Module['preRun'].push(function (){
	window.indexedDB = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
	if (!window.indexedDB)
		return;
	FS.mkdir('/idbfs');
	FS.mount(IDBFS, {}, '/idbfs');
	Module.addRunDependency('JS_FileSystem_Mount');
	FS.syncfs(true, function (err) {
		Module.removeRunDependency('JS_FileSystem_Mount'); 
	});
});
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  if (!Module['printErr']) Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };

  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    var data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  this['Module'] = Module;

}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WEB) {
    window['Module'] = Module;
  } else {
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
if (!Module['thisProgram']) {
  Module['thisProgram'] = './this.program';
}

// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}



// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in: 
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at: 
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  STACK_ALIGN: 16,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  getAsmConst: function (code, numArgs) {
    // code is a constant string on the heap, so we can cache these
    if (!Runtime.asmConstCache) Runtime.asmConstCache = {};
    var func = Runtime.asmConstCache[code];
    if (func) return func;
    var args = [];
    for (var i = 0; i < numArgs; i++) {
      args.push(String.fromCharCode(36) + i); // $0, $1 etc
    }
    var source = Pointer_stringify(code);
    if (source[0] === '"') {
      // tolerate EM_ASM("..code..") even though EM_ASM(..code..) is correct
      if (source.indexOf('"', 1) === source.length-1) {
        source = source.substr(1, source.length-2);
      } else {
        // something invalid happened, e.g. EM_ASM("..code($0)..", input)
        abort('invalid EM_ASM input |' + source + '|. Please use EM_ASM(..code..) (no quotes) or EM_ASM({ ..code($0).. }, input) (to input values)');
      }
    }
    try {
      // Module is the only 'upvar', which we provide directly. We also provide FS for legacy support.
      var evalled = eval('(function(Module, FS) { return function(' + args.join(',') + '){ ' + source + ' } })')(Module, typeof FS !== 'undefined' ? FS : null);
    } catch(e) {
      Module.printErr('error in executing inline EM_ASM code: ' + e + ' on: \n\n' + source + '\n\nwith args |' + args + '| (make sure to use the right one out of EM_ASM, EM_ASM_ARGS, etc.)');
      throw e;
    }
    return Runtime.asmConstCache[code] = evalled;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[sig]) {
      Runtime.funcWrappers[sig] = {};
    }
    var sigCache = Runtime.funcWrappers[sig];
    if (!sigCache[func]) {
      sigCache[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return sigCache[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;

      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }

      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }

      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          (((codePoint - 0x10000) / 0x400)|0) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function processJSString(string) {
      /* TODO: use TextEncoder when present,
        var encoder = new TextEncoder();
        encoder['encoding'] = "utf-8";
        var utf8Array = encoder['encode'](aMsg.data);
      */
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+15)&-16); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = (((STATICTOP)+15)&-16); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = (((DYNAMICTOP)+15)&-16); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 16))*(quantum ? quantum : 16); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*4294967296.0)) : ((+((low>>>0)))+((+((high|0)))*4294967296.0))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}


Module['Runtime'] = Runtime;









//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  if (!func) {
    try {
      func = eval('_' + ident); // explicit lookup
    } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

var cwrap, ccall;
(function(){
  var stack = 0;
  var JSfuncs = {
    'stackSave' : function() {
      stack = Runtime.stackSave();
    },
    'stackRestore' : function() {
      Runtime.stackRestore(stack);
    },
    // type conversion from js to c
    'arrayToC' : function(arr) {
      var ret = Runtime.stackAlloc(arr.length);
      writeArrayToMemory(arr, ret);
      return ret;
    },
    'stringToC' : function(str) {
      var ret = 0;
      if (str !== null && str !== undefined && str !== 0) { // null string
        // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
        ret = Runtime.stackAlloc((str.length << 2) + 1);
        writeStringToMemory(str, ret);
      }
      return ret;
    }
  };
  // For fast lookup of conversion functions
  var toC = {'string' : JSfuncs['stringToC'], 'array' : JSfuncs['arrayToC']};

  // C calling interface. 
  ccall = function ccallFunc(ident, returnType, argTypes, args) {
    var func = getCFunc(ident);
    var cArgs = [];
    if (args) {
      for (var i = 0; i < args.length; i++) {
        var converter = toC[argTypes[i]];
        if (converter) {
          if (stack === 0) stack = Runtime.stackSave();
          cArgs[i] = converter(args[i]);
        } else {
          cArgs[i] = args[i];
        }
      }
    }
    var ret = func.apply(null, cArgs);
    if (returnType === 'string') ret = Pointer_stringify(ret);
    if (stack !== 0) JSfuncs['stackRestore']();
    return ret;
  }

  var sourceRegex = /^function\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
  function parseJSFunc(jsfunc) {
    // Match the body and the return value of a javascript function source
    var parsed = jsfunc.toString().match(sourceRegex).slice(1);
    return {arguments : parsed[0], body : parsed[1], returnValue: parsed[2]}
  }
  var JSsource = {};
  for (var fun in JSfuncs) {
    if (JSfuncs.hasOwnProperty(fun)) {
      // Elements of toCsource are arrays of three items:
      // the code, and the return value
      JSsource[fun] = parseJSFunc(JSfuncs[fun]);
    }
  }

  
  cwrap = function cwrap(ident, returnType, argTypes) {
    argTypes = argTypes || [];
    var cfunc = getCFunc(ident);
    // When the function takes numbers and returns a number, we can just return
    // the original function
    var numericArgs = argTypes.every(function(type){ return type === 'number'});
    var numericRet = (returnType !== 'string');
    if ( numericRet && numericArgs) {
      return cfunc;
    }
    // Creation of the arguments list (["$1","$2",...,"$nargs"])
    var argNames = argTypes.map(function(x,i){return '$'+i});
    var funcstr = "(function(" + argNames.join(',') + ") {";
    var nargs = argTypes.length;
    if (!numericArgs) {
      // Generate the code needed to convert the arguments from javascript
      // values to pointers
      funcstr += JSsource['stackSave'].body + ';';
      for (var i = 0; i < nargs; i++) {
        var arg = argNames[i], type = argTypes[i];
        if (type === 'number') continue;
        var convertCode = JSsource[type + 'ToC']; // [code, return]
        funcstr += 'var ' + convertCode.arguments + ' = ' + arg + ';';
        funcstr += convertCode.body + ';';
        funcstr += arg + '=' + convertCode.returnValue + ';';
      }
    }

    // When the code is compressed, the name of cfunc is not literally 'cfunc' anymore
    var cfuncname = parseJSFunc(function(){return cfunc}).returnValue;
    // Call the function
    funcstr += 'var ret = ' + cfuncname + '(' + argNames.join(',') + ');';
    if (!numericRet) { // Return type can only by 'string' or 'number'
      // Convert the result to a string
      var strgfy = parseJSFunc(function(){return Pointer_stringify}).returnValue;
      funcstr += 'ret = ' + strgfy + '(ret);';
    }
    if (!numericArgs) {
      // If we had a stack, restore it
      funcstr += JSsource['stackRestore'].body + ';';
    }
    funcstr += 'return ret})';
    return eval(funcstr);
  };
})();
Module["cwrap"] = cwrap;
Module["ccall"] = ccall;


function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;


function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }

  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

function UTF16ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;


function stringToUTF16(str, outPtr) {
  for(var i = 0; i < str.length; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[(((outPtr)+(i*2))>>1)]=codeUnit;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[(((outPtr)+(str.length*2))>>1)]=0;
}
Module['stringToUTF16'] = stringToUTF16;


function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;


function stringToUTF32(str, outPtr) {
  var iChar = 0;
  for(var iCodeUnit = 0; iCodeUnit < str.length; ++iCodeUnit) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    var codeUnit = str.charCodeAt(iCodeUnit); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++iCodeUnit);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[(((outPtr)+(iChar*4))>>2)]=codeUnit;
    ++iChar;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[(((outPtr)+(iChar*4))>>2)]=0;
}
Module['stringToUTF32'] = stringToUTF32;

function demangle(func) {
  var hasLibcxxabi = !!Module['___cxa_demangle'];
  if (hasLibcxxabi) {
    try {
      var buf = _malloc(func.length);
      writeStringToMemory(func.substr(1), buf);
      var status = _malloc(4);
      var ret = Module['___cxa_demangle'](buf, 0, 0, status);
      if (getValue(status, 'i32') === 0 && ret) {
        return Pointer_stringify(ret);
      }
      // otherwise, libcxxabi failed, we can try ours which may return a partial result
    } catch(e) {
      // failure when using libcxxabi, we can try ours which may return a partial result
    } finally {
      if (buf) _free(buf);
      if (status) _free(status);
      if (ret) _free(ret);
    }
  }
  var i = 3;
  // params, etc.
  var basicTypes = {
    'v': 'void',
    'b': 'bool',
    'c': 'char',
    's': 'short',
    'i': 'int',
    'l': 'long',
    'f': 'float',
    'd': 'double',
    'w': 'wchar_t',
    'a': 'signed char',
    'h': 'unsigned char',
    't': 'unsigned short',
    'j': 'unsigned int',
    'm': 'unsigned long',
    'x': 'long long',
    'y': 'unsigned long long',
    'z': '...'
  };
  var subs = [];
  var first = true;
  function dump(x) {
    //return;
    if (x) Module.print(x);
    Module.print(func);
    var pre = '';
    for (var a = 0; a < i; a++) pre += ' ';
    Module.print (pre + '^');
  }
  function parseNested() {
    i++;
    if (func[i] === 'K') i++; // ignore const
    var parts = [];
    while (func[i] !== 'E') {
      if (func[i] === 'S') { // substitution
        i++;
        var next = func.indexOf('_', i);
        var num = func.substring(i, next) || 0;
        parts.push(subs[num] || '?');
        i = next+1;
        continue;
      }
      if (func[i] === 'C') { // constructor
        parts.push(parts[parts.length-1]);
        i += 2;
        continue;
      }
      var size = parseInt(func.substr(i));
      var pre = size.toString().length;
      if (!size || !pre) { i--; break; } // counter i++ below us
      var curr = func.substr(i + pre, size);
      parts.push(curr);
      subs.push(curr);
      i += pre + size;
    }
    i++; // skip E
    return parts;
  }
  function parse(rawList, limit, allowVoid) { // main parser
    limit = limit || Infinity;
    var ret = '', list = [];
    function flushList() {
      return '(' + list.join(', ') + ')';
    }
    var name;
    if (func[i] === 'N') {
      // namespaced N-E
      name = parseNested().join('::');
      limit--;
      if (limit === 0) return rawList ? [name] : name;
    } else {
      // not namespaced
      if (func[i] === 'K' || (first && func[i] === 'L')) i++; // ignore const and first 'L'
      var size = parseInt(func.substr(i));
      if (size) {
        var pre = size.toString().length;
        name = func.substr(i + pre, size);
        i += pre + size;
      }
    }
    first = false;
    if (func[i] === 'I') {
      i++;
      var iList = parse(true);
      var iRet = parse(true, 1, true);
      ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
    } else {
      ret = name;
    }
    paramLoop: while (i < func.length && limit-- > 0) {
      //dump('paramLoop');
      var c = func[i++];
      if (c in basicTypes) {
        list.push(basicTypes[c]);
      } else {
        switch (c) {
          case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
          case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
          case 'L': { // literal
            i++; // skip basic type
            var end = func.indexOf('E', i);
            var size = end - i;
            list.push(func.substr(i, size));
            i += size + 2; // size + 'EE'
            break;
          }
          case 'A': { // array
            var size = parseInt(func.substr(i));
            i += size.toString().length;
            if (func[i] !== '_') throw '?';
            i++; // skip _
            list.push(parse(true, 1, true)[0] + ' [' + size + ']');
            break;
          }
          case 'E': break paramLoop;
          default: ret += '?' + c; break paramLoop;
        }
      }
    }
    if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
    if (rawList) {
      if (ret) {
        list.push(ret + '?');
      }
      return list;
    } else {
      return ret + flushList();
    }
  }
  var final = func;
  try {
    // Special-case the entry point, since its name differs from other name mangling.
    if (func == 'Object._main' || func == '_main') {
      return 'main()';
    }
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    switch (func[3]) {
      case 'n': return 'operator new()';
      case 'd': return 'operator delete()';
    }
    final = parse();
  } catch(e) {
    final += '?';
  }
  if (final.indexOf('?') >= 0 && !hasLibcxxabi) {
    Runtime.warnOnce('warning: a problem occurred in builtin C++ name demangling; build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  }
  return final;
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  return demangleAll(jsStackTrace());
}
Module['stackTrace'] = stackTrace;

// Memory management

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return (x+4095)&-4096;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk

function enlargeMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.');
}

var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 268435456;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;

var totalMemory = 64*1024;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be more reasonable');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');

var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;
var runtimeExited = false;

function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;

// Tools


function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))>>0)]=chr;
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))>>0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; i++) {
    HEAP8[(((buffer)+(i))>>0)]=str.charCodeAt(i);
  }
  if (!dontAddNull) HEAP8[(((buffer)+(str.length))>>0)]=0;
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];

if (!Math['fround']) Math['fround'] = function(x) { return x };
Math.fround = Math['fround'];

var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data


var memoryInitializer = null;

// === Body ===





STATIC_BASE = 8;

STATICTOP = STATIC_BASE + Runtime.alignMemory(3111363);
  /* global initializers */ __ATINIT__.push({ func: function() { __GLOBAL__I_a1261() } }, { func: function() { __GLOBAL__I_a1253() } }, { func: function() { __GLOBAL__I_a4171() } }, { func: function() { __GLOBAL__I_a4182() } }, { func: function() { __GLOBAL__I_a4186() } }, { func: function() { __GLOBAL__I_a4208() } }, { func: function() { __GLOBAL__I_a4557() } }, { func: function() { __GLOBAL__I_a6522() } }, { func: function() { __GLOBAL__I_a1306() } }, { func: function() { __GLOBAL__I_a1532() } }, { func: function() { __GLOBAL__I_a1629() } }, { func: function() { __GLOBAL__I_a1638() } }, { func: function() { __GLOBAL__I_a1651() } }, { func: function() { __GLOBAL__I_a1667() } }, { func: function() { __GLOBAL__I_a1688() } }, { func: function() { __GLOBAL__I_a1817() } }, { func: function() { __GLOBAL__I_a1915() } }, { func: function() { __GLOBAL__I_a1998() } }, { func: function() { __GLOBAL__I_a2062() } }, { func: function() { __GLOBAL__I_a2431() } }, { func: function() { __GLOBAL__I_a2482() } }, { func: function() { __GLOBAL__I_a2517() } }, { func: function() { __GLOBAL__I_a2967() } }, { func: function() { __GLOBAL__I_a3258() } }, { func: function() { __GLOBAL__I_a3392() } }, { func: function() { __GLOBAL__I_a3547() } }, { func: function() { __GLOBAL__I_a3708() } }, { func: function() { __GLOBAL__I_a4056() } }, { func: function() { __GLOBAL__I_a4778() } }, { func: function() { __GLOBAL__I_a6056() } }, { func: function() { __GLOBAL__I_a6584() } }, { func: function() { __GLOBAL__I_a8226() } }, { func: function() { __GLOBAL__I_a8687() } }, { func: function() { __GLOBAL__I_a9384() } }, { func: function() { __GLOBAL__I_a11687() } }, { func: function() { __GLOBAL__I_a11737() } }, { func: function() { __GLOBAL__I_a13766() } }, { func: function() { __GLOBAL__I_a18997() } }, { func: function() { __GLOBAL__I_a19751() } }, { func: function() { __GLOBAL__I_a19771() } }, { func: function() { __GLOBAL__I_a19829() } }, { func: function() { __GLOBAL__I_a20005() } }, { func: function() { __GLOBAL__I_a20041() } }, { func: function() { __GLOBAL__I_a20087() } }, { func: function() { __GLOBAL__I_a21124() } }, { func: function() { __GLOBAL__I_a21804() } }, { func: function() { __GLOBAL__I_a1263() } }, { func: function() { __GLOBAL__I_a5() } }, { func: function() { __GLOBAL__I_a9() } }, { func: function() { __GLOBAL__I_a14() } }, { func: function() { __GLOBAL__I_a23365() } }, { func: function() { __GLOBAL__I_a23371() } }, { func: function() { __GLOBAL__I_a23378() } }, { func: function() { __GLOBAL__I_a23385() } }, { func: function() { __GLOBAL__I_a23391() } }, { func: function() { __GLOBAL__I_a1496() } });
  

var memoryInitializer = "WebGL.html.mem";




var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}


  var _UItoF=true;

  var _UItoD=true;

  
  var GL={counter:1,lastError:0,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],vaos:[],contexts:[],byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],programInfos:{},stringCache:{},packAlignment:4,unpackAlignment:4,init:function () {
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
      },recordError:function recordError(errorCode) {
        if (!GL.lastError) {
          GL.lastError = errorCode;
        }
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:16,miniTempBuffer:null,miniTempBufferViews:[0],getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        return source;
      },computeImageSize:function (width, height, sizePerPixel, alignment) {
        // FIXME: possible bug with negative x
        function roundedToNextMultipleOf(x, y) {
          return Math.floor((x + y - 1) / y) * y
        }
        var plainRowSize = width * sizePerPixel;
        var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
        return (height <= 0) ? 0 :
                 ((height - 1) * alignedRowSize + plainRowSize);
      },get:function (name_, p, type) {
        // Guard against user passing a null pointer.
        // Note that GLES2 spec does not say anything about how passing a null pointer should be treated.
        // Testing on desktop core GL 3, the application crashes on glGetIntegerv to a null pointer, but
        // better to report an error instead of doing anything random.
        if (!p) {
          GL.recordError(0x0501 /* GL_INVALID_VALUE */);
          return;
        }
        var ret = undefined;
        switch(name_) { // Handle a few trivial GLES values
          case 0x8DFA: // GL_SHADER_COMPILER
            ret = 1;
            break;
          case 0x8DF8: // GL_SHADER_BINARY_FORMATS
            if (type !== 'Integer') {
              GL.recordError(0x0500); // GL_INVALID_ENUM
            }
            return; // Do not write anything to the out pointer, since no binary formats are supported.
          case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
            ret = 0;
            break;
          case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
            // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
            // so implement it ourselves to allow C++ GLES2 code get the length.
            var formats = GLctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
            ret = formats.length;
            break;
          case 0x8B9A: // GL_IMPLEMENTATION_COLOR_READ_TYPE
            ret = 0x1401; // GL_UNSIGNED_BYTE
            break;
          case 0x8B9B: // GL_IMPLEMENTATION_COLOR_READ_FORMAT
            ret = 0x1908; // GL_RGBA
            break;
        }
  
        if (ret === undefined) {
          var result = GLctx.getParameter(name_);
          switch (typeof(result)) {
            case "number":
              ret = result;
              break;
            case "boolean":
              ret = result ? 1 : 0;
              break;
            case "string":
              GL.recordError(0x0500); // GL_INVALID_ENUM
              return;
            case "object":
              if (result === null) {
                // null is a valid result for some (e.g., which buffer is bound - perhaps nothing is bound), but otherwise
                // can mean an invalid name_, which we need to report as an error
                switch(name_) {
                  case 0x8894: // ARRAY_BUFFER_BINDING
                  case 0x8B8D: // CURRENT_PROGRAM
                  case 0x8895: // ELEMENT_ARRAY_BUFFER_BINDING
                  case 0x8CA6: // FRAMEBUFFER_BINDING
                  case 0x8CA7: // RENDERBUFFER_BINDING
                  case 0x8069: // TEXTURE_BINDING_2D
                  case 0x8514: { // TEXTURE_BINDING_CUBE_MAP
                    ret = 0;
                    break;
                  }
                  default: {
                    GL.recordError(0x0500); // GL_INVALID_ENUM
                    return;
                  }
                }
              } else if (result instanceof Float32Array ||
                         result instanceof Uint32Array ||
                         result instanceof Int32Array ||
                         result instanceof Array) {
                for (var i = 0; i < result.length; ++i) {
                  switch (type) {
                    case 'Integer': HEAP32[(((p)+(i*4))>>2)]=result[i];   break;
                    case 'Float':   HEAPF32[(((p)+(i*4))>>2)]=result[i]; break;
                    case 'Boolean': HEAP8[(((p)+(i))>>0)]=result[i] ? 1 : 0;    break;
                    default: throw 'internal glGet error, bad type: ' + type;
                  }
                }
                return;
              } else if (result instanceof WebGLBuffer ||
                         result instanceof WebGLProgram ||
                         result instanceof WebGLFramebuffer ||
                         result instanceof WebGLRenderbuffer ||
                         result instanceof WebGLTexture) {
                ret = result.name | 0;
              } else {
                GL.recordError(0x0500); // GL_INVALID_ENUM
                return;
              }
              break;
            default:
              GL.recordError(0x0500); // GL_INVALID_ENUM
              return;
          }
        }
  
        switch (type) {
          case 'Integer': HEAP32[((p)>>2)]=ret;    break;
          case 'Float':   HEAPF32[((p)>>2)]=ret;  break;
          case 'Boolean': HEAP8[((p)>>0)]=ret ? 1 : 0; break;
          default: throw 'internal glGet error, bad type: ' + type;
        }
      },getTexPixelData:function (type, format, width, height, pixels, internalFormat) {
        var sizePerPixel;
        switch (type) {
          case 0x1401 /* GL_UNSIGNED_BYTE */:
            switch (format) {
              case 0x1906 /* GL_ALPHA */:
              case 0x1909 /* GL_LUMINANCE */:
                sizePerPixel = 1;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4;
                break;
              case 0x190A /* GL_LUMINANCE_ALPHA */:
                sizePerPixel = 2;
                break;
              default:
                GL.recordError(0x0500); // GL_INVALID_ENUM
                return {
                  pixels: null,
                  internalFormat: 0x0
                };
            }
            break;
          case 0x1403 /* GL_UNSIGNED_SHORT */:
            if (format == 0x1902 /* GL_DEPTH_COMPONENT */) {
              sizePerPixel = 2;
            } else {
              GL.recordError(0x0500); // GL_INVALID_ENUM
              return {
                pixels: null,
                internalFormat: 0x0
              };
            }
            break;
          case 0x1405 /* GL_UNSIGNED_INT */:
            if (format == 0x1902 /* GL_DEPTH_COMPONENT */) {
              sizePerPixel = 4;
            } else {
              GL.recordError(0x0500); // GL_INVALID_ENUM
              return {
                pixels: null,
                internalFormat: 0x0
              };
            }
            break;
          case 0x84FA /* UNSIGNED_INT_24_8_WEBGL */:
            sizePerPixel = 4;
            break;
          case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
          case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
          case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
            sizePerPixel = 2;
            break;
          case 0x1406 /* GL_FLOAT */:
            switch (format) {
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*4;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*4;
                break;
              default:
                GL.recordError(0x0500); // GL_INVALID_ENUM
                return {
                  pixels: null,
                  internalFormat: 0x0
                };
            }
            internalFormat = GLctx.RGBA;
            break;
          case 0x8D61 /* GL_HALF_FLOAT_OES */:
            switch (format) {
              case 0x1903 /* GL_RED */:
                sizePerPixel = 2;
                break;
              case 0x8277 /* GL_RG */:
                sizePerPixel = 2*2;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*2;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*2;
                break;
              default:
                GL.recordError(0x0500); // GL_INVALID_ENUM
                return {
                  pixels: null,
                  internalFormat: 0x0
                };
            }
            break;
          default:
            GL.recordError(0x0500); // GL_INVALID_ENUM
            return {
              pixels: null,
              internalFormat: 0x0
            };
        }
        var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
        if (type == 0x1401 /* GL_UNSIGNED_BYTE */) {
          pixels = HEAPU8.subarray((pixels),(pixels+bytes));
        } else if (type == 0x1406 /* GL_FLOAT */) {
          pixels = HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else if (type == 0x1405 /* GL_UNSIGNED_INT */ || type == 0x84FA /* UNSIGNED_INT_24_8_WEBGL */) {
          pixels = HEAPU32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else {
          pixels = HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        }
        return {
          pixels: pixels,
          internalFormat: internalFormat
        };
      },createContext:function (canvas, webGLContextAttributes) {
        // Default to creating a WebGL 1.0 context if nothing else is specified.
        if (typeof webGLContextAttributes.majorVersion === 'undefined' && typeof webGLContextAttributes.minorVersion === 'undefined') {
          webGLContextAttributes.majorVersion = 1;
          webGLContextAttributes.minorVersion = 0;
        }
        var ctx;
        var errorInfo = '?';
        function onContextCreationError(event) {
          errorInfo = event.statusMessage || errorInfo;
        }
        try {
          canvas.addEventListener('webglcontextcreationerror', onContextCreationError, false);
          try {
            if (webGLContextAttributes.majorVersion == 1 && webGLContextAttributes.minorVersion == 0) {
              ctx = canvas.getContext("webgl", webGLContextAttributes) || canvas.getContext("experimental-webgl", webGLContextAttributes);
            } else {
              throw 'Unsupported WebGL context version ' + majorVersion + '.' + minorVersion + '!'
            }
          } finally {
            canvas.removeEventListener('webglcontextcreationerror', onContextCreationError, false);
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas: ' + [errorInfo, e]);
          return 0;
        }
        // possible GL_DEBUG entry point: ctx = wrapDebugGL(ctx);
  
        if (!ctx) return 0;
        var handle = GL.getNewId(GL.contexts);
        var context = { handle: handle };
        context.GLctx = ctx;
        GL.contexts[handle] = context;
        if (typeof webGLContextAttributes['webGLContextAttributes'] === 'undefined' || webGLContextAttributes.enableExtensionsByDefault) {
          GL.initExtensions(context);
        }
        return handle;
      },makeContextCurrent:function (contextHandle) {
        var context = GL.contexts[contextHandle];
        if (!context) return false;
        GLctx = Module.ctx = context.GLctx; // Active WebGL context object.
        GL.currentContext = context; // Active Emscripten GL layer context object.
        return true;
      },getContext:function (contextHandle) {
        return GL.contexts[contextHandle];
      },deleteContext:function (contextHandle) {
        if (GL.currentContext === GL.contexts[contextHandle]) GL.currentContext = 0;
        GL.contexts[contextHandle] = null;
      },initExtensions:function (context) {
  
        // If this function is called without a specific context object, init the extensions of the currently active context.
        if (!context) context = GL.currentContext;
  
        if (context.initExtensionsDone) return;
        context.initExtensionsDone = true;
  
        var GLctx = context.GLctx;
  
        context.maxVertexAttribs = GLctx.getParameter(GLctx.MAX_VERTEX_ATTRIBS);
  
        // Detect the presence of a few extensions manually, this GL interop layer itself will need to know if they exist. 
        context.compressionExt = GLctx.getExtension('WEBGL_compressed_texture_s3tc') ||
                            GLctx.getExtension('MOZ_WEBGL_compressed_texture_s3tc') ||
                            GLctx.getExtension('WEBKIT_WEBGL_compressed_texture_s3tc');
  
        context.anisotropicExt = GLctx.getExtension('EXT_texture_filter_anisotropic') ||
                            GLctx.getExtension('MOZ_EXT_texture_filter_anisotropic') ||
                            GLctx.getExtension('WEBKIT_EXT_texture_filter_anisotropic');
  
        context.floatExt = GLctx.getExtension('OES_texture_float');
  
        // Extension available from Firefox 26 and Google Chrome 30
        context.instancedArraysExt = GLctx.getExtension('ANGLE_instanced_arrays');
        
        // Extension available from Firefox 25 and WebKit
        context.vaoExt = GLctx.getExtension('OES_vertex_array_object');
  
        context.drawBuffersExt = GLctx.getExtension('WEBGL_draw_buffers');
  
        // These are the 'safe' feature-enabling extensions that don't add any performance impact related to e.g. debugging, and
        // should be enabled by default so that client GLES2/GL code will not need to go through extra hoops to get its stuff working.
        // As new extensions are ratified at http://www.khronos.org/registry/webgl/extensions/ , feel free to add your new extensions
        // here, as long as they don't produce a performance impact for users that might not be using those extensions.
        // E.g. debugging-related extensions should probably be off by default.
        var automaticallyEnabledExtensions = [ "OES_texture_float", "OES_texture_half_float", "OES_standard_derivatives",
                                               "OES_vertex_array_object", "WEBGL_compressed_texture_s3tc", "WEBGL_depth_texture",
                                               "OES_element_index_uint", "EXT_texture_filter_anisotropic", "ANGLE_instanced_arrays",
                                               "OES_texture_float_linear", "OES_texture_half_float_linear", "WEBGL_compressed_texture_atc",
                                               "WEBGL_compressed_texture_pvrtc", "EXT_color_buffer_half_float", "WEBGL_color_buffer_float",
                                               "EXT_frag_depth", "EXT_sRGB", "WEBGL_draw_buffers", "WEBGL_shared_resources",
                                               "EXT_shader_texture_lod" ];
  
        function shouldEnableAutomatically(extension) {
          var ret = false;
          automaticallyEnabledExtensions.forEach(function(include) {
            if (ext.indexOf(include) != -1) {
              ret = true;
            }
          });
          return ret;
        }
  
   
        GLctx.getSupportedExtensions().forEach(function(ext) {
          ext = ext.replace('MOZ_', '').replace('WEBKIT_', '');
          if (automaticallyEnabledExtensions.indexOf(ext) != -1) {
            GLctx.getExtension(ext); // Calling .getExtension enables that extension permanently, no need to store the return value to be enabled.
          }
        });
      },populateUniformTable:function (program) {
        var p = GL.programs[program];
        GL.programInfos[program] = {
          uniforms: {},
          maxUniformLength: 0, // This is eagerly computed below, since we already enumerate all uniforms anyway.
          maxAttributeLength: -1 // This is lazily computed and cached, computed when/if first asked, "-1" meaning not computed yet.
        };
  
        var ptable = GL.programInfos[program];
        var utable = ptable.uniforms;
        // A program's uniform table maps the string name of an uniform to an integer location of that uniform.
        // The global GL.uniforms map maps integer locations to WebGLUniformLocations.
        var numUniforms = GLctx.getProgramParameter(p, GLctx.ACTIVE_UNIFORMS);
        for (var i = 0; i < numUniforms; ++i) {
          var u = GLctx.getActiveUniform(p, i);
  
          var name = u.name;
          ptable.maxUniformLength = Math.max(ptable.maxUniformLength, name.length+1);
  
          // Strip off any trailing array specifier we might have got, e.g. "[0]".
          if (name.indexOf(']', name.length-1) !== -1) {
            var ls = name.lastIndexOf('[');
            name = name.slice(0, ls);
          }
  
          // Optimize memory usage slightly: If we have an array of uniforms, e.g. 'vec3 colors[3];', then 
          // only store the string 'colors' in utable, and 'colors[0]', 'colors[1]' and 'colors[2]' will be parsed as 'colors'+i.
          // Note that for the GL.uniforms table, we still need to fetch the all WebGLUniformLocations for all the indices.
          var loc = GLctx.getUniformLocation(p, name);
          var id = GL.getNewId(GL.uniforms);
          utable[name] = [u.size, id];
          GL.uniforms[id] = loc;
  
          for (var j = 1; j < u.size; ++j) {
            var n = name + '['+j+']';
            loc = GLctx.getUniformLocation(p, n);
            id = GL.getNewId(GL.uniforms);
  
            GL.uniforms[id] = loc;
          }
        }
      }};function _emscripten_glStencilMaskSeparate(x0, x1) { GLctx.stencilMaskSeparate(x0, x1) }

  
  
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value;
      return value;
    }
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            return ''; // an invalid portion invalidates the whole thing
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  
  var MEMFS={ops_table:null,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            },
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.usedBytes = 0; // The actual number of bytes used in the typed array, as opposed to contents.buffer.byteLength which gives the whole capacity.
          // When the byte data of the file is populated, this will point to either a typed array, or a normal JS array. Typed arrays are preferred
          // for performance, and used by default. However, typed arrays are not resizable like normal JS arrays are, so there is a small disk size
          // penalty involved for appending file writes that continuously grow a file similar to std::vector capacity vs used -scheme.
          node.contents = null; 
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },getFileDataAsRegularArray:function (node) {
        if (node.contents && node.contents.subarray) {
          var arr = [];
          for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
          return arr; // Returns a copy of the original data.
        }
        return node.contents; // No-op, the file contents are already in a JS array. Return as-is.
      },getFileDataAsTypedArray:function (node) {
        if (node.contents && node.contents.subarray) return node.contents.subarray(0, node.usedBytes); // Make sure to not return excess unused bytes.
        return new Uint8Array(node.contents);
      },expandFileStorage:function (node, newCapacity) {
  
        // If we are asked to expand the size of a file that already exists, revert to using a standard JS array to store the file
        // instead of a typed array. This makes resizing the array more flexible because we can just .push() elements at the back to
        // increase the size.
        if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
          node.contents = MEMFS.getFileDataAsRegularArray(node);
          node.usedBytes = node.contents.length; // We might be writing to a lazy-loaded file which had overridden this property, so force-reset it.
        }
  
        if (!node.contents || node.contents.subarray) { // Keep using a typed array if creating a new storage, or if old one was a typed array as well.
          var prevCapacity = node.contents ? node.contents.buffer.byteLength : 0;
          if (prevCapacity >= newCapacity) return; // No need to expand, the storage was already large enough.
          // Don't expand strictly to the given requested limit if it's only a very small increase, but instead geometrically grow capacity.
          // For small filesizes (<1MB), perform size*2 geometric increase, but for large sizes, do a much more conservative size*1.125 increase to
          // avoid overshooting the allocation cap by a very large margin.
          var CAPACITY_DOUBLING_MAX = 1024 * 1024;
          newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2.0 : 1.125)) | 0);
          if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256); // At minimum allocate 256b for each file when expanding.
          var oldContents = node.contents;
          node.contents = new Uint8Array(newCapacity); // Allocate new storage.
          if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0); // Copy old data over to the new storage.
          return;
        }
        // Not using a typed array to back the file storage. Use a standard JS array instead.
        if (!node.contents && newCapacity > 0) node.contents = [];
        while (node.contents.length < newCapacity) node.contents.push(0);
      },resizeFileStorage:function (node, newSize) {
        if (node.usedBytes == newSize) return;
        if (newSize == 0) {
          node.contents = null; // Fully decommit when requesting a resize to zero.
          node.usedBytes = 0;
          return;
        }
  
        if (!node.contents || node.contents.subarray) { // Resize a typed array if that is being used as the backing store.
          var oldContents = node.contents;
          node.contents = new Uint8Array(new ArrayBuffer(newSize)); // Allocate new storage.
          if (oldContents) {
            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes))); // Copy old data over to the new storage.
          }
          node.usedBytes = newSize;
          return;
        }
        // Backing with a JS array.
        if (!node.contents) node.contents = [];
        if (node.contents.length > newSize) node.contents.length = newSize;
        else while (node.contents.length < newSize) node.contents.push(0);
        node.usedBytes = newSize;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.usedBytes;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.resizeFileStorage(node, attr.size);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= stream.node.usedBytes) return 0;
          var size = Math.min(stream.node.usedBytes - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          if (!length) return 0;
          var node = stream.node;
          node.timestamp = Date.now();
  
          if (buffer.subarray && (!node.contents || node.contents.subarray)) { // This write is from a typed array to a typed array?
            if (canOwn) { // Can we just reuse the buffer we are given?
              node.contents = buffer.subarray(offset, offset + length);
              node.usedBytes = length;
              return length;
            } else if (node.usedBytes === 0 && position === 0) { // If this is a simple first write to an empty file, do a fast set since we don't need to care about old data.
              node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
              node.usedBytes = length;
              return length;
            } else if (position + length <= node.usedBytes) { // Writing to an already allocated and used subrange of the file?
              node.contents.set(buffer.subarray(offset, offset + length), position);
              return length;
            }
          }
          // Appending to an existing file and we need to reallocate, or source data did not come as a typed array.
          MEMFS.expandFileStorage(node, position+length);
          if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); // Use typed array write if available.
          else
            for (var i = 0; i < length; i++) {
             node.contents[position + i] = buffer[offset + i]; // Or fall back to manual write if not.
            }
          node.usedBytes = Math.max(node.usedBytes, position+length);
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.usedBytes;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.expandFileStorage(stream.node, offset + length);
          stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < stream.node.usedBytes) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        if (typeof indexedDB !== 'undefined') return indexedDB;
        var ret = null;
        if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
        assert(ret, 'IDBFS used, but indexedDB not supported');
        return ret;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          fileStore.createIndex('timestamp', 'timestamp', { unique: false });
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function() {
          callback(this.error);
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function() { callback(this.error); };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          // Performance consideration: storing a normal JavaScript array to a IndexedDB is much slower than storing a typed array.
          // Therefore always convert the file contents to a typed array first before writing the data to IndexedDB.
          node.contents = MEMFS.getFileDataAsTypedArray(node);
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.chmod(path, entry.mode);
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function() { callback(this.error); };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function() { done(this.error); };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so 
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          stream.position = position;
          return position;
        }}};
  
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        if (!path) return { path: '', node: null };
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err, parent);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); },
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); },
            },
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        var err = FS.nodePermissions(dir, 'x');
        if (err) return err;
        if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
        return 0;
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getStreamFromPtr:function (ptr) {
        return FS.streams[ptr - 1];
      },getPtrForStream:function (stream) {
        return stream ? stream.fd + 1 : 0;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            callback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        if (!name || name === '.' || name === '..') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        if (!PATH.resolve(oldpath)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        if (!parent) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        if (path === "") {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        var created = false;
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
            created = true;
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions, if this is not a file we just created now (it is ok to
        // create and write to a file with read-only permissions; it is read-only
        // for later use)
        if (!created) {
          var err = FS.mayOpen(node, flags);
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = '';
          var utf8 = new Runtime.UTF8Processor();
          for (var i = 0; i < length; i++) {
            ret += utf8.processCChar(buf[i]);
          }
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var utf8 = new Runtime.UTF8Processor();
          var buf = new Uint8Array(utf8.processJSString(data));
          FS.write(stream, buf, 0, buf.length, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
        FS.mkdir('/home');
        FS.mkdir('/home/web_user');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // setup /dev/[u]random
        var random_device;
        if (typeof crypto !== 'undefined') {
          // for modern web browsers
          var randomBuffer = new Uint8Array(1);
          random_device = function() { crypto.getRandomValues(randomBuffer); return randomBuffer[0]; };
        } else if (ENVIRONMENT_IS_NODE) {
          // for nodejs
          random_device = function() { return require('crypto').randomBytes(1)[0]; };
        } else {
          // default for ES5 platforms
          random_device = function() { return (Math.random()*256)|0; };
        }
        FS.createDevice('/dev', 'random', random_device);
        FS.createDevice('/dev', 'urandom', random_device);
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=FS.getPtrForStream(stdin);
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=FS.getPtrForStream(stdout);
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=FS.getPtrForStream(stderr);
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno, node) {
          this.node = node;
          this.setErrno = function(errno) {
            this.errno = errno;
            for (var key in ERRNO_CODES) {
              if (ERRNO_CODES[key] === errno) {
                this.code = key;
                break;
              }
            }
          };
          this.setErrno(errno);
          this.message = ERRNO_MESSAGES[errno];
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
            obj.usedBytes = obj.contents.length;
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = (idx / this.chunkSize)|0;
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var chunkSize = 1024*1024; // Chunk size in bytes
  
          if (!hasByteServing) chunkSize = datalength;
  
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
  
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = this;
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * chunkSize;
            var end = (chunkNum+1) * chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
  
          this._length = datalength;
          this._chunkSize = chunkSize;
          this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // Add a function that defers querying the file size until it is asked the first time.
        Object.defineProperty(node, "usedBytes", {
            get: function() { return this.contents.length; }
        });
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) return -1;
      return stream.fd;
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      var fd = _fileno(stream);
      _fsync(fd);
      return _close(fd);
    }

  function _pthread_mutex_lock() {}

  
  
  function _free() {
  }
  Module["_free"] = _free;function ___cxa_free_exception(ptr) {
      try {
        return _free(ptr);
      } catch(e) { // XXX FIXME
      }
    }
  
  var EXCEPTIONS={last:0,caught:[],infos:{},deAdjust:function (adjusted) {
        if (!adjusted || EXCEPTIONS.infos[adjusted]) return adjusted;
        for (var ptr in EXCEPTIONS.infos) {
          var info = EXCEPTIONS.infos[ptr];
          if (info.adjusted === adjusted) {
            return ptr;
          }
        }
        return adjusted;
      },addRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        info.refcount++;
      },decRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        assert(info.refcount > 0);
        info.refcount--;
        if (info.refcount === 0) {
          if (info.destructor) {
            Runtime.dynCall('vi', info.destructor, [ptr]);
          }
          delete EXCEPTIONS.infos[ptr];
          ___cxa_free_exception(ptr);
        }
      },clearRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        info.refcount = 0;
      }};function ___cxa_end_catch() {
      if (___cxa_end_catch.rethrown) {
        ___cxa_end_catch.rethrown = false;
        return;
      }
      // Clear state flag.
      asm['setThrew'](0);
      // Call destructor if one is registered then clear it.
      var ptr = EXCEPTIONS.caught.pop();
      if (ptr) {
        EXCEPTIONS.decRef(EXCEPTIONS.deAdjust(ptr));
        EXCEPTIONS.last = 0; // XXX in decRef?
      }
    }

  var _acosf=Math_acos;

  function _emscripten_glStencilFunc(x0, x1, x2) { GLctx.stencilFunc(x0, x1, x2) }

  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      GLctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }

  
  function _log2(x) {
      return Math.log(x) / Math.LN2;
    }function _log2f() {
  return _log2.apply(null, arguments)
  }

  function _emscripten_glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      GLctx.uniform3iv(location, value);
    }

  var _llvm_pow_f32=Math_pow;

  
  
  var _tzname=allocate(8, "i32*", ALLOC_STATIC);
  
  var _daylight=allocate(1, "i32*", ALLOC_STATIC);
  
  var _timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
  
      HEAP32[((_timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60;
  
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((_daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());
  
      function extractZone(date) {
        var match = date.toTimeString().match(/\(([A-Za-z ]+)\)$/);
        return match ? match[1] : "GMT";
      };
      var winterName = extractZone(winter);
      var summerName = extractZone(summer);
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      if (summer.getTimezoneOffset() < winter.getTimezoneOffset()) {
        // Northern hemisphere
        HEAP32[((_tzname)>>2)]=winterNamePtr;
        HEAP32[(((_tzname)+(4))>>2)]=summerNamePtr;
      } else {
        HEAP32[((_tzname)>>2)]=summerNamePtr;
        HEAP32[(((_tzname)+(4))>>2)]=winterNamePtr;
      }
    }function _mktime(tmPtr) {
      _tzset();
      var date = new Date(HEAP32[(((tmPtr)+(20))>>2)] + 1900,
                          HEAP32[(((tmPtr)+(16))>>2)],
                          HEAP32[(((tmPtr)+(12))>>2)],
                          HEAP32[(((tmPtr)+(8))>>2)],
                          HEAP32[(((tmPtr)+(4))>>2)],
                          HEAP32[((tmPtr)>>2)],
                          0);
  
      // There's an ambiguous hour when the time goes back; the tm_isdst field is
      // used to disambiguate it.  Date() basically guesses, so we fix it up if it
      // guessed wrong, or fill in tm_isdst with the guess if it's -1.
      var dst = HEAP32[(((tmPtr)+(32))>>2)];
      var guessedOffset = date.getTimezoneOffset();
      var start = new Date(date.getFullYear(), 0, 1);
      var summerOffset = new Date(2000, 6, 1).getTimezoneOffset();
      var winterOffset = start.getTimezoneOffset();
      var dstOffset = Math.min(winterOffset, summerOffset); // DST is in December in South
      if (dst < 0) {
        HEAP32[(((tmPtr)+(32))>>2)]=Number(winterOffset != guessedOffset);
      } else if ((dst > 0) != (winterOffset != guessedOffset)) {
        var summerOffset = new Date(date.getFullYear(), 6, 1).getTimezoneOffset();
        var trueOffset = dst > 0 ? summerOffset : winterOffset;
        // Don't try setMinutes(date.getMinutes() + ...) -- it's messed up.
        date.setTime(date.getTime() + (trueOffset - guessedOffset)*60000);
      }
  
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
      var yday = ((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
  
      return (date.getTime() / 1000)|0;
    }

  function _emscripten_glTexParameterf(x0, x1, x2) { GLctx.texParameterf(x0, x1, x2) }

  
  var JSEvents={keyEvent:0,mouseEvent:0,wheelEvent:0,uiEvent:0,focusEvent:0,deviceOrientationEvent:0,deviceMotionEvent:0,fullscreenChangeEvent:0,pointerlockChangeEvent:0,visibilityChangeEvent:0,touchEvent:0,previousFullscreenElement:null,previousScreenX:null,previousScreenY:null,removeEventListenersRegistered:false,registerRemoveEventListeners:function () {
        if (!JSEvents.removeEventListenersRegistered) {
        __ATEXIT__.push({ func: function() {
            for(var i = JSEvents.eventHandlers.length-1; i >= 0; --i) {
              JSEvents._removeHandler(i);
            }
           } });
          JSEvents.removeEventListenersRegistered = true;
        }
      },findEventTarget:function (target) {
        if (target) {
          if (typeof target == "number") {
            target = Pointer_stringify(target);
          }
          if (target == '#window') return window;
          else if (target == '#document') return document;
          else if (target == '#screen') return window.screen;
          else if (target == '#canvas') return Module['canvas'];
  
          if (typeof target == 'string') return document.getElementById(target);
          else return target;
        } else {
          // The sensible target varies between events, but use window as the default
          // since DOM events mostly can default to that. Specific callback registrations
          // override their own defaults.
          return window;
        }
      },deferredCalls:[],deferCall:function (targetFunction, precedence, argsList) {
        function arraysHaveEqualContent(arrA, arrB) {
          if (arrA.length != arrB.length) return false;
  
          for(var i in arrA) {
            if (arrA[i] != arrB[i]) return false;
          }
          return true;
        }
        // Test if the given call was already queued, and if so, don't add it again.
        for(var i in JSEvents.deferredCalls) {
          var call = JSEvents.deferredCalls[i];
          if (call.targetFunction == targetFunction && arraysHaveEqualContent(call.argsList, argsList)) {
            return;
          }
        }
        JSEvents.deferredCalls.push({
          targetFunction: targetFunction,
          precedence: precedence,
          argsList: argsList
        });
  
        JSEvents.deferredCalls.sort(function(x,y) { return x.precedence < y.precedence; });
      },removeDeferredCalls:function (targetFunction) {
        for(var i = 0; i < JSEvents.deferredCalls.length; ++i) {
          if (JSEvents.deferredCalls[i].targetFunction == targetFunction) {
            JSEvents.deferredCalls.splice(i, 1);
            --i;
          }
        }
      },canPerformEventHandlerRequests:function () {
        return JSEvents.inEventHandler && JSEvents.currentEventHandler.allowsDeferredCalls;
      },runDeferredCalls:function () {
        if (!JSEvents.canPerformEventHandlerRequests()) {
          return;
        }
        for(var i = 0; i < JSEvents.deferredCalls.length; ++i) {
          var call = JSEvents.deferredCalls[i];
          JSEvents.deferredCalls.splice(i, 1);
          --i;
          call.targetFunction.apply(this, call.argsList);
        }
      },inEventHandler:0,currentEventHandler:null,eventHandlers:[],isInternetExplorer:function () { return navigator.userAgent.indexOf('MSIE') !== -1 || navigator.appVersion.indexOf('Trident/') > 0; },_removeHandler:function (i) {
        var h = JSEvents.eventHandlers[i];
        h.target.removeEventListener(h.eventTypeString, h.eventListenerFunc, h.useCapture);
        JSEvents.eventHandlers.splice(i, 1);
      },registerOrRemoveHandler:function (eventHandler) {
        var jsEventHandler = function jsEventHandler(event) {
          // Increment nesting count for the event handler.
          ++JSEvents.inEventHandler;
          JSEvents.currentEventHandler = eventHandler;
          // Process any old deferred calls the user has placed.
          JSEvents.runDeferredCalls();
          // Process the actual event, calls back to user C code handler.
          eventHandler.handlerFunc(event);
          // Process any new deferred calls that were placed right now from this event handler.
          JSEvents.runDeferredCalls();
          // Out of event handler - restore nesting count.
          --JSEvents.inEventHandler;
        }
        
        if (eventHandler.callbackfunc) {
          eventHandler.eventListenerFunc = jsEventHandler;
          eventHandler.target.addEventListener(eventHandler.eventTypeString, jsEventHandler, eventHandler.useCapture);
          JSEvents.eventHandlers.push(eventHandler);
          JSEvents.registerRemoveEventListeners();
        } else {
          for(var i = 0; i < JSEvents.eventHandlers.length; ++i) {
            if (JSEvents.eventHandlers[i].target == eventHandler.target
             && JSEvents.eventHandlers[i].eventTypeString == eventHandler.eventTypeString) {
               JSEvents._removeHandler(i--);
             }
          }
        }
      },registerKeyEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.keyEvent) {
          JSEvents.keyEvent = _malloc( 164 );
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
          writeStringToMemory(e.key ? e.key : "", JSEvents.keyEvent + 0 );
          writeStringToMemory(e.code ? e.code : "", JSEvents.keyEvent + 32 );
          HEAP32[(((JSEvents.keyEvent)+(64))>>2)]=e.location;
          HEAP32[(((JSEvents.keyEvent)+(68))>>2)]=e.ctrlKey;
          HEAP32[(((JSEvents.keyEvent)+(72))>>2)]=e.shiftKey;
          HEAP32[(((JSEvents.keyEvent)+(76))>>2)]=e.altKey;
          HEAP32[(((JSEvents.keyEvent)+(80))>>2)]=e.metaKey;
          HEAP32[(((JSEvents.keyEvent)+(84))>>2)]=e.repeat;
          writeStringToMemory(e.locale ? e.locale : "", JSEvents.keyEvent + 88 );
          writeStringToMemory(e.char ? e.char : "", JSEvents.keyEvent + 120 );
          HEAP32[(((JSEvents.keyEvent)+(152))>>2)]=e.charCode;
          HEAP32[(((JSEvents.keyEvent)+(156))>>2)]=e.keyCode;
          HEAP32[(((JSEvents.keyEvent)+(160))>>2)]=e.which;
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.keyEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: JSEvents.isInternetExplorer() ? false : true, // MSIE doesn't allow fullscreen and pointerlock requests from key handlers, others do.
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },fillMouseEventData:function (eventStruct, e, target) {
        HEAPF64[((eventStruct)>>3)]=JSEvents.tick();
        HEAP32[(((eventStruct)+(8))>>2)]=e.screenX;
        HEAP32[(((eventStruct)+(12))>>2)]=e.screenY;
        HEAP32[(((eventStruct)+(16))>>2)]=e.clientX;
        HEAP32[(((eventStruct)+(20))>>2)]=e.clientY;
        HEAP32[(((eventStruct)+(24))>>2)]=e.ctrlKey;
        HEAP32[(((eventStruct)+(28))>>2)]=e.shiftKey;
        HEAP32[(((eventStruct)+(32))>>2)]=e.altKey;
        HEAP32[(((eventStruct)+(36))>>2)]=e.metaKey;
        HEAP16[(((eventStruct)+(40))>>1)]=e.button;
        HEAP16[(((eventStruct)+(42))>>1)]=e.buttons;
        HEAP32[(((eventStruct)+(44))>>2)]=e["movementX"] || e["mozMovementX"] || e["webkitMovementX"] || (e.screenX-JSEvents.previousScreenX);
        HEAP32[(((eventStruct)+(48))>>2)]=e["movementY"] || e["mozMovementY"] || e["webkitMovementY"] || (e.screenY-JSEvents.previousScreenY);
  
        if (Module['canvas']) {
          var rect = Module['canvas'].getBoundingClientRect();
          HEAP32[(((eventStruct)+(60))>>2)]=e.clientX - rect.left;
          HEAP32[(((eventStruct)+(64))>>2)]=e.clientY - rect.top;
        } else { // Canvas is not initialized, return 0.
          HEAP32[(((eventStruct)+(60))>>2)]=0;
          HEAP32[(((eventStruct)+(64))>>2)]=0;
        }
        if (target) {
          var rect = (target === window) ? { left: 0, top: 0 } : target.getBoundingClientRect();
          HEAP32[(((eventStruct)+(52))>>2)]=e.clientX - rect.left;
          HEAP32[(((eventStruct)+(56))>>2)]=e.clientY - rect.top;        
        } else { // No specific target passed, return 0.
          HEAP32[(((eventStruct)+(52))>>2)]=0;
          HEAP32[(((eventStruct)+(56))>>2)]=0;
        }
        JSEvents.previousScreenX = e.screenX;
        JSEvents.previousScreenY = e.screenY;
      },registerMouseEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.mouseEvent) {
          JSEvents.mouseEvent = _malloc( 72 );
        }
        target = JSEvents.findEventTarget(target);
        var handlerFunc = function(event) {
          var e = event || window.event;
          JSEvents.fillMouseEventData(JSEvents.mouseEvent, e, target);
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.mouseEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: eventTypeString != 'mousemove', // Mouse move events do not allow fullscreen/pointer lock requests to be handled in them!
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        // In IE, mousedown events don't either allow deferred calls to be run!
        if (JSEvents.isInternetExplorer() && eventTypeString == 'mousedown') eventHandler.allowsDeferredCalls = false;
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerWheelEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.wheelEvent) {
          JSEvents.wheelEvent = _malloc( 104 );
        }
        target = JSEvents.findEventTarget(target);
        // The DOM Level 3 events spec event 'wheel'
        var wheelHandlerFunc = function(event) {
          var e = event || window.event;
          JSEvents.fillMouseEventData(JSEvents.wheelEvent, e, target);
          HEAPF64[(((JSEvents.wheelEvent)+(72))>>3)]=e["deltaX"];
          HEAPF64[(((JSEvents.wheelEvent)+(80))>>3)]=e["deltaY"];
          HEAPF64[(((JSEvents.wheelEvent)+(88))>>3)]=e["deltaZ"];
          HEAP32[(((JSEvents.wheelEvent)+(96))>>2)]=e["deltaMode"];
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.wheelEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
        // The 'mousewheel' event as implemented in Safari 6.0.5
        var mouseWheelHandlerFunc = function(event) {
          var e = event || window.event;
          JSEvents.fillMouseEventData(JSEvents.wheelEvent, e, target);
          HEAPF64[(((JSEvents.wheelEvent)+(72))>>3)]=e["wheelDeltaX"];
          HEAPF64[(((JSEvents.wheelEvent)+(80))>>3)]=-e["wheelDeltaY"] /* Invert to unify direction with the DOM Level 3 wheel event. */;
          HEAPF64[(((JSEvents.wheelEvent)+(88))>>3)]=0 /* Not available */;
          HEAP32[(((JSEvents.wheelEvent)+(96))>>2)]=0 /* DOM_DELTA_PIXEL */;
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.wheelEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: true,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: (eventTypeString == 'wheel') ? wheelHandlerFunc : mouseWheelHandlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },pageScrollPos:function () {
        if (window.pageXOffset > 0 || window.pageYOffset > 0) {
          return [window.pageXOffset, window.pageYOffset];
        }
        if (typeof document.documentElement.scrollLeft !== 'undefined' || typeof document.documentElement.scrollTop !== 'undefined') {
          return [document.documentElement.scrollLeft, document.documentElement.scrollTop];
        }
        return [document.body.scrollLeft|0, document.body.scrollTop|0];
      },registerUiEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.uiEvent) {
          JSEvents.uiEvent = _malloc( 36 );
        }
  
        if (eventTypeString == "scroll" && !target) {
          target = document; // By default read scroll events on document rather than window.
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
          if (e.target != target) {
            // Never take ui events such as scroll via a 'bubbled' route, but always from the direct element that
            // was targeted. Otherwise e.g. if app logs a message in response to a page scroll, the Emscripten log
            // message box could cause to scroll, generating a new (bubbled) scroll message, causing a new log print,
            // causing a new scroll, etc..
            return;
          }
          var scrollPos = JSEvents.pageScrollPos();
          HEAP32[((JSEvents.uiEvent)>>2)]=e.detail;
          HEAP32[(((JSEvents.uiEvent)+(4))>>2)]=document.body.clientWidth;
          HEAP32[(((JSEvents.uiEvent)+(8))>>2)]=document.body.clientHeight;
          HEAP32[(((JSEvents.uiEvent)+(12))>>2)]=window.innerWidth;
          HEAP32[(((JSEvents.uiEvent)+(16))>>2)]=window.innerHeight;
          HEAP32[(((JSEvents.uiEvent)+(20))>>2)]=window.outerWidth;
          HEAP32[(((JSEvents.uiEvent)+(24))>>2)]=window.outerHeight;
          HEAP32[(((JSEvents.uiEvent)+(28))>>2)]=scrollPos[0];
          HEAP32[(((JSEvents.uiEvent)+(32))>>2)]=scrollPos[1];
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.uiEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false, // Neither scroll or resize events allow running requests inside them.
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },getNodeNameForTarget:function (target) {
        if (!target) return '';
        if (target == window) return '#window';
        if (target == window.screen) return '#screen';
        return (target && target.nodeName) ? target.nodeName : '';
      },registerFocusEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.focusEvent) {
          JSEvents.focusEvent = _malloc( 256 );
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var nodeName = JSEvents.getNodeNameForTarget(e.target);
          var id = e.target.id ? e.target.id : '';
          writeStringToMemory(nodeName, JSEvents.focusEvent + 0 );
          writeStringToMemory(id, JSEvents.focusEvent + 128 );
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.focusEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },tick:function () {
        if (window['performance'] && window['performance']['now']) return window['performance']['now']();
        else return Date.now();
      },registerDeviceOrientationEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.deviceOrientationEvent) {
          JSEvents.deviceOrientationEvent = _malloc( 40 );
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          HEAPF64[((JSEvents.deviceOrientationEvent)>>3)]=JSEvents.tick();
          HEAPF64[(((JSEvents.deviceOrientationEvent)+(8))>>3)]=e.alpha;
          HEAPF64[(((JSEvents.deviceOrientationEvent)+(16))>>3)]=e.beta;
          HEAPF64[(((JSEvents.deviceOrientationEvent)+(24))>>3)]=e.gamma;
          HEAP32[(((JSEvents.deviceOrientationEvent)+(32))>>2)]=e.absolute;
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.deviceOrientationEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerDeviceMotionEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.deviceMotionEvent) {
          JSEvents.deviceMotionEvent = _malloc( 80 );
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          HEAPF64[((JSEvents.deviceOrientationEvent)>>3)]=JSEvents.tick();
          HEAPF64[(((JSEvents.deviceMotionEvent)+(8))>>3)]=e.acceleration.x;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(16))>>3)]=e.acceleration.y;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(24))>>3)]=e.acceleration.z;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(32))>>3)]=e.accelerationIncludingGravity.x;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(40))>>3)]=e.accelerationIncludingGravity.y;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(48))>>3)]=e.accelerationIncludingGravity.z;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(56))>>3)]=e.rotationRate.alpha;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(64))>>3)]=e.rotationRate.beta;
          HEAPF64[(((JSEvents.deviceMotionEvent)+(72))>>3)]=e.rotationRate.gamma;
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.deviceMotionEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },screenOrientation:function () {
        if (!window.screen) return undefined;
        return window.screen.orientation || window.screen.mozOrientation || window.screen.webkitOrientation || window.screen.msOrientation;
      },fillOrientationChangeEventData:function (eventStruct, e) {
        var orientations  = ["portrait-primary", "portrait-secondary", "landscape-primary", "landscape-secondary"];
        var orientations2 = ["portrait",         "portrait",           "landscape",         "landscape"];
  
        var orientationString = JSEvents.screenOrientation();
        var orientation = orientations.indexOf(orientationString);
        if (orientation == -1) {
          orientation = orientations2.indexOf(orientationString);
        }
  
        HEAP32[((eventStruct)>>2)]=1 << orientation;
        HEAP32[(((eventStruct)+(4))>>2)]=window.orientation;
      },registerOrientationChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.orientationChangeEvent) {
          JSEvents.orientationChangeEvent = _malloc( 8 );
        }
  
        if (!target) {
          target = window.screen; // Orientation events need to be captured from 'window.screen' instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillOrientationChangeEventData(JSEvents.orientationChangeEvent, e);
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.orientationChangeEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        if (eventTypeString == "orientationchange" && window.screen.mozOrientation !== undefined) {
          eventTypeString = "mozorientationchange";
        }
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },fullscreenEnabled:function () {
        return document.fullscreenEnabled || document.mozFullscreenEnabled || document.mozFullScreenEnabled || document.webkitFullscreenEnabled || document.msFullscreenEnabled;
      },fillFullscreenChangeEventData:function (eventStruct, e) {
        var fullscreenElement = document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
        var isFullscreen = !!fullscreenElement;
        HEAP32[((eventStruct)>>2)]=isFullscreen;
        HEAP32[(((eventStruct)+(4))>>2)]=JSEvents.fullscreenEnabled();
        // If transitioning to fullscreen, report info about the element that is now fullscreen.
        // If transitioning to windowed mode, report info about the element that just was fullscreen.
        var reportedElement = isFullscreen ? fullscreenElement : JSEvents.previousFullscreenElement;
        var nodeName = JSEvents.getNodeNameForTarget(reportedElement);
        var id = (reportedElement && reportedElement.id) ? reportedElement.id : '';
        writeStringToMemory(nodeName, eventStruct + 8 );
        writeStringToMemory(id, eventStruct + 136 );
        HEAP32[(((eventStruct)+(264))>>2)]=reportedElement ? reportedElement.clientWidth : 0;
        HEAP32[(((eventStruct)+(268))>>2)]=reportedElement ? reportedElement.clientHeight : 0;
        HEAP32[(((eventStruct)+(272))>>2)]=screen.width;
        HEAP32[(((eventStruct)+(276))>>2)]=screen.height;
        if (isFullscreen) {
          JSEvents.previousFullscreenElement = fullscreenElement;
        }
      },registerFullscreenChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.fullscreenChangeEvent) {
          JSEvents.fullscreenChangeEvent = _malloc( 280 );
        }
  
        if (!target) {
          target = document; // Fullscreen change events need to be captured from 'document' by default instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillFullscreenChangeEventData(JSEvents.fullscreenChangeEvent, e);
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.fullscreenChangeEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },requestFullscreen:function (target) {
        if (target.requestFullscreen) {
          target.requestFullscreen();
        } else if (target.msRequestFullscreen) {
          target.msRequestFullscreen();
        } else if (target.mozRequestFullScreen) {
          target.mozRequestFullScreen();
        } else if (target.mozRequestFullscreen) {
          target.mozRequestFullscreen();
        } else if (target.webkitRequestFullscreen) {
          target.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT);
        } else {
          if (typeof JSEvents.fullscreenEnabled() === 'undefined') {
            return -1;
          } else {
            return -3;
          }
        }
        return 0;
      },fillPointerlockChangeEventData:function (eventStruct, e) {
        var pointerLockElement = document.pointerLockElement || document.mozPointerLockElement || document.webkitPointerLockElement || document.msPointerLockElement;
        var isPointerlocked = !!pointerLockElement;
        HEAP32[((eventStruct)>>2)]=isPointerlocked;
        var nodeName = JSEvents.getNodeNameForTarget(pointerLockElement);
        var id = (pointerLockElement && pointerLockElement.id) ? pointerLockElement.id : '';
        writeStringToMemory(nodeName, eventStruct + 4 );
        writeStringToMemory(id, eventStruct + 132);
      },registerPointerlockChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.pointerlockChangeEvent) {
          JSEvents.pointerlockChangeEvent = _malloc( 260 );
        }
  
        if (!target) {
          target = document; // Pointer lock change events need to be captured from 'document' by default instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillPointerlockChangeEventData(JSEvents.pointerlockChangeEvent, e);
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.pointerlockChangeEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },requestPointerLock:function (target) {
        if (target.requestPointerLock) {
          target.requestPointerLock();
        } else if (target.mozRequestPointerLock) {
          target.mozRequestPointerLock();
        } else if (target.webkitRequestPointerLock) {
          target.webkitRequestPointerLock();
        } else if (target.msRequestPointerLock) {
          target.msRequestPointerLock();
        } else {
          // document.body is known to accept pointer lock, so use that to differentiate if the user passed a bad element,
          // or if the whole browser just doesn't support the feature.
          if (document.body.requestPointerLock || document.body.mozRequestPointerLock || document.body.webkitRequestPointerLock || document.body.msRequestPointerLock) {
            return -3;
          } else {
            return -1;
          }
        }
        return 0;
      },fillVisibilityChangeEventData:function (eventStruct, e) {
        var visibilityStates = [ "hidden", "visible", "prerender", "unloaded" ];
        var visibilityState = visibilityStates.indexOf(document.visibilityState);
  
        HEAP32[((eventStruct)>>2)]=document.hidden;
        HEAP32[(((eventStruct)+(4))>>2)]=visibilityState;
      },registerVisibilityChangeEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.visibilityChangeEvent) {
          JSEvents.visibilityChangeEvent = _malloc( 8 );
        }
  
        if (!target) {
          target = document; // Visibility change events need to be captured from 'document' by default instead of 'window'
        } else {
          target = JSEvents.findEventTarget(target);
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillVisibilityChangeEventData(JSEvents.visibilityChangeEvent, e);
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.visibilityChangeEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerTouchEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.touchEvent) {
          JSEvents.touchEvent = _malloc( 1684 );
        }
  
        target = JSEvents.findEventTarget(target);
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var touches = {};
          for(var i = 0; i < e.touches.length; ++i) {
            var touch = e.touches[i];
            touches[touch.identifier] = touch;
          }
          for(var i = 0; i < e.changedTouches.length; ++i) {
            var touch = e.changedTouches[i];
            touches[touch.identifier] = touch;
            touch.changed = true;
          }
          for(var i = 0; i < e.targetTouches.length; ++i) {
            var touch = e.targetTouches[i];
            touches[touch.identifier].onTarget = true;
          }
          
          var ptr = JSEvents.touchEvent;
          HEAP32[(((ptr)+(4))>>2)]=e.ctrlKey;
          HEAP32[(((ptr)+(8))>>2)]=e.shiftKey;
          HEAP32[(((ptr)+(12))>>2)]=e.altKey;
          HEAP32[(((ptr)+(16))>>2)]=e.metaKey;
          ptr += 20; // Advance to the start of the touch array.
          var canvasRect = Module['canvas'] ? Module['canvas'].getBoundingClientRect() : undefined;
          var targetRect = (target === window) ? { left: 0, top: 0 } : target.getBoundingClientRect();
          var numTouches = 0;
          for(var i in touches) {
            var t = touches[i];
            HEAP32[((ptr)>>2)]=t.identifier;
            HEAP32[(((ptr)+(4))>>2)]=t.screenX;
            HEAP32[(((ptr)+(8))>>2)]=t.screenY;
            HEAP32[(((ptr)+(12))>>2)]=t.clientX;
            HEAP32[(((ptr)+(16))>>2)]=t.clientY;
            HEAP32[(((ptr)+(20))>>2)]=t.pageX;
            HEAP32[(((ptr)+(24))>>2)]=t.pageY;
            HEAP32[(((ptr)+(28))>>2)]=t.changed;
            HEAP32[(((ptr)+(32))>>2)]=t.onTarget;
            if (canvasRect) {
              HEAP32[(((ptr)+(44))>>2)]=t.clientX - canvasRect.left;
              HEAP32[(((ptr)+(48))>>2)]=t.clientY - canvasRect.top;
            } else {
              HEAP32[(((ptr)+(44))>>2)]=0;
              HEAP32[(((ptr)+(48))>>2)]=0;            
            }
            HEAP32[(((ptr)+(36))>>2)]=t.clientX - targetRect.left;
            HEAP32[(((ptr)+(40))>>2)]=t.clientY - targetRect.top;
            
            ptr += 52;
  
            if (++numTouches >= 32) {
              break;
            }
          }
          HEAP32[((JSEvents.touchEvent)>>2)]=numTouches;
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.touchEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: target,
          allowsDeferredCalls: false, // XXX Currently disabled, see bug https://bugzilla.mozilla.org/show_bug.cgi?id=966493
          // Once the above bug is resolved, enable the following condition if possible:
          // allowsDeferredCalls: eventTypeString == 'touchstart',
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },fillGamepadEventData:function (eventStruct, e) {
        HEAPF64[((eventStruct)>>3)]=e.timestamp;
        for(var i = 0; i < e.axes.length; ++i) {
          HEAPF64[(((eventStruct+i*8)+(16))>>3)]=e.axes[i];
        }
        for(var i = 0; i < e.buttons.length; ++i) {
          if (typeof(e.buttons[i]) === 'object') {
            HEAPF64[(((eventStruct+i*8)+(528))>>3)]=e.buttons[i].value;
          } else {
            HEAPF64[(((eventStruct+i*8)+(528))>>3)]=e.buttons[i];
          }
        }
        for(var i = 0; i < e.buttons.length; ++i) {
          if (typeof(e.buttons[i]) === 'object') {
            HEAP32[(((eventStruct+i*4)+(1040))>>2)]=e.buttons[i].pressed;
          } else {
            HEAP32[(((eventStruct+i*4)+(1040))>>2)]=e.buttons[i] == 1.0;
          }
        }
        HEAP32[(((eventStruct)+(1296))>>2)]=e.connected;
        HEAP32[(((eventStruct)+(1300))>>2)]=e.index;
        HEAP32[(((eventStruct)+(8))>>2)]=e.axes.length;
        HEAP32[(((eventStruct)+(12))>>2)]=e.buttons.length;
        writeStringToMemory(e.id, eventStruct + 1304 );
        writeStringToMemory(e.mapping, eventStruct + 1368 );
      },registerGamepadEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.gamepadEvent) {
          JSEvents.gamepadEvent = _malloc( 1432 );
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillGamepadEventData(JSEvents.gamepadEvent, e.gamepad);
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.gamepadEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: true,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerBeforeUnloadEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var confirmationMessage = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, 0, userData]);
          
          if (confirmationMessage) {
            confirmationMessage = Pointer_stringify(confirmationMessage);
          }
          if (confirmationMessage) {
            e.preventDefault();
            e.returnValue = confirmationMessage;
            return confirmationMessage;
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },battery:function () { return navigator.battery || navigator.mozBattery || navigator.webkitBattery; },fillBatteryEventData:function (eventStruct, e) {
        HEAPF64[((eventStruct)>>3)]=e.chargingTime;
        HEAPF64[(((eventStruct)+(8))>>3)]=e.dischargingTime;
        HEAPF64[(((eventStruct)+(16))>>3)]=e.level;
        HEAP32[(((eventStruct)+(24))>>2)]=e.charging;
      },registerBatteryEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!JSEvents.batteryEvent) {
          JSEvents.batteryEvent = _malloc( 32 );
        }
  
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          JSEvents.fillBatteryEventData(JSEvents.batteryEvent, JSEvents.battery());
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, JSEvents.batteryEvent, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      },registerWebGlEventCallback:function (target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
        if (!target) {
          target = Module['canvas'];
        }
        var handlerFunc = function(event) {
          var e = event || window.event;
  
          var shouldCancel = Runtime.dynCall('iiii', callbackfunc, [eventTypeId, 0, userData]);
          if (shouldCancel) {
            e.preventDefault();
          }
        };
  
        var eventHandler = {
          target: JSEvents.findEventTarget(target),
          allowsDeferredCalls: false,
          eventTypeString: eventTypeString,
          callbackfunc: callbackfunc,
          handlerFunc: handlerFunc,
          useCapture: useCapture
        };
        JSEvents.registerOrRemoveHandler(eventHandler);
      }};function _emscripten_webgl_destroy_context(contextHandle) {
      GL.deleteContext(contextHandle);
    }

  function _emscripten_glTexParameteri(x0, x1, x2) { GLctx.texParameteri(x0, x1, x2) }

  function _glCompileShader(shader) {
      GLctx.compileShader(GL.shaders[shader]);
    }

  
  var ___tm_current=allocate(44, "i8", ALLOC_STATIC);
  
  
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);function _localtime_r(time, tmPtr) {
      _tzset();
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
  
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = ((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(36))>>2)]=-(date.getTimezoneOffset() * 60);
  
      // DST is in December in South
      var summerOffset = new Date(2000, 6, 1).getTimezoneOffset();
      var winterOffset = start.getTimezoneOffset();
      var dst = (date.getTimezoneOffset() == Math.min(winterOffset, summerOffset))|0;
      HEAP32[(((tmPtr)+(32))>>2)]=dst;
  
      var zonePtr = HEAP32[(((_tzname)+(dst ? Runtime.QUANTUM_SIZE : 0))>>2)];
      HEAP32[(((tmPtr)+(40))>>2)]=zonePtr;
  
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }

  function _emscripten_glFrustum() {
  Module['printErr']('missing function: emscripten_glFrustum'); abort(-1);
  }

  function _emscripten_glGetTexParameterfv(target, pname, params) {
      HEAPF32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }

  function _emscripten_glBindRenderbuffer(target, renderbuffer) {
      GLctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }

  function _emscripten_glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }

  
  var systemInfo={get:function ()
  		{
  				if (systemInfo.hasOwnProperty('hasWebGL'))
  					return this;
  
  				var unknown = '-';
  
  				// screen
  				this.width = (screen.width) ? screen.width : 0;
  				this.height = (screen.height) ? screen.height : 0;
  
  				//browser
  				var nVer = navigator.appVersion;
  				var nAgt = navigator.userAgent;
  				var browser = navigator.appName;
  				var version = '' + parseFloat(navigator.appVersion);
  				var majorVersion = parseInt(navigator.appVersion, 10);
  				var nameOffset, verOffset, ix;
  
  				// Opera
  				if ((verOffset = nAgt.indexOf('Opera')) != -1) {
  						browser = 'Opera';
  						version = nAgt.substring(verOffset + 6);
  						if ((verOffset = nAgt.indexOf('Version')) != -1) {
  								version = nAgt.substring(verOffset + 8);
  						}
  				}
  				// MSIE
  				else if ((verOffset = nAgt.indexOf('MSIE')) != -1) {
  						browser = 'Microsoft Internet Explorer';
  						version = nAgt.substring(verOffset + 5);
  				}
  				// Chrome
  				else if ((verOffset = nAgt.indexOf('Chrome')) != -1) {
  						browser = 'Chrome';
  						version = nAgt.substring(verOffset + 7);
  				}
  				// Safari
  				else if ((verOffset = nAgt.indexOf('Safari')) != -1) {
  						browser = 'Safari';
  						version = nAgt.substring(verOffset + 7);
  						if ((verOffset = nAgt.indexOf('Version')) != -1) {
  								version = nAgt.substring(verOffset + 8);
  						}
  				}
  				// Firefox
  				else if ((verOffset = nAgt.indexOf('Firefox')) != -1) {
  						browser = 'Firefox';
  						version = nAgt.substring(verOffset + 8);
  				}
  				// MSIE 11+
  				else if (nAgt.indexOf('Trident/') != -1) {
  						browser = 'Microsoft Internet Explorer';
  						version = nAgt.substring(nAgt.indexOf('rv:') + 3);
  				}
  				// Other browsers
  				else if ((nameOffset = nAgt.lastIndexOf(' ') + 1) < (verOffset = nAgt.lastIndexOf('/'))) {
  						browser = nAgt.substring(nameOffset, verOffset);
  						version = nAgt.substring(verOffset + 1);
  						if (browser.toLowerCase() == browser.toUpperCase()) {
  								browser = navigator.appName;
  						}
  				}
  				// trim the version string
  				if ((ix = version.indexOf(';')) != -1) version = version.substring(0, ix);
  				if ((ix = version.indexOf(' ')) != -1) version = version.substring(0, ix);
  				if ((ix = version.indexOf(')')) != -1) version = version.substring(0, ix);
  
  				majorVersion = parseInt('' + version, 10);
  				if (isNaN(majorVersion)) {
  						version = '' + parseFloat(navigator.appVersion);
  						majorVersion = parseInt(navigator.appVersion, 10);
  				}
  
  				// mobile version
  				var mobile = /Mobile|mini|Fennec|Android|iP(ad|od|hone)/.test(nVer);
  
  				// system
  				var os = unknown;
  				var clientStrings = [
  						{s:'Windows 3.11', r:/Win16/},
  						{s:'Windows 95', r:/(Windows 95|Win95|Windows_95)/},
  						{s:'Windows ME', r:/(Win 9x 4.90|Windows ME)/},
  						{s:'Windows 98', r:/(Windows 98|Win98)/},
  						{s:'Windows CE', r:/Windows CE/},
  						{s:'Windows 2000', r:/(Windows NT 5.0|Windows 2000)/},
  						{s:'Windows XP', r:/(Windows NT 5.1|Windows XP)/},
  						{s:'Windows Server 2003', r:/Windows NT 5.2/},
  						{s:'Windows Vista', r:/Windows NT 6.0/},
  						{s:'Windows 7', r:/(Windows 7|Windows NT 6.1)/},
  						{s:'Windows 8.1', r:/(Windows 8.1|Windows NT 6.3)/},
  						{s:'Windows 8', r:/(Windows 8|Windows NT 6.2)/},
  						{s:'Windows NT 4.0', r:/(Windows NT 4.0|WinNT4.0|WinNT|Windows NT)/},
  						{s:'Windows ME', r:/Windows ME/},
  						{s:'Android', r:/Android/},
  						{s:'Open BSD', r:/OpenBSD/},
  						{s:'Sun OS', r:/SunOS/},
  						{s:'Linux', r:/(Linux|X11)/},
  						{s:'iOS', r:/(iPhone|iPad|iPod)/},
  						{s:'Mac OS X', r:/Mac OS X/},
  						{s:'Mac OS', r:/(MacPPC|MacIntel|Mac_PowerPC|Macintosh)/},
  						{s:'QNX', r:/QNX/},
  						{s:'UNIX', r:/UNIX/},
  						{s:'BeOS', r:/BeOS/},
  						{s:'OS/2', r:/OS\/2/},
  						{s:'Search Bot', r:/(nuhk|Googlebot|Yammybot|Openbot|Slurp|MSNBot|Ask Jeeves\/Teoma|ia_archiver)/}
  				];
  				for (var id in clientStrings) {
  						var cs = clientStrings[id];
  						if (cs.r.test(nAgt)) {
  								os = cs.s;
  								break;
  						}
  				}
  
  				var osVersion = unknown;
  
  				if (/Windows/.test(os)) {
  						osVersion = /Windows (.*)/.exec(os)[1];
  						os = 'Windows';
  				}
  
  				switch (os) {
  						case 'Mac OS X':
  								osVersion = /Mac OS X (10[\.\_\d]+)/.exec(nAgt)[1];
  								break;
  
  						case 'Android':
  								osVersion = /Android ([\.\_\d]+)/.exec(nAgt)[1];
  								break;
  
  						case 'iOS':
  								osVersion = /OS (\d+)_(\d+)_?(\d+)?/.exec(nVer);
  								osVersion = osVersion[1] + '.' + osVersion[2] + '.' + (osVersion[3] | 0);
  								break;
  				}
  				this.browser = browser;
  				this.browserVersion = version;
  				this.mobile = mobile;
  				this.os = os;
  				this.osVersion = osVersion;
  
  				this.hasWebGL = function(){
  					if (!window.WebGLRenderingContext) 
  					{
  						// Browser has no idea what WebGL is. Suggest they
  						// get a new browser by presenting the user with link to
  						// http://get.webgl.org
  						return 0;   
  					}
  
  					var canvas = document.createElement('canvas'); 
  					var gl = canvas.getContext("webgl");   
  					if (!gl) 
  					{
  						gl = canvas.getContext("experimental-webgl");   
  						if (!gl) 
  						{
  							// Browser could not initialize WebGL. User probably needs to
  							// update their drivers or get a new browser. Present a link to
  							// http://get.webgl.org/troubleshooting
  							return 0;  
  						}
  					}
  					return 1;
  				}();
  
  				this.hasCursorLock = function(){
  					var e = document.createElement('canvas');
  					if (e['requestPointerLock'] ||
  							e['mozRequestPointerLock'] ||
  							e['webkitRequestPointerLock'] ||
  							e['msRequestPointerLock'])
  						return 1;
  					else
  						return 0;
  				}();
  
  				this.hasFullscreen = function(){        
  					var e = document.createElement('canvas');
  					if (e['requestFullScreen'] ||
  							e['mozRequestFullScreen'] ||
  							e['msRequestFullscreen'] ||
  							e['webkitRequestFullScreen'])
  					{
  						// Safari currently blocks input in Fullscreen mode, so we don't support it.
  						if (browser.indexOf("Safari") == -1)
  							return 1;
  					}
  					return 0;
  				}();
  
  				this.language = window.navigator.userLanguage || window.navigator.language;
  				return this;
  		}};function _JS_SystemInfo_HasFullscreen() 
  	{
  		return systemInfo.get().hasFullscreen;
  	}

  function _emscripten_glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      GLctx.texParameterf(target, pname, param);
    }

  function _emscripten_glDepthRangef(x0, x1) { GLctx.depthRange(x0, x1) }

  
  function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var fd = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd));
    }

  function _emscripten_glGetObjectParameterivARB() {
  Module['printErr']('missing function: emscripten_glGetObjectParameterivARB'); abort(-1);
  }

  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = GLctx.createShader(shaderType);
      return id;
    }

  function _emscripten_glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      GLctx.bindAttribLocation(GL.programs[program], index, name);
    }

  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = GLctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }

  var _cosf=Math_cos;

  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      // N.b. using array notation explicitly to not confuse Closure minification.
      GLctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }

  function _glBlendFuncSeparate(x0, x1, x2, x3) { GLctx.blendFuncSeparate(x0, x1, x2, x3) }

  function ___errno_location() {
      return ___errno_state;
    }

  
  var WEBAudio={audioInstances:[],audioContext:{},audioWebEnabled:0};function _JS_Sound_Set3D(channelInstance, threeD)
  {
  	var channel = WEBAudio.audioInstances[channelInstance];
  	if (channel.threeD != threeD)
  	{
  		channel.threeD = threeD;
  		channel.setupPanning();
  	}
  }

  function _cosh(x) {
      var p = Math.pow(Math.E, x);
      return (p + (1 / p)) / 2;
    }

  
  function _trunc(x) {
      return (x < 0) ? Math.ceil(x) : Math.floor(x);
    }function _truncf() {
  return _trunc.apply(null, arguments)
  }

  function _JS_SystemInfo_HasCursorLock() 
  	{
  		return systemInfo.get().hasCursorLock;
  	}


  var _asin=Math_asin;

  function _emscripten_glVertexAttrib3f(x0, x1, x2, x3) { GLctx.vertexAttrib3f(x0, x1, x2, x3) }

  function _clock() {
      if (_clock.start === undefined) _clock.start = Date.now();
      return ((Date.now() - _clock.start) * (1000000 / 1000))|0;
    }

  var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC); 
  Module["_llvm_ctlz_i32"] = _llvm_ctlz_i32;

  function _access(path, amode) {
      // int access(const char *path, int amode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/access.html
      path = Pointer_stringify(path);
      if (amode & ~7) {
        // need a valid mode
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      var perms = '';
      if (amode & 4) perms += 'r';
      if (amode & 2) perms += 'w';
      if (amode & 1) perms += 'x';
      if (perms /* otherwise, they've just passed F_OK */ && FS.nodePermissions(node, perms)) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      }
      return 0;
    }

  var _abs=Math_abs;

  function _glRenderbufferStorage(x0, x1, x2, x3) { GLctx.renderbufferStorage(x0, x1, x2, x3) }

  function _modff(x, intpart) {
      HEAPF32[((intpart)>>2)]=(x < 0) ? Math.ceil(x) : Math.floor(x);
      return x - HEAPF32[((intpart)>>2)];
    }

  function _JS_Sound_SetListenerPosition(x, y, z)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	WEBAudio.audioContext.listener.setPosition(x, y, z);
  }

  function _emscripten_glDeleteShader(shader) {
      GLctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }

  function ___cxa_guard_acquire(variable) {
      if (!HEAP8[((variable)>>0)]) { // ignore SAFE_HEAP stuff because llvm mixes i64 and i8 here
        HEAP8[((variable)>>0)]=1;
        return 1;
      }
      return 0;
    }

  function _pthread_attr_init(attr) {
      /* int pthread_attr_init(pthread_attr_t *attr); */
      //FIXME: should allocate a pthread_attr_t
      return 0;
    }

  function _emscripten_glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _emscripten_glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
  
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
  
        GLctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
  
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }

  function _sinh(x) {
      var p = Math.pow(Math.E, x);
      return (p - (1 / p)) / 2;
    }

  var _sinf=Math_sin;

  function _emscripten_glUniformMatrix2fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[3];
        for (var i = 0; i < 4; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniformMatrix2fv(location, transpose, view);
    }

  function _emscripten_glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      GLctx.uniformMatrix4fv(location, transpose, view);
    }

  function _emscripten_glEnableClientState() {
  Module['printErr']('missing function: emscripten_glEnableClientState'); abort(-1);
  }

  function _emscripten_glStencilMask(x0) { GLctx.stencilMask(x0) }

  function _JS_Sound_SetListenerOrientation(x, y, z, xUp, yUp, zUp)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	WEBAudio.audioContext.listener.setPosition(x, y, z, xUp, yUp, zUp);
  }

  
  function __ZSt18uncaught_exceptionv() { // std::uncaught_exception()
      return !!__ZSt18uncaught_exceptionv.uncaught_exception;
    }function ___cxa_begin_catch(ptr) {
      __ZSt18uncaught_exceptionv.uncaught_exception--;
      EXCEPTIONS.caught.push(ptr);
      EXCEPTIONS.addRef(EXCEPTIONS.deAdjust(ptr));
      return ptr;
    }

  function _JS_Eval_EvalJS(ptr)
  {
  	var str = Pointer_stringify(ptr);
  	eval (str);
  }

  
  
  var Browser={mainLoop:{scheduler:null,method:"",shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        },runIter:function (func) {
          if (ABORT) return;
          if (Module['preMainLoop']) {
            var preRet = Module['preMainLoop']();
            if (preRet === false) {
              return; // |return false| skips a frame
            }
          }
          try {
            func();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
              throw e;
            }
          }
          if (Module['postMainLoop']) Module['postMainLoop']();
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        var canvas = Module['canvas'];
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas ||
                                document['msPointerLockElement'] === canvas;
        }
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;
          
          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
  
          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);
  
          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && canvas.requestPointerLock) {
                canvas.requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx; // no need to recreate GL context if it's already been created for this canvas.
  
        var ctx;
        var contextHandle;
        if (useWebGL) {
          // For GLES2/desktop GL compatibility, adjust a few defaults to be different to WebGL defaults, so that they align better with the desktop defaults.
          var contextAttributes = {
            antialias: false,
            alpha: false
          };
  
          if (webGLContextAttributes) {
            for (var attribute in webGLContextAttributes) {
              contextAttributes[attribute] = webGLContextAttributes[attribute];
            }
          }
  
          contextHandle = GL.createContext(canvas, contextAttributes);
          if (contextHandle) {
            ctx = GL.getContext(contextHandle).GLctx;
          }
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
        } else {
          ctx = canvas.getContext('2d');
        }
  
        if (!ctx) return null;
  
        if (setInModule) {
          if (!useWebGL) assert(typeof GLctx === 'undefined', 'cannot set in module if GLctx is used, but we are a non-GL context that would replace it');
  
          Module.ctx = ctx;
          if (useWebGL) GL.makeContextCurrent(contextHandle);
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
  
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement'] ||
               document['msFullScreenElement'] || document['msFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'] ||
                                      document['msExitFullscreen'] ||
                                      document['exitFullscreen'] ||
                                      function() {};
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else {
            
            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);
            
            if (Browser.resizeCanvas) Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
          Browser.updateCanvasDimensions(canvas);
        }
  
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
          document.addEventListener('MSFullscreenChange', fullScreenChange, false);
        }
  
        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);
        
        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullScreen = canvasContainer['requestFullScreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvasContainer.requestFullScreen();
      },nextRAF:0,fakeRequestAnimationFrame:function (func) {
        // try to keep 60fps between calls to here
        var now = Date.now();
        if (Browser.nextRAF === 0) {
          Browser.nextRAF = now + 1000/60;
        } else {
          while (now + 2 >= Browser.nextRAF) { // fudge a little, to avoid timer jitter causing us to do lots of delay:0
            Browser.nextRAF += 1000/60;
          }
        }
        var delay = Math.max(Browser.nextRAF - now, 0);
        setTimeout(func, delay);
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          Browser.fakeRequestAnimationFrame(func);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           Browser.fakeRequestAnimationFrame;
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        var delta = 0;
        switch (event.type) {
          case 'DOMMouseScroll': 
            delta = event.detail;
            break;
          case 'mousewheel': 
            delta = event.wheelDelta;
            break;
          case 'wheel': 
            delta = event['deltaY'];
            break;
          default:
            throw 'unrecognized mouse wheel event: ' + event.type;
        }
        return delta;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
  
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
  
          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL
  
            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);
  
            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);
  
            var coords = { x: adjustedX, y: adjustedY };
            
            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              Browser.lastTouches[touch.identifier] = Browser.touches[touch.identifier];
              Browser.touches[touch.identifier] = { x: adjustedX, y: adjustedY };
            } 
            return;
          }
  
          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
             document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
             document['fullScreenElement'] || document['fullscreenElement'] ||
             document['msFullScreenElement'] || document['msFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      },wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function () {
        var handle = Browser.nextWgetRequestHandle;
        Browser.nextWgetRequestHandle++;
        return handle;
      }};
  
  
  function _malloc(bytes) {
      /* Over-allocate to make sure it is byte-aligned by 8.
       * This will leak memory, but this is only the dummy
       * implementation (replaced by dlmalloc normally) so
       * not an issue.
       */
      var ptr = Runtime.dynamicAlloc(bytes + 8);
      return (ptr+8) & 0xFFFFFFF8;
    }
  Module["_malloc"] = _malloc;
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
  
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'web_user';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/web_user';
        ENV['LANG'] = 'C';
        ENV['_'] = Module['thisProgram'];
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr;
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
  
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
  
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        writeAsciiToMemory(line, poolPtr);
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
  
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }
  
  function _putenv(string) {
      // int putenv(char *string);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/putenv.html
      // WARNING: According to the standard (and the glibc implementation), the
      //          string is taken by reference so future changes are reflected.
      //          We copy it instead, possibly breaking some uses.
      if (string === 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      string = Pointer_stringify(string);
      var splitPoint = string.indexOf('=')
      if (string === '' || string.indexOf('=') === -1) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var name = string.slice(0, splitPoint);
      var value = string.slice(splitPoint + 1);
      if (!(name in ENV) || ENV[name] !== value) {
        ENV[name] = value;
        ___buildEnvironment(ENV);
      }
      return 0;
    }
  
  function _SDL_RWFromConstMem(mem, size) {
      var id = SDL.rwops.length; // TODO: recycle ids when they are null
      SDL.rwops.push({ bytes: mem, count: size });
      return id;
    }function _TTF_RenderText_Solid(font, text, color) {
      // XXX the font and color are ignored
      text = Pointer_stringify(text) || ' '; // if given an empty string, still return a valid surface
      var fontData = SDL.fonts[font];
      var w = SDL.estimateTextWidth(fontData, text);
      var h = fontData.size;
      var color = SDL.loadColorToCSSRGB(color); // XXX alpha breaks fonts?
      var fontString = h + 'px ' + fontData.name;
      var surf = SDL.makeSurface(w, h, 0, false, 'text:' + text); // bogus numbers..
      var surfData = SDL.surfaces[surf];
      surfData.ctx.save();
      surfData.ctx.fillStyle = color;
      surfData.ctx.font = fontString;
      surfData.ctx.textBaseline = 'top';
      surfData.ctx.fillText(text, 0, 0);
      surfData.ctx.restore();
      return surf;
    }function _Mix_HaltMusic() {
      var audio = SDL.music.audio;
      if (audio) {
        audio.src = audio.src; // rewind <media> element
        audio.currentPosition = 0; // rewind Web Audio graph playback.
        audio.pause();
      }
      SDL.music.audio = null;
      if (SDL.hookMusicFinished) {
        Runtime.dynCall('v', SDL.hookMusicFinished);
      }
      return 0;
    }function _Mix_PlayMusic(id, loops) {
      // Pause old music if it exists.
      if (SDL.music.audio) {
        if (!SDL.music.audio.paused) Module.printErr('Music is already playing. ' + SDL.music.source);
        SDL.music.audio.pause();
      }
      var info = SDL.audios[id];
      var audio;
      if (info.webAudio) { // Play via Web Audio API
        // Create an instance of the WebAudio object.
        audio = {};
        audio.resource = info; // This new webAudio object is an instance that refers to this existing resource.
        audio.paused = false;
        audio.currentPosition = 0;
        audio.play = function() { SDL.playWebAudio(this); }
        audio.pause = function() { SDL.pauseWebAudio(this); }
      } else if (info.audio) { // Play via the <audio> element
        audio = info.audio;
      }
      audio['onended'] = function() { if (SDL.music.audio == this) _Mix_HaltMusic(); } // will send callback
      audio.loop = loops != 0; // TODO: handle N loops for finite N
      audio.volume = SDL.music.volume;
      SDL.music.audio = audio;
      audio.play();
      return 0;
    }function _Mix_FreeChunk(id) {
      SDL.audios[id] = null;
    }function _Mix_LoadWAV_RW(rwopsID, freesrc) {
      var rwops = SDL.rwops[rwopsID];
  
      if (rwops === undefined)
        return 0;
  
      var filename = '';
      var audio;
      var webAudio;
      var bytes;
  
      if (rwops.filename !== undefined) {
        filename = PATH.resolve(rwops.filename);
        var raw = Module["preloadedAudios"][filename];
        if (!raw) {
          if (raw === null) Module.printErr('Trying to reuse preloaded audio, but freePreloadedMediaOnUse is set!');
          if (!Module.noAudioDecoding) Runtime.warnOnce('Cannot find preloaded audio ' + filename);
  
          // see if we can read the file-contents from the in-memory FS
          try {
            bytes = FS.readFile(filename);
          } catch (e) {
            Module.printErr('Couldn\'t find file for: ' + filename);
            return 0;
          }
        }
        if (Module['freePreloadedMediaOnUse']) {
          Module["preloadedAudios"][filename] = null;
        }
        audio = raw;
      }
      else if (rwops.bytes !== undefined) {
        // For Web Audio context buffer decoding, we must make a clone of the audio data, but for <media> element,
        // a view to existing data is sufficient.
        if (SDL.webAudioAvailable()) bytes = HEAPU8.buffer.slice(rwops.bytes, rwops.bytes + rwops.count);
        else bytes = HEAPU8.subarray(rwops.bytes, rwops.bytes + rwops.count);
      }
      else {
        return 0;
      }
  
      var arrayBuffer = bytes ? bytes.buffer || bytes : bytes;
  
      // To allow user code to work around browser bugs with audio playback on <audio> elements an Web Audio, enable
      // the user code to hook in a callback to decide on a file basis whether each file should use Web Audio or <audio> for decoding and playback.
      // In particular, see https://bugzilla.mozilla.org/show_bug.cgi?id=654787 and ?id=1012801 for tradeoffs.
      var canPlayWithWebAudio = Module['SDL_canPlayWithWebAudio'] === undefined || Module['SDL_canPlayWithWebAudio'](filename, arrayBuffer);
  
      if (bytes !== undefined && SDL.webAudioAvailable() && canPlayWithWebAudio) {
        audio = undefined;
        webAudio = {};
        // The audio decoding process is asynchronous, which gives trouble if user code plays the audio data back immediately
        // after loading. Therefore prepare an array of callback handlers to run when this audio decoding is complete, which
        // will then start the playback (with some delay).
        webAudio.onDecodeComplete = []; // While this member array exists, decoding hasn't finished yet.
        function onDecodeComplete(data) {
          webAudio.decodedBuffer = data;
          // Call all handlers that were waiting for this decode to finish, and clear the handler list.
          webAudio.onDecodeComplete.forEach(function(e) { e(); });
          webAudio.onDecodeComplete = undefined; // Don't allow more callback handlers since audio has finished decoding.
        }
  
        SDL.audioContext['decodeAudioData'](arrayBuffer, onDecodeComplete);
      } else if (audio === undefined && bytes) {
        // Here, we didn't find a preloaded audio but we either were passed a filepath for
        // which we loaded bytes, or we were passed some bytes
        var blob = new Blob([bytes], {type: rwops.mimetype});
        var url = URL.createObjectURL(blob);
        audio = new Audio();
        audio.src = url;
        audio.mozAudioChannelType = 'content'; // bugzilla 910340
      }
  
      var id = SDL.audios.length;
      // Keep the loaded audio in the audio arrays, ready for playback
      SDL.audios.push({
        source: filename,
        audio: audio, // Points to the <audio> element, if loaded
        webAudio: webAudio // Points to a Web Audio -specific resource object, if loaded
      });
      return id;
    }function _Mix_PlayChannel(channel, id, loops) {
      // TODO: handle fixed amount of N loops. Currently loops either 0 or infinite times.
  
      // Get the audio element associated with the ID
      var info = SDL.audios[id];
      if (!info) return -1;
      if (!info.audio && !info.webAudio) return -1;
  
      // If the user asks us to allocate a channel automatically, get the first
      // free one.
      if (channel == -1) {
        for (var i = SDL.channelMinimumNumber; i < SDL.numChannels; i++) {
          if (!SDL.channels[i].audio) {
            channel = i;
            break;
          }
        }
        if (channel == -1) {
          Module.printErr('All ' + SDL.numChannels + ' channels in use!');
          return -1;
        }
      }
      var channelInfo = SDL.channels[channel];
      var audio;
      if (info.webAudio) {
        // Create an instance of the WebAudio object.
        audio = {};
        audio.resource = info; // This new object is an instance that refers to this existing resource.
        audio.paused = false;
        audio.currentPosition = 0;
        // Make our instance look similar to the instance of a <media> to make api simple.
        audio.play = function() { SDL.playWebAudio(this); }
        audio.pause = function() { SDL.pauseWebAudio(this); }
      } else {
        // We clone the audio node to utilize the preloaded audio buffer, since
        // the browser has already preloaded the audio file.
        audio = info.audio.cloneNode(true);
        audio.numChannels = info.audio.numChannels;
        audio.frequency = info.audio.frequency;
      }
      audio['onended'] = function SDL_audio_onended() { // TODO: cache these
        if (channelInfo.audio == this) { channelInfo.audio.paused = true; channelInfo.audio = null; }
        if (SDL.channelFinished) Runtime.getFuncWrapper(SDL.channelFinished, 'vi')(channel);
      }
      channelInfo.audio = audio;
      // TODO: handle N loops. Behavior matches Mix_PlayMusic
      audio.loop = loops != 0;
      audio.volume = channelInfo.volume;
      audio.play();
      return channel;
    }function _SDL_PauseAudio(pauseOn) {
      if (!SDL.audio) {
        return;
      }
      if (pauseOn) {
        if (SDL.audio.timer !== undefined) {
          clearTimeout(SDL.audio.timer);
          SDL.audio.numAudioTimersPending = 0;
          SDL.audio.timer = undefined;
        }
      } else if (!SDL.audio.timer) {
        // Start the audio playback timer callback loop.
        SDL.audio.numAudioTimersPending = 1;
        SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, 1);
      }
      SDL.audio.paused = pauseOn;
    }function _SDL_CloseAudio() {
      if (SDL.audio) {
        _SDL_PauseAudio(1);
        _free(SDL.audio.buffer);
        SDL.audio = null;
        SDL.allocateChannels(0);
      }
    }function _SDL_LockSurface(surf) {
      var surfData = SDL.surfaces[surf];
  
      surfData.locked++;
      if (surfData.locked > 1) return 0;
  
      if (!surfData.buffer) {
        surfData.buffer = _malloc(surfData.width * surfData.height * 4);
        HEAP32[(((surf)+(20))>>2)]=surfData.buffer;
      }
  
      // Mark in C/C++-accessible SDL structure
      // SDL_Surface has the following fields: Uint32 flags, SDL_PixelFormat *format; int w, h; Uint16 pitch; void *pixels; ...
      // So we have fields all of the same size, and 5 of them before us.
      // TODO: Use macros like in library.js
      HEAP32[(((surf)+(20))>>2)]=surfData.buffer;
  
      if (surf == SDL.screen && Module.screenIsReadOnly && surfData.image) return 0;
  
      surfData.image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
      if (surf == SDL.screen) {
        var data = surfData.image.data;
        var num = data.length;
        for (var i = 0; i < num/4; i++) {
          data[i*4+3] = 255; // opacity, as canvases blend alpha
        }
      }
  
      if (SDL.defaults.copyOnLock) {
        // Copy pixel data to somewhere accessible to 'C/C++'
        if (surfData.isFlagSet(0x00200000 /* SDL_HWPALETTE */)) {
          // If this is neaded then
          // we should compact the data from 32bpp to 8bpp index.
          // I think best way to implement this is use
          // additional colorMap hash (color->index).
          // Something like this:
          //
          // var size = surfData.width * surfData.height;
          // var data = '';
          // for (var i = 0; i<size; i++) {
          //   var color = SDL.translateRGBAToColor(
          //     surfData.image.data[i*4   ], 
          //     surfData.image.data[i*4 +1], 
          //     surfData.image.data[i*4 +2], 
          //     255);
          //   var index = surfData.colorMap[color];
          //   HEAP8[(((surfData.buffer)+(i))>>0)]=index;
          // }
          throw 'CopyOnLock is not supported for SDL_LockSurface with SDL_HWPALETTE flag set' + new Error().stack;
        } else {
        HEAPU8.set(surfData.image.data, surfData.buffer);
        }
      }
  
      return 0;
    }
  
  function _SDL_FreeRW(rwopsID) {
      SDL.rwops[rwopsID] = null;
      while (SDL.rwops.length > 0 && SDL.rwops[SDL.rwops.length-1] === null) {
        SDL.rwops.pop();
      }
    }function _IMG_Load_RW(rwopsID, freeSrc) {
      try {
        // stb_image integration support
        function cleanup() {
          if (rwops && freeSrc) _SDL_FreeRW(rwopsID);
        };
        function addCleanup(func) {
          var old = cleanup;
          cleanup = function added_cleanup() {
            old();
            func();
          }
        }
        function callStbImage(func, params) {
          var x = Module['_malloc'](4);
          var y = Module['_malloc'](4);
          var comp = Module['_malloc'](4);
          addCleanup(function() {
            Module['_free'](x);
            Module['_free'](y);
            Module['_free'](comp);
            if (data) Module['_stbi_image_free'](data);
          });
          var data = Module['_' + func].apply(null, params.concat([x, y, comp, 0]));
          if (!data) return null;
          return {
            rawData: true,
            data: data,
            width: HEAP32[((x)>>2)],
            height: HEAP32[((y)>>2)],
            size: HEAP32[((x)>>2)] * HEAP32[((y)>>2)] * HEAP32[((comp)>>2)],
            bpp: HEAP32[((comp)>>2)]
          };
        }
  
        var rwops = SDL.rwops[rwopsID];
        if (rwops === undefined) {
          return 0;
        }
  
        var filename = rwops.filename;
        if (filename === undefined) {
          Runtime.warnOnce('Only file names that have been preloaded are supported for IMG_Load_RW. Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js)');
          return 0;
        }
  
        if (!raw) {
          filename = PATH.resolve(filename);
          var raw = Module["preloadedImages"][filename];
          if (!raw) {
            if (raw === null) Module.printErr('Trying to reuse preloaded image, but freePreloadedMediaOnUse is set!');
            Runtime.warnOnce('Cannot find preloaded image ' + filename);
            Runtime.warnOnce('Cannot find preloaded image ' + filename + '. Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js)');
            return 0;
          } else if (Module['freePreloadedMediaOnUse']) {
            Module["preloadedImages"][filename] = null;
          }
        }
  
        var surf = SDL.makeSurface(raw.width, raw.height, 0, false, 'load:' + filename);
        var surfData = SDL.surfaces[surf];
        surfData.ctx.globalCompositeOperation = "copy";
        if (!raw.rawData) {
          surfData.ctx.drawImage(raw, 0, 0, raw.width, raw.height, 0, 0, raw.width, raw.height);
        } else {
          var imageData = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
          if (raw.bpp == 4) {
            // rgba
            imageData.data.set(HEAPU8.subarray((raw.data),(raw.data+raw.size)));
          } else if (raw.bpp == 3) {
            // rgb
            var pixels = raw.size/3;
            var data = imageData.data;
            var sourcePtr = raw.data;
            var destPtr = 0;
            for (var i = 0; i < pixels; i++) {
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = 255;
            }
          } else if (raw.bpp == 1) {
            // grayscale
            var pixels = raw.size;
            var data = imageData.data;
            var sourcePtr = raw.data;
            var destPtr = 0;
            for (var i = 0; i < pixels; i++) {
              var value = HEAPU8[((sourcePtr++)>>0)];
              data[destPtr++] = value;
              data[destPtr++] = value;
              data[destPtr++] = value;
              data[destPtr++] = 255;
            }
          } else {
            Module.printErr('cannot handle bpp ' + raw.bpp);
            return 0;
          }
          surfData.ctx.putImageData(imageData, 0, 0);
        }
        surfData.ctx.globalCompositeOperation = "source-over";
        // XXX SDL does not specify that loaded images must have available pixel data, in fact
        //     there are cases where you just want to blit them, so you just need the hardware
        //     accelerated version. However, code everywhere seems to assume that the pixels
        //     are in fact available, so we retrieve it here. This does add overhead though.
        _SDL_LockSurface(surf);
        surfData.locked--; // The surface is not actually locked in this hack
        if (SDL.GL) {
          // After getting the pixel data, we can free the canvas and context if we do not need to do 2D canvas blitting
          surfData.canvas = surfData.ctx = null;
        }
        return surf;
      } finally {
        cleanup();
      }
    }
  
  function _SDL_RWFromFile(_name, mode) {
      var id = SDL.rwops.length; // TODO: recycle ids when they are null
      var name = Pointer_stringify(_name)
      SDL.rwops.push({ filename: name, mimetype: Browser.getMimetype(name) });
      return id;
    }function _IMG_Load(filename){
      var rwops = _SDL_RWFromFile(filename);
      var result = _IMG_Load_RW(rwops, 1);
      return result;
    }function _SDL_UpperBlitScaled(src, srcrect, dst, dstrect) {
      return SDL.blitSurface(src, srcrect, dst, dstrect, true);
    }function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
      return SDL.blitSurface(src, srcrect, dst, dstrect, false);
    }function _SDL_GetTicks() {
      return (Date.now() - SDL.startTime)|0;
    }var SDL={defaults:{width:320,height:200,copyOnLock:true},version:null,surfaces:{},canvasPool:[],events:[],fonts:[null],audios:[null],rwops:[null],music:{audio:null,volume:1},mixerFrequency:22050,mixerFormat:32784,mixerNumChannels:2,mixerChunkSize:1024,channelMinimumNumber:0,GL:false,glAttributes:{0:3,1:3,2:2,3:0,4:0,5:1,6:16,7:0,8:0,9:0,10:0,11:0,12:0,13:0,14:0,15:1,16:0,17:0,18:0},keyboardState:null,keyboardMap:{},canRequestFullscreen:false,isRequestingFullscreen:false,textInput:false,startTime:null,initFlags:0,buttonState:0,modState:0,DOMButtons:[0,0,0],DOMEventToSDLEvent:{},TOUCH_DEFAULT_ID:0,eventHandler:null,eventHandlerContext:null,keyCodes:{16:1249,17:1248,18:1250,20:1081,33:1099,34:1102,35:1101,36:1098,37:1104,38:1106,39:1103,40:1105,44:316,45:1097,46:127,91:1251,93:1125,96:1122,97:1113,98:1114,99:1115,100:1116,101:1117,102:1118,103:1119,104:1120,105:1121,106:1109,107:1111,109:1110,110:1123,111:1108,112:1082,113:1083,114:1084,115:1085,116:1086,117:1087,118:1088,119:1089,120:1090,121:1091,122:1092,123:1093,124:1128,125:1129,126:1130,127:1131,128:1132,129:1133,130:1134,131:1135,132:1136,133:1137,134:1138,135:1139,144:1107,160:94,161:33,162:34,163:35,164:36,165:37,166:38,167:95,168:40,169:41,170:42,171:43,172:124,173:45,174:123,175:125,176:126,181:127,182:129,183:128,188:44,190:46,191:47,192:96,219:91,220:92,221:93,222:39},scanCodes:{8:42,9:43,13:40,27:41,32:44,35:204,39:53,44:54,46:55,47:56,48:39,49:30,50:31,51:32,52:33,53:34,54:35,55:36,56:37,57:38,58:203,59:51,61:46,91:47,92:49,93:48,96:52,97:4,98:5,99:6,100:7,101:8,102:9,103:10,104:11,105:12,106:13,107:14,108:15,109:16,110:17,111:18,112:19,113:20,114:21,115:22,116:23,117:24,118:25,119:26,120:27,121:28,122:29,127:76,305:224,308:226,316:70},loadRect:function (rect) {
        return {
          x: HEAP32[((rect + 0)>>2)],
          y: HEAP32[((rect + 4)>>2)],
          w: HEAP32[((rect + 8)>>2)],
          h: HEAP32[((rect + 12)>>2)]
        };
      },checkPixelFormat:function (fmt) {
      },loadColorToCSSRGB:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgb(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ')';
      },loadColorToCSSRGBA:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgba(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ',' + (((rgba >> 24)&255)/255) + ')';
      },translateColorToCSSRGBA:function (rgba) {
        return 'rgba(' + (rgba&0xff) + ',' + (rgba>>8 & 0xff) + ',' + (rgba>>16 & 0xff) + ',' + (rgba>>>24)/0xff + ')';
      },translateRGBAToCSSRGBA:function (r, g, b, a) {
        return 'rgba(' + (r&0xff) + ',' + (g&0xff) + ',' + (b&0xff) + ',' + (a&0xff)/255 + ')';
      },translateRGBAToColor:function (r, g, b, a) {
        return r | g << 8 | b << 16 | a << 24;
      },makeSurface:function (width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
        flags = flags || 0;
        var is_SDL_HWSURFACE = flags & 0x00000001;
        var is_SDL_HWPALETTE = flags & 0x00200000;
        var is_SDL_OPENGL = flags & 0x04000000;
  
        var surf = _malloc(60);
        var pixelFormat = _malloc(44);
        //surface with SDL_HWPALETTE flag is 8bpp surface (1 byte)
        var bpp = is_SDL_HWPALETTE ? 1 : 4;
        var buffer = 0;
  
        // preemptively initialize this for software surfaces,
        // otherwise it will be lazily initialized inside of SDL_LockSurface
        if (!is_SDL_HWSURFACE && !is_SDL_OPENGL) {
          buffer = _malloc(width * height * 4);
        }
  
        HEAP32[((surf)>>2)]=flags;
        HEAP32[(((surf)+(4))>>2)]=pixelFormat;
        HEAP32[(((surf)+(8))>>2)]=width;
        HEAP32[(((surf)+(12))>>2)]=height;
        HEAP32[(((surf)+(16))>>2)]=width * bpp;  // assuming RGBA or indexed for now,
                                                                                          // since that is what ImageData gives us in browsers
        HEAP32[(((surf)+(20))>>2)]=buffer;
  
        HEAP32[(((surf)+(36))>>2)]=0;
        HEAP32[(((surf)+(40))>>2)]=0;
        HEAP32[(((surf)+(44))>>2)]=Module["canvas"].width;
        HEAP32[(((surf)+(48))>>2)]=Module["canvas"].height;
  
        HEAP32[(((surf)+(56))>>2)]=1;
  
        HEAP32[((pixelFormat)>>2)]=-2042224636;
        HEAP32[(((pixelFormat)+(4))>>2)]=0;// TODO
        HEAP8[(((pixelFormat)+(8))>>0)]=bpp * 8;
        HEAP8[(((pixelFormat)+(9))>>0)]=bpp;
  
        HEAP32[(((pixelFormat)+(12))>>2)]=rmask || 0x000000ff;
        HEAP32[(((pixelFormat)+(16))>>2)]=gmask || 0x0000ff00;
        HEAP32[(((pixelFormat)+(20))>>2)]=bmask || 0x00ff0000;
        HEAP32[(((pixelFormat)+(24))>>2)]=amask || 0xff000000;
  
        // Decide if we want to use WebGL or not
        SDL.GL = SDL.GL || is_SDL_OPENGL;
        var canvas;
        if (!usePageCanvas) {
          if (SDL.canvasPool.length > 0) {
            canvas = SDL.canvasPool.pop();
          } else {
            canvas = document.createElement('canvas');
          }
          canvas.width = width;
          canvas.height = height;
        } else {
          canvas = Module['canvas'];
        }
  
        var webGLContextAttributes = {
          antialias: ((SDL.glAttributes[13 /*SDL_GL_MULTISAMPLEBUFFERS*/] != 0) && (SDL.glAttributes[14 /*SDL_GL_MULTISAMPLESAMPLES*/] > 1)),
          depth: (SDL.glAttributes[6 /*SDL_GL_DEPTH_SIZE*/] > 0),
          stencil: (SDL.glAttributes[7 /*SDL_GL_STENCIL_SIZE*/] > 0)
        };
        
        var ctx = Browser.createContext(canvas, is_SDL_OPENGL, usePageCanvas, webGLContextAttributes);
              
        SDL.surfaces[surf] = {
          width: width,
          height: height,
          canvas: canvas,
          ctx: ctx,
          surf: surf,
          buffer: buffer,
          pixelFormat: pixelFormat,
          alpha: 255,
          flags: flags,
          locked: 0,
          usePageCanvas: usePageCanvas,
          source: source,
  
          isFlagSet: function(flag) {
            return flags & flag;
          }
        };
  
        return surf;
      },copyIndexedColorData:function (surfData, rX, rY, rW, rH) {
        // HWPALETTE works with palette
        // setted by SDL_SetColors
        if (!surfData.colors) {
          return;
        }
        
        var fullWidth  = Module['canvas'].width;
        var fullHeight = Module['canvas'].height;
  
        var startX  = rX || 0;
        var startY  = rY || 0;
        var endX    = (rW || (fullWidth - startX)) + startX;
        var endY    = (rH || (fullHeight - startY)) + startY;
        
        var buffer  = surfData.buffer;
        var data    = surfData.image.data;
        var colors  = surfData.colors;
  
        for (var y = startY; y < endY; ++y) {
          var indexBase = y * fullWidth;
          var colorBase = indexBase * 4;
          for (var x = startX; x < endX; ++x) {
            // HWPALETTE have only 256 colors (not rgba)
            var index = HEAPU8[((buffer + indexBase + x)>>0)] * 3;
            var colorOffset = colorBase + x * 4;
  
            data[colorOffset   ] = colors[index   ];
            data[colorOffset +1] = colors[index +1];
            data[colorOffset +2] = colors[index +2];
            //unused: data[colorOffset +3] = color[index +3];
          }
        }
      },freeSurface:function (surf) {
        var refcountPointer = surf + 56;
        var refcount = HEAP32[((refcountPointer)>>2)];
        if (refcount > 1) {
          HEAP32[((refcountPointer)>>2)]=refcount - 1;
          return;
        }
  
        var info = SDL.surfaces[surf];
        if (!info.usePageCanvas && info.canvas) SDL.canvasPool.push(info.canvas);
        if (info.buffer) _free(info.buffer);
        _free(info.pixelFormat);
        _free(surf);
        SDL.surfaces[surf] = null;
  
        if (surf === SDL.screen) {
          SDL.screen = null;
        }
      },blitSurface__deps:["SDL_LockSurface"],blitSurface:function (src, srcrect, dst, dstrect, scale) {
        var srcData = SDL.surfaces[src];
        var dstData = SDL.surfaces[dst];
        var sr, dr;
        if (srcrect) {
          sr = SDL.loadRect(srcrect);
        } else {
          sr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
        }
        if (dstrect) {
          dr = SDL.loadRect(dstrect);
        } else {
          dr = { x: 0, y: 0, w: -1, h: -1 };
        }
        var oldAlpha = dstData.ctx.globalAlpha;
        dstData.ctx.globalAlpha = srcData.alpha/255;
        var blitw, blitr;
        if (scale) {
          blitw = dr.w; blith = dr.h;
        } else {
          blitw = sr.w; blith = sr.h;
        }
        dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, blitw, blith);
        dstData.ctx.globalAlpha = oldAlpha;
        if (dst != SDL.screen) {
          // XXX As in IMG_Load, for compatibility we write out |pixels|
          Runtime.warnOnce('WARNING: copying canvas data to memory for compatibility');
          _SDL_LockSurface(dst);
          dstData.locked--; // The surface is not actually locked in this hack
        }
        return 0;
      },downFingers:{},savedKeydown:null,receiveEvent:function (event) {
        function unpressAllPressedKeys() {
          // Un-press all pressed keys: TODO
          for (var code in SDL.keyboardMap) {
            SDL.events.push({
              type: 'keyup',
              keyCode: SDL.keyboardMap[code]
            });
          }
        };
        switch(event.type) {
          case 'touchstart': case 'touchmove': {
            event.preventDefault();
  
            var touches = [];
            
            // Clear out any touchstart events that we've already processed
            if (event.type === 'touchstart') {
              for (var i = 0; i < event.touches.length; i++) {
                var touch = event.touches[i];
                if (SDL.downFingers[touch.identifier] != true) {
                  SDL.downFingers[touch.identifier] = true;
                  touches.push(touch);
                }
              }
            } else {
              touches = event.touches;
            }
            
            var firstTouch = touches[0];
            if (event.type == 'touchstart') {
              SDL.DOMButtons[0] = 1;
            }
            var mouseEventType;
            switch(event.type) {
              case 'touchstart': mouseEventType = 'mousedown'; break;
              case 'touchmove': mouseEventType = 'mousemove'; break;
            }
            var mouseEvent = {
              type: mouseEventType,
              button: 0,
              pageX: firstTouch.clientX,
              pageY: firstTouch.clientY
            };
            SDL.events.push(mouseEvent);
  
            for (var i = 0; i < touches.length; i++) {
              var touch = touches[i];
              SDL.events.push({
                type: event.type,
                touch: touch
              });
            };
            break;
          }
          case 'touchend': {
            event.preventDefault();
            
            // Remove the entry in the SDL.downFingers hash
            // because the finger is no longer down.
            for(var i = 0; i < event.changedTouches.length; i++) {
              var touch = event.changedTouches[i];
              if (SDL.downFingers[touch.identifier] === true) {
                delete SDL.downFingers[touch.identifier];
              }
            }
  
            var mouseEvent = {
              type: 'mouseup',
              button: 0,
              pageX: event.changedTouches[0].clientX,
              pageY: event.changedTouches[0].clientY
            };
            SDL.DOMButtons[0] = 0;
            SDL.events.push(mouseEvent);
            
            for (var i = 0; i < event.changedTouches.length; i++) {
              var touch = event.changedTouches[i];
              SDL.events.push({
                type: 'touchend',
                touch: touch
              });
            };
            break;
          }
          case 'DOMMouseScroll': case 'mousewheel': case 'wheel':
            var delta = -Browser.getMouseWheelDelta(event); // Flip the wheel direction to translate from browser wheel direction (+:down) to SDL direction (+:up)
            delta = (delta == 0) ? 0 : (delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1)); // Quantize to integer so that minimum scroll is at least +/- 1.
  
            // Simulate old-style SDL events representing mouse wheel input as buttons
            var button = delta > 0 ? 3 /*SDL_BUTTON_WHEELUP-1*/ : 4 /*SDL_BUTTON_WHEELDOWN-1*/; // Subtract one since JS->C marshalling is defined to add one back.
            SDL.events.push({ type: 'mousedown', button: button, pageX: event.pageX, pageY: event.pageY });
            SDL.events.push({ type: 'mouseup', button: button, pageX: event.pageX, pageY: event.pageY });
  
            // Pass a delta motion event.
            SDL.events.push({ type: 'wheel', deltaX: 0, deltaY: delta });
            event.preventDefault(); // If we don't prevent this, then 'wheel' event will be sent again by the browser as 'DOMMouseScroll' and we will receive this same event the second time.
            break;
          case 'mousemove':
            if (SDL.DOMButtons[0] === 1) {
              SDL.events.push({
                type: 'touchmove',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
            }
            if (Browser.pointerLock) {
              // workaround for firefox bug 750111
              if ('mozMovementX' in event) {
                event['movementX'] = event['mozMovementX'];
                event['movementY'] = event['mozMovementY'];
              }
              // workaround for Firefox bug 782777
              if (event['movementX'] == 0 && event['movementY'] == 0) {
                // ignore a mousemove event if it doesn't contain any movement info
                // (without pointer lock, we infer movement from pageX/pageY, so this check is unnecessary)
                event.preventDefault();
                return;
              }
            }
            // fall through
          case 'keydown': case 'keyup': case 'keypress': case 'mousedown': case 'mouseup':
            // If we preventDefault on keydown events, the subsequent keypress events
            // won't fire. However, it's fine (and in some cases necessary) to
            // preventDefault for keys that don't generate a character. Otherwise,
            // preventDefault is the right thing to do in general.
            if (event.type !== 'keydown' || (!SDL.unicode && !SDL.textInput) || (event.keyCode === 8 /* backspace */ || event.keyCode === 9 /* tab */)) {
              event.preventDefault();
            }
  
            if (event.type == 'mousedown') {
              SDL.DOMButtons[event.button] = 1;
              SDL.events.push({
                type: 'touchstart',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
            } else if (event.type == 'mouseup') {
              // ignore extra ups, can happen if we leave the canvas while pressing down, then return,
              // since we add a mouseup in that case
              if (!SDL.DOMButtons[event.button]) {
                return;
              }
  
              SDL.events.push({
                type: 'touchend',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
              SDL.DOMButtons[event.button] = 0;
            }
  
            // We can only request fullscreen as the result of user input.
            // Due to this limitation, we toggle a boolean on keydown which
            // SDL_WM_ToggleFullScreen will check and subsequently set another
            // flag indicating for us to request fullscreen on the following
            // keyup. This isn't perfect, but it enables SDL_WM_ToggleFullScreen
            // to work as the result of a keypress (which is an extremely
            // common use case).
            if (event.type === 'keydown' || event.type === 'mousedown') {
              SDL.canRequestFullscreen = true;
            } else if (event.type === 'keyup' || event.type === 'mouseup') {
              if (SDL.isRequestingFullscreen) {
                Module['requestFullScreen'](true, true);
                SDL.isRequestingFullscreen = false;
              }
              SDL.canRequestFullscreen = false;
            }
  
            // SDL expects a unicode character to be passed to its keydown events.
            // Unfortunately, the browser APIs only provide a charCode property on
            // keypress events, so we must backfill in keydown events with their
            // subsequent keypress event's charCode.
            if (event.type === 'keypress' && SDL.savedKeydown) {
              // charCode is read-only
              SDL.savedKeydown.keypressCharCode = event.charCode;
              SDL.savedKeydown = null;
            } else if (event.type === 'keydown') {
              SDL.savedKeydown = event;
            }
  
            // Don't push keypress events unless SDL_StartTextInput has been called.
            if (event.type !== 'keypress' || SDL.textInput) {
              SDL.events.push(event);
            }
            break;
          case 'mouseout':
            // Un-press all pressed mouse buttons, because we might miss the release outside of the canvas
            for (var i = 0; i < 3; i++) {
              if (SDL.DOMButtons[i]) {
                SDL.events.push({
                  type: 'mouseup',
                  button: i,
                  pageX: event.pageX,
                  pageY: event.pageY
                });
                SDL.DOMButtons[i] = 0;
              }
            }
            event.preventDefault();
            break;
          case 'focus':
            SDL.events.push(event);
            event.preventDefault();
            break;
          case 'blur':
            SDL.events.push(event);
            unpressAllPressedKeys();
            event.preventDefault();
            break;
          case 'visibilitychange':
            SDL.events.push({
              type: 'visibilitychange',
              visible: !document.hidden
            });
            unpressAllPressedKeys();
            event.preventDefault();
            break;
          case 'unload':
            if (Browser.mainLoop.runner) {
              SDL.events.push(event);
              // Force-run a main event loop, since otherwise this event will never be caught!
              Browser.mainLoop.runner();
            }
            return;
          case 'resize':
            SDL.events.push(event);
            // manually triggered resize event doesn't have a preventDefault member
            if (event.preventDefault) {
              event.preventDefault();
            }
            break;
        }
        if (SDL.events.length >= 10000) {
          Module.printErr('SDL event queue full, dropping events');
          SDL.events = SDL.events.slice(0, 10000);
        }
        // If we have a handler installed, this will push the events to the app
        // instead of the app polling for them.
        SDL.flushEventsToHandler();
        return;
      },lookupKeyCodeForEvent:function (event) {
          var code = event.keyCode;
          if (code >= 65 && code <= 90) {
            code += 32; // make lowercase for SDL
          } else {
            code = SDL.keyCodes[event.keyCode] || event.keyCode;
            // If this is one of the modifier keys (224 | 1<<10 - 227 | 1<<10), and the event specifies that it is
            // a right key, add 4 to get the right key SDL key code.
            if (event.location === KeyboardEvent.DOM_KEY_LOCATION_RIGHT && code >= (224 | 1<<10) && code <= (227 | 1<<10)) {
              code += 4;
            }
          }
          return code;
      },handleEvent:function (event) {
        if (event.handled) return;
        event.handled = true;
  
        switch (event.type) {
          case 'touchstart': case 'touchend': case 'touchmove': {
            Browser.calculateMouseEvent(event);
            break;
          }
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            var code = SDL.lookupKeyCodeForEvent(event);
            HEAP8[(((SDL.keyboardState)+(code))>>0)]=down;
            // TODO: lmeta, rmeta, numlock, capslock, KMOD_MODE, KMOD_RESERVED
            SDL.modState = (HEAP8[(((SDL.keyboardState)+(1248))>>0)] ? 0x0040 : 0) | // KMOD_LCTRL
              (HEAP8[(((SDL.keyboardState)+(1249))>>0)] ? 0x0001 : 0) | // KMOD_LSHIFT
              (HEAP8[(((SDL.keyboardState)+(1250))>>0)] ? 0x0100 : 0) | // KMOD_LALT
              (HEAP8[(((SDL.keyboardState)+(1252))>>0)] ? 0x0080 : 0) | // KMOD_RCTRL
              (HEAP8[(((SDL.keyboardState)+(1253))>>0)] ? 0x0002 : 0) | // KMOD_RSHIFT
              (HEAP8[(((SDL.keyboardState)+(1254))>>0)] ? 0x0200 : 0); //  KMOD_RALT
            if (down) {
              SDL.keyboardMap[code] = event.keyCode; // save the DOM input, which we can use to unpress it during blur
            } else {
              delete SDL.keyboardMap[code];
            }
  
            break;
          }
          case 'mousedown': case 'mouseup':
            if (event.type == 'mousedown') {
              // SDL_BUTTON(x) is defined as (1 << ((x)-1)).  SDL buttons are 1-3,
              // and DOM buttons are 0-2, so this means that the below formula is
              // correct.
              SDL.buttonState |= 1 << event.button;
            } else if (event.type == 'mouseup') {
              SDL.buttonState &= ~(1 << event.button);
            }
            // fall through
          case 'mousemove': {
            Browser.calculateMouseEvent(event);
            break;
          }
        }
      },flushEventsToHandler:function () {
        if (!SDL.eventHandler) return;
  
        // All SDLEvents take the same amount of memory
        var sdlEventPtr = allocate(28, "i8", ALLOC_STACK);
  
        while (SDL.pollEvent(sdlEventPtr)) {
          Runtime.dynCall('iii', SDL.eventHandler, [SDL.eventHandlerContext, sdlEventPtr]);
        }
      },pollEvent:function (ptr) {
        if (SDL.initFlags & 0x200 && SDL.joystickEventState) {
          // If SDL_INIT_JOYSTICK was supplied AND the joystick system is configured
          // to automatically query for events, query for joystick events.
          SDL.queryJoysticks();
        }
        if (ptr) {
          while (SDL.events.length > 0) {
            if (SDL.makeCEvent(SDL.events.shift(), ptr) !== false) return 1;
          }
          return 0;
        } else {
          // XXX: somewhat risky in that we do not check if the event is real or not (makeCEvent returns false) if no pointer supplied
          return SDL.events.length > 0;
        }
      },makeCEvent:function (event, ptr) {
        if (typeof event === 'number') {
          // This is a pointer to a copy of a native C event that was SDL_PushEvent'ed
          _memcpy(ptr, event, 28);
          _free(event); // the copy is no longer needed
          return;
        }
  
        SDL.handleEvent(event);
  
        switch (event.type) {
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            //Module.print('Received key event: ' + event.keyCode);
            var key = SDL.lookupKeyCodeForEvent(event);
            var scan;
            if (key >= 1024) {
              scan = key - 1024;
            } else {
              scan = SDL.scanCodes[key] || key;
            }
  
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(8))>>0)]=down ? 1 : 0;
            HEAP8[(((ptr)+(9))>>0)]=0; // TODO
            HEAP32[(((ptr)+(12))>>2)]=scan;
            HEAP32[(((ptr)+(16))>>2)]=key;
            HEAP16[(((ptr)+(20))>>1)]=SDL.modState;
            // some non-character keys (e.g. backspace and tab) won't have keypressCharCode set, fill in with the keyCode.
            HEAP32[(((ptr)+(24))>>2)]=event.keypressCharCode || key;
  
            break;
          }
          case 'keypress': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            // Not filling in windowID for now
            var cStr = intArrayFromString(String.fromCharCode(event.charCode));
            for (var i = 0; i < cStr.length; ++i) {
              HEAP8[(((ptr)+(8 + i))>>0)]=cStr[i];
            }
            break;
          }
          case 'mousedown': case 'mouseup': case 'mousemove': {
            if (event.type != 'mousemove') {
              var down = event.type === 'mousedown';
              HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP32[(((ptr)+(4))>>2)]=0;
              HEAP32[(((ptr)+(8))>>2)]=0;
              HEAP32[(((ptr)+(12))>>2)]=0;
              HEAP8[(((ptr)+(16))>>0)]=event.button+1; // DOM buttons are 0-2, SDL 1-3
              HEAP8[(((ptr)+(17))>>0)]=down ? 1 : 0;
              HEAP32[(((ptr)+(20))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(24))>>2)]=Browser.mouseY;
            } else {
              HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP32[(((ptr)+(4))>>2)]=0;
              HEAP32[(((ptr)+(8))>>2)]=0;
              HEAP32[(((ptr)+(12))>>2)]=0;
              HEAP32[(((ptr)+(16))>>2)]=SDL.buttonState;
              HEAP32[(((ptr)+(20))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(24))>>2)]=Browser.mouseY;
              HEAP32[(((ptr)+(28))>>2)]=Browser.mouseMovementX;
              HEAP32[(((ptr)+(32))>>2)]=Browser.mouseMovementY;
            }
            break;
          }
          case 'wheel': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(16))>>2)]=event.deltaX;
            HEAP32[(((ptr)+(20))>>2)]=event.deltaY; 
            break;       
          }
          case 'touchstart': case 'touchend': case 'touchmove': {
            var touch = event.touch;
            if (!Browser.touches[touch.identifier]) break;
            var w = Module['canvas'].width;
            var h = Module['canvas'].height;
            var x = Browser.touches[touch.identifier].x / w;
            var y = Browser.touches[touch.identifier].y / h;
            var lx = Browser.lastTouches[touch.identifier].x / w;
            var ly = Browser.lastTouches[touch.identifier].y / h;
            var dx = x - lx;
            var dy = y - ly;
            if (touch['deviceID'] === undefined) touch.deviceID = SDL.TOUCH_DEFAULT_ID;
            if (dx === 0 && dy === 0 && event.type === 'touchmove') return false; // don't send these if nothing happened
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=_SDL_GetTicks();
            (tempI64 = [touch.deviceID>>>0,(tempDouble=touch.deviceID,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[(((ptr)+(8))>>2)]=tempI64[0],HEAP32[(((ptr)+(12))>>2)]=tempI64[1]);
            (tempI64 = [touch.identifier>>>0,(tempDouble=touch.identifier,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[(((ptr)+(16))>>2)]=tempI64[0],HEAP32[(((ptr)+(20))>>2)]=tempI64[1]);
            HEAPF32[(((ptr)+(24))>>2)]=x;
            HEAPF32[(((ptr)+(28))>>2)]=y;
            HEAPF32[(((ptr)+(32))>>2)]=dx;
            HEAPF32[(((ptr)+(36))>>2)]=dy;
            if (touch.force !== undefined) {
              HEAPF32[(((ptr)+(40))>>2)]=touch.force;
            } else { // No pressure data, send a digital 0/1 pressure.
              HEAPF32[(((ptr)+(40))>>2)]=event.type == "touchend" ? 0 : 1;
            }
            break;
          }
          case 'unload': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            break;
          }
          case 'resize': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=event.w;
            HEAP32[(((ptr)+(8))>>2)]=event.h;
            break;
          }
          case 'joystick_button_up': case 'joystick_button_down': {
            var state = event.type === 'joystick_button_up' ? 0 : 1;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(4))>>0)]=event.index;
            HEAP8[(((ptr)+(5))>>0)]=event.button;
            HEAP8[(((ptr)+(6))>>0)]=state;
            break;
          }
          case 'joystick_axis_motion': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(4))>>0)]=event.index;
            HEAP8[(((ptr)+(5))>>0)]=event.axis;
            HEAP32[(((ptr)+(8))>>2)]=SDL.joystickAxisValueConversion(event.value);
            break;
          }
          case 'focus': {
            var SDL_WINDOWEVENT_FOCUS_GAINED = 12 /* SDL_WINDOWEVENT_FOCUS_GAINED */;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=SDL_WINDOWEVENT_FOCUS_GAINED;
            break;
          }
          case 'blur': {
            var SDL_WINDOWEVENT_FOCUS_LOST = 13 /* SDL_WINDOWEVENT_FOCUS_LOST */;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=SDL_WINDOWEVENT_FOCUS_LOST;
            break;
          }
          case 'visibilitychange': {
            var SDL_WINDOWEVENT_SHOWN  = 1 /* SDL_WINDOWEVENT_SHOWN */;
            var SDL_WINDOWEVENT_HIDDEN = 2 /* SDL_WINDOWEVENT_HIDDEN */;
            var visibilityEventID = event.visible ? SDL_WINDOWEVENT_SHOWN : SDL_WINDOWEVENT_HIDDEN;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=0;
            HEAP8[(((ptr)+(8))>>0)]=visibilityEventID;
            break;
          }
          default: throw 'Unhandled SDL event: ' + event.type;
        }
      },estimateTextWidth:function (fontData, text) {
        var h = fontData.size;
        var fontString = h + 'px ' + fontData.name;
        var tempCtx = SDL.ttfContext;
        tempCtx.save();
        tempCtx.font = fontString;
        var ret = tempCtx.measureText(text).width | 0;
        tempCtx.restore();
        return ret;
      },allocateChannels:function (num) { // called from Mix_AllocateChannels and init
        if (SDL.numChannels && SDL.numChannels >= num && num != 0) return;
        SDL.numChannels = num;
        SDL.channels = [];
        for (var i = 0; i < num; i++) {
          SDL.channels[i] = {
            audio: null,
            volume: 1.0
          };
        }
      },setGetVolume:function (info, volume) {
        if (!info) return 0;
        var ret = info.volume * 128; // MIX_MAX_VOLUME
        if (volume != -1) {
          info.volume = Math.min(Math.max(volume, 0), 128) / 128;
          if (info.audio) {
            try {
              info.audio.volume = info.volume; // For <audio> element
              if (info.audio.webAudioGainNode) info.audio.webAudioGainNode['gain']['value'] = info.volume; // For WebAudio playback
            } catch(e) {
              Module.printErr('setGetVolume failed to set audio volume: ' + e);
            }
          }
        }
        return ret;
      },playWebAudio:function (audio) {
        if (!audio) return;
        if (audio.webAudioNode) return; // This instance is already playing, don't start again.
        if (!SDL.webAudioAvailable()) return;
        try {
          var webAudio = audio.resource.webAudio;
          audio.paused = false;
          if (!webAudio.decodedBuffer) {
            if (webAudio.onDecodeComplete === undefined) abort("Cannot play back audio object that was not loaded");
            webAudio.onDecodeComplete.push(function() { if (!audio.paused) SDL.playWebAudio(audio); });
            return;
          }
          audio.webAudioNode = SDL.audioContext['createBufferSource']();
          audio.webAudioNode['buffer'] = webAudio.decodedBuffer;
          audio.webAudioNode['loop'] = audio.loop;
          audio.webAudioNode['onended'] = function() { audio.onended(); } // For <media> element compatibility, route the onended signal to the instance.
  
          // Add an intermediate gain node to control volume.
          audio.webAudioGainNode = SDL.audioContext['createGain']();
          audio.webAudioGainNode['gain']['value'] = audio.volume;
          audio.webAudioNode['connect'](audio.webAudioGainNode);
          audio.webAudioGainNode['connect'](SDL.audioContext['destination']);
          audio.webAudioNode['start'](0, audio.currentPosition);
          audio.startTime = SDL.audioContext['currentTime'] - audio.currentPosition;
        } catch(e) {
          Module.printErr('playWebAudio failed: ' + e);
        }
      },pauseWebAudio:function (audio) {
        if (!audio) return;
        if (audio.webAudioNode) {
          try {
            // Remember where we left off, so that if/when we resume, we can restart the playback at a proper place.
            audio.currentPosition = (SDL.audioContext['currentTime'] - audio.startTime) % audio.resource.webAudio.decodedBuffer.duration;
            // Important: When we reach here, the audio playback is stopped by the user. But when calling .stop() below, the Web Audio
            // graph will send the onended signal, but we don't want to process that, since pausing should not clear/destroy the audio
            // channel.
            audio.webAudioNode['onended'] = undefined;
            audio.webAudioNode.stop();
            audio.webAudioNode = undefined;
          } catch(e) {
            Module.printErr('pauseWebAudio failed: ' + e);
          }
        }
        audio.paused = true;
      },openAudioContext:function () {
        // Initialize Web Audio API if we haven't done so yet. Note: Only initialize Web Audio context ever once on the web page,
        // since initializing multiple times fails on Chrome saying 'audio resources have been exhausted'.
        if (!SDL.audioContext) {
          if (typeof(AudioContext) !== 'undefined') SDL.audioContext = new AudioContext();
          else if (typeof(webkitAudioContext) !== 'undefined') SDL.audioContext = new webkitAudioContext();
        }
      },webAudioAvailable:function () { return !!SDL.audioContext; },fillWebAudioBufferFromHeap:function (heapPtr, sizeSamplesPerChannel, dstAudioBuffer) {
        // The input audio data is interleaved across the channels, i.e. [L, R, L, R, L, R, ...] and is either 8-bit or 16-bit as
        // supported by the SDL API. The output audio wave data for Web Audio API must be in planar buffers of [-1,1]-normalized Float32 data,
        // so perform a buffer conversion for the data.
        var numChannels = SDL.audio.channels;
        for(var c = 0; c < numChannels; ++c) {
          var channelData = dstAudioBuffer['getChannelData'](c);
          if (channelData.length != sizeSamplesPerChannel) {
            throw 'Web Audio output buffer length mismatch! Destination size: ' + channelData.length + ' samples vs expected ' + sizeSamplesPerChannel + ' samples!';
          }
          if (SDL.audio.format == 0x8010 /*AUDIO_S16LSB*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              channelData[j] = (HEAP16[(((heapPtr)+((j*numChannels + c)*2))>>1)]) / 0x8000;
            }
          } else if (SDL.audio.format == 0x0008 /*AUDIO_U8*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              var v = (HEAP8[(((heapPtr)+(j*numChannels + c))>>0)]);
              channelData[j] = ((v >= 0) ? v-128 : v+128) /128;
            }
          }
        }
      },debugSurface:function (surfData) {
        console.log('dumping surface ' + [surfData.surf, surfData.source, surfData.width, surfData.height]);
        var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
        var data = image.data;
        var num = Math.min(surfData.width, surfData.height);
        for (var i = 0; i < num; i++) {
          console.log('   diagonal ' + i + ':' + [data[i*surfData.width*4 + i*4 + 0], data[i*surfData.width*4 + i*4 + 1], data[i*surfData.width*4 + i*4 + 2], data[i*surfData.width*4 + i*4 + 3]]);
        }
      },joystickEventState:1,lastJoystickState:{},joystickNamePool:{},recordJoystickState:function (joystick, state) {
        // Standardize button state.
        var buttons = new Array(state.buttons.length);
        for (var i = 0; i < state.buttons.length; i++) {
          buttons[i] = SDL.getJoystickButtonState(state.buttons[i]);
        }
  
        SDL.lastJoystickState[joystick] = {
          buttons: buttons,
          axes: state.axes.slice(0),
          timestamp: state.timestamp,
          index: state.index,
          id: state.id
        };
      },getJoystickButtonState:function (button) {
        if (typeof button === 'object') {
          // Current gamepad API editor's draft (Firefox Nightly)
          // https://dvcs.w3.org/hg/gamepad/raw-file/default/gamepad.html#idl-def-GamepadButton
          return button.pressed;
        } else {
          // Current gamepad API working draft (Firefox / Chrome Stable)
          // http://www.w3.org/TR/2012/WD-gamepad-20120529/#gamepad-interface
          return button > 0;
        }
      },queryJoysticks:function () {
        for (var joystick in SDL.lastJoystickState) {
          var state = SDL.getGamepad(joystick - 1);
          var prevState = SDL.lastJoystickState[joystick];
          // Check only if the timestamp has differed.
          // NOTE: Timestamp is not available in Firefox.
          if (typeof state.timestamp !== 'number' || state.timestamp !== prevState.timestamp) {
            var i;
            for (i = 0; i < state.buttons.length; i++) {
              var buttonState = SDL.getJoystickButtonState(state.buttons[i]);
              // NOTE: The previous state already has a boolean representation of
              //       its button, so no need to standardize its button state here.
              if (buttonState !== prevState.buttons[i]) {
                // Insert button-press event.
                SDL.events.push({
                  type: buttonState ? 'joystick_button_down' : 'joystick_button_up',
                  joystick: joystick,
                  index: joystick - 1,
                  button: i
                });
              }
            }
            for (i = 0; i < state.axes.length; i++) {
              if (state.axes[i] !== prevState.axes[i]) {
                // Insert axes-change event.
                SDL.events.push({
                  type: 'joystick_axis_motion',
                  joystick: joystick,
                  index: joystick - 1,
                  axis: i,
                  value: state.axes[i]
                });
              }
            }
  
            SDL.recordJoystickState(joystick, state);
          }
        }
      },joystickAxisValueConversion:function (value) {
        // Ensures that 0 is 0, 1 is 32767, and -1 is 32768.
        return Math.ceil(((value+1) * 32767.5) - 32768);
      },getGamepads:function () {
        var fcn = navigator.getGamepads || navigator.webkitGamepads || navigator.mozGamepads || navigator.gamepads || navigator.webkitGetGamepads;
        if (fcn !== undefined) {
          // The function must be applied on the navigator object.
          return fcn.apply(navigator);
        } else {
          return [];
        }
      },getGamepad:function (deviceIndex) {
        var gamepads = SDL.getGamepads();
        if (gamepads.length > deviceIndex && deviceIndex >= 0) {
          return gamepads[deviceIndex];
        }
        return null;
      }};function _SDL_StartTextInput() {
      SDL.textInput = true;
    }

  function _sem_timedwait() {
  Module['printErr']('missing function: sem_timedwait'); abort(-1);
  }

  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        GLctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }

  function _glDrawArrays(mode, first, count) {
  
      GLctx.drawArrays(mode, first, count);
  
    }

  
  
  
  
  
  
  function _mkport() { throw 'TODO' }var SOCKFS={mount:function (mount) {
        // If Module['websocket'] has already been defined (e.g. for configuring
        // the subprotocol/url) use that, if not initialise it to a new object.
        Module['websocket'] = (Module['websocket'] && 
                               ('object' === typeof Module['websocket'])) ? Module['websocket'] : {};
  
        // Add the Event registration mechanism to the exported websocket configuration
        // object so we can register network callbacks from native JavaScript too.
        // For more documentation see system/include/emscripten/emscripten.h
        Module['websocket']._callbacks = {};
        Module['websocket']['on'] = function(event, callback) {
  	    if ('function' === typeof callback) {
  		  this._callbacks[event] = callback;
          }
  	    return this;
        };
  
        Module['websocket'].emit = function(event, param) {
  	    if ('function' === typeof this._callbacks[event]) {
  		  this._callbacks[event].call(this, param);
          }
        };
  
        // If debug is enabled register simple default logging callbacks for each Event.
  
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          error: null, // Used in getsockopt for SOL_SOCKET/SO_ERROR test
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              // runtimeConfig gets set to true if WebSocket runtime configuration is available.
              var runtimeConfig = (Module['websocket'] && ('object' === typeof Module['websocket']));
  
              // The default value is 'ws://' the replace is needed because the compiler replaces '//' comments with '#'
              // comments without checking context, so we'd end up with ws:#, the replace swaps the '#' for '//' again.
              var url = 'ws:#'.replace('#', '//');
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['url']) {
                  url = Module['websocket']['url']; // Fetch runtime WebSocket URL config.
                }
              }
  
              if (url === 'ws://' || url === 'wss://') { // Is the supplied URL config just a prefix, if so complete it.
                var parts = addr.split('/');
                url = url + parts[0] + ":" + port + "/" + parts.slice(1).join('/');
              }
  
              // Make the WebSocket subprotocol (Sec-WebSocket-Protocol) default to binary if no configuration is set.
              var subProtocols = 'binary'; // The default value is 'binary'
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['subprotocol']) {
                  subProtocols = Module['websocket']['subprotocol']; // Fetch runtime WebSocket subprotocol config.
                }
              }
  
              // The regex trims the string (removes spaces at the beginning and end, then splits the string by
              // <any space>,<any space> into an Array. Whitespace removal is important for Websockify and ws.
              subProtocols = subProtocols.replace(/^ +| +$/g,"").split(/ *, */);
  
              // The node ws library API for specifying optional subprotocol is slightly different than the browser's.
              var opts = ENVIRONMENT_IS_NODE ? {'protocol': subProtocols.toString()} : subProtocols;
  
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
  
            Module['websocket'].emit('open', sock.stream.fd);
  
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
            Module['websocket'].emit('message', sock.stream.fd);
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('close', function() {
              Module['websocket'].emit('close', sock.stream.fd);
            });
            peer.socket.on('error', function(error) {
              // Although the ws library may pass errors that may be more descriptive than
              // ECONNREFUSED they are not necessarily the expected error code e.g. 
              // ENOTFOUND on getaddrinfo seems to be node.js specific, so using ECONNREFUSED
              // is still probably the most useful thing to do.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onclose = function() {
              Module['websocket'].emit('close', sock.stream.fd);
            };
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
            peer.socket.onerror = function(error) {
              // The WebSocket spec only allows a 'simple event' to be thrown on error,
              // so we only really know as much as ECONNREFUSED.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          Module['websocket'].emit('listen', sock.stream.fd); // Send Event with listen fd.
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
              Module['websocket'].emit('connection', newsock.stream.fd);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
              Module['websocket'].emit('connection', sock.stream.fd);
            }
          });
          sock.server.on('closed', function() {
            Module['websocket'].emit('close', sock.stream.fd);
            sock.server = null;
          });
          sock.server.on('error', function(error) {
            // Although the ws library may pass errors that may be more descriptive than
            // ECONNREFUSED they are not necessarily the expected error code e.g. 
            // ENOTFOUND on getaddrinfo seems to be node.js specific, so using EHOSTUNREACH
            // is still probably the most useful thing to do. This error shouldn't
            // occur in a well written app as errors should get trapped in the compiled
            // app's own getaddrinfo call.
            sock.error = ERRNO_CODES.EHOSTUNREACH; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
            Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'EHOSTUNREACH: Host is unreachable']);
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)>>0)]=chr;
      var fd = _fileno(stream);
      var ret = _write(fd, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;

  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }

  function _emscripten_set_blur_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerFocusEventCallback(target, userData, useCapture, callbackfunc, 12, "blur");
      return 0;
    }

  function _emscripten_glReleaseShaderCompiler() {
      // NOP (as allowed by GLES 2.0 spec)
    }

  function _glClear(x0) { GLctx.clear(x0) }

  function _glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      GLctx.uniform2iv(location, value);
    }

  function _glStencilOp(x0, x1, x2) { GLctx.stencilOp(x0, x1, x2) }

  function _SDL_GetError() {
      if (!SDL.errorMessage) {
        SDL.errorMessage = allocate(intArrayFromString("unknown SDL-emscripten error"), 'i8', ALLOC_NORMAL);
      }
      return SDL.errorMessage;
    }

  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      GLctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }

  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = GLctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=result;
    }

  function _emscripten_request_pointerlock(target, deferUntilInEventHandler) {
      if (!target) target = '#canvas';
      target = JSEvents.findEventTarget(target);
      if (!target) return -4;
      if (!target.requestPointerLock && !target.mozRequestPointerLock && !target.webkitRequestPointerLock && !target.msRequestPointerLock) {
        return -1;
      }
  
      var canPerformRequests = JSEvents.canPerformEventHandlerRequests();
  
      // Queue this function call if we're not currently in an event handler and the user saw it appropriate to do so.
      if (!canPerformRequests) {
        if (deferUntilInEventHandler) {
          JSEvents.deferCall(JSEvents.requestPointerLock, 2 /* priority below fullscreen */, [target]);
          return 1;
        } else {
          return -2;
        }
      }
  
      return JSEvents.requestPointerLock(target);
    }

  function _pthread_cond_broadcast() {
      return 0;
    }

  function _gettimeofday(ptr) {
      var now = Date.now();
      HEAP32[((ptr)>>2)]=(now/1000)|0; // seconds
      HEAP32[(((ptr)+(4))>>2)]=((now % 1000)*1000)|0; // microseconds
      return 0;
    }

  function _JS_Sound_SetVolume(channelInstance, v)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	WEBAudio.audioInstances[channelInstance].gain.gain.value = v;
  }

  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = GLctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }

  
  
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  
  
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
  
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
  
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
  
      var tm_zone = HEAP32[(((tm)+(40))>>2)];
  
      var date = {
        tm_sec: HEAP32[((tm)>>2)],
        tm_min: HEAP32[(((tm)+(4))>>2)],
        tm_hour: HEAP32[(((tm)+(8))>>2)],
        tm_mday: HEAP32[(((tm)+(12))>>2)],
        tm_mon: HEAP32[(((tm)+(16))>>2)],
        tm_year: HEAP32[(((tm)+(20))>>2)],
        tm_wday: HEAP32[(((tm)+(24))>>2)],
        tm_yday: HEAP32[(((tm)+(28))>>2)],
        tm_isdst: HEAP32[(((tm)+(32))>>2)],
        tm_gmtoff: HEAP32[(((tm)+(36))>>2)],
        tm_zone: tm_zone ? Pointer_stringify(tm_zone) : ''
      };
  
      var pattern = Pointer_stringify(format);
  
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
  
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
  
      function leadingSomething(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
  
      function leadingNulls(value, digits) {
        return leadingSomething(value, digits, '0');
      };
  
      function compareByDay(date1, date2) {
        function sgn(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
  
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
  
      function getFirstWeekStartDate(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
  
      function getWeekBasedYear(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
  
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls((year/100)|0,2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
  
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
  
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
  
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
  
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ).
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich).
          var off = date.tm_gmtoff;
          var ahead = off >= 0;
          off = Math.abs(off) / 60;
          // convert from minutes into hhmm format (which means 60 minutes = 100 units)
          off = (off / 60)*100 + (off % 60);
          return (ahead ? '+' : '-') + String("0000" + off).slice(-4);
        },
        '%Z': function(date) {
          return date.tm_zone;
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
  
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
  
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }function _strftime_l(s, maxsize, format, tm) {
      return _strftime(s, maxsize, format, tm); // no locale support yet
    }

  var _ceil=Math_ceil;

  function _JS_Sound_SetPaused(channelInstance, paused)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	// This is a bad hack to fake pausing by setting the pitch to 0.0000001 (as zero is not allowed).
  	// The Web Audio API has no built-in support for pausing (which seems to be one hell of an oversight.),
  	// and other commonly suggested workarounds based on remembering start and pause times of sounds, and seeking
  	// have other issues with looping and pitch, so I chose this simpler hack instead.
  	WEBAudio.audioInstances[channelInstance].source.playbackRate.value = paused?0.0000001:1;
  }

  
  function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          writeAsciiToMemory(msg, strerrbuf);
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }

  function _emscripten_glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }

  function _catclose(catd) {
      // int catclose (nl_catd catd)
      return 0;
    }

  function _emscripten_glSampleCoverage(x0, x1) { GLctx.sampleCoverage(x0, x1) }

  function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        if (!texture) continue;
        GLctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }

  function _glDisableVertexAttribArray(index) {
      GLctx.disableVertexAttribArray(index);
    }

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 79:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: {
          if (typeof navigator === 'object') return navigator['hardwareConcurrency'] || 1;
          return 1;
        }
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  var _SItoD=true;

  var _SItoF=true;

  function _emscripten_glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _abort() {
      Module['abort']();
    }

  
  function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var fd = _fileno(stream);
      var bytesWritten = _write(fd, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return (bytesWritten / size)|0;
      }
    }
  
  
   
  Module["_strlen"] = _strlen;
  
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = (HEAP32[((tempDoublePtr)>>2)]=HEAP32[(((varargs)+(argIndex))>>2)],HEAP32[(((tempDoublePtr)+(4))>>2)]=HEAP32[(((varargs)+((argIndex)+(4)))>>2)],(+(HEAPF64[(tempDoublePtr)>>3])));
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
  
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Runtime.getNativeFieldSize(type);
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[((textIndex)>>0)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)>>0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)>>0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)>>0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)>>0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)>>0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)>>0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[((i)>>0)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }

  function _JS_Log_Dump(ptr, type)
  {
  	var str = Pointer_stringify(ptr);
  	if (typeof dump == 'function')
  		dump (str);
  	switch (type)
  	{
  		case 0: //LogType_Error
  		case 1: //LogType_Assert
  		case 4: //LogType_Exception
  			console.error (str);
  			return;
  
  		case 2: //LogType_Warning
  			console.warn (str);
  			return;
  
  		case 3: //LogType_Log
  		case 5: //LogType_Debug
  			console.log (str);
  			return;			
  
  		default:
  			console.error ("Unknown console message type!")
  			console.error (str);
  	}
  }

  var _tan=Math_tan;


  function _emscripten_glPolygonOffset(x0, x1) { GLctx.polygonOffset(x0, x1) }

  function _emscripten_glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return GLctx.isBuffer(b);
    }

  
  var PTHREAD_SPECIFIC={};function _pthread_getspecific(key) {
      return PTHREAD_SPECIFIC[key] || 0;
    }

  function _glEnable(x0) { GLctx.enable(x0) }

  var _atanf=Math_atan;

  function _emscripten_glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      GLctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }


  function _emscripten_glUniform2f(location, v0, v1) {
      location = GL.uniforms[location];
      GLctx.uniform2f(location, v0, v1);
    }

  function _glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return GLctx.getAttribLocation(program, name);
    }

  var _sin=Math_sin;

  function _emscripten_glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        GLctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }

  function ___cxa_pure_virtual() {
      ABORT = true;
      throw 'Pure virtual function called!';
    }

  var _atan=Math_atan;

  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg) {
      Module['noExitRuntime'] = true;
  
      assert(!Browser.mainLoop.scheduler, 'there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one, if you want to');
  
      Browser.mainLoop.shouldPause = Browser.mainLoop.paused = false; // if we were cancelled or paused, undo that
  
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
  
        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.
  
        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          Module.printErr('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }
  
        Browser.mainLoop.runIter(function() {
          if (typeof arg !== 'undefined') {
            Runtime.dynCall('vi', func, [arg]);
          } else {
            Runtime.dynCall('v', func);
          }
        });
  
        // Queue new audio data. This is important to be right after the main loop invocation, so that we will immediately be able
        // to queue the newest produced audio samples.
        // TODO: Consider adding pre- and post- rAF callbacks so that GL.newRenderingFrameStarted() and SDL.audio.queueNewAudioData()
        //       do not need to be hardcoded into this function, but can be more generic.
        if (typeof SDL === 'object' && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();
  
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      }
      Browser.mainLoop.scheduler();
  
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }

  function _emscripten_glDepthRange(x0, x1) { GLctx.depthRange(x0, x1) }

  function _emscripten_set_fullscreenchange_callback(target, userData, useCapture, callbackfunc) {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      if (!target) target = document;
      else {
        target = JSEvents.findEventTarget(target);
        if (!target) return -4;
      }
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "fullscreenchange");
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "mozfullscreenchange");
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "webkitfullscreenchange");
      JSEvents.registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "msfullscreenchange");
      return 0;
    }

  function _glPolygonOffset(x0, x1) { GLctx.polygonOffset(x0, x1) }

  function _clearerr(stream) {
      // void clearerr(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/clearerr.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        return;
      }
      stream.eof = false;
      stream.error = false;
    }

  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _emscripten_glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = GLctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }

  function _JS_Sound_SetListenerVelocity(x, y, z)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	WEBAudio.audioContext.listener.setVelocity(x, y, z);
  }

  var _atan2=Math_atan2;

  function _emscripten_glBindProgramARB() {
  Module['printErr']('missing function: emscripten_glBindProgramARB'); abort(-1);
  }

  function _emscripten_glBindTexture(target, texture) {
      GLctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }

  function _emscripten_glVertexAttrib3fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+12)>>2);
      GLctx.vertexAttrib3fv(index, v);
    }

  function _glFlush() { GLctx.flush() }

  function _emscripten_glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return GLctx.isFramebuffer(fb);
    }

  function _JS_Sound_SetVelocity(channelInstance, x, y, z)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	WEBAudio.audioInstances[channelInstance].panner.setVelocity(x, y, z);
  }

  function _glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=GLctx.getVertexAttribOffset(index, pname);
    }

  function _uname(name) {
      // int uname(struct utsname *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/uname.html
      var layout = {"sysname":0,"nodename":65,"domainname":325,"machine":260,"version":195,"release":130,"__size__":390};
      function copyString(element, value) {
        var offset = layout[element];
        writeAsciiToMemory(value, name + offset);
      }
      if (name === 0) {
        return -1;
      } else {
        copyString('sysname', 'Emscripten');
        copyString('nodename', 'emscripten');
        copyString('release', '1.0');
        copyString('version', '#1');
        copyString('machine', 'x86-JS');
        return 0;
      }
    }

  function _SDL_JoystickOpen(deviceIndex) {
      var gamepad = SDL.getGamepad(deviceIndex);
      if (gamepad) {
        // Use this as a unique 'pointer' for this joystick.
        var joystick = deviceIndex+1;
        SDL.recordJoystickState(joystick, gamepad);
        return joystick;
      }
      return 0;
    }

  function _emscripten_glRotatef() {
  Module['printErr']('missing function: emscripten_glRotatef'); abort(-1);
  }

  var _emscripten_check_longjmp=true;

  function _emscripten_glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = GLctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=result;
    }

  function _glBlendEquationSeparate(x0, x1) { GLctx.blendEquationSeparate(x0, x1) }


  function _emscripten_set_focus_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerFocusEventCallback(target, userData, useCapture, callbackfunc, 13, "focus");
      return 0;
    }

  function _emscripten_glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) log = '(unknown error)';
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }

  function _emscripten_set_mouseup_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerMouseEventCallback(target, userData, useCapture, callbackfunc, 6, "mouseup");
      return 0;
    }

  function _emscripten_glStencilOpSeparate(x0, x1, x2, x3) { GLctx.stencilOpSeparate(x0, x1, x2, x3) }

  function _emscripten_glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      GLctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, format, data);
    }

   
  Module["_bitshift64Ashr"] = _bitshift64Ashr;

  function _glStencilFuncSeparate(x0, x1, x2, x3) { GLctx.stencilFuncSeparate(x0, x1, x2, x3) }

  function _emscripten_glIsEnabled(x0) { return GLctx.isEnabled(x0) }

  function _glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      GLctx.uniform4iv(location, value);
    }

  function _glClearStencil(x0) { GLctx.clearStencil(x0) }

  function _JS_Sound_SetPosition(channelInstance, x, y, z)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	WEBAudio.audioInstances[channelInstance].panner.setPosition(x, y, z);
  }

  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = GLctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }

  function _emscripten_glVertexAttrib4f(x0, x1, x2, x3, x4) { GLctx.vertexAttrib4f(x0, x1, x2, x3, x4) }

  function _emscripten_glUniform2i(location, v0, v1) {
      location = GL.uniforms[location];
      GLctx.uniform2i(location, v0, v1);
    }

  function ___cxa_rethrow() {
      ___cxa_end_catch.rethrown = true;
      var ptr = EXCEPTIONS.caught.pop();
      EXCEPTIONS.last = ptr;
      throw ptr;
    }

  function _fmod(x, y) {
      return x % y;
    }

  function _emscripten_glClear(x0) { GLctx.clear(x0) }

  
  function _emscripten_get_now() {
      if (!_emscripten_get_now.actual) {
        if (ENVIRONMENT_IS_NODE) {
          _emscripten_get_now.actual = function _emscripten_get_now_actual() {
            var t = process['hrtime']();
            return t[0] * 1e3 + t[1] / 1e6;
          }
        } else if (typeof dateNow !== 'undefined') {
          _emscripten_get_now.actual = dateNow;
        } else if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
          _emscripten_get_now.actual = function _emscripten_get_now_actual() { return window['performance']['now'](); };
        } else {
          _emscripten_get_now.actual = Date.now;
        }
      }
      return _emscripten_get_now.actual();
    }
  
  function _emscripten_get_now_is_monotonic() {
      // return whether emscripten_get_now is guaranteed monotonic; the Date.now
      // implementation is not :(
      return ENVIRONMENT_IS_NODE || (typeof dateNow !== 'undefined') ||
          (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']);
    }function _clock_gettime(clk_id, tp) {
      // int clock_gettime(clockid_t clk_id, struct timespec *tp);
      var now;
      if (clk_id === 0) {
        now = Date.now();
      } else if (clk_id === 1 && _emscripten_get_now_is_monotonic()) {
        now = _emscripten_get_now();
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      HEAP32[((tp)>>2)]=(now/1000)|0; // seconds
      HEAP32[(((tp)+(4))>>2)]=((now % 1000)*1000*1000)|0; // nanoseconds
      return 0;
    }

  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        GLctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }

  function _glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=GLctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else if (pname == 0x8B87 /* GL_ACTIVE_UNIFORM_MAX_LENGTH */) {
        var ptable = GL.programInfos[program];
        if (ptable) {
          HEAP32[((p)>>2)]=ptable.maxUniformLength;
          return;
        } else if (program < GL.counter) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
        } else {
          GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        }
      } else if (pname == 0x8B8A /* GL_ACTIVE_ATTRIBUTE_MAX_LENGTH */) {
        var ptable = GL.programInfos[program];
        if (ptable) {
          if (ptable.maxAttributeLength == -1) {
            var program = GL.programs[program];
            var numAttribs = GLctx.getProgramParameter(program, GLctx.ACTIVE_ATTRIBUTES);
            ptable.maxAttributeLength = 0; // Spec says if there are no active attribs, 0 must be returned.
            for(var i = 0; i < numAttribs; ++i) {
              var activeAttrib = GLctx.getActiveAttrib(program, i);
              ptable.maxAttributeLength = Math.max(ptable.maxAttributeLength, activeAttrib.name.length+1);
            }
          }
          HEAP32[((p)>>2)]=ptable.maxAttributeLength;
          return;
        } else if (program < GL.counter) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
        } else {
          GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        }
      } else {
        HEAP32[((p)>>2)]=GLctx.getProgramParameter(GL.programs[program], pname);
      }
    }

  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      GLctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }

   
  Module["_bitshift64Shl"] = _bitshift64Shl;

  function _pthread_create() {
  Module['printErr']('missing function: pthread_create'); abort(-1);
  }

  function _emscripten_glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = GLctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }

  function _flock(fd, operation) {
      // int flock(int fd, int operation);
      // Pretend to succeed
      return 0;
    }

  function _emscripten_glFrontFace(x0) { GLctx.frontFace(x0) }

  function _emscripten_glLinkProgram(program) {
      GLctx.linkProgram(GL.programs[program]);
      GL.programInfos[program] = null; // uniforms no longer keep the same names after linking
      GL.populateUniformTable(program);
    }

  function _emscripten_glGetInfoLogARB() {
  Module['printErr']('missing function: emscripten_glGetInfoLogARB'); abort(-1);
  }

  function _pthread_key_delete(key) {
      if (key in PTHREAD_SPECIFIC) {
        delete PTHREAD_SPECIFIC[key];
        return 0;
      }
      return ERRNO_CODES.EINVAL;
    }

  function _emscripten_glDepthMask(x0) { GLctx.depthMask(x0) }

  function ___ctype_b_loc() {
      // http://refspecs.freestandards.org/LSB_3.0.0/LSB-Core-generic/LSB-Core-generic/baselib---ctype-b-loc.html
      var me = ___ctype_b_loc;
      if (!me.ret) {
        var values = [
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,2,8195,8194,8194,8194,8194,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,24577,49156,49156,49156,
          49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,55304,55304,55304,55304,55304,55304,55304,55304,
          55304,55304,49156,49156,49156,49156,49156,49156,49156,54536,54536,54536,54536,54536,54536,50440,50440,50440,50440,50440,
          50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,49156,49156,49156,49156,49156,
          49156,54792,54792,54792,54792,54792,54792,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,
          50696,50696,50696,50696,50696,50696,50696,49156,49156,49156,49156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
        ];
        var i16size = 2;
        var arr = _malloc(values.length * i16size);
        for (var i = 0; i < values.length; i++) {
          HEAP16[(((arr)+(i * i16size))>>1)]=values[i];
        }
        me.ret = allocate([arr + 128 * i16size], 'i16*', ALLOC_NORMAL);
      }
      return me.ret;
    }

  var _atan2f=Math_atan2;

  function _emscripten_glRenderbufferStorage(x0, x1, x2, x3) { GLctx.renderbufferStorage(x0, x1, x2, x3) }

  function _catgets(catd, set_id, msg_id, s) {
      // char *catgets (nl_catd catd, int set_id, int msg_id, const char *s)
      return s;
    }

  function _emscripten_glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { GLctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }

  function _ferror(stream) {
      // int ferror(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ferror.html
      stream = FS.getStreamFromPtr(stream);
      return Number(stream && stream.error);
    }

  function _getcwd(buf, size) {
      // char *getcwd(char *buf, size_t size);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getcwd.html
      if (size == 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var cwd = FS.cwd();
      if (size < cwd.length + 1) {
        ___setErrNo(ERRNO_CODES.ERANGE);
        return 0;
      } else {
        writeAsciiToMemory(cwd, buf);
        return buf;
      }
    }

  function _emscripten_glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      GLctx.texParameteri(target, pname, param);
    }

  function _llvm_trap() {
      abort('trap!');
    }

  
  function _copysign(a, b) {
      return __reallyNegative(a) === __reallyNegative(b) ? a : -a;
    }function _copysignf() {
  return _copysign.apply(null, arguments)
  }

  function _emscripten_glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return GLctx.isProgram(program);
    }

  function _emscripten_webgl_init_context_attributes(attributes) {
      HEAP32[((attributes)>>2)]=1;
      HEAP32[(((attributes)+(4))>>2)]=1;
      HEAP32[(((attributes)+(8))>>2)]=0;
      HEAP32[(((attributes)+(12))>>2)]=1;
      HEAP32[(((attributes)+(16))>>2)]=1;
      HEAP32[(((attributes)+(20))>>2)]=0;
      HEAP32[(((attributes)+(24))>>2)]=0;
      HEAP32[(((attributes)+(28))>>2)]=0;
      HEAP32[(((attributes)+(32))>>2)]=1;
      HEAP32[(((attributes)+(36))>>2)]=0;
      HEAP32[(((attributes)+(40))>>2)]=1;
    }

  function _emscripten_glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
        // Work around a bug in Chromium which causes getShaderInfoLog to return null
        if (!log) log = '(unknown error)';
        HEAP32[((p)>>2)]=log.length + 1;
      } else {
        HEAP32[((p)>>2)]=GLctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }

  function _emscripten_glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      GLctx.uniformMatrix3fv(location, transpose, view);
    }


  function _JS_Sound_Load(ptr, length)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return 0;
  
  	var sound = {
  		buffer: null, 
  		pendingsources: []
  	};
  	var instance = WEBAudio.audioInstances.push(sound) - 1;
  	WEBAudio.audioContext.decodeAudioData(
  		HEAPU8.buffer.slice(ptr, ptr+length), 
  		function(buffer) 
  		{
  			sound.buffer = buffer;
  			for (var i = 0; i < sound.pendingsources.length; i++)
  			{
  				if (sound.pendingsources[i])
  					sound.pendingsources[i].playBuffer (buffer);
  			}
  			sound.pendingsources = [];
  		}, 
  		function () 
  		{
  			console.log ("Decode error.");
  		}
      );
  	return instance;
  }

  function _emscripten_glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = GLctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }

  function _JS_Sound_Play(bufferInstance, channelInstance)
  {
  	// stop sound which is playing in the channel currently.
  	_JS_Sound_Stop (channelInstance);
  
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	var sound = WEBAudio.audioInstances[bufferInstance];
  	var channel = WEBAudio.audioInstances[channelInstance];
  	if (sound.buffer)
  		channel.playBuffer (sound.buffer);
  	else
  	{
  		// queue new sound.
  		channel.pendingSound = sound;
  		sound.pendingsources.push(channel);
  	}
  }

  function _glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
        // Work around a bug in Chromium which causes getShaderInfoLog to return null
        if (!log) log = '(unknown error)';
        HEAP32[((p)>>2)]=log.length + 1;
      } else {
        HEAP32[((p)>>2)]=GLctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }

  function _emscripten_glBlendEquationSeparate(x0, x1) { GLctx.blendEquationSeparate(x0, x1) }

  function _emscripten_glDrawRangeElements() {
  Module['printErr']('missing function: emscripten_glDrawRangeElements'); abort(-1);
  }

  function _emscripten_glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = GLctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }

  var _floorf=Math_floor;

  function _emscripten_glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveUniform(program, index);
  
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
  
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }

  function _sem_post() {
  Module['printErr']('missing function: sem_post'); abort(-1);
  }

  function _pthread_join() { throw 'TODO: ' + aborter }

  function _JS_Sound_ReleaseInstance(instance)
  {
  	WEBAudio.audioInstances[instance] = null;
  }


   
  Module["_strncpy"] = _strncpy;

  function _emscripten_glDrawArrays(mode, first, count) {
  
      GLctx.drawArrays(mode, first, count);
  
    }

  function _emscripten_glClearDepth(x0) { GLctx.clearDepth(x0) }

  function _copysignl() {
  return _copysign.apply(null, arguments)
  }

  
  function _mknod(path, mode, dev) {
      // int mknod(const char *path, mode_t mode, dev_t dev);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mknod.html
      path = Pointer_stringify(path);
      // we don't want this in the JS API as the JS API
      // uses mknod to create all nodes.
      switch (mode & 61440) {
        case 32768:
        case 8192:
        case 24576:
        case 4096:
        case 49152:
          break;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      try {
        FS.mknod(path, mode, dev);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _mkdir(path, mode) {
      // int mkdir(const char *path, mode_t mode);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mkdir.html
      path = Pointer_stringify(path);
      // remove a trailing slash, if one - /a/b/ has basename of '', but
      // we want to create b in the context of this function
      path = PATH.normalize(path);
      if (path[path.length-1] === '/') path = path.substr(0, path.length-1);
      try {
        FS.mkdir(path, mode, 0);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _emscripten_glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
  
      var arrayOffset = 0;
      // If user passed an array accessor "[index]", parse the array index off the accessor.
      if (name.indexOf(']', name.length-1) !== -1) {
        var ls = name.lastIndexOf('[');
        var arrayIndex = name.slice(ls+1, -1);
        if (arrayIndex.length > 0) {
          arrayOffset = parseInt(arrayIndex);
          if (arrayOffset < 0) {
            return -1;
          }
        }
        name = name.slice(0, ls);
      }
  
      var ptable = GL.programInfos[program];
      if (!ptable) {
        return -1;
      }
      var utable = ptable.uniforms;
      var uniformInfo = utable[name]; // returns pair [ dimension_of_uniform_array, uniform_location ]
      if (uniformInfo && arrayOffset < uniformInfo[0]) { // Check if user asked for an out-of-bounds element, i.e. for 'vec4 colors[3];' user could ask for 'colors[10]' which should return -1.
        return uniformInfo[1]+arrayOffset;
      } else {
        return -1;
      }
    }

  function _glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      GLctx.uniform3fv(location, view);
    }

  function _emscripten_glVertexAttrib4fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+16)>>2);
      GLctx.vertexAttrib4fv(index, v);
    }

  function _emscripten_glScissor(x0, x1, x2, x3) { GLctx.scissor(x0, x1, x2, x3) }

   
  Module["_bitshift64Lshr"] = _bitshift64Lshr;

   
  Module["_memset"] = _memset;

  function _JS_SystemInfo_GetDocumentURL(buffer, bufferSize) 
  	{
  		var result = document.URL;
  		result = result.slice(0, Math.max(0, bufferSize - 1));
  		if (buffer)
  			writeStringToMemory(result, buffer);
  		return document.URL.length + 1;
  	}

  function _JS_SystemInfo_GetMemory() 
  	{
  		return TOTAL_MEMORY/(1024*1024);
  	}

  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
  
      var arrayOffset = 0;
      // If user passed an array accessor "[index]", parse the array index off the accessor.
      if (name.indexOf(']', name.length-1) !== -1) {
        var ls = name.lastIndexOf('[');
        var arrayIndex = name.slice(ls+1, -1);
        if (arrayIndex.length > 0) {
          arrayOffset = parseInt(arrayIndex);
          if (arrayOffset < 0) {
            return -1;
          }
        }
        name = name.slice(0, ls);
      }
  
      var ptable = GL.programInfos[program];
      if (!ptable) {
        return -1;
      }
      var utable = ptable.uniforms;
      var uniformInfo = utable[name]; // returns pair [ dimension_of_uniform_array, uniform_location ]
      if (uniformInfo && arrayOffset < uniformInfo[0]) { // Check if user asked for an out-of-bounds element, i.e. for 'vec4 colors[3];' user could ask for 'colors[10]' which should return -1.
        return uniformInfo[1]+arrayOffset;
      } else {
        return -1;
      }
    }

  function _pthread_mutexattr_destroy() {}

  
  
   
  Module["_testSetjmp"] = _testSetjmp;function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }function _emscripten_longjmp(env, value) {
      _longjmp(env, value);
    }

  function _glGetVertexAttribiv(index, pname, params) {
      var data = GLctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }

  function _JS_FileSystem_Sync()
  {
  	if (!window.indexedDB)
  		return;
  
  	FS.syncfs(false, function (err) {
  	});
  }

  function _emscripten_glBlendEquation(x0) { GLctx.blendEquation(x0) }

  function _emscripten_glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      if (!data) {
        GLctx.bufferData(target, size, usage);
      } else {
        GLctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
      }
    }

  var _BItoD=true;

  function _emscripten_glGetShaderSource(shader, bufSize, length, source) {
      var result = GLctx.getShaderSource(GL.shaders[shader]);
      result = result.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(result, source);
      if (length) {
        HEAP32[((length)>>2)]=result.length;
      }
    }

   
  Module["_llvm_bswap_i32"] = _llvm_bswap_i32;

  function ___cxa_guard_release() {}

  var _expf=Math_exp;

  function _emscripten_glGetFloatv(name_, p) {
      return GL.get(name_, p, 'Float');
    }

  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = GLctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }

  function _emscripten_glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      GLctx.uniform3fv(location, view);
    }

  function _emscripten_glDrawElementsInstanced(mode, count, type, indices, primcount) {
      GL.currentContext.instancedArraysExt.drawElementsInstancedANGLE(mode, count, type, indices, primcount);
    }

  function _emscripten_glDrawElements(mode, count, type, indices) {
  
      GLctx.drawElements(mode, count, type, indices);
  
    }

  function _emscripten_glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = GLctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }

  function _pthread_once(ptr, func) {
      if (!_pthread_once.seen) _pthread_once.seen = {};
      if (ptr in _pthread_once.seen) return;
      Runtime.dynCall('v', func);
      _pthread_once.seen[ptr] = 1;
    }

  function _emscripten_glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      // N.b. using array notation explicitly to not confuse Closure minification.
      GLctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }

  function _emscripten_glClearColor(x0, x1, x2, x3) { GLctx.clearColor(x0, x1, x2, x3) }

  
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var fd = _fileno(stream);
      var ret = _lseek(fd, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStreamFromPtr(stream);
      stream.eof = false;
      return 0;
    }

  function _pthread_attr_destroy(attr) {
      /* int pthread_attr_destroy(pthread_attr_t *attr); */
      //FIXME: should destroy the pthread_attr_t struct
      return 0;
    }

  function _JS_SystemInfo_HasWebGL() 
  	{
  		return systemInfo.get().hasWebGL;
  	}

  function _glFinish() { GLctx.finish() }

  function _emscripten_glLoadMatrixf() {
  Module['printErr']('missing function: emscripten_glLoadMatrixf'); abort(-1);
  }

  function _glDeleteShader(shader) {
      GLctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }

  function _emscripten_glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = GLctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }

  function _emscripten_glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=GLctx.getVertexAttribOffset(index, pname);
    }

  function _glViewport(x0, x1, x2, x3) { GLctx.viewport(x0, x1, x2, x3) }

  function _catopen(name, oflag) {
      // nl_catd catopen (const char *name, int oflag)
      return -1;
    }

  function _JS_Sound_Init()
  {
  	try {
  		window.AudioContext = window.AudioContext||window.webkitAudioContext;
  		WEBAudio.audioContext = new AudioContext();
  		WEBAudio.audioWebEnabled = 1;
  	}
  	catch(e) {
  		alert('Web Audio API is not supported in this browser');
  	}
  }

  function _emscripten_glFlush() { GLctx.flush() }

  function __ZN4FMOD13DSPConnection6setMixEf() {
  Module['printErr']('missing function: _ZN4FMOD13DSPConnection6setMixEf'); abort(-1);
  }

  function _emscripten_glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = GLctx.createShader(shaderType);
      return id;
    }

  function _glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      GLctx.uniform3iv(location, value);
    }

  function _pthread_cond_init() {}

  function _emscripten_glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return GLctx.isShader(s);
    }

  
  function _JS_Cursor_SetCursorString(cursor) {
      var styleSheet = document.styleSheets[0];
      var rule = 'canvas.emscripten { border: 0px none; cursor: '+cursor+'; }';
      for (var i=0;i<styleSheet.cssRules.length;i++)
      {
        if (styleSheet.cssRules[i].cssText.indexOf ('canvas.emscripten') != -1)
        {
          styleSheet.deleteRule(i);
          styleSheet.insertRule(rule, 0);
          return;
        }
      }
      styleSheet.insertRule(rule, 0);
    }function _JS_Cursor_SetShow(show) {
      var styleSheet = document.styleSheets[0];
      var rules = styleSheet.cssRules;
      for (var i = 0; i < rules.length; i++) {
        if (rules[i].cssText.substr(0, 6) == 'canvas') {
          styleSheet.deleteRule(i);
          i--;
        }
      }
      var cursor = show?'default':'none';
      _JS_Cursor_SetCursorString(cursor);
    }

  function _glTexParameteri(x0, x1, x2) { GLctx.texParameteri(x0, x1, x2) }

  function _emscripten_glColorMask(x0, x1, x2, x3) { GLctx.colorMask(x0, x1, x2, x3) }

  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }

  var _exp=Math_exp;

  function _emscripten_glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return GLctx.isRenderbuffer(rb);
    }

  var _DtoILow=true;

  function _sem_wait() {
  Module['printErr']('missing function: sem_wait'); abort(-1);
  }

  function _glLinkProgram(program) {
      GLctx.linkProgram(GL.programs[program]);
      GL.programInfos[program] = null; // uniforms no longer keep the same names after linking
      GL.populateUniformTable(program);
    }

  function _glBindTexture(target, texture) {
      GLctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }


  function _glGetString(name_) {
      if (GL.stringCache[name_]) return GL.stringCache[name_];
      var ret; 
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          ret = allocate(intArrayFromString(GLctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F03 /* GL_EXTENSIONS */:
          var exts = GLctx.getSupportedExtensions();
          var gl_exts = [];
          for (i in exts) {
            gl_exts.push(exts[i]);
            gl_exts.push("GL_" + exts[i]);
          }
          ret = allocate(intArrayFromString(gl_exts.join(' ')), 'i8', ALLOC_NORMAL);
          break;
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          ret = allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
          break;
        default:
          GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          return 0;
      }
      GL.stringCache[name_] = ret;
      return ret;
    }

  function _emscripten_glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      GLctx.shaderSource(GL.shaders[shader], source);
    }

  function _pthread_mutex_init() {}

  function _emscripten_glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return GLctx.isTexture(texture);
    }


  function _pthread_mutex_trylock() {
      return 0;
    }

  function _glDepthFunc(x0) { GLctx.depthFunc(x0) }

  function _emscripten_glUniform4f(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      GLctx.uniform4f(location, v0, v1, v2, v3);
    }

  function _glStencilOpSeparate(x0, x1, x2, x3) { GLctx.stencilOpSeparate(x0, x1, x2, x3) }

  function _emscripten_glHint(x0, x1) { GLctx.hint(x0, x1) }

  function _SDL_NumJoysticks() {
      var count = 0;
      var gamepads = SDL.getGamepads();
      // The length is not the number of gamepads; check which ones are defined.
      for (var i = 0; i < gamepads.length; i++) {
        if (gamepads[i] !== undefined) count++;
      }
      return count;
    }

  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { GLctx.vertexAttrib4f(x0, x1, x2, x3, x4) }

  function _emscripten_glUniform4i(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      GLctx.uniform4i(location, v0, v1, v2, v3);
    }

  function _glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=GLctx.getTexParameter(target, pname);
    }

  function _emscripten_glViewport(x0, x1, x2, x3) { GLctx.viewport(x0, x1, x2, x3) }

  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;

  var _llvm_pow_f64=Math_pow;


  var _emscripten_preinvoke=true;

  function _pthread_mutexattr_init() {}

  function _glGetVertexAttribfv(index, pname, params) {
      var data = GLctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }

  function _emscripten_glUniform3f(location, v0, v1, v2) {
      location = GL.uniforms[location];
      GLctx.uniform3f(location, v0, v1, v2);
    }

  function _emscripten_glBlendFunc(x0, x1) { GLctx.blendFunc(x0, x1) }

  function _emscripten_glUniform3i(location, v0, v1, v2) {
      location = GL.uniforms[location];
      GLctx.uniform3i(location, v0, v1, v2);
    }

  function _emscripten_glStencilOp(x0, x1, x2) { GLctx.stencilOp(x0, x1, x2) }

  function _glUniform1i(location, v0) {
      location = GL.uniforms[location];
      GLctx.uniform1i(location, v0);
    }

  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveAttrib(program, index);
  
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
  
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }

  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      GLctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }

  function _glDisable(x0) { GLctx.disable(x0) }

  function _emscripten_glEnableVertexAttribArray(index) {
      GLctx.enableVertexAttribArray(index);
    }

  var _BDtoILow=true;

  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }

  function _glBindFramebuffer(target, framebuffer) {
      GLctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }

  function _emscripten_glBlendFuncSeparate(x0, x1, x2, x3) { GLctx.blendFuncSeparate(x0, x1, x2, x3) }

  function _glCullFace(x0) { GLctx.cullFace(x0) }

  function _emscripten_glColorPointer() {
  Module['printErr']('missing function: emscripten_glColorPointer'); abort(-1);
  }

  function _emscripten_glEnable(x0) { GLctx.enable(x0) }

  function _emscripten_glNormalPointer() {
  Module['printErr']('missing function: emscripten_glNormalPointer'); abort(-1);
  }

  function _emscripten_webgl_make_context_current(contextHandle) {
      var success = GL.makeContextCurrent(contextHandle);
      return success ? 0 : -5;
    }


  var _emscripten_get_longjmp_result=true;

  function _emscripten_get_pointerlock_status(pointerlockStatus) {
      if (!document.body.requestPointerLock && !document.body.mozRequestPointerLock && !document.body.webkitRequestPointerLock && !document.body.msRequestPointerLock) {
        return -1;
      }
      JSEvents.fillPointerlockChangeEventData(pointerlockStatus);  
      return 0;
    }

  
  var LOCALE={curr:0,check:function (locale) {
        if (locale) locale = Pointer_stringify(locale);
        return locale === 'C' || locale === 'POSIX' || !locale;
      }};function _freelocale(locale) {
      _free(locale);
    }

  function _glAttachShader(program, shader) {
      GLctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }

  function _emscripten_glGetVertexAttribfv(index, pname, params) {
      var data = GLctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }

  function _glDeleteProgram(program) {
      var program = GL.programs[program];
      GLctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.programInfos[program] = null;
    }

  function _emscripten_set_keyup_callback(target, userData, useCapture, callbackfunc) {
      JSEvents.registerKeyEventCallback(target, userData, useCapture, callbackfunc, 3, "keyup");
      return 0;
    }

  function _glDrawElements(mode, count, type, indices) {
  
      GLctx.drawElements(mode, count, type, indices);
  
    }

  function _emscripten_get_fullscreen_status(fullscreenStatus) {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      JSEvents.fillFullscreenChangeEventData(fullscreenStatus);
      return 0;
    }

  var _cos=Math_cos;

  function _glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      GLctx.uniform1iv(location, value);
    }

  function _emscripten_glGetVertexAttribiv(index, pname, params) {
      var data = GLctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }

  function _emscripten_glDrawArraysInstanced(mode, first, count, primcount) {
      GL.currentContext.instancedArraysExt.drawArraysInstancedANGLE(mode, first, count, primcount);
    }

  function _glGenerateMipmap(x0) { GLctx.generateMipmap(x0) }

  function _emscripten_glGetPointerv() {
  Module['printErr']('missing function: emscripten_glGetPointerv'); abort(-1);
  }


  function _emscripten_glStencilFuncSeparate(x0, x1, x2, x3) { GLctx.stencilFuncSeparate(x0, x1, x2, x3) }

   
  Module["_i64Subtract"] = _i64Subtract;

  var _fabsf=Math_abs;

   
  Module["_i64Add"] = _i64Add;

  
  function _fmax(x, y) {
      return isNaN(x) ? y : isNaN(y) ? x : Math.max(x, y);
    }function _fmaxf() {
  return _fmax.apply(null, arguments)
  }

  function _JS_Sound_Load_PCM(channels, length, sampleRate, ptr)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return 0;
  
  	var sound = {
  		buffer: WEBAudio.audioContext.createBuffer(channels, length, sampleRate), 
  		pendingsources: []
  	};
  	for (var i = 0; i < channels; i++)
  	{
  		var offs = (ptr>>2) + length * i;
  		sound.buffer.copyToChannel (HEAPF32.subarray(offs, offs + length),i, 0);
  	}
  	var instance = WEBAudio.audioInstances.push(sound) - 1;
  	return instance;
  }

  
  
  function ___resumeException(ptr) {
      if (!EXCEPTIONS.last) { EXCEPTIONS.last = ptr; }
      EXCEPTIONS.clearRef(EXCEPTIONS.deAdjust(ptr)); // exception refcount should be cleared, but don't free it
      throw ptr;
    }function ___cxa_find_matching_catch() {
      var thrown = EXCEPTIONS.last;
      if (!thrown) {
        // just pass through the null ptr
        return ((asm["setTempRet0"](0),0)|0);
      }
      var info = EXCEPTIONS.infos[thrown];
      var throwntype = info.type;
      if (!throwntype) {
        // just pass through the thrown ptr
        return ((asm["setTempRet0"](0),thrown)|0);
      }
      var typeArray = Array.prototype.slice.call(arguments);
  
      var pointer = Module['___cxa_is_pointer_type'](throwntype);
      // can_catch receives a **, add indirection
      if (!___cxa_find_matching_catch.buffer) ___cxa_find_matching_catch.buffer = _malloc(4);
      HEAP32[((___cxa_find_matching_catch.buffer)>>2)]=thrown;
      thrown = ___cxa_find_matching_catch.buffer;
      // The different catch blocks are denoted by different types.
      // Due to inheritance, those types may not precisely match the
      // type of the thrown object. Find one which matches, and
      // return the type of the catch block which should be called.
      for (var i = 0; i < typeArray.length; i++) {
        if (typeArray[i] && Module['___cxa_can_catch'](typeArray[i], throwntype, thrown)) {
          thrown = HEAP32[((thrown)>>2)]; // undo indirection
          info.adjusted = thrown;
          return ((asm["setTempRet0"](typeArray[i]),thrown)|0);
        }
      }
      // Shouldn't happen unless we have bogus data in typeArray
      // or encounter a type for which emscripten doesn't have suitable
      // typeinfo defined. Best-efforts match just in case.
      thrown = HEAP32[((thrown)>>2)]; // undo indirection
      return ((asm["setTempRet0"](throwntype),thrown)|0);
    }function ___cxa_throw(ptr, type, destructor) {
      EXCEPTIONS.infos[ptr] = {
        ptr: ptr,
        adjusted: ptr,
        type: type,
        destructor: destructor,
        refcount: 0
      };
      EXCEPTIONS.last = ptr;
      if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
        __ZSt18uncaught_exceptionv.uncaught_exception = 1;
      } else {
        __ZSt18uncaught_exceptionv.uncaught_exception++;
      }
      throw ptr;
    }

  function _glUseProgram(program) {
      GLctx.useProgram(program ? GL.programs[program] : null);
    }

  var _emscripten_landingpad=true;

  function _emscripten_glDisableVertexAttribArray(index) {
      GLctx.disableVertexAttribArray(index);
    }

  function _glBindRenderbuffer(target, renderbuffer) {
      GLctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }

  function _emscripten_glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = GLctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }

  function _emscripten_glDepthFunc(x0) { GLctx.depthFunc(x0) }

  function _gethostname(name, namelen) {
      // int gethostname(char *name, size_t namelen);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/gethostname.html
      var host = 'emscripten';
      if (typeof window !== 'undefined' && window.location.host) {
        host = window.location.host;
      }
      var length = Math.min(namelen, host.length);
      for (var i = 0; i < length; i++) {
        HEAP8[(((name)+(i))>>0)]=host.charCodeAt(i);
      }
      if (namelen > length) {
        HEAP8[(((name)+(i))>>0)]=0;
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.ENAMETOOLONG);
        return -1;
      }
    }

  
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      var fd = _fileno(stream);
      return _write(fd, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }

  function _emscripten_glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      GLctx.uniform4iv(location, value);
    }

  function _emscripten_glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }

  function _emscripten_glVertexAttribDivisor(index, divisor) {
      GL.currentContext.instancedArraysExt.vertexAttribDivisorANGLE(index, divisor);    
    }

  function _glActiveTexture(x0) { GLctx.activeTexture(x0) }

  function _glEnableVertexAttribArray(index) {
      GLctx.enableVertexAttribArray(index);
    }

  
  function _fmin(x, y) {
      return isNaN(x) ? y : isNaN(y) ? x : Math.min(x, y);
    }function _fminf() {
  return _fmin.apply(null, arguments)
  }

  function _glReadPixels(x, y, width, height, format, type, pixels) {
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: 
          GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          return;
      }
      var totalSize = width*height*sizePerPixel;
      if (type == 0x1401 /* GL_UNSIGNED_BYTE */ || type == 0x1400 /* GL_BYTE */) {
        GLctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
      } else if (type == 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */ || type == 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */
        || type == 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */ || type == 0x1403 /* GL_UNSIGNED_SHORT */ || type == 0x1402 /* GL_SHORT */) {
        GLctx.readPixels(x, y, width, height, format, type, HEAPU16.subarray(pixels >> 1, pixels + totalSize >> 1));
      } else if (type == 0x1404 /* GL_INT */ || type == 0x1405 /* GL_UNSIGNED_INT */) {
        GLctx.readPixels(x, y, width, height, format, type, HEAPU32.subarray(pixels >> 2, pixels + totalSize >> 2));
      } else if (type == 0x1406 /* GL_FLOAT */) {
        GLctx.readPixels(x, y, width, height, format, type, HEAPF32.subarray(pixels >> 2, pixels + totalSize >> 2));
      } else {
        GL.recordError(0x0500/*GL_INVALID_ENUM*/);
        return;
      }
    }

  function _emscripten_glGetRenderbufferParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=GLctx.getRenderbufferParameter(target, pname);
    }

  var _emscripten_prep_setjmp=true;

  function _glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      GLctx.uniformMatrix3fv(location, transpose, view);
    }

  var _asinf=Math_asin;

  function _SDL_GL_SwapBuffers() {
      if (Browser.doSwapBuffers) Browser.doSwapBuffers(); // in workers, this is used to send out a buffered frame
    }

  function _emscripten_webgl_create_context(target, attributes) {
      var contextAttributes = {};
      contextAttributes.alpha = !!HEAP32[((attributes)>>2)];
      contextAttributes.depth = !!HEAP32[(((attributes)+(4))>>2)];
      contextAttributes.stencil = !!HEAP32[(((attributes)+(8))>>2)];
      contextAttributes.antialias = !!HEAP32[(((attributes)+(12))>>2)];
      contextAttributes.premultipliedAlpha = !!HEAP32[(((attributes)+(16))>>2)];
      contextAttributes.preserveDrawingBuffer = !!HEAP32[(((attributes)+(20))>>2)];
      contextAttributes.preferLowPowerToHighPerformance = !!HEAP32[(((attributes)+(24))>>2)];
      contextAttributes.failIfMajorPerformanceCaveat = !!HEAP32[(((attributes)+(28))>>2)];
      var majorVersion = HEAP32[(((attributes)+(32))>>2)];
      var minorVersion = HEAP32[(((attributes)+(36))>>2)];
      var enableExtensionsByDefault = HEAP32[(((attributes)+(40))>>2)];
  
      if (!target) {
        target = Module['canvas'];
      } else {
        target = JSEvents.findEventTarget(target);
      }
      var contextHandle = GL.createContext(target, contextAttributes);
      return contextHandle;
    }

  function _emscripten_glClearStencil(x0) { GLctx.clearStencil(x0) }

  function _emscripten_glDetachShader(program, shader) {
      GLctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }

  function _JS_Sound_Stop(channelInstance)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	var channel = WEBAudio.audioInstances[channelInstance];
  
  	// cancel queued sounds.
  	if (channel.pendingSound)
  	{
  		var pendingsources = channel.pendingSound.pendingsources;
  		for (var i = 0; i < pendingsources.length; i++)
  		{
  			if (pendingsources[i] == channel)
  			{
  				pendingsources[i] = null;
  				break;
  			}
  		}
  		channel.pendingSound = null;
  	}
  
  	// stop sound currently playing.
  	if (channel.source.buffer)
  	{
  		channel.source.stop(0);
  
  		// disable callback for this channel when manually stopped.
  		channel.source.onended = function(){};
  
  		// recreate channel for future use.
  		channel.setup();
  	}
  }

  function _emscripten_glDeleteVertexArrays(n, vaos) {
      for(var i = 0; i < n; i++) {
        var id = HEAP32[(((vaos)+(i*4))>>2)];
        GL.currentContext.vaoExt.deleteVertexArrayOES(GL.vaos[id]);
        GL.vaos[id] = null;
      }
    }

  function _tanh(x) {
      return _sinh(x) / _cosh(x);
    }

  var _tanf=Math_tan;

  function _glStencilFunc(x0, x1, x2) { GLctx.stencilFunc(x0, x1, x2) }

  function _pthread_mutex_destroy() {}

  function _glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      GLctx.uniform1fv(location, view);
    }

  function _emscripten_glGenerateMipmap(x0) { GLctx.generateMipmap(x0) }

  function _emscripten_glCullFace(x0) { GLctx.cullFace(x0) }

  function _rename(old_path, new_path) {
      // int rename(const char *old, const char *new);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rename.html
      old_path = Pointer_stringify(old_path);
      new_path = Pointer_stringify(new_path);
      try {
        FS.rename(old_path, new_path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _emscripten_glUseProgram(program) {
      GLctx.useProgram(program ? GL.programs[program] : null);
    }

  
  function _log10(x) {
      return Math.log(x) / Math.LN10;
    }function _log10f() {
  return _log10.apply(null, arguments)
  }

  function _emscripten_glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      GLctx.uniform2fv(location, view);
    }

  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) log = '(unknown error)';
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }

  function _emscripten_glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      GLctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }

  var _emscripten_resume=true;

  function _emscripten_glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        GLctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }

  function _emscripten_glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      GLctx.uniform2iv(location, value);
    }

  function _emscripten_asm_const(code) {
      Runtime.getAsmConst(code, 0)();
    }

  function _emscripten_glVertexAttrib1fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+4)>>2);
      GLctx.vertexAttrib1fv(index, v);
    }

  var _fabs=Math_abs;

  
  
  
  
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)>>0)]=streamObj.ungotten.pop();
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(streamObj.fd, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return (bytesRead / size)|0;
    }function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)>>0)];
      }
    }function _getc() {
  return _fgetc.apply(null, arguments)
  }

  var _sqrt=Math_sqrt;

  var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_STATIC); 
  Module["_llvm_cttz_i32"] = _llvm_cttz_i32;

  function _emscripten_asm_const_int(code) {
      var args = Array.prototype.slice.call(arguments, 1);
      return Runtime.getAsmConst(code, args.length).apply(null, args) | 0;
    }

  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = GLctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }

  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = GLctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }

  var _ceilf=Math_ceil;

  function _emscripten_glGetBufferParameteriv(target, value, data) {
      HEAP32[((data)>>2)]=GLctx.getBufferParameter(target, value);
    }

  function _emscripten_glGetUniformiv(program, location, params) {
      var data = GLctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }

  function _pthread_cond_wait() {
      return 0;
    }

  function _emscripten_exit_fullscreen() {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      // Make sure no queued up calls will fire after this.
      JSEvents.removeDeferredCalls(JSEvents.requestFullscreen);
  
      if (document.exitFullscreen) {
        document.exitFullscreen();
      } else if (document.msExitFullscreen) {
        document.msExitFullscreen();
      } else if (document.mozCancelFullScreen) {
        document.mozCancelFullScreen();
      } else if (document.webkitExitFullscreen) {
        document.webkitExitFullscreen();
      } else {
        return -1;
      }
      return 0;
    }

  function ___ctype_tolower_loc() {
      // http://refspecs.freestandards.org/LSB_3.1.1/LSB-Core-generic/LSB-Core-generic/libutil---ctype-tolower-loc.html
      var me = ___ctype_tolower_loc;
      if (!me.ret) {
        var values = [
          128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,
          158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
          188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,
          218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,
          248,249,250,251,252,253,254,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,
          33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,97,98,99,100,101,102,103,
          104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,91,92,93,94,95,96,97,98,99,100,101,102,103,
          104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,
          134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,
          164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,
          194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,
          224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,
          254,255
        ];
        var i32size = 4;
        var arr = _malloc(values.length * i32size);
        for (var i = 0; i < values.length; i++) {
          HEAP32[(((arr)+(i * i32size))>>2)]=values[i];
        }
        me.ret = allocate([arr + 128 * i32size], 'i32*', ALLOC_NORMAL);
      }
      return me.ret;
    }

  var _emscripten_setjmp=true;

  function _emscripten_glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      GLctx.uniform1fv(location, view);
    }


  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
  
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
  
        GLctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
  
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }

  function _glScissor(x0, x1, x2, x3) { GLctx.scissor(x0, x1, x2, x3) }

  function _emscripten_glCheckFramebufferStatus(x0) { return GLctx.checkFramebufferStatus(x0) }

  function _emscripten_glDeleteProgram(program) {
      var program = GL.programs[program];
      GLctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.programInfos[program] = null;
    }

  function _emscripten_glDisable(x0) { GLctx.disable(x0) }

  function _glClearColor(x0, x1, x2, x3) { GLctx.clearColor(x0, x1, x2, x3) }

  function _emscripten_glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveAttrib(program, index);
  
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
  
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }

  function _emscripten_glLineWidth(x0) { GLctx.lineWidth(x0) }

  function _emscripten_glGetString(name_) {
      if (GL.stringCache[name_]) return GL.stringCache[name_];
      var ret; 
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          ret = allocate(intArrayFromString(GLctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F03 /* GL_EXTENSIONS */:
          var exts = GLctx.getSupportedExtensions();
          var gl_exts = [];
          for (i in exts) {
            gl_exts.push(exts[i]);
            gl_exts.push("GL_" + exts[i]);
          }
          ret = allocate(intArrayFromString(gl_exts.join(' ')), 'i8', ALLOC_NORMAL);
          break;
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          ret = allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
          break;
        default:
          GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          return 0;
      }
      GL.stringCache[name_] = ret;
      return ret;
    }

  function _emscripten_glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return GLctx.getAttribLocation(program, name);
    }


  function _emscripten_glGetIntegerv(name_, p) {
      return GL.get(name_, p, 'Integer');
    }

  
  function _emscripten_get_now_res() { // return resolution of get_now, in nanoseconds
      if (ENVIRONMENT_IS_NODE) {
        return 1; // nanoseconds
      } else if (typeof dateNow !== 'undefined' ||
                 (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now'])) {
        return 1000; // microseconds (1/1000 of a millisecond)
      } else {
        return 1000*1000; // milliseconds
      }
    }function _clock_getres(clk_id, res) {
      // int clock_getres(clockid_t clk_id, struct timespec *res);
      var nsec;
      if (clk_id === 0) {
        nsec = 1000 * 1000; // educated guess that it's milliseconds
      } else if (clk_id === 1 && _emscripten_get_now_is_monotonic()) {
        nsec = _emscripten_get_now_res();
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      HEAP32[((res)>>2)]=(nsec/1000000000)|0;
      HEAP32[(((res)+(4))>>2)]=nsec // resolution is nanoseconds
      return 0;
    }

  function _sem_destroy() {
  Module['printErr']('missing function: sem_destroy'); abort(-1);
  }

  function _JS_Sound_SetLoop(channelInstance, loop)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return;
  
  	WEBAudio.audioInstances[channelInstance].source.loop = loop;
  }

  function _emscripten_glClientActiveTexture() {
  Module['printErr']('missing function: emscripten_glClientActiveTexture'); abort(-1);
  }

  function _sem_init() {
  Module['printErr']('missing function: sem_init'); abort(-1);
  }

  function _glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      GLctx.uniform2fv(location, view);
    }

  function _emscripten_glReadPixels(x, y, width, height, format, type, pixels) {
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: 
          GL.recordError(0x0500/*GL_INVALID_ENUM*/);
          return;
      }
      var totalSize = width*height*sizePerPixel;
      if (type == 0x1401 /* GL_UNSIGNED_BYTE */ || type == 0x1400 /* GL_BYTE */) {
        GLctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
      } else if (type == 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */ || type == 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */
        || type == 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */ || type == 0x1403 /* GL_UNSIGNED_SHORT */ || type == 0x1402 /* GL_SHORT */) {
        GLctx.readPixels(x, y, width, height, format, type, HEAPU16.subarray(pixels >> 1, pixels + totalSize >> 1));
      } else if (type == 0x1404 /* GL_INT */ || type == 0x1405 /* GL_UNSIGNED_INT */) {
        GLctx.readPixels(x, y, width, height, format, type, HEAPU32.subarray(pixels >> 2, pixels + totalSize >> 2));
      } else if (type == 0x1406 /* GL_FLOAT */) {
        GLctx.readPixels(x, y, width, height, format, type, HEAPF32.subarray(pixels >> 2, pixels + totalSize >> 2));
      } else {
        GL.recordError(0x0500/*GL_INVALID_ENUM*/);
        return;
      }
    }

  function _emscripten_request_fullscreen(target, deferUntilInEventHandler) {
      if (typeof JSEvents.fullscreenEnabled() === 'undefined') return -1;
      if (!JSEvents.fullscreenEnabled()) return -3;
      if (!target) target = '#canvas';
      target = JSEvents.findEventTarget(target);
      if (!target) return -4;
  
      if (!target.requestFullscreen && !target.msRequestFullscreen && !target.mozRequestFullScreen && !target.mozRequestFullscreen && !target.webkitRequestFullscreen) {
        return -3;
      }
  
      var canPerformRequests = JSEvents.canPerformEventHandlerRequests();
  
      // Queue this function call if we're not currently in an event handler and the user saw it appropriate to do so.
      if (!canPerformRequests) {
        if (deferUntilInEventHandler) {
          JSEvents.deferCall(JSEvents.requestFullscreen, 1 /* priority over pointer lock */, [target]);
          return 1;
        } else {
          return -2;
        }
      }
  
      return JSEvents.requestFullscreen(target);
    }

  function _emscripten_glGetError() {
      // First return any GL error generated by the emscripten library_gl.js interop layer.
      if (GL.lastError) {
        var error = GL.lastError;
        GL.lastError = 0/*GL_NO_ERROR*/;
        return error;
      } else { // If there were none, return the GL error from the browser GL context.
        return GLctx.getError();
      }
    }

  function _emscripten_glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      GLctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }


  function _glClearDepthf(x0) { GLctx.clearDepth(x0) }

   
  Module["_memmove"] = _memmove;

  function ___cxa_guard_abort() {}

  
  function _calloc(n, s) {
      var ret = _malloc(n*s);
      _memset(ret, 0, n*s);
      return ret;
    }
  Module["_calloc"] = _calloc;function _newlocale(mask, locale, base) {
      if (!LOCALE.check(locale)) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      if (!base) base = _calloc(1, 4);
      return base;
    }

  function _glColorMask(x0, x1, x2, x3) { GLctx.colorMask(x0, x1, x2, x3) }

  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      GLctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, format, data);
    }

  function _emscripten_glClearDepthf(x0) { GLctx.clearDepth(x0) }

  function _JS_SystemInfo_GetHeight() 
  	{
  		return systemInfo.get().height;
  	}

  function _JS_SystemInfo_GetWidth() 
  	{
  		return systemInfo.get().width;
  	}

  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  function _emscripten_glGetUniformfv(program, location, params) {
      var data = GLctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }

  
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStreamFromPtr(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      if (!stream.currReading) {
        try {
          // load the list of entries now, then readdir will traverse that list, to ignore changes to files
          stream.currReading = FS.readdir(stream.path);
        } catch (e) {
          return FS.handleFSError(e);
        }
      }
      if (stream.position < 0 || stream.position >= stream.currReading.length) {
        HEAP32[((result)>>2)]=0;
        return 0;
      }
      var id;
      var type;
      var name = stream.currReading[stream.position++];
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        try {
          // child may have been removed since we started to read this directory
          var child = FS.lookupNode(stream.node, name);
        } catch (e) {
          // skip to the next entry (not infinite since position is incremented until currReading.length)
          return _readdir_r(dirp, entry, result);
        }
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[((entry)>>2)]=id;
      HEAP32[(((entry)+(4))>>2)]=stream.position;
      HEAP32[(((entry)+(8))>>2)]=name.length + 1;
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + 11)+(i))>>0)]=name.charCodeAt(i);
      }
      HEAP8[(((entry + 11)+(i))>>0)]=0;
      HEAP8[(((entry)+(10))>>0)]=type;
      HEAP32[((result)>>2)]=entry;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStreamFromPtr(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(268);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }

  function ___gxx_personality_v0() {
    }

  function _emscripten_exit_pointerlock() {
      // Make sure no queued up calls will fire after this.
      JSEvents.removeDeferredCalls(JSEvents.requestPointerLock);
  
      if (document.exitPointerLock) {
        document.exitPointerLock();
      } else if (document.msExitPointerLock) {
        document.msExitPointerLock();
      } else if (document.mozExitPointerLock) {
        document.mozExitPointerLock();
      } else if (document.webkitExitPointerLock) {
        document.webkitExitPointerLock();
      } else {
        return -1;
      }
      return 0;
    }

  function _SDL_JoystickNumAxes(joystick) {
      var gamepad = SDL.getGamepad(joystick - 1);
      if (gamepad) {
        return gamepad.axes.length;
      }
      return 0;
    }

  function _emscripten_glFinish() { GLctx.finish() }

  function _emscripten_glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      GLctx.uniform1iv(location, value);
    }

  
  function _exp2(x) {
      return Math.pow(2, x);
    }function _exp2f() {
  return _exp2.apply(null, arguments)
  }

  function _glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniform4fv(location, view);
    }

  function _emscripten_glTexCoordPointer() {
  Module['printErr']('missing function: emscripten_glTexCoordPointer'); abort(-1);
  }

  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }

  
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }

  function _pthread_setspecific(key, value) {
      if (!(key in PTHREAD_SPECIFIC)) {
        return ERRNO_CODES.EINVAL;
      }
      PTHREAD_SPECIFIC[key] = value;
      return 0;
    }

  function _emscripten_glVertexAttrib1f(x0, x1) { GLctx.vertexAttrib1f(x0, x1) }

  function _glCheckFramebufferStatus(x0) { return GLctx.checkFramebufferStatus(x0) }

  
  function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getUTCSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getUTCMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getUTCHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getUTCDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getUTCMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getUTCFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getUTCDay();
      HEAP32[(((tmPtr)+(36))>>2)]=0;
      HEAP32[(((tmPtr)+(32))>>2)]=0;
      var start = Date.UTC(date.getUTCFullYear(), 0, 1, 0, 0, 0, 0);
      var yday = ((date.getTime() - start) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }

  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      GLctx.bindAttribLocation(GL.programs[program], index, name);
    }

  function _emscripten_glShaderBinary() {
      GL.recordError(0x0500/*GL_INVALID_ENUM*/);
    }

  function _emscripten_glBlendColor(x0, x1, x2, x3) { GLctx.blendColor(x0, x1, x2, x3) }

  function _emscripten_glVertexAttrib2f(x0, x1, x2) { GLctx.vertexAttrib2f(x0, x1, x2) }

  function _emscripten_glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      GLctx.uniform4fv(location, view);
    }

  function _glBufferSubData(target, offset, size, data) {
      GLctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }

  var _emscripten_postinvoke=true;

  function ___cxa_call_unexpected(exception) {
      Module.printErr('Unexpected exception thrown, this is not properly supported - aborting');
      ABORT = true;
      throw exception;
    }

  function _SDL_Init(initFlags) {
      SDL.startTime = Date.now();
      SDL.initFlags = initFlags;
  
      // capture all key events. we just keep down and up, but also capture press to prevent default actions
      if (!Module['doNotCaptureKeyboard']) {
        var keyboardListeningElement = Module['keyboardListeningElement'] || document;
        keyboardListeningElement.addEventListener("keydown", SDL.receiveEvent);
        keyboardListeningElement.addEventListener("keyup", SDL.receiveEvent);
        keyboardListeningElement.addEventListener("keypress", SDL.receiveEvent);
        window.addEventListener("focus", SDL.receiveEvent);
        window.addEventListener("blur", SDL.receiveEvent);
        document.addEventListener("visibilitychange", SDL.receiveEvent);
      }
  
      if (initFlags & 0x200) {
        // SDL_INIT_JOYSTICK
        // Firefox will not give us Joystick data unless we register this NOP
        // callback.
        // https://bugzilla.mozilla.org/show_bug.cgi?id=936104
        addEventListener("gamepadconnected", function() {});
      }
  
      window.addEventListener("unload", SDL.receiveEvent);
      SDL.keyboardState = _malloc(0x10000); // Our SDL needs 512, but 64K is safe for older SDLs
      _memset(SDL.keyboardState, 0, 0x10000);
      // Initialize this structure carefully for closure
      SDL.DOMEventToSDLEvent['keydown']    = 0x300  /* SDL_KEYDOWN */;
      SDL.DOMEventToSDLEvent['keyup']      = 0x301  /* SDL_KEYUP */;
      SDL.DOMEventToSDLEvent['keypress']   = 0x303  /* SDL_TEXTINPUT */;
      SDL.DOMEventToSDLEvent['mousedown']  = 0x401  /* SDL_MOUSEBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['mouseup']    = 0x402  /* SDL_MOUSEBUTTONUP */;
      SDL.DOMEventToSDLEvent['mousemove']  = 0x400  /* SDL_MOUSEMOTION */;
      SDL.DOMEventToSDLEvent['wheel']      = 0x403  /* SDL_MOUSEWHEEL */; 
      SDL.DOMEventToSDLEvent['touchstart'] = 0x700  /* SDL_FINGERDOWN */;
      SDL.DOMEventToSDLEvent['touchend']   = 0x701  /* SDL_FINGERUP */;
      SDL.DOMEventToSDLEvent['touchmove']  = 0x702  /* SDL_FINGERMOTION */;
      SDL.DOMEventToSDLEvent['unload']     = 0x100  /* SDL_QUIT */;
      SDL.DOMEventToSDLEvent['resize']     = 0x7001 /* SDL_VIDEORESIZE/SDL_EVENT_COMPAT2 */;
      SDL.DOMEventToSDLEvent['visibilitychange'] = 0x200 /* SDL_WINDOWEVENT */;
      SDL.DOMEventToSDLEvent['focus']      = 0x200 /* SDL_WINDOWEVENT */;
      SDL.DOMEventToSDLEvent['blur']       = 0x200 /* SDL_WINDOWEVENT */;
  
      // These are not technically DOM events; the HTML gamepad API is poll-based.
      // However, we define them here, as the rest of the SDL code assumes that
      // all SDL events originate as DOM events.
      SDL.DOMEventToSDLEvent['joystick_axis_motion'] = 0x600 /* SDL_JOYAXISMOTION */;
      SDL.DOMEventToSDLEvent['joystick_button_down'] = 0x603 /* SDL_JOYBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['joystick_button_up'] = 0x604 /* SDL_JOYBUTTONUP */;
      return 0; // success
    }

   
  Module["_strcpy"] = _strcpy;

  function _emscripten_glGenVertexArrays(n, arrays) {
  
      for(var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.vaos);
        var vao = GL.currentContext.vaoExt.createVertexArrayOES();
        vao.name = id;
        GL.vaos[id] = vao;
        HEAP32[(((arrays)+(i*4))>>2)]=id;
      }
    }

  var _acos=Math_acos;

  
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[((rqtp)>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(4))>>2)];
      if (rmtp !== 0) {
        HEAP32[((rmtp)>>2)]=0;
        HEAP32[(((rmtp)+(4))>>2)]=0;
      }
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }

  
  function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[((buf)>>2)]=stat.dev;
        HEAP32[(((buf)+(4))>>2)]=0;
        HEAP32[(((buf)+(8))>>2)]=stat.ino;
        HEAP32[(((buf)+(12))>>2)]=stat.mode;
        HEAP32[(((buf)+(16))>>2)]=stat.nlink;
        HEAP32[(((buf)+(20))>>2)]=stat.uid;
        HEAP32[(((buf)+(24))>>2)]=stat.gid;
        HEAP32[(((buf)+(28))>>2)]=stat.rdev;
        HEAP32[(((buf)+(32))>>2)]=0;
        HEAP32[(((buf)+(36))>>2)]=stat.size;
        HEAP32[(((buf)+(40))>>2)]=4096;
        HEAP32[(((buf)+(44))>>2)]=stat.blocks;
        HEAP32[(((buf)+(48))>>2)]=(stat.atime.getTime() / 1000)|0;
        HEAP32[(((buf)+(52))>>2)]=0;
        HEAP32[(((buf)+(56))>>2)]=(stat.mtime.getTime() / 1000)|0;
        HEAP32[(((buf)+(60))>>2)]=0;
        HEAP32[(((buf)+(64))>>2)]=(stat.ctime.getTime() / 1000)|0;
        HEAP32[(((buf)+(68))>>2)]=0;
        HEAP32[(((buf)+(72))>>2)]=stat.ino;
        return 0;
      } catch (e) {
        if (e.node && PATH.normalize(path) !== PATH.normalize(FS.getPath(e.node))) {
          // an error occurred while trying to look up the path; we should just report ENOTDIR
          e.setErrno(ERRNO_CODES.ENOTDIR);
        }
        FS.handleFSError(e);
        return -1;
      }
    }function _lstat(path, buf) {
      // int lstat(const char *path, struct stat *buf);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/lstat.html
      return _stat(path, buf, true);
    }

  function _emscripten_glUniform1i(location, v0) {
      location = GL.uniforms[location];
      GLctx.uniform1i(location, v0);
    }

  function _emscripten_glVertexAttrib2fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+8)>>2);
      GLctx.vertexAttrib2fv(index, v);
    }

  function _setlocale(category, locale) {
      if (LOCALE.check(locale)) {
        if (!_setlocale.ret) _setlocale.ret = allocate(intArrayFromString('C'), 'i8', ALLOC_NORMAL);
        return _setlocale.ret;
      }
      return 0;
    }

  
  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }function _roundf() {
  return _round.apply(null, arguments)
  }

  function _emscripten_glDeleteObjectARB() {
  Module['printErr']('missing function: emscripten_glDeleteObjectARB'); abort(-1);
  }

  function _emscripten_glUniform1f(location, v0) {
      location = GL.uniforms[location];
      GLctx.uniform1f(location, v0);
    }

  function _emscripten_glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      GLctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }

  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      GLctx.shaderSource(GL.shaders[shader], source);
    }

  function _emscripten_glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
  
  
      GLctx.bindBuffer(target, bufferObj);
    }

  function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 512;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 1024;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var fd = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd));
    }

  var _sqrtf=Math_sqrt;

  function _emscripten_glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = GLctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }

  var _log=Math_log;

  function _SDL_PollEvent(ptr) {
      return SDL.pollEvent(ptr);
    }

  
  var PTHREAD_SPECIFIC_NEXT_KEY=1;function _pthread_key_create(key, destructor) {
      if (key == 0) {
        return ERRNO_CODES.EINVAL;
      }
      HEAP32[((key)>>2)]=PTHREAD_SPECIFIC_NEXT_KEY;
      // values start at 0
      PTHREAD_SPECIFIC[PTHREAD_SPECIFIC_NEXT_KEY] = 0;
      PTHREAD_SPECIFIC_NEXT_KEY++;
      return 0;
    }

  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
  
  
      GLctx.bindBuffer(target, bufferObj);
    }

  function _JS_Sound_Create_Channel(callback, userData)
  {
  	if (WEBAudio.audioWebEnabled == 0)
  		return; 
  
  	var channel = {
  		gain: WEBAudio.audioContext.createGain(),
  		panner: WEBAudio.audioContext.createPanner(),
  		pendingSound : null,
  		threeD: false,
  		playBuffer: function(buffer)
  		{			
  			this.source.buffer = buffer;
  			var chan = this;
  			this.source.onended = function()
  			{
  				if (callback)
  					Runtime.dynCall('vi', callback, [userData]);
  
  				// recreate channel for future use.
  				chan.setup();
  			};
  			this.source.start(0);
  		},
  		setup: function()
  		{
  			this.source = WEBAudio.audioContext.createBufferSource();
  			this.setupPanning();
  		},
  		setupPanning: function()
  		{
  			if(this.threeD)
  			{
  				this.source.disconnect();
  				this.source.connect(this.panner);
  				this.panner.connect(this.gain);		
  			}
  			else
  			{
  				this.panner.disconnect();
  				this.source.connect(this.gain);
  			}
  		}
  	};
  	channel.panner.rolloffFactor = 0; // We calculate rolloff ourselves.
  	channel.gain.connect ( WEBAudio.audioContext.destination);				
  	channel.setup();
  	return WEBAudio.audioInstances.push(channel) - 1;
  }

  function _SDL_InitSubSystem(flags) { return 0 }

  function _pthread_cond_timedwait() {
      return 0;
    }


  function _emscripten_glAttachShader(program, shader) {
      GLctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }

  function _glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      if (!data) {
        GLctx.bufferData(target, size, usage);
      } else {
        GLctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
      }
    }

  var _BDtoIHigh=true;


  function _glGetError() {
      // First return any GL error generated by the emscripten library_gl.js interop layer.
      if (GL.lastError) {
        var error = GL.lastError;
        GL.lastError = 0/*GL_NO_ERROR*/;
        return error;
      } else { // If there were none, return the GL error from the browser GL context.
        return GLctx.getError();
      }
    }

  function _emscripten_glDrawBuffers(n, bufs) {
      var bufArray = [];
      for (var i = 0; i < n; i++)
        bufArray.push(HEAP32[(((bufs)+(i*4))>>2)]);
  
      GL.currentContext.drawBuffersExt.drawBuffersWEBGL(bufArray);
    }

  function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }

  function _pthread_mutex_unlock() {}

  function _emscripten_glBindFramebuffer(target, framebuffer) {
      GLctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }

  function _emscripten_glBufferSubData(target, offset, size, data) {
      GLctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }

  function _glGetIntegerv(name_, p) {
      return GL.get(name_, p, 'Integer');
    }

  function _ungetc(c, stream) {
      // int ungetc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ungetc.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        return -1;
      }
      if (c === -1) {
        // do nothing for EOF character
        return c;
      }
      c = unSign(c & 0xFF);
      stream.ungotten.push(c);
      stream.eof = false;
      return c;
    }

  function _glFrontFace(x0) { GLctx.frontFace(x0) }

  function _uselocale(locale) {
      var old = LOCALE.curr;
      if (locale) LOCALE.curr = locale;
      return old;
    }

  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      GLctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }

  function _glStencilMask(x0) { GLctx.stencilMask(x0) }


  var _DtoIHigh=true;

  function _pthread_mutexattr_settype() {}

  function _pthread_cond_destroy() {}

  function _JS_Cursor_SetImage(ptr, length) {
      var styleSheet = document.styleSheets[0];
      var binary = ''
      for (var i = 0; i < length; i++) {
          binary += String.fromCharCode( HEAPU8[ ptr+i ] )
      }
      var base64 = btoa( binary );
      var cursor = "url(data:image/cur;base64,"+base64+"),default";
      _JS_Cursor_SetCursorString(cursor);
    }

  function _emscripten_glBindVertexArray(vao) {
  
      GL.currentContext.vaoExt.bindVertexArrayOES(GL.vaos[vao]);
    }

  var _floor=Math_floor;

  function _fmodf() {
  return _fmod.apply(null, arguments)
  }

  function ___cxa_allocate_exception(size) {
      return _malloc(size);
    }

  function _emscripten_glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=GLctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else if (pname == 0x8B87 /* GL_ACTIVE_UNIFORM_MAX_LENGTH */) {
        var ptable = GL.programInfos[program];
        if (ptable) {
          HEAP32[((p)>>2)]=ptable.maxUniformLength;
          return;
        } else if (program < GL.counter) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
        } else {
          GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        }
      } else if (pname == 0x8B8A /* GL_ACTIVE_ATTRIBUTE_MAX_LENGTH */) {
        var ptable = GL.programInfos[program];
        if (ptable) {
          if (ptable.maxAttributeLength == -1) {
            var program = GL.programs[program];
            var numAttribs = GLctx.getProgramParameter(program, GLctx.ACTIVE_ATTRIBUTES);
            ptable.maxAttributeLength = 0; // Spec says if there are no active attribs, 0 must be returned.
            for(var i = 0; i < numAttribs; ++i) {
              var activeAttrib = GLctx.getActiveAttrib(program, i);
              ptable.maxAttributeLength = Math.max(ptable.maxAttributeLength, activeAttrib.name.length+1);
            }
          }
          HEAP32[((p)>>2)]=ptable.maxAttributeLength;
          return;
        } else if (program < GL.counter) {
          GL.recordError(0x0502 /* GL_INVALID_OPERATION */);
        } else {
          GL.recordError(0x0501 /* GL_INVALID_VALUE */);
        }
      } else {
        HEAP32[((p)>>2)]=GLctx.getProgramParameter(GL.programs[program], pname);
      }
    }

  function _fmodl() {
  return _fmod.apply(null, arguments)
  }


  function _emscripten_glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      GLctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }

  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      GLctx.pixelStorei(pname, param);
    }

  function _truncate(path, length) {
      // int truncate(const char *path, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/truncate.html
      // NOTE: The path argument may be a string, to simplify ftruncate().
      if (typeof path !== 'string') path = Pointer_stringify(path);
      try {
        FS.truncate(path, length);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _emscripten_glActiveTexture(x0) { GLctx.activeTexture(x0) }

  function ___ctype_toupper_loc() {
      // http://refspecs.freestandards.org/LSB_3.1.1/LSB-Core-generic/LSB-Core-generic/libutil---ctype-toupper-loc.html
      var me = ___ctype_toupper_loc;
      if (!me.ret) {
        var values = [
          128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,
          158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
          188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,
          218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,
          248,249,250,251,252,253,254,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,
          33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,
          73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,
          81,82,83,84,85,86,87,88,89,90,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,
          145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,
          175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,
          205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,
          235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255
        ];
        var i32size = 4;
        var arr = _malloc(values.length * i32size);
        for (var i = 0; i < values.length; i++) {
          HEAP32[(((arr)+(i * i32size))>>2)]=values[i];
        }
        me.ret = allocate([arr + 128 * i32size], 'i32*', ALLOC_NORMAL);
      }
      return me.ret;
    }

  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      var fd = _fileno(dirp);
      var stream = FS.getStream(fd);
      if (stream.currReading) stream.currReading = null;
      return _close(fd);
    }

  function _readlink(path, buf, bufsize) {
      // ssize_t readlink(const char *restrict path, char *restrict buf, size_t bufsize);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/readlink.html
      path = Pointer_stringify(path);
      var str;
      try {
        str = FS.readlink(path);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      str = str.slice(0, Math.max(0, bufsize - 1));
      writeStringToMemory(str, buf, true);
      return str.length;
    }

  function _glDepthMask(x0) { GLctx.depthMask(x0) }

  function _llvm_eh_typeid_for(type) {
      return type;
    }

  function _glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count === 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      GLctx.uniformMatrix4fv(location, transpose, view);
    }

  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = GLctx.getActiveUniform(program, index);
  
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
  
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }

  function _emscripten_glValidateProgram(program) {
      GLctx.validateProgram(GL.programs[program]);
    }

  function _difftime(time1, time0) {
      return time1 - time0;
    }

  function _emscripten_webgl_get_current_context() {
      return GL.currentContext ? GL.currentContext.handle : 0;
    }

  function _emscripten_glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      GLctx.pixelStorei(pname, param);
    }

  function _emscripten_glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        if (!texture) continue;
        GLctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }

  function _time(ptr) {
      var ret = (Date.now()/1000)|0;
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  function _pthread_self() {
      //FIXME: assumes only a single thread
      return 0;
    }

  function _emscripten_glGetBooleanv(name_, p) {
      return GL.get(name_, p, 'Boolean');
    }

  function _emscripten_glCompileShader(shader) {
      GLctx.compileShader(GL.shaders[shader]);
    }



var GLctx; GL.init()
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); NODEFS.staticInit(); }
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
___buildEnvironment(ENV);
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + 5242880;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");


  var Math_min = Math.min;
function invoke_fiff(index,a1,a2,a3) {
  try {
    return Module["dynCall_fiff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifiiiiiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21) {
  try {
    Module["dynCall_vifiiiiiiiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fff(index,a1,a2) {
  try {
    return Module["dynCall_fff"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iidi(index,a1,a2,a3) {
  try {
    return Module["dynCall_iidi"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiiiiiifiiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14) {
  try {
    return Module["dynCall_fiiiiiifiiiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiifiif(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiiifiif"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiffi(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiffi"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    return Module["dynCall_iiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiffifff(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_fiffifff"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fif(index,a1,a2) {
  try {
    return Module["dynCall_fif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
  try {
    Module["dynCall_viiiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fid(index,a1,a2) {
  try {
    return Module["dynCall_fid"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ddii(index,a1,a2,a3) {
  try {
    return Module["dynCall_ddii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_di(index,a1) {
  try {
    return Module["dynCall_di"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_dd(index,a1) {
  try {
    return Module["dynCall_dd"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viff(index,a1,a2,a3) {
  try {
    Module["dynCall_viff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vffi(index,a1,a2,a3) {
  try {
    Module["dynCall_vffi"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiifiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiifiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viffff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_d(index) {
  try {
    return Module["dynCall_d"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_didd(index,a1,a2,a3) {
  try {
    return Module["dynCall_didd"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiifffiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13) {
  try {
    Module["dynCall_viiiiifffiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiifffiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    return Module["dynCall_iiiiifffiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_dii(index,a1,a2) {
  try {
    return Module["dynCall_dii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_did(index,a1,a2) {
  try {
    return Module["dynCall_did"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_dif(index,a1,a2) {
  try {
    return Module["dynCall_dif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iifii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iifii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    return Module["dynCall_iiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vdddddd(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_vdddddd"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiffiff(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_fiffiff"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiiiffffii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17) {
  try {
    return Module["dynCall_iiiiiiiiiiiiffffii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vdd(index,a1,a2) {
  try {
    Module["dynCall_vdd"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiifiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiifiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiif(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiif"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiifffiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13) {
  try {
    return Module["dynCall_iiiiiifffiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
  try {
    Module["dynCall_vifiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiifii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiifii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fifff(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_fifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viffi(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viffi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiid(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiid"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiifiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiifiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifi(index,a1,a2,a3) {
  try {
    Module["dynCall_vifi"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ddd(index,a1,a2) {
  try {
    return Module["dynCall_ddd"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_fiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iifff(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiif(index,a1,a2,a3) {
  try {
    return Module["dynCall_fiif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiifiiiiiiiiiffffi(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20) {
  try {
    return Module["dynCall_iiiiiifiiiiiiiiiffffi"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiifiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    return Module["dynCall_iiiiifiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiffffff(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiffffff"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    Module["dynCall_viiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_diii(index,a1,a2,a3) {
  try {
    return Module["dynCall_diii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_fiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiifiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19) {
  try {
    Module["dynCall_viiiiifiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiifiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    return Module["dynCall_iiiiiifiif"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iifffi(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iifffi"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vif(index,a1,a2) {
  try {
    Module["dynCall_vif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vid(index,a1,a2) {
  try {
    Module["dynCall_vid"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiidi(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiidi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiidii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiidii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiffff(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiif(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiif"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viifii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viifii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fi(index,a1) {
  try {
    return Module["dynCall_fi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viidi(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viidi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viifif(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viifif"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vf(index,a1) {
  try {
    Module["dynCall_vf"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiiiiiiiifiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14) {
  try {
    return Module["dynCall_fiiiiiiiifiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_vifiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiifiiiiiiiiiffffi(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21) {
  try {
    return Module["dynCall_iiiiiiifiiiiiiiiiffffi"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_diiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_diiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiifiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiifiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13) {
  try {
    Module["dynCall_viiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiffffii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
  try {
    return Module["dynCall_iiiiiiiiiiffffii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iid(index,a1,a2) {
  try {
    return Module["dynCall_iid"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iif(index,a1,a2) {
  try {
    return Module["dynCall_iif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_vifiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifiiiiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20) {
  try {
    Module["dynCall_vifiiiiiiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiif(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiif"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiifii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiifii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_f(index) {
  try {
    return Module["dynCall_f"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vffff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vffff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifffi(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_vifffi"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiifiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiifiiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiifi(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiifi"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viid(index,a1,a2,a3) {
  try {
    Module["dynCall_viid"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiff(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiff"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viif(index,a1,a2,a3) {
  try {
    Module["dynCall_viif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiffif(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_fiffif"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiifi(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiifi"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vd(index,a1) {
  try {
    Module["dynCall_vd"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiffffff(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiffffff"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiifiiifiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16) {
  try {
    Module["dynCall_viiiiiiiifiiifiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_fiiff(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_fiiff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiifffii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiifffii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    return Module["dynCall_iiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiff(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viifi(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viifi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiifiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    return Module["dynCall_iiiiifiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiifiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    return Module["dynCall_iiiiifiiiiif"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    Module["dynCall_viiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iifi(index,a1,a2,a3) {
  try {
    return Module["dynCall_iifi"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiif(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiif"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiifiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
  try {
    Module["dynCall_viiiiifiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiffii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiffii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vifiiiiiiiiiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21,a22,a23,a24,a25) {
  try {
    Module["dynCall_vifiiiiiiiiiiiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21,a22,a23,a24,a25);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iifiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iifiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiifi(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiifi"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viifff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viifff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiffi(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiffi"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiif(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiid(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiid"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiifi(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiifi"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viffffff(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viffffff"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
  try {
    return Module["dynCall_iiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiifiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    return Module["dynCall_iiiifiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14) {
  try {
    return Module["dynCall_iiiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiiiiiiiiiiiiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21,a22,a23,a24,a25,a26,a27,a28,a29) {
  try {
    Module["dynCall_viiiiiiiiiiiiiiiiiiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21,a22,a23,a24,a25,a26,a27,a28,a29);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viffffffffffffiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17) {
  try {
    Module["dynCall_viffffffffffffiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vfi(index,a1,a2) {
  try {
    Module["dynCall_vfi"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vff(index,a1,a2) {
  try {
    Module["dynCall_vff"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiifiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiifiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiifiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18) {
  try {
    return Module["dynCall_iiiiiifiiiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiffff(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiffff"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viffffi(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viffffi"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

  // EMSCRIPTEN_START_ASM
  var asm = (function(global, env, buffer) {
    'use asm';
    var HEAP8 = new global.Int8Array(buffer);
    var HEAP16 = new global.Int16Array(buffer);
    var HEAP32 = new global.Int32Array(buffer);
    var HEAPU8 = new global.Uint8Array(buffer);
    var HEAPU16 = new global.Uint16Array(buffer);
    var HEAPU32 = new global.Uint32Array(buffer);
    var HEAPF32 = new global.Float32Array(buffer);
    var HEAPF64 = new global.Float64Array(buffer);
  
  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var cttz_i8=env.cttz_i8|0;
  var ctlz_i8=env.ctlz_i8|0;
  var _stderr=env._stderr|0;
  var _stdin=env._stdin|0;
  var _stdout=env._stdout|0;

    var __THREW__ = 0;
    var threwValue = 0;
    var setjmpId = 0;
    var undef = 0;
    var nan = +env.NaN, inf = +env.Infinity;
    var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;
  
    var tempRet0 = 0;
    var tempRet1 = 0;
    var tempRet2 = 0;
    var tempRet3 = 0;
    var tempRet4 = 0;
    var tempRet5 = 0;
    var tempRet6 = 0;
    var tempRet7 = 0;
    var tempRet8 = 0;
    var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var Math_fround=global.Math.fround;
  var abort=env.abort;
  var assert=env.assert;
  var Math_min=env.min;
  var invoke_fiff=env.invoke_fiff;
  var invoke_iiiiiii=env.invoke_iiiiiii;
  var invoke_vifiiiiiiiiiiiiiiiiiii=env.invoke_vifiiiiiiiiiiiiiiiiiii;
  var invoke_viiiiiiiiiii=env.invoke_viiiiiiiiiii;
  var invoke_fff=env.invoke_fff;
  var invoke_iidi=env.invoke_iidi;
  var invoke_fiiiiiifiiiiiif=env.invoke_fiiiiiifiiiiiif;
  var invoke_iiiiifiif=env.invoke_iiiiifiif;
  var invoke_viiiiiffi=env.invoke_viiiiiffi;
  var invoke_iiiiiiiiiiii=env.invoke_iiiiiiiiiiii;
  var invoke_fiffifff=env.invoke_fiffifff;
  var invoke_fif=env.invoke_fif;
  var invoke_viiiiiiiiiiiiiii=env.invoke_viiiiiiiiiiiiiii;
  var invoke_fid=env.invoke_fid;
  var invoke_fii=env.invoke_fii;
  var invoke_ddii=env.invoke_ddii;
  var invoke_di=env.invoke_di;
  var invoke_dd=env.invoke_dd;
  var invoke_viff=env.invoke_viff;
  var invoke_vffi=env.invoke_vffi;
  var invoke_viiiifiii=env.invoke_viiiifiii;
  var invoke_viffff=env.invoke_viffff;
  var invoke_d=env.invoke_d;
  var invoke_didd=env.invoke_didd;
  var invoke_viiiiifffiiiii=env.invoke_viiiiifffiiiii;
  var invoke_iiiiifffiiiii=env.invoke_iiiiifffiiiii;
  var invoke_dii=env.invoke_dii;
  var invoke_did=env.invoke_did;
  var invoke_dif=env.invoke_dif;
  var invoke_iifii=env.invoke_iifii;
  var invoke_iiiiiiiiii=env.invoke_iiiiiiiiii;
  var invoke_vdddddd=env.invoke_vdddddd;
  var invoke_fiffiff=env.invoke_fiffiff;
  var invoke_iiiiiiiiiiiiffffii=env.invoke_iiiiiiiiiiiiffffii;
  var invoke_vdd=env.invoke_vdd;
  var invoke_viiifiiii=env.invoke_viiifiiii;
  var invoke_iiiif=env.invoke_iiiif;
  var invoke_iiiiiiii=env.invoke_iiiiiiii;
  var invoke_iiiiiifffiiiii=env.invoke_iiiiiifffiiiii;
  var invoke_vifiiiiiiiiiiiii=env.invoke_vifiiiiiiiiiiiii;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_iiifii=env.invoke_iiifii;
  var invoke_fifff=env.invoke_fifff;
  var invoke_viffi=env.invoke_viffi;
  var invoke_viiiiid=env.invoke_viiiiid;
  var invoke_iiiifiiii=env.invoke_iiiifiiii;
  var invoke_vifi=env.invoke_vifi;
  var invoke_vifff=env.invoke_vifff;
  var invoke_viiiiii=env.invoke_viiiiii;
  var invoke_ddd=env.invoke_ddd;
  var invoke_fiii=env.invoke_fiii;
  var invoke_iifff=env.invoke_iifff;
  var invoke_fiif=env.invoke_fiif;
  var invoke_iiiiiifiiiiiiiiiffffi=env.invoke_iiiiiifiiiiiiiiiffffi;
  var invoke_iiiiifiiiif=env.invoke_iiiiifiiiif;
  var invoke_viiffffff=env.invoke_viiffffff;
  var invoke_viiiiiiiiii=env.invoke_viiiiiiiiii;
  var invoke_diii=env.invoke_diii;
  var invoke_fiiii=env.invoke_fiiii;
  var invoke_iiiiii=env.invoke_iiiiii;
  var invoke_viiiiifiiiiiiiiiiiii=env.invoke_viiiiifiiiiiiiiiiiii;
  var invoke_viiiff=env.invoke_viiiff;
  var invoke_iiiiiifiif=env.invoke_iiiiiifiif;
  var invoke_viiii=env.invoke_viiii;
  var invoke_viiiii=env.invoke_viiiii;
  var invoke_iifffi=env.invoke_iifffi;
  var invoke_vif=env.invoke_vif;
  var invoke_vid=env.invoke_vid;
  var invoke_iiidi=env.invoke_iiidi;
  var invoke_viiidii=env.invoke_viiidii;
  var invoke_vii=env.invoke_vii;
  var invoke_iiffff=env.invoke_iiffff;
  var invoke_viiiif=env.invoke_viiiif;
  var invoke_viifii=env.invoke_viifii;
  var invoke_fi=env.invoke_fi;
  var invoke_viidi=env.invoke_viidi;
  var invoke_viifif=env.invoke_viifif;
  var invoke_vf=env.invoke_vf;
  var invoke_fiiiiiiiifiiiif=env.invoke_fiiiiiiiifiiiif;
  var invoke_vi=env.invoke_vi;
  var invoke_vifiii=env.invoke_vifiii;
  var invoke_iiiiiiifiiiiiiiiiffffi=env.invoke_iiiiiiifiiiiiiiiiffffi;
  var invoke_diiii=env.invoke_diiii;
  var invoke_iiifiiii=env.invoke_iiifiiii;
  var invoke_viiiiiiiiiiiii=env.invoke_viiiiiiiiiiiii;
  var invoke_iiiiiiiiiiffffii=env.invoke_iiiiiiiiiiffffii;
  var invoke_viiiiiiii=env.invoke_viiiiiiii;
  var invoke_iid=env.invoke_iid;
  var invoke_iif=env.invoke_iif;
  var invoke_vifiiii=env.invoke_vifiiii;
  var invoke_viiiiiii=env.invoke_viiiiiii;
  var invoke_vifiiiiiiiiiiiiiiiiii=env.invoke_vifiiiiiiiiiiiiiiiiii;
  var invoke_viiiiiiiii=env.invoke_viiiiiiiii;
  var invoke_viiiiiif=env.invoke_viiiiiif;
  var invoke_iii=env.invoke_iii;
  var invoke_iiiifii=env.invoke_iiiifii;
  var invoke_f=env.invoke_f;
  var invoke_vffff=env.invoke_vffff;
  var invoke_vifffi=env.invoke_vifffi;
  var invoke_viiiifiiiiif=env.invoke_viiiifiiiiif;
  var invoke_viii=env.invoke_viii;
  var invoke_viiiifi=env.invoke_viiiifi;
  var invoke_v=env.invoke_v;
  var invoke_viid=env.invoke_viid;
  var invoke_viiiiff=env.invoke_viiiiff;
  var invoke_viif=env.invoke_viif;
  var invoke_fiffif=env.invoke_fiffif;
  var invoke_iiiifi=env.invoke_iiiifi;
  var invoke_vd=env.invoke_vd;
  var invoke_iiffffff=env.invoke_iiffffff;
  var invoke_viiiiiiiifiiifiii=env.invoke_viiiiiiiifiiifiii;
  var invoke_fiiff=env.invoke_fiiff;
  var invoke_viiifffii=env.invoke_viiifffii;
  var invoke_iiiiiiiiiii=env.invoke_iiiiiiiiiii;
  var invoke_ii=env.invoke_ii;
  var invoke_iiff=env.invoke_iiff;
  var invoke_viifi=env.invoke_viifi;
  var invoke_iiiiifiiiiii=env.invoke_iiiiifiiiiii;
  var invoke_iiiiifiiiiif=env.invoke_iiiiifiiiiif;
  var invoke_viiff=env.invoke_viiff;
  var invoke_viiiiiiiiiiii=env.invoke_viiiiiiiiiiii;
  var invoke_iifi=env.invoke_iifi;
  var invoke_viiif=env.invoke_viiif;
  var invoke_viiiiifiiii=env.invoke_viiiiifiiii;
  var invoke_viiiffii=env.invoke_viiiffii;
  var invoke_vifiiiiiiiiiiiiiiiiiiiiiii=env.invoke_vifiiiiiiiiiiiiiiiiiiiiiii;
  var invoke_iifiiiii=env.invoke_iifiiiii;
  var invoke_iiifi=env.invoke_iiifi;
  var invoke_iiii=env.invoke_iiii;
  var invoke_viifff=env.invoke_viifff;
  var invoke_viiffi=env.invoke_viiffi;
  var invoke_iiif=env.invoke_iiif;
  var invoke_viiiiiid=env.invoke_viiiiiid;
  var invoke_viiifi=env.invoke_viiifi;
  var invoke_viffffff=env.invoke_viffffff;
  var invoke_iiiiiiiiiiiii=env.invoke_iiiiiiiiiiiii;
  var invoke_iiiifiiiii=env.invoke_iiiifiiiii;
  var invoke_iiiiiiiiiiiiiii=env.invoke_iiiiiiiiiiiiiii;
  var invoke_viiiiiiiiiiiiiiiiiiiiiiiiiiiii=env.invoke_viiiiiiiiiiiiiiiiiiiiiiiiiiiii;
  var invoke_viffffffffffffiiii=env.invoke_viffffffffffffiiii;
  var invoke_vfi=env.invoke_vfi;
  var invoke_i=env.invoke_i;
  var invoke_vff=env.invoke_vff;
  var invoke_viiifiiiii=env.invoke_viiifiiiii;
  var invoke_iiiiiifiiiiiiiiiiii=env.invoke_iiiiiifiiiiiiiiiiii;
  var invoke_viiffff=env.invoke_viiffff;
  var invoke_iiiiiiiii=env.invoke_iiiiiiiii;
  var invoke_viffffi=env.invoke_viffffi;
  var _emscripten_glGetTexParameterfv=env._emscripten_glGetTexParameterfv;
  var _log2f=env._log2f;
  var _glClearStencil=env._glClearStencil;
  var _asinf=env._asinf;
  var _emscripten_glBlendFuncSeparate=env._emscripten_glBlendFuncSeparate;
  var _emscripten_glGetIntegerv=env._emscripten_glGetIntegerv;
  var _glUniformMatrix4fv=env._glUniformMatrix4fv;
  var _glVertexAttrib4f=env._glVertexAttrib4f;
  var _emscripten_glDepthFunc=env._emscripten_glDepthFunc;
  var _emscripten_webgl_create_context=env._emscripten_webgl_create_context;
  var _pthread_key_delete=env._pthread_key_delete;
  var _glDisableVertexAttribArray=env._glDisableVertexAttribArray;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _pthread_attr_init=env._pthread_attr_init;
  var _ceilf=env._ceilf;
  var _emscripten_glUniform1f=env._emscripten_glUniform1f;
  var _Mix_PlayMusic=env._Mix_PlayMusic;
  var _emscripten_glUniform1i=env._emscripten_glUniform1i;
  var _puts=env._puts;
  var _emscripten_glIsProgram=env._emscripten_glIsProgram;
  var _ftell=env._ftell;
  var _glFramebufferRenderbuffer=env._glFramebufferRenderbuffer;
  var _gmtime_r=env._gmtime_r;
  var ___cxa_rethrow=env.___cxa_rethrow;
  var _emscripten_glTexParameteriv=env._emscripten_glTexParameteriv;
  var _catclose=env._catclose;
  var _emscripten_glAttachShader=env._emscripten_glAttachShader;
  var _emscripten_get_now_is_monotonic=env._emscripten_get_now_is_monotonic;
  var _pthread_cond_timedwait=env._pthread_cond_timedwait;
  var _emscripten_glTexParameterfv=env._emscripten_glTexParameterfv;
  var _pthread_attr_destroy=env._pthread_attr_destroy;
  var _emscripten_glUniformMatrix2fv=env._emscripten_glUniformMatrix2fv;
  var _SDL_GetTicks=env._SDL_GetTicks;
  var _emscripten_glDrawArraysInstanced=env._emscripten_glDrawArraysInstanced;
  var _JS_Sound_SetListenerVelocity=env._JS_Sound_SetListenerVelocity;
  var _glDepthMask=env._glDepthMask;
  var _strerror_r=env._strerror_r;
  var _glViewport=env._glViewport;
  var _newlocale=env._newlocale;
  var _emscripten_glFlush=env._emscripten_glFlush;
  var ___cxa_call_unexpected=env.___cxa_call_unexpected;
  var _nanosleep=env._nanosleep;
  var _pthread_once=env._pthread_once;
  var _fopen=env._fopen;
  var _JS_Sound_SetListenerOrientation=env._JS_Sound_SetListenerOrientation;
  var _emscripten_glGetAttribLocation=env._emscripten_glGetAttribLocation;
  var _stat=env._stat;
  var _glAttachShader=env._glAttachShader;
  var _emscripten_glTexCoordPointer=env._emscripten_glTexCoordPointer;
  var __addDays=env.__addDays;
  var _emscripten_glLoadMatrixf=env._emscripten_glLoadMatrixf;
  var _emscripten_glStencilFuncSeparate=env._emscripten_glStencilFuncSeparate;
  var _emscripten_glVertexAttrib3f=env._emscripten_glVertexAttrib3f;
  var _pthread_mutex_lock=env._pthread_mutex_lock;
  var ___cxa_guard_abort=env.___cxa_guard_abort;
  var _readdir_r=env._readdir_r;
  var _glCullFace=env._glCullFace;
  var _getcwd=env._getcwd;
  var _lseek=env._lseek;
  var _pthread_mutex_trylock=env._pthread_mutex_trylock;
  var _glCompressedTexImage2D=env._glCompressedTexImage2D;
  var _emscripten_glUniform1iv=env._emscripten_glUniform1iv;
  var _cosf=env._cosf;
  var _glClearColor=env._glClearColor;
  var _glFinish=env._glFinish;
  var _emscripten_glUniform3iv=env._emscripten_glUniform3iv;
  var _emscripten_glGetBufferParameteriv=env._emscripten_glGetBufferParameteriv;
  var _emscripten_glVertexAttrib4fv=env._emscripten_glVertexAttrib4fv;
  var _glGetTexParameteriv=env._glGetTexParameteriv;
  var _pthread_getspecific=env._pthread_getspecific;
  var _glDrawArrays=env._glDrawArrays;
  var _glCreateShader=env._glCreateShader;
  var _glGetError=env._glGetError;
  var _emscripten_glDepthRange=env._emscripten_glDepthRange;
  var _floorf=env._floorf;
  var _sqrtf=env._sqrtf;
  var _glActiveTexture=env._glActiveTexture;
  var _SDL_NumJoysticks=env._SDL_NumJoysticks;
  var _emscripten_glCopyTexSubImage2D=env._emscripten_glCopyTexSubImage2D;
  var _emscripten_glCopyTexImage2D=env._emscripten_glCopyTexImage2D;
  var _emscripten_glFramebufferTexture2D=env._emscripten_glFramebufferTexture2D;
  var _glEnableVertexAttribArray=env._glEnableVertexAttribArray;
  var _emscripten_glStencilFunc=env._emscripten_glStencilFunc;
  var _glDeleteBuffers=env._glDeleteBuffers;
  var _localtime=env._localtime;
  var _sin=env._sin;
  var _glCompressedTexSubImage2D=env._glCompressedTexSubImage2D;
  var _emscripten_glRenderbufferStorage=env._emscripten_glRenderbufferStorage;
  var _emscripten_glVertexPointer=env._emscripten_glVertexPointer;
  var _fmin=env._fmin;
  var _JS_SystemInfo_GetHeight=env._JS_SystemInfo_GetHeight;
  var _glGetVertexAttribPointerv=env._glGetVertexAttribPointerv;
  var _glLinkProgram=env._glLinkProgram;
  var _emscripten_glGetUniformfv=env._emscripten_glGetUniformfv;
  var _SDL_FreeRW=env._SDL_FreeRW;
  var _log10=env._log10;
  var _fileno=env._fileno;
  var _Mix_LoadWAV_RW=env._Mix_LoadWAV_RW;
  var _emscripten_glStencilOp=env._emscripten_glStencilOp;
  var _emscripten_glBlendEquation=env._emscripten_glBlendEquation;
  var ___ctype_tolower_loc=env.___ctype_tolower_loc;
  var _pthread_self=env._pthread_self;
  var _emscripten_glVertexAttrib1fv=env._emscripten_glVertexAttrib1fv;
  var _emscripten_glBufferSubData=env._emscripten_glBufferSubData;
  var _emscripten_glGetProgramInfoLog=env._emscripten_glGetProgramInfoLog;
  var _emscripten_glUniform4fv=env._emscripten_glUniform4fv;
  var _fgetc=env._fgetc;
  var ___cxa_throw=env.___cxa_throw;
  var _glUniform1iv=env._glUniform1iv;
  var _emscripten_glUniform2fv=env._emscripten_glUniform2fv;
  var _emscripten_glBindBuffer=env._emscripten_glBindBuffer;
  var _emscripten_glGetFloatv=env._emscripten_glGetFloatv;
  var _pthread_mutex_init=env._pthread_mutex_init;
  var _glBlendEquationSeparate=env._glBlendEquationSeparate;
  var _glTexSubImage2D=env._glTexSubImage2D;
  var _glUseProgram=env._glUseProgram;
  var _glUniformMatrix3fv=env._glUniformMatrix3fv;
  var _exp=env._exp;
  var _SDL_StartTextInput=env._SDL_StartTextInput;
  var _emscripten_glCullFace=env._emscripten_glCullFace;
  var _emscripten_glStencilMaskSeparate=env._emscripten_glStencilMaskSeparate;
  var _emscripten_glUniform3fv=env._emscripten_glUniform3fv;
  var _glBindBuffer=env._glBindBuffer;
  var _emscripten_request_fullscreen=env._emscripten_request_fullscreen;
  var _emscripten_webgl_make_context_current=env._emscripten_webgl_make_context_current;
  var _JS_Sound_Play=env._JS_Sound_Play;
  var _rename=env._rename;
  var _emscripten_glDisableVertexAttribArray=env._emscripten_glDisableVertexAttribArray;
  var _TTF_RenderText_Solid=env._TTF_RenderText_Solid;
  var _glPolygonOffset=env._glPolygonOffset;
  var _emscripten_webgl_get_current_context=env._emscripten_webgl_get_current_context;
  var _clock=env._clock;
  var _SDL_InitSubSystem=env._SDL_InitSubSystem;
  var _JS_Sound_SetListenerPosition=env._JS_Sound_SetListenerPosition;
  var _emscripten_glGetBooleanv=env._emscripten_glGetBooleanv;
  var _emscripten_glVertexAttribDivisor=env._emscripten_glVertexAttribDivisor;
  var _readdir=env._readdir;
  var _tanh=env._tanh;
  var _emscripten_glGenBuffers=env._emscripten_glGenBuffers;
  var _emscripten_glDeleteObjectARB=env._emscripten_glDeleteObjectARB;
  var _emscripten_glUniform4f=env._emscripten_glUniform4f;
  var _emscripten_glGetShaderPrecisionFormat=env._emscripten_glGetShaderPrecisionFormat;
  var _write=env._write;
  var _fsync=env._fsync;
  var _emscripten_glIsEnabled=env._emscripten_glIsEnabled;
  var _SDL_JoystickOpen=env._SDL_JoystickOpen;
  var _JS_SystemInfo_HasFullscreen=env._JS_SystemInfo_HasFullscreen;
  var _pthread_cond_destroy=env._pthread_cond_destroy;
  var _JS_Sound_Set3D=env._JS_Sound_Set3D;
  var _emscripten_glGetActiveAttrib=env._emscripten_glGetActiveAttrib;
  var _glGenerateMipmap=env._glGenerateMipmap;
  var _JS_Sound_SetPosition=env._JS_Sound_SetPosition;
  var _uselocale=env._uselocale;
  var _truncf=env._truncf;
  var _log2=env._log2;
  var _setlocale=env._setlocale;
  var ___cxa_free_exception=env.___cxa_free_exception;
  var _atan2f=env._atan2f;
  var ___cxa_find_matching_catch=env.___cxa_find_matching_catch;
  var _JS_SystemInfo_HasCursorLock=env._JS_SystemInfo_HasCursorLock;
  var _emscripten_glClear=env._emscripten_glClear;
  var _glDrawElements=env._glDrawElements;
  var ___cxa_guard_release=env.___cxa_guard_release;
  var _glBufferSubData=env._glBufferSubData;
  var _emscripten_glValidateProgram=env._emscripten_glValidateProgram;
  var _emscripten_glUniform4iv=env._emscripten_glUniform4iv;
  var ___setErrNo=env.___setErrNo;
  var _glStencilOpSeparate=env._glStencilOpSeparate;
  var _emscripten_glVertexAttrib2f=env._emscripten_glVertexAttrib2f;
  var ___resumeException=env.___resumeException;
  var _asin=env._asin;
  var _mktime=env._mktime;
  var _emscripten_glGetError=env._emscripten_glGetError;
  var _putchar=env._putchar;
  var _emscripten_glBufferData=env._emscripten_glBufferData;
  var _glBlendFuncSeparate=env._glBlendFuncSeparate;
  var _glGenTextures=env._glGenTextures;
  var _glGetIntegerv=env._glGetIntegerv;
  var _glUniform3iv=env._glUniform3iv;
  var _emscripten_glClearStencil=env._emscripten_glClearStencil;
  var _JS_Sound_Stop=env._JS_Sound_Stop;
  var _emscripten_set_mouseup_callback=env._emscripten_set_mouseup_callback;
  var _emscripten_glFinish=env._emscripten_glFinish;
  var _emscripten_glClearDepth=env._emscripten_glClearDepth;
  var _emscripten_glUniform1fv=env._emscripten_glUniform1fv;
  var _fwrite=env._fwrite;
  var _glBindFramebuffer=env._glBindFramebuffer;
  var _emscripten_glStencilOpSeparate=env._emscripten_glStencilOpSeparate;
  var _glGenFramebuffers=env._glGenFramebuffers;
  var _SDL_UpperBlitScaled=env._SDL_UpperBlitScaled;
  var _emscripten_glGetActiveUniform=env._emscripten_glGetActiveUniform;
  var _emscripten_glUniform4i=env._emscripten_glUniform4i;
  var _glUniform1fv=env._glUniform1fv;
  var _llvm_pow_f64=env._llvm_pow_f64;
  var _trunc=env._trunc;
  var _glDeleteFramebuffers=env._glDeleteFramebuffers;
  var _JS_FileSystem_Sync=env._JS_FileSystem_Sync;
  var _IMG_Load=env._IMG_Load;
  var _glCheckFramebufferStatus=env._glCheckFramebufferStatus;
  var _vfprintf=env._vfprintf;
  var ___ctype_b_loc=env.___ctype_b_loc;
  var _emscripten_glBlendFunc=env._emscripten_glBlendFunc;
  var _floor=env._floor;
  var _emscripten_glStencilMask=env._emscripten_glStencilMask;
  var _modff=env._modff;
  var _localtime_r=env._localtime_r;
  var _glBindTexture=env._glBindTexture;
  var _fabsf=env._fabsf;
  var _readlink=env._readlink;
  var _strftime=env._strftime;
  var _sem_wait=env._sem_wait;
  var _emscripten_glGetVertexAttribiv=env._emscripten_glGetVertexAttribiv;
  var _glReadPixels=env._glReadPixels;
  var _fseek=env._fseek;
  var _glGetActiveAttrib=env._glGetActiveAttrib;
  var _emscripten_glUniformMatrix3fv=env._emscripten_glUniformMatrix3fv;
  var _glUniform2iv=env._glUniform2iv;
  var _pthread_key_create=env._pthread_key_create;
  var _emscripten_glDeleteFramebuffers=env._emscripten_glDeleteFramebuffers;
  var _recv=env._recv;
  var _glFrontFace=env._glFrontFace;
  var _emscripten_glGetObjectParameterivARB=env._emscripten_glGetObjectParameterivARB;
  var _JS_SystemInfo_HasWebGL=env._JS_SystemInfo_HasWebGL;
  var _emscripten_glGetUniformiv=env._emscripten_glGetUniformiv;
  var _ceil=env._ceil;
  var _exp2f=env._exp2f;
  var _emscripten_glVertexAttrib2fv=env._emscripten_glVertexAttrib2fv;
  var _copysignl=env._copysignl;
  var _glGetProgramiv=env._glGetProgramiv;
  var _glScissor=env._glScissor;
  var _glGetFramebufferAttachmentParameteriv=env._glGetFramebufferAttachmentParameteriv;
  var _fabs=env._fabs;
  var _difftime=env._difftime;
  var _emscripten_glTexSubImage2D=env._emscripten_glTexSubImage2D;
  var _ungetc=env._ungetc;
  var _emscripten_glDeleteTextures=env._emscripten_glDeleteTextures;
  var _fflush=env._fflush;
  var _emscripten_exit_fullscreen=env._emscripten_exit_fullscreen;
  var _strftime_l=env._strftime_l;
  var _glGetShaderiv=env._glGetShaderiv;
  var _llvm_eh_typeid_for=env._llvm_eh_typeid_for;
  var _SDL_PollEvent=env._SDL_PollEvent;
  var _catgets=env._catgets;
  var _glUniform4fv=env._glUniform4fv;
  var _glRenderbufferStorage=env._glRenderbufferStorage;
  var _sem_post=env._sem_post;
  var _IMG_Load_RW=env._IMG_Load_RW;
  var _glBindAttribLocation=env._glBindAttribLocation;
  var _emscripten_glColorMask=env._emscripten_glColorMask;
  var _emscripten_webgl_destroy_context=env._emscripten_webgl_destroy_context;
  var _pthread_mutex_unlock=env._pthread_mutex_unlock;
  var _emscripten_glBindTexture=env._emscripten_glBindTexture;
  var _glFramebufferTexture2D=env._glFramebufferTexture2D;
  var _glUniform4iv=env._glUniform4iv;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var ___errno_location=env.___errno_location;
  var _emscripten_glIsShader=env._emscripten_glIsShader;
  var _copysign=env._copysign;
  var _fputc=env._fputc;
  var _emscripten_glCompressedTexImage2D=env._emscripten_glCompressedTexImage2D;
  var _glDisable=env._glDisable;
  var _emscripten_glGetInfoLogARB=env._emscripten_glGetInfoLogARB;
  var _emscripten_longjmp=env._emscripten_longjmp;
  var __formatString=env.__formatString;
  var _atexit=env._atexit;
  var _glStencilFuncSeparate=env._glStencilFuncSeparate;
  var _JS_Sound_ReleaseInstance=env._JS_Sound_ReleaseInstance;
  var _emscripten_glGenRenderbuffers=env._emscripten_glGenRenderbuffers;
  var _emscripten_glReleaseShaderCompiler=env._emscripten_glReleaseShaderCompiler;
  var _glStencilFunc=env._glStencilFunc;
  var __ZN4FMOD13DSPConnection6setMixEf=env.__ZN4FMOD13DSPConnection6setMixEf;
  var _flock=env._flock;
  var ___cxa_guard_acquire=env.___cxa_guard_acquire;
  var _SDL_RWFromFile=env._SDL_RWFromFile;
  var _glUniform2fv=env._glUniform2fv;
  var _emscripten_glFrontFace=env._emscripten_glFrontFace;
  var _truncate=env._truncate;
  var _glDeleteProgram=env._glDeleteProgram;
  var __ZSt18uncaught_exceptionv=env.__ZSt18uncaught_exceptionv;
  var _emscripten_glUseProgram=env._emscripten_glUseProgram;
  var ___ctype_toupper_loc=env.___ctype_toupper_loc;
  var _glCreateProgram=env._glCreateProgram;
  var _clock_gettime=env._clock_gettime;
  var _SDL_GetError=env._SDL_GetError;
  var _uname=env._uname;
  var _glGetAttribLocation=env._glGetAttribLocation;
  var _Mix_PlayChannel=env._Mix_PlayChannel;
  var _sinf=env._sinf;
  var _sinh=env._sinh;
  var _sysconf=env._sysconf;
  var __reallyNegative=env.__reallyNegative;
  var _ferror=env._ferror;
  var _emscripten_glLineWidth=env._emscripten_glLineWidth;
  var _pthread_mutexattr_settype=env._pthread_mutexattr_settype;
  var _tan=env._tan;
  var _glGenBuffers=env._glGenBuffers;
  var _glShaderSource=env._glShaderSource;
  var _round=env._round;
  var _emscripten_glScissor=env._emscripten_glScissor;
  var _glGetVertexAttribfv=env._glGetVertexAttribfv;
  var _mkdir=env._mkdir;
  var _closedir=env._closedir;
  var _llvm_trap=env._llvm_trap;
  var _JS_Sound_SetVolume=env._JS_Sound_SetVolume;
  var _JS_Cursor_SetShow=env._JS_Cursor_SetShow;
  var _emscripten_glIsBuffer=env._emscripten_glIsBuffer;
  var _emscripten_glVertexAttrib1f=env._emscripten_glVertexAttrib1f;
  var _emscripten_set_keyup_callback=env._emscripten_set_keyup_callback;
  var _emscripten_glCompressedTexSubImage2D=env._emscripten_glCompressedTexSubImage2D;
  var _glGetVertexAttribiv=env._glGetVertexAttribiv;
  var _JS_Log_Dump=env._JS_Log_Dump;
  var _emscripten_glGetAttachedShaders=env._emscripten_glGetAttachedShaders;
  var _emscripten_glGenTextures=env._emscripten_glGenTextures;
  var _JS_Cursor_SetCursorString=env._JS_Cursor_SetCursorString;
  var _glBindRenderbuffer=env._glBindRenderbuffer;
  var _pthread_cond_init=env._pthread_cond_init;
  var _SDL_LockSurface=env._SDL_LockSurface;
  var _gmtime=env._gmtime;
  var _emscripten_glGetTexParameteriv=env._emscripten_glGetTexParameteriv;
  var _glDeleteTextures=env._glDeleteTextures;
  var _emscripten_glClientActiveTexture=env._emscripten_glClientActiveTexture;
  var _emscripten_glPolygonOffset=env._emscripten_glPolygonOffset;
  var _emscripten_glCheckFramebufferStatus=env._emscripten_glCheckFramebufferStatus;
  var _abs=env._abs;
  var _emscripten_glUniform3f=env._emscripten_glUniform3f;
  var _emscripten_glUniform3i=env._emscripten_glUniform3i;
  var _emscripten_glDeleteShader=env._emscripten_glDeleteShader;
  var _glEnable=env._glEnable;
  var _glGetString=env._glGetString;
  var _emscripten_glGetUniformLocation=env._emscripten_glGetUniformLocation;
  var _emscripten_glEnableVertexAttribArray=env._emscripten_glEnableVertexAttribArray;
  var _emscripten_get_now=env._emscripten_get_now;
  var _fprintf=env._fprintf;
  var _gettimeofday=env._gettimeofday;
  var _catopen=env._catopen;
  var _emscripten_glEnableClientState=env._emscripten_glEnableClientState;
  var _pthread_join=env._pthread_join;
  var _fmod=env._fmod;
  var _JS_Sound_Init=env._JS_Sound_Init;
  var _emscripten_glReadPixels=env._emscripten_glReadPixels;
  var _emscripten_glDrawElements=env._emscripten_glDrawElements;
  var ___buildEnvironment=env.___buildEnvironment;
  var _glClearDepthf=env._glClearDepthf;
  var _tzset=env._tzset;
  var _emscripten_asm_const=env._emscripten_asm_const;
  var _SDL_Init=env._SDL_Init;
  var _emscripten_glDisable=env._emscripten_glDisable;
  var ___cxa_end_catch=env.___cxa_end_catch;
  var _emscripten_glDeleteRenderbuffers=env._emscripten_glDeleteRenderbuffers;
  var _emscripten_glDrawElementsInstanced=env._emscripten_glDrawElementsInstanced;
  var _emscripten_glVertexAttrib4f=env._emscripten_glVertexAttrib4f;
  var _JS_Sound_Create_Channel=env._JS_Sound_Create_Channel;
  var _emscripten_glPixelStorei=env._emscripten_glPixelStorei;
  var _emscripten_webgl_init_context_attributes=env._emscripten_webgl_init_context_attributes;
  var _fclose=env._fclose;
  var _log=env._log;
  var _emscripten_glFramebufferRenderbuffer=env._emscripten_glFramebufferRenderbuffer;
  var _fminf=env._fminf;
  var _glBufferData=env._glBufferData;
  var _JS_Sound_SetPaused=env._JS_Sound_SetPaused;
  var _emscripten_glRotatef=env._emscripten_glRotatef;
  var _emscripten_glGetShaderiv=env._emscripten_glGetShaderiv;
  var ___cxa_pure_virtual=env.___cxa_pure_virtual;
  var _emscripten_glUniformMatrix4fv=env._emscripten_glUniformMatrix4fv;
  var _emscripten_glGetPointerv=env._emscripten_glGetPointerv;
  var _pthread_cond_wait=env._pthread_cond_wait;
  var _emscripten_set_blur_callback=env._emscripten_set_blur_callback;
  var _acosf=env._acosf;
  var _acos=env._acos;
  var _cosh=env._cosh;
  var _emscripten_glIsRenderbuffer=env._emscripten_glIsRenderbuffer;
  var _emscripten_request_pointerlock=env._emscripten_request_pointerlock;
  var _tanf=env._tanf;
  var _glDeleteRenderbuffers=env._glDeleteRenderbuffers;
  var _JS_SystemInfo_GetMemory=env._JS_SystemInfo_GetMemory;
  var _JS_Sound_SetLoop=env._JS_Sound_SetLoop;
  var _emscripten_set_focus_callback=env._emscripten_set_focus_callback;
  var _pthread_mutexattr_destroy=env._pthread_mutexattr_destroy;
  var _emscripten_glGetVertexAttribfv=env._emscripten_glGetVertexAttribfv;
  var _SDL_PauseAudio=env._SDL_PauseAudio;
  var _emscripten_glVertexAttrib3fv=env._emscripten_glVertexAttrib3fv;
  var _glGetUniformLocation=env._glGetUniformLocation;
  var _emscripten_glCompileShader=env._emscripten_glCompileShader;
  var _glClear=env._glClear;
  var __arraySum=env.__arraySum;
  var _emscripten_glLinkProgram=env._emscripten_glLinkProgram;
  var _atan=env._atan;
  var _pread=env._pread;
  var _mkport=env._mkport;
  var _emscripten_get_pointerlock_status=env._emscripten_get_pointerlock_status;
  var _emscripten_glDrawRangeElements=env._emscripten_glDrawRangeElements;
  var _getc=env._getc;
  var _pthread_create=env._pthread_create;
  var _copysignf=env._copysignf;
  var _pthread_setspecific=env._pthread_setspecific;
  var _rmdir=env._rmdir;
  var _glColorMask=env._glColorMask;
  var _emscripten_glClearColor=env._emscripten_glClearColor;
  var _glCopyTexSubImage2D=env._glCopyTexSubImage2D;
  var _emscripten_glCreateProgram=env._emscripten_glCreateProgram;
  var _glTexParameteri=env._glTexParameteri;
  var _emscripten_glDetachShader=env._emscripten_glDetachShader;
  var _SDL_RWFromConstMem=env._SDL_RWFromConstMem;
  var _emscripten_set_fullscreenchange_callback=env._emscripten_set_fullscreenchange_callback;
  var _emscripten_glVertexAttribPointer=env._emscripten_glVertexAttribPointer;
  var _fmodl=env._fmodl;
  var _fread=env._fread;
  var _emscripten_glDrawArrays=env._emscripten_glDrawArrays;
  var _fmodf=env._fmodf;
  var _longjmp=env._longjmp;
  var _emscripten_glBlendColor=env._emscripten_glBlendColor;
  var _emscripten_get_now_res=env._emscripten_get_now_res;
  var _glGetShaderInfoLog=env._glGetShaderInfoLog;
  var _clock_getres=env._clock_getres;
  var _sbrk=env._sbrk;
  var ___cxa_begin_catch=env.___cxa_begin_catch;
  var _emscripten_glGetProgramiv=env._emscripten_glGetProgramiv;
  var _exp2=env._exp2;
  var _close=env._close;
  var _glStencilOp=env._glStencilOp;
  var _emscripten_glGetShaderSource=env._emscripten_glGetShaderSource;
  var _cos=env._cos;
  var _sem_timedwait=env._sem_timedwait;
  var _expf=env._expf;
  var _emscripten_glTexImage2D=env._emscripten_glTexImage2D;
  var __isLeapYear=env.__isLeapYear;
  var _emscripten_glBlendEquationSeparate=env._emscripten_glBlendEquationSeparate;
  var _emscripten_glGetString=env._emscripten_glGetString;
  var _emscripten_glIsFramebuffer=env._emscripten_glIsFramebuffer;
  var __exit=env.__exit;
  var _JS_Eval_EvalJS=env._JS_Eval_EvalJS;
  var _emscripten_glBindProgramARB=env._emscripten_glBindProgramARB;
  var _mknod=env._mknod;
  var _gethostname=env._gethostname;
  var _emscripten_glUniform2i=env._emscripten_glUniform2i;
  var _send=env._send;
  var _JS_SystemInfo_GetWidth=env._JS_SystemInfo_GetWidth;
  var _atan2=env._atan2;
  var _glGetProgramInfoLog=env._glGetProgramInfoLog;
  var _emscripten_glTexParameterf=env._emscripten_glTexParameterf;
  var _emscripten_glTexParameteri=env._emscripten_glTexParameteri;
  var _JS_Sound_Load=env._JS_Sound_Load;
  var _sem_init=env._sem_init;
  var _JS_Sound_Load_PCM=env._JS_Sound_Load_PCM;
  var _emscripten_glGenVertexArrays=env._emscripten_glGenVertexArrays;
  var _JS_SystemInfo_GetDocumentURL=env._JS_SystemInfo_GetDocumentURL;
  var _Mix_HaltMusic=env._Mix_HaltMusic;
  var _emscripten_glBindAttribLocation=env._emscripten_glBindAttribLocation;
  var _llvm_pow_f32=env._llvm_pow_f32;
  var _glDepthFunc=env._glDepthFunc;
  var ___cxa_allocate_exception=env.___cxa_allocate_exception;
  var _emscripten_set_canvas_size=env._emscripten_set_canvas_size;
  var _unlink=env._unlink;
  var _freelocale=env._freelocale;
  var _emscripten_glClearDepthf=env._emscripten_glClearDepthf;
  var _atanf=env._atanf;
  var _printf=env._printf;
  var _emscripten_glMatrixMode=env._emscripten_glMatrixMode;
  var _fmaxf=env._fmaxf;
  var _emscripten_glNormalPointer=env._emscripten_glNormalPointer;
  var _emscripten_glHint=env._emscripten_glHint;
  var _emscripten_glEnable=env._emscripten_glEnable;
  var _read=env._read;
  var _emscripten_glBindFramebuffer=env._emscripten_glBindFramebuffer;
  var _emscripten_glBindRenderbuffer=env._emscripten_glBindRenderbuffer;
  var _time=env._time;
  var _emscripten_glGetFramebufferAttachmentParameteriv=env._emscripten_glGetFramebufferAttachmentParameteriv;
  var _exit=env._exit;
  var _roundf=env._roundf;
  var _putenv=env._putenv;
  var _emscripten_glDeleteBuffers=env._emscripten_glDeleteBuffers;
  var _access=env._access;
  var _JS_Cursor_SetImage=env._JS_Cursor_SetImage;
  var _emscripten_glShaderBinary=env._emscripten_glShaderBinary;
  var _emscripten_glGetShaderInfoLog=env._emscripten_glGetShaderInfoLog;
  var _glUniform3fv=env._glUniform3fv;
  var _emscripten_glGetVertexAttribPointerv=env._emscripten_glGetVertexAttribPointerv;
  var _pwrite=env._pwrite;
  var _open=env._open;
  var _emscripten_glUniform2f=env._emscripten_glUniform2f;
  var _emscripten_glDeleteProgram=env._emscripten_glDeleteProgram;
  var _glUniform1i=env._glUniform1i;
  var _emscripten_glCreateShader=env._emscripten_glCreateShader;
  var _pthread_mutex_destroy=env._pthread_mutex_destroy;
  var _emscripten_glColorPointer=env._emscripten_glColorPointer;
  var _SDL_UpperBlit=env._SDL_UpperBlit;
  var _emscripten_glViewport=env._emscripten_glViewport;
  var _pthread_cond_broadcast=env._pthread_cond_broadcast;
  var _emscripten_glDepthMask=env._emscripten_glDepthMask;
  var _emscripten_glDrawBuffers=env._emscripten_glDrawBuffers;
  var _SDL_JoystickNumAxes=env._SDL_JoystickNumAxes;
  var _clearerr=env._clearerr;
  var _glCompileShader=env._glCompileShader;
  var _emscripten_exit_pointerlock=env._emscripten_exit_pointerlock;
  var _log10f=env._log10f;
  var _abort=env._abort;
  var _emscripten_glGenerateMipmap=env._emscripten_glGenerateMipmap;
  var _glTexImage2D=env._glTexImage2D;
  var _emscripten_glGenFramebuffers=env._emscripten_glGenFramebuffers;
  var _glFlush=env._glFlush;
  var _emscripten_glLoadIdentity=env._emscripten_glLoadIdentity;
  var _glDeleteShader=env._glDeleteShader;
  var _emscripten_glShaderSource=env._emscripten_glShaderSource;
  var _glGetActiveUniform=env._glGetActiveUniform;
  var _sem_destroy=env._sem_destroy;
  var _SDL_CloseAudio=env._SDL_CloseAudio;
  var ___gxx_personality_v0=env.___gxx_personality_v0;
  var _emscripten_asm_const_int=env._emscripten_asm_const_int;
  var _usleep=env._usleep;
  var _fmax=env._fmax;
  var _emscripten_get_fullscreen_status=env._emscripten_get_fullscreen_status;
  var _glVertexAttribPointer=env._glVertexAttribPointer;
  var _JS_Sound_SetVelocity=env._JS_Sound_SetVelocity;
  var _emscripten_glGetRenderbufferParameteriv=env._emscripten_glGetRenderbufferParameteriv;
  var _glGenRenderbuffers=env._glGenRenderbuffers;
  var _strerror=env._strerror;
  var _emscripten_glSampleCoverage=env._emscripten_glSampleCoverage;
  var _emscripten_glFrustum=env._emscripten_glFrustum;
  var _Mix_FreeChunk=env._Mix_FreeChunk;
  var _emscripten_glDepthRangef=env._emscripten_glDepthRangef;
  var _glPixelStorei=env._glPixelStorei;
  var _emscripten_glIsTexture=env._emscripten_glIsTexture;
  var _fputs=env._fputs;
  var _emscripten_glBindVertexArray=env._emscripten_glBindVertexArray;
  var _glStencilMask=env._glStencilMask;
  var _emscripten_glActiveTexture=env._emscripten_glActiveTexture;
  var _emscripten_glDeleteVertexArrays=env._emscripten_glDeleteVertexArrays;
  var _emscripten_glUniform2iv=env._emscripten_glUniform2iv;
  var _lstat=env._lstat;
  var _pthread_mutexattr_init=env._pthread_mutexattr_init;
  var _getenv=env._getenv;
  var _SDL_GL_SwapBuffers=env._SDL_GL_SwapBuffers;
  var _opendir=env._opendir;
  var _sqrt=env._sqrt;
  var tempFloat = Math_fround(0);
  const f0 = Math_fround(0);

  // EMSCRIPTEN_START_FUNCS
  function stackAlloc(size) {
    size = size|0;
    var ret = 0;
    ret = STACKTOP;
    STACKTOP = (STACKTOP + size)|0;
  STACKTOP = (STACKTOP + 15)&-16;

    return ret|0;
  }
  function stackSave() {
    return STACKTOP|0;
  }
  function stackRestore(top) {
    top = top|0;
    STACKTOP = top;
  }

  function setThrew(threw, value) {
    threw = threw|0;
    value = value|0;
    if ((__THREW__|0) == 0) {
      __THREW__ = threw;
      threwValue = value;
    }
  }
  function copyTempFloat(ptr) {
    ptr = ptr|0;
    HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
    HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
    HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
    HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
  }
  function copyTempDouble(ptr) {
    ptr = ptr|0;
    HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
    HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
    HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
    HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
    HEAP8[tempDoublePtr+4>>0] = HEAP8[ptr+4>>0];
    HEAP8[tempDoublePtr+5>>0] = HEAP8[ptr+5>>0];
    HEAP8[tempDoublePtr+6>>0] = HEAP8[ptr+6>>0];
    HEAP8[tempDoublePtr+7>>0] = HEAP8[ptr+7>>0];
  }
  function setTempRet0(value) {
    value = value|0;
    tempRet0 = value;
  }
  function getTempRet0() {
    return tempRet0|0;
  }
  
function _GC_default_print_heap_obj_proc($p) {
 $p = $p|0;
 var $$$i = 0, $$0$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $candidate_hdr$0$lcssa$i = 0, $candidate_hdr$01$i = 0, $h$0$lcssa$i = 0, $h$02$i = 0, $or$cond$i = 0, $r$0$lcssa$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[62424>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $$0$i = 0;
 } else {
  $2 = $p;
  $3 = $2 & -4096;
  $4 = $3;
  $5 = $2 >>> 22;
  $6 = ((56 + ($5<<2)|0) + 57964|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $2 >>> 12;
  $9 = $8 & 1023;
  $10 = (($7) + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $$0$i = 0;
  } else {
   $13 = ($11>>>0)<((4096)>>>0);
   if ($13) {
    $candidate_hdr$01$i = $11;$h$02$i = $4;
    while(1) {
     $14 = $candidate_hdr$01$i;
     $15 = (0 - ($14))|0;
     $16 = (($h$02$i) + ($15<<12)|0);
     $17 = $16;
     $18 = $17 >>> 12;
     $19 = $18 & 1023;
     $20 = $17 >>> 22;
     $21 = ((56 + ($20<<2)|0) + 57964|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($22) + ($19<<2)|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24>>>0)<((4096)>>>0);
     if ($25) {
      $candidate_hdr$01$i = $24;$h$02$i = $16;
     } else {
      break;
     }
    }
    $candidate_hdr$0$lcssa$i = $24;$h$0$lcssa$i = $16;$r$0$lcssa$i = $16;
   } else {
    $candidate_hdr$0$lcssa$i = $11;$h$0$lcssa$i = $4;$r$0$lcssa$i = $p;
   }
   $26 = (($candidate_hdr$0$lcssa$i) + 13|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27 & 4;
   $29 = ($28<<24>>24)==(0);
   if ($29) {
    $30 = $r$0$lcssa$i;
    $31 = $30 & -4;
    $32 = $31;
    $33 = $30 & 4092;
    $34 = (($candidate_hdr$0$lcssa$i) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($33>>>0) % ($35>>>0))&-1;
    $$sum$i = (($35) - ($36))|0;
    $37 = (($32) + ($$sum$i)|0);
    $38 = (($h$0$lcssa$i) + 4096|0);
    $39 = ($37>>>0)>($38>>>0);
    $40 = ($35>>>0)<(4097);
    $or$cond$i = $39 & $40;
    if ($or$cond$i) {
     $$0$i = 0;
    } else {
     $41 = (0 - ($36))|0;
     $42 = (($32) + ($41)|0);
     $43 = ($37>>>0)>($p>>>0);
     $$$i = $43 ? $42 : 0;
     $$0$i = $$$i;
    }
   } else {
    $$0$i = 0;
   }
  }
 }
 $44 = $$0$i;
 $45 = $44 >>> 12;
 $46 = $45 & 1023;
 $47 = $44 >>> 22;
 $48 = ((56 + ($47<<2)|0) + 57964|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + ($46<<2)|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 12|0);
 $53 = HEAP8[$52>>0]|0;
 $54 = (($51) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($53<<24>>24)==(0);
 if ($56) {
  $59 = 62160;
  HEAP32[$vararg_buffer>>2] = $$0$i;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $55;
  $vararg_ptr2 = (($vararg_buffer) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $59;
  _GC_err_printf(62120,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $57 = ($53<<24>>24)==(2);
 $58 = $57 ? 62168 : 62184;
 $59 = $58;
 HEAP32[$vararg_buffer>>2] = $$0$i;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $55;
 $vararg_ptr2 = (($vararg_buffer) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $59;
 _GC_err_printf(62120,$vararg_buffer);
 STACKTOP = sp;return;
}
function _GC_base($p) {
 $p = $p|0;
 var $$ = 0, $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $candidate_hdr$0$lcssa = 0, $candidate_hdr$01 = 0, $h$0$lcssa = 0, $h$02 = 0, $or$cond = 0, $r$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[62424>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $p;
 $3 = $2 & -4096;
 $4 = $3;
 $5 = $2 >>> 22;
 $6 = ((56 + ($5<<2)|0) + 57964|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $2 >>> 12;
 $9 = $8 & 1023;
 $10 = (($7) + ($9<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = ($11>>>0)<((4096)>>>0);
 if ($13) {
  $candidate_hdr$01 = $11;$h$02 = $4;
  while(1) {
   $14 = $candidate_hdr$01;
   $15 = (0 - ($14))|0;
   $16 = (($h$02) + ($15<<12)|0);
   $17 = $16;
   $18 = $17 >>> 12;
   $19 = $18 & 1023;
   $20 = $17 >>> 22;
   $21 = ((56 + ($20<<2)|0) + 57964|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + ($19<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24>>>0)<((4096)>>>0);
   if ($25) {
    $candidate_hdr$01 = $24;$h$02 = $16;
   } else {
    break;
   }
  }
  $candidate_hdr$0$lcssa = $24;$h$0$lcssa = $16;$r$0$lcssa = $16;
 } else {
  $candidate_hdr$0$lcssa = $11;$h$0$lcssa = $4;$r$0$lcssa = $p;
 }
 $26 = (($candidate_hdr$0$lcssa) + 13|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27 & 4;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = $r$0$lcssa;
 $31 = $30 & -4;
 $32 = $31;
 $33 = $30 & 4092;
 $34 = (($candidate_hdr$0$lcssa) + 16|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($33>>>0) % ($35>>>0))&-1;
 $$sum = (($35) - ($36))|0;
 $37 = (($32) + ($$sum)|0);
 $38 = (($h$0$lcssa) + 4096|0);
 $39 = ($37>>>0)>($38>>>0);
 $40 = ($35>>>0)<(4097);
 $or$cond = $39 & $40;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = (0 - ($36))|0;
 $42 = (($32) + ($41)|0);
 $43 = ($37>>>0)>($p>>>0);
 $$ = $43 ? $42 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function _GC_err_printf($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $buf = 0, $bytes_written$01$i$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $buf = sp + 16|0;
 $args = sp;
 HEAP32[$args>>2] = $varargs;
 $0 = (($buf) + 1024|0);
 HEAP8[$0>>0] = 21;
 (_vsnprintf($buf,1024,$format,$args)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(21);
 if (!($2)) {
  _GC_default_on_abort(67560);
  _abort();
  // unreachable;
 }
 $3 = (_strlen(($buf|0))|0);
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $bytes_written$01$i$i = 0;
 }
 while(1) {
  $5 = (($buf) + ($bytes_written$01$i$i)|0);
  $6 = (($3) - ($bytes_written$01$i$i))|0;
  $7 = (_write(2,($5|0),($6|0))|0);
  $8 = ($7|0)!=(-1);
  $9 = (($7) + ($bytes_written$01$i$i))|0;
  $10 = ($9>>>0)<($3>>>0);
  $or$cond$i = $8 & $10;
  if ($or$cond$i) {
   $bytes_written$01$i$i = $9;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _GC_scratch_alloc($bytes) {
 $bytes = $bytes|0;
 var $$$i$i = 0, $$$i$i1 = 0, $$$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $result$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[62320>>2]|0;
 $1 = (($bytes) + 7)|0;
 $2 = $1 & -8;
 $3 = (($0) + ($2)|0);
 HEAP32[62320>>2] = $3;
 $4 = HEAP32[((56 + 52|0))>>2]|0;
 $5 = ($3>>>0)>($4>>>0);
 if (!($5)) {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $6 = ($2>>>0)>(65535);
  $7 = (_sbrk(0)|0);
  $8 = $7;
  $9 = HEAP32[65032>>2]|0;
  $10 = (($9) + -1)|0;
  $11 = $10 & $8;
  if ($6) {
   label = 3;
   break;
  }
  $23 = ($11|0)==(0);
  if (!($23)) {
   $24 = (($9) - ($11))|0;
   $25 = (_sbrk(($24|0))|0);
   $26 = ($25|0)==((-1)|0);
   if ($26) {
    label = 11;
    break;
   }
  }
  $27 = (_sbrk(65536)|0);
  $28 = ($27|0)==((-1)|0);
  $$$i$i1 = $28 ? 0 : $27;
  $29 = ($$$i$i1|0)==(0|0);
  if ($29) {
   label = 11;
   break;
  }
  $45 = (($$$i$i1) + 65536|0);
  HEAP32[((56 + 52|0))>>2] = $45;
  HEAP32[((56 + 56|0))>>2] = $45;
  $46 = (($$$i$i1) + ($2)|0);
  HEAP32[62320>>2] = $46;
  $47 = ($2|0)>(65536);
  if (!($47)) {
   $$0 = $$$i$i1;
   label = 16;
   break;
  }
 }
 if ((label|0) == 3) {
  $12 = ($2|0)<(0);
  do {
   if ($12) {
    $result$0$i$i = 0;
   } else {
    $13 = ($11|0)==(0);
    if (!($13)) {
     $14 = (($9) - ($11))|0;
     $15 = (_sbrk(($14|0))|0);
     $16 = ($15|0)==((-1)|0);
     if ($16) {
      $result$0$i$i = 0;
      break;
     }
    }
    $17 = (_sbrk(($2|0))|0);
    $18 = ($17|0)==((-1)|0);
    $$$i$i = $18 ? 0 : $17;
    $result$0$i$i = $$$i$i;
   }
  } while(0);
  $19 = HEAP32[62320>>2]|0;
  $20 = (0 - ($2))|0;
  $21 = (($19) + ($20)|0);
  HEAP32[62320>>2] = $21;
  $22 = (($result$0$i$i) + ($2)|0);
  HEAP32[((56 + 56|0))>>2] = $22;
  $$0 = $result$0$i$i;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 11) {
  _GC_default_warn_proc(62328,0);
  $30 = HEAP32[62320>>2]|0;
  $31 = (0 - ($2))|0;
  $32 = (($30) + ($31)|0);
  HEAP32[62320>>2] = $32;
  $33 = (_sbrk(0)|0);
  $34 = $33;
  $35 = HEAP32[65032>>2]|0;
  $36 = (($35) + -1)|0;
  $37 = $36 & $34;
  $38 = ($2|0)<(0);
  if ($38) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $39 = ($37|0)==(0);
  if (!($39)) {
   $40 = (($35) - ($37))|0;
   $41 = (_sbrk(($40|0))|0);
   $42 = ($41|0)==((-1)|0);
   if ($42) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $43 = (_sbrk(($2|0))|0);
  $44 = ($43|0)==((-1)|0);
  $$$i$i4 = $44 ? 0 : $43;
  $$0 = $$$i$i4;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _GC_bl_init() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond3 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (1)==(0);
 $1 = HEAP32[16>>2]|0;
 $2 = ($1|0)==(0|0);
 $or$cond3 = $0 & $2;
 do {
  if ($or$cond3) {
   $3 = (_GC_scratch_alloc(32768)|0);
   HEAP32[8>>2] = $3;
   $4 = (_GC_scratch_alloc(32768)|0);
   HEAP32[16>>2] = $4;
   $5 = HEAP32[8>>2]|0;
   $6 = ($5|0)==(0|0);
   $7 = ($4|0)==(0|0);
   $or$cond$i = $6 | $7;
   if ($or$cond$i) {
    _GC_err_printf(62200,$vararg_buffer1);
    _GC_default_on_abort(0);
    _exit(1);
    // unreachable;
   } else {
    _memset(($5|0),0,32768)|0;
    _memset(($4|0),0,32768)|0;
    break;
   }
  }
 } while(0);
 $8 = (_GC_scratch_alloc(32768)|0);
 HEAP32[24>>2] = $8;
 $9 = (_GC_scratch_alloc(32768)|0);
 HEAP32[32>>2] = $9;
 $10 = HEAP32[24>>2]|0;
 $11 = ($10|0)==(0|0);
 $12 = ($9|0)==(0|0);
 $or$cond = $11 | $12;
 if ($or$cond) {
  _GC_err_printf(62200,$vararg_buffer1);
  _GC_default_on_abort(0);
  _exit(1);
  // unreachable;
 } else {
  _memset(($10|0),0,32768)|0;
  _memset(($9|0),0,32768)|0;
  STACKTOP = sp;return;
 }
}
function _GC_promote_black_lists() {
 var $$pr = 0, $$pr1 = 0, $$pr3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $h$02$i$i = 0, $i$02$i = 0, $not$$i$i = 0, $phitmp$i = 0, $result$0$$i$i = 0, $result$0$lcssa$i$i = 0, $result$01$i$i = 0, $total$0$lcssa$i = 0, $total$01$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[8>>2]|0;
 $1 = HEAP32[24>>2]|0;
 $2 = HEAP32[16>>2]|0;
 HEAP32[8>>2] = $2;
 $3 = HEAP32[32>>2]|0;
 HEAP32[24>>2] = $3;
 $4 = (1)==(0);
 if ($4) {
  _memset(($0|0),0,32768)|0;
 }
 _memset(($1|0),0,32768)|0;
 HEAP32[16>>2] = $0;
 HEAP32[32>>2] = $1;
 $5 = HEAP32[63528>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $total$0$lcssa$i = 0;
 } else {
  $i$02$i = 0;$total$01$i = 0;
  while(1) {
   $7 = ((56 + ($i$02$i<<3)|0) + 16744|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((56 + ($i$02$i<<3)|0) + 16748|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 12;
   $12 = (($8) + ($11<<12)|0);
   $13 = ($8>>>0)<($12>>>0);
   if ($13) {
    $h$02$i$i = $8;$result$01$i$i = 0;
    while(1) {
     $14 = $h$02$i$i;
     $15 = $14 >>> 12;
     $16 = $14 >>> 17;
     $17 = $16 & 8191;
     $18 = (($3) + ($17<<2)|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $15 & 31;
     $21 = 1 << $20;
     $22 = $21 & $19;
     $not$$i$i = ($22|0)!=(0);
     $23 = $not$$i$i&1;
     $result$0$$i$i = (($23) + ($result$01$i$i))|0;
     $24 = (($h$02$i$i) + 4096|0);
     $25 = ($24>>>0)<($12>>>0);
     if ($25) {
      $h$02$i$i = $24;$result$01$i$i = $result$0$$i$i;
     } else {
      $result$0$lcssa$i$i = $result$0$$i$i;
      break;
     }
    }
   } else {
    $result$0$lcssa$i$i = 0;
   }
   $26 = (($result$0$lcssa$i$i) + ($total$01$i))|0;
   $27 = (($i$02$i) + 1)|0;
   $exitcond = ($27|0)==($5|0);
   if ($exitcond) {
    break;
   } else {
    $i$02$i = $27;$total$01$i = $26;
   }
  }
  $phitmp$i = $26 << 12;
  $total$0$lcssa$i = $phitmp$i;
 }
 HEAP32[40>>2] = $total$0$lcssa$i;
 $28 = HEAP32[62240>>2]|0;
 $29 = ($28|0)==(2);
 if ($29) {
  HEAP32[$vararg_buffer>>2] = $total$0$lcssa$i;
  _GC_log_printf(62248,$vararg_buffer);
  $$pr = HEAP32[40>>2]|0;
  $31 = $$pr;
 } else {
  $31 = $total$0$lcssa$i;
 }
 $30 = ($31|0)==(0);
 if ($30) {
  $$pr1 = HEAP32[48>>2]|0;
  $$pr3 = $$pr1;
 } else {
  $32 = HEAP32[56>>2]|0;
  $33 = (($32>>>0) / ($31>>>0))&-1;
  $34 = $33 << 12;
  HEAP32[48>>2] = $34;
  $$pr3 = $34;
 }
 $35 = ($$pr3>>>0)<(12288);
 if ($35) {
  HEAP32[48>>2] = 12288;
  STACKTOP = sp;return;
 }
 $36 = ($$pr3>>>0)>(8388608);
 if (!($36)) {
  STACKTOP = sp;return;
 }
 HEAP32[48>>2] = 8388608;
 STACKTOP = sp;return;
}
function _GC_log_printf($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $buf = 0, $bytes_written$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $buf = sp + 16|0;
 $args = sp;
 HEAP32[$args>>2] = $varargs;
 $0 = (($buf) + 1024|0);
 HEAP8[$0>>0] = 21;
 (_vsnprintf($buf,1024,$format,$args)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(21);
 if (!($2)) {
  _GC_default_on_abort(67560);
  _abort();
  // unreachable;
 }
 $3 = (_strlen(($buf|0))|0);
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $bytes_written$01$i = 0;
 }
 while(1) {
  $7 = (($buf) + ($bytes_written$01$i)|0);
  $8 = (($3) - ($bytes_written$01$i))|0;
  $9 = (_write(2,($7|0),($8|0))|0);
  $10 = ($9|0)==(-1);
  $6 = (($9) + ($bytes_written$01$i))|0;
  if ($10) {
   label = 7;
   break;
  }
  $5 = ($6>>>0)<($3>>>0);
  if ($5) {
   $bytes_written$01$i = $6;
  } else {
   break;
  }
 }
 if ((label|0) == 7) {
  _GC_default_on_abort(67616);
  _abort();
  // unreachable;
 }
 $11 = ($6|0)<(0);
 if ($11) {
  _GC_default_on_abort(67616);
  _abort();
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function _GC_is_black_listed($h,$len) {
 $h = $h|0;
 $len = $len|0;
 var $$0 = 0, $$pn = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$1 = 0, $index$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $h;
 $1 = $0 >>> 12;
 $2 = $1 & 262143;
 $3 = (1)==(0);
 do {
  if ($3) {
   $4 = $2 >>> 5;
   $5 = HEAP32[8>>2]|0;
   $6 = (($5) + ($4<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $1 & 31;
   $9 = 1 << $8;
   $10 = $7 & $9;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = HEAP32[16>>2]|0;
    $13 = (($12) + ($4<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 & $9;
    $16 = ($15|0)==(0);
    if ($16) {
     break;
    }
   }
   $17 = (($h) + 4096|0);
   $$0 = $17;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $18 = $len >>> 12;
 $19 = HEAP32[24>>2]|0;
 $20 = HEAP32[32>>2]|0;
 $i$0 = 0;$index$0 = $2;
 while(1) {
  $21 = $index$0 >>> 5;
  $22 = (($19) + ($21<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0);
  if ($24) {
   $25 = (($20) + ($21<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0);
   if ($27) {
    $28 = $index$0 & 31;
    $29 = (32 - ($28))|0;
    $$pn = $29;
   } else {
    label = 9;
   }
  } else {
   label = 9;
  }
  if ((label|0) == 9) {
   label = 0;
   $30 = $index$0 & 31;
   $31 = 1 << $30;
   $32 = $23 & $31;
   $33 = ($32|0)==(0);
   if (!($33)) {
    break;
   }
   $34 = (($20) + ($21<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 & $31;
   $37 = ($36|0)==(0);
   if ($37) {
    $$pn = 1;
   } else {
    break;
   }
  }
  $i$1 = (($$pn) + ($i$0))|0;
  $39 = ($i$1>>>0)<($18>>>0);
  if (!($39)) {
   $$0 = 0;
   label = 14;
   break;
  }
  $40 = (($h) + ($i$1<<12)|0);
  $41 = $40;
  $42 = $41 >>> 12;
  $43 = $42 & 262143;
  $i$0 = $i$1;$index$0 = $43;
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return ($$0|0);
 }
 $$sum = (($i$0) + 1)|0;
 $38 = (($h) + ($$sum<<12)|0);
 $$0 = $38;
 STACKTOP = sp;return ($$0|0);
}
function _GC_init() {
 var $$0$i = 0, $$0$i3 = 0, $$0$i6 = 0, $$0$i7 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $endptr$i = 0, $exitcond = 0, $exitcond$i = 0, $i$01$i = 0, $i$01$i5 = 0;
 var $initial_heap_sz$0 = 0, $or$cond = 0, $phitmp = 0, $vararg_buffer11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer11 = sp;
 $endptr$i = sp + 4|0;
 $0 = HEAP32[62424>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 HEAP32[65032>>2] = 4096;
 $2 = (_getenv((66768|0))|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = (_getenv((66792|0))|0);
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   HEAP32[62240>>2] = 1;
  }
 } else {
  HEAP32[62240>>2] = 2;
 }
 $6 = (_getenv((66808|0))|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  HEAP32[64552>>2] = 1;
 }
 $8 = (_getenv((66832|0))|0);
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  HEAP32[63736>>2] = 1;
 }
 $10 = (_getenv((66848|0))|0);
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  HEAP32[65312>>2] = 1;
 }
 $12 = (_getenv((66872|0))|0);
 $13 = ($12|0)==(0|0);
 if (!($13)) {
 }
 $14 = (_getenv((66904|0))|0);
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  HEAP32[62440>>2] = 1;
 }
 $16 = (_getenv((66920|0))|0);
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  HEAP32[64560>>2] = 1;
 }
 $18 = (_getenv((66944|0))|0);
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  HEAP32[63608>>2] = 2147483647;
 }
 $20 = (_getenv((66968|0))|0);
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  _GC_default_warn_proc(66984,0);
 }
 $22 = (_getenv((67048|0))|0);
 $23 = ($22|0)==(0|0);
 do {
  if (!($23)) {
   $24 = (_atol($22)|0);
   $25 = ($24|0)<(5);
   if ($25) {
    _GC_default_warn_proc(67072,0);
    break;
   } else {
    HEAP32[63952>>2] = $24;
    break;
   }
  }
 } while(0);
 $26 = (_getenv((67168|0))|0);
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = (_atoi($26)|0);
  $29 = ($28|0)>(0);
  if ($29) {
   HEAP32[63920>>2] = $28;
  }
 }
 $30 = (_getenv((67192|0))|0);
 $31 = ($30|0)==(0|0);
 do {
  if (!($31)) {
   $32 = (_atol($30)|0);
   $33 = ($32|0)<(1);
   if ($33) {
    _GC_default_warn_proc(67224,0);
    break;
   } else {
    HEAP32[63608>>2] = $32;
    break;
   }
  }
 } while(0);
 $34 = (_getenv((67312|0))|0);
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = (_atoi($34)|0);
  $37 = ($36|0)>(0);
  if ($37) {
   HEAP32[63944>>2] = $36;
  }
 }
 $38 = (1)==(0);
 if (!($38)) {
  HEAP32[((62448 + 28|0))>>2] = -4;
 }
 _GC_exclude_static_roots_inner(56,((56 + 62060|0)));
 _GC_exclude_static_roots_inner(62448,((62448 + 320|0)));
 $39 = HEAP32[62840>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  HEAP32[62840>>2] = (-4);
 }
 $41 = HEAP32[62432>>2]|0;
 $42 = ($41|0)==(0);
 if ($42) {
  $43 = (_getenv((67336|0))|0);
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   label = 42;
  }
 } else {
  label = 42;
 }
 if ((label|0) == 42) {
  $45 = HEAP32[62240>>2]|0;
  $46 = ($45|0)==(2);
  if ($46) {
   _GC_log_printf(67768,$vararg_buffer11);
  }
  HEAP32[65912>>2] = 1;
  HEAP32[62432>>2] = 1;
 }
 $47 = (_GC_scratch_alloc(4108)|0);
 HEAP32[((56 + 57960|0))>>2] = $47;
 $48 = ($47|0)==(0|0);
 if ($48) {
  _GC_err_printf(62384,$vararg_buffer11);
  _GC_default_on_abort(0);
  _exit(1);
  // unreachable;
 }
 _memset(($47|0),0,4108)|0;
 $i$01$i = 0;
 while(1) {
  $49 = HEAP32[((56 + 57960|0))>>2]|0;
  $50 = ((56 + ($i$01$i<<2)|0) + 57964|0);
  HEAP32[$50>>2] = $49;
  $51 = (($i$01$i) + 1)|0;
  $exitcond$i = ($51|0)==(1024);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $51;
  }
 }
 _GC_bl_init();
 _alloc_mark_stack(4096);
 $52 = (_getenv((67360|0))|0);
 $53 = ($52|0)==(0|0);
 if ($53) {
  $initial_heap_sz$0 = 16;
 } else {
  $54 = HEAP8[$52>>0]|0;
  $55 = ($54<<24>>24)==(0);
  L75: do {
   if ($55) {
    $$0$i7 = 0;
    label = 58;
   } else {
    $56 = (_strtoul($52,$endptr$i,10)|0);
    $57 = HEAP32[$endptr$i>>2]|0;
    $58 = HEAP8[$57>>0]|0;
    $59 = $58 << 24 >> 24;
    $60 = ($58<<24>>24)==(0);
    L77: do {
     if ($60) {
      $$0$i = $56;
     } else {
      $61 = (($57) + 1|0);
      $62 = HEAP8[$61>>0]|0;
      $63 = ($62<<24>>24)==(0);
      if (!($63)) {
       $$0$i7 = 0;
       label = 58;
       break L75;
      }
      switch ($59|0) {
      case 109: case 77:  {
       $65 = $56 << 20;
       $$0$i = $65;
       break L77;
       break;
      }
      case 103: case 71:  {
       $66 = $56 << 30;
       $$0$i = $66;
       break L77;
       break;
      }
      case 107: case 75:  {
       $64 = $56 << 10;
       $$0$i = $64;
       break L77;
       break;
      }
      default: {
       $$0$i7 = 0;
       label = 58;
       break L75;
      }
      }
     }
    } while(0);
    $67 = ($$0$i>>>0)<(65537);
    if ($67) {
     $$0$i7 = $$0$i;
     label = 58;
    } else {
     $$0$i6 = $$0$i;
    }
   }
  } while(0);
  if ((label|0) == 58) {
   $68 = $52;
   _GC_default_warn_proc(67384,$68);
   $$0$i6 = $$0$i7;
  }
  $69 = $$0$i6 >>> 12;
  $initial_heap_sz$0 = $69;
 }
 $70 = (_getenv((67440|0))|0);
 $71 = ($70|0)==(0|0);
 if (!($71)) {
  $72 = HEAP8[$70>>0]|0;
  $73 = ($72<<24>>24)==(0);
  L91: do {
   if ($73) {
    $$0$i3 = 0;
   } else {
    $74 = (_strtoul($70,$vararg_buffer11,10)|0);
    $75 = HEAP32[$vararg_buffer11>>2]|0;
    $76 = HEAP8[$75>>0]|0;
    $77 = $76 << 24 >> 24;
    $78 = ($76<<24>>24)==(0);
    if ($78) {
     $$0$i3 = $74;
     break;
    }
    $79 = (($75) + 1|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = ($80<<24>>24)==(0);
    if (!($81)) {
     $$0$i3 = 0;
     break;
    }
    switch ($77|0) {
    case 107: case 75:  {
     $82 = $74 << 10;
     $$0$i3 = $82;
     break L91;
     break;
    }
    case 103: case 71:  {
     $84 = $74 << 30;
     $$0$i3 = $84;
     break L91;
     break;
    }
    case 109: case 77:  {
     $83 = $74 << 20;
     $$0$i3 = $83;
     break L91;
     break;
    }
    default: {
     $$0$i3 = 0;
     break L91;
    }
    }
   }
  } while(0);
  $85 = $initial_heap_sz$0 << 12;
  $86 = ($$0$i3>>>0)<($85>>>0);
  if ($86) {
   $87 = $70;
   _GC_default_warn_proc(67464,$87);
  }
  $88 = HEAP32[65024>>2]|0;
  $89 = ($88|0)==(0);
  if ($89) {
   HEAP32[65024>>2] = 2;
  }
  HEAP32[65016>>2] = $$0$i3;
 }
 $90 = (_GC_expand_hp_inner($initial_heap_sz$0)|0);
 $91 = ($90|0)==(0);
 if ($91) {
  _GC_err_printf(67520,$vararg_buffer11);
  _GC_default_on_abort(0);
  _exit(1);
  // unreachable;
 }
 $92 = HEAP32[((56 + 4|0))>>2]|0;
 $93 = (($92) + ($initial_heap_sz$0))|0;
 HEAP32[((56 + 4|0))>>2] = $93;
 $94 = (1)==(0);
 do {
  if ($94) {
   $$pre = HEAP8[((56 + 12644|0))>>0]|0;
   $phitmp = ($$pre<<24>>24)==(0);
   if (!($phitmp)) {
    break;
   }
   HEAP8[((56 + 12644|0))>>0] = 1;
   HEAP8[((56 + 16740|0))>>0] = 1;
  } else {
   _memset((((56 + 12644|0))|0),1,4096)|0;
  }
 } while(0);
 HEAP32[((56 + 3420|0))>>2] = 1;
 $95 = (256 - 1)|0;
 $96 = ($95|0)<(1);
 if (!($96)) {
  $97 = (1 + 7)|0;
  $98 = (257 - 1)|0;
  $i$01$i5 = 1;
  while(1) {
   $99 = (($97) + ($i$01$i5))|0;
   $100 = $99 >> 3;
   $101 = ((56 + ($i$01$i5<<2)|0) + 3420|0);
   HEAP32[$101>>2] = $100;
   $102 = (($i$01$i5) + 1)|0;
   $exitcond = ($102|0)==($98|0);
   if ($exitcond) {
    break;
   } else {
    $i$01$i5 = $102;
   }
  }
 }
 HEAP32[62424>>2] = 1;
 $103 = HEAP32[64552>>2]|0;
 $104 = ($103|0)==(0);
 if (!($104)) {
  _GC_printf(67672,$vararg_buffer11);
  _GC_print_static_roots();
  _GC_printf(67696,$vararg_buffer11);
  _GC_print_heap_sects();
  _GC_printf(67720,$vararg_buffer11);
  _GC_print_hblkfreelist();
  _GC_printf(67744,$vararg_buffer11);
  _GC_print_block_list();
 }
 $105 = (0)==(0);
 $106 = HEAP32[62432>>2]|0;
 $107 = ($106|0)!=(0);
 $or$cond = $105 | $107;
 if ($or$cond) {
  (_GC_try_to_collect_inner(1)|0);
 }
 $108 = HEAP32[63736>>2]|0;
 $109 = ($108|0)==(0);
 if ($109) {
  STACKTOP = sp;return;
 }
 (_atexit((65|0))|0);
 STACKTOP = sp;return;
}
function _GC_generic_malloc_inner($lb,$k) {
 $lb = $lb|0;
 $k = $k|0;
 var $$$i = 0, $$0 = 0, $$0$i = 0, $$1$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0;
 var $9 = 0, $granule_sz$0$i = 0, $j$02$i = 0, $lg$1 = 0, $lg$23 = 0, $lg$3 = 0, $low_limit$0$i = 0, $low_limit$1$i = 0, $low_limit$1$in$i = 0, $low_limit$2$i = 0, $op$1 = 0, $op$2 = 0, $opp$04 = 0, $opp$1 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($lb>>>0)<(2048);
 if ($0) {
  label = 3;
 } else {
  $1 = (2048 - 1)|0;
  $2 = ($1>>>0)<($lb>>>0);
  if ($2) {
   $65 = (1 + ($lb))|0;
   $66 = (_GC_alloc_large($65,$k,0)|0);
   $67 = (($65) + 4095)|0;
   $68 = $67 & -4096;
   $69 = ($66|0)==(0|0);
   do {
    if ($69) {
     $$0$i = 0;
    } else {
     $70 = (0)==(0);
     if ($70) {
      $71 = ((62448 + (($k*20)|0)|0) + 16|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = ($72|0)==(0);
      if ($73) {
       $$0$i = $66;
       break;
      }
     }
     _memset(($66|0),0,($68|0))|0;
     $$0$i = $66;
    }
   } while(0);
   $74 = HEAP32[((56 + 32|0))>>2]|0;
   $75 = (($74) + ($lb))|0;
   $op$2 = $$0$i;$storemerge = $75;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $3 = ((56 + ($lb<<2)|0) + 3420|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (62448 + (($k*20)|0)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($4<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  do {
   if ($9) {
    $10 = ($4|0)==(0);
    if ($10) {
     $11 = HEAP32[62424>>2]|0;
     $12 = ($11|0)==(0);
     if ($12) {
      _GC_init();
      $13 = HEAP32[$3>>2]|0;
      $14 = ($13|0)==(0);
      if ($14) {
       label = 7;
      } else {
       $lg$1 = $13;
      }
     } else {
      label = 7;
     }
     if ((label|0) == 7) {
      $15 = (($lb) + 7)|0;
      $16 = (($15) + 1)|0;
      $17 = $16 >>> 3;
      $18 = $17 << 3;
      $19 = (($18) - ($17))|0;
      $20 = ((56 + ($19<<2)|0) + 3420|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21|0)==(0);
      if ($22) {
       $23 = $17 << 1;
       $24 = (($18) - ($23))|0;
       $low_limit$0$i = $24;
       while(1) {
        $25 = ((56 + ($low_limit$0$i<<2)|0) + 3420|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = ($26|0)==(0);
        $28 = (($low_limit$0$i) + 1)|0;
        if ($27) {
         $granule_sz$0$i = $17;$low_limit$2$i = $low_limit$0$i;
         break;
        } else {
         $low_limit$0$i = $28;
        }
       }
      } else {
       $low_limit$1$in$i = $19;
       while(1) {
        $low_limit$1$i = (($low_limit$1$in$i) + 1)|0;
        $29 = ((56 + ($low_limit$1$i<<2)|0) + 3420|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = ($30|0)==(0);
        if ($31) {
         break;
        } else {
         $low_limit$1$in$i = $low_limit$1$i;
        }
       }
       $32 = (1 + 8)|0;
       $33 = (($32) + ($low_limit$1$in$i))|0;
       $34 = $33 >>> 3;
       $35 = $33 >>> 6;
       $36 = (($34) + ($35))|0;
       $37 = ($36>>>0)<($17>>>0);
       $$1$i = $37 ? $17 : $36;
       $granule_sz$0$i = $$1$i;$low_limit$2$i = $low_limit$1$i;
      }
      $38 = (($granule_sz$0$i) + 1)|0;
      $39 = $38 & -2;
      $40 = ($39>>>0)>(256);
      $$$i = $40 ? 256 : $39;
      $41 = (512 / ($$$i>>>0))&-1;
      $42 = (512 / ($41>>>0))&-1;
      $43 = $42 & 1022;
      $44 = $43 << 3;
      $45 = (($44) - 1)|0;
      $46 = ($low_limit$2$i>>>0)>($45>>>0);
      if ($46) {
       $lg$1 = 0;
      } else {
       $j$02$i = $low_limit$2$i;
       while(1) {
        $47 = ((56 + ($j$02$i<<2)|0) + 3420|0);
        HEAP32[$47>>2] = $43;
        $48 = (($j$02$i) + 1)|0;
        $49 = ($48>>>0)>($45>>>0);
        if ($49) {
         break;
        } else {
         $j$02$i = $48;
        }
       }
       $$pre = HEAP32[$3>>2]|0;
       $lg$1 = $$pre;
      }
     }
     $50 = HEAP32[$5>>2]|0;
     $51 = (($50) + ($lg$1<<2)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==(0|0);
     if ($53) {
      $lg$23 = $lg$1;$opp$04 = $51;
     } else {
      $lg$3 = $lg$1;$op$1 = $52;$opp$1 = $51;
      break;
     }
    } else {
     $lg$23 = $4;$opp$04 = $7;
    }
    $54 = ((62448 + (($k*20)|0)|0) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==(0|0);
    do {
     if ($56) {
      $57 = (_GC_scratch_alloc(1028)|0);
      $58 = ($57|0)==(0|0);
      if ($58) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      } else {
       _memset(($57|0),0,1028)|0;
       HEAP32[$54>>2] = $57;
       break;
      }
     }
    } while(0);
    $59 = (_GC_allocobj($lg$23,$k)|0);
    $60 = ($59|0)==(0|0);
    if ($60) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    } else {
     $lg$3 = $lg$23;$op$1 = $59;$opp$1 = $opp$04;
    }
   } else {
    $lg$3 = $4;$op$1 = $8;$opp$1 = $7;
   }
  } while(0);
  $61 = HEAP32[$op$1>>2]|0;
  HEAP32[$opp$1>>2] = $61;
  HEAP32[$op$1>>2] = 0;
  $62 = $lg$3 << 3;
  $63 = HEAP32[((56 + 32|0))>>2]|0;
  $64 = (($63) + ($62))|0;
  $op$2 = $op$1;$storemerge = $64;
 }
 HEAP32[((56 + 32|0))>>2] = $storemerge;
 $$0 = $op$2;
 STACKTOP = sp;return ($$0|0);
}
function _GC_header_cache_miss($p,$hce) {
 $p = $p|0;
 $hce = $hce|0;
 var $$0 = 0, $$pre$i1 = 0, $$pre$i14 = 0, $$pre$i35 = 0, $$pre$i7 = 0, $$pre$phi2$i12Z2D = 0, $$pre$phi2$i6Z2D = 0, $$pre$phi4$i11Z2D = 0, $$pre$phi4$i5Z2D = 0, $$pre1$i15 = 0, $$pre1$i2 = 0, $$pre1$i36 = 0, $$pre1$i8 = 0, $$pre3$i16 = 0, $$pre3$i3 = 0, $$pre3$i37 = 0, $$pre3$i9 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $current$0 = 0;
 var $hhdr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $p;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7>>>0)<((4096)>>>0);
 if (!($8)) {
  $64 = (($7) + 13|0);
  $65 = HEAP8[$64>>0]|0;
  $66 = $65 & 4;
  $67 = ($66<<24>>24)==(0);
  if ($67) {
   HEAP32[$hce>>2] = $1;
   $101 = (($hce) + 4|0);
   HEAP32[$101>>2] = $7;
   $$0 = $7;
   STACKTOP = sp;return ($$0|0);
  }
  $68 = (1)==(0);
  if (!($68)) {
   $69 = $1 & 262143;
   $70 = ($7|0)==(0|0);
   if ($70) {
    $$pre$i7 = $1 & 31;
    $$pre1$i8 = 1 << $$pre$i7;
    $$pre3$i9 = $69 >>> 5;
    $$pre$phi2$i12Z2D = $$pre1$i8;$$pre$phi4$i11Z2D = $$pre3$i9;
   } else {
    $71 = $69 >>> 5;
    $72 = HEAP32[24>>2]|0;
    $73 = (($72) + ($71<<2)|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = $1 & 31;
    $76 = 1 << $75;
    $77 = $74 & $76;
    $78 = ($77|0)==(0);
    if ($78) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    } else {
     $$pre$phi2$i12Z2D = $76;$$pre$phi4$i11Z2D = $71;
    }
   }
   $79 = HEAP32[32>>2]|0;
   $80 = (($79) + ($$pre$phi4$i11Z2D<<2)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = $81 | $$pre$phi2$i12Z2D;
   HEAP32[$80>>2] = $82;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $83 = $0 & 3;
  $84 = ((56 + ($83)|0) + 16740|0);
  $85 = HEAP8[$84>>0]|0;
  $86 = ($85<<24>>24)==(0);
  if ($86) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $87 = $1 & 262143;
  $88 = ($7|0)==(0|0);
  if ($88) {
   $$pre$i1 = $1 & 31;
   $$pre1$i2 = 1 << $$pre$i1;
   $$pre3$i3 = $87 >>> 5;
   $$pre$phi2$i6Z2D = $$pre1$i2;$$pre$phi4$i5Z2D = $$pre3$i3;
  } else {
   $89 = $87 >>> 5;
   $90 = HEAP32[8>>2]|0;
   $91 = (($90) + ($89<<2)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = $1 & 31;
   $94 = 1 << $93;
   $95 = $92 & $94;
   $96 = ($95|0)==(0);
   if ($96) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$pre$phi2$i6Z2D = $94;$$pre$phi4$i5Z2D = $89;
   }
  }
  $97 = HEAP32[16>>2]|0;
  $98 = (($97) + ($$pre$phi4$i5Z2D<<2)|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = $99 | $$pre$phi2$i6Z2D;
  HEAP32[$98>>2] = $100;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (1)==(0);
 $10 = ($7|0)==(0|0);
 if ($9) {
  if (!($10)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $55 = $0 & 3;
  $56 = ((56 + ($55)|0) + 16740|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = ($57<<24>>24)==(0);
  if ($58) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $$pre$i14 = $1 & 31;
  $$pre1$i15 = 1 << $$pre$i14;
  $59 = $0 >>> 17;
  $$pre3$i16 = $59 & 8191;
  $60 = HEAP32[16>>2]|0;
  $61 = (($60) + ($$pre3$i16<<2)|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = $62 | $$pre1$i15;
  HEAP32[$61>>2] = $63;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ($10) {
  $$pre$i35 = $1 & 31;
  $$pre1$i36 = 1 << $$pre$i35;
  $50 = $0 >>> 17;
  $$pre3$i37 = $50 & 8191;
  $51 = HEAP32[32>>2]|0;
  $52 = (($51) + ($$pre3$i37<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = $53 | $$pre1$i36;
  HEAP32[$52>>2] = $54;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = $0 & -4096;
 $12 = $11;
 $current$0 = $12;$hhdr$0 = $7;
 while(1) {
  $13 = $hhdr$0;
  $14 = $13 << 12;
  $15 = (0 - ($14))|0;
  $16 = (($current$0) + ($15)|0);
  $17 = $16;
  $18 = $17 >>> 12;
  $19 = $18 & 1023;
  $20 = $17 >>> 22;
  $21 = ((56 + ($20<<2)|0) + 57964|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + ($19<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24>>>0)<((4096)>>>0);
  if ($25) {
   $current$0 = $16;$hhdr$0 = $24;
  } else {
   break;
  }
 }
 $26 = (($24) + 13|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 $29 = $28 & 1;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = $28 & 4;
 $32 = ($31|0)==(0);
 if ($32) {
  $33 = (($0) - ($17))|0;
  $34 = (($24) + 16|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($33|0)<($35|0);
  if ($36) {
   $$0 = $24;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $37 = $0 >>> 17;
 $38 = $37 & 8191;
 $39 = HEAP32[24>>2]|0;
 $40 = (($39) + ($38<<2)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $1 & 31;
 $43 = 1 << $42;
 $44 = $41 & $43;
 $45 = ($44|0)==(0);
 if ($45) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = HEAP32[32>>2]|0;
 $47 = (($46) + ($38<<2)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 | $43;
 HEAP32[$47>>2] = $49;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GC_install_header($h) {
 $h = $h|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pi$0$lcssa$i = 0, $pi$06$i = 0, $pi$06$i$phi = 0, $prev$0$lcssa$i = 0, $prev$02$i = 0, $prev$05$i = 0, $result$0$i2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $h;
 $1 = $0 >>> 22;
 $2 = ((56 + ($1<<2)|0) + 57964|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[((56 + 57960|0))>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  $6 = (_GC_scratch_alloc(4108)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$2>>2] = $6;
  _memset(($6|0),0,4104)|0;
  $8 = (($6) + 4104|0);
  HEAP32[$8>>2] = $1;
  $9 = HEAP32[62304>>2]|0;
  $10 = ($9|0)==(0|0);
  L6: do {
   if ($10) {
    $pi$0$lcssa$i = 0;$prev$0$lcssa$i = 62304;
    label = 6;
   } else {
    $15 = $9;$pi$06$i = 0;$prev$05$i = 62304;
    while(1) {
     $14 = (($15) + 4104|0);
     $16 = HEAP32[$14>>2]|0;
     $17 = ($16>>>0)<($1>>>0);
     $12 = (($15) + 4096|0);
     if (!($17)) {
      break;
     }
     $11 = HEAP32[$12>>2]|0;
     $13 = ($11|0)==(0|0);
     if ($13) {
      $pi$0$lcssa$i = $15;$prev$0$lcssa$i = $12;
      label = 6;
      break L6;
     } else {
      $pi$06$i$phi = $15;$15 = $11;$prev$05$i = $12;$pi$06$i = $pi$06$i$phi;
     }
    }
    $19 = (($6) + 4100|0);
    HEAP32[$19>>2] = $pi$06$i;
    $20 = (($15) + 4100|0);
    HEAP32[$20>>2] = $6;
    $22 = $15;$prev$02$i = $prev$05$i;
   }
  } while(0);
  if ((label|0) == 6) {
   $18 = (($6) + 4100|0);
   HEAP32[$18>>2] = $pi$0$lcssa$i;
   HEAP32[62312>>2] = $6;
   $22 = 0;$prev$02$i = $prev$0$lcssa$i;
  }
  $21 = (($6) + 4096|0);
  HEAP32[$21>>2] = $22;
  HEAP32[$prev$02$i>>2] = $6;
 }
 $23 = HEAP32[67920>>2]|0;
 $24 = ($23|0)==(0|0);
 do {
  if ($24) {
   $26 = (_GC_scratch_alloc(104)|0);
   $27 = ($26|0)==(0|0);
   if ($27) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $result$0$i2 = $26;
    break;
   }
  } else {
   $25 = HEAP32[$23>>2]|0;
   HEAP32[67920>>2] = $25;
   $result$0$i2 = $23;
  }
 } while(0);
 $28 = $0 >>> 12;
 $29 = $28 & 1023;
 $30 = HEAP32[$2>>2]|0;
 $31 = (($30) + ($29<<2)|0);
 HEAP32[$31>>2] = $result$0$i2;
 $$0 = $result$0$i2;
 STACKTOP = sp;return ($$0|0);
}
function _GC_install_counts($h,$sz) {
 $h = $h|0;
 $sz = $sz|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $hbp$030 = 0, $hbp$1 = 0, $hbp$112 = 0, $hbp$113 = 0, $pi$0$lcssa$i = 0, $pi$0$lcssa$i4 = 0, $pi$06$i = 0, $pi$06$i$phi = 0, $pi$06$i1 = 0, $pi$06$i1$phi = 0, $prev$0$lcssa$i = 0;
 var $prev$0$lcssa$i5 = 0, $prev$02$i = 0, $prev$02$i7 = 0, $prev$05$i = 0, $prev$05$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $h;
 $1 = (($0) + ($sz))|0;
 $2 = ($0>>>0)<($1>>>0);
 L1: do {
  if ($2) {
   $4 = $0;$hbp$030 = $h;
   while(1) {
    $3 = $4 >>> 22;
    $5 = ((56 + ($3<<2)|0) + 57964|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = HEAP32[((56 + 57960|0))>>2]|0;
    $8 = ($6|0)==($7|0);
    if ($8) {
     $9 = (_GC_scratch_alloc(4108)|0);
     $10 = ($9|0)==(0|0);
     if ($10) {
      $$0 = 0;
      break;
     }
     HEAP32[$5>>2] = $9;
     _memset(($9|0),0,4104)|0;
     $11 = (($9) + 4104|0);
     HEAP32[$11>>2] = $3;
     $12 = HEAP32[62304>>2]|0;
     $13 = ($12|0)==(0|0);
     L7: do {
      if ($13) {
       $pi$0$lcssa$i = 0;$prev$0$lcssa$i = 62304;
       label = 7;
      } else {
       $18 = $12;$pi$06$i = 0;$prev$05$i = 62304;
       while(1) {
        $17 = (($18) + 4104|0);
        $19 = HEAP32[$17>>2]|0;
        $20 = ($19>>>0)<($3>>>0);
        $15 = (($18) + 4096|0);
        if (!($20)) {
         break;
        }
        $14 = HEAP32[$15>>2]|0;
        $16 = ($14|0)==(0|0);
        if ($16) {
         $pi$0$lcssa$i = $18;$prev$0$lcssa$i = $15;
         label = 7;
         break L7;
        } else {
         $pi$06$i$phi = $18;$18 = $14;$prev$05$i = $15;$pi$06$i = $pi$06$i$phi;
        }
       }
       $22 = (($9) + 4100|0);
       HEAP32[$22>>2] = $pi$06$i;
       $23 = (($18) + 4100|0);
       HEAP32[$23>>2] = $9;
       $25 = $18;$prev$02$i = $prev$05$i;
      }
     } while(0);
     if ((label|0) == 7) {
      label = 0;
      $21 = (($9) + 4100|0);
      HEAP32[$21>>2] = $pi$0$lcssa$i;
      HEAP32[62312>>2] = $9;
      $25 = 0;$prev$02$i = $prev$0$lcssa$i;
     }
     $24 = (($9) + 4096|0);
     HEAP32[$24>>2] = $25;
     HEAP32[$prev$02$i>>2] = $9;
    }
    $26 = (($hbp$030) + 4194304|0);
    $27 = $26;
    $28 = ($27>>>0)<($1>>>0);
    if ($28) {
     $4 = $27;$hbp$030 = $26;
    } else {
     break L1;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $29 = (($1) + -1)|0;
 $30 = $29 >>> 22;
 $31 = ((56 + ($30<<2)|0) + 57964|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[((56 + 57960|0))>>2]|0;
 $34 = ($32|0)==($33|0);
 if ($34) {
  $35 = (_GC_scratch_alloc(4108)|0);
  $36 = ($35|0)==(0|0);
  if ($36) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$31>>2] = $35;
  _memset(($35|0),0,4104)|0;
  $37 = (($35) + 4104|0);
  HEAP32[$37>>2] = $30;
  $38 = HEAP32[62304>>2]|0;
  $39 = ($38|0)==(0|0);
  L23: do {
   if ($39) {
    $pi$0$lcssa$i4 = 0;$prev$0$lcssa$i5 = 62304;
    label = 16;
   } else {
    $44 = $38;$pi$06$i1 = 0;$prev$05$i2 = 62304;
    while(1) {
     $43 = (($44) + 4104|0);
     $45 = HEAP32[$43>>2]|0;
     $46 = ($45>>>0)<($30>>>0);
     $41 = (($44) + 4096|0);
     if (!($46)) {
      break;
     }
     $40 = HEAP32[$41>>2]|0;
     $42 = ($40|0)==(0|0);
     if ($42) {
      $pi$0$lcssa$i4 = $44;$prev$0$lcssa$i5 = $41;
      label = 16;
      break L23;
     } else {
      $pi$06$i1$phi = $44;$44 = $40;$prev$05$i2 = $41;$pi$06$i1 = $pi$06$i1$phi;
     }
    }
    $48 = (($35) + 4100|0);
    HEAP32[$48>>2] = $pi$06$i1;
    $49 = (($44) + 4100|0);
    HEAP32[$49>>2] = $35;
    $51 = $44;$prev$02$i7 = $prev$05$i2;
   }
  } while(0);
  if ((label|0) == 16) {
   $47 = (($35) + 4100|0);
   HEAP32[$47>>2] = $pi$0$lcssa$i4;
   HEAP32[62312>>2] = $35;
   $51 = 0;$prev$02$i7 = $prev$0$lcssa$i5;
  }
  $50 = (($35) + 4096|0);
  HEAP32[$50>>2] = $51;
  HEAP32[$prev$02$i7>>2] = $35;
 }
 $hbp$112 = (($h) + 4096|0);
 $52 = $hbp$112;
 $53 = ($52>>>0)<($1>>>0);
 if ($53) {
  $55 = $52;$hbp$113 = $hbp$112;
 } else {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $54 = (($55) - ($0))|0;
  $56 = $54 >> 12;
  $57 = ($56>>>0)>(4095);
  $58 = $56;
  $59 = $57 ? (4095) : $58;
  $60 = $55 >>> 12;
  $61 = $60 & 1023;
  $62 = $55 >>> 22;
  $63 = ((56 + ($62<<2)|0) + 57964|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($64) + ($61<<2)|0);
  HEAP32[$65>>2] = $59;
  $hbp$1 = (($hbp$113) + 4096|0);
  $66 = $hbp$1;
  $67 = ($66>>>0)<($1>>>0);
  if ($67) {
   $55 = $66;$hbp$113 = $hbp$1;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _GC_alloc_large($lb,$k,$flags) {
 $lb = $lb|0;
 $k = $k|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0$lcssa = 0, $or$cond = 0, $result$0 = 0, $retry$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($lb) + 7)|0;
 $1 = $0 & -8;
 $2 = (($1) + 4095)|0;
 $3 = $2 >>> 12;
 $4 = HEAP32[62424>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  _GC_init();
 }
 $6 = HEAP32[62432>>2]|0;
 $7 = ($6|0)==(0);
 $8 = HEAP32[62440>>2]|0;
 $9 = ($8|0)!=(0);
 $or$cond = $7 | $9;
 if (!($or$cond)) {
  _GC_collect_a_little_inner($3);
 }
 $10 = (_GC_allochblk($1,$k,$flags)|0);
 $11 = ($10|0)==(0|0);
 L7: do {
  if ($11) {
   $12 = ($flags|0)!=(0);
   $13 = $12&1;
   $retry$04 = 0;
   while(1) {
    $14 = (_GC_collect_or_expand($3,$13,$retry$04)|0);
    $15 = ($14|0)==(0);
    if ($15) {
     $result$0 = 0;
     break;
    }
    $16 = (_GC_allochblk($1,$k,$flags)|0);
    $17 = ($16|0)==(0|0);
    if ($17) {
     $retry$04 = 1;
    } else {
     $h$0$lcssa = $16;
     break L7;
    }
   }
   STACKTOP = sp;return ($result$0|0);
  } else {
   $h$0$lcssa = $10;
  }
 } while(0);
 $18 = ($2>>>0)>(8191);
 if ($18) {
  $19 = $3 << 12;
  $20 = HEAP32[((56 + 20|0))>>2]|0;
  $21 = (($20) + ($19))|0;
  HEAP32[((56 + 20|0))>>2] = $21;
  $22 = HEAP32[((56 + 24|0))>>2]|0;
  $23 = ($21>>>0)>($22>>>0);
  if ($23) {
   HEAP32[((56 + 24|0))>>2] = $21;
  }
 }
 $result$0 = $h$0$lcssa;
 STACKTOP = sp;return ($result$0|0);
}
function _GC_collect_a_little_inner($n) {
 $n = $n|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[62440>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[62432>>2]|0;
 $3 = ($2|0)==(0);
 $4 = HEAP32[65672>>2]|0;
 $5 = ($4|0)==(0);
 $or$cond3 = $3 | $5;
 if ($or$cond3) {
  _GC_maybe_gc();
  STACKTOP = sp;return;
 }
 $6 = HEAP32[64304>>2]|0;
 $7 = ($n*10)|0;
 $8 = ($6|0)<($7|0);
 if ($8) {
  $i$05 = $6;
  while(1) {
   $11 = (_GC_mark_some(0)|0);
   $12 = ($11|0)==(0);
   $10 = (($i$05) + 1)|0;
   if (!($12)) {
    label = 6;
    break;
   }
   $9 = ($10|0)<($7|0);
   if ($9) {
    $i$05 = $10;
   } else {
    break;
   }
  }
  do {
   if ((label|0) == 6) {
    $13 = HEAP32[63968>>2]|0;
    $14 = ($13|0)<(1);
    $15 = HEAP32[63952>>2]|0;
    $16 = ($15|0)!=(999999);
    $or$cond = $14 & $16;
    if ($or$cond) {
     $17 = (_clock()|0);
     HEAP32[63960>>2] = $17;
     $18 = (_GC_stopped_mark(2)|0);
     $19 = ($18|0)==(0);
     if ($19) {
      $20 = HEAP32[63968>>2]|0;
      $21 = (($20) + 1)|0;
      HEAP32[63968>>2] = $21;
      break;
     }
    } else {
     (_GC_stopped_mark(1)|0);
    }
    _GC_finish_collection();
   }
  } while(0);
  $$pr = HEAP32[64304>>2]|0;
  $23 = $$pr;
 } else {
  $23 = $6;
 }
 $22 = ($23|0)>(0);
 if ($22) {
  $24 = (($23) - ($7))|0;
  HEAP32[64304>>2] = $24;
  $26 = $24;
 } else {
  $26 = $23;
 }
 $25 = ($26|0)<(0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 HEAP32[64304>>2] = 0;
 STACKTOP = sp;return;
}
function _GC_allochblk($sz,$kind,$flags) {
 $sz = $sz|0;
 $kind = $kind|0;
 $flags = $flags|0;
 var $$ = 0, $$$i1$i = 0, $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $bytes$02$i = 0, $n$01$i = 0, $or$cond = 0, $or$cond3 = 0;
 var $split_limit$0 = 0, $start_list$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($sz) + 4095)|0;
 $1 = ($0|0)<(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $0 >>> 12;
 $3 = ($0>>>0)<(135168);
 if ($3) {
  $$0$i = $2;
 } else {
  $4 = ($0>>>0)>(1048575);
  if ($4) {
   $$0$i = 60;
  } else {
   $5 = (($2) + -32)|0;
   $6 = (($5|0) / 8)&-1;
   $7 = (($6) + 32)|0;
   $$0$i = $7;
  }
 }
 $8 = (_GC_allochblk_nth($sz,$kind,$flags,$$0$i,0)|0);
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[62440>>2]|0;
 $11 = $10 | 0;
 $12 = ($11|0)==(0);
 L11: do {
  if ($12) {
   $13 = HEAP32[56>>2]|0;
   $14 = HEAP32[((56 + 16|0))>>2]|0;
   $15 = (($13) - ($14))|0;
   $16 = HEAP32[((56 + 4|0))>>2]|0;
   $17 = ($15>>>0)<($16>>>0);
   $18 = HEAP32[62432>>2]|0;
   $19 = ($18|0)!=(0);
   $or$cond3 = $17 | $19;
   if ($or$cond3) {
    $split_limit$0 = 60;
   } else {
    $20 = HEAP32[64072>>2]|0;
    $21 = HEAP32[63912>>2]|0;
    $22 = ($20|0)==($21|0);
    if ($22) {
     $$pre$i = HEAP32[64064>>2]|0;
     $50 = $$pre$i;
    } else {
     HEAP32[64072>>2] = $21;
     $23 = HEAP32[((56 + 3412|0))>>2]|0;
     $24 = $23 << 1;
     $25 = HEAP32[((56 + 3416|0))>>2]|0;
     $26 = $25 >>> 2;
     $27 = (($24) + 0)|0;
     $28 = (($27) + ($26))|0;
     $29 = HEAP32[63944>>2]|0;
     $30 = (($28>>>0) / ($29>>>0))&-1;
     $31 = ($30|0)!=(0);
     $32 = $31 ? $30 : 1;
     HEAP32[64064>>2] = $32;
     $50 = $32;
    }
    $33 = HEAP32[62776>>2]|0;
    $34 = HEAP32[64048>>2]|0;
    $35 = HEAP32[((56 + 32|0))>>2]|0;
    $36 = HEAP32[((56 + 36|0))>>2]|0;
    $37 = HEAP32[((56 + 44|0))>>2]|0;
    $38 = HEAP32[((56 + 48|0))>>2]|0;
    $39 = (($34) - ($33))|0;
    $40 = (($39) + ($35))|0;
    $41 = (($40) + ($36))|0;
    $42 = (($41) - ($37))|0;
    $43 = (($42) + ($38))|0;
    $44 = ($43|0)>($35|0);
    $$$i1$i = $44 ? $35 : $43;
    $45 = HEAP32[((56 + 40|0))>>2]|0;
    $46 = (($$$i1$i) + ($45))|0;
    $47 = $35 >>> 3;
    $48 = ($46|0)<($47|0);
    $$0$i$i = $48 ? $47 : $46;
    $49 = ($$0$i$i>>>0)<($50>>>0);
    $51 = HEAP32[64056>>2]|0;
    $52 = ($13>>>0)<($51>>>0);
    $or$cond = $49 & $52;
    if ($or$cond) {
     $split_limit$0 = 60;
    } else {
     $53 = $13 >>> 4;
     $54 = ($38>>>0)>($53>>>0);
     if ($54) {
      $split_limit$0 = 0;
     } else {
      $55 = HEAP32[((56 + 20|0))>>2]|0;
      $56 = HEAP32[((56 + 24|0))>>2]|0;
      $bytes$02$i = $55;$n$01$i = 60;
      while(1) {
       $59 = (63096 + ($n$01$i<<2)|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = (($60) + ($bytes$02$i))|0;
       $62 = ($61>>>0)<($56>>>0);
       if (!($62)) {
        $split_limit$0 = $n$01$i;
        break L11;
       }
       $57 = (($n$01$i) + -1)|0;
       $58 = ($n$01$i|0)>(0);
       if ($58) {
        $bytes$02$i = $61;$n$01$i = $57;
       } else {
        $split_limit$0 = 0;
        break;
       }
      }
     }
    }
   }
  } else {
   $split_limit$0 = 60;
  }
 } while(0);
 $63 = ($$0$i|0)<(32);
 $64 = $63&1;
 $$ = (($64) + ($$0$i))|0;
 $65 = ($$|0)>($split_limit$0|0);
 if ($65) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $start_list$06 = $$;
 }
 while(1) {
  $68 = (_GC_allochblk_nth($sz,$kind,$flags,$start_list$06,1)|0);
  $69 = ($68|0)==(0|0);
  if (!($69)) {
   $$0 = $68;
   label = 19;
   break;
  }
  $66 = (($start_list$06) + 1)|0;
  $67 = ($start_list$06|0)<($split_limit$0|0);
  if ($67) {
   $start_list$06 = $66;
  } else {
   $$0 = 0;
   label = 19;
   break;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _GC_collect_or_expand($needed_blocks,$ignore_off_page,$retry) {
 $needed_blocks = $needed_blocks|0;
 $ignore_off_page = $ignore_off_page|0;
 $retry = $retry|0;
 var $$ = 0, $$$i$i = 0, $$$i1$i = 0, $$0 = 0, $$0$i$i = 0, $$GC_never_stop_func = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $blocks_to_get$0 = 0, $gc_not_stopped$0 = 0, $needed_blocks$ = 0, $not$$i$i = 0, $or$cond = 0, $or$cond3 = 0, $or$cond4 = 0;
 var $or$cond6 = 0, $slop$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[62432>>2]|0;
 $1 = HEAP32[62440>>2]|0;
 $2 = $1 | $0;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $4 = (0)!=(0);
   $5 = HEAP32[((56 + 32|0))>>2]|0;
   $6 = ($5|0)!=(0);
   $or$cond3 = $4 & $6;
   do {
    if (!($or$cond3)) {
     $7 = HEAP32[65136>>2]|0;
     $8 = HEAP32[65144>>2]|0;
     $9 = (($8) + 500)|0;
     $10 = ($7>>>0)>($9>>>0);
     if ($10) {
      $11 = HEAP32[65152>>2]|0;
      $12 = HEAP32[((56 + 40|0))>>2]|0;
      $13 = $12 | $11;
      $14 = ($13|0)==(0);
      if (!($14)) {
       break;
      }
     }
     $15 = HEAP32[64072>>2]|0;
     $16 = HEAP32[63912>>2]|0;
     $17 = ($15|0)==($16|0);
     if ($17) {
      $$pre$i = HEAP32[64064>>2]|0;
      $45 = $$pre$i;
     } else {
      HEAP32[64072>>2] = $16;
      $18 = HEAP32[((56 + 3412|0))>>2]|0;
      $19 = $18 << 1;
      $20 = HEAP32[((56 + 3416|0))>>2]|0;
      $21 = $20 >>> 2;
      $22 = (($19) + 0)|0;
      $23 = (($22) + ($21))|0;
      $24 = HEAP32[63944>>2]|0;
      $25 = (($23>>>0) / ($24>>>0))&-1;
      $not$$i$i = ($0|0)!=(0);
      $26 = $not$$i$i&1;
      $$$i$i = $25 >>> $26;
      $27 = ($$$i$i|0)!=(0);
      $28 = $27 ? $$$i$i : 1;
      HEAP32[64064>>2] = $28;
      $45 = $28;
     }
     $29 = HEAP32[62776>>2]|0;
     $30 = HEAP32[64048>>2]|0;
     $31 = HEAP32[((56 + 36|0))>>2]|0;
     $32 = HEAP32[((56 + 44|0))>>2]|0;
     $33 = HEAP32[((56 + 48|0))>>2]|0;
     $34 = (($30) - ($29))|0;
     $35 = (($34) + ($5))|0;
     $36 = (($35) + ($31))|0;
     $37 = (($36) - ($32))|0;
     $38 = (($37) + ($33))|0;
     $39 = ($38|0)>($5|0);
     $$$i1$i = $39 ? $5 : $38;
     $40 = HEAP32[((56 + 40|0))>>2]|0;
     $41 = (($$$i1$i) + ($40))|0;
     $42 = $5 >>> 3;
     $43 = ($41|0)<($42|0);
     $$0$i$i = $43 ? $42 : $41;
     $44 = ($$0$i$i>>>0)<($45>>>0);
     if ($44) {
      $46 = HEAP32[56>>2]|0;
      $47 = HEAP32[64056>>2]|0;
      $48 = ($46>>>0)<($47>>>0);
      if ($48) {
       $gc_not_stopped$0 = 1;
       break L1;
      }
     }
    }
   } while(0);
   $49 = ($5|0)==(0);
   if ($49) {
    $52 = 1;
   } else {
    $50 = (0)==(0);
    $51 = ($retry|0)==(0);
    $or$cond = $50 | $51;
    $$GC_never_stop_func = $or$cond ? 1 : 1;
    $52 = $$GC_never_stop_func;
   }
   $53 = (_GC_try_to_collect_inner($52)|0);
   $54 = ($53|0)==(1);
   $55 = ($retry|0)==(0);
   $or$cond4 = $54 | $55;
   if ($or$cond4) {
    $56 = HEAP32[65136>>2]|0;
    HEAP32[65144>>2] = $56;
    $57 = HEAP32[((56 + 40|0))>>2]|0;
    HEAP32[65152>>2] = $57;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $gc_not_stopped$0 = $53;
   }
  } else {
   $gc_not_stopped$0 = 1;
  }
 } while(0);
 $58 = HEAP32[56>>2]|0;
 $59 = HEAP32[63944>>2]|0;
 $60 = $59 << 12;
 $61 = (($58>>>0) / ($60>>>0))&-1;
 $62 = (($61) + ($needed_blocks))|0;
 $63 = ($62>>>0)>(2048);
 if ($63) {
  $64 = ($ignore_off_page|0)==(0);
  if ($64) {
   $65 = HEAP32[48>>2]|0;
   $66 = $65 >>> 12;
   $67 = $66 << 1;
   $68 = ($67>>>0)>($needed_blocks>>>0);
   $needed_blocks$ = $68 ? $needed_blocks : $67;
   $slop$0 = $needed_blocks$;
  } else {
   $slop$0 = 4;
  }
  $69 = (($slop$0) + ($needed_blocks))|0;
  $70 = ($69>>>0)>(2048);
  $$ = $70 ? $69 : 2048;
  $blocks_to_get$0 = $$;
 } else {
  $blocks_to_get$0 = $62;
 }
 $71 = (_GC_expand_hp_inner($blocks_to_get$0)|0);
 $72 = ($71|0)==(0);
 if ($72) {
  $73 = (_GC_expand_hp_inner($needed_blocks)|0);
  $74 = ($73|0)==(0);
  if ($74) {
   $75 = ($gc_not_stopped$0|0)==(0);
   if ($75) {
    (_GC_try_to_collect_inner(1)|0);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $76 = HEAP32[63752>>2]|0;
   $77 = (($76) + 1)|0;
   HEAP32[63752>>2] = $77;
   $78 = HEAP32[65024>>2]|0;
   $79 = ($76>>>0)<($78>>>0);
   if ($79) {
    _GC_default_warn_proc(65160,0);
    (_GC_try_to_collect_inner(1)|0);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $80 = HEAP32[56>>2]|0;
    $81 = $80 >>> 20;
    _GC_default_warn_proc(65216,$81);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $82 = HEAP32[63752>>2]|0;
 $83 = ($82|0)==(0);
 $84 = HEAP32[62240>>2]|0;
 $85 = ($84|0)==(0);
 $or$cond6 = $83 | $85;
 if ($or$cond6) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 _GC_log_printf(65280,$vararg_buffer);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _GC_allocobj($gran,$kind) {
 $gran = $gran|0;
 $kind = $kind|0;
 var $$0 = 0, $$pr = 0, $$pr5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, $or$cond3 = 0, $or$cond4 = 0, $retry$0$ph = 0, $retry$0$ph$ph = 0, $tried_minor$0$ph$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (62448 + (($kind*20)|0)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($gran<<2)|0);
 $3 = ($gran|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ((62448 + (($kind*20)|0)|0) + 4|0);
 $retry$0$ph$ph = 0;$tried_minor$0$ph$ph = 1;
 L4: while(1) {
  $retry$0$ph = $retry$0$ph$ph;
  while(1) {
   $$pr = HEAP32[$2>>2]|0;
   $5 = ($$pr|0)==(0|0);
   if (!($5)) {
    $56 = $$pr;
    break L4;
   }
   $6 = HEAP32[62432>>2]|0;
   $7 = ($6|0)!=(0);
   $8 = HEAP32[63952>>2]|0;
   $9 = ($8|0)!=(999999);
   $or$cond = $7 & $9;
   if ($or$cond) {
    _GC_collect_a_little_inner(1);
   }
   $10 = HEAP32[$4>>2]|0;
   $11 = HEAP32[$0>>2]|0;
   $12 = (($11) + ($gran<<2)|0);
   $13 = ($10|0)==(0|0);
   L12: do {
    if (!($13)) {
     $14 = (($10) + ($gran<<2)|0);
     while(1) {
      $15 = HEAP32[$14>>2]|0;
      $16 = ($15|0)==(0|0);
      if ($16) {
       break L12;
      }
      $17 = $15;
      $18 = $17 >>> 12;
      $19 = $18 & 1023;
      $20 = $17 >>> 22;
      $21 = ((56 + ($20<<2)|0) + 57964|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($22) + ($19<<2)|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = HEAP32[$24>>2]|0;
      HEAP32[$14>>2] = $25;
      $26 = HEAP32[$21>>2]|0;
      $27 = (($26) + ($19<<2)|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($28) + 16|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($28) + 12|0);
      $32 = HEAP8[$31>>0]|0;
      $33 = $32&255;
      $34 = $30 >>> 3;
      $35 = (62448 + (($33*20)|0)|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($36) + ($34<<2)|0);
      $38 = HEAP32[63912>>2]|0;
      $39 = $38&65535;
      $40 = (($28) + 14|0);
      HEAP16[$40>>1] = $39;
      $41 = ((62448 + (($33*20)|0)|0) + 16|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = HEAP32[$37>>2]|0;
      $44 = (_GC_reclaim_generic($15,$28,$30,$42,$43,64464)|0);
      HEAP32[$37>>2] = $44;
      $45 = HEAP32[$12>>2]|0;
      $46 = ($45|0)==(0|0);
      if (!($46)) {
       break;
      }
     }
    }
   } while(0);
   $47 = HEAP32[$2>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    $56 = $47;
    break L4;
   }
   _GC_new_hblk($gran,$kind);
   $$pr5 = HEAP32[$2>>2]|0;
   $49 = ($$pr5|0)==(0|0);
   if (!($49)) {
    $56 = $$pr5;
    break L4;
   }
   $50 = HEAP32[62432>>2]|0;
   $51 = ($50|0)!=(0);
   $52 = HEAP32[63952>>2]|0;
   $53 = ($52|0)==(999999);
   $or$cond3 = $51 & $53;
   $or$cond4 = $or$cond3 & $tried_minor$0$ph$ph;
   if ($or$cond4) {
    break;
   }
   $54 = (_GC_collect_or_expand(1,0,$retry$0$ph)|0);
   $55 = ($54|0)==(0);
   if ($55) {
    $$0 = 0;
    label = 17;
    break L4;
   } else {
    $retry$0$ph = 1;
   }
  }
  _GC_collect_a_little_inner(1);
  $retry$0$ph$ph = $retry$0$ph;$tried_minor$0$ph$ph = 0;
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[63752>>2] = 0;
 $$0 = $56;
 STACKTOP = sp;return ($$0|0);
}
function _GC_generic_malloc($lb,$k) {
 $lb = $lb|0;
 $k = $k|0;
 var $$0 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $or$cond = 0, $or$cond3 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[62768>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  _GC_print_all_errors();
 }
 _GC_notify_or_invoke_finalizers();
 $2 = ($lb>>>0)<(2048);
 if ($2) {
  label = 5;
 } else {
  $3 = (2048 - 1)|0;
  $4 = ($3>>>0)<($lb>>>0);
  if ($4) {
   $6 = (($lb) + 7)|0;
   $7 = (($6) + 1)|0;
   $8 = $7 & -8;
   $9 = ($8>>>0)<($lb>>>0);
   if ($9) {
    $10 = (_GC_default_oom_fn($lb)|0);
    $$0 = $10;
    STACKTOP = sp;return ($$0|0);
   }
   $11 = (($8) + 4095)|0;
   $12 = $11 >>> 12;
   $13 = ((62448 + (($k*20)|0)|0) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (_GC_alloc_large($8,$k,0)|0);
   $16 = ($15|0)!=(0|0);
   $17 = (0)!=(0);
   $or$cond3 = $16 & $17;
   if ($or$cond3) {
    $18 = $12 << 12;
    _memset(($15|0),0,($18|0))|0;
    $23 = 0;
   } else {
    $23 = 0;
   }
   $19 = HEAP32[((56 + 32|0))>>2]|0;
   $20 = (($19) + ($8))|0;
   HEAP32[((56 + 32|0))>>2] = $20;
   $21 = ($14|0)==(0);
   $22 = ($23|0)!=(0);
   $or$cond = $21 | $22;
   $$not = $16 ^ 1;
   $brmerge = $or$cond | $$not;
   if ($brmerge) {
    $result$0 = $15;
   } else {
    $24 = $12 << 12;
    _memset(($15|0),0,($24|0))|0;
    $result$0 = $15;
   }
  } else {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $5 = (_GC_generic_malloc_inner($lb,$k)|0);
  $result$0 = $5;
 }
 $25 = ($result$0|0)==(0|0);
 if (!($25)) {
  $$0 = $result$0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = (_GC_default_oom_fn($lb)|0);
 $$0 = $26;
 STACKTOP = sp;return ($$0|0);
}
function _GC_print_all_errors() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $have_errors$0 = 0, $i$01 = 0, $leaked = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $vararg_buffer = sp;
 $leaked = sp + 8|0;
 $0 = HEAP32[66488>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[62768>>2]|0;
 HEAP32[66488>>2] = 1;
 $3 = HEAP32[66480>>2]|0;
 $4 = $3 << 2;
 _memcpy(($leaked|0),(66320|0),($4|0))|0;
 HEAP32[66480>>2] = 0;
 _memset((66320|0),0,($4|0))|0;
 $5 = (0)==(0);
 if ($5) {
  $have_errors$0 = 0;
 } else {
  abort /* segfault, call an absolute addr */ ();
  $have_errors$0 = $2;
 }
 $6 = ($3|0)==(0);
 if ($6) {
  $10 = ($have_errors$0|0)==(0);
  if (!($10)) {
   label = 8;
  }
 } else {
  HEAP32[$vararg_buffer>>2] = $3;
  _GC_err_printf(66496,$vararg_buffer);
  $i$01 = 0;
  while(1) {
   $7 = (($leaked) + ($i$01<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   _GC_default_print_heap_obj_proc($8);
   _GC_free($8);
   $9 = (($i$01) + 1)|0;
   $exitcond = ($9|0)==($3|0);
   if ($exitcond) {
    label = 8;
    break;
   } else {
    $i$01 = $9;
   }
  }
 }
 if ((label|0) == 8) {
  $11 = (_getenv((66528|0))|0);
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   _GC_default_on_abort(66552);
   _abort();
   // unreachable;
  }
 }
 HEAP32[66488>>2] = 0;
 STACKTOP = sp;return;
}
function _GC_notify_or_invoke_finalizers() {
 var $$bytes_freed_before$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bytes_freed_before$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[65448>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (0)==(0);
 if (!($2)) {
  $30 = HEAP32[65728>>2]|0;
  $31 = HEAP32[63912>>2]|0;
  $32 = ($30|0)==($31|0);
  if ($32) {
   STACKTOP = sp;return;
  }
  HEAP32[65728>>2] = $31;
  $33 = (0|0)==(0|0);
  if ($33) {
   STACKTOP = sp;return;
  }
  abort /* segfault, call an absolute addr */ ();
  STACKTOP = sp;return;
 }
 $3 = HEAP8[65656>>0]|0;
 $4 = $3&255;
 $5 = ($3<<24>>24)==(0);
 do {
  if (!($5)) {
   $6 = HEAP32[65664>>2]|0;
   $7 = (($6) + 1)|0;
   HEAP32[65664>>2] = $7;
   $8 = 1 << $4;
   $9 = ($7>>>0)<($8>>>0);
   if ($9) {
    STACKTOP = sp;return;
   } else {
    HEAP32[65664>>2] = 0;
    break;
   }
  }
 } while(0);
 $10 = (($4) + 1)|0;
 $11 = $10&255;
 HEAP8[65656>>0] = $11;
 $13 = 1;$15 = $0;$bytes_freed_before$02$i = 0;
 while(1) {
  $12 = HEAP32[((56 + 44|0))>>2]|0;
  $$bytes_freed_before$0$i = $13 ? $12 : $bytes_freed_before$02$i;
  $14 = (($15) + 4|0);
  $16 = HEAP32[$14>>2]|0;
  HEAP32[65448>>2] = $16;
  HEAP32[$14>>2] = 0;
  $17 = (($15) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$15>>2]|0;
  $20 = $19;
  $21 = (($15) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_vii[$18 & 4095]($20,$22);
  HEAP32[$21>>2] = 0;
  $23 = HEAP32[65448>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   break;
  } else {
   $13 = 0;$15 = $23;$bytes_freed_before$02$i = $$bytes_freed_before$0$i;
  }
 }
 $25 = HEAP32[((56 + 44|0))>>2]|0;
 $26 = ($$bytes_freed_before$0$i|0)==($25|0);
 if (!($26)) {
  $27 = (($25) - ($$bytes_freed_before$0$i))|0;
  $28 = HEAP32[((56 + 48|0))>>2]|0;
  $29 = (($27) + ($28))|0;
  HEAP32[((56 + 48|0))>>2] = $29;
 }
 HEAP8[65656>>0] = 0;
 STACKTOP = sp;return;
}
function _GC_malloc_atomic($lb) {
 $lb = $lb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($lb>>>0)<(2048);
 if (!($0)) {
  $1 = (2048 - 1)|0;
  $2 = ($1>>>0)<($lb>>>0);
  if ($2) {
   $13 = (_GC_generic_malloc($lb,0)|0);
   $$0 = $13;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $3 = ((56 + ($lb<<2)|0) + 3420|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((56 + ($4<<2)|0) + 1356|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (_GC_generic_malloc($lb,0)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 } else {
  $9 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $9;
  $10 = $4 << 3;
  $11 = HEAP32[((56 + 32|0))>>2]|0;
  $12 = (($11) + ($10))|0;
  HEAP32[((56 + 32|0))>>2] = $12;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _GC_malloc($lb) {
 $lb = $lb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($lb>>>0)<(2048);
 if (!($0)) {
  $1 = (2048 - 1)|0;
  $2 = ($1>>>0)<($lb>>>0);
  if ($2) {
   $13 = (_GC_generic_malloc($lb,1)|0);
   $$0 = $13;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $3 = ((56 + ($lb<<2)|0) + 3420|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((56 + ($4<<2)|0) + 328|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (_GC_generic_malloc($lb,1)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 } else {
  $9 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $9;
  HEAP32[$6>>2] = 0;
  $10 = $4 << 3;
  $11 = HEAP32[((56 + 32|0))>>2]|0;
  $12 = (($11) + ($10))|0;
  HEAP32[((56 + 32|0))>>2] = $12;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _GC_malloc_uncollectable($lb) {
 $lb = $lb|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$or$cond = 0, $notlhs = 0, $notrhs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($lb>>>0)<(2048);
 if (!($0)) {
  $1 = (2048 - 1)|0;
  $2 = ($1>>>0)<($lb>>>0);
  if ($2) {
   $16 = (_GC_generic_malloc($lb,2)|0);
   $17 = ($16|0)==(0|0);
   if ($17) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $18 = $16;
   $19 = $18 >>> 12;
   $20 = $19 & 1023;
   $21 = $18 >>> 22;
   $22 = ((56 + ($21<<2)|0) + 57964|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + ($20<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 36|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $27 | 1;
   HEAP32[$26>>2] = $28;
   $29 = (($25) + 32|0);
   HEAP32[$29>>2] = 1;
   $$0 = $16;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $notlhs = (1)!=(0);
 $notrhs = ($lb|0)!=(0);
 $not$or$cond = $notrhs & $notlhs;
 $3 = $not$or$cond << 31 >> 31;
 $$01 = (($3) + ($lb))|0;
 $4 = ((56 + ($$01<<2)|0) + 3420|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((56 + ($5<<2)|0) + 2384|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $15 = (_GC_generic_malloc($$01,2)|0);
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 } else {
  $9 = HEAP32[$7>>2]|0;
  HEAP32[$6>>2] = $9;
  HEAP32[$7>>2] = 0;
  $10 = $5 << 3;
  $11 = HEAP32[((56 + 32|0))>>2]|0;
  $12 = (($11) + ($10))|0;
  HEAP32[((56 + 32|0))>>2] = $12;
  $13 = HEAP32[62776>>2]|0;
  $14 = (($13) + ($10))|0;
  HEAP32[62776>>2] = $14;
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _GC_free($p) {
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($p|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = $p;
 $2 = $1 & -4096;
 $3 = $2;
 $4 = $1 >>> 12;
 $5 = $4 & 1023;
 $6 = $1 >>> 22;
 $7 = ((56 + ($6<<2)|0) + 57964|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($5<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 >>> 3;
 $14 = (($10) + 12|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = ($12>>>0)<(2056);
 if ($17) {
  $18 = HEAP32[((56 + 44|0))>>2]|0;
  $19 = (($18) + ($12))|0;
  HEAP32[((56 + 44|0))>>2] = $19;
  $20 = ($15<<24>>24)==(2);
  if ($20) {
   $21 = HEAP32[62776>>2]|0;
   $22 = (($21) - ($12))|0;
   HEAP32[62776>>2] = $22;
  }
  $23 = ((62448 + (($16*20)|0)|0) + 16|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0);
  if (!($25)) {
   $26 = (($p) + 4|0);
   $27 = (($12) + -4)|0;
   _memset(($26|0),0,($27|0))|0;
  }
  $28 = (62448 + (($16*20)|0)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + ($13<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$p>>2] = $31;
  HEAP32[$30>>2] = $p;
  STACKTOP = sp;return;
 } else {
  $32 = (($12) + 4095)|0;
  $33 = $32 & -4096;
  $34 = HEAP32[((56 + 44|0))>>2]|0;
  $35 = (($34) + ($12))|0;
  HEAP32[((56 + 44|0))>>2] = $35;
  $36 = ($15<<24>>24)==(2);
  if ($36) {
   $37 = HEAP32[62776>>2]|0;
   $38 = (($37) - ($12))|0;
   HEAP32[62776>>2] = $38;
  }
  $39 = ($32>>>0)>(8191);
  if ($39) {
   $40 = HEAP32[((56 + 20|0))>>2]|0;
   $41 = (($40) - ($33))|0;
   HEAP32[((56 + 20|0))>>2] = $41;
  }
  _GC_freehblk($3);
  STACKTOP = sp;return;
 }
}
function _GC_freehblk($hbp) {
 $hbp = $hbp|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i1 = 0, $$0$i$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $hbp$0$i = 0;
 var $hbp$01$i = 0, $hbp$02$i = 0, $hhdr$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = $hbp;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4095)|0;
 $11 = $10 & -4096;
 $12 = ($11|0)<(1);
 if ($12) {
  _GC_default_on_abort(63760);
  _abort();
  // unreachable;
 }
 $hbp$01$i = (($hbp) + 4096|0);
 $13 = $hbp$01$i;
 $14 = (($11) + ($0))|0;
 $15 = ($13>>>0)<($14>>>0);
 if ($15) {
  $17 = $13;$hbp$02$i = $hbp$01$i;
  while(1) {
   $16 = $17 >>> 12;
   $18 = $16 & 1023;
   $19 = $17 >>> 22;
   $20 = ((56 + ($19<<2)|0) + 57964|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($18<<2)|0);
   HEAP32[$22>>2] = 0;
   $hbp$0$i = (($hbp$02$i) + 4096|0);
   $23 = $hbp$0$i;
   $24 = ($23>>>0)<($14>>>0);
   if ($24) {
    $17 = $23;$hbp$02$i = $hbp$0$i;
   } else {
    break;
   }
  }
 }
 HEAP32[$8>>2] = $11;
 $25 = (($7) + 13|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = $27 & 4;
 $29 = ($28|0)==(0);
 if (!($29)) {
  $30 = HEAP32[62240>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   _GC_default_on_abort(63872);
   _abort();
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $hbp;
  _GC_log_printf(63824,$vararg_buffer);
  _GC_default_on_abort(63872);
  _abort();
  // unreachable;
 }
 $32 = $27 | 4;
 $33 = $32&255;
 HEAP8[$25>>0] = $33;
 $34 = (($hbp) + ($11)|0);
 $35 = $34;
 $36 = $35 >>> 12;
 $37 = $36 & 1023;
 $38 = $35 >>> 22;
 $39 = ((56 + ($38<<2)|0) + 57964|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($37<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (_GC_free_block_ending_at($hbp)|0);
 $44 = ($42|0)==(0|0);
 if ($44) {
  $104 = $11;
 } else {
  $45 = (($42) + 13|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46 & 4;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   $104 = $11;
  } else {
   $49 = (($42) + 16|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($50) + ($11))|0;
   $52 = ($51|0)>(0);
   if ($52) {
    $53 = $50 >>> 12;
    $54 = ($50>>>0)<(135168);
    if ($54) {
     $$0$i$i3 = $53;
    } else {
     $55 = ($50>>>0)>(1048575);
     if ($55) {
      $$0$i$i3 = 60;
     } else {
      $56 = (($53) + -32)|0;
      $57 = (($56|0) / 8)&-1;
      $58 = (($57) + 32)|0;
      $$0$i$i3 = $58;
     }
    }
    $59 = (($42) + 4|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==(0|0);
    if ($61) {
     $62 = HEAP32[$42>>2]|0;
     $63 = (62848 + ($$0$i$i3<<2)|0);
     HEAP32[$63>>2] = $62;
    } else {
     $64 = $60;
     $65 = $64 >>> 12;
     $66 = $65 & 1023;
     $67 = $64 >>> 22;
     $68 = ((56 + ($67<<2)|0) + 57964|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (($69) + ($66<<2)|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = HEAP32[$42>>2]|0;
     HEAP32[$71>>2] = $72;
    }
    $73 = (63096 + ($$0$i$i3<<2)|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($74) - ($50))|0;
    HEAP32[$73>>2] = $75;
    $76 = HEAP32[$42>>2]|0;
    $77 = ($76|0)==(0|0);
    if (!($77)) {
     $78 = $76;
     $79 = $78 >>> 12;
     $80 = $79 & 1023;
     $81 = $78 >>> 22;
     $82 = ((56 + ($81<<2)|0) + 57964|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (($83) + ($80<<2)|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = HEAP32[$59>>2]|0;
     $87 = (($85) + 4|0);
     HEAP32[$87>>2] = $86;
    }
    HEAP32[$8>>2] = $51;
    $88 = HEAP32[$39>>2]|0;
    $89 = (($88) + ($37<<2)|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = HEAP32[67920>>2]|0;
    HEAP32[$90>>2] = $91;
    HEAP32[67920>>2] = $90;
    HEAP32[$89>>2] = 0;
    $104 = $51;
   } else {
    $104 = $11;
   }
  }
 }
 $92 = ($43|0)==(0|0);
 if ($92) {
  $$0 = $hbp;$148 = $104;$hhdr$0 = $7;
 } else {
  $93 = $43;
  $94 = $93 >>> 12;
  $95 = $94 & 1023;
  $96 = $93 >>> 22;
  $97 = ((56 + ($96<<2)|0) + 57964|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = (($98) + ($95<<2)|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($100) + 16|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($102) + ($104))|0;
  $105 = ($103|0)>(0);
  if ($105) {
   $106 = $102 >>> 12;
   $107 = ($102>>>0)<(135168);
   if ($107) {
    $$0$i$i1 = $106;
   } else {
    $108 = ($102>>>0)>(1048575);
    if ($108) {
     $$0$i$i1 = 60;
    } else {
     $109 = (($106) + -32)|0;
     $110 = (($109|0) / 8)&-1;
     $111 = (($110) + 32)|0;
     $$0$i$i1 = $111;
    }
   }
   $112 = (($100) + 4|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)==(0|0);
   if ($114) {
    $115 = HEAP32[$100>>2]|0;
    $116 = (62848 + ($$0$i$i1<<2)|0);
    HEAP32[$116>>2] = $115;
   } else {
    $117 = $113;
    $118 = $117 >>> 12;
    $119 = $118 & 1023;
    $120 = $117 >>> 22;
    $121 = ((56 + ($120<<2)|0) + 57964|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = (($122) + ($119<<2)|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = HEAP32[$100>>2]|0;
    HEAP32[$124>>2] = $125;
   }
   $126 = (63096 + ($$0$i$i1<<2)|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($127) - ($102))|0;
   HEAP32[$126>>2] = $128;
   $129 = HEAP32[$100>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = $129;
    $132 = $131 >>> 12;
    $133 = $132 & 1023;
    $134 = $131 >>> 22;
    $135 = ((56 + ($134<<2)|0) + 57964|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($136) + ($133<<2)|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = HEAP32[$112>>2]|0;
    $140 = (($138) + 4|0);
    HEAP32[$140>>2] = $139;
   }
   HEAP32[$101>>2] = $103;
   $141 = HEAP32[$4>>2]|0;
   $142 = (($141) + ($2<<2)|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = HEAP32[67920>>2]|0;
   HEAP32[$143>>2] = $144;
   HEAP32[67920>>2] = $143;
   HEAP32[$142>>2] = 0;
   $$0 = $43;$148 = $103;$hhdr$0 = $100;
  } else {
   $$0 = $hbp;$148 = $104;$hhdr$0 = $7;
  }
 }
 $145 = HEAP32[((56 + 16|0))>>2]|0;
 $146 = (($145) + ($11))|0;
 HEAP32[((56 + 16|0))>>2] = $146;
 $147 = $148 >>> 12;
 $149 = ($148>>>0)<(135168);
 if ($149) {
  $$0$i$i = $147;
 } else {
  $150 = ($148>>>0)>(1048575);
  if ($150) {
   $$0$i$i = 60;
  } else {
   $151 = (($147) + -32)|0;
   $152 = (($151|0) / 8)&-1;
   $153 = (($152) + 32)|0;
   $$0$i$i = $153;
  }
 }
 $154 = (62848 + ($$0$i$i<<2)|0);
 $155 = HEAP32[$154>>2]|0;
 HEAP32[$154>>2] = $$0;
 $156 = (63096 + ($$0$i$i<<2)|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = (($157) + ($148))|0;
 HEAP32[$156>>2] = $158;
 HEAP32[$hhdr$0>>2] = $155;
 $159 = (($hhdr$0) + 4|0);
 HEAP32[$159>>2] = 0;
 $160 = ($155|0)==(0|0);
 if ($160) {
  $170 = (($hhdr$0) + 13|0);
  $171 = HEAP8[$170>>0]|0;
  $172 = $171&255;
  $173 = $172 | 4;
  $174 = $173&255;
  HEAP8[$170>>0] = $174;
  STACKTOP = sp;return;
 }
 $161 = $155;
 $162 = $161 >>> 12;
 $163 = $162 & 1023;
 $164 = $161 >>> 22;
 $165 = ((56 + ($164<<2)|0) + 57964|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = (($166) + ($163<<2)|0);
 $168 = HEAP32[$167>>2]|0;
 $169 = (($168) + 4|0);
 HEAP32[$169>>2] = $$0;
 $170 = (($hhdr$0) + 13|0);
 $171 = HEAP8[$170>>0]|0;
 $172 = $171&255;
 $173 = $172 | 4;
 $174 = $173&255;
 HEAP8[$170>>0] = $174;
 STACKTOP = sp;return;
}
function _GC_build_fl($h,$sz,$clear,$list) {
 $h = $h|0;
 $sz = $sz|0;
 $clear = $clear|0;
 $list = $list|0;
 var $$0$in = 0, $$c = 0, $$pn$lcssa = 0, $$pn5 = 0, $$pn5$phi = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, $p$01$i = 0, $p$01$i1 = 0, $p$01$i2 = 0, $p$01$i3 = 0, $p$04 = 0, $p$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($h) + 128|0);
 $1 = (($h) + 256|0);
 $2 = (($h) + 378|0);
 if ((($sz|0) == 2)) {
  $3 = ($clear|0)==(0);
  $4 = (($h) + 4096|0);
  $5 = $list;
  HEAP32[$h>>2] = $5;
  if ($3) {
   $19 = $h;
   $20 = (($h) + 8|0);
   HEAP32[$20>>2] = $19;
   $21 = (($h) + 16|0);
   $24 = $20;$p$01$i3 = $21;
   while(1) {
    $22 = $p$01$i3;
    $23 = $24;
    HEAP32[$p$01$i3>>2] = $23;
    $25 = (($p$01$i3) + 8|0);
    HEAP32[$25>>2] = $22;
    $26 = (($p$01$i3) + 16|0);
    $27 = ($26>>>0)<($4>>>0);
    if ($27) {
     $24 = $25;$p$01$i3 = $26;
    } else {
     $$0$in = $25;
     break;
    }
   }
   STACKTOP = sp;return ($$0$in|0);
  } else {
   $6 = (($h) + 4|0);
   HEAP32[$6>>2] = 0;
   $7 = $h;
   $8 = (($h) + 8|0);
   HEAP32[$8>>2] = $7;
   $9 = (($h) + 12|0);
   HEAP32[$9>>2] = 0;
   $10 = (($h) + 16|0);
   $13 = $8;$p$01$i = $10;
   while(1) {
    $11 = $p$01$i;
    $12 = $13;
    HEAP32[$p$01$i>>2] = $12;
    $14 = (($p$01$i) + 4|0);
    HEAP32[$14>>2] = 0;
    $15 = (($p$01$i) + 8|0);
    HEAP32[$15>>2] = $11;
    $16 = (($p$01$i) + 12|0);
    HEAP32[$16>>2] = 0;
    $17 = (($p$01$i) + 16|0);
    $18 = ($17>>>0)<($4>>>0);
    if ($18) {
     $13 = $15;$p$01$i = $17;
    } else {
     $$0$in = $15;
     break;
    }
   }
   STACKTOP = sp;return ($$0$in|0);
  }
 } else if ((($sz|0) == 4)) {
  $28 = ($clear|0)==(0);
  $29 = (($h) + 4096|0);
  $30 = $list;
  HEAP32[$h>>2] = $30;
  if ($28) {
   $43 = $h;
   $44 = (($h) + 16|0);
   HEAP32[$44>>2] = $43;
   $45 = (($h) + 32|0);
   $p$01$i1 = $45;
   while(1) {
    $46 = $p$01$i1;
    $47 = (($p$01$i1) + 256|0);
    $48 = (($p$01$i1) + -16|0);
    $49 = $48;
    HEAP32[$p$01$i1>>2] = $49;
    $50 = (($p$01$i1) + 16|0);
    HEAP32[$50>>2] = $46;
    $51 = (($p$01$i1) + 32|0);
    $52 = ($51>>>0)<($29>>>0);
    if ($52) {
     $p$01$i1 = $51;
    } else {
     $$0$in = $50;
     break;
    }
   }
   STACKTOP = sp;return ($$0$in|0);
  } else {
   $31 = (($h) + 4|0);
   HEAP32[$31>>2] = 0;
   $32 = (($h) + 8|0);
   HEAP32[$32>>2] = 0;
   $33 = (($h) + 12|0);
   HEAP32[$33>>2] = 0;
   $34 = (($h) + 16|0);
   $p$01$i2 = $34;
   while(1) {
    $35 = (($p$01$i2) + 256|0);
    $36 = (($p$01$i2) + -16|0);
    $37 = $36;
    HEAP32[$p$01$i2>>2] = $37;
    $38 = (($p$01$i2) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($p$01$i2) + 8|0);
    HEAP32[$39>>2] = 0;
    $40 = (($p$01$i2) + 12|0);
    HEAP32[$40>>2] = 0;
    $41 = (($p$01$i2) + 16|0);
    $42 = ($41>>>0)<($29>>>0);
    if ($42) {
     $p$01$i2 = $41;
    } else {
     $$0$in = $p$01$i2;
     break;
    }
   }
   STACKTOP = sp;return ($$0$in|0);
  }
 } else {
  $53 = ($clear|0)==(0);
  if (!($53)) {
   _memset(($h|0),0,4096)|0;
  }
  $54 = (($h) + 4096|0);
  $55 = (0 - ($sz))|0;
  $56 = (($54) + ($55<<2)|0);
  $p$04 = (($h) + ($sz<<2)|0);
  $57 = ($p$04>>>0)>($56>>>0);
  if ($57) {
   $$pn$lcssa = $h;
  } else {
   $$pn5 = $h;$p$06 = $p$04;
   while(1) {
    $$c = $$pn5;
    HEAP32[$p$06>>2] = $$c;
    $p$0 = (($p$06) + ($sz<<2)|0);
    $58 = ($p$0>>>0)>($56>>>0);
    if ($58) {
     $$pn$lcssa = $p$06;
     break;
    } else {
     $$pn5$phi = $p$06;$p$06 = $p$0;$$pn5 = $$pn5$phi;
    }
   }
  }
  HEAP32[$h>>2] = $list;
  $$0$in = $$pn$lcssa;
  STACKTOP = sp;return ($$0$in|0);
 }
 return 0|0;
}
function _GC_new_hblk($gran,$kind) {
 $gran = $gran|0;
 $kind = $kind|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $phitmp1$i = 0, $scevgep$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((62448 + (($kind*20)|0)|0) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (0)!=(0);
 $$ = $2 ? 1 : $1;
 $3 = $gran << 3;
 $4 = (_GC_allochblk($3,$kind,0)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ($kind|0)==(2);
 if ($6) {
  $7 = $4;
  $8 = $7 >>> 12;
  $9 = $8 & 1023;
  $10 = $7 >>> 22;
  $11 = ((56 + ($10<<2)|0) + 57964|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($9<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 16|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16>>>0)>(2048);
  if ($17) {
   $23 = 17;
   label = 5;
  } else {
   $18 = (4096 % ($16>>>0))&-1;
   $19 = (4096 - ($18))|0;
   $20 = $19 >>> 3;
   $phitmp$i = (($20) + 32)|0;
   $phitmp1$i = $phitmp$i >>> 5;
   $21 = ($phitmp1$i|0)==(0);
   if (!($21)) {
    $23 = $phitmp1$i;
    label = 5;
   }
  }
  if ((label|0) == 5) {
   $scevgep$i = (($14) + 36|0);
   $22 = $23 << 2;
   _memset(($scevgep$i|0),-1,($22|0))|0;
  }
  $24 = (4096 / ($16>>>0))&-1;
  $25 = (($14) + 32|0);
  HEAP32[$25>>2] = $24;
 }
 $26 = $gran << 1;
 $27 = (62448 + (($kind*20)|0)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + ($gran<<2)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (_GC_build_fl($4,$26,$$,$30)|0);
 $32 = HEAP32[$27>>2]|0;
 $33 = (($32) + ($gran<<2)|0);
 HEAP32[$33>>2] = $31;
 STACKTOP = sp;return;
}
function _GC_print_hblkfreelist() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond$i = 0, $h$0$i = 0, $h$01$i = 0, $h$02 = 0, $h$03$i = 0, $i$03 = 0, $i$05$i = 0;
 var $total_free$04$i = 0, $total_free$1$lcssa$i = 0, $total_free$12$i = 0, $vararg_buffer10 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer10 = sp;
 $i$03 = 0;
 while(1) {
  $0 = (62848 + ($i$03<<2)|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(0|0);
  if (!($2)) {
   $3 = (63096 + ($i$03<<2)|0);
   $4 = HEAP32[$3>>2]|0;
   HEAP32[$vararg_buffer10>>2] = $i$03;
   $vararg_ptr1 = (($vararg_buffer10) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $4;
   _GC_printf(63344,$vararg_buffer10);
   $h$02 = $1;
   while(1) {
    $5 = $h$02;
    $6 = $5 >>> 12;
    $7 = $6 & 1023;
    $8 = $5 >>> 22;
    $9 = ((56 + ($8<<2)|0) + 57964|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($7<<2)|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 16|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $6 & 262143;
    $16 = (1)==(0);
    if ($16) {
     $17 = $15 >>> 5;
     $18 = HEAP32[8>>2]|0;
     $19 = (($18) + ($17<<2)|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = $6 & 31;
     $22 = 1 << $21;
     $23 = $20 & $22;
     $24 = ($23|0)==(0);
     if ($24) {
      $25 = HEAP32[16>>2]|0;
      $26 = (($25) + ($17<<2)|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = $27 & $22;
      $29 = ($28|0)==(0);
      if ($29) {
       label = 7;
      } else {
       $50 = 63408;
      }
     } else {
      $50 = 63408;
     }
    } else {
     label = 7;
    }
    do {
     if ((label|0) == 7) {
      label = 0;
      $30 = HEAP32[24>>2]|0;
      $31 = HEAP32[32>>2]|0;
      $32 = $15 >>> 5;
      $33 = (($30) + ($32<<2)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==(0);
      if ($35) {
       $36 = (($31) + ($32<<2)|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($37|0)==(0);
       if (!($38)) {
        label = 9;
       }
      } else {
       label = 9;
      }
      if ((label|0) == 9) {
       label = 0;
       $39 = $6 & 31;
       $40 = 1 << $39;
       $41 = $40 & $34;
       $42 = ($41|0)==(0);
       if (!($42)) {
        $50 = 63408;
        break;
       }
       $43 = (($31) + ($32<<2)|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = $44 & $40;
       $46 = ($45|0)==(0);
       if (!($46)) {
        $50 = 63408;
        break;
       }
      }
      $47 = (_GC_is_black_listed($h$02,$14)|0);
      $48 = ($47|0)!=(0|0);
      $49 = $48 ? 63416 : 63432;
      $50 = $49;
     }
    } while(0);
    HEAP32[$vararg_buffer10>>2] = $h$02;
    $vararg_ptr5 = (($vararg_buffer10) + 4|0);
    HEAP32[$vararg_ptr5>>2] = $14;
    $vararg_ptr6 = (($vararg_buffer10) + 8|0);
    HEAP32[$vararg_ptr6>>2] = $50;
    _GC_printf(63376,$vararg_buffer10);
    $51 = HEAP32[$12>>2]|0;
    $52 = ($51|0)==(0|0);
    if ($52) {
     break;
    } else {
     $h$02 = $51;
    }
   }
  }
  $53 = (($i$03) + 1)|0;
  $exitcond = ($53|0)==(61);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $53;
  }
 }
 $54 = HEAP32[((56 + 16|0))>>2]|0;
 HEAP32[$vararg_buffer10>>2] = $54;
 _GC_printf(63440,$vararg_buffer10);
 $i$05$i = 0;$total_free$04$i = 0;
 while(1) {
  $55 = (62848 + ($i$05$i<<2)|0);
  $h$01$i = HEAP32[$55>>2]|0;
  $56 = ($h$01$i|0)==(0|0);
  if ($56) {
   $total_free$1$lcssa$i = $total_free$04$i;
  } else {
   $h$03$i = $h$01$i;$total_free$12$i = $total_free$04$i;
   while(1) {
    $57 = $h$03$i;
    $58 = $57 >>> 12;
    $59 = $58 & 1023;
    $60 = $57 >>> 22;
    $61 = ((56 + ($60<<2)|0) + 57964|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($62) + ($59<<2)|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($64) + 16|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($66) + ($total_free$12$i))|0;
    $h$0$i = HEAP32[$64>>2]|0;
    $68 = ($h$0$i|0)==(0|0);
    if ($68) {
     $total_free$1$lcssa$i = $67;
     break;
    } else {
     $h$03$i = $h$0$i;$total_free$12$i = $67;
    }
   }
  }
  $69 = (($i$05$i) + 1)|0;
  $exitcond$i = ($69|0)==(61);
  if ($exitcond$i) {
   break;
  } else {
   $i$05$i = $69;$total_free$04$i = $total_free$1$lcssa$i;
  }
 }
 $70 = HEAP32[((56 + 16|0))>>2]|0;
 $71 = ($total_free$1$lcssa$i|0)==($70|0);
 if ($71) {
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer10>>2] = $total_free$1$lcssa$i;
 _GC_err_printf(63472,$vararg_buffer10);
 STACKTOP = sp;return;
}
function _GC_printf($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $buf = 0, $bytes_written$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $buf = sp + 16|0;
 $args = sp;
 $0 = (0)==(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 HEAP32[$args>>2] = $varargs;
 $1 = (($buf) + 1024|0);
 HEAP8[$1>>0] = 21;
 (_vsnprintf($buf,1024,$format,$args)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(21);
 if (!($3)) {
  _GC_default_on_abort(67560);
  _abort();
  // unreachable;
 }
 $4 = (_strlen(($buf|0))|0);
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $bytes_written$01$i = 0;
 }
 while(1) {
  $8 = (($buf) + ($bytes_written$01$i)|0);
  $9 = (($4) - ($bytes_written$01$i))|0;
  $10 = (_write(1,($8|0),($9|0))|0);
  $11 = ($10|0)==(-1);
  $7 = (($10) + ($bytes_written$01$i))|0;
  if ($11) {
   label = 8;
   break;
  }
  $6 = ($7>>>0)<($4>>>0);
  if ($6) {
   $bytes_written$01$i = $7;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  _GC_default_on_abort(67592);
  _abort();
  // unreachable;
 }
 $12 = ($7|0)<(0);
 if ($12) {
  _GC_default_on_abort(67592);
  _abort();
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function _GC_free_block_ending_at($h) {
 $h = $h|0;
 var $$0 = 0, $$lcssa = 0, $$p$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $bi$0$i = 0, $bi$07$i = 0, $bi$08$i = 0, $bi$15$i = 0, $j$04$i = 0, $j$1$be$i = 0, $j$12$i = 0, $or$cond = 0, $or$cond6 = 0;
 var $p$0$lcssa = 0, $p$07 = 0, $phdr$0 = 0, $phdr$0$lcssa = 0, $phdr$05 = 0, $phdr$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($h) + -4096|0);
 $1 = $0;
 $2 = $1 >>> 12;
 $3 = $2 & 1023;
 $4 = $1 >>> 22;
 $5 = ((56 + ($4<<2)|0) + 57964|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($3<<2)|0);
 $phdr$05 = HEAP32[$7>>2]|0;
 $8 = ($phdr$05|0)!=(0|0);
 $9 = ($phdr$05>>>0)<((4096)>>>0);
 $or$cond6 = $8 & $9;
 if ($or$cond6) {
  $p$07 = $0;$phdr$08 = $phdr$05;
  while(1) {
   $10 = $phdr$08;
   $11 = (0 - ($10))|0;
   $12 = (($p$07) + ($11<<12)|0);
   $13 = $12;
   $14 = $13 >>> 12;
   $15 = $14 & 1023;
   $16 = $13 >>> 22;
   $17 = ((56 + ($16<<2)|0) + 57964|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + ($15<<2)|0);
   $phdr$0 = HEAP32[$19>>2]|0;
   $20 = ($phdr$0|0)!=(0|0);
   $21 = ($phdr$0>>>0)<((4096)>>>0);
   $or$cond = $20 & $21;
   if ($or$cond) {
    $p$07 = $12;$phdr$08 = $phdr$0;
   } else {
    $$lcssa = $20;$p$0$lcssa = $12;$phdr$0$lcssa = $phdr$0;
    break;
   }
  }
 } else {
  $$lcssa = $8;$p$0$lcssa = $0;$phdr$0$lcssa = $phdr$05;
 }
 if ($$lcssa) {
  $22 = (($phdr$0$lcssa) + 13|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23 & 4;
  $25 = ($24<<24>>24)==(0);
  $$p$0 = $25 ? 0 : $p$0$lcssa;
  $$0 = $$p$0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = HEAP32[((56 + 57960|0))>>2]|0;
 $27 = ($6|0)==($26|0);
 L9: do {
  if ($27) {
   $bi$07$i = HEAP32[62312>>2]|0;
   $28 = ($bi$07$i|0)==(0|0);
   if (!($28)) {
    $bi$08$i = $bi$07$i;
    while(1) {
     $31 = (($bi$08$i) + 4104|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32>>>0)>($4>>>0);
     if (!($33)) {
      $bi$15$i = $bi$08$i;$j$04$i = 1023;
      label = 10;
      break L9;
     }
     $29 = (($bi$08$i) + 4100|0);
     $bi$0$i = HEAP32[$29>>2]|0;
     $30 = ($bi$0$i|0)==(0|0);
     if ($30) {
      break;
     } else {
      $bi$08$i = $bi$0$i;
     }
    }
   }
  } else {
   $34 = ($6|0)==(0|0);
   if (!($34)) {
    $bi$15$i = $6;$j$04$i = $3;
    label = 10;
   }
  }
 } while(0);
 L15: do {
  if ((label|0) == 10) {
   L16: while(1) {
    label = 0;
    $j$12$i = $j$04$i;
    while(1) {
     $35 = (($bi$15$i) + ($j$12$i<<2)|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      $38 = (($j$12$i) + -1)|0;
      $j$1$be$i = $38;
     } else {
      $39 = ($36>>>0)<((4096)>>>0);
      if (!($39)) {
       break L16;
      }
      $40 = $36;
      $41 = (($j$12$i) - ($40))|0;
      $j$1$be$i = $41;
     }
     $42 = ($j$1$be$i|0)>(-1);
     if ($42) {
      $j$12$i = $j$1$be$i;
     } else {
      break;
     }
    }
    $43 = (($bi$15$i) + 4100|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     break L15;
    } else {
     $bi$15$i = $44;$j$04$i = 1023;
     label = 10;
    }
   }
   $46 = (($bi$15$i) + 4104|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 << 10;
   $49 = (($48) + ($j$12$i))|0;
   $50 = $49 << 12;
   $51 = $50;
   $52 = ($50|0)==(0);
   if (!($52)) {
    $53 = $49 & 1023;
    $54 = $49 >>> 10;
    $55 = $54 & 1023;
    $56 = ((56 + ($55<<2)|0) + 57964|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($57) + ($53<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($59) + 13|0);
    $61 = HEAP8[$60>>0]|0;
    $62 = $61 & 4;
    $63 = ($62<<24>>24)==(0);
    if (!($63)) {
     $64 = (($59) + 16|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (($51) + ($65)|0);
     $67 = ($66|0)==($h|0);
     if ($67) {
      $$0 = $51;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GC_get_first_part($h,$hhdr,$bytes,$index) {
 $h = $h|0;
 $hhdr = $hhdr|0;
 $bytes = $bytes|0;
 $index = $index|0;
 var $$0 = 0, $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hhdr) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($hhdr) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = HEAP32[$hhdr>>2]|0;
  $6 = (62848 + ($index<<2)|0);
  HEAP32[$6>>2] = $5;
 } else {
  $7 = $3;
  $8 = $7 >>> 12;
  $9 = $8 & 1023;
  $10 = $7 >>> 22;
  $11 = ((56 + ($10<<2)|0) + 57964|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($9<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$hhdr>>2]|0;
  HEAP32[$14>>2] = $15;
 }
 $16 = (63096 + ($index<<2)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) - ($1))|0;
 HEAP32[$16>>2] = $18;
 $19 = HEAP32[$hhdr>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = $19;
  $22 = $21 >>> 12;
  $23 = $22 & 1023;
  $24 = $21 >>> 22;
  $25 = ((56 + ($24<<2)|0) + 57964|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($23<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$2>>2]|0;
  $30 = (($28) + 4|0);
  HEAP32[$30>>2] = $29;
 }
 $31 = ($1|0)==($bytes|0);
 if ($31) {
  $$0 = $h;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = $h;
 $33 = (($32) + ($bytes))|0;
 $34 = $33;
 $35 = (_GC_install_header($34)|0);
 $36 = ($35|0)==(0|0);
 if ($36) {
  _GC_default_warn_proc(63544,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = (($1) - ($bytes))|0;
 $38 = (($35) + 16|0);
 HEAP32[$38>>2] = $37;
 $39 = (($35) + 13|0);
 HEAP8[$39>>0] = 0;
 $40 = $37 >>> 12;
 $41 = ($37>>>0)<(135168);
 if ($41) {
  $$0$i$i = $40;
 } else {
  $42 = ($37>>>0)>(1048575);
  if ($42) {
   $$0$i$i = 60;
  } else {
   $43 = (($40) + -32)|0;
   $44 = (($43|0) / 8)&-1;
   $45 = (($44) + 32)|0;
   $$0$i$i = $45;
  }
 }
 $46 = (62848 + ($$0$i$i<<2)|0);
 $47 = HEAP32[$46>>2]|0;
 HEAP32[$46>>2] = $34;
 $48 = (63096 + ($$0$i$i<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + ($37))|0;
 HEAP32[$48>>2] = $50;
 HEAP32[$35>>2] = $47;
 $51 = (($35) + 4|0);
 HEAP32[$51>>2] = 0;
 $52 = ($47|0)==(0|0);
 if (!($52)) {
  $53 = $47;
  $54 = $53 >>> 12;
  $55 = $54 & 1023;
  $56 = $53 >>> 22;
  $57 = ((56 + ($56<<2)|0) + 57964|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + ($55<<2)|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 4|0);
  HEAP32[$61>>2] = $34;
 }
 $62 = HEAP8[$39>>0]|0;
 $63 = $62&255;
 $64 = $63 | 4;
 $65 = $64&255;
 HEAP8[$39>>0] = $65;
 $$0 = $h;
 STACKTOP = sp;return ($$0|0);
}
function _GC_split_block($h,$hhdr,$n,$nhdr,$index) {
 $h = $h|0;
 $hhdr = $hhdr|0;
 $n = $n|0;
 $nhdr = $nhdr|0;
 $index = $index|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hhdr) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $n;
 $3 = $h;
 $4 = (($2) - ($3))|0;
 $5 = (($hhdr) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$hhdr>>2]|0;
 $8 = (($nhdr) + 4|0);
 HEAP32[$8>>2] = $6;
 HEAP32[$nhdr>>2] = $7;
 $9 = (($1) - ($4))|0;
 $10 = (($nhdr) + 16|0);
 HEAP32[$10>>2] = $9;
 $11 = (($nhdr) + 13|0);
 HEAP8[$11>>0] = 0;
 $12 = ($6|0)==(0|0);
 if ($12) {
  $21 = (62848 + ($index<<2)|0);
  HEAP32[$21>>2] = $n;
 } else {
  $13 = $6;
  $14 = $13 >>> 12;
  $15 = $14 & 1023;
  $16 = $13 >>> 22;
  $17 = ((56 + ($16<<2)|0) + 57964|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($15<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$20>>2] = $n;
 }
 $22 = ($7|0)==(0|0);
 if (!($22)) {
  $23 = $7;
  $24 = $23 >>> 12;
  $25 = $24 & 1023;
  $26 = $23 >>> 22;
  $27 = ((56 + ($26<<2)|0) + 57964|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + ($25<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 4|0);
  HEAP32[$31>>2] = $n;
 }
 $32 = (63096 + ($index<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) - ($4))|0;
 HEAP32[$32>>2] = $34;
 HEAP32[$0>>2] = $4;
 $35 = $4 >>> 12;
 $36 = ($4>>>0)<(135168);
 if ($36) {
  $$0$i$i = $35;
 } else {
  $37 = ($4>>>0)>(1048575);
  if ($37) {
   $$0$i$i = 60;
  } else {
   $38 = (($35) + -32)|0;
   $39 = (($38|0) / 8)&-1;
   $40 = (($39) + 32)|0;
   $$0$i$i = $40;
  }
 }
 $41 = (62848 + ($$0$i$i<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 HEAP32[$41>>2] = $h;
 $43 = (63096 + ($$0$i$i<<2)|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + ($4))|0;
 HEAP32[$43>>2] = $45;
 HEAP32[$hhdr>>2] = $42;
 HEAP32[$5>>2] = 0;
 $46 = ($42|0)==(0|0);
 if ($46) {
  $56 = (($hhdr) + 13|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57&255;
  $59 = $58 | 4;
  $60 = $59&255;
  HEAP8[$56>>0] = $60;
  $61 = HEAP8[$11>>0]|0;
  $62 = $61&255;
  $63 = $62 | 4;
  $64 = $63&255;
  HEAP8[$11>>0] = $64;
  STACKTOP = sp;return;
 }
 $47 = $42;
 $48 = $47 >>> 12;
 $49 = $48 & 1023;
 $50 = $47 >>> 22;
 $51 = ((56 + ($50<<2)|0) + 57964|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + ($49<<2)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 4|0);
 HEAP32[$55>>2] = $h;
 $56 = (($hhdr) + 13|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = $57&255;
 $59 = $58 | 4;
 $60 = $59&255;
 HEAP8[$56>>0] = $60;
 $61 = HEAP8[$11>>0]|0;
 $62 = $61&255;
 $63 = $62 | 4;
 $64 = $63&255;
 HEAP8[$11>>0] = $64;
 STACKTOP = sp;return;
}
function _GC_allochblk_nth($sz,$kind,$flags,$n,$may_split) {
 $sz = $sz|0;
 $kind = $kind|0;
 $flags = $flags|0;
 $n = $n|0;
 $may_split = $may_split|0;
 var $$$i = 0, $$$i4 = 0, $$0 = 0, $$granules$i = 0, $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $displ$01$i = 0, $displ$01$i8 = 0, $displ$14$i = 0, $exitcond$i = 0, $exitcond$i9 = 0, $exitcond5$i = 0, $h$018 = 0, $hbp$0 = 0, $hbp$0$i = 0, $hbp$01$i = 0, $hbp$02$i = 0, $hbp$021 = 0, $hbp$02126 = 0, $hbp$022 = 0, $hbp$1 = 0, $hhdr$017 = 0, $hhdr$1 = 0, $hhdr$2 = 0, $hhdr$3 = 0;
 var $lasthbp$0 = 0, $or$cond = 0, $or$cond2 = 0, $or$cond34 = 0, $phitmp = 0, $phitmp33 = 0, $size_avail$0 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (($sz) + 4095)|0;
 $1 = $0 & -4096;
 $2 = (62848 + ($n<<2)|0);
 $hbp$02126 = HEAP32[$2>>2]|0;
 $3 = ($hbp$02126|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = $flags & 1;
 $5 = ($4|0)!=(0);
 $6 = $5 ? 4096 : $1;
 $7 = ($1|0)!=(4096);
 $8 = (63096 + ($n<<2)|0);
 $9 = ($1|0)>(8192);
 $10 = ($may_split|0)==(0);
 $hbp$022 = $hbp$02126;
 L4: while(1) {
  $12 = $hbp$022;
  $13 = $12 >>> 12;
  $14 = $13 & 1023;
  $15 = $12 >>> 22;
  $16 = ((56 + ($15<<2)|0) + 57964|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($14<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 16|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)<($1|0);
  do {
   if ($22) {
    $hhdr$3 = $19;
   } else {
    $23 = ($21|0)==($1|0);
    if (!($23)) {
     if ($10) {
      $hhdr$3 = $19;
      break;
     }
     $24 = HEAP32[$19>>2]|0;
     $25 = ($24|0)==(0|0);
     if (!($25)) {
      $26 = $24;
      $27 = $26 >>> 12;
      $28 = $27 & 1023;
      $29 = $26 >>> 22;
      $30 = ((56 + ($29<<2)|0) + 57964|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($31) + ($28<<2)|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($33) + 16|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)>=($21|0);
      $37 = ($35|0)<($1|0);
      $or$cond2 = $36 | $37;
      if (!($or$cond2)) {
       $38 = (_GC_is_black_listed($24,$1)|0);
       $39 = ($38|0)==(0|0);
       if ($39) {
        $hhdr$3 = $19;
        break;
       }
      }
     }
    }
    if ((($kind|0) == 2)) {
     $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = $21;
    } else if ((($kind|0) == 0)) {
     if ($9) {
      label = 12;
     } else {
      $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = $21;
     }
    } else {
     label = 12;
    }
    do {
     if ((label|0) == 12) {
      label = 0;
      $$sum = (($21) - ($1))|0;
      $40 = (($hbp$022) + ($$sum)|0);
      $lasthbp$0 = $hbp$022;
      while(1) {
       $41 = ($lasthbp$0>>>0)>($40>>>0);
       if ($41) {
        break;
       }
       $42 = (_GC_is_black_listed($lasthbp$0,$6)|0);
       $43 = ($42|0)==(0|0);
       if ($43) {
        break;
       } else {
        $lasthbp$0 = $42;
       }
      }
      $44 = $lasthbp$0;
      $45 = (($12) - ($44))|0;
      $46 = (($45) + ($21))|0;
      $47 = ($46|0)<($1|0);
      if (!($47)) {
       $48 = ($lasthbp$0|0)==($hbp$022|0);
       if ($48) {
        $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = $46;
        break;
       }
       $49 = (_GC_install_header($lasthbp$0)|0);
       $50 = ($49|0)==(0|0);
       if ($50) {
        $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = $46;
        break;
       }
       _GC_split_block($hbp$022,$19,$lasthbp$0,$49,$n);
       $hbp$1 = $lasthbp$0;$hhdr$2 = $49;$size_avail$0 = $46;
       break;
      }
      $51 = HEAP32[48>>2]|0;
      $52 = ($1|0)>($51|0);
      $53 = ($$sum|0)>($51|0);
      $or$cond34 = $52 & $53;
      if ($or$cond34) {
       $54 = HEAP32[63600>>2]|0;
       $55 = (($54) + 1)|0;
       HEAP32[63600>>2] = $55;
       $56 = HEAP32[63608>>2]|0;
       $57 = ($55|0)<($56|0);
       if ($57) {
        $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = $21;
        break;
       }
       _GC_default_warn_proc(63616,$1);
       HEAP32[63600>>2] = 0;
       $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = $21;
       break;
      }
      $58 = ($46|0)==(0);
      if ($58) {
       $59 = HEAP32[63736>>2]|0;
       $60 = ($59|0)!=(0);
       $or$cond = $7 | $60;
       if ($or$cond) {
        $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = 0;
       } else {
        $61 = HEAP32[63744>>2]|0;
        $62 = (($61) + 1)|0;
        HEAP32[63744>>2] = $62;
        $63 = $62 & 3;
        $64 = ($63|0)==(0);
        if ($64) {
         $65 = HEAP32[$20>>2]|0;
         $66 = $65 >>> 12;
         $67 = (($hbp$022) + ($66<<12)|0);
         $68 = (($19) + 4|0);
         $69 = HEAP32[$68>>2]|0;
         $70 = HEAP32[((56 + 16|0))>>2]|0;
         $71 = (($70) - ($65))|0;
         HEAP32[((56 + 16|0))>>2] = $71;
         $72 = HEAP32[((56 + 36|0))>>2]|0;
         $73 = (($72) + ($65))|0;
         HEAP32[((56 + 36|0))>>2] = $73;
         $74 = ($69|0)==(0|0);
         if ($74) {
          $75 = HEAP32[$19>>2]|0;
          HEAP32[$2>>2] = $75;
         } else {
          $76 = $69;
          $77 = $76 >>> 12;
          $78 = $77 & 1023;
          $79 = $76 >>> 22;
          $80 = ((56 + ($79<<2)|0) + 57964|0);
          $81 = HEAP32[$80>>2]|0;
          $82 = (($81) + ($78<<2)|0);
          $83 = HEAP32[$82>>2]|0;
          $84 = HEAP32[$19>>2]|0;
          HEAP32[$83>>2] = $84;
         }
         $85 = HEAP32[$8>>2]|0;
         $86 = (($85) - ($65))|0;
         HEAP32[$8>>2] = $86;
         $87 = HEAP32[$19>>2]|0;
         $88 = ($87|0)==(0|0);
         if (!($88)) {
          $89 = $87;
          $90 = $89 >>> 12;
          $91 = $90 & 1023;
          $92 = $89 >>> 22;
          $93 = ((56 + ($92<<2)|0) + 57964|0);
          $94 = HEAP32[$93>>2]|0;
          $95 = (($94) + ($91<<2)|0);
          $96 = HEAP32[$95>>2]|0;
          $97 = HEAP32[$68>>2]|0;
          $98 = (($96) + 4|0);
          HEAP32[$98>>2] = $97;
         }
         $99 = ($66|0)==(0);
         if (!($99)) {
          $h$018 = $hbp$022;$hhdr$017 = $19;
          while(1) {
           $100 = ($h$018|0)==($hbp$022|0);
           if ($100) {
            $hhdr$1 = $hhdr$017;
           } else {
            $101 = (_GC_install_header($h$018)|0);
            $hhdr$1 = $101;
           }
           $102 = ($hhdr$1|0)==(0|0);
           do {
            if (!($102)) {
             $103 = (($hhdr$1) + 16|0);
             HEAP32[$103>>2] = 4096;
             $104 = (($hhdr$1) + 12|0);
             HEAP8[$104>>0] = 0;
             $105 = (($hhdr$1) + 13|0);
             HEAP8[$105>>0] = 0;
             $106 = (($hhdr$1) + 8|0);
             HEAP32[$106>>2] = $h$018;
             $107 = HEAP32[((62448 + 8|0))>>2]|0;
             $108 = HEAP32[((62448 + 12|0))>>2]|0;
             $109 = ($108|0)==(0);
             $110 = $109 ? 0 : 4096;
             $$$i = (($110) + ($107))|0;
             $111 = (($hhdr$1) + 20|0);
             HEAP32[$111>>2] = $$$i;
             $112 = (($hhdr$1) + 24|0);
             HEAP8[$112>>0] = 1;
             $113 = HEAP32[((56 + 11616|0))>>2]|0;
             $114 = ($113|0)==(0|0);
             do {
              if ($114) {
               $117 = (_GC_scratch_alloc(1024)|0);
               $118 = ($117|0)==(0|0);
               if ($118) {
                HEAP32[$103>>2] = 4096;
                HEAP32[$111>>2] = 0;
                HEAP8[$112>>0] = 1;
                $123 = (($hhdr$1) + 28|0);
                HEAP32[$123>>2] = 0;
                break;
               }
               $119 = HEAP32[62240>>2]|0;
               $120 = ($119|0)==(0);
               if ($120) {
                $displ$01$i = 0;
               } else {
                HEAP32[$vararg_buffer2>>2] = 0;
                $vararg_ptr1 = (($vararg_buffer2) + 4|0);
                HEAP32[$vararg_ptr1>>2] = 0;
                _GC_log_printf(62784,$vararg_buffer2);
                $displ$01$i = 0;
               }
               while(1) {
                $121 = (($117) + ($displ$01$i<<1)|0);
                HEAP16[$121>>1] = 1;
                $122 = (($displ$01$i) + 1)|0;
                $exitcond$i = ($122|0)==(512);
                if ($exitcond$i) {
                 break;
                } else {
                 $displ$01$i = $122;
                }
               }
               HEAP32[((56 + 11616|0))>>2] = $117;
               $$pre = HEAP8[$112>>0]|0;
               $$pre28 = HEAP32[$103>>2]|0;
               $phitmp = ($$pre<<24>>24)!=(0);
               $phitmp33 = $phitmp ? 0 : 512;
               $124 = ((56 + ($phitmp33<<2)|0) + 11616|0);
               $125 = HEAP32[$124>>2]|0;
               $126 = (($hhdr$1) + 28|0);
               HEAP32[$126>>2] = $125;
               $127 = ($$pre28>>>0)>(2048);
               if ($127) {
                $133 = 512;
                label = 43;
                break;
               }
               $128 = (4096 % ($$pre28>>>0))&-1;
               $129 = (4096 - ($128))|0;
               $130 = $129 >>> 3;
               $133 = $130;
               label = 43;
              } else {
               $115 = HEAP32[((56 + 11616|0))>>2]|0;
               $116 = (($hhdr$1) + 28|0);
               HEAP32[$116>>2] = $115;
               $133 = 512;
               label = 43;
              }
             } while(0);
             if ((label|0) == 43) {
              label = 0;
              $131 = (($hhdr$1) + 36|0);
              dest=$131+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
              $132 = $133 & 31;
              $134 = 1 << $132;
              $135 = $133 >>> 5;
              $136 = ((($hhdr$1) + ($135<<2)|0) + 36|0);
              $137 = HEAP32[$136>>2]|0;
              $138 = $137 | $134;
              HEAP32[$136>>2] = $138;
              $139 = (($hhdr$1) + 32|0);
              HEAP32[$139>>2] = 0;
              $140 = HEAP32[63912>>2]|0;
              $141 = $140&65535;
              $142 = (($hhdr$1) + 14|0);
              HEAP16[$142>>1] = $141;
             }
             $143 = (0)==(0);
             if ($143) {
              break;
             }
             _memset(($h$018|0),0,4096)|0;
            }
           } while(0);
           $144 = (($h$018) + 4096|0);
           $145 = ($144>>>0)<($67>>>0);
           if ($145) {
            $h$018 = $144;$hhdr$017 = $hhdr$1;
           } else {
            break;
           }
          }
         }
         if ($74) {
          $hbp$021 = HEAP32[$2>>2]|0;
          $11 = ($hbp$021|0)==(0|0);
          if ($11) {
           $$0 = 0;
           label = 66;
           break L4;
          } else {
           $hbp$022 = $hbp$021;
           continue L4;
          }
         } else {
          $146 = $69;
          $147 = $146 >>> 12;
          $148 = $147 & 1023;
          $149 = $146 >>> 22;
          $150 = ((56 + ($149<<2)|0) + 57964|0);
          $151 = HEAP32[$150>>2]|0;
          $152 = (($151) + ($148<<2)|0);
          $153 = HEAP32[$152>>2]|0;
          $hbp$1 = $69;$hhdr$2 = $153;$size_avail$0 = 0;
          break;
         }
        } else {
         $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = 0;
        }
       }
      } else {
       $hbp$1 = $hbp$022;$hhdr$2 = $19;$size_avail$0 = $46;
      }
     }
    } while(0);
    $154 = ($size_avail$0|0)<($1|0);
    if ($154) {
     $hhdr$3 = $hhdr$2;
    } else {
     label = 50;
     break L4;
    }
   }
  } while(0);
  $hbp$0 = HEAP32[$hhdr$3>>2]|0;
  $157 = ($hbp$0|0)==(0|0);
  if ($157) {
   $$0 = 0;
   label = 66;
   break;
  } else {
   $hbp$022 = $hbp$0;
  }
 }
 if ((label|0) == 50) {
  $155 = (_GC_get_first_part($hbp$1,$hhdr$2,$1,$n)|0);
  $156 = ($155|0)==(0|0);
  if ($156) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $158 = (_GC_install_counts($155,$1)|0);
  $159 = ($158|0)==(0);
  if ($159) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $160 = (($hhdr$2) + 16|0);
  HEAP32[$160>>2] = $sz;
  $161 = $kind&255;
  $162 = (($hhdr$2) + 12|0);
  HEAP8[$162>>0] = $161;
  $163 = $flags&255;
  $164 = (($hhdr$2) + 13|0);
  HEAP8[$164>>0] = $163;
  $165 = (($hhdr$2) + 8|0);
  HEAP32[$165>>2] = $155;
  $166 = ((62448 + (($kind*20)|0)|0) + 8|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = ((62448 + (($kind*20)|0)|0) + 12|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = ($169|0)==(0);
  $171 = $170 ? 0 : $sz;
  $$$i4 = (($171) + ($167))|0;
  $172 = (($hhdr$2) + 20|0);
  HEAP32[$172>>2] = $$$i4;
  $173 = ($sz>>>0)>(2048);
  $174 = $173&1;
  $175 = (($hhdr$2) + 24|0);
  HEAP8[$175>>0] = $174;
  $176 = $sz >>> 3;
  $177 = ($sz>>>0)>(2055);
  $$granules$i = $177 ? 0 : $176;
  $178 = ((56 + ($$granules$i<<2)|0) + 11616|0);
  $179 = HEAP32[$178>>2]|0;
  $180 = ($179|0)==(0|0);
  if ($180) {
   $181 = (_GC_scratch_alloc(1024)|0);
   $182 = ($181|0)==(0|0);
   if ($182) {
    HEAP32[$160>>2] = 4096;
    HEAP32[$172>>2] = 0;
    HEAP8[$175>>0] = 1;
    $204 = (($hhdr$2) + 28|0);
    HEAP32[$204>>2] = 0;
    $hbp$01$i = (($155) + 4096|0);
    $205 = $hbp$01$i;
    $206 = $155;
    $207 = (($206) + ($1))|0;
    $208 = ($205>>>0)<($207>>>0);
    if ($208) {
     $210 = $205;$hbp$02$i = $hbp$01$i;
    } else {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    while(1) {
     $209 = $210 >>> 12;
     $211 = $209 & 1023;
     $212 = $210 >>> 22;
     $213 = ((56 + ($212<<2)|0) + 57964|0);
     $214 = HEAP32[$213>>2]|0;
     $215 = (($214) + ($211<<2)|0);
     HEAP32[$215>>2] = 0;
     $hbp$0$i = (($hbp$02$i) + 4096|0);
     $216 = $hbp$0$i;
     $217 = ($216>>>0)<($207>>>0);
     if ($217) {
      $210 = $216;$hbp$02$i = $hbp$0$i;
     } else {
      $$0 = 0;
      break;
     }
    }
    STACKTOP = sp;return ($$0|0);
   }
   $183 = HEAP32[62240>>2]|0;
   $184 = ($183|0)==(0);
   if (!($184)) {
    $185 = $$granules$i << 3;
    HEAP32[$vararg_buffer2>>2] = $$granules$i;
    $vararg_ptr5 = (($vararg_buffer2) + 4|0);
    HEAP32[$vararg_ptr5>>2] = $185;
    _GC_log_printf(62784,$vararg_buffer2);
   }
   $186 = ($$granules$i|0)==(0);
   if ($186) {
    $displ$01$i8 = 0;
    while(1) {
     $187 = (($181) + ($displ$01$i8<<1)|0);
     HEAP16[$187>>1] = 1;
     $188 = (($displ$01$i8) + 1)|0;
     $exitcond$i9 = ($188|0)==(512);
     if ($exitcond$i9) {
      break;
     } else {
      $displ$01$i8 = $188;
     }
    }
   } else {
    $displ$14$i = 0;
    while(1) {
     $189 = (($displ$14$i>>>0) % ($176>>>0))&-1;
     $190 = $189&65535;
     $191 = (($181) + ($displ$14$i<<1)|0);
     HEAP16[$191>>1] = $190;
     $192 = (($displ$14$i) + 1)|0;
     $exitcond5$i = ($192|0)==(512);
     if ($exitcond5$i) {
      break;
     } else {
      $displ$14$i = $192;
     }
    }
   }
   HEAP32[$178>>2] = $181;
   $$pre29 = HEAP8[$175>>0]|0;
   $$pre30 = HEAP32[$160>>2]|0;
   $194 = $$pre29;$200 = $$pre30;
  } else {
   $194 = $174;$200 = $sz;
  }
  $193 = ($194<<24>>24)!=(0);
  $195 = $193 ? 0 : $176;
  $196 = ((56 + ($195<<2)|0) + 11616|0);
  $197 = HEAP32[$196>>2]|0;
  $198 = (($hhdr$2) + 28|0);
  HEAP32[$198>>2] = $197;
  $199 = ($200>>>0)>(2048);
  if ($199) {
   $220 = 512;
  } else {
   $201 = (4096 % ($200>>>0))&-1;
   $202 = (4096 - ($201))|0;
   $203 = $202 >>> 3;
   $220 = $203;
  }
  $218 = (($hhdr$2) + 36|0);
  dest=$218+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $219 = $220 & 31;
  $221 = 1 << $219;
  $222 = $220 >>> 5;
  $223 = ((($hhdr$2) + ($222<<2)|0) + 36|0);
  $224 = HEAP32[$223>>2]|0;
  $225 = $224 | $221;
  HEAP32[$223>>2] = $225;
  $226 = (($hhdr$2) + 32|0);
  HEAP32[$226>>2] = 0;
  $227 = HEAP32[63912>>2]|0;
  $228 = $227&65535;
  $229 = (($hhdr$2) + 14|0);
  HEAP16[$229>>1] = $228;
  HEAP32[63752>>2] = 0;
  $230 = HEAP32[((56 + 16|0))>>2]|0;
  $231 = (($230) - ($1))|0;
  HEAP32[((56 + 16|0))>>2] = $231;
  $$0 = $155;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 66) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _GC_never_stop_func() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _GC_timeout_stop_func() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (_GC_never_stop_func()|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = HEAP32[63976>>2]|0;
  $3 = (($2) + 1)|0;
  HEAP32[63976>>2] = $3;
  $4 = $2 & 3;
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = (_clock()|0);
   $7 = HEAP32[63960>>2]|0;
   $8 = (($6) - ($7))|0;
   $9 = (($8>>>0) / 1000)&-1;
   $10 = HEAP32[63952>>2]|0;
   $11 = ($9>>>0)<($10>>>0);
   if ($11) {
    $$0 = 0;
   } else {
    $12 = HEAP32[62240>>2]|0;
    $13 = ($12|0)==(0);
    if ($13) {
     $$0 = 1;
    } else {
     $14 = HEAP32[63968>>2]|0;
     HEAP32[$vararg_buffer>>2] = $9;
     $vararg_ptr1 = (($vararg_buffer) + 4|0);
     HEAP32[$vararg_ptr1>>2] = $14;
     _GC_log_printf(63984,$vararg_buffer);
     $$0 = 1;
    }
   }
  } else {
   $$0 = 0;
  }
 } else {
  $$0 = 1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _GC_maybe_gc() {
 var $$$i$i = 0, $$$i1$i = 0, $$0$i$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$$i$i = 0, $phitmp = 0, $phitmp2 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[64072>>2]|0;
 $1 = HEAP32[63912>>2]|0;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$pre$i = HEAP32[64064>>2]|0;
  $32 = $$pre$i;
 } else {
  HEAP32[64072>>2] = $1;
  $3 = HEAP32[((56 + 3412|0))>>2]|0;
  $4 = $3 << 1;
  $5 = HEAP32[((56 + 3416|0))>>2]|0;
  $6 = $5 >>> 2;
  $7 = (($4) + 0)|0;
  $8 = (($7) + ($6))|0;
  $9 = HEAP32[63944>>2]|0;
  $10 = (($8>>>0) / ($9>>>0))&-1;
  $11 = HEAP32[62432>>2]|0;
  $not$$i$i = ($11|0)!=(0);
  $12 = $not$$i$i&1;
  $$$i$i = $10 >>> $12;
  $13 = ($$$i$i|0)!=(0);
  $14 = $13 ? $$$i$i : 1;
  HEAP32[64064>>2] = $14;
  $32 = $14;
 }
 $15 = HEAP32[62776>>2]|0;
 $16 = HEAP32[64048>>2]|0;
 $17 = HEAP32[((56 + 32|0))>>2]|0;
 $18 = HEAP32[((56 + 36|0))>>2]|0;
 $19 = HEAP32[((56 + 44|0))>>2]|0;
 $20 = HEAP32[((56 + 48|0))>>2]|0;
 $21 = (($16) - ($15))|0;
 $22 = (($21) + ($17))|0;
 $23 = (($22) + ($18))|0;
 $24 = (($23) - ($19))|0;
 $25 = (($24) + ($20))|0;
 $26 = ($25|0)>($17|0);
 $$$i1$i = $26 ? $17 : $25;
 $27 = HEAP32[((56 + 40|0))>>2]|0;
 $28 = (($$$i1$i) + ($27))|0;
 $29 = $17 >>> 3;
 $30 = ($28|0)<($29|0);
 $$0$i$i = $30 ? $29 : $28;
 $31 = ($$0$i$i>>>0)<($32>>>0);
 if ($31) {
  $33 = HEAP32[56>>2]|0;
  $34 = HEAP32[64056>>2]|0;
  $35 = ($33>>>0)<($34>>>0);
  if ($35) {
   STACKTOP = sp;return;
  }
 }
 $36 = HEAP32[62432>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  (_GC_try_to_collect_inner(1)|0);
  HEAP32[64088>>2] = 0;
  STACKTOP = sp;return;
 }
 $38 = HEAP32[63928>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  $40 = HEAP32[64088>>2]|0;
  $41 = HEAP32[63920>>2]|0;
  $42 = ($40|0)<($41|0);
  if ($42) {
   $47 = (($40) + 1)|0;
   HEAP32[64088>>2] = $47;
  } else {
   label = 10;
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $43 = HEAP32[62240>>2]|0;
  $44 = ($43|0)==(0);
  if (!($44)) {
   $45 = (($1) + 1)|0;
   HEAP32[$vararg_buffer>>2] = $45;
   $vararg_ptr1 = (($vararg_buffer) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $17;
   _GC_log_printf(64096,$vararg_buffer);
  }
  _GC_promote_black_lists();
  (_GC_reclaim_all(0,1)|0);
  $46 = (0|0)==(0|0);
  if (!($46)) {
   abort /* segfault, call an absolute addr */ ();
  }
  _GC_clear_marks();
  HEAP32[64088>>2] = 0;
  HEAP32[64080>>2] = 1;
 }
 $48 = HEAP32[63952>>2]|0;
 $49 = ($48|0)==(999999);
 if ($49) {
  $51 = 1;
 } else {
  $50 = (_clock()|0);
  HEAP32[63960>>2] = $50;
  $$pre = HEAP32[63952>>2]|0;
  $phitmp = ($$pre|0)==(999999);
  $phitmp2 = $phitmp ? 1 : 2;
  $51 = $phitmp2;
 }
 $52 = (_GC_stopped_mark($51)|0);
 $53 = ($52|0)==(0);
 if (!($53)) {
  _GC_finish_collection();
  STACKTOP = sp;return;
 }
 $54 = HEAP32[64080>>2]|0;
 $55 = ($54|0)==(0);
 if (!($55)) {
  STACKTOP = sp;return;
 }
 $56 = HEAP32[63968>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[63968>>2] = $57;
 STACKTOP = sp;return;
}
function _GC_try_to_collect_inner($stop_func) {
 $stop_func = $stop_func|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond2 = 0, $start_time$0 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer3 = sp;
 $0 = HEAP32[62440>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (FUNCTION_TABLE_i[$stop_func & 255]()|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[62432>>2]|0;
 $5 = ($4|0)==(0);
 $6 = HEAP32[65672>>2]|0;
 $7 = ($6|0)==(0);
 $or$cond2 = $5 | $7;
 L7: do {
  if (!($or$cond2)) {
   $8 = HEAP32[62240>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $11 = $6;
   } else {
    _GC_log_printf(64160,$vararg_buffer3);
    $$pre = HEAP32[65672>>2]|0;
    $11 = $$pre;
   }
   $10 = ($11|0)==(0);
   if (!($10)) {
    while(1) {
     $12 = (FUNCTION_TABLE_i[$stop_func & 255]()|0);
     $13 = ($12|0)==(0);
     if (!($13)) {
      $$0 = 0;
      break;
     }
     _GC_collect_a_little_inner(1);
     $14 = HEAP32[65672>>2]|0;
     $15 = ($14|0)==(0);
     if ($15) {
      break L7;
     }
    }
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $16 = (0|0)==(0|0);
 if (!($16)) {
  abort /* segfault, call an absolute addr */ ();
 }
 $17 = HEAP32[62240>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $start_time$0 = 0;
 } else {
  $19 = (_clock()|0);
  _GC_log_printf(64224,$vararg_buffer3);
  $start_time$0 = $19;
 }
 _GC_promote_black_lists();
 $20 = HEAP32[63736>>2]|0;
 $21 = ($20|0)==(0);
 $22 = ($stop_func|0)==(1|0);
 $or$cond = $21 & $22;
 if (!($or$cond)) {
  $23 = (_GC_reclaim_all($stop_func,0)|0);
  $24 = ($23|0)==(0);
  if ($24) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[65672>>2] = 5;
 $25 = HEAP32[((56 + 60|0))>>2]|0;
 $26 = (($25) + -8|0);
 HEAP32[((56 + 68|0))>>2] = $26;
 _GC_clear_marks();
 HEAP32[64080>>2] = 1;
 $27 = (_GC_stopped_mark($stop_func)|0);
 $28 = ($27|0)==(0);
 if (!($28)) {
  _GC_finish_collection();
  $38 = HEAP32[62240>>2]|0;
  $39 = ($38|0)==(0);
  if ($39) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $40 = (_clock()|0);
  $41 = (($40) - ($start_time$0))|0;
  $42 = (($41>>>0) / 1000)&-1;
  HEAP32[$vararg_buffer3>>2] = $42;
  _GC_log_printf(64264,$vararg_buffer3);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = HEAP32[62432>>2]|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[65672>>2] = 5;
 $31 = HEAP32[((56 + 60|0))>>2]|0;
 $32 = (($31) + -8|0);
 HEAP32[((56 + 68|0))>>2] = $32;
 $33 = (1)==(0);
 if ($33) {
  $34 = HEAP32[8>>2]|0;
  $35 = HEAP32[16>>2]|0;
  _memcpy(($35|0),($34|0),32768)|0;
 }
 $36 = HEAP32[24>>2]|0;
 $37 = HEAP32[32>>2]|0;
 _memcpy(($37|0),($36|0),32768)|0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GC_reclaim_all($stop_func,$ignore_old) {
 $stop_func = $stop_func|0;
 $ignore_old = $ignore_old|0;
 var $$0 = 0, $$pre10 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $kind$03 = 0, $start_time$0 = 0, $sz$02 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[62240>>2]|0;
 $1 = ($0|0)==(2);
 if ($1) {
  $2 = (_clock()|0);
  $start_time$0 = $2;
 } else {
  $start_time$0 = 0;
 }
 $3 = (3)==(0);
 L4: do {
  if (!($3)) {
   $4 = ($stop_func|0)==(0|0);
   $5 = ($ignore_old|0)==(0);
   $61 = 3;$kind$03 = 0;
   L6: while(1) {
    $6 = ((62448 + (($kind$03*20)|0)|0) + 4|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $55 = $61;
    } else {
     $sz$02 = 1;
     while(1) {
      $9 = (($7) + ($sz$02<<2)|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0|0);
      if (!($11)) {
       $15 = $10;
       while(1) {
        if (!($4)) {
         $12 = (FUNCTION_TABLE_i[$stop_func & 255]()|0);
         $13 = ($12|0)==(0);
         if (!($13)) {
          $$0 = 0;
          break L6;
         }
        }
        $14 = $15;
        $16 = $14 >>> 12;
        $17 = $16 & 1023;
        $18 = $14 >>> 22;
        $19 = ((56 + ($18<<2)|0) + 57964|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = (($20) + ($17<<2)|0);
        $22 = HEAP32[$21>>2]|0;
        $23 = HEAP32[$22>>2]|0;
        HEAP32[$9>>2] = $23;
        if ($5) {
         $$pre10 = HEAP32[63912>>2]|0;
         $43 = $$pre10;
         label = 12;
        } else {
         $24 = (($22) + 14|0);
         $25 = HEAP16[$24>>1]|0;
         $26 = $25&65535;
         $27 = HEAP32[63912>>2]|0;
         $28 = (($27) + -1)|0;
         $29 = ($26|0)==($28|0);
         if ($29) {
          $43 = $27;
          label = 12;
         } else {
          $50 = $23;
         }
        }
        if ((label|0) == 12) {
         label = 0;
         $30 = HEAP32[$19>>2]|0;
         $31 = (($30) + ($17<<2)|0);
         $32 = HEAP32[$31>>2]|0;
         $33 = (($32) + 16|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = (($32) + 12|0);
         $36 = HEAP8[$35>>0]|0;
         $37 = $36&255;
         $38 = $34 >>> 3;
         $39 = (62448 + (($37*20)|0)|0);
         $40 = HEAP32[$39>>2]|0;
         $41 = (($40) + ($38<<2)|0);
         $42 = $43&65535;
         $44 = (($32) + 14|0);
         HEAP16[$44>>1] = $42;
         $45 = ((62448 + (($37*20)|0)|0) + 16|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = HEAP32[$41>>2]|0;
         $48 = (_GC_reclaim_generic($15,$32,$34,$46,$47,64464)|0);
         HEAP32[$41>>2] = $48;
         $$pre7 = HEAP32[$9>>2]|0;
         $50 = $$pre7;
        }
        $49 = ($50|0)==(0|0);
        if ($49) {
         break;
        } else {
         $15 = $50;
        }
       }
      }
      $51 = (($sz$02) + 1)|0;
      $52 = ($51>>>0)<(257);
      if ($52) {
       $sz$02 = $51;
      } else {
       break;
      }
     }
     $55 = 3;
    }
    $53 = (($kind$03) + 1)|0;
    $54 = ($53>>>0)<($55>>>0);
    if ($54) {
     $61 = $55;$kind$03 = $53;
    } else {
     break L4;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $56 = HEAP32[62240>>2]|0;
 $57 = ($56|0)==(2);
 if (!($57)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $58 = (_clock()|0);
 $59 = (($58) - ($start_time$0))|0;
 $60 = (($59>>>0) / 1000)&-1;
 HEAP32[$vararg_buffer>>2] = $60;
 _GC_log_printf(66720,$vararg_buffer);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _GC_clear_marks() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index_p$0$i = 0, $index_p$02$i = 0, $index_p$03$i = 0, $j$0$be$i = 0, $j$01$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $index_p$02$i = HEAP32[62304>>2]|0;
 $0 = ($index_p$02$i|0)==(0|0);
 if ($0) {
  HEAP32[65896>>2] = 0;
  HEAP32[65672>>2] = 5;
  HEAP32[65904>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $index_p$03$i = $index_p$02$i;
 }
 while(1) {
  $1 = (($index_p$03$i) + 4104|0);
  $j$01$i = 1023;
  while(1) {
   $2 = (($index_p$03$i) + ($j$01$i<<2)|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = $3;
   $5 = ($3>>>0)<((4096)>>>0);
   do {
    if ($5) {
     $39 = ($3|0)==(0|0);
     if ($39) {
      $40 = (($j$01$i) + -1)|0;
      $j$0$be$i = $40;
      break;
     } else {
      $42 = (($j$01$i) - ($4))|0;
      $j$0$be$i = $42;
      break;
     }
    } else {
     $6 = (($3) + 13|0);
     $7 = HEAP8[$6>>0]|0;
     $8 = $7 & 4;
     $9 = ($8<<24>>24)==(0);
     if ($9) {
      $10 = HEAP32[$1>>2]|0;
      $11 = $10 << 10;
      $12 = (($11) + ($j$01$i))|0;
      $13 = $12 & 1023;
      $14 = $12 >>> 10;
      $15 = $14 & 1023;
      $16 = ((56 + ($15<<2)|0) + 57964|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($17) + ($13<<2)|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = (($19) + 12|0);
      $21 = HEAP8[$20>>0]|0;
      $22 = ($21<<24>>24)==(2);
      if (!($22)) {
       $23 = (($19) + 16|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($24>>>0)>(2048);
       if ($25) {
        $31 = 512;
       } else {
        $26 = (4096 % ($24>>>0))&-1;
        $27 = (4096 - ($26))|0;
        $28 = $27 >>> 3;
        $31 = $28;
       }
       $29 = (($19) + 36|0);
       dest=$29+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       $30 = $31 & 31;
       $32 = 1 << $30;
       $33 = $31 >>> 5;
       $34 = ((($19) + ($33<<2)|0) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = $35 | $32;
       HEAP32[$34>>2] = $36;
       $37 = (($19) + 32|0);
       HEAP32[$37>>2] = 0;
      }
     }
     $38 = (($j$01$i) + -1)|0;
     $j$0$be$i = $38;
    }
   } while(0);
   $41 = ($j$0$be$i|0)>(-1);
   if ($41) {
    $j$01$i = $j$0$be$i;
   } else {
    break;
   }
  }
  $43 = (($index_p$03$i) + 4096|0);
  $index_p$0$i = HEAP32[$43>>2]|0;
  $44 = ($index_p$0$i|0)==(0|0);
  if ($44) {
   break;
  } else {
   $index_p$03$i = $index_p$0$i;
  }
 }
 HEAP32[65896>>2] = 0;
 HEAP32[65672>>2] = 5;
 HEAP32[65904>>2] = 0;
 STACKTOP = sp;return;
}
function _GC_stopped_mark($stop_func) {
 $stop_func = $stop_func|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $divisor$0 = 0, $i$0$lcssa = 0, $i$03 = 0, $or$cond = 0, $start_time$01 = 0, $total_time$0 = 0, $vararg_buffer10 = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer10 = sp;
 $0 = HEAP32[62240>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $start_time$01 = 0;
 } else {
  $2 = (_clock()|0);
  $$pr = HEAP32[62240>>2]|0;
  $3 = ($$pr|0)==(0);
  if ($3) {
   $start_time$01 = $2;
  } else {
   $4 = HEAP32[63912>>2]|0;
   $5 = (($4) + 1)|0;
   $6 = HEAP32[((56 + 32|0))>>2]|0;
   HEAP32[$vararg_buffer10>>2] = $5;
   $vararg_ptr1 = (($vararg_buffer10) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $6;
   _GC_log_printf(64312,$vararg_buffer10);
   $start_time$01 = $2;
  }
 }
 HEAP32[65880>>2] = 0;
 $7 = HEAP32[65672>>2]|0;
 if ((($7|0) == 0)) {
  HEAP32[65672>>2] = 1;
 } else if (!((($7|0) == 5))) {
  _GC_default_on_abort(65920);
  _abort();
  // unreachable;
 }
 HEAP32[65904>>2] = 0;
 $8 = (FUNCTION_TABLE_i[$stop_func & 255]()|0);
 $9 = ($8|0)==(0);
 L9: do {
  if ($9) {
   $10 = $vararg_buffer10;
   $i$03 = 0;
   while(1) {
    HEAP32[$vararg_buffer10>>2] = $10;
    $15 = HEAP32[$vararg_buffer10>>2]|0;
    $16 = $15;
    $17 = (_GC_mark_some($16)|0);
    $18 = ($17|0)==(0);
    $19 = (($i$03) + 1)|0;
    if (!($18)) {
     break;
    }
    $11 = (FUNCTION_TABLE_i[$stop_func & 255]()|0);
    $12 = ($11|0)==(0);
    if ($12) {
     $i$03 = $19;
    } else {
     $i$0$lcssa = $19;
     break L9;
    }
   }
   $20 = HEAP32[63912>>2]|0;
   $21 = (($20) + 1)|0;
   HEAP32[63912>>2] = $21;
   $22 = HEAP32[62240>>2]|0;
   $23 = ($22|0)==(0);
   if (!($23)) {
    $24 = HEAP32[64464>>2]|0;
    $25 = HEAP32[56>>2]|0;
    $26 = (($25) + 511)|0;
    $27 = $26 >>> 10;
    HEAP32[$vararg_buffer10>>2] = $21;
    $vararg_ptr8 = (($vararg_buffer10) + 4|0);
    HEAP32[$vararg_ptr8>>2] = $24;
    $vararg_ptr9 = (($vararg_buffer10) + 8|0);
    HEAP32[$vararg_ptr9>>2] = $27;
    _GC_log_printf(64424,$vararg_buffer10);
   }
   $28 = (0)==(0);
   if (!($28)) {
    abort /* segfault, call an absolute addr */ ();
   }
   $29 = HEAP32[62240>>2]|0;
   $30 = ($29|0)==(0);
   if ($30) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $31 = (_clock()|0);
   $32 = (($31) - ($start_time$01))|0;
   $33 = (($32>>>0) / 1000)&-1;
   $34 = HEAP32[64472>>2]|0;
   $35 = HEAP32[64480>>2]|0;
   $36 = ($34|0)<(0);
   $37 = ($35>>>0)>(999);
   $or$cond = $36 | $37;
   if ($or$cond) {
    $38 = $34 >>> 1;
    $39 = $35 >>> 1;
    $divisor$0 = $39;$total_time$0 = $38;
   } else {
    $divisor$0 = $35;$total_time$0 = $34;
   }
   $40 = (($total_time$0) + ($33))|0;
   HEAP32[64472>>2] = $40;
   $41 = (($divisor$0) + 1)|0;
   HEAP32[64480>>2] = $41;
   $42 = (($40>>>0) / ($41>>>0))&-1;
   HEAP32[$vararg_buffer10>>2] = $33;
   $vararg_ptr13 = (($vararg_buffer10) + 4|0);
   HEAP32[$vararg_ptr13>>2] = $42;
   _GC_log_printf(64488,$vararg_buffer10);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$0$lcssa = 0;
  }
 } while(0);
 $13 = HEAP32[62240>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  HEAP32[$vararg_buffer10>>2] = $i$0$lcssa;
  _GC_log_printf(64376,$vararg_buffer10);
 }
 HEAP32[64304>>2] = $i$0$lcssa;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GC_finish_collection() {
 var $$$i = 0, $$0$i = 0, $$0$i5 = 0, $$0$ph$i = 0, $$0$ph$i2 = 0, $$pre = 0, $$pre32 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond31 = 0, $finalize_time$0 = 0, $fo$01$i = 0, $h$0$ph$i = 0, $hhdr$0$ph$i = 0, $hhdr$0$ph$i3 = 0, $hhdr$0$ph$in$i = 0, $hhdr$0$ph$in$i1 = 0, $kind$021 = 0, $kind3$013 = 0, $last_h$0$ph$i = 0, $not$$i = 0, $ready$0$lcssa$i = 0, $ready$02$i = 0;
 var $size$019 = 0, $size1$011 = 0, $start_time$0 = 0, $storemerge = 0, $sz$0$ph$i = 0, $sz$0$ph$in$i = 0, $vararg_buffer30 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr23 = 0, $vararg_ptr24 = 0, $vararg_ptr28 = 0, $vararg_ptr29 = 0, $vararg_ptr33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer30 = sp;
 $0 = HEAP32[62240>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $start_time$0 = 0;
 } else {
  $2 = (_clock()|0);
  $start_time$0 = $2;
 }
 $3 = HEAP32[64464>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $5 = HEAP32[64544>>2]|0;
  $6 = (($5) + ($3))|0;
  HEAP32[64544>>2] = $6;
 }
 HEAP32[64464>>2] = 0;
 $7 = HEAP32[64552>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  _GC_printf(67672,$vararg_buffer30);
  _GC_print_static_roots();
  _GC_printf(67696,$vararg_buffer30);
  _GC_print_heap_sects();
  _GC_printf(67720,$vararg_buffer30);
  _GC_print_hblkfreelist();
  _GC_printf(67744,$vararg_buffer30);
  _GC_print_block_list();
 }
 $9 = HEAP32[63736>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (3)==(0);
  if (!($11)) {
   $kind$021 = 0;
   while(1) {
    $12 = (62448 + (($kind$021*20)|0)|0);
    $$pre33 = HEAP32[$12>>2]|0;
    $size$019 = 1;
    while(1) {
     $13 = (($$pre33) + ($size$019<<2)|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0|0);
     L17: do {
      if (!($15)) {
       $16 = $14;
       $17 = $16 & -4096;
       $18 = $17;
       $19 = $16 >>> 12;
       $20 = $19 & 1023;
       $21 = $16 >>> 22;
       $22 = ((56 + ($21<<2)|0) + 57964|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = (($23) + ($20<<2)|0);
       $$0$ph$i = $14;$h$0$ph$i = $18;$hhdr$0$ph$in$i = $24;
       while(1) {
        $hhdr$0$ph$i = HEAP32[$hhdr$0$ph$in$i>>2]|0;
        $25 = (($hhdr$0$ph$i) + 32|0);
        $26 = $h$0$ph$i;
        $$0$i = $$0$ph$i;
        while(1) {
         $27 = $$0$i;
         $28 = (($27) - ($26))|0;
         $29 = $28 >>> 3;
         $30 = $28 >>> 8;
         $31 = ((($hhdr$0$ph$i) + ($30<<2)|0) + 36|0);
         $32 = HEAP32[$31>>2]|0;
         $33 = $29 & 31;
         $34 = 1 << $33;
         $35 = $34 & $32;
         $36 = ($35|0)==(0);
         if ($36) {
          $37 = $34 | $32;
          HEAP32[$31>>2] = $37;
          $38 = HEAP32[$25>>2]|0;
          $39 = (($38) + 1)|0;
          HEAP32[$25>>2] = $39;
         }
         $40 = HEAP32[$$0$i>>2]|0;
         $41 = ($40|0)==(0|0);
         if ($41) {
          break L17;
         }
         $42 = $40;
         $43 = $42 & -4096;
         $44 = $43;
         $45 = ($44|0)==($h$0$ph$i|0);
         if ($45) {
          $$0$i = $40;
         } else {
          break;
         }
        }
        $46 = $42 >>> 12;
        $47 = $46 & 1023;
        $48 = $42 >>> 22;
        $49 = ((56 + ($48<<2)|0) + 57964|0);
        $50 = HEAP32[$49>>2]|0;
        $51 = (($50) + ($47<<2)|0);
        $$0$ph$i = $40;$h$0$ph$i = $44;$hhdr$0$ph$in$i = $51;
       }
      }
     } while(0);
     $52 = (($size$019) + 1)|0;
     $exitcond31 = ($52|0)==(257);
     if ($exitcond31) {
      break;
     } else {
      $size$019 = $52;
     }
    }
    $53 = (($kind$021) + 1)|0;
    $54 = ($53>>>0)<(3);
    if ($54) {
     $kind$021 = $53;
    } else {
     break;
    }
   }
  }
  _GC_start_reclaim(1);
 }
 _GC_finalize();
 $55 = HEAP32[62240>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $finalize_time$0 = 0;
 } else {
  $57 = (_clock()|0);
  $finalize_time$0 = $57;
 }
 $58 = HEAP32[64560>>2]|0;
 $59 = ($58|0)==(0);
 if (!($59)) {
  _GC_err_printf(64568,$vararg_buffer30);
 }
 $60 = (3)==(0);
 if (!($60)) {
  $kind3$013 = 0;
  while(1) {
   $61 = (62448 + (($kind3$013*20)|0)|0);
   $$pre32 = HEAP32[$61>>2]|0;
   $size1$011 = 1;
   while(1) {
    $62 = (($$pre32) + ($size1$011<<2)|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = ($63|0)==(0|0);
    L43: do {
     if (!($64)) {
      $65 = $63;
      $66 = $65 & -4096;
      $67 = $66;
      $68 = $65 >>> 12;
      $69 = $68 & 1023;
      $70 = $65 >>> 22;
      $71 = ((56 + ($70<<2)|0) + 57964|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($72) + ($69<<2)|0);
      $$0$ph$i2 = $63;$hhdr$0$ph$in$i1 = $73;$last_h$0$ph$i = $67;
      while(1) {
       $hhdr$0$ph$i3 = HEAP32[$hhdr$0$ph$in$i1>>2]|0;
       $sz$0$ph$in$i = (($hhdr$0$ph$i3) + 16|0);
       $sz$0$ph$i = HEAP32[$sz$0$ph$in$i>>2]|0;
       $74 = (($hhdr$0$ph$i3) + 32|0);
       $75 = $last_h$0$ph$i;
       $$0$i5 = $$0$ph$i2;
       while(1) {
        $76 = $$0$i5;
        $77 = (($76) - ($75))|0;
        $78 = $77 >>> 3;
        $79 = $77 >>> 8;
        $80 = ((($hhdr$0$ph$i3) + ($79<<2)|0) + 36|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = $78 & 31;
        $83 = 1 << $82;
        $84 = $83 & $81;
        $85 = ($84|0)==(0);
        if (!($85)) {
         $86 = HEAP32[$74>>2]|0;
         $87 = (($86) + -1)|0;
         $88 = $83 ^ -1;
         $89 = $81 & $88;
         HEAP32[$80>>2] = $89;
         HEAP32[$74>>2] = $87;
        }
        $90 = HEAP32[64464>>2]|0;
        $91 = (($90) - ($sz$0$ph$i))|0;
        HEAP32[64464>>2] = $91;
        $92 = HEAP32[$$0$i5>>2]|0;
        $93 = ($92|0)==(0|0);
        if ($93) {
         break L43;
        }
        $94 = $92;
        $95 = $94 & -4096;
        $96 = $95;
        $97 = ($96|0)==($last_h$0$ph$i|0);
        if ($97) {
         $$0$i5 = $92;
        } else {
         break;
        }
       }
       $98 = $94 >>> 12;
       $99 = $98 & 1023;
       $100 = $94 >>> 22;
       $101 = ((56 + ($100<<2)|0) + 57964|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = (($102) + ($99<<2)|0);
       $$0$ph$i2 = $92;$hhdr$0$ph$in$i1 = $103;$last_h$0$ph$i = $96;
      }
     }
    } while(0);
    $104 = (($size1$011) + 1)|0;
    $exitcond = ($104|0)==(257);
    if ($exitcond) {
     break;
    } else {
     $size1$011 = $104;
    }
   }
   $105 = (($kind3$013) + 1)|0;
   $106 = ($105>>>0)<(3);
   if ($106) {
    $kind3$013 = $105;
   } else {
    break;
   }
  }
 }
 $107 = HEAP32[62240>>2]|0;
 $108 = ($107|0)==(2);
 if ($108) {
  $109 = HEAP32[64464>>2]|0;
  HEAP32[$vararg_buffer30>>2] = $109;
  _GC_log_printf(64640,$vararg_buffer30);
 }
 _GC_start_reclaim(0);
 $110 = HEAP32[62240>>2]|0;
 $111 = ($110|0)==(0);
 if (!($111)) {
  $112 = HEAP32[((56 + 3412|0))>>2]|0;
  $113 = HEAP32[((56 + 3416|0))>>2]|0;
  $114 = (($113) + ($112))|0;
  $115 = HEAP32[56>>2]|0;
  $116 = ($114>>>0)<($115>>>0);
  do {
   if ($116) {
    $117 = ($114>>>0)<(42949672);
    if ($117) {
     $118 = ($114*100)|0;
     $119 = (($118>>>0) / ($115>>>0))&-1;
     $126 = $119;
     break;
    } else {
     $120 = (($115>>>0) / 100)&-1;
     $121 = (($114>>>0) / ($120>>>0))&-1;
     $126 = $121;
     break;
    }
   } else {
    $126 = 0;
   }
  } while(0);
  $122 = (($112) + 511)|0;
  $123 = $122 >>> 10;
  $124 = (($113) + 511)|0;
  $125 = $124 >>> 10;
  HEAP32[$vararg_buffer30>>2] = $126;
  $vararg_ptr14 = (($vararg_buffer30) + 4|0);
  HEAP32[$vararg_ptr14>>2] = $123;
  $vararg_ptr15 = (($vararg_buffer30) + 8|0);
  HEAP32[$vararg_ptr15>>2] = $125;
  _GC_log_printf(64696,$vararg_buffer30);
 }
 $127 = HEAP32[64080>>2]|0;
 $128 = ($127|0)==(0);
 $129 = HEAP32[56>>2]|0;
 $130 = HEAP32[((56 + 16|0))>>2]|0;
 $131 = (($129) - ($130))|0;
 if ($128) {
  $132 = HEAP32[63936>>2]|0;
  $133 = (($131) - ($132))|0;
  $134 = HEAP32[((56 + 3412|0))>>2]|0;
  $135 = $134 << 1;
  $136 = HEAP32[((56 + 3416|0))>>2]|0;
  $137 = $136 >>> 2;
  $138 = (($135) + 0)|0;
  $139 = (($138) + ($137))|0;
  $140 = HEAP32[63944>>2]|0;
  $141 = (($139>>>0) / ($140>>>0))&-1;
  $142 = HEAP32[62432>>2]|0;
  $not$$i = ($142|0)!=(0);
  $143 = $not$$i&1;
  $$$i = $141 >>> $143;
  $144 = ($$$i|0)!=(0);
  $145 = $144 ? $$$i : 1;
  $146 = ($133>>>0)>($145>>>0);
  $147 = $146&1;
  $storemerge = $147;
 } else {
  HEAP32[63936>>2] = $131;
  $storemerge = 0;
 }
 HEAP32[63928>>2] = $storemerge;
 $148 = HEAP32[62240>>2]|0;
 $149 = ($148|0)==(2);
 if ($149) {
  $150 = HEAP32[64464>>2]|0;
  HEAP32[$vararg_buffer30>>2] = $150;
  $vararg_ptr19 = (($vararg_buffer30) + 4|0);
  HEAP32[$vararg_ptr19>>2] = $129;
  _GC_log_printf(64752,$vararg_buffer30);
  $$pre = HEAP32[62240>>2]|0;
  $156 = $$pre;
 } else {
  $156 = $148;
 }
 HEAP32[63968>>2] = 0;
 HEAP32[64080>>2] = 0;
 $151 = HEAP32[((56 + 32|0))>>2]|0;
 $152 = HEAP32[((56 + 28|0))>>2]|0;
 $153 = (($152) + ($151))|0;
 HEAP32[((56 + 28|0))>>2] = $153;
 $154 = HEAP32[62776>>2]|0;
 HEAP32[64048>>2] = $154;
 HEAP32[((56 + 32|0))>>2] = 0;
 HEAP32[((56 + 36|0))>>2] = 0;
 HEAP32[((56 + 44|0))>>2] = 0;
 HEAP32[((56 + 48|0))>>2] = 0;
 $155 = ($156|0)==(0);
 if ($155) {
  STACKTOP = sp;return;
 }
 $157 = (_clock()|0);
 $158 = HEAP32[65136>>2]|0;
 $159 = HEAP32[((65408 + 8|0))>>2]|0;
 $160 = HEAP32[((65424 + 8|0))>>2]|0;
 HEAP32[$vararg_buffer30>>2] = $158;
 $vararg_ptr23 = (($vararg_buffer30) + 4|0);
 HEAP32[$vararg_ptr23>>2] = $159;
 $vararg_ptr24 = (($vararg_buffer30) + 8|0);
 HEAP32[$vararg_ptr24>>2] = $160;
 _GC_log_printf(65736,$vararg_buffer30);
 $161 = HEAP32[65448>>2]|0;
 $162 = ($161|0)==(0|0);
 if ($162) {
  $ready$0$lcssa$i = 0;
 } else {
  $fo$01$i = $161;$ready$02$i = 0;
  while(1) {
   $163 = (($ready$02$i) + 1)|0;
   $164 = (($fo$01$i) + 4|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($165|0)==(0|0);
   if ($166) {
    $ready$0$lcssa$i = $163;
    break;
   } else {
    $fo$01$i = $165;$ready$02$i = $163;
   }
  }
 }
 $167 = HEAP32[65640>>2]|0;
 $168 = HEAP32[((65408 + 8|0))>>2]|0;
 $169 = (($167) - ($168))|0;
 $170 = HEAP32[65648>>2]|0;
 $171 = HEAP32[((65424 + 8|0))>>2]|0;
 $172 = (($170) - ($171))|0;
 HEAP32[$vararg_buffer30>>2] = $ready$0$lcssa$i;
 $vararg_ptr28 = (($vararg_buffer30) + 4|0);
 HEAP32[$vararg_ptr28>>2] = $169;
 $vararg_ptr29 = (($vararg_buffer30) + 8|0);
 HEAP32[$vararg_ptr29>>2] = $172;
 _GC_log_printf(65808,$vararg_buffer30);
 $173 = (($finalize_time$0) - ($start_time$0))|0;
 $174 = (($173>>>0) / 1000)&-1;
 $175 = (($157) - ($finalize_time$0))|0;
 $176 = (($175>>>0) / 1000)&-1;
 HEAP32[$vararg_buffer30>>2] = $174;
 $vararg_ptr33 = (($vararg_buffer30) + 4|0);
 HEAP32[$vararg_ptr33>>2] = $176;
 _GC_log_printf(64808,$vararg_buffer30);
 STACKTOP = sp;return;
}
function _GC_mark_some($cold_gc_frame) {
 $cold_gc_frame = $cold_gc_frame|0;
 var $$0 = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[65672>>2]|0;
 switch ($0|0) {
 case 3:  {
  $30 = HEAP32[((56 + 68|0))>>2]|0;
  $31 = HEAP32[((56 + 60|0))>>2]|0;
  $32 = ($30>>>0)<($31>>>0);
  if (!($32)) {
   $33 = HEAP32[65592>>2]|0;
   $34 = (($31) + ($33<<3)|0);
   $35 = (_GC_mark_from($30,$31,$34)|0);
   HEAP32[((56 + 68|0))>>2] = $35;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[65672>>2] = 0;
  $36 = HEAP32[65888>>2]|0;
  $37 = ($36|0)==(0);
  if ($37) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $38 = HEAP32[65592>>2]|0;
  $39 = $38 << 1;
  _alloc_mark_stack($39);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 0:  {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4: case 5:  {
  $40 = HEAP32[65896>>2]|0;
  $41 = ($40|0)==(0);
  if ($41) {
   HEAP32[65672>>2] = 2;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $42 = HEAP32[((56 + 68|0))>>2]|0;
  $43 = HEAP32[((56 + 60|0))>>2]|0;
  $44 = ($42>>>0)<($43>>>0);
  if (!($44)) {
   $45 = HEAP32[65592>>2]|0;
   $46 = (($43) + ($45<<3)|0);
   $47 = (_GC_mark_from($42,$43,$46)|0);
   HEAP32[((56 + 68|0))>>2] = $47;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $48 = HEAP32[65904>>2]|0;
  $49 = ($48|0)==(0|0);
  $50 = ($0|0)==(5);
  $or$cond = $49 & $50;
  if ($or$cond) {
   $51 = HEAP32[65888>>2]|0;
   $52 = ($51|0)==(0);
   if ($52) {
    $$pre = 0;
   } else {
    $53 = HEAP32[65592>>2]|0;
    $54 = $53 << 1;
    _alloc_mark_stack($54);
    $$pre$pre = HEAP32[65904>>2]|0;
    $$pre = $$pre$pre;
   }
   HEAP32[65672>>2] = 4;
   $55 = $$pre;
  } else {
   $55 = $48;
  }
  $56 = (_GC_push_next_marked($55)|0);
  HEAP32[65904>>2] = $56;
  $57 = ($56|0)==(0|0);
  $58 = HEAP32[65672>>2]|0;
  $59 = ($58|0)==(4);
  $or$cond3 = $57 & $59;
  if (!($or$cond3)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  _GC_push_roots(1,0);
  HEAP32[65896>>2] = 1;
  $60 = HEAP32[65672>>2]|0;
  $61 = ($60|0)==(5);
  if ($61) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[65672>>2] = 3;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $17 = HEAP32[((56 + 68|0))>>2]|0;
  $18 = HEAP32[((56 + 60|0))>>2]|0;
  $19 = HEAP32[65592>>2]|0;
  $20 = $19 >>> 2;
  $21 = (($18) + ($20<<3)|0);
  $22 = ($17>>>0)<($21>>>0);
  if (!($22)) {
   $23 = (($18) + ($19<<3)|0);
   $24 = (_GC_mark_from($17,$18,$23)|0);
   HEAP32[((56 + 68|0))>>2] = $24;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $25 = HEAP32[65904>>2]|0;
  $26 = (_GC_push_next_marked_uncollectable($25)|0);
  HEAP32[65904>>2] = $26;
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  _GC_push_roots(1,0);
  HEAP32[65896>>2] = 1;
  $28 = HEAP32[65672>>2]|0;
  $29 = ($28|0)==(5);
  if ($29) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[65672>>2] = 3;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1:  {
  $1 = HEAP32[((56 + 68|0))>>2]|0;
  $2 = HEAP32[((56 + 64|0))>>2]|0;
  $3 = (($2) + -16384|0);
  $4 = ($1>>>0)<($3>>>0);
  if (!($4)) {
   HEAP32[65888>>2] = 1;
   $5 = HEAP32[((56 + 60|0))>>2]|0;
   $6 = HEAP32[65592>>2]|0;
   $7 = (($5) + ($6<<3)|0);
   $8 = (_GC_mark_from($1,$5,$7)|0);
   HEAP32[((56 + 68|0))>>2] = $8;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $9 = HEAP32[65904>>2]|0;
  $10 = (_GC_push_next_marked_dirty($9)|0);
  HEAP32[65904>>2] = $10;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $12 = HEAP32[62240>>2]|0;
  $13 = ($12|0)==(0);
  if (!($13)) {
   $14 = HEAP32[65880>>2]|0;
   HEAP32[$vararg_buffer>>2] = $14;
   _GC_log_printf(65944,$vararg_buffer);
  }
  _GC_push_roots(0,0);
  HEAP32[65896>>2] = 1;
  $15 = HEAP32[65672>>2]|0;
  $16 = ($15|0)==(5);
  if ($16) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[65672>>2] = 3;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  _GC_default_on_abort(65976);
  _abort();
  // unreachable;
 }
 }
 return 0|0;
}
function _GC_collect_a_little() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _GC_collect_a_little_inner(1);
 $0 = HEAP32[65672>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = $1&1;
 $3 = $1 ^ 1;
 $4 = (0)!=(0);
 $or$cond = $4 & $3;
 if (!($or$cond)) {
  STACKTOP = sp;return ($2|0);
 }
 abort /* segfault, call an absolute addr */ ();
 STACKTOP = sp;return ($2|0);
}
function _GC_start_reclaim($report_if_found) {
 $report_if_found = $report_if_found|0;
 var $$02$i = 0, $$02$i$phi = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fop$01 = 0, $fop$01$us = 0, $index_p$0$i = 0, $index_p$02$i = 0, $index_p$03$i = 0, $j$0$be$i = 0, $j$01$i = 0, $kind$02 = 0, $next$0$i = 0, $next$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[((56 + 3412|0))>>2] = 0;
 HEAP32[((56 + 3416|0))>>2] = 0;
 $0 = (3)==(0);
 if (!($0)) {
  $1 = ($report_if_found|0)==(0);
  $kind$02 = 0;
  while(1) {
   $2 = ((62448 + (($kind$02*20)|0)|0) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ((62448 + (($kind$02*20)|0)|0) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0);
   $7 = ($3|0)==(0|0);
   if (!($7)) {
    if ($1) {
     $8 = (62448 + (($kind$02*20)|0)|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($9) + 1028|0);
     if ($6) {
      $fop$01$us = $9;
      while(1) {
       $11 = HEAP32[$fop$01$us>>2]|0;
       $12 = ($11|0)==(0|0);
       if (!($12)) {
        HEAP32[$fop$01$us>>2] = 0;
       }
       $13 = (($fop$01$us) + 4|0);
       $14 = ($13>>>0)<($10>>>0);
       if ($14) {
        $fop$01$us = $13;
       } else {
        break;
       }
      }
     } else {
      $fop$01 = $9;
      while(1) {
       $15 = HEAP32[$fop$01>>2]|0;
       $16 = ($15|0)==(0|0);
       if (!($16)) {
        $$02$i = $fop$01;$next$03$i = $15;
        while(1) {
         HEAP32[$$02$i>>2] = 0;
         $next$0$i = HEAP32[$next$03$i>>2]|0;
         $17 = ($next$0$i|0)==(0|0);
         if ($17) {
          break;
         } else {
          $$02$i$phi = $next$03$i;$next$03$i = $next$0$i;$$02$i = $$02$i$phi;
         }
        }
       }
       $18 = (($fop$01) + 4|0);
       $19 = ($18>>>0)<($10>>>0);
       if ($19) {
        $fop$01 = $18;
       } else {
        break;
       }
      }
     }
    }
    _memset(($3|0),0,1028)|0;
   }
   $20 = (($kind$02) + 1)|0;
   $21 = ($20>>>0)<(3);
   if ($21) {
    $kind$02 = $20;
   } else {
    break;
   }
  }
 }
 $index_p$02$i = HEAP32[62304>>2]|0;
 $22 = ($index_p$02$i|0)==(0|0);
 if ($22) {
  STACKTOP = sp;return;
 } else {
  $index_p$03$i = $index_p$02$i;
 }
 while(1) {
  $23 = (($index_p$03$i) + 4104|0);
  $j$01$i = 1023;
  while(1) {
   $24 = (($index_p$03$i) + ($j$01$i<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25;
   $27 = ($25>>>0)<((4096)>>>0);
   do {
    if ($27) {
     $38 = ($25|0)==(0|0);
     if ($38) {
      $39 = (($j$01$i) + -1)|0;
      $j$0$be$i = $39;
      break;
     } else {
      $41 = (($j$01$i) - ($26))|0;
      $j$0$be$i = $41;
      break;
     }
    } else {
     $28 = (($25) + 13|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = $29 & 4;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      $32 = HEAP32[$23>>2]|0;
      $33 = $32 << 10;
      $34 = (($33) + ($j$01$i))|0;
      $35 = $34 << 12;
      $36 = $35;
      _GC_reclaim_block($36,$report_if_found);
     }
     $37 = (($j$01$i) + -1)|0;
     $j$0$be$i = $37;
    }
   } while(0);
   $40 = ($j$0$be$i|0)>(-1);
   if ($40) {
    $j$01$i = $j$0$be$i;
   } else {
    break;
   }
  }
  $42 = (($index_p$03$i) + 4096|0);
  $index_p$0$i = HEAP32[$42>>2]|0;
  $43 = ($index_p$0$i|0)==(0|0);
  if ($43) {
   break;
  } else {
   $index_p$03$i = $index_p$0$i;
  }
 }
 STACKTOP = sp;return;
}
function _GC_finalize() {
 var $$ = 0, $$neg5 = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $curr_fo$032 = 0, $curr_fo$1$ph23 = 0, $curr_fo$118 = 0, $curr_fo$215 = 0, $curr_fo$3$ph41 = 0, $curr_fo$313 = 0, $i$036 = 0;
 var $i$124 = 0, $prev_fo$0$ph22 = 0, $prev_fo$1$ph40 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[65600>>2]|0;
 $1 = ($0|0)==(-1);
 $2 = 1 << $0;
 $$ = $1 ? 0 : $2;
 $3 = HEAP32[((65408 + 8|0))>>2]|0;
 HEAP32[65640>>2] = $3;
 $4 = HEAP32[((65424 + 8|0))>>2]|0;
 HEAP32[65648>>2] = $4;
 _GC_make_disappearing_links_disappear(65408);
 if ($1) {
  HEAP32[((56 + 40|0))>>2] = 0;
 } else {
  $i$036 = 0;
  while(1) {
   $5 = HEAP32[65440>>2]|0;
   $6 = (($5) + ($i$036<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    $curr_fo$032 = $7;
    while(1) {
     $9 = HEAP32[$curr_fo$032>>2]|0;
     $10 = $9 ^ -1;
     $11 = $10 >>> 12;
     $12 = $11 & 1023;
     $13 = $10 >>> 22;
     $14 = ((56 + ($13<<2)|0) + 57964|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($15) + ($12<<2)|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = $10 >>> 3;
     $19 = $10 >>> 8;
     $20 = $19 & 15;
     $21 = ((($17) + ($20<<2)|0) + 36|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = $18 & 31;
     $24 = 1 << $23;
     $25 = $22 & $24;
     $26 = ($25|0)==(0);
     if ($26) {
      $27 = $10;
      $28 = (($curr_fo$032) + 20|0);
      $29 = HEAP32[$28>>2]|0;
      FUNCTION_TABLE_vi[$29 & 4095]($27);
      $30 = HEAP32[((56 + 68|0))>>2]|0;
      $31 = HEAP32[((56 + 60|0))>>2]|0;
      $32 = ($30>>>0)<($31>>>0);
      if (!($32)) {
       $35 = $31;$36 = $30;
       while(1) {
        $33 = HEAP32[65592>>2]|0;
        $34 = (($35) + ($33<<3)|0);
        $37 = (_GC_mark_from($36,$35,$34)|0);
        HEAP32[((56 + 68|0))>>2] = $37;
        $38 = HEAP32[((56 + 60|0))>>2]|0;
        $39 = ($37>>>0)<($38>>>0);
        if ($39) {
         break;
        } else {
         $35 = $38;$36 = $37;
        }
       }
      }
      $40 = HEAP32[65672>>2]|0;
      $41 = ($40|0)==(0);
      if (!($41)) {
       $42 = HEAP32[$14>>2]|0;
       $43 = (($42) + ($12<<2)|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ((($44) + ($20<<2)|0) + 36|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = $46 & $24;
       $48 = ($47|0)==(0);
       if ($48) {
        $49 = $46 | $24;
        HEAP32[$45>>2] = $49;
        $50 = (($44) + 32|0);
        $51 = HEAP32[$50>>2]|0;
        $52 = (($51) + 1)|0;
        HEAP32[$50>>2] = $52;
       }
       while(1) {
        $53 = (_GC_mark_some(0)|0);
        $54 = ($53|0)==(0);
        if (!($54)) {
         break;
        }
       }
      }
      $55 = HEAP32[$14>>2]|0;
      $56 = (($55) + ($12<<2)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ((($57) + ($20<<2)|0) + 36|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = $59 & $24;
      $61 = ($60|0)==(0);
      if (!($61)) {
       _GC_default_warn_proc(65680,$10);
      }
     }
     $62 = (($curr_fo$032) + 4|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63|0)==(0|0);
     if ($64) {
      break;
     } else {
      $curr_fo$032 = $63;
     }
    }
   }
   $65 = (($i$036) + 1)|0;
   $66 = ($65>>>0)<($$>>>0);
   if ($66) {
    $i$036 = $65;
   } else {
    break;
   }
  }
  HEAP32[((56 + 40|0))>>2] = 0;
  if (!($1)) {
   $i$124 = 0;
   while(1) {
    $67 = HEAP32[65440>>2]|0;
    $68 = (($67) + ($i$124<<2)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(0|0);
    L26: do {
     if (!($70)) {
      $curr_fo$1$ph23 = $69;$prev_fo$0$ph22 = 0;
      while(1) {
       $71 = ($prev_fo$0$ph22|0)==(0|0);
       $72 = (($prev_fo$0$ph22) + 4|0);
       $curr_fo$118 = $curr_fo$1$ph23;
       while(1) {
        $73 = HEAP32[$curr_fo$118>>2]|0;
        $74 = $73 ^ -1;
        $75 = $74 >>> 12;
        $76 = $75 & 1023;
        $77 = $74 >>> 22;
        $78 = ((56 + ($77<<2)|0) + 57964|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = (($79) + ($76<<2)|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = $74 >>> 3;
        $83 = $74 >>> 8;
        $84 = $83 & 15;
        $85 = ((($81) + ($84<<2)|0) + 36|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = $82 & 31;
        $88 = 1 << $87;
        $89 = $86 & $88;
        $90 = ($89|0)==(0);
        if (!($90)) {
         break;
        }
        $91 = (1)==(0);
        if ($91) {
         $92 = $86 | $88;
         HEAP32[$85>>2] = $92;
         $93 = (($81) + 32|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = (($94) + 1)|0;
         HEAP32[$93>>2] = $95;
        }
        $96 = (($curr_fo$118) + 4|0);
        $97 = HEAP32[$96>>2]|0;
        if ($71) {
         $98 = HEAP32[65440>>2]|0;
         $99 = (($98) + ($i$124<<2)|0);
         HEAP32[$99>>2] = $97;
        } else {
         HEAP32[$72>>2] = $97;
        }
        $100 = HEAP32[65136>>2]|0;
        $101 = (($100) + -1)|0;
        HEAP32[65136>>2] = $101;
        $102 = HEAP32[65448>>2]|0;
        HEAP32[$96>>2] = $102;
        HEAP32[65448>>2] = $curr_fo$118;
        $103 = HEAP32[$curr_fo$118>>2]|0;
        $104 = $103 ^ -1;
        HEAP32[$curr_fo$118>>2] = $104;
        $105 = (($curr_fo$118) + 16|0);
        $106 = HEAP32[$105>>2]|0;
        $107 = (($106) + 24)|0;
        $108 = HEAP32[((56 + 40|0))>>2]|0;
        $109 = (($107) + ($108))|0;
        HEAP32[((56 + 40|0))>>2] = $109;
        $110 = ($97|0)==(0|0);
        if ($110) {
         break L26;
        } else {
         $curr_fo$118 = $97;
        }
       }
       $111 = (($curr_fo$118) + 4|0);
       $112 = HEAP32[$111>>2]|0;
       $113 = ($112|0)==(0|0);
       if ($113) {
        break;
       } else {
        $curr_fo$1$ph23 = $112;$prev_fo$0$ph22 = $curr_fo$118;
       }
      }
     }
    } while(0);
    $114 = (($i$124) + 1)|0;
    $115 = ($114>>>0)<($$>>>0);
    if ($115) {
     $i$124 = $114;
    } else {
     break;
    }
   }
  }
 }
 $116 = (1)==(0);
 L43: do {
  if (!($116)) {
   $117 = HEAP32[65448>>2]|0;
   $118 = ($117|0)==(0|0);
   if (!($118)) {
    $curr_fo$215 = $117;
    while(1) {
     $119 = HEAP32[$curr_fo$215>>2]|0;
     $120 = $119;
     $121 = $119 >>> 12;
     $122 = $121 & 1023;
     $123 = $119 >>> 22;
     $124 = ((56 + ($123<<2)|0) + 57964|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = (($125) + ($122<<2)|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = $119 >>> 3;
     $129 = $119 >>> 8;
     $130 = $129 & 15;
     $131 = ((($127) + ($130<<2)|0) + 36|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = $128 & 31;
     $134 = 1 << $133;
     $135 = $132 & $134;
     $136 = ($135|0)==(0);
     if ($136) {
      $137 = (($curr_fo$215) + 20|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = ($138|0)==(3297|0);
      if ($139) {
       $140 = (($127) + 20|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = ($141|0)==(0);
       $$pre = HEAP32[((56 + 68|0))>>2]|0;
       if ($142) {
        $156 = $$pre;
       } else {
        $143 = (($$pre) + 8|0);
        HEAP32[((56 + 68|0))>>2] = $143;
        $144 = HEAP32[65592>>2]|0;
        $145 = HEAP32[((56 + 60|0))>>2]|0;
        $146 = (($145) + ($144<<3)|0);
        $147 = ($143>>>0)<($146>>>0);
        if ($147) {
         $151 = $143;
        } else {
         HEAP32[65672>>2] = 5;
         HEAP32[65888>>2] = 1;
         $148 = HEAP32[62240>>2]|0;
         $149 = ($148|0)==(0);
         if (!($149)) {
          HEAP32[$vararg_buffer>>2] = $144;
          _GC_log_printf(66000,$vararg_buffer);
         }
         $150 = (($$pre) + -4088|0);
         HEAP32[((56 + 68|0))>>2] = $150;
         $151 = $150;
        }
        HEAP32[$151>>2] = $120;
        $152 = HEAP32[((56 + 68|0))>>2]|0;
        $153 = (($152) + 4|0);
        HEAP32[$153>>2] = $141;
        $156 = $152;
       }
       $154 = HEAP32[((56 + 60|0))>>2]|0;
       $155 = ($156>>>0)<($154>>>0);
       if (!($155)) {
        $159 = $154;$160 = $156;
        while(1) {
         $157 = HEAP32[65592>>2]|0;
         $158 = (($159) + ($157<<3)|0);
         $161 = (_GC_mark_from($160,$159,$158)|0);
         HEAP32[((56 + 68|0))>>2] = $161;
         $162 = HEAP32[((56 + 60|0))>>2]|0;
         $163 = ($161>>>0)<($162>>>0);
         if ($163) {
          break;
         } else {
          $159 = $162;$160 = $161;
         }
        }
       }
       $164 = HEAP32[65672>>2]|0;
       $165 = ($164|0)==(0);
       if (!($165)) {
        $166 = HEAP32[$124>>2]|0;
        $167 = (($166) + ($122<<2)|0);
        $168 = HEAP32[$167>>2]|0;
        $169 = ((($168) + ($130<<2)|0) + 36|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = $170 & $134;
        $172 = ($171|0)==(0);
        if ($172) {
         $173 = $170 | $134;
         HEAP32[$169>>2] = $173;
         $174 = (($168) + 32|0);
         $175 = HEAP32[$174>>2]|0;
         $176 = (($175) + 1)|0;
         HEAP32[$174>>2] = $176;
        }
        while(1) {
         $177 = (_GC_mark_some(0)|0);
         $178 = ($177|0)==(0);
         if (!($178)) {
          break;
         }
        }
       }
       $$pr = HEAP32[$137>>2]|0;
       $180 = $$pr;
      } else {
       $180 = $138;
      }
      $179 = ($180|0)==(3298|0);
      if (!($179)) {
       $181 = HEAP32[$124>>2]|0;
       $182 = (($181) + ($122<<2)|0);
       $183 = HEAP32[$182>>2]|0;
       $184 = ((($183) + ($130<<2)|0) + 36|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = $185 & $134;
       $187 = ($186|0)==(0);
       if ($187) {
        $188 = $185 | $134;
        HEAP32[$184>>2] = $188;
        $189 = (($183) + 32|0);
        $190 = HEAP32[$189>>2]|0;
        $191 = (($190) + 1)|0;
        HEAP32[$189>>2] = $191;
       }
      }
     }
     $192 = (($curr_fo$215) + 4|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = ($193|0)==(0|0);
     if ($194) {
      break;
     } else {
      $curr_fo$215 = $193;
     }
    }
   }
   $195 = (0)==(0);
   if (!($195)) {
    $196 = HEAP32[65448>>2]|0;
    $197 = ($196|0)==(0|0);
    if (!($197)) {
     $curr_fo$3$ph41 = $196;$prev_fo$1$ph40 = 0;
     while(1) {
      $198 = ($prev_fo$1$ph40|0)==(0|0);
      $199 = (($prev_fo$1$ph40) + 4|0);
      $curr_fo$313 = $curr_fo$3$ph41;
      while(1) {
       $200 = (($curr_fo$313) + 4|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = (($curr_fo$313) + 20|0);
       $203 = HEAP32[$202>>2]|0;
       $204 = ($203|0)==(3298|0);
       if (!($204)) {
        break;
       }
       $205 = HEAP32[$curr_fo$313>>2]|0;
       $206 = $205 >>> 12;
       $207 = $206 & 1023;
       $208 = $205 >>> 22;
       $209 = ((56 + ($208<<2)|0) + 57964|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = (($210) + ($207<<2)|0);
       $212 = HEAP32[$211>>2]|0;
       $213 = $205 >>> 3;
       $214 = $205 >>> 8;
       $215 = $214 & 15;
       $216 = ((($212) + ($215<<2)|0) + 36|0);
       $217 = HEAP32[$216>>2]|0;
       $218 = $213 & 31;
       $219 = 1 << $218;
       $220 = $217 & $219;
       $221 = ($220|0)==(0);
       if ($221) {
        label = 54;
        break;
       }
       if ($198) {
        HEAP32[65448>>2] = $201;
       } else {
        HEAP32[$199>>2] = $201;
       }
       $227 = $205 ^ -1;
       HEAP32[$curr_fo$313>>2] = $227;
       $228 = (($curr_fo$313) + 16|0);
       $229 = HEAP32[$228>>2]|0;
       $230 = HEAP32[((56 + 40|0))>>2]|0;
       $$neg5 = (-24 - ($229))|0;
       $231 = (($$neg5) + ($230))|0;
       HEAP32[((56 + 40|0))>>2] = $231;
       $232 = HEAP32[65600>>2]|0;
       $233 = (($232) + 3)|0;
       $234 = $205 >>> $233;
       $235 = $234 ^ $213;
       $236 = 1 << $232;
       $237 = (($236) + -1)|0;
       $238 = $235 & $237;
       $239 = HEAP32[65440>>2]|0;
       $240 = (($239) + ($238<<2)|0);
       $241 = HEAP32[$240>>2]|0;
       HEAP32[$200>>2] = $241;
       $242 = HEAP32[65136>>2]|0;
       $243 = (($242) + 1)|0;
       HEAP32[65136>>2] = $243;
       $244 = HEAP32[65440>>2]|0;
       $245 = (($244) + ($238<<2)|0);
       HEAP32[$245>>2] = $curr_fo$313;
       $246 = ($201|0)==(0|0);
       if ($246) {
        break L43;
       } else {
        $curr_fo$313 = $201;
       }
      }
      if ((label|0) == 54) {
       label = 0;
       $223 = $217 | $219;
       HEAP32[$216>>2] = $223;
       $224 = (($212) + 32|0);
       $225 = HEAP32[$224>>2]|0;
       $226 = (($225) + 1)|0;
       HEAP32[$224>>2] = $226;
      }
      $222 = ($201|0)==(0|0);
      if ($222) {
       break;
      } else {
       $curr_fo$3$ph41 = $201;$prev_fo$1$ph40 = $curr_fo$313;
      }
     }
    }
   }
  }
 } while(0);
 _GC_remove_dangling_disappearing_links(65408);
 _GC_make_disappearing_links_disappear(65424);
 _GC_remove_dangling_disappearing_links(65424);
 $247 = HEAP32[63752>>2]|0;
 $248 = ($247|0)==(0);
 if ($248) {
  STACKTOP = sp;return;
 }
 HEAP32[65656>>2] = 0;
 STACKTOP = sp;return;
}
function _GC_gcollect() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[62424>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  _GC_init();
 }
 $2 = (0)==(0);
 if (!($2)) {
  abort /* segfault, call an absolute addr */ ();
 }
 _GC_notify_or_invoke_finalizers();
 $3 = (_GC_try_to_collect_inner(1)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (0)==(0);
  if (!($5)) {
   abort /* segfault, call an absolute addr */ ();
  }
  _GC_notify_or_invoke_finalizers();
 }
 $6 = HEAP32[62768>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 _GC_print_all_errors();
 STACKTOP = sp;return;
}
function _GC_add_to_heap($p,$bytes) {
 $p = $p|0;
 $bytes = $bytes|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $endp$0 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[63528>>2]|0;
 $1 = ($0>>>0)>(511);
 if ($1) {
  _GC_default_on_abort(64864);
  _abort();
  // unreachable;
 } else {
  $$0 = $p;$$02 = $bytes;
 }
 while(1) {
  $2 = $$0;
  $3 = ($$0>>>0)<((4097)>>>0);
  if (!($3)) {
   break;
  }
  $4 = (($$0) + 4096|0);
  $5 = (($$02) + -4096)|0;
  $6 = ($5|0)==(0);
  if ($6) {
   label = 13;
   break;
  } else {
   $$0 = $4;$$02 = $5;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
 $7 = (($2) + ($$02))|0;
 $8 = ($7>>>0)>($2>>>0);
 do {
  if ($8) {
   $$1 = $$02;$endp$0 = $7;
  } else {
   $9 = (($$02) + -4096)|0;
   $10 = ($9|0)==(0);
   if ($10) {
    STACKTOP = sp;return;
   } else {
    $11 = (($7) + -4096)|0;
    $$1 = $9;$endp$0 = $11;
    break;
   }
  }
 } while(0);
 $12 = (_GC_install_header($$0)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[63528>>2]|0;
 $15 = ((56 + ($14<<3)|0) + 16744|0);
 HEAP32[$15>>2] = $$0;
 $16 = ((56 + ($14<<3)|0) + 16748|0);
 HEAP32[$16>>2] = $$1;
 $17 = (($14) + 1)|0;
 HEAP32[63528>>2] = $17;
 $18 = (($12) + 16|0);
 HEAP32[$18>>2] = $$1;
 $19 = (($12) + 13|0);
 HEAP8[$19>>0] = 0;
 _GC_freehblk($$0);
 $20 = HEAP32[56>>2]|0;
 $21 = (($20) + ($$1))|0;
 HEAP32[56>>2] = $21;
 $22 = HEAP32[64928>>2]|0;
 $23 = ($$0>>>0)<=($22>>>0);
 $24 = ($22|0)==(0|0);
 $or$cond = $23 | $24;
 if ($or$cond) {
  $25 = (($$0) + -4|0);
  HEAP32[64928>>2] = $25;
 }
 $26 = (($$1) + ($2))|0;
 $27 = HEAP32[64936>>2]|0;
 $28 = $27;
 $29 = ($26>>>0)<($28>>>0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = $endp$0;
 HEAP32[64936>>2] = $30;
 STACKTOP = sp;return;
}
function _GC_print_heap_sects() {
 var $$0$i = 0, $$0$i$us = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $h$01 = 0, $h$01$us = 0, $i$05 = 0, $index$0$i = 0, $index$0$i$in = 0, $index$0$i$in$in = 0, $nbl$0$ = 0, $nbl$0$$us = 0;
 var $nbl$0$lcssa = 0, $nbl$03 = 0, $nbl$03$us = 0, $not$$us = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer1 = sp;
 $0 = HEAP32[56>>2]|0;
 HEAP32[$vararg_buffer1>>2] = $0;
 _GC_printf(64944,$vararg_buffer1);
 $1 = HEAP32[63528>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $i$05 = 0;
 }
 while(1) {
  $3 = ((56 + ($i$05<<3)|0) + 16744|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ((56 + ($i$05<<3)|0) + 16748|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + ($6)|0);
  $8 = ($6|0)>(0);
  L5: do {
   if ($8) {
    $9 = (1)==(0);
    $10 = HEAP32[8>>2]|0;
    $11 = HEAP32[16>>2]|0;
    $12 = HEAP32[24>>2]|0;
    $13 = HEAP32[32>>2]|0;
    if ($9) {
     $h$01$us = $4;$nbl$03$us = 0;
    } else {
     $h$01 = $4;$nbl$03 = 0;
     while(1) {
      $index$0$i$in$in = $h$01;
      $index$0$i$in = $index$0$i$in$in >>> 12;
      $index$0$i = $index$0$i$in$in >>> 17;
      $47 = $index$0$i & 8191;
      $48 = (($12) + ($47<<2)|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0);
      if ($50) {
       $51 = (($13) + ($47<<2)|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52|0)==(0);
       if ($53) {
        label = 18;
       } else {
        label = 16;
       }
      } else {
       label = 16;
      }
      if ((label|0) == 16) {
       label = 0;
       $54 = $index$0$i$in & 31;
       $55 = 1 << $54;
       $56 = $55 & $49;
       $57 = ($56|0)==(0);
       if ($57) {
        $58 = (($13) + ($47<<2)|0);
        $59 = HEAP32[$58>>2]|0;
        $60 = $59 & $55;
        $61 = ($60|0)==(0);
        if ($61) {
         label = 18;
        } else {
         $$0$i = 1;
        }
       } else {
        $$0$i = 1;
       }
      }
      if ((label|0) == 18) {
       label = 0;
       $$0$i = 0;
      }
      $nbl$0$ = (($$0$i) + ($nbl$03))|0;
      $62 = (($h$01) + 4096|0);
      $63 = ($62>>>0)<($7>>>0);
      if ($63) {
       $h$01 = $62;$nbl$03 = $nbl$0$;
      } else {
       $nbl$0$lcssa = $nbl$0$;
       break L5;
      }
     }
    }
    while(1) {
     $14 = $h$01$us;
     $15 = $14 >>> 12;
     $16 = $15 & 262143;
     $17 = $16 >>> 5;
     $18 = (($10) + ($17<<2)|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $15 & 31;
     $21 = 1 << $20;
     $22 = $19 & $21;
     $23 = ($22|0)==(0);
     L20: do {
      if ($23) {
       $24 = (($11) + ($17<<2)|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = $25 & $21;
       $27 = ($26|0)==(0);
       if ($27) {
        $29 = $16 >>> 5;
        $30 = (($12) + ($29<<2)|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = ($31|0)==(0);
        if ($32) {
         $33 = (($13) + ($29<<2)|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = ($34|0)==(0);
         if (!($35)) {
          label = 9;
         }
        } else {
         label = 9;
        }
        do {
         if ((label|0) == 9) {
          label = 0;
          $36 = $15 & 31;
          $37 = 1 << $36;
          $38 = $37 & $31;
          $39 = ($38|0)==(0);
          if ($39) {
           $40 = (($13) + ($29<<2)|0);
           $41 = HEAP32[$40>>2]|0;
           $42 = $41 & $37;
           $43 = ($42|0)==(0);
           if ($43) {
            break;
           }
          }
          $44 = (($h$01$us) + 4096|0);
          $$0$i$us = $44;$$pre$phiZ2D = $44;
          break L20;
         }
        } while(0);
        $$pre = (($h$01$us) + 4096|0);
        $$0$i$us = 0;$$pre$phiZ2D = $$pre;
       } else {
        label = 6;
       }
      } else {
       label = 6;
      }
     } while(0);
     if ((label|0) == 6) {
      label = 0;
      $28 = (($h$01$us) + 4096|0);
      $$0$i$us = $28;$$pre$phiZ2D = $28;
     }
     $not$$us = ($$0$i$us|0)!=(0|0);
     $45 = $not$$us&1;
     $nbl$0$$us = (($45) + ($nbl$03$us))|0;
     $46 = ($$pre$phiZ2D>>>0)<($7>>>0);
     if ($46) {
      $h$01$us = $$pre$phiZ2D;$nbl$03$us = $nbl$0$$us;
     } else {
      $nbl$0$lcssa = $nbl$0$$us;
      break;
     }
    }
   } else {
    $nbl$0$lcssa = 0;
   }
  } while(0);
  $64 = $6 >>> 12;
  HEAP32[$vararg_buffer1>>2] = $i$05;
  $vararg_ptr4 = (($vararg_buffer1) + 4|0);
  HEAP32[$vararg_ptr4>>2] = $4;
  $vararg_ptr5 = (($vararg_buffer1) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $7;
  $vararg_ptr6 = (($vararg_buffer1) + 12|0);
  HEAP32[$vararg_ptr6>>2] = $nbl$0$lcssa;
  $vararg_ptr7 = (($vararg_buffer1) + 16|0);
  HEAP32[$vararg_ptr7>>2] = $64;
  _GC_printf(64968,$vararg_buffer1);
  $65 = (($i$05) + 1)|0;
  $66 = HEAP32[63528>>2]|0;
  $67 = ($65>>>0)<($66>>>0);
  if ($67) {
   $i$05 = $65;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _GC_expand_hp_inner($n) {
 $n = $n|0;
 var $$ = 0, $$$i = 0, $$$i$i = 0, $$$i$op = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $n$op = 0, $n$op$op = 0, $not$$i = 0, $or$cond = 0, $or$cond$not = 0, $or$cond1 = 0, $or$cond3 = 0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($n>>>0)<(16);
 $n$op = $n << 12;
 $1 = HEAP32[65032>>2]|0;
 $n$op$op = (($n$op) + -1)|0;
 $2 = $0 ? 65535 : $n$op$op;
 $3 = (($2) + ($1))|0;
 $4 = (0 - ($1))|0;
 $5 = $3 & $4;
 $6 = HEAP32[65016>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = HEAP32[56>>2]|0;
  $9 = (($8) + ($5))|0;
  $10 = ($9>>>0)>($6>>>0);
  if ($10) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $11 = (_sbrk(0)|0);
 $12 = $11;
 $13 = HEAP32[65032>>2]|0;
 $14 = (($13) + -1)|0;
 $15 = $14 & $12;
 $16 = ($5|0)<(0);
 do {
  if (!($16)) {
   $17 = ($15|0)==(0);
   if (!($17)) {
    $18 = (($13) - ($15))|0;
    $19 = (_sbrk(($18|0))|0);
    $20 = ($19|0)==((-1)|0);
    if ($20) {
     break;
    }
   }
   $21 = (_sbrk(($5|0))|0);
   $22 = ($21|0)==((-1)|0);
   $$$i$i = $22 ? 0 : $21;
   $23 = ($$$i$i|0)==(0|0);
   if (!($23)) {
    $24 = HEAP32[62240>>2]|0;
    $25 = ($24|0)==(0);
    if (!($25)) {
     $26 = HEAP32[56>>2]|0;
     $27 = (($5) + 511)|0;
     $28 = (($27) + ($26))|0;
     $29 = $28 >>> 10;
     $30 = HEAP32[((56 + 32|0))>>2]|0;
     HEAP32[$vararg_buffer>>2] = $29;
     $vararg_ptr1 = (($vararg_buffer) + 4|0);
     HEAP32[$vararg_ptr1>>2] = $30;
     _GC_log_printf(65088,$vararg_buffer);
    }
    $31 = HEAP32[((56 + 3412|0))>>2]|0;
    $32 = $31 << 1;
    $33 = HEAP32[((56 + 3416|0))>>2]|0;
    $34 = $33 >>> 2;
    $35 = (($32) + 0)|0;
    $36 = (($35) + ($34))|0;
    $37 = HEAP32[63944>>2]|0;
    $38 = (($36>>>0) / ($37>>>0))&-1;
    $39 = HEAP32[62432>>2]|0;
    $not$$i = ($39|0)!=(0);
    $40 = $not$$i&1;
    $$$i = $38 >>> $40;
    $41 = ($$$i|0)!=(0);
    $$$i$op = (($$$i) + 33554432)|0;
    $42 = $41 ? $$$i$op : 33554433;
    $43 = HEAP32[((56 + 8|0))>>2]|0;
    $44 = ($43|0)!=(0|0);
    $45 = ($$$i$i|0)<(0|0);
    $or$cond = $44 | $45;
    $or$cond$not = $or$cond ^ 1;
    $46 = ($43>>>0)<($$$i$i>>>0);
    $or$cond1 = $44 & $46;
    $or$cond3 = $or$cond1 | $or$cond$not;
    $47 = $$$i$i;
    if ($or$cond3) {
     $48 = (($47) + ($5))|0;
     $49 = (($48) + ($42))|0;
     $50 = ($49>>>0)>($47>>>0);
     if ($50) {
      $51 = HEAP32[64936>>2]|0;
      $52 = $51;
      $53 = ($52>>>0)>($49>>>0);
      $54 = $53 ? $52 : $49;
      $55 = $54;
      HEAP32[64936>>2] = $55;
     }
    } else {
     $56 = (($47) - ($42))|0;
     $57 = ($56>>>0)<($47>>>0);
     if ($57) {
      $58 = HEAP32[64928>>2]|0;
      $59 = $58;
      $60 = ($59>>>0)<($56>>>0);
      $61 = $60 ? $59 : $56;
      $62 = $61;
      HEAP32[64928>>2] = $62;
     }
    }
    HEAP32[((56 + 12|0))>>2] = $43;
    HEAP32[((56 + 8|0))>>2] = $$$i$i;
    _GC_add_to_heap($$$i$i,$5);
    $63 = HEAP32[56>>2]|0;
    $64 = (($42) + -16777216)|0;
    $65 = (($64) + ($63))|0;
    $66 = ($65>>>0)<($63>>>0);
    $$ = $66 ? -1 : $65;
    HEAP32[64056>>2] = $$;
    $67 = (0|0)==(0|0);
    if ($67) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    abort /* segfault, call an absolute addr */ (($63|0));
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 _GC_default_warn_proc(65040,$5);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GC_is_marked($p) {
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $p;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $0 >>> 3;
 $9 = $0 >>> 8;
 $10 = $9 & 15;
 $11 = ((($7) + ($10<<2)|0) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $8 & 31;
 $14 = $12 >>> $13;
 $15 = $14 & 1;
 STACKTOP = sp;return ($15|0);
}
function _GC_check_leaked($base) {
 $base = $base|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $not$ = 0, $or$cond$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($base) + 16|0);
 $1 = $base;
 $2 = $1 >>> 12;
 $3 = $2 & 1023;
 $4 = $1 >>> 22;
 $5 = ((56 + ($4<<2)|0) + 57964|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($3<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $1 & -4096;
 $12 = $11;
 $13 = $0;
 $14 = $13 & -4096;
 $15 = $14;
 $16 = ($12|0)!=($15|0);
 $17 = ($10>>>0)<(20);
 $or$cond$i = $16 | $17;
 if ($or$cond$i) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($base) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $13 ^ -19075637;
 $21 = ($19|0)==($20|0);
 if (!($21)) {
  $22 = $10 >>> 2;
  $23 = (($22) + -1)|0;
  $24 = (($base) + ($23<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $13 ^ -1126248977;
  $27 = ($25|0)==($26|0);
  if (!($27)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $28 = (($base) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $not$ = ($29|0)==($10|0);
 if (!($not$)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (($10) + -16)|0;
 $31 = $30 >>> 2;
 $32 = ($31|0)==(0);
 if ($32) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$01 = 0;
 }
 while(1) {
  $35 = (($0) + ($i$01<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(-559038737);
  $34 = (($i$01) + 1)|0;
  if (!($37)) {
   break;
  }
  $33 = ($34>>>0)<($31>>>0);
  if ($33) {
   $i$01 = $34;
  } else {
   $$0 = 0;
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 $38 = $1 >>> 3;
 $39 = $1 >>> 8;
 $40 = $39 & 15;
 $41 = ((($8) + ($40<<2)|0) + 36|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $38 & 31;
 $44 = 1 << $43;
 $45 = $42 & $44;
 $46 = ($45|0)==(0);
 if ($46) {
  $47 = $42 | $44;
  HEAP32[$41>>2] = $47;
  $48 = (($8) + 32|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 1)|0;
  HEAP32[$48>>2] = $50;
 }
 $51 = HEAP32[65400>>2]|0;
 $52 = (65320 + ($51<<2)|0);
 HEAP32[$52>>2] = $35;
 $53 = ($51>>>0)<(19);
 if ($53) {
  $54 = (($51) + 1)|0;
  HEAP32[65400>>2] = $54;
 }
 HEAP32[62768>>2] = 1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GC_register_finalizer_no_order($obj,$fn,$cd,$ofn,$ocd) {
 $obj = $obj|0;
 $fn = $fn|0;
 $cd = $cd|0;
 $ofn = $ofn|0;
 $ocd = $ocd|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _GC_register_finalizer_inner($obj,$fn,$cd,$ofn,$ocd,3297);
 STACKTOP = sp;return;
}
function _GC_push_finalizer_structures() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  if (((((((65424) + 3)|0) & -4)>>>0)<((((65424 + 4|0)))>>>0))) {
   $0 = HEAP32[((56 + 68|0))>>2]|0;
   $1 = (($0) + 8|0);
   HEAP32[((56 + 68|0))>>2] = $1;
   $2 = HEAP32[((56 + 64|0))>>2]|0;
   $3 = ($1>>>0)<($2>>>0);
   if ($3) {
    HEAP32[$1>>2] = (((((65424) + 3)|0) & -4));
    $4 = HEAP32[((56 + 68|0))>>2]|0;
    $5 = (($4) + 4|0);
    HEAP32[$5>>2] = (((((65424 + 4|0))) - ((((65424) + 3)|0) & -4))|0);
    break;
   } else {
    _GC_default_on_abort(66080);
    _abort();
    // unreachable;
   }
  }
 } while(0);
 do {
  if (((((((65408) + 3)|0) & -4)>>>0)<((((65408 + 4|0)))>>>0))) {
   $6 = HEAP32[((56 + 68|0))>>2]|0;
   $7 = (($6) + 8|0);
   HEAP32[((56 + 68|0))>>2] = $7;
   $8 = HEAP32[((56 + 64|0))>>2]|0;
   $9 = ($7>>>0)<($8>>>0);
   if ($9) {
    HEAP32[$7>>2] = (((((65408) + 3)|0) & -4));
    $10 = HEAP32[((56 + 68|0))>>2]|0;
    $11 = (($10) + 4|0);
    HEAP32[$11>>2] = (((((65408 + 4|0))) - ((((65408) + 3)|0) & -4))|0);
    break;
   } else {
    _GC_default_on_abort(66080);
    _abort();
    // unreachable;
   }
  }
 } while(0);
 do {
  if (((((((65440) + 3)|0) & -4)>>>0)<((((65440 + 4|0)))>>>0))) {
   $12 = HEAP32[((56 + 68|0))>>2]|0;
   $13 = (($12) + 8|0);
   HEAP32[((56 + 68|0))>>2] = $13;
   $14 = HEAP32[((56 + 64|0))>>2]|0;
   $15 = ($13>>>0)<($14>>>0);
   if ($15) {
    HEAP32[$13>>2] = (((((65440) + 3)|0) & -4));
    $16 = HEAP32[((56 + 68|0))>>2]|0;
    $17 = (($16) + 4|0);
    HEAP32[$17>>2] = (((((65440 + 4|0))) - ((((65440) + 3)|0) & -4))|0);
    break;
   } else {
    _GC_default_on_abort(66080);
    _abort();
    // unreachable;
   }
  }
 } while(0);
 if (!(((((((65448) + 3)|0) & -4)>>>0)<((((65448 + 4|0)))>>>0)))) {
  STACKTOP = sp;return;
 }
 $18 = HEAP32[((56 + 68|0))>>2]|0;
 $19 = (($18) + 8|0);
 HEAP32[((56 + 68|0))>>2] = $19;
 $20 = HEAP32[((56 + 64|0))>>2]|0;
 $21 = ($19>>>0)<($20>>>0);
 if (!($21)) {
  _GC_default_on_abort(66080);
  _abort();
  // unreachable;
 }
 HEAP32[$19>>2] = (((((65448) + 3)|0) & -4));
 $22 = HEAP32[((56 + 68|0))>>2]|0;
 $23 = (($22) + 4|0);
 HEAP32[$23>>2] = (((((65448 + 4|0))) - ((((65448) + 3)|0) & -4))|0);
 STACKTOP = sp;return;
}
function _GC_grow_table($table,$log_size_ptr) {
 $table = $table|0;
 $log_size_ptr = $log_size_ptr|0;
 var $$ = 0, $$0$i = 0, $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $p$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$log_size_ptr>>2]|0;
 $1 = (($0) + 1)|0;
 $2 = ($0|0)==(-1);
 $3 = 1 << $0;
 $$ = $2 ? 0 : $3;
 $4 = 1 << $1;
 $5 = $4 << 2;
 $6 = ($5>>>0)<(4097);
 if ($6) {
  $7 = (_GC_generic_malloc_inner($5,1)|0);
  $$0$i = $7;
 } else {
  $8 = (1 + ($5))|0;
  $9 = (_GC_alloc_large($8,1,1)|0);
  $10 = (($8) + 4095)|0;
  $11 = $10 & -4096;
  $12 = ($9|0)==(0|0);
  if ($12) {
   $$0$i$i = 0;
  } else {
   $13 = HEAP32[((62448 + 36|0))>>2]|0;
   $14 = $13 | 0;
   $15 = ($14|0)==(0);
   if ($15) {
    $$0$i$i = $9;
   } else {
    _memset(($9|0),0,($11|0))|0;
    $$0$i$i = $9;
   }
  }
  $16 = HEAP32[((56 + 32|0))>>2]|0;
  $17 = (($16) + ($8))|0;
  HEAP32[((56 + 32|0))>>2] = $17;
  $$0$i = $$0$i$i;
 }
 $18 = ($$0$i|0)==(0|0);
 if ($18) {
  $21 = HEAP32[$table>>2]|0;
  $22 = ($21|0)==(0|0);
  if ($22) {
   _GC_default_on_abort(65456);
   _abort();
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 if (!($2)) {
  $19 = (($0) + 4)|0;
  $20 = (($4) + -1)|0;
  $i$03 = 0;
  while(1) {
   $23 = HEAP32[$table>>2]|0;
   $24 = (($23) + ($i$03<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $p$02 = $25;
    while(1) {
     $27 = HEAP32[$p$02>>2]|0;
     $28 = $27 ^ -1;
     $29 = (($p$02) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = $28 >>> 3;
     $32 = $28 >>> $19;
     $33 = $31 ^ $32;
     $34 = $33 & $20;
     $35 = (($$0$i) + ($34<<2)|0);
     $36 = HEAP32[$35>>2]|0;
     HEAP32[$29>>2] = $36;
     HEAP32[$35>>2] = $p$02;
     $37 = ($30|0)==(0|0);
     if ($37) {
      break;
     } else {
      $p$02 = $30;
     }
    }
   }
   $38 = (($i$03) + 1)|0;
   $39 = ($38>>>0)<($$>>>0);
   if ($39) {
    $i$03 = $38;
   } else {
    break;
   }
  }
 }
 HEAP32[$log_size_ptr>>2] = $1;
 HEAP32[$table>>2] = $$0$i;
 STACKTOP = sp;return;
}
function _GC_general_register_disappearing_link($link,$obj) {
 $link = $link|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $link;
 $1 = $0 & 3;
 $2 = ($1|0)!=(0);
 $3 = ($link|0)==(0|0);
 $or$cond = $2 | $3;
 if ($or$cond) {
  _GC_default_on_abort(65536);
  _abort();
  // unreachable;
 } else {
  $4 = (_GC_register_disappearing_link_inner(65408,$link,$obj)|0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function _GC_register_disappearing_link_inner($dl_hashtbl,$link,$obj) {
 $dl_hashtbl = $dl_hashtbl|0;
 $link = $link|0;
 $obj = $obj|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre10 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $curr_dl$04 = 0, $curr_dl$12 = 0, $index$0 = 0, $new_dl$0$in = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($dl_hashtbl) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  label = 3;
 } else {
  $3 = (($dl_hashtbl) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = 1 << $1;
  $6 = ($4>>>0)>($5>>>0);
  if ($6) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  _GC_grow_table($dl_hashtbl,$0);
  $7 = HEAP32[62240>>2]|0;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = HEAP32[$0>>2]|0;
   $10 = 1 << $9;
   HEAP32[$vararg_buffer>>2] = $10;
   _GC_log_printf(65504,$vararg_buffer);
  }
 }
 $11 = $link;
 $12 = $11 >>> 3;
 $13 = HEAP32[$0>>2]|0;
 $14 = (($13) + 3)|0;
 $15 = $11 >>> $14;
 $16 = $15 ^ $12;
 $17 = 1 << $13;
 $18 = (($17) + -1)|0;
 $19 = $16 & $18;
 $20 = HEAP32[$dl_hashtbl>>2]|0;
 $21 = (($20) + ($19<<2)|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 L7: do {
  if (!($23)) {
   $24 = $11 ^ -1;
   $curr_dl$04 = $22;
   while(1) {
    $25 = HEAP32[$curr_dl$04>>2]|0;
    $26 = ($25|0)==($24|0);
    if ($26) {
     break;
    }
    $30 = (($curr_dl$04) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     break L7;
    } else {
     $curr_dl$04 = $31;
    }
   }
   $27 = $obj;
   $28 = $27 ^ -1;
   $29 = (($curr_dl$04) + 8|0);
   HEAP32[$29>>2] = $28;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $33 = (_GC_generic_malloc_inner(12,1)|0);
 $34 = ($33|0)==(0|0);
 L15: do {
  if ($34) {
   $35 = (_GC_default_oom_fn(12)|0);
   $36 = ($35|0)==(0|0);
   if ($36) {
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = HEAP32[$0>>2]|0;
   $38 = (($37) + 3)|0;
   $39 = $11 >>> $38;
   $40 = $39 ^ $12;
   $41 = 1 << $37;
   $42 = (($41) + -1)|0;
   $43 = $40 & $42;
   $44 = HEAP32[$dl_hashtbl>>2]|0;
   $45 = (($44) + ($43<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    $62 = 0;$index$0 = $43;$new_dl$0$in = $35;
   } else {
    $48 = $11 ^ -1;
    $curr_dl$12 = $46;
    while(1) {
     $49 = HEAP32[$curr_dl$12>>2]|0;
     $50 = ($49|0)==($48|0);
     if ($50) {
      break;
     }
     $54 = (($curr_dl$12) + 4|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==(0|0);
     if ($56) {
      $62 = $46;$index$0 = $43;$new_dl$0$in = $35;
      break L15;
     } else {
      $curr_dl$12 = $55;
     }
    }
    $51 = $obj;
    $52 = $51 ^ -1;
    $53 = (($curr_dl$12) + 8|0);
    HEAP32[$53>>2] = $52;
    _GC_free($35);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$pre = HEAP32[$dl_hashtbl>>2]|0;
   $$phi$trans$insert = (($$pre) + ($19<<2)|0);
   $$pre10 = HEAP32[$$phi$trans$insert>>2]|0;
   $62 = $$pre10;$index$0 = $19;$new_dl$0$in = $33;
  }
 } while(0);
 $57 = $obj;
 $58 = $57 ^ -1;
 $59 = (($new_dl$0$in) + 8|0);
 HEAP32[$59>>2] = $58;
 $60 = $11 ^ -1;
 HEAP32[$new_dl$0$in>>2] = $60;
 $61 = (($new_dl$0$in) + 4|0);
 HEAP32[$61>>2] = $62;
 $63 = HEAP32[$dl_hashtbl>>2]|0;
 $64 = (($63) + ($index$0<<2)|0);
 HEAP32[$64>>2] = $new_dl$0$in;
 $65 = (($dl_hashtbl) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _GC_unregister_disappearing_link($link) {
 $link = $link|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curr_dl$03$i = 0, $curr_dl$05$i = 0, $prev_dl$04$i = 0, $prev_dl$04$i$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $link;
 $1 = $0 & 3;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = $0 >>> 3;
 $4 = HEAP32[((65408 + 4|0))>>2]|0;
 $5 = (($4) + 3)|0;
 $6 = $0 >>> $5;
 $7 = $6 ^ $3;
 $8 = 1 << $4;
 $9 = (($8) + -1)|0;
 $10 = $7 & $9;
 $11 = HEAP32[65408>>2]|0;
 $12 = (($11) + ($10<<2)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = $0 ^ -1;
 $curr_dl$05$i = $13;$prev_dl$04$i = 0;
 while(1) {
  $16 = HEAP32[$curr_dl$05$i>>2]|0;
  $17 = ($16|0)==($15|0);
  if ($17) {
   label = 5;
   break;
  }
  $24 = (($curr_dl$05$i) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   $curr_dl$03$i = $25;
   break;
  } else {
   $prev_dl$04$i$phi = $curr_dl$05$i;$curr_dl$05$i = $25;$prev_dl$04$i = $prev_dl$04$i$phi;
  }
 }
 if ((label|0) == 5) {
  $18 = ($prev_dl$04$i|0)==(0|0);
  $19 = (($curr_dl$05$i) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  if ($18) {
   HEAP32[$12>>2] = $20;
  } else {
   $21 = (($prev_dl$04$i) + 4|0);
   HEAP32[$21>>2] = $20;
  }
  $22 = HEAP32[((65408 + 8|0))>>2]|0;
  $23 = (($22) + -1)|0;
  HEAP32[((65408 + 8|0))>>2] = $23;
  $curr_dl$03$i = $curr_dl$05$i;
 }
 $27 = ($curr_dl$03$i|0)==(0|0);
 if ($27) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 _GC_free($curr_dl$03$i);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _GC_mark_and_push($obj,$mark_stack_ptr,$mark_stack_limit,$src) {
 $obj = $obj|0;
 $mark_stack_ptr = $mark_stack_ptr|0;
 $mark_stack_limit = $mark_stack_limit|0;
 $src = $src|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$lobit = 0, $$pr = 0, $$pre$i = 0, $$pre$i16 = 0, $$pre$i23 = 0, $$pre$i3 = 0, $$pre$i30 = 0, $$pre$i9 = 0, $$pre$phi2$i14Z2D = 0, $$pre$phi2$i21Z2D = 0, $$pre$phi2$i28Z2D = 0, $$pre$phi2$i35Z2D = 0, $$pre$phi2$i8Z2D = 0, $$pre$phi2$iZ2D = 0, $$pre$phi4$i13Z2D = 0, $$pre$phi4$i20Z2D = 0, $$pre$phi4$i27Z2D = 0;
 var $$pre$phi4$i34Z2D = 0, $$pre$phi4$i7Z2D = 0, $$pre$phi4$iZ2D = 0, $$pre1$i = 0, $$pre1$i10 = 0, $$pre1$i17 = 0, $$pre1$i24 = 0, $$pre1$i31 = 0, $$pre1$i4 = 0, $$pre3$i = 0, $$pre3$i11 = 0, $$pre3$i18 = 0, $$pre3$i25 = 0, $$pre3$i32 = 0, $$pre3$i5 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $base$0 = 0, $candidate_hdr$01$i = 0, $gran_displ$0 = 0, $h$02$i = 0, $hhdr$0 = 0, $or$cond$i = 0, $phitmp = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = $obj;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7>>>0)<((4096)>>>0);
 if ($8) {
  $9 = (1)==(0);
  if (!($9)) {
   $10 = HEAP32[62424>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    $$0$i = 0;
   } else {
    $12 = $0 & -4096;
    $13 = $12;
    $14 = ($7|0)==(0|0);
    if ($14) {
     $$0$i = 0;
    } else {
     $candidate_hdr$01$i = $7;$h$02$i = $13;
     while(1) {
      $15 = $candidate_hdr$01$i;
      $16 = (0 - ($15))|0;
      $17 = (($h$02$i) + ($16<<12)|0);
      $18 = $17;
      $19 = $18 >>> 12;
      $20 = $19 & 1023;
      $21 = $18 >>> 22;
      $22 = ((56 + ($21<<2)|0) + 57964|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = (($23) + ($20<<2)|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25>>>0)<((4096)>>>0);
      if ($26) {
       $candidate_hdr$01$i = $25;$h$02$i = $17;
      } else {
       break;
      }
     }
     $27 = (($25) + 13|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = $28 & 4;
     $30 = ($29<<24>>24)==(0);
     if ($30) {
      $31 = $17;
      $32 = $31 & -4;
      $33 = $32;
      $34 = $31 & 4092;
      $35 = (($25) + 16|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($34>>>0) % ($36>>>0))&-1;
      $$sum$i = (($36) - ($37))|0;
      $38 = (($33) + ($$sum$i)|0);
      $$sum = (1 - ($15))|0;
      $39 = (($h$02$i) + ($$sum<<12)|0);
      $40 = ($38>>>0)>($39>>>0);
      $41 = ($36>>>0)<(4097);
      $or$cond$i = $40 & $41;
      if ($or$cond$i) {
       $$0$i = 0;
      } else {
       $42 = (0 - ($37))|0;
       $43 = (($33) + ($42)|0);
       $44 = ($38>>>0)>($obj>>>0);
       $45 = $43;
       $phitmp = $44 ? $45 : 0;
       $$0$i = $phitmp;
      }
     } else {
      $$0$i = 0;
     }
    }
   }
   $46 = $$0$i >>> 12;
   $47 = $46 & 1023;
   $48 = $$0$i >>> 22;
   $49 = ((56 + ($48<<2)|0) + 57964|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($50) + ($47<<2)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $$pr = 1;
    label = 12;
   } else {
    $hhdr$0 = $52;
    label = 10;
   }
  }
 } else {
  $hhdr$0 = $7;
  label = 10;
 }
 do {
  if ((label|0) == 10) {
   $54 = (($hhdr$0) + 13|0);
   $55 = HEAP8[$54>>0]|0;
   $$lobit = $55 & 4;
   $56 = ($$lobit<<24>>24)==(0);
   if (!($56)) {
    $$pr = 1;
    label = 12;
    break;
   }
   $90 = $0 & 4095;
   $91 = $90 >>> 3;
   $92 = (($hhdr$0) + 28|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + ($91<<1)|0);
   $95 = HEAP16[$94>>1]|0;
   $96 = $95 << 16 >> 16;
   $97 = $0 & 7;
   $98 = $96 | $97;
   $99 = ($98|0)==(0);
   do {
    if ($99) {
     $base$0 = $obj;$gran_displ$0 = $91;
    } else {
     $100 = (($hhdr$0) + 24|0);
     $101 = HEAP8[$100>>0]|0;
     $102 = ($101<<24>>24)==(0);
     if ($102) {
      $144 = $96 << 3;
      $145 = $144 | $97;
      $146 = ((56 + ($145)|0) + 12644|0);
      $147 = HEAP8[$146>>0]|0;
      $148 = ($147<<24>>24)==(0);
      if (!($148)) {
       $182 = (($91) - ($96))|0;
       $183 = (0 - ($145))|0;
       $184 = (($obj) + ($183)|0);
       $base$0 = $184;$gran_displ$0 = $182;
       break;
      }
      $149 = (1)==(0);
      if (!($149)) {
       $150 = $1 & 262143;
       $151 = ($7|0)==(0|0);
       if ($151) {
        $$pre$i3 = $1 & 31;
        $$pre1$i4 = 1 << $$pre$i3;
        $$pre3$i5 = $150 >>> 5;
        $$pre$phi2$i8Z2D = $$pre1$i4;$$pre$phi4$i7Z2D = $$pre3$i5;
       } else {
        $152 = $150 >>> 5;
        $153 = HEAP32[24>>2]|0;
        $154 = (($153) + ($152<<2)|0);
        $155 = HEAP32[$154>>2]|0;
        $156 = $1 & 31;
        $157 = 1 << $156;
        $158 = $155 & $157;
        $159 = ($158|0)==(0);
        if ($159) {
         $$0 = $mark_stack_ptr;
         STACKTOP = sp;return ($$0|0);
        } else {
         $$pre$phi2$i8Z2D = $157;$$pre$phi4$i7Z2D = $152;
        }
       }
       $160 = HEAP32[32>>2]|0;
       $161 = (($160) + ($$pre$phi4$i7Z2D<<2)|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = $162 | $$pre$phi2$i8Z2D;
       HEAP32[$161>>2] = $163;
       $$0 = $mark_stack_ptr;
       STACKTOP = sp;return ($$0|0);
      }
      $164 = $0 & 3;
      $165 = ((56 + ($164)|0) + 16740|0);
      $166 = HEAP8[$165>>0]|0;
      $167 = ($166<<24>>24)==(0);
      if ($167) {
       $$0 = $mark_stack_ptr;
       STACKTOP = sp;return ($$0|0);
      }
      $168 = $1 & 262143;
      $169 = ($7|0)==(0|0);
      if ($169) {
       $$pre$i = $1 & 31;
       $$pre1$i = 1 << $$pre$i;
       $$pre3$i = $168 >>> 5;
       $$pre$phi2$iZ2D = $$pre1$i;$$pre$phi4$iZ2D = $$pre3$i;
      } else {
       $170 = $168 >>> 5;
       $171 = HEAP32[8>>2]|0;
       $172 = (($171) + ($170<<2)|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = $1 & 31;
       $175 = 1 << $174;
       $176 = $173 & $175;
       $177 = ($176|0)==(0);
       if ($177) {
        $$0 = $mark_stack_ptr;
        STACKTOP = sp;return ($$0|0);
       } else {
        $$pre$phi2$iZ2D = $175;$$pre$phi4$iZ2D = $170;
       }
      }
      $178 = HEAP32[16>>2]|0;
      $179 = (($178) + ($$pre$phi4$iZ2D<<2)|0);
      $180 = HEAP32[$179>>2]|0;
      $181 = $180 | $$pre$phi2$iZ2D;
      HEAP32[$179>>2] = $181;
      $$0 = $mark_stack_ptr;
      STACKTOP = sp;return ($$0|0);
     } else {
      $103 = (($hhdr$0) + 8|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = $104;
      $106 = (($0) - ($105))|0;
      $107 = ($106|0)==($90|0);
      if (!($107)) {
       $base$0 = $104;$gran_displ$0 = 0;
       break;
      }
      $108 = ((56 + ($90)|0) + 12644|0);
      $109 = HEAP8[$108>>0]|0;
      $110 = ($109<<24>>24)==(0);
      if (!($110)) {
       $base$0 = $104;$gran_displ$0 = 0;
       break;
      }
      $111 = (1)==(0);
      if (!($111)) {
       $112 = $1 & 262143;
       $113 = ($7|0)==(0|0);
       if ($113) {
        $$pre$i16 = $1 & 31;
        $$pre1$i17 = 1 << $$pre$i16;
        $$pre3$i18 = $112 >>> 5;
        $$pre$phi2$i21Z2D = $$pre1$i17;$$pre$phi4$i20Z2D = $$pre3$i18;
       } else {
        $114 = $112 >>> 5;
        $115 = HEAP32[24>>2]|0;
        $116 = (($115) + ($114<<2)|0);
        $117 = HEAP32[$116>>2]|0;
        $118 = $1 & 31;
        $119 = 1 << $118;
        $120 = $117 & $119;
        $121 = ($120|0)==(0);
        if ($121) {
         $$0 = $mark_stack_ptr;
         STACKTOP = sp;return ($$0|0);
        } else {
         $$pre$phi2$i21Z2D = $119;$$pre$phi4$i20Z2D = $114;
        }
       }
       $122 = HEAP32[32>>2]|0;
       $123 = (($122) + ($$pre$phi4$i20Z2D<<2)|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = $124 | $$pre$phi2$i21Z2D;
       HEAP32[$123>>2] = $125;
       $$0 = $mark_stack_ptr;
       STACKTOP = sp;return ($$0|0);
      }
      $126 = $0 & 3;
      $127 = ((56 + ($126)|0) + 16740|0);
      $128 = HEAP8[$127>>0]|0;
      $129 = ($128<<24>>24)==(0);
      if ($129) {
       $$0 = $mark_stack_ptr;
       STACKTOP = sp;return ($$0|0);
      }
      $130 = $1 & 262143;
      $131 = ($7|0)==(0|0);
      if ($131) {
       $$pre$i9 = $1 & 31;
       $$pre1$i10 = 1 << $$pre$i9;
       $$pre3$i11 = $130 >>> 5;
       $$pre$phi2$i14Z2D = $$pre1$i10;$$pre$phi4$i13Z2D = $$pre3$i11;
      } else {
       $132 = $130 >>> 5;
       $133 = HEAP32[8>>2]|0;
       $134 = (($133) + ($132<<2)|0);
       $135 = HEAP32[$134>>2]|0;
       $136 = $1 & 31;
       $137 = 1 << $136;
       $138 = $135 & $137;
       $139 = ($138|0)==(0);
       if ($139) {
        $$0 = $mark_stack_ptr;
        STACKTOP = sp;return ($$0|0);
       } else {
        $$pre$phi2$i14Z2D = $137;$$pre$phi4$i13Z2D = $132;
       }
      }
      $140 = HEAP32[16>>2]|0;
      $141 = (($140) + ($$pre$phi4$i13Z2D<<2)|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = $142 | $$pre$phi2$i14Z2D;
      HEAP32[$141>>2] = $143;
      $$0 = $mark_stack_ptr;
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $185 = $gran_displ$0 >>> 5;
   $186 = ((($hhdr$0) + ($185<<2)|0) + 36|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = $gran_displ$0 & 31;
   $189 = 1 << $188;
   $190 = $189 & $187;
   $191 = ($190|0)==(0);
   if (!($191)) {
    $$0 = $mark_stack_ptr;
    STACKTOP = sp;return ($$0|0);
   }
   $192 = $189 | $187;
   HEAP32[$186>>2] = $192;
   $193 = (($hhdr$0) + 32|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = (($194) + 1)|0;
   HEAP32[$193>>2] = $195;
   $196 = (($hhdr$0) + 20|0);
   $197 = HEAP32[$196>>2]|0;
   $198 = ($197|0)==(0);
   if ($198) {
    $$0 = $mark_stack_ptr;
    STACKTOP = sp;return ($$0|0);
   }
   $199 = (($mark_stack_ptr) + 8|0);
   $200 = ($199>>>0)<($mark_stack_limit>>>0);
   if ($200) {
    $$01 = $199;
   } else {
    HEAP32[65672>>2] = 5;
    HEAP32[65888>>2] = 1;
    $201 = HEAP32[62240>>2]|0;
    $202 = ($201|0)==(0);
    if (!($202)) {
     $203 = HEAP32[65592>>2]|0;
     HEAP32[$vararg_buffer>>2] = $203;
     _GC_log_printf(66000,$vararg_buffer);
    }
    $204 = (($mark_stack_ptr) + -4088|0);
    $$01 = $204;
   }
   HEAP32[$$01>>2] = $base$0;
   $205 = (($$01) + 4|0);
   HEAP32[$205>>2] = $197;
   $$0 = $$01;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 if ((label|0) == 12) {
  $57 = ($$pr|0)==(0);
  if (!($57)) {
   $58 = $1 & 262143;
   $59 = ($7|0)==(0|0);
   if ($59) {
    $$pre$i30 = $1 & 31;
    $$pre1$i31 = 1 << $$pre$i30;
    $$pre3$i32 = $58 >>> 5;
    $$pre$phi2$i35Z2D = $$pre1$i31;$$pre$phi4$i34Z2D = $$pre3$i32;
   } else {
    $60 = $58 >>> 5;
    $61 = HEAP32[24>>2]|0;
    $62 = (($61) + ($60<<2)|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = $1 & 31;
    $65 = 1 << $64;
    $66 = $63 & $65;
    $67 = ($66|0)==(0);
    if ($67) {
     $$0 = $mark_stack_ptr;
     STACKTOP = sp;return ($$0|0);
    } else {
     $$pre$phi2$i35Z2D = $65;$$pre$phi4$i34Z2D = $60;
    }
   }
   $68 = HEAP32[32>>2]|0;
   $69 = (($68) + ($$pre$phi4$i34Z2D<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = $70 | $$pre$phi2$i35Z2D;
   HEAP32[$69>>2] = $71;
   $$0 = $mark_stack_ptr;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $72 = $0 & 3;
 $73 = ((56 + ($72)|0) + 16740|0);
 $74 = HEAP8[$73>>0]|0;
 $75 = ($74<<24>>24)==(0);
 if ($75) {
  $$0 = $mark_stack_ptr;
  STACKTOP = sp;return ($$0|0);
 }
 $76 = $1 & 262143;
 $77 = ($7|0)==(0|0);
 if ($77) {
  $$pre$i23 = $1 & 31;
  $$pre1$i24 = 1 << $$pre$i23;
  $$pre3$i25 = $76 >>> 5;
  $$pre$phi2$i28Z2D = $$pre1$i24;$$pre$phi4$i27Z2D = $$pre3$i25;
 } else {
  $78 = $76 >>> 5;
  $79 = HEAP32[8>>2]|0;
  $80 = (($79) + ($78<<2)|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = $1 & 31;
  $83 = 1 << $82;
  $84 = $81 & $83;
  $85 = ($84|0)==(0);
  if ($85) {
   $$0 = $mark_stack_ptr;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$pre$phi2$i28Z2D = $83;$$pre$phi4$i27Z2D = $78;
  }
 }
 $86 = HEAP32[16>>2]|0;
 $87 = (($86) + ($$pre$phi4$i27Z2D<<2)|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = $88 | $$pre$phi2$i28Z2D;
 HEAP32[$87>>2] = $89;
 $$0 = $mark_stack_ptr;
 STACKTOP = sp;return ($$0|0);
}
function _GC_null_finalize_mark_proc($p) {
 $p = $p|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _GC_unreachable_finalize_mark_proc($p) {
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = $p;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[((56 + 68|0))>>2]|0;
 $12 = (($11) + 8|0);
 HEAP32[((56 + 68|0))>>2] = $12;
 $13 = HEAP32[65592>>2]|0;
 $14 = HEAP32[((56 + 60|0))>>2]|0;
 $15 = (($14) + ($13<<3)|0);
 $16 = ($12>>>0)<($15>>>0);
 if ($16) {
  $20 = $12;
 } else {
  HEAP32[65672>>2] = 5;
  HEAP32[65888>>2] = 1;
  $17 = HEAP32[62240>>2]|0;
  $18 = ($17|0)==(0);
  if (!($18)) {
   HEAP32[$vararg_buffer>>2] = $13;
   _GC_log_printf(66000,$vararg_buffer);
  }
  $19 = (($11) + -4088|0);
  HEAP32[((56 + 68|0))>>2] = $19;
  $20 = $19;
 }
 HEAP32[$20>>2] = $p;
 $21 = HEAP32[((56 + 68|0))>>2]|0;
 $22 = (($21) + 4|0);
 HEAP32[$22>>2] = $9;
 STACKTOP = sp;return;
}
function _GC_register_finalizer_inner($obj,$fn,$cd,$ofn,$ocd,$mp) {
 $obj = $obj|0;
 $fn = $fn|0;
 $cd = $cd|0;
 $ofn = $ofn|0;
 $ocd = $ocd|0;
 $mp = $mp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, $curr_fo$04 = 0, $hhdr$0 = 0, $hhdr$1 = 0, $new_fo$0 = 0, $new_fo$1 = 0, $prev_fo$03 = 0, $prev_fo$03$phi = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[65600>>2]|0;
 $1 = ($0|0)==(-1);
 if ($1) {
  label = 3;
 } else {
  $2 = HEAP32[65136>>2]|0;
  $3 = 1 << $0;
  $4 = ($2>>>0)>($3>>>0);
  if ($4) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  _GC_grow_table(65440,65600);
  $5 = HEAP32[62240>>2]|0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = HEAP32[65600>>2]|0;
   $8 = 1 << $7;
   HEAP32[$vararg_buffer>>2] = $8;
   _GC_log_printf(65608,$vararg_buffer);
  }
 }
 $9 = $obj;
 $10 = $9 >>> 3;
 $11 = ($fn|0)==(0|0);
 $12 = $9 >>> 12;
 $13 = $12 & 1023;
 $14 = $9 >>> 22;
 $15 = ((56 + ($14<<2)|0) + 57964|0);
 $16 = $9 ^ -1;
 $hhdr$0 = 0;$new_fo$0 = 0;
 L7: while(1) {
  $17 = HEAP32[65600>>2]|0;
  $18 = (($17) + 3)|0;
  $19 = $9 >>> $18;
  $20 = $19 ^ $10;
  $21 = 1 << $17;
  $22 = (($21) + -1)|0;
  $23 = $20 & $22;
  $24 = HEAP32[65440>>2]|0;
  $25 = (($24) + ($23<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   $curr_fo$04 = $26;$prev_fo$03 = 0;
   while(1) {
    $28 = HEAP32[$curr_fo$04>>2]|0;
    $29 = ($28|0)==($16|0);
    if ($29) {
     label = 8;
     break L7;
    }
    $51 = (($curr_fo$04) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==(0|0);
    if ($53) {
     break;
    } else {
     $prev_fo$03$phi = $curr_fo$04;$curr_fo$04 = $52;$prev_fo$03 = $prev_fo$03$phi;
    }
   }
  }
  $54 = ($new_fo$0|0)==(0|0);
  if (!($54)) {
   $hhdr$1 = $hhdr$0;$new_fo$1 = $new_fo$0;
   label = 37;
   break;
  }
  if ($11) {
   label = 25;
   break;
  }
  $57 = HEAP32[$15>>2]|0;
  $58 = (($57) + ($13<<2)|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59|0)==(0|0);
  if ($60) {
   label = 30;
   break;
  }
  $63 = (_GC_generic_malloc_inner(24,1)|0);
  $64 = ($63|0)==(0|0);
  if (!($64)) {
   $hhdr$1 = $59;$new_fo$1 = $63;
   label = 37;
   break;
  }
  $65 = (_GC_default_oom_fn(24)|0);
  $66 = ($65|0)==(0|0);
  if ($66) {
   label = 42;
   break;
  }
  $hhdr$0 = $59;$new_fo$0 = $65;
 }
 if ((label|0) == 8) {
  $30 = ($ocd|0)==(0|0);
  if (!($30)) {
   $31 = (($curr_fo$04) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$ocd>>2] = $32;
  }
  $33 = ($ofn|0)==(0|0);
  if (!($33)) {
   $34 = (($curr_fo$04) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   HEAP32[$ofn>>2] = $35;
  }
  $36 = ($prev_fo$03|0)==(0|0);
  $37 = (($curr_fo$04) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  if ($36) {
   $39 = HEAP32[65440>>2]|0;
   $40 = (($39) + ($23<<2)|0);
   HEAP32[$40>>2] = $38;
  } else {
   $41 = (($prev_fo$03) + 4|0);
   HEAP32[$41>>2] = $38;
  }
  do {
   if ($11) {
    $42 = HEAP32[65136>>2]|0;
    $43 = (($42) + -1)|0;
    HEAP32[65136>>2] = $43;
    _GC_free($curr_fo$04);
   } else {
    $44 = (($curr_fo$04) + 8|0);
    HEAP32[$44>>2] = $fn;
    $45 = (($curr_fo$04) + 12|0);
    HEAP32[$45>>2] = $cd;
    $46 = (($curr_fo$04) + 20|0);
    HEAP32[$46>>2] = $mp;
    if ($36) {
     $47 = HEAP32[65440>>2]|0;
     $48 = (($47) + ($23<<2)|0);
     HEAP32[$48>>2] = $curr_fo$04;
     break;
    } else {
     $49 = (($prev_fo$03) + 4|0);
     HEAP32[$49>>2] = $curr_fo$04;
     break;
    }
   }
  } while(0);
  $50 = ($new_fo$0|0)==(0|0);
  if ($50) {
   STACKTOP = sp;return;
  }
  _GC_free($new_fo$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 25) {
  $55 = ($ocd|0)==(0|0);
  if (!($55)) {
   HEAP32[$ocd>>2] = 0;
  }
  $56 = ($ofn|0)==(0|0);
  if ($56) {
   STACKTOP = sp;return;
  }
  HEAP32[$ofn>>2] = 0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 30) {
  $61 = ($ocd|0)==(0|0);
  if (!($61)) {
   HEAP32[$ocd>>2] = 0;
  }
  $62 = ($ofn|0)==(0|0);
  if ($62) {
   STACKTOP = sp;return;
  }
  HEAP32[$ofn>>2] = 0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 37) {
  $67 = ($ocd|0)==(0|0);
  if (!($67)) {
   HEAP32[$ocd>>2] = 0;
  }
  $68 = ($ofn|0)==(0|0);
  if (!($68)) {
   HEAP32[$ofn>>2] = 0;
  }
  HEAP32[$new_fo$1>>2] = $16;
  $69 = (($new_fo$1) + 8|0);
  HEAP32[$69>>2] = $fn;
  $70 = (($new_fo$1) + 12|0);
  HEAP32[$70>>2] = $cd;
  $71 = (($hhdr$1) + 16|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($new_fo$1) + 16|0);
  HEAP32[$73>>2] = $72;
  $74 = (($new_fo$1) + 20|0);
  HEAP32[$74>>2] = $mp;
  $75 = HEAP32[65440>>2]|0;
  $76 = (($75) + ($23<<2)|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($new_fo$1) + 4|0);
  HEAP32[$78>>2] = $77;
  $79 = HEAP32[65136>>2]|0;
  $80 = (($79) + 1)|0;
  HEAP32[65136>>2] = $80;
  $81 = HEAP32[65440>>2]|0;
  $82 = (($81) + ($23<<2)|0);
  HEAP32[$82>>2] = $new_fo$1;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 42) {
  STACKTOP = sp;return;
 }
}
function _GC_make_disappearing_links_disappear($dl_hashtbl) {
 $dl_hashtbl = $dl_hashtbl|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curr$0$lcssa1 = 0, $curr$0$ph4 = 0, $curr$02 = 0, $curr$02$us = 0, $i$05 = 0, $prev$0$ph3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($dl_hashtbl) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 $3 = 1 << $1;
 $$ = $2 ? 0 : $3;
 if ($2) {
  STACKTOP = sp;return;
 }
 $4 = (($dl_hashtbl) + 8|0);
 $i$05 = 0;
 while(1) {
  $5 = HEAP32[$dl_hashtbl>>2]|0;
  $6 = (($5) + ($i$05<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  L6: do {
   if (!($8)) {
    $curr$0$ph4 = $7;$prev$0$ph3 = 0;
    while(1) {
     $9 = ($prev$0$ph3|0)==(0|0);
     $10 = (($prev$0$ph3) + 4|0);
     L9: do {
      if ($9) {
       $curr$02$us = $curr$0$ph4;
       while(1) {
        $11 = (($curr$02$us) + 8|0);
        $12 = HEAP32[$11>>2]|0;
        $13 = $12 ^ -1;
        $14 = $13;
        $15 = (_GC_is_marked($14)|0);
        $16 = ($15|0)==(0);
        if (!($16)) {
         $curr$0$lcssa1 = $curr$02$us;
         break L9;
        }
        $17 = HEAP32[$curr$02$us>>2]|0;
        $18 = $17 ^ -1;
        $19 = $18;
        HEAP32[$19>>2] = 0;
        _GC_clear_mark_bit($curr$02$us);
        $20 = (($curr$02$us) + 4|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = HEAP32[$dl_hashtbl>>2]|0;
        $23 = (($22) + ($i$05<<2)|0);
        HEAP32[$23>>2] = $21;
        _GC_clear_mark_bit($curr$02$us);
        $24 = HEAP32[$4>>2]|0;
        $25 = (($24) + -1)|0;
        HEAP32[$4>>2] = $25;
        $26 = ($21|0)==(0|0);
        if ($26) {
         break L6;
        } else {
         $curr$02$us = $21;
        }
       }
      } else {
       $curr$02 = $curr$0$ph4;
       while(1) {
        $27 = (($curr$02) + 8|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = $28 ^ -1;
        $30 = $29;
        $31 = (_GC_is_marked($30)|0);
        $32 = ($31|0)==(0);
        if (!($32)) {
         $curr$0$lcssa1 = $curr$02;
         break L9;
        }
        $33 = HEAP32[$curr$02>>2]|0;
        $34 = $33 ^ -1;
        $35 = $34;
        HEAP32[$35>>2] = 0;
        _GC_clear_mark_bit($curr$02);
        $36 = (($curr$02) + 4|0);
        $37 = HEAP32[$36>>2]|0;
        HEAP32[$10>>2] = $37;
        _GC_clear_mark_bit($curr$02);
        $38 = HEAP32[$4>>2]|0;
        $39 = (($38) + -1)|0;
        HEAP32[$4>>2] = $39;
        $40 = ($37|0)==(0|0);
        if ($40) {
         break L6;
        } else {
         $curr$02 = $37;
        }
       }
      }
     } while(0);
     $41 = (($curr$0$lcssa1) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0|0);
     if ($43) {
      break;
     } else {
      $curr$0$ph4 = $42;$prev$0$ph3 = $curr$0$lcssa1;
     }
    }
   }
  } while(0);
  $44 = (($i$05) + 1)|0;
  $45 = ($44>>>0)<($$>>>0);
  if ($45) {
   $i$05 = $44;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _GC_mark_from($mark_stack_top,$mark_stack,$mark_stack_limit) {
 $mark_stack_top = $mark_stack_top|0;
 $mark_stack = $mark_stack|0;
 $mark_stack_limit = $mark_stack_limit|0;
 var $$0$be = 0, $$0$lcssa = 0, $$0105 = 0, $$187 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$5$lcssa = 0, $$5100 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre$i14 = 0, $$pre$i21 = 0, $$pre$i28 = 0, $$pre$i35 = 0, $$pre$i43 = 0, $$pre$i50 = 0;
 var $$pre$i57 = 0, $$pre$i64 = 0, $$pre$i7 = 0, $$pre$i71 = 0, $$pre$phi2$i12Z2D = 0, $$pre$phi2$i19Z2D = 0, $$pre$phi2$i26Z2D = 0, $$pre$phi2$i33Z2D = 0, $$pre$phi2$i40Z2D = 0, $$pre$phi2$i48Z2D = 0, $$pre$phi2$i55Z2D = 0, $$pre$phi2$i62Z2D = 0, $$pre$phi2$i69Z2D = 0, $$pre$phi2$i6Z2D = 0, $$pre$phi2$i76Z2D = 0, $$pre$phi2$iZ2D = 0, $$pre$phi4$i11Z2D = 0, $$pre$phi4$i18Z2D = 0, $$pre$phi4$i25Z2D = 0, $$pre$phi4$i32Z2D = 0;
 var $$pre$phi4$i39Z2D = 0, $$pre$phi4$i47Z2D = 0, $$pre$phi4$i54Z2D = 0, $$pre$phi4$i5Z2D = 0, $$pre$phi4$i61Z2D = 0, $$pre$phi4$i68Z2D = 0, $$pre$phi4$i75Z2D = 0, $$pre$phi4$iZ2D = 0, $$pre1$i = 0, $$pre1$i15 = 0, $$pre1$i2 = 0, $$pre1$i22 = 0, $$pre1$i29 = 0, $$pre1$i36 = 0, $$pre1$i44 = 0, $$pre1$i51 = 0, $$pre1$i58 = 0, $$pre1$i65 = 0, $$pre1$i72 = 0, $$pre1$i8 = 0;
 var $$pre3$i = 0, $$pre3$i16 = 0, $$pre3$i23 = 0, $$pre3$i3 = 0, $$pre3$i30 = 0, $$pre3$i37 = 0, $$pre3$i45 = 0, $$pre3$i52 = 0, $$pre3$i59 = 0, $$pre3$i66 = 0, $$pre3$i73 = 0, $$pre3$i9 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0;
 var $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $base$0 = 0, $base21$0 = 0, $base8$0 = 0, $credit$0$be = 0, $credit$0104 = 0, $current_p$086 = 0, $current_p$199 = 0, $deferred$0$ph = 0, $descr$0 = 0, $descr$185 = 0, $descr$2 = 0, $descr$2$in$in = 0, $gran_displ$0 = 0, $gran_displ18$0 = 0, $gran_displ5$0 = 0, $hdr_cache = 0, $limit$0 = 0, $limit$1 = 0, $limit$2$ph = 0, $my_hhdr$0 = 0;
 var $my_hhdr15$0 = 0, $my_hhdr2$0 = 0, $or$cond = 0, $or$cond126 = 0, $or$cond127 = 0, $or$cond128 = 0, $vararg_buffer4 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer4 = sp;
 $hdr_cache = sp + 8|0;
 $0 = HEAP32[64936>>2]|0;
 $1 = HEAP32[64928>>2]|0;
 HEAP32[65896>>2] = 1;
 dest=$hdr_cache+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $2 = $mark_stack_top;
 $3 = $mark_stack;
 $4 = (($2) - ($3))|0;
 $5 = ($4|0)>(-1);
 if (!($5)) {
  $$0$lcssa = $mark_stack_top;
  STACKTOP = sp;return ($$0$lcssa|0);
 }
 $6 = $1;
 $7 = $0;
 $$0105 = $mark_stack_top;$credit$0104 = 4096;
 while(1) {
  $8 = HEAP32[$$0105>>2]|0;
  $9 = (($$0105) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $descr$0 = $10;
  while(1) {
   $11 = $descr$0 & -509;
   $12 = ($11|0)==(0);
   if ($12) {
    label = 58;
    break;
   }
   $13 = $descr$0 & 3;
   if ((($13|0) == 1)) {
    label = 7;
    break;
   } else if ((($13|0) == 0)) {
    label = 6;
    break;
   } else if ((($13|0) == 2)) {
    label = 47;
    break;
   } else if (!((($13|0) == 3))) {
    label = 56;
    break;
   }
   $189 = ($descr$0|0)>(-1);
   if ($189) {
    $$sum = (($descr$0) + -3)|0;
    $190 = (($8) + ($$sum)|0);
    $descr$2$in$in = $190;
   } else {
    $191 = HEAP32[$8>>2]|0;
    $192 = ($191|0)==(0|0);
    if ($192) {
     label = 52;
     break;
    }
    $194 = (-13 - ($descr$0))|0;
    $195 = (($191) + ($194)|0);
    $descr$2$in$in = $195;
   }
   $descr$2 = HEAP32[$descr$2$in$in>>2]|0;
   $196 = ($descr$2|0)==(0);
   if ($196) {
    label = 55;
    break;
   } else {
    $descr$0 = $descr$2;
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $14 = (($8) + 508|0);
   HEAP32[$$0105>>2] = $14;
   $15 = (($descr$0) + -508)|0;
   HEAP32[$9>>2] = $15;
   $$4 = $$0105;$limit$0 = $14;
   label = 60;
  }
  else if ((label|0) == 7) {
   label = 0;
   $16 = (($$0105) + -8|0);
   $17 = $descr$0 & -4;
   $18 = (($credit$0104) + -64)|0;
   $19 = ($17|0)==(0);
   if ($19) {
    $$0$be = $16;$credit$0$be = $18;
   } else {
    $$187 = $16;$current_p$086 = $8;$descr$185 = $17;
    while(1) {
     $20 = ($descr$185|0)<(0);
     L19: do {
      if ($20) {
       $21 = HEAP32[$current_p$086>>2]|0;
       $22 = ($21>>>0)>=($6>>>0);
       $23 = ($21>>>0)<($7>>>0);
       $or$cond = $22 & $23;
       if ($or$cond) {
        $24 = $21;
        $25 = $21 >>> 12;
        $26 = $25 & 7;
        $27 = (($hdr_cache) + ($26<<3)|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = ($28|0)==($25|0);
        if ($29) {
         $30 = ((($hdr_cache) + ($26<<3)|0) + 4|0);
         $31 = HEAP32[$30>>2]|0;
         $my_hhdr$0 = $31;
        } else {
         $32 = (_GC_header_cache_miss($24,$27)|0);
         $33 = ($32|0)==(0|0);
         if ($33) {
          $$3 = $$187;
          break;
         } else {
          $my_hhdr$0 = $32;
         }
        }
        $34 = $21 & 4095;
        $35 = $34 >>> 3;
        $36 = (($my_hhdr$0) + 28|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = (($37) + ($35<<1)|0);
        $39 = HEAP16[$38>>1]|0;
        $40 = $39 << 16 >> 16;
        $41 = $21 & 7;
        $42 = $40 | $41;
        $43 = ($42|0)==(0);
        do {
         if ($43) {
          $base$0 = $24;$gran_displ$0 = $35;
         } else {
          $44 = (($my_hhdr$0) + 24|0);
          $45 = HEAP8[$44>>0]|0;
          $46 = ($45<<24>>24)==(0);
          if ($46) {
           $100 = $40 << 3;
           $101 = $100 | $41;
           $102 = ((56 + ($101)|0) + 12644|0);
           $103 = HEAP8[$102>>0]|0;
           $104 = ($103<<24>>24)==(0);
           if (!($104)) {
            $150 = (($35) - ($40))|0;
            $151 = (0 - ($101))|0;
            $152 = (($24) + ($151)|0);
            $base$0 = $152;$gran_displ$0 = $150;
            break;
           }
           $105 = (1)==(0);
           if (!($105)) {
            $106 = $25 & 262143;
            $107 = $25 & 1023;
            $108 = $21 >>> 22;
            $109 = ((56 + ($108<<2)|0) + 57964|0);
            $110 = HEAP32[$109>>2]|0;
            $111 = (($110) + ($107<<2)|0);
            $112 = HEAP32[$111>>2]|0;
            $113 = ($112|0)==(0|0);
            if ($113) {
             $$pre$i35 = $25 & 31;
             $$pre1$i36 = 1 << $$pre$i35;
             $$pre3$i37 = $106 >>> 5;
             $$pre$phi2$i40Z2D = $$pre1$i36;$$pre$phi4$i39Z2D = $$pre3$i37;
            } else {
             $114 = $106 >>> 5;
             $115 = HEAP32[24>>2]|0;
             $116 = (($115) + ($114<<2)|0);
             $117 = HEAP32[$116>>2]|0;
             $118 = $25 & 31;
             $119 = 1 << $118;
             $120 = $117 & $119;
             $121 = ($120|0)==(0);
             if ($121) {
              $$3 = $$187;
              break L19;
             } else {
              $$pre$phi2$i40Z2D = $119;$$pre$phi4$i39Z2D = $114;
             }
            }
            $122 = HEAP32[32>>2]|0;
            $123 = (($122) + ($$pre$phi4$i39Z2D<<2)|0);
            $124 = HEAP32[$123>>2]|0;
            $125 = $124 | $$pre$phi2$i40Z2D;
            HEAP32[$123>>2] = $125;
            $$3 = $$187;
            break L19;
           }
           $126 = $21 & 3;
           $127 = ((56 + ($126)|0) + 16740|0);
           $128 = HEAP8[$127>>0]|0;
           $129 = ($128<<24>>24)==(0);
           if ($129) {
            $$3 = $$187;
            break L19;
           }
           $130 = $25 & 262143;
           $131 = $25 & 1023;
           $132 = $21 >>> 22;
           $133 = ((56 + ($132<<2)|0) + 57964|0);
           $134 = HEAP32[$133>>2]|0;
           $135 = (($134) + ($131<<2)|0);
           $136 = HEAP32[$135>>2]|0;
           $137 = ($136|0)==(0|0);
           if ($137) {
            $$pre$i43 = $25 & 31;
            $$pre1$i44 = 1 << $$pre$i43;
            $$pre3$i45 = $130 >>> 5;
            $$pre$phi2$i48Z2D = $$pre1$i44;$$pre$phi4$i47Z2D = $$pre3$i45;
           } else {
            $138 = $130 >>> 5;
            $139 = HEAP32[8>>2]|0;
            $140 = (($139) + ($138<<2)|0);
            $141 = HEAP32[$140>>2]|0;
            $142 = $25 & 31;
            $143 = 1 << $142;
            $144 = $141 & $143;
            $145 = ($144|0)==(0);
            if ($145) {
             $$3 = $$187;
             break L19;
            } else {
             $$pre$phi2$i48Z2D = $143;$$pre$phi4$i47Z2D = $138;
            }
           }
           $146 = HEAP32[16>>2]|0;
           $147 = (($146) + ($$pre$phi4$i47Z2D<<2)|0);
           $148 = HEAP32[$147>>2]|0;
           $149 = $148 | $$pre$phi2$i48Z2D;
           HEAP32[$147>>2] = $149;
           $$3 = $$187;
           break L19;
          } else {
           $47 = (($my_hhdr$0) + 8|0);
           $48 = HEAP32[$47>>2]|0;
           $49 = $48;
           $50 = (($21) - ($49))|0;
           $51 = ($50|0)==($34|0);
           if (!($51)) {
            $base$0 = $48;$gran_displ$0 = 0;
            break;
           }
           $52 = ((56 + ($34)|0) + 12644|0);
           $53 = HEAP8[$52>>0]|0;
           $54 = ($53<<24>>24)==(0);
           if (!($54)) {
            $base$0 = $48;$gran_displ$0 = 0;
            break;
           }
           $55 = (1)==(0);
           if (!($55)) {
            $56 = $25 & 262143;
            $57 = $25 & 1023;
            $58 = $21 >>> 22;
            $59 = ((56 + ($58<<2)|0) + 57964|0);
            $60 = HEAP32[$59>>2]|0;
            $61 = (($60) + ($57<<2)|0);
            $62 = HEAP32[$61>>2]|0;
            $63 = ($62|0)==(0|0);
            if ($63) {
             $$pre$i = $25 & 31;
             $$pre1$i = 1 << $$pre$i;
             $$pre3$i = $56 >>> 5;
             $$pre$phi2$iZ2D = $$pre1$i;$$pre$phi4$iZ2D = $$pre3$i;
            } else {
             $64 = $56 >>> 5;
             $65 = HEAP32[24>>2]|0;
             $66 = (($65) + ($64<<2)|0);
             $67 = HEAP32[$66>>2]|0;
             $68 = $25 & 31;
             $69 = 1 << $68;
             $70 = $67 & $69;
             $71 = ($70|0)==(0);
             if ($71) {
              $$3 = $$187;
              break L19;
             } else {
              $$pre$phi2$iZ2D = $69;$$pre$phi4$iZ2D = $64;
             }
            }
            $72 = HEAP32[32>>2]|0;
            $73 = (($72) + ($$pre$phi4$iZ2D<<2)|0);
            $74 = HEAP32[$73>>2]|0;
            $75 = $74 | $$pre$phi2$iZ2D;
            HEAP32[$73>>2] = $75;
            $$3 = $$187;
            break L19;
           }
           $76 = $21 & 3;
           $77 = ((56 + ($76)|0) + 16740|0);
           $78 = HEAP8[$77>>0]|0;
           $79 = ($78<<24>>24)==(0);
           if ($79) {
            $$3 = $$187;
            break L19;
           }
           $80 = $25 & 262143;
           $81 = $25 & 1023;
           $82 = $21 >>> 22;
           $83 = ((56 + ($82<<2)|0) + 57964|0);
           $84 = HEAP32[$83>>2]|0;
           $85 = (($84) + ($81<<2)|0);
           $86 = HEAP32[$85>>2]|0;
           $87 = ($86|0)==(0|0);
           if ($87) {
            $$pre$i1 = $25 & 31;
            $$pre1$i2 = 1 << $$pre$i1;
            $$pre3$i3 = $80 >>> 5;
            $$pre$phi2$i6Z2D = $$pre1$i2;$$pre$phi4$i5Z2D = $$pre3$i3;
           } else {
            $88 = $80 >>> 5;
            $89 = HEAP32[8>>2]|0;
            $90 = (($89) + ($88<<2)|0);
            $91 = HEAP32[$90>>2]|0;
            $92 = $25 & 31;
            $93 = 1 << $92;
            $94 = $91 & $93;
            $95 = ($94|0)==(0);
            if ($95) {
             $$3 = $$187;
             break L19;
            } else {
             $$pre$phi2$i6Z2D = $93;$$pre$phi4$i5Z2D = $88;
            }
           }
           $96 = HEAP32[16>>2]|0;
           $97 = (($96) + ($$pre$phi4$i5Z2D<<2)|0);
           $98 = HEAP32[$97>>2]|0;
           $99 = $98 | $$pre$phi2$i6Z2D;
           HEAP32[$97>>2] = $99;
           $$3 = $$187;
           break L19;
          }
         }
        } while(0);
        $153 = $gran_displ$0 >>> 5;
        $154 = ((($my_hhdr$0) + ($153<<2)|0) + 36|0);
        $155 = HEAP32[$154>>2]|0;
        $156 = $gran_displ$0 & 31;
        $157 = 1 << $156;
        $158 = $157 & $155;
        $159 = ($158|0)==(0);
        if ($159) {
         $160 = $157 | $155;
         HEAP32[$154>>2] = $160;
         $161 = (($my_hhdr$0) + 32|0);
         $162 = HEAP32[$161>>2]|0;
         $163 = (($162) + 1)|0;
         HEAP32[$161>>2] = $163;
         $164 = (($my_hhdr$0) + 20|0);
         $165 = HEAP32[$164>>2]|0;
         $166 = ($165|0)==(0);
         if ($166) {
          $$3 = $$187;
         } else {
          $167 = (($$187) + 8|0);
          $168 = ($167>>>0)<($mark_stack_limit>>>0);
          if ($168) {
           $$2 = $167;
          } else {
           HEAP32[65672>>2] = 5;
           HEAP32[65888>>2] = 1;
           $169 = HEAP32[62240>>2]|0;
           $170 = ($169|0)==(0);
           if (!($170)) {
            $171 = HEAP32[65592>>2]|0;
            HEAP32[$vararg_buffer4>>2] = $171;
            _GC_log_printf(66000,$vararg_buffer4);
           }
           $172 = (($$187) + -4088|0);
           $$2 = $172;
          }
          HEAP32[$$2>>2] = $base$0;
          $173 = (($$2) + 4|0);
          HEAP32[$173>>2] = $165;
          $$3 = $$2;
         }
        } else {
         $$3 = $$187;
        }
       } else {
        $$3 = $$187;
       }
      } else {
       $$3 = $$187;
      }
     } while(0);
     $174 = $descr$185 << 1;
     $175 = (($current_p$086) + 4|0);
     $176 = ($174|0)==(0);
     if ($176) {
      $$0$be = $$3;$credit$0$be = $18;
      break;
     } else {
      $$187 = $$3;$current_p$086 = $175;$descr$185 = $174;
     }
    }
   }
  }
  else if ((label|0) == 47) {
   label = 0;
   $177 = (($$0105) + -8|0);
   $178 = (($credit$0104) + -100)|0;
   $179 = $descr$0 >>> 2;
   $180 = $179 & 63;
   $181 = ((56 + ($180<<2)|0) + 72|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = $descr$0 >>> 8;
   $184 = (FUNCTION_TABLE_iiiii[$182 & 511]($8,$177,$mark_stack_limit,$183)|0);
   $$0$be = $184;$credit$0$be = $178;
  }
  else if ((label|0) == 52) {
   label = 0;
   $193 = (($$0105) + -8|0);
   $$0$be = $193;$credit$0$be = $credit$0104;
  }
  else if ((label|0) == 55) {
   label = 0;
   $197 = (($$0105) + -8|0);
   $$0$be = $197;$credit$0$be = $credit$0104;
  }
  else if ((label|0) == 56) {
   label = 0;
   $198 = (2474|0)==((-1)|0);
   if ($198) {
    $$4 = $$0105;$limit$0 = 0;
    label = 60;
   } else {
    label = 57;
    break;
   }
  }
  else if ((label|0) == 58) {
   label = 0;
   $199 = (($$0105) + -8|0);
   $200 = ($descr$0>>>0)<(4);
   if ($200) {
    $$0$be = $199;$credit$0$be = $credit$0104;
   } else {
    $201 = (($8) + ($descr$0)|0);
    $$4 = $199;$limit$0 = $201;
    label = 60;
   }
  }
  L77: do {
   if ((label|0) == 60) {
    label = 0;
    $202 = $limit$0;
    $203 = $8;
    $204 = (($203) - ($202))|0;
    $205 = (($204) + ($credit$0104))|0;
    $206 = (($limit$0) + -4|0);
    $limit$1 = $206;
    while(1) {
     $207 = (($limit$1) + -128|0);
     $208 = HEAP32[$limit$1>>2]|0;
     $209 = (($limit$1) + -4|0);
     $210 = ($208>>>0)>=($6>>>0);
     $211 = ($208>>>0)<($7>>>0);
     $or$cond126 = $210 & $211;
     if ($or$cond126) {
      label = 62;
      break;
     }
     $214 = ($8>>>0)>($209>>>0);
     if ($214) {
      $$0$be = $$4;$credit$0$be = $205;
      break L77;
     }
     $215 = HEAP32[$209>>2]|0;
     $216 = (($limit$1) + -8|0);
     $217 = ($215>>>0)>=($6>>>0);
     $218 = ($215>>>0)<($7>>>0);
     $or$cond127 = $217 & $218;
     if ($or$cond127) {
      label = 66;
      break;
     }
     $220 = ($8>>>0)>($216>>>0);
     if ($220) {
      $$0$be = $$4;$credit$0$be = $205;
      break L77;
     } else {
      $limit$1 = $216;
     }
    }
    if ((label|0) == 62) {
     label = 0;
     $212 = $208;
     $deferred$0$ph = $208;$limit$2$ph = $209;
    }
    else if ((label|0) == 66) {
     label = 0;
     $219 = $215;
     $deferred$0$ph = $215;$limit$2$ph = $216;
    }
    $213 = ($8>>>0)>($limit$2$ph>>>0);
    if ($213) {
     $$5$lcssa = $$4;
    } else {
     $$5100 = $$4;$current_p$199 = $8;
     while(1) {
      $221 = HEAP32[$current_p$199>>2]|0;
      $222 = (($current_p$199) + 128|0);
      $223 = ($221>>>0)>=($6>>>0);
      $224 = ($221>>>0)<($7>>>0);
      $or$cond128 = $223 & $224;
      L91: do {
       if ($or$cond128) {
        $225 = $221;
        $226 = $221 >>> 12;
        $227 = $226 & 7;
        $228 = (($hdr_cache) + ($227<<3)|0);
        $229 = HEAP32[$228>>2]|0;
        $230 = ($229|0)==($226|0);
        if ($230) {
         $231 = ((($hdr_cache) + ($227<<3)|0) + 4|0);
         $232 = HEAP32[$231>>2]|0;
         $my_hhdr2$0 = $232;
        } else {
         $233 = (_GC_header_cache_miss($225,$228)|0);
         $234 = ($233|0)==(0|0);
         if ($234) {
          $$7 = $$5100;
          break;
         } else {
          $my_hhdr2$0 = $233;
         }
        }
        $235 = $221 & 4095;
        $236 = $235 >>> 3;
        $237 = (($my_hhdr2$0) + 28|0);
        $238 = HEAP32[$237>>2]|0;
        $239 = (($238) + ($236<<1)|0);
        $240 = HEAP16[$239>>1]|0;
        $241 = $240 << 16 >> 16;
        $242 = $221 & 7;
        $243 = $241 | $242;
        $244 = ($243|0)==(0);
        do {
         if ($244) {
          $base8$0 = $225;$gran_displ5$0 = $236;
         } else {
          $245 = (($my_hhdr2$0) + 24|0);
          $246 = HEAP8[$245>>0]|0;
          $247 = ($246<<24>>24)==(0);
          if ($247) {
           $301 = $241 << 3;
           $302 = $301 | $242;
           $303 = ((56 + ($302)|0) + 12644|0);
           $304 = HEAP8[$303>>0]|0;
           $305 = ($304<<24>>24)==(0);
           if (!($305)) {
            $351 = (($236) - ($241))|0;
            $352 = (0 - ($302))|0;
            $353 = (($225) + ($352)|0);
            $base8$0 = $353;$gran_displ5$0 = $351;
            break;
           }
           $306 = (1)==(0);
           if (!($306)) {
            $307 = $226 & 262143;
            $308 = $226 & 1023;
            $309 = $221 >>> 22;
            $310 = ((56 + ($309<<2)|0) + 57964|0);
            $311 = HEAP32[$310>>2]|0;
            $312 = (($311) + ($308<<2)|0);
            $313 = HEAP32[$312>>2]|0;
            $314 = ($313|0)==(0|0);
            if ($314) {
             $$pre$i57 = $226 & 31;
             $$pre1$i58 = 1 << $$pre$i57;
             $$pre3$i59 = $307 >>> 5;
             $$pre$phi2$i62Z2D = $$pre1$i58;$$pre$phi4$i61Z2D = $$pre3$i59;
            } else {
             $315 = $307 >>> 5;
             $316 = HEAP32[24>>2]|0;
             $317 = (($316) + ($315<<2)|0);
             $318 = HEAP32[$317>>2]|0;
             $319 = $226 & 31;
             $320 = 1 << $319;
             $321 = $318 & $320;
             $322 = ($321|0)==(0);
             if ($322) {
              $$7 = $$5100;
              break L91;
             } else {
              $$pre$phi2$i62Z2D = $320;$$pre$phi4$i61Z2D = $315;
             }
            }
            $323 = HEAP32[32>>2]|0;
            $324 = (($323) + ($$pre$phi4$i61Z2D<<2)|0);
            $325 = HEAP32[$324>>2]|0;
            $326 = $325 | $$pre$phi2$i62Z2D;
            HEAP32[$324>>2] = $326;
            $$7 = $$5100;
            break L91;
           }
           $327 = $221 & 3;
           $328 = ((56 + ($327)|0) + 16740|0);
           $329 = HEAP8[$328>>0]|0;
           $330 = ($329<<24>>24)==(0);
           if ($330) {
            $$7 = $$5100;
            break L91;
           }
           $331 = $226 & 262143;
           $332 = $226 & 1023;
           $333 = $221 >>> 22;
           $334 = ((56 + ($333<<2)|0) + 57964|0);
           $335 = HEAP32[$334>>2]|0;
           $336 = (($335) + ($332<<2)|0);
           $337 = HEAP32[$336>>2]|0;
           $338 = ($337|0)==(0|0);
           if ($338) {
            $$pre$i50 = $226 & 31;
            $$pre1$i51 = 1 << $$pre$i50;
            $$pre3$i52 = $331 >>> 5;
            $$pre$phi2$i55Z2D = $$pre1$i51;$$pre$phi4$i54Z2D = $$pre3$i52;
           } else {
            $339 = $331 >>> 5;
            $340 = HEAP32[8>>2]|0;
            $341 = (($340) + ($339<<2)|0);
            $342 = HEAP32[$341>>2]|0;
            $343 = $226 & 31;
            $344 = 1 << $343;
            $345 = $342 & $344;
            $346 = ($345|0)==(0);
            if ($346) {
             $$7 = $$5100;
             break L91;
            } else {
             $$pre$phi2$i55Z2D = $344;$$pre$phi4$i54Z2D = $339;
            }
           }
           $347 = HEAP32[16>>2]|0;
           $348 = (($347) + ($$pre$phi4$i54Z2D<<2)|0);
           $349 = HEAP32[$348>>2]|0;
           $350 = $349 | $$pre$phi2$i55Z2D;
           HEAP32[$348>>2] = $350;
           $$7 = $$5100;
           break L91;
          } else {
           $248 = (($my_hhdr2$0) + 8|0);
           $249 = HEAP32[$248>>2]|0;
           $250 = $249;
           $251 = (($221) - ($250))|0;
           $252 = ($251|0)==($235|0);
           if (!($252)) {
            $base8$0 = $249;$gran_displ5$0 = 0;
            break;
           }
           $253 = ((56 + ($235)|0) + 12644|0);
           $254 = HEAP8[$253>>0]|0;
           $255 = ($254<<24>>24)==(0);
           if (!($255)) {
            $base8$0 = $249;$gran_displ5$0 = 0;
            break;
           }
           $256 = (1)==(0);
           if (!($256)) {
            $257 = $226 & 262143;
            $258 = $226 & 1023;
            $259 = $221 >>> 22;
            $260 = ((56 + ($259<<2)|0) + 57964|0);
            $261 = HEAP32[$260>>2]|0;
            $262 = (($261) + ($258<<2)|0);
            $263 = HEAP32[$262>>2]|0;
            $264 = ($263|0)==(0|0);
            if ($264) {
             $$pre$i71 = $226 & 31;
             $$pre1$i72 = 1 << $$pre$i71;
             $$pre3$i73 = $257 >>> 5;
             $$pre$phi2$i76Z2D = $$pre1$i72;$$pre$phi4$i75Z2D = $$pre3$i73;
            } else {
             $265 = $257 >>> 5;
             $266 = HEAP32[24>>2]|0;
             $267 = (($266) + ($265<<2)|0);
             $268 = HEAP32[$267>>2]|0;
             $269 = $226 & 31;
             $270 = 1 << $269;
             $271 = $268 & $270;
             $272 = ($271|0)==(0);
             if ($272) {
              $$7 = $$5100;
              break L91;
             } else {
              $$pre$phi2$i76Z2D = $270;$$pre$phi4$i75Z2D = $265;
             }
            }
            $273 = HEAP32[32>>2]|0;
            $274 = (($273) + ($$pre$phi4$i75Z2D<<2)|0);
            $275 = HEAP32[$274>>2]|0;
            $276 = $275 | $$pre$phi2$i76Z2D;
            HEAP32[$274>>2] = $276;
            $$7 = $$5100;
            break L91;
           }
           $277 = $221 & 3;
           $278 = ((56 + ($277)|0) + 16740|0);
           $279 = HEAP8[$278>>0]|0;
           $280 = ($279<<24>>24)==(0);
           if ($280) {
            $$7 = $$5100;
            break L91;
           }
           $281 = $226 & 262143;
           $282 = $226 & 1023;
           $283 = $221 >>> 22;
           $284 = ((56 + ($283<<2)|0) + 57964|0);
           $285 = HEAP32[$284>>2]|0;
           $286 = (($285) + ($282<<2)|0);
           $287 = HEAP32[$286>>2]|0;
           $288 = ($287|0)==(0|0);
           if ($288) {
            $$pre$i64 = $226 & 31;
            $$pre1$i65 = 1 << $$pre$i64;
            $$pre3$i66 = $281 >>> 5;
            $$pre$phi2$i69Z2D = $$pre1$i65;$$pre$phi4$i68Z2D = $$pre3$i66;
           } else {
            $289 = $281 >>> 5;
            $290 = HEAP32[8>>2]|0;
            $291 = (($290) + ($289<<2)|0);
            $292 = HEAP32[$291>>2]|0;
            $293 = $226 & 31;
            $294 = 1 << $293;
            $295 = $292 & $294;
            $296 = ($295|0)==(0);
            if ($296) {
             $$7 = $$5100;
             break L91;
            } else {
             $$pre$phi2$i69Z2D = $294;$$pre$phi4$i68Z2D = $289;
            }
           }
           $297 = HEAP32[16>>2]|0;
           $298 = (($297) + ($$pre$phi4$i68Z2D<<2)|0);
           $299 = HEAP32[$298>>2]|0;
           $300 = $299 | $$pre$phi2$i69Z2D;
           HEAP32[$298>>2] = $300;
           $$7 = $$5100;
           break L91;
          }
         }
        } while(0);
        $354 = $gran_displ5$0 >>> 5;
        $355 = ((($my_hhdr2$0) + ($354<<2)|0) + 36|0);
        $356 = HEAP32[$355>>2]|0;
        $357 = $gran_displ5$0 & 31;
        $358 = 1 << $357;
        $359 = $358 & $356;
        $360 = ($359|0)==(0);
        if ($360) {
         $361 = $358 | $356;
         HEAP32[$355>>2] = $361;
         $362 = (($my_hhdr2$0) + 32|0);
         $363 = HEAP32[$362>>2]|0;
         $364 = (($363) + 1)|0;
         HEAP32[$362>>2] = $364;
         $365 = (($my_hhdr2$0) + 20|0);
         $366 = HEAP32[$365>>2]|0;
         $367 = ($366|0)==(0);
         if ($367) {
          $$7 = $$5100;
         } else {
          $368 = (($$5100) + 8|0);
          $369 = ($368>>>0)<($mark_stack_limit>>>0);
          if ($369) {
           $$6 = $368;
          } else {
           HEAP32[65672>>2] = 5;
           HEAP32[65888>>2] = 1;
           $370 = HEAP32[62240>>2]|0;
           $371 = ($370|0)==(0);
           if (!($371)) {
            $372 = HEAP32[65592>>2]|0;
            HEAP32[$vararg_buffer4>>2] = $372;
            _GC_log_printf(66000,$vararg_buffer4);
           }
           $373 = (($$5100) + -4088|0);
           $$6 = $373;
          }
          HEAP32[$$6>>2] = $base8$0;
          $374 = (($$6) + 4|0);
          HEAP32[$374>>2] = $366;
          $$7 = $$6;
         }
        } else {
         $$7 = $$5100;
        }
       } else {
        $$7 = $$5100;
       }
      } while(0);
      $375 = (($current_p$199) + 4|0);
      $376 = ($375>>>0)>($limit$2$ph>>>0);
      if ($376) {
       $$5$lcssa = $$7;
       break;
      } else {
       $$5100 = $$7;$current_p$199 = $375;
      }
     }
    }
    $377 = $deferred$0$ph;
    $378 = $deferred$0$ph >>> 12;
    $379 = $378 & 7;
    $380 = (($hdr_cache) + ($379<<3)|0);
    $381 = HEAP32[$380>>2]|0;
    $382 = ($381|0)==($378|0);
    if ($382) {
     $383 = ((($hdr_cache) + ($379<<3)|0) + 4|0);
     $384 = HEAP32[$383>>2]|0;
     $my_hhdr15$0 = $384;
    } else {
     $385 = (_GC_header_cache_miss($377,$380)|0);
     $386 = ($385|0)==(0|0);
     if ($386) {
      $$0$be = $$5$lcssa;$credit$0$be = $205;
      break;
     } else {
      $my_hhdr15$0 = $385;
     }
    }
    $387 = $deferred$0$ph & 4095;
    $388 = $387 >>> 3;
    $389 = (($my_hhdr15$0) + 28|0);
    $390 = HEAP32[$389>>2]|0;
    $391 = (($390) + ($388<<1)|0);
    $392 = HEAP16[$391>>1]|0;
    $393 = $392 << 16 >> 16;
    $394 = $deferred$0$ph & 7;
    $395 = $393 | $394;
    $396 = ($395|0)==(0);
    do {
     if ($396) {
      $base21$0 = $377;$gran_displ18$0 = $388;
     } else {
      $397 = (($my_hhdr15$0) + 24|0);
      $398 = HEAP8[$397>>0]|0;
      $399 = ($398<<24>>24)==(0);
      if ($399) {
       $453 = $393 << 3;
       $454 = $453 | $394;
       $455 = ((56 + ($454)|0) + 12644|0);
       $456 = HEAP8[$455>>0]|0;
       $457 = ($456<<24>>24)==(0);
       if (!($457)) {
        $503 = (($388) - ($393))|0;
        $504 = (0 - ($454))|0;
        $505 = (($377) + ($504)|0);
        $base21$0 = $505;$gran_displ18$0 = $503;
        break;
       }
       $458 = (1)==(0);
       if (!($458)) {
        $459 = $378 & 262143;
        $460 = $378 & 1023;
        $461 = $deferred$0$ph >>> 22;
        $462 = ((56 + ($461<<2)|0) + 57964|0);
        $463 = HEAP32[$462>>2]|0;
        $464 = (($463) + ($460<<2)|0);
        $465 = HEAP32[$464>>2]|0;
        $466 = ($465|0)==(0|0);
        if ($466) {
         $$pre$i14 = $378 & 31;
         $$pre1$i15 = 1 << $$pre$i14;
         $$pre3$i16 = $459 >>> 5;
         $$pre$phi2$i19Z2D = $$pre1$i15;$$pre$phi4$i18Z2D = $$pre3$i16;
        } else {
         $467 = $459 >>> 5;
         $468 = HEAP32[24>>2]|0;
         $469 = (($468) + ($467<<2)|0);
         $470 = HEAP32[$469>>2]|0;
         $471 = $378 & 31;
         $472 = 1 << $471;
         $473 = $470 & $472;
         $474 = ($473|0)==(0);
         if ($474) {
          $$0$be = $$5$lcssa;$credit$0$be = $205;
          break L77;
         } else {
          $$pre$phi2$i19Z2D = $472;$$pre$phi4$i18Z2D = $467;
         }
        }
        $475 = HEAP32[32>>2]|0;
        $476 = (($475) + ($$pre$phi4$i18Z2D<<2)|0);
        $477 = HEAP32[$476>>2]|0;
        $478 = $477 | $$pre$phi2$i19Z2D;
        HEAP32[$476>>2] = $478;
        $$0$be = $$5$lcssa;$credit$0$be = $205;
        break L77;
       }
       $479 = $deferred$0$ph & 3;
       $480 = ((56 + ($479)|0) + 16740|0);
       $481 = HEAP8[$480>>0]|0;
       $482 = ($481<<24>>24)==(0);
       if ($482) {
        $$0$be = $$5$lcssa;$credit$0$be = $205;
        break L77;
       }
       $483 = $378 & 262143;
       $484 = $378 & 1023;
       $485 = $deferred$0$ph >>> 22;
       $486 = ((56 + ($485<<2)|0) + 57964|0);
       $487 = HEAP32[$486>>2]|0;
       $488 = (($487) + ($484<<2)|0);
       $489 = HEAP32[$488>>2]|0;
       $490 = ($489|0)==(0|0);
       if ($490) {
        $$pre$i7 = $378 & 31;
        $$pre1$i8 = 1 << $$pre$i7;
        $$pre3$i9 = $483 >>> 5;
        $$pre$phi2$i12Z2D = $$pre1$i8;$$pre$phi4$i11Z2D = $$pre3$i9;
       } else {
        $491 = $483 >>> 5;
        $492 = HEAP32[8>>2]|0;
        $493 = (($492) + ($491<<2)|0);
        $494 = HEAP32[$493>>2]|0;
        $495 = $378 & 31;
        $496 = 1 << $495;
        $497 = $494 & $496;
        $498 = ($497|0)==(0);
        if ($498) {
         $$0$be = $$5$lcssa;$credit$0$be = $205;
         break L77;
        } else {
         $$pre$phi2$i12Z2D = $496;$$pre$phi4$i11Z2D = $491;
        }
       }
       $499 = HEAP32[16>>2]|0;
       $500 = (($499) + ($$pre$phi4$i11Z2D<<2)|0);
       $501 = HEAP32[$500>>2]|0;
       $502 = $501 | $$pre$phi2$i12Z2D;
       HEAP32[$500>>2] = $502;
       $$0$be = $$5$lcssa;$credit$0$be = $205;
       break L77;
      } else {
       $400 = (($my_hhdr15$0) + 8|0);
       $401 = HEAP32[$400>>2]|0;
       $402 = $401;
       $403 = (($deferred$0$ph) - ($402))|0;
       $404 = ($403|0)==($387|0);
       if (!($404)) {
        $base21$0 = $401;$gran_displ18$0 = 0;
        break;
       }
       $405 = ((56 + ($387)|0) + 12644|0);
       $406 = HEAP8[$405>>0]|0;
       $407 = ($406<<24>>24)==(0);
       if (!($407)) {
        $base21$0 = $401;$gran_displ18$0 = 0;
        break;
       }
       $408 = (1)==(0);
       if (!($408)) {
        $409 = $378 & 262143;
        $410 = $378 & 1023;
        $411 = $deferred$0$ph >>> 22;
        $412 = ((56 + ($411<<2)|0) + 57964|0);
        $413 = HEAP32[$412>>2]|0;
        $414 = (($413) + ($410<<2)|0);
        $415 = HEAP32[$414>>2]|0;
        $416 = ($415|0)==(0|0);
        if ($416) {
         $$pre$i28 = $378 & 31;
         $$pre1$i29 = 1 << $$pre$i28;
         $$pre3$i30 = $409 >>> 5;
         $$pre$phi2$i33Z2D = $$pre1$i29;$$pre$phi4$i32Z2D = $$pre3$i30;
        } else {
         $417 = $409 >>> 5;
         $418 = HEAP32[24>>2]|0;
         $419 = (($418) + ($417<<2)|0);
         $420 = HEAP32[$419>>2]|0;
         $421 = $378 & 31;
         $422 = 1 << $421;
         $423 = $420 & $422;
         $424 = ($423|0)==(0);
         if ($424) {
          $$0$be = $$5$lcssa;$credit$0$be = $205;
          break L77;
         } else {
          $$pre$phi2$i33Z2D = $422;$$pre$phi4$i32Z2D = $417;
         }
        }
        $425 = HEAP32[32>>2]|0;
        $426 = (($425) + ($$pre$phi4$i32Z2D<<2)|0);
        $427 = HEAP32[$426>>2]|0;
        $428 = $427 | $$pre$phi2$i33Z2D;
        HEAP32[$426>>2] = $428;
        $$0$be = $$5$lcssa;$credit$0$be = $205;
        break L77;
       }
       $429 = $deferred$0$ph & 3;
       $430 = ((56 + ($429)|0) + 16740|0);
       $431 = HEAP8[$430>>0]|0;
       $432 = ($431<<24>>24)==(0);
       if ($432) {
        $$0$be = $$5$lcssa;$credit$0$be = $205;
        break L77;
       }
       $433 = $378 & 262143;
       $434 = $378 & 1023;
       $435 = $deferred$0$ph >>> 22;
       $436 = ((56 + ($435<<2)|0) + 57964|0);
       $437 = HEAP32[$436>>2]|0;
       $438 = (($437) + ($434<<2)|0);
       $439 = HEAP32[$438>>2]|0;
       $440 = ($439|0)==(0|0);
       if ($440) {
        $$pre$i21 = $378 & 31;
        $$pre1$i22 = 1 << $$pre$i21;
        $$pre3$i23 = $433 >>> 5;
        $$pre$phi2$i26Z2D = $$pre1$i22;$$pre$phi4$i25Z2D = $$pre3$i23;
       } else {
        $441 = $433 >>> 5;
        $442 = HEAP32[8>>2]|0;
        $443 = (($442) + ($441<<2)|0);
        $444 = HEAP32[$443>>2]|0;
        $445 = $378 & 31;
        $446 = 1 << $445;
        $447 = $444 & $446;
        $448 = ($447|0)==(0);
        if ($448) {
         $$0$be = $$5$lcssa;$credit$0$be = $205;
         break L77;
        } else {
         $$pre$phi2$i26Z2D = $446;$$pre$phi4$i25Z2D = $441;
        }
       }
       $449 = HEAP32[16>>2]|0;
       $450 = (($449) + ($$pre$phi4$i25Z2D<<2)|0);
       $451 = HEAP32[$450>>2]|0;
       $452 = $451 | $$pre$phi2$i26Z2D;
       HEAP32[$450>>2] = $452;
       $$0$be = $$5$lcssa;$credit$0$be = $205;
       break L77;
      }
     }
    } while(0);
    $506 = $gran_displ18$0 >>> 5;
    $507 = ((($my_hhdr15$0) + ($506<<2)|0) + 36|0);
    $508 = HEAP32[$507>>2]|0;
    $509 = $gran_displ18$0 & 31;
    $510 = 1 << $509;
    $511 = $508 & $510;
    $512 = ($511|0)==(0);
    if ($512) {
     $513 = $508 | $510;
     HEAP32[$507>>2] = $513;
     $514 = (($my_hhdr15$0) + 32|0);
     $515 = HEAP32[$514>>2]|0;
     $516 = (($515) + 1)|0;
     HEAP32[$514>>2] = $516;
     $517 = (($my_hhdr15$0) + 20|0);
     $518 = HEAP32[$517>>2]|0;
     $519 = ($518|0)==(0);
     if ($519) {
      $$0$be = $$5$lcssa;$credit$0$be = $205;
     } else {
      $520 = (($$5$lcssa) + 8|0);
      $521 = ($520>>>0)<($mark_stack_limit>>>0);
      if ($521) {
       $$8 = $520;
      } else {
       HEAP32[65672>>2] = 5;
       HEAP32[65888>>2] = 1;
       $522 = HEAP32[62240>>2]|0;
       $523 = ($522|0)==(0);
       if (!($523)) {
        $524 = HEAP32[65592>>2]|0;
        HEAP32[$vararg_buffer4>>2] = $524;
        _GC_log_printf(66000,$vararg_buffer4);
       }
       $525 = (($$5$lcssa) + -4088|0);
       $$8 = $525;
      }
      HEAP32[$$8>>2] = $base21$0;
      $526 = (($$8) + 4|0);
      HEAP32[$526>>2] = $518;
      $$0$be = $$8;$credit$0$be = $205;
     }
    } else {
     $$0$be = $$5$lcssa;$credit$0$be = $205;
    }
   }
  } while(0);
  $185 = $$0$be;
  $186 = (($185) - ($3))|0;
  $187 = $186 | $credit$0$be;
  $188 = ($187|0)>(-1);
  if ($188) {
   $$0105 = $$0$be;$credit$0104 = $credit$0$be;
  } else {
   $$0$lcssa = $$0$be;
   label = 142;
   break;
  }
 }
 if ((label|0) == 57) {
  _GC_default_on_abort(66056);
  _abort();
  // unreachable;
 }
 else if ((label|0) == 142) {
  STACKTOP = sp;return ($$0$lcssa|0);
 }
 return 0|0;
}
function _GC_remove_dangling_disappearing_links($dl_hashtbl) {
 $dl_hashtbl = $dl_hashtbl|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curr$0$ph4 = 0, $curr$02 = 0, $i$05 = 0, $prev$0$ph3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($dl_hashtbl) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 $3 = 1 << $1;
 $$ = $2 ? 0 : $3;
 if ($2) {
  STACKTOP = sp;return;
 }
 $4 = (($dl_hashtbl) + 8|0);
 $i$05 = 0;
 while(1) {
  $5 = HEAP32[$dl_hashtbl>>2]|0;
  $6 = (($5) + ($i$05<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  L6: do {
   if (!($8)) {
    $curr$0$ph4 = $7;$prev$0$ph3 = 0;
    while(1) {
     $9 = ($prev$0$ph3|0)==(0|0);
     $10 = (($prev$0$ph3) + 4|0);
     $curr$02 = $curr$0$ph4;
     while(1) {
      $11 = HEAP32[$curr$02>>2]|0;
      $12 = $11 ^ -1;
      $13 = $12;
      $14 = (_GC_base($13)|0);
      $15 = ($14|0)==(0|0);
      if ($15) {
       break;
      }
      $16 = (_GC_is_marked($14)|0);
      $17 = ($16|0)==(0);
      if (!($17)) {
       break;
      }
      _GC_clear_mark_bit($curr$02);
      $18 = (($curr$02) + 4|0);
      $19 = HEAP32[$18>>2]|0;
      if ($9) {
       $20 = HEAP32[$dl_hashtbl>>2]|0;
       $21 = (($20) + ($i$05<<2)|0);
       HEAP32[$21>>2] = $19;
      } else {
       HEAP32[$10>>2] = $19;
      }
      _GC_clear_mark_bit($curr$02);
      $22 = HEAP32[$4>>2]|0;
      $23 = (($22) + -1)|0;
      HEAP32[$4>>2] = $23;
      $24 = ($19|0)==(0|0);
      if ($24) {
       break L6;
      } else {
       $curr$02 = $19;
      }
     }
     $25 = (($curr$02) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==(0|0);
     if ($27) {
      break;
     } else {
      $curr$0$ph4 = $26;$prev$0$ph3 = $curr$02;
     }
    }
   }
  } while(0);
  $28 = (($i$05) + 1)|0;
  $29 = ($28>>>0)<($$>>>0);
  if ($29) {
   $i$05 = $28;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _GC_invoke_finalizers() {
 var $$bytes_freed_before$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $bytes_freed_before$02 = 0, $count$0$lcssa7 = 0, $count$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[65448>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $count$0$lcssa7 = 0;
  STACKTOP = sp;return ($count$0$lcssa7|0);
 } else {
  $3 = 1;$5 = $0;$bytes_freed_before$02 = 0;$count$01 = 0;
 }
 while(1) {
  $2 = HEAP32[((56 + 44|0))>>2]|0;
  $$bytes_freed_before$0 = $3 ? $2 : $bytes_freed_before$02;
  $4 = (($5) + 4|0);
  $6 = HEAP32[$4>>2]|0;
  HEAP32[65448>>2] = $6;
  HEAP32[$4>>2] = 0;
  $7 = (($5) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$5>>2]|0;
  $10 = $9;
  $11 = (($5) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$8 & 4095]($10,$12);
  HEAP32[$11>>2] = 0;
  $13 = (($count$01) + 1)|0;
  $14 = HEAP32[65448>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   break;
  } else {
   $3 = 0;$5 = $14;$bytes_freed_before$02 = $$bytes_freed_before$0;$count$01 = $13;
  }
 }
 $16 = HEAP32[((56 + 44|0))>>2]|0;
 $17 = ($$bytes_freed_before$0|0)==($16|0);
 if ($17) {
  $count$0$lcssa7 = $13;
  STACKTOP = sp;return ($count$0$lcssa7|0);
 }
 $18 = (($16) - ($$bytes_freed_before$0))|0;
 $19 = HEAP32[((56 + 48|0))>>2]|0;
 $20 = (($18) + ($19))|0;
 HEAP32[((56 + 48|0))>>2] = $20;
 $count$0$lcssa7 = $13;
 STACKTOP = sp;return ($count$0$lcssa7|0);
}
function _GC_should_invoke_finalizers() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[65448>>2]|0;
 $1 = ($0|0)!=(0|0);
 $2 = $1&1;
 STACKTOP = sp;return ($2|0);
}
function _GC_reclaim_generic($hbp,$hhdr,$sz,$init,$list,$count) {
 $hbp = $hbp|0;
 $hhdr = $hhdr|0;
 $sz = $sz|0;
 $init = $init|0;
 $list = $list|0;
 $count = $count|0;
 var $$0$c$i = 0, $$0$c$i4 = 0, $$0$lcssa$i = 0, $$0$lcssa$i9 = 0, $$03$i = 0, $$05$i = 0, $$1$i = 0, $$1$i6 = 0, $$pre$phi$iZ2D = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $bit_no$01$i = 0, $bit_no$04$i = 0, $n_bytes_found$0$lcssa$i = 0, $n_bytes_found$0$lcssa$i8 = 0, $n_bytes_found$04$i = 0, $n_bytes_found$06$i = 0, $n_bytes_found$1$i = 0, $n_bytes_found$1$i7 = 0, $p$02$i = 0, $p$03$i = 0, $p$1$i = 0, $p$11$i = 0, $p$12$i = 0, $p$2$i = 0, $phitmp$i = 0, $phitmp1$i = 0, $result$0 = 0, $scevgep$i = 0, $storemerge = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = 0 | $init;
 $1 = ($0|0)==(0);
 $$sum$i = (4096 - ($sz))|0;
 $2 = (($hbp) + ($$sum$i)|0);
 if ($1) {
  $21 = ($2>>>0)<($hbp>>>0);
  if ($21) {
   $$0$lcssa$i = $list;$n_bytes_found$0$lcssa$i = 0;
  } else {
   $22 = $sz >>> 3;
   $$03$i = $list;$bit_no$01$i = 0;$n_bytes_found$04$i = 0;$p$02$i = $hbp;
   while(1) {
    $23 = $bit_no$01$i >>> 5;
    $24 = ((($hhdr) + ($23<<2)|0) + 36|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = $bit_no$01$i & 31;
    $27 = 1 << $26;
    $28 = $27 & $25;
    $29 = ($28|0)==(0);
    if ($29) {
     $30 = (($n_bytes_found$04$i) + ($sz))|0;
     $$0$c$i = $$03$i;
     HEAP32[$p$02$i>>2] = $$0$c$i;
     $$1$i = $p$02$i;$$pre$phi$iZ2D = $p$02$i;$n_bytes_found$1$i = $30;
    } else {
     $$1$i = $$03$i;$$pre$phi$iZ2D = $p$02$i;$n_bytes_found$1$i = $n_bytes_found$04$i;
    }
    $31 = (($$pre$phi$iZ2D) + ($sz)|0);
    $32 = (($bit_no$01$i) + ($22))|0;
    $33 = ($31>>>0)>($2>>>0);
    if ($33) {
     $$0$lcssa$i = $$1$i;$n_bytes_found$0$lcssa$i = $n_bytes_found$1$i;
     break;
    } else {
     $$03$i = $$1$i;$bit_no$01$i = $32;$n_bytes_found$04$i = $n_bytes_found$1$i;$p$02$i = $31;
    }
   }
  }
  $34 = HEAP32[$count>>2]|0;
  $35 = (($34) + ($n_bytes_found$0$lcssa$i))|0;
  $result$0 = $$0$lcssa$i;$storemerge = $35;
 } else {
  $3 = ($2>>>0)<($hbp>>>0);
  if ($3) {
   $$0$lcssa$i9 = $list;$n_bytes_found$0$lcssa$i8 = 0;
  } else {
   $4 = $sz >>> 3;
   $5 = ($sz|0)>(4);
   $$05$i = $list;$bit_no$04$i = 0;$n_bytes_found$06$i = 0;$p$03$i = $hbp;
   while(1) {
    $6 = $bit_no$04$i >>> 5;
    $7 = ((($hhdr) + ($6<<2)|0) + 36|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = $bit_no$04$i & 31;
    $10 = 1 << $9;
    $11 = $8 & $10;
    $12 = ($11|0)==(0);
    if ($12) {
     $14 = (($n_bytes_found$06$i) + ($sz))|0;
     $$0$c$i4 = $$05$i;
     HEAP32[$p$03$i>>2] = $$0$c$i4;
     $15 = (($p$03$i) + ($sz)|0);
     $p$11$i = (($p$03$i) + 4|0);
     if ($5) {
      $p$12$i = $p$11$i;
      while(1) {
       HEAP32[$p$12$i>>2] = 0;
       $p$1$i = (($p$12$i) + 4|0);
       $16 = ($p$1$i>>>0)<($15>>>0);
       if ($16) {
        $p$12$i = $p$1$i;
       } else {
        $$1$i6 = $p$03$i;$n_bytes_found$1$i7 = $14;$p$2$i = $p$1$i;
        break;
       }
      }
     } else {
      $$1$i6 = $p$03$i;$n_bytes_found$1$i7 = $14;$p$2$i = $p$11$i;
     }
    } else {
     $13 = (($p$03$i) + ($sz)|0);
     $$1$i6 = $$05$i;$n_bytes_found$1$i7 = $n_bytes_found$06$i;$p$2$i = $13;
    }
    $17 = (($bit_no$04$i) + ($4))|0;
    $18 = ($p$2$i>>>0)>($2>>>0);
    if ($18) {
     $$0$lcssa$i9 = $$1$i6;$n_bytes_found$0$lcssa$i8 = $n_bytes_found$1$i7;
     break;
    } else {
     $$05$i = $$1$i6;$bit_no$04$i = $17;$n_bytes_found$06$i = $n_bytes_found$1$i7;$p$03$i = $p$2$i;
    }
   }
  }
  $19 = HEAP32[$count>>2]|0;
  $20 = (($19) + ($n_bytes_found$0$lcssa$i8))|0;
  $result$0 = $$0$lcssa$i9;$storemerge = $20;
 }
 HEAP32[$count>>2] = $storemerge;
 $36 = (($hhdr) + 12|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)==(2);
 if (!($38)) {
  STACKTOP = sp;return ($result$0|0);
 }
 $39 = (($hhdr) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40>>>0)>(2048);
 if ($41) {
  $47 = 17;
  label = 20;
 } else {
  $42 = (4096 % ($40>>>0))&-1;
  $43 = (4096 - ($42))|0;
  $44 = $43 >>> 3;
  $phitmp$i = (($44) + 32)|0;
  $phitmp1$i = $phitmp$i >>> 5;
  $45 = ($phitmp1$i|0)==(0);
  if (!($45)) {
   $47 = $phitmp1$i;
   label = 20;
  }
 }
 if ((label|0) == 20) {
  $scevgep$i = (($hhdr) + 36|0);
  $46 = $47 << 2;
  _memset(($scevgep$i|0),-1,($46|0))|0;
 }
 $48 = (4096 / ($40>>>0))&-1;
 $49 = (($hhdr) + 32|0);
 HEAP32[$49>>2] = $48;
 STACKTOP = sp;return ($result$0|0);
}
function _GC_clear_mark_bit($p) {
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $p;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $0 >>> 3;
 $9 = $0 >>> 8;
 $10 = $9 & 15;
 $11 = ((($7) + ($10<<2)|0) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $8 & 31;
 $14 = 1 << $13;
 $15 = $12 & $14;
 $16 = ($15|0)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = $14 ^ -1;
 $18 = $12 & $17;
 HEAP32[$11>>2] = $18;
 $19 = (($7) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + -1)|0;
 HEAP32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function _GC_push_next_marked_dirty($h) {
 $h = $h|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $8 = 0, $9 = 0, $bi$0$i = 0, $bi$07$i = 0, $bi$08$i = 0, $bi$15$i = 0, $hhdr$0 = 0, $hhdr$0$in = 0, $hhdr$1 = 0, $j$04$i = 0, $j$1$be$i = 0, $j$12$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $h;
 $1 = HEAP32[65912>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  _GC_default_on_abort(66112);
  _abort();
  // unreachable;
 }
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = $0 >>> 12;
 $6 = HEAP32[$4>>2]|0;
 $7 = $5 & 1023;
 $8 = (($6) + ($7<<2)|0);
 $9 = HEAP32[((56 + 57960|0))>>2]|0;
 $bi$07$i = HEAP32[62304>>2]|0;
 $10 = ($bi$07$i|0)==(0|0);
 $$0 = $h;$hhdr$0$in = $8;
 L4: while(1) {
  $hhdr$0 = HEAP32[$hhdr$0$in>>2]|0;
  $11 = ($hhdr$0>>>0)<((4096)>>>0);
  if ($11) {
   label = 6;
  } else {
   $12 = (($hhdr$0) + 13|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = $13 & 4;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $$1 = $$0;$hhdr$1 = $hhdr$0;
   } else {
    label = 6;
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $16 = $$0;
   $17 = $16 >>> 22;
   $18 = ((56 + ($17<<2)|0) + 57964|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==($9|0);
   L10: do {
    if ($20) {
     if ($10) {
      $$01 = 0;
      label = 24;
      break L4;
     } else {
      $bi$08$i = $bi$07$i;
     }
     while(1) {
      $23 = (($bi$08$i) + 4104|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24>>>0)<($17>>>0);
      if (!($25)) {
       $bi$15$i = $bi$08$i;$j$04$i = 0;
       break L10;
      }
      $21 = (($bi$08$i) + 4096|0);
      $bi$0$i = HEAP32[$21>>2]|0;
      $22 = ($bi$0$i|0)==(0|0);
      if ($22) {
       $$01 = 0;
       label = 24;
       break L4;
      } else {
       $bi$08$i = $bi$0$i;
      }
     }
    } else {
     $26 = $16 >>> 12;
     $27 = $26 & 1023;
     $28 = ($19|0)==(0|0);
     if ($28) {
      $$01 = 0;
      label = 24;
      break L4;
     } else {
      $bi$15$i = $19;$j$04$i = $27;
     }
    }
   } while(0);
   L16: while(1) {
    $j$12$i = $j$04$i;
    while(1) {
     $29 = (($bi$15$i) + ($j$12$i<<2)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30>>>0)<((4096)>>>0);
     if ($31) {
      $32 = (($j$12$i) + 1)|0;
      $j$1$be$i = $32;
     } else {
      $33 = (($30) + 13|0);
      $34 = HEAP8[$33>>0]|0;
      $35 = $34 & 4;
      $36 = ($35<<24>>24)==(0);
      if ($36) {
       break L16;
      }
      $37 = (($30) + 16|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = $38 >>> 12;
      $40 = (($39) + ($j$12$i))|0;
      $j$1$be$i = $40;
     }
     $41 = ($j$1$be$i>>>0)<(1024);
     if ($41) {
      $j$12$i = $j$1$be$i;
     } else {
      break;
     }
    }
    $42 = (($bi$15$i) + 4096|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     $$01 = 0;
     label = 24;
     break L4;
    } else {
     $bi$15$i = $43;$j$04$i = 0;
    }
   }
   $45 = (($bi$15$i) + 4104|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = $46 << 10;
   $48 = (($47) + ($j$12$i))|0;
   $49 = $48 << 12;
   $50 = ($49|0)==(0);
   if ($50) {
    $$01 = 0;
    label = 24;
    break;
   }
   $51 = $49;
   $52 = $48 & 1023;
   $53 = $48 >>> 10;
   $54 = $53 & 1023;
   $55 = ((56 + ($54<<2)|0) + 57964|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + ($52<<2)|0);
   $58 = HEAP32[$57>>2]|0;
   $$1 = $51;$hhdr$1 = $58;
  }
  $59 = (($hhdr$1) + 16|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60>>>0)<(2049);
  if ($61) {
   label = 23;
   break;
  }
  $62 = $$1;
  $63 = (($60) + ($62))|0;
  $64 = ($62>>>0)<($63>>>0);
  if ($64) {
   label = 23;
   break;
  }
  $65 = (($60) + 4095)|0;
  $66 = $65 >>> 12;
  $67 = (($$1) + ($66<<12)|0);
  $68 = $67;
  $69 = $68 >>> 12;
  $70 = $69 & 1023;
  $71 = $68 >>> 22;
  $72 = ((56 + ($71<<2)|0) + 57964|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($73) + ($70<<2)|0);
  $$0 = $67;$hhdr$0$in = $74;
 }
 if ((label|0) == 23) {
  _GC_push_marked($$1,$hhdr$1);
  $75 = HEAP32[$59>>2]|0;
  $76 = (($75) + 4095)|0;
  $77 = $76 >>> 12;
  $78 = (($$1) + ($77<<12)|0);
  $$01 = $78;
  STACKTOP = sp;return ($$01|0);
 }
 else if ((label|0) == 24) {
  STACKTOP = sp;return ($$01|0);
 }
 return 0|0;
}
function _GC_push_roots($all,$cold_gc_frame) {
 $all = $all|0;
 $cold_gc_frame = $cold_gc_frame|0;
 var $$$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $candidate_hdr$0$lcssa$i = 0, $candidate_hdr$01$i = 0, $h$0$lcssa$i = 0, $h$02$i = 0, $i$04 = 0, $kind$03 = 0, $or$cond$i = 0, $r$0$lcssa$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[66136>>2] = 1;
 $0 = (0)>(0);
 if ($0) {
  $i$04 = 0;
  while(1) {
   $2 = ((56 + ($i$04<<4)|0) + 20840|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ((56 + ($i$04<<4)|0) + 20844|0);
   $5 = HEAP32[$4>>2]|0;
   _GC_push_conditional_with_exclusions($3,$5,$all);
   $6 = (($i$04) + 1)|0;
   $7 = ($6|0)<(0);
   if ($7) {
    $i$04 = $6;
   } else {
    break;
   }
  }
 }
 $1 = (3)==(0);
 if (!($1)) {
  $84 = 3;$kind$03 = 0;
  while(1) {
   $8 = (62448 + (($kind$03*20)|0)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[62424>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    $78 = $84;
   } else {
    $12 = $9;
    $13 = $12 & -4096;
    $14 = $13;
    $15 = $12 >>> 22;
    $16 = ((56 + ($15<<2)|0) + 57964|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = $12 >>> 12;
    $19 = $18 & 1023;
    $20 = (($17) + ($19<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     $78 = $84;
    } else {
     $23 = ($21>>>0)<((4096)>>>0);
     if ($23) {
      $candidate_hdr$01$i = $21;$h$02$i = $14;
      while(1) {
       $24 = $candidate_hdr$01$i;
       $25 = (0 - ($24))|0;
       $26 = (($h$02$i) + ($25<<12)|0);
       $27 = $26;
       $28 = $27 >>> 12;
       $29 = $28 & 1023;
       $30 = $27 >>> 22;
       $31 = ((56 + ($30<<2)|0) + 57964|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($32) + ($29<<2)|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ($34>>>0)<((4096)>>>0);
       if ($35) {
        $candidate_hdr$01$i = $34;$h$02$i = $26;
       } else {
        break;
       }
      }
      $candidate_hdr$0$lcssa$i = $34;$h$0$lcssa$i = $26;$r$0$lcssa$i = $26;
     } else {
      $candidate_hdr$0$lcssa$i = $21;$h$0$lcssa$i = $14;$r$0$lcssa$i = $9;
     }
     $36 = (($candidate_hdr$0$lcssa$i) + 13|0);
     $37 = HEAP8[$36>>0]|0;
     $38 = $37 & 4;
     $39 = ($38<<24>>24)==(0);
     if ($39) {
      $40 = $r$0$lcssa$i;
      $41 = $40 & -4;
      $42 = $41;
      $43 = $40 & 4092;
      $44 = (($candidate_hdr$0$lcssa$i) + 16|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = (($43>>>0) % ($45>>>0))&-1;
      $$sum$i = (($45) - ($46))|0;
      $47 = (($42) + ($$sum$i)|0);
      $48 = (($h$0$lcssa$i) + 4096|0);
      $49 = ($47>>>0)>($48>>>0);
      $50 = ($45>>>0)<(4097);
      $or$cond$i = $49 & $50;
      if ($or$cond$i) {
       $78 = $84;
      } else {
       $51 = (0 - ($46))|0;
       $52 = (($42) + ($51)|0);
       $53 = ($47>>>0)>($9>>>0);
       $$$i = $53 ? $52 : 0;
       $54 = ($$$i|0)==(0|0);
       if ($54) {
        $78 = $84;
       } else {
        $55 = $$$i;
        $56 = $55 >>> 12;
        $57 = $56 & 1023;
        $58 = $55 >>> 22;
        $59 = ((56 + ($58<<2)|0) + 57964|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = (($60) + ($57<<2)|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = $55 >>> 3;
        $64 = $55 >>> 8;
        $65 = $64 & 15;
        $66 = ((($62) + ($65<<2)|0) + 36|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = $63 & 31;
        $69 = 1 << $68;
        $70 = $67 & $69;
        $71 = ($70|0)==(0);
        if ($71) {
         $72 = $67 | $69;
         HEAP32[$66>>2] = $72;
         $73 = (($62) + 32|0);
         $74 = HEAP32[$73>>2]|0;
         $75 = (($74) + 1)|0;
         HEAP32[$73>>2] = $75;
         $78 = 3;
        } else {
         $78 = $84;
        }
       }
      }
     } else {
      $78 = $84;
     }
    }
   }
   $76 = (($kind$03) + 1)|0;
   $77 = ($76>>>0)<($78>>>0);
   if ($77) {
    $84 = $78;$kind$03 = $76;
   } else {
    break;
   }
  }
 }
 $79 = HEAP32[66136>>2]|0;
 $80 = 0 | $79;
 $81 = ($80|0)==(0);
 if (!($81)) {
  _GC_push_finalizer_structures();
  $82 = (0|0)==(0|0);
  if (!($82)) {
   abort /* segfault, call an absolute addr */ ();
  }
 }
 $83 = (0|0)==(0|0);
 if ($83) {
  STACKTOP = sp;return;
 }
 abort /* segfault, call an absolute addr */ ();
 STACKTOP = sp;return;
}
function _GC_push_next_marked_uncollectable($h) {
 $h = $h|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $bi$0$i = 0, $bi$07$i = 0, $bi$08$i = 0, $bi$15$i = 0, $hhdr$0 = 0, $hhdr$0$in = 0, $hhdr$1 = 0, $j$04$i = 0, $j$1$be$i = 0, $j$12$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $h;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[((56 + 57960|0))>>2]|0;
 $bi$07$i = HEAP32[62304>>2]|0;
 $8 = ($bi$07$i|0)==(0|0);
 $$0 = $h;$hhdr$0$in = $6;
 L1: while(1) {
  $hhdr$0 = HEAP32[$hhdr$0$in>>2]|0;
  $9 = ($hhdr$0>>>0)<((4096)>>>0);
  if ($9) {
   label = 4;
  } else {
   $10 = (($hhdr$0) + 13|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = $11 & 4;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    $$1 = $$0;$hhdr$1 = $hhdr$0;
   } else {
    label = 4;
   }
  }
  if ((label|0) == 4) {
   label = 0;
   $14 = $$0;
   $15 = $14 >>> 22;
   $16 = ((56 + ($15<<2)|0) + 57964|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==($7|0);
   L7: do {
    if ($18) {
     if ($8) {
      $$01 = 0;
      label = 21;
      break L1;
     } else {
      $bi$08$i = $bi$07$i;
     }
     while(1) {
      $21 = (($bi$08$i) + 4104|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22>>>0)<($15>>>0);
      if (!($23)) {
       $bi$15$i = $bi$08$i;$j$04$i = 0;
       break L7;
      }
      $19 = (($bi$08$i) + 4096|0);
      $bi$0$i = HEAP32[$19>>2]|0;
      $20 = ($bi$0$i|0)==(0|0);
      if ($20) {
       $$01 = 0;
       label = 21;
       break L1;
      } else {
       $bi$08$i = $bi$0$i;
      }
     }
    } else {
     $24 = $14 >>> 12;
     $25 = $24 & 1023;
     $26 = ($17|0)==(0|0);
     if ($26) {
      $$01 = 0;
      label = 21;
      break L1;
     } else {
      $bi$15$i = $17;$j$04$i = $25;
     }
    }
   } while(0);
   L13: while(1) {
    $j$12$i = $j$04$i;
    while(1) {
     $27 = (($bi$15$i) + ($j$12$i<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28>>>0)<((4096)>>>0);
     if ($29) {
      $30 = (($j$12$i) + 1)|0;
      $j$1$be$i = $30;
     } else {
      $31 = (($28) + 13|0);
      $32 = HEAP8[$31>>0]|0;
      $33 = $32 & 4;
      $34 = ($33<<24>>24)==(0);
      if ($34) {
       break L13;
      }
      $35 = (($28) + 16|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = $36 >>> 12;
      $38 = (($37) + ($j$12$i))|0;
      $j$1$be$i = $38;
     }
     $39 = ($j$1$be$i>>>0)<(1024);
     if ($39) {
      $j$12$i = $j$1$be$i;
     } else {
      break;
     }
    }
    $40 = (($bi$15$i) + 4096|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     $$01 = 0;
     label = 21;
     break L1;
    } else {
     $bi$15$i = $41;$j$04$i = 0;
    }
   }
   $43 = (($bi$15$i) + 4104|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = $44 << 10;
   $46 = (($45) + ($j$12$i))|0;
   $47 = $46 << 12;
   $48 = ($47|0)==(0);
   if ($48) {
    $$01 = 0;
    label = 21;
    break;
   }
   $49 = $47;
   $50 = $46 & 1023;
   $51 = $46 >>> 10;
   $52 = $51 & 1023;
   $53 = ((56 + ($52<<2)|0) + 57964|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + ($50<<2)|0);
   $56 = HEAP32[$55>>2]|0;
   $$1 = $49;$hhdr$1 = $56;
  }
  $57 = (($hhdr$1) + 12|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = ($58<<24>>24)==(2);
  if ($59) {
   label = 19;
   break;
  }
  $65 = (($hhdr$1) + 16|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + 4095)|0;
  $68 = $67 >>> 12;
  $69 = (($$1) + ($68<<12)|0);
  $70 = $69;
  $71 = $70 >>> 12;
  $72 = $71 & 1023;
  $73 = $70 >>> 22;
  $74 = ((56 + ($73<<2)|0) + 57964|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($75) + ($72<<2)|0);
  $$0 = $69;$hhdr$0$in = $76;
 }
 if ((label|0) == 19) {
  _GC_push_marked($$1,$hhdr$1);
  $60 = (($hhdr$1) + 16|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 4095)|0;
  $63 = $62 >>> 12;
  $64 = (($$1) + ($63<<12)|0);
  $$01 = $64;
  STACKTOP = sp;return ($$01|0);
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return ($$01|0);
 }
 return 0|0;
}
function _alloc_mark_stack($n) {
 $n = $n|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = $n << 3;
 $1 = (_GC_scratch_alloc($0)|0);
 HEAP32[65888>>2] = 0;
 $2 = HEAP32[65592>>2]|0;
 $3 = ($2|0)==(0);
 $4 = ($1|0)==(0|0);
 do {
  if ($3) {
   if ($4) {
    _GC_err_printf(67888,$vararg_buffer1);
    _GC_default_on_abort(0);
    _exit(1);
    // unreachable;
   } else {
    HEAP32[((56 + 60|0))>>2] = $1;
    HEAP32[65592>>2] = $n;
    $22 = (($1) + ($n<<3)|0);
    HEAP32[((56 + 64|0))>>2] = $22;
    break;
   }
  } else {
   if ($4) {
    _GC_default_warn_proc(67832,$n);
    break;
   }
   $5 = HEAP32[((56 + 60|0))>>2]|0;
   $6 = $5;
   $7 = HEAP32[65032>>2]|0;
   $8 = (($7) + -1)|0;
   $9 = $8 & $6;
   $10 = $2 << 3;
   $11 = ($9|0)==(0);
   $12 = (($7) - ($9))|0;
   $$ = $11 ? 0 : $12;
   $13 = (($10) - ($$))|0;
   $14 = (0 - ($7))|0;
   $15 = $13 & $14;
   $16 = ($15|0)==(0);
   if (!($16)) {
    $17 = (($$) + ($6))|0;
    $18 = $17;
    _GC_add_to_heap($18,$15);
   }
   HEAP32[((56 + 60|0))>>2] = $1;
   HEAP32[65592>>2] = $n;
   $19 = (($1) + ($n<<3)|0);
   HEAP32[((56 + 64|0))>>2] = $19;
   $20 = HEAP32[62240>>2]|0;
   $21 = ($20|0)==(0);
   if (!($21)) {
    HEAP32[$vararg_buffer1>>2] = $n;
    _GC_log_printf(67800,$vararg_buffer1);
   }
  }
 } while(0);
 $23 = HEAP32[((56 + 60|0))>>2]|0;
 $24 = (($23) + -8|0);
 HEAP32[((56 + 68|0))>>2] = $24;
 STACKTOP = sp;return;
}
function _GC_push_next_marked($h) {
 $h = $h|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bi$0$i = 0;
 var $bi$07$i = 0, $bi$08$i = 0, $bi$15$i = 0, $hhdr$0 = 0, $j$04$i = 0, $j$1$be$i = 0, $j$12$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $h;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7>>>0)<((4096)>>>0);
 if ($8) {
  label = 3;
 } else {
  $9 = (($7) + 13|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10 & 4;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $$0 = $h;$hhdr$0 = $7;
  } else {
   label = 3;
  }
 }
 do {
  if ((label|0) == 3) {
   $13 = HEAP32[((56 + 57960|0))>>2]|0;
   $14 = ($5|0)==($13|0);
   L5: do {
    if ($14) {
     $bi$07$i = HEAP32[62304>>2]|0;
     $15 = ($bi$07$i|0)==(0|0);
     if ($15) {
      $$01 = 0;
      STACKTOP = sp;return ($$01|0);
     } else {
      $bi$08$i = $bi$07$i;
     }
     while(1) {
      $18 = (($bi$08$i) + 4104|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = ($19>>>0)<($3>>>0);
      if (!($20)) {
       $bi$15$i = $bi$08$i;$j$04$i = 0;
       break L5;
      }
      $16 = (($bi$08$i) + 4096|0);
      $bi$0$i = HEAP32[$16>>2]|0;
      $17 = ($bi$0$i|0)==(0|0);
      if ($17) {
       $$01 = 0;
       break;
      } else {
       $bi$08$i = $bi$0$i;
      }
     }
     STACKTOP = sp;return ($$01|0);
    } else {
     $21 = ($5|0)==(0|0);
     if ($21) {
      $$01 = 0;
      STACKTOP = sp;return ($$01|0);
     } else {
      $bi$15$i = $5;$j$04$i = $2;
     }
    }
   } while(0);
   L15: while(1) {
    $j$12$i = $j$04$i;
    while(1) {
     $22 = (($bi$15$i) + ($j$12$i<<2)|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23>>>0)<((4096)>>>0);
     if ($24) {
      $25 = (($j$12$i) + 1)|0;
      $j$1$be$i = $25;
     } else {
      $26 = (($23) + 13|0);
      $27 = HEAP8[$26>>0]|0;
      $28 = $27 & 4;
      $29 = ($28<<24>>24)==(0);
      if ($29) {
       break L15;
      }
      $30 = (($23) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = $31 >>> 12;
      $33 = (($32) + ($j$12$i))|0;
      $j$1$be$i = $33;
     }
     $34 = ($j$1$be$i>>>0)<(1024);
     if ($34) {
      $j$12$i = $j$1$be$i;
     } else {
      break;
     }
    }
    $35 = (($bi$15$i) + 4096|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$01 = 0;
     label = 18;
     break;
    } else {
     $bi$15$i = $36;$j$04$i = 0;
    }
   }
   if ((label|0) == 18) {
    STACKTOP = sp;return ($$01|0);
   }
   $38 = (($bi$15$i) + 4104|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = $39 << 10;
   $41 = (($40) + ($j$12$i))|0;
   $42 = $41 << 12;
   $43 = ($42|0)==(0);
   if ($43) {
    $$01 = 0;
    STACKTOP = sp;return ($$01|0);
   } else {
    $44 = $42;
    $45 = $41 & 1023;
    $46 = $41 >>> 10;
    $47 = $46 & 1023;
    $48 = ((56 + ($47<<2)|0) + 57964|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($45<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $$0 = $44;$hhdr$0 = $51;
    break;
   }
  }
 } while(0);
 _GC_push_marked($$0,$hhdr$0);
 $52 = (($hhdr$0) + 16|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 4095)|0;
 $55 = $54 >>> 12;
 $56 = (($$0) + ($55<<12)|0);
 $$01 = $56;
 STACKTOP = sp;return ($$01|0);
}
function _GC_push_selected($bottom,$top,$dirty_fn) {
 $bottom = $bottom|0;
 $top = $top|0;
 $dirty_fn = $dirty_fn|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $h$0$lcssa = 0, $h$012 = 0, $h$012$phi = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $bottom;
 $1 = (($0) + 3)|0;
 $2 = $1 & -4;
 $3 = $top;
 $4 = $3 & -4;
 $5 = $4;
 $6 = ($2>>>0)<($4>>>0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = $2;
 $8 = (($7) + 4096|0);
 $9 = $8;
 $10 = $9 & -4096;
 $11 = $10;
 $12 = ($4>>>0)>($10>>>0);
 $13 = (($11) + -4096|0);
 $14 = (FUNCTION_TABLE_ii[$dirty_fn & 4095]($13)|0);
 $15 = ($14|0)!=(0);
 if (!($12)) {
  if (!($15)) {
   STACKTOP = sp;return;
  }
  $16 = HEAP32[((56 + 68|0))>>2]|0;
  $17 = (($16) + 8|0);
  HEAP32[((56 + 68|0))>>2] = $17;
  $18 = HEAP32[((56 + 64|0))>>2]|0;
  $19 = ($17>>>0)<($18>>>0);
  if (!($19)) {
   _GC_default_on_abort(66080);
   _abort();
   // unreachable;
  }
  $20 = (($4) - ($2))|0;
  HEAP32[$17>>2] = $7;
  $21 = HEAP32[((56 + 68|0))>>2]|0;
  $22 = (($21) + 4|0);
  HEAP32[$22>>2] = $20;
  STACKTOP = sp;return;
 }
 $23 = ($2>>>0)<($10>>>0);
 $or$cond = $15 & $23;
 do {
  if ($or$cond) {
   $24 = HEAP32[((56 + 68|0))>>2]|0;
   $25 = (($24) + 8|0);
   HEAP32[((56 + 68|0))>>2] = $25;
   $26 = HEAP32[((56 + 64|0))>>2]|0;
   $27 = ($25>>>0)<($26>>>0);
   if ($27) {
    $28 = (($10) - ($2))|0;
    HEAP32[$25>>2] = $7;
    $29 = HEAP32[((56 + 68|0))>>2]|0;
    $30 = (($29) + 4|0);
    HEAP32[$30>>2] = $28;
    break;
   } else {
    _GC_default_on_abort(66080);
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $31 = (($11) + 4096|0);
 $32 = $31;
 $33 = ($32>>>0)>($4>>>0);
 L20: do {
  if ($33) {
   $h$0$lcssa = $11;
  } else {
   $37 = $31;$h$012 = $11;
   while(1) {
    $34 = (FUNCTION_TABLE_ii[$dirty_fn & 4095]($h$012)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $40 = HEAP32[((56 + 68|0))>>2]|0;
     $41 = HEAP32[((56 + 60|0))>>2]|0;
     $42 = $40;
     $43 = $41;
     $44 = (($42) - ($43))|0;
     $45 = $44 >> 3;
     $46 = HEAP32[65592>>2]|0;
     $47 = ($46*3)|0;
     $48 = $47 >>> 2;
     $49 = ($45>>>0)>($48>>>0);
     $50 = $h$012;
     $51 = (($50) + 3)|0;
     $52 = $51 & -4;
     $53 = $52;
     if ($49) {
      break;
     }
     $61 = $37;
     $62 = $61 & -4;
     $63 = ($52>>>0)<($62>>>0);
     if ($63) {
      $64 = (($40) + 8|0);
      HEAP32[((56 + 68|0))>>2] = $64;
      $65 = HEAP32[((56 + 64|0))>>2]|0;
      $66 = ($64>>>0)<($65>>>0);
      if (!($66)) {
       label = 21;
       break;
      }
      $67 = (($62) - ($52))|0;
      HEAP32[$64>>2] = $53;
      $68 = HEAP32[((56 + 68|0))>>2]|0;
      $69 = (($68) + 4|0);
      HEAP32[$69>>2] = $67;
     }
    }
    $36 = (($37) + 4096|0);
    $38 = $36;
    $39 = ($38>>>0)>($4>>>0);
    if ($39) {
     $h$0$lcssa = $37;
     break L20;
    } else {
     $h$012$phi = $37;$37 = $36;$h$012 = $h$012$phi;
    }
   }
   if ((label|0) == 21) {
    _GC_default_on_abort(66080);
    _abort();
    // unreachable;
   }
   $54 = ($52>>>0)<($4>>>0);
   if (!($54)) {
    STACKTOP = sp;return;
   }
   $55 = (($40) + 8|0);
   HEAP32[((56 + 68|0))>>2] = $55;
   $56 = HEAP32[((56 + 64|0))>>2]|0;
   $57 = ($55>>>0)<($56>>>0);
   if (!($57)) {
    _GC_default_on_abort(66080);
    _abort();
    // unreachable;
   }
   $58 = (($4) - ($52))|0;
   HEAP32[$55>>2] = $53;
   $59 = HEAP32[((56 + 68|0))>>2]|0;
   $60 = (($59) + 4|0);
   HEAP32[$60>>2] = $58;
   STACKTOP = sp;return;
  }
 } while(0);
 $70 = ($h$0$lcssa|0)==($5|0);
 do {
  if (!($70)) {
   $71 = (FUNCTION_TABLE_ii[$dirty_fn & 4095]($h$0$lcssa)|0);
   $72 = ($71|0)==(0);
   if (!($72)) {
    $73 = $h$0$lcssa;
    $74 = (($73) + 3)|0;
    $75 = $74 & -4;
    $76 = $75;
    $77 = ($75>>>0)<($4>>>0);
    if ($77) {
     $78 = HEAP32[((56 + 68|0))>>2]|0;
     $79 = (($78) + 8|0);
     HEAP32[((56 + 68|0))>>2] = $79;
     $80 = HEAP32[((56 + 64|0))>>2]|0;
     $81 = ($79>>>0)<($80>>>0);
     if ($81) {
      $82 = (($4) - ($75))|0;
      HEAP32[$79>>2] = $76;
      $83 = HEAP32[((56 + 68|0))>>2]|0;
      $84 = (($83) + 4|0);
      HEAP32[$84>>2] = $82;
      break;
     } else {
      _GC_default_on_abort(66080);
      _abort();
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $85 = HEAP32[((56 + 68|0))>>2]|0;
 $86 = HEAP32[((56 + 64|0))>>2]|0;
 $87 = ($85>>>0)<($86>>>0);
 if ($87) {
  STACKTOP = sp;return;
 } else {
  _GC_default_on_abort(66080);
  _abort();
  // unreachable;
 }
}
function _GC_page_was_dirty($h) {
 $h = $h|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function _GC_push_marked2($h,$hhdr) {
 $h = $h|0;
 $hhdr = $hhdr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mark_stack_top$0$lcssa = 0, $mark_stack_top$06 = 0, $mark_stack_top$1$lcssa = 0, $mark_stack_top$14 = 0, $mark_stack_top$2 = 0, $mark_stack_top$3 = 0, $mark_stack_top$4 = 0, $mark_stack_top$5 = 0, $mark_word$01 = 0, $mark_word_addr$07 = 0, $or$cond = 0, $or$cond12 = 0, $or$cond13 = 0, $or$cond14 = 0, $p$05 = 0, $q$02 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((56 + 68|0))>>2]|0;
 $1 = HEAP32[((56 + 64|0))>>2]|0;
 $2 = $h;
 $3 = (($2) + 4096)|0;
 $4 = ($h>>>0)<((-4096)>>>0);
 if (!($4)) {
  $mark_stack_top$0$lcssa = $0;
  HEAP32[((56 + 68|0))>>2] = $mark_stack_top$0$lcssa;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[64936>>2]|0;
 $6 = HEAP32[64928>>2]|0;
 $7 = (($hhdr) + 36|0);
 $8 = $6;
 $9 = $5;
 $mark_stack_top$06 = $0;$mark_word_addr$07 = $7;$p$05 = $h;
 while(1) {
  $10 = (($mark_word_addr$07) + 4|0);
  $11 = HEAP32[$mark_word_addr$07>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $mark_stack_top$1$lcssa = $mark_stack_top$06;
  } else {
   $mark_stack_top$14 = $mark_stack_top$06;$mark_word$01 = $11;$q$02 = $p$05;
   while(1) {
    $13 = $mark_word$01 & 1;
    $14 = ($13|0)==(0);
    if ($14) {
     $mark_stack_top$5 = $mark_stack_top$14;
    } else {
     $15 = HEAP32[$q$02>>2]|0;
     $16 = ($15>>>0)>=($8>>>0);
     $17 = ($15>>>0)<($9>>>0);
     $or$cond = $16 & $17;
     if ($or$cond) {
      $18 = $15;
      $19 = (_GC_mark_and_push($18,$mark_stack_top$14,$1,0)|0);
      $mark_stack_top$2 = $19;
     } else {
      $mark_stack_top$2 = $mark_stack_top$14;
     }
     $20 = (($q$02) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21>>>0)>=($8>>>0);
     $23 = ($21>>>0)<($9>>>0);
     $or$cond12 = $22 & $23;
     if ($or$cond12) {
      $24 = $21;
      $25 = (_GC_mark_and_push($24,$mark_stack_top$2,$1,0)|0);
      $mark_stack_top$3 = $25;
     } else {
      $mark_stack_top$3 = $mark_stack_top$2;
     }
     $26 = (($q$02) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27>>>0)>=($8>>>0);
     $29 = ($27>>>0)<($9>>>0);
     $or$cond13 = $28 & $29;
     if ($or$cond13) {
      $30 = $27;
      $31 = (_GC_mark_and_push($30,$mark_stack_top$3,$1,0)|0);
      $mark_stack_top$4 = $31;
     } else {
      $mark_stack_top$4 = $mark_stack_top$3;
     }
     $32 = (($q$02) + 12|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33>>>0)>=($8>>>0);
     $35 = ($33>>>0)<($9>>>0);
     $or$cond14 = $34 & $35;
     if ($or$cond14) {
      $36 = $33;
      $37 = (_GC_mark_and_push($36,$mark_stack_top$4,$1,0)|0);
      $mark_stack_top$5 = $37;
     } else {
      $mark_stack_top$5 = $mark_stack_top$4;
     }
    }
    $38 = (($q$02) + 16|0);
    $39 = $mark_word$01 >>> 2;
    $40 = ($39|0)==(0);
    if ($40) {
     $mark_stack_top$1$lcssa = $mark_stack_top$5;
     break;
    } else {
     $mark_stack_top$14 = $mark_stack_top$5;$mark_word$01 = $39;$q$02 = $38;
    }
   }
  }
  $41 = (($p$05) + 256|0);
  $42 = $41;
  $43 = ($42>>>0)<($3>>>0);
  if ($43) {
   $mark_stack_top$06 = $mark_stack_top$1$lcssa;$mark_word_addr$07 = $10;$p$05 = $41;
  } else {
   $mark_stack_top$0$lcssa = $mark_stack_top$1$lcssa;
   break;
  }
 }
 HEAP32[((56 + 68|0))>>2] = $mark_stack_top$0$lcssa;
 STACKTOP = sp;return;
}
function _GC_push_marked4($h,$hhdr) {
 $h = $h|0;
 $hhdr = $hhdr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $mark_stack_top$0$lcssa = 0, $mark_stack_top$06 = 0, $mark_stack_top$1$lcssa = 0, $mark_stack_top$14 = 0, $mark_stack_top$2 = 0, $mark_stack_top$3 = 0, $mark_stack_top$4 = 0, $mark_stack_top$5 = 0, $mark_stack_top$6 = 0, $mark_stack_top$7 = 0, $mark_stack_top$8 = 0, $mark_stack_top$9 = 0;
 var $mark_word$01 = 0, $mark_word_addr$07 = 0, $or$cond = 0, $or$cond12 = 0, $or$cond13 = 0, $or$cond14 = 0, $or$cond15 = 0, $or$cond16 = 0, $or$cond17 = 0, $or$cond18 = 0, $p$05 = 0, $q$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((56 + 68|0))>>2]|0;
 $1 = HEAP32[((56 + 64|0))>>2]|0;
 $2 = $h;
 $3 = (($2) + 4096)|0;
 $4 = ($h>>>0)<((-4096)>>>0);
 if (!($4)) {
  $mark_stack_top$0$lcssa = $0;
  HEAP32[((56 + 68|0))>>2] = $mark_stack_top$0$lcssa;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[64936>>2]|0;
 $6 = HEAP32[64928>>2]|0;
 $7 = (($hhdr) + 36|0);
 $8 = $6;
 $9 = $5;
 $mark_stack_top$06 = $0;$mark_word_addr$07 = $7;$p$05 = $h;
 while(1) {
  $10 = (($mark_word_addr$07) + 4|0);
  $11 = HEAP32[$mark_word_addr$07>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $mark_stack_top$1$lcssa = $mark_stack_top$06;
  } else {
   $mark_stack_top$14 = $mark_stack_top$06;$mark_word$01 = $11;$q$02 = $p$05;
   while(1) {
    $13 = $mark_word$01 & 1;
    $14 = ($13|0)==(0);
    if ($14) {
     $mark_stack_top$9 = $mark_stack_top$14;
    } else {
     $15 = HEAP32[$q$02>>2]|0;
     $16 = ($15>>>0)>=($8>>>0);
     $17 = ($15>>>0)<($9>>>0);
     $or$cond = $16 & $17;
     if ($or$cond) {
      $18 = $15;
      $19 = (_GC_mark_and_push($18,$mark_stack_top$14,$1,0)|0);
      $mark_stack_top$2 = $19;
     } else {
      $mark_stack_top$2 = $mark_stack_top$14;
     }
     $20 = (($q$02) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21>>>0)>=($8>>>0);
     $23 = ($21>>>0)<($9>>>0);
     $or$cond12 = $22 & $23;
     if ($or$cond12) {
      $24 = $21;
      $25 = (_GC_mark_and_push($24,$mark_stack_top$2,$1,0)|0);
      $mark_stack_top$3 = $25;
     } else {
      $mark_stack_top$3 = $mark_stack_top$2;
     }
     $26 = (($q$02) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27>>>0)>=($8>>>0);
     $29 = ($27>>>0)<($9>>>0);
     $or$cond13 = $28 & $29;
     if ($or$cond13) {
      $30 = $27;
      $31 = (_GC_mark_and_push($30,$mark_stack_top$3,$1,0)|0);
      $mark_stack_top$4 = $31;
     } else {
      $mark_stack_top$4 = $mark_stack_top$3;
     }
     $32 = (($q$02) + 12|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33>>>0)>=($8>>>0);
     $35 = ($33>>>0)<($9>>>0);
     $or$cond14 = $34 & $35;
     if ($or$cond14) {
      $36 = $33;
      $37 = (_GC_mark_and_push($36,$mark_stack_top$4,$1,0)|0);
      $mark_stack_top$5 = $37;
     } else {
      $mark_stack_top$5 = $mark_stack_top$4;
     }
     $38 = (($q$02) + 16|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39>>>0)>=($8>>>0);
     $41 = ($39>>>0)<($9>>>0);
     $or$cond15 = $40 & $41;
     if ($or$cond15) {
      $42 = $39;
      $43 = (_GC_mark_and_push($42,$mark_stack_top$5,$1,0)|0);
      $mark_stack_top$6 = $43;
     } else {
      $mark_stack_top$6 = $mark_stack_top$5;
     }
     $44 = (($q$02) + 20|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)>=($8>>>0);
     $47 = ($45>>>0)<($9>>>0);
     $or$cond16 = $46 & $47;
     if ($or$cond16) {
      $48 = $45;
      $49 = (_GC_mark_and_push($48,$mark_stack_top$6,$1,0)|0);
      $mark_stack_top$7 = $49;
     } else {
      $mark_stack_top$7 = $mark_stack_top$6;
     }
     $50 = (($q$02) + 24|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51>>>0)>=($8>>>0);
     $53 = ($51>>>0)<($9>>>0);
     $or$cond17 = $52 & $53;
     if ($or$cond17) {
      $54 = $51;
      $55 = (_GC_mark_and_push($54,$mark_stack_top$7,$1,0)|0);
      $mark_stack_top$8 = $55;
     } else {
      $mark_stack_top$8 = $mark_stack_top$7;
     }
     $56 = (($q$02) + 28|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57>>>0)>=($8>>>0);
     $59 = ($57>>>0)<($9>>>0);
     $or$cond18 = $58 & $59;
     if ($or$cond18) {
      $60 = $57;
      $61 = (_GC_mark_and_push($60,$mark_stack_top$8,$1,0)|0);
      $mark_stack_top$9 = $61;
     } else {
      $mark_stack_top$9 = $mark_stack_top$8;
     }
    }
    $62 = (($q$02) + 32|0);
    $63 = $mark_word$01 >>> 4;
    $64 = ($63|0)==(0);
    if ($64) {
     $mark_stack_top$1$lcssa = $mark_stack_top$9;
     break;
    } else {
     $mark_stack_top$14 = $mark_stack_top$9;$mark_word$01 = $63;$q$02 = $62;
    }
   }
  }
  $65 = (($p$05) + 256|0);
  $66 = $65;
  $67 = ($66>>>0)<($3>>>0);
  if ($67) {
   $mark_stack_top$06 = $mark_stack_top$1$lcssa;$mark_word_addr$07 = $10;$p$05 = $65;
  } else {
   $mark_stack_top$0$lcssa = $mark_stack_top$1$lcssa;
   break;
  }
 }
 HEAP32[((56 + 68|0))>>2] = $mark_stack_top$0$lcssa;
 STACKTOP = sp;return;
}
function _GC_push_marked($h,$hhdr) {
 $h = $h|0;
 $hhdr = $hhdr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $GC_mark_stack_top_reg$0$lcssa = 0, $GC_mark_stack_top_reg$01 = 0, $GC_mark_stack_top_reg$1 = 0, $GC_mark_stack_top_reg$2 = 0, $bit_no$02 = 0, $lim$0 = 0, $mark_stack_top$0$lcssa$i = 0, $mark_stack_top$05$i = 0, $mark_stack_top$1$lcssa$i = 0, $mark_stack_top$13$i = 0, $mark_stack_top$2$i = 0, $mark_stack_top$3$i = 0, $mark_word$01$i = 0;
 var $mark_word_addr$06$i = 0, $or$cond$i = 0, $or$cond11$i = 0, $p$03 = 0, $p$04$i = 0, $q$02$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($hhdr) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($hhdr) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[((56 + 64|0))>>2]|0;
 $5 = ($3|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($hhdr) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[65880>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[65880>>2] = $10;
 HEAP32[65896>>2] = 1;
 $11 = ($1>>>0)>(2048);
 if ($11) {
  $lim$0 = $h;
 } else {
  $12 = (0 - ($1))|0;
  $13 = ((($h) + ($12)|0) + 4096|0);
  $lim$0 = $13;
 }
 $14 = $1 >>> 3;
 if ((($14|0) == 1)) {
  $15 = HEAP32[((56 + 68|0))>>2]|0;
  $16 = $h;
  $17 = (($16) + 4096)|0;
  $18 = ($h>>>0)<((-4096)>>>0);
  if ($18) {
   $19 = HEAP32[64936>>2]|0;
   $20 = HEAP32[64928>>2]|0;
   $21 = (($hhdr) + 36|0);
   $22 = $20;
   $23 = $19;
   $mark_stack_top$05$i = $15;$mark_word_addr$06$i = $21;$p$04$i = $h;
   while(1) {
    $24 = (($mark_word_addr$06$i) + 4|0);
    $25 = HEAP32[$mark_word_addr$06$i>>2]|0;
    $26 = ($25|0)==(0);
    if ($26) {
     $mark_stack_top$1$lcssa$i = $mark_stack_top$05$i;
    } else {
     $mark_stack_top$13$i = $mark_stack_top$05$i;$mark_word$01$i = $25;$q$02$i = $p$04$i;
     while(1) {
      $27 = $mark_word$01$i & 1;
      $28 = ($27|0)==(0);
      if ($28) {
       $mark_stack_top$3$i = $mark_stack_top$13$i;
      } else {
       $29 = HEAP32[$q$02$i>>2]|0;
       $30 = ($29>>>0)>=($22>>>0);
       $31 = ($29>>>0)<($23>>>0);
       $or$cond$i = $30 & $31;
       if ($or$cond$i) {
        $32 = $29;
        $33 = (_GC_mark_and_push($32,$mark_stack_top$13$i,$4,0)|0);
        $mark_stack_top$2$i = $33;
       } else {
        $mark_stack_top$2$i = $mark_stack_top$13$i;
       }
       $34 = (($q$02$i) + 4|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = ($35>>>0)>=($22>>>0);
       $37 = ($35>>>0)<($23>>>0);
       $or$cond11$i = $36 & $37;
       if ($or$cond11$i) {
        $38 = $35;
        $39 = (_GC_mark_and_push($38,$mark_stack_top$2$i,$4,0)|0);
        $mark_stack_top$3$i = $39;
       } else {
        $mark_stack_top$3$i = $mark_stack_top$2$i;
       }
      }
      $40 = (($q$02$i) + 8|0);
      $41 = $mark_word$01$i >>> 1;
      $42 = ($41|0)==(0);
      if ($42) {
       $mark_stack_top$1$lcssa$i = $mark_stack_top$3$i;
       break;
      } else {
       $mark_stack_top$13$i = $mark_stack_top$3$i;$mark_word$01$i = $41;$q$02$i = $40;
      }
     }
    }
    $43 = (($p$04$i) + 256|0);
    $44 = $43;
    $45 = ($44>>>0)<($17>>>0);
    if ($45) {
     $mark_stack_top$05$i = $mark_stack_top$1$lcssa$i;$mark_word_addr$06$i = $24;$p$04$i = $43;
    } else {
     $mark_stack_top$0$lcssa$i = $mark_stack_top$1$lcssa$i;
     break;
    }
   }
  } else {
   $mark_stack_top$0$lcssa$i = $15;
  }
  HEAP32[((56 + 68|0))>>2] = $mark_stack_top$0$lcssa$i;
  STACKTOP = sp;return;
 } else if ((($14|0) == 4)) {
  _GC_push_marked4($h,$hhdr);
  STACKTOP = sp;return;
 } else if ((($14|0) == 2)) {
  _GC_push_marked2($h,$hhdr);
  STACKTOP = sp;return;
 } else {
  $46 = HEAP32[((56 + 68|0))>>2]|0;
  $47 = ($h>>>0)>($lim$0>>>0);
  if ($47) {
   $GC_mark_stack_top_reg$0$lcssa = $46;
  } else {
   $GC_mark_stack_top_reg$01 = $46;$bit_no$02 = 0;$p$03 = $h;
   while(1) {
    $48 = $bit_no$02 >>> 5;
    $49 = ((($hhdr) + ($48<<2)|0) + 36|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = $bit_no$02 & 31;
    $52 = 1 << $51;
    $53 = $50 & $52;
    $54 = ($53|0)==(0);
    if ($54) {
     $GC_mark_stack_top_reg$2 = $GC_mark_stack_top_reg$01;
    } else {
     $55 = HEAP32[$2>>2]|0;
     $56 = ($55|0)==(0);
     if ($56) {
      $GC_mark_stack_top_reg$2 = $GC_mark_stack_top_reg$01;
     } else {
      $57 = (($GC_mark_stack_top_reg$01) + 8|0);
      $58 = ($57>>>0)<($4>>>0);
      if ($58) {
       $GC_mark_stack_top_reg$1 = $57;
      } else {
       HEAP32[65672>>2] = 5;
       HEAP32[65888>>2] = 1;
       $59 = HEAP32[62240>>2]|0;
       $60 = ($59|0)==(0);
       if (!($60)) {
        $61 = HEAP32[65592>>2]|0;
        HEAP32[$vararg_buffer>>2] = $61;
        _GC_log_printf(66000,$vararg_buffer);
       }
       $62 = (($GC_mark_stack_top_reg$01) + -4088|0);
       $GC_mark_stack_top_reg$1 = $62;
      }
      HEAP32[$GC_mark_stack_top_reg$1>>2] = $p$03;
      $63 = (($GC_mark_stack_top_reg$1) + 4|0);
      HEAP32[$63>>2] = $55;
      $GC_mark_stack_top_reg$2 = $GC_mark_stack_top_reg$1;
     }
    }
    $64 = (($p$03) + ($1)|0);
    $65 = (($bit_no$02) + ($14))|0;
    $66 = ($64>>>0)>($lim$0>>>0);
    if ($66) {
     $GC_mark_stack_top_reg$0$lcssa = $GC_mark_stack_top_reg$2;
     break;
    } else {
     $GC_mark_stack_top_reg$01 = $GC_mark_stack_top_reg$2;$bit_no$02 = $65;$p$03 = $64;
    }
   }
  }
  HEAP32[((56 + 68|0))>>2] = $GC_mark_stack_top_reg$0$lcssa;
  STACKTOP = sp;return;
 }
}
function _GC_print_static_roots() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $i$01$i = 0, $size$0$lcssa$i = 0, $size$02$i = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer6 = sp;
 $0 = (0)>(0);
 if ($0) {
  $i$01 = 0;
  while(1) {
   $1 = ((56 + ($i$01<<4)|0) + 20840|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = ((56 + ($i$01<<4)|0) + 20844|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ((56 + ($i$01<<4)|0) + 20852|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)!=(0);
   $8 = $7 ? 66168 : 63536;
   HEAP32[$vararg_buffer6>>2] = $2;
   $vararg_ptr1 = (($vararg_buffer6) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $4;
   $vararg_ptr2 = (($vararg_buffer6) + 8|0);
   HEAP32[$vararg_ptr2>>2] = $8;
   _GC_printf(66144,$vararg_buffer6);
   $9 = (($i$01) + 1)|0;
   $10 = ($9|0)<(0);
   if ($10) {
    $i$01 = $9;
   } else {
    break;
   }
  }
 }
 HEAP32[$vararg_buffer6>>2] = 0;
 _GC_printf(66184,$vararg_buffer6);
 $11 = (0)>(0);
 if ($11) {
  $i$01$i = 0;$size$02$i = 0;
  while(1) {
   $12 = ((56 + ($i$01$i<<4)|0) + 20844|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((56 + ($i$01$i<<4)|0) + 20840|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = $13;
   $17 = $15;
   $18 = (($16) + ($size$02$i))|0;
   $19 = (($18) - ($17))|0;
   $20 = (($i$01$i) + 1)|0;
   $exitcond = ($20|0)==(0);
   if ($exitcond) {
    $size$0$lcssa$i = $19;
    break;
   } else {
    $i$01$i = $20;$size$02$i = $19;
   }
  }
 } else {
  $size$0$lcssa$i = 0;
 }
 $21 = ($size$0$lcssa$i|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer6>>2] = $size$0$lcssa$i;
 _GC_err_printf(66208,$vararg_buffer6);
 STACKTOP = sp;return;
}
function _GC_exclude_static_roots_inner($start,$finish) {
 $start = $start|0;
 $finish = $finish|0;
 var $$high$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $high$02$i = 0, $i$01 = 0, $low$0$$i = 0, $low$0$lcssa$i = 0, $low$01$i = 0, $next_index$0 = 0, $next_index$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[66256>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $next_index$02 = 0;
 } else {
  $2 = (($0) + -1)|0;
  $3 = ($2|0)==(0);
  if ($3) {
   $low$0$lcssa$i = 0;
  } else {
   $high$02$i = $2;$low$01$i = 0;
   while(1) {
    $4 = (($low$01$i) + ($high$02$i))|0;
    $5 = $4 >>> 1;
    $6 = ((56 + ($5<<3)|0) + 53868|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)>($start>>>0);
    $9 = (($5) + 1)|0;
    $low$0$$i = $8 ? $low$01$i : $9;
    $$high$0$i = $8 ? $5 : $high$02$i;
    $10 = ($$high$0$i>>>0)>($low$0$$i>>>0);
    if ($10) {
     $high$02$i = $$high$0$i;$low$01$i = $low$0$$i;
    } else {
     $low$0$lcssa$i = $low$0$$i;
     break;
    }
   }
  }
  $11 = ((56 + ($low$0$lcssa$i<<3)|0) + 53868|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12>>>0)>($start>>>0);
  do {
   if ($13) {
    $14 = ((56 + ($low$0$lcssa$i<<3)|0) + 53864|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15>>>0)<($finish>>>0);
    if ($16) {
     _GC_default_on_abort(66264);
     _abort();
     // unreachable;
    }
    $17 = ($15|0)==($finish|0);
    if ($17) {
     HEAP32[$14>>2] = $start;
     STACKTOP = sp;return;
    } else {
     $18 = $14;
     $19 = (($18) - (((56 + 53864|0))))|0;
     $20 = $19 >> 3;
     $21 = ($0>>>0)>($20>>>0);
     if ($21) {
      $i$01 = $0;
     } else {
      $next_index$0 = $20;
      break;
     }
     while(1) {
      $22 = ((56 + ($i$01<<3)|0) + 53864|0);
      $23 = (($i$01) + -1)|0;
      $24 = ((56 + ($23<<3)|0) + 53864|0);
      $25 = $24;
      $26 = $25;
      $27 = HEAP32[$26>>2]|0;
      $28 = (($25) + 4)|0;
      $29 = $28;
      $30 = HEAP32[$29>>2]|0;
      $31 = $22;
      $32 = $31;
      HEAP32[$32>>2] = $27;
      $33 = (($31) + 4)|0;
      $34 = $33;
      HEAP32[$34>>2] = $30;
      $35 = ($23>>>0)>($20>>>0);
      if ($35) {
       $i$01 = $23;
      } else {
       $next_index$0 = $20;
       break;
      }
     }
    }
   } else {
    $next_index$0 = $0;
   }
  } while(0);
  $36 = ($0|0)==(512);
  if ($36) {
   _GC_default_on_abort(66296);
   _abort();
   // unreachable;
  } else {
   $next_index$02 = $next_index$0;
  }
 }
 $37 = ((56 + ($next_index$02<<3)|0) + 53864|0);
 HEAP32[$37>>2] = $start;
 $38 = ((56 + ($next_index$02<<3)|0) + 53868|0);
 HEAP32[$38>>2] = $finish;
 $39 = (($0) + 1)|0;
 HEAP32[66256>>2] = $39;
 STACKTOP = sp;return;
}
function _GC_push_conditional_with_exclusions($bottom,$top,$all) {
 $bottom = $bottom|0;
 $top = $top|0;
 $all = $all|0;
 var $$04 = 0, $$high$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $high$02$i = 0, $low$0$$i = 0, $low$0$lcssa$i = 0, $low$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bottom>>>0)<($top>>>0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = ($all|0)==(0);
 $$04 = $bottom;
 L4: while(1) {
  $2 = HEAP32[66256>>2]|0;
  $3 = (($2) + -1)|0;
  $4 = ($3|0)==(0);
  if ($4) {
   $low$0$lcssa$i = 0;
  } else {
   $high$02$i = $3;$low$01$i = 0;
   while(1) {
    $5 = (($low$01$i) + ($high$02$i))|0;
    $6 = $5 >>> 1;
    $7 = ((56 + ($6<<3)|0) + 53868|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8>>>0)>($$04>>>0);
    $10 = (($6) + 1)|0;
    $low$0$$i = $9 ? $low$01$i : $10;
    $$high$0$i = $9 ? $6 : $high$02$i;
    $11 = ($$high$0$i>>>0)>($low$0$$i>>>0);
    if ($11) {
     $high$02$i = $$high$0$i;$low$01$i = $low$0$$i;
    } else {
     $low$0$lcssa$i = $low$0$$i;
     break;
    }
   }
  }
  $12 = ((56 + ($low$0$lcssa$i<<3)|0) + 53868|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13>>>0)>($$04>>>0);
  if (!($14)) {
   label = 7;
   break;
  }
  $15 = ((56 + ($low$0$lcssa$i<<3)|0) + 53864|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16>>>0)<($top>>>0);
  if (!($17)) {
   label = 7;
   break;
  }
  $32 = ($16>>>0)>($$04>>>0);
  do {
   if ($32) {
    if ($1) {
     _GC_push_selected($$04,$16,2985);
     break;
    }
    $33 = $$04;
    $34 = (($33) + 3)|0;
    $35 = $34 & -4;
    $36 = $35;
    $37 = $16;
    $38 = $37 & -4;
    $39 = ($35>>>0)<($38>>>0);
    if ($39) {
     $40 = HEAP32[((56 + 68|0))>>2]|0;
     $41 = (($40) + 8|0);
     HEAP32[((56 + 68|0))>>2] = $41;
     $42 = HEAP32[((56 + 64|0))>>2]|0;
     $43 = ($41>>>0)<($42>>>0);
     if (!($43)) {
      label = 18;
      break L4;
     }
     $44 = (($38) - ($35))|0;
     HEAP32[$41>>2] = $36;
     $45 = HEAP32[((56 + 68|0))>>2]|0;
     $46 = (($45) + 4|0);
     HEAP32[$46>>2] = $44;
    }
   }
  } while(0);
  $47 = HEAP32[$12>>2]|0;
  $48 = ($47>>>0)<($top>>>0);
  if ($48) {
   $$04 = $47;
  } else {
   label = 21;
   break;
  }
 }
 if ((label|0) == 7) {
  if ($1) {
   _GC_push_selected($$04,$top,2985);
   STACKTOP = sp;return;
  }
  $18 = $$04;
  $19 = (($18) + 3)|0;
  $20 = $19 & -4;
  $21 = $20;
  $22 = $top;
  $23 = $22 & -4;
  $24 = ($20>>>0)<($23>>>0);
  if (!($24)) {
   STACKTOP = sp;return;
  }
  $25 = HEAP32[((56 + 68|0))>>2]|0;
  $26 = (($25) + 8|0);
  HEAP32[((56 + 68|0))>>2] = $26;
  $27 = HEAP32[((56 + 64|0))>>2]|0;
  $28 = ($26>>>0)<($27>>>0);
  if (!($28)) {
   _GC_default_on_abort(66080);
   _abort();
   // unreachable;
  }
  $29 = (($23) - ($20))|0;
  HEAP32[$26>>2] = $21;
  $30 = HEAP32[((56 + 68|0))>>2]|0;
  $31 = (($30) + 4|0);
  HEAP32[$31>>2] = $29;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 18) {
  _GC_default_on_abort(66080);
  _abort();
  // unreachable;
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function _GC_reclaim_check($hbp,$hhdr,$sz) {
 $hbp = $hbp|0;
 $hhdr = $hhdr|0;
 $sz = $sz|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $bit_no$03 = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$sum = (4096 - ($sz))|0;
 $0 = (($hbp) + ($$sum)|0);
 $1 = ($$sum|0)<(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = $sz >>> 3;
 $bit_no$03 = 0;$p$01 = $hbp;
 while(1) {
  $3 = $bit_no$03 >>> 5;
  $4 = ((($hhdr) + ($3<<2)|0) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $bit_no$03 & 31;
  $7 = 1 << $6;
  $8 = $5 & $7;
  $9 = ($8|0)==(0);
  do {
   if ($9) {
    $10 = HEAP32[65312>>2]|0;
    $11 = ($10|0)==(0);
    if (!($11)) {
     $12 = (_GC_check_leaked($p$01)|0);
     $13 = ($12|0)==(0);
     if ($13) {
      break;
     }
    }
    HEAP32[62768>>2] = 1;
    $14 = HEAP32[66480>>2]|0;
    $15 = ($14>>>0)<(40);
    if ($15) {
     $16 = (($14) + 1)|0;
     HEAP32[66480>>2] = $16;
     $17 = (66320 + ($14<<2)|0);
     HEAP32[$17>>2] = $p$01;
     $18 = $p$01;
     $19 = $18 >>> 12;
     $20 = $19 & 1023;
     $21 = $18 >>> 22;
     $22 = ((56 + ($21<<2)|0) + 57964|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($23) + ($20<<2)|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = $18 >>> 3;
     $27 = $18 >>> 8;
     $28 = $27 & 15;
     $29 = ((($25) + ($28<<2)|0) + 36|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = $26 & 31;
     $32 = 1 << $31;
     $33 = $30 & $32;
     $34 = ($33|0)==(0);
     if ($34) {
      $35 = $30 | $32;
      HEAP32[$29>>2] = $35;
      $36 = (($25) + 32|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($37) + 1)|0;
      HEAP32[$36>>2] = $38;
     }
    }
   }
  } while(0);
  $39 = (($p$01) + ($sz)|0);
  $40 = (($bit_no$03) + ($2))|0;
  $41 = ($39>>>0)>($0>>>0);
  if ($41) {
   break;
  } else {
   $bit_no$03 = $40;$p$01 = $39;
  }
 }
 STACKTOP = sp;return;
}
function _GC_reclaim_block($hbp,$report_if_found) {
 $hbp = $hbp|0;
 $report_if_found = $report_if_found|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $hbp;
 $1 = $0 >>> 12;
 $2 = $1 & 1023;
 $3 = $0 >>> 22;
 $4 = ((56 + ($3<<2)|0) + 57964|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 12|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = ($9>>>0)>(2048);
 if (!($13)) {
  $57 = (($7) + 32|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($report_if_found|0)==(0);
  do {
   if ($59) {
    $63 = ($58|0)==(0);
    if ($63) {
     $64 = HEAP32[64464>>2]|0;
     $65 = (($64) + 4096)|0;
     HEAP32[64464>>2] = $65;
     _GC_freehblk($hbp);
     break;
    }
    $66 = HEAP32[63736>>2]|0;
    $67 = ($66|0)==(0);
    if ($67) {
     $68 = (4096 / ($9>>>0))&-1;
     $69 = ($68*7)|0;
     $70 = $69 >>> 3;
     $71 = ($58>>>0)>($70>>>0);
     if ($71) {
      break;
     }
    }
    $72 = $9 >>> 3;
    $73 = ((62448 + (($12*20)|0)|0) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($74) + ($72<<2)|0);
    $76 = HEAP32[$75>>2]|0;
    HEAP32[$7>>2] = $76;
    HEAP32[$75>>2] = $hbp;
   } else {
    $60 = HEAP32[63912>>2]|0;
    $61 = $60&65535;
    $62 = (($7) + 14|0);
    HEAP16[$62>>1] = $61;
    _GC_reclaim_check($hbp,$7,$9);
   }
  } while(0);
  $77 = (($7) + 20|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0);
  $80 = HEAP32[$57>>2]|0;
  $81 = Math_imul($80, $9)|0;
  if ($79) {
   $84 = HEAP32[((56 + 3416|0))>>2]|0;
   $85 = (($84) + ($81))|0;
   HEAP32[((56 + 3416|0))>>2] = $85;
   STACKTOP = sp;return;
  } else {
   $82 = HEAP32[((56 + 3412|0))>>2]|0;
   $83 = (($82) + ($81))|0;
   HEAP32[((56 + 3412|0))>>2] = $83;
   STACKTOP = sp;return;
  }
 }
 $14 = (($7) + 36|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 1;
 $17 = ($16|0)==(0);
 if (!($17)) {
  $50 = (($7) + 20|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0);
  if ($52) {
   $55 = HEAP32[((56 + 3416|0))>>2]|0;
   $56 = (($55) + ($9))|0;
   HEAP32[((56 + 3416|0))>>2] = $56;
   STACKTOP = sp;return;
  } else {
   $53 = HEAP32[((56 + 3412|0))>>2]|0;
   $54 = (($53) + ($9))|0;
   HEAP32[((56 + 3412|0))>>2] = $54;
   STACKTOP = sp;return;
  }
 }
 $18 = ($report_if_found|0)==(0);
 if ($18) {
  $43 = (($9) + 4095)|0;
  $44 = ($43>>>0)>(8191);
  if ($44) {
   $45 = $43 & -4096;
   $46 = HEAP32[((56 + 20|0))>>2]|0;
   $47 = (($46) - ($45))|0;
   HEAP32[((56 + 20|0))>>2] = $47;
  }
  $48 = HEAP32[64464>>2]|0;
  $49 = (($48) + ($9))|0;
  HEAP32[64464>>2] = $49;
  _GC_freehblk($hbp);
  STACKTOP = sp;return;
 }
 $19 = HEAP32[65312>>2]|0;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = (_GC_check_leaked($hbp)|0);
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[62768>>2] = 1;
 $23 = HEAP32[66480>>2]|0;
 $24 = ($23>>>0)<(40);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 $25 = (($23) + 1)|0;
 HEAP32[66480>>2] = $25;
 $26 = (66320 + ($23<<2)|0);
 HEAP32[$26>>2] = $hbp;
 $27 = HEAP32[$4>>2]|0;
 $28 = (($27) + ($2<<2)|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = $0 >>> 3;
 $31 = $0 >>> 8;
 $32 = $31 & 15;
 $33 = ((($29) + ($32<<2)|0) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $30 & 31;
 $36 = 1 << $35;
 $37 = $34 & $36;
 $38 = ($37|0)==(0);
 if (!($38)) {
  STACKTOP = sp;return;
 }
 $39 = $34 | $36;
 HEAP32[$33>>2] = $39;
 $40 = (($29) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 STACKTOP = sp;return;
}
function _GC_print_block_list() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$0$i8 = 0, $index_p$0$i = 0, $index_p$02$i = 0, $index_p$03$i = 0, $j$0$be$i = 0, $j$01$i = 0, $m$0$i10 = 0, $m$0$i26 = 0, $result$0$$i = 0, $result$0$$i4 = 0, $result$0$i1$lcssa = 0, $result$0$i111 = 0, $result$0$i3$lcssa = 0, $result$0$i37 = 0;
 var $result$0$i9 = 0, $vararg_buffer11 = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer11 = sp;
 _GC_printf(66624,$vararg_buffer11);
 $index_p$02$i = HEAP32[62304>>2]|0;
 $0 = ($index_p$02$i|0)==(0|0);
 if ($0) {
  $57 = 0;$58 = 0;
  HEAP32[$vararg_buffer11>>2] = $57;
  $vararg_ptr14 = (($vararg_buffer11) + 4|0);
  HEAP32[$vararg_ptr14>>2] = $58;
  _GC_printf(66688,$vararg_buffer11);
  STACKTOP = sp;return;
 } else {
  $59 = 0;$60 = 0;$index_p$03$i = $index_p$02$i;
 }
 while(1) {
  $1 = (($index_p$03$i) + 4104|0);
  $47 = $59;$49 = $60;$j$01$i = 1023;
  while(1) {
   $2 = (($index_p$03$i) + ($j$01$i<<2)|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = $3;
   $5 = ($3>>>0)<((4096)>>>0);
   do {
    if ($5) {
     $51 = ($3|0)==(0|0);
     if ($51) {
      $52 = (($j$01$i) + -1)|0;
      $63 = $47;$64 = $49;$j$0$be$i = $52;
      break;
     } else {
      $54 = (($j$01$i) - ($4))|0;
      $63 = $47;$64 = $49;$j$0$be$i = $54;
      break;
     }
    } else {
     $6 = (($3) + 13|0);
     $7 = HEAP8[$6>>0]|0;
     $8 = $7 & 4;
     $9 = ($8<<24>>24)==(0);
     if ($9) {
      $10 = HEAP32[$1>>2]|0;
      $11 = $10 << 10;
      $12 = (($11) + ($j$01$i))|0;
      $13 = $12 & 1023;
      $14 = $12 >>> 10;
      $15 = $14 & 1023;
      $16 = ((56 + ($15<<2)|0) + 57964|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($17) + ($13<<2)|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = (($19) + 16|0);
      $21 = HEAP32[$20>>2]|0;
      $i$0$i8 = 0;$result$0$i9 = 0;
      while(1) {
       $22 = ((($19) + ($i$0$i8<<2)|0) + 36|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = ($23|0)==(0);
       if ($24) {
        $result$0$i3$lcssa = 0;
       } else {
        $m$0$i26 = $23;$result$0$i37 = 0;
        while(1) {
         $25 = $m$0$i26 & 1;
         $result$0$$i4 = (($result$0$i37) + ($25))|0;
         $26 = $m$0$i26 >>> 1;
         $27 = ($26|0)==(0);
         if ($27) {
          $result$0$i3$lcssa = $result$0$$i4;
          break;
         } else {
          $m$0$i26 = $26;$result$0$i37 = $result$0$$i4;
         }
        }
       }
       $28 = (($result$0$i3$lcssa) + ($result$0$i9))|0;
       $29 = (($i$0$i8) + 1)|0;
       $exitcond = ($29|0)==(16);
       if ($exitcond) {
        break;
       } else {
        $i$0$i8 = $29;$result$0$i9 = $28;
       }
      }
      $30 = (($19) + 100|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==(0);
      if ($32) {
       $result$0$i1$lcssa = 0;
      } else {
       $m$0$i10 = $31;$result$0$i111 = 0;
       while(1) {
        $33 = $m$0$i10 & 1;
        $result$0$$i = (($result$0$i111) + ($33))|0;
        $34 = $m$0$i10 >>> 1;
        $35 = ($34|0)==(0);
        if ($35) {
         $result$0$i1$lcssa = $result$0$$i;
         break;
        } else {
         $m$0$i10 = $34;$result$0$i111 = $result$0$$i;
        }
       }
      }
      $36 = (($28) + -1)|0;
      $37 = (($36) + ($result$0$i1$lcssa))|0;
      $38 = (($19) + 32|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = ($39|0)==($37|0);
      $41 = (($19) + 12|0);
      $42 = HEAP8[$41>>0]|0;
      $43 = $42&255;
      if ($40) {
       HEAP32[$vararg_buffer11>>2] = $43;
       $vararg_ptr9 = (($vararg_buffer11) + 4|0);
       HEAP32[$vararg_ptr9>>2] = $21;
       $vararg_ptr10 = (($vararg_buffer11) + 8|0);
       HEAP32[$vararg_ptr10>>2] = $37;
       _GC_printf(66608,$vararg_buffer11);
      } else {
       HEAP32[$vararg_buffer11>>2] = $43;
       $vararg_ptr3 = (($vararg_buffer11) + 4|0);
       HEAP32[$vararg_ptr3>>2] = $21;
       $vararg_ptr4 = (($vararg_buffer11) + 8|0);
       HEAP32[$vararg_ptr4>>2] = $39;
       $vararg_ptr5 = (($vararg_buffer11) + 12|0);
       HEAP32[$vararg_ptr5>>2] = $37;
       _GC_printf(66592,$vararg_buffer11);
      }
      $44 = (($21) + 4095)|0;
      $45 = $44 & -4096;
      $46 = (($47) + ($45))|0;
      $48 = (($49) + 1)|0;
      $61 = $46;$62 = $48;
     } else {
      $61 = $47;$62 = $49;
     }
     $50 = (($j$01$i) + -1)|0;
     $63 = $61;$64 = $62;$j$0$be$i = $50;
    }
   } while(0);
   $53 = ($j$0$be$i|0)>(-1);
   if ($53) {
    $47 = $63;$49 = $64;$j$01$i = $j$0$be$i;
   } else {
    break;
   }
  }
  $55 = (($index_p$03$i) + 4096|0);
  $index_p$0$i = HEAP32[$55>>2]|0;
  $56 = ($index_p$0$i|0)==(0|0);
  if ($56) {
   $57 = $64;$58 = $63;
   break;
  } else {
   $59 = $63;$60 = $64;$index_p$03$i = $index_p$0$i;
  }
 }
 HEAP32[$vararg_buffer11>>2] = $57;
 $vararg_ptr14 = (($vararg_buffer11) + 4|0);
 HEAP32[$vararg_ptr14>>2] = $58;
 _GC_printf(66688,$vararg_buffer11);
 STACKTOP = sp;return;
}
function _GC_default_oom_fn($bytes_requested) {
 $bytes_requested = $bytes_requested|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function _GC_get_heap_size() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[56>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function _GC_get_free_bytes() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((56 + 16|0))>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function _GC_exit_check() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[63736>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  _GC_gcollect();
 }
 STACKTOP = sp;return;
}
function _GC_default_warn_proc($msg,$arg) {
 $msg = $msg|0;
 $arg = $arg|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $arg;
 _GC_err_printf($msg,$vararg_buffer);
 STACKTOP = sp;return;
}
function _GC_default_on_abort($msg) {
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bytes_written$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[63736>>2] = 0;
 $0 = ($msg|0)==(0|0);
 L1: do {
  if (!($0)) {
   $1 = (_strlen(($msg|0))|0);
   $2 = ($1|0)==(0);
   if ($2) {
    $10 = 2;
   } else {
    $bytes_written$01$i = 0;
    while(1) {
     $5 = (($msg) + ($bytes_written$01$i)|0);
     $6 = (($1) - ($bytes_written$01$i))|0;
     $7 = (_write(2,($5|0),($6|0))|0);
     $8 = ($7|0)==(-1);
     $4 = (($7) + ($bytes_written$01$i))|0;
     if ($8) {
      break L1;
     }
     $3 = ($4>>>0)<($1>>>0);
     if ($3) {
      $bytes_written$01$i = $4;
     } else {
      break;
     }
    }
    $9 = ($4|0)>(-1);
    if (!($9)) {
     break;
    }
    $10 = 2;
   }
   while(1) {
    $11 = (_write(($10|0),(67640|0),1)|0);
    $12 = ($11|0)==(0);
    if (!($12)) {
     break;
    }
   }
  }
 } while(0);
 $13 = (_getenv((67648|0))|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 } else {
  while(1) {
  }
 }
}
function _GC_enable() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[62440>>2]|0;
 $1 = (($0) + -1)|0;
 HEAP32[62440>>2] = $1;
 STACKTOP = sp;return;
}
function _GC_disable() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[62440>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[62440>>2] = $1;
 STACKTOP = sp;return;
}
function _GC_call_with_alloc_lock($fn,$client_data) {
 $fn = $fn|0;
 $client_data = $client_data|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (FUNCTION_TABLE_ii[$fn & 4095]($client_data)|0);
 STACKTOP = sp;return ($0|0);
}
function _GC_get_gc_no() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[63912>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function _GC_set_no_dls($value) {
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[66136>>2] = $value;
 STACKTOP = sp;return;
}
function _il2cpp_init($domain_name) {
 $domain_name = $domain_name|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm7Runtime4InitEPKc($domain_name);
 STACKTOP = sp;return;
}
function _il2cpp_set_commandline_arguments($argc,$argv,$basedir) {
 $argc = $argc|0;
 $argv = $argv|0;
 $basedir = $basedir|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm11Environment11SetMainArgsEPPci($argv,$argc);
 STACKTOP = sp;return;
}
function _il2cpp_get_corlib() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_add_internal_call($name,$method) {
 $name = $name|0;
 $method = $method|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE($name,$method);
 STACKTOP = sp;return;
}
function _il2cpp_array_class_get($element_class,$rank) {
 $element_class = $element_class|0;
 $rank = $rank|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class13GetArrayClassEP8TypeInfoj($element_class,$rank)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_array_length($array) {
 $array = $array|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($array)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_array_new($elementTypeInfo,$length) {
 $elementTypeInfo = $elementTypeInfo|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($elementTypeInfo,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_array_new_specific($arrayTypeInfo,$length) {
 $arrayTypeInfo = $arrayTypeInfo|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayTypeInfo,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_bounded_array_class_get($element_class,$rank,$bounded) {
 $element_class = $element_class|0;
 $rank = $rank|0;
 $bounded = $bounded|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class20GetBoundedArrayClassEP8TypeInfojb($element_class,$rank,$bounded)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_array_element_size($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Array14GetElementSizeEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_assembly_get_image($assembly) {
 $assembly = $assembly|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm8Assembly8GetImageEPK14Il2CppAssembly($assembly)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_enum_basetype($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_from_system_type($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class14FromSystemTypeEP20Il2CppReflectionType($type)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_is_generic($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class9IsGenericEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_is_subclass_of($klass,$klassc,$check_interfaces) {
 $klass = $klass|0;
 $klassc = $klassc|0;
 $check_interfaces = $check_interfaces|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class12IsSubclassOfEPK8TypeInfoS4_b($klass,$klassc,$check_interfaces)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_from_il2cpp_type($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($type)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_from_name($image,$namespaze,$name) {
 $image = $image|0;
 $namespaze = $namespaze|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($image,$namespaze,$name)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_fields($klass,$iter) {
 $klass = $klass|0;
 $iter = $iter|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($klass,$iter)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_field_from_name($klass,$name) {
 $klass = $klass|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class16GetFieldFromNameEPK8TypeInfoPKc($klass,$name)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_methods($klass,$iter) {
 $klass = $klass|0;
 $iter = $iter|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class10GetMethodsEPK8TypeInfoPPv($klass,$iter)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_name($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class7GetNameEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_namespace($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class12GetNamespaceEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_parent($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class9GetParentEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_instance_size($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class15GetInstanceSizeEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_is_valuetype($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class11IsValuetypeEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_flags($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class8GetFlagsEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_is_abstract($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class10IsAbstractEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_is_interface($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class11IsInterfaceEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_array_element_size($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class19GetArrayElementSizeEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_from_type($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($type)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_type($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class7GetTypeEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_has_attribute($klass,$attr_class) {
 $klass = $klass|0;
 $attr_class = $attr_class|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class12HasAttributeEP8TypeInfoS3_($klass,$attr_class)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_is_enum($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class6IsEnumEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_image($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class8GetImageEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_class_get_assemblyname($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class15GetAssemblyNameEPK8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_domain_get() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Domain10GetCurrentEv()|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_domain_assembly_open($domain,$name) {
 $domain = $domain|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm8Assembly4LoadEPKc($name)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_raise_exception($exc) {
 $exc = $exc|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($exc);
 STACKTOP = sp;return;
}
function _il2cpp_exception_from_name_msg($image,$name_space,$name,$msg) {
 $image = $image|0;
 $name_space = $name_space|0;
 $name = $name|0;
 $msg = $msg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception11FromNameMsgEPK11Il2CppImagePKcS6_S6_($image,$name_space,$name,$msg)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_field_get_name($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Field7GetNameEP9FieldInfo($field)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_field_get_flags($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Field8GetFlagsEP9FieldInfo($field)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_field_get_parent($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Field9GetParentEP9FieldInfo($field)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_field_get_offset($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Field9GetOffsetEP9FieldInfo($field)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_field_get_type($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Field7GetTypeEP9FieldInfo($field)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_field_has_attribute($field,$attr_class) {
 $field = $field|0;
 $attr_class = $attr_class|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Field12HasAttributeEP9FieldInfoP8TypeInfo($field,$attr_class)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_gchandle_new($obj,$pinned) {
 $obj = $obj|0;
 $pinned = $pinned|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2gc8GCHandle3NewEP12Il2CppObjectb($obj,$pinned)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_gchandle_get_target($gchandle) {
 $gchandle = $gchandle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2gc8GCHandle9GetTargetEj($gchandle)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_gchandle_free($gchandle) {
 $gchandle = $gchandle|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2gc8GCHandle4FreeEj($gchandle);
 STACKTOP = sp;return;
}
function _il2cpp_unity_liveness_calculation_begin($filter,$max_object_count,$callback,$userdata) {
 $filter = $filter|0;
 $max_object_count = $max_object_count|0;
 $callback = $callback|0;
 $userdata = $userdata|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm8Liveness5BeginEP8TypeInfoiPFvPPviS4_ES4_($filter,$max_object_count,$callback,$userdata)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_unity_liveness_calculation_end($state) {
 $state = $state|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Liveness3EndEPv($state);
 STACKTOP = sp;return;
}
function _il2cpp_unity_liveness_calculation_from_root($root,$state) {
 $root = $root|0;
 $state = $state|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Liveness8FromRootEP12Il2CppObjectPv($root,$state);
 STACKTOP = sp;return;
}
function _il2cpp_unity_liveness_calculation_from_statics($state) {
 $state = $state|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Liveness11FromStaticsEPv($state);
 STACKTOP = sp;return;
}
function _il2cpp_method_get_return_type($method) {
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Method13GetReturnTypeEP10MethodInfo($method)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_method_get_object($method,$refclass) {
 $method = $method|0;
 $refclass = $refclass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo($method,$refclass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_method_get_name($method) {
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Method7GetNameEP10MethodInfo($method)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_method_is_instance($method) {
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Method10IsInstanceEP10MethodInfo($method)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_method_get_param_count($method) {
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Method13GetParamCountEP10MethodInfo($method)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_method_get_param($method,$index) {
 $method = $method|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Method8GetParamEP10MethodInfoj($method,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_method_has_attribute($method,$attr_class) {
 $method = $method|0;
 $attr_class = $attr_class|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Method12HasAttributeEP10MethodInfoP8TypeInfo($method,$attr_class)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_object_get_class($obj) {
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_object_get_virtual_method($obj,$method) {
 $obj = $obj|0;
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Object16GetVirtualMethodEP12Il2CppObjectP10MethodInfo($obj,$method)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_object_new($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_runtime_invoke_convert_args($method,$obj,$params,$paramCount,$exc) {
 $method = $method|0;
 $obj = $obj|0;
 $params = $params|0;
 $paramCount = $paramCount|0;
 $exc = $exc|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm7Runtime17InvokeConvertArgsEP10MethodInfoPvPP12Il2CppObjectiS7_($method,$obj,$params,$paramCount,$exc)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_runtime_invoke($method,$obj,$params,$exc) {
 $method = $method|0;
 $obj = $obj|0;
 $params = $params|0;
 $exc = $exc|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm7Runtime6InvokeEP10MethodInfoPvPS4_PP12Il2CppObject($method,$obj,$params,$exc)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_runtime_object_init_exception($obj,$exc) {
 $obj = $obj|0;
 $exc = $exc|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm7Runtime19ObjectInitExceptionEP12Il2CppObjectPS3_($obj,$exc);
 STACKTOP = sp;return;
}
function _il2cpp_runtime_unhandled_exception_policy_set($value) {
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm7Runtime27SetUnhandledExceptionPolicyE37Il2CppRuntimeUnhandledExceptionPolicy($value);
 STACKTOP = sp;return;
}
function _il2cpp_string_length($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($str)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_string_chars($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($str)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_string_new($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String3NewEPKc($str)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_string_new_wrapper($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String10NewWrapperEPKc($str)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_string_intern($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String6InternEP12Il2CppString($str)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_string_is_interned($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String10IsInternedEP12Il2CppString($str)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_type_get_object($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($type)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_type_get_type($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm4Type7GetTypeEPK10Il2CppType($type)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_type_get_class_or_element_class($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm4Type22GetClassOrElementClassEPK10Il2CppType($type)|0);
 STACKTOP = sp;return ($0|0);
}
function _il2cpp_type_get_name($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm4Type7GetNameEPK10Il2CppType20Il2CppTypeNameFormat($type,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($__os,$__str) {
 $__os = $__os|0;
 $__str = $__str|0;
 var $$0 = 0, $$byval_copy = 0, $$phi$trans$insert$phi$trans$insert = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre10 = 0, $$pre10$pre = 0, $$sum = 0, $$sum$i = 0, $$sum$i$i = 0, $$sum1$i = 0, $$sum7 = 0, $$sum8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $__s = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $__s = sp;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 HEAP8[$__s>>0] = 0;
 $2 = (($__s) + 4|0);
 HEAP32[$2>>2] = $__os;
 $3 = HEAP32[$__os>>2]|0;
 $4 = (($3) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $$sum$i = (($5) + 16)|0;
 $6 = (($__os) + ($$sum$i)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 do {
  if ($8) {
   $$sum1$i = (($5) + 72)|0;
   $9 = (($__os) + ($$sum1$i)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$pre10 = $5;
   } else {
    __THREW__ = 0;
    (invoke_ii(2986,($10|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 19;
     break;
    }
    $$pre$pre = HEAP32[$__os>>2]|0;
    $$phi$trans$insert$phi$trans$insert = (($$pre$pre) + -12|0);
    $$pre10$pre = HEAP32[$$phi$trans$insert$phi$trans$insert>>2]|0;
    $$pre10 = $$pre10$pre;
   }
   HEAP8[$__s>>0] = 1;
   $14 = (_strlen(($__str|0))|0);
   $$sum$i$i = (($$pre10) + 24)|0;
   $15 = (($__os) + ($$sum$i$i)|0);
   $16 = HEAP32[$15>>2]|0;
   HEAP32[$0>>2] = $16;
   $$sum = (($$pre10) + 4)|0;
   $17 = (($__os) + ($$sum)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = $18 & 176;
   $20 = ($19|0)==(32);
   if ($20) {
    $21 = (($__str) + ($14)|0);
    $49 = $21;
   } else {
    $49 = $__str;
   }
   $22 = (($__os) + ($$pre10)|0);
   $$sum7 = (($$pre10) + 76)|0;
   $23 = (($__os) + ($$sum7)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(-1);
   do {
    if ($25) {
     __THREW__ = 0;
     invoke_vii(2475,($$byval_copy|0),($22|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 20;
     } else {
      __THREW__ = 0;
      $28 = (invoke_iii(2228,($$byval_copy|0),(3093336|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = HEAP32[$28>>2]|0;
       $32 = (($31) + 28|0);
       $33 = HEAP32[$32>>2]|0;
       __THREW__ = 0;
       $34 = (invoke_iii($33|0,($28|0),32)|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        __THREW__ = 0;
        invoke_vi(3299,($$byval_copy|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 20;
         break;
        }
        $45 = $34 << 24 >> 24;
        HEAP32[$23>>2] = $45;
        $$pre$phiZ2D = $22;$47 = $45;
        label = 16;
        break;
       }
      }
      $37 = ___cxa_find_matching_catch(0|0)|0;
      $38 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3299,($$byval_copy|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       $41 = ___cxa_find_matching_catch(0|0)|0;
       $42 = tempRet0;
       ___clang_call_terminate($41);
       // unreachable;
      } else {
       $eh$lpad$body$indexZ2D = $37;
      }
     }
    } else {
     $$pre$phiZ2D = $22;$47 = $24;
     label = 16;
    }
   } while(0);
   if ((label|0) == 16) {
    $46 = $47&255;
    $48 = (($__str) + ($14)|0);
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viiiiiii(60,($1|0),($$byval_copy|0),($__str|0),($49|0),($48|0),($$pre$phiZ2D|0),($46|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 20;
    } else {
     $52 = HEAP32[$1>>2]|0;
     $53 = ($52|0)==(0|0);
     if (!($53)) {
      label = 22;
      break;
     }
     $54 = HEAP32[$__os>>2]|0;
     $55 = (($54) + -12|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($__os) + ($56)|0);
     $$sum8 = (($56) + 16)|0;
     $58 = (($__os) + ($$sum8)|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = $59 | 5;
     __THREW__ = 0;
     invoke_vii(2476,($57|0),($60|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 20;
     } else {
      label = 22;
      break;
     }
    }
   }
   if ((label|0) == 20) {
    $65 = ___cxa_find_matching_catch(0|0)|0;
    $66 = tempRet0;
    $eh$lpad$body$indexZ2D = $65;
   }
   __THREW__ = 0;
   invoke_vi(3300,($__s|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $81 = ___cxa_find_matching_catch(0|0)|0;
    $82 = tempRet0;
    ___clang_call_terminate($81);
    // unreachable;
   } else {
    $$0 = $eh$lpad$body$indexZ2D;
   }
  } else {
   label = 22;
  }
 } while(0);
 if ((label|0) == 22) {
  __THREW__ = 0;
  invoke_vi(3300,($__s|0));
  $69 = __THREW__; __THREW__ = 0;
  $70 = $69&1;
  if ($70) {
   label = 19;
  } else {
   STACKTOP = sp;return ($__os|0);
  }
 }
 if ((label|0) == 19) {
  $63 = ___cxa_find_matching_catch(0|0)|0;
  $64 = tempRet0;
  $$0 = $63;
 }
 (___cxa_begin_catch(($$0|0))|0);
 $71 = HEAP32[$__os>>2]|0;
 $72 = (($71) + -12|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($__os) + ($73)|0);
 __THREW__ = 0;
 invoke_vi(3301,($74|0));
 $75 = __THREW__; __THREW__ = 0;
 $76 = $75&1;
 if (!($76)) {
  ___cxa_end_catch();
  STACKTOP = sp;return ($__os|0);
 }
 $77 = ___cxa_find_matching_catch()|0;
 $78 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $79 = __THREW__; __THREW__ = 0;
 $80 = $79&1;
 if ($80) {
  $81 = ___cxa_find_matching_catch(0|0)|0;
  $82 = tempRet0;
  ___clang_call_terminate($81);
  // unreachable;
 } else {
  ___resumeException($77|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__116__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$__s,$__ob,$__op,$__oe,$__iob,$__fl) {
 $agg$result = $agg$result|0;
 $__s = $__s|0;
 $__ob = $__ob|0;
 $__op = $__op|0;
 $__oe = $__oe|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__ns$0 = 0, $__p$0$i$i$i = 0, $__sp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__sp = sp;
 $0 = HEAP32[$__s>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[$agg$result>>2] = 0;
  STACKTOP = sp;return;
 }
 $2 = $__oe;
 $3 = $__ob;
 $4 = (($2) - ($3))|0;
 $5 = (($__iob) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>($4|0);
 $8 = (($6) - ($4))|0;
 $__ns$0 = $7 ? $8 : 0;
 $9 = $__op;
 $10 = (($9) - ($3))|0;
 $11 = ($10|0)>(0);
 if ($11) {
  $12 = HEAP32[$0>>2]|0;
  $13 = (($12) + 48|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_iiii[$14 & 2047]($0,$__ob,$10)|0);
  $16 = ($15|0)==($10|0);
  if (!($16)) {
   HEAP32[$__s>>2] = 0;
   HEAP32[$agg$result>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $17 = ($__ns$0|0)>(0);
 do {
  if ($17) {
   $18 = ($__ns$0>>>0)<(11);
   if ($18) {
    $19 = $__ns$0 << 1;
    $20 = $19&255;
    HEAP8[$__sp>>0] = $20;
    $21 = (($__sp) + 1|0);
    $$pre$phiZ2D = $__sp;$31 = $20;$__p$0$i$i$i = $21;
   } else {
    $22 = (($__ns$0) + 16)|0;
    $23 = $22 & -16;
    $24 = (__Znwj($23)|0);
    $25 = (($__sp) + 8|0);
    HEAP32[$25>>2] = $24;
    $26 = $23 | 1;
    HEAP32[$__sp>>2] = $26;
    $27 = (($__sp) + 4|0);
    HEAP32[$27>>2] = $__ns$0;
    $28 = $26&255;
    $$pre$phiZ2D = $__sp;$31 = $28;$__p$0$i$i$i = $24;
   }
   _memset(($__p$0$i$i$i|0),($__fl|0),($__ns$0|0))|0;
   $29 = (($__p$0$i$i$i) + ($__ns$0)|0);
   HEAP8[$29>>0] = 0;
   $30 = $31 & 1;
   $32 = ($30<<24>>24)==(0);
   if ($32) {
    $35 = (($__sp) + 1|0);
    $39 = $35;
   } else {
    $33 = (($__sp) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $39 = $34;
   }
   $36 = HEAP32[$0>>2]|0;
   $37 = (($36) + 48|0);
   $38 = HEAP32[$37>>2]|0;
   __THREW__ = 0;
   $40 = (invoke_iiii($38|0,($0|0),($39|0),($__ns$0|0))|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $49 = ___cxa_find_matching_catch()|0;
    $50 = tempRet0;
    $51 = HEAP8[$$pre$phiZ2D>>0]|0;
    $52 = $51 & 1;
    $53 = ($52<<24>>24)==(0);
    if ($53) {
     ___resumeException($49|0);
     // unreachable;
    }
    $54 = (($__sp) + 8|0);
    $55 = HEAP32[$54>>2]|0;
    __ZdlPv($55);
    ___resumeException($49|0);
    // unreachable;
   }
   $43 = ($40|0)==($__ns$0|0);
   if ($43) {
    $56 = HEAP8[$$pre$phiZ2D>>0]|0;
    $57 = $56 & 1;
    $58 = ($57<<24>>24)==(0);
    if ($58) {
     break;
    }
    $59 = (($__sp) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    __ZdlPv($60);
    break;
   }
   HEAP32[$__s>>2] = 0;
   HEAP32[$agg$result>>2] = 0;
   $44 = HEAP8[$$pre$phiZ2D>>0]|0;
   $45 = $44 & 1;
   $46 = ($45<<24>>24)==(0);
   if ($46) {
    STACKTOP = sp;return;
   }
   $47 = (($__sp) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   __ZdlPv($48);
   STACKTOP = sp;return;
  }
 } while(0);
 $61 = (($2) - ($9))|0;
 $62 = ($61|0)>(0);
 if ($62) {
  $63 = HEAP32[$0>>2]|0;
  $64 = (($63) + 48|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (FUNCTION_TABLE_iiii[$65 & 2047]($0,$__op,$61)|0);
  $67 = ($66|0)==($61|0);
  if (!($67)) {
   HEAP32[$__s>>2] = 0;
   HEAP32[$agg$result>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$5>>2] = 0;
 HEAP32[$agg$result>>2] = $0;
 STACKTOP = sp;return;
}
function ___clang_call_terminate($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (___cxa_begin_catch(($0|0))|0);
 __ZSt9terminatev();
 // unreachable;
}
function __Z19il2cpp_gc_base_initv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[67992>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 _GC_init();
 _GC_set_no_dls(1);
 HEAP8[67992>>0] = 1;
 STACKTOP = sp;return;
}
function __Z17il2cpp_gc_collecti($generation) {
 $generation = $generation|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _GC_gcollect();
 STACKTOP = sp;return;
}
function __Z24il2cpp_gc_max_generationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z26il2cpp_gc_collection_counti($generation) {
 $generation = $generation|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_GC_get_gc_no()|0);
 STACKTOP = sp;return ($0|0);
}
function __Z29il2cpp_gc_add_memory_pressurex($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z23il2cpp_gc_get_used_sizev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_GC_get_heap_size()|0);
 $1 = (_GC_get_free_bytes()|0);
 $2 = (($0) - ($1))|0;
 tempRet0 = 0;
 STACKTOP = sp;return ($2|0);
}
function __Z17il2cpp_gc_disablev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 _GC_disable();
 STACKTOP = sp;return;
}
function __Z16il2cpp_gc_enablev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 _GC_enable();
 STACKTOP = sp;return;
}
function __Z25il2cpp_gc_register_threadPv($baseptr) {
 $baseptr = $baseptr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __Z27il2cpp_gc_unregister_threadv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __Z23il2cpp_gc_weak_link_addPPvP12Il2CppObjectb($link_addr,$obj,$track) {
 $link_addr = $link_addr|0;
 $obj = $obj|0;
 $track = $track|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $obj;
 $1 = $0 ^ -1;
 $2 = $1;
 HEAP32[$link_addr>>2] = $2;
 (_GC_general_register_disappearing_link($link_addr,$obj)|0);
 STACKTOP = sp;return;
}
function __Z26il2cpp_gc_weak_link_removePPv($link_addr) {
 $link_addr = $link_addr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_GC_unregister_disappearing_link($link_addr)|0);
 HEAP32[$link_addr>>2] = 0;
 STACKTOP = sp;return;
}
function __Z23il2cpp_gc_weak_link_getPPv($link_addr) {
 $link_addr = $link_addr|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_GC_call_with_alloc_lock(2987,$link_addr)|0);
 $1 = ($0|0)==((-1)|0);
 if ($1) {
  $$0 = 0;
 } else {
  $$0 = $0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL11reveal_linkPv($link_addr) {
 $link_addr = $link_addr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$link_addr>>2]|0;
 $1 = $0;
 $2 = $1 ^ -1;
 $3 = $2;
 STACKTOP = sp;return ($3|0);
}
function __Z21il2cpp_gc_alloc_fixedjPv($size,$descr) {
 $size = $size|0;
 $descr = $descr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_GC_malloc_uncollectable($size)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z20il2cpp_gc_free_fixedPv($addr) {
 $addr = $addr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _GC_free($addr);
 STACKTOP = sp;return;
}
function __Z27il2cpp_gc_invoke_finalizersv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_GC_invoke_finalizers()|0);
 STACKTOP = sp;return ($0|0);
}
function __Z28il2cpp_gc_pending_finalizersv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_GC_should_invoke_finalizers()|0);
 $1 = ($0|0)!=(0);
 STACKTOP = sp;return ($1|0);
}
function __Z31il2cpp_gc_add_weak_track_handleP12Il2CppObjectj($obj,$handle) {
 $obj = $obj|0;
 $handle = $handle|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68024;
 (_printf((68000|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __Z34il2cpp_gc_remove_weak_track_handlej($gchandle) {
 $gchandle = $gchandle|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68056;
 (_printf((68000|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __Z34il2cpp_gc_change_weak_track_handleP12Il2CppObjectS0_j($old_obj,$obj,$gchandle) {
 $old_obj = $old_obj|0;
 $obj = $obj|0;
 $gchandle = $gchandle|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68096;
 (_printf((68000|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __Z24il2cpp_gc_get_generationPv($addr) {
 $addr = $addr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z14il2cpp_gc_initv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z19il2cpp_gc_base_initv();
 STACKTOP = sp;return;
}
function __Z22il2cpp_gc_run_finalizePvS_($obj,$data) {
 $obj = $obj|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $exc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exc = sp;
 HEAP32[$exc>>2] = 0;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (__ZN6il2cpp2vm5Class12GetFinalizerEP8TypeInfo($0)|0);
 (__ZN6il2cpp2vm7Runtime6InvokeEP10MethodInfoPvPS4_PP12Il2CppObject($1,$obj,0,$exc)|0);
 STACKTOP = sp;return;
}
function __Z28il2cpp_gc_register_finalizerP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $1 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(68136)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 }
 _GC_register_finalizer_no_order($obj,2477,0,0,0);
 STACKTOP = sp;return;
}
function __Z28il2cpp_gc_suppress_finalizerP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $1 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(68136)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 }
 _GC_register_finalizer_no_order($obj,0,0,0,0);
 STACKTOP = sp;return;
}
function __Z37il2cpp_gc_wait_for_pending_finalizersv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z28il2cpp_gc_pending_finalizersv()|0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 (__Z27il2cpp_gc_invoke_finalizersv()|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2gc8GCHandle3NewEP12Il2CppObjectb($obj,$pinned) {
 $obj = $obj|0;
 $pinned = $pinned|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $pinned ? 3 : 2;
 $1 = (68144 + (($0*20)|0)|0);
 $2 = (__ZN6il2cpp2gcL12alloc_handleEPNS0_10HandleDataEP12Il2CppObjectb($1,$obj,0)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2gcL12alloc_handleEPNS0_10HandleDataEP12Il2CppObjectb($handles,$obj,$track) {
 $handles = $handles|0;
 $obj = $obj|0;
 $track = $track|0;
 var $$clear = 0, $$hi = 0, $$hi$sh = 0, $$hi$sh16 = 0, $$hi$sh22 = 0, $$hi$sh28 = 0, $$hi$sh9 = 0, $$hi1 = 0, $$hi1$ext = 0, $$hi1$ext$sh = 0, $$hi10 = 0, $$hi11 = 0, $$hi17 = 0, $$hi18 = 0, $$hi23 = 0, $$hi24 = 0, $$hi29 = 0, $$hi30 = 0, $$hi4 = 0, $$hi5 = 0;
 var $$lcssa = 0, $$lo = 0, $$lo$ext = 0, $$lo15 = 0, $$lo21 = 0, $$lo27 = 0, $$lo3 = 0, $$lo8 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$01$i1 = 0, $i$28 = 0, $i$3 = 0, $or$cond = 0, $slot$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($handles) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$0>>2] = 32;
  $3 = (($handles) + 12|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4&255)>(1);
  if ($5) {
   $6 = (__Z21il2cpp_gc_alloc_fixedjPv(128,0)|0);
   $7 = (($handles) + 4|0);
   HEAP32[$7>>2] = $6;
   $$pre = HEAP32[$0>>2]|0;
   $13 = $$pre;
  } else {
   $8 = (_calloc(1,128)|0);
   $9 = (($handles) + 4|0);
   HEAP32[$9>>2] = $8;
   $10 = (_calloc(1,64)|0);
   $11 = (($handles) + 16|0);
   HEAP32[$11>>2] = $10;
   $13 = 32;
  }
  $12 = $13 >>> 3;
  $14 = (_calloc(1,$12)|0);
  HEAP32[$handles>>2] = $14;
  $19 = $13;
 } else {
  $19 = $1;
 }
 $15 = (($handles) + 13|0);
 $$lo = HEAPU8[$15>>0]|(HEAPU8[$15+1>>0]<<8);
 $$lo$ext = $$lo&65535;
 $$hi = (($15) + 2|0);
 $$hi1 = HEAP8[$$hi>>0]|0;
 $$hi1$ext = $$hi1&255;
 $$hi1$ext$sh = $$hi1$ext << 16;
 $16 = $$lo$ext | $$hi1$ext$sh;
 $17 = $16 & 16777215;
 $18 = $19 >>> 5;
 $20 = ($17>>>0)<($18>>>0);
 L8: do {
  if ($20) {
   $21 = HEAP32[$handles>>2]|0;
   $25 = $17;
   while(1) {
    $24 = (($21) + ($25<<2)|0);
    $26 = HEAP32[$24>>2]|0;
    $27 = ($26|0)==(-1);
    $23 = (($25) + 1)|0;
    if (!($27)) {
     $i$01$i = 0;
     break;
    }
    $22 = ($23>>>0)<($18>>>0);
    if ($22) {
     $25 = $23;
    } else {
     $34 = $16;
     label = 14;
     break L8;
    }
   }
   while(1) {
    $30 = 1 << $i$01$i;
    $31 = $30 & $26;
    $32 = ($31|0)==(0);
    $29 = (($i$01$i) + 1)|0;
    if ($32) {
     label = 13;
     break;
    }
    $28 = ($29|0)<(32);
    if ($28) {
     $i$01$i = $29;
    } else {
     label = 11;
     break;
    }
   }
   if ((label|0) == 11) {
    $$lo3 = $25&65535;
    HEAP8[$15>>0]=$$lo3&255;HEAP8[$15+1>>0]=$$lo3>>8;
    $$hi$sh = $25 >>> 16;
    $$hi4 = (($15) + 2|0);
    $$hi5 = $$hi$sh&255;
    HEAP8[$$hi4>>0] = $$hi5;
    $34 = $25;
    label = 14;
    break;
   }
   else if ((label|0) == 13) {
    $$lo8 = $25&65535;
    HEAP8[$15>>0]=$$lo8&255;HEAP8[$15+1>>0]=$$lo8>>8;
    $$hi$sh9 = $25 >>> 16;
    $$hi10 = (($15) + 2|0);
    $$hi11 = $$hi$sh9&255;
    HEAP8[$$hi10>>0] = $$hi11;
    $33 = ($i$01$i|0)==(-1);
    if ($33) {
     $34 = $25;
     label = 14;
     break;
    } else {
     $$pre$phiZ2D = $handles;$i$3 = $i$01$i;$slot$3 = $25;
     break;
    }
   }
  } else {
   $34 = $16;
   label = 14;
  }
 } while(0);
 L19: do {
  if ((label|0) == 14) {
   $$clear = $34 & 16777215;
   $35 = ($$clear|0)==(0);
   L21: do {
    if (!($35)) {
     $36 = HEAP32[$handles>>2]|0;
     $41 = 0;
     while(1) {
      $40 = (($36) + ($41<<2)|0);
      $42 = HEAP32[$40>>2]|0;
      $43 = ($42|0)==(-1);
      $39 = (($41) + 1)|0;
      if (!($43)) {
       $i$01$i1 = 0;
       break;
      }
      $37 = $34 & 16777215;
      $38 = ($39|0)<($37|0);
      if ($38) {
       $41 = $39;
      } else {
       break L21;
      }
     }
     while(1) {
      $46 = 1 << $i$01$i1;
      $47 = $46 & $42;
      $48 = ($47|0)==(0);
      $45 = (($i$01$i1) + 1)|0;
      if ($48) {
       break;
      }
      $44 = ($45|0)<(32);
      if ($44) {
       $i$01$i1 = $45;
      } else {
       label = 19;
       break;
      }
     }
     if ((label|0) == 19) {
      $$lo15 = $41&65535;
      HEAP8[$15>>0]=$$lo15&255;HEAP8[$15+1>>0]=$$lo15>>8;
      $$hi$sh16 = $41 >>> 16;
      $$hi17 = (($15) + 2|0);
      $$hi18 = $$hi$sh16&255;
      HEAP8[$$hi17>>0] = $$hi18;
      break;
     }
     $$lo21 = $41&65535;
     HEAP8[$15>>0]=$$lo21&255;HEAP8[$15+1>>0]=$$lo21>>8;
     $$hi$sh22 = $41 >>> 16;
     $$hi23 = (($15) + 2|0);
     $$hi24 = $$hi$sh22&255;
     HEAP8[$$hi23>>0] = $$hi24;
     $49 = ($i$01$i1|0)==(-1);
     if (!($49)) {
      $$pre$phiZ2D = $handles;$i$3 = $i$01$i1;$slot$3 = $41;
      break L19;
     }
    }
   } while(0);
   $50 = $19 << 1;
   $51 = $19 >>> 2;
   $52 = $51 & 536870911;
   $53 = (_calloc(1,$52)|0);
   $54 = HEAP32[$handles>>2]|0;
   $55 = $19 >>> 3;
   _memcpy(($53|0),($54|0),($55|0))|0;
   _free($54);
   HEAP32[$handles>>2] = $53;
   $56 = (($handles) + 12|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ($57&255)>(1);
   if ($58) {
    $59 = $19 << 3;
    $60 = (__Z21il2cpp_gc_alloc_fixedjPv($59,0)|0);
    $61 = (($handles) + 4|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = HEAP32[$0>>2]|0;
    $64 = $63 << 2;
    _memcpy(($60|0),($62|0),($64|0))|0;
    HEAP32[$61>>2] = $60;
   } else {
    $65 = $19 << 2;
    $66 = (_calloc(1,$65)|0);
    $67 = $19 << 3;
    $68 = (_malloc($67)|0);
    __Z17il2cpp_gc_disablev();
    $69 = (($handles) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = HEAP32[$0>>2]|0;
    $72 = $71 << 2;
    _memcpy(($68|0),($70|0),($72|0))|0;
    $73 = (($68) + ($71<<2)|0);
    _memset(($73|0),0,($72|0))|0;
    $74 = (($handles) + 16|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $71 << 1;
    _memcpy(($66|0),($75|0),($76|0))|0;
    $77 = ($71|0)==(0);
    if ($77) {
     $$lcssa = $70;
    } else {
     $79 = $70;$i$28 = 0;
     while(1) {
      $78 = (($79) + ($i$28<<2)|0);
      $80 = (__Z23il2cpp_gc_weak_link_getPPv($78)|0);
      $81 = HEAP32[$69>>2]|0;
      $82 = (($81) + ($i$28<<2)|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ($83|0)==(0|0);
      if (!($84)) {
       __Z26il2cpp_gc_weak_link_removePPv($82);
      }
      $85 = ($80|0)==(0|0);
      if (!($85)) {
       $86 = (($68) + ($i$28<<2)|0);
       __Z23il2cpp_gc_weak_link_addPPvP12Il2CppObjectb($86,$80,$track);
      }
      $87 = (($i$28) + 1)|0;
      $88 = HEAP32[$0>>2]|0;
      $89 = ($87>>>0)<($88>>>0);
      $90 = HEAP32[$69>>2]|0;
      if ($89) {
       $79 = $90;$i$28 = $87;
      } else {
       $$lcssa = $90;
       break;
      }
     }
    }
    _free($$lcssa);
    $91 = HEAP32[$74>>2]|0;
    _free($91);
    HEAP32[$69>>2] = $68;
    HEAP32[$74>>2] = $66;
    __Z16il2cpp_gc_enablev();
   }
   $92 = HEAP32[$0>>2]|0;
   $93 = (($92) + 1)|0;
   $94 = $93 >>> 5;
   $$lo27 = $93&65535;
   HEAP8[$15>>0]=$$lo27&255;HEAP8[$15+1>>0]=$$lo27>>8;
   $$hi$sh28 = $93 >>> 16;
   $$hi29 = (($15) + 2|0);
   $$hi30 = $$hi$sh28&255;
   HEAP8[$$hi29>>0] = $$hi30;
   HEAP32[$0>>2] = $50;
   $$pre$phiZ2D = $handles;$i$3 = 0;$slot$3 = $94;
  }
 } while(0);
 $95 = 1 << $i$3;
 $96 = HEAP32[$$pre$phiZ2D>>2]|0;
 $97 = (($96) + ($slot$3<<2)|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = $98 | $95;
 HEAP32[$97>>2] = $99;
 $100 = $slot$3 << 5;
 $101 = (($100) + ($i$3))|0;
 $102 = (($handles) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + ($101<<2)|0);
 HEAP32[$104>>2] = $obj;
 $105 = (($handles) + 12|0);
 $106 = HEAP8[$105>>0]|0;
 $107 = ($106&255)>(1);
 $108 = ($obj|0)==(0|0);
 $or$cond = $107 | $108;
 if ($or$cond) {
  $113 = $106;
  $111 = $101 << 3;
  $112 = $113&255;
  $114 = (($112) + 1)|0;
  $115 = $114 | $111;
  STACKTOP = sp;return ($115|0);
 }
 $109 = HEAP32[$102>>2]|0;
 $110 = (($109) + ($101<<2)|0);
 __Z23il2cpp_gc_weak_link_addPPvP12Il2CppObjectb($110,$obj,$track);
 $$pre33 = HEAP8[$105>>0]|0;
 $113 = $$pre33;
 $111 = $101 << 3;
 $112 = $113&255;
 $114 = (($112) + 1)|0;
 $115 = $114 | $111;
 STACKTOP = sp;return ($115|0);
}
function __ZN6il2cpp2gc8GCHandle9GetTargetEj($gchandle) {
 $gchandle = $gchandle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $gchandle >>> 3;
 $1 = $gchandle & 7;
 $2 = (($1) + -1)|0;
 $3 = ($2>>>0)>(3);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ((68144 + (($2*20)|0)|0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($0>>>0)<($5>>>0);
 if (!($6)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = $gchandle >>> 8;
 $8 = (68144 + (($2*20)|0)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $0 & 31;
 $13 = 1 << $12;
 $14 = $11 & $13;
 $15 = ($14|0)==(0);
 if ($15) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = ((68144 + (($2*20)|0)|0) + 12|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17&255)<(2);
 $19 = ((68144 + (($2*20)|0)|0) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($0<<2)|0);
 if ($18) {
  $22 = (__Z23il2cpp_gc_weak_link_getPPv($21)|0);
  $$0 = $22;
  STACKTOP = sp;return ($$0|0);
 } else {
  $23 = HEAP32[$21>>2]|0;
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2gc8GCHandle4FreeEj($gchandle) {
 $gchandle = $gchandle|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $gchandle >>> 3;
 $1 = $gchandle & 7;
 $2 = (($1) + -1)|0;
 $3 = ($2>>>0)>(3);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)==(1);
 if ($4) {
  __Z34il2cpp_gc_remove_weak_track_handlej($gchandle);
 }
 $5 = ((68144 + (($2*20)|0)|0) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($0>>>0)<($6>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = $gchandle >>> 8;
 $9 = (68144 + (($2*20)|0)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($8<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $0 & 31;
 $14 = 1 << $13;
 $15 = $12 & $14;
 $16 = ($15|0)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = ((68144 + (($2*20)|0)|0) + 12|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18&255)<(2);
 $20 = ((68144 + (($2*20)|0)|0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($0<<2)|0);
 if ($19) {
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   __Z26il2cpp_gc_weak_link_removePPv($22);
  }
 } else {
  HEAP32[$22>>2] = 0;
 }
 $25 = $14 ^ -1;
 $26 = HEAP32[$9>>2]|0;
 $27 = (($26) + ($8<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 & $25;
 HEAP32[$27>>2] = $29;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2gc8GCHandle15GetTargetHandleEP12Il2CppObjectii($obj,$handle,$type) {
 $obj = $obj|0;
 $handle = $handle|0;
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $old_obj$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 switch ($type|0) {
 case 0:  {
  $33 = (__ZN6il2cpp2gcL12alloc_handleEPNS0_10HandleDataEP12Il2CppObjectb(68144,$obj,0)|0);
  $$0 = $33;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $36 = (__ZN6il2cpp2gcL12alloc_handleEPNS0_10HandleDataEP12Il2CppObjectb(((68144 + 60|0)),$obj,0)|0);
  $$0 = $36;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $35 = (__ZN6il2cpp2gcL12alloc_handleEPNS0_10HandleDataEP12Il2CppObjectb(((68144 + 40|0)),$obj,0)|0);
  $$0 = $35;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case -1:  {
  $0 = $handle >>> 3;
  $1 = $handle & 7;
  $2 = (($1) + -1)|0;
  $3 = ($2>>>0)>(3);
  if ($3) {
   $$0 = $handle;
   STACKTOP = sp;return ($$0|0);
  }
  $4 = ((68144 + (($2*20)|0)|0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($0>>>0)<($5>>>0);
  do {
   if ($6) {
    $7 = $handle >>> 8;
    $8 = (68144 + (($2*20)|0)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + ($7<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = $0 & 31;
    $13 = 1 << $12;
    $14 = $11 & $13;
    $15 = ($14|0)==(0);
    if ($15) {
     $old_obj$0$i = 0;
    } else {
     $16 = ((68144 + (($2*20)|0)|0) + 12|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = ($17&255)<(2);
     if (!($18)) {
      $29 = ((68144 + (($2*20)|0)|0) + 4|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($30) + ($0<<2)|0);
      HEAP32[$31>>2] = $obj;
      $old_obj$0$i = 0;
      break;
     }
     $19 = ((68144 + (($2*20)|0)|0) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($20) + ($0<<2)|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     if (!($23)) {
      __Z26il2cpp_gc_weak_link_removePPv($21);
     }
     $24 = ($obj|0)==(0|0);
     if ($24) {
      $old_obj$0$i = $22;
     } else {
      $25 = HEAP32[$19>>2]|0;
      $26 = (($25) + ($0<<2)|0);
      $27 = HEAP8[$16>>0]|0;
      $28 = ($27<<24>>24)==(1);
      __Z23il2cpp_gc_weak_link_addPPvP12Il2CppObjectb($26,$obj,$28);
      $old_obj$0$i = $22;
     }
    }
   } else {
    $old_obj$0$i = 0;
   }
  } while(0);
  $32 = ($2|0)==(1);
  if (!($32)) {
   $$0 = $handle;
   STACKTOP = sp;return ($$0|0);
  }
  __Z34il2cpp_gc_change_weak_track_handleP12Il2CppObjectS0_j($old_obj$0$i,$obj,$handle);
  $$0 = $handle;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1:  {
  $34 = (__ZN6il2cpp2gcL12alloc_handleEPNS0_10HandleDataEP12Il2CppObjectb(((68144 + 20|0)),$obj,1)|0);
  __Z31il2cpp_gc_add_weak_track_handleP12Il2CppObjectj($obj,$34);
  $$0 = $34;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN6il2cpp2gc12WriteBarrier12GenericStoreEPvP12Il2CppObject($ptr,$value) {
 $ptr = $ptr|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$ptr>>2] = $value;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib4Mono7Runtime14GetDisplayNameEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String3NewEPKc(68224)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib4Mono7Runtime29mono_runtime_install_handlersEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(68264)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib4Mono13Globalization7Unicode13Normalization27load_normalization_resourceEP12Il2CppIntPtrS7_S7_S7_S7_S7_($props,$mappedChars,$charMapIndex,$helperIndex,$mapIdxToComposite,$combiningClass) {
 $props = $props|0;
 $mappedChars = $mappedChars|0;
 $charMapIndex = $charMapIndex|0;
 $helperIndex = $helperIndex|0;
 $mapIdxToComposite = $mapIdxToComposite|0;
 $combiningClass = $combiningClass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(68456)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib4Mono7Interop15ComInteropProxy8AddProxyE12Il2CppIntPtrP37mscorlib_Mono_Interop_ComInteropProxy($pItf,$proxy) {
 $pItf = $pItf|0;
 $proxy = $proxy|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68712;
 (_printf((68680|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib4Mono7Interop15ComInteropProxy9FindProxyE12Il2CppIntPtr($pItf) {
 $pItf = $pItf|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68744;
 (_printf((68680|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence10_CanSecureEP12Il2CppString($root) {
 $root = $root|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68808;
 (_printf((68776|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence12_ProtectUserEP12Il2CppString($path) {
 $path = $path|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68840;
 (_printf((68776|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence15_ProtectMachineEP12Il2CppString($path) {
 $path = $path|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68880;
 (_printf((68776|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence16_IsUserProtectedEP12Il2CppString($path) {
 $path = $path|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68920;
 (_printf((68776|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence19_IsMachineProtectedEP12Il2CppString($path) {
 $path = $path|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 68960;
 (_printf((68776|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System11__ComObject9CreateRCWEP20Il2CppReflectionType($t) {
 $t = $t|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 69032;
 (_printf((69000|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11__ComObject17ReleaseInterfacesEP27mscorlib_System___ComObject($__this) {
 $__this = $__this|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 69056;
 (_printf((69000|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System11__ComObject20GetInterfaceInternalEP27mscorlib_System___ComObjectP20Il2CppReflectionTypeb($__this,$t,$throwException) {
 $__this = $__this|0;
 $t = $t|0;
 $throwException = $throwException|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 69088;
 (_printf((69000|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Activator22CreateInstanceInternalEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 $8 = (($2) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZN6il2cpp2vm5Image17FindClassMatchingEP11Il2CppImagePKcS5_P8TypeInfo($4,$6,$7,$9)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (_il2cpp_object_new($10)|0);
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain12getCurDomainEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Domain10GetCurrentEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[((388944 + 128|0))>>2]|0;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($3)|0);
 HEAP32[$0>>2] = $4;
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain13getRootDomainEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Domain7GetRootEv()|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain12createDomainEP12Il2CppStringP30mscorlib_System_AppDomainSetup($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(69128)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain13GetAssembliesEP15Il2CppAppDomainb($ad,$refonly) {
 $ad = $ad|0;
 $refonly = $refonly|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[69336>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = HEAP32[388944>>2]|0;
  $3 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($2,69344,69368)|0);
  HEAP32[69336>>2] = $3;
 }
 $4 = (__ZN6il2cpp2vm8Assembly16GetAllAssembliesEv()|0);
 $5 = HEAP32[69336>>2]|0;
 $6 = (($4) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$4>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($5,$12)|0);
 $14 = HEAP32[$4>>2]|0;
 $15 = HEAP32[$6>>2]|0;
 $16 = ($14|0)==($15|0);
 if ($16) {
  STACKTOP = sp;return ($13|0);
 } else {
  $20 = $14;$c$02 = 0;
 }
 while(1) {
  $17 = (($c$02) + 1)|0;
  $18 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($13,4,$c$02)|0);
  $19 = HEAP32[$20>>2]|0;
  $21 = (__ZN6il2cpp2vm10Reflection17GetAssemblyObjectEP14Il2CppAssembly($19)|0);
  HEAP32[$18>>2] = $21;
  $22 = (($20) + 4|0);
  $23 = HEAP32[$6>>2]|0;
  $24 = ($22|0)==($23|0);
  if ($24) {
   break;
  } else {
   $20 = $22;$c$02 = $17;
  }
 }
 STACKTOP = sp;return ($13|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain15getFriendlyNameEP15Il2CppAppDomain($ad) {
 $ad = $ad|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ad) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_il2cpp_string_new($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain8getSetupEP15Il2CppAppDomain($domain) {
 $domain = $domain|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($domain) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain25InternalGetDefaultContextEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(69384)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain18InternalGetContextEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(69608)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain22InternalGetProcessGuidEP12Il2CppString($newguid) {
 $newguid = $newguid|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(69880)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain20InternalPopDomainRefEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(70120)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain21InternalPushDomainRefEP25mscorlib_System_AppDomain($domain) {
 $domain = $domain|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(70336)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain25InternalPushDomainRefByIDEi($domain_id) {
 $domain_id = $domain_id|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(70552)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain18InternalSetContextEP49mscorlib_System_Runtime_Remoting_Contexts_Context($context) {
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(70776)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain17InternalSetDomainEP25mscorlib_System_AppDomain($context) {
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(70992)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain21InternalSetDomainByIDEi($domain_id) {
 $domain_id = $domain_id|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(71208)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain12LoadAssemblyEP15Il2CppAppDomainP12Il2CppStringP40mscorlib_System_Security_Policy_Evidenceb($ad,$assemblyRef,$evidence,$refOnly) {
 $ad = $ad|0;
 $assemblyRef = $assemblyRef|0;
 $evidence = $evidence|0;
 $refOnly = $refOnly|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6il2cpp2vm8Assembly16GetAllAssembliesEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($1) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($assemblyRef) + 12|0);
 $7 = (($0) + 1|0);
 $8 = (($0) + 8|0);
 $10 = $2;
 while(1) {
  $13 = HEAP32[$10>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  __ZN6il2cpp5utils11StringUtils11Utf16ToUtf8EPKt($0,$6);
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $18 = (_strcmp($14,$7)|0);
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   }
  } else {
   $20 = HEAP32[$8>>2]|0;
   $21 = (_strcmp($14,$20)|0);
   $22 = ($21|0)==(0);
   __ZdlPv($20);
   if ($22) {
    break;
   }
  }
  $9 = (($10) + 4|0);
  $11 = HEAP32[$3>>2]|0;
  $12 = ($9|0)==($11|0);
  if ($12) {
   $$0 = 0;
   label = 8;
   break;
  } else {
   $10 = $9;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 $23 = HEAP32[$10>>2]|0;
 $24 = (__ZN6il2cpp2vm10Reflection17GetAssemblyObjectEP14Il2CppAssembly($23)|0);
 $$0 = $24;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain15ExecuteAssemblyEP15Il2CppAppDomainP14Il2CppAssemblyP11Il2CppArray($self,$a,$args) {
 $self = $self|0;
 $a = $a|0;
 $args = $args|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(71424)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain7GetDataEP15Il2CppAppDomainP12Il2CppString($self,$name) {
 $self = $self|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(71608)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain15LoadAssemblyRawEP15Il2CppAppDomainP11Il2CppArrayS7_Pvb($self,$rawAssembly,$rawSymbolStore,$securityEvidence,$refonly) {
 $self = $self|0;
 $rawAssembly = $rawAssembly|0;
 $rawSymbolStore = $rawSymbolStore|0;
 $securityEvidence = $securityEvidence|0;
 $refonly = $refonly|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(71784)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain29InternalIsFinalizingForUnloadEi($domain_id) {
 $domain_id = $domain_id|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(71968)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain14InternalUnloadEi($domain_id) {
 $domain_id = $domain_id|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(72168)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9AppDomain7SetDataEP15Il2CppAppDomainP12Il2CppStringP12Il2CppObject($self,$name,$data) {
 $self = $self|0;
 $name = $name|0;
 $data = $data|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(72352)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System11ArgIterator5SetupEP27mscorlib_System_ArgIterator12Il2CppIntPtrS6_($__this,$argsp,$start) {
 $__this = $__this|0;
 $argsp = $argsp|0;
 $start = $start|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(72528)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System11ArgIterator44IntGetNextArg_mscorlib_System_TypedReferenceEP27mscorlib_System_ArgIterator($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(72736)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System11ArgIterator67IntGetNextArg_mscorlib_System_TypedReference_mscorlib_System_IntPtrEP27mscorlib_System_ArgIterator12Il2CppIntPtr($agg$result,$__this,$rth) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $rth = $rth|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(72944)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System11ArgIterator17IntGetNextArgTypeEP27mscorlib_System_ArgIterator($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(73152)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System5Array13ClearInternalEP11Il2CppArrayii($arr,$idx,$length) {
 $arr = $arr|0;
 $idx = $idx|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$arr>>2]|0;
 $1 = (__Z25il2cpp_array_element_sizeP8TypeInfo($0)|0);
 $2 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($arr,$1,$idx)|0);
 $3 = Math_imul($1, $length)|0;
 _memset(($2|0),0,($3|0))|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System5Array5CloneEP11Il2CppArray($arr) {
 $arr = $arr|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i3 = 0, $$01 = 0, $$02 = 0, $$pre = 0, $$pre57 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $i$055 = 0, $len = 0, $phitmp = 0, $size$0$lcssa = 0, $size$056 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $len = sp;
 $0 = HEAP32[$arr>>2]|0;
 $1 = (__ZN6il2cpp2vm5Array14GetElementSizeEPK8TypeInfo($0)|0);
 $2 = (($arr) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($arr)|0);
  HEAP32[$len>>2] = $5;
  $6 = (__ZN6il2cpp2vm5Array7NewFullEP8TypeInfoPjS4_($0,$len,0)|0);
  $7 = (($6) + 16|0);
  $8 = (($arr) + 16|0);
  $9 = HEAP32[$len>>2]|0;
  $10 = Math_imul($9, $1)|0;
  _memcpy(($7|0),($8|0),($10|0))|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($0) + 112|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ($12<<24>>24)==(0);
 do {
  if ($14) {
   $50 = 0;$51 = 0;$size$0$lcssa = $1;
   label = 19;
  } else {
   $15 = $13 << 2;
   $16 = (__Znwj($15)|0);
   $$0$i$i$i = $13;$18 = $16;
   while(1) {
    $17 = ($18|0)==(0|0);
    if (!($17)) {
     HEAP32[$18>>2] = 0;
    }
    $19 = (($18) + 4|0);
    $20 = (($$0$i$i$i) + -1)|0;
    $21 = ($20|0)==(0);
    if ($21) {
     break;
    } else {
     $$0$i$i$i = $20;$18 = $19;
    }
   }
   $$pre = HEAP8[$11>>0]|0;
   $22 = $$pre&255;
   $23 = ($$pre<<24>>24)==(0);
   if ($23) {
    $50 = 0;$51 = $16;$size$0$lcssa = $1;
    label = 19;
   } else {
    $24 = $22 << 2;
    __THREW__ = 0;
    $25 = (invoke_ii(2988,($24|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     $45 = ___cxa_find_matching_catch()|0;
     $46 = tempRet0;
     $$01 = $46;$$02 = $45;$60 = $16;
     break;
    }
    $$0$i$i$i3 = $22;$29 = $25;
    while(1) {
     $28 = ($29|0)==(0|0);
     if (!($28)) {
      HEAP32[$29>>2] = 0;
     }
     $30 = (($29) + 4|0);
     $31 = (($$0$i$i$i3) + -1)|0;
     $32 = ($31|0)==(0);
     if ($32) {
      break;
     } else {
      $$0$i$i$i3 = $31;$29 = $30;
     }
    }
    $$pre57 = HEAP8[$11>>0]|0;
    $phitmp = ($$pre57<<24>>24)==(0);
    if ($phitmp) {
     $50 = $25;$51 = $16;$size$0$lcssa = $1;
     label = 19;
    } else {
     $i$055 = 0;$size$056 = $1;
     while(1) {
      $33 = (($3) + ($i$055<<3)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($16) + ($i$055<<2)|0);
      HEAP32[$35>>2] = $34;
      $36 = HEAP32[$33>>2]|0;
      $37 = Math_imul($36, $size$056)|0;
      $38 = ((($3) + ($i$055<<3)|0) + 4|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = (($25) + ($i$055<<2)|0);
      HEAP32[$40>>2] = $39;
      $41 = (($i$055) + 1)|0;
      $42 = HEAP8[$11>>0]|0;
      $43 = $42&255;
      $44 = ($41|0)<($43|0);
      if ($44) {
       $i$055 = $41;$size$056 = $37;
      } else {
       $50 = $25;$51 = $16;$size$0$lcssa = $37;
       label = 19;
       break;
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 19) {
   __THREW__ = 0;
   $52 = (invoke_iiii(1475,($0|0),($51|0),($50|0))|0);
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $47 = ___cxa_find_matching_catch()|0;
    $48 = tempRet0;
    $49 = ($50|0)==(0|0);
    if ($49) {
     $$01 = $48;$$02 = $47;$60 = $51;
     break;
    }
    __ZdlPv($50);
    $$01 = $48;$$02 = $47;$60 = $51;
    break;
   }
   $55 = (($52) + 16|0);
   $56 = (($arr) + 16|0);
   _memcpy(($55|0),($56|0),($size$0$lcssa|0))|0;
   $57 = ($50|0)==(0|0);
   if (!($57)) {
    __ZdlPv($50);
   }
   $58 = ($51|0)==(0|0);
   if ($58) {
    $$0 = $52;
    STACKTOP = sp;return ($$0|0);
   }
   __ZdlPv($51);
   $$0 = $52;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $59 = ($60|0)==(0|0);
 if ($59) {
  ___resumeException($$02|0);
  // unreachable;
 }
 __ZdlPv($60);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System5Array18CreateInstanceImplEP20Il2CppReflectionTypeP11Il2CppArrayS7_($elementType,$lengths,$bounds) {
 $elementType = $elementType|0;
 $lengths = $lengths|0;
 $bounds = $bounds|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i32bounds$0 = 0, $i32lengths$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($lengths|0)==(0|0);
 if ($0) {
  $i32lengths$0 = 0;
 } else {
  $1 = HEAP32[$lengths>>2]|0;
  $2 = (__Z25il2cpp_array_element_sizeP8TypeInfo($1)|0);
  $3 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($lengths,$2,0)|0);
  $i32lengths$0 = $3;
 }
 $4 = ($bounds|0)==(0|0);
 if ($4) {
  $i32bounds$0 = 0;
 } else {
  $5 = HEAP32[$bounds>>2]|0;
  $6 = (__Z25il2cpp_array_element_sizeP8TypeInfo($5)|0);
  $7 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($bounds,$6,0)|0);
  $i32bounds$0 = $7;
 }
 $8 = (($elementType) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($9)|0);
 $11 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($lengths)|0);
 $12 = (__ZN6il2cpp2vm5Class13GetArrayClassEP8TypeInfoj($10,$11)|0);
 $13 = (__ZN6il2cpp2vm5Array7NewFullEP8TypeInfoPjS4_($12,$i32lengths$0,$i32bounds$0)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN6il2cpp6icalls8mscorlib6System5Array8FastCopyEP11Il2CppArrayiS5_ii($source,$source_idx,$dest,$dest_idx,$length) {
 $source = $source|0;
 $source_idx = $source_idx|0;
 $dest = $dest|0;
 $dest_idx = $dest_idx|0;
 $length = $length|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0;
 var $i$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$source>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = HEAP32[$dest>>2]|0;
 $4 = (($3) + 112|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($2<<24>>24)==($5<<24>>24);
 if (!($6)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($source) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($dest) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($length) + ($dest_idx))|0;
 $14 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($dest)|0);
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = (($length) + ($source_idx))|0;
 $17 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($source)|0);
 $18 = ($16>>>0)>($17>>>0);
 if ($18) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = HEAP32[$source>>2]|0;
 $20 = (($19) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[((388944 + 4|0))>>2]|0;
 $23 = ($21|0)==($22|0);
 $24 = HEAP32[$dest>>2]|0;
 $25 = (($24) + 28|0);
 $26 = HEAP32[$25>>2]|0;
 if ($23) {
  $27 = (($26) + 113|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if (!($29)) {
   $30 = ($length|0)>(0);
   if ($30) {
    $i$02 = $source_idx;
    while(1) {
     $31 = (($i$02) + 1)|0;
     $32 = ($31|0)<($16|0);
     if ($32) {
      $i$02 = $31;
     } else {
      break;
     }
    }
    $$pre = HEAP32[$dest>>2]|0;
    $33 = $$pre;
   } else {
    $33 = $24;
   }
   $34 = (__Z25il2cpp_array_element_sizeP8TypeInfo($33)|0);
   $35 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($dest,$34,$dest_idx)|0);
   $36 = Math_imul($34, $length)|0;
   _memset(($35|0),0,($36|0))|0;
   if ($30) {
    $i$11 = 0;
   } else {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   while(1) {
    $37 = (($i$11) + ($source_idx))|0;
    $38 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($source,4,$37)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($i$11) + ($dest_idx))|0;
    $41 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($dest,$34,$40)|0);
    $42 = ($39|0)==(0|0);
    if (!($42)) {
     $43 = (($39) + 8|0);
     _memcpy(($41|0),($43|0),($34|0))|0;
    }
    $44 = (($i$11) + 1)|0;
    $exitcond = ($44|0)==($length|0);
    if ($exitcond) {
     $$0 = 1;
     break;
    } else {
     $i$11 = $44;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 }
 $45 = (($dest) + 16|0);
 $46 = (($26) + 92|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = Math_imul($47, $dest_idx)|0;
 $49 = (($45) + ($48)|0);
 $50 = (($source) + 16|0);
 $51 = (($21) + 92|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = Math_imul($52, $source_idx)|0;
 $54 = (($50) + ($53)|0);
 $55 = Math_imul($47, $length)|0;
 _memmove(($49|0),($54|0),($55|0))|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System5Array9GetLengthEP11Il2CppArrayi($__this,$dimension) {
 $__this = $__this|0;
 $dimension = $dimension|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $length$0 = 0, $length$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($dimension|0)<(0);
 if ($0) {
  label = 3;
 } else {
  $1 = HEAP32[$__this>>2]|0;
  $2 = (($1) + 112|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3&255;
  $5 = ($4|0)>($dimension|0);
  if (!($5)) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $6 = (__ZN6il2cpp2vm9Exception27GetIndexOutOfRangeExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($6);
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (($__this) + 12|0);
  $length$0$in = $10;
  $length$0 = HEAP32[$length$0$in>>2]|0;
  STACKTOP = sp;return ($length$0|0);
 } else {
  $11 = (($8) + ($dimension<<3)|0);
  $length$0$in = $11;
  $length$0 = HEAP32[$length$0$in>>2]|0;
  STACKTOP = sp;return ($length$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System5Array13GetLowerBoundEP11Il2CppArrayi($__this,$dimension) {
 $__this = $__this|0;
 $dimension = $dimension|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($dimension|0)<(0);
 if ($0) {
  label = 3;
 } else {
  $1 = HEAP32[$__this>>2]|0;
  $2 = (($1) + 112|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3&255;
  $5 = ($4|0)>($dimension|0);
  if (!($5)) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $6 = (__ZN6il2cpp2vm9Exception27GetIndexOutOfRangeExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($6);
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ((($8) + ($dimension<<3)|0) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $11;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System5Array7GetRankEP11Il2CppArray($arr) {
 $arr = $arr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$arr>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp6icalls8mscorlib6System5Array8GetValueEP11Il2CppArrayS5_($__this,$indices) {
 $__this = $__this|0;
 $indices = $indices|0;
 var $$0 = 0, $$pre = 0, $$pre10 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $i$05 = 0, $i$13 = 0, $pos$0$lcssa = 0, $pos$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($indices|0)==(0|0);
 if ($0) {
  $1 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(73360)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 }
 $2 = HEAP32[$__this>>2]|0;
 $3 = (($indices) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($indices) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + 112|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = ($7|0)==($10|0);
  if (!($11)) {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $12 = (__ZN6il2cpp2vm9Exception20GetArgumentExceptionEPKcS3_(0,0)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($12);
 }
 $13 = (($indices) + 16|0);
 $14 = (($__this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $24 = HEAP32[$13>>2]|0;
  $25 = ($24|0)<(0);
  if ($25) {
   label = 11;
  } else {
   $26 = (($__this) + 12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($24>>>0)<($27>>>0);
   if ($28) {
    $35 = $24;
   } else {
    label = 11;
   }
  }
  if ((label|0) == 11) {
   $29 = (__ZN6il2cpp2vm9Exception27GetIndexOutOfRangeExceptionEv()|0);
   __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($29);
   $$pre = HEAP32[$13>>2]|0;
   $35 = $$pre;
  }
  $30 = HEAP32[$__this>>2]|0;
  $31 = (($__this) + 16|0);
  $32 = (($30) + 92|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = Math_imul($33, $35)|0;
  $36 = (($31) + ($34)|0);
  $37 = (($30) + 28|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 113|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $43 = HEAP32[$36>>2]|0;
   $$0 = $43;
   STACKTOP = sp;return ($$0|0);
  } else {
   $42 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv($38,$36)|0);
   $$0 = $42;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $17 = (($2) + 112|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $20 = HEAP32[$13>>2]|0;
  $21 = (($15) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) - ($22))|0;
  $pos$0$lcssa = $23;
 } else {
  $47 = $15;$89 = $18;$i$05 = 0;
  while(1) {
   $44 = (($13) + ($i$05<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ((($47) + ($i$05<<3)|0) + 4|0);
   $48 = HEAP32[$46>>2]|0;
   $49 = ($45|0)<($48|0);
   if ($49) {
    label = 17;
   } else {
    $50 = (($47) + ($i$05<<3)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) + ($48))|0;
    $53 = ($45>>>0)<($52>>>0);
    if ($53) {
     $57 = $89;
    } else {
     label = 17;
    }
   }
   if ((label|0) == 17) {
    label = 0;
    $54 = (__ZN6il2cpp2vm9Exception27GetIndexOutOfRangeExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($54);
    $$pre10 = HEAP8[$17>>0]|0;
    $57 = $$pre10;
   }
   $55 = (($i$05) + 1)|0;
   $56 = $57&255;
   $58 = ($55|0)<($56|0);
   $$pre14 = HEAP32[$14>>2]|0;
   if ($58) {
    $47 = $$pre14;$89 = $57;$i$05 = $55;
   } else {
    break;
   }
  }
  $59 = HEAP32[$13>>2]|0;
  $60 = (($$pre14) + 4|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) - ($61))|0;
  $63 = ($57&255)>(1);
  if ($63) {
   $64 = $57&255;
   $i$13 = 1;$pos$04 = $62;
   while(1) {
    $65 = (($$pre14) + ($i$13<<3)|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = Math_imul($66, $pos$04)|0;
    $68 = (($13) + ($i$13<<2)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($67) + ($69))|0;
    $71 = ((($$pre14) + ($i$13<<3)|0) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) - ($72))|0;
    $74 = (($i$13) + 1)|0;
    $75 = ($74|0)<($64|0);
    if ($75) {
     $i$13 = $74;$pos$04 = $73;
    } else {
     $pos$0$lcssa = $73;
     break;
    }
   }
  } else {
   $pos$0$lcssa = $62;
  }
 }
 $76 = HEAP32[$__this>>2]|0;
 $77 = (($__this) + 16|0);
 $78 = (($76) + 92|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = Math_imul($79, $pos$0$lcssa)|0;
 $81 = (($77) + ($80)|0);
 $82 = (($76) + 28|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($83) + 113|0);
 $85 = HEAP8[$84>>0]|0;
 $86 = ($85<<24>>24)==(0);
 if ($86) {
  $88 = HEAP32[$81>>2]|0;
  $$0 = $88;
  STACKTOP = sp;return ($$0|0);
 } else {
  $87 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv($83,$81)|0);
  $$0 = $87;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System5Array12GetValueImplEP11Il2CppArrayi($__this,$pos) {
 $__this = $__this|0;
 $pos = $pos|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($__this) + 16|0);
 $2 = (($0) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_imul($3, $pos)|0;
 $5 = (($1) + ($4)|0);
 $6 = (($0) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 113|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $12 = HEAP32[$5>>2]|0;
  $$0 = $12;
  STACKTOP = sp;return ($$0|0);
 } else {
  $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv($7,$5)|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System5Array8SetValueEP11Il2CppArrayP12Il2CppObjectS5_($__this,$value,$idxs) {
 $__this = $__this|0;
 $value = $value|0;
 $idxs = $idxs|0;
 var $$pre = 0, $$pre10 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i$12 = 0, $pos$0$lcssa = 0, $pos$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($idxs|0)==(0|0);
 if ($0) {
  $1 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(73368)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 }
 $2 = HEAP32[$__this>>2]|0;
 $3 = (($idxs) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($idxs) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + 112|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = ($7|0)==($10|0);
  if (!($11)) {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $12 = (__ZN6il2cpp2vm9Exception20GetArgumentExceptionEPKcS3_(0,0)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($12);
 }
 $13 = (($idxs) + 16|0);
 $14 = (($__this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $24 = HEAP32[$13>>2]|0;
  $25 = ($24|0)<(0);
  if ($25) {
   label = 11;
  } else {
   $26 = (($__this) + 12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($24>>>0)<($27>>>0);
   if ($28) {
    $30 = $24;
   } else {
    label = 11;
   }
  }
  if ((label|0) == 11) {
   $29 = (__ZN6il2cpp2vm9Exception27GetIndexOutOfRangeExceptionEv()|0);
   __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($29);
   $$pre = HEAP32[$13>>2]|0;
   $30 = $$pre;
  }
  __ZN6il2cpp6icalls8mscorlib6System5Array12SetValueImplEP11Il2CppArrayP12Il2CppObjecti($__this,$value,$30);
  STACKTOP = sp;return;
 }
 $17 = (($2) + 112|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $20 = HEAP32[$13>>2]|0;
  $21 = (($15) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) - ($22))|0;
  $pos$0$lcssa = $23;
 } else {
  $34 = $15;$63 = $18;$i$03 = 0;
  while(1) {
   $31 = (($13) + ($i$03<<2)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($34) + ($i$03<<3)|0) + 4|0);
   $35 = HEAP32[$33>>2]|0;
   $36 = ($32|0)<($35|0);
   if ($36) {
    label = 15;
   } else {
    $37 = (($34) + ($i$03<<3)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + ($35))|0;
    $40 = ($32|0)<($39|0);
    if ($40) {
     $44 = $63;
    } else {
     label = 15;
    }
   }
   if ((label|0) == 15) {
    label = 0;
    $41 = (__ZN6il2cpp2vm9Exception27GetIndexOutOfRangeExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($41);
    $$pre8 = HEAP8[$17>>0]|0;
    $44 = $$pre8;
   }
   $42 = (($i$03) + 1)|0;
   $43 = $44&255;
   $45 = ($42|0)<($43|0);
   $$pre10 = HEAP32[$14>>2]|0;
   if ($45) {
    $34 = $$pre10;$63 = $44;$i$03 = $42;
   } else {
    break;
   }
  }
  $46 = HEAP32[$13>>2]|0;
  $47 = (($$pre10) + 4|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) - ($48))|0;
  $50 = ($44&255)>(1);
  if ($50) {
   $51 = $44&255;
   $i$12 = 1;$pos$01 = $49;
   while(1) {
    $52 = (($$pre10) + ($i$12<<3)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = Math_imul($53, $pos$01)|0;
    $55 = (($13) + ($i$12<<2)|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($54) + ($56))|0;
    $58 = ((($$pre10) + ($i$12<<3)|0) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($57) - ($59))|0;
    $61 = (($i$12) + 1)|0;
    $62 = ($61|0)<($51|0);
    if ($62) {
     $i$12 = $61;$pos$01 = $60;
    } else {
     $pos$0$lcssa = $60;
     break;
    }
   }
  } else {
   $pos$0$lcssa = $49;
  }
 }
 __ZN6il2cpp6icalls8mscorlib6System5Array12SetValueImplEP11Il2CppArrayP12Il2CppObjecti($__this,$value,$pos$0$lcssa);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System5Array12SetValueImplEP11Il2CppArrayP12Il2CppObjecti($__this,$value,$index) {
 $__this = $__this|0;
 $value = $value|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$value>>2]|0;
 $4 = (__ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_($2,$3)|0);
 if (!($4)) {
  $5 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($5);
 }
 $6 = HEAP32[$1>>2]|0;
 $7 = (($6) + 113|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $18 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($__this,4,$index)|0);
  HEAP32[$18>>2] = $value;
  STACKTOP = sp;return;
 } else {
  $10 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($value)|0);
  $11 = HEAP32[$1>>2]|0;
  $12 = (($11) + 92|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($__this,$13,$index)|0);
  $15 = HEAP32[$1>>2]|0;
  $16 = (($15) + 92|0);
  $17 = HEAP32[$16>>2]|0;
  _memcpy(($14|0),($10|0),($17|0))|0;
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp6icalls8mscorlib6System6Buffer17BlockCopyInternalEP11Il2CppArrayiS5_ii($src,$src_offset,$dest,$dest_offset,$count) {
 $src = $src|0;
 $src_offset = $src_offset|0;
 $dest = $dest|0;
 $dest_offset = $dest_offset|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($src|0)==(0|0);
 if ($0) {
  $1 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(73376)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 }
 $2 = ($dest|0)==(0|0);
 if ($2) {
  $3 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(73384)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
 }
 $4 = (__ZN6il2cpp2vm5Array13GetByteLengthEP11Il2CppArray($src)|0);
 $5 = (($4) - ($count))|0;
 $6 = ($5>>>0)<($src_offset>>>0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__ZN6il2cpp2vm5Array13GetByteLengthEP11Il2CppArray($dest)|0);
 $8 = (($7) - ($count))|0;
 $9 = ($8>>>0)<($dest_offset>>>0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[$src>>2]|0;
 $11 = (($10) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 88|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($src,$14,0)|0);
 $16 = (($15) + ($src_offset)|0);
 $17 = HEAP32[$dest>>2]|0;
 $18 = (($17) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 88|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($dest,$21,0)|0);
 $23 = (($22) + ($dest_offset)|0);
 $24 = ($src|0)==($dest|0);
 if ($24) {
  _memmove(($23|0),($16|0),($count|0))|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  _memcpy(($23|0),($16|0),($count|0))|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System6Buffer18ByteLengthInternalEP11Il2CppArray($arr) {
 $arr = $arr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Array13GetByteLengthEP11Il2CppArray($arr)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6Buffer15GetByteInternalEP11Il2CppArrayi($arr,$idx) {
 $arr = $arr|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($arr,1,$idx)|0);
 $1 = HEAP8[$0>>0]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6Buffer15SetByteInternalEP11Il2CppArrayii($arr,$idx,$value) {
 $arr = $arr|0;
 $idx = $idx|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($arr,1,$idx)|0);
 $1 = $value&255;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System4Char20GetDataTablePointersEPPhS5_PPdPPtS9_S9_S9_($category_data,$numeric_data,$numeric_data_values,$to_lower_data_low,$to_lower_data_high,$to_upper_data_low,$to_upper_data_high) {
 $category_data = $category_data|0;
 $numeric_data = $numeric_data|0;
 $numeric_data_values = $numeric_data_values|0;
 $to_lower_data_low = $to_lower_data_low|0;
 $to_lower_data_high = $to_lower_data_high|0;
 $to_upper_data_low = $to_upper_data_low|0;
 $to_upper_data_high = $to_upper_data_high|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$category_data>>2] = 73392;
 HEAP32[$numeric_data>>2] = 145072;
 HEAP32[$numeric_data_values>>2] = 158016;
 HEAP32[$to_lower_data_low>>2] = 158480;
 HEAP32[$to_lower_data_high>>2] = 177328;
 HEAP32[$to_upper_data_low>>2] = 177776;
 HEAP32[$to_upper_data_high>>2] = 196680;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Convert24InternalFromBase64StringEP12Il2CppStringb($str,$allowWhitespaceOnly) {
 $str = $str|0;
 $allowWhitespaceOnly = $allowWhitespaceOnly|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($str) + 12|0);
 $1 = (($str) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp6icalls8mscorlib6System7Convert17Base64ToByteArrayEPtib($0,$2,$allowWhitespaceOnly)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Convert17Base64ToByteArrayEPtib($start,$length,$allowWhitespaceOnly) {
 $start = $start|0;
 $length = $length|0;
 $allowWhitespaceOnly = $allowWhitespaceOnly|0;
 var $$ = 0, $$0 = 0, $$last$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $a = 0, $b = 0, $exitcond = 0, $i$012 = 0, $i$19 = 0, $i$2$lcssa = 0, $i$2$ph = 0, $i$2$us = 0, $i$3$lcssa = 0, $i$38 = 0, $ignored$0$ = 0;
 var $ignored$0$lcssa = 0, $ignored$011 = 0, $ignored$1 = 0, $k$0$ph = 0, $last$0$lcssa = 0, $last$0$prev_last$0 = 0, $last$013 = 0, $last$1 = 0, $olength$1 = 0, $or$cond = 0, $or$cond3 = 0, $prev2_last$0$lcssa = 0, $prev2_last$015 = 0, $prev2_last$1 = 0, $prev_last$0$lcssa = 0, $prev_last$0$prev2_last$0 = 0, $prev_last$014 = 0, $prev_last$1 = 0, $res_ptr$010 = 0, $res_ptr$1 = 0;
 var $res_ptr$2$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $a = sp + 16|0;
 $b = sp;
 $0 = ($length|0)>(0);
 if ($0) {
  $i$012 = 0;$ignored$011 = 0;$last$013 = 0;$prev2_last$015 = 0;$prev_last$014 = 0;
  while(1) {
   $1 = (($start) + ($i$012<<1)|0);
   $2 = HEAP16[$1>>1]|0;
   $3 = ($2&65535)>(122);
   if ($3) {
    $4 = (__ZN6il2cpp2vm9Exception18GetFormatExceptionEPKc(197256)|0);
    _il2cpp_raise_exception($4);
    $ignored$1 = $ignored$011;$last$1 = $last$013;$prev2_last$1 = $prev2_last$015;$prev_last$1 = $prev_last$014;
   } else {
    $5 = $2&65535;
    $6 = (_isspace($5)|0);
    $7 = ($6|0)==(0);
    $8 = $7&1;
    $9 = $8 ^ 1;
    $ignored$0$ = (($9) + ($ignored$011))|0;
    $$last$0 = $7 ? $2 : $last$013;
    $last$0$prev_last$0 = $7 ? $last$013 : $prev_last$014;
    $prev_last$0$prev2_last$0 = $7 ? $prev_last$014 : $prev2_last$015;
    $ignored$1 = $ignored$0$;$last$1 = $$last$0;$prev2_last$1 = $prev_last$0$prev2_last$0;$prev_last$1 = $last$0$prev_last$0;
   }
   $10 = (($i$012) + 1)|0;
   $exitcond = ($10|0)==($length|0);
   if ($exitcond) {
    $ignored$0$lcssa = $ignored$1;$last$0$lcssa = $last$1;$prev2_last$0$lcssa = $prev2_last$1;$prev_last$0$lcssa = $prev_last$1;
    break;
   } else {
    $i$012 = $10;$ignored$011 = $ignored$1;$last$013 = $last$1;$prev2_last$015 = $prev2_last$1;$prev_last$014 = $prev_last$1;
   }
  }
 } else {
  $ignored$0$lcssa = 0;$last$0$lcssa = 0;$prev2_last$0$lcssa = 0;$prev_last$0$lcssa = 0;
 }
 $11 = (($length) - ($ignored$0$lcssa))|0;
 $12 = ($ignored$0$lcssa|0)==($length|0);
 $or$cond3 = $12 & $allowWhitespaceOnly;
 if ($or$cond3) {
  $13 = HEAP32[((388944 + 8|0))>>2]|0;
  $14 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($13,0)|0);
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = $11 & 3;
 $16 = ($15|0)!=(0);
 $17 = ($11|0)<(1);
 $or$cond = $16 | $17;
 if ($or$cond) {
  $18 = (__ZN6il2cpp2vm9Exception18GetFormatExceptionEPKc(197288)|0);
  _il2cpp_raise_exception($18);
 }
 $19 = ($prev2_last$0$lcssa<<16>>16)==(61);
 if ($19) {
  $20 = (__ZN6il2cpp2vm9Exception18GetFormatExceptionEPKc(197304)|0);
  _il2cpp_raise_exception($20);
 }
 $21 = ($11*3)|0;
 $22 = (($21|0) / 4)&-1;
 $23 = ($last$0$lcssa<<16>>16)==(61);
 $24 = $23 << 31 >> 31;
 $25 = ($prev_last$0$lcssa<<16>>16)==(61);
 $26 = $25 << 31 >> 31;
 $$ = (($26) + ($24))|0;
 $olength$1 = (($$) + ($22))|0;
 $27 = HEAP32[((388944 + 8|0))>>2]|0;
 $28 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($27,$olength$1)|0);
 $29 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($28,1,0)|0);
 if (!($0)) {
  $$0 = $28;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (($b) + 4|0);
 $31 = (($a) + 8|0);
 $32 = (($a) + 12|0);
 $33 = (($b) + 8|0);
 $34 = (($b) + 12|0);
 $i$19 = 0;$res_ptr$010 = $29;
 while(1) {
  $i$2$ph = $i$19;$k$0$ph = 0;
  L24: while(1) {
   $36 = ($k$0$ph|0)<(4);
   if ($36) {
    $i$2$us = $i$2$ph;
   } else {
    $i$2$lcssa = $i$2$ph;
    break;
   }
   while(1) {
    $37 = ($i$2$us|0)<($length|0);
    if (!($37)) {
     $i$2$lcssa = $i$2$us;
     break L24;
    }
    $38 = (($i$2$us) + 1)|0;
    $39 = (($start) + ($i$2$us<<1)|0);
    $40 = HEAP16[$39>>1]|0;
    $41 = $40&65535;
    $42 = (_isspace($41)|0);
    $43 = ($42|0)==(0);
    if ($43) {
     break;
    } else {
     $i$2$us = $38;
    }
   }
   $44 = $41 & 255;
   $45 = (($a) + ($k$0$ph<<2)|0);
   HEAP32[$45>>2] = $44;
   $46 = (197128 + ($41)|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = $47&255;
   $49 = (($b) + ($k$0$ph<<2)|0);
   HEAP32[$49>>2] = $48;
   $50 = $48 & 128;
   $51 = ($50|0)==(0);
   if (!($51)) {
    $52 = (__ZN6il2cpp2vm9Exception18GetFormatExceptionEPKc(197256)|0);
    _il2cpp_raise_exception($52);
   }
   $53 = (($k$0$ph) + 1)|0;
   $i$2$ph = $38;$k$0$ph = $53;
  }
  $54 = HEAP32[$b>>2]|0;
  $55 = $54 << 2;
  $56 = HEAP32[$30>>2]|0;
  $57 = $56 >>> 4;
  $58 = $57 | $55;
  $59 = $58&255;
  $60 = (($res_ptr$010) + 1|0);
  HEAP8[$res_ptr$010>>0] = $59;
  $61 = HEAP32[$31>>2]|0;
  $62 = ($61|0)==(61);
  if ($62) {
   $res_ptr$1 = $60;
  } else {
   $63 = HEAP32[$30>>2]|0;
   $64 = $63 << 4;
   $65 = HEAP32[$33>>2]|0;
   $66 = $65 >>> 2;
   $67 = $66 | $64;
   $68 = $67&255;
   $69 = (($res_ptr$010) + 2|0);
   HEAP8[$60>>0] = $68;
   $res_ptr$1 = $69;
  }
  $70 = HEAP32[$32>>2]|0;
  $71 = ($70|0)==(61);
  if ($71) {
   $res_ptr$2$ph = $res_ptr$1;
  } else {
   $72 = HEAP32[$33>>2]|0;
   $73 = $72 << 6;
   $74 = HEAP32[$34>>2]|0;
   $75 = $73 | $74;
   $76 = $75&255;
   $77 = (($res_ptr$1) + 1|0);
   HEAP8[$res_ptr$1>>0] = $76;
   $res_ptr$2$ph = $77;
  }
  $78 = ($i$2$lcssa|0)<($length|0);
  L40: do {
   if ($78) {
    $i$38 = $i$2$lcssa;
    while(1) {
     $81 = (($start) + ($i$38<<1)|0);
     $82 = HEAP16[$81>>1]|0;
     $83 = $82&65535;
     $84 = (_isspace($83)|0);
     $85 = ($84|0)==(0);
     $80 = (($i$38) + 1)|0;
     if ($85) {
      $i$3$lcssa = $i$38;
      break L40;
     }
     $79 = ($80|0)<($length|0);
     if ($79) {
      $i$38 = $80;
     } else {
      $i$3$lcssa = $80;
      break;
     }
    }
   } else {
    $i$3$lcssa = $i$2$lcssa;
   }
  } while(0);
  $35 = ($i$3$lcssa|0)<($length|0);
  if ($35) {
   $i$19 = $i$3$lcssa;$res_ptr$010 = $res_ptr$2$ph;
  } else {
   $$0 = $28;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Convert27InternalFromBase64CharArrayEP11Il2CppArrayii($chars,$offset,$length) {
 $chars = $chars|0;
 $offset = $offset|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($chars,2,$offset)|0);
 $1 = (__ZN6il2cpp6icalls8mscorlib6System7Convert17Base64ToByteArrayEPtib($0,$length,0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System21CurrentSystemTimeZone15GetTimeZoneDataEiPP11Il2CppArrayS6_($year,$data,$names) {
 $year = $year|0;
 $data = $data|0;
 $names = $names|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $dataTemp = 0, $i$012 = 0, $i1$07 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $namesTemp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $dataTemp = sp;
 $namesTemp = sp + 32|0;
 ;HEAP32[$namesTemp+0>>2]=0|0;HEAP32[$namesTemp+4>>2]=0|0;HEAP32[$namesTemp+8>>2]=0|0;HEAP32[$namesTemp+12>>2]=0|0;HEAP32[$namesTemp+16>>2]=0|0;HEAP32[$namesTemp+20>>2]=0|0;
 $0 = ($data|0)==(0|0);
 if ($0) {
  __THREW__ = 0;
  $1 = (invoke_ii(2989,(197320|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   label = 6;
  } else {
   __THREW__ = 0;
   invoke_vi(3302,($1|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    label = 6;
   } else {
    label = 8;
   }
  }
 } else {
  label = 8;
 }
 L4: do {
  if ((label|0) == 8) {
   $16 = ($names|0)==(0|0);
   if ($16) {
    __THREW__ = 0;
    $17 = (invoke_ii(2989,(197328|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($17|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 6;
     break;
    }
   }
   $22 = HEAP32[((388944 + 48|0))>>2]|0;
   __THREW__ = 0;
   $23 = (invoke_iii(2229,($22|0),4)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 6;
   } else {
    HEAP32[$data>>2] = $23;
    $26 = HEAP32[((388944 + 68|0))>>2]|0;
    __THREW__ = 0;
    $27 = (invoke_iii(2229,($26|0),2)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 6;
    } else {
     HEAP32[$names>>2] = $27;
     __THREW__ = 0;
     $30 = (invoke_iiii(1476,($year|0),($dataTemp|0),($namesTemp|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      label = 6;
     } else {
      L13: do {
       if ($30) {
        $i$012 = 0;
        while(1) {
         $33 = HEAP32[$data>>2]|0;
         __THREW__ = 0;
         $34 = (invoke_iiii(1477,($33|0),8,($i$012|0))|0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          label = 5;
          break;
         }
         $37 = (($dataTemp) + ($i$012<<3)|0);
         $38 = $37;
         $39 = $38;
         $40 = HEAP32[$39>>2]|0;
         $41 = (($38) + 4)|0;
         $42 = $41;
         $43 = HEAP32[$42>>2]|0;
         $44 = $34;
         $45 = $44;
         HEAP32[$45>>2] = $40;
         $46 = (($44) + 4)|0;
         $47 = $46;
         HEAP32[$47>>2] = $43;
         $48 = (($i$012) + 1)|0;
         $49 = ($48|0)<(4);
         if ($49) {
          $i$012 = $48;
         } else {
          $i1$07 = 0;
          break;
         }
        }
        if ((label|0) == 5) {
         $8 = ___cxa_find_matching_catch()|0;
         $9 = tempRet0;
         $lpad$phi$index = $8;$lpad$phi$index3 = $9;
         break L4;
        }
        while(1) {
         $50 = HEAP32[$names>>2]|0;
         __THREW__ = 0;
         $51 = (invoke_iiii(1477,($50|0),4,($i1$07|0))|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break;
         }
         $54 = (($namesTemp) + (($i1$07*12)|0)|0);
         $55 = HEAP8[$54>>0]|0;
         $56 = $55 & 1;
         $57 = ($56<<24>>24)==(0);
         if ($57) {
          $60 = (($54) + 1|0);
          $61 = $60;
         } else {
          $58 = ((($namesTemp) + (($i1$07*12)|0)|0) + 8|0);
          $59 = HEAP32[$58>>2]|0;
          $61 = $59;
         }
         __THREW__ = 0;
         $62 = (invoke_ii(2990,($61|0))|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break;
         }
         HEAP32[$51>>2] = $62;
         $65 = (($i1$07) + 1)|0;
         $66 = ($65|0)<(2);
         if ($66) {
          $i1$07 = $65;
         } else {
          $$0 = 1;
          break L13;
         }
        }
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index3 = $7;
        break L4;
       } else {
        $$0 = 0;
       }
      } while(0);
      $67 = (($namesTemp) + 12|0);
      $68 = HEAP8[$67>>0]|0;
      $69 = $68 & 1;
      $70 = ($69<<24>>24)==(0);
      if (!($70)) {
       $71 = (($namesTemp) + 20|0);
       $72 = HEAP32[$71>>2]|0;
       __ZdlPv($72);
      }
      $73 = HEAP8[$namesTemp>>0]|0;
      $74 = $73 & 1;
      $75 = ($74<<24>>24)==(0);
      if ($75) {
       STACKTOP = sp;return ($$0|0);
      }
      $83 = (($namesTemp) + 8|0);
      $84 = HEAP32[$83>>2]|0;
      __ZdlPv($84);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index3 = $11;
 }
 $12 = (($namesTemp) + 12|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  $76 = (($namesTemp) + 20|0);
  $77 = HEAP32[$76>>2]|0;
  __ZdlPv($77);
 }
 $78 = HEAP8[$namesTemp>>0]|0;
 $79 = $78 & 1;
 $80 = ($79<<24>>24)==(0);
 if ($80) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $81 = (($namesTemp) + 8|0);
 $82 = HEAP32[$81>>2]|0;
 __ZdlPv($82);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8DateTime6GetNowEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os4Time30GetTicks100NanosecondsDateTimeEv()|0);
 $1 = tempRet0;
 tempRet0 = $1;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8DateTime16GetTimeMonotonicEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os4Time31GetTicks100NanosecondsMonotonicEv()|0);
 $1 = tempRet0;
 tempRet0 = $1;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal18decimalSetExponentEP19il2cpp_decimal_repri($pA,$texp) {
 $pA = $pA|0;
 $texp = $texp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ahi = 0, $alo = 0, $fold = 0, $or$cond$i = 0, $scale = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $scale = sp + 16|0;
 $alo = sp;
 $ahi = sp + 8|0;
 $0 = HEAP32[$pA>>2]|0;
 $1 = $0 >>> 16;
 $2 = $1 & 255;
 $3 = (($2) - ($texp))|0;
 HEAP32[$scale>>2] = $3;
 $4 = ($3>>>0)>(28);
 if (!($4)) {
  $fold = (($1) - ($texp))|0;
  $47 = $fold << 16;
  $48 = $47 & 16711680;
  $49 = $0 & -16711681;
  $50 = $49 | $48;
  HEAP32[$pA>>2] = $50;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($pA) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($pA) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $alo;
 $10 = $9;
 HEAP32[$10>>2] = $8;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $6;
 $13 = (($pA) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $ahi;
 $16 = $15;
 HEAP32[$16>>2] = $14;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = 0;
 $19 = (__ZL10rescale128PyS_Piiiii($alo,$ahi,$scale,0,28,1)|0);
 $20 = ($19|0)==(0);
 if (!($20)) {
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = $alo;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 4)|0;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = $ahi;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + 4)|0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$scale>>2]|0;
 $34 = ($33>>>0)>(28);
 $35 = ($32>>>0)>(0);
 $36 = ($32|0)==(0);
 $37 = ($29>>>0)>(4294967295);
 $38 = $36 & $37;
 $39 = $35 | $38;
 $or$cond$i = $34 | $39;
 if ($or$cond$i) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = HEAP32[$pA>>2]|0;
 $41 = $40 & -2147483648;
 HEAP32[$7>>2] = $23;
 HEAP32[$5>>2] = $26;
 HEAP32[$13>>2] = $29;
 $42 = $40 & 2130771967;
 $43 = $33 << 16;
 $44 = $43 & 16711680;
 $45 = $41 | $44;
 $46 = $45 | $42;
 HEAP32[$pA>>2] = $46;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZL10rescale128PyS_Piiiii($pclo,$pchi,$pScale,$texp,$maxScale,$roundFlag) {
 $pclo = $pclo|0;
 $pchi = $pchi|0;
 $pScale = $pScale|0;
 $texp = $texp|0;
 $maxScale = $maxScale|0;
 $roundFlag = $roundFlag|0;
 var $$ = 0, $$$13 = 0, $$0 = 0, $$0$i = 0, $$0233 = 0, $$1 = 0, $$1$us = 0, $$13$lcssa = 0, $$13$ph = 0, $$1325 = 0, $$2$ph = 0, $$2$ph62 = 0, $$218 = 0, $$3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$0$i = 0, $i$1 = 0;
 var $or$cond = 0, $overhang$0$ph = 0, $overhang$024 = 0, $roundBit$034 = 0, $roundBit$1$lcssa = 0, $roundBit$126 = 0, $roundBit$2 = 0, $roundBit$3$ph63 = 0, $roundBit$319 = 0, $roundBit$4 = 0, $roundBit$5$lcssa = 0, $roundBit$5$ph = 0, $roundBit$6$lcssa = 0, $roundBit$611 = 0, $scale$0$lcssa = 0, $scale$0$lcssa61 = 0, $scale$032 = 0, $scale$1$lcssa = 0, $scale$1$ph = 0, $scale$114 = 0;
 var $scale$2$lcssa = 0, $scale$210 = 0, $scale$210$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$pScale>>2]|0;
 $1 = ($texp|0)>(0);
 do {
  if ($1) {
   $2 = ($0|0)>($maxScale|0);
   if ($2) {
    $$2$ph62 = $texp;$roundBit$3$ph63 = 0;$scale$0$lcssa61 = $0;
   } else {
    $3 = $pchi;
    $4 = $3;
    $5 = HEAP32[$4>>2]|0;
    $6 = (($3) + 4)|0;
    $7 = $6;
    $8 = HEAP32[$7>>2]|0;
    $$0233 = $texp;$12 = $8;$36 = $5;$roundBit$034 = 0;$scale$032 = $0;
    while(1) {
     $11 = ($12|0)==(0);
     if ($11) {
      $$13$ph = $$0233;$overhang$0$ph = 0;
     } else {
      $i$0$i = 32;
      while(1) {
       $13 = ($i$0$i|0)>(0);
       if (!($13)) {
        $$0$i = -1;
        break;
       }
       $14 = (($i$0$i) + -1)|0;
       $15 = 1 << $14;
       $16 = $15 & $12;
       $17 = ($16|0)==(0);
       if ($17) {
        $i$0$i = $14;
       } else {
        $$0$i = $14;
        break;
       }
      }
      $18 = (($$0$i) + -11)|0;
      $19 = ($18|0)<($$0233|0);
      $20 = (($$0233) + -1)|0;
      $$3 = $19 ? $18 : $20;
      $21 = ($$3|0)>(0);
      if ($21) {
       $22 = (($$0233) - ($$3))|0;
       $23 = $pclo;
       $24 = $23;
       $25 = HEAP32[$24>>2]|0;
       $26 = (($23) + 4)|0;
       $27 = $26;
       $28 = HEAP32[$27>>2]|0;
       $29 = (_bitshift64Lshr(($25|0),($28|0),($$3|0))|0);
       $30 = tempRet0;
       $31 = 1 << $$3;
       $32 = (($31) + -1)|0;
       $33 = ($32|0)<(0);
       $34 = $33 << 31 >> 31;
       $35 = $36 & $32;
       $37 = $12 & $34;
       $38 = (64 - ($$3))|0;
       $39 = (_bitshift64Shl(($35|0),($37|0),($38|0))|0);
       $40 = tempRet0;
       $41 = $39 | $29;
       $42 = $40 | $30;
       $43 = $pclo;
       $44 = $43;
       HEAP32[$44>>2] = $41;
       $45 = (($43) + 4)|0;
       $46 = $45;
       HEAP32[$46>>2] = $42;
       $47 = $pchi;
       $48 = $47;
       $49 = HEAP32[$48>>2]|0;
       $50 = (($47) + 4)|0;
       $51 = $50;
       $52 = HEAP32[$51>>2]|0;
       $53 = (_bitshift64Lshr(($49|0),($52|0),($$3|0))|0);
       $54 = tempRet0;
       $55 = $pchi;
       $56 = $55;
       HEAP32[$56>>2] = $53;
       $57 = (($55) + 4)|0;
       $58 = $57;
       HEAP32[$58>>2] = $54;
       $59 = $12 >>> $$3;
       $$13$ph = $22;$overhang$0$ph = $59;
      } else {
       $$13$ph = $$0233;$overhang$0$ph = $12;
      }
     }
     $60 = ($$13$ph|0)>(0);
     L14: do {
      if ($60) {
       $$1325 = $$13$ph;$overhang$024 = $overhang$0$ph;$roundBit$126 = $roundBit$034;
       while(1) {
        $61 = ($overhang$024>>>0)>(1024);
        if (!($61)) {
         $62 = $pclo;
         $63 = $62;
         $64 = HEAP32[$63>>2]|0;
         $65 = (($62) + 4)|0;
         $66 = $65;
         $67 = HEAP32[$66>>2]|0;
         $68 = $64 & 1;
         $69 = ($68|0)==(0);
         $70 = (0)==(0);
         $71 = $69 & $70;
         if (!($71)) {
          $$13$lcssa = $$1325;$roundBit$1$lcssa = $roundBit$126;
          break L14;
         }
        }
        $72 = (($$1325) + -1)|0;
        $73 = ($72|0)==(0);
        $74 = $pclo;
        $75 = $74;
        $76 = HEAP32[$75>>2]|0;
        $77 = (($74) + 4)|0;
        $78 = $77;
        $79 = HEAP32[$78>>2]|0;
        if ($73) {
         $80 = $76 & 1;
         $roundBit$2 = $80;
        } else {
         $roundBit$2 = $roundBit$126;
        }
        $81 = (_bitshift64Lshr(($76|0),($79|0),1)|0);
        $82 = tempRet0;
        $83 = $pclo;
        $84 = $83;
        HEAP32[$84>>2] = $81;
        $85 = (($83) + 4)|0;
        $86 = $85;
        HEAP32[$86>>2] = $82;
        $87 = $pchi;
        $88 = $87;
        $89 = HEAP32[$88>>2]|0;
        $90 = (($87) + 4)|0;
        $91 = $90;
        $92 = HEAP32[$91>>2]|0;
        $93 = (_bitshift64Shl(($89|0),($92|0),63)|0);
        $94 = tempRet0;
        $95 = $93 | $81;
        $96 = $94 | $82;
        $97 = $pclo;
        $98 = $97;
        HEAP32[$98>>2] = $95;
        $99 = (($97) + 4)|0;
        $100 = $99;
        HEAP32[$100>>2] = $96;
        $101 = $pchi;
        $102 = $101;
        $103 = HEAP32[$102>>2]|0;
        $104 = (($101) + 4)|0;
        $105 = $104;
        $106 = HEAP32[$105>>2]|0;
        $107 = (_bitshift64Lshr(($103|0),($106|0),1)|0);
        $108 = tempRet0;
        $109 = $pchi;
        $110 = $109;
        HEAP32[$110>>2] = $107;
        $111 = (($109) + 4)|0;
        $112 = $111;
        HEAP32[$112>>2] = $108;
        $113 = $overhang$024 >>> 1;
        $114 = ($72|0)>(0);
        if ($114) {
         $$1325 = $72;$overhang$024 = $113;$roundBit$126 = $roundBit$2;
        } else {
         $$13$lcssa = $72;$roundBit$1$lcssa = $roundBit$2;
         break;
        }
       }
      } else {
       $$13$lcssa = $$13$ph;$roundBit$1$lcssa = $roundBit$034;
      }
     } while(0);
     $115 = ($$13$lcssa|0)>(9);
     $$$13 = $115 ? 9 : $$13$lcssa;
     $116 = (($$$13) + ($scale$032))|0;
     $117 = ($116|0)>($maxScale|0);
     $118 = (($maxScale) - ($scale$032))|0;
     $i$1 = $117 ? $118 : $$$13;
     $119 = ($i$1|0)==(0);
     if ($119) {
      $$2$ph = $$13$lcssa;$scale$0$lcssa = $scale$032;
      break;
     }
     $120 = (($$13$lcssa) - ($i$1))|0;
     $121 = (($i$1) + ($scale$032))|0;
     $122 = (197336 + ($i$1<<2)|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = $123 >>> $i$1;
     $125 = $pclo;
     $126 = $125;
     $127 = HEAP32[$126>>2]|0;
     $128 = (($125) + 4)|0;
     $129 = $128;
     $130 = HEAP32[$129>>2]|0;
     $131 = (___muldi3(($127|0),0,($124|0),0)|0);
     $132 = tempRet0;
     $133 = (___muldi3(($130|0),0,($124|0),0)|0);
     $134 = tempRet0;
     $135 = (_i64Add(($132|0),0,($133|0),($134|0))|0);
     $136 = tempRet0;
     $137 = $pclo;
     $138 = $137;
     HEAP32[$138>>2] = $131;
     $139 = (($137) + 4)|0;
     $140 = $139;
     HEAP32[$140>>2] = $135;
     $141 = $pchi;
     $142 = $141;
     $143 = HEAP32[$142>>2]|0;
     $144 = (($141) + 4)|0;
     $145 = $144;
     $146 = HEAP32[$145>>2]|0;
     $147 = (___muldi3(($143|0),($146|0),($124|0),0)|0);
     $148 = tempRet0;
     $149 = (_i64Add(($147|0),($148|0),($136|0),0)|0);
     $150 = tempRet0;
     $151 = $pchi;
     $152 = $151;
     HEAP32[$152>>2] = $149;
     $153 = (($151) + 4)|0;
     $154 = $153;
     HEAP32[$154>>2] = $150;
     $155 = ($120|0)<(1);
     $156 = ($121|0)>($maxScale|0);
     $or$cond = $155 | $156;
     if ($or$cond) {
      $$2$ph = $120;$scale$0$lcssa = $121;
      break;
     } else {
      $$0233 = $120;$12 = $150;$36 = $149;$roundBit$034 = $roundBit$1$lcssa;$scale$032 = $121;
     }
    }
    $10 = ($$2$ph|0)>(0);
    if ($10) {
     $$2$ph62 = $$2$ph;$roundBit$3$ph63 = $roundBit$1$lcssa;$scale$0$lcssa61 = $scale$0$lcssa;
    } else {
     $roundBit$5$ph = $roundBit$1$lcssa;$scale$1$ph = $scale$0$lcssa;
     break;
    }
   }
   $$218 = $$2$ph62;$roundBit$319 = $roundBit$3$ph63;
   while(1) {
    $157 = (($$218) + -1)|0;
    $158 = ($157|0)==(0);
    $159 = $pclo;
    $160 = $159;
    $161 = HEAP32[$160>>2]|0;
    $162 = (($159) + 4)|0;
    $163 = $162;
    $164 = HEAP32[$163>>2]|0;
    if ($158) {
     $165 = $161 & 1;
     $roundBit$4 = $165;
    } else {
     $roundBit$4 = $roundBit$319;
    }
    $166 = (_bitshift64Lshr(($161|0),($164|0),1)|0);
    $167 = tempRet0;
    $168 = $pclo;
    $169 = $168;
    HEAP32[$169>>2] = $166;
    $170 = (($168) + 4)|0;
    $171 = $170;
    HEAP32[$171>>2] = $167;
    $172 = $pchi;
    $173 = $172;
    $174 = HEAP32[$173>>2]|0;
    $175 = (($172) + 4)|0;
    $176 = $175;
    $177 = HEAP32[$176>>2]|0;
    $178 = (_bitshift64Shl(($174|0),($177|0),63)|0);
    $179 = tempRet0;
    $180 = $178 | $166;
    $181 = $179 | $167;
    $182 = $pclo;
    $183 = $182;
    HEAP32[$183>>2] = $180;
    $184 = (($182) + 4)|0;
    $185 = $184;
    HEAP32[$185>>2] = $181;
    $186 = $pchi;
    $187 = $186;
    $188 = HEAP32[$187>>2]|0;
    $189 = (($186) + 4)|0;
    $190 = $189;
    $191 = HEAP32[$190>>2]|0;
    $192 = (_bitshift64Lshr(($188|0),($191|0),1)|0);
    $193 = tempRet0;
    $194 = $pchi;
    $195 = $194;
    HEAP32[$195>>2] = $192;
    $196 = (($194) + 4)|0;
    $197 = $196;
    HEAP32[$197>>2] = $193;
    $198 = ($157|0)>(0);
    if ($198) {
     $$218 = $157;$roundBit$319 = $roundBit$4;
    } else {
     $roundBit$5$ph = $roundBit$4;$scale$1$ph = $scale$0$lcssa61;
     break;
    }
   }
  } else {
   $roundBit$5$ph = 0;$scale$1$ph = $0;
  }
 } while(0);
 $9 = ($scale$1$ph|0)>($maxScale|0);
 if ($9) {
  $scale$114 = $scale$1$ph;
  while(1) {
   $248 = (($scale$114) - ($maxScale))|0;
   $249 = ($248|0)>(9);
   $$ = $249 ? 9 : $248;
   $250 = (($scale$114) - ($$))|0;
   $251 = (197336 + ($$<<2)|0);
   $252 = HEAP32[$251>>2]|0;
   $253 = $pchi;
   $254 = $253;
   $255 = HEAP32[$254>>2]|0;
   $256 = (($253) + 4)|0;
   $257 = $256;
   $258 = HEAP32[$257>>2]|0;
   $259 = (___udivdi3(($258|0),0,($252|0),0)|0);
   $260 = tempRet0;
   $261 = (___muldi3(($259|0),($260|0),($252|0),0)|0);
   $262 = tempRet0;
   $263 = (_i64Subtract(($258|0),0,($261|0),($262|0))|0);
   $264 = tempRet0;
   $265 = (___udivdi3(($255|0),($263|0),($252|0),0)|0);
   $266 = tempRet0;
   $267 = (___muldi3(($265|0),($266|0),($252|0),0)|0);
   $268 = tempRet0;
   $269 = (_i64Subtract(($255|0),($258|0),($267|0),($268|0))|0);
   $270 = tempRet0;
   $271 = $pchi;
   $272 = $271;
   HEAP32[$272>>2] = $265;
   $273 = (($271) + 4)|0;
   $274 = $273;
   HEAP32[$274>>2] = $259;
   $275 = $pclo;
   $276 = $275;
   $277 = HEAP32[$276>>2]|0;
   $278 = (($275) + 4)|0;
   $279 = $278;
   $280 = HEAP32[$279>>2]|0;
   $281 = (___udivdi3(($280|0),($269|0),($252|0),0)|0);
   $282 = tempRet0;
   $283 = (___muldi3(($281|0),($282|0),($252|0),0)|0);
   $284 = tempRet0;
   $285 = (_i64Subtract(($280|0),0,($283|0),($284|0))|0);
   $286 = tempRet0;
   $287 = (___udivdi3(($277|0),($285|0),($252|0),0)|0);
   $288 = tempRet0;
   $289 = (___muldi3(($287|0),($288|0),($252|0),0)|0);
   $290 = tempRet0;
   $291 = (_i64Subtract(($277|0),($285|0),($289|0),($290|0))|0);
   $292 = tempRet0;
   $293 = $pclo;
   $294 = $293;
   HEAP32[$294>>2] = $287;
   $295 = (($293) + 4)|0;
   $296 = $295;
   HEAP32[$296>>2] = $281;
   $297 = (_bitshift64Shl(($291|0),($292|0),1)|0);
   $298 = tempRet0;
   $299 = ($298>>>0)<(0);
   $300 = ($298|0)==(0);
   $301 = ($297>>>0)<($252>>>0);
   $302 = $300 & $301;
   $303 = $299 | $302;
   if ($303) {
    $304 = ($297|0)==($252|0);
    $305 = ($298|0)==(0);
    $306 = $304 & $305;
    if ($306) {
     $307 = $287 & 1;
     $308 = ($307|0)!=(0);
     $309 = (0)!=(0);
     $310 = $308 | $309;
     $200 = $310;
    } else {
     $200 = 0;
    }
   } else {
    $200 = 1;
   }
   $311 = ($250|0)>($maxScale|0);
   if ($311) {
    $scale$114 = $250;
   } else {
    break;
   }
  }
  $199 = $200&1;
  $roundBit$5$lcssa = $199;$scale$1$lcssa = $250;
 } else {
  $roundBit$5$lcssa = $roundBit$5$ph;$scale$1$lcssa = $scale$1$ph;
 }
 $201 = ($scale$1$lcssa|0)<(0);
 L42: do {
  if ($201) {
   $202 = ($roundFlag|0)==(0);
   if ($202) {
    $scale$210$us = $scale$1$lcssa;
    while(1) {
     $205 = (0 - ($scale$210$us))|0;
     $206 = ($205|0)>(9);
     $$1$us = $206 ? 9 : $205;
     $207 = (197336 + ($$1$us<<2)|0);
     $208 = HEAP32[$207>>2]|0;
     $209 = $pclo;
     $210 = $209;
     $211 = HEAP32[$210>>2]|0;
     $212 = (($209) + 4)|0;
     $213 = $212;
     $214 = HEAP32[$213>>2]|0;
     $215 = (___muldi3(($211|0),0,($208|0),0)|0);
     $216 = tempRet0;
     $217 = (___muldi3(($214|0),0,($208|0),0)|0);
     $218 = tempRet0;
     $219 = (_i64Add(($216|0),0,($217|0),($218|0))|0);
     $220 = tempRet0;
     $221 = $pclo;
     $222 = $221;
     HEAP32[$222>>2] = $215;
     $223 = (($221) + 4)|0;
     $224 = $223;
     HEAP32[$224>>2] = $219;
     $225 = $pchi;
     $226 = $225;
     $227 = HEAP32[$226>>2]|0;
     $228 = (($225) + 4)|0;
     $229 = $228;
     $230 = HEAP32[$229>>2]|0;
     $231 = (___muldi3(($227|0),0,($208|0),0)|0);
     $232 = tempRet0;
     $233 = (_i64Add(($220|0),0,($231|0),($232|0))|0);
     $234 = tempRet0;
     $235 = (___muldi3(($230|0),0,($208|0),0)|0);
     $236 = tempRet0;
     $237 = (_i64Add(($234|0),0,($235|0),($236|0))|0);
     $238 = tempRet0;
     $239 = $pchi;
     $240 = $239;
     HEAP32[$240>>2] = $233;
     $241 = (($239) + 4)|0;
     $242 = $241;
     HEAP32[$242>>2] = $237;
     $243 = ($238>>>0)<(1);
     $244 = ($238|0)==(1);
     $245 = ($237>>>0)<(0);
     $246 = $244 & $245;
     $247 = $243 | $246;
     $204 = (($$1$us) + ($scale$210$us))|0;
     if (!($247)) {
      $$0 = 2;
      break;
     }
     $203 = ($204|0)<(0);
     if ($203) {
      $scale$210$us = $204;
     } else {
      $roundBit$6$lcssa = 0;$scale$2$lcssa = $204;
      break L42;
     }
    }
    STACKTOP = sp;return ($$0|0);
   } else {
    $roundBit$611 = $roundBit$5$lcssa;$scale$210 = $scale$1$lcssa;
   }
   while(1) {
    $314 = (0 - ($scale$210))|0;
    $315 = ($314|0)>(9);
    $$1 = $315 ? 9 : $314;
    $316 = (197336 + ($$1<<2)|0);
    $317 = HEAP32[$316>>2]|0;
    $318 = $pclo;
    $319 = $318;
    $320 = HEAP32[$319>>2]|0;
    $321 = (($318) + 4)|0;
    $322 = $321;
    $323 = HEAP32[$322>>2]|0;
    $324 = (___muldi3(($320|0),0,($317|0),0)|0);
    $325 = tempRet0;
    $326 = ($roundBit$611|0)==(0);
    if ($326) {
     $332 = $325;$337 = $324;
    } else {
     $327 = $317 >>> 1;
     $328 = (_i64Add(($324|0),($325|0),($327|0),0)|0);
     $329 = tempRet0;
     $332 = $329;$337 = $328;
    }
    $330 = (___muldi3(($323|0),0,($317|0),0)|0);
    $331 = tempRet0;
    $333 = (_i64Add(($332|0),0,($330|0),($331|0))|0);
    $334 = tempRet0;
    $335 = $pclo;
    $336 = $335;
    HEAP32[$336>>2] = $337;
    $338 = (($335) + 4)|0;
    $339 = $338;
    HEAP32[$339>>2] = $333;
    $340 = $pchi;
    $341 = $340;
    $342 = HEAP32[$341>>2]|0;
    $343 = (($340) + 4)|0;
    $344 = $343;
    $345 = HEAP32[$344>>2]|0;
    $346 = (___muldi3(($342|0),0,($317|0),0)|0);
    $347 = tempRet0;
    $348 = (_i64Add(($334|0),0,($346|0),($347|0))|0);
    $349 = tempRet0;
    $350 = (___muldi3(($345|0),0,($317|0),0)|0);
    $351 = tempRet0;
    $352 = (_i64Add(($349|0),0,($350|0),($351|0))|0);
    $353 = tempRet0;
    $354 = $pchi;
    $355 = $354;
    HEAP32[$355>>2] = $348;
    $356 = (($354) + 4)|0;
    $357 = $356;
    HEAP32[$357>>2] = $352;
    $358 = ($353>>>0)<(1);
    $359 = ($353|0)==(1);
    $360 = ($352>>>0)<(0);
    $361 = $359 & $360;
    $362 = $358 | $361;
    $313 = (($$1) + ($scale$210))|0;
    if (!($362)) {
     $$0 = 2;
     break;
    }
    $312 = ($313|0)<(0);
    if ($312) {
     $roundBit$611 = 0;$scale$210 = $313;
    } else {
     $roundBit$6$lcssa = 0;$scale$2$lcssa = $313;
     break L42;
    }
   }
   STACKTOP = sp;return ($$0|0);
  } else {
   $roundBit$6$lcssa = $roundBit$5$lcssa;$scale$2$lcssa = $scale$1$lcssa;
  }
 } while(0);
 HEAP32[$pScale>>2] = $scale$2$lcssa;
 $363 = (__ZL12normalize128PyS_Piii($pclo,$pchi,$pScale,$roundFlag,$roundBit$6$lcssa)|0);
 $$0 = $363;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal14string2decimalEP19il2cpp_decimal_reprP12Il2CppStringji($pA,$str,$decrDecimal,$sign) {
 $pA = $pA|0;
 $str = $str|0;
 $decrDecimal = $decrDecimal|0;
 $sign = $sign|0;
 var $$$i5 = 0, $$0 = 0, $$0$lcssa$i = 0, $$off0 = 0, $$off32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $deltaScale$0$lcssa$i = 0, $deltaScale$03$i = 0, $i$0$lcssa = 0, $i$022 = 0;
 var $i$1 = 0, $i$1$in = 0, $len$031 = 0, $or$cond = 0, $or$cond$i = 0, $overhang$0$be$i = 0, $overhang$06$i = 0, $p$030 = 0, $p$121 = 0, $roundBit$0 = 0, $scale$07$i = 0, $sigLen$024 = 0, $sigLen$1 = 0, $sigLen$2 = 0, $sigLen$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($str)|0);
 ;HEAP32[$pA+0>>2]=0|0;HEAP32[$pA+4>>2]=0|0;HEAP32[$pA+8>>2]=0|0;HEAP32[$pA+12>>2]=0|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(0);
 do {
  if (!($2)) {
   $len$031 = 0;$p$030 = $0;
   while(1) {
    $3 = (($len$031) + 1)|0;
    $4 = (($p$030) + 2|0);
    $5 = HEAP16[$4>>1]|0;
    $6 = ($5<<16>>16)==(0);
    if ($6) {
     break;
    } else {
     $len$031 = $3;$p$030 = $4;
    }
   }
   L5: do {
    if ($2) {
     $102 = 0;$104 = 0;$202 = 0;$203 = 0;$i$0$lcssa = 0;$sigLen$3 = -1;
    } else {
     $54 = 0;$55 = 0;$66 = 0;$67 = 0;$8 = $1;$i$022 = 0;$p$121 = $0;$sigLen$024 = -1;
     while(1) {
      $7 = $8&65535;
      $9 = (($7) + -48)|0;
      $10 = ($9>>>0)>(9);
      if ($10) {
       $$0 = 2;
       label = 43;
       break;
      }
      $11 = ($9|0)==(0);
      if ($11) {
       $204 = $54;$205 = $55;$206 = $66;$207 = $67;$sigLen$2 = $sigLen$024;
      } else {
       $12 = ($sigLen$024|0)<(0);
       if ($12) {
        $13 = (($3) - ($i$022))|0;
        $14 = ($13|0)>(29);
        $15 = (($i$022) + 29)|0;
        $16 = $14 ? $15 : $3;
        $17 = (($16) + 1)|0;
        $18 = ($17>>>0)<($decrDecimal>>>0);
        if ($18) {
         $$0 = 2;
         label = 43;
         break;
        } else {
         $sigLen$1 = $16;
        }
       } else {
        $sigLen$1 = $sigLen$024;
       }
       $19 = ($i$022|0)<($sigLen$1|0);
       if (!($19)) {
        $102 = $66;$104 = $67;$202 = $54;$203 = $55;$i$0$lcssa = $i$022;$sigLen$3 = $sigLen$1;
        break L5;
       }
       $20 = $i$022 ^ -1;
       $21 = (($sigLen$1) + ($20))|0;
       $22 = (197432 + ($21<<4)|0);
       $23 = $22;
       $24 = $23;
       $25 = HEAP32[$24>>2]|0;
       $26 = (($23) + 4)|0;
       $27 = $26;
       $28 = HEAP32[$27>>2]|0;
       $29 = ((197432 + ($21<<4)|0) + 8|0);
       $30 = $29;
       $31 = $30;
       $32 = HEAP32[$31>>2]|0;
       $33 = (($30) + 4)|0;
       $34 = $33;
       $35 = HEAP32[$34>>2]|0;
       $36 = ($9|0)==(1);
       if ($36) {
        $52 = $25;$53 = $28;$64 = $32;$65 = $35;
       } else {
        $37 = (___muldi3(($25|0),0,($9|0),0)|0);
        $38 = tempRet0;
        $39 = (___muldi3(($28|0),0,($9|0),0)|0);
        $40 = tempRet0;
        $41 = (_i64Add(($38|0),0,($39|0),($40|0))|0);
        $42 = tempRet0;
        $43 = (___muldi3(($32|0),($35|0),($9|0),0)|0);
        $44 = tempRet0;
        $45 = (_i64Add(($42|0),0,($43|0),($44|0))|0);
        $46 = tempRet0;
        $47 = ($35>>>0)>($46>>>0);
        $48 = ($35|0)==($46|0);
        $49 = ($32>>>0)>($45>>>0);
        $50 = $48 & $49;
        $51 = $47 | $50;
        if ($51) {
         $$0 = 2;
         label = 43;
         break;
        } else {
         $52 = $37;$53 = $41;$64 = $45;$65 = $46;
        }
       }
       $56 = (_i64Add(($52|0),($53|0),($54|0),($55|0))|0);
       $57 = tempRet0;
       $58 = ($57>>>0)<($53>>>0);
       $59 = ($57|0)==($53|0);
       $60 = ($56>>>0)<($52>>>0);
       $61 = $59 & $60;
       $62 = $58 | $61;
       $63 = $62&1;
       $68 = (_i64Add(($64|0),($65|0),($66|0),($67|0))|0);
       $69 = tempRet0;
       $70 = (_i64Add(($68|0),($69|0),($63|0),0)|0);
       $71 = tempRet0;
       $72 = ($67>>>0)>($71>>>0);
       $73 = ($67|0)==($71|0);
       $74 = ($66>>>0)>($70>>>0);
       $75 = $73 & $74;
       $76 = $72 | $75;
       if ($76) {
        $$0 = 2;
        label = 43;
        break;
       } else {
        $204 = $56;$205 = $57;$206 = $70;$207 = $71;$sigLen$2 = $sigLen$1;
       }
      }
      $77 = (($i$022) + 1)|0;
      $78 = (($p$121) + 2|0);
      $79 = HEAP16[$78>>1]|0;
      $80 = ($79<<16>>16)==(0);
      if ($80) {
       $102 = $206;$104 = $207;$202 = $204;$203 = $205;$i$0$lcssa = $77;$sigLen$3 = $sigLen$2;
       break L5;
      } else {
       $54 = $204;$55 = $205;$66 = $206;$67 = $207;$8 = $79;$i$022 = $77;$p$121 = $78;$sigLen$024 = $sigLen$2;
      }
     }
     if ((label|0) == 43) {
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $81 = (($sigLen$3) - ($decrDecimal))|0;
   $82 = ($i$0$lcssa|0)<($3|0);
   do {
    if ($82) {
     $83 = (($0) + ($i$0$lcssa<<1)|0);
     $84 = HEAP16[$83>>1]|0;
     $85 = $84&65535;
     $86 = (($85) + -48)|0;
     $87 = ($86>>>0)>(9);
     if ($87) {
      $$0 = 2;
      STACKTOP = sp;return ($$0|0);
     }
     $88 = ($86|0)>(5);
     if ($88) {
      $roundBit$0 = 1;
     } else {
      $89 = ($86|0)==(5);
      if ($89) {
       $90 = (($i$0$lcssa) + -1)|0;
       $91 = (($0) + ($90<<1)|0);
       $92 = HEAP16[$91>>1]|0;
       $93 = $92&65535;
       $94 = (($93) + -48)|0;
       $i$1$in = $i$0$lcssa;
       while(1) {
        $i$1 = (($i$1$in) + 1)|0;
        $95 = ($i$1|0)<($3|0);
        if (!($95)) {
         label = 20;
         break;
        }
        $96 = (($0) + ($i$1<<1)|0);
        $97 = HEAP16[$96>>1]|0;
        $98 = ($97<<16>>16)==(48);
        if ($98) {
         $i$1$in = $i$1;
        } else {
         break;
        }
       }
       if ((label|0) == 20) {
        $99 = (($94|0) % 2)&-1;
        $100 = ($99|0)==(1);
        if (!($100)) {
         $roundBit$0 = 0;
         break;
        }
       }
       $roundBit$0 = 1;
      } else {
       $roundBit$0 = 0;
      }
     }
    } else {
     $roundBit$0 = 0;
    }
   } while(0);
   $101 = ($102|0)==(0);
   $103 = ($104|0)==(0);
   $105 = $101 & $103;
   if ($105) {
    $178 = $202;$180 = $203;$208 = 0;$209 = 0;
    label = 38;
   } else {
    $106 = ($104|0)==(0);
    L41: do {
     if ($106) {
      $$0$lcssa$i = $roundBit$0;$166 = $202;$167 = $203;$173 = $102;$174 = $104;
     } else {
      $116 = $104;$123 = $102;$130 = $203;$137 = $202;$overhang$06$i = $104;$scale$07$i = $81;
      while(1) {
       $deltaScale$03$i = 1;
       while(1) {
        $109 = (197336 + ($deltaScale$03$i<<2)|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = ($overhang$06$i>>>0)<($110>>>0);
        $108 = (($deltaScale$03$i) + 1)|0;
        if ($111) {
         $deltaScale$0$lcssa$i = $deltaScale$03$i;
         break;
        }
        $107 = ($108|0)<(9);
        if ($107) {
         $deltaScale$03$i = $108;
        } else {
         $deltaScale$0$lcssa$i = $108;
         break;
        }
       }
       $112 = (($scale$07$i) - ($deltaScale$0$lcssa$i))|0;
       $113 = ($112|0)<(0);
       if ($113) {
        $$0 = 2;
        break;
       }
       $114 = (197336 + ($deltaScale$0$lcssa$i<<2)|0);
       $115 = HEAP32[$114>>2]|0;
       $117 = (___udivdi3(($116|0),0,($115|0),0)|0);
       $118 = tempRet0;
       $119 = (___muldi3(($117|0),($118|0),($115|0),0)|0);
       $120 = tempRet0;
       $121 = (_i64Subtract(($116|0),0,($119|0),($120|0))|0);
       $122 = tempRet0;
       $124 = (___udivdi3(($123|0),($121|0),($115|0),0)|0);
       $125 = tempRet0;
       $126 = (___muldi3(($124|0),($125|0),($115|0),0)|0);
       $127 = tempRet0;
       $128 = (_i64Subtract(($123|0),($116|0),($126|0),($127|0))|0);
       $129 = tempRet0;
       $131 = (___udivdi3(($130|0),($128|0),($115|0),0)|0);
       $132 = tempRet0;
       $133 = (___muldi3(($131|0),($132|0),($115|0),0)|0);
       $134 = tempRet0;
       $135 = (_i64Subtract(($130|0),0,($133|0),($134|0))|0);
       $136 = tempRet0;
       $138 = (___udivdi3(($137|0),($135|0),($115|0),0)|0);
       $139 = tempRet0;
       $140 = (___muldi3(($138|0),($139|0),($115|0),0)|0);
       $141 = tempRet0;
       $142 = (_i64Subtract(($137|0),($135|0),($140|0),($141|0))|0);
       $143 = tempRet0;
       $144 = (_bitshift64Shl(($142|0),($143|0),1)|0);
       $145 = tempRet0;
       $146 = ($145>>>0)<(0);
       $147 = ($145|0)==(0);
       $148 = ($144>>>0)<($115>>>0);
       $149 = $147 & $148;
       $150 = $146 | $149;
       do {
        if ($150) {
         $151 = ($144|0)==($115|0);
         $152 = ($145|0)==(0);
         $153 = $151 & $152;
         if ($153) {
          $154 = $138 & 1;
          $155 = ($154|0)!=(0);
          $156 = (0)!=(0);
          $157 = $155 | $156;
          $159 = $157;
          label = 32;
          break;
         } else {
          $210 = 0;$overhang$0$be$i = $117;
          break;
         }
        } else {
         $159 = 1;
         label = 32;
        }
       } while(0);
       if ((label|0) == 32) {
        label = 0;
        $158 = $159&1;
        $160 = ($138|0)==(-1);
        $161 = ($131|0)==(-1);
        $162 = $160 & $161;
        $or$cond = $159 & $162;
        if ($or$cond) {
         $164 = ($124|0)==(-1);
         $$$i5 = $164 ? 1 : $117;
         $210 = $158;$overhang$0$be$i = $$$i5;
        } else {
         $210 = $158;$overhang$0$be$i = $117;
        }
       }
       $163 = ($overhang$0$be$i|0)==(0);
       if ($163) {
        $$0$lcssa$i = $210;$166 = $138;$167 = $131;$173 = $124;$174 = $117;
        break L41;
       } else {
        $116 = $117;$123 = $124;$130 = $131;$137 = $138;$overhang$06$i = $overhang$0$be$i;$scale$07$i = $112;
       }
      }
      STACKTOP = sp;return ($$0|0);
     }
    } while(0);
    $165 = ($$0$lcssa$i|0)==(0);
    if ($165) {
     $178 = $166;$180 = $167;$208 = $173;$209 = $174;
     label = 38;
    } else {
     $168 = (_i64Add(($166|0),($167|0),1,0)|0);
     $169 = tempRet0;
     $170 = ($168|0)==(0);
     $171 = ($169|0)==(0);
     $172 = $170 & $171;
     if ($172) {
      $175 = (_i64Add(($173|0),($174|0),1,0)|0);
      $176 = tempRet0;
      $183 = $175;$185 = $176;
      label = 39;
     } else {
      $$off0 = $168;$$off32 = $169;$189 = $174;$192 = $173;
     }
    }
   }
   if ((label|0) == 38) {
    $177 = ($178|0)==(0);
    $179 = ($180|0)==(0);
    $181 = $177 & $179;
    if ($181) {
     $183 = $208;$185 = $209;
     label = 39;
    } else {
     $$off0 = $178;$$off32 = $180;$189 = $209;$192 = $208;
    }
   }
   if ((label|0) == 39) {
    $182 = ($183|0)==(0);
    $184 = ($185|0)==(0);
    $186 = $182 & $184;
    if ($186) {
     break;
    } else {
     $$off0 = 0;$$off32 = 0;$189 = $185;$192 = $183;
    }
   }
   $187 = ($81>>>0)>(28);
   $188 = ($189>>>0)>(0);
   $190 = ($189|0)==(0);
   $191 = ($192>>>0)>(4294967295);
   $193 = $190 & $191;
   $194 = $188 | $193;
   $or$cond$i = $187 | $194;
   if ($or$cond$i) {
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   }
   $195 = (($pA) + 8|0);
   HEAP32[$195>>2] = $$off0;
   $196 = (($pA) + 12|0);
   HEAP32[$196>>2] = $$off32;
   $197 = (($pA) + 4|0);
   HEAP32[$197>>2] = $192;
   $198 = $sign << 31;
   $199 = $81 << 16;
   $200 = $199 & 16711680;
   $201 = $200 | $198;
   HEAP32[$pA>>2] = $201;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 ;HEAP32[$pA+0>>2]=0|0;HEAP32[$pA+4>>2]=0|0;HEAP32[$pA+8>>2]=0|0;HEAP32[$pA+12>>2]=0|0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZL12normalize128PyS_Piii($pclo,$pchi,$pScale,$roundFlag,$roundBit) {
 $pclo = $pclo|0;
 $pchi = $pchi|0;
 $pScale = $pScale|0;
 $roundFlag = $roundFlag|0;
 $roundBit = $roundBit|0;
 var $$ = 0, $$0$lcssa = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $deltaScale$0$lcssa = 0, $deltaScale$0$lcssa$us = 0, $deltaScale$03 = 0, $deltaScale$03$us = 0, $or$cond2 = 0, $overhang$0$be = 0, $overhang$06 = 0, $overhang$06$us = 0, $scale$0$lcssa = 0, $scale$07 = 0, $scale$07$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $pchi;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$pScale>>2]|0;
 $7 = ($5|0)==(0);
 L1: do {
  if ($7) {
   $$0$lcssa = $roundBit;$scale$0$lcssa = $6;
  } else {
   $8 = ($roundFlag|0)==(0);
   if ($8) {
    $overhang$06$us = $5;$scale$07$us = $6;
    while(1) {
     $deltaScale$03$us = 1;
     while(1) {
      $11 = (197336 + ($deltaScale$03$us<<2)|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = ($overhang$06$us>>>0)<($12>>>0);
      $10 = (($deltaScale$03$us) + 1)|0;
      if ($13) {
       $deltaScale$0$lcssa$us = $deltaScale$03$us;
       break;
      }
      $9 = ($10|0)<(9);
      if ($9) {
       $deltaScale$03$us = $10;
      } else {
       $deltaScale$0$lcssa$us = $10;
       break;
      }
     }
     $14 = (($scale$07$us) - ($deltaScale$0$lcssa$us))|0;
     $15 = ($14|0)<(0);
     if ($15) {
      $$01 = 2;
      break;
     }
     $16 = (197336 + ($deltaScale$0$lcssa$us<<2)|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (__ZL10div128by32PyS_jPj($pclo,$pchi,$17,0)|0);
     $19 = $pchi;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + 4)|0;
     $23 = $22;
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0);
     if ($25) {
      $$0$lcssa = $18;$scale$0$lcssa = $14;
      break L1;
     } else {
      $overhang$06$us = $24;$scale$07$us = $14;
     }
    }
    STACKTOP = sp;return ($$01|0);
   } else {
    $overhang$06 = $5;$scale$07 = $6;
   }
   while(1) {
    $deltaScale$03 = 1;
    while(1) {
     $28 = (197336 + ($deltaScale$03<<2)|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($overhang$06>>>0)<($29>>>0);
     $27 = (($deltaScale$03) + 1)|0;
     if ($30) {
      $deltaScale$0$lcssa = $deltaScale$03;
      break;
     }
     $26 = ($27|0)<(9);
     if ($26) {
      $deltaScale$03 = $27;
     } else {
      $deltaScale$0$lcssa = $27;
      break;
     }
    }
    $31 = (($scale$07) - ($deltaScale$0$lcssa))|0;
    $32 = ($31|0)<(0);
    if ($32) {
     $$01 = 2;
     break;
    }
    $33 = (197336 + ($deltaScale$0$lcssa<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (__ZL10div128by32PyS_jPj($pclo,$pchi,$34,0)|0);
    $36 = $pchi;
    $37 = $36;
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 4)|0;
    $40 = $39;
    $41 = HEAP32[$40>>2]|0;
    $42 = ($35|0)==(0);
    if ($42) {
     $overhang$0$be = $41;
    } else {
     $43 = $pclo;
     $44 = $43;
     $45 = HEAP32[$44>>2]|0;
     $46 = (($43) + 4)|0;
     $47 = $46;
     $48 = HEAP32[$47>>2]|0;
     $49 = ($45|0)==(-1);
     $50 = ($48|0)==(-1);
     $51 = $49 & $50;
     if ($51) {
      $53 = ($38|0)==(-1);
      $$ = $53 ? 1 : $41;
      $overhang$0$be = $$;
     } else {
      $overhang$0$be = $41;
     }
    }
    $52 = ($overhang$0$be|0)==(0);
    if ($52) {
     $$0$lcssa = $35;$scale$0$lcssa = $31;
     break L1;
    } else {
     $overhang$06 = $overhang$0$be;$scale$07 = $31;
    }
   }
   STACKTOP = sp;return ($$01|0);
  }
 } while(0);
 HEAP32[$pScale>>2] = $scale$0$lcssa;
 $54 = ($roundFlag|0)==(0);
 $55 = ($$0$lcssa|0)==(0);
 $or$cond2 = $54 | $55;
 if ($or$cond2) {
  $$01 = 0;
  STACKTOP = sp;return ($$01|0);
 }
 $56 = $pclo;
 $57 = $56;
 $58 = HEAP32[$57>>2]|0;
 $59 = (($56) + 4)|0;
 $60 = $59;
 $61 = HEAP32[$60>>2]|0;
 $62 = (_i64Add(($58|0),($61|0),1,0)|0);
 $63 = tempRet0;
 $64 = $pclo;
 $65 = $64;
 HEAP32[$65>>2] = $62;
 $66 = (($64) + 4)|0;
 $67 = $66;
 HEAP32[$67>>2] = $63;
 $68 = ($62|0)==(0);
 $69 = ($63|0)==(0);
 $70 = $68 & $69;
 if (!($70)) {
  $$01 = 0;
  STACKTOP = sp;return ($$01|0);
 }
 $71 = $pchi;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($71) + 4)|0;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = (_i64Add(($73|0),($76|0),1,0)|0);
 $78 = tempRet0;
 $79 = $pchi;
 $80 = $79;
 HEAP32[$80>>2] = $77;
 $81 = (($79) + 4)|0;
 $82 = $81;
 HEAP32[$82>>2] = $78;
 $$01 = 0;
 STACKTOP = sp;return ($$01|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal14decimalCompareEP19il2cpp_decimal_reprS5_($pA,$pB) {
 $pA = $pA|0;
 $pB = $pB|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i5 = 0, $$0$i$i3$i = 0, $$0$i$i3$i13 = 0, $$0$i$i9$i = 0, $$0$i$i9$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aa = 0, $i$0$i$i$i = 0, $i$0$i$i$i3 = 0, $i$0$i$i1$i = 0;
 var $i$0$i$i1$i11 = 0, $i$0$i$i7$i = 0, $i$0$i$i7$i7 = 0, $tlog2$0$i = 0, $tlog2$0$i15 = 0, $tlog2$1$i = 0, $tlog2$1$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $aa = sp;
 $0 = HEAP32[$pA>>2]|0;
 $1 = $0 >> 31;
 $2 = $1 | 1;
 $3 = HEAP32[$pB>>2]|0;
 $4 = $3 ^ $0;
 $5 = ($4|0)<(0);
 if ($5) {
  $6 = (($pA) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = (($pA) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = (($pA) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0);
    if ($14) {
     $15 = (($pB) + 8|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0);
     if ($17) {
      $18 = (($pB) + 12|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = ($19|0)==(0);
      if ($20) {
       $21 = (($pB) + 4|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($22|0)==(0);
       if ($23) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = $0 >>> 16;
 $25 = $24 & 255;
 $26 = (($pA) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 do {
  if ($28) {
   $35 = (($pA) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0);
   if (!($37)) {
    $i$0$i$i7$i7 = 32;
    while(1) {
     $38 = ($i$0$i$i7$i7|0)>(0);
     if (!($38)) {
      $$0$i$i9$i9 = -1;
      break;
     }
     $39 = (($i$0$i$i7$i7) + -1)|0;
     $40 = 1 << $39;
     $41 = $40 & $36;
     $42 = ($41|0)==(0);
     if ($42) {
      $i$0$i$i7$i7 = $39;
     } else {
      $$0$i$i9$i9 = $39;
      break;
     }
    }
    $43 = (($$0$i$i9$i9) + 33)|0;
    $tlog2$0$i15 = $43;
    label = 21;
    break;
   }
   $44 = (($pA) + 8|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $tlog2$1$i17 = -1000;
   } else {
    $i$0$i$i1$i11 = 32;
    while(1) {
     $47 = ($i$0$i$i1$i11|0)>(0);
     if (!($47)) {
      $$0$i$i3$i13 = -1;
      break;
     }
     $48 = (($i$0$i$i1$i11) + -1)|0;
     $49 = 1 << $48;
     $50 = $49 & $45;
     $51 = ($50|0)==(0);
     if ($51) {
      $i$0$i$i1$i11 = $48;
     } else {
      $$0$i$i3$i13 = $48;
      break;
     }
    }
    $52 = (($$0$i$i3$i13) + 1)|0;
    $tlog2$0$i15 = $52;
    label = 21;
   }
  } else {
   $i$0$i$i$i3 = 32;
   while(1) {
    $29 = ($i$0$i$i$i3|0)>(0);
    if (!($29)) {
     $$0$i$i$i5 = -1;
     break;
    }
    $30 = (($i$0$i$i$i3) + -1)|0;
    $31 = 1 << $30;
    $32 = $31 & $27;
    $33 = ($32|0)==(0);
    if ($33) {
     $i$0$i$i$i3 = $30;
    } else {
     $$0$i$i$i5 = $30;
     break;
    }
   }
   $34 = (($$0$i$i$i5) + 65)|0;
   $tlog2$0$i15 = $34;
   label = 21;
  }
 } while(0);
 if ((label|0) == 21) {
  $53 = ($tlog2$0$i15|0)==(-1000);
  if ($53) {
   $tlog2$1$i17 = -1000;
  } else {
   $54 = ($25*33219)|0;
   $55 = (($54>>>0) / 10000)&-1;
   $56 = (($tlog2$0$i15) - ($55))|0;
   $tlog2$1$i17 = $56;
  }
 }
 $57 = $3 >>> 16;
 $58 = $57 & 255;
 $59 = (($pB) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0);
 do {
  if ($61) {
   $68 = (($pB) + 12|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0);
   if (!($70)) {
    $i$0$i$i7$i = 32;
    while(1) {
     $71 = ($i$0$i$i7$i|0)>(0);
     if (!($71)) {
      $$0$i$i9$i = -1;
      break;
     }
     $72 = (($i$0$i$i7$i) + -1)|0;
     $73 = 1 << $72;
     $74 = $73 & $69;
     $75 = ($74|0)==(0);
     if ($75) {
      $i$0$i$i7$i = $72;
     } else {
      $$0$i$i9$i = $72;
      break;
     }
    }
    $76 = (($$0$i$i9$i) + 33)|0;
    $tlog2$0$i = $76;
    label = 35;
    break;
   }
   $77 = (($pB) + 8|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==(0);
   if ($79) {
    $tlog2$1$i = -1000;
   } else {
    $i$0$i$i1$i = 32;
    while(1) {
     $80 = ($i$0$i$i1$i|0)>(0);
     if (!($80)) {
      $$0$i$i3$i = -1;
      break;
     }
     $81 = (($i$0$i$i1$i) + -1)|0;
     $82 = 1 << $81;
     $83 = $82 & $78;
     $84 = ($83|0)==(0);
     if ($84) {
      $i$0$i$i1$i = $81;
     } else {
      $$0$i$i3$i = $81;
      break;
     }
    }
    $85 = (($$0$i$i3$i) + 1)|0;
    $tlog2$0$i = $85;
    label = 35;
   }
  } else {
   $i$0$i$i$i = 32;
   while(1) {
    $62 = ($i$0$i$i$i|0)>(0);
    if (!($62)) {
     $$0$i$i$i = -1;
     break;
    }
    $63 = (($i$0$i$i$i) + -1)|0;
    $64 = 1 << $63;
    $65 = $64 & $60;
    $66 = ($65|0)==(0);
    if ($66) {
     $i$0$i$i$i = $63;
    } else {
     $$0$i$i$i = $63;
     break;
    }
   }
   $67 = (($$0$i$i$i) + 65)|0;
   $tlog2$0$i = $67;
   label = 35;
  }
 } while(0);
 if ((label|0) == 35) {
  $86 = ($tlog2$0$i|0)==(-1000);
  if ($86) {
   $tlog2$1$i = -1000;
  } else {
   $87 = ($58*33219)|0;
   $88 = (($87>>>0) / 10000)&-1;
   $89 = (($tlog2$0$i) - ($88))|0;
   $tlog2$1$i = $89;
  }
 }
 $90 = (($tlog2$1$i17) - ($tlog2$1$i))|0;
 $91 = ($90|0)<(-1);
 if ($91) {
  $92 = (0 - ($2))|0;
  $$0 = $92;
  STACKTOP = sp;return ($$0|0);
 }
 $93 = ($90|0)>(1);
 if ($93) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$aa+0>>2]=HEAP32[$pA+0>>2]|0;HEAP32[$aa+4>>2]=HEAP32[$pA+4>>2]|0;HEAP32[$aa+8>>2]=HEAP32[$pA+8>>2]|0;HEAP32[$aa+12>>2]=HEAP32[$pA+12>>2]|0;
 $94 = HEAP32[$aa>>2]|0;
 $95 = $94 ^ -2147483648;
 HEAP32[$aa>>2] = $95;
 (__ZN6il2cpp6icalls8mscorlib6System7Decimal11decimalIncrEP19il2cpp_decimal_reprS5_($aa,$pB)|0);
 $96 = (($aa) + 8|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ($97|0)==(0);
 if ($98) {
  $99 = (($aa) + 12|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0);
  if ($101) {
   $102 = (($aa) + 4|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==(0);
   if ($104) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $105 = HEAP32[$aa>>2]|0;
 $106 = $105 >> 31;
 $107 = $106 & 2;
 $108 = (($107) + -1)|0;
 $$0 = $108;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal11decimalIncrEP19il2cpp_decimal_reprS5_($pA,$pB) {
 $pA = $pA|0;
 $pB = $pB|0;
 var $$ = 0, $$$i20 = 0, $$$i3 = 0, $$$i4 = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i6 = 0, $$0$i$i19 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i12 = 0, $$0$i2$i$i$i = 0, $$0$i2$i$i$i9 = 0, $$off0 = 0, $$off32 = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $ahi = 0, $alo = 0, $bhi = 0, $blo = 0, $deltaScale$0$lcssa$i = 0, $deltaScale$03$i = 0, $i$0$i$i$i$i = 0, $i$0$i$i$i$i5 = 0, $i$0$i$i1$i$i = 0, $i$0$i$i1$i$i11 = 0, $i$0$i1$i$i$i = 0, $i$0$i1$i$i$i8 = 0, $or$cond$i = 0, $overhang$0$be$i = 0, $overhang$06$i = 0, $phitmp = 0, $phitmp38 = 0, $scale$07$i = 0, $scaleA = 0;
 var $sign$0 = 0, $sign$1 = 0, $sign$222 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $alo = sp + 24|0;
 $ahi = sp;
 $blo = sp + 8|0;
 $bhi = sp + 16|0;
 $scaleA = sp + 32|0;
 $0 = (($pA) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($pA) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $alo;
 $5 = $4;
 HEAP32[$5>>2] = $3;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $1;
 $8 = (($pA) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $ahi;
 $11 = $10;
 HEAP32[$11>>2] = $9;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = 0;
 $14 = (($pB) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($pB) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $blo;
 $19 = $18;
 HEAP32[$19>>2] = $17;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $15;
 $22 = (($pB) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $bhi;
 $25 = $24;
 HEAP32[$25>>2] = $23;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 $28 = HEAP32[$pA>>2]|0;
 $29 = $28 >>> 31;
 $30 = HEAP32[$pB>>2]|0;
 $31 = $30 >>> 31;
 $32 = $28 >>> 16;
 $33 = $32 & 255;
 HEAP32[$scaleA>>2] = $33;
 $34 = $30 >>> 16;
 $35 = $34 & 255;
 $36 = ($33|0)==($35|0);
 do {
  if ($36) {
   $37 = ($29|0)==($31|0);
   if ($37) {
    $85 = (_i64Add(($17|0),($15|0),($3|0),($1|0))|0);
    $86 = tempRet0;
    $87 = ($86>>>0)<($15>>>0);
    $88 = ($86|0)==($15|0);
    $89 = ($85>>>0)<($17>>>0);
    $90 = $88 & $89;
    $91 = $87 | $90;
    $92 = $91&1;
    $93 = (_i64Add(($23|0),0,($9|0),0)|0);
    $94 = tempRet0;
    $95 = (_i64Add(($93|0),($94|0),($92|0),0)|0);
    $96 = tempRet0;
    $97 = $alo;
    $98 = $97;
    HEAP32[$98>>2] = $85;
    $99 = (($97) + 4)|0;
    $100 = $99;
    HEAP32[$100>>2] = $86;
    $101 = $ahi;
    $102 = $101;
    HEAP32[$102>>2] = $95;
    $103 = (($101) + 4)|0;
    $104 = $103;
    HEAP32[$104>>2] = $96;
    $106 = $96;$379 = $85;$380 = $86;$381 = $95;$sign$0 = $29;
   } else {
    $38 = (_i64Subtract(($3|0),($1|0),($17|0),($15|0))|0);
    $39 = tempRet0;
    $40 = (_i64Subtract(($9|0),0,($23|0),0)|0);
    $41 = tempRet0;
    $42 = ($1>>>0)<($15>>>0);
    $43 = ($1|0)==($15|0);
    $44 = ($3>>>0)<($17>>>0);
    $45 = $43 & $44;
    $46 = $42 | $45;
    $47 = $46 << 31 >> 31;
    $48 = ($47|0)<(0);
    $49 = $48 << 31 >> 31;
    $50 = (_i64Add(($40|0),($41|0),($47|0),($49|0))|0);
    $51 = tempRet0;
    $52 = $alo;
    $53 = $52;
    HEAP32[$53>>2] = $38;
    $54 = (($52) + 4)|0;
    $55 = $54;
    HEAP32[$55>>2] = $39;
    $56 = $ahi;
    $57 = $56;
    HEAP32[$57>>2] = $50;
    $58 = (($56) + 4)|0;
    $59 = $58;
    HEAP32[$59>>2] = $51;
    $60 = ($51|0)<(0);
    if ($60) {
     $61 = (_i64Subtract(0,0,($38|0),($39|0))|0);
     $62 = tempRet0;
     $63 = $alo;
     $64 = $63;
     HEAP32[$64>>2] = $61;
     $65 = (($63) + 4)|0;
     $66 = $65;
     HEAP32[$66>>2] = $62;
     $67 = ($3|0)==($17|0);
     $68 = ($1|0)==($15|0);
     $69 = $67 & $68;
     if ($69) {
      $70 = (_i64Add(($50|0),($51|0),-1,-1)|0);
      $71 = tempRet0;
      $72 = $ahi;
      $73 = $72;
      HEAP32[$73>>2] = $70;
      $74 = (($72) + 4)|0;
      $75 = $74;
      HEAP32[$75>>2] = $71;
      $77 = $70;$79 = $71;
     } else {
      $77 = $50;$79 = $51;
     }
     $76 = $77 ^ -1;
     $78 = $79 ^ -1;
     $80 = $ahi;
     $81 = $80;
     HEAP32[$81>>2] = $76;
     $82 = (($80) + 4)|0;
     $83 = $82;
     HEAP32[$83>>2] = $78;
     $84 = $29 ^ 1;
     $106 = $78;$379 = $61;$380 = $62;$381 = $76;$sign$0 = $84;
    } else {
     $106 = $51;$379 = $38;$380 = $39;$381 = $50;$sign$0 = $29;
    }
   }
   $105 = ($106|0)==(0);
   if ($105) {
    HEAP32[$scaleA>>2] = $33;
    $$off0 = $379;$$off32 = $380;$364 = $33;$366 = $106;$369 = $381;$sign$222 = $sign$0;
    break;
   } else {
    $116 = $106;$123 = $381;$134 = $380;$141 = $379;$overhang$06$i = $106;$scale$07$i = $33;
   }
   while(1) {
    $deltaScale$03$i = 1;
    while(1) {
     $109 = (197336 + ($deltaScale$03$i<<2)|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($overhang$06$i>>>0)<($110>>>0);
     $108 = (($deltaScale$03$i) + 1)|0;
     if ($111) {
      $deltaScale$0$lcssa$i = $deltaScale$03$i;
      break;
     }
     $107 = ($108|0)<(9);
     if ($107) {
      $deltaScale$03$i = $108;
     } else {
      $deltaScale$0$lcssa$i = $108;
      break;
     }
    }
    $112 = (($scale$07$i) - ($deltaScale$0$lcssa$i))|0;
    $113 = ($112|0)<(0);
    if ($113) {
     $$0 = 2;
     label = 65;
     break;
    }
    $114 = (197336 + ($deltaScale$0$lcssa$i<<2)|0);
    $115 = HEAP32[$114>>2]|0;
    $117 = (___udivdi3(($116|0),0,($115|0),0)|0);
    $118 = tempRet0;
    $119 = (___muldi3(($117|0),($118|0),($115|0),0)|0);
    $120 = tempRet0;
    $121 = (_i64Subtract(($116|0),0,($119|0),($120|0))|0);
    $122 = tempRet0;
    $124 = (___udivdi3(($123|0),($121|0),($115|0),0)|0);
    $125 = tempRet0;
    $126 = (___muldi3(($124|0),($125|0),($115|0),0)|0);
    $127 = tempRet0;
    $128 = (_i64Subtract(($123|0),($116|0),($126|0),($127|0))|0);
    $129 = tempRet0;
    $130 = $ahi;
    $131 = $130;
    HEAP32[$131>>2] = $124;
    $132 = (($130) + 4)|0;
    $133 = $132;
    HEAP32[$133>>2] = $117;
    $135 = (___udivdi3(($134|0),($128|0),($115|0),0)|0);
    $136 = tempRet0;
    $137 = (___muldi3(($135|0),($136|0),($115|0),0)|0);
    $138 = tempRet0;
    $139 = (_i64Subtract(($134|0),0,($137|0),($138|0))|0);
    $140 = tempRet0;
    $142 = (___udivdi3(($141|0),($139|0),($115|0),0)|0);
    $143 = tempRet0;
    $144 = (___muldi3(($142|0),($143|0),($115|0),0)|0);
    $145 = tempRet0;
    $146 = (_i64Subtract(($141|0),($139|0),($144|0),($145|0))|0);
    $147 = tempRet0;
    $148 = $alo;
    $149 = $148;
    HEAP32[$149>>2] = $142;
    $150 = (($148) + 4)|0;
    $151 = $150;
    HEAP32[$151>>2] = $135;
    $152 = (_bitshift64Shl(($146|0),($147|0),1)|0);
    $153 = tempRet0;
    $154 = ($153>>>0)<(0);
    $155 = ($153|0)==(0);
    $156 = ($152>>>0)<($115>>>0);
    $157 = $155 & $156;
    $158 = $154 | $157;
    do {
     if ($158) {
      $159 = ($152|0)==($115|0);
      $160 = ($153|0)==(0);
      $161 = $159 & $160;
      if ($161) {
       $162 = $142 & 1;
       $163 = ($162|0)==(0);
       $164 = (0)==(0);
       $165 = $163 & $164;
       if ($165) {
        $382 = 0;$383 = $142;$384 = $135;$overhang$0$be$i = $117;
        break;
       } else {
        $171 = $117;
        label = 19;
        break;
       }
      } else {
       $382 = 0;$383 = $142;$384 = $135;$overhang$0$be$i = $117;
       break;
      }
     } else {
      $171 = $117;
      label = 19;
     }
    } while(0);
    if ((label|0) == 19) {
     label = 0;
     $166 = ($142|0)==(-1);
     $167 = ($135|0)==(-1);
     $168 = $166 & $167;
     if ($168) {
      $170 = ($124|0)==(-1);
      $$$i3 = $170 ? 1 : $171;
      $382 = 1;$383 = -1;$384 = -1;$overhang$0$be$i = $$$i3;
     } else {
      $382 = 1;$383 = $142;$384 = $135;$overhang$0$be$i = $171;
     }
    }
    $169 = ($overhang$0$be$i|0)==(0);
    if ($169) {
     break;
    } else {
     $116 = $117;$123 = $124;$134 = $384;$141 = $383;$overhang$06$i = $overhang$0$be$i;$scale$07$i = $112;
    }
   }
   if ((label|0) == 65) {
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$scaleA>>2] = $112;
   if ($382) {
    $172 = (_i64Add(($142|0),($135|0),1,0)|0);
    $173 = tempRet0;
    $174 = $alo;
    $175 = $174;
    HEAP32[$175>>2] = $172;
    $176 = (($174) + 4)|0;
    $177 = $176;
    HEAP32[$177>>2] = $173;
    $178 = ($172|0)==(0);
    $179 = ($173|0)==(0);
    $180 = $178 & $179;
    if ($180) {
     $181 = (_i64Add(($124|0),($117|0),1,0)|0);
     $182 = tempRet0;
     $183 = $ahi;
     $184 = $183;
     HEAP32[$184>>2] = $181;
     $185 = (($183) + 4)|0;
     $186 = $185;
     HEAP32[$186>>2] = $182;
     $$off0 = 0;$$off32 = 0;$364 = $112;$366 = $182;$369 = $181;$sign$222 = $sign$0;
    } else {
     $$off0 = $172;$$off32 = $173;$364 = $112;$366 = $117;$369 = $124;$sign$222 = $sign$0;
    }
   } else {
    $$off0 = $142;$$off32 = $135;$364 = $112;$366 = $117;$369 = $124;$sign$222 = $sign$0;
   }
  } else {
   $187 = ($9|0)==(0);
   do {
    if ($187) {
     $188 = ($3|0)==(0);
     $189 = ($1|0)==(0);
     $190 = $188 & $189;
     if ($190) {
      $$0$i$i = -1000;
     } else {
      $191 = ($1|0)==(0);
      if ($191) {
       $i$0$i$i$i$i = 32;
       while(1) {
        $192 = ($i$0$i$i$i$i|0)>(0);
        if (!($192)) {
         $$0$i$i$i$i = -1;
         break;
        }
        $193 = (($i$0$i$i$i$i) + -1)|0;
        $194 = 1 << $193;
        $195 = $194 & $3;
        $196 = ($195|0)==(0);
        if ($196) {
         $i$0$i$i$i$i = $193;
        } else {
         $$0$i$i$i$i = $193;
         break;
        }
       }
       $197 = (($$0$i$i$i$i) + 1)|0;
       $$0$i$i = $197;
       break;
      } else {
       $i$0$i1$i$i$i = 32;
       while(1) {
        $198 = ($i$0$i1$i$i$i|0)>(0);
        if (!($198)) {
         $$0$i2$i$i$i = -1;
         break;
        }
        $199 = (($i$0$i1$i$i$i) + -1)|0;
        $200 = 1 << $199;
        $201 = $200 & $1;
        $202 = ($201|0)==(0);
        if ($202) {
         $i$0$i1$i$i$i = $199;
        } else {
         $$0$i2$i$i$i = $199;
         break;
        }
       }
       $203 = (($$0$i2$i$i$i) + 33)|0;
       $$0$i$i = $203;
       break;
      }
     }
    } else {
     $i$0$i$i1$i$i = 32;
     while(1) {
      $204 = ($i$0$i$i1$i$i|0)>(0);
      if (!($204)) {
       $$0$i$i2$i$i = -1;
       break;
      }
      $205 = (($i$0$i$i1$i$i) + -1)|0;
      $206 = 1 << $205;
      $207 = $206 & $9;
      $208 = ($207|0)==(0);
      if ($208) {
       $i$0$i$i1$i$i = $205;
      } else {
       $$0$i$i2$i$i = $205;
       break;
      }
     }
     $phitmp = (($$0$i$i2$i$i) + 65)|0;
     $$0$i$i = $phitmp;
    }
   } while(0);
   $209 = ($$0$i$i|0)<(0);
   $$$i4 = $209 ? 0 : $$0$i$i;
   $210 = ($33*33219)|0;
   $211 = (($210>>>0) / 10000)&-1;
   $212 = (($$$i4) - ($211))|0;
   $213 = ($23|0)==(0);
   do {
    if ($213) {
     $214 = ($17|0)==(0);
     $215 = ($15|0)==(0);
     $216 = $214 & $215;
     if ($216) {
      $$0$i$i19 = -1000;
     } else {
      $217 = ($15|0)==(0);
      if ($217) {
       $i$0$i$i$i$i5 = 32;
       while(1) {
        $218 = ($i$0$i$i$i$i5|0)>(0);
        if (!($218)) {
         $$0$i$i$i$i6 = -1;
         break;
        }
        $219 = (($i$0$i$i$i$i5) + -1)|0;
        $220 = 1 << $219;
        $221 = $220 & $17;
        $222 = ($221|0)==(0);
        if ($222) {
         $i$0$i$i$i$i5 = $219;
        } else {
         $$0$i$i$i$i6 = $219;
         break;
        }
       }
       $223 = (($$0$i$i$i$i6) + 1)|0;
       $$0$i$i19 = $223;
       break;
      } else {
       $i$0$i1$i$i$i8 = 32;
       while(1) {
        $224 = ($i$0$i1$i$i$i8|0)>(0);
        if (!($224)) {
         $$0$i2$i$i$i9 = -1;
         break;
        }
        $225 = (($i$0$i1$i$i$i8) + -1)|0;
        $226 = 1 << $225;
        $227 = $226 & $15;
        $228 = ($227|0)==(0);
        if ($228) {
         $i$0$i1$i$i$i8 = $225;
        } else {
         $$0$i2$i$i$i9 = $225;
         break;
        }
       }
       $229 = (($$0$i2$i$i$i9) + 33)|0;
       $$0$i$i19 = $229;
       break;
      }
     }
    } else {
     $i$0$i$i1$i$i11 = 32;
     while(1) {
      $230 = ($i$0$i$i1$i$i11|0)>(0);
      if (!($230)) {
       $$0$i$i2$i$i12 = -1;
       break;
      }
      $231 = (($i$0$i$i1$i$i11) + -1)|0;
      $232 = 1 << $231;
      $233 = $232 & $23;
      $234 = ($233|0)==(0);
      if ($234) {
       $i$0$i$i1$i$i11 = $231;
      } else {
       $$0$i$i2$i$i12 = $231;
       break;
      }
     }
     $phitmp38 = (($$0$i$i2$i$i12) + 65)|0;
     $$0$i$i19 = $phitmp38;
    }
   } while(0);
   $235 = ($$0$i$i19|0)<(0);
   $$$i20 = $235 ? 0 : $$0$i$i19;
   $236 = ($35*33219)|0;
   $237 = (($236>>>0) / 10000)&-1;
   $238 = (($$$i20) - ($237))|0;
   $239 = ($212|0)>($238|0);
   $240 = $239 ? $212 : $238;
   $241 = ($29|0)==($31|0);
   $242 = $29 ^ 1;
   $243 = $242 ^ $31;
   $$ = (($240) + ($243))|0;
   $244 = ($$*1000)|0;
   $245 = (($244|0) / 3322)&-1;
   $246 = (($245) + 1)|0;
   $247 = ($35>>>0)>($33>>>0);
   if ($247) {
    HEAP32[$scaleA>>2] = $35;
    $249 = $35;
   } else {
    $249 = $33;
   }
   $248 = (($246) + ($249))|0;
   $250 = ($248|0)>(35);
   if ($250) {
    $251 = (34 - ($245))|0;
    HEAP32[$scaleA>>2] = $251;
    $253 = $251;
   } else {
    $253 = $249;
   }
   $252 = (($253) - ($33))|0;
   $254 = (__ZL14adjustScale128PyS_i($alo,$ahi,$252)|0);
   $255 = ($254|0)==(0);
   if (!($255)) {
    $$0 = $254;
    STACKTOP = sp;return ($$0|0);
   }
   $256 = (($253) - ($35))|0;
   $257 = (__ZL14adjustScale128PyS_i($blo,$bhi,$256)|0);
   $258 = ($257|0)==(0);
   if (!($258)) {
    $$0 = $257;
    STACKTOP = sp;return ($$0|0);
   }
   $259 = $alo;
   $260 = $259;
   $261 = HEAP32[$260>>2]|0;
   $262 = (($259) + 4)|0;
   $263 = $262;
   $264 = HEAP32[$263>>2]|0;
   $265 = $ahi;
   $266 = $265;
   $267 = HEAP32[$266>>2]|0;
   $268 = (($265) + 4)|0;
   $269 = $268;
   $270 = HEAP32[$269>>2]|0;
   $271 = $blo;
   $272 = $271;
   $273 = HEAP32[$272>>2]|0;
   $274 = (($271) + 4)|0;
   $275 = $274;
   $276 = HEAP32[$275>>2]|0;
   $277 = $bhi;
   $278 = $277;
   $279 = HEAP32[$278>>2]|0;
   $280 = (($277) + 4)|0;
   $281 = $280;
   $282 = HEAP32[$281>>2]|0;
   if ($241) {
    $329 = (_i64Add(($273|0),($276|0),($261|0),($264|0))|0);
    $330 = tempRet0;
    $331 = ($330>>>0)<($276>>>0);
    $332 = ($330|0)==($276|0);
    $333 = ($329>>>0)<($273>>>0);
    $334 = $332 & $333;
    $335 = $331 | $334;
    $336 = $335&1;
    $337 = (_i64Add(($279|0),($282|0),($267|0),($270|0))|0);
    $338 = tempRet0;
    $339 = (_i64Add(($337|0),($338|0),($336|0),0)|0);
    $340 = tempRet0;
    $341 = $alo;
    $342 = $341;
    HEAP32[$342>>2] = $329;
    $343 = (($341) + 4)|0;
    $344 = $343;
    HEAP32[$344>>2] = $330;
    $345 = $ahi;
    $346 = $345;
    HEAP32[$346>>2] = $339;
    $347 = (($345) + 4)|0;
    $348 = $347;
    HEAP32[$348>>2] = $340;
    $sign$1 = $29;
   } else {
    $283 = (_i64Subtract(($261|0),($264|0),($273|0),($276|0))|0);
    $284 = tempRet0;
    $285 = (_i64Subtract(($267|0),($270|0),($279|0),($282|0))|0);
    $286 = tempRet0;
    $287 = ($264>>>0)<($276>>>0);
    $288 = ($264|0)==($276|0);
    $289 = ($261>>>0)<($273>>>0);
    $290 = $288 & $289;
    $291 = $287 | $290;
    $292 = $291 << 31 >> 31;
    $293 = ($292|0)<(0);
    $294 = $293 << 31 >> 31;
    $295 = (_i64Add(($285|0),($286|0),($292|0),($294|0))|0);
    $296 = tempRet0;
    $297 = $alo;
    $298 = $297;
    HEAP32[$298>>2] = $283;
    $299 = (($297) + 4)|0;
    $300 = $299;
    HEAP32[$300>>2] = $284;
    $301 = $ahi;
    $302 = $301;
    HEAP32[$302>>2] = $295;
    $303 = (($301) + 4)|0;
    $304 = $303;
    HEAP32[$304>>2] = $296;
    $305 = ($296|0)<(0);
    if ($305) {
     $306 = (_i64Subtract(0,0,($283|0),($284|0))|0);
     $307 = tempRet0;
     $308 = $alo;
     $309 = $308;
     HEAP32[$309>>2] = $306;
     $310 = (($308) + 4)|0;
     $311 = $310;
     HEAP32[$311>>2] = $307;
     $312 = ($261|0)==($273|0);
     $313 = ($264|0)==($276|0);
     $314 = $312 & $313;
     if ($314) {
      $315 = (_i64Add(($295|0),($296|0),-1,-1)|0);
      $316 = tempRet0;
      $317 = $ahi;
      $318 = $317;
      HEAP32[$318>>2] = $315;
      $319 = (($317) + 4)|0;
      $320 = $319;
      HEAP32[$320>>2] = $316;
      $322 = $315;$324 = $316;
     } else {
      $322 = $295;$324 = $296;
     }
     $321 = $322 ^ -1;
     $323 = $324 ^ -1;
     $325 = $ahi;
     $326 = $325;
     HEAP32[$326>>2] = $321;
     $327 = (($325) + 4)|0;
     $328 = $327;
     HEAP32[$328>>2] = $323;
     $sign$1 = $242;
    } else {
     $sign$1 = $29;
    }
   }
   $349 = (__ZL10rescale128PyS_Piiiii($alo,$ahi,$scaleA,0,28,1)|0);
   $350 = ($349|0)==(0);
   if ($350) {
    $351 = $alo;
    $352 = $351;
    $353 = HEAP32[$352>>2]|0;
    $354 = (($351) + 4)|0;
    $355 = $354;
    $356 = HEAP32[$355>>2]|0;
    $357 = $ahi;
    $358 = $357;
    $359 = HEAP32[$358>>2]|0;
    $360 = (($357) + 4)|0;
    $361 = $360;
    $362 = HEAP32[$361>>2]|0;
    $$pre27 = HEAP32[$scaleA>>2]|0;
    $$off0 = $353;$$off32 = $356;$364 = $$pre27;$366 = $362;$369 = $359;$sign$222 = $sign$1;
    break;
   } else {
    $$0 = $349;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $363 = ($364>>>0)>(28);
 $365 = ($366>>>0)>(0);
 $367 = ($366|0)==(0);
 $368 = ($369>>>0)>(4294967295);
 $370 = $367 & $368;
 $371 = $365 | $370;
 $or$cond$i = $363 | $371;
 if ($or$cond$i) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$2>>2] = $$off0;
 HEAP32[$0>>2] = $$off32;
 HEAP32[$8>>2] = $369;
 $372 = HEAP32[$pA>>2]|0;
 $373 = $sign$222 << 31;
 $374 = $372 & 2130771967;
 $375 = $364 << 16;
 $376 = $375 & 16711680;
 $377 = $376 | $373;
 $378 = $377 | $374;
 HEAP32[$pA>>2] = $378;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZL14adjustScale128PyS_i($palo,$pahi,$deltaScale) {
 $palo = $palo|0;
 $pahi = $pahi|0;
 $deltaScale = $deltaScale|0;
 var $$0 = 0, $$012 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($deltaScale|0)<(0);
 if ($0) {
  $1 = (0 - ($deltaScale))|0;
  $2 = ($1|0)>(28);
  if ($2) {
   $$0 = 3;
   STACKTOP = sp;return ($$0|0);
  }
  $3 = ($1|0)>(0);
  if ($3) {
   $$012 = $1;
  } else {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  while(1) {
   $4 = ($$012|0)>(9);
   $5 = $4 ? 9 : $$012;
   $6 = (($$012) - ($5))|0;
   $7 = (197336 + ($5<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $pahi;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + 4)|0;
   $13 = $12;
   $14 = HEAP32[$13>>2]|0;
   $15 = (___udivdi3(($14|0),0,($8|0),0)|0);
   $16 = tempRet0;
   $17 = (___muldi3(($15|0),($16|0),($8|0),0)|0);
   $18 = tempRet0;
   $19 = (_i64Subtract(($14|0),0,($17|0),($18|0))|0);
   $20 = tempRet0;
   $21 = (___udivdi3(($11|0),($19|0),($8|0),0)|0);
   $22 = tempRet0;
   $23 = (___muldi3(($21|0),($22|0),($8|0),0)|0);
   $24 = tempRet0;
   $25 = (_i64Subtract(($11|0),($14|0),($23|0),($24|0))|0);
   $26 = tempRet0;
   $27 = $pahi;
   $28 = $27;
   HEAP32[$28>>2] = $21;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $15;
   $31 = $palo;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 4)|0;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (___udivdi3(($36|0),($25|0),($8|0),0)|0);
   $38 = tempRet0;
   $39 = (___muldi3(($37|0),($38|0),($8|0),0)|0);
   $40 = tempRet0;
   $41 = (_i64Subtract(($36|0),0,($39|0),($40|0))|0);
   $42 = tempRet0;
   $43 = (___udivdi3(($33|0),($41|0),($8|0),0)|0);
   $44 = tempRet0;
   $45 = $palo;
   $46 = $45;
   HEAP32[$46>>2] = $43;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $37;
   $49 = ($6|0)>(0);
   if ($49) {
    $$012 = $6;
   } else {
    $$0 = 0;
    break;
   }
  }
  STACKTOP = sp;return ($$0|0);
 }
 $50 = ($deltaScale|0)>(0);
 if (!($50)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $51 = ($deltaScale|0)>(28);
 if ($51) {
  $$0 = 3;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$1 = $deltaScale;
 }
 while(1) {
  $52 = ($$1|0)>(0);
  if (!($52)) {
   $$0 = 0;
   label = 9;
   break;
  }
  $53 = ($$1|0)>(9);
  $54 = $53 ? 9 : $$1;
  $55 = (($$1) - ($54))|0;
  $56 = (197336 + ($54<<2)|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = $palo;
  $59 = $58;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($58) + 4)|0;
  $62 = $61;
  $63 = HEAP32[$62>>2]|0;
  $64 = (___muldi3(($60|0),0,($57|0),0)|0);
  $65 = tempRet0;
  $66 = (___muldi3(($63|0),0,($57|0),0)|0);
  $67 = tempRet0;
  $68 = (_i64Add(($65|0),0,($66|0),($67|0))|0);
  $69 = tempRet0;
  $70 = $palo;
  $71 = $70;
  HEAP32[$71>>2] = $64;
  $72 = (($70) + 4)|0;
  $73 = $72;
  HEAP32[$73>>2] = $68;
  $74 = $pahi;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + 4)|0;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = (___muldi3(($76|0),0,($57|0),0)|0);
  $81 = tempRet0;
  $82 = (_i64Add(($69|0),0,($80|0),($81|0))|0);
  $83 = tempRet0;
  $84 = (___muldi3(($79|0),0,($57|0),0)|0);
  $85 = tempRet0;
  $86 = (_i64Add(($83|0),0,($84|0),($85|0))|0);
  $87 = tempRet0;
  $88 = $pahi;
  $89 = $88;
  HEAP32[$89>>2] = $82;
  $90 = (($88) + 4)|0;
  $91 = $90;
  HEAP32[$91>>2] = $86;
  $92 = ($87>>>0)<(1);
  $93 = ($87|0)==(1);
  $94 = ($86>>>0)<(0);
  $95 = $93 & $94;
  $96 = $92 | $95;
  $97 = $96 ? 0 : 2;
  if ($96) {
   $$1 = $55;
  } else {
   $$0 = $97;
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal20decimalFloorAndTruncEP19il2cpp_decimal_repri($pA,$floorFlag) {
 $pA = $pA|0;
 $floorFlag = $floorFlag|0;
 var $$off0 = 0, $$off32 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $hasRest$011 = 0, $or$cond = 0, $or$cond1 = 0, $phitmp = 0, $scale$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$pA>>2]|0;
 $1 = $0 >>> 16;
 $2 = $1 & 255;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($pA) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($pA) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($pA) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $0 >>> 31;
 $16 = 0;$23 = $9;$30 = $5;$37 = $7;$hasRest$011 = 0;$scale$010 = $2;
 while(1) {
  $11 = ($scale$010|0)>(9);
  $12 = $11 ? 9 : $scale$010;
  $13 = (197336 + ($12<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($scale$010) - ($12))|0;
  $17 = (___udivdi3(($16|0),0,($14|0),0)|0);
  $18 = tempRet0;
  $19 = (___muldi3(($17|0),($18|0),($14|0),0)|0);
  $20 = tempRet0;
  $21 = (_i64Subtract(($16|0),0,($19|0),($20|0))|0);
  $22 = tempRet0;
  $24 = (___udivdi3(($23|0),($21|0),($14|0),0)|0);
  $25 = tempRet0;
  $26 = (___muldi3(($24|0),($25|0),($14|0),0)|0);
  $27 = tempRet0;
  $28 = (_i64Subtract(($23|0),($16|0),($26|0),($27|0))|0);
  $29 = tempRet0;
  $31 = (___udivdi3(($30|0),($28|0),($14|0),0)|0);
  $32 = tempRet0;
  $33 = (___muldi3(($31|0),($32|0),($14|0),0)|0);
  $34 = tempRet0;
  $35 = (_i64Subtract(($30|0),0,($33|0),($34|0))|0);
  $36 = tempRet0;
  $38 = (___udivdi3(($37|0),($35|0),($14|0),0)|0);
  $39 = tempRet0;
  $40 = (___muldi3(($38|0),($39|0),($14|0),0)|0);
  $41 = tempRet0;
  $42 = (_i64Subtract(($37|0),($30|0),($40|0),($41|0))|0);
  $43 = tempRet0;
  $44 = $42 | $hasRest$011;
  $45 = ($44|0)!=(0);
  $46 = $45&1;
  $47 = ($15|0)>(0);
  if ($47) {
   $16 = $17;$23 = $24;$30 = $31;$37 = $38;$hasRest$011 = $46;$scale$010 = $15;
  } else {
   break;
  }
 }
 $phitmp = $45 ^ 1;
 $48 = ($floorFlag|0)==(0);
 $or$cond = $48 | $phitmp;
 $49 = ($10|0)==(0);
 $or$cond1 = $or$cond | $49;
 if ($or$cond1) {
  $$off0 = $38;$$off32 = $31;$59 = $17;$62 = $24;
 } else {
  $50 = (_i64Add(($38|0),($31|0),1,0)|0);
  $51 = tempRet0;
  $52 = ($50|0)==(0);
  $53 = ($51|0)==(0);
  $54 = $52 & $53;
  $55 = $54&1;
  $56 = (_i64Add(($55|0),0,($24|0),($17|0))|0);
  $57 = tempRet0;
  $$off0 = $50;$$off32 = $51;$59 = $57;$62 = $56;
 }
 $58 = ($59>>>0)>(0);
 $60 = ($59|0)==(0);
 $61 = ($62>>>0)>(4294967295);
 $63 = $60 & $61;
 $64 = $58 | $63;
 if ($64) {
  STACKTOP = sp;return;
 }
 HEAP32[$6>>2] = $$off0;
 HEAP32[$4>>2] = $$off32;
 HEAP32[$8>>2] = $62;
 $65 = $10 << 31;
 $66 = $0 & 2130771967;
 $67 = $66 | $65;
 HEAP32[$pA>>2] = $67;
 STACKTOP = sp;return;
}
function __ZL10div128by32PyS_jPj($plo,$phi,$factor,$pRest) {
 $plo = $plo|0;
 $phi = $phi|0;
 $factor = $factor|0;
 $pRest = $pRest|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $phi;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___udivdi3(($5|0),0,($factor|0),0)|0);
 $7 = tempRet0;
 $8 = (___muldi3(($6|0),($7|0),($factor|0),0)|0);
 $9 = tempRet0;
 $10 = (_i64Subtract(($5|0),0,($8|0),($9|0))|0);
 $11 = tempRet0;
 $12 = (___udivdi3(($2|0),($10|0),($factor|0),0)|0);
 $13 = tempRet0;
 $14 = (___muldi3(($12|0),($13|0),($factor|0),0)|0);
 $15 = tempRet0;
 $16 = (_i64Subtract(($2|0),($5|0),($14|0),($15|0))|0);
 $17 = tempRet0;
 $18 = $phi;
 $19 = $18;
 HEAP32[$19>>2] = $12;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $6;
 $22 = $plo;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 4)|0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (___udivdi3(($27|0),($16|0),($factor|0),0)|0);
 $29 = tempRet0;
 $30 = (___muldi3(($28|0),($29|0),($factor|0),0)|0);
 $31 = tempRet0;
 $32 = (_i64Subtract(($27|0),0,($30|0),($31|0))|0);
 $33 = tempRet0;
 $34 = (___udivdi3(($24|0),($32|0),($factor|0),0)|0);
 $35 = tempRet0;
 $36 = (___muldi3(($34|0),($35|0),($factor|0),0)|0);
 $37 = tempRet0;
 $38 = (_i64Subtract(($24|0),($32|0),($36|0),($37|0))|0);
 $39 = tempRet0;
 $40 = $plo;
 $41 = $40;
 HEAP32[$41>>2] = $34;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = ($pRest|0)==(0|0);
 if (!($44)) {
  HEAP32[$pRest>>2] = $38;
 }
 $45 = (_bitshift64Shl(($38|0),($39|0),1)|0);
 $46 = tempRet0;
 $47 = ($46>>>0)<(0);
 $48 = ($46|0)==(0);
 $49 = ($45>>>0)<($factor>>>0);
 $50 = $48 & $49;
 $51 = $47 | $50;
 if (!($51)) {
  $60 = 1;
  $59 = $60&1;
  STACKTOP = sp;return ($59|0);
 }
 $52 = ($45|0)==($factor|0);
 $53 = ($46|0)==(0);
 $54 = $52 & $53;
 if (!($54)) {
  $60 = 0;
  $59 = $60&1;
  STACKTOP = sp;return ($59|0);
 }
 $55 = $34 & 1;
 $56 = ($55|0)!=(0);
 $57 = (0)!=(0);
 $58 = $56 | $57;
 $60 = $58;
 $59 = $60&1;
 STACKTOP = sp;return ($59|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal14decimal2UInt64EP19il2cpp_decimal_reprPy($pA,$pResult) {
 $pA = $pA|0;
 $pResult = $pResult|0;
 var $$0 = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($pA) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($pA) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($pA) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$pA>>2]|0;
 $7 = $6 >>> 16;
 $8 = $7 & 255;
 $9 = ($8|0)==(0);
 if ($9) {
  $67 = $5;$69 = 0;$72 = $3;$74 = $1;
 } else {
  $$01$i = $8;$15 = 0;$22 = $5;$29 = $1;$36 = $3;
  while(1) {
   $10 = ($$01$i|0)>(9);
   $11 = $10 ? 9 : $$01$i;
   $12 = (($$01$i) - ($11))|0;
   $13 = (197336 + ($11<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $16 = (___udivdi3(($15|0),0,($14|0),0)|0);
   $17 = tempRet0;
   $18 = (___muldi3(($16|0),($17|0),($14|0),0)|0);
   $19 = tempRet0;
   $20 = (_i64Subtract(($15|0),0,($18|0),($19|0))|0);
   $21 = tempRet0;
   $23 = (___udivdi3(($22|0),($20|0),($14|0),0)|0);
   $24 = tempRet0;
   $25 = (___muldi3(($23|0),($24|0),($14|0),0)|0);
   $26 = tempRet0;
   $27 = (_i64Subtract(($22|0),($15|0),($25|0),($26|0))|0);
   $28 = tempRet0;
   $30 = (___udivdi3(($29|0),($27|0),($14|0),0)|0);
   $31 = tempRet0;
   $32 = (___muldi3(($30|0),($31|0),($14|0),0)|0);
   $33 = tempRet0;
   $34 = (_i64Subtract(($29|0),0,($32|0),($33|0))|0);
   $35 = tempRet0;
   $37 = (___udivdi3(($36|0),($34|0),($14|0),0)|0);
   $38 = tempRet0;
   $39 = (___muldi3(($37|0),($38|0),($14|0),0)|0);
   $40 = tempRet0;
   $41 = (_i64Subtract(($36|0),($34|0),($39|0),($40|0))|0);
   $42 = tempRet0;
   $43 = (_bitshift64Shl(($41|0),($42|0),1)|0);
   $44 = tempRet0;
   $45 = ($44>>>0)<(0);
   $46 = ($44|0)==(0);
   $47 = ($43>>>0)<($14>>>0);
   $48 = $46 & $47;
   $49 = $45 | $48;
   if ($49) {
    $50 = ($43|0)==($14|0);
    $51 = ($44|0)==(0);
    $52 = $50 & $51;
    if ($52) {
     $53 = $37 & 1;
     $54 = ($53|0)!=(0);
     $55 = (0)!=(0);
     $56 = $54 | $55;
     $81 = $56;
    } else {
     $81 = 0;
    }
   } else {
    $81 = 1;
   }
   $57 = ($12|0)>(0);
   if ($57) {
    $$01$i = $12;$15 = $16;$22 = $23;$29 = $30;$36 = $37;
   } else {
    break;
   }
  }
  if ($81) {
   $58 = (_i64Add(($37|0),($30|0),1,0)|0);
   $59 = tempRet0;
   $60 = ($58|0)==(0);
   $61 = ($59|0)==(0);
   $62 = $60 & $61;
   $63 = $62&1;
   $64 = (_i64Add(($63|0),0,($23|0),($16|0))|0);
   $65 = tempRet0;
   $67 = $64;$69 = $65;$72 = $58;$74 = $59;
  } else {
   $67 = $23;$69 = $16;$72 = $37;$74 = $30;
  }
 }
 $66 = ($67|0)==(0);
 $68 = ($69|0)==(0);
 $70 = $66 & $68;
 if (!($70)) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = ($72|0)!=(0);
 $73 = ($74|0)!=(0);
 $75 = $71 | $73;
 $76 = ($6|0)<(0);
 $or$cond = $75 & $76;
 if ($or$cond) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $77 = $pResult;
 $78 = $77;
 HEAP32[$78>>2] = $72;
 $79 = (($77) + 4)|0;
 $80 = $79;
 HEAP32[$80>>2] = $74;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal13decimal2Int64EP19il2cpp_decimal_reprPx($pA,$pResult) {
 $pA = $pA|0;
 $pResult = $pResult|0;
 var $$0 = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($pA) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($pA) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($pA) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$pA>>2]|0;
 $7 = $6 >>> 16;
 $8 = $7 & 255;
 $9 = ($8|0)==(0);
 if ($9) {
  $67 = $5;$69 = 0;$73 = $3;$75 = $1;
 } else {
  $$01$i = $8;$15 = 0;$22 = $5;$29 = $1;$36 = $3;
  while(1) {
   $10 = ($$01$i|0)>(9);
   $11 = $10 ? 9 : $$01$i;
   $12 = (($$01$i) - ($11))|0;
   $13 = (197336 + ($11<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $16 = (___udivdi3(($15|0),0,($14|0),0)|0);
   $17 = tempRet0;
   $18 = (___muldi3(($16|0),($17|0),($14|0),0)|0);
   $19 = tempRet0;
   $20 = (_i64Subtract(($15|0),0,($18|0),($19|0))|0);
   $21 = tempRet0;
   $23 = (___udivdi3(($22|0),($20|0),($14|0),0)|0);
   $24 = tempRet0;
   $25 = (___muldi3(($23|0),($24|0),($14|0),0)|0);
   $26 = tempRet0;
   $27 = (_i64Subtract(($22|0),($15|0),($25|0),($26|0))|0);
   $28 = tempRet0;
   $30 = (___udivdi3(($29|0),($27|0),($14|0),0)|0);
   $31 = tempRet0;
   $32 = (___muldi3(($30|0),($31|0),($14|0),0)|0);
   $33 = tempRet0;
   $34 = (_i64Subtract(($29|0),0,($32|0),($33|0))|0);
   $35 = tempRet0;
   $37 = (___udivdi3(($36|0),($34|0),($14|0),0)|0);
   $38 = tempRet0;
   $39 = (___muldi3(($37|0),($38|0),($14|0),0)|0);
   $40 = tempRet0;
   $41 = (_i64Subtract(($36|0),($34|0),($39|0),($40|0))|0);
   $42 = tempRet0;
   $43 = (_bitshift64Shl(($41|0),($42|0),1)|0);
   $44 = tempRet0;
   $45 = ($44>>>0)<(0);
   $46 = ($44|0)==(0);
   $47 = ($43>>>0)<($14>>>0);
   $48 = $46 & $47;
   $49 = $45 | $48;
   if ($49) {
    $50 = ($43|0)==($14|0);
    $51 = ($44|0)==(0);
    $52 = $50 & $51;
    if ($52) {
     $53 = $37 & 1;
     $54 = ($53|0)!=(0);
     $55 = (0)!=(0);
     $56 = $54 | $55;
     $91 = $56;
    } else {
     $91 = 0;
    }
   } else {
    $91 = 1;
   }
   $57 = ($12|0)>(0);
   if ($57) {
    $$01$i = $12;$15 = $16;$22 = $23;$29 = $30;$36 = $37;
   } else {
    break;
   }
  }
  if ($91) {
   $58 = (_i64Add(($37|0),($30|0),1,0)|0);
   $59 = tempRet0;
   $60 = ($58|0)==(0);
   $61 = ($59|0)==(0);
   $62 = $60 & $61;
   $63 = $62&1;
   $64 = (_i64Add(($63|0),0,($23|0),($16|0))|0);
   $65 = tempRet0;
   $67 = $64;$69 = $65;$73 = $58;$75 = $59;
  } else {
   $67 = $23;$69 = $16;$73 = $37;$75 = $30;
  }
 }
 $66 = ($67|0)==(0);
 $68 = ($69|0)==(0);
 $70 = $66 & $68;
 if (!($70)) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = ($6|0)<(0);
 do {
  if ($71) {
   $72 = ($73|0)==(0);
   $74 = ($75|0)==(0);
   $76 = $72 & $74;
   if ($76) {
    $87 = 0;$90 = 0;
   } else {
    $77 = ($75>>>0)>(2147483648);
    $78 = ($75|0)==(-2147483648);
    $79 = ($73>>>0)>(0);
    $80 = $78 & $79;
    $81 = $77 | $80;
    if ($81) {
     $$0 = 2;
     STACKTOP = sp;return ($$0|0);
    } else {
     $82 = (_i64Subtract(0,0,($73|0),($75|0))|0);
     $83 = tempRet0;
     $87 = $82;$90 = $83;
     break;
    }
   }
  } else {
   $84 = ($75|0)<(0);
   if ($84) {
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   } else {
    $87 = $73;$90 = $75;
   }
  }
 } while(0);
 $85 = $pResult;
 $86 = $85;
 HEAP32[$86>>2] = $87;
 $88 = (($85) + 4)|0;
 $89 = $88;
 HEAP32[$89>>2] = $90;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal11decimalMultEP19il2cpp_decimal_reprS5_($pA,$pB) {
 $pA = $pA|0;
 $pB = $pB|0;
 var $$$i = 0, $$0 = 0, $$1$i = 0, $$carry0$2$i = 0, $$carry1$1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $carry0$1$i = 0, $carry0$2$i = 0, $carry1$1$i = 0, $low = 0, $mid = 0, $or$cond$i = 0, $scale = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $low = sp + 8|0;
 $mid = sp;
 $scale = sp + 16|0;
 $0 = (($pA) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($pA) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($pA) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($pB) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($pB) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($pB) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (___muldi3(($7|0),0,($1|0),0)|0);
 $13 = tempRet0;
 $14 = (___muldi3(($9|0),0,($1|0),0)|0);
 $15 = tempRet0;
 $16 = (___muldi3(($7|0),0,($3|0),0)|0);
 $17 = tempRet0;
 $18 = (_i64Add(($13|0),0,($14|0),($15|0))|0);
 $19 = tempRet0;
 $20 = ($19>>>0)<($15>>>0);
 $21 = ($19|0)==($15|0);
 $22 = ($18>>>0)<($14>>>0);
 $23 = $21 & $22;
 $24 = $20 | $23;
 $$$i = $24&1;
 $25 = (_i64Add(($18|0),($19|0),($16|0),($17|0))|0);
 $26 = tempRet0;
 $27 = ($26>>>0)<($17>>>0);
 $28 = ($26|0)==($17|0);
 $29 = ($25>>>0)<($16>>>0);
 $30 = $28 & $29;
 $31 = $27 | $30;
 $32 = $24 ? 2 : 1;
 $carry0$1$i = $31 ? $32 : $$$i;
 $33 = (___muldi3(($11|0),0,($1|0),0)|0);
 $34 = tempRet0;
 $35 = (___muldi3(($9|0),0,($3|0),0)|0);
 $36 = tempRet0;
 $37 = (___muldi3(($7|0),0,($5|0),0)|0);
 $38 = tempRet0;
 $39 = (_i64Add(($26|0),0,($33|0),($34|0))|0);
 $40 = tempRet0;
 $41 = ($40>>>0)<($34>>>0);
 $42 = ($40|0)==($34|0);
 $43 = ($39>>>0)<($33>>>0);
 $44 = $42 & $43;
 $45 = $41 | $44;
 $$1$i = $45&1;
 $46 = (_i64Add(($39|0),($40|0),($35|0),($36|0))|0);
 $47 = tempRet0;
 $48 = ($47>>>0)<($36>>>0);
 $49 = ($47|0)==($36|0);
 $50 = ($46>>>0)<($35>>>0);
 $51 = $49 & $50;
 $52 = $48 | $51;
 $53 = $45 ? 2 : 1;
 $carry1$1$i = $52 ? $53 : $$1$i;
 $54 = (_i64Add(($46|0),($47|0),($37|0),($38|0))|0);
 $55 = tempRet0;
 $56 = ($55>>>0)<($38>>>0);
 $57 = ($55|0)==($38|0);
 $58 = ($54>>>0)<($37>>>0);
 $59 = $57 & $58;
 $60 = $56 | $59;
 $61 = $60&1;
 $$carry1$1$i = (($61) + ($carry1$1$i))|0;
 $62 = (___muldi3(($11|0),0,($3|0),0)|0);
 $63 = tempRet0;
 $64 = (___muldi3(($9|0),0,($5|0),0)|0);
 $65 = tempRet0;
 $66 = (_i64Add(($carry0$1$i|0),0,($62|0),($63|0))|0);
 $67 = tempRet0;
 $68 = (_i64Add(($66|0),($67|0),($55|0),0)|0);
 $69 = tempRet0;
 $70 = ($69>>>0)<($63>>>0);
 $71 = ($69|0)==($63|0);
 $72 = ($68>>>0)<($62>>>0);
 $73 = $71 & $72;
 $74 = $70 | $73;
 $carry0$2$i = $74&1;
 $75 = (_i64Add(($68|0),($69|0),($64|0),($65|0))|0);
 $76 = tempRet0;
 $77 = ($76>>>0)<($65>>>0);
 $78 = ($76|0)==($65|0);
 $79 = ($75>>>0)<($64>>>0);
 $80 = $78 & $79;
 $81 = $77 | $80;
 $82 = $74 ? 2 : 1;
 $$carry0$2$i = $81 ? $82 : $carry0$2$i;
 $83 = ($$carry1$1$i|0)<(0);
 $84 = $83 << 31 >> 31;
 $85 = (___muldi3(($11|0),0,($5|0),0)|0);
 $86 = tempRet0;
 $87 = $low;
 $88 = $87;
 HEAP32[$88>>2] = $12;
 $89 = (($87) + 4)|0;
 $90 = $89;
 HEAP32[$90>>2] = $25;
 $91 = $mid;
 $92 = $91;
 HEAP32[$92>>2] = $54;
 $93 = (($91) + 4)|0;
 $94 = $93;
 HEAP32[$94>>2] = $75;
 $95 = (_i64Add(($$carry1$1$i|0),($84|0),($85|0),($86|0))|0);
 $96 = tempRet0;
 $97 = (_i64Add(($95|0),($96|0),($76|0),0)|0);
 $98 = tempRet0;
 $99 = (_i64Add(($97|0),($98|0),0,($$carry0$2$i|0))|0);
 $100 = tempRet0;
 $101 = HEAP32[$pA>>2]|0;
 $102 = $101 >>> 16;
 $103 = $102 & 255;
 $104 = HEAP32[$pB>>2]|0;
 $105 = $104 >>> 16;
 $106 = $105 & 255;
 $107 = (($106) + ($103))|0;
 HEAP32[$scale>>2] = $107;
 $108 = $104 ^ $101;
 $110 = $99;$112 = $100;$115 = 0;$118 = $75;$119 = 1000000000;$130 = $107;$151 = $54;$162 = $25;$169 = $12;
 while(1) {
  $109 = ($110|0)==(0);
  $111 = ($112|0)==(0);
  $113 = $109 & $111;
  if ($113) {
   $114 = (0)<($115>>>0);
   $116 = (0)==($115|0);
   $117 = ($118>>>0)<($119>>>0);
   $120 = $116 & $117;
   $121 = $114 | $120;
   if ($121) {
    break;
   } else {
    label = 5;
   }
  } else {
   $122 = ($112>>>0)<(0);
   $123 = ($112|0)==(0);
   $124 = ($110>>>0)<(100);
   $125 = $123 & $124;
   $126 = $122 | $125;
   if ($126) {
    label = 5;
   } else {
    $131 = (($130) + -9)|0;
    $132 = $119;$204 = $115;$storemerge = $131;
   }
  }
  if ((label|0) == 5) {
   label = 0;
   $127 = (___udivdi3(($119|0),($115|0),1000,0)|0);
   $128 = tempRet0;
   $129 = (($130) + -6)|0;
   $132 = $127;$204 = $128;$storemerge = $129;
  }
  HEAP32[$scale>>2] = $storemerge;
  $133 = (___udivdi3(($112|0),0,($132|0),0)|0);
  $134 = tempRet0;
  $135 = (___muldi3(($133|0),($134|0),($132|0),0)|0);
  $136 = tempRet0;
  $137 = (_i64Subtract(($112|0),0,($135|0),($136|0))|0);
  $138 = tempRet0;
  $139 = (___udivdi3(($110|0),($137|0),($132|0),0)|0);
  $140 = tempRet0;
  $141 = (___muldi3(($139|0),($140|0),($132|0),0)|0);
  $142 = tempRet0;
  $143 = (_i64Subtract(($110|0),($112|0),($141|0),($142|0))|0);
  $144 = tempRet0;
  $145 = (___udivdi3(($118|0),($143|0),($132|0),0)|0);
  $146 = tempRet0;
  $147 = (___muldi3(($145|0),($146|0),($132|0),0)|0);
  $148 = tempRet0;
  $149 = (_i64Subtract(($118|0),0,($147|0),($148|0))|0);
  $150 = tempRet0;
  $152 = (___udivdi3(($151|0),($149|0),($132|0),0)|0);
  $153 = tempRet0;
  $154 = (___muldi3(($152|0),($153|0),($132|0),0)|0);
  $155 = tempRet0;
  $156 = (_i64Subtract(($151|0),($118|0),($154|0),($155|0))|0);
  $157 = tempRet0;
  $158 = $mid;
  $159 = $158;
  HEAP32[$159>>2] = $152;
  $160 = (($158) + 4)|0;
  $161 = $160;
  HEAP32[$161>>2] = $145;
  $163 = (___udivdi3(($162|0),($156|0),($132|0),0)|0);
  $164 = tempRet0;
  $165 = (___muldi3(($163|0),($164|0),($132|0),0)|0);
  $166 = tempRet0;
  $167 = (_i64Subtract(($162|0),0,($165|0),($166|0))|0);
  $168 = tempRet0;
  $170 = (___udivdi3(($169|0),($167|0),($132|0),0)|0);
  $171 = tempRet0;
  $172 = $low;
  $173 = $172;
  HEAP32[$173>>2] = $170;
  $174 = (($172) + 4)|0;
  $175 = $174;
  HEAP32[$175>>2] = $163;
  $110 = $139;$112 = $133;$115 = $204;$118 = $145;$119 = $132;$130 = $storemerge;$151 = $152;$162 = $163;$169 = $170;
 }
 $176 = $108 & -2147483648;
 $177 = (__ZL10rescale128PyS_Piiiii($low,$mid,$scale,0,28,1)|0);
 $178 = ($177|0)==(0);
 if (!($178)) {
  $$0 = $177;
  STACKTOP = sp;return ($$0|0);
 }
 $179 = $low;
 $180 = $179;
 $181 = HEAP32[$180>>2]|0;
 $182 = (($179) + 4)|0;
 $183 = $182;
 $184 = HEAP32[$183>>2]|0;
 $185 = $mid;
 $186 = $185;
 $187 = HEAP32[$186>>2]|0;
 $188 = (($185) + 4)|0;
 $189 = $188;
 $190 = HEAP32[$189>>2]|0;
 $191 = HEAP32[$scale>>2]|0;
 $192 = ($191>>>0)>(28);
 $193 = ($190>>>0)>(0);
 $194 = ($190|0)==(0);
 $195 = ($187>>>0)>(4294967295);
 $196 = $194 & $195;
 $197 = $193 | $196;
 $or$cond$i = $192 | $197;
 if ($or$cond$i) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $181;
 HEAP32[$2>>2] = $184;
 HEAP32[$4>>2] = $187;
 $198 = HEAP32[$pA>>2]|0;
 $199 = $198 & 2130771967;
 $200 = $191 << 16;
 $201 = $200 & 16711680;
 $202 = $201 | $176;
 $203 = $202 | $199;
 HEAP32[$pA>>2] = $203;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal10decimalDivEP19il2cpp_decimal_reprS5_S5_($pC,$pA,$pB) {
 $pC = $pC|0;
 $pA = $pA|0;
 $pB = $pB|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $chi = 0, $clo = 0, $or$cond$i = 0, $pA$idx = 0, $pA$idx$val = 0, $pA$idx1 = 0, $pA$idx1$val = 0, $pA$idx2 = 0, $pA$idx2$val = 0, $pB$idx = 0, $pB$idx$val = 0, $pB$idx3 = 0, $pB$idx3$val = 0, $pB$idx4 = 0, $pB$idx4$val = 0, $scale = 0, $texp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $clo = sp + 8|0;
 $chi = sp;
 $scale = sp + 20|0;
 $texp = sp + 16|0;
 $0 = (__ZN6il2cpp6icalls8mscorlib6System7Decimal14decimalCompareEP19il2cpp_decimal_reprS5_($pA,$pB)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($pC) + 8|0);
  HEAP32[$2>>2] = 1;
  $3 = (($pC) + 12|0);
  HEAP32[$3>>2] = 0;
  $4 = (($pC) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = HEAP32[$pC>>2]|0;
  $6 = $5 & 2130771967;
  HEAP32[$pC>>2] = $6;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$pA>>2]|0;
 $8 = $7 ^ -2147483648;
 HEAP32[$pA>>2] = $8;
 $9 = (__ZN6il2cpp6icalls8mscorlib6System7Decimal14decimalCompareEP19il2cpp_decimal_reprS5_($pA,$pB)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = (($pC) + 8|0);
  HEAP32[$11>>2] = 1;
  $12 = (($pC) + 12|0);
  HEAP32[$12>>2] = 0;
  $13 = (($pC) + 4|0);
  HEAP32[$13>>2] = 0;
  $14 = HEAP32[$pC>>2]|0;
  $15 = $14 & 2130771967;
  $16 = $15 | -2147483648;
  HEAP32[$pC>>2] = $16;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = HEAP32[$pA>>2]|0;
 $18 = $17 ^ -2147483648;
 HEAP32[$pA>>2] = $18;
 $pA$idx = (($pA) + 4|0);
 $pA$idx$val = HEAP32[$pA$idx>>2]|0;
 $pA$idx1 = (($pA) + 8|0);
 $pA$idx1$val = HEAP32[$pA$idx1>>2]|0;
 $pA$idx2 = (($pA) + 12|0);
 $pA$idx2$val = HEAP32[$pA$idx2>>2]|0;
 $pB$idx = (($pB) + 4|0);
 $pB$idx$val = HEAP32[$pB$idx>>2]|0;
 $pB$idx3 = (($pB) + 8|0);
 $pB$idx3$val = HEAP32[$pB$idx3>>2]|0;
 $pB$idx4 = (($pB) + 12|0);
 $pB$idx4$val = HEAP32[$pB$idx4>>2]|0;
 $19 = (__ZL13decimalDivSubP19il2cpp_decimal_reprS0_PyS1_Pi($pA$idx$val,$pA$idx1$val,$pA$idx2$val,$pB$idx$val,$pB$idx3$val,$pB$idx4$val,$clo,$chi,$texp)|0);
 if ((($19|0) == 0)) {
  $20 = HEAP32[$pA>>2]|0;
  $21 = $20 >>> 16;
  $22 = $21 & 255;
  $23 = HEAP32[$pB>>2]|0;
  $24 = $23 >>> 16;
  $25 = $24 & 255;
  $26 = (($22) - ($25))|0;
  HEAP32[$scale>>2] = $26;
  $27 = HEAP32[$texp>>2]|0;
  $28 = (__ZL10rescale128PyS_Piiiii($clo,$chi,$scale,$27,28,1)|0);
  $29 = ($28|0)==(0);
  if (!($29)) {
   $$0 = $28;
   STACKTOP = sp;return ($$0|0);
  }
  $30 = $clo;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 4)|0;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = $chi;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = HEAP32[$scale>>2]|0;
  $43 = ($42>>>0)>(28);
  $44 = ($41>>>0)>(0);
  $45 = ($41|0)==(0);
  $46 = ($38>>>0)>(4294967295);
  $47 = $45 & $46;
  $48 = $44 | $47;
  $or$cond$i = $43 | $48;
  if ($or$cond$i) {
   $$0 = 2;
   STACKTOP = sp;return ($$0|0);
  }
  $49 = HEAP32[$pB>>2]|0;
  $50 = HEAP32[$pA>>2]|0;
  $51 = $50 ^ $49;
  $52 = $51 & -2147483648;
  $53 = (($pC) + 8|0);
  HEAP32[$53>>2] = $32;
  $54 = (($pC) + 12|0);
  HEAP32[$54>>2] = $35;
  $55 = (($pC) + 4|0);
  HEAP32[$55>>2] = $38;
  $56 = HEAP32[$pC>>2]|0;
  $57 = $56 & 2130771967;
  $58 = $42 << 16;
  $59 = $58 & 16711680;
  $60 = $52 | $59;
  $61 = $60 | $57;
  HEAP32[$pC>>2] = $61;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($19|0) == 1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL13decimalDivSubP19il2cpp_decimal_reprS0_PyS1_Pi($pA$0$1$val,$pA$0$2$val,$pA$0$3$val,$pB$0$1$val,$pB$0$2$val,$pB$0$3$val,$pclo,$pchi,$pExp) {
 $pA$0$1$val = $pA$0$1$val|0;
 $pA$0$2$val = $pA$0$2$val|0;
 $pA$0$3$val = $pA$0$3$val|0;
 $pB$0$1$val = $pB$0$1$val|0;
 $pB$0$2$val = $pB$0$2$val|0;
 $pB$0$3$val = $pB$0$3$val|0;
 $pclo = $pclo|0;
 $pchi = $pchi|0;
 $pExp = $pExp|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ashift$051 = 0, $ashift$143 = 0;
 var $ashift$2 = 0, $bhi$023 = 0, $bhi$133 = 0, $bhi$2 = 0, $blo$031 = 0, $blo$1 = 0, $bmi$022 = 0, $bmi$132 = 0, $bmi$2 = 0, $bshift$024 = 0, $bshift$134 = 0, $bshift$2 = 0, $c$0$i$i = 0, $c$0$i1$i = 0, $c$0$i12$i = 0, $c$1$lcssa$i$i = 0, $c$1$lcssa$i19$i = 0, $c$1$lcssa$i8$i = 0, $c$15$i$i = 0, $c$15$i16$i = 0;
 var $c$15$i5$i = 0, $extraBit$0 = 0, $i$0$i = 0, $or$cond5 = 0, $texp$0$lcssa = 0, $texp$0$ph = 0, $texp$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($pB$0$3$val|0)==(0);
 $1 = ($pB$0$1$val|0)==(0);
 $2 = $pB$0$2$val | $pB$0$1$val;
 $3 = $2 | $pB$0$3$val;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 5;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($pA$0$2$val|0)==(0);
 $6 = ($pA$0$3$val|0)==(0);
 $7 = ($pA$0$1$val|0)==(0);
 $8 = $6 & $7;
 if ($5) {
  if ($8) {
   $14 = $pchi;
   $15 = $14;
   HEAP32[$15>>2] = 0;
   $16 = (($14) + 4)|0;
   $17 = $16;
   HEAP32[$17>>2] = 0;
   $18 = $pclo;
   $19 = $18;
   HEAP32[$19>>2] = 0;
   $20 = (($18) + 4)|0;
   $21 = $20;
   HEAP32[$21>>2] = 0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $372 = 0;$373 = 0;
   label = 4;
  }
 } else {
  if ($8) {
   $22 = ($pA$0$2$val|0)>(-1);
   $23 = ($pA$0$2$val|0)==(-1);
   $24 = (0)>(4294967295);
   $25 = $23 & $24;
   $26 = $22 | $25;
   if ($26) {
    $27 = 0;$28 = $pA$0$2$val;$ashift$051 = 64;
    while(1) {
     $29 = (_bitshift64Shl(($27|0),($28|0),1)|0);
     $30 = tempRet0;
     $31 = (($ashift$051) + 1)|0;
     $32 = ($30|0)>(-1);
     $33 = ($30|0)==(-1);
     $34 = ($29>>>0)>(4294967295);
     $35 = $33 & $34;
     $36 = $32 | $35;
     if ($36) {
      $27 = $29;$28 = $30;$ashift$051 = $31;
     } else {
      $81 = $30;$84 = $29;$91 = 0;$94 = 0;$ashift$2 = $31;
      break;
     }
    }
   } else {
    $81 = $pA$0$2$val;$84 = 0;$91 = 0;$94 = 0;$ashift$2 = 64;
   }
  } else {
   $372 = 0;$373 = $pA$0$2$val;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $9 = ($pA$0$1$val|0)>(-1);
  $10 = ($pA$0$1$val|0)==(-1);
  $11 = ($pA$0$3$val>>>0)>(4294967295);
  $12 = $10 & $11;
  $13 = $9 | $12;
  if ($13) {
   $37 = $pA$0$3$val;$38 = $pA$0$1$val;$41 = $372;$42 = $373;$ashift$143 = 0;
   while(1) {
    $39 = (_bitshift64Shl(($37|0),($38|0),1)|0);
    $40 = tempRet0;
    $43 = (_bitshift64Lshr(($41|0),($42|0),63)|0);
    $44 = tempRet0;
    $45 = $39 | $43;
    $46 = $40 | $44;
    $47 = (_bitshift64Shl(($41|0),($42|0),1)|0);
    $48 = tempRet0;
    $49 = (($ashift$143) + 1)|0;
    $50 = ($46|0)>(-1);
    $51 = ($46|0)==(-1);
    $52 = ($45>>>0)>(4294967295);
    $53 = $51 & $52;
    $54 = $50 | $53;
    if ($54) {
     $37 = $45;$38 = $46;$41 = $47;$42 = $48;$ashift$143 = $49;
    } else {
     $81 = $46;$84 = $45;$91 = $48;$94 = $47;$ashift$2 = $49;
     break;
    }
   }
  } else {
   $81 = $pA$0$1$val;$84 = $pA$0$3$val;$91 = $373;$94 = $372;$ashift$2 = 0;
  }
 }
 L17: do {
  if ($1) {
   if ($0) {
    $i$0$i = 32;
   } else {
    $56 = ($pB$0$3$val|0)>(-1);
    if ($56) {
     $bhi$023 = $pB$0$3$val;$bmi$022 = $pB$0$2$val;$bshift$024 = 32;
    } else {
     $bhi$2 = $pB$0$3$val;$blo$1 = 0;$bmi$2 = $pB$0$2$val;$bshift$2 = 32;
     break;
    }
    while(1) {
     $65 = $bhi$023 << 1;
     $66 = $bmi$022 >>> 31;
     $67 = $65 | $66;
     $68 = $bmi$022 << 1;
     $69 = (($bshift$024) + 1)|0;
     $70 = ($67|0)>(-1);
     if ($70) {
      $bhi$023 = $67;$bmi$022 = $68;$bshift$024 = $69;
     } else {
      $bhi$2 = $67;$blo$1 = 0;$bmi$2 = $68;$bshift$2 = $69;
      break L17;
     }
    }
   }
   while(1) {
    $57 = ($i$0$i|0)>(0);
    if (!($57)) {
     $$0$i = -1;
     break;
    }
    $58 = (($i$0$i) + -1)|0;
    $59 = 1 << $58;
    $60 = $59 & $pB$0$2$val;
    $61 = ($60|0)==(0);
    if ($61) {
     $i$0$i = $58;
    } else {
     $$0$i = $58;
     break;
    }
   }
   $62 = (31 - ($$0$i))|0;
   $63 = $pB$0$2$val << $62;
   $64 = (($62) + 64)|0;
   $bhi$2 = $63;$blo$1 = 0;$bmi$2 = 0;$bshift$2 = $64;
  } else {
   $55 = ($pB$0$1$val|0)>(-1);
   if ($55) {
    $bhi$133 = $pB$0$1$val;$blo$031 = $pB$0$2$val;$bmi$132 = $pB$0$3$val;$bshift$134 = 0;
    while(1) {
     $71 = $bhi$133 << 1;
     $72 = $bmi$132 >>> 31;
     $73 = $71 | $72;
     $74 = $bmi$132 << 1;
     $75 = $blo$031 >>> 31;
     $76 = $74 | $75;
     $77 = $blo$031 << 1;
     $78 = (($bshift$134) + 1)|0;
     $79 = ($73|0)>(-1);
     if ($79) {
      $bhi$133 = $73;$blo$031 = $77;$bmi$132 = $76;$bshift$134 = $78;
     } else {
      $bhi$2 = $73;$blo$1 = $77;$bmi$2 = $76;$bshift$2 = $78;
      break;
     }
    }
   } else {
    $bhi$2 = $pB$0$1$val;$blo$1 = $pB$0$2$val;$bmi$2 = $pB$0$3$val;$bshift$2 = 0;
   }
  }
 } while(0);
 $80 = ($81>>>0)>($bhi$2>>>0);
 $82 = ($81|0)==($bhi$2|0);
 $83 = ($84>>>0)>($bmi$2>>>0);
 $85 = $82 & $83;
 $86 = $80 | $85;
 if ($86) {
  label = 21;
 } else {
  $87 = ($84|0)!=($bmi$2|0);
  $88 = ($81|0)!=($bhi$2|0);
  $89 = $87 | $88;
  $90 = ($91>>>0)<($blo$1>>>0);
  $92 = ($91|0)==($blo$1|0);
  $93 = ($94>>>0)<(0);
  $95 = $92 & $93;
  $96 = $90 | $95;
  $or$cond5 = $89 | $96;
  if ($or$cond5) {
   $112 = $81;$115 = $84;$128 = $94;$129 = $91;$extraBit$0 = 0;
  } else {
   label = 21;
  }
 }
 if ((label|0) == 21) {
  $97 = (_i64Subtract(($94|0),($91|0),0,($blo$1|0))|0);
  $98 = tempRet0;
  $99 = ($91>>>0)<($blo$1>>>0);
  $100 = ($91|0)==($blo$1|0);
  $101 = ($94>>>0)<(0);
  $102 = $100 & $101;
  $103 = $99 | $102;
  $104 = $103 << 31 >> 31;
  $105 = ($104|0)<(0);
  $106 = $105 << 31 >> 31;
  $107 = (_i64Add(($104|0),($106|0),($84|0),($81|0))|0);
  $108 = tempRet0;
  $109 = (_i64Subtract(($107|0),($108|0),($bmi$2|0),($bhi$2|0))|0);
  $110 = tempRet0;
  $112 = $110;$115 = $109;$128 = $97;$129 = $98;$extraBit$0 = 1;
 }
 $111 = ($bhi$2>>>0)>($112>>>0);
 $113 = ($bhi$2|0)==($112|0);
 $114 = (0)>($115>>>0);
 $116 = $113 & $114;
 $117 = $111 | $116;
 if ($117) {
  $118 = (___udivdi3(($115|0),($112|0),($bhi$2|0),0)|0);
  $119 = tempRet0;
  $c$0$i$i = $118;
 } else {
  $c$0$i$i = -1;
 }
 $120 = (___muldi3(($c$0$i$i|0),0,($blo$1|0),0)|0);
 $121 = tempRet0;
 $122 = (___muldi3(($c$0$i$i|0),0,($bmi$2|0),0)|0);
 $123 = tempRet0;
 $124 = (_i64Add(($121|0),0,($122|0),($123|0))|0);
 $125 = tempRet0;
 $126 = (___muldi3(($c$0$i$i|0),0,($bhi$2|0),0)|0);
 $127 = tempRet0;
 $130 = (_i64Subtract(($128|0),($129|0),($120|0),($124|0))|0);
 $131 = tempRet0;
 $132 = ($124>>>0)>($129>>>0);
 $133 = ($124|0)==($129|0);
 $134 = ($120>>>0)>($128>>>0);
 $135 = $133 & $134;
 $136 = $132 | $135;
 $137 = $136 << 31 >> 31;
 $138 = ($137|0)<(0);
 $139 = $138 << 31 >> 31;
 $140 = (_i64Subtract(($115|0),($112|0),($126|0),($127|0))|0);
 $141 = tempRet0;
 $142 = (_i64Subtract(($140|0),($141|0),($125|0),0)|0);
 $143 = tempRet0;
 $144 = (_i64Add(($142|0),($143|0),($137|0),($139|0))|0);
 $145 = tempRet0;
 $146 = ($145|0)<(0);
 if ($146) {
  $148 = $130;$149 = $131;$158 = $144;$159 = $145;$c$15$i$i = $c$0$i$i;
  while(1) {
   $147 = (($c$15$i$i) + -1)|0;
   $150 = (_i64Add(($148|0),($149|0),($blo$1|0),($bmi$2|0))|0);
   $151 = tempRet0;
   $152 = ($151>>>0)<($bmi$2>>>0);
   $153 = ($151|0)==($bmi$2|0);
   $154 = ($150>>>0)<($blo$1>>>0);
   $155 = $153 & $154;
   $156 = $152 | $155;
   $157 = $156&1;
   $160 = (_i64Add(($158|0),($159|0),($bhi$2|0),0)|0);
   $161 = tempRet0;
   $162 = (_i64Add(($160|0),($161|0),($157|0),0)|0);
   $163 = tempRet0;
   $164 = ($163|0)<(0);
   if ($164) {
    $148 = $150;$149 = $151;$158 = $162;$159 = $163;$c$15$i$i = $147;
   } else {
    $166 = $162;$169 = $151;$182 = $150;$374 = $163;$c$1$lcssa$i$i = $147;
    break;
   }
  }
 } else {
  $166 = $144;$169 = $131;$182 = $130;$374 = $145;$c$1$lcssa$i$i = $c$0$i$i;
 }
 $165 = ($166>>>0)<($bhi$2>>>0);
 $167 = ($166|0)==($bhi$2|0);
 $168 = ($169>>>0)<(0);
 $170 = $167 & $168;
 $171 = $165 | $170;
 if ($171) {
  $172 = (___udivdi3(($169|0),($166|0),($bhi$2|0),0)|0);
  $173 = tempRet0;
  $c$0$i12$i = $172;
 } else {
  $c$0$i12$i = -1;
 }
 $174 = (___muldi3(($c$0$i12$i|0),0,($blo$1|0),0)|0);
 $175 = tempRet0;
 $176 = (___muldi3(($c$0$i12$i|0),0,($bmi$2|0),0)|0);
 $177 = tempRet0;
 $178 = (_i64Add(($175|0),0,($176|0),($177|0))|0);
 $179 = tempRet0;
 $180 = (___muldi3(($c$0$i12$i|0),0,($bhi$2|0),0)|0);
 $181 = tempRet0;
 $183 = (_i64Subtract(0,($182|0),($174|0),($178|0))|0);
 $184 = tempRet0;
 $185 = ($182>>>0)<($178>>>0);
 $186 = ($182|0)==($178|0);
 $187 = (0)<($174>>>0);
 $188 = $186 & $187;
 $189 = $185 | $188;
 $190 = $189 << 31 >> 31;
 $191 = ($190|0)<(0);
 $192 = $191 << 31 >> 31;
 $193 = (_i64Subtract(($169|0),($166|0),($180|0),($181|0))|0);
 $194 = tempRet0;
 $195 = (_i64Subtract(($193|0),($194|0),($179|0),0)|0);
 $196 = tempRet0;
 $197 = (_i64Add(($195|0),($196|0),($190|0),($192|0))|0);
 $198 = tempRet0;
 $199 = ($198|0)<(0);
 if ($199) {
  $201 = $183;$202 = $184;$211 = $197;$212 = $198;$c$15$i16$i = $c$0$i12$i;
  while(1) {
   $200 = (($c$15$i16$i) + -1)|0;
   $203 = (_i64Add(($201|0),($202|0),($blo$1|0),($bmi$2|0))|0);
   $204 = tempRet0;
   $205 = ($204>>>0)<($bmi$2>>>0);
   $206 = ($204|0)==($bmi$2|0);
   $207 = ($203>>>0)<($blo$1>>>0);
   $208 = $206 & $207;
   $209 = $205 | $208;
   $210 = $209&1;
   $213 = (_i64Add(($211|0),($212|0),($bhi$2|0),0)|0);
   $214 = tempRet0;
   $215 = (_i64Add(($213|0),($214|0),($210|0),0)|0);
   $216 = tempRet0;
   $217 = ($216|0)<(0);
   if ($217) {
    $201 = $203;$202 = $204;$211 = $215;$212 = $216;$c$15$i16$i = $200;
   } else {
    $223 = $215;$226 = $204;$240 = $203;$375 = $216;$c$1$lcssa$i19$i = $200;
    break;
   }
  }
 } else {
  $223 = $197;$226 = $184;$240 = $183;$375 = $198;$c$1$lcssa$i19$i = $c$0$i12$i;
 }
 $218 = $pchi;
 $219 = $218;
 HEAP32[$219>>2] = $c$1$lcssa$i19$i;
 $220 = (($218) + 4)|0;
 $221 = $220;
 HEAP32[$221>>2] = $c$1$lcssa$i$i;
 $222 = ($223>>>0)<($bhi$2>>>0);
 $224 = ($223|0)==($bhi$2|0);
 $225 = ($226>>>0)<(0);
 $227 = $224 & $225;
 $228 = $222 | $227;
 if ($228) {
  $229 = (___udivdi3(($226|0),($223|0),($bhi$2|0),0)|0);
  $230 = tempRet0;
  $c$0$i1$i = $229;
 } else {
  $c$0$i1$i = -1;
 }
 $231 = (___muldi3(($c$0$i1$i|0),0,($blo$1|0),0)|0);
 $232 = tempRet0;
 $233 = (___muldi3(($c$0$i1$i|0),0,($bmi$2|0),0)|0);
 $234 = tempRet0;
 $235 = (_i64Add(($232|0),0,($233|0),($234|0))|0);
 $236 = tempRet0;
 $237 = (___muldi3(($c$0$i1$i|0),0,($bhi$2|0),0)|0);
 $238 = tempRet0;
 $239 = ($240>>>0)<($235>>>0);
 $241 = ($240|0)==($235|0);
 $242 = (0)<($231>>>0);
 $243 = $241 & $242;
 $244 = $239 | $243;
 $245 = $244 << 31 >> 31;
 $246 = ($245|0)<(0);
 $247 = $246 << 31 >> 31;
 $248 = (_i64Subtract(($226|0),($223|0),($237|0),($238|0))|0);
 $249 = tempRet0;
 $250 = (_i64Subtract(($248|0),($249|0),($236|0),0)|0);
 $251 = tempRet0;
 $252 = (_i64Add(($250|0),($251|0),($245|0),($247|0))|0);
 $253 = tempRet0;
 $254 = ($253|0)<(0);
 if ($254) {
  $255 = (_i64Subtract(0,($240|0),($231|0),($235|0))|0);
  $256 = tempRet0;
  $258 = $255;$259 = $256;$268 = $252;$269 = $253;$c$15$i5$i = $c$0$i1$i;
  while(1) {
   $257 = (($c$15$i5$i) + -1)|0;
   $260 = (_i64Add(($258|0),($259|0),($blo$1|0),($bmi$2|0))|0);
   $261 = tempRet0;
   $262 = ($261>>>0)<($bmi$2>>>0);
   $263 = ($261|0)==($bmi$2|0);
   $264 = ($260>>>0)<($blo$1>>>0);
   $265 = $263 & $264;
   $266 = $262 | $265;
   $267 = $266&1;
   $270 = (_i64Add(($268|0),($269|0),($bhi$2|0),0)|0);
   $271 = tempRet0;
   $272 = (_i64Add(($270|0),($271|0),($267|0),0)|0);
   $273 = tempRet0;
   $274 = ($273|0)<(0);
   if ($274) {
    $258 = $260;$259 = $261;$268 = $272;$269 = $273;$c$15$i5$i = $257;
   } else {
    $276 = $273;$279 = $272;$c$1$lcssa$i8$i = $257;
    break;
   }
  }
 } else {
  $276 = $253;$279 = $252;$c$1$lcssa$i8$i = $c$0$i1$i;
 }
 $275 = ($276>>>0)<(0);
 $277 = ($276|0)==(0);
 $278 = ($279>>>0)<($bhi$2>>>0);
 $280 = $277 & $278;
 $281 = $275 | $280;
 if ($281) {
  $282 = (___udivdi3(0,($279|0),($bhi$2|0),0)|0);
  $283 = tempRet0;
  $285 = 0;$288 = $282;
 } else {
  $285 = 0;$288 = -1;
 }
 $284 = $285 | $c$1$lcssa$i8$i;
 $286 = $pclo;
 $287 = $286;
 HEAP32[$287>>2] = $288;
 $289 = (($286) + 4)|0;
 $290 = $289;
 HEAP32[$290>>2] = $284;
 $291 = (($ashift$2) + 128)|0;
 $292 = (($291) - ($bshift$2))|0;
 if ($extraBit$0) {
  $293 = (_bitshift64Lshr(($288|0),($284|0),1)|0);
  $294 = tempRet0;
  $295 = $pclo;
  $296 = $295;
  HEAP32[$296>>2] = $293;
  $297 = (($295) + 4)|0;
  $298 = $297;
  HEAP32[$298>>2] = $294;
  $299 = $pchi;
  $300 = $299;
  $301 = HEAP32[$300>>2]|0;
  $302 = (($299) + 4)|0;
  $303 = $302;
  $304 = HEAP32[$303>>2]|0;
  $305 = (_bitshift64Shl(($301|0),($304|0),63)|0);
  $306 = tempRet0;
  $307 = $305 | $293;
  $308 = $306 | $294;
  $309 = $pclo;
  $310 = $309;
  HEAP32[$310>>2] = $307;
  $311 = (($309) + 4)|0;
  $312 = $311;
  HEAP32[$312>>2] = $308;
  $313 = $pchi;
  $314 = $313;
  $315 = HEAP32[$314>>2]|0;
  $316 = (($313) + 4)|0;
  $317 = $316;
  $318 = HEAP32[$317>>2]|0;
  $319 = (_bitshift64Lshr(($315|0),($318|0),1)|0);
  $320 = tempRet0;
  $321 = $320 | -2147483648;
  $322 = $pchi;
  $323 = $322;
  HEAP32[$323>>2] = $319;
  $324 = (($322) + 4)|0;
  $325 = $324;
  HEAP32[$325>>2] = $321;
  $326 = (($292) + -1)|0;
  $texp$0$ph = $326;
 } else {
  $texp$0$ph = $292;
 }
 $327 = ($texp$0$ph|0)>(0);
 L66: do {
  if ($327) {
   $texp$012 = $texp$0$ph;
   while(1) {
    $328 = $pclo;
    $329 = $328;
    $330 = HEAP32[$329>>2]|0;
    $331 = (($328) + 4)|0;
    $332 = $331;
    $333 = HEAP32[$332>>2]|0;
    $334 = $330 & 1;
    $335 = ($334|0)==(0);
    $336 = (0)==(0);
    $337 = $335 & $336;
    if (!($337)) {
     $texp$0$lcssa = $texp$012;
     break L66;
    }
    $338 = (_bitshift64Lshr(($330|0),($333|0),1)|0);
    $339 = tempRet0;
    $340 = $pclo;
    $341 = $340;
    HEAP32[$341>>2] = $338;
    $342 = (($340) + 4)|0;
    $343 = $342;
    HEAP32[$343>>2] = $339;
    $344 = $pchi;
    $345 = $344;
    $346 = HEAP32[$345>>2]|0;
    $347 = (($344) + 4)|0;
    $348 = $347;
    $349 = HEAP32[$348>>2]|0;
    $350 = (_bitshift64Shl(($346|0),($349|0),63)|0);
    $351 = tempRet0;
    $352 = $350 | $338;
    $353 = $351 | $339;
    $354 = $pclo;
    $355 = $354;
    HEAP32[$355>>2] = $352;
    $356 = (($354) + 4)|0;
    $357 = $356;
    HEAP32[$357>>2] = $353;
    $358 = $pchi;
    $359 = $358;
    $360 = HEAP32[$359>>2]|0;
    $361 = (($358) + 4)|0;
    $362 = $361;
    $363 = HEAP32[$362>>2]|0;
    $364 = (_bitshift64Lshr(($360|0),($363|0),1)|0);
    $365 = tempRet0;
    $366 = $pchi;
    $367 = $366;
    HEAP32[$367>>2] = $364;
    $368 = (($366) + 4)|0;
    $369 = $368;
    HEAP32[$369>>2] = $365;
    $370 = (($texp$012) + -1)|0;
    $371 = ($370|0)>(0);
    if ($371) {
     $texp$012 = $370;
    } else {
     $texp$0$lcssa = $370;
     break;
    }
   }
  } else {
   $texp$0$lcssa = $texp$0$ph;
  }
 } while(0);
 HEAP32[$pExp>>2] = $texp$0$lcssa;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal14decimal2doubleEP19il2cpp_decimal_repr($pA) {
 $pA = $pA|0;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$0 = 0, $i$0$i$i = 0, $or$cond = 0, $scale$0$i$0 = 0, $scale$0$ph = 0, $texp$0$ph = 0, $texp$0$us = 0, $texp$1$lcssa$us = 0, $texp$17$us = 0, $texp$2$lcssa = 0;
 var $texp$22 = 0, $texp$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($pA) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($pA) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($pA) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==(0);
 $7 = ($1|0)==(0);
 $8 = $6 & $7;
 $9 = ($5|0)==(0);
 $or$cond = $8 & $9;
 if ($or$cond) {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $10 = HEAP32[$pA>>2]|0;
 $11 = $10 >>> 16;
 $12 = $11 & 255;
 $145 = 0;$146 = $5;$42 = $1;$45 = $3;$scale$0$ph = $12;$texp$0$ph = 0;
 while(1) {
  $13 = ($scale$0$ph|0)>(0);
  if ($13) {
   $147 = $145;$148 = $146;$35 = $42;$38 = $45;$texp$0$us = $texp$0$ph;
  } else {
   break;
  }
  while(1) {
   $34 = ($35|0)>(-1);
   $36 = ($35|0)==(-1);
   $37 = ($38>>>0)>(4294967295);
   $39 = $36 & $37;
   $40 = $34 | $39;
   if ($40) {
    $16 = $38;$17 = $35;$20 = $147;$21 = $148;$texp$17$us = $texp$0$us;
    while(1) {
     $18 = (_bitshift64Shl(($16|0),($17|0),1)|0);
     $19 = tempRet0;
     $22 = (_bitshift64Lshr(($20|0),($21|0),63)|0);
     $23 = tempRet0;
     $24 = $18 | $22;
     $25 = $19 | $23;
     $26 = (_bitshift64Shl(($20|0),($21|0),1)|0);
     $27 = tempRet0;
     $28 = (($texp$17$us) + 1)|0;
     $29 = ($25|0)>(-1);
     $30 = ($25|0)==(-1);
     $31 = ($24>>>0)>(4294967295);
     $32 = $30 & $31;
     $33 = $29 | $32;
     if ($33) {
      $16 = $24;$17 = $25;$20 = $26;$21 = $27;$texp$17$us = $28;
     } else {
      $15 = $25;$72 = $24;$79 = $27;$86 = $26;$texp$1$lcssa$us = $28;
      break;
     }
    }
   } else {
    $15 = $35;$72 = $38;$79 = $148;$86 = $147;$texp$1$lcssa$us = $texp$0$us;
   }
   $14 = ($15>>>0)>(4);
   if ($14) {
    $i$0$i$i = 32;
    break;
   } else {
    $147 = $86;$148 = $79;$35 = $15;$38 = $72;$texp$0$us = $texp$1$lcssa$us;
   }
  }
  while(1) {
   $48 = ($i$0$i$i|0)>(0);
   if (!($48)) {
    $57 = 0;
    label = 11;
    break;
   }
   $49 = (($i$0$i$i) + -1)|0;
   $50 = 1 << $49;
   $51 = $50 & $15;
   $52 = ($51|0)==(0);
   if ($52) {
    $i$0$i$i = $49;
   } else {
    label = 10;
    break;
   }
  }
  if ((label|0) == 10) {
   label = 0;
   $53 = ($i$0$i$i*1000)|0;
   $54 = (($53|0) / 2322)&-1;
   $55 = ($53|0)<(20898);
   if ($55) {
    $57 = $54;
    label = 11;
   } else {
    $i$0 = 9;
   }
  }
  if ((label|0) == 11) {
   label = 0;
   $56 = (197336 + ($57<<2)|0);
   $58 = HEAP32[$56>>2]|0;
   $59 = $58 >>> $57;
   $60 = (($15>>>0) / ($59>>>0))&-1;
   $61 = (($60) + ($57))|0;
   $i$0 = $61;
  }
  $62 = ($i$0|0)>($scale$0$ph|0);
  $scale$0$i$0 = $62 ? $scale$0$ph : $i$0;
  $63 = (197336 + ($scale$0$i$0<<2)|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = $64 >>> $scale$0$i$0;
  $66 = (___udivdi3(($15|0),0,($65|0),0)|0);
  $67 = tempRet0;
  $68 = (___muldi3(($65|0),0,($66|0),($67|0))|0);
  $69 = tempRet0;
  $70 = (_i64Subtract(($15|0),0,($68|0),($69|0))|0);
  $71 = tempRet0;
  $73 = (___udivdi3(($72|0),($70|0),($65|0),0)|0);
  $74 = tempRet0;
  $75 = (___muldi3(($65|0),0,($73|0),($74|0))|0);
  $76 = tempRet0;
  $77 = (_i64Subtract(($72|0),($15|0),($75|0),($76|0))|0);
  $78 = tempRet0;
  $80 = (___udivdi3(($79|0),($77|0),($65|0),0)|0);
  $81 = tempRet0;
  $82 = (___muldi3(($80|0),($81|0),($65|0),0)|0);
  $83 = tempRet0;
  $84 = (_i64Subtract(($79|0),0,($82|0),($83|0))|0);
  $85 = tempRet0;
  $87 = (___udivdi3(($86|0),($84|0),($65|0),0)|0);
  $88 = tempRet0;
  $89 = (($scale$0$ph) - ($scale$0$i$0))|0;
  $90 = (($scale$0$i$0) + ($texp$1$lcssa$us))|0;
  $145 = $87;$146 = $80;$42 = $66;$45 = $73;$scale$0$ph = $89;$texp$0$ph = $90;
 }
 $41 = ($42|0)>(-1);
 $43 = ($42|0)==(-1);
 $44 = ($45>>>0)>(4294967295);
 $46 = $43 & $44;
 $47 = $41 | $46;
 if ($47) {
  $91 = $45;$92 = $42;$95 = $145;$96 = $146;$texp$22 = $texp$0$ph;
  while(1) {
   $93 = (_bitshift64Shl(($91|0),($92|0),1)|0);
   $94 = tempRet0;
   $97 = (_bitshift64Lshr(($95|0),($96|0),63)|0);
   $98 = tempRet0;
   $99 = $93 | $97;
   $100 = $94 | $98;
   $101 = (_bitshift64Shl(($95|0),($96|0),1)|0);
   $102 = tempRet0;
   $103 = (($texp$22) + 1)|0;
   $104 = ($100|0)>(-1);
   $105 = ($100|0)==(-1);
   $106 = ($99>>>0)>(4294967295);
   $107 = $105 & $106;
   $108 = $104 | $107;
   if ($108) {
    $91 = $99;$92 = $100;$95 = $101;$96 = $102;$texp$22 = $103;
   } else {
    $109 = $99;$110 = $100;$texp$2$lcssa = $103;
    break;
   }
  }
 } else {
  $109 = $45;$110 = $42;$texp$2$lcssa = $texp$0$ph;
 }
 $111 = (_i64Add(($109|0),($110|0),1024,0)|0);
 $112 = tempRet0;
 $113 = ($112|0)>(-1);
 $114 = ($112|0)==(-1);
 $115 = ($111>>>0)>(4294967295);
 $116 = $114 & $115;
 $117 = $113 | $116;
 if ($117) {
  $118 = (_bitshift64Lshr(($111|0),($112|0),1)|0);
  $119 = tempRet0;
  $120 = (($texp$2$lcssa) + -1)|0;
  $128 = $118;$129 = $119;$texp$3 = $120;
 } else {
  $121 = $109 & 1024;
  $122 = ($121|0)==(0);
  $123 = (0)==(0);
  $124 = $122 & $123;
  $125 = $111 & -2;
  $126 = $124 ? $125 : $111;
  $127 = $124 ? $112 : $112;
  $128 = $126;$129 = $127;$texp$3 = $texp$2$lcssa;
 }
 $130 = (_bitshift64Lshr(($128|0),($129|0),11)|0);
 $131 = tempRet0;
 $132 = $131 & 1048575;
 $133 = $10 >>> 31;
 $134 = (_bitshift64Shl(($133|0),0,63)|0);
 $135 = tempRet0;
 $136 = (1118 - ($texp$3))|0;
 $137 = $136 & 2047;
 $138 = (_bitshift64Shl(($137|0),0,52)|0);
 $139 = tempRet0;
 $140 = $134 | $130;
 $141 = $135 | $132;
 $142 = $140 | $138;
 $143 = $141 | $139;
 HEAP32[tempDoublePtr>>2] = $142;HEAP32[tempDoublePtr+4>>2] = $143;$144 = +HEAPF64[tempDoublePtr>>3];
 $$0 = $144;
 STACKTOP = sp;return (+$$0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal14decimal2stringEP19il2cpp_decimal_repriiP11Il2CppArrayiPiS8_($val,$digits,$decimals,$bufDigits,$bufSize,$decPos,$sign) {
 $val = $val|0;
 $digits = $digits|0;
 $decimals = $decimals|0;
 $bufDigits = $bufDigits|0;
 $bufSize = $bufSize|0;
 $decPos = $decPos|0;
 $sign = $sign|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 197408;
 (_printf((197376|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Decimal13decimalIntDivEP19il2cpp_decimal_reprS5_S5_($pC,$pA,$pB) {
 $pC = $pC|0;
 $pA = $pA|0;
 $pB = $pB|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $chi = 0, $clo = 0, $or$cond$i = 0, $pA$idx = 0, $pA$idx$val = 0, $pA$idx1 = 0, $pA$idx1$val = 0, $pA$idx2 = 0, $pA$idx2$val = 0, $pB$idx = 0, $pB$idx$val = 0, $pB$idx3 = 0, $pB$idx3$val = 0, $pB$idx4 = 0, $pB$idx4$val = 0, $scale = 0, $texp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $clo = sp + 8|0;
 $chi = sp;
 $scale = sp + 20|0;
 $texp = sp + 16|0;
 $pA$idx = (($pA) + 4|0);
 $pA$idx$val = HEAP32[$pA$idx>>2]|0;
 $pA$idx1 = (($pA) + 8|0);
 $pA$idx1$val = HEAP32[$pA$idx1>>2]|0;
 $pA$idx2 = (($pA) + 12|0);
 $pA$idx2$val = HEAP32[$pA$idx2>>2]|0;
 $pB$idx = (($pB) + 4|0);
 $pB$idx$val = HEAP32[$pB$idx>>2]|0;
 $pB$idx3 = (($pB) + 8|0);
 $pB$idx3$val = HEAP32[$pB$idx3>>2]|0;
 $pB$idx4 = (($pB) + 12|0);
 $pB$idx4$val = HEAP32[$pB$idx4>>2]|0;
 $0 = (__ZL13decimalDivSubP19il2cpp_decimal_reprS0_PyS1_Pi($pA$idx$val,$pA$idx1$val,$pA$idx2$val,$pB$idx$val,$pB$idx3$val,$pB$idx4$val,$clo,$chi,$texp)|0);
 if ((($0|0) == 1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($0|0) == 0)) {
  $1 = HEAP32[$pA>>2]|0;
  $2 = $1 >>> 16;
  $3 = $2 & 255;
  $4 = HEAP32[$pB>>2]|0;
  $5 = $4 >>> 16;
  $6 = $5 & 255;
  $7 = (($3) - ($6))|0;
  HEAP32[$scale>>2] = $7;
  $8 = HEAP32[$texp>>2]|0;
  $9 = (__ZL10rescale128PyS_Piiiii($clo,$chi,$scale,$8,0,0)|0);
  $10 = ($9|0)==(0);
  if (!($10)) {
   $$0 = $9;
   STACKTOP = sp;return ($$0|0);
  }
  $11 = $clo;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = $chi;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$scale>>2]|0;
  $24 = ($23>>>0)>(28);
  $25 = ($22>>>0)>(0);
  $26 = ($22|0)==(0);
  $27 = ($19>>>0)>(4294967295);
  $28 = $26 & $27;
  $29 = $25 | $28;
  $or$cond$i = $24 | $29;
  if ($or$cond$i) {
   $$0 = 2;
   STACKTOP = sp;return ($$0|0);
  }
  $30 = HEAP32[$pA>>2]|0;
  $31 = $30 & -2147483648;
  $32 = (($pC) + 8|0);
  HEAP32[$32>>2] = $13;
  $33 = (($pC) + 12|0);
  HEAP32[$33>>2] = $16;
  $34 = (($pC) + 4|0);
  HEAP32[$34>>2] = $19;
  $35 = HEAP32[$pC>>2]|0;
  $36 = $35 & 2130771967;
  $37 = $23 << 16;
  $38 = $37 & 16711680;
  $39 = $31 | $38;
  $40 = $39 | $36;
  HEAP32[$pC>>2] = $40;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Delegate23CreateDelegate_internalEP20Il2CppReflectionTypeP12Il2CppObjectP22Il2CppReflectionMethodb($__type,$target,$info,$throwOnBindFailure) {
 $__type = $__type|0;
 $target = $target|0;
 $info = $info|0;
 $throwOnBindFailure = $throwOnBindFailure|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (($info) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($2)|0);
 $6 = (($4) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($4|0)==(0|0);
 if (!($8)) {
  $9 = (($5) + 20|0);
  HEAP32[$9>>2] = $4;
 }
 $10 = 388936;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (_i64Add(($12|0),($15|0),1,0)|0);
 $17 = tempRet0;
 $18 = 388936;
 $19 = $18;
 HEAP32[$19>>2] = $16;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 $22 = (($5) + 8|0);
 HEAP32[$22>>2] = $7;
 $23 = (($5) + 16|0);
 HEAP32[$23>>2] = $target;
 $24 = (($4) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($5) + 12|0);
 HEAP32[$26>>2] = $25;
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Delegate18SetMulticastInvokeEP14Il2CppDelegate($delegate) {
 $delegate = $delegate|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$delegate>>2]|0;
 $1 = (__ZN6il2cpp2vm5Class17GetMethodFromNameEP8TypeInfoPKci($0,197896,-1)|0);
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($delegate) + 12|0);
 HEAP32[$4>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System6Double9ParseImplEPcPd($ptr,$result) {
 $ptr = $ptr|0;
 $result = $result|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $endptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $endptr = sp;
 HEAP32[$endptr>>2] = 0;
 HEAPF64[$result>>3] = 0.0;
 $0 = HEAP8[$ptr>>0]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   $$0 = 0;
  } else {
   $2 = (+_strtod($ptr,$endptr));
   HEAPF64[$result>>3] = $2;
   $$pr = HEAP8[$ptr>>0]|0;
   $3 = ($$pr<<24>>24)==(0);
   if ($3) {
    $$0 = 0;
   } else {
    $4 = HEAP32[$endptr>>2]|0;
    $5 = ($4|0)==(0|0);
    if (!($5)) {
     $6 = HEAP8[$4>>0]|0;
     $7 = ($6<<24>>24)==(0);
     if (!($7)) {
      $$0 = 0;
      break;
     }
    }
    $$0 = 1;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Enum9get_valueEP12Il2CppObject($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__this|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$__this>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__this) + 8|0);
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv($3,$4)|0);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Enum16compare_value_toEP12Il2CppObjectS5_($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 8|0);
 $1 = (($other) + 8|0);
 $2 = (__ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($__this)|0);
 $3 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($2)|0);
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 16;
 $7 = $6 & 255;
 switch ($7|0) {
 case 10:  {
  $60 = $0;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = (($60) + 4)|0;
  $64 = $63;
  $65 = HEAP32[$64>>2]|0;
  $66 = $1;
  $67 = $66;
  $68 = HEAP32[$67>>2]|0;
  $69 = (($66) + 4)|0;
  $70 = $69;
  $71 = HEAP32[$70>>2]|0;
  $72 = ($62|0)==($68|0);
  $73 = ($65|0)==($71|0);
  $74 = $72 & $73;
  if ($74) {
   $$0 = 0;
  } else {
   $75 = ($65|0)>($71|0);
   $76 = ($65|0)==($71|0);
   $77 = ($62>>>0)>($68>>>0);
   $78 = $76 & $77;
   $79 = $75 | $78;
   $80 = $79 ? 1 : -1;
   $$0 = $80;
  }
  break;
 }
 case 4:  {
  $13 = HEAP8[$0>>0]|0;
  $14 = HEAP8[$1>>0]|0;
  $15 = ($13<<24>>24)==($14<<24>>24);
  if ($15) {
   $$0 = 0;
  } else {
   $16 = ($13<<24>>24)>($14<<24>>24);
   $17 = $16 ? 1 : -1;
   $$0 = $17;
  }
  break;
 }
 case 11:  {
  $39 = $0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + 4)|0;
  $43 = $42;
  $44 = HEAP32[$43>>2]|0;
  $45 = $1;
  $46 = $45;
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + 4)|0;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = ($41|0)==($47|0);
  $52 = ($44|0)==($50|0);
  $53 = $51 & $52;
  if ($53) {
   $$0 = 0;
  } else {
   $54 = ($44>>>0)>($50>>>0);
   $55 = ($44|0)==($50|0);
   $56 = ($41>>>0)>($47>>>0);
   $57 = $55 & $56;
   $58 = $54 | $57;
   $59 = $58 ? 1 : -1;
   $$0 = $59;
  }
  break;
 }
 case 6:  {
  $24 = HEAP16[$0>>1]|0;
  $25 = HEAP16[$1>>1]|0;
  $26 = ($24<<16>>16)==($25<<16>>16);
  if ($26) {
   $$0 = 0;
  } else {
   $27 = ($24<<16>>16)>($25<<16>>16);
   $28 = $27 ? 1 : -1;
   $$0 = $28;
  }
  break;
 }
 case 5:  {
  $8 = HEAP8[$0>>0]|0;
  $9 = HEAP8[$1>>0]|0;
  $10 = ($8<<24>>24)==($9<<24>>24);
  if ($10) {
   $$0 = 0;
  } else {
   $11 = ($8&255)>($9&255);
   $12 = $11 ? 1 : -1;
   $$0 = $12;
  }
  break;
 }
 case 8:  {
  $34 = HEAP32[$0>>2]|0;
  $35 = HEAP32[$1>>2]|0;
  $36 = ($34|0)==($35|0);
  if ($36) {
   $$0 = 0;
  } else {
   $37 = ($34|0)>($35|0);
   $38 = $37 ? 1 : -1;
   $$0 = $38;
  }
  break;
 }
 case 7: case 3:  {
  $18 = HEAP16[$0>>1]|0;
  $19 = HEAP16[$1>>1]|0;
  $20 = ($18<<16>>16)==($19<<16>>16);
  if ($20) {
   $$0 = 0;
  } else {
   $21 = $18&65535;
   $22 = $19&65535;
   $23 = (($21) - ($22))|0;
   $$0 = $23;
  }
  break;
 }
 case 9:  {
  $29 = HEAP32[$0>>2]|0;
  $30 = HEAP32[$1>>2]|0;
  $31 = ($29|0)==($30|0);
  if ($31) {
   $$0 = 0;
  } else {
   $32 = ($29>>>0)>($30>>>0);
   $33 = $32 ? 1 : -1;
   $$0 = $33;
  }
  break;
 }
 default: {
  $$0 = 0;
 }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Enum12get_hashcodeEP12Il2CppObject($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$__this>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[((388944 + 20|0))>>2]|0;
 $5 = ($3|0)==($4|0);
 do {
  if ($5) {
   $6 = HEAP8[$0>>0]|0;
   $7 = $6 << 24 >> 24;
   $$0 = $7;
  } else {
   $8 = HEAP32[((388944 + 8|0))>>2]|0;
   $9 = ($3|0)==($8|0);
   if ($9) {
    $10 = HEAP8[$0>>0]|0;
    $11 = $10&255;
    $$0 = $11;
    break;
   }
   $12 = HEAP32[((388944 + 64|0))>>2]|0;
   $13 = ($3|0)==($12|0);
   $14 = HEAP32[((388944 + 28|0))>>2]|0;
   $15 = ($3|0)==($14|0);
   $or$cond = $13 | $15;
   if ($or$cond) {
    $16 = HEAP16[$0>>1]|0;
    $17 = $16&65535;
    $$0 = $17;
    break;
   }
   $18 = HEAP32[((388944 + 24|0))>>2]|0;
   $19 = ($3|0)==($18|0);
   if ($19) {
    $20 = HEAP16[$0>>1]|0;
    $21 = $20&65535;
    $$0 = $21;
    break;
   }
   $22 = HEAP32[((388944 + 36|0))>>2]|0;
   $23 = ($3|0)==($22|0);
   if ($23) {
    $24 = HEAP32[$0>>2]|0;
    $$0 = $24;
    break;
   }
   $25 = HEAP32[((388944 + 32|0))>>2]|0;
   $26 = ($3|0)==($25|0);
   if ($26) {
    $27 = HEAP32[$0>>2]|0;
    $$0 = $27;
    break;
   } else {
    $28 = $0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 4)|0;
    $32 = $31;
    $33 = HEAP32[$32>>2]|0;
    $34 = $33 ^ $30;
    $$0 = $34;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Enum8ToObjectEP20Il2CppReflectionTypeP12Il2CppObject($enumType,$value) {
 $enumType = $enumType|0;
 $value = $value|0;
 var $$c = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $or$cond$i = 0, $or$cond3$i = 0, $or$cond5$i = 0, $or$cond7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($enumType|0)==(0|0);
 if ($0) {
  $1 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(197904)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 }
 $2 = ($value|0)==(0|0);
 if ($2) {
  $3 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(197920)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
 }
 $4 = (($enumType) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($5)|0);
 $7 = (__ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($value)|0);
 $8 = (__ZN6il2cpp2vm5Class15GetElementClassEP8TypeInfo($6)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (__ZN6il2cpp2vm9Exception20GetArgumentExceptionEPKcS3_(197928,197904)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($10);
 }
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($6)|0);
 $12 = (($value) + 8|0);
 $13 = (($7) + 117|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $20 = $7;
 } else {
  $16 = (($7) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  $20 = $17;
 }
 $18 = HEAP32[((388944 + 8|0))>>2]|0;
 $19 = ($18|0)==($20|0);
 do {
  if ($19) {
   $21 = HEAP8[$12>>0]|0;
   $22 = $21 << 24 >> 24;
   $23 = ($22|0)<(0);
   $24 = $23 << 31 >> 31;
   $$pre = HEAP32[((388944 + 20|0))>>2]|0;
   $66 = $$pre;$68 = $22;$86 = $24;
  } else {
   $25 = HEAP32[((388944 + 20|0))>>2]|0;
   $26 = ($25|0)==($20|0);
   if ($26) {
    $27 = HEAP8[$12>>0]|0;
    $28 = $27&255;
    $66 = $20;$68 = $28;$86 = 0;
    break;
   }
   $29 = HEAP32[((388944 + 28|0))>>2]|0;
   $30 = ($29|0)==($20|0);
   if ($30) {
    $31 = HEAP16[$12>>1]|0;
    $32 = $31&65535;
    $66 = $25;$68 = $32;$86 = 0;
    break;
   }
   $33 = HEAP32[((388944 + 24|0))>>2]|0;
   $34 = ($33|0)==($20|0);
   if ($34) {
    $35 = HEAP16[$12>>1]|0;
    $36 = $35 << 16 >> 16;
    $37 = ($36|0)<(0);
    $38 = $37 << 31 >> 31;
    $66 = $25;$68 = $36;$86 = $38;
    break;
   }
   $39 = HEAP32[((388944 + 36|0))>>2]|0;
   $40 = ($39|0)==($20|0);
   if ($40) {
    $41 = HEAP32[$12>>2]|0;
    $66 = $25;$68 = $41;$86 = 0;
    break;
   }
   $42 = HEAP32[((388944 + 32|0))>>2]|0;
   $43 = ($42|0)==($20|0);
   if ($43) {
    $44 = HEAP32[$12>>2]|0;
    $45 = ($44|0)<(0);
    $46 = $45 << 31 >> 31;
    $66 = $25;$68 = $44;$86 = $46;
    break;
   }
   $47 = HEAP32[((388944 + 52|0))>>2]|0;
   $48 = ($47|0)==($20|0);
   if ($48) {
    $49 = $12;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = (($49) + 4)|0;
    $53 = $52;
    $54 = HEAP32[$53>>2]|0;
    $66 = $25;$68 = $51;$86 = $54;
    break;
   }
   $55 = HEAP32[((388944 + 48|0))>>2]|0;
   $56 = ($55|0)==($20|0);
   if ($56) {
    $57 = $12;
    $58 = $57;
    $59 = HEAP32[$58>>2]|0;
    $60 = (($57) + 4)|0;
    $61 = $60;
    $62 = HEAP32[$61>>2]|0;
    $66 = $25;$68 = $59;$86 = $62;
   } else {
    $66 = $25;$68 = 0;$86 = 0;
   }
  }
 } while(0);
 $63 = (($11) + 8|0);
 $64 = ($18|0)==($8|0);
 $65 = ($66|0)==($8|0);
 $or$cond$i = $64 | $65;
 if ($or$cond$i) {
  $67 = $68&255;
  HEAP8[$63>>0] = $67;
  STACKTOP = sp;return ($11|0);
 }
 $69 = HEAP32[((388944 + 28|0))>>2]|0;
 $70 = ($69|0)==($8|0);
 $71 = HEAP32[((388944 + 24|0))>>2]|0;
 $72 = ($71|0)==($8|0);
 $or$cond3$i = $70 | $72;
 if ($or$cond3$i) {
  $73 = $68&65535;
  HEAP16[$63>>1] = $73;
  STACKTOP = sp;return ($11|0);
 }
 $74 = HEAP32[((388944 + 36|0))>>2]|0;
 $75 = ($74|0)==($8|0);
 $76 = HEAP32[((388944 + 32|0))>>2]|0;
 $77 = ($76|0)==($8|0);
 $or$cond5$i = $75 | $77;
 if ($or$cond5$i) {
  $$c = $68;
  HEAP32[$63>>2] = $$c;
  STACKTOP = sp;return ($11|0);
 }
 $78 = HEAP32[((388944 + 52|0))>>2]|0;
 $79 = ($78|0)==($8|0);
 $80 = HEAP32[((388944 + 48|0))>>2]|0;
 $81 = ($80|0)==($8|0);
 $or$cond7$i = $79 | $81;
 if (!($or$cond7$i)) {
  STACKTOP = sp;return ($11|0);
 }
 $82 = $63;
 $83 = $82;
 HEAP32[$83>>2] = $68;
 $84 = (($82) + 4)|0;
 $85 = $84;
 HEAP32[$85>>2] = $86;
 STACKTOP = sp;return ($11|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Enum19get_underlying_typeEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($2)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (__ZN6il2cpp2vm9Exception20GetArgumentExceptionEPKcS3_(197928,197904)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($5);
 }
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($3)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment15get_MachineNameEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN6il2cpp2os11Environment14GetMachineNameEv($0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 __THREW__ = 0;
 $8 = (invoke_ii(2990,($7|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return ($8|0);
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment11get_NewLineEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(197976)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment25get_SocketSecurityEnabledEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment13get_TickCountEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os4Time29GetTicksMillisecondsMonotonicEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment18get_ProcessorCountEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os11Environment17GetProcessorCountEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment18GetCommandLineArgsEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm11Environment14GetNumMainArgsEv()|0);
 $1 = (__ZN6il2cpp2vm11Environment11GetMainArgsEv()|0);
 (__ZN6il2cpp2vm6Domain10GetCurrentEv()|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[((388944 + 68|0))>>2]|0;
 $4 = (__ZN6il2cpp2vm5Class13GetArrayClassEP8TypeInfoj($3,1)|0);
 $5 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($4,$0)|0);
 $6 = ($0|0)>(0);
 if ($6) {
  $i$01 = 0;
 } else {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $7 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($5,4,$i$01)|0);
  $8 = (($1) + ($i$01<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZN6il2cpp2vm6String3NewEPKc($9)|0);
  HEAP32[$7>>2] = $10;
  $11 = (($i$01) + 1)|0;
  $exitcond = ($11|0)==($0|0);
  if ($exitcond) {
   $$0 = $5;
   break;
  } else {
   $i$01 = $11;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment27GetEnvironmentVariableNamesEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 198016;
 (_printf((197984|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment20GetWindowsFolderPathEi($folder) {
 $folder = $folder|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 198064;
 (_printf((197984|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment15internalGetHomeEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 198104;
 (_printf((197984|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment24GetLogicalDrivesInternalEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 198136;
 (_printf((197984|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment30InternalSetEnvironmentVariableEP12Il2CppStringS5_($variable,$value) {
 $variable = $variable|0;
 $value = $value|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 198176;
 (_printf((197984|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment30internalBroadcastSettingChangeEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 198224;
 (_printf((197984|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment20GetMachineConfigPathEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String3NewEPKc(198272)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment30internalGetEnvironmentVariableEP12Il2CppString($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment18GetOSVersionStringEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN6il2cpp2os11Environment18GetOsVersionStringEv($0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 __THREW__ = 0;
 $8 = (invoke_ii(2990,($7|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return ($8|0);
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment12get_PlatformEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 4;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment12get_ExitCodeEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[198280>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment12set_ExitCodeEi($value) {
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[198280>>2] = $value;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment22get_HasShutdownStartedEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(198288)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment21get_EmbeddingHostNameEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String3NewEPKc(198480)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment12get_UserNameEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN6il2cpp2os11Environment13GetOsUserNameEv($0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 __THREW__ = 0;
 $8 = (invoke_ii(2990,($7|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return ($8|0);
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System11Environment4ExitEi($exitCode) {
 $exitCode = $exitCode|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(198488)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2GC16SuppressFinalizeEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z28il2cpp_gc_suppress_finalizerP12Il2CppObject($obj);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2GC13GetGenerationEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24il2cpp_gc_get_generationPv($obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2GC9KeepAliveEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2GC15InternalCollectEi($generation) {
 $generation = $generation|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17il2cpp_gc_collecti($generation);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2GC17get_MaxGenerationEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24il2cpp_gc_max_generationv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2GC14RecordPressureEx($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2GC24WaitForPendingFinalizersEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z37il2cpp_gc_wait_for_pending_finalizersv();
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2GC14GetTotalMemoryEb($forceFullCollection) {
 $forceFullCollection = $forceFullCollection|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($forceFullCollection) {
  $0 = (__Z24il2cpp_gc_max_generationv()|0);
  __Z17il2cpp_gc_collecti($0);
 }
 $1 = (__Z23il2cpp_gc_get_used_sizev()|0);
 $2 = tempRet0;
 tempRet0 = $2;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2GC21ReRegisterForFinalizeEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z28il2cpp_gc_register_finalizerP12Il2CppObject($obj);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2GC15CollectionCountEi($generation) {
 $generation = $generation|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z26il2cpp_gc_collection_counti($generation)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math4AcosEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_acos((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math4AsinEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_asin((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math4AtanEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_atan((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math5Atan2Edd($y,$x) {
 $y = +$y;
 $x = +$x;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_atan2((+$y),(+$x)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math3CosEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_cos((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math4CoshEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_cosh((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math3ExpEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_exp((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math5FloorEd($x) {
 $x = +$x;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_floor((+$x)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math3LogEd($x) {
 $x = +$x;
 var $$0 = 0.0, $0 = 0, $1 = 0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x == 0.0;
 if ($0) {
  $$0 = -inf;
 } else {
  $1 = $x < 0.0;
  if ($1) {
   $$0 = nan;
  } else {
   $2 = (+Math_log((+$x)));
   $$0 = $2;
  }
 }
 STACKTOP = sp;return (+$$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math5Log10Ed($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_log10((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math3PowEdd($val,$exp) {
 $val = +$val;
 $exp = +$exp;
 var $$ = 0.0, $$0 = 0.0, $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_pow((+$val),(+$exp)));
 HEAPF64[tempDoublePtr>>3] = $0;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)>(2146435072);
 $5 = ($3|0)==(2146435072);
 $6 = ($1>>>0)>(0);
 $7 = $5 & $6;
 $8 = $4 | $7;
 if ($8) {
  $$0 = 1.0;
  STACKTOP = sp;return (+$$0);
 }
 $9 = $0 == -0.0;
 $$ = $9 ? 0.0 : $0;
 $$0 = $$;
 STACKTOP = sp;return (+$$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math5RoundEd($x) {
 $x = +$x;
 var $$old = 0, $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, $int_part$0 = 0.0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_floor((+$x)));
 $1 = $x - $0;
 $2 = $1 == 0.5;
 if ($2) {
  $3 = $0 * 0.5;
  $4 = (+Math_floor((+$3)));
  $5 = $3 - $4;
  $6 = $5 * 2.0;
  $7 = $6 != 0.0;
  $8 = $1 > 0.5;
  $or$cond = $7 | $8;
  if ($or$cond) {
   label = 4;
  } else {
   $int_part$0 = $0;
  }
 } else {
  $$old = $1 > 0.5;
  if ($$old) {
   label = 4;
  } else {
   $int_part$0 = $0;
  }
 }
 if ((label|0) == 4) {
  $9 = $0 + 1.0;
  $int_part$0 = $9;
 }
 STACKTOP = sp;return (+$int_part$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math3SinEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_sin((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math4SinhEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_sinh((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math4SqrtEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_sqrt((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math3TanEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_tan((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math4TanhEd($val) {
 $val = +$val;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_tanh((+$val)));
 STACKTOP = sp;return (+$0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Math6Round2Edib($value,$digits,$away_from_zero) {
 $value = +$value;
 $digits = $digits|0;
 $away_from_zero = $away_from_zero|0;
 var $$0 = 0.0, $$not = 0, $$old$i = 0, $$pn = 0.0, $$pn1 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0;
 var $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, $brmerge = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $value == inf;
 do {
  if ($0) {
   $$0 = inf;
  } else {
   $1 = $value == -inf;
   if ($1) {
    $$0 = -inf;
   } else {
    $$not = ($digits|0)!=(0);
    $brmerge = $$not | $away_from_zero;
    if (!($brmerge)) {
     $2 = (+Math_floor((+$value)));
     $3 = $value - $2;
     $4 = $3 == 0.5;
     if ($4) {
      $5 = $2 * 0.5;
      $6 = (+Math_floor((+$5)));
      $7 = $5 - $6;
      $8 = $7 * 2.0;
      $9 = $8 != 0.0;
      $10 = $3 > 0.5;
      $or$cond$i = $9 | $10;
      if (!($or$cond$i)) {
       $$0 = $2;
       break;
      }
     } else {
      $$old$i = $3 > 0.5;
      if (!($$old$i)) {
       $$0 = $2;
       break;
      }
     }
     $11 = $2 + 1.0;
     $$0 = $11;
     break;
    }
    $12 = (+($digits|0));
    $13 = (+Math_pow(10.0,(+$12)));
    $14 = $value >= 0.0;
    $15 = $13 * $value;
    if ($away_from_zero) {
     if ($14) {
      $16 = $15 + 0.5;
      $17 = (+Math_floor((+$16)));
      $$pn1 = $17;
     } else {
      $18 = $15 + -0.5;
      $19 = (+Math_ceil((+$18)));
      $$pn1 = $19;
     }
     $20 = $$pn1 / $13;
     $$0 = $20;
     break;
    } else {
     if ($14) {
      $21 = $15 + -0.5;
      $22 = (+Math_ceil((+$21)));
      $$pn = $22;
     } else {
      $23 = $15 + 0.5;
      $24 = (+Math_floor((+$23)));
      $$pn = $24;
     }
     $25 = $$pn / $13;
     $$0 = $25;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return (+$$0);
}
function __ZN6il2cpp6icalls8mscorlib6System15MonoCustomAttrs27GetCustomAttributesInternalEP12Il2CppObjectP20Il2CppReflectionTypeb($obj,$type,$pseudoAttrs) {
 $obj = $obj|0;
 $type = $type|0;
 $pseudoAttrs = $pseudoAttrs|0;
 var $$0 = 0, $$count$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0$lcssa = 0, $count$04 = 0, $i$03 = 0, $i2$02 = 0, $index$01 = 0, $index$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP12Il2CppObject($obj)|0);
 $1 = ($type|0)==(0|0);
 if ($1) {
  $2 = HEAP32[((388944 + 4|0))>>2]|0;
  $3 = HEAP32[$0>>2]|0;
  $4 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($2,$3)|0);
  $5 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($4,4,0)|0);
  $6 = (($0) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$0>>2]|0;
  $9 = $8 << 2;
  _memcpy(($5|0),($7|0),($9|0))|0;
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($type) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($11)|0);
 $13 = HEAP32[$0>>2]|0;
 $14 = ($13|0)>(0);
 if ($14) {
  $15 = (($0) + 4|0);
  $count$04 = 0;$i$03 = 0;
  while(1) {
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($i$03<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = (__ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_($12,$19)|0);
   $21 = $20&1;
   $$count$0 = (($21) + ($count$04))|0;
   $22 = (($i$03) + 1)|0;
   $23 = HEAP32[$0>>2]|0;
   $24 = ($22|0)<($23|0);
   if ($24) {
    $count$04 = $$count$0;$i$03 = $22;
   } else {
    $count$0$lcssa = $$count$0;
    break;
   }
  }
 } else {
  $count$0$lcssa = 0;
 }
 $25 = HEAP32[((388944 + 4|0))>>2]|0;
 $26 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($25,$count$0$lcssa)|0);
 $27 = HEAP32[$0>>2]|0;
 $28 = ($27|0)>(0);
 if (!($28)) {
  $$0 = $26;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($0) + 4|0);
 $i2$02 = 0;$index$01 = 0;
 while(1) {
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + ($i2$02<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (__ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_($12,$33)|0);
  if ($34) {
   $35 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($26,4,$index$01)|0);
   $36 = HEAP32[$29>>2]|0;
   $37 = (($36) + ($i2$02<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   HEAP32[$35>>2] = $38;
   $39 = (($index$01) + 1)|0;
   $index$1 = $39;
  } else {
   $index$1 = $index$01;
  }
  $40 = (($i2$02) + 1)|0;
  $41 = HEAP32[$0>>2]|0;
  $42 = ($40|0)<($41|0);
  if ($42) {
   $i2$02 = $40;$index$01 = $index$1;
  } else {
   $$0 = $26;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System15MonoCustomAttrs17IsDefinedInternalEP12Il2CppObjectP20Il2CppReflectionType($obj,$attr_type) {
 $obj = $obj|0;
 $attr_type = $attr_type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP12Il2CppObject($obj)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($attr_type) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($3)|0);
 $5 = (__ZN6il2cpp2vm10Reflection18CustomAttrsHasAttrEP21CustomAttributesCacheP8TypeInfo($0,$4)|0);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System15MonoCustomAttrs31GetCustomAttributesDataInternalEPv($obj) {
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(198664)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System12MonoEnumInfo13get_enum_infoEP20Il2CppReflectionTypeP14Il2CppEnumInfo($type,$info) {
 $type = $type|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $def_type = 0, $iter = 0, $j$0$ph2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp + 4|0;
 $def_type = sp;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (__ZN6il2cpp2vm5Class12GetNumFieldsEPK8TypeInfo($2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $8 = 0;
 } else {
  $5 = (__ZN6il2cpp2vm5Class12GetNumFieldsEPK8TypeInfo($2)|0);
  $6 = (($5) + -1)|0;
  $8 = $6;
 }
 $7 = HEAP32[((388944 + 68|0))>>2]|0;
 $9 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($7,$8)|0);
 $10 = (($info) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($2,$8)|0);
 $12 = (($info) + 4|0);
 HEAP32[$12>>2] = $11;
 HEAP32[$iter>>2] = 0;
 $13 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($2,$iter)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 } else {
  $56 = $13;$j$0$ph2 = 0;
 }
 L6: while(1) {
  $16 = $56;
  while(1) {
   $15 = HEAP32[$16>>2]|0;
   $17 = (_strcmp(198872,$15)|0);
   $18 = ($17|0)==(0);
   if (!($18)) {
    $21 = (__ZN6il2cpp2vm5Field9IsDeletedEP9FieldInfo($16)|0);
    if (!($21)) {
     break;
    }
   }
   $19 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($2,$iter)|0);
   $20 = ($19|0)==(0|0);
   if ($20) {
    label = 14;
    break L6;
   } else {
    $16 = $19;
   }
  }
  $22 = HEAP32[$10>>2]|0;
  $23 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($22,4,$j$0$ph2)|0);
  $24 = (__ZN6il2cpp2vm5Field7GetNameEP9FieldInfo($16)|0);
  $25 = (__ZN6il2cpp2vm6String3NewEPKc($24)|0);
  HEAP32[$23>>2] = $25;
  $26 = (__ZN6il2cpp2vm5Class20GetFieldDefaultValueEPK9FieldInfoP14Il2CppTypeEnum($16,$def_type)|0);
  $27 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($2)|0);
  $28 = (($27) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $29 >>> 16;
  $31 = $30 & 255;
  switch ($31|0) {
  case 4: case 5:  {
   $32 = HEAP32[$12>>2]|0;
   $33 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($32,1,$j$0$ph2)|0);
   $34 = HEAP8[$26>>0]|0;
   HEAP8[$33>>0] = $34;
   break;
  }
  case 10: case 11:  {
   $41 = HEAP32[$12>>2]|0;
   $42 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($41,8,$j$0$ph2)|0);
   $43 = $26;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = (($43) + 4)|0;
   $47 = $46;
   $48 = HEAP32[$47>>2]|0;
   $49 = $42;
   $50 = $49;
   HEAP32[$50>>2] = $45;
   $51 = (($49) + 4)|0;
   $52 = $51;
   HEAP32[$52>>2] = $48;
   break;
  }
  case 8: case 9:  {
   $38 = HEAP32[$12>>2]|0;
   $39 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($38,4,$j$0$ph2)|0);
   $40 = HEAP32[$26>>2]|0;
   HEAP32[$39>>2] = $40;
   break;
  }
  case 6: case 7: case 3:  {
   $35 = HEAP32[$12>>2]|0;
   $36 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($35,2,$j$0$ph2)|0);
   $37 = HEAP16[$26>>1]|0;
   HEAP16[$36>>1] = $37;
   break;
  }
  default: {
  }
  }
  $53 = (($j$0$ph2) + 1)|0;
  $54 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($2,$iter)|0);
  $55 = ($54|0)==(0|0);
  if ($55) {
   label = 14;
   break;
  } else {
   $56 = $54;$j$0$ph2 = $53;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType12get_AssemblyEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (($2) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN6il2cpp2vm10Reflection17GetAssemblyObjectEP14Il2CppAssembly($6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType14get_attributesEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class14FromSystemTypeEP20Il2CppReflectionType($type)|0);
 $1 = (($0) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType12GetArrayRankEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType17get_DeclaringTypeEP24Il2CppReflectionMonoType($monoType) {
 $monoType = $monoType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (($monoType) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741824;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = $3 >>> 16;
 $7 = $6 & 255;
 if ((($7|0) == 30)) {
  HEAP32[$vararg_buffer1>>2] = 198912;
  (_printf((198880|0),($vararg_buffer1|0))|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($7|0) == 19)) {
  HEAP32[$vararg_buffer1>>2] = 198912;
  (_printf((198880|0),($vararg_buffer1|0))|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $8 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
  $9 = (($8) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $12 = (($10) + 48|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($13)|0);
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType22get_IsGenericParameterEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741824;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $10 = 0;
  STACKTOP = sp;return ($10|0);
 }
 $6 = $3 >>> 16;
 $7 = $6 & 255;
 $8 = ($7|0)==(19);
 $9 = ($7|0)==(30);
 $$$i = $8 | $9;
 $10 = $$$i;
 STACKTOP = sp;return ($10|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType10get_ModuleEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (($2) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN6il2cpp2vm10Reflection15GetModuleObjectEP11Il2CppImage($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType8get_NameEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $n = sp + 4|0;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 1073741824;
 $7 = ($6|0)==(0);
 $8 = HEAP32[$2>>2]|0;
 if ($7) {
  $31 = (__ZN6il2cpp2vm6String10NewWrapperEPKc($8)|0);
  $$0 = $31;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = $8;
 __ZN6il2cpp5utils11StringUtils6PrintfEPKcz($n,198944,$vararg_buffer);
 $9 = HEAP8[$n>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $14 = (($n) + 1|0);
  $15 = $14;
 } else {
  $12 = (($n) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $15 = $13;
 }
 __THREW__ = 0;
 $16 = (invoke_ii(2990,($15|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  $26 = HEAP8[$n>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   ___resumeException($24|0);
   // unreachable;
  }
  $29 = (($n) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  __ZdlPv($30);
  ___resumeException($24|0);
  // unreachable;
 } else {
  $19 = HEAP8[$n>>0]|0;
  $20 = $19 & 1;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   $$0 = $16;
   STACKTOP = sp;return ($$0|0);
  }
  $22 = (($n) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  __ZdlPv($23);
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType13get_NamespaceEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $typeInfo$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $typeInfo$0 = $2;
 while(1) {
  $3 = (($typeInfo$0) + 24|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   break;
  } else {
   $typeInfo$0 = $4;
  }
 }
 $6 = (($typeInfo$0) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (__ZN6il2cpp2vm6String10NewWrapperEPKc($7)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType12get_BaseTypeEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $9 = 0;
  STACKTOP = sp;return ($9|0);
 }
 $6 = (($4) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 $9 = $8;
 STACKTOP = sp;return ($9|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType24GetConstructors_internalEP20Il2CppReflectionTypeiS5_($type,$bflags,$reftype) {
 $type = $type|0;
 $bflags = $bflags|0;
 $reftype = $reftype|0;
 var $$0 = 0, $$not = 0, $$pre = 0, $$pre$i = 0, $$pre$i$us = 0, $$pre$i$us27 = 0, $$sink4 = 0, $$sink4$us = 0, $$sink4$us24 = 0, $$sink4$v = 0, $$sink4$v$us = 0, $$sink4$v$us23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i5 = 0, $brmerge = 0, $i$017 = 0, $iter = 0;
 var $lpad$phi$index = 0, $lpad$phi$index5 = 0, $member = 0, $not$ = 0, $not$$us = 0, $not$$us25 = 0, $not$16 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $tmp_vec = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $member = sp + 16|0;
 $iter = sp;
 $tmp_vec = sp + 4|0;
 HEAP32[$iter>>2] = 0;
 HEAP32[$tmp_vec>>2] = 0;
 $0 = (($tmp_vec) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($tmp_vec) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($type) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 1073741824;
 $7 = ($6|0)==(0);
 L1: do {
  if ($7) {
   __THREW__ = 0;
   $29 = (invoke_ii(2991,($3|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    label = 6;
   } else {
    $32 = (($reftype) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(2991,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
    } else {
     $37 = HEAP32[198952>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      $39 = HEAP32[388944>>2]|0;
      __THREW__ = 0;
      $40 = (invoke_iiii(1478,($39|0),(198960|0),(198984|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 6;
       break;
      }
      HEAP32[198952>>2] = $40;
     }
     HEAP32[$iter>>2] = 0;
     $43 = $bflags & 4;
     $not$16 = ($43|0)==(0);
     $44 = $bflags & 8;
     $45 = ($44|0)==(0);
     L9: do {
      if ($45) {
       while(1) {
        __THREW__ = 0;
        $46 = (invoke_iii(2230,($29|0),($iter|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        $49 = ($46|0)==(0|0);
        if ($49) {
         break L9;
        }
        $50 = HEAP32[$46>>2]|0;
        $51 = (_strcmp($50,199000)|0);
        $52 = ($51|0)==(0);
        if (!($52)) {
         $53 = (_strcmp($50,199008)|0);
         $54 = ($53|0)==(0);
         if (!($54)) {
          continue;
         }
        }
        $55 = (($46) + 28|0);
        $56 = HEAP16[$55>>1]|0;
        $57 = $56 & 7;
        $58 = ($57<<16>>16)==(6);
        $$sink4$v$us = $58 ? 16 : 32;
        $$sink4$us = $$sink4$v$us & $bflags;
        $not$$us = ($$sink4$us|0)==(0);
        if ($not$$us) {
         continue;
        }
        $59 = $56 & 16;
        $$not = ($59<<16>>16)!=(0);
        $brmerge = $$not | $not$16;
        if ($brmerge) {
         continue;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(2231,($46|0),($34|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         break;
        }
        HEAP32[$member>>2] = $60;
        $63 = HEAP32[$0>>2]|0;
        $64 = HEAP32[$1>>2]|0;
        $65 = ($63|0)==($64|0);
        if ($65) {
         __THREW__ = 0;
         invoke_vii(2478,($tmp_vec|0),($member|0));
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          break;
         } else {
          continue;
         }
        }
        $66 = ($63|0)==(0|0);
        if ($66) {
         $68 = 0;
        } else {
         HEAP32[$63>>2] = $60;
         $$pre$i$us = HEAP32[$0>>2]|0;
         $68 = $$pre$i$us;
        }
        $67 = (($68) + 4|0);
        HEAP32[$0>>2] = $67;
       }
       $71 = ___cxa_find_matching_catch()|0;
       $72 = tempRet0;
       $lpad$phi$index = $71;$lpad$phi$index5 = $72;
       break L1;
      } else {
       if (!($not$16)) {
        while(1) {
         __THREW__ = 0;
         $101 = (invoke_iii(2230,($29|0),($iter|0))|0);
         $102 = __THREW__; __THREW__ = 0;
         $103 = $102&1;
         if ($103) {
          break;
         }
         $104 = ($101|0)==(0|0);
         if ($104) {
          break L9;
         }
         $105 = HEAP32[$101>>2]|0;
         $106 = (_strcmp($105,199000)|0);
         $107 = ($106|0)==(0);
         if (!($107)) {
          $108 = (_strcmp($105,199008)|0);
          $109 = ($108|0)==(0);
          if (!($109)) {
           continue;
          }
         }
         $110 = (($101) + 28|0);
         $111 = HEAP16[$110>>1]|0;
         $112 = $111 & 7;
         $113 = ($112<<16>>16)==(6);
         $$sink4$v = $113 ? 16 : 32;
         $$sink4 = $$sink4$v & $bflags;
         $not$ = ($$sink4|0)==(0);
         if ($not$) {
          continue;
         }
         __THREW__ = 0;
         $114 = (invoke_iii(2231,($101|0),($34|0))|0);
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break;
         }
         HEAP32[$member>>2] = $114;
         $117 = HEAP32[$0>>2]|0;
         $118 = HEAP32[$1>>2]|0;
         $119 = ($117|0)==($118|0);
         if ($119) {
          __THREW__ = 0;
          invoke_vii(2478,($tmp_vec|0),($member|0));
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if ($124) {
           break;
          } else {
           continue;
          }
         }
         $120 = ($117|0)==(0|0);
         if ($120) {
          $122 = 0;
         } else {
          HEAP32[$117>>2] = $114;
          $$pre$i = HEAP32[$0>>2]|0;
          $122 = $$pre$i;
         }
         $121 = (($122) + 4|0);
         HEAP32[$0>>2] = $121;
        }
        $14 = ___cxa_find_matching_catch()|0;
        $15 = tempRet0;
        $lpad$phi$index = $14;$lpad$phi$index5 = $15;
        break L1;
       }
       while(1) {
        __THREW__ = 0;
        $73 = (invoke_iii(2230,($29|0),($iter|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        $76 = ($73|0)==(0|0);
        if ($76) {
         break L9;
        }
        $77 = HEAP32[$73>>2]|0;
        $78 = (_strcmp($77,199000)|0);
        $79 = ($78|0)==(0);
        if (!($79)) {
         $80 = (_strcmp($77,199008)|0);
         $81 = ($80|0)==(0);
         if (!($81)) {
          continue;
         }
        }
        $82 = (($73) + 28|0);
        $83 = HEAP16[$82>>1]|0;
        $84 = $83 & 7;
        $85 = ($84<<16>>16)==(6);
        $$sink4$v$us23 = $85 ? 16 : 32;
        $$sink4$us24 = $$sink4$v$us23 & $bflags;
        $not$$us25 = ($$sink4$us24|0)==(0);
        if ($not$$us25) {
         continue;
        }
        $86 = $83 & 16;
        $87 = ($86<<16>>16)==(0);
        if ($87) {
         continue;
        }
        __THREW__ = 0;
        $88 = (invoke_iii(2231,($73|0),($34|0))|0);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         break;
        }
        HEAP32[$member>>2] = $88;
        $91 = HEAP32[$0>>2]|0;
        $92 = HEAP32[$1>>2]|0;
        $93 = ($91|0)==($92|0);
        if ($93) {
         __THREW__ = 0;
         invoke_vii(2478,($tmp_vec|0),($member|0));
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          break;
         } else {
          continue;
         }
        }
        $94 = ($91|0)==(0|0);
        if ($94) {
         $96 = 0;
        } else {
         HEAP32[$91>>2] = $88;
         $$pre$i$us27 = HEAP32[$0>>2]|0;
         $96 = $$pre$i$us27;
        }
        $95 = (($96) + 4|0);
        HEAP32[$0>>2] = $95;
       }
       $99 = ___cxa_find_matching_catch()|0;
       $100 = tempRet0;
       $lpad$phi$index = $99;$lpad$phi$index5 = $100;
       break L1;
      }
     } while(0);
     $125 = HEAP32[198952>>2]|0;
     $126 = HEAP32[$0>>2]|0;
     $127 = HEAP32[$tmp_vec>>2]|0;
     $128 = $126;
     $129 = $127;
     $130 = (($128) - ($129))|0;
     $131 = $130 >> 2;
     __THREW__ = 0;
     $132 = (invoke_iii(2229,($125|0),($131|0))|0);
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if ($134) {
      label = 6;
     } else {
      $135 = HEAP32[$0>>2]|0;
      $136 = HEAP32[$tmp_vec>>2]|0;
      $137 = ($135|0)==($136|0);
      if ($137) {
       $$0 = $132;$153 = $135;
       label = 60;
      } else {
       $i$017 = 0;
       while(1) {
        __THREW__ = 0;
        $138 = (invoke_iiii(1477,($132|0),4,($i$017|0))|0);
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         break;
        }
        $141 = HEAP32[$tmp_vec>>2]|0;
        $142 = (($141) + ($i$017<<2)|0);
        $143 = HEAP32[$142>>2]|0;
        HEAP32[$138>>2] = $143;
        $144 = (($i$017) + 1)|0;
        $145 = HEAP32[$0>>2]|0;
        $146 = HEAP32[$tmp_vec>>2]|0;
        $147 = $145;
        $148 = $146;
        $149 = (($147) - ($148))|0;
        $150 = $149 >> 2;
        $151 = ($144>>>0)<($150>>>0);
        if ($151) {
         $i$017 = $144;
        } else {
         $$0 = $132;$153 = $146;
         label = 60;
         break L1;
        }
       }
       $12 = ___cxa_find_matching_catch()|0;
       $13 = tempRet0;
       $lpad$phi$index = $12;$lpad$phi$index5 = $13;
      }
     }
    }
   }
  } else {
   $8 = HEAP32[((388944 + 140|0))>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_iii(2229,($8|0),0)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 6;
   } else {
    $$pre = HEAP32[$tmp_vec>>2]|0;
    $$0 = $9;$153 = $$pre;
    label = 60;
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $lpad$phi$index = $16;$lpad$phi$index5 = $17;
 }
 else if ((label|0) == 60) {
  $152 = ($153|0)==(0|0);
  if ($152) {
   STACKTOP = sp;return ($$0|0);
  }
  $154 = HEAP32[$0>>2]|0;
  $155 = ($154|0)==($153|0);
  if (!($155)) {
   $__new_last2$i$i$i$i$i = $153;
   $scevgep$i$i$i$i$i = (($154) + -4|0);
   $156 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($156)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $157 = $uglygep3$i$i$i$i$i >>> 2;
   $158 = $157 ^ -1;
   $scevgep4$i$i$i$i$i = (($154) + ($158<<2)|0);
   HEAP32[$0>>2] = $scevgep4$i$i$i$i$i;
  }
  __THREW__ = 0;
  invoke_vi(3303,($153|0));
  $159 = __THREW__; __THREW__ = 0;
  $160 = $159&1;
  if ($160) {
   $161 = ___cxa_find_matching_catch()|0;
   $162 = tempRet0;
   ___cxa_call_unexpected(($161|0));
   // unreachable;
  } else {
   STACKTOP = sp;return ($$0|0);
  }
 }
 $18 = HEAP32[$tmp_vec>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $20 = HEAP32[$0>>2]|0;
 $21 = ($20|0)==($18|0);
 if (!($21)) {
  $__new_last2$i$i$i$i$i5 = $18;
  $scevgep$i$i$i$i$i6 = (($20) + -4|0);
  $22 = (0 - ($__new_last2$i$i$i$i$i5))|0;
  $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($22)|0);
  $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
  $23 = $uglygep3$i$i$i$i$i9 >>> 2;
  $24 = $23 ^ -1;
  $scevgep4$i$i$i$i$i10 = (($20) + ($24<<2)|0);
  HEAP32[$0>>2] = $scevgep4$i$i$i$i$i10;
 }
 __THREW__ = 0;
 invoke_vi(3303,($18|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  ___cxa_call_unexpected(($27|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType30GetCorrespondingInflatedMethodEP24Il2CppReflectionMonoTypeS5_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 199016;
 (_printf((198880|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType14GetElementTypeEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1090453504;
 $5 = ($4|0)==(1900544);
 if ($5) {
  $6 = HEAP32[$1>>2]|0;
  $7 = (($6) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($8)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 1073741824;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = (($10) + 48|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($17)|0);
  $$0 = $18;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = (($10) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = (($10) + 112|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if (!($24)) {
  $25 = (($20) + 48|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($26)|0);
  $$0 = $27;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = $13 & 16711680;
 $29 = ($28|0)==(983040);
 if (!($29)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (($20) + 48|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($31)|0);
 $$0 = $32;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType8GetFieldEP20Il2CppReflectionTypeP12Il2CppStringi($type,$name,$bflags) {
 $type = $type|0;
 $name = $name|0;
 $bflags = $bflags|0;
 var $$0 = 0, $$sink7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $iter = 0, $klass$0 = 0, $not$ = 0, $not$8 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond2$not = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 1073741824;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = $bflags & 2;
 $9 = ($8|0)==(0);
 $10 = $bflags & 16;
 $11 = $bflags & 4;
 $not$8 = ($11|0)==(0);
 $12 = $bflags & 8;
 $13 = ($12|0)==(0);
 $14 = $bflags & 64;
 $15 = $bflags & 32;
 $klass$0 = $2;
 L4: while(1) {
  HEAP32[$iter>>2] = 0;
  $16 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($klass$0,$iter)|0);
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = ($klass$0|0)!=($2|0);
   $20 = $16;
   while(1) {
    $19 = (($20) + 4|0);
    $21 = HEAP32[$19>>2]|0;
    $22 = ($21|0)==(0|0);
    do {
     if (!($22)) {
      $25 = (__ZN6il2cpp2vm5Field9IsDeletedEP9FieldInfo($20)|0);
      if (!($25)) {
       $26 = HEAP32[$19>>2]|0;
       $27 = (($26) + 4|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = $28 & 7;
       $30 = ($29|0)==(6);
       if ($30) {
        $$sink7 = $10;
       } else {
        $31 = ($29|0)==(1);
        $or$cond = $18 & $31;
        if ($or$cond) {
         break;
        } else {
         $$sink7 = $15;
        }
       }
       $not$ = ($$sink7|0)==(0);
       if (!($not$)) {
        $32 = $28 & 16;
        $33 = ($32|0)==(0);
        if ($33) {
         if ($not$8) {
          break;
         }
        } else {
         $notlhs = ($14|0)==(0);
         $notrhs = ($klass$0|0)!=($2|0);
         $or$cond2$not = $notrhs & $notlhs;
         $brmerge = $13 | $or$cond2$not;
         if ($brmerge) {
          break;
         }
        }
        $34 = (__ZN6il2cpp2vm5Field7GetNameEP9FieldInfo($20)|0);
        $35 = (__ZN6il2cpp2vm6String3NewEPKc($34)|0);
        $36 = (__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($35)|0);
        $37 = (__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($name)|0);
        $38 = ($36|0)==($37|0);
        if ($38) {
         $39 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($35)|0);
         $40 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($name)|0);
         $41 = (__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($35)|0);
         $42 = $41 << 1;
         $43 = (_memcmp($39,$40,$42)|0);
         $44 = ($43|0)==(0);
         if ($44) {
          label = 16;
          break L4;
         }
        }
       }
      }
     }
    } while(0);
    $23 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($klass$0,$iter)|0);
    $24 = ($23|0)==(0|0);
    if ($24) {
     break;
    } else {
     $20 = $23;
    }
   }
  }
  if (!($9)) {
   $$0 = 0;
   label = 19;
   break;
  }
  $46 = (($klass$0) + 20|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  if ($48) {
   $$0 = 0;
   label = 19;
   break;
  } else {
   $klass$0 = $47;
  }
 }
 if ((label|0) == 16) {
  $45 = (__ZN6il2cpp2vm10Reflection14GetFieldObjectEP8TypeInfoP9FieldInfo($klass$0,$20)|0);
  $$0 = $45;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 19) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType18GetFields_internalEP20Il2CppReflectionTypeiS5_($type,$bflags,$0) {
 $type = $type|0;
 $bflags = $bflags|0;
 $0 = $0|0;
 var $$0 = 0, $$sink7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $count$0 = 0, $count$113 = 0, $count$2$be = 0, $count$2$lcssa = 0, $count$29 = 0, $count$3 = 0, $index$0 = 0, $index$114 = 0, $index$2$be = 0, $index$2$lcssa = 0;
 var $index$210 = 0, $index$3 = 0, $iter = 0, $klass$012 = 0, $not$ = 0, $not$8 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond2$not = 0, $res$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 $1 = (($type) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1073741824;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = HEAP32[((388944 + 136|0))>>2]|0;
  $8 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($7,0)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($2)|0);
 $10 = ($9|0)==(0|0);
 $11 = $bflags & 2;
 $12 = ($11|0)==(0);
 $13 = $bflags & 16;
 $14 = $bflags & 4;
 $not$8 = ($14|0)==(0);
 $15 = $bflags & 8;
 $16 = ($15|0)==(0);
 $17 = $bflags & 64;
 $18 = $bflags & 32;
 $count$0 = 0;$index$0 = 0;$res$0 = 0;
 while(1) {
  L7: do {
   if ($10) {
    $count$3 = $count$0;$index$3 = $index$0;
   } else {
    $19 = ($res$0|0)==(0|0);
    $count$113 = $count$0;$index$114 = $index$0;$klass$012 = $9;
    while(1) {
     HEAP32[$iter>>2] = 0;
     $20 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($klass$012,$iter)|0);
     $21 = ($20|0)==(0|0);
     if ($21) {
      $count$2$lcssa = $count$113;$index$2$lcssa = $index$114;
     } else {
      $22 = ($klass$012|0)!=($9|0);
      $24 = $20;$count$29 = $count$113;$index$210 = $index$114;
      while(1) {
       $23 = (($24) + 4|0);
       $25 = HEAP32[$23>>2]|0;
       $26 = ($25|0)==(0|0);
       do {
        if ($26) {
         $count$2$be = $count$29;$index$2$be = $index$210;
        } else {
         $29 = (__ZN6il2cpp2vm5Field9IsDeletedEP9FieldInfo($24)|0);
         if ($29) {
          $count$2$be = $count$29;$index$2$be = $index$210;
         } else {
          $30 = HEAP32[$23>>2]|0;
          $31 = (($30) + 4|0);
          $32 = HEAP32[$31>>2]|0;
          $33 = $32 & 7;
          $34 = ($33|0)==(6);
          if ($34) {
           $$sink7 = $13;
          } else {
           $35 = ($33|0)==(1);
           $or$cond = $22 & $35;
           if ($or$cond) {
            $count$2$be = $count$29;$index$2$be = $index$210;
            break;
           } else {
            $$sink7 = $18;
           }
          }
          $not$ = ($$sink7|0)==(0);
          if ($not$) {
           $count$2$be = $count$29;$index$2$be = $index$210;
          } else {
           $36 = $32 & 16;
           $37 = ($36|0)==(0);
           if ($37) {
            if ($not$8) {
             $count$2$be = $count$29;$index$2$be = $index$210;
             break;
            }
           } else {
            $notlhs = ($17|0)==(0);
            $notrhs = ($klass$012|0)!=($9|0);
            $or$cond2$not = $notrhs & $notlhs;
            $brmerge = $16 | $or$cond2$not;
            if ($brmerge) {
             $count$2$be = $count$29;$index$2$be = $index$210;
             break;
            }
           }
           if ($19) {
            $41 = (($count$29) + 1)|0;
            $count$2$be = $41;$index$2$be = $index$210;
            break;
           } else {
            $38 = (($index$210) + 1)|0;
            $39 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($res$0,4,$index$210)|0);
            $40 = (__ZN6il2cpp2vm10Reflection14GetFieldObjectEP8TypeInfoP9FieldInfo($klass$012,$24)|0);
            HEAP32[$39>>2] = $40;
            $count$2$be = $count$29;$index$2$be = $38;
            break;
           }
          }
         }
        }
       } while(0);
       $27 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($klass$012,$iter)|0);
       $28 = ($27|0)==(0|0);
       if ($28) {
        $count$2$lcssa = $count$2$be;$index$2$lcssa = $index$2$be;
        break;
       } else {
        $24 = $27;$count$29 = $count$2$be;$index$210 = $index$2$be;
       }
      }
     }
     if (!($12)) {
      $count$3 = $count$2$lcssa;$index$3 = $index$2$lcssa;
      break L7;
     }
     $42 = (($klass$012) + 20|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      $count$3 = $count$2$lcssa;$index$3 = $index$2$lcssa;
      break;
     } else {
      $count$113 = $count$2$lcssa;$index$114 = $index$2$lcssa;$klass$012 = $43;
     }
    }
   }
  } while(0);
  $45 = ($res$0|0)==(0|0);
  if (!($45)) {
   $$0 = $res$0;
   break;
  }
  $46 = HEAP32[((388944 + 136|0))>>2]|0;
  $47 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($46,$count$3)|0);
  $count$0 = $count$3;$index$0 = $index$3;$res$0 = $47;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType11getFullNameEP20Il2CppReflectionTypebb($type,$full_name,$assembly_qualified) {
 $type = $type|0;
 $full_name = $full_name|0;
 $assembly_qualified = $assembly_qualified|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($full_name) {
  $0 = $assembly_qualified ? 3 : 2;
  $format$0 = $0;
 } else {
  $format$0 = 1;
 }
 $1 = (($type) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2vm4Type7GetNameEPK10Il2CppType20Il2CppTypeNameFormat($2,$format$0)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 do {
  if ($full_name) {
   $6 = HEAP32[$1>>2]|0;
   $7 = (($6) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8 >>> 16;
   $10 = $9 & 255;
   if (!((($10|0) == 30) | (($10|0) == 19))) {
    $11 = (__ZN6il2cpp2vm6String10NewWrapperEPKc($3)|0);
    $12 = $11;
    break;
   }
   __ZdaPv($3);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc($3)|0);
   $12 = $5;
  }
 } while(0);
 __ZdaPv($3);
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType19GetGenericArgumentsEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i$11 = 0, $res$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (($2) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[((388944 + 108|0))>>2]|0;
  $7 = (($4) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 << 1;
  $10 = $9 >> 1;
  $11 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($6,$10)|0);
  $12 = HEAP32[$7>>2]|0;
  $13 = $12 << 1;
  $14 = ($13|0)>(0);
  if (!($14)) {
   $res$0 = $11;
   STACKTOP = sp;return ($res$0|0);
  }
  $15 = (($4) + 20|0);
  $i$03 = 0;
  while(1) {
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($i$03<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (__ZN6il2cpp2vm5Class20FromGenericParameterEP18Il2CppGenericParam($18)|0);
   $20 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($11,4,$i$03)|0);
   $21 = (($19) + 48|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($22)|0);
   HEAP32[$20>>2] = $23;
   $24 = (($i$03) + 1)|0;
   $25 = HEAP32[$7>>2]|0;
   $26 = $25 << 1;
   $27 = $26 >> 1;
   $28 = ($24|0)<($27|0);
   if ($28) {
    $i$03 = $24;
   } else {
    $res$0 = $11;
    break;
   }
  }
  STACKTOP = sp;return ($res$0|0);
 }
 $29 = (($2) + 68|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $48 = HEAP32[((388944 + 108|0))>>2]|0;
  $49 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($48,0)|0);
  $res$0 = $49;
  STACKTOP = sp;return ($res$0|0);
 }
 $32 = (($30) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[((388944 + 108|0))>>2]|0;
 $35 = HEAP32[$33>>2]|0;
 $36 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($34,$35)|0);
 $37 = HEAP32[$33>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  $res$0 = $36;
  STACKTOP = sp;return ($res$0|0);
 }
 $39 = (($33) + 4|0);
 $i$11 = 0;
 while(1) {
  $40 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($36,4,$i$11)|0);
  $41 = HEAP32[$39>>2]|0;
  $42 = (($41) + ($i$11<<2)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($43)|0);
  HEAP32[$40>>2] = $44;
  $45 = (($i$11) + 1)|0;
  $46 = HEAP32[$33>>2]|0;
  $47 = ($45>>>0)<($46>>>0);
  if ($47) {
   $i$11 = $45;
  } else {
   $res$0 = $36;
   break;
  }
 }
 STACKTOP = sp;return ($res$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType13GetInterfacesEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $currentType$010 = 0, $i$03 = 0, $interfaces$07 = 0, $itfs = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $itfs = sp;
 $1 = (($type) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($2)|0);
 $4 = (($itfs) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($itfs) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($itfs) + 4|0);
 HEAP32[$itfs>>2] = $6;
 $7 = ($3|0)==(0|0);
 do {
  if ($7) {
   $20 = 0;
  } else {
   $currentType$010 = $3;
   L3: while(1) {
    $8 = (($currentType$010) + 32|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    L5: do {
     if (!($10)) {
      $interfaces$07 = $9;
      while(1) {
       $11 = HEAP32[$interfaces$07>>2]|0;
       $12 = ($11|0)==(0|0);
       if ($12) {
        break L5;
       }
       __THREW__ = 0;
       invoke_viii(1560,($0|0),($itfs|0),($interfaces$07|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break L3;
       }
       $15 = (($interfaces$07) + 4|0);
       $interfaces$07 = $15;
      }
     }
    } while(0);
    $16 = (($currentType$010) + 20|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     label = 8;
     break;
    } else {
     $currentType$010 = $17;
    }
   }
   if ((label|0) == 8) {
    $$pre = HEAP32[$5>>2]|0;
    $20 = $$pre;
    break;
   }
   $51 = ___cxa_find_matching_catch()|0;
   $52 = tempRet0;
   $lpad$phi$index = $51;$lpad$phi$index3 = $52;
   $55 = HEAP32[$4>>2]|0;
   __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($itfs,$55);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $19 = HEAP32[((388944 + 108|0))>>2]|0;
 __THREW__ = 0;
 $21 = (invoke_iii(2229,($19|0),($20|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  $lpad$phi$index = $53;$lpad$phi$index3 = $54;
  $55 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($itfs,$55);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $24 = HEAP32[$itfs>>2]|0;
 $25 = ($24|0)==($6|0);
 if ($25) {
  $48 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($itfs,$48);
  STACKTOP = sp;return ($21|0);
 } else {
  $30 = $24;$i$03 = 0;
 }
 while(1) {
  __THREW__ = 0;
  $26 = (invoke_iiii(1477,($21|0),4,($i$03|0))|0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   break;
  }
  $29 = (($30) + 16|0);
  $31 = HEAP32[$29>>2]|0;
  $32 = (($31) + 48|0);
  $33 = HEAP32[$32>>2]|0;
  __THREW__ = 0;
  $34 = (invoke_ii(2992,($33|0))|0);
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if ($36) {
   break;
  }
  HEAP32[$26>>2] = $34;
  $37 = (($30) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0|0);
  if ($39) {
   $$01$i$i = $30;
   while(1) {
    $42 = (($$01$i$i) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==($$01$i$i|0);
    if ($45) {
     $$0$i$i = $43;
     break;
    } else {
     $$01$i$i = $43;
    }
   }
  } else {
   $$0$i$i$i = $38;
   while(1) {
    $40 = HEAP32[$$0$i$i$i>>2]|0;
    $41 = ($40|0)==(0|0);
    if ($41) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $40;
    }
   }
  }
  $46 = (($i$03) + 1)|0;
  $47 = ($$0$i$i|0)==($6|0);
  if ($47) {
   label = 18;
   break;
  } else {
   $30 = $$0$i$i;$i$03 = $46;
  }
 }
 if ((label|0) == 18) {
  $48 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($itfs,$48);
  STACKTOP = sp;return ($21|0);
 }
 $49 = ___cxa_find_matching_catch()|0;
 $50 = tempRet0;
 $lpad$phi$index = $49;$lpad$phi$index3 = $50;
 $55 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($itfs,$55);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType16GetMethodsByNameEP20Il2CppReflectionTypeP12Il2CppStringibS5_($type,$name,$bflags,$ignore_case,$reftype) {
 $type = $type|0;
 $name = $name|0;
 $bflags = $bflags|0;
 $ignore_case = $ignore_case|0;
 $reftype = $reftype|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$idx = 0, $$idx$val = 0, $$idx2 = 0, $$idx2$val = 0, $$idx3$val = 0, $$idx3$val$pre = 0, $$not = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$0 = 0, $count$1$lcssa = 0, $count$124 = 0, $count$2 = 0, $count$2$phi = 0, $filledSlots = 0, $iklass$022 = 0, $index$0 = 0, $index$1$lcssa = 0, $index$123 = 0, $index$2 = 0, $index$2$phi = 0, $iter = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $or$cond12 = 0, $res$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $filledSlots = sp;
 $iter = sp + 12|0;
 $1 = (($type) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($2)|0);
 $4 = (($reftype) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($5)|0);
 $7 = HEAP32[199064>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = HEAP32[((388944 + 140|0))>>2]|0;
  $10 = (__ZN6il2cpp2vm5Class13GetArrayClassEP8TypeInfoj($9,1)|0);
  HEAP32[199064>>2] = $10;
 }
 $11 = (($filledSlots) + 4|0);
 $12 = (($filledSlots) + 8|0);
 $13 = (($filledSlots) + 4|0);
 $14 = ($3|0)==(0|0);
 $15 = ($name|0)==(0|0);
 $16 = $bflags & 16;
 $17 = ($16|0)==(0);
 $18 = $bflags & 32;
 $19 = ($18|0)==(0);
 $20 = $bflags & 8;
 $21 = ($20|0)==(0);
 $22 = $bflags & 2;
 $23 = ($22|0)==(0);
 $count$0 = 0;$index$0 = 0;$res$0 = 0;
 L4: while(1) {
  HEAP32[$11>>2] = 0;
  HEAP32[$12>>2] = 0;
  HEAP32[$filledSlots>>2] = $13;
  L6: do {
   if ($14) {
    $count$1$lcssa = $count$0;$index$1$lcssa = $index$0;
   } else {
    $24 = ($res$0|0)==(0|0);
    $count$124 = $count$0;$iklass$022 = $3;$index$123 = $index$0;
    while(1) {
     HEAP32[$iter>>2] = 0;
     $25 = ($iklass$022|0)==($3|0);
     $count$2 = $count$124;$index$2 = $index$123;
     L10: while(1) {
      __THREW__ = 0;
      $26 = (invoke_iii(2230,($iklass$022|0),($iter|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 53;
       break L4;
      }
      $29 = ($26|0)==(0|0);
      if ($29) {
       break;
      }
      __THREW__ = 0;
      $30 = (invoke_ii(2993,($26|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 53;
       break L4;
      }
      __THREW__ = 0;
      $33 = (invoke_ii(2990,($30|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 53;
       break L4;
      }
      if (!($15)) {
       __THREW__ = 0;
       $36 = (invoke_ii(2994,($33|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 53;
        break L4;
       }
       __THREW__ = 0;
       $39 = (invoke_ii(2994,($name|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        label = 53;
        break L4;
       }
       $42 = ($36|0)==($39|0);
       if (!($42)) {
        $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
        continue;
       }
       __THREW__ = 0;
       $43 = (invoke_ii(2995,($33|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 53;
        break L4;
       }
       __THREW__ = 0;
       $46 = (invoke_ii(2995,($name|0))|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        label = 53;
        break L4;
       }
       __THREW__ = 0;
       $49 = (invoke_ii(2994,($33|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        label = 53;
        break L4;
       }
       $52 = $49 << 1;
       $53 = (_memcmp($43,$46,$52)|0);
       $54 = ($53|0)==(0);
       if (!($54)) {
        $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
        continue;
       }
      }
      if ($17) {
       label = 21;
      } else {
       $$idx = (($26) + 28|0);
       $$idx$val = HEAP16[$$idx>>1]|0;
       $55 = $$idx$val & 7;
       $56 = ($55<<16>>16)==(6);
       if ($56) {
        $62 = $$idx$val;
       } else {
        label = 21;
       }
      }
      do {
       if ((label|0) == 21) {
        label = 0;
        if ($19) {
         $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
         continue L10;
        }
        $$idx2 = (($26) + 28|0);
        $$idx2$val = HEAP16[$$idx2>>1]|0;
        $57 = $$idx2$val&65535;
        $58 = $57 & 7;
        if ((($58|0) == 6)) {
         $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
         continue L10;
        } else if ((($58|0) == 1)) {
         if ($25) {
          $62 = $$idx2$val;
          break;
         } else {
          $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
          continue L10;
         }
        } else if ((($58|0) == 3)) {
         $59 = HEAP32[((388944 + 160|0))>>2]|0;
         $60 = ($59|0)!=(0|0);
         $or$cond12 = $25 | $60;
         if ($or$cond12) {
          $62 = $$idx2$val;
          break;
         } else {
          $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
          continue L10;
         }
        } else {
         $62 = $$idx2$val;
         break;
        }
       }
      } while(0);
      if ($21) {
       $61 = $62 & 16;
       $63 = ($61<<16>>16)==(0);
       if (!($63)) {
        $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
        continue;
       }
      }
      $$pre$phiZ2D = (($26) + 28|0);
      $64 = $62 & 64;
      $65 = ($64<<16>>16)==(0);
      if ($65) {
       $$idx3$val = $62;
      } else {
       $66 = (($26) + 32|0);
       $67 = HEAP32[$11>>2]|0;
       $68 = ($67|0)==(0|0);
       if (!($68)) {
        $69 = HEAP8[$66>>0]|0;
        $$0$ph7$i$i$i = $13;$$01$ph6$i$in$i$i = $67;
        L41: while(1) {
         $$013$i$in$i$i = $$01$ph6$i$in$i$i;
         while(1) {
          $70 = (($$013$i$in$i$i) + 13|0);
          $71 = HEAP8[$70>>0]|0;
          $72 = ($71&255)<($69&255);
          if (!($72)) {
           break;
          }
          $75 = (($$013$i$in$i$i) + 4|0);
          $76 = HEAP32[$75>>2]|0;
          $77 = ($76|0)==(0|0);
          if ($77) {
           $$0$ph5$i$i$i = $$0$ph7$i$i$i;
           break L41;
          } else {
           $$013$i$in$i$i = $76;
          }
         }
         $73 = HEAP32[$$013$i$in$i$i>>2]|0;
         $74 = ($73|0)==(0|0);
         if ($74) {
          $$0$ph5$i$i$i = $$013$i$in$i$i;
          break;
         } else {
          $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $73;
         }
        }
        $78 = ($$0$ph5$i$i$i|0)==($13|0);
        if (!($78)) {
         $79 = (($$0$ph5$i$i$i) + 13|0);
         $80 = HEAP8[$79>>0]|0;
         $81 = ($69&255)<($80&255);
         if (!($81)) {
          $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
          continue;
         }
        }
       }
       __THREW__ = 0;
       invoke_viii(1561,($0|0),($filledSlots|0),($66|0));
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        label = 53;
        break L4;
       }
       $$idx3$val$pre = HEAP16[$$pre$phiZ2D>>1]|0;
       $$idx3$val = $$idx3$val$pre;
      }
      $84 = $$idx3$val & 16;
      $$not = ($84<<16>>16)==(0);
      $or$cond = $$not | $25;
      if (!($or$cond)) {
       $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
       continue;
      }
      $85 = $$idx3$val & -12288;
      $86 = ($85<<16>>16)==(4096);
      if ($86) {
       $87 = HEAP32[$26>>2]|0;
       $88 = (_strcmp($87,199000)|0);
       $89 = ($88|0)==(0);
       if ($89) {
        $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
        continue;
       }
       $90 = (_strcmp($87,199008)|0);
       $91 = ($90|0)==(0);
       if ($91) {
        $index$2$phi = $index$2;$count$2$phi = $count$2;$index$2 = $index$2$phi;$count$2 = $count$2$phi;
        continue;
       }
      }
      if ($24) {
       $99 = (($count$2) + 1)|0;
       $index$2$phi = $index$2;$count$2 = $99;$index$2 = $index$2$phi;
       continue;
      }
      $92 = (($index$2) + 1)|0;
      __THREW__ = 0;
      $93 = (invoke_iiii(1477,($res$0|0),4,($index$2|0))|0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       label = 53;
       break L4;
      }
      __THREW__ = 0;
      $96 = (invoke_iii(2231,($26|0),($6|0))|0);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       label = 53;
       break L4;
      }
      HEAP32[$93>>2] = $96;
      $count$2$phi = $count$2;$index$2 = $92;$count$2 = $count$2$phi;
     }
     if (!($23)) {
      $count$1$lcssa = $count$2;$index$1$lcssa = $index$2;
      break L6;
     }
     $100 = (($iklass$022) + 20|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101|0)==(0|0);
     if ($102) {
      $count$1$lcssa = $count$2;$index$1$lcssa = $index$2;
      break;
     } else {
      $count$124 = $count$2;$iklass$022 = $101;$index$123 = $index$2;
     }
    }
   }
  } while(0);
  $103 = ($res$0|0)==(0|0);
  if (!($103)) {
   label = 52;
   break;
  }
  $104 = HEAP32[199064>>2]|0;
  __THREW__ = 0;
  $105 = (invoke_iii(2232,($104|0),($count$1$lcssa|0))|0);
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if ($107) {
   label = 54;
   break;
  }
  $108 = HEAP32[$11>>2]|0;
  __ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE7destroyEPNS_11__tree_nodeIhPvEE($filledSlots,$108);
  $count$0 = $count$1$lcssa;$index$0 = $index$1$lcssa;$res$0 = $105;
 }
 if ((label|0) == 52) {
  $109 = HEAP32[$11>>2]|0;
  __ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE7destroyEPNS_11__tree_nodeIhPvEE($filledSlots,$109);
  STACKTOP = sp;return ($res$0|0);
 }
 else if ((label|0) == 53) {
  $110 = ___cxa_find_matching_catch()|0;
  $111 = tempRet0;
  $lpad$phi$index = $110;$lpad$phi$index2 = $111;
  $114 = HEAP32[$11>>2]|0;
  __ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE7destroyEPNS_11__tree_nodeIhPvEE($filledSlots,$114);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 54) {
  $112 = ___cxa_find_matching_catch()|0;
  $113 = tempRet0;
  $lpad$phi$index = $112;$lpad$phi$index2 = $113;
  $114 = HEAP32[$11>>2]|0;
  __ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE7destroyEPNS_11__tree_nodeIhPvEE($filledSlots,$114);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType14GetNestedTypesEP24Il2CppReflectionMonoTypei($type,$bindingAttr) {
 $type = $type|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((388944 + 112|0))>>2]|0;
 $1 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($0,0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType19GetPropertiesByNameEP20Il2CppReflectionTypeP12Il2CppStringjbS5_($type,$name,$bflags,$ignore_case,$reftype) {
 $type = $type|0;
 $name = $name|0;
 $bflags = $bflags|0;
 $ignore_case = $ignore_case|0;
 $reftype = $reftype|0;
 var $$ = 0, $$0 = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i17 = 0, $$01 = 0, $$02 = 0, $$pn$i$i = 0, $$pre$phiZ2D = 0, $$pre41 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__nd$0$i$i = 0, $brmerge = 0, $flags$043 = 0, $flags$044 = 0, $i$032 = 0, $iter = 0, $klass$0 = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, $not$ = 0, $not$30 = 0, $not$31 = 0, $notlhs = 0;
 var $notrhs = 0, $or$cond$not = 0, $phitmp = 0, $phitmp46 = 0, $prop = 0, $properties = 0, $propname = 0, $vararg_buffer10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer10 = sp;
 $prop = sp + 52|0;
 $propname = sp + 4|0;
 $iter = sp + 16|0;
 $properties = sp + 20|0;
 $0 = sp + 40|0;
 ;HEAP32[$propname+0>>2]=0|0;HEAP32[$propname+4>>2]=0|0;HEAP32[$propname+8>>2]=0|0;
 $1 = (($properties) + 16|0);
 ;HEAP32[$properties+0>>2]=0|0;HEAP32[$properties+4>>2]=0|0;HEAP32[$properties+8>>2]=0|0;HEAP32[$properties+12>>2]=0|0;
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($type) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 1073741824;
 $7 = ($6|0)==(0);
 L1: do {
  if ($7) {
   __THREW__ = 0;
   $20 = (invoke_ii(2991,($3|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 7;
   } else {
    $23 = ($name|0)!=(0|0);
    if ($23) {
     $24 = (($name) + 12|0);
     __THREW__ = 0;
     invoke_vii(2479,($0|0),($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     (invoke_iii(2233,($propname|0),($0|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      $47 = ___cxa_find_matching_catch()|0;
      $48 = tempRet0;
      $49 = HEAP8[$0>>0]|0;
      $50 = $49 & 1;
      $51 = ($50<<24>>24)==(0);
      if ($51) {
       $$01 = $48;$$02 = $47;
       break;
      }
      $52 = (($0) + 8|0);
      $53 = HEAP32[$52>>2]|0;
      __ZdlPv($53);
      $$01 = $48;$$02 = $47;
      break;
     }
     $29 = HEAP8[$0>>0]|0;
     $30 = $29 & 1;
     $31 = ($30<<24>>24)==(0);
     if (!($31)) {
      $32 = (($0) + 8|0);
      $33 = HEAP32[$32>>2]|0;
      __ZdlPv($33);
     }
     if ($ignore_case) {
      HEAP32[$vararg_buffer10>>2] = 199072;
      (_printf((198880|0),($vararg_buffer10|0))|0);
     }
    }
    $34 = $bflags & 32;
    $35 = ($34|0)==(0);
    $36 = $bflags & 16;
    $not$ = ($36|0)==(0);
    $37 = $bflags & 4;
    $not$31 = ($37|0)==(0);
    $38 = (($propname) + 1|0);
    $39 = (($propname) + 8|0);
    $40 = (($propname) + 4|0);
    $41 = (($properties) + 4|0);
    $42 = $bflags & 8;
    $43 = ($42|0)==(0);
    $44 = $bflags & 64;
    $45 = $bflags & 2;
    $46 = ($45|0)==(0);
    $klass$0 = $20;
    L18: while(1) {
     __THREW__ = 0;
     (invoke_ii(2996,($klass$0|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      label = 6;
      break;
     }
     HEAP32[$iter>>2] = 0;
     L21: while(1) {
      __THREW__ = 0;
      $56 = (invoke_iii(2234,($klass$0|0),($iter|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 5;
       break L18;
      }
      HEAP32[$prop>>2] = $56;
      $59 = ($56|0)==(0|0);
      if ($59) {
       break;
      }
      $60 = (($56) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $63 = (($56) + 12|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = ($64|0)==(0|0);
       if ($65) {
        $flags$043 = 0;
        label = 28;
       } else {
        $66 = (($64) + 28|0);
        $67 = HEAP16[$66>>1]|0;
        $68 = $67&65535;
        $phitmp46 = $68 & 16;
        $flags$043 = $phitmp46;
        label = 28;
       }
      } else {
       $69 = (($61) + 28|0);
       $70 = HEAP16[$69>>1]|0;
       $71 = $70&65535;
       $phitmp = $71 & 16;
       $72 = $70 & 7;
       $73 = ($72<<16>>16)==(6);
       if ($73) {
        $flags$044 = $phitmp;
       } else {
        $flags$043 = $phitmp;
        label = 28;
       }
      }
      do {
       if ((label|0) == 28) {
        label = 0;
        $74 = (($56) + 12|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = ($75|0)==(0|0);
        if (!($76)) {
         $77 = (($75) + 28|0);
         $78 = HEAP16[$77>>1]|0;
         $79 = $78 & 7;
         $80 = ($79<<16>>16)==(6);
         if ($80) {
          $flags$044 = $flags$043;
          break;
         }
        }
        if ($35) {
         continue L21;
        }
        HEAP32[$vararg_buffer10>>2] = 199072;
        (_printf((198880|0),($vararg_buffer10|0))|0);
        continue L21;
       }
      } while(0);
      if ($not$) {
       continue;
      }
      $81 = ($flags$044|0)==(0);
      if ($81) {
       if ($not$31) {
        continue;
       }
      } else {
       $notlhs = ($44|0)==(0);
       $notrhs = ($klass$0|0)!=($20|0);
       $or$cond$not = $notrhs & $notlhs;
       $brmerge = $43 | $or$cond$not;
       if ($brmerge) {
        continue;
       }
      }
      $82 = (($56) + 4|0);
      $83 = HEAP32[$82>>2]|0;
      if ($23) {
       $84 = (_strlen(($83|0))|0);
       $85 = HEAP8[$propname>>0]|0;
       $86 = $85 & 1;
       $87 = ($86<<24>>24)==(0);
       if ($87) {
        $89 = $85&255;
        $90 = $89 >>> 1;
        $96 = $90;
       } else {
        $88 = HEAP32[$40>>2]|0;
        $96 = $88;
       }
       $91 = ($84|0)==(-1);
       if ($91) {
        label = 41;
        break L18;
       }
       $94 = HEAP32[$39>>2]|0;
       $$ = $87 ? $38 : $94;
       $95 = ($96>>>0)>($84>>>0);
       $97 = $95 ? $84 : $96;
       $98 = (_memcmp($$,$83,$97)|0);
       $99 = ($98|0)==(0);
       if (!($99)) {
        continue;
       }
       $102 = $95 ^ 1;
       $not$30 = ($96>>>0)>=($84>>>0);
       $103 = $not$30 & $102;
       if (!($103)) {
        continue;
       }
      }
      $104 = (($56) + 4|0);
      __THREW__ = 0;
      $105 = (invoke_ii(2997,($83|0))|0);
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       label = 5;
       break L18;
      }
      $108 = HEAP32[$41>>2]|0;
      $109 = ($108|0)==(0);
      L51: do {
       if (!($109)) {
        $110 = (($108) + -1)|0;
        $111 = $110 & $108;
        $112 = ($111|0)==(0);
        if ($112) {
         $113 = $110 & $105;
         $117 = $113;
        } else {
         $114 = (($105>>>0) % ($108>>>0))&-1;
         $117 = $114;
        }
        $115 = HEAP32[$properties>>2]|0;
        $116 = (($115) + ($117<<2)|0);
        $118 = HEAP32[$116>>2]|0;
        $119 = ($118|0)==(0|0);
        if (!($119)) {
         $$pn$i$i = $118;
         while(1) {
          $__nd$0$i$i = HEAP32[$$pn$i$i>>2]|0;
          $120 = ($__nd$0$i$i|0)==(0|0);
          if ($120) {
           break L51;
          }
          $121 = (($__nd$0$i$i) + 4|0);
          $122 = HEAP32[$121>>2]|0;
          if ($112) {
           $123 = $122 & $110;
           $126 = $123;
          } else {
           $124 = (($122>>>0) % ($108>>>0))&-1;
           $126 = $124;
          }
          $125 = ($126|0)==($117|0);
          if (!($125)) {
           break L51;
          }
          $127 = (($__nd$0$i$i) + 8|0);
          $128 = HEAP32[$127>>2]|0;
          $129 = (($128) + 4|0);
          $130 = HEAP32[$129>>2]|0;
          $131 = HEAP32[$104>>2]|0;
          $132 = (_strcmp($130,$131)|0);
          $133 = ($132|0)==(0);
          if ($133) {
           continue L21;
          } else {
           $$pn$i$i = $__nd$0$i$i;
          }
         }
        }
       }
      } while(0);
      __THREW__ = 0;
      $134 = (invoke_iii(2235,($20|0),($56|0))|0);
      $135 = __THREW__; __THREW__ = 0;
      $136 = $135&1;
      if ($136) {
       label = 5;
       break L18;
      }
      __THREW__ = 0;
      $137 = (invoke_iii(2236,($properties|0),($prop|0))|0);
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       label = 5;
       break L18;
      }
      HEAP32[$137>>2] = $134;
     }
     if (!($46)) {
      label = 63;
      break;
     }
     $140 = (($klass$0) + 20|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ($141|0)==(0|0);
     if ($142) {
      label = 63;
      break;
     } else {
      $klass$0 = $141;
     }
    }
    if ((label|0) == 5) {
     $14 = ___cxa_find_matching_catch()|0;
     $15 = tempRet0;
     $lpad$phi$index = $14;$lpad$phi$index4 = $15;
     label = 8;
     break;
    }
    else if ((label|0) == 6) {
     $16 = ___cxa_find_matching_catch()|0;
     $17 = tempRet0;
     $lpad$phi$index = $16;$lpad$phi$index4 = $17;
     label = 8;
     break;
    }
    else if ((label|0) == 41) {
     __THREW__ = 0;
     invoke_vi(3304,0);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      $100 = ___cxa_find_matching_catch()|0;
      $101 = tempRet0;
      ___cxa_call_unexpected(($100|0));
      // unreachable;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 63) {
     $143 = HEAP32[((388944 + 144|0))>>2]|0;
     $144 = (($properties) + 12|0);
     $145 = HEAP32[$144>>2]|0;
     __THREW__ = 0;
     $146 = (invoke_iii(2229,($143|0),($145|0))|0);
     $147 = __THREW__; __THREW__ = 0;
     $148 = $147&1;
     if ($148) {
      label = 7;
      break;
     }
     $149 = (($properties) + 8|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = ($150|0)==(0|0);
     if ($151) {
      $$0 = $146;$$pre$phiZ2D = $149;
      label = 67;
      break;
     } else {
      $156 = $150;$i$032 = 0;
     }
     while(1) {
      __THREW__ = 0;
      $152 = (invoke_iiii(1477,($146|0),4,($i$032|0))|0);
      $153 = __THREW__; __THREW__ = 0;
      $154 = $153&1;
      if ($154) {
       break;
      }
      $155 = (($156) + 12|0);
      $157 = HEAP32[$155>>2]|0;
      HEAP32[$152>>2] = $157;
      $158 = (($i$032) + 1)|0;
      $159 = HEAP32[$156>>2]|0;
      $160 = ($159|0)==(0|0);
      if ($160) {
       $$0 = $146;$$pre$phiZ2D = $149;
       label = 67;
       break L1;
      } else {
       $156 = $159;$i$032 = $158;
      }
     }
     $12 = ___cxa_find_matching_catch()|0;
     $13 = tempRet0;
     $lpad$phi$index = $12;$lpad$phi$index4 = $13;
     label = 8;
     break;
    }
   }
  } else {
   $8 = HEAP32[((388944 + 144|0))>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_iii(2229,($8|0),0)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 7;
   } else {
    $$pre41 = (($properties) + 8|0);
    $$0 = $9;$$pre$phiZ2D = $$pre41;
    label = 67;
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $lpad$phi$index = $18;$lpad$phi$index4 = $19;
  label = 8;
 }
 else if ((label|0) == 67) {
  $161 = HEAP32[$$pre$phiZ2D>>2]|0;
  $$0$i$i$i$i$i17 = $161;
  while(1) {
   $162 = ($$0$i$i$i$i$i17|0)==(0|0);
   if ($162) {
    break;
   }
   $163 = HEAP32[$$0$i$i$i$i$i17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3303,($$0$i$i$i$i$i17|0));
   $164 = __THREW__; __THREW__ = 0;
   $165 = $164&1;
   if ($165) {
    label = 70;
    break;
   } else {
    $$0$i$i$i$i$i17 = $163;
   }
  }
  if ((label|0) == 70) {
   $166 = ___cxa_find_matching_catch()|0;
   $167 = tempRet0;
   ___cxa_call_unexpected(($166|0));
   // unreachable;
  }
  $168 = HEAP32[$properties>>2]|0;
  HEAP32[$properties>>2] = 0;
  $169 = ($168|0)==(0|0);
  if (!($169)) {
   __THREW__ = 0;
   invoke_vi(3303,($168|0));
   $170 = __THREW__; __THREW__ = 0;
   $171 = $170&1;
   if ($171) {
    $172 = ___cxa_find_matching_catch()|0;
    $173 = tempRet0;
    ___cxa_call_unexpected(($172|0));
    // unreachable;
   }
  }
  $174 = HEAP8[$propname>>0]|0;
  $175 = $174 & 1;
  $176 = ($175<<24>>24)==(0);
  if ($176) {
   STACKTOP = sp;return ($$0|0);
  }
  $177 = (($propname) + 8|0);
  $178 = HEAP32[$177>>2]|0;
  __ZdlPv($178);
  STACKTOP = sp;return ($$0|0);
 }
 if ((label|0) == 8) {
  $$01 = $lpad$phi$index4;$$02 = $lpad$phi$index;
 }
 $179 = (($properties) + 8|0);
 $180 = HEAP32[$179>>2]|0;
 $$0$i$i$i$i$i = $180;
 while(1) {
  $181 = ($$0$i$i$i$i$i|0)==(0|0);
  if ($181) {
   break;
  }
  $182 = HEAP32[$$0$i$i$i$i$i>>2]|0;
  __THREW__ = 0;
  invoke_vi(3303,($$0$i$i$i$i$i|0));
  $183 = __THREW__; __THREW__ = 0;
  $184 = $183&1;
  if ($184) {
   label = 80;
   break;
  } else {
   $$0$i$i$i$i$i = $182;
  }
 }
 if ((label|0) == 80) {
  $185 = ___cxa_find_matching_catch()|0;
  $186 = tempRet0;
  ___cxa_call_unexpected(($185|0));
  // unreachable;
 }
 $187 = HEAP32[$properties>>2]|0;
 HEAP32[$properties>>2] = 0;
 $188 = ($187|0)==(0|0);
 if (!($188)) {
  __THREW__ = 0;
  invoke_vi(3303,($187|0));
  $189 = __THREW__; __THREW__ = 0;
  $190 = $189&1;
  if ($190) {
   $191 = ___cxa_find_matching_catch()|0;
   $192 = tempRet0;
   ___cxa_call_unexpected(($191|0));
   // unreachable;
  }
 }
 $193 = HEAP8[$propname>>0]|0;
 $194 = $193 & 1;
 $195 = ($194<<24>>24)==(0);
 if ($195) {
  ___resumeException($$02|0);
  // unreachable;
 }
 $196 = (($propname) + 8|0);
 $197 = HEAP32[$196>>2]|0;
 __ZdlPv($197);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZNSt3__113unordered_mapIP12PropertyInfoP24Il2CppReflectionPropertyN6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashENS8_25Il2CppPropertyInfoCompareENS5_2gc9AllocatorINS_4pairIKS2_S4_EEEEEixERSE_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0 = 0, $$pn$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$i$i = 0, $__nd$0$i$i$sink = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$__k>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN6il2cpp5utils11StringUtils4HashEPKc($3)|0);
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 L1: do {
  if (!($7)) {
   $8 = (($6) + -1)|0;
   $9 = $8 & $6;
   $10 = ($9|0)==(0);
   if ($10) {
    $11 = $8 & $4;
    $15 = $11;
   } else {
    $12 = (($4>>>0) % ($6>>>0))&-1;
    $15 = $12;
   }
   $13 = HEAP32[$this>>2]|0;
   $14 = (($13) + ($15<<2)|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $$pn$i$i = $16;
    while(1) {
     $__nd$0$i$i = HEAP32[$$pn$i$i>>2]|0;
     $18 = ($__nd$0$i$i|0)==(0|0);
     if ($18) {
      break L1;
     }
     $19 = (($__nd$0$i$i) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     if ($10) {
      $21 = $20 & $8;
      $24 = $21;
     } else {
      $22 = (($20>>>0) % ($6>>>0))&-1;
      $24 = $22;
     }
     $23 = ($24|0)==($15|0);
     if (!($23)) {
      break L1;
     }
     $25 = (($__nd$0$i$i) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$__k>>2]|0;
     $28 = (($26) + 4|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + 4|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (_strcmp($29,$31)|0);
     $33 = ($32|0)==(0);
     if ($33) {
      $__nd$0$i$i$sink = $__nd$0$i$i;
      break;
     } else {
      $$pn$i$i = $__nd$0$i$i;
     }
    }
    $$0 = (($__nd$0$i$i$sink) + 12|0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $34 = (__Z21il2cpp_gc_alloc_fixedjPv(16,0)|0);
 $35 = (($34) + 8|0);
 $36 = HEAP32[$__k>>2]|0;
 HEAP32[$35>>2] = $36;
 $37 = (($34) + 12|0);
 HEAP32[$37>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1562,($0|0),($this|0),($34|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  $40 = HEAP32[$0>>2]|0;
  $__nd$0$i$i$sink = $40;
  $$0 = (($__nd$0$i$i$sink) + 12|0);
  STACKTOP = sp;return ($$0|0);
 }
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 $43 = ($34|0)==(0|0);
 if ($43) {
  ___resumeException($41|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3303,($34|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  ___resumeException($41|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType11IsByRefImplEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741824;
 $5 = ($4|0)!=(0);
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType15IsCOMObjectImplEP24Il2CppReflectionMonoType($0) {
 $0 = $0|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 199104;
 (_printf((198880|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType13IsPointerImplEP24Il2CppReflectionMonoType($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType15IsPrimitiveImplEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741824;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $11 = 0;
  STACKTOP = sp;return ($11|0);
 }
 $6 = $3 >>> 16;
 $7 = $6 & 255;
 $$off = (($7) + -2)|0;
 $8 = ($$off>>>0)<(12);
 if ($8) {
  $11 = 1;
  STACKTOP = sp;return ($11|0);
 } else {
  $9 = $6 & 254;
  $10 = ($9|0)==(24);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType16InternalGetEventEP20Il2CppReflectionTypeP12Il2CppStringi($__this,$name,$bindingAttr) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 199136;
 (_printf((198880|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType18GetEvents_internalEP20Il2CppReflectionTypeiS5_($__this,$bindingAttr,$reflected_type) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $reflected_type = $reflected_type|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((388944 + 148|0))>>2]|0;
 $1 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($0,0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType13type_from_objEPvP12Il2CppObject($type,$obj) {
 $type = $type|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(199168)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType13GetNestedTypeEPvP12Il2CppStringi($self,$name,$bindingAttr) {
 $self = $self|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(199352)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8MonoType19get_DeclaringMethodEPv($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(199536)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIP12PropertyInfoP24Il2CppReflectionPropertyEENS_22__unordered_map_hasherIS3_S6_N6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashELb1EEENS_21__unordered_map_equalIS3_S6_NSB_25Il2CppPropertyInfoCompareELb1EEENS8_2gc9AllocatorIS6_EEE20__node_insert_uniqueEPNS_11__hash_nodeIS6_PvEE($agg$result,$this,$__nd) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__nd = $__nd|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__bc$0 = 0, $__chash$0 = 0, $__chash$1 = 0, $__ndptr$0 = 0, $__ndptr$1 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__nd) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN6il2cpp5utils11StringUtils4HashEPKc($3)|0);
 $5 = (($__nd) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 L1: do {
  if ($8) {
   $__chash$0 = 0;
  } else {
   $9 = (($7) + -1)|0;
   $10 = $9 & $7;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = $9 & $4;
    $16 = $12;
   } else {
    $13 = (($4>>>0) % ($7>>>0))&-1;
    $16 = $13;
   }
   $14 = HEAP32[$this>>2]|0;
   $15 = (($14) + ($16<<2)|0);
   $17 = HEAP32[$15>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $__chash$0 = $16;
   } else {
    $$pn = $17;
    while(1) {
     $__ndptr$0 = HEAP32[$$pn>>2]|0;
     $19 = ($__ndptr$0|0)==(0|0);
     if ($19) {
      $__chash$0 = $16;
      break L1;
     }
     $20 = (($__ndptr$0) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     if ($11) {
      $22 = $21 & $9;
      $25 = $22;
     } else {
      $23 = (($21>>>0) % ($7>>>0))&-1;
      $25 = $23;
     }
     $24 = ($25|0)==($16|0);
     if (!($24)) {
      $__chash$0 = $16;
      break L1;
     }
     $26 = (($__ndptr$0) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = HEAP32[$0>>2]|0;
     $29 = (($27) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (_strcmp($30,$32)|0);
     $34 = ($33|0)==(0);
     if ($34) {
      $89 = 0;$__ndptr$1 = $__ndptr$0;
      break;
     } else {
      $$pn = $__ndptr$0;
     }
    }
    HEAP32[$agg$result>>2] = $__ndptr$1;
    $88 = (($agg$result) + 4|0);
    HEAP8[$88>>0] = $89;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $35 = (($this) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 1)|0;
 $38 = (Math_fround(($37>>>0)));
 $39 = (Math_fround(($7>>>0)));
 $40 = (($this) + 16|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($39 * $41);
 $43 = $38 > $42;
 $or$cond = $43 | $8;
 do {
  if ($or$cond) {
   $44 = $7 << 1;
   $45 = ($7>>>0)>(2);
   if ($45) {
    $46 = (($7) + -1)|0;
    $47 = $46 & $7;
    $48 = ($47|0)==(0);
    $50 = $48;
   } else {
    $50 = 0;
   }
   $49 = $50&1;
   $51 = $49 | $44;
   $52 = $51 ^ 1;
   $53 = Math_fround($38 / $41);
   $54 = (Math_fround(Math_ceil((Math_fround($53)))));
   $55 = (~~(($54))>>>0);
   $56 = ($52>>>0)<($55>>>0);
   $57 = $56 ? $55 : $52;
   __ZNSt3__112__hash_tableINS_17__hash_value_typeIP12PropertyInfoP24Il2CppReflectionPropertyEENS_22__unordered_map_hasherIS3_S6_N6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashELb1EEENS_21__unordered_map_equalIS3_S6_NSB_25Il2CppPropertyInfoCompareELb1EEENS8_2gc9AllocatorIS6_EEE6rehashEj($this,$57);
   $58 = HEAP32[$6>>2]|0;
   $59 = HEAP32[$5>>2]|0;
   $60 = (($58) + -1)|0;
   $61 = $60 & $58;
   $62 = ($61|0)==(0);
   if ($62) {
    $63 = $60 & $59;
    $__bc$0 = $58;$__chash$1 = $63;
    break;
   } else {
    $64 = (($59>>>0) % ($58>>>0))&-1;
    $__bc$0 = $58;$__chash$1 = $64;
    break;
   }
  } else {
   $__bc$0 = $7;$__chash$1 = $__chash$0;
  }
 } while(0);
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + ($__chash$1<<2)|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  $69 = (($this) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  HEAP32[$__nd>>2] = $70;
  HEAP32[$69>>2] = $__nd;
  $71 = HEAP32[$this>>2]|0;
  $72 = (($71) + ($__chash$1<<2)|0);
  HEAP32[$72>>2] = $69;
  $73 = HEAP32[$__nd>>2]|0;
  $74 = ($73|0)==(0|0);
  if (!($74)) {
   $75 = (($73) + 4|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($__bc$0) + -1)|0;
   $78 = $77 & $__bc$0;
   $79 = ($78|0)==(0);
   if ($79) {
    $80 = $76 & $77;
    $84 = $80;
   } else {
    $81 = (($76>>>0) % ($__bc$0>>>0))&-1;
    $84 = $81;
   }
   $82 = HEAP32[$this>>2]|0;
   $83 = (($82) + ($84<<2)|0);
   HEAP32[$83>>2] = $__nd;
  }
 } else {
  $85 = HEAP32[$67>>2]|0;
  HEAP32[$__nd>>2] = $85;
  HEAP32[$67>>2] = $__nd;
 }
 $86 = HEAP32[$35>>2]|0;
 $87 = (($86) + 1)|0;
 HEAP32[$35>>2] = $87;
 $89 = 1;$__ndptr$1 = $__nd;
 HEAP32[$agg$result>>2] = $__ndptr$1;
 $88 = (($agg$result) + 4|0);
 HEAP8[$88>>0] = $89;
 STACKTOP = sp;return;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIP12PropertyInfoP24Il2CppReflectionPropertyEENS_22__unordered_map_hasherIS3_S6_N6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashELb1EEENS_21__unordered_map_equalIS3_S6_NSB_25Il2CppPropertyInfoCompareELb1EEENS8_2gc9AllocatorIS6_EEE6rehashEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)==(1);
 if ($0) {
  $8 = 2;
 } else {
  $1 = (($__n) + -1)|0;
  $2 = $1 & $__n;
  $3 = ($2|0)==(0);
  if ($3) {
   $8 = $__n;
  } else {
   $4 = (__ZNSt3__112__next_primeEj($__n)|0);
   $8 = $4;
  }
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($8>>>0)>($6>>>0);
 if ($7) {
  __ZNSt3__112__hash_tableINS_17__hash_value_typeIP12PropertyInfoP24Il2CppReflectionPropertyEENS_22__unordered_map_hasherIS3_S6_N6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashELb1EEENS_21__unordered_map_equalIS3_S6_NSB_25Il2CppPropertyInfoCompareELb1EEENS8_2gc9AllocatorIS6_EEE8__rehashEj($this,$8);
  STACKTOP = sp;return;
 }
 $9 = ($8>>>0)<($6>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = ($6>>>0)>(2);
 if ($10) {
  $11 = (($6) + -1)|0;
  $12 = $11 & $6;
  $13 = ($12|0)==(0);
  $31 = $13;
 } else {
  $31 = 0;
 }
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (Math_fround(($15>>>0)));
 $17 = (($this) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 / $18);
 $20 = (Math_fround(Math_ceil((Math_fround($19)))));
 $21 = (~~(($20))>>>0);
 if ($31) {
  $22 = (($21) + -1)|0;
  $23 = (_llvm_ctlz_i32(($22|0))|0);
  $24 = (32 - ($23))|0;
  $25 = 1 << $24;
  $28 = $25;
 } else {
  $26 = (__ZNSt3__112__next_primeEj($21)|0);
  $28 = $26;
 }
 $27 = ($8>>>0)<($28>>>0);
 $29 = $27 ? $28 : $8;
 $30 = ($29>>>0)<($6>>>0);
 if (!($30)) {
  STACKTOP = sp;return;
 }
 __ZNSt3__112__hash_tableINS_17__hash_value_typeIP12PropertyInfoP24Il2CppReflectionPropertyEENS_22__unordered_map_hasherIS3_S6_N6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashELb1EEENS_21__unordered_map_equalIS3_S6_NSB_25Il2CppPropertyInfoCompareELb1EEENS8_2gc9AllocatorIS6_EEE8__rehashEj($this,$29);
 STACKTOP = sp;return;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIP12PropertyInfoP24Il2CppReflectionPropertyEENS_22__unordered_map_hasherIS3_S6_N6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashELb1EEENS_21__unordered_map_equalIS3_S6_NSB_25Il2CppPropertyInfoCompareELb1EEENS8_2gc9AllocatorIS6_EEE8__rehashEj($this,$__nbc) {
 $this = $this|0;
 $__nbc = $__nbc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__cp$0 = 0, $__cp$0$in1423 = 0, $__cp$0$in17 = 0, $__cp$07 = 0, $__cp$0715 = 0, $__cp$071520 = 0, $__cp$071524 = 0, $__cp$0718 = 0, $__cp$08 = 0, $__i$010 = 0, $__np$0 = 0, $__phash$0$ph$ph22 = 0, $__pp$0$ph$ph21 = 0, $__pp$0$ph16 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nbc|0)!=(0);
 if ($0) {
  $1 = $__nbc << 2;
  $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
  $4 = $2;
 } else {
  $4 = 0;
 }
 $3 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $4;
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  __THREW__ = 0;
  invoke_vi(3303,($3|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   ___cxa_call_unexpected(($8|0));
   // unreachable;
  }
 }
 $10 = (($this) + 4|0);
 HEAP32[$10>>2] = $__nbc;
 if ($0) {
  $__i$010 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $11 = HEAP32[$this>>2]|0;
  $12 = (($11) + ($__i$010<<2)|0);
  HEAP32[$12>>2] = 0;
  $13 = (($__i$010) + 1)|0;
  $exitcond = ($13|0)==($__nbc|0);
  if ($exitcond) {
   break;
  } else {
   $__i$010 = $13;
  }
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (($15) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($__nbc) + -1)|0;
 $20 = $19 & $__nbc;
 $21 = ($20|0)==(0);
 if ($21) {
  $22 = $18 & $19;
  $26 = $22;
 } else {
  $23 = (($18>>>0) % ($__nbc>>>0))&-1;
  $26 = $23;
 }
 $24 = HEAP32[$this>>2]|0;
 $25 = (($24) + ($26<<2)|0);
 HEAP32[$25>>2] = $14;
 $__cp$071520 = HEAP32[$15>>2]|0;
 $27 = ($__cp$071520|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $__cp$0$in1423 = $15;$__cp$071524 = $__cp$071520;$__phash$0$ph$ph22 = $26;$__pp$0$ph$ph21 = $15;
 }
 L22: while(1) {
  $__cp$0$in17 = $__cp$0$in1423;$__cp$0718 = $__cp$071524;$__pp$0$ph16 = $__pp$0$ph$ph21;
  L24: while(1) {
   $__cp$08 = $__cp$0718;
   while(1) {
    $29 = (($__cp$08) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    if ($21) {
     $31 = $30 & $19;
     $34 = $31;
    } else {
     $32 = (($30>>>0) % ($__nbc>>>0))&-1;
     $34 = $32;
    }
    $33 = ($34|0)==($__phash$0$ph$ph22|0);
    if ($33) {
     break;
    }
    $35 = HEAP32[$this>>2]|0;
    $36 = (($35) + ($34<<2)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     break L24;
    }
    $39 = (($__cp$08) + 8|0);
    $__np$0 = $__cp$08;
    while(1) {
     $41 = HEAP32[$__np$0>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      break;
     }
     $43 = HEAP32[$39>>2]|0;
     $44 = (($41) + 8|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($43) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (($45) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = (_strcmp($47,$49)|0);
     $51 = ($50|0)==(0);
     if ($51) {
      $__np$0 = $41;
     } else {
      break;
     }
    }
    HEAP32[$__cp$0$in17>>2] = $41;
    $52 = HEAP32[$this>>2]|0;
    $53 = (($52) + ($34<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = HEAP32[$54>>2]|0;
    HEAP32[$__np$0>>2] = $55;
    $56 = HEAP32[$this>>2]|0;
    $57 = (($56) + ($34<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    HEAP32[$58>>2] = $__cp$08;
    $__cp$0 = HEAP32[$__cp$0$in17>>2]|0;
    $59 = ($__cp$0|0)==(0|0);
    if ($59) {
     label = 26;
     break L22;
    } else {
     $__cp$08 = $__cp$0;
    }
   }
   $__cp$07 = HEAP32[$__cp$08>>2]|0;
   $28 = ($__cp$07|0)==(0|0);
   if ($28) {
    label = 26;
    break L22;
   } else {
    $__cp$0$in17 = $__cp$08;$__cp$0718 = $__cp$07;$__pp$0$ph16 = $__cp$08;
   }
  }
  HEAP32[$36>>2] = $__pp$0$ph16;
  $__cp$0715 = HEAP32[$__cp$08>>2]|0;
  $40 = ($__cp$0715|0)==(0|0);
  if ($40) {
   label = 26;
   break;
  } else {
   $__cp$0$in1423 = $__cp$08;$__cp$071524 = $__cp$0715;$__phash$0$ph$ph22 = $34;$__pp$0$ph$ph21 = $__cp$08;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE15__insert_uniqueERKh($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $3 = HEAP8[$__v>>0]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 13|0);
    $5 = HEAP8[$4>>0]|0;
    $6 = ($3&255)<($5&255);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5&255)<($3&255);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $31 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $30 = (($agg$result) + 4|0);
  HEAP8[$30>>0] = $31;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(16)|0);
 $17 = (($16) + 13|0);
 $18 = HEAP8[$__v>>0]|0;
 HEAP8[$17>>0] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $31 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $30 = (($agg$result) + 4|0);
 HEAP8[$30>>0] = $31;
 STACKTOP = sp;return;
}
function __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($__root,$__x) {
 $__root = $__root|0;
 $__x = $__x|0;
 var $$06 = 0, $$pre = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__x|0)==($__root|0);
 $1 = (($__x) + 12|0);
 $2 = $0&1;
 HEAP8[$1>>0] = $2;
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $$06 = $__x;
 }
 while(1) {
  $3 = (($$06) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 12|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   label = 37;
   break;
  }
  $8 = (($4) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($4|0);
  if ($11) {
   $12 = (($9) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    label = 7;
    break;
   }
   $15 = (($13) + 12|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if (!($17)) {
    label = 7;
    break;
   }
   HEAP8[$5>>0] = 1;
   $18 = ($9|0)==($__root|0);
   $19 = (($9) + 12|0);
   $20 = $18&1;
   HEAP8[$19>>0] = $20;
   HEAP8[$15>>0] = 1;
  } else {
   $50 = ($10|0)==(0|0);
   if ($50) {
    label = 24;
    break;
   }
   $51 = (($10) + 12|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = ($52<<24>>24)==(0);
   if (!($53)) {
    label = 24;
    break;
   }
   HEAP8[$5>>0] = 1;
   $54 = ($9|0)==($__root|0);
   $55 = (($9) + 12|0);
   $56 = $54&1;
   HEAP8[$55>>0] = $56;
   HEAP8[$51>>0] = 1;
  }
  $57 = ($9|0)==($__root|0);
  if ($57) {
   label = 37;
   break;
  } else {
   $$06 = $9;
  }
 }
 if ((label|0) == 7) {
  $21 = HEAP32[$4>>2]|0;
  $22 = ($21|0)==($$06|0);
  if ($22) {
   $35 = $4;$37 = $9;$39 = $4;
  } else {
   $23 = (($4) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$23>>2] = $25;
   $26 = ($25|0)==(0|0);
   if ($26) {
    $29 = $9;
   } else {
    $27 = (($25) + 8|0);
    HEAP32[$27>>2] = $4;
    $$pre14 = HEAP32[$8>>2]|0;
    $29 = $$pre14;
   }
   $28 = (($24) + 8|0);
   HEAP32[$28>>2] = $29;
   $30 = HEAP32[$8>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($4|0);
   if ($32) {
    HEAP32[$30>>2] = $24;
   } else {
    $33 = (($30) + 4|0);
    HEAP32[$33>>2] = $24;
   }
   HEAP32[$24>>2] = $4;
   HEAP32[$8>>2] = $24;
   $$pre = HEAP32[$28>>2]|0;
   $$pre13 = HEAP32[$$pre>>2]|0;
   $35 = $24;$37 = $$pre;$39 = $$pre13;
  }
  $34 = (($35) + 12|0);
  HEAP8[$34>>0] = 1;
  $36 = (($37) + 12|0);
  HEAP8[$36>>0] = 0;
  $38 = (($39) + 4|0);
  $40 = HEAP32[$38>>2]|0;
  HEAP32[$37>>2] = $40;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = (($40) + 8|0);
   HEAP32[$42>>2] = $37;
  }
  $43 = (($37) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($39) + 8|0);
  HEAP32[$45>>2] = $44;
  $46 = HEAP32[$43>>2]|0;
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==($37|0);
  if ($48) {
   HEAP32[$46>>2] = $39;
  } else {
   $49 = (($46) + 4|0);
   HEAP32[$49>>2] = $39;
  }
  HEAP32[$38>>2] = $37;
  HEAP32[$43>>2] = $39;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 24) {
  $58 = HEAP32[$4>>2]|0;
  $59 = ($58|0)==($$06|0);
  if ($59) {
   $60 = (($$06) + 4|0);
   $61 = HEAP32[$60>>2]|0;
   HEAP32[$4>>2] = $61;
   $62 = ($61|0)==(0|0);
   if ($62) {
    $64 = $9;
   } else {
    $63 = (($61) + 8|0);
    HEAP32[$63>>2] = $4;
    $$pre15 = HEAP32[$8>>2]|0;
    $64 = $$pre15;
   }
   HEAP32[$3>>2] = $64;
   $65 = HEAP32[$8>>2]|0;
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==($4|0);
   if ($67) {
    HEAP32[$65>>2] = $$06;
   } else {
    $68 = (($65) + 4|0);
    HEAP32[$68>>2] = $$06;
   }
   HEAP32[$60>>2] = $4;
   HEAP32[$8>>2] = $$06;
   $$pre16 = HEAP32[$3>>2]|0;
   $70 = $$06;$72 = $$pre16;
  } else {
   $70 = $4;$72 = $9;
  }
  $69 = (($70) + 12|0);
  HEAP8[$69>>0] = 1;
  $71 = (($72) + 12|0);
  HEAP8[$71>>0] = 0;
  $73 = (($72) + 4|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = HEAP32[$74>>2]|0;
  HEAP32[$73>>2] = $75;
  $76 = ($75|0)==(0|0);
  if (!($76)) {
   $77 = (($75) + 8|0);
   HEAP32[$77>>2] = $72;
  }
  $78 = (($72) + 8|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($74) + 8|0);
  HEAP32[$80>>2] = $79;
  $81 = HEAP32[$78>>2]|0;
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==($72|0);
  if ($83) {
   HEAP32[$81>>2] = $74;
  } else {
   $84 = (($81) + 4|0);
   HEAP32[$84>>2] = $74;
  }
  HEAP32[$74>>2] = $72;
  HEAP32[$78>>2] = $74;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 37) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3>>>0)<($5>>>0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5>>>0)<($3>>>0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $31 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $30 = (($agg$result) + 4|0);
  HEAP8[$30>>0] = $31;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(20)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__v>>2]|0;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $31 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $30 = (($agg$result) + 4|0);
 HEAP8[$30>>0] = $31;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIP12Il2CppObjectN6il2cpp2gc9AllocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7|0)<(0);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = $12 >> 2;
 $14 = ($13>>>0)<(1073741823);
 if ($14) {
  $15 = $12 >> 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = $$0$i2 << 2;
  $20 = (__Z21il2cpp_gc_alloc_fixedjPv($19,0)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + ($6<<2)|0);
 $23 = (($22) + ($$0$i3<<2)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  $25 = HEAP32[$__x>>2]|0;
  HEAP32[$21>>2] = $25;
 }
 $26 = (($22) + ($7<<2)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$0>>2]|0;
 $29 = $28;
 $30 = $27;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 2;
 $$sum1 = (($6) - ($32))|0;
 $33 = (($22) + ($$sum1<<2)|0);
 _memcpy(($33|0),($27|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$0>>2] = $26;
 HEAP32[$9>>2] = $23;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3303,($34|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE7destroyEPNS_11__tree_nodeIhPvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE7destroyEPNS_11__tree_nodeIhPvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE7destroyEPNS_11__tree_nodeIhPvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp6icalls8mscorlib6System15NumberFormatter18GetFormatterTablesEPPyPPiPPsS9_PPxS7_($mantissas,$exponents,$digitLowerTable,$digitUpperTable,$tenPowersList,$decHexDigits) {
 $mantissas = $mantissas|0;
 $exponents = $exponents|0;
 $digitLowerTable = $digitLowerTable|0;
 $digitUpperTable = $digitUpperTable|0;
 $tenPowersList = $tenPowersList|0;
 $decHexDigits = $decHexDigits|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$mantissas>>2] = 199720;
 HEAP32[$exponents>>2] = 216104;
 HEAP32[$digitLowerTable>>2] = 224296;
 HEAP32[$digitUpperTable>>2] = 224328;
 HEAP32[$tenPowersList>>2] = 224360;
 HEAP32[$decHexDigits>>2] = 224512;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System6Object19InternalGetHashCodeEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Object7GetHashEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6Object7GetTypeEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6Object15MemberwiseCloneEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Object5CloneEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6Object11obj_addressEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($obj|0);
}
function __ZN6il2cpp6icalls8mscorlib6System19RuntimeMethodHandle18GetFunctionPointerE12Il2CppIntPtr($m) {
 $m = $m|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 224944;
 (_printf((224912|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6String22RedirectToCreateStringEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(224984)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System6String19InternalAllocateStrEi($length) {
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String7NewSizeEi($length)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6String13InternalSplitEP12Il2CppStringP11Il2CppArrayii($me,$separator,$count,$options) {
 $me = $me|0;
 $separator = $separator|0;
 $count = $count|0;
 $options = $options|0;
 var $$0 = 0, $$0$i = 0, $$not = 0, $$splitsize$0 = 0, $$splitsize$2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arrpos$01$i = 0, $arrpos$01$i10 = 0, $arrpos$01$i14 = 0, $arrpos$01$i18 = 0, $arrpos$01$i22 = 0, $arrpos$01$i26 = 0, $arrpos$01$i6 = 0;
 var $arrpos$067 = 0, $arrpos$1 = 0, $arrpos$2 = 0, $brmerge = 0, $flag$082 = 0, $flag$1 = 0, $i$071 = 0, $i$177 = 0, $i$264 = 0, $lastpos$078 = 0, $lastpos$1 = 0, $lastpos$266 = 0, $lastpos$356 = 0, $lastpos$358 = 0, $lastpos$4 = 0, $lastpos$5 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0;
 var $or$cond563 = 0, $or$cond70 = 0, $splitsize$072 = 0, $splitsize$280 = 0, $splitsize$4 = 0, $splitsize$5 = 0, $src$037 = 0, $src$044 = 0, $srcsize$043 = 0, $srcsize$1$ph = 0, $srcsize$132 = 0, $srcsize$133 = 0, $srcsize$250 = 0, $srcsize$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $options & 1;
 $1 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($me)|0);
 $2 = (__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($me)|0);
 $3 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($separator)|0);
 $4 = HEAP32[225200>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = HEAP32[((388944 + 68|0))>>2]|0;
  $7 = (__ZN6il2cpp2vm5Class13GetArrayClassEP8TypeInfoj($6,1)|0);
  HEAP32[225200>>2] = $7;
 }
 $8 = ($0|0)==(0);
 do {
  if ($8) {
   $9 = ($2|0)!=(0);
   $10 = ($count|0)>(1);
   $or$cond70 = $9 & $10;
   if ($or$cond70) {
    $11 = ($3|0)==(0);
    $i$071 = 0;$splitsize$072 = 1;
    while(1) {
     $12 = (($1) + ($i$071<<1)|0);
     $13 = HEAP16[$12>>1]|0;
     L9: do {
      if ($11) {
       $$0$i = 0;
      } else {
       $arrpos$01$i = 0;
       while(1) {
        $16 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($separator,2,$arrpos$01$i)|0);
        $17 = HEAP16[$16>>1]|0;
        $18 = ($17<<16>>16)==($13<<16>>16);
        $15 = (($arrpos$01$i) + 1)|0;
        if ($18) {
         $$0$i = 1;
         break L9;
        }
        $14 = ($15|0)==($3|0);
        if ($14) {
         $$0$i = 0;
         break;
        } else {
         $arrpos$01$i = $15;
        }
       }
      }
     } while(0);
     $$splitsize$0 = (($$0$i) + ($splitsize$072))|0;
     $19 = (($i$071) + 1)|0;
     $20 = ($19|0)!=($2|0);
     $21 = ($$splitsize$0|0)<($count|0);
     $or$cond = $20 & $21;
     if ($or$cond) {
      $i$071 = $19;$splitsize$072 = $$splitsize$0;
     } else {
      $splitsize$5 = $$splitsize$0;
      label = 21;
      break;
     }
    }
   }
  } else {
   $22 = ($count|0)>(1);
   if ($22) {
    $23 = ($2|0)==(0);
    if (!($23)) {
     $24 = ($3|0)==(0);
     $flag$082 = 0;$i$177 = 0;$lastpos$078 = 0;$splitsize$280 = 1;
     while(1) {
      $25 = (($1) + ($i$177<<1)|0);
      $26 = HEAP16[$25>>1]|0;
      L20: do {
       if ($24) {
        label = 16;
       } else {
        $arrpos$01$i6 = 0;
        while(1) {
         $29 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($separator,2,$arrpos$01$i6)|0);
         $30 = HEAP16[$29>>1]|0;
         $31 = ($30<<16>>16)==($26<<16>>16);
         $28 = (($arrpos$01$i6) + 1)|0;
         if ($31) {
          $flag$1 = 0;$lastpos$1 = $lastpos$078;$splitsize$4 = $splitsize$280;
          break L20;
         }
         $27 = ($28|0)==($3|0);
         if ($27) {
          label = 16;
          break;
         } else {
          $arrpos$01$i6 = $28;
         }
        }
       }
      } while(0);
      if ((label|0) == 16) {
       label = 0;
       $32 = ($flag$082|0)==(0);
       if ($32) {
        $33 = ($lastpos$078|0)==(1);
        $34 = $33&1;
        $$splitsize$2 = (($34) + ($splitsize$280))|0;
        $flag$1 = 1;$lastpos$1 = 1;$splitsize$4 = $$splitsize$2;
       } else {
        $flag$1 = $flag$082;$lastpos$1 = $lastpos$078;$splitsize$4 = $splitsize$280;
       }
      }
      $35 = (($i$177) + 1)|0;
      $36 = ($35|0)!=($2|0);
      $37 = ($splitsize$4|0)<($count|0);
      $or$cond3 = $36 & $37;
      if ($or$cond3) {
       $flag$082 = $flag$1;$i$177 = $35;$lastpos$078 = $lastpos$1;$splitsize$280 = $splitsize$4;
      } else {
       break;
      }
     }
     $38 = ($lastpos$1|0)==(0);
     if (!($38)) {
      $splitsize$5 = $splitsize$4;
      label = 21;
      break;
     }
    }
    $39 = HEAP32[225200>>2]|0;
    $40 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($39,0)|0);
    $$0 = $40;
    STACKTOP = sp;return ($$0|0);
   } else {
    label = 22;
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $41 = ($splitsize$5|0)==(1);
  if ($41) {
   label = 22;
  } else {
   $74 = HEAP32[225200>>2]|0;
   $75 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($74,$splitsize$5)|0);
   $76 = ($2|0)==(0);
   $77 = ($splitsize$5|0)==(0);
   $or$cond563 = $76 | $77;
   if ($or$cond563) {
    $$0 = $75;
    STACKTOP = sp;return ($$0|0);
   }
   $78 = ($3|0)==(0);
   $79 = (($splitsize$5) + -1)|0;
   $arrpos$067 = 0;$i$264 = 0;$lastpos$266 = 0;
   L37: while(1) {
    $80 = (($1) + ($i$264<<1)|0);
    $81 = HEAP16[$80>>1]|0;
    L39: do {
     if ($78) {
      $arrpos$2 = $arrpos$067;$lastpos$5 = $lastpos$266;
     } else {
      $arrpos$01$i18 = 0;
      while(1) {
       $84 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($separator,2,$arrpos$01$i18)|0);
       $85 = HEAP16[$84>>1]|0;
       $86 = ($85<<16>>16)==($81<<16>>16);
       $83 = (($arrpos$01$i18) + 1)|0;
       if ($86) {
        break;
       }
       $82 = ($83|0)==($3|0);
       if ($82) {
        $arrpos$2 = $arrpos$067;$lastpos$5 = $lastpos$266;
        break L39;
       } else {
        $arrpos$01$i18 = $83;
       }
      }
      $$not = ($lastpos$266|0)!=($i$264|0);
      $brmerge = $$not | $8;
      if ($brmerge) {
       $87 = (($i$264) - ($lastpos$266))|0;
       $88 = (__ZN6il2cpp2vm6String7NewSizeEi($87)|0);
       $89 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($88)|0);
       $90 = (($1) + ($lastpos$266<<1)|0);
       $91 = $87 << 1;
       _memcpy(($89|0),($90|0),($91|0))|0;
       $92 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($75,4,$arrpos$067)|0);
       HEAP32[$92>>2] = $88;
       $93 = (($arrpos$067) + 1)|0;
       $94 = ($93|0)==($79|0);
       if ($94) {
        break L37;
       } else {
        $arrpos$1 = $93;
       }
      } else {
       $arrpos$1 = $arrpos$067;
      }
      $124 = (($i$264) + 1)|0;
      $arrpos$2 = $arrpos$1;$lastpos$5 = $124;
     }
    } while(0);
    $125 = (($i$264) + 1)|0;
    $126 = ($125|0)==($2|0);
    $127 = ($arrpos$2|0)==($splitsize$5|0);
    $or$cond5 = $126 | $127;
    if ($or$cond5) {
     $$0 = $75;
     label = 59;
     break;
    } else {
     $arrpos$067 = $arrpos$2;$i$264 = $125;$lastpos$266 = $lastpos$5;
    }
   }
   if ((label|0) == 59) {
    STACKTOP = sp;return ($$0|0);
   }
   $95 = (($i$264) + 1)|0;
   L51: do {
    if ($8) {
     $lastpos$4 = $95;$srcsize$3 = $2;
    } else {
     $96 = ($95|0)==($2|0);
     L53: do {
      if ($96) {
       $lastpos$356 = $2;
      } else {
       $lastpos$358 = $95;
       while(1) {
        $97 = (($1) + ($lastpos$358<<1)|0);
        $98 = HEAP16[$97>>1]|0;
        $arrpos$01$i22 = 0;
        while(1) {
         $101 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($separator,2,$arrpos$01$i22)|0);
         $102 = HEAP16[$101>>1]|0;
         $103 = ($102<<16>>16)==($98<<16>>16);
         $100 = (($arrpos$01$i22) + 1)|0;
         if ($103) {
          break;
         }
         $99 = ($100|0)==($3|0);
         if ($99) {
          $lastpos$356 = $lastpos$358;
          break L53;
         } else {
          $arrpos$01$i22 = $100;
         }
        }
        $104 = (($lastpos$358) + 1)|0;
        $105 = ($104|0)==($2|0);
        if ($105) {
         $lastpos$356 = $2;
         break;
        } else {
         $lastpos$358 = $104;
        }
       }
      }
     } while(0);
     $106 = ($splitsize$5|0)<($count|0);
     if ($106) {
      $107 = (($lastpos$356) + 1)|0;
      $108 = ($2|0)==($107|0);
      if ($108) {
       $lastpos$4 = $lastpos$356;$srcsize$3 = $2;
      } else {
       $srcsize$250 = $2;
       while(1) {
        $110 = (($srcsize$250) + -1)|0;
        $111 = (($1) + ($110<<1)|0);
        $112 = HEAP16[$111>>1]|0;
        $arrpos$01$i26 = 0;
        while(1) {
         $115 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($separator,2,$arrpos$01$i26)|0);
         $116 = HEAP16[$115>>1]|0;
         $117 = ($116<<16>>16)==($112<<16>>16);
         $114 = (($arrpos$01$i26) + 1)|0;
         if ($117) {
          break;
         }
         $113 = ($114|0)==($3|0);
         if ($113) {
          $lastpos$4 = $lastpos$356;$srcsize$3 = $srcsize$250;
          break L51;
         } else {
          $arrpos$01$i26 = $114;
         }
        }
        $109 = ($110|0)==($107|0);
        if ($109) {
         $lastpos$4 = $lastpos$356;$srcsize$3 = $107;
         break;
        } else {
         $srcsize$250 = $110;
        }
       }
      }
     } else {
      $lastpos$4 = $lastpos$356;$srcsize$3 = $2;
     }
    }
   } while(0);
   $118 = (($srcsize$3) - ($lastpos$4))|0;
   $119 = (__ZN6il2cpp2vm6String7NewSizeEi($118)|0);
   $120 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($119)|0);
   $121 = (($1) + ($lastpos$4<<1)|0);
   $122 = $118 << 1;
   _memcpy(($120|0),($121|0),($122|0))|0;
   $123 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($75,4,$79)|0);
   HEAP32[$123>>2] = $119;
   $$0 = $75;
   STACKTOP = sp;return ($$0|0);
  }
 }
 if ((label|0) == 22) {
  $42 = ($count|0)==(1);
  $or$cond4 = $8 | $42;
  if (!($or$cond4)) {
   $43 = ($2|0)==(0);
   L73: do {
    if ($43) {
     $src$037 = $1;$srcsize$1$ph = 0;
    } else {
     $44 = ($3|0)==(0);
     if ($44) {
      $src$037 = $1;$srcsize$1$ph = $2;
     } else {
      $src$044 = $1;$srcsize$043 = $2;
      while(1) {
       $48 = HEAP16[$src$044>>1]|0;
       $arrpos$01$i10 = 0;
       while(1) {
        $53 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($separator,2,$arrpos$01$i10)|0);
        $54 = HEAP16[$53>>1]|0;
        $55 = ($54<<16>>16)==($48<<16>>16);
        $50 = (($arrpos$01$i10) + 1)|0;
        if ($55) {
         break;
        }
        $49 = ($50|0)==($3|0);
        if ($49) {
         $src$037 = $src$044;$srcsize$1$ph = $srcsize$043;
         break L73;
        } else {
         $arrpos$01$i10 = $50;
        }
       }
       $56 = (($srcsize$043) + -1)|0;
       $57 = (($src$044) + 2|0);
       $58 = ($56|0)==(0);
       if ($58) {
        $src$037 = $57;$srcsize$1$ph = 0;
        break;
       } else {
        $src$044 = $57;$srcsize$043 = $56;
       }
      }
     }
    }
   } while(0);
   $51 = ($srcsize$1$ph|0)==(0);
   L82: do {
    if ($51) {
     $srcsize$132 = 0;
    } else {
     $52 = ($3|0)==(0);
     if ($52) {
      $srcsize$132 = $srcsize$1$ph;
     } else {
      $srcsize$133 = $srcsize$1$ph;
      while(1) {
       $60 = (($srcsize$133) + -1)|0;
       $61 = (($src$037) + ($60<<1)|0);
       $62 = HEAP16[$61>>1]|0;
       $arrpos$01$i14 = 0;
       while(1) {
        $65 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($separator,2,$arrpos$01$i14)|0);
        $66 = HEAP16[$65>>1]|0;
        $67 = ($66<<16>>16)==($62<<16>>16);
        $64 = (($arrpos$01$i14) + 1)|0;
        if ($67) {
         break;
        }
        $63 = ($64|0)==($3|0);
        if ($63) {
         $srcsize$132 = $srcsize$133;
         break L82;
        } else {
         $arrpos$01$i14 = $64;
        }
       }
       $59 = ($60|0)==(0);
       if ($59) {
        $srcsize$132 = 0;
        break;
       } else {
        $srcsize$133 = $60;
       }
      }
     }
    }
   } while(0);
   $68 = (__ZN6il2cpp2vm6String7NewSizeEi($srcsize$132)|0);
   $69 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($68)|0);
   $70 = $srcsize$132 << 1;
   _memcpy(($69|0),($src$037|0),($70|0))|0;
   $71 = HEAP32[225200>>2]|0;
   $72 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($71,1)|0);
   $73 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($72,4,0)|0);
   HEAP32[$73>>2] = $68;
   $$0 = $72;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $45 = HEAP32[225200>>2]|0;
 $46 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($45,1)|0);
 $47 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($46,4,0)|0);
 HEAP32[$47>>2] = $me;
 $$0 = $46;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6String14InternalInternEP12Il2CppString($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_string_intern($str)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System6String18InternalIsInternedEP12Il2CppString($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_string_is_interned($str)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type14EqualsInternalEP20Il2CppReflectionTypeS5_($left,$right) {
 $left = $left|0;
 $right = $right|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($left) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($right) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type17get_IsGenericTypeEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741824;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $7 = (($6) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($6) + 72|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)!=(0|0);
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type27get_IsGenericTypeDefinitionEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741824;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $7 = (($6) + 72|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)!=(0|0);
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type27GetGenericParameterPositionEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp6icalls8mscorlib6System8MonoType22get_IsGenericParameterEP20Il2CppReflectionType($type)|0);
 if (!($0)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($type) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type29GetGenericTypeDefinition_implEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741824;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $7 = (($6) + 72|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $$0 = $type;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($6) + 68|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[$11>>2]|0;
 $14 = (($13) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($15)|0);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type19GetTypeCodeInternalEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $t$0 = 0, $t$0$in = 0, $t$0$in$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741824;
 $5 = ($4|0)==(0);
 L1: do {
  if ($5) {
   $t$0$in$in = $3;
   L2: while(1) {
    $t$0$in = $t$0$in$in >>> 16;
    $t$0 = $t$0$in & 255;
    switch ($t$0|0) {
    case 14:  {
     label = 20;
     break L2;
     break;
    }
    case 13:  {
     label = 13;
     break L2;
     break;
    }
    case 11:  {
     label = 10;
     break L2;
     break;
    }
    case 12:  {
     label = 12;
     break L2;
     break;
    }
    case 10:  {
     label = 11;
     break L2;
     break;
    }
    case 7:  {
     label = 5;
     break L2;
     break;
    }
    case 21: case 22: case 30: case 19: case 28: case 20: case 29: case 24: case 25: case 15: case 1:  {
     label = 25;
     break L2;
     break;
    }
    case 17:  {
     break;
    }
    case 18:  {
     label = 21;
     break L2;
     break;
    }
    case 9:  {
     label = 8;
     break L2;
     break;
    }
    case 3:  {
     label = 7;
     break L2;
     break;
    }
    case 8:  {
     label = 9;
     break L2;
     break;
    }
    case 6:  {
     label = 6;
     break L2;
     break;
    }
    case 4:  {
     label = 4;
     break L2;
     break;
    }
    case 2:  {
     $$0 = 3;
     break L1;
     break;
    }
    case 5:  {
     label = 3;
     break L2;
     break;
    }
    default: {
     label = 24;
     break L2;
    }
    }
    $6 = HEAP32[$0>>2]|0;
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + 117|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     label = 16;
     break;
    }
    $11 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($7)|0);
    $12 = (($11) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $t$0$in$in = $13;
   }
   switch (label|0) {
    case 3: {
     $$0 = 6;
     break L1;
     break;
    }
    case 4: {
     $$0 = 5;
     break L1;
     break;
    }
    case 5: {
     $$0 = 8;
     break L1;
     break;
    }
    case 6: {
     $$0 = 7;
     break L1;
     break;
    }
    case 7: {
     $$0 = 4;
     break L1;
     break;
    }
    case 8: {
     $$0 = 10;
     break L1;
     break;
    }
    case 9: {
     $$0 = 9;
     break L1;
     break;
    }
    case 10: {
     $$0 = 12;
     break L1;
     break;
    }
    case 11: {
     $$0 = 11;
     break L1;
     break;
    }
    case 12: {
     $$0 = 13;
     break L1;
     break;
    }
    case 13: {
     $$0 = 14;
     break L1;
     break;
    }
    case 16: {
     $14 = (($7) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (_strcmp($15,225208)|0);
     $17 = ($16|0)==(0);
     if ($17) {
      $18 = HEAP32[$7>>2]|0;
      $19 = (_strcmp($18,225216)|0);
      $20 = ($19|0)==(0);
      if ($20) {
       $$0 = 15;
       break L1;
      }
      $21 = (_strcmp($18,225224)|0);
      $22 = ($21|0)==(0);
      if ($22) {
       $$0 = 16;
       break L1;
      }
     }
     $$0 = 1;
     break L1;
     break;
    }
    case 20: {
     $$0 = 18;
     break L1;
     break;
    }
    case 21: {
     $23 = HEAP32[$0>>2]|0;
     $24 = HEAP32[$23>>2]|0;
     $25 = (($24) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (_strcmp($26,225208)|0);
     $28 = ($27|0)==(0);
     if ($28) {
      $29 = HEAP32[$24>>2]|0;
      $30 = (_strcmp($29,225240)|0);
      $31 = ($30|0)==(0);
      if ($31) {
       $$0 = 2;
       break L1;
      }
     }
     $$0 = 1;
     break L1;
     break;
    }
    case 24: {
     _abort();
     // unreachable;
     break;
    }
    case 25: {
     $$0 = 1;
     break L1;
     break;
    }
   }
  } else {
   $$0 = 1;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type20internal_from_handleE12Il2CppIntPtr($ptr) {
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ptr>>2]|0;
 $1 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($0)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($1)|0);
 $2 = (($1) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type18internal_from_nameEP12Il2CppStringbb($name,$throwOnError,$ignoreCase) {
 $name = $name|0;
 $throwOnError = $throwOnError|0;
 $ignoreCase = $ignoreCase|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$not = 0, $$not3 = 0, $$not6 = 0, $$not9 = 0, $$pre = 0, $$sink26 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0;
 var $brmerge11 = 0, $brmerge5 = 0, $brmerge8 = 0, $image$01315 = 0, $info = 0, $klass$1 = 0, $klass$12124 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $parser = 0, $str = 0, $throwOnError$not = 0, $throwOnError$not7 = 0, $throwOnError$not719 = 0, $throwOnError$not72223 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $str = sp + 152|0;
 $info = sp;
 $parser = sp + 140|0;
 $0 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($name)|0);
 __ZN6il2cpp5utils11StringUtils11Utf16ToUtf8EPKt($str,$0);
 __THREW__ = 0;
 invoke_vi(3305,($info|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 8;
  } else {
   __THREW__ = 0;
   invoke_viii(1563,($parser|0),($str|0),($info|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   L3: do {
    if ($4) {
     label = 10;
    } else {
     __THREW__ = 0;
     $5 = (invoke_ii(2998,($parser|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      label = 10;
     } else {
      if ($5) {
       label = 12;
      } else {
       if ($throwOnError) {
        __THREW__ = 0;
        $8 = (invoke_i(3)|0);
        $9 = __THREW__; __THREW__ = 0;
        $10 = $9&1;
        if ($10) {
         label = 10;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($8|0));
        $11 = __THREW__; __THREW__ = 0;
        $12 = $11&1;
        if ($12) {
         label = 10;
         break;
        } else {
         label = 12;
        }
       } else {
        $$0 = 0;
       }
      }
      L10: do {
       if ((label|0) == 12) {
        $21 = (($info) + 24|0);
        $22 = HEAP8[$21>>0]|0;
        $23 = $22 & 1;
        $24 = ($23<<24>>24)==(0);
        if ($24) {
         $27 = $22&255;
         $28 = $27 >>> 1;
         $30 = $28;
        } else {
         $25 = (($info) + 28|0);
         $26 = HEAP32[$25>>2]|0;
         $30 = $26;
        }
        $29 = ($30|0)==(0);
        L16: do {
         if ($29) {
          __THREW__ = 0;
          $31 = (invoke_i(4)|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if ($33) {
           label = 10;
           break L3;
          }
          __THREW__ = 0;
          $34 = (invoke_ii(2999,($31|0))|0);
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if ($36) {
           label = 10;
           break L3;
          }
          $37 = (($34) + 4|0);
          $38 = HEAP32[$37>>2]|0;
          $39 = HEAP32[$34>>2]|0;
          $40 = ($38|0)==($39|0);
          L37: do {
           if ($40) {
            $image$01315 = 0;
           } else {
            $$sink26 = $38;$129 = $39;
            while(1) {
             $41 = (($$sink26) + -4|0);
             $42 = HEAP32[$41>>2]|0;
             $43 = (($42) + 8|0);
             $44 = HEAP32[$43>>2]|0;
             $45 = (($44) + 64|0);
             $46 = HEAP32[$45>>2]|0;
             $47 = ($46|0)==(0|0);
             if ($47) {
              $53 = $129;
             } else {
              __THREW__ = 0;
              $48 = (invoke_i(5)|0);
              $49 = __THREW__; __THREW__ = 0;
              $50 = $49&1;
              if ($50) {
               label = 9;
               break;
              }
              $51 = ($46|0)==($48|0);
              if (!($51)) {
               break;
              }
              $$pre = HEAP32[$34>>2]|0;
              $53 = $$pre;
             }
             $52 = ($41|0)==($53|0);
             if ($52) {
              $image$01315 = 0;
              break L37;
             } else {
              $$sink26 = $41;$129 = $53;
             }
            }
            if ((label|0) == 9) {
             $15 = ___cxa_find_matching_catch()|0;
             $16 = tempRet0;
             $lpad$phi$index = $15;$lpad$phi$index2 = $16;
             break L3;
            }
            $54 = HEAP32[$45>>2]|0;
            $55 = ($54|0)==(0|0);
            if ($55) {
             $image$01315 = 0;
            } else {
             __THREW__ = 0;
             $56 = (invoke_iii(2237,($54|0),($info|0))|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              label = 10;
              break L3;
             }
             $59 = ($56|0)==(0|0);
             if ($59) {
              $image$01315 = $54;
             } else {
              $throwOnError$not719 = $throwOnError ^ 1;
              $klass$12124 = $56;$throwOnError$not72223 = $throwOnError$not719;
              break L16;
             }
            }
           }
          } while(0);
          __THREW__ = 0;
          $60 = (invoke_i(5)|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           label = 10;
           break L3;
          }
          $63 = ($image$01315|0)==($60|0);
          if ($63) {
           $klass$1 = 0;
           label = 46;
          } else {
           __THREW__ = 0;
           $64 = (invoke_i(5)|0);
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if ($66) {
            label = 10;
            break L3;
           }
           __THREW__ = 0;
           $67 = (invoke_iii(2237,($64|0),($info|0))|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            label = 10;
            break L3;
           } else {
            $klass$1 = $67;
            label = 46;
           }
          }
         } else {
          if ($24) {
           $72 = (($21) + 1|0);
           $73 = $72;
          } else {
           $70 = (($info) + 32|0);
           $71 = HEAP32[$70>>2]|0;
           $73 = $71;
          }
          __THREW__ = 0;
          $74 = (invoke_ii(3000,($73|0))|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 10;
           break L3;
          }
          $77 = ($74|0)==(0|0);
          $$not = $77 ^ 1;
          $throwOnError$not = $throwOnError ^ 1;
          $brmerge = $$not | $throwOnError$not;
          if (!($brmerge)) {
           __THREW__ = 0;
           $78 = (invoke_i(3)|0);
           $79 = __THREW__; __THREW__ = 0;
           $80 = $79&1;
           if ($80) {
            label = 10;
            break L3;
           }
           __THREW__ = 0;
           invoke_vi(3302,($78|0));
           $81 = __THREW__; __THREW__ = 0;
           $82 = $81&1;
           if ($82) {
            label = 10;
            break L3;
           }
          }
          if ($77) {
           $$0 = 0;
           break L10;
          }
          __THREW__ = 0;
          $83 = (invoke_ii(3001,($74|0))|0);
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if ($85) {
           label = 10;
           break L3;
          }
          $86 = ($83|0)==(0|0);
          $$not3 = $86 ^ 1;
          $brmerge5 = $$not3 | $throwOnError$not;
          if (!($brmerge5)) {
           __THREW__ = 0;
           $87 = (invoke_i(3)|0);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            label = 10;
            break L3;
           }
           __THREW__ = 0;
           invoke_vi(3302,($87|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            label = 10;
            break L3;
           }
          }
          if ($86) {
           $$0 = 0;
           break L10;
          }
          __THREW__ = 0;
          $92 = (invoke_iii(2237,($83|0),($info|0))|0);
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           label = 10;
           break L3;
          } else {
           $klass$1 = $92;
           label = 46;
          }
         }
        } while(0);
        if ((label|0) == 46) {
         $95 = ($klass$1|0)==(0|0);
         $$not6 = $95 ^ 1;
         $throwOnError$not7 = $throwOnError ^ 1;
         $brmerge8 = $$not6 | $throwOnError$not7;
         if (!($brmerge8)) {
          __THREW__ = 0;
          $96 = (invoke_i(3)|0);
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           label = 10;
           break L3;
          }
          __THREW__ = 0;
          invoke_vi(3302,($96|0));
          $99 = __THREW__; __THREW__ = 0;
          $100 = $99&1;
          if ($100) {
           label = 10;
           break L3;
          }
         }
         if ($95) {
          $$0 = 0;
          break;
         } else {
          $klass$12124 = $klass$1;$throwOnError$not72223 = $throwOnError$not7;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,($klass$12124|0))|0);
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         label = 10;
         break L3;
        }
        __THREW__ = 0;
        $103 = (invoke_iii(2238,($klass$12124|0),($info|0))|0);
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if ($105) {
         label = 10;
         break L3;
        }
        $106 = ($103|0)==(0|0);
        $$not9 = $106 ^ 1;
        $brmerge11 = $throwOnError$not72223 | $$not9;
        if (!($brmerge11)) {
         __THREW__ = 0;
         $107 = (invoke_i(3)|0);
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          label = 10;
          break L3;
         }
         __THREW__ = 0;
         invoke_vi(3302,($107|0));
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         if ($111) {
          label = 10;
          break L3;
         }
        }
        if ($106) {
         $$0 = 0;
        } else {
         __THREW__ = 0;
         $112 = (invoke_ii(2992,($103|0))|0);
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          label = 10;
          break L3;
         } else {
          $$0 = $112;
         }
        }
       }
      } while(0);
      __THREW__ = 0;
      invoke_vi(3306,($info|0));
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       label = 8;
       break L1;
      }
      $117 = HEAP8[$str>>0]|0;
      $118 = $117 & 1;
      $119 = ($118<<24>>24)==(0);
      if ($119) {
       STACKTOP = sp;return ($$0|0);
      }
      $120 = (($str) + 8|0);
      $121 = HEAP32[$120>>2]|0;
      __ZdlPv($121);
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   if ((label|0) == 10) {
    $17 = ___cxa_find_matching_catch()|0;
    $18 = tempRet0;
    $lpad$phi$index = $17;$lpad$phi$index2 = $18;
   }
   __THREW__ = 0;
   invoke_vi(3306,($info|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $127 = ___cxa_find_matching_catch(0|0)|0;
    $128 = tempRet0;
    ___clang_call_terminate($127);
    // unreachable;
   } else {
    $$01 = $lpad$phi$index;$$02 = $lpad$phi$index2;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $$01 = $13;$$02 = $14;
 }
 $122 = HEAP8[$str>>0]|0;
 $123 = $122 & 1;
 $124 = ($123<<24>>24)==(0);
 if ($124) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $125 = (($str) + 8|0);
 $126 = HEAP32[$125>>2]|0;
 __ZdlPv($126);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System4Type11IsArrayImplEP20Il2CppReflectionType($t) {
 $t = $t|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class14FromSystemTypeEP20Il2CppReflectionType($t)|0);
 $1 = (($0) + 112|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type16IsInstanceOfTypeEP20Il2CppReflectionTypeP12Il2CppObject($type,$obj) {
 $type = $type|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$2)|0);
 $4 = ($3|0)!=(0|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System31validate_make_array_type_inputsEP20Il2CppReflectionTypei($type,$rank) {
 $type = $type|0;
 $rank = $rank|0;
 var $$0 = 0, $$01 = 0, $$01$i = 0, $$01$i15 = 0, $$01$i37 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre54 = 0, $$sink$i$index2 = 0, $$sink$i14$index7 = 0, $$sink$i36$index12 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$indexZ2D = 0, $message = 0, $message1 = 0, $message2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 496|0;
 $0 = sp + 476|0;
 $message = sp;
 $1 = sp + 144|0;
 $message1 = sp + 160|0;
 $2 = sp + 304|0;
 $message2 = sp + 320|0;
 $3 = sp + 464|0;
 $4 = ($rank|0)>(32);
 L1: do {
  if ($4) {
   $5 = (($message) + 64|0);
   $6 = (($message) + 8|0);
   HEAP32[$6>>2] = ((225744 + 32|0));
   $7 = (($message) + 12|0);
   HEAP32[$message>>2] = ((225808 + 12|0));
   HEAP32[$5>>2] = ((225808 + 32|0));
   $8 = (($message) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($message) + 64|0);
   __THREW__ = 0;
   invoke_vii(2480,($9|0),($7|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   do {
    if ($11) {
     $41 = ___cxa_find_matching_catch()|0;
     $42 = tempRet0;
     $$01$i = $41;$$sink$i$index2 = $42;
    } else {
     $12 = (($message) + 136|0);
     HEAP32[$12>>2] = 0;
     $13 = (($message) + 140|0);
     HEAP32[$13>>2] = -1;
     HEAP32[$message>>2] = ((225744 + 12|0));
     HEAP32[$5>>2] = ((225744 + 52|0));
     HEAP32[$6>>2] = ((225744 + 32|0));
     HEAP32[$7>>2] = ((3090568 + 8|0));
     $14 = (($message) + 16|0);
     __ZNSt3__16localeC2Ev($14);
     $15 = (($message) + 20|0);
     ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP32[$15+20>>2]=0|0;
     HEAP32[$7>>2] = ((225848 + 8|0));
     $16 = (($message) + 44|0);
     $17 = (($message) + 60|0);
     ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
     HEAP32[$17>>2] = 24;
     ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vii(2481,($7|0),($0|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      $25 = ___cxa_find_matching_catch()|0;
      $26 = tempRet0;
      $27 = HEAP8[$0>>0]|0;
      $28 = $27 & 1;
      $29 = ($28<<24>>24)==(0);
      if (!($29)) {
       $30 = (($0) + 8|0);
       $31 = HEAP32[$30>>2]|0;
       __ZdlPv($31);
      }
      $32 = HEAP8[$16>>0]|0;
      $33 = $32 & 1;
      $34 = ($33<<24>>24)==(0);
      if (!($34)) {
       $35 = (($message) + 52|0);
       $36 = HEAP32[$35>>2]|0;
       __ZdlPv($36);
      }
      HEAP32[$7>>2] = ((3090568 + 8|0));
      __THREW__ = 0;
      invoke_vi(3299,($14|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       $39 = ___cxa_find_matching_catch(0|0)|0;
       $40 = tempRet0;
       ___clang_call_terminate($39);
       // unreachable;
      } else {
       $$01$i = $25;$$sink$i$index2 = $26;
       break;
      }
     }
     $20 = HEAP8[$0>>0]|0;
     $21 = $20 & 1;
     $22 = ($21<<24>>24)==(0);
     if (!($22)) {
      $23 = (($0) + 8|0);
      $24 = HEAP32[$23>>2]|0;
      __ZdlPv($24);
     }
     $47 = (($message) + 8|0);
     $48 = (($type) + 8|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = HEAP32[$49>>2]|0;
     $51 = (($50) + 4|0);
     $52 = HEAP32[$51>>2]|0;
     __THREW__ = 0;
     $53 = (invoke_iii(2239,($47|0),($52|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      label = 39;
     } else {
      __THREW__ = 0;
      $56 = (invoke_iii(2239,($53|0),(225248|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 39;
      } else {
       $59 = HEAP32[$48>>2]|0;
       $60 = HEAP32[$59>>2]|0;
       $61 = HEAP32[$60>>2]|0;
       __THREW__ = 0;
       $62 = (invoke_iii(2239,($56|0),($61|0))|0);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 39;
       } else {
        __THREW__ = 0;
        $65 = (invoke_iii(2239,($62|0),(225256|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         label = 39;
        } else {
         __THREW__ = 0;
         $68 = (invoke_iii(2240,($65|0),($rank|0))|0);
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          label = 39;
         } else {
          __THREW__ = 0;
          (invoke_iii(2239,($68|0),(225272|0))|0);
          $71 = __THREW__; __THREW__ = 0;
          $72 = $71&1;
          if ($72) {
           label = 39;
          } else {
           __THREW__ = 0;
           invoke_vii(2482,($1|0),($7|0));
           $73 = __THREW__; __THREW__ = 0;
           $74 = $73&1;
           if ($74) {
            label = 39;
           } else {
            $75 = HEAP8[$1>>0]|0;
            $76 = $75 & 1;
            $77 = ($76<<24>>24)==(0);
            if ($77) {
             $80 = (($1) + 1|0);
             $81 = $80;
            } else {
             $78 = (($1) + 8|0);
             $79 = HEAP32[$78>>2]|0;
             $81 = $79;
            }
            __THREW__ = 0;
            $82 = (invoke_ii(3002,($81|0))|0);
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if (!($84)) {
             __THREW__ = 0;
             invoke_vi(3307,($82|0));
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP8[$1>>0]|0;
              $88 = $87 & 1;
              $89 = ($88<<24>>24)==(0);
              if (!($89)) {
               $90 = (($1) + 8|0);
               $91 = HEAP32[$90>>2]|0;
               __ZdlPv($91);
              }
              HEAP32[$message>>2] = ((225744 + 12|0));
              $92 = (($message) + 64|0);
              HEAP32[$92>>2] = ((225744 + 52|0));
              HEAP32[$6>>2] = ((225744 + 32|0));
              $93 = (($message) + 12|0);
              HEAP32[$93>>2] = ((225848 + 8|0));
              $94 = HEAP8[$16>>0]|0;
              $95 = $94 & 1;
              $96 = ($95<<24>>24)==(0);
              if (!($96)) {
               $97 = (($message) + 52|0);
               $98 = HEAP32[$97>>2]|0;
               __ZdlPv($98);
              }
              HEAP32[$93>>2] = ((3090568 + 8|0));
              __THREW__ = 0;
              invoke_vi(3299,($14|0));
              $99 = __THREW__; __THREW__ = 0;
              $100 = $99&1;
              if (!($100)) {
               __ZNSt3__18ios_baseD2Ev($9);
               $$pre$phiZ2D = $48;
               label = 48;
               break L1;
              }
              $101 = ___cxa_find_matching_catch()|0;
              $102 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3217,($9|0));
              $103 = __THREW__; __THREW__ = 0;
              $104 = $103&1;
              if ($104) {
               $105 = ___cxa_find_matching_catch(0|0)|0;
               $106 = tempRet0;
               ___clang_call_terminate($105);
               // unreachable;
              } else {
               ___resumeException($101|0);
               // unreachable;
              }
             }
            }
            $109 = ___cxa_find_matching_catch()|0;
            $110 = tempRet0;
            $111 = HEAP8[$1>>0]|0;
            $112 = $111 & 1;
            $113 = ($112<<24>>24)==(0);
            if ($113) {
             $$0 = $110;$$01 = $109;
            } else {
             $114 = (($1) + 8|0);
             $115 = HEAP32[$114>>2]|0;
             __ZdlPv($115);
             $$0 = $110;$$01 = $109;
            }
           }
          }
         }
        }
       }
      }
     }
     if ((label|0) == 39) {
      $107 = ___cxa_find_matching_catch()|0;
      $108 = tempRet0;
      $$0 = $108;$$01 = $107;
     }
     HEAP32[$message>>2] = ((225744 + 12|0));
     $116 = (($message) + 64|0);
     HEAP32[$116>>2] = ((225744 + 52|0));
     HEAP32[$6>>2] = ((225744 + 32|0));
     $117 = (($message) + 12|0);
     HEAP32[$117>>2] = ((225848 + 8|0));
     $118 = HEAP8[$16>>0]|0;
     $119 = $118 & 1;
     $120 = ($119<<24>>24)==(0);
     if (!($120)) {
      $121 = (($message) + 52|0);
      $122 = HEAP32[$121>>2]|0;
      __ZdlPv($122);
     }
     HEAP32[$117>>2] = ((3090568 + 8|0));
     __THREW__ = 0;
     invoke_vi(3299,($14|0));
     $123 = __THREW__; __THREW__ = 0;
     $124 = $123&1;
     if (!($124)) {
      __THREW__ = 0;
      invoke_vi(3217,($9|0));
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if ($126) {
       break L1;
      } else {
       $$3 = $$0;$$34 = $$01;
      }
      ___resumeException($$34|0);
      // unreachable;
     }
     $127 = ___cxa_find_matching_catch(0|0)|0;
     $128 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3217,($9|0));
     $129 = __THREW__; __THREW__ = 0;
     $130 = $129&1;
     if ($130) {
      $131 = ___cxa_find_matching_catch(0|0)|0;
      $132 = tempRet0;
      ___clang_call_terminate($131);
      // unreachable;
     } else {
      $eh$lpad$body$indexZ2D = $127;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3217,($5|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $45 = ___cxa_find_matching_catch(0|0)|0;
    $46 = tempRet0;
    ___clang_call_terminate($45);
    // unreachable;
   } else {
    ___resumeException($$01$i|0);
    // unreachable;
   }
  } else {
   $$pre54 = (($type) + 8|0);
   $$pre$phiZ2D = $$pre54;
   label = 48;
  }
 } while(0);
 L68: do {
  if ((label|0) == 48) {
   $133 = HEAP32[$$pre$phiZ2D>>2]|0;
   $134 = (($133) + 4|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = $135 & 1073741824;
   $137 = ($136|0)==(0);
   L70: do {
    if ($137) {
     $263 = $133;
    } else {
     $138 = (($message1) + 64|0);
     $139 = (($message1) + 8|0);
     HEAP32[$139>>2] = ((225744 + 32|0));
     $140 = (($message1) + 12|0);
     HEAP32[$message1>>2] = ((225808 + 12|0));
     HEAP32[$138>>2] = ((225808 + 32|0));
     $141 = (($message1) + 4|0);
     HEAP32[$141>>2] = 0;
     $142 = (($message1) + 64|0);
     __THREW__ = 0;
     invoke_vii(2480,($142|0),($140|0));
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     do {
      if ($144) {
       $174 = ___cxa_find_matching_catch()|0;
       $175 = tempRet0;
       $$01$i15 = $174;$$sink$i14$index7 = $175;
      } else {
       $145 = (($message1) + 136|0);
       HEAP32[$145>>2] = 0;
       $146 = (($message1) + 140|0);
       HEAP32[$146>>2] = -1;
       HEAP32[$message1>>2] = ((225744 + 12|0));
       HEAP32[$138>>2] = ((225744 + 52|0));
       HEAP32[$139>>2] = ((225744 + 32|0));
       HEAP32[$140>>2] = ((3090568 + 8|0));
       $147 = (($message1) + 16|0);
       __ZNSt3__16localeC2Ev($147);
       $148 = (($message1) + 20|0);
       ;HEAP32[$148+0>>2]=0|0;HEAP32[$148+4>>2]=0|0;HEAP32[$148+8>>2]=0|0;HEAP32[$148+12>>2]=0|0;HEAP32[$148+16>>2]=0|0;HEAP32[$148+20>>2]=0|0;
       HEAP32[$140>>2] = ((225848 + 8|0));
       $149 = (($message1) + 44|0);
       $150 = (($message1) + 60|0);
       ;HEAP32[$149+0>>2]=0|0;HEAP32[$149+4>>2]=0|0;HEAP32[$149+8>>2]=0|0;HEAP32[$149+12>>2]=0|0;
       HEAP32[$150>>2] = 24;
       ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
       __THREW__ = 0;
       invoke_vii(2481,($140|0),($0|0));
       $151 = __THREW__; __THREW__ = 0;
       $152 = $151&1;
       if ($152) {
        $158 = ___cxa_find_matching_catch()|0;
        $159 = tempRet0;
        $160 = HEAP8[$0>>0]|0;
        $161 = $160 & 1;
        $162 = ($161<<24>>24)==(0);
        if (!($162)) {
         $163 = (($0) + 8|0);
         $164 = HEAP32[$163>>2]|0;
         __ZdlPv($164);
        }
        $165 = HEAP8[$149>>0]|0;
        $166 = $165 & 1;
        $167 = ($166<<24>>24)==(0);
        if (!($167)) {
         $168 = (($message1) + 52|0);
         $169 = HEAP32[$168>>2]|0;
         __ZdlPv($169);
        }
        HEAP32[$140>>2] = ((3090568 + 8|0));
        __THREW__ = 0;
        invoke_vi(3299,($147|0));
        $170 = __THREW__; __THREW__ = 0;
        $171 = $170&1;
        if ($171) {
         $172 = ___cxa_find_matching_catch(0|0)|0;
         $173 = tempRet0;
         ___clang_call_terminate($172);
         // unreachable;
        } else {
         $$01$i15 = $158;$$sink$i14$index7 = $159;
         break;
        }
       }
       $153 = HEAP8[$0>>0]|0;
       $154 = $153 & 1;
       $155 = ($154<<24>>24)==(0);
       if (!($155)) {
        $156 = (($0) + 8|0);
        $157 = HEAP32[$156>>2]|0;
        __ZdlPv($157);
       }
       $180 = (($message1) + 8|0);
       __THREW__ = 0;
       $181 = (invoke_iii(2239,($180|0),(225304|0))|0);
       $182 = __THREW__; __THREW__ = 0;
       $183 = $182&1;
       if ($183) {
        label = 84;
       } else {
        $184 = HEAP32[$$pre$phiZ2D>>2]|0;
        $185 = HEAP32[$184>>2]|0;
        $186 = (($185) + 4|0);
        $187 = HEAP32[$186>>2]|0;
        __THREW__ = 0;
        $188 = (invoke_iii(2239,($181|0),($187|0))|0);
        $189 = __THREW__; __THREW__ = 0;
        $190 = $189&1;
        if ($190) {
         label = 84;
        } else {
         __THREW__ = 0;
         $191 = (invoke_iii(2239,($188|0),(225248|0))|0);
         $192 = __THREW__; __THREW__ = 0;
         $193 = $192&1;
         if ($193) {
          label = 84;
         } else {
          $194 = HEAP32[$$pre$phiZ2D>>2]|0;
          $195 = HEAP32[$194>>2]|0;
          $196 = HEAP32[$195>>2]|0;
          __THREW__ = 0;
          $197 = (invoke_iii(2239,($191|0),($196|0))|0);
          $198 = __THREW__; __THREW__ = 0;
          $199 = $198&1;
          if ($199) {
           label = 84;
          } else {
           __THREW__ = 0;
           (invoke_iii(2239,($197|0),(225336|0))|0);
           $200 = __THREW__; __THREW__ = 0;
           $201 = $200&1;
           if ($201) {
            label = 84;
           } else {
            __THREW__ = 0;
            invoke_vii(2482,($2|0),($140|0));
            $202 = __THREW__; __THREW__ = 0;
            $203 = $202&1;
            if ($203) {
             label = 84;
            } else {
             $204 = HEAP8[$2>>0]|0;
             $205 = $204 & 1;
             $206 = ($205<<24>>24)==(0);
             if ($206) {
              $209 = (($2) + 1|0);
              $210 = $209;
             } else {
              $207 = (($2) + 8|0);
              $208 = HEAP32[$207>>2]|0;
              $210 = $208;
             }
             __THREW__ = 0;
             $211 = (invoke_ii(3002,($210|0))|0);
             $212 = __THREW__; __THREW__ = 0;
             $213 = $212&1;
             if (!($213)) {
              __THREW__ = 0;
              invoke_vi(3307,($211|0));
              $214 = __THREW__; __THREW__ = 0;
              $215 = $214&1;
              if (!($215)) {
               $216 = HEAP8[$2>>0]|0;
               $217 = $216 & 1;
               $218 = ($217<<24>>24)==(0);
               if (!($218)) {
                $219 = (($2) + 8|0);
                $220 = HEAP32[$219>>2]|0;
                __ZdlPv($220);
               }
               HEAP32[$message1>>2] = ((225744 + 12|0));
               $221 = (($message1) + 64|0);
               HEAP32[$221>>2] = ((225744 + 52|0));
               HEAP32[$139>>2] = ((225744 + 32|0));
               $222 = (($message1) + 12|0);
               HEAP32[$222>>2] = ((225848 + 8|0));
               $223 = HEAP8[$149>>0]|0;
               $224 = $223 & 1;
               $225 = ($224<<24>>24)==(0);
               if (!($225)) {
                $226 = (($message1) + 52|0);
                $227 = HEAP32[$226>>2]|0;
                __ZdlPv($227);
               }
               HEAP32[$222>>2] = ((3090568 + 8|0));
               __THREW__ = 0;
               invoke_vi(3299,($147|0));
               $228 = __THREW__; __THREW__ = 0;
               $229 = $228&1;
               if (!($229)) {
                __ZNSt3__18ios_baseD2Ev($142);
                $$pre = HEAP32[$$pre$phiZ2D>>2]|0;
                $263 = $$pre;
                break L70;
               }
               $230 = ___cxa_find_matching_catch()|0;
               $231 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3217,($142|0));
               $232 = __THREW__; __THREW__ = 0;
               $233 = $232&1;
               if ($233) {
                $234 = ___cxa_find_matching_catch(0|0)|0;
                $235 = tempRet0;
                ___clang_call_terminate($234);
                // unreachable;
               } else {
                ___resumeException($230|0);
                // unreachable;
               }
              }
             }
             $238 = ___cxa_find_matching_catch()|0;
             $239 = tempRet0;
             $240 = HEAP8[$2>>0]|0;
             $241 = $240 & 1;
             $242 = ($241<<24>>24)==(0);
             if ($242) {
              $$1 = $239;$$12 = $238;
             } else {
              $243 = (($2) + 8|0);
              $244 = HEAP32[$243>>2]|0;
              __ZdlPv($244);
              $$1 = $239;$$12 = $238;
             }
            }
           }
          }
         }
        }
       }
       if ((label|0) == 84) {
        $236 = ___cxa_find_matching_catch()|0;
        $237 = tempRet0;
        $$1 = $237;$$12 = $236;
       }
       HEAP32[$message1>>2] = ((225744 + 12|0));
       $245 = (($message1) + 64|0);
       HEAP32[$245>>2] = ((225744 + 52|0));
       HEAP32[$139>>2] = ((225744 + 32|0));
       $246 = (($message1) + 12|0);
       HEAP32[$246>>2] = ((225848 + 8|0));
       $247 = HEAP8[$149>>0]|0;
       $248 = $247 & 1;
       $249 = ($248<<24>>24)==(0);
       if (!($249)) {
        $250 = (($message1) + 52|0);
        $251 = HEAP32[$250>>2]|0;
        __ZdlPv($251);
       }
       HEAP32[$246>>2] = ((3090568 + 8|0));
       __THREW__ = 0;
       invoke_vi(3299,($147|0));
       $252 = __THREW__; __THREW__ = 0;
       $253 = $252&1;
       if (!($253)) {
        __THREW__ = 0;
        invoke_vi(3217,($142|0));
        $254 = __THREW__; __THREW__ = 0;
        $255 = $254&1;
        if ($255) {
         break L68;
        } else {
         $$3 = $$1;$$34 = $$12;
        }
        ___resumeException($$34|0);
        // unreachable;
       }
       $256 = ___cxa_find_matching_catch(0|0)|0;
       $257 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3217,($142|0));
       $258 = __THREW__; __THREW__ = 0;
       $259 = $258&1;
       if ($259) {
        $260 = ___cxa_find_matching_catch(0|0)|0;
        $261 = tempRet0;
        ___clang_call_terminate($260);
        // unreachable;
       } else {
        $eh$lpad$body$indexZ2D = $256;
        ___clang_call_terminate($eh$lpad$body$indexZ2D);
        // unreachable;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3217,($138|0));
     $176 = __THREW__; __THREW__ = 0;
     $177 = $176&1;
     if ($177) {
      $178 = ___cxa_find_matching_catch(0|0)|0;
      $179 = tempRet0;
      ___clang_call_terminate($178);
      // unreachable;
     } else {
      ___resumeException($$01$i15|0);
      // unreachable;
     }
    }
   } while(0);
   $262 = HEAP32[$263>>2]|0;
   $264 = (($262) + 4|0);
   $265 = HEAP32[$264>>2]|0;
   $266 = (_strcmp($265,225208)|0);
   $267 = ($266|0)==(0);
   if (!($267)) {
    STACKTOP = sp;return;
   }
   $268 = HEAP32[$262>>2]|0;
   $269 = (_strcmp($268,225344)|0);
   $270 = ($269|0)==(0);
   if (!($270)) {
    STACKTOP = sp;return;
   }
   $271 = (($message2) + 64|0);
   $272 = (($message2) + 8|0);
   HEAP32[$272>>2] = ((225744 + 32|0));
   $273 = (($message2) + 12|0);
   HEAP32[$message2>>2] = ((225808 + 12|0));
   HEAP32[$271>>2] = ((225808 + 32|0));
   $274 = (($message2) + 4|0);
   HEAP32[$274>>2] = 0;
   $275 = (($message2) + 64|0);
   __THREW__ = 0;
   invoke_vii(2480,($275|0),($273|0));
   $276 = __THREW__; __THREW__ = 0;
   $277 = $276&1;
   do {
    if ($277) {
     $307 = ___cxa_find_matching_catch()|0;
     $308 = tempRet0;
     $$01$i37 = $307;$$sink$i36$index12 = $308;
    } else {
     $278 = (($message2) + 136|0);
     HEAP32[$278>>2] = 0;
     $279 = (($message2) + 140|0);
     HEAP32[$279>>2] = -1;
     HEAP32[$message2>>2] = ((225744 + 12|0));
     HEAP32[$271>>2] = ((225744 + 52|0));
     HEAP32[$272>>2] = ((225744 + 32|0));
     HEAP32[$273>>2] = ((3090568 + 8|0));
     $280 = (($message2) + 16|0);
     __ZNSt3__16localeC2Ev($280);
     $281 = (($message2) + 20|0);
     ;HEAP32[$281+0>>2]=0|0;HEAP32[$281+4>>2]=0|0;HEAP32[$281+8>>2]=0|0;HEAP32[$281+12>>2]=0|0;HEAP32[$281+16>>2]=0|0;HEAP32[$281+20>>2]=0|0;
     HEAP32[$273>>2] = ((225848 + 8|0));
     $282 = (($message2) + 44|0);
     $283 = (($message2) + 60|0);
     ;HEAP32[$282+0>>2]=0|0;HEAP32[$282+4>>2]=0|0;HEAP32[$282+8>>2]=0|0;HEAP32[$282+12>>2]=0|0;
     HEAP32[$283>>2] = 24;
     ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vii(2481,($273|0),($0|0));
     $284 = __THREW__; __THREW__ = 0;
     $285 = $284&1;
     if ($285) {
      $291 = ___cxa_find_matching_catch()|0;
      $292 = tempRet0;
      $293 = HEAP8[$0>>0]|0;
      $294 = $293 & 1;
      $295 = ($294<<24>>24)==(0);
      if (!($295)) {
       $296 = (($0) + 8|0);
       $297 = HEAP32[$296>>2]|0;
       __ZdlPv($297);
      }
      $298 = HEAP8[$282>>0]|0;
      $299 = $298 & 1;
      $300 = ($299<<24>>24)==(0);
      if (!($300)) {
       $301 = (($message2) + 52|0);
       $302 = HEAP32[$301>>2]|0;
       __ZdlPv($302);
      }
      HEAP32[$273>>2] = ((3090568 + 8|0));
      __THREW__ = 0;
      invoke_vi(3299,($280|0));
      $303 = __THREW__; __THREW__ = 0;
      $304 = $303&1;
      if ($304) {
       $305 = ___cxa_find_matching_catch(0|0)|0;
       $306 = tempRet0;
       ___clang_call_terminate($305);
       // unreachable;
      } else {
       $$01$i37 = $291;$$sink$i36$index12 = $292;
       break;
      }
     }
     $286 = HEAP8[$0>>0]|0;
     $287 = $286 & 1;
     $288 = ($287<<24>>24)==(0);
     if (!($288)) {
      $289 = (($0) + 8|0);
      $290 = HEAP32[$289>>2]|0;
      __ZdlPv($290);
     }
     $313 = (($message2) + 8|0);
     __THREW__ = 0;
     $314 = (invoke_iii(2239,($313|0),(225304|0))|0);
     $315 = __THREW__; __THREW__ = 0;
     $316 = $315&1;
     if ($316) {
      label = 130;
     } else {
      $317 = HEAP32[$$pre$phiZ2D>>2]|0;
      $318 = HEAP32[$317>>2]|0;
      $319 = (($318) + 4|0);
      $320 = HEAP32[$319>>2]|0;
      __THREW__ = 0;
      $321 = (invoke_iii(2239,($314|0),($320|0))|0);
      $322 = __THREW__; __THREW__ = 0;
      $323 = $322&1;
      if ($323) {
       label = 130;
      } else {
       __THREW__ = 0;
       $324 = (invoke_iii(2239,($321|0),(225248|0))|0);
       $325 = __THREW__; __THREW__ = 0;
       $326 = $325&1;
       if ($326) {
        label = 130;
       } else {
        $327 = HEAP32[$$pre$phiZ2D>>2]|0;
        $328 = HEAP32[$327>>2]|0;
        $329 = HEAP32[$328>>2]|0;
        __THREW__ = 0;
        $330 = (invoke_iii(2239,($324|0),($329|0))|0);
        $331 = __THREW__; __THREW__ = 0;
        $332 = $331&1;
        if ($332) {
         label = 130;
        } else {
         __THREW__ = 0;
         (invoke_iii(2239,($330|0),(225360|0))|0);
         $333 = __THREW__; __THREW__ = 0;
         $334 = $333&1;
         if ($334) {
          label = 130;
         } else {
          __THREW__ = 0;
          invoke_vii(2482,($3|0),($273|0));
          $335 = __THREW__; __THREW__ = 0;
          $336 = $335&1;
          if ($336) {
           label = 130;
          } else {
           $337 = HEAP8[$3>>0]|0;
           $338 = $337 & 1;
           $339 = ($338<<24>>24)==(0);
           if ($339) {
            $342 = (($3) + 1|0);
            $343 = $342;
           } else {
            $340 = (($3) + 8|0);
            $341 = HEAP32[$340>>2]|0;
            $343 = $341;
           }
           __THREW__ = 0;
           $344 = (invoke_ii(3002,($343|0))|0);
           $345 = __THREW__; __THREW__ = 0;
           $346 = $345&1;
           if (!($346)) {
            __THREW__ = 0;
            invoke_vi(3307,($344|0));
            $347 = __THREW__; __THREW__ = 0;
            $348 = $347&1;
            if (!($348)) {
             $349 = HEAP8[$3>>0]|0;
             $350 = $349 & 1;
             $351 = ($350<<24>>24)==(0);
             if (!($351)) {
              $352 = (($3) + 8|0);
              $353 = HEAP32[$352>>2]|0;
              __ZdlPv($353);
             }
             HEAP32[$message2>>2] = ((225744 + 12|0));
             $354 = (($message2) + 64|0);
             HEAP32[$354>>2] = ((225744 + 52|0));
             HEAP32[$272>>2] = ((225744 + 32|0));
             $355 = (($message2) + 12|0);
             HEAP32[$355>>2] = ((225848 + 8|0));
             $356 = HEAP8[$282>>0]|0;
             $357 = $356 & 1;
             $358 = ($357<<24>>24)==(0);
             if (!($358)) {
              $359 = (($message2) + 52|0);
              $360 = HEAP32[$359>>2]|0;
              __ZdlPv($360);
             }
             HEAP32[$355>>2] = ((3090568 + 8|0));
             __THREW__ = 0;
             invoke_vi(3299,($280|0));
             $361 = __THREW__; __THREW__ = 0;
             $362 = $361&1;
             if (!($362)) {
              __ZNSt3__18ios_baseD2Ev($275);
              STACKTOP = sp;return;
             }
             $363 = ___cxa_find_matching_catch()|0;
             $364 = tempRet0;
             __THREW__ = 0;
             invoke_vi(3217,($275|0));
             $365 = __THREW__; __THREW__ = 0;
             $366 = $365&1;
             if ($366) {
              $367 = ___cxa_find_matching_catch(0|0)|0;
              $368 = tempRet0;
              ___clang_call_terminate($367);
              // unreachable;
             } else {
              ___resumeException($363|0);
              // unreachable;
             }
            }
           }
           $371 = ___cxa_find_matching_catch()|0;
           $372 = tempRet0;
           $373 = HEAP8[$3>>0]|0;
           $374 = $373 & 1;
           $375 = ($374<<24>>24)==(0);
           if ($375) {
            $$2 = $372;$$23 = $371;
           } else {
            $376 = (($3) + 8|0);
            $377 = HEAP32[$376>>2]|0;
            __ZdlPv($377);
            $$2 = $372;$$23 = $371;
           }
          }
         }
        }
       }
      }
     }
     if ((label|0) == 130) {
      $369 = ___cxa_find_matching_catch()|0;
      $370 = tempRet0;
      $$2 = $370;$$23 = $369;
     }
     HEAP32[$message2>>2] = ((225744 + 12|0));
     $378 = (($message2) + 64|0);
     HEAP32[$378>>2] = ((225744 + 52|0));
     HEAP32[$272>>2] = ((225744 + 32|0));
     $379 = (($message2) + 12|0);
     HEAP32[$379>>2] = ((225848 + 8|0));
     $380 = HEAP8[$282>>0]|0;
     $381 = $380 & 1;
     $382 = ($381<<24>>24)==(0);
     if (!($382)) {
      $383 = (($message2) + 52|0);
      $384 = HEAP32[$383>>2]|0;
      __ZdlPv($384);
     }
     HEAP32[$379>>2] = ((3090568 + 8|0));
     __THREW__ = 0;
     invoke_vi(3299,($280|0));
     $385 = __THREW__; __THREW__ = 0;
     $386 = $385&1;
     if (!($386)) {
      __THREW__ = 0;
      invoke_vi(3217,($275|0));
      $387 = __THREW__; __THREW__ = 0;
      $388 = $387&1;
      if ($388) {
       break L68;
      } else {
       $$3 = $$2;$$34 = $$23;
      }
      ___resumeException($$34|0);
      // unreachable;
     }
     $389 = ___cxa_find_matching_catch(0|0)|0;
     $390 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3217,($275|0));
     $391 = __THREW__; __THREW__ = 0;
     $392 = $391&1;
     if ($392) {
      $393 = ___cxa_find_matching_catch(0|0)|0;
      $394 = tempRet0;
      ___clang_call_terminate($393);
      // unreachable;
     } else {
      $eh$lpad$body$indexZ2D = $389;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3217,($271|0));
   $309 = __THREW__; __THREW__ = 0;
   $310 = $309&1;
   if ($310) {
    $311 = ___cxa_find_matching_catch(0|0)|0;
    $312 = tempRet0;
    ___clang_call_terminate($311);
    // unreachable;
   } else {
    ___resumeException($$01$i37|0);
    // unreachable;
   }
  }
 } while(0);
 $395 = ___cxa_find_matching_catch(0|0)|0;
 $396 = tempRet0;
 $eh$lpad$body$indexZ2D = $395;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZNSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((225744 + 12|0));
 $0 = (($this) + 64|0);
 HEAP32[$0>>2] = ((225744 + 52|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((225744 + 32|0));
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = ((225848 + 8|0));
 $3 = (($this) + 44|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = (($this) + 52|0);
  $8 = HEAP32[$7>>2]|0;
  __ZdlPv($8);
 }
 HEAP32[$2>>2] = ((3090568 + 8|0));
 $9 = (($this) + 16|0);
 __THREW__ = 0;
 invoke_vi(3299,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = (($this) + 64|0);
  __ZNSt3__18ios_baseD2Ev($12);
  STACKTOP = sp;return;
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $15 = (($this) + 64|0);
 __THREW__ = 0;
 invoke_vi(3217,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
}
function __ZN6il2cpp6icalls8mscorlib6System4Type15make_array_typeEP20Il2CppReflectionTypei($type,$rank) {
 $type = $type|0;
 $rank = $rank|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arrayClass$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp6icalls8mscorlib6System31validate_make_array_type_inputsEP20Il2CppReflectionTypei($type,$rank);
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_il2cpp_class_from_il2cpp_type($1)|0);
 $3 = ($rank|0)==(0);
 if ($3) {
  $4 = (_il2cpp_array_class_get($2,1)|0);
  $arrayClass$0 = $4;
 } else {
  $5 = (_il2cpp_bounded_array_class_get($2,$rank,1)|0);
  $arrayClass$0 = $5;
 }
 $6 = ($arrayClass$0|0)==(0|0);
 if ($6) {
  $10 = 0;
  STACKTOP = sp;return ($10|0);
 }
 $7 = (($arrayClass$0) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($8)|0);
 $10 = $9;
 STACKTOP = sp;return ($10|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type15MakeGenericTypeEP20Il2CppReflectionTypeP11Il2CppArray($type,$genericArgumentTypes) {
 $type = $type|0;
 $genericArgumentTypes = $genericArgumentTypes|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i3 = 0, $genericArguments = 0, $i$012 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $genericArguments = sp;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($genericArgumentTypes)|0);
 HEAP32[$genericArguments>>2] = 0;
 $4 = (($genericArguments) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($genericArguments) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = ($3|0)==(0);
 L1: do {
  if ($6) {
   label = 27;
  } else {
   $7 = $3 << 2;
   __THREW__ = 0;
   $8 = (invoke_ii(2988,($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 22;
   } else {
    $11 = (($8) + ($3<<2)|0);
    HEAP32[$genericArguments>>2] = $8;
    HEAP32[$4>>2] = $8;
    HEAP32[$5>>2] = $11;
    $i$012 = 0;
    while(1) {
     __THREW__ = 0;
     $12 = (invoke_iiii(1477,($genericArgumentTypes|0),4,($i$012|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 21;
      break;
     }
     $15 = HEAP32[$12>>2]|0;
     $16 = (($15) + 8|0);
     $17 = HEAP32[$4>>2]|0;
     $18 = HEAP32[$5>>2]|0;
     $19 = ($17|0)==($18|0);
     if ($19) {
      $24 = HEAP32[$genericArguments>>2]|0;
      $25 = $17;
      $26 = $24;
      $27 = (($25) - ($26))|0;
      $28 = $27 >> 2;
      $29 = (($28) + 1)|0;
      $30 = ($29>>>0)>(1073741823);
      if ($30) {
       break;
      }
      $33 = ($28>>>0)<(536870911);
      if ($33) {
       $34 = $27 >> 1;
       $35 = ($34>>>0)<($29>>>0);
       $36 = $35 ? $29 : $34;
       $37 = ($36|0)==(0);
       if ($37) {
        $$0$i3$i$i = 0;$43 = 0;
       } else {
        $$0$i2$i$i = $36;
        label = 14;
       }
      } else {
       $$0$i2$i$i = 1073741823;
       label = 14;
      }
      if ((label|0) == 14) {
       label = 0;
       $38 = $$0$i2$i$i << 2;
       __THREW__ = 0;
       $39 = (invoke_ii(2988,($38|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        label = 21;
        break;
       }
       $$0$i3$i$i = $$0$i2$i$i;$43 = $39;
      }
      $42 = (($43) + ($28<<2)|0);
      $44 = (($43) + ($$0$i3$i$i<<2)|0);
      $45 = ($42|0)==(0|0);
      if (!($45)) {
       $46 = HEAP32[$16>>2]|0;
       HEAP32[$42>>2] = $46;
      }
      $47 = (($43) + ($29<<2)|0);
      _memcpy(($43|0),($24|0),($27|0))|0;
      HEAP32[$genericArguments>>2] = $43;
      HEAP32[$4>>2] = $47;
      HEAP32[$5>>2] = $44;
      $48 = ($24|0)==(0|0);
      if (!($48)) {
       __ZdlPv($24);
      }
     } else {
      $20 = ($17|0)==(0|0);
      if ($20) {
       $23 = 0;
      } else {
       $21 = HEAP32[$16>>2]|0;
       HEAP32[$17>>2] = $21;
       $$pre$i = HEAP32[$4>>2]|0;
       $23 = $$pre$i;
      }
      $22 = (($23) + 4|0);
      HEAP32[$4>>2] = $22;
     }
     $49 = (($i$012) + 1)|0;
     $50 = ($49>>>0)<($3>>>0);
     if ($50) {
      $i$012 = $49;
     } else {
      label = 27;
      break L1;
     }
    }
    if ((label|0) == 21) {
     $51 = ___cxa_find_matching_catch()|0;
     $52 = tempRet0;
     $lpad$phi$index = $51;$lpad$phi$index2 = $52;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3308,0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     label = 22;
    } else {
     // unreachable;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 27) {
   __THREW__ = 0;
   $62 = (invoke_iii(2241,($2|0),($genericArguments|0))|0);
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    label = 22;
   } else {
    $65 = ($62|0)==(0|0);
    if ($65) {
     $$0 = 0;
    } else {
     $66 = (($62) + 48|0);
     $67 = HEAP32[$66>>2]|0;
     __THREW__ = 0;
     $68 = (invoke_ii(2992,($67|0))|0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      label = 22;
      break;
     } else {
      $$0 = $68;
     }
    }
    $71 = HEAP32[$genericArguments>>2]|0;
    $72 = ($71|0)==(0|0);
    if ($72) {
     STACKTOP = sp;return ($$0|0);
    }
    $73 = HEAP32[$4>>2]|0;
    $74 = ($73|0)==($71|0);
    if (!($74)) {
     $__new_last2$i$i$i$i$i = $71;
     $scevgep$i$i$i$i$i = (($73) + -4|0);
     $75 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($75)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $76 = $uglygep3$i$i$i$i$i >>> 2;
     $77 = $76 ^ -1;
     $scevgep4$i$i$i$i$i = (($73) + ($77<<2)|0);
     HEAP32[$4>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($71);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  $lpad$phi$index = $53;$lpad$phi$index2 = $54;
 }
 $55 = HEAP32[$genericArguments>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $57 = HEAP32[$4>>2]|0;
 $58 = ($57|0)==($55|0);
 if (!($58)) {
  $__new_last2$i$i$i$i$i3 = $55;
  $scevgep$i$i$i$i$i4 = (($57) + -4|0);
  $59 = (0 - ($__new_last2$i$i$i$i$i3))|0;
  $uglygep$i$i$i$i$i6 = (($scevgep$i$i$i$i$i4) + ($59)|0);
  $uglygep3$i$i$i$i$i7 = $uglygep$i$i$i$i$i6;
  $60 = $uglygep3$i$i$i$i$i7 >>> 2;
  $61 = $60 ^ -1;
  $scevgep4$i$i$i$i$i8 = (($57) + ($61<<2)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i$i$i8;
 }
 __ZdlPv($55);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System4Type23type_is_assignable_fromEP20Il2CppReflectionTypeS5_($type,$c) {
 $type = $type|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (($c) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($4)|0);
 $6 = HEAP32[$0>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1073741824;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = HEAP32[$3>>2]|0;
  $12 = (($11) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 & 1073741824;
  $15 = ($14|0)==(0);
  if ($15) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $16 = (__ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_($2,$5)|0);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type18type_is_subtype_ofEP20Il2CppReflectionTypeS5_b($type,$c,$check_interfaces) {
 $type = $type|0;
 $c = $c|0;
 $check_interfaces = $check_interfaces|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($c|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN6il2cpp2vm5Class14FromSystemTypeEP20Il2CppReflectionType($type)|0);
 $2 = (__ZN6il2cpp2vm5Class14FromSystemTypeEP20Il2CppReflectionType($c)|0);
 $3 = (__ZN6il2cpp2vm5Class12IsSubclassOfEPK8TypeInfoS4_b($1,$2,$check_interfaces)|0);
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type15make_byref_typeEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (($2) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type15MakePointerTypeEP20Il2CppReflectionType($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(225368)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type19GetInterfaceMapDataEP20Il2CppReflectionTypeS5_PP11Il2CppArrayS8_($type,$iface,$targets,$methods) {
 $type = $type|0;
 $iface = $iface|0;
 $targets = $targets|0;
 $methods = $methods|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $unused = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $unused = sp;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_il2cpp_class_from_il2cpp_type($1)|0);
 $3 = (($iface) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (_il2cpp_class_from_il2cpp_type($4)|0);
 $6 = (__ZN6il2cpp2vm5Class13GetNumMethodsEPK8TypeInfo($5)|0);
 $7 = HEAP32[((388944 + 140|0))>>2]|0;
 $8 = (_il2cpp_array_new($7,$6)|0);
 HEAP32[$targets>>2] = $8;
 $9 = HEAP32[((388944 + 140|0))>>2]|0;
 $10 = (_il2cpp_array_new($9,$6)|0);
 HEAP32[$methods>>2] = $10;
 HEAP32[$unused>>2] = 0;
 $11 = (__ZN6il2cpp2vm5Class18GetInterfaceOffsetEPK8TypeInfoPS2_($2,$5)|0);
 $12 = ($6|0)>(0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($2) + 36|0);
 $i$01 = 0;
 while(1) {
  $14 = (_il2cpp_class_get_methods($5,$unused)|0);
  $15 = (_il2cpp_method_get_object($14,$5)|0);
  $16 = HEAP32[$methods>>2]|0;
  $17 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($16,4,$i$01)|0);
  HEAP32[$17>>2] = $15;
  $18 = (($i$01) + ($11))|0;
  $19 = HEAP32[$13>>2]|0;
  $20 = (($19) + ($18<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (_il2cpp_method_get_object($21,$2)|0);
  $23 = HEAP32[$targets>>2]|0;
  $24 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($23,4,$i$01)|0);
  HEAP32[$24>>2] = $22;
  $25 = (($i$01) + 1)|0;
  $exitcond = ($25|0)==($6|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System4Type29GetGenericParameterAttributesEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($2) + 16|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6&65535;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type35GetGenericParameterConstraints_implEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $currentConstraint$02 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($2) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = HEAP32[((388944 + 112|0))>>2]|0;
  $9 = (_il2cpp_array_new($8,0)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 } else {
  $count$03 = 0;$currentConstraint$02 = $6;
 }
 while(1) {
  $10 = HEAP32[$currentConstraint$02>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   break;
  }
  $12 = (($currentConstraint$02) + 4|0);
  $13 = (($count$03) + 1)|0;
  $count$03 = $13;$currentConstraint$02 = $12;
 }
 $14 = HEAP32[((388944 + 112|0))>>2]|0;
 $15 = (_il2cpp_array_new($14,$count$03)|0);
 $16 = ($count$03|0)>(0);
 if ($16) {
  $i$01 = 0;
 } else {
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $17 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($15,4,$i$01)|0);
  $18 = HEAP32[$5>>2]|0;
  $19 = (($18) + ($i$01<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (_il2cpp_type_get_object($22)|0);
  HEAP32[$17>>2] = $23;
  $24 = (($i$01) + 1)|0;
  $exitcond = ($24|0)==($count$03|0);
  if ($exitcond) {
   $$0 = $15;
   break;
  } else {
   $i$01 = $24;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System4Type10GetPackingEP20Il2CppReflectionTypePiS6_($type,$packing,$size) {
 $type = $type|0;
 $packing = $packing|0;
 $size = $size|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(225552)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZNKSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$02$i$i$i = 0, $$02$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p$0$lcssa$i$i$i = 0, $__p$0$lcssa$i$i$i11 = 0, $__p$0$ph$i$i$i = 0, $__p$0$ph$i$i$i2 = 0, $__p$01$i$i$i = 0, $__p$01$i$i$i6 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i7 = 0, $scevgep3$i$i$i = 0, $scevgep3$i$i$i8 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($this) + 44|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5>>>0)<($7>>>0);
  if ($8) {
   HEAP32[$4>>2] = $7;
   $13 = $7;
  } else {
   $13 = $5;
  }
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10;
  $12 = $13;
  $14 = (($12) - ($11))|0;
  $15 = ($14>>>0)>(4294967279);
  if ($15) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $16 = ($14>>>0)<(11);
  if ($16) {
   $17 = $14 << 1;
   $18 = $17&255;
   HEAP8[$agg$result>>0] = $18;
   $19 = (($agg$result) + 1|0);
   $__p$0$ph$i$i$i2 = $19;
  } else {
   $20 = (($14) + 16)|0;
   $21 = $20 & -16;
   $22 = (__Znwj($21)|0);
   $23 = (($agg$result) + 8|0);
   HEAP32[$23>>2] = $22;
   $24 = $21 | 1;
   HEAP32[$agg$result>>2] = $24;
   $25 = (($agg$result) + 4|0);
   HEAP32[$25>>2] = $14;
   $__p$0$ph$i$i$i2 = $22;
  }
  $26 = ($10|0)==($13|0);
  if ($26) {
   $__p$0$lcssa$i$i$i11 = $__p$0$ph$i$i$i2;
  } else {
   $$02$i$i$i5 = $10;$__p$01$i$i$i6 = $__p$0$ph$i$i$i2;
   while(1) {
    $27 = HEAP8[$$02$i$i$i5>>0]|0;
    HEAP8[$__p$01$i$i$i6>>0] = $27;
    $28 = (($$02$i$i$i5) + 1|0);
    $29 = (($__p$01$i$i$i6) + 1|0);
    $30 = ($28|0)==($13|0);
    if ($30) {
     break;
    } else {
     $$02$i$i$i5 = $28;$__p$01$i$i$i6 = $29;
    }
   }
   $31 = (0 - ($11))|0;
   $scevgep$i$i$i7 = (($13) + ($31)|0);
   $scevgep3$i$i$i8 = $scevgep$i$i$i7;
   $scevgep4$i$i$i9 = (($__p$0$ph$i$i$i2) + ($scevgep3$i$i$i8)|0);
   $__p$0$lcssa$i$i$i11 = $scevgep4$i$i$i9;
  }
  HEAP8[$__p$0$lcssa$i$i$i11>>0] = 0;
  STACKTOP = sp;return;
 }
 $32 = $1 & 8;
 $33 = ($32|0)==(0);
 if ($33) {
  ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
  STACKTOP = sp;return;
 }
 $34 = (($this) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $35;
 $39 = $37;
 $40 = (($39) - ($38))|0;
 $41 = ($40>>>0)>(4294967279);
 if ($41) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $42 = ($40>>>0)<(11);
 if ($42) {
  $43 = $40 << 1;
  $44 = $43&255;
  HEAP8[$agg$result>>0] = $44;
  $45 = (($agg$result) + 1|0);
  $__p$0$ph$i$i$i = $45;
 } else {
  $46 = (($40) + 16)|0;
  $47 = $46 & -16;
  $48 = (__Znwj($47)|0);
  $49 = (($agg$result) + 8|0);
  HEAP32[$49>>2] = $48;
  $50 = $47 | 1;
  HEAP32[$agg$result>>2] = $50;
  $51 = (($agg$result) + 4|0);
  HEAP32[$51>>2] = $40;
  $__p$0$ph$i$i$i = $48;
 }
 $52 = ($35|0)==($37|0);
 if ($52) {
  $__p$0$lcssa$i$i$i = $__p$0$ph$i$i$i;
 } else {
  $$02$i$i$i = $35;$__p$01$i$i$i = $__p$0$ph$i$i$i;
  while(1) {
   $53 = HEAP8[$$02$i$i$i>>0]|0;
   HEAP8[$__p$01$i$i$i>>0] = $53;
   $54 = (($$02$i$i$i) + 1|0);
   $55 = (($__p$01$i$i$i) + 1|0);
   $56 = ($54|0)==($37|0);
   if ($56) {
    break;
   } else {
    $$02$i$i$i = $54;$__p$01$i$i$i = $55;
   }
  }
  $57 = (0 - ($38))|0;
  $scevgep$i$i$i = (($37) + ($57)|0);
  $scevgep3$i$i$i = $scevgep$i$i$i;
  $scevgep4$i$i$i = (($__p$0$ph$i$i$i) + ($scevgep3$i$i$i)|0);
  $__p$0$lcssa$i$i$i = $scevgep4$i$i$i;
 }
 HEAP8[$__p$0$lcssa$i$i$i>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((225744 + 12|0));
 $0 = (($this) + 64|0);
 HEAP32[$0>>2] = ((225744 + 52|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((225744 + 32|0));
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = ((225848 + 8|0));
 $3 = (($this) + 44|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = (($this) + 52|0);
  $8 = HEAP32[$7>>2]|0;
  __ZdlPv($8);
 }
 HEAP32[$2>>2] = ((3090568 + 8|0));
 $9 = (($this) + 16|0);
 __THREW__ = 0;
 invoke_vi(3299,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = (($this) + 64|0);
  __THREW__ = 0;
  invoke_vi(3217,($17|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $16;$eh$lpad$body$indexZ2D = $15;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $12 = (($this) + 64|0);
 __THREW__ = 0;
 invoke_vi(3217,($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $eh$lpad$body$index2Z2D = $23;$eh$lpad$body$indexZ2D = $22;
 __ZdlPv($this);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZThn8_NSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 HEAP32[$0>>2] = ((225744 + 12|0));
 $1 = (($0) + 64|0);
 HEAP32[$1>>2] = ((225744 + 52|0));
 $2 = (($0) + 8|0);
 HEAP32[$2>>2] = ((225744 + 32|0));
 $3 = (($0) + 12|0);
 HEAP32[$3>>2] = ((225848 + 8|0));
 $4 = (($0) + 44|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($0) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 HEAP32[$3>>2] = ((3090568 + 8|0));
 $10 = (($0) + 16|0);
 __THREW__ = 0;
 invoke_vi(3299,($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if (!($12)) {
  __ZNSt3__18ios_baseD2Ev($1);
  STACKTOP = sp;return;
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3217,($1|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
}
function __ZThn8_NSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 HEAP32[$0>>2] = ((225744 + 12|0));
 $1 = (($0) + 64|0);
 HEAP32[$1>>2] = ((225744 + 52|0));
 $2 = (($0) + 8|0);
 HEAP32[$2>>2] = ((225744 + 32|0));
 $3 = (($0) + 12|0);
 HEAP32[$3>>2] = ((225848 + 8|0));
 $4 = (($0) + 44|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($0) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 HEAP32[$3>>2] = ((3090568 + 8|0));
 $10 = (($0) + 16|0);
 __THREW__ = 0;
 invoke_vi(3299,($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3217,($1|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $19 = ___cxa_find_matching_catch(0|0)|0;
   $20 = tempRet0;
   ___clang_call_terminate($19);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $16;$eh$lpad$body$i$indexZ2D = $15;
   __ZdlPv($0);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3217,($1|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $22;$eh$lpad$body$i$indexZ2D = $21;
 __ZdlPv($0);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n12_NSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($this) {
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2)|0);
 HEAP32[$3>>2] = ((225744 + 12|0));
 $$sum = (($2) + 64)|0;
 $4 = (($this) + ($$sum)|0);
 HEAP32[$4>>2] = ((225744 + 52|0));
 $$sum1 = (($2) + 8)|0;
 $5 = (($this) + ($$sum1)|0);
 HEAP32[$5>>2] = ((225744 + 32|0));
 $$sum2 = (($2) + 12)|0;
 $6 = (($this) + ($$sum2)|0);
 HEAP32[$6>>2] = ((225848 + 8|0));
 $$sum3 = (($2) + 44)|0;
 $7 = (($this) + ($$sum3)|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $$sum4 = (($2) + 52)|0;
  $11 = (($this) + ($$sum4)|0);
  $12 = HEAP32[$11>>2]|0;
  __ZdlPv($12);
 }
 HEAP32[$6>>2] = ((3090568 + 8|0));
 $$sum5 = (($2) + 16)|0;
 $13 = (($this) + ($$sum5)|0);
 __THREW__ = 0;
 invoke_vi(3299,($13|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  __ZNSt3__18ios_baseD2Ev($4);
  STACKTOP = sp;return;
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3217,($4|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch(0|0)|0;
  $21 = tempRet0;
  ___clang_call_terminate($20);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
}
function __ZTv0_n12_NSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($this) {
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2)|0);
 HEAP32[$3>>2] = ((225744 + 12|0));
 $$sum = (($2) + 64)|0;
 $4 = (($this) + ($$sum)|0);
 HEAP32[$4>>2] = ((225744 + 52|0));
 $$sum1 = (($2) + 8)|0;
 $5 = (($this) + ($$sum1)|0);
 HEAP32[$5>>2] = ((225744 + 32|0));
 $$sum2 = (($2) + 12)|0;
 $6 = (($this) + ($$sum2)|0);
 HEAP32[$6>>2] = ((225848 + 8|0));
 $$sum3 = (($2) + 44)|0;
 $7 = (($this) + ($$sum3)|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $$sum4 = (($2) + 52)|0;
  $11 = (($this) + ($$sum4)|0);
  $12 = HEAP32[$11>>2]|0;
  __ZdlPv($12);
 }
 HEAP32[$6>>2] = ((3090568 + 8|0));
 $$sum5 = (($2) + 16)|0;
 $13 = (($this) + ($$sum5)|0);
 __THREW__ = 0;
 invoke_vi(3299,($13|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3217,($4|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $22 = ___cxa_find_matching_catch(0|0)|0;
   $23 = tempRet0;
   ___clang_call_terminate($22);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $19;$eh$lpad$body$i$indexZ2D = $18;
   __ZdlPv($3);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3217,($4|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  __ZdlPv($3);
  STACKTOP = sp;return;
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $25;$eh$lpad$body$i$indexZ2D = $24;
 __ZdlPv($3);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((225848 + 8|0));
 $0 = (($this) + 32|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  __ZdlPv($5);
 }
 HEAP32[$this>>2] = ((3090568 + 8|0));
 $6 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($6);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((225848 + 8|0));
 $0 = (($this) + 32|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  __ZdlPv($5);
 }
 HEAP32[$this>>2] = ((3090568 + 8|0));
 $6 = (($this) + 4|0);
 __THREW__ = 0;
 invoke_vi(3299,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZdlPv($this);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekoffExNS_8ios_base7seekdirEj($agg$result,$this,$0,$1,$__way,$__wch) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $__way = $__way|0;
 $__wch = $__wch|0;
 var $$pre = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  HEAP32[$2>>2] = $5;
  $52 = $5;
 } else {
  $52 = $3;
 }
 $7 = $__wch & 24;
 do {
  if ((($7|0) == 0)) {
   $8 = $agg$result;
   $9 = $8;
   HEAP32[$9>>2] = 0;
   $10 = (($8) + 4)|0;
   $11 = $10;
   HEAP32[$11>>2] = 0;
   $12 = (($agg$result) + 8|0);
   $13 = $12;
   $14 = $13;
   HEAP32[$14>>2] = -1;
   $15 = (($13) + 4)|0;
   $16 = $15;
   HEAP32[$16>>2] = -1;
   STACKTOP = sp;return;
  } else if ((($7|0) == 24)) {
   if ((($__way|0) == 0)) {
    $67 = 0;$68 = 0;
    break;
   } else if ((($__way|0) == 2)) {
    label = 11;
    break;
   } else if (!((($__way|0) == 1))) {
    label = 15;
    break;
   }
   $17 = $agg$result;
   $18 = $17;
   HEAP32[$18>>2] = 0;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = 0;
   $21 = (($agg$result) + 8|0);
   $22 = $21;
   $23 = $22;
   HEAP32[$23>>2] = -1;
   $24 = (($22) + 4)|0;
   $25 = $24;
   HEAP32[$25>>2] = -1;
   STACKTOP = sp;return;
  } else {
   if ((($__way|0) == 0)) {
    $67 = 0;$68 = 0;
    break;
   } else if ((($__way|0) == 2)) {
    label = 11;
    break;
   } else if (!((($__way|0) == 1))) {
    label = 15;
    break;
   }
   $26 = $__wch & 8;
   $27 = ($26|0)==(0);
   if ($27) {
    $37 = (($this) + 20|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = $5;
    $40 = $38;
    $41 = (($39) - ($40))|0;
    $42 = ($41|0)<(0);
    $43 = $42 << 31 >> 31;
    $67 = $41;$68 = $43;
    break;
   } else {
    $28 = (($this) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($this) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = $29;
    $33 = $31;
    $34 = (($32) - ($33))|0;
    $35 = ($34|0)<(0);
    $36 = $35 << 31 >> 31;
    $67 = $34;$68 = $36;
    break;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $58 = $agg$result;
  $59 = $58;
  HEAP32[$59>>2] = 0;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = 0;
  $62 = (($agg$result) + 8|0);
  $63 = $62;
  $64 = $63;
  HEAP32[$64>>2] = -1;
  $65 = (($63) + 4)|0;
  $66 = $65;
  HEAP32[$66>>2] = -1;
  STACKTOP = sp;return;
 }
 if ((label|0) == 11) {
  $44 = (($this) + 32|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45 & 1;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   $50 = (($44) + 1|0);
   $54 = $50;
  } else {
   $48 = (($this) + 40|0);
   $49 = HEAP32[$48>>2]|0;
   $54 = $49;
  }
  $51 = $52;
  $53 = $54;
  $55 = (($51) - ($53))|0;
  $56 = ($55|0)<(0);
  $57 = $56 << 31 >> 31;
  $67 = $55;$68 = $57;
 }
 $69 = (_i64Add(($67|0),($68|0),($0|0),($1|0))|0);
 $70 = tempRet0;
 $71 = ($70|0)<(0);
 if (!($71)) {
  $72 = (($this) + 32|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = $73 & 1;
  $75 = ($74<<24>>24)==(0);
  if ($75) {
   $78 = (($72) + 1|0);
   $81 = $78;
  } else {
   $76 = (($this) + 40|0);
   $77 = HEAP32[$76>>2]|0;
   $81 = $77;
  }
  $79 = $52;
  $80 = $81;
  $82 = (($79) - ($80))|0;
  $83 = ($82|0)<(0);
  $84 = $83 << 31 >> 31;
  $85 = ($84|0)<($70|0);
  $86 = ($84|0)==($70|0);
  $87 = ($82>>>0)<($69>>>0);
  $88 = $86 & $87;
  $89 = $85 | $88;
  if (!($89)) {
   $99 = ($69|0)==(0);
   $100 = ($70|0)==(0);
   $101 = $99 & $100;
   $$pre = $__wch & 8;
   if (!($101)) {
    $102 = ($$pre|0)==(0);
    if (!($102)) {
     $103 = (($this) + 12|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = ($104|0)==(0|0);
     if ($105) {
      $106 = $agg$result;
      $107 = $106;
      HEAP32[$107>>2] = 0;
      $108 = (($106) + 4)|0;
      $109 = $108;
      HEAP32[$109>>2] = 0;
      $110 = (($agg$result) + 8|0);
      $111 = $110;
      $112 = $111;
      HEAP32[$112>>2] = -1;
      $113 = (($111) + 4)|0;
      $114 = $113;
      HEAP32[$114>>2] = -1;
      STACKTOP = sp;return;
     }
    }
    $115 = $__wch & 16;
    $116 = ($115|0)!=(0);
    $117 = ($5|0)==(0|0);
    $or$cond = $116 & $117;
    if ($or$cond) {
     $118 = $agg$result;
     $119 = $118;
     HEAP32[$119>>2] = 0;
     $120 = (($118) + 4)|0;
     $121 = $120;
     HEAP32[$121>>2] = 0;
     $122 = (($agg$result) + 8|0);
     $123 = $122;
     $124 = $123;
     HEAP32[$124>>2] = -1;
     $125 = (($123) + 4)|0;
     $126 = $125;
     HEAP32[$126>>2] = -1;
     STACKTOP = sp;return;
    }
   }
   $127 = ($$pre|0)==(0);
   if (!($127)) {
    $128 = (($this) + 8|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = (($129) + ($69)|0);
    $131 = (($this) + 12|0);
    HEAP32[$131>>2] = $130;
    $132 = (($this) + 16|0);
    HEAP32[$132>>2] = $52;
   }
   $133 = $__wch & 16;
   $134 = ($133|0)==(0);
   if (!($134)) {
    $135 = (($this) + 20|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($136) + ($69)|0);
    HEAP32[$4>>2] = $137;
   }
   $138 = $agg$result;
   $139 = $138;
   HEAP32[$139>>2] = 0;
   $140 = (($138) + 4)|0;
   $141 = $140;
   HEAP32[$141>>2] = 0;
   $142 = (($agg$result) + 8|0);
   $143 = $142;
   $144 = $143;
   HEAP32[$144>>2] = $69;
   $145 = (($143) + 4)|0;
   $146 = $145;
   HEAP32[$146>>2] = $70;
   STACKTOP = sp;return;
  }
 }
 $90 = $agg$result;
 $91 = $90;
 HEAP32[$91>>2] = 0;
 $92 = (($90) + 4)|0;
 $93 = $92;
 HEAP32[$93>>2] = 0;
 $94 = (($agg$result) + 8|0);
 $95 = $94;
 $96 = $95;
 HEAP32[$96>>2] = -1;
 $97 = (($95) + 4)|0;
 $98 = $97;
 HEAP32[$98>>2] = -1;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekposENS_4fposI11__mbstate_tEEj($agg$result,$this,$__sp,$__wch) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__sp = $__sp|0;
 $__wch = $__wch|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__sp) + 8|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiiiii[$2 & 255]($agg$result,$this,$6,$9,0,$__wch);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9underflowEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  HEAP32[$0>>2] = $3;
  $12 = $3;
 } else {
  $12 = $1;
 }
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 8;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)<($12>>>0);
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 if ($11) {
  HEAP32[$9>>2] = $12;
  $16 = $12;
 } else {
  $16 = $10;
 }
 $15 = ($14>>>0)<($16>>>0);
 if (!($15)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = HEAP8[$14>>0]|0;
 $18 = $17&255;
 $$0 = $18;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9pbackfailEi($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $$0 = 0, $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  HEAP32[$0>>2] = $3;
  $13 = $3;
 } else {
  $13 = $1;
 }
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if (!($9)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ($__c|0)==(-1);
 if ($10) {
  $11 = (($8) + -1|0);
  HEAP32[$5>>2] = $6;
  HEAP32[$7>>2] = $11;
  $12 = (($this) + 16|0);
  HEAP32[$12>>2] = $13;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($this) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 16;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = $__c&255;
  $19 = (($8) + -1|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($18<<24>>24)==($20<<24>>24);
  if ($21) {
   $$pre$phi2Z2D = $18;$$pre$phiZ2D = $19;
  } else {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$pre = (($8) + -1|0);
  $$pre1 = $__c&255;
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;
 }
 HEAP32[$5>>2] = $6;
 HEAP32[$7>>2] = $$pre$phiZ2D;
 $22 = (($this) + 16|0);
 HEAP32[$22>>2] = $13;
 HEAP8[$$pre$phiZ2D>>0] = $$pre$phi2Z2D;
 $$0 = $__c;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE8overflowEi($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pn$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__cap$0$i = 0, $__p$0$i = 0, $__p$0$sum$pre$i = 0, $__p$0$sum$pre$phi$iZZZ2D = 0, $__sz$0$i = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__c|0)==(-1);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 L4: do {
  if ($12) {
   $13 = (($this) + 48|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $14 & 16;
   $16 = ($15|0)==(0);
   if ($16) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $17 = (($this) + 20|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = $9;
   $20 = $18;
   $21 = (($19) - ($20))|0;
   $22 = (($this) + 44|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23;
   $25 = (($24) - ($20))|0;
   $26 = (($this) + 32|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27 & 1;
   $29 = ($28<<24>>24)!=(0);
   if ($29) {
    $32 = HEAP32[$26>>2]|0;
    $33 = $32 & -2;
    $34 = (($33) + -1)|0;
    $35 = (($this) + 36|0);
    $36 = HEAP32[$35>>2]|0;
    $__cap$0$i = $34;$__sz$0$i = $36;
   } else {
    $30 = $27&255;
    $31 = $30 >>> 1;
    $__cap$0$i = 10;$__sz$0$i = $31;
   }
   $37 = ($__sz$0$i|0)==($__cap$0$i|0);
   if ($37) {
    __THREW__ = 0;
    invoke_viiiiiii(61,($26|0),($__cap$0$i|0),1,($__cap$0$i|0),($__cap$0$i|0),0,0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     $40 = HEAP8[$26>>0]|0;
     $41 = $40 & 1;
     $42 = ($41<<24>>24)==(0);
     if ($42) {
      label = 12;
     } else {
      label = 13;
     }
    }
   } else {
    if ($29) {
     label = 13;
    } else {
     label = 12;
    }
   }
   if ((label|0) == 12) {
    $43 = (($26) + 1|0);
    $44 = $__sz$0$i << 1;
    $45 = (($44) + 2)|0;
    $46 = $45&255;
    HEAP8[$26>>0] = $46;
    $__p$0$sum$pre$i = (($__sz$0$i) + 1)|0;
    $$pn$i = $43;$__p$0$sum$pre$phi$iZZZ2D = $__p$0$sum$pre$i;
    label = 14;
   }
   else if ((label|0) == 13) {
    $47 = (($this) + 40|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($__sz$0$i) + 1)|0;
    $50 = (($this) + 36|0);
    HEAP32[$50>>2] = $49;
    $$pn$i = $48;$__p$0$sum$pre$phi$iZZZ2D = $49;
    label = 14;
   }
   L20: do {
    if ((label|0) == 14) {
     $__p$0$i = (($$pn$i) + ($__sz$0$i)|0);
     HEAP8[$__p$0$i>>0] = 0;
     $51 = (($$pn$i) + ($__p$0$sum$pre$phi$iZZZ2D)|0);
     HEAP8[$51>>0] = 0;
     $52 = HEAP8[$26>>0]|0;
     $53 = $52 & 1;
     $54 = ($53<<24>>24)==(0);
     if ($54) {
      $59 = $52;$67 = 10;
     } else {
      $55 = HEAP32[$26>>2]|0;
      $56 = $55 & -2;
      $phitmp$i = (($56) + -1)|0;
      $57 = $55&255;
      $59 = $57;$67 = $phitmp$i;
     }
     $58 = $59 & 1;
     $60 = ($58<<24>>24)==(0);
     if ($60) {
      $63 = $59&255;
      $64 = $63 >>> 1;
      $66 = $64;
     } else {
      $61 = (($this) + 36|0);
      $62 = HEAP32[$61>>2]|0;
      $66 = $62;
     }
     $65 = ($66>>>0)<($67>>>0);
     do {
      if ($65) {
       $68 = (($67) - ($66))|0;
       __THREW__ = 0;
       (invoke_iiii(1479,($26|0),($68|0),0)|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break L20;
       }
      } else {
       if ($60) {
        $75 = ((($26) + ($67)|0) + 1|0);
        HEAP8[$75>>0] = 0;
        $76 = $67 << 1;
        $77 = $76&255;
        HEAP8[$26>>0] = $77;
        break;
       } else {
        $71 = (($this) + 40|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = (($72) + ($67)|0);
        HEAP8[$73>>0] = 0;
        $74 = (($this) + 36|0);
        HEAP32[$74>>2] = $67;
        break;
       }
      }
     } while(0);
     $78 = HEAP8[$26>>0]|0;
     $79 = $78 & 1;
     $80 = ($79<<24>>24)==(0);
     if ($80) {
      $85 = (($26) + 1|0);
      $86 = $78&255;
      $87 = $86 >>> 1;
      $89 = $85;$90 = $87;
     } else {
      $81 = (($this) + 40|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($this) + 36|0);
      $84 = HEAP32[$83>>2]|0;
      $89 = $82;$90 = $84;
     }
     $88 = (($89) + ($90)|0);
     HEAP32[$17>>2] = $89;
     HEAP32[$10>>2] = $88;
     $91 = (($89) + ($21)|0);
     HEAP32[$8>>2] = $91;
     $92 = (($89) + ($25)|0);
     HEAP32[$22>>2] = $92;
     $$pre$phiZ2D = $13;$115 = $88;$96 = $91;$99 = $92;
     break L4;
    }
   } while(0);
   $93 = ___cxa_find_matching_catch(0|0)|0;
   $94 = tempRet0;
   (___cxa_begin_catch(($93|0))|0);
   ___cxa_end_catch();
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$phi$trans$insert = (($this) + 44|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $$pre3 = (($this) + 48|0);
   $$pre$phiZ2D = $$pre3;$115 = $11;$96 = $9;$99 = $$pre;
  }
 } while(0);
 $95 = (($96) + 1|0);
 $97 = (($this) + 44|0);
 $98 = ($95>>>0)<($99>>>0);
 $100 = $98 ? $99 : $95;
 HEAP32[$97>>2] = $100;
 $101 = HEAP32[$$pre$phiZ2D>>2]|0;
 $102 = $101 & 8;
 $103 = ($102|0)==(0);
 if (!($103)) {
  $104 = (($this) + 32|0);
  $105 = HEAP8[$104>>0]|0;
  $106 = $105 & 1;
  $107 = ($106<<24>>24)==(0);
  if ($107) {
   $110 = (($104) + 1|0);
   $112 = $110;
  } else {
   $108 = (($this) + 40|0);
   $109 = HEAP32[$108>>2]|0;
   $112 = $109;
  }
  $111 = (($112) + ($7)|0);
  HEAP32[$3>>2] = $112;
  HEAP32[$1>>2] = $111;
  $113 = (($this) + 16|0);
  HEAP32[$113>>2] = $100;
 }
 $114 = ($96|0)==($115|0);
 if ($114) {
  $116 = HEAP32[$this>>2]|0;
  $117 = (($116) + 52|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = $__c & 255;
  $120 = (FUNCTION_TABLE_iii[$118 & 4095]($this,$119)|0);
  $$0 = $120;
  STACKTOP = sp;return ($$0|0);
 } else {
  $121 = $__c&255;
  HEAP32[$8>>2] = $95;
  HEAP8[$96>>0] = $121;
  $122 = $__c & 255;
  $$0 = $122;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE($this,$__s) {
 $this = $this|0;
 $__s = $__s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($0,$__s)|0);
 $1 = (($this) + 44|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 8;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = HEAP8[$0>>0]|0;
  $7 = $6 & 1;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $16 = $6&255;
   $17 = $16 >>> 1;
   $18 = ((($0) + ($17)|0) + 1|0);
   HEAP32[$1>>2] = $18;
   $19 = (($0) + 1|0);
   $20 = (($0) + 1|0);
   $22 = $19;$24 = $20;$26 = $18;
  } else {
   $9 = (($this) + 40|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 36|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($10) + ($12)|0);
   HEAP32[$1>>2] = $13;
   $14 = (($this) + 40|0);
   $15 = HEAP32[$14>>2]|0;
   $22 = $15;$24 = $15;$26 = $13;
  }
  $21 = (($this) + 8|0);
  HEAP32[$21>>2] = $22;
  $23 = (($this) + 12|0);
  HEAP32[$23>>2] = $24;
  $25 = (($this) + 16|0);
  HEAP32[$25>>2] = $26;
 }
 $27 = $3 & 16;
 $28 = ($27|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = HEAP8[$0>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $32 = $29&255;
  $33 = $32 >>> 1;
  $34 = ((($0) + ($33)|0) + 1|0);
  HEAP32[$1>>2] = $34;
  $44 = $29;$52 = 10;$83 = $33;
 } else {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($this) + 40|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36)|0);
  HEAP32[$1>>2] = $39;
  $40 = HEAP32[$0>>2]|0;
  $41 = $40 & -2;
  $phitmp$i = (($41) + -1)|0;
  $42 = $40&255;
  $44 = $42;$52 = $phitmp$i;$83 = $36;
 }
 $43 = $44 & 1;
 $45 = ($43<<24>>24)==(0);
 if ($45) {
  $48 = $44&255;
  $49 = $48 >>> 1;
  $51 = $49;
 } else {
  $46 = (($this) + 36|0);
  $47 = HEAP32[$46>>2]|0;
  $51 = $47;
 }
 $50 = ($51>>>0)<($52>>>0);
 do {
  if ($50) {
   $53 = (($52) - ($51))|0;
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEjc($0,$53,0)|0);
  } else {
   if ($45) {
    $58 = ((($0) + ($52)|0) + 1|0);
    HEAP8[$58>>0] = 0;
    $59 = $52 << 1;
    $60 = $59&255;
    HEAP8[$0>>0] = $60;
    break;
   } else {
    $54 = (($this) + 40|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($55) + ($52)|0);
    HEAP8[$56>>0] = 0;
    $57 = (($this) + 36|0);
    HEAP32[$57>>2] = $52;
    break;
   }
  }
 } while(0);
 $61 = HEAP8[$0>>0]|0;
 $62 = $61 & 1;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  $68 = (($0) + 1|0);
  $69 = (($0) + 1|0);
  $70 = $61&255;
  $71 = $70 >>> 1;
  $73 = $69;$74 = $71;$76 = $68;
 } else {
  $64 = (($this) + 40|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($this) + 36|0);
  $67 = HEAP32[$66>>2]|0;
  $73 = $65;$74 = $67;$76 = $65;
 }
 $72 = (($73) + ($74)|0);
 $75 = (($this) + 24|0);
 HEAP32[$75>>2] = $76;
 $77 = (($this) + 20|0);
 HEAP32[$77>>2] = $76;
 $78 = (($this) + 28|0);
 HEAP32[$78>>2] = $72;
 $79 = HEAP32[$2>>2]|0;
 $80 = $79 & 3;
 $81 = ($80|0)==(0);
 if ($81) {
  STACKTOP = sp;return;
 }
 $82 = (($76) + ($83)|0);
 HEAP32[$75>>2] = $82;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System14TypedReference8ToObjectEPv($value) {
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(225912)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9ValueType14InternalEqualsEP12Il2CppObjectS5_PP11Il2CppArray($__this,$that,$fields) {
 $__this = $__this|0;
 $that = $that|0;
 $fields = $fields|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0;
 var $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$0$ph = 0, $count$1 = 0, $count$2 = 0, $exitcond = 0, $i$01 = 0, $iter = 0, $or$cond = 0, $values$0$ph = 0, $values$1 = 0;
 var $values$2 = 0, $values$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 $0 = ($that|0)==(0|0);
 if ($0) {
  $1 = (__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc(226096)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 }
 $2 = HEAP32[$__this>>2]|0;
 $3 = HEAP32[$that>>2]|0;
 $4 = ($2|0)==($3|0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($__this)|0);
 $6 = (($5) + 117|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($5)|0);
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($5)|0);
   $12 = (($11) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 & 16711680;
   $15 = ($14|0)==(524288);
   if ($15) {
    $16 = (($__this) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($that) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($17|0)==($19|0);
    $$0 = $20;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$fields>>2] = 0;
 HEAP32[$iter>>2] = 0;
 $count$0$ph = 0;$values$0$ph = 0;
 L13: while(1) {
  $21 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($5,$iter)|0);
  $22 = ($21|0)==(0|0);
  if ($22) {
   $count$2 = $count$0$ph;$values$3 = $values$0$ph;
   label = 28;
   break;
  } else {
   $24 = $21;
  }
  while(1) {
   $23 = (($24) + 4|0);
   $25 = HEAP32[$23>>2]|0;
   $26 = (($25) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $27 & 16;
   $29 = ($28|0)==(0);
   if ($29) {
    $30 = (__ZN6il2cpp2vm5Field9IsDeletedEP9FieldInfo($24)|0);
    if (!($30)) {
     break;
    }
   }
   $31 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($5,$iter)|0);
   $32 = ($31|0)==(0|0);
   if ($32) {
    $count$2 = $count$0$ph;$values$3 = $values$0$ph;
    label = 28;
    break L13;
   } else {
    $24 = $31;
   }
  }
  $33 = HEAP32[$23>>2]|0;
  $34 = (($33) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = $35 >>> 16;
  $37 = $36 & 255;
  switch ($37|0) {
  case 9: case 8:  {
   $52 = (($24) + 12|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($__this) + ($53)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($that) + ($53)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($55|0)==($57|0);
   if ($58) {
    $count$1 = $count$0$ph;$values$2 = $values$0$ph;
   } else {
    $$0 = 0;
    label = 31;
    break L13;
   }
   break;
  }
  case 11: case 10:  {
   $59 = (($24) + 12|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($__this) + ($60)|0);
   $62 = $61;
   $63 = $62;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($62) + 4)|0;
   $66 = $65;
   $67 = HEAP32[$66>>2]|0;
   $68 = (($that) + ($60)|0);
   $69 = $68;
   $70 = $69;
   $71 = HEAP32[$70>>2]|0;
   $72 = (($69) + 4)|0;
   $73 = $72;
   $74 = HEAP32[$73>>2]|0;
   $75 = ($64|0)==($71|0);
   $76 = ($67|0)==($74|0);
   $77 = $75 & $76;
   if ($77) {
    $count$1 = $count$0$ph;$values$2 = $values$0$ph;
   } else {
    $$0 = 0;
    label = 31;
    break L13;
   }
   break;
  }
  case 2: case 5: case 4:  {
   $38 = (($24) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($__this) + ($39)|0);
   $41 = HEAP8[$40>>0]|0;
   $42 = (($that) + ($39)|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = ($41<<24>>24)==($43<<24>>24);
   if ($44) {
    $count$1 = $count$0$ph;$values$2 = $values$0$ph;
   } else {
    $$0 = 0;
    label = 31;
    break L13;
   }
   break;
  }
  case 12:  {
   $78 = (($24) + 12|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($__this) + ($79)|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   $82 = (($that) + ($79)|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = $81 != $83;
   if ($84) {
    $$0 = 0;
    label = 31;
    break L13;
   } else {
    $count$1 = $count$0$ph;$values$2 = $values$0$ph;
   }
   break;
  }
  case 3: case 7: case 6:  {
   $45 = (($24) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($__this) + ($46)|0);
   $48 = HEAP16[$47>>1]|0;
   $49 = (($that) + ($46)|0);
   $50 = HEAP16[$49>>1]|0;
   $51 = ($48<<16>>16)==($50<<16>>16);
   if ($51) {
    $count$1 = $count$0$ph;$values$2 = $values$0$ph;
   } else {
    $$0 = 0;
    label = 31;
    break L13;
   }
   break;
  }
  case 13:  {
   $85 = (($24) + 12|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($__this) + ($86)|0);
   $88 = +HEAPF64[$87>>3];
   $89 = (($that) + ($86)|0);
   $90 = +HEAPF64[$89>>3];
   $91 = $88 != $90;
   if ($91) {
    $$0 = 0;
    label = 31;
    break L13;
   } else {
    $count$1 = $count$0$ph;$values$2 = $values$0$ph;
   }
   break;
  }
  case 14:  {
   $92 = (($24) + 12|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($__this) + ($93)|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($that) + ($93)|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($95|0)==($97|0);
   if ($98) {
    $count$1 = $count$0$ph;$values$2 = $values$0$ph;
   } else {
    $99 = ($95|0)==(0|0);
    $100 = ($97|0)==(0|0);
    $or$cond = $99 | $100;
    if ($or$cond) {
     $$0 = 0;
     label = 31;
     break L13;
    }
    $101 = (__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($95)|0);
    $102 = (__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($97)|0);
    $103 = ($101|0)==($102|0);
    if (!($103)) {
     $$0 = 0;
     label = 31;
     break L13;
    }
    $104 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($95)|0);
    $105 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($97)|0);
    $106 = $101 << 1;
    $107 = (_memcmp($104,$105,$106)|0);
    $108 = ($107|0)==(0);
    if ($108) {
     $count$1 = $count$0$ph;$values$2 = $values$0$ph;
    } else {
     $$0 = 0;
     label = 31;
     break L13;
    }
   }
   break;
  }
  default: {
   $109 = ($values$0$ph|0)==(0|0);
   if ($109) {
    $110 = (__ZN6il2cpp2vm5Class12GetNumFieldsEPK8TypeInfo($5)|0);
    $111 = $110 << 3;
    $112 = STACKTOP; STACKTOP = STACKTOP + ((((1*$111)|0)+15)&-16)|0;;
    $values$1 = $112;
   } else {
    $values$1 = $values$0$ph;
   }
   $113 = (__ZN6il2cpp2vm5Field14GetValueObjectEP9FieldInfoP12Il2CppObject($24,$__this)|0);
   $114 = (($count$0$ph) + 1)|0;
   $115 = (($values$1) + ($count$0$ph<<2)|0);
   HEAP32[$115>>2] = $113;
   $116 = (__ZN6il2cpp2vm5Field14GetValueObjectEP9FieldInfoP12Il2CppObject($24,$that)|0);
   $117 = (($count$0$ph) + 2)|0;
   $118 = (($values$1) + ($114<<2)|0);
   HEAP32[$118>>2] = $116;
   $count$1 = $117;$values$2 = $values$1;
  }
  }
  $119 = HEAP8[$6>>0]|0;
  $120 = ($119<<24>>24)==(0);
  if ($120) {
   $count$0$ph = $count$1;$values$0$ph = $values$2;
  } else {
   $count$2 = $count$1;$values$3 = $values$2;
   label = 28;
   break;
  }
 }
 if ((label|0) == 28) {
  $121 = ($values$3|0)==(0|0);
  if ($121) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $122 = HEAP32[((388944 + 4|0))>>2]|0;
  $123 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($122,$count$2)|0);
  __ZN6il2cpp2gc12WriteBarrier12GenericStoreEPvP12Il2CppObject($fields,$123);
  $124 = ($count$2|0)>(0);
  if ($124) {
   $i$01 = 0;
  } else {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  while(1) {
   $125 = HEAP32[$fields>>2]|0;
   $126 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($125,4,$i$01)|0);
   $127 = (($values$3) + ($i$01<<2)|0);
   $128 = HEAP32[$127>>2]|0;
   HEAP32[$126>>2] = $128;
   $129 = (($i$01) + 1)|0;
   $exitcond = ($129|0)==($count$2|0);
   if ($exitcond) {
    $$0 = 0;
    break;
   } else {
    $i$01 = $129;
   }
  }
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 31) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System9ValueType19InternalGetHashCodeEP12Il2CppObjectPP11Il2CppArray($obj,$fields) {
 $obj = $obj|0;
 $fields = $fields|0;
 var $$0 = 0, $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0$ph30 = 0, $count$0$ph313 = 0, $count$0$ph318 = 0, $exitcond = 0, $i$01 = 0;
 var $iter = 0, $result$0$ph$be = 0, $result$0$ph23 = 0, $result$0$ph2350 = 0, $result$0$ph29 = 0, $values$0$ph31 = 0, $values$0$ph417 = 0, $values$0$ph419 = 0, $values$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 HEAP32[$iter>>2] = 0;
 $0 = (__ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($obj)|0);
 $1 = (__ZN6il2cpp2vm5Class12GetNumFieldsEPK8TypeInfo($0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (__ZN6il2cpp2vm6Object7GetHashEP12Il2CppObject($obj)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$iter>>2] = 0;
 $4 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($0,$iter)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $result$0$ph2350 = 0;
 } else {
  $51 = $4;$count$0$ph30 = 0;$result$0$ph29 = 0;$values$0$ph31 = 0;
  L7: while(1) {
   $52 = $51;$count$0$ph318 = $count$0$ph30;$values$0$ph419 = $values$0$ph31;
   L9: while(1) {
    $7 = $52;
    while(1) {
     $6 = (($7) + 4|0);
     $8 = HEAP32[$6>>2]|0;
     $9 = (($8) + 4|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = $10 & 16;
     $12 = ($11|0)==(0);
     if ($12) {
      $13 = (__ZN6il2cpp2vm5Field9IsDeletedEP9FieldInfo($7)|0);
      if (!($13)) {
       $16 = HEAP32[$6>>2]|0;
       $17 = (($16) + 4|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = $18 >>> 16;
       $20 = $19 & 255;
       if ((($20|0) == 8)) {
        label = 11;
        break L9;
       } else if (!((($20|0) == 14))) {
        break;
       }
       $25 = (($7) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = (($obj) + ($26)|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = ($28|0)==(0|0);
       if (!($29)) {
        label = 13;
        break L9;
       }
      }
     }
     $14 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($0,$iter)|0);
     $15 = ($14|0)==(0|0);
     if ($15) {
      $count$0$ph313 = $count$0$ph318;$result$0$ph23 = $result$0$ph29;$values$0$ph417 = $values$0$ph419;
      break L7;
     } else {
      $7 = $14;
     }
    }
    $33 = ($values$0$ph419|0)==(0|0);
    if ($33) {
     $34 = (__ZN6il2cpp2vm5Class12GetNumFieldsEPK8TypeInfo($0)|0);
     $35 = $34 << 2;
     $36 = STACKTOP; STACKTOP = STACKTOP + ((((1*$35)|0)+15)&-16)|0;;
     $values$1 = $36;
    } else {
     $values$1 = $values$0$ph419;
    }
    $37 = (__ZN6il2cpp2vm5Field14GetValueObjectEP9FieldInfoP12Il2CppObject($7,$obj)|0);
    $38 = (($count$0$ph318) + 1)|0;
    $39 = (($values$1) + ($count$0$ph318<<2)|0);
    HEAP32[$39>>2] = $37;
    $40 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($0,$iter)|0);
    $41 = ($40|0)==(0|0);
    if ($41) {
     $count$0$ph313 = $38;$result$0$ph23 = $result$0$ph29;$values$0$ph417 = $values$1;
     break L7;
    } else {
     $52 = $40;$count$0$ph318 = $38;$values$0$ph419 = $values$1;
    }
   }
   if ((label|0) == 11) {
    label = 0;
    $21 = (($7) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($obj) + ($22)|0);
    $24 = HEAP32[$23>>2]|0;
    $$pn = $24;
   }
   else if ((label|0) == 13) {
    label = 0;
    $30 = (__ZN6il2cpp2vm6String7GetHashEP12Il2CppString($28)|0);
    $$pn = $30;
   }
   $result$0$ph$be = $$pn ^ $result$0$ph29;
   $31 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($0,$iter)|0);
   $32 = ($31|0)==(0|0);
   if ($32) {
    $count$0$ph313 = $count$0$ph318;$result$0$ph23 = $result$0$ph$be;$values$0$ph417 = $values$0$ph419;
    break;
   } else {
    $51 = $31;$count$0$ph30 = $count$0$ph318;$result$0$ph29 = $result$0$ph$be;$values$0$ph31 = $values$0$ph419;
   }
  }
  $42 = ($values$0$ph417|0)==(0|0);
  if ($42) {
   $result$0$ph2350 = $result$0$ph23;
  } else {
   $43 = HEAP32[((388944 + 4|0))>>2]|0;
   $44 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($43,$count$0$ph313)|0);
   __ZN6il2cpp2gc12WriteBarrier12GenericStoreEPvP12Il2CppObject($fields,$44);
   $45 = ($count$0$ph313|0)>(0);
   if ($45) {
    $i$01 = 0;
   } else {
    $$0 = $result$0$ph23;
    STACKTOP = sp;return ($$0|0);
   }
   while(1) {
    $46 = HEAP32[$fields>>2]|0;
    $47 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($46,4,$i$01)|0);
    $48 = (($values$0$ph417) + ($i$01<<2)|0);
    $49 = HEAP32[$48>>2]|0;
    HEAP32[$47>>2] = $49;
    $50 = (($i$01) + 1)|0;
    $exitcond = ($50|0)==($count$0$ph313|0);
    if ($exitcond) {
     $$0 = $result$0$ph23;
     break;
    } else {
     $i$01 = $50;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$fields>>2] = 0;
 $$0 = $result$0$ph2350;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Diagnostics8Debugger19IsAttached_internalEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(226104)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System11Diagnostics10StackFrame14get_frame_infoEibPP22Il2CppReflectionMethodPiS8_PP12Il2CppStringS8_S8_($skip,$needFileInfo,$method,$iloffset,$native_offset,$file,$line,$column) {
 $skip = $skip|0;
 $needFileInfo = $needFileInfo|0;
 $method = $method|0;
 $iloffset = $iloffset|0;
 $native_offset = $native_offset|0;
 $file = $file|0;
 $line = $line|0;
 $column = $column|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Thread7CurrentEv()|0);
 $1 = (__ZN6il2cpp2vm6Thread14GetStackFramesEP12Il2CppThread($0)|0);
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = (($8) - ($skip))|0;
 $10 = (($9) + -1)|0;
 $11 = ($10>>>0)>=($8>>>0);
 $12 = ($10|0)<(0);
 $or$cond = $11 | $12;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($4) + ($10<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo($14,$16)|0);
 HEAP32[$method>>2] = $17;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System11Diagnostics10StackTrace9get_traceEP15Il2CppExceptionib($exc,$skip,$need_file_info) {
 $exc = $exc|0;
 $skip = $skip|0;
 $need_file_info = $need_file_info|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[((388944 + 152|0))>>2]|0;
  $4 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($3,0)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($1)|0);
 $6 = HEAP32[((388944 + 152|0))>>2]|0;
 $7 = ($5|0)>($skip|0);
 $8 = (($5) - ($skip))|0;
 $$ = $7 ? $8 : 0;
 $9 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($6,$$)|0);
 if ($7) {
  $i$01 = $skip;
 } else {
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $10 = HEAP32[((388944 + 152|0))>>2]|0;
  $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($10)|0);
  $12 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($1,4,$i$01)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo($13,0)|0);
  $15 = (($11) + 16|0);
  HEAP32[$15>>2] = $14;
  $16 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($9,4,$i$01)|0);
  HEAP32[$16>>2] = $11;
  $17 = (($i$01) + 1)|0;
  $exitcond = ($17|0)==($5|0);
  if ($exitcond) {
   $$0 = $9;
   break;
  } else {
   $i$01 = $17;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo22free_internal_collatorEP41mscorlib_System_Globalization_CompareInfo($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo14internal_indexEP41mscorlib_System_Globalization_CompareInfoP12Il2CppStringiiS8_ib($__this,$source,$sindex,$count,$value,$options,$first) {
 $__this = $__this|0;
 $source = $source|0;
 $sindex = $sindex|0;
 $count = $count|0;
 $value = $value|0;
 $options = $options|0;
 $first = $first|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$i = 0, $pos$03$i = 0, $pos1$05$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($value)|0);
 $1 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($source)|0);
 $2 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($value)|0);
 if (!($first)) {
  $16 = (($sindex) + 1)|0;
  $17 = (($16) - ($0))|0;
  $18 = (($sindex) - ($count))|0;
  $19 = ($17|0)>($18|0);
  if (!($19)) {
   $$0$i = -1;
   STACKTOP = sp;return ($$0$i|0);
  }
  $20 = $0 << 1;
  $pos1$05$i = $17;
  while(1) {
   $23 = (($1) + ($pos1$05$i<<1)|0);
   $24 = (_memcmp($23,$2,$20)|0);
   $25 = ($24|0)==(0);
   $22 = (($pos1$05$i) + -1)|0;
   if ($25) {
    $$0$i = $pos1$05$i;
    label = 11;
    break;
   }
   $21 = ($22|0)>($18|0);
   if ($21) {
    $pos1$05$i = $22;
   } else {
    $$0$i = -1;
    label = 11;
    break;
   }
  }
  if ((label|0) == 11) {
   STACKTOP = sp;return ($$0$i|0);
  }
 }
 $3 = (($count) + ($sindex))|0;
 $4 = (($3) - ($0))|0;
 $5 = ($4|0)<($sindex|0);
 if ($5) {
  $$0$i = -1;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $pos$03$i = $sindex;
 }
 L15: while(1) {
  $i$0$i = 0;
  while(1) {
   $6 = (($i$0$i) + ($pos$03$i))|0;
   $7 = (($1) + ($6<<1)|0);
   $8 = HEAP16[$7>>1]|0;
   $9 = (($2) + ($i$0$i<<1)|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = ($8<<16>>16)==($10<<16>>16);
   if (!($11)) {
    break;
   }
   $12 = (($i$0$i) + 1)|0;
   $13 = ($12|0)==($0|0);
   if ($13) {
    $$0$i = $pos$03$i;
    label = 11;
    break L15;
   } else {
    $i$0$i = $12;
   }
  }
  $14 = (($pos$03$i) + 1)|0;
  $15 = ($pos$03$i|0)<($4|0);
  if ($15) {
   $pos$03$i = $14;
  } else {
   $$0$i = -1;
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo16internal_compareEP41mscorlib_System_Globalization_CompareInfoP12Il2CppStringiiS8_iii($__this,$str1,$off1,$len1,$str2,$off2,$len2,$options) {
 $__this = $__this|0;
 $str1 = $str1|0;
 $off1 = $off1|0;
 $len1 = $len1|0;
 $str2 = $str2|0;
 $off2 = $off2|0;
 $len2 = $len2|0;
 $options = $options|0;
 var $$$i = 0, $$0$i = 0, $$lcssa$i = 0, $$sum$i = 0, $$sum1$i = 0, $$sum2$i = 0, $$sum3$i = 0, $$sum4$i = 0, $$sum4$us$i = 0, $$sum4$us20$i = 0, $$sum5$i = 0, $$sum5$us$i = 0, $$sum5$us21$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $len2$len1$i = 0, $not$$i = 0, $or$cond$i = 0, $or$cond$us$i = 0, $or$cond$us23$i = 0, $or$cond15$i = 0, $or$cond6$i = 0, $or$cond6$us$i = 0, $or$cond6$us24$i = 0, $or$cond616$i = 0;
 var $pos$0$lcssa$i = 0, $pos$017$i = 0, $pos$017$us$i = 0, $pos$017$us19$i = 0, $result$0$i$us$i = 0, $result$0$i10$i = 0, $result$0$i7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($len1|0)<($len2|0);
 $len2$len1$i = $0 ? $len2 : $len1;
 $1 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($str1)|0);
 $2 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($str2)|0);
 $3 = ($len2$len1$i|0)!=(0);
 $4 = ($len1|0)>(0);
 $or$cond15$i = $3 & $4;
 $5 = ($len2|0)>(0);
 $or$cond616$i = $or$cond15$i & $5;
 L1: do {
  if ($or$cond616$i) {
   $6 = $options & 1073741824;
   $7 = ($6|0)==(0);
   $8 = $options & 1;
   $9 = ($8|0)==(0);
   if ($7) {
    $pos$017$us$i = 0;
    while(1) {
     $$sum5$us$i = (($pos$017$us$i) + ($off2))|0;
     $14 = (($2) + ($$sum5$us$i<<1)|0);
     $15 = HEAP16[$14>>1]|0;
     $$sum4$us$i = (($pos$017$us$i) + ($off1))|0;
     $16 = (($1) + ($$sum4$us$i<<1)|0);
     $17 = HEAP16[$16>>1]|0;
     $18 = $17&65535;
     if ($9) {
      $23 = $15&65535;
      $24 = (($18) - ($23))|0;
      $result$0$i$us$i = $24;
     } else {
      $19 = (_towlower($18)|0);
      $20 = $15&65535;
      $21 = (_towlower($20)|0);
      $22 = (($19) - ($21))|0;
      $result$0$i$us$i = $22;
     }
     $25 = ($result$0$i$us$i|0)<(0);
     if ($25) {
      $$0$i = -1;
      label = 34;
      break;
     }
     $26 = ($result$0$i$us$i|0)>(0);
     $27 = $26&1;
     $11 = (($pos$017$us$i) + 1)|0;
     if ($26) {
      $$0$i = $27;
      label = 34;
      break;
     }
     $10 = ($11|0)!=($len2$len1$i|0);
     $12 = ($11|0)<($len1|0);
     $or$cond$us$i = $10 & $12;
     $13 = ($11|0)<($len2|0);
     $or$cond6$us$i = $or$cond$us$i & $13;
     if ($or$cond6$us$i) {
      $pos$017$us$i = $11;
     } else {
      $$lcssa$i = $12;$pos$0$lcssa$i = $11;
      break L1;
     }
    }
    if ((label|0) == 34) {
     STACKTOP = sp;return ($$0$i|0);
    }
   }
   if ($9) {
    $pos$017$us19$i = 0;
    while(1) {
     $$sum5$us21$i = (($pos$017$us19$i) + ($off2))|0;
     $$sum4$us20$i = (($pos$017$us19$i) + ($off1))|0;
     $32 = (($2) + ($$sum5$us21$i<<1)|0);
     $33 = (($1) + ($$sum4$us20$i<<1)|0);
     $34 = HEAP16[$32>>1]|0;
     $35 = HEAP16[$33>>1]|0;
     $36 = ($35<<16>>16)==($34<<16>>16);
     $29 = (($pos$017$us19$i) + 1)|0;
     if (!($36)) {
      break;
     }
     $28 = ($29|0)!=($len2$len1$i|0);
     $30 = ($29|0)<($len1|0);
     $or$cond$us23$i = $28 & $30;
     $31 = ($29|0)<($len2|0);
     $or$cond6$us24$i = $or$cond$us23$i & $31;
     if ($or$cond6$us24$i) {
      $pos$017$us19$i = $29;
     } else {
      $$lcssa$i = $30;$pos$0$lcssa$i = $29;
      break L1;
     }
    }
    $91 = $34&65535;
    $92 = $35&65535;
    $93 = (($92) - ($91))|0;
    $$0$i = $93;
    STACKTOP = sp;return ($$0$i|0);
   } else {
    $pos$017$i = 0;
    while(1) {
     $$sum5$i = (($pos$017$i) + ($off2))|0;
     $$sum4$i = (($pos$017$i) + ($off1))|0;
     $41 = (($2) + ($$sum5$i<<1)|0);
     $42 = (($1) + ($$sum4$i<<1)|0);
     $43 = HEAP16[$41>>1]|0;
     $44 = HEAP16[$42>>1]|0;
     $45 = ($44<<16>>16)==($43<<16>>16);
     $38 = (($pos$017$i) + 1)|0;
     if (!($45)) {
      break;
     }
     $37 = ($38|0)!=($len2$len1$i|0);
     $39 = ($38|0)<($len1|0);
     $or$cond$i = $37 & $39;
     $40 = ($38|0)<($len2|0);
     $or$cond6$i = $or$cond$i & $40;
     if ($or$cond6$i) {
      $pos$017$i = $38;
     } else {
      $$lcssa$i = $39;$pos$0$lcssa$i = $38;
      break L1;
     }
    }
    $94 = $43&65535;
    $95 = $44&65535;
    $96 = (($95) - ($94))|0;
    $$0$i = $96;
    STACKTOP = sp;return ($$0$i|0);
   }
  } else {
   $$lcssa$i = $4;$pos$0$lcssa$i = 0;
  }
 } while(0);
 $46 = ($pos$0$lcssa$i|0)==($len2$len1$i|0);
 if ($46) {
  $47 = (($len2$len1$i) + -1)|0;
  $$sum2$i = (($47) + ($off1))|0;
  $48 = (($1) + ($$sum2$i<<1)|0);
  $49 = HEAP16[$48>>1]|0;
  $$sum3$i = (($47) + ($off2))|0;
  $50 = (($2) + ($$sum3$i<<1)|0);
  $51 = HEAP16[$50>>1]|0;
  $52 = $options & 1073741824;
  $53 = ($52|0)==(0);
  if (!($53)) {
   $54 = $49&65535;
   $55 = $51&65535;
   $56 = (($54) - ($55))|0;
   $$0$i = $56;
   STACKTOP = sp;return ($$0$i|0);
  }
  $57 = $options & 1;
  $58 = ($57|0)==(0);
  $59 = $49&65535;
  if ($58) {
   $64 = $51&65535;
   $65 = (($59) - ($64))|0;
   $result$0$i7$i = $65;
  } else {
   $60 = (_towlower($59)|0);
   $61 = $51&65535;
   $62 = (_towlower($61)|0);
   $63 = (($60) - ($62))|0;
   $result$0$i7$i = $63;
  }
  $66 = ($result$0$i7$i|0)<(0);
  if ($66) {
   $$0$i = -1;
   STACKTOP = sp;return ($$0$i|0);
  }
  $67 = ($result$0$i7$i|0)>(0);
  $68 = $67&1;
  $$0$i = $68;
  STACKTOP = sp;return ($$0$i|0);
 }
 $69 = ($pos$0$lcssa$i|0)>=($len2|0);
 if (!($$lcssa$i)) {
  $not$$i = $69 ^ 1;
  $$$i = $not$$i << 31 >> 31;
  $$0$i = $$$i;
  STACKTOP = sp;return ($$0$i|0);
 }
 if ($69) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $$sum$i = (($pos$0$lcssa$i) + ($off1))|0;
 $70 = (($1) + ($$sum$i<<1)|0);
 $71 = HEAP16[$70>>1]|0;
 $$sum1$i = (($pos$0$lcssa$i) + ($off2))|0;
 $72 = (($2) + ($$sum1$i<<1)|0);
 $73 = HEAP16[$72>>1]|0;
 $74 = $options & 1073741824;
 $75 = ($74|0)==(0);
 if (!($75)) {
  $76 = $71&65535;
  $77 = $73&65535;
  $78 = (($76) - ($77))|0;
  $$0$i = $78;
  STACKTOP = sp;return ($$0$i|0);
 }
 $79 = $options & 1;
 $80 = ($79|0)==(0);
 $81 = $71&65535;
 if ($80) {
  $86 = $73&65535;
  $87 = (($81) - ($86))|0;
  $result$0$i10$i = $87;
 } else {
  $82 = (_towlower($81)|0);
  $83 = $73&65535;
  $84 = (_towlower($83)|0);
  $85 = (($82) - ($84))|0;
  $result$0$i10$i = $85;
 }
 $88 = ($result$0$i10$i|0)<(0);
 if ($88) {
  $$0$i = -1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $89 = ($result$0$i10$i|0)>(0);
 $90 = $89&1;
 $$0$i = $90;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo21construct_compareinfoEP41mscorlib_System_Globalization_CompareInfoP12Il2CppString($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo14assign_sortkeyEPvP12Il2CppObjectP12Il2CppStringNS3_14CompareOptionsE($self,$key,$source,$options) {
 $self = $self|0;
 $key = $key|0;
 $source = $source|0;
 $options = $options|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(226304)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo25construct_datetime_formatEP17Il2CppCultureInfo($cultureInfo) {
 $cultureInfo = $cultureInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i14 = 0, $exitcond$i22 = 0;
 var $exitcond$i30 = 0, $exitcond$i38 = 0, $exitcond$i46 = 0, $exitcond$i54 = 0, $exitcond$i6 = 0, $i1$01$i = 0, $i1$01$i13 = 0, $i1$01$i21 = 0, $i1$01$i29 = 0, $i1$01$i37 = 0, $i1$01$i45 = 0, $i1$01$i5 = 0, $i1$01$i53 = 0, $len$0$lcssa$i = 0, $len$0$lcssa$i11 = 0, $len$0$lcssa$i19 = 0, $len$0$lcssa$i27 = 0, $len$0$lcssa$i3 = 0, $len$0$lcssa$i35 = 0, $len$0$lcssa$i43 = 0;
 var $len$0$lcssa$i51 = 0, $len$03$i = 0, $len$03$i1 = 0, $len$03$i17 = 0, $len$03$i25 = 0, $len$03$i33 = 0, $len$03$i41 = 0, $len$03$i49 = 0, $len$03$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cultureInfo) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cultureInfo) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($cultureInfo) + 8|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = (($1) + 8|0);
 HEAP8[$6>>0] = $5;
 $len$03$i = 0;
 while(1) {
  $7 = (((226504 + (($3*190)|0)|0) + ($len$03$i<<1)|0) + 32|0);
  $8 = HEAP16[$7>>1]|0;
  $9 = ($8<<16>>16)==(0);
  if ($9) {
   $len$0$lcssa$i = $len$03$i;
   break;
  }
  $10 = (($len$03$i) + 1)|0;
  $11 = ($10|0)<(7);
  if ($11) {
   $len$03$i = $10;
  } else {
   $len$0$lcssa$i = $10;
   break;
  }
 }
 $12 = HEAP32[((388944 + 68|0))>>2]|0;
 $13 = (_il2cpp_array_class_get($12,1)|0);
 $14 = (_il2cpp_array_new_specific($13,$len$0$lcssa$i)|0);
 $15 = ($len$0$lcssa$i|0)>(0);
 if ($15) {
  $i1$01$i = 0;
  while(1) {
   $16 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($14,4,$i1$01$i)|0);
   $17 = (((226504 + (($3*190)|0)|0) + ($i1$01$i<<1)|0) + 32|0);
   $18 = HEAP16[$17>>1]|0;
   $19 = $18&65535;
   $20 = (258240 + ($19)|0);
   $21 = (_il2cpp_string_new($20)|0);
   HEAP32[$16>>2] = $21;
   $22 = (($i1$01$i) + 1)|0;
   $exitcond$i = ($22|0)==($len$0$lcssa$i|0);
   if ($exitcond$i) {
    break;
   } else {
    $i1$01$i = $22;
   }
  }
 }
 $23 = (($1) + 80|0);
 HEAP32[$23>>2] = $14;
 $len$03$i1 = 0;
 while(1) {
  $24 = (((226504 + (($3*190)|0)|0) + ($len$03$i1<<1)|0) + 72|0);
  $25 = HEAP16[$24>>1]|0;
  $26 = ($25<<16>>16)==(0);
  if ($26) {
   $len$0$lcssa$i3 = $len$03$i1;
   break;
  }
  $27 = (($len$03$i1) + 1)|0;
  $28 = ($27|0)<(13);
  if ($28) {
   $len$03$i1 = $27;
  } else {
   $len$0$lcssa$i3 = $27;
   break;
  }
 }
 $29 = HEAP32[((388944 + 68|0))>>2]|0;
 $30 = (_il2cpp_array_class_get($29,1)|0);
 $31 = (_il2cpp_array_new_specific($30,$len$0$lcssa$i3)|0);
 $32 = ($len$0$lcssa$i3|0)>(0);
 if ($32) {
  $i1$01$i5 = 0;
  while(1) {
   $33 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($31,4,$i1$01$i5)|0);
   $34 = (((226504 + (($3*190)|0)|0) + ($i1$01$i5<<1)|0) + 72|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = $35&65535;
   $37 = (258240 + ($36)|0);
   $38 = (_il2cpp_string_new($37)|0);
   HEAP32[$33>>2] = $38;
   $39 = (($i1$01$i5) + 1)|0;
   $exitcond$i6 = ($39|0)==($len$0$lcssa$i3|0);
   if ($exitcond$i6) {
    break;
   } else {
    $i1$01$i5 = $39;
   }
  }
 }
 $40 = (($1) + 92|0);
 HEAP32[$40>>2] = $31;
 $41 = ((226504 + (($3*190)|0)|0) + 14|0);
 $42 = HEAP16[$41>>1]|0;
 $43 = $42&65535;
 $44 = (258240 + ($43)|0);
 $45 = (_il2cpp_string_new($44)|0);
 $46 = (($1) + 12|0);
 HEAP32[$46>>2] = $45;
 $47 = ((226504 + (($3*190)|0)|0) + 98|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48 << 24 >> 24;
 $50 = (($1) + 76|0);
 HEAP32[$50>>2] = $49;
 $51 = ((226504 + (($3*190)|0)|0) + 100|0);
 $52 = HEAP16[$51>>1]|0;
 $53 = $52&65535;
 $54 = (258240 + ($53)|0);
 $55 = (_il2cpp_string_new($54)|0);
 $56 = (($1) + 20|0);
 HEAP32[$56>>2] = $55;
 $len$03$i9 = 0;
 while(1) {
  $57 = (((226504 + (($3*190)|0)|0) + ($len$03$i9<<1)|0) + 18|0);
  $58 = HEAP16[$57>>1]|0;
  $59 = ($58<<16>>16)==(0);
  if ($59) {
   $len$0$lcssa$i11 = $len$03$i9;
   break;
  }
  $60 = (($len$03$i9) + 1)|0;
  $61 = ($60|0)<(7);
  if ($61) {
   $len$03$i9 = $60;
  } else {
   $len$0$lcssa$i11 = $60;
   break;
  }
 }
 $62 = HEAP32[((388944 + 68|0))>>2]|0;
 $63 = (_il2cpp_array_class_get($62,1)|0);
 $64 = (_il2cpp_array_new_specific($63,$len$0$lcssa$i11)|0);
 $65 = ($len$0$lcssa$i11|0)>(0);
 if ($65) {
  $i1$01$i13 = 0;
  while(1) {
   $66 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($64,4,$i1$01$i13)|0);
   $67 = (((226504 + (($3*190)|0)|0) + ($i1$01$i13<<1)|0) + 18|0);
   $68 = HEAP16[$67>>1]|0;
   $69 = $68&65535;
   $70 = (258240 + ($69)|0);
   $71 = (_il2cpp_string_new($70)|0);
   HEAP32[$66>>2] = $71;
   $72 = (($i1$01$i13) + 1)|0;
   $exitcond$i14 = ($72|0)==($len$0$lcssa$i11|0);
   if ($exitcond$i14) {
    break;
   } else {
    $i1$01$i13 = $72;
   }
  }
 }
 $73 = (($1) + 84|0);
 HEAP32[$73>>2] = $64;
 $74 = ((226504 + (($3*190)|0)|0) + 99|0);
 $75 = HEAP8[$74>>0]|0;
 $76 = $75 << 24 >> 24;
 $77 = (($1) + 68|0);
 HEAP32[$77>>2] = $76;
 $78 = (226504 + (($3*190)|0)|0);
 $79 = HEAP16[$78>>1]|0;
 $80 = $79&65535;
 $81 = (258240 + ($80)|0);
 $82 = (_il2cpp_string_new($81)|0);
 $83 = (($1) + 52|0);
 HEAP32[$83>>2] = $82;
 $84 = ((226504 + (($3*190)|0)|0) + 2|0);
 $85 = HEAP16[$84>>1]|0;
 $86 = $85&65535;
 $87 = (258240 + ($86)|0);
 $88 = (_il2cpp_string_new($87)|0);
 $89 = (($1) + 32|0);
 HEAP32[$89>>2] = $88;
 $90 = ((226504 + (($3*190)|0)|0) + 6|0);
 $91 = HEAP16[$90>>1]|0;
 $92 = $91&65535;
 $93 = (258240 + ($92)|0);
 $94 = (_il2cpp_string_new($93)|0);
 $95 = (($1) + 40|0);
 HEAP32[$95>>2] = $94;
 $96 = ((226504 + (($3*190)|0)|0) + 12|0);
 $97 = HEAP16[$96>>1]|0;
 $98 = $97&65535;
 $99 = (258240 + ($98)|0);
 $100 = (_il2cpp_string_new($99)|0);
 $101 = (($1) + 44|0);
 HEAP32[$101>>2] = $100;
 $len$03$i17 = 0;
 while(1) {
  $102 = (((226504 + (($3*190)|0)|0) + ($len$03$i17<<1)|0) + 46|0);
  $103 = HEAP16[$102>>1]|0;
  $104 = ($103<<16>>16)==(0);
  if ($104) {
   $len$0$lcssa$i19 = $len$03$i17;
   break;
  }
  $105 = (($len$03$i17) + 1)|0;
  $106 = ($105|0)<(13);
  if ($106) {
   $len$03$i17 = $105;
  } else {
   $len$0$lcssa$i19 = $105;
   break;
  }
 }
 $107 = HEAP32[((388944 + 68|0))>>2]|0;
 $108 = (_il2cpp_array_class_get($107,1)|0);
 $109 = (_il2cpp_array_new_specific($108,$len$0$lcssa$i19)|0);
 $110 = ($len$0$lcssa$i19|0)>(0);
 if ($110) {
  $i1$01$i21 = 0;
  while(1) {
   $111 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($109,4,$i1$01$i21)|0);
   $112 = (((226504 + (($3*190)|0)|0) + ($i1$01$i21<<1)|0) + 46|0);
   $113 = HEAP16[$112>>1]|0;
   $114 = $113&65535;
   $115 = (258240 + ($114)|0);
   $116 = (_il2cpp_string_new($115)|0);
   HEAP32[$111>>2] = $116;
   $117 = (($i1$01$i21) + 1)|0;
   $exitcond$i22 = ($117|0)==($len$0$lcssa$i19|0);
   if ($exitcond$i22) {
    break;
   } else {
    $i1$01$i21 = $117;
   }
  }
 }
 $118 = (($1) + 88|0);
 HEAP32[$118>>2] = $109;
 $119 = ((226504 + (($3*190)|0)|0) + 16|0);
 $120 = HEAP16[$119>>1]|0;
 $121 = $120&65535;
 $122 = (258240 + ($121)|0);
 $123 = (_il2cpp_string_new($122)|0);
 $124 = (($1) + 16|0);
 HEAP32[$124>>2] = $123;
 $125 = ((226504 + (($3*190)|0)|0) + 4|0);
 $126 = HEAP16[$125>>1]|0;
 $127 = $126&65535;
 $128 = (258240 + ($127)|0);
 $129 = (_il2cpp_string_new($128)|0);
 $130 = (($1) + 28|0);
 HEAP32[$130>>2] = $129;
 $131 = ((226504 + (($3*190)|0)|0) + 8|0);
 $132 = HEAP16[$131>>1]|0;
 $133 = $132&65535;
 $134 = (258240 + ($133)|0);
 $135 = (_il2cpp_string_new($134)|0);
 $136 = (($1) + 36|0);
 HEAP32[$136>>2] = $135;
 $137 = ((226504 + (($3*190)|0)|0) + 102|0);
 $138 = HEAP16[$137>>1]|0;
 $139 = $138&65535;
 $140 = (258240 + ($139)|0);
 $141 = (_il2cpp_string_new($140)|0);
 $142 = (($1) + 24|0);
 HEAP32[$142>>2] = $141;
 $143 = ((226504 + (($3*190)|0)|0) + 10|0);
 $144 = HEAP16[$143>>1]|0;
 $145 = $144&65535;
 $146 = (258240 + ($145)|0);
 $147 = (_il2cpp_string_new($146)|0);
 $148 = (($1) + 48|0);
 HEAP32[$148>>2] = $147;
 $len$03$i25 = 0;
 while(1) {
  $149 = (((226504 + (($3*190)|0)|0) + ($len$03$i25<<1)|0) + 104|0);
  $150 = HEAP16[$149>>1]|0;
  $151 = ($150<<16>>16)==(0);
  if ($151) {
   $len$0$lcssa$i27 = $len$03$i25;
   break;
  }
  $152 = (($len$03$i25) + 1)|0;
  $153 = ($152|0)<(14);
  if ($153) {
   $len$03$i25 = $152;
  } else {
   $len$0$lcssa$i27 = $152;
   break;
  }
 }
 $154 = HEAP32[((388944 + 68|0))>>2]|0;
 $155 = (_il2cpp_array_class_get($154,1)|0);
 $156 = (_il2cpp_array_new_specific($155,$len$0$lcssa$i27)|0);
 $157 = ($len$0$lcssa$i27|0)>(0);
 if ($157) {
  $i1$01$i29 = 0;
  while(1) {
   $158 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($156,4,$i1$01$i29)|0);
   $159 = (((226504 + (($3*190)|0)|0) + ($i1$01$i29<<1)|0) + 104|0);
   $160 = HEAP16[$159>>1]|0;
   $161 = $160&65535;
   $162 = (258240 + ($161)|0);
   $163 = (_il2cpp_string_new($162)|0);
   HEAP32[$158>>2] = $163;
   $164 = (($i1$01$i29) + 1)|0;
   $exitcond$i30 = ($164|0)==($len$0$lcssa$i27|0);
   if ($exitcond$i30) {
    break;
   } else {
    $i1$01$i29 = $164;
   }
  }
 }
 $165 = (($1) + 96|0);
 HEAP32[$165>>2] = $156;
 $len$03$i33 = 0;
 while(1) {
  $166 = (((226504 + (($3*190)|0)|0) + ($len$03$i33<<1)|0) + 132|0);
  $167 = HEAP16[$166>>1]|0;
  $168 = ($167<<16>>16)==(0);
  if ($168) {
   $len$0$lcssa$i35 = $len$03$i33;
   break;
  }
  $169 = (($len$03$i33) + 1)|0;
  $170 = ($169|0)<(8);
  if ($170) {
   $len$03$i33 = $169;
  } else {
   $len$0$lcssa$i35 = $169;
   break;
  }
 }
 $171 = HEAP32[((388944 + 68|0))>>2]|0;
 $172 = (_il2cpp_array_class_get($171,1)|0);
 $173 = (_il2cpp_array_new_specific($172,$len$0$lcssa$i35)|0);
 $174 = ($len$0$lcssa$i35|0)>(0);
 if ($174) {
  $i1$01$i37 = 0;
  while(1) {
   $175 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($173,4,$i1$01$i37)|0);
   $176 = (((226504 + (($3*190)|0)|0) + ($i1$01$i37<<1)|0) + 132|0);
   $177 = HEAP16[$176>>1]|0;
   $178 = $177&65535;
   $179 = (258240 + ($178)|0);
   $180 = (_il2cpp_string_new($179)|0);
   HEAP32[$175>>2] = $180;
   $181 = (($i1$01$i37) + 1)|0;
   $exitcond$i38 = ($181|0)==($len$0$lcssa$i35|0);
   if ($exitcond$i38) {
    break;
   } else {
    $i1$01$i37 = $181;
   }
  }
 }
 $182 = (($1) + 100|0);
 HEAP32[$182>>2] = $173;
 $len$03$i41 = 0;
 while(1) {
  $183 = (((226504 + (($3*190)|0)|0) + ($len$03$i41<<1)|0) + 148|0);
  $184 = HEAP16[$183>>1]|0;
  $185 = ($184<<16>>16)==(0);
  if ($185) {
   $len$0$lcssa$i43 = $len$03$i41;
   break;
  }
  $186 = (($len$03$i41) + 1)|0;
  $187 = ($186|0)<(11);
  if ($187) {
   $len$03$i41 = $186;
  } else {
   $len$0$lcssa$i43 = $186;
   break;
  }
 }
 $188 = HEAP32[((388944 + 68|0))>>2]|0;
 $189 = (_il2cpp_array_class_get($188,1)|0);
 $190 = (_il2cpp_array_new_specific($189,$len$0$lcssa$i43)|0);
 $191 = ($len$0$lcssa$i43|0)>(0);
 if ($191) {
  $i1$01$i45 = 0;
  while(1) {
   $192 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($190,4,$i1$01$i45)|0);
   $193 = (((226504 + (($3*190)|0)|0) + ($i1$01$i45<<1)|0) + 148|0);
   $194 = HEAP16[$193>>1]|0;
   $195 = $194&65535;
   $196 = (258240 + ($195)|0);
   $197 = (_il2cpp_string_new($196)|0);
   HEAP32[$192>>2] = $197;
   $198 = (($i1$01$i45) + 1)|0;
   $exitcond$i46 = ($198|0)==($len$0$lcssa$i43|0);
   if ($exitcond$i46) {
    break;
   } else {
    $i1$01$i45 = $198;
   }
  }
 }
 $199 = (($1) + 104|0);
 HEAP32[$199>>2] = $190;
 $len$03$i49 = 0;
 while(1) {
  $200 = (((226504 + (($3*190)|0)|0) + ($len$03$i49<<1)|0) + 170|0);
  $201 = HEAP16[$200>>1]|0;
  $202 = ($201<<16>>16)==(0);
  if ($202) {
   $len$0$lcssa$i51 = $len$03$i49;
   break;
  }
  $203 = (($len$03$i49) + 1)|0;
  $204 = ($203|0)<(10);
  if ($204) {
   $len$03$i49 = $203;
  } else {
   $len$0$lcssa$i51 = $203;
   break;
  }
 }
 $205 = HEAP32[((388944 + 68|0))>>2]|0;
 $206 = (_il2cpp_array_class_get($205,1)|0);
 $207 = (_il2cpp_array_new_specific($206,$len$0$lcssa$i51)|0);
 $208 = ($len$0$lcssa$i51|0)>(0);
 if ($208) {
  $i1$01$i53 = 0;
 } else {
  $216 = (($1) + 108|0);
  HEAP32[$216>>2] = $207;
  STACKTOP = sp;return;
 }
 while(1) {
  $209 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($207,4,$i1$01$i53)|0);
  $210 = (((226504 + (($3*190)|0)|0) + ($i1$01$i53<<1)|0) + 170|0);
  $211 = HEAP16[$210>>1]|0;
  $212 = $211&65535;
  $213 = (258240 + ($212)|0);
  $214 = (_il2cpp_string_new($213)|0);
  HEAP32[$209>>2] = $214;
  $215 = (($i1$01$i53) + 1)|0;
  $exitcond$i54 = ($215|0)==($len$0$lcssa$i51|0);
  if ($exitcond$i54) {
   break;
  } else {
   $i1$01$i53 = $215;
  }
 }
 $216 = (($1) + 108|0);
 HEAP32[$216>>2] = $207;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo45construct_internal_locale_from_current_localeEP17Il2CppCultureInfo($cultureInfo) {
 $cultureInfo = $cultureInfo|0;
 var $$0 = 0, $$0$i = 0, $$0$i1 = 0, $$01$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i14$i = 0, $corrected$0$i = 0, $corrected$1$i = 0;
 var $corrected$2$i = 0, $entry$0$i = 0, $key$i$i = 0, $locale = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index2 = 0, $or$cond$i = 0, $result$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $key$i$i = sp + 24|0;
 $result$i = sp;
 $locale = sp + 12|0;
 __ZN6il2cpp2os6Locale9GetLocaleEv($key$i$i);
 $0 = HEAP8[$key$i$i>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($key$i$i) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8|0)==(0);
 L5: do {
  if ($7) {
   ;HEAP32[$locale+0>>2]=0|0;HEAP32[$locale+4>>2]=0|0;HEAP32[$locale+8>>2]=0|0;
  } else {
   if ($2) {
    $13 = (($key$i$i) + 1|0);
    $14 = $13;
   } else {
    $11 = (($key$i$i) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $14 = $12;
   }
   $15 = (___strdup($14)|0);
   $16 = (_strchr($15,46)|0);
   $17 = ($16|0)==(0|0);
   if ($17) {
    $corrected$0$i = 0;
   } else {
    $18 = (_strlen(($15|0))|0);
    $19 = (_malloc($18)|0);
    $20 = $16;
    $21 = $15;
    $22 = (($20) - ($21))|0;
    (_strncpy(($19|0),($15|0),($22|0))|0);
    $23 = (($19) + ($22)|0);
    HEAP8[$23>>0] = 0;
    $24 = (_strchr($19,64)|0);
    $25 = ($24|0)==(0|0);
    if ($25) {
     $corrected$0$i = $19;
    } else {
     $26 = $24;
     $27 = $19;
     $28 = (($26) - ($27))|0;
     $29 = (($19) + ($28)|0);
     HEAP8[$29>>0] = 0;
     $corrected$0$i = $19;
    }
   }
   $30 = (_strrchr($15,64)|0);
   $31 = ($30|0)!=(0|0);
   $32 = ($corrected$0$i|0)==(0|0);
   $or$cond$i = $31 & $32;
   if ($or$cond$i) {
    $33 = (_strlen(($15|0))|0);
    $34 = (_malloc($33)|0);
    $35 = $30;
    $36 = $15;
    $37 = (($35) - ($36))|0;
    (_strncpy(($34|0),($15|0),($37|0))|0);
    $38 = (($34) + ($37)|0);
    HEAP8[$38>>0] = 0;
    $corrected$1$i = $34;
   } else {
    $corrected$1$i = $corrected$0$i;
   }
   $39 = ($corrected$1$i|0)==(0|0);
   if ($39) {
    $corrected$2$i = $15;
   } else {
    _free($15);
    $corrected$2$i = $corrected$1$i;
   }
   $40 = (_strchr($corrected$2$i,95)|0);
   $41 = ($40|0)==(0|0);
   if (!($41)) {
    HEAP8[$40>>0] = 45;
   }
   $42 = (_strlen(($corrected$2$i|0))|0);
   $43 = ($42>>>0)>(4294967279);
   do {
    if ($43) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 6;
     } else {
      // unreachable;
     }
    } else {
     $46 = ($42>>>0)<(11);
     if ($46) {
      $47 = $42 << 1;
      $48 = $47&255;
      HEAP8[$result$i>>0] = $48;
      $49 = (($result$i) + 1|0);
      $__p$0$i$i$i$i = $49;
     } else {
      $50 = (($42) + 16)|0;
      $51 = $50 & -16;
      __THREW__ = 0;
      $52 = (invoke_ii(2988,($51|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 6;
       break;
      }
      $55 = (($result$i) + 8|0);
      HEAP32[$55>>2] = $52;
      $56 = $51 | 1;
      HEAP32[$result$i>>2] = $56;
      $57 = (($result$i) + 4|0);
      HEAP32[$57>>2] = $42;
      $__p$0$i$i$i$i = $52;
     }
     _memcpy(($__p$0$i$i$i$i|0),($corrected$2$i|0),($42|0))|0;
     $58 = (($__p$0$i$i$i$i) + ($42)|0);
     HEAP8[$58>>0] = 0;
     _free($corrected$2$i);
     $59 = HEAP8[$result$i>>0]|0;
     $60 = $59 & 1;
     $61 = ($60<<24>>24)==(0);
     if ($61) {
      $67 = (($result$i) + 1|0);
      $68 = $59&255;
      $69 = $68 >>> 1;
      $70 = ((($result$i) + ($69)|0) + 1|0);
      $72 = $67;$73 = $70;
     } else {
      $62 = (($result$i) + 8|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($result$i) + 4|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($63) + ($65)|0);
      $72 = $63;$73 = $66;
     }
     $71 = ($72|0)==($73|0);
     do {
      if ($71) {
       $84 = $59;
       label = 33;
      } else {
       $75 = $72;
       while(1) {
        $74 = HEAP8[$75>>0]|0;
        $76 = $74 << 24 >> 24;
        __THREW__ = 0;
        $77 = (invoke_ii(3003,($76|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 43;
         break;
        }
        $80 = $77&255;
        HEAP8[$75>>0] = $80;
        $81 = (($75) + 1|0);
        $82 = ($81|0)==($73|0);
        if ($82) {
         label = 32;
         break;
        } else {
         $75 = $81;
        }
       }
       if ((label|0) == 32) {
        $$pre$i = HEAP8[$result$i>>0]|0;
        $84 = $$pre$i;
        label = 33;
        break;
       }
       else if ((label|0) == 43) {
        $106 = ___cxa_find_matching_catch()|0;
        $107 = tempRet0;
        $lpad$phi$i$index = $106;$lpad$phi$i$index2 = $107;
        break;
       }
      }
     } while(0);
     if ((label|0) == 33) {
      $83 = $84 & 1;
      $85 = ($83<<24>>24)==(0);
      if ($85) {
       ;HEAP32[$locale+0>>2]=HEAP32[$result$i+0>>2]|0;HEAP32[$locale+4>>2]=HEAP32[$result$i+4>>2]|0;HEAP32[$locale+8>>2]=HEAP32[$result$i+8>>2]|0;
       break L5;
      }
      $86 = (($result$i) + 8|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = (($result$i) + 4|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($89>>>0)>(4294967279);
      do {
       if ($90) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if (!($92)) {
         // unreachable;
        }
       } else {
        $93 = ($89>>>0)<(11);
        if ($93) {
         $94 = $89 << 1;
         $95 = $94&255;
         HEAP8[$locale>>0] = $95;
         $96 = (($locale) + 1|0);
         $__p$0$i$i$i14$i = $96;
        } else {
         $97 = (($89) + 16)|0;
         $98 = $97 & -16;
         __THREW__ = 0;
         $99 = (invoke_ii(2988,($98|0))|0);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          break;
         }
         $102 = (($locale) + 8|0);
         HEAP32[$102>>2] = $99;
         $103 = $98 | 1;
         HEAP32[$locale>>2] = $103;
         $104 = (($locale) + 4|0);
         HEAP32[$104>>2] = $89;
         $__p$0$i$i$i14$i = $99;
        }
        _memcpy(($__p$0$i$i$i14$i|0),($87|0),($89|0))|0;
        $105 = (($__p$0$i$i$i14$i) + ($89)|0);
        HEAP8[$105>>0] = 0;
        __ZdlPv($87);
        break L5;
       }
      } while(0);
      $108 = ___cxa_find_matching_catch()|0;
      $109 = tempRet0;
      $lpad$phi$i$index = $108;$lpad$phi$i$index2 = $109;
     }
     $110 = HEAP8[$result$i>>0]|0;
     $111 = $110 & 1;
     $112 = ($111<<24>>24)==(0);
     if ($112) {
      $$0$i = $lpad$phi$i$index2;$$01$i = $lpad$phi$i$index;
     } else {
      $113 = (($result$i) + 8|0);
      $114 = HEAP32[$113>>2]|0;
      __ZdlPv($114);
      $$0$i = $lpad$phi$i$index2;$$01$i = $lpad$phi$i$index;
     }
    }
   } while(0);
   if ((label|0) == 6) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    $$0$i = $10;$$01$i = $9;
   }
   $120 = HEAP8[$key$i$i>>0]|0;
   $121 = $120 & 1;
   $122 = ($121<<24>>24)==(0);
   if ($122) {
    ___resumeException($$01$i|0);
    // unreachable;
   }
   $123 = (($key$i$i) + 8|0);
   $124 = HEAP32[$123>>2]|0;
   __ZdlPv($124);
   ___resumeException($$01$i|0);
   // unreachable;
  }
 } while(0);
 $115 = HEAP8[$key$i$i>>0]|0;
 $116 = $115 & 1;
 $117 = ($116<<24>>24)==(0);
 if (!($117)) {
  $118 = (($key$i$i) + 8|0);
  $119 = HEAP32[$118>>2]|0;
  __ZdlPv($119);
 }
 $125 = HEAP8[$locale>>0]|0;
 $126 = $125 & 1;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  $130 = $125&255;
  $131 = $130 >>> 1;
  $133 = $131;
 } else {
  $128 = (($locale) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $133 = $129;
 }
 $132 = ($133|0)==(0);
 L77: do {
  if ($132) {
   $$0 = 0;$166 = $125;
  } else {
   if ($127) {
    $136 = (($locale) + 1|0);
    $137 = $136;
   } else {
    $134 = (($locale) + 8|0);
    $135 = HEAP32[$134>>2]|0;
    $137 = $135;
   }
   __THREW__ = 0;
   $138 = (invoke_iiiiii(166,($137|0),(290848|0),167,4,(2242|0))|0);
   $139 = __THREW__; __THREW__ = 0;
   $140 = $139&1;
   do {
    if (!($140)) {
     $141 = ($138|0)==(0|0);
     if ($141) {
      $$0$i1 = 0;
     } else {
      $142 = (($138) + 2|0);
      $143 = HEAP16[$142>>1]|0;
      $144 = $143 << 16 >> 16;
      $145 = (308200 + (($144*72)|0)|0);
      $146 = HEAP16[$145>>1]|0;
      $147 = ((308200 + (($144*72)|0)|0) + 4|0);
      $148 = HEAP16[$147>>1]|0;
      $149 = ($146<<16>>16)==($148<<16>>16);
      if ($149) {
       $entry$0$i = $145;
      } else {
       HEAP16[$key$i$i>>1] = $148;
       __THREW__ = 0;
       $150 = (invoke_iiiiii(166,($key$i$i|0),(308200|0),167,72,(2243|0))|0);
       $151 = __THREW__; __THREW__ = 0;
       $152 = $151&1;
       if ($152) {
        break;
       }
       $entry$0$i = $150;
      }
      $153 = ($entry$0$i|0)==(0|0);
      if ($153) {
       $$0$i1 = 0;
      } else {
       __THREW__ = 0;
       invoke_vii(2483,($cultureInfo|0),($entry$0$i|0));
       $154 = __THREW__; __THREW__ = 0;
       $155 = $154&1;
       if ($155) {
        break;
       } else {
        $$0$i1 = 1;
       }
      }
     }
     $156 = (($cultureInfo) + 8|0);
     HEAP8[$156>>0] = 1;
     $157 = (($cultureInfo) + 32|0);
     HEAP8[$157>>0] = 1;
     $$pre = HEAP8[$locale>>0]|0;
     $$0 = $$0$i1;$166 = $$pre;
     break L77;
    }
   } while(0);
   $158 = ___cxa_find_matching_catch()|0;
   $159 = tempRet0;
   $160 = HEAP8[$locale>>0]|0;
   $161 = $160 & 1;
   $162 = ($161<<24>>24)==(0);
   if ($162) {
    ___resumeException($158|0);
    // unreachable;
   }
   $163 = (($locale) + 8|0);
   $164 = HEAP32[$163>>2]|0;
   __ZdlPv($164);
   ___resumeException($158|0);
   // unreachable;
  }
 } while(0);
 $165 = $166 & 1;
 $167 = ($165<<24>>24)==(0);
 if ($167) {
  STACKTOP = sp;return ($$0|0);
 }
 $168 = (($locale) + 8|0);
 $169 = HEAP32[$168>>2]|0;
 __ZdlPv($169);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo35construct_internal_locale_from_lcidEP17Il2CppCultureInfoi($cultureInfo,$lcid) {
 $cultureInfo = $cultureInfo|0;
 $lcid = $lcid|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $key$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $key$i = sp;
 $0 = $lcid&65535;
 HEAP16[$key$i>>1] = $0;
 $1 = (_bsearch($key$i,308200,167,72,2243)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN6il2cpp6icalls8mscorlib6System13GlobalizationL17construct_cultureEP17Il2CppCultureInfoPK16CultureInfoEntry($cultureInfo,$1);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System13GlobalizationL17construct_cultureEP17Il2CppCultureInfoPK16CultureInfoEntry($cultureInfo,$ci) {
 $cultureInfo = $cultureInfo|0;
 $ci = $ci|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$ci>>1]|0;
 $1 = $0 << 16 >> 16;
 $2 = (($cultureInfo) + 12|0);
 HEAP32[$2>>2] = $1;
 $3 = (($ci) + 8|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = (258240 + ($5)|0);
 $7 = (_il2cpp_string_new($6)|0);
 $8 = (($cultureInfo) + 48|0);
 HEAP32[$8>>2] = $7;
 $9 = (($ci) + 10|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 $12 = (258240 + ($11)|0);
 $13 = (_il2cpp_string_new($12)|0);
 $14 = (($cultureInfo) + 72|0);
 HEAP32[$14>>2] = $13;
 $15 = (($ci) + 14|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = (258240 + ($17)|0);
 $19 = (_il2cpp_string_new($18)|0);
 $20 = (($cultureInfo) + 52|0);
 HEAP32[$20>>2] = $19;
 $21 = (($ci) + 12|0);
 $22 = HEAP16[$21>>1]|0;
 $23 = $22&65535;
 $24 = (258240 + ($23)|0);
 $25 = (_il2cpp_string_new($24)|0);
 $26 = (($cultureInfo) + 56|0);
 HEAP32[$26>>2] = $25;
 $27 = (($ci) + 16|0);
 $28 = HEAP16[$27>>1]|0;
 $29 = $28&65535;
 $30 = (258240 + ($29)|0);
 $31 = (_il2cpp_string_new($30)|0);
 $32 = (($cultureInfo) + 60|0);
 HEAP32[$32>>2] = $31;
 $33 = (($ci) + 18|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = $34&65535;
 $36 = (258240 + ($35)|0);
 $37 = (_il2cpp_string_new($36)|0);
 $38 = (($cultureInfo) + 76|0);
 HEAP32[$38>>2] = $37;
 $39 = (($ci) + 20|0);
 $40 = HEAP16[$39>>1]|0;
 $41 = $40&65535;
 $42 = (258240 + ($41)|0);
 $43 = (_il2cpp_string_new($42)|0);
 $44 = (($cultureInfo) + 64|0);
 HEAP32[$44>>2] = $43;
 $45 = (($ci) + 22|0);
 $46 = HEAP16[$45>>1]|0;
 $47 = $46&65535;
 $48 = (258240 + ($47)|0);
 $49 = (_il2cpp_string_new($48)|0);
 $50 = (($cultureInfo) + 68|0);
 HEAP32[$50>>2] = $49;
 $51 = (($ci) + 24|0);
 $52 = HEAP16[$51>>1]|0;
 $53 = $52&65535;
 $54 = (258240 + ($53)|0);
 $55 = (_il2cpp_string_new($54)|0);
 $56 = (($cultureInfo) + 80|0);
 HEAP32[$56>>2] = $55;
 $57 = (($ci) + 2|0);
 $58 = HEAP16[$57>>1]|0;
 $59 = $58 << 16 >> 16;
 $60 = (($cultureInfo) + 16|0);
 HEAP32[$60>>2] = $59;
 $61 = (($ci) + 4|0);
 $62 = HEAP16[$61>>1]|0;
 $63 = $62 << 16 >> 16;
 $64 = (($cultureInfo) + 20|0);
 HEAP32[$64>>2] = $63;
 $65 = (($ci) + 48|0);
 $66 = HEAP16[$65>>1]|0;
 $67 = $66 << 16 >> 16;
 $68 = (($cultureInfo) + 24|0);
 HEAP32[$68>>2] = $67;
 $69 = (($ci) + 50|0);
 $70 = HEAP16[$69>>1]|0;
 $71 = $70 << 16 >> 16;
 $72 = (($cultureInfo) + 28|0);
 HEAP32[$72>>2] = $71;
 $73 = (($ci) + 28|0);
 $74 = (($cultureInfo) + 88|0);
 HEAP32[$74>>2] = $73;
 $75 = (($ci) + 52|0);
 $76 = (($cultureInfo) + 92|0);
 HEAP32[$76>>2] = $75;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo35construct_internal_locale_from_nameEP17Il2CppCultureInfoP12Il2CppString($cultureInfo,$name) {
 $cultureInfo = $cultureInfo|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cultureName = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $cultureName = sp;
 $0 = (($name) + 12|0);
 __ZN6il2cpp5utils11StringUtils11Utf16ToUtf8EPKt($cultureName,$0);
 $1 = HEAP8[$cultureName>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($cultureName) + 1|0);
  $7 = $6;
 } else {
  $4 = (($cultureName) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 __THREW__ = 0;
 $8 = (invoke_iiiiii(166,($7|0),(290848|0),167,4,(2242|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if (!($10)) {
   $11 = ($8|0)==(0|0);
   if ($11) {
    $$0 = 0;
   } else {
    $19 = (($8) + 2|0);
    $20 = HEAP16[$19>>1]|0;
    $21 = $20 << 16 >> 16;
    $22 = (308200 + (($21*72)|0)|0);
    __THREW__ = 0;
    invoke_vii(2483,($cultureInfo|0),($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    } else {
     $$0 = 1;
    }
   }
   $25 = HEAP8[$cultureName>>0]|0;
   $26 = $25 & 1;
   $27 = ($26<<24>>24)==(0);
   if ($27) {
    STACKTOP = sp;return ($$0|0);
   }
   $28 = (($cultureName) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   __ZdlPv($29);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $14 = HEAP8[$cultureName>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  ___resumeException($12|0);
  // unreachable;
 }
 $17 = (($cultureName) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 __ZdlPv($18);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System13GlobalizationL20culture_name_locatorEPKvS5_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$b>>1]|0;
 $1 = $0&65535;
 $2 = (258240 + ($1)|0);
 $3 = (_strcmp($a,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo23construct_number_formatEP17Il2CppCultureInfo($cultureInfo) {
 $cultureInfo = $cultureInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i10 = 0, $exitcond$i4 = 0, $i$03$i = 0, $i$03$i1 = 0, $i$03$i7 = 0, $i$11$i = 0, $i$11$i3 = 0, $i$11$i9 = 0, $len$0$lcssa$i = 0, $len$0$lcssa$i2 = 0, $len$0$lcssa$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cultureInfo) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($cultureInfo) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($cultureInfo) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = (($4) + 8|0);
 HEAP8[$7>>0] = $6;
 $8 = ((291520 + (($1*96)|0)|0) + 33|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 << 24 >> 24;
 $11 = (($4) + 32|0);
 HEAP32[$11>>2] = $10;
 $12 = (291520 + (($1*96)|0)|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13&65535;
 $15 = (258240 + ($14)|0);
 $16 = (_il2cpp_string_new($15)|0);
 $17 = (($4) + 36|0);
 HEAP32[$17>>2] = $16;
 $18 = ((291520 + (($1*96)|0)|0) + 2|0);
 $19 = HEAP16[$18>>1]|0;
 $20 = $19&65535;
 $21 = (258240 + ($20)|0);
 $22 = (_il2cpp_string_new($21)|0);
 $23 = (($4) + 40|0);
 HEAP32[$23>>2] = $22;
 $i$03$i = 0;
 while(1) {
  $24 = (((291520 + (($1*96)|0)|0) + ($i$03$i<<2)|0) + 36|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(-1);
  if ($26) {
   $len$0$lcssa$i = $i$03$i;
   break;
  }
  $27 = (($i$03$i) + 1)|0;
  $28 = ($27|0)<(5);
  if ($28) {
   $i$03$i = $27;
  } else {
   $len$0$lcssa$i = $27;
   break;
  }
 }
 $29 = HEAP32[((388944 + 32|0))>>2]|0;
 $30 = (_il2cpp_array_class_get($29,1)|0);
 $31 = (_il2cpp_array_new_specific($30,$len$0$lcssa$i)|0);
 $32 = ($len$0$lcssa$i|0)>(0);
 if ($32) {
  $i$11$i = 0;
  while(1) {
   $33 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($31,4,$i$11$i)|0);
   $34 = (((291520 + (($1*96)|0)|0) + ($i$11$i<<2)|0) + 36|0);
   $35 = HEAP32[$34>>2]|0;
   HEAP32[$33>>2] = $35;
   $36 = (($i$11$i) + 1)|0;
   $exitcond$i = ($36|0)==($len$0$lcssa$i|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$11$i = $36;
   }
  }
 }
 $37 = (($4) + 44|0);
 HEAP32[$37>>2] = $31;
 $38 = ((291520 + (($1*96)|0)|0) + 28|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39 << 24 >> 24;
 $41 = (($4) + 48|0);
 HEAP32[$41>>2] = $40;
 $42 = ((291520 + (($1*96)|0)|0) + 29|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43 << 24 >> 24;
 $45 = (($4) + 52|0);
 HEAP32[$45>>2] = $44;
 $46 = ((291520 + (($1*96)|0)|0) + 12|0);
 $47 = HEAP16[$46>>1]|0;
 $48 = $47&65535;
 $49 = (258240 + ($48)|0);
 $50 = (_il2cpp_string_new($49)|0);
 $51 = (($4) + 56|0);
 HEAP32[$51>>2] = $50;
 $52 = ((291520 + (($1*96)|0)|0) + 16|0);
 $53 = HEAP16[$52>>1]|0;
 $54 = $53&65535;
 $55 = (258240 + ($54)|0);
 $56 = (_il2cpp_string_new($55)|0);
 $57 = (($4) + 60|0);
 HEAP32[$57>>2] = $56;
 $58 = ((291520 + (($1*96)|0)|0) + 20|0);
 $59 = HEAP16[$58>>1]|0;
 $60 = $59&65535;
 $61 = (258240 + ($60)|0);
 $62 = (_il2cpp_string_new($61)|0);
 $63 = (($4) + 64|0);
 HEAP32[$63>>2] = $62;
 $64 = ((291520 + (($1*96)|0)|0) + 24|0);
 $65 = HEAP16[$64>>1]|0;
 $66 = $65&65535;
 $67 = (258240 + ($66)|0);
 $68 = (_il2cpp_string_new($67)|0);
 $69 = (($4) + 68|0);
 HEAP32[$69>>2] = $68;
 $70 = ((291520 + (($1*96)|0)|0) + 35|0);
 $71 = HEAP8[$70>>0]|0;
 $72 = $71 << 24 >> 24;
 $73 = (($4) + 72|0);
 HEAP32[$73>>2] = $72;
 $74 = ((291520 + (($1*96)|0)|0) + 8|0);
 $75 = HEAP16[$74>>1]|0;
 $76 = $75&65535;
 $77 = (258240 + ($76)|0);
 $78 = (_il2cpp_string_new($77)|0);
 $79 = (($4) + 76|0);
 HEAP32[$79>>2] = $78;
 $80 = ((291520 + (($1*96)|0)|0) + 10|0);
 $81 = HEAP16[$80>>1]|0;
 $82 = $81&65535;
 $83 = (258240 + ($82)|0);
 $84 = (_il2cpp_string_new($83)|0);
 $85 = (($4) + 80|0);
 HEAP32[$85>>2] = $84;
 $i$03$i1 = 0;
 while(1) {
  $86 = (((291520 + (($1*96)|0)|0) + ($i$03$i1<<2)|0) + 76|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==(-1);
  if ($88) {
   $len$0$lcssa$i2 = $i$03$i1;
   break;
  }
  $89 = (($i$03$i1) + 1)|0;
  $90 = ($89|0)<(5);
  if ($90) {
   $i$03$i1 = $89;
  } else {
   $len$0$lcssa$i2 = $89;
   break;
  }
 }
 $91 = HEAP32[((388944 + 32|0))>>2]|0;
 $92 = (_il2cpp_array_class_get($91,1)|0);
 $93 = (_il2cpp_array_new_specific($92,$len$0$lcssa$i2)|0);
 $94 = ($len$0$lcssa$i2|0)>(0);
 if ($94) {
  $i$11$i3 = 0;
  while(1) {
   $95 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($93,4,$i$11$i3)|0);
   $96 = (((291520 + (($1*96)|0)|0) + ($i$11$i3<<2)|0) + 76|0);
   $97 = HEAP32[$96>>2]|0;
   HEAP32[$95>>2] = $97;
   $98 = (($i$11$i3) + 1)|0;
   $exitcond$i4 = ($98|0)==($len$0$lcssa$i2|0);
   if ($exitcond$i4) {
    break;
   } else {
    $i$11$i3 = $98;
   }
  }
 }
 $99 = (($4) + 84|0);
 HEAP32[$99>>2] = $93;
 $100 = ((291520 + (($1*96)|0)|0) + 32|0);
 $101 = HEAP8[$100>>0]|0;
 $102 = $101 << 24 >> 24;
 $103 = (($4) + 88|0);
 HEAP32[$103>>2] = $102;
 $104 = ((291520 + (($1*96)|0)|0) + 34|0);
 $105 = HEAP8[$104>>0]|0;
 $106 = $105 << 24 >> 24;
 $107 = (($4) + 92|0);
 HEAP32[$107>>2] = $106;
 $108 = ((291520 + (($1*96)|0)|0) + 4|0);
 $109 = HEAP16[$108>>1]|0;
 $110 = $109&65535;
 $111 = (258240 + ($110)|0);
 $112 = (_il2cpp_string_new($111)|0);
 $113 = (($4) + 96|0);
 HEAP32[$113>>2] = $112;
 $114 = ((291520 + (($1*96)|0)|0) + 6|0);
 $115 = HEAP16[$114>>1]|0;
 $116 = $115&65535;
 $117 = (258240 + ($116)|0);
 $118 = (_il2cpp_string_new($117)|0);
 $119 = (($4) + 100|0);
 HEAP32[$119>>2] = $118;
 $i$03$i7 = 0;
 while(1) {
  $120 = (((291520 + (($1*96)|0)|0) + ($i$03$i7<<2)|0) + 56|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ($121|0)==(-1);
  if ($122) {
   $len$0$lcssa$i8 = $i$03$i7;
   break;
  }
  $123 = (($i$03$i7) + 1)|0;
  $124 = ($123|0)<(5);
  if ($124) {
   $i$03$i7 = $123;
  } else {
   $len$0$lcssa$i8 = $123;
   break;
  }
 }
 $125 = HEAP32[((388944 + 32|0))>>2]|0;
 $126 = (_il2cpp_array_class_get($125,1)|0);
 $127 = (_il2cpp_array_new_specific($126,$len$0$lcssa$i8)|0);
 $128 = ($len$0$lcssa$i8|0)>(0);
 if ($128) {
  $i$11$i9 = 0;
  while(1) {
   $129 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($127,4,$i$11$i9)|0);
   $130 = (((291520 + (($1*96)|0)|0) + ($i$11$i9<<2)|0) + 56|0);
   $131 = HEAP32[$130>>2]|0;
   HEAP32[$129>>2] = $131;
   $132 = (($i$11$i9) + 1)|0;
   $exitcond$i10 = ($132|0)==($len$0$lcssa$i8|0);
   if ($exitcond$i10) {
    break;
   } else {
    $i$11$i9 = $132;
   }
  }
 }
 $133 = (($4) + 104|0);
 HEAP32[$133>>2] = $127;
 $134 = ((291520 + (($1*96)|0)|0) + 30|0);
 $135 = HEAP8[$134>>0]|0;
 $136 = $135 << 24 >> 24;
 $137 = (($4) + 108|0);
 HEAP32[$137>>2] = $136;
 $138 = ((291520 + (($1*96)|0)|0) + 31|0);
 $139 = HEAP8[$138>>0]|0;
 $140 = $139 << 24 >> 24;
 $141 = (($4) + 112|0);
 HEAP32[$141>>2] = $140;
 $142 = ((291520 + (($1*96)|0)|0) + 14|0);
 $143 = HEAP16[$142>>1]|0;
 $144 = $143&65535;
 $145 = (258240 + ($144)|0);
 $146 = (_il2cpp_string_new($145)|0);
 $147 = (($4) + 116|0);
 HEAP32[$147>>2] = $146;
 $148 = ((291520 + (($1*96)|0)|0) + 18|0);
 $149 = HEAP16[$148>>1]|0;
 $150 = $149&65535;
 $151 = (258240 + ($150)|0);
 $152 = (_il2cpp_string_new($151)|0);
 $153 = (($4) + 120|0);
 HEAP32[$153>>2] = $152;
 $154 = ((291520 + (($1*96)|0)|0) + 22|0);
 $155 = HEAP16[$154>>1]|0;
 $156 = $155&65535;
 $157 = (258240 + ($156)|0);
 $158 = (_il2cpp_string_new($157)|0);
 $159 = (($4) + 124|0);
 HEAP32[$159>>2] = $158;
 $160 = ((291520 + (($1*96)|0)|0) + 26|0);
 $161 = HEAP16[$160>>1]|0;
 $162 = $161&65535;
 $163 = (258240 + ($162)|0);
 $164 = (_il2cpp_string_new($163)|0);
 $165 = (($4) + 128|0);
 HEAP32[$165>>2] = $164;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo44construct_internal_locale_from_specific_nameEPvP12Il2CppString($ci,$name) {
 $ci = $ci|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(307552)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo21internal_get_culturesEbbb($neutral,$specific,$installed) {
 $neutral = $neutral|0;
 $specific = $specific|0;
 $installed = $installed|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(307784)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo24internal_is_lcid_neutralEiPb($lcid,$is_neutral) {
 $lcid = $lcid|0;
 $is_neutral = $is_neutral|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(307992)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System13GlobalizationL20culture_lcid_locatorEPKvS5_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$a>>1]|0;
 $1 = $0 << 16 >> 16;
 $2 = HEAP16[$b>>1]|0;
 $3 = $2 << 16 >> 16;
 $4 = (($1) - ($3))|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System13Globalization10RegionInfo35construct_internal_region_from_nameEPvP12Il2CppString($self,$name) {
 $self = $self|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(320224)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO9DriveInfo24GetDiskFreeSpaceInternalEP12Il2CppStringPyS7_S7_Pi($pathName,$freeBytesAvail,$totalNumberOfBytes,$totalNumberOfFreeBytes,$error) {
 $pathName = $pathName|0;
 $freeBytesAvail = $freeBytesAvail|0;
 $totalNumberOfBytes = $totalNumberOfBytes|0;
 $totalNumberOfFreeBytes = $totalNumberOfFreeBytes|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(320440)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO9DriveInfo20GetDriveTypeInternalEP12Il2CppString($rootPathName) {
 $rootPathName = $rootPathName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(320632)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO29get_AltDirectorySeparatorCharEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 47;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO5CloseE12Il2CppIntPtrPi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 320856;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO13CopyFileICallEP12Il2CppStringS6_bPi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 320872;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO16get_ConsoleErrorEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os4File11GetStdErrorEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO16get_ConsoleInputEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os4File11GetStdInputEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO17get_ConsoleOutputEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os4File12GetStdOutputEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO20CreateDirectoryICallEP12Il2CppStringPi($path,$error) {
 $path = $path|0;
 $error = $error|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 320896;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO15DeleteFileICallEP12Il2CppStringPi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 320920;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO26get_DirectorySeparatorCharEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 47;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO24GetCurrentDirectoryICallEPi($error) {
 $error = $error|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $directory = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $directory = sp;
 ;HEAP32[$directory+0>>2]=0|0;HEAP32[$directory+4>>2]=0|0;HEAP32[$directory+8>>2]=0|0;
 __THREW__ = 0;
 $0 = (invoke_ii(3004,($directory|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$error>>2] = $0;
  $3 = HEAP8[$directory>>0]|0;
  $4 = $3 & 1;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $8 = (($directory) + 1|0);
   $9 = $8;
  } else {
   $6 = (($directory) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $9 = $7;
  }
  __THREW__ = 0;
  $10 = (invoke_ii(2990,($9|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP8[$directory>>0]|0;
   $14 = $13 & 1;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    STACKTOP = sp;return ($10|0);
   }
   $16 = (($directory) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   __ZdlPv($17);
   STACKTOP = sp;return ($10|0);
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $20 = HEAP8[$directory>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  ___resumeException($18|0);
  // unreachable;
 }
 $23 = (($directory) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 __ZdlPv($24);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO22GetFileAttributesICallEP12Il2CppStringPi($path,$error) {
 $path = $path|0;
 $error = $error|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $attributes = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $attributes = sp + 12|0;
 $0 = sp;
 $1 = (($path) + 12|0);
 __ZN6il2cpp5utils11StringUtils11Utf16ToUtf8EPKt($0,$1);
 __THREW__ = 0;
 $2 = (invoke_iii(2244,($0|0),($attributes|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $13 = HEAP8[$0>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   ___resumeException($11|0);
   // unreachable;
  }
  $16 = (($0) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  __ZdlPv($17);
  ___resumeException($11|0);
  // unreachable;
 } else {
  HEAP32[$error>>2] = $2;
  $5 = HEAP8[$0>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   $10 = HEAP32[$attributes>>2]|0;
   STACKTOP = sp;return ($10|0);
  }
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
  $10 = HEAP32[$attributes>>2]|0;
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11GetFileStatEP12Il2CppStringP29mscorlib_System_IO_MonoIOStatPi($path,$stat,$error) {
 $path = $path|0;
 $stat = $stat|0;
 $error = $error|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 320944;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11GetFileTypeE12Il2CppIntPtrPi($handle,$error) {
 $handle = $handle|0;
 $error = $error|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$handle>>2]|0;
 $1 = (__ZN6il2cpp2os4File11GetFileTypeEPNS0_10FileHandleE($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO9GetLengthE12Il2CppIntPtrPi($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 320968;
 (_printf((320824|0),($vararg_buffer|0))|0);
 tempRet0 = 0;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO4OpenEP12Il2CppStringiiiiPi($0,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 320992;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO17get_PathSeparatorEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 58;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO4ReadE12Il2CppIntPtrP11Il2CppArrayiiPi($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 321008;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO24SetCurrentDirectoryICallEP12Il2CppStringPi($path,$error) {
 $path = $path|0;
 $error = $error|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 321024;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO9SetLengthE12Il2CppIntPtrxPi($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 321056;
 (_printf((320824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO4SeekE12Il2CppIntPtrxiPi($0,$1,$2,$3,$4) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 321080;
 (_printf((320824|0),($vararg_buffer|0))|0);
 tempRet0 = 0;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO5WriteE12Il2CppIntPtrP11Il2CppArrayiiPi($handle,$src,$src_offset,$count,$error) {
 $handle = $handle|0;
 $src = $src|0;
 $src_offset = $src_offset|0;
 $count = $count|0;
 $error = $error|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$handle>>2]|0;
 HEAP32[$error>>2] = 0;
 $1 = (($count) + ($src_offset))|0;
 $2 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($src)|0);
 $3 = ($1>>>0)>($2>>>0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($src,1,$src_offset)|0);
 $5 = (__ZN6il2cpp2os4File5WriteEPNS0_10FileHandleEPci($0,$4,$count)|0);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO23get_VolumeSeparatorCharEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 47;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO15RemoveDirectoryEP12Il2CppStringPi($path,$error) {
 $path = $path|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(321096)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO20GetFileSystemEntriesEP12Il2CppStringS6_iiPi($path,$path_with_pattern,$attrs,$mask,$error) {
 $path = $path|0;
 $path_with_pattern = $path_with_pattern|0;
 $attrs = $attrs|0;
 $mask = $mask|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(321280)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO8MoveFileEP12Il2CppStringS6_Pi($path,$dest,$error) {
 $path = $path|0;
 $dest = $dest|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(321464)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11ReplaceFileEP12Il2CppStringS6_S6_bPi($sourceFileName,$destinationFileName,$destinationBackupFileName,$ignoreMetadataErrors,$error) {
 $sourceFileName = $sourceFileName|0;
 $destinationFileName = $destinationFileName|0;
 $destinationBackupFileName = $destinationBackupFileName|0;
 $ignoreMetadataErrors = $ignoreMetadataErrors|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(321640)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO17SetFileAttributesEP12Il2CppStringiPi($path,$attrs,$error) {
 $path = $path|0;
 $attrs = $attrs|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(321816)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO5FlushE12Il2CppIntPtrPi($handle,$error) {
 $handle = $handle|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(322000)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11SetFileTimeE12Il2CppIntPtrxxxPi($handle,$0,$1,$2,$3,$4,$5,$error) {
 $handle = $handle|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $error = $error|0;
 var $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $6 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(322168)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($6);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO4LockE12Il2CppIntPtrxxPi($handle,$0,$1,$2,$3,$error) {
 $handle = $handle|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $error = $error|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(322344)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($4);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO6UnlockE12Il2CppIntPtrxxPi($handle,$0,$1,$2,$3,$error) {
 $handle = $handle|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $error = $error|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(322512)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($4);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO10CreatePipeEP12Il2CppIntPtrS6_($read_handle,$write_handle) {
 $read_handle = $read_handle|0;
 $write_handle = $write_handle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(322688)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO15DuplicateHandleE12Il2CppIntPtrS5_S5_PS5_iii($source_process_handle,$source_handle,$target_process_handle,$target_handle,$access,$inherit,$options) {
 $source_process_handle = $source_process_handle|0;
 $source_handle = $source_handle|0;
 $target_process_handle = $target_process_handle|0;
 $target_handle = $target_handle|0;
 $access = $access|0;
 $inherit = $inherit|0;
 $options = $options|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(322864)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11GetTempPathEPP12Il2CppString($path) {
 $path = $path|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(323048)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System2IO4Path13get_temp_pathEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(323224)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly12get_fullnameEP24Il2CppReflectionAssembly($assembly) {
 $assembly = $assembly|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n = 0, $name = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $vararg_buffer = sp;
 $name = sp + 48|0;
 $n = sp + 32|0;
 $0 = (($assembly) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 dest=$name+0|0; src=$1+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = HEAP32[$name>>2]|0;
 $3 = (($name) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 65535;
 $6 = $4 >>> 16;
 $7 = (($name) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 65535;
 $10 = $8 >>> 16;
 $11 = (($name) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($name) + 16|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 $$ = $15 ? 323464 : $13;
 $16 = (($name) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 256;
 $19 = ($18|0)!=(0);
 $20 = $19 ? 323472 : 323496;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $vararg_ptr2 = (($vararg_buffer) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $6;
 $vararg_ptr3 = (($vararg_buffer) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $9;
 $vararg_ptr4 = (($vararg_buffer) + 16|0);
 HEAP32[$vararg_ptr4>>2] = $10;
 $vararg_ptr5 = (($vararg_buffer) + 20|0);
 HEAP32[$vararg_ptr5>>2] = $12;
 $vararg_ptr6 = (($vararg_buffer) + 24|0);
 HEAP32[$vararg_ptr6>>2] = $$;
 $vararg_ptr7 = (($vararg_buffer) + 28|0);
 HEAP32[$vararg_ptr7>>2] = $20;
 __ZN6il2cpp5utils11StringUtils6PrintfEPKcz($n,323400,$vararg_buffer);
 $21 = HEAP8[$n>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $26 = (($n) + 1|0);
  $27 = $26;
 } else {
  $24 = (($n) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $27 = $25;
 }
 __THREW__ = 0;
 $28 = (invoke_ii(2990,($27|0))|0);
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  $38 = HEAP8[$n>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if ($40) {
   ___resumeException($36|0);
   // unreachable;
  }
  $41 = (($n) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  __ZdlPv($42);
  ___resumeException($36|0);
  // unreachable;
 } else {
  $31 = HEAP8[$n>>0]|0;
  $32 = $31 & 1;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   STACKTOP = sp;return ($28|0);
  }
  $34 = (($n) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  __ZdlPv($35);
  STACKTOP = sp;return ($28|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly12get_locationEP35mscorlib_System_Reflection_Assembly($0) {
 $0 = $0|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 323536;
 (_printf((323504|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly16GetEntryAssemblyEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly20GetExecutingAssemblyEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[323560>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = HEAP32[388944>>2]|0;
  $3 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($2,323568,323592)|0);
  HEAP32[323560>>2] = $3;
  $4 = $3;
 } else {
  $4 = $0;
 }
 $5 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($4)|0);
 $6 = HEAP32[388944>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + 8|0);
 HEAP32[$9>>2] = $8;
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly27GetManifestResourceInternalEP35mscorlib_System_Reflection_AssemblyP12Il2CppStringPiPP33mscorlib_System_Reflection_Module($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly15InternalGetTypeEP24Il2CppReflectionAssemblyP33mscorlib_System_Reflection_ModuleP12Il2CppStringbb($assembly,$0,$name,$throwOnError,$ignoreCase) {
 $assembly = $assembly|0;
 $0 = $0|0;
 $name = $name|0;
 $throwOnError = $throwOnError|0;
 $ignoreCase = $ignoreCase|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$not = 0, $$not3 = 0, $$not6 = 0, $$not9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0;
 var $brmerge = 0, $brmerge11 = 0, $brmerge5 = 0, $brmerge8 = 0, $info = 0, $parser = 0, $str = 0, $throwOnError$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $str = sp + 152|0;
 $info = sp;
 $parser = sp + 140|0;
 $1 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($name)|0);
 __ZN6il2cpp5utils11StringUtils11Utf16ToUtf8EPKt($str,$1);
 __THREW__ = 0;
 invoke_vi(3305,($info|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if ($3) {
   label = 8;
  } else {
   __THREW__ = 0;
   invoke_viii(1563,($parser|0),($str|0),($info|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   do {
    if (!($5)) {
     __THREW__ = 0;
     $6 = (invoke_ii(2998,($parser|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      if ($6) {
       label = 10;
      } else {
       if ($throwOnError) {
        __THREW__ = 0;
        $9 = (invoke_i(3)|0);
        $10 = __THREW__; __THREW__ = 0;
        $11 = $10&1;
        if ($11) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($9|0));
        $12 = __THREW__; __THREW__ = 0;
        $13 = $12&1;
        if ($13) {
         break;
        } else {
         label = 10;
        }
       } else {
        $$0 = 0;
       }
      }
      if ((label|0) == 10) {
       $20 = ($assembly|0)==(0|0);
       $$not = $20 ^ 1;
       $throwOnError$not = $throwOnError ^ 1;
       $brmerge = $$not | $throwOnError$not;
       if (!($brmerge)) {
        __THREW__ = 0;
        $21 = (invoke_i(3)|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($21|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         break;
        }
       }
       if ($20) {
        $$0 = 0;
       } else {
        $26 = (($assembly) + 8|0);
        $27 = HEAP32[$26>>2]|0;
        __THREW__ = 0;
        $28 = (invoke_ii(3001,($27|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break;
        }
        $31 = ($28|0)==(0|0);
        $$not3 = $31 ^ 1;
        $brmerge5 = $$not3 | $throwOnError$not;
        if (!($brmerge5)) {
         __THREW__ = 0;
         $32 = (invoke_i(3)|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($32|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          break;
         }
        }
        if ($31) {
         $$0 = 0;
        } else {
         __THREW__ = 0;
         $37 = (invoke_iii(2237,($28|0),($info|0))|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          break;
         }
         $40 = ($37|0)==(0|0);
         $$not6 = $40 ^ 1;
         $brmerge8 = $$not6 | $throwOnError$not;
         if (!($brmerge8)) {
          __THREW__ = 0;
          $41 = (invoke_i(3)|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($41|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          }
         }
         if ($40) {
          $$0 = 0;
         } else {
          __THREW__ = 0;
          (invoke_ii(2996,($37|0))|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          $48 = (invoke_iii(2238,($37|0),($info|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
          $51 = ($48|0)==(0|0);
          $$not9 = $51 ^ 1;
          $brmerge11 = $$not9 | $throwOnError$not;
          if (!($brmerge11)) {
           __THREW__ = 0;
           $52 = (invoke_i(3)|0);
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if ($54) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($52|0));
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if ($56) {
            break;
           }
          }
          if ($51) {
           $$0 = 0;
          } else {
           __THREW__ = 0;
           $57 = (invoke_ii(2992,($48|0))|0);
           $58 = __THREW__; __THREW__ = 0;
           $59 = $58&1;
           if ($59) {
            break;
           } else {
            $$0 = $57;
           }
          }
         }
        }
       }
      }
      __THREW__ = 0;
      invoke_vi(3306,($info|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       label = 8;
       break L1;
      }
      $62 = HEAP8[$str>>0]|0;
      $63 = $62 & 1;
      $64 = ($63<<24>>24)==(0);
      if ($64) {
       STACKTOP = sp;return ($$0|0);
      }
      $65 = (($str) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      __ZdlPv($66);
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3306,($info|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $72 = ___cxa_find_matching_catch(0|0)|0;
    $73 = tempRet0;
    ___clang_call_terminate($72);
    // unreachable;
   } else {
    $$01 = $16;$$02 = $17;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $$01 = $14;$$02 = $15;
 }
 $67 = HEAP8[$str>>0]|0;
 $68 = $67 & 1;
 $69 = ($68<<24>>24)==(0);
 if ($69) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $70 = (($str) + 8|0);
 $71 = HEAP32[$70>>2]|0;
 __ZdlPv($71);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly22load_with_partial_nameEP12Il2CppStringP40mscorlib_System_Security_Policy_Evidence($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 323608;
 (_printf((323504|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly8FillNameEP35mscorlib_System_Reflection_AssemblyP39mscorlib_System_Reflection_AssemblyName($ass,$aname) {
 $ass = $ass|0;
 $aname = $aname|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 323648;
 (_printf((323504|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly18GetModulesInternalEP35mscorlib_System_Reflection_Assembly($__this) {
 $__this = $__this|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 323672;
 (_printf((323504|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly15LoadPermissionsEP35mscorlib_System_Reflection_AssemblyP12Il2CppIntPtrPiS8_S9_S8_S9_($a,$minimum,$minLength,$optional,$optLength,$refused,$refLength) {
 $a = $a|0;
 $minimum = $minimum|0;
 $minLength = $minLength|0;
 $optional = $optional|0;
 $optLength = $optLength|0;
 $refused = $refused|0;
 $refLength = $refLength|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 323704;
 (_printf((323504|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly18GetCallingAssemblyEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 323736;
 (_printf((323504|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly13get_code_baseEP35mscorlib_System_Reflection_Assemblyb($__this,$escaped) {
 $__this = $__this|0;
 $escaped = $escaped|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 323768;
 (_printf((323504|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly8GetTypesEP35mscorlib_System_Reflection_Assemblyb($__this,$exportedOnly) {
 $__this = $__this|0;
 $exportedOnly = $exportedOnly|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 323792;
 (_printf((323504|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly27InternalImageRuntimeVersionEP14Il2CppAssembly($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(323816)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly14get_EntryPointEP14Il2CppAssembly($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(324024)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly25get_global_assembly_cacheEP14Il2CppAssembly($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(324216)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly16GetFilesInternalEP14Il2CppAssemblyP12Il2CppStringb($self,$name,$getResourceModules) {
 $self = $self|0;
 $name = $name|0;
 $getResourceModules = $getResourceModules|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(324416)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly23InternalGetAssemblyNameEP12Il2CppStringP18Il2CppAssemblyName($assemblyFile,$aname) {
 $assemblyFile = $assemblyFile|0;
 $aname = $aname|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(324608)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly8LoadFromEP12Il2CppStringb($assemblyFile,$refonly) {
 $assemblyFile = $assemblyFile|0;
 $refonly = $refonly|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(324808)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly13GetNamespacesEP14Il2CppAssembly($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(324992)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly24GetManifestResourceNamesEP14Il2CppAssembly($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(325184)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly23GetReferencedAssembliesEP14Il2CppAssembly($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(325384)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly31GetManifestResourceInfoInternalEP14Il2CppAssemblyP12Il2CppStringPv($self,$name,$info) {
 $self = $self|0;
 $name = $name|0;
 $info = $info|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(325584)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly27MonoDebugger_GetMethodTokenEPv($method) {
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(325792)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly25GetManifestModuleInternalEP14Il2CppAssembly($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(326000)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly18get_ReflectionOnlyEP14Il2CppAssembly($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(326200)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection12AssemblyName9ParseNameEP18Il2CppAssemblyNameP12Il2CppString($aname,$assemblyName) {
 $aname = $aname|0;
 $assemblyName = $assemblyName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(326400)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection9FieldInfo16GetTypeModifiersEP21Il2CppReflectionFieldb($field,$optional) {
 $field = $field|0;
 $optional = $optional|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(326592)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection9FieldInfo19GetUnmanagedMarshalEP21Il2CppReflectionField($field) {
 $field = $field|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection9FieldInfo25internal_from_handle_typeE12Il2CppIntPtrS5_($field_handle,$type_handle) {
 $field_handle = $field_handle|0;
 $type_handle = $type_handle|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 326856;
 (_printf((326824|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MemberInfo17get_MetadataTokenEPv($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(326896)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MethodBase31GetMethodFromHandleInternalTypeE12Il2CppIntPtrS5_($method,$type) {
 $method = $method|0;
 $type = $type|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $klass$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$type>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = HEAP32[$method>>2]|0;
  $3 = (($2) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $2;$klass$0 = $4;
 } else {
  HEAP32[$vararg_buffer>>2] = 327128;
  (_printf((327096|0),($vararg_buffer|0))|0);
  $$pre = HEAP32[$method>>2]|0;
  $5 = $$pre;$klass$0 = 0;
 }
 $6 = (__ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo($5,$klass$0)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MethodBase16GetCurrentMethodEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(327176)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MethodBase21GetMethodBodyInternalE12Il2CppIntPtr($handle) {
 $handle = $handle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(327376)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module16InternalGetTypesEP33mscorlib_System_Reflection_Module($__this) {
 $__this = $__this|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 327608;
 (_printf((327576|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module15GetGuidInternalEP33mscorlib_System_Reflection_Module($__this) {
 $__this = $__this|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 327640;
 (_printf((327576|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module12GetHINSTANCEEP33mscorlib_System_Reflection_Module($__this) {
 $__this = $__this|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 327664;
 (_printf((327576|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module17get_MetadataTokenEP22Il2CppReflectionModule($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(327688)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module18GetMDStreamVersionE12Il2CppIntPtr($module_handle) {
 $module_handle = $module_handle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(327880)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module13GetGlobalTypeEP22Il2CppReflectionModule($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(328072)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module16ResolveTypeTokenE12Il2CppIntPtriP11Il2CppArrayS7_Pi($module,$token,$type_args,$method_args,$error) {
 $module = $module|0;
 $token = $token|0;
 $type_args = $type_args|0;
 $method_args = $method_args|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(328256)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module18ResolveMethodTokenE12Il2CppIntPtriP11Il2CppArrayS7_Pi($module,$token,$type_args,$method_args,$error) {
 $module = $module|0;
 $token = $token|0;
 $type_args = $type_args|0;
 $method_args = $method_args|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(328448)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module17ResolveFieldTokenE12Il2CppIntPtriP11Il2CppArrayS7_Pi($module,$token,$type_args,$method_args,$error) {
 $module = $module|0;
 $token = $token|0;
 $type_args = $type_args|0;
 $method_args = $method_args|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(328640)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module18ResolveStringTokenE12Il2CppIntPtriPi($module,$token,$error) {
 $module = $module|0;
 $token = $token|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(328832)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module18ResolveMemberTokenE12Il2CppIntPtriP11Il2CppArrayS7_Pi($module,$token,$type_args,$method_args,$error) {
 $module = $module|0;
 $token = $token|0;
 $type_args = $type_args|0;
 $method_args = $method_args|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(329024)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module16ResolveSignatureE12Il2CppIntPtriPi($module,$metadataToken,$error) {
 $module = $module|0;
 $metadataToken = $metadataToken|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(329216)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection6Module9GetPEKindE12Il2CppIntPtrPiS6_($module,$peKind,$machine) {
 $module = $module|0;
 $peKind = $peKind|0;
 $machine = $machine|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(329408)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection13MonoEventInfo14get_event_infoEP36mscorlib_System_Reflection_MonoEventP40mscorlib_System_Reflection_MonoEventInfo($ev,$info) {
 $ev = $ev|0;
 $info = $info|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 329624;
 (_printf((329592|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField13GetParentTypeEP21Il2CppReflectionFieldb($field,$declaring) {
 $field = $field|0;
 $declaring = $declaring|0;
 var $$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($declaring) {
  $0 = (($field) + 12|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($1) + 8|0);
  $$in = $2;
 } else {
  $3 = (($field) + 8|0);
  $$in = $3;
 }
 $4 = HEAP32[$$in>>2]|0;
 $5 = (($4) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField14GetFieldOffsetEP21Il2CppReflectionField($field) {
 $field = $field|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -8)|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField16GetValueInternalEP21Il2CppReflectionFieldP12Il2CppObject($field,$obj) {
 $field = $field|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $k$0 = 0, $k$02 = 0, $k$03 = 0, $not$ = 0, $o = 0, $vararg_buffer1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $o = sp + 4|0;
 $0 = (($field) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($field) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($3)|0);
 $4 = (($1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 16;
 $not$ = ($8|0)!=(0);
 $9 = ($obj|0)==(0|0);
 $brmerge = $9 | $not$;
 L1: do {
  if (!($brmerge)) {
   $k$02 = HEAP32[$obj>>2]|0;
   $10 = ($k$02|0)==(0|0);
   if (!($10)) {
    $11 = (($1) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $k$03 = $k$02;
    while(1) {
     $15 = ($k$03|0)==($12|0);
     if ($15) {
      break L1;
     }
     $13 = (($k$03) + 20|0);
     $k$0 = HEAP32[$13>>2]|0;
     $14 = ($k$0|0)==(0|0);
     if ($14) {
      break;
     } else {
      $k$03 = $k$0;
     }
    }
   }
  }
 } while(0);
 $16 = (__ZN6il2cpp2vm4Type17GetUnderlyingTypeEPK10Il2CppType($5)|0);
 $17 = (($16) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 >>> 16;
 $20 = $19 & 255;
 switch ($20|0) {
 case 17: case 13: case 10: case 11: case 12: case 8: case 9: case 24: case 25: case 3: case 6: case 7: case 2: case 4: case 5:  {
  $21 = $18 & 1073741824;
  $22 = ($21|0)==(0);
  if (!($22)) {
   label = 9;
  }
  break;
 }
 case 29: case 20: case 18: case 28: case 14:  {
  label = 9;
  break;
 }
 case 21:  {
  HEAP32[$vararg_buffer1>>2] = 329680;
  (_printf((329656|0),($vararg_buffer1|0))|0);
  break;
 }
 default: {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 if ((label|0) == 9) {
  if ($not$) {
   __ZN6il2cpp2vm5Field14StaticGetValueEP9FieldInfoPv($1,$o);
  } else {
   __ZN6il2cpp2vm5Field8GetValueEP12Il2CppObjectP9FieldInfoPv($obj,$1,$o);
  }
  $23 = HEAP32[$o>>2]|0;
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = HEAP32[$4>>2]|0;
 $25 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($24)|0);
 $26 = (__ZN6il2cpp2vm5Class10IsNullableEPK8TypeInfo($25)|0);
 if ($26) {
  HEAP32[$vararg_buffer1>>2] = 329680;
  (_printf((329656|0),($vararg_buffer1|0))|0);
 }
 $27 = HEAP32[$4>>2]|0;
 $28 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($27)|0);
 $29 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($28)|0);
 HEAP32[$o>>2] = $29;
 $30 = (($29) + 8|0);
 if ($not$) {
  __ZN6il2cpp2vm5Field14StaticGetValueEP9FieldInfoPv($1,$30);
 } else {
  __ZN6il2cpp2vm5Field8GetValueEP12Il2CppObjectP9FieldInfoPv($obj,$1,$30);
 }
 $31 = HEAP32[$o>>2]|0;
 $$0 = $31;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField16SetValueInternalEP21Il2CppReflectionFieldP12Il2CppObjectS8_($field,$obj,$value) {
 $field = $field|0;
 $obj = $obj|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $v$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($field) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 1073741824;
 $7 = ($6|0)==(0);
 L1: do {
  if ($7) {
   $8 = $5 >>> 16;
   $9 = $8 & 255;
   switch ($9|0) {
   case 29: case 20: case 18: case 28: case 14:  {
    $v$0 = $value;
    break L1;
    break;
   }
   case 17: case 13: case 10: case 11: case 12: case 8: case 9: case 24: case 25: case 3: case 6: case 7: case 2: case 4: case 5:  {
    $10 = ($value|0)==(0|0);
    if ($10) {
     $v$0 = $value;
     break L1;
    }
    $11 = (($value) + 8|0);
    $v$0 = $11;
    break L1;
    break;
   }
   case 21:  {
    $12 = HEAP32[$3>>2]|0;
    $13 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($3)|0);
    $14 = (__ZN6il2cpp2vm5Class10IsNullableEPK8TypeInfo($13)|0);
    if ($14) {
     $15 = HEAP32[$2>>2]|0;
     (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($15)|0);
     HEAP32[$vararg_buffer>>2] = 329712;
     (_printf((329656|0),($vararg_buffer|0))|0);
     $v$0 = $value;
     break L1;
    }
    $16 = HEAP32[$12>>2]|0;
    $17 = (($16) + 113|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)==(0);
    $20 = ($value|0)==(0|0);
    $or$cond = $19 | $20;
    if ($or$cond) {
     $v$0 = $value;
     break L1;
    }
    $21 = (($value) + 8|0);
    $v$0 = $21;
    break L1;
    break;
   }
   default: {
    STACKTOP = sp;return;
   }
   }
  } else {
   $v$0 = $value;
  }
 } while(0);
 $22 = HEAP32[$2>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 & 16;
 $26 = ($25|0)==(0);
 if ($26) {
  __ZN6il2cpp2vm5Field8SetValueEP12Il2CppObjectP9FieldInfoPv($obj,$1,$v$0);
  STACKTOP = sp;return;
 } else {
  __ZN6il2cpp2vm5Field14StaticSetValueEP9FieldInfoPv($1,$v$0);
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField19GetRawConstantValueEPv($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(329744)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection16MonoGenericClass10initializeEP43mscorlib_System_Reflection_MonoGenericClassP11Il2CppArrayS8_S8_S8_S8_($__this,$methods,$ctors,$fields,$properties,$events) {
 $__this = $__this|0;
 $methods = $methods|0;
 $ctors = $ctors|0;
 $fields = $fields|0;
 $properties = $properties|0;
 $events = $events|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 329976;
 (_printf((329944|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection18MonoGenericCMethod17get_ReflectedTypeEPv($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(330008)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection17MonoGenericMethod17get_ReflectedTypeEPv($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(330224)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod19get_base_definitionEP22Il2CppReflectionMethod($m) {
 $m = $m|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($m|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod19get_IsGenericMethodEP22Il2CppReflectionMethod($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod8get_nameEP22Il2CppReflectionMethod($m) {
 $m = $m|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($m) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2vm6String3NewEPKc($2)|0);
 $4 = (($m) + 12|0);
 HEAP32[$4>>2] = $3;
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod21GetDllImportAttributeE12Il2CppIntPtr($0) {
 $0 = $0|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 330472;
 (_printf((330440|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod19GetGenericArgumentsEP22Il2CppReflectionMethod($0) {
 $0 = $0|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 330512;
 (_printf((330440|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod14InternalInvokeEP22Il2CppReflectionMethodP12Il2CppObjectP11Il2CppArrayPS8_($method,$__this,$params,$exc) {
 $method = $method|0;
 $__this = $__this|0;
 $params = $params|0;
 $exc = $exc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $lengths$0 = 0, $lower_bounds$0 = 0, $m$0 = 0;
 var $obj$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($method) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$exc>>2] = 0;
 $2 = (($1) + 28|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & 16;
 $5 = ($4<<16>>16)==(0);
 do {
  if ($5) {
   $6 = ($__this|0)==(0|0);
   if ($6) {
    $18 = HEAP32[$1>>2]|0;
    $19 = (_strcmp($18,330544)|0);
    $20 = ($19|0)==(0);
    if ($20) {
     $m$0 = $1;$obj$0 = $__this;
     break;
    } else {
     $$0 = 0;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $7 = (($1) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($__this,$8)|0);
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $11 = (__ZN6il2cpp2vm6Object16GetVirtualMethodEP12Il2CppObjectP10MethodInfo($__this,$1)|0);
   $12 = (($11) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 113|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $m$0 = $11;$obj$0 = $__this;
   } else {
    $17 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($__this)|0);
    $m$0 = $11;$obj$0 = $17;
   }
  } else {
   $m$0 = $1;$obj$0 = $__this;
  }
 } while(0);
 $21 = ($params|0)==(0|0);
 if ($21) {
  $27 = 0;
 } else {
  $22 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($params)|0);
  $27 = $22;
 }
 $23 = (($m$0) + 33|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24&255;
 $26 = ($27|0)==($25|0);
 if (!($26)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = (($m$0) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 112|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if (!($32)) {
  $33 = HEAP32[$m$0>>2]|0;
  $34 = (_strcmp($33,330544)|0);
  $35 = ($34|0)==(0);
  if ($35) {
   $36 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($params)|0);
   $37 = $36 << 2;
   $38 = STACKTOP; STACKTOP = STACKTOP + ((((1*$37)|0)+15)&-16)|0;;
   $39 = ($36|0)>(0);
   if ($39) {
    $i$01 = 0;
    while(1) {
     $40 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($params,4,$i$01)|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($38) + ($i$01<<2)|0);
     HEAP32[$44>>2] = $43;
     $45 = (($i$01) + 1)|0;
     $exitcond = ($45|0)==($36|0);
     if ($exitcond) {
      break;
     } else {
      $i$01 = $45;
     }
    }
   }
   $46 = HEAP32[$28>>2]|0;
   $47 = (($46) + 112|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = $48&255;
   $50 = ($49|0)==($36|0);
   if ($50) {
    $lengths$0 = $38;$lower_bounds$0 = 0;
   } else {
    $51 = (($38) + ($49<<2)|0);
    $lengths$0 = $51;$lower_bounds$0 = $38;
   }
   $52 = (__ZN6il2cpp2vm5Array7NewFullEP8TypeInfoPjS4_($46,$lengths$0,$lower_bounds$0)|0);
   $$0 = $52;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $53 = (__ZN6il2cpp2vm7Runtime11InvokeArrayEP10MethodInfoPvP11Il2CppArrayPP12Il2CppObject($m$0,$obj$0,$params,0)|0);
 $$0 = $53;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod29get_IsGenericMethodDefinitionEP22Il2CppReflectionMethod($0) {
 $0 = $0|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 330552;
 (_printf((330440|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod22MakeGenericMethod_implEP22Il2CppReflectionMethodP11Il2CppArray($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 330600;
 (_printf((330440|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod31GetGenericMethodDefinition_implEPv($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(330640)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection14MonoMethodInfo15get_method_infoE12Il2CppIntPtrP16Il2CppMethodInfo($methodPtr,$info) {
 $methodPtr = $methodPtr|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$methodPtr>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($4)|0);
 HEAP32[$info>>2] = $5;
 $6 = (($0) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 $9 = (($info) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = (($0) + 28|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = $11&65535;
 $13 = (($info) + 8|0);
 HEAP32[$13>>2] = $12;
 $14 = (($0) + 30|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = (($info) + 12|0);
 HEAP32[$17>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection14MonoMethodInfo18get_parameter_infoE12Il2CppIntPtrP22Il2CppReflectionMethod($methodPtr,$member) {
 $methodPtr = $methodPtr|0;
 $member = $member|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$methodPtr>>2]|0;
 $1 = (($member) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $7 = 0;
 } else {
  $4 = (($2) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($5)|0);
  $7 = $6;
 }
 $8 = (__ZN6il2cpp2vm10Reflection15GetParamObjectsEP10MethodInfoP8TypeInfo($0,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection14MonoMethodInfo18get_retval_marshalE12Il2CppIntPtr($handle) {
 $handle = $handle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(330856)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection16MonoPropertyInfo17get_property_infoEP24Il2CppReflectionPropertyP18Il2CppPropertyInfoNS3_5PInfoE($property,$info,$req_info) {
 $property = $property|0;
 $info = $info|0;
 $req_info = $req_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $req_info & 8;
 $1 = ($0|0)==(0);
 if ($1) {
  $7 = $req_info & 16;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = (($property) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 48|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($13)|0);
   HEAP32[$info>>2] = $14;
  }
 } else {
  $2 = (($property) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
  HEAP32[$info>>2] = $6;
 }
 $15 = $req_info & 32;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = (($property) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (__ZN6il2cpp2vm6String3NewEPKc($20)|0);
  $22 = (($info) + 4|0);
  HEAP32[$22>>2] = $21;
 }
 $23 = $req_info & 1;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = (($property) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 16|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($info) + 16|0);
  HEAP32[$29>>2] = $28;
 }
 $30 = $req_info & 2;
 $31 = ($30|0)==(0);
 if (!($31)) {
  $32 = (($property) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   $41 = 0;
  } else {
   $37 = (($property) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (__ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo($35,$38)|0);
   $41 = $39;
  }
  $40 = (($info) + 8|0);
  HEAP32[$40>>2] = $41;
 }
 $42 = $req_info & 4;
 $43 = ($42|0)==(0);
 if ($43) {
  STACKTOP = sp;return;
 }
 $44 = (($property) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  $53 = 0;
 } else {
  $49 = (($property) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (__ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo($47,$50)|0);
  $53 = $51;
 }
 $52 = (($info) + 12|0);
 HEAP32[$52>>2] = $53;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection16MonoPropertyInfo16GetTypeModifiersEPvb($prop,$optional) {
 $prop = $prop|0;
 $optional = $optional|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(331064)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection13ParameterInfo16GetMetadataTokenEPv($self) {
 $self = $self|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(331272)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection13ParameterInfo16GetTypeModifiersEPvb($self,$optional) {
 $self = $self|0;
 $optional = $optional|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(331472)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit15AssemblyBuilder10basic_initEP47mscorlib_System_Reflection_Emit_AssemblyBuilder($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(331672)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit15AssemblyBuilder17InternalAddModuleEP47mscorlib_System_Reflection_Emit_AssemblyBuilderP12Il2CppString($__this,$fileName) {
 $__this = $__this|0;
 $fileName = $fileName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(331880)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit22CustomAttributeBuilder7GetBlobEP14Il2CppAssemblyPvP11Il2CppArraySA_SA_SA_SA_($asmb,$con,$constructorArgs,$namedProperties,$propertyValues,$namedFields,$fieldValues) {
 $asmb = $asmb|0;
 $con = $con|0;
 $constructorArgs = $constructorArgs|0;
 $namedProperties = $namedProperties|0;
 $propertyValues = $propertyValues|0;
 $namedFields = $namedFields|0;
 $fieldValues = $fieldValues|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(332096)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11DerivedType21create_unmanaged_typeEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(332312)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13DynamicMethod21create_dynamic_methodEP29Il2CppReflectionDynamicMethodS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(332520)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13DynamicMethod22destroy_dynamic_methodEP29Il2CppReflectionDynamicMethodS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(332736)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11EnumBuilder15setup_enum_typeEP20Il2CppReflectionTypeS7_($enumtype,$t) {
 $enumtype = $enumtype|0;
 $t = $t|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(332952)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit27GenericTypeParameterBuilder10initializeEP28Il2CppReflectionGenericParam($genericParameter) {
 $genericParameter = $genericParameter|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(333152)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13MethodBuilder17MakeGenericMethodEP22Il2CppReflectionMethodP11Il2CppArray($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(333384)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder10basic_initEP29Il2CppReflectionModuleBuilder($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(333592)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder13RegisterTokenEP29Il2CppReflectionModuleBuilderP12Il2CppObjecti($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(333792)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder17set_wrappers_typeEP29Il2CppReflectionModuleBuilderP20Il2CppReflectionType($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(334000)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder20create_modified_typeEP27Il2CppReflectionTypeBuilderP12Il2CppString($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(334208)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder10getUSIndexEP29Il2CppReflectionModuleBuilderP12Il2CppString($0,$str) {
 $0 = $0|0;
 $str = $str|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(334424)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder8getTokenEP29Il2CppReflectionModuleBuilderP12Il2CppObject($0,$obj) {
 $0 = $0|0;
 $obj = $obj|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(334624)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder14getMethodTokenEP29Il2CppReflectionModuleBuilderP22Il2CppReflectionMethodP11Il2CppArray($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(334824)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder14build_metadataEP29Il2CppReflectionModuleBuilder($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(335032)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder11WriteToFileEP29Il2CppReflectionModuleBuilder12Il2CppIntPtr($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(335240)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit15SignatureHelper19get_signature_localEP25Il2CppReflectionSigHelper($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(335440)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit15SignatureHelper19get_signature_fieldEP25Il2CppReflectionSigHelper($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(335656)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder20create_generic_classEP27Il2CppReflectionTypeBuilder($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(335872)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder20create_runtime_classEP27Il2CppReflectionTypeBuilderS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(336080)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder14get_event_infoEP27Il2CppReflectionTypeBuilderP28Il2CppReflectionEventBuilder($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(336288)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder22get_IsGenericParameterEP27Il2CppReflectionTypeBuilder($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(336488)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder20setup_internal_classEP27Il2CppReflectionTypeBuilderS7_($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(336696)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder21create_internal_classEP27Il2CppReflectionTypeBuilder($tb) {
 $tb = $tb|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(336904)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder19setup_generic_classEP27Il2CppReflectionTypeBuilder($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(337112)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers22get_OffsetToStringDataEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 12;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers15InitializeArrayEP11Il2CppArray12Il2CppIntPtr($array,$ptr) {
 $array = $array|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ptr>>2]|0;
 $1 = HEAP32[$array>>2]|0;
 $2 = (__ZN6il2cpp2vm5Array14GetElementSizeEPK8TypeInfo($1)|0);
 $3 = (($1) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN6il2cpp2vm4Type17GetUnderlyingTypeEPK10Il2CppType($6)|0);
 $8 = (__ZN6il2cpp2vm4Type11IsReferenceEPK10Il2CppType($7)|0);
 if ($8) {
  label = 5;
 } else {
  $9 = (($7) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & 16711680;
  $12 = ($11|0)==(1114112);
  if ($12) {
   $13 = (__ZN6il2cpp2vm4Type8GetClassEPK10Il2CppType($7)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    label = 5;
   } else {
    $15 = (__ZN6il2cpp2vm4Type8GetClassEPK10Il2CppType($7)|0);
    $16 = (($15) + 119|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)==(0);
    if (!($18)) {
     label = 5;
    }
   }
  }
 }
 if ((label|0) == 5) {
  $19 = (__ZN6il2cpp2vm9Exception20GetArgumentExceptionEPKcS3_(337320,337328)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($19);
 }
 $20 = (($0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 256;
 $25 = ($24|0)==(0);
 if ($25) {
  $26 = (__ZN6il2cpp2vm9Exception20GetArgumentExceptionEPKcS3_(337376,337392)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($26);
 }
 $27 = (($array) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = Math_imul($28, $2)|0;
 $30 = (__ZN6il2cpp2vm5Field7GetDataEP9FieldInfo($0)|0);
 $31 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($array,1,0)|0);
 _memcpy(($31|0),($30|0),($29|0))|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers14GetObjectValueEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(337424)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers19RunClassConstructorE12Il2CppIntPtr($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(337640)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers20RunModuleConstructorE12Il2CppIntPtr($module) {
 $module = $module|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(337864)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle18CheckCurrentDomainEi($handle) {
 $handle = $handle|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338120;
 (_printf((338088|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle10FreeHandleEi($handle) {
 $handle = $handle|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338152;
 (_printf((338088|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle21GetAddrOfPinnedObjectEi($handle) {
 $handle = $handle|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338176;
 (_printf((338088|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle9GetTargetEi($handle) {
 $handle = $handle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2gc8GCHandle9GetTargetEj($handle)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle15GetTargetHandleEP12Il2CppObjectii($obj,$handle,$type) {
 $obj = $obj|0;
 $handle = $handle|0;
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2gc8GCHandle15GetTargetHandleEP12Il2CppObjectii($obj,$handle,$type)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14AddRefInternalE12Il2CppIntPtr($pUnk) {
 $pUnk = $pUnk|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338240;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14AllocCoTaskMemEi($cb) {
 $cb = $cb|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338264;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal12AllocHGlobalE12Il2CppIntPtr($cb) {
 $cb = $cb|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cb>>2]|0;
 $1 = $0;
 $2 = (_malloc($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal19copy_from_unmanagedE12Il2CppIntPtriP11Il2CppArrayi($source,$startIndex,$destination,$length) {
 $source = $source|0;
 $startIndex = $startIndex|0;
 $destination = $destination|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$destination>>2]|0;
 $1 = (__Z25il2cpp_array_element_sizeP8TypeInfo($0)|0);
 $2 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($destination,$1,$startIndex)|0);
 $3 = HEAP32[$source>>2]|0;
 _memcpy(($2|0),($3|0),($length|0))|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal17copy_to_unmanagedEP11Il2CppArrayi12Il2CppIntPtri($source,$startIndex,$destination,$length) {
 $source = $source|0;
 $startIndex = $startIndex|0;
 $destination = $destination|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$source>>2]|0;
 $1 = (__Z25il2cpp_array_element_sizeP8TypeInfo($0)|0);
 $2 = HEAP32[$destination>>2]|0;
 $3 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($source,$1,$startIndex)|0);
 _memcpy(($2|0),($3|0),($length|0))|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal8FreeBSTRE12Il2CppIntPtr($ptr) {
 $ptr = $ptr|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338288;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal13FreeCoTaskMemE12Il2CppIntPtr($ptr) {
 $ptr = $ptr|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338312;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal11FreeHGlobalE12Il2CppIntPtr($hglobal) {
 $hglobal = $hglobal|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$hglobal>>2]|0;
 _free($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal11IsComObjectEP12Il2CppObject($o) {
 $o = $o|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338336;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal6GetCCWEP12Il2CppObjectP20Il2CppReflectionType($o,$T) {
 $o = $o|0;
 $T = $T|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338360;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal31GetComSlotForMethodInfoInternalEP37mscorlib_System_Reflection_MemberInfo($m) {
 $m = $m|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338376;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal37GetDelegateForFunctionPointerInternalE12Il2CppIntPtrP20Il2CppReflectionType($ptr,$t) {
 $ptr = $ptr|0;
 $t = $t|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338424;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal37GetFunctionPointerForDelegateInternalEP24mscorlib_System_Delegate($d) {
 $d = $d|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338472;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal29GetIDispatchForObjectInternalEP12Il2CppObject($o) {
 $o = $o|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338520;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal28GetIUnknownForObjectInternalEP12Il2CppObject($o) {
 $o = $o|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338560;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal15GetObjectForCCWE12Il2CppIntPtr($pUnk) {
 $pUnk = $pUnk|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338600;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal15PtrToStringBSTRE12Il2CppIntPtr($ptr) {
 $ptr = $ptr|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338632;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal61PtrToStringAnsi_mscorlib_System_String_mscorlib_System_IntPtrE12Il2CppIntPtr($ptr) {
 $ptr = $ptr|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338664;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal83PtrToStringAnsi_mscorlib_System_String_mscorlib_System_IntPtr_mscorlib_System_Int32E12Il2CppIntPtri($ptr,$len) {
 $ptr = $ptr|0;
 $len = $len|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338736;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal60PtrToStringUni_mscorlib_System_String_mscorlib_System_IntPtrE12Il2CppIntPtr($ptr) {
 $ptr = $ptr|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338832;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal82PtrToStringUni_mscorlib_System_String_mscorlib_System_IntPtr_mscorlib_System_Int32E12Il2CppIntPtri($ptr,$len) {
 $ptr = $ptr|0;
 $len = $len|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 338904;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14PtrToStructureE12Il2CppIntPtrP20Il2CppReflectionType($ptr,$structureType) {
 $ptr = $ptr|0;
 $structureType = $structureType|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339000;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal22QueryInterfaceInternalE12Il2CppIntPtrP20mscorlib_System_GuidPS6_($pUnk,$iid,$ppv) {
 $pUnk = $pUnk|0;
 $iid = $iid|0;
 $ppv = $ppv|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339024;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal8ReadByteE12Il2CppIntPtri($ptr,$ofs) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339056;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal9ReadInt16E12Il2CppIntPtri($ptr,$ofs) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339080;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal9ReadInt32E12Il2CppIntPtri($ptr,$ofs) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339104;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal9ReadInt64E12Il2CppIntPtri($ptr,$ofs) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339128;
 (_printf((338208|0),($vararg_buffer|0))|0);
 tempRet0 = 0;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10ReadIntPtrE12Il2CppIntPtri($ptr,$ofs) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339152;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal15ReleaseInternalE12Il2CppIntPtr($pUnk) {
 $pUnk = $pUnk|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339176;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal24ReleaseComObjectInternalEP12Il2CppObject($co) {
 $co = $co|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339208;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal6SizeOfEP20Il2CppReflectionType($rtype) {
 $rtype = $rtype|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($rtype) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 $3 = (($2) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal12StringToBSTREP12Il2CppString($s) {
 $s = $s|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339248;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal18StringToHGlobalUniEP12Il2CppString($s) {
 $s = $s|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339272;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal19StringToHGlobalAnsiEP12Il2CppString($s) {
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $str = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $str = sp;
 $0 = (__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($s)|0);
 __ZN6il2cpp5utils11StringUtils11Utf16ToUtf8EPKt($str,$0);
 $1 = HEAP8[$str>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $10 = $1&255;
  $11 = $10 >>> 1;
  $12 = (($11) + 1)|0;
  $13 = (_malloc($12)|0);
  $14 = (($str) + 1|0);
  $15 = $13;$16 = $14;
 } else {
  $4 = (($str) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 1)|0;
  $7 = (_malloc($6)|0);
  $8 = (($str) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $15 = $7;$16 = $9;
 }
 (_strcpy(($15|0),($16|0))|0);
 $17 = HEAP8[$str>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  STACKTOP = sp;return ($15|0);
 }
 $20 = (($str) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 __ZdlPv($21);
 STACKTOP = sp;return ($15|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14StructureToPtrEP12Il2CppObject12Il2CppIntPtrb($structure,$ptr,$fDeleteOld) {
 $structure = $structure|0;
 $ptr = $ptr|0;
 $fDeleteOld = $fDeleteOld|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339304;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal9WriteByteE12Il2CppIntPtrih($ptr,$ofs,$val) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 $val = $val|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339328;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10WriteInt16E12Il2CppIntPtris($ptr,$ofs,$val) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 $val = $val|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339352;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10WriteInt32E12Il2CppIntPtrii($ptr,$ofs,$val) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 $val = $val|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339376;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10WriteInt64E12Il2CppIntPtrix($ptr,$ofs,$0,$1) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 $0 = $0|0;
 $1 = $1|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339400;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal11WriteIntPtrE12Il2CppIntPtriS6_($ptr,$ofs,$val) {
 $ptr = $ptr|0;
 $ofs = $ofs|0;
 $val = $val|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339424;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal16DestroyStructureE12Il2CppIntPtrP20Il2CppReflectionType($ptr,$structuretype) {
 $ptr = $ptr|0;
 $structuretype = $structuretype|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339448;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal17GetLastWin32ErrorEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339480;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal8OffsetOfEP20Il2CppReflectionTypeP12Il2CppString($t,$fieldName) {
 $t = $t|0;
 $fieldName = $fieldName|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339512;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal7PrelinkEP22Il2CppReflectionMethod($m) {
 $m = $m|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(339536)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10PrelinkAllEP20Il2CppReflectionType($c) {
 $c = $c|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(339736)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal16ReAllocCoTaskMemE12Il2CppIntPtri($pv,$cb) {
 $pv = $pv|0;
 $cb = $cb|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339936;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14ReAllocHGlobalE12Il2CppIntPtrS6_($pv,$cb) {
 $pv = $pv|0;
 $cb = $cb|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339968;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal30UnsafeAddrOfPinnedArrayElementEP11Il2CppArrayi($arr,$index) {
 $arr = $arr|0;
 $index = $index|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 339992;
 (_printf((338208|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting16RemotingServices16GetVirtualMethodEP20Il2CppReflectionTypeP22Il2CppReflectionMethod($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(340032)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting16RemotingServices15InternalExecuteEP22Il2CppReflectionMethodP12Il2CppObjectP11Il2CppArrayPSB_($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(340248)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($4);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting16RemotingServices18IsTransparentProxyEP12Il2CppObject($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(340464)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting10Activation18ActivationServices21EnableProxyActivationEP20Il2CppReflectionTypeb($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(340680)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting10Activation18ActivationServices34AllocateUninitializedClassInstanceEP20Il2CppReflectionType($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(340920)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting9Messaging17MonoMethodMessage11InitMessageEP19Il2CppMethodMessageP22Il2CppReflectionMethodP11Il2CppArray($0,$1,$2) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(341168)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting7Proxies9RealProxy27InternalGetTransparentProxyEP12Il2CppObjectP12Il2CppString($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(341392)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting7Proxies9RealProxy20InternalGetProxyTypeEP12Il2CppObject($0) {
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(341616)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($1);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security13SecurityFrame17_GetSecurityStackEi($skip) {
 $skip = $skip|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 341864;
 (_printf((341832|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security13SecurityFrame17_GetSecurityFrameEi($skip) {
 $skip = $skip|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(341912)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager24get_CheckExecutionRightsEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 342144;
 (_printf((342112|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager21GetLinkDemandSecurityEP37mscorlib_System_Reflection_MethodBaseP51mscorlib_System_Security_RuntimeDeclSecurityActionsS8_($method,$_____cdecl,$mdecl) {
 $method = $method|0;
 $_____cdecl = $_____cdecl|0;
 $mdecl = $mdecl|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 342192;
 (_printf((342112|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager19get_SecurityEnabledEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager24set_CheckExecutionRightsEb($value) {
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(342232)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager19set_SecurityEnabledEb($value) {
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(342448)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security12Cryptography24RNGCryptoServiceProvider8RngCloseE12Il2CppIntPtr($provider) {
 $provider = $provider|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security12Cryptography24RNGCryptoServiceProvider11RngGetBytesE12Il2CppIntPtrP11Il2CppArray($provider,$data) {
 $provider = $provider|0;
 $data = $data|0;
 var $$sroa$01$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_array_length($data)|0);
 $1 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($data,1,0)|0);
 $2 = HEAP32[$provider>>2]|0;
 $3 = (__ZN6il2cpp2os12Cryptography25FillBufferWithRandomBytesEPvjPh($2,$0,$1)|0);
 if ($3) {
  $$sroa$01$0 = $2;
  STACKTOP = sp;return ($$sroa$01$0|0);
 }
 $4 = (__ZN6il2cpp2os12Cryptography23GetCryptographyProviderEv()|0);
 HEAP32[$provider>>2] = $4;
 $5 = (__ZN6il2cpp2os12Cryptography25FillBufferWithRandomBytesEPvjPh($4,$0,$1)|0);
 if ($5) {
  $$sroa$01$0 = $4;
  STACKTOP = sp;return ($$sroa$01$0|0);
 }
 $$sroa$01$0 = 0;
 STACKTOP = sp;return ($$sroa$01$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security12Cryptography24RNGCryptoServiceProvider13RngInitializeEP11Il2CppArray($seed) {
 $seed = $seed|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os12Cryptography23GetCryptographyProviderEv()|0);
 $1 = ($0|0)==(0|0);
 $2 = ($seed|0)==(0|0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  STACKTOP = sp;return ($0|0);
 }
 $3 = (_il2cpp_array_length($seed)|0);
 $4 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($seed,1,0)|0);
 $5 = (_malloc($3)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return ($0|0);
 }
 _memcpy(($5|0),($4|0),($3|0))|0;
 (__ZN6il2cpp2os12Cryptography25FillBufferWithRandomBytesEPvjPh($0,$3,$5)|0);
 _free($5);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security12Cryptography24RNGCryptoServiceProvider7RngOpenEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os12Cryptography24OpenCryptographyProviderEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security6Policy8Evidence21IsAuthenticodePresentEP14Il2CppAssembly($a) {
 $a = $a|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(342656)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal15WindowsIdentity12GetTokenNameE12Il2CppIntPtr($token) {
 $token = $token|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 342888;
 (_printf((342856|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal15WindowsIdentity15GetCurrentTokenEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 342920;
 (_printf((342856|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal15WindowsIdentity9_GetRolesE12Il2CppIntPtr($token) {
 $token = $token|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(342960)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal15WindowsIdentity12GetUserTokenEP12Il2CppString($username) {
 $username = $username|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(343168)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal27WindowsImpersonationContext10CloseTokenE12Il2CppIntPtr($token) {
 $token = $token|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(343376)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal27WindowsImpersonationContext14DuplicateTokenE12Il2CppIntPtr($token) {
 $token = $token|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(343608)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal27WindowsImpersonationContext15SetCurrentTokenE12Il2CppIntPtr($token) {
 $token = $token|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(343848)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal27WindowsImpersonationContext12RevertToSelfEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(344088)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal16WindowsPrincipal17IsMemberOfGroupIdE12Il2CppIntPtrS6_($user,$group) {
 $user = $user|0;
 $group = $group|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(344320)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System8Security9Principal16WindowsPrincipal19IsMemberOfGroupNameE12Il2CppIntPtrP12Il2CppString($user,$group) {
 $user = $user|0;
 $group = $group|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(344536)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System4Text8Encoding16InternalCodePageEPi($codePage) {
 $codePage = $codePage|0;
 var $$0 = 0, $$pr$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $c$08 = 0, $code$0$ph14 = 0, $i$0$ph15 = 0, $i$07 = 0, $isascii1 = 0, $p$0$ph13 = 0, $p$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$codePage>>2]|0;
 HEAP32[$codePage>>2] = -1;
 $1 = (__ZN6il2cpp5utils11StringUtils15StringDuplicateEPKc(344776)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 $4 = 1;
 if ($3) {
  $code$0$ph14 = 0;$i$0$ph15 = 0;$p$0$ph13 = $4;
 } else {
  $5 = $2;$c$08 = $1;
  while(1) {
   $isascii1 = ($5<<24>>24)>(-1);
   if ($isascii1) {
    $6 = $5 << 24 >> 24;
    $7 = (_isalpha($6)|0);
    $8 = ($7|0)==(0);
    $$pr$pre = HEAP8[$c$08>>0]|0;
    if ($8) {
     $13 = $$pr$pre;
    } else {
     $9 = $$pr$pre << 24 >> 24;
     $10 = (_tolower($9)|0);
     $11 = $10&255;
     HEAP8[$c$08>>0] = $11;
     $13 = $11;
    }
    $12 = ($13<<24>>24)==(45);
    if ($12) {
     HEAP8[$c$08>>0] = 95;
    }
   }
   $14 = (($c$08) + 1|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   $17 = 1;
   if ($16) {
    $code$0$ph14 = 0;$i$0$ph15 = 0;$p$0$ph13 = $17;
    break;
   } else {
    $5 = $15;$c$08 = $14;
   }
  }
 }
 L11: while(1) {
  $i$07 = $i$0$ph15;$p$06 = $p$0$ph13;
  while(1) {
   $18 = ($p$06>>>0)<((7)>>>0);
   if ($18) {
    break;
   }
   $24 = (_strcmp($p$06,$1)|0);
   $25 = ($24|0)==(0);
   if ($25) {
    label = 12;
    break L11;
   }
   $26 = (($i$07) + 1)|0;
   $27 = (344784 + ($26<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($26|0)==(36);
   if ($29) {
    break L11;
   } else {
    $i$07 = $26;$p$06 = $28;
   }
  }
  $19 = $p$06;
  $20 = (($i$07) + 1)|0;
  $21 = (344784 + ($20<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($20|0)==(36);
  if ($23) {
   break;
  } else {
   $code$0$ph14 = $19;$i$0$ph15 = $20;$p$0$ph13 = $22;
  }
 }
 if ((label|0) == 12) {
  HEAP32[$codePage>>2] = $code$0$ph14;
 }
 $30 = (_strstr($1,344936)|0);
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = HEAP32[$codePage>>2]|0;
  $33 = $32 | 268435456;
  HEAP32[$codePage>>2] = $33;
 }
 _free($1);
 $34 = ($0|0)==(0);
 if ($34) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $35 = HEAP32[$codePage>>2]|0;
 $36 = ($35|0)==(-1);
 if (!($36)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(344760)|0);
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked17CompareExchange_TEPPvS5_S5_($location,$value,$comparand) {
 $location = $location|0;
 $value = $value|0;
 $comparand = $comparand|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$location>>2]|0;
 $1 = HEAP32[$location>>2]|0;
 $2 = ($1|0)==($comparand|0);
 if (!($2)) {
  STACKTOP = sp;return ($0|0);
 }
 HEAP32[$location>>2] = $value;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked21CompareExchangeIntPtrEP12Il2CppIntPtrS5_S5_($location,$value,$comparand) {
 $location = $location|0;
 $value = $value|0;
 $comparand = $comparand|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$value>>2]|0;
 $1 = HEAP32[$comparand>>2]|0;
 $2 = HEAP32[$location>>2]|0;
 $3 = HEAP32[$location>>2]|0;
 $4 = ($3|0)==($1|0);
 if (!($4)) {
  STACKTOP = sp;return ($2|0);
 }
 HEAP32[$location>>2] = $0;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked15CompareExchangeEPiii($location,$value,$comparand) {
 $location = $location|0;
 $value = $value|0;
 $comparand = $comparand|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$location>>2]|0;
 $1 = HEAP32[$location>>2]|0;
 $2 = ($1|0)==($comparand|0);
 if (!($2)) {
  STACKTOP = sp;return ($0|0);
 }
 HEAP32[$location>>2] = $value;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked17CompareExchange64EPxxx($location,$0,$1,$2,$3) {
 $location = $location|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $4 = $location;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $location;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = ($12|0)==($2|0);
 $17 = ($15|0)==($3|0);
 $18 = $16 & $17;
 if (!($18)) {
  tempRet0 = $9;
  STACKTOP = sp;return ($6|0);
 }
 $19 = $location;
 $20 = $19;
 HEAP32[$20>>2] = $0;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $1;
 tempRet0 = $9;
 STACKTOP = sp;return ($6|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked3AddEPii($location1,$value) {
 $location1 = $location1|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$location1>>2]|0;
 $1 = (($0) + ($value))|0;
 HEAP32[$location1>>2] = $1;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked5Add64EPxx($location1,$0,$1) {
 $location1 = $location1|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $location1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (_i64Add(($4|0),($7|0),($0|0),($1|0))|0);
 $9 = tempRet0;
 $10 = $location1;
 $11 = $10;
 HEAP32[$11>>2] = $8;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 tempRet0 = $9;
 STACKTOP = sp;return ($8|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked21CompareExchangeDoubleEPddd($location1,$value,$comparand) {
 $location1 = $location1|0;
 $value = +$value;
 $comparand = +$comparand;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $comparand;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = $location1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $location1;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = ($10|0)==($0|0);
 $15 = ($13|0)==($1|0);
 $16 = $14 & $15;
 if (!($16)) {
  HEAP32[tempDoublePtr>>2] = $4;HEAP32[tempDoublePtr+4>>2] = $7;$23 = +HEAPF64[tempDoublePtr>>3];
  STACKTOP = sp;return (+$23);
 }
 HEAPF64[tempDoublePtr>>3] = $value;$17 = HEAP32[tempDoublePtr>>2]|0;
 $18 = HEAP32[tempDoublePtr+4>>2]|0;
 $19 = $location1;
 $20 = $19;
 HEAP32[$20>>2] = $17;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 HEAP32[tempDoublePtr>>2] = $4;HEAP32[tempDoublePtr+4>>2] = $7;$23 = +HEAPF64[tempDoublePtr>>3];
 STACKTOP = sp;return (+$23);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked21CompareExchangeSingleEPfff($location1,$value,$comparand) {
 $location1 = $location1|0;
 $value = Math_fround($value);
 $comparand = Math_fround($comparand);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (HEAPF32[tempDoublePtr>>2]=$comparand,HEAP32[tempDoublePtr>>2]|0);
 $1 = HEAP32[$location1>>2]|0;
 $2 = HEAP32[$location1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  $4 = (HEAPF32[tempDoublePtr>>2]=$value,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$location1>>2] = $4;
 }
 $5 = (HEAP32[tempDoublePtr>>2]=$1,Math_fround(HEAPF32[tempDoublePtr>>2]));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked9IncrementEPi($value) {
 $value = $value|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$value>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[$value>>2] = $1;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked11Increment64EPx($location) {
 $location = $location|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $location;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (_i64Add(($2|0),($5|0),1,0)|0);
 $7 = tempRet0;
 $8 = $location;
 $9 = $8;
 HEAP32[$9>>2] = $6;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 tempRet0 = $7;
 STACKTOP = sp;return ($6|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked9DecrementEPi($location) {
 $location = $location|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$location>>2]|0;
 $1 = (($0) + -1)|0;
 HEAP32[$location>>2] = $1;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked11Decrement64EPx($location) {
 $location = $location|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $location;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (_i64Add(($2|0),($5|0),-1,-1)|0);
 $7 = tempRet0;
 $8 = $location;
 $9 = $8;
 HEAP32[$9>>2] = $6;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 tempRet0 = $7;
 STACKTOP = sp;return ($6|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked14ExchangeDoubleEPdd($location1,$value) {
 $location1 = $location1|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $value;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = $location1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $location1;
 $9 = $8;
 HEAP32[$9>>2] = $0;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $1;
 HEAP32[tempDoublePtr>>2] = $4;HEAP32[tempDoublePtr+4>>2] = $7;$12 = +HEAPF64[tempDoublePtr>>3];
 STACKTOP = sp;return (+$12);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked8ExchangeEPii($location1,$value) {
 $location1 = $location1|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$location1>>2]|0;
 HEAP32[$location1>>2] = $value;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked10Exchange64EPxx($location1,$0,$1) {
 $location1 = $location1|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $location1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $location1;
 $9 = $8;
 HEAP32[$9>>2] = $0;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $1;
 tempRet0 = $7;
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked15ExchangePointerEPPvS5_($location1,$value) {
 $location1 = $location1|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$location1>>2]|0;
 HEAP32[$location1>>2] = $value;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked14ExchangeSingleEPff($location1,$value) {
 $location1 = $location1|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (HEAPF32[tempDoublePtr>>2]=$value,HEAP32[tempDoublePtr>>2]|0);
 $1 = HEAP32[$location1>>2]|0;
 HEAP32[$location1>>2] = $0;
 $2 = (HEAP32[tempDoublePtr>>2]=$1,Math_fround(HEAPF32[tempDoublePtr>>2]));
 STACKTOP = sp;return (Math_fround($2));
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked4ReadEPx($location) {
 $location = $location|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $location;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 tempRet0 = $5;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor5EnterEP12Il2CppObject($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor4ExitEP12Il2CppObject($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor25Monitor_test_synchronisedEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 345440;
 (_printf((345408|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor13Monitor_pulseEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 345480;
 (_printf((345408|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor12Monitor_waitEP12Il2CppObjecti($obj,$ms) {
 $obj = $obj|0;
 $ms = $ms|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 345504;
 (_printf((345408|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor17Monitor_try_enterEP12Il2CppObjecti($obj,$ms) {
 $obj = $obj|0;
 $ms = $ms|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 345528;
 (_printf((345408|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor17Monitor_pulse_allEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 345560;
 (_printf((345408|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading5Mutex20CreateMutex_internalEbP12Il2CppStringPb($initiallyOwned,$name,$created) {
 $initiallyOwned = $initiallyOwned|0;
 $name = $name|0;
 $created = $created|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $mutex$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$created>>0] = 1;
 $0 = ($name|0)==(0|0);
 if ($0) {
  $1 = (__Znwj(8)|0);
  __THREW__ = 0;
  invoke_vii(2484,($1|0),0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   $7 = ___cxa_find_matching_catch()|0;
   $8 = tempRet0;
   __ZdlPv($1);
   ___resumeException($7|0);
   // unreachable;
  } else {
   $mutex$0 = $1;
  }
 } else {
  $4 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(345592)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($4);
  $mutex$0 = 0;
 }
 if ($initiallyOwned) {
  __ZN6il2cpp2os5Mutex4LockEv($mutex$0);
 }
 $5 = (__Znwj(8)|0);
 HEAP32[$5>>2] = ((345776 + 8|0));
 $6 = (($5) + 4|0);
 HEAP32[$6>>2] = $mutex$0;
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading5Mutex21ReleaseMutex_internalE12Il2CppIntPtr($handle) {
 $handle = $handle|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$handle>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN6il2cpp2os5Mutex6UnlockEv($2);
 STACKTOP = sp;return 1;
}
function __ZN6il2cpp2os11MutexHandleD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((345776 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3310,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 }
 __ZdlPv($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os11MutexHandleD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((345776 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3310,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  __ZdlPv($this);
  ___resumeException($5|0);
  // unreachable;
 }
 __ZdlPv($1);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os11MutexHandle4WaitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2os5Mutex4LockEv($1);
 STACKTOP = sp;return 1;
}
function __ZN6il2cpp2os11MutexHandle4WaitEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $$0 = 0, $$mux = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $not$ = 0, $timeWaitedMs$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ms|0)==(-1);
 if ($0) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2os5Mutex7TryLockEv($2)|0);
 if ($3) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $timeWaitedMs$01 = 0;
 }
 while(1) {
  (__ZN6il2cpp2os6Thread5SleepEj(10)|0);
  $8 = (($timeWaitedMs$01) + 10)|0;
  $9 = ($8>>>0)>($ms>>>0);
  $10 = HEAP32[$1>>2]|0;
  $11 = (__ZN6il2cpp2os5Mutex7TryLockEv($10)|0);
  $brmerge = $9 | $11;
  if ($brmerge) {
   break;
  } else {
   $timeWaitedMs$01 = $8;
  }
 }
 $not$ = $9 ^ 1;
 $$mux = $11 | $not$;
 $$0 = $$mux;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os11MutexHandle10IsSignaledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2os5Mutex10IsSignaledEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2os11MutexHandle6SignalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2os5Mutex6SignalEv($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading16NativeEventCalls19ResetEvent_internalE12Il2CppIntPtr($handlePtr) {
 $handlePtr = $handlePtr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$handlePtr>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2os5Event5ResetEv($2)|0);
 $4 = ($3|0)==(0);
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading16NativeEventCalls17SetEvent_internalE12Il2CppIntPtr($handlePtr) {
 $handlePtr = $handlePtr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$handlePtr>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2os5Event3SetEv($2)|0);
 $4 = ($3|0)==(0);
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading16NativeEventCalls20CreateEvent_internalEbbP12Il2CppStringPb($manualReset,$signaled,$name,$created) {
 $manualReset = $manualReset|0;
 $signaled = $signaled|0;
 $name = $name|0;
 $created = $created|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $event$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$created>>0] = 1;
 $0 = ($name|0)==(0|0);
 if ($0) {
  $1 = (__Znwj(4)|0);
  __THREW__ = 0;
  invoke_viii(1564,($1|0),($manualReset|0),($signaled|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   $7 = ___cxa_find_matching_catch()|0;
   $8 = tempRet0;
   __ZdlPv($1);
   ___resumeException($7|0);
   // unreachable;
  } else {
   $event$0 = $1;
  }
 } else {
  $4 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(345808)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($4);
  $event$0 = 0;
 }
 $5 = (__Znwj(8)|0);
 HEAP32[$5>>2] = ((346016 + 8|0));
 $6 = (($5) + 4|0);
 HEAP32[$6>>2] = $event$0;
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading16NativeEventCalls19CloseEvent_internalE12Il2CppIntPtr($handlePtr) {
 $handlePtr = $handlePtr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$handlePtr>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os11EventHandleD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((346016 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3311,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 }
 __ZdlPv($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os11EventHandleD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((346016 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3311,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  __ZdlPv($this);
  ___resumeException($5|0);
  // unreachable;
 }
 __ZdlPv($1);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os11EventHandle4WaitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 (__ZN6il2cpp2os5Event4WaitEv($1)|0);
 STACKTOP = sp;return 1;
}
function __ZN6il2cpp2os11EventHandle4WaitEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2os5Event4WaitEj($1,$ms)|0);
 $3 = ($2|0)!=(2);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp2os11EventHandle10IsSignaledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2os5Event10IsSignaledEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2os11EventHandle6SignalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2os5Event6SignalEv($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread8ClrStateEP12Il2CppThreadNS_2vm11ThreadStateE($__this,$state) {
 $__this = $__this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2os5Mutex4LockEv($1);
 __ZN6il2cpp2os5Mutex6UnlockEv($1);
 $2 = $state ^ -1;
 $3 = (($__this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & $2;
 HEAP32[$3>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread22CurrentThread_internalEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Thread7CurrentEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread23GetCachedCurrentCultureEP12Il2CppThread($__this) {
 $__this = $__this|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   $$0$i = 0;
  } else {
   $3 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($1,4,0)|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    $7 = 1;
    while(1) {
     $6 = ($7|0)<(4);
     if (!($6)) {
      $$0$i = 0;
      break L1;
     }
     $$pre$i = HEAP32[$0>>2]|0;
     $8 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($$pre$i,4,$7)|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ($9|0)==(0|0);
     $11 = (($7) + 1)|0;
     if ($10) {
      $7 = $11;
     } else {
      $$0$i = $9;
      break;
     }
    }
   } else {
    $$0$i = $4;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread11GetDomainIDEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346080;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread27GetSerializedCurrentCultureEP12Il2CppThread($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $res$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $res$0 = 0;
  STACKTOP = sp;return ($res$0|0);
 }
 $3 = HEAP32[((388944 + 8|0))>>2]|0;
 $4 = (($__this) + 116|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($3,$5)|0);
 $7 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($6,1,0)|0);
 $8 = HEAP32[$0>>2]|0;
 $9 = HEAP32[$4>>2]|0;
 _memcpy(($7|0),($8|0),($9|0))|0;
 $res$0 = $6;
 STACKTOP = sp;return ($res$0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread8GetStateEP12Il2CppThread($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2os5Mutex4LockEv($1);
 __ZN6il2cpp2os5Mutex6UnlockEv($1);
 $2 = (($__this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread13Join_internalEP12Il2CppThreadiPv($__this,$ms,$thread) {
 $__this = $__this|0;
 $ms = $ms|0;
 $thread = $thread|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN6il2cpp2os5Mutex4LockEv($3);
 __ZN6il2cpp2os5Mutex6UnlockEv($3);
 __ZN6il2cpp2vm6Thread8SetStateEP12Il2CppThreadNS0_11ThreadStateE($__this,32);
 $4 = (__ZN6il2cpp2os6Thread4JoinEj($1,$ms)|0);
 $5 = HEAP32[$2>>2]|0;
 __ZN6il2cpp2os5Mutex4LockEv($5);
 __ZN6il2cpp2os5Mutex6UnlockEv($5);
 $6 = (($__this) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & -33;
 HEAP32[$6>>2] = $8;
 $9 = ($4|0)==(0);
 STACKTOP = sp;return ($9|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread8SetStateEP12Il2CppThreadNS_2vm11ThreadStateE($__this,$state) {
 $__this = $__this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2os5Mutex4LockEv($1);
 __ZN6il2cpp2os5Mutex6UnlockEv($1);
 __ZN6il2cpp2vm6Thread8SetStateEP12Il2CppThreadNS0_11ThreadStateE($__this,$state);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread19ResetAbort_internalEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346104;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread23SetCachedCurrentCultureEP12Il2CppThreadP12Il2CppObject($__this,$culture) {
 $__this = $__this|0;
 $culture = $culture|0;
 var $$ph = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$05$i$lcssa7 = 0, $i$05$i3 = 0, $i$05$i3$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[((388944 + 4|0))>>2]|0;
  $4 = (__ZN6il2cpp2vm5Array3NewEP8TypeInfoj($3,8)|0);
  HEAP32[$0>>2] = $4;
  $$ph = $4;
 } else {
  $$ph = $1;
 }
 $5 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($$ph,4,0)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $9 = 1;$i$05$i3 = 0;
   while(1) {
    $8 = ($9|0)<(4);
    if (!($8)) {
     break;
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $10 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($$pre$i,4,$9)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    $13 = (($9) + 1)|0;
    if ($12) {
     $i$05$i3$phi = $9;$9 = $13;$i$05$i3 = $i$05$i3$phi;
    } else {
     label = 6;
     break;
    }
   }
   if ((label|0) == 6) {
    $14 = ($9|0)>(-1);
    if ($14) {
     $i$05$i$lcssa7 = $9;
     break;
    }
   }
   $17 = ($i$05$i3|0)>(-1);
   if (!($17)) {
    STACKTOP = sp;return;
   }
   $18 = HEAP32[$0>>2]|0;
   $19 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($18,4,$i$05$i3)|0);
   HEAP32[$19>>2] = $culture;
   STACKTOP = sp;return;
  } else {
   $i$05$i$lcssa7 = 0;
  }
 } while(0);
 $15 = HEAP32[$0>>2]|0;
 $16 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($15,4,$i$05$i$lcssa7)|0);
 HEAP32[$16>>2] = $culture;
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread16SetName_internalEP32mscorlib_System_Threading_ThreadP12Il2CppString($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346136;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread14Sleep_internalEi($milliseconds) {
 $milliseconds = $milliseconds|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2os6Thread5SleepEj($milliseconds)|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread11Thread_initEP12Il2CppThread($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(8)|0);
 __THREW__ = 0;
 invoke_vii(2484,($0|0),0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($__this) + 108|0);
  HEAP32[$3>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread15Thread_internalEP12Il2CppThreadP14Il2CppDelegate($__this,$start) {
 $__this = $__this|0;
 $start = $start|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21il2cpp_gc_alloc_fixedjPv(20,0)|0);
 HEAP32[$0>>2] = $__this;
 $1 = (__ZN6il2cpp2vm6Domain10GetCurrentEv()|0);
 $2 = (($0) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = (($0) + 8|0);
 HEAP32[$3>>2] = $start;
 $4 = (($__this) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (__Znwj(12)|0);
 __THREW__ = 0;
 invoke_viii(1565,($7|0),0,1);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  __ZdlPv($7);
  $$0 = $24;$$01 = $25;
  ___resumeException($$0|0);
  // unreachable;
 }
 $10 = (($0) + 16|0);
 HEAP32[$10>>2] = $7;
 $11 = (__Znwj(4)|0);
 __THREW__ = 0;
 invoke_vi(3312,($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  __ZdlPv($11);
  $$0 = $26;$$01 = $27;
  ___resumeException($$0|0);
  // unreachable;
 }
 (__ZN6il2cpp2os6Thread3RunEPFvPvES2_($11,3313,$0)|0);
 $14 = (($__this) + 12|0);
 HEAP32[$14>>2] = $11;
 $15 = (($__this) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & -9;
 HEAP32[$15>>2] = $17;
 $18 = (__Znwj(8)|0);
 __THREW__ = 0;
 invoke_vii(2484,($18|0),0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if (!($20)) {
  $21 = (($__this) + 108|0);
  HEAP32[$21>>2] = $18;
  $22 = HEAP32[$10>>2]|0;
  (__ZN6il2cpp2os9Semaphore4PostEiPi($22,1,0)|0);
  $23 = HEAP32[$14>>2]|0;
  STACKTOP = sp;return ($23|0);
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZdlPv($18);
 $$0 = $28;$$01 = $29;
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System9ThreadingL11ThreadStartEPv($arg) {
 $arg = $arg|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $exc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exc = sp + 4|0;
 $args = sp;
 $0 = (($arg) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 (__ZN6il2cpp2os9Semaphore4WaitEv($1)|0);
 $2 = HEAP32[$arg>>2]|0;
 __ZN6il2cpp2vm6Thread10InitializeEP12Il2CppThread($2);
 HEAP32[$exc>>2] = 0;
 $3 = (($arg) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$args>>2] = $4;
 $5 = (($arg) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 (__ZN6il2cpp2vm7Runtime14DelegateInvokeEP14Il2CppDelegatePPvPP12Il2CppObject($6,$args,$exc)|0);
 $7 = HEAP32[$exc>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  __ZN6il2cpp2vm7Runtime18UnhandledExceptionEP12Il2CppObject($7);
 }
 $9 = HEAP32[$arg>>2]|0;
 __ZN6il2cpp2vm6Thread12UninitializeEP12Il2CppThread($9);
 $10 = HEAP32[$0>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  __Z20il2cpp_gc_free_fixedPv($arg);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3314,($10|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZdlPv($10);
  ___resumeException($14|0);
  // unreachable;
 }
 __ZdlPv($10);
 __Z20il2cpp_gc_free_fixedPv($arg);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread20Thread_free_internalEP12Il2CppThread12Il2CppIntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(3310,($1|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $7 = ___cxa_find_matching_catch()|0;
    $8 = tempRet0;
    __ZdlPv($1);
    ___resumeException($7|0);
    // unreachable;
   } else {
    __ZdlPv($1);
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 0;
 $5 = HEAP32[$handle>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 __ZdlPv($5);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread19FreeLocalSlotValuesEib($slot,$use_thread_local) {
 $slot = $slot|0;
 $use_thread_local = $use_thread_local|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346168;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread27SetSerializedCurrentCultureEPvP11Il2CppArray($self,$culture) {
 $self = $self|0;
 $culture = $culture|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346200;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread25GetCachedCurrentUICultureEPv($self) {
 $self = $self|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346240;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread29GetSerializedCurrentUICultureEPv($self) {
 $self = $self|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346280;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread25SetCachedCurrentUICultureEPvS5_($self,$culture) {
 $self = $self|0;
 $culture = $culture|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346320;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread29SetSerializedCurrentUICultureEPvP11Il2CppArray($self,$culture) {
 $self = $self|0;
 $culture = $culture|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346360;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread16GetName_internalEPv($self) {
 $self = $self|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346400;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread14Abort_internalEPvP12Il2CppObject($self,$stateInfo) {
 $self = $self|0;
 $stateInfo = $stateInfo|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346432;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread22GetAbortExceptionStateEPv($self) {
 $self = $self|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346456;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread18Interrupt_internalEPv($self) {
 $self = $self|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346488;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread14MemoryBarrier_Ev() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346520;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread15Resume_internalEPv($self) {
 $self = $self|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346544;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread12SpinWait_nopEv() {
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346568;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread16Suspend_internalEPv($self) {
 $self = $self|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346592;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread12VolatileReadEPh($address) {
 $address = $address|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346624;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading6Thread13VolatileWriteEPhh($address,$value) {
 $address = $address|0;
 $value = $value|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 346648;
 (_printf((346048|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading10ThreadPool13GetMaxThreadsEPiS5_($workerThreads,$completionPortThreads) {
 $workerThreads = $workerThreads|0;
 $completionPortThreads = $completionPortThreads|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(346672)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading10ThreadPool13GetMinThreadsEPiS5_($workerThreads,$completionPortThreads) {
 $workerThreads = $workerThreads|0;
 $completionPortThreads = $completionPortThreads|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(346864)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading10ThreadPool13SetMinThreadsEii($workerThreads,$completionPortThreads) {
 $workerThreads = $workerThreads|0;
 $completionPortThreads = $completionPortThreads|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(347056)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading10ThreadPool13SetMaxThreadsEii($workerThreads,$completionPortThreads) {
 $workerThreads = $workerThreads|0;
 $completionPortThreads = $completionPortThreads|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(347248)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading29il2cpp_wait_handle_get_handleEP16Il2CppWaitHandle($handle) {
 $handle = $handle|0;
 var $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $sh = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $sh = sp;
 $1 = HEAP32[347440>>2]|0;
 $2 = ($1|0)!=(0|0);
 $3 = HEAP32[347448>>2]|0;
 $4 = ($3|0)!=(0|0);
 $or$cond = $2 | $4;
 if ($or$cond) {
  $10 = $1;$11 = $3;
 } else {
  $5 = HEAP32[((388944 + 92|0))>>2]|0;
  $6 = (__ZN6il2cpp2vm5Class16GetFieldFromNameEPK8TypeInfoPKc($5,347456)|0);
  HEAP32[347440>>2] = $6;
  $7 = HEAP32[((388944 + 92|0))>>2]|0;
  $8 = (__ZN6il2cpp2vm5Class16GetFieldFromNameEPK8TypeInfoPKc($7,347472)|0);
  HEAP32[347448>>2] = $8;
  $$pr = HEAP32[347440>>2]|0;
  $10 = $$pr;$11 = $8;
 }
 $9 = ($10|0)==(0|0);
 if ($9) {
  __ZN6il2cpp2vm5Field8GetValueEP12Il2CppObjectP9FieldInfoPv($handle,$11,$sh);
  $12 = HEAP32[$sh>>2]|0;
  $13 = (($12) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$0>>2] = $14;
  $15 = $14;
  STACKTOP = sp;return ($15|0);
 } else {
  __ZN6il2cpp2vm5Field8GetValueEP12Il2CppObjectP9FieldInfoPv($handle,$10,$0);
  $$pre = HEAP32[$0>>2]|0;
  $15 = $$pre;
  STACKTOP = sp;return ($15|0);
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading20ExtractOsWaitHandlesEP11Il2CppArray($agg$result,$handles) {
 $agg$result = $agg$result|0;
 $handles = $handles|0;
 var $$0$i$i$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i1 = 0, $i$09 = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($handles)|0);
 HEAP32[$agg$result>>2] = 0;
 $1 = (($agg$result) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($agg$result) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = ($0|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($0>>>0)>(1073741823);
 if ($4) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $5 = $0 << 2;
 $6 = (__Znwj($5)|0);
 HEAP32[$1>>2] = $6;
 HEAP32[$agg$result>>2] = $6;
 $7 = (($6) + ($0<<2)|0);
 HEAP32[$2>>2] = $7;
 $$0$i$i$i = $0;$9 = $6;
 while(1) {
  $8 = ($9|0)==(0|0);
  if ($8) {
   $11 = 0;
  } else {
   HEAP32[$9>>2] = 0;
   $11 = $9;
  }
  $10 = (($11) + 4|0);
  $12 = (($$0$i$i$i) + -1)|0;
  $13 = ($12|0)==(0);
  if ($13) {
   break;
  } else {
   $$0$i$i$i = $12;$9 = $10;
  }
 }
 HEAP32[$1>>2] = $10;
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $i$09 = 0;
 }
 while(1) {
  __THREW__ = 0;
  $14 = (invoke_iiii(1477,($handles|0),4,($i$09|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   break;
  }
  $17 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $18 = (invoke_ii(3005,($17|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   break;
  }
  $21 = HEAP32[$agg$result>>2]|0;
  $22 = (($21) + ($i$09<<2)|0);
  HEAP32[$22>>2] = $18;
  $23 = (($i$09) + 1)|0;
  $24 = ($23>>>0)<($0>>>0);
  if ($24) {
   $i$09 = $23;
  } else {
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$agg$result>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = ($10|0)==($27|0);
 if (!($29)) {
  $__new_last2$i$i$i$i$i1 = $27;
  $30 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($11) + ($30)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $31 = $uglygep3$i$i$i$i$i5 >>> 2;
  $$sum = (0 - ($31))|0;
  $scevgep4$i$i$i$i$i6 = (($11) + ($$sum<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($27);
 ___resumeException($25|0);
 // unreachable;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading10WaitHandle16WaitAny_internalEP11Il2CppArrayib($handles,$ms,$exitContext) {
 $handles = $handles|0;
 $ms = $ms|0;
 $exitContext = $exitContext|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i7 = 0, $i$019$us = 0, $i$019$us$us = 0, $lpad$phi$index = 0, $lpad$phi$index6 = 0, $osWaitHandles = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i8 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i12 = 0, $timeWaitedMs$022$us$us = 0, $timeWaitedMs$022$us26 = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i10 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $osWaitHandles = sp;
 __ZN6il2cpp6icalls8mscorlib6System9Threading20ExtractOsWaitHandlesEP11Il2CppArray($osWaitHandles,$handles);
 __THREW__ = 0;
 $0 = (invoke_i(4)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 24;
  } else {
   __THREW__ = 0;
   invoke_vii(2485,($0|0),32);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    label = 24;
   } else {
    $5 = ($ms|0)!=(-1);
    $6 = ($ms|0)<(-1);
    L4: do {
     if ($6) {
      $$0 = 258;
     } else {
      $7 = (($osWaitHandles) + 4|0);
      $8 = HEAP32[$7>>2]|0;
      $9 = HEAP32[$osWaitHandles>>2]|0;
      $10 = $8;
      $11 = $9;
      $12 = (($10) - ($11))|0;
      $13 = $12 >> 2;
      $14 = ($13|0)==(0);
      do {
       if ($14) {
        if ($5) {
         $timeWaitedMs$022$us26 = 0;
        } else {
         while(1) {
          __THREW__ = 0;
          (invoke_ii(3006,10)|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           break;
          }
         }
         $57 = ___cxa_find_matching_catch()|0;
         $58 = tempRet0;
         $lpad$phi$index = $57;$lpad$phi$index6 = $58;
         break;
        }
        while(1) {
         __THREW__ = 0;
         (invoke_ii(3006,10)|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if ($50) {
          break;
         }
         $51 = (($timeWaitedMs$022$us26) + 10)|0;
         $52 = ($51|0)>($ms|0);
         if ($52) {
          $$0 = 258;
          break L4;
         } else {
          $timeWaitedMs$022$us26 = $51;
         }
        }
        $53 = ___cxa_find_matching_catch()|0;
        $54 = tempRet0;
        $lpad$phi$index = $53;$lpad$phi$index6 = $54;
       } else {
        if ($5) {
         $timeWaitedMs$022$us$us = 0;
        } else {
         $i$019$us = 0;
         while(1) {
          $37 = (($9) + ($i$019$us<<2)|0);
          $38 = HEAP32[$37>>2]|0;
          $39 = HEAP32[$38>>2]|0;
          $40 = (($39) + 16|0);
          $41 = HEAP32[$40>>2]|0;
          __THREW__ = 0;
          $42 = (invoke_ii($41|0,($38|0))|0);
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           label = 20;
           break;
          }
          $34 = (($i$019$us) + 1)|0;
          if ($42) {
           $$0 = $i$019$us;
           break L4;
          }
          $33 = ($34>>>0)<($13>>>0);
          if ($33) {
           $i$019$us = $34;
           continue;
          }
          __THREW__ = 0;
          (invoke_ii(3006,10)|0);
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if ($36) {
           label = 19;
           break;
          } else {
           $i$019$us = 0;
          }
         }
         if ((label|0) == 19) {
          $45 = ___cxa_find_matching_catch()|0;
          $46 = tempRet0;
          $lpad$phi$index = $45;$lpad$phi$index6 = $46;
          break;
         }
         else if ((label|0) == 20) {
          $47 = ___cxa_find_matching_catch()|0;
          $48 = tempRet0;
          $lpad$phi$index = $47;$lpad$phi$index6 = $48;
          break;
         }
        }
        L26: while(1) {
         $i$019$us$us = 0;
         while(1) {
          $19 = (($9) + ($i$019$us$us<<2)|0);
          $20 = HEAP32[$19>>2]|0;
          $21 = HEAP32[$20>>2]|0;
          $22 = (($21) + 16|0);
          $23 = HEAP32[$22>>2]|0;
          __THREW__ = 0;
          $24 = (invoke_ii($23|0,($20|0))|0);
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if ($26) {
           label = 14;
           break L26;
          }
          $28 = (($i$019$us$us) + 1)|0;
          if ($24) {
           $$0 = $i$019$us$us;
           break L4;
          }
          $27 = ($28>>>0)<($13>>>0);
          if ($27) {
           $i$019$us$us = $28;
          } else {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(3006,10)|0);
         $15 = __THREW__; __THREW__ = 0;
         $16 = $15&1;
         if ($16) {
          label = 13;
          break;
         }
         $17 = (($timeWaitedMs$022$us$us) + 10)|0;
         $18 = ($17|0)>($ms|0);
         if ($18) {
          $$0 = 258;
          break L4;
         } else {
          $timeWaitedMs$022$us$us = $17;
         }
        }
        if ((label|0) == 13) {
         $29 = ___cxa_find_matching_catch()|0;
         $30 = tempRet0;
         $lpad$phi$index = $29;$lpad$phi$index6 = $30;
         break;
        }
        else if ((label|0) == 14) {
         $31 = ___cxa_find_matching_catch()|0;
         $32 = tempRet0;
         $lpad$phi$index = $31;$lpad$phi$index6 = $32;
         break;
        }
       }
      } while(0);
      __THREW__ = 0;
      invoke_vii(2486,($0|0),32);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if (!($60)) {
       $$01 = $lpad$phi$index6;$$02 = $lpad$phi$index;$74 = $9;
       break L1;
      }
      $81 = ___cxa_find_matching_catch(0|0)|0;
      $82 = tempRet0;
      ___clang_call_terminate($81);
      // unreachable;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vii(2486,($0|0),32);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     label = 24;
    } else {
     $65 = HEAP32[$osWaitHandles>>2]|0;
     $66 = ($65|0)==(0|0);
     if ($66) {
      STACKTOP = sp;return ($$0|0);
     }
     $67 = (($osWaitHandles) + 4|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ($68|0)==($65|0);
     if (!($69)) {
      $__new_last2$i$i$i$i$i = $65;
      $scevgep$i$i$i$i$i = (($68) + -4|0);
      $70 = (0 - ($__new_last2$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($70)|0);
      $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
      $71 = $uglygep3$i$i$i$i$i >>> 2;
      $72 = $71 ^ -1;
      $scevgep4$i$i$i$i$i = (($68) + ($72<<2)|0);
      HEAP32[$67>>2] = $scevgep4$i$i$i$i$i;
     }
     __ZdlPv($65);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $55 = ___cxa_find_matching_catch()|0;
  $56 = tempRet0;
  $$pre = HEAP32[$osWaitHandles>>2]|0;
  $$01 = $56;$$02 = $55;$74 = $$pre;
 }
 $73 = ($74|0)==(0|0);
 if ($73) {
  ___resumeException($$02|0);
  // unreachable;
 }
 $75 = (($osWaitHandles) + 4|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i7 = $74;
  $scevgep$i$i$i$i$i8 = (($76) + -4|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i7))|0;
  $uglygep$i$i$i$i$i10 = (($scevgep$i$i$i$i$i8) + ($78)|0);
  $uglygep3$i$i$i$i$i11 = $uglygep$i$i$i$i$i10;
  $79 = $uglygep3$i$i$i$i$i11 >>> 2;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i12 = (($76) + ($80<<2)|0);
  HEAP32[$75>>2] = $scevgep4$i$i$i$i$i12;
 }
 __ZdlPv($74);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading10WaitHandle16WaitOne_internalEP12Il2CppObject12Il2CppIntPtrib($unused,$handlePtr,$ms,$exitContext) {
 $unused = $unused|0;
 $handlePtr = $handlePtr|0;
 $ms = $ms|0;
 $exitContext = $exitContext|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$handlePtr>>2]|0;
 $1 = (__ZN6il2cpp2vm6Thread7CurrentEv()|0);
 __ZN6il2cpp2vm6Thread8SetStateEP12Il2CppThreadNS0_11ThreadStateE($1,32);
 $2 = ($ms|0)==(-1);
 if ($2) {
  $3 = HEAP32[$0>>2]|0;
  $4 = (($3) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_ii($5|0,($0|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $$0 = $6;
   __ZN6il2cpp2vm6Thread8ClrStateEP12Il2CppThreadNS0_11ThreadStateE($1,32);
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $13 = HEAP32[$0>>2]|0;
  $14 = (($13) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_iii($15|0,($0|0),($ms|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   $$0 = $16;
   __ZN6il2cpp2vm6Thread8ClrStateEP12Il2CppThreadNS0_11ThreadStateE($1,32);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vii(2486,($1|0),32);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $19 = ___cxa_find_matching_catch(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading10WaitHandle16WaitAll_internalEP11Il2CppArrayib($handles,$ms,$exitContext) {
 $handles = $handles|0;
 $ms = $ms|0;
 $exitContext = $exitContext|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$13 = 0, $$15 = 0, $$2 = 0, $$lcssa = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre85 = 0, $$pre86 = 0, $$pre87 = 0, $$pre88 = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i19 = 0, $cond = 0, $exitcond = 0, $i$066 = 0, $i1$072 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond = 0, $osWaitHandles = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i24 = 0, $scevgep4$i$i$i$i$i3557 = 0;
 var $scevgep4$i$i$i$i$i3558$lcssa = 0, $scevgep4$i$i$i$i$i355865 = 0, $timeWaitedMs$0 = 0, $timeWaitedMs$1 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $osWaitHandles = sp;
 __ZN6il2cpp6icalls8mscorlib6System9Threading20ExtractOsWaitHandlesEP11Il2CppArray($osWaitHandles,$handles);
 __THREW__ = 0;
 $0 = (invoke_i(4)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 23;
  } else {
   __THREW__ = 0;
   invoke_vii(2485,($0|0),32);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    label = 23;
   } else {
    $5 = ($ms|0)!=(-1);
    $6 = (($osWaitHandles) + 4|0);
    $timeWaitedMs$0 = 0;
    L4: while(1) {
     $7 = ($timeWaitedMs$0|0)>($ms|0);
     $or$cond = $5 & $7;
     if ($or$cond) {
      $$2 = 0;
      label = 53;
      break;
     }
     $8 = HEAP32[$6>>2]|0;
     $9 = HEAP32[$osWaitHandles>>2]|0;
     $10 = $8;
     $11 = $9;
     $12 = (($10) - ($11))|0;
     $13 = $12 >> 2;
     $14 = ($13|0)==(0);
     L7: do {
      if ($14) {
       $$lcssa = 0;$scevgep4$i$i$i$i$i3558$lcssa = 0;
      } else {
       $16 = $9;$25 = 0;$32 = 0;$i$066 = 0;$scevgep4$i$i$i$i$i355865 = 0;
       while(1) {
        $15 = (($16) + ($i$066<<2)|0);
        $17 = HEAP32[$15>>2]|0;
        $18 = HEAP32[$17>>2]|0;
        $19 = (($18) + 16|0);
        $20 = HEAP32[$19>>2]|0;
        __THREW__ = 0;
        $21 = (invoke_ii($20|0,($17|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         label = 24;
         break L4;
        }
        do {
         if ($21) {
          $24 = ($scevgep4$i$i$i$i$i355865|0)==($25|0);
          if (!($24)) {
           $26 = ($scevgep4$i$i$i$i$i355865|0)==(0|0);
           if ($26) {
            $29 = 0;
           } else {
            $27 = HEAP32[$15>>2]|0;
            HEAP32[$scevgep4$i$i$i$i$i355865>>2] = $27;
            $29 = $scevgep4$i$i$i$i$i355865;
           }
           $28 = (($29) + 4|0);
           $142 = $25;$143 = $32;$scevgep4$i$i$i$i$i3557 = $28;
           break;
          }
          $30 = $scevgep4$i$i$i$i$i355865;
          $31 = $32;
          $33 = (($30) - ($31))|0;
          $34 = $33 >> 2;
          $35 = (($34) + 1)|0;
          $36 = ($35>>>0)>(1073741823);
          if ($36) {
           label = 13;
           break L4;
          }
          $39 = ($34>>>0)<(536870911);
          if ($39) {
           $40 = $33 >> 1;
           $41 = ($40>>>0)<($35>>>0);
           $42 = $41 ? $35 : $40;
           $43 = ($42|0)==(0);
           if ($43) {
            $$0$i3$i$i = 0;$49 = 0;
           } else {
            $$0$i2$i$i = $42;
            label = 17;
           }
          } else {
           $$0$i2$i$i = 1073741823;
           label = 17;
          }
          if ((label|0) == 17) {
           label = 0;
           $44 = $$0$i2$i$i << 2;
           __THREW__ = 0;
           $45 = (invoke_ii(2988,($44|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if ($47) {
            label = 24;
            break L4;
           }
           $$0$i3$i$i = $$0$i2$i$i;$49 = $45;
          }
          $48 = (($49) + ($34<<2)|0);
          $50 = (($49) + ($$0$i3$i$i<<2)|0);
          $51 = ($48|0)==(0|0);
          if (!($51)) {
           $52 = HEAP32[$15>>2]|0;
           HEAP32[$48>>2] = $52;
          }
          $53 = (($49) + ($35<<2)|0);
          _memcpy(($49|0),($32|0),($33|0))|0;
          $54 = ($32|0)==(0|0);
          if ($54) {
           $142 = $50;$143 = $49;$scevgep4$i$i$i$i$i3557 = $53;
          } else {
           __ZdlPv($32);
           $142 = $50;$143 = $49;$scevgep4$i$i$i$i$i3557 = $53;
          }
         } else {
          $142 = $25;$143 = $32;$scevgep4$i$i$i$i$i3557 = $scevgep4$i$i$i$i$i355865;
         }
        } while(0);
        $65 = (($i$066) + 1)|0;
        $66 = ($65>>>0)<($13>>>0);
        if (!($66)) {
         $$lcssa = $143;$scevgep4$i$i$i$i$i3558$lcssa = $scevgep4$i$i$i$i$i3557;
         break L7;
        }
        $$pre88 = HEAP32[$osWaitHandles>>2]|0;
        $16 = $$pre88;$25 = $142;$32 = $143;$i$066 = $65;$scevgep4$i$i$i$i$i355865 = $scevgep4$i$i$i$i$i3557;
       }
      }
     } while(0);
     $67 = $scevgep4$i$i$i$i$i3558$lcssa;
     $68 = $$lcssa;
     $69 = (($67) - ($68))|0;
     $70 = $69 >> 2;
     $71 = ($70|0)==($13|0);
     if ($71) {
      $$0 = 1;$timeWaitedMs$1 = $timeWaitedMs$0;
     } else {
      $72 = ($70|0)==(0);
      if (!($72)) {
       $$pre = HEAP32[$osWaitHandles>>2]|0;
       $$pre85 = HEAP32[$6>>2]|0;
       $75 = $$pre;$76 = $$pre85;$i1$072 = 0;
       while(1) {
        $73 = (($$lcssa) + ($i1$072<<2)|0);
        $74 = ($75|0)==($76|0);
        L39: do {
         if ($74) {
          $144 = $75;$145 = $76;
         } else {
          $77 = HEAP32[$73>>2]|0;
          $79 = $75;
          while(1) {
           $78 = HEAP32[$79>>2]|0;
           $80 = ($78|0)==($77|0);
           if ($80) {
            break;
           }
           $81 = (($79) + 4|0);
           $82 = ($81|0)==($76|0);
           if ($82) {
            $144 = $75;$145 = $76;
            break L39;
           } else {
            $79 = $81;
           }
          }
          $83 = ($79|0)==($76|0);
          if ($83) {
           $144 = $75;$145 = $76;
          } else {
           $84 = (($79) + 4|0);
           $85 = ($84|0)==($76|0);
           if ($85) {
            $101 = $76;$95 = $79;$97 = $75;
           } else {
            $87 = $84;$90 = $79;
            while(1) {
             $86 = HEAP32[$87>>2]|0;
             $88 = HEAP32[$73>>2]|0;
             $89 = ($86|0)==($88|0);
             if ($89) {
              $146 = $90;
             } else {
              HEAP32[$90>>2] = $86;
              $91 = (($90) + 4|0);
              $146 = $91;
             }
             $92 = (($87) + 4|0);
             $93 = ($92|0)==($76|0);
             if ($93) {
              break;
             } else {
              $87 = $92;$90 = $146;
             }
            }
            $$pre86 = HEAP32[$6>>2]|0;
            $$pre87 = HEAP32[$osWaitHandles>>2]|0;
            $101 = $$pre86;$95 = $146;$97 = $$pre87;
           }
           $94 = $95;
           $96 = $97;
           $98 = (($94) - ($96))|0;
           $99 = $98 >> 2;
           $100 = ($95|0)==($101|0);
           if ($100) {
            $144 = $97;$145 = $101;
           } else {
            $102 = (($97) + ($99<<2)|0);
            $103 = $101;
            $104 = (($103) - ($94))|0;
            $105 = $104 >> 2;
            $$sum$i = (($99) + ($105))|0;
            $106 = (($97) + ($$sum$i<<2)|0);
            $107 = $106;
            $108 = (($103) - ($107))|0;
            $109 = $108 >> 2;
            _memmove(($102|0),($106|0),($108|0))|0;
            $$sum1$i = (($109) + ($99))|0;
            $110 = (($97) + ($$sum1$i<<2)|0);
            $111 = HEAP32[$6>>2]|0;
            $112 = ($111|0)==($110|0);
            if ($112) {
             $144 = $97;$145 = $110;
            } else {
             $__new_last2$i$i$i = $110;
             $scevgep$i$i$i = (($111) + -4|0);
             $113 = (0 - ($__new_last2$i$i$i))|0;
             $uglygep$i$i$i = (($scevgep$i$i$i) + ($113)|0);
             $uglygep3$i$i$i = $uglygep$i$i$i;
             $114 = $uglygep3$i$i$i >>> 2;
             $115 = $114 ^ -1;
             $scevgep4$i$i$i = (($111) + ($115<<2)|0);
             HEAP32[$6>>2] = $scevgep4$i$i$i;
             $144 = $97;$145 = $scevgep4$i$i$i;
            }
           }
          }
         }
        } while(0);
        $116 = (($i1$072) + 1)|0;
        $exitcond = ($116|0)==($70|0);
        if ($exitcond) {
         break;
        } else {
         $75 = $144;$76 = $145;$i1$072 = $116;
        }
       }
      }
      __THREW__ = 0;
      (invoke_ii(3006,10)|0);
      $117 = __THREW__; __THREW__ = 0;
      $118 = $117&1;
      if ($118) {
       label = 25;
       break;
      }
      $119 = (($timeWaitedMs$0) + 10)|0;
      $$0 = 0;$timeWaitedMs$1 = $119;
     }
     $120 = ($$lcssa|0)==(0|0);
     if (!($120)) {
      __ZdlPv($$lcssa);
     }
     $cond = ($$0|0)==(0);
     if ($cond) {
      $timeWaitedMs$0 = $timeWaitedMs$1;
     } else {
      $$2 = 1;
      label = 53;
      break;
     }
    }
    do {
     if ((label|0) == 13) {
      __THREW__ = 0;
      invoke_vi(3308,0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       $61 = ___cxa_find_matching_catch()|0;
       $62 = tempRet0;
       $64 = $32;$lpad$phi$index = $61;$lpad$phi$index3 = $62;
       break;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 24) {
      $57 = ___cxa_find_matching_catch()|0;
      $58 = tempRet0;
      $64 = $32;$lpad$phi$index = $57;$lpad$phi$index3 = $58;
     }
     else if ((label|0) == 25) {
      $59 = ___cxa_find_matching_catch()|0;
      $60 = tempRet0;
      $64 = $$lcssa;$lpad$phi$index = $59;$lpad$phi$index3 = $60;
     }
     else if ((label|0) == 53) {
      __THREW__ = 0;
      invoke_vii(2486,($0|0),32);
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 23;
       break L1;
      }
      $123 = HEAP32[$osWaitHandles>>2]|0;
      $124 = ($123|0)==(0|0);
      if ($124) {
       STACKTOP = sp;return ($$2|0);
      }
      $125 = HEAP32[$6>>2]|0;
      $126 = ($125|0)==($123|0);
      if (!($126)) {
       $__new_last2$i$i$i$i$i19 = $123;
       $scevgep$i$i$i$i$i20 = (($125) + -4|0);
       $127 = (0 - ($__new_last2$i$i$i$i$i19))|0;
       $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($127)|0);
       $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
       $128 = $uglygep3$i$i$i$i$i23 >>> 2;
       $129 = $128 ^ -1;
       $scevgep4$i$i$i$i$i24 = (($125) + ($129<<2)|0);
       HEAP32[$6>>2] = $scevgep4$i$i$i$i$i24;
      }
      __ZdlPv($123);
      STACKTOP = sp;return ($$2|0);
     }
    } while(0);
    $63 = ($64|0)==(0|0);
    if (!($63)) {
     __ZdlPv($64);
    }
    __THREW__ = 0;
    invoke_vii(2486,($0|0),32);
    $130 = __THREW__; __THREW__ = 0;
    $131 = $130&1;
    if ($131) {
     $140 = ___cxa_find_matching_catch(0|0)|0;
     $141 = tempRet0;
     ___clang_call_terminate($140);
     // unreachable;
    } else {
     $$13 = $lpad$phi$index3;$$15 = $lpad$phi$index;$$pre$phiZ2D = $osWaitHandles;
    }
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $55 = ___cxa_find_matching_catch()|0;
  $56 = tempRet0;
  $$13 = $56;$$15 = $55;$$pre$phiZ2D = $osWaitHandles;
 }
 $132 = HEAP32[$$pre$phiZ2D>>2]|0;
 $133 = ($132|0)==(0|0);
 if ($133) {
  ___resumeException($$15|0);
  // unreachable;
 }
 $134 = (($osWaitHandles) + 4|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = ($135|0)==($132|0);
 if (!($136)) {
  $__new_last2$i$i$i$i$i = $132;
  $scevgep$i$i$i$i$i = (($135) + -4|0);
  $137 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($137)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $138 = $uglygep3$i$i$i$i$i >>> 2;
  $139 = $138 ^ -1;
  $scevgep4$i$i$i$i$i = (($135) + ($139<<2)|0);
  HEAP32[$134>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($132);
 ___resumeException($$15|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp6icalls8mscorlib6System9Threading10WaitHandle22SignalAndWait_InternalE12Il2CppIntPtrS5_ib($toSignal,$toWaitOn,$ms,$exitContext) {
 $toSignal = $toSignal|0;
 $toWaitOn = $toWaitOn|0;
 $ms = $ms|0;
 $exitContext = $exitContext|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$toSignal>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($0);
 $4 = HEAP32[$toWaitOn>>2]|0;
 $5 = (__ZN6il2cpp2vm6Thread7CurrentEv()|0);
 __ZN6il2cpp2vm6Thread8SetStateEP12Il2CppThreadNS0_11ThreadStateE($5,32);
 $6 = ($ms|0)==(-1);
 if ($6) {
  $7 = HEAP32[$4>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  __THREW__ = 0;
  $10 = (invoke_ii($9|0,($4|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $$0$i = $10;
   __ZN6il2cpp2vm6Thread8ClrStateEP12Il2CppThreadNS0_11ThreadStateE($5,32);
   STACKTOP = sp;return ($$0$i|0);
  }
 } else {
  $17 = HEAP32[$4>>2]|0;
  $18 = (($17) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  __THREW__ = 0;
  $20 = (invoke_iii($19|0,($4|0),($ms|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $$0$i = $20;
   __ZN6il2cpp2vm6Thread8ClrStateEP12Il2CppThreadNS0_11ThreadStateE($5,32);
   STACKTOP = sp;return ($$0$i|0);
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __THREW__ = 0;
 invoke_vii(2486,($5|0),32);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $23 = ___cxa_find_matching_catch(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN6il2cpp6icalls6System6System11Diagnostics9Stopwatch12GetTimestampEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os4Time31GetTicks100NanosecondsMonotonicEv()|0);
 $1 = tempRet0;
 tempRet0 = $1;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp6icalls6System6System9Threading9Semaphore24CreateSemaphore_internalEiiP12Il2CppStringPb($initialCount,$maximumCount,$name,$created) {
 $initialCount = $initialCount|0;
 $maximumCount = $maximumCount|0;
 $name = $name|0;
 $created = $created|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $semaphore$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$created>>0] = 1;
 $0 = ($name|0)==(0|0);
 if ($0) {
  $1 = (__Znwj(12)|0);
  __THREW__ = 0;
  invoke_viii(1565,($1|0),($initialCount|0),($maximumCount|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   $7 = ___cxa_find_matching_catch()|0;
   $8 = tempRet0;
   __ZdlPv($1);
   ___resumeException($7|0);
   // unreachable;
  } else {
   $semaphore$0 = $1;
  }
 } else {
  $4 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(347496)|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($4);
  $semaphore$0 = 0;
 }
 $5 = (__Znwj(8)|0);
 HEAP32[$5>>2] = ((347888 + 8|0));
 $6 = (($5) + 4|0);
 HEAP32[$6>>2] = $semaphore$0;
 STACKTOP = sp;return ($5|0);
}
function __ZN6il2cpp6icalls6System6System9Threading9Semaphore25ReleaseSemaphore_internalE12Il2CppIntPtriPb($handlePtr,$releaseCount,$fail) {
 $handlePtr = $handlePtr|0;
 $releaseCount = $releaseCount|0;
 $fail = $fail|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $previousCount = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $previousCount = sp;
 $0 = HEAP32[$handlePtr>>2]|0;
 HEAP32[$previousCount>>2] = 0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2os9Semaphore4PostEiPi($2,$releaseCount,$previousCount)|0);
 $4 = $3&1;
 $5 = $4 ^ 1;
 HEAP8[$fail>>0] = $5;
 $6 = HEAP32[$previousCount>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZN6il2cpp6icalls6System6System9Threading9Semaphore22OpenSemaphore_internalEP12Il2CppStringiPi($name,$rights,$error) {
 $name = $name|0;
 $rights = $rights|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc(347696)|0);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($0);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp2os15SemaphoreHandleD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((347888 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3314,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  ___resumeException($5|0);
  // unreachable;
 }
 __ZdlPv($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os15SemaphoreHandleD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((347888 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3314,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($1);
  __ZdlPv($this);
  ___resumeException($5|0);
  // unreachable;
 }
 __ZdlPv($1);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os15SemaphoreHandle4WaitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 (__ZN6il2cpp2os9Semaphore4WaitEv($1)|0);
 STACKTOP = sp;return 1;
}
function __ZN6il2cpp2os15SemaphoreHandle4WaitEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2os9Semaphore4WaitEj($1,$ms)|0);
 $3 = ($2|0)!=(2);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp2os15SemaphoreHandle10IsSignaledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2os9Semaphore10IsSignaledEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2os15SemaphoreHandle6SignalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 (__ZN6il2cpp2os9Semaphore4PostEiPi($1,1,0)|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os11Environment14GetMachineNameEv($agg$result) {
 $agg$result = $agg$result|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2os15EnvironmentImpl14GetMachineNameEv($agg$result);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os11Environment17GetProcessorCountEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os15EnvironmentImpl17GetProcessorCountEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2os11Environment18GetOsVersionStringEv($agg$result) {
 $agg$result = $agg$result|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2os15EnvironmentImpl18GetOsVersionStringEv($agg$result);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os11Environment13GetOsUserNameEv($agg$result) {
 $agg$result = $agg$result|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2os15EnvironmentImpl13GetOsUserNameEv($agg$result);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os5EventC2Ebb($this,$manualReset,$signaled) {
 $this = $this|0;
 $manualReset = $manualReset|0;
 $signaled = $signaled|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(80)|0);
 __THREW__ = 0;
 invoke_viii(1566,($0|0),($manualReset|0),($signaled|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[$this>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2os5EventD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3315,($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 }
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os5Event3SetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os9EventImpl3SetEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os5Event5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os9EventImpl5ResetEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os5Event4WaitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os9EventImpl4WaitEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os5Event4WaitEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os9EventImpl4WaitEj($0,$ms)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os5Event10IsSignaledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os9EventImpl10IsSignaledEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os5Event6SignalEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __ZN6il2cpp2os9EventImpl6SignalEv($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os5MutexC2Eb($this,$initiallyOwned) {
 $this = $this|0;
 $initiallyOwned = $initiallyOwned|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(24)|0);
 __THREW__ = 0;
 invoke_vi(3316,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZdlPv($0);
  ___resumeException($7|0);
  // unreachable;
 }
 HEAP32[$this>>2] = $0;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = 1;
 if (!($initiallyOwned)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2os9MutexImpl4LockEv($0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = ($5|0)==(1);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os5Mutex4LockEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __ZN6il2cpp2os9MutexImpl4LockEv($0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(1);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os5MutexD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3317,($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 }
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os5Mutex7TryLockEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os9MutexImpl7TryLockEv($0)|0);
 if ($1) {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$2>>2]|0;
  $5 = ($4|0)==(1);
  if ($5) {
   HEAP32[$2>>2] = 0;
  }
 }
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os5Mutex6UnlockEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __ZN6il2cpp2os9MutexImpl6UnlockEv($0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 1;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os5Mutex10IsSignaledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2os5Mutex6SignalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __ZN6il2cpp2os9MutexImpl6UnlockEv($0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 1;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9SemaphoreC2Eii($this,$initialValue,$maximumValue) {
 $this = $this|0;
 $initialValue = $initialValue|0;
 $maximumValue = $maximumValue|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(16)|0);
 __THREW__ = 0;
 invoke_vii(2487,($0|0),($initialValue|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  HEAP32[$this>>2] = $0;
  $3 = (($this) + 4|0);
  HEAP32[$3>>2] = $initialValue;
  $4 = (($this) + 8|0);
  HEAP32[$4>>2] = $maximumValue;
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2os9SemaphoreD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3318,($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 }
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9Semaphore4PostEiPi($this,$releaseCount,$previousCount) {
 $this = $this|0;
 $releaseCount = $releaseCount|0;
 $previousCount = $previousCount|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($releaseCount))|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)>($4|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = (__ZN6il2cpp2os13SemaphoreImpl4PostEi($6,$releaseCount)|0);
 $8 = ($previousCount|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$0>>2]|0;
  HEAP32[$previousCount>>2] = $9;
 }
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[$0>>2]|0;
 $11 = (($10) + ($releaseCount))|0;
 HEAP32[$0>>2] = $11;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os9Semaphore4WaitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os13SemaphoreImpl4WaitEv($0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return ($1|0);
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os9Semaphore4WaitEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os13SemaphoreImpl4WaitEj($0,$ms)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return ($1|0);
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$3>>2] = $5;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os9Semaphore10IsSignaledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2os6ThreadC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(8)|0);
 __THREW__ = 0;
 invoke_vi(3319,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[$this>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2os6Thread3RunEPFvPvES2_($this,$func,$arg) {
 $this = $this|0;
 $func = $func|0;
 $arg = $arg|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os10ThreadImpl3RunEPFvPvES2_($0,$func,$arg)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os6Thread4JoinEj($this,$milliseconds) {
 $this = $this|0;
 $milliseconds = $milliseconds|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os10ThreadImpl4JoinEj($0,$milliseconds)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os6Thread5SleepEj($milliseconds) {
 $milliseconds = $milliseconds|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2os10ThreadImpl5SleepEj($milliseconds)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2os16ThreadLocalValueC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(4)|0);
 __THREW__ = 0;
 invoke_vi(3320,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[$this>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2os16ThreadLocalValue8SetValueEPv($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os20ThreadLocalValueImpl8SetValueEPv($0,$value)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os16ThreadLocalValue8GetValueEPPv($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN6il2cpp2os20ThreadLocalValueImpl8GetValueEPPv($0,$value)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os12Cryptography23GetCryptographyProviderEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 347920;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)<(0);
 if ($6) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $7 = $2;
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZN6il2cpp2os12Cryptography24OpenCryptographyProviderEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (_open((347928|0),0,($vararg_buffer|0))|0);
 $1 = ($0|0)<(0);
 $2 = $1 << 31 >> 31;
 $3 = 347920;
 $4 = $3;
 HEAP32[$4>>2] = $0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 STACKTOP = sp;return 1;
}
function __ZN6il2cpp2os12Cryptography27ReleaseCryptographyProviderEPv($provider) {
 $provider = $provider|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os12Cryptography25FillBufferWithRandomBytesEPvjPh($provider,$length,$data) {
 $provider = $provider|0;
 $length = $length|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$0 = 0, $count$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $provider;
 $1 = 347920;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = ($0|0)==($3|0);
 $8 = (0)==($6|0);
 $9 = $7 & $8;
 if ($9) {
  $count$0 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $10 = (($data) + ($count$0)|0);
  $11 = (($length) - ($count$0))|0;
  $12 = (_read(($0|0),($10|0),($11|0))|0);
  $13 = ($12|0)<(0);
  if ($13) {
   $14 = (___errno_location()|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(4);
   if ($16) {
    $count$1 = $count$0;
   } else {
    break;
   }
  } else {
   $17 = (($12) + ($count$0))|0;
   $count$1 = $17;
  }
  $18 = ($count$1>>>0)<($length>>>0);
  if ($18) {
   $count$0 = $count$1;
  } else {
   break;
  }
 }
 $19 = ($12|0)>(-1);
 $$0 = $19;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os9Directory10GetCurrentERNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($directory) {
 $directory = $directory|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_getcwd((0|0),0)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($directory,$0)|0);
 _free($0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp2os15EnvironmentImpl14GetMachineNameEv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i2 = 0, $buf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $buf = sp;
 $0 = (_gethostname(($buf|0),256)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $15 = (_strlen(($buf|0))|0);
  $16 = ($15>>>0)>(4294967279);
  if ($16) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $17 = ($15>>>0)<(11);
  if ($17) {
   $18 = $15 << 1;
   $19 = $18&255;
   HEAP8[$agg$result>>0] = $19;
   $20 = (($agg$result) + 1|0);
   $__p$0$i$i$i2 = $20;
  } else {
   $21 = (($15) + 16)|0;
   $22 = $21 & -16;
   $23 = (__Znwj($22)|0);
   $24 = (($agg$result) + 8|0);
   HEAP32[$24>>2] = $23;
   $25 = $22 | 1;
   HEAP32[$agg$result>>2] = $25;
   $26 = (($agg$result) + 4|0);
   HEAP32[$26>>2] = $15;
   $__p$0$i$i$i2 = $23;
  }
  _memcpy(($__p$0$i$i$i2|0),($buf|0),($15|0))|0;
  $27 = (($__p$0$i$i$i2) + ($15)|0);
  HEAP8[$27>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $2 = (_strlen((0|0))|0);
  $3 = ($2>>>0)>(4294967279);
  if ($3) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $4 = ($2>>>0)<(11);
  if ($4) {
   $5 = $2 << 1;
   $6 = $5&255;
   HEAP8[$agg$result>>0] = $6;
   $7 = (($agg$result) + 1|0);
   $__p$0$i$i$i = $7;
  } else {
   $8 = (($2) + 16)|0;
   $9 = $8 & -16;
   $10 = (__Znwj($9)|0);
   $11 = (($agg$result) + 8|0);
   HEAP32[$11>>2] = $10;
   $12 = $9 | 1;
   HEAP32[$agg$result>>2] = $12;
   $13 = (($agg$result) + 4|0);
   HEAP32[$13>>2] = $2;
   $__p$0$i$i$i = $10;
  }
  _memcpy(($__p$0$i$i$i|0),(0|0),($2|0))|0;
  $14 = (($__p$0$i$i$i) + ($2)|0);
  HEAP8[$14>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2os15EnvironmentImpl17GetProcessorCountEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_sysconf(84)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2os15EnvironmentImpl18GetOsVersionStringEv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $name = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $name = sp;
 $0 = (_uname(($name|0))|0);
 $1 = ($0|0)>(-1);
 if (!($1)) {
  HEAP8[$agg$result>>0] = 14;
  $16 = (($agg$result) + 1|0);
  ;HEAP8[$16+0>>0]=HEAP8[347944+0>>0]|0;HEAP8[$16+1>>0]=HEAP8[347944+1>>0]|0;HEAP8[$16+2>>0]=HEAP8[347944+2>>0]|0;HEAP8[$16+3>>0]=HEAP8[347944+3>>0]|0;HEAP8[$16+4>>0]=HEAP8[347944+4>>0]|0;HEAP8[$16+5>>0]=HEAP8[347944+5>>0]|0;HEAP8[$16+6>>0]=HEAP8[347944+6>>0]|0;
  $17 = (($agg$result) + 8|0);
  HEAP8[$17>>0] = 0;
  STACKTOP = sp;return;
 }
 $2 = (($name) + 130|0);
 $3 = (_strlen(($2|0))|0);
 $4 = ($3>>>0)>(4294967279);
 if ($4) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $5 = ($3>>>0)<(11);
 if ($5) {
  $6 = $3 << 1;
  $7 = $6&255;
  HEAP8[$agg$result>>0] = $7;
  $8 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $8;
 } else {
  $9 = (($3) + 16)|0;
  $10 = $9 & -16;
  $11 = (__Znwj($10)|0);
  $12 = (($agg$result) + 8|0);
  HEAP32[$12>>2] = $11;
  $13 = $10 | 1;
  HEAP32[$agg$result>>2] = $13;
  $14 = (($agg$result) + 4|0);
  HEAP32[$14>>2] = $3;
  $__p$0$i$i$i = $11;
 }
 _memcpy(($__p$0$i$i$i|0),($2|0),($3|0))|0;
 $15 = (($__p$0$i$i$i) + ($3)|0);
 HEAP8[$15>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os15EnvironmentImpl13GetOsUserNameEv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0] = 14;
 $0 = (($agg$result) + 1|0);
 ;HEAP8[$0+0>>0]=HEAP8[347952+0>>0]|0;HEAP8[$0+1>>0]=HEAP8[347952+1>>0]|0;HEAP8[$0+2>>0]=HEAP8[347952+2>>0]|0;HEAP8[$0+3>>0]=HEAP8[347952+3>>0]|0;HEAP8[$0+4>>0]=HEAP8[347952+4>>0]|0;HEAP8[$0+5>>0]=HEAP8[347952+5>>0]|0;HEAP8[$0+6>>0]=HEAP8[347952+6>>0]|0;
 $1 = (($agg$result) + 8|0);
 HEAP8[$1>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9EventImplC2Ebb($this,$manualReset,$signaled) {
 $this = $this|0;
 $manualReset = $manualReset|0;
 $signaled = $signaled|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $attr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $attr = sp;
 $0 = $manualReset&1;
 HEAP8[$this>>0] = $0;
 $1 = (($this) + 4|0);
 $2 = $signaled&1;
 HEAP32[$1>>2] = $2;
 (_pthread_mutexattr_init(($attr|0))|0);
 (_pthread_mutexattr_settype(($attr|0),1)|0);
 $3 = (($this) + 56|0);
 (_pthread_mutex_init(($3|0),($attr|0))|0);
 (_pthread_mutexattr_destroy(($attr|0))|0);
 $4 = (($this) + 8|0);
 (_pthread_cond_init(($4|0),(0|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9EventImplD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 (_pthread_mutex_destroy(($0|0))|0);
 $1 = (($this) + 8|0);
 (_pthread_cond_destroy(($1|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9EventImpl3SetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 (_pthread_mutex_lock(($0|0))|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  HEAP32[$1>>2] = 1;
 }
 $5 = (($this) + 8|0);
 (_pthread_cond_broadcast(($5|0))|0);
 (_pthread_mutex_unlock(($0|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp2os9EventImpl5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 (_pthread_mutex_lock(($0|0))|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(1);
 if ($4) {
  HEAP32[$1>>2] = 0;
 }
 (_pthread_mutex_unlock(($0|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp2os9EventImpl4WaitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 (_pthread_mutex_lock(($0|0))|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 8|0);
  while(1) {
   (_pthread_cond_wait(($4|0),($0|0))|0);
   $5 = HEAP32[$1>>2]|0;
   $6 = ($5|0)==(0);
   if (!($6)) {
    break;
   }
  }
 }
 $7 = HEAP8[$this>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $9 = HEAP32[$1>>2]|0;
  $10 = HEAP32[$1>>2]|0;
  $11 = ($10|0)==(1);
  if ($11) {
   HEAP32[$1>>2] = 0;
  }
 }
 (_pthread_mutex_unlock(($0|0))|0);
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp2os9EventImpl4WaitEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $status$0 = 0, $timeout = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $timeout = sp;
 $0 = (($ms>>>0) / 1000)&-1;
 HEAP32[$timeout>>2] = $0;
 $1 = (($ms>>>0) % 1000)&-1;
 $2 = ($1*1000000)|0;
 $3 = (($timeout) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (($this) + 56|0);
 (_pthread_mutex_lock(($4|0))|0);
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 8|0);
  $9 = (_pthread_cond_timedwait(($8|0),($4|0),($timeout|0))|0);
  $10 = ($9|0)==(110);
  $$ = $10 ? 2 : 0;
  $status$0 = $$;
 } else {
  $status$0 = 0;
 }
 $11 = HEAP8[$this>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = HEAP32[$5>>2]|0;
  $15 = ($14|0)==(1);
  if ($15) {
   HEAP32[$5>>2] = 0;
  }
 }
 (_pthread_mutex_unlock(($4|0))|0);
 STACKTOP = sp;return ($status$0|0);
}
function __ZN6il2cpp2os9EventImpl10IsSignaledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2os9EventImpl6SignalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 (_pthread_mutex_lock(($0|0))|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  HEAP32[$1>>2] = 1;
 }
 $5 = (($this) + 8|0);
 (_pthread_cond_broadcast(($5|0))|0);
 (_pthread_mutex_unlock(($0|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os4File11GetStdErrorEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[347960>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__Znwj(8)|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 HEAP32[347960>>2] = $2;
 HEAP32[$2>>2] = 2;
 $7 = (($2) + 4|0);
 HEAP32[$7>>2] = 2;
 $$0 = $2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os4File11GetStdInputEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[347968>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__Znwj(8)|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 HEAP32[347968>>2] = $2;
 HEAP32[$2>>2] = 0;
 $7 = (($2) + 4|0);
 HEAP32[$7>>2] = 2;
 $$0 = $2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os4File12GetStdOutputEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[347976>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__Znwj(8)|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 HEAP32[347976>>2] = $2;
 HEAP32[$2>>2] = 1;
 $7 = (($2) + 4|0);
 HEAP32[$7>>2] = 2;
 $$0 = $2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os4File13GetAttributesENSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEERNS1_14FileAttributesE($path,$attributes) {
 $path = $path|0;
 $attributes = $attributes|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$attributes>>2] = 0;
 STACKTOP = sp;return 31;
}
function __ZN6il2cpp2os4File11GetFileTypeEPNS0_10FileHandleE($handle) {
 $handle = $handle|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($handle) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os4File5WriteEPNS0_10FileHandleEPci($handle,$buffer,$count) {
 $handle = $handle|0;
 $buffer = $buffer|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$handle>>2]|0;
 $1 = (_write(($0|0),($buffer|0),($count|0))|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os6Locale9GetLocaleEv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $posix_locale$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_getenv((347984|0))|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_getenv((347992|0))|0);
  $3 = ($2|0)==(0|0);
  if ($3) {
   $4 = (_setlocale(6,(0|0))|0);
   $5 = ($4|0)==(0|0);
   if ($5) {
    ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
    STACKTOP = sp;return;
   } else {
    $posix_locale$02 = $4;
   }
  } else {
   $posix_locale$02 = $2;
  }
 } else {
  $posix_locale$02 = $0;
 }
 $6 = (_strcmp(348000,$posix_locale$02)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (_strchr($posix_locale$02,32)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (_strchr($posix_locale$02,47)|0);
   $11 = ($10|0)==(0|0);
   if ($11) {
    $12 = (_strlen(($posix_locale$02|0))|0);
    $13 = ($12>>>0)>(4294967279);
    if ($13) {
     __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
     // unreachable;
    }
    $14 = ($12>>>0)<(11);
    if ($14) {
     $15 = $12 << 1;
     $16 = $15&255;
     HEAP8[$agg$result>>0] = $16;
     $17 = (($agg$result) + 1|0);
     $__p$0$i$i$i = $17;
    } else {
     $18 = (($12) + 16)|0;
     $19 = $18 & -16;
     $20 = (__Znwj($19)|0);
     $21 = (($agg$result) + 8|0);
     HEAP32[$21>>2] = $20;
     $22 = $19 | 1;
     HEAP32[$agg$result>>2] = $22;
     $23 = (($agg$result) + 4|0);
     HEAP32[$23>>2] = $12;
     $__p$0$i$i$i = $20;
    }
    _memcpy(($__p$0$i$i$i|0),($posix_locale$02|0),($12|0))|0;
    $24 = (($__p$0$i$i$i) + ($12)|0);
    HEAP8[$24>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9MutexImplC2Ev($this) {
 $this = $this|0;
 var $attr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $attr = sp;
 (_pthread_mutexattr_init(($attr|0))|0);
 (_pthread_mutexattr_settype(($attr|0),1)|0);
 (_pthread_mutex_init(($this|0),($attr|0))|0);
 (_pthread_mutexattr_destroy(($attr|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9MutexImplD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_destroy(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9MutexImpl4LockEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_lock(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os9MutexImpl7TryLockEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_mutex_trylock(($this|0))|0);
 $1 = ($0|0)==(0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2os9MutexImpl6UnlockEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_unlock(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os13SemaphoreImplC2Ei($this,$initialValue) {
 $this = $this|0;
 $initialValue = $initialValue|0;
 var $sem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $sem = sp;
 (_sem_init(($sem|0),0,($initialValue|0))|0);
 ;HEAP32[$this+0>>2]=HEAP32[$sem+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$sem+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$sem+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$sem+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os13SemaphoreImplD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_sem_destroy(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os13SemaphoreImpl4PostEi($this,$releaseCount) {
 $this = $this|0;
 $releaseCount = $releaseCount|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($releaseCount|0)>(0);
 L1: do {
  if ($0) {
   $i$01 = 0;
   while(1) {
    $3 = (_sem_post(($this|0))|0);
    $4 = ($3|0)==(-1);
    $2 = (($i$01) + 1)|0;
    if ($4) {
     $$0 = 0;
     break L1;
    }
    $1 = ($2|0)<($releaseCount|0);
    if ($1) {
     $i$01 = $2;
    } else {
     $$0 = 1;
     break;
    }
   }
  } else {
   $$0 = 1;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os13SemaphoreImpl4WaitEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_sem_wait(($this|0))|0);
 $1 = ($0|0)==(-1);
 $$ = $1&1;
 STACKTOP = sp;return ($$|0);
}
function __ZN6il2cpp2os13SemaphoreImpl4WaitEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $timeout = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $timeout = sp;
 $0 = (($ms>>>0) / 1000)&-1;
 HEAP32[$timeout>>2] = $0;
 $1 = (($ms>>>0) % 1000)&-1;
 $2 = ($1*1000000)|0;
 $3 = (($timeout) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (_sem_timedwait(($this|0),($timeout|0))|0);
 $5 = ($4|0)==(-1);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (___errno_location()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(110);
 $$ = $8 ? 2 : 1;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os10ThreadImplC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os10ThreadImpl3RunEPFvPvES2_($this,$func,$arg) {
 $this = $this|0;
 $func = $func|0;
 $arg = $arg|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $attr = 0, $threadId = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $attr = sp + 4|0;
 $threadId = sp;
 $0 = (_malloc(8)|0);
 HEAP32[$0>>2] = $func;
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = $arg;
 $2 = (_pthread_attr_init(($attr|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (_pthread_create(($threadId|0),($attr|0),(3007|0),($0|0))|0);
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = (_pthread_attr_destroy(($attr|0))|0);
   $7 = ($6|0)==(0);
   if ($7) {
    $8 = HEAP32[$threadId>>2]|0;
    HEAP32[$this>>2] = $8;
    $$0 = 0;
   } else {
    $$0 = 31;
   }
  } else {
   $$0 = 31;
  }
 } else {
  $$0 = 31;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2osL18ThreadStartWrapperEPv($arg) {
 $arg = $arg|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$arg>>2]|0;
 $1 = (($arg) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$0 & 4095]($2);
 _free($arg);
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp2os10ThreadImpl4JoinEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $res = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $res = sp;
 HEAP32[$res>>2] = 0;
 $0 = HEAP32[$this>>2]|0;
 $1 = (_pthread_join(($0|0),($res|0))|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 4|0);
 HEAP8[$3>>0] = 1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2os10ThreadImpl5SleepEj($milliseconds) {
 $milliseconds = $milliseconds|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $t = sp;
 $0 = (($milliseconds>>>0) / 1000)&-1;
 HEAP32[$t>>2] = $0;
 $1 = (($milliseconds>>>0) % 1000)&-1;
 $2 = ($1*1000000)|0;
 $3 = (($t) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (_nanosleep(($t|0),(0|0))|0);
 $5 = ($4|0)==(0);
 $$ = $5 ? 0 : 31;
 STACKTOP = sp;return ($$|0);
}
function __ZN6il2cpp2os20ThreadLocalValueImplC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $key = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $key = sp;
 (_pthread_key_create(($key|0),(0|0))|0);
 $0 = HEAP32[$key>>2]|0;
 HEAP32[$this>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2os20ThreadLocalValueImpl8SetValueEPv($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (_pthread_setspecific(($0|0),($value|0))|0);
 $2 = ($1|0)==(0);
 $$ = $2 ? 0 : 31;
 STACKTOP = sp;return ($$|0);
}
function __ZN6il2cpp2os20ThreadLocalValueImpl8GetValueEPPv($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (_pthread_getspecific(($0|0))|0);
 HEAP32[$value>>2] = $1;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp2os4Time29GetTicksMillisecondsMonotonicEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = 348008;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($2|0)==(0);
 $7 = ($5|0)==(0);
 $8 = $6 & $7;
 if ($8) {
  HEAP32[$vararg_buffer>>2] = 348056;
  (_printf((348032|0),($vararg_buffer|0))|0);
  $9 = 348008;
  $10 = $9;
  HEAP32[$10>>2] = -1294967296;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = 0;
 }
 $13 = (__ZN6il2cpp2os4Time31GetTicks100NanosecondsMonotonicEv()|0);
 $14 = tempRet0;
 $15 = 348008;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (_i64Subtract(($13|0),($14|0),($17|0),($20|0))|0);
 $22 = tempRet0;
 $23 = (___divdi3(($21|0),($22|0),10000,0)|0);
 $24 = tempRet0;
 STACKTOP = sp;return ($23|0);
}
function __ZN6il2cpp2os4Time31GetTicks100NanosecondsMonotonicEv() {
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tspec = 0;
 var $tv = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tv = sp + 8|0;
 $tspec = sp;
 $0 = HEAP32[((348016 + 4|0))>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (_clock_getres(1,(348016|0))|0);
  $3 = ($2|0)==(0);
  $4 = $3&1;
  HEAP32[348024>>2] = $4;
  $6 = $4;
 } else {
  $$pr = HEAP32[348024>>2]|0;
  $6 = $$pr;
 }
 $5 = ($6|0)==(0);
 if (!($5)) {
  $7 = (_clock_gettime(1,($tspec|0))|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = HEAP32[$tspec>>2]|0;
   $10 = ($9|0)<(0);
   $11 = $10 << 31 >> 31;
   $12 = (___muldi3(($9|0),($11|0),10000000,0)|0);
   $13 = tempRet0;
   $14 = (($tspec) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15|0) / 100)&-1;
   $17 = ($16|0)<(0);
   $18 = $17 << 31 >> 31;
   $19 = (_i64Add(($16|0),($18|0),($12|0),($13|0))|0);
   $20 = tempRet0;
   $36 = $20;$37 = $19;
   tempRet0 = $36;
   STACKTOP = sp;return ($37|0);
  }
 }
 $21 = (_gettimeofday(($tv|0),(0|0))|0);
 $22 = ($21|0)==(0);
 if (!($22)) {
  $36 = 0;$37 = 0;
  tempRet0 = $36;
  STACKTOP = sp;return ($37|0);
 }
 $23 = HEAP32[$tv>>2]|0;
 $24 = ($23|0)<(0);
 $25 = $24 << 31 >> 31;
 $26 = (___muldi3(($23|0),($25|0),1000000,0)|0);
 $27 = tempRet0;
 $28 = (($tv) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)<(0);
 $31 = $30 << 31 >> 31;
 $32 = (_i64Add(($26|0),($27|0),($29|0),($31|0))|0);
 $33 = tempRet0;
 $34 = (___muldi3(($32|0),($33|0),10,0)|0);
 $35 = tempRet0;
 $36 = $35;$37 = $34;
 tempRet0 = $36;
 STACKTOP = sp;return ($37|0);
}
function __ZN6il2cpp2os4Time30GetTicks100NanosecondsDateTimeEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tv = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tv = sp;
 $0 = (_gettimeofday(($tv|0),(0|0))|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $17 = 0;$18 = 0;
  tempRet0 = $17;
  STACKTOP = sp;return ($18|0);
 }
 $2 = HEAP32[$tv>>2]|0;
 $3 = ($2|0)<(0);
 $4 = $3 << 31 >> 31;
 $5 = (___muldi3(($2|0),($4|0),1000000,0)|0);
 $6 = tempRet0;
 $7 = (_i64Add(($5|0),($6|0),-13910016,14467070)|0);
 $8 = tempRet0;
 $9 = (($tv) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)<(0);
 $12 = $11 << 31 >> 31;
 $13 = (_i64Add(($7|0),($8|0),($10|0),($12|0))|0);
 $14 = tempRet0;
 $15 = (___muldi3(($13|0),($14|0),10,0)|0);
 $16 = tempRet0;
 $17 = $16;$18 = $15;
 tempRet0 = $17;
 STACKTOP = sp;return ($18|0);
}
function __ZN6il2cpp2os8TimeZone15GetTimeZoneDataEiPxPNSt3__112basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE($year,$data,$names) {
 $year = $year|0;
 $data = $data|0;
 $names = $names|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $day$012 = 0, $g$i7 = 0, $gmtoff$010 = 0, $gmtoff$2 = 0;
 var $is_daylight$011 = 0, $is_daylight$2 = 0, $or$cond = 0, $start = 0, $t = 0, $t1 = 0, $tt = 0, $tzone = 0, $year$off = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 140|0;
 $g$i7 = sp;
 $start = sp + 44|0;
 $tt = sp + 88|0;
 $t = sp + 132|0;
 $tzone = sp + 144|0;
 $t1 = sp + 136|0;
 dest=$start+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $1 = (($start) + 12|0);
 HEAP32[$1>>2] = 1;
 $2 = (($year) + -1900)|0;
 $3 = (($start) + 20|0);
 HEAP32[$3>>2] = $2;
 $4 = (_mktime(($start|0))|0);
 HEAP32[$t>>2] = $4;
 $year$off = (($year) + -1970)|0;
 $5 = ($year$off>>>0)>(67);
 $6 = ($4|0)==(-1);
 $or$cond = $5 | $6;
 if ($or$cond) {
  $7 = (_time((0|0))|0);
  HEAP32[$t>>2] = $7;
  $8 = (_localtime(($t|0))|0);
  dest=$tt+0|0; src=$8+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  (_strftime(($tzone|0),64,(348072|0),($tt|0))|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($names,$tzone)|0);
  $9 = (($names) + 12|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($9,$tzone)|0);
  STACKTOP = sp;return 1;
 }
 HEAP32[$0>>2] = $4;
 $10 = (_gmtime(($0|0))|0);
 dest=$g$i7+0|0; src=$10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $11 = (($start) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($g$i7) + 32|0);
 HEAP32[$13>>2] = $12;
 $14 = (_mktime(($g$i7|0))|0);
 $15 = HEAP32[$0>>2]|0;
 $16 = (+_difftime(($15|0),($14|0)));
 $17 = (~~(($16)));
 $18 = (($tt) + 32|0);
 $19 = (($g$i7) + 32|0);
 $20 = (($g$i7) + 32|0);
 $21 = (($g$i7) + 32|0);
 $22 = (($names) + 12|0);
 $23 = (($data) + 16|0);
 $24 = (($g$i7) + 32|0);
 $25 = (($data) + 24|0);
 $26 = (($g$i7) + 32|0);
 $day$012 = 0;$gmtoff$010 = $17;$is_daylight$011 = 0;
 while(1) {
  $27 = HEAP32[$t>>2]|0;
  $28 = (($27) + 86400)|0;
  HEAP32[$t>>2] = $28;
  $29 = (_localtime(($t|0))|0);
  dest=$tt+0|0; src=$29+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $30 = HEAP32[$t>>2]|0;
  HEAP32[$0>>2] = $30;
  $31 = (_gmtime(($0|0))|0);
  dest=$g$i7+0|0; src=$31+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $32 = HEAP32[$18>>2]|0;
  HEAP32[$19>>2] = $32;
  $33 = (_mktime(($g$i7|0))|0);
  $34 = HEAP32[$0>>2]|0;
  $35 = (+_difftime(($34|0),($33|0)));
  $36 = (~~(($35)));
  $37 = ($36|0)==($gmtoff$010|0);
  if ($37) {
   $gmtoff$2 = $gmtoff$010;$is_daylight$2 = $is_daylight$011;
  } else {
   $38 = HEAP32[$t>>2]|0;
   HEAP32[$t1>>2] = $38;
   $40 = $38;
   while(1) {
    $39 = (($40) + -3600)|0;
    HEAP32[$t1>>2] = $39;
    $41 = (_localtime(($t1|0))|0);
    $42 = (($41) + 32|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$t1>>2]|0;
    HEAP32[$0>>2] = $44;
    $45 = (_gmtime(($0|0))|0);
    dest=$g$i7+0|0; src=$45+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$20>>2] = $43;
    $46 = (_mktime(($g$i7|0))|0);
    $47 = HEAP32[$0>>2]|0;
    $48 = (+_difftime(($47|0),($46|0)));
    $49 = (~~(($48)));
    $50 = ($49|0)==($gmtoff$010|0);
    if ($50) {
     break;
    }
    $$pre = HEAP32[$t1>>2]|0;
    $40 = $$pre;
   }
   while(1) {
    $51 = HEAP32[$t1>>2]|0;
    $52 = (($51) + 60)|0;
    HEAP32[$t1>>2] = $52;
    $53 = (_localtime(($t1|0))|0);
    $54 = (($53) + 32|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$t1>>2]|0;
    HEAP32[$0>>2] = $56;
    $57 = (_gmtime(($0|0))|0);
    dest=$g$i7+0|0; src=$57+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$21>>2] = $55;
    $58 = (_mktime(($g$i7|0))|0);
    $59 = HEAP32[$0>>2]|0;
    $60 = (+_difftime(($59|0),($58|0)));
    $61 = (~~(($60)));
    $62 = ($61|0)==($gmtoff$010|0);
    if (!($62)) {
     break;
    }
   }
   $63 = HEAP32[$t1>>2]|0;
   $64 = (($63) + ($gmtoff$010))|0;
   HEAP32[$t1>>2] = $64;
   (_strftime(($tzone|0),64,(348072|0),($tt|0))|0);
   $65 = ($is_daylight$011|0)==(0);
   if (!($65)) {
    label = 11;
    break;
   }
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($22,$tzone)|0);
   $66 = HEAP32[$t1>>2]|0;
   $67 = ($66|0)<(0);
   $68 = $67 << 31 >> 31;
   $69 = (___muldi3(($66|0),($68|0),10000000,0)|0);
   $70 = tempRet0;
   $71 = (_i64Add(($69|0),($70|0),-139100160,144670709)|0);
   $72 = tempRet0;
   $73 = $data;
   $74 = $73;
   HEAP32[$74>>2] = $71;
   $75 = (($73) + 4)|0;
   $76 = $75;
   HEAP32[$76>>2] = $72;
   $77 = ($gmtoff$010|0)<(0);
   $78 = $77 << 31 >> 31;
   $79 = (___muldi3(($gmtoff$010|0),($78|0),10000000,0)|0);
   $80 = tempRet0;
   $81 = $23;
   $82 = $81;
   HEAP32[$82>>2] = $79;
   $83 = (($81) + 4)|0;
   $84 = $83;
   HEAP32[$84>>2] = $80;
   $85 = HEAP32[$t>>2]|0;
   HEAP32[$0>>2] = $85;
   $86 = (_gmtime(($0|0))|0);
   dest=$g$i7+0|0; src=$86+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $87 = HEAP32[$18>>2]|0;
   HEAP32[$24>>2] = $87;
   $88 = (_mktime(($g$i7|0))|0);
   $89 = HEAP32[$0>>2]|0;
   $90 = (+_difftime(($89|0),($88|0)));
   $91 = (~~(($90)));
   $92 = (($91) - ($gmtoff$010))|0;
   $93 = ($92|0)<(0);
   $94 = $93 << 31 >> 31;
   $95 = (___muldi3(($92|0),($94|0),10000000,0)|0);
   $96 = tempRet0;
   $97 = $25;
   $98 = $97;
   HEAP32[$98>>2] = $95;
   $99 = (($97) + 4)|0;
   $100 = $99;
   HEAP32[$100>>2] = $96;
   $101 = HEAP32[$t>>2]|0;
   HEAP32[$0>>2] = $101;
   $102 = (_gmtime(($0|0))|0);
   dest=$g$i7+0|0; src=$102+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $103 = HEAP32[$18>>2]|0;
   HEAP32[$26>>2] = $103;
   $104 = (_mktime(($g$i7|0))|0);
   $105 = HEAP32[$0>>2]|0;
   $106 = (+_difftime(($105|0),($104|0)));
   $107 = (~~(($106)));
   $gmtoff$2 = $107;$is_daylight$2 = 1;
  }
  $120 = (($day$012) + 1)|0;
  $121 = ($120|0)<(365);
  if ($121) {
   $day$012 = $120;$gmtoff$010 = $gmtoff$2;$is_daylight$011 = $is_daylight$2;
  } else {
   break;
  }
 }
 if ((label|0) == 11) {
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($names,$tzone)|0);
  $108 = HEAP32[$t1>>2]|0;
  $109 = ($108|0)<(0);
  $110 = $109 << 31 >> 31;
  $111 = (___muldi3(($108|0),($110|0),10000000,0)|0);
  $112 = tempRet0;
  $113 = (_i64Add(($111|0),($112|0),-139100160,144670709)|0);
  $114 = tempRet0;
  $115 = (($data) + 8|0);
  $116 = $115;
  $117 = $116;
  HEAP32[$117>>2] = $113;
  $118 = (($116) + 4)|0;
  $119 = $118;
  HEAP32[$119>>2] = $114;
  STACKTOP = sp;return 1;
 }
 $122 = ($is_daylight$2|0)==(0);
 if (!($122)) {
  STACKTOP = sp;return 1;
 }
 (_strftime(($tzone|0),64,(348072|0),($tt|0))|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($names,$tzone)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($22,$tzone)|0);
 $123 = ($gmtoff$2|0)<(0);
 $124 = $123 << 31 >> 31;
 $125 = (___muldi3(($gmtoff$2|0),($124|0),10000000,0)|0);
 $126 = tempRet0;
 ;HEAP32[$data+0>>2]=0|0;HEAP32[$data+4>>2]=0|0;HEAP32[$data+8>>2]=0|0;HEAP32[$data+12>>2]=0|0;
 $127 = $23;
 $128 = $127;
 HEAP32[$128>>2] = $125;
 $129 = (($127) + 4)|0;
 $130 = $129;
 HEAP32[$130>>2] = $126;
 $131 = $25;
 $132 = $131;
 HEAP32[$132>>2] = 0;
 $133 = (($131) + 4)|0;
 $134 = $133;
 HEAP32[$134>>2] = 0;
 STACKTOP = sp;return 1;
}
function __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i($this,$Initialize,$Cleanup,$order) {
 $this = $this|0;
 $Initialize = $Initialize|0;
 $Cleanup = $Cleanup|0;
 $order = $order|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 HEAP32[$1>>2] = $Initialize;
 $2 = HEAP32[348080>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = (__Znwj(12)|0);
  $5 = (($4) + 4|0);
  HEAP32[$5>>2] = 0;
  $6 = (($4) + 8|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$4>>2] = $5;
  HEAP32[348080>>2] = $4;
  $7 = $4;
 } else {
  $7 = $2;
 }
 __ZNSt3__16__treeIPFvvENS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_($0,$7,$1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanup22ExecuteInitializationsEv() {
 var $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[348080>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($0) + 4|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $1;
 }
 while(1) {
  $4 = (($5) + 16|0);
  $6 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_v[$6 & 1023]();
  $7 = (($5) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $$01$i$i = $5;
   while(1) {
    $12 = (($$01$i$i) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($$01$i$i|0);
    if ($15) {
     $$0$i$i = $13;
     break;
    } else {
     $$01$i$i = $13;
    }
   }
  } else {
   $$0$i$i$i = $8;
   while(1) {
    $10 = HEAP32[$$0$i$i$i>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $10;
    }
   }
  }
  $16 = HEAP32[348080>>2]|0;
  $17 = (($16) + 4|0);
  $18 = ($$0$i$i|0)==($17|0);
  if ($18) {
   break;
  } else {
   $5 = $$0$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeIPFvvENS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3>>>0)<($5>>>0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5>>>0)<($3>>>0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $31 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $30 = (($agg$result) + 4|0);
  HEAP8[$30>>0] = $31;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(20)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__v>>2]|0;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $31 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $30 = (($agg$result) + 4|0);
 HEAP8[$30>>0] = $31;
 STACKTOP = sp;return;
}
function __ZN6il2cpp5utils11StringUtils4HashEPKc($str) {
 $str = $str|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $hash$0$lcssa = 0, $hash$01 = 0, $ustr$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$str>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $hash$0$lcssa = 5381;
  STACKTOP = sp;return ($hash$0$lcssa|0);
 } else {
  $3 = $0;$hash$01 = 5381;$ustr$02 = $str;
 }
 while(1) {
  $2 = $3&255;
  $4 = (($ustr$02) + 1|0);
  $5 = ($hash$01*33)|0;
  $6 = (($2) + ($5))|0;
  $7 = HEAP8[$4>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $hash$0$lcssa = $6;
   break;
  } else {
   $3 = $7;$hash$01 = $6;$ustr$02 = $4;
  }
 }
 STACKTOP = sp;return ($hash$0$lcssa|0);
}
function __ZN6il2cpp5utils11StringUtils6PrintfEPKcz($agg$result,$format,$varargs) {
 $agg$result = $agg$result|0;
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i10 = 0, $__p$0$i$i$i5 = 0, $args = 0, $buf = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $args = sp + 16|0;
 $ret = sp;
 $buf = sp + 32|0;
 ;HEAP32[$ret+0>>2]=0|0;HEAP32[$ret+4>>2]=0|0;HEAP32[$ret+8>>2]=0|0;
 HEAP32[$args>>2] = $varargs;
 $0 = (_vsnprintf($buf,0,$format,$args)|0);
 $1 = ($0|0)==(-1);
 L1: do {
  if ($1) {
   $2 = (_strlen((0|0))|0);
   $3 = ($2>>>0)>(4294967279);
   if ($3) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     label = 10;
     break;
    }
    // unreachable;
   }
   $6 = ($2>>>0)<(11);
   if ($6) {
    $7 = $2 << 1;
    $8 = $7&255;
    HEAP8[$agg$result>>0] = $8;
    $9 = (($agg$result) + 1|0);
    $__p$0$i$i$i = $9;
   } else {
    $10 = (($2) + 16)|0;
    $11 = $10 & -16;
    __THREW__ = 0;
    $12 = (invoke_ii(2988,($11|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 10;
     break;
    }
    $15 = (($agg$result) + 8|0);
    HEAP32[$15>>2] = $12;
    $16 = $11 | 1;
    HEAP32[$agg$result>>2] = $16;
    $17 = (($agg$result) + 4|0);
    HEAP32[$17>>2] = $2;
    $__p$0$i$i$i = $12;
   }
   _memcpy(($__p$0$i$i$i|0),(0|0),($2|0))|0;
   $18 = (($__p$0$i$i$i) + ($2)|0);
   HEAP8[$18>>0] = 0;
   label = 42;
  } else {
   $26 = (($0) + 1)|0;
   $27 = HEAP8[$ret>>0]|0;
   $28 = $27 & 1;
   $29 = ($28<<24>>24)==(0);
   if ($29) {
    $32 = $27&255;
    $33 = $32 >>> 1;
    $35 = $33;
   } else {
    $30 = (($ret) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $35 = $31;
   }
   $34 = ($35>>>0)<($26>>>0);
   do {
    if ($34) {
     $36 = (($26) - ($35))|0;
     __THREW__ = 0;
     (invoke_iiii(1479,($ret|0),($36|0),0)|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 10;
      break L1;
     }
    } else {
     if ($29) {
      $43 = ((($ret) + ($26)|0) + 1|0);
      HEAP8[$43>>0] = 0;
      $44 = $26 << 1;
      $45 = $44&255;
      HEAP8[$ret>>0] = $45;
      break;
     } else {
      $39 = (($ret) + 8|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + ($26)|0);
      HEAP8[$41>>0] = 0;
      $42 = (($ret) + 4|0);
      HEAP32[$42>>2] = $26;
      break;
     }
    }
   } while(0);
   $46 = HEAP8[$ret>>0]|0;
   $47 = $46 & 1;
   $48 = ($47<<24>>24)==(0);
   if ($48) {
    $53 = (($ret) + 1|0);
    $54 = $46&255;
    $55 = $54 >>> 1;
    $56 = $53;$57 = $55;
   } else {
    $49 = (($ret) + 8|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($ret) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    $56 = $50;$57 = $52;
   }
   $58 = (_vsnprintf($56,$57,$format,$args)|0);
   $59 = ($58|0)==(-1);
   if ($59) {
    $60 = (_strlen((0|0))|0);
    $61 = ($60>>>0)>(4294967279);
    if ($61) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      label = 10;
      break;
     }
     // unreachable;
    }
    $64 = ($60>>>0)<(11);
    if ($64) {
     $65 = $60 << 1;
     $66 = $65&255;
     HEAP8[$agg$result>>0] = $66;
     $67 = (($agg$result) + 1|0);
     $__p$0$i$i$i5 = $67;
    } else {
     $68 = (($60) + 16)|0;
     $69 = $68 & -16;
     __THREW__ = 0;
     $70 = (invoke_ii(2988,($69|0))|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      label = 10;
      break;
     }
     $73 = (($agg$result) + 8|0);
     HEAP32[$73>>2] = $70;
     $74 = $69 | 1;
     HEAP32[$agg$result>>2] = $74;
     $75 = (($agg$result) + 4|0);
     HEAP32[$75>>2] = $60;
     $__p$0$i$i$i5 = $70;
    }
    _memcpy(($__p$0$i$i$i5|0),(0|0),($60|0))|0;
    $76 = (($__p$0$i$i$i5) + ($60)|0);
    HEAP8[$76>>0] = 0;
    label = 42;
    break;
   }
   $77 = HEAP8[$ret>>0]|0;
   $78 = $77 & 1;
   $79 = ($78<<24>>24)==(0);
   if ($79) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$ret+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$ret+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$ret+8>>2]|0;
    label = 42;
    break;
   }
   $80 = (($ret) + 8|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($ret) + 4|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83>>>0)>(4294967279);
   if ($84) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     label = 10;
     break;
    }
    // unreachable;
   }
   $87 = ($83>>>0)<(11);
   if ($87) {
    $88 = $83 << 1;
    $89 = $88&255;
    HEAP8[$agg$result>>0] = $89;
    $90 = (($agg$result) + 1|0);
    $__p$0$i$i$i10 = $90;
   } else {
    $91 = (($83) + 16)|0;
    $92 = $91 & -16;
    __THREW__ = 0;
    $93 = (invoke_ii(2988,($92|0))|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 10;
     break;
    }
    $96 = (($agg$result) + 8|0);
    HEAP32[$96>>2] = $93;
    $97 = $92 | 1;
    HEAP32[$agg$result>>2] = $97;
    $98 = (($agg$result) + 4|0);
    HEAP32[$98>>2] = $83;
    $__p$0$i$i$i10 = $93;
   }
   _memcpy(($__p$0$i$i$i10|0),($81|0),($83|0))|0;
   $99 = (($__p$0$i$i$i10) + ($83)|0);
   HEAP8[$99>>0] = 0;
   label = 42;
  }
 } while(0);
 if ((label|0) == 10) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP8[$ret>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   ___resumeException($19|0);
   // unreachable;
  }
  $24 = (($ret) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  __ZdlPv($25);
  ___resumeException($19|0);
  // unreachable;
 }
 else if ((label|0) == 42) {
  $100 = HEAP8[$ret>>0]|0;
  $101 = $100 & 1;
  $102 = ($101<<24>>24)==(0);
  if ($102) {
   STACKTOP = sp;return;
  }
  $103 = (($ret) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  __ZdlPv($104);
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp5utils11StringUtils11Utf16ToUtf8EPKt($agg$result,$utf16String) {
 $agg$result = $agg$result|0;
 $utf16String = $utf16String|0;
 var $$off0 = 0, $$off011 = 0, $$phi$trans$insert = 0, $$phi$trans$insert8 = 0, $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond7 = 0, $extract$t10 = 0, $extract$t12 = 0;
 var $extract$t13 = 0, $i$01 = 0, $i$01$us = 0, $len$0$lcssa1415 = 0, $len$0$lcssa141617 = 0, $len$03 = 0, $ptr$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$utf16String>>1]|0;
 $1 = ($0<<16>>16)==(0);
 if ($1) {
  $len$0$lcssa1415 = 0;
  label = 7;
 } else {
  $len$03 = 0;$ptr$02 = $utf16String;
  while(1) {
   $2 = (($ptr$02) + 2|0);
   $3 = (($len$03) + 1)|0;
   $4 = HEAP16[$2>>1]|0;
   $5 = ($4<<16>>16)==(0);
   if ($5) {
    break;
   } else {
    $len$03 = $3;$ptr$02 = $2;
   }
  }
  $6 = ($3>>>0)>(4294967279);
  if ($6) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $7 = ($3>>>0)<(11);
  if ($7) {
   $len$0$lcssa1415 = $3;
   label = 7;
  } else {
   $8 = (($len$03) + 17)|0;
   $9 = $8 & -16;
   $10 = (__Znwj($9)|0);
   $11 = (($agg$result) + 8|0);
   HEAP32[$11>>2] = $10;
   $12 = $9 | 1;
   HEAP32[$agg$result>>2] = $12;
   $13 = (($agg$result) + 4|0);
   HEAP32[$13>>2] = $3;
   $14 = $12&255;
   _memset(($10|0),0,($3|0))|0;
   $15 = (($10) + ($3)|0);
   HEAP8[$15>>0] = 0;
   $22 = $14;$len$0$lcssa141617 = $3;
  }
 }
 if ((label|0) == 7) {
  $16 = $len$0$lcssa1415 << 1;
  $17 = $16&255;
  HEAP8[$agg$result>>0] = $17;
  $18 = (($agg$result) + 1|0);
  _memset(($18|0),0,($len$0$lcssa1415|0))|0;
  $19 = ((($agg$result) + ($len$0$lcssa1415)|0) + 1|0);
  HEAP8[$19>>0] = 0;
  $20 = ($len$0$lcssa1415|0)==(0);
  if ($20) {
   STACKTOP = sp;return;
  } else {
   $22 = $17;$len$0$lcssa141617 = $len$0$lcssa1415;
  }
 }
 $21 = $22 & 1;
 $23 = ($21<<24>>24)==(0);
 $24 = (($agg$result) + 8|0);
 $extract$t12 = $0&255;
 if ($23) {
  $$off011 = $extract$t12;$i$01$us = 0;
  while(1) {
   $25 = ((($agg$result) + ($i$01$us)|0) + 1|0);
   HEAP8[$25>>0] = $$off011;
   $26 = (($i$01$us) + 1)|0;
   $exitcond7 = ($26|0)==($len$0$lcssa141617|0);
   if ($exitcond7) {
    break;
   }
   $$phi$trans$insert = (($utf16String) + ($26<<1)|0);
   $$pre = HEAP16[$$phi$trans$insert>>1]|0;
   $extract$t13 = $$pre&255;
   $$off011 = $extract$t13;$i$01$us = $26;
  }
  STACKTOP = sp;return;
 } else {
  $$off0 = $extract$t12;$i$01 = 0;
  while(1) {
   $27 = HEAP32[$24>>2]|0;
   $28 = (($27) + ($i$01)|0);
   HEAP8[$28>>0] = $$off0;
   $29 = (($i$01) + 1)|0;
   $exitcond = ($29|0)==($len$0$lcssa141617|0);
   if ($exitcond) {
    break;
   }
   $$phi$trans$insert8 = (($utf16String) + ($29<<1)|0);
   $$pre9 = HEAP16[$$phi$trans$insert8>>1]|0;
   $extract$t10 = $$pre9&255;
   $$off0 = $extract$t10;$i$01 = $29;
  }
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp5utils11StringUtils11Utf8ToUtf16EPKcj($agg$result,$utf8String,$length) {
 $agg$result = $agg$result|0;
 $utf8String = $utf8String|0;
 $length = $length|0;
 var $$0$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($length) + 1)|0;
 HEAP32[$agg$result>>2] = 0;
 $1 = (($agg$result) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($agg$result) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = ($0|0)==(0);
 if ($3) {
  $18 = 0;
 } else {
  $4 = ($0|0)<(0);
  if ($4) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $5 = $0 << 1;
  $6 = (__Znwj($5)|0);
  HEAP32[$1>>2] = $6;
  HEAP32[$agg$result>>2] = $6;
  $7 = (($6) + ($0<<1)|0);
  HEAP32[$2>>2] = $7;
  $$0$i$i$i = $0;$9 = $6;
  while(1) {
   $8 = ($9|0)==(0|0);
   if (!($8)) {
    HEAP16[$9>>1] = 0;
   }
   $10 = (($9) + 2|0);
   $11 = (($$0$i$i$i) + -1)|0;
   $12 = ($11|0)==(0);
   if ($12) {
    break;
   } else {
    $$0$i$i$i = $11;$9 = $10;
   }
  }
  HEAP32[$1>>2] = $7;
  $18 = $6;
 }
 $13 = ($length|0)==(0);
 if ($13) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $14 = (($utf8String) + ($i$01)|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15 << 24 >> 24;
  $17 = (($18) + ($i$01<<1)|0);
  HEAP16[$17>>1] = $16;
  $19 = (($i$01) + 1)|0;
  $exitcond = ($19|0)==($length|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $19;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6il2cpp5utils11StringUtils15StringDuplicateEPKc($strSource) {
 $strSource = $strSource|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($strSource|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_strlen(($strSource|0))|0);
  $2 = (($1) + 1)|0;
  $3 = (_malloc($2)|0);
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0 = 0;
  } else {
   (_strlcpy($3,$strSource,$2)|0);
   $$0 = $3;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Array14GetElementSizeEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($array) {
 $array = $array|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($array) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Array13GetByteLengthEP11Il2CppArray($array) {
 $array = $array|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$02 = 0, $length$01 = 0, $length$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$array>>2]|0;
 $1 = (($array) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $8 = (($array) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $length$1 = $9;
 } else {
  $4 = (($0) + 112|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $length$1 = 1;
  } else {
   $7 = $5&255;
   $i$02 = 0;$length$01 = 1;
   while(1) {
    $10 = (($2) + ($i$02<<3)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = Math_imul($11, $length$01)|0;
    $13 = (($i$02) + 1)|0;
    $14 = ($13|0)<($7|0);
    if ($14) {
     $i$02 = $13;$length$01 = $12;
    } else {
     $length$1 = $12;
     break;
    }
   }
  }
 }
 $15 = (($0) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 92|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = Math_imul($18, $length$1)|0;
 STACKTOP = sp;return ($19|0);
}
function __ZN6il2cpp2vm5Array3NewEP8TypeInfoj($elementTypeInfo,$length) {
 $elementTypeInfo = $elementTypeInfo|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$c$i = 0, $o$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class13GetArrayClassEP8TypeInfoj($elementTypeInfo,1)|0);
 $1 = (($0) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_imul($2, $length)|0;
 $4 = (($3) + 16)|0;
 $5 = (($0) + 119|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $8 = (__ZN6il2cpp2vm6Object15AllocatePtrFreeEjP8TypeInfo($4,$0)|0);
  $9 = (($8) + 8|0);
  HEAP32[$9>>2] = 0;
  $10 = (($8) + 8|0);
  $11 = (($3) + 8)|0;
  _memset(($10|0),0,($11|0))|0;
  $o$0$i = $8;
 } else {
  $12 = (__ZN6il2cpp2vm6Object8AllocateEjP8TypeInfo($4,$0)|0);
  $o$0$i = $12;
 }
 $13 = (($o$0$i) + 12|0);
 $n$c$i = $length;
 HEAP32[$13>>2] = $n$c$i;
 $14 = 0 & 128;
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return ($o$0$i|0);
 }
 __ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo($o$0$i,$0);
 STACKTOP = sp;return ($o$0$i|0);
}
function __ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($klass,$n) {
 $klass = $klass|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$c = 0, $o$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_imul($1, $n)|0;
 $3 = (($2) + 16)|0;
 $4 = (($klass) + 119|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = (__ZN6il2cpp2vm6Object15AllocatePtrFreeEjP8TypeInfo($3,$klass)|0);
  $8 = (($7) + 8|0);
  HEAP32[$8>>2] = 0;
  $9 = (($7) + 8|0);
  $10 = (($2) + 8)|0;
  _memset(($9|0),0,($10|0))|0;
  $o$0 = $7;
 } else {
  $11 = (__ZN6il2cpp2vm6Object8AllocateEjP8TypeInfo($3,$klass)|0);
  $o$0 = $11;
 }
 $12 = (($o$0) + 12|0);
 $n$c = $n;
 HEAP32[$12>>2] = $n$c;
 $13 = 0 & 128;
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return ($o$0|0);
 }
 __ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo($o$0,$klass);
 STACKTOP = sp;return ($o$0|0);
}
function __ZN6il2cpp2vm5Array7NewFullEP8TypeInfoPjS4_($array_class,$lengths,$lower_bounds) {
 $array_class = $array_class|0;
 $lengths = $lengths|0;
 $lower_bounds = $lower_bounds|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $byte_len$0 = 0, $i$03 = 0, $i$11 = 0, $i$11$us = 0, $len$0$c = 0, $len$0$lcssa5 = 0, $len$02 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($array_class) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($array_class) + 112|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 3;
 $6 = ($3<<24>>24)==(0);
 if ($6) {
  $7 = (($1) + 16)|0;
  $51 = 0;$byte_len$0 = $7;$len$0$lcssa5 = 1;
 } else {
  $i$03 = 0;$len$02 = 1;
  while(1) {
   $8 = (($lengths) + ($i$03<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = Math_imul($9, $len$02)|0;
   $11 = (($i$03) + 1)|0;
   $12 = ($11|0)<($4|0);
   if ($12) {
    $i$03 = $11;$len$02 = $10;
   } else {
    break;
   }
  }
  $13 = Math_imul($10, $1)|0;
  $14 = (($13) + 16)|0;
  $15 = ($3<<24>>24)==(0);
  if ($15) {
   $51 = 0;$byte_len$0 = $14;$len$0$lcssa5 = $10;
  } else {
   $16 = (($13) + 19)|0;
   $17 = $16 & -4;
   $18 = (($17) + ($5))|0;
   $51 = 1;$byte_len$0 = $18;$len$0$lcssa5 = $10;
  }
 }
 $19 = (($array_class) + 119|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $22 = (__ZN6il2cpp2vm6Object15AllocatePtrFreeEjP8TypeInfo($byte_len$0,$array_class)|0);
  $23 = (($22) + 8|0);
  $24 = (($byte_len$0) + -8)|0;
  _memset(($23|0),0,($24|0))|0;
 } else {
  (__ZN6il2cpp2vm6Object8AllocateEjP8TypeInfo($byte_len$0,$array_class)|0);
 }
 $25 = (__ZN6il2cpp2vm6Object8AllocateEjP8TypeInfo($byte_len$0,$array_class)|0);
 $26 = (($25) + 12|0);
 $len$0$c = $len$0$lcssa5;
 HEAP32[$26>>2] = $len$0$c;
 if ($51) {
  $$sum = (($byte_len$0) - ($5))|0;
  $27 = (($25) + ($$sum)|0);
  $28 = (($25) + 8|0);
  HEAP32[$28>>2] = $27;
  $29 = HEAP8[$2>>0]|0;
  $30 = ($29<<24>>24)==(0);
  if (!($30)) {
   $31 = ($lower_bounds|0)==(0|0);
   if ($31) {
    $i$11$us = 0;
    while(1) {
     $32 = (($lengths) + ($i$11$us<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($27) + ($i$11$us<<3)|0);
     HEAP32[$34>>2] = $33;
     $35 = (($i$11$us) + 1)|0;
     $36 = HEAP8[$2>>0]|0;
     $37 = $36&255;
     $38 = ($35|0)<($37|0);
     if ($38) {
      $i$11$us = $35;
     } else {
      break;
     }
    }
   } else {
    $i$11 = 0;
    while(1) {
     $39 = (($lengths) + ($i$11<<2)|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($27) + ($i$11<<3)|0);
     HEAP32[$41>>2] = $40;
     $42 = (($lower_bounds) + ($i$11<<2)|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ((($27) + ($i$11<<3)|0) + 4|0);
     HEAP32[$44>>2] = $43;
     $45 = (($i$11) + 1)|0;
     $46 = HEAP8[$2>>0]|0;
     $47 = $46&255;
     $48 = ($45|0)<($47|0);
     if ($48) {
      $i$11 = $45;
     } else {
      break;
     }
    }
   }
  }
 }
 $49 = 0 & 128;
 $50 = ($49|0)==(0);
 if ($50) {
  STACKTOP = sp;return ($25|0);
 }
 __ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo($25,$array_class);
 STACKTOP = sp;return ($25|0);
}
function __Z25il2cpp_array_element_sizeP8TypeInfo($ac) {
 $ac = $ac|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ac) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($array,$size,$idx) {
 $array = $array|0;
 $size = $size|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($array) + 16|0);
 $1 = Math_imul($idx, $size)|0;
 $2 = (($0) + ($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm8Assembly16GetAllAssembliesEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (348088|0);
}
function __ZN6il2cpp2vm8Assembly8GetImageEPK14Il2CppAssembly($assembly) {
 $assembly = $assembly|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($assembly) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm8Assembly4LoadEPKc($name) {
 $name = $name|0;
 var $$0 = 0, $$sum$i = 0, $$sum$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $result$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($name|0))|0);
 $1 = HEAP32[348088>>2]|0;
 $2 = HEAP32[((348088 + 4|0))>>2]|0;
 $3 = ($1|0)==($2|0);
 L1: do {
  if ($3) {
   $28 = $1;
  } else {
   $7 = $1;
   while(1) {
    $6 = HEAP32[$7>>2]|0;
    $8 = HEAP32[$6>>2]|0;
    $9 = (_strcmp($name,$8)|0);
    $10 = ($9|0)==(0);
    $5 = (($7) + 4|0);
    if ($10) {
     $$0 = $6;
     break;
    }
    $4 = ($5|0)==($2|0);
    if ($4) {
     $28 = $2;
     break L1;
    } else {
     $7 = $5;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $11 = ($name|0)==(0|0);
 do {
  if (!($11)) {
   $12 = (_strlen(($name|0))|0);
   $13 = ($12>>>0)<(4);
   if (!($13)) {
    $$sum$i1 = (($12) + -4)|0;
    $14 = (($name) + ($$sum$i1)|0);
    $15 = (_strncmp($14,348104,4)|0);
    $16 = ($15|0)==(0);
    if (!($16)) {
     $$sum$i = (($12) + -4)|0;
     $17 = (($name) + ($$sum$i)|0);
     $18 = (_strncmp($17,348112,4)|0);
     $19 = ($18|0)==(0);
     if (!($19)) {
      break;
     }
    }
    $27 = ($1|0)==($28|0);
    if ($27) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    } else {
     $32 = $1;
    }
    while(1) {
     $31 = HEAP32[$32>>2]|0;
     $33 = (($31) + 56|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = HEAP32[$34>>2]|0;
     $36 = (_strcmp($name,$35)|0);
     $37 = ($36|0)==(0);
     $30 = (($32) + 4|0);
     if ($37) {
      $$0 = $31;
      label = 15;
      break;
     }
     $29 = ($30|0)==($28|0);
     if ($29) {
      $$0 = 0;
      label = 15;
      break;
     } else {
      $32 = $30;
     }
    }
    if ((label|0) == 15) {
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $20 = (($0) + 5)|0;
 $21 = (__Znaj($20)|0);
 _memset(($21|0),0,($20|0))|0;
 _memcpy(($21|0),($name|0),($0|0))|0;
 $22 = (($21) + ($0)|0);
 HEAP8[$22>>0]=1819042862&255;HEAP8[$22+1>>0]=(1819042862>>8)&255;HEAP8[$22+2>>0]=(1819042862>>16)&255;HEAP8[$22+3>>0]=1819042862>>24;
 $23 = (__ZN6il2cpp2vm8Assembly4LoadEPKc($21)|0);
 $24 = ($23|0)==(0|0);
 if ($24) {
  HEAP8[$22>>0]=1702389038&255;HEAP8[$22+1>>0]=(1702389038>>8)&255;HEAP8[$22+2>>0]=(1702389038>>16)&255;HEAP8[$22+3>>0]=1702389038>>24;
  $25 = (__ZN6il2cpp2vm8Assembly4LoadEPKc($21)|0);
  $result$09 = $25;
 } else {
  $26 = ($21|0)==(0|0);
  if ($26) {
   $$0 = $23;
   STACKTOP = sp;return ($$0|0);
  } else {
   $result$09 = $23;
  }
 }
 __ZdaPv($21);
 $$0 = $result$09;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly($assembly) {
 $assembly = $assembly|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($assembly) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2vm5Image8RegisterEP11Il2CppImage($1);
 $2 = HEAP32[((348088 + 4|0))>>2]|0;
 $3 = HEAP32[((348088 + 8|0))>>2]|0;
 $4 = ($2|0)==($3|0);
 if (!($4)) {
  $5 = ($2|0)==(0|0);
  if ($5) {
   $7 = 0;
  } else {
   HEAP32[$2>>2] = $assembly;
   $$pre$i = HEAP32[((348088 + 4|0))>>2]|0;
   $7 = $$pre$i;
  }
  $6 = (($7) + 4|0);
  HEAP32[((348088 + 4|0))>>2] = $6;
  STACKTOP = sp;return;
 }
 $8 = HEAP32[348088>>2]|0;
 $9 = $2;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = (($12) + 1)|0;
 $14 = ($13>>>0)>(1073741823);
 if ($14) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $15 = ($12>>>0)<(536870911);
 if ($15) {
  $16 = $11 >> 1;
  $17 = ($16>>>0)<($13>>>0);
  $18 = $17 ? $13 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3$i$i = 0;$23 = 0;
  } else {
   $$0$i2$i$i = $18;
   label = 9;
  }
 } else {
  $$0$i2$i$i = 1073741823;
  label = 9;
 }
 if ((label|0) == 9) {
  $20 = $$0$i2$i$i << 2;
  $21 = (__Znwj($20)|0);
  $$0$i3$i$i = $$0$i2$i$i;$23 = $21;
 }
 $22 = (($23) + ($12<<2)|0);
 $24 = (($23) + ($$0$i3$i$i<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  HEAP32[$22>>2] = $assembly;
 }
 $26 = (($23) + ($13<<2)|0);
 _memcpy(($23|0),($8|0),($11|0))|0;
 HEAP32[348088>>2] = $23;
 HEAP32[((348088 + 4|0))>>2] = $26;
 HEAP32[((348088 + 8|0))>>2] = $24;
 $27 = ($8|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 __ZdlPv($8);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm8Assembly10InitializeEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[348088>>2]|0;
 $1 = HEAP32[((348088 + 4|0))>>2]|0;
 $2 = ($0|0)==($1|0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $4 = $0;
 }
 while(1) {
  $3 = HEAP32[$4>>2]|0;
  $5 = (($3) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN6il2cpp2vm5Image10InitializeEP11Il2CppImage($6);
  $7 = (($4) + 4|0);
  $8 = HEAP32[((348088 + 4|0))>>2]|0;
  $9 = ($7|0)==($8|0);
  if ($9) {
   break;
  } else {
   $4 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $vararg_buffer10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer10 = sp;
 $0 = (($type) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 16;
 $3 = $2 & 255;
 do {
  switch ($3|0) {
  case 21:  {
   $81 = HEAP32[$type>>2]|0;
   $82 = (__ZN6il2cpp2vm12GenericClass8GetClassEP18Il2CppGenericClass($81)|0);
   $$0 = $82;
   break;
  }
  case 3:  {
   $16 = HEAP32[$type>>2]|0;
   $17 = ($16|0)==(0|0);
   $18 = HEAP32[((388944 + 64|0))>>2]|0;
   $19 = $17 ? $18 : $16;
   $$0 = $19;
   break;
  }
  case 9:  {
   $40 = HEAP32[$type>>2]|0;
   $41 = ($40|0)==(0|0);
   $42 = HEAP32[((388944 + 36|0))>>2]|0;
   $43 = $41 ? $42 : $40;
   $$0 = $43;
   break;
  }
  case 24:  {
   $44 = HEAP32[$type>>2]|0;
   $45 = ($44|0)==(0|0);
   $46 = HEAP32[((388944 + 40|0))>>2]|0;
   $47 = $45 ? $46 : $44;
   $$0 = $47;
   break;
  }
  case 17: case 18:  {
   $80 = HEAP32[$type>>2]|0;
   $$0 = $80;
   break;
  }
  case 10:  {
   $52 = HEAP32[$type>>2]|0;
   $53 = ($52|0)==(0|0);
   $54 = HEAP32[((388944 + 48|0))>>2]|0;
   $55 = $53 ? $54 : $52;
   $$0 = $55;
   break;
  }
  case 20:  {
   $72 = HEAP32[$type>>2]|0;
   $73 = HEAP32[$72>>2]|0;
   $74 = (($72) + 4|0);
   $75 = HEAP8[$74>>0]|0;
   $76 = $75&255;
   $77 = (__ZN6il2cpp2vm5Image20GetBoundedArrayClassEP8TypeInfojb($73,$76,1)|0);
   $$0 = $77;
   break;
  }
  case 27:  {
   HEAP32[$vararg_buffer10>>2] = 348168;
   (_printf((348144|0),($vararg_buffer10|0))|0);
   $$0 = 0;
   break;
  }
  case 15:  {
   HEAP32[$vararg_buffer10>>2] = 348168;
   (_printf((348144|0),($vararg_buffer10|0))|0);
   $$0 = 0;
   break;
  }
  case 28:  {
   $4 = HEAP32[$type>>2]|0;
   $5 = ($4|0)==(0|0);
   $6 = HEAP32[((388944 + 4|0))>>2]|0;
   $7 = $5 ? $6 : $4;
   $$0 = $7;
   break;
  }
  case 2:  {
   $12 = HEAP32[$type>>2]|0;
   $13 = ($12|0)==(0|0);
   $14 = HEAP32[((388944 + 16|0))>>2]|0;
   $15 = $13 ? $14 : $12;
   $$0 = $15;
   break;
  }
  case 4:  {
   $20 = HEAP32[$type>>2]|0;
   $21 = ($20|0)==(0|0);
   $22 = HEAP32[((388944 + 20|0))>>2]|0;
   $23 = $21 ? $22 : $20;
   $$0 = $23;
   break;
  }
  case 12:  {
   $60 = HEAP32[$type>>2]|0;
   $61 = ($60|0)==(0|0);
   $62 = HEAP32[((388944 + 56|0))>>2]|0;
   $63 = $61 ? $62 : $60;
   $$0 = $63;
   break;
  }
  case 1:  {
   $8 = HEAP32[$type>>2]|0;
   $9 = ($8|0)==(0|0);
   $10 = HEAP32[((388944 + 12|0))>>2]|0;
   $11 = $9 ? $10 : $8;
   $$0 = $11;
   break;
  }
  case 5:  {
   $24 = HEAP32[$type>>2]|0;
   $25 = ($24|0)==(0|0);
   $26 = HEAP32[((388944 + 8|0))>>2]|0;
   $27 = $25 ? $26 : $24;
   $$0 = $27;
   break;
  }
  case 13:  {
   $64 = HEAP32[$type>>2]|0;
   $65 = ($64|0)==(0|0);
   $66 = HEAP32[((388944 + 60|0))>>2]|0;
   $67 = $65 ? $66 : $64;
   $$0 = $67;
   break;
  }
  case 25:  {
   $48 = HEAP32[$type>>2]|0;
   $49 = ($48|0)==(0|0);
   $50 = HEAP32[((388944 + 44|0))>>2]|0;
   $51 = $49 ? $50 : $48;
   $$0 = $51;
   break;
  }
  case 22:  {
   HEAP32[$vararg_buffer10>>2] = 348168;
   (_printf((348144|0),($vararg_buffer10|0))|0);
   $$0 = 0;
   break;
  }
  case 6:  {
   $28 = HEAP32[$type>>2]|0;
   $29 = ($28|0)==(0|0);
   $30 = HEAP32[((388944 + 24|0))>>2]|0;
   $31 = $29 ? $30 : $28;
   $$0 = $31;
   break;
  }
  case 14:  {
   $68 = HEAP32[$type>>2]|0;
   $69 = ($68|0)==(0|0);
   $70 = HEAP32[((388944 + 68|0))>>2]|0;
   $71 = $69 ? $70 : $68;
   $$0 = $71;
   break;
  }
  case 8:  {
   $36 = HEAP32[$type>>2]|0;
   $37 = ($36|0)==(0|0);
   $38 = HEAP32[((388944 + 32|0))>>2]|0;
   $39 = $37 ? $38 : $36;
   $$0 = $39;
   break;
  }
  case 7:  {
   $32 = HEAP32[$type>>2]|0;
   $33 = ($32|0)==(0|0);
   $34 = HEAP32[((388944 + 28|0))>>2]|0;
   $35 = $33 ? $34 : $32;
   $$0 = $35;
   break;
  }
  case 29:  {
   $78 = HEAP32[$type>>2]|0;
   $79 = (__ZN6il2cpp2vm5Image20GetBoundedArrayClassEP8TypeInfojb($78,1,0)|0);
   $$0 = $79;
   break;
  }
  case 30:  {
   HEAP32[$vararg_buffer10>>2] = 348168;
   (_printf((348144|0),($vararg_buffer10|0))|0);
   $$0 = 0;
   break;
  }
  case 19:  {
   $83 = HEAP32[$type>>2]|0;
   $84 = (($83) + 8|0);
   $85 = HEAP32[$84>>2]|0;
   $$0 = $85;
   break;
  }
  case 11:  {
   $56 = HEAP32[$type>>2]|0;
   $57 = ($56|0)==(0|0);
   $58 = HEAP32[((388944 + 52|0))>>2]|0;
   $59 = $57 ? $58 : $56;
   $$0 = $59;
   break;
  }
  default: {
   HEAP32[$vararg_buffer10>>2] = 348168;
   (_printf((348144|0),($vararg_buffer10|0))|0);
   $$0 = 0;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class20GetBoundedArrayClassEP8TypeInfojb($eclass,$rank,$bounded) {
 $eclass = $eclass|0;
 $rank = $rank|0;
 $bounded = $bounded|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image20GetBoundedArrayClassEP8TypeInfojb($eclass,$rank,$bounded)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm5Class13GetArrayClassEP8TypeInfoj($element_class,$rank) {
 $element_class = $element_class|0;
 $rank = $rank|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image20GetBoundedArrayClassEP8TypeInfojb($element_class,$rank,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm5Class20FromGenericParameterEP18Il2CppGenericParam($param) {
 $param = $param|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($param) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Class14FromSystemTypeEP20Il2CppReflectionType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm5Class15GetElementClassEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($klass|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (($1) + 48|0);
  $4 = HEAP32[$3>>2]|0;
  $$0 = $4;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($klass,$iter) {
 $klass = $klass|0;
 $iter = $iter|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($iter|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = HEAP32[$iter>>2]|0;
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (($klass) + 16|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($4|0)==(0|0);
    if ($5) {
     $$0 = 0;
     break;
    }
    HEAP32[$iter>>2] = $4;
    $6 = HEAP32[$3>>2]|0;
    $7 = HEAP32[$6>>2]|0;
    $$0 = $7;
    break;
   } else {
    $8 = (($1) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $$0 = 0;
     break;
    }
    HEAP32[$iter>>2] = $8;
    $11 = HEAP32[$8>>2]|0;
    $$0 = $11;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class16GetFieldFromNameEPK8TypeInfoPKc($klass,$name) {
 $klass = $klass|0;
 $name = $name|0;
 var $$0 = 0, $$0$i3 = 0, $$015 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($klass|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$015 = $klass;
 }
 L3: while(1) {
  $1 = (($$015) + 16|0);
  $3 = 0;
  while(1) {
   $2 = ($3|0)==(0|0);
   if ($2) {
    $4 = HEAP32[$1>>2]|0;
    $5 = ($4|0)==(0|0);
    if ($5) {
     break;
    }
    $9 = HEAP32[$4>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     break;
    } else {
     $$0$i3 = $9;$17 = $4;
    }
   } else {
    $6 = (($3) + 4|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     break;
    } else {
     $$0$i3 = $7;$17 = $6;
    }
   }
   $11 = (__ZN6il2cpp2vm5Field7GetNameEP9FieldInfo($$0$i3)|0);
   $12 = (_strcmp($name,$11)|0);
   $13 = ($12|0)==(0);
   if ($13) {
    $$0 = $$0$i3;
    label = 9;
    break L3;
   } else {
    $3 = $17;
   }
  }
  $14 = (($$015) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0 = 0;
   label = 9;
   break;
  } else {
   $$015 = $15;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Class12GetFinalizerEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 115|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($klass)|0);
 }
 $3 = (($klass) + 122|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[348136>>2]|0;
 $7 = (($klass) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class4InitEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $vmethod$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 115|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return 1;
 }
 $3 = (($klass) + 120|0);
 HEAP8[$3>>0] = 1;
 $4 = (($klass) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 16;
 $9 = $8 & 255;
 if ((($9|0) == 29) | (($9|0) == 20)) {
  $10 = (($klass) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 115|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($11)|0);
  }
 }
 $15 = 388928;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (_i64Add(($17|0),($20|0),1,0)|0);
 $22 = tempRet0;
 $23 = 388928;
 $24 = $23;
 HEAP32[$24>>2] = $21;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 $27 = (($klass) + 20|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = (($28) + 115|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($28)|0);
  }
 }
 $33 = (($klass) + 121|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  __ZN6il2cpp2vm5Class12LayoutFieldsEP8TypeInfo($klass);
  HEAP8[$33>>0] = 1;
 }
 $36 = (($klass) + 112|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if (!($38)) {
  __ZN6il2cpp2vm5Class14InitArrayClassEP8TypeInfo($klass);
 }
 $39 = HEAP32[((388944 + 4|0))>>2]|0;
 $40 = ($39|0)==($klass|0);
 if ($40) {
  $41 = (($klass) + 36|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   $46 = $43;$i$02 = 0;$vmethod$01 = $42;
   while(1) {
    $45 = HEAP32[$46>>2]|0;
    $47 = (_strcmp($45,348192)|0);
    $48 = ($47|0)==(0);
    if ($48) {
    } else {
     $49 = (_strcmp($45,348208)|0);
     $50 = ($49|0)==(0);
     if ($50) {
      HEAP32[348136>>2] = $i$02;
     }
    }
    $51 = (($vmethod$01) + 4|0);
    $52 = (($i$02) + 1)|0;
    $53 = HEAP32[$51>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     break;
    } else {
     $46 = $53;$i$02 = $52;$vmethod$01 = $51;
    }
   }
  }
 }
 HEAP8[$0>>0] = 1;
 HEAP8[$3>>0] = 0;
 STACKTOP = sp;return 1;
}
function __ZN6il2cpp2vm5Class15GetInstanceSizeEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Class10GetMethodsEPK8TypeInfoPPv($klass,$iter) {
 $klass = $klass|0;
 $iter = $iter|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($iter|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = HEAP32[$iter>>2]|0;
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (($klass) + 8|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($4|0)==(0|0);
    if ($5) {
     $$0 = 0;
     break;
    }
    HEAP32[$iter>>2] = $4;
    $6 = HEAP32[$3>>2]|0;
    $7 = HEAP32[$6>>2]|0;
    $$0 = $7;
    break;
   } else {
    $8 = (($1) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $$0 = 0;
     break;
    }
    HEAP32[$iter>>2] = $8;
    $11 = HEAP32[$8>>2]|0;
    $$0 = $11;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class17GetMethodFromNameEP8TypeInfoPKci($klass,$name,$argsCount) {
 $klass = $klass|0;
 $name = $name|0;
 $argsCount = $argsCount|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class22GetMethodFromNameFlagsEP8TypeInfoPKcii($klass,$name,$argsCount,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm5Class22GetMethodFromNameFlagsEP8TypeInfoPKcii($klass,$name,$argsCount,$flags) {
 $klass = $klass|0;
 $name = $name|0;
 $argsCount = $argsCount|0;
 $flags = $flags|0;
 var $$0$i2 = 0, $$0$i2$us = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $res$0$lcssa = 0, $res$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($klass)|0);
 $0 = ($klass|0)==(0|0);
 if ($0) {
  $res$0$lcssa = 0;
  STACKTOP = sp;return ($res$0$lcssa|0);
 }
 $1 = ($argsCount|0)==(-1);
 $$03 = $klass;
 while(1) {
  $2 = (($$03) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  L6: do {
   if ($4) {
    $res$1 = 0;
   } else {
    if ($1) {
     $6 = 0;
     while(1) {
      $5 = ($6|0)==(0|0);
      if ($5) {
       $10 = HEAP32[$3>>2]|0;
       $11 = ($10|0)==(0|0);
       if ($11) {
        $res$1 = 0;
        break L6;
       }
       $$0$i2$us = $10;$49 = $3;
      } else {
       $7 = (($6) + 4|0);
       $8 = HEAP32[$7>>2]|0;
       $9 = ($8|0)==(0|0);
       if ($9) {
        $res$1 = 0;
        break L6;
       } else {
        $$0$i2$us = $8;$49 = $7;
       }
      }
      $12 = HEAP32[$$0$i2$us>>2]|0;
      $13 = HEAP8[$12>>0]|0;
      $14 = HEAP8[$name>>0]|0;
      $15 = ($13<<24>>24)==($14<<24>>24);
      if (!($15)) {
       $6 = $49;
       continue;
      }
      $16 = (_strcmp($name,$12)|0);
      $17 = ($16|0)==(0);
      if (!($17)) {
       $6 = $49;
       continue;
      }
      $18 = (($$0$i2$us) + 28|0);
      $19 = HEAP16[$18>>1]|0;
      $20 = $19&65535;
      $21 = $20 & $flags;
      $22 = ($21|0)==($flags|0);
      if ($22) {
       $res$1 = $$0$i2$us;
       break L6;
      } else {
       $6 = $49;
      }
     }
    } else {
     $24 = 0;
    }
    while(1) {
     $23 = ($24|0)==(0|0);
     if ($23) {
      $28 = HEAP32[$3>>2]|0;
      $29 = ($28|0)==(0|0);
      if ($29) {
       $res$1 = 0;
       break L6;
      }
      $$0$i2 = $28;$50 = $3;
     } else {
      $25 = (($24) + 4|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==(0|0);
      if ($27) {
       $res$1 = 0;
       break L6;
      } else {
       $$0$i2 = $26;$50 = $25;
      }
     }
     $30 = HEAP32[$$0$i2>>2]|0;
     $31 = HEAP8[$30>>0]|0;
     $32 = HEAP8[$name>>0]|0;
     $33 = ($31<<24>>24)==($32<<24>>24);
     if (!($33)) {
      $24 = $50;
      continue;
     }
     $34 = (_strcmp($name,$30)|0);
     $35 = ($34|0)==(0);
     if (!($35)) {
      $24 = $50;
      continue;
     }
     $36 = (($$0$i2) + 33|0);
     $37 = HEAP8[$36>>0]|0;
     $38 = $37&255;
     $39 = ($38|0)==($argsCount|0);
     if (!($39)) {
      $24 = $50;
      continue;
     }
     $40 = (($$0$i2) + 28|0);
     $41 = HEAP16[$40>>1]|0;
     $42 = $41&65535;
     $43 = $42 & $flags;
     $44 = ($43|0)==($flags|0);
     if ($44) {
      $res$1 = $$0$i2;
      break;
     } else {
      $24 = $50;
     }
    }
   }
  } while(0);
  $45 = (($$03) + 20|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)!=(0|0);
  $48 = ($res$1|0)==(0|0);
  $or$cond = $47 & $48;
  if ($or$cond) {
   $$03 = $46;
  } else {
   $res$0$lcssa = $res$1;
   break;
  }
 }
 STACKTOP = sp;return ($res$0$lcssa|0);
}
function __ZN6il2cpp2vm5Class7GetNameEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$klass>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm5Class12GetNamespaceEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Class13GetNumMethodsEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 124|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm5Class12GetNumFieldsEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 128|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm5Class9GetParentEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Class13GetPropertiesEPK8TypeInfoPPv($klass,$iter) {
 $klass = $klass|0;
 $iter = $iter|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($iter|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = HEAP32[$iter>>2]|0;
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (($klass) + 12|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($4|0)==(0|0);
    if ($5) {
     $$0 = 0;
     break;
    }
    HEAP32[$iter>>2] = $4;
    $6 = HEAP32[$3>>2]|0;
    $7 = HEAP32[$6>>2]|0;
    $$0 = $7;
    break;
   } else {
    $8 = (($1) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $$0 = 0;
     break;
    }
    HEAP32[$iter>>2] = $8;
    $11 = HEAP32[$8>>2]|0;
    $$0 = $11;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class12GetValueSizeEP8TypeInfoPj($klass,$align) {
 $klass = $klass|0;
 $align = $align|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -8)|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm5Class9HasParentEPK8TypeInfoS4_($klass,$parent) {
 $klass = $klass|0;
 $parent = $parent|0;
 var $$0 = 0, $$012 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($klass|0)==(0|0);
 L1: do {
  if ($0) {
   $$0 = 0;
  } else {
   $$012 = $klass;
   while(1) {
    $1 = ($$012|0)==($parent|0);
    if ($1) {
     $$0 = 1;
     break L1;
    }
    $2 = (($$012) + 20|0);
    $3 = HEAP32[$2>>2]|0;
    $4 = ($3|0)==(0|0);
    if ($4) {
     $$0 = 0;
     break;
    } else {
     $$012 = $3;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_($klass,$oklass) {
 $klass = $klass|0;
 $oklass = $oklass|0;
 var $$0$idx = 0, $$0$idx$val = 0, $$01 = 0, $$04 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $interfaceTypeInfo$01$i2 = 0, $klass$tr13 = 0, $klass$tr9 = 0, $oklass$tr12 = 0, $oklass$tr14 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 114|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 L1: do {
  if ($2) {
   $klass$tr13 = $klass;$oklass$tr14 = $oklass;
   while(1) {
    $3 = (($klass$tr13) + 112|0);
    $4 = HEAP8[$3>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     break;
    }
    $6 = (($oklass$tr14) + 112|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = ($7<<24>>24)==($4<<24>>24);
    if (!($8)) {
     $$01 = 0;
     label = 13;
     break;
    }
    $9 = (($klass$tr13) + 44|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($oklass$tr14) + 44|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + 114|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     $klass$tr13 = $10;$oklass$tr14 = $12;
    } else {
     $klass$tr9 = $10;$oklass$tr12 = $12;
     break L1;
    }
   }
   if ((label|0) == 13) {
    STACKTOP = sp;return ($$01|0);
   }
   $16 = HEAP32[((388944 + 4|0))>>2]|0;
   $17 = ($16|0)==($klass$tr13|0);
   if ($17) {
    $$01 = 1;
    STACKTOP = sp;return ($$01|0);
   } else {
    $klass$tr9 = $klass$tr13;$oklass$tr12 = $oklass$tr14;
   }
  } else {
   $klass$tr9 = $klass;$oklass$tr12 = $oklass;
  }
 } while(0);
 $18 = ($oklass$tr12|0)==(0|0);
 if ($18) {
  $$01 = 0;
  STACKTOP = sp;return ($$01|0);
 } else {
  $$04 = $oklass$tr12;
 }
 L13: while(1) {
  $19 = ($$04|0)==($klass$tr9|0);
  if ($19) {
   $$01 = 1;
   label = 13;
   break;
  }
  $$0$idx = (($$04) + 32|0);
  $$0$idx$val = HEAP32[$$0$idx>>2]|0;
  $20 = ($$0$idx$val|0)==(0|0);
  if (!($20)) {
   $21 = HEAP32[$$0$idx$val>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    $27 = $21;$interfaceTypeInfo$01$i2 = $$0$idx$val;
    while(1) {
     $26 = ($27|0)==($klass$tr9|0);
     $24 = (($interfaceTypeInfo$01$i2) + 4|0);
     if ($26) {
      $$01 = 1;
      label = 13;
      break L13;
     }
     $23 = HEAP32[$24>>2]|0;
     $25 = ($23|0)==(0|0);
     if ($25) {
      break;
     } else {
      $27 = $23;$interfaceTypeInfo$01$i2 = $24;
     }
    }
   }
  }
  $28 = (($$04) + 20|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $$01 = 0;
   label = 13;
   break;
  } else {
   $$04 = $29;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$01|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Class9IsGenericEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 118|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm5Class12IsSubclassOfEPK8TypeInfoS4_b($klass,$klassc,$check_interfaces) {
 $klass = $klass|0;
 $klassc = $klassc|0;
 $check_interfaces = $check_interfaces|0;
 var $$0 = 0, $$012$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $interfaces$04 = 0, $interfaces1$010 = 0, $oklass$06 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 L1: do {
  if ($check_interfaces) {
   $0 = (($klassc) + 114|0);
   $1 = HEAP8[$0>>0]|0;
   $2 = ($1<<24>>24)==(0);
   if ($2) {
    label = 14;
   } else {
    $3 = (($klass) + 114|0);
    $4 = HEAP8[$3>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if (!($5)) {
     $17 = (($klass) + 32|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      break;
     } else {
      $interfaces1$010 = $18;
     }
     while(1) {
      $21 = HEAP32[$interfaces1$010>>2]|0;
      $22 = ($21|0)==(0|0);
      if ($22) {
       break L1;
      }
      $23 = ($21|0)==($klassc|0);
      if ($23) {
       $$0 = 1;
       break;
      }
      $20 = (($interfaces1$010) + 4|0);
      $interfaces1$010 = $20;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $6 = ($klass|0)==(0|0);
    if (!($6)) {
     $oklass$06 = $klass;
     L12: while(1) {
      $7 = (($oklass$06) + 32|0);
      $8 = HEAP32[$7>>2]|0;
      $9 = ($8|0)==(0|0);
      L14: do {
       if (!($9)) {
        $interfaces$04 = $8;
        while(1) {
         $11 = HEAP32[$interfaces$04>>2]|0;
         $12 = ($11|0)==(0|0);
         if ($12) {
          break L14;
         }
         $13 = ($11|0)==($klassc|0);
         if ($13) {
          $$0 = 1;
          break L12;
         }
         $10 = (($interfaces$04) + 4|0);
         $interfaces$04 = $10;
        }
       }
      } while(0);
      $14 = (($oklass$06) + 20|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = ($15|0)==(0|0);
      if ($16) {
       break L1;
      } else {
       $oklass$06 = $15;
      }
     }
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   label = 14;
  }
 } while(0);
 L21: do {
  if ((label|0) == 14) {
   $24 = (($klass) + 114|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)!=(0);
   $27 = ($klass|0)==(0|0);
   $or$cond = $26 | $27;
   if (!($or$cond)) {
    $$012$i = $klass;
    while(1) {
     $28 = ($$012$i|0)==($klassc|0);
     if ($28) {
      $$0 = 1;
      break;
     }
     $29 = (($$012$i) + 20|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      break L21;
     } else {
      $$012$i = $30;
     }
    }
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $32 = HEAP32[((388944 + 4|0))>>2]|0;
 $33 = ($32|0)==($klassc|0);
 $$0 = $33;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class11IsValuetypeEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 113|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm5Class18GetInterfaceOffsetEPK8TypeInfoPS2_($klass,$itf) {
 $klass = $klass|0;
 $itf = $itf|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $interfaceTypeInfo$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$03 = 0;$interfaceTypeInfo$02 = $1;
 }
 while(1) {
  $3 = HEAP32[$interfaceTypeInfo$02>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0 = -1;
   label = 6;
   break;
  }
  $5 = ($3|0)==($itf|0);
  if ($5) {
   break;
  }
  $10 = (($interfaceTypeInfo$02) + 4|0);
  $11 = (($i$03) + 1)|0;
  $i$03 = $11;$interfaceTypeInfo$02 = $10;
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($klass) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($i$03<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class12LayoutFieldsEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $fields$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 119|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = (($klass) + 119|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6 | $4;
  HEAP8[$5>>0] = $7;
 }
 $8 = (($klass) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 L4: do {
  if (!($10)) {
   $11 = (($klass) + 119|0);
   $fields$01 = $9;
   while(1) {
    $12 = HEAP32[$fields$01>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     break L4;
    }
    $14 = (($12) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($15) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = $17 & 16;
    $19 = ($18|0)==(0);
    do {
     if ($19) {
      $20 = (__ZN6il2cpp2vm4Type17GetUnderlyingTypeEPK10Il2CppType($15)|0);
      $21 = (__ZN6il2cpp2vm4Type11IsReferenceEPK10Il2CppType($20)|0);
      if (!($21)) {
       $22 = (__ZN6il2cpp2vm4Type8IsStructEPK10Il2CppType($20)|0);
       if (!($22)) {
        break;
       }
       $23 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($20)|0);
       $24 = (($23) + 120|0);
       $25 = HEAP8[$24>>0]|0;
       $26 = ($25<<24>>24)==(0);
       if ($26) {
        (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($23)|0);
        $27 = (($23) + 119|0);
        $28 = HEAP8[$27>>0]|0;
        $29 = ($28<<24>>24)==(0);
        if ($29) {
         break;
        }
       }
      }
      HEAP8[$11>>0] = 1;
     }
    } while(0);
    $30 = (($fields$01) + 4|0);
    $fields$01 = $30;
   }
  }
 } while(0);
 $31 = (($klass) + 96|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0);
 do {
  if (!($33)) {
   $34 = (__Z21il2cpp_gc_alloc_fixedjPv($32,0)|0);
   $35 = (($klass) + 80|0);
   HEAP32[$35>>2] = $34;
   $36 = HEAP32[((348120 + 4|0))>>2]|0;
   $37 = HEAP32[((348120 + 8|0))>>2]|0;
   $38 = ($36|0)==($37|0);
   if (!($38)) {
    $39 = ($36|0)==(0|0);
    if ($39) {
     $41 = 0;
    } else {
     HEAP32[$36>>2] = $klass;
     $$pre$i = HEAP32[((348120 + 4|0))>>2]|0;
     $41 = $$pre$i;
    }
    $40 = (($41) + 4|0);
    HEAP32[((348120 + 4|0))>>2] = $40;
    break;
   }
   $42 = HEAP32[348120>>2]|0;
   $43 = $36;
   $44 = $42;
   $45 = (($43) - ($44))|0;
   $46 = $45 >> 2;
   $47 = (($46) + 1)|0;
   $48 = ($47>>>0)>(1073741823);
   if ($48) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $49 = ($46>>>0)<(536870911);
   if ($49) {
    $50 = $45 >> 1;
    $51 = ($50>>>0)<($47>>>0);
    $52 = $51 ? $47 : $50;
    $53 = ($52|0)==(0);
    if ($53) {
     $$0$i3$i$i = 0;$57 = 0;
    } else {
     $$0$i2$i$i = $52;
     label = 22;
    }
   } else {
    $$0$i2$i$i = 1073741823;
    label = 22;
   }
   if ((label|0) == 22) {
    $54 = $$0$i2$i$i << 2;
    $55 = (__Znwj($54)|0);
    $$0$i3$i$i = $$0$i2$i$i;$57 = $55;
   }
   $56 = (($57) + ($46<<2)|0);
   $58 = (($57) + ($$0$i3$i$i<<2)|0);
   $59 = ($56|0)==(0|0);
   if (!($59)) {
    HEAP32[$56>>2] = $klass;
   }
   $60 = (($57) + ($47<<2)|0);
   _memcpy(($57|0),($42|0),($45|0))|0;
   HEAP32[348120>>2] = $57;
   HEAP32[((348120 + 4|0))>>2] = $60;
   HEAP32[((348120 + 8|0))>>2] = $58;
   $61 = ($42|0)==(0|0);
   if (!($61)) {
    __ZdlPv($42);
   }
  }
 } while(0);
 $62 = (($klass) + 100|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0);
 if ($64) {
  STACKTOP = sp;return;
 }
 $65 = (__ZN6il2cpp2vm6Thread21AllocThreadStaticDataEi($63)|0);
 $66 = (($klass) + 104|0);
 HEAP32[$66>>2] = $65;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm5Class14InitArrayClassEP8TypeInfo($arrayType) {
 $arrayType = $arrayType|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($arrayType) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (_strlen(($2|0))|0);
 $4 = (($arrayType) + 112|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = (($3) + 3)|0;
 $8 = (($7) + ($6))|0;
 $9 = (_malloc($8)|0);
 $10 = HEAP32[$1>>2]|0;
 _memcpy(($9|0),($10|0),($3|0))|0;
 $11 = (($9) + ($3)|0);
 HEAP8[$11>>0] = 91;
 $12 = ($5&255)>(1);
 if ($12) {
  $$sum = (($3) + 1)|0;
  $13 = (($9) + ($$sum)|0);
  $14 = (($6) + -1)|0;
  _memset(($13|0),44,($14|0))|0;
 }
 $15 = (($6) + ($3))|0;
 $16 = (($9) + ($15)|0);
 HEAP8[$16>>0] = 93;
 $17 = (($15) + 1)|0;
 $18 = (($9) + ($17)|0);
 HEAP8[$18>>0] = 0;
 HEAP32[$arrayType>>2] = $9;
 $19 = (($1) + 117|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $25 = (($arrayType) + 44|0);
  HEAP32[$25>>2] = $1;
  $29 = $1;
 } else {
  $22 = (($1) + 28|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($arrayType) + 44|0);
  HEAP32[$24>>2] = $23;
  $29 = $23;
 }
 $26 = (($arrayType) + 44|0);
 $27 = HEAP32[((388944 + 20|0))>>2]|0;
 $28 = ($29|0)==($27|0);
 do {
  if ($28) {
   $30 = HEAP32[((388944 + 8|0))>>2]|0;
   HEAP32[$26>>2] = $30;
  } else {
   $31 = HEAP32[((388944 + 28|0))>>2]|0;
   $32 = ($29|0)==($31|0);
   if ($32) {
    $33 = HEAP32[((388944 + 24|0))>>2]|0;
    HEAP32[$26>>2] = $33;
    break;
   }
   $34 = HEAP32[((388944 + 36|0))>>2]|0;
   $35 = ($29|0)==($34|0);
   if ($35) {
    $36 = HEAP32[((388944 + 32|0))>>2]|0;
    HEAP32[$26>>2] = $36;
    break;
   }
   $37 = HEAP32[((388944 + 52|0))>>2]|0;
   $38 = ($29|0)==($37|0);
   if ($38) {
    $39 = HEAP32[((388944 + 48|0))>>2]|0;
    HEAP32[$26>>2] = $39;
    break;
   }
   $40 = HEAP32[((388944 + 40|0))>>2]|0;
   $41 = ($29|0)==($40|0);
   if (!($41)) {
    $42 = (__ZN6il2cpp2vm7Runtime9IsUIntPtrEP8TypeInfo($29)|0);
    if (!($42)) {
     break;
    }
   }
   $43 = HEAP32[((388944 + 32|0))>>2]|0;
   HEAP32[$26>>2] = $43;
  }
 } while(0);
 $44 = HEAP8[$19>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  $46 = (($1) + 92|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($arrayType) + 92|0);
  HEAP32[$48>>2] = $47;
 }
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($1)|0);
 $49 = (($1) + 48|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (__ZN6il2cpp2vm4Type11IsReferenceEPK10Il2CppType($50)|0);
 if ($51) {
  $55 = 1;
  $54 = (($arrayType) + 119|0);
  HEAP8[$54>>0] = $55;
  STACKTOP = sp;return;
 }
 $52 = (($1) + 119|0);
 $53 = HEAP8[$52>>0]|0;
 $55 = $53;
 $54 = (($arrayType) + 119|0);
 HEAP8[$54>>0] = $55;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($image,$namespaze,$name) {
 $image = $image|0;
 $namespaze = $namespaze|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image13ClassFromNameEPK11Il2CppImagePKcS6_($image,$namespaze,$name)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm5Class8GetFlagsEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Class10IsAbstractEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 128;
 $3 = ($2|0)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp2vm5Class11IsInterfaceEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 114|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm5Class10IsNullableEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $6 = 0;
  STACKTOP = sp;return ($6|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[((388944 + 164|0))>>2]|0;
 $5 = ($3|0)==($4|0);
 $6 = $5;
 STACKTOP = sp;return ($6|0);
}
function __ZN6il2cpp2vm5Class19GetArrayElementSizeEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $$0$i = 0, $$0$ph = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $type$0 = 0, $type$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $$0$ph = $klass;$type$0$ph = $1;
 L1: while(1) {
  $type$0 = $type$0$ph;
  L3: while(1) {
   $2 = (($type$0) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = $3 >>> 16;
   $5 = $4 & 255;
   switch ($5|0) {
   case 13: case 11: case 10:  {
    label = 6;
    break L1;
    break;
   }
   case 17:  {
    break L3;
    break;
   }
   case 1:  {
    label = 13;
    break L1;
    break;
   }
   case 3: case 7: case 6:  {
    $$01 = 2;
    break L1;
    break;
   }
   case 2: case 5: case 4:  {
    label = 15;
    break L1;
    break;
   }
   case 30: case 19: case 20: case 29: case 28: case 14: case 18: case 15: case 25: case 24:  {
    label = 5;
    break L1;
    break;
   }
   case 12: case 9: case 8:  {
    label = 4;
    break L1;
    break;
   }
   case 21:  {
    break;
   }
   default: {
    label = 14;
    break L1;
   }
   }
   $20 = HEAP32[$type$0>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 48|0);
   $23 = HEAP32[$22>>2]|0;
   $type$0 = $23;
  }
  $6 = HEAP32[$type$0>>2]|0;
  $7 = (($6) + 117|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   label = 11;
   break;
  }
  $10 = (($6) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==($6|0);
  if ($12) {
   $$0$i = 0;
  } else {
   $13 = (($11) + 48|0);
   $14 = HEAP32[$13>>2]|0;
   $$0$i = $14;
  }
  $15 = (($$0$ph) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$ph = $16;$type$0$ph = $$0$i;
 }
 if ((label|0) == 4) {
  $$01 = 4;
 }
 else if ((label|0) == 5) {
  $$01 = 4;
 }
 else if ((label|0) == 6) {
  $$01 = 8;
 }
 else if ((label|0) == 11) {
  $17 = (($$0$ph) + 88|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + -8)|0;
  $$01 = $19;
 }
 else if ((label|0) == 13) {
  $$01 = 0;
 }
 else if ((label|0) == 14) {
  $$01 = -1;
 }
 else if ((label|0) == 15) {
  $$01 = 1;
 }
 STACKTOP = sp;return ($$01|0);
}
function __ZN6il2cpp2vm5Class7GetTypeEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Class7GetTypeEP8TypeInfoRKNS0_17TypeNameParseInfoE($klass,$info) {
 $klass = $klass|0;
 $info = $info|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 L1: do {
  if ($4) {
   $11 = $1;
   label = 4;
  } else {
   $6 = $1;
   while(1) {
    $5 = HEAP32[$6>>2]|0;
    $7 = ($5|0)==(0);
    if ($7) {
     $11 = $6;
     label = 4;
     break L1;
    }
    $8 = (($6) + 4|0);
    $9 = ($8|0)==($3|0);
    if ($9) {
     break;
    } else {
     $6 = $8;
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $10 = ($11|0)==($3|0);
  if (!($10)) {
   $12 = (($klass) + 52|0);
   $13 = HEAP32[$12>>2]|0;
   $$0 = $13;
   STACKTOP = sp;return ($$0|0);
  }
 }
 L10: do {
  if ($4) {
   $20 = $1;
   label = 9;
  } else {
   $15 = $1;
   while(1) {
    $14 = HEAP32[$15>>2]|0;
    $16 = ($14|0)==(-1);
    if ($16) {
     $20 = $15;
     label = 9;
     break L10;
    }
    $17 = (($15) + 4|0);
    $18 = ($17|0)==($3|0);
    if ($18) {
     break;
    } else {
     $15 = $17;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $19 = ($20|0)==($3|0);
  if (!($19)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $21 = (($info) + 120|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($info) + 116|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22|0)==($24|0);
 if (!($25)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 L21: do {
  if (!($4)) {
   $29 = $1;
   while(1) {
    $28 = HEAP32[$29>>2]|0;
    $30 = ($28|0)>(0);
    $27 = (($29) + 4|0);
    if ($30) {
     $$0 = 0;
     break;
    }
    $26 = ($27|0)==($3|0);
    if ($26) {
     break L21;
    } else {
     $29 = $27;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $31 = (($klass) + 48|0);
 $32 = HEAP32[$31>>2]|0;
 $$0 = $32;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class12HasAttributeEP8TypeInfoS3_($klass,$attr_class) {
 $klass = $klass|0;
 $attr_class = $attr_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP8TypeInfo($klass)|0);
 $1 = (($0) + 4|0);
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $i$01 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $7 = HEAP32[$1>>2]|0;
  $8 = (($7) + ($i$01<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($9)|0);
  $11 = ($10|0)==($attr_class|0);
  $6 = (($i$01) + 1)|0;
  if ($11) {
   $$0 = 1;
   label = 4;
   break;
  }
  $4 = HEAP32[$0>>2]|0;
  $5 = ($6|0)<($4|0);
  if ($5) {
   $i$01 = $6;
  } else {
   $$0 = 0;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Class6IsEnumEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 117|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm5Class8GetImageEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Class8GetCCtorEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $$0 = 0, $$0$i2$us$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $res$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 123|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($klass)|0);
 $$03$i = $klass;
 while(1) {
  $3 = (($$03$i) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  L6: do {
   if ($5) {
    $res$1$i = 0;
   } else {
    $7 = 0;
    while(1) {
     $6 = ($7|0)==(0|0);
     if ($6) {
      $11 = HEAP32[$4>>2]|0;
      $12 = ($11|0)==(0|0);
      if ($12) {
       $res$1$i = 0;
       break L6;
      } else {
       $$0$i2$us$i = $11;$26 = $4;
      }
     } else {
      $8 = (($7) + 4|0);
      $9 = HEAP32[$8>>2]|0;
      $10 = ($9|0)==(0|0);
      if ($10) {
       $res$1$i = 0;
       break L6;
      } else {
       $$0$i2$us$i = $9;$26 = $8;
      }
     }
     $13 = HEAP32[$$0$i2$us$i>>2]|0;
     $14 = HEAP8[$13>>0]|0;
     $15 = ($14<<24>>24)==(46);
     if (!($15)) {
      $7 = $26;
      continue;
     }
     $16 = (_strcmp(348224,$13)|0);
     $17 = ($16|0)==(0);
     if (!($17)) {
      $7 = $26;
      continue;
     }
     $18 = (($$0$i2$us$i) + 28|0);
     $19 = HEAP16[$18>>1]|0;
     $20 = $19 & 2048;
     $21 = ($20<<16>>16)==(0);
     if ($21) {
      $7 = $26;
     } else {
      $res$1$i = $$0$i2$us$i;
      break;
     }
    }
   }
  } while(0);
  $22 = (($$03$i) + 20|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)!=(0|0);
  $25 = ($res$1$i|0)==(0|0);
  $or$cond$i = $24 & $25;
  if ($or$cond$i) {
   $$03$i = $23;
  } else {
   $$0 = $res$1$i;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class20GetFieldDefaultValueEPK9FieldInfoP14Il2CppTypeEnum($field,$def_type) {
 $field = $field|0;
 $def_type = $def_type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $entry$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $10 = $4;$entry$03 = $3;
 }
 while(1) {
  $9 = HEAP32[$10>>2]|0;
  $11 = ($9|0)==($field|0);
  $7 = (($entry$03) + 4|0);
  if ($11) {
   break;
  }
  $6 = HEAP32[$7>>2]|0;
  $8 = ($6|0)==(0|0);
  if ($8) {
   $$0 = 0;
   label = 5;
   break;
  } else {
   $10 = $6;$entry$03 = $7;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($10) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$def_type>>2] = $13;
 $14 = (($10) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Class18GetStaticFieldDataEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (348120|0);
}
function __ZN6il2cpp2vm5Class15GetAssemblyNameEPK8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm6Domain10GetCurrentEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[348232>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__Z21il2cpp_gc_alloc_fixedjPv(12,0)|0);
  HEAP32[348232>>2] = $2;
  $$0 = $2;
 } else {
  $$0 = $0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm6Domain7GetRootEv() {
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[348232>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__Z21il2cpp_gc_alloc_fixedjPv(12,0)|0);
  HEAP32[348232>>2] = $2;
  $$0$i = $2;
 } else {
  $$0$i = $0;
 }
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN6il2cpp2vm11Environment11SetMainArgsEPPci($args,$num_args) {
 $args = $args|0;
 $num_args = $num_args|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[348248>>2] = $args;
 HEAP32[348240>>2] = $num_args;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm11Environment11GetMainArgsEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[348248>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm11Environment14GetNumMainArgsEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[348240>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex) {
 $ex = $ex|0;
 var $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$012 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep4$i$i$i$i$i711 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Thread7CurrentEv()|0);
 $1 = (__ZN6il2cpp2vm6Thread14GetStackFramesEP12Il2CppThread($0)|0);
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $25 = 0;$scevgep4$i$i$i$i$i711 = 0;
 } else {
  $10 = ($8>>>0)>(1073741823);
  if ($10) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $11 = (__Znwj($7)|0);
  $12 = HEAP32[$1>>2]|0;
  $13 = HEAP32[$2>>2]|0;
  $14 = ($12|0)==($13|0);
  if ($14) {
   $25 = $11;$scevgep4$i$i$i$i$i711 = $11;
  } else {
   $$01$i$i$i = $12;$16 = $11;
   while(1) {
    $15 = ($16|0)==(0|0);
    if ($15) {
     $19 = 0;
    } else {
     $17 = HEAP32[$$01$i$i$i>>2]|0;
     HEAP32[$16>>2] = $17;
     $19 = $16;
    }
    $18 = (($19) + 4|0);
    $20 = (($$01$i$i$i) + 4|0);
    $21 = ($20|0)==($13|0);
    if ($21) {
     $25 = $11;$scevgep4$i$i$i$i$i711 = $18;
     break;
    } else {
     $$01$i$i$i = $20;$16 = $18;
    }
   }
  }
 }
 $22 = HEAP32[((388944 + 40|0))>>2]|0;
 $23 = $scevgep4$i$i$i$i$i711;
 $24 = $25;
 $26 = (($23) - ($24))|0;
 $27 = $26 >> 2;
 __THREW__ = 0;
 $28 = (invoke_iii(2229,($22|0),($27|0))|0);
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 L12: do {
  if ($30) {
   label = 14;
  } else {
   $31 = ($25|0)==($scevgep4$i$i$i$i$i711|0);
   L14: do {
    if (!($31)) {
     $36 = $25;$i$012 = 0;
     while(1) {
      __THREW__ = 0;
      $32 = (invoke_iiii(1477,($28|0),4,($i$012|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$32>>2] = $35;
      $37 = (($36) + 4|0);
      $38 = (($i$012) + 1)|0;
      $39 = ($37|0)==($scevgep4$i$i$i$i$i711|0);
      if ($39) {
       break L14;
      } else {
       $36 = $37;$i$012 = $38;
      }
     }
     $44 = ___cxa_find_matching_catch()|0;
     $45 = tempRet0;
     $lpad$phi$index = $44;$lpad$phi$index2 = $45;
     break L12;
    }
   } while(0);
   $40 = (($ex) + 8|0);
   HEAP32[$40>>2] = $28;
   $41 = (___cxa_allocate_exception(4)|0);
   HEAP32[$41>>2] = $ex;
   __THREW__ = 0;
   invoke_viii(1567,($41|0),(348288|0),(0|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    label = 14;
   } else {
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $lpad$phi$index = $46;$lpad$phi$index2 = $47;
 }
 $48 = ($25|0)==(0|0);
 if ($48) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __ZdlPv($25);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN6il2cpp2vm9Exception25RaiseOutOfMemoryExceptionEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348488)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 // unreachable;
}
function __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348440)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($2);
 // unreachable;
}
function __ZN6il2cpp2vm9Exception11FromNameMsgEPK11Il2CppImagePKcS6_S6_($image,$name_space,$name,$msg) {
 $image = $image|0;
 $name_space = $name_space|0;
 $name = $name|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($image,$name_space,$name)|0);
 $1 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($0)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($1);
 $2 = ($msg|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return ($1|0);
 }
 $3 = (__ZN6il2cpp2vm6String3NewEPKc($msg)|0);
 $4 = (($1) + 16|0);
 HEAP32[$4>>2] = $3;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm9Exception20GetArgumentExceptionEPKcS3_($arg,$msg) {
 $arg = $arg|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348304)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 $3 = ($msg|0)==(0|0);
 if (!($3)) {
  $4 = (__ZN6il2cpp2vm6String3NewEPKc($msg)|0);
  $5 = (($2) + 16|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = ($arg|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return ($2|0);
 }
 $7 = (__ZN6il2cpp2vm6String3NewEPKc($arg)|0);
 $8 = (($2) + 52|0);
 HEAP32[$8>>2] = $7;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc($arg) {
 $arg = $arg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348328)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 $3 = ($arg|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return ($2|0);
 }
 $4 = (__ZN6il2cpp2vm6String3NewEPKc($arg)|0);
 $5 = (($2) + 52|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception30GetTypeInitializationExceptionEPKcP15Il2CppException($msg,$innerException) {
 $msg = $msg|0;
 $innerException = $innerException|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348352)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 $3 = ($msg|0)==(0|0);
 if (!($3)) {
  $4 = (__ZN6il2cpp2vm6String3NewEPKc($msg)|0);
  $5 = (($2) + 16|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = ($innerException|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return ($2|0);
 }
 $7 = (($2) + 12|0);
 HEAP32[$7>>2] = $innerException;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348384)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception27GetIndexOutOfRangeExceptionEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348408)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception20GetTypeLoadExceptionEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348464)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception20GetOverflowExceptionEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348512)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception18GetFormatExceptionEPKc($msg) {
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348536)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 $3 = ($msg|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return ($2|0);
 }
 $4 = (__ZN6il2cpp2vm6String3NewEPKc($msg)|0);
 $5 = (($2) + 16|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception24GetNotSupportedExceptionEPKc($msg) {
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348552)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 $3 = ($msg|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return ($2|0);
 }
 $4 = (__ZN6il2cpp2vm6String3NewEPKc($msg)|0);
 $5 = (($2) + 16|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception29GetArrayTypeMismatchExceptionEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348576)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm9Exception20GetTypeLoadExceptionEPKc($msg) {
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm5Image9GetCorlibEv()|0);
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,348296,348464)|0);
 $2 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($2);
 $3 = ($msg|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return ($2|0);
 }
 $4 = (__ZN6il2cpp2vm6String3NewEPKc($msg)|0);
 $5 = (($2) + 16|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return ($2|0);
}
function __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_SB_($agg$result,$__lhs,$__rhs) {
 $agg$result = $agg$result|0;
 $__lhs = $__lhs|0;
 $__rhs = $__rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $0 = HEAP8[$__lhs>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $19 = $6;
 } else {
  $3 = (($__lhs) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $19 = $4;
 }
 $7 = HEAP8[$__rhs>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $12 = $7&255;
  $13 = $12 >>> 1;
  $18 = $13;
 } else {
  $10 = (($__rhs) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $18 = $11;
 }
 if ($2) {
  $16 = (($__lhs) + 1|0);
  $35 = $16;
 } else {
  $14 = (($__lhs) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $35 = $15;
 }
 $17 = (($18) + ($19))|0;
 $20 = ($17>>>0)>(4294967279);
 do {
  if ($20) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    // unreachable;
   }
  } else {
   $23 = ($17>>>0)<(11);
   if ($23) {
    $24 = $19 << 1;
    $25 = $24&255;
    HEAP8[$agg$result>>0] = $25;
    $26 = (($agg$result) + 1|0);
    $__p$0$i = $26;
   } else {
    $27 = (($17) + 16)|0;
    $28 = $27 & -16;
    __THREW__ = 0;
    $29 = (invoke_ii(2988,($28|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = (($agg$result) + 8|0);
    HEAP32[$32>>2] = $29;
    $33 = $28 | 1;
    HEAP32[$agg$result>>2] = $33;
    $34 = (($agg$result) + 4|0);
    HEAP32[$34>>2] = $19;
    $__p$0$i = $29;
   }
   _memcpy(($__p$0$i|0),($35|0),($19|0))|0;
   $36 = (($__p$0$i) + ($19)|0);
   HEAP8[$36>>0] = 0;
   $37 = HEAP8[$__rhs>>0]|0;
   $38 = $37 & 1;
   $39 = ($38<<24>>24)==(0);
   if ($39) {
    $42 = (($__rhs) + 1|0);
    $43 = $42;
   } else {
    $40 = (($__rhs) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    $43 = $41;
   }
   __THREW__ = 0;
   (invoke_iiii(1480,($agg$result|0),($43|0),($18|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $46 = ___cxa_find_matching_catch()|0;
 $47 = tempRet0;
 $48 = HEAP8[$agg$result>>0]|0;
 $49 = $48 & 1;
 $50 = ($49<<24>>24)==(0);
 if ($50) {
  ___resumeException($46|0);
  // unreachable;
 }
 $51 = (($agg$result) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 __ZdlPv($52);
 ___resumeException($46|0);
 // unreachable;
}
function __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_($agg$result,$__lhs,$__rhs) {
 $agg$result = $agg$result|0;
 $__lhs = $__lhs|0;
 $__rhs = $__rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__p$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $0 = HEAP8[$__lhs>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $8 = $0&255;
  $9 = $8 >>> 1;
  $10 = (_strlen(($__rhs|0))|0);
  $11 = (($__lhs) + 1|0);
  $13 = $10;$14 = $9;$30 = $11;
 } else {
  $3 = (($__lhs) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (_strlen(($__rhs|0))|0);
  $6 = (($__lhs) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $13 = $5;$14 = $4;$30 = $7;
 }
 $12 = (($13) + ($14))|0;
 $15 = ($12>>>0)>(4294967279);
 do {
  if ($15) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    // unreachable;
   }
  } else {
   $18 = ($12>>>0)<(11);
   if ($18) {
    $19 = $14 << 1;
    $20 = $19&255;
    HEAP8[$agg$result>>0] = $20;
    $21 = (($agg$result) + 1|0);
    $__p$0$i = $21;
   } else {
    $22 = (($12) + 16)|0;
    $23 = $22 & -16;
    __THREW__ = 0;
    $24 = (invoke_ii(2988,($23|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = (($agg$result) + 8|0);
    HEAP32[$27>>2] = $24;
    $28 = $23 | 1;
    HEAP32[$agg$result>>2] = $28;
    $29 = (($agg$result) + 4|0);
    HEAP32[$29>>2] = $14;
    $__p$0$i = $24;
   }
   _memcpy(($__p$0$i|0),($30|0),($14|0))|0;
   $31 = (($__p$0$i) + ($14)|0);
   HEAP8[$31>>0] = 0;
   __THREW__ = 0;
   (invoke_iiii(1480,($agg$result|0),($__rhs|0),($13|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 $36 = HEAP8[$agg$result>>0]|0;
 $37 = $36 & 1;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  ___resumeException($34|0);
  // unreachable;
 }
 $39 = (($agg$result) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 __ZdlPv($40);
 ___resumeException($34|0);
 // unreachable;
}
function __ZN6il2cpp2vm5Field7GetNameEP9FieldInfo($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$field>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm5Field9GetParentEP9FieldInfo($field) {
 $field = $field|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Field8GetFlagsEP9FieldInfo($field) {
 $field = $field|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 65535;
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp2vm5Field9GetOffsetEP9FieldInfo($field) {
 $field = $field|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Field8GetValueEP12Il2CppObjectP9FieldInfoPv($obj,$field,$value) {
 $obj = $obj|0;
 $field = $field|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($obj) + ($1)|0);
 $3 = (($field) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN6il2cpp2vmL9set_valueEPK10Il2CppTypePvS4_b($4,$value,$2,1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vmL9set_valueEPK10Il2CppTypePvS4_b($type,$dest,$value,$deref_pointer) {
 $type = $type|0;
 $dest = $dest|0;
 $value = $value|0;
 $deref_pointer = $deref_pointer|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $t$0 = 0, $t$0$in = 0, $t$0$in$in = 0, $t$0$in$in$be = 0, $t$0$in$in$be$in$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1073741824;
 $3 = ($2|0)==(0);
 if (!($3)) {
  HEAP32[$dest>>2] = $value;
  STACKTOP = sp;return;
 }
 $t$0$in$in = $1;
 L5: while(1) {
  $t$0$in = $t$0$in$in >>> 16;
  $t$0 = $t$0$in & 255;
  switch ($t$0|0) {
  case 17:  {
   $36 = HEAP32[$0>>2]|0;
   $37 = $36 & 16711680;
   $38 = ($37|0)==(1114112);
   if (!($38)) {
    label = 33;
    break L5;
   }
   $39 = HEAP32[$type>>2]|0;
   $40 = (($39) + 117|0);
   $41 = HEAP8[$40>>0]|0;
   $42 = ($41<<24>>24)==(0);
   if ($42) {
    label = 33;
    break L5;
   }
   $43 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($39)|0);
   $$pn = $43;
   break;
  }
  case 9: case 8:  {
   label = 11;
   break L5;
   break;
  }
  case 20: case 28: case 18: case 29: case 14:  {
   label = 23;
   break L5;
   break;
  }
  case 21:  {
   $47 = HEAP32[$type>>2]|0;
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + 48|0);
   $50 = HEAP32[$49>>2]|0;
   $$pn = $50;
   break;
  }
  case 13:  {
   label = 20;
   break L5;
   break;
  }
  case 3: case 7: case 6:  {
   label = 8;
   break L5;
   break;
  }
  case 15: case 27:  {
   label = 26;
   break L5;
   break;
  }
  case 11: case 10:  {
   label = 14;
   break L5;
   break;
  }
  case 12:  {
   label = 17;
   break L5;
   break;
  }
  case 5: case 4: case 2:  {
   label = 5;
   break L5;
   break;
  }
  default: {
   label = 37;
   break L5;
  }
  }
  $t$0$in$in$be$in$in = (($$pn) + 4|0);
  $t$0$in$in$be = HEAP32[$t$0$in$in$be$in$in>>2]|0;
  $t$0$in$in = $t$0$in$in$be;
 }
 switch (label|0) {
  case 5: {
   $4 = ($value|0)==(0|0);
   if ($4) {
    $6 = 0;
   } else {
    $5 = HEAP8[$value>>0]|0;
    $6 = $5;
   }
   HEAP8[$dest>>0] = $6;
   STACKTOP = sp;return;
   break;
  }
  case 8: {
   $7 = ($value|0)==(0|0);
   if ($7) {
    $9 = 0;
   } else {
    $8 = HEAP16[$value>>1]|0;
    $9 = $8;
   }
   HEAP16[$dest>>1] = $9;
   STACKTOP = sp;return;
   break;
  }
  case 11: {
   $10 = ($value|0)==(0|0);
   if ($10) {
    $12 = 0;
   } else {
    $11 = HEAP32[$value>>2]|0;
    $12 = $11;
   }
   HEAP32[$dest>>2] = $12;
   STACKTOP = sp;return;
   break;
  }
  case 14: {
   $13 = ($value|0)==(0|0);
   if ($13) {
    $22 = 0;$25 = 0;
   } else {
    $14 = $value;
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + 4)|0;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $22 = $16;$25 = $19;
   }
   $20 = $dest;
   $21 = $20;
   HEAP32[$21>>2] = $22;
   $23 = (($20) + 4)|0;
   $24 = $23;
   HEAP32[$24>>2] = $25;
   STACKTOP = sp;return;
   break;
  }
  case 17: {
   $26 = ($value|0)==(0|0);
   if ($26) {
    $28 = Math_fround(0.0);
   } else {
    $27 = Math_fround(HEAPF32[$value>>2]);
    $28 = $27;
   }
   HEAPF32[$dest>>2] = $28;
   STACKTOP = sp;return;
   break;
  }
  case 20: {
   $29 = ($value|0)==(0|0);
   if ($29) {
    $31 = 0.0;
   } else {
    $30 = +HEAPF64[$value>>3];
    $31 = $30;
   }
   HEAPF64[$dest>>3] = $31;
   STACKTOP = sp;return;
   break;
  }
  case 23: {
   if ($deref_pointer) {
    $32 = HEAP32[$value>>2]|0;
    $33 = $32;
   } else {
    $33 = $value;
   }
   HEAP32[$dest>>2] = $33;
   STACKTOP = sp;return;
   break;
  }
  case 26: {
   if ($deref_pointer) {
    $34 = HEAP32[$value>>2]|0;
    $35 = $34;
   } else {
    $35 = $value;
   }
   HEAP32[$dest>>2] = $35;
   STACKTOP = sp;return;
   break;
  }
  case 33: {
   $44 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($type)|0);
   $45 = (__ZN6il2cpp2vm5Class12GetValueSizeEP8TypeInfoPj($44,0)|0);
   $46 = ($value|0)==(0|0);
   if ($46) {
    _memset(($dest|0),0,($45|0))|0;
    STACKTOP = sp;return;
   } else {
    _memcpy(($dest|0),($value|0),($45|0))|0;
    STACKTOP = sp;return;
   }
   break;
  }
  case 37: {
   STACKTOP = sp;return;
   break;
  }
 }
}
function __ZN6il2cpp2vm5Field14GetValueObjectEP9FieldInfoP12Il2CppObject($field,$obj) {
 $field = $field|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $extract$t = 0, $is_ref$0$off0 = 0, $is_static$0$off0 = 0, $o = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $o = sp + 4|0;
 $0 = (($field) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 16;
 $5 = $4 & 255;
 switch ($5|0) {
 case 17: case 13: case 10: case 11: case 12: case 8: case 9: case 24: case 25: case 3: case 6: case 7: case 2: case 4: case 5:  {
  $6 = $3 & 1073741824;
  $7 = ($6|0)!=(0);
  $is_ref$0$off0 = $7;
  break;
 }
 case 29: case 20: case 18: case 28: case 14:  {
  $is_ref$0$off0 = 1;
  break;
 }
 case 21:  {
  $8 = HEAP32[$1>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 113|0);
  $11 = HEAP8[$10>>0]|0;
  $extract$t = ($11<<24>>24)!=(1);
  $is_ref$0$off0 = $extract$t;
  break;
 }
 default: {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 $12 = $3 & 16;
 $13 = ($12|0)==(0);
 if ($13) {
  $is_static$0$off0 = 0;
 } else {
  HEAP32[$vararg_buffer1>>2] = 348632;
  (_printf((348608|0),($vararg_buffer1|0))|0);
  $is_static$0$off0 = 1;
 }
 if ($is_ref$0$off0) {
  if ($is_static$0$off0) {
   __ZN6il2cpp2vm5Field14StaticGetValueEP9FieldInfoPv($field,$o);
  } else {
   $14 = (($field) + 12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($obj) + ($15)|0);
   $17 = HEAP32[$0>>2]|0;
   __ZN6il2cpp2vmL9set_valueEPK10Il2CppTypePvS4_b($17,$o,$16,1);
  }
  $18 = HEAP32[$o>>2]|0;
  $$0 = $18;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($19)|0);
 $21 = (__ZN6il2cpp2vm5Class10IsNullableEPK8TypeInfo($20)|0);
 if ($21) {
  HEAP32[$vararg_buffer1>>2] = 348632;
  (_printf((348608|0),($vararg_buffer1|0))|0);
 }
 $22 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($20)|0);
 HEAP32[$o>>2] = $22;
 $23 = (($22) + 8|0);
 if ($is_static$0$off0) {
  __ZN6il2cpp2vm5Field14StaticGetValueEP9FieldInfoPv($field,$23);
  $$0 = $22;
  STACKTOP = sp;return ($$0|0);
 } else {
  $24 = (($field) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($obj) + ($25)|0);
  $27 = HEAP32[$0>>2]|0;
  __ZN6il2cpp2vmL9set_valueEPK10Il2CppTypePvS4_b($27,$23,$26,1);
  $$0 = $22;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Field14StaticGetValueEP9FieldInfoPv($field,$value) {
 $field = $field|0;
 $value = $value|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0.0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $def_type$i = 0, $src$0 = 0, $vararg_buffer4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer4 = sp;
 $def_type$i = sp + 4|0;
 $0 = (($field) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 64;
 $5 = ($4|0)==(0);
 if ($5) {
  $23 = (($field) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(-1);
  if ($25) {
   HEAP32[$vararg_buffer4>>2] = 348688;
   (_printf((348608|0),($vararg_buffer4|0))|0);
   $$pre = HEAP32[$0>>2]|0;
   $31 = $$pre;$src$0 = 0;
  } else {
   $26 = (($field) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 80|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + ($24)|0);
   $31 = $1;$src$0 = $30;
  }
  __ZN6il2cpp2vmL9set_valueEPK10Il2CppTypePvS4_b($31,$value,$src$0,1);
  STACKTOP = sp;return;
 }
 $6 = (__ZN6il2cpp2vm5Class20GetFieldDefaultValueEPK9FieldInfoP14Il2CppTypeEnum($field,$def_type$i)|0);
 $7 = HEAP32[$def_type$i>>2]|0;
 switch ($7|0) {
 case 6: case 7: case 3:  {
  $9 = HEAP16[$6>>1]|0;
  HEAP16[$value>>1] = $9;
  STACKTOP = sp;return;
  break;
 }
 case 14:  {
  HEAP32[$vararg_buffer4>>2] = 348656;
  (_printf((348608|0),($vararg_buffer4|0))|0);
  STACKTOP = sp;return;
  break;
 }
 case 13:  {
  $22 = +HEAPF64[$6>>3];
  HEAPF64[$value>>3] = $22;
  STACKTOP = sp;return;
  break;
 }
 case 4: case 5: case 2:  {
  $8 = HEAP8[$6>>0]|0;
  HEAP8[$value>>0] = $8;
  STACKTOP = sp;return;
  break;
 }
 case 12:  {
  $21 = Math_fround(HEAPF32[$6>>2]);
  HEAPF32[$value>>2] = $21;
  STACKTOP = sp;return;
  break;
 }
 case 18:  {
  HEAP32[$value>>2] = 0;
  HEAP32[$vararg_buffer4>>2] = 348656;
  (_printf((348608|0),($vararg_buffer4|0))|0);
  STACKTOP = sp;return;
  break;
 }
 case 8: case 9:  {
  $10 = HEAP32[$6>>2]|0;
  HEAP32[$value>>2] = $10;
  STACKTOP = sp;return;
  break;
 }
 case 10: case 11:  {
  $11 = $6;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = $value;
  $18 = $17;
  HEAP32[$18>>2] = $13;
  $19 = (($17) + 4)|0;
  $20 = $19;
  HEAP32[$20>>2] = $16;
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZN6il2cpp2vm5Field7GetTypeEP9FieldInfo($field) {
 $field = $field|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm5Field12HasAttributeEP9FieldInfoP8TypeInfo($field,$attr_class) {
 $field = $field|0;
 $attr_class = $attr_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP9FieldInfo($field)|0);
 $1 = (($0) + 4|0);
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $i$01 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $7 = HEAP32[$1>>2]|0;
  $8 = (($7) + ($i$01<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($9)|0);
  $11 = ($10|0)==($attr_class|0);
  $6 = (($i$01) + 1)|0;
  if ($11) {
   $$0 = 1;
   label = 4;
   break;
  }
  $4 = HEAP32[$0>>2]|0;
  $5 = ($6|0)<($4|0);
  if ($5) {
   $i$01 = $6;
  } else {
   $$0 = 0;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Field9IsDeletedEP9FieldInfo($field) {
 $field = $field|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6il2cpp2vm5Field8SetValueEP12Il2CppObjectP9FieldInfoPv($obj,$field,$value) {
 $obj = $obj|0;
 $field = $field|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($obj) + ($1)|0);
 $3 = (($field) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN6il2cpp2vmL9set_valueEPK10Il2CppTypePvS4_b($4,$2,$value,0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm5Field14StaticSetValueEP9FieldInfoPv($field,$value) {
 $field = $field|0;
 $value = $value|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 348712;
 (_printf((348608|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm5Field7GetDataEP9FieldInfo($field) {
 $field = $field|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $def_type = 0, $def_type1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $def_type = sp + 4|0;
 $def_type1 = sp;
 $0 = (($field) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 32768;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (__ZN6il2cpp2vm5Class20GetFieldDefaultValueEPK9FieldInfoP14Il2CppTypeEnum($field,$def_type)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = $3 & 256;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__ZN6il2cpp2vm5Class20GetFieldDefaultValueEPK9FieldInfoP14Il2CppTypeEnum($field,$def_type1)|0);
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm12GenericClass8GetClassEP18Il2CppGenericClass($gclass) {
 $gclass = $gclass|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($gclass) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm12GenericClass11IsValueTypeEP18Il2CppGenericClass($gclass) {
 $gclass = $gclass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$gclass>>2]|0;
 $1 = (($0) + 113|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZNK6il2cpp2vm17Il2CppTypeCompareclEPK10Il2CppTypeS4_($this,$t1,$t2) {
 $this = $this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm17Il2CppTypeCompare7compareEPK10Il2CppTypeS4_($t1,$t2)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm17Il2CppTypeCompare7compareEPK10Il2CppTypeS4_($t1,$t2) {
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (($t1) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 16;
 $3 = $2 & 255;
 $4 = (($t2) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 16;
 $7 = $6 & 255;
 $8 = ($3|0)==($7|0);
 L1: do {
  if ($8) {
   $9 = $5 ^ $1;
   $10 = $9 & 1073741824;
   $11 = ($10|0)==(0);
   if ($11) {
    switch ($3|0) {
    case 22: case 28: case 25: case 24: case 14: case 13: case 12: case 11: case 10: case 9: case 8: case 7: case 6: case 5: case 4: case 3: case 2: case 1:  {
     $$0 = 1;
     break L1;
     break;
    }
    case 15:  {
     HEAP32[$vararg_buffer1>>2] = 348760;
     (_printf((348736|0),($vararg_buffer1|0))|0);
     $$0 = 0;
     break L1;
     break;
    }
    case 20:  {
     $15 = HEAP32[$t1>>2]|0;
     $16 = (($15) + 4|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = HEAP32[$t2>>2]|0;
     $19 = (($18) + 4|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = ($17<<24>>24)==($20<<24>>24);
     if (!($21)) {
      $$0 = 0;
      break L1;
     }
     $22 = HEAP32[$15>>2]|0;
     $23 = HEAP32[$18>>2]|0;
     $24 = ($22|0)==($23|0);
     $$0 = $24;
     break L1;
     break;
    }
    case 30: case 19:  {
     $55 = HEAP32[$t1>>2]|0;
     $56 = HEAP32[$t2>>2]|0;
     $57 = ($55|0)==($56|0);
     $$0 = $57;
     break L1;
     break;
    }
    case 29: case 18: case 17:  {
     $12 = HEAP32[$t1>>2]|0;
     $13 = HEAP32[$t2>>2]|0;
     $14 = ($12|0)==($13|0);
     $$0 = $14;
     break L1;
     break;
    }
    case 21:  {
     $25 = HEAP32[$t1>>2]|0;
     $26 = (($25) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = HEAP32[$t2>>2]|0;
     $29 = (($28) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = HEAP32[$27>>2]|0;
     $32 = HEAP32[$30>>2]|0;
     $33 = ($31|0)==($32|0);
     if (!($33)) {
      $$0 = 0;
      break L1;
     }
     $34 = HEAP32[$25>>2]|0;
     $35 = (($34) + 48|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = HEAP32[$28>>2]|0;
     $38 = (($37) + 48|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (__ZN6il2cpp2vm17Il2CppTypeCompare7compareEPK10Il2CppTypeS4_($36,$39)|0);
     if (!($40)) {
      $$0 = 0;
      break L1;
     }
     $41 = HEAP32[$27>>2]|0;
     $42 = ($41|0)==(0);
     if ($42) {
      $$0 = 1;
      break L1;
     }
     $43 = (($27) + 4|0);
     $44 = (($30) + 4|0);
     $i$01 = 0;
     while(1) {
      $48 = HEAP32[$43>>2]|0;
      $49 = (($48) + ($i$01<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = HEAP32[$44>>2]|0;
      $52 = (($51) + ($i$01<<2)|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (__ZN6il2cpp2vm17Il2CppTypeCompare7compareEPK10Il2CppTypeS4_($50,$53)|0);
      $47 = (($i$01) + 1)|0;
      if (!($54)) {
       $$0 = 0;
       break L1;
      }
      $45 = HEAP32[$27>>2]|0;
      $46 = ($47>>>0)<($45>>>0);
      if ($46) {
       $i$01 = $47;
      } else {
       $$0 = 1;
       break;
      }
     }
     break;
    }
    default: {
     HEAP32[$vararg_buffer1>>2] = 348760;
     (_printf((348736|0),($vararg_buffer1|0))|0);
     $$0 = 0;
     break L1;
    }
    }
   } else {
    $$0 = 0;
   }
  } else {
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm5Image8RegisterEP11Il2CppImage($image) {
 $image = $image|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 $0 = (__Znwj(72)|0);
 dest=$0+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $1 = (($0) + 16|0);
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 20|0);
 HEAP32[$2>>2] = 0;
 $3 = (($0) + 12|0);
 HEAP32[$3>>2] = $1;
 $4 = (($0) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($0) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = (($0) + 24|0);
 HEAP32[$6>>2] = $4;
 $7 = (($0) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = (($0) + 44|0);
 HEAP32[$8>>2] = 0;
 $9 = (($0) + 36|0);
 HEAP32[$9>>2] = $7;
 $10 = (($0) + 52|0);
 HEAP32[$10>>2] = 0;
 $11 = (($0) + 56|0);
 HEAP32[$11>>2] = 0;
 $12 = (($0) + 48|0);
 HEAP32[$12>>2] = $10;
 $13 = (($0) + 64|0);
 HEAP32[$13>>2] = 0;
 $14 = (($0) + 68|0);
 HEAP32[$14>>2] = 0;
 $15 = (($0) + 60|0);
 HEAP32[$15>>2] = $13;
 $16 = (($image) + 4|0);
 HEAP32[$16>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm5Image10InitializeEP11Il2CppImage($image) {
 $image = $image|0;
 var $$0$i$i$i = 0, $$0$i$i$i3 = 0, $$pre$i$i$i = 0, $$pre$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__nd$0$in$i$i$i = 0, $__nd$0$in$i$i$i1 = 0, $elementClass2 = 0;
 var $gvm$024 = 0, $type$045 = 0, $type$141 = 0, $type$237 = 0, $type$333 = 0, $type$429 = 0, $type$525 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $elementClass2 = sp + 12|0;
 $2 = (($image) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($image) + 4|0);
  $type$045 = $3;
  while(1) {
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 12|0);
   __ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_($0,$8,$type$045);
   $9 = (($type$045) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    break;
   } else {
    $type$045 = $9;
   }
  }
 }
 $12 = (($image) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $17 = $14;$type$141 = $13;
  while(1) {
   $16 = (($17) + 28|0);
   $18 = HEAP32[$16>>2]|0;
   $19 = (($18) + 64|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($17) + 64|0);
   HEAP32[$21>>2] = $20;
   $22 = (($type$141) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    break;
   } else {
    $17 = $23;$type$141 = $22;
   }
  }
 }
 $25 = (($image) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $30 = $27;$type$237 = $26;
  while(1) {
   $29 = (($30) + 28|0);
   $31 = HEAP32[$29>>2]|0;
   $32 = (($31) + 64|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($30) + 64|0);
   HEAP32[$34>>2] = $33;
   $35 = (($type$237) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    break;
   } else {
    $30 = $36;$type$237 = $35;
   }
  }
 }
 $38 = HEAP32[$12>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $42 = $39;$type$333 = $38;
  while(1) {
   $41 = (($42) + 28|0);
   $43 = HEAP32[$41>>2]|0;
   HEAP32[$elementClass2>>2] = $43;
   $44 = HEAP32[$type$333>>2]|0;
   $45 = (($43) + 64|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($46) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + 24|0);
   $50 = (__ZNSt3__13mapIP8TypeInfoS2_NS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S2_EEEEEixERS7_($49,$elementClass2)|0);
   HEAP32[$50>>2] = $44;
   $51 = (($type$333) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    break;
   } else {
    $42 = $52;$type$333 = $51;
   }
  }
 }
 $54 = HEAP32[$25>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $58 = $55;$type$429 = $54;
  while(1) {
   $57 = (($58) + 28|0);
   $59 = HEAP32[$57>>2]|0;
   $60 = (($59) + 64|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($61) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = $59;
   $65 = $58;
   $66 = (($63) + 40|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(0|0);
   if ($68) {
    $77 = (($63) + 40|0);
    $$0$i$i$i = $77;$86 = $77;
   } else {
    $__nd$0$in$i$i$i = $67;
    while(1) {
     $69 = (($__nd$0$in$i$i$i) + 16|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($59>>>0)<($70>>>0);
     if ($71) {
      $72 = HEAP32[$__nd$0$in$i$i$i>>2]|0;
      $73 = ($72|0)==(0|0);
      if ($73) {
       $$0$i$i$i = $__nd$0$in$i$i$i;$86 = $__nd$0$in$i$i$i;
       break;
      } else {
       $__nd$0$in$i$i$i = $72;
       continue;
      }
     } else {
      $74 = (($__nd$0$in$i$i$i) + 4|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($75|0)==(0|0);
      if ($76) {
       $$0$i$i$i = $74;$86 = $__nd$0$in$i$i$i;
       break;
      } else {
       $__nd$0$in$i$i$i = $75;
       continue;
      }
     }
    }
   }
   $78 = (__Znwj(24)|0);
   $79 = (($78) + 16|0);
   $80 = $79;
   $81 = $80;
   HEAP32[$81>>2] = $64;
   $82 = (($80) + 4)|0;
   $83 = $82;
   HEAP32[$83>>2] = $65;
   HEAP32[$78>>2] = 0;
   $84 = (($78) + 4|0);
   HEAP32[$84>>2] = 0;
   $85 = (($78) + 8|0);
   HEAP32[$85>>2] = $86;
   HEAP32[$$0$i$i$i>>2] = $78;
   $87 = (($63) + 36|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)==(0|0);
   if ($90) {
    $92 = $78;
   } else {
    HEAP32[$87>>2] = $89;
    $$pre$i$i$i = HEAP32[$$0$i$i$i>>2]|0;
    $92 = $$pre$i$i$i;
   }
   $91 = HEAP32[$66>>2]|0;
   __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($91,$92);
   $93 = (($63) + 44|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 1)|0;
   HEAP32[$93>>2] = $95;
   $96 = (($type$429) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0|0);
   if ($98) {
    break;
   } else {
    $58 = $97;$type$429 = $96;
   }
  }
 }
 $99 = (($image) + 12|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==(0|0);
 if (!($102)) {
  $104 = $101;$type$525 = $100;
  while(1) {
   $103 = (($104) + 68|0);
   $105 = HEAP32[$103>>2]|0;
   $106 = HEAP32[$105>>2]|0;
   $107 = (($104) + 64|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($108) + 4|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = $106;
   $112 = $104;
   $113 = (($110) + 52|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==(0|0);
   if ($115) {
    $124 = (($110) + 52|0);
    $$0$i$i$i3 = $124;$133 = $124;
   } else {
    $__nd$0$in$i$i$i1 = $114;
    while(1) {
     $116 = (($__nd$0$in$i$i$i1) + 16|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ($106>>>0)<($117>>>0);
     if ($118) {
      $119 = HEAP32[$__nd$0$in$i$i$i1>>2]|0;
      $120 = ($119|0)==(0|0);
      if ($120) {
       $$0$i$i$i3 = $__nd$0$in$i$i$i1;$133 = $__nd$0$in$i$i$i1;
       break;
      } else {
       $__nd$0$in$i$i$i1 = $119;
       continue;
      }
     } else {
      $121 = (($__nd$0$in$i$i$i1) + 4|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = ($122|0)==(0|0);
      if ($123) {
       $$0$i$i$i3 = $121;$133 = $__nd$0$in$i$i$i1;
       break;
      } else {
       $__nd$0$in$i$i$i1 = $122;
       continue;
      }
     }
    }
   }
   $125 = (__Znwj(24)|0);
   $126 = (($125) + 16|0);
   $127 = $126;
   $128 = $127;
   HEAP32[$128>>2] = $111;
   $129 = (($127) + 4)|0;
   $130 = $129;
   HEAP32[$130>>2] = $112;
   HEAP32[$125>>2] = 0;
   $131 = (($125) + 4|0);
   HEAP32[$131>>2] = 0;
   $132 = (($125) + 8|0);
   HEAP32[$132>>2] = $133;
   HEAP32[$$0$i$i$i3>>2] = $125;
   $134 = (($110) + 48|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = HEAP32[$135>>2]|0;
   $137 = ($136|0)==(0|0);
   if ($137) {
    $139 = $125;
   } else {
    HEAP32[$134>>2] = $136;
    $$pre$i$i$i5 = HEAP32[$$0$i$i$i3>>2]|0;
    $139 = $$pre$i$i$i5;
   }
   $138 = HEAP32[$113>>2]|0;
   __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($138,$139);
   $140 = (($110) + 56|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = (($141) + 1)|0;
   HEAP32[$140>>2] = $142;
   $143 = (($type$525) + 4|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ($144|0)==(0|0);
   if ($145) {
    break;
   } else {
    $104 = $144;$type$525 = $143;
   }
  }
 }
 $146 = (($image) + 28|0);
 $147 = HEAP32[$146>>2]|0;
 $148 = (($147) + 4|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = ($149|0)==(0|0);
 if ($150) {
  STACKTOP = sp;return;
 }
 $151 = (($1) + 8|0);
 $153 = $149;$gvm$024 = $147;
 while(1) {
  $152 = (($153) + 8|0);
  $154 = HEAP32[$152>>2]|0;
  $155 = (($154) + 64|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = (($156) + 4|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = HEAP32[$gvm$024>>2]|0;
  $160 = (($gvm$024) + 8|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = $159;
  $163 = $153;
  $164 = (($158) + 60|0);
  $165 = $1;
  $166 = $165;
  HEAP32[$166>>2] = $162;
  $167 = (($165) + 4)|0;
  $168 = $167;
  HEAP32[$168>>2] = $163;
  HEAP32[$151>>2] = $161;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIP8TypeInfoP10MethodInfoEES6_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS_9allocatorIS8_EEE15__insert_uniqueERKS8_($0,$164,$1);
  $169 = (($gvm$024) + 12|0);
  $170 = (($gvm$024) + 16|0);
  $171 = HEAP32[$170>>2]|0;
  $172 = ($171|0)==(0|0);
  if ($172) {
   break;
  } else {
   $153 = $171;$gvm$024 = $169;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIP8TypeInfoS2_NS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S2_EEEEEixERS7_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$22 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3>>>0)<($5>>>0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5>>>0)<($3>>>0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $31 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($31|0);
 }
 $16 = (__Znwj(24)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$16>>2] = 0;
 $20 = (($16) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $16;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $16;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $__r$0 = $16;
 $31 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($31|0);
}
function __ZN6il2cpp2vm5Image9GetCorlibEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[388944>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm5Image13ClassFromNameEPK11Il2CppImagePKcS6_($image,$namespaze,$name) {
 $image = $image|0;
 $namespaze = $namespaze|0;
 $name = $name|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($image) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 16|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $7 = $3;
 }
 while(1) {
  $6 = (($7) + 16|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (_strcmp($namespaze,$10)|0);
  $12 = ($11|0)==(0);
  if ($12) {
   $13 = HEAP32[$8>>2]|0;
   $14 = (_strcmp($name,$13)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = (($8) + 24|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$0 = $8;
     label = 10;
     break;
    }
   }
  }
  $19 = (($7) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if ($21) {
   $$01$i$i$i = $7;
   while(1) {
    $24 = (($$01$i$i$i) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==($$01$i$i$i|0);
    if ($27) {
     $$0$i$i$i = $25;
     break;
    } else {
     $$01$i$i$i = $25;
    }
   }
  } else {
   $$0$i$i$i$i = $20;
   while(1) {
    $22 = HEAP32[$$0$i$i$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $22;
    }
   }
  }
  $28 = ($$0$i$i$i|0)==($4|0);
  if ($28) {
   $$0 = 0;
   label = 10;
   break;
  } else {
   $7 = $$0$i$i$i;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Image17FindClassMatchingEP11Il2CppImagePKcS5_P8TypeInfo($image,$namespaze,$name,$nested_in) {
 $image = $image|0;
 $namespaze = $namespaze|0;
 $name = $name|0;
 $nested_in = $nested_in|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($image) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 16|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $7 = $3;
 }
 while(1) {
  $6 = (($7) + 16|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (_strcmp($namespaze,$10)|0);
  $12 = ($11|0)==(0);
  if ($12) {
   $13 = HEAP32[$8>>2]|0;
   $14 = (_strcmp($name,$13)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = (($8) + 24|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==($nested_in|0);
    if ($18) {
     $$0 = $8;
     label = 10;
     break;
    }
   }
  }
  $19 = (($7) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if ($21) {
   $$01$i$i$i = $7;
   while(1) {
    $24 = (($$01$i$i$i) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==($$01$i$i$i|0);
    if ($27) {
     $$0$i$i$i = $25;
     break;
    } else {
     $$01$i$i$i = $25;
    }
   }
  } else {
   $$0$i$i$i$i = $20;
   while(1) {
    $22 = HEAP32[$$0$i$i$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $22;
    }
   }
  }
  $28 = ($$0$i$i$i|0)==($4|0);
  if ($28) {
   $$0 = 0;
   label = 10;
   break;
  } else {
   $7 = $$0$i$i$i;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Image21FromTypeNameParseInfoEP11Il2CppImageRKNS0_17TypeNameParseInfoE($image,$info) {
 $image = $image|0;
 $info = $info|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i4 = 0, $$0$i$i$i$i8 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $parent_class$017 = 0, $strcmpload = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$info>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($info) + 1|0);
  $24 = $5;
 } else {
  $3 = (($info) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $24 = $4;
 }
 $6 = (($info) + 12|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $12 = (($6) + 1|0);
  $28 = $12;
 } else {
  $10 = (($info) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $28 = $11;
 }
 $13 = (($image) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 16|0);
 $18 = ($16|0)==($17|0);
 if ($18) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = $16;
 while(1) {
  $19 = (($20) + 16|0);
  $21 = HEAP32[$19>>2]|0;
  $22 = (($21) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $25 = (_strcmp($24,$23)|0);
  $26 = ($25|0)==(0);
  if ($26) {
   $27 = HEAP32[$21>>2]|0;
   $29 = (_strcmp($28,$27)|0);
   $30 = ($29|0)==(0);
   if ($30) {
    $31 = (($21) + 24|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     break;
    }
   }
  }
  $34 = (($20) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   $$01$i$i$i$i6 = $20;
   while(1) {
    $39 = (($$01$i$i$i$i6) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==($$01$i$i$i$i6|0);
    if ($42) {
     $$0$i$i$i$i8 = $40;
     break;
    } else {
     $$01$i$i$i$i6 = $40;
    }
   }
  } else {
   $$0$i$i$i$i$i4 = $35;
   while(1) {
    $37 = HEAP32[$$0$i$i$i$i$i4>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     $$0$i$i$i$i8 = $$0$i$i$i$i$i4;
     break;
    } else {
     $$0$i$i$i$i$i4 = $37;
    }
   }
  }
  $43 = ($$0$i$i$i$i8|0)==($17|0);
  if ($43) {
   $$0 = 0;
   label = 33;
   break;
  } else {
   $20 = $$0$i$i$i$i8;
  }
 }
 if ((label|0) == 33) {
  STACKTOP = sp;return ($$0|0);
 }
 $44 = ($21|0)==(0|0);
 if ($44) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($info) + 128|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($info) + 132|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($46|0)==($48|0);
 if ($49) {
  $$0 = $21;
  STACKTOP = sp;return ($$0|0);
 } else {
  $53 = $46;$parent_class$017 = $21;
 }
 L33: while(1) {
  $52 = HEAP8[$53>>0]|0;
  $54 = $52 & 1;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   $58 = (($53) + 1|0);
   $66 = $58;
  } else {
   $56 = (($53) + 8|0);
   $57 = HEAP32[$56>>2]|0;
   $66 = $57;
  }
  $60 = $16;
  while(1) {
   $59 = (($60) + 16|0);
   $61 = HEAP32[$59>>2]|0;
   $62 = (($61) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $strcmpload = HEAP8[$63>>0]|0;
   $64 = ($strcmpload<<24>>24)==(0);
   if ($64) {
    $65 = HEAP32[$61>>2]|0;
    $67 = (_strcmp($66,$65)|0);
    $68 = ($67|0)==(0);
    if ($68) {
     $69 = (($61) + 24|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==($parent_class$017|0);
     if ($71) {
      break;
     }
    }
   }
   $72 = (($60) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    $$01$i$i$i$i = $60;
    while(1) {
     $77 = (($$01$i$i$i$i) + 8|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)==($$01$i$i$i$i|0);
     if ($80) {
      $$0$i$i$i$i = $78;
      break;
     } else {
      $$01$i$i$i$i = $78;
     }
    }
   } else {
    $$0$i$i$i$i$i = $73;
    while(1) {
     $75 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $76 = ($75|0)==(0|0);
     if ($76) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $75;
     }
    }
   }
   $81 = ($$0$i$i$i$i|0)==($17|0);
   if ($81) {
    $$0 = 0;
    label = 33;
    break L33;
   } else {
    $60 = $$0$i$i$i$i;
   }
  }
  $82 = ($61|0)==(0|0);
  $51 = (($53) + 12|0);
  if ($82) {
   $$0 = 0;
   label = 33;
   break;
  }
  $50 = ($51|0)==($48|0);
  if ($50) {
   $$0 = $61;
   label = 33;
   break;
  } else {
   $53 = $51;$parent_class$017 = $61;
  }
 }
 if ((label|0) == 33) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Image20GetBoundedArrayClassEP8TypeInfojb($eclass,$rank,$bounded) {
 $eclass = $eclass|0;
 $rank = $rank|0;
 $bounded = $bounded|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i8$i$i = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i3 = 0, $$0$ph7$i3$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i4 = 0, $$01$ph6$i4$in$i$i = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i6 = 0, $$013$i6$in$i$i = 0, $$bounded = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__result$0$ph34$i$i = 0, $__rt$0$in$i$i = 0, $__rt$0$in25$i$i = 0, $__rt$0$in2532$i$i = 0, $__rt$02636$in$i$i = 0, $__rt$028$in$i$i = 0, $brmerge = 0, $not$ = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($eclass) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $not$ = ($rank>>>0)<(2);
 $$bounded = $not$ & $bounded;
 $$not = ($rank|0)!=(1);
 $brmerge = $$not | $$bounded;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 if (!($brmerge)) {
  $4 = (($3) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 28|0);
  $7 = ($5|0)==(0|0);
  if ($7) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0$ph7$i$i$i = $6;$$01$ph6$i$in$i$i = $5;
  }
  L5: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $8 = (($$013$i$in$i$i) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9>>>0)<($eclass>>>0);
    if (!($10)) {
     break;
    }
    $13 = (($$013$i$in$i$i) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L5;
    } else {
     $$013$i$in$i$i = $14;
    }
   }
   $11 = HEAP32[$$013$i$in$i$i>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $11;
   }
  }
  $16 = ($$0$ph5$i$i$i|0)==($6|0);
  if ($16) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $17 = (($$0$ph5$i$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18>>>0)>($eclass>>>0);
  $20 = ($$0$ph5$i$i$i|0)==($6|0);
  $or$cond = $19 | $20;
  if ($or$cond) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $21 = (($$0$ph5$i$i$i) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($22)|0);
  $23 = HEAP32[$21>>2]|0;
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = (($3) + 40|0);
 $25 = (($3) + 40|0);
 $__rt$0$in2532$i$i = HEAP32[$25>>2]|0;
 $26 = ($__rt$0$in2532$i$i|0)==(0|0);
 if ($26) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $__result$0$ph34$i$i = $24;$__rt$02636$in$i$i = $__rt$0$in2532$i$i;
 }
 L22: while(1) {
  $__rt$028$in$i$i = $__rt$02636$in$i$i;
  while(1) {
   $29 = (($__rt$028$in$i$i) + 16|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30>>>0)>($eclass>>>0);
   if ($31) {
    break;
   }
   $33 = ($30>>>0)<($eclass>>>0);
   if (!($33)) {
    label = 16;
    break L22;
   }
   $27 = (($__rt$028$in$i$i) + 4|0);
   $__rt$0$in$i$i = HEAP32[$27>>2]|0;
   $28 = ($__rt$0$in$i$i|0)==(0|0);
   if ($28) {
    $$0 = 0;
    label = 34;
    break L22;
   } else {
    $__rt$028$in$i$i = $__rt$0$in$i$i;
   }
  }
  $__rt$0$in25$i$i = HEAP32[$__rt$028$in$i$i>>2]|0;
  $32 = ($__rt$0$in25$i$i|0)==(0|0);
  if ($32) {
   $$0 = 0;
   label = 34;
   break;
  } else {
   $__result$0$ph34$i$i = $__rt$028$in$i$i;$__rt$02636$in$i$i = $__rt$0$in25$i$i;
  }
 }
 if ((label|0) == 16) {
  $34 = HEAP32[$__rt$028$in$i$i>>2]|0;
  $35 = ($34|0)==(0|0);
  L31: do {
   if ($35) {
    $$0$ph5$i8$i$i = $__rt$028$in$i$i;
   } else {
    $$0$ph7$i3$i$i = $__rt$028$in$i$i;$$01$ph6$i4$in$i$i = $34;
    while(1) {
     $$013$i6$in$i$i = $$01$ph6$i4$in$i$i;
     while(1) {
      $36 = (($$013$i6$in$i$i) + 16|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = ($37>>>0)<($eclass>>>0);
      if (!($38)) {
       break;
      }
      $41 = (($$013$i6$in$i$i) + 4|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0|0);
      if ($43) {
       $$0$ph5$i8$i$i = $$0$ph7$i3$i$i;
       break L31;
      } else {
       $$013$i6$in$i$i = $42;
      }
     }
     $39 = HEAP32[$$013$i6$in$i$i>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      $$0$ph5$i8$i$i = $$013$i6$in$i$i;
      break;
     } else {
      $$0$ph7$i3$i$i = $$013$i6$in$i$i;$$01$ph6$i4$in$i$i = $39;
     }
    }
   }
  } while(0);
  $44 = (($__rt$028$in$i$i) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  L39: do {
   if ($46) {
    $56 = $__result$0$ph34$i$i;
   } else {
    $$0$ph7$i$i$i3 = $__result$0$ph34$i$i;$$01$ph6$i$in$i$i4 = $45;
    while(1) {
     $$013$i$in$i$i6 = $$01$ph6$i$in$i$i4;
     while(1) {
      $47 = (($$013$i$in$i$i6) + 16|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48>>>0)>($eclass>>>0);
      if ($49) {
       break;
      }
      $52 = (($$013$i$in$i$i6) + 4|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==(0|0);
      if ($54) {
       $56 = $$0$ph7$i$i$i3;
       break L39;
      } else {
       $$013$i$in$i$i6 = $53;
      }
     }
     $50 = HEAP32[$$013$i$in$i$i6>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      $56 = $$013$i$in$i$i6;
      break;
     } else {
      $$0$ph7$i$i$i3 = $$013$i$in$i$i6;$$01$ph6$i$in$i$i4 = $50;
     }
    }
   }
  } while(0);
  $55 = ($$0$ph5$i8$i$i|0)==($56|0);
  if ($55) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $58 = $$0$ph5$i8$i$i;
  }
  while(1) {
   $57 = (($58) + 20|0);
   $59 = HEAP32[$57>>2]|0;
   $60 = (($59) + 112|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61&255;
   $63 = ($62|0)==($rank|0);
   if ($63) {
    break;
   }
   $65 = (($58) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if ($67) {
    $$01$i$i$i = $58;
    while(1) {
     $70 = (($$01$i$i$i) + 8|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)==($$01$i$i$i|0);
     if ($73) {
      $$0$i$i$i = $71;
      break;
     } else {
      $$01$i$i$i = $71;
     }
    }
   } else {
    $$0$i$i$i$i = $66;
    while(1) {
     $68 = HEAP32[$$0$i$i$i$i>>2]|0;
     $69 = ($68|0)==(0|0);
     if ($69) {
      $$0$i$i$i = $$0$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i = $68;
     }
    }
   }
   $74 = ($$0$i$i$i|0)==($56|0);
   if ($74) {
    $$0 = 0;
    label = 34;
    break;
   } else {
    $58 = $$0$i$i$i;
   }
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($59)|0);
  $64 = HEAP32[$57>>2]|0;
  $$0 = $64;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 34) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm5Image22GetGenericInstanceTypeEP8TypeInfoRKNSt3__16vectorIPK10Il2CppTypeNS4_9allocatorIS8_EEEE($genericTypeDefinition,$genericArgumentTypes) {
 $genericTypeDefinition = $genericTypeDefinition|0;
 $genericArgumentTypes = $genericArgumentTypes|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$ph5$i8$i$i = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i3$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i4$in$i$i = 0, $$013$i$in$i$i = 0, $$013$i6$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__result$0$ph34$i$i = 0, $__rt$0$in$i$i = 0;
 var $__rt$0$in25$i$i = 0, $__rt$0$in2532$i$i = 0, $__rt$02636$in$i$i = 0, $__rt$028$in$i$i = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($genericTypeDefinition) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 52|0);
 $5 = (($3) + 52|0);
 $__rt$0$in2532$i$i = HEAP32[$5>>2]|0;
 $6 = ($__rt$0$in2532$i$i|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $__result$0$ph34$i$i = $4;$__rt$02636$in$i$i = $__rt$0$in2532$i$i;
 }
 L3: while(1) {
  $__rt$028$in$i$i = $__rt$02636$in$i$i;
  while(1) {
   $9 = (($__rt$028$in$i$i) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10>>>0)>($genericTypeDefinition>>>0);
   if ($11) {
    break;
   }
   $13 = ($10>>>0)<($genericTypeDefinition>>>0);
   if (!($13)) {
    label = 7;
    break L3;
   }
   $7 = (($__rt$028$in$i$i) + 4|0);
   $__rt$0$in$i$i = HEAP32[$7>>2]|0;
   $8 = ($__rt$0$in$i$i|0)==(0|0);
   if ($8) {
    $$0 = 0;
    label = 28;
    break L3;
   } else {
    $__rt$028$in$i$i = $__rt$0$in$i$i;
   }
  }
  $__rt$0$in25$i$i = HEAP32[$__rt$028$in$i$i>>2]|0;
  $12 = ($__rt$0$in25$i$i|0)==(0|0);
  if ($12) {
   $$0 = 0;
   label = 28;
   break;
  } else {
   $__result$0$ph34$i$i = $__rt$028$in$i$i;$__rt$02636$in$i$i = $__rt$0$in25$i$i;
  }
 }
 if ((label|0) == 7) {
  $14 = HEAP32[$__rt$028$in$i$i>>2]|0;
  $15 = ($14|0)==(0|0);
  L13: do {
   if ($15) {
    $$0$ph5$i8$i$i = $__rt$028$in$i$i;
   } else {
    $$0$ph7$i3$i$i = $__rt$028$in$i$i;$$01$ph6$i4$in$i$i = $14;
    while(1) {
     $$013$i6$in$i$i = $$01$ph6$i4$in$i$i;
     while(1) {
      $16 = (($$013$i6$in$i$i) + 16|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17>>>0)<($genericTypeDefinition>>>0);
      if (!($18)) {
       break;
      }
      $21 = (($$013$i6$in$i$i) + 4|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22|0)==(0|0);
      if ($23) {
       $$0$ph5$i8$i$i = $$0$ph7$i3$i$i;
       break L13;
      } else {
       $$013$i6$in$i$i = $22;
      }
     }
     $19 = HEAP32[$$013$i6$in$i$i>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      $$0$ph5$i8$i$i = $$013$i6$in$i$i;
      break;
     } else {
      $$0$ph7$i3$i$i = $$013$i6$in$i$i;$$01$ph6$i4$in$i$i = $19;
     }
    }
   }
  } while(0);
  $24 = (($__rt$028$in$i$i) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  L21: do {
   if ($26) {
    $36 = $__result$0$ph34$i$i;
   } else {
    $$0$ph7$i$i$i = $__result$0$ph34$i$i;$$01$ph6$i$in$i$i = $25;
    while(1) {
     $$013$i$in$i$i = $$01$ph6$i$in$i$i;
     while(1) {
      $27 = (($$013$i$in$i$i) + 16|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($28>>>0)>($genericTypeDefinition>>>0);
      if ($29) {
       break;
      }
      $32 = (($$013$i$in$i$i) + 4|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($33|0)==(0|0);
      if ($34) {
       $36 = $$0$ph7$i$i$i;
       break L21;
      } else {
       $$013$i$in$i$i = $33;
      }
     }
     $30 = HEAP32[$$013$i$in$i$i>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $36 = $$013$i$in$i$i;
      break;
     } else {
      $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $30;
     }
    }
   }
  } while(0);
  $35 = ($$0$ph5$i8$i$i|0)==($36|0);
  if ($35) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $38 = $$0$ph5$i8$i$i;
  L32: while(1) {
   $37 = (($38) + 20|0);
   $39 = HEAP32[$37>>2]|0;
   $40 = (($39) + 68|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0);
   if ($45) {
    $$0 = $39;
    label = 28;
    break;
   }
   $46 = (($43) + 4|0);
   $i$01 = 0;
   while(1) {
    $50 = HEAP32[$46>>2]|0;
    $51 = (($50) + ($i$01<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = HEAP32[$genericArgumentTypes>>2]|0;
    $54 = (($53) + ($i$01<<2)|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (__ZN6il2cpp2vm17Il2CppTypeCompare7compareEPK10Il2CppTypeS4_($52,$55)|0);
    $49 = (($i$01) + 1)|0;
    if (!($56)) {
     break;
    }
    $47 = HEAP32[$43>>2]|0;
    $48 = ($49>>>0)<($47>>>0);
    if ($48) {
     $i$01 = $49;
    } else {
     $$0 = $39;
     label = 28;
     break L32;
    }
   }
   $57 = (($38) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==(0|0);
   if ($59) {
    $$01$i$i$i = $38;
    while(1) {
     $62 = (($$01$i$i$i) + 8|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)==($$01$i$i$i|0);
     if ($65) {
      $$0$i$i$i = $63;
      break;
     } else {
      $$01$i$i$i = $63;
     }
    }
   } else {
    $$0$i$i$i$i = $58;
    while(1) {
     $60 = HEAP32[$$0$i$i$i$i>>2]|0;
     $61 = ($60|0)==(0|0);
     if ($61) {
      $$0$i$i$i = $$0$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i = $60;
     }
    }
   }
   $66 = ($$0$i$i$i|0)==($36|0);
   if ($66) {
    $$0 = 0;
    label = 28;
    break;
   } else {
    $38 = $$0$i$i$i;
   }
  }
  if ((label|0) == 28) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 28) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeINS_4pairIP8TypeInfoP10MethodInfoEES6_EENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS_9allocatorIS8_EEE15__insert_uniqueERKS8_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0;
 var $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $19 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $19;
   $$0$i = $19;$26 = $19;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $4 = (($__v) + 4|0);
   $__nd$0$in$i = $1;
   L4: while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($3>>>0)<($6>>>0);
    do {
     if (!($7)) {
      $8 = ($6>>>0)<($3>>>0);
      if (!($8)) {
       $9 = HEAP32[$4>>2]|0;
       $10 = (($__nd$0$in$i) + 20|0);
       $11 = HEAP32[$10>>2]|0;
       $12 = ($9>>>0)<($11>>>0);
       if ($12) {
        break;
       }
       $15 = ($11>>>0)<($9>>>0);
       if (!($15)) {
        label = 11;
        break L4;
       }
      }
      $16 = (($__nd$0$in$i) + 4|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17|0)==(0|0);
      if ($18) {
       label = 10;
       break L4;
      } else {
       $__nd$0$in$i = $17;
       continue L4;
      }
     }
    } while(0);
    $13 = HEAP32[$__nd$0$in$i>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     label = 7;
     break;
    } else {
     $__nd$0$in$i = $13;
    }
   }
   if ((label|0) == 7) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$26 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 10) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $16;$26 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 11) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$26 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $20 = HEAP32[$$0$i>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $36 = 0;$__r$0 = $20;
  HEAP32[$agg$result>>2] = $__r$0;
  $35 = (($agg$result) + 4|0);
  HEAP8[$35>>0] = $36;
  STACKTOP = sp;return;
 }
 $22 = (__Znwj(28)|0);
 $23 = (($22) + 16|0);
 ;HEAP32[$23+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__v+8>>2]|0;
 HEAP32[$22>>2] = 0;
 $24 = (($22) + 4|0);
 HEAP32[$24>>2] = 0;
 $25 = (($22) + 8|0);
 HEAP32[$25>>2] = $26;
 HEAP32[$$0$i>>2] = $22;
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $31 = $22;
 } else {
  HEAP32[$this>>2] = $28;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $31 = $$pre$i;
 }
 $30 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($30,$31);
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 1)|0;
 HEAP32[$32>>2] = $34;
 $36 = 1;$__r$0 = $22;
 HEAP32[$agg$result>>2] = $__r$0;
 $35 = (($agg$result) + 4|0);
 HEAP8[$35>>0] = $36;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE($name,$method) {
 $name = $name|0;
 $method = $method|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i3 = 0, $res = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $res = sp + 24|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = (_strlen(($name|0))|0);
 $3 = ($2>>>0)>(4294967279);
 if ($3) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $4 = ($2>>>0)<(11);
 if ($4) {
  $5 = $2 << 1;
  $6 = $5&255;
  HEAP8[$0>>0] = $6;
  $7 = (($0) + 1|0);
  $$pre$phiZ2D = $0;$__p$0$i$i$i = $7;
 } else {
  $8 = (($2) + 16)|0;
  $9 = $8 & -16;
  $10 = (__Znwj($9)|0);
  $11 = (($0) + 8|0);
  HEAP32[$11>>2] = $10;
  $12 = $9 | 1;
  HEAP32[$0>>2] = $12;
  $13 = (($0) + 4|0);
  HEAP32[$13>>2] = $2;
  $$pre$phiZ2D = $0;$__p$0$i$i$i = $10;
 }
 _memcpy(($__p$0$i$i$i|0),($name|0),($2|0))|0;
 $14 = (($__p$0$i$i$i) + ($2)|0);
 HEAP8[$14>>0] = 0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE4findIS7_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_($res,348792,$0);
 $15 = HEAP8[$$pre$phiZ2D>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if (!($17)) {
  $18 = (($0) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  __ZdlPv($19);
 }
 $20 = (_strlen(($name|0))|0);
 $21 = ($20>>>0)>(4294967279);
 if ($21) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = ($20>>>0)<(11);
 if ($22) {
  $23 = $20 << 1;
  $24 = $23&255;
  HEAP8[$1>>0] = $24;
  $25 = (($1) + 1|0);
  $__p$0$i$i$i3 = $25;
 } else {
  $26 = (($20) + 16)|0;
  $27 = $26 & -16;
  $28 = (__Znwj($27)|0);
  $29 = (($1) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $27 | 1;
  HEAP32[$1>>2] = $30;
  $31 = (($1) + 4|0);
  HEAP32[$31>>2] = $20;
  $__p$0$i$i$i3 = $28;
 }
 _memcpy(($__p$0$i$i$i3|0),($name|0),($20|0))|0;
 $32 = (($__p$0$i$i$i3) + ($20)|0);
 HEAP8[$32>>0] = 0;
 __THREW__ = 0;
 $33 = (invoke_iii(2245,(348792|0),($1|0))|0);
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  $43 = HEAP8[$1>>0]|0;
  $44 = $43 & 1;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   ___resumeException($41|0);
   // unreachable;
  }
  $46 = (($1) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  __ZdlPv($47);
  ___resumeException($41|0);
  // unreachable;
 } else {
  HEAP32[$33>>2] = $method;
  $36 = HEAP8[$1>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  if ($38) {
   STACKTOP = sp;return;
  }
  $39 = (($1) + 8|0);
  $40 = HEAP32[$39>>2]|0;
  __ZdlPv($40);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvENS_4lessIS6_EENS4_INS_4pairIKS6_S8_EEEEEixERSC_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (__ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvENS_4lessIS6_EENS4_INS_4pairIKS6_S8_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERSC_($this,$__parent,$__k)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $__r$0 = $1;
  $44 = (($__r$0) + 28|0);
  STACKTOP = sp;return ($44|0);
 }
 $3 = (__Znwj(32)|0);
 $4 = (($3) + 16|0);
 $5 = HEAP8[$__k>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 L4: do {
  if ($7) {
   ;HEAP32[$4+0>>2]=HEAP32[$__k+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__k+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__k+8>>2]|0;
  } else {
   $8 = (($__k) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($__k) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11>>>0)>(4294967279);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    } else {
     $15 = ($11>>>0)<(11);
     if ($15) {
      $16 = $11 << 1;
      $17 = $16&255;
      HEAP8[$4>>0] = $17;
      $18 = (($3) + 17|0);
      $__p$0$i$i$i$i$i = $18;
     } else {
      $19 = (($11) + 16)|0;
      $20 = $19 & -16;
      __THREW__ = 0;
      $21 = (invoke_ii(2988,($20|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      $24 = (($3) + 24|0);
      HEAP32[$24>>2] = $21;
      $25 = $20 | 1;
      HEAP32[$4>>2] = $25;
      $26 = (($3) + 20|0);
      HEAP32[$26>>2] = $11;
      $__p$0$i$i$i$i$i = $21;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($9|0),($11|0))|0;
     $27 = (($__p$0$i$i$i$i$i) + ($11)|0);
     HEAP8[$27>>0] = 0;
     break L4;
    }
   } while(0);
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = ($3|0)==(0|0);
   if ($30) {
    ___resumeException($28|0);
    // unreachable;
   }
   __ZdlPv($3);
   ___resumeException($28|0);
   // unreachable;
  }
 } while(0);
 $31 = (($3) + 28|0);
 HEAP32[$31>>2] = 0;
 $32 = HEAP32[$__parent>>2]|0;
 HEAP32[$3>>2] = 0;
 $33 = (($3) + 4|0);
 HEAP32[$33>>2] = 0;
 $34 = (($3) + 8|0);
 HEAP32[$34>>2] = $32;
 HEAP32[$0>>2] = $3;
 $35 = HEAP32[$this>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $40 = $3;
 } else {
  HEAP32[$this>>2] = $36;
  $$pre$i = HEAP32[$0>>2]|0;
  $40 = $$pre$i;
 }
 $38 = (($this) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($39,$40);
 $41 = (($this) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 1)|0;
 HEAP32[$41>>2] = $43;
 $__r$0 = $3;
 $44 = (($__r$0) + 28|0);
 STACKTOP = sp;return ($44|0);
}
function __ZN6il2cpp2vm13InternalCalls4InitEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(348808,85);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(348976,2488);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349064,3008);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349120,6);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349152,67);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349200,3009);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349280,3010);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349368,3011);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349448,3012);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349528,3013);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349608,3014);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349656,1481);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349728,3321);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349768,3015);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349824,2246);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349896,1482);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(349976,2247);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350024,7);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350064,2248);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350112,3016);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350152,8);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350192,3017);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350224,9);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350264,10);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350312,3018);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350368,3019);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350432,68);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350480,3322);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350544,3323);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350608,3020);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350688,3021);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350744,3022);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350800,3324);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350848,215);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(350944,167);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351056,1568);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351112,2489);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351152,1569);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351208,3023);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351248,1570);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351304,1571);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351376,3024);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351400,1483);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351480,168);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351576,2249);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351616,2250);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351664,3025);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351688,2251);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351728,2252);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351776,1572);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351832,1573);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351888,169);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(351992,3026);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352040,2253);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352104,1574);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352176,62);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352320,1484);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352408,2254);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352480,1485);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352576,11);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352608,12);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352648,7);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352696,2255);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352760,98);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352896,2256);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(352960,2257);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353024,1486);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353104,2490);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353176,2258);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353240,1487);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353320,2259);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353384,2260);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353456,216);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353552,217);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353664,3325);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353704,13);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353760,34);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(353936,1488);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354024,14);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354072,2261);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354128,2262);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354176,3027);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354208,3028);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354256,3029);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354288,2263);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354344,3326);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354384,15);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354432,16);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354472,17);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354520,18);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354560,19);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354600,20);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354640,21);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354688,22);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354736,23);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354776,24);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354816,25);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354864,26);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354920,27);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(354968,28);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355016,29);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355064,3030);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355120,69);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355176,3031);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355248,30);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355288,2491);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355368,3327);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355416,3032);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355464,31);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355496,3033);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355536,3034);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355584,3328);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355632,3329);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355672,2492);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355712,3330);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355760,3331);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355808,70);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355848,320);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(355968,2493);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356040,3332);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356104,35);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356272,99);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356432,99);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356592,3333);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356656,3035);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356776,2264);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356864,2265);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(356952,2266);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357080,3334);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357144,1489);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357248,2267);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357344,2268);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357432,170);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357568,3036);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357632,2269);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357696,218);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357792,2270);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357864,2271);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(357928,2272);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358000,100);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358136,2273);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358200,32);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358256,33);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358296,34);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358336,35);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358376,36);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358424,37);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358464,38);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358512,3037);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358576,2274);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358656,1490);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358752,171);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358872,2275);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(358944,2276);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359016,3038);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359064,86);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359152,1491);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359232,101);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359376,172);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359480,2277);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359552,173);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359664,174);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359760,2278);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359840,1492);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(359944,36);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360056,219);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360136,87);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360232,175);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360336,39);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360368,1);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360408,2);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360448,3);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360488,1);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360536,4);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360568,5);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360608,6);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360640,7);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360680,8);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360712,9);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360752,2);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360800,10);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360840,1);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360904,11);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360936,12);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(360976,13);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361016,14);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361048,15);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361088,3039);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361192,1493);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361320,2279);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361424,2494);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361496,3040);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361528,3041);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361576,3042);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361608,3043);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361648,3044);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361688,3045);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361736,3046);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361768,3047);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361800,3048);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361840,3049);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361872,1494);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(361960,2280);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362048,2280);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362128,3050);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362168,1495);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362248,1496);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362320,1497);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362400,1498);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362464,3051);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362504,3052);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362544,176);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362656,1499);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362736,2281);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362800,177);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362912,1500);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(362992,3053);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363024,3054);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363064,3055);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363104,3056);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363144,2495);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363208,88);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363344,3057);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363376,3058);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363432,3059);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363472,3060);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363504,2496);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363600,2282);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363664,3061);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363712,3062);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363760,3063);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363816,3064);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363864,3065);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363920,40);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(363976,41);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364024,42);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364080,1501);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364160,3066);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364216,1502);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364336,220);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364448,3067);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364504,3068);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364560,3069);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364608,3070);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364664,2283);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364720,2497);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364824,178);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(364944,3071);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365008,2284);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365112,2285);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365184,101);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365344,3072);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365432,2286);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365520,3335);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365616,2287);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365696,102);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(365928,3336);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366000,2498);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366104,2499);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366208,2500);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366280,3337);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366352,2288);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366424,3338);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366512,3339);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366608,2289);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366720,1503);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366856,2290);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(366960,2291);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367064,1575);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367144,2501);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367256,2502);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367328,3073);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367392,3074);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367456,3340);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367520,3341);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367616,2292);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367712,2293);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367800,3075);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367864,3342);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(367928,2503);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368024,2294);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368088,3076);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368144,2295);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368232,3077);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368288,43);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368344,3078);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368416,2296);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368512,3079);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368560,3080);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368608,3081);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368656,3082);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368704,3083);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368768,1576);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368904,3084);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(368952,179);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(369096,180);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(369240,181);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(369384,1504);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(369496,1505);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(369608,182);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(369752,221);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(369848,2504);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(369960,3085);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370008,2297);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370072,3086);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370128,2298);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370192,1577);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370296,89);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370504,3087);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370568,3088);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370632,3089);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370712,3090);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370768,3091);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370832,3092);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370904,3093);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(370976,3094);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371032,3095);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371096,221);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371192,2299);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371264,2505);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371368,2300);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371472,3096);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371544,1578);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371696,2301);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371800,3097);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371856,2302);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(371928,44);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372008,3098);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372088,2506);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372184,3343);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372272,3344);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372360,3099);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372440,3345);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372512,3100);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372592,3101);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372664,1506);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372800,3102);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372872,3103);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(372944,3104);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373016,321);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373136,322);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373248,2507);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373336,3346);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373400,3347);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373472,3348);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373544,2303);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373624,3105);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373728,2304);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373840,3106);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(373936,3107);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374024,3108);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374112,45);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374176,3109);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374248,3110);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374320,2305);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374400,3349);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374480,3350);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374544,3111);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374616,2306);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374704,3112);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374776,3113);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374848,2307);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(374936,2308);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375024,2308);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375112,1507);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375224,2309);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375304,2310);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375384,2311);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375464,2312);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375544,2313);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375624,2314);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375712,2315);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375800,3114);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375880,3115);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(375952,3116);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376016,3117);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376088,3118);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376168,3119);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376248,1579);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376352,2316);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376456,1580);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376552,1581);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376648,1581);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376744,1582);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376840,323);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(376936,1583);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377032,3120);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377136,2508);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377248,1584);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377360,3121);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377440,2317);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377528,2318);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377632,222);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377768,3122);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377848,3123);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377912,3351);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(377992,2319);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378088,3124);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378176,46);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378248,3125);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378336,3126);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378408,47);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378472,3127);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378544,3128);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378616,3129);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378704,3130);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378792,48);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378864,3131);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(378952,2320);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379048,2321);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379144,3132);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379208,3133);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379272,49);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379336,50);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379392,1508);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379568,3352);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379648,3353);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379720,71);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379760,71);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379824,71);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379872,71);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379912,71);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(379976,71);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380016,71);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380080,71);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380168,3134);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380224,3135);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380272,3136);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380328,223);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380400,3137);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380456,2322);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380520,1509);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380584,2);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380680,1510);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380768,183);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380856,1511);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(380952,1512);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381048,7);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381144,1512);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381200,3138);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381256,3139);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381312,2323);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381360,8);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381432,2324);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381504,1513);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381576,2323);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381648,2323);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381720,14);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381792,3140);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381848,3141);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381904,3142);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(381960,3354);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382008,3355);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382056,3356);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382112,3357);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382176,3143);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382248,2325);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382320,2326);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382392,1514);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382488,3144);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382552,3358);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382624,224);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382744,3145);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382816,3146);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382888,2509);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(382944,2510);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383008,51);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383064,2511);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383144,3147);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383200,3148);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383256,3149);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383312,52);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383352,3150);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383400,3151);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383456,3152);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383520,3153);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383560,3359);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383608,1515);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383680,72);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383728,73);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383776,3360);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383824,2512);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(383912,2513);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384000,2514);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384064,2515);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384136,2516);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384208,2517);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384272,3361);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384328,74);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384368,3362);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384416,2518);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384480,3363);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384520,2327);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384592,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384648,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384704,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384760,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384816,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384872,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384928,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(384984,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385040,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385096,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385152,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385208,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385264,3154);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385320,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385392,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385464,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385536,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385608,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385680,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385752,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385824,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385896,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(385968,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386040,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386112,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386184,2519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386256,2520);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386328,2521);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386400,2328);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386472,2329);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386544,225);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386656,1516);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386768,1517);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386880,226);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(386976,2330);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387024,3155);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387064,3156);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387112,3157);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387160,3158);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387216,3159);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387264,3160);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387312,324);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387440,1585);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387496,3161);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387544,3162);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387600,1518);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387680,3163);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387720,2331);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387768,2332);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387816,3164);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387848,2333);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387904,3165);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(387936,2334);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(388000,1519);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(388072,3166);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(388128,1520);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(388208,2335);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(388280,227);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(388392,1521);
 __ZN6il2cpp2vm13InternalCalls3AddEPKcPFvvE(388528,1522);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm13InternalCalls7ResolveEPKc($name) {
 $name = $name|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$pre$phi17Z2D = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i7 = 0, $res = 0, $shortName = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $res = sp + 40|0;
 $0 = sp;
 $shortName = sp + 12|0;
 $1 = sp + 24|0;
 $2 = sp + 36|0;
 $3 = (_strlen(($name|0))|0);
 $4 = ($3>>>0)>(4294967279);
 if ($4) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $5 = ($3>>>0)<(11);
 if ($5) {
  $6 = $3 << 1;
  $7 = $6&255;
  HEAP8[$0>>0] = $7;
  $8 = (($0) + 1|0);
  $$pre$phiZ2D = $0;$__p$0$i$i$i = $8;
 } else {
  $9 = (($3) + 16)|0;
  $10 = $9 & -16;
  $11 = (__Znwj($10)|0);
  $12 = (($0) + 8|0);
  HEAP32[$12>>2] = $11;
  $13 = $10 | 1;
  HEAP32[$0>>2] = $13;
  $14 = (($0) + 4|0);
  HEAP32[$14>>2] = $3;
  $$pre$phiZ2D = $0;$__p$0$i$i$i = $11;
 }
 _memcpy(($__p$0$i$i$i|0),($name|0),($3|0))|0;
 $15 = (($__p$0$i$i$i) + ($3)|0);
 HEAP8[$15>>0] = 0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE4findIS7_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_($res,348792,$0);
 $16 = HEAP8[$$pre$phiZ2D>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 if (!($18)) {
  $19 = (($0) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  __ZdlPv($20);
 }
 $21 = HEAP32[$res>>2]|0;
 $22 = ($21|0)==(((348792 + 4|0))|0);
 if (!($22)) {
  $23 = (($21) + 28|0);
  $24 = HEAP32[$23>>2]|0;
  $$1 = $24;
  STACKTOP = sp;return ($$1|0);
 }
 $25 = (_strlen(($name|0))|0);
 $26 = ($25>>>0)>(4294967279);
 if ($26) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $27 = ($25>>>0)<(11);
 if ($27) {
  $28 = $25 << 1;
  $29 = $28&255;
  HEAP8[$shortName>>0] = $29;
  $30 = (($shortName) + 1|0);
  $$pre$phi17Z2D = $shortName;$40 = $29;$__p$0$i$i$i7 = $30;
 } else {
  $31 = (($25) + 16)|0;
  $32 = $31 & -16;
  $33 = (__Znwj($32)|0);
  $34 = (($shortName) + 8|0);
  HEAP32[$34>>2] = $33;
  $35 = $32 | 1;
  HEAP32[$shortName>>2] = $35;
  $36 = (($shortName) + 4|0);
  HEAP32[$36>>2] = $25;
  $37 = $35&255;
  $$pre$phi17Z2D = $shortName;$40 = $37;$__p$0$i$i$i7 = $33;
 }
 _memcpy(($__p$0$i$i$i7|0),($name|0),($25|0))|0;
 $38 = (($__p$0$i$i$i7) + ($25)|0);
 HEAP8[$38>>0] = 0;
 $39 = $40 & 1;
 $41 = ($39<<24>>24)==(0);
 if ($41) {
  $44 = $40&255;
  $45 = $44 >>> 1;
  $47 = $45;
 } else {
  $42 = (($shortName) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $47 = $43;
 }
 $46 = ($47|0)==(0);
 L26: do {
  if ($46) {
   $$0 = 0;
  } else {
   if ($41) {
    $50 = (($shortName) + 1|0);
    $51 = $50;
   } else {
    $48 = (($shortName) + 8|0);
    $49 = HEAP32[$48>>2]|0;
    $51 = $49;
   }
   $52 = (_memchr($51,40,$47)|0);
   $53 = ($52|0)==(0|0);
   if ($53) {
    $$0 = 0;
   } else {
    $54 = $52;
    $55 = $51;
    $56 = (($54) - ($55))|0;
    $57 = ($56|0)==(-1);
    if ($57) {
     $$0 = 0;
    } else {
     $58 = $40 & 1;
     $59 = ($58<<24>>24)==(0);
     if ($59) {
      $64 = $40&255;
      $65 = $64 >>> 1;
      $66 = (($shortName) + 1|0);
      $68 = $65;$85 = $66;
     } else {
      $60 = (($shortName) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = (($shortName) + 8|0);
      $63 = HEAP32[$62>>2]|0;
      $68 = $61;$85 = $63;
     }
     $67 = ($68>>>0)<($56>>>0);
     $69 = $67 ? $68 : $56;
     $70 = ($69>>>0)>(4294967279);
     do {
      if ($70) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        label = 39;
       } else {
        // unreachable;
       }
      } else {
       $73 = ($69>>>0)<(11);
       if ($73) {
        $74 = $69 << 1;
        $75 = $74&255;
        HEAP8[$1>>0] = $75;
        $76 = (($1) + 1|0);
        $__p$0$i$i = $76;
       } else {
        $77 = (($69) + 16)|0;
        $78 = $77 & -16;
        __THREW__ = 0;
        $79 = (invoke_ii(2988,($78|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 39;
         break;
        }
        $82 = (($1) + 8|0);
        HEAP32[$82>>2] = $79;
        $83 = $78 | 1;
        HEAP32[$1>>2] = $83;
        $84 = (($1) + 4|0);
        HEAP32[$84>>2] = $69;
        $__p$0$i$i = $79;
       }
       _memcpy(($__p$0$i$i|0),($85|0),($69|0))|0;
       $86 = (($__p$0$i$i) + ($69)|0);
       HEAP8[$86>>0] = 0;
       __THREW__ = 0;
       (invoke_iii(2233,($shortName|0),($1|0))|0);
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        $100 = ___cxa_find_matching_catch()|0;
        $101 = tempRet0;
        $102 = HEAP8[$1>>0]|0;
        $103 = $102 & 1;
        $104 = ($103<<24>>24)==(0);
        if ($104) {
         $$01 = $101;$$03 = $100;
         break;
        }
        $105 = (($1) + 8|0);
        $106 = HEAP32[$105>>2]|0;
        __ZdlPv($106);
        $$01 = $101;$$03 = $100;
        break;
       }
       $89 = HEAP8[$1>>0]|0;
       $90 = $89 & 1;
       $91 = ($90<<24>>24)==(0);
       if (!($91)) {
        $92 = (($1) + 8|0);
        $93 = HEAP32[$92>>2]|0;
        __ZdlPv($93);
       }
       __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE4findIS7_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_($2,348792,$shortName);
       $94 = HEAP32[$2>>2]|0;
       HEAP32[$res>>2] = $94;
       $95 = ($94|0)==(((348792 + 4|0))|0);
       if ($95) {
        $$0 = 0;
        break L26;
       }
       $96 = (($94) + 28|0);
       $97 = HEAP32[$96>>2]|0;
       $$0 = $97;
       break L26;
      }
     } while(0);
     if ((label|0) == 39) {
      $98 = ___cxa_find_matching_catch()|0;
      $99 = tempRet0;
      $$01 = $99;$$03 = $98;
     }
     $112 = HEAP8[$$pre$phi17Z2D>>0]|0;
     $113 = $112 & 1;
     $114 = ($113<<24>>24)==(0);
     if ($114) {
      ___resumeException($$03|0);
      // unreachable;
     }
     $115 = (($shortName) + 8|0);
     $116 = HEAP32[$115>>2]|0;
     __ZdlPv($116);
     ___resumeException($$03|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $107 = HEAP8[$$pre$phi17Z2D>>0]|0;
 $108 = $107 & 1;
 $109 = ($108<<24>>24)==(0);
 if ($109) {
  $$1 = $$0;
  STACKTOP = sp;return ($$1|0);
 }
 $110 = (($shortName) + 8|0);
 $111 = HEAP32[$110>>2]|0;
 __ZdlPv($111);
 $$1 = $$0;
 STACKTOP = sp;return ($$1|0);
}
function __ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvENS_4lessIS6_EENS4_INS_4pairIKS6_S8_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERSC_($this,$__parent,$__k) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__k = $__k|0;
 var $$$$i$i$i = 0, $$$$i$i$i5 = 0, $$$i$i$i = 0, $$$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $60 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $60;
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__k>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__k) + 1|0);
 $9 = (($__k) + 8|0);
 $10 = (($__k) + 4|0);
 $__nd$0$in = $1;
 while(1) {
  $11 = (($__nd$0$in) + 16|0);
  if ($5) {
   $26 = $7;
  } else {
   $12 = HEAP32[$10>>2]|0;
   $26 = $12;
  }
  $13 = HEAP8[$11>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $25 = $19;
  } else {
   $16 = (($__nd$0$in) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $25 = $17;
  }
  if ($5) {
   $28 = $8;
  } else {
   $20 = HEAP32[$9>>2]|0;
   $28 = $20;
  }
  if ($15) {
   $23 = (($11) + 1|0);
   $29 = $23;
  } else {
   $21 = (($__nd$0$in) + 24|0);
   $22 = HEAP32[$21>>2]|0;
   $29 = $22;
  }
  $24 = ($25>>>0)<($26>>>0);
  $27 = $24 ? $25 : $26;
  $30 = (_memcmp($28,$29,$27)|0);
  $31 = ($30|0)==(0);
  if ($31) {
   $32 = ($26>>>0)<($25>>>0);
   $$$i$i$i4 = $24&1;
   $$$$i$i$i5 = $32 ? -1 : $$$i$i$i4;
   $34 = $$$$i$i$i5;
  } else {
   $34 = $30;
  }
  $33 = ($34|0)<(0);
  if ($33) {
   $35 = HEAP32[$__nd$0$in>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 17;
    break;
   } else {
    $__nd$0$in = $35;
    continue;
   }
  }
  if ($15) {
   $39 = $13&255;
   $40 = $39 >>> 1;
   $48 = $40;
  } else {
   $37 = (($__nd$0$in) + 20|0);
   $38 = HEAP32[$37>>2]|0;
   $48 = $38;
  }
  if ($5) {
   $47 = $7;
  } else {
   $41 = HEAP32[$10>>2]|0;
   $47 = $41;
  }
  if ($15) {
   $44 = (($11) + 1|0);
   $50 = $44;
  } else {
   $42 = (($__nd$0$in) + 24|0);
   $43 = HEAP32[$42>>2]|0;
   $50 = $43;
  }
  if ($5) {
   $51 = $8;
  } else {
   $45 = HEAP32[$9>>2]|0;
   $51 = $45;
  }
  $46 = ($47>>>0)<($48>>>0);
  $49 = $46 ? $47 : $48;
  $52 = (_memcmp($50,$51,$49)|0);
  $53 = ($52|0)==(0);
  if ($53) {
   $54 = ($48>>>0)<($47>>>0);
   $$$i$i$i = $46&1;
   $$$$i$i$i = $54 ? -1 : $$$i$i$i;
   $56 = $$$$i$i$i;
  } else {
   $56 = $52;
  }
  $55 = ($56|0)<(0);
  if (!($55)) {
   label = 33;
   break;
  }
  $57 = (($__nd$0$in) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   label = 32;
   break;
  } else {
   $__nd$0$in = $58;
  }
 }
 if ((label|0) == 17) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $57;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE4findIS7_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE13__lower_boundIS7_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_SM_SM_($__p,$this,$__v,$1,$2);
 $3 = HEAP32[$__p>>2]|0;
 $4 = ($3|0)==($2|0);
 if (!($4)) {
  $5 = (($3) + 16|0);
  $6 = HEAP8[$__v>>0]|0;
  $7 = $6 & 1;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $11 = $6&255;
   $12 = $11 >>> 1;
   $28 = $12;
  } else {
   $9 = (($__v) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $28 = $10;
  }
  $13 = HEAP8[$5>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $27 = $19;
  } else {
   $16 = (($3) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $27 = $17;
  }
  if ($8) {
   $22 = (($__v) + 1|0);
   $30 = $22;
  } else {
   $20 = (($__v) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $30 = $21;
  }
  if ($15) {
   $25 = (($5) + 1|0);
   $31 = $25;
  } else {
   $23 = (($3) + 24|0);
   $24 = HEAP32[$23>>2]|0;
   $31 = $24;
  }
  $26 = ($27>>>0)<($28>>>0);
  $29 = $26 ? $27 : $28;
  $32 = (_memcmp($30,$31,$29)|0);
  $33 = ($32|0)==(0);
  if ($33) {
   $34 = ($28>>>0)<($27>>>0);
   $$$i$i$i$i = $26&1;
   $$$$i$i$i$i = $34 ? -1 : $$$i$i$i$i;
   $36 = $$$$i$i$i$i;
  } else {
   $36 = $32;
  }
  $35 = ($36|0)<(0);
  if (!($35)) {
   HEAP32[$agg$result>>2] = $3;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE13__lower_boundIS7_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_SM_SM_($agg$result,$this,$__v,$__root,$__result) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 $__root = $__root|0;
 $__result = $__result|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0$ph6 = 0, $$0$ph9 = 0, $$01$lcssa2 = 0, $$01$ph8 = 0, $$013 = 0, $$013$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__root|0)==(0|0);
 if ($0) {
  $$0$ph6 = $__result;
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
 $1 = HEAP8[$__v>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 $4 = $1&255;
 $5 = $4 >>> 1;
 $6 = (($__v) + 1|0);
 $7 = (($__v) + 8|0);
 $8 = (($__v) + 4|0);
 $$0$ph9 = $__result;$$01$ph8 = $__root;
 L4: while(1) {
  L6: do {
   if ($3) {
    $$013$us = $$01$ph8;
    while(1) {
     $9 = (($$013$us) + 16|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 & 1;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $17 = $10&255;
      $18 = $17 >>> 1;
      $19 = (($9) + 1|0);
      $21 = $18;$23 = $19;
     } else {
      $13 = (($$013$us) + 20|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($$013$us) + 24|0);
      $16 = HEAP32[$15>>2]|0;
      $21 = $14;$23 = $16;
     }
     $20 = ($5>>>0)<($21>>>0);
     $22 = $20 ? $5 : $21;
     $24 = (_memcmp($23,$6,$22)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = ($21>>>0)<($5>>>0);
      $$$i$i$i$i$us = $20&1;
      $$$$i$i$i$i$us = $26 ? -1 : $$$i$i$i$i$us;
      $28 = $$$$i$i$i$i$us;
     } else {
      $28 = $24;
     }
     $27 = ($28|0)<(0);
     if (!($27)) {
      $$01$lcssa2 = $$013$us;
      break L6;
     }
     $29 = (($$013$us) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013$us = $30;
     }
    }
   } else {
    $$013 = $$01$ph8;
    while(1) {
     $32 = (($$013) + 16|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if ($35) {
      $40 = $33&255;
      $41 = $40 >>> 1;
      $42 = (($32) + 1|0);
      $46 = $41;$48 = $42;
     } else {
      $36 = (($$013) + 20|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($$013) + 24|0);
      $39 = HEAP32[$38>>2]|0;
      $46 = $37;$48 = $39;
     }
     $43 = HEAP32[$8>>2]|0;
     $44 = HEAP32[$7>>2]|0;
     $45 = ($43>>>0)<($46>>>0);
     $47 = $45 ? $43 : $46;
     $49 = (_memcmp($48,$44,$47)|0);
     $50 = ($49|0)==(0);
     if ($50) {
      $51 = ($46>>>0)<($43>>>0);
      $$$i$i$i$i = $45&1;
      $$$$i$i$i$i = $51 ? -1 : $$$i$i$i$i;
      $53 = $$$$i$i$i$i;
     } else {
      $53 = $49;
     }
     $52 = ($53|0)<(0);
     if (!($52)) {
      $$01$lcssa2 = $$013;
      break L6;
     }
     $56 = (($$013) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013 = $57;
     }
    }
   }
  } while(0);
  $54 = HEAP32[$$01$lcssa2>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$0$ph6 = $$01$lcssa2;
   label = 19;
   break;
  } else {
   $$0$ph9 = $$01$lcssa2;$$01$ph8 = $54;
  }
 }
 if ((label|0) == 19) {
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2vm13LivenessStateD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($1) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==($3|0);
   if (!($7)) {
    $__new_last2$i$i$i$i$i = $3;
    $scevgep$i$i$i$i$i = (($6) + -4|0);
    $8 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($8)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $9 = $uglygep3$i$i$i$i$i >>> 2;
    $10 = $9 ^ -1;
    $scevgep4$i$i$i$i$i = (($6) + ($10<<2)|0);
    HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($3);
  }
  __ZdlPv($1);
 }
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$12>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = (($12) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($14|0);
  if (!($18)) {
   $__new_last2$i$i$i$i$i2 = $14;
   $scevgep$i$i$i$i$i3 = (($17) + -4|0);
   $19 = (0 - ($__new_last2$i$i$i$i$i2))|0;
   $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($19)|0);
   $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
   $20 = $uglygep3$i$i$i$i$i6 >>> 2;
   $21 = $20 ^ -1;
   $scevgep4$i$i$i$i$i7 = (($17) + ($21<<2)|0);
   HEAP32[$16>>2] = $scevgep4$i$i$i$i$i7;
  }
  __ZdlPv($14);
 }
 __ZdlPv($12);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm13LivenessState13FilterObjectsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $filtered_objects = 0, $i$01 = 0, $num_objects$02 = 0, $num_objects$1 = 0, $num_objects$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $filtered_objects = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($0>>>0)<($9>>>0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 8|0);
 $12 = (($this) + 24|0);
 $13 = (($this) + 20|0);
 $15 = $5;$i$01 = $0;$num_objects$02 = 0;
 while(1) {
  $14 = (($15) + ($i$01<<2)|0);
  $16 = HEAP32[$14>>2]|0;
  $17 = HEAP32[$11>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   label = 5;
  } else {
   $19 = HEAP32[$16>>2]|0;
   $20 = $19;
   $21 = $20 & -2;
   $22 = $21;
   $23 = (__ZN6il2cpp2vm5Class9HasParentEPK8TypeInfoS4_($22,$17)|0);
   if ($23) {
    label = 5;
   } else {
    $num_objects$1 = $num_objects$02;
   }
  }
  if ((label|0) == 5) {
   label = 0;
   $24 = (($num_objects$02) + 1)|0;
   $25 = (($filtered_objects) + ($num_objects$02<<2)|0);
   HEAP32[$25>>2] = $16;
   $num_objects$1 = $24;
  }
  $26 = ($num_objects$1|0)==(64);
  if ($26) {
   $27 = HEAP32[$12>>2]|0;
   $28 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_viii[$27 & 4095]($filtered_objects,64,$28);
   $num_objects$2 = 0;
  } else {
   $num_objects$2 = $num_objects$1;
  }
  $29 = (($i$01) + 1)|0;
  $30 = HEAP32[$1>>2]|0;
  $31 = (($30) + 4|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$30>>2]|0;
  $34 = $32;
  $35 = $33;
  $36 = (($34) - ($35))|0;
  $37 = $36 >> 2;
  $38 = ($29>>>0)<($37>>>0);
  if ($38) {
   $15 = $33;$i$01 = $29;$num_objects$02 = $num_objects$2;
  } else {
   break;
  }
 }
 $39 = ($num_objects$2|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($this) + 20|0);
 $43 = HEAP32[$42>>2]|0;
 FUNCTION_TABLE_viii[$41 & 4095]($filtered_objects,$num_objects$2,$43);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm13LivenessState13TraverseArrayEP11Il2CppArrayPS1_($array,$state) {
 $array = $array|0;
 $state = $state|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $__new_last2$i$i$i$i4 = 0, $exitcond = 0, $exitcond17 = 0, $has_references$0$off0 = 0, $i$014 = 0, $i$110 = 0, $iter = 0, $or$cond$i = 0, $scevgep4$i$i$i$i = 0, $scevgep4$i$i$i$i8 = 0;
 var $uglygep$i$i$i$i = 0, $uglygep$i$i$i$i6 = 0, $uglygep3$i$i$i$i = 0, $uglygep3$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 $0 = HEAP32[$array>>2]|0;
 $1 = $0;
 $2 = $1 & -2;
 $3 = $2;
 $4 = (($3) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN6il2cpp2vm5Class11IsValuetypeEPK8TypeInfo($5)|0);
 $7 = $6 ^ 1;
 HEAP32[$iter>>2] = 0;
 $has_references$0$off0 = $7;
 while(1) {
  $8 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($5,$iter)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   label = 7;
   break;
  }
  $10 = (($8) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__ZN6il2cpp2vm4Type8IsStructEPK10Il2CppType($11)|0);
  if ($12) {
   break;
  }
  $13 = HEAP32[$10>>2]|0;
  $14 = (($13) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 & 64;
  $17 = ($16|0)!=(0);
  $18 = $15 & 16711680;
  $19 = ($18|0)==(917504);
  $or$cond$i = $17 | $19;
  if ($or$cond$i) {
   $$0$i = 0;
  } else {
   $20 = (__ZN6il2cpp2vm4Type11IsReferenceEPK10Il2CppType($13)|0);
   $$0$i = $20;
  }
  $21 = $has_references$0$off0 | $$0$i;
  if ($21) {
   break;
  } else {
   $has_references$0$off0 = 0;
  }
 }
 if ((label|0) == 7) {
  if (!($has_references$0$off0)) {
   STACKTOP = sp;return;
  }
 }
 $22 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($array)|0);
 $23 = (($5) + 113|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $26 = ($22|0)==(0);
  if ($26) {
   STACKTOP = sp;return;
  }
  $27 = (($state) + 12|0);
  $i$110 = 0;
  while(1) {
   $59 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($array,4,$i$110)|0);
   $60 = HEAP32[$59>>2]|0;
   __ZN6il2cpp2vm13LivenessState16AddProcessObjectEP12Il2CppObjectPS1_($60,$state);
   $61 = (($i$110) + 1)|0;
   $62 = $61 & 63;
   $63 = ($62|0)==(0);
   if ($63) {
    $64 = HEAP32[$27>>2]|0;
    $65 = (($64) + 4|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = HEAP32[$64>>2]|0;
    $68 = ($66|0)==($67|0);
    if (!($68)) {
     $70 = $66;$75 = $65;
     while(1) {
      $69 = (($70) + -4|0);
      $71 = HEAP32[$69>>2]|0;
      $__new_last2$i$i$i$i = $69;
      $72 = (0 - ($__new_last2$i$i$i$i))|0;
      $uglygep$i$i$i$i = (($69) + ($72)|0);
      $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
      $73 = $uglygep3$i$i$i$i >>> 2;
      $74 = $73 ^ -1;
      $scevgep4$i$i$i$i = (($70) + ($74<<2)|0);
      HEAP32[$75>>2] = $scevgep4$i$i$i$i;
      $76 = HEAP32[$71>>2]|0;
      $77 = $76;
      $78 = $77 & -2;
      $79 = $78;
      $80 = (($79) + 112|0);
      $81 = HEAP8[$80>>0]|0;
      $82 = ($81<<24>>24)==(0);
      if ($82) {
       __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($71,0,$79,$state);
      } else {
       __ZN6il2cpp2vm13LivenessState13TraverseArrayEP11Il2CppArrayPS1_($71,$state);
      }
      $83 = HEAP32[$27>>2]|0;
      $84 = (($83) + 4|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = HEAP32[$83>>2]|0;
      $87 = ($85|0)==($86|0);
      if ($87) {
       break;
      } else {
       $70 = $85;$75 = $84;
      }
     }
    }
   }
   $exitcond = ($61|0)==($22|0);
   if ($exitcond) {
    break;
   } else {
    $i$110 = $61;
   }
  }
  STACKTOP = sp;return;
 } else {
  $28 = (__ZN6il2cpp2vm5Class19GetArrayElementSizeEPK8TypeInfo($5)|0);
  $29 = ($22|0)==(0);
  if ($29) {
   STACKTOP = sp;return;
  }
  $30 = (($state) + 12|0);
  $i$014 = 0;
  while(1) {
   $31 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($array,$28,$i$014)|0);
   __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($31,1,$5,$state);
   $32 = (($i$014) + 1)|0;
   $33 = $32 & 63;
   $34 = ($33|0)==(0);
   if ($34) {
    $35 = HEAP32[$30>>2]|0;
    $36 = (($35) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$35>>2]|0;
    $39 = ($37|0)==($38|0);
    if (!($39)) {
     $41 = $37;$46 = $36;
     while(1) {
      $40 = (($41) + -4|0);
      $42 = HEAP32[$40>>2]|0;
      $__new_last2$i$i$i$i4 = $40;
      $43 = (0 - ($__new_last2$i$i$i$i4))|0;
      $uglygep$i$i$i$i6 = (($40) + ($43)|0);
      $uglygep3$i$i$i$i7 = $uglygep$i$i$i$i6;
      $44 = $uglygep3$i$i$i$i7 >>> 2;
      $45 = $44 ^ -1;
      $scevgep4$i$i$i$i8 = (($41) + ($45<<2)|0);
      HEAP32[$46>>2] = $scevgep4$i$i$i$i8;
      $47 = HEAP32[$42>>2]|0;
      $48 = $47;
      $49 = $48 & -2;
      $50 = $49;
      $51 = (($50) + 112|0);
      $52 = HEAP8[$51>>0]|0;
      $53 = ($52<<24>>24)==(0);
      if ($53) {
       __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($42,0,$50,$state);
      } else {
       __ZN6il2cpp2vm13LivenessState13TraverseArrayEP11Il2CppArrayPS1_($42,$state);
      }
      $54 = HEAP32[$30>>2]|0;
      $55 = (($54) + 4|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$54>>2]|0;
      $58 = ($56|0)==($57|0);
      if ($58) {
       break;
      } else {
       $41 = $56;$46 = $55;
      }
     }
    }
   }
   $exitcond17 = ($32|0)==($22|0);
   if ($exitcond17) {
    break;
   } else {
    $i$014 = $32;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($object,$isStruct,$klass,$state) {
 $object = $object|0;
 $isStruct = $isStruct|0;
 $klass = $klass|0;
 $state = $state|0;
 var $$object = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $iter = 0, $or$cond$i = 0, $p$02 = 0, $val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp + 4|0;
 $val = sp;
 $0 = (($object) + -8|0);
 $$object = $isStruct ? $0 : $object;
 $1 = ($klass|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $p$02 = $klass;
 while(1) {
  $2 = (($p$02) + 121|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   HEAP32[$iter>>2] = 0;
   $5 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($p$02,$iter)|0);
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $8 = $5;
    while(1) {
     $7 = (($8) + 4|0);
     $9 = HEAP32[$7>>2]|0;
     $10 = (($9) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = $11 & 16;
     $13 = ($12|0)==(0);
     do {
      if ($13) {
       $14 = (__ZN6il2cpp2vm4Type8IsStructEPK10Il2CppType($9)|0);
       if (!($14)) {
        $15 = HEAP32[$7>>2]|0;
        $16 = (($15) + 4|0);
        $17 = HEAP32[$16>>2]|0;
        $18 = $17 & 64;
        $19 = ($18|0)!=(0);
        $20 = $17 & 16711680;
        $21 = ($20|0)==(917504);
        $or$cond$i = $19 | $21;
        if ($or$cond$i) {
         break;
        }
        $22 = (__ZN6il2cpp2vm4Type11IsReferenceEPK10Il2CppType($15)|0);
        if (!($22)) {
         break;
        }
       }
       $25 = HEAP32[$7>>2]|0;
       $26 = (__ZN6il2cpp2vm4Type8IsStructEPK10Il2CppType($25)|0);
       $27 = (($8) + 12|0);
       $28 = HEAP32[$27>>2]|0;
       if (!($26)) {
        $39 = ($28|0)==(-1);
        if ($39) {
         break;
        }
        HEAP32[$val>>2] = 0;
        __ZN6il2cpp2vm5Field8GetValueEP12Il2CppObjectP9FieldInfoPv($$object,$8,$val);
        $40 = HEAP32[$val>>2]|0;
        __ZN6il2cpp2vm13LivenessState16AddProcessObjectEP12Il2CppObjectPS1_($40,$state);
        break;
       }
       $29 = (($$object) + ($28)|0);
       $30 = HEAP32[$7>>2]|0;
       $31 = (($30) + 4|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = $32 & 16711680;
       $34 = ($33|0)==(1376256);
       if ($34) {
        $35 = HEAP32[$30>>2]|0;
        $36 = (($35) + 12|0);
        $37 = HEAP32[$36>>2]|0;
        __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($29,1,$37,$state);
        break;
       } else {
        $38 = HEAP32[$30>>2]|0;
        __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($29,1,$38,$state);
        break;
       }
      }
     } while(0);
     $23 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($p$02,$iter)|0);
     $24 = ($23|0)==(0|0);
     if ($24) {
      break;
     } else {
      $8 = $23;
     }
    }
   }
  }
  $41 = (($p$02) + 20|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   break;
  } else {
   $p$02 = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm13LivenessState16AddProcessObjectEP12Il2CppObjectPS1_($object,$state) {
 $object = $object|0;
 $state = $state|0;
 var $$0$i2$i$i = 0, $$0$i2$i$i4 = 0, $$0$i3$i$i = 0, $$0$i3$i$i6 = 0, $$phi$trans$insert = 0, $$phi$trans$insert11 = 0, $$phi$trans$insert14 = 0, $$phi$trans$insert16 = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre10 = 0, $$pre12 = 0, $$pre13 = 0, $$pre15 = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($object|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$object>>2]|0;
 $2 = $1;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = $2 & -2;
 $6 = $5;
 $7 = (($6) + 119|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 if ($9) {
  label = 6;
 } else {
  $10 = (($state) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   label = 6;
  } else {
   $13 = (__ZN6il2cpp2vm5Class9HasParentEPK8TypeInfoS4_($6,$11)|0);
   if ($13) {
    label = 6;
   }
  }
 }
 if ((label|0) == 6) {
  $14 = (($state) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($17|0)==($19|0);
  if ($20) {
   __ZN6il2cpp2vm13LivenessState13SafeGrowArrayEPNSt3__16vectorIP12Il2CppObjectNS2_9allocatorIS5_EEEE($state,$15);
   $$pre = HEAP32[$14>>2]|0;
   $$phi$trans$insert = (($$pre) + 4|0);
   $$pre10 = HEAP32[$$phi$trans$insert>>2]|0;
   $$phi$trans$insert11 = (($$pre) + 8|0);
   $$pre12 = HEAP32[$$phi$trans$insert11>>2]|0;
   $22 = $$pre;$25 = $$pre10;$26 = $$pre12;
  } else {
   $22 = $15;$25 = $17;$26 = $19;
  }
  $21 = (($22) + 4|0);
  $23 = (($22) + 8|0);
  $24 = ($25|0)==($26|0);
  if ($24) {
   $30 = HEAP32[$22>>2]|0;
   $31 = $26;
   $32 = $30;
   $33 = (($31) - ($32))|0;
   $34 = $33 >> 2;
   $35 = (($34) + 1)|0;
   $36 = ($35>>>0)>(1073741823);
   if ($36) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $37 = ($34>>>0)<(536870911);
   if ($37) {
    $38 = $33 >> 1;
    $39 = ($38>>>0)<($35>>>0);
    $40 = $39 ? $35 : $38;
    $41 = ($40|0)==(0);
    if ($41) {
     $$0$i3$i$i6 = 0;$45 = 0;
    } else {
     $$0$i2$i$i4 = $40;
     label = 16;
    }
   } else {
    $$0$i2$i$i4 = 1073741823;
    label = 16;
   }
   if ((label|0) == 16) {
    $42 = $$0$i2$i$i4 << 2;
    $43 = (__Znwj($42)|0);
    $$0$i3$i$i6 = $$0$i2$i$i4;$45 = $43;
   }
   $44 = (($45) + ($34<<2)|0);
   $46 = (($45) + ($$0$i3$i$i6<<2)|0);
   $47 = ($44|0)==(0|0);
   if (!($47)) {
    HEAP32[$44>>2] = $object;
   }
   $48 = (($45) + ($35<<2)|0);
   _memcpy(($45|0),($30|0),($33|0))|0;
   HEAP32[$22>>2] = $45;
   HEAP32[$21>>2] = $48;
   HEAP32[$23>>2] = $46;
   $49 = ($30|0)==(0|0);
   if (!($49)) {
    __ZdlPv($30);
   }
  } else {
   $27 = ($25|0)==(0|0);
   if ($27) {
    $29 = 0;
   } else {
    HEAP32[$25>>2] = $object;
    $$pre$i1 = HEAP32[$21>>2]|0;
    $29 = $$pre$i1;
   }
   $28 = (($29) + 4|0);
   HEAP32[$21>>2] = $28;
  }
  $50 = HEAP32[$object>>2]|0;
  $51 = $50;
  $52 = $51 | 1;
  $53 = $52;
  HEAP32[$object>>2] = $53;
 }
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $54 = (($state) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 8|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($57|0)==($59|0);
 if ($60) {
  __ZN6il2cpp2vm13LivenessState13SafeGrowArrayEPNSt3__16vectorIP12Il2CppObjectNS2_9allocatorIS5_EEEE($state,$55);
  $$pre13 = HEAP32[$54>>2]|0;
  $$phi$trans$insert14 = (($$pre13) + 4|0);
  $$pre15 = HEAP32[$$phi$trans$insert14>>2]|0;
  $$phi$trans$insert16 = (($$pre13) + 8|0);
  $$pre17 = HEAP32[$$phi$trans$insert16>>2]|0;
  $62 = $$pre13;$65 = $$pre15;$66 = $$pre17;
 } else {
  $62 = $55;$65 = $57;$66 = $59;
 }
 $61 = (($62) + 4|0);
 $63 = (($62) + 8|0);
 $64 = ($65|0)==($66|0);
 if (!($64)) {
  $67 = ($65|0)==(0|0);
  if ($67) {
   $69 = 0;
  } else {
   HEAP32[$65>>2] = $object;
   $$pre$i = HEAP32[$61>>2]|0;
   $69 = $$pre$i;
  }
  $68 = (($69) + 4|0);
  HEAP32[$61>>2] = $68;
  STACKTOP = sp;return;
 }
 $70 = HEAP32[$62>>2]|0;
 $71 = $66;
 $72 = $70;
 $73 = (($71) - ($72))|0;
 $74 = $73 >> 2;
 $75 = (($74) + 1)|0;
 $76 = ($75>>>0)>(1073741823);
 if ($76) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $77 = ($74>>>0)<(536870911);
 if ($77) {
  $78 = $73 >> 1;
  $79 = ($78>>>0)<($75>>>0);
  $80 = $79 ? $75 : $78;
  $81 = ($80|0)==(0);
  if ($81) {
   $$0$i3$i$i = 0;$85 = 0;
  } else {
   $$0$i2$i$i = $80;
   label = 33;
  }
 } else {
  $$0$i2$i$i = 1073741823;
  label = 33;
 }
 if ((label|0) == 33) {
  $82 = $$0$i2$i$i << 2;
  $83 = (__Znwj($82)|0);
  $$0$i3$i$i = $$0$i2$i$i;$85 = $83;
 }
 $84 = (($85) + ($74<<2)|0);
 $86 = (($85) + ($$0$i3$i$i<<2)|0);
 $87 = ($84|0)==(0|0);
 if (!($87)) {
  HEAP32[$84>>2] = $object;
 }
 $88 = (($85) + ($75<<2)|0);
 _memcpy(($85|0),($70|0),($73|0))|0;
 HEAP32[$62>>2] = $85;
 HEAP32[$61>>2] = $88;
 HEAP32[$63>>2] = $86;
 $89 = ($70|0)==(0|0);
 if ($89) {
  STACKTOP = sp;return;
 }
 __ZdlPv($70);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm13LivenessState13SafeGrowArrayEPNSt3__16vectorIP12Il2CppObjectNS2_9allocatorIS5_EEEE($this,$array) {
 $this = $this|0;
 $array = $array|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $i$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $7 = $4;$i$02 = 0;
  while(1) {
   $6 = (($7) + ($i$02<<2)|0);
   $8 = HEAP32[$6>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   $10 = $9;
   $11 = $10 & -2;
   $12 = $11;
   HEAP32[$8>>2] = $12;
   $13 = (($i$02) + 1)|0;
   $14 = HEAP32[$0>>2]|0;
   $15 = (($14) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$14>>2]|0;
   $18 = $16;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = $20 >> 2;
   $22 = ($13>>>0)<($21>>>0);
   if ($22) {
    $7 = $17;$i$02 = $13;
   } else {
    break;
   }
  }
 }
 $23 = (($array) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$array>>2]|0;
 $26 = $24;
 $27 = $25;
 $28 = (($26) - ($27))|0;
 $29 = $28 >> 2;
 $30 = $28 >> 1;
 $31 = ($29>>>0)<($30>>>0);
 if ($31) {
  $32 = (($array) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33;
  $35 = (($34) - ($27))|0;
  $36 = $35 >> 2;
  $37 = ($30|0)==(0);
  if ($37) {
   $41 = 0;
  } else {
   $38 = $28 << 1;
   $39 = (__Znwj($38)|0);
   $41 = $39;
  }
  $40 = (($41) + ($36<<2)|0);
  $42 = (($41) + ($30<<2)|0);
  _memcpy(($41|0),($25|0),($35|0))|0;
  HEAP32[$array>>2] = $41;
  HEAP32[$32>>2] = $40;
  HEAP32[$23>>2] = $42;
  $43 = ($25|0)==(0|0);
  if (!($43)) {
   __ZdlPv($25);
  }
 }
 $44 = HEAP32[$0>>2]|0;
 $45 = (($44) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$44>>2]|0;
 $48 = ($46|0)==($47|0);
 if ($48) {
  STACKTOP = sp;return;
 } else {
  $50 = $47;$i$11 = 0;
 }
 while(1) {
  $49 = (($50) + ($i$11<<2)|0);
  $51 = HEAP32[$49>>2]|0;
  $52 = HEAP32[$51>>2]|0;
  $53 = $52;
  $54 = $53 | 1;
  $55 = $54;
  HEAP32[$51>>2] = $55;
  $56 = (($i$11) + 1)|0;
  $57 = HEAP32[$0>>2]|0;
  $58 = (($57) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$57>>2]|0;
  $61 = $59;
  $62 = $60;
  $63 = (($61) - ($62))|0;
  $64 = $63 >> 2;
  $65 = ($56>>>0)<($64>>>0);
  if ($65) {
   $50 = $60;$i$11 = $56;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm8Liveness5BeginEP8TypeInfoiPFvPPviS4_ES4_($filter,$max_object_count,$callback,$userdata) {
 $filter = $filter|0;
 $max_object_count = $max_object_count|0;
 $callback = $callback|0;
 $userdata = $userdata|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(28)|0);
 $1 = (($0) + 8|0);
 $2 = (($0) + 12|0);
 $3 = (($0) + 20|0);
 $4 = (($0) + 24|0);
 $5 = ($max_object_count>>>0)<(1000);
 $6 = $5 ? 1000 : $max_object_count;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;
 __THREW__ = 0;
 $7 = (invoke_ii(2988,12)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if (!($9)) {
   $10 = (($0) + 4|0);
   HEAP32[$7>>2] = 0;
   $11 = (($7) + 4|0);
   HEAP32[$11>>2] = 0;
   $12 = (($7) + 8|0);
   HEAP32[$12>>2] = 0;
   HEAP32[$10>>2] = $7;
   $13 = $6 << 2;
   $14 = ($13|0)==(0);
   if (!($14)) {
    $15 = $6 << 4;
    __THREW__ = 0;
    $16 = (invoke_ii(2988,($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    $19 = (($16) + ($13<<2)|0);
    HEAP32[$7>>2] = $16;
    HEAP32[$11>>2] = $16;
    HEAP32[$12>>2] = $19;
   }
   __THREW__ = 0;
   $20 = (invoke_ii(2988,12)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    HEAP32[$20>>2] = 0;
    $23 = (($20) + 4|0);
    HEAP32[$23>>2] = 0;
    $24 = (($20) + 8|0);
    HEAP32[$24>>2] = 0;
    HEAP32[$2>>2] = $20;
    $25 = ($6|0)==(0);
    if ($25) {
     HEAP32[$0>>2] = 0;
     HEAP32[$1>>2] = $filter;
     HEAP32[$3>>2] = $userdata;
     HEAP32[$4>>2] = $callback;
     STACKTOP = sp;return ($0|0);
    }
    __THREW__ = 0;
    $26 = (invoke_ii(2988,($13|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = (($26) + ($6<<2)|0);
     HEAP32[$20>>2] = $26;
     HEAP32[$23>>2] = $26;
     HEAP32[$24>>2] = $29;
     HEAP32[$0>>2] = 0;
     HEAP32[$1>>2] = $filter;
     HEAP32[$3>>2] = $userdata;
     HEAP32[$4>>2] = $callback;
     STACKTOP = sp;return ($0|0);
    }
   }
  }
 } while(0);
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZdlPv($0);
 ___resumeException($30|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp2vm8Liveness3EndEPv($state) {
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $7 = $4;$i$01$i = 0;
  while(1) {
   $6 = (($7) + ($i$01$i<<2)|0);
   $8 = HEAP32[$6>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   $10 = $9;
   $11 = $10 & -2;
   $12 = $11;
   HEAP32[$8>>2] = $12;
   $13 = (($i$01$i) + 1)|0;
   $14 = HEAP32[$0>>2]|0;
   $15 = (($14) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$14>>2]|0;
   $18 = $16;
   $19 = $17;
   $20 = (($18) - ($19))|0;
   $21 = $20 >> 2;
   $22 = ($13>>>0)<($21>>>0);
   if ($22) {
    $7 = $17;$i$01$i = $13;
   } else {
    break;
   }
  }
 }
 __THREW__ = 0;
 invoke_vi(3364,($state|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZdlPv($state);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZdlPv($state);
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2vm8Liveness8FromRootEP12Il2CppObjectPv($root,$state) {
 $root = $root|0;
 $state = $state|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $__new_last2$i$i$i$i1 = 0, $scevgep$i$i$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $scevgep4$i$i$i$i5 = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i$i$i3 = 0, $uglygep3$i$i$i$i = 0, $uglygep3$i$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$state>>2] = $8;
 $9 = (($state) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($10) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($11|0);
 if ($14) {
  $19 = $10;$23 = $11;
 } else {
  $__new_last2$i$i$i$i = $11;
  $scevgep$i$i$i$i = (($13) + -4|0);
  $15 = (0 - ($__new_last2$i$i$i$i))|0;
  $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($15)|0);
  $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
  $16 = $uglygep3$i$i$i$i >>> 2;
  $17 = $16 ^ -1;
  $scevgep4$i$i$i$i = (($13) + ($17<<2)|0);
  HEAP32[$12>>2] = $scevgep4$i$i$i$i;
  $$pre = HEAP32[$9>>2]|0;
  $$phi$trans$insert = (($$pre) + 4|0);
  $$pre6 = HEAP32[$$phi$trans$insert>>2]|0;
  $19 = $$pre;$23 = $$pre6;
 }
 $18 = (($19) + 4|0);
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($23|0)==($21|0);
 if ($22) {
  $27 = HEAP32[$19>>2]|0;
  $28 = $23;
  $29 = $27;
  $30 = (($28) - ($29))|0;
  $31 = $30 >> 2;
  $32 = (($31) + 1)|0;
  $33 = ($32>>>0)>(1073741823);
  if ($33) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $34 = ($31>>>0)<(536870911);
  if ($34) {
   $35 = $30 >> 1;
   $36 = ($35>>>0)<($32>>>0);
   $37 = $36 ? $32 : $35;
   $38 = ($37|0)==(0);
   if ($38) {
    $$0$i3$i$i = 0;$42 = 0;
   } else {
    $$0$i2$i$i = $37;
    label = 11;
   }
  } else {
   $$0$i2$i$i = 1073741823;
   label = 11;
  }
  if ((label|0) == 11) {
   $39 = $$0$i2$i$i << 2;
   $40 = (__Znwj($39)|0);
   $$0$i3$i$i = $$0$i2$i$i;$42 = $40;
  }
  $41 = (($42) + ($31<<2)|0);
  $43 = (($42) + ($$0$i3$i$i<<2)|0);
  $44 = ($41|0)==(0|0);
  if (!($44)) {
   HEAP32[$41>>2] = $root;
  }
  $45 = (($42) + ($32<<2)|0);
  _memcpy(($42|0),($27|0),($30|0))|0;
  HEAP32[$19>>2] = $42;
  HEAP32[$18>>2] = $45;
  HEAP32[$20>>2] = $43;
  $46 = ($27|0)==(0|0);
  if (!($46)) {
   __ZdlPv($27);
  }
 } else {
  $24 = ($23|0)==(0|0);
  if ($24) {
   $26 = 0;
  } else {
   HEAP32[$23>>2] = $root;
   $$pre$i = HEAP32[$18>>2]|0;
   $26 = $$pre$i;
  }
  $25 = (($26) + 4|0);
  HEAP32[$18>>2] = $25;
 }
 $47 = HEAP32[$9>>2]|0;
 $48 = (($47) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$47>>2]|0;
 $51 = ($49|0)==($50|0);
 if ($51) {
  __ZN6il2cpp2vm13LivenessState13FilterObjectsEv($state);
  STACKTOP = sp;return;
 } else {
  $53 = $49;$58 = $48;
 }
 while(1) {
  $52 = (($53) + -4|0);
  $54 = HEAP32[$52>>2]|0;
  $__new_last2$i$i$i$i1 = $52;
  $55 = (0 - ($__new_last2$i$i$i$i1))|0;
  $uglygep$i$i$i$i3 = (($52) + ($55)|0);
  $uglygep3$i$i$i$i4 = $uglygep$i$i$i$i3;
  $56 = $uglygep3$i$i$i$i4 >>> 2;
  $57 = $56 ^ -1;
  $scevgep4$i$i$i$i5 = (($53) + ($57<<2)|0);
  HEAP32[$58>>2] = $scevgep4$i$i$i$i5;
  $59 = HEAP32[$54>>2]|0;
  $60 = $59;
  $61 = $60 & -2;
  $62 = $61;
  $63 = (($62) + 112|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = ($64<<24>>24)==(0);
  if ($65) {
   __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($54,0,$62,$state);
  } else {
   __ZN6il2cpp2vm13LivenessState13TraverseArrayEP11Il2CppArrayPS1_($54,$state);
  }
  $66 = HEAP32[$9>>2]|0;
  $67 = (($66) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = HEAP32[$66>>2]|0;
  $70 = ($68|0)==($69|0);
  if ($70) {
   break;
  } else {
   $53 = $68;$58 = $67;
  }
 }
 __ZN6il2cpp2vm13LivenessState13FilterObjectsEv($state);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm8Liveness11FromStaticsEPv($state) {
 $state = $state|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i = 0, $__new_last2$i$i$i$i1 = 0, $fieldIter = 0, $or$cond$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep4$i$i$i$i5 = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i$i$i3 = 0, $uglygep3$i$i$i$i = 0, $uglygep3$i$i$i$i4 = 0, $val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fieldIter = sp + 4|0;
 $val = sp;
 $0 = (__ZN6il2cpp2vm5Class18GetStaticFieldDataEv()|0);
 $1 = (($state) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 HEAP32[$state>>2] = $9;
 $10 = (($state) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($11) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==($12|0);
 if (!($15)) {
  $__new_last2$i$i$i$i = $12;
  $scevgep$i$i$i$i = (($14) + -4|0);
  $16 = (0 - ($__new_last2$i$i$i$i))|0;
  $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($16)|0);
  $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
  $17 = $uglygep3$i$i$i$i >>> 2;
  $18 = $17 ^ -1;
  $scevgep4$i$i$i$i = (($14) + ($18<<2)|0);
  HEAP32[$13>>2] = $scevgep4$i$i$i$i;
 }
 $19 = HEAP32[$0>>2]|0;
 $20 = (($0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19|0)==($21|0);
 if (!($22)) {
  $100 = $21;$24 = $19;
  while(1) {
   $23 = HEAP32[$24>>2]|0;
   $25 = ($23|0)==(0|0);
   if ($25) {
    $75 = $100;
   } else {
    $26 = (($23) + 64|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = HEAP32[388944>>2]|0;
    $29 = ($27|0)==($28|0);
    if ($29) {
     $75 = $100;
    } else {
     $30 = (($23) + 121|0);
     $31 = HEAP8[$30>>0]|0;
     $32 = ($31<<24>>24)==(0);
     if ($32) {
      $75 = $100;
     } else {
      HEAP32[$fieldIter>>2] = 0;
      $33 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($23,$fieldIter)|0);
      $34 = ($33|0)==(0|0);
      if (!($34)) {
       $35 = (($23) + 80|0);
       $37 = $33;
       while(1) {
        $36 = (($37) + 4|0);
        $38 = HEAP32[$36>>2]|0;
        $39 = (($38) + 4|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = $40 & 16;
        $42 = ($41|0)==(0);
        do {
         if (!($42)) {
          $43 = (__ZN6il2cpp2vm4Type8IsStructEPK10Il2CppType($38)|0);
          if (!($43)) {
           $44 = HEAP32[$36>>2]|0;
           $45 = (($44) + 4|0);
           $46 = HEAP32[$45>>2]|0;
           $47 = $46 & 64;
           $48 = ($47|0)!=(0);
           $49 = $46 & 16711680;
           $50 = ($49|0)==(917504);
           $or$cond$i = $48 | $50;
           if ($or$cond$i) {
            break;
           }
           $51 = (__ZN6il2cpp2vm4Type11IsReferenceEPK10Il2CppType($44)|0);
           if (!($51)) {
            break;
           }
          }
          $54 = (($37) + 12|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = ($55|0)==(-1);
          if (!($56)) {
           $57 = HEAP32[$36>>2]|0;
           $58 = (__ZN6il2cpp2vm4Type8IsStructEPK10Il2CppType($57)|0);
           if (!($58)) {
            HEAP32[$val>>2] = 0;
            __ZN6il2cpp2vm5Field14StaticGetValueEP9FieldInfoPv($37,$val);
            $71 = HEAP32[$val>>2]|0;
            $72 = ($71|0)==(0|0);
            if ($72) {
             break;
            }
            __ZN6il2cpp2vm13LivenessState16AddProcessObjectEP12Il2CppObjectPS1_($71,$state);
            break;
           }
           $59 = HEAP32[$35>>2]|0;
           $60 = HEAP32[$54>>2]|0;
           $61 = (($59) + ($60)|0);
           $62 = HEAP32[$36>>2]|0;
           $63 = (($62) + 4|0);
           $64 = HEAP32[$63>>2]|0;
           $65 = $64 & 16711680;
           $66 = ($65|0)==(1376256);
           if ($66) {
            $67 = HEAP32[$62>>2]|0;
            $68 = (($67) + 12|0);
            $69 = HEAP32[$68>>2]|0;
            __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($61,1,$69,$state);
            break;
           } else {
            $70 = HEAP32[$62>>2]|0;
            __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($61,1,$70,$state);
            break;
           }
          }
         }
        } while(0);
        $52 = (__ZN6il2cpp2vm5Class9GetFieldsEPK8TypeInfoPPv($23,$fieldIter)|0);
        $53 = ($52|0)==(0|0);
        if ($53) {
         break;
        } else {
         $37 = $52;
        }
       }
      }
      $$pre = HEAP32[$20>>2]|0;
      $75 = $$pre;
     }
    }
   }
   $73 = (($24) + 4|0);
   $74 = ($73|0)==($75|0);
   if ($74) {
    break;
   } else {
    $100 = $75;$24 = $73;
   }
  }
 }
 $76 = HEAP32[$10>>2]|0;
 $77 = (($76) + 4|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = HEAP32[$76>>2]|0;
 $80 = ($78|0)==($79|0);
 if ($80) {
  __ZN6il2cpp2vm13LivenessState13FilterObjectsEv($state);
  STACKTOP = sp;return;
 } else {
  $82 = $78;$87 = $77;
 }
 while(1) {
  $81 = (($82) + -4|0);
  $83 = HEAP32[$81>>2]|0;
  $__new_last2$i$i$i$i1 = $81;
  $84 = (0 - ($__new_last2$i$i$i$i1))|0;
  $uglygep$i$i$i$i3 = (($81) + ($84)|0);
  $uglygep3$i$i$i$i4 = $uglygep$i$i$i$i3;
  $85 = $uglygep3$i$i$i$i4 >>> 2;
  $86 = $85 ^ -1;
  $scevgep4$i$i$i$i5 = (($82) + ($86<<2)|0);
  HEAP32[$87>>2] = $scevgep4$i$i$i$i5;
  $88 = HEAP32[$83>>2]|0;
  $89 = $88;
  $90 = $89 & -2;
  $91 = $90;
  $92 = (($91) + 112|0);
  $93 = HEAP8[$92>>0]|0;
  $94 = ($93<<24>>24)==(0);
  if ($94) {
   __ZN6il2cpp2vm13LivenessState22TraverseObjectInternalEP12Il2CppObjectbP8TypeInfoPS1_($83,0,$91,$state);
  } else {
   __ZN6il2cpp2vm13LivenessState13TraverseArrayEP11Il2CppArrayPS1_($83,$state);
  }
  $95 = HEAP32[$10>>2]|0;
  $96 = (($95) + 4|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = HEAP32[$95>>2]|0;
  $99 = ($97|0)==($98|0);
  if ($99) {
   break;
  } else {
   $82 = $97;$87 = $96;
  }
 }
 __ZN6il2cpp2vm13LivenessState13FilterObjectsEv($state);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm6Method13GetReturnTypeEP10MethodInfo($method) {
 $method = $method|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($method) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm6Method7GetNameEP10MethodInfo($method) {
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm6Method10IsInstanceEP10MethodInfo($method) {
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($method) + 28|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 16;
 $3 = ($2<<16>>16)==(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp2vm6Method13GetParamCountEP10MethodInfo($method) {
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($method) + 33|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm6Method8GetParamEP10MethodInfoj($method,$index) {
 $method = $method|0;
 $index = $index|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($method) + 33|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = ($2>>>0)>($index>>>0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($method) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5) + (($index*12)|0)|0) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm6Method12HasAttributeEP10MethodInfoP8TypeInfo($method,$attr_class) {
 $method = $method|0;
 $attr_class = $attr_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP10MethodInfo($method)|0);
 $1 = (($0) + 4|0);
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $i$01 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $7 = HEAP32[$1>>2]|0;
  $8 = (($7) + ($i$01<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($9)|0);
  $11 = ($10|0)==($attr_class|0);
  $6 = (($i$01) + 1)|0;
  if ($11) {
   $$0 = 1;
   label = 4;
   break;
  }
  $4 = HEAP32[$0>>2]|0;
  $5 = ($6|0)<($4|0);
  if ($5) {
   $i$01 = $6;
  } else {
   $$0 = 0;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm6Object8AllocateEjP8TypeInfo($size,$typeInfo) {
 $size = $size|0;
 $typeInfo = $typeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 388920;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (_i64Add(($2|0),($5|0),1,0)|0);
 $7 = tempRet0;
 $8 = 388920;
 $9 = $8;
 HEAP32[$9>>2] = $6;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = (_GC_malloc($size)|0);
 HEAP32[$12>>2] = $typeInfo;
 STACKTOP = sp;return ($12|0);
}
function __ZN6il2cpp2vm6Object15AllocatePtrFreeEjP8TypeInfo($size,$typeInfo) {
 $size = $size|0;
 $typeInfo = $typeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 388920;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (_i64Add(($2|0),($5|0),1,0)|0);
 $7 = tempRet0;
 $8 = 388920;
 $9 = $8;
 HEAP32[$9>>2] = $6;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = (_GC_malloc_atomic($size)|0);
 HEAP32[$12>>2] = $typeInfo;
 $13 = (($12) + 4|0);
 HEAP32[$13>>2] = 0;
 STACKTOP = sp;return ($12|0);
}
function __ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv($typeInfo,$val) {
 $typeInfo = $typeInfo|0;
 $val = $val|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($typeInfo) + 113|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = HEAP32[$val>>2]|0;
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 } else {
  $4 = (__ZN6il2cpp2vm5Class15GetInstanceSizeEPK8TypeInfo($typeInfo)|0);
  $5 = (__ZN6il2cpp2vm6Object16NewAllocSpecificEP8TypeInfo($typeInfo)|0);
  $6 = (($4) + -8)|0;
  $7 = (($5) + 8|0);
  _memcpy(($7|0),($val|0),($6|0))|0;
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm6Object3NewEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Object16NewAllocSpecificEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm6Object5CloneEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = 388920;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (_i64Add(($5|0),($8|0),1,0)|0);
 $10 = tempRet0;
 $11 = 388920;
 $12 = $11;
 HEAP32[$12>>2] = $9;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = (_GC_malloc($2)|0);
 HEAP32[$15>>2] = $0;
 $16 = (($15) + 8|0);
 $17 = (($obj) + 8|0);
 $18 = (($2) + -8)|0;
 _memcpy(($16|0),($17|0),($18|0))|0;
 $19 = HEAP32[$obj>>2]|0;
 $20 = (($19) + 122|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if (!($22)) {
  __Z28il2cpp_gc_register_finalizerP12Il2CppObject($15);
 }
 $23 = 0 & 128;
 $24 = ($23|0)==(0);
 if ($24) {
  STACKTOP = sp;return ($15|0);
 }
 $25 = HEAP32[$obj>>2]|0;
 __ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo($15,$25);
 STACKTOP = sp;return ($15|0);
}
function __ZN6il2cpp2vm6Object8GetClassEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm6Object7GetHashEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $obj;
 $1 = $0 >>> 2;
 $2 = Math_imul($1, -1640531535)|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN6il2cpp2vm6Object16GetVirtualMethodEP12Il2CppObjectP10MethodInfo($obj,$method) {
 $obj = $obj|0;
 $method = $method|0;
 var $$0 = 0, $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $res$0 = 0, $res$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($method) + 28|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 96;
 $6 = ($5<<16>>16)==(64);
 if (!($6)) {
  $$0 = $method;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($method) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 114|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $17 = (($method) + 32|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $$pn = $19;
 } else {
  $12 = (__ZN6il2cpp2vm5Class18GetInterfaceOffsetEPK8TypeInfoPS2_($0,$8)|0);
  $13 = (($method) + 32|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = (($15) + ($12))|0;
  $$pn = $16;
 }
 $res$0$in = (($2) + ($$pn<<2)|0);
 $res$0 = HEAP32[$res$0$in>>2]|0;
 $$0 = $res$0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_($klass,$1)|0);
 $3 = $2 ? $obj : 0;
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm6Object16NewAllocSpecificEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $o$0 = 0, $p$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($klass)|0);
 $0 = (($klass) + 119|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($klass) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 do {
  if ($2) {
   $5 = (_GC_malloc_atomic($4)|0);
   HEAP32[$5>>2] = $klass;
   $6 = (($5) + 4|0);
   HEAP32[$6>>2] = 0;
   $7 = HEAP32[$3>>2]|0;
   $8 = ($7>>>0)<(128);
   if (!($8)) {
    $14 = (($5) + 8|0);
    $15 = (($7) + -8)|0;
    _memset(($14|0),0,($15|0))|0;
    $o$0 = $5;
    break;
   }
   $9 = (($5) + ($7)|0);
   $10 = ($7|0)>(8);
   if ($10) {
    $11 = (($5) + 8|0);
    $p$01$i = $11;
    while(1) {
     HEAP32[$p$01$i>>2] = 0;
     $12 = (($p$01$i) + 4|0);
     $13 = ($12>>>0)<($9>>>0);
     if ($13) {
      $p$01$i = $12;
     } else {
      $o$0 = $5;
      break;
     }
    }
   } else {
    $o$0 = $5;
   }
  } else {
   $16 = 388920;
   $17 = $16;
   $18 = HEAP32[$17>>2]|0;
   $19 = (($16) + 4)|0;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (_i64Add(($18|0),($21|0),1,0)|0);
   $23 = tempRet0;
   $24 = 388920;
   $25 = $24;
   HEAP32[$25>>2] = $22;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   $28 = (_GC_malloc($4)|0);
   HEAP32[$28>>2] = $klass;
   $o$0 = $28;
  }
 } while(0);
 $29 = (($klass) + 122|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  __Z28il2cpp_gc_register_finalizerP12Il2CppObject($o$0);
 }
 $32 = 0 & 128;
 $33 = ($32|0)==(0);
 if ($33) {
  STACKTOP = sp;return ($o$0|0);
 }
 __ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo($o$0,$klass);
 STACKTOP = sp;return ($o$0|0);
}
function __ZN6il2cpp2vm6Object9NewPinnedEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN6il2cpp2vm6Object16NewAllocSpecificEP8TypeInfo($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($obj) + 8|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $14 = 0;$2 = 0;
 }
 while(1) {
  $1 = HEAP32[$2>>2]|0;
  $3 = (($1) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4 & 128;
  $6 = ($5|0)==(0);
  if ($6) {
   $13 = $14;
  } else {
   $7 = (($1) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $13 = $14;
   } else {
    $10 = HEAP32[$1>>2]|0;
    FUNCTION_TABLE_viii[$8 & 4095]($10,$obj,$klass);
    $13 = 0;
   }
  }
  $11 = (($2) + 4|0);
  $12 = ($11|0)==($13|0);
  if ($12) {
   break;
  } else {
   $14 = $13;$2 = $11;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm10Reflection17GetAssemblyObjectEP14Il2CppAssembly($assembly) {
 $assembly = $assembly|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $__nd$0$i$i = 0, $__nd$0$i$i16 = 0, $__nd$0$us$i$i = 0, $__nd$0$us$i$i10 = 0, $__nd$04$i$i = 0, $__nd$04$i$i3 = 0, $__nd$05$i$i = 0;
 var $__nd$05$i$i12 = 0, $__nd$05$us$i$i = 0, $__nd$05$us$i$i6 = 0, $e2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $e2 = sp;
 $0 = $assembly;
 $1 = $0 >>> 3;
 $2 = HEAP32[((388632 + 4|0))>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = (($2) + -1)|0;
   $5 = $4 & $2;
   $6 = ($5|0)==(0);
   if ($6) {
    $7 = $4 & $1;
    $11 = $7;
   } else {
    $8 = (($1>>>0) % ($2>>>0))&-1;
    $11 = $8;
   }
   $9 = HEAP32[388632>>2]|0;
   $10 = (($9) + ($11<<2)|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $__nd$04$i$i = HEAP32[$12>>2]|0;
    $14 = ($__nd$04$i$i|0)==(0|0);
    if (!($14)) {
     L9: do {
      if ($6) {
       $__nd$05$us$i$i = $__nd$04$i$i;
       while(1) {
        $15 = (($__nd$05$us$i$i) + 4|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = $16 & $4;
        $18 = ($17|0)==($11|0);
        if (!($18)) {
         break L1;
        }
        $19 = (($__nd$05$us$i$i) + 8|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)==($assembly|0);
        if ($22) {
         $23 = (($20) + 4|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = ($24|0)==(0|0);
         if ($25) {
          $40 = $__nd$05$us$i$i;
          break L9;
         }
        }
        $__nd$0$us$i$i = HEAP32[$__nd$05$us$i$i>>2]|0;
        $26 = ($__nd$0$us$i$i|0)==(0|0);
        if ($26) {
         break L1;
        } else {
         $__nd$05$us$i$i = $__nd$0$us$i$i;
        }
       }
      } else {
       $__nd$05$i$i = $__nd$04$i$i;
       while(1) {
        $27 = (($__nd$05$i$i) + 4|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($28>>>0) % ($2>>>0))&-1;
        $30 = ($29|0)==($11|0);
        if (!($30)) {
         break L1;
        }
        $31 = (($__nd$05$i$i) + 8|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = HEAP32[$32>>2]|0;
        $34 = ($33|0)==($assembly|0);
        if ($34) {
         $35 = (($32) + 4|0);
         $36 = HEAP32[$35>>2]|0;
         $37 = ($36|0)==(0|0);
         if ($37) {
          $40 = $__nd$05$i$i;
          break L9;
         }
        }
        $__nd$0$i$i = HEAP32[$__nd$05$i$i>>2]|0;
        $38 = ($__nd$0$i$i|0)==(0|0);
        if ($38) {
         break L1;
        } else {
         $__nd$05$i$i = $__nd$0$i$i;
        }
       }
      }
     } while(0);
     $39 = ($40|0)==(0|0);
     if (!($39)) {
      $41 = (($40) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $$0 = $42;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $43 = HEAP32[388656>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $45 = HEAP32[388944>>2]|0;
  $46 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($45,388664,388688)|0);
  HEAP32[388656>>2] = $46;
  $47 = $46;
 } else {
  $47 = $43;
 }
 $48 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($47)|0);
 $49 = (($48) + 8|0);
 HEAP32[$49>>2] = $assembly;
 $50 = HEAP32[((388632 + 4|0))>>2]|0;
 $51 = ($50|0)==(0);
 L29: do {
  if (!($51)) {
   $52 = (($50) + -1)|0;
   $53 = $52 & $50;
   $54 = ($53|0)==(0);
   if ($54) {
    $55 = $52 & $1;
    $59 = $55;
   } else {
    $56 = (($1>>>0) % ($50>>>0))&-1;
    $59 = $56;
   }
   $57 = HEAP32[388632>>2]|0;
   $58 = (($57) + ($59<<2)|0);
   $60 = HEAP32[$58>>2]|0;
   $61 = ($60|0)==(0|0);
   if (!($61)) {
    $__nd$04$i$i3 = HEAP32[$60>>2]|0;
    $62 = ($__nd$04$i$i3|0)==(0|0);
    if (!($62)) {
     L37: do {
      if ($54) {
       $__nd$05$us$i$i6 = $__nd$04$i$i3;
       while(1) {
        $63 = (($__nd$05$us$i$i6) + 4|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = $64 & $52;
        $66 = ($65|0)==($59|0);
        if (!($66)) {
         break L29;
        }
        $67 = (($__nd$05$us$i$i6) + 8|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = HEAP32[$68>>2]|0;
        $70 = ($69|0)==($assembly|0);
        if ($70) {
         $71 = (($68) + 4|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = ($72|0)==(0|0);
         if ($73) {
          $88 = $__nd$05$us$i$i6;
          break L37;
         }
        }
        $__nd$0$us$i$i10 = HEAP32[$__nd$05$us$i$i6>>2]|0;
        $74 = ($__nd$0$us$i$i10|0)==(0|0);
        if ($74) {
         break L29;
        } else {
         $__nd$05$us$i$i6 = $__nd$0$us$i$i10;
        }
       }
      } else {
       $__nd$05$i$i12 = $__nd$04$i$i3;
       while(1) {
        $75 = (($__nd$05$i$i12) + 4|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = (($76>>>0) % ($50>>>0))&-1;
        $78 = ($77|0)==($59|0);
        if (!($78)) {
         break L29;
        }
        $79 = (($__nd$05$i$i12) + 8|0);
        $80 = HEAP32[$79>>2]|0;
        $81 = HEAP32[$80>>2]|0;
        $82 = ($81|0)==($assembly|0);
        if ($82) {
         $83 = (($80) + 4|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = ($84|0)==(0|0);
         if ($85) {
          $88 = $__nd$05$i$i12;
          break L37;
         }
        }
        $__nd$0$i$i16 = HEAP32[$__nd$05$i$i12>>2]|0;
        $86 = ($__nd$0$i$i16|0)==(0|0);
        if ($86) {
         break L29;
        } else {
         $__nd$05$i$i12 = $__nd$0$i$i16;
        }
       }
      }
     } while(0);
     $87 = ($88|0)==(0|0);
     if (!($87)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $89 = (_malloc(8)|0);
 HEAP32[$e2>>2] = $89;
 HEAP32[$89>>2] = $assembly;
 $90 = (($89) + 4|0);
 HEAP32[$90>>2] = 0;
 $91 = (__ZNSt3__113unordered_mapIP14ReflectedEntryPv19Il2CppReflectedHash22Il2CppReflectedCompareN6il2cpp2gc9AllocatorINS_4pairIKS2_S3_EEEEEixERSA_(388632,$e2)|0);
 HEAP32[$91>>2] = $48;
 $$0 = $48;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__113unordered_mapIP14ReflectedEntryPv19Il2CppReflectedHash22Il2CppReflectedCompareN6il2cpp2gc9AllocatorINS_4pairIKS2_S3_EEEEEixERSA_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$i$i = 0, $__nd$0$us$i$i = 0, $__nd$04$i$i = 0, $__nd$05$i$i = 0, $__nd$05$us$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$__k>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3 >>> 3;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 L1: do {
  if (!($7)) {
   $8 = (($6) + -1)|0;
   $9 = $8 & $6;
   $10 = ($9|0)==(0);
   if ($10) {
    $11 = $8 & $4;
    $15 = $11;
   } else {
    $12 = (($4>>>0) % ($6>>>0))&-1;
    $15 = $12;
   }
   $13 = HEAP32[$this>>2]|0;
   $14 = (($13) + ($15<<2)|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $__nd$04$i$i = HEAP32[$16>>2]|0;
    $18 = ($__nd$04$i$i|0)==(0|0);
    if (!($18)) {
     $19 = (($1) + 4|0);
     L9: do {
      if ($10) {
       $__nd$05$us$i$i = $__nd$04$i$i;
       while(1) {
        $20 = (($__nd$05$us$i$i) + 4|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = $21 & $8;
        $23 = ($22|0)==($15|0);
        if (!($23)) {
         break L1;
        }
        $24 = (($__nd$05$us$i$i) + 8|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = HEAP32[$25>>2]|0;
        $27 = ($26|0)==($2|0);
        if ($27) {
         $28 = (($25) + 4|0);
         $29 = HEAP32[$28>>2]|0;
         $30 = HEAP32[$19>>2]|0;
         $31 = ($29|0)==($30|0);
         if ($31) {
          $47 = $__nd$05$us$i$i;
          break L9;
         }
        }
        $__nd$0$us$i$i = HEAP32[$__nd$05$us$i$i>>2]|0;
        $32 = ($__nd$0$us$i$i|0)==(0|0);
        if ($32) {
         break L1;
        } else {
         $__nd$05$us$i$i = $__nd$0$us$i$i;
        }
       }
      } else {
       $__nd$05$i$i = $__nd$04$i$i;
       while(1) {
        $33 = (($__nd$05$i$i) + 4|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = (($34>>>0) % ($6>>>0))&-1;
        $36 = ($35|0)==($15|0);
        if (!($36)) {
         break L1;
        }
        $37 = (($__nd$05$i$i) + 8|0);
        $38 = HEAP32[$37>>2]|0;
        $39 = HEAP32[$38>>2]|0;
        $40 = ($39|0)==($2|0);
        if ($40) {
         $41 = (($38) + 4|0);
         $42 = HEAP32[$41>>2]|0;
         $43 = HEAP32[$19>>2]|0;
         $44 = ($42|0)==($43|0);
         if ($44) {
          $47 = $__nd$05$i$i;
          break L9;
         }
        }
        $__nd$0$i$i = HEAP32[$__nd$05$i$i>>2]|0;
        $45 = ($__nd$0$i$i|0)==(0|0);
        if ($45) {
         break L1;
        } else {
         $__nd$05$i$i = $__nd$0$i$i;
        }
       }
      }
     } while(0);
     $46 = ($47|0)==(0|0);
     if (!($46)) {
      $$sink = $47;
      $$0 = (($$sink) + 12|0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $48 = (__Z21il2cpp_gc_alloc_fixedjPv(16,0)|0);
 $49 = (($48) + 8|0);
 $50 = HEAP32[$__k>>2]|0;
 HEAP32[$49>>2] = $50;
 $51 = (($48) + 12|0);
 HEAP32[$51>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1586,($0|0),($this|0),($48|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if (!($53)) {
  $54 = HEAP32[$0>>2]|0;
  $$sink = $54;
  $$0 = (($$sink) + 12|0);
  STACKTOP = sp;return ($$0|0);
 }
 $55 = ___cxa_find_matching_catch()|0;
 $56 = tempRet0;
 $57 = ($48|0)==(0|0);
 if ($57) {
  ___resumeException($55|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3303,($48|0));
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if ($59) {
  $60 = ___cxa_find_matching_catch()|0;
  $61 = tempRet0;
  ___cxa_call_unexpected(($60|0));
  // unreachable;
 } else {
  ___resumeException($55|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN6il2cpp2vm10Reflection14GetFieldObjectEP8TypeInfoP9FieldInfo($klass,$field) {
 $klass = $klass|0;
 $field = $field|0;
 var $$0 = 0, $$c1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__nd$0$i$i = 0, $__nd$0$i$i18 = 0, $__nd$0$us$i$i = 0, $__nd$0$us$i$i12 = 0, $__nd$04$i$i = 0, $__nd$04$i$i5 = 0, $__nd$05$i$i = 0, $__nd$05$i$i14 = 0, $__nd$05$us$i$i = 0, $__nd$05$us$i$i8 = 0, $e2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $e2 = sp;
 $0 = $field;
 $1 = $0 >>> 3;
 $2 = HEAP32[((388632 + 4|0))>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = (($2) + -1)|0;
   $5 = $4 & $2;
   $6 = ($5|0)==(0);
   if ($6) {
    $7 = $4 & $1;
    $11 = $7;
   } else {
    $8 = (($1>>>0) % ($2>>>0))&-1;
    $11 = $8;
   }
   $9 = HEAP32[388632>>2]|0;
   $10 = (($9) + ($11<<2)|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $__nd$04$i$i = HEAP32[$12>>2]|0;
    $14 = ($__nd$04$i$i|0)==(0|0);
    if (!($14)) {
     L9: do {
      if ($6) {
       $__nd$05$us$i$i = $__nd$04$i$i;
       while(1) {
        $15 = (($__nd$05$us$i$i) + 4|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = $16 & $4;
        $18 = ($17|0)==($11|0);
        if (!($18)) {
         break L1;
        }
        $19 = (($__nd$05$us$i$i) + 8|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)==($field|0);
        if ($22) {
         $23 = (($20) + 4|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = ($24|0)==($klass|0);
         if ($25) {
          $40 = $__nd$05$us$i$i;
          break L9;
         }
        }
        $__nd$0$us$i$i = HEAP32[$__nd$05$us$i$i>>2]|0;
        $26 = ($__nd$0$us$i$i|0)==(0|0);
        if ($26) {
         break L1;
        } else {
         $__nd$05$us$i$i = $__nd$0$us$i$i;
        }
       }
      } else {
       $__nd$05$i$i = $__nd$04$i$i;
       while(1) {
        $27 = (($__nd$05$i$i) + 4|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($28>>>0) % ($2>>>0))&-1;
        $30 = ($29|0)==($11|0);
        if (!($30)) {
         break L1;
        }
        $31 = (($__nd$05$i$i) + 8|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = HEAP32[$32>>2]|0;
        $34 = ($33|0)==($field|0);
        if ($34) {
         $35 = (($32) + 4|0);
         $36 = HEAP32[$35>>2]|0;
         $37 = ($36|0)==($klass|0);
         if ($37) {
          $40 = $__nd$05$i$i;
          break L9;
         }
        }
        $__nd$0$i$i = HEAP32[$__nd$05$i$i>>2]|0;
        $38 = ($__nd$0$i$i|0)==(0|0);
        if ($38) {
         break L1;
        } else {
         $__nd$05$i$i = $__nd$0$i$i;
        }
       }
      }
     } while(0);
     $39 = ($40|0)==(0|0);
     if (!($39)) {
      $41 = (($40) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $$0 = $42;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $43 = HEAP32[388704>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $45 = HEAP32[388944>>2]|0;
  $46 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($45,388664,388712)|0);
  HEAP32[388704>>2] = $46;
  $47 = $46;
 } else {
  $47 = $43;
 }
 $48 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($47)|0);
 $49 = (($48) + 8|0);
 HEAP32[$49>>2] = $klass;
 $50 = (($48) + 12|0);
 HEAP32[$50>>2] = $field;
 $51 = (__ZN6il2cpp2vm5Field7GetNameEP9FieldInfo($field)|0);
 $52 = (__ZN6il2cpp2vm6String3NewEPKc($51)|0);
 $53 = (($48) + 16|0);
 HEAP32[$53>>2] = $52;
 $54 = (($field) + 4|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $57 & 65535;
 $59 = (($48) + 24|0);
 $$c1 = $58;
 HEAP32[$59>>2] = $$c1;
 $60 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($55)|0);
 $61 = (($48) + 20|0);
 HEAP32[$61>>2] = $60;
 $62 = HEAP32[((388632 + 4|0))>>2]|0;
 $63 = ($62|0)==(0);
 L29: do {
  if (!($63)) {
   $64 = (($62) + -1)|0;
   $65 = $64 & $62;
   $66 = ($65|0)==(0);
   if ($66) {
    $67 = $64 & $1;
    $71 = $67;
   } else {
    $68 = (($1>>>0) % ($62>>>0))&-1;
    $71 = $68;
   }
   $69 = HEAP32[388632>>2]|0;
   $70 = (($69) + ($71<<2)|0);
   $72 = HEAP32[$70>>2]|0;
   $73 = ($72|0)==(0|0);
   if (!($73)) {
    $__nd$04$i$i5 = HEAP32[$72>>2]|0;
    $74 = ($__nd$04$i$i5|0)==(0|0);
    if (!($74)) {
     L37: do {
      if ($66) {
       $__nd$05$us$i$i8 = $__nd$04$i$i5;
       while(1) {
        $75 = (($__nd$05$us$i$i8) + 4|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = $76 & $64;
        $78 = ($77|0)==($71|0);
        if (!($78)) {
         break L29;
        }
        $79 = (($__nd$05$us$i$i8) + 8|0);
        $80 = HEAP32[$79>>2]|0;
        $81 = HEAP32[$80>>2]|0;
        $82 = ($81|0)==($field|0);
        if ($82) {
         $83 = (($80) + 4|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = ($84|0)==($klass|0);
         if ($85) {
          $100 = $__nd$05$us$i$i8;
          break L37;
         }
        }
        $__nd$0$us$i$i12 = HEAP32[$__nd$05$us$i$i8>>2]|0;
        $86 = ($__nd$0$us$i$i12|0)==(0|0);
        if ($86) {
         break L29;
        } else {
         $__nd$05$us$i$i8 = $__nd$0$us$i$i12;
        }
       }
      } else {
       $__nd$05$i$i14 = $__nd$04$i$i5;
       while(1) {
        $87 = (($__nd$05$i$i14) + 4|0);
        $88 = HEAP32[$87>>2]|0;
        $89 = (($88>>>0) % ($62>>>0))&-1;
        $90 = ($89|0)==($71|0);
        if (!($90)) {
         break L29;
        }
        $91 = (($__nd$05$i$i14) + 8|0);
        $92 = HEAP32[$91>>2]|0;
        $93 = HEAP32[$92>>2]|0;
        $94 = ($93|0)==($field|0);
        if ($94) {
         $95 = (($92) + 4|0);
         $96 = HEAP32[$95>>2]|0;
         $97 = ($96|0)==($klass|0);
         if ($97) {
          $100 = $__nd$05$i$i14;
          break L37;
         }
        }
        $__nd$0$i$i18 = HEAP32[$__nd$05$i$i14>>2]|0;
        $98 = ($__nd$0$i$i18|0)==(0|0);
        if ($98) {
         break L29;
        } else {
         $__nd$05$i$i14 = $__nd$0$i$i18;
        }
       }
      }
     } while(0);
     $99 = ($100|0)==(0|0);
     if (!($99)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $101 = (_malloc(8)|0);
 HEAP32[$e2>>2] = $101;
 HEAP32[$101>>2] = $field;
 $102 = (($101) + 4|0);
 HEAP32[$102>>2] = $klass;
 $103 = (__ZNSt3__113unordered_mapIP14ReflectedEntryPv19Il2CppReflectedHash22Il2CppReflectedCompareN6il2cpp2gc9AllocatorINS_4pairIKS2_S3_EEEEEixERSA_(388632,$e2)|0);
 HEAP32[$103>>2] = $48;
 $$0 = $48;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($type) {
 $type = $type|0;
 var $$0 = 0, $$pn$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $type;
 $1 = HEAP8[388856>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  ;HEAP32[388832+0>>2]=0|0;HEAP32[388832+4>>2]=0|0;HEAP32[388832+8>>2]=0|0;HEAP32[388832+12>>2]=0|0;
  HEAPF32[((388832 + 16|0))>>2] = Math_fround(1.0);
  HEAP8[388856>>0] = 1;
 }
 $3 = (__ZNK6il2cpp2vm14Il2CppTypeHash9type_hashEPK10Il2CppType(((388832 + 12|0)),$type)|0);
 $4 = HEAP32[((388832 + 4|0))>>2]|0;
 $5 = ($4|0)==(0);
 L4: do {
  if (!($5)) {
   $6 = (($4) + -1)|0;
   $7 = $6 & $4;
   $8 = ($7|0)==(0);
   if ($8) {
    $9 = $6 & $3;
    $13 = $9;
   } else {
    $10 = (($3>>>0) % ($4>>>0))&-1;
    $13 = $10;
   }
   $11 = HEAP32[388832>>2]|0;
   $12 = (($11) + ($13<<2)|0);
   $14 = HEAP32[$12>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    $$pn$i$i = $14;
    while(1) {
     $__nd$0$i$i = HEAP32[$$pn$i$i>>2]|0;
     $16 = ($__nd$0$i$i|0)==(0|0);
     if ($16) {
      break L4;
     }
     $17 = (($__nd$0$i$i) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     if ($8) {
      $19 = $18 & $6;
      $22 = $19;
     } else {
      $20 = (($18>>>0) % ($4>>>0))&-1;
      $22 = $20;
     }
     $21 = ($22|0)==($13|0);
     if (!($21)) {
      break L4;
     }
     $23 = (($__nd$0$i$i) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (__ZNK6il2cpp2vm17Il2CppTypeCompareclEPK10Il2CppTypeS4_(((388832 + 16|0)),$24,$type)|0);
     if ($25) {
      break;
     } else {
      $$pn$i$i = $__nd$0$i$i;
     }
    }
    $26 = (($__nd$0$i$i) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $28 = HEAP32[((388944 + 112|0))>>2]|0;
 $29 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($28)|0);
 $30 = (($29) + 8|0);
 HEAP32[$30>>2] = $type;
 (__ZN6il2cpp2gc8GCHandle3NewEP12Il2CppObjectb($29,1)|0);
 $31 = (__ZNSt3__113unordered_mapIPK10Il2CppTypeP20Il2CppReflectionTypeN6il2cpp2vm14Il2CppTypeHashENS7_17Il2CppTypeCompareENS_9allocatorINS_4pairIKS3_S5_EEEEEixERSC_(388832,$0)|0);
 HEAP32[$31>>2] = $29;
 $$0 = $29;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo($method,$refclass) {
 $method = $method|0;
 $refclass = $refclass|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__nd$0$i$i = 0, $__nd$0$i$i17 = 0, $__nd$0$us$i$i = 0, $__nd$0$us$i$i11 = 0, $__nd$04$i$i = 0, $__nd$04$i$i4 = 0, $__nd$05$i$i = 0, $__nd$05$i$i13 = 0, $__nd$05$us$i$i = 0;
 var $__nd$05$us$i$i7 = 0, $e2 = 0, $klass$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $e2 = sp;
 $0 = ($refclass|0)==(0|0);
 if ($0) {
  $1 = (($method) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $$01 = $2;
 } else {
  $$01 = $refclass;
 }
 $3 = $method;
 $4 = $3 >>> 3;
 $5 = HEAP32[((388632 + 4|0))>>2]|0;
 $6 = ($5|0)==(0);
 L4: do {
  if (!($6)) {
   $7 = (($5) + -1)|0;
   $8 = $7 & $5;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = $7 & $4;
    $14 = $10;
   } else {
    $11 = (($4>>>0) % ($5>>>0))&-1;
    $14 = $11;
   }
   $12 = HEAP32[388632>>2]|0;
   $13 = (($12) + ($14<<2)|0);
   $15 = HEAP32[$13>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $__nd$04$i$i = HEAP32[$15>>2]|0;
    $17 = ($__nd$04$i$i|0)==(0|0);
    if (!($17)) {
     L12: do {
      if ($9) {
       $__nd$05$us$i$i = $__nd$04$i$i;
       while(1) {
        $18 = (($__nd$05$us$i$i) + 4|0);
        $19 = HEAP32[$18>>2]|0;
        $20 = $19 & $7;
        $21 = ($20|0)==($14|0);
        if (!($21)) {
         break L4;
        }
        $22 = (($__nd$05$us$i$i) + 8|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = HEAP32[$23>>2]|0;
        $25 = ($24|0)==($method|0);
        if ($25) {
         $26 = (($23) + 4|0);
         $27 = HEAP32[$26>>2]|0;
         $28 = ($27|0)==($$01|0);
         if ($28) {
          $43 = $__nd$05$us$i$i;
          break L12;
         }
        }
        $__nd$0$us$i$i = HEAP32[$__nd$05$us$i$i>>2]|0;
        $29 = ($__nd$0$us$i$i|0)==(0|0);
        if ($29) {
         break L4;
        } else {
         $__nd$05$us$i$i = $__nd$0$us$i$i;
        }
       }
      } else {
       $__nd$05$i$i = $__nd$04$i$i;
       while(1) {
        $30 = (($__nd$05$i$i) + 4|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = (($31>>>0) % ($5>>>0))&-1;
        $33 = ($32|0)==($14|0);
        if (!($33)) {
         break L4;
        }
        $34 = (($__nd$05$i$i) + 8|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = HEAP32[$35>>2]|0;
        $37 = ($36|0)==($method|0);
        if ($37) {
         $38 = (($35) + 4|0);
         $39 = HEAP32[$38>>2]|0;
         $40 = ($39|0)==($$01|0);
         if ($40) {
          $43 = $__nd$05$i$i;
          break L12;
         }
        }
        $__nd$0$i$i = HEAP32[$__nd$05$i$i>>2]|0;
        $41 = ($__nd$0$i$i|0)==(0|0);
        if ($41) {
         break L4;
        } else {
         $__nd$05$i$i = $__nd$0$i$i;
        }
       }
      }
     } while(0);
     $42 = ($43|0)==(0|0);
     if (!($42)) {
      $44 = (($43) + 12|0);
      $45 = HEAP32[$44>>2]|0;
      $$0 = $45;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $46 = HEAP32[$method>>2]|0;
 $47 = HEAP8[$46>>0]|0;
 $48 = ($47<<24>>24)==(46);
 do {
  if ($48) {
   $49 = (_strcmp($46,388744)|0);
   $50 = ($49|0)==(0);
   if (!($50)) {
    $51 = (_strcmp($46,388752)|0);
    $52 = ($51|0)==(0);
    if (!($52)) {
     label = 25;
     break;
    }
   }
   $53 = HEAP32[388736>>2]|0;
   $54 = ($53|0)==(0|0);
   if ($54) {
    $55 = HEAP32[388944>>2]|0;
    $56 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($55,388664,388760)|0);
    HEAP32[388736>>2] = $56;
    $klass$0 = $56;
   } else {
    $klass$0 = $53;
   }
  } else {
   label = 25;
  }
 } while(0);
 if ((label|0) == 25) {
  $57 = HEAP32[388728>>2]|0;
  $58 = ($57|0)==(0|0);
  if ($58) {
   $59 = HEAP32[388944>>2]|0;
   $60 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($59,388664,388776)|0);
   HEAP32[388728>>2] = $60;
   $klass$0 = $60;
  } else {
   $klass$0 = $57;
  }
 }
 $61 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($klass$0)|0);
 $62 = (($61) + 8|0);
 HEAP32[$62>>2] = $method;
 $63 = (($$01) + 48|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($64)|0);
 $66 = (($61) + 16|0);
 HEAP32[$66>>2] = $65;
 $67 = HEAP32[((388632 + 4|0))>>2]|0;
 $68 = ($67|0)==(0);
 L39: do {
  if (!($68)) {
   $69 = (($67) + -1)|0;
   $70 = $69 & $67;
   $71 = ($70|0)==(0);
   if ($71) {
    $72 = $69 & $4;
    $76 = $72;
   } else {
    $73 = (($4>>>0) % ($67>>>0))&-1;
    $76 = $73;
   }
   $74 = HEAP32[388632>>2]|0;
   $75 = (($74) + ($76<<2)|0);
   $77 = HEAP32[$75>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    $__nd$04$i$i4 = HEAP32[$77>>2]|0;
    $79 = ($__nd$04$i$i4|0)==(0|0);
    if (!($79)) {
     L47: do {
      if ($71) {
       $__nd$05$us$i$i7 = $__nd$04$i$i4;
       while(1) {
        $80 = (($__nd$05$us$i$i7) + 4|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = $81 & $69;
        $83 = ($82|0)==($76|0);
        if (!($83)) {
         break L39;
        }
        $84 = (($__nd$05$us$i$i7) + 8|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = HEAP32[$85>>2]|0;
        $87 = ($86|0)==($method|0);
        if ($87) {
         $88 = (($85) + 4|0);
         $89 = HEAP32[$88>>2]|0;
         $90 = ($89|0)==($$01|0);
         if ($90) {
          $105 = $__nd$05$us$i$i7;
          break L47;
         }
        }
        $__nd$0$us$i$i11 = HEAP32[$__nd$05$us$i$i7>>2]|0;
        $91 = ($__nd$0$us$i$i11|0)==(0|0);
        if ($91) {
         break L39;
        } else {
         $__nd$05$us$i$i7 = $__nd$0$us$i$i11;
        }
       }
      } else {
       $__nd$05$i$i13 = $__nd$04$i$i4;
       while(1) {
        $92 = (($__nd$05$i$i13) + 4|0);
        $93 = HEAP32[$92>>2]|0;
        $94 = (($93>>>0) % ($67>>>0))&-1;
        $95 = ($94|0)==($76|0);
        if (!($95)) {
         break L39;
        }
        $96 = (($__nd$05$i$i13) + 8|0);
        $97 = HEAP32[$96>>2]|0;
        $98 = HEAP32[$97>>2]|0;
        $99 = ($98|0)==($method|0);
        if ($99) {
         $100 = (($97) + 4|0);
         $101 = HEAP32[$100>>2]|0;
         $102 = ($101|0)==($$01|0);
         if ($102) {
          $105 = $__nd$05$i$i13;
          break L47;
         }
        }
        $__nd$0$i$i17 = HEAP32[$__nd$05$i$i13>>2]|0;
        $103 = ($__nd$0$i$i17|0)==(0|0);
        if ($103) {
         break L39;
        } else {
         $__nd$05$i$i13 = $__nd$0$i$i17;
        }
       }
      }
     } while(0);
     $104 = ($105|0)==(0|0);
     if (!($104)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $106 = (_malloc(8)|0);
 HEAP32[$e2>>2] = $106;
 HEAP32[$106>>2] = $method;
 $107 = (($106) + 4|0);
 HEAP32[$107>>2] = $$01;
 $108 = (__ZNSt3__113unordered_mapIP14ReflectedEntryPv19Il2CppReflectedHash22Il2CppReflectedCompareN6il2cpp2gc9AllocatorINS_4pairIKS2_S3_EEEEEixERSA_(388632,$e2)|0);
 HEAP32[$108>>2] = $61;
 $$0 = $61;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm10Reflection15GetModuleObjectEP11Il2CppImage($image) {
 $image = $image|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__nd$0$i$i = 0, $__nd$0$i$i18 = 0, $__nd$0$us$i$i = 0, $__nd$0$us$i$i12 = 0, $__nd$04$i$i = 0, $__nd$04$i$i5 = 0, $__nd$05$i$i = 0, $__nd$05$i$i14 = 0, $__nd$05$us$i$i = 0, $__nd$05$us$i$i8 = 0, $e2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $e2 = sp;
 $0 = $image;
 $1 = $0 >>> 3;
 $2 = HEAP32[((388632 + 4|0))>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = (($2) + -1)|0;
   $5 = $4 & $2;
   $6 = ($5|0)==(0);
   if ($6) {
    $7 = $4 & $1;
    $11 = $7;
   } else {
    $8 = (($1>>>0) % ($2>>>0))&-1;
    $11 = $8;
   }
   $9 = HEAP32[388632>>2]|0;
   $10 = (($9) + ($11<<2)|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $__nd$04$i$i = HEAP32[$12>>2]|0;
    $14 = ($__nd$04$i$i|0)==(0|0);
    if (!($14)) {
     L9: do {
      if ($6) {
       $__nd$05$us$i$i = $__nd$04$i$i;
       while(1) {
        $15 = (($__nd$05$us$i$i) + 4|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = $16 & $4;
        $18 = ($17|0)==($11|0);
        if (!($18)) {
         break L1;
        }
        $19 = (($__nd$05$us$i$i) + 8|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)==($image|0);
        if ($22) {
         $23 = (($20) + 4|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = ($24|0)==(0|0);
         if ($25) {
          $40 = $__nd$05$us$i$i;
          break L9;
         }
        }
        $__nd$0$us$i$i = HEAP32[$__nd$05$us$i$i>>2]|0;
        $26 = ($__nd$0$us$i$i|0)==(0|0);
        if ($26) {
         break L1;
        } else {
         $__nd$05$us$i$i = $__nd$0$us$i$i;
        }
       }
      } else {
       $__nd$05$i$i = $__nd$04$i$i;
       while(1) {
        $27 = (($__nd$05$i$i) + 4|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($28>>>0) % ($2>>>0))&-1;
        $30 = ($29|0)==($11|0);
        if (!($30)) {
         break L1;
        }
        $31 = (($__nd$05$i$i) + 8|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = HEAP32[$32>>2]|0;
        $34 = ($33|0)==($image|0);
        if ($34) {
         $35 = (($32) + 4|0);
         $36 = HEAP32[$35>>2]|0;
         $37 = ($36|0)==(0|0);
         if ($37) {
          $40 = $__nd$05$i$i;
          break L9;
         }
        }
        $__nd$0$i$i = HEAP32[$__nd$05$i$i>>2]|0;
        $38 = ($__nd$0$i$i|0)==(0|0);
        if ($38) {
         break L1;
        } else {
         $__nd$05$i$i = $__nd$0$i$i;
        }
       }
      }
     } while(0);
     $39 = ($40|0)==(0|0);
     if (!($39)) {
      $41 = (($40) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $$0 = $42;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $43 = HEAP32[388792>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $45 = HEAP32[388944>>2]|0;
  $46 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($45,388664,388800)|0);
  HEAP32[388792>>2] = $46;
  $47 = $46;
 } else {
  $47 = $43;
 }
 $48 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($47)|0);
 $49 = (($48) + 8|0);
 HEAP32[$49>>2] = $image;
 $50 = (($image) + 24|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (__ZN6il2cpp2vm10Reflection17GetAssemblyObjectEP14Il2CppAssembly($51)|0);
 $53 = (($48) + 12|0);
 HEAP32[$53>>2] = $52;
 $54 = HEAP32[$image>>2]|0;
 $55 = (__ZN6il2cpp2vm6String3NewEPKc($54)|0);
 $56 = (($48) + 16|0);
 HEAP32[$56>>2] = $55;
 $57 = HEAP32[$image>>2]|0;
 $58 = (__ZN6il2cpp2vm6String3NewEPKc($57)|0);
 $59 = (($48) + 20|0);
 HEAP32[$59>>2] = $58;
 $60 = HEAP32[((388632 + 4|0))>>2]|0;
 $61 = ($60|0)==(0);
 L29: do {
  if (!($61)) {
   $62 = (($60) + -1)|0;
   $63 = $62 & $60;
   $64 = ($63|0)==(0);
   if ($64) {
    $65 = $62 & $1;
    $69 = $65;
   } else {
    $66 = (($1>>>0) % ($60>>>0))&-1;
    $69 = $66;
   }
   $67 = HEAP32[388632>>2]|0;
   $68 = (($67) + ($69<<2)|0);
   $70 = HEAP32[$68>>2]|0;
   $71 = ($70|0)==(0|0);
   if (!($71)) {
    $__nd$04$i$i5 = HEAP32[$70>>2]|0;
    $72 = ($__nd$04$i$i5|0)==(0|0);
    if (!($72)) {
     L37: do {
      if ($64) {
       $__nd$05$us$i$i8 = $__nd$04$i$i5;
       while(1) {
        $73 = (($__nd$05$us$i$i8) + 4|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = $74 & $62;
        $76 = ($75|0)==($69|0);
        if (!($76)) {
         break L29;
        }
        $77 = (($__nd$05$us$i$i8) + 8|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = HEAP32[$78>>2]|0;
        $80 = ($79|0)==($image|0);
        if ($80) {
         $81 = (($78) + 4|0);
         $82 = HEAP32[$81>>2]|0;
         $83 = ($82|0)==(0|0);
         if ($83) {
          $98 = $__nd$05$us$i$i8;
          break L37;
         }
        }
        $__nd$0$us$i$i12 = HEAP32[$__nd$05$us$i$i8>>2]|0;
        $84 = ($__nd$0$us$i$i12|0)==(0|0);
        if ($84) {
         break L29;
        } else {
         $__nd$05$us$i$i8 = $__nd$0$us$i$i12;
        }
       }
      } else {
       $__nd$05$i$i14 = $__nd$04$i$i5;
       while(1) {
        $85 = (($__nd$05$i$i14) + 4|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = (($86>>>0) % ($60>>>0))&-1;
        $88 = ($87|0)==($69|0);
        if (!($88)) {
         break L29;
        }
        $89 = (($__nd$05$i$i14) + 8|0);
        $90 = HEAP32[$89>>2]|0;
        $91 = HEAP32[$90>>2]|0;
        $92 = ($91|0)==($image|0);
        if ($92) {
         $93 = (($90) + 4|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = ($94|0)==(0|0);
         if ($95) {
          $98 = $__nd$05$i$i14;
          break L37;
         }
        }
        $__nd$0$i$i18 = HEAP32[$__nd$05$i$i14>>2]|0;
        $96 = ($__nd$0$i$i18|0)==(0|0);
        if ($96) {
         break L29;
        } else {
         $__nd$05$i$i14 = $__nd$0$i$i18;
        }
       }
      }
     } while(0);
     $97 = ($98|0)==(0|0);
     if (!($97)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $99 = (_malloc(8)|0);
 HEAP32[$e2>>2] = $99;
 HEAP32[$99>>2] = $image;
 $100 = (($99) + 4|0);
 HEAP32[$100>>2] = 0;
 $101 = (__ZNSt3__113unordered_mapIP14ReflectedEntryPv19Il2CppReflectedHash22Il2CppReflectedCompareN6il2cpp2gc9AllocatorINS_4pairIKS2_S3_EEEEEixERSA_(388632,$e2)|0);
 HEAP32[$101>>2] = $48;
 $$0 = $48;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm10Reflection17GetPropertyObjectEP8TypeInfoP12PropertyInfo($klass,$property) {
 $klass = $klass|0;
 $property = $property|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $__nd$0$i$i = 0, $__nd$0$i$i16 = 0, $__nd$0$us$i$i = 0, $__nd$0$us$i$i10 = 0, $__nd$04$i$i = 0, $__nd$04$i$i3 = 0;
 var $__nd$05$i$i = 0, $__nd$05$i$i12 = 0, $__nd$05$us$i$i = 0, $__nd$05$us$i$i6 = 0, $e2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $e2 = sp;
 $0 = $property;
 $1 = $0 >>> 3;
 $2 = HEAP32[((388632 + 4|0))>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = (($2) + -1)|0;
   $5 = $4 & $2;
   $6 = ($5|0)==(0);
   if ($6) {
    $7 = $4 & $1;
    $11 = $7;
   } else {
    $8 = (($1>>>0) % ($2>>>0))&-1;
    $11 = $8;
   }
   $9 = HEAP32[388632>>2]|0;
   $10 = (($9) + ($11<<2)|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $__nd$04$i$i = HEAP32[$12>>2]|0;
    $14 = ($__nd$04$i$i|0)==(0|0);
    if (!($14)) {
     L9: do {
      if ($6) {
       $__nd$05$us$i$i = $__nd$04$i$i;
       while(1) {
        $15 = (($__nd$05$us$i$i) + 4|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = $16 & $4;
        $18 = ($17|0)==($11|0);
        if (!($18)) {
         break L1;
        }
        $19 = (($__nd$05$us$i$i) + 8|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)==($property|0);
        if ($22) {
         $23 = (($20) + 4|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = ($24|0)==($klass|0);
         if ($25) {
          $40 = $__nd$05$us$i$i;
          break L9;
         }
        }
        $__nd$0$us$i$i = HEAP32[$__nd$05$us$i$i>>2]|0;
        $26 = ($__nd$0$us$i$i|0)==(0|0);
        if ($26) {
         break L1;
        } else {
         $__nd$05$us$i$i = $__nd$0$us$i$i;
        }
       }
      } else {
       $__nd$05$i$i = $__nd$04$i$i;
       while(1) {
        $27 = (($__nd$05$i$i) + 4|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($28>>>0) % ($2>>>0))&-1;
        $30 = ($29|0)==($11|0);
        if (!($30)) {
         break L1;
        }
        $31 = (($__nd$05$i$i) + 8|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = HEAP32[$32>>2]|0;
        $34 = ($33|0)==($property|0);
        if ($34) {
         $35 = (($32) + 4|0);
         $36 = HEAP32[$35>>2]|0;
         $37 = ($36|0)==($klass|0);
         if ($37) {
          $40 = $__nd$05$i$i;
          break L9;
         }
        }
        $__nd$0$i$i = HEAP32[$__nd$05$i$i>>2]|0;
        $38 = ($__nd$0$i$i|0)==(0|0);
        if ($38) {
         break L1;
        } else {
         $__nd$05$i$i = $__nd$0$i$i;
        }
       }
      }
     } while(0);
     $39 = ($40|0)==(0|0);
     if (!($39)) {
      $41 = (($40) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $$0 = $42;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $43 = HEAP32[388808>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $45 = HEAP32[388944>>2]|0;
  $46 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($45,388664,388816)|0);
  HEAP32[388808>>2] = $46;
  $47 = $46;
 } else {
  $47 = $43;
 }
 $48 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($47)|0);
 $49 = (($48) + 8|0);
 HEAP32[$49>>2] = $klass;
 $50 = (($48) + 12|0);
 HEAP32[$50>>2] = $property;
 $51 = HEAP32[((388632 + 4|0))>>2]|0;
 $52 = ($51|0)==(0);
 L29: do {
  if (!($52)) {
   $53 = (($51) + -1)|0;
   $54 = $53 & $51;
   $55 = ($54|0)==(0);
   if ($55) {
    $56 = $53 & $1;
    $60 = $56;
   } else {
    $57 = (($1>>>0) % ($51>>>0))&-1;
    $60 = $57;
   }
   $58 = HEAP32[388632>>2]|0;
   $59 = (($58) + ($60<<2)|0);
   $61 = HEAP32[$59>>2]|0;
   $62 = ($61|0)==(0|0);
   if (!($62)) {
    $__nd$04$i$i3 = HEAP32[$61>>2]|0;
    $63 = ($__nd$04$i$i3|0)==(0|0);
    if (!($63)) {
     L37: do {
      if ($55) {
       $__nd$05$us$i$i6 = $__nd$04$i$i3;
       while(1) {
        $64 = (($__nd$05$us$i$i6) + 4|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = $65 & $53;
        $67 = ($66|0)==($60|0);
        if (!($67)) {
         break L29;
        }
        $68 = (($__nd$05$us$i$i6) + 8|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = HEAP32[$69>>2]|0;
        $71 = ($70|0)==($property|0);
        if ($71) {
         $72 = (($69) + 4|0);
         $73 = HEAP32[$72>>2]|0;
         $74 = ($73|0)==($klass|0);
         if ($74) {
          $89 = $__nd$05$us$i$i6;
          break L37;
         }
        }
        $__nd$0$us$i$i10 = HEAP32[$__nd$05$us$i$i6>>2]|0;
        $75 = ($__nd$0$us$i$i10|0)==(0|0);
        if ($75) {
         break L29;
        } else {
         $__nd$05$us$i$i6 = $__nd$0$us$i$i10;
        }
       }
      } else {
       $__nd$05$i$i12 = $__nd$04$i$i3;
       while(1) {
        $76 = (($__nd$05$i$i12) + 4|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = (($77>>>0) % ($51>>>0))&-1;
        $79 = ($78|0)==($60|0);
        if (!($79)) {
         break L29;
        }
        $80 = (($__nd$05$i$i12) + 8|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = HEAP32[$81>>2]|0;
        $83 = ($82|0)==($property|0);
        if ($83) {
         $84 = (($81) + 4|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = ($85|0)==($klass|0);
         if ($86) {
          $89 = $__nd$05$i$i12;
          break L37;
         }
        }
        $__nd$0$i$i16 = HEAP32[$__nd$05$i$i12>>2]|0;
        $87 = ($__nd$0$i$i16|0)==(0|0);
        if ($87) {
         break L29;
        } else {
         $__nd$05$i$i12 = $__nd$0$i$i16;
        }
       }
      }
     } while(0);
     $88 = ($89|0)==(0|0);
     if (!($88)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $90 = (_malloc(8)|0);
 HEAP32[$e2>>2] = $90;
 HEAP32[$90>>2] = $property;
 $91 = (($90) + 4|0);
 HEAP32[$91>>2] = $klass;
 $92 = (__ZNSt3__113unordered_mapIP14ReflectedEntryPv19Il2CppReflectedHash22Il2CppReflectedCompareN6il2cpp2gc9AllocatorINS_4pairIKS2_S3_EEEEEixERSA_(388632,$e2)|0);
 HEAP32[$92>>2] = $48;
 $$0 = $48;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__113unordered_mapIPK10Il2CppTypeP20Il2CppReflectionTypeN6il2cpp2vm14Il2CppTypeHashENS7_17Il2CppTypeCompareENS_9allocatorINS_4pairIKS3_S5_EEEEEixERSC_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0 = 0, $$pn$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__nd$0$i$i = 0, $__nd$0$i$i$sink = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$__k>>2]|0;
 $3 = (__ZNK6il2cpp2vm14Il2CppTypeHash9type_hashEPK10Il2CppType($1,$2)|0);
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 L1: do {
  if (!($6)) {
   $7 = (($5) + -1)|0;
   $8 = $7 & $5;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = $7 & $3;
    $14 = $10;
   } else {
    $11 = (($3>>>0) % ($5>>>0))&-1;
    $14 = $11;
   }
   $12 = HEAP32[$this>>2]|0;
   $13 = (($12) + ($14<<2)|0);
   $15 = HEAP32[$13>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = (($this) + 16|0);
    $$pn$i$i = $15;
    while(1) {
     $__nd$0$i$i = HEAP32[$$pn$i$i>>2]|0;
     $18 = ($__nd$0$i$i|0)==(0|0);
     if ($18) {
      break L1;
     }
     $19 = (($__nd$0$i$i) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     if ($9) {
      $21 = $20 & $7;
      $24 = $21;
     } else {
      $22 = (($20>>>0) % ($5>>>0))&-1;
      $24 = $22;
     }
     $23 = ($24|0)==($14|0);
     if (!($23)) {
      break L1;
     }
     $25 = (($__nd$0$i$i) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$__k>>2]|0;
     $28 = (__ZNK6il2cpp2vm17Il2CppTypeCompareclEPK10Il2CppTypeS4_($17,$26,$27)|0);
     if ($28) {
      $__nd$0$i$i$sink = $__nd$0$i$i;
      break;
     } else {
      $$pn$i$i = $__nd$0$i$i;
     }
    }
    $$0 = (($__nd$0$i$i$sink) + 12|0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $29 = (__Znwj(16)|0);
 $30 = (($29) + 8|0);
 $31 = HEAP32[$__k>>2]|0;
 HEAP32[$30>>2] = $31;
 $32 = (($29) + 12|0);
 HEAP32[$32>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1587,($0|0),($this|0),($29|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if (!($34)) {
  $35 = HEAP32[$0>>2]|0;
  $__nd$0$i$i$sink = $35;
  $$0 = (($__nd$0$i$i$sink) + 12|0);
  STACKTOP = sp;return ($$0|0);
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = ($29|0)==(0|0);
 if ($38) {
  ___resumeException($36|0);
  // unreachable;
 }
 __ZdlPv($29);
 ___resumeException($36|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp2vm10Reflection15GetParamObjectsEP10MethodInfoP8TypeInfo($method,$refclass) {
 $method = $method|0;
 $refclass = $refclass|0;
 var $$0 = 0, $$c3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $__nd$0$i$i = 0, $__nd$0$us$i$i = 0, $__nd$04$i$i = 0, $__nd$05$i$i = 0, $__nd$05$us$i$i = 0, $i$0$c = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[388872>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = HEAP32[388944>>2]|0;
  $3 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($2,388664,388880)|0);
  HEAP32[388864>>2] = $3;
  $4 = (__ZN6il2cpp2vm5Class13GetArrayClassEP8TypeInfoj($3,1)|0);
  HEAP32[388872>>2] = $4;
  $8 = $4;
 } else {
  $8 = $0;
 }
 $5 = (($method) + 33|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $9 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($8,0)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($method) + 4|0);
 $11 = $10;
 $12 = $11 >>> 3;
 $13 = HEAP32[((388632 + 4|0))>>2]|0;
 $14 = ($13|0)==(0);
 L8: do {
  if (!($14)) {
   $15 = (($13) + -1)|0;
   $16 = $15 & $13;
   $17 = ($16|0)==(0);
   if ($17) {
    $18 = $15 & $12;
    $22 = $18;
   } else {
    $19 = (($12>>>0) % ($13>>>0))&-1;
    $22 = $19;
   }
   $20 = HEAP32[388632>>2]|0;
   $21 = (($20) + ($22<<2)|0);
   $23 = HEAP32[$21>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $__nd$04$i$i = HEAP32[$23>>2]|0;
    $25 = ($__nd$04$i$i|0)==(0|0);
    if (!($25)) {
     L16: do {
      if ($17) {
       $__nd$05$us$i$i = $__nd$04$i$i;
       while(1) {
        $26 = (($__nd$05$us$i$i) + 4|0);
        $27 = HEAP32[$26>>2]|0;
        $28 = $27 & $15;
        $29 = ($28|0)==($22|0);
        if (!($29)) {
         break L8;
        }
        $30 = (($__nd$05$us$i$i) + 8|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = HEAP32[$31>>2]|0;
        $33 = ($32|0)==($10|0);
        if ($33) {
         $34 = (($31) + 4|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = ($35|0)==($refclass|0);
         if ($36) {
          $51 = $__nd$05$us$i$i;
          break L16;
         }
        }
        $__nd$0$us$i$i = HEAP32[$__nd$05$us$i$i>>2]|0;
        $37 = ($__nd$0$us$i$i|0)==(0|0);
        if ($37) {
         break L8;
        } else {
         $__nd$05$us$i$i = $__nd$0$us$i$i;
        }
       }
      } else {
       $__nd$05$i$i = $__nd$04$i$i;
       while(1) {
        $38 = (($__nd$05$i$i) + 4|0);
        $39 = HEAP32[$38>>2]|0;
        $40 = (($39>>>0) % ($13>>>0))&-1;
        $41 = ($40|0)==($22|0);
        if (!($41)) {
         break L8;
        }
        $42 = (($__nd$05$i$i) + 8|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = HEAP32[$43>>2]|0;
        $45 = ($44|0)==($10|0);
        if ($45) {
         $46 = (($43) + 4|0);
         $47 = HEAP32[$46>>2]|0;
         $48 = ($47|0)==($refclass|0);
         if ($48) {
          $51 = $__nd$05$i$i;
          break L16;
         }
        }
        $__nd$0$i$i = HEAP32[$__nd$05$i$i>>2]|0;
        $49 = ($__nd$0$i$i|0)==(0|0);
        if ($49) {
         break L8;
        } else {
         $__nd$05$i$i = $__nd$0$i$i;
        }
       }
      }
     } while(0);
     $50 = ($51|0)==(0|0);
     if (!($50)) {
      $52 = (($51) + 12|0);
      $53 = HEAP32[$52>>2]|0;
      $$0 = $53;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $54 = (__ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo($method,$refclass)|0);
 $55 = HEAP32[388872>>2]|0;
 $56 = HEAP8[$5>>0]|0;
 $57 = $56&255;
 $58 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($55,$57)|0);
 $59 = HEAP8[$5>>0]|0;
 $60 = ($59<<24>>24)==(0);
 if ($60) {
  $$0 = $58;
  STACKTOP = sp;return ($$0|0);
 }
 $61 = (($method) + 20|0);
 $i$05 = 0;
 while(1) {
  $62 = HEAP32[388864>>2]|0;
  $63 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($62)|0);
  $64 = HEAP32[$61>>2]|0;
  $65 = ((($64) + (($i$05*12)|0)|0) + 8|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($66)|0);
  $68 = (($63) + 8|0);
  HEAP32[$68>>2] = $67;
  $69 = (($63) + 16|0);
  HEAP32[$69>>2] = $54;
  $70 = HEAP32[$61>>2]|0;
  $71 = (($70) + (($i$05*12)|0)|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (__ZN6il2cpp2vm6String3NewEPKc($72)|0);
  $74 = (($63) + 20|0);
  HEAP32[$74>>2] = $73;
  $75 = (($63) + 24|0);
  $i$0$c = $i$05;
  HEAP32[$75>>2] = $i$0$c;
  $76 = HEAP32[$61>>2]|0;
  $77 = ((($76) + (($i$05*12)|0)|0) + 8|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($78) + 4|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = $80 & 65535;
  $82 = (($63) + 28|0);
  $$c3 = $81;
  HEAP32[$82>>2] = $$c3;
  $83 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($58,4,$i$05)|0);
  HEAP32[$83>>2] = $63;
  $84 = (($i$05) + 1)|0;
  $85 = HEAP8[$5>>0]|0;
  $86 = $85&255;
  $87 = ($84|0)<($86|0);
  if ($87) {
   $i$05 = $84;
  } else {
   $$0 = $58;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP12Il2CppObject($obj) {
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $obj$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $obj$idx$val = HEAP32[$obj>>2]|0;
 $0 = HEAP32[$obj$idx$val>>2]|0;
 $1 = (_strcmp($0,388776)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($obj$idx$val) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (_strcmp($4,388664)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = (($obj) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $$0 = $10;
    STACKTOP = sp;return ($$0|0);
   }
   $14 = HEAP32[$10>>2]|0;
   $15 = ($14|0)==(0);
   if ($15) {
    $$0 = $10;
    STACKTOP = sp;return ($$0|0);
   }
   $16 = (($10) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vi[$17 & 4095]($10);
   $$0 = $10;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $18 = (_strcmp($0,388816)|0);
 $19 = ($18|0)==(0);
 if ($19) {
  $20 = (($obj$idx$val) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (_strcmp($21,388664)|0);
  $23 = ($22|0)==(0);
  if ($23) {
   $24 = (($obj) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 20|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
   $31 = HEAP32[$27>>2]|0;
   $32 = ($31|0)==(0);
   if ($32) {
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
   $33 = (($27) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   FUNCTION_TABLE_vi[$34 & 4095]($27);
   $$0 = $27;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $35 = (_strcmp($0,388712)|0);
 $36 = ($35|0)==(0);
 if ($36) {
  $37 = (($obj$idx$val) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (_strcmp($38,388664)|0);
  $40 = ($39|0)==(0);
  if ($40) {
   $41 = (($obj) + 12|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 16|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    $$0 = $44;
    STACKTOP = sp;return ($$0|0);
   }
   $48 = HEAP32[$44>>2]|0;
   $49 = ($48|0)==(0);
   if ($49) {
    $$0 = $44;
    STACKTOP = sp;return ($$0|0);
   }
   $50 = (($44) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   FUNCTION_TABLE_vi[$51 & 4095]($44);
   $$0 = $44;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $52 = (_strcmp($0,388896)|0);
 $53 = ($52|0)==(0);
 if ($53) {
  $54 = (($obj$idx$val) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (_strcmp($55,388912)|0);
  $57 = ($56|0)==(0);
  if ($57) {
   $58 = (__ZN6il2cpp2vm5Class14FromSystemTypeEP20Il2CppReflectionType($obj)|0);
   $60 = $58;
  } else {
   $60 = $obj$idx$val;
  }
 } else {
  $60 = $obj$idx$val;
 }
 $59 = (($60) + 40|0);
 $61 = HEAP32[$59>>2]|0;
 $62 = (($61) + 4|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0|0);
 if (!($64)) {
  $$0 = $61;
  STACKTOP = sp;return ($$0|0);
 }
 $65 = HEAP32[$61>>2]|0;
 $66 = ($65|0)==(0);
 if ($66) {
  $$0 = $61;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = (($61) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vi[$68 & 4095]($61);
 $$0 = $61;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm10Reflection18CustomAttrsHasAttrEP21CustomAttributesCacheP8TypeInfo($ainfo,$attr_klass) {
 $ainfo = $ainfo|0;
 $attr_klass = $attr_klass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ainfo>>2]|0;
 $1 = ($0|0)>(0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($ainfo) + 4|0);
 $3 = (($attr_klass) + 114|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$2>>2]|0;
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (__ZN6il2cpp2vm5Class9HasParentEPK8TypeInfoS4_($7,$attr_klass)|0);
  if ($8) {
   $$0 = 1;
   label = 7;
   break;
  }
  $9 = HEAP8[$3>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if (!($10)) {
   $11 = (__ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_($attr_klass,$7)|0);
   if ($11) {
    $$0 = 1;
    label = 7;
    break;
   }
  }
  $12 = (($i$01) + 1)|0;
  $13 = HEAP32[$ainfo>>2]|0;
  $14 = ($12|0)<($13|0);
  if ($14) {
   $i$01 = $12;
  } else {
   $$0 = 0;
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP9FieldInfo($field) {
 $field = $field|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($field) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = (($1) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vi[$8 & 4095]($1);
  }
 }
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP10MethodInfo($method) {
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($method) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = (($1) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vi[$8 & 4095]($1);
  }
 }
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm10Reflection18GetCustomAttrsInfoEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = (($1) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vi[$8 & 4095]($1);
  }
 }
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIPK10Il2CppTypeP20Il2CppReflectionTypeEENS_22__unordered_map_hasherIS4_S7_N6il2cpp2vm14Il2CppTypeHashELb1EEENS_21__unordered_map_equalIS4_S7_NSA_17Il2CppTypeCompareELb1EEENS_9allocatorIS7_EEE20__node_insert_uniqueEPNS_11__hash_nodeIS7_PvEE($agg$result,$this,$__nd) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__nd = $__nd|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__bc$0 = 0, $__chash$0 = 0, $__chash$1 = 0, $__ndptr$0 = 0, $__ndptr$1 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($__nd) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK6il2cpp2vm14Il2CppTypeHash9type_hashEPK10Il2CppType($0,$2)|0);
 $4 = (($__nd) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 L1: do {
  if ($7) {
   $__chash$0 = 0;
  } else {
   $8 = (($6) + -1)|0;
   $9 = $8 & $6;
   $10 = ($9|0)==(0);
   if ($10) {
    $11 = $8 & $3;
    $15 = $11;
   } else {
    $12 = (($3>>>0) % ($6>>>0))&-1;
    $15 = $12;
   }
   $13 = HEAP32[$this>>2]|0;
   $14 = (($13) + ($15<<2)|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $__chash$0 = $15;
   } else {
    $18 = (($this) + 16|0);
    $$pn = $16;
    while(1) {
     $__ndptr$0 = HEAP32[$$pn>>2]|0;
     $19 = ($__ndptr$0|0)==(0|0);
     if ($19) {
      $__chash$0 = $15;
      break L1;
     }
     $20 = (($__ndptr$0) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     if ($10) {
      $22 = $21 & $8;
      $25 = $22;
     } else {
      $23 = (($21>>>0) % ($6>>>0))&-1;
      $25 = $23;
     }
     $24 = ($25|0)==($15|0);
     if (!($24)) {
      $__chash$0 = $15;
      break L1;
     }
     $26 = (($__ndptr$0) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = HEAP32[$1>>2]|0;
     $29 = (__ZNK6il2cpp2vm17Il2CppTypeCompareclEPK10Il2CppTypeS4_($18,$27,$28)|0);
     if ($29) {
      $84 = 0;$__ndptr$1 = $__ndptr$0;
      break;
     } else {
      $$pn = $__ndptr$0;
     }
    }
    HEAP32[$agg$result>>2] = $__ndptr$1;
    $83 = (($agg$result) + 4|0);
    HEAP8[$83>>0] = $84;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $30 = (($this) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 1)|0;
 $33 = (Math_fround(($32>>>0)));
 $34 = (Math_fround(($6>>>0)));
 $35 = (($this) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 * $36);
 $38 = $33 > $37;
 $or$cond = $38 | $7;
 do {
  if ($or$cond) {
   $39 = $6 << 1;
   $40 = ($6>>>0)>(2);
   if ($40) {
    $41 = (($6) + -1)|0;
    $42 = $41 & $6;
    $43 = ($42|0)==(0);
    $45 = $43;
   } else {
    $45 = 0;
   }
   $44 = $45&1;
   $46 = $44 | $39;
   $47 = $46 ^ 1;
   $48 = Math_fround($33 / $36);
   $49 = (Math_fround(Math_ceil((Math_fround($48)))));
   $50 = (~~(($49))>>>0);
   $51 = ($47>>>0)<($50>>>0);
   $52 = $51 ? $50 : $47;
   __ZNSt3__112__hash_tableINS_17__hash_value_typeIPK10Il2CppTypeP20Il2CppReflectionTypeEENS_22__unordered_map_hasherIS4_S7_N6il2cpp2vm14Il2CppTypeHashELb1EEENS_21__unordered_map_equalIS4_S7_NSA_17Il2CppTypeCompareELb1EEENS_9allocatorIS7_EEE6rehashEj($this,$52);
   $53 = HEAP32[$5>>2]|0;
   $54 = HEAP32[$4>>2]|0;
   $55 = (($53) + -1)|0;
   $56 = $55 & $53;
   $57 = ($56|0)==(0);
   if ($57) {
    $58 = $55 & $54;
    $__bc$0 = $53;$__chash$1 = $58;
    break;
   } else {
    $59 = (($54>>>0) % ($53>>>0))&-1;
    $__bc$0 = $53;$__chash$1 = $59;
    break;
   }
  } else {
   $__bc$0 = $6;$__chash$1 = $__chash$0;
  }
 } while(0);
 $60 = HEAP32[$this>>2]|0;
 $61 = (($60) + ($__chash$1<<2)|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0|0);
 if ($63) {
  $64 = (($this) + 8|0);
  $65 = HEAP32[$64>>2]|0;
  HEAP32[$__nd>>2] = $65;
  HEAP32[$64>>2] = $__nd;
  $66 = HEAP32[$this>>2]|0;
  $67 = (($66) + ($__chash$1<<2)|0);
  HEAP32[$67>>2] = $64;
  $68 = HEAP32[$__nd>>2]|0;
  $69 = ($68|0)==(0|0);
  if (!($69)) {
   $70 = (($68) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($__bc$0) + -1)|0;
   $73 = $72 & $__bc$0;
   $74 = ($73|0)==(0);
   if ($74) {
    $75 = $71 & $72;
    $79 = $75;
   } else {
    $76 = (($71>>>0) % ($__bc$0>>>0))&-1;
    $79 = $76;
   }
   $77 = HEAP32[$this>>2]|0;
   $78 = (($77) + ($79<<2)|0);
   HEAP32[$78>>2] = $__nd;
  }
 } else {
  $80 = HEAP32[$62>>2]|0;
  HEAP32[$__nd>>2] = $80;
  HEAP32[$62>>2] = $__nd;
 }
 $81 = HEAP32[$30>>2]|0;
 $82 = (($81) + 1)|0;
 HEAP32[$30>>2] = $82;
 $84 = 1;$__ndptr$1 = $__nd;
 HEAP32[$agg$result>>2] = $__ndptr$1;
 $83 = (($agg$result) + 4|0);
 HEAP8[$83>>0] = $84;
 STACKTOP = sp;return;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIPK10Il2CppTypeP20Il2CppReflectionTypeEENS_22__unordered_map_hasherIS4_S7_N6il2cpp2vm14Il2CppTypeHashELb1EEENS_21__unordered_map_equalIS4_S7_NSA_17Il2CppTypeCompareELb1EEENS_9allocatorIS7_EEE6rehashEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)==(1);
 if ($0) {
  $8 = 2;
 } else {
  $1 = (($__n) + -1)|0;
  $2 = $1 & $__n;
  $3 = ($2|0)==(0);
  if ($3) {
   $8 = $__n;
  } else {
   $4 = (__ZNSt3__112__next_primeEj($__n)|0);
   $8 = $4;
  }
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($8>>>0)>($6>>>0);
 if ($7) {
  __ZNSt3__112__hash_tableINS_17__hash_value_typeIPK10Il2CppTypeP20Il2CppReflectionTypeEENS_22__unordered_map_hasherIS4_S7_N6il2cpp2vm14Il2CppTypeHashELb1EEENS_21__unordered_map_equalIS4_S7_NSA_17Il2CppTypeCompareELb1EEENS_9allocatorIS7_EEE8__rehashEj($this,$8);
  STACKTOP = sp;return;
 }
 $9 = ($8>>>0)<($6>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = ($6>>>0)>(2);
 if ($10) {
  $11 = (($6) + -1)|0;
  $12 = $11 & $6;
  $13 = ($12|0)==(0);
  $31 = $13;
 } else {
  $31 = 0;
 }
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (Math_fround(($15>>>0)));
 $17 = (($this) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 / $18);
 $20 = (Math_fround(Math_ceil((Math_fround($19)))));
 $21 = (~~(($20))>>>0);
 if ($31) {
  $22 = (($21) + -1)|0;
  $23 = (_llvm_ctlz_i32(($22|0))|0);
  $24 = (32 - ($23))|0;
  $25 = 1 << $24;
  $28 = $25;
 } else {
  $26 = (__ZNSt3__112__next_primeEj($21)|0);
  $28 = $26;
 }
 $27 = ($8>>>0)<($28>>>0);
 $29 = $27 ? $28 : $8;
 $30 = ($29>>>0)<($6>>>0);
 if (!($30)) {
  STACKTOP = sp;return;
 }
 __ZNSt3__112__hash_tableINS_17__hash_value_typeIPK10Il2CppTypeP20Il2CppReflectionTypeEENS_22__unordered_map_hasherIS4_S7_N6il2cpp2vm14Il2CppTypeHashELb1EEENS_21__unordered_map_equalIS4_S7_NSA_17Il2CppTypeCompareELb1EEENS_9allocatorIS7_EEE8__rehashEj($this,$29);
 STACKTOP = sp;return;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIPK10Il2CppTypeP20Il2CppReflectionTypeEENS_22__unordered_map_hasherIS4_S7_N6il2cpp2vm14Il2CppTypeHashELb1EEENS_21__unordered_map_equalIS4_S7_NSA_17Il2CppTypeCompareELb1EEENS_9allocatorIS7_EEE8__rehashEj($this,$__nbc) {
 $this = $this|0;
 $__nbc = $__nbc|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__cp$0 = 0;
 var $__cp$0$in1524 = 0, $__cp$0$in18 = 0, $__cp$07 = 0, $__cp$0716 = 0, $__cp$071621 = 0, $__cp$071625 = 0, $__cp$0719 = 0, $__cp$08 = 0, $__i$011 = 0, $__phash$0$ph$ph23 = 0, $__pp$0$ph$ph22 = 0, $__pp$0$ph17 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nbc|0)!=(0);
 if ($0) {
  $1 = $__nbc << 2;
  $2 = (__Znwj($1)|0);
  $4 = $2;
 } else {
  $4 = 0;
 }
 $3 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $4;
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  __ZdlPv($3);
 }
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = $__nbc;
 if ($0) {
  $__i$011 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $7 = HEAP32[$this>>2]|0;
  $8 = (($7) + ($__i$011<<2)|0);
  HEAP32[$8>>2] = 0;
  $9 = (($__i$011) + 1)|0;
  $exitcond = ($9|0)==($__nbc|0);
  if ($exitcond) {
   break;
  } else {
   $__i$011 = $9;
  }
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($11) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($__nbc) + -1)|0;
 $16 = $15 & $__nbc;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = $14 & $15;
  $22 = $18;
 } else {
  $19 = (($14>>>0) % ($__nbc>>>0))&-1;
  $22 = $19;
 }
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + ($22<<2)|0);
 HEAP32[$21>>2] = $10;
 $__cp$071621 = HEAP32[$11>>2]|0;
 $23 = ($__cp$071621|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 16|0);
 $__cp$0$in1524 = $11;$__cp$071625 = $__cp$071621;$__phash$0$ph$ph23 = $22;$__pp$0$ph$ph22 = $11;
 L22: while(1) {
  $__cp$0$in18 = $__cp$0$in1524;$__cp$0719 = $__cp$071625;$__pp$0$ph17 = $__pp$0$ph$ph22;
  L24: while(1) {
   $__cp$08 = $__cp$0719;
   while(1) {
    $26 = (($__cp$08) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    if ($17) {
     $28 = $27 & $15;
     $31 = $28;
    } else {
     $29 = (($27>>>0) % ($__nbc>>>0))&-1;
     $31 = $29;
    }
    $30 = ($31|0)==($__phash$0$ph$ph23|0);
    if ($30) {
     break;
    }
    $32 = HEAP32[$this>>2]|0;
    $33 = (($32) + ($31<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     break L24;
    }
    $36 = HEAP32[$__cp$08>>2]|0;
    $37 = ($36|0)==(0|0);
    L34: do {
     if ($37) {
      $$lcssa = $__cp$08;$49 = 0;
     } else {
      $38 = (($__cp$08) + 8|0);
      $42 = $36;$46 = $__cp$08;
      while(1) {
       $40 = HEAP32[$38>>2]|0;
       $41 = (($42) + 8|0);
       $43 = HEAP32[$41>>2]|0;
       $44 = (__ZNK6il2cpp2vm17Il2CppTypeCompareclEPK10Il2CppTypeS4_($24,$40,$43)|0);
       $45 = HEAP32[$46>>2]|0;
       if (!($44)) {
        $$lcssa = $46;$49 = $45;
        break L34;
       }
       $47 = HEAP32[$45>>2]|0;
       $48 = ($47|0)==(0|0);
       if ($48) {
        $$lcssa = $45;$49 = 0;
        break;
       } else {
        $42 = $47;$46 = $45;
       }
      }
     }
    } while(0);
    HEAP32[$__cp$0$in18>>2] = $49;
    $50 = HEAP32[$this>>2]|0;
    $51 = (($50) + ($31<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = HEAP32[$52>>2]|0;
    HEAP32[$$lcssa>>2] = $53;
    $54 = HEAP32[$this>>2]|0;
    $55 = (($54) + ($31<<2)|0);
    $56 = HEAP32[$55>>2]|0;
    HEAP32[$56>>2] = $__cp$08;
    $__cp$0 = HEAP32[$__cp$0$in18>>2]|0;
    $57 = ($__cp$0|0)==(0|0);
    if ($57) {
     label = 27;
     break L22;
    } else {
     $__cp$08 = $__cp$0;
    }
   }
   $__cp$07 = HEAP32[$__cp$08>>2]|0;
   $25 = ($__cp$07|0)==(0|0);
   if ($25) {
    label = 27;
    break L22;
   } else {
    $__cp$0$in18 = $__cp$08;$__cp$0719 = $__cp$07;$__pp$0$ph17 = $__cp$08;
   }
  }
  HEAP32[$33>>2] = $__pp$0$ph17;
  $__cp$0716 = HEAP32[$__cp$08>>2]|0;
  $39 = ($__cp$0716|0)==(0|0);
  if ($39) {
   label = 27;
   break;
  } else {
   $__cp$0$in1524 = $__cp$08;$__cp$071625 = $__cp$0716;$__phash$0$ph$ph23 = $31;$__pp$0$ph$ph22 = $__cp$08;
  }
 }
 if ((label|0) == 27) {
  STACKTOP = sp;return;
 }
}
function __ZNK6il2cpp2vm14Il2CppTypeHash9type_hashEPK10Il2CppType($this,$t1) {
 $this = $this|0;
 $t1 = $t1|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $hash$0 = 0, $hash$01 = 0, $hash$03 = 0, $i$02 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($t1) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 16;
 $3 = $2 & 255;
 $4 = $1 >>> 24;
 $5 = $4 & 64;
 $6 = $3 | $5;
 switch ($3|0) {
 case 21:  {
  $16 = HEAP32[$t1>>2]|0;
  $17 = (($16) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$16>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = (__ZN6il2cpp5utils11StringUtils4HashEPKc($20)|0);
  $22 = (($21) + ($6))|0;
  $hash$01 = ($22*13)|0;
  $23 = HEAP32[$18>>2]|0;
  $24 = ($23|0)==(0);
  if ($24) {
   $$0 = $hash$01;
   STACKTOP = sp;return ($$0|0);
  }
  $25 = (($18) + 4|0);
  $hash$03 = $hash$01;$i$02 = 0;
  while(1) {
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + ($i$02<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (__ZNK6il2cpp2vm14Il2CppTypeHash9type_hashEPK10Il2CppType($this,$28)|0);
   $30 = (($29) + ($hash$03))|0;
   $31 = (($i$02) + 1)|0;
   $hash$0 = ($30*13)|0;
   $32 = HEAP32[$18>>2]|0;
   $33 = ($31>>>0)<($32>>>0);
   if ($33) {
    $hash$03 = $hash$0;$i$02 = $31;
   } else {
    $$0 = $hash$0;
    break;
   }
  }
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 29: case 18: case 17:  {
  $7 = ($6*31)|0;
  $8 = HEAP32[$t1>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZN6il2cpp5utils11StringUtils4HashEPKc($9)|0);
  $11 = $10 ^ $7;
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 15:  {
  $12 = ($6*31)|0;
  $13 = HEAP32[$t1>>2]|0;
  $14 = (__ZNK6il2cpp2vm14Il2CppTypeHash9type_hashEPK10Il2CppType($this,$13)|0);
  $15 = $14 ^ $12;
  STACKTOP = sp;return ($15|0);
  break;
 }
 default: {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIP14ReflectedEntryPvEENS_22__unordered_map_hasherIS3_S5_19Il2CppReflectedHashLb1EEENS_21__unordered_map_equalIS3_S5_22Il2CppReflectedCompareLb1EEEN6il2cpp2gc9AllocatorIS5_EEE20__node_insert_uniqueEPNS_11__hash_nodeIS5_S4_EE($agg$result,$this,$__nd) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__bc$0 = 0, $__chash$0 = 0, $__chash$1 = 0, $__ndptr$0 = 0, $__ndptr$0$us = 0, $__ndptr$06 = 0, $__ndptr$07 = 0, $__ndptr$07$us = 0, $__ndptr$1 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__nd) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3 >>> 3;
 $5 = (($__nd) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 L1: do {
  if ($8) {
   $__chash$0 = 0;
  } else {
   $9 = (($7) + -1)|0;
   $10 = $9 & $7;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = $9 & $4;
    $16 = $12;
   } else {
    $13 = (($4>>>0) % ($7>>>0))&-1;
    $16 = $13;
   }
   $14 = HEAP32[$this>>2]|0;
   $15 = (($14) + ($16<<2)|0);
   $17 = HEAP32[$15>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $__chash$0 = $16;
   } else {
    $__ndptr$06 = HEAP32[$17>>2]|0;
    $19 = ($__ndptr$06|0)==(0|0);
    if ($19) {
     $__chash$0 = $16;
    } else {
     if ($11) {
      $__ndptr$07$us = $__ndptr$06;
      while(1) {
       $20 = (($__ndptr$07$us) + 4|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = $21 & $9;
       $23 = ($22|0)==($16|0);
       if (!($23)) {
        $__chash$0 = $16;
        break L1;
       }
       $24 = (($__ndptr$07$us) + 8|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = HEAP32[$25>>2]|0;
       $27 = ($26|0)==($2|0);
       if ($27) {
        $28 = (($25) + 4|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = (($1) + 4|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = ($29|0)==($31|0);
        if ($32) {
         $102 = 0;$__ndptr$1 = $__ndptr$07$us;
         break;
        }
       }
       $__ndptr$0$us = HEAP32[$__ndptr$07$us>>2]|0;
       $33 = ($__ndptr$0$us|0)==(0|0);
       if ($33) {
        $__chash$0 = $16;
        break L1;
       } else {
        $__ndptr$07$us = $__ndptr$0$us;
       }
      }
      HEAP32[$agg$result>>2] = $__ndptr$1;
      $101 = (($agg$result) + 4|0);
      HEAP8[$101>>0] = $102;
      STACKTOP = sp;return;
     } else {
      $__ndptr$07 = $__ndptr$06;
      while(1) {
       $34 = (($__ndptr$07) + 4|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = (($35>>>0) % ($7>>>0))&-1;
       $37 = ($36|0)==($16|0);
       if (!($37)) {
        $__chash$0 = $16;
        break L1;
       }
       $38 = (($__ndptr$07) + 8|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = HEAP32[$39>>2]|0;
       $41 = ($40|0)==($2|0);
       if ($41) {
        $42 = (($39) + 4|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = (($1) + 4|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ($43|0)==($45|0);
        if ($46) {
         $102 = 0;$__ndptr$1 = $__ndptr$07;
         break;
        }
       }
       $__ndptr$0 = HEAP32[$__ndptr$07>>2]|0;
       $47 = ($__ndptr$0|0)==(0|0);
       if ($47) {
        $__chash$0 = $16;
        break L1;
       } else {
        $__ndptr$07 = $__ndptr$0;
       }
      }
      HEAP32[$agg$result>>2] = $__ndptr$1;
      $101 = (($agg$result) + 4|0);
      HEAP8[$101>>0] = $102;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $48 = (($this) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 1)|0;
 $51 = (Math_fround(($50>>>0)));
 $52 = (Math_fround(($7>>>0)));
 $53 = (($this) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($52 * $54);
 $56 = $51 > $55;
 $or$cond = $56 | $8;
 do {
  if ($or$cond) {
   $57 = $7 << 1;
   $58 = ($7>>>0)>(2);
   if ($58) {
    $59 = (($7) + -1)|0;
    $60 = $59 & $7;
    $61 = ($60|0)==(0);
    $63 = $61;
   } else {
    $63 = 0;
   }
   $62 = $63&1;
   $64 = $62 | $57;
   $65 = $64 ^ 1;
   $66 = Math_fround($51 / $54);
   $67 = (Math_fround(Math_ceil((Math_fround($66)))));
   $68 = (~~(($67))>>>0);
   $69 = ($65>>>0)<($68>>>0);
   $70 = $69 ? $68 : $65;
   __ZNSt3__112__hash_tableINS_17__hash_value_typeIP14ReflectedEntryPvEENS_22__unordered_map_hasherIS3_S5_19Il2CppReflectedHashLb1EEENS_21__unordered_map_equalIS3_S5_22Il2CppReflectedCompareLb1EEEN6il2cpp2gc9AllocatorIS5_EEE6rehashEj($this,$70);
   $71 = HEAP32[$6>>2]|0;
   $72 = HEAP32[$5>>2]|0;
   $73 = (($71) + -1)|0;
   $74 = $73 & $71;
   $75 = ($74|0)==(0);
   if ($75) {
    $76 = $73 & $72;
    $__bc$0 = $71;$__chash$1 = $76;
    break;
   } else {
    $77 = (($72>>>0) % ($71>>>0))&-1;
    $__bc$0 = $71;$__chash$1 = $77;
    break;
   }
  } else {
   $__bc$0 = $7;$__chash$1 = $__chash$0;
  }
 } while(0);
 $78 = HEAP32[$this>>2]|0;
 $79 = (($78) + ($__chash$1<<2)|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0|0);
 if ($81) {
  $82 = (($this) + 8|0);
  $83 = HEAP32[$82>>2]|0;
  HEAP32[$__nd>>2] = $83;
  HEAP32[$82>>2] = $__nd;
  $84 = HEAP32[$this>>2]|0;
  $85 = (($84) + ($__chash$1<<2)|0);
  HEAP32[$85>>2] = $82;
  $86 = HEAP32[$__nd>>2]|0;
  $87 = ($86|0)==(0|0);
  if (!($87)) {
   $88 = (($86) + 4|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($__bc$0) + -1)|0;
   $91 = $90 & $__bc$0;
   $92 = ($91|0)==(0);
   if ($92) {
    $93 = $89 & $90;
    $97 = $93;
   } else {
    $94 = (($89>>>0) % ($__bc$0>>>0))&-1;
    $97 = $94;
   }
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95) + ($97<<2)|0);
   HEAP32[$96>>2] = $__nd;
  }
 } else {
  $98 = HEAP32[$80>>2]|0;
  HEAP32[$__nd>>2] = $98;
  HEAP32[$80>>2] = $__nd;
 }
 $99 = HEAP32[$48>>2]|0;
 $100 = (($99) + 1)|0;
 HEAP32[$48>>2] = $100;
 $102 = 1;$__ndptr$1 = $__nd;
 HEAP32[$agg$result>>2] = $__ndptr$1;
 $101 = (($agg$result) + 4|0);
 HEAP8[$101>>0] = $102;
 STACKTOP = sp;return;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIP14ReflectedEntryPvEENS_22__unordered_map_hasherIS3_S5_19Il2CppReflectedHashLb1EEENS_21__unordered_map_equalIS3_S5_22Il2CppReflectedCompareLb1EEEN6il2cpp2gc9AllocatorIS5_EEE6rehashEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)==(1);
 if ($0) {
  $8 = 2;
 } else {
  $1 = (($__n) + -1)|0;
  $2 = $1 & $__n;
  $3 = ($2|0)==(0);
  if ($3) {
   $8 = $__n;
  } else {
   $4 = (__ZNSt3__112__next_primeEj($__n)|0);
   $8 = $4;
  }
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($8>>>0)>($6>>>0);
 if ($7) {
  __ZNSt3__112__hash_tableINS_17__hash_value_typeIP14ReflectedEntryPvEENS_22__unordered_map_hasherIS3_S5_19Il2CppReflectedHashLb1EEENS_21__unordered_map_equalIS3_S5_22Il2CppReflectedCompareLb1EEEN6il2cpp2gc9AllocatorIS5_EEE8__rehashEj($this,$8);
  STACKTOP = sp;return;
 }
 $9 = ($8>>>0)<($6>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = ($6>>>0)>(2);
 if ($10) {
  $11 = (($6) + -1)|0;
  $12 = $11 & $6;
  $13 = ($12|0)==(0);
  $31 = $13;
 } else {
  $31 = 0;
 }
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (Math_fround(($15>>>0)));
 $17 = (($this) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 / $18);
 $20 = (Math_fround(Math_ceil((Math_fround($19)))));
 $21 = (~~(($20))>>>0);
 if ($31) {
  $22 = (($21) + -1)|0;
  $23 = (_llvm_ctlz_i32(($22|0))|0);
  $24 = (32 - ($23))|0;
  $25 = 1 << $24;
  $28 = $25;
 } else {
  $26 = (__ZNSt3__112__next_primeEj($21)|0);
  $28 = $26;
 }
 $27 = ($8>>>0)<($28>>>0);
 $29 = $27 ? $28 : $8;
 $30 = ($29>>>0)<($6>>>0);
 if (!($30)) {
  STACKTOP = sp;return;
 }
 __ZNSt3__112__hash_tableINS_17__hash_value_typeIP14ReflectedEntryPvEENS_22__unordered_map_hasherIS3_S5_19Il2CppReflectedHashLb1EEENS_21__unordered_map_equalIS3_S5_22Il2CppReflectedCompareLb1EEEN6il2cpp2gc9AllocatorIS5_EEE8__rehashEj($this,$29);
 STACKTOP = sp;return;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIP14ReflectedEntryPvEENS_22__unordered_map_hasherIS3_S5_19Il2CppReflectedHashLb1EEENS_21__unordered_map_equalIS3_S5_22Il2CppReflectedCompareLb1EEEN6il2cpp2gc9AllocatorIS5_EEE8__rehashEj($this,$__nbc) {
 $this = $this|0;
 $__nbc = $__nbc|0;
 var $$lcssa = 0, $$lcssa$us = 0, $$lcssa5 = 0, $$lcssa6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $98$phi = 0, $99 = 0, $99$phi = 0, $__cp$0 = 0, $__cp$0$in1827 = 0, $__cp$0$in21 = 0, $__cp$0$lcssa2 = 0, $__cp$0$lcssa3 = 0, $__cp$0$us = 0, $__cp$07 = 0, $__cp$0719 = 0, $__cp$071924 = 0, $__cp$071928 = 0, $__cp$0722 = 0, $__cp$08 = 0, $__cp$08$us = 0, $__i$011 = 0;
 var $__phash$0$ph$ph26 = 0, $__pp$0$ph$ph25 = 0, $__pp$0$ph20 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nbc|0)!=(0);
 if ($0) {
  $1 = $__nbc << 2;
  $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
  $4 = $2;
 } else {
  $4 = 0;
 }
 $3 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $4;
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  __THREW__ = 0;
  invoke_vi(3303,($3|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   ___cxa_call_unexpected(($8|0));
   // unreachable;
  }
 }
 $10 = (($this) + 4|0);
 HEAP32[$10>>2] = $__nbc;
 if ($0) {
  $__i$011 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $11 = HEAP32[$this>>2]|0;
  $12 = (($11) + ($__i$011<<2)|0);
  HEAP32[$12>>2] = 0;
  $13 = (($__i$011) + 1)|0;
  $exitcond = ($13|0)==($__nbc|0);
  if ($exitcond) {
   break;
  } else {
   $__i$011 = $13;
  }
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (($15) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($__nbc) + -1)|0;
 $20 = $19 & $__nbc;
 $21 = ($20|0)==(0);
 if ($21) {
  $22 = $18 & $19;
  $26 = $22;
 } else {
  $23 = (($18>>>0) % ($__nbc>>>0))&-1;
  $26 = $23;
 }
 $24 = HEAP32[$this>>2]|0;
 $25 = (($24) + ($26<<2)|0);
 HEAP32[$25>>2] = $14;
 $__cp$071924 = HEAP32[$15>>2]|0;
 $27 = ($__cp$071924|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $__cp$0$in1827 = $15;$__cp$071928 = $__cp$071924;$__phash$0$ph$ph26 = $26;$__pp$0$ph$ph25 = $15;
 }
 L22: while(1) {
  $__cp$0$in21 = $__cp$0$in1827;$__cp$0722 = $__cp$071928;$__pp$0$ph20 = $__pp$0$ph$ph25;
  L24: while(1) {
   L26: do {
    if ($21) {
     $__cp$08$us = $__cp$0722;
     while(1) {
      $29 = (($__cp$08$us) + 4|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = $30 & $19;
      $32 = ($31|0)==($__phash$0$ph$ph26|0);
      if ($32) {
       $__cp$0$lcssa2 = $__cp$08$us;
       break L26;
      }
      $33 = HEAP32[$this>>2]|0;
      $34 = (($33) + ($31<<2)|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==(0|0);
      if ($36) {
       $$lcssa5 = $31;$$lcssa6 = $34;$__cp$0$lcssa3 = $__cp$08$us;
       break L24;
      }
      $59 = HEAP32[$__cp$08$us>>2]|0;
      $60 = ($59|0)==(0|0);
      L31: do {
       if ($60) {
        $$lcssa$us = $__cp$08$us;$50 = 0;
       } else {
        $61 = (($__cp$08$us) + 8|0);
        $62 = HEAP32[$61>>2]|0;
        $42 = HEAP32[$62>>2]|0;
        $44 = (($62) + 4|0);
        $38 = $59;$98 = $__cp$08$us;
        while(1) {
         $37 = (($38) + 8|0);
         $39 = HEAP32[$37>>2]|0;
         $40 = HEAP32[$39>>2]|0;
         $41 = ($42|0)==($40|0);
         if (!($41)) {
          $$lcssa$us = $98;$50 = $38;
          break L31;
         }
         $43 = HEAP32[$44>>2]|0;
         $45 = (($39) + 4|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = ($43|0)==($46|0);
         if (!($47)) {
          $$lcssa$us = $98;$50 = $38;
          break L31;
         }
         $48 = HEAP32[$38>>2]|0;
         $49 = ($48|0)==(0|0);
         if ($49) {
          $$lcssa$us = $38;$50 = 0;
          break;
         } else {
          $98$phi = $38;$38 = $48;$98 = $98$phi;
         }
        }
       }
      } while(0);
      HEAP32[$__cp$0$in21>>2] = $50;
      $51 = HEAP32[$this>>2]|0;
      $52 = (($51) + ($31<<2)|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = HEAP32[$53>>2]|0;
      HEAP32[$$lcssa$us>>2] = $54;
      $55 = HEAP32[$this>>2]|0;
      $56 = (($55) + ($31<<2)|0);
      $57 = HEAP32[$56>>2]|0;
      HEAP32[$57>>2] = $__cp$08$us;
      $__cp$0$us = HEAP32[$__cp$0$in21>>2]|0;
      $58 = ($__cp$0$us|0)==(0|0);
      if ($58) {
       label = 33;
       break L22;
      } else {
       $__cp$08$us = $__cp$0$us;
      }
     }
    } else {
     $__cp$08 = $__cp$0722;
     while(1) {
      $63 = (($__cp$08) + 4|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64>>>0) % ($__nbc>>>0))&-1;
      $66 = ($65|0)==($__phash$0$ph$ph26|0);
      if ($66) {
       $__cp$0$lcssa2 = $__cp$08;
       break L26;
      }
      $67 = HEAP32[$this>>2]|0;
      $68 = (($67) + ($65<<2)|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($69|0)==(0|0);
      if ($70) {
       $$lcssa5 = $65;$$lcssa6 = $68;$__cp$0$lcssa3 = $__cp$08;
       break L24;
      }
      $71 = HEAP32[$__cp$08>>2]|0;
      $72 = ($71|0)==(0|0);
      L42: do {
       if ($72) {
        $$lcssa = $__cp$08;$89 = 0;
       } else {
        $73 = (($__cp$08) + 8|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = HEAP32[$74>>2]|0;
        $76 = (($74) + 4|0);
        $79 = $71;$99 = $__cp$08;
        while(1) {
         $78 = (($79) + 8|0);
         $80 = HEAP32[$78>>2]|0;
         $81 = HEAP32[$80>>2]|0;
         $82 = ($75|0)==($81|0);
         if (!($82)) {
          $$lcssa = $99;$89 = $79;
          break L42;
         }
         $83 = HEAP32[$76>>2]|0;
         $84 = (($80) + 4|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = ($83|0)==($85|0);
         if (!($86)) {
          $$lcssa = $99;$89 = $79;
          break L42;
         }
         $87 = HEAP32[$79>>2]|0;
         $88 = ($87|0)==(0|0);
         if ($88) {
          $$lcssa = $79;$89 = 0;
          break;
         } else {
          $99$phi = $79;$79 = $87;$99 = $99$phi;
         }
        }
       }
      } while(0);
      HEAP32[$__cp$0$in21>>2] = $89;
      $90 = HEAP32[$this>>2]|0;
      $91 = (($90) + ($65<<2)|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = HEAP32[$92>>2]|0;
      HEAP32[$$lcssa>>2] = $93;
      $94 = HEAP32[$this>>2]|0;
      $95 = (($94) + ($65<<2)|0);
      $96 = HEAP32[$95>>2]|0;
      HEAP32[$96>>2] = $__cp$08;
      $__cp$0 = HEAP32[$__cp$0$in21>>2]|0;
      $97 = ($__cp$0|0)==(0|0);
      if ($97) {
       label = 33;
       break L22;
      } else {
       $__cp$08 = $__cp$0;
      }
     }
    }
   } while(0);
   $__cp$07 = HEAP32[$__cp$0$lcssa2>>2]|0;
   $28 = ($__cp$07|0)==(0|0);
   if ($28) {
    label = 33;
    break L22;
   } else {
    $__cp$0$in21 = $__cp$0$lcssa2;$__cp$0722 = $__cp$07;$__pp$0$ph20 = $__cp$0$lcssa2;
   }
  }
  HEAP32[$$lcssa6>>2] = $__pp$0$ph20;
  $__cp$0719 = HEAP32[$__cp$0$lcssa3>>2]|0;
  $77 = ($__cp$0719|0)==(0|0);
  if ($77) {
   label = 33;
   break;
  } else {
   $__cp$0$in1827 = $__cp$0$lcssa3;$__cp$071928 = $__cp$0719;$__phash$0$ph$ph26 = $$lcssa5;$__pp$0$ph$ph25 = $__cp$0$lcssa3;
  }
 }
 if ((label|0) == 33) {
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2vm8basepathEPKc($path) {
 $path = $path|0;
 var $$0$i$i = 0, $$pre$phi8Z2D = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $__p$0$i$i = 0, $__p$0$i$i$i = 0, $__ps$0$i$i = 0;
 var $original_path = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $original_path = sp + 12|0;
 $0 = sp;
 $1 = (_strlen(($path|0))|0);
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$original_path>>0] = $5;
  $6 = (($original_path) + 1|0);
  $$pre$phiZ2D = $original_path;$16 = $5;$__p$0$i$i$i = $6;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  $10 = (($original_path) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$original_path>>2] = $11;
  $12 = (($original_path) + 4|0);
  HEAP32[$12>>2] = $1;
  $13 = $11&255;
  $$pre$phiZ2D = $original_path;$16 = $13;$__p$0$i$i$i = $9;
 }
 _memcpy(($__p$0$i$i$i|0),($path|0),($1|0))|0;
 $14 = (($__p$0$i$i$i) + ($1)|0);
 HEAP8[$14>>0] = 0;
 $15 = $16 & 1;
 $17 = ($15<<24>>24)==(0);
 if ($17) {
  $20 = $16&255;
  $21 = $20 >>> 1;
  $23 = $21;
 } else {
  $18 = (($original_path) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $23 = $19;
 }
 $22 = ($23|0)==(0);
 L12: do {
  if ($22) {
   $$0$i$i = 0;
  } else {
   if ($17) {
    $26 = (($original_path) + 1|0);
    $28 = $26;
   } else {
    $24 = (($original_path) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $28 = $25;
   }
   $27 = (($28) + ($23)|0);
   $__ps$0$i$i = $27;
   while(1) {
    $29 = ($__ps$0$i$i|0)==($28|0);
    if ($29) {
     $$0$i$i = 0;
     break L12;
    }
    $30 = (($__ps$0$i$i) + -1|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = ($31<<24>>24)==(47);
    if ($32) {
     break;
    } else {
     $__ps$0$i$i = $30;
    }
   }
   $33 = $30;
   $34 = $28;
   $35 = (1 - ($34))|0;
   $phitmp = (($35) + ($33))|0;
   $$0$i$i = $phitmp;
  }
 } while(0);
 $36 = $16 & 1;
 $37 = ($36<<24>>24)==(0);
 if ($37) {
  $40 = $16&255;
  $41 = $40 >>> 1;
  $43 = $41;
 } else {
  $38 = (($original_path) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $43 = $39;
 }
 $42 = ($43>>>0)<($$0$i$i>>>0);
 do {
  if ($42) {
   __THREW__ = 0;
   invoke_vi(3304,0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    // unreachable;
   }
  } else {
   if ($37) {
    $48 = (($original_path) + 1|0);
    $50 = $48;
   } else {
    $46 = (($original_path) + 8|0);
    $47 = HEAP32[$46>>2]|0;
    $50 = $47;
   }
   $49 = (($50) + ($$0$i$i)|0);
   $51 = (($43) - ($$0$i$i))|0;
   $52 = ($51>>>0)>(4294967279);
   if ($52) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    // unreachable;
   }
   $55 = ($51>>>0)<(11);
   if ($55) {
    $56 = $51 << 1;
    $57 = $56&255;
    HEAP8[$0>>0] = $57;
    $58 = (($0) + 1|0);
    $$pre$phi8Z2D = $0;$70 = $57;$__p$0$i$i = $58;
   } else {
    $59 = (($51) + 16)|0;
    $60 = $59 & -16;
    __THREW__ = 0;
    $61 = (invoke_ii(2988,($60|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    $64 = (($0) + 8|0);
    HEAP32[$64>>2] = $61;
    $65 = $60 | 1;
    HEAP32[$0>>2] = $65;
    $66 = (($0) + 4|0);
    HEAP32[$66>>2] = $51;
    $67 = $65&255;
    $$pre$phi8Z2D = $0;$70 = $67;$__p$0$i$i = $61;
   }
   _memcpy(($__p$0$i$i|0),($49|0),($51|0))|0;
   $68 = (($__p$0$i$i) + ($51)|0);
   HEAP8[$68>>0] = 0;
   $69 = $70 & 1;
   $71 = ($69<<24>>24)==(0);
   if ($71) {
    $74 = (($0) + 1|0);
    $75 = $74;
   } else {
    $72 = (($0) + 8|0);
    $73 = HEAP32[$72>>2]|0;
    $75 = $73;
   }
   $76 = (___strdup($75)|0);
   $77 = HEAP8[$$pre$phi8Z2D>>0]|0;
   $78 = $77 & 1;
   $79 = ($78<<24>>24)==(0);
   if (!($79)) {
    $80 = (($0) + 8|0);
    $81 = HEAP32[$80>>2]|0;
    __ZdlPv($81);
   }
   $82 = HEAP8[$$pre$phiZ2D>>0]|0;
   $83 = $82 & 1;
   $84 = ($83<<24>>24)==(0);
   if ($84) {
    STACKTOP = sp;return ($76|0);
   }
   $85 = (($original_path) + 8|0);
   $86 = HEAP32[$85>>2]|0;
   __ZdlPv($86);
   STACKTOP = sp;return ($76|0);
  }
 } while(0);
 $87 = ___cxa_find_matching_catch()|0;
 $88 = tempRet0;
 $89 = HEAP8[$$pre$phiZ2D>>0]|0;
 $90 = $89 & 1;
 $91 = ($90<<24>>24)==(0);
 if ($91) {
  ___resumeException($87|0);
  // unreachable;
 }
 $92 = (($original_path) + 8|0);
 $93 = HEAP32[$92>>2]|0;
 __ZdlPv($93);
 ___resumeException($87|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp2vm7Runtime4InitEPKc($filename) {
 $filename = $filename|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanup22ExecuteInitializationsEv();
 __ZN6il2cpp2vm8Assembly10InitializeEv();
 __Z19il2cpp_gc_base_initv();
 __ZN6il2cpp2vm13InternalCalls4InitEv();
 _memset((388944|0),0,168)|0;
 $0 = (__ZN6il2cpp2vm8Assembly4LoadEPKc(389120)|0);
 $1 = (__ZN6il2cpp2vm8Assembly8GetImageEPK14Il2CppAssembly($0)|0);
 HEAP32[388944>>2] = $1;
 $2 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($1,389136,389144)|0);
 HEAP32[((388944 + 4|0))>>2] = $2;
 $3 = HEAP32[388944>>2]|0;
 $4 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($3,389136,389152)|0);
 HEAP32[((388944 + 12|0))>>2] = $4;
 $5 = HEAP32[388944>>2]|0;
 $6 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($5,389136,389160)|0);
 HEAP32[((388944 + 16|0))>>2] = $6;
 $7 = HEAP32[388944>>2]|0;
 $8 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($7,389136,389168)|0);
 HEAP32[((388944 + 8|0))>>2] = $8;
 $9 = HEAP32[388944>>2]|0;
 $10 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($9,389136,389176)|0);
 HEAP32[((388944 + 20|0))>>2] = $10;
 $11 = HEAP32[388944>>2]|0;
 $12 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($11,389136,389184)|0);
 HEAP32[((388944 + 24|0))>>2] = $12;
 $13 = HEAP32[388944>>2]|0;
 $14 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($13,389136,389192)|0);
 HEAP32[((388944 + 28|0))>>2] = $14;
 $15 = HEAP32[388944>>2]|0;
 $16 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($15,389136,389200)|0);
 HEAP32[((388944 + 32|0))>>2] = $16;
 $17 = HEAP32[388944>>2]|0;
 $18 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($17,389136,389208)|0);
 HEAP32[((388944 + 36|0))>>2] = $18;
 $19 = HEAP32[388944>>2]|0;
 $20 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($19,389136,389216)|0);
 HEAP32[((388944 + 44|0))>>2] = $20;
 $21 = HEAP32[388944>>2]|0;
 $22 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($21,389136,389224)|0);
 HEAP32[((388944 + 40|0))>>2] = $22;
 $23 = HEAP32[388944>>2]|0;
 $24 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($23,389136,389232)|0);
 HEAP32[((388944 + 48|0))>>2] = $24;
 $25 = HEAP32[388944>>2]|0;
 $26 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($25,389136,389240)|0);
 HEAP32[((388944 + 52|0))>>2] = $26;
 $27 = HEAP32[388944>>2]|0;
 $28 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($27,389136,389248)|0);
 HEAP32[((388944 + 56|0))>>2] = $28;
 $29 = HEAP32[388944>>2]|0;
 $30 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($29,389136,389256)|0);
 HEAP32[((388944 + 60|0))>>2] = $30;
 $31 = HEAP32[388944>>2]|0;
 $32 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($31,389136,389264)|0);
 HEAP32[((388944 + 64|0))>>2] = $32;
 $33 = HEAP32[388944>>2]|0;
 $34 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($33,389136,389272)|0);
 HEAP32[((388944 + 68|0))>>2] = $34;
 $35 = HEAP32[388944>>2]|0;
 $36 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($35,389136,389280)|0);
 HEAP32[((388944 + 72|0))>>2] = $36;
 $37 = HEAP32[388944>>2]|0;
 $38 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($37,389136,389288)|0);
 HEAP32[((388944 + 76|0))>>2] = $38;
 $39 = HEAP32[388944>>2]|0;
 $40 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($39,389136,389296)|0);
 HEAP32[((388944 + 80|0))>>2] = $40;
 $41 = HEAP32[388944>>2]|0;
 $42 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($41,389136,389312)|0);
 HEAP32[((388944 + 84|0))>>2] = $42;
 $43 = HEAP32[388944>>2]|0;
 $44 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($43,389336,389360)|0);
 HEAP32[((388944 + 92|0))>>2] = $44;
 $45 = HEAP32[388944>>2]|0;
 $46 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($45,389136,389384)|0);
 HEAP32[((388944 + 108|0))>>2] = $46;
 $47 = HEAP32[388944>>2]|0;
 $48 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($47,389136,389392)|0);
 HEAP32[((388944 + 112|0))>>2] = $48;
 $49 = HEAP32[388944>>2]|0;
 $50 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($49,389336,389408)|0);
 HEAP32[((388944 + 124|0))>>2] = $50;
 $51 = HEAP32[388944>>2]|0;
 $52 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($51,389136,389416)|0);
 HEAP32[((388944 + 128|0))>>2] = $52;
 $53 = HEAP32[388944>>2]|0;
 $54 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($53,389136,389432)|0);
 HEAP32[((388944 + 132|0))>>2] = $54;
 $55 = HEAP32[388944>>2]|0;
 $56 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($55,389448,389472)|0);
 HEAP32[((388944 + 136|0))>>2] = $56;
 $57 = HEAP32[388944>>2]|0;
 $58 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($57,389448,389488)|0);
 HEAP32[((388944 + 140|0))>>2] = $58;
 $59 = HEAP32[388944>>2]|0;
 $60 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($59,389448,389504)|0);
 HEAP32[((388944 + 144|0))>>2] = $60;
 $61 = HEAP32[388944>>2]|0;
 $62 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($61,389448,389520)|0);
 HEAP32[((388944 + 148|0))>>2] = $62;
 $63 = HEAP32[388944>>2]|0;
 $64 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($63,389536,389560)|0);
 HEAP32[((388944 + 152|0))>>2] = $64;
 $65 = HEAP32[388944>>2]|0;
 $66 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($65,389536,389576)|0);
 HEAP32[((388944 + 156|0))>>2] = $66;
 $67 = HEAP32[388944>>2]|0;
 $68 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($67,389592,389624)|0);
 HEAP32[((388944 + 160|0))>>2] = $68;
 $69 = HEAP32[388944>>2]|0;
 $70 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($69,389136,389632)|0);
 HEAP32[((388944 + 164|0))>>2] = $70;
 $71 = HEAP32[((388944 + 68|0))>>2]|0;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($71)|0);
 $72 = (__ZN6il2cpp2vm6Domain10GetCurrentEv()|0);
 $73 = HEAP32[((388944 + 128|0))>>2]|0;
 $74 = (__ZN6il2cpp2vm6Object9NewPinnedEP8TypeInfo($73)|0);
 $75 = HEAP32[((388944 + 128|0))>>2]|0;
 $76 = (__ZN6il2cpp2vm6Object9NewPinnedEP8TypeInfo($75)|0);
 $77 = (($76) + 12|0);
 HEAP32[$77>>2] = $72;
 HEAP32[$72>>2] = $76;
 $78 = (($72) + 4|0);
 HEAP32[$78>>2] = $74;
 $79 = (__ZN6il2cpp2vm8basepathEPKc($filename)|0);
 $80 = (($72) + 8|0);
 HEAP32[$80>>2] = $79;
 (__ZN6il2cpp2vm6Thread6AttachEP12Il2CppDomain($72)|0);
 __Z14il2cpp_gc_initv();
 HEAP8[389112>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm7Runtime14DelegateInvokeEP14Il2CppDelegatePPvPP12Il2CppObject($delegate,$params,$exc) {
 $delegate = $delegate|0;
 $params = $params|0;
 $exc = $exc|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$delegate>>2]|0;
 $1 = (__ZN6il2cpp2vm5Class17GetMethodFromNameEP8TypeInfoPKci($0,389648,-1)|0);
 $2 = ($exc|0)!=(0|0);
 if ($2) {
  HEAP32[$exc>>2] = 0;
 }
 $3 = (($1) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_iiii($4|0,($6|0),($delegate|0),($params|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $$0$i = $7;
  STACKTOP = sp;return ($$0$i|0);
 }
 $10 = ___cxa_find_matching_catch(348288|0)|0;
 $11 = tempRet0;
 $12 = (_llvm_eh_typeid_for((348288|0))|0);
 $13 = ($11|0)==($12|0);
 if (!($13)) {
  ___resumeException($10|0);
  // unreachable;
 }
 $14 = (___cxa_begin_catch(($10|0))|0);
 if ($2) {
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$exc>>2] = $15;
 }
 ___cxa_end_catch();
 $$0$i = 0;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN6il2cpp2vm7Runtime6InvokeEP10MethodInfoPvPS4_PP12Il2CppObject($method,$obj,$params,$exc) {
 $method = $method|0;
 $obj = $obj|0;
 $params = $params|0;
 $exc = $exc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($exc|0)!=(0|0);
 if ($0) {
  HEAP32[$exc>>2] = 0;
 }
 $1 = (($method) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($method) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iiii($2|0,($4|0),($obj|0),($params|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ___cxa_find_matching_catch(348288|0)|0;
 $9 = tempRet0;
 $10 = (_llvm_eh_typeid_for((348288|0))|0);
 $11 = ($9|0)==($10|0);
 if (!($11)) {
  ___resumeException($8|0);
  // unreachable;
 }
 $12 = (___cxa_begin_catch(($8|0))|0);
 if ($0) {
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$exc>>2] = $13;
 }
 ___cxa_end_catch();
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm7Runtime11InvokeArrayEP10MethodInfoPvP11Il2CppArrayPP12Il2CppObject($method,$obj,$params,$exc) {
 $method = $method|0;
 $obj = $obj|0;
 $params = $params|0;
 $exc = $exc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $pa$0 = 0, $pc$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($params|0)==(0|0);
 if ($0) {
  $pa$0 = 0;$pc$0 = 0;
 } else {
  $1 = (__ZN6il2cpp2vm5Array9GetLengthEP11Il2CppArray($params)|0);
  $2 = $1 << 2;
  $3 = STACKTOP; STACKTOP = STACKTOP + ((((1*$2)|0)+15)&-16)|0;;
  $4 = ($1|0)>(0);
  if ($4) {
   $i$01 = 0;
   while(1) {
    $5 = (__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij($params,4,$i$01)|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($3) + ($i$01<<2)|0);
    HEAP32[$7>>2] = $6;
    $8 = (($i$01) + 1)|0;
    $exitcond = ($8|0)==($1|0);
    if ($exitcond) {
     $pa$0 = $3;$pc$0 = $1;
     break;
    } else {
     $i$01 = $8;
    }
   }
  } else {
   $pa$0 = $3;$pc$0 = $1;
  }
 }
 $9 = (__ZN6il2cpp2vm7Runtime17InvokeConvertArgsEP10MethodInfoPvPP12Il2CppObjectiS7_($method,$obj,$pa$0,$pc$0,$exc)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN6il2cpp2vm7Runtime17InvokeConvertArgsEP10MethodInfoPvPP12Il2CppObjectiS7_($method,$obj,$params,$paramCount,$exc) {
 $method = $method|0;
 $obj = $obj|0;
 $params = $params|0;
 $paramCount = $paramCount|0;
 $exc = $exc|0;
 var $$0 = 0, $$0$i2 = 0, $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $exitcond = 0, $i$08 = 0, $o$0 = 0, $pa$0 = 0, $t$0 = 0, $t$0$in = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($params|0)==(0|0);
 if ($0) {
  $pa$0 = 0;
 } else {
  $1 = $paramCount << 2;
  $2 = STACKTOP; STACKTOP = STACKTOP + ((((1*$1)|0)+15)&-16)|0;;
  $3 = ($paramCount|0)>(0);
  if ($3) {
   $4 = (($method) + 20|0);
   $i$08 = 0;
   while(1) {
    $5 = HEAP32[$4>>2]|0;
    $6 = ((($5) + (($i$08*12)|0)|0) + 8|0);
    $t$0$in = $6;
    L6: while(1) {
     $t$0 = HEAP32[$t$0$in>>2]|0;
     $7 = (($t$0) + 4|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = $8 >>> 16;
     $10 = $9 & 255;
     switch ($10|0) {
     case 29: case 20: case 18: case 28: case 14:  {
      label = 11;
      break L6;
      break;
     }
     case 17: case 13: case 12: case 10: case 11: case 8: case 9: case 24: case 25: case 3: case 6: case 7: case 2: case 4: case 5:  {
      label = 6;
      break L6;
      break;
     }
     case 15:  {
      label = 17;
      break L6;
      break;
     }
     case 21:  {
      break;
     }
     default: {
      break L6;
     }
     }
     $33 = $8 & 1073741824;
     $34 = ($33|0)==(0);
     $35 = HEAP32[$t$0>>2]|0;
     $36 = HEAP32[$35>>2]|0;
     if ($34) {
      $38 = (($36) + 48|0);
      $t$0$in = $38;
      continue;
     } else {
      $37 = (($36) + 52|0);
      $t$0$in = $37;
      continue;
     }
    }
    do {
     if ((label|0) == 6) {
      label = 0;
      $11 = (($params) + ($i$08<<2)|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = ($12|0)==(0|0);
      if ($13) {
       $14 = HEAP32[$6>>2]|0;
       $15 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($14)|0);
       $16 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($15)|0);
       HEAP32[$11>>2] = $16;
       $$pre = HEAP32[$7>>2]|0;
       $18 = $$pre;$21 = $16;
      } else {
       $18 = $8;$21 = $12;
      }
      $17 = $18 & 1073741824;
      $19 = ($17|0)==(0);
      if ($19) {
       $24 = $21;
      } else {
       $20 = HEAP32[$21>>2]|0;
       $22 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($21)|0);
       $23 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv($20,$22)|0);
       HEAP32[$11>>2] = $23;
       $24 = $23;
      }
      $25 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($24)|0);
      $26 = (($2) + ($i$08<<2)|0);
      HEAP32[$26>>2] = $25;
     }
     else if ((label|0) == 11) {
      label = 0;
      $27 = $8 & 1073741824;
      $28 = ($27|0)==(0);
      $29 = (($params) + ($i$08<<2)|0);
      if ($28) {
       $31 = HEAP32[$29>>2]|0;
       $32 = (($2) + ($i$08<<2)|0);
       HEAP32[$32>>2] = $31;
       break;
      } else {
       $30 = (($2) + ($i$08<<2)|0);
       HEAP32[$30>>2] = $29;
       break;
      }
     }
     else if ((label|0) == 17) {
      label = 0;
      $39 = (($params) + ($i$08<<2)|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       $42 = (($2) + ($i$08<<2)|0);
       HEAP32[$42>>2] = 0;
       break;
      } else {
       $43 = HEAP32[$40>>2]|0;
       $44 = (($2) + ($i$08<<2)|0);
       HEAP32[$44>>2] = $43;
       break;
      }
     }
    } while(0);
    $45 = (($i$08) + 1)|0;
    $exitcond = ($45|0)==($paramCount|0);
    if ($exitcond) {
     $pa$0 = $2;
     break;
    } else {
     $i$08 = $45;
    }
   }
  } else {
   $pa$0 = $2;
  }
 }
 $46 = HEAP32[$method>>2]|0;
 $47 = (_strcmp($46,389656)|0);
 $48 = ($47|0)==(0);
 if ($48) {
  $49 = (($method) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = HEAP32[((388944 + 68|0))>>2]|0;
  $52 = ($50|0)==($51|0);
  if (!($52)) {
   $53 = ($obj|0)==(0|0);
   if ($53) {
    $54 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($50)|0);
    $55 = HEAP32[$49>>2]|0;
    $56 = (($55) + 113|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = ($57<<24>>24)==(0);
    if ($58) {
     $$01 = $54;$o$0 = $54;
    } else {
     $59 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($54)|0);
     $$01 = $54;$o$0 = $59;
    }
   } else {
    $60 = (($50) + 113|0);
    $61 = HEAP8[$60>>0]|0;
    $62 = ($61<<24>>24)==(0);
    if ($62) {
     $$01 = $obj;$o$0 = $obj;
    } else {
     $63 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv($50,$obj)|0);
     $$01 = $63;$o$0 = $obj;
    }
   }
   $64 = ($exc|0)!=(0|0);
   if ($64) {
    HEAP32[$exc>>2] = 0;
   }
   $65 = (($method) + 16|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($method) + 4|0);
   $68 = HEAP32[$67>>2]|0;
   __THREW__ = 0;
   (invoke_iiii($66|0,($68|0),($o$0|0),($pa$0|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    $71 = ___cxa_find_matching_catch(348288|0)|0;
    $72 = tempRet0;
    $73 = (_llvm_eh_typeid_for((348288|0))|0);
    $74 = ($72|0)==($73|0);
    if (!($74)) {
     ___resumeException($71|0);
     // unreachable;
    }
    $75 = (___cxa_begin_catch(($71|0))|0);
    if ($64) {
     $76 = HEAP32[$75>>2]|0;
     HEAP32[$exc>>2] = $76;
    }
    ___cxa_end_catch();
   }
   $$0 = $$01;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $77 = ($exc|0)!=(0|0);
 if ($77) {
  HEAP32[$exc>>2] = 0;
 }
 $78 = (($method) + 16|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($method) + 4|0);
 $81 = HEAP32[$80>>2]|0;
 __THREW__ = 0;
 $82 = (invoke_iiii($79|0,($81|0),($obj|0),($pa$0|0))|0);
 $83 = __THREW__; __THREW__ = 0;
 $84 = $83&1;
 if ($84) {
  $85 = ___cxa_find_matching_catch(348288|0)|0;
  $86 = tempRet0;
  $87 = (_llvm_eh_typeid_for((348288|0))|0);
  $88 = ($86|0)==($87|0);
  if (!($88)) {
   ___resumeException($85|0);
   // unreachable;
  }
  $89 = (___cxa_begin_catch(($85|0))|0);
  if ($77) {
   $90 = HEAP32[$89>>2]|0;
   HEAP32[$exc>>2] = $90;
  }
  ___cxa_end_catch();
  $$0$i2 = 0;
 } else {
  $$0$i2 = $82;
 }
 $91 = (($method) + 12|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + 4|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = $94 & 16711680;
 $96 = ($95|0)==(983040);
 if (!($96)) {
  $$0 = $$0$i2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = 389712;
 (_printf((389688|0),($vararg_buffer|0))|0);
 $$0 = $$0$i2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm7Runtime10ObjectInitEP12Il2CppObject($object) {
 $object = $object|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$object>>2]|0;
 $1 = (__ZN6il2cpp2vm5Class17GetMethodFromNameEP8TypeInfoPKci($0,389656,0)|0);
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 113|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $$0$i = $object;
 } else {
  $7 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($object)|0);
  $$0$i = $7;
 }
 $8 = (($1) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($1) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 (invoke_iiii($9|0,($11|0),($$0$i|0),(0|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = ___cxa_find_matching_catch(348288|0)|0;
 $15 = tempRet0;
 $16 = (_llvm_eh_typeid_for((348288|0))|0);
 $17 = ($15|0)==($16|0);
 if (!($17)) {
  ___resumeException($14|0);
  // unreachable;
 }
 (___cxa_begin_catch(($14|0))|0);
 ___cxa_end_catch();
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm7Runtime19ObjectInitExceptionEP12Il2CppObjectPS3_($object,$exc) {
 $object = $object|0;
 $exc = $exc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$object>>2]|0;
 $1 = (__ZN6il2cpp2vm5Class17GetMethodFromNameEP8TypeInfoPKci($0,389656,0)|0);
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 113|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $$0 = $object;
 } else {
  $7 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($object)|0);
  $$0 = $7;
 }
 $8 = ($exc|0)!=(0|0);
 if ($8) {
  HEAP32[$exc>>2] = 0;
 }
 $9 = (($1) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($1) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 (invoke_iiii($10|0,($12|0),($$0|0),(0|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = ___cxa_find_matching_catch(348288|0)|0;
 $16 = tempRet0;
 $17 = (_llvm_eh_typeid_for((348288|0))|0);
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  ___resumeException($15|0);
  // unreachable;
 }
 $19 = (___cxa_begin_catch(($15|0))|0);
 if ($8) {
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$exc>>2] = $20;
 }
 ___cxa_end_catch();
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm7Runtime27SetUnhandledExceptionPolicyE37Il2CppRuntimeUnhandledExceptionPolicy($value) {
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm7Runtime18UnhandledExceptionEP12Il2CppObject($exc) {
 $exc = $exc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pa$i = 0, $root_appdomain_delegate = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pa$i = sp + 8|0;
 $root_appdomain_delegate = sp;
 (__ZN6il2cpp2vm6Domain10GetCurrentEv()|0);
 $0 = (__ZN6il2cpp2vm6Domain7GetRootEv()|0);
 HEAP32[$root_appdomain_delegate>>2] = 0;
 $1 = HEAP32[((388944 + 128|0))>>2]|0;
 $2 = (__ZN6il2cpp2vm5Class16GetFieldFromNameEPK8TypeInfoPKc($1,389664)|0);
 $3 = HEAP32[$exc>>2]|0;
 $4 = HEAP32[((388944 + 120|0))>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 (__ZN6il2cpp2vm6Thread7CurrentEv()|0);
 (__ZN6il2cpp2vm6Thread4MainEv()|0);
 $6 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2vm5Field8GetValueEP12Il2CppObjectP9FieldInfoPv($6,$2,$root_appdomain_delegate);
 $7 = HEAP32[$root_appdomain_delegate>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$0>>2]|0;
 HEAP32[$pa$i>>2] = $9;
 $10 = (__ZN6il2cpp2vm7Runtime33CreateUnhandledExceptionEventArgsEP12Il2CppObject($exc)|0);
 $11 = (($pa$i) + 4|0);
 HEAP32[$11>>2] = $10;
 $12 = HEAP32[$7>>2]|0;
 $13 = (__ZN6il2cpp2vm5Class17GetMethodFromNameEP8TypeInfoPKci($12,389648,-1)|0);
 $14 = (($13) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 __THREW__ = 0;
 (invoke_iiii($15|0,($17|0),($7|0),($pa$i|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = ___cxa_find_matching_catch(348288|0)|0;
 $21 = tempRet0;
 $22 = (_llvm_eh_typeid_for((348288|0))|0);
 $23 = ($21|0)==($22|0);
 if (!($23)) {
  ___resumeException($20|0);
  // unreachable;
 }
 (___cxa_begin_catch(($20|0))|0);
 ___cxa_end_catch();
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm7Runtime9IsUIntPtrEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $$ = 0, $0 = 0, $1 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((388944 + 44|0))>>2]|0;
 $1 = ($0|0)==($klass|0);
 $not$ = ($0|0)!=(0|0);
 $$ = $1 & $not$;
 STACKTOP = sp;return ($$|0);
}
function __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($agg$result,$method,$obj) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($method) + 32|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = (($0) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($3<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$agg$result>>2] = $obj;
 $8 = (($agg$result) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = (($7) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 113|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($10) + 117|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 HEAP32[$agg$result>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($agg$result,$method,$obj) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($method) + 32|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = (($method) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN6il2cpp2vm5Class18GetInterfaceOffsetEPK8TypeInfoPS2_($0,$4)|0);
 $6 = $2&255;
 $7 = (($5) + ($6))|0;
 $8 = $7 & 255;
 $9 = (($0) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($8<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$agg$result>>2] = $obj;
 $13 = (($agg$result) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = (($12) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 113|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($15) + 117|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 HEAP32[$agg$result>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm7Runtime33CreateUnhandledExceptionEventArgsEP12Il2CppObject($exc) {
 $exc = $exc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $is_terminating = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $args = sp;
 $is_terminating = sp + 8|0;
 HEAP8[$is_terminating>>0] = 1;
 $0 = HEAP32[388944>>2]|0;
 $1 = (__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_($0,389136,389800)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($1)|0);
 $2 = (__ZN6il2cpp2vm5Class22GetMethodFromNameFlagsEP8TypeInfoPKcii($1,389656,2,6)|0);
 HEAP32[$args>>2] = $exc;
 $3 = (($args) + 4|0);
 HEAP32[$3>>2] = $is_terminating;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($1)|0);
 $5 = (($2) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($2) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 (invoke_iiii($6|0,($8|0),($4|0),($args|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  STACKTOP = sp;return ($4|0);
 }
 $11 = ___cxa_find_matching_catch(348288|0)|0;
 $12 = tempRet0;
 $13 = (_llvm_eh_typeid_for((348288|0))|0);
 $14 = ($12|0)==($13|0);
 if (!($14)) {
  ___resumeException($11|0);
  // unreachable;
 }
 (___cxa_begin_catch(($11|0))|0);
 ___cxa_end_catch();
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $n = sp + 4|0;
 $0 = (($klass) + 123|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($klass) + 116|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = HEAP8[389112>>0]|0;
 $7 = ($6<<24>>24)==(0);
 $or$cond = $5 | $7;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $8 = (__ZN6il2cpp2vm6Thread7CurrentEv()|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (__ZN6il2cpp2vm5Class8GetCCtorEP8TypeInfo($klass)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 HEAP8[$3>>0] = 1;
 $12 = (($10) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($10) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 __THREW__ = 0;
 (invoke_iiii($13|0,($15|0),(0|0),(0|0))|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = ___cxa_find_matching_catch(348288|0)|0;
 $19 = tempRet0;
 $20 = (_llvm_eh_typeid_for((348288|0))|0);
 $21 = ($19|0)==($20|0);
 if (!($21)) {
  ___resumeException($18|0);
  // unreachable;
 }
 $22 = (___cxa_begin_catch(($18|0))|0);
 $23 = HEAP32[$22>>2]|0;
 ___cxa_end_catch();
 $24 = ($23|0)==(0|0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (__ZN6il2cpp2vm5Class7GetTypeEP8TypeInfo($klass)|0);
 $26 = (__ZN6il2cpp2vm4Type7GetNameEPK10Il2CppType20Il2CppTypeNameFormat($25,0)|0);
 HEAP32[$vararg_buffer>>2] = $26;
 __ZN6il2cpp5utils11StringUtils6PrintfEPKcz($n,389744,$vararg_buffer);
 $27 = HEAP8[$n>>0]|0;
 $28 = $27 & 1;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  $32 = (($n) + 1|0);
  $33 = $32;
 } else {
  $30 = (($n) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $33 = $31;
 }
 __THREW__ = 0;
 $34 = (invoke_iii(2336,($33|0),($23|0))|0);
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if (!($36)) {
  __THREW__ = 0;
  invoke_vi(3302,($34|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if (!($38)) {
   $39 = HEAP8[$n>>0]|0;
   $40 = $39 & 1;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    STACKTOP = sp;return;
   }
   $42 = (($n) + 8|0);
   $43 = HEAP32[$42>>2]|0;
   __ZdlPv($43);
   STACKTOP = sp;return;
  }
 }
 $44 = ___cxa_find_matching_catch()|0;
 $45 = tempRet0;
 $46 = HEAP8[$n>>0]|0;
 $47 = $46 & 1;
 $48 = ($47<<24>>24)==(0);
 if ($48) {
  ___resumeException($44|0);
  // unreachable;
 }
 $49 = (($n) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 __ZdlPv($50);
 ___resumeException($44|0);
 // unreachable;
}
function __ZN6il2cpp2vm6String9GetLengthEP12Il2CppString($str) {
 $str = $str|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($str) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm6String8GetCharsEP12Il2CppString($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($str) + 12|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm6String7GetHashEP12Il2CppString($str) {
 $str = $str|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $h$0$lcssa = 0, $h$03 = 0, $i$01 = 0, $p$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($str) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $h$0$lcssa = 0;
  STACKTOP = sp;return ($h$0$lcssa|0);
 }
 $3 = (($str) + 12|0);
 $h$03 = 0;$i$01 = 0;$p$02 = $3;
 while(1) {
  $4 = ($h$03*31)|0;
  $5 = HEAP16[$p$02>>1]|0;
  $6 = $5&65535;
  $7 = (($6) + ($4))|0;
  $8 = (($p$02) + 2|0);
  $9 = (($i$01) + 1)|0;
  $exitcond = ($9|0)==($1|0);
  if ($exitcond) {
   $h$0$lcssa = $7;
   break;
  } else {
   $h$03 = $7;$i$01 = $9;$p$02 = $8;
  }
 }
 STACKTOP = sp;return ($h$0$lcssa|0);
}
function __ZN6il2cpp2vm6String3NewEPKc($str) {
 $str = $str|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($str|0))|0);
 $1 = (__ZN6il2cpp2vm6String6NewLenEPKcj($str,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm6String6NewLenEPKcj($str,$length) {
 $str = $str|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i3 = 0, $len$c$i$i = 0, $scevgep$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i7 = 0, $utf16Chars = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $utf16Chars = sp;
 __ZN6il2cpp5utils11StringUtils11Utf8ToUtf16EPKcj($utf16Chars,$str,$length);
 $0 = HEAP32[$utf16Chars>>2]|0;
 $1 = $length << 1;
 $2 = (($1) + 14)|0;
 $3 = ($2>>>0)<($length>>>0);
 if ($3) {
  __THREW__ = 0;
  invoke_v(75);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 do {
  if ((label|0) == 3) {
   $6 = HEAP32[((388944 + 68|0))>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(2337,($2|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($7) + 8|0);
    $len$c$i$i = $length;
    HEAP32[$10>>2] = $len$c$i$i;
    $11 = (($7) + 12|0);
    $12 = (($11) + ($length<<1)|0);
    HEAP16[$12>>1] = 0;
    $13 = 0 & 128;
    $14 = ($13|0)==(0);
    if (!($14)) {
     $15 = HEAP32[((388944 + 68|0))>>2]|0;
     __THREW__ = 0;
     invoke_vii(2522,($7|0),($15|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
    }
    _memcpy(($11|0),($0|0),($1|0))|0;
    $18 = HEAP32[$utf16Chars>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     STACKTOP = sp;return ($7|0);
    }
    $20 = (($utf16Chars) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($18|0);
    if (!($22)) {
     $__new_last2$i$i$i$i$i3 = $18;
     $scevgep$i$i$i$i$i4 = (($21) + -2|0);
     $23 = (0 - ($__new_last2$i$i$i$i$i3))|0;
     $uglygep$i$i$i$i$i6 = (($scevgep$i$i$i$i$i4) + ($23)|0);
     $uglygep3$i$i$i$i$i7 = $uglygep$i$i$i$i$i6;
     $24 = $uglygep3$i$i$i$i$i7 >>> 1;
     $25 = $24 ^ -1;
     $scevgep4$i$i$i$i$i8 = (($21) + ($25<<1)|0);
     HEAP32[$20>>2] = $scevgep4$i$i$i$i$i8;
    }
    __ZdlPv($18);
    STACKTOP = sp;return ($7|0);
   }
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 $28 = HEAP32[$utf16Chars>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  ___resumeException($26|0);
  // unreachable;
 }
 $30 = (($utf16Chars) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==($28|0);
 if (!($32)) {
  $__new_last2$i$i$i$i$i = $28;
  $scevgep$i$i$i$i$i = (($31) + -2|0);
  $33 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($33)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $34 = $uglygep3$i$i$i$i$i >>> 1;
  $35 = $34 ^ -1;
  $scevgep4$i$i$i$i$i = (($31) + ($35<<1)|0);
  HEAP32[$30>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($28);
 ___resumeException($26|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp2vm6String10NewWrapperEPKc($str) {
 $str = $str|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($str|0))|0);
 $1 = (__ZN6il2cpp2vm6String6NewLenEPKcj($str,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN6il2cpp2vm6String7NewSizeEi($len) {
 $len = $len|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $len$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $len << 1;
 $1 = (($0) + 14)|0;
 $2 = ($1>>>0)<($len>>>0);
 if ($2) {
  __ZN6il2cpp2vm9Exception25RaiseOutOfMemoryExceptionEv();
 }
 $3 = HEAP32[((388944 + 68|0))>>2]|0;
 $4 = (__ZN6il2cpp2vm6Object15AllocatePtrFreeEjP8TypeInfo($1,$3)|0);
 $5 = (($4) + 8|0);
 $len$c = $len;
 HEAP32[$5>>2] = $len$c;
 $6 = (($4) + 12|0);
 $7 = (($6) + ($len<<1)|0);
 HEAP16[$7>>1] = 0;
 $8 = 0 & 128;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return ($4|0);
 }
 $10 = HEAP32[((388944 + 68|0))>>2]|0;
 __ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo($4,$10);
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp2vm6String4LoadEPKtj($chars,$length) {
 $chars = $chars|0;
 $length = $length|0;
 var $$0 = 0, $$0$i = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__i$i = 0, $internedString = 0, $len$c$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__i$i = sp + 20|0;
 $0 = sp + 8|0;
 $internedString = sp;
 $1 = sp + 16|0;
 HEAP32[$internedString>>2] = $length;
 $2 = (($internedString) + 4|0);
 HEAP32[$2>>2] = $chars;
 __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE4findIS4_EENS_15__hash_iteratorIPNS_11__hash_nodeIS7_PvEEEERKT_($1,389832,$internedString);
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = $length << 1;
 $8 = (($7) + 14)|0;
 $9 = ($8>>>0)<($length>>>0);
 if ($9) {
  __ZN6il2cpp2vm9Exception25RaiseOutOfMemoryExceptionEv();
 }
 $10 = HEAP32[((388944 + 68|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm6Object15AllocatePtrFreeEjP8TypeInfo($8,$10)|0);
 $12 = (($11) + 8|0);
 $len$c$i$i = $length;
 HEAP32[$12>>2] = $len$c$i$i;
 $13 = (($11) + 12|0);
 $14 = (($13) + ($length<<1)|0);
 HEAP16[$14>>1] = 0;
 $15 = 0 & 128;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = HEAP32[((388944 + 68|0))>>2]|0;
  __ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo($11,$17);
 }
 _memcpy(($13|0),($chars|0),($7|0))|0;
 (__ZN6il2cpp2gc8GCHandle3NewEP12Il2CppObjectb($11,1)|0);
 __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE4findIS4_EENS_15__hash_iteratorIPNS_11__hash_nodeIS7_PvEEEERKT_($__i$i,389832,$internedString);
 $18 = HEAP32[$__i$i>>2]|0;
 $19 = ($18|0)==(0|0);
 do {
  if ($19) {
   $20 = (__Znwj(20)|0);
   $21 = (($20) + 8|0);
   $22 = $internedString;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = (($22) + 4)|0;
   $26 = $25;
   $27 = HEAP32[$26>>2]|0;
   $28 = $21;
   $29 = $28;
   HEAP32[$29>>2] = $24;
   $30 = (($28) + 4)|0;
   $31 = $30;
   HEAP32[$31>>2] = $27;
   $32 = (($20) + 16|0);
   HEAP32[$32>>2] = 0;
   __THREW__ = 0;
   invoke_viii(1588,($0|0),(389832|0),($20|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    $35 = HEAP32[$0>>2]|0;
    $$sink$i = $35;
    break;
   }
   $36 = ___cxa_find_matching_catch()|0;
   $37 = tempRet0;
   $38 = ($20|0)==(0|0);
   if ($38) {
    ___resumeException($36|0);
    // unreachable;
   }
   __ZdlPv($20);
   ___resumeException($36|0);
   // unreachable;
  } else {
   $$sink$i = $18;
  }
 } while(0);
 $$0$i = (($$sink$i) + 16|0);
 HEAP32[$$0$i>>2] = $11;
 $$0 = $11;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm6String6InternEP12Il2CppString($str) {
 $str = $str|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($str) + 12|0);
 $1 = (($str) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj($0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp2vm6String10IsInternedEP12Il2CppString($str) {
 $str = $str|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $internedString = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $internedString = sp + 8|0;
 $0 = sp;
 $1 = (($str) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$internedString>>2] = $2;
 $3 = (($internedString) + 4|0);
 $4 = (($str) + 12|0);
 HEAP32[$3>>2] = $4;
 __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE4findIS4_EENS_15__hash_iteratorIPNS_11__hash_nodeIS7_PvEEEERKT_($0,389832,$internedString);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($5) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE20__node_insert_uniqueEPNS_11__hash_nodeIS7_PvEE($agg$result,$this,$__nd) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__bc$0 = 0, $__chash$0 = 0, $__chash$1 = 0, $__ndptr$0 = 0, $__ndptr$0$us = 0, $__ndptr$06 = 0, $__ndptr$07 = 0, $__ndptr$07$us = 0, $__ndptr$1 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__nd) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__nd) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 L1: do {
  if ($5) {
   $__chash$0 = 0;
  } else {
   $6 = (($4) + -1)|0;
   $7 = $6 & $4;
   $8 = ($7|0)==(0);
   if ($8) {
    $9 = $6 & $1;
    $13 = $9;
   } else {
    $10 = (($1>>>0) % ($4>>>0))&-1;
    $13 = $10;
   }
   $11 = HEAP32[$this>>2]|0;
   $12 = (($11) + ($13<<2)|0);
   $14 = HEAP32[$12>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    $__chash$0 = $13;
   } else {
    $__ndptr$06 = HEAP32[$14>>2]|0;
    $16 = ($__ndptr$06|0)==(0|0);
    if ($16) {
     $__chash$0 = $13;
    } else {
     $17 = (($__nd) + 12|0);
     if ($8) {
      $__ndptr$07$us = $__ndptr$06;
      while(1) {
       $18 = (($__ndptr$07$us) + 4|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = $19 & $6;
       $21 = ($20|0)==($13|0);
       if (!($21)) {
        $__chash$0 = $13;
        break L1;
       }
       $22 = (($__ndptr$07$us) + 8|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = ($23|0)==($1|0);
       if ($24) {
        $25 = (($__ndptr$07$us) + 12|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = HEAP32[$17>>2]|0;
        $28 = $1 << 1;
        $29 = (_memcmp($26,$27,$28)|0);
        $30 = ($29|0)==(0);
        if ($30) {
         $100 = 0;$__ndptr$1 = $__ndptr$07$us;
         break;
        }
       }
       $__ndptr$0$us = HEAP32[$__ndptr$07$us>>2]|0;
       $31 = ($__ndptr$0$us|0)==(0|0);
       if ($31) {
        $__chash$0 = $13;
        break L1;
       } else {
        $__ndptr$07$us = $__ndptr$0$us;
       }
      }
      HEAP32[$agg$result>>2] = $__ndptr$1;
      $99 = (($agg$result) + 4|0);
      HEAP8[$99>>0] = $100;
      STACKTOP = sp;return;
     } else {
      $__ndptr$07 = $__ndptr$06;
      while(1) {
       $32 = (($__ndptr$07) + 4|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = (($33>>>0) % ($4>>>0))&-1;
       $35 = ($34|0)==($13|0);
       if (!($35)) {
        $__chash$0 = $13;
        break L1;
       }
       $36 = (($__ndptr$07) + 8|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($37|0)==($1|0);
       if ($38) {
        $39 = (($__ndptr$07) + 12|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = HEAP32[$17>>2]|0;
        $42 = $1 << 1;
        $43 = (_memcmp($40,$41,$42)|0);
        $44 = ($43|0)==(0);
        if ($44) {
         $100 = 0;$__ndptr$1 = $__ndptr$07;
         break;
        }
       }
       $__ndptr$0 = HEAP32[$__ndptr$07>>2]|0;
       $45 = ($__ndptr$0|0)==(0|0);
       if ($45) {
        $__chash$0 = $13;
        break L1;
       } else {
        $__ndptr$07 = $__ndptr$0;
       }
      }
      HEAP32[$agg$result>>2] = $__ndptr$1;
      $99 = (($agg$result) + 4|0);
      HEAP8[$99>>0] = $100;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $46 = (($this) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 1)|0;
 $49 = (Math_fround(($48>>>0)));
 $50 = (Math_fround(($4>>>0)));
 $51 = (($this) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($50 * $52);
 $54 = $49 > $53;
 $or$cond = $54 | $5;
 do {
  if ($or$cond) {
   $55 = $4 << 1;
   $56 = ($4>>>0)>(2);
   if ($56) {
    $57 = (($4) + -1)|0;
    $58 = $57 & $4;
    $59 = ($58|0)==(0);
    $61 = $59;
   } else {
    $61 = 0;
   }
   $60 = $61&1;
   $62 = $60 | $55;
   $63 = $62 ^ 1;
   $64 = Math_fround($49 / $52);
   $65 = (Math_fround(Math_ceil((Math_fround($64)))));
   $66 = (~~(($65))>>>0);
   $67 = ($63>>>0)<($66>>>0);
   $68 = $67 ? $66 : $63;
   __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE6rehashEj($this,$68);
   $69 = HEAP32[$3>>2]|0;
   $70 = HEAP32[$2>>2]|0;
   $71 = (($69) + -1)|0;
   $72 = $71 & $69;
   $73 = ($72|0)==(0);
   if ($73) {
    $74 = $71 & $70;
    $__bc$0 = $69;$__chash$1 = $74;
    break;
   } else {
    $75 = (($70>>>0) % ($69>>>0))&-1;
    $__bc$0 = $69;$__chash$1 = $75;
    break;
   }
  } else {
   $__bc$0 = $4;$__chash$1 = $__chash$0;
  }
 } while(0);
 $76 = HEAP32[$this>>2]|0;
 $77 = (($76) + ($__chash$1<<2)|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0|0);
 if ($79) {
  $80 = (($this) + 8|0);
  $81 = HEAP32[$80>>2]|0;
  HEAP32[$__nd>>2] = $81;
  HEAP32[$80>>2] = $__nd;
  $82 = HEAP32[$this>>2]|0;
  $83 = (($82) + ($__chash$1<<2)|0);
  HEAP32[$83>>2] = $80;
  $84 = HEAP32[$__nd>>2]|0;
  $85 = ($84|0)==(0|0);
  if (!($85)) {
   $86 = (($84) + 4|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($__bc$0) + -1)|0;
   $89 = $88 & $__bc$0;
   $90 = ($89|0)==(0);
   if ($90) {
    $91 = $87 & $88;
    $95 = $91;
   } else {
    $92 = (($87>>>0) % ($__bc$0>>>0))&-1;
    $95 = $92;
   }
   $93 = HEAP32[$this>>2]|0;
   $94 = (($93) + ($95<<2)|0);
   HEAP32[$94>>2] = $__nd;
  }
 } else {
  $96 = HEAP32[$78>>2]|0;
  HEAP32[$__nd>>2] = $96;
  HEAP32[$78>>2] = $__nd;
 }
 $97 = HEAP32[$46>>2]|0;
 $98 = (($97) + 1)|0;
 HEAP32[$46>>2] = $98;
 $100 = 1;$__ndptr$1 = $__nd;
 HEAP32[$agg$result>>2] = $__ndptr$1;
 $99 = (($agg$result) + 4|0);
 HEAP8[$99>>0] = $100;
 STACKTOP = sp;return;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE6rehashEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)==(1);
 if ($0) {
  $8 = 2;
 } else {
  $1 = (($__n) + -1)|0;
  $2 = $1 & $__n;
  $3 = ($2|0)==(0);
  if ($3) {
   $8 = $__n;
  } else {
   $4 = (__ZNSt3__112__next_primeEj($__n)|0);
   $8 = $4;
  }
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($8>>>0)>($6>>>0);
 if ($7) {
  __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE8__rehashEj($this,$8);
  STACKTOP = sp;return;
 }
 $9 = ($8>>>0)<($6>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = ($6>>>0)>(2);
 if ($10) {
  $11 = (($6) + -1)|0;
  $12 = $11 & $6;
  $13 = ($12|0)==(0);
  $31 = $13;
 } else {
  $31 = 0;
 }
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (Math_fround(($15>>>0)));
 $17 = (($this) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 / $18);
 $20 = (Math_fround(Math_ceil((Math_fround($19)))));
 $21 = (~~(($20))>>>0);
 if ($31) {
  $22 = (($21) + -1)|0;
  $23 = (_llvm_ctlz_i32(($22|0))|0);
  $24 = (32 - ($23))|0;
  $25 = 1 << $24;
  $28 = $25;
 } else {
  $26 = (__ZNSt3__112__next_primeEj($21)|0);
  $28 = $26;
 }
 $27 = ($8>>>0)<($28>>>0);
 $29 = $27 ? $28 : $8;
 $30 = ($29>>>0)<($6>>>0);
 if (!($30)) {
  STACKTOP = sp;return;
 }
 __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE8__rehashEj($this,$29);
 STACKTOP = sp;return;
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE8__rehashEj($this,$__nbc) {
 $this = $this|0;
 $__nbc = $__nbc|0;
 var $$lcssa = 0, $$lcssa$us = 0, $$lcssa5 = 0, $$lcssa6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $94$phi = 0;
 var $95 = 0, $95$phi = 0, $__cp$0 = 0, $__cp$0$in1827 = 0, $__cp$0$in21 = 0, $__cp$0$lcssa2 = 0, $__cp$0$lcssa3 = 0, $__cp$0$us = 0, $__cp$07 = 0, $__cp$0719 = 0, $__cp$071924 = 0, $__cp$071928 = 0, $__cp$0722 = 0, $__cp$08 = 0, $__cp$08$us = 0, $__i$011 = 0, $__phash$0$ph$ph26 = 0, $__pp$0$ph$ph25 = 0, $__pp$0$ph20 = 0, $exitcond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nbc|0)!=(0);
 if ($0) {
  $1 = $__nbc << 2;
  $2 = (__Znwj($1)|0);
  $4 = $2;
 } else {
  $4 = 0;
 }
 $3 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $4;
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  __ZdlPv($3);
 }
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = $__nbc;
 if ($0) {
  $__i$011 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $7 = HEAP32[$this>>2]|0;
  $8 = (($7) + ($__i$011<<2)|0);
  HEAP32[$8>>2] = 0;
  $9 = (($__i$011) + 1)|0;
  $exitcond = ($9|0)==($__nbc|0);
  if ($exitcond) {
   break;
  } else {
   $__i$011 = $9;
  }
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($11) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($__nbc) + -1)|0;
 $16 = $15 & $__nbc;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = $14 & $15;
  $22 = $18;
 } else {
  $19 = (($14>>>0) % ($__nbc>>>0))&-1;
  $22 = $19;
 }
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + ($22<<2)|0);
 HEAP32[$21>>2] = $10;
 $__cp$071924 = HEAP32[$11>>2]|0;
 $23 = ($__cp$071924|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 } else {
  $__cp$0$in1827 = $11;$__cp$071928 = $__cp$071924;$__phash$0$ph$ph26 = $22;$__pp$0$ph$ph25 = $11;
 }
 L21: while(1) {
  $__cp$0$in21 = $__cp$0$in1827;$__cp$0722 = $__cp$071928;$__pp$0$ph20 = $__pp$0$ph$ph25;
  L23: while(1) {
   L25: do {
    if ($17) {
     $__cp$08$us = $__cp$0722;
     while(1) {
      $25 = (($__cp$08$us) + 4|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = $26 & $15;
      $28 = ($27|0)==($__phash$0$ph$ph26|0);
      if ($28) {
       $__cp$0$lcssa2 = $__cp$08$us;
       break L25;
      }
      $29 = HEAP32[$this>>2]|0;
      $30 = (($29) + ($27<<2)|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==(0|0);
      if ($32) {
       $$lcssa5 = $27;$$lcssa6 = $30;$__cp$0$lcssa3 = $__cp$08$us;
       break L23;
      }
      $39 = (($__cp$08$us) + 12|0);
      $56 = HEAP32[$__cp$08$us>>2]|0;
      $57 = ($56|0)==(0|0);
      L30: do {
       if ($57) {
        $$lcssa$us = $__cp$08$us;$47 = 0;
       } else {
        $58 = (($__cp$08$us) + 8|0);
        $37 = HEAP32[$58>>2]|0;
        $42 = $37 << 1;
        $34 = $56;$94 = $__cp$08$us;
        while(1) {
         $33 = (($34) + 8|0);
         $35 = HEAP32[$33>>2]|0;
         $36 = ($37|0)==($35|0);
         if (!($36)) {
          $$lcssa$us = $94;$47 = $34;
          break L30;
         }
         $38 = HEAP32[$39>>2]|0;
         $40 = (($34) + 12|0);
         $41 = HEAP32[$40>>2]|0;
         $43 = (_memcmp($38,$41,$42)|0);
         $44 = ($43|0)==(0);
         if (!($44)) {
          $$lcssa$us = $94;$47 = $34;
          break L30;
         }
         $45 = HEAP32[$34>>2]|0;
         $46 = ($45|0)==(0|0);
         if ($46) {
          $$lcssa$us = $34;$47 = 0;
          break;
         } else {
          $94$phi = $34;$34 = $45;$94 = $94$phi;
         }
        }
       }
      } while(0);
      HEAP32[$__cp$0$in21>>2] = $47;
      $48 = HEAP32[$this>>2]|0;
      $49 = (($48) + ($27<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = HEAP32[$50>>2]|0;
      HEAP32[$$lcssa$us>>2] = $51;
      $52 = HEAP32[$this>>2]|0;
      $53 = (($52) + ($27<<2)|0);
      $54 = HEAP32[$53>>2]|0;
      HEAP32[$54>>2] = $__cp$08$us;
      $__cp$0$us = HEAP32[$__cp$0$in21>>2]|0;
      $55 = ($__cp$0$us|0)==(0|0);
      if ($55) {
       label = 32;
       break L21;
      } else {
       $__cp$08$us = $__cp$0$us;
      }
     }
    } else {
     $__cp$08 = $__cp$0722;
     while(1) {
      $59 = (($__cp$08) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = (($60>>>0) % ($__nbc>>>0))&-1;
      $62 = ($61|0)==($__phash$0$ph$ph26|0);
      if ($62) {
       $__cp$0$lcssa2 = $__cp$08;
       break L25;
      }
      $63 = HEAP32[$this>>2]|0;
      $64 = (($63) + ($61<<2)|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = ($65|0)==(0|0);
      if ($66) {
       $$lcssa5 = $61;$$lcssa6 = $64;$__cp$0$lcssa3 = $__cp$08;
       break L23;
      }
      $67 = (($__cp$08) + 12|0);
      $68 = HEAP32[$__cp$08>>2]|0;
      $69 = ($68|0)==(0|0);
      L41: do {
       if ($69) {
        $$lcssa = $__cp$08;$85 = 0;
       } else {
        $70 = (($__cp$08) + 8|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = $71 << 1;
        $75 = $68;$95 = $__cp$08;
        while(1) {
         $74 = (($75) + 8|0);
         $76 = HEAP32[$74>>2]|0;
         $77 = ($71|0)==($76|0);
         if (!($77)) {
          $$lcssa = $95;$85 = $75;
          break L41;
         }
         $78 = HEAP32[$67>>2]|0;
         $79 = (($75) + 12|0);
         $80 = HEAP32[$79>>2]|0;
         $81 = (_memcmp($78,$80,$72)|0);
         $82 = ($81|0)==(0);
         if (!($82)) {
          $$lcssa = $95;$85 = $75;
          break L41;
         }
         $83 = HEAP32[$75>>2]|0;
         $84 = ($83|0)==(0|0);
         if ($84) {
          $$lcssa = $75;$85 = 0;
          break;
         } else {
          $95$phi = $75;$75 = $83;$95 = $95$phi;
         }
        }
       }
      } while(0);
      HEAP32[$__cp$0$in21>>2] = $85;
      $86 = HEAP32[$this>>2]|0;
      $87 = (($86) + ($61<<2)|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = HEAP32[$88>>2]|0;
      HEAP32[$$lcssa>>2] = $89;
      $90 = HEAP32[$this>>2]|0;
      $91 = (($90) + ($61<<2)|0);
      $92 = HEAP32[$91>>2]|0;
      HEAP32[$92>>2] = $__cp$08;
      $__cp$0 = HEAP32[$__cp$0$in21>>2]|0;
      $93 = ($__cp$0|0)==(0|0);
      if ($93) {
       label = 32;
       break L21;
      } else {
       $__cp$08 = $__cp$0;
      }
     }
    }
   } while(0);
   $__cp$07 = HEAP32[$__cp$0$lcssa2>>2]|0;
   $24 = ($__cp$07|0)==(0|0);
   if ($24) {
    label = 32;
    break L21;
   } else {
    $__cp$0$in21 = $__cp$0$lcssa2;$__cp$0722 = $__cp$07;$__pp$0$ph20 = $__cp$0$lcssa2;
   }
  }
  HEAP32[$$lcssa6>>2] = $__pp$0$ph20;
  $__cp$0719 = HEAP32[$__cp$0$lcssa3>>2]|0;
  $73 = ($__cp$0719|0)==(0|0);
  if ($73) {
   label = 32;
   break;
  } else {
   $__cp$0$in1827 = $__cp$0$lcssa3;$__cp$071928 = $__cp$0719;$__phash$0$ph$ph26 = $$lcssa5;$__pp$0$ph$ph25 = $__cp$0$lcssa3;
  }
 }
 if ((label|0) == 32) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE4findIS4_EENS_15__hash_iteratorIPNS_11__hash_nodeIS7_PvEEEERKT_($agg$result,$this,$__k) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__k = $__k|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0 = 0, $__nd$0$lcssa2 = 0, $__nd$0$us = 0, $__nd$04 = 0, $__nd$05 = 0, $__nd$05$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__k>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = (($2) + -1)|0;
   $5 = $4 & $2;
   $6 = ($5|0)==(0);
   if ($6) {
    $7 = $4 & $0;
    $11 = $7;
   } else {
    $8 = (($0>>>0) % ($2>>>0))&-1;
    $11 = $8;
   }
   $9 = HEAP32[$this>>2]|0;
   $10 = (($9) + ($11<<2)|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $__nd$04 = HEAP32[$12>>2]|0;
    $14 = ($__nd$04|0)==(0|0);
    if (!($14)) {
     $15 = (($__k) + 4|0);
     L9: do {
      if ($6) {
       $__nd$05$us = $__nd$04;
       while(1) {
        $16 = (($__nd$05$us) + 4|0);
        $17 = HEAP32[$16>>2]|0;
        $18 = $17 & $4;
        $19 = ($18|0)==($11|0);
        if (!($19)) {
         break L1;
        }
        $20 = (($__nd$05$us) + 8|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)==($0|0);
        if ($22) {
         $23 = (($__nd$05$us) + 12|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = HEAP32[$15>>2]|0;
         $26 = $0 << 1;
         $27 = (_memcmp($24,$25,$26)|0);
         $28 = ($27|0)==(0);
         if ($28) {
          $__nd$0$lcssa2 = $__nd$05$us;
          break L9;
         }
        }
        $__nd$0$us = HEAP32[$__nd$05$us>>2]|0;
        $29 = ($__nd$0$us|0)==(0|0);
        if ($29) {
         break L1;
        } else {
         $__nd$05$us = $__nd$0$us;
        }
       }
      } else {
       $__nd$05 = $__nd$04;
       while(1) {
        $30 = (($__nd$05) + 4|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = (($31>>>0) % ($2>>>0))&-1;
        $33 = ($32|0)==($11|0);
        if (!($33)) {
         break L1;
        }
        $34 = (($__nd$05) + 8|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = ($35|0)==($0|0);
        if ($36) {
         $37 = (($__nd$05) + 12|0);
         $38 = HEAP32[$37>>2]|0;
         $39 = HEAP32[$15>>2]|0;
         $40 = $0 << 1;
         $41 = (_memcmp($38,$39,$40)|0);
         $42 = ($41|0)==(0);
         if ($42) {
          $__nd$0$lcssa2 = $__nd$05;
          break L9;
         }
        }
        $__nd$0 = HEAP32[$__nd$05>>2]|0;
        $43 = ($__nd$0|0)==(0|0);
        if ($43) {
         break L1;
        } else {
         $__nd$05 = $__nd$0;
        }
       }
      }
     } while(0);
     HEAP32[$agg$result>>2] = $__nd$0$lcssa2;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 HEAP32[$agg$result>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm6Thread4InitEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm6Thread6AttachEP12Il2CppDomain($domain) {
 $domain = $domain|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $temp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $temp$i = sp;
 HEAP32[$temp$i>>2] = 0;
 (__ZN6il2cpp2os16ThreadLocalValue8GetValueEPPv(389912,$temp$i)|0);
 $0 = HEAP32[$temp$i>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP32[((388944 + 124|0))>>2]|0;
 $3 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo($2)|0);
 (__ZN6il2cpp2gc8GCHandle3NewEP12Il2CppObjectb($3,1)|0);
 HEAP32[$temp$i>>2] = 0;
 $4 = (__Znwj(8)|0);
 __THREW__ = 0;
 invoke_vii(2484,($4|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZdlPv($4);
  ___resumeException($7|0);
  // unreachable;
 }
 $9 = (($3) + 108|0);
 HEAP32[$9>>2] = $4;
 (__ZN6il2cpp2os16ThreadLocalValue8SetValueEPv(389912,$3)|0);
 __ZN6il2cpp2vm6Thread8RegisterEP12Il2CppThread($3);
 __ZN6il2cpp2vm6Thread16AdjustStaticDataEv();
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm6Thread7CurrentEv() {
 var $0 = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp;
 HEAP32[$value>>2] = 0;
 (__ZN6il2cpp2os16ThreadLocalValue8GetValueEPPv(389912,$value)|0);
 $0 = HEAP32[$value>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN6il2cpp2vm6Thread10InitializeEP12Il2CppThread($thread) {
 $thread = $thread|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $temp = sp;
 HEAP32[$temp>>2] = 0;
 $0 = (__Znwj(8)|0);
 __THREW__ = 0;
 invoke_vii(2484,($0|0),0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($thread) + 108|0);
  HEAP32[$3>>2] = $0;
  (__ZN6il2cpp2os16ThreadLocalValue8SetValueEPv(389912,$thread)|0);
  __ZN6il2cpp2vm6Thread8RegisterEP12Il2CppThread($thread);
  __ZN6il2cpp2vm6Thread16AdjustStaticDataEv();
  STACKTOP = sp;return;
 }
}
function __ZN6il2cpp2vm6Thread8RegisterEP12Il2CppThread($thread) {
 $thread = $thread|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2os5Mutex4LockEv(389880);
 $0 = HEAP32[389864>>2]|0;
 $1 = HEAP32[389872>>2]|0;
 $2 = ($0|0)==($1|0);
 if (!($2)) {
  $3 = ($0|0)==(0|0);
  if ($3) {
   $5 = 0;
  } else {
   HEAP32[$0>>2] = $thread;
   $$pre$i = HEAP32[389864>>2]|0;
   $5 = $$pre$i;
  }
  $4 = (($5) + 4|0);
  HEAP32[389864>>2] = $4;
  __ZN6il2cpp2os5Mutex6UnlockEv(389880);
  STACKTOP = sp;return;
 }
 $6 = HEAP32[389856>>2]|0;
 $7 = $0;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = (($10) + 1)|0;
 $12 = ($11>>>0)>(1073741823);
 do {
  if ($12) {
   __THREW__ = 0;
   invoke_vi(3308,0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    // unreachable;
   }
  } else {
   $15 = ($10>>>0)<(536870911);
   if ($15) {
    $16 = $9 >> 1;
    $17 = ($16>>>0)<($11>>>0);
    $18 = $17 ? $11 : $16;
    $19 = ($18|0)==(0);
    if ($19) {
     $$0$i3$i$i = 0;$25 = 0;
    } else {
     $$0$i2$i$i = $18;
     label = 10;
    }
   } else {
    $$0$i2$i$i = 1073741823;
    label = 10;
   }
   if ((label|0) == 10) {
    $20 = $$0$i2$i$i << 2;
    __THREW__ = 0;
    $21 = (invoke_ii(2988,($20|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $$0$i3$i$i = $$0$i2$i$i;$25 = $21;
   }
   $24 = (($25) + ($10<<2)|0);
   $26 = (($25) + ($$0$i3$i$i<<2)|0);
   $27 = ($24|0)==(0|0);
   if (!($27)) {
    HEAP32[$24>>2] = $thread;
   }
   $28 = (($25) + ($11<<2)|0);
   _memcpy(($25|0),($6|0),($9|0))|0;
   HEAP32[389856>>2] = $25;
   HEAP32[389864>>2] = $28;
   HEAP32[389872>>2] = $26;
   $29 = ($6|0)==(0|0);
   if ($29) {
    __ZN6il2cpp2os5Mutex6UnlockEv(389880);
    STACKTOP = sp;return;
   }
   __ZdlPv($6);
   __ZN6il2cpp2os5Mutex6UnlockEv(389880);
   STACKTOP = sp;return;
  }
 } while(0);
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3365,(389880|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch(0|0)|0;
  $35 = tempRet0;
  ___clang_call_terminate($34);
  // unreachable;
 } else {
  ___resumeException($30|0);
  // unreachable;
 }
}
function __ZN6il2cpp2vm6Thread16AdjustStaticDataEv() {
 var $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$02 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $value$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i = sp;
 __ZN6il2cpp2os5Mutex4LockEv(389880);
 HEAP32[$value$i>>2] = 0;
 __THREW__ = 0;
 (invoke_iii(2338,(389912|0),($value$i|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if ($1) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   $lpad$phi$index = $9;$lpad$phi$index2 = $10;
  } else {
   $2 = HEAP32[$value$i>>2]|0;
   $3 = (($2) + 64|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    $6 = (_calloc(2048,4)|0);
    HEAP32[$3>>2] = $6;
    $33 = $6;
   } else {
    $33 = $4;
   }
   $13 = HEAP32[389888>>2]|0;
   $14 = HEAP32[389896>>2]|0;
   $15 = ($13|0)==($14|0);
   if ($15) {
    __ZN6il2cpp2os5Mutex6UnlockEv(389880);
    STACKTOP = sp;return;
   } else {
    $17 = $33;$21 = $13;$34 = $14;$index$02 = 0;
   }
   while(1) {
    $16 = (($17) + ($index$02<<2)|0);
    $18 = HEAP32[$16>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $20 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     $22 = (invoke_iii(2339,($20|0),(0|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 4;
      break;
     }
     $25 = HEAP32[$3>>2]|0;
     $26 = (($25) + ($index$02<<2)|0);
     HEAP32[$26>>2] = $22;
     $$pre = HEAP32[389896>>2]|0;
     $29 = $$pre;
    } else {
     $29 = $34;
    }
    $27 = (($21) + 4|0);
    $28 = ($27|0)==($29|0);
    if ($28) {
     label = 13;
     break;
    }
    $30 = (($index$02) + 1)|0;
    $$pre4 = HEAP32[$3>>2]|0;
    $17 = $$pre4;$21 = $27;$34 = $29;$index$02 = $30;
   }
   if ((label|0) == 4) {
    $7 = ___cxa_find_matching_catch()|0;
    $8 = tempRet0;
    $lpad$phi$index = $7;$lpad$phi$index2 = $8;
    break;
   }
   else if ((label|0) == 13) {
    __ZN6il2cpp2os5Mutex6UnlockEv(389880);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3365,(389880|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $31 = ___cxa_find_matching_catch(0|0)|0;
  $32 = tempRet0;
  ___clang_call_terminate($31);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN6il2cpp2vm6Thread12UninitializeEP12Il2CppThread($thread) {
 $thread = $thread|0;
 var $$lcssa3$i = 0, $$pre$i = 0, $$pre8$i = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $index$05$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2os5Mutex4LockEv(389880);
 $0 = HEAP32[389856>>2]|0;
 $1 = HEAP32[389864>>2]|0;
 $2 = ($0|0)==($1|0);
 L1: do {
  if ($2) {
   $9 = $0;
  } else {
   $4 = $0;
   while(1) {
    $3 = HEAP32[$4>>2]|0;
    $5 = ($3|0)==($thread|0);
    if ($5) {
     $9 = $4;
     break L1;
    }
    $6 = (($4) + 4|0);
    $7 = ($6|0)==($1|0);
    if ($7) {
     $9 = $1;
     break;
    } else {
     $4 = $6;
    }
   }
  }
 } while(0);
 $8 = $9;
 $10 = $0;
 $11 = (($8) - ($10))|0;
 $12 = $11 >> 2;
 $13 = (($0) + ($12<<2)|0);
 $$sum$i$i = (($12) + 1)|0;
 $14 = (($0) + ($$sum$i$i<<2)|0);
 $15 = $1;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = $17 >> 2;
 _memmove(($13|0),($14|0),($17|0))|0;
 $$sum1$i$i = (($18) + ($12))|0;
 $19 = (($0) + ($$sum1$i$i<<2)|0);
 $20 = HEAP32[389864>>2]|0;
 $21 = ($20|0)==($19|0);
 if (!($21)) {
  $__new_last2$i$i$i$i = $19;
  $scevgep$i$i$i$i = (($20) + -4|0);
  $22 = (0 - ($__new_last2$i$i$i$i))|0;
  $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($22)|0);
  $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
  $23 = $uglygep3$i$i$i$i >>> 2;
  $24 = $23 ^ -1;
  $scevgep4$i$i$i$i = (($20) + ($24<<2)|0);
  HEAP32[389864>>2] = $scevgep4$i$i$i$i;
 }
 __ZN6il2cpp2os5Mutex6UnlockEv(389880);
 __ZN6il2cpp2os5Mutex4LockEv(389880);
 $25 = HEAP32[389888>>2]|0;
 $26 = HEAP32[389896>>2]|0;
 $27 = ($25|0)==($26|0);
 $28 = (($thread) + 64|0);
 $29 = HEAP32[$28>>2]|0;
 if ($27) {
  $$lcssa3$i = $29;
  _free($$lcssa3$i);
  HEAP32[$28>>2] = 0;
  __ZN6il2cpp2os5Mutex6UnlockEv(389880);
  __ZN6il2cpp2vm14MethodStackMap18ClearStackFrameForEP12Il2CppThread(389920,$thread);
  (__ZN6il2cpp2os16ThreadLocalValue8SetValueEPv(389912,0)|0);
  STACKTOP = sp;return;
 } else {
  $31 = $29;$42 = $25;$47 = $26;$index$05$i = 0;
 }
 while(1) {
  $30 = (($31) + ($index$05$i<<2)|0);
  $32 = HEAP32[$30>>2]|0;
  $33 = ($32|0)==(0|0);
  if ($33) {
   $44 = $47;$48 = $31;
  } else {
   __THREW__ = 0;
   invoke_vi(3303,($32|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    break;
   }
   $$pre$i = HEAP32[389896>>2]|0;
   $$pre8$i = HEAP32[$28>>2]|0;
   $44 = $$pre$i;$48 = $$pre8$i;
  }
  $40 = (($index$05$i) + 1)|0;
  $41 = (($42) + 4|0);
  $43 = ($41|0)==($44|0);
  if ($43) {
   $$lcssa3$i = $48;
   label = 14;
   break;
  } else {
   $31 = $48;$42 = $41;$47 = $44;$index$05$i = $40;
  }
 }
 if ((label|0) == 14) {
  _free($$lcssa3$i);
  HEAP32[$28>>2] = 0;
  __ZN6il2cpp2os5Mutex6UnlockEv(389880);
  __ZN6il2cpp2vm14MethodStackMap18ClearStackFrameForEP12Il2CppThread(389920,$thread);
  (__ZN6il2cpp2os16ThreadLocalValue8SetValueEPv(389912,0)|0);
  STACKTOP = sp;return;
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3365,(389880|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $45 = ___cxa_find_matching_catch(0|0)|0;
  $46 = tempRet0;
  ___clang_call_terminate($45);
  // unreachable;
 } else {
  ___resumeException($36|0);
  // unreachable;
 }
}
function __ZN6il2cpp2vm14MethodStackMap18ClearStackFrameForEP12Il2CppThread($this,$thread) {
 $this = $this|0;
 $thread = $thread|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$i$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $thread;
 __ZN6il2cpp2os5Mutex4LockEv($this);
 $1 = (($this) + 8|0);
 __THREW__ = 0;
 $2 = (invoke_iii(2340,($1|0),($0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $47 = ___cxa_find_matching_catch()|0;
  $48 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3365,($this|0));
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if ($50) {
   $51 = ___cxa_find_matching_catch(0|0)|0;
   $52 = tempRet0;
   ___clang_call_terminate($51);
   // unreachable;
  } else {
   ___resumeException($47|0);
   // unreachable;
  }
 }
 $5 = HEAP32[$2>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (($5) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($7|0);
   if (!($11)) {
    $__new_last2$i$i$i$i$i = $7;
    $scevgep$i$i$i$i$i = (($10) + -4|0);
    $12 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($12)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $13 = $uglygep3$i$i$i$i$i >>> 2;
    $14 = $13 ^ -1;
    $scevgep4$i$i$i$i$i = (($10) + ($14<<2)|0);
    HEAP32[$9>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($7);
  }
  __ZdlPv($5);
 }
 $15 = (($this) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 12|0);
 $18 = ($16|0)==(0|0);
 if ($18) {
  label = 16;
 } else {
  $19 = HEAP32[$0>>2]|0;
  $$0$ph7$i$i$i = $17;$$01$ph6$i$in$i$i = $16;
  L18: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $20 = (($$013$i$in$i$i) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21>>>0)<($19>>>0);
    if (!($22)) {
     break;
    }
    $25 = (($$013$i$in$i$i) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L18;
    } else {
     $$013$i$in$i$i = $26;
    }
   }
   $23 = HEAP32[$$013$i$in$i$i>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $23;
   }
  }
  $28 = ($$0$ph5$i$i$i|0)==($17|0);
  if ($28) {
   label = 16;
  } else {
   $29 = (($$0$ph5$i$i$i) + 16|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($19>>>0)<($30>>>0);
   if ($31) {
    label = 16;
   } else {
    $33 = $$0$ph5$i$i$i;
   }
  }
 }
 if ((label|0) == 16) {
  $33 = $17;
 }
 $32 = (($33) + 4|0);
 $34 = HEAP32[$32>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $$01$i$i$i$i = $33;
  while(1) {
   $38 = (($$01$i$i$i$i) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==($$01$i$i$i$i|0);
   if ($41) {
    $$0$i$i$i$i = $39;
    break;
   } else {
    $$01$i$i$i$i = $39;
   }
  }
 } else {
  $$0$i$i$i$i$i = $34;
  while(1) {
   $36 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    $$0$i$i$i$i = $$0$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i = $36;
   }
  }
 }
 $42 = HEAP32[$1>>2]|0;
 $43 = ($42|0)==($33|0);
 if (!($43)) {
  $44 = (($this) + 16|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + -1)|0;
  HEAP32[$44>>2] = $46;
  __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($16,$33);
  __ZdlPv($33);
  __ZN6il2cpp2os5Mutex6UnlockEv($this);
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $$0$i$i$i$i;
 $44 = (($this) + 16|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + -1)|0;
 HEAP32[$44>>2] = $46;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($16,$33);
 __ZdlPv($33);
 __ZN6il2cpp2os5Mutex6UnlockEv($this);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm6Thread4MainEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN6il2cpp2vm6Thread8SetStateEP12Il2CppThreadNS0_11ThreadStateE($thread,$value) {
 $thread = $thread|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($thread) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2os5Mutex4LockEv($1);
 $2 = (($thread) + 36|0);
 HEAP32[$2>>2] = $value;
 __ZN6il2cpp2os5Mutex6UnlockEv($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm6Thread8ClrStateEP12Il2CppThreadNS0_11ThreadStateE($thread,$state) {
 $thread = $thread|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($thread) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6il2cpp2os5Mutex4LockEv($1);
 $2 = $state ^ -1;
 $3 = (($thread) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & $2;
 HEAP32[$3>>2] = $5;
 __ZN6il2cpp2os5Mutex6UnlockEv($1);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm6Thread21AllocThreadStaticDataEi($size) {
 $size = $size|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2os5Mutex4LockEv(389880);
 $0 = HEAP32[389896>>2]|0;
 $1 = HEAP32[389888>>2]|0;
 $2 = $0;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = HEAP32[389904>>2]|0;
 $7 = ($0|0)==($6|0);
 L1: do {
  if ($7) {
   $10 = (($5) + 1)|0;
   $11 = ($10>>>0)>(1073741823);
   do {
    if ($11) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    } else {
     $14 = ($5>>>0)<(536870911);
     if ($14) {
      $15 = $4 >> 1;
      $16 = ($15>>>0)<($10>>>0);
      $17 = $16 ? $10 : $15;
      $18 = ($17|0)==(0);
      if ($18) {
       $$0$i3$i$i = 0;$24 = 0;
      } else {
       $$0$i2$i$i = $17;
       label = 10;
      }
     } else {
      $$0$i2$i$i = 1073741823;
      label = 10;
     }
     if ((label|0) == 10) {
      $19 = $$0$i2$i$i << 2;
      __THREW__ = 0;
      $20 = (invoke_ii(2988,($19|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      $$0$i3$i$i = $$0$i2$i$i;$24 = $20;
     }
     $23 = (($24) + ($5<<2)|0);
     $25 = (($24) + ($$0$i3$i$i<<2)|0);
     $26 = ($23|0)==(0|0);
     if (!($26)) {
      HEAP32[$23>>2] = $size;
     }
     $27 = (($24) + ($10<<2)|0);
     _memcpy(($24|0),($1|0),($4|0))|0;
     HEAP32[389888>>2] = $24;
     HEAP32[389896>>2] = $27;
     HEAP32[389904>>2] = $25;
     $28 = ($1|0)==(0|0);
     if ($28) {
      label = 16;
      break L1;
     }
     __ZdlPv($1);
     label = 16;
     break L1;
    }
   } while(0);
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $lpad$phi$index = $40;$lpad$phi$index2 = $41;
  } else {
   $8 = ($0|0)==(0|0);
   if (!($8)) {
    HEAP32[$0>>2] = $size;
   }
   $9 = (($0) + 4|0);
   HEAP32[389896>>2] = $9;
   label = 16;
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   $29 = HEAP32[389856>>2]|0;
   $30 = HEAP32[389864>>2]|0;
   $31 = ($29|0)==($30|0);
   if ($31) {
    __ZN6il2cpp2os5Mutex6UnlockEv(389880);
    STACKTOP = sp;return ($5|0);
   } else {
    $33 = $29;
   }
   while(1) {
    $32 = HEAP32[$33>>2]|0;
    $34 = (($32) + 64|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==(0|0);
    if ($36) {
     $37 = (_calloc(2048,4)|0);
     HEAP32[$34>>2] = $37;
    }
    __THREW__ = 0;
    $44 = (invoke_iii(2339,($size|0),(0|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     label = 19;
     break;
    }
    $47 = HEAP32[$34>>2]|0;
    $48 = (($47) + ($5<<2)|0);
    HEAP32[$48>>2] = $44;
    $49 = (($33) + 4|0);
    $50 = HEAP32[389864>>2]|0;
    $51 = ($49|0)==($50|0);
    if ($51) {
     label = 24;
     break;
    } else {
     $33 = $49;
    }
   }
   if ((label|0) == 19) {
    $38 = ___cxa_find_matching_catch()|0;
    $39 = tempRet0;
    $lpad$phi$index = $38;$lpad$phi$index2 = $39;
    break;
   }
   else if ((label|0) == 24) {
    __ZN6il2cpp2os5Mutex6UnlockEv(389880);
    STACKTOP = sp;return ($5|0);
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3365,(389880|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $52 = ___cxa_find_matching_catch(0|0)|0;
  $53 = tempRet0;
  ___clang_call_terminate($52);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN6il2cpp2vm6Thread19GetThreadStaticDataEi($offset) {
 $offset = $offset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $value$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i = sp;
 HEAP32[$value$i>>2] = 0;
 (__ZN6il2cpp2os16ThreadLocalValue8GetValueEPPv(389912,$value$i)|0);
 $0 = HEAP32[$value$i>>2]|0;
 $1 = (($0) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($offset<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN6il2cpp2vm6Thread9PushFrameEP12Il2CppThreadR20Il2CppStackFrameInfo($thread,$info) {
 $thread = $thread|0;
 $info = $info|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm14MethodStackMap17PushStackFrameForEP12Il2CppThreadRK20Il2CppStackFrameInfo(389920,$thread,$info);
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm14MethodStackMap17PushStackFrameForEP12Il2CppThreadRK20Il2CppStackFrameInfo($this,$thread,$info) {
 $this = $this|0;
 $thread = $thread|0;
 $info = $info|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $thread;
 __ZN6il2cpp2os5Mutex4LockEv($this);
 $1 = (($this) + 8|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 12|0);
 $5 = ($3|0)==(0|0);
 if ($5) {
  label = 8;
 } else {
  $$0$ph7$i$i$i = $4;$$01$ph6$i$in$i$i = $3;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $6 = (($$013$i$in$i$i) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7>>>0)<($thread>>>0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($4|0);
  if ($14) {
   label = 8;
  } else {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16>>>0)>($thread>>>0);
   if ($17) {
    label = 8;
   } else {
    label = 11;
   }
  }
 }
 if ((label|0) == 8) {
  __THREW__ = 0;
  $18 = (invoke_ii(2988,12)|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   HEAP32[$18>>2] = 0;
   $21 = (($18) + 4|0);
   HEAP32[$21>>2] = 0;
   $22 = (($18) + 8|0);
   HEAP32[$22>>2] = 0;
   __THREW__ = 0;
   $23 = (invoke_iii(2340,($1|0),($0|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    HEAP32[$23>>2] = $18;
    label = 11;
   }
  }
 }
 do {
  if ((label|0) == 11) {
   __THREW__ = 0;
   $26 = (invoke_iii(2340,($1|0),($0|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[$26>>2]|0;
    $30 = (($29) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($31|0)==($33|0);
    if (!($34)) {
     $35 = ($31|0)==(0|0);
     if ($35) {
      $38 = 0;
     } else {
      $36 = HEAP32[$info>>2]|0;
      HEAP32[$31>>2] = $36;
      $$pre$i = HEAP32[$30>>2]|0;
      $38 = $$pre$i;
     }
     $37 = (($38) + 4|0);
     HEAP32[$30>>2] = $37;
     __ZN6il2cpp2os5Mutex6UnlockEv($this);
     STACKTOP = sp;return;
    }
    $39 = HEAP32[$29>>2]|0;
    $40 = $31;
    $41 = $39;
    $42 = (($40) - ($41))|0;
    $43 = $42 >> 2;
    $44 = (($43) + 1)|0;
    $45 = ($44>>>0)>(1073741823);
    if ($45) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     // unreachable;
    }
    $48 = ($43>>>0)<(536870911);
    if ($48) {
     $49 = $42 >> 1;
     $50 = ($49>>>0)<($44>>>0);
     $51 = $50 ? $44 : $49;
     $52 = ($51|0)==(0);
     if ($52) {
      $$0$i3$i$i = 0;$58 = 0;
     } else {
      $$0$i2$i$i = $51;
      label = 21;
     }
    } else {
     $$0$i2$i$i = 1073741823;
     label = 21;
    }
    if ((label|0) == 21) {
     $53 = $$0$i2$i$i << 2;
     __THREW__ = 0;
     $54 = (invoke_ii(2988,($53|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     $$0$i3$i$i = $$0$i2$i$i;$58 = $54;
    }
    $57 = (($58) + ($43<<2)|0);
    $59 = (($58) + ($$0$i3$i$i<<2)|0);
    $60 = ($57|0)==(0|0);
    if (!($60)) {
     $61 = HEAP32[$info>>2]|0;
     HEAP32[$57>>2] = $61;
    }
    $62 = (($58) + ($44<<2)|0);
    _memcpy(($58|0),($39|0),($42|0))|0;
    HEAP32[$29>>2] = $58;
    HEAP32[$30>>2] = $62;
    HEAP32[$32>>2] = $59;
    $63 = ($39|0)==(0|0);
    if ($63) {
     __ZN6il2cpp2os5Mutex6UnlockEv($this);
     STACKTOP = sp;return;
    }
    __ZdlPv($39);
    __ZN6il2cpp2os5Mutex6UnlockEv($this);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $64 = ___cxa_find_matching_catch()|0;
 $65 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3365,($this|0));
 $66 = __THREW__; __THREW__ = 0;
 $67 = $66&1;
 if ($67) {
  $68 = ___cxa_find_matching_catch(0|0)|0;
  $69 = tempRet0;
  ___clang_call_terminate($68);
  // unreachable;
 } else {
  ___resumeException($64|0);
  // unreachable;
 }
}
function __ZN6il2cpp2vm6Thread8PopFrameEP12Il2CppThread($thread) {
 $thread = $thread|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0;
 var $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $thread;
 __ZN6il2cpp2os5Mutex4LockEv(389920);
 __THREW__ = 0;
 (invoke_iii(2340,(((389920 + 8|0))|0),($0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2340,(((389920 + 8|0))|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $12 = HEAP32[$3>>2]|0;
   $13 = (($12) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + -4|0);
   $__new_last2$i$i$i$i = $15;
   $scevgep$i$i$i$i = (($14) + -4|0);
   $16 = (0 - ($__new_last2$i$i$i$i))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($16)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $17 = $uglygep3$i$i$i$i >>> 2;
   $18 = $17 ^ -1;
   $scevgep4$i$i$i$i = (($14) + ($18<<2)|0);
   HEAP32[$13>>2] = $scevgep4$i$i$i$i;
   __ZN6il2cpp2os5Mutex6UnlockEv(389920);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3365,(389920|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
}
function __ZN6il2cpp2vm6Thread14GetStackFramesEP12Il2CppThread($thread) {
 $thread = $thread|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $thread;
 __ZN6il2cpp2os5Mutex4LockEv(389920);
 __THREW__ = 0;
 $1 = (invoke_iii(2340,(((389920 + 8|0))|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $10 = HEAP32[$1>>2]|0;
  __ZN6il2cpp2os5Mutex6UnlockEv(389920);
  STACKTOP = sp;return ($10|0);
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3365,(389920|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__13mapIP12Il2CppThreadPNS_6vectorI20Il2CppStackFrameInfoNS_9allocatorIS4_EEEENS_4lessIS2_EENS5_INS_4pairIKS2_S8_EEEEEixERSC_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$22 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3>>>0)<($5>>>0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5>>>0)<($3>>>0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $31 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($31|0);
 }
 $16 = (__Znwj(24)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$16>>2] = 0;
 $20 = (($16) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $16;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $16;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $__r$0 = $16;
 $31 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($31|0);
}
function __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($__root,$__z) {
 $__root = $__root|0;
 $__z = $__z|0;
 var $$$0 = 0, $$0 = 0, $$0$i$i = 0, $$1 = 0, $$2 = 0, $$2$be = 0, $$4 = 0, $$6 = 0, $$in = 0, $$in1 = 0, $$in2 = 0, $$lcssa18 = 0, $$phi$trans$insert35 = 0, $$pre = 0, $$pre23 = 0, $$pre24 = 0, $$pre37 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__w$0 = 0, $__w$1 = 0, $__w$1$$2 = 0, $__w$1$$23 = 0, $__w$1$be = 0, $__w$1$be$in = 0, $__w$2 = 0, $__w$3 = 0, $__w$4 = 0, $__w$5 = 0, $or$cond = 0, $or$cond8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__z>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $10 = $__z;$8 = 0;
 } else {
  $2 = (($__z) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $10 = $__z;$8 = $0;
  } else {
   $$0$i$i = $3;
   while(1) {
    $5 = HEAP32[$$0$i$i>>2]|0;
    $6 = ($5|0)==(0|0);
    if ($6) {
     $10 = $$0$i$i;$8 = 0;
     break;
    } else {
     $$0$i$i = $5;
    }
   }
  }
 }
 $7 = ($8|0)==(0|0);
 $9 = (($10) + 4|0);
 $$in = $7 ? $9 : $10;
 $11 = HEAP32[$$in>>2]|0;
 $12 = ($11|0)==(0|0);
 $$pre37 = (($10) + 8|0);
 if (!($12)) {
  $13 = HEAP32[$$pre37>>2]|0;
  $14 = (($11) + 8|0);
  HEAP32[$14>>2] = $13;
 }
 $15 = HEAP32[$$pre37>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==($10|0);
 if ($17) {
  HEAP32[$15>>2] = $11;
  $18 = ($10|0)==($__root|0);
  if ($18) {
   $$0 = $11;$__w$0 = 0;
  } else {
   $19 = HEAP32[$$pre37>>2]|0;
   $20 = (($19) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $$0 = $__root;$__w$0 = $21;
  }
 } else {
  $22 = (($15) + 4|0);
  HEAP32[$22>>2] = $11;
  $23 = HEAP32[$$pre37>>2]|0;
  $24 = HEAP32[$23>>2]|0;
  $$0 = $__root;$__w$0 = $24;
 }
 $25 = (($10) + 12|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = ($26<<24>>24)==(0);
 $28 = ($10|0)==($__z|0);
 if ($28) {
  $$1 = $$0;
 } else {
  $29 = (($__z) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$$pre37>>2] = $30;
  $31 = HEAP32[$29>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==($__z|0);
  if ($33) {
   HEAP32[$30>>2] = $10;
  } else {
   $34 = (($30) + 4|0);
   HEAP32[$34>>2] = $10;
  }
  $35 = HEAP32[$__z>>2]|0;
  HEAP32[$10>>2] = $35;
  $36 = (($35) + 8|0);
  HEAP32[$36>>2] = $10;
  $37 = (($__z) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$9>>2] = $38;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   $40 = (($38) + 8|0);
   HEAP32[$40>>2] = $10;
  }
  $41 = (($__z) + 12|0);
  $42 = HEAP8[$41>>0]|0;
  HEAP8[$25>>0] = $42;
  $43 = ($$0|0)==($__z|0);
  $$$0 = $43 ? $10 : $$0;
  $$1 = $$$0;
 }
 $44 = ($$1|0)==(0|0);
 $or$cond8 = $27 | $44;
 if ($or$cond8) {
  STACKTOP = sp;return;
 }
 if ($12) {
  $$2 = $$1;$__w$1 = $__w$0;
 } else {
  $45 = (($11) + 12|0);
  HEAP8[$45>>0] = 1;
  STACKTOP = sp;return;
 }
 while(1) {
  $46 = (($__w$1) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==($__w$1|0);
  $50 = (($__w$1) + 12|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = ($51<<24>>24)!=(0);
  if ($49) {
   if ($52) {
    $$6 = $$2;$__w$4 = $__w$1;
   } else {
    HEAP8[$50>>0] = 1;
    $131 = (($47) + 12|0);
    HEAP8[$131>>0] = 0;
    $132 = (($__w$1) + 4|0);
    $133 = HEAP32[$132>>2]|0;
    HEAP32[$47>>2] = $133;
    $134 = ($133|0)==(0|0);
    if (!($134)) {
     $135 = (($133) + 8|0);
     HEAP32[$135>>2] = $47;
    }
    $136 = (($47) + 8|0);
    $137 = HEAP32[$136>>2]|0;
    HEAP32[$46>>2] = $137;
    $138 = HEAP32[$136>>2]|0;
    $139 = HEAP32[$138>>2]|0;
    $140 = ($139|0)==($47|0);
    if ($140) {
     HEAP32[$138>>2] = $__w$1;
    } else {
     $141 = (($138) + 4|0);
     HEAP32[$141>>2] = $__w$1;
    }
    HEAP32[$132>>2] = $47;
    HEAP32[$136>>2] = $__w$1;
    $142 = HEAP32[$132>>2]|0;
    $143 = ($$2|0)==($142|0);
    $__w$1$$23 = $143 ? $__w$1 : $$2;
    $144 = HEAP32[$142>>2]|0;
    $$6 = $__w$1$$23;$__w$4 = $144;
   }
   $145 = HEAP32[$__w$4>>2]|0;
   $146 = ($145|0)==(0|0);
   if (!($146)) {
    $147 = (($145) + 12|0);
    $148 = HEAP8[$147>>0]|0;
    $149 = ($148<<24>>24)==(0);
    if ($149) {
     label = 66;
     break;
    }
   }
   $150 = (($__w$4) + 4|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ($151|0)==(0|0);
   if (!($152)) {
    $153 = (($151) + 12|0);
    $154 = HEAP8[$153>>0]|0;
    $155 = ($154<<24>>24)==(0);
    if ($155) {
     label = 65;
     break;
    }
   }
   $156 = (($__w$4) + 12|0);
   HEAP8[$156>>0] = 0;
   $157 = (($__w$4) + 8|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($158) + 12|0);
   $160 = HEAP8[$159>>0]|0;
   $161 = ($160<<24>>24)==(0);
   $162 = ($158|0)==($$6|0);
   $or$cond = $161 | $162;
   if ($or$cond) {
    label = 62;
    break;
   }
   $163 = (($158) + 8|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = HEAP32[$164>>2]|0;
   $166 = ($165|0)==($158|0);
   $167 = (($164) + 4|0);
   $$in2 = $166 ? $167 : $164;
   $$2$be = $$6;$__w$1$be$in = $$in2;
  } else {
   if ($52) {
    $$4 = $$2;$__w$2 = $__w$1;
   } else {
    HEAP8[$50>>0] = 1;
    $53 = (($47) + 12|0);
    HEAP8[$53>>0] = 0;
    $54 = (($47) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$55>>2]|0;
    HEAP32[$54>>2] = $56;
    $57 = ($56|0)==(0|0);
    if (!($57)) {
     $58 = (($56) + 8|0);
     HEAP32[$58>>2] = $47;
    }
    $59 = (($47) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($55) + 8|0);
    HEAP32[$61>>2] = $60;
    $62 = HEAP32[$59>>2]|0;
    $63 = HEAP32[$62>>2]|0;
    $64 = ($63|0)==($47|0);
    if ($64) {
     HEAP32[$62>>2] = $55;
    } else {
     $65 = (($62) + 4|0);
     HEAP32[$65>>2] = $55;
    }
    HEAP32[$55>>2] = $47;
    HEAP32[$59>>2] = $55;
    $66 = HEAP32[$__w$1>>2]|0;
    $67 = ($$2|0)==($66|0);
    $__w$1$$2 = $67 ? $__w$1 : $$2;
    $68 = (($66) + 4|0);
    $69 = HEAP32[$68>>2]|0;
    $$4 = $__w$1$$2;$__w$2 = $69;
   }
   $70 = HEAP32[$__w$2>>2]|0;
   $71 = ($70|0)==(0|0);
   if (!($71)) {
    $72 = (($70) + 12|0);
    $73 = HEAP8[$72>>0]|0;
    $74 = ($73<<24>>24)==(0);
    if ($74) {
     label = 36;
     break;
    }
   }
   $75 = (($__w$2) + 4|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==(0|0);
   if (!($77)) {
    $78 = (($76) + 12|0);
    $79 = HEAP8[$78>>0]|0;
    $80 = ($79<<24>>24)==(0);
    if ($80) {
     $96 = $76;
     label = 37;
     break;
    }
   }
   $81 = (($__w$2) + 12|0);
   HEAP8[$81>>0] = 0;
   $82 = (($__w$2) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==($$4|0);
   if ($84) {
    $$lcssa18 = $$4;
    label = 34;
    break;
   }
   $85 = (($83) + 12|0);
   $86 = HEAP8[$85>>0]|0;
   $87 = ($86<<24>>24)==(0);
   if ($87) {
    $$lcssa18 = $83;
    label = 34;
    break;
   }
   $89 = (($83) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==($83|0);
   $93 = (($90) + 4|0);
   $$in1 = $92 ? $93 : $90;
   $$2$be = $$4;$__w$1$be$in = $$in1;
  }
  $__w$1$be = HEAP32[$__w$1$be$in>>2]|0;
  $$2 = $$2$be;$__w$1 = $__w$1$be;
 }
 if ((label|0) == 34) {
  $88 = (($$lcssa18) + 12|0);
  HEAP8[$88>>0] = 1;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 36) {
  $$phi$trans$insert35 = (($__w$2) + 4|0);
  $$pre = HEAP32[$$phi$trans$insert35>>2]|0;
  $94 = ($$pre|0)==(0|0);
  if ($94) {
   label = 38;
  } else {
   $96 = $$pre;
   label = 37;
  }
 }
 else if ((label|0) == 62) {
  HEAP8[$159>>0] = 1;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 65) {
  if ($146) {
   label = 67;
  } else {
   label = 66;
  }
 }
 if ((label|0) == 37) {
  $95 = (($96) + 12|0);
  $97 = HEAP8[$95>>0]|0;
  $98 = ($97<<24>>24)==(0);
  if ($98) {
   $118 = $96;$__w$3 = $__w$2;
   label = 44;
  } else {
   label = 38;
  }
 }
 else if ((label|0) == 66) {
  $168 = (($145) + 12|0);
  $169 = HEAP8[$168>>0]|0;
  $170 = ($169<<24>>24)==(0);
  if ($170) {
   $191 = $145;$__w$5 = $__w$4;
   label = 73;
  } else {
   label = 67;
  }
 }
 if ((label|0) == 38) {
  $99 = (($70) + 12|0);
  HEAP8[$99>>0] = 1;
  $100 = (($__w$2) + 12|0);
  HEAP8[$100>>0] = 0;
  $101 = (($70) + 4|0);
  $102 = HEAP32[$101>>2]|0;
  HEAP32[$__w$2>>2] = $102;
  $103 = ($102|0)==(0|0);
  if (!($103)) {
   $104 = (($102) + 8|0);
   HEAP32[$104>>2] = $__w$2;
  }
  $105 = (($__w$2) + 8|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($70) + 8|0);
  HEAP32[$107>>2] = $106;
  $108 = HEAP32[$105>>2]|0;
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)==($__w$2|0);
  if ($110) {
   HEAP32[$108>>2] = $70;
  } else {
   $111 = (($108) + 4|0);
   HEAP32[$111>>2] = $70;
  }
  HEAP32[$101>>2] = $__w$2;
  HEAP32[$105>>2] = $70;
  $$pre24 = HEAP32[$101>>2]|0;
  $118 = $$pre24;$__w$3 = $70;
  label = 44;
 }
 else if ((label|0) == 67) {
  $171 = (($__w$4) + 4|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = (($172) + 12|0);
  HEAP8[$173>>0] = 1;
  $174 = (($__w$4) + 12|0);
  HEAP8[$174>>0] = 0;
  $175 = HEAP32[$172>>2]|0;
  HEAP32[$171>>2] = $175;
  $176 = ($175|0)==(0|0);
  if (!($176)) {
   $177 = (($175) + 8|0);
   HEAP32[$177>>2] = $__w$4;
  }
  $178 = (($__w$4) + 8|0);
  $179 = HEAP32[$178>>2]|0;
  $180 = (($172) + 8|0);
  HEAP32[$180>>2] = $179;
  $181 = HEAP32[$178>>2]|0;
  $182 = HEAP32[$181>>2]|0;
  $183 = ($182|0)==($__w$4|0);
  if ($183) {
   HEAP32[$181>>2] = $172;
  } else {
   $184 = (($181) + 4|0);
   HEAP32[$184>>2] = $172;
  }
  HEAP32[$172>>2] = $__w$4;
  HEAP32[$178>>2] = $172;
  $$pre23 = HEAP32[$172>>2]|0;
  $191 = $$pre23;$__w$5 = $172;
  label = 73;
 }
 if ((label|0) == 44) {
  $112 = (($__w$3) + 8|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($113) + 12|0);
  $115 = HEAP8[$114>>0]|0;
  $116 = (($__w$3) + 12|0);
  HEAP8[$116>>0] = $115;
  HEAP8[$114>>0] = 1;
  $117 = (($118) + 12|0);
  HEAP8[$117>>0] = 1;
  $119 = (($113) + 4|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = HEAP32[$120>>2]|0;
  HEAP32[$119>>2] = $121;
  $122 = ($121|0)==(0|0);
  if (!($122)) {
   $123 = (($121) + 8|0);
   HEAP32[$123>>2] = $113;
  }
  $124 = (($113) + 8|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (($120) + 8|0);
  HEAP32[$126>>2] = $125;
  $127 = HEAP32[$124>>2]|0;
  $128 = HEAP32[$127>>2]|0;
  $129 = ($128|0)==($113|0);
  if ($129) {
   HEAP32[$127>>2] = $120;
  } else {
   $130 = (($127) + 4|0);
   HEAP32[$130>>2] = $120;
  }
  HEAP32[$120>>2] = $113;
  HEAP32[$124>>2] = $120;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 73) {
  $185 = (($__w$5) + 8|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = (($186) + 12|0);
  $188 = HEAP8[$187>>0]|0;
  $189 = (($__w$5) + 12|0);
  HEAP8[$189>>0] = $188;
  HEAP8[$187>>0] = 1;
  $190 = (($191) + 12|0);
  HEAP8[$190>>0] = 1;
  $192 = HEAP32[$186>>2]|0;
  $193 = (($192) + 4|0);
  $194 = HEAP32[$193>>2]|0;
  HEAP32[$186>>2] = $194;
  $195 = ($194|0)==(0|0);
  if (!($195)) {
   $196 = (($194) + 8|0);
   HEAP32[$196>>2] = $186;
  }
  $197 = (($186) + 8|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = (($192) + 8|0);
  HEAP32[$199>>2] = $198;
  $200 = HEAP32[$197>>2]|0;
  $201 = HEAP32[$200>>2]|0;
  $202 = ($201|0)==($186|0);
  if ($202) {
   HEAP32[$200>>2] = $192;
  } else {
   $203 = (($200) + 4|0);
   HEAP32[$203>>2] = $192;
  }
  HEAP32[$193>>2] = $186;
  HEAP32[$197>>2] = $192;
  STACKTOP = sp;return;
 }
}
function __GLOBAL__I_a1261() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[389856>>2] = 0;
 HEAP32[389864>>2] = 0;
 HEAP32[389872>>2] = 0;
 __ZN6il2cpp2os5MutexC2Eb(389880,0);
 HEAP32[389888>>2] = 0;
 HEAP32[389896>>2] = 0;
 HEAP32[389904>>2] = 0;
 __ZN6il2cpp2os16ThreadLocalValueC2Ev(389912);
 __ZN6il2cpp2os5MutexC2Eb(389920,0);
 HEAP32[((389920 + 12|0))>>2] = 0;
 HEAP32[((389920 + 16|0))>>2] = 0;
 HEAP32[((389920 + 8|0))>>2] = ((389920 + 12|0));
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm14TypeNameParserC2ERNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEERNS0_17TypeNameParseInfoE($this,$name,$info) {
 $this = $this|0;
 $name = $name|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $name;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $info;
 $1 = HEAP8[$name>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($name) + 1|0);
  $8 = $6;
 } else {
  $4 = (($name) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $8 = $5;
 }
 $7 = (($this) + 8|0);
 HEAP32[$7>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm14TypeNameParser5ParseEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $arity = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $arity = sp;
 HEAP32[$arity>>2] = 0;
 $0 = (($this) + 8|0);
 $$pre$i$i = HEAP32[$this>>2]|0;
 $1 = (($$pre$i$i) + 1|0);
 $2 = (($$pre$i$i) + 8|0);
 $3 = (($$pre$i$i) + 4|0);
 while(1) {
  $4 = HEAP8[$$pre$i$i>>0]|0;
  $5 = $4 & 1;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $9 = $4&255;
   $10 = $9 >>> 1;
   $12 = $1;$13 = $10;
  } else {
   $7 = HEAP32[$2>>2]|0;
   $8 = HEAP32[$3>>2]|0;
   $12 = $7;$13 = $8;
  }
  $11 = (($12) + ($13)|0);
  $14 = HEAP32[$0>>2]|0;
  $15 = ($14>>>0)<($11>>>0);
  if ($15) {
   $16 = HEAP8[$14>>0]|0;
   $17 = ($16<<24>>24)==(32);
   if (!($17)) {
    label = 7;
   }
  } else {
   label = 7;
  }
  if ((label|0) == 7) {
   label = 0;
   if ($6) {
    $20 = $4&255;
    $21 = $20 >>> 1;
    $23 = $1;$24 = $21;
   } else {
    $18 = HEAP32[$2>>2]|0;
    $19 = HEAP32[$3>>2]|0;
    $23 = $18;$24 = $19;
   }
   $22 = (($23) + ($24)|0);
   $25 = ($14>>>0)<($22>>>0);
   if (!($25)) {
    break;
   }
   $26 = HEAP8[$14>>0]|0;
   $27 = ($26<<24>>24)==(9);
   if (!($27)) {
    break;
   }
  }
  $28 = (($14) + 1|0);
  HEAP32[$0>>2] = $28;
 }
 if ($6) {
  $31 = $4&255;
  $32 = $31 >>> 1;
  $34 = $1;$35 = $32;
 } else {
  $29 = HEAP32[$2>>2]|0;
  $30 = HEAP32[$3>>2]|0;
  $34 = $29;$35 = $30;
 }
 $33 = (($34) + ($35)|0);
 $36 = ($14>>>0)<($33>>>0);
 if (!($36)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = (__ZN6il2cpp2vm14TypeNameParser13ParseTypeNameERi($this,$arity)|0);
 if (!($37)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = (__ZN6il2cpp2vm14TypeNameParser23ParseNestedTypeOptionalERi($this,$arity)|0);
 if (!($38)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = (__ZN6il2cpp2vm14TypeNameParser26ParseTypeModifiersOptionalEv($this)|0);
 if (!($39)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = (__ZN6il2cpp2vm14TypeNameParser25ParseAssemblyNameOptionalEv($this)|0);
 $$0 = $40;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm14TypeNameParser13ParseTypeNameERi($this,$arity) {
 $this = $this|0;
 $arity = $arity|0;
 var $$0 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$pre = 0, $$pre$i = 0, $$pre$i4 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $isdigit$i = 0, $isdigit2$i = 0, $isdigittmp$i = 0, $isdigittmp1$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $$byval_copy4 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = sp + 24|0;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $16 = (($8) + 1|0);
  $17 = $9&255;
  $18 = $17 >>> 1;
  $20 = $16;$21 = $18;
 } else {
  $12 = (($8) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($8) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $20 = $13;$21 = $15;
 }
 $19 = (($20) + ($21)|0);
 $$pre$i = $7;$137 = $19;$146 = $9;
 while(1) {
  $147 = $146;$23 = $$pre$i;
  L7: while(1) {
   $22 = HEAP8[$23>>0]|0;
   $24 = $22 << 24 >> 24;
   switch ($24|0) {
   case 92:  {
    $25 = (($23) + 1|0);
    HEAP32[$6>>2] = $25;
    $27 = $25;
    break;
   }
   case 96: case 34: case 61: case 46: case 93: case 91: case 42: case 38: case 43: case 44:  {
    $43 = $147;$56 = $23;
    break L7;
    break;
   }
   default: {
    $27 = $23;
   }
   }
   $26 = (($27) + 1|0);
   HEAP32[$6>>2] = $26;
   $28 = HEAP8[$8>>0]|0;
   $29 = $28 & 1;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $35 = (($8) + 1|0);
    $36 = $28&255;
    $37 = $36 >>> 1;
    $39 = $35;$40 = $37;
   } else {
    $31 = (($8) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($8) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $39 = $32;$40 = $34;
   }
   $38 = (($39) + ($40)|0);
   $41 = ($26>>>0)<($38>>>0);
   if ($41) {
    $147 = $28;$23 = $26;
   } else {
    $43 = $28;$56 = $26;
    break;
   }
  }
  $42 = $43 & 1;
  $44 = ($42<<24>>24)==(0);
  if ($44) {
   $49 = (($8) + 1|0);
   $50 = $43&255;
   $51 = $50 >>> 1;
   $53 = $49;$54 = $51;
  } else {
   $45 = (($8) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($8) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $53 = $46;$54 = $48;
  }
  $52 = (($53) + ($54)|0);
  $55 = ($56>>>0)<($52>>>0);
  if (!($55)) {
   break;
  }
  $57 = HEAP8[$56>>0]|0;
  $58 = ($57<<24>>24)==(46);
  if (!($58)) {
   break;
  }
  $59 = (($56) + 1|0);
  HEAP32[$6>>2] = $59;
  $60 = HEAP8[$8>>0]|0;
  $61 = $60 & 1;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $67 = (($8) + 1|0);
   $68 = $60&255;
   $69 = $68 >>> 1;
   $71 = $67;$72 = $69;
  } else {
   $63 = (($8) + 8|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($8) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $71 = $64;$72 = $66;
  }
  $70 = (($71) + ($72)|0);
  $73 = ($59>>>0)<($70>>>0);
  if ($73) {
   $$pre$i = $59;$137 = $56;$146 = $60;
  } else {
   $$0 = 0;
   label = 43;
   break;
  }
 }
 if ((label|0) == 43) {
  STACKTOP = sp;return ($$0|0);
 }
 if ($44) {
  $78 = (($8) + 1|0);
  $79 = $43&255;
  $80 = $79 >>> 1;
  $82 = $78;$83 = $80;
 } else {
  $74 = (($8) + 8|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($8) + 4|0);
  $77 = HEAP32[$76>>2]|0;
  $82 = $75;$83 = $77;
 }
 $81 = (($82) + ($83)|0);
 $84 = ($56>>>0)<($81>>>0);
 if ($84) {
  $85 = HEAP8[$56>>0]|0;
  $86 = ($85<<24>>24)==(96);
  if ($86) {
   $87 = (($56) + 1|0);
   HEAP32[$6>>2] = $87;
   $88 = HEAP8[$8>>0]|0;
   $89 = $88 & 1;
   $90 = ($89<<24>>24)==(0);
   if ($90) {
    $95 = (($8) + 1|0);
    $96 = $88&255;
    $97 = $96 >>> 1;
    $100 = $97;$99 = $95;
   } else {
    $91 = (($8) + 8|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = (($8) + 4|0);
    $94 = HEAP32[$93>>2]|0;
    $100 = $94;$99 = $92;
   }
   $98 = (($99) + ($100)|0);
   $101 = ($87>>>0)<($98>>>0);
   if (!($101)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $102 = HEAP8[$87>>0]|0;
   $103 = $102 << 24 >> 24;
   $isdigittmp$i = (($103) + -48)|0;
   $isdigit$i = ($isdigittmp$i>>>0)<(10);
   if ($isdigit$i) {
    $105 = $87;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   while(1) {
    $104 = (($105) + 1|0);
    HEAP32[$6>>2] = $104;
    $106 = HEAP8[$8>>0]|0;
    $107 = $106 & 1;
    $108 = ($107<<24>>24)==(0);
    if ($108) {
     $113 = (($8) + 1|0);
     $114 = $106&255;
     $115 = $114 >>> 1;
     $117 = $113;$118 = $115;
    } else {
     $109 = (($8) + 8|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = (($8) + 4|0);
     $112 = HEAP32[$111>>2]|0;
     $117 = $110;$118 = $112;
    }
    $116 = (($117) + ($118)|0);
    $119 = ($104>>>0)<($116>>>0);
    if (!($119)) {
     break;
    }
    $$pre$i4 = HEAP8[$104>>0]|0;
    $120 = $$pre$i4 << 24 >> 24;
    $isdigittmp1$i = (($120) + -48)|0;
    $isdigit2$i = ($isdigittmp1$i>>>0)<(10);
    if ($isdigit2$i) {
     $105 = $104;
    } else {
     break;
    }
   }
   $121 = (_strtol($87,0,10)|0);
   HEAP32[$arity>>2] = $121;
   $$pre = HEAP32[$this>>2]|0;
   $$pre16 = HEAP8[$$pre>>0]|0;
   $123 = $$pre16;$126 = $$pre;
  } else {
   $123 = $43;$126 = $8;
  }
 } else {
  $123 = $43;$126 = $8;
 }
 $122 = $123 & 1;
 $124 = ($122<<24>>24)==(0);
 if ($124) {
  $130 = (($126) + 1|0);
  $131 = $123&255;
  $132 = $131 >>> 1;
  $134 = $130;$135 = $132;
 } else {
  $125 = (($126) + 8|0);
  $127 = HEAP32[$125>>2]|0;
  $128 = (($126) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $134 = $127;$135 = $129;
 }
 $133 = (($134) + ($135)|0);
 $136 = ($137|0)==($133|0);
 $138 = (($this) + 4|0);
 $139 = HEAP32[$138>>2]|0;
 if ($136) {
  $140 = (($139) + 12|0);
  HEAP32[$0>>2] = $7;
  $141 = HEAP32[$6>>2]|0;
  HEAP32[$1>>2] = $141;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignINS_11__wrap_iterIPKcEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeESC_SC_($140,$$byval_copy4,$$byval_copy5)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$2>>2] = $7;
  HEAP32[$3>>2] = $137;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignINS_11__wrap_iterIPKcEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeESC_SC_($139,$$byval_copy4,$$byval_copy5)|0);
  $142 = HEAP32[$138>>2]|0;
  $143 = (($142) + 12|0);
  $144 = (($137) + 1|0);
  HEAP32[$4>>2] = $144;
  $145 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $145;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignINS_11__wrap_iterIPKcEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeESC_SC_($143,$$byval_copy4,$$byval_copy5)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm14TypeNameParser23ParseNestedTypeOptionalERi($this,$arity) {
 $this = $this|0;
 $arity = $arity|0;
 var $$0 = 0, $$pre = 0, $$pre$i11 = 0, $$pre21 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$lcssa$i$i$i = 0, $__p$0$ph$i$i$i = 0, $__p$02$i$i$i = 0, $isdigit$i = 0, $isdigit2$i = 0, $isdigittmp$i = 0, $isdigittmp1$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $scevgep8$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = (($this) + 4|0);
 $3 = (($0) + 1|0);
 $4 = (($0) + 8|0);
 $5 = (($0) + 4|0);
 L1: while(1) {
  $6 = HEAP32[$this>>2]|0;
  $7 = HEAP8[$6>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   $14 = (($6) + 1|0);
   $15 = $7&255;
   $16 = $15 >>> 1;
   $18 = $14;$19 = $16;
  } else {
   $10 = (($6) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($6) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $18 = $11;$19 = $13;
  }
  $17 = (($18) + ($19)|0);
  $20 = HEAP32[$1>>2]|0;
  $21 = ($20>>>0)<($17>>>0);
  if (!($21)) {
   $$0 = 1;
   label = 62;
   break;
  }
  $22 = HEAP8[$20>>0]|0;
  $23 = ($22<<24>>24)==(43);
  if (!($23)) {
   $$0 = 1;
   label = 62;
   break;
  }
  $24 = (($20) + 1|0);
  HEAP32[$1>>2] = $24;
  $25 = HEAP8[$6>>0]|0;
  $26 = $25 & 1;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $32 = (($6) + 1|0);
   $33 = $25&255;
   $34 = $33 >>> 1;
   $36 = $32;$37 = $34;
  } else {
   $28 = (($6) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($6) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $36 = $29;$37 = $31;
  }
  $35 = (($36) + ($37)|0);
  $38 = ($24>>>0)<($35>>>0);
  if ($38) {
   $177 = $25;$40 = $24;
  } else {
   $$0 = 0;
   label = 62;
   break;
  }
  L13: while(1) {
   $39 = HEAP8[$40>>0]|0;
   $41 = $39 << 24 >> 24;
   switch ($41|0) {
   case 92:  {
    $42 = (($40) + 1|0);
    HEAP32[$1>>2] = $42;
    $44 = $42;
    break;
   }
   case 96: case 34: case 61: case 46: case 93: case 91: case 42: case 38: case 43: case 44:  {
    $60 = $177;$73 = $40;
    break L13;
    break;
   }
   default: {
    $44 = $40;
   }
   }
   $43 = (($44) + 1|0);
   HEAP32[$1>>2] = $43;
   $45 = HEAP8[$6>>0]|0;
   $46 = $45 & 1;
   $47 = ($46<<24>>24)==(0);
   if ($47) {
    $52 = (($6) + 1|0);
    $53 = $45&255;
    $54 = $53 >>> 1;
    $56 = $52;$57 = $54;
   } else {
    $48 = (($6) + 8|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($6) + 4|0);
    $51 = HEAP32[$50>>2]|0;
    $56 = $49;$57 = $51;
   }
   $55 = (($56) + ($57)|0);
   $58 = ($43>>>0)<($55>>>0);
   if ($58) {
    $177 = $45;$40 = $43;
   } else {
    $60 = $45;$73 = $43;
    break;
   }
  }
  $59 = $60 & 1;
  $61 = ($59<<24>>24)==(0);
  if ($61) {
   $66 = (($6) + 1|0);
   $67 = $60&255;
   $68 = $67 >>> 1;
   $70 = $66;$71 = $68;
  } else {
   $62 = (($6) + 8|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($6) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $70 = $63;$71 = $65;
  }
  $69 = (($70) + ($71)|0);
  $72 = ($73>>>0)<($69>>>0);
  if ($72) {
   $74 = HEAP8[$73>>0]|0;
   $75 = ($74<<24>>24)==(96);
   if ($75) {
    $76 = (($73) + 1|0);
    HEAP32[$1>>2] = $76;
    $77 = HEAP8[$6>>0]|0;
    $78 = $77 & 1;
    $79 = ($78<<24>>24)==(0);
    if ($79) {
     $84 = (($6) + 1|0);
     $85 = $77&255;
     $86 = $85 >>> 1;
     $88 = $84;$89 = $86;
    } else {
     $80 = (($6) + 8|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($6) + 4|0);
     $83 = HEAP32[$82>>2]|0;
     $88 = $81;$89 = $83;
    }
    $87 = (($88) + ($89)|0);
    $90 = ($76>>>0)<($87>>>0);
    if (!($90)) {
     $$0 = 0;
     label = 62;
     break;
    }
    $91 = HEAP8[$76>>0]|0;
    $92 = $91 << 24 >> 24;
    $isdigittmp$i = (($92) + -48)|0;
    $isdigit$i = ($isdigittmp$i>>>0)<(10);
    if ($isdigit$i) {
     $94 = $76;
    } else {
     $$0 = 0;
     label = 62;
     break;
    }
    while(1) {
     $93 = (($94) + 1|0);
     HEAP32[$1>>2] = $93;
     $95 = HEAP8[$6>>0]|0;
     $96 = $95 & 1;
     $97 = ($96<<24>>24)==(0);
     if ($97) {
      $102 = (($6) + 1|0);
      $103 = $95&255;
      $104 = $103 >>> 1;
      $106 = $102;$107 = $104;
     } else {
      $98 = (($6) + 8|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = (($6) + 4|0);
      $101 = HEAP32[$100>>2]|0;
      $106 = $99;$107 = $101;
     }
     $105 = (($106) + ($107)|0);
     $108 = ($93>>>0)<($105>>>0);
     if (!($108)) {
      break;
     }
     $$pre$i11 = HEAP8[$93>>0]|0;
     $109 = $$pre$i11 << 24 >> 24;
     $isdigittmp1$i = (($109) + -48)|0;
     $isdigit2$i = ($isdigittmp1$i>>>0)<(10);
     if ($isdigit2$i) {
      $94 = $93;
     } else {
      break;
     }
    }
    $110 = (_strtol($76,0,10)|0);
    $111 = HEAP32[$arity>>2]|0;
    $112 = (($111) + ($110))|0;
    HEAP32[$arity>>2] = $112;
    $$pre = HEAP32[$1>>2]|0;
    $117 = $$pre;
   } else {
    $117 = $73;
   }
  } else {
   $117 = $73;
  }
  $113 = HEAP32[$2>>2]|0;
  $114 = (($113) + 128|0);
  $115 = $24;
  $116 = $117;
  $118 = (($116) - ($115))|0;
  $119 = ($118>>>0)>(4294967279);
  if ($119) {
   label = 34;
   break;
  }
  $120 = ($118>>>0)<(11);
  if ($120) {
   $121 = $118 << 1;
   $122 = $121&255;
   HEAP8[$0>>0] = $122;
   $__p$0$ph$i$i$i = $3;
  } else {
   $123 = (($118) + 16)|0;
   $124 = $123 & -16;
   $125 = (__Znwj($124)|0);
   HEAP32[$4>>2] = $125;
   $126 = $124 | 1;
   HEAP32[$0>>2] = $126;
   HEAP32[$5>>2] = $118;
   $__p$0$ph$i$i$i = $125;
  }
  $127 = ($24|0)==($117|0);
  if ($127) {
   $__p$0$lcssa$i$i$i = $__p$0$ph$i$i$i;
  } else {
   $128 = (0 - ($115))|0;
   $130 = $24;$__p$02$i$i$i = $__p$0$ph$i$i$i;
   while(1) {
    $129 = HEAP8[$130>>0]|0;
    HEAP8[$__p$02$i$i$i>>0] = $129;
    $131 = (($130) + 1|0);
    $132 = (($__p$02$i$i$i) + 1|0);
    $133 = ($131|0)==($117|0);
    if ($133) {
     break;
    } else {
     $130 = $131;$__p$02$i$i$i = $132;
    }
   }
   $scevgep$i$i = (($117) + ($128)|0);
   $scevgep7$i$i = $scevgep$i$i;
   $scevgep8$i$i = (($__p$0$ph$i$i$i) + ($scevgep7$i$i)|0);
   $__p$0$lcssa$i$i$i = $scevgep8$i$i;
  }
  HEAP8[$__p$0$lcssa$i$i$i>>0] = 0;
  $134 = (($113) + 132|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = (($113) + 136|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = ($135|0)==($137|0);
  if ($138) {
   __THREW__ = 0;
   invoke_vii(2523,($114|0),($0|0));
   $163 = __THREW__; __THREW__ = 0;
   $164 = $163&1;
   if ($164) {
    label = 58;
    break;
   }
  } else {
   $139 = ($135|0)==(0|0);
   do {
    if (!($139)) {
     $140 = HEAP8[$0>>0]|0;
     $141 = $140 & 1;
     $142 = ($141<<24>>24)==(0);
     if ($142) {
      ;HEAP32[$135+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$135+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$135+8>>2]=HEAP32[$0+8>>2]|0;
      break;
     }
     $143 = HEAP32[$4>>2]|0;
     $144 = HEAP32[$5>>2]|0;
     $145 = ($144>>>0)>(4294967279);
     if ($145) {
      label = 47;
      break L1;
     }
     $148 = ($144>>>0)<(11);
     if ($148) {
      $149 = $144 << 1;
      $150 = $149&255;
      HEAP8[$135>>0] = $150;
      $151 = (($135) + 1|0);
      $__p$0$i$i$i$i$i = $151;
     } else {
      $152 = (($144) + 16)|0;
      $153 = $152 & -16;
      __THREW__ = 0;
      $154 = (invoke_ii(2988,($153|0))|0);
      $155 = __THREW__; __THREW__ = 0;
      $156 = $155&1;
      if ($156) {
       label = 58;
       break L1;
      }
      $157 = (($135) + 8|0);
      HEAP32[$157>>2] = $154;
      $158 = $153 | 1;
      HEAP32[$135>>2] = $158;
      $159 = (($135) + 4|0);
      HEAP32[$159>>2] = $144;
      $__p$0$i$i$i$i$i = $154;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($143|0),($144|0))|0;
     $160 = (($__p$0$i$i$i$i$i) + ($144)|0);
     HEAP8[$160>>0] = 0;
    }
   } while(0);
   $161 = HEAP32[$134>>2]|0;
   $162 = (($161) + 12|0);
   HEAP32[$134>>2] = $162;
  }
  $165 = HEAP8[$0>>0]|0;
  $166 = $165 & 1;
  $167 = ($166<<24>>24)==(0);
  if ($167) {
   continue;
  }
  $168 = HEAP32[$4>>2]|0;
  __ZdlPv($168);
 }
 do {
  if ((label|0) == 34) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  else if ((label|0) == 47) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $146 = __THREW__; __THREW__ = 0;
   $147 = $146&1;
   if ($147) {
    $171 = ___cxa_find_matching_catch()|0;
    $172 = tempRet0;
    $174 = $140;$lpad$phi$index = $171;$lpad$phi$index2 = $172;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 58) {
   $169 = ___cxa_find_matching_catch()|0;
   $170 = tempRet0;
   $$pre21 = HEAP8[$0>>0]|0;
   $174 = $$pre21;$lpad$phi$index = $169;$lpad$phi$index2 = $170;
  }
  else if ((label|0) == 62) {
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $173 = $174 & 1;
 $175 = ($173<<24>>24)==(0);
 if ($175) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $176 = HEAP32[$4>>2]|0;
 __ZdlPv($176);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp2vm14TypeNameParser26ParseTypeModifiersOptionalEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $8 = (($0) + 1|0);
  $9 = $1&255;
  $10 = $9 >>> 1;
  $12 = $8;$13 = $10;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($0) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $12 = $5;$13 = $7;
 }
 $11 = (($12) + ($13)|0);
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15>>>0)<($11>>>0);
 if (!($16)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = (($this) + 4|0);
 $19 = $15;
 while(1) {
  $18 = HEAP8[$19>>0]|0;
  $20 = $18 << 24 >> 24;
  if ((($20|0) == 93) | (($20|0) == 91) | (($20|0) == 42)) {
   label = 28;
   break;
  } else if (!((($20|0) == 38))) {
   $$0 = 1;
   label = 29;
   break;
  }
  $21 = HEAP32[$17>>2]|0;
  $22 = (($21) + 104|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21) + 108|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($23|0)==($25|0);
  L11: do {
   if ($26) {
    $33 = $23;
    label = 10;
   } else {
    $28 = $23;
    while(1) {
     $27 = HEAP32[$28>>2]|0;
     $29 = ($27|0)==(0);
     if ($29) {
      $33 = $28;
      label = 10;
      break L11;
     }
     $30 = (($28) + 4|0);
     $31 = ($30|0)==($25|0);
     if ($31) {
      break;
     } else {
      $28 = $30;
     }
    }
   }
  } while(0);
  if ((label|0) == 10) {
   label = 0;
   $32 = ($33|0)==($25|0);
   if (!($32)) {
    $$0 = 0;
    label = 29;
    break;
   }
  }
  $34 = (($21) + 112|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($25|0)==($35|0);
  if ($36) {
   $39 = $25;
   $40 = $23;
   $41 = (($39) - ($40))|0;
   $42 = $41 >> 2;
   $43 = (($42) + 1)|0;
   $44 = ($43>>>0)>(1073741823);
   if ($44) {
    label = 16;
    break;
   }
   $45 = ($42>>>0)<(536870911);
   if ($45) {
    $46 = $41 >> 1;
    $47 = ($46>>>0)<($43>>>0);
    $48 = $47 ? $43 : $46;
    $49 = ($48|0)==(0);
    if ($49) {
     $$0$i3$i$i = 0;$53 = 0;
    } else {
     $$0$i2$i$i = $48;
     label = 19;
    }
   } else {
    $$0$i2$i$i = 1073741823;
    label = 19;
   }
   if ((label|0) == 19) {
    label = 0;
    $50 = $$0$i2$i$i << 2;
    $51 = (__Znwj($50)|0);
    $$0$i3$i$i = $$0$i2$i$i;$53 = $51;
   }
   $52 = (($53) + ($42<<2)|0);
   $54 = (($53) + ($$0$i3$i$i<<2)|0);
   $55 = ($52|0)==(0|0);
   if (!($55)) {
    HEAP32[$52>>2] = 0;
   }
   $56 = (($53) + ($43<<2)|0);
   _memcpy(($53|0),($23|0),($41|0))|0;
   HEAP32[$22>>2] = $53;
   HEAP32[$24>>2] = $56;
   HEAP32[$34>>2] = $54;
   $57 = ($23|0)==(0|0);
   if (!($57)) {
    __ZdlPv($23);
   }
  } else {
   $37 = ($25|0)==(0|0);
   if (!($37)) {
    HEAP32[$25>>2] = 0;
   }
   $38 = (($25) + 4|0);
   HEAP32[$24>>2] = $38;
  }
  $58 = HEAP32[$14>>2]|0;
  $59 = (($58) + 1|0);
  HEAP32[$14>>2] = $59;
  $60 = HEAP32[$this>>2]|0;
  $61 = HEAP8[$60>>0]|0;
  $62 = $61 & 1;
  $63 = ($62<<24>>24)==(0);
  if ($63) {
   $68 = (($60) + 1|0);
   $69 = $61&255;
   $70 = $69 >>> 1;
   $72 = $68;$73 = $70;
  } else {
   $64 = (($60) + 8|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($60) + 4|0);
   $67 = HEAP32[$66>>2]|0;
   $72 = $65;$73 = $67;
  }
  $71 = (($72) + ($73)|0);
  $74 = ($59>>>0)<($71>>>0);
  if ($74) {
   $19 = $59;
  } else {
   $$0 = 1;
   label = 29;
   break;
  }
 }
 if ((label|0) == 16) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  HEAP32[$vararg_buffer>>2] = 389968;
  (_printf((389944|0),($vararg_buffer|0))|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 29) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm14TypeNameParser25ParseAssemblyNameOptionalEv($this) {
 $this = $this|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $10 = (($2) + 1|0);
  $11 = $3&255;
  $12 = $11 >>> 1;
  $14 = $10;$15 = $12;
 } else {
  $6 = (($2) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $14 = $7;$15 = $9;
 }
 $13 = (($14) + ($15)|0);
 $16 = (($this) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17>>>0)<($13>>>0);
 if (!($18)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = HEAP8[$17>>0]|0;
 $20 = ($19<<24>>24)==(44);
 if (!($20)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($17) + 1|0);
 HEAP32[$16>>2] = $21;
 $22 = HEAP8[$2>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $29 = (($2) + 1|0);
  $30 = $22&255;
  $31 = $30 >>> 1;
  $33 = $29;$34 = $31;
 } else {
  $25 = (($2) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($2) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $33 = $26;$34 = $28;
 }
 $32 = (($33) + ($34)|0);
 $35 = ($21>>>0)<($32>>>0);
 if (!($35)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = (($2) + 1|0);
 $37 = (($2) + 8|0);
 $38 = (($2) + 4|0);
 $40 = $22;$50 = $21;
 while(1) {
  $39 = $40 & 1;
  $41 = ($39<<24>>24)==(0);
  if ($41) {
   $44 = $40&255;
   $45 = $44 >>> 1;
   $47 = $36;$48 = $45;
  } else {
   $42 = HEAP32[$37>>2]|0;
   $43 = HEAP32[$38>>2]|0;
   $47 = $42;$48 = $43;
  }
  $46 = (($47) + ($48)|0);
  $49 = ($50>>>0)<($46>>>0);
  if ($49) {
   $51 = HEAP8[$50>>0]|0;
   $52 = ($51<<24>>24)==(32);
   if (!($52)) {
    label = 16;
   }
  } else {
   label = 16;
  }
  if ((label|0) == 16) {
   label = 0;
   if ($41) {
    $55 = $40&255;
    $56 = $55 >>> 1;
    $58 = $36;$59 = $56;
   } else {
    $53 = HEAP32[$37>>2]|0;
    $54 = HEAP32[$38>>2]|0;
    $58 = $53;$59 = $54;
   }
   $57 = (($58) + ($59)|0);
   $60 = ($50>>>0)<($57>>>0);
   if (!($60)) {
    $65 = $50;
    break;
   }
   $61 = HEAP8[$50>>0]|0;
   $62 = ($61<<24>>24)==(9);
   if (!($62)) {
    $65 = $50;
    break;
   }
  }
  $63 = (($50) + 1|0);
  HEAP32[$16>>2] = $63;
  $$pre = HEAP8[$2>>0]|0;
  $40 = $$pre;$50 = $63;
 }
 L34: while(1) {
  $64 = HEAP8[$65>>0]|0;
  $66 = $64 << 24 >> 24;
  switch ($66|0) {
  case 96: case 34: case 61: case 93: case 91: case 42: case 38: case 43: case 44:  {
   $84 = $65;
   break L34;
   break;
  }
  case 92:  {
   $67 = (($65) + 1|0);
   HEAP32[$16>>2] = $67;
   $69 = $67;
   break;
  }
  default: {
   $69 = $65;
  }
  }
  $68 = (($69) + 1|0);
  HEAP32[$16>>2] = $68;
  $70 = HEAP8[$2>>0]|0;
  $71 = $70 & 1;
  $72 = ($71<<24>>24)==(0);
  if ($72) {
   $75 = $70&255;
   $76 = $75 >>> 1;
   $78 = $36;$79 = $76;
  } else {
   $73 = HEAP32[$37>>2]|0;
   $74 = HEAP32[$38>>2]|0;
   $78 = $73;$79 = $74;
  }
  $77 = (($78) + ($79)|0);
  $80 = ($68>>>0)<($77>>>0);
  if ($80) {
   $65 = $68;
  } else {
   $84 = $68;
   break;
  }
 }
 $81 = (($this) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($82) + 24|0);
 HEAP32[$0>>2] = $50;
 HEAP32[$1>>2] = $84;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignINS_11__wrap_iterIPKcEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeESC_SC_($83,$$byval_copy,$$byval_copy1)|0);
 $$pre$i = HEAP32[$this>>2]|0;
 $85 = (($$pre$i) + 1|0);
 $86 = (($$pre$i) + 8|0);
 $87 = (($$pre$i) + 4|0);
 while(1) {
  $88 = HEAP8[$$pre$i>>0]|0;
  $89 = $88 & 1;
  $90 = ($89<<24>>24)==(0);
  if ($90) {
   $93 = $88&255;
   $94 = $93 >>> 1;
   $96 = $85;$97 = $94;
  } else {
   $91 = HEAP32[$86>>2]|0;
   $92 = HEAP32[$87>>2]|0;
   $96 = $91;$97 = $92;
  }
  $95 = (($96) + ($97)|0);
  $98 = HEAP32[$16>>2]|0;
  $99 = ($98>>>0)<($95>>>0);
  if ($99) {
   $100 = HEAP8[$98>>0]|0;
   $101 = ($100<<24>>24)==(32);
   if (!($101)) {
    label = 34;
   }
  } else {
   label = 34;
  }
  if ((label|0) == 34) {
   label = 0;
   if ($90) {
    $104 = $88&255;
    $105 = $104 >>> 1;
    $107 = $85;$108 = $105;
   } else {
    $102 = HEAP32[$86>>2]|0;
    $103 = HEAP32[$87>>2]|0;
    $107 = $102;$108 = $103;
   }
   $106 = (($107) + ($108)|0);
   $109 = ($98>>>0)<($106>>>0);
   if (!($109)) {
    break;
   }
   $110 = HEAP8[$98>>0]|0;
   $111 = ($110<<24>>24)==(9);
   if (!($111)) {
    break;
   }
  }
  $112 = (($98) + 1|0);
  HEAP32[$16>>2] = $112;
 }
 (__ZN6il2cpp2vm14TypeNameParser23ParsePropertiesOptionalEv($this)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignINS_11__wrap_iterIPKcEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__p$0$lcssa = 0, $__p$0$ph = 0, $__p$02 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = HEAP8[$this>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $12 = 10;$17 = $5;
 } else {
  $8 = HEAP32[$this>>2]|0;
  $9 = $8 & -2;
  $phitmp$i = (($9) + -1)|0;
  $10 = $8&255;
  $12 = $phitmp$i;$17 = $10;
 }
 $11 = ($12>>>0)<($4>>>0);
 if ($11) {
  $13 = (($4) - ($12))|0;
  $14 = (-17 - ($12))|0;
  $15 = ($14>>>0)<($13>>>0);
  if ($15) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $16 = $17 & 1;
  $18 = ($16<<24>>24)==(0);
  if ($18) {
   $21 = (($this) + 1|0);
   $33 = $21;
  } else {
   $19 = (($this) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $33 = $20;
  }
  $22 = ($12>>>0)<(2147483623);
  if ($22) {
   $24 = $12 << 1;
   $25 = ($4>>>0)<($24>>>0);
   $26 = $25 ? $24 : $4;
   $27 = ($26>>>0)<(11);
   if ($27) {
    $30 = 11;
   } else {
    $28 = (($26) + 16)|0;
    $29 = $28 & -16;
    $30 = $29;
   }
   $31 = (__Znwj($30)|0);
   $32 = ($12|0)==(10);
   if ($32) {
    $35 = $31;$37 = $30;
   } else {
    $59 = $31;$60 = $30;
    label = 14;
   }
  } else {
   $23 = (__Znwj(-17)|0);
   $59 = $23;$60 = -17;
   label = 14;
  }
  if ((label|0) == 14) {
   __ZdlPv($33);
   $35 = $59;$37 = $60;
  }
  $34 = (($this) + 8|0);
  HEAP32[$34>>2] = $35;
  $36 = $37 | 1;
  HEAP32[$this>>2] = $36;
  $38 = $36&255;
  $40 = $38;
 } else {
  $40 = $17;
 }
 $39 = $40 & 1;
 $41 = ($39<<24>>24)==(0);
 if ($41) {
  $44 = (($this) + 1|0);
  $__p$0$ph = $44;
 } else {
  $42 = (($this) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $__p$0$ph = $43;
 }
 $45 = ($0|0)==($1|0);
 if ($45) {
  $__p$0$lcssa = $__p$0$ph;
 } else {
  $47 = $0;$__p$02 = $__p$0$ph;
  while(1) {
   $46 = HEAP8[$47>>0]|0;
   HEAP8[$__p$02>>0] = $46;
   $48 = HEAP32[$__first>>2]|0;
   $49 = (($48) + 1|0);
   HEAP32[$__first>>2] = $49;
   $50 = (($__p$02) + 1|0);
   $51 = HEAP32[$__last>>2]|0;
   $52 = ($49|0)==($51|0);
   if ($52) {
    $__p$0$lcssa = $50;
    break;
   } else {
    $47 = $49;$__p$02 = $50;
   }
  }
 }
 HEAP8[$__p$0$lcssa>>0] = 0;
 $53 = HEAP8[$this>>0]|0;
 $54 = $53 & 1;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  $57 = $4 << 1;
  $58 = $57&255;
  HEAP8[$this>>0] = $58;
  STACKTOP = sp;return ($this|0);
 } else {
  $56 = (($this) + 4|0);
  HEAP32[$56>>2] = $4;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZN6il2cpp2vm14TypeNameParser23ParsePropertiesOptionalEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$3 = 0, $$pre = 0, $$pre73 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$lcssa$i$i$i = 0;
 var $__p$0$lcssa$i$i$i34 = 0, $__p$0$ph$i$i$i = 0, $__p$0$ph$i$i$i25 = 0, $__p$02$i$i$i = 0, $__p$02$i$i$i29 = 0, $cond = 0, $cond$i = 0, $cond$i18 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$ = 0, $not$69 = 0, $not$70 = 0, $not$71 = 0, $or$cond = 0, $or$cond72 = 0, $propertyName = 0, $propertyValue = 0, $scevgep$i$i = 0, $scevgep$i$i27 = 0;
 var $scevgep7$i$i = 0, $scevgep7$i$i31 = 0, $scevgep8$i$i = 0, $scevgep8$i$i32 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $propertyName = sp + 16|0;
 $propertyValue = sp + 4|0;
 $0 = (($this) + 8|0);
 $1 = (($propertyName) + 1|0);
 $2 = (($propertyValue) + 1|0);
 $3 = (($this) + 4|0);
 $4 = (($propertyValue) + 8|0);
 $5 = (($propertyValue) + 4|0);
 $6 = (($propertyName) + 8|0);
 $7 = (($propertyName) + 4|0);
 L1: while(1) {
  $8 = HEAP32[$this>>2]|0;
  $9 = HEAP8[$8>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $16 = (($8) + 1|0);
   $17 = $9&255;
   $18 = $17 >>> 1;
   $20 = $16;$21 = $18;
  } else {
   $12 = (($8) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($8) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $20 = $13;$21 = $15;
  }
  $19 = (($20) + ($21)|0);
  $22 = HEAP32[$0>>2]|0;
  $23 = ($22>>>0)<($19>>>0);
  if (!($23)) {
   $$3 = 1;
   label = 108;
   break;
  }
  $24 = HEAP8[$22>>0]|0;
  $25 = ($24<<24>>24)==(44);
  if (!($25)) {
   $$3 = 1;
   label = 108;
   break;
  }
  $26 = (($22) + 1|0);
  HEAP32[$0>>2] = $26;
  $27 = HEAP8[$8>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $34 = (($8) + 1|0);
   $35 = $27&255;
   $36 = $35 >>> 1;
   $38 = $34;$39 = $36;
  } else {
   $30 = (($8) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($8) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $38 = $31;$39 = $33;
  }
  $37 = (($38) + ($39)|0);
  $40 = ($26>>>0)<($37>>>0);
  if (!($40)) {
   $$3 = 0;
   label = 108;
   break;
  }
  $41 = (($8) + 1|0);
  $42 = (($8) + 8|0);
  $43 = (($8) + 4|0);
  $45 = $27;$55 = $26;
  while(1) {
   $44 = $45 & 1;
   $46 = ($44<<24>>24)==(0);
   if ($46) {
    $49 = $45&255;
    $50 = $49 >>> 1;
    $52 = $41;$53 = $50;
   } else {
    $47 = HEAP32[$42>>2]|0;
    $48 = HEAP32[$43>>2]|0;
    $52 = $47;$53 = $48;
   }
   $51 = (($52) + ($53)|0);
   $54 = ($55>>>0)<($51>>>0);
   if ($54) {
    $56 = HEAP8[$55>>0]|0;
    $57 = ($56<<24>>24)==(32);
    if (!($57)) {
     label = 17;
    }
   } else {
    label = 17;
   }
   if ((label|0) == 17) {
    label = 0;
    if ($46) {
     $60 = $45&255;
     $61 = $60 >>> 1;
     $63 = $41;$64 = $61;
    } else {
     $58 = HEAP32[$42>>2]|0;
     $59 = HEAP32[$43>>2]|0;
     $63 = $58;$64 = $59;
    }
    $62 = (($63) + ($64)|0);
    $65 = ($55>>>0)<($62>>>0);
    if (!($65)) {
     $70 = $55;
     break;
    }
    $66 = HEAP8[$55>>0]|0;
    $67 = ($66<<24>>24)==(9);
    if (!($67)) {
     $70 = $55;
     break;
    }
   }
   $68 = (($55) + 1|0);
   HEAP32[$0>>2] = $68;
   $$pre = HEAP8[$8>>0]|0;
   $45 = $$pre;$55 = $68;
  }
  while(1) {
   $69 = HEAP8[$70>>0]|0;
   $cond$i = ($69<<24>>24)==(61);
   if ($cond$i) {
    $85 = $70;
    break;
   }
   $71 = (($70) + 1|0);
   HEAP32[$0>>2] = $71;
   $72 = HEAP8[$8>>0]|0;
   $73 = $72 & 1;
   $74 = ($73<<24>>24)==(0);
   if ($74) {
    $77 = $72&255;
    $78 = $77 >>> 1;
    $80 = $41;$81 = $78;
   } else {
    $75 = HEAP32[$42>>2]|0;
    $76 = HEAP32[$43>>2]|0;
    $80 = $75;$81 = $76;
   }
   $79 = (($80) + ($81)|0);
   $82 = ($71>>>0)<($79>>>0);
   if ($82) {
    $70 = $71;
   } else {
    $85 = $71;
    break;
   }
  }
  $83 = $55;
  $84 = $85;
  $86 = (($84) - ($83))|0;
  $87 = ($86>>>0)>(4294967279);
  if ($87) {
   label = 29;
   break;
  }
  $88 = ($86>>>0)<(11);
  if ($88) {
   $89 = $86 << 1;
   $90 = $89&255;
   HEAP8[$propertyName>>0] = $90;
   $__p$0$ph$i$i$i = $1;
  } else {
   $91 = (($86) + 16)|0;
   $92 = $91 & -16;
   $93 = (__Znwj($92)|0);
   HEAP32[$6>>2] = $93;
   $94 = $92 | 1;
   HEAP32[$propertyName>>2] = $94;
   HEAP32[$7>>2] = $86;
   $__p$0$ph$i$i$i = $93;
  }
  $95 = ($55|0)==($85|0);
  if ($95) {
   $__p$0$lcssa$i$i$i = $__p$0$ph$i$i$i;
  } else {
   $96 = (0 - ($83))|0;
   $98 = $55;$__p$02$i$i$i = $__p$0$ph$i$i$i;
   while(1) {
    $97 = HEAP8[$98>>0]|0;
    HEAP8[$__p$02$i$i$i>>0] = $97;
    $99 = (($98) + 1|0);
    $100 = (($__p$02$i$i$i) + 1|0);
    $101 = ($99|0)==($85|0);
    if ($101) {
     break;
    } else {
     $98 = $99;$__p$02$i$i$i = $100;
    }
   }
   $scevgep$i$i = (($85) + ($96)|0);
   $scevgep7$i$i = $scevgep$i$i;
   $scevgep8$i$i = (($__p$0$ph$i$i$i) + ($scevgep7$i$i)|0);
   $__p$0$lcssa$i$i$i = $scevgep8$i$i;
  }
  HEAP8[$__p$0$lcssa$i$i$i>>0] = 0;
  $102 = HEAP32[$this>>2]|0;
  $103 = HEAP8[$102>>0]|0;
  $104 = $103 & 1;
  $105 = ($104<<24>>24)==(0);
  if ($105) {
   $110 = (($102) + 1|0);
   $111 = $103&255;
   $112 = $111 >>> 1;
   $114 = $110;$115 = $112;
  } else {
   $106 = (($102) + 8|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($102) + 4|0);
   $109 = HEAP32[$108>>2]|0;
   $114 = $107;$115 = $109;
  }
  $113 = (($114) + ($115)|0);
  $116 = HEAP32[$0>>2]|0;
  $117 = ($116>>>0)<($113>>>0);
  do {
   if ($117) {
    $118 = HEAP8[$116>>0]|0;
    $119 = ($118<<24>>24)==(61);
    if ($119) {
     $124 = (($116) + 1|0);
     HEAP32[$0>>2] = $124;
     $125 = HEAP8[$102>>0]|0;
     $126 = $125 & 1;
     $127 = ($126<<24>>24)==(0);
     if ($127) {
      $132 = (($102) + 1|0);
      $133 = $125&255;
      $134 = $133 >>> 1;
      $136 = $132;$137 = $134;
     } else {
      $128 = (($102) + 8|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = (($102) + 4|0);
      $131 = HEAP32[$130>>2]|0;
      $136 = $129;$137 = $131;
     }
     $135 = (($136) + ($137)|0);
     $138 = ($124>>>0)<($135>>>0);
     if ($138) {
      $140 = $124;
      while(1) {
       $139 = HEAP8[$140>>0]|0;
       $cond$i18 = ($139<<24>>24)==(44);
       if ($cond$i18) {
        $158 = $140;
        break;
       }
       $141 = (($140) + 1|0);
       HEAP32[$0>>2] = $141;
       $142 = HEAP8[$102>>0]|0;
       $143 = $142 & 1;
       $144 = ($143<<24>>24)==(0);
       if ($144) {
        $149 = (($102) + 1|0);
        $150 = $142&255;
        $151 = $150 >>> 1;
        $153 = $149;$154 = $151;
       } else {
        $145 = (($102) + 8|0);
        $146 = HEAP32[$145>>2]|0;
        $147 = (($102) + 4|0);
        $148 = HEAP32[$147>>2]|0;
        $153 = $146;$154 = $148;
       }
       $152 = (($153) + ($154)|0);
       $155 = ($141>>>0)<($152>>>0);
       if ($155) {
        $140 = $141;
       } else {
        $158 = $141;
        break;
       }
      }
      $156 = $124;
      $157 = $158;
      $159 = (($157) - ($156))|0;
      $160 = ($159>>>0)>(4294967279);
      if ($160) {
       label = 55;
       break L1;
      }
      $163 = ($159>>>0)<(11);
      if ($163) {
       $164 = $159 << 1;
       $165 = $164&255;
       HEAP8[$propertyValue>>0] = $165;
       $__p$0$ph$i$i$i25 = $2;
      } else {
       $166 = (($159) + 16)|0;
       $167 = $166 & -16;
       __THREW__ = 0;
       $168 = (invoke_ii(2988,($167|0))|0);
       $169 = __THREW__; __THREW__ = 0;
       $170 = $169&1;
       if ($170) {
        label = 42;
        break L1;
       }
       HEAP32[$4>>2] = $168;
       $171 = $167 | 1;
       HEAP32[$propertyValue>>2] = $171;
       HEAP32[$5>>2] = $159;
       $__p$0$ph$i$i$i25 = $168;
      }
      $172 = ($124|0)==($158|0);
      if ($172) {
       $__p$0$lcssa$i$i$i34 = $__p$0$ph$i$i$i25;
      } else {
       $173 = (0 - ($156))|0;
       $175 = $124;$__p$02$i$i$i29 = $__p$0$ph$i$i$i25;
       while(1) {
        $174 = HEAP8[$175>>0]|0;
        HEAP8[$__p$02$i$i$i29>>0] = $174;
        $176 = (($175) + 1|0);
        $177 = (($__p$02$i$i$i29) + 1|0);
        $178 = ($176|0)==($158|0);
        if ($178) {
         break;
        } else {
         $175 = $176;$__p$02$i$i$i29 = $177;
        }
       }
       $scevgep$i$i27 = (($158) + ($173)|0);
       $scevgep7$i$i31 = $scevgep$i$i27;
       $scevgep8$i$i32 = (($__p$0$ph$i$i$i25) + ($scevgep7$i$i31)|0);
       $__p$0$lcssa$i$i$i34 = $scevgep8$i$i32;
      }
      HEAP8[$__p$0$lcssa$i$i$i34>>0] = 0;
      $179 = HEAP8[$propertyName>>0]|0;
      $180 = $179 & 1;
      $181 = ($180<<24>>24)==(0);
      if ($181) {
       $184 = $179&255;
       $185 = $184 >>> 1;
       $187 = $185;$189 = $1;
      } else {
       $182 = HEAP32[$7>>2]|0;
       $183 = HEAP32[$6>>2]|0;
       $187 = $182;$189 = $183;
      }
      $186 = ($187>>>0)>(7);
      $188 = $186 ? 7 : $187;
      $190 = (_memcmp($189,390016,$188)|0);
      $191 = ($190|0)==(0);
      do {
       if ($191) {
        $192 = $186 ^ 1;
        $not$71 = ($187>>>0)>(6);
        $193 = $not$71 & $192;
        if (!($193)) {
         label = 74;
         break;
        }
        $194 = HEAP32[$3>>2]|0;
        $195 = (($194) + 96|0);
        $196 = (($194) + 98|0);
        $197 = (($194) + 100|0);
        $198 = (($194) + 102|0);
        __THREW__ = 0;
        $199 = (invoke_iiiiii(184,($propertyValue|0),($195|0),($196|0),($197|0),($198|0))|0);
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         label = 72;
         break L1;
        }
        if ($199) {
         label = 100;
        } else {
         $$0 = 1;
        }
       } else {
        label = 74;
       }
      } while(0);
      L88: do {
       if ((label|0) == 74) {
        label = 0;
        if ($181) {
         $210 = $179&255;
         $211 = $210 >>> 1;
         $213 = $211;$215 = $1;
        } else {
         $208 = HEAP32[$7>>2]|0;
         $209 = HEAP32[$6>>2]|0;
         $213 = $208;$215 = $209;
        }
        $212 = ($213>>>0)>(9);
        $214 = $212 ? 9 : $213;
        $216 = (_memcmp($215,390024,$214)|0);
        $217 = ($216|0)==(0);
        do {
         if ($217) {
          $218 = $212 ^ 1;
          $not$70 = ($213>>>0)>(8);
          $219 = $not$70 & $218;
          if (!($219)) {
           break;
          }
          $220 = HEAP8[$propertyValue>>0]|0;
          $221 = $220 & 1;
          $222 = ($221<<24>>24)==(0);
          if ($222) {
           $225 = $220&255;
           $226 = $225 >>> 1;
           $228 = $226;$230 = $2;
          } else {
           $223 = HEAP32[$5>>2]|0;
           $224 = HEAP32[$4>>2]|0;
           $228 = $223;$230 = $224;
          }
          $227 = ($228>>>0)>(4);
          $229 = $227 ? 4 : $228;
          $231 = (_memcmp($230,390040,$229)|0);
          $232 = ($231|0)==(0);
          $233 = ($228|0)==(4);
          $or$cond = $232 & $233;
          if ($or$cond) {
           label = 100;
           break L88;
          }
          $234 = HEAP32[$3>>2]|0;
          $235 = (($234) + 60|0);
          __THREW__ = 0;
          (invoke_iii(2233,($235|0),($propertyValue|0))|0);
          $236 = __THREW__; __THREW__ = 0;
          $237 = $236&1;
          if ($237) {
           label = 72;
           break L1;
          } else {
           label = 100;
           break L88;
          }
         }
        } while(0);
        if ($181) {
         $240 = $179&255;
         $241 = $240 >>> 1;
         $243 = $241;$245 = $1;
        } else {
         $238 = HEAP32[$7>>2]|0;
         $239 = HEAP32[$6>>2]|0;
         $243 = $238;$245 = $239;
        }
        $242 = ($243>>>0)>(14);
        $244 = $242 ? 14 : $243;
        $246 = (_memcmp($245,390048,$244)|0);
        $247 = ($246|0)==(0);
        do {
         if ($247) {
          $248 = $242 ^ 1;
          $not$69 = ($243>>>0)>(13);
          $249 = $not$69 & $248;
          if (!($249)) {
           break;
          }
          $250 = HEAP8[$propertyValue>>0]|0;
          $251 = $250 & 1;
          $252 = ($251<<24>>24)==(0);
          if ($252) {
           $255 = $250&255;
           $256 = $255 >>> 1;
           $258 = $256;$260 = $2;
          } else {
           $253 = HEAP32[$5>>2]|0;
           $254 = HEAP32[$4>>2]|0;
           $258 = $253;$260 = $254;
          }
          $257 = ($258>>>0)>(4);
          $259 = $257 ? 4 : $258;
          $261 = (_memcmp($260,390040,$259)|0);
          $262 = ($261|0)==(0);
          $263 = ($258|0)==(4);
          $or$cond72 = $262 & $263;
          if ($or$cond72) {
           label = 100;
           break L88;
          }
          HEAP32[$vararg_buffer>>2] = 390064;
          (_printf((389944|0),($vararg_buffer|0))|0);
          label = 100;
          break L88;
         }
        } while(0);
        if ($181) {
         $266 = $179&255;
         $267 = $266 >>> 1;
         $269 = $267;$271 = $1;
        } else {
         $264 = HEAP32[$7>>2]|0;
         $265 = HEAP32[$6>>2]|0;
         $269 = $264;$271 = $265;
        }
        $268 = ($269>>>0)>(7);
        $270 = $268 ? 7 : $269;
        $272 = (_memcmp($271,390104,$270)|0);
        $273 = ($272|0)==(0);
        if (!($273)) {
         $$0 = 1;
         break;
        }
        $274 = $268 ^ 1;
        $not$ = ($269>>>0)>(6);
        $275 = $not$ & $274;
        if (!($275)) {
         $$0 = 1;
         break;
        }
        $276 = HEAP32[$3>>2]|0;
        $277 = (($276) + 36|0);
        __THREW__ = 0;
        (invoke_iii(2233,($277|0),($propertyValue|0))|0);
        $278 = __THREW__; __THREW__ = 0;
        $279 = $278&1;
        if ($279) {
         label = 72;
         break L1;
        } else {
         label = 100;
        }
       }
      } while(0);
      if ((label|0) == 100) {
       label = 0;
       $$0 = 0;
      }
      $280 = HEAP8[$propertyValue>>0]|0;
      $281 = $280 & 1;
      $282 = ($281<<24>>24)==(0);
      if ($282) {
       $$1 = $$0;
       break;
      }
      $283 = HEAP32[$4>>2]|0;
      __ZdlPv($283);
      $$1 = $$0;
     } else {
      $$1 = 1;
     }
    } else {
     $$1 = 1;
    }
   } else {
    $$1 = 1;
   }
  } while(0);
  $284 = HEAP8[$propertyName>>0]|0;
  $285 = $284 & 1;
  $286 = ($285<<24>>24)==(0);
  if (!($286)) {
   $287 = HEAP32[$6>>2]|0;
   __ZdlPv($287);
  }
  $cond = ($$1|0)==(1);
  if ($cond) {
   $$3 = 0;
   label = 108;
   break;
  }
 }
 do {
  if ((label|0) == 29) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  else if ((label|0) == 42) {
   $120 = ___cxa_find_matching_catch()|0;
   $121 = tempRet0;
   $lpad$phi$index = $120;$lpad$phi$index2 = $121;
   label = 44;
  }
  else if ((label|0) == 55) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $161 = __THREW__; __THREW__ = 0;
   $162 = $161&1;
   if ($162) {
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    $lpad$phi$index = $122;$lpad$phi$index2 = $123;
    label = 44;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 72) {
   $202 = ___cxa_find_matching_catch()|0;
   $203 = tempRet0;
   $204 = HEAP8[$propertyValue>>0]|0;
   $205 = $204 & 1;
   $206 = ($205<<24>>24)==(0);
   if ($206) {
    $$01 = $203;$$02 = $202;$289 = $179;
   } else {
    $207 = HEAP32[$4>>2]|0;
    __ZdlPv($207);
    $$01 = $203;$$02 = $202;$289 = $179;
   }
  }
  else if ((label|0) == 108) {
   STACKTOP = sp;return ($$3|0);
  }
 } while(0);
 if ((label|0) == 44) {
  $$pre73 = HEAP8[$propertyName>>0]|0;
  $$01 = $lpad$phi$index2;$$02 = $lpad$phi$index;$289 = $$pre73;
 }
 $288 = $289 & 1;
 $290 = ($288<<24>>24)==(0);
 if ($290) {
  ___resumeException($$02|0);
  // unreachable;
 }
 $291 = HEAP32[$6>>2]|0;
 __ZdlPv($291);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN6il2cpp2vm14TypeNameParser12ParseVersionERKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEERtSB_SB_SB_($version,$major,$minor,$build,$revision) {
 $version = $version|0;
 $major = $major|0;
 $minor = $minor|0;
 $build = $build|0;
 $revision = $revision|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $component = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $component = sp + 36|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = sp + 24|0;
 $3 = HEAP8[$version>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = $3&255;
  $9 = $8 >>> 1;
  $11 = $9;
 } else {
  $6 = (($version) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $11 = $7;
 }
 $10 = ($11|0)==(0);
 if ($10) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 if ($5) {
  $14 = (($version) + 1|0);
  $15 = $14;
 } else {
  $12 = (($version) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $15 = $13;
 }
 $16 = (_memchr($15,46,$11)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $18 = $16;
 $19 = $15;
 $20 = (($18) - ($19))|0;
 $21 = ($20|0)==(-1);
 if ($21) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 if ($5) {
  $26 = $3&255;
  $27 = $26 >>> 1;
  $28 = (($version) + 1|0);
  $30 = $27;$44 = $28;
 } else {
  $22 = (($version) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($version) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $30 = $23;$44 = $25;
 }
 $29 = ($30>>>0)<($20>>>0);
 $31 = $29 ? $30 : $20;
 $32 = ($31>>>0)>(4294967279);
 if ($32) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $33 = ($31>>>0)<(11);
 if ($33) {
  $34 = $31 << 1;
  $35 = $34&255;
  HEAP8[$component>>0] = $35;
  $36 = (($component) + 1|0);
  $$pre$phiZ2D = $component;$47 = $35;$__p$0$i$i = $36;
 } else {
  $37 = (($31) + 16)|0;
  $38 = $37 & -16;
  $39 = (__Znwj($38)|0);
  $40 = (($component) + 8|0);
  HEAP32[$40>>2] = $39;
  $41 = $38 | 1;
  HEAP32[$component>>2] = $41;
  $42 = (($component) + 4|0);
  HEAP32[$42>>2] = $31;
  $43 = $41&255;
  $$pre$phiZ2D = $component;$47 = $43;$__p$0$i$i = $39;
 }
 _memcpy(($__p$0$i$i|0),($44|0),($31|0))|0;
 $45 = (($__p$0$i$i) + ($31)|0);
 HEAP8[$45>>0] = 0;
 $46 = $47 & 1;
 $48 = ($46<<24>>24)==(0);
 if ($48) {
  $51 = (($component) + 1|0);
  $52 = $51;
 } else {
  $49 = (($component) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  $52 = $50;
 }
 $53 = (_atoi($52)|0);
 $54 = $53&65535;
 HEAP16[$major>>1] = $54;
 $55 = (($20) + 1)|0;
 $56 = HEAP8[$version>>0]|0;
 $57 = $56 & 1;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $61 = $56&255;
  $62 = $61 >>> 1;
  $64 = $62;
 } else {
  $59 = (($version) + 4|0);
  $60 = HEAP32[$59>>2]|0;
  $64 = $60;
 }
 $63 = ($64>>>0)>($55>>>0);
 L37: do {
  if ($63) {
   if ($58) {
    $67 = (($version) + 1|0);
    $69 = $67;
   } else {
    $65 = (($version) + 8|0);
    $66 = HEAP32[$65>>2]|0;
    $69 = $66;
   }
   $68 = (($69) + ($55)|0);
   $70 = (($64) - ($55))|0;
   $71 = (_memchr($68,46,$70)|0);
   $72 = ($71|0)==(0|0);
   if ($72) {
    $$02 = 0;$189 = $47;
   } else {
    $73 = $71;
    $74 = $69;
    $75 = (($73) - ($74))|0;
    $76 = ($75|0)==(-1);
    if ($76) {
     $$02 = 0;$189 = $47;
    } else {
     $79 = (($75) - ($55))|0;
     __THREW__ = 0;
     invoke_viiiii(85,($0|0),($version|0),($55|0),($79|0),0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     do {
      if ($81) {
       label = 30;
      } else {
       __THREW__ = 0;
       (invoke_iii(2233,($component|0),($0|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        $120 = ___cxa_find_matching_catch()|0;
        $121 = tempRet0;
        $122 = HEAP8[$0>>0]|0;
        $123 = $122 & 1;
        $124 = ($123<<24>>24)==(0);
        if ($124) {
         $$0 = $121;$$01 = $120;
         break;
        }
        $125 = (($0) + 8|0);
        $126 = HEAP32[$125>>2]|0;
        __ZdlPv($126);
        $$0 = $121;$$01 = $120;
        break;
       }
       $84 = HEAP8[$0>>0]|0;
       $85 = $84 & 1;
       $86 = ($85<<24>>24)==(0);
       if (!($86)) {
        $87 = (($0) + 8|0);
        $88 = HEAP32[$87>>2]|0;
        __ZdlPv($88);
       }
       $89 = HEAP8[$$pre$phiZ2D>>0]|0;
       $90 = $89 & 1;
       $91 = ($90<<24>>24)==(0);
       if ($91) {
        $94 = (($component) + 1|0);
        $95 = $94;
       } else {
        $92 = (($component) + 8|0);
        $93 = HEAP32[$92>>2]|0;
        $95 = $93;
       }
       $96 = (_atoi($95)|0);
       $97 = $96&65535;
       HEAP16[$minor>>1] = $97;
       $98 = (($75) + 1)|0;
       $99 = HEAP8[$version>>0]|0;
       $100 = $99 & 1;
       $101 = ($100<<24>>24)==(0);
       if ($101) {
        $104 = $99&255;
        $105 = $104 >>> 1;
        $107 = $105;
       } else {
        $102 = (($version) + 4|0);
        $103 = HEAP32[$102>>2]|0;
        $107 = $103;
       }
       $106 = ($107>>>0)>($98>>>0);
       if (!($106)) {
        $$02 = 0;$189 = $89;
        break L37;
       }
       if ($101) {
        $110 = (($version) + 1|0);
        $112 = $110;
       } else {
        $108 = (($version) + 8|0);
        $109 = HEAP32[$108>>2]|0;
        $112 = $109;
       }
       $111 = (($112) + ($98)|0);
       $113 = (($107) - ($98))|0;
       $114 = (_memchr($111,46,$113)|0);
       $115 = ($114|0)==(0|0);
       if ($115) {
        $$02 = 0;$189 = $89;
        break L37;
       }
       $116 = $114;
       $117 = $112;
       $118 = (($116) - ($117))|0;
       $119 = ($118|0)==(-1);
       if ($119) {
        $$02 = 0;$189 = $89;
        break L37;
       }
       $127 = (($118) - ($98))|0;
       __THREW__ = 0;
       invoke_viiiii(85,($1|0),($version|0),($98|0),($127|0),0);
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 30;
        break;
       }
       __THREW__ = 0;
       (invoke_iii(2233,($component|0),($1|0))|0);
       $130 = __THREW__; __THREW__ = 0;
       $131 = $130&1;
       if ($131) {
        $174 = ___cxa_find_matching_catch()|0;
        $175 = tempRet0;
        $176 = HEAP8[$1>>0]|0;
        $177 = $176 & 1;
        $178 = ($177<<24>>24)==(0);
        if ($178) {
         $$0 = $175;$$01 = $174;
         break;
        }
        $179 = (($1) + 8|0);
        $180 = HEAP32[$179>>2]|0;
        __ZdlPv($180);
        $$0 = $175;$$01 = $174;
        break;
       }
       $132 = HEAP8[$1>>0]|0;
       $133 = $132 & 1;
       $134 = ($133<<24>>24)==(0);
       if (!($134)) {
        $135 = (($1) + 8|0);
        $136 = HEAP32[$135>>2]|0;
        __ZdlPv($136);
       }
       $137 = HEAP8[$$pre$phiZ2D>>0]|0;
       $138 = $137 & 1;
       $139 = ($138<<24>>24)==(0);
       if ($139) {
        $142 = (($component) + 1|0);
        $143 = $142;
       } else {
        $140 = (($component) + 8|0);
        $141 = HEAP32[$140>>2]|0;
        $143 = $141;
       }
       $144 = (_atoi($143)|0);
       $145 = $144&65535;
       HEAP16[$build>>1] = $145;
       $146 = (($118) + 1)|0;
       $147 = HEAP8[$version>>0]|0;
       $148 = $147 & 1;
       $149 = ($148<<24>>24)==(0);
       if ($149) {
        $152 = $147&255;
        $153 = $152 >>> 1;
        $155 = $153;
       } else {
        $150 = (($version) + 4|0);
        $151 = HEAP32[$150>>2]|0;
        $155 = $151;
       }
       $154 = (($155) - ($146))|0;
       __THREW__ = 0;
       invoke_viiiii(85,($2|0),($version|0),($146|0),($154|0),0);
       $156 = __THREW__; __THREW__ = 0;
       $157 = $156&1;
       if ($157) {
        label = 30;
        break;
       }
       __THREW__ = 0;
       (invoke_iii(2233,($component|0),($2|0))|0);
       $158 = __THREW__; __THREW__ = 0;
       $159 = $158&1;
       if ($159) {
        $181 = ___cxa_find_matching_catch()|0;
        $182 = tempRet0;
        $183 = HEAP8[$2>>0]|0;
        $184 = $183 & 1;
        $185 = ($184<<24>>24)==(0);
        if ($185) {
         $$0 = $182;$$01 = $181;
         break;
        }
        $186 = (($2) + 8|0);
        $187 = HEAP32[$186>>2]|0;
        __ZdlPv($187);
        $$0 = $182;$$01 = $181;
        break;
       }
       $160 = HEAP8[$2>>0]|0;
       $161 = $160 & 1;
       $162 = ($161<<24>>24)==(0);
       if (!($162)) {
        $163 = (($2) + 8|0);
        $164 = HEAP32[$163>>2]|0;
        __ZdlPv($164);
       }
       $165 = HEAP8[$$pre$phiZ2D>>0]|0;
       $166 = $165 & 1;
       $167 = ($166<<24>>24)==(0);
       if ($167) {
        $170 = (($component) + 1|0);
        $171 = $170;
       } else {
        $168 = (($component) + 8|0);
        $169 = HEAP32[$168>>2]|0;
        $171 = $169;
       }
       $172 = (_atoi($171)|0);
       $173 = $172&65535;
       HEAP16[$revision>>1] = $173;
       $$02 = 1;$189 = $165;
       break L37;
      }
     } while(0);
     if ((label|0) == 30) {
      $77 = ___cxa_find_matching_catch()|0;
      $78 = tempRet0;
      $$0 = $78;$$01 = $77;
     }
     $193 = HEAP8[$$pre$phiZ2D>>0]|0;
     $194 = $193 & 1;
     $195 = ($194<<24>>24)==(0);
     if ($195) {
      ___resumeException($$01|0);
      // unreachable;
     }
     $196 = (($component) + 8|0);
     $197 = HEAP32[$196>>2]|0;
     __ZdlPv($197);
     ___resumeException($$01|0);
     // unreachable;
    }
   }
  } else {
   $$02 = 0;$189 = $47;
  }
 } while(0);
 $188 = $189 & 1;
 $190 = ($188<<24>>24)==(0);
 if ($190) {
  $$1 = $$02;
  STACKTOP = sp;return ($$1|0);
 }
 $191 = (($component) + 8|0);
 $192 = HEAP32[$191>>2]|0;
 __ZdlPv($192);
 $$1 = $$02;
 STACKTOP = sp;return ($$1|0);
}
function __ZN6il2cpp2vm17TypeNameParseInfoC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _memset(($this|0),0,140)|0;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm17TypeNameParseInfoD2Ev($this) {
 $this = $this|0;
 var $$3 = 0, $$34 = 0, $$pr = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i27 = 0, $$pre$i$i$i24 = 0, $$pre$i$i$i28 = 0, $$pre60 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i32 = 0, $__new_last2$i$i$i$i$i41 = 0, $__new_last2$i$i$i$i$i7 = 0, $__new_last2$i$i$i15 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i33 = 0, $scevgep$i$i$i$i$i42 = 0, $scevgep$i$i$i$i$i8 = 0, $scevgep$i$i$i16 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i12 = 0, $scevgep4$i$i$i$i$i37 = 0, $scevgep4$i$i$i$i$i46 = 0;
 var $scevgep4$i$i$i20 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i10 = 0, $uglygep$i$i$i$i$i35 = 0, $uglygep$i$i$i$i$i44 = 0, $uglygep$i$i$i18 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i11 = 0, $uglygep3$i$i$i$i$i36 = 0, $uglygep3$i$i$i$i$i45 = 0, $uglygep3$i$i$i19 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 do {
  if ($4) {
   label = 15;
  } else {
   $132 = $3;$6 = $1;
   while(1) {
    $5 = HEAP32[$6>>2]|0;
    $7 = ($5|0)==(0|0);
    if ($7) {
     $12 = $132;
    } else {
     __THREW__ = 0;
     invoke_vi(3306,($5|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __ZdlPv($5);
     $$pre60 = HEAP32[$2>>2]|0;
     $12 = $$pre60;
    }
    $10 = (($6) + 4|0);
    $11 = ($10|0)==($12|0);
    if ($11) {
     label = 13;
     break;
    } else {
     $132 = $12;$6 = $10;
    }
   }
   if ((label|0) == 13) {
    $$pre = HEAP32[$0>>2]|0;
    $31 = ($12|0)==($$pre|0);
    if ($31) {
     label = 15;
     break;
    }
    $__new_last2$i$i$i = $$pre;
    $scevgep$i$i$i = (($12) + -4|0);
    $32 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($32)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $33 = $uglygep3$i$i$i >>> 2;
    $34 = $33 ^ -1;
    $scevgep4$i$i$i = (($12) + ($34<<2)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i;
    label = 15;
    break;
   }
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   __ZdlPv($5);
   $15 = (($this) + 128|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $18 = (($this) + 132|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($16|0);
    if ($20) {
     $30 = $16;
    } else {
     $22 = $19;
     while(1) {
      $21 = (($22) + -12|0);
      HEAP32[$18>>2] = $21;
      $23 = HEAP8[$21>>0]|0;
      $24 = $23 & 1;
      $25 = ($24<<24>>24)==(0);
      if ($25) {
       $27 = $21;
      } else {
       $28 = (($22) + -4|0);
       $29 = HEAP32[$28>>2]|0;
       __ZdlPv($29);
       $$pre$i$i$i$i$i = HEAP32[$18>>2]|0;
       $27 = $$pre$i$i$i$i$i;
      }
      $26 = ($27|0)==($16|0);
      if ($26) {
       break;
      } else {
       $22 = $27;
      }
     }
     $$pre$i$i$i = HEAP32[$15>>2]|0;
     $30 = $$pre$i$i$i;
    }
    __ZdlPv($30);
   }
   $98 = HEAP32[$0>>2]|0;
   $99 = ($98|0)==(0|0);
   if (!($99)) {
    $100 = HEAP32[$2>>2]|0;
    $101 = ($100|0)==($98|0);
    if (!($101)) {
     $__new_last2$i$i$i$i$i7 = $98;
     $scevgep$i$i$i$i$i8 = (($100) + -4|0);
     $102 = (0 - ($__new_last2$i$i$i$i$i7))|0;
     $uglygep$i$i$i$i$i10 = (($scevgep$i$i$i$i$i8) + ($102)|0);
     $uglygep3$i$i$i$i$i11 = $uglygep$i$i$i$i$i10;
     $103 = $uglygep3$i$i$i$i$i11 >>> 2;
     $104 = $103 ^ -1;
     $scevgep4$i$i$i$i$i12 = (($100) + ($104<<2)|0);
     HEAP32[$2>>2] = $scevgep4$i$i$i$i$i12;
    }
    __ZdlPv($98);
   }
   $105 = (($this) + 104|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($106|0)==(0|0);
   if (!($107)) {
    $108 = (($this) + 108|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($109|0)==($106|0);
    if (!($110)) {
     $__new_last2$i$i$i$i$i = $106;
     $scevgep$i$i$i$i$i = (($109) + -4|0);
     $111 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($111)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $112 = $uglygep3$i$i$i$i$i >>> 2;
     $113 = $112 ^ -1;
     $scevgep4$i$i$i$i$i = (($109) + ($113<<2)|0);
     HEAP32[$108>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($106);
   }
   $116 = (($this) + 24|0);
   __THREW__ = 0;
   invoke_vi(3366,($116|0));
   $117 = __THREW__; __THREW__ = 0;
   $118 = $117&1;
   if ($118) {
    $130 = ___cxa_find_matching_catch(0|0)|0;
    $131 = tempRet0;
    ___clang_call_terminate($130);
    // unreachable;
   } else {
    $$3 = $14;$$34 = $13;
   }
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   $35 = (($this) + 104|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($this) + 108|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==($36|0);
   if (!($39)) {
    $__new_last2$i$i$i15 = $36;
    $scevgep$i$i$i16 = (($38) + -4|0);
    $40 = (0 - ($__new_last2$i$i$i15))|0;
    $uglygep$i$i$i18 = (($scevgep$i$i$i16) + ($40)|0);
    $uglygep3$i$i$i19 = $uglygep$i$i$i18;
    $41 = $uglygep3$i$i$i19 >>> 2;
    $42 = $41 ^ -1;
    $scevgep4$i$i$i20 = (($38) + ($42<<2)|0);
    HEAP32[$37>>2] = $scevgep4$i$i$i20;
   }
   $43 = (($this) + 128|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($this) + 132|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($44|0);
   if ($47) {
    $58 = $44;
   } else {
    $49 = $46;
    while(1) {
     $48 = (($49) + -12|0);
     HEAP32[$45>>2] = $48;
     $50 = HEAP8[$48>>0]|0;
     $51 = $50 & 1;
     $52 = ($51<<24>>24)==(0);
     if ($52) {
      $54 = $48;
     } else {
      $55 = (($49) + -4|0);
      $56 = HEAP32[$55>>2]|0;
      __ZdlPv($56);
      $$pre$i$i$i24 = HEAP32[$45>>2]|0;
      $54 = $$pre$i$i$i24;
     }
     $53 = ($54|0)==($44|0);
     if ($53) {
      break;
     } else {
      $49 = $54;
     }
    }
    $$pr = HEAP32[$43>>2]|0;
    $58 = $$pr;
   }
   $57 = ($58|0)==(0|0);
   if (!($57)) {
    $59 = ($44|0)==($58|0);
    if ($59) {
     $69 = $44;
    } else {
     $61 = $44;
     while(1) {
      $60 = (($61) + -12|0);
      HEAP32[$45>>2] = $60;
      $62 = HEAP8[$60>>0]|0;
      $63 = $62 & 1;
      $64 = ($63<<24>>24)==(0);
      if ($64) {
       $66 = $60;
      } else {
       $67 = (($61) + -4|0);
       $68 = HEAP32[$67>>2]|0;
       __ZdlPv($68);
       $$pre$i$i$i$i$i27 = HEAP32[$45>>2]|0;
       $66 = $$pre$i$i$i$i$i27;
      }
      $65 = ($66|0)==($58|0);
      if ($65) {
       break;
      } else {
       $61 = $66;
      }
     }
     $$pre$i$i$i28 = HEAP32[$43>>2]|0;
     $69 = $$pre$i$i$i28;
    }
    __ZdlPv($69);
   }
   $70 = HEAP32[$0>>2]|0;
   $71 = ($70|0)==(0|0);
   if (!($71)) {
    $72 = HEAP32[$2>>2]|0;
    $73 = ($72|0)==($70|0);
    if (!($73)) {
     $__new_last2$i$i$i$i$i32 = $70;
     $scevgep$i$i$i$i$i33 = (($72) + -4|0);
     $74 = (0 - ($__new_last2$i$i$i$i$i32))|0;
     $uglygep$i$i$i$i$i35 = (($scevgep$i$i$i$i$i33) + ($74)|0);
     $uglygep3$i$i$i$i$i36 = $uglygep$i$i$i$i$i35;
     $75 = $uglygep3$i$i$i$i$i36 >>> 2;
     $76 = $75 ^ -1;
     $scevgep4$i$i$i$i$i37 = (($72) + ($76<<2)|0);
     HEAP32[$2>>2] = $scevgep4$i$i$i$i$i37;
    }
    __ZdlPv($70);
   }
   $77 = HEAP32[$35>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    $79 = HEAP32[$37>>2]|0;
    $80 = ($79|0)==($77|0);
    if (!($80)) {
     $__new_last2$i$i$i$i$i41 = $77;
     $scevgep$i$i$i$i$i42 = (($79) + -4|0);
     $81 = (0 - ($__new_last2$i$i$i$i$i41))|0;
     $uglygep$i$i$i$i$i44 = (($scevgep$i$i$i$i$i42) + ($81)|0);
     $uglygep3$i$i$i$i$i45 = $uglygep$i$i$i$i$i44;
     $82 = $uglygep3$i$i$i$i$i45 >>> 2;
     $83 = $82 ^ -1;
     $scevgep4$i$i$i$i$i46 = (($79) + ($83<<2)|0);
     HEAP32[$37>>2] = $scevgep4$i$i$i$i$i46;
    }
    __ZdlPv($77);
   }
   $84 = (($this) + 24|0);
   __THREW__ = 0;
   invoke_vi(3366,($84|0));
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    $114 = ___cxa_find_matching_catch()|0;
    $115 = tempRet0;
    $$3 = $115;$$34 = $114;
    break;
   }
   $87 = (($this) + 12|0);
   $88 = HEAP8[$87>>0]|0;
   $89 = $88 & 1;
   $90 = ($89<<24>>24)==(0);
   if (!($90)) {
    $91 = (($this) + 20|0);
    $92 = HEAP32[$91>>2]|0;
    __ZdlPv($92);
   }
   $93 = HEAP8[$this>>0]|0;
   $94 = $93 & 1;
   $95 = ($94<<24>>24)==(0);
   if ($95) {
    STACKTOP = sp;return;
   }
   $96 = (($this) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   __ZdlPv($97);
   STACKTOP = sp;return;
  }
 } while(0);
 $119 = (($this) + 12|0);
 $120 = HEAP8[$119>>0]|0;
 $121 = $120 & 1;
 $122 = ($121<<24>>24)==(0);
 if (!($122)) {
  $123 = (($this) + 20|0);
  $124 = HEAP32[$123>>2]|0;
  __ZdlPv($124);
 }
 $125 = HEAP8[$this>>0]|0;
 $126 = $125 & 1;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  ___resumeException($$34|0);
  // unreachable;
 }
 $128 = (($this) + 8|0);
 $129 = HEAP32[$128>>2]|0;
 __ZdlPv($129);
 ___resumeException($$34|0);
 // unreachable;
}
function __ZN6il2cpp2vm4Type7GetTypeEPK10Il2CppType($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 16;
 $3 = $2 & 255;
 STACKTOP = sp;return ($3|0);
}
function __ZN6il2cpp2vm4Type15GetNameInternalERNSt3__119basic_ostringstreamIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPK10Il2CppType20Il2CppTypeNameFormatb($oss,$type,$format,$is_nested) {
 $oss = $oss|0;
 $type = $type|0;
 $format = $format|0;
 $is_nested = $is_nested|0;
 var $$ = 0, $$0 = 0, $$02$i$i$i = 0, $$0218 = 0, $$0317 = 0, $$04 = 0, $$10 = 0, $$11 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre29 = 0, $$pre30 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$lcssa$i$i$i = 0, $__p$0$ph$i$i$i = 0, $__p$01$i$i$i = 0, $format$off = 0, $i$026 = 0, $i3$022 = 0, $i3$022$us = 0, $i4$021 = 0, $scevgep$i$i$i = 0, $scevgep3$i$i$i = 0, $scevgep4$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($type) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 16;
 $4 = $3 & 255;
 switch ($4|0) {
 case 15:  {
  $119 = HEAP32[$type>>2]|0;
  $120 = ($format|0)==(3);
  $121 = $120 ? 2 : $format;
  __ZN6il2cpp2vm4Type15GetNameInternalERNSt3__119basic_ostringstreamIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPK10Il2CppType20Il2CppTypeNameFormatb($oss,$119,$121,0);
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,42)|0);
  $122 = HEAP32[$1>>2]|0;
  $123 = $122 & 1073741824;
  $124 = ($123|0)==(0);
  if (!($124)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,38)|0);
  }
  if (!($120)) {
   STACKTOP = sp;return;
  }
  $125 = HEAP32[$type>>2]|0;
  $126 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($125)|0);
  $127 = (($126) + 64|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (($128) + 24|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($oss,390112)|0);
  $132 = HEAP32[$130>>2]|0;
  $133 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($131,$132)|0);
  $134 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($133,390120)|0);
  $135 = (($130) + 48|0);
  $136 = HEAP16[$135>>1]|0;
  $137 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($134,$136)|0);
  $138 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($137,390136)|0);
  $139 = (($130) + 50|0);
  $140 = HEAP16[$139>>1]|0;
  $141 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($138,$140)|0);
  $142 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($141,390136)|0);
  $143 = (($130) + 52|0);
  $144 = HEAP16[$143>>1]|0;
  $145 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($142,$144)|0);
  $146 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($145,390136)|0);
  $147 = (($130) + 54|0);
  $148 = HEAP16[$147>>1]|0;
  $149 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($146,$148)|0);
  $150 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($149,390144)|0);
  $151 = (($130) + 4|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = ($152|0)==(0|0);
  if ($153) {
   $156 = 390160;
  } else {
   $154 = HEAP8[$152>>0]|0;
   $155 = ($154<<24>>24)==(0);
   $$8 = $155 ? 390160 : $152;
   $156 = $$8;
  }
  $157 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($150,$156)|0);
  $158 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($157,390168)|0);
  $159 = (($130) + 16|0);
  $160 = HEAP8[$159>>0]|0;
  $161 = ($160<<24>>24)==(0);
  $$9 = $161 ? 390040 : $159;
  $162 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($158,$$9)|0);
  $163 = (($130) + 44|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = $164 & 256;
  $166 = ($165|0)!=(0);
  $167 = $166 ? 390192 : 390216;
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($162,$167)|0);
  STACKTOP = sp;return;
  break;
 }
 case 30: case 19:  {
  $168 = $2 & 1073741824;
  $169 = ($168|0)==(0);
  if ($169) {
   STACKTOP = sp;return;
  }
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,38)|0);
  STACKTOP = sp;return;
  break;
 }
 case 20:  {
  $5 = HEAP32[$type>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($format|0)==(3);
  $10 = $9 ? 2 : $format;
  __ZN6il2cpp2vm4Type15GetNameInternalERNSt3__119basic_ostringstreamIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPK10Il2CppType20Il2CppTypeNameFormatb($oss,$8,$10,0);
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,91)|0);
  $11 = HEAP32[$type>>2]|0;
  $12 = (($11) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(1);
  if ($14) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,42)|0);
   $$pre29 = HEAP32[$type>>2]|0;
   $$phi$trans$insert = (($$pre29) + 4|0);
   $$pre30 = HEAP8[$$phi$trans$insert>>0]|0;
   $16 = $$pre30;
  } else {
   $16 = $13;
  }
  $15 = ($16&255)>(1);
  if ($15) {
   $i$026 = 1;
   while(1) {
    (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,44)|0);
    $17 = (($i$026) + 1)|0;
    $18 = HEAP32[$type>>2]|0;
    $19 = (($18) + 4|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    $22 = ($17|0)<($21|0);
    if ($22) {
     $i$026 = $17;
    } else {
     break;
    }
   }
  }
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,93)|0);
  $23 = HEAP32[$1>>2]|0;
  $24 = $23 & 1073741824;
  $25 = ($24|0)==(0);
  if (!($25)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,38)|0);
  }
  if (!($9)) {
   STACKTOP = sp;return;
  }
  $26 = HEAP32[$type>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 64|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 24|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($oss,390112)|0);
  $33 = HEAP32[$31>>2]|0;
  $34 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($32,$33)|0);
  $35 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($34,390120)|0);
  $36 = (($31) + 48|0);
  $37 = HEAP16[$36>>1]|0;
  $38 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($35,$37)|0);
  $39 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($38,390136)|0);
  $40 = (($31) + 50|0);
  $41 = HEAP16[$40>>1]|0;
  $42 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($39,$41)|0);
  $43 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($42,390136)|0);
  $44 = (($31) + 52|0);
  $45 = HEAP16[$44>>1]|0;
  $46 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($43,$45)|0);
  $47 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($46,390136)|0);
  $48 = (($31) + 54|0);
  $49 = HEAP16[$48>>1]|0;
  $50 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($47,$49)|0);
  $51 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($50,390144)|0);
  $52 = (($31) + 4|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $57 = 390160;
  } else {
   $55 = HEAP8[$53>>0]|0;
   $56 = ($55<<24>>24)==(0);
   $$ = $56 ? 390160 : $53;
   $57 = $$;
  }
  $58 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($51,$57)|0);
  $59 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($58,390168)|0);
  $60 = (($31) + 16|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  $$5 = $62 ? 390040 : $60;
  $63 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($59,$$5)|0);
  $64 = (($31) + 44|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = $65 & 256;
  $67 = ($66|0)!=(0);
  $68 = $67 ? 390192 : 390216;
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($63,$68)|0);
  STACKTOP = sp;return;
  break;
 }
 case 29:  {
  $69 = HEAP32[$type>>2]|0;
  $70 = (($69) + 48|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($format|0)==(3);
  $73 = $72 ? 2 : $format;
  __ZN6il2cpp2vm4Type15GetNameInternalERNSt3__119basic_ostringstreamIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPK10Il2CppType20Il2CppTypeNameFormatb($oss,$71,$73,0);
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($oss,390224)|0);
  $74 = HEAP32[$1>>2]|0;
  $75 = $74 & 1073741824;
  $76 = ($75|0)==(0);
  if (!($76)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,38)|0);
  }
  if (!($72)) {
   STACKTOP = sp;return;
  }
  $77 = HEAP32[$type>>2]|0;
  $78 = (($77) + 64|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($79) + 24|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($oss,390112)|0);
  $83 = HEAP32[$81>>2]|0;
  $84 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($82,$83)|0);
  $85 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($84,390120)|0);
  $86 = (($81) + 48|0);
  $87 = HEAP16[$86>>1]|0;
  $88 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($85,$87)|0);
  $89 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($88,390136)|0);
  $90 = (($81) + 50|0);
  $91 = HEAP16[$90>>1]|0;
  $92 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($89,$91)|0);
  $93 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($92,390136)|0);
  $94 = (($81) + 52|0);
  $95 = HEAP16[$94>>1]|0;
  $96 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($93,$95)|0);
  $97 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($96,390136)|0);
  $98 = (($81) + 54|0);
  $99 = HEAP16[$98>>1]|0;
  $100 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($97,$99)|0);
  $101 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($100,390144)|0);
  $102 = (($81) + 4|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ($103|0)==(0|0);
  if ($104) {
   $107 = 390160;
  } else {
   $105 = HEAP8[$103>>0]|0;
   $106 = ($105<<24>>24)==(0);
   $$6 = $106 ? 390160 : $103;
   $107 = $$6;
  }
  $108 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($101,$107)|0);
  $109 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($108,390168)|0);
  $110 = (($81) + 16|0);
  $111 = HEAP8[$110>>0]|0;
  $112 = ($111<<24>>24)==(0);
  $$7 = $112 ? 390040 : $110;
  $113 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($109,$$7)|0);
  $114 = (($81) + 44|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = $115 & 256;
  $117 = ($116|0)!=(0);
  $118 = $117 ? 390192 : 390216;
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($113,$118)|0);
  STACKTOP = sp;return;
  break;
 }
 default: {
  $170 = (__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType($type)|0);
  $171 = (($170) + 24|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = ($172|0)==(0|0);
  if ($173) {
   $178 = (($170) + 4|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = HEAP8[$179>>0]|0;
   $181 = ($180<<24>>24)==(0);
   if (!($181)) {
    $182 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($oss,$179)|0);
    (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($182,46)|0);
   }
  } else {
   $174 = (($172) + 48|0);
   $175 = HEAP32[$174>>2]|0;
   __ZN6il2cpp2vm4Type15GetNameInternalERNSt3__119basic_ostringstreamIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPK10Il2CppType20Il2CppTypeNameFormatb($oss,$175,$format,1);
   $176 = ($format|0)==(0);
   $177 = $176 ? 46 : 43;
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,$177)|0);
  }
  $183 = ($format|0)==(0);
  do {
   if ($183) {
    $184 = HEAP32[$170>>2]|0;
    $185 = (_strchr($184,96)|0);
    $186 = ($185|0)==(0|0);
    L44: do {
     if ($186) {
      $207 = (_strlen(($184|0))|0);
      $208 = ($207>>>0)>(4294967279);
      do {
       if ($208) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $209 = __THREW__; __THREW__ = 0;
        $210 = $209&1;
        if (!($210)) {
         // unreachable;
        }
       } else {
        $211 = ($207>>>0)<(11);
        if ($211) {
         $212 = $207 << 1;
         $213 = $212&255;
         HEAP8[$0>>0] = $213;
         $214 = (($0) + 1|0);
         $__p$0$i$i$i = $214;
        } else {
         $215 = (($207) + 16)|0;
         $216 = $215 & -16;
         __THREW__ = 0;
         $217 = (invoke_ii(2988,($216|0))|0);
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if ($219) {
          break;
         }
         $220 = (($0) + 8|0);
         HEAP32[$220>>2] = $217;
         $221 = $216 | 1;
         HEAP32[$0>>2] = $221;
         $222 = (($0) + 4|0);
         HEAP32[$222>>2] = $207;
         $__p$0$i$i$i = $217;
        }
        _memcpy(($__p$0$i$i$i|0),($184|0),($207|0))|0;
        $223 = (($__p$0$i$i$i) + ($207)|0);
        HEAP8[$223>>0] = 0;
        $$0 = 0;$$04 = 1;
        break L44;
       }
      } while(0);
      $236 = ___cxa_find_matching_catch()|0;
      $237 = tempRet0;
      $$0218 = $236;$$0317 = $237;
      ___resumeException($$0218|0);
      // unreachable;
     } else {
      $187 = $184;
      $188 = $185;
      $189 = (($188) - ($187))|0;
      $190 = ($189>>>0)>(4294967279);
      if ($190) {
       __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
       // unreachable;
      }
      $191 = ($189>>>0)<(11);
      if ($191) {
       $192 = $189 << 1;
       $193 = $192&255;
       HEAP8[$0>>0] = $193;
       $194 = (($0) + 1|0);
       $__p$0$ph$i$i$i = $194;
      } else {
       $195 = (($189) + 16)|0;
       $196 = $195 & -16;
       $197 = (__Znwj($196)|0);
       $198 = (($0) + 8|0);
       HEAP32[$198>>2] = $197;
       $199 = $196 | 1;
       HEAP32[$0>>2] = $199;
       $200 = (($0) + 4|0);
       HEAP32[$200>>2] = $189;
       $__p$0$ph$i$i$i = $197;
      }
      $201 = ($184|0)==($185|0);
      if ($201) {
       $__p$0$lcssa$i$i$i = $__p$0$ph$i$i$i;
      } else {
       $$02$i$i$i = $184;$__p$01$i$i$i = $__p$0$ph$i$i$i;
       while(1) {
        $202 = HEAP8[$$02$i$i$i>>0]|0;
        HEAP8[$__p$01$i$i$i>>0] = $202;
        $203 = (($$02$i$i$i) + 1|0);
        $204 = (($__p$01$i$i$i) + 1|0);
        $205 = ($203|0)==($185|0);
        if ($205) {
         break;
        } else {
         $$02$i$i$i = $203;$__p$01$i$i$i = $204;
        }
       }
       $206 = (0 - ($187))|0;
       $scevgep$i$i$i = (($185) + ($206)|0);
       $scevgep3$i$i$i = $scevgep$i$i$i;
       $scevgep4$i$i$i = (($__p$0$ph$i$i$i) + ($scevgep3$i$i$i)|0);
       $__p$0$lcssa$i$i$i = $scevgep4$i$i$i;
      }
      HEAP8[$__p$0$lcssa$i$i$i>>0] = 0;
      $$0 = 1;$$04 = 0;
     }
    } while(0);
    __THREW__ = 0;
    (invoke_iii(2341,($oss|0),($0|0))|0);
    $224 = __THREW__; __THREW__ = 0;
    $225 = $224&1;
    if (!($225)) {
     if ($$04) {
      $226 = HEAP8[$0>>0]|0;
      $227 = $226 & 1;
      $228 = ($227<<24>>24)==(0);
      if (!($228)) {
       $229 = (($0) + 8|0);
       $230 = HEAP32[$229>>2]|0;
       __ZdlPv($230);
      }
     }
     if (!($$0)) {
      break;
     }
     $231 = HEAP8[$0>>0]|0;
     $232 = $231 & 1;
     $233 = ($232<<24>>24)==(0);
     if ($233) {
      break;
     }
     $234 = (($0) + 8|0);
     $235 = HEAP32[$234>>2]|0;
     __ZdlPv($235);
     break;
    }
    $238 = ___cxa_find_matching_catch()|0;
    $239 = tempRet0;
    if ($$04) {
     $240 = HEAP8[$0>>0]|0;
     $241 = $240 & 1;
     $242 = ($241<<24>>24)==(0);
     if ($242) {
      label = 60;
     } else {
      $243 = (($0) + 8|0);
      $244 = HEAP32[$243>>2]|0;
      __ZdlPv($244);
      if ($$0) {
       $$pre$phiZ2D = $0;
      } else {
       $$0218 = $238;$$0317 = $239;
       ___resumeException($$0218|0);
       // unreachable;
      }
     }
    } else {
     label = 60;
    }
    do {
     if ((label|0) == 60) {
      if ($$0) {
       $$pre$phiZ2D = $0;
       break;
      } else {
       $$0218 = $238;$$0317 = $239;
       ___resumeException($$0218|0);
       // unreachable;
      }
     }
    } while(0);
    $245 = HEAP8[$$pre$phiZ2D>>0]|0;
    $246 = $245 & 1;
    $247 = ($246<<24>>24)==(0);
    if ($247) {
     $$0218 = $238;$$0317 = $239;
     ___resumeException($$0218|0);
     // unreachable;
    }
    $248 = (($0) + 8|0);
    $249 = HEAP32[$248>>2]|0;
    __ZdlPv($249);
    $$0218 = $238;$$0317 = $239;
    ___resumeException($$0218|0);
    // unreachable;
   } else {
    $250 = HEAP32[$170>>2]|0;
    (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($oss,$250)|0);
   }
  } while(0);
  if ($is_nested) {
   STACKTOP = sp;return;
  }
  $251 = (($170) + 68|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = ($252|0)==(0|0);
  if ($253) {
   $294 = (($170) + 72|0);
   $295 = HEAP32[$294>>2]|0;
   $296 = ($295|0)==(0|0);
   if (!($296)) {
    $format$off = (($format) + -2)|0;
    $297 = ($format$off>>>0)>(1);
    if ($297) {
     $298 = $183 ? 60 : 91;
     (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,$298)|0);
     $299 = HEAP32[$294>>2]|0;
     $300 = (($299) + 16|0);
     $301 = HEAP32[$300>>2]|0;
     $302 = $301 << 1;
     $303 = ($302|0)>(0);
     if ($303) {
      $367 = $299;$i4$021 = 0;
      while(1) {
       $304 = ($i4$021|0)==(0);
       if ($304) {
        $306 = $367;
       } else {
        (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,44)|0);
        $$pre = HEAP32[$294>>2]|0;
        $306 = $$pre;
       }
       $305 = (($306) + 20|0);
       $307 = HEAP32[$305>>2]|0;
       $308 = HEAP32[$307>>2]|0;
       $309 = ((($308) + (($i4$021*28)|0)|0) + 12|0);
       $310 = HEAP32[$309>>2]|0;
       (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($oss,$310)|0);
       $311 = (($i4$021) + 1)|0;
       $312 = HEAP32[$294>>2]|0;
       $313 = (($312) + 16|0);
       $314 = HEAP32[$313>>2]|0;
       $315 = $314 << 1;
       $316 = $315 >> 1;
       $317 = ($311|0)<($316|0);
       if ($317) {
        $367 = $312;$i4$021 = $311;
       } else {
        break;
       }
      }
     }
     $318 = $183 ? 62 : 93;
     (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,$318)|0);
    }
   }
  } else {
   $254 = (($252) + 4|0);
   $255 = HEAP32[$254>>2]|0;
   $256 = ($format|0)==(2);
   $257 = $256 ? 3 : $format;
   $258 = $183 ? 60 : 91;
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,$258)|0);
   $259 = HEAP32[$255>>2]|0;
   $260 = ($259|0)==(0);
   L111: do {
    if (!($260)) {
     $261 = (($255) + 4|0);
     $262 = ($257|0)==(3);
     if ($262) {
      $i3$022$us = 0;
     } else {
      $i3$022 = 0;
      while(1) {
       $286 = ($i3$022|0)==(0);
       if (!($286)) {
        (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,44)|0);
       }
       $287 = HEAP32[$261>>2]|0;
       $288 = (($287) + ($i3$022<<2)|0);
       $289 = HEAP32[$288>>2]|0;
       __ZN6il2cpp2vm4Type15GetNameInternalERNSt3__119basic_ostringstreamIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPK10Il2CppType20Il2CppTypeNameFormatb($oss,$289,$257,0);
       $290 = (($i3$022) + 1)|0;
       $291 = HEAP32[$255>>2]|0;
       $292 = ($290>>>0)<($291>>>0);
       if ($292) {
        $i3$022 = $290;
       } else {
        break L111;
       }
      }
     }
     while(1) {
      $263 = HEAP32[$261>>2]|0;
      $264 = (($263) + ($i3$022$us<<2)|0);
      $265 = HEAP32[$264>>2]|0;
      $266 = ($i3$022$us|0)==(0);
      if (!($266)) {
       (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,44)|0);
      }
      $267 = (($265) + 4|0);
      $268 = HEAP32[$267>>2]|0;
      $269 = $268 & 16711680;
      $270 = ($269|0)==(1245184);
      if (!($270)) {
       $271 = HEAP32[$1>>2]|0;
       $272 = $271 & 16711680;
       $273 = ($272|0)==(1966080);
       if (!($273)) {
        (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,91)|0);
       }
      }
      $274 = HEAP32[$261>>2]|0;
      $275 = (($274) + ($i3$022$us<<2)|0);
      $276 = HEAP32[$275>>2]|0;
      __ZN6il2cpp2vm4Type15GetNameInternalERNSt3__119basic_ostringstreamIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPK10Il2CppType20Il2CppTypeNameFormatb($oss,$276,3,0);
      $277 = HEAP32[$267>>2]|0;
      $278 = $277 & 16711680;
      $279 = ($278|0)==(1245184);
      if (!($279)) {
       $280 = HEAP32[$1>>2]|0;
       $281 = $280 & 16711680;
       $282 = ($281|0)==(1966080);
       if (!($282)) {
        (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,93)|0);
       }
      }
      $283 = (($i3$022$us) + 1)|0;
      $284 = HEAP32[$255>>2]|0;
      $285 = ($283>>>0)<($284>>>0);
      if ($285) {
       $i3$022$us = $283;
      } else {
       break;
      }
     }
    }
   } while(0);
   $293 = $183 ? 62 : 93;
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,$293)|0);
  }
  $319 = HEAP32[$1>>2]|0;
  $320 = $319 & 1073741824;
  $321 = ($320|0)==(0);
  if (!($321)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($oss,38)|0);
  }
  $322 = ($format|0)==(3);
  if (!($322)) {
   STACKTOP = sp;return;
  }
  $323 = HEAP32[$1>>2]|0;
  $324 = $323 >>> 16;
  $325 = $324 & 255;
  if ((($325|0) == 30) | (($325|0) == 19)) {
   STACKTOP = sp;return;
  }
  $326 = (($170) + 64|0);
  $327 = HEAP32[$326>>2]|0;
  $328 = (($327) + 24|0);
  $329 = HEAP32[$328>>2]|0;
  $330 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($oss,390112)|0);
  $331 = HEAP32[$329>>2]|0;
  $332 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($330,$331)|0);
  $333 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($332,390120)|0);
  $334 = (($329) + 48|0);
  $335 = HEAP16[$334>>1]|0;
  $336 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($333,$335)|0);
  $337 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($336,390136)|0);
  $338 = (($329) + 50|0);
  $339 = HEAP16[$338>>1]|0;
  $340 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($337,$339)|0);
  $341 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($340,390136)|0);
  $342 = (($329) + 52|0);
  $343 = HEAP16[$342>>1]|0;
  $344 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($341,$343)|0);
  $345 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($344,390136)|0);
  $346 = (($329) + 54|0);
  $347 = HEAP16[$346>>1]|0;
  $348 = (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($345,$347)|0);
  $349 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($348,390144)|0);
  $350 = (($329) + 4|0);
  $351 = HEAP32[$350>>2]|0;
  $352 = ($351|0)==(0|0);
  if ($352) {
   $355 = 390160;
  } else {
   $353 = HEAP8[$351>>0]|0;
   $354 = ($353<<24>>24)==(0);
   $$10 = $354 ? 390160 : $351;
   $355 = $$10;
  }
  $356 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($349,$355)|0);
  $357 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($356,390168)|0);
  $358 = (($329) + 16|0);
  $359 = HEAP8[$358>>0]|0;
  $360 = ($359<<24>>24)==(0);
  $$11 = $360 ? 390040 : $358;
  $361 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($357,$$11)|0);
  $362 = (($329) + 44|0);
  $363 = HEAP32[$362>>2]|0;
  $364 = $363 & 256;
  $365 = ($364|0)!=(0);
  $366 = $365 ? 390192 : 390216;
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($361,$366)|0);
  STACKTOP = sp;return;
 }
 }
}
function __ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_c($__os,$__c) {
 $__os = $__os|0;
 $__c = $__c|0;
 var $$0 = 0, $$byval_copy = 0, $$phi$trans$insert$phi$trans$insert = 0, $$pre$pre = 0, $$pre10 = 0, $$pre10$pre = 0, $$sum = 0, $$sum$i = 0, $$sum$i$i = 0, $$sum1$i = 0, $$sum7 = 0, $$sum8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__s = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $0 = sp + 24|0;
 $__s = sp + 8|0;
 $1 = sp + 16|0;
 $2 = sp;
 HEAP8[$0>>0] = $__c;
 HEAP8[$__s>>0] = 0;
 $3 = (($__s) + 4|0);
 HEAP32[$3>>2] = $__os;
 $4 = HEAP32[$__os>>2]|0;
 $5 = (($4) + -12|0);
 $6 = HEAP32[$5>>2]|0;
 $$sum$i = (($6) + 16)|0;
 $7 = (($__os) + ($$sum$i)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 do {
  if ($9) {
   $$sum1$i = (($6) + 72)|0;
   $10 = (($__os) + ($$sum1$i)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$pre10 = $6;
   } else {
    __THREW__ = 0;
    (invoke_ii(2986,($11|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 16;
     break;
    }
    $$pre$pre = HEAP32[$__os>>2]|0;
    $$phi$trans$insert$phi$trans$insert = (($$pre$pre) + -12|0);
    $$pre10$pre = HEAP32[$$phi$trans$insert$phi$trans$insert>>2]|0;
    $$pre10 = $$pre10$pre;
   }
   HEAP8[$__s>>0] = 1;
   $$sum$i$i = (($$pre10) + 24)|0;
   $15 = (($__os) + ($$sum$i$i)|0);
   $16 = HEAP32[$15>>2]|0;
   HEAP32[$1>>2] = $16;
   $17 = (($__os) + ($$pre10)|0);
   $$sum = (($$pre10) + 4)|0;
   $18 = (($__os) + ($$sum)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($0) + 1|0);
   $$sum7 = (($$pre10) + 76)|0;
   $21 = (($__os) + ($$sum7)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(-1);
   do {
    if ($23) {
     __THREW__ = 0;
     invoke_vii(2475,($$byval_copy|0),($17|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 17;
     } else {
      __THREW__ = 0;
      $26 = (invoke_iii(2228,($$byval_copy|0),(3093336|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = HEAP32[$26>>2]|0;
       $30 = (($29) + 28|0);
       $31 = HEAP32[$30>>2]|0;
       __THREW__ = 0;
       $32 = (invoke_iii($31|0,($26|0),32)|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        __THREW__ = 0;
        invoke_vi(3299,($$byval_copy|0));
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 17;
         break;
        }
        $43 = $32 << 24 >> 24;
        HEAP32[$21>>2] = $43;
        $45 = $43;
        label = 13;
        break;
       }
      }
      $35 = ___cxa_find_matching_catch(0|0)|0;
      $36 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3299,($$byval_copy|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       $39 = ___cxa_find_matching_catch(0|0)|0;
       $40 = tempRet0;
       ___clang_call_terminate($39);
       // unreachable;
      } else {
       $eh$lpad$body$indexZ2D = $35;
      }
     }
    } else {
     $45 = $22;
     label = 13;
    }
   } while(0);
   if ((label|0) == 13) {
    $44 = $45&255;
    $46 = $19 & 176;
    $47 = ($46|0)==(32);
    $48 = $47 ? $20 : $0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viiiiiii(60,($2|0),($$byval_copy|0),($0|0),($48|0),($20|0),($17|0),($44|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 17;
    } else {
     $51 = HEAP32[$2>>2]|0;
     $52 = ($51|0)==(0|0);
     if (!($52)) {
      label = 19;
      break;
     }
     $53 = HEAP32[$__os>>2]|0;
     $54 = (($53) + -12|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($__os) + ($55)|0);
     $$sum8 = (($55) + 16)|0;
     $57 = (($__os) + ($$sum8)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = $58 | 5;
     __THREW__ = 0;
     invoke_vii(2476,($56|0),($59|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 17;
     } else {
      label = 19;
      break;
     }
    }
   }
   if ((label|0) == 17) {
    $64 = ___cxa_find_matching_catch(0|0)|0;
    $65 = tempRet0;
    $eh$lpad$body$indexZ2D = $64;
   }
   __THREW__ = 0;
   invoke_vi(3300,($__s|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $80 = ___cxa_find_matching_catch(0|0)|0;
    $81 = tempRet0;
    ___clang_call_terminate($80);
    // unreachable;
   } else {
    $$0 = $eh$lpad$body$indexZ2D;
   }
  } else {
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  __THREW__ = 0;
  invoke_vi(3300,($__s|0));
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   label = 16;
  } else {
   STACKTOP = sp;return ($__os|0);
  }
 }
 if ((label|0) == 16) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  $$0 = $62;
 }
 (___cxa_begin_catch(($$0|0))|0);
 $70 = HEAP32[$__os>>2]|0;
 $71 = (($70) + -12|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($__os) + ($72)|0);
 __THREW__ = 0;
 invoke_vi(3301,($73|0));
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if (!($75)) {
  ___cxa_end_catch();
  STACKTOP = sp;return ($__os|0);
 }
 $76 = ___cxa_find_matching_catch()|0;
 $77 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $78 = __THREW__; __THREW__ = 0;
 $79 = $78&1;
 if ($79) {
  $80 = ___cxa_find_matching_catch(0|0)|0;
  $81 = tempRet0;
  ___clang_call_terminate($80);
  // unreachable;
 } else {
  ___resumeException($76|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__1lsIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_13basic_ostreamIT_T0_EES9_RKNS_12basic_stringIS6_S7_T1_EE($__os,$__str) {
 $__os = $__os|0;
 $__str = $__str|0;
 var $$0 = 0, $$byval_copy = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum$i = 0, $$sum$i$i = 0, $$sum1$i = 0, $$sum10 = 0, $$sum11 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__s = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $__s = sp;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 HEAP8[$__s>>0] = 0;
 $2 = (($__s) + 4|0);
 HEAP32[$2>>2] = $__os;
 $3 = HEAP32[$__os>>2]|0;
 $4 = (($3) + -12|0);
 $5 = HEAP32[$4>>2]|0;
 $$sum$i = (($5) + 16)|0;
 $6 = (($__os) + ($$sum$i)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 do {
  if ($8) {
   $$sum1$i = (($5) + 72)|0;
   $9 = (($__os) + ($$sum1$i)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    __THREW__ = 0;
    (invoke_ii(2986,($10|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 26;
     break;
    }
   }
   HEAP8[$__s>>0] = 1;
   $14 = HEAP8[$__str>>0]|0;
   $15 = $14 & 1;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $19 = $14&255;
    $20 = $19 >>> 1;
    $41 = $20;
   } else {
    $17 = (($__str) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $41 = $18;
   }
   $21 = HEAP32[$__os>>2]|0;
   $22 = (($21) + -12|0);
   $23 = HEAP32[$22>>2]|0;
   $$sum$i$i = (($23) + 24)|0;
   $24 = (($__os) + ($$sum$i$i)|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$0>>2] = $25;
   if ($16) {
    $34 = (($__str) + 1|0);
    $$sum11 = (($23) + 4)|0;
    $35 = (($__os) + ($$sum11)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36 & 176;
    $38 = ($37|0)==(32);
    $39 = (($__str) + 1|0);
    if ($38) {
     $40 = ((($__str) + ($41)|0) + 1|0);
     $110 = $40;
    } else {
     $110 = $39;
    }
    $45 = (($__str) + 1|0);
    $73 = $45;$74 = $34;$75 = $110;
   } else {
    $26 = (($__str) + 8|0);
    $27 = HEAP32[$26>>2]|0;
    $$sum = (($23) + 4)|0;
    $28 = (($__os) + ($$sum)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = $29 & 176;
    $31 = ($30|0)==(32);
    $32 = (($__str) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    if ($31) {
     $42 = (($33) + ($41)|0);
     $109 = $42;
    } else {
     $109 = $33;
    }
    $43 = (($__str) + 8|0);
    $44 = HEAP32[$43>>2]|0;
    $73 = $44;$74 = $27;$75 = $109;
   }
   $46 = (($__os) + ($23)|0);
   $$sum9 = (($23) + 76)|0;
   $47 = (($__os) + ($$sum9)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(-1);
   do {
    if ($49) {
     __THREW__ = 0;
     invoke_vii(2475,($$byval_copy|0),($46|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 27;
     } else {
      __THREW__ = 0;
      $52 = (invoke_iii(2228,($$byval_copy|0),(3093336|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if (!($54)) {
       $55 = HEAP32[$52>>2]|0;
       $56 = (($55) + 28|0);
       $57 = HEAP32[$56>>2]|0;
       __THREW__ = 0;
       $58 = (invoke_iii($57|0,($52|0),32)|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if (!($60)) {
        __THREW__ = 0;
        invoke_vi(3299,($$byval_copy|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         label = 27;
         break;
        }
        $69 = $58 << 24 >> 24;
        HEAP32[$47>>2] = $69;
        $$pre$phiZ2D = $46;$71 = $69;
        label = 23;
        break;
       }
      }
      $61 = ___cxa_find_matching_catch(0|0)|0;
      $62 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3299,($$byval_copy|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       $65 = ___cxa_find_matching_catch(0|0)|0;
       $66 = tempRet0;
       ___clang_call_terminate($65);
       // unreachable;
      } else {
       $eh$lpad$body$indexZ2D = $61;
      }
     }
    } else {
     $$pre$phiZ2D = $46;$71 = $48;
     label = 23;
    }
   } while(0);
   if ((label|0) == 23) {
    $70 = $71&255;
    $72 = (($73) + ($41)|0);
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viiiiiii(60,($1|0),($$byval_copy|0),($74|0),($75|0),($72|0),($$pre$phiZ2D|0),($70|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     label = 27;
    } else {
     $78 = HEAP32[$1>>2]|0;
     $79 = ($78|0)==(0|0);
     if (!($79)) {
      label = 29;
      break;
     }
     $80 = HEAP32[$__os>>2]|0;
     $81 = (($80) + -12|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = (($__os) + ($82)|0);
     $$sum10 = (($82) + 16)|0;
     $84 = (($__os) + ($$sum10)|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = $85 | 5;
     __THREW__ = 0;
     invoke_vii(2476,($83|0),($86|0));
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 27;
     } else {
      label = 29;
      break;
     }
    }
   }
   if ((label|0) == 27) {
    $91 = ___cxa_find_matching_catch(0|0)|0;
    $92 = tempRet0;
    $eh$lpad$body$indexZ2D = $91;
   }
   __THREW__ = 0;
   invoke_vi(3300,($__s|0));
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $107 = ___cxa_find_matching_catch(0|0)|0;
    $108 = tempRet0;
    ___clang_call_terminate($107);
    // unreachable;
   } else {
    $$0 = $eh$lpad$body$indexZ2D;
   }
  } else {
   label = 29;
  }
 } while(0);
 if ((label|0) == 29) {
  __THREW__ = 0;
  invoke_vi(3300,($__s|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   label = 26;
  } else {
   STACKTOP = sp;return ($__os|0);
  }
 }
 if ((label|0) == 26) {
  $89 = ___cxa_find_matching_catch(0|0)|0;
  $90 = tempRet0;
  $$0 = $89;
 }
 (___cxa_begin_catch(($$0|0))|0);
 $97 = HEAP32[$__os>>2]|0;
 $98 = (($97) + -12|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = (($__os) + ($99)|0);
 __THREW__ = 0;
 invoke_vi(3301,($100|0));
 $101 = __THREW__; __THREW__ = 0;
 $102 = $101&1;
 if (!($102)) {
  ___cxa_end_catch();
  STACKTOP = sp;return ($__os|0);
 }
 $103 = ___cxa_find_matching_catch()|0;
 $104 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $105 = __THREW__; __THREW__ = 0;
 $106 = $105&1;
 if ($106) {
  $107 = ___cxa_find_matching_catch(0|0)|0;
  $108 = tempRet0;
  ___clang_call_terminate($107);
  // unreachable;
 } else {
  ___resumeException($103|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN6il2cpp2vm4Type7GetNameEPK10Il2CppType20Il2CppTypeNameFormat($type,$format) {
 $type = $type|0;
 $format = $format|0;
 var $$01$i = 0, $$off0 = 0, $$phi$trans$insert = 0, $$sink$i$index2 = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$indexZ2D = 0, $oss = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $0 = sp + 164|0;
 $oss = sp + 16|0;
 $1 = sp;
 $2 = sp + 152|0;
 $3 = (($oss) + 56|0);
 $4 = (($oss) + 4|0);
 HEAP32[$oss>>2] = ((390272 + 12|0));
 $5 = (($oss) + 56|0);
 HEAP32[$5>>2] = ((390272 + 32|0));
 $6 = (($oss) + 56|0);
 __THREW__ = 0;
 invoke_vii(2480,($6|0),($4|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if ($8) {
   $38 = ___cxa_find_matching_catch()|0;
   $39 = tempRet0;
   $$01$i = $38;$$sink$i$index2 = $39;
  } else {
   $9 = (($oss) + 128|0);
   HEAP32[$9>>2] = 0;
   $10 = (($oss) + 132|0);
   HEAP32[$10>>2] = -1;
   HEAP32[$oss>>2] = ((390232 + 12|0));
   HEAP32[$3>>2] = ((390232 + 32|0));
   HEAP32[$4>>2] = ((3090568 + 8|0));
   $11 = (($oss) + 8|0);
   __ZNSt3__16localeC2Ev($11);
   $12 = (($oss) + 12|0);
   ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;HEAP32[$12+20>>2]=0|0;
   HEAP32[$4>>2] = ((225848 + 8|0));
   $13 = (($oss) + 36|0);
   $14 = (($oss) + 52|0);
   ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
   HEAP32[$14>>2] = 16;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(2481,($4|0),($0|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $24 = HEAP8[$0>>0]|0;
    $25 = $24 & 1;
    $26 = ($25<<24>>24)==(0);
    if (!($26)) {
     $27 = (($0) + 8|0);
     $28 = HEAP32[$27>>2]|0;
     __ZdlPv($28);
    }
    $29 = HEAP8[$13>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if (!($31)) {
     $32 = (($oss) + 44|0);
     $33 = HEAP32[$32>>2]|0;
     __ZdlPv($33);
    }
    HEAP32[$4>>2] = ((3090568 + 8|0));
    __THREW__ = 0;
    invoke_vi(3299,($11|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     $36 = ___cxa_find_matching_catch(0|0)|0;
     $37 = tempRet0;
     ___clang_call_terminate($36);
     // unreachable;
    } else {
     $$01$i = $22;$$sink$i$index2 = $23;
     break;
    }
   }
   $17 = HEAP8[$0>>0]|0;
   $18 = $17 & 1;
   $19 = ($18<<24>>24)==(0);
   if (!($19)) {
    $20 = (($0) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    __ZdlPv($21);
   }
   __THREW__ = 0;
   invoke_viiii(325,($oss|0),($type|0),($format|0),0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   do {
    if (!($45)) {
     $46 = HEAP32[$oss>>2]|0;
     $47 = (($46) + -12|0);
     $48 = HEAP32[$47>>2]|0;
     $$sum$i = (($48) + 16)|0;
     $49 = (($oss) + ($$sum$i)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = $50 & 5;
     $52 = ($51|0)==(0);
     if ($52) {
      $$sum1$i = (($48) + 24)|0;
      $62 = (($oss) + ($$sum1$i)|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 16|0);
      $66 = HEAP32[$65>>2]|0;
      __THREW__ = 0;
      invoke_viiiiii($66|0,($1|0),($63|0),0,0,1,16);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      $$phi$trans$insert = (($1) + 8|0);
      $69 = $$phi$trans$insert;
      $70 = $69;
      $71 = HEAP32[$70>>2]|0;
      $72 = (($69) + 4)|0;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $$off0 = $71;
     } else {
      $53 = $1;
      $54 = $53;
      HEAP32[$54>>2] = 0;
      $55 = (($53) + 4)|0;
      $56 = $55;
      HEAP32[$56>>2] = 0;
      $57 = (($1) + 8|0);
      $58 = $57;
      $59 = $58;
      HEAP32[$59>>2] = -1;
      $60 = (($58) + 4)|0;
      $61 = $60;
      HEAP32[$61>>2] = -1;
      $$off0 = -1;
     }
     $75 = (($$off0) + 1)|0;
     __THREW__ = 0;
     $76 = (invoke_ii(3167,($75|0))|0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if (!($78)) {
      __THREW__ = 0;
      invoke_vii(2482,($2|0),($4|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if (!($80)) {
       $81 = HEAP8[$2>>0]|0;
       $82 = $81 & 1;
       $83 = ($82<<24>>24)==(0);
       if ($83) {
        $84 = (($2) + 1|0);
        _memcpy(($76|0),($84|0),($$off0|0))|0;
       } else {
        $85 = (($2) + 8|0);
        $86 = HEAP32[$85>>2]|0;
        _memcpy(($76|0),($86|0),($$off0|0))|0;
        $87 = (($2) + 8|0);
        $88 = HEAP32[$87>>2]|0;
        __ZdlPv($88);
       }
       $89 = (($76) + ($$off0)|0);
       HEAP8[$89>>0] = 0;
       HEAP32[$oss>>2] = ((390232 + 12|0));
       HEAP32[$5>>2] = ((390232 + 32|0));
       $90 = (($oss) + 4|0);
       HEAP32[$90>>2] = ((225848 + 8|0));
       $91 = HEAP8[$13>>0]|0;
       $92 = $91 & 1;
       $93 = ($92<<24>>24)==(0);
       if (!($93)) {
        $94 = (($oss) + 44|0);
        $95 = HEAP32[$94>>2]|0;
        __ZdlPv($95);
       }
       HEAP32[$90>>2] = ((3090568 + 8|0));
       __THREW__ = 0;
       invoke_vi(3299,($11|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        __ZNSt3__18ios_baseD2Ev($6);
        STACKTOP = sp;return ($76|0);
       }
       $98 = ___cxa_find_matching_catch()|0;
       $99 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3217,($6|0));
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        $102 = ___cxa_find_matching_catch(0|0)|0;
        $103 = tempRet0;
        ___clang_call_terminate($102);
        // unreachable;
       } else {
        ___resumeException($98|0);
        // unreachable;
       }
      }
     }
    }
   } while(0);
   $104 = ___cxa_find_matching_catch()|0;
   $105 = tempRet0;
   HEAP32[$oss>>2] = ((390232 + 12|0));
   HEAP32[$5>>2] = ((390232 + 32|0));
   $106 = (($oss) + 4|0);
   HEAP32[$106>>2] = ((225848 + 8|0));
   $107 = HEAP8[$13>>0]|0;
   $108 = $107 & 1;
   $109 = ($108<<24>>24)==(0);
   if (!($109)) {
    $110 = (($oss) + 44|0);
    $111 = HEAP32[$110>>2]|0;
    __ZdlPv($111);
   }
   HEAP32[$106>>2] = ((3090568 + 8|0));
   __THREW__ = 0;
   invoke_vi(3299,($11|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    $116 = ___cxa_find_matching_catch(0|0)|0;
    $117 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3217,($6|0));
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     $120 = ___cxa_find_matching_catch(0|0)|0;
     $121 = tempRet0;
     ___clang_call_terminate($120);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $116;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_vi(3217,($6|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if (!($115)) {
    ___resumeException($104|0);
    // unreachable;
   }
   $122 = ___cxa_find_matching_catch(0|0)|0;
   $123 = tempRet0;
   $eh$lpad$body$indexZ2D = $122;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3217,($3|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((390232 + 12|0));
 $0 = (($this) + 56|0);
 HEAP32[$0>>2] = ((390232 + 32|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = ((225848 + 8|0));
 $2 = (($this) + 36|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($this) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  __ZdlPv($7);
 }
 HEAP32[$1>>2] = ((3090568 + 8|0));
 $8 = (($this) + 8|0);
 __THREW__ = 0;
 invoke_vi(3299,($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = (($this) + 56|0);
  __ZNSt3__18ios_baseD2Ev($11);
  STACKTOP = sp;return;
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $14 = (($this) + 56|0);
 __THREW__ = 0;
 invoke_vi(3217,($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  ___resumeException($12|0);
  // unreachable;
 }
}
function __ZN6il2cpp2vm4Type22GetClassOrElementClassEPK10Il2CppType($type) {
 $type = $type|0;
 var $$0 = 0, $$0$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16711680;
 $3 = ($2|0)==(1310720);
 if ($3) {
  $4 = HEAP32[$type>>2]|0;
  $$0$in = $4;
 } else {
  $$0$in = $type;
 }
 $$0 = HEAP32[$$0$in>>2]|0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm4Type17GetUnderlyingTypeEPK10Il2CppType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16711680;
 do {
  if ((($2|0) == 1114112)) {
   $3 = HEAP32[$type>>2]|0;
   $4 = (($3) + 117|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $$0 = $type;
   } else {
    $7 = $1 & 1073741824;
    $8 = ($7|0)==(0);
    if ($8) {
     $9 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($3)|0);
     $$0 = $9;
     break;
    } else {
     $10 = ($2|0)==(1376256);
     if ($10) {
      label = 6;
      break;
     } else {
      $$0 = $type;
      break;
     }
    }
   }
  } else if ((($2|0) == 1376256)) {
   label = 6;
  } else {
   $$0 = $type;
  }
 } while(0);
 if ((label|0) == 6) {
  $11 = HEAP32[$type>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 117|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $$0 = $type;
  } else {
   $16 = $1 & 1073741824;
   $17 = ($16|0)==(0);
   if ($17) {
    $18 = (__ZN6il2cpp2vm5Class15GetEnumBaseTypeEP8TypeInfo($12)|0);
    $$0 = $18;
   } else {
    $$0 = $type;
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm4Type11IsReferenceEPK10Il2CppType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($type|0)==(0|0);
 L1: do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (($type) + 4|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = $2 >>> 16;
   $4 = $3 & 255;
   switch ($4|0) {
   case 21:  {
    $5 = HEAP32[$type>>2]|0;
    $6 = (__ZN6il2cpp2vm12GenericClass11IsValueTypeEP18Il2CppGenericClass($5)|0);
    if (!($6)) {
     $$0 = 1;
     break L1;
    }
    break;
   }
   case 20: case 28: case 18: case 29: case 14:  {
    $$0 = 1;
    break L1;
    break;
   }
   default: {
   }
   }
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm4Type8IsStructEPK10Il2CppType($type) {
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($type) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1073741824;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = $1 & 16711680;
   $5 = ($4|0)==(1114112);
   if ($5) {
    $6 = HEAP32[$type>>2]|0;
    $7 = (($6) + 117|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $$0 = 1;
     break;
    }
   }
   $10 = $1 >>> 16;
   $11 = $10 & 255;
   if ((($11|0) == 22)) {
    $$0 = 1;
    break;
   } else if ((($11|0) == 21)) {
    $12 = HEAP32[$type>>2]|0;
    $13 = (__ZN6il2cpp2vm12GenericClass11IsValueTypeEP18Il2CppGenericClass($12)|0);
    if ($13) {
     $14 = HEAP32[$type>>2]|0;
     $15 = HEAP32[$14>>2]|0;
     $16 = (($15) + 117|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = ($17<<24>>24)==(0);
     if ($18) {
      $$0 = 1;
      break;
     }
    }
   }
   $$0 = 0;
  } else {
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6il2cpp2vm4Type8GetClassEPK10Il2CppType($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$type>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((390232 + 12|0));
 $0 = (($this) + 56|0);
 HEAP32[$0>>2] = ((390232 + 32|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = ((225848 + 8|0));
 $2 = (($this) + 36|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($this) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  __ZdlPv($7);
 }
 HEAP32[$1>>2] = ((3090568 + 8|0));
 $8 = (($this) + 8|0);
 __THREW__ = 0;
 invoke_vi(3299,($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $16 = (($this) + 56|0);
  __THREW__ = 0;
  invoke_vi(3217,($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $19 = ___cxa_find_matching_catch(0|0)|0;
   $20 = tempRet0;
   ___clang_call_terminate($19);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $15;$eh$lpad$body$indexZ2D = $14;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $11 = (($this) + 56|0);
 __THREW__ = 0;
 invoke_vi(3217,($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $eh$lpad$body$index2Z2D = $22;$eh$lpad$body$indexZ2D = $21;
 __ZdlPv($this);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZTv0_n12_NSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($this) {
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2)|0);
 HEAP32[$3>>2] = ((390232 + 12|0));
 $$sum = (($2) + 56)|0;
 $4 = (($this) + ($$sum)|0);
 HEAP32[$4>>2] = ((390232 + 32|0));
 $$sum1 = (($2) + 4)|0;
 $5 = (($this) + ($$sum1)|0);
 HEAP32[$5>>2] = ((225848 + 8|0));
 $$sum2 = (($2) + 36)|0;
 $6 = (($this) + ($$sum2)|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $$sum3 = (($2) + 44)|0;
  $10 = (($this) + ($$sum3)|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
 }
 HEAP32[$5>>2] = ((3090568 + 8|0));
 $$sum4 = (($2) + 8)|0;
 $12 = (($this) + ($$sum4)|0);
 __THREW__ = 0;
 invoke_vi(3299,($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  __ZNSt3__18ios_baseD2Ev($4);
  STACKTOP = sp;return;
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3217,($4|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZTv0_n12_NSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev($this) {
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$index2Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2)|0);
 HEAP32[$3>>2] = ((390232 + 12|0));
 $$sum = (($2) + 56)|0;
 $4 = (($this) + ($$sum)|0);
 HEAP32[$4>>2] = ((390232 + 32|0));
 $$sum1 = (($2) + 4)|0;
 $5 = (($this) + ($$sum1)|0);
 HEAP32[$5>>2] = ((225848 + 8|0));
 $$sum2 = (($2) + 36)|0;
 $6 = (($this) + ($$sum2)|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $$sum3 = (($2) + 44)|0;
  $10 = (($this) + ($$sum3)|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
 }
 HEAP32[$5>>2] = ((3090568 + 8|0));
 $$sum4 = (($2) + 8)|0;
 $12 = (($this) + ($$sum4)|0);
 __THREW__ = 0;
 invoke_vi(3299,($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3217,($4|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $21 = ___cxa_find_matching_catch(0|0)|0;
   $22 = tempRet0;
   ___clang_call_terminate($21);
   // unreachable;
  } else {
   $eh$lpad$body$i$index2Z2D = $18;$eh$lpad$body$i$indexZ2D = $17;
   __ZdlPv($3);
   ___resumeException($eh$lpad$body$i$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3217,($4|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  __ZdlPv($3);
  STACKTOP = sp;return;
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $eh$lpad$body$i$index2Z2D = $24;$eh$lpad$body$i$indexZ2D = $23;
 __ZdlPv($3);
 ___resumeException($eh$lpad$body$i$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE21__push_back_slow_pathIKS6_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i7 = 0, $$0$i8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(357913941);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 12)&-1;
 $15 = ($14>>>0)<(178956970);
 if ($15) {
  $18 = $14 << 1;
  $19 = ($18>>>0)<($8>>>0);
  $20 = $19 ? $8 : $18;
  $21 = (($__v) + 12|0);
  HEAP32[$21>>2] = 0;
  $22 = (($__v) + 16|0);
  HEAP32[$22>>2] = $0;
  $23 = ($20|0)==(0);
  if ($23) {
   $$0$i8 = 0;$26 = 0;$31 = $21;
  } else {
   $$0$i7 = $20;$88 = $21;
   label = 6;
  }
 } else {
  $16 = (($__v) + 12|0);
  HEAP32[$16>>2] = 0;
  $17 = (($__v) + 16|0);
  HEAP32[$17>>2] = $0;
  $$0$i7 = 357913941;$88 = $16;
  label = 6;
 }
 if ((label|0) == 6) {
  $24 = ($$0$i7*12)|0;
  $25 = (__Znwj($24)|0);
  $$0$i8 = $$0$i7;$26 = $25;$31 = $88;
 }
 HEAP32[$__v>>2] = $26;
 $27 = (($26) + (($7*12)|0)|0);
 $28 = (($__v) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = (($__v) + 4|0);
 HEAP32[$29>>2] = $27;
 $30 = (($26) + (($$0$i8*12)|0)|0);
 HEAP32[$31>>2] = $30;
 $32 = ($27|0)==(0|0);
 do {
  if ($32) {
   $57 = 0;
   label = 18;
  } else {
   $33 = HEAP8[$__x>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    ;HEAP32[$27+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__x+8>>2]|0;
    $57 = $27;
    label = 18;
    break;
   }
   $36 = (($__x) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($__x) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39>>>0)>(4294967279);
   if ($40) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    // unreachable;
   }
   $43 = ($39>>>0)<(11);
   if ($43) {
    $44 = $39 << 1;
    $45 = $44&255;
    HEAP8[$27>>0] = $45;
    $46 = (($27) + 1|0);
    $__p$0$i$i$i$i = $46;
   } else {
    $47 = (($39) + 16)|0;
    $48 = $47 & -16;
    __THREW__ = 0;
    $49 = (invoke_ii(2988,($48|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    $52 = ((($26) + (($7*12)|0)|0) + 8|0);
    HEAP32[$52>>2] = $49;
    $53 = $48 | 1;
    HEAP32[$27>>2] = $53;
    $54 = ((($26) + (($7*12)|0)|0) + 4|0);
    HEAP32[$54>>2] = $39;
    $__p$0$i$i$i$i = $49;
   }
   _memcpy(($__p$0$i$i$i$i|0),($37|0),($39|0))|0;
   $55 = (($__p$0$i$i$i$i) + ($39)|0);
   HEAP8[$55>>0] = 0;
   $$pre = HEAP32[$28>>2]|0;
   $57 = $$pre;
   label = 18;
  }
 } while(0);
 if ((label|0) == 18) {
  $56 = (($57) + 12|0);
  HEAP32[$28>>2] = $56;
  __THREW__ = 0;
  invoke_vii(2524,($this|0),($__v|0));
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if (!($59)) {
   $60 = HEAP32[$29>>2]|0;
   $61 = HEAP32[$28>>2]|0;
   $62 = ($61|0)==($60|0);
   if (!($62)) {
    $64 = $61;
    while(1) {
     $63 = (($64) + -12|0);
     HEAP32[$28>>2] = $63;
     $65 = HEAP8[$63>>0]|0;
     $66 = $65 & 1;
     $67 = ($66<<24>>24)==(0);
     if (!($67)) {
      $69 = (($64) + -4|0);
      $70 = HEAP32[$69>>2]|0;
      __ZdlPv($70);
     }
     $68 = ($63|0)==($60|0);
     if ($68) {
      break;
     } else {
      $64 = $63;
     }
    }
   }
   $71 = HEAP32[$__v>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    STACKTOP = sp;return;
   }
   __ZdlPv($71);
   STACKTOP = sp;return;
  }
 }
 $73 = ___cxa_find_matching_catch()|0;
 $74 = tempRet0;
 $75 = HEAP32[$29>>2]|0;
 $76 = HEAP32[$28>>2]|0;
 $77 = ($76|0)==($75|0);
 if (!($77)) {
  $79 = $76;
  while(1) {
   $78 = (($79) + -12|0);
   HEAP32[$28>>2] = $78;
   $80 = HEAP8[$78>>0]|0;
   $81 = $80 & 1;
   $82 = ($81<<24>>24)==(0);
   if (!($82)) {
    $84 = (($79) + -4|0);
    $85 = HEAP32[$84>>2]|0;
    __ZdlPv($85);
   }
   $83 = ($78|0)==($75|0);
   if ($83) {
    break;
   } else {
    $79 = $78;
   }
  }
 }
 $86 = HEAP32[$__v>>2]|0;
 $87 = ($86|0)==(0|0);
 if ($87) {
  ___resumeException($73|0);
  // unreachable;
 }
 __ZdlPv($86);
 ___resumeException($73|0);
 // unreachable;
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__v) + 4|0);
 $4 = ($2|0)==($0|0);
 $$pre1 = HEAP32[$3>>2]|0;
 do {
  if ($4) {
   $30 = $$pre1;$31 = $0;
  } else {
   $$01$i = $2;$6 = $$pre1;
   while(1) {
    $5 = (($6) + -12|0);
    $7 = (($$01$i) + -12|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     ;HEAP32[$5+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$7+8>>2]|0;
    } else {
     $11 = (($$01$i) + -4|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($$01$i) + -8|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14>>>0)>(4294967279);
     if ($15) {
      label = 5;
      break;
     }
     $16 = ($14>>>0)<(11);
     if ($16) {
      $17 = $14 << 1;
      $18 = $17&255;
      HEAP8[$5>>0] = $18;
      $19 = (($5) + 1|0);
      $__p$0$i$i$i$i$i = $19;
     } else {
      $20 = (($14) + 16)|0;
      $21 = $20 & -16;
      $22 = (__Znwj($21)|0);
      $23 = (($6) + -4|0);
      HEAP32[$23>>2] = $22;
      $24 = $21 | 1;
      HEAP32[$5>>2] = $24;
      $25 = (($6) + -8|0);
      HEAP32[$25>>2] = $14;
      $__p$0$i$i$i$i$i = $22;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($12|0),($14|0))|0;
     $26 = (($__p$0$i$i$i$i$i) + ($14)|0);
     HEAP8[$26>>0] = 0;
    }
    $27 = HEAP32[$3>>2]|0;
    $28 = (($27) + -12|0);
    HEAP32[$3>>2] = $28;
    $29 = ($7|0)==($0|0);
    if ($29) {
     label = 11;
     break;
    } else {
     $$01$i = $7;$6 = $28;
    }
   }
   if ((label|0) == 5) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 11) {
    $$pre = HEAP32[$this>>2]|0;
    $30 = $28;$31 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $30;
 HEAP32[$3>>2] = $31;
 $32 = (($__v) + 8|0);
 $33 = HEAP32[$1>>2]|0;
 $34 = HEAP32[$32>>2]|0;
 HEAP32[$1>>2] = $34;
 HEAP32[$32>>2] = $33;
 $35 = (($this) + 8|0);
 $36 = (($__v) + 12|0);
 $37 = HEAP32[$35>>2]|0;
 $38 = HEAP32[$36>>2]|0;
 HEAP32[$35>>2] = $38;
 HEAP32[$36>>2] = $37;
 $39 = HEAP32[$3>>2]|0;
 HEAP32[$__v>>2] = $39;
 STACKTOP = sp;return;
}
function __ZN6il2cpp2vm17TypeNameParseInfo12AssemblyNameD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 52|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if (!($5)) {
   HEAP32[$3>>2] = $1;
  }
  __ZdlPv($1);
 }
 $6 = (($this) + 36|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = (($this) + 44|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
 }
 $12 = (($this) + 24|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  $16 = (($this) + 32|0);
  $17 = HEAP32[$16>>2]|0;
  __ZdlPv($17);
 }
 $18 = (($this) + 12|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  $22 = (($this) + 20|0);
  $23 = HEAP32[$22>>2]|0;
  __ZdlPv($23);
 }
 $24 = HEAP8[$this>>0]|0;
 $25 = $24 & 1;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 __ZdlPv($28);
 STACKTOP = sp;return;
}
function _png_zalloc($png_ptr,$items,$size) {
 $png_ptr = $png_ptr|0;
 $items = $items|0;
 $size = $size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (4294967295 / ($size>>>0))&-1;
  $2 = ($1>>>0)>($items>>>0);
  if ($2) {
   $3 = Math_imul($size, $items)|0;
   $4 = (_png_malloc_warn($png_ptr,$3)|0);
   $$0 = $4;
  } else {
   $$0 = 0;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _png_zfree($png_ptr,$ptr) {
 $png_ptr = $png_ptr|0;
 $ptr = $ptr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _png_free($png_ptr,$ptr);
 STACKTOP = sp;return;
}
function _png_reset_crc($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_crc32(0,0,0)|0);
 $1 = (($png_ptr) + 408|0);
 HEAP32[$1>>2] = $0;
 STACKTOP = sp;return;
}
function _png_calculate_crc($png_ptr,$ptr,$length) {
 $png_ptr = $png_ptr|0;
 $ptr = $ptr|0;
 $length = $length|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $crc$0 = 0, $need_crc$0 = 0, $need_crc$0$not = 0, $not$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 536870912;
 $3 = ($2|0)==(0);
 $4 = (($png_ptr) + 208|0);
 $5 = HEAP32[$4>>2]|0;
 if ($3) {
  $7 = $5 & 2048;
  $8 = ($7|0)==(0);
  $need_crc$0 = $8;
 } else {
  $6 = $5 & 768;
  $not$ = ($6|0)!=(768);
  $need_crc$0 = $not$;
 }
 $need_crc$0$not = $need_crc$0 ^ 1;
 $9 = ($length|0)==(0);
 $or$cond = $9 | $need_crc$0$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $10 = (($png_ptr) + 408|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $ptr;$$01 = $length;$crc$0 = $11;
 while(1) {
  $12 = ($$01|0)==(0);
  $$ = $12 ? -1 : $$01;
  $13 = (_crc32($crc$0,$$0,$$)|0);
  $14 = (($$0) + ($$)|0);
  $15 = (($$01) - ($$))|0;
  $16 = ($$01|0)==($$|0);
  if ($16) {
   break;
  } else {
   $$0 = $14;$$01 = $15;$crc$0 = $13;
  }
 }
 HEAP32[$10>>2] = $13;
 STACKTOP = sp;return;
}
function _png_user_version_check($png_ptr,$user_png_ver) {
 $png_ptr = $png_ptr|0;
 $user_png_ver = $user_png_ver|0;
 var $$0 = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($user_png_ver|0)==(0|0);
 $1 = (($png_ptr) + 208|0);
 if ($0) {
  $9 = HEAP32[$1>>2]|0;
  $10 = $9 | 131072;
  HEAP32[$1>>2] = $10;
  $12 = $10;
 } else {
  $2 = HEAP8[$user_png_ver>>0]|0;
  $3 = ($2<<24>>24)==(49);
  if (!($3)) {
   $4 = HEAP32[$1>>2]|0;
   $5 = $4 | 131072;
   HEAP32[$1>>2] = $5;
  }
  $6 = (($user_png_ver) + 1|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(46);
  if (!($8)) {
   $22 = HEAP32[$1>>2]|0;
   $23 = $22 | 131072;
   HEAP32[$1>>2] = $23;
  }
  $24 = (($user_png_ver) + 2|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(54);
  if (!($26)) {
   $27 = HEAP32[$1>>2]|0;
   $28 = $27 | 131072;
   HEAP32[$1>>2] = $28;
  }
  $29 = (($user_png_ver) + 3|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(46);
  if (!($31)) {
   $32 = HEAP32[$1>>2]|0;
   $33 = $32 | 131072;
   HEAP32[$1>>2] = $33;
  }
  $34 = (($user_png_ver) + 4|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ($35<<24>>24)==(49);
  if (!($36)) {
   $37 = HEAP32[$1>>2]|0;
   $38 = $37 | 131072;
   HEAP32[$1>>2] = $38;
  }
  $39 = (($user_png_ver) + 5|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)==(48);
  if (!($41)) {
   $42 = HEAP32[$1>>2]|0;
   $43 = $42 | 131072;
   HEAP32[$1>>2] = $43;
  }
  $44 = (($user_png_ver) + 6|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = ($45<<24>>24)==(0);
  $$pre$pre = HEAP32[$1>>2]|0;
  if ($46) {
   $12 = $$pre$pre;
  } else {
   $47 = $$pre$pre | 131072;
   HEAP32[$1>>2] = $47;
   $12 = $47;
  }
 }
 $11 = $12 & 131072;
 $13 = ($11|0)==(0);
 if (!($13)) {
  if ($0) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $14 = HEAP8[$user_png_ver>>0]|0;
  $15 = ($14<<24>>24)==(49);
  if (!($15)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $16 = (($user_png_ver) + 2|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==(54);
  if (!($18)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $19 = (($user_png_ver) + 3|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(46);
  if (!($21)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _png_create_png_struct($user_png_ver,$error_ptr,$error_fn,$warn_fn,$mem_ptr,$malloc_fn,$free_fn) {
 $user_png_ver = $user_png_ver|0;
 $error_ptr = $error_ptr|0;
 $error_fn = $error_fn|0;
 $warn_fn = $warn_fn|0;
 $mem_ptr = $mem_ptr|0;
 $malloc_fn = $malloc_fn|0;
 $free_fn = $free_fn|0;
 var $$0$reg2mem$0 = 0, $$reg2mem38$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $create_jmp_buf = 0, $create_struct = 0, _setjmpTable = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 912|0;
 _setjmpTable = STACKTOP; STACKTOP = STACKTOP + 168|0;HEAP32[_setjmpTable>>2]=0;
 $create_struct = sp + 156|0;
 $create_jmp_buf = sp;
 _memset(($create_struct|0),0,756)|0;
 $0 = (($create_struct) + 624|0);
 HEAP32[$0>>2] = 2147483647;
 $1 = (($create_struct) + 628|0);
 HEAP32[$1>>2] = 2147483647;
 $2 = (($create_struct) + 632|0);
 HEAP32[$2>>2] = 0;
 $3 = (($create_struct) + 636|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(326,($create_struct|0),($mem_ptr|0),($malloc_fn|0),($free_fn|0));
 $4 = __THREW__; __THREW__ = 0;
 if ((($4|0) != 0) & ((threwValue|0) != 0)) { $5 = _testSetjmp(HEAP32[$4>>2]|0, _setjmpTable)|0; if (($5|0) == 0) { _longjmp($4|0, threwValue|0); } tempRet0 = threwValue; } else { $5 = -1; };
 $6 = tempRet0;
 if ((($5|0) == 1)) {
  $$reg2mem38$0 = $6;
 } else {
  __THREW__ = 0;
  invoke_viiii(327,($create_struct|0),($error_ptr|0),($error_fn|0),($warn_fn|0));
  $7 = __THREW__; __THREW__ = 0;
  if ((($7|0) != 0) & ((threwValue|0) != 0)) { $8 = _testSetjmp(HEAP32[$7>>2]|0, _setjmpTable)|0; if (($8|0) == 0) { _longjmp($7|0, threwValue|0); } tempRet0 = threwValue; } else { $8 = -1; };
  $9 = tempRet0;
  if ((($8|0) == 1)) {
   $$reg2mem38$0 = $9;
  } else {
   _saveSetjmp($create_jmp_buf,1,_setjmpTable|0)|0;
   __THREW__ = 0;
   $10 = __THREW__; __THREW__ = 0;
   if ((($10|0) != 0) & ((threwValue|0) != 0)) { $11 = _testSetjmp(HEAP32[$10>>2]|0, _setjmpTable)|0; if (($11|0) == 0) { _longjmp($10|0, threwValue|0); } tempRet0 = threwValue; } else { $11 = -1; };
   $12 = tempRet0;
   if ((($11|0) == 1)) {
    $$reg2mem38$0 = $12;
   } else {
    $$reg2mem38$0 = 0;
   }
  }
 }
 while(1) {
  $13 = ($$reg2mem38$0|0)==(0);
  if (!($13)) {
   $$0$reg2mem$0 = 0;
   label = 11;
   break;
  }
  $14 = (($create_struct) + 160|0);
  HEAP32[$14>>2] = $create_jmp_buf;
  $15 = (($create_struct) + 164|0);
  HEAP32[$15>>2] = 0;
  $16 = (($create_struct) + 156|0);
  HEAP32[$16>>2] = 2525;
  __THREW__ = 0;
  $17 = (invoke_iii(2342,($create_struct|0),($user_png_ver|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  if ((($18|0) != 0) & ((threwValue|0) != 0)) { $19 = _testSetjmp(HEAP32[$18>>2]|0, _setjmpTable)|0; if (($19|0) == 0) { _longjmp($18|0, threwValue|0); } tempRet0 = threwValue; } else { $19 = -1; };
  $20 = tempRet0;
  if ((($19|0) == 1)) {
   $$reg2mem38$0 = $20;
   continue;
  }
  $21 = ($17|0)==(0);
  if ($21) {
   $$0$reg2mem$0 = 0;
   label = 11;
   break;
  }
  __THREW__ = 0;
  $22 = (invoke_iii(2343,($create_struct|0),756)|0);
  $23 = __THREW__; __THREW__ = 0;
  if ((($23|0) != 0) & ((threwValue|0) != 0)) { $24 = _testSetjmp(HEAP32[$23>>2]|0, _setjmpTable)|0; if (($24|0) == 0) { _longjmp($23|0, threwValue|0); } tempRet0 = threwValue; } else { $24 = -1; };
  $25 = tempRet0;
  if ((($24|0) == 1)) {
   $$reg2mem38$0 = $25;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  $26 = ($22|0)==(0|0);
  if ($26) {
   $$0$reg2mem$0 = 0;
   STACKTOP = sp;return ($$0$reg2mem$0|0);
  }
  $27 = (($create_struct) + 252|0);
  HEAP32[$27>>2] = 1523;
  $28 = (($create_struct) + 256|0);
  HEAP32[$28>>2] = 2526;
  $29 = (($create_struct) + 260|0);
  HEAP32[$29>>2] = $22;
  HEAP32[$14>>2] = 0;
  HEAP32[$15>>2] = 0;
  HEAP32[$16>>2] = 0;
  _memcpy(($22|0),($create_struct|0),756)|0;
  $$0$reg2mem$0 = $22;
  STACKTOP = sp;return ($$0$reg2mem$0|0);
 }
 else if ((label|0) == 11) {
  STACKTOP = sp;return ($$0$reg2mem$0|0);
 }
 return 0|0;
}
function _png_create_info_struct($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_png_malloc_base($png_ptr,244)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $$0 = $1;
  } else {
   _memset(($1|0),0,244)|0;
   $$0 = $1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _png_destroy_info_struct($png_ptr,$info_ptr_ptr) {
 $png_ptr = $png_ptr|0;
 $info_ptr_ptr = $info_ptr_ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 $1 = ($info_ptr_ptr|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$info_ptr_ptr>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 HEAP32[$info_ptr_ptr>>2] = 0;
 _png_free_data($png_ptr,$2,32767,-1);
 _memset(($2|0),0,244)|0;
 _png_free($png_ptr,$2);
 STACKTOP = sp;return;
}
function _png_free_data($png_ptr,$info_ptr,$mask,$num) {
 $png_ptr = $png_ptr|0;
 $info_ptr = $info_ptr|0;
 $mask = $mask|0;
 $num = $num|0;
 var $$lcssa = 0, $$pre = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$08 = 0, $i1$03 = 0, $i2$01 = 0, $mask$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 $1 = ($info_ptr|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = $mask & 16384;
 $3 = (($info_ptr) + 220|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2 & $4;
 $6 = ($5|0)==(0);
 do {
  if (!($6)) {
   $7 = ($num|0)==(-1);
   if ($7) {
    $8 = (($info_ptr) + 128|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)>(0);
    if ($10) {
     $i$08 = 0;
     while(1) {
      _png_free_data($png_ptr,$info_ptr,16384,$i$08);
      $19 = (($i$08) + 1)|0;
      $20 = HEAP32[$8>>2]|0;
      $21 = ($19|0)<($20|0);
      if ($21) {
       $i$08 = $19;
      } else {
       break;
      }
     }
    }
    $22 = (($info_ptr) + 136|0);
    $23 = HEAP32[$22>>2]|0;
    _png_free($png_ptr,$23);
    HEAP32[$22>>2] = 0;
    HEAP32[$8>>2] = 0;
    break;
   } else {
    $11 = (($info_ptr) + 136|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     break;
    }
    $14 = ((($12) + (($num*28)|0)|0) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     break;
    }
    _png_free($png_ptr,$15);
    $17 = HEAP32[$11>>2]|0;
    $18 = ((($17) + (($num*28)|0)|0) + 4|0);
    HEAP32[$18>>2] = 0;
    break;
   }
  }
 } while(0);
 $24 = $mask & 8192;
 $25 = HEAP32[$3>>2]|0;
 $26 = $24 & $25;
 $27 = ($26|0)==(0);
 if ($27) {
  $35 = $25;
 } else {
  $28 = (($info_ptr) + 148|0);
  $29 = HEAP32[$28>>2]|0;
  _png_free($png_ptr,$29);
  HEAP32[$28>>2] = 0;
  $30 = (($info_ptr) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $31 & -17;
  HEAP32[$30>>2] = $32;
  $$pre = HEAP32[$3>>2]|0;
  $35 = $$pre;
 }
 $33 = $mask & 256;
 $34 = $33 & $35;
 $36 = ($34|0)==(0);
 if ($36) {
  $46 = $35;
 } else {
  $37 = (($info_ptr) + 236|0);
  $38 = HEAP32[$37>>2]|0;
  _png_free($png_ptr,$38);
  $39 = (($info_ptr) + 240|0);
  $40 = HEAP32[$39>>2]|0;
  _png_free($png_ptr,$40);
  HEAP32[$37>>2] = 0;
  HEAP32[$39>>2] = 0;
  $41 = (($info_ptr) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 & -16385;
  HEAP32[$41>>2] = $43;
  $$pre13 = HEAP32[$3>>2]|0;
  $46 = $$pre13;
 }
 $44 = $mask & 128;
 $45 = $44 & $46;
 $47 = ($45|0)==(0);
 if ($47) {
  $73 = $46;
 } else {
  $48 = (($info_ptr) + 196|0);
  $49 = HEAP32[$48>>2]|0;
  _png_free($png_ptr,$49);
  $50 = (($info_ptr) + 208|0);
  $51 = HEAP32[$50>>2]|0;
  _png_free($png_ptr,$51);
  HEAP32[$48>>2] = 0;
  HEAP32[$50>>2] = 0;
  $52 = (($info_ptr) + 212|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (($info_ptr) + 217|0);
   $56 = HEAP8[$55>>0]|0;
   $57 = ($56<<24>>24)==(0);
   if ($57) {
    $$lcssa = $53;
   } else {
    $59 = $53;$i1$03 = 0;
    while(1) {
     $58 = (($59) + ($i1$03<<2)|0);
     $60 = HEAP32[$58>>2]|0;
     _png_free($png_ptr,$60);
     $61 = HEAP32[$52>>2]|0;
     $62 = (($61) + ($i1$03<<2)|0);
     HEAP32[$62>>2] = 0;
     $63 = (($i1$03) + 1)|0;
     $64 = HEAP8[$55>>0]|0;
     $65 = $64&255;
     $66 = ($63>>>0)<($65>>>0);
     $67 = HEAP32[$52>>2]|0;
     if ($66) {
      $59 = $67;$i1$03 = $63;
     } else {
      $$lcssa = $67;
      break;
     }
    }
   }
   _png_free($png_ptr,$$lcssa);
   HEAP32[$52>>2] = 0;
  }
  $68 = (($info_ptr) + 8|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = $69 & -1025;
  HEAP32[$68>>2] = $70;
  $$pre14 = HEAP32[$3>>2]|0;
  $73 = $$pre14;
 }
 $71 = $mask & 16;
 $72 = $71 & $73;
 $74 = ($72|0)==(0);
 if ($74) {
  $84 = $73;
 } else {
  $75 = (($info_ptr) + 116|0);
  $76 = HEAP32[$75>>2]|0;
  _png_free($png_ptr,$76);
  $77 = (($info_ptr) + 120|0);
  $78 = HEAP32[$77>>2]|0;
  _png_free($png_ptr,$78);
  HEAP32[$75>>2] = 0;
  HEAP32[$77>>2] = 0;
  $79 = (($info_ptr) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = $80 & -4097;
  HEAP32[$79>>2] = $81;
  $$pre15 = HEAP32[$3>>2]|0;
  $84 = $$pre15;
 }
 $82 = $mask & 32;
 $83 = $82 & $84;
 $85 = ($83|0)==(0);
 do {
  if (!($85)) {
   $86 = ($num|0)==(-1);
   if (!($86)) {
    $87 = (($info_ptr) + 224|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==(0|0);
    if ($89) {
     break;
    }
    $90 = (($88) + ($num<<4)|0);
    $91 = HEAP32[$90>>2]|0;
    _png_free($png_ptr,$91);
    $92 = HEAP32[$87>>2]|0;
    $93 = ((($92) + ($num<<4)|0) + 8|0);
    $94 = HEAP32[$93>>2]|0;
    _png_free($png_ptr,$94);
    $95 = HEAP32[$87>>2]|0;
    $96 = (($95) + ($num<<4)|0);
    HEAP32[$96>>2] = 0;
    $97 = HEAP32[$87>>2]|0;
    $98 = ((($97) + ($num<<4)|0) + 8|0);
    HEAP32[$98>>2] = 0;
    break;
   }
   $99 = (($info_ptr) + 228|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==(0);
   if (!($101)) {
    $102 = ($100|0)>(0);
    if ($102) {
     $i2$01 = 0;
     while(1) {
      _png_free_data($png_ptr,$info_ptr,32,$i2$01);
      $103 = (($i2$01) + 1)|0;
      $104 = HEAP32[$99>>2]|0;
      $105 = ($103|0)<($104|0);
      if ($105) {
       $i2$01 = $103;
      } else {
       break;
      }
     }
    }
    $106 = (($info_ptr) + 224|0);
    $107 = HEAP32[$106>>2]|0;
    _png_free($png_ptr,$107);
    HEAP32[$106>>2] = 0;
    HEAP32[$99>>2] = 0;
   }
   $108 = (($info_ptr) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = $109 & -8193;
   HEAP32[$108>>2] = $110;
  }
 } while(0);
 $111 = $mask & 4096;
 $112 = HEAP32[$3>>2]|0;
 $113 = $111 & $112;
 $114 = ($113|0)==(0);
 if ($114) {
  $125 = $112;
 } else {
  $115 = (($info_ptr) + 16|0);
  $116 = HEAP32[$115>>2]|0;
  _png_free($png_ptr,$116);
  HEAP32[$115>>2] = 0;
  $117 = (($info_ptr) + 8|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = $118 & -9;
  HEAP32[$117>>2] = $119;
  $120 = (($info_ptr) + 20|0);
  HEAP16[$120>>1] = 0;
  $$pre16 = HEAP32[$3>>2]|0;
  $125 = $$pre16;
 }
 $121 = ($num|0)==(-1);
 $122 = $mask & -16929;
 $mask$ = $121 ? $mask : $122;
 $123 = $mask$ ^ -1;
 $124 = $125 & $123;
 HEAP32[$3>>2] = $124;
 STACKTOP = sp;return;
}
function _png_get_io_ptr($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (($png_ptr) + 184|0);
  $2 = HEAP32[$1>>2]|0;
  $$0 = $2;
 }
 STACKTOP = sp;return ($$0|0);
}
function _png_save_int_32($buf,$i) {
 $buf = $buf|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $i >>> 24;
 $1 = $0&255;
 HEAP8[$buf>>0] = $1;
 $2 = $i >>> 16;
 $3 = $2&255;
 $4 = (($buf) + 1|0);
 HEAP8[$4>>0] = $3;
 $5 = $i >>> 8;
 $6 = $5&255;
 $7 = (($buf) + 2|0);
 HEAP8[$7>>0] = $6;
 $8 = $i&255;
 $9 = (($buf) + 3|0);
 HEAP8[$9>>0] = $8;
 STACKTOP = sp;return;
}
function _png_zstream_error($png_ptr,$ret) {
 $png_ptr = $png_ptr|0;
 $ret = $ret|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 244|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   do {
    switch ($ret|0) {
    case 1:  {
     HEAP32[$0>>2] = 390344;
     break L1;
     break;
    }
    case -1:  {
     HEAP32[$0>>2] = 390400;
     break L1;
     break;
    }
    case -5:  {
     HEAP32[$0>>2] = 390488;
     break L1;
     break;
    }
    case -2:  {
     HEAP32[$0>>2] = 390416;
     break L1;
     break;
    }
    case -7:  {
     HEAP32[$0>>2] = 390536;
     break L1;
     break;
    }
    case -3:  {
     HEAP32[$0>>2] = 390440;
     break L1;
     break;
    }
    case 2:  {
     HEAP32[$0>>2] = 390376;
     break L1;
     break;
    }
    case -6:  {
     HEAP32[$0>>2] = 390504;
     break L1;
     break;
    }
    case -4:  {
     HEAP32[$0>>2] = 390464;
     break L1;
     break;
    }
    default: {
     HEAP32[$0>>2] = 390312;
     break L1;
    }
    }
   } while(0);
  }
 } while(0);
 STACKTOP = sp;return;
}
function _png_check_IHDR($png_ptr,$width,$height,$bit_depth,$color_type,$interlace_type,$compression_type,$filter_type) {
 $png_ptr = $png_ptr|0;
 $width = $width|0;
 $height = $height|0;
 $bit_depth = $bit_depth|0;
 $color_type = $color_type|0;
 $interlace_type = $interlace_type|0;
 $compression_type = $compression_type|0;
 $filter_type = $filter_type|0;
 var $$ = 0, $$error$1 = 0, $$error$3 = 0, $$error$5 = 0, $$error$8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $bit_depth$off = 0, $error$1 = 0, $error$10 = 0, $error$11 = 0, $error$11$ = 0, $error$12 = 0, $error$3 = 0, $error$5 = 0, $error$7 = 0, $error$8 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond20 = 0, $or$cond21 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($width|0)==(0);
 $$ = $0&1;
 $1 = ($height|0)==(0);
 $error$1 = $1 ? 1 : $$;
 $2 = (($png_ptr) + 624|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)<($width>>>0);
 $$error$1 = $4 ? 1 : $error$1;
 $5 = (($png_ptr) + 628|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6>>>0)<($height>>>0);
 $error$3 = $7 ? 1 : $$error$1;
 $8 = ($width|0)<(0);
 $$error$3 = $8 ? 1 : $error$3;
 $9 = ($height|0)<(0);
 $error$5 = $9 ? 1 : $$error$3;
 $bit_depth$off = (($bit_depth) + -1)|0;
 $10 = ($bit_depth$off>>>0)>(1);
 $11 = ($bit_depth|0)!=(4);
 $or$cond3 = $10 & $11;
 $12 = ($bit_depth|0)!=(8);
 $or$cond5 = $or$cond3 & $12;
 $13 = ($bit_depth|0)!=(16);
 $or$cond7 = $or$cond5 & $13;
 $$error$5 = $or$cond7 ? 1 : $error$5;
 $14 = ($color_type|0)<(0);
 $15 = ($color_type|0)==(1);
 $or$cond9 = $14 | $15;
 $16 = ($color_type|0)==(5);
 $or$cond11 = $or$cond9 | $16;
 $17 = ($color_type|0)>(6);
 $or$cond13 = $or$cond11 | $17;
 $error$7 = $or$cond13 ? 1 : $$error$5;
 $18 = ($color_type|0)==(3);
 $19 = ($bit_depth|0)>(8);
 $or$cond = $18 & $19;
 if ($or$cond) {
  label = 4;
 } else {
  if ((($color_type|0) == 2) | (($color_type|0) == 4) | (($color_type|0) == 6)) {
   $20 = ($bit_depth|0)<(8);
   if ($20) {
    label = 4;
   } else {
    $error$8 = $error$7;
   }
  } else {
   $error$8 = $error$7;
  }
 }
 if ((label|0) == 4) {
  $error$8 = 1;
 }
 $21 = ($interlace_type|0)>(1);
 $$error$8 = $21 ? 1 : $error$8;
 $22 = ($compression_type|0)==(0);
 $error$10 = $22 ? $$error$8 : 1;
 $23 = ($filter_type|0)==(0);
 if ($23) {
  $error$12 = $error$10;
 } else {
  $24 = (($png_ptr) + 204|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 & 4096;
  $27 = (($png_ptr) + 596|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 & 4;
  $30 = ($29|0)!=(0);
  $31 = ($filter_type|0)==(64);
  $or$cond20 = $30 & $31;
  $32 = ($26|0)==(0);
  $or$cond21 = $or$cond20 & $32;
  if ($or$cond21) {
   $33 = $color_type & -5;
   $34 = ($33|0)==(2);
   if ($34) {
    $error$11 = $error$10;
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
  if ((label|0) == 8) {
   $error$11 = 1;
  }
  $error$11$ = $32 ? $error$11 : 1;
  $error$12 = $error$11$;
 }
 $35 = ($error$12|0)==(1);
 if ($35) {
  _png_error($png_ptr,390560);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function _png_error($png_ptr,$error_message) {
 $png_ptr = $png_ptr|0;
 $error_message = $error_message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if (!($0)) {
  $1 = (($png_ptr) + 168|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   FUNCTION_TABLE_vii[$2 & 4095]($png_ptr,$error_message);
  }
 }
 _png_longjmp($png_ptr,1);
 // unreachable;
}
function _png_safecat($buffer,$bufsize,$pos,$string) {
 $buffer = $buffer|0;
 $bufsize = $bufsize|0;
 $pos = $pos|0;
 $string = $string|0;
 var $$014 = 0, $$05 = 0, $$1 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond2 = 0, $or$cond23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buffer|0)!=(0|0);
 $1 = ($pos>>>0)<($bufsize>>>0);
 $or$cond = $0 & $1;
 if (!($or$cond)) {
  $$2 = $pos;
  STACKTOP = sp;return ($$2|0);
 }
 $2 = ($string|0)==(0|0);
 if ($2) {
  $$1 = $pos;
 } else {
  $3 = (($bufsize) + -1)|0;
  $4 = HEAP8[$string>>0]|0;
  $5 = ($4<<24>>24)!=(0);
  $6 = ($3>>>0)>($pos>>>0);
  $or$cond23 = $5 & $6;
  if ($or$cond23) {
   $$014 = $pos;$$05 = $string;$10 = $4;
   while(1) {
    $7 = (($$05) + 1|0);
    $8 = (($$014) + 1)|0;
    $9 = (($buffer) + ($$014)|0);
    HEAP8[$9>>0] = $10;
    $11 = HEAP8[$7>>0]|0;
    $12 = ($11<<24>>24)!=(0);
    $13 = ($8>>>0)<($3>>>0);
    $or$cond2 = $12 & $13;
    if ($or$cond2) {
     $$014 = $8;$$05 = $7;$10 = $11;
    } else {
     $$1 = $8;
     break;
    }
   }
  } else {
   $$1 = $pos;
  }
 }
 $14 = (($buffer) + ($$1)|0);
 HEAP8[$14>>0] = 0;
 $$2 = $$1;
 STACKTOP = sp;return ($$2|0);
}
function _png_benign_error($png_ptr,$error_message) {
 $png_ptr = $png_ptr|0;
 $error_message = $error_message|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 208|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1048576;
 $3 = ($2|0)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($png_ptr) + 204|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 32768;
 $7 = ($6|0)==(0);
 if ($7) {
  _png_error($png_ptr,$error_message);
  // unreachable;
 }
 $8 = (($png_ptr) + 372|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  _png_error($png_ptr,$error_message);
  // unreachable;
 } else {
  _png_chunk_error($png_ptr,$error_message);
  // unreachable;
 }
}
function _png_chunk_error($png_ptr,$error_message) {
 $png_ptr = $png_ptr|0;
 $error_message = $error_message|0;
 var $$off$1$i = 0, $$off$2$i = 0, $$off$3$i = 0, $$off$i = 0, $$off4$1$i = 0, $$off4$2$i = 0, $$off4$3$i = 0, $$off4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $iin$02$i = 0, $iout$0$be$1$i = 0, $iout$0$be$2$i = 0, $iout$0$be$3$i = 0, $iout$0$be$i = 0, $iout$1$lcssa$i = 0, $iout$11$i = 0, $msg = 0, $or$cond$1$i = 0, $or$cond$2$i = 0, $or$cond$3$i = 0, $or$cond$i = 0, $png_ptr$idx = 0, $png_ptr$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $msg = sp;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  _png_error(0,$error_message);
  // unreachable;
 }
 $png_ptr$idx = (($png_ptr) + 372|0);
 $png_ptr$idx$val = HEAP32[$png_ptr$idx>>2]|0;
 $1 = $png_ptr$idx$val >>> 24;
 $$off$i = (($1) + -65)|0;
 $2 = ($$off$i>>>0)>(57);
 $$off4$i = (($1) + -91)|0;
 $3 = ($$off4$i>>>0)<(6);
 $or$cond$i = $2 | $3;
 if ($or$cond$i) {
  HEAP8[$msg>>0] = 91;
  $4 = $png_ptr$idx$val >>> 28;
  $5 = (390616 + ($4)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = (($msg) + 1|0);
  HEAP8[$7>>0] = $6;
  $8 = $1 & 15;
  $9 = (390616 + ($8)|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = (($msg) + 2|0);
  HEAP8[$11>>0] = $10;
  $12 = (($msg) + 3|0);
  HEAP8[$12>>0] = 93;
  $iout$0$be$i = 4;
 } else {
  $13 = $1&255;
  HEAP8[$msg>>0] = $13;
  $iout$0$be$i = 1;
 }
 $14 = $png_ptr$idx$val >>> 16;
 $15 = $14 & 255;
 $$off$1$i = (($15) + -65)|0;
 $16 = ($$off$1$i>>>0)>(57);
 $$off4$1$i = (($15) + -91)|0;
 $17 = ($$off4$1$i>>>0)<(6);
 $or$cond$1$i = $16 | $17;
 if ($or$cond$1$i) {
  $34 = (($iout$0$be$i) + 1)|0;
  $35 = (($msg) + ($iout$0$be$i)|0);
  HEAP8[$35>>0] = 91;
  $36 = $png_ptr$idx$val >>> 20;
  $37 = $36 & 15;
  $38 = (390616 + ($37)|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $iout$0$be$i | 2;
  $41 = (($msg) + ($34)|0);
  HEAP8[$41>>0] = $39;
  $42 = $14 & 15;
  $43 = (390616 + ($42)|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = (($iout$0$be$i) + 3)|0;
  $46 = (($msg) + ($40)|0);
  HEAP8[$46>>0] = $44;
  $47 = (($iout$0$be$i) + 4)|0;
  $48 = (($msg) + ($45)|0);
  HEAP8[$48>>0] = 93;
  $iout$0$be$1$i = $47;
 } else {
  $31 = $14&255;
  $32 = (($iout$0$be$i) + 1)|0;
  $33 = (($msg) + ($iout$0$be$i)|0);
  HEAP8[$33>>0] = $31;
  $iout$0$be$1$i = $32;
 }
 $49 = $png_ptr$idx$val >>> 8;
 $50 = $49 & 255;
 $$off$2$i = (($50) + -65)|0;
 $51 = ($$off$2$i>>>0)>(57);
 $$off4$2$i = (($50) + -91)|0;
 $52 = ($$off4$2$i>>>0)<(6);
 $or$cond$2$i = $51 | $52;
 if ($or$cond$2$i) {
  $56 = (($iout$0$be$1$i) + 1)|0;
  $57 = (($msg) + ($iout$0$be$1$i)|0);
  HEAP8[$57>>0] = 91;
  $58 = $png_ptr$idx$val >>> 12;
  $59 = $58 & 15;
  $60 = (390616 + ($59)|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = (($iout$0$be$1$i) + 2)|0;
  $63 = (($msg) + ($56)|0);
  HEAP8[$63>>0] = $61;
  $64 = $49 & 15;
  $65 = (390616 + ($64)|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = (($iout$0$be$1$i) + 3)|0;
  $68 = (($msg) + ($62)|0);
  HEAP8[$68>>0] = $66;
  $69 = (($iout$0$be$1$i) + 4)|0;
  $70 = (($msg) + ($67)|0);
  HEAP8[$70>>0] = 93;
  $iout$0$be$2$i = $69;
 } else {
  $53 = $49&255;
  $54 = (($iout$0$be$1$i) + 1)|0;
  $55 = (($msg) + ($iout$0$be$1$i)|0);
  HEAP8[$55>>0] = $53;
  $iout$0$be$2$i = $54;
 }
 $71 = $png_ptr$idx$val & 255;
 $$off$3$i = (($71) + -65)|0;
 $72 = ($$off$3$i>>>0)>(57);
 $$off4$3$i = (($71) + -91)|0;
 $73 = ($$off4$3$i>>>0)<(6);
 $or$cond$3$i = $72 | $73;
 if ($or$cond$3$i) {
  $77 = (($iout$0$be$2$i) + 1)|0;
  $78 = (($msg) + ($iout$0$be$2$i)|0);
  HEAP8[$78>>0] = 91;
  $79 = $png_ptr$idx$val >>> 4;
  $80 = $79 & 15;
  $81 = (390616 + ($80)|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = (($iout$0$be$2$i) + 2)|0;
  $84 = (($msg) + ($77)|0);
  HEAP8[$84>>0] = $82;
  $85 = $png_ptr$idx$val & 15;
  $86 = (390616 + ($85)|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = (($iout$0$be$2$i) + 3)|0;
  $89 = (($msg) + ($83)|0);
  HEAP8[$89>>0] = $87;
  $90 = (($iout$0$be$2$i) + 4)|0;
  $91 = (($msg) + ($88)|0);
  HEAP8[$91>>0] = 93;
  $iout$0$be$3$i = $90;
 } else {
  $74 = $png_ptr$idx$val&255;
  $75 = (($iout$0$be$2$i) + 1)|0;
  $76 = (($msg) + ($iout$0$be$2$i)|0);
  HEAP8[$76>>0] = $74;
  $iout$0$be$3$i = $75;
 }
 $92 = ($error_message|0)==(0|0);
 if ($92) {
  $18 = (($msg) + ($iout$0$be$3$i)|0);
  HEAP8[$18>>0] = 0;
  _png_error($png_ptr,$msg);
  // unreachable;
 }
 $19 = (($iout$0$be$3$i) + 1)|0;
 $20 = (($msg) + ($iout$0$be$3$i)|0);
 HEAP8[$20>>0] = 58;
 $21 = (($iout$0$be$3$i) + 2)|0;
 $22 = (($msg) + ($19)|0);
 HEAP8[$22>>0] = 32;
 $iin$02$i = 0;$iout$11$i = $21;
 while(1) {
  $23 = (($error_message) + ($iin$02$i)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   $iout$1$lcssa$i = $iout$11$i;
   break;
  }
  $26 = (($iin$02$i) + 1)|0;
  $27 = (($iout$11$i) + 1)|0;
  $28 = (($msg) + ($iout$11$i)|0);
  HEAP8[$28>>0] = $24;
  $29 = ($26|0)<(195);
  if ($29) {
   $iin$02$i = $26;$iout$11$i = $27;
  } else {
   $iout$1$lcssa$i = $27;
   break;
  }
 }
 $30 = (($msg) + ($iout$1$lcssa$i)|0);
 HEAP8[$30>>0] = 0;
 _png_error($png_ptr,$msg);
 // unreachable;
}
function _png_app_warning($png_ptr,$error_message) {
 $png_ptr = $png_ptr|0;
 $error_message = $error_message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 208|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2097152;
 $3 = ($2|0)==(0);
 if ($3) {
  _png_error($png_ptr,$error_message);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function _png_set_longjmp_fn($png_ptr,$longjmp_fn,$jmp_buf_size) {
 $png_ptr = $png_ptr|0;
 $longjmp_fn = $longjmp_fn|0;
 $jmp_buf_size = $jmp_buf_size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($png_ptr) + 160|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = (($png_ptr) + 164|0);
 do {
  if ($3) {
   HEAP32[$4>>2] = 0;
   $5 = ($jmp_buf_size>>>0)<(157);
   if ($5) {
    HEAP32[$1>>2] = $png_ptr;
    $13 = $png_ptr;
    break;
   }
   $6 = (_png_malloc_warn($png_ptr,$jmp_buf_size)|0);
   HEAP32[$1>>2] = $6;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$4>>2] = $jmp_buf_size;
    $13 = $6;
    break;
   }
  } else {
   $8 = HEAP32[$4>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = ($2|0)==($png_ptr|0);
    if ($10) {
     $size$0 = 156;
    } else {
     _png_error($png_ptr,390584);
     // unreachable;
    }
   } else {
    $size$0 = $8;
   }
   $11 = ($size$0|0)==($jmp_buf_size|0);
   if ($11) {
    $13 = $2;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $12 = (($png_ptr) + 156|0);
 HEAP32[$12>>2] = $longjmp_fn;
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function _png_free_jmpbuf($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $$pre = 0, $$reg2mem15$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $free_jmp_buf = 0, $or$cond = 0;
 var _setjmpTable = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 _setjmpTable = STACKTOP; STACKTOP = STACKTOP + 168|0;HEAP32[_setjmpTable>>2]=0;
 $free_jmp_buf = sp;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 160|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $$pre = (($png_ptr) + 164|0);
 L4: do {
  if (!($3)) {
   $4 = HEAP32[$$pre>>2]|0;
   $5 = ($4|0)==(0);
   $6 = ($2|0)==($png_ptr|0);
   $or$cond = $5 | $6;
   if (!($or$cond)) {
    _saveSetjmp($free_jmp_buf,1,_setjmpTable|0)|0;
    __THREW__ = 0;
    $7 = __THREW__; __THREW__ = 0;
    if ((($7|0) != 0) & ((threwValue|0) != 0)) { $8 = _testSetjmp(HEAP32[$7>>2]|0, _setjmpTable)|0; if (($8|0) == 0) { _longjmp($7|0, threwValue|0); } tempRet0 = threwValue; } else { $8 = -1; };
    $9 = tempRet0;
    if ((($8|0) == 1)) {
     $$reg2mem15$0 = $9;
    } else {
     $$reg2mem15$0 = 0;
    }
    while(1) {
     $10 = ($$reg2mem15$0|0)==(0);
     if (!($10)) {
      break L4;
     }
     HEAP32[$1>>2] = $free_jmp_buf;
     HEAP32[$$pre>>2] = 0;
     $11 = (($png_ptr) + 156|0);
     HEAP32[$11>>2] = 2525;
     __THREW__ = 0;
     invoke_vii(2527,($png_ptr|0),($2|0));
     $12 = __THREW__; __THREW__ = 0;
     if ((($12|0) != 0) & ((threwValue|0) != 0)) { $13 = _testSetjmp(HEAP32[$12>>2]|0, _setjmpTable)|0; if (($13|0) == 0) { _longjmp($12|0, threwValue|0); } tempRet0 = threwValue; } else { $13 = -1; };
     $14 = tempRet0;
     if ((($13|0) == 1)) {
      $$reg2mem15$0 = $14;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 HEAP32[$$pre>>2] = 0;
 HEAP32[$1>>2] = 0;
 $15 = (($png_ptr) + 156|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function _png_longjmp($png_ptr,$val) {
 $png_ptr = $png_ptr|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if (!($0)) {
  $1 = (($png_ptr) + 156|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($png_ptr) + 160|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    FUNCTION_TABLE_vii[$2 & 4095]($5,$val);
   }
  }
 }
 _abort();
 // unreachable;
}
function _png_set_error_fn($png_ptr,$error_ptr,$error_fn,$warning_fn) {
 $png_ptr = $png_ptr|0;
 $error_ptr = $error_ptr|0;
 $error_fn = $error_fn|0;
 $warning_fn = $warning_fn|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 172|0);
 HEAP32[$1>>2] = $error_ptr;
 $2 = (($png_ptr) + 168|0);
 HEAP32[$2>>2] = $error_fn;
 STACKTOP = sp;return;
}
function _png_destroy_png_struct($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $dummy_struct = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 768|0;
 $dummy_struct = sp;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 _memcpy(($dummy_struct|0),($png_ptr|0),756)|0;
 _memset(($png_ptr|0),0,756)|0;
 $1 = (($dummy_struct) + 612|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  _free($png_ptr);
 } else {
  FUNCTION_TABLE_vii[$2 & 4095]($dummy_struct,$png_ptr);
 }
 _png_free_jmpbuf($dummy_struct);
 STACKTOP = sp;return;
}
function _png_free($png_ptr,$ptr) {
 $png_ptr = $png_ptr|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 $1 = ($ptr|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = (($png_ptr) + 612|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  _free($ptr);
  STACKTOP = sp;return;
 } else {
  FUNCTION_TABLE_vii[$3 & 4095]($png_ptr,$ptr);
  STACKTOP = sp;return;
 }
}
function _png_calloc($png_ptr,$size) {
 $png_ptr = $png_ptr|0;
 $size = $size|0;
 var $$0$i$i = 0, $$0$i1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  $$0$i1 = 0;
  STACKTOP = sp;return ($$0$i1|0);
 }
 $1 = ($size|0)==(0);
 if ($1) {
  _png_error($png_ptr,390632);
  // unreachable;
 }
 $2 = (($png_ptr) + 608|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $6 = (_malloc($size)|0);
  $$0$i$i = $6;
 } else {
  $5 = (FUNCTION_TABLE_iii[$3 & 4095]($png_ptr,$size)|0);
  $$0$i$i = $5;
 }
 $7 = ($$0$i$i|0)==(0|0);
 if ($7) {
  _png_error($png_ptr,390632);
  // unreachable;
 }
 _memset(($$0$i$i|0),0,($size|0))|0;
 $$0$i1 = $$0$i$i;
 STACKTOP = sp;return ($$0$i1|0);
}
function _png_malloc($png_ptr,$size) {
 $png_ptr = $png_ptr|0;
 $size = $size|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($size|0)==(0);
 if ($1) {
  _png_error($png_ptr,390632);
  // unreachable;
 }
 $2 = (($png_ptr) + 608|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $6 = (_malloc($size)|0);
  $$0$i = $6;
 } else {
  $5 = (FUNCTION_TABLE_iii[$3 & 4095]($png_ptr,$size)|0);
  $$0$i = $5;
 }
 $7 = ($$0$i|0)==(0|0);
 if ($7) {
  _png_error($png_ptr,390632);
  // unreachable;
 } else {
  $$0 = $$0$i;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _png_malloc_base($png_ptr,$size) {
 $png_ptr = $png_ptr|0;
 $size = $size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = ($png_ptr|0)==(0|0);
   if (!($1)) {
    $2 = (($png_ptr) + 608|0);
    $3 = HEAP32[$2>>2]|0;
    $4 = ($3|0)==(0|0);
    if (!($4)) {
     $5 = (FUNCTION_TABLE_iii[$3 & 4095]($png_ptr,$size)|0);
     $$0 = $5;
     break;
    }
   }
   $6 = (_malloc($size)|0);
   $$0 = $6;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _png_malloc_warn($png_ptr,$size) {
 $png_ptr = $png_ptr|0;
 $size = $size|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 $1 = ($size|0)==(0);
 $or$cond = $0 | $1;
 if (!($or$cond)) {
  $2 = (($png_ptr) + 608|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $6 = (_malloc($size)|0);
   $$0$i = $6;
  } else {
   $5 = (FUNCTION_TABLE_iii[$3 & 4095]($png_ptr,$size)|0);
   $$0$i = $5;
  }
  $7 = ($$0$i|0)==(0|0);
  if (!($7)) {
   $$0 = $$0$i;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _png_set_mem_fn($png_ptr,$mem_ptr,$malloc_fn,$free_fn) {
 $png_ptr = $png_ptr|0;
 $mem_ptr = $mem_ptr|0;
 $malloc_fn = $malloc_fn|0;
 $free_fn = $free_fn|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 604|0);
 HEAP32[$1>>2] = $mem_ptr;
 $2 = (($png_ptr) + 608|0);
 HEAP32[$2>>2] = $malloc_fn;
 $3 = (($png_ptr) + 612|0);
 HEAP32[$3>>2] = $free_fn;
 STACKTOP = sp;return;
}
function _png_set_IHDR($png_ptr,$info_ptr,$width,$height,$bit_depth,$color_type,$interlace_type,$compression_type,$filter_type) {
 $png_ptr = $png_ptr|0;
 $info_ptr = $info_ptr|0;
 $width = $width|0;
 $height = $height|0;
 $bit_depth = $bit_depth|0;
 $color_type = $color_type|0;
 $interlace_type = $interlace_type|0;
 $compression_type = $compression_type|0;
 $filter_type = $filter_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 $1 = ($info_ptr|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 HEAP32[$info_ptr>>2] = $width;
 $2 = (($info_ptr) + 4|0);
 HEAP32[$2>>2] = $height;
 $3 = $bit_depth&255;
 $4 = (($info_ptr) + 24|0);
 HEAP8[$4>>0] = $3;
 $5 = $color_type&255;
 $6 = (($info_ptr) + 25|0);
 HEAP8[$6>>0] = $5;
 $7 = $compression_type&255;
 $8 = (($info_ptr) + 26|0);
 HEAP8[$8>>0] = $7;
 $9 = $filter_type&255;
 $10 = (($info_ptr) + 27|0);
 HEAP8[$10>>0] = $9;
 $11 = $interlace_type&255;
 $12 = (($info_ptr) + 28|0);
 HEAP8[$12>>0] = $11;
 $13 = $bit_depth & 255;
 $14 = $color_type & 255;
 $15 = $interlace_type & 255;
 $16 = $compression_type & 255;
 $17 = $filter_type & 255;
 _png_check_IHDR($png_ptr,$width,$height,$13,$14,$15,$16,$17);
 $18 = HEAP8[$6>>0]|0;
 $19 = ($18<<24>>24)==(3);
 if ($19) {
  $20 = (($info_ptr) + 29|0);
  HEAP8[$20>>0] = 1;
  $30 = 1;
 } else {
  $21 = $18 & 2;
  $22 = ($21<<24>>24)==(0);
  $23 = (($info_ptr) + 29|0);
  if ($22) {
   $28 = 1;$storemerge = 1;
  } else {
   $28 = 3;$storemerge = 3;
  }
  HEAP8[$23>>0] = $storemerge;
  $24 = $18 & 4;
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   $30 = $28;
  } else {
   $26 = (($info_ptr) + 29|0);
   $27 = (($28) + 1)<<24>>24;
   HEAP8[$26>>0] = $27;
   $30 = $27;
  }
 }
 $29 = $30&255;
 $31 = HEAP8[$4>>0]|0;
 $32 = $31&255;
 $33 = Math_imul($32, $29)|0;
 $34 = $33&255;
 $35 = (($info_ptr) + 30|0);
 HEAP8[$35>>0] = $34;
 $36 = $33 & 255;
 $37 = ($36>>>0)>(7);
 if ($37) {
  $38 = $36 >>> 3;
  $39 = Math_imul($38, $width)|0;
  $44 = $39;
 } else {
  $40 = Math_imul($36, $width)|0;
  $41 = (($40) + 7)|0;
  $42 = $41 >>> 3;
  $44 = $42;
 }
 $43 = (($info_ptr) + 12|0);
 HEAP32[$43>>2] = $44;
 STACKTOP = sp;return;
}
function _png_do_swap($row_info,$row) {
 $row_info = $row_info|0;
 $row = $row|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $rp$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($row_info) + 9|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(16);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$row_info>>2]|0;
 $4 = (($row_info) + 10|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = Math_imul($6, $3)|0;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;$rp$02 = $row;
 }
 while(1) {
  $9 = HEAP8[$rp$02>>0]|0;
  $10 = (($rp$02) + 1|0);
  $11 = HEAP8[$10>>0]|0;
  HEAP8[$rp$02>>0] = $11;
  HEAP8[$10>>0] = $9;
  $12 = (($i$01) + 1)|0;
  $13 = (($rp$02) + 2|0);
  $exitcond = ($12|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $12;$rp$02 = $13;
  }
 }
 STACKTOP = sp;return;
}
function _png_do_strip_channel($row_info,$row,$at_start) {
 $row_info = $row_info|0;
 $row = $row|0;
 $at_start = $at_start|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, $dp$0$lcssa = 0, $dp$0$ph = 0, $dp$01 = 0, $dp$1$lcssa = 0, $dp$1$ph = 0, $dp$14 = 0, $dp$2 = 0, $dp$3$lcssa = 0, $dp$3$ph = 0, $dp$310 = 0, $dp$4$lcssa = 0, $dp$4$ph = 0, $dp$416 = 0, $dp$5 = 0, $dp$6 = 0, $sp$0$ph = 0, $sp$02 = 0, $sp$1$ph = 0;
 var $sp$15 = 0, $sp$2$ph = 0, $sp$211 = 0, $sp$3$ph = 0, $sp$317 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($row_info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($row) + ($1)|0);
 $3 = (($row_info) + 10|0);
 $4 = HEAP8[$3>>0]|0;
 if ((($4<<24>>24) == 2)) {
  $5 = (($row_info) + 9|0);
  $6 = HEAP8[$5>>0]|0;
  if ((($6<<24>>24) == 16)) {
   $17 = ($at_start|0)==(0);
   if ($17) {
    $19 = (($row) + 4|0);
    $20 = (($row) + 2|0);
    $dp$1$ph = $20;$sp$1$ph = $19;
   } else {
    $18 = (($row) + 2|0);
    $dp$1$ph = $row;$sp$1$ph = $18;
   }
   $21 = ($sp$1$ph>>>0)<($2>>>0);
   if ($21) {
    $dp$14 = $dp$1$ph;$sp$15 = $sp$1$ph;
    while(1) {
     $22 = (($sp$15) + 1|0);
     $23 = HEAP8[$sp$15>>0]|0;
     $24 = (($dp$14) + 1|0);
     HEAP8[$dp$14>>0] = $23;
     $25 = HEAP8[$22>>0]|0;
     $26 = (($dp$14) + 2|0);
     HEAP8[$24>>0] = $25;
     $27 = (($sp$15) + 4|0);
     $28 = ($27>>>0)<($2>>>0);
     if ($28) {
      $dp$14 = $26;$sp$15 = $27;
     } else {
      $dp$1$lcssa = $26;
      break;
     }
    }
   } else {
    $dp$1$lcssa = $dp$1$ph;
   }
   $29 = (($row_info) + 11|0);
   HEAP8[$29>>0] = 16;
   $dp$2 = $dp$1$lcssa;
  } else if ((($6<<24>>24) == 8)) {
   $7 = ($at_start|0)==(0);
   if ($7) {
    $9 = (($row) + 2|0);
    $10 = (($row) + 1|0);
    $dp$0$ph = $10;$sp$0$ph = $9;
   } else {
    $8 = (($row) + 1|0);
    $dp$0$ph = $row;$sp$0$ph = $8;
   }
   $11 = ($sp$0$ph>>>0)<($2>>>0);
   if ($11) {
    $dp$01 = $dp$0$ph;$sp$02 = $sp$0$ph;
    while(1) {
     $12 = HEAP8[$sp$02>>0]|0;
     $13 = (($dp$01) + 1|0);
     HEAP8[$dp$01>>0] = $12;
     $14 = (($sp$02) + 2|0);
     $15 = ($14>>>0)<($2>>>0);
     if ($15) {
      $dp$01 = $13;$sp$02 = $14;
     } else {
      $dp$0$lcssa = $13;
      break;
     }
    }
   } else {
    $dp$0$lcssa = $dp$0$ph;
   }
   $16 = (($row_info) + 11|0);
   HEAP8[$16>>0] = 8;
   $dp$2 = $dp$0$lcssa;
  } else {
   STACKTOP = sp;return;
  }
  HEAP8[$3>>0] = 1;
  $30 = (($row_info) + 8|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)==(4);
  if ($32) {
   HEAP8[$30>>0] = 0;
   $dp$6 = $dp$2;
  } else {
   $dp$6 = $dp$2;
  }
 } else if ((($4<<24>>24) == 4)) {
  $33 = (($row_info) + 9|0);
  $34 = HEAP8[$33>>0]|0;
  if ((($34<<24>>24) == 8)) {
   $35 = ($at_start|0)==(0);
   if ($35) {
    $37 = (($row) + 4|0);
    $38 = (($row) + 3|0);
    $dp$3$ph = $38;$sp$2$ph = $37;
   } else {
    $36 = (($row) + 1|0);
    $dp$3$ph = $row;$sp$2$ph = $36;
   }
   $39 = ($sp$2$ph>>>0)<($2>>>0);
   if ($39) {
    $dp$310 = $dp$3$ph;$sp$211 = $sp$2$ph;
    while(1) {
     $40 = (($sp$211) + 1|0);
     $41 = HEAP8[$sp$211>>0]|0;
     $42 = (($dp$310) + 1|0);
     HEAP8[$dp$310>>0] = $41;
     $43 = (($sp$211) + 2|0);
     $44 = HEAP8[$40>>0]|0;
     $45 = (($dp$310) + 2|0);
     HEAP8[$42>>0] = $44;
     $46 = HEAP8[$43>>0]|0;
     $47 = (($dp$310) + 3|0);
     HEAP8[$45>>0] = $46;
     $48 = (($sp$211) + 4|0);
     $49 = ($48>>>0)<($2>>>0);
     if ($49) {
      $dp$310 = $47;$sp$211 = $48;
     } else {
      $dp$3$lcssa = $47;
      break;
     }
    }
   } else {
    $dp$3$lcssa = $dp$3$ph;
   }
   $50 = (($row_info) + 11|0);
   HEAP8[$50>>0] = 24;
   $dp$5 = $dp$3$lcssa;
  } else if ((($34<<24>>24) == 16)) {
   $51 = ($at_start|0)==(0);
   if ($51) {
    $53 = (($row) + 8|0);
    $54 = (($row) + 6|0);
    $dp$4$ph = $54;$sp$3$ph = $53;
   } else {
    $52 = (($row) + 2|0);
    $dp$4$ph = $row;$sp$3$ph = $52;
   }
   $55 = ($sp$3$ph>>>0)<($2>>>0);
   if ($55) {
    $dp$416 = $dp$4$ph;$sp$317 = $sp$3$ph;
    while(1) {
     $56 = (($sp$317) + 1|0);
     $57 = HEAP8[$sp$317>>0]|0;
     $58 = (($dp$416) + 1|0);
     HEAP8[$dp$416>>0] = $57;
     $59 = (($sp$317) + 2|0);
     $60 = HEAP8[$56>>0]|0;
     $61 = (($dp$416) + 2|0);
     HEAP8[$58>>0] = $60;
     $62 = (($sp$317) + 3|0);
     $63 = HEAP8[$59>>0]|0;
     $64 = (($dp$416) + 3|0);
     HEAP8[$61>>0] = $63;
     $65 = (($sp$317) + 4|0);
     $66 = HEAP8[$62>>0]|0;
     $67 = (($dp$416) + 4|0);
     HEAP8[$64>>0] = $66;
     $68 = (($sp$317) + 5|0);
     $69 = HEAP8[$65>>0]|0;
     $70 = (($dp$416) + 5|0);
     HEAP8[$67>>0] = $69;
     $71 = HEAP8[$68>>0]|0;
     $72 = (($dp$416) + 6|0);
     HEAP8[$70>>0] = $71;
     $73 = (($sp$317) + 8|0);
     $74 = ($73>>>0)<($2>>>0);
     if ($74) {
      $dp$416 = $72;$sp$317 = $73;
     } else {
      $dp$4$lcssa = $72;
      break;
     }
    }
   } else {
    $dp$4$lcssa = $dp$4$ph;
   }
   $75 = (($row_info) + 11|0);
   HEAP8[$75>>0] = 48;
   $dp$5 = $dp$4$lcssa;
  } else {
   STACKTOP = sp;return;
  }
  HEAP8[$3>>0] = 3;
  $76 = (($row_info) + 8|0);
  $77 = HEAP8[$76>>0]|0;
  $78 = ($77<<24>>24)==(6);
  if ($78) {
   HEAP8[$76>>0] = 2;
   $dp$6 = $dp$5;
  } else {
   $dp$6 = $dp$5;
  }
 } else {
  STACKTOP = sp;return;
 }
 $79 = $dp$6;
 $80 = $row;
 $81 = (($79) - ($80))|0;
 HEAP32[$0>>2] = $81;
 STACKTOP = sp;return;
}
function _png_do_check_palette_indexes($png_ptr,$row_info) {
 $png_ptr = $png_ptr|0;
 $row_info = $row_info|0;
 var $$pre = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $or$cond = 0, $padding$01 = 0, $padding$15 = 0, $padding$210 = 0, $rp$02 = 0;
 var $rp$16 = 0, $rp$211 = 0, $rp$315 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 416|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = (($row_info) + 9|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = 1 << $5;
 $7 = ($2|0)>=($6|0);
 $8 = ($1<<16>>16)==(0);
 $or$cond = $7 | $8;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $9 = (($row_info) + 11|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = (0 - ($11))|0;
 $13 = HEAP32[$row_info>>2]|0;
 $14 = Math_imul($13, $12)|0;
 $15 = $14 & 7;
 $16 = (($png_ptr) + 380|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($row_info) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + ($19)|0);
 if ((($5|0) == 4)) {
  $23 = ($19|0)>(0);
  if (!($23)) {
   STACKTOP = sp;return;
  }
  $24 = (($png_ptr) + 420|0);
  $$pre20 = HEAP32[$24>>2]|0;
  $69 = $$pre20;$padding$210 = $15;$rp$211 = $20;
  while(1) {
   $64 = HEAP8[$rp$211>>0]|0;
   $65 = $64&255;
   $66 = $65 >>> $padding$210;
   $67 = $66 & 15;
   $68 = ($67|0)>($69|0);
   if ($68) {
    HEAP32[$24>>2] = $67;
    $$pre21 = HEAP8[$rp$211>>0]|0;
    $71 = $$pre21;$76 = $67;
   } else {
    $71 = $64;$76 = $69;
   }
   $70 = $71&255;
   $72 = $70 >>> $padding$210;
   $73 = $72 >>> 4;
   $74 = $73 & 15;
   $75 = ($74|0)>($76|0);
   if ($75) {
    HEAP32[$24>>2] = $74;
    $86 = $74;
   } else {
    $86 = $76;
   }
   $77 = (($rp$211) + -1|0);
   $78 = ($77>>>0)>($17>>>0);
   if ($78) {
    $69 = $86;$padding$210 = 0;$rp$211 = $77;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else if ((($5|0) == 8)) {
  $21 = ($19|0)>(0);
  if (!($21)) {
   STACKTOP = sp;return;
  }
  $22 = (($png_ptr) + 420|0);
  $$pre22 = HEAP32[$22>>2]|0;
  $82 = $$pre22;$rp$315 = $20;
  while(1) {
   $79 = HEAP8[$rp$315>>0]|0;
   $80 = $79&255;
   $81 = ($80|0)>($82|0);
   if ($81) {
    HEAP32[$22>>2] = $80;
    $87 = $80;
   } else {
    $87 = $82;
   }
   $83 = (($rp$315) + -1|0);
   $84 = ($83>>>0)>($17>>>0);
   if ($84) {
    $82 = $87;$rp$315 = $83;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else if ((($5|0) == 2)) {
  $25 = ($19|0)>(0);
  if (!($25)) {
   STACKTOP = sp;return;
  }
  $26 = (($png_ptr) + 420|0);
  $$pre = HEAP32[$26>>2]|0;
  $40 = $$pre;$padding$15 = $15;$rp$16 = $20;
  while(1) {
   $35 = HEAP8[$rp$16>>0]|0;
   $36 = $35&255;
   $37 = $36 >>> $padding$15;
   $38 = $37 & 3;
   $39 = ($38|0)>($40|0);
   if ($39) {
    HEAP32[$26>>2] = $38;
    $$pre17 = HEAP8[$rp$16>>0]|0;
    $42 = $$pre17;$47 = $38;
   } else {
    $42 = $35;$47 = $40;
   }
   $41 = $42&255;
   $43 = $41 >>> $padding$15;
   $44 = $43 >>> 2;
   $45 = $44 & 3;
   $46 = ($45|0)>($47|0);
   if ($46) {
    HEAP32[$26>>2] = $45;
    $$pre18 = HEAP8[$rp$16>>0]|0;
    $49 = $$pre18;$54 = $45;
   } else {
    $49 = $42;$54 = $47;
   }
   $48 = $49&255;
   $50 = $48 >>> $padding$15;
   $51 = $50 >>> 4;
   $52 = $51 & 3;
   $53 = ($52|0)>($54|0);
   if ($53) {
    HEAP32[$26>>2] = $52;
    $$pre19 = HEAP8[$rp$16>>0]|0;
    $56 = $$pre19;$61 = $52;
   } else {
    $56 = $49;$61 = $54;
   }
   $55 = $56&255;
   $57 = $55 >>> $padding$15;
   $58 = $57 >>> 6;
   $59 = $58 & 3;
   $60 = ($59|0)>($61|0);
   if ($60) {
    HEAP32[$26>>2] = $59;
    $85 = $59;
   } else {
    $85 = $61;
   }
   $62 = (($rp$16) + -1|0);
   $63 = ($62>>>0)>($17>>>0);
   if ($63) {
    $40 = $85;$padding$15 = 0;$rp$16 = $62;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else if ((($5|0) == 1)) {
  $27 = ($19|0)>(0);
  if (!($27)) {
   STACKTOP = sp;return;
  }
  $28 = (($png_ptr) + 420|0);
  $padding$01 = $15;$rp$02 = $20;
  while(1) {
   $29 = HEAP8[$rp$02>>0]|0;
   $30 = $29&255;
   $31 = $30 >>> $padding$01;
   $32 = ($31|0)==(0);
   if (!($32)) {
    HEAP32[$28>>2] = 1;
   }
   $33 = (($rp$02) + -1|0);
   $34 = ($33>>>0)>($17>>>0);
   if ($34) {
    $padding$01 = 0;$rp$02 = $33;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function _png_write_data($png_ptr,$data,$length) {
 $png_ptr = $png_ptr|0;
 $data = $data|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 176|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  _png_error($png_ptr,390648);
  // unreachable;
 } else {
  FUNCTION_TABLE_viii[$1 & 4095]($png_ptr,$data,$length);
  STACKTOP = sp;return;
 }
}
function _png_default_write_data($png_ptr,$data,$length) {
 $png_ptr = $png_ptr|0;
 $data = $data|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (_fwrite(($data|0),1,($length|0),($2|0))|0);
 $4 = ($3|0)==($length|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  _png_error($png_ptr,390680);
  // unreachable;
 }
}
function _png_flush($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 468|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 FUNCTION_TABLE_vi[$1 & 4095]($png_ptr);
 STACKTOP = sp;return;
}
function _png_default_flush($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 184|0);
 $2 = HEAP32[$1>>2]|0;
 (_fflush(($2|0))|0);
 STACKTOP = sp;return;
}
function _png_set_write_fn($png_ptr,$io_ptr,$write_data_fn,$output_flush_fn) {
 $png_ptr = $png_ptr|0;
 $io_ptr = $io_ptr|0;
 $write_data_fn = $write_data_fn|0;
 $output_flush_fn = $output_flush_fn|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $png_default_write_data$write_data_fn = 0, $storemerge1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 184|0);
 HEAP32[$1>>2] = $io_ptr;
 $2 = ($write_data_fn|0)==(0|0);
 $3 = (($png_ptr) + 176|0);
 $png_default_write_data$write_data_fn = $2 ? 1589 : $write_data_fn;
 HEAP32[$3>>2] = $png_default_write_data$write_data_fn;
 $4 = ($output_flush_fn|0)==(0|0);
 $5 = (($png_ptr) + 468|0);
 $storemerge1 = $4 ? 3367 : $output_flush_fn;
 HEAP32[$5>>2] = $storemerge1;
 $6 = (($png_ptr) + 180|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function _png_write_info_before_PLTE($png_ptr,$info_ptr) {
 $png_ptr = $png_ptr|0;
 $info_ptr = $info_ptr|0;
 var $$pr = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 $1 = ($info_ptr|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = (($png_ptr) + 204|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1024;
 $5 = ($4|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 _png_write_sig($png_ptr);
 $6 = HEAP32[$2>>2]|0;
 $7 = $6 & 4096;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = (($png_ptr) + 596|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0);
  if (!($11)) {
   HEAP32[$9>>2] = 0;
  }
 }
 $12 = HEAP32[$info_ptr>>2]|0;
 $13 = (($info_ptr) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($info_ptr) + 24|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = (($info_ptr) + 25|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = (($info_ptr) + 26|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22&255;
 $24 = (($info_ptr) + 27|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25&255;
 _png_write_IHDR($png_ptr,$12,$14,$17,$20,$23,$26,0);
 $27 = (($info_ptr) + 114|0);
 $28 = HEAP16[$27>>1]|0;
 $29 = $28 & -32760;
 $30 = ($29<<16>>16)==(8);
 if ($30) {
  $31 = (($info_ptr) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $32 & 1;
  $34 = ($33|0)==(0);
  if ($34) {
   $$pr = $28;
  } else {
   $35 = (($info_ptr) + 40|0);
   $36 = HEAP32[$35>>2]|0;
   _png_write_gAMA_fixed($png_ptr,$36);
   $$pre = HEAP16[$27>>1]|0;
   $$pr = $$pre;
  }
 } else {
  $$pr = $28;
 }
 $37 = ($$pr<<16>>16)<(0);
 $$pre5 = (($info_ptr) + 8|0);
 do {
  if (!($37)) {
   $38 = HEAP32[$$pre5>>2]|0;
   $39 = $38 & 4096;
   $40 = ($39|0)==(0);
   $41 = $38 & 2048;
   $42 = ($41|0)==(0);
   if ($40) {
    if ($42) {
     break;
    }
    $47 = (($info_ptr) + 112|0);
    $48 = HEAP16[$47>>1]|0;
    $49 = $48&65535;
    _png_write_sRGB($png_ptr,$49);
    break;
   }
   if (!($42)) {
    _png_app_warning($png_ptr,390696);
   }
   $43 = (($info_ptr) + 116|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($info_ptr) + 120|0);
   $46 = HEAP32[$45>>2]|0;
   _png_write_iCCP($png_ptr,$44,$46);
  }
 } while(0);
 $50 = HEAP32[$$pre5>>2]|0;
 $51 = $50 & 2;
 $52 = ($51|0)==(0);
 if (!($52)) {
  $53 = (($info_ptr) + 140|0);
  $54 = HEAP8[$18>>0]|0;
  $55 = $54&255;
  _png_write_sBIT($png_ptr,$53,$55);
 }
 $56 = HEAP16[$27>>1]|0;
 $57 = $56 & -32752;
 $58 = ($57<<16>>16)==(16);
 if ($58) {
  $59 = HEAP32[$$pre5>>2]|0;
  $60 = $59 & 4;
  $61 = ($60|0)==(0);
  if (!($61)) {
   $62 = (($info_ptr) + 44|0);
   _png_write_cHRM_fixed($png_ptr,$62);
  }
 }
 $63 = HEAP32[$2>>2]|0;
 $64 = $63 | 1024;
 HEAP32[$2>>2] = $64;
 STACKTOP = sp;return;
}
function _png_write_info($png_ptr,$info_ptr) {
 $png_ptr = $png_ptr|0;
 $info_ptr = $info_ptr|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre17 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$03 = 0, $i$11 = 0, $j$07 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 $1 = ($info_ptr|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 _png_write_info_before_PLTE($png_ptr,$info_ptr);
 $2 = (($info_ptr) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 8;
 $5 = ($4|0)==(0);
 if ($5) {
  $11 = (($info_ptr) + 25|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(3);
  if ($13) {
   _png_error($png_ptr,390744);
   // unreachable;
  } else {
   $15 = $3;
  }
 } else {
  $6 = (($info_ptr) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($info_ptr) + 20|0);
  $9 = HEAP16[$8>>1]|0;
  $10 = $9&65535;
  _png_write_PLTE($png_ptr,$7,$10);
  $$pre = HEAP32[$2>>2]|0;
  $15 = $$pre;
 }
 $14 = $15 & 16;
 $16 = ($14|0)==(0);
 if ($16) {
  $46 = $15;
 } else {
  $17 = (($png_ptr) + 212|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 524288;
  $20 = ($19|0)==(0);
  $$pre17 = (($info_ptr) + 25|0);
  if (!($20)) {
   $21 = HEAP8[$$pre17>>0]|0;
   $22 = ($21<<24>>24)==(3);
   if ($22) {
    $23 = (($info_ptr) + 22|0);
    $24 = HEAP16[$23>>1]|0;
    $25 = ($24<<16>>16)==(0);
    if (!($25)) {
     $26 = (($info_ptr) + 148|0);
     $j$07 = 0;
     while(1) {
      $27 = HEAP32[$26>>2]|0;
      $28 = (($27) + ($j$07)|0);
      $29 = HEAP8[$28>>0]|0;
      $30 = $29&255;
      $31 = $30 ^ 255;
      $32 = $31&255;
      HEAP8[$28>>0] = $32;
      $33 = (($j$07) + 1)|0;
      $34 = HEAP16[$23>>1]|0;
      $35 = $34&65535;
      $36 = ($33|0)<($35|0);
      if ($36) {
       $j$07 = $33;
      } else {
       break;
      }
     }
    }
   }
  }
  $37 = (($info_ptr) + 148|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($info_ptr) + 152|0);
  $40 = (($info_ptr) + 22|0);
  $41 = HEAP16[$40>>1]|0;
  $42 = $41&65535;
  $43 = HEAP8[$$pre17>>0]|0;
  $44 = $43&255;
  _png_write_tRNS($png_ptr,$38,$39,$42,$44);
  $$pre9 = HEAP32[$2>>2]|0;
  $46 = $$pre9;
 }
 $45 = $46 & 32;
 $47 = ($45|0)==(0);
 if ($47) {
  $53 = $46;
 } else {
  $48 = (($info_ptr) + 162|0);
  $49 = (($info_ptr) + 25|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = $50&255;
  _png_write_bKGD($png_ptr,$48,$51);
  $$pre10 = HEAP32[$2>>2]|0;
  $53 = $$pre10;
 }
 $52 = $53 & 256;
 $54 = ($52|0)==(0);
 if ($54) {
  $63 = $53;
 } else {
  $55 = (($info_ptr) + 172|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($info_ptr) + 176|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($info_ptr) + 180|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = $60&255;
  _png_write_oFFs($png_ptr,$56,$58,$61);
  $$pre11 = HEAP32[$2>>2]|0;
  $63 = $$pre11;
 }
 $62 = $63 & 1024;
 $64 = ($62|0)==(0);
 if ($64) {
  $82 = $63;
 } else {
  $65 = (($info_ptr) + 196|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($info_ptr) + 200|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($info_ptr) + 204|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($info_ptr) + 216|0);
  $72 = HEAP8[$71>>0]|0;
  $73 = $72&255;
  $74 = (($info_ptr) + 217|0);
  $75 = HEAP8[$74>>0]|0;
  $76 = $75&255;
  $77 = (($info_ptr) + 208|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($info_ptr) + 212|0);
  $80 = HEAP32[$79>>2]|0;
  _png_write_pCAL($png_ptr,$66,$68,$70,$73,$76,$78,$80);
  $$pre12 = HEAP32[$2>>2]|0;
  $82 = $$pre12;
 }
 $81 = $82 & 16384;
 $83 = ($81|0)==(0);
 if ($83) {
  $92 = $82;
 } else {
  $84 = (($info_ptr) + 232|0);
  $85 = HEAP8[$84>>0]|0;
  $86 = $85&255;
  $87 = (($info_ptr) + 236|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($info_ptr) + 240|0);
  $90 = HEAP32[$89>>2]|0;
  _png_write_sCAL_s($png_ptr,$86,$88,$90);
  $$pre13 = HEAP32[$2>>2]|0;
  $92 = $$pre13;
 }
 $91 = $92 & 128;
 $93 = ($91|0)==(0);
 if ($93) {
  $102 = $92;
 } else {
  $94 = (($info_ptr) + 184|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($info_ptr) + 188|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($info_ptr) + 192|0);
  $99 = HEAP8[$98>>0]|0;
  $100 = $99&255;
  _png_write_pHYs($png_ptr,$95,$97,$100);
  $$pre14 = HEAP32[$2>>2]|0;
  $102 = $$pre14;
 }
 $101 = $102 & 8192;
 $103 = ($101|0)==(0);
 if (!($103)) {
  $104 = (($info_ptr) + 228|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ($105|0)>(0);
  if ($106) {
   $107 = (($info_ptr) + 224|0);
   $i$03 = 0;
   while(1) {
    $112 = HEAP32[$107>>2]|0;
    $113 = (($112) + ($i$03<<4)|0);
    _png_write_sPLT($png_ptr,$113);
    $114 = (($i$03) + 1)|0;
    $115 = HEAP32[$104>>2]|0;
    $116 = ($114|0)<($115|0);
    if ($116) {
     $i$03 = $114;
    } else {
     break;
    }
   }
  }
 }
 $108 = (($info_ptr) + 128|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ($109|0)>(0);
 if (!($110)) {
  STACKTOP = sp;return;
 }
 $111 = (($info_ptr) + 136|0);
 $$pre15 = HEAP32[$111>>2]|0;
 $118 = $$pre15;$i$11 = 0;
 while(1) {
  $117 = (($118) + (($i$11*28)|0)|0);
  $119 = HEAP32[$117>>2]|0;
  $120 = ($119|0)>(0);
  do {
   if ($120) {
    $121 = ((($118) + (($i$11*28)|0)|0) + 4|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = ((($118) + (($i$11*28)|0)|0) + 20|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = ((($118) + (($i$11*28)|0)|0) + 24|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ((($118) + (($i$11*28)|0)|0) + 8|0);
    $128 = HEAP32[$127>>2]|0;
    _png_write_iTXt($png_ptr,$119,$122,$124,$126,$128);
    $129 = HEAP32[$111>>2]|0;
    $130 = (($129) + (($i$11*28)|0)|0);
    HEAP32[$130>>2] = -3;
    $146 = $129;
   } else {
    if ((($119|0) == -1)) {
     $137 = ((($118) + (($i$11*28)|0)|0) + 4|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = ((($118) + (($i$11*28)|0)|0) + 8|0);
     $140 = HEAP32[$139>>2]|0;
     _png_write_tEXt($png_ptr,$138,$140,0);
     $141 = HEAP32[$111>>2]|0;
     $142 = (($141) + (($i$11*28)|0)|0);
     HEAP32[$142>>2] = -3;
     $146 = $141;
     break;
    } else if ((($119|0) == 0)) {
     $131 = ((($118) + (($i$11*28)|0)|0) + 4|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ((($118) + (($i$11*28)|0)|0) + 8|0);
     $134 = HEAP32[$133>>2]|0;
     _png_write_zTXt($png_ptr,$132,$134,0,0);
     $135 = HEAP32[$111>>2]|0;
     $136 = (($135) + (($i$11*28)|0)|0);
     HEAP32[$136>>2] = -2;
     $146 = $135;
     break;
    } else {
     $146 = $118;
     break;
    }
   }
  } while(0);
  $143 = (($i$11) + 1)|0;
  $144 = HEAP32[$108>>2]|0;
  $145 = ($143|0)<($144|0);
  if ($145) {
   $118 = $146;$i$11 = $143;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _png_write_end($png_ptr,$info_ptr) {
 $png_ptr = $png_ptr|0;
 $info_ptr = $info_ptr|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 204|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 4;
 $4 = ($3|0)==(0);
 if ($4) {
  _png_error($png_ptr,390792);
  // unreachable;
 }
 $5 = (($png_ptr) + 420|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($png_ptr) + 416|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $10 = ($6|0)>($9|0);
 if ($10) {
  _png_benign_error($png_ptr,390824);
 }
 $11 = ($info_ptr|0)==(0|0);
 if (!($11)) {
  $12 = (($info_ptr) + 128|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)>(0);
  if ($14) {
   $15 = (($info_ptr) + 136|0);
   $$pre = HEAP32[$15>>2]|0;
   $17 = $$pre;$i$01 = 0;
   while(1) {
    $16 = (($17) + (($i$01*28)|0)|0);
    $18 = HEAP32[$16>>2]|0;
    $19 = ($18|0)>(0);
    do {
     if ($19) {
      $20 = ((($17) + (($i$01*28)|0)|0) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ((($17) + (($i$01*28)|0)|0) + 20|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ((($17) + (($i$01*28)|0)|0) + 24|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ((($17) + (($i$01*28)|0)|0) + 8|0);
      $27 = HEAP32[$26>>2]|0;
      _png_write_iTXt($png_ptr,$18,$21,$23,$25,$27);
      $28 = HEAP32[$15>>2]|0;
      $29 = (($28) + (($i$01*28)|0)|0);
      HEAP32[$29>>2] = -3;
      $49 = $28;
     } else {
      $30 = ($18|0)>(-1);
      if ($30) {
       $31 = ((($17) + (($i$01*28)|0)|0) + 4|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = ((($17) + (($i$01*28)|0)|0) + 8|0);
       $34 = HEAP32[$33>>2]|0;
       _png_write_zTXt($png_ptr,$32,$34,0,$18);
       $35 = HEAP32[$15>>2]|0;
       $36 = (($35) + (($i$01*28)|0)|0);
       HEAP32[$36>>2] = -2;
       $49 = $35;
       break;
      }
      $37 = ($18|0)==(-1);
      if ($37) {
       $38 = ((($17) + (($i$01*28)|0)|0) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = ((($17) + (($i$01*28)|0)|0) + 8|0);
       $41 = HEAP32[$40>>2]|0;
       _png_write_tEXt($png_ptr,$39,$41,0);
       $42 = HEAP32[$15>>2]|0;
       $43 = (($42) + (($i$01*28)|0)|0);
       HEAP32[$43>>2] = -3;
       $49 = $42;
      } else {
       $49 = $17;
      }
     }
    } while(0);
    $44 = (($i$01) + 1)|0;
    $45 = HEAP32[$12>>2]|0;
    $46 = ($44|0)<($45|0);
    if ($46) {
     $17 = $49;$i$01 = $44;
    } else {
     break;
    }
   }
  }
 }
 $47 = HEAP32[$1>>2]|0;
 $48 = $47 | 8;
 HEAP32[$1>>2] = $48;
 _png_write_IEND($png_ptr);
 STACKTOP = sp;return;
}
function _png_create_write_struct($user_png_ver,$error_ptr,$error_fn,$warn_fn) {
 $user_png_ver = $user_png_ver|0;
 $error_ptr = $error_ptr|0;
 $error_fn = $error_fn|0;
 $warn_fn = $warn_fn|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_png_create_png_struct($user_png_ver,$error_ptr,$error_fn,$warn_fn,0,0,0)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return ($0|0);
 }
 $2 = (($0) + 280|0);
 HEAP32[$2>>2] = 8192;
 $3 = (($0) + 300|0);
 HEAP32[$3>>2] = 1;
 $4 = (($0) + 284|0);
 HEAP32[$4>>2] = -1;
 $5 = (($0) + 296|0);
 HEAP32[$5>>2] = 8;
 $6 = (($0) + 292|0);
 HEAP32[$6>>2] = 15;
 $7 = (($0) + 288|0);
 HEAP32[$7>>2] = 8;
 $8 = (($0) + 320|0);
 HEAP32[$8>>2] = 0;
 $9 = (($0) + 304|0);
 HEAP32[$9>>2] = -1;
 $10 = (($0) + 316|0);
 HEAP32[$10>>2] = 8;
 $11 = (($0) + 312|0);
 HEAP32[$11>>2] = 15;
 $12 = (($0) + 308|0);
 HEAP32[$12>>2] = 8;
 $13 = (($0) + 208|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 | 2097152;
 HEAP32[$13>>2] = $15;
 _png_set_write_fn($0,0,0,0);
 STACKTOP = sp;return ($0|0);
}
function _png_write_row($png_ptr,$row) {
 $png_ptr = $png_ptr|0;
 $row = $row|0;
 var $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $bytes_per_pixel$0$i = 0, $exitcond$i = 0, $i$02$i = 0, $or$cond$i = 0, $row_info = 0, $row_info$idx$val = 0, $row_info$idx1$val = 0, $rp$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $row_info = sp;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 368|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = (($png_ptr) + 429|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $7 = (($png_ptr) + 204|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = $8 & 1024;
    $10 = ($9|0)==(0);
    if ($10) {
     _png_error($png_ptr,390872);
     // unreachable;
    } else {
     _png_write_start_row($png_ptr);
     break;
    }
   }
  }
 } while(0);
 $11 = (($png_ptr) + 431|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = (($row_info) + 8|0);
 HEAP8[$13>>0] = $12;
 $14 = (($png_ptr) + 356|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$row_info>>2] = $15;
 $16 = (($png_ptr) + 436|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = (($row_info) + 10|0);
 HEAP8[$18>>0] = $17;
 $19 = (($png_ptr) + 433|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = (($row_info) + 9|0);
 HEAP8[$21>>0] = $20;
 $22 = $20&255;
 $23 = $17&255;
 $24 = Math_imul($23, $22)|0;
 $25 = $24&255;
 $26 = (($row_info) + 11|0);
 HEAP8[$26>>0] = $25;
 $27 = $24 & 255;
 $28 = ($27>>>0)>(7);
 if ($28) {
  $29 = $27 >>> 3;
  $30 = Math_imul($29, $15)|0;
  $35 = $30;
 } else {
  $31 = Math_imul($27, $15)|0;
  $32 = (($31) + 7)|0;
  $33 = $32 >>> 3;
  $35 = $33;
 }
 $34 = (($row_info) + 4|0);
 HEAP32[$34>>2] = $35;
 $36 = (($png_ptr) + 380|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1|0);
 _memcpy(($38|0),($row|0),($35|0))|0;
 $39 = (($png_ptr) + 212|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0);
 if (!($41)) {
  _png_do_write_transformations($png_ptr,$row_info);
 }
 $42 = HEAP8[$26>>0]|0;
 $43 = (($png_ptr) + 434|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($42<<24>>24)==($44<<24>>24);
 if (!($45)) {
  _png_error($png_ptr,390928);
  // unreachable;
 }
 $46 = (($png_ptr) + 439|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = ($42<<24>>24)==($47<<24>>24);
 if (!($48)) {
  _png_error($png_ptr,390928);
  // unreachable;
 }
 $49 = (($png_ptr) + 596|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 4;
 $52 = ($51|0)==(0);
 do {
  if (!($52)) {
   $53 = (($png_ptr) + 600|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)==(64);
   if ($55) {
    $56 = HEAP32[$36>>2]|0;
    $57 = (($56) + 1|0);
    $row_info$idx$val = HEAP32[$row_info>>2]|0;
    $row_info$idx1$val = HEAP16[$13>>1]|0;
    $58 = $row_info$idx1$val&255;
    $59 = $58 & 2;
    $60 = ($59<<24>>24)!=(0);
    $$mask = $row_info$idx1$val & -256;
    $61 = ($$mask<<16>>16)==(2048);
    $or$cond$i = $60 & $61;
    if ($or$cond$i) {
     if ((($58<<24>>24) == 6)) {
      $bytes_per_pixel$0$i = 4;
     } else if ((($58<<24>>24) == 2)) {
      $bytes_per_pixel$0$i = 3;
     } else {
      break;
     }
     $62 = ($row_info$idx$val|0)==(0);
     if (!($62)) {
      $i$02$i = 0;$rp$01$i = $57;
      while(1) {
       $63 = HEAP8[$rp$01$i>>0]|0;
       $64 = $63&255;
       $65 = (($rp$01$i) + 1|0);
       $66 = HEAP8[$65>>0]|0;
       $67 = $66&255;
       $68 = (($64) - ($67))|0;
       $69 = $68&255;
       HEAP8[$rp$01$i>>0] = $69;
       $70 = (($rp$01$i) + 2|0);
       $71 = HEAP8[$70>>0]|0;
       $72 = $71&255;
       $73 = (($72) - ($67))|0;
       $74 = $73&255;
       HEAP8[$70>>0] = $74;
       $75 = (($i$02$i) + 1)|0;
       $76 = (($rp$01$i) + ($bytes_per_pixel$0$i)|0);
       $exitcond$i = ($75|0)==($row_info$idx$val|0);
       if ($exitcond$i) {
        break;
       } else {
        $i$02$i = $75;$rp$01$i = $76;
       }
      }
     }
    }
   }
  }
 } while(0);
 $77 = HEAP8[$13>>0]|0;
 $78 = ($77<<24>>24)==(3);
 if ($78) {
  $79 = (($png_ptr) + 420|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)>(-1);
  if ($81) {
   _png_do_check_palette_indexes($png_ptr,$row_info);
  }
 }
 _png_write_find_filter($png_ptr,$row_info);
 $82 = (($png_ptr) + 544|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($83|0)==(0|0);
 if ($84) {
  STACKTOP = sp;return;
 }
 $85 = HEAP32[$1>>2]|0;
 $86 = (($png_ptr) + 429|0);
 $87 = HEAP8[$86>>0]|0;
 $88 = $87&255;
 FUNCTION_TABLE_viii[$83 & 4095]($png_ptr,$85,$88);
 STACKTOP = sp;return;
}
function _png_write_flush($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 368|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($png_ptr) + 352|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 _png_compress_IDAT($png_ptr,0,0,2);
 $6 = (($png_ptr) + 476|0);
 HEAP32[$6>>2] = 0;
 _png_flush($png_ptr);
 STACKTOP = sp;return;
}
function _png_destroy_write_struct($png_ptr_ptr,$info_ptr_ptr) {
 $png_ptr_ptr = $png_ptr_ptr|0;
 $info_ptr_ptr = $info_ptr_ptr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$png_ptr_ptr>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 _png_destroy_info_struct($1,$info_ptr_ptr);
 HEAP32[$png_ptr_ptr>>2] = 0;
 $3 = (($1) + 208|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($1) + 220|0);
  (_deflateEnd($7)|0);
 }
 $8 = (($1) + 276|0);
 _png_free_buffer_list($1,$8);
 $9 = (($1) + 380|0);
 $10 = HEAP32[$9>>2]|0;
 _png_free($1,$10);
 $11 = (($1) + 376|0);
 $12 = HEAP32[$11>>2]|0;
 _png_free($1,$12);
 $13 = (($1) + 384|0);
 $14 = HEAP32[$13>>2]|0;
 _png_free($1,$14);
 $15 = (($1) + 388|0);
 $16 = HEAP32[$15>>2]|0;
 _png_free($1,$16);
 $17 = (($1) + 392|0);
 $18 = HEAP32[$17>>2]|0;
 _png_free($1,$18);
 $19 = (($1) + 396|0);
 $20 = HEAP32[$19>>2]|0;
 _png_free($1,$20);
 $21 = (($1) + 592|0);
 $22 = HEAP32[$21>>2]|0;
 _png_free($1,$22);
 _png_destroy_png_struct($1);
 STACKTOP = sp;return;
}
function _png_set_compression_level($png_ptr,$level) {
 $png_ptr = $png_ptr|0;
 $level = $level|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if (!($0)) {
  $1 = (($png_ptr) + 284|0);
  HEAP32[$1>>2] = $level;
 }
 STACKTOP = sp;return;
}
function _png_do_write_transformations($png_ptr,$row_info) {
 $png_ptr = $png_ptr|0;
 $row_info = $row_info|0;
 var $$lobit = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $dp2$05$i = 0, $dp2$06$i = 0, $exitcond$i = 0, $exitcond$i2 = 0, $exitcond8$i = 0;
 var $exitcond9$i = 0, $i$01$i = 0, $i$01$i1 = 0, $i3$06$i = 0, $i3$07$i = 0, $sp$02$i = 0, $sp$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 1048576;
 $4 = ($3|0)==(0);
 if ($4) {
  $12 = $2;
 } else {
  $5 = (($png_ptr) + 192|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $12 = $2;
  } else {
   $8 = (($png_ptr) + 380|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 1|0);
   FUNCTION_TABLE_viii[$6 & 4095]($png_ptr,$row_info,$10);
   $$pre = HEAP32[$1>>2]|0;
   $12 = $$pre;
  }
 }
 $11 = $12 & 32768;
 $13 = ($11|0)==(0);
 if ($13) {
  $22 = $12;
 } else {
  $14 = (($png_ptr) + 380|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 1|0);
  $17 = (($png_ptr) + 208|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 >>> 7;
  $$lobit = $19 & 1;
  $20 = $$lobit ^ 1;
  _png_do_strip_channel($row_info,$16,$20);
  $$pre6 = HEAP32[$1>>2]|0;
  $22 = $$pre6;
 }
 $21 = $22 & 16;
 $23 = ($21|0)==(0);
 if ($23) {
  $28 = $22;
 } else {
  $24 = (($png_ptr) + 380|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 1|0);
  _png_do_swap($row_info,$26);
  $$pre7 = HEAP32[$1>>2]|0;
  $28 = $$pre7;
 }
 $27 = $28 & 131072;
 $29 = ($27|0)==(0);
 do {
  if (!($29)) {
   $30 = (($png_ptr) + 380|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 1|0);
   $33 = (($row_info) + 8|0);
   $34 = HEAP8[$33>>0]|0;
   if ((($34<<24>>24) == 6)) {
    $35 = (($row_info) + 9|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = ($36<<24>>24)==(8);
    if (!($37)) {
     break;
    }
    $38 = HEAP32[$row_info>>2]|0;
    $39 = ($38|0)==(0);
    if ($39) {
     break;
    } else {
     $i$01$i = 0;$sp$03$i = $32;
    }
    while(1) {
     $40 = (($sp$03$i) + 1|0);
     $41 = HEAP8[$sp$03$i>>0]|0;
     $42 = (($sp$03$i) + 2|0);
     $43 = HEAP8[$40>>0]|0;
     HEAP8[$sp$03$i>>0] = $43;
     $44 = (($sp$03$i) + 3|0);
     $45 = HEAP8[$42>>0]|0;
     HEAP8[$40>>0] = $45;
     $46 = (($sp$03$i) + 4|0);
     $47 = HEAP8[$44>>0]|0;
     HEAP8[$42>>0] = $47;
     HEAP8[$44>>0] = $41;
     $48 = (($i$01$i) + 1)|0;
     $exitcond$i = ($48|0)==($38|0);
     if ($exitcond$i) {
      break;
     } else {
      $i$01$i = $48;$sp$03$i = $46;
     }
    }
   } else if ((($34<<24>>24) == 4)) {
    $49 = (($row_info) + 9|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = ($50<<24>>24)==(8);
    if (!($51)) {
     break;
    }
    $52 = HEAP32[$row_info>>2]|0;
    $53 = ($52|0)==(0);
    if ($53) {
     break;
    } else {
     $dp2$06$i = $32;$i3$07$i = 0;
    }
    while(1) {
     $54 = (($dp2$06$i) + 1|0);
     $55 = HEAP8[$dp2$06$i>>0]|0;
     $56 = (($dp2$06$i) + 2|0);
     $57 = HEAP8[$54>>0]|0;
     HEAP8[$dp2$06$i>>0] = $57;
     HEAP8[$54>>0] = $55;
     $58 = (($i3$07$i) + 1)|0;
     $exitcond9$i = ($58|0)==($52|0);
     if ($exitcond9$i) {
      break;
     } else {
      $dp2$06$i = $56;$i3$07$i = $58;
     }
    }
   } else {
    break;
   }
  }
 } while(0);
 $59 = HEAP32[$1>>2]|0;
 $60 = $59 & 524288;
 $61 = ($60|0)==(0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $62 = (($png_ptr) + 380|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 1|0);
 $65 = (($row_info) + 8|0);
 $66 = HEAP8[$65>>0]|0;
 if ((($66<<24>>24) == 4)) {
  $79 = (($row_info) + 9|0);
  $80 = HEAP8[$79>>0]|0;
  $81 = ($80<<24>>24)==(8);
  if (!($81)) {
   STACKTOP = sp;return;
  }
  $82 = HEAP32[$row_info>>2]|0;
  $83 = ($82|0)==(0);
  if ($83) {
   STACKTOP = sp;return;
  } else {
   $dp2$05$i = $64;$i3$06$i = 0;
  }
  while(1) {
   $84 = (($dp2$05$i) + 1|0);
   $85 = (($dp2$05$i) + 2|0);
   $86 = HEAP8[$84>>0]|0;
   $87 = $86&255;
   $88 = $87 ^ 255;
   $89 = $88&255;
   HEAP8[$84>>0] = $89;
   $90 = (($i3$06$i) + 1)|0;
   $exitcond8$i = ($90|0)==($82|0);
   if ($exitcond8$i) {
    break;
   } else {
    $dp2$05$i = $85;$i3$06$i = $90;
   }
  }
  STACKTOP = sp;return;
 } else if ((($66<<24>>24) == 6)) {
  $67 = (($row_info) + 9|0);
  $68 = HEAP8[$67>>0]|0;
  $69 = ($68<<24>>24)==(8);
  if (!($69)) {
   STACKTOP = sp;return;
  }
  $70 = HEAP32[$row_info>>2]|0;
  $71 = ($70|0)==(0);
  if ($71) {
   STACKTOP = sp;return;
  } else {
   $i$01$i1 = 0;$sp$02$i = $64;
  }
  while(1) {
   $72 = (($sp$02$i) + 3|0);
   $73 = (($sp$02$i) + 4|0);
   $74 = HEAP8[$72>>0]|0;
   $75 = $74&255;
   $76 = $75 ^ 255;
   $77 = $76&255;
   HEAP8[$72>>0] = $77;
   $78 = (($i$01$i1) + 1)|0;
   $exitcond$i2 = ($78|0)==($70|0);
   if ($exitcond$i2) {
    break;
   } else {
    $i$01$i1 = $78;$sp$02$i = $73;
   }
  }
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function _png_write_sig($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $png_signature = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $png_signature = sp;
 $0 = $png_signature;
 $1 = $0;
 HEAP32[$1>>2] = 1196314761;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 169478669;
 $4 = (($png_ptr) + 656|0);
 HEAP32[$4>>2] = 18;
 $5 = (($png_ptr) + 437|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = (($png_signature) + ($7)|0);
 $9 = (8 - ($7))|0;
 _png_write_data($png_ptr,$8,$9);
 $10 = HEAP8[$5>>0]|0;
 $11 = ($10&255)<(3);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($png_ptr) + 204|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 | 4096;
 HEAP32[$12>>2] = $14;
 STACKTOP = sp;return;
}
function _png_free_buffer_list($png_ptr,$listp) {
 $png_ptr = $png_ptr|0;
 $listp = $listp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $list$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$listp>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 HEAP32[$listp>>2] = 0;
 $list$0 = $0;
 while(1) {
  $2 = HEAP32[$list$0>>2]|0;
  _png_free($png_ptr,$list$0);
  $3 = ($2|0)==(0|0);
  if ($3) {
   break;
  } else {
   $list$0 = $2;
  }
 }
 STACKTOP = sp;return;
}
function _png_write_IHDR($png_ptr,$width,$height,$bit_depth,$color_type,$compression_type,$filter_type,$interlace_type) {
 $png_ptr = $png_ptr|0;
 $width = $width|0;
 $height = $height|0;
 $bit_depth = $bit_depth|0;
 $color_type = $color_type|0;
 $compression_type = $compression_type|0;
 $filter_type = $filter_type|0;
 $interlace_type = $interlace_type|0;
 var $$0 = 0, $$old4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $buf = 0, $buf$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $buf$i7 = sp + 16|0;
 $buf = sp;
 L1: do {
  switch ($color_type|0) {
  case 0:  {
   if ((($bit_depth|0) == 8) | (($bit_depth|0) == 4) | (($bit_depth|0) == 2) | (($bit_depth|0) == 1)) {
    $0 = (($png_ptr) + 435|0);
    HEAP8[$0>>0] = 1;
    $28 = 1;
    break L1;
   } else {
    _png_error($png_ptr,390968);
    // unreachable;
   }
   break;
  }
  case 2:  {
   $1 = ($bit_depth|0)==(8);
   if ($1) {
    $2 = (($png_ptr) + 435|0);
    HEAP8[$2>>0] = 3;
    $28 = 3;
    break L1;
   } else {
    _png_error($png_ptr,391008);
    // unreachable;
   }
   break;
  }
  case 6:  {
   $5 = ($bit_depth|0)==(8);
   if ($5) {
    $6 = (($png_ptr) + 435|0);
    HEAP8[$6>>0] = 4;
    $28 = 4;
    break L1;
   } else {
    _png_error($png_ptr,391128);
    // unreachable;
   }
   break;
  }
  case 4:  {
   if ((($bit_depth|0) == 8) | (($bit_depth|0) == 16)) {
    $4 = (($png_ptr) + 435|0);
    HEAP8[$4>>0] = 2;
    $28 = 2;
    break L1;
   } else {
    _png_error($png_ptr,391080);
    // unreachable;
   }
   break;
  }
  case 3:  {
   if ((($bit_depth|0) == 8) | (($bit_depth|0) == 4) | (($bit_depth|0) == 2) | (($bit_depth|0) == 1)) {
    $3 = (($png_ptr) + 435|0);
    HEAP8[$3>>0] = 1;
    $28 = 1;
    break L1;
   } else {
    _png_error($png_ptr,391040);
    // unreachable;
   }
   break;
  }
  default: {
   _png_error($png_ptr,391168);
   // unreachable;
  }
  }
 } while(0);
 $7 = (($png_ptr) + 596|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 4;
 $10 = ($9|0)==(0);
 if ($10) {
  label = 22;
 } else {
  $11 = (($png_ptr) + 204|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 & 4096;
  $14 = ($13|0)==(0);
  if ($14) {
   $15 = $color_type & -5;
   $16 = ($15|0)==(2);
   if ($16) {
    if ((($filter_type|0) == 0) | (($filter_type|0) == 64)) {
     $$0 = $filter_type;
    } else {
     label = 23;
    }
   } else {
    label = 22;
   }
  } else {
   label = 22;
  }
 }
 if ((label|0) == 22) {
  $$old4 = ($filter_type|0)==(0);
  if ($$old4) {
   $$0 = 0;
  } else {
   label = 23;
  }
 }
 if ((label|0) == 23) {
  $$0 = 0;
 }
 $17 = $bit_depth&255;
 $18 = (($png_ptr) + 432|0);
 HEAP8[$18>>0] = $17;
 $19 = $color_type&255;
 $20 = (($png_ptr) + 431|0);
 HEAP8[$20>>0] = $19;
 $21 = (($png_ptr) + 428|0);
 HEAP8[$21>>0] = 0;
 $22 = $$0&255;
 $23 = (($png_ptr) + 600|0);
 HEAP8[$23>>0] = $22;
 $24 = (($png_ptr) + 620|0);
 HEAP8[$24>>0] = 0;
 $25 = (($png_ptr) + 344|0);
 HEAP32[$25>>2] = $width;
 $26 = (($png_ptr) + 348|0);
 HEAP32[$26>>2] = $height;
 $27 = $28&255;
 $29 = Math_imul($27, $bit_depth)|0;
 $30 = $29&255;
 $31 = (($png_ptr) + 434|0);
 HEAP8[$31>>0] = $30;
 $32 = $29 & 255;
 $33 = ($32>>>0)>(7);
 if ($33) {
  $34 = $32 >>> 3;
  $35 = Math_imul($34, $width)|0;
  $40 = $35;
 } else {
  $36 = Math_imul($32, $width)|0;
  $37 = (($36) + 7)|0;
  $38 = $37 >>> 3;
  $40 = $38;
 }
 $39 = (($png_ptr) + 360|0);
 HEAP32[$39>>2] = $40;
 $41 = (($png_ptr) + 356|0);
 HEAP32[$41>>2] = $width;
 $42 = (($png_ptr) + 433|0);
 HEAP8[$42>>0] = $17;
 $43 = (($png_ptr) + 436|0);
 HEAP8[$43>>0] = $28;
 $44 = $width >>> 24;
 $45 = $44&255;
 HEAP8[$buf>>0] = $45;
 $46 = $width >>> 16;
 $47 = $46&255;
 $48 = (($buf) + 1|0);
 HEAP8[$48>>0] = $47;
 $49 = $width >>> 8;
 $50 = $49&255;
 $51 = (($buf) + 2|0);
 HEAP8[$51>>0] = $50;
 $52 = $width&255;
 $53 = (($buf) + 3|0);
 HEAP8[$53>>0] = $52;
 $54 = (($buf) + 4|0);
 $55 = $height >>> 24;
 $56 = $55&255;
 HEAP8[$54>>0] = $56;
 $57 = $height >>> 16;
 $58 = $57&255;
 $59 = (($buf) + 5|0);
 HEAP8[$59>>0] = $58;
 $60 = $height >>> 8;
 $61 = $60&255;
 $62 = (($buf) + 6|0);
 HEAP8[$62>>0] = $61;
 $63 = $height&255;
 $64 = (($buf) + 7|0);
 HEAP8[$64>>0] = $63;
 $65 = (($buf) + 8|0);
 HEAP8[$65>>0] = $17;
 $66 = (($buf) + 9|0);
 HEAP8[$66>>0] = $19;
 $67 = (($buf) + 10|0);
 HEAP8[$67>>0] = 0;
 $68 = (($buf) + 11|0);
 HEAP8[$68>>0] = $22;
 $69 = (($buf) + 12|0);
 HEAP8[$69>>0] = 0;
 $70 = ($png_ptr|0)==(0|0);
 if (!($70)) {
  $71 = (($png_ptr) + 656|0);
  HEAP32[$71>>2] = 34;
  HEAP8[$buf$i7>>0] = 0;
  $72 = (($buf$i7) + 1|0);
  HEAP8[$72>>0] = 0;
  $73 = (($buf$i7) + 2|0);
  HEAP8[$73>>0] = 0;
  $74 = (($buf$i7) + 3|0);
  HEAP8[$74>>0] = 13;
  $75 = (($buf$i7) + 4|0);
  HEAP8[$75>>0] = 73;
  $76 = (($buf$i7) + 5|0);
  HEAP8[$76>>0] = 72;
  $77 = (($buf$i7) + 6|0);
  HEAP8[$77>>0] = 68;
  $78 = (($buf$i7) + 7|0);
  HEAP8[$78>>0] = 82;
  _png_write_data($png_ptr,$buf$i7,8);
  $79 = (($png_ptr) + 372|0);
  HEAP32[$79>>2] = 1229472850;
  _png_reset_crc($png_ptr);
  _png_calculate_crc($png_ptr,$75,4);
  HEAP32[$71>>2] = 66;
  _png_write_data($png_ptr,$buf,13);
  _png_calculate_crc($png_ptr,$buf,13);
  HEAP32[$71>>2] = 130;
  $80 = (($png_ptr) + 408|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = $81 >>> 24;
  $83 = $82&255;
  HEAP8[$buf$i7>>0] = $83;
  $84 = $81 >>> 16;
  $85 = $84&255;
  $86 = (($buf$i7) + 1|0);
  HEAP8[$86>>0] = $85;
  $87 = $81 >>> 8;
  $88 = $87&255;
  $89 = (($buf$i7) + 2|0);
  HEAP8[$89>>0] = $88;
  $90 = $81&255;
  $91 = (($buf$i7) + 3|0);
  HEAP8[$91>>0] = $90;
  _png_write_data($png_ptr,$buf$i7,4);
 }
 $92 = (($png_ptr) + 430|0);
 $93 = HEAP8[$92>>0]|0;
 $94 = ($93<<24>>24)==(0);
 if (!($94)) {
  $99 = (($png_ptr) + 204|0);
  HEAP32[$99>>2] = 1;
  STACKTOP = sp;return;
 }
 $95 = HEAP8[$20>>0]|0;
 $96 = ($95<<24>>24)==(3);
 if (!($96)) {
  $97 = HEAP8[$18>>0]|0;
  $98 = ($97&255)<(8);
  if (!($98)) {
   HEAP8[$92>>0] = -8;
   $99 = (($png_ptr) + 204|0);
   HEAP32[$99>>2] = 1;
   STACKTOP = sp;return;
  }
 }
 HEAP8[$92>>0] = 8;
 $99 = (($png_ptr) + 204|0);
 HEAP32[$99>>2] = 1;
 STACKTOP = sp;return;
}
function _png_write_PLTE($png_ptr,$palette,$num_pal) {
 $png_ptr = $png_ptr|0;
 $palette = $palette|0;
 $num_pal = $num_pal|0;
 var $$old1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $buf$i = 0, $buf$i2 = 0, $exitcond = 0, $exitcond5 = 0, $i$03 = 0, $i$03$us = 0, $or$cond = 0, $pal_ptr$04 = 0, $pal_ptr$04$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf$i2 = sp + 12|0;
 $buf$i = sp;
 $buf = sp + 8|0;
 $0 = (($png_ptr) + 596|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = ($num_pal|0)==(0);
  $5 = ($num_pal>>>0)>(256);
  $or$cond = $4 | $5;
  if ($or$cond) {
   label = 4;
  }
 } else {
  $$old1 = ($num_pal>>>0)>(256);
  if ($$old1) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $6 = (($png_ptr) + 431|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(3);
  if ($8) {
   _png_error($png_ptr,391208);
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $9 = (($png_ptr) + 431|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10 & 2;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = $num_pal&65535;
 $14 = (($png_ptr) + 416|0);
 HEAP16[$14>>1] = $13;
 $15 = ($num_pal*3)|0;
 $16 = ($png_ptr|0)==(0|0);
 if (!($16)) {
  $17 = (($png_ptr) + 656|0);
  HEAP32[$17>>2] = 34;
  $18 = $15 >>> 24;
  $19 = $18&255;
  HEAP8[$buf$i>>0] = $19;
  $20 = $15 >>> 16;
  $21 = $20&255;
  $22 = (($buf$i) + 1|0);
  HEAP8[$22>>0] = $21;
  $23 = $15 >>> 8;
  $24 = $23&255;
  $25 = (($buf$i) + 2|0);
  HEAP8[$25>>0] = $24;
  $26 = $15&255;
  $27 = (($buf$i) + 3|0);
  HEAP8[$27>>0] = $26;
  $28 = (($buf$i) + 4|0);
  HEAP8[$28>>0] = 80;
  $29 = (($buf$i) + 5|0);
  HEAP8[$29>>0] = 76;
  $30 = (($buf$i) + 6|0);
  HEAP8[$30>>0] = 84;
  $31 = (($buf$i) + 7|0);
  HEAP8[$31>>0] = 69;
  _png_write_data($png_ptr,$buf$i,8);
  $32 = (($png_ptr) + 372|0);
  HEAP32[$32>>2] = 1347179589;
  _png_reset_crc($png_ptr);
  _png_calculate_crc($png_ptr,$28,4);
  HEAP32[$17>>2] = 66;
 }
 $33 = ($num_pal|0)==(0);
 if (!($33)) {
  $34 = (($buf) + 1|0);
  $35 = (($buf) + 2|0);
  if ($16) {
   $i$03$us = 0;$pal_ptr$04$us = $palette;
   while(1) {
    $36 = HEAP8[$pal_ptr$04$us>>0]|0;
    HEAP8[$buf>>0] = $36;
    $37 = (($pal_ptr$04$us) + 1|0);
    $38 = HEAP8[$37>>0]|0;
    HEAP8[$34>>0] = $38;
    $39 = (($pal_ptr$04$us) + 2|0);
    $40 = HEAP8[$39>>0]|0;
    HEAP8[$35>>0] = $40;
    $41 = (($i$03$us) + 1)|0;
    $42 = (($pal_ptr$04$us) + 3|0);
    $exitcond5 = ($41|0)==($num_pal|0);
    if ($exitcond5) {
     break;
    } else {
     $i$03$us = $41;$pal_ptr$04$us = $42;
    }
   }
  } else {
   $i$03 = 0;$pal_ptr$04 = $palette;
   while(1) {
    $43 = HEAP8[$pal_ptr$04>>0]|0;
    HEAP8[$buf>>0] = $43;
    $44 = (($pal_ptr$04) + 1|0);
    $45 = HEAP8[$44>>0]|0;
    HEAP8[$34>>0] = $45;
    $46 = (($pal_ptr$04) + 2|0);
    $47 = HEAP8[$46>>0]|0;
    HEAP8[$35>>0] = $47;
    _png_write_data($png_ptr,$buf,3);
    _png_calculate_crc($png_ptr,$buf,3);
    $48 = (($i$03) + 1)|0;
    $49 = (($pal_ptr$04) + 3|0);
    $exitcond = ($48|0)==($num_pal|0);
    if ($exitcond) {
     break;
    } else {
     $i$03 = $48;$pal_ptr$04 = $49;
    }
   }
  }
 }
 if (!($16)) {
  $50 = (($png_ptr) + 656|0);
  HEAP32[$50>>2] = 130;
  $51 = (($png_ptr) + 408|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 >>> 24;
  $54 = $53&255;
  HEAP8[$buf$i2>>0] = $54;
  $55 = $52 >>> 16;
  $56 = $55&255;
  $57 = (($buf$i2) + 1|0);
  HEAP8[$57>>0] = $56;
  $58 = $52 >>> 8;
  $59 = $58&255;
  $60 = (($buf$i2) + 2|0);
  HEAP8[$60>>0] = $59;
  $61 = $52&255;
  $62 = (($buf$i2) + 3|0);
  HEAP8[$62>>0] = $61;
  _png_write_data($png_ptr,$buf$i2,4);
 }
 $63 = (($png_ptr) + 204|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 | 2;
 HEAP32[$63>>2] = $65;
 STACKTOP = sp;return;
}
function _png_compress_IDAT($png_ptr,$input,$input_len,$flush) {
 $png_ptr = $png_ptr|0;
 $input = $input|0;
 $input_len = $input_len|0;
 $flush = $flush|0;
 var $$0 = 0, $$pre = 0, $$pre$phi30Z2D = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre$phiZ2D = 0, $$pre29 = 0, $$pre31 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf$i = 0, $buf$i13 = 0, $half_z_window_size$0$i = 0, $half_z_window_size$0$i5 = 0, $list$0$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i3 = 0, $or$cond2$i = 0, $or$cond2$i6 = 0, $z_cinfo$0$i = 0, $z_cinfo$0$i4 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf$i13 = sp + 8|0;
 $buf$i = sp;
 $0 = (($png_ptr) + 216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1229209940);
 do {
  if ($2) {
   $$pre = (($png_ptr) + 236|0);
   $$pre29 = (($png_ptr) + 276|0);
   $$pre31 = (($png_ptr) + 280|0);
   $$pre33 = (($png_ptr) + 232|0);
   $$pre$phi30Z2D = $$pre29;$$pre$phi32Z2D = $$pre31;$$pre$phi34Z2D = $$pre33;$$pre$phiZ2D = $$pre;
  } else {
   $3 = (($png_ptr) + 276|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    $6 = (($png_ptr) + 280|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + 4)|0;
    $9 = (_png_malloc($png_ptr,$8)|0);
    HEAP32[$3>>2] = $9;
    HEAP32[$9>>2] = 0;
   } else {
    $10 = HEAP32[$4>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     HEAP32[$4>>2] = 0;
     $list$0$i = $10;
     while(1) {
      $12 = HEAP32[$list$0$i>>2]|0;
      _png_free($png_ptr,$list$0$i);
      $13 = ($12|0)==(0|0);
      if ($13) {
       break;
      } else {
       $list$0$i = $12;
      }
     }
    }
   }
   $14 = (_png_image_size($png_ptr)|0);
   $15 = (_png_deflate_claim($png_ptr,1229209940,$14)|0);
   $16 = ($15|0)==(0);
   if ($16) {
    $19 = HEAP32[$3>>2]|0;
    $20 = (($19) + 4|0);
    $21 = (($png_ptr) + 232|0);
    HEAP32[$21>>2] = $20;
    $22 = (($png_ptr) + 280|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($png_ptr) + 236|0);
    HEAP32[$24>>2] = $23;
    $$pre$phi30Z2D = $3;$$pre$phi32Z2D = $22;$$pre$phi34Z2D = $21;$$pre$phiZ2D = $24;
    break;
   } else {
    $17 = (($png_ptr) + 244|0);
    $18 = HEAP32[$17>>2]|0;
    _png_error($png_ptr,$18);
    // unreachable;
   }
  }
 } while(0);
 $25 = (($png_ptr) + 220|0);
 HEAP32[$25>>2] = $input;
 $26 = (($png_ptr) + 224|0);
 HEAP32[$26>>2] = 0;
 $27 = (($png_ptr) + 204|0);
 $28 = (($png_ptr) + 620|0);
 $29 = ($png_ptr|0)==(0|0);
 $30 = ($flush|0)==(0);
 $31 = (($png_ptr) + 656|0);
 $32 = (($buf$i13) + 1|0);
 $33 = (($buf$i13) + 2|0);
 $34 = (($buf$i13) + 3|0);
 $35 = (($buf$i13) + 4|0);
 $36 = (($buf$i13) + 5|0);
 $37 = (($buf$i13) + 6|0);
 $38 = (($buf$i13) + 7|0);
 $39 = (($png_ptr) + 372|0);
 $40 = (($png_ptr) + 408|0);
 $41 = (($buf$i) + 1|0);
 $42 = (($buf$i) + 2|0);
 $43 = (($buf$i) + 3|0);
 $$0 = $input_len;
 while(1) {
  HEAP32[$26>>2] = $$0;
  $44 = (_deflate($25,$flush)|0);
  $45 = HEAP32[$26>>2]|0;
  HEAP32[$26>>2] = 0;
  $46 = HEAP32[$$pre$phiZ2D>>2]|0;
  $47 = ($46|0)==(0);
  if ($47) {
   $48 = HEAP32[$$pre$phi30Z2D>>2]|0;
   $49 = (($48) + 4|0);
   $50 = HEAP32[$$pre$phi32Z2D>>2]|0;
   $51 = HEAP32[$27>>2]|0;
   $52 = $51 & 4;
   $53 = ($52|0)==(0);
   if ($53) {
    $54 = HEAP8[$28>>0]|0;
    $55 = ($54<<24>>24)==(0);
    if ($55) {
     $56 = (_png_image_size($png_ptr)|0);
     $57 = ($56>>>0)<(16385);
     if ($57) {
      $58 = HEAP8[$49>>0]|0;
      $59 = $58&255;
      $60 = $59 & 15;
      $61 = ($60|0)==(8);
      $62 = $59 & 240;
      $63 = ($62>>>0)<(113);
      $or$cond$i = $61 & $63;
      if ($or$cond$i) {
       $64 = $59 >>> 4;
       $65 = (($64) + 7)|0;
       $66 = 1 << $65;
       $67 = ($66>>>0)<($56>>>0);
       if (!($67)) {
        $half_z_window_size$0$i = $66;$z_cinfo$0$i = $64;
        while(1) {
         $68 = $half_z_window_size$0$i >>> 1;
         $69 = (($z_cinfo$0$i) + -1)|0;
         $70 = ($69|0)==(0);
         $71 = ($68>>>0)<($56>>>0);
         $or$cond2$i = $70 | $71;
         if ($or$cond2$i) {
          break;
         } else {
          $half_z_window_size$0$i = $68;$z_cinfo$0$i = $69;
         }
        }
        $72 = $69 << 4;
        $73 = $72 | 8;
        $74 = $73&255;
        HEAP8[$49>>0] = $74;
        $75 = (($48) + 5|0);
        $76 = HEAP8[$75>>0]|0;
        $77 = $76&255;
        $78 = $77 & 224;
        $79 = $73 << 8;
        $80 = $78 | $79;
        $81 = (($80>>>0) % 31)&-1;
        $82 = $78 | $81;
        $83 = $82 ^ 31;
        $84 = $83&255;
        HEAP8[$75>>0] = $84;
       }
      }
     }
    }
   }
   if (!($29)) {
    $85 = ($50|0)<(0);
    if ($85) {
     label = 22;
     break;
    }
    HEAP32[$31>>2] = 34;
    $86 = $50 >>> 24;
    $87 = $86&255;
    HEAP8[$buf$i13>>0] = $87;
    $88 = $50 >>> 16;
    $89 = $88&255;
    HEAP8[$32>>0] = $89;
    $90 = $50 >>> 8;
    $91 = $90&255;
    HEAP8[$33>>0] = $91;
    $92 = $50&255;
    HEAP8[$34>>0] = $92;
    HEAP8[$35>>0] = 73;
    HEAP8[$36>>0] = 68;
    HEAP8[$37>>0] = 65;
    HEAP8[$38>>0] = 84;
    _png_write_data($png_ptr,$buf$i13,8);
    HEAP32[$39>>2] = 1229209940;
    _png_reset_crc($png_ptr);
    _png_calculate_crc($png_ptr,$35,4);
    HEAP32[$31>>2] = 66;
    $93 = ($50|0)==(0);
    if (!($93)) {
     _png_write_data($png_ptr,$49,$50);
     _png_calculate_crc($png_ptr,$49,$50);
    }
    HEAP32[$31>>2] = 130;
    $94 = HEAP32[$40>>2]|0;
    $95 = $94 >>> 24;
    $96 = $95&255;
    HEAP8[$buf$i>>0] = $96;
    $97 = $94 >>> 16;
    $98 = $97&255;
    HEAP8[$41>>0] = $98;
    $99 = $94 >>> 8;
    $100 = $99&255;
    HEAP8[$42>>0] = $100;
    $101 = $94&255;
    HEAP8[$43>>0] = $101;
    _png_write_data($png_ptr,$buf$i,4);
   }
   $102 = HEAP32[$27>>2]|0;
   $103 = $102 | 4;
   HEAP32[$27>>2] = $103;
   HEAP32[$$pre$phi34Z2D>>2] = $49;
   HEAP32[$$pre$phiZ2D>>2] = $50;
   $104 = ($44|0)!=(0);
   $or$cond = $104 | $30;
   if ($or$cond) {
    $112 = $50;
   } else {
    $$0 = $45;
    continue;
   }
  } else {
   $112 = $46;
  }
  if ((($44|0) == 1)) {
   label = 31;
   break;
  } else if (!((($44|0) == 0))) {
   $176 = $44;
   label = 46;
   break;
  }
  $105 = ($45|0)==(0);
  if ($105) {
   label = 29;
   break;
  } else {
   $$0 = $45;
  }
 }
 if ((label|0) == 22) {
  _png_error($png_ptr,392064);
  // unreachable;
 }
 else if ((label|0) == 29) {
  $106 = ($flush|0)==(4);
  if ($106) {
   _png_error($png_ptr,391248);
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 else if ((label|0) == 31) {
  $107 = ($flush|0)==(4);
  if (!($107)) {
   $176 = 1;
   _png_zstream_error($png_ptr,$176);
   $177 = (($png_ptr) + 244|0);
   $178 = HEAP32[$177>>2]|0;
   _png_error($png_ptr,$178);
   // unreachable;
  }
  $108 = HEAP32[$$pre$phi30Z2D>>2]|0;
  $109 = (($108) + 4|0);
  $110 = HEAP32[$$pre$phi32Z2D>>2]|0;
  $111 = (($110) - ($112))|0;
  $113 = HEAP32[$27>>2]|0;
  $114 = $113 & 4;
  $115 = ($114|0)==(0);
  if ($115) {
   $116 = HEAP8[$28>>0]|0;
   $117 = ($116<<24>>24)==(0);
   if ($117) {
    $118 = (_png_image_size($png_ptr)|0);
    $119 = ($118>>>0)<(16385);
    if ($119) {
     $120 = HEAP8[$109>>0]|0;
     $121 = $120&255;
     $122 = $121 & 15;
     $123 = ($122|0)==(8);
     $124 = $121 & 240;
     $125 = ($124>>>0)<(113);
     $or$cond$i3 = $123 & $125;
     if ($or$cond$i3) {
      $126 = $121 >>> 4;
      $127 = (($126) + 7)|0;
      $128 = 1 << $127;
      $129 = ($128>>>0)<($118>>>0);
      if (!($129)) {
       $half_z_window_size$0$i5 = $128;$z_cinfo$0$i4 = $126;
       while(1) {
        $130 = $half_z_window_size$0$i5 >>> 1;
        $131 = (($z_cinfo$0$i4) + -1)|0;
        $132 = ($131|0)==(0);
        $133 = ($130>>>0)<($118>>>0);
        $or$cond2$i6 = $132 | $133;
        if ($or$cond2$i6) {
         break;
        } else {
         $half_z_window_size$0$i5 = $130;$z_cinfo$0$i4 = $131;
        }
       }
       $134 = $131 << 4;
       $135 = $134 | 8;
       $136 = $135&255;
       HEAP8[$109>>0] = $136;
       $137 = (($108) + 5|0);
       $138 = HEAP8[$137>>0]|0;
       $139 = $138&255;
       $140 = $139 & 224;
       $141 = $135 << 8;
       $142 = $140 | $141;
       $143 = (($142>>>0) % 31)&-1;
       $144 = $140 | $143;
       $145 = $144 ^ 31;
       $146 = $145&255;
       HEAP8[$137>>0] = $146;
      }
     }
    }
   }
  }
  if (!($29)) {
   $147 = ($111|0)<(0);
   if ($147) {
    _png_error($png_ptr,392064);
    // unreachable;
   }
   HEAP32[$31>>2] = 34;
   $148 = $111 >>> 24;
   $149 = $148&255;
   HEAP8[$buf$i13>>0] = $149;
   $150 = $111 >>> 16;
   $151 = $150&255;
   $152 = (($buf$i13) + 1|0);
   HEAP8[$152>>0] = $151;
   $153 = $111 >>> 8;
   $154 = $153&255;
   $155 = (($buf$i13) + 2|0);
   HEAP8[$155>>0] = $154;
   $156 = $111&255;
   $157 = (($buf$i13) + 3|0);
   HEAP8[$157>>0] = $156;
   $158 = (($buf$i13) + 4|0);
   HEAP8[$158>>0] = 73;
   $159 = (($buf$i13) + 5|0);
   HEAP8[$159>>0] = 68;
   $160 = (($buf$i13) + 6|0);
   HEAP8[$160>>0] = 65;
   $161 = (($buf$i13) + 7|0);
   HEAP8[$161>>0] = 84;
   _png_write_data($png_ptr,$buf$i13,8);
   HEAP32[$39>>2] = 1229209940;
   _png_reset_crc($png_ptr);
   _png_calculate_crc($png_ptr,$158,4);
   HEAP32[$31>>2] = 66;
   $162 = ($110|0)==($112|0);
   if (!($162)) {
    _png_write_data($png_ptr,$109,$111);
    _png_calculate_crc($png_ptr,$109,$111);
   }
   HEAP32[$31>>2] = 130;
   $163 = HEAP32[$40>>2]|0;
   $164 = $163 >>> 24;
   $165 = $164&255;
   HEAP8[$buf$i13>>0] = $165;
   $166 = $163 >>> 16;
   $167 = $166&255;
   $168 = (($buf$i13) + 1|0);
   HEAP8[$168>>0] = $167;
   $169 = $163 >>> 8;
   $170 = $169&255;
   $171 = (($buf$i13) + 2|0);
   HEAP8[$171>>0] = $170;
   $172 = $163&255;
   $173 = (($buf$i13) + 3|0);
   HEAP8[$173>>0] = $172;
   _png_write_data($png_ptr,$buf$i13,4);
  }
  HEAP32[$$pre$phiZ2D>>2] = 0;
  HEAP32[$$pre$phi34Z2D>>2] = 0;
  $174 = HEAP32[$27>>2]|0;
  $175 = $174 | 12;
  HEAP32[$27>>2] = $175;
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 46) {
  _png_zstream_error($png_ptr,$176);
  $177 = (($png_ptr) + 244|0);
  $178 = HEAP32[$177>>2]|0;
  _png_error($png_ptr,$178);
  // unreachable;
 }
}
function _png_deflate_claim($png_ptr,$owner,$data_size) {
 $png_ptr = $png_ptr|0;
 $owner = $owner|0;
 $data_size = $data_size|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $half_window_size$06 = 0, $level$0 = 0, $memLevel$0 = 0, $method$0 = 0, $msg = 0, $not$ = 0, $ret$04 = 0, $strategy$0 = 0, $windowBits$0 = 0, $windowBits$15 = 0, $windowBits$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $msg = sp;
 $0 = (($png_ptr) + 216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if (!($2)) {
   $3 = $owner >>> 24;
   $4 = $3&255;
   HEAP8[$msg>>0] = $4;
   $5 = $owner >>> 16;
   $6 = $5&255;
   $7 = (($msg) + 1|0);
   HEAP8[$7>>0] = $6;
   $8 = $owner >>> 8;
   $9 = $8&255;
   $10 = (($msg) + 2|0);
   HEAP8[$10>>0] = $9;
   $11 = $owner&255;
   $12 = (($msg) + 3|0);
   HEAP8[$12>>0] = $11;
   $13 = (($msg) + 4|0);
   HEAP8[$13>>0] = 58;
   $14 = (($msg) + 5|0);
   HEAP8[$14>>0] = 32;
   $15 = $1 >>> 24;
   $16 = $15&255;
   $17 = (($msg) + 6|0);
   HEAP8[$17>>0] = $16;
   $18 = $1 >>> 16;
   $19 = $18&255;
   $20 = (($msg) + 7|0);
   HEAP8[$20>>0] = $19;
   $21 = $1 >>> 8;
   $22 = $21&255;
   $23 = (($msg) + 8|0);
   HEAP8[$23>>0] = $22;
   $24 = $1&255;
   $25 = (($msg) + 9|0);
   HEAP8[$25>>0] = $24;
   (_png_safecat($msg,64,10,392024)|0);
   $26 = HEAP32[$0>>2]|0;
   $27 = ($26|0)==(1229209940);
   if (!($27)) {
    HEAP32[$0>>2] = 0;
    break;
   }
   $28 = (($png_ptr) + 244|0);
   HEAP32[$28>>2] = 392040;
   $$1 = -2;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 $29 = (($png_ptr) + 284|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($png_ptr) + 288|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($png_ptr) + 292|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($png_ptr) + 296|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($owner|0)==(1229209940);
 do {
  if ($37) {
   $38 = (($png_ptr) + 208|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = $39 & 1;
   $41 = ($40|0)==(0);
   if ($41) {
    $44 = (($png_ptr) + 430|0);
    $45 = HEAP8[$44>>0]|0;
    $not$ = ($45<<24>>24)!=(8);
    $$ = $not$&1;
    $level$0 = $30;$memLevel$0 = $36;$method$0 = $32;$strategy$0 = $$;$windowBits$0 = $34;
    break;
   } else {
    $42 = (($png_ptr) + 300|0);
    $43 = HEAP32[$42>>2]|0;
    $level$0 = $30;$memLevel$0 = $36;$method$0 = $32;$strategy$0 = $43;$windowBits$0 = $34;
    break;
   }
  } else {
   $46 = (($png_ptr) + 304|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($png_ptr) + 308|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($png_ptr) + 312|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($png_ptr) + 316|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($png_ptr) + 320|0);
   $55 = HEAP32[$54>>2]|0;
   $level$0 = $47;$memLevel$0 = $53;$method$0 = $49;$strategy$0 = $55;$windowBits$0 = $51;
  }
 } while(0);
 $56 = ($data_size>>>0)<(16385);
 if ($56) {
  $57 = (($windowBits$0) + -1)|0;
  $58 = 1 << $57;
  $59 = (($data_size) + 262)|0;
  $60 = ($59>>>0)>($58>>>0);
  if ($60) {
   $windowBits$2 = $windowBits$0;
  } else {
   $half_window_size$06 = $58;$windowBits$15 = $windowBits$0;
   while(1) {
    $61 = $half_window_size$06 >>> 1;
    $62 = (($windowBits$15) + -1)|0;
    $63 = ($59>>>0)>($61>>>0);
    if ($63) {
     $windowBits$2 = $62;
     break;
    } else {
     $half_window_size$06 = $61;$windowBits$15 = $62;
    }
   }
  }
 } else {
  $windowBits$2 = $windowBits$0;
 }
 $64 = (($png_ptr) + 208|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = $65 & 2;
 $67 = ($66|0)==(0);
 do {
  if ($67) {
   $91 = $65;
  } else {
   $68 = (($png_ptr) + 324|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==($level$0|0);
   if ($70) {
    $71 = (($png_ptr) + 328|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==($method$0|0);
    if ($73) {
     $74 = (($png_ptr) + 332|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = ($75|0)==($windowBits$2|0);
     if ($76) {
      $77 = (($png_ptr) + 336|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ($78|0)==($memLevel$0|0);
      if ($79) {
       $80 = (($png_ptr) + 340|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==($strategy$0|0);
       if ($82) {
        $91 = $65;
        break;
       }
      }
     }
    }
   }
   $83 = (($png_ptr) + 220|0);
   (_deflateEnd($83)|0);
   $84 = HEAP32[$64>>2]|0;
   $85 = $84 & -3;
   HEAP32[$64>>2] = $85;
   $91 = $85;
  }
 } while(0);
 $86 = (($png_ptr) + 220|0);
 HEAP32[$86>>2] = 0;
 $87 = (($png_ptr) + 224|0);
 HEAP32[$87>>2] = 0;
 $88 = (($png_ptr) + 232|0);
 HEAP32[$88>>2] = 0;
 $89 = (($png_ptr) + 236|0);
 HEAP32[$89>>2] = 0;
 $90 = $91 & 2;
 $92 = ($90|0)==(0);
 if ($92) {
  $93 = (_deflateInit2_($86,$level$0,$method$0,$windowBits$2,$memLevel$0,$strategy$0,392056,56)|0);
  $94 = ($93|0)==(0);
  if ($94) {
   $95 = HEAP32[$64>>2]|0;
   $96 = $95 | 2;
   HEAP32[$64>>2] = $96;
   label = 24;
  } else {
   $ret$04 = $93;
   label = 25;
  }
 } else {
  $97 = (_deflateReset($86)|0);
  $98 = ($97|0)==(0);
  if ($98) {
   label = 24;
  } else {
   $ret$04 = $97;
   label = 25;
  }
 }
 if ((label|0) == 24) {
  HEAP32[$0>>2] = $owner;
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 else if ((label|0) == 25) {
  _png_zstream_error($png_ptr,$ret$04);
  $$1 = $ret$04;
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function _png_image_size($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $cb_base$0$ph = 0;
 var $cb_base$0$ph$us = 0, $pass$0 = 0, $pass$0$ph = 0, $pass$0$ph$us = 0, $pass$0$us = 0, $phitmp = 0, $phitmp5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($png_ptr) + 360|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 | $1;
 $5 = ($4>>>0)<(32768);
 if (!($5)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($png_ptr) + 428|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $96 = (($3) + 1)|0;
  $97 = Math_imul($96, $1)|0;
  $$0 = $97;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($png_ptr) + 344|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($png_ptr) + 434|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = (($10) + -1)|0;
 $15 = ($12&255)>(7);
 $16 = $13 >>> 3;
 $17 = (($1) + -1)|0;
 if ($15) {
  $cb_base$0$ph$us = 0;$pass$0$ph$us = 0;
  L28: while(1) {
   $pass$0$us = $pass$0$ph$us;
   while(1) {
    $55 = ($pass$0$us|0)<(7);
    if (!($55)) {
     $$0 = $cb_base$0$ph$us;
     break L28;
    }
    $18 = ($pass$0$us|0)>(1);
    if ($18) {
     $19 = (7 - ($pass$0$us))|0;
     $20 = $19 >> 1;
     $22 = $20;
    } else {
     $22 = 3;
    }
    $21 = 1 << $22;
    $23 = $pass$0$us & 1;
    $24 = (($pass$0$us) + 1)|0;
    $25 = $24 >> 1;
    $26 = (3 - ($25))|0;
    $27 = $23 << $26;
    $28 = $27 & 7;
    $29 = (($14) - ($28))|0;
    $30 = (($29) + ($21))|0;
    if ($18) {
     $31 = (7 - ($pass$0$us))|0;
     $32 = $31 >> 1;
     $34 = $32;
    } else {
     $34 = 3;
    }
    $33 = $30 >>> $34;
    $35 = ($33|0)==(0);
    if ($35) {
     $pass$0$us = $24;
    } else {
     break;
    }
   }
   $36 = Math_imul($33, $16)|0;
   $phitmp5 = (($36) + 1)|0;
   $37 = ($pass$0$us|0)>(2);
   if ($37) {
    $38 = (8 - ($pass$0$us))|0;
    $39 = $38 >> 1;
    $41 = $39;
   } else {
    $41 = 3;
   }
   $40 = 1 << $41;
   $42 = $23 ^ 1;
   $43 = $pass$0$us >> 1;
   $44 = (3 - ($43))|0;
   $45 = $42 << $44;
   $46 = $45 & 7;
   $47 = (($17) - ($46))|0;
   $48 = (($47) + ($40))|0;
   if ($37) {
    $49 = (8 - ($pass$0$us))|0;
    $50 = $49 >> 1;
    $52 = $50;
   } else {
    $52 = 3;
   }
   $51 = $48 >>> $52;
   $53 = Math_imul($51, $phitmp5)|0;
   $54 = (($53) + ($cb_base$0$ph$us))|0;
   $cb_base$0$ph$us = $54;$pass$0$ph$us = $24;
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $cb_base$0$ph = 0;$pass$0$ph = 0;
  L9: while(1) {
   $pass$0 = $pass$0$ph;
   while(1) {
    $56 = ($pass$0|0)<(7);
    if (!($56)) {
     $$0 = $cb_base$0$ph;
     break L9;
    }
    $57 = ($pass$0|0)>(1);
    if ($57) {
     $58 = (7 - ($pass$0))|0;
     $59 = $58 >> 1;
     $61 = $59;
    } else {
     $61 = 3;
    }
    $60 = 1 << $61;
    $62 = $pass$0 & 1;
    $63 = (($pass$0) + 1)|0;
    $64 = $63 >> 1;
    $65 = (3 - ($64))|0;
    $66 = $62 << $65;
    $67 = $66 & 7;
    $68 = (($14) - ($67))|0;
    $69 = (($68) + ($60))|0;
    if ($57) {
     $70 = (7 - ($pass$0))|0;
     $71 = $70 >> 1;
     $73 = $71;
    } else {
     $73 = 3;
    }
    $72 = $69 >>> $73;
    $74 = ($72|0)==(0);
    if ($74) {
     $pass$0 = $63;
    } else {
     break;
    }
   }
   $75 = Math_imul($72, $13)|0;
   $76 = (($75) + 7)|0;
   $77 = $76 >>> 3;
   $phitmp = (($77) + 1)|0;
   $78 = ($pass$0|0)>(2);
   if ($78) {
    $79 = (8 - ($pass$0))|0;
    $80 = $79 >> 1;
    $82 = $80;
   } else {
    $82 = 3;
   }
   $81 = 1 << $82;
   $83 = $62 ^ 1;
   $84 = $pass$0 >> 1;
   $85 = (3 - ($84))|0;
   $86 = $83 << $85;
   $87 = $86 & 7;
   $88 = (($17) - ($87))|0;
   $89 = (($88) + ($81))|0;
   if ($78) {
    $90 = (8 - ($pass$0))|0;
    $91 = $90 >> 1;
    $93 = $91;
   } else {
    $93 = 3;
   }
   $92 = $89 >>> $93;
   $94 = Math_imul($92, $phitmp)|0;
   $95 = (($94) + ($cb_base$0$ph))|0;
   $cb_base$0$ph = $95;$pass$0$ph = $63;
  }
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _png_write_IEND($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $buf$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf$i1 = sp;
 $0 = ($png_ptr|0)==(0|0);
 if ($0) {
  $19 = (($png_ptr) + 204|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20 | 16;
  HEAP32[$19>>2] = $21;
  STACKTOP = sp;return;
 }
 $1 = (($png_ptr) + 656|0);
 HEAP32[$1>>2] = 34;
 $2 = (($buf$i1) + 4|0);
 HEAP32[$buf$i1>>2] = 0;
 HEAP8[$2>>0] = 73;
 $3 = (($buf$i1) + 5|0);
 HEAP8[$3>>0] = 69;
 $4 = (($buf$i1) + 6|0);
 HEAP8[$4>>0] = 78;
 $5 = (($buf$i1) + 7|0);
 HEAP8[$5>>0] = 68;
 _png_write_data($png_ptr,$buf$i1,8);
 $6 = (($png_ptr) + 372|0);
 HEAP32[$6>>2] = 1229278788;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$2,4);
 HEAP32[$1>>2] = 130;
 $7 = (($png_ptr) + 408|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9&255;
 HEAP8[$buf$i1>>0] = $10;
 $11 = $8 >>> 16;
 $12 = $11&255;
 $13 = (($buf$i1) + 1|0);
 HEAP8[$13>>0] = $12;
 $14 = $8 >>> 8;
 $15 = $14&255;
 $16 = (($buf$i1) + 2|0);
 HEAP8[$16>>0] = $15;
 $17 = $8&255;
 $18 = (($buf$i1) + 3|0);
 HEAP8[$18>>0] = $17;
 _png_write_data($png_ptr,$buf$i1,4);
 $19 = (($png_ptr) + 204|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 | 16;
 HEAP32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function _png_write_gAMA_fixed($png_ptr,$file_gamma) {
 $png_ptr = $png_ptr|0;
 $file_gamma = $file_gamma|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $buf$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf$i1 = sp + 8|0;
 $buf = sp;
 $0 = $file_gamma >>> 24;
 $1 = $0&255;
 HEAP8[$buf>>0] = $1;
 $2 = $file_gamma >>> 16;
 $3 = $2&255;
 $4 = (($buf) + 1|0);
 HEAP8[$4>>0] = $3;
 $5 = $file_gamma >>> 8;
 $6 = $5&255;
 $7 = (($buf) + 2|0);
 HEAP8[$7>>0] = $6;
 $8 = $file_gamma&255;
 $9 = (($buf) + 3|0);
 HEAP8[$9>>0] = $8;
 $10 = ($png_ptr|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($png_ptr) + 656|0);
 HEAP32[$11>>2] = 34;
 HEAP8[$buf$i1>>0] = 0;
 $12 = (($buf$i1) + 1|0);
 HEAP8[$12>>0] = 0;
 $13 = (($buf$i1) + 2|0);
 HEAP8[$13>>0] = 0;
 $14 = (($buf$i1) + 3|0);
 HEAP8[$14>>0] = 4;
 $15 = (($buf$i1) + 4|0);
 HEAP8[$15>>0] = 103;
 $16 = (($buf$i1) + 5|0);
 HEAP8[$16>>0] = 65;
 $17 = (($buf$i1) + 6|0);
 HEAP8[$17>>0] = 77;
 $18 = (($buf$i1) + 7|0);
 HEAP8[$18>>0] = 65;
 _png_write_data($png_ptr,$buf$i1,8);
 $19 = (($png_ptr) + 372|0);
 HEAP32[$19>>2] = 1732332865;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$15,4);
 HEAP32[$11>>2] = 66;
 _png_write_data($png_ptr,$buf,4);
 _png_calculate_crc($png_ptr,$buf,4);
 HEAP32[$11>>2] = 130;
 $20 = (($png_ptr) + 408|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 >>> 24;
 $23 = $22&255;
 HEAP8[$buf$i1>>0] = $23;
 $24 = $21 >>> 16;
 $25 = $24&255;
 $26 = (($buf$i1) + 1|0);
 HEAP8[$26>>0] = $25;
 $27 = $21 >>> 8;
 $28 = $27&255;
 $29 = (($buf$i1) + 2|0);
 HEAP8[$29>>0] = $28;
 $30 = $21&255;
 $31 = (($buf$i1) + 3|0);
 HEAP8[$31>>0] = $30;
 _png_write_data($png_ptr,$buf$i1,4);
 STACKTOP = sp;return;
}
function _png_write_sRGB($png_ptr,$srgb_intent) {
 $png_ptr = $png_ptr|0;
 $srgb_intent = $srgb_intent|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $buf = 0, $buf$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf$i1 = sp + 8|0;
 $buf = sp;
 $0 = $srgb_intent&255;
 HEAP8[$buf>>0] = $0;
 $1 = ($png_ptr|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($png_ptr) + 656|0);
 HEAP32[$2>>2] = 34;
 HEAP8[$buf$i1>>0] = 0;
 $3 = (($buf$i1) + 1|0);
 HEAP8[$3>>0] = 0;
 $4 = (($buf$i1) + 2|0);
 HEAP8[$4>>0] = 0;
 $5 = (($buf$i1) + 3|0);
 HEAP8[$5>>0] = 1;
 $6 = (($buf$i1) + 4|0);
 HEAP8[$6>>0] = 115;
 $7 = (($buf$i1) + 5|0);
 HEAP8[$7>>0] = 82;
 $8 = (($buf$i1) + 6|0);
 HEAP8[$8>>0] = 71;
 $9 = (($buf$i1) + 7|0);
 HEAP8[$9>>0] = 66;
 _png_write_data($png_ptr,$buf$i1,8);
 $10 = (($png_ptr) + 372|0);
 HEAP32[$10>>2] = 1934772034;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$6,4);
 HEAP32[$2>>2] = 66;
 _png_write_data($png_ptr,$buf,1);
 _png_calculate_crc($png_ptr,$buf,1);
 HEAP32[$2>>2] = 130;
 $11 = (($png_ptr) + 408|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 >>> 24;
 $14 = $13&255;
 HEAP8[$buf$i1>>0] = $14;
 $15 = $12 >>> 16;
 $16 = $15&255;
 $17 = (($buf$i1) + 1|0);
 HEAP8[$17>>0] = $16;
 $18 = $12 >>> 8;
 $19 = $18&255;
 $20 = (($buf$i1) + 2|0);
 HEAP8[$20>>0] = $19;
 $21 = $12&255;
 $22 = (($buf$i1) + 3|0);
 HEAP8[$22>>0] = $21;
 _png_write_data($png_ptr,$buf$i1,4);
 STACKTOP = sp;return;
}
function _png_write_iCCP($png_ptr,$name,$profile) {
 $png_ptr = $png_ptr|0;
 $name = $name|0;
 $profile = $profile|0;
 var $$ = 0, $$01$ph$be$i = 0, $$01$ph26$i = 0, $$01$ph42$i = 0, $$02$ph$be$i = 0, $$02$ph41$i = 0, $$0214$us18$i = 0, $$1$i = 0, $$4 = 0, $$off$us$i = 0, $$off$us19$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $avail$0$i = 0, $buf$i = 0, $buf$i1 = 0, $comp = 0, $key_len$0$ph$be$i = 0, $key_len$0$ph32$i = 0, $key_len$0$ph47$i = 0, $key_len$1$i = 0, $new_name = 0, $next$0$i = 0, $next$0$in$i = 0, $or$cond$i = 0;
 var $or$cond1$i$i = 0, $or$cond13$i = 0, $or$cond2$us$i = 0, $or$cond2$us20$i = 0, $or$cond3$i = 0, $output$0$i = 0, $output_len$0$avail$0$i = 0, $output_len$0$i = 0, $space$0$ph$be$i = 0, $space$0$ph38$i = 0, $space$0$ph53$i = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1136|0;
 $buf$i1 = sp + 1128|0;
 $buf$i = sp + 1120|0;
 $new_name = sp + 1036|0;
 $comp = sp;
 $0 = ($profile|0)==(0|0);
 if ($0) {
  _png_error($png_ptr,391288);
  // unreachable;
 }
 $1 = HEAP8[$profile>>0]|0;
 $2 = $1&255;
 $3 = $2 << 24;
 $4 = (($profile) + 1|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 16;
 $8 = $7 | $3;
 $9 = (($profile) + 2|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = $11 << 8;
 $13 = $8 | $12;
 $14 = (($profile) + 3|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = $13 | $16;
 $18 = ($17>>>0)<(132);
 if ($18) {
  _png_error($png_ptr,391320);
  // unreachable;
 }
 $19 = $16 & 3;
 $20 = ($19|0)==(0);
 if (!($20)) {
  _png_error($png_ptr,391344);
  // unreachable;
 }
 $21 = ($name|0)==(0|0);
 if ($21) {
  HEAP8[$new_name>>0] = 0;
  _png_error($png_ptr,391400);
  // unreachable;
 }
 $22 = HEAP8[$name>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  HEAP8[$new_name>>0] = 0;
  _png_error($png_ptr,391400);
  // unreachable;
 } else {
  $$01$ph42$i = $new_name;$$02$ph41$i = $name;$29 = $22;$key_len$0$ph47$i = 0;$space$0$ph53$i = 1;
 }
 L17: while(1) {
  $27 = ($space$0$ph53$i|0)==(0);
  L19: do {
   if ($27) {
    $28 = (($$02$ph41$i) + 1|0);
    $$off$us$i = (($29) + -33)<<24>>24;
    $30 = ($$off$us$i&255)<(94);
    $31 = ($29&255)>(160);
    $or$cond2$us$i = $30 | $31;
    $$ = $or$cond2$us$i ? $29 : 32;
    $32 = $or$cond2$us$i&1;
    $$4 = $32 ^ 1;
    $$02$ph$be$i = $28;$space$0$ph$be$i = $$4;$storemerge$i = $$;
   } else {
    $$0214$us18$i = $$02$ph41$i;$34 = $29;
    while(1) {
     $33 = (($$0214$us18$i) + 1|0);
     $$off$us19$i = (($34) + -33)<<24>>24;
     $35 = ($$off$us19$i&255)<(94);
     $36 = ($34&255)>(160);
     $or$cond2$us20$i = $35 | $36;
     if ($or$cond2$us20$i) {
      $$02$ph$be$i = $33;$space$0$ph$be$i = 0;$storemerge$i = $34;
      break L19;
     }
     $37 = HEAP8[$33>>0]|0;
     $38 = ($37<<24>>24)==(0);
     if ($38) {
      $$01$ph26$i = $$01$ph42$i;$key_len$0$ph32$i = $key_len$0$ph47$i;$space$0$ph38$i = $space$0$ph53$i;
      break L17;
     } else {
      $$0214$us18$i = $33;$34 = $37;
     }
    }
   }
  } while(0);
  HEAP8[$$01$ph42$i>>0] = $storemerge$i;
  $key_len$0$ph$be$i = (($key_len$0$ph47$i) + 1)|0;
  $$01$ph$be$i = (($$01$ph42$i) + 1|0);
  $24 = HEAP8[$$02$ph$be$i>>0]|0;
  $25 = ($24<<24>>24)!=(0);
  $26 = ($key_len$0$ph$be$i>>>0)<(79);
  $or$cond13$i = $25 & $26;
  if ($or$cond13$i) {
   $$01$ph42$i = $$01$ph$be$i;$$02$ph41$i = $$02$ph$be$i;$29 = $24;$key_len$0$ph47$i = $key_len$0$ph$be$i;$space$0$ph53$i = $space$0$ph$be$i;
  } else {
   $$01$ph26$i = $$01$ph$be$i;$key_len$0$ph32$i = $key_len$0$ph$be$i;$space$0$ph38$i = $space$0$ph$be$i;
   break;
  }
 }
 $39 = ($key_len$0$ph32$i|0)==(0);
 $40 = ($space$0$ph38$i|0)==(0);
 $or$cond3$i = $39 | $40;
 if ($or$cond3$i) {
  $$1$i = $$01$ph26$i;$key_len$1$i = $key_len$0$ph32$i;
 } else {
  $41 = (($key_len$0$ph32$i) + -1)|0;
  $42 = (($$01$ph26$i) + -1|0);
  $$1$i = $42;$key_len$1$i = $41;
 }
 HEAP8[$$1$i>>0] = 0;
 $43 = ($key_len$1$i|0)==(0);
 if ($43) {
  _png_error($png_ptr,391400);
  // unreachable;
 }
 $44 = (($key_len$1$i) + 1)|0;
 $45 = (($new_name) + ($44)|0);
 HEAP8[$45>>0] = 0;
 $46 = (($key_len$1$i) + 2)|0;
 HEAP32[$comp>>2] = $profile;
 $47 = (($comp) + 4|0);
 HEAP32[$47>>2] = $17;
 $48 = (($comp) + 8|0);
 HEAP32[$48>>2] = 0;
 $49 = (_png_text_compress($png_ptr,1766015824,$comp,$46)|0);
 $50 = ($49|0)==(0);
 if (!($50)) {
  $51 = (($png_ptr) + 244|0);
  $52 = HEAP32[$51>>2]|0;
  _png_error($png_ptr,$52);
  // unreachable;
 }
 $53 = HEAP32[$48>>2]|0;
 $54 = (($53) + ($46))|0;
 $55 = ($png_ptr|0)==(0|0);
 if (!($55)) {
  $56 = (($png_ptr) + 656|0);
  HEAP32[$56>>2] = 34;
  $57 = $54 >>> 24;
  $58 = $57&255;
  HEAP8[$buf$i1>>0] = $58;
  $59 = $54 >>> 16;
  $60 = $59&255;
  $61 = (($buf$i1) + 1|0);
  HEAP8[$61>>0] = $60;
  $62 = $54 >>> 8;
  $63 = $62&255;
  $64 = (($buf$i1) + 2|0);
  HEAP8[$64>>0] = $63;
  $65 = $54&255;
  $66 = (($buf$i1) + 3|0);
  HEAP8[$66>>0] = $65;
  $67 = (($buf$i1) + 4|0);
  HEAP8[$67>>0] = 105;
  $68 = (($buf$i1) + 5|0);
  HEAP8[$68>>0] = 67;
  $69 = (($buf$i1) + 6|0);
  HEAP8[$69>>0] = 67;
  $70 = (($buf$i1) + 7|0);
  HEAP8[$70>>0] = 80;
  _png_write_data($png_ptr,$buf$i1,8);
  $71 = (($png_ptr) + 372|0);
  HEAP32[$71>>2] = 1766015824;
  _png_reset_crc($png_ptr);
  _png_calculate_crc($png_ptr,$67,4);
  HEAP32[$56>>2] = 66;
  $72 = ($46|0)==(0);
  if (!($72)) {
   _png_write_data($png_ptr,$new_name,$46);
   _png_calculate_crc($png_ptr,$new_name,$46);
  }
 }
 $73 = HEAP32[$48>>2]|0;
 $74 = (($comp) + 12|0);
 $75 = (($png_ptr) + 276|0);
 $76 = (($png_ptr) + 280|0);
 $avail$0$i = 1024;$next$0$in$i = $75;$output$0$i = $74;$output_len$0$i = $73;
 while(1) {
  $next$0$i = HEAP32[$next$0$in$i>>2]|0;
  $77 = ($avail$0$i>>>0)>($output_len$0$i>>>0);
  $output_len$0$avail$0$i = $77 ? $output_len$0$i : $avail$0$i;
  $78 = ($output_len$0$avail$0$i|0)==(0);
  $or$cond1$i$i = $55 | $78;
  if (!($or$cond1$i$i)) {
   _png_write_data($png_ptr,$output$0$i,$output_len$0$avail$0$i);
   _png_calculate_crc($png_ptr,$output$0$i,$output_len$0$avail$0$i);
  }
  $79 = ($output_len$0$i|0)==($output_len$0$avail$0$i|0);
  $80 = ($next$0$i|0)==(0|0);
  $or$cond$i = $79 | $80;
  if ($or$cond$i) {
   break;
  }
  $81 = (($output_len$0$i) - ($output_len$0$avail$0$i))|0;
  $82 = HEAP32[$76>>2]|0;
  $83 = (($next$0$i) + 4|0);
  $avail$0$i = $82;$next$0$in$i = $next$0$i;$output$0$i = $83;$output_len$0$i = $81;
 }
 if (!($79)) {
  _png_error($png_ptr,391944);
  // unreachable;
 }
 if ($55) {
  STACKTOP = sp;return;
 }
 $84 = (($png_ptr) + 656|0);
 HEAP32[$84>>2] = 130;
 $85 = (($png_ptr) + 408|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = $86 >>> 24;
 $88 = $87&255;
 HEAP8[$buf$i>>0] = $88;
 $89 = $86 >>> 16;
 $90 = $89&255;
 $91 = (($buf$i) + 1|0);
 HEAP8[$91>>0] = $90;
 $92 = $86 >>> 8;
 $93 = $92&255;
 $94 = (($buf$i) + 2|0);
 HEAP8[$94>>0] = $93;
 $95 = $86&255;
 $96 = (($buf$i) + 3|0);
 HEAP8[$96>>0] = $95;
 _png_write_data($png_ptr,$buf$i,4);
 STACKTOP = sp;return;
}
function _png_text_compress($png_ptr,$chunk_name,$comp,$prefix_len) {
 $png_ptr = $png_ptr|0;
 $chunk_name = $chunk_name|0;
 $comp = $comp|0;
 $prefix_len = $prefix_len|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $end$0 = 0, $end$1 = 0, $half_z_window_size$0$i = 0, $input_len$0 = 0, $input_len$1 = 0, $next$0 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond2$i = 0, $output_len$0 = 0, $output_len$1 = 0;
 var $output_len$2 = 0, $phitmp = 0, $ret$0 = 0, $z_cinfo$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($comp) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_png_deflate_claim($png_ptr,$chunk_name,$1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($png_ptr) + 276|0);
 $5 = HEAP32[$0>>2]|0;
 $6 = HEAP32[$comp>>2]|0;
 $7 = (($png_ptr) + 220|0);
 HEAP32[$7>>2] = $6;
 $8 = (($png_ptr) + 224|0);
 HEAP32[$8>>2] = 0;
 $9 = (($comp) + 12|0);
 $10 = (($png_ptr) + 232|0);
 HEAP32[$10>>2] = $9;
 $11 = (($png_ptr) + 236|0);
 HEAP32[$11>>2] = 1024;
 $12 = (($png_ptr) + 280|0);
 $66 = 0;$end$0 = $4;$input_len$0 = $5;$output_len$0 = 1024;
 while(1) {
  HEAP32[$8>>2] = $input_len$0;
  if ($66) {
   $13 = (($output_len$0) + ($prefix_len))|0;
   $14 = ($13|0)<(0);
   if ($14) {
    $input_len$1 = 0;$output_len$2 = $output_len$0;$ret$0 = -4;
    break;
   }
   $15 = HEAP32[$end$0>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $17 = HEAP32[$12>>2]|0;
    $18 = (($17) + 4)|0;
    $19 = (_png_malloc_base($png_ptr,$18)|0);
    $20 = ($19|0)==(0|0);
    if ($20) {
     $input_len$1 = 0;$output_len$2 = $output_len$0;$ret$0 = -4;
     break;
    }
    HEAP32[$19>>2] = 0;
    HEAP32[$end$0>>2] = $19;
    $next$0 = $19;
   } else {
    $next$0 = $15;
   }
   $21 = (($next$0) + 4|0);
   HEAP32[$10>>2] = $21;
   $22 = HEAP32[$12>>2]|0;
   HEAP32[$11>>2] = $22;
   $23 = (($22) + ($output_len$0))|0;
   $end$1 = $next$0;$output_len$1 = $23;
  } else {
   $end$1 = $end$0;$output_len$1 = $output_len$0;
  }
  $24 = (_deflate($7,4)|0);
  $25 = HEAP32[$8>>2]|0;
  HEAP32[$8>>2] = 0;
  $26 = ($24|0)==(0);
  if (!($26)) {
   $input_len$1 = $25;$output_len$2 = $output_len$1;$ret$0 = $24;
   break;
  }
  $$pre = HEAP32[$11>>2]|0;
  $phitmp = ($$pre|0)==(0);
  $66 = $phitmp;$end$0 = $end$1;$input_len$0 = $25;$output_len$0 = $output_len$1;
 }
 $27 = HEAP32[$11>>2]|0;
 $28 = (($output_len$2) - ($27))|0;
 HEAP32[$11>>2] = 0;
 $29 = (($comp) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = (($28) + ($prefix_len))|0;
 $31 = ($30>>>0)>(2147483646);
 if ($31) {
  $32 = (($png_ptr) + 244|0);
  HEAP32[$32>>2] = 391992;
  $33 = (($png_ptr) + 216|0);
  HEAP32[$33>>2] = 0;
  $$0 = -4;
  STACKTOP = sp;return ($$0|0);
 }
 _png_zstream_error($png_ptr,$ret$0);
 $34 = (($png_ptr) + 216|0);
 HEAP32[$34>>2] = 0;
 $35 = ($ret$0|0)==(1);
 $36 = ($input_len$1|0)==(0);
 $or$cond = $35 & $36;
 if (!($or$cond)) {
  $$0 = $ret$0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = HEAP32[$0>>2]|0;
 $38 = ($37>>>0)<(16385);
 if (!($38)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = HEAP8[$9>>0]|0;
 $40 = $39&255;
 $41 = $40 & 15;
 $42 = ($41|0)==(8);
 $43 = $40 & 240;
 $44 = ($43>>>0)<(113);
 $or$cond$i = $42 & $44;
 if (!($or$cond$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = $40 >>> 4;
 $46 = (($45) + 7)|0;
 $47 = 1 << $46;
 $48 = ($47>>>0)<($37>>>0);
 if ($48) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $half_z_window_size$0$i = $47;$z_cinfo$0$i = $45;
 }
 while(1) {
  $49 = $half_z_window_size$0$i >>> 1;
  $50 = (($z_cinfo$0$i) + -1)|0;
  $51 = ($50|0)==(0);
  $52 = ($49>>>0)<($37>>>0);
  $or$cond2$i = $51 | $52;
  if ($or$cond2$i) {
   break;
  } else {
   $half_z_window_size$0$i = $49;$z_cinfo$0$i = $50;
  }
 }
 $53 = $50 << 4;
 $54 = $53 | 8;
 $55 = $54&255;
 HEAP8[$9>>0] = $55;
 $56 = (($comp) + 13|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = $57&255;
 $59 = $58 & 224;
 $60 = $54 << 8;
 $61 = $59 | $60;
 $62 = (($61>>>0) % 31)&-1;
 $63 = $59 | $62;
 $64 = $63 ^ 31;
 $65 = $64&255;
 HEAP8[$56>>0] = $65;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _png_write_sPLT($png_ptr,$spalette) {
 $png_ptr = $png_ptr|0;
 $spalette = $spalette|0;
 var $$ = 0, $$01$ph$be$i = 0, $$01$ph26$i = 0, $$01$ph42$i = 0, $$02$ph$be$i = 0, $$02$ph41$i = 0, $$0214$us18$i = 0, $$1$i = 0, $$6 = 0, $$off$us$i = 0, $$off$us19$i = 0, $$pre = 0, $$pre21 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf$i = 0;
 var $buf$i1 = 0, $entrybuf = 0, $ep$07 = 0, $key_len$0$ph$be$i = 0, $key_len$0$ph32$i = 0, $key_len$0$ph47$i = 0, $key_len$1$i = 0, $new_name = 0, $or$cond13$i = 0, $or$cond2$us$i = 0, $or$cond2$us20$i = 0, $or$cond3$i = 0, $space$0$ph$be$i = 0, $space$0$ph38$i = 0, $space$0$ph53$i = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $buf$i1 = sp + 104|0;
 $buf$i = sp;
 $new_name = sp + 8|0;
 $entrybuf = sp + 88|0;
 $0 = (($spalette) + 4|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(8);
 $3 = $2 ? 6 : 10;
 $4 = (($spalette) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$spalette>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  HEAP8[$new_name>>0] = 0;
  _png_error($png_ptr,391424);
  // unreachable;
 }
 $8 = HEAP8[$6>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  HEAP8[$new_name>>0] = 0;
  _png_error($png_ptr,391424);
  // unreachable;
 } else {
  $$01$ph42$i = $new_name;$$02$ph41$i = $6;$15 = $8;$key_len$0$ph47$i = 0;$space$0$ph53$i = 1;
 }
 L8: while(1) {
  $13 = ($space$0$ph53$i|0)==(0);
  L10: do {
   if ($13) {
    $14 = (($$02$ph41$i) + 1|0);
    $$off$us$i = (($15) + -33)<<24>>24;
    $16 = ($$off$us$i&255)<(94);
    $17 = ($15&255)>(160);
    $or$cond2$us$i = $16 | $17;
    $$ = $or$cond2$us$i ? $15 : 32;
    $18 = $or$cond2$us$i&1;
    $$6 = $18 ^ 1;
    $$02$ph$be$i = $14;$space$0$ph$be$i = $$6;$storemerge$i = $$;
   } else {
    $$0214$us18$i = $$02$ph41$i;$20 = $15;
    while(1) {
     $19 = (($$0214$us18$i) + 1|0);
     $$off$us19$i = (($20) + -33)<<24>>24;
     $21 = ($$off$us19$i&255)<(94);
     $22 = ($20&255)>(160);
     $or$cond2$us20$i = $21 | $22;
     if ($or$cond2$us20$i) {
      $$02$ph$be$i = $19;$space$0$ph$be$i = 0;$storemerge$i = $20;
      break L10;
     }
     $23 = HEAP8[$19>>0]|0;
     $24 = ($23<<24>>24)==(0);
     if ($24) {
      $$01$ph26$i = $$01$ph42$i;$key_len$0$ph32$i = $key_len$0$ph47$i;$space$0$ph38$i = $space$0$ph53$i;
      break L8;
     } else {
      $$0214$us18$i = $19;$20 = $23;
     }
    }
   }
  } while(0);
  HEAP8[$$01$ph42$i>>0] = $storemerge$i;
  $key_len$0$ph$be$i = (($key_len$0$ph47$i) + 1)|0;
  $$01$ph$be$i = (($$01$ph42$i) + 1|0);
  $10 = HEAP8[$$02$ph$be$i>>0]|0;
  $11 = ($10<<24>>24)!=(0);
  $12 = ($key_len$0$ph$be$i>>>0)<(79);
  $or$cond13$i = $11 & $12;
  if ($or$cond13$i) {
   $$01$ph42$i = $$01$ph$be$i;$$02$ph41$i = $$02$ph$be$i;$15 = $10;$key_len$0$ph47$i = $key_len$0$ph$be$i;$space$0$ph53$i = $space$0$ph$be$i;
  } else {
   $$01$ph26$i = $$01$ph$be$i;$key_len$0$ph32$i = $key_len$0$ph$be$i;$space$0$ph38$i = $space$0$ph$be$i;
   break;
  }
 }
 $25 = ($key_len$0$ph32$i|0)==(0);
 $26 = ($space$0$ph38$i|0)==(0);
 $or$cond3$i = $25 | $26;
 if ($or$cond3$i) {
  $$1$i = $$01$ph26$i;$key_len$1$i = $key_len$0$ph32$i;
 } else {
  $27 = (($key_len$0$ph32$i) + -1)|0;
  $28 = (($$01$ph26$i) + -1|0);
  $$1$i = $28;$key_len$1$i = $27;
 }
 HEAP8[$$1$i>>0] = 0;
 $29 = ($key_len$1$i|0)==(0);
 if ($29) {
  _png_error($png_ptr,391424);
  // unreachable;
 }
 $30 = Math_imul($3, $5)|0;
 $31 = (($30) + 2)|0;
 $32 = (($31) + ($key_len$1$i))|0;
 $33 = ($png_ptr|0)==(0|0);
 if (!($33)) {
  $34 = (($png_ptr) + 656|0);
  HEAP32[$34>>2] = 34;
  $35 = $32 >>> 24;
  $36 = $35&255;
  HEAP8[$buf$i1>>0] = $36;
  $37 = $32 >>> 16;
  $38 = $37&255;
  $39 = (($buf$i1) + 1|0);
  HEAP8[$39>>0] = $38;
  $40 = $32 >>> 8;
  $41 = $40&255;
  $42 = (($buf$i1) + 2|0);
  HEAP8[$42>>0] = $41;
  $43 = $32&255;
  $44 = (($buf$i1) + 3|0);
  HEAP8[$44>>0] = $43;
  $45 = (($buf$i1) + 4|0);
  HEAP8[$45>>0] = 115;
  $46 = (($buf$i1) + 5|0);
  HEAP8[$46>>0] = 80;
  $47 = (($buf$i1) + 6|0);
  HEAP8[$47>>0] = 76;
  $48 = (($buf$i1) + 7|0);
  HEAP8[$48>>0] = 84;
  _png_write_data($png_ptr,$buf$i1,8);
  $49 = (($png_ptr) + 372|0);
  HEAP32[$49>>2] = 1934642260;
  _png_reset_crc($png_ptr);
  _png_calculate_crc($png_ptr,$45,4);
  HEAP32[$34>>2] = 66;
  $50 = (($key_len$1$i) + 1)|0;
  $51 = ($50|0)==(0);
  if (!($51)) {
   _png_write_data($png_ptr,$new_name,$50);
   _png_calculate_crc($png_ptr,$new_name,$50);
  }
  _png_write_data($png_ptr,$0,1);
  _png_calculate_crc($png_ptr,$0,1);
 }
 $52 = (($spalette) + 8|0);
 $53 = HEAP32[$4>>2]|0;
 $54 = ($53|0)>(0);
 if ($54) {
  $55 = HEAP32[$52>>2]|0;
  $56 = (($entrybuf) + 1|0);
  $57 = (($entrybuf) + 2|0);
  $58 = (($entrybuf) + 3|0);
  $59 = (($entrybuf) + 4|0);
  $60 = (($entrybuf) + 5|0);
  $61 = (($entrybuf) + 6|0);
  $62 = (($entrybuf) + 7|0);
  $63 = (($entrybuf) + 8|0);
  $64 = (($entrybuf) + 9|0);
  $124 = $53;$125 = $55;$ep$07 = $55;
  while(1) {
   $65 = HEAP8[$0>>0]|0;
   $66 = ($65<<24>>24)==(8);
   $67 = HEAP16[$ep$07>>1]|0;
   if ($66) {
    $68 = $67&255;
    HEAP8[$entrybuf>>0] = $68;
    $69 = (($ep$07) + 2|0);
    $70 = HEAP16[$69>>1]|0;
    $71 = $70&255;
    HEAP8[$56>>0] = $71;
    $72 = (($ep$07) + 4|0);
    $73 = HEAP16[$72>>1]|0;
    $74 = $73&255;
    HEAP8[$57>>0] = $74;
    $75 = (($ep$07) + 6|0);
    $76 = HEAP16[$75>>1]|0;
    $77 = $76&255;
    HEAP8[$58>>0] = $77;
    $78 = (($ep$07) + 8|0);
    $79 = HEAP16[$78>>1]|0;
    $80 = ($79&65535) >>> 8;
    $81 = $80&255;
    HEAP8[$59>>0] = $81;
    $82 = $79&255;
    HEAP8[$60>>0] = $82;
   } else {
    $83 = ($67&65535) >>> 8;
    $84 = $83&255;
    HEAP8[$entrybuf>>0] = $84;
    $85 = $67&255;
    HEAP8[$56>>0] = $85;
    $86 = (($ep$07) + 2|0);
    $87 = HEAP16[$86>>1]|0;
    $88 = ($87&65535) >>> 8;
    $89 = $88&255;
    HEAP8[$57>>0] = $89;
    $90 = $87&255;
    HEAP8[$58>>0] = $90;
    $91 = (($ep$07) + 4|0);
    $92 = HEAP16[$91>>1]|0;
    $93 = ($92&65535) >>> 8;
    $94 = $93&255;
    HEAP8[$59>>0] = $94;
    $95 = $92&255;
    HEAP8[$60>>0] = $95;
    $96 = (($ep$07) + 6|0);
    $97 = HEAP16[$96>>1]|0;
    $98 = ($97&65535) >>> 8;
    $99 = $98&255;
    HEAP8[$61>>0] = $99;
    $100 = $97&255;
    HEAP8[$62>>0] = $100;
    $101 = (($ep$07) + 8|0);
    $102 = HEAP16[$101>>1]|0;
    $103 = ($102&65535) >>> 8;
    $104 = $103&255;
    HEAP8[$63>>0] = $104;
    $105 = $102&255;
    HEAP8[$64>>0] = $105;
   }
   if ($33) {
    $108 = $125;$109 = $124;
   } else {
    _png_write_data($png_ptr,$entrybuf,$3);
    _png_calculate_crc($png_ptr,$entrybuf,$3);
    $$pre = HEAP32[$52>>2]|0;
    $$pre21 = HEAP32[$4>>2]|0;
    $108 = $$pre;$109 = $$pre21;
   }
   $106 = (($ep$07) + 10|0);
   $107 = (($108) + (($109*10)|0)|0);
   $110 = ($106>>>0)<($107>>>0);
   if ($110) {
    $124 = $109;$125 = $108;$ep$07 = $106;
   } else {
    break;
   }
  }
 }
 if ($33) {
  STACKTOP = sp;return;
 }
 $111 = (($png_ptr) + 656|0);
 HEAP32[$111>>2] = 130;
 $112 = (($png_ptr) + 408|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = $113 >>> 24;
 $115 = $114&255;
 HEAP8[$buf$i>>0] = $115;
 $116 = $113 >>> 16;
 $117 = $116&255;
 $118 = (($buf$i) + 1|0);
 HEAP8[$118>>0] = $117;
 $119 = $113 >>> 8;
 $120 = $119&255;
 $121 = (($buf$i) + 2|0);
 HEAP8[$121>>0] = $120;
 $122 = $113&255;
 $123 = (($buf$i) + 3|0);
 HEAP8[$123>>0] = $122;
 _png_write_data($png_ptr,$buf$i,4);
 STACKTOP = sp;return;
}
function _png_write_sBIT($png_ptr,$sbit,$color_type) {
 $png_ptr = $png_ptr|0;
 $sbit = $sbit|0;
 $color_type = $color_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $buf$i3 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $size$0 = 0, $size$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf$i3 = sp + 8|0;
 $buf = sp;
 $0 = $color_type & 2;
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   $19 = (($sbit) + 3|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)==(0);
   if ($21) {
    STACKTOP = sp;return;
   }
   $22 = (($png_ptr) + 433|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($20&255)>($23&255);
   if ($24) {
    STACKTOP = sp;return;
   } else {
    HEAP8[$buf>>0] = $20;
    $size$0 = 1;
    break;
   }
  } else {
   $2 = ($color_type|0)==(3);
   if ($2) {
    $8 = 8;
   } else {
    $3 = (($png_ptr) + 433|0);
    $4 = HEAP8[$3>>0]|0;
    $8 = $4;
   }
   $5 = HEAP8[$sbit>>0]|0;
   $6 = ($5<<24>>24)==(0);
   $7 = ($5&255)>($8&255);
   $or$cond = $6 | $7;
   if ($or$cond) {
    STACKTOP = sp;return;
   }
   $9 = (($sbit) + 1|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)==(0);
   $12 = ($10&255)>($8&255);
   $or$cond1 = $11 | $12;
   if ($or$cond1) {
    STACKTOP = sp;return;
   }
   $13 = (($sbit) + 2|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   $16 = ($14&255)>($8&255);
   $or$cond2 = $15 | $16;
   if ($or$cond2) {
    STACKTOP = sp;return;
   } else {
    HEAP8[$buf>>0] = $5;
    $17 = (($buf) + 1|0);
    HEAP8[$17>>0] = $10;
    $18 = (($buf) + 2|0);
    HEAP8[$18>>0] = $14;
    $size$0 = 3;
    break;
   }
  }
 } while(0);
 $25 = $color_type & 4;
 $26 = ($25|0)==(0);
 do {
  if ($26) {
   $size$1 = $size$0;
  } else {
   $27 = (($sbit) + 4|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = ($28<<24>>24)==(0);
   if ($29) {
    STACKTOP = sp;return;
   }
   $30 = (($png_ptr) + 433|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($28&255)>($31&255);
   if ($32) {
    STACKTOP = sp;return;
   } else {
    $33 = (($size$0) + 1)|0;
    $34 = (($buf) + ($size$0)|0);
    HEAP8[$34>>0] = $28;
    $size$1 = $33;
    break;
   }
  }
 } while(0);
 $35 = ($png_ptr|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = ($size$1|0)<(0);
 if ($36) {
  _png_error($png_ptr,392064);
  // unreachable;
 }
 $37 = (($png_ptr) + 656|0);
 HEAP32[$37>>2] = 34;
 $38 = $size$1 >>> 24;
 $39 = $38&255;
 HEAP8[$buf$i3>>0] = $39;
 $40 = $size$1 >>> 16;
 $41 = $40&255;
 $42 = (($buf$i3) + 1|0);
 HEAP8[$42>>0] = $41;
 $43 = $size$1 >>> 8;
 $44 = $43&255;
 $45 = (($buf$i3) + 2|0);
 HEAP8[$45>>0] = $44;
 $46 = $size$1&255;
 $47 = (($buf$i3) + 3|0);
 HEAP8[$47>>0] = $46;
 $48 = (($buf$i3) + 4|0);
 HEAP8[$48>>0] = 115;
 $49 = (($buf$i3) + 5|0);
 HEAP8[$49>>0] = 66;
 $50 = (($buf$i3) + 6|0);
 HEAP8[$50>>0] = 73;
 $51 = (($buf$i3) + 7|0);
 HEAP8[$51>>0] = 84;
 _png_write_data($png_ptr,$buf$i3,8);
 $52 = (($png_ptr) + 372|0);
 HEAP32[$52>>2] = 1933723988;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$48,4);
 HEAP32[$37>>2] = 66;
 _png_write_data($png_ptr,$buf,$size$1);
 _png_calculate_crc($png_ptr,$buf,$size$1);
 HEAP32[$37>>2] = 130;
 $53 = (($png_ptr) + 408|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 >>> 24;
 $56 = $55&255;
 HEAP8[$buf$i3>>0] = $56;
 $57 = $54 >>> 16;
 $58 = $57&255;
 $59 = (($buf$i3) + 1|0);
 HEAP8[$59>>0] = $58;
 $60 = $54 >>> 8;
 $61 = $60&255;
 $62 = (($buf$i3) + 2|0);
 HEAP8[$62>>0] = $61;
 $63 = $54&255;
 $64 = (($buf$i3) + 3|0);
 HEAP8[$64>>0] = $63;
 _png_write_data($png_ptr,$buf$i3,4);
 STACKTOP = sp;return;
}
function _png_write_cHRM_fixed($png_ptr,$xy) {
 $png_ptr = $png_ptr|0;
 $xy = $xy|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $buf$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $buf$i1 = sp + 32|0;
 $buf = sp;
 $0 = (($xy) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 _png_save_int_32($buf,$1);
 $2 = (($buf) + 4|0);
 $3 = (($xy) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 _png_save_int_32($2,$4);
 $5 = (($buf) + 8|0);
 $6 = HEAP32[$xy>>2]|0;
 _png_save_int_32($5,$6);
 $7 = (($buf) + 12|0);
 $8 = (($xy) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 _png_save_int_32($7,$9);
 $10 = (($buf) + 16|0);
 $11 = (($xy) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 _png_save_int_32($10,$12);
 $13 = (($buf) + 20|0);
 $14 = (($xy) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 _png_save_int_32($13,$15);
 $16 = (($buf) + 24|0);
 $17 = (($xy) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 _png_save_int_32($16,$18);
 $19 = (($buf) + 28|0);
 $20 = (($xy) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 _png_save_int_32($19,$21);
 $22 = ($png_ptr|0)==(0|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (($png_ptr) + 656|0);
 HEAP32[$23>>2] = 34;
 HEAP8[$buf$i1>>0] = 0;
 $24 = (($buf$i1) + 1|0);
 HEAP8[$24>>0] = 0;
 $25 = (($buf$i1) + 2|0);
 HEAP8[$25>>0] = 0;
 $26 = (($buf$i1) + 3|0);
 HEAP8[$26>>0] = 32;
 $27 = (($buf$i1) + 4|0);
 HEAP8[$27>>0] = 99;
 $28 = (($buf$i1) + 5|0);
 HEAP8[$28>>0] = 72;
 $29 = (($buf$i1) + 6|0);
 HEAP8[$29>>0] = 82;
 $30 = (($buf$i1) + 7|0);
 HEAP8[$30>>0] = 77;
 _png_write_data($png_ptr,$buf$i1,8);
 $31 = (($png_ptr) + 372|0);
 HEAP32[$31>>2] = 1665684045;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$27,4);
 HEAP32[$23>>2] = 66;
 _png_write_data($png_ptr,$buf,32);
 _png_calculate_crc($png_ptr,$buf,32);
 HEAP32[$23>>2] = 130;
 $32 = (($png_ptr) + 408|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 >>> 24;
 $35 = $34&255;
 HEAP8[$buf$i1>>0] = $35;
 $36 = $33 >>> 16;
 $37 = $36&255;
 $38 = (($buf$i1) + 1|0);
 HEAP8[$38>>0] = $37;
 $39 = $33 >>> 8;
 $40 = $39&255;
 $41 = (($buf$i1) + 2|0);
 HEAP8[$41>>0] = $40;
 $42 = $33&255;
 $43 = (($buf$i1) + 3|0);
 HEAP8[$43>>0] = $42;
 _png_write_data($png_ptr,$buf$i1,4);
 STACKTOP = sp;return;
}
function _png_write_tRNS($png_ptr,$trans_alpha,$tran,$num_trans,$color_type) {
 $png_ptr = $png_ptr|0;
 $trans_alpha = $trans_alpha|0;
 $tran = $tran|0;
 $num_trans = $num_trans|0;
 $color_type = $color_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf = 0, $buf$i12 = 0, $or$cond1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf$i12 = sp + 8|0;
 $buf = sp;
 if ((($color_type|0) == 0)) {
  $37 = (($tran) + 8|0);
  $38 = HEAP16[$37>>1]|0;
  $39 = $38&65535;
  $40 = (($png_ptr) + 432|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41&255;
  $43 = 1 << $42;
  $44 = ($39|0)<($43|0);
  if ($44) {
   $45 = ($38&65535) >>> 8;
   $46 = $45&255;
   HEAP8[$buf>>0] = $46;
   $47 = $38&255;
   $48 = (($buf) + 1|0);
   HEAP8[$48>>0] = $47;
   $49 = (($png_ptr) + 656|0);
   HEAP32[$49>>2] = 34;
   HEAP8[$buf$i12>>0] = 0;
   $50 = (($buf$i12) + 1|0);
   HEAP8[$50>>0] = 0;
   $51 = (($buf$i12) + 2|0);
   HEAP8[$51>>0] = 0;
   $52 = (($buf$i12) + 3|0);
   HEAP8[$52>>0] = 2;
   $53 = (($buf$i12) + 4|0);
   HEAP8[$53>>0] = 116;
   $54 = (($buf$i12) + 5|0);
   HEAP8[$54>>0] = 82;
   $55 = (($buf$i12) + 6|0);
   HEAP8[$55>>0] = 78;
   $56 = (($buf$i12) + 7|0);
   HEAP8[$56>>0] = 83;
   _png_write_data($png_ptr,$buf$i12,8);
   $57 = (($png_ptr) + 372|0);
   HEAP32[$57>>2] = 1951551059;
   _png_reset_crc($png_ptr);
   _png_calculate_crc($png_ptr,$53,4);
   HEAP32[$49>>2] = 66;
   _png_write_data($png_ptr,$buf,2);
   _png_calculate_crc($png_ptr,$buf,2);
   HEAP32[$49>>2] = 130;
   $58 = (($png_ptr) + 408|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 >>> 24;
   $61 = $60&255;
   HEAP8[$buf$i12>>0] = $61;
   $62 = $59 >>> 16;
   $63 = $62&255;
   $64 = (($buf$i12) + 1|0);
   HEAP8[$64>>0] = $63;
   $65 = $59 >>> 8;
   $66 = $65&255;
   $67 = (($buf$i12) + 2|0);
   HEAP8[$67>>0] = $66;
   $68 = $59&255;
   $69 = (($buf$i12) + 3|0);
   HEAP8[$69>>0] = $68;
   _png_write_data($png_ptr,$buf$i12,4);
   STACKTOP = sp;return;
  } else {
   _png_app_warning($png_ptr,391496);
   STACKTOP = sp;return;
  }
 } else if ((($color_type|0) == 3)) {
  $0 = ($num_trans|0)<(1);
  if (!($0)) {
   $1 = (($png_ptr) + 416|0);
   $2 = HEAP16[$1>>1]|0;
   $3 = $2&65535;
   $4 = ($3|0)<($num_trans|0);
   if (!($4)) {
    $5 = ($png_ptr|0)==(0|0);
    if ($5) {
     STACKTOP = sp;return;
    }
    $6 = ($num_trans|0)<(0);
    if ($6) {
     _png_error($png_ptr,392064);
     // unreachable;
    }
    $7 = (($png_ptr) + 656|0);
    HEAP32[$7>>2] = 34;
    $8 = $num_trans >>> 24;
    $9 = $8&255;
    HEAP8[$buf$i12>>0] = $9;
    $10 = $num_trans >>> 16;
    $11 = $10&255;
    $12 = (($buf$i12) + 1|0);
    HEAP8[$12>>0] = $11;
    $13 = $num_trans >>> 8;
    $14 = $13&255;
    $15 = (($buf$i12) + 2|0);
    HEAP8[$15>>0] = $14;
    $16 = $num_trans&255;
    $17 = (($buf$i12) + 3|0);
    HEAP8[$17>>0] = $16;
    $18 = (($buf$i12) + 4|0);
    HEAP8[$18>>0] = 116;
    $19 = (($buf$i12) + 5|0);
    HEAP8[$19>>0] = 82;
    $20 = (($buf$i12) + 6|0);
    HEAP8[$20>>0] = 78;
    $21 = (($buf$i12) + 7|0);
    HEAP8[$21>>0] = 83;
    _png_write_data($png_ptr,$buf$i12,8);
    $22 = (($png_ptr) + 372|0);
    HEAP32[$22>>2] = 1951551059;
    _png_reset_crc($png_ptr);
    _png_calculate_crc($png_ptr,$18,4);
    HEAP32[$7>>2] = 66;
    $23 = ($trans_alpha|0)==(0|0);
    $24 = ($num_trans|0)==(0);
    $or$cond1$i$i = $23 | $24;
    if (!($or$cond1$i$i)) {
     _png_write_data($png_ptr,$trans_alpha,$num_trans);
     _png_calculate_crc($png_ptr,$trans_alpha,$num_trans);
    }
    HEAP32[$7>>2] = 130;
    $25 = (($png_ptr) + 408|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = $26 >>> 24;
    $28 = $27&255;
    HEAP8[$buf$i12>>0] = $28;
    $29 = $26 >>> 16;
    $30 = $29&255;
    $31 = (($buf$i12) + 1|0);
    HEAP8[$31>>0] = $30;
    $32 = $26 >>> 8;
    $33 = $32&255;
    $34 = (($buf$i12) + 2|0);
    HEAP8[$34>>0] = $33;
    $35 = $26&255;
    $36 = (($buf$i12) + 3|0);
    HEAP8[$36>>0] = $35;
    _png_write_data($png_ptr,$buf$i12,4);
    STACKTOP = sp;return;
   }
  }
  _png_app_warning($png_ptr,391448);
  STACKTOP = sp;return;
 } else if ((($color_type|0) == 2)) {
  $70 = (($tran) + 2|0);
  $71 = HEAP16[$70>>1]|0;
  $72 = ($71&65535) >>> 8;
  $73 = $72&255;
  HEAP8[$buf>>0] = $73;
  $74 = $71&255;
  $75 = (($buf) + 1|0);
  HEAP8[$75>>0] = $74;
  $76 = (($buf) + 2|0);
  $77 = (($tran) + 4|0);
  $78 = HEAP16[$77>>1]|0;
  $79 = ($78&65535) >>> 8;
  $80 = $79&255;
  HEAP8[$76>>0] = $80;
  $81 = $78&255;
  $82 = (($buf) + 3|0);
  HEAP8[$82>>0] = $81;
  $83 = (($buf) + 4|0);
  $84 = (($tran) + 6|0);
  $85 = HEAP16[$84>>1]|0;
  $86 = ($85&65535) >>> 8;
  $87 = $86&255;
  HEAP8[$83>>0] = $87;
  $88 = $85&255;
  $89 = (($buf) + 5|0);
  HEAP8[$89>>0] = $88;
  $90 = $79 | $72;
  $91 = $90 | $86;
  $92 = ($91<<16>>16)==(0);
  if (!($92)) {
   _png_app_warning($png_ptr,391560);
   STACKTOP = sp;return;
  }
  $93 = ($png_ptr|0)==(0|0);
  if ($93) {
   STACKTOP = sp;return;
  }
  $94 = (($png_ptr) + 656|0);
  HEAP32[$94>>2] = 34;
  HEAP8[$buf$i12>>0] = 0;
  $95 = (($buf$i12) + 1|0);
  HEAP8[$95>>0] = 0;
  $96 = (($buf$i12) + 2|0);
  HEAP8[$96>>0] = 0;
  $97 = (($buf$i12) + 3|0);
  HEAP8[$97>>0] = 6;
  $98 = (($buf$i12) + 4|0);
  HEAP8[$98>>0] = 116;
  $99 = (($buf$i12) + 5|0);
  HEAP8[$99>>0] = 82;
  $100 = (($buf$i12) + 6|0);
  HEAP8[$100>>0] = 78;
  $101 = (($buf$i12) + 7|0);
  HEAP8[$101>>0] = 83;
  _png_write_data($png_ptr,$buf$i12,8);
  $102 = (($png_ptr) + 372|0);
  HEAP32[$102>>2] = 1951551059;
  _png_reset_crc($png_ptr);
  _png_calculate_crc($png_ptr,$98,4);
  HEAP32[$94>>2] = 66;
  _png_write_data($png_ptr,$buf,6);
  _png_calculate_crc($png_ptr,$buf,6);
  HEAP32[$94>>2] = 130;
  $103 = (($png_ptr) + 408|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = $104 >>> 24;
  $106 = $105&255;
  HEAP8[$buf$i12>>0] = $106;
  $107 = $104 >>> 16;
  $108 = $107&255;
  $109 = (($buf$i12) + 1|0);
  HEAP8[$109>>0] = $108;
  $110 = $104 >>> 8;
  $111 = $110&255;
  $112 = (($buf$i12) + 2|0);
  HEAP8[$112>>0] = $111;
  $113 = $104&255;
  $114 = (($buf$i12) + 3|0);
  HEAP8[$114>>0] = $113;
  _png_write_data($png_ptr,$buf$i12,4);
  STACKTOP = sp;return;
 } else {
  _png_app_warning($png_ptr,391624);
  STACKTOP = sp;return;
 }
}
function _png_write_bKGD($png_ptr,$back,$color_type) {
 $png_ptr = $png_ptr|0;
 $back = $back|0;
 $color_type = $color_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf = 0, $buf$i = 0, $buf$i10 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $buf$i10 = sp + 16|0;
 $buf$i = sp;
 $buf = sp + 4|0;
 $0 = ($color_type|0)==(3);
 if (!($0)) {
  $36 = $color_type & 2;
  $37 = ($36|0)==(0);
  if ($37) {
   $83 = (($back) + 8|0);
   $84 = HEAP16[$83>>1]|0;
   $85 = $84&65535;
   $86 = (($png_ptr) + 432|0);
   $87 = HEAP8[$86>>0]|0;
   $88 = $87&255;
   $89 = 1 << $88;
   $90 = ($85|0)<($89|0);
   if (!($90)) {
    STACKTOP = sp;return;
   }
   $91 = ($84&65535) >>> 8;
   $92 = $91&255;
   HEAP8[$buf>>0] = $92;
   $93 = $84&255;
   $94 = (($buf) + 1|0);
   HEAP8[$94>>0] = $93;
   $95 = (($png_ptr) + 656|0);
   HEAP32[$95>>2] = 34;
   HEAP8[$buf$i10>>0] = 0;
   $96 = (($buf$i10) + 1|0);
   HEAP8[$96>>0] = 0;
   $97 = (($buf$i10) + 2|0);
   HEAP8[$97>>0] = 0;
   $98 = (($buf$i10) + 3|0);
   HEAP8[$98>>0] = 2;
   $99 = (($buf$i10) + 4|0);
   HEAP8[$99>>0] = 98;
   $100 = (($buf$i10) + 5|0);
   HEAP8[$100>>0] = 75;
   $101 = (($buf$i10) + 6|0);
   HEAP8[$101>>0] = 71;
   $102 = (($buf$i10) + 7|0);
   HEAP8[$102>>0] = 68;
   _png_write_data($png_ptr,$buf$i10,8);
   $103 = (($png_ptr) + 372|0);
   HEAP32[$103>>2] = 1649100612;
   _png_reset_crc($png_ptr);
   _png_calculate_crc($png_ptr,$99,4);
   HEAP32[$95>>2] = 66;
   _png_write_data($png_ptr,$buf,2);
   _png_calculate_crc($png_ptr,$buf,2);
   HEAP32[$95>>2] = 130;
   $104 = (($png_ptr) + 408|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = $105 >>> 24;
   $107 = $106&255;
   HEAP8[$buf$i10>>0] = $107;
   $108 = $105 >>> 16;
   $109 = $108&255;
   $110 = (($buf$i10) + 1|0);
   HEAP8[$110>>0] = $109;
   $111 = $105 >>> 8;
   $112 = $111&255;
   $113 = (($buf$i10) + 2|0);
   HEAP8[$113>>0] = $112;
   $114 = $105&255;
   $115 = (($buf$i10) + 3|0);
   HEAP8[$115>>0] = $114;
   _png_write_data($png_ptr,$buf$i10,4);
   STACKTOP = sp;return;
  } else {
   $38 = (($back) + 2|0);
   $39 = HEAP16[$38>>1]|0;
   $40 = ($39&65535) >>> 8;
   $41 = $40&255;
   HEAP8[$buf>>0] = $41;
   $42 = $39&255;
   $43 = (($buf) + 1|0);
   HEAP8[$43>>0] = $42;
   $44 = (($buf) + 2|0);
   $45 = (($back) + 4|0);
   $46 = HEAP16[$45>>1]|0;
   $47 = ($46&65535) >>> 8;
   $48 = $47&255;
   HEAP8[$44>>0] = $48;
   $49 = $46&255;
   $50 = (($buf) + 3|0);
   HEAP8[$50>>0] = $49;
   $51 = (($buf) + 4|0);
   $52 = (($back) + 6|0);
   $53 = HEAP16[$52>>1]|0;
   $54 = ($53&65535) >>> 8;
   $55 = $54&255;
   HEAP8[$51>>0] = $55;
   $56 = $53&255;
   $57 = (($buf) + 5|0);
   HEAP8[$57>>0] = $56;
   $58 = $47 | $40;
   $59 = $58 | $54;
   $60 = ($59<<16>>16)!=(0);
   $61 = ($png_ptr|0)==(0|0);
   $or$cond = $60 | $61;
   if ($or$cond) {
    STACKTOP = sp;return;
   }
   $62 = (($png_ptr) + 656|0);
   HEAP32[$62>>2] = 34;
   HEAP8[$buf$i10>>0] = 0;
   $63 = (($buf$i10) + 1|0);
   HEAP8[$63>>0] = 0;
   $64 = (($buf$i10) + 2|0);
   HEAP8[$64>>0] = 0;
   $65 = (($buf$i10) + 3|0);
   HEAP8[$65>>0] = 6;
   $66 = (($buf$i10) + 4|0);
   HEAP8[$66>>0] = 98;
   $67 = (($buf$i10) + 5|0);
   HEAP8[$67>>0] = 75;
   $68 = (($buf$i10) + 6|0);
   HEAP8[$68>>0] = 71;
   $69 = (($buf$i10) + 7|0);
   HEAP8[$69>>0] = 68;
   _png_write_data($png_ptr,$buf$i10,8);
   $70 = (($png_ptr) + 372|0);
   HEAP32[$70>>2] = 1649100612;
   _png_reset_crc($png_ptr);
   _png_calculate_crc($png_ptr,$66,4);
   HEAP32[$62>>2] = 66;
   _png_write_data($png_ptr,$buf,6);
   _png_calculate_crc($png_ptr,$buf,6);
   HEAP32[$62>>2] = 130;
   $71 = (($png_ptr) + 408|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = $72 >>> 24;
   $74 = $73&255;
   HEAP8[$buf$i10>>0] = $74;
   $75 = $72 >>> 16;
   $76 = $75&255;
   $77 = (($buf$i10) + 1|0);
   HEAP8[$77>>0] = $76;
   $78 = $72 >>> 8;
   $79 = $78&255;
   $80 = (($buf$i10) + 2|0);
   HEAP8[$80>>0] = $79;
   $81 = $72&255;
   $82 = (($buf$i10) + 3|0);
   HEAP8[$82>>0] = $81;
   _png_write_data($png_ptr,$buf$i10,4);
   STACKTOP = sp;return;
  }
 }
 $1 = (($png_ptr) + 416|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  $4 = (($png_ptr) + 596|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 & 1;
  $7 = ($6|0)==(0);
  if ($7) {
   label = 4;
  } else {
   $13 = HEAP8[$back>>0]|0;
   HEAP8[$buf>>0] = $13;
   $116 = $buf$i10;$23 = $buf;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $8 = HEAP8[$back>>0]|0;
   $9 = $8&255;
   $10 = $2&65535;
   $11 = ($9>>>0)<($10>>>0);
   if (!($11)) {
    STACKTOP = sp;return;
   }
   HEAP8[$buf>>0] = $8;
   $12 = ($png_ptr|0)==(0|0);
   if ($12) {
    STACKTOP = sp;return;
   } else {
    $116 = $buf$i10;$23 = $buf;
    break;
   }
  }
 } while(0);
 $14 = (($png_ptr) + 656|0);
 HEAP32[$14>>2] = 34;
 HEAP8[$buf$i10>>0] = 0;
 $15 = (($buf$i10) + 1|0);
 HEAP8[$15>>0] = 0;
 $16 = (($buf$i10) + 2|0);
 HEAP8[$16>>0] = 0;
 $17 = (($buf$i10) + 3|0);
 HEAP8[$17>>0] = 1;
 $18 = (($buf$i10) + 4|0);
 HEAP8[$18>>0] = 98;
 $19 = (($buf$i10) + 5|0);
 HEAP8[$19>>0] = 75;
 $20 = (($buf$i10) + 6|0);
 HEAP8[$20>>0] = 71;
 $21 = (($buf$i10) + 7|0);
 HEAP8[$21>>0] = 68;
 _png_write_data($png_ptr,$buf$i10,8);
 $22 = (($png_ptr) + 372|0);
 HEAP32[$22>>2] = 1649100612;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$18,4);
 HEAP32[$14>>2] = 66;
 _png_write_data($png_ptr,$23,1);
 _png_calculate_crc($png_ptr,$23,1);
 HEAP32[$14>>2] = 130;
 $24 = (($png_ptr) + 408|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 >>> 24;
 $27 = $26&255;
 HEAP8[$buf$i>>0] = $27;
 $28 = $25 >>> 16;
 $29 = $28&255;
 $30 = (($buf$i) + 1|0);
 HEAP8[$30>>0] = $29;
 $31 = $25 >>> 8;
 $32 = $31&255;
 $33 = (($buf$i) + 2|0);
 HEAP8[$33>>0] = $32;
 $34 = $25&255;
 $35 = (($buf$i) + 3|0);
 HEAP8[$35>>0] = $34;
 _png_write_data($png_ptr,$buf$i,4);
 STACKTOP = sp;return;
}
function _png_write_tEXt($png_ptr,$key,$text,$text_len) {
 $png_ptr = $png_ptr|0;
 $key = $key|0;
 $text = $text|0;
 $text_len = $text_len|0;
 var $$ = 0, $$01$ph$be$i = 0, $$01$ph26$i = 0, $$01$ph42$i = 0, $$02$ph$be$i = 0, $$02$ph41$i = 0, $$0214$us18$i = 0, $$05 = 0, $$1$i = 0, $$7 = 0, $$off$us$i = 0, $$off$us19$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $buf$i = 0, $buf$i1 = 0, $key_len$0$ph$be$i = 0, $key_len$0$ph32$i = 0, $key_len$0$ph47$i = 0;
 var $key_len$1$i = 0, $new_key = 0, $or$cond = 0, $or$cond$i = 0, $or$cond13$i = 0, $or$cond2$us$i = 0, $or$cond2$us20$i = 0, $or$cond3$i = 0, $space$0$ph$be$i = 0, $space$0$ph38$i = 0, $space$0$ph53$i = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $buf$i1 = sp + 88|0;
 $buf$i = sp;
 $new_key = sp + 8|0;
 $0 = ($key|0)==(0|0);
 if ($0) {
  HEAP8[$new_key>>0] = 0;
  _png_error($png_ptr,391664);
  // unreachable;
 }
 $1 = HEAP8[$key>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  HEAP8[$new_key>>0] = 0;
  _png_error($png_ptr,391664);
  // unreachable;
 } else {
  $$01$ph42$i = $new_key;$$02$ph41$i = $key;$8 = $1;$key_len$0$ph47$i = 0;$space$0$ph53$i = 1;
 }
 L8: while(1) {
  $6 = ($space$0$ph53$i|0)==(0);
  L10: do {
   if ($6) {
    $7 = (($$02$ph41$i) + 1|0);
    $$off$us$i = (($8) + -33)<<24>>24;
    $9 = ($$off$us$i&255)<(94);
    $10 = ($8&255)>(160);
    $or$cond2$us$i = $9 | $10;
    $$ = $or$cond2$us$i ? $8 : 32;
    $11 = $or$cond2$us$i&1;
    $$7 = $11 ^ 1;
    $$02$ph$be$i = $7;$space$0$ph$be$i = $$7;$storemerge$i = $$;
   } else {
    $$0214$us18$i = $$02$ph41$i;$13 = $8;
    while(1) {
     $12 = (($$0214$us18$i) + 1|0);
     $$off$us19$i = (($13) + -33)<<24>>24;
     $14 = ($$off$us19$i&255)<(94);
     $15 = ($13&255)>(160);
     $or$cond2$us20$i = $14 | $15;
     if ($or$cond2$us20$i) {
      $$02$ph$be$i = $12;$space$0$ph$be$i = 0;$storemerge$i = $13;
      break L10;
     }
     $16 = HEAP8[$12>>0]|0;
     $17 = ($16<<24>>24)==(0);
     if ($17) {
      $$01$ph26$i = $$01$ph42$i;$key_len$0$ph32$i = $key_len$0$ph47$i;$space$0$ph38$i = $space$0$ph53$i;
      break L8;
     } else {
      $$0214$us18$i = $12;$13 = $16;
     }
    }
   }
  } while(0);
  HEAP8[$$01$ph42$i>>0] = $storemerge$i;
  $key_len$0$ph$be$i = (($key_len$0$ph47$i) + 1)|0;
  $$01$ph$be$i = (($$01$ph42$i) + 1|0);
  $3 = HEAP8[$$02$ph$be$i>>0]|0;
  $4 = ($3<<24>>24)!=(0);
  $5 = ($key_len$0$ph$be$i>>>0)<(79);
  $or$cond13$i = $4 & $5;
  if ($or$cond13$i) {
   $$01$ph42$i = $$01$ph$be$i;$$02$ph41$i = $$02$ph$be$i;$8 = $3;$key_len$0$ph47$i = $key_len$0$ph$be$i;$space$0$ph53$i = $space$0$ph$be$i;
  } else {
   $$01$ph26$i = $$01$ph$be$i;$key_len$0$ph32$i = $key_len$0$ph$be$i;$space$0$ph38$i = $space$0$ph$be$i;
   break;
  }
 }
 $18 = ($key_len$0$ph32$i|0)==(0);
 $19 = ($space$0$ph38$i|0)==(0);
 $or$cond3$i = $18 | $19;
 if ($or$cond3$i) {
  $$1$i = $$01$ph26$i;$key_len$1$i = $key_len$0$ph32$i;
 } else {
  $20 = (($key_len$0$ph32$i) + -1)|0;
  $21 = (($$01$ph26$i) + -1|0);
  $$1$i = $21;$key_len$1$i = $20;
 }
 HEAP8[$$1$i>>0] = 0;
 $22 = ($key_len$1$i|0)==(0);
 if ($22) {
  _png_error($png_ptr,391664);
  // unreachable;
 }
 $23 = ($text|0)==(0|0);
 if ($23) {
  $$05 = 0;
 } else {
  $24 = HEAP8[$text>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   $$05 = 0;
  } else {
   $26 = (_strlen(($text|0))|0);
   $27 = (2147483646 - ($key_len$1$i))|0;
   $28 = ($26>>>0)>($27>>>0);
   if ($28) {
    _png_error($png_ptr,391688);
    // unreachable;
   } else {
    $$05 = $26;
   }
  }
 }
 $29 = (($key_len$1$i) + 1)|0;
 $30 = (($29) + ($$05))|0;
 $31 = ($png_ptr|0)==(0|0);
 if (!($31)) {
  $32 = (($png_ptr) + 656|0);
  HEAP32[$32>>2] = 34;
  $33 = $30 >>> 24;
  $34 = $33&255;
  HEAP8[$buf$i1>>0] = $34;
  $35 = $30 >>> 16;
  $36 = $35&255;
  $37 = (($buf$i1) + 1|0);
  HEAP8[$37>>0] = $36;
  $38 = $30 >>> 8;
  $39 = $38&255;
  $40 = (($buf$i1) + 2|0);
  HEAP8[$40>>0] = $39;
  $41 = $30&255;
  $42 = (($buf$i1) + 3|0);
  HEAP8[$42>>0] = $41;
  $43 = (($buf$i1) + 4|0);
  HEAP8[$43>>0] = 116;
  $44 = (($buf$i1) + 5|0);
  HEAP8[$44>>0] = 69;
  $45 = (($buf$i1) + 6|0);
  HEAP8[$45>>0] = 88;
  $46 = (($buf$i1) + 7|0);
  HEAP8[$46>>0] = 116;
  _png_write_data($png_ptr,$buf$i1,8);
  $47 = (($png_ptr) + 372|0);
  HEAP32[$47>>2] = 1950701684;
  _png_reset_crc($png_ptr);
  _png_calculate_crc($png_ptr,$43,4);
  HEAP32[$32>>2] = 66;
  $48 = ($29|0)==(0);
  if (!($48)) {
   _png_write_data($png_ptr,$new_key,$29);
   _png_calculate_crc($png_ptr,$new_key,$29);
  }
 }
 $49 = ($$05|0)==(0);
 $or$cond$i = $31 | $23;
 $or$cond = $49 | $or$cond$i;
 if (!($or$cond)) {
  _png_write_data($png_ptr,$text,$$05);
  _png_calculate_crc($png_ptr,$text,$$05);
 }
 if ($31) {
  STACKTOP = sp;return;
 }
 $50 = (($png_ptr) + 656|0);
 HEAP32[$50>>2] = 130;
 $51 = (($png_ptr) + 408|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 >>> 24;
 $54 = $53&255;
 HEAP8[$buf$i>>0] = $54;
 $55 = $52 >>> 16;
 $56 = $55&255;
 $57 = (($buf$i) + 1|0);
 HEAP8[$57>>0] = $56;
 $58 = $52 >>> 8;
 $59 = $58&255;
 $60 = (($buf$i) + 2|0);
 HEAP8[$60>>0] = $59;
 $61 = $52&255;
 $62 = (($buf$i) + 3|0);
 HEAP8[$62>>0] = $61;
 _png_write_data($png_ptr,$buf$i,4);
 STACKTOP = sp;return;
}
function _png_write_zTXt($png_ptr,$key,$text,$text_len,$compression) {
 $png_ptr = $png_ptr|0;
 $key = $key|0;
 $text = $text|0;
 $text_len = $text_len|0;
 $compression = $compression|0;
 var $$ = 0, $$01$ph$be$i = 0, $$01$ph26$i = 0, $$01$ph42$i = 0, $$02$ph$be$i = 0, $$02$ph41$i = 0, $$0214$us18$i = 0, $$1$i = 0, $$4 = 0, $$off$us$i = 0, $$off$us19$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $avail$0$i = 0, $buf$i = 0, $buf$i1 = 0, $comp = 0, $key_len$0$ph$be$i = 0, $key_len$0$ph32$i = 0, $key_len$0$ph47$i = 0, $key_len$1$i = 0, $new_key = 0, $next$0$i = 0;
 var $next$0$in$i = 0, $or$cond$i = 0, $or$cond1$i$i = 0, $or$cond13$i = 0, $or$cond2$us$i = 0, $or$cond2$us20$i = 0, $or$cond3$i = 0, $output$0$i = 0, $output_len$0$avail$0$i = 0, $output_len$0$i = 0, $space$0$ph$be$i = 0, $space$0$ph38$i = 0, $space$0$ph53$i = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1136|0;
 $buf$i1 = sp + 1128|0;
 $buf$i = sp + 1120|0;
 $new_key = sp + 1036|0;
 $comp = sp;
 if ((($compression|0) == 0)) {
  $0 = ($key|0)==(0|0);
  if ($0) {
   HEAP8[$new_key>>0] = 0;
   _png_error($png_ptr,391744);
   // unreachable;
  }
  $1 = HEAP8[$key>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   HEAP8[$new_key>>0] = 0;
   _png_error($png_ptr,391744);
   // unreachable;
  } else {
   $$01$ph42$i = $new_key;$$02$ph41$i = $key;$8 = $1;$key_len$0$ph47$i = 0;$space$0$ph53$i = 1;
  }
  L10: while(1) {
   $6 = ($space$0$ph53$i|0)==(0);
   L12: do {
    if ($6) {
     $7 = (($$02$ph41$i) + 1|0);
     $$off$us$i = (($8) + -33)<<24>>24;
     $9 = ($$off$us$i&255)<(94);
     $10 = ($8&255)>(160);
     $or$cond2$us$i = $9 | $10;
     $$ = $or$cond2$us$i ? $8 : 32;
     $11 = $or$cond2$us$i&1;
     $$4 = $11 ^ 1;
     $$02$ph$be$i = $7;$space$0$ph$be$i = $$4;$storemerge$i = $$;
    } else {
     $$0214$us18$i = $$02$ph41$i;$13 = $8;
     while(1) {
      $12 = (($$0214$us18$i) + 1|0);
      $$off$us19$i = (($13) + -33)<<24>>24;
      $14 = ($$off$us19$i&255)<(94);
      $15 = ($13&255)>(160);
      $or$cond2$us20$i = $14 | $15;
      if ($or$cond2$us20$i) {
       $$02$ph$be$i = $12;$space$0$ph$be$i = 0;$storemerge$i = $13;
       break L12;
      }
      $16 = HEAP8[$12>>0]|0;
      $17 = ($16<<24>>24)==(0);
      if ($17) {
       $$01$ph26$i = $$01$ph42$i;$key_len$0$ph32$i = $key_len$0$ph47$i;$space$0$ph38$i = $space$0$ph53$i;
       break L10;
      } else {
       $$0214$us18$i = $12;$13 = $16;
      }
     }
    }
   } while(0);
   HEAP8[$$01$ph42$i>>0] = $storemerge$i;
   $key_len$0$ph$be$i = (($key_len$0$ph47$i) + 1)|0;
   $$01$ph$be$i = (($$01$ph42$i) + 1|0);
   $3 = HEAP8[$$02$ph$be$i>>0]|0;
   $4 = ($3<<24>>24)!=(0);
   $5 = ($key_len$0$ph$be$i>>>0)<(79);
   $or$cond13$i = $4 & $5;
   if ($or$cond13$i) {
    $$01$ph42$i = $$01$ph$be$i;$$02$ph41$i = $$02$ph$be$i;$8 = $3;$key_len$0$ph47$i = $key_len$0$ph$be$i;$space$0$ph53$i = $space$0$ph$be$i;
   } else {
    $$01$ph26$i = $$01$ph$be$i;$key_len$0$ph32$i = $key_len$0$ph$be$i;$space$0$ph38$i = $space$0$ph$be$i;
    break;
   }
  }
  $18 = ($key_len$0$ph32$i|0)==(0);
  $19 = ($space$0$ph38$i|0)==(0);
  $or$cond3$i = $18 | $19;
  if ($or$cond3$i) {
   $$1$i = $$01$ph26$i;$key_len$1$i = $key_len$0$ph32$i;
  } else {
   $20 = (($key_len$0$ph32$i) + -1)|0;
   $21 = (($$01$ph26$i) + -1|0);
   $$1$i = $21;$key_len$1$i = $20;
  }
  HEAP8[$$1$i>>0] = 0;
  $22 = ($key_len$1$i|0)==(0);
  if ($22) {
   _png_error($png_ptr,391744);
   // unreachable;
  }
  $23 = (($key_len$1$i) + 1)|0;
  $24 = (($new_key) + ($23)|0);
  HEAP8[$24>>0] = 0;
  $25 = (($key_len$1$i) + 2)|0;
  $26 = ($text|0)==(0|0);
  if ($26) {
   $29 = 0;
  } else {
   $27 = (_strlen(($text|0))|0);
   $29 = $27;
  }
  HEAP32[$comp>>2] = $text;
  $28 = (($comp) + 4|0);
  HEAP32[$28>>2] = $29;
  $30 = (($comp) + 8|0);
  HEAP32[$30>>2] = 0;
  $31 = (_png_text_compress($png_ptr,2052348020,$comp,$25)|0);
  $32 = ($31|0)==(0);
  if (!($32)) {
   $33 = (($png_ptr) + 244|0);
   $34 = HEAP32[$33>>2]|0;
   _png_error($png_ptr,$34);
   // unreachable;
  }
  $35 = HEAP32[$30>>2]|0;
  $36 = (($35) + ($25))|0;
  $37 = ($png_ptr|0)==(0|0);
  if (!($37)) {
   $38 = (($png_ptr) + 656|0);
   HEAP32[$38>>2] = 34;
   $39 = $36 >>> 24;
   $40 = $39&255;
   HEAP8[$buf$i1>>0] = $40;
   $41 = $36 >>> 16;
   $42 = $41&255;
   $43 = (($buf$i1) + 1|0);
   HEAP8[$43>>0] = $42;
   $44 = $36 >>> 8;
   $45 = $44&255;
   $46 = (($buf$i1) + 2|0);
   HEAP8[$46>>0] = $45;
   $47 = $36&255;
   $48 = (($buf$i1) + 3|0);
   HEAP8[$48>>0] = $47;
   $49 = (($buf$i1) + 4|0);
   HEAP8[$49>>0] = 122;
   $50 = (($buf$i1) + 5|0);
   HEAP8[$50>>0] = 84;
   $51 = (($buf$i1) + 6|0);
   HEAP8[$51>>0] = 88;
   $52 = (($buf$i1) + 7|0);
   HEAP8[$52>>0] = 116;
   _png_write_data($png_ptr,$buf$i1,8);
   $53 = (($png_ptr) + 372|0);
   HEAP32[$53>>2] = 2052348020;
   _png_reset_crc($png_ptr);
   _png_calculate_crc($png_ptr,$49,4);
   HEAP32[$38>>2] = 66;
   $54 = ($25|0)==(0);
   if (!($54)) {
    _png_write_data($png_ptr,$new_key,$25);
    _png_calculate_crc($png_ptr,$new_key,$25);
   }
  }
  $55 = HEAP32[$30>>2]|0;
  $56 = (($comp) + 12|0);
  $57 = (($png_ptr) + 276|0);
  $58 = (($png_ptr) + 280|0);
  $avail$0$i = 1024;$next$0$in$i = $57;$output$0$i = $56;$output_len$0$i = $55;
  while(1) {
   $next$0$i = HEAP32[$next$0$in$i>>2]|0;
   $59 = ($avail$0$i>>>0)>($output_len$0$i>>>0);
   $output_len$0$avail$0$i = $59 ? $output_len$0$i : $avail$0$i;
   $60 = ($output_len$0$avail$0$i|0)==(0);
   $or$cond1$i$i = $37 | $60;
   if (!($or$cond1$i$i)) {
    _png_write_data($png_ptr,$output$0$i,$output_len$0$avail$0$i);
    _png_calculate_crc($png_ptr,$output$0$i,$output_len$0$avail$0$i);
   }
   $61 = ($output_len$0$i|0)==($output_len$0$avail$0$i|0);
   $62 = ($next$0$i|0)==(0|0);
   $or$cond$i = $61 | $62;
   if ($or$cond$i) {
    break;
   }
   $63 = (($output_len$0$i) - ($output_len$0$avail$0$i))|0;
   $64 = HEAP32[$58>>2]|0;
   $65 = (($next$0$i) + 4|0);
   $avail$0$i = $64;$next$0$in$i = $next$0$i;$output$0$i = $65;$output_len$0$i = $63;
  }
  if (!($61)) {
   _png_error($png_ptr,391944);
   // unreachable;
  }
  if ($37) {
   STACKTOP = sp;return;
  }
  $66 = (($png_ptr) + 656|0);
  HEAP32[$66>>2] = 130;
  $67 = (($png_ptr) + 408|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = $68 >>> 24;
  $70 = $69&255;
  HEAP8[$buf$i>>0] = $70;
  $71 = $68 >>> 16;
  $72 = $71&255;
  $73 = (($buf$i) + 1|0);
  HEAP8[$73>>0] = $72;
  $74 = $68 >>> 8;
  $75 = $74&255;
  $76 = (($buf$i) + 2|0);
  HEAP8[$76>>0] = $75;
  $77 = $68&255;
  $78 = (($buf$i) + 3|0);
  HEAP8[$78>>0] = $77;
  _png_write_data($png_ptr,$buf$i,4);
  STACKTOP = sp;return;
 } else if ((($compression|0) == -1)) {
  _png_write_tEXt($png_ptr,$key,$text,0);
  STACKTOP = sp;return;
 } else {
  _png_error($png_ptr,391712);
  // unreachable;
 }
}
function _png_write_iTXt($png_ptr,$compression,$key,$lang,$lang_key,$text) {
 $png_ptr = $png_ptr|0;
 $compression = $compression|0;
 $key = $key|0;
 $lang = $lang|0;
 $lang_key = $lang_key|0;
 $text = $text|0;
 var $$ = 0, $$0 = 0, $$01$ph$be$i = 0, $$01$ph26$i = 0, $$01$ph42$i = 0, $$02$ph$be$i = 0, $$02$ph41$i = 0, $$0214$us18$i = 0, $$03 = 0, $$1$i = 0, $$15 = 0, $$lang = 0, $$off$us$i = 0, $$off$us19$i = 0, $$pre = 0, $$text = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $avail$0$i = 0, $buf$i = 0, $buf$i4 = 0, $comp = 0;
 var $key_len$0 = 0, $key_len$0$ph$be$i = 0, $key_len$0$ph32$i = 0, $key_len$0$ph47$i = 0, $key_len$1$i = 0, $new_key = 0, $next$0$i = 0, $next$0$in$i = 0, $or$cond$i = 0, $or$cond1$i = 0, $or$cond1$i$i = 0, $or$cond13$i = 0, $or$cond2$us$i = 0, $or$cond2$us20$i = 0, $or$cond3$i = 0, $output$0$i = 0, $output_len$0$avail$0$i = 0, $output_len$0$i = 0, $prefix_len$0 = 0, $prefix_len$1 = 0;
 var $space$0$ph$be$i = 0, $space$0$ph38$i = 0, $space$0$ph53$i = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1136|0;
 $buf$i4 = sp + 1128|0;
 $buf$i = sp + 1120|0;
 $new_key = sp + 1036|0;
 $comp = sp;
 $0 = ($key|0)==(0|0);
 if ($0) {
  HEAP8[$new_key>>0] = 0;
  _png_error($png_ptr,391768);
  // unreachable;
 }
 $1 = HEAP8[$key>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  HEAP8[$new_key>>0] = 0;
  _png_error($png_ptr,391768);
  // unreachable;
 } else {
  $$01$ph42$i = $new_key;$$02$ph41$i = $key;$8 = $1;$key_len$0$ph47$i = 0;$space$0$ph53$i = 1;
 }
 L8: while(1) {
  $6 = ($space$0$ph53$i|0)==(0);
  L10: do {
   if ($6) {
    $7 = (($$02$ph41$i) + 1|0);
    $$off$us$i = (($8) + -33)<<24>>24;
    $9 = ($$off$us$i&255)<(94);
    $10 = ($8&255)>(160);
    $or$cond2$us$i = $9 | $10;
    $$ = $or$cond2$us$i ? $8 : 32;
    $11 = $or$cond2$us$i&1;
    $$15 = $11 ^ 1;
    $$02$ph$be$i = $7;$space$0$ph$be$i = $$15;$storemerge$i = $$;
   } else {
    $$0214$us18$i = $$02$ph41$i;$13 = $8;
    while(1) {
     $12 = (($$0214$us18$i) + 1|0);
     $$off$us19$i = (($13) + -33)<<24>>24;
     $14 = ($$off$us19$i&255)<(94);
     $15 = ($13&255)>(160);
     $or$cond2$us20$i = $14 | $15;
     if ($or$cond2$us20$i) {
      $$02$ph$be$i = $12;$space$0$ph$be$i = 0;$storemerge$i = $13;
      break L10;
     }
     $16 = HEAP8[$12>>0]|0;
     $17 = ($16<<24>>24)==(0);
     if ($17) {
      $$01$ph26$i = $$01$ph42$i;$key_len$0$ph32$i = $key_len$0$ph47$i;$space$0$ph38$i = $space$0$ph53$i;
      break L8;
     } else {
      $$0214$us18$i = $12;$13 = $16;
     }
    }
   }
  } while(0);
  HEAP8[$$01$ph42$i>>0] = $storemerge$i;
  $key_len$0$ph$be$i = (($key_len$0$ph47$i) + 1)|0;
  $$01$ph$be$i = (($$01$ph42$i) + 1|0);
  $3 = HEAP8[$$02$ph$be$i>>0]|0;
  $4 = ($3<<24>>24)!=(0);
  $5 = ($key_len$0$ph$be$i>>>0)<(79);
  $or$cond13$i = $4 & $5;
  if ($or$cond13$i) {
   $$01$ph42$i = $$01$ph$be$i;$$02$ph41$i = $$02$ph$be$i;$8 = $3;$key_len$0$ph47$i = $key_len$0$ph$be$i;$space$0$ph53$i = $space$0$ph$be$i;
  } else {
   $$01$ph26$i = $$01$ph$be$i;$key_len$0$ph32$i = $key_len$0$ph$be$i;$space$0$ph38$i = $space$0$ph$be$i;
   break;
  }
 }
 $18 = ($key_len$0$ph32$i|0)==(0);
 $19 = ($space$0$ph38$i|0)==(0);
 $or$cond3$i = $18 | $19;
 if ($or$cond3$i) {
  $$1$i = $$01$ph26$i;$key_len$1$i = $key_len$0$ph32$i;
 } else {
  $20 = (($key_len$0$ph32$i) + -1)|0;
  $21 = (($$01$ph26$i) + -1|0);
  $$1$i = $21;$key_len$1$i = $20;
 }
 HEAP8[$$1$i>>0] = 0;
 $22 = ($key_len$1$i|0)==(0);
 if ($22) {
  _png_error($png_ptr,391768);
  // unreachable;
 }
 if ((($compression|0) == 2) | (($compression|0) == 0)) {
  $25 = (($key_len$1$i) + 1)|0;
  $26 = (($new_key) + ($25)|0);
  HEAP8[$26>>0] = 1;
  $$0 = 1;$key_len$0 = $25;
 } else if ((($compression|0) == -1) | (($compression|0) == 1)) {
  $23 = (($key_len$1$i) + 1)|0;
  $24 = (($new_key) + ($23)|0);
  HEAP8[$24>>0] = 0;
  $$0 = 0;$key_len$0 = $23;
 } else {
  _png_error($png_ptr,391792);
  // unreachable;
 }
 $27 = (($key_len$0) + 1)|0;
 $28 = (($new_key) + ($27)|0);
 HEAP8[$28>>0] = 0;
 $29 = (($key_len$0) + 2)|0;
 $30 = ($lang|0)==(0|0);
 $$lang = $30 ? 391824 : $lang;
 $31 = (_strlen(($$lang|0))|0);
 $32 = (($31) + 1)|0;
 $33 = ($lang_key|0)==(0|0);
 $$03 = $33 ? 391824 : $lang_key;
 $34 = (_strlen(($$03|0))|0);
 $35 = (($34) + 1)|0;
 $36 = ($text|0)==(0|0);
 $$text = $36 ? 391824 : $text;
 $37 = (2147483645 - ($key_len$0))|0;
 $38 = ($32>>>0)>($37>>>0);
 $39 = (($32) + ($29))|0;
 $prefix_len$0 = $38 ? 2147483647 : $39;
 $40 = (2147483647 - ($prefix_len$0))|0;
 $41 = ($35>>>0)>($40>>>0);
 $42 = (($prefix_len$0) + ($35))|0;
 $prefix_len$1 = $41 ? 2147483647 : $42;
 $43 = (_strlen(($$text|0))|0);
 HEAP32[$comp>>2] = $$text;
 $44 = (($comp) + 4|0);
 HEAP32[$44>>2] = $43;
 $45 = (($comp) + 8|0);
 HEAP32[$45>>2] = 0;
 do {
  if ($$0) {
   $46 = (_png_text_compress($png_ptr,1767135348,$comp,$prefix_len$1)|0);
   $47 = ($46|0)==(0);
   if ($47) {
    $$pre = HEAP32[$45>>2]|0;
    $53 = $$pre;
    break;
   } else {
    $48 = (($png_ptr) + 244|0);
    $49 = HEAP32[$48>>2]|0;
    _png_error($png_ptr,$49);
    // unreachable;
   }
  } else {
   $50 = (2147483647 - ($prefix_len$1))|0;
   $51 = ($43>>>0)>($50>>>0);
   if ($51) {
    _png_error($png_ptr,391832);
    // unreachable;
   } else {
    HEAP32[$45>>2] = $43;
    $53 = $43;
    break;
   }
  }
 } while(0);
 $52 = (($53) + ($prefix_len$1))|0;
 $54 = ($png_ptr|0)==(0|0);
 if (!($54)) {
  $55 = (($png_ptr) + 656|0);
  HEAP32[$55>>2] = 34;
  $56 = $52 >>> 24;
  $57 = $56&255;
  HEAP8[$buf$i4>>0] = $57;
  $58 = $52 >>> 16;
  $59 = $58&255;
  $60 = (($buf$i4) + 1|0);
  HEAP8[$60>>0] = $59;
  $61 = $52 >>> 8;
  $62 = $61&255;
  $63 = (($buf$i4) + 2|0);
  HEAP8[$63>>0] = $62;
  $64 = $52&255;
  $65 = (($buf$i4) + 3|0);
  HEAP8[$65>>0] = $64;
  $66 = (($buf$i4) + 4|0);
  HEAP8[$66>>0] = 105;
  $67 = (($buf$i4) + 5|0);
  HEAP8[$67>>0] = 84;
  $68 = (($buf$i4) + 6|0);
  HEAP8[$68>>0] = 88;
  $69 = (($buf$i4) + 7|0);
  HEAP8[$69>>0] = 116;
  _png_write_data($png_ptr,$buf$i4,8);
  $70 = (($png_ptr) + 372|0);
  HEAP32[$70>>2] = 1767135348;
  _png_reset_crc($png_ptr);
  _png_calculate_crc($png_ptr,$66,4);
  HEAP32[$55>>2] = 66;
  $71 = ($29|0)==(0);
  if (!($71)) {
   _png_write_data($png_ptr,$new_key,$29);
   _png_calculate_crc($png_ptr,$new_key,$29);
  }
  $72 = ($32|0)==(0);
  if (!($72)) {
   _png_write_data($png_ptr,$$lang,$32);
   _png_calculate_crc($png_ptr,$$lang,$32);
  }
  $73 = ($35|0)==(0);
  if (!($73)) {
   _png_write_data($png_ptr,$$03,$35);
   _png_calculate_crc($png_ptr,$$03,$35);
  }
 }
 if ($$0) {
  $74 = HEAP32[$45>>2]|0;
  $75 = (($comp) + 12|0);
  $76 = (($png_ptr) + 276|0);
  $77 = (($png_ptr) + 280|0);
  $avail$0$i = 1024;$next$0$in$i = $76;$output$0$i = $75;$output_len$0$i = $74;
  while(1) {
   $next$0$i = HEAP32[$next$0$in$i>>2]|0;
   $78 = ($avail$0$i>>>0)>($output_len$0$i>>>0);
   $output_len$0$avail$0$i = $78 ? $output_len$0$i : $avail$0$i;
   $79 = ($output_len$0$avail$0$i|0)==(0);
   $or$cond1$i$i = $54 | $79;
   if (!($or$cond1$i$i)) {
    _png_write_data($png_ptr,$output$0$i,$output_len$0$avail$0$i);
    _png_calculate_crc($png_ptr,$output$0$i,$output_len$0$avail$0$i);
   }
   $80 = ($output_len$0$i|0)==($output_len$0$avail$0$i|0);
   $81 = ($next$0$i|0)==(0|0);
   $or$cond$i = $80 | $81;
   if ($or$cond$i) {
    break;
   }
   $82 = (($output_len$0$i) - ($output_len$0$avail$0$i))|0;
   $83 = HEAP32[$77>>2]|0;
   $84 = (($next$0$i) + 4|0);
   $avail$0$i = $83;$next$0$in$i = $next$0$i;$output$0$i = $84;$output_len$0$i = $82;
  }
  if (!($80)) {
   _png_error($png_ptr,391944);
   // unreachable;
  }
 } else {
  $85 = HEAP32[$44>>2]|0;
  $86 = ($85|0)==(0);
  $or$cond1$i = $54 | $86;
  if (!($or$cond1$i)) {
   _png_write_data($png_ptr,$$text,$85);
   _png_calculate_crc($png_ptr,$$text,$85);
  }
 }
 if ($54) {
  STACKTOP = sp;return;
 }
 $87 = (($png_ptr) + 656|0);
 HEAP32[$87>>2] = 130;
 $88 = (($png_ptr) + 408|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = $89 >>> 24;
 $91 = $90&255;
 HEAP8[$buf$i>>0] = $91;
 $92 = $89 >>> 16;
 $93 = $92&255;
 $94 = (($buf$i) + 1|0);
 HEAP8[$94>>0] = $93;
 $95 = $89 >>> 8;
 $96 = $95&255;
 $97 = (($buf$i) + 2|0);
 HEAP8[$97>>0] = $96;
 $98 = $89&255;
 $99 = (($buf$i) + 3|0);
 HEAP8[$99>>0] = $98;
 _png_write_data($png_ptr,$buf$i,4);
 STACKTOP = sp;return;
}
function _png_write_oFFs($png_ptr,$x_offset,$y_offset,$unit_type) {
 $png_ptr = $png_ptr|0;
 $x_offset = $x_offset|0;
 $y_offset = $y_offset|0;
 $unit_type = $unit_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $buf$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $buf$i1 = sp + 16|0;
 $buf = sp;
 _png_save_int_32($buf,$x_offset);
 $0 = (($buf) + 4|0);
 _png_save_int_32($0,$y_offset);
 $1 = $unit_type&255;
 $2 = (($buf) + 8|0);
 HEAP8[$2>>0] = $1;
 $3 = ($png_ptr|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($png_ptr) + 656|0);
 HEAP32[$4>>2] = 34;
 HEAP8[$buf$i1>>0] = 0;
 $5 = (($buf$i1) + 1|0);
 HEAP8[$5>>0] = 0;
 $6 = (($buf$i1) + 2|0);
 HEAP8[$6>>0] = 0;
 $7 = (($buf$i1) + 3|0);
 HEAP8[$7>>0] = 9;
 $8 = (($buf$i1) + 4|0);
 HEAP8[$8>>0] = 111;
 $9 = (($buf$i1) + 5|0);
 HEAP8[$9>>0] = 70;
 $10 = (($buf$i1) + 6|0);
 HEAP8[$10>>0] = 70;
 $11 = (($buf$i1) + 7|0);
 HEAP8[$11>>0] = 115;
 _png_write_data($png_ptr,$buf$i1,8);
 $12 = (($png_ptr) + 372|0);
 HEAP32[$12>>2] = 1866876531;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$8,4);
 HEAP32[$4>>2] = 66;
 _png_write_data($png_ptr,$buf,9);
 _png_calculate_crc($png_ptr,$buf,9);
 HEAP32[$4>>2] = 130;
 $13 = (($png_ptr) + 408|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 >>> 24;
 $16 = $15&255;
 HEAP8[$buf$i1>>0] = $16;
 $17 = $14 >>> 16;
 $18 = $17&255;
 $19 = (($buf$i1) + 1|0);
 HEAP8[$19>>0] = $18;
 $20 = $14 >>> 8;
 $21 = $20&255;
 $22 = (($buf$i1) + 2|0);
 HEAP8[$22>>0] = $21;
 $23 = $14&255;
 $24 = (($buf$i1) + 3|0);
 HEAP8[$24>>0] = $23;
 _png_write_data($png_ptr,$buf$i1,4);
 STACKTOP = sp;return;
}
function _png_write_pCAL($png_ptr,$purpose,$X0,$X1,$type,$nparams,$units,$params) {
 $png_ptr = $png_ptr|0;
 $purpose = $purpose|0;
 $X0 = $X0|0;
 $X1 = $X1|0;
 $type = $type|0;
 $nparams = $nparams|0;
 $units = $units|0;
 $params = $params|0;
 var $$ = 0, $$01$ph$be$i = 0, $$01$ph26$i = 0, $$01$ph42$i = 0, $$02$ph$be$i = 0, $$02$ph41$i = 0, $$0214$us18$i = 0, $$1$i = 0, $$13 = 0, $$off$us$i = 0, $$off$us19$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $buf = 0, $buf$i = 0;
 var $buf$i2 = 0, $exitcond = 0, $exitcond25 = 0, $i$016 = 0, $i$114 = 0, $key_len$0$ph$be$i = 0, $key_len$0$ph32$i = 0, $key_len$0$ph47$i = 0, $key_len$1$i = 0, $new_purpose = 0, $not$ = 0, $not$1 = 0, $or$cond$i6 = 0, $or$cond1$i4 = 0, $or$cond1$i7 = 0, $or$cond13$i = 0, $or$cond2$us$i = 0, $or$cond2$us20$i = 0, $or$cond3$i = 0, $space$0$ph$be$i = 0;
 var $space$0$ph38$i = 0, $space$0$ph53$i = 0, $storemerge$i = 0, $total_len$0$lcssa = 0, $total_len$015 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $buf$i2 = sp + 96|0;
 $buf$i = sp;
 $buf = sp + 4|0;
 $new_purpose = sp + 16|0;
 $0 = ($type|0)>(3);
 if ($0) {
  _png_error($png_ptr,391872);
  // unreachable;
 }
 $1 = ($purpose|0)==(0|0);
 if ($1) {
  HEAP8[$new_purpose>>0] = 0;
  _png_error($png_ptr,391920);
  // unreachable;
 }
 $2 = HEAP8[$purpose>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  HEAP8[$new_purpose>>0] = 0;
  _png_error($png_ptr,391920);
  // unreachable;
 } else {
  $$01$ph42$i = $new_purpose;$$02$ph41$i = $purpose;$9 = $2;$key_len$0$ph47$i = 0;$space$0$ph53$i = 1;
 }
 L11: while(1) {
  $7 = ($space$0$ph53$i|0)==(0);
  L13: do {
   if ($7) {
    $8 = (($$02$ph41$i) + 1|0);
    $$off$us$i = (($9) + -33)<<24>>24;
    $10 = ($$off$us$i&255)<(94);
    $11 = ($9&255)>(160);
    $or$cond2$us$i = $10 | $11;
    $$ = $or$cond2$us$i ? $9 : 32;
    $12 = $or$cond2$us$i&1;
    $$13 = $12 ^ 1;
    $$02$ph$be$i = $8;$space$0$ph$be$i = $$13;$storemerge$i = $$;
   } else {
    $$0214$us18$i = $$02$ph41$i;$14 = $9;
    while(1) {
     $13 = (($$0214$us18$i) + 1|0);
     $$off$us19$i = (($14) + -33)<<24>>24;
     $15 = ($$off$us19$i&255)<(94);
     $16 = ($14&255)>(160);
     $or$cond2$us20$i = $15 | $16;
     if ($or$cond2$us20$i) {
      $$02$ph$be$i = $13;$space$0$ph$be$i = 0;$storemerge$i = $14;
      break L13;
     }
     $17 = HEAP8[$13>>0]|0;
     $18 = ($17<<24>>24)==(0);
     if ($18) {
      $$01$ph26$i = $$01$ph42$i;$key_len$0$ph32$i = $key_len$0$ph47$i;$space$0$ph38$i = $space$0$ph53$i;
      break L11;
     } else {
      $$0214$us18$i = $13;$14 = $17;
     }
    }
   }
  } while(0);
  HEAP8[$$01$ph42$i>>0] = $storemerge$i;
  $key_len$0$ph$be$i = (($key_len$0$ph47$i) + 1)|0;
  $$01$ph$be$i = (($$01$ph42$i) + 1|0);
  $4 = HEAP8[$$02$ph$be$i>>0]|0;
  $5 = ($4<<24>>24)!=(0);
  $6 = ($key_len$0$ph$be$i>>>0)<(79);
  $or$cond13$i = $5 & $6;
  if ($or$cond13$i) {
   $$01$ph42$i = $$01$ph$be$i;$$02$ph41$i = $$02$ph$be$i;$9 = $4;$key_len$0$ph47$i = $key_len$0$ph$be$i;$space$0$ph53$i = $space$0$ph$be$i;
  } else {
   $$01$ph26$i = $$01$ph$be$i;$key_len$0$ph32$i = $key_len$0$ph$be$i;$space$0$ph38$i = $space$0$ph$be$i;
   break;
  }
 }
 $19 = ($key_len$0$ph32$i|0)==(0);
 $20 = ($space$0$ph38$i|0)==(0);
 $or$cond3$i = $19 | $20;
 if ($or$cond3$i) {
  $$1$i = $$01$ph26$i;$key_len$1$i = $key_len$0$ph32$i;
 } else {
  $21 = (($key_len$0$ph32$i) + -1)|0;
  $22 = (($$01$ph26$i) + -1|0);
  $$1$i = $22;$key_len$1$i = $21;
 }
 HEAP8[$$1$i>>0] = 0;
 $23 = ($key_len$1$i|0)==(0);
 if ($23) {
  _png_error($png_ptr,391920);
  // unreachable;
 }
 $24 = (($key_len$1$i) + 1)|0;
 $25 = (_strlen(($units|0))|0);
 $not$ = ($nparams|0)!=(0);
 $26 = $not$&1;
 $27 = (($25) + ($26))|0;
 $28 = (($key_len$1$i) + 11)|0;
 $29 = (($28) + ($27))|0;
 $30 = $nparams << 2;
 $31 = (_png_malloc($png_ptr,$30)|0);
 $32 = ($nparams|0)>(0);
 if ($32) {
  $33 = (($nparams) + -1)|0;
  $i$016 = 0;$total_len$015 = $29;
  while(1) {
   $34 = (($params) + ($i$016<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (_strlen(($35|0))|0);
   $not$1 = ($i$016|0)!=($33|0);
   $37 = $not$1&1;
   $38 = (($36) + ($37))|0;
   $39 = (($31) + ($i$016<<2)|0);
   HEAP32[$39>>2] = $38;
   $40 = (($38) + ($total_len$015))|0;
   $41 = (($i$016) + 1)|0;
   $exitcond25 = ($41|0)==($nparams|0);
   if ($exitcond25) {
    $total_len$0$lcssa = $40;
    break;
   } else {
    $i$016 = $41;$total_len$015 = $40;
   }
  }
 } else {
  $total_len$0$lcssa = $29;
 }
 $42 = ($png_ptr|0)==(0|0);
 if (!($42)) {
  $43 = (($png_ptr) + 656|0);
  HEAP32[$43>>2] = 34;
  $44 = $total_len$0$lcssa >>> 24;
  $45 = $44&255;
  HEAP8[$buf$i2>>0] = $45;
  $46 = $total_len$0$lcssa >>> 16;
  $47 = $46&255;
  $48 = (($buf$i2) + 1|0);
  HEAP8[$48>>0] = $47;
  $49 = $total_len$0$lcssa >>> 8;
  $50 = $49&255;
  $51 = (($buf$i2) + 2|0);
  HEAP8[$51>>0] = $50;
  $52 = $total_len$0$lcssa&255;
  $53 = (($buf$i2) + 3|0);
  HEAP8[$53>>0] = $52;
  $54 = (($buf$i2) + 4|0);
  HEAP8[$54>>0] = 112;
  $55 = (($buf$i2) + 5|0);
  HEAP8[$55>>0] = 67;
  $56 = (($buf$i2) + 6|0);
  HEAP8[$56>>0] = 65;
  $57 = (($buf$i2) + 7|0);
  HEAP8[$57>>0] = 76;
  _png_write_data($png_ptr,$buf$i2,8);
  $58 = (($png_ptr) + 372|0);
  HEAP32[$58>>2] = 1883455820;
  _png_reset_crc($png_ptr);
  _png_calculate_crc($png_ptr,$54,4);
  HEAP32[$43>>2] = 66;
  $59 = ($24|0)==(0);
  if (!($59)) {
   _png_write_data($png_ptr,$new_purpose,$24);
   _png_calculate_crc($png_ptr,$new_purpose,$24);
  }
 }
 _png_save_int_32($buf,$X0);
 $60 = (($buf) + 4|0);
 _png_save_int_32($60,$X1);
 $61 = $type&255;
 $62 = (($buf) + 8|0);
 HEAP8[$62>>0] = $61;
 $63 = $nparams&255;
 $64 = (($buf) + 9|0);
 HEAP8[$64>>0] = $63;
 if (!($42)) {
  _png_write_data($png_ptr,$buf,10);
  _png_calculate_crc($png_ptr,$buf,10);
  $65 = ($units|0)==(0|0);
  $66 = ($27|0)==(0);
  $or$cond1$i4 = $65 | $66;
  if (!($or$cond1$i4)) {
   _png_write_data($png_ptr,$units,$27);
   _png_calculate_crc($png_ptr,$units,$27);
  }
 }
 if ($32) {
  $i$114 = 0;
  while(1) {
   $67 = (($params) + ($i$114<<2)|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (($31) + ($i$114<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($68|0)==(0|0);
   $or$cond$i6 = $42 | $71;
   $72 = ($70|0)==(0);
   $or$cond1$i7 = $or$cond$i6 | $72;
   if (!($or$cond1$i7)) {
    _png_write_data($png_ptr,$68,$70);
    _png_calculate_crc($png_ptr,$68,$70);
   }
   $73 = (($i$114) + 1)|0;
   $exitcond = ($73|0)==($nparams|0);
   if ($exitcond) {
    break;
   } else {
    $i$114 = $73;
   }
  }
 }
 _png_free($png_ptr,$31);
 if ($42) {
  STACKTOP = sp;return;
 }
 $74 = (($png_ptr) + 656|0);
 HEAP32[$74>>2] = 130;
 $75 = (($png_ptr) + 408|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = $76 >>> 24;
 $78 = $77&255;
 HEAP8[$buf$i>>0] = $78;
 $79 = $76 >>> 16;
 $80 = $79&255;
 $81 = (($buf$i) + 1|0);
 HEAP8[$81>>0] = $80;
 $82 = $76 >>> 8;
 $83 = $82&255;
 $84 = (($buf$i) + 2|0);
 HEAP8[$84>>0] = $83;
 $85 = $76&255;
 $86 = (($buf$i) + 3|0);
 HEAP8[$86>>0] = $85;
 _png_write_data($png_ptr,$buf$i,4);
 STACKTOP = sp;return;
}
function _png_write_sCAL_s($png_ptr,$unit,$width,$height) {
 $png_ptr = $png_ptr|0;
 $unit = $unit|0;
 $width = $width|0;
 $height = $height|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $buf = 0, $buf$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $buf$i1 = sp + 64|0;
 $buf = sp;
 $0 = (_strlen(($width|0))|0);
 $1 = (_strlen(($height|0))|0);
 $2 = (($0) + 2)|0;
 $3 = (($2) + ($1))|0;
 $4 = ($3>>>0)>(64);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $unit&255;
 HEAP8[$buf>>0] = $5;
 $6 = (($buf) + 1|0);
 $7 = (($0) + 1)|0;
 _memcpy(($6|0),($width|0),($7|0))|0;
 $8 = (($buf) + ($2)|0);
 _memcpy(($8|0),($height|0),($1|0))|0;
 $9 = ($png_ptr|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($3|0)<(0);
 if ($10) {
  _png_error($png_ptr,392064);
  // unreachable;
 }
 $11 = (($png_ptr) + 656|0);
 HEAP32[$11>>2] = 34;
 $12 = $3 >>> 24;
 $13 = $12&255;
 HEAP8[$buf$i1>>0] = $13;
 $14 = $3 >>> 16;
 $15 = $14&255;
 $16 = (($buf$i1) + 1|0);
 HEAP8[$16>>0] = $15;
 $17 = $3 >>> 8;
 $18 = $17&255;
 $19 = (($buf$i1) + 2|0);
 HEAP8[$19>>0] = $18;
 $20 = $3&255;
 $21 = (($buf$i1) + 3|0);
 HEAP8[$21>>0] = $20;
 $22 = (($buf$i1) + 4|0);
 HEAP8[$22>>0] = 115;
 $23 = (($buf$i1) + 5|0);
 HEAP8[$23>>0] = 67;
 $24 = (($buf$i1) + 6|0);
 HEAP8[$24>>0] = 65;
 $25 = (($buf$i1) + 7|0);
 HEAP8[$25>>0] = 76;
 _png_write_data($png_ptr,$buf$i1,8);
 $26 = (($png_ptr) + 372|0);
 HEAP32[$26>>2] = 1933787468;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$22,4);
 HEAP32[$11>>2] = 66;
 $27 = ($3|0)==(0);
 if (!($27)) {
  _png_write_data($png_ptr,$buf,$3);
  _png_calculate_crc($png_ptr,$buf,$3);
 }
 HEAP32[$11>>2] = 130;
 $28 = (($png_ptr) + 408|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = $29 >>> 24;
 $31 = $30&255;
 HEAP8[$buf$i1>>0] = $31;
 $32 = $29 >>> 16;
 $33 = $32&255;
 $34 = (($buf$i1) + 1|0);
 HEAP8[$34>>0] = $33;
 $35 = $29 >>> 8;
 $36 = $35&255;
 $37 = (($buf$i1) + 2|0);
 HEAP8[$37>>0] = $36;
 $38 = $29&255;
 $39 = (($buf$i1) + 3|0);
 HEAP8[$39>>0] = $38;
 _png_write_data($png_ptr,$buf$i1,4);
 STACKTOP = sp;return;
}
function _png_write_pHYs($png_ptr,$x_pixels_per_unit,$y_pixels_per_unit,$unit_type) {
 $png_ptr = $png_ptr|0;
 $x_pixels_per_unit = $x_pixels_per_unit|0;
 $y_pixels_per_unit = $y_pixels_per_unit|0;
 $unit_type = $unit_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $buf$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $buf$i1 = sp + 16|0;
 $buf = sp;
 $0 = $x_pixels_per_unit >>> 24;
 $1 = $0&255;
 HEAP8[$buf>>0] = $1;
 $2 = $x_pixels_per_unit >>> 16;
 $3 = $2&255;
 $4 = (($buf) + 1|0);
 HEAP8[$4>>0] = $3;
 $5 = $x_pixels_per_unit >>> 8;
 $6 = $5&255;
 $7 = (($buf) + 2|0);
 HEAP8[$7>>0] = $6;
 $8 = $x_pixels_per_unit&255;
 $9 = (($buf) + 3|0);
 HEAP8[$9>>0] = $8;
 $10 = (($buf) + 4|0);
 $11 = $y_pixels_per_unit >>> 24;
 $12 = $11&255;
 HEAP8[$10>>0] = $12;
 $13 = $y_pixels_per_unit >>> 16;
 $14 = $13&255;
 $15 = (($buf) + 5|0);
 HEAP8[$15>>0] = $14;
 $16 = $y_pixels_per_unit >>> 8;
 $17 = $16&255;
 $18 = (($buf) + 6|0);
 HEAP8[$18>>0] = $17;
 $19 = $y_pixels_per_unit&255;
 $20 = (($buf) + 7|0);
 HEAP8[$20>>0] = $19;
 $21 = $unit_type&255;
 $22 = (($buf) + 8|0);
 HEAP8[$22>>0] = $21;
 $23 = ($png_ptr|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($png_ptr) + 656|0);
 HEAP32[$24>>2] = 34;
 HEAP8[$buf$i1>>0] = 0;
 $25 = (($buf$i1) + 1|0);
 HEAP8[$25>>0] = 0;
 $26 = (($buf$i1) + 2|0);
 HEAP8[$26>>0] = 0;
 $27 = (($buf$i1) + 3|0);
 HEAP8[$27>>0] = 9;
 $28 = (($buf$i1) + 4|0);
 HEAP8[$28>>0] = 112;
 $29 = (($buf$i1) + 5|0);
 HEAP8[$29>>0] = 72;
 $30 = (($buf$i1) + 6|0);
 HEAP8[$30>>0] = 89;
 $31 = (($buf$i1) + 7|0);
 HEAP8[$31>>0] = 115;
 _png_write_data($png_ptr,$buf$i1,8);
 $32 = (($png_ptr) + 372|0);
 HEAP32[$32>>2] = 1883789683;
 _png_reset_crc($png_ptr);
 _png_calculate_crc($png_ptr,$28,4);
 HEAP32[$24>>2] = 66;
 _png_write_data($png_ptr,$buf,9);
 _png_calculate_crc($png_ptr,$buf,9);
 HEAP32[$24>>2] = 130;
 $33 = (($png_ptr) + 408|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 >>> 24;
 $36 = $35&255;
 HEAP8[$buf$i1>>0] = $36;
 $37 = $34 >>> 16;
 $38 = $37&255;
 $39 = (($buf$i1) + 1|0);
 HEAP8[$39>>0] = $38;
 $40 = $34 >>> 8;
 $41 = $40&255;
 $42 = (($buf$i1) + 2|0);
 HEAP8[$42>>0] = $41;
 $43 = $34&255;
 $44 = (($buf$i1) + 3|0);
 HEAP8[$44>>0] = $43;
 _png_write_data($png_ptr,$buf$i1,4);
 STACKTOP = sp;return;
}
function _png_write_start_row($png_ptr) {
 $png_ptr = $png_ptr|0;
 var $$pr = 0, $$pr1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 436|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = (($png_ptr) + 433|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = Math_imul($5, $2)|0;
 $7 = ($6>>>0)>(7);
 $8 = (($png_ptr) + 344|0);
 $9 = HEAP32[$8>>2]|0;
 if ($7) {
  $10 = $6 >>> 3;
  $11 = Math_imul($10, $9)|0;
  $16 = $11;
 } else {
  $12 = Math_imul($6, $9)|0;
  $13 = (($12) + 7)|0;
  $14 = $13 >>> 3;
  $16 = $14;
 }
 $15 = (($16) + 1)|0;
 $17 = (($png_ptr) + 434|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = (($png_ptr) + 439|0);
 HEAP8[$19>>0] = $18;
 $20 = $6&255;
 $21 = (($png_ptr) + 438|0);
 HEAP8[$21>>0] = $20;
 $22 = (_png_malloc($png_ptr,$15)|0);
 $23 = (($png_ptr) + 380|0);
 HEAP32[$23>>2] = $22;
 HEAP8[$22>>0] = 0;
 $24 = (($png_ptr) + 430|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25 & 16;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $34 = $25;
 } else {
  $28 = (($png_ptr) + 360|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 1)|0;
  $31 = (_png_malloc($png_ptr,$30)|0);
  $32 = (($png_ptr) + 384|0);
  HEAP32[$32>>2] = $31;
  HEAP8[$31>>0] = 1;
  $$pr = HEAP8[$24>>0]|0;
  $34 = $$pr;
 }
 $33 = ($34&255)>(31);
 if ($33) {
  $35 = (_png_calloc($png_ptr,$15)|0);
  $36 = (($png_ptr) + 376|0);
  HEAP32[$36>>2] = $35;
  $37 = HEAP8[$24>>0]|0;
  $38 = $37 & 32;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $46 = $37;
  } else {
   $40 = (($png_ptr) + 360|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 1)|0;
   $43 = (_png_malloc($png_ptr,$42)|0);
   $44 = (($png_ptr) + 388|0);
   HEAP32[$44>>2] = $43;
   HEAP8[$43>>0] = 2;
   $$pre = HEAP8[$24>>0]|0;
   $46 = $$pre;
  }
  $45 = $46 & 64;
  $47 = ($45<<24>>24)==(0);
  if ($47) {
   $54 = $46;
  } else {
   $48 = (($png_ptr) + 360|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + 1)|0;
   $51 = (_png_malloc($png_ptr,$50)|0);
   $52 = (($png_ptr) + 392|0);
   HEAP32[$52>>2] = $51;
   HEAP8[$51>>0] = 3;
   $$pr1 = HEAP8[$24>>0]|0;
   $54 = $$pr1;
  }
  $53 = ($54<<24>>24)<(0);
  if ($53) {
   $55 = (($png_ptr) + 360|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 1)|0;
   $58 = (_png_malloc($png_ptr,$57)|0);
   $59 = (($png_ptr) + 396|0);
   HEAP32[$59>>2] = $58;
   HEAP8[$58>>0] = 4;
  }
 }
 $60 = (($png_ptr) + 348|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($png_ptr) + 352|0);
 HEAP32[$62>>2] = $61;
 $63 = HEAP32[$8>>2]|0;
 $64 = (($png_ptr) + 356|0);
 HEAP32[$64>>2] = $63;
 STACKTOP = sp;return;
}
function _png_write_find_filter($png_ptr,$row_info) {
 $png_ptr = $png_ptr|0;
 $row_info = $row_info|0;
 var $$ = 0, $$pn = 0, $$pn171 = 0, $$pn172 = 0, $$pn173 = 0, $$pn174 = 0, $$pn175 = 0, $$pn176 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $best_row$0 = 0, $best_row$1 = 0, $best_row$2 = 0, $best_row$3 = 0, $cp$021 = 0, $cp40$038 = 0, $dp$0 = 0, $dp$0$lcssa = 0, $dp$0134 = 0, $dp$0137 = 0, $dp$1129 = 0, $dp10$0109 = 0, $dp13$0120 = 0, $dp20$0 = 0, $dp20$0$lcssa = 0, $dp20$068 = 0, $dp20$072 = 0;
 var $dp20$161 = 0, $dp25$0 = 0, $dp25$0$lcssa = 0, $dp25$091 = 0, $dp25$096 = 0, $dp25$181 = 0, $dp33$0 = 0, $dp33$0$lcssa = 0, $dp33$024 = 0, $dp33$028 = 0, $dp33$119 = 0, $dp38$0 = 0, $dp38$0$lcssa = 0, $dp38$046 = 0, $dp38$051 = 0, $dp38$136 = 0, $dp4$0 = 0, $dp4$0$lcssa = 0, $dp4$0153 = 0, $dp4$0157 = 0;
 var $dp4$1147 = 0, $exitcond = 0, $exitcond191 = 0, $exitcond209 = 0, $exitcond212 = 0, $exitcond229 = 0, $i$0166 = 0, $i11$0107 = 0, $i17$0118 = 0, $i2$0$lcssa = 0, $i2$0135 = 0, $i2$1128 = 0, $i23$0$lcssa = 0, $i23$070 = 0, $i23$164 = 0, $i30$0$lcssa = 0, $i30$094 = 0, $i30$185 = 0, $i36$0$lcssa = 0, $i36$027 = 0;
 var $i36$123 = 0, $i44$0$lcssa = 0, $i44$050 = 0, $i44$141 = 0, $i7$0$lcssa = 0, $i7$0154 = 0, $i7$1144 = 0, $lp$0130 = 0, $lp22$063 = 0, $lp27$083 = 0, $lp35$022 = 0, $lp41$039 = 0, $lp5$0146 = 0, $mins$0 = 0, $mins$1 = 0, $mins$2 = 0, $mins$3 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond15 = 0;
 var $or$cond16 = 0, $or$cond17 = 0, $or$cond232 = 0, $pp$0108 = 0, $pp14$0119 = 0, $pp21$0 = 0, $pp21$0$lcssa = 0, $pp21$067 = 0, $pp21$071 = 0, $pp21$162 = 0, $pp26$0 = 0, $pp26$0$lcssa = 0, $pp26$090 = 0, $pp26$095 = 0, $pp26$182 = 0, $pp34$0$lcssa = 0, $pp34$026 = 0, $pp34$120 = 0, $pp39$0$lcssa = 0, $pp39$048 = 0;
 var $pp39$137 = 0, $rp$0168 = 0, $rp1$0$lcssa = 0, $rp1$0136 = 0, $rp1$1131 = 0, $rp12$0121 = 0, $rp19$0$lcssa = 0, $rp19$069 = 0, $rp19$160 = 0, $rp24$0$lcssa = 0, $rp24$092 = 0, $rp24$180 = 0, $rp3$0$lcssa = 0, $rp3$0156 = 0, $rp3$1148 = 0, $rp32$0$lcssa = 0, $rp32$025 = 0, $rp32$118 = 0, $rp37$0$lcssa = 0, $rp37$047 = 0;
 var $rp37$135 = 0, $rp9$0110 = 0, $scevgep = 0, $scevgep180 = 0, $scevgep181 = 0, $scevgep188 = 0, $scevgep189 = 0, $scevgep190 = 0, $scevgep196 = 0, $scevgep197 = 0, $scevgep198 = 0, $scevgep206 = 0, $scevgep207 = 0, $scevgep208 = 0, $scevgep216 = 0, $scevgep217 = 0, $scevgep225 = 0, $scevgep226 = 0, $sum$0167 = 0, $sum15$0117 = 0;
 var $sum15$1 = 0, $sum28$0$lcssa = 0, $sum28$093 = 0, $sum28$184 = 0, $sum28$2 = 0, $sum42$0$lcssa = 0, $sum42$049 = 0, $sum42$140 = 0, $sum42$2 = 0, $sum6$0$lcssa = 0, $sum6$0155 = 0, $sum6$1145 = 0, $sum6$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($png_ptr) + 430|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = (($row_info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($png_ptr) + 368|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 $7 = ($1<<24>>24)==(-8);
 $or$cond = $6 & $7;
 $$ = $or$cond ? 88 : $1;
 $8 = (($row_info) + 11|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = (($10) + 7)|0;
 $12 = $11 >>> 3;
 $13 = (($png_ptr) + 376|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($png_ptr) + 380|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $$&255;
 $18 = $17 & 8;
 $19 = ($18|0)==(0);
 $20 = ($$<<24>>24)==(8);
 $or$cond15 = $19 | $20;
 if ($or$cond15) {
  $mins$0 = 2147483647;
 } else {
  $21 = ($3|0)==(0);
  if ($21) {
   $mins$0 = 0;
  } else {
   $$pn176 = $16;$i$0166 = 0;$sum$0167 = 0;
   while(1) {
    $rp$0168 = (($$pn176) + 1|0);
    $22 = HEAP8[$rp$0168>>0]|0;
    $23 = $22&255;
    $24 = ($22<<24>>24)>(-1);
    $25 = (256 - ($23))|0;
    $26 = $24 ? $23 : $25;
    $27 = (($26) + ($sum$0167))|0;
    $28 = (($i$0166) + 1)|0;
    $exitcond229 = ($28|0)==($3|0);
    if ($exitcond229) {
     $mins$0 = $27;
     break;
    } else {
     $$pn176 = $rp$0168;$i$0166 = $28;$sum$0167 = $27;
    }
   }
  }
 }
 $29 = ($$<<24>>24)==(16);
 if ($29) {
  $30 = (($16) + 1|0);
  $31 = (($png_ptr) + 384|0);
  $32 = HEAP32[$31>>2]|0;
  $dp$0134 = (($32) + 1|0);
  $33 = ($12|0)==(0);
  if ($33) {
   $dp$0$lcssa = $dp$0134;$i2$0$lcssa = 0;$rp1$0$lcssa = $30;
  } else {
   $34 = (($12) + 1)|0;
   $scevgep216 = (($32) + ($34)|0);
   $dp$0137 = $dp$0134;$i2$0135 = 0;$rp1$0136 = $30;
   while(1) {
    $36 = HEAP8[$rp1$0136>>0]|0;
    HEAP8[$dp$0137>>0] = $36;
    $37 = (($i2$0135) + 1)|0;
    $38 = (($rp1$0136) + 1|0);
    $dp$0 = (($dp$0137) + 1|0);
    $39 = ($37>>>0)<($12>>>0);
    if ($39) {
     $dp$0137 = $dp$0;$i2$0135 = $37;$rp1$0136 = $38;
    } else {
     break;
    }
   }
   $scevgep217 = (($16) + ($34)|0);
   $dp$0$lcssa = $scevgep216;$i2$0$lcssa = $12;$rp1$0$lcssa = $scevgep217;
  }
  $35 = ($i2$0$lcssa>>>0)<($3>>>0);
  if ($35) {
   $dp$1129 = $dp$0$lcssa;$i2$1128 = $i2$0$lcssa;$lp$0130 = $30;$rp1$1131 = $rp1$0$lcssa;
   while(1) {
    $40 = HEAP8[$rp1$1131>>0]|0;
    $41 = $40&255;
    $42 = HEAP8[$lp$0130>>0]|0;
    $43 = $42&255;
    $44 = (($41) - ($43))|0;
    $45 = $44&255;
    HEAP8[$dp$1129>>0] = $45;
    $46 = (($i2$1128) + 1)|0;
    $47 = (($rp1$1131) + 1|0);
    $48 = (($lp$0130) + 1|0);
    $49 = (($dp$1129) + 1|0);
    $exitcond212 = ($46|0)==($3|0);
    if ($exitcond212) {
     break;
    } else {
     $dp$1129 = $49;$i2$1128 = $46;$lp$0130 = $48;$rp1$1131 = $47;
    }
   }
  }
  $50 = HEAP32[$31>>2]|0;
  $best_row$0 = $50;$mins$1 = $mins$0;
 } else {
  $51 = $17 & 16;
  $52 = ($51|0)==(0);
  if ($52) {
   $best_row$0 = $16;$mins$1 = $mins$0;
  } else {
   $53 = (($16) + 1|0);
   $54 = (($png_ptr) + 384|0);
   $55 = HEAP32[$54>>2]|0;
   $dp4$0153 = (($55) + 1|0);
   $56 = ($12|0)==(0);
   if ($56) {
    $dp4$0$lcssa = $dp4$0153;$i7$0$lcssa = 0;$rp3$0$lcssa = $53;$sum6$0$lcssa = 0;
   } else {
    $57 = (($12) + 1)|0;
    $scevgep225 = (($55) + ($57)|0);
    $dp4$0157 = $dp4$0153;$i7$0154 = 0;$rp3$0156 = $53;$sum6$0155 = 0;
    while(1) {
     $59 = HEAP8[$rp3$0156>>0]|0;
     HEAP8[$dp4$0157>>0] = $59;
     $60 = $59&255;
     $61 = ($59<<24>>24)>(-1);
     $62 = (256 - ($60))|0;
     $63 = $61 ? $60 : $62;
     $64 = (($63) + ($sum6$0155))|0;
     $65 = (($i7$0154) + 1)|0;
     $66 = (($rp3$0156) + 1|0);
     $dp4$0 = (($dp4$0157) + 1|0);
     $67 = ($65>>>0)<($12>>>0);
     if ($67) {
      $dp4$0157 = $dp4$0;$i7$0154 = $65;$rp3$0156 = $66;$sum6$0155 = $64;
     } else {
      break;
     }
    }
    $scevgep226 = (($16) + ($57)|0);
    $dp4$0$lcssa = $scevgep225;$i7$0$lcssa = $12;$rp3$0$lcssa = $scevgep226;$sum6$0$lcssa = $64;
   }
   $58 = ($i7$0$lcssa>>>0)<($3>>>0);
   L26: do {
    if ($58) {
     $dp4$1147 = $dp4$0$lcssa;$i7$1144 = $i7$0$lcssa;$lp5$0146 = $53;$rp3$1148 = $rp3$0$lcssa;$sum6$1145 = $sum6$0$lcssa;
     while(1) {
      $68 = HEAP8[$rp3$1148>>0]|0;
      $69 = $68&255;
      $70 = HEAP8[$lp5$0146>>0]|0;
      $71 = $70&255;
      $72 = (($69) - ($71))|0;
      $73 = $72&255;
      HEAP8[$dp4$1147>>0] = $73;
      $74 = $72 & 255;
      $75 = ($74>>>0)<(128);
      $76 = (256 - ($74))|0;
      $77 = $75 ? $74 : $76;
      $78 = (($77) + ($sum6$1145))|0;
      $79 = ($78>>>0)>($mins$0>>>0);
      if ($79) {
       $sum6$2 = $78;
       break L26;
      }
      $80 = (($i7$1144) + 1)|0;
      $81 = (($rp3$1148) + 1|0);
      $82 = (($lp5$0146) + 1|0);
      $83 = (($dp4$1147) + 1|0);
      $84 = ($80>>>0)<($3>>>0);
      if ($84) {
       $dp4$1147 = $83;$i7$1144 = $80;$lp5$0146 = $82;$rp3$1148 = $81;$sum6$1145 = $78;
      } else {
       $sum6$2 = $78;
       break;
      }
     }
    } else {
     $sum6$2 = $sum6$0$lcssa;
    }
   } while(0);
   $85 = ($sum6$2>>>0)<($mins$0>>>0);
   if ($85) {
    $86 = HEAP32[$54>>2]|0;
    $best_row$0 = $86;$mins$1 = $sum6$2;
   } else {
    $best_row$0 = $16;$mins$1 = $mins$0;
   }
  }
 }
 $87 = ($$<<24>>24)==(32);
 if ($87) {
  $88 = (($png_ptr) + 388|0);
  $89 = ($3|0)==(0);
  if (!($89)) {
   $90 = HEAP32[$88>>2]|0;
   $$pn173 = $16;$$pn174 = $90;$$pn175 = $14;$i11$0107 = 0;
   while(1) {
    $pp$0108 = (($$pn175) + 1|0);
    $dp10$0109 = (($$pn174) + 1|0);
    $rp9$0110 = (($$pn173) + 1|0);
    $91 = HEAP8[$rp9$0110>>0]|0;
    $92 = $91&255;
    $93 = HEAP8[$pp$0108>>0]|0;
    $94 = $93&255;
    $95 = (($92) - ($94))|0;
    $96 = $95&255;
    HEAP8[$dp10$0109>>0] = $96;
    $97 = (($i11$0107) + 1)|0;
    $exitcond209 = ($97|0)==($3|0);
    if ($exitcond209) {
     break;
    } else {
     $$pn173 = $rp9$0110;$$pn174 = $dp10$0109;$$pn175 = $pp$0108;$i11$0107 = $97;
    }
   }
  }
  $98 = HEAP32[$88>>2]|0;
  $best_row$1 = $98;$mins$2 = $mins$1;
 } else {
  $99 = $17 & 32;
  $100 = ($99|0)==(0);
  if ($100) {
   $best_row$1 = $best_row$0;$mins$2 = $mins$1;
  } else {
   $101 = (($png_ptr) + 388|0);
   $102 = ($3|0)==(0);
   if ($102) {
    $sum15$1 = 0;
   } else {
    $103 = HEAP32[$101>>2]|0;
    $$pn = $16;$$pn171 = $103;$$pn172 = $14;$i17$0118 = 0;$sum15$0117 = 0;
    while(1) {
     $pp14$0119 = (($$pn172) + 1|0);
     $dp13$0120 = (($$pn171) + 1|0);
     $rp12$0121 = (($$pn) + 1|0);
     $104 = HEAP8[$rp12$0121>>0]|0;
     $105 = $104&255;
     $106 = HEAP8[$pp14$0119>>0]|0;
     $107 = $106&255;
     $108 = (($105) - ($107))|0;
     $109 = $108&255;
     HEAP8[$dp13$0120>>0] = $109;
     $110 = $108 & 255;
     $111 = ($110>>>0)<(128);
     $112 = (256 - ($110))|0;
     $113 = $111 ? $110 : $112;
     $114 = (($113) + ($sum15$0117))|0;
     $115 = ($114>>>0)<=($mins$1>>>0);
     $116 = (($i17$0118) + 1)|0;
     $117 = ($116>>>0)<($3>>>0);
     $or$cond232 = $115 & $117;
     if ($or$cond232) {
      $$pn = $rp12$0121;$$pn171 = $dp13$0120;$$pn172 = $pp14$0119;$i17$0118 = $116;$sum15$0117 = $114;
     } else {
      $sum15$1 = $114;
      break;
     }
    }
   }
   $118 = ($sum15$1>>>0)<($mins$1>>>0);
   if ($118) {
    $119 = HEAP32[$101>>2]|0;
    $best_row$1 = $119;$mins$2 = $sum15$1;
   } else {
    $best_row$1 = $best_row$0;$mins$2 = $mins$1;
   }
  }
 }
 $120 = ($$<<24>>24)==(64);
 if ($120) {
  $121 = (($16) + 1|0);
  $122 = (($png_ptr) + 392|0);
  $123 = HEAP32[$122>>2]|0;
  $pp21$067 = (($14) + 1|0);
  $dp20$068 = (($123) + 1|0);
  $124 = ($12|0)==(0);
  if ($124) {
   $dp20$0$lcssa = $dp20$068;$i23$0$lcssa = 0;$pp21$0$lcssa = $pp21$067;$rp19$0$lcssa = $121;
  } else {
   $125 = (($12) + 1)|0;
   $scevgep197 = (($14) + ($125)|0);
   $dp20$072 = $dp20$068;$i23$070 = 0;$pp21$071 = $pp21$067;$rp19$069 = $121;
   while(1) {
    $127 = (($rp19$069) + 1|0);
    $128 = HEAP8[$rp19$069>>0]|0;
    $129 = $128&255;
    $130 = HEAP8[$pp21$071>>0]|0;
    $131 = $130&255;
    $132 = $131 >>> 1;
    $133 = (($129) - ($132))|0;
    $134 = $133&255;
    HEAP8[$dp20$072>>0] = $134;
    $135 = (($i23$070) + 1)|0;
    $pp21$0 = (($pp21$071) + 1|0);
    $dp20$0 = (($dp20$072) + 1|0);
    $136 = ($135>>>0)<($12>>>0);
    if ($136) {
     $dp20$072 = $dp20$0;$i23$070 = $135;$pp21$071 = $pp21$0;$rp19$069 = $127;
    } else {
     break;
    }
   }
   $scevgep196 = (($123) + ($125)|0);
   $scevgep198 = (($16) + ($125)|0);
   $dp20$0$lcssa = $scevgep196;$i23$0$lcssa = $12;$pp21$0$lcssa = $scevgep197;$rp19$0$lcssa = $scevgep198;
  }
  $126 = ($i23$0$lcssa>>>0)<($3>>>0);
  if ($126) {
   $dp20$161 = $dp20$0$lcssa;$i23$164 = $i23$0$lcssa;$lp22$063 = $121;$pp21$162 = $pp21$0$lcssa;$rp19$160 = $rp19$0$lcssa;
   while(1) {
    $137 = (($rp19$160) + 1|0);
    $138 = HEAP8[$rp19$160>>0]|0;
    $139 = $138&255;
    $140 = (($pp21$162) + 1|0);
    $141 = HEAP8[$pp21$162>>0]|0;
    $142 = $141&255;
    $143 = (($lp22$063) + 1|0);
    $144 = HEAP8[$lp22$063>>0]|0;
    $145 = $144&255;
    $146 = (($145) + ($142))|0;
    $147 = $146 >>> 1;
    $148 = (($139) - ($147))|0;
    $149 = $148&255;
    $150 = (($dp20$161) + 1|0);
    HEAP8[$dp20$161>>0] = $149;
    $151 = (($i23$164) + 1)|0;
    $exitcond191 = ($151|0)==($3|0);
    if ($exitcond191) {
     break;
    } else {
     $dp20$161 = $150;$i23$164 = $151;$lp22$063 = $143;$pp21$162 = $140;$rp19$160 = $137;
    }
   }
  }
  $152 = HEAP32[$122>>2]|0;
  $best_row$2 = $152;$mins$3 = $mins$2;
 } else {
  $153 = $17 & 64;
  $154 = ($153|0)==(0);
  if ($154) {
   $best_row$2 = $best_row$1;$mins$3 = $mins$2;
  } else {
   $155 = (($16) + 1|0);
   $156 = (($png_ptr) + 392|0);
   $157 = HEAP32[$156>>2]|0;
   $pp26$090 = (($14) + 1|0);
   $dp25$091 = (($157) + 1|0);
   $158 = ($12|0)==(0);
   if ($158) {
    $dp25$0$lcssa = $dp25$091;$i30$0$lcssa = 0;$pp26$0$lcssa = $pp26$090;$rp24$0$lcssa = $155;$sum28$0$lcssa = 0;
   } else {
    $159 = (($12) + 1)|0;
    $scevgep207 = (($14) + ($159)|0);
    $dp25$096 = $dp25$091;$i30$094 = 0;$pp26$095 = $pp26$090;$rp24$092 = $155;$sum28$093 = 0;
    while(1) {
     $161 = (($rp24$092) + 1|0);
     $162 = HEAP8[$rp24$092>>0]|0;
     $163 = $162&255;
     $164 = HEAP8[$pp26$095>>0]|0;
     $165 = $164&255;
     $166 = $165 >>> 1;
     $167 = (($163) - ($166))|0;
     $168 = $167&255;
     HEAP8[$dp25$096>>0] = $168;
     $169 = $167 & 255;
     $170 = ($169>>>0)<(128);
     $171 = (256 - ($169))|0;
     $172 = $170 ? $169 : $171;
     $173 = (($172) + ($sum28$093))|0;
     $174 = (($i30$094) + 1)|0;
     $pp26$0 = (($pp26$095) + 1|0);
     $dp25$0 = (($dp25$096) + 1|0);
     $175 = ($174>>>0)<($12>>>0);
     if ($175) {
      $dp25$096 = $dp25$0;$i30$094 = $174;$pp26$095 = $pp26$0;$rp24$092 = $161;$sum28$093 = $173;
     } else {
      break;
     }
    }
    $scevgep206 = (($157) + ($159)|0);
    $scevgep208 = (($16) + ($159)|0);
    $dp25$0$lcssa = $scevgep206;$i30$0$lcssa = $12;$pp26$0$lcssa = $scevgep207;$rp24$0$lcssa = $scevgep208;$sum28$0$lcssa = $173;
   }
   $160 = ($i30$0$lcssa>>>0)<($3>>>0);
   L58: do {
    if ($160) {
     $dp25$181 = $dp25$0$lcssa;$i30$185 = $i30$0$lcssa;$lp27$083 = $155;$pp26$182 = $pp26$0$lcssa;$rp24$180 = $rp24$0$lcssa;$sum28$184 = $sum28$0$lcssa;
     while(1) {
      $176 = HEAP8[$rp24$180>>0]|0;
      $177 = $176&255;
      $178 = HEAP8[$pp26$182>>0]|0;
      $179 = $178&255;
      $180 = HEAP8[$lp27$083>>0]|0;
      $181 = $180&255;
      $182 = (($181) + ($179))|0;
      $183 = $182 >>> 1;
      $184 = (($177) - ($183))|0;
      $185 = $184&255;
      HEAP8[$dp25$181>>0] = $185;
      $186 = $184 & 255;
      $187 = ($186>>>0)<(128);
      $188 = (256 - ($186))|0;
      $189 = $187 ? $186 : $188;
      $190 = (($189) + ($sum28$184))|0;
      $191 = ($190>>>0)>($mins$2>>>0);
      if ($191) {
       $sum28$2 = $190;
       break L58;
      }
      $192 = (($dp25$181) + 1|0);
      $193 = (($lp27$083) + 1|0);
      $194 = (($pp26$182) + 1|0);
      $195 = (($rp24$180) + 1|0);
      $196 = (($i30$185) + 1)|0;
      $197 = ($196>>>0)<($3>>>0);
      if ($197) {
       $dp25$181 = $192;$i30$185 = $196;$lp27$083 = $193;$pp26$182 = $194;$rp24$180 = $195;$sum28$184 = $190;
      } else {
       $sum28$2 = $190;
       break;
      }
     }
    } else {
     $sum28$2 = $sum28$0$lcssa;
    }
   } while(0);
   $198 = ($sum28$2>>>0)<($mins$2>>>0);
   if ($198) {
    $199 = HEAP32[$156>>2]|0;
    $best_row$2 = $199;$mins$3 = $sum28$2;
   } else {
    $best_row$2 = $best_row$1;$mins$3 = $mins$2;
   }
  }
 }
 $200 = ($$<<24>>24)==(-128);
 if ($200) {
  $201 = (($16) + 1|0);
  $202 = (($png_ptr) + 396|0);
  $203 = HEAP32[$202>>2]|0;
  $204 = (($14) + 1|0);
  $dp33$024 = (($203) + 1|0);
  $205 = ($12|0)==(0);
  if ($205) {
   $dp33$0$lcssa = $dp33$024;$i36$0$lcssa = 0;$pp34$0$lcssa = $204;$rp32$0$lcssa = $201;
  } else {
   $206 = (($12) + 1)|0;
   $scevgep180 = (($14) + ($206)|0);
   $dp33$028 = $dp33$024;$i36$027 = 0;$pp34$026 = $204;$rp32$025 = $201;
   while(1) {
    $208 = (($rp32$025) + 1|0);
    $209 = HEAP8[$rp32$025>>0]|0;
    $210 = $209&255;
    $211 = (($pp34$026) + 1|0);
    $212 = HEAP8[$pp34$026>>0]|0;
    $213 = $212&255;
    $214 = (($210) - ($213))|0;
    $215 = $214&255;
    HEAP8[$dp33$028>>0] = $215;
    $216 = (($i36$027) + 1)|0;
    $dp33$0 = (($dp33$028) + 1|0);
    $217 = ($216>>>0)<($12>>>0);
    if ($217) {
     $dp33$028 = $dp33$0;$i36$027 = $216;$pp34$026 = $211;$rp32$025 = $208;
    } else {
     break;
    }
   }
   $scevgep = (($203) + ($206)|0);
   $scevgep181 = (($16) + ($206)|0);
   $dp33$0$lcssa = $scevgep;$i36$0$lcssa = $12;$pp34$0$lcssa = $scevgep180;$rp32$0$lcssa = $scevgep181;
  }
  $207 = ($i36$0$lcssa>>>0)<($3>>>0);
  if ($207) {
   $cp$021 = $204;$dp33$119 = $dp33$0$lcssa;$i36$123 = $i36$0$lcssa;$lp35$022 = $201;$pp34$120 = $pp34$0$lcssa;$rp32$118 = $rp32$0$lcssa;
   while(1) {
    $218 = (($pp34$120) + 1|0);
    $219 = HEAP8[$pp34$120>>0]|0;
    $220 = $219&255;
    $221 = (($cp$021) + 1|0);
    $222 = HEAP8[$cp$021>>0]|0;
    $223 = $222&255;
    $224 = (($lp35$022) + 1|0);
    $225 = HEAP8[$lp35$022>>0]|0;
    $226 = $225&255;
    $227 = (($220) - ($223))|0;
    $228 = (($226) - ($223))|0;
    $229 = ($227|0)<(0);
    $230 = (0 - ($227))|0;
    $231 = $229 ? $230 : $227;
    $232 = ($228|0)<(0);
    $233 = (0 - ($228))|0;
    $234 = $232 ? $233 : $228;
    $235 = (($228) + ($227))|0;
    $236 = ($235|0)<(0);
    $237 = (0 - ($235))|0;
    $238 = $236 ? $237 : $235;
    $239 = ($231|0)>($234|0);
    $240 = ($231|0)>($238|0);
    $or$cond16 = $239 | $240;
    if ($or$cond16) {
     $241 = ($234|0)<=($238|0);
     $242 = $241 ? $220 : $223;
     $247 = $242;
    } else {
     $247 = $226;
    }
    $243 = (($rp32$118) + 1|0);
    $244 = HEAP8[$rp32$118>>0]|0;
    $245 = $244&255;
    $246 = (($245) - ($247))|0;
    $248 = $246&255;
    $249 = (($dp33$119) + 1|0);
    HEAP8[$dp33$119>>0] = $248;
    $250 = (($i36$123) + 1)|0;
    $exitcond = ($250|0)==($3|0);
    if ($exitcond) {
     break;
    } else {
     $cp$021 = $221;$dp33$119 = $249;$i36$123 = $250;$lp35$022 = $224;$pp34$120 = $218;$rp32$118 = $243;
    }
   }
  }
  $251 = HEAP32[$202>>2]|0;
  $best_row$3 = $251;
 } else {
  $252 = $17 & 128;
  $253 = ($252|0)==(0);
  if ($253) {
   $best_row$3 = $best_row$2;
  } else {
   $254 = (($16) + 1|0);
   $255 = (($png_ptr) + 396|0);
   $256 = HEAP32[$255>>2]|0;
   $257 = (($14) + 1|0);
   $dp38$046 = (($256) + 1|0);
   $258 = ($12|0)==(0);
   if ($258) {
    $dp38$0$lcssa = $dp38$046;$i44$0$lcssa = 0;$pp39$0$lcssa = $257;$rp37$0$lcssa = $254;$sum42$0$lcssa = 0;
   } else {
    $259 = (($12) + 1)|0;
    $scevgep189 = (($14) + ($259)|0);
    $dp38$051 = $dp38$046;$i44$050 = 0;$pp39$048 = $257;$rp37$047 = $254;$sum42$049 = 0;
    while(1) {
     $261 = (($rp37$047) + 1|0);
     $262 = HEAP8[$rp37$047>>0]|0;
     $263 = $262&255;
     $264 = (($pp39$048) + 1|0);
     $265 = HEAP8[$pp39$048>>0]|0;
     $266 = $265&255;
     $267 = (($263) - ($266))|0;
     $268 = $267&255;
     HEAP8[$dp38$051>>0] = $268;
     $269 = $267 & 255;
     $270 = ($269>>>0)<(128);
     $271 = (256 - ($269))|0;
     $272 = $270 ? $269 : $271;
     $273 = (($272) + ($sum42$049))|0;
     $274 = (($i44$050) + 1)|0;
     $dp38$0 = (($dp38$051) + 1|0);
     $275 = ($274>>>0)<($12>>>0);
     if ($275) {
      $dp38$051 = $dp38$0;$i44$050 = $274;$pp39$048 = $264;$rp37$047 = $261;$sum42$049 = $273;
     } else {
      break;
     }
    }
    $scevgep188 = (($256) + ($259)|0);
    $scevgep190 = (($16) + ($259)|0);
    $dp38$0$lcssa = $scevgep188;$i44$0$lcssa = $12;$pp39$0$lcssa = $scevgep189;$rp37$0$lcssa = $scevgep190;$sum42$0$lcssa = $273;
   }
   $260 = ($i44$0$lcssa>>>0)<($3>>>0);
   L99: do {
    if ($260) {
     $cp40$038 = $257;$dp38$136 = $dp38$0$lcssa;$i44$141 = $i44$0$lcssa;$lp41$039 = $254;$pp39$137 = $pp39$0$lcssa;$rp37$135 = $rp37$0$lcssa;$sum42$140 = $sum42$0$lcssa;
     while(1) {
      $276 = (($pp39$137) + 1|0);
      $277 = HEAP8[$pp39$137>>0]|0;
      $278 = $277&255;
      $279 = (($cp40$038) + 1|0);
      $280 = HEAP8[$cp40$038>>0]|0;
      $281 = $280&255;
      $282 = (($lp41$039) + 1|0);
      $283 = HEAP8[$lp41$039>>0]|0;
      $284 = $283&255;
      $285 = (($278) - ($281))|0;
      $286 = (($284) - ($281))|0;
      $287 = ($285|0)<(0);
      $288 = (0 - ($285))|0;
      $289 = $287 ? $288 : $285;
      $290 = ($286|0)<(0);
      $291 = (0 - ($286))|0;
      $292 = $290 ? $291 : $286;
      $293 = (($286) + ($285))|0;
      $294 = ($293|0)<(0);
      $295 = (0 - ($293))|0;
      $296 = $294 ? $295 : $293;
      $297 = ($289|0)>($292|0);
      $298 = ($289|0)>($296|0);
      $or$cond17 = $297 | $298;
      if ($or$cond17) {
       $299 = ($292|0)<=($296|0);
       $300 = $299 ? $278 : $281;
       $304 = $300;
      } else {
       $304 = $284;
      }
      $301 = HEAP8[$rp37$135>>0]|0;
      $302 = $301&255;
      $303 = (($302) - ($304))|0;
      $305 = $303&255;
      HEAP8[$dp38$136>>0] = $305;
      $306 = $303 & 255;
      $307 = ($306>>>0)<(128);
      $308 = (256 - ($306))|0;
      $309 = $307 ? $306 : $308;
      $310 = (($309) + ($sum42$140))|0;
      $311 = ($310>>>0)>($mins$3>>>0);
      if ($311) {
       $sum42$2 = $310;
       break L99;
      }
      $312 = (($dp38$136) + 1|0);
      $313 = (($rp37$135) + 1|0);
      $314 = (($i44$141) + 1)|0;
      $315 = ($314>>>0)<($3>>>0);
      if ($315) {
       $cp40$038 = $279;$dp38$136 = $312;$i44$141 = $314;$lp41$039 = $282;$pp39$137 = $276;$rp37$135 = $313;$sum42$140 = $310;
      } else {
       $sum42$2 = $310;
       break;
      }
     }
    } else {
     $sum42$2 = $sum42$0$lcssa;
    }
   } while(0);
   $316 = ($sum42$2>>>0)<($mins$3>>>0);
   if ($316) {
    $317 = HEAP32[$255>>2]|0;
    $best_row$3 = $317;
   } else {
    $best_row$3 = $best_row$2;
   }
  }
 }
 $318 = HEAP32[$2>>2]|0;
 $319 = (($318) + 1)|0;
 _png_compress_IDAT($png_ptr,$best_row$3,$319,0);
 $320 = HEAP32[$13>>2]|0;
 $321 = ($320|0)==(0|0);
 if (!($321)) {
  $322 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $322;
  HEAP32[$15>>2] = $320;
 }
 $323 = HEAP32[$4>>2]|0;
 $324 = (($323) + 1)|0;
 HEAP32[$4>>2] = $324;
 $325 = (($png_ptr) + 352|0);
 $326 = HEAP32[$325>>2]|0;
 $327 = ($324>>>0)<($326>>>0);
 if (!($327)) {
  _png_compress_IDAT($png_ptr,0,0,4);
 }
 $328 = (($png_ptr) + 476|0);
 $329 = HEAP32[$328>>2]|0;
 $330 = (($329) + 1)|0;
 HEAP32[$328>>2] = $330;
 $331 = (($png_ptr) + 472|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = ($332|0)==(0);
 $334 = ($330>>>0)<($332>>>0);
 $or$cond$i = $333 | $334;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 }
 _png_write_flush($png_ptr);
 STACKTOP = sp;return;
}
function _adler32($adler,$buf,$len) {
 $adler = $adler|0;
 $buf = $buf|0;
 $len = $len|0;
 var $$ = 0, $$$16 = 0, $$010 = 0, $$0112 = 0, $$013 = 0, $$1239 = 0, $$140 = 0, $$16$lcssa = 0, $$1611 = 0, $$228 = 0, $$23 = 0, $$319 = 0, $$3427 = 0, $$3838 = 0, $$418 = 0, $$49 = 0, $$526 = 0, $$6$lcssa = 0, $$617 = 0, $$7 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $n$0 = 0, $scevgep = 0, $sum2$0 = 0, $sum2$1$lcssa = 0, $sum2$114 = 0, $sum2$241 = 0, $sum2$3 = 0, $sum2$429 = 0, $sum2$5$lcssa = 0;
 var $sum2$520 = 0, $sum2$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $adler >>> 16;
 $1 = $adler & 65535;
 $2 = ($len|0)==(1);
 if ($2) {
  $3 = HEAP8[$buf>>0]|0;
  $4 = $3&255;
  $5 = (($4) + ($1))|0;
  $6 = ($5>>>0)>(65520);
  $7 = (($5) + -65521)|0;
  $$ = $6 ? $7 : $5;
  $8 = (($$) + ($0))|0;
  $9 = ($8>>>0)>(65520);
  $10 = (($8) + 15)|0;
  $sum2$0 = $9 ? $10 : $8;
  $11 = $sum2$0 << 16;
  $12 = $11 | $$;
  $$010 = $12;
  STACKTOP = sp;return ($$010|0);
 }
 $13 = ($buf|0)==(0|0);
 if ($13) {
  $$010 = 1;
  STACKTOP = sp;return ($$010|0);
 }
 $14 = ($len>>>0)<(16);
 if ($14) {
  $16 = ($len|0)==(0);
  if ($16) {
   $$16$lcssa = $1;$sum2$1$lcssa = $0;
  } else {
   $$0112 = $buf;$$013 = $len;$$1611 = $1;$sum2$114 = $0;
   while(1) {
    $17 = (($$013) + -1)|0;
    $18 = (($$0112) + 1|0);
    $19 = HEAP8[$$0112>>0]|0;
    $20 = $19&255;
    $21 = (($20) + ($$1611))|0;
    $22 = (($21) + ($sum2$114))|0;
    $23 = ($17|0)==(0);
    if ($23) {
     $$16$lcssa = $21;$sum2$1$lcssa = $22;
     break;
    } else {
     $$0112 = $18;$$013 = $17;$$1611 = $21;$sum2$114 = $22;
    }
   }
  }
  $24 = ($$16$lcssa>>>0)>(65520);
  $25 = (($$16$lcssa) + -65521)|0;
  $$$16 = $24 ? $25 : $$16$lcssa;
  $26 = (($sum2$1$lcssa>>>0) % 65521)&-1;
  $27 = $26 << 16;
  $28 = $27 | $$$16;
  $$010 = $28;
  STACKTOP = sp;return ($$010|0);
 }
 $15 = ($len>>>0)>(5551);
 if ($15) {
  $$1239 = $buf;$$140 = $len;$$3838 = $1;$sum2$241 = $0;
  while(1) {
   $29 = (($$140) + -5552)|0;
   $$23 = $$1239;$$49 = $$3838;$n$0 = 347;$sum2$3 = $sum2$241;
   while(1) {
    $30 = HEAP8[$$23>>0]|0;
    $31 = $30&255;
    $32 = (($31) + ($$49))|0;
    $33 = (($32) + ($sum2$3))|0;
    $34 = (($$23) + 1|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = $35&255;
    $37 = (($32) + ($36))|0;
    $38 = (($33) + ($37))|0;
    $39 = (($$23) + 2|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = $40&255;
    $42 = (($37) + ($41))|0;
    $43 = (($38) + ($42))|0;
    $44 = (($$23) + 3|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = $45&255;
    $47 = (($42) + ($46))|0;
    $48 = (($43) + ($47))|0;
    $49 = (($$23) + 4|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = $50&255;
    $52 = (($47) + ($51))|0;
    $53 = (($48) + ($52))|0;
    $54 = (($$23) + 5|0);
    $55 = HEAP8[$54>>0]|0;
    $56 = $55&255;
    $57 = (($52) + ($56))|0;
    $58 = (($53) + ($57))|0;
    $59 = (($$23) + 6|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = $60&255;
    $62 = (($57) + ($61))|0;
    $63 = (($58) + ($62))|0;
    $64 = (($$23) + 7|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = $65&255;
    $67 = (($62) + ($66))|0;
    $68 = (($63) + ($67))|0;
    $69 = (($$23) + 8|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = $70&255;
    $72 = (($67) + ($71))|0;
    $73 = (($68) + ($72))|0;
    $74 = (($$23) + 9|0);
    $75 = HEAP8[$74>>0]|0;
    $76 = $75&255;
    $77 = (($72) + ($76))|0;
    $78 = (($73) + ($77))|0;
    $79 = (($$23) + 10|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = $80&255;
    $82 = (($77) + ($81))|0;
    $83 = (($78) + ($82))|0;
    $84 = (($$23) + 11|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = (($82) + ($86))|0;
    $88 = (($83) + ($87))|0;
    $89 = (($$23) + 12|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = $90&255;
    $92 = (($87) + ($91))|0;
    $93 = (($88) + ($92))|0;
    $94 = (($$23) + 13|0);
    $95 = HEAP8[$94>>0]|0;
    $96 = $95&255;
    $97 = (($92) + ($96))|0;
    $98 = (($93) + ($97))|0;
    $99 = (($$23) + 14|0);
    $100 = HEAP8[$99>>0]|0;
    $101 = $100&255;
    $102 = (($97) + ($101))|0;
    $103 = (($98) + ($102))|0;
    $104 = (($$23) + 15|0);
    $105 = HEAP8[$104>>0]|0;
    $106 = $105&255;
    $107 = (($102) + ($106))|0;
    $108 = (($103) + ($107))|0;
    $109 = (($$23) + 16|0);
    $110 = (($n$0) + -1)|0;
    $111 = ($110|0)==(0);
    if ($111) {
     break;
    } else {
     $$23 = $109;$$49 = $107;$n$0 = $110;$sum2$3 = $108;
    }
   }
   $scevgep = (($$1239) + 5552|0);
   $112 = (($107>>>0) % 65521)&-1;
   $113 = (($108>>>0) % 65521)&-1;
   $114 = ($29>>>0)>(5551);
   if ($114) {
    $$1239 = $scevgep;$$140 = $29;$$3838 = $112;$sum2$241 = $113;
   } else {
    break;
   }
  }
  $115 = ($29|0)==(0);
  if ($115) {
   $$7 = $112;$sum2$6 = $113;
  } else {
   $116 = ($29>>>0)>(15);
   if ($116) {
    $$228 = $29;$$3427 = $scevgep;$$526 = $112;$sum2$429 = $113;
    label = 15;
   } else {
    $$319 = $29;$$418 = $scevgep;$$617 = $112;$sum2$520 = $113;
    label = 16;
   }
  }
 } else {
  $$228 = $len;$$3427 = $buf;$$526 = $1;$sum2$429 = $0;
  label = 15;
 }
 if ((label|0) == 15) {
  while(1) {
   label = 0;
   $118 = (($$228) + -16)|0;
   $119 = HEAP8[$$3427>>0]|0;
   $120 = $119&255;
   $121 = (($120) + ($$526))|0;
   $122 = (($121) + ($sum2$429))|0;
   $123 = (($$3427) + 1|0);
   $124 = HEAP8[$123>>0]|0;
   $125 = $124&255;
   $126 = (($121) + ($125))|0;
   $127 = (($122) + ($126))|0;
   $128 = (($$3427) + 2|0);
   $129 = HEAP8[$128>>0]|0;
   $130 = $129&255;
   $131 = (($126) + ($130))|0;
   $132 = (($127) + ($131))|0;
   $133 = (($$3427) + 3|0);
   $134 = HEAP8[$133>>0]|0;
   $135 = $134&255;
   $136 = (($131) + ($135))|0;
   $137 = (($132) + ($136))|0;
   $138 = (($$3427) + 4|0);
   $139 = HEAP8[$138>>0]|0;
   $140 = $139&255;
   $141 = (($136) + ($140))|0;
   $142 = (($137) + ($141))|0;
   $143 = (($$3427) + 5|0);
   $144 = HEAP8[$143>>0]|0;
   $145 = $144&255;
   $146 = (($141) + ($145))|0;
   $147 = (($142) + ($146))|0;
   $148 = (($$3427) + 6|0);
   $149 = HEAP8[$148>>0]|0;
   $150 = $149&255;
   $151 = (($146) + ($150))|0;
   $152 = (($147) + ($151))|0;
   $153 = (($$3427) + 7|0);
   $154 = HEAP8[$153>>0]|0;
   $155 = $154&255;
   $156 = (($151) + ($155))|0;
   $157 = (($152) + ($156))|0;
   $158 = (($$3427) + 8|0);
   $159 = HEAP8[$158>>0]|0;
   $160 = $159&255;
   $161 = (($156) + ($160))|0;
   $162 = (($157) + ($161))|0;
   $163 = (($$3427) + 9|0);
   $164 = HEAP8[$163>>0]|0;
   $165 = $164&255;
   $166 = (($161) + ($165))|0;
   $167 = (($162) + ($166))|0;
   $168 = (($$3427) + 10|0);
   $169 = HEAP8[$168>>0]|0;
   $170 = $169&255;
   $171 = (($166) + ($170))|0;
   $172 = (($167) + ($171))|0;
   $173 = (($$3427) + 11|0);
   $174 = HEAP8[$173>>0]|0;
   $175 = $174&255;
   $176 = (($171) + ($175))|0;
   $177 = (($172) + ($176))|0;
   $178 = (($$3427) + 12|0);
   $179 = HEAP8[$178>>0]|0;
   $180 = $179&255;
   $181 = (($176) + ($180))|0;
   $182 = (($177) + ($181))|0;
   $183 = (($$3427) + 13|0);
   $184 = HEAP8[$183>>0]|0;
   $185 = $184&255;
   $186 = (($181) + ($185))|0;
   $187 = (($182) + ($186))|0;
   $188 = (($$3427) + 14|0);
   $189 = HEAP8[$188>>0]|0;
   $190 = $189&255;
   $191 = (($186) + ($190))|0;
   $192 = (($187) + ($191))|0;
   $193 = (($$3427) + 15|0);
   $194 = HEAP8[$193>>0]|0;
   $195 = $194&255;
   $196 = (($191) + ($195))|0;
   $197 = (($192) + ($196))|0;
   $198 = (($$3427) + 16|0);
   $199 = ($118>>>0)>(15);
   if ($199) {
    $$228 = $118;$$3427 = $198;$$526 = $196;$sum2$429 = $197;
    label = 15;
   } else {
    break;
   }
  }
  $117 = ($118|0)==(0);
  if ($117) {
   $$6$lcssa = $196;$sum2$5$lcssa = $197;
   label = 17;
  } else {
   $$319 = $118;$$418 = $198;$$617 = $196;$sum2$520 = $197;
   label = 16;
  }
 }
 if ((label|0) == 16) {
  while(1) {
   label = 0;
   $200 = (($$319) + -1)|0;
   $201 = (($$418) + 1|0);
   $202 = HEAP8[$$418>>0]|0;
   $203 = $202&255;
   $204 = (($203) + ($$617))|0;
   $205 = (($204) + ($sum2$520))|0;
   $206 = ($200|0)==(0);
   if ($206) {
    $$6$lcssa = $204;$sum2$5$lcssa = $205;
    label = 17;
    break;
   } else {
    $$319 = $200;$$418 = $201;$$617 = $204;$sum2$520 = $205;
    label = 16;
   }
  }
 }
 if ((label|0) == 17) {
  $207 = (($$6$lcssa>>>0) % 65521)&-1;
  $208 = (($sum2$5$lcssa>>>0) % 65521)&-1;
  $$7 = $207;$sum2$6 = $208;
 }
 $209 = $sum2$6 << 16;
 $210 = $209 | $$7;
 $$010 = $210;
 STACKTOP = sp;return ($$010|0);
}
function _crc32($crc,$buf,$len) {
 $crc = $crc|0;
 $buf = $buf|0;
 $len = $len|0;
 var $$0 = 0, $$0116$i = 0, $$017$i = 0, $$1$lcssa$i = 0, $$12$i = 0, $$19$i = 0, $$2$lcssa$i = 0, $$24$i = 0, $$3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $buf4$0$lcssa$i = 0, $buf4$011$i = 0, $buf4$1$lcssa$i = 0, $buf4$16$i = 0, $c$0$masked$i = 0, $c$018$i = 0, $c$1$lcssa$i = 0, $c$110$i = 0, $c$2$lcssa$i = 0, $c$25$i = 0, $c$3$i = 0, $c$3$masked$i = 0, $c$4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buf|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = $crc ^ -1;
 $2 = ($len|0)==(0);
 L4: do {
  if ($2) {
   $c$4$i = $1;
  } else {
   $$0116$i = $buf;$$017$i = $len;$c$018$i = $1;
   while(1) {
    $3 = $$0116$i;
    $4 = $3 & 3;
    $5 = ($4|0)==(0);
    if ($5) {
     break;
    }
    $6 = (($$0116$i) + 1|0);
    $7 = HEAP8[$$0116$i>>0]|0;
    $8 = $7&255;
    $c$0$masked$i = $c$018$i & 255;
    $9 = $8 ^ $c$0$masked$i;
    $10 = (392096 + ($9<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = $c$018$i >>> 8;
    $13 = $11 ^ $12;
    $14 = (($$017$i) + -1)|0;
    $15 = ($14|0)==(0);
    if ($15) {
     $c$4$i = $13;
     break L4;
    } else {
     $$0116$i = $6;$$017$i = $14;$c$018$i = $13;
    }
   }
   $16 = ($$017$i>>>0)>(31);
   if ($16) {
    $$19$i = $$017$i;$buf4$011$i = $$0116$i;$c$110$i = $c$018$i;
    while(1) {
     $18 = (($buf4$011$i) + 4|0);
     $19 = HEAP32[$buf4$011$i>>2]|0;
     $20 = $19 ^ $c$110$i;
     $21 = $20 & 255;
     $22 = ((392096 + ($21<<2)|0) + 3072|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = $20 >>> 8;
     $25 = $24 & 255;
     $26 = ((392096 + ($25<<2)|0) + 2048|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = $27 ^ $23;
     $29 = $20 >>> 16;
     $30 = $29 & 255;
     $31 = ((392096 + ($30<<2)|0) + 1024|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = $28 ^ $32;
     $34 = $20 >>> 24;
     $35 = (392096 + ($34<<2)|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = $33 ^ $36;
     $38 = (($buf4$011$i) + 8|0);
     $39 = HEAP32[$18>>2]|0;
     $40 = $37 ^ $39;
     $41 = $40 & 255;
     $42 = ((392096 + ($41<<2)|0) + 3072|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = $40 >>> 8;
     $45 = $44 & 255;
     $46 = ((392096 + ($45<<2)|0) + 2048|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = $47 ^ $43;
     $49 = $40 >>> 16;
     $50 = $49 & 255;
     $51 = ((392096 + ($50<<2)|0) + 1024|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = $48 ^ $52;
     $54 = $40 >>> 24;
     $55 = (392096 + ($54<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = $53 ^ $56;
     $58 = (($buf4$011$i) + 12|0);
     $59 = HEAP32[$38>>2]|0;
     $60 = $57 ^ $59;
     $61 = $60 & 255;
     $62 = ((392096 + ($61<<2)|0) + 3072|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = $60 >>> 8;
     $65 = $64 & 255;
     $66 = ((392096 + ($65<<2)|0) + 2048|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = $67 ^ $63;
     $69 = $60 >>> 16;
     $70 = $69 & 255;
     $71 = ((392096 + ($70<<2)|0) + 1024|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = $68 ^ $72;
     $74 = $60 >>> 24;
     $75 = (392096 + ($74<<2)|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = $73 ^ $76;
     $78 = (($buf4$011$i) + 16|0);
     $79 = HEAP32[$58>>2]|0;
     $80 = $77 ^ $79;
     $81 = $80 & 255;
     $82 = ((392096 + ($81<<2)|0) + 3072|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = $80 >>> 8;
     $85 = $84 & 255;
     $86 = ((392096 + ($85<<2)|0) + 2048|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = $87 ^ $83;
     $89 = $80 >>> 16;
     $90 = $89 & 255;
     $91 = ((392096 + ($90<<2)|0) + 1024|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = $88 ^ $92;
     $94 = $80 >>> 24;
     $95 = (392096 + ($94<<2)|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = $93 ^ $96;
     $98 = (($buf4$011$i) + 20|0);
     $99 = HEAP32[$78>>2]|0;
     $100 = $97 ^ $99;
     $101 = $100 & 255;
     $102 = ((392096 + ($101<<2)|0) + 3072|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = $100 >>> 8;
     $105 = $104 & 255;
     $106 = ((392096 + ($105<<2)|0) + 2048|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = $107 ^ $103;
     $109 = $100 >>> 16;
     $110 = $109 & 255;
     $111 = ((392096 + ($110<<2)|0) + 1024|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = $108 ^ $112;
     $114 = $100 >>> 24;
     $115 = (392096 + ($114<<2)|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = $113 ^ $116;
     $118 = (($buf4$011$i) + 24|0);
     $119 = HEAP32[$98>>2]|0;
     $120 = $117 ^ $119;
     $121 = $120 & 255;
     $122 = ((392096 + ($121<<2)|0) + 3072|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = $120 >>> 8;
     $125 = $124 & 255;
     $126 = ((392096 + ($125<<2)|0) + 2048|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = $127 ^ $123;
     $129 = $120 >>> 16;
     $130 = $129 & 255;
     $131 = ((392096 + ($130<<2)|0) + 1024|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = $128 ^ $132;
     $134 = $120 >>> 24;
     $135 = (392096 + ($134<<2)|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = $133 ^ $136;
     $138 = (($buf4$011$i) + 28|0);
     $139 = HEAP32[$118>>2]|0;
     $140 = $137 ^ $139;
     $141 = $140 & 255;
     $142 = ((392096 + ($141<<2)|0) + 3072|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = $140 >>> 8;
     $145 = $144 & 255;
     $146 = ((392096 + ($145<<2)|0) + 2048|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = $147 ^ $143;
     $149 = $140 >>> 16;
     $150 = $149 & 255;
     $151 = ((392096 + ($150<<2)|0) + 1024|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = $148 ^ $152;
     $154 = $140 >>> 24;
     $155 = (392096 + ($154<<2)|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = $153 ^ $156;
     $158 = (($buf4$011$i) + 32|0);
     $159 = HEAP32[$138>>2]|0;
     $160 = $157 ^ $159;
     $161 = $160 & 255;
     $162 = ((392096 + ($161<<2)|0) + 3072|0);
     $163 = HEAP32[$162>>2]|0;
     $164 = $160 >>> 8;
     $165 = $164 & 255;
     $166 = ((392096 + ($165<<2)|0) + 2048|0);
     $167 = HEAP32[$166>>2]|0;
     $168 = $167 ^ $163;
     $169 = $160 >>> 16;
     $170 = $169 & 255;
     $171 = ((392096 + ($170<<2)|0) + 1024|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = $168 ^ $172;
     $174 = $160 >>> 24;
     $175 = (392096 + ($174<<2)|0);
     $176 = HEAP32[$175>>2]|0;
     $177 = $173 ^ $176;
     $178 = (($$19$i) + -32)|0;
     $179 = ($178>>>0)>(31);
     if ($179) {
      $$19$i = $178;$buf4$011$i = $158;$c$110$i = $177;
     } else {
      $$1$lcssa$i = $178;$buf4$0$lcssa$i = $158;$c$1$lcssa$i = $177;
      break;
     }
    }
   } else {
    $$1$lcssa$i = $$017$i;$buf4$0$lcssa$i = $$0116$i;$c$1$lcssa$i = $c$018$i;
   }
   $17 = ($$1$lcssa$i>>>0)>(3);
   if ($17) {
    $$24$i = $$1$lcssa$i;$buf4$16$i = $buf4$0$lcssa$i;$c$25$i = $c$1$lcssa$i;
    while(1) {
     $180 = (($buf4$16$i) + 4|0);
     $181 = HEAP32[$buf4$16$i>>2]|0;
     $182 = $181 ^ $c$25$i;
     $183 = $182 & 255;
     $184 = ((392096 + ($183<<2)|0) + 3072|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = $182 >>> 8;
     $187 = $186 & 255;
     $188 = ((392096 + ($187<<2)|0) + 2048|0);
     $189 = HEAP32[$188>>2]|0;
     $190 = $189 ^ $185;
     $191 = $182 >>> 16;
     $192 = $191 & 255;
     $193 = ((392096 + ($192<<2)|0) + 1024|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = $190 ^ $194;
     $196 = $182 >>> 24;
     $197 = (392096 + ($196<<2)|0);
     $198 = HEAP32[$197>>2]|0;
     $199 = $195 ^ $198;
     $200 = (($$24$i) + -4)|0;
     $201 = ($200>>>0)>(3);
     if ($201) {
      $$24$i = $200;$buf4$16$i = $180;$c$25$i = $199;
     } else {
      $$2$lcssa$i = $200;$buf4$1$lcssa$i = $180;$c$2$lcssa$i = $199;
      break;
     }
    }
   } else {
    $$2$lcssa$i = $$1$lcssa$i;$buf4$1$lcssa$i = $buf4$0$lcssa$i;$c$2$lcssa$i = $c$1$lcssa$i;
   }
   $202 = ($$2$lcssa$i|0)==(0);
   if ($202) {
    $c$4$i = $c$2$lcssa$i;
   } else {
    $$12$i = $buf4$1$lcssa$i;$$3$i = $$2$lcssa$i;$c$3$i = $c$2$lcssa$i;
    while(1) {
     $203 = (($$12$i) + 1|0);
     $204 = HEAP8[$$12$i>>0]|0;
     $205 = $204&255;
     $c$3$masked$i = $c$3$i & 255;
     $206 = $205 ^ $c$3$masked$i;
     $207 = (392096 + ($206<<2)|0);
     $208 = HEAP32[$207>>2]|0;
     $209 = $c$3$i >>> 8;
     $210 = $208 ^ $209;
     $211 = (($$3$i) + -1)|0;
     $212 = ($211|0)==(0);
     if ($212) {
      $c$4$i = $210;
      break;
     } else {
      $$12$i = $203;$$3$i = $211;$c$3$i = $210;
     }
    }
   }
  }
 } while(0);
 $213 = $c$4$i ^ -1;
 $$0 = $213;
 STACKTOP = sp;return ($$0|0);
}
function _deflateInit2_($strm,$level,$method,$windowBits,$memLevel,$strategy,$version,$stream_size) {
 $strm = $strm|0;
 $level = $level|0;
 $method = $method|0;
 $windowBits = $windowBits|0;
 $memLevel = $memLevel|0;
 $strategy = $strategy|0;
 $version = $version|0;
 $stream_size = $stream_size|0;
 var $$ = 0, $$$09 = 0, $$0 = 0, $$09 = 0, $$09$off = 0, $$level = 0, $$windowBits = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $memLevel$off = 0, $or$cond = 0, $or$cond10 = 0, $or$cond11 = 0;
 var $or$cond12 = 0, $or$cond13 = 0, $wrap$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($version|0)==(0|0);
 if ($0) {
  $$0 = -6;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP8[$version>>0]|0;
 $2 = ($1<<24>>24)==(49);
 $3 = ($stream_size|0)==(56);
 $or$cond = $2 & $3;
 if (!($or$cond)) {
  $$0 = -6;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ($strm|0)==(0|0);
 if ($4) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($strm) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($strm) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP32[$6>>2] = 1524;
  $9 = (($strm) + 40|0);
  HEAP32[$9>>2] = 0;
  $26 = 1524;
 } else {
  $26 = $7;
 }
 $10 = (($strm) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  HEAP32[$10>>2] = 2528;
 }
 $13 = ($level|0)==(-1);
 $$level = $13 ? 6 : $level;
 $14 = ($windowBits|0)<(0);
 if ($14) {
  $15 = (0 - ($windowBits))|0;
  $$09 = $15;$wrap$0 = 0;
 } else {
  $16 = ($windowBits|0)>(15);
  $17 = (($windowBits) + -16)|0;
  $$windowBits = $16 ? $17 : $windowBits;
  $$ = $16 ? 2 : 1;
  $$09 = $$windowBits;$wrap$0 = $$;
 }
 $memLevel$off = (($memLevel) + -1)|0;
 $18 = ($memLevel$off>>>0)<(9);
 $19 = ($method|0)==(8);
 $or$cond10 = $18 & $19;
 if (!($or$cond10)) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $$09$off = (($$09) + -8)|0;
 $20 = ($$09$off>>>0)>(7);
 $21 = ($$level>>>0)>(9);
 $or$cond11 = $20 | $21;
 $22 = ($strategy>>>0)>(4);
 $or$cond12 = $or$cond11 | $22;
 if ($or$cond12) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = ($$09|0)==(8);
 $$$09 = $23 ? 9 : $$09;
 $24 = (($strm) + 40|0);
 $25 = HEAP32[$24>>2]|0;
 $27 = (FUNCTION_TABLE_iiii[$26 & 2047]($25,1,5824)|0);
 $28 = ($27|0)==(0|0);
 if ($28) {
  $$0 = -4;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($strm) + 28|0);
 HEAP32[$29>>2] = $27;
 HEAP32[$27>>2] = $strm;
 $30 = (($27) + 24|0);
 HEAP32[$30>>2] = $wrap$0;
 $31 = (($27) + 28|0);
 HEAP32[$31>>2] = 0;
 $32 = (($27) + 48|0);
 HEAP32[$32>>2] = $$$09;
 $33 = 1 << $$$09;
 $34 = (($27) + 44|0);
 HEAP32[$34>>2] = $33;
 $35 = (($33) + -1)|0;
 $36 = (($27) + 52|0);
 HEAP32[$36>>2] = $35;
 $37 = (($memLevel) + 7)|0;
 $38 = (($27) + 80|0);
 HEAP32[$38>>2] = $37;
 $39 = 1 << $37;
 $40 = (($27) + 76|0);
 HEAP32[$40>>2] = $39;
 $41 = (($39) + -1)|0;
 $42 = (($27) + 84|0);
 HEAP32[$42>>2] = $41;
 $43 = (($memLevel) + 9)|0;
 $44 = (($43>>>0) / 3)&-1;
 $45 = (($27) + 88|0);
 HEAP32[$45>>2] = $44;
 $46 = HEAP32[$6>>2]|0;
 $47 = HEAP32[$24>>2]|0;
 $48 = (FUNCTION_TABLE_iiii[$46 & 2047]($47,$33,2)|0);
 $49 = (($27) + 56|0);
 HEAP32[$49>>2] = $48;
 $50 = HEAP32[$6>>2]|0;
 $51 = HEAP32[$24>>2]|0;
 $52 = HEAP32[$34>>2]|0;
 $53 = (FUNCTION_TABLE_iiii[$50 & 2047]($51,$52,2)|0);
 $54 = (($27) + 64|0);
 HEAP32[$54>>2] = $53;
 $55 = HEAP32[$6>>2]|0;
 $56 = HEAP32[$24>>2]|0;
 $57 = HEAP32[$40>>2]|0;
 $58 = (FUNCTION_TABLE_iiii[$55 & 2047]($56,$57,2)|0);
 $59 = (($27) + 68|0);
 HEAP32[$59>>2] = $58;
 $60 = (($memLevel) + 6)|0;
 $61 = 1 << $60;
 $62 = (($27) + 5788|0);
 HEAP32[$62>>2] = $61;
 $63 = HEAP32[$6>>2]|0;
 $64 = HEAP32[$24>>2]|0;
 $65 = (FUNCTION_TABLE_iiii[$63 & 2047]($64,$61,4)|0);
 $66 = (($27) + 8|0);
 HEAP32[$66>>2] = $65;
 $67 = HEAP32[$62>>2]|0;
 $68 = $67 << 2;
 $69 = (($27) + 12|0);
 HEAP32[$69>>2] = $68;
 $70 = HEAP32[$49>>2]|0;
 $71 = ($70|0)==(0|0);
 if (!($71)) {
  $72 = HEAP32[$54>>2]|0;
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   $74 = HEAP32[$59>>2]|0;
   $75 = ($74|0)==(0|0);
   $76 = ($65|0)==(0|0);
   $or$cond13 = $75 | $76;
   if (!($or$cond13)) {
    $79 = $67 >>> 1;
    $80 = (($65) + ($79<<1)|0);
    $81 = (($27) + 5796|0);
    HEAP32[$81>>2] = $80;
    $82 = ($67*3)|0;
    $83 = (($65) + ($82)|0);
    $84 = (($27) + 5784|0);
    HEAP32[$84>>2] = $83;
    $85 = (($27) + 132|0);
    HEAP32[$85>>2] = $$level;
    $86 = (($27) + 136|0);
    HEAP32[$86>>2] = $strategy;
    $87 = (($27) + 36|0);
    HEAP8[$87>>0] = 8;
    $88 = (_deflateReset($strm)|0);
    $$0 = $88;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $77 = (($27) + 4|0);
 HEAP32[$77>>2] = 666;
 $78 = HEAP32[((403256 + 24|0))>>2]|0;
 HEAP32[$5>>2] = $78;
 (_deflateEnd($strm)|0);
 $$0 = -4;
 STACKTOP = sp;return ($$0|0);
}
function _deflateEnd($strm) {
 $strm = $strm|0;
 var $$0 = 0, $$pre = 0, $$pre$phi17Z2D = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($strm|0)==(0|0);
 if ($0) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($strm) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($2) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 switch ($5|0) {
 case 42: case 69: case 73: case 91: case 103: case 113: case 666:  {
  break;
 }
 default: {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 }
 $6 = (($2) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $14 = $2;
 } else {
  $9 = (($strm) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($strm) + 40|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$10 & 4095]($12,$7);
  $$pre = HEAP32[$1>>2]|0;
  $14 = $$pre;
 }
 $13 = (($14) + 68|0);
 $15 = HEAP32[$13>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $22 = $14;
 } else {
  $17 = (($strm) + 36|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($strm) + 40|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vii[$18 & 4095]($20,$15);
  $$pre12 = HEAP32[$1>>2]|0;
  $22 = $$pre12;
 }
 $21 = (($22) + 64|0);
 $23 = HEAP32[$21>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $30 = $22;
 } else {
  $25 = (($strm) + 36|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($strm) + 40|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$26 & 4095]($28,$23);
  $$pre13 = HEAP32[$1>>2]|0;
  $30 = $$pre13;
 }
 $29 = (($30) + 56|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = ($31|0)==(0|0);
 $$pre15 = (($strm) + 36|0);
 if ($32) {
  $$pre16 = (($strm) + 40|0);
  $$pre$phi17Z2D = $$pre16;$38 = $30;
 } else {
  $33 = HEAP32[$$pre15>>2]|0;
  $34 = (($strm) + 40|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vii[$33 & 4095]($35,$31);
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre$phi17Z2D = $34;$38 = $$pre14;
 }
 $36 = HEAP32[$$pre15>>2]|0;
 $37 = HEAP32[$$pre$phi17Z2D>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($37,$38);
 HEAP32[$1>>2] = 0;
 $39 = ($5|0)==(113);
 $40 = $39 ? -3 : 0;
 $$0 = $40;
 STACKTOP = sp;return ($$0|0);
}
function _deflateReset($strm) {
 $strm = $strm|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($strm|0)==(0|0);
 if ($0) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($strm) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($strm) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($strm) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($strm) + 20|0);
 HEAP32[$10>>2] = 0;
 $11 = (($strm) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (($strm) + 24|0);
 HEAP32[$12>>2] = 0;
 $13 = (($strm) + 44|0);
 HEAP32[$13>>2] = 2;
 $14 = (($2) + 20|0);
 HEAP32[$14>>2] = 0;
 $15 = (($2) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($2) + 16|0);
 HEAP32[$17>>2] = $16;
 $18 = (($2) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)<(0);
 if ($20) {
  $21 = (0 - ($19))|0;
  HEAP32[$18>>2] = $21;
  $23 = $21;
 } else {
  $23 = $19;
 }
 $22 = ($23|0)!=(0);
 $24 = $22 ? 42 : 113;
 $25 = (($2) + 4|0);
 HEAP32[$25>>2] = $24;
 $26 = ($23|0)==(2);
 if ($26) {
  $27 = (_crc32(0,0,0)|0);
  $30 = $27;
 } else {
  $28 = (_adler32(0,0,0)|0);
  $30 = $28;
 }
 $29 = (($strm) + 48|0);
 HEAP32[$29>>2] = $30;
 $31 = (($2) + 40|0);
 HEAP32[$31>>2] = 0;
 __tr_init($2);
 $32 = (($2) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 << 1;
 $35 = (($2) + 60|0);
 HEAP32[$35>>2] = $34;
 $36 = (($2) + 76|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + -1)|0;
 $39 = (($2) + 68|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($38<<1)|0);
 HEAP16[$41>>1] = 0;
 $42 = $37 << 1;
 $43 = (($42) + -2)|0;
 _memset(($40|0),0,($43|0))|0;
 $44 = (($2) + 132|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((400288 + (($45*12)|0)|0) + 2|0);
 $47 = HEAP16[$46>>1]|0;
 $48 = $47&65535;
 $49 = (($2) + 128|0);
 HEAP32[$49>>2] = $48;
 $50 = (400288 + (($45*12)|0)|0);
 $51 = HEAP16[$50>>1]|0;
 $52 = $51&65535;
 $53 = (($2) + 140|0);
 HEAP32[$53>>2] = $52;
 $54 = ((400288 + (($45*12)|0)|0) + 4|0);
 $55 = HEAP16[$54>>1]|0;
 $56 = $55&65535;
 $57 = (($2) + 144|0);
 HEAP32[$57>>2] = $56;
 $58 = ((400288 + (($45*12)|0)|0) + 6|0);
 $59 = HEAP16[$58>>1]|0;
 $60 = $59&65535;
 $61 = (($2) + 124|0);
 HEAP32[$61>>2] = $60;
 $62 = (($2) + 108|0);
 HEAP32[$62>>2] = 0;
 $63 = (($2) + 92|0);
 HEAP32[$63>>2] = 0;
 $64 = (($2) + 116|0);
 HEAP32[$64>>2] = 0;
 $65 = (($2) + 120|0);
 HEAP32[$65>>2] = 2;
 $66 = (($2) + 96|0);
 HEAP32[$66>>2] = 2;
 $67 = (($2) + 104|0);
 HEAP32[$67>>2] = 0;
 $68 = (($2) + 72|0);
 HEAP32[$68>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _deflate($strm,$flush) {
 $strm = $strm|0;
 $flush = $flush|0;
 var $$ = 0, $$$i = 0, $$$i14 = 0, $$$i16 = 0, $$$i18 = 0, $$$i20 = 0, $$$i22 = 0, $$$i24 = 0, $$0 = 0, $$10 = 0, $$phi$trans$insert76 = 0, $$pr = 0, $$pr27$pr = 0, $$pr27$pr$pre = 0, $$pr29 = 0, $$pr33$pr = 0, $$pr33$pr$pre = 0, $$pr36 = 0, $$pr37 = 0, $$pre = 0;
 var $$pre$phi84Z2D = 0, $$pre$phi86Z2D = 0, $$pre$phiZ2D = 0, $$pre47 = 0, $$pre48 = 0, $$pre73 = 0, $$pre74 = 0, $$pre75 = 0, $$pre77 = 0, $$pre78 = 0, $$pre79 = 0, $$pre82 = 0, $$pre83 = 0, $$pre85 = 0, $$pre88 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $beg$044 = 0, $beg$1 = 0, $beg$2 = 0, $beg1$0 = 0, $beg1$1 = 0, $beg1$2 = 0, $beg2$0 = 0, $beg2$1 = 0, $beg2$2 = 0;
 var $cond = 0, $level_flags$0 = 0, $not$ = 0, $or$cond = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond13 = 0, $or$cond3 = 0, $or$cond9 = 0, $phitmp = 0, $phitmp43 = 0, $val$0 = 0, $val3$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($strm|0)==(0|0);
 if ($0) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($strm) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = ($flush>>>0)>(4);
 $or$cond = $3 | $4;
 if ($or$cond) {
  $$0 = -2;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($strm) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if (!($7)) {
   $8 = HEAP32[$strm>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $10 = (($strm) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0);
    if (!($12)) {
     break;
    }
   }
   $13 = (($2) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)!=(666);
   $16 = ($flush|0)==(4);
   $or$cond9 = $15 | $16;
   if ($or$cond9) {
    $19 = (($strm) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0);
    if ($21) {
     $22 = HEAP32[((403256 + 28|0))>>2]|0;
     $23 = (($strm) + 24|0);
     HEAP32[$23>>2] = $22;
     $$0 = -5;
     STACKTOP = sp;return ($$0|0);
    }
    HEAP32[$2>>2] = $strm;
    $24 = (($2) + 40|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$24>>2] = $flush;
    $26 = ($14|0)==(42);
    do {
     if ($26) {
      $27 = (($2) + 24|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($28|0)==(2);
      if (!($29)) {
       $197 = (($2) + 48|0);
       $198 = HEAP32[$197>>2]|0;
       $199 = $198 << 12;
       $200 = (($199) + -30720)|0;
       $201 = (($2) + 136|0);
       $202 = HEAP32[$201>>2]|0;
       $203 = ($202|0)>(1);
       if ($203) {
        $level_flags$0 = 0;
       } else {
        $204 = (($2) + 132|0);
        $205 = HEAP32[$204>>2]|0;
        $206 = ($205|0)<(2);
        if ($206) {
         $level_flags$0 = 0;
        } else {
         $207 = ($205|0)<(6);
         if ($207) {
          $level_flags$0 = 64;
         } else {
          $208 = ($205|0)==(6);
          $$ = $208 ? 128 : 192;
          $level_flags$0 = $$;
         }
        }
       }
       $209 = $level_flags$0 | $200;
       $210 = (($2) + 108|0);
       $211 = HEAP32[$210>>2]|0;
       $212 = ($211|0)==(0);
       $213 = $209 | 32;
       $214 = $212 ? $209 : $213;
       $215 = (($214>>>0) % 31)&-1;
       $$10 = $214 | $215;
       $216 = $$10 ^ 31;
       HEAP32[$13>>2] = 113;
       $217 = $214 >>> 8;
       $218 = $217&255;
       $219 = (($2) + 20|0);
       $220 = HEAP32[$219>>2]|0;
       $221 = (($220) + 1)|0;
       HEAP32[$219>>2] = $221;
       $222 = (($2) + 8|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = (($223) + ($220)|0);
       HEAP8[$224>>0] = $218;
       $225 = $216&255;
       $226 = HEAP32[$219>>2]|0;
       $227 = (($226) + 1)|0;
       HEAP32[$219>>2] = $227;
       $228 = HEAP32[$222>>2]|0;
       $229 = (($228) + ($226)|0);
       HEAP8[$229>>0] = $225;
       $230 = HEAP32[$210>>2]|0;
       $231 = ($230|0)==(0);
       $$pre88 = (($strm) + 48|0);
       if (!($231)) {
        $232 = HEAP32[$$pre88>>2]|0;
        $233 = $232 >>> 16;
        $234 = $232 >>> 24;
        $235 = $234&255;
        $236 = HEAP32[$219>>2]|0;
        $237 = (($236) + 1)|0;
        HEAP32[$219>>2] = $237;
        $238 = HEAP32[$222>>2]|0;
        $239 = (($238) + ($236)|0);
        HEAP8[$239>>0] = $235;
        $240 = $233&255;
        $241 = HEAP32[$219>>2]|0;
        $242 = (($241) + 1)|0;
        HEAP32[$219>>2] = $242;
        $243 = HEAP32[$222>>2]|0;
        $244 = (($243) + ($241)|0);
        HEAP8[$244>>0] = $240;
        $245 = HEAP32[$$pre88>>2]|0;
        $246 = $245 >>> 8;
        $247 = $246&255;
        $248 = HEAP32[$219>>2]|0;
        $249 = (($248) + 1)|0;
        HEAP32[$219>>2] = $249;
        $250 = HEAP32[$222>>2]|0;
        $251 = (($250) + ($248)|0);
        HEAP8[$251>>0] = $247;
        $252 = $245&255;
        $253 = HEAP32[$219>>2]|0;
        $254 = (($253) + 1)|0;
        HEAP32[$219>>2] = $254;
        $255 = HEAP32[$222>>2]|0;
        $256 = (($255) + ($253)|0);
        HEAP8[$256>>0] = $252;
       }
       $257 = (_adler32(0,0,0)|0);
       HEAP32[$$pre88>>2] = $257;
       $$pr = HEAP32[$13>>2]|0;
       $259 = $$pr;
       label = 32;
       break;
      }
      $30 = (_crc32(0,0,0)|0);
      $31 = (($strm) + 48|0);
      HEAP32[$31>>2] = $30;
      $32 = (($2) + 20|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($33) + 1)|0;
      HEAP32[$32>>2] = $34;
      $35 = (($2) + 8|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($36) + ($33)|0);
      HEAP8[$37>>0] = 31;
      $38 = HEAP32[$32>>2]|0;
      $39 = (($38) + 1)|0;
      HEAP32[$32>>2] = $39;
      $40 = HEAP32[$35>>2]|0;
      $41 = (($40) + ($38)|0);
      HEAP8[$41>>0] = -117;
      $42 = HEAP32[$32>>2]|0;
      $43 = (($42) + 1)|0;
      HEAP32[$32>>2] = $43;
      $44 = HEAP32[$35>>2]|0;
      $45 = (($44) + ($42)|0);
      HEAP8[$45>>0] = 8;
      $46 = (($2) + 28|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($47|0)==(0|0);
      if ($48) {
       $49 = HEAP32[$32>>2]|0;
       $50 = (($49) + 1)|0;
       HEAP32[$32>>2] = $50;
       $51 = HEAP32[$35>>2]|0;
       $52 = (($51) + ($49)|0);
       HEAP8[$52>>0] = 0;
       $53 = HEAP32[$32>>2]|0;
       $54 = (($53) + 1)|0;
       HEAP32[$32>>2] = $54;
       $55 = HEAP32[$35>>2]|0;
       $56 = (($55) + ($53)|0);
       HEAP8[$56>>0] = 0;
       $57 = HEAP32[$32>>2]|0;
       $58 = (($57) + 1)|0;
       HEAP32[$32>>2] = $58;
       $59 = HEAP32[$35>>2]|0;
       $60 = (($59) + ($57)|0);
       HEAP8[$60>>0] = 0;
       $61 = HEAP32[$32>>2]|0;
       $62 = (($61) + 1)|0;
       HEAP32[$32>>2] = $62;
       $63 = HEAP32[$35>>2]|0;
       $64 = (($63) + ($61)|0);
       HEAP8[$64>>0] = 0;
       $65 = HEAP32[$32>>2]|0;
       $66 = (($65) + 1)|0;
       HEAP32[$32>>2] = $66;
       $67 = HEAP32[$35>>2]|0;
       $68 = (($67) + ($65)|0);
       HEAP8[$68>>0] = 0;
       $69 = (($2) + 132|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = ($70|0)==(9);
       if ($71) {
        $80 = 2;
       } else {
        $72 = (($2) + 136|0);
        $73 = HEAP32[$72>>2]|0;
        $74 = ($73|0)>(1);
        if ($74) {
         $80 = 4;
        } else {
         $75 = ($70|0)<(2);
         $phitmp = $75 ? 4 : 0;
         $80 = $phitmp;
        }
       }
       $76 = HEAP32[$32>>2]|0;
       $77 = (($76) + 1)|0;
       HEAP32[$32>>2] = $77;
       $78 = HEAP32[$35>>2]|0;
       $79 = (($78) + ($76)|0);
       HEAP8[$79>>0] = $80;
       $81 = HEAP32[$32>>2]|0;
       $82 = (($81) + 1)|0;
       HEAP32[$32>>2] = $82;
       $83 = HEAP32[$35>>2]|0;
       $84 = (($83) + ($81)|0);
       HEAP8[$84>>0] = 3;
       HEAP32[$13>>2] = 113;
       break;
      }
      $85 = HEAP32[$47>>2]|0;
      $86 = ($85|0)!=(0);
      $87 = $86&1;
      $88 = (($47) + 44|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($89|0)!=(0);
      $91 = $90 ? 2 : 0;
      $92 = $91 | $87;
      $93 = (($47) + 16|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = ($94|0)==(0|0);
      $96 = $95 ? 0 : 4;
      $97 = $92 | $96;
      $98 = (($47) + 28|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = ($99|0)==(0|0);
      $101 = $100 ? 0 : 8;
      $102 = $97 | $101;
      $103 = (($47) + 36|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = ($104|0)==(0|0);
      $106 = $105 ? 0 : 16;
      $107 = $102 | $106;
      $108 = $107&255;
      $109 = HEAP32[$32>>2]|0;
      $110 = (($109) + 1)|0;
      HEAP32[$32>>2] = $110;
      $111 = HEAP32[$35>>2]|0;
      $112 = (($111) + ($109)|0);
      HEAP8[$112>>0] = $108;
      $113 = HEAP32[$46>>2]|0;
      $114 = (($113) + 4|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = $115&255;
      $117 = HEAP32[$32>>2]|0;
      $118 = (($117) + 1)|0;
      HEAP32[$32>>2] = $118;
      $119 = HEAP32[$35>>2]|0;
      $120 = (($119) + ($117)|0);
      HEAP8[$120>>0] = $116;
      $121 = HEAP32[$46>>2]|0;
      $122 = (($121) + 4|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = $123 >>> 8;
      $125 = $124&255;
      $126 = HEAP32[$32>>2]|0;
      $127 = (($126) + 1)|0;
      HEAP32[$32>>2] = $127;
      $128 = HEAP32[$35>>2]|0;
      $129 = (($128) + ($126)|0);
      HEAP8[$129>>0] = $125;
      $130 = HEAP32[$46>>2]|0;
      $131 = (($130) + 4|0);
      $132 = HEAP32[$131>>2]|0;
      $133 = $132 >>> 16;
      $134 = $133&255;
      $135 = HEAP32[$32>>2]|0;
      $136 = (($135) + 1)|0;
      HEAP32[$32>>2] = $136;
      $137 = HEAP32[$35>>2]|0;
      $138 = (($137) + ($135)|0);
      HEAP8[$138>>0] = $134;
      $139 = HEAP32[$46>>2]|0;
      $140 = (($139) + 4|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = $141 >>> 24;
      $143 = $142&255;
      $144 = HEAP32[$32>>2]|0;
      $145 = (($144) + 1)|0;
      HEAP32[$32>>2] = $145;
      $146 = HEAP32[$35>>2]|0;
      $147 = (($146) + ($144)|0);
      HEAP8[$147>>0] = $143;
      $148 = (($2) + 132|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = ($149|0)==(9);
      if ($150) {
       $159 = 2;
      } else {
       $151 = (($2) + 136|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = ($152|0)>(1);
       if ($153) {
        $159 = 4;
       } else {
        $154 = ($149|0)<(2);
        $phitmp43 = $154 ? 4 : 0;
        $159 = $phitmp43;
       }
      }
      $155 = HEAP32[$32>>2]|0;
      $156 = (($155) + 1)|0;
      HEAP32[$32>>2] = $156;
      $157 = HEAP32[$35>>2]|0;
      $158 = (($157) + ($155)|0);
      HEAP8[$158>>0] = $159;
      $160 = HEAP32[$46>>2]|0;
      $161 = (($160) + 12|0);
      $162 = HEAP32[$161>>2]|0;
      $163 = $162&255;
      $164 = HEAP32[$32>>2]|0;
      $165 = (($164) + 1)|0;
      HEAP32[$32>>2] = $165;
      $166 = HEAP32[$35>>2]|0;
      $167 = (($166) + ($164)|0);
      HEAP8[$167>>0] = $163;
      $168 = HEAP32[$46>>2]|0;
      $169 = (($168) + 16|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = ($170|0)==(0|0);
      if ($171) {
       $189 = $168;
      } else {
       $172 = (($168) + 20|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = $173&255;
       $175 = HEAP32[$32>>2]|0;
       $176 = (($175) + 1)|0;
       HEAP32[$32>>2] = $176;
       $177 = HEAP32[$35>>2]|0;
       $178 = (($177) + ($175)|0);
       HEAP8[$178>>0] = $174;
       $179 = HEAP32[$46>>2]|0;
       $180 = (($179) + 20|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = $181 >>> 8;
       $183 = $182&255;
       $184 = HEAP32[$32>>2]|0;
       $185 = (($184) + 1)|0;
       HEAP32[$32>>2] = $185;
       $186 = HEAP32[$35>>2]|0;
       $187 = (($186) + ($184)|0);
       HEAP8[$187>>0] = $183;
       $$pre = HEAP32[$46>>2]|0;
       $189 = $$pre;
      }
      $188 = (($189) + 44|0);
      $190 = HEAP32[$188>>2]|0;
      $191 = ($190|0)==(0);
      if (!($191)) {
       $192 = HEAP32[$31>>2]|0;
       $193 = HEAP32[$35>>2]|0;
       $194 = HEAP32[$32>>2]|0;
       $195 = (_crc32($192,$193,$194)|0);
       HEAP32[$31>>2] = $195;
      }
      $196 = (($2) + 32|0);
      HEAP32[$196>>2] = 0;
      HEAP32[$13>>2] = 69;
      $$pre$phiZ2D = $46;
      label = 34;
     } else {
      $259 = $14;
      label = 32;
     }
    } while(0);
    if ((label|0) == 32) {
     $258 = ($259|0)==(69);
     if ($258) {
      $$pre82 = (($2) + 28|0);
      $$pre$phiZ2D = $$pre82;
      label = 34;
     } else {
      $$pr27$pr = $259;
      label = 55;
     }
    }
    do {
     if ((label|0) == 34) {
      $260 = HEAP32[$$pre$phiZ2D>>2]|0;
      $261 = (($260) + 16|0);
      $262 = HEAP32[$261>>2]|0;
      $263 = ($262|0)==(0|0);
      if ($263) {
       HEAP32[$13>>2] = 73;
       $357 = $260;
       label = 57;
       break;
      }
      $264 = (($2) + 20|0);
      $265 = HEAP32[$264>>2]|0;
      $266 = (($2) + 32|0);
      $267 = HEAP32[$266>>2]|0;
      $268 = (($260) + 20|0);
      $269 = HEAP32[$268>>2]|0;
      $270 = $269 & 65535;
      $271 = ($267>>>0)<($270>>>0);
      L55: do {
       if ($271) {
        $272 = (($2) + 12|0);
        $273 = (($strm) + 48|0);
        $274 = (($2) + 8|0);
        $275 = (($strm) + 20|0);
        $278 = $265;$280 = $260;$795 = $267;$beg$044 = $265;
        while(1) {
         $276 = HEAP32[$272>>2]|0;
         $277 = ($278|0)==($276|0);
         if ($277) {
          $279 = (($280) + 44|0);
          $281 = HEAP32[$279>>2]|0;
          $282 = ($281|0)!=(0);
          $283 = ($278>>>0)>($beg$044>>>0);
          $or$cond11 = $282 & $283;
          if ($or$cond11) {
           $284 = HEAP32[$273>>2]|0;
           $285 = HEAP32[$274>>2]|0;
           $286 = (($285) + ($beg$044)|0);
           $287 = (($278) - ($beg$044))|0;
           $288 = (_crc32($284,$286,$287)|0);
           HEAP32[$273>>2] = $288;
          }
          $289 = HEAP32[$1>>2]|0;
          $290 = (($289) + 20|0);
          $291 = HEAP32[$290>>2]|0;
          $292 = HEAP32[$19>>2]|0;
          $293 = ($291>>>0)>($292>>>0);
          $$$i24 = $293 ? $292 : $291;
          $294 = ($$$i24|0)==(0);
          if (!($294)) {
           $295 = HEAP32[$5>>2]|0;
           $296 = (($289) + 16|0);
           $297 = HEAP32[$296>>2]|0;
           _memcpy(($295|0),($297|0),($$$i24|0))|0;
           $298 = HEAP32[$5>>2]|0;
           $299 = (($298) + ($$$i24)|0);
           HEAP32[$5>>2] = $299;
           $300 = HEAP32[$1>>2]|0;
           $301 = (($300) + 16|0);
           $302 = HEAP32[$301>>2]|0;
           $303 = (($302) + ($$$i24)|0);
           HEAP32[$301>>2] = $303;
           $304 = HEAP32[$275>>2]|0;
           $305 = (($304) + ($$$i24))|0;
           HEAP32[$275>>2] = $305;
           $306 = HEAP32[$19>>2]|0;
           $307 = (($306) - ($$$i24))|0;
           HEAP32[$19>>2] = $307;
           $308 = HEAP32[$1>>2]|0;
           $309 = (($308) + 20|0);
           $310 = HEAP32[$309>>2]|0;
           $311 = (($310) - ($$$i24))|0;
           HEAP32[$309>>2] = $311;
           $312 = ($310|0)==($$$i24|0);
           if ($312) {
            $313 = (($308) + 8|0);
            $314 = HEAP32[$313>>2]|0;
            $315 = (($308) + 16|0);
            HEAP32[$315>>2] = $314;
           }
          }
          $316 = HEAP32[$264>>2]|0;
          $317 = HEAP32[$272>>2]|0;
          $318 = ($316|0)==($317|0);
          if ($318) {
           break;
          }
          $$pre74 = HEAP32[$266>>2]|0;
          $$pre75 = HEAP32[$$pre$phiZ2D>>2]|0;
          $320 = $$pre75;$323 = $$pre74;$326 = $316;$beg$1 = $316;
         } else {
          $320 = $280;$323 = $795;$326 = $278;$beg$1 = $beg$044;
         }
         $319 = (($320) + 16|0);
         $321 = HEAP32[$319>>2]|0;
         $322 = (($321) + ($323)|0);
         $324 = HEAP8[$322>>0]|0;
         $325 = (($326) + 1)|0;
         HEAP32[$264>>2] = $325;
         $327 = HEAP32[$274>>2]|0;
         $328 = (($327) + ($326)|0);
         HEAP8[$328>>0] = $324;
         $329 = HEAP32[$266>>2]|0;
         $330 = (($329) + 1)|0;
         HEAP32[$266>>2] = $330;
         $331 = HEAP32[$$pre$phiZ2D>>2]|0;
         $332 = (($331) + 20|0);
         $333 = HEAP32[$332>>2]|0;
         $334 = $333 & 65535;
         $335 = ($330>>>0)<($334>>>0);
         if (!($335)) {
          $337 = $331;$beg$2 = $beg$1;
          break L55;
         }
         $$pre73 = HEAP32[$264>>2]|0;
         $278 = $$pre73;$280 = $331;$795 = $330;$beg$044 = $beg$1;
        }
        $$pre47 = HEAP32[$$pre$phiZ2D>>2]|0;
        $337 = $$pre47;$beg$2 = $316;
       } else {
        $337 = $260;$beg$2 = $265;
       }
      } while(0);
      $336 = (($337) + 44|0);
      $338 = HEAP32[$336>>2]|0;
      $339 = ($338|0)==(0);
      if ($339) {
       $351 = $337;
      } else {
       $340 = HEAP32[$264>>2]|0;
       $341 = ($340>>>0)>($beg$2>>>0);
       if ($341) {
        $342 = (($strm) + 48|0);
        $343 = HEAP32[$342>>2]|0;
        $344 = (($2) + 8|0);
        $345 = HEAP32[$344>>2]|0;
        $346 = (($345) + ($beg$2)|0);
        $347 = (($340) - ($beg$2))|0;
        $348 = (_crc32($343,$346,$347)|0);
        HEAP32[$342>>2] = $348;
        $$pre48 = HEAP32[$$pre$phiZ2D>>2]|0;
        $351 = $$pre48;
       } else {
        $351 = $337;
       }
      }
      $349 = HEAP32[$266>>2]|0;
      $350 = (($351) + 20|0);
      $352 = HEAP32[$350>>2]|0;
      $353 = ($349|0)==($352|0);
      if ($353) {
       HEAP32[$266>>2] = 0;
       HEAP32[$13>>2] = 73;
       $357 = $351;
       label = 57;
       break;
      } else {
       $$pr27$pr$pre = HEAP32[$13>>2]|0;
       $$pr27$pr = $$pr27$pr$pre;
       label = 55;
       break;
      }
     }
    } while(0);
    if ((label|0) == 55) {
     $354 = ($$pr27$pr|0)==(73);
     if ($354) {
      $$phi$trans$insert76 = (($2) + 28|0);
      $$pre77 = HEAP32[$$phi$trans$insert76>>2]|0;
      $357 = $$pre77;
      label = 57;
     } else {
      $436 = $$pr27$pr;
      label = 76;
     }
    }
    do {
     if ((label|0) == 57) {
      $355 = (($2) + 28|0);
      $356 = (($357) + 28|0);
      $358 = HEAP32[$356>>2]|0;
      $359 = ($358|0)==(0|0);
      if ($359) {
       HEAP32[$13>>2] = 91;
       $$pre$phi84Z2D = $355;
       label = 78;
       break;
      }
      $360 = (($2) + 20|0);
      $361 = HEAP32[$360>>2]|0;
      $362 = (($2) + 12|0);
      $363 = (($strm) + 48|0);
      $364 = (($2) + 8|0);
      $365 = (($strm) + 20|0);
      $366 = (($2) + 32|0);
      $369 = $361;$beg1$0 = $361;
      while(1) {
       $367 = HEAP32[$362>>2]|0;
       $368 = ($369|0)==($367|0);
       if ($368) {
        $370 = HEAP32[$355>>2]|0;
        $371 = (($370) + 44|0);
        $372 = HEAP32[$371>>2]|0;
        $373 = ($372|0)!=(0);
        $374 = ($369>>>0)>($beg1$0>>>0);
        $or$cond12 = $373 & $374;
        if ($or$cond12) {
         $375 = HEAP32[$363>>2]|0;
         $376 = HEAP32[$364>>2]|0;
         $377 = (($376) + ($beg1$0)|0);
         $378 = (($369) - ($beg1$0))|0;
         $379 = (_crc32($375,$377,$378)|0);
         HEAP32[$363>>2] = $379;
        }
        $380 = HEAP32[$1>>2]|0;
        $381 = (($380) + 20|0);
        $382 = HEAP32[$381>>2]|0;
        $383 = HEAP32[$19>>2]|0;
        $384 = ($382>>>0)>($383>>>0);
        $$$i22 = $384 ? $383 : $382;
        $385 = ($$$i22|0)==(0);
        if (!($385)) {
         $386 = HEAP32[$5>>2]|0;
         $387 = (($380) + 16|0);
         $388 = HEAP32[$387>>2]|0;
         _memcpy(($386|0),($388|0),($$$i22|0))|0;
         $389 = HEAP32[$5>>2]|0;
         $390 = (($389) + ($$$i22)|0);
         HEAP32[$5>>2] = $390;
         $391 = HEAP32[$1>>2]|0;
         $392 = (($391) + 16|0);
         $393 = HEAP32[$392>>2]|0;
         $394 = (($393) + ($$$i22)|0);
         HEAP32[$392>>2] = $394;
         $395 = HEAP32[$365>>2]|0;
         $396 = (($395) + ($$$i22))|0;
         HEAP32[$365>>2] = $396;
         $397 = HEAP32[$19>>2]|0;
         $398 = (($397) - ($$$i22))|0;
         HEAP32[$19>>2] = $398;
         $399 = HEAP32[$1>>2]|0;
         $400 = (($399) + 20|0);
         $401 = HEAP32[$400>>2]|0;
         $402 = (($401) - ($$$i22))|0;
         HEAP32[$400>>2] = $402;
         $403 = ($401|0)==($$$i22|0);
         if ($403) {
          $404 = (($399) + 8|0);
          $405 = HEAP32[$404>>2]|0;
          $406 = (($399) + 16|0);
          HEAP32[$406>>2] = $405;
         }
        }
        $407 = HEAP32[$360>>2]|0;
        $408 = HEAP32[$362>>2]|0;
        $409 = ($407|0)==($408|0);
        if ($409) {
         $beg1$2 = $407;$val$0 = 1;
         break;
        } else {
         $418 = $407;$beg1$1 = $407;
        }
       } else {
        $418 = $369;$beg1$1 = $beg1$0;
       }
       $410 = HEAP32[$366>>2]|0;
       $411 = (($410) + 1)|0;
       HEAP32[$366>>2] = $411;
       $412 = HEAP32[$355>>2]|0;
       $413 = (($412) + 28|0);
       $414 = HEAP32[$413>>2]|0;
       $415 = (($414) + ($410)|0);
       $416 = HEAP8[$415>>0]|0;
       $417 = (($418) + 1)|0;
       HEAP32[$360>>2] = $417;
       $419 = HEAP32[$364>>2]|0;
       $420 = (($419) + ($418)|0);
       HEAP8[$420>>0] = $416;
       $421 = ($416<<24>>24)==(0);
       if ($421) {
        label = 68;
        break;
       }
       $$pre78 = HEAP32[$360>>2]|0;
       $369 = $$pre78;$beg1$0 = $beg1$1;
      }
      if ((label|0) == 68) {
       $422 = $416&255;
       $beg1$2 = $beg1$1;$val$0 = $422;
      }
      $423 = HEAP32[$355>>2]|0;
      $424 = (($423) + 44|0);
      $425 = HEAP32[$424>>2]|0;
      $426 = ($425|0)==(0);
      if (!($426)) {
       $427 = HEAP32[$360>>2]|0;
       $428 = ($427>>>0)>($beg1$2>>>0);
       if ($428) {
        $429 = HEAP32[$363>>2]|0;
        $430 = HEAP32[$364>>2]|0;
        $431 = (($430) + ($beg1$2)|0);
        $432 = (($427) - ($beg1$2))|0;
        $433 = (_crc32($429,$431,$432)|0);
        HEAP32[$363>>2] = $433;
       }
      }
      $434 = ($val$0|0)==(0);
      if ($434) {
       HEAP32[$366>>2] = 0;
       HEAP32[$13>>2] = 91;
       $$pre$phi84Z2D = $355;
       label = 78;
       break;
      } else {
       $$pr29 = HEAP32[$13>>2]|0;
       $436 = $$pr29;
       label = 76;
       break;
      }
     }
    } while(0);
    if ((label|0) == 76) {
     $435 = ($436|0)==(91);
     if ($435) {
      $$pre83 = (($2) + 28|0);
      $$pre$phi84Z2D = $$pre83;
      label = 78;
     } else {
      $$pr33$pr = $436;
      label = 97;
     }
    }
    do {
     if ((label|0) == 78) {
      $437 = HEAP32[$$pre$phi84Z2D>>2]|0;
      $438 = (($437) + 36|0);
      $439 = HEAP32[$438>>2]|0;
      $440 = ($439|0)==(0|0);
      if ($440) {
       HEAP32[$13>>2] = 103;
       $$pre$phi86Z2D = $$pre$phi84Z2D;
       label = 99;
       break;
      }
      $441 = (($2) + 20|0);
      $442 = HEAP32[$441>>2]|0;
      $443 = (($2) + 12|0);
      $444 = (($strm) + 48|0);
      $445 = (($2) + 8|0);
      $446 = (($strm) + 20|0);
      $447 = (($2) + 32|0);
      $450 = $442;$beg2$0 = $442;
      while(1) {
       $448 = HEAP32[$443>>2]|0;
       $449 = ($450|0)==($448|0);
       if ($449) {
        $451 = HEAP32[$$pre$phi84Z2D>>2]|0;
        $452 = (($451) + 44|0);
        $453 = HEAP32[$452>>2]|0;
        $454 = ($453|0)!=(0);
        $455 = ($450>>>0)>($beg2$0>>>0);
        $or$cond13 = $454 & $455;
        if ($or$cond13) {
         $456 = HEAP32[$444>>2]|0;
         $457 = HEAP32[$445>>2]|0;
         $458 = (($457) + ($beg2$0)|0);
         $459 = (($450) - ($beg2$0))|0;
         $460 = (_crc32($456,$458,$459)|0);
         HEAP32[$444>>2] = $460;
        }
        $461 = HEAP32[$1>>2]|0;
        $462 = (($461) + 20|0);
        $463 = HEAP32[$462>>2]|0;
        $464 = HEAP32[$19>>2]|0;
        $465 = ($463>>>0)>($464>>>0);
        $$$i20 = $465 ? $464 : $463;
        $466 = ($$$i20|0)==(0);
        if (!($466)) {
         $467 = HEAP32[$5>>2]|0;
         $468 = (($461) + 16|0);
         $469 = HEAP32[$468>>2]|0;
         _memcpy(($467|0),($469|0),($$$i20|0))|0;
         $470 = HEAP32[$5>>2]|0;
         $471 = (($470) + ($$$i20)|0);
         HEAP32[$5>>2] = $471;
         $472 = HEAP32[$1>>2]|0;
         $473 = (($472) + 16|0);
         $474 = HEAP32[$473>>2]|0;
         $475 = (($474) + ($$$i20)|0);
         HEAP32[$473>>2] = $475;
         $476 = HEAP32[$446>>2]|0;
         $477 = (($476) + ($$$i20))|0;
         HEAP32[$446>>2] = $477;
         $478 = HEAP32[$19>>2]|0;
         $479 = (($478) - ($$$i20))|0;
         HEAP32[$19>>2] = $479;
         $480 = HEAP32[$1>>2]|0;
         $481 = (($480) + 20|0);
         $482 = HEAP32[$481>>2]|0;
         $483 = (($482) - ($$$i20))|0;
         HEAP32[$481>>2] = $483;
         $484 = ($482|0)==($$$i20|0);
         if ($484) {
          $485 = (($480) + 8|0);
          $486 = HEAP32[$485>>2]|0;
          $487 = (($480) + 16|0);
          HEAP32[$487>>2] = $486;
         }
        }
        $488 = HEAP32[$441>>2]|0;
        $489 = HEAP32[$443>>2]|0;
        $490 = ($488|0)==($489|0);
        if ($490) {
         $beg2$2 = $488;$val3$0 = 1;
         break;
        } else {
         $499 = $488;$beg2$1 = $488;
        }
       } else {
        $499 = $450;$beg2$1 = $beg2$0;
       }
       $491 = HEAP32[$447>>2]|0;
       $492 = (($491) + 1)|0;
       HEAP32[$447>>2] = $492;
       $493 = HEAP32[$$pre$phi84Z2D>>2]|0;
       $494 = (($493) + 36|0);
       $495 = HEAP32[$494>>2]|0;
       $496 = (($495) + ($491)|0);
       $497 = HEAP8[$496>>0]|0;
       $498 = (($499) + 1)|0;
       HEAP32[$441>>2] = $498;
       $500 = HEAP32[$445>>2]|0;
       $501 = (($500) + ($499)|0);
       HEAP8[$501>>0] = $497;
       $502 = ($497<<24>>24)==(0);
       if ($502) {
        label = 89;
        break;
       }
       $$pre79 = HEAP32[$441>>2]|0;
       $450 = $$pre79;$beg2$0 = $beg2$1;
      }
      if ((label|0) == 89) {
       $503 = $497&255;
       $beg2$2 = $beg2$1;$val3$0 = $503;
      }
      $504 = HEAP32[$$pre$phi84Z2D>>2]|0;
      $505 = (($504) + 44|0);
      $506 = HEAP32[$505>>2]|0;
      $507 = ($506|0)==(0);
      if (!($507)) {
       $508 = HEAP32[$441>>2]|0;
       $509 = ($508>>>0)>($beg2$2>>>0);
       if ($509) {
        $510 = HEAP32[$444>>2]|0;
        $511 = HEAP32[$445>>2]|0;
        $512 = (($511) + ($beg2$2)|0);
        $513 = (($508) - ($beg2$2))|0;
        $514 = (_crc32($510,$512,$513)|0);
        HEAP32[$444>>2] = $514;
       }
      }
      $515 = ($val3$0|0)==(0);
      if ($515) {
       HEAP32[$13>>2] = 103;
       $$pre$phi86Z2D = $$pre$phi84Z2D;
       label = 99;
       break;
      } else {
       $$pr33$pr$pre = HEAP32[$13>>2]|0;
       $$pr33$pr = $$pr33$pr$pre;
       label = 97;
       break;
      }
     }
    } while(0);
    if ((label|0) == 97) {
     $516 = ($$pr33$pr|0)==(103);
     if ($516) {
      $$pre85 = (($2) + 28|0);
      $$pre$phi86Z2D = $$pre85;
      label = 99;
     }
    }
    do {
     if ((label|0) == 99) {
      $517 = HEAP32[$$pre$phi86Z2D>>2]|0;
      $518 = (($517) + 44|0);
      $519 = HEAP32[$518>>2]|0;
      $520 = ($519|0)==(0);
      if ($520) {
       HEAP32[$13>>2] = 113;
       break;
      }
      $521 = (($2) + 20|0);
      $522 = HEAP32[$521>>2]|0;
      $523 = (($522) + 2)|0;
      $524 = (($2) + 12|0);
      $525 = HEAP32[$524>>2]|0;
      $526 = ($523>>>0)>($525>>>0);
      if ($526) {
       $527 = HEAP32[$1>>2]|0;
       $528 = (($527) + 20|0);
       $529 = HEAP32[$528>>2]|0;
       $530 = HEAP32[$19>>2]|0;
       $531 = ($529>>>0)>($530>>>0);
       $$$i18 = $531 ? $530 : $529;
       $532 = ($$$i18|0)==(0);
       if (!($532)) {
        $533 = HEAP32[$5>>2]|0;
        $534 = (($527) + 16|0);
        $535 = HEAP32[$534>>2]|0;
        _memcpy(($533|0),($535|0),($$$i18|0))|0;
        $536 = HEAP32[$5>>2]|0;
        $537 = (($536) + ($$$i18)|0);
        HEAP32[$5>>2] = $537;
        $538 = HEAP32[$1>>2]|0;
        $539 = (($538) + 16|0);
        $540 = HEAP32[$539>>2]|0;
        $541 = (($540) + ($$$i18)|0);
        HEAP32[$539>>2] = $541;
        $542 = (($strm) + 20|0);
        $543 = HEAP32[$542>>2]|0;
        $544 = (($543) + ($$$i18))|0;
        HEAP32[$542>>2] = $544;
        $545 = HEAP32[$19>>2]|0;
        $546 = (($545) - ($$$i18))|0;
        HEAP32[$19>>2] = $546;
        $547 = HEAP32[$1>>2]|0;
        $548 = (($547) + 20|0);
        $549 = HEAP32[$548>>2]|0;
        $550 = (($549) - ($$$i18))|0;
        HEAP32[$548>>2] = $550;
        $551 = ($549|0)==($$$i18|0);
        if ($551) {
         $552 = (($547) + 8|0);
         $553 = HEAP32[$552>>2]|0;
         $554 = (($547) + 16|0);
         HEAP32[$554>>2] = $553;
        }
       }
      }
      $555 = HEAP32[$521>>2]|0;
      $556 = (($555) + 2)|0;
      $557 = HEAP32[$524>>2]|0;
      $558 = ($556>>>0)>($557>>>0);
      if (!($558)) {
       $559 = (($strm) + 48|0);
       $560 = HEAP32[$559>>2]|0;
       $561 = $560&255;
       $562 = (($555) + 1)|0;
       HEAP32[$521>>2] = $562;
       $563 = (($2) + 8|0);
       $564 = HEAP32[$563>>2]|0;
       $565 = (($564) + ($555)|0);
       HEAP8[$565>>0] = $561;
       $566 = HEAP32[$559>>2]|0;
       $567 = $566 >>> 8;
       $568 = $567&255;
       $569 = HEAP32[$521>>2]|0;
       $570 = (($569) + 1)|0;
       HEAP32[$521>>2] = $570;
       $571 = HEAP32[$563>>2]|0;
       $572 = (($571) + ($569)|0);
       HEAP8[$572>>0] = $568;
       $573 = (_crc32(0,0,0)|0);
       HEAP32[$559>>2] = $573;
       HEAP32[$13>>2] = 113;
      }
     }
    } while(0);
    $574 = (($2) + 20|0);
    $575 = HEAP32[$574>>2]|0;
    $576 = ($575|0)==(0);
    if ($576) {
     $607 = (($strm) + 4|0);
     $608 = HEAP32[$607>>2]|0;
     $609 = ($608|0)==(0);
     if ($609) {
      $610 = ($25|0)>=($flush|0);
      $611 = ($flush|0)!=(4);
      $or$cond3 = $610 & $611;
      if ($or$cond3) {
       $612 = HEAP32[((403256 + 28|0))>>2]|0;
       $613 = (($strm) + 24|0);
       HEAP32[$613>>2] = $612;
       $$0 = -5;
       STACKTOP = sp;return ($$0|0);
      }
     }
    } else {
     $577 = HEAP32[$1>>2]|0;
     $578 = (($577) + 20|0);
     $579 = HEAP32[$578>>2]|0;
     $580 = HEAP32[$19>>2]|0;
     $581 = ($579>>>0)>($580>>>0);
     $$$i16 = $581 ? $580 : $579;
     $582 = ($$$i16|0)==(0);
     if ($582) {
      $606 = $580;
     } else {
      $583 = HEAP32[$5>>2]|0;
      $584 = (($577) + 16|0);
      $585 = HEAP32[$584>>2]|0;
      _memcpy(($583|0),($585|0),($$$i16|0))|0;
      $586 = HEAP32[$5>>2]|0;
      $587 = (($586) + ($$$i16)|0);
      HEAP32[$5>>2] = $587;
      $588 = HEAP32[$1>>2]|0;
      $589 = (($588) + 16|0);
      $590 = HEAP32[$589>>2]|0;
      $591 = (($590) + ($$$i16)|0);
      HEAP32[$589>>2] = $591;
      $592 = (($strm) + 20|0);
      $593 = HEAP32[$592>>2]|0;
      $594 = (($593) + ($$$i16))|0;
      HEAP32[$592>>2] = $594;
      $595 = HEAP32[$19>>2]|0;
      $596 = (($595) - ($$$i16))|0;
      HEAP32[$19>>2] = $596;
      $597 = HEAP32[$1>>2]|0;
      $598 = (($597) + 20|0);
      $599 = HEAP32[$598>>2]|0;
      $600 = (($599) - ($$$i16))|0;
      HEAP32[$598>>2] = $600;
      $601 = ($599|0)==($$$i16|0);
      if ($601) {
       $602 = (($597) + 8|0);
       $603 = HEAP32[$602>>2]|0;
       $604 = (($597) + 16|0);
       HEAP32[$604>>2] = $603;
      }
      $$pr36 = HEAP32[$19>>2]|0;
      $606 = $$pr36;
     }
     $605 = ($606|0)==(0);
     if ($605) {
      HEAP32[$24>>2] = -1;
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
    $614 = HEAP32[$13>>2]|0;
    $615 = ($614|0)==(666);
    $616 = (($strm) + 4|0);
    $617 = HEAP32[$616>>2]|0;
    $618 = ($617|0)==(0);
    if ($615) {
     if ($618) {
      label = 121;
     } else {
      $619 = HEAP32[((403256 + 28|0))>>2]|0;
      $620 = (($strm) + 24|0);
      HEAP32[$620>>2] = $619;
      $$0 = -5;
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     if ($618) {
      label = 121;
     } else {
      label = 124;
     }
    }
    do {
     if ((label|0) == 121) {
      $621 = (($2) + 116|0);
      $622 = HEAP32[$621>>2]|0;
      $623 = ($622|0)==(0);
      if ($623) {
       $cond = ($flush|0)==(0);
       if ($cond) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       } else {
        if ($615) {
         break;
        } else {
         label = 124;
         break;
        }
       }
      } else {
       label = 124;
      }
     }
    } while(0);
    if ((label|0) == 124) {
     $624 = (($2) + 132|0);
     $625 = HEAP32[$624>>2]|0;
     $626 = ((400288 + (($625*12)|0)|0) + 8|0);
     $627 = HEAP32[$626>>2]|0;
     $628 = (FUNCTION_TABLE_iii[$627 & 4095]($2,$flush)|0);
     $629 = $628 & -2;
     $630 = ($629|0)==(2);
     if ($630) {
      HEAP32[$13>>2] = 666;
     }
     $631 = $628 & -3;
     $632 = ($631|0)==(0);
     if ($632) {
      $633 = HEAP32[$19>>2]|0;
      $634 = ($633|0)==(0);
      if (!($634)) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      HEAP32[$24>>2] = -1;
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $635 = ($628|0)==(1);
     if ($635) {
      $636 = ($flush|0)==(1);
      if ($636) {
       __tr_align($2);
      } else {
       __tr_stored_block($2,0,0,0);
       $637 = ($flush|0)==(3);
       if ($637) {
        $638 = (($2) + 76|0);
        $639 = HEAP32[$638>>2]|0;
        $640 = (($639) + -1)|0;
        $641 = (($2) + 68|0);
        $642 = HEAP32[$641>>2]|0;
        $643 = (($642) + ($640<<1)|0);
        HEAP16[$643>>1] = 0;
        $644 = $639 << 1;
        $645 = (($644) + -2)|0;
        _memset(($642|0),0,($645|0))|0;
       }
      }
      $646 = HEAP32[$1>>2]|0;
      $647 = (($646) + 20|0);
      $648 = HEAP32[$647>>2]|0;
      $649 = HEAP32[$19>>2]|0;
      $650 = ($648>>>0)>($649>>>0);
      $$$i14 = $650 ? $649 : $648;
      $651 = ($$$i14|0)==(0);
      if ($651) {
       $675 = $649;
      } else {
       $652 = HEAP32[$5>>2]|0;
       $653 = (($646) + 16|0);
       $654 = HEAP32[$653>>2]|0;
       _memcpy(($652|0),($654|0),($$$i14|0))|0;
       $655 = HEAP32[$5>>2]|0;
       $656 = (($655) + ($$$i14)|0);
       HEAP32[$5>>2] = $656;
       $657 = HEAP32[$1>>2]|0;
       $658 = (($657) + 16|0);
       $659 = HEAP32[$658>>2]|0;
       $660 = (($659) + ($$$i14)|0);
       HEAP32[$658>>2] = $660;
       $661 = (($strm) + 20|0);
       $662 = HEAP32[$661>>2]|0;
       $663 = (($662) + ($$$i14))|0;
       HEAP32[$661>>2] = $663;
       $664 = HEAP32[$19>>2]|0;
       $665 = (($664) - ($$$i14))|0;
       HEAP32[$19>>2] = $665;
       $666 = HEAP32[$1>>2]|0;
       $667 = (($666) + 20|0);
       $668 = HEAP32[$667>>2]|0;
       $669 = (($668) - ($$$i14))|0;
       HEAP32[$667>>2] = $669;
       $670 = ($668|0)==($$$i14|0);
       if ($670) {
        $671 = (($666) + 8|0);
        $672 = HEAP32[$671>>2]|0;
        $673 = (($666) + 16|0);
        HEAP32[$673>>2] = $672;
       }
       $$pr37 = HEAP32[$19>>2]|0;
       $675 = $$pr37;
      }
      $674 = ($675|0)==(0);
      if ($674) {
       HEAP32[$24>>2] = -1;
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
    if (!($16)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $676 = (($2) + 24|0);
    $677 = HEAP32[$676>>2]|0;
    $678 = ($677|0)<(1);
    if ($678) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $679 = ($677|0)==(2);
    $680 = (($strm) + 48|0);
    $681 = HEAP32[$680>>2]|0;
    if ($679) {
     $682 = $681&255;
     $683 = HEAP32[$574>>2]|0;
     $684 = (($683) + 1)|0;
     HEAP32[$574>>2] = $684;
     $685 = (($2) + 8|0);
     $686 = HEAP32[$685>>2]|0;
     $687 = (($686) + ($683)|0);
     HEAP8[$687>>0] = $682;
     $688 = HEAP32[$680>>2]|0;
     $689 = $688 >>> 8;
     $690 = $689&255;
     $691 = HEAP32[$574>>2]|0;
     $692 = (($691) + 1)|0;
     HEAP32[$574>>2] = $692;
     $693 = HEAP32[$685>>2]|0;
     $694 = (($693) + ($691)|0);
     HEAP8[$694>>0] = $690;
     $695 = HEAP32[$680>>2]|0;
     $696 = $695 >>> 16;
     $697 = $696&255;
     $698 = HEAP32[$574>>2]|0;
     $699 = (($698) + 1)|0;
     HEAP32[$574>>2] = $699;
     $700 = HEAP32[$685>>2]|0;
     $701 = (($700) + ($698)|0);
     HEAP8[$701>>0] = $697;
     $702 = HEAP32[$680>>2]|0;
     $703 = $702 >>> 24;
     $704 = $703&255;
     $705 = HEAP32[$574>>2]|0;
     $706 = (($705) + 1)|0;
     HEAP32[$574>>2] = $706;
     $707 = HEAP32[$685>>2]|0;
     $708 = (($707) + ($705)|0);
     HEAP8[$708>>0] = $704;
     $709 = (($strm) + 8|0);
     $710 = HEAP32[$709>>2]|0;
     $711 = $710&255;
     $712 = HEAP32[$574>>2]|0;
     $713 = (($712) + 1)|0;
     HEAP32[$574>>2] = $713;
     $714 = HEAP32[$685>>2]|0;
     $715 = (($714) + ($712)|0);
     HEAP8[$715>>0] = $711;
     $716 = HEAP32[$709>>2]|0;
     $717 = $716 >>> 8;
     $718 = $717&255;
     $719 = HEAP32[$574>>2]|0;
     $720 = (($719) + 1)|0;
     HEAP32[$574>>2] = $720;
     $721 = HEAP32[$685>>2]|0;
     $722 = (($721) + ($719)|0);
     HEAP8[$722>>0] = $718;
     $723 = HEAP32[$709>>2]|0;
     $724 = $723 >>> 16;
     $725 = $724&255;
     $726 = HEAP32[$574>>2]|0;
     $727 = (($726) + 1)|0;
     HEAP32[$574>>2] = $727;
     $728 = HEAP32[$685>>2]|0;
     $729 = (($728) + ($726)|0);
     HEAP8[$729>>0] = $725;
     $730 = HEAP32[$709>>2]|0;
     $731 = $730 >>> 24;
     $732 = $731&255;
     $733 = HEAP32[$574>>2]|0;
     $734 = (($733) + 1)|0;
     HEAP32[$574>>2] = $734;
     $735 = HEAP32[$685>>2]|0;
     $736 = (($735) + ($733)|0);
     HEAP8[$736>>0] = $732;
    } else {
     $737 = $681 >>> 16;
     $738 = $681 >>> 24;
     $739 = $738&255;
     $740 = HEAP32[$574>>2]|0;
     $741 = (($740) + 1)|0;
     HEAP32[$574>>2] = $741;
     $742 = (($2) + 8|0);
     $743 = HEAP32[$742>>2]|0;
     $744 = (($743) + ($740)|0);
     HEAP8[$744>>0] = $739;
     $745 = $737&255;
     $746 = HEAP32[$574>>2]|0;
     $747 = (($746) + 1)|0;
     HEAP32[$574>>2] = $747;
     $748 = HEAP32[$742>>2]|0;
     $749 = (($748) + ($746)|0);
     HEAP8[$749>>0] = $745;
     $750 = HEAP32[$680>>2]|0;
     $751 = $750 >>> 8;
     $752 = $751&255;
     $753 = HEAP32[$574>>2]|0;
     $754 = (($753) + 1)|0;
     HEAP32[$574>>2] = $754;
     $755 = HEAP32[$742>>2]|0;
     $756 = (($755) + ($753)|0);
     HEAP8[$756>>0] = $752;
     $757 = $750&255;
     $758 = HEAP32[$574>>2]|0;
     $759 = (($758) + 1)|0;
     HEAP32[$574>>2] = $759;
     $760 = HEAP32[$742>>2]|0;
     $761 = (($760) + ($758)|0);
     HEAP8[$761>>0] = $757;
    }
    $762 = HEAP32[$1>>2]|0;
    $763 = (($762) + 20|0);
    $764 = HEAP32[$763>>2]|0;
    $765 = HEAP32[$19>>2]|0;
    $766 = ($764>>>0)>($765>>>0);
    $$$i = $766 ? $765 : $764;
    $767 = ($$$i|0)==(0);
    if (!($767)) {
     $768 = HEAP32[$5>>2]|0;
     $769 = (($762) + 16|0);
     $770 = HEAP32[$769>>2]|0;
     _memcpy(($768|0),($770|0),($$$i|0))|0;
     $771 = HEAP32[$5>>2]|0;
     $772 = (($771) + ($$$i)|0);
     HEAP32[$5>>2] = $772;
     $773 = HEAP32[$1>>2]|0;
     $774 = (($773) + 16|0);
     $775 = HEAP32[$774>>2]|0;
     $776 = (($775) + ($$$i)|0);
     HEAP32[$774>>2] = $776;
     $777 = (($strm) + 20|0);
     $778 = HEAP32[$777>>2]|0;
     $779 = (($778) + ($$$i))|0;
     HEAP32[$777>>2] = $779;
     $780 = HEAP32[$19>>2]|0;
     $781 = (($780) - ($$$i))|0;
     HEAP32[$19>>2] = $781;
     $782 = HEAP32[$1>>2]|0;
     $783 = (($782) + 20|0);
     $784 = HEAP32[$783>>2]|0;
     $785 = (($784) - ($$$i))|0;
     HEAP32[$783>>2] = $785;
     $786 = ($784|0)==($$$i|0);
     if ($786) {
      $787 = (($782) + 8|0);
      $788 = HEAP32[$787>>2]|0;
      $789 = (($782) + 16|0);
      HEAP32[$789>>2] = $788;
     }
    }
    $790 = HEAP32[$676>>2]|0;
    $791 = ($790|0)>(0);
    if ($791) {
     $792 = (0 - ($790))|0;
     HEAP32[$676>>2] = $792;
    }
    $793 = HEAP32[$574>>2]|0;
    $not$ = ($793|0)==(0);
    $794 = $not$&1;
    $$0 = $794;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $17 = HEAP32[((403256 + 16|0))>>2]|0;
 $18 = (($strm) + 24|0);
 HEAP32[$18>>2] = $17;
 $$0 = -2;
 STACKTOP = sp;return ($$0|0);
}
function _deflate_stored($s,$flush) {
 $s = $s|0;
 $flush = $flush|0;
 var $$ = 0, $$$i = 0, $$$i2 = 0, $$$i4 = 0, $$0 = 0, $$pre = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -5)|0;
 $3 = ($2>>>0)<(65535);
 $$ = $3 ? $2 : 65535;
 $4 = (($s) + 116|0);
 $5 = (($s) + 108|0);
 $6 = (($s) + 92|0);
 $7 = (($s) + 44|0);
 $8 = (($s) + 56|0);
 while(1) {
  $9 = HEAP32[$4>>2]|0;
  $10 = ($9>>>0)<(2);
  if ($10) {
   _fill_window($s);
   $11 = HEAP32[$4>>2]|0;
   $12 = $11 | $flush;
   $13 = ($12|0)==(0);
   if ($13) {
    $$0 = 0;
    label = 28;
    break;
   }
   $14 = ($11|0)==(0);
   if ($14) {
    label = 20;
    break;
   } else {
    $17 = $11;
   }
  } else {
   $17 = $9;
  }
  $15 = HEAP32[$5>>2]|0;
  $16 = (($15) + ($17))|0;
  HEAP32[$5>>2] = $16;
  HEAP32[$4>>2] = 0;
  $18 = HEAP32[$6>>2]|0;
  $19 = (($18) + ($$))|0;
  $20 = ($16|0)!=(0);
  $21 = ($16>>>0)<($19>>>0);
  $or$cond1 = $20 & $21;
  if ($or$cond1) {
   $65 = $16;$66 = $18;
  } else {
   $22 = (($16) - ($19))|0;
   HEAP32[$4>>2] = $22;
   HEAP32[$5>>2] = $19;
   $23 = ($18|0)>(-1);
   if ($23) {
    $24 = HEAP32[$8>>2]|0;
    $25 = (($24) + ($18)|0);
    $26 = $25;
   } else {
    $26 = 0;
   }
   __tr_flush_block($s,$26,$$,0);
   $27 = HEAP32[$5>>2]|0;
   HEAP32[$6>>2] = $27;
   $28 = HEAP32[$s>>2]|0;
   $29 = (($28) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 20|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($28) + 16|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($32>>>0)>($34>>>0);
   $$$i = $35 ? $34 : $32;
   $36 = ($$$i|0)==(0);
   if (!($36)) {
    $37 = (($28) + 12|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($30) + 16|0);
    $40 = HEAP32[$39>>2]|0;
    _memcpy(($38|0),($40|0),($$$i|0))|0;
    $41 = HEAP32[$37>>2]|0;
    $42 = (($41) + ($$$i)|0);
    HEAP32[$37>>2] = $42;
    $43 = HEAP32[$29>>2]|0;
    $44 = (($43) + 16|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($45) + ($$$i)|0);
    HEAP32[$44>>2] = $46;
    $47 = (($28) + 20|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + ($$$i))|0;
    HEAP32[$47>>2] = $49;
    $50 = HEAP32[$33>>2]|0;
    $51 = (($50) - ($$$i))|0;
    HEAP32[$33>>2] = $51;
    $52 = HEAP32[$29>>2]|0;
    $53 = (($52) + 20|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) - ($$$i))|0;
    HEAP32[$53>>2] = $55;
    $56 = ($54|0)==($$$i|0);
    if ($56) {
     $57 = (($52) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($52) + 16|0);
     HEAP32[$59>>2] = $58;
    }
   }
   $60 = HEAP32[$s>>2]|0;
   $61 = (($60) + 16|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==(0);
   if ($63) {
    $$0 = 0;
    label = 28;
    break;
   }
   $$pre = HEAP32[$5>>2]|0;
   $$pre8 = HEAP32[$6>>2]|0;
   $65 = $$pre;$66 = $$pre8;
  }
  $64 = (($65) - ($66))|0;
  $67 = HEAP32[$7>>2]|0;
  $68 = (($67) + -262)|0;
  $69 = ($64>>>0)<($68>>>0);
  if ($69) {
   continue;
  }
  $70 = ($66|0)>(-1);
  if ($70) {
   $71 = HEAP32[$8>>2]|0;
   $72 = (($71) + ($66)|0);
   $73 = $72;
  } else {
   $73 = 0;
  }
  __tr_flush_block($s,$73,$64,0);
  $74 = HEAP32[$5>>2]|0;
  HEAP32[$6>>2] = $74;
  $75 = HEAP32[$s>>2]|0;
  $76 = (($75) + 28|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($77) + 20|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($75) + 16|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($79>>>0)>($81>>>0);
  $$$i4 = $82 ? $81 : $79;
  $83 = ($$$i4|0)==(0);
  if (!($83)) {
   $84 = (($75) + 12|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($77) + 16|0);
   $87 = HEAP32[$86>>2]|0;
   _memcpy(($85|0),($87|0),($$$i4|0))|0;
   $88 = HEAP32[$84>>2]|0;
   $89 = (($88) + ($$$i4)|0);
   HEAP32[$84>>2] = $89;
   $90 = HEAP32[$76>>2]|0;
   $91 = (($90) + 16|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($92) + ($$$i4)|0);
   HEAP32[$91>>2] = $93;
   $94 = (($75) + 20|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($95) + ($$$i4))|0;
   HEAP32[$94>>2] = $96;
   $97 = HEAP32[$80>>2]|0;
   $98 = (($97) - ($$$i4))|0;
   HEAP32[$80>>2] = $98;
   $99 = HEAP32[$76>>2]|0;
   $100 = (($99) + 20|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (($101) - ($$$i4))|0;
   HEAP32[$100>>2] = $102;
   $103 = ($101|0)==($$$i4|0);
   if ($103) {
    $104 = (($99) + 8|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($99) + 16|0);
    HEAP32[$106>>2] = $105;
   }
  }
  $107 = HEAP32[$s>>2]|0;
  $108 = (($107) + 16|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)==(0);
  if ($110) {
   $$0 = 0;
   label = 28;
   break;
  }
 }
 if ((label|0) == 20) {
  $111 = HEAP32[$6>>2]|0;
  $112 = ($111|0)>(-1);
  if ($112) {
   $113 = HEAP32[$8>>2]|0;
   $114 = (($113) + ($111)|0);
   $119 = $114;
  } else {
   $119 = 0;
  }
  $115 = HEAP32[$5>>2]|0;
  $116 = (($115) - ($111))|0;
  $117 = ($flush|0)==(4);
  $118 = $117&1;
  __tr_flush_block($s,$119,$116,$118);
  $120 = HEAP32[$5>>2]|0;
  HEAP32[$6>>2] = $120;
  $121 = HEAP32[$s>>2]|0;
  $122 = (($121) + 28|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = (($123) + 20|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (($121) + 16|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ($125>>>0)>($127>>>0);
  $$$i2 = $128 ? $127 : $125;
  $129 = ($$$i2|0)==(0);
  if (!($129)) {
   $130 = (($121) + 12|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = (($123) + 16|0);
   $133 = HEAP32[$132>>2]|0;
   _memcpy(($131|0),($133|0),($$$i2|0))|0;
   $134 = HEAP32[$130>>2]|0;
   $135 = (($134) + ($$$i2)|0);
   HEAP32[$130>>2] = $135;
   $136 = HEAP32[$122>>2]|0;
   $137 = (($136) + 16|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = (($138) + ($$$i2)|0);
   HEAP32[$137>>2] = $139;
   $140 = (($121) + 20|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = (($141) + ($$$i2))|0;
   HEAP32[$140>>2] = $142;
   $143 = HEAP32[$126>>2]|0;
   $144 = (($143) - ($$$i2))|0;
   HEAP32[$126>>2] = $144;
   $145 = HEAP32[$122>>2]|0;
   $146 = (($145) + 20|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = (($147) - ($$$i2))|0;
   HEAP32[$146>>2] = $148;
   $149 = ($147|0)==($$$i2|0);
   if ($149) {
    $150 = (($145) + 8|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = (($145) + 16|0);
    HEAP32[$152>>2] = $151;
   }
  }
  $153 = HEAP32[$s>>2]|0;
  $154 = (($153) + 16|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = ($155|0)==(0);
  if ($156) {
   $157 = $117 ? 2 : 0;
   $$0 = $157;
   STACKTOP = sp;return ($$0|0);
  } else {
   $158 = $117 ? 3 : 1;
   $$0 = $158;
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 28) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _deflate_fast($s,$flush) {
 $s = $s|0;
 $flush = $flush|0;
 var $$$i = 0, $$$i2 = 0, $$0 = 0, $$off = 0, $$pn = 0, $$pr = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $$sink = 0, $$sink$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bflush$0 = 0, $hash_head$0 = 0, $hash_head$1 = 0, $hash_head$2 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond4 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 116|0);
 $1 = ($flush|0)==(0);
 $2 = (($s) + 72|0);
 $3 = (($s) + 88|0);
 $4 = (($s) + 108|0);
 $5 = (($s) + 56|0);
 $6 = (($s) + 84|0);
 $7 = (($s) + 68|0);
 $8 = (($s) + 52|0);
 $9 = (($s) + 64|0);
 $10 = (($s) + 96|0);
 $11 = (($s) + 112|0);
 $12 = (($s) + 5792|0);
 $13 = (($s) + 5796|0);
 $14 = (($s) + 5784|0);
 $15 = (($s) + 5788|0);
 $16 = (($s) + 128|0);
 $17 = (($s) + 92|0);
 $18 = (($s) + 44|0);
 $19 = (($s) + 136|0);
 $hash_head$0 = 0;
 while(1) {
  $20 = HEAP32[$0>>2]|0;
  $21 = ($20>>>0)<(262);
  if ($21) {
   _fill_window($s);
   $22 = HEAP32[$0>>2]|0;
   $23 = ($22>>>0)<(262);
   $or$cond = $23 & $1;
   if ($or$cond) {
    $$0 = 0;
    label = 38;
    break;
   }
   $24 = ($22|0)==(0);
   if ($24) {
    label = 30;
    break;
   }
   $25 = ($22>>>0)>(2);
   if ($25) {
    label = 6;
   } else {
    $hash_head$1 = $hash_head$0;
   }
  } else {
   label = 6;
  }
  if ((label|0) == 6) {
   label = 0;
   $26 = HEAP32[$2>>2]|0;
   $27 = HEAP32[$3>>2]|0;
   $28 = $26 << $27;
   $29 = HEAP32[$4>>2]|0;
   $30 = (($29) + 2)|0;
   $31 = HEAP32[$5>>2]|0;
   $32 = (($31) + ($30)|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = $33&255;
   $35 = $34 ^ $28;
   $36 = HEAP32[$6>>2]|0;
   $37 = $35 & $36;
   HEAP32[$2>>2] = $37;
   $38 = HEAP32[$7>>2]|0;
   $39 = (($38) + ($37<<1)|0);
   $40 = HEAP16[$39>>1]|0;
   $41 = HEAP32[$8>>2]|0;
   $42 = $41 & $29;
   $43 = HEAP32[$9>>2]|0;
   $44 = (($43) + ($42<<1)|0);
   HEAP16[$44>>1] = $40;
   $45 = $40&65535;
   $46 = $29&65535;
   HEAP16[$39>>1] = $46;
   $hash_head$1 = $45;
  }
  $47 = ($hash_head$1|0)==(0);
  do {
   if ($47) {
    label = 13;
   } else {
    $48 = HEAP32[$4>>2]|0;
    $49 = (($48) - ($hash_head$1))|0;
    $50 = HEAP32[$18>>2]|0;
    $51 = (($50) + -262)|0;
    $52 = ($49>>>0)>($51>>>0);
    if ($52) {
     label = 13;
    } else {
     $53 = HEAP32[$19>>2]|0;
     $$off = (($53) + -2)|0;
     $switch = ($$off>>>0)<(2);
     if (!($switch)) {
      $54 = (_longest_match($s,$hash_head$1)|0);
      HEAP32[$10>>2] = $54;
      $59 = $54;
      break;
     }
     $55 = ($53|0)==(3);
     $56 = ($49|0)==(1);
     $or$cond4 = $55 & $56;
     if ($or$cond4) {
      $57 = (_longest_match_fast($s,$hash_head$1)|0);
      HEAP32[$10>>2] = $57;
      $59 = $57;
     } else {
      label = 13;
     }
    }
   }
  } while(0);
  if ((label|0) == 13) {
   label = 0;
   $$pr = HEAP32[$10>>2]|0;
   $59 = $$pr;
  }
  $58 = ($59>>>0)>(2);
  do {
   if ($58) {
    $60 = (($59) + 253)|0;
    $61 = $60&255;
    $62 = HEAP32[$4>>2]|0;
    $63 = HEAP32[$11>>2]|0;
    $64 = (($62) - ($63))|0;
    $65 = $64&65535;
    $66 = HEAP32[$12>>2]|0;
    $67 = HEAP32[$13>>2]|0;
    $68 = (($67) + ($66<<1)|0);
    HEAP16[$68>>1] = $65;
    $69 = (($66) + 1)|0;
    HEAP32[$12>>2] = $69;
    $70 = HEAP32[$14>>2]|0;
    $71 = (($70) + ($66)|0);
    HEAP8[$71>>0] = $61;
    $72 = (($64) + 65535)|0;
    $73 = $60 & 255;
    $74 = (400920 + ($73)|0);
    $75 = HEAP8[$74>>0]|0;
    $76 = $75&255;
    $77 = $76 | 256;
    $78 = (($77) + 1)|0;
    $79 = ((($s) + ($78<<2)|0) + 148|0);
    $80 = HEAP16[$79>>1]|0;
    $81 = (($80) + 1)<<16>>16;
    HEAP16[$79>>1] = $81;
    $82 = $72 & 65535;
    $83 = ($82>>>0)<(256);
    if ($83) {
     $$pn = $82;
    } else {
     $84 = $82 >>> 7;
     $85 = (($84) + 256)|0;
     $$pn = $85;
    }
    $$sink$in = (400408 + ($$pn)|0);
    $$sink = HEAP8[$$sink$in>>0]|0;
    $86 = $$sink&255;
    $87 = ((($s) + ($86<<2)|0) + 2440|0);
    $88 = HEAP16[$87>>1]|0;
    $89 = (($88) + 1)<<16>>16;
    HEAP16[$87>>1] = $89;
    $90 = HEAP32[$12>>2]|0;
    $91 = HEAP32[$15>>2]|0;
    $92 = (($91) + -1)|0;
    $93 = ($90|0)==($92|0);
    $94 = $93&1;
    $95 = HEAP32[$10>>2]|0;
    $96 = HEAP32[$0>>2]|0;
    $97 = (($96) - ($95))|0;
    HEAP32[$0>>2] = $97;
    $98 = HEAP32[$16>>2]|0;
    $99 = ($95>>>0)<=($98>>>0);
    $100 = ($97>>>0)>(2);
    $or$cond1 = $99 & $100;
    if (!($or$cond1)) {
     $122 = HEAP32[$4>>2]|0;
     $123 = (($122) + ($95))|0;
     HEAP32[$4>>2] = $123;
     HEAP32[$10>>2] = 0;
     $124 = HEAP32[$5>>2]|0;
     $125 = (($124) + ($123)|0);
     $126 = HEAP8[$125>>0]|0;
     $127 = $126&255;
     HEAP32[$2>>2] = $127;
     $128 = HEAP32[$3>>2]|0;
     $129 = $127 << $128;
     $130 = (($123) + 1)|0;
     $131 = (($124) + ($130)|0);
     $132 = HEAP8[$131>>0]|0;
     $133 = $132&255;
     $134 = $133 ^ $129;
     $135 = HEAP32[$6>>2]|0;
     $136 = $134 & $135;
     HEAP32[$2>>2] = $136;
     $166 = $123;$bflush$0 = $94;$hash_head$2 = $hash_head$1;
     break;
    }
    $101 = (($95) + -1)|0;
    HEAP32[$10>>2] = $101;
    $$pre = HEAP32[$4>>2]|0;
    $$pre5 = HEAP32[$2>>2]|0;
    $$pre6 = HEAP32[$3>>2]|0;
    $$pre7 = HEAP32[$5>>2]|0;
    $$pre8 = HEAP32[$6>>2]|0;
    $$pre9 = HEAP32[$7>>2]|0;
    $$pre10 = HEAP32[$8>>2]|0;
    $$pre11 = HEAP32[$9>>2]|0;
    $103 = $$pre;$105 = $$pre5;$118 = $101;
    while(1) {
     $102 = (($103) + 1)|0;
     HEAP32[$4>>2] = $102;
     $104 = $105 << $$pre6;
     $106 = (($103) + 3)|0;
     $107 = (($$pre7) + ($106)|0);
     $108 = HEAP8[$107>>0]|0;
     $109 = $108&255;
     $110 = $109 ^ $104;
     $111 = $110 & $$pre8;
     HEAP32[$2>>2] = $111;
     $112 = (($$pre9) + ($111<<1)|0);
     $113 = HEAP16[$112>>1]|0;
     $114 = $$pre10 & $102;
     $115 = (($$pre11) + ($114<<1)|0);
     HEAP16[$115>>1] = $113;
     $116 = $102&65535;
     HEAP16[$112>>1] = $116;
     $117 = (($118) + -1)|0;
     HEAP32[$10>>2] = $117;
     $119 = ($117|0)==(0);
     if ($119) {
      break;
     } else {
      $103 = $102;$105 = $111;$118 = $117;
     }
    }
    $120 = $113&65535;
    $121 = (($103) + 2)|0;
    HEAP32[$4>>2] = $121;
    $166 = $121;$bflush$0 = $94;$hash_head$2 = $120;
   } else {
    $137 = HEAP32[$4>>2]|0;
    $138 = HEAP32[$5>>2]|0;
    $139 = (($138) + ($137)|0);
    $140 = HEAP8[$139>>0]|0;
    $141 = HEAP32[$12>>2]|0;
    $142 = HEAP32[$13>>2]|0;
    $143 = (($142) + ($141<<1)|0);
    HEAP16[$143>>1] = 0;
    $144 = (($141) + 1)|0;
    HEAP32[$12>>2] = $144;
    $145 = HEAP32[$14>>2]|0;
    $146 = (($145) + ($141)|0);
    HEAP8[$146>>0] = $140;
    $147 = $140&255;
    $148 = ((($s) + ($147<<2)|0) + 148|0);
    $149 = HEAP16[$148>>1]|0;
    $150 = (($149) + 1)<<16>>16;
    HEAP16[$148>>1] = $150;
    $151 = HEAP32[$12>>2]|0;
    $152 = HEAP32[$15>>2]|0;
    $153 = (($152) + -1)|0;
    $154 = ($151|0)==($153|0);
    $155 = $154&1;
    $156 = HEAP32[$0>>2]|0;
    $157 = (($156) + -1)|0;
    HEAP32[$0>>2] = $157;
    $158 = HEAP32[$4>>2]|0;
    $159 = (($158) + 1)|0;
    HEAP32[$4>>2] = $159;
    $166 = $159;$bflush$0 = $155;$hash_head$2 = $hash_head$1;
   }
  } while(0);
  $160 = ($bflush$0|0)==(0);
  if ($160) {
   $hash_head$0 = $hash_head$2;
   continue;
  }
  $161 = HEAP32[$17>>2]|0;
  $162 = ($161|0)>(-1);
  if ($162) {
   $163 = HEAP32[$5>>2]|0;
   $164 = (($163) + ($161)|0);
   $167 = $164;
  } else {
   $167 = 0;
  }
  $165 = (($166) - ($161))|0;
  __tr_flush_block($s,$167,$165,0);
  $168 = HEAP32[$4>>2]|0;
  HEAP32[$17>>2] = $168;
  $169 = HEAP32[$s>>2]|0;
  $170 = (($169) + 28|0);
  $171 = HEAP32[$170>>2]|0;
  $172 = (($171) + 20|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = (($169) + 16|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = ($173>>>0)>($175>>>0);
  $$$i = $176 ? $175 : $173;
  $177 = ($$$i|0)==(0);
  if (!($177)) {
   $178 = (($169) + 12|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = (($171) + 16|0);
   $181 = HEAP32[$180>>2]|0;
   _memcpy(($179|0),($181|0),($$$i|0))|0;
   $182 = HEAP32[$178>>2]|0;
   $183 = (($182) + ($$$i)|0);
   HEAP32[$178>>2] = $183;
   $184 = HEAP32[$170>>2]|0;
   $185 = (($184) + 16|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = (($186) + ($$$i)|0);
   HEAP32[$185>>2] = $187;
   $188 = (($169) + 20|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = (($189) + ($$$i))|0;
   HEAP32[$188>>2] = $190;
   $191 = HEAP32[$174>>2]|0;
   $192 = (($191) - ($$$i))|0;
   HEAP32[$174>>2] = $192;
   $193 = HEAP32[$170>>2]|0;
   $194 = (($193) + 20|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = (($195) - ($$$i))|0;
   HEAP32[$194>>2] = $196;
   $197 = ($195|0)==($$$i|0);
   if ($197) {
    $198 = (($193) + 8|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = (($193) + 16|0);
    HEAP32[$200>>2] = $199;
   }
  }
  $201 = HEAP32[$s>>2]|0;
  $202 = (($201) + 16|0);
  $203 = HEAP32[$202>>2]|0;
  $204 = ($203|0)==(0);
  if ($204) {
   $$0 = 0;
   label = 38;
   break;
  } else {
   $hash_head$0 = $hash_head$2;
  }
 }
 if ((label|0) == 30) {
  $205 = HEAP32[$17>>2]|0;
  $206 = ($205|0)>(-1);
  if ($206) {
   $207 = HEAP32[$5>>2]|0;
   $208 = (($207) + ($205)|0);
   $213 = $208;
  } else {
   $213 = 0;
  }
  $209 = HEAP32[$4>>2]|0;
  $210 = (($209) - ($205))|0;
  $211 = ($flush|0)==(4);
  $212 = $211&1;
  __tr_flush_block($s,$213,$210,$212);
  $214 = HEAP32[$4>>2]|0;
  HEAP32[$17>>2] = $214;
  $215 = HEAP32[$s>>2]|0;
  $216 = (($215) + 28|0);
  $217 = HEAP32[$216>>2]|0;
  $218 = (($217) + 20|0);
  $219 = HEAP32[$218>>2]|0;
  $220 = (($215) + 16|0);
  $221 = HEAP32[$220>>2]|0;
  $222 = ($219>>>0)>($221>>>0);
  $$$i2 = $222 ? $221 : $219;
  $223 = ($$$i2|0)==(0);
  if (!($223)) {
   $224 = (($215) + 12|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = (($217) + 16|0);
   $227 = HEAP32[$226>>2]|0;
   _memcpy(($225|0),($227|0),($$$i2|0))|0;
   $228 = HEAP32[$224>>2]|0;
   $229 = (($228) + ($$$i2)|0);
   HEAP32[$224>>2] = $229;
   $230 = HEAP32[$216>>2]|0;
   $231 = (($230) + 16|0);
   $232 = HEAP32[$231>>2]|0;
   $233 = (($232) + ($$$i2)|0);
   HEAP32[$231>>2] = $233;
   $234 = (($215) + 20|0);
   $235 = HEAP32[$234>>2]|0;
   $236 = (($235) + ($$$i2))|0;
   HEAP32[$234>>2] = $236;
   $237 = HEAP32[$220>>2]|0;
   $238 = (($237) - ($$$i2))|0;
   HEAP32[$220>>2] = $238;
   $239 = HEAP32[$216>>2]|0;
   $240 = (($239) + 20|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = (($241) - ($$$i2))|0;
   HEAP32[$240>>2] = $242;
   $243 = ($241|0)==($$$i2|0);
   if ($243) {
    $244 = (($239) + 8|0);
    $245 = HEAP32[$244>>2]|0;
    $246 = (($239) + 16|0);
    HEAP32[$246>>2] = $245;
   }
  }
  $247 = HEAP32[$s>>2]|0;
  $248 = (($247) + 16|0);
  $249 = HEAP32[$248>>2]|0;
  $250 = ($249|0)==(0);
  if ($250) {
   $251 = $211 ? 2 : 0;
   $$0 = $251;
   STACKTOP = sp;return ($$0|0);
  } else {
   $252 = $211 ? 3 : 1;
   $$0 = $252;
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 38) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _deflate_slow($s,$flush) {
 $s = $s|0;
 $flush = $flush|0;
 var $$$i = 0, $$$i1 = 0, $$$i3 = 0, $$0 = 0, $$neg10 = 0, $$off = 0, $$pn = 0, $$pr = 0, $$pr7 = 0, $$pre = 0, $$sink = 0, $$sink$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $hash_head$0 = 0, $hash_head$0$ph = 0, $hash_head$1 = 0, $hash_head$2 = 0, $hash_head$3 = 0, $or$cond = 0, $or$cond17 = 0, $or$cond8 = 0, $storemerge = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 116|0);
 $1 = ($flush|0)==(0);
 $2 = (($s) + 72|0);
 $3 = (($s) + 88|0);
 $4 = (($s) + 108|0);
 $5 = (($s) + 56|0);
 $6 = (($s) + 84|0);
 $7 = (($s) + 68|0);
 $8 = (($s) + 52|0);
 $9 = (($s) + 64|0);
 $10 = (($s) + 96|0);
 $11 = (($s) + 120|0);
 $12 = (($s) + 112|0);
 $13 = (($s) + 100|0);
 $14 = (($s) + 5792|0);
 $15 = (($s) + 5796|0);
 $16 = (($s) + 5784|0);
 $17 = (($s) + 5788|0);
 $18 = (($s) + 104|0);
 $19 = (($s) + 92|0);
 $20 = (($s) + 128|0);
 $21 = (($s) + 44|0);
 $22 = (($s) + 136|0);
 $hash_head$0$ph = 0;
 L1: while(1) {
  $$pr = HEAP32[$0>>2]|0;
  $24 = $$pr;$hash_head$0 = $hash_head$0$ph;
  while(1) {
   $23 = ($24>>>0)<(262);
   if ($23) {
    _fill_window($s);
    $25 = HEAP32[$0>>2]|0;
    $26 = ($25>>>0)<(262);
    $or$cond = $26 & $1;
    if ($or$cond) {
     $$0 = 0;
     label = 54;
     break L1;
    }
    $27 = ($25|0)==(0);
    if ($27) {
     label = 44;
     break L1;
    }
    $28 = ($25>>>0)>(2);
    if ($28) {
     label = 7;
    } else {
     $hash_head$1 = $hash_head$0;
    }
   } else {
    label = 7;
   }
   if ((label|0) == 7) {
    label = 0;
    $29 = HEAP32[$2>>2]|0;
    $30 = HEAP32[$3>>2]|0;
    $31 = $29 << $30;
    $32 = HEAP32[$4>>2]|0;
    $33 = (($32) + 2)|0;
    $34 = HEAP32[$5>>2]|0;
    $35 = (($34) + ($33)|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = $36&255;
    $38 = $37 ^ $31;
    $39 = HEAP32[$6>>2]|0;
    $40 = $38 & $39;
    HEAP32[$2>>2] = $40;
    $41 = HEAP32[$7>>2]|0;
    $42 = (($41) + ($40<<1)|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = HEAP32[$8>>2]|0;
    $45 = $44 & $32;
    $46 = HEAP32[$9>>2]|0;
    $47 = (($46) + ($45<<1)|0);
    HEAP16[$47>>1] = $43;
    $48 = $43&65535;
    $49 = $32&65535;
    HEAP16[$42>>1] = $49;
    $hash_head$1 = $48;
   }
   $50 = HEAP32[$10>>2]|0;
   HEAP32[$11>>2] = $50;
   $51 = HEAP32[$12>>2]|0;
   HEAP32[$13>>2] = $51;
   HEAP32[$10>>2] = 2;
   $52 = ($hash_head$1|0)==(0);
   do {
    if ($52) {
     $329 = 2;
     label = 20;
    } else {
     $53 = HEAP32[$20>>2]|0;
     $54 = ($50>>>0)<($53>>>0);
     if ($54) {
      $55 = HEAP32[$4>>2]|0;
      $56 = (($55) - ($hash_head$1))|0;
      $57 = HEAP32[$21>>2]|0;
      $58 = (($57) + -262)|0;
      $59 = ($56>>>0)>($58>>>0);
      if ($59) {
       $329 = 2;
       label = 20;
      } else {
       $60 = HEAP32[$22>>2]|0;
       $$off = (($60) + -2)|0;
       $switch = ($$off>>>0)<(2);
       if ($switch) {
        $62 = ($60|0)==(3);
        $63 = ($56|0)==(1);
        $or$cond8 = $62 & $63;
        if ($or$cond8) {
         $64 = (_longest_match_fast($s,$hash_head$1)|0);
         $66 = $64;$storemerge = $64;
         label = 15;
        } else {
         $70 = 2;
        }
       } else {
        $61 = (_longest_match($s,$hash_head$1)|0);
        $66 = $61;$storemerge = $61;
        label = 15;
       }
       if ((label|0) == 15) {
        label = 0;
        HEAP32[$10>>2] = $storemerge;
        $65 = ($66>>>0)<(6);
        if ($65) {
         $70 = $66;
        } else {
         $329 = $66;
         label = 20;
         break;
        }
       }
       $67 = HEAP32[$22>>2]|0;
       $68 = ($67|0)==(1);
       if (!($68)) {
        $69 = ($70|0)==(3);
        if (!($69)) {
         $329 = $70;
         label = 20;
         break;
        }
        $71 = HEAP32[$4>>2]|0;
        $72 = HEAP32[$12>>2]|0;
        $73 = (($71) - ($72))|0;
        $74 = ($73>>>0)>(4096);
        if (!($74)) {
         $329 = 3;
         label = 20;
         break;
        }
       }
       HEAP32[$10>>2] = 2;
       $329 = 2;
       label = 20;
      }
     } else {
      $76 = $50;$78 = 2;
     }
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    $$pr7 = HEAP32[$11>>2]|0;
    $76 = $$pr7;$78 = $329;
   }
   $75 = ($76>>>0)<(3);
   $77 = ($78>>>0)>($76>>>0);
   $or$cond17 = $75 | $77;
   if (!($or$cond17)) {
    break;
   }
   $191 = HEAP32[$18>>2]|0;
   $192 = ($191|0)==(0);
   if ($192) {
    HEAP32[$18>>2] = 1;
    $260 = HEAP32[$4>>2]|0;
    $261 = (($260) + 1)|0;
    HEAP32[$4>>2] = $261;
    $262 = HEAP32[$0>>2]|0;
    $263 = (($262) + -1)|0;
    HEAP32[$0>>2] = $263;
    $24 = $263;$hash_head$0 = $hash_head$1;
    continue;
   }
   $193 = HEAP32[$4>>2]|0;
   $194 = (($193) + -1)|0;
   $195 = HEAP32[$5>>2]|0;
   $196 = (($195) + ($194)|0);
   $197 = HEAP8[$196>>0]|0;
   $198 = HEAP32[$14>>2]|0;
   $199 = HEAP32[$15>>2]|0;
   $200 = (($199) + ($198<<1)|0);
   HEAP16[$200>>1] = 0;
   $201 = (($198) + 1)|0;
   HEAP32[$14>>2] = $201;
   $202 = HEAP32[$16>>2]|0;
   $203 = (($202) + ($198)|0);
   HEAP8[$203>>0] = $197;
   $204 = $197&255;
   $205 = ((($s) + ($204<<2)|0) + 148|0);
   $206 = HEAP16[$205>>1]|0;
   $207 = (($206) + 1)<<16>>16;
   HEAP16[$205>>1] = $207;
   $208 = HEAP32[$14>>2]|0;
   $209 = HEAP32[$17>>2]|0;
   $210 = (($209) + -1)|0;
   $211 = ($208|0)==($210|0);
   if ($211) {
    $212 = HEAP32[$19>>2]|0;
    $213 = ($212|0)>(-1);
    if ($213) {
     $214 = HEAP32[$5>>2]|0;
     $215 = (($214) + ($212)|0);
     $218 = $215;
    } else {
     $218 = 0;
    }
    $216 = HEAP32[$4>>2]|0;
    $217 = (($216) - ($212))|0;
    __tr_flush_block($s,$218,$217,0);
    $219 = HEAP32[$4>>2]|0;
    HEAP32[$19>>2] = $219;
    $220 = HEAP32[$s>>2]|0;
    $221 = (($220) + 28|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = (($222) + 20|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = (($220) + 16|0);
    $226 = HEAP32[$225>>2]|0;
    $227 = ($224>>>0)>($226>>>0);
    $$$i3 = $227 ? $226 : $224;
    $228 = ($$$i3|0)==(0);
    if (!($228)) {
     $229 = (($220) + 12|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = (($222) + 16|0);
     $232 = HEAP32[$231>>2]|0;
     _memcpy(($230|0),($232|0),($$$i3|0))|0;
     $233 = HEAP32[$229>>2]|0;
     $234 = (($233) + ($$$i3)|0);
     HEAP32[$229>>2] = $234;
     $235 = HEAP32[$221>>2]|0;
     $236 = (($235) + 16|0);
     $237 = HEAP32[$236>>2]|0;
     $238 = (($237) + ($$$i3)|0);
     HEAP32[$236>>2] = $238;
     $239 = (($220) + 20|0);
     $240 = HEAP32[$239>>2]|0;
     $241 = (($240) + ($$$i3))|0;
     HEAP32[$239>>2] = $241;
     $242 = HEAP32[$225>>2]|0;
     $243 = (($242) - ($$$i3))|0;
     HEAP32[$225>>2] = $243;
     $244 = HEAP32[$221>>2]|0;
     $245 = (($244) + 20|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = (($246) - ($$$i3))|0;
     HEAP32[$245>>2] = $247;
     $248 = ($246|0)==($$$i3|0);
     if ($248) {
      $249 = (($244) + 8|0);
      $250 = HEAP32[$249>>2]|0;
      $251 = (($244) + 16|0);
      HEAP32[$251>>2] = $250;
     }
    }
   }
   $252 = HEAP32[$4>>2]|0;
   $253 = (($252) + 1)|0;
   HEAP32[$4>>2] = $253;
   $254 = HEAP32[$0>>2]|0;
   $255 = (($254) + -1)|0;
   HEAP32[$0>>2] = $255;
   $256 = HEAP32[$s>>2]|0;
   $257 = (($256) + 16|0);
   $258 = HEAP32[$257>>2]|0;
   $259 = ($258|0)==(0);
   if ($259) {
    $$0 = 0;
    label = 54;
    break L1;
   } else {
    $24 = $255;$hash_head$0 = $hash_head$1;
   }
  }
  $79 = HEAP32[$4>>2]|0;
  $80 = HEAP32[$0>>2]|0;
  $81 = (($79) + -3)|0;
  $82 = (($81) + ($80))|0;
  $83 = (($76) + 253)|0;
  $84 = $83&255;
  $85 = (($79) + 65535)|0;
  $86 = HEAP32[$13>>2]|0;
  $87 = (($85) - ($86))|0;
  $88 = $87&65535;
  $89 = HEAP32[$14>>2]|0;
  $90 = HEAP32[$15>>2]|0;
  $91 = (($90) + ($89<<1)|0);
  HEAP16[$91>>1] = $88;
  $92 = (($89) + 1)|0;
  HEAP32[$14>>2] = $92;
  $93 = HEAP32[$16>>2]|0;
  $94 = (($93) + ($89)|0);
  HEAP8[$94>>0] = $84;
  $95 = (($87) + 65535)|0;
  $96 = $83 & 255;
  $97 = (400920 + ($96)|0);
  $98 = HEAP8[$97>>0]|0;
  $99 = $98&255;
  $100 = $99 | 256;
  $101 = (($100) + 1)|0;
  $102 = ((($s) + ($101<<2)|0) + 148|0);
  $103 = HEAP16[$102>>1]|0;
  $104 = (($103) + 1)<<16>>16;
  HEAP16[$102>>1] = $104;
  $105 = $95 & 65535;
  $106 = ($105>>>0)<(256);
  if ($106) {
   $$pn = $105;
  } else {
   $107 = $105 >>> 7;
   $108 = (($107) + 256)|0;
   $$pn = $108;
  }
  $$sink$in = (400408 + ($$pn)|0);
  $$sink = HEAP8[$$sink$in>>0]|0;
  $109 = $$sink&255;
  $110 = ((($s) + ($109<<2)|0) + 2440|0);
  $111 = HEAP16[$110>>1]|0;
  $112 = (($111) + 1)<<16>>16;
  HEAP16[$110>>1] = $112;
  $113 = HEAP32[$14>>2]|0;
  $114 = HEAP32[$17>>2]|0;
  $115 = (($114) + -1)|0;
  $116 = HEAP32[$11>>2]|0;
  $117 = HEAP32[$0>>2]|0;
  $$neg10 = (1 - ($116))|0;
  $118 = (($$neg10) + ($117))|0;
  HEAP32[$0>>2] = $118;
  $119 = (($116) + -2)|0;
  HEAP32[$11>>2] = $119;
  $$pre = HEAP32[$4>>2]|0;
  $121 = $$pre;$144 = $119;$hash_head$2 = $hash_head$1;
  while(1) {
   $120 = (($121) + 1)|0;
   HEAP32[$4>>2] = $120;
   $122 = ($120>>>0)>($82>>>0);
   if ($122) {
    $hash_head$3 = $hash_head$2;
   } else {
    $123 = HEAP32[$2>>2]|0;
    $124 = HEAP32[$3>>2]|0;
    $125 = $123 << $124;
    $126 = (($121) + 3)|0;
    $127 = HEAP32[$5>>2]|0;
    $128 = (($127) + ($126)|0);
    $129 = HEAP8[$128>>0]|0;
    $130 = $129&255;
    $131 = $130 ^ $125;
    $132 = HEAP32[$6>>2]|0;
    $133 = $131 & $132;
    HEAP32[$2>>2] = $133;
    $134 = HEAP32[$7>>2]|0;
    $135 = (($134) + ($133<<1)|0);
    $136 = HEAP16[$135>>1]|0;
    $137 = HEAP32[$8>>2]|0;
    $138 = $137 & $120;
    $139 = HEAP32[$9>>2]|0;
    $140 = (($139) + ($138<<1)|0);
    HEAP16[$140>>1] = $136;
    $141 = $136&65535;
    $142 = $120&65535;
    HEAP16[$135>>1] = $142;
    $hash_head$3 = $141;
   }
   $143 = (($144) + -1)|0;
   HEAP32[$11>>2] = $143;
   $145 = ($143|0)==(0);
   if ($145) {
    break;
   } else {
    $121 = $120;$144 = $143;$hash_head$2 = $hash_head$3;
   }
  }
  $146 = ($113|0)==($115|0);
  HEAP32[$18>>2] = 0;
  HEAP32[$10>>2] = 2;
  $147 = (($121) + 2)|0;
  HEAP32[$4>>2] = $147;
  if (!($146)) {
   $hash_head$0$ph = $hash_head$3;
   continue;
  }
  $148 = HEAP32[$19>>2]|0;
  $149 = ($148|0)>(-1);
  if ($149) {
   $150 = HEAP32[$5>>2]|0;
   $151 = (($150) + ($148)|0);
   $153 = $151;
  } else {
   $153 = 0;
  }
  $152 = (($147) - ($148))|0;
  __tr_flush_block($s,$153,$152,0);
  $154 = HEAP32[$4>>2]|0;
  HEAP32[$19>>2] = $154;
  $155 = HEAP32[$s>>2]|0;
  $156 = (($155) + 28|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = (($157) + 20|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = (($155) + 16|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = ($159>>>0)>($161>>>0);
  $$$i = $162 ? $161 : $159;
  $163 = ($$$i|0)==(0);
  if (!($163)) {
   $164 = (($155) + 12|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = (($157) + 16|0);
   $167 = HEAP32[$166>>2]|0;
   _memcpy(($165|0),($167|0),($$$i|0))|0;
   $168 = HEAP32[$164>>2]|0;
   $169 = (($168) + ($$$i)|0);
   HEAP32[$164>>2] = $169;
   $170 = HEAP32[$156>>2]|0;
   $171 = (($170) + 16|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = (($172) + ($$$i)|0);
   HEAP32[$171>>2] = $173;
   $174 = (($155) + 20|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = (($175) + ($$$i))|0;
   HEAP32[$174>>2] = $176;
   $177 = HEAP32[$160>>2]|0;
   $178 = (($177) - ($$$i))|0;
   HEAP32[$160>>2] = $178;
   $179 = HEAP32[$156>>2]|0;
   $180 = (($179) + 20|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = (($181) - ($$$i))|0;
   HEAP32[$180>>2] = $182;
   $183 = ($181|0)==($$$i|0);
   if ($183) {
    $184 = (($179) + 8|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = (($179) + 16|0);
    HEAP32[$186>>2] = $185;
   }
  }
  $187 = HEAP32[$s>>2]|0;
  $188 = (($187) + 16|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = ($189|0)==(0);
  if ($190) {
   $$0 = 0;
   label = 54;
   break;
  } else {
   $hash_head$0$ph = $hash_head$3;
  }
 }
 if ((label|0) == 44) {
  $264 = HEAP32[$18>>2]|0;
  $265 = ($264|0)==(0);
  if (!($265)) {
   $266 = HEAP32[$4>>2]|0;
   $267 = (($266) + -1)|0;
   $268 = HEAP32[$5>>2]|0;
   $269 = (($268) + ($267)|0);
   $270 = HEAP8[$269>>0]|0;
   $271 = HEAP32[$14>>2]|0;
   $272 = HEAP32[$15>>2]|0;
   $273 = (($272) + ($271<<1)|0);
   HEAP16[$273>>1] = 0;
   $274 = (($271) + 1)|0;
   HEAP32[$14>>2] = $274;
   $275 = HEAP32[$16>>2]|0;
   $276 = (($275) + ($271)|0);
   HEAP8[$276>>0] = $270;
   $277 = $270&255;
   $278 = ((($s) + ($277<<2)|0) + 148|0);
   $279 = HEAP16[$278>>1]|0;
   $280 = (($279) + 1)<<16>>16;
   HEAP16[$278>>1] = $280;
   HEAP32[$18>>2] = 0;
  }
  $281 = HEAP32[$19>>2]|0;
  $282 = ($281|0)>(-1);
  if ($282) {
   $283 = HEAP32[$5>>2]|0;
   $284 = (($283) + ($281)|0);
   $289 = $284;
  } else {
   $289 = 0;
  }
  $285 = HEAP32[$4>>2]|0;
  $286 = (($285) - ($281))|0;
  $287 = ($flush|0)==(4);
  $288 = $287&1;
  __tr_flush_block($s,$289,$286,$288);
  $290 = HEAP32[$4>>2]|0;
  HEAP32[$19>>2] = $290;
  $291 = HEAP32[$s>>2]|0;
  $292 = (($291) + 28|0);
  $293 = HEAP32[$292>>2]|0;
  $294 = (($293) + 20|0);
  $295 = HEAP32[$294>>2]|0;
  $296 = (($291) + 16|0);
  $297 = HEAP32[$296>>2]|0;
  $298 = ($295>>>0)>($297>>>0);
  $$$i1 = $298 ? $297 : $295;
  $299 = ($$$i1|0)==(0);
  if (!($299)) {
   $300 = (($291) + 12|0);
   $301 = HEAP32[$300>>2]|0;
   $302 = (($293) + 16|0);
   $303 = HEAP32[$302>>2]|0;
   _memcpy(($301|0),($303|0),($$$i1|0))|0;
   $304 = HEAP32[$300>>2]|0;
   $305 = (($304) + ($$$i1)|0);
   HEAP32[$300>>2] = $305;
   $306 = HEAP32[$292>>2]|0;
   $307 = (($306) + 16|0);
   $308 = HEAP32[$307>>2]|0;
   $309 = (($308) + ($$$i1)|0);
   HEAP32[$307>>2] = $309;
   $310 = (($291) + 20|0);
   $311 = HEAP32[$310>>2]|0;
   $312 = (($311) + ($$$i1))|0;
   HEAP32[$310>>2] = $312;
   $313 = HEAP32[$296>>2]|0;
   $314 = (($313) - ($$$i1))|0;
   HEAP32[$296>>2] = $314;
   $315 = HEAP32[$292>>2]|0;
   $316 = (($315) + 20|0);
   $317 = HEAP32[$316>>2]|0;
   $318 = (($317) - ($$$i1))|0;
   HEAP32[$316>>2] = $318;
   $319 = ($317|0)==($$$i1|0);
   if ($319) {
    $320 = (($315) + 8|0);
    $321 = HEAP32[$320>>2]|0;
    $322 = (($315) + 16|0);
    HEAP32[$322>>2] = $321;
   }
  }
  $323 = HEAP32[$s>>2]|0;
  $324 = (($323) + 16|0);
  $325 = HEAP32[$324>>2]|0;
  $326 = ($325|0)==(0);
  if ($326) {
   $327 = $287 ? 2 : 0;
   $$0 = $327;
   STACKTOP = sp;return ($$0|0);
  } else {
   $328 = $287 ? 3 : 1;
   $$0 = $328;
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 54) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _fill_window($s) {
 $s = $s|0;
 var $$0$i = 0, $$pre = 0, $$pre$phi$iZ2D = 0, $$pre2 = 0, $$pre3 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $more$0 = 0, $n$0 = 0, $n$1 = 0, $p$0 = 0, $p$1 = 0, $phitmp = 0, $phitmp1 = 0, $size$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($s) + 60|0);
 $3 = (($s) + 116|0);
 $4 = (($s) + 108|0);
 $5 = (($1) + -262)|0;
 $6 = (($s) + 56|0);
 $7 = (($s) + 72|0);
 $8 = (($s) + 88|0);
 $9 = (($s) + 84|0);
 $10 = (($s) + 112|0);
 $11 = (($s) + 92|0);
 $12 = (($s) + 76|0);
 $13 = (($s) + 68|0);
 $14 = (($s) + 64|0);
 $$pre = HEAP32[$3>>2]|0;
 $17 = $$pre;$21 = $1;
 while(1) {
  $15 = HEAP32[$2>>2]|0;
  $16 = (($15) - ($17))|0;
  $18 = HEAP32[$4>>2]|0;
  $19 = (($16) - ($18))|0;
  $20 = (($5) + ($21))|0;
  $22 = ($18>>>0)<($20>>>0);
  if ($22) {
   $59 = $18;$more$0 = $19;
  } else {
   $23 = HEAP32[$6>>2]|0;
   $24 = (($23) + ($1)|0);
   _memcpy(($23|0),($24|0),($1|0))|0;
   $25 = HEAP32[$10>>2]|0;
   $26 = (($25) - ($1))|0;
   HEAP32[$10>>2] = $26;
   $27 = HEAP32[$4>>2]|0;
   $28 = (($27) - ($1))|0;
   HEAP32[$4>>2] = $28;
   $29 = HEAP32[$11>>2]|0;
   $30 = (($29) - ($1))|0;
   HEAP32[$11>>2] = $30;
   $31 = HEAP32[$12>>2]|0;
   $32 = HEAP32[$13>>2]|0;
   $33 = (($32) + ($31<<1)|0);
   $n$0 = $31;$p$0 = $33;
   while(1) {
    $34 = (($p$0) + -2|0);
    $35 = HEAP16[$34>>1]|0;
    $36 = $35&65535;
    $37 = ($36>>>0)<($1>>>0);
    if ($37) {
     $39 = 0;
    } else {
     $38 = (($36) - ($1))|0;
     $phitmp = $38&65535;
     $39 = $phitmp;
    }
    HEAP16[$34>>1] = $39;
    $40 = (($n$0) + -1)|0;
    $41 = ($40|0)==(0);
    if ($41) {
     break;
    } else {
     $n$0 = $40;$p$0 = $34;
    }
   }
   $42 = HEAP32[$14>>2]|0;
   $43 = (($42) + ($1<<1)|0);
   $n$1 = $1;$p$1 = $43;
   while(1) {
    $44 = (($p$1) + -2|0);
    $45 = HEAP16[$44>>1]|0;
    $46 = $45&65535;
    $47 = ($46>>>0)<($1>>>0);
    if ($47) {
     $49 = 0;
    } else {
     $48 = (($46) - ($1))|0;
     $phitmp1 = $48&65535;
     $49 = $phitmp1;
    }
    HEAP16[$44>>1] = $49;
    $50 = (($n$1) + -1)|0;
    $51 = ($50|0)==(0);
    if ($51) {
     break;
    } else {
     $n$1 = $50;$p$1 = $44;
    }
   }
   $52 = (($19) + ($1))|0;
   $59 = $28;$more$0 = $52;
  }
  $53 = HEAP32[$s>>2]|0;
  $54 = (($53) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0);
  if ($56) {
   label = 23;
   break;
  }
  $57 = HEAP32[$6>>2]|0;
  $58 = HEAP32[$3>>2]|0;
  $$sum = (($58) + ($59))|0;
  $60 = (($57) + ($$sum)|0);
  $61 = ($55>>>0)>($more$0>>>0);
  $size$$i = $61 ? $more$0 : $55;
  $62 = ($size$$i|0)==(0);
  if ($62) {
   $$0$i = 0;$83 = $58;
  } else {
   $63 = (($55) - ($size$$i))|0;
   HEAP32[$54>>2] = $63;
   $64 = (($53) + 28|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 24|0);
   $67 = HEAP32[$66>>2]|0;
   if ((($67|0) == 1)) {
    $68 = (($53) + 48|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = HEAP32[$53>>2]|0;
    $71 = (_adler32($69,$70,$size$$i)|0);
    HEAP32[$68>>2] = $71;
    $$pre$phi$iZ2D = $53;
   } else if ((($67|0) == 2)) {
    $72 = (($53) + 48|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = HEAP32[$53>>2]|0;
    $75 = (_crc32($73,$74,$size$$i)|0);
    HEAP32[$72>>2] = $75;
    $$pre$phi$iZ2D = $53;
   } else {
    $$pre$phi$iZ2D = $53;
   }
   $76 = HEAP32[$$pre$phi$iZ2D>>2]|0;
   _memcpy(($60|0),($76|0),($size$$i|0))|0;
   $77 = HEAP32[$$pre$phi$iZ2D>>2]|0;
   $78 = (($77) + ($size$$i)|0);
   HEAP32[$$pre$phi$iZ2D>>2] = $78;
   $79 = (($53) + 8|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($80) + ($size$$i))|0;
   HEAP32[$79>>2] = $81;
   $$pre2 = HEAP32[$3>>2]|0;
   $$0$i = $size$$i;$83 = $$pre2;
  }
  $82 = (($83) + ($$0$i))|0;
  HEAP32[$3>>2] = $82;
  $84 = ($82>>>0)>(2);
  if ($84) {
   $85 = HEAP32[$4>>2]|0;
   $86 = HEAP32[$6>>2]|0;
   $87 = (($86) + ($85)|0);
   $88 = HEAP8[$87>>0]|0;
   $89 = $88&255;
   HEAP32[$7>>2] = $89;
   $90 = HEAP32[$8>>2]|0;
   $91 = $89 << $90;
   $92 = (($85) + 1)|0;
   $93 = (($86) + ($92)|0);
   $94 = HEAP8[$93>>0]|0;
   $95 = $94&255;
   $96 = $95 ^ $91;
   $97 = HEAP32[$9>>2]|0;
   $98 = $96 & $97;
   HEAP32[$7>>2] = $98;
   $99 = ($82>>>0)<(262);
   if (!($99)) {
    label = 23;
    break;
   }
  }
  $100 = HEAP32[$s>>2]|0;
  $101 = (($100) + 4|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)==(0);
  if ($103) {
   label = 23;
   break;
  }
  $$pre3 = HEAP32[$0>>2]|0;
  $17 = $82;$21 = $$pre3;
 }
 if ((label|0) == 23) {
  STACKTOP = sp;return;
 }
}
function _longest_match($s,$cur_match) {
 $s = $s|0;
 $cur_match = $cur_match|0;
 var $$ = 0, $$09 = 0, $$19 = 0, $$best_len$2 = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum17 = 0, $$sum18 = 0, $$sum20 = 0, $$sum21 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $best_len$0 = 0, $best_len$1 = 0, $best_len$2 = 0, $chain_length$0 = 0, $chain_length$1 = 0, $match$0 = 0, $or$cond = 0, $scan$1 = 0, $scan$2 = 0, $scan_end$0 = 0, $scan_end$1 = 0, $scan_end1$0 = 0, $scan_end1$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($s) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($s) + 108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5)|0);
 $7 = (($s) + 120|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($s) + 144|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($s) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + -262)|0;
 $14 = ($5>>>0)>($13>>>0);
 $15 = (($5) - ($13))|0;
 $$ = $14 ? $15 : 0;
 $16 = (($s) + 64|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($s) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 $$sum = (($5) + 258)|0;
 $20 = (($3) + ($$sum)|0);
 $21 = (($5) + -1)|0;
 $$sum10 = (($21) + ($8))|0;
 $22 = (($3) + ($$sum10)|0);
 $23 = HEAP8[$22>>0]|0;
 $$sum11 = (($8) + ($5))|0;
 $24 = (($3) + ($$sum11)|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = (($s) + 140|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($8>>>0)<($27>>>0);
 $29 = $1 >>> 2;
 $chain_length$0 = $28 ? $1 : $29;
 $30 = (($s) + 116|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($10>>>0)>($31>>>0);
 $$19 = $32 ? $31 : $10;
 $33 = (($s) + 112|0);
 $$sum20 = (($5) + 1)|0;
 $34 = (($3) + ($$sum20)|0);
 $$sum21 = (($5) + 2)|0;
 $35 = (($3) + ($$sum21)|0);
 $36 = $20;
 $37 = (($5) + 257)|0;
 $$09 = $cur_match;$best_len$0 = $8;$chain_length$1 = $chain_length$0;$scan_end$0 = $25;$scan_end1$0 = $23;
 while(1) {
  $38 = (($3) + ($$09)|0);
  $$sum12 = (($$09) + ($best_len$0))|0;
  $39 = (($3) + ($$sum12)|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)==($scan_end$0<<24>>24);
  if ($41) {
   $42 = (($best_len$0) + -1)|0;
   $$sum13 = (($42) + ($$09))|0;
   $43 = (($3) + ($$sum13)|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($44<<24>>24)==($scan_end1$0<<24>>24);
   if ($45) {
    $46 = HEAP8[$38>>0]|0;
    $47 = HEAP8[$6>>0]|0;
    $48 = ($46<<24>>24)==($47<<24>>24);
    if ($48) {
     $$sum14 = (($$09) + 1)|0;
     $49 = (($3) + ($$sum14)|0);
     $50 = HEAP8[$49>>0]|0;
     $51 = HEAP8[$34>>0]|0;
     $52 = ($50<<24>>24)==($51<<24>>24);
     if ($52) {
      $$sum15 = (($$09) + 2)|0;
      $53 = (($3) + ($$sum15)|0);
      $match$0 = $53;$scan$1 = $35;
      while(1) {
       $54 = (($scan$1) + 1|0);
       $55 = HEAP8[$54>>0]|0;
       $56 = (($match$0) + 1|0);
       $57 = HEAP8[$56>>0]|0;
       $58 = ($55<<24>>24)==($57<<24>>24);
       if (!($58)) {
        $scan$2 = $54;
        break;
       }
       $59 = (($scan$1) + 2|0);
       $60 = HEAP8[$59>>0]|0;
       $61 = (($match$0) + 2|0);
       $62 = HEAP8[$61>>0]|0;
       $63 = ($60<<24>>24)==($62<<24>>24);
       if (!($63)) {
        $scan$2 = $59;
        break;
       }
       $64 = (($scan$1) + 3|0);
       $65 = HEAP8[$64>>0]|0;
       $66 = (($match$0) + 3|0);
       $67 = HEAP8[$66>>0]|0;
       $68 = ($65<<24>>24)==($67<<24>>24);
       if (!($68)) {
        $scan$2 = $64;
        break;
       }
       $69 = (($scan$1) + 4|0);
       $70 = HEAP8[$69>>0]|0;
       $71 = (($match$0) + 4|0);
       $72 = HEAP8[$71>>0]|0;
       $73 = ($70<<24>>24)==($72<<24>>24);
       if (!($73)) {
        $scan$2 = $69;
        break;
       }
       $74 = (($scan$1) + 5|0);
       $75 = HEAP8[$74>>0]|0;
       $76 = (($match$0) + 5|0);
       $77 = HEAP8[$76>>0]|0;
       $78 = ($75<<24>>24)==($77<<24>>24);
       if (!($78)) {
        $scan$2 = $74;
        break;
       }
       $79 = (($scan$1) + 6|0);
       $80 = HEAP8[$79>>0]|0;
       $81 = (($match$0) + 6|0);
       $82 = HEAP8[$81>>0]|0;
       $83 = ($80<<24>>24)==($82<<24>>24);
       if (!($83)) {
        $scan$2 = $79;
        break;
       }
       $84 = (($scan$1) + 7|0);
       $85 = HEAP8[$84>>0]|0;
       $86 = (($match$0) + 7|0);
       $87 = HEAP8[$86>>0]|0;
       $88 = ($85<<24>>24)==($87<<24>>24);
       if (!($88)) {
        $scan$2 = $84;
        break;
       }
       $89 = (($scan$1) + 8|0);
       $90 = HEAP8[$89>>0]|0;
       $91 = (($match$0) + 8|0);
       $92 = HEAP8[$91>>0]|0;
       $93 = ($90<<24>>24)==($92<<24>>24);
       $94 = ($89>>>0)<($20>>>0);
       $or$cond = $93 & $94;
       if ($or$cond) {
        $match$0 = $91;$scan$1 = $89;
       } else {
        $scan$2 = $89;
        break;
       }
      }
      $95 = $scan$2;
      $96 = (($95) - ($36))|0;
      $97 = (($96) + 258)|0;
      $98 = ($97|0)>($best_len$0|0);
      if ($98) {
       HEAP32[$33>>2] = $$09;
       $99 = ($97|0)<($$19|0);
       if (!($99)) {
        $best_len$2 = $97;
        label = 20;
        break;
       }
       $$sum17 = (($37) + ($96))|0;
       $100 = (($3) + ($$sum17)|0);
       $101 = HEAP8[$100>>0]|0;
       $$sum18 = (($97) + ($5))|0;
       $102 = (($3) + ($$sum18)|0);
       $103 = HEAP8[$102>>0]|0;
       $best_len$1 = $97;$scan_end$1 = $103;$scan_end1$1 = $101;
      } else {
       $best_len$1 = $best_len$0;$scan_end$1 = $scan_end$0;$scan_end1$1 = $scan_end1$0;
      }
     } else {
      $best_len$1 = $best_len$0;$scan_end$1 = $scan_end$0;$scan_end1$1 = $scan_end1$0;
     }
    } else {
     $best_len$1 = $best_len$0;$scan_end$1 = $scan_end$0;$scan_end1$1 = $scan_end1$0;
    }
   } else {
    $best_len$1 = $best_len$0;$scan_end$1 = $scan_end$0;$scan_end1$1 = $scan_end1$0;
   }
  } else {
   $best_len$1 = $best_len$0;$scan_end$1 = $scan_end$0;$scan_end1$1 = $scan_end1$0;
  }
  $104 = $$09 & $19;
  $105 = (($17) + ($104<<1)|0);
  $106 = HEAP16[$105>>1]|0;
  $107 = $106&65535;
  $108 = ($107>>>0)>($$>>>0);
  if (!($108)) {
   $best_len$2 = $best_len$1;
   label = 20;
   break;
  }
  $109 = (($chain_length$1) + -1)|0;
  $110 = ($109|0)==(0);
  if ($110) {
   $best_len$2 = $best_len$1;
   label = 20;
   break;
  } else {
   $$09 = $107;$best_len$0 = $best_len$1;$chain_length$1 = $109;$scan_end$0 = $scan_end$1;$scan_end1$0 = $scan_end1$1;
  }
 }
 if ((label|0) == 20) {
  $111 = ($best_len$2>>>0)>($31>>>0);
  $$best_len$2 = $111 ? $31 : $best_len$2;
  STACKTOP = sp;return ($$best_len$2|0);
 }
 return 0|0;
}
function _longest_match_fast($s,$cur_match) {
 $s = $s|0;
 $cur_match = $cur_match|0;
 var $$ = 0, $$0 = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $match$0 = 0, $or$cond = 0, $scan$0 = 0, $scan$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($s) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3)|0);
 $$sum = (($3) + 258)|0;
 $5 = (($1) + ($$sum)|0);
 $6 = (($1) + ($cur_match)|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = HEAP8[$4>>0]|0;
 $9 = ($7<<24>>24)==($8<<24>>24);
 if (!($9)) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $$sum8 = (($cur_match) + 1)|0;
 $10 = (($1) + ($$sum8)|0);
 $11 = HEAP8[$10>>0]|0;
 $$sum9 = (($3) + 1)|0;
 $12 = (($1) + ($$sum9)|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($11<<24>>24)==($13<<24>>24);
 if (!($14)) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $$sum10 = (($3) + 2)|0;
 $15 = (($1) + ($$sum10)|0);
 $$sum11 = (($cur_match) + 2)|0;
 $16 = (($1) + ($$sum11)|0);
 $match$0 = $16;$scan$0 = $15;
 while(1) {
  $17 = (($scan$0) + 1|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = (($match$0) + 1|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($18<<24>>24)==($20<<24>>24);
  if (!($21)) {
   $scan$1 = $17;
   break;
  }
  $22 = (($scan$0) + 2|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = (($match$0) + 2|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($23<<24>>24)==($25<<24>>24);
  if (!($26)) {
   $scan$1 = $22;
   break;
  }
  $27 = (($scan$0) + 3|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = (($match$0) + 3|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($28<<24>>24)==($30<<24>>24);
  if (!($31)) {
   $scan$1 = $27;
   break;
  }
  $32 = (($scan$0) + 4|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = (($match$0) + 4|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ($33<<24>>24)==($35<<24>>24);
  if (!($36)) {
   $scan$1 = $32;
   break;
  }
  $37 = (($scan$0) + 5|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = (($match$0) + 5|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($38<<24>>24)==($40<<24>>24);
  if (!($41)) {
   $scan$1 = $37;
   break;
  }
  $42 = (($scan$0) + 6|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = (($match$0) + 6|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = ($43<<24>>24)==($45<<24>>24);
  if (!($46)) {
   $scan$1 = $42;
   break;
  }
  $47 = (($scan$0) + 7|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = (($match$0) + 7|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = ($48<<24>>24)==($50<<24>>24);
  if (!($51)) {
   $scan$1 = $47;
   break;
  }
  $52 = (($scan$0) + 8|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = (($match$0) + 8|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = ($53<<24>>24)==($55<<24>>24);
  $57 = ($52>>>0)<($5>>>0);
  $or$cond = $56 & $57;
  if ($or$cond) {
   $match$0 = $54;$scan$0 = $52;
  } else {
   $scan$1 = $52;
   break;
  }
 }
 $58 = $5;
 $59 = $scan$1;
 $60 = (($59) - ($58))|0;
 $61 = (($60) + 258)|0;
 $62 = ($61|0)<(3);
 if ($62) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = (($s) + 112|0);
 HEAP32[$63>>2] = $cur_match;
 $64 = (($s) + 116|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($61>>>0)>($65>>>0);
 $$ = $66 ? $65 : $61;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __tr_init($s) {
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 148|0);
 $1 = (($s) + 2840|0);
 HEAP32[$1>>2] = $0;
 $2 = (($s) + 2848|0);
 HEAP32[$2>>2] = 401176;
 $3 = (($s) + 2440|0);
 $4 = (($s) + 2852|0);
 HEAP32[$4>>2] = $3;
 $5 = (($s) + 2860|0);
 HEAP32[$5>>2] = 401200;
 $6 = (($s) + 2684|0);
 $7 = (($s) + 2864|0);
 HEAP32[$7>>2] = $6;
 $8 = (($s) + 2872|0);
 HEAP32[$8>>2] = 401224;
 $9 = (($s) + 5816|0);
 HEAP16[$9>>1] = 0;
 $10 = (($s) + 5820|0);
 HEAP32[$10>>2] = 0;
 $11 = (($s) + 5812|0);
 HEAP32[$11>>2] = 8;
 _init_block($s);
 STACKTOP = sp;return;
}
function _init_block($s) {
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $n$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $n$04 = 0;
 while(1) {
  $54 = ((($s) + ($n$04<<2)|0) + 148|0);
  HEAP16[$54>>1] = 0;
  $55 = (($n$04) + 1)|0;
  $exitcond = ($55|0)==(286);
  if ($exitcond) {
   break;
  } else {
   $n$04 = $55;
  }
 }
 $0 = (($s) + 2440|0);
 HEAP16[$0>>1] = 0;
 $1 = (($s) + 2444|0);
 HEAP16[$1>>1] = 0;
 $2 = (($s) + 2448|0);
 HEAP16[$2>>1] = 0;
 $3 = (($s) + 2452|0);
 HEAP16[$3>>1] = 0;
 $4 = (($s) + 2456|0);
 HEAP16[$4>>1] = 0;
 $5 = (($s) + 2460|0);
 HEAP16[$5>>1] = 0;
 $6 = (($s) + 2464|0);
 HEAP16[$6>>1] = 0;
 $7 = (($s) + 2468|0);
 HEAP16[$7>>1] = 0;
 $8 = (($s) + 2472|0);
 HEAP16[$8>>1] = 0;
 $9 = (($s) + 2476|0);
 HEAP16[$9>>1] = 0;
 $10 = (($s) + 2480|0);
 HEAP16[$10>>1] = 0;
 $11 = (($s) + 2484|0);
 HEAP16[$11>>1] = 0;
 $12 = (($s) + 2488|0);
 HEAP16[$12>>1] = 0;
 $13 = (($s) + 2492|0);
 HEAP16[$13>>1] = 0;
 $14 = (($s) + 2496|0);
 HEAP16[$14>>1] = 0;
 $15 = (($s) + 2500|0);
 HEAP16[$15>>1] = 0;
 $16 = (($s) + 2504|0);
 HEAP16[$16>>1] = 0;
 $17 = (($s) + 2508|0);
 HEAP16[$17>>1] = 0;
 $18 = (($s) + 2512|0);
 HEAP16[$18>>1] = 0;
 $19 = (($s) + 2516|0);
 HEAP16[$19>>1] = 0;
 $20 = (($s) + 2520|0);
 HEAP16[$20>>1] = 0;
 $21 = (($s) + 2524|0);
 HEAP16[$21>>1] = 0;
 $22 = (($s) + 2528|0);
 HEAP16[$22>>1] = 0;
 $23 = (($s) + 2532|0);
 HEAP16[$23>>1] = 0;
 $24 = (($s) + 2536|0);
 HEAP16[$24>>1] = 0;
 $25 = (($s) + 2540|0);
 HEAP16[$25>>1] = 0;
 $26 = (($s) + 2544|0);
 HEAP16[$26>>1] = 0;
 $27 = (($s) + 2548|0);
 HEAP16[$27>>1] = 0;
 $28 = (($s) + 2552|0);
 HEAP16[$28>>1] = 0;
 $29 = (($s) + 2556|0);
 HEAP16[$29>>1] = 0;
 $30 = (($s) + 2684|0);
 HEAP16[$30>>1] = 0;
 $31 = (($s) + 2688|0);
 HEAP16[$31>>1] = 0;
 $32 = (($s) + 2692|0);
 HEAP16[$32>>1] = 0;
 $33 = (($s) + 2696|0);
 HEAP16[$33>>1] = 0;
 $34 = (($s) + 2700|0);
 HEAP16[$34>>1] = 0;
 $35 = (($s) + 2704|0);
 HEAP16[$35>>1] = 0;
 $36 = (($s) + 2708|0);
 HEAP16[$36>>1] = 0;
 $37 = (($s) + 2712|0);
 HEAP16[$37>>1] = 0;
 $38 = (($s) + 2716|0);
 HEAP16[$38>>1] = 0;
 $39 = (($s) + 2720|0);
 HEAP16[$39>>1] = 0;
 $40 = (($s) + 2724|0);
 HEAP16[$40>>1] = 0;
 $41 = (($s) + 2728|0);
 HEAP16[$41>>1] = 0;
 $42 = (($s) + 2732|0);
 HEAP16[$42>>1] = 0;
 $43 = (($s) + 2736|0);
 HEAP16[$43>>1] = 0;
 $44 = (($s) + 2740|0);
 HEAP16[$44>>1] = 0;
 $45 = (($s) + 2744|0);
 HEAP16[$45>>1] = 0;
 $46 = (($s) + 2748|0);
 HEAP16[$46>>1] = 0;
 $47 = (($s) + 2752|0);
 HEAP16[$47>>1] = 0;
 $48 = (($s) + 2756|0);
 HEAP16[$48>>1] = 0;
 $49 = (($s) + 1172|0);
 HEAP16[$49>>1] = 1;
 $50 = (($s) + 5804|0);
 HEAP32[$50>>2] = 0;
 $51 = (($s) + 5800|0);
 HEAP32[$51>>2] = 0;
 $52 = (($s) + 5808|0);
 HEAP32[$52>>2] = 0;
 $53 = (($s) + 5792|0);
 HEAP32[$53>>2] = 0;
 STACKTOP = sp;return;
}
function __tr_stored_block($s,$buf,$stored_len,$eof) {
 $s = $s|0;
 $buf = $buf|0;
 $stored_len = $stored_len|0;
 $eof = $eof|0;
 var $$011$i = 0, $$02$i = 0, $$off0 = 0, $$off0$in = 0, $$pre$phi$iZ2D = 0, $$pre$phi4$iZ2D = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 5820|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(13);
 $3 = $eof << $1;
 $4 = (($s) + 5816|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = $6 | $3;
 $8 = $7&65535;
 HEAP16[$4>>1] = $8;
 if ($2) {
  $9 = $7&255;
  $10 = (($s) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$10>>2] = $12;
  $13 = (($s) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11)|0);
  HEAP8[$15>>0] = $9;
  $16 = HEAP16[$4>>1]|0;
  $17 = ($16&65535) >>> 8;
  $18 = $17&255;
  $19 = HEAP32[$10>>2]|0;
  $20 = (($19) + 1)|0;
  HEAP32[$10>>2] = $20;
  $21 = HEAP32[$13>>2]|0;
  $22 = (($21) + ($19)|0);
  HEAP8[$22>>0] = $18;
  $23 = $eof & 65535;
  $24 = HEAP32[$0>>2]|0;
  $25 = (16 - ($24))|0;
  $26 = $23 >>> $25;
  $27 = $26&65535;
  HEAP16[$4>>1] = $27;
  $28 = (($24) + -13)|0;
  $$off0$in = $26;$storemerge = $28;
 } else {
  $29 = (($1) + 3)|0;
  $$off0$in = $7;$storemerge = $29;
 }
 $$off0 = $$off0$in&255;
 HEAP32[$0>>2] = $storemerge;
 $30 = ($storemerge|0)>(8);
 do {
  if ($30) {
   $31 = (($s) + 20|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 1)|0;
   HEAP32[$31>>2] = $33;
   $34 = (($s) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + ($32)|0);
   HEAP8[$36>>0] = $$off0;
   $37 = HEAP16[$4>>1]|0;
   $38 = ($37&65535) >>> 8;
   $39 = $38&255;
   $40 = HEAP32[$31>>2]|0;
   $41 = (($40) + 1)|0;
   HEAP32[$31>>2] = $41;
   $42 = HEAP32[$34>>2]|0;
   $43 = (($42) + ($40)|0);
   HEAP8[$43>>0] = $39;
   $$pre$phi$iZ2D = $31;$$pre$phi4$iZ2D = $34;
  } else {
   $44 = ($storemerge|0)>(0);
   $45 = (($s) + 20|0);
   if ($44) {
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + 1)|0;
    HEAP32[$45>>2] = $47;
    $48 = (($s) + 8|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($46)|0);
    HEAP8[$50>>0] = $$off0;
    $$pre$phi$iZ2D = $45;$$pre$phi4$iZ2D = $48;
    break;
   } else {
    $$pre3$i = (($s) + 8|0);
    $$pre$phi$iZ2D = $45;$$pre$phi4$iZ2D = $$pre3$i;
    break;
   }
  }
 } while(0);
 HEAP16[$4>>1] = 0;
 HEAP32[$0>>2] = 0;
 $51 = (($s) + 5812|0);
 HEAP32[$51>>2] = 8;
 $52 = $stored_len&255;
 $53 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$$pre$phi$iZ2D>>2] = $54;
 $55 = HEAP32[$$pre$phi4$iZ2D>>2]|0;
 $56 = (($55) + ($53)|0);
 HEAP8[$56>>0] = $52;
 $57 = $stored_len >>> 8;
 $58 = $57&255;
 $59 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$$pre$phi$iZ2D>>2] = $60;
 $61 = HEAP32[$$pre$phi4$iZ2D>>2]|0;
 $62 = (($61) + ($59)|0);
 HEAP8[$62>>0] = $58;
 $63 = $stored_len & 65535;
 $64 = $63 ^ 65535;
 $65 = $64&255;
 $66 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$$pre$phi$iZ2D>>2] = $67;
 $68 = HEAP32[$$pre$phi4$iZ2D>>2]|0;
 $69 = (($68) + ($66)|0);
 HEAP8[$69>>0] = $65;
 $70 = $64 >>> 8;
 $71 = $70&255;
 $72 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $73 = (($72) + 1)|0;
 HEAP32[$$pre$phi$iZ2D>>2] = $73;
 $74 = HEAP32[$$pre$phi4$iZ2D>>2]|0;
 $75 = (($74) + ($72)|0);
 HEAP8[$75>>0] = $71;
 $76 = ($stored_len|0)==(0);
 if ($76) {
  STACKTOP = sp;return;
 } else {
  $$011$i = $stored_len;$$02$i = $buf;
 }
 while(1) {
  $77 = (($$011$i) + -1)|0;
  $78 = (($$02$i) + 1|0);
  $79 = HEAP8[$$02$i>>0]|0;
  $80 = HEAP32[$$pre$phi$iZ2D>>2]|0;
  $81 = (($80) + 1)|0;
  HEAP32[$$pre$phi$iZ2D>>2] = $81;
  $82 = HEAP32[$$pre$phi4$iZ2D>>2]|0;
  $83 = (($82) + ($80)|0);
  HEAP8[$83>>0] = $79;
  $84 = ($77|0)==(0);
  if ($84) {
   break;
  } else {
   $$011$i = $77;$$02$i = $78;
  }
 }
 STACKTOP = sp;return;
}
function __tr_align($s) {
 $s = $s|0;
 var $$off0 = 0, $$off0$in = 0, $$off06 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $storemerge = 0, $storemerge2 = 0, $storemerge3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 5820|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(13);
 $3 = 2 << $1;
 $4 = (($s) + 5816|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = $6 | $3;
 $8 = $7&65535;
 HEAP16[$4>>1] = $8;
 if ($2) {
  $9 = $7&255;
  $10 = (($s) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$10>>2] = $12;
  $13 = (($s) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11)|0);
  HEAP8[$15>>0] = $9;
  $16 = HEAP16[$4>>1]|0;
  $17 = ($16&65535) >>> 8;
  $18 = $17&255;
  $19 = HEAP32[$10>>2]|0;
  $20 = (($19) + 1)|0;
  HEAP32[$10>>2] = $20;
  $21 = HEAP32[$13>>2]|0;
  $22 = (($21) + ($19)|0);
  HEAP8[$22>>0] = $18;
  $23 = HEAP32[$0>>2]|0;
  $24 = (16 - ($23))|0;
  $25 = 2 >>> $24;
  $26 = $25&65535;
  HEAP16[$4>>1] = $26;
  $27 = (($23) + -13)|0;
  $31 = $26;$storemerge = $27;
 } else {
  $28 = (($1) + 3)|0;
  $31 = $8;$storemerge = $28;
 }
 HEAP32[$0>>2] = $storemerge;
 $29 = ($storemerge|0)>(9);
 if ($29) {
  $30 = $31&255;
  $32 = (($s) + 20|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $35 = (($s) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($33)|0);
  HEAP8[$37>>0] = $30;
  $38 = HEAP16[$4>>1]|0;
  $39 = ($38&65535) >>> 8;
  $40 = $39&255;
  $41 = HEAP32[$32>>2]|0;
  $42 = (($41) + 1)|0;
  HEAP32[$32>>2] = $42;
  $43 = HEAP32[$35>>2]|0;
  $44 = (($43) + ($41)|0);
  HEAP8[$44>>0] = $40;
  HEAP16[$4>>1] = 0;
  $45 = HEAP32[$0>>2]|0;
  $46 = (($45) + -9)|0;
  $$pr = $46;$50 = 0;
 } else {
  $47 = (($storemerge) + 7)|0;
  $$pr = $47;$50 = $31;
 }
 HEAP32[$0>>2] = $$pr;
 $48 = ($$pr|0)==(16);
 if ($48) {
  $49 = $50&255;
  $51 = (($s) + 20|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + 1)|0;
  HEAP32[$51>>2] = $53;
  $54 = (($s) + 8|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + ($52)|0);
  HEAP8[$56>>0] = $49;
  $57 = HEAP16[$4>>1]|0;
  $58 = ($57&65535) >>> 8;
  $59 = $58&255;
  $60 = HEAP32[$51>>2]|0;
  $61 = (($60) + 1)|0;
  HEAP32[$51>>2] = $61;
  $62 = HEAP32[$54>>2]|0;
  $63 = (($62) + ($60)|0);
  HEAP8[$63>>0] = $59;
  HEAP16[$4>>1] = 0;
  HEAP32[$0>>2] = 0;
  $79 = 0;$85 = 0;
 } else {
  $64 = ($$pr|0)>(7);
  if ($64) {
   $65 = $50&255;
   $66 = (($s) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($67) + 1)|0;
   HEAP32[$66>>2] = $68;
   $69 = (($s) + 8|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + ($67)|0);
   HEAP8[$71>>0] = $65;
   $72 = HEAP16[$4>>1]|0;
   $73 = ($72&65535) >>> 8;
   HEAP16[$4>>1] = $73;
   $74 = HEAP32[$0>>2]|0;
   $75 = (($74) + -8)|0;
   HEAP32[$0>>2] = $75;
   $79 = $75;$85 = $73;
  } else {
   $79 = $$pr;$85 = $50;
  }
 }
 $76 = (($s) + 5812|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (11 - ($79))|0;
 $80 = (($78) + ($77))|0;
 $81 = ($80|0)<(9);
 if (!($81)) {
  HEAP32[$76>>2] = 7;
  STACKTOP = sp;return;
 }
 $82 = ($79|0)>(13);
 $83 = 2 << $79;
 $84 = $85&65535;
 $86 = $84 | $83;
 $87 = $86&65535;
 HEAP16[$4>>1] = $87;
 if ($82) {
  $88 = $86&255;
  $89 = (($s) + 20|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($90) + 1)|0;
  HEAP32[$89>>2] = $91;
  $92 = (($s) + 8|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (($93) + ($90)|0);
  HEAP8[$94>>0] = $88;
  $95 = HEAP16[$4>>1]|0;
  $96 = ($95&65535) >>> 8;
  $97 = $96&255;
  $98 = HEAP32[$89>>2]|0;
  $99 = (($98) + 1)|0;
  HEAP32[$89>>2] = $99;
  $100 = HEAP32[$92>>2]|0;
  $101 = (($100) + ($98)|0);
  HEAP8[$101>>0] = $97;
  $102 = HEAP32[$0>>2]|0;
  $103 = (16 - ($102))|0;
  $104 = 2 >>> $103;
  $105 = $104&65535;
  HEAP16[$4>>1] = $105;
  $106 = (($102) + -13)|0;
  $$off0$in = $104;$storemerge2 = $106;
 } else {
  $107 = (($79) + 3)|0;
  $$off0$in = $86;$storemerge2 = $107;
 }
 $$off0 = $$off0$in&255;
 HEAP32[$0>>2] = $storemerge2;
 $108 = ($storemerge2|0)>(9);
 if ($108) {
  $109 = (($s) + 20|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (($110) + 1)|0;
  HEAP32[$109>>2] = $111;
  $112 = (($s) + 8|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($113) + ($110)|0);
  HEAP8[$114>>0] = $$off0;
  $115 = HEAP16[$4>>1]|0;
  $116 = ($115&65535) >>> 8;
  $117 = $116&255;
  $118 = HEAP32[$109>>2]|0;
  $119 = (($118) + 1)|0;
  HEAP32[$109>>2] = $119;
  $120 = HEAP32[$112>>2]|0;
  $121 = (($120) + ($118)|0);
  HEAP8[$121>>0] = $117;
  HEAP16[$4>>1] = 0;
  $122 = HEAP32[$0>>2]|0;
  $123 = (($122) + -9)|0;
  $$off06 = 0;$storemerge3 = $123;
 } else {
  $124 = (($storemerge2) + 7)|0;
  $$off06 = $$off0;$storemerge3 = $124;
 }
 HEAP32[$0>>2] = $storemerge3;
 $125 = ($storemerge3|0)==(16);
 if ($125) {
  $126 = (($s) + 20|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = (($127) + 1)|0;
  HEAP32[$126>>2] = $128;
  $129 = (($s) + 8|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($130) + ($127)|0);
  HEAP8[$131>>0] = $$off06;
  $132 = HEAP16[$4>>1]|0;
  $133 = ($132&65535) >>> 8;
  $134 = $133&255;
  $135 = HEAP32[$126>>2]|0;
  $136 = (($135) + 1)|0;
  HEAP32[$126>>2] = $136;
  $137 = HEAP32[$129>>2]|0;
  $138 = (($137) + ($135)|0);
  HEAP8[$138>>0] = $134;
  HEAP16[$4>>1] = 0;
  HEAP32[$0>>2] = 0;
  HEAP32[$76>>2] = 7;
  STACKTOP = sp;return;
 }
 $139 = ($storemerge3|0)>(7);
 if (!($139)) {
  HEAP32[$76>>2] = 7;
  STACKTOP = sp;return;
 }
 $140 = (($s) + 20|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (($141) + 1)|0;
 HEAP32[$140>>2] = $142;
 $143 = (($s) + 8|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = (($144) + ($141)|0);
 HEAP8[$145>>0] = $$off06;
 $146 = HEAP16[$4>>1]|0;
 $147 = ($146&65535) >>> 8;
 HEAP16[$4>>1] = $147;
 $148 = HEAP32[$0>>2]|0;
 $149 = (($148) + -8)|0;
 HEAP32[$0>>2] = $149;
 HEAP32[$76>>2] = 7;
 STACKTOP = sp;return;
}
function __tr_flush_block($s,$buf,$stored_len,$eof) {
 $s = $s|0;
 $buf = $buf|0;
 $stored_len = $stored_len|0;
 $eof = $eof|0;
 var $$ = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $max_blindex$0 = 0, $max_blindex$0$lcssa$i = 0;
 var $max_blindex$01$i = 0, $n$0$lcssa$i = 0, $n$02$i = 0, $n$11$i = 0, $n$2$i = 0, $opt_lenb$0 = 0, $or$cond = 0, $or$cond2 = 0, $rank$04$i = 0, $static_lenb$0 = 0, $storemerge = 0, $storemerge1 = 0, $storemerge2$i = 0, $storemerge3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 132|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if ($2) {
  $3 = ($stored_len|0)==(0);
  if (!($3)) {
   $4 = HEAP32[$s>>2]|0;
   $5 = (($4) + 44|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(2);
   if ($7) {
    $n$02$i = 0;
    while(1) {
     $10 = ((($s) + ($n$02$i<<2)|0) + 148|0);
     $11 = HEAP16[$10>>1]|0;
     $12 = ($11<<16>>16)==(0);
     $9 = (($n$02$i) + 1)|0;
     if (!($12)) {
      $n$0$lcssa$i = $n$02$i;
      break;
     }
     $8 = ($9|0)<(9);
     if ($8) {
      $n$02$i = $9;
     } else {
      $n$0$lcssa$i = $9;
      break;
     }
    }
    $13 = ($n$0$lcssa$i|0)==(9);
    L10: do {
     if ($13) {
      $n$11$i = 14;
      while(1) {
       $16 = ((($s) + ($n$11$i<<2)|0) + 148|0);
       $17 = HEAP16[$16>>1]|0;
       $18 = ($17<<16>>16)==(0);
       $15 = (($n$11$i) + 1)|0;
       if (!($18)) {
        $n$2$i = $n$11$i;
        break L10;
       }
       $14 = ($15|0)<(32);
       if ($14) {
        $n$11$i = $15;
       } else {
        $n$2$i = $15;
        break;
       }
      }
     } else {
      $n$2$i = $n$0$lcssa$i;
     }
    } while(0);
    $19 = ($n$2$i|0)==(32);
    $20 = $19&1;
    HEAP32[$5>>2] = $20;
   }
  }
  $21 = (($s) + 2840|0);
  _build_tree($s,$21);
  $22 = (($s) + 2852|0);
  _build_tree($s,$22);
  $23 = (($s) + 148|0);
  $24 = (($s) + 2844|0);
  $25 = HEAP32[$24>>2]|0;
  _scan_tree($s,$23,$25);
  $26 = (($s) + 2440|0);
  $27 = (($s) + 2856|0);
  $28 = HEAP32[$27>>2]|0;
  _scan_tree($s,$26,$28);
  $29 = (($s) + 2864|0);
  _build_tree($s,$29);
  $max_blindex$01$i = 18;
  while(1) {
   $32 = (403000 + ($max_blindex$01$i)|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = $33&255;
   $35 = ((($s) + ($34<<2)|0) + 2686|0);
   $36 = HEAP16[$35>>1]|0;
   $37 = ($36<<16>>16)==(0);
   $31 = (($max_blindex$01$i) + -1)|0;
   if (!($37)) {
    $max_blindex$0$lcssa$i = $max_blindex$01$i;
    break;
   }
   $30 = ($31|0)>(2);
   if ($30) {
    $max_blindex$01$i = $31;
   } else {
    $max_blindex$0$lcssa$i = $31;
    break;
   }
  }
  $38 = ($max_blindex$0$lcssa$i*3)|0;
  $39 = (($38) + 17)|0;
  $40 = (($s) + 5800|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41))|0;
  HEAP32[$40>>2] = $42;
  $43 = (($42) + 10)|0;
  $44 = $43 >>> 3;
  $45 = (($s) + 5804|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + 10)|0;
  $48 = $47 >>> 3;
  $49 = ($48>>>0)>($44>>>0);
  $$ = $49 ? $44 : $48;
  $max_blindex$0 = $max_blindex$0$lcssa$i;$opt_lenb$0 = $$;$static_lenb$0 = $48;
 } else {
  $50 = (($stored_len) + 5)|0;
  $max_blindex$0 = 0;$opt_lenb$0 = $50;$static_lenb$0 = $50;
 }
 $51 = (($stored_len) + 4)|0;
 $52 = ($51>>>0)>($opt_lenb$0>>>0);
 $53 = ($buf|0)==(0|0);
 $or$cond = $52 | $53;
 do {
  if ($or$cond) {
   $54 = (($s) + 136|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(4);
   $57 = ($static_lenb$0|0)==($opt_lenb$0|0);
   $or$cond2 = $56 | $57;
   $58 = (($s) + 5820|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)>(13);
   if ($or$cond2) {
    $61 = (($eof) + 2)|0;
    $62 = $61 << $59;
    $63 = (($s) + 5816|0);
    $64 = HEAP16[$63>>1]|0;
    $65 = $64&65535;
    $66 = $65 | $62;
    $67 = $66&65535;
    HEAP16[$63>>1] = $67;
    if ($60) {
     $68 = $66&255;
     $69 = (($s) + 20|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($70) + 1)|0;
     HEAP32[$69>>2] = $71;
     $72 = (($s) + 8|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = (($73) + ($70)|0);
     HEAP8[$74>>0] = $68;
     $75 = HEAP16[$63>>1]|0;
     $76 = ($75&65535) >>> 8;
     $77 = $76&255;
     $78 = HEAP32[$69>>2]|0;
     $79 = (($78) + 1)|0;
     HEAP32[$69>>2] = $79;
     $80 = HEAP32[$72>>2]|0;
     $81 = (($80) + ($78)|0);
     HEAP8[$81>>0] = $77;
     $82 = $61 & 65535;
     $83 = HEAP32[$58>>2]|0;
     $84 = (16 - ($83))|0;
     $85 = $82 >>> $84;
     $86 = $85&65535;
     HEAP16[$63>>1] = $86;
     $87 = (($83) + -13)|0;
     $storemerge1 = $87;
    } else {
     $88 = (($59) + 3)|0;
     $storemerge1 = $88;
    }
    HEAP32[$58>>2] = $storemerge1;
    _compress_block($s,401248,402400);
    break;
   }
   $89 = (($eof) + 4)|0;
   $90 = $89 << $59;
   $91 = (($s) + 5816|0);
   $92 = HEAP16[$91>>1]|0;
   $93 = $92&65535;
   $94 = $93 | $90;
   $95 = $94&65535;
   HEAP16[$91>>1] = $95;
   if ($60) {
    $96 = $94&255;
    $97 = (($s) + 20|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (($98) + 1)|0;
    HEAP32[$97>>2] = $99;
    $100 = (($s) + 8|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = (($101) + ($98)|0);
    HEAP8[$102>>0] = $96;
    $103 = HEAP16[$91>>1]|0;
    $104 = ($103&65535) >>> 8;
    $105 = $104&255;
    $106 = HEAP32[$97>>2]|0;
    $107 = (($106) + 1)|0;
    HEAP32[$97>>2] = $107;
    $108 = HEAP32[$100>>2]|0;
    $109 = (($108) + ($106)|0);
    HEAP8[$109>>0] = $105;
    $110 = $89 & 65535;
    $111 = HEAP32[$58>>2]|0;
    $112 = (16 - ($111))|0;
    $113 = $110 >>> $112;
    $114 = $113&65535;
    HEAP16[$91>>1] = $114;
    $115 = (($111) + -13)|0;
    $125 = $113;$storemerge = $115;
   } else {
    $116 = (($59) + 3)|0;
    $125 = $94;$storemerge = $116;
   }
   HEAP32[$58>>2] = $storemerge;
   $117 = (($s) + 2844|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($s) + 2856|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ($storemerge|0)>(11);
   $122 = (($118) + -256)|0;
   $123 = $122 << $storemerge;
   $124 = $125 & 65535;
   $126 = $124 | $123;
   $127 = $126&65535;
   HEAP16[$91>>1] = $127;
   if ($121) {
    $128 = $126&255;
    $129 = (($s) + 20|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = (($130) + 1)|0;
    HEAP32[$129>>2] = $131;
    $132 = (($s) + 8|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = (($133) + ($130)|0);
    HEAP8[$134>>0] = $128;
    $135 = HEAP16[$91>>1]|0;
    $136 = ($135&65535) >>> 8;
    $137 = $136&255;
    $138 = HEAP32[$129>>2]|0;
    $139 = (($138) + 1)|0;
    HEAP32[$129>>2] = $139;
    $140 = HEAP32[$132>>2]|0;
    $141 = (($140) + ($138)|0);
    HEAP8[$141>>0] = $137;
    $142 = $122 & 65535;
    $143 = HEAP32[$58>>2]|0;
    $144 = (16 - ($143))|0;
    $145 = $142 >>> $144;
    $146 = $145&65535;
    HEAP16[$91>>1] = $146;
    $147 = (($143) + -11)|0;
    $149 = $147;$153 = $145;
   } else {
    $148 = (($storemerge) + 5)|0;
    $149 = $148;$153 = $126;
   }
   HEAP32[$58>>2] = $149;
   $150 = ($149|0)>(11);
   $151 = $120 << $149;
   $152 = $153 & 65535;
   $154 = $151 | $152;
   $155 = $154&65535;
   HEAP16[$91>>1] = $155;
   if ($150) {
    $156 = $154&255;
    $157 = (($s) + 20|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($158) + 1)|0;
    HEAP32[$157>>2] = $159;
    $160 = (($s) + 8|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = (($161) + ($158)|0);
    HEAP8[$162>>0] = $156;
    $163 = HEAP16[$91>>1]|0;
    $164 = ($163&65535) >>> 8;
    $165 = $164&255;
    $166 = HEAP32[$157>>2]|0;
    $167 = (($166) + 1)|0;
    HEAP32[$157>>2] = $167;
    $168 = HEAP32[$160>>2]|0;
    $169 = (($168) + ($166)|0);
    HEAP8[$169>>0] = $165;
    $170 = $120 & 65535;
    $171 = HEAP32[$58>>2]|0;
    $172 = (16 - ($171))|0;
    $173 = $170 >>> $172;
    $174 = $173&65535;
    HEAP16[$91>>1] = $174;
    $175 = (($171) + -11)|0;
    $177 = $175;$182 = $173;
   } else {
    $176 = (($149) + 5)|0;
    $177 = $176;$182 = $154;
   }
   HEAP32[$58>>2] = $177;
   $178 = ($177|0)>(12);
   $179 = (($max_blindex$0) + -3)|0;
   $180 = $179 << $177;
   $181 = $182 & 65535;
   $183 = $180 | $181;
   $184 = $183&65535;
   HEAP16[$91>>1] = $184;
   if ($178) {
    $185 = $183&255;
    $186 = (($s) + 20|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = (($187) + 1)|0;
    HEAP32[$186>>2] = $188;
    $189 = (($s) + 8|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = (($190) + ($187)|0);
    HEAP8[$191>>0] = $185;
    $192 = HEAP16[$91>>1]|0;
    $193 = ($192&65535) >>> 8;
    $194 = $193&255;
    $195 = HEAP32[$186>>2]|0;
    $196 = (($195) + 1)|0;
    HEAP32[$186>>2] = $196;
    $197 = HEAP32[$189>>2]|0;
    $198 = (($197) + ($195)|0);
    HEAP8[$198>>0] = $194;
    $199 = $179 & 65535;
    $200 = HEAP32[$58>>2]|0;
    $201 = (16 - ($200))|0;
    $202 = $199 >>> $201;
    $203 = $202&65535;
    HEAP16[$91>>1] = $203;
    $204 = (($200) + -12)|0;
    $273 = $202;$storemerge2$i = $204;
   } else {
    $205 = (($177) + 4)|0;
    $273 = $183;$storemerge2$i = $205;
   }
   HEAP32[$58>>2] = $storemerge2$i;
   $206 = ($max_blindex$0|0)>(-1);
   if ($206) {
    $207 = (($s) + 20|0);
    $208 = (($s) + 8|0);
    $210 = $storemerge2$i;$219 = $273;$rank$04$i = 0;
    while(1) {
     $209 = ($210|0)>(13);
     $211 = (403000 + ($rank$04$i)|0);
     $212 = HEAP8[$211>>0]|0;
     $213 = $212&255;
     $214 = ((($s) + ($213<<2)|0) + 2686|0);
     $215 = HEAP16[$214>>1]|0;
     $216 = $215&65535;
     $217 = $216 << $210;
     $218 = $219 & 65535;
     $220 = $217 | $218;
     $221 = $220&65535;
     HEAP16[$91>>1] = $221;
     if ($209) {
      $222 = $220&255;
      $223 = HEAP32[$207>>2]|0;
      $224 = (($223) + 1)|0;
      HEAP32[$207>>2] = $224;
      $225 = HEAP32[$208>>2]|0;
      $226 = (($225) + ($223)|0);
      HEAP8[$226>>0] = $222;
      $227 = HEAP16[$91>>1]|0;
      $228 = ($227&65535) >>> 8;
      $229 = $228&255;
      $230 = HEAP32[$207>>2]|0;
      $231 = (($230) + 1)|0;
      HEAP32[$207>>2] = $231;
      $232 = HEAP32[$208>>2]|0;
      $233 = (($232) + ($230)|0);
      HEAP8[$233>>0] = $229;
      $234 = HEAP32[$58>>2]|0;
      $235 = (16 - ($234))|0;
      $236 = $216 >>> $235;
      $237 = $236&65535;
      HEAP16[$91>>1] = $237;
      $238 = (($234) + -13)|0;
      $274 = $236;$storemerge3$i = $238;
     } else {
      $239 = (($210) + 3)|0;
      $274 = $220;$storemerge3$i = $239;
     }
     HEAP32[$58>>2] = $storemerge3$i;
     $240 = (($rank$04$i) + 1)|0;
     $exitcond$i = ($rank$04$i|0)==($max_blindex$0|0);
     if ($exitcond$i) {
      break;
     } else {
      $210 = $storemerge3$i;$219 = $274;$rank$04$i = $240;
     }
    }
   }
   $241 = (($s) + 148|0);
   _send_tree($s,$241,$118);
   $242 = (($s) + 2440|0);
   _send_tree($s,$242,$120);
   _compress_block($s,$241,$242);
  } else {
   __tr_stored_block($s,$buf,$stored_len,$eof);
  }
 } while(0);
 _init_block($s);
 $243 = ($eof|0)==(0);
 if ($243) {
  STACKTOP = sp;return;
 }
 $244 = (($s) + 5820|0);
 $245 = HEAP32[$244>>2]|0;
 $246 = ($245|0)>(8);
 if ($246) {
  $247 = (($s) + 5816|0);
  $248 = HEAP16[$247>>1]|0;
  $249 = $248&255;
  $250 = (($s) + 20|0);
  $251 = HEAP32[$250>>2]|0;
  $252 = (($251) + 1)|0;
  HEAP32[$250>>2] = $252;
  $253 = (($s) + 8|0);
  $254 = HEAP32[$253>>2]|0;
  $255 = (($254) + ($251)|0);
  HEAP8[$255>>0] = $249;
  $256 = HEAP16[$247>>1]|0;
  $257 = ($256&65535) >>> 8;
  $258 = $257&255;
  $259 = HEAP32[$250>>2]|0;
  $260 = (($259) + 1)|0;
  HEAP32[$250>>2] = $260;
  $261 = HEAP32[$253>>2]|0;
  $262 = (($261) + ($259)|0);
  HEAP8[$262>>0] = $258;
  $$pre$phi$iZ2D = $247;
 } else {
  $263 = ($245|0)>(0);
  $264 = (($s) + 5816|0);
  if ($263) {
   $265 = HEAP16[$264>>1]|0;
   $266 = $265&255;
   $267 = (($s) + 20|0);
   $268 = HEAP32[$267>>2]|0;
   $269 = (($268) + 1)|0;
   HEAP32[$267>>2] = $269;
   $270 = (($s) + 8|0);
   $271 = HEAP32[$270>>2]|0;
   $272 = (($271) + ($268)|0);
   HEAP8[$272>>0] = $266;
   $$pre$phi$iZ2D = $264;
  } else {
   $$pre$phi$iZ2D = $264;
  }
 }
 HEAP16[$$pre$phi$iZ2D>>1] = 0;
 HEAP32[$244>>2] = 0;
 STACKTOP = sp;return;
}
function _build_tree($s,$desc) {
 $s = $s|0;
 $desc = $desc|0;
 var $$ = 0, $$$i = 0, $$$us = 0, $$$us$i = 0, $$0$i$i = 0, $$0$lcssa$i = 0, $$0$lcssa$i14 = 0, $$0$lcssa$i22 = 0, $$01$i$i = 0, $$02$i = 0, $$02$i10 = 0, $$02$i18 = 0, $$1 = 0, $$max_code$2 = 0, $$max_code$2$us = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = 0, $$pre48 = 0, $$pre54 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bits$03$i = 0, $bits$2$i = 0, $bits$2$in$i = 0, $bits$34$i = 0, $code$04$i = 0, $desc$idx$val = 0, $desc$idx2$val = 0, $desc$idx3$val = 0;
 var $exitcond = 0, $exitcond$i = 0, $exitcond$i5 = 0, $exitcond23$i = 0, $exitcond5$i = 0, $h$0$i = 0, $h$0$us$i = 0, $h$011$i = 0, $h$011$us$i = 0, $h$09$i = 0, $h$15$i = 0, $h$2$i = 0, $h$2$ph$i$lcssa = 0, $h$2$ph$i27 = 0, $j$0$i = 0, $j$0$i13 = 0, $j$0$i21 = 0, $j$01$i = 0, $j$03$i = 0, $j$03$i17 = 0;
 var $j$03$i9 = 0, $j$1$i = 0, $j$1$i11 = 0, $j$1$i19 = 0, $max_code$0$lcssa56 = 0, $max_code$039 = 0, $max_code$1 = 0, $max_code$2$lcssa = 0, $max_code$235 = 0, $max_code$235$us = 0, $n$0$ph$i26 = 0, $n$01$i = 0, $n$038 = 0, $n$133 = 0, $next_code$i = 0, $node$0 = 0, $overflow$0$$i = 0, $overflow$0$$us$i = 0, $overflow$0$lcssa$i = 0, $overflow$010$i = 0;
 var $overflow$010$us$i = 0, $overflow$2$i = 0, $res$0$i$i = 0, $scevgep$i = 0, $xbits$0$i = 0, $xbits$0$us$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $next_code$i = sp;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($2) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($s) + 5200|0);
 HEAP32[$6>>2] = 0;
 $7 = (($s) + 5204|0);
 HEAP32[$7>>2] = 573;
 $8 = ($5|0)>(0);
 if ($8) {
  $max_code$039 = -1;$n$038 = 0;
  while(1) {
   $24 = (($0) + ($n$038<<2)|0);
   $25 = HEAP16[$24>>1]|0;
   $26 = ($25<<16>>16)==(0);
   if ($26) {
    $31 = ((($0) + ($n$038<<2)|0) + 2|0);
    HEAP16[$31>>1] = 0;
    $max_code$1 = $max_code$039;
   } else {
    $27 = HEAP32[$6>>2]|0;
    $28 = (($27) + 1)|0;
    HEAP32[$6>>2] = $28;
    $29 = ((($s) + ($28<<2)|0) + 2908|0);
    HEAP32[$29>>2] = $n$038;
    $30 = ((($s) + ($n$038)|0) + 5208|0);
    HEAP8[$30>>0] = 0;
    $max_code$1 = $n$038;
   }
   $32 = (($n$038) + 1)|0;
   $exitcond = ($32|0)==($5|0);
   if ($exitcond) {
    break;
   } else {
    $max_code$039 = $max_code$1;$n$038 = $32;
   }
  }
  $$pre = HEAP32[$6>>2]|0;
  $9 = ($$pre|0)<(2);
  if ($9) {
   $351 = $$pre;$max_code$0$lcssa56 = $max_code$1;
   label = 3;
  } else {
   $max_code$2$lcssa = $max_code$1;
  }
 } else {
  $351 = 0;$max_code$0$lcssa56 = -1;
  label = 3;
 }
 if ((label|0) == 3) {
  $10 = (($s) + 5800|0);
  $11 = ($3|0)==(0|0);
  $12 = (($s) + 5804|0);
  if ($11) {
   $16 = $351;$max_code$235$us = $max_code$0$lcssa56;
   while(1) {
    $13 = ($max_code$235$us|0)<(2);
    $14 = (($max_code$235$us) + 1)|0;
    $$max_code$2$us = $13 ? $14 : $max_code$235$us;
    $$$us = $13 ? $14 : 0;
    $15 = (($16) + 1)|0;
    HEAP32[$6>>2] = $15;
    $17 = ((($s) + ($15<<2)|0) + 2908|0);
    HEAP32[$17>>2] = $$$us;
    $18 = (($0) + ($$$us<<2)|0);
    HEAP16[$18>>1] = 1;
    $19 = ((($s) + ($$$us)|0) + 5208|0);
    HEAP8[$19>>0] = 0;
    $20 = HEAP32[$10>>2]|0;
    $21 = (($20) + -1)|0;
    HEAP32[$10>>2] = $21;
    $22 = HEAP32[$6>>2]|0;
    $23 = ($22|0)<(2);
    if ($23) {
     $16 = $22;$max_code$235$us = $$max_code$2$us;
    } else {
     $max_code$2$lcssa = $$max_code$2$us;
     break;
    }
   }
  } else {
   $36 = $351;$max_code$235 = $max_code$0$lcssa56;
   while(1) {
    $33 = ($max_code$235|0)<(2);
    $34 = (($max_code$235) + 1)|0;
    $$max_code$2 = $33 ? $34 : $max_code$235;
    $$ = $33 ? $34 : 0;
    $35 = (($36) + 1)|0;
    HEAP32[$6>>2] = $35;
    $37 = ((($s) + ($35<<2)|0) + 2908|0);
    HEAP32[$37>>2] = $$;
    $38 = (($0) + ($$<<2)|0);
    HEAP16[$38>>1] = 1;
    $39 = ((($s) + ($$)|0) + 5208|0);
    HEAP8[$39>>0] = 0;
    $40 = HEAP32[$10>>2]|0;
    $41 = (($40) + -1)|0;
    HEAP32[$10>>2] = $41;
    $42 = ((($3) + ($$<<2)|0) + 2|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = $43&65535;
    $45 = HEAP32[$12>>2]|0;
    $46 = (($45) - ($44))|0;
    HEAP32[$12>>2] = $46;
    $47 = HEAP32[$6>>2]|0;
    $48 = ($47|0)<(2);
    if ($48) {
     $36 = $47;$max_code$235 = $$max_code$2;
    } else {
     $max_code$2$lcssa = $$max_code$2;
     break;
    }
   }
  }
 }
 $49 = (($desc) + 4|0);
 HEAP32[$49>>2] = $max_code$2$lcssa;
 $50 = HEAP32[$6>>2]|0;
 $51 = ($50|0)>(1);
 if ($51) {
  $52 = (($50|0) / 2)&-1;
  $58 = $50;$n$133 = $52;
  while(1) {
   $54 = ((($s) + ($n$133<<2)|0) + 2908|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ((($s) + ($55)|0) + 5208|0);
   $j$01$i = $n$133 << 1;
   $57 = ($j$01$i|0)>($58|0);
   L21: do {
    if ($57) {
     $$0$lcssa$i = $n$133;
    } else {
     $59 = (($0) + ($55<<2)|0);
     $$02$i = $n$133;$61 = $58;$j$03$i = $j$01$i;
     while(1) {
      $60 = ($j$03$i|0)<($61|0);
      do {
       if ($60) {
        $62 = $j$03$i | 1;
        $63 = ((($s) + ($62<<2)|0) + 2908|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = (($0) + ($64<<2)|0);
        $66 = HEAP16[$65>>1]|0;
        $67 = ((($s) + ($j$03$i<<2)|0) + 2908|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = (($0) + ($68<<2)|0);
        $70 = HEAP16[$69>>1]|0;
        $71 = ($66&65535)<($70&65535);
        if (!($71)) {
         $72 = ($66<<16>>16)==($70<<16>>16);
         if (!($72)) {
          $j$1$i = $j$03$i;
          break;
         }
         $73 = ((($s) + ($64)|0) + 5208|0);
         $74 = HEAP8[$73>>0]|0;
         $75 = ((($s) + ($68)|0) + 5208|0);
         $76 = HEAP8[$75>>0]|0;
         $77 = ($74&255)>($76&255);
         if ($77) {
          $j$1$i = $j$03$i;
          break;
         }
        }
        $j$1$i = $62;
       } else {
        $j$1$i = $j$03$i;
       }
      } while(0);
      $78 = HEAP16[$59>>1]|0;
      $79 = ((($s) + ($j$1$i<<2)|0) + 2908|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($0) + ($80<<2)|0);
      $82 = HEAP16[$81>>1]|0;
      $83 = ($78&65535)<($82&65535);
      if ($83) {
       $$0$lcssa$i = $$02$i;
       break L21;
      }
      $84 = ($78<<16>>16)==($82<<16>>16);
      if ($84) {
       $85 = HEAP8[$56>>0]|0;
       $86 = ((($s) + ($80)|0) + 5208|0);
       $87 = HEAP8[$86>>0]|0;
       $88 = ($85&255)>($87&255);
       if (!($88)) {
        $$0$lcssa$i = $$02$i;
        break L21;
       }
      }
      $89 = ((($s) + ($$02$i<<2)|0) + 2908|0);
      HEAP32[$89>>2] = $80;
      $j$0$i = $j$1$i << 1;
      $90 = HEAP32[$6>>2]|0;
      $91 = ($j$0$i|0)>($90|0);
      if ($91) {
       $$0$lcssa$i = $j$1$i;
       break;
      } else {
       $$02$i = $j$1$i;$61 = $90;$j$03$i = $j$0$i;
      }
     }
    }
   } while(0);
   $92 = ((($s) + ($$0$lcssa$i<<2)|0) + 2908|0);
   HEAP32[$92>>2] = $55;
   $93 = (($n$133) + -1)|0;
   $94 = ($93|0)>(0);
   $$pre54 = HEAP32[$6>>2]|0;
   if ($94) {
    $58 = $$pre54;$n$133 = $93;
   } else {
    $$pre48 = $$pre54;
    break;
   }
  }
 } else {
  $$pre48 = $50;
 }
 $53 = (($s) + 2912|0);
 $97 = $$pre48;$node$0 = $5;
 while(1) {
  $95 = HEAP32[$53>>2]|0;
  $96 = (($97) + -1)|0;
  HEAP32[$6>>2] = $96;
  $98 = ((($s) + ($97<<2)|0) + 2908|0);
  $99 = HEAP32[$98>>2]|0;
  HEAP32[$53>>2] = $99;
  $100 = ((($s) + ($99)|0) + 5208|0);
  $101 = ($97|0)<(3);
  L40: do {
   if ($101) {
    $$0$lcssa$i22 = 1;
   } else {
    $102 = (($0) + ($99<<2)|0);
    $$02$i18 = 1;$104 = $96;$j$03$i17 = 2;
    while(1) {
     $103 = ($j$03$i17|0)<($104|0);
     do {
      if ($103) {
       $105 = $j$03$i17 | 1;
       $106 = ((($s) + ($105<<2)|0) + 2908|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = (($0) + ($107<<2)|0);
       $109 = HEAP16[$108>>1]|0;
       $110 = ((($s) + ($j$03$i17<<2)|0) + 2908|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = (($0) + ($111<<2)|0);
       $113 = HEAP16[$112>>1]|0;
       $114 = ($109&65535)<($113&65535);
       if (!($114)) {
        $115 = ($109<<16>>16)==($113<<16>>16);
        if (!($115)) {
         $j$1$i19 = $j$03$i17;
         break;
        }
        $116 = ((($s) + ($107)|0) + 5208|0);
        $117 = HEAP8[$116>>0]|0;
        $118 = ((($s) + ($111)|0) + 5208|0);
        $119 = HEAP8[$118>>0]|0;
        $120 = ($117&255)>($119&255);
        if ($120) {
         $j$1$i19 = $j$03$i17;
         break;
        }
       }
       $j$1$i19 = $105;
      } else {
       $j$1$i19 = $j$03$i17;
      }
     } while(0);
     $121 = HEAP16[$102>>1]|0;
     $122 = ((($s) + ($j$1$i19<<2)|0) + 2908|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = (($0) + ($123<<2)|0);
     $125 = HEAP16[$124>>1]|0;
     $126 = ($121&65535)<($125&65535);
     if ($126) {
      $$0$lcssa$i22 = $$02$i18;
      break L40;
     }
     $127 = ($121<<16>>16)==($125<<16>>16);
     if ($127) {
      $128 = HEAP8[$100>>0]|0;
      $129 = ((($s) + ($123)|0) + 5208|0);
      $130 = HEAP8[$129>>0]|0;
      $131 = ($128&255)>($130&255);
      if (!($131)) {
       $$0$lcssa$i22 = $$02$i18;
       break L40;
      }
     }
     $132 = ((($s) + ($$02$i18<<2)|0) + 2908|0);
     HEAP32[$132>>2] = $123;
     $j$0$i21 = $j$1$i19 << 1;
     $133 = HEAP32[$6>>2]|0;
     $134 = ($j$0$i21|0)>($133|0);
     if ($134) {
      $$0$lcssa$i22 = $j$1$i19;
      break;
     } else {
      $$02$i18 = $j$1$i19;$104 = $133;$j$03$i17 = $j$0$i21;
     }
    }
   }
  } while(0);
  $135 = ((($s) + ($$0$lcssa$i22<<2)|0) + 2908|0);
  HEAP32[$135>>2] = $99;
  $136 = HEAP32[$53>>2]|0;
  $137 = HEAP32[$7>>2]|0;
  $138 = (($137) + -1)|0;
  HEAP32[$7>>2] = $138;
  $139 = ((($s) + ($138<<2)|0) + 2908|0);
  HEAP32[$139>>2] = $95;
  $140 = HEAP32[$7>>2]|0;
  $141 = (($140) + -1)|0;
  HEAP32[$7>>2] = $141;
  $142 = ((($s) + ($141<<2)|0) + 2908|0);
  HEAP32[$142>>2] = $136;
  $143 = (($0) + ($95<<2)|0);
  $144 = HEAP16[$143>>1]|0;
  $145 = $144&65535;
  $146 = (($0) + ($136<<2)|0);
  $147 = HEAP16[$146>>1]|0;
  $148 = $147&65535;
  $149 = (($148) + ($145))|0;
  $150 = $149&65535;
  $151 = (($0) + ($node$0<<2)|0);
  HEAP16[$151>>1] = $150;
  $152 = ((($s) + ($95)|0) + 5208|0);
  $153 = HEAP8[$152>>0]|0;
  $154 = ((($s) + ($136)|0) + 5208|0);
  $155 = HEAP8[$154>>0]|0;
  $156 = ($153&255)<($155&255);
  $$1 = $156 ? $155 : $153;
  $157 = $$1&255;
  $158 = (($157) + 1)|0;
  $159 = $158&255;
  $160 = ((($s) + ($node$0)|0) + 5208|0);
  HEAP8[$160>>0] = $159;
  $161 = $node$0&65535;
  $162 = ((($0) + ($136<<2)|0) + 2|0);
  HEAP16[$162>>1] = $161;
  $163 = ((($0) + ($95<<2)|0) + 2|0);
  HEAP16[$163>>1] = $161;
  $164 = (($node$0) + 1)|0;
  HEAP32[$53>>2] = $node$0;
  $165 = HEAP32[$6>>2]|0;
  $166 = ($165|0)<(2);
  L56: do {
   if ($166) {
    $$0$lcssa$i14 = 1;
   } else {
    $$02$i10 = 1;$168 = $165;$j$03$i9 = 2;
    while(1) {
     $167 = ($j$03$i9|0)<($168|0);
     do {
      if ($167) {
       $169 = $j$03$i9 | 1;
       $170 = ((($s) + ($169<<2)|0) + 2908|0);
       $171 = HEAP32[$170>>2]|0;
       $172 = (($0) + ($171<<2)|0);
       $173 = HEAP16[$172>>1]|0;
       $174 = ((($s) + ($j$03$i9<<2)|0) + 2908|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = (($0) + ($175<<2)|0);
       $177 = HEAP16[$176>>1]|0;
       $178 = ($173&65535)<($177&65535);
       if (!($178)) {
        $179 = ($173<<16>>16)==($177<<16>>16);
        if (!($179)) {
         $j$1$i11 = $j$03$i9;
         break;
        }
        $180 = ((($s) + ($171)|0) + 5208|0);
        $181 = HEAP8[$180>>0]|0;
        $182 = ((($s) + ($175)|0) + 5208|0);
        $183 = HEAP8[$182>>0]|0;
        $184 = ($181&255)>($183&255);
        if ($184) {
         $j$1$i11 = $j$03$i9;
         break;
        }
       }
       $j$1$i11 = $169;
      } else {
       $j$1$i11 = $j$03$i9;
      }
     } while(0);
     $185 = HEAP16[$151>>1]|0;
     $186 = ((($s) + ($j$1$i11<<2)|0) + 2908|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = (($0) + ($187<<2)|0);
     $189 = HEAP16[$188>>1]|0;
     $190 = ($185&65535)<($189&65535);
     if ($190) {
      $$0$lcssa$i14 = $$02$i10;
      break L56;
     }
     $191 = ($185<<16>>16)==($189<<16>>16);
     if ($191) {
      $192 = HEAP8[$160>>0]|0;
      $193 = ((($s) + ($187)|0) + 5208|0);
      $194 = HEAP8[$193>>0]|0;
      $195 = ($192&255)>($194&255);
      if (!($195)) {
       $$0$lcssa$i14 = $$02$i10;
       break L56;
      }
     }
     $196 = ((($s) + ($$02$i10<<2)|0) + 2908|0);
     HEAP32[$196>>2] = $187;
     $j$0$i13 = $j$1$i11 << 1;
     $197 = HEAP32[$6>>2]|0;
     $198 = ($j$0$i13|0)>($197|0);
     if ($198) {
      $$0$lcssa$i14 = $j$1$i11;
      break;
     } else {
      $$02$i10 = $j$1$i11;$168 = $197;$j$03$i9 = $j$0$i13;
     }
    }
   }
  } while(0);
  $199 = ((($s) + ($$0$lcssa$i14<<2)|0) + 2908|0);
  HEAP32[$199>>2] = $node$0;
  $200 = HEAP32[$6>>2]|0;
  $201 = ($200|0)>(1);
  if ($201) {
   $97 = $200;$node$0 = $164;
  } else {
   break;
  }
 }
 $202 = HEAP32[$53>>2]|0;
 $203 = HEAP32[$7>>2]|0;
 $204 = (($203) + -1)|0;
 HEAP32[$7>>2] = $204;
 $205 = ((($s) + ($204<<2)|0) + 2908|0);
 HEAP32[$205>>2] = $202;
 $desc$idx$val = HEAP32[$desc>>2]|0;
 $desc$idx2$val = HEAP32[$49>>2]|0;
 $desc$idx3$val = HEAP32[$1>>2]|0;
 $206 = HEAP32[$desc$idx3$val>>2]|0;
 $207 = (($desc$idx3$val) + 4|0);
 $208 = HEAP32[$207>>2]|0;
 $209 = (($desc$idx3$val) + 8|0);
 $210 = HEAP32[$209>>2]|0;
 $211 = (($desc$idx3$val) + 16|0);
 $212 = HEAP32[$211>>2]|0;
 $scevgep$i = (($s) + 2876|0);
 dest=$scevgep$i+0|0; stop=dest+32|0; do { HEAP16[dest>>1]=0|0; dest=dest+2|0; } while ((dest|0) < (stop|0));
 $213 = HEAP32[$7>>2]|0;
 $214 = ((($s) + ($213<<2)|0) + 2908|0);
 $215 = HEAP32[$214>>2]|0;
 $216 = ((($desc$idx$val) + ($215<<2)|0) + 2|0);
 HEAP16[$216>>1] = 0;
 $h$09$i = (($213) + 1)|0;
 $217 = ($h$09$i|0)<(573);
 L72: do {
  if ($217) {
   $218 = (($s) + 5800|0);
   $219 = ($206|0)==(0|0);
   $220 = (($s) + 5804|0);
   if ($219) {
    $h$011$us$i = $h$09$i;$overflow$010$us$i = 0;
    while(1) {
     $221 = ((($s) + ($h$011$us$i<<2)|0) + 2908|0);
     $222 = HEAP32[$221>>2]|0;
     $223 = ((($desc$idx$val) + ($222<<2)|0) + 2|0);
     $224 = HEAP16[$223>>1]|0;
     $225 = $224&65535;
     $226 = ((($desc$idx$val) + ($225<<2)|0) + 2|0);
     $227 = HEAP16[$226>>1]|0;
     $228 = $227&65535;
     $229 = (($228) + 1)|0;
     $230 = ($228|0)<($212|0);
     $$$us$i = $230 ? $229 : $212;
     $231 = $230&1;
     $232 = $231 ^ 1;
     $overflow$0$$us$i = (($232) + ($overflow$010$us$i))|0;
     $233 = $$$us$i&65535;
     HEAP16[$223>>1] = $233;
     $234 = ($222|0)>($desc$idx2$val|0);
     if (!($234)) {
      $235 = ((($s) + ($$$us$i<<1)|0) + 2876|0);
      $236 = HEAP16[$235>>1]|0;
      $237 = (($236) + 1)<<16>>16;
      HEAP16[$235>>1] = $237;
      $238 = ($222|0)<($210|0);
      if ($238) {
       $xbits$0$us$i = 0;
      } else {
       $239 = (($222) - ($210))|0;
       $240 = (($208) + ($239<<2)|0);
       $241 = HEAP32[$240>>2]|0;
       $xbits$0$us$i = $241;
      }
      $242 = (($desc$idx$val) + ($222<<2)|0);
      $243 = HEAP16[$242>>1]|0;
      $244 = $243&65535;
      $245 = (($xbits$0$us$i) + ($$$us$i))|0;
      $246 = Math_imul($244, $245)|0;
      $247 = HEAP32[$218>>2]|0;
      $248 = (($246) + ($247))|0;
      HEAP32[$218>>2] = $248;
     }
     $h$0$us$i = (($h$011$us$i) + 1)|0;
     $exitcond23$i = ($h$0$us$i|0)==(573);
     if ($exitcond23$i) {
      $overflow$0$lcssa$i = $overflow$0$$us$i;
      break;
     } else {
      $h$011$us$i = $h$0$us$i;$overflow$010$us$i = $overflow$0$$us$i;
     }
    }
   } else {
    $h$011$i = $h$09$i;$overflow$010$i = 0;
    while(1) {
     $249 = ((($s) + ($h$011$i<<2)|0) + 2908|0);
     $250 = HEAP32[$249>>2]|0;
     $251 = ((($desc$idx$val) + ($250<<2)|0) + 2|0);
     $252 = HEAP16[$251>>1]|0;
     $253 = $252&65535;
     $254 = ((($desc$idx$val) + ($253<<2)|0) + 2|0);
     $255 = HEAP16[$254>>1]|0;
     $256 = $255&65535;
     $257 = (($256) + 1)|0;
     $258 = ($256|0)<($212|0);
     $$$i = $258 ? $257 : $212;
     $259 = $258&1;
     $260 = $259 ^ 1;
     $overflow$0$$i = (($260) + ($overflow$010$i))|0;
     $261 = $$$i&65535;
     HEAP16[$251>>1] = $261;
     $262 = ($250|0)>($desc$idx2$val|0);
     if (!($262)) {
      $263 = ((($s) + ($$$i<<1)|0) + 2876|0);
      $264 = HEAP16[$263>>1]|0;
      $265 = (($264) + 1)<<16>>16;
      HEAP16[$263>>1] = $265;
      $266 = ($250|0)<($210|0);
      if ($266) {
       $xbits$0$i = 0;
      } else {
       $267 = (($250) - ($210))|0;
       $268 = (($208) + ($267<<2)|0);
       $269 = HEAP32[$268>>2]|0;
       $xbits$0$i = $269;
      }
      $270 = (($desc$idx$val) + ($250<<2)|0);
      $271 = HEAP16[$270>>1]|0;
      $272 = $271&65535;
      $273 = (($xbits$0$i) + ($$$i))|0;
      $274 = Math_imul($272, $273)|0;
      $275 = HEAP32[$218>>2]|0;
      $276 = (($274) + ($275))|0;
      HEAP32[$218>>2] = $276;
      $277 = ((($206) + ($250<<2)|0) + 2|0);
      $278 = HEAP16[$277>>1]|0;
      $279 = $278&65535;
      $280 = (($279) + ($xbits$0$i))|0;
      $281 = Math_imul($280, $272)|0;
      $282 = HEAP32[$220>>2]|0;
      $283 = (($281) + ($282))|0;
      HEAP32[$220>>2] = $283;
     }
     $h$0$i = (($h$011$i) + 1)|0;
     $exitcond$i5 = ($h$0$i|0)==(573);
     if ($exitcond$i5) {
      $overflow$0$lcssa$i = $overflow$0$$i;
      break;
     } else {
      $h$011$i = $h$0$i;$overflow$010$i = $overflow$0$$i;
     }
    }
   }
   $284 = ($overflow$0$lcssa$i|0)==(0);
   if (!($284)) {
    $285 = ((($s) + ($212<<1)|0) + 2876|0);
    $overflow$2$i = $overflow$0$lcssa$i;
    while(1) {
     $bits$2$in$i = $212;
     while(1) {
      $bits$2$i = (($bits$2$in$i) + -1)|0;
      $286 = ((($s) + ($bits$2$i<<1)|0) + 2876|0);
      $287 = HEAP16[$286>>1]|0;
      $288 = ($287<<16>>16)==(0);
      if ($288) {
       $bits$2$in$i = $bits$2$i;
      } else {
       break;
      }
     }
     $289 = (($287) + -1)<<16>>16;
     HEAP16[$286>>1] = $289;
     $290 = ((($s) + ($bits$2$in$i<<1)|0) + 2876|0);
     $291 = HEAP16[$290>>1]|0;
     $292 = $291&65535;
     $293 = (($292) + 2)|0;
     $294 = $293&65535;
     HEAP16[$290>>1] = $294;
     $295 = HEAP16[$285>>1]|0;
     $296 = (($295) + -1)<<16>>16;
     HEAP16[$285>>1] = $296;
     $297 = (($overflow$2$i) + -2)|0;
     $298 = ($297|0)>(0);
     if ($298) {
      $overflow$2$i = $297;
     } else {
      break;
     }
    }
    $299 = ($212|0)==(0);
    if (!($299)) {
     $302 = $296;$bits$34$i = $212;$h$15$i = 573;
     while(1) {
      $300 = $bits$34$i&65535;
      $301 = ($302<<16>>16)==(0);
      if ($301) {
       $h$2$ph$i$lcssa = $h$15$i;
      } else {
       $303 = $302&65535;
       $h$2$ph$i27 = $h$15$i;$n$0$ph$i26 = $303;
       while(1) {
        $h$2$i = $h$2$ph$i27;
        while(1) {
         $304 = (($h$2$i) + -1)|0;
         $305 = ((($s) + ($304<<2)|0) + 2908|0);
         $306 = HEAP32[$305>>2]|0;
         $307 = ($306|0)>($desc$idx2$val|0);
         if ($307) {
          $h$2$i = $304;
         } else {
          break;
         }
        }
        $308 = ((($desc$idx$val) + ($306<<2)|0) + 2|0);
        $309 = HEAP16[$308>>1]|0;
        $310 = $309&65535;
        $311 = ($310|0)==($bits$34$i|0);
        if (!($311)) {
         $312 = (($bits$34$i) - ($310))|0;
         $313 = (($desc$idx$val) + ($306<<2)|0);
         $314 = HEAP16[$313>>1]|0;
         $315 = $314&65535;
         $316 = Math_imul($315, $312)|0;
         $317 = HEAP32[$218>>2]|0;
         $318 = (($316) + ($317))|0;
         HEAP32[$218>>2] = $318;
         HEAP16[$308>>1] = $300;
        }
        $319 = (($n$0$ph$i26) + -1)|0;
        $320 = ($319|0)==(0);
        if ($320) {
         $h$2$ph$i$lcssa = $304;
         break;
        } else {
         $h$2$ph$i27 = $304;$n$0$ph$i26 = $319;
        }
       }
      }
      $321 = (($bits$34$i) + -1)|0;
      $322 = ($321|0)==(0);
      if ($322) {
       break L72;
      }
      $$phi$trans$insert$i = ((($s) + ($321<<1)|0) + 2876|0);
      $$pre$i = HEAP16[$$phi$trans$insert$i>>1]|0;
      $302 = $$pre$i;$bits$34$i = $321;$h$15$i = $h$2$ph$i$lcssa;
     }
    }
   }
  }
 } while(0);
 $bits$03$i = 1;$code$04$i = 0;
 while(1) {
  $324 = $code$04$i & 65534;
  $325 = (($bits$03$i) + -1)|0;
  $326 = ((($s) + ($325<<1)|0) + 2876|0);
  $327 = HEAP16[$326>>1]|0;
  $328 = $327&65535;
  $329 = (($328) + ($324))|0;
  $330 = $329 << 1;
  $331 = $330&65535;
  $332 = (($next_code$i) + ($bits$03$i<<1)|0);
  HEAP16[$332>>1] = $331;
  $333 = (($bits$03$i) + 1)|0;
  $exitcond5$i = ($333|0)==(16);
  if ($exitcond5$i) {
   break;
  } else {
   $bits$03$i = $333;$code$04$i = $330;
  }
 }
 $323 = ($max_code$2$lcssa|0)<(0);
 if ($323) {
  STACKTOP = sp;return;
 } else {
  $n$01$i = 0;
 }
 while(1) {
  $334 = ((($0) + ($n$01$i<<2)|0) + 2|0);
  $335 = HEAP16[$334>>1]|0;
  $336 = $335&65535;
  $337 = ($335<<16>>16)==(0);
  if (!($337)) {
   $338 = (($next_code$i) + ($336<<1)|0);
   $339 = HEAP16[$338>>1]|0;
   $340 = (($339) + 1)<<16>>16;
   HEAP16[$338>>1] = $340;
   $341 = $339&65535;
   $$0$i$i = $336;$$01$i$i = $341;$res$0$i$i = 0;
   while(1) {
    $342 = $$01$i$i & 1;
    $343 = $res$0$i$i | $342;
    $344 = $$01$i$i >>> 1;
    $345 = $343 << 1;
    $346 = (($$0$i$i) + -1)|0;
    $347 = ($346|0)>(0);
    if ($347) {
     $$0$i$i = $346;$$01$i$i = $344;$res$0$i$i = $345;
    } else {
     break;
    }
   }
   $348 = $343&65535;
   $349 = (($0) + ($n$01$i<<2)|0);
   HEAP16[$349>>1] = $348;
  }
  $350 = (($n$01$i) + 1)|0;
  $exitcond$i = ($n$01$i|0)==($max_code$2$lcssa|0);
  if ($exitcond$i) {
   break;
  } else {
   $n$01$i = $350;
  }
 }
 STACKTOP = sp;return;
}
function _compress_block($s,$ltree,$dtree) {
 $s = $s|0;
 $ltree = $ltree|0;
 $dtree = $dtree|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert5 = 0, $$pn = 0, $$pre = 0, $$pre6 = 0, $$sink = 0, $$sink$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lx$0 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 5792|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$phi$trans$insert = (($s) + 5820|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$phi$trans$insert5 = (($s) + 5816|0);
  $$pre6 = HEAP16[$$phi$trans$insert5>>1]|0;
  $206 = $$pre;$213 = $$pre6;
 } else {
  $3 = (($s) + 5796|0);
  $4 = (($s) + 5784|0);
  $5 = (($s) + 5820|0);
  $6 = (($s) + 5816|0);
  $7 = (($s) + 20|0);
  $8 = (($s) + 8|0);
  $lx$0 = 0;
  while(1) {
   $9 = HEAP32[$3>>2]|0;
   $10 = (($9) + ($lx$0<<1)|0);
   $11 = HEAP16[$10>>1]|0;
   $12 = $11&65535;
   $13 = (($lx$0) + 1)|0;
   $14 = HEAP32[$4>>2]|0;
   $15 = (($14) + ($lx$0)|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = $16&255;
   $18 = ($11<<16>>16)==(0);
   do {
    if ($18) {
     $19 = ((($ltree) + ($17<<2)|0) + 2|0);
     $20 = HEAP16[$19>>1]|0;
     $21 = $20&65535;
     $22 = HEAP32[$5>>2]|0;
     $23 = (16 - ($21))|0;
     $24 = ($22|0)>($23|0);
     $25 = (($ltree) + ($17<<2)|0);
     $26 = HEAP16[$25>>1]|0;
     $27 = $26&65535;
     $28 = $27 << $22;
     $29 = HEAP16[$6>>1]|0;
     $30 = $29&65535;
     $31 = $30 | $28;
     $32 = $31&65535;
     HEAP16[$6>>1] = $32;
     if ($24) {
      $33 = $31&255;
      $34 = HEAP32[$7>>2]|0;
      $35 = (($34) + 1)|0;
      HEAP32[$7>>2] = $35;
      $36 = HEAP32[$8>>2]|0;
      $37 = (($36) + ($34)|0);
      HEAP8[$37>>0] = $33;
      $38 = HEAP16[$6>>1]|0;
      $39 = ($38&65535) >>> 8;
      $40 = $39&255;
      $41 = HEAP32[$7>>2]|0;
      $42 = (($41) + 1)|0;
      HEAP32[$7>>2] = $42;
      $43 = HEAP32[$8>>2]|0;
      $44 = (($43) + ($41)|0);
      HEAP8[$44>>0] = $40;
      $45 = HEAP32[$5>>2]|0;
      $46 = (16 - ($45))|0;
      $47 = $27 >>> $46;
      $48 = $47&65535;
      HEAP16[$6>>1] = $48;
      $49 = (($21) + -16)|0;
      $50 = (($49) + ($45))|0;
      HEAP32[$5>>2] = $50;
      $240 = $48;$241 = $50;
      break;
     } else {
      $51 = (($22) + ($21))|0;
      HEAP32[$5>>2] = $51;
      $240 = $32;$241 = $51;
      break;
     }
    } else {
     $52 = (400920 + ($17)|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = $53&255;
     $55 = $54 | 256;
     $56 = (($55) + 1)|0;
     $57 = ((($ltree) + ($56<<2)|0) + 2|0);
     $58 = HEAP16[$57>>1]|0;
     $59 = $58&65535;
     $60 = HEAP32[$5>>2]|0;
     $61 = (16 - ($59))|0;
     $62 = ($60|0)>($61|0);
     $63 = (($ltree) + ($56<<2)|0);
     $64 = HEAP16[$63>>1]|0;
     $65 = $64&65535;
     $66 = $65 << $60;
     $67 = HEAP16[$6>>1]|0;
     $68 = $67&65535;
     $69 = $68 | $66;
     $70 = $69&65535;
     HEAP16[$6>>1] = $70;
     if ($62) {
      $71 = $69&255;
      $72 = HEAP32[$7>>2]|0;
      $73 = (($72) + 1)|0;
      HEAP32[$7>>2] = $73;
      $74 = HEAP32[$8>>2]|0;
      $75 = (($74) + ($72)|0);
      HEAP8[$75>>0] = $71;
      $76 = HEAP16[$6>>1]|0;
      $77 = ($76&65535) >>> 8;
      $78 = $77&255;
      $79 = HEAP32[$7>>2]|0;
      $80 = (($79) + 1)|0;
      HEAP32[$7>>2] = $80;
      $81 = HEAP32[$8>>2]|0;
      $82 = (($81) + ($79)|0);
      HEAP8[$82>>0] = $78;
      $83 = HEAP32[$5>>2]|0;
      $84 = (16 - ($83))|0;
      $85 = $65 >>> $84;
      $86 = $85&65535;
      HEAP16[$6>>1] = $86;
      $87 = (($59) + -16)|0;
      $88 = (($87) + ($83))|0;
      $102 = $86;$90 = $88;
     } else {
      $89 = (($60) + ($59))|0;
      $102 = $70;$90 = $89;
     }
     HEAP32[$5>>2] = $90;
     $91 = (402520 + ($54<<2)|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = (($54) + -8)|0;
     $94 = ($93>>>0)<(20);
     do {
      if ($94) {
       $95 = (402640 + ($54<<2)|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = (($17) - ($96))|0;
       $98 = (16 - ($92))|0;
       $99 = ($90|0)>($98|0);
       $100 = $97 << $90;
       $101 = $102&65535;
       $103 = $101 | $100;
       $104 = $103&65535;
       HEAP16[$6>>1] = $104;
       if ($99) {
        $105 = $103&255;
        $106 = HEAP32[$7>>2]|0;
        $107 = (($106) + 1)|0;
        HEAP32[$7>>2] = $107;
        $108 = HEAP32[$8>>2]|0;
        $109 = (($108) + ($106)|0);
        HEAP8[$109>>0] = $105;
        $110 = HEAP16[$6>>1]|0;
        $111 = ($110&65535) >>> 8;
        $112 = $111&255;
        $113 = HEAP32[$7>>2]|0;
        $114 = (($113) + 1)|0;
        HEAP32[$7>>2] = $114;
        $115 = HEAP32[$8>>2]|0;
        $116 = (($115) + ($113)|0);
        HEAP8[$116>>0] = $112;
        $117 = $97 & 65535;
        $118 = HEAP32[$5>>2]|0;
        $119 = (16 - ($118))|0;
        $120 = $117 >>> $119;
        $121 = $120&65535;
        HEAP16[$6>>1] = $121;
        $122 = (($92) + -16)|0;
        $123 = (($122) + ($118))|0;
        HEAP32[$5>>2] = $123;
        $135 = $123;$141 = $121;
        break;
       } else {
        $124 = (($90) + ($92))|0;
        HEAP32[$5>>2] = $124;
        $135 = $124;$141 = $104;
        break;
       }
      } else {
       $135 = $90;$141 = $102;
      }
     } while(0);
     $125 = (($12) + -1)|0;
     $126 = ($125>>>0)<(256);
     if ($126) {
      $$pn = $125;
     } else {
      $127 = $125 >>> 7;
      $128 = (($127) + 256)|0;
      $$pn = $128;
     }
     $$sink$in = (400408 + ($$pn)|0);
     $$sink = HEAP8[$$sink$in>>0]|0;
     $129 = $$sink&255;
     $130 = ((($dtree) + ($129<<2)|0) + 2|0);
     $131 = HEAP16[$130>>1]|0;
     $132 = $131&65535;
     $133 = (16 - ($132))|0;
     $134 = ($135|0)>($133|0);
     $136 = (($dtree) + ($129<<2)|0);
     $137 = HEAP16[$136>>1]|0;
     $138 = $137&65535;
     $139 = $138 << $135;
     $140 = $141&65535;
     $142 = $140 | $139;
     $143 = $142&65535;
     HEAP16[$6>>1] = $143;
     if ($134) {
      $144 = $142&255;
      $145 = HEAP32[$7>>2]|0;
      $146 = (($145) + 1)|0;
      HEAP32[$7>>2] = $146;
      $147 = HEAP32[$8>>2]|0;
      $148 = (($147) + ($145)|0);
      HEAP8[$148>>0] = $144;
      $149 = HEAP16[$6>>1]|0;
      $150 = ($149&65535) >>> 8;
      $151 = $150&255;
      $152 = HEAP32[$7>>2]|0;
      $153 = (($152) + 1)|0;
      HEAP32[$7>>2] = $153;
      $154 = HEAP32[$8>>2]|0;
      $155 = (($154) + ($152)|0);
      HEAP8[$155>>0] = $151;
      $156 = HEAP32[$5>>2]|0;
      $157 = (16 - ($156))|0;
      $158 = $138 >>> $157;
      $159 = $158&65535;
      HEAP16[$6>>1] = $159;
      $160 = (($132) + -16)|0;
      $161 = (($160) + ($156))|0;
      $163 = $161;$175 = $159;
     } else {
      $162 = (($135) + ($132))|0;
      $163 = $162;$175 = $143;
     }
     HEAP32[$5>>2] = $163;
     $164 = (402760 + ($129<<2)|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = (($129) + -4)|0;
     $167 = ($166>>>0)<(26);
     if ($167) {
      $168 = (402880 + ($129<<2)|0);
      $169 = HEAP32[$168>>2]|0;
      $170 = (($125) - ($169))|0;
      $171 = (16 - ($165))|0;
      $172 = ($163|0)>($171|0);
      $173 = $170 << $163;
      $174 = $175&65535;
      $176 = $174 | $173;
      $177 = $176&65535;
      HEAP16[$6>>1] = $177;
      if ($172) {
       $178 = $176&255;
       $179 = HEAP32[$7>>2]|0;
       $180 = (($179) + 1)|0;
       HEAP32[$7>>2] = $180;
       $181 = HEAP32[$8>>2]|0;
       $182 = (($181) + ($179)|0);
       HEAP8[$182>>0] = $178;
       $183 = HEAP16[$6>>1]|0;
       $184 = ($183&65535) >>> 8;
       $185 = $184&255;
       $186 = HEAP32[$7>>2]|0;
       $187 = (($186) + 1)|0;
       HEAP32[$7>>2] = $187;
       $188 = HEAP32[$8>>2]|0;
       $189 = (($188) + ($186)|0);
       HEAP8[$189>>0] = $185;
       $190 = $170 & 65535;
       $191 = HEAP32[$5>>2]|0;
       $192 = (16 - ($191))|0;
       $193 = $190 >>> $192;
       $194 = $193&65535;
       HEAP16[$6>>1] = $194;
       $195 = (($165) + -16)|0;
       $196 = (($195) + ($191))|0;
       HEAP32[$5>>2] = $196;
       $240 = $194;$241 = $196;
       break;
      } else {
       $197 = (($163) + ($165))|0;
       HEAP32[$5>>2] = $197;
       $240 = $177;$241 = $197;
       break;
      }
     } else {
      $240 = $175;$241 = $163;
     }
    }
   } while(0);
   $198 = HEAP32[$0>>2]|0;
   $199 = ($13>>>0)<($198>>>0);
   if ($199) {
    $lx$0 = $13;
   } else {
    $206 = $241;$213 = $240;
    break;
   }
  }
 }
 $200 = (($ltree) + 1026|0);
 $201 = HEAP16[$200>>1]|0;
 $202 = $201&65535;
 $203 = (($s) + 5820|0);
 $204 = (16 - ($202))|0;
 $205 = ($206|0)>($204|0);
 $207 = (($ltree) + 1024|0);
 $208 = HEAP16[$207>>1]|0;
 $209 = $208&65535;
 $210 = $209 << $206;
 $211 = (($s) + 5816|0);
 $212 = $213&65535;
 $214 = $212 | $210;
 $215 = $214&65535;
 HEAP16[$211>>1] = $215;
 if ($205) {
  $216 = $214&255;
  $217 = (($s) + 20|0);
  $218 = HEAP32[$217>>2]|0;
  $219 = (($218) + 1)|0;
  HEAP32[$217>>2] = $219;
  $220 = (($s) + 8|0);
  $221 = HEAP32[$220>>2]|0;
  $222 = (($221) + ($218)|0);
  HEAP8[$222>>0] = $216;
  $223 = HEAP16[$211>>1]|0;
  $224 = ($223&65535) >>> 8;
  $225 = $224&255;
  $226 = HEAP32[$217>>2]|0;
  $227 = (($226) + 1)|0;
  HEAP32[$217>>2] = $227;
  $228 = HEAP32[$220>>2]|0;
  $229 = (($228) + ($226)|0);
  HEAP8[$229>>0] = $225;
  $230 = HEAP32[$203>>2]|0;
  $231 = (16 - ($230))|0;
  $232 = $209 >>> $231;
  $233 = $232&65535;
  HEAP16[$211>>1] = $233;
  $234 = (($202) + -16)|0;
  $235 = (($234) + ($230))|0;
  $storemerge = $235;
  HEAP32[$203>>2] = $storemerge;
  $237 = HEAP16[$200>>1]|0;
  $238 = $237&65535;
  $239 = (($s) + 5812|0);
  HEAP32[$239>>2] = $238;
  STACKTOP = sp;return;
 } else {
  $236 = (($206) + ($202))|0;
  $storemerge = $236;
  HEAP32[$203>>2] = $storemerge;
  $237 = HEAP16[$200>>1]|0;
  $238 = $237&65535;
  $239 = (($s) + 5812|0);
  HEAP32[$239>>2] = $238;
  STACKTOP = sp;return;
 }
}
function _send_tree($s,$tree,$max_code) {
 $s = $s|0;
 $tree = $tree|0;
 $max_code = $max_code|0;
 var $$ = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$pre = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$0 = 0;
 var $count$1 = 0, $count$2 = 0, $max_count$1$ph = 0, $min_count$1$ph = 0, $n$0 = 0, $n$0$ph = 0, $nextlen$0$ph = 0, $or$cond = 0, $prevlen$0$ph = 0, $prevlen$0$ph$phi = 0, $storemerge3 = 0, $storemerge4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($tree) + 2|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ($1<<16>>16)==(0);
 $$ = $3 ? 3 : 4;
 $$5 = $3 ? 138 : 7;
 $4 = (($s) + 2754|0);
 $5 = (($s) + 5820|0);
 $6 = (($s) + 2752|0);
 $7 = (($s) + 5816|0);
 $8 = (($s) + 20|0);
 $9 = (($s) + 8|0);
 $10 = (($s) + 2758|0);
 $11 = (($s) + 2756|0);
 $12 = (($s) + 2750|0);
 $13 = (($s) + 2748|0);
 $max_count$1$ph = $$5;$min_count$1$ph = $$;$n$0$ph = 0;$nextlen$0$ph = $2;$prevlen$0$ph = -1;
 L1: while(1) {
  $count$0 = 0;$n$0 = $n$0$ph;
  while(1) {
   $14 = ($n$0|0)>($max_code|0);
   if ($14) {
    break L1;
   }
   $15 = (($n$0) + 1)|0;
   $16 = ((($tree) + ($15<<2)|0) + 2|0);
   $17 = HEAP16[$16>>1]|0;
   $18 = $17&65535;
   $19 = (($count$0) + 1)|0;
   $20 = ($19|0)<($max_count$1$ph|0);
   $21 = ($nextlen$0$ph|0)==($18|0);
   $or$cond = $20 & $21;
   if ($or$cond) {
    $count$0 = $19;$n$0 = $15;
   } else {
    break;
   }
  }
  $22 = ($19|0)<($min_count$1$ph|0);
  do {
   if ($22) {
    $23 = ((($s) + ($nextlen$0$ph<<2)|0) + 2686|0);
    $24 = ((($s) + ($nextlen$0$ph<<2)|0) + 2684|0);
    $$pre = HEAP32[$5>>2]|0;
    $$pre20 = HEAP16[$7>>1]|0;
    $29 = $$pre;$34 = $$pre20;$count$1 = $19;
    while(1) {
     $25 = HEAP16[$23>>1]|0;
     $26 = $25&65535;
     $27 = (16 - ($26))|0;
     $28 = ($29|0)>($27|0);
     $30 = HEAP16[$24>>1]|0;
     $31 = $30&65535;
     $32 = $31 << $29;
     $33 = $34&65535;
     $35 = $33 | $32;
     $36 = $35&65535;
     HEAP16[$7>>1] = $36;
     if ($28) {
      $37 = $35&255;
      $38 = HEAP32[$8>>2]|0;
      $39 = (($38) + 1)|0;
      HEAP32[$8>>2] = $39;
      $40 = HEAP32[$9>>2]|0;
      $41 = (($40) + ($38)|0);
      HEAP8[$41>>0] = $37;
      $42 = HEAP16[$7>>1]|0;
      $43 = ($42&65535) >>> 8;
      $44 = $43&255;
      $45 = HEAP32[$8>>2]|0;
      $46 = (($45) + 1)|0;
      HEAP32[$8>>2] = $46;
      $47 = HEAP32[$9>>2]|0;
      $48 = (($47) + ($45)|0);
      HEAP8[$48>>0] = $44;
      $49 = HEAP32[$5>>2]|0;
      $50 = (16 - ($49))|0;
      $51 = $31 >>> $50;
      $52 = $51&65535;
      HEAP16[$7>>1] = $52;
      $53 = (($26) + -16)|0;
      $54 = (($53) + ($49))|0;
      $269 = $52;$storemerge4 = $54;
     } else {
      $55 = (($29) + ($26))|0;
      $269 = $36;$storemerge4 = $55;
     }
     HEAP32[$5>>2] = $storemerge4;
     $56 = (($count$1) + -1)|0;
     $57 = ($56|0)==(0);
     if ($57) {
      break;
     } else {
      $29 = $storemerge4;$34 = $269;$count$1 = $56;
     }
    }
   } else {
    $58 = ($nextlen$0$ph|0)==(0);
    if (!($58)) {
     $59 = ($nextlen$0$ph|0)==($prevlen$0$ph|0);
     if ($59) {
      $$pre21 = HEAP32[$5>>2]|0;
      $$pre22 = HEAP16[$7>>1]|0;
      $102 = $$pre22;$97 = $$pre21;$count$2 = $19;
     } else {
      $60 = ((($s) + ($nextlen$0$ph<<2)|0) + 2686|0);
      $61 = HEAP16[$60>>1]|0;
      $62 = $61&65535;
      $63 = HEAP32[$5>>2]|0;
      $64 = (16 - ($62))|0;
      $65 = ($63|0)>($64|0);
      $66 = ((($s) + ($nextlen$0$ph<<2)|0) + 2684|0);
      $67 = HEAP16[$66>>1]|0;
      $68 = $67&65535;
      $69 = $68 << $63;
      $70 = HEAP16[$7>>1]|0;
      $71 = $70&65535;
      $72 = $71 | $69;
      $73 = $72&65535;
      HEAP16[$7>>1] = $73;
      if ($65) {
       $74 = $72&255;
       $75 = HEAP32[$8>>2]|0;
       $76 = (($75) + 1)|0;
       HEAP32[$8>>2] = $76;
       $77 = HEAP32[$9>>2]|0;
       $78 = (($77) + ($75)|0);
       HEAP8[$78>>0] = $74;
       $79 = HEAP16[$7>>1]|0;
       $80 = ($79&65535) >>> 8;
       $81 = $80&255;
       $82 = HEAP32[$8>>2]|0;
       $83 = (($82) + 1)|0;
       HEAP32[$8>>2] = $83;
       $84 = HEAP32[$9>>2]|0;
       $85 = (($84) + ($82)|0);
       HEAP8[$85>>0] = $81;
       $86 = HEAP32[$5>>2]|0;
       $87 = (16 - ($86))|0;
       $88 = $68 >>> $87;
       $89 = $88&65535;
       HEAP16[$7>>1] = $89;
       $90 = (($62) + -16)|0;
       $91 = (($90) + ($86))|0;
       $270 = $89;$storemerge3 = $91;
      } else {
       $92 = (($63) + ($62))|0;
       $270 = $73;$storemerge3 = $92;
      }
      HEAP32[$5>>2] = $storemerge3;
      $102 = $270;$97 = $storemerge3;$count$2 = $count$0;
     }
     $93 = HEAP16[$12>>1]|0;
     $94 = $93&65535;
     $95 = (16 - ($94))|0;
     $96 = ($97|0)>($95|0);
     $98 = HEAP16[$13>>1]|0;
     $99 = $98&65535;
     $100 = $99 << $97;
     $101 = $102&65535;
     $103 = $101 | $100;
     $104 = $103&65535;
     HEAP16[$7>>1] = $104;
     if ($96) {
      $105 = $103&255;
      $106 = HEAP32[$8>>2]|0;
      $107 = (($106) + 1)|0;
      HEAP32[$8>>2] = $107;
      $108 = HEAP32[$9>>2]|0;
      $109 = (($108) + ($106)|0);
      HEAP8[$109>>0] = $105;
      $110 = HEAP16[$7>>1]|0;
      $111 = ($110&65535) >>> 8;
      $112 = $111&255;
      $113 = HEAP32[$8>>2]|0;
      $114 = (($113) + 1)|0;
      HEAP32[$8>>2] = $114;
      $115 = HEAP32[$9>>2]|0;
      $116 = (($115) + ($113)|0);
      HEAP8[$116>>0] = $112;
      $117 = HEAP32[$5>>2]|0;
      $118 = (16 - ($117))|0;
      $119 = $99 >>> $118;
      $120 = $119&65535;
      HEAP16[$7>>1] = $120;
      $121 = (($94) + -16)|0;
      $122 = (($121) + ($117))|0;
      $124 = $122;$129 = $119;
     } else {
      $123 = (($97) + ($94))|0;
      $124 = $123;$129 = $103;
     }
     HEAP32[$5>>2] = $124;
     $125 = ($124|0)>(14);
     $126 = (($count$2) + -3)|0;
     $127 = $126 << $124;
     $128 = $129 & 65535;
     $130 = $128 | $127;
     $131 = $130&65535;
     HEAP16[$7>>1] = $131;
     if ($125) {
      $132 = $130&255;
      $133 = HEAP32[$8>>2]|0;
      $134 = (($133) + 1)|0;
      HEAP32[$8>>2] = $134;
      $135 = HEAP32[$9>>2]|0;
      $136 = (($135) + ($133)|0);
      HEAP8[$136>>0] = $132;
      $137 = HEAP16[$7>>1]|0;
      $138 = ($137&65535) >>> 8;
      $139 = $138&255;
      $140 = HEAP32[$8>>2]|0;
      $141 = (($140) + 1)|0;
      HEAP32[$8>>2] = $141;
      $142 = HEAP32[$9>>2]|0;
      $143 = (($142) + ($140)|0);
      HEAP8[$143>>0] = $139;
      $144 = $126 & 65535;
      $145 = HEAP32[$5>>2]|0;
      $146 = (16 - ($145))|0;
      $147 = $144 >>> $146;
      $148 = $147&65535;
      HEAP16[$7>>1] = $148;
      $149 = (($145) + -14)|0;
      HEAP32[$5>>2] = $149;
      break;
     } else {
      $150 = (($124) + 2)|0;
      HEAP32[$5>>2] = $150;
      break;
     }
    }
    $151 = ($19|0)<(11);
    if ($151) {
     $152 = HEAP16[$4>>1]|0;
     $153 = $152&65535;
     $154 = HEAP32[$5>>2]|0;
     $155 = (16 - ($153))|0;
     $156 = ($154|0)>($155|0);
     $157 = HEAP16[$6>>1]|0;
     $158 = $157&65535;
     $159 = $158 << $154;
     $160 = HEAP16[$7>>1]|0;
     $161 = $160&65535;
     $162 = $161 | $159;
     $163 = $162&65535;
     HEAP16[$7>>1] = $163;
     if ($156) {
      $164 = $162&255;
      $165 = HEAP32[$8>>2]|0;
      $166 = (($165) + 1)|0;
      HEAP32[$8>>2] = $166;
      $167 = HEAP32[$9>>2]|0;
      $168 = (($167) + ($165)|0);
      HEAP8[$168>>0] = $164;
      $169 = HEAP16[$7>>1]|0;
      $170 = ($169&65535) >>> 8;
      $171 = $170&255;
      $172 = HEAP32[$8>>2]|0;
      $173 = (($172) + 1)|0;
      HEAP32[$8>>2] = $173;
      $174 = HEAP32[$9>>2]|0;
      $175 = (($174) + ($172)|0);
      HEAP8[$175>>0] = $171;
      $176 = HEAP32[$5>>2]|0;
      $177 = (16 - ($176))|0;
      $178 = $158 >>> $177;
      $179 = $178&65535;
      HEAP16[$7>>1] = $179;
      $180 = (($153) + -16)|0;
      $181 = (($180) + ($176))|0;
      $183 = $181;$188 = $178;
     } else {
      $182 = (($154) + ($153))|0;
      $183 = $182;$188 = $162;
     }
     HEAP32[$5>>2] = $183;
     $184 = ($183|0)>(13);
     $185 = (($count$0) + -2)|0;
     $186 = $185 << $183;
     $187 = $188 & 65535;
     $189 = $187 | $186;
     $190 = $189&65535;
     HEAP16[$7>>1] = $190;
     if ($184) {
      $191 = $189&255;
      $192 = HEAP32[$8>>2]|0;
      $193 = (($192) + 1)|0;
      HEAP32[$8>>2] = $193;
      $194 = HEAP32[$9>>2]|0;
      $195 = (($194) + ($192)|0);
      HEAP8[$195>>0] = $191;
      $196 = HEAP16[$7>>1]|0;
      $197 = ($196&65535) >>> 8;
      $198 = $197&255;
      $199 = HEAP32[$8>>2]|0;
      $200 = (($199) + 1)|0;
      HEAP32[$8>>2] = $200;
      $201 = HEAP32[$9>>2]|0;
      $202 = (($201) + ($199)|0);
      HEAP8[$202>>0] = $198;
      $203 = $185 & 65535;
      $204 = HEAP32[$5>>2]|0;
      $205 = (16 - ($204))|0;
      $206 = $203 >>> $205;
      $207 = $206&65535;
      HEAP16[$7>>1] = $207;
      $208 = (($204) + -13)|0;
      HEAP32[$5>>2] = $208;
      break;
     } else {
      $209 = (($183) + 3)|0;
      HEAP32[$5>>2] = $209;
      break;
     }
    } else {
     $210 = HEAP16[$10>>1]|0;
     $211 = $210&65535;
     $212 = HEAP32[$5>>2]|0;
     $213 = (16 - ($211))|0;
     $214 = ($212|0)>($213|0);
     $215 = HEAP16[$11>>1]|0;
     $216 = $215&65535;
     $217 = $216 << $212;
     $218 = HEAP16[$7>>1]|0;
     $219 = $218&65535;
     $220 = $219 | $217;
     $221 = $220&65535;
     HEAP16[$7>>1] = $221;
     if ($214) {
      $222 = $220&255;
      $223 = HEAP32[$8>>2]|0;
      $224 = (($223) + 1)|0;
      HEAP32[$8>>2] = $224;
      $225 = HEAP32[$9>>2]|0;
      $226 = (($225) + ($223)|0);
      HEAP8[$226>>0] = $222;
      $227 = HEAP16[$7>>1]|0;
      $228 = ($227&65535) >>> 8;
      $229 = $228&255;
      $230 = HEAP32[$8>>2]|0;
      $231 = (($230) + 1)|0;
      HEAP32[$8>>2] = $231;
      $232 = HEAP32[$9>>2]|0;
      $233 = (($232) + ($230)|0);
      HEAP8[$233>>0] = $229;
      $234 = HEAP32[$5>>2]|0;
      $235 = (16 - ($234))|0;
      $236 = $216 >>> $235;
      $237 = $236&65535;
      HEAP16[$7>>1] = $237;
      $238 = (($211) + -16)|0;
      $239 = (($238) + ($234))|0;
      $241 = $239;$246 = $236;
     } else {
      $240 = (($212) + ($211))|0;
      $241 = $240;$246 = $220;
     }
     HEAP32[$5>>2] = $241;
     $242 = ($241|0)>(9);
     $243 = (($count$0) + -10)|0;
     $244 = $243 << $241;
     $245 = $246 & 65535;
     $247 = $245 | $244;
     $248 = $247&65535;
     HEAP16[$7>>1] = $248;
     if ($242) {
      $249 = $247&255;
      $250 = HEAP32[$8>>2]|0;
      $251 = (($250) + 1)|0;
      HEAP32[$8>>2] = $251;
      $252 = HEAP32[$9>>2]|0;
      $253 = (($252) + ($250)|0);
      HEAP8[$253>>0] = $249;
      $254 = HEAP16[$7>>1]|0;
      $255 = ($254&65535) >>> 8;
      $256 = $255&255;
      $257 = HEAP32[$8>>2]|0;
      $258 = (($257) + 1)|0;
      HEAP32[$8>>2] = $258;
      $259 = HEAP32[$9>>2]|0;
      $260 = (($259) + ($257)|0);
      HEAP8[$260>>0] = $256;
      $261 = $243 & 65535;
      $262 = HEAP32[$5>>2]|0;
      $263 = (16 - ($262))|0;
      $264 = $261 >>> $263;
      $265 = $264&65535;
      HEAP16[$7>>1] = $265;
      $266 = (($262) + -9)|0;
      HEAP32[$5>>2] = $266;
      break;
     } else {
      $267 = (($241) + 7)|0;
      HEAP32[$5>>2] = $267;
      break;
     }
    }
   }
  } while(0);
  $268 = ($17<<16>>16)==(0);
  if ($268) {
   $prevlen$0$ph$phi = $nextlen$0$ph;$max_count$1$ph = 138;$min_count$1$ph = 3;$n$0$ph = $15;$nextlen$0$ph = $18;$prevlen$0$ph = $prevlen$0$ph$phi;
   continue;
  }
  $$6 = $21 ? 3 : 4;
  $$7 = $21 ? 6 : 7;
  $prevlen$0$ph$phi = $nextlen$0$ph;$max_count$1$ph = $$7;$min_count$1$ph = $$6;$n$0$ph = $15;$nextlen$0$ph = $18;$prevlen$0$ph = $prevlen$0$ph$phi;
 }
 STACKTOP = sp;return;
}
function _scan_tree($s,$tree,$max_code) {
 $s = $s|0;
 $tree = $tree|0;
 $max_code = $max_code|0;
 var $$ = 0, $$1 = 0, $$2 = 0, $$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$0 = 0, $max_count$1$ph = 0, $min_count$1$ph = 0, $n$0 = 0, $n$0$ph = 0, $nextlen$0$ph = 0, $or$cond = 0, $prevlen$0$ph = 0, $prevlen$0$ph$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($tree) + 2|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ($1<<16>>16)==(0);
 $$ = $3 ? 138 : 7;
 $$1 = $3 ? 3 : 4;
 $4 = (($max_code) + 1)|0;
 $5 = ((($tree) + ($4<<2)|0) + 2|0);
 HEAP16[$5>>1] = -1;
 $6 = (($s) + 2752|0);
 $7 = (($s) + 2756|0);
 $8 = (($s) + 2748|0);
 $max_count$1$ph = $$;$min_count$1$ph = $$1;$n$0$ph = 0;$nextlen$0$ph = $2;$prevlen$0$ph = -1;
 L1: while(1) {
  $count$0 = 0;$n$0 = $n$0$ph;
  while(1) {
   $9 = ($n$0|0)>($max_code|0);
   if ($9) {
    break L1;
   }
   $10 = (($n$0) + 1)|0;
   $11 = ((($tree) + ($10<<2)|0) + 2|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = $12&65535;
   $14 = (($count$0) + 1)|0;
   $15 = ($14|0)<($max_count$1$ph|0);
   $16 = ($nextlen$0$ph|0)==($13|0);
   $or$cond = $15 & $16;
   if ($or$cond) {
    $count$0 = $14;$n$0 = $10;
   } else {
    break;
   }
  }
  $17 = ($14|0)<($min_count$1$ph|0);
  do {
   if ($17) {
    $18 = ((($s) + ($nextlen$0$ph<<2)|0) + 2684|0);
    $19 = HEAP16[$18>>1]|0;
    $20 = $19&65535;
    $21 = (($20) + ($14))|0;
    $22 = $21&65535;
    HEAP16[$18>>1] = $22;
   } else {
    $23 = ($nextlen$0$ph|0)==(0);
    if ($23) {
     $30 = ($14|0)<(11);
     if ($30) {
      $31 = HEAP16[$6>>1]|0;
      $32 = (($31) + 1)<<16>>16;
      HEAP16[$6>>1] = $32;
      break;
     } else {
      $33 = HEAP16[$7>>1]|0;
      $34 = (($33) + 1)<<16>>16;
      HEAP16[$7>>1] = $34;
      break;
     }
    } else {
     $24 = ($nextlen$0$ph|0)==($prevlen$0$ph|0);
     if (!($24)) {
      $25 = ((($s) + ($nextlen$0$ph<<2)|0) + 2684|0);
      $26 = HEAP16[$25>>1]|0;
      $27 = (($26) + 1)<<16>>16;
      HEAP16[$25>>1] = $27;
     }
     $28 = HEAP16[$8>>1]|0;
     $29 = (($28) + 1)<<16>>16;
     HEAP16[$8>>1] = $29;
     break;
    }
   }
  } while(0);
  $35 = ($12<<16>>16)==(0);
  if ($35) {
   $prevlen$0$ph$phi = $nextlen$0$ph;$max_count$1$ph = 138;$min_count$1$ph = 3;$n$0$ph = $10;$nextlen$0$ph = $13;$prevlen$0$ph = $prevlen$0$ph$phi;
   continue;
  }
  $$2 = $16 ? 6 : 7;
  $$3 = $16 ? 3 : 4;
  $prevlen$0$ph$phi = $nextlen$0$ph;$max_count$1$ph = $$2;$min_count$1$ph = $$3;$n$0$ph = $10;$nextlen$0$ph = $13;$prevlen$0$ph = $prevlen$0$ph$phi;
 }
 STACKTOP = sp;return;
}
function _zcalloc($opaque,$items,$size) {
 $opaque = $opaque|0;
 $items = $items|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_imul($size, $items)|0;
 $1 = (_malloc($0)|0);
 STACKTOP = sp;return ($1|0);
}
function _zcfree($opaque,$ptr) {
 $opaque = $opaque|0;
 $ptr = $ptr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($ptr);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxControllerC2ERKNS_16PxControllerDescERNS_9PxPhysicsEPNS_7PxSceneE($this,$desc,$sdk,$s) {
 $this = $this|0;
 $desc = $desc|0;
 $sdk = $sdk|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0;
 var $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $boxGeom = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $boxGeom = sp;
 HEAP32[$this>>2] = ((403480 + 8|0));
 $0 = (($this) + 8|0);
 __ZN5physx3Cct10ControllerC2ERKNS_16PxControllerDescEPNS_7PxSceneE($0,$desc,$s);
 HEAP32[$this>>2] = ((403296 + 8|0));
 HEAP32[$0>>2] = ((403296 + 160|0));
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($desc) + 100|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 496|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($desc) + 104|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 500|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($desc) + 108|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 504|0);
 HEAPF32[$10>>2] = $9;
 HEAP32[$boxGeom>>2] = 3;
 $11 = (($boxGeom) + 4|0);
 $12 = (($boxGeom) + 8|0);
 $13 = (($boxGeom) + 12|0);
 $14 = Math_fround(HEAPF32[$2>>2]);
 $15 = Math_fround(HEAPF32[$5>>2]);
 $16 = Math_fround(HEAPF32[$8>>2]);
 $17 = (($this) + 488|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($14 * $18);
 $20 = Math_fround($15 * $18);
 $21 = Math_fround($16 * $18);
 HEAPF32[$11>>2] = $19;
 HEAPF32[$12>>2] = $20;
 HEAPF32[$13>>2] = $21;
 $22 = (($desc) + 92|0);
 $23 = HEAP32[$22>>2]|0;
 (__ZN5physx3Cct10Controller16createProxyActorERNS_9PxPhysicsERKNS_10PxGeometryERKNS_10PxMaterialE($0,$sdk,$boxGeom,$23)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxControllerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 __ZN5physx3Cct10ControllerD2Ev($1);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx3Cct13BoxControllerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 $2 = (($1) + 8|0);
 __ZN5physx3Cct10ControllerD2Ev($2);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxControllerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZN5physx3Cct10ControllerD2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx3Cct13BoxControllerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 8|0);
 __ZN5physx3Cct10ControllerD2Ev($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxController15invalidateCacheEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 __ZN5physx3Cct9SweepTest13voidTestCacheEv($0);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController11getWorldBoxERNS_17PxExtendedBounds3E($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = Math_fround(0), $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0;
 var $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 $1 = (($this) + 496|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 500|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 504|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 ;HEAP32[$box+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$box+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$box+20>>2]=HEAP32[$0+20>>2]|0;
 $7 = +$2;
 $8 = +HEAPF64[$box>>3];
 $9 = $8 - $7;
 HEAPF64[$box>>3] = $9;
 $10 = +$4;
 $11 = (($box) + 8|0);
 $12 = +HEAPF64[$11>>3];
 $13 = $12 - $10;
 HEAPF64[$11>>3] = $13;
 $14 = +$6;
 $15 = (($box) + 16|0);
 $16 = +HEAPF64[$15>>3];
 $17 = $16 - $14;
 HEAPF64[$15>>3] = $17;
 $18 = (($box) + 24|0);
 ;HEAP32[$18+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$18+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$18+20>>2]=HEAP32[$0+20>>2]|0;
 $19 = +HEAPF64[$18>>3];
 $20 = $7 + $19;
 HEAPF64[$18>>3] = $20;
 $21 = (($box) + 32|0);
 $22 = +HEAPF64[$21>>3];
 $23 = $10 + $22;
 HEAPF64[$21>>3] = $23;
 $24 = (($box) + 40|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $14 + $25;
 HEAPF64[$24>>3] = $26;
 STACKTOP = sp;return 1;
}
function __ZThn8_NK5physx3Cct13BoxController11getWorldBoxERNS_17PxExtendedBounds3E($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 416|0);
 $2 = (($0) + 496|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($0) + 500|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($0) + 504|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 ;HEAP32[$box+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$box+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$box+20>>2]=HEAP32[$1+20>>2]|0;
 $8 = +$3;
 $9 = +HEAPF64[$box>>3];
 $10 = $9 - $8;
 HEAPF64[$box>>3] = $10;
 $11 = +$5;
 $12 = (($box) + 8|0);
 $13 = +HEAPF64[$12>>3];
 $14 = $13 - $11;
 HEAPF64[$12>>3] = $14;
 $15 = +$7;
 $16 = (($box) + 16|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $17 - $15;
 HEAPF64[$16>>3] = $18;
 $19 = (($box) + 24|0);
 ;HEAP32[$19+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$19+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$19+20>>2]=HEAP32[$1+20>>2]|0;
 $20 = +HEAPF64[$19>>3];
 $21 = $8 + $20;
 HEAPF64[$19>>3] = $21;
 $22 = (($box) + 32|0);
 $23 = +HEAPF64[$22>>3];
 $24 = $11 + $23;
 HEAPF64[$22>>3] = $24;
 $25 = (($box) + 40|0);
 $26 = +HEAPF64[$25>>3];
 $27 = $15 + $26;
 HEAPF64[$25>>3] = $27;
 STACKTOP = sp;return 1;
}
function __ZNK5physx3Cct13BoxController13getHalfHeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 496|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx3Cct13BoxController17getHalfSideExtentEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 500|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx3Cct13BoxController20getHalfForwardExtentEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 504|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx3Cct13BoxController13setHalfHeightEf($this,$halfHeight) {
 $this = $this|0;
 $halfHeight = Math_fround($halfHeight);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bg$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $bg$i = sp;
 $0 = !($halfHeight <= Math_fround(0.0));
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 496|0);
 HEAPF32[$1>>2] = $halfHeight;
 $2 = (($this) + 408|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 8|0);
 $6 = (__ZNK5physx3Cct10Controller12getKineShapeEv($5)|0);
 HEAP32[$bg$i>>2] = 3;
 $7 = (($bg$i) + 4|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($bg$i) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($bg$i) + 12|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iii[$12 & 4095]($6,$bg$i)|0);
 $13 = Math_fround(HEAPF32[$1>>2]);
 $14 = (($this) + 500|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 504|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 488|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($13 * $19);
 $21 = Math_fround($15 * $19);
 $22 = Math_fround($17 * $19);
 HEAPF32[$7>>2] = $20;
 HEAPF32[$8>>2] = $21;
 HEAPF32[$9>>2] = $22;
 $23 = HEAP32[$6>>2]|0;
 $24 = (($23) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095]($6,$bg$i);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Cct13BoxController17setHalfSideExtentEf($this,$halfSideExtent) {
 $this = $this|0;
 $halfSideExtent = Math_fround($halfSideExtent);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bg$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $bg$i = sp;
 $0 = !($halfSideExtent <= Math_fround(0.0));
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 500|0);
 HEAPF32[$1>>2] = $halfSideExtent;
 $2 = (($this) + 408|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 8|0);
 $6 = (__ZNK5physx3Cct10Controller12getKineShapeEv($5)|0);
 HEAP32[$bg$i>>2] = 3;
 $7 = (($bg$i) + 4|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($bg$i) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($bg$i) + 12|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iii[$12 & 4095]($6,$bg$i)|0);
 $13 = (($this) + 496|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$1>>2]);
 $16 = (($this) + 504|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 488|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($14 * $19);
 $21 = Math_fround($15 * $19);
 $22 = Math_fround($17 * $19);
 HEAPF32[$7>>2] = $20;
 HEAPF32[$8>>2] = $21;
 HEAPF32[$9>>2] = $22;
 $23 = HEAP32[$6>>2]|0;
 $24 = (($23) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095]($6,$bg$i);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Cct13BoxController20setHalfForwardExtentEf($this,$halfForwardExtent) {
 $this = $this|0;
 $halfForwardExtent = Math_fround($halfForwardExtent);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bg$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $bg$i = sp;
 $0 = !($halfForwardExtent <= Math_fround(0.0));
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 504|0);
 HEAPF32[$1>>2] = $halfForwardExtent;
 $2 = (($this) + 408|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 8|0);
 $6 = (__ZNK5physx3Cct10Controller12getKineShapeEv($5)|0);
 HEAP32[$bg$i>>2] = 3;
 $7 = (($bg$i) + 4|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($bg$i) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($bg$i) + 12|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iii[$12 & 4095]($6,$bg$i)|0);
 $13 = (($this) + 496|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 500|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$1>>2]);
 $18 = (($this) + 488|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($14 * $19);
 $21 = Math_fround($16 * $19);
 $22 = Math_fround($17 * $19);
 HEAPF32[$7>>2] = $20;
 HEAPF32[$8>>2] = $21;
 HEAPF32[$9>>2] = $22;
 $23 = HEAP32[$6>>2]|0;
 $24 = (($23) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095]($6,$bg$i);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx3Cct13BoxController15getFootPositionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = Math_fround(0), $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $3 = 0;
 var $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$0+20>>2]|0;
 $1 = (($this) + 496|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 + $4);
 $6 = (($this) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $5);
 $9 = (($this) + 40|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($5 * $10);
 $12 = (($this) + 44|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($5 * $13);
 $15 = +$8;
 $16 = +HEAPF64[$agg$result>>3];
 $17 = $16 - $15;
 HEAPF64[$agg$result>>3] = $17;
 $18 = +$11;
 $19 = (($agg$result) + 8|0);
 $20 = +HEAPF64[$19>>3];
 $21 = $20 - $18;
 HEAPF64[$19>>3] = $21;
 $22 = +$14;
 $23 = (($agg$result) + 16|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $24 - $22;
 HEAPF64[$23>>3] = $25;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxController15setFootPositionERKNS_14PxExtendedVec3E($this,$position) {
 $this = $this|0;
 $position = $position|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $centerPosition = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $centerPosition = sp;
 ;HEAP32[$centerPosition+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$centerPosition+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$centerPosition+8>>2]=HEAP32[$position+8>>2]|0;HEAP32[$centerPosition+12>>2]=HEAP32[$position+12>>2]|0;HEAP32[$centerPosition+16>>2]=HEAP32[$position+16>>2]|0;HEAP32[$centerPosition+20>>2]=HEAP32[$position+20>>2]|0;
 $0 = (($this) + 496|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 52|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = (($this) + 36|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $4);
 $8 = (($this) + 40|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($4 * $9);
 $11 = (($this) + 44|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($4 * $12);
 $14 = +$7;
 $15 = +HEAPF64[$centerPosition>>3];
 $16 = $14 + $15;
 HEAPF64[$centerPosition>>3] = $16;
 $17 = +$10;
 $18 = (($centerPosition) + 8|0);
 $19 = +HEAPF64[$18>>3];
 $20 = $17 + $19;
 HEAPF64[$18>>3] = $20;
 $21 = +$13;
 $22 = (($centerPosition) + 16|0);
 $23 = +HEAPF64[$22>>3];
 $24 = $21 + $23;
 HEAPF64[$22>>3] = $24;
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + 20|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (FUNCTION_TABLE_iii[$27 & 4095]($this,$centerPosition)|0);
 STACKTOP = sp;return ($28|0);
}
function __ZNK5physx3Cct13BoxController6getOBBERNS_13PxExtendedBoxE($this,$obb) {
 $this = $this|0;
 $obb = $obb|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = Math_fround(0), $24 = 0.0, $25 = Math_fround(0), $26 = 0.0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, $worldBox = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $worldBox = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_iii[$2 & 4095]($this,$worldBox)|0);
 $3 = +HEAPF64[$worldBox>>3];
 $4 = (($worldBox) + 24|0);
 $5 = +HEAPF64[$4>>3];
 $6 = $3 + $5;
 $7 = (($worldBox) + 8|0);
 $8 = +HEAPF64[$7>>3];
 $9 = (($worldBox) + 32|0);
 $10 = +HEAPF64[$9>>3];
 $11 = $8 + $10;
 $12 = (($worldBox) + 16|0);
 $13 = +HEAPF64[$12>>3];
 $14 = (($worldBox) + 40|0);
 $15 = +HEAPF64[$14>>3];
 $16 = $13 + $15;
 $17 = (($obb) + 8|0);
 $18 = (($obb) + 16|0);
 $19 = $6 * 0.5;
 HEAPF64[$obb>>3] = $19;
 $20 = $11 * 0.5;
 HEAPF64[$17>>3] = $20;
 $21 = $16 * 0.5;
 HEAPF64[$18>>3] = $21;
 $22 = $5 - $3;
 $23 = Math_fround($22);
 $24 = $10 - $8;
 $25 = Math_fround($24);
 $26 = $15 - $13;
 $27 = Math_fround($26);
 $28 = (($obb) + 24|0);
 $29 = (($obb) + 28|0);
 $30 = (($obb) + 32|0);
 $31 = Math_fround($23 * Math_fround(0.5));
 HEAPF32[$28>>2] = $31;
 $32 = Math_fround($25 * Math_fround(0.5));
 HEAPF32[$29>>2] = $32;
 $33 = Math_fround($27 * Math_fround(0.5));
 HEAPF32[$30>>2] = $33;
 $34 = (($this) + 20|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($obb) + 36|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($this) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($obb) + 40|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($this) + 28|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($obb) + 44|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($this) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($obb) + 48|0);
 HEAPF32[$45>>2] = $44;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxController6resizeEf($this,$height) {
 $this = $this|0;
 $height = Math_fround($height);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = Math_fround(0), $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $pos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (Math_fround(FUNCTION_TABLE_fi[$2 & 255]($this)));
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 120|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_iif[$6 & 31]($this,$height)|0);
 $7 = Math_fround($height - $3);
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
 ;HEAP32[$pos+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$pos+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$pos+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$pos+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$pos+16>>2]=HEAP32[$11+16>>2]|0;HEAP32[$pos+20>>2]=HEAP32[$11+20>>2]|0;
 $12 = (($this) + 36|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($7 * $13);
 $15 = (($this) + 40|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = (($this) + 44|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($7 * $19);
 $21 = +$14;
 $22 = +HEAPF64[$pos>>3];
 $23 = $21 + $22;
 HEAPF64[$pos>>3] = $23;
 $24 = +$17;
 $25 = (($pos) + 8|0);
 $26 = +HEAPF64[$25>>3];
 $27 = $24 + $26;
 HEAPF64[$25>>3] = $27;
 $28 = +$20;
 $29 = (($pos) + 16|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $28 + $30;
 HEAPF64[$29>>3] = $31;
 $32 = HEAP32[$this>>2]|0;
 $33 = (($32) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_iii[$34 & 4095]($this,$pos)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController7getTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct13BoxController7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZN5physx3Cct10Controller15releaseInternalEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxController11setPositionERKNS_14PxExtendedVec3E($this,$position) {
 $this = $this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (__ZN5physx3Cct10Controller6setPosERKNS_14PxExtendedVec3E($0,$position)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Cct13BoxController11getPositionEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx3Cct13BoxController8getActorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 408|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct13BoxController13setStepOffsetEf($this,$offset) {
 $this = $this|0;
 $offset = Math_fround($offset);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $offset > Math_fround(0.0);
 if ($0) {
  $1 = (($this) + 56|0);
  HEAPF32[$1>>2] = $offset;
 }
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController13getStepOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx3Cct13BoxController18setNonWalkableModeENS_27PxControllerNonWalkableMode4EnumE($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = $flag;
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController18getNonWalkableModeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Cct13BoxController16getContactOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx3Cct13BoxController16setContactOffsetEf($this,$offset) {
 $this = $this|0;
 $offset = Math_fround($offset);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $offset > Math_fround(0.0);
 if ($0) {
  $1 = (($this) + 52|0);
  HEAPF32[$1>>2] = $offset;
 }
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController14getUpDirectionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 44|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxController14setUpDirectionERKNS_6PxVec3E($this,$up) {
 $this = $this|0;
 $up = $up|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZN5physx3Cct10Controller22setUpDirectionInternalERKNS_6PxVec3E($0,$up);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController13getSlopeLimitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx3Cct13BoxController13setSlopeLimitEf($this,$slopeLimit) {
 $this = $this|0;
 $slopeLimit = Math_fround($slopeLimit);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $slopeLimit > Math_fround(0.0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 48|0);
 HEAPF32[$1>>2] = $slopeLimit;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxController8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 464|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Cct13BoxController11getUserDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct13BoxController11setUserDataEPv($this,$userData) {
 $this = $this|0;
 $userData = $userData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 HEAP32[$0>>2] = $userData;
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController8getStateERNS_17PxControllerStateE($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNK5physx3Cct10Controller16getInternalStateERNS_17PxControllerStateE($0,$state);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController8getStatsERNS_17PxControllerStatsE($this,$stats) {
 $this = $this|0;
 $stats = $stats|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNK5physx3Cct10Controller16getInternalStatsERNS_17PxControllerStatsE($0,$stats);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct13BoxController21getHalfHeightInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 496|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx3Cct13BoxController15getPxControllerEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZThn8_NK5physx3Cct13BoxController21getHalfHeightInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 496|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 STACKTOP = sp;return (Math_fround($2));
}
function __ZThn8_N5physx3Cct13BoxController15getPxControllerEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx15PxBoxControllerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx15PxBoxControllerD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleControllerC2ERKNS_16PxControllerDescERNS_9PxPhysicsEPNS_7PxSceneE($this,$desc,$sdk,$s) {
 $this = $this|0;
 $desc = $desc|0;
 $sdk = $sdk|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0;
 var $8 = 0, $9 = 0, $capsGeom = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $capsGeom = sp;
 HEAP32[$this>>2] = ((403808 + 8|0));
 $0 = (($this) + 8|0);
 __ZN5physx3Cct10ControllerC2ERKNS_16PxControllerDescEPNS_7PxSceneE($0,$desc,$s);
 HEAP32[$this>>2] = ((403624 + 8|0));
 HEAP32[$0>>2] = ((403624 + 160|0));
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 1;
 $2 = (($desc) + 100|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 496|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($desc) + 104|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 500|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($desc) + 108|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 504|0);
 HEAP32[$10>>2] = $9;
 HEAP32[$capsGeom>>2] = 2;
 $11 = (($capsGeom) + 4|0);
 $12 = (($capsGeom) + 8|0);
 $13 = Math_fround(HEAPF32[$2>>2]);
 $14 = (($this) + 488|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 * $15);
 HEAPF32[$11>>2] = $16;
 $17 = Math_fround(HEAPF32[$5>>2]);
 $18 = Math_fround($17 * Math_fround(0.5));
 $19 = Math_fround($18 * $15);
 HEAPF32[$12>>2] = $19;
 $20 = (($desc) + 92|0);
 $21 = HEAP32[$20>>2]|0;
 (__ZN5physx3Cct10Controller16createProxyActorERNS_9PxPhysicsERKNS_10PxGeometryERKNS_10PxMaterialE($0,$sdk,$capsGeom,$21)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleControllerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 __ZN5physx3Cct10ControllerD2Ev($1);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx3Cct17CapsuleControllerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 $2 = (($1) + 8|0);
 __ZN5physx3Cct10ControllerD2Ev($2);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleControllerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZN5physx3Cct10ControllerD2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx3Cct17CapsuleControllerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 8|0);
 __ZN5physx3Cct10ControllerD2Ev($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleController15invalidateCacheEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 __ZN5physx3Cct9SweepTest13voidTestCacheEv($0);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController11getWorldBoxERNS_17PxExtendedBounds3E($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = Math_fround(0), $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $3 = 0;
 var $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 $1 = (($this) + 496|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 500|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(0.5));
 $6 = Math_fround($2 + $5);
 ;HEAP32[$box+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$box+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$box+20>>2]=HEAP32[$0+20>>2]|0;
 $7 = +$2;
 $8 = +HEAPF64[$box>>3];
 $9 = $8 - $7;
 HEAPF64[$box>>3] = $9;
 $10 = +$6;
 $11 = (($box) + 8|0);
 $12 = +HEAPF64[$11>>3];
 $13 = $12 - $10;
 HEAPF64[$11>>3] = $13;
 $14 = (($box) + 16|0);
 $15 = +HEAPF64[$14>>3];
 $16 = $15 - $7;
 HEAPF64[$14>>3] = $16;
 $17 = (($box) + 24|0);
 ;HEAP32[$17+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$17+20>>2]=HEAP32[$0+20>>2]|0;
 $18 = +HEAPF64[$17>>3];
 $19 = $7 + $18;
 HEAPF64[$17>>3] = $19;
 $20 = (($box) + 32|0);
 $21 = +HEAPF64[$20>>3];
 $22 = $10 + $21;
 HEAPF64[$20>>3] = $22;
 $23 = (($box) + 40|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $7 + $24;
 HEAPF64[$23>>3] = $25;
 STACKTOP = sp;return 1;
}
function __ZThn8_NK5physx3Cct17CapsuleController11getWorldBoxERNS_17PxExtendedBounds3E($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0.0;
 var $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 416|0);
 $2 = (($0) + 496|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($0) + 500|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(0.5));
 $7 = Math_fround($3 + $6);
 ;HEAP32[$box+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$box+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$box+20>>2]=HEAP32[$1+20>>2]|0;
 $8 = +$3;
 $9 = +HEAPF64[$box>>3];
 $10 = $9 - $8;
 HEAPF64[$box>>3] = $10;
 $11 = +$7;
 $12 = (($box) + 8|0);
 $13 = +HEAPF64[$12>>3];
 $14 = $13 - $11;
 HEAPF64[$12>>3] = $14;
 $15 = (($box) + 16|0);
 $16 = +HEAPF64[$15>>3];
 $17 = $16 - $8;
 HEAPF64[$15>>3] = $17;
 $18 = (($box) + 24|0);
 ;HEAP32[$18+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$18+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$18+20>>2]=HEAP32[$1+20>>2]|0;
 $19 = +HEAPF64[$18>>3];
 $20 = $8 + $19;
 HEAPF64[$18>>3] = $20;
 $21 = (($box) + 32|0);
 $22 = +HEAPF64[$21>>3];
 $23 = $11 + $22;
 HEAPF64[$21>>3] = $23;
 $24 = (($box) + 40|0);
 $25 = +HEAPF64[$24>>3];
 $26 = $8 + $25;
 HEAPF64[$24>>3] = $26;
 STACKTOP = sp;return 1;
}
function __ZN5physx3Cct17CapsuleController9setRadiusEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cg = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $cg = sp;
 $0 = (($this) + 496|0);
 HEAPF32[$0>>2] = $r;
 $1 = (($this) + 408|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 8|0);
 $5 = (__ZNK5physx3Cct10Controller12getKineShapeEv($4)|0);
 HEAP32[$cg>>2] = 2;
 $6 = (($cg) + 4|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($cg) + 8|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = HEAP32[$5>>2]|0;
 $9 = (($8) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_iii[$10 & 4095]($5,$cg)|0);
 $11 = (($this) + 488|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $r);
 HEAPF32[$6>>2] = $13;
 $14 = HEAP32[$5>>2]|0;
 $15 = (($14) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($5,$cg);
 STACKTOP = sp;return 1;
}
function __ZN5physx3Cct17CapsuleController9setHeightEf($this,$h) {
 $this = $this|0;
 $h = Math_fround($h);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cg = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $cg = sp;
 $0 = (($this) + 500|0);
 HEAPF32[$0>>2] = $h;
 $1 = (($this) + 408|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 8|0);
 $5 = (__ZNK5physx3Cct10Controller12getKineShapeEv($4)|0);
 HEAP32[$cg>>2] = 2;
 $6 = (($cg) + 4|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($cg) + 8|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = HEAP32[$5>>2]|0;
 $9 = (($8) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_iii[$10 & 4095]($5,$cg)|0);
 $11 = (($this) + 488|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($h * Math_fround(0.5));
 $14 = Math_fround($13 * $12);
 HEAPF32[$7>>2] = $14;
 $15 = HEAP32[$5>>2]|0;
 $16 = (($15) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($5,$cg);
 STACKTOP = sp;return 1;
}
function __ZNK5physx3Cct17CapsuleController15getClimbingModeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 504|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct17CapsuleController15setClimbingModeENS_21PxCapsuleClimbingMode4EnumE($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mode|0)>(1);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (($this) + 504|0);
  HEAP32[$1>>2] = $mode;
  $$0 = 1;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx3Cct17CapsuleController15getFootPositionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0.0, $2 = Math_fround(0), $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$0+20>>2]|0;
 $1 = (($this) + 52|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 496|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 + $4);
 $6 = (($this) + 500|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(0.5));
 $9 = Math_fround($5 + $8);
 $10 = (($this) + 36|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $9);
 $13 = (($this) + 40|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $9);
 $16 = (($this) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($9 * $17);
 $19 = +$12;
 $20 = +HEAPF64[$agg$result>>3];
 $21 = $20 - $19;
 HEAPF64[$agg$result>>3] = $21;
 $22 = +$15;
 $23 = (($agg$result) + 8|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $24 - $22;
 HEAPF64[$23>>3] = $25;
 $26 = +$18;
 $27 = (($agg$result) + 16|0);
 $28 = +HEAPF64[$27>>3];
 $29 = $28 - $26;
 HEAPF64[$27>>3] = $29;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleController15setFootPositionERKNS_14PxExtendedVec3E($this,$position) {
 $this = $this|0;
 $position = $position|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $centerPosition = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $centerPosition = sp;
 ;HEAP32[$centerPosition+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$centerPosition+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$centerPosition+8>>2]=HEAP32[$position+8>>2]|0;HEAP32[$centerPosition+12>>2]=HEAP32[$position+12>>2]|0;HEAP32[$centerPosition+16>>2]=HEAP32[$position+16>>2]|0;HEAP32[$centerPosition+20>>2]=HEAP32[$position+20>>2]|0;
 $0 = (($this) + 52|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 496|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = (($this) + 500|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * Math_fround(0.5));
 $8 = Math_fround($4 + $7);
 $9 = (($this) + 36|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $8);
 $12 = (($this) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $8);
 $15 = (($this) + 44|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($8 * $16);
 $18 = +$11;
 $19 = +HEAPF64[$centerPosition>>3];
 $20 = $19 + $18;
 HEAPF64[$centerPosition>>3] = $20;
 $21 = +$14;
 $22 = (($centerPosition) + 8|0);
 $23 = +HEAPF64[$22>>3];
 $24 = $21 + $23;
 HEAPF64[$22>>3] = $24;
 $25 = +$17;
 $26 = (($centerPosition) + 16|0);
 $27 = +HEAPF64[$26>>3];
 $28 = $25 + $27;
 HEAPF64[$26>>3] = $28;
 $29 = HEAP32[$this>>2]|0;
 $30 = (($29) + 20|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_iii[$31 & 4095]($this,$centerPosition)|0);
 STACKTOP = sp;return ($32|0);
}
function __ZNK5physx3Cct17CapsuleController10getCapsuleERNS_17PxExtendedCapsuleE($this,$capsule) {
 $this = $this|0;
 $capsule = $capsule|0;
 var $0 = 0, $1 = 0.0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 $1 = +HEAPF64[$0>>3];
 $2 = (($this) + 424|0);
 $3 = +HEAPF64[$2>>3];
 $4 = (($this) + 432|0);
 $5 = +HEAPF64[$4>>3];
 $6 = (($this) + 500|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 36|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 * $9);
 $11 = (($this) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($7 * $12);
 $14 = (($this) + 44|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($7 * $15);
 $17 = Math_fround($10 * Math_fround(0.5));
 $18 = Math_fround($13 * Math_fround(0.5));
 $19 = Math_fround($16 * Math_fround(0.5));
 $20 = +$17;
 $21 = $1 - $20;
 $22 = +$18;
 $23 = $3 - $22;
 $24 = +$19;
 $25 = $5 - $24;
 $26 = $1 + $20;
 $27 = $3 + $22;
 $28 = $5 + $24;
 HEAPF64[$capsule>>3] = $21;
 $29 = (($capsule) + 8|0);
 HEAPF64[$29>>3] = $23;
 $30 = (($capsule) + 16|0);
 HEAPF64[$30>>3] = $25;
 $31 = (($capsule) + 24|0);
 HEAPF64[$31>>3] = $26;
 $32 = (($capsule) + 32|0);
 HEAPF64[$32>>3] = $27;
 $33 = (($capsule) + 40|0);
 HEAPF64[$33>>3] = $28;
 $34 = (($this) + 496|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($capsule) + 48|0);
 HEAPF32[$36>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleController6resizeEf($this,$height) {
 $this = $this|0;
 $height = Math_fround($height);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = Math_fround(0), $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $pos = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 116|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (Math_fround(FUNCTION_TABLE_fi[$2 & 255]($this)));
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 120|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_iif[$6 & 31]($this,$height)|0);
 $7 = Math_fround($height - $3);
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
 ;HEAP32[$pos+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$pos+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$pos+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$pos+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$pos+16>>2]=HEAP32[$11+16>>2]|0;HEAP32[$pos+20>>2]=HEAP32[$11+20>>2]|0;
 $12 = (($this) + 36|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($7 * $13);
 $15 = (($this) + 40|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = (($this) + 44|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($7 * $19);
 $21 = Math_fround($14 * Math_fround(0.5));
 $22 = Math_fround($17 * Math_fround(0.5));
 $23 = Math_fround($20 * Math_fround(0.5));
 $24 = +$21;
 $25 = +HEAPF64[$pos>>3];
 $26 = $25 + $24;
 HEAPF64[$pos>>3] = $26;
 $27 = +$22;
 $28 = (($pos) + 8|0);
 $29 = +HEAPF64[$28>>3];
 $30 = $29 + $27;
 HEAPF64[$28>>3] = $30;
 $31 = +$23;
 $32 = (($pos) + 16|0);
 $33 = +HEAPF64[$32>>3];
 $34 = $33 + $31;
 HEAPF64[$32>>3] = $34;
 $35 = HEAP32[$this>>2]|0;
 $36 = (($35) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 (FUNCTION_TABLE_iii[$37 & 4095]($this,$pos)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController7getTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct17CapsuleController7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZN5physx3Cct10Controller15releaseInternalEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleController11setPositionERKNS_14PxExtendedVec3E($this,$position) {
 $this = $this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (__ZN5physx3Cct10Controller6setPosERKNS_14PxExtendedVec3E($0,$position)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Cct17CapsuleController11getPositionEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx3Cct17CapsuleController8getActorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 408|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct17CapsuleController13setStepOffsetEf($this,$offset) {
 $this = $this|0;
 $offset = Math_fround($offset);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $offset > Math_fround(0.0);
 if ($0) {
  $1 = (($this) + 56|0);
  HEAPF32[$1>>2] = $offset;
 }
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController13getStepOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx3Cct17CapsuleController18setNonWalkableModeENS_27PxControllerNonWalkableMode4EnumE($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = $flag;
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController18getNonWalkableModeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Cct17CapsuleController16getContactOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx3Cct17CapsuleController16setContactOffsetEf($this,$offset) {
 $this = $this|0;
 $offset = Math_fround($offset);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $offset > Math_fround(0.0);
 if ($0) {
  $1 = (($this) + 52|0);
  HEAPF32[$1>>2] = $offset;
 }
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController14getUpDirectionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 44|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleController14setUpDirectionERKNS_6PxVec3E($this,$up) {
 $this = $this|0;
 $up = $up|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZN5physx3Cct10Controller22setUpDirectionInternalERKNS_6PxVec3E($0,$up);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController13getSlopeLimitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx3Cct17CapsuleController13setSlopeLimitEf($this,$slopeLimit) {
 $this = $this|0;
 $slopeLimit = Math_fround($slopeLimit);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $slopeLimit > Math_fround(0.0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 48|0);
 HEAPF32[$1>>2] = $slopeLimit;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleController8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 464|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Cct17CapsuleController11getUserDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct17CapsuleController11setUserDataEPv($this,$userData) {
 $this = $this|0;
 $userData = $userData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 HEAP32[$0>>2] = $userData;
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController8getStateERNS_17PxControllerStateE($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNK5physx3Cct10Controller16getInternalStateERNS_17PxControllerStateE($0,$state);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController8getStatsERNS_17PxControllerStatsE($this,$stats) {
 $this = $this|0;
 $stats = $stats|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNK5physx3Cct10Controller16getInternalStatsERNS_17PxControllerStatsE($0,$stats);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct17CapsuleController9getRadiusEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 496|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx3Cct17CapsuleController9getHeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 500|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx3Cct17CapsuleController21getHalfHeightInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 496|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 500|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(0.5));
 $5 = Math_fround($1 + $4);
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx3Cct17CapsuleController15getPxControllerEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZThn8_NK5physx3Cct17CapsuleController21getHalfHeightInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 496|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($0) + 500|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(0.5));
 $6 = Math_fround($2 + $5);
 STACKTOP = sp;return (Math_fround($6));
}
function __ZThn8_N5physx3Cct17CapsuleController15getPxControllerEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx19PxCapsuleControllerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx19PxCapsuleControllerD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9CCTParamsC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 59|0);
 dest=$1+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP16[$1+36>>1]=0|0;HEAP8[$1+38>>0]=0|0;
 HEAP8[$2>>0] = 1;
 $3 = (($this) + 60|0);
 HEAP8[$3>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTestC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 224|0);
 $1 = (($this) + 240|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 dest=$this+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 244|0);
 $3 = (($this) + 283|0);
 dest=$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP16[$2+36>>1]=0|0;HEAP8[$2+38>>0]=0|0;
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 284|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 296|0);
 HEAP32[$5>>2] = -1;
 $6 = (($this) + 300|0);
 $7 = (($this) + 48|0);
 ;HEAP16[$6+0>>1]=0|0;HEAP16[$6+2>>1]=0|0;HEAP16[$6+4>>1]=0|0;HEAP16[$6+6>>1]=0|0;HEAP16[$6+8>>1]=0|0;HEAP16[$6+10>>1]=0|0;
 HEAPF64[$7>>3] = 1.79769313486231570815E+308;
 $8 = (($this) + 56|0);
 HEAPF64[$8>>3] = 1.79769313486231570815E+308;
 $9 = (($this) + 64|0);
 HEAPF64[$9>>3] = 1.79769313486231570815E+308;
 $10 = (($this) + 72|0);
 HEAPF64[$10>>3] = -1.79769313486231570815E+308;
 $11 = (($this) + 80|0);
 HEAPF64[$11>>3] = -1.79769313486231570815E+308;
 $12 = (($this) + 88|0);
 HEAPF64[$12>>3] = -1.79769313486231570815E+308;
 $13 = (($this) + 96|0);
 $14 = (($this) + 156|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 160|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 152|0);
 ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;HEAP32[$13+16>>2]=0|0;HEAP32[$13+20>>2]=0|0;
 HEAP32[$16>>2] = -1;
 $17 = (($this) + 164|0);
 $18 = (($this) + 288|0);
 dest=$17+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$18>>2] = Math_fround(1.5);
 $19 = (($this) + 120|0);
 ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;HEAP32[$19+16>>2]=0|0;HEAP32[$19+20>>2]=0|0;HEAP32[$19+24>>2]=0|0;HEAP32[$19+28>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTestD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i1 = $15 & $16;
 if ($or$cond$i$i1) {
  $17 = (($this) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i3 = $27 & $28;
 if (!($or$cond$i$i3)) {
  STACKTOP = sp;return;
 }
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest13voidTestCacheEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAPF64[$0>>3] = 1.79769313486231570815E+308;
 $1 = (($this) + 56|0);
 HEAPF64[$1>>3] = 1.79769313486231570815E+308;
 $2 = (($this) + 64|0);
 HEAPF64[$2>>3] = 1.79769313486231570815E+308;
 $3 = (($this) + 72|0);
 HEAPF64[$3>>3] = -1.79769313486231570815E+308;
 $4 = (($this) + 80|0);
 HEAPF64[$4>>3] = -1.79769313486231570815E+308;
 $5 = (($this) + 88|0);
 HEAPF64[$5>>3] = -1.79769313486231570815E+308;
 $6 = (($this) + 156|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 160|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 152|0);
 HEAP32[$8>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest9onReleaseERKNS_6PxBaseE($this,$observed) {
 $this = $this|0;
 $observed = $observed|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $Data$01$i = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($observed) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $$off = (($1) + -5)<<16>>16;
 $switch = ($$off&65535)<(2);
 if ($switch) {
  $2 = (($this) + 160|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==($observed|0);
  if (!($4)) {
   STACKTOP = sp;return;
  }
  $5 = (($this) + 156|0);
  HEAP32[$5>>2] = 0;
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $6 = ($1<<16>>16)==(7);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $$idx = (($this) + 32|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $$idx1 = (($this) + 36|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $7 = (($$idx$val) + ($$idx1$val<<2)|0);
 $8 = ($$idx1$val|0)==(0);
 L11: do {
  if (!($8)) {
   $Data$01$i = $$idx$val;
   while(1) {
    $9 = (($Data$01$i) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($observed|0);
    if ($11) {
     break;
    }
    $12 = HEAP32[$Data$01$i>>2]|0;
    $13 = (403952 + ($12<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($Data$01$i) + ($14)|0);
    $16 = ($15|0)==($7|0);
    if ($16) {
     break L11;
    } else {
     $Data$01$i = $15;
    }
   }
   $17 = (($this) + 48|0);
   HEAPF64[$17>>3] = 1.79769313486231570815E+308;
   $18 = (($this) + 56|0);
   HEAPF64[$18>>3] = 1.79769313486231570815E+308;
   $19 = (($this) + 64|0);
   HEAPF64[$19>>3] = 1.79769313486231570815E+308;
   $20 = (($this) + 72|0);
   HEAPF64[$20>>3] = -1.79769313486231570815E+308;
   $21 = (($this) + 80|0);
   HEAPF64[$21>>3] = -1.79769313486231570815E+308;
   $22 = (($this) + 88|0);
   HEAPF64[$22>>3] = -1.79769313486231570815E+308;
  }
 } while(0);
 $23 = (($this) + 156|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($observed|0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 HEAP32[$23>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest15onObstacleAddedEjPKNS_17PxObstacleContextERKNS_6PxVec3ES7_f($this,$index,$context,$origin,$unitDir,$distance) {
 $this = $this|0;
 $index = $index|0;
 $context = $context|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0.0, $46 = Math_fround(0), $47 = 0, $48 = 0.0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $obstacleHit = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $obstacleHit = sp;
 HEAP32[$0>>2] = $index;
 $1 = (($this) + 152|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 if ($3) {
  STACKTOP = sp;return;
 }
 HEAP32[$obstacleHit>>2] = 0;
 $4 = (($obstacleHit) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($obstacleHit) + 8|0);
 HEAP32[$5>>2] = -1;
 $6 = (($obstacleHit) + 12|0);
 HEAP16[$6>>1] = 0;
 $7 = (($obstacleHit) + 16|0);
 $8 = (($obstacleHit) + 40|0);
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;
 HEAPF32[$8>>2] = Math_fround(3.40282346638528859812E+38);
 $9 = (($obstacleHit) + 44|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($obstacleHit) + 48|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (__ZNK5physx3Cct15ObstacleContext13raycastSingleERNS_12PxRaycastHitERKjRKNS_6PxVec3ES8_f($context,$obstacleHit,$0,$origin,$unitDir,$distance)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = Math_fround(HEAPF32[$7>>2]);
 $14 = Math_fround(HEAPF32[$unitDir>>2]);
 $15 = Math_fround($13 * $14);
 $16 = (($obstacleHit) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($unitDir) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = Math_fround($15 + $20);
 $22 = (($obstacleHit) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($unitDir) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 * $25);
 $27 = Math_fround($21 + $26);
 $28 = (($this) + 212|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($14 * $29);
 $31 = (($this) + 216|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($19 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($this) + 220|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($25 * $36);
 $38 = Math_fround($34 + $37);
 $39 = $27 < $38;
 if (!($39)) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = $40;
 HEAPF32[$28>>2] = $13;
 HEAPF32[$31>>2] = $17;
 HEAPF32[$35>>2] = $23;
 $41 = (($11) + 8|0);
 $42 = +HEAPF64[$41>>3];
 $43 = Math_fround($42);
 $44 = (($11) + 16|0);
 $45 = +HEAPF64[$44>>3];
 $46 = Math_fround($45);
 $47 = (($11) + 24|0);
 $48 = +HEAPF64[$47>>3];
 $49 = Math_fround($48);
 $50 = (($11) + 32|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($11) + 36|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($11) + 40|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($11) + 44|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($13 - $43);
 $59 = Math_fround($17 - $46);
 $60 = Math_fround($23 - $49);
 $61 = Math_fround($58 * Math_fround(2.0));
 $62 = Math_fround($59 * Math_fround(2.0));
 $63 = Math_fround($60 * Math_fround(2.0));
 $64 = Math_fround($57 * $57);
 $65 = Math_fround($64 + Math_fround(-0.5));
 $66 = Math_fround($61 * $51);
 $67 = Math_fround($62 * $53);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($63 * $55);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($61 * $65);
 $72 = Math_fround($53 * $63);
 $73 = Math_fround($62 * $55);
 $74 = Math_fround($72 - $73);
 $75 = Math_fround($57 * $74);
 $76 = Math_fround($71 - $75);
 $77 = Math_fround($51 * $70);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($62 * $65);
 $80 = Math_fround($61 * $55);
 $81 = Math_fround($51 * $63);
 $82 = Math_fround($80 - $81);
 $83 = Math_fround($57 * $82);
 $84 = Math_fround($79 - $83);
 $85 = Math_fround($53 * $70);
 $86 = Math_fround($85 + $84);
 $87 = Math_fround($63 * $65);
 $88 = Math_fround($51 * $62);
 $89 = Math_fround($61 * $53);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($57 * $90);
 $92 = Math_fround($87 - $91);
 $93 = Math_fround($55 * $70);
 $94 = Math_fround($93 + $92);
 $95 = (($this) + 200|0);
 HEAPF32[$95>>2] = $78;
 $96 = (($this) + 204|0);
 HEAPF32[$96>>2] = $86;
 $97 = (($this) + 208|0);
 HEAPF32[$97>>2] = $94;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest17onObstacleRemovedEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($index|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest17onObstacleUpdatedEjPKNS_17PxObstacleContextERKNS_6PxVec3ES7_f($this,$index,$context,$origin,$unitDir,$distance) {
 $this = $this|0;
 $index = $index|0;
 $context = $context|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0.0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0.0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0.0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0;
 var $closestHandle = 0, $obstacleHit = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $obstacleHit = sp + 8|0;
 $closestHandle = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($index|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 HEAP32[$obstacleHit>>2] = 0;
 $3 = (($obstacleHit) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($obstacleHit) + 8|0);
 HEAP32[$4>>2] = -1;
 $5 = (($obstacleHit) + 12|0);
 HEAP16[$5>>1] = 0;
 $6 = (($obstacleHit) + 16|0);
 $7 = (($obstacleHit) + 40|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 HEAPF32[$7>>2] = Math_fround(3.40282346638528859812E+38);
 $8 = (($obstacleHit) + 44|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($obstacleHit) + 48|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 HEAP32[$closestHandle>>2] = -1;
 $10 = (__ZNK5physx3Cct15ObstacleContext13raycastSingleERNS_12PxRaycastHitERKNS_6PxVec3ES6_fRj($context,$obstacleHit,$origin,$unitDir,$distance,$closestHandle)|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = HEAP32[$closestHandle>>2]|0;
 $13 = ($11|0)==($12|0);
 $14 = ($10|0)==(0|0);
 $or$cond = $13 | $14;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $12;
 $15 = Math_fround(HEAPF32[$6>>2]);
 $16 = (($this) + 212|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($obstacleHit) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 216|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($obstacleHit) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 220|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($10) + 8|0);
 $24 = +HEAPF64[$23>>3];
 $25 = Math_fround($24);
 $26 = (($10) + 16|0);
 $27 = +HEAPF64[$26>>3];
 $28 = Math_fround($27);
 $29 = (($10) + 24|0);
 $30 = +HEAPF64[$29>>3];
 $31 = Math_fround($30);
 $32 = (($10) + 32|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($10) + 36|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($10) + 40|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($10) + 44|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($15 - $25);
 $41 = Math_fround($18 - $28);
 $42 = Math_fround($21 - $31);
 $43 = Math_fround($40 * Math_fround(2.0));
 $44 = Math_fround($41 * Math_fround(2.0));
 $45 = Math_fround($42 * Math_fround(2.0));
 $46 = Math_fround($39 * $39);
 $47 = Math_fround($46 + Math_fround(-0.5));
 $48 = Math_fround($43 * $33);
 $49 = Math_fround($44 * $35);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($45 * $37);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($43 * $47);
 $54 = Math_fround($35 * $45);
 $55 = Math_fround($44 * $37);
 $56 = Math_fround($54 - $55);
 $57 = Math_fround($39 * $56);
 $58 = Math_fround($53 - $57);
 $59 = Math_fround($33 * $52);
 $60 = Math_fround($59 + $58);
 $61 = Math_fround($44 * $47);
 $62 = Math_fround($43 * $37);
 $63 = Math_fround($33 * $45);
 $64 = Math_fround($62 - $63);
 $65 = Math_fround($39 * $64);
 $66 = Math_fround($61 - $65);
 $67 = Math_fround($35 * $52);
 $68 = Math_fround($67 + $66);
 $69 = Math_fround($45 * $47);
 $70 = Math_fround($33 * $44);
 $71 = Math_fround($43 * $35);
 $72 = Math_fround($70 - $71);
 $73 = Math_fround($39 * $72);
 $74 = Math_fround($69 - $73);
 $75 = Math_fround($37 * $52);
 $76 = Math_fround($75 + $74);
 $77 = (($this) + 200|0);
 HEAPF32[$77>>2] = $60;
 $78 = (($this) + 204|0);
 HEAPF32[$78>>2] = $68;
 $79 = (($this) + 208|0);
 HEAPF32[$79>>2] = $76;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = Math_fround(0), $1 = 0.0, $10 = 0.0, $11 = 0, $12 = Math_fround(0), $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0.0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0.0, $67 = Math_fround(0), $68 = 0.0, $69 = Math_fround(0), $7 = 0.0, $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0.0, $data$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$shift>>2]);
 $1 = +$0;
 $2 = (($this) + 48|0);
 $3 = +HEAPF64[$2>>3];
 $4 = $3 - $1;
 HEAPF64[$2>>3] = $4;
 $5 = (($shift) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = +$6;
 $8 = (($this) + 56|0);
 $9 = +HEAPF64[$8>>3];
 $10 = $9 - $7;
 HEAPF64[$8>>3] = $10;
 $11 = (($shift) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = +$12;
 $14 = (($this) + 64|0);
 $15 = +HEAPF64[$14>>3];
 $16 = $15 - $13;
 HEAPF64[$14>>3] = $16;
 $17 = (($this) + 72|0);
 $18 = +HEAPF64[$17>>3];
 $19 = $18 - $1;
 HEAPF64[$17>>3] = $19;
 $20 = (($this) + 80|0);
 $21 = +HEAPF64[$20>>3];
 $22 = $21 - $7;
 HEAPF64[$20>>3] = $22;
 $23 = (($this) + 88|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $24 - $13;
 HEAPF64[$23>>3] = $25;
 $26 = (($this) + 156|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $45 = (($this) + 152|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(-1);
  if (!($47)) {
   $48 = (($this) + 212|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = Math_fround($49 - $0);
   HEAPF32[$48>>2] = $50;
   $51 = Math_fround(HEAPF32[$5>>2]);
   $52 = (($this) + 216|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = Math_fround($53 - $51);
   HEAPF32[$52>>2] = $54;
   $55 = Math_fround(HEAPF32[$11>>2]);
   $56 = (($this) + 220|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround($57 - $55);
   HEAPF32[$56>>2] = $58;
  }
 } else {
  $29 = (($this) + 160|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 4|0);
  $32 = HEAP16[$31>>1]|0;
  $33 = ($32<<16>>16)==(6);
  if (!($33)) {
   $34 = (($this) + 188|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = Math_fround($35 - $0);
   HEAPF32[$34>>2] = $36;
   $37 = Math_fround(HEAPF32[$5>>2]);
   $38 = (($this) + 192|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = Math_fround($39 - $37);
   HEAPF32[$38>>2] = $40;
   $41 = Math_fround(HEAPF32[$11>>2]);
   $42 = (($this) + 196|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = Math_fround($43 - $41);
   HEAPF32[$42>>2] = $44;
  }
 }
 $59 = (($this) + 32|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($this) + 36|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($60) + ($62<<2)|0);
 $64 = ($62|0)==(0);
 if ($64) {
  STACKTOP = sp;return;
 }
 $65 = Math_fround(HEAPF32[$shift>>2]);
 $66 = +$65;
 $67 = Math_fround(HEAPF32[$5>>2]);
 $68 = +$67;
 $69 = Math_fround(HEAPF32[$11>>2]);
 $70 = +$69;
 $data$01 = $60;
 while(1) {
  $71 = (($data$01) + 16|0);
  $72 = +HEAPF64[$71>>3];
  $73 = $72 - $66;
  HEAPF64[$71>>3] = $73;
  $74 = (($data$01) + 24|0);
  $75 = +HEAPF64[$74>>3];
  $76 = $75 - $68;
  HEAPF64[$74>>3] = $76;
  $77 = (($data$01) + 32|0);
  $78 = +HEAPF64[$77>>3];
  $79 = $78 - $70;
  HEAPF64[$77>>3] = $79;
  $80 = HEAP32[$data$01>>2]|0;
  $81 = (403952 + ($80<<2)|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($data$01) + ($82)|0);
  $84 = ($83|0)==($63|0);
  if ($84) {
   break;
  } else {
   $data$01 = $83;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest20findTouchedObstaclesERKNS0_13UserObstaclesERKNS_17PxExtendedBounds3E($this,$userObstacles,$worldBox) {
 $this = $this|0;
 $userObstacles = $userObstacles|0;
 $worldBox = $worldBox|0;
 var $$c = 0, $$c1 = 0, $$pre = 0.0, $$pre29 = 0.0, $$pre30 = 0.0, $$pre31 = 0.0, $$pre32 = 0.0, $$pre33 = 0.0, $$pre35 = 0.0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0;
 var $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0.0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0.0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0;
 var $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0.0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = Math_fround(0), $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0;
 var $163 = Math_fround(0), $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0.0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0.0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0.0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0.0, $200 = 0, $201 = Math_fround(0), $202 = 0.0, $203 = 0, $204 = 0.0, $205 = 0, $206 = 0.0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0.0, $21 = 0.0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = Math_fround(0), $214 = 0.0, $215 = Math_fround(0), $216 = 0.0;
 var $217 = 0, $218 = 0, $219 = 0.0, $22 = 0, $220 = 0, $221 = 0.0, $222 = 0, $223 = 0.0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0.0, $227 = 0.0, $228 = 0, $229 = 0.0, $23 = 0, $230 = Math_fround(0), $231 = 0.0, $232 = Math_fround(0), $233 = 0.0, $234 = 0;
 var $235 = 0, $236 = 0.0, $237 = 0, $238 = 0.0, $239 = 0, $24 = 0, $240 = 0.0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0.0, $244 = 0.0, $245 = 0, $246 = 0.0, $247 = Math_fround(0), $248 = 0.0, $249 = Math_fround(0), $25 = 0, $250 = 0.0, $251 = 0, $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0.0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0.0, $78 = Math_fround(0), $79 = 0;
 var $8 = 0.0, $80 = 0.0, $81 = Math_fround(0), $82 = 0, $83 = 0.0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $Extents = 0, $center$i = 0, $exitcond = 0, $exitcond28 = 0, $extents$i = 0, $i$024 = 0, $i1$023 = 0, $obb = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $center$i = sp + 192|0;
 $extents$i = sp + 180|0;
 $0 = sp + 144|0;
 $obb = sp + 84|0;
 $Extents = sp + 72|0;
 $1 = sp + 24|0;
 $2 = sp + 12|0;
 $3 = sp;
 $4 = sp + 36|0;
 $5 = +HEAPF64[$worldBox>>3];
 $6 = (($worldBox) + 24|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $5 + $7;
 $9 = (($worldBox) + 8|0);
 $10 = +HEAPF64[$9>>3];
 $11 = (($worldBox) + 32|0);
 $12 = +HEAPF64[$11>>3];
 $13 = $10 + $12;
 $14 = (($worldBox) + 16|0);
 $15 = +HEAPF64[$14>>3];
 $16 = (($worldBox) + 40|0);
 $17 = +HEAPF64[$16>>3];
 $18 = $15 + $17;
 $19 = $8 * 0.5;
 $20 = $13 * 0.5;
 $21 = $18 * 0.5;
 $22 = HEAP32[$userObstacles>>2]|0;
 $23 = (($userObstacles) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($userObstacles) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = Math_fround($5);
 $28 = Math_fround($10);
 $29 = Math_fround($15);
 $30 = Math_fround($7);
 $31 = Math_fround($12);
 $32 = Math_fround($17);
 $33 = ($22|0)==(0);
 if ($33) {
  $157 = $5;$158 = $7;$161 = $10;$162 = $12;$165 = $15;$166 = $17;
 } else {
  $34 = (($obb) + 4|0);
  $35 = (($obb) + 8|0);
  $36 = (($obb) + 12|0);
  $37 = (($obb) + 16|0);
  $38 = (($obb) + 20|0);
  $39 = (($obb) + 24|0);
  $40 = (($obb) + 28|0);
  $41 = (($obb) + 32|0);
  $42 = (($obb) + 36|0);
  $43 = (($obb) + 40|0);
  $44 = (($obb) + 44|0);
  $45 = (($obb) + 48|0);
  $46 = (($obb) + 52|0);
  $47 = (($obb) + 56|0);
  $48 = Math_fround($27 + $30);
  $49 = Math_fround($28 + $31);
  $50 = Math_fround($29 + $32);
  $51 = Math_fround($48 * Math_fround(0.5));
  $52 = Math_fround($49 * Math_fround(0.5));
  $53 = Math_fround($50 * Math_fround(0.5));
  $54 = (($center$i) + 4|0);
  $55 = (($center$i) + 8|0);
  $56 = Math_fround($30 - $27);
  $57 = Math_fround($31 - $28);
  $58 = Math_fround($32 - $29);
  $59 = Math_fround($56 * Math_fround(0.5));
  $60 = Math_fround($57 * Math_fround(0.5));
  $61 = Math_fround($58 * Math_fround(0.5));
  $62 = (($extents$i) + 4|0);
  $63 = (($extents$i) + 8|0);
  $64 = (($obb) + 48|0);
  $65 = (($obb) + 36|0);
  $66 = (($0) + 4|0);
  $67 = (($0) + 8|0);
  $68 = (($0) + 12|0);
  $69 = (($0) + 16|0);
  $70 = (($0) + 20|0);
  $71 = (($0) + 24|0);
  $72 = (($0) + 28|0);
  $73 = (($0) + 32|0);
  $74 = (($this) + 32|0);
  $75 = (($this) + 36|0);
  $i$024 = 0;
  while(1) {
   $76 = (($24) + (($i$024*56)|0)|0);
   $77 = +HEAPF64[$76>>3];
   $78 = Math_fround($77);
   $79 = ((($24) + (($i$024*56)|0)|0) + 8|0);
   $80 = +HEAPF64[$79>>3];
   $81 = Math_fround($80);
   $82 = ((($24) + (($i$024*56)|0)|0) + 16|0);
   $83 = +HEAPF64[$82>>3];
   $84 = Math_fround($83);
   $85 = ((($24) + (($i$024*56)|0)|0) + 36|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   $87 = ((($24) + (($i$024*56)|0)|0) + 40|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = ((($24) + (($i$024*56)|0)|0) + 44|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = ((($24) + (($i$024*56)|0)|0) + 48|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = Math_fround($86 + $86);
   $94 = Math_fround($88 + $88);
   $95 = Math_fround($90 + $90);
   $96 = Math_fround($86 * $93);
   $97 = Math_fround($88 * $94);
   $98 = Math_fround($90 * $95);
   $99 = Math_fround($93 * $88);
   $100 = Math_fround($93 * $90);
   $101 = Math_fround($93 * $92);
   $102 = Math_fround($94 * $90);
   $103 = Math_fround($94 * $92);
   $104 = Math_fround($95 * $92);
   $105 = Math_fround(Math_fround(1.0) - $97);
   $106 = Math_fround($105 - $98);
   $107 = Math_fround($99 + $104);
   $108 = Math_fround($100 - $103);
   $109 = Math_fround($99 - $104);
   $110 = Math_fround(Math_fround(1.0) - $96);
   $111 = Math_fround($110 - $98);
   $112 = Math_fround($102 + $101);
   $113 = Math_fround($100 + $103);
   $114 = Math_fround($102 - $101);
   $115 = Math_fround($110 - $97);
   HEAPF32[$obb>>2] = $106;
   HEAPF32[$34>>2] = $107;
   HEAPF32[$35>>2] = $108;
   HEAPF32[$36>>2] = $109;
   HEAPF32[$37>>2] = $111;
   HEAPF32[$38>>2] = $112;
   HEAPF32[$39>>2] = $113;
   HEAPF32[$40>>2] = $114;
   HEAPF32[$41>>2] = $115;
   HEAPF32[$42>>2] = $78;
   HEAPF32[$43>>2] = $81;
   HEAPF32[$44>>2] = $84;
   $116 = ((($24) + (($i$024*56)|0)|0) + 24|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   HEAPF32[$45>>2] = $117;
   $118 = ((($24) + (($i$024*56)|0)|0) + 28|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   HEAPF32[$46>>2] = $119;
   $120 = ((($24) + (($i$024*56)|0)|0) + 32|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   HEAPF32[$47>>2] = $121;
   HEAPF32[$center$i>>2] = $51;
   HEAPF32[$54>>2] = $52;
   HEAPF32[$55>>2] = $53;
   HEAPF32[$extents$i>>2] = $59;
   HEAPF32[$62>>2] = $60;
   HEAPF32[$63>>2] = $61;
   HEAPF32[$0>>2] = Math_fround(1.0);
   HEAPF32[$66>>2] = Math_fround(0.0);
   HEAPF32[$67>>2] = Math_fround(0.0);
   HEAPF32[$68>>2] = Math_fround(0.0);
   HEAPF32[$69>>2] = Math_fround(1.0);
   HEAPF32[$70>>2] = Math_fround(0.0);
   HEAPF32[$71>>2] = Math_fround(0.0);
   HEAPF32[$72>>2] = Math_fround(0.0);
   HEAPF32[$73>>2] = Math_fround(1.0);
   $122 = (__ZN5physx2Gu15intersectOBBOBBERKNS_6PxVec3ES3_RKNS_7PxMat33ES3_S3_S6_b($64,$65,$obb,$extents$i,$center$i,$0,1)|0);
   if ($122) {
    $123 = HEAP32[$75>>2]|0;
    $124 = (($123) + 24)|0;
    __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($74,$124);
    $125 = HEAP32[$74>>2]|0;
    $126 = (($125) + ($123<<2)|0);
    HEAP32[$126>>2] = 0;
    $127 = (($26) + ($i$024<<2)|0);
    $128 = HEAP32[$127>>2]|0;
    $$sum10 = (($123) + 1)|0;
    $129 = (($125) + ($$sum10<<2)|0);
    $$c1 = $128;
    HEAP32[$129>>2] = $$c1;
    $$sum11 = (($123) + 2)|0;
    $130 = (($125) + ($$sum11<<2)|0);
    HEAP32[$130>>2] = 0;
    $$sum12 = (($123) + 4)|0;
    $131 = (($125) + ($$sum12<<2)|0);
    HEAPF64[$131>>3] = $19;
    $$sum13 = (($123) + 6)|0;
    $132 = (($125) + ($$sum13<<2)|0);
    HEAPF64[$132>>3] = $20;
    $$sum14 = (($123) + 8)|0;
    $133 = (($125) + ($$sum14<<2)|0);
    HEAPF64[$133>>3] = $21;
    $$sum15 = (($123) + 10)|0;
    $134 = (($125) + ($$sum15<<2)|0);
    ;HEAP32[$134+0>>2]=HEAP32[$76+0>>2]|0;HEAP32[$134+4>>2]=HEAP32[$76+4>>2]|0;HEAP32[$134+8>>2]=HEAP32[$76+8>>2]|0;HEAP32[$134+12>>2]=HEAP32[$76+12>>2]|0;HEAP32[$134+16>>2]=HEAP32[$76+16>>2]|0;HEAP32[$134+20>>2]=HEAP32[$76+20>>2]|0;
    $135 = Math_fround(HEAPF32[$116>>2]);
    $$sum16 = (($123) + 16)|0;
    $136 = (($125) + ($$sum16<<2)|0);
    HEAPF32[$136>>2] = $135;
    $137 = Math_fround(HEAPF32[$118>>2]);
    $$sum17 = (($123) + 17)|0;
    $138 = (($125) + ($$sum17<<2)|0);
    HEAPF32[$138>>2] = $137;
    $139 = Math_fround(HEAPF32[$120>>2]);
    $$sum18 = (($123) + 18)|0;
    $140 = (($125) + ($$sum18<<2)|0);
    HEAPF32[$140>>2] = $139;
    $141 = Math_fround(HEAPF32[$85>>2]);
    $$sum19 = (($123) + 19)|0;
    $142 = (($125) + ($$sum19<<2)|0);
    HEAPF32[$142>>2] = $141;
    $143 = Math_fround(HEAPF32[$87>>2]);
    $$sum20 = (($123) + 20)|0;
    $144 = (($125) + ($$sum20<<2)|0);
    HEAPF32[$144>>2] = $143;
    $145 = Math_fround(HEAPF32[$89>>2]);
    $$sum21 = (($123) + 21)|0;
    $146 = (($125) + ($$sum21<<2)|0);
    HEAPF32[$146>>2] = $145;
    $147 = Math_fround(HEAPF32[$91>>2]);
    $$sum22 = (($123) + 22)|0;
    $148 = (($125) + ($$sum22<<2)|0);
    HEAPF32[$148>>2] = $147;
   }
   $149 = (($i$024) + 1)|0;
   $exitcond28 = ($149|0)==($22|0);
   if ($exitcond28) {
    break;
   } else {
    $i$024 = $149;
   }
  }
  $$pre = +HEAPF64[$worldBox>>3];
  $$pre29 = +HEAPF64[$6>>3];
  $$pre30 = +HEAPF64[$9>>3];
  $$pre31 = +HEAPF64[$11>>3];
  $$pre32 = +HEAPF64[$14>>3];
  $$pre33 = +HEAPF64[$16>>3];
  $157 = $$pre;$158 = $$pre29;$161 = $$pre30;$162 = $$pre31;$165 = $$pre32;$166 = $$pre33;
 }
 $150 = (($userObstacles) + 12|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = (($userObstacles) + 16|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = (($userObstacles) + 20|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = $158 - $157;
 $159 = Math_fround($156);
 $160 = $162 - $161;
 $163 = Math_fround($160);
 $164 = $166 - $165;
 $167 = Math_fround($164);
 $168 = (($Extents) + 4|0);
 $169 = (($Extents) + 8|0);
 $170 = Math_fround($159 * Math_fround(0.5));
 HEAPF32[$Extents>>2] = $170;
 $171 = Math_fround($163 * Math_fround(0.5));
 HEAPF32[$168>>2] = $171;
 $172 = Math_fround($167 * Math_fround(0.5));
 HEAPF32[$169>>2] = $172;
 $173 = ($151|0)==(0);
 if ($173) {
  STACKTOP = sp;return;
 }
 $174 = $165 + $166;
 $175 = $161 + $162;
 $176 = $157 + $158;
 $177 = $174 * 0.5;
 $178 = $175 * 0.5;
 $179 = $176 * 0.5;
 $180 = (($1) + 4|0);
 $181 = (($1) + 8|0);
 $182 = (($2) + 4|0);
 $183 = (($2) + 8|0);
 $184 = Math_fround($179);
 $185 = Math_fround($178);
 $186 = Math_fround($177);
 $187 = (($3) + 4|0);
 $188 = (($3) + 8|0);
 $189 = (($4) + 4|0);
 $190 = (($4) + 8|0);
 $191 = (($4) + 12|0);
 $192 = (($4) + 16|0);
 $193 = (($4) + 20|0);
 $194 = (($4) + 24|0);
 $195 = (($4) + 28|0);
 $196 = (($4) + 32|0);
 $197 = (($this) + 32|0);
 $198 = (($this) + 36|0);
 $211 = $158;$i1$023 = 0;
 while(1) {
  $199 = (($153) + (($i1$023*56)|0)|0);
  $200 = ((($153) + (($i1$023*56)|0)|0) + 48|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = +HEAPF64[$199>>3];
  $203 = ((($153) + (($i1$023*56)|0)|0) + 24|0);
  $204 = +HEAPF64[$203>>3];
  $205 = $202 < $204;
  $206 = $205 ? $202 : $204;
  $207 = Math_fround($206);
  $208 = Math_fround($207 - $201);
  $209 = +$208;
  $210 = $209 > $211;
  if (!($210)) {
   $212 = $205 ? $204 : $202;
   $213 = Math_fround($212);
   $214 = +HEAPF64[$worldBox>>3];
   $215 = Math_fround($201 + $213);
   $216 = +$215;
   $217 = $214 > $216;
   if (!($217)) {
    $218 = ((($153) + (($i1$023*56)|0)|0) + 8|0);
    $219 = +HEAPF64[$218>>3];
    $220 = ((($153) + (($i1$023*56)|0)|0) + 32|0);
    $221 = +HEAPF64[$220>>3];
    $222 = $219 < $221;
    $223 = $222 ? $219 : $221;
    $224 = Math_fround($223);
    $225 = Math_fround($224 - $201);
    $226 = +$225;
    $227 = +HEAPF64[$11>>3];
    $228 = $226 > $227;
    if (!($228)) {
     $229 = $222 ? $221 : $219;
     $230 = Math_fround($229);
     $231 = +HEAPF64[$9>>3];
     $232 = Math_fround($201 + $230);
     $233 = +$232;
     $234 = $231 > $233;
     if (!($234)) {
      $235 = ((($153) + (($i1$023*56)|0)|0) + 16|0);
      $236 = +HEAPF64[$235>>3];
      $237 = ((($153) + (($i1$023*56)|0)|0) + 40|0);
      $238 = +HEAPF64[$237>>3];
      $239 = $236 < $238;
      $240 = $239 ? $236 : $238;
      $241 = Math_fround($240);
      $242 = Math_fround($241 - $201);
      $243 = +$242;
      $244 = +HEAPF64[$16>>3];
      $245 = $243 > $244;
      if (!($245)) {
       $246 = $239 ? $238 : $236;
       $247 = Math_fround($246);
       $248 = +HEAPF64[$14>>3];
       $249 = Math_fround($201 + $247);
       $250 = +$249;
       $251 = $248 > $250;
       if (!($251)) {
        $252 = Math_fround($202);
        $253 = Math_fround($219);
        $254 = Math_fround($236);
        HEAPF32[$1>>2] = $252;
        HEAPF32[$180>>2] = $253;
        HEAPF32[$181>>2] = $254;
        $255 = Math_fround($204);
        $256 = Math_fround($221);
        $257 = Math_fround($238);
        HEAPF32[$2>>2] = $255;
        HEAPF32[$182>>2] = $256;
        HEAPF32[$183>>2] = $257;
        HEAPF32[$3>>2] = $184;
        HEAPF32[$187>>2] = $185;
        HEAPF32[$188>>2] = $186;
        HEAPF32[$4>>2] = Math_fround(1.0);
        HEAPF32[$189>>2] = Math_fround(0.0);
        HEAPF32[$190>>2] = Math_fround(0.0);
        HEAPF32[$191>>2] = Math_fround(0.0);
        HEAPF32[$192>>2] = Math_fround(1.0);
        HEAPF32[$193>>2] = Math_fround(0.0);
        HEAPF32[$194>>2] = Math_fround(0.0);
        HEAPF32[$195>>2] = Math_fround(0.0);
        HEAPF32[$196>>2] = Math_fround(1.0);
        $258 = (Math_fround(__ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($1,$2,$3,$Extents,$4,0,0)));
        $259 = Math_fround($201 * $201);
        $260 = $258 > $259;
        if (!($260)) {
         $261 = HEAP32[$198>>2]|0;
         $262 = (($261) + 24)|0;
         __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($197,$262);
         $263 = HEAP32[$197>>2]|0;
         $264 = (($263) + ($261<<2)|0);
         HEAP32[$264>>2] = 1;
         $265 = (($155) + ($i1$023<<2)|0);
         $266 = HEAP32[$265>>2]|0;
         $$sum = (($261) + 1)|0;
         $267 = (($263) + ($$sum<<2)|0);
         $$c = $266;
         HEAP32[$267>>2] = $$c;
         $$sum5 = (($261) + 2)|0;
         $268 = (($263) + ($$sum5<<2)|0);
         HEAP32[$268>>2] = 0;
         $$sum6 = (($261) + 4)|0;
         $269 = (($263) + ($$sum6<<2)|0);
         HEAPF64[$269>>3] = $19;
         $$sum7 = (($261) + 6)|0;
         $270 = (($263) + ($$sum7<<2)|0);
         HEAPF64[$270>>3] = $20;
         $$sum8 = (($261) + 8)|0;
         $271 = (($263) + ($$sum8<<2)|0);
         HEAPF64[$271>>3] = $21;
         $$sum9 = (($261) + 10)|0;
         $272 = (($263) + ($$sum9<<2)|0);
         dest=$272+0|0; src=$199+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        }
       }
      }
     }
    }
   }
  }
  $273 = (($i1$023) + 1)|0;
  $exitcond = ($273|0)==($151|0);
  if ($exitcond) {
   break;
  }
  $$pre35 = +HEAPF64[$6>>3];
  $211 = $$pre35;$i1$023 = $273;
 }
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest18updateTouchedGeomsEPKNS0_30InternalCBData_FindTouchedGeomERKNS0_13UserObstaclesERKNS_17PxExtendedBounds3ERKNS_19PxControllerFiltersERKNS_6PxVec3E($this,$userData,$userObstacles,$worldTemporalBox,$filters,$sideVector) {
 $this = $this|0;
 $userData = $userData|0;
 $userObstacles = $userObstacles|0;
 $worldTemporalBox = $worldTemporalBox|0;
 $filters = $filters|0;
 $sideVector = $sideVector|0;
 var $$pre = 0, $$pre$phi28Z2D = 0, $$pre$phiZ2D = 0, $$pre26 = 0, $$pre29 = 0, $$tr = 0, $$tr24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0;
 var $11 = 0, $110 = 0.0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0);
 var $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = Math_fround(0), $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = Math_fround(0), $143 = 0, $144 = 0.0, $145 = 0;
 var $146 = 0.0, $147 = 0.0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0.0, $158 = Math_fround(0), $159 = 0.0, $16 = 0, $160 = Math_fround(0), $161 = 0.0, $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0;
 var $182 = 0.0, $183 = 0, $184 = 0.0, $185 = 0, $186 = 0.0, $187 = 0, $188 = 0.0, $189 = 0, $19 = 0.0, $190 = 0.0, $191 = 0, $192 = 0.0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0.0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0.0, $235 = Math_fround(0);
 var $236 = 0, $237 = 0.0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0.0, $241 = Math_fround(0), $242 = 0, $243 = 0.0, $244 = Math_fround(0), $245 = 0, $246 = 0.0, $247 = Math_fround(0), $248 = 0, $249 = 0.0, $25 = 0.0, $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0.0, $262 = Math_fround(0), $263 = 0, $264 = 0.0, $265 = Math_fround(0), $266 = 0, $267 = 0.0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0.0, $271 = Math_fround(0);
 var $272 = 0, $273 = 0.0, $274 = Math_fround(0), $275 = 0, $276 = 0.0, $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = 0.0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0;
 var $35 = 0.0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = Math_fround(0), $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0;
 var $9 = 0, $90 = 0.0, $91 = Math_fround(0), $92 = 0.0, $93 = Math_fround(0), $94 = 0.0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i3 = Math_fround(0), $filter = 0, $newCachedBox$0$off0 = 0, $not$$i = 0, $or$cond = 0, $out = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $filter = sp + 160|0;
 $out = sp;
 $0 = sp + 104|0;
 $1 = sp + 132|0;
 ;HEAP32[$filter+0>>2]=0|0;HEAP32[$filter+4>>2]=0|0;HEAP32[$filter+8>>2]=0|0;HEAP32[$filter+12>>2]=0|0;
 $2 = HEAP32[$filters>>2]|0;
 HEAP32[$filter>>2] = $2;
 $3 = (($filters) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($filter) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($filters) + 8|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = (($filter) + 10|0);
 $9 = ($7&65535) >>> 2;
 $$tr = $9&255;
 $10 = $$tr & 1;
 HEAP8[$8>>0] = $10;
 $11 = (($filter) + 11|0);
 $12 = ($7&65535) >>> 3;
 $$tr24 = $12&255;
 $13 = $$tr24 & 1;
 HEAP8[$11>>0] = $13;
 $14 = (__ZN5physx3Cct17getSceneTimestampEPKNS0_30InternalCBData_FindTouchedGeomE($userData)|0);
 $15 = (($this) + 296|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($14|0)==($16|0);
 if ($17) {
  $18 = (($this) + 48|0);
  $19 = +HEAPF64[$18>>3];
  $20 = +HEAPF64[$worldTemporalBox>>3];
  $21 = $19 > $20;
  if ($21) {
   $$pre$phi28Z2D = $18;$$pre$phiZ2D = $18;
   label = 13;
  } else {
   $22 = (($this) + 56|0);
   $23 = +HEAPF64[$22>>3];
   $24 = (($worldTemporalBox) + 8|0);
   $25 = +HEAPF64[$24>>3];
   $26 = $23 > $25;
   if ($26) {
    $$pre$phi28Z2D = $18;$$pre$phiZ2D = $18;
    label = 13;
   } else {
    $27 = (($this) + 64|0);
    $28 = +HEAPF64[$27>>3];
    $29 = (($worldTemporalBox) + 16|0);
    $30 = +HEAPF64[$29>>3];
    $31 = $28 > $30;
    if ($31) {
     $$pre$phi28Z2D = $18;$$pre$phiZ2D = $18;
     label = 13;
    } else {
     $32 = (($this) + 72|0);
     $33 = +HEAPF64[$32>>3];
     $34 = (($worldTemporalBox) + 24|0);
     $35 = +HEAPF64[$34>>3];
     $36 = $33 < $35;
     if ($36) {
      $$pre$phi28Z2D = $18;$$pre$phiZ2D = $18;
      label = 13;
     } else {
      $37 = (($this) + 80|0);
      $38 = +HEAPF64[$37>>3];
      $39 = (($worldTemporalBox) + 32|0);
      $40 = +HEAPF64[$39>>3];
      $41 = $38 < $40;
      if ($41) {
       $$pre$phi28Z2D = $18;$$pre$phiZ2D = $18;
       label = 13;
      } else {
       $42 = (($this) + 88|0);
       $43 = +HEAPF64[$42>>3];
       $44 = (($worldTemporalBox) + 40|0);
       $45 = +HEAPF64[$44>>3];
       $not$$i = !($43 < $45);
       if ($not$$i) {
        $46 = (($this) + 308|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = $47 & 128;
        $49 = ($48|0)==(0);
        if ($49) {
         $newCachedBox$0$off0 = 0;
        } else {
         $50 = $47 & -129;
         HEAP32[$46>>2] = $50;
         $51 = (($this) + 32|0);
         $52 = (($this) + 112|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = (($this) + 36|0);
         HEAP32[$54>>2] = $53;
         $55 = (($this) + 8|0);
         $56 = (($this) + 116|0);
         $57 = HEAP32[$56>>2]|0;
         $58 = (($this) + 12|0);
         HEAP32[$58>>2] = $57;
         $59 = (($this) + 20|0);
         $60 = (($this) + 24|0);
         HEAP32[$60>>2] = $57;
         $61 = (($filter) + 8|0);
         HEAP8[$61>>0] = 0;
         $62 = HEAP16[$6>>1]|0;
         $63 = $62 & 2;
         $64 = ($63<<16>>16)==(0);
         if (!($64)) {
          $65 = (($filter) + 9|0);
          HEAP8[$65>>0] = 1;
         }
         $66 = (($this) + 224|0);
         $67 = (($this) + 304|0);
         __ZN5physx3Cct19findTouchedGeometryEPKNS0_30InternalCBData_FindTouchedGeomERKNS_17PxExtendedBounds3ERNS_6shdfnd5ArrayINS_10PxTriangleENS7_19ReflectionAllocatorIS9_EEEERNS8_IjNSA_IjEEEESG_RKNS0_9CCTFilterERKNS0_9CCTParamsERt($userData,$18,$55,$59,$51,$filter,$66,$67);
         __ZN5physx3Cct9SweepTest20findTouchedObstaclesERKNS0_13UserObstaclesERKNS_17PxExtendedBounds3E($this,$userObstacles,$18);
         $68 = (($this) + 302|0);
         $69 = HEAP16[$68>>1]|0;
         $70 = (($69) + 1)<<16>>16;
         HEAP16[$68>>1] = $70;
         $newCachedBox$0$off0 = 0;
        }
       } else {
        $$pre$phi28Z2D = $18;$$pre$phiZ2D = $18;
        label = 13;
       }
      }
     }
    }
   }
  }
 } else {
  HEAP32[$15>>2] = $14;
  $$pre26 = (($this) + 48|0);
  $$pre$phi28Z2D = $$pre26;$$pre$phiZ2D = $$pre26;
  label = 13;
 }
 if ((label|0) == 13) {
  dest=$$pre$phiZ2D+0|0; src=$worldTemporalBox+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $71 = (($this) + 288|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = +HEAPF64[$$pre$phi28Z2D>>3];
  $74 = (($this) + 72|0);
  $75 = +HEAPF64[$74>>3];
  $76 = $73 + $75;
  $77 = (($this) + 56|0);
  $78 = +HEAPF64[$77>>3];
  $79 = (($this) + 80|0);
  $80 = +HEAPF64[$79>>3];
  $81 = $78 + $80;
  $82 = (($this) + 64|0);
  $83 = +HEAPF64[$82>>3];
  $84 = (($this) + 88|0);
  $85 = +HEAPF64[$84>>3];
  $86 = $83 + $85;
  $87 = $76 * 0.5;
  $88 = $81 * 0.5;
  $89 = $86 * 0.5;
  $90 = $75 - $73;
  $91 = Math_fround($90);
  $92 = $80 - $78;
  $93 = Math_fround($92);
  $94 = $85 - $83;
  $95 = Math_fround($94);
  $96 = Math_fround($91 * Math_fround(0.5));
  $97 = Math_fround($93 * Math_fround(0.5));
  $98 = Math_fround($95 * Math_fround(0.5));
  $99 = Math_fround($72 * $96);
  $100 = Math_fround($72 * $97);
  $101 = Math_fround($72 * $98);
  $102 = +$99;
  $103 = $87 - $102;
  HEAPF64[$$pre$phi28Z2D>>3] = $103;
  $104 = +$100;
  $105 = $88 - $104;
  HEAPF64[$77>>3] = $105;
  $106 = +$101;
  $107 = $89 - $106;
  HEAPF64[$82>>3] = $107;
  $108 = $87 + $102;
  HEAPF64[$74>>3] = $108;
  $109 = $88 + $104;
  HEAPF64[$79>>3] = $109;
  $110 = $89 + $106;
  HEAPF64[$84>>3] = $110;
  $111 = Math_fround(HEAPF32[$sideVector>>2]);
  $112 = $111 == Math_fround(0.0);
  $113 = (($sideVector) + 4|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = $114 == Math_fround(0.0);
  $or$cond = $112 & $115;
  if ($or$cond) {
   $116 = (($sideVector) + 8|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = $117 == Math_fround(0.0);
   if (!($118)) {
    label = 15;
   }
  } else {
   label = 15;
  }
  if ((label|0) == 15) {
   $119 = Math_fround($111 * $111);
   $120 = Math_fround($114 * $114);
   $121 = Math_fround($119 + $120);
   $122 = (($sideVector) + 8|0);
   $123 = Math_fround(HEAPF32[$122>>2]);
   $124 = Math_fround($123 * $123);
   $125 = Math_fround($121 + $124);
   $126 = $125 > Math_fround(0.0);
   if ($126) {
    $127 = (Math_fround(Math_sqrt((Math_fround($125)))));
    $128 = Math_fround(Math_fround(1.0) / $127);
    $129 = Math_fround($111 * $128);
    $130 = Math_fround($114 * $128);
    $131 = Math_fround($123 * $128);
    $150 = $129;$152 = $130;$155 = $131;
   } else {
    $150 = Math_fround(0.0);$152 = Math_fround(0.0);$155 = Math_fround(0.0);
   }
   $132 = (($worldTemporalBox) + 24|0);
   $133 = +HEAPF64[$132>>3];
   $134 = +HEAPF64[$worldTemporalBox>>3];
   $135 = $133 - $134;
   $136 = Math_fround($135);
   $137 = (($worldTemporalBox) + 32|0);
   $138 = +HEAPF64[$137>>3];
   $139 = (($worldTemporalBox) + 8|0);
   $140 = +HEAPF64[$139>>3];
   $141 = $138 - $140;
   $142 = Math_fround($141);
   $143 = (($worldTemporalBox) + 40|0);
   $144 = +HEAPF64[$143>>3];
   $145 = (($worldTemporalBox) + 16|0);
   $146 = +HEAPF64[$145>>3];
   $147 = $144 - $146;
   $148 = Math_fround($147);
   $149 = Math_fround($150 * $136);
   $151 = Math_fround($152 * $142);
   $153 = Math_fround($149 + $151);
   $154 = Math_fround($155 * $148);
   $156 = Math_fround($153 + $154);
   $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($156)))));
   $157 = $108 - $103;
   $158 = Math_fround($157);
   $159 = $109 - $105;
   $160 = Math_fround($159);
   $161 = $110 - $107;
   $162 = Math_fround($161);
   $163 = Math_fround($150 * $158);
   $164 = Math_fround($152 * $160);
   $165 = Math_fround($163 + $164);
   $166 = Math_fround($155 * $162);
   $167 = Math_fround($165 + $166);
   $fabsf$i$i = (Math_fround(Math_abs((Math_fround($167)))));
   $168 = Math_fround($fabsf$i$i - $fabsf$i$i3);
   $169 = Math_fround($168 * Math_fround(0.449999988079071044922));
   $170 = Math_fround($150 * $169);
   $171 = Math_fround($152 * $169);
   $172 = Math_fround($155 * $169);
   $173 = +$170;
   $174 = $103 + $173;
   HEAPF64[$$pre$phi28Z2D>>3] = $174;
   $175 = +$171;
   $176 = $105 + $175;
   HEAPF64[$77>>3] = $176;
   $177 = +$172;
   $178 = $107 + $177;
   HEAPF64[$82>>3] = $178;
   $179 = $108 + $173;
   HEAPF64[$74>>3] = $179;
   $180 = $109 + $175;
   HEAPF64[$79>>3] = $180;
   $181 = $177 + $110;
   HEAPF64[$84>>3] = $181;
   $182 = +HEAPF64[$worldTemporalBox>>3];
   $183 = $174 > $182;
   if ($183) {
    HEAPF64[$$pre$phi28Z2D>>3] = $182;
   }
   $184 = +HEAPF64[$139>>3];
   $185 = $176 > $184;
   if ($185) {
    HEAPF64[$77>>3] = $184;
   }
   $186 = +HEAPF64[$145>>3];
   $187 = $178 > $186;
   if ($187) {
    HEAPF64[$82>>3] = $186;
   }
   $188 = +HEAPF64[$132>>3];
   $189 = $179 < $188;
   if ($189) {
    HEAPF64[$74>>3] = $188;
   }
   $190 = +HEAPF64[$137>>3];
   $191 = $180 < $190;
   if ($191) {
    HEAPF64[$79>>3] = $190;
   }
   $192 = +HEAPF64[$143>>3];
   $193 = $181 < $192;
   if ($193) {
    HEAPF64[$84>>3] = $192;
   }
  }
  $194 = (($this) + 8|0);
  $195 = (($this) + 12|0);
  HEAP32[$195>>2] = 0;
  $196 = (($this) + 20|0);
  $197 = (($this) + 24|0);
  HEAP32[$197>>2] = 0;
  $198 = (($this) + 32|0);
  $199 = (($this) + 36|0);
  HEAP32[$199>>2] = 0;
  $200 = (($this) + 96|0);
  $201 = (($this) + 300|0);
  ;HEAP32[$200+0>>2]=0|0;HEAP32[$200+4>>2]=0|0;HEAP32[$200+8>>2]=0|0;HEAP32[$200+12>>2]=0|0;
  $202 = HEAP16[$201>>1]|0;
  $203 = (($202) + 1)<<16>>16;
  HEAP16[$201>>1] = $203;
  $204 = HEAP16[$6>>1]|0;
  $205 = $204 & 1;
  $206 = ($205<<16>>16)==(0);
  $$pre29 = (($filter) + 8|0);
  if (!($206)) {
   HEAP8[$$pre29>>0] = 1;
  }
  $207 = (($filter) + 9|0);
  HEAP8[$207>>0] = 0;
  $208 = (($this) + 224|0);
  $209 = (($this) + 304|0);
  __ZN5physx3Cct19findTouchedGeometryEPKNS0_30InternalCBData_FindTouchedGeomERKNS_17PxExtendedBounds3ERNS_6shdfnd5ArrayINS_10PxTriangleENS7_19ReflectionAllocatorIS9_EEEERNS8_IjNSA_IjEEEESG_RKNS0_9CCTFilterERKNS0_9CCTParamsERt($userData,$$pre$phiZ2D,$194,$196,$198,$filter,$208,$209);
  $210 = HEAP32[$199>>2]|0;
  $211 = (($this) + 112|0);
  HEAP32[$211>>2] = $210;
  $212 = HEAP32[$195>>2]|0;
  $213 = (($this) + 116|0);
  HEAP32[$213>>2] = $212;
  HEAP8[$$pre29>>0] = 0;
  $214 = HEAP16[$6>>1]|0;
  $215 = $214 & 2;
  $216 = ($215<<16>>16)==(0);
  if (!($216)) {
   HEAP8[$207>>0] = 1;
  }
  __ZN5physx3Cct19findTouchedGeometryEPKNS0_30InternalCBData_FindTouchedGeomERKNS_17PxExtendedBounds3ERNS_6shdfnd5ArrayINS_10PxTriangleENS7_19ReflectionAllocatorIS9_EEEERNS8_IjNSA_IjEEEESG_RKNS0_9CCTFilterERKNS0_9CCTParamsERt($userData,$$pre$phiZ2D,$194,$196,$198,$filter,$208,$209);
  __ZN5physx3Cct9SweepTest20findTouchedObstaclesERKNS0_13UserObstaclesERKNS_17PxExtendedBounds3E($this,$userObstacles,$$pre$phiZ2D);
  $217 = (($this) + 308|0);
  $218 = HEAP32[$217>>2]|0;
  $219 = $218 & -129;
  HEAP32[$217>>2] = $219;
  $newCachedBox$0$off0 = 1;
 }
 $220 = HEAP32[$this>>2]|0;
 $221 = ($220|0)==(0|0);
 if ($221) {
  STACKTOP = sp;return;
 }
 $222 = (($out) + 36|0);
 dest=$out+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$222>>2] = Math_fround(1.0);
 $223 = (($out) + 40|0);
 $224 = (($out) + 56|0);
 ;HEAP32[$223+0>>2]=0|0;HEAP32[$223+4>>2]=0|0;HEAP32[$223+8>>2]=0|0;HEAP32[$223+12>>2]=0|0;
 HEAPF32[$224>>2] = Math_fround(1.0);
 $225 = (($out) + 60|0);
 $226 = (($out) + 76|0);
 ;HEAP32[$225+0>>2]=0|0;HEAP32[$225+4>>2]=0|0;HEAP32[$225+8>>2]=0|0;HEAP32[$225+12>>2]=0|0;
 HEAPF32[$226>>2] = Math_fround(1.0);
 $227 = (($out) + 80|0);
 $228 = (($out) + 96|0);
 ;HEAP32[$227+0>>2]=0|0;HEAP32[$227+4>>2]=0|0;HEAP32[$227+8>>2]=0|0;HEAP32[$227+12>>2]=0|0;
 HEAPF32[$228>>2] = Math_fround(1.0);
 $229 = (($out) + 100|0);
 HEAP32[$229>>2] = $220;
 $230 = (($this) + 4|0);
 $231 = HEAP32[$230>>2]|0;
 $232 = $231 & 1;
 $233 = ($232|0)==(0);
 if ($233) {
  $258 = $231;
 } else {
  (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
  $234 = +HEAPF64[$worldTemporalBox>>3];
  $235 = Math_fround($234);
  $236 = (($worldTemporalBox) + 8|0);
  $237 = +HEAPF64[$236>>3];
  $238 = Math_fround($237);
  $239 = (($worldTemporalBox) + 16|0);
  $240 = +HEAPF64[$239>>3];
  $241 = Math_fround($240);
  $242 = (($worldTemporalBox) + 24|0);
  $243 = +HEAPF64[$242>>3];
  $244 = Math_fround($243);
  $245 = (($worldTemporalBox) + 32|0);
  $246 = +HEAPF64[$245>>3];
  $247 = Math_fround($246);
  $248 = (($worldTemporalBox) + 40|0);
  $249 = +HEAPF64[$248>>3];
  $250 = Math_fround($249);
  HEAPF32[$0>>2] = $235;
  $251 = (($0) + 4|0);
  HEAPF32[$251>>2] = $238;
  $252 = (($0) + 8|0);
  HEAPF32[$252>>2] = $241;
  $253 = (($0) + 12|0);
  HEAPF32[$253>>2] = $244;
  $254 = (($0) + 16|0);
  HEAPF32[$254>>2] = $247;
  $255 = (($0) + 20|0);
  HEAPF32[$255>>2] = $250;
  $256 = (($0) + 24|0);
  HEAP8[$256>>0] = 1;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$0)|0);
  $$pre = HEAP32[$230>>2]|0;
  $258 = $$pre;
 }
 $257 = $258 & 2;
 $259 = ($257|0)==(0);
 if ($259) {
  STACKTOP = sp;return;
 }
 if ($newCachedBox$0$off0) {
  (__ZN5physx2Cm12RenderOutputlsEj($out,-65536)|0);
 } else {
  (__ZN5physx2Cm12RenderOutputlsEj($out,-16711936)|0);
 }
 $260 = (($this) + 48|0);
 $261 = +HEAPF64[$260>>3];
 $262 = Math_fround($261);
 $263 = (($this) + 56|0);
 $264 = +HEAPF64[$263>>3];
 $265 = Math_fround($264);
 $266 = (($this) + 64|0);
 $267 = +HEAPF64[$266>>3];
 $268 = Math_fround($267);
 $269 = (($this) + 72|0);
 $270 = +HEAPF64[$269>>3];
 $271 = Math_fround($270);
 $272 = (($this) + 80|0);
 $273 = +HEAPF64[$272>>3];
 $274 = Math_fround($273);
 $275 = (($this) + 88|0);
 $276 = +HEAPF64[$275>>3];
 $277 = Math_fround($276);
 HEAPF32[$1>>2] = $262;
 $278 = (($1) + 4|0);
 HEAPF32[$278>>2] = $265;
 $279 = (($1) + 8|0);
 HEAPF32[$279>>2] = $268;
 $280 = (($1) + 12|0);
 HEAPF32[$280>>2] = $271;
 $281 = (($1) + 16|0);
 HEAPF32[$281>>2] = $274;
 $282 = (($1) + 20|0);
 HEAPF32[$282>>2] = $277;
 $283 = (($1) + 24|0);
 HEAP8[$283>>0] = 1;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$1)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct9SweepTest11doSweepTestEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERKNS0_13UserObstaclesERNS0_11SweptVolumeERKNS_6PxVec3ESF_jPjfRKNS_19PxControllerFiltersENS0_9SweepPassE($this,$userData,$userHitData,$userObstacles,$swept_volume,$direction,$sideVector,$max_iter,$nb_collisions,$min_dist,$filters,$sweepPass) {
 $this = $this|0;
 $userData = $userData|0;
 $userHitData = $userHitData|0;
 $userObstacles = $userObstacles|0;
 $swept_volume = $swept_volume|0;
 $direction = $direction|0;
 $sideVector = $sideVector|0;
 $max_iter = $max_iter|0;
 $nb_collisions = $nb_collisions|0;
 $min_dist = Math_fround($min_dist);
 $filters = $filters|0;
 $sweepPass = $sweepPass|0;
 var $$0281 = 0, $$13 = 0, $$13$v = 0, $$2 = 0, $$not = 0, $$pre = 0.0, $$pre$i = 0, $$pre112 = 0.0, $$pre113 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = Math_fround(0), $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = Math_fround(0), $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0;
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0;
 var $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0;
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0.0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0.0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0.0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0.0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0.0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = 0.0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0.0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0);
 var $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0.0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0.0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0);
 var $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0);
 var $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0;
 var $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0;
 var $379 = 0, $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0.0;
 var $397 = Math_fround(0), $398 = 0.0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0.0, $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0.0, $412 = Math_fround(0), $413 = 0.0;
 var $414 = Math_fround(0), $415 = 0.0, $416 = Math_fround(0), $417 = 0, $418 = 0.0, $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = 0.0, $422 = Math_fround(0), $423 = 0, $424 = 0.0, $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = Math_fround(0);
 var $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0;
 var $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0);
 var $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = Math_fround(0);
 var $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = 0, $5 = Math_fround(0), $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0);
 var $504 = Math_fround(0), $505 = Math_fround(0), $506 = 0, $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = Math_fround(0), $512 = Math_fround(0), $513 = 0, $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = 0, $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = 0;
 var $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = 0.0, $53 = 0, $530 = 0.0, $531 = 0.0, $532 = 0.0, $533 = 0.0, $534 = 0.0, $535 = 0.0, $536 = 0.0, $537 = 0.0, $538 = 0.0, $539 = 0.0, $54 = 0;
 var $540 = 0.0, $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0);
 var $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0);
 var $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0);
 var $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0);
 var $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0;
 var $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0);
 var $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0);
 var $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = 0.0, $672 = Math_fround(0), $673 = 0.0, $674 = Math_fround(0), $675 = 0.0, $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0);
 var $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0);
 var $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0;
 var $720 = 0, $721 = 0, $722 = 0, $723 = Math_fround(0), $724 = 0, $725 = Math_fround(0), $726 = Math_fround(0), $727 = 0, $728 = Math_fround(0), $729 = 0, $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = 0, $733 = Math_fround(0), $734 = 0, $735 = Math_fround(0), $736 = Math_fround(0), $737 = 0, $738 = Math_fround(0);
 var $739 = Math_fround(0), $74 = 0, $740 = 0, $741 = Math_fround(0), $742 = Math_fround(0), $743 = 0, $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0);
 var $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = 0, $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = 0, $767 = 0, $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0);
 var $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0.0, $786 = Math_fround(0), $787 = 0.0, $788 = Math_fround(0), $789 = 0.0, $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0);
 var $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $800 = Math_fround(0), $801 = 0, $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = 0.0, $81 = 0;
 var $810 = 0.0, $811 = 0.0, $812 = 0.0, $813 = 0.0, $814 = 0.0, $815 = 0.0, $816 = 0.0, $817 = 0.0, $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0);
 var $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = 0, $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0);
 var $847 = Math_fround(0), $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0);
 var $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = 0, $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = 0, $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0);
 var $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = 0.0, $894 = 0.0, $895 = 0.0, $896 = 0.0, $897 = 0.0, $898 = 0.0, $899 = 0.0, $9 = 0, $90 = 0;
 var $900 = 0.0, $901 = 0.0, $902 = 0.0, $903 = 0.0, $904 = 0.0, $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = 0, $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0);
 var $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = 0.0, $924 = 0.0, $925 = 0.0, $926 = 0.0, $927 = 0.0, $928 = 0.0, $929 = 0, $93 = 0, $930 = 0, $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0);
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $C = 0, $C$i = 0, $Data$08$i = 0, $Data$09$i = 0, $Data$09$us$i = 0, $NbCollisions$062 = 0, $NbCollisions$079 = 0, $boxGeom$i = 0, $brmerge = 0, $brmerge$not = 0, $capsuleGeom$i = 0, $currentDirection = 0, $currentDirection$idx$val = Math_fround(0), $currentDirection$idx16$val = Math_fround(0);
 var $currentDirection$idx17$val = Math_fround(0), $currentPosition = 0, $currentPosition$idx$val = 0.0, $currentPosition$idx14$val = 0.0, $currentPosition$idx15$val = 0.0, $depth$i = 0, $gh$i = 0, $globalPose$i = 0, $hasMoved$0$off080 = 0, $hasMoved$1$off0 = 0, $isValid$1$off0$lcssa$i = 0, $isValid$1$off09$i = 0, $isValid$3$off0$i = 0, $mtd$i = 0, $nbIter$013$i = 0, $nbIter$1$lcssa$i = 0, $nbIter$110$i = 0, $nbIter$3$i = 0, $or$cond = 0, $or$cond$i = 0;
 var $preventVerticalMotion$0$off0 = 0, $preventVerticalMotion$1$off0 = 0, $stopSliding$0$off0 = 0, $switch = 0, $switch$i = 0, $switch$i20 = 0, $volumePose$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $0 = sp + 136|0;
 $1 = sp + 196|0;
 $gh$i = sp + 224|0;
 $globalPose$i = sp + 324|0;
 $mtd$i = sp + 356|0;
 $depth$i = sp + 352|0;
 $volumePose$i = sp + 264|0;
 $capsuleGeom$i = sp + 312|0;
 $boxGeom$i = sp + 296|0;
 $C$i = sp + 24|0;
 $currentPosition = sp;
 $currentDirection = sp + 184|0;
 $C = sp + 80|0;
 $2 = Math_fround(HEAPF32[$direction>>2]);
 $3 = $2 == Math_fround(0.0);
 $4 = (($direction) + 4|0);
 if ($3) {
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = $5 == Math_fround(0.0);
  if ($6) {
   $7 = (($direction) + 8|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = $8 == Math_fround(0.0);
   if ($9) {
    $$2 = 0;
    STACKTOP = sp;return ($$2|0);
   }
  }
 }
 $10 = (($this) + 308|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & -53;
 HEAP32[$10>>2] = $12;
 $13 = (($this) + 156|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 160|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 152|0);
 HEAP32[$15>>2] = -1;
 $16 = (($swept_volume) + 8|0);
 ;HEAP32[$currentPosition+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$currentPosition+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$currentPosition+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$currentPosition+12>>2]=HEAP32[$16+12>>2]|0;HEAP32[$currentPosition+16>>2]=HEAP32[$16+16>>2]|0;HEAP32[$currentPosition+20>>2]=HEAP32[$16+20>>2]|0;
 $17 = (($swept_volume) + 16|0);
 $18 = (($swept_volume) + 24|0);
 $19 = (($direction) + 8|0);
 $20 = ($max_iter|0)==(0);
 L6: do {
  if ($20) {
   $NbCollisions$062 = 0;$hasMoved$1$off0 = 0;
  } else {
   $21 = Math_fround(HEAPF32[$19>>2]);
   $22 = Math_fround(HEAPF32[$4>>2]);
   $23 = (($swept_volume) + 8|0);
   $24 = +$21;
   $25 = +$22;
   $26 = +$2;
   $27 = +HEAPF64[$18>>3];
   $28 = +HEAPF64[$17>>3];
   $29 = +HEAPF64[$23>>3];
   $30 = $27 + $24;
   $31 = $28 + $25;
   $32 = $29 + $26;
   $33 = (($this) + 306|0);
   $34 = (($currentPosition) + 8|0);
   $35 = (($currentPosition) + 16|0);
   $36 = (($currentDirection) + 4|0);
   $37 = (($currentDirection) + 8|0);
   $38 = (($this) + 260|0);
   $39 = (($C) + 36|0);
   $40 = (($this) + 282|0);
   $41 = (($C) + 40|0);
   $42 = (($C) + 44|0);
   $43 = (($C) + 48|0);
   $44 = (($this) + 32|0);
   $45 = (($this) + 36|0);
   $46 = (($swept_volume) + 36|0);
   $47 = (($C$i) + 36|0);
   $48 = (($C$i) + 40|0);
   $49 = (($C$i) + 44|0);
   $50 = (($C$i) + 24|0);
   $51 = (($C) + 24|0);
   $52 = (($C$i) + 28|0);
   $53 = (($C) + 28|0);
   $54 = (($C$i) + 32|0);
   $55 = (($C) + 32|0);
   $56 = ($sweepPass|0)==(3);
   $57 = (($userHitData) + 8|0);
   $58 = (($userHitData) + 12|0);
   $59 = ($sweepPass|0)==(2);
   $60 = (($C) + 8|0);
   $61 = (($C) + 16|0);
   $62 = (($this) + 212|0);
   $63 = (($this) + 216|0);
   $64 = (($this) + 220|0);
   $65 = (($this) + 200|0);
   $66 = (($this) + 204|0);
   $67 = (($this) + 208|0);
   $$not = ($sweepPass|0)!=(2);
   $68 = (($this) + 244|0);
   $69 = (($this) + 248|0);
   $70 = (($this) + 252|0);
   $71 = (($this) + 292|0);
   $72 = (($this) + 224|0);
   $73 = (($this) + 8|0);
   $74 = (($this) + 48|0);
   $75 = (($this) + 72|0);
   $76 = (($this) + 56|0);
   $77 = (($this) + 80|0);
   $78 = (($this) + 64|0);
   $79 = (($this) + 88|0);
   $80 = (($this) + 144|0);
   $81 = (($this) + 148|0);
   $82 = (($this) + 120|0);
   $83 = (($this) + 124|0);
   $84 = (($this) + 128|0);
   $85 = (($1) + 16|0);
   $86 = (($1) + 20|0);
   $87 = (($1) + 24|0);
   $88 = (($0) + 12|0);
   $89 = (($0) + 4|0);
   $90 = (($0) + 8|0);
   $91 = (($0) + 16|0);
   $92 = (($0) + 20|0);
   $93 = (($0) + 24|0);
   $94 = (($1) + 12|0);
   $95 = (($1) + 8|0);
   $96 = (($1) + 4|0);
   $97 = (($this) + 188|0);
   $98 = (($this) + 192|0);
   $99 = (($this) + 196|0);
   $100 = (($this) + 176|0);
   $101 = (($this) + 180|0);
   $102 = (($this) + 184|0);
   $103 = $sweepPass & -3;
   $104 = ($103|0)==(1);
   $105 = (($this) + 132|0);
   $106 = (($this) + 136|0);
   $107 = (($this) + 140|0);
   $108 = (($this) + 284|0);
   $$pre = +HEAPF64[$currentPosition>>3];
   $$pre112 = +HEAPF64[$34>>3];
   $$pre113 = +HEAPF64[$35>>3];
   $$0281 = $max_iter;$112 = $$pre;$113 = $32;$116 = $$pre112;$117 = $31;$120 = $$pre113;$121 = $30;$NbCollisions$079 = 0;$hasMoved$0$off080 = 0;
   while(1) {
    $109 = HEAP16[$33>>1]|0;
    $110 = (($109) + 1)<<16>>16;
    HEAP16[$33>>1] = $110;
    $111 = $113 - $112;
    $114 = Math_fround($111);
    $115 = $117 - $116;
    $118 = Math_fround($115);
    $119 = $121 - $120;
    $122 = Math_fround($119);
    HEAPF32[$currentDirection>>2] = $114;
    HEAPF32[$36>>2] = $118;
    HEAPF32[$37>>2] = $122;
    $123 = HEAP32[$swept_volume>>2]|0;
    $124 = (($123) + 8|0);
    $125 = HEAP32[$124>>2]|0;
    FUNCTION_TABLE_viiiii[$125 & 255]($swept_volume,$this,$0,$currentPosition,$currentDirection);
    __ZN5physx3Cct9SweepTest18updateTouchedGeomsEPKNS0_30InternalCBData_FindTouchedGeomERKNS0_13UserObstaclesERKNS_17PxExtendedBounds3ERKNS_19PxControllerFiltersERKNS_6PxVec3E($this,$userData,$userObstacles,$0,$filters,$sideVector);
    $126 = Math_fround(HEAPF32[$currentDirection>>2]);
    $127 = Math_fround($126 * $126);
    $128 = Math_fround(HEAPF32[$36>>2]);
    $129 = Math_fround($128 * $128);
    $130 = Math_fround($127 + $129);
    $131 = Math_fround(HEAPF32[$37>>2]);
    $132 = Math_fround($131 * $131);
    $133 = Math_fround($130 + $132);
    $134 = (Math_fround(Math_sqrt((Math_fround($133)))));
    $135 = !($134 <= $min_dist);
    if (!($135)) {
     $NbCollisions$062 = $NbCollisions$079;$hasMoved$1$off0 = $hasMoved$0$off080;
     break L6;
    }
    $136 = Math_fround(Math_fround(1.0) / $134);
    $137 = Math_fround($126 * $136);
    HEAPF32[$currentDirection>>2] = $137;
    $138 = Math_fround($136 * $128);
    HEAPF32[$36>>2] = $138;
    $139 = Math_fround($136 * $131);
    HEAPF32[$37>>2] = $139;
    $140 = Math_fround(HEAPF32[$direction>>2]);
    $141 = Math_fround($137 * $140);
    $142 = Math_fround(HEAPF32[$4>>2]);
    $143 = Math_fround($138 * $142);
    $144 = Math_fround($141 + $143);
    $145 = Math_fround(HEAPF32[$19>>2]);
    $146 = Math_fround($139 * $145);
    $147 = Math_fround($144 + $146);
    $148 = !($147 <= Math_fround(0.0));
    if (!($148)) {
     $NbCollisions$062 = $NbCollisions$079;$hasMoved$1$off0 = $hasMoved$0$off080;
     break L6;
    }
    $149 = Math_fround(HEAPF32[$38>>2]);
    $150 = Math_fround($134 + $149);
    HEAPF32[$39>>2] = $150;
    $151 = HEAP8[$40>>0]|0;
    HEAP32[$41>>2] = -1;
    HEAP32[$42>>2] = -1;
    HEAP32[$43>>2] = 0;
    $152 = HEAP32[$44>>2]|0;
    $153 = HEAP32[$45>>2]|0;
    $154 = (($152) + ($153<<2)|0);
    $155 = ($153|0)==(0);
    if ($155) {
     label = 77;
     break;
    }
    $156 = ($151<<24>>24)==(0);
    L13: do {
     if ($156) {
      $Data$09$us$i = $152;
      while(1) {
       $157 = HEAP32[$Data$09$us$i>>2]|0;
       $158 = HEAP32[$46>>2]|0;
       $159 = ((404592 + (($158*24)|0)|0) + ($157<<2)|0);
       $160 = HEAP32[$159>>2]|0;
       $161 = ($160|0)==(0|0);
       if (!($161)) {
        $162 = Math_fround(HEAPF32[$39>>2]);
        HEAPF32[$47>>2] = $162;
        HEAP32[$48>>2] = -1;
        HEAP32[$49>>2] = -1;
        $163 = (FUNCTION_TABLE_iiiiiii[$160 & 255]($this,$swept_volume,$Data$09$us$i,$currentPosition,$currentDirection,$C$i)|0);
        if ($163) {
         $164 = Math_fround(HEAPF32[$47>>2]);
         $165 = $164 == Math_fround(0.0);
         if (!($165)) {
          $166 = Math_fround(HEAPF32[$39>>2]);
          $167 = $164 < $166;
          if ($167) {
           ;HEAP32[$C+0>>2]=HEAP32[$C$i+0>>2]|0;HEAP32[$C+4>>2]=HEAP32[$C$i+4>>2]|0;HEAP32[$C+8>>2]=HEAP32[$C$i+8>>2]|0;HEAP32[$C+12>>2]=HEAP32[$C$i+12>>2]|0;HEAP32[$C+16>>2]=HEAP32[$C$i+16>>2]|0;HEAP32[$C+20>>2]=HEAP32[$C$i+20>>2]|0;
           $168 = Math_fround(HEAPF32[$50>>2]);
           HEAPF32[$51>>2] = $168;
           $169 = Math_fround(HEAPF32[$52>>2]);
           HEAPF32[$53>>2] = $169;
           $170 = Math_fround(HEAPF32[$54>>2]);
           HEAPF32[$55>>2] = $170;
           ;HEAP32[$39+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$47+8>>2]|0;
           HEAP32[$43>>2] = $Data$09$us$i;
           $171 = !($164 <= Math_fround(0.0));
           if (!($171)) {
            $211 = $Data$09$us$i;
            break L13;
           }
          }
         }
        }
       }
       $172 = HEAP32[$Data$09$us$i>>2]|0;
       $173 = (403952 + ($172<<2)|0);
       $174 = HEAP32[$173>>2]|0;
       $175 = (($174) + 7)|0;
       $176 = $175 & -8;
       $177 = (($Data$09$us$i) + ($176)|0);
       $178 = ($177|0)==($154|0);
       if ($178) {
        label = 25;
        break;
       } else {
        $Data$09$us$i = $177;
       }
      }
     } else {
      $Data$09$i = $152;
      L14: while(1) {
       $179 = HEAP32[$Data$09$i>>2]|0;
       $180 = HEAP32[$46>>2]|0;
       $181 = ((404592 + (($180*24)|0)|0) + ($179<<2)|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = ($182|0)==(0|0);
       do {
        if (!($183)) {
         $184 = Math_fround(HEAPF32[$39>>2]);
         HEAPF32[$47>>2] = $184;
         HEAP32[$48>>2] = -1;
         HEAP32[$49>>2] = -1;
         $185 = (FUNCTION_TABLE_iiiiiii[$182 & 255]($this,$swept_volume,$Data$09$i,$currentPosition,$currentDirection,$C$i)|0);
         if ($185) {
          $186 = Math_fround(HEAPF32[$47>>2]);
          $187 = $186 == Math_fround(0.0);
          if ($187) {
           $188 = HEAP32[$Data$09$i>>2]|0;
           $switch$i = ($188>>>0)<(2);
           if ($switch$i) {
            break;
           }
           $189 = (($Data$09$i) + 8|0);
           $190 = HEAP32[$189>>2]|0;
           $191 = (($190) + 4|0);
           $192 = HEAP16[$191>>1]|0;
           $193 = ($192<<16>>16)==(6);
           if ($193) {
            break L14;
           } else {
            break;
           }
          } else {
           $197 = Math_fround(HEAPF32[$39>>2]);
           $198 = $186 < $197;
           if (!($198)) {
            break;
           }
           ;HEAP32[$C+0>>2]=HEAP32[$C$i+0>>2]|0;HEAP32[$C+4>>2]=HEAP32[$C$i+4>>2]|0;HEAP32[$C+8>>2]=HEAP32[$C$i+8>>2]|0;HEAP32[$C+12>>2]=HEAP32[$C$i+12>>2]|0;HEAP32[$C+16>>2]=HEAP32[$C$i+16>>2]|0;HEAP32[$C+20>>2]=HEAP32[$C$i+20>>2]|0;
           $199 = Math_fround(HEAPF32[$50>>2]);
           HEAPF32[$51>>2] = $199;
           $200 = Math_fround(HEAPF32[$52>>2]);
           HEAPF32[$53>>2] = $200;
           $201 = Math_fround(HEAPF32[$54>>2]);
           HEAPF32[$55>>2] = $201;
           ;HEAP32[$39+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$47+8>>2]|0;
           HEAP32[$43>>2] = $Data$09$i;
           $202 = !($186 <= Math_fround(0.0));
           if ($202) {
            break;
           } else {
            $211 = $Data$09$i;
            break L13;
           }
          }
         }
        }
       } while(0);
       $203 = HEAP32[$Data$09$i>>2]|0;
       $204 = (403952 + ($203<<2)|0);
       $205 = HEAP32[$204>>2]|0;
       $206 = (($205) + 7)|0;
       $207 = $206 & -8;
       $208 = (($Data$09$i) + ($207)|0);
       $209 = ($208|0)==($154|0);
       if ($209) {
        label = 25;
        break L13;
       } else {
        $Data$09$i = $208;
       }
      }
      ;HEAP32[$C+0>>2]=HEAP32[$C$i+0>>2]|0;HEAP32[$C+4>>2]=HEAP32[$C$i+4>>2]|0;HEAP32[$C+8>>2]=HEAP32[$C$i+8>>2]|0;HEAP32[$C+12>>2]=HEAP32[$C$i+12>>2]|0;HEAP32[$C+16>>2]=HEAP32[$C$i+16>>2]|0;HEAP32[$C+20>>2]=HEAP32[$C$i+20>>2]|0;
      $194 = Math_fround(HEAPF32[$50>>2]);
      HEAPF32[$51>>2] = $194;
      $195 = Math_fround(HEAPF32[$52>>2]);
      HEAPF32[$53>>2] = $195;
      $196 = Math_fround(HEAPF32[$54>>2]);
      HEAPF32[$55>>2] = $196;
      ;HEAP32[$39+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$47+8>>2]|0;
      HEAP32[$43>>2] = $Data$09$i;
      $211 = $Data$09$i;
     }
    } while(0);
    if ((label|0) == 25) {
     label = 0;
     $$pre$i = HEAP32[$43>>2]|0;
     $211 = $$pre$i;
    }
    $210 = ($211|0)==(0|0);
    if ($210) {
     label = 77;
     break;
    }
    $212 = HEAP8[$40>>0]|0;
    $213 = ($212<<24>>24)==(0);
    if (!($213)) {
     $214 = Math_fround(HEAPF32[$39>>2]);
     $215 = $214 == Math_fround(0.0);
     if ($215) {
      break;
     }
    }
    $402 = HEAP32[$211>>2]|0;
    $switch = ($402>>>0)<(2);
    do {
     if ($switch) {
      if ($56) {
       $preventVerticalMotion$1$off0 = 0;$stopSliding$0$off0 = 1;
      } else {
       HEAP32[$57>>2] = 0;
       HEAP32[$58>>2] = -1;
       $403 = (__ZN5physx3Cct15userHitCallbackEPKNS0_20InternalCBData_OnHitERKNS0_12SweptContactERKNS_6PxVec3Ef($userHitData,$C,$currentDirection,$134)|0);
       $404 = $403 & 2;
       $405 = ($404|0)==(0);
       $406 = HEAP32[$57>>2]|0;
       $407 = HEAP32[$58>>2]|0;
       if ($59) {
        $408 = ($406|0)==(0|0);
        $409 = HEAP32[$10>>2]|0;
        if ($408) {
         $471 = $409 | 16;
         HEAP32[$10>>2] = $471;
         $preventVerticalMotion$1$off0 = 0;$stopSliding$0$off0 = $405;
         break;
        } else {
         $410 = $409 | 32;
         HEAP32[$10>>2] = $410;
         HEAP32[$15>>2] = $407;
         $411 = +HEAPF64[$C>>3];
         $412 = Math_fround($411);
         $413 = +HEAPF64[$60>>3];
         $414 = Math_fround($413);
         $415 = +HEAPF64[$61>>3];
         $416 = Math_fround($415);
         HEAPF32[$62>>2] = $412;
         HEAPF32[$63>>2] = $414;
         HEAPF32[$64>>2] = $416;
         $417 = (($406) + 8|0);
         $418 = +HEAPF64[$417>>3];
         $419 = Math_fround($418);
         $420 = (($406) + 16|0);
         $421 = +HEAPF64[$420>>3];
         $422 = Math_fround($421);
         $423 = (($406) + 24|0);
         $424 = +HEAPF64[$423>>3];
         $425 = Math_fround($424);
         $426 = (($406) + 32|0);
         $427 = Math_fround(HEAPF32[$426>>2]);
         $428 = (($406) + 36|0);
         $429 = Math_fround(HEAPF32[$428>>2]);
         $430 = (($406) + 40|0);
         $431 = Math_fround(HEAPF32[$430>>2]);
         $432 = (($406) + 44|0);
         $433 = Math_fround(HEAPF32[$432>>2]);
         $434 = Math_fround($412 - $419);
         $435 = Math_fround($414 - $422);
         $436 = Math_fround($416 - $425);
         $437 = Math_fround($434 * Math_fround(2.0));
         $438 = Math_fround($435 * Math_fround(2.0));
         $439 = Math_fround($436 * Math_fround(2.0));
         $440 = Math_fround($433 * $433);
         $441 = Math_fround($440 + Math_fround(-0.5));
         $442 = Math_fround($437 * $427);
         $443 = Math_fround($438 * $429);
         $444 = Math_fround($442 + $443);
         $445 = Math_fround($439 * $431);
         $446 = Math_fround($444 + $445);
         $447 = Math_fround($437 * $441);
         $448 = Math_fround($429 * $439);
         $449 = Math_fround($438 * $431);
         $450 = Math_fround($448 - $449);
         $451 = Math_fround($433 * $450);
         $452 = Math_fround($447 - $451);
         $453 = Math_fround($427 * $446);
         $454 = Math_fround($453 + $452);
         $455 = Math_fround($438 * $441);
         $456 = Math_fround($437 * $431);
         $457 = Math_fround($427 * $439);
         $458 = Math_fround($456 - $457);
         $459 = Math_fround($433 * $458);
         $460 = Math_fround($455 - $459);
         $461 = Math_fround($429 * $446);
         $462 = Math_fround($461 + $460);
         $463 = Math_fround($439 * $441);
         $464 = Math_fround($427 * $438);
         $465 = Math_fround($437 * $429);
         $466 = Math_fround($464 - $465);
         $467 = Math_fround($433 * $466);
         $468 = Math_fround($463 - $467);
         $469 = Math_fround($431 * $446);
         $470 = Math_fround($469 + $468);
         HEAPF32[$65>>2] = $454;
         HEAPF32[$66>>2] = $462;
         HEAPF32[$67>>2] = $470;
         $preventVerticalMotion$1$off0 = 0;$stopSliding$0$off0 = $405;
         break;
        }
       } else {
        $preventVerticalMotion$1$off0 = 0;$stopSliding$0$off0 = $405;
       }
      }
     } else {
      $472 = (($211) + 4|0);
      $473 = HEAP32[$472>>2]|0;
      $474 = (($211) + 8|0);
      $475 = HEAP32[$474>>2]|0;
      if ($59) {
       $476 = HEAP32[$10>>2]|0;
       $477 = $476 & -49;
       HEAP32[$10>>2] = $477;
       $478 = (($475) + 4|0);
       $479 = HEAP16[$478>>1]|0;
       $480 = ($479<<16>>16)==(6);
       if ($480) {
        $481 = HEAP32[$41>>2]|0;
        $482 = ($481|0)==(-1);
        if (!($482)) {
         $483 = $477 | 4;
         HEAP32[$10>>2] = $483;
         $484 = HEAP32[$73>>2]|0;
         $485 = (($484) + (($481*36)|0)|0);
         $486 = Math_fround(HEAPF32[$485>>2]);
         $487 = Math_fround(HEAPF32[$68>>2]);
         $488 = Math_fround($486 * $487);
         $489 = ((($484) + (($481*36)|0)|0) + 4|0);
         $490 = Math_fround(HEAPF32[$489>>2]);
         $491 = Math_fround(HEAPF32[$69>>2]);
         $492 = Math_fround($490 * $491);
         $493 = Math_fround($488 + $492);
         $494 = ((($484) + (($481*36)|0)|0) + 8|0);
         $495 = Math_fround(HEAPF32[$494>>2]);
         $496 = Math_fround(HEAPF32[$70>>2]);
         $497 = Math_fround($495 * $496);
         $498 = Math_fround($493 + $497);
         $499 = ((($484) + (($481*36)|0)|0) + 12|0);
         $500 = Math_fround(HEAPF32[$499>>2]);
         $501 = Math_fround($487 * $500);
         $502 = ((($484) + (($481*36)|0)|0) + 16|0);
         $503 = Math_fround(HEAPF32[$502>>2]);
         $504 = Math_fround($491 * $503);
         $505 = Math_fround($501 + $504);
         $506 = ((($484) + (($481*36)|0)|0) + 20|0);
         $507 = Math_fround(HEAPF32[$506>>2]);
         $508 = Math_fround($496 * $507);
         $509 = Math_fround($505 + $508);
         $510 = ((($484) + (($481*36)|0)|0) + 24|0);
         $511 = Math_fround(HEAPF32[$510>>2]);
         $512 = Math_fround($487 * $511);
         $513 = ((($484) + (($481*36)|0)|0) + 28|0);
         $514 = Math_fround(HEAPF32[$513>>2]);
         $515 = Math_fround($491 * $514);
         $516 = Math_fround($512 + $515);
         $517 = ((($484) + (($481*36)|0)|0) + 32|0);
         $518 = Math_fround(HEAPF32[$517>>2]);
         $519 = Math_fround($496 * $518);
         $520 = Math_fround($516 + $519);
         $521 = $498 < $509;
         $522 = $521 ? $498 : $509;
         $523 = $522 < $520;
         $524 = $523 ? $522 : $520;
         $525 = $498 > $509;
         $526 = $525 ? $498 : $509;
         $527 = $526 > $520;
         $528 = $527 ? $526 : $520;
         $529 = +HEAPF64[$74>>3];
         $530 = +HEAPF64[$75>>3];
         $531 = $529 + $530;
         $532 = +HEAPF64[$76>>3];
         $533 = +HEAPF64[$77>>3];
         $534 = $532 + $533;
         $535 = +HEAPF64[$78>>3];
         $536 = +HEAPF64[$79>>3];
         $537 = $535 + $536;
         $538 = $531 * 0.5;
         $539 = $534 * 0.5;
         $540 = $537 * 0.5;
         $541 = Math_fround($538);
         $542 = Math_fround($539);
         $543 = Math_fround($540);
         $544 = Math_fround($487 * $541);
         $545 = Math_fround($491 * $542);
         $546 = Math_fround($544 + $545);
         $547 = Math_fround($496 * $543);
         $548 = Math_fround($546 + $547);
         $549 = Math_fround($524 + $548);
         HEAPF32[$80>>2] = $549;
         $550 = Math_fround($528 + $548);
         HEAPF32[$81>>2] = $550;
         $551 = Math_fround(HEAPF32[$499>>2]);
         $552 = Math_fround(HEAPF32[$485>>2]);
         $553 = Math_fround($551 - $552);
         $554 = Math_fround(HEAPF32[$502>>2]);
         $555 = Math_fround(HEAPF32[$489>>2]);
         $556 = Math_fround($554 - $555);
         $557 = Math_fround(HEAPF32[$506>>2]);
         $558 = Math_fround(HEAPF32[$494>>2]);
         $559 = Math_fround($557 - $558);
         $560 = Math_fround(HEAPF32[$510>>2]);
         $561 = Math_fround($560 - $552);
         $562 = Math_fround(HEAPF32[$513>>2]);
         $563 = Math_fround($562 - $555);
         $564 = Math_fround(HEAPF32[$517>>2]);
         $565 = Math_fround($564 - $558);
         $566 = Math_fround($556 * $565);
         $567 = Math_fround($559 * $563);
         $568 = Math_fround($566 - $567);
         $569 = Math_fround($559 * $561);
         $570 = Math_fround($553 * $565);
         $571 = Math_fround($569 - $570);
         $572 = Math_fround($553 * $563);
         $573 = Math_fround($556 * $561);
         $574 = Math_fround($572 - $573);
         HEAPF32[$82>>2] = $568;
         HEAPF32[$83>>2] = $571;
         HEAPF32[$84>>2] = $574;
         $575 = Math_fround($568 * $568);
         $576 = Math_fround($571 * $571);
         $577 = Math_fround($575 + $576);
         $578 = Math_fround($574 * $574);
         $579 = Math_fround($578 + $577);
         $580 = (Math_fround(Math_sqrt((Math_fround($579)))));
         $581 = $580 > Math_fround(0.0);
         if ($581) {
          $582 = Math_fround(Math_fround(1.0) / $580);
          $583 = Math_fround($568 * $582);
          HEAPF32[$82>>2] = $583;
          $584 = Math_fround($571 * $582);
          HEAPF32[$83>>2] = $584;
          $585 = Math_fround($574 * $582);
          HEAPF32[$84>>2] = $585;
         }
        }
       }
       HEAP32[$13>>2] = $473;
       HEAP32[$14>>2] = $475;
       $586 = HEAP32[$475>>2]|0;
       $587 = (($586) + 84|0);
       $588 = HEAP32[$587>>2]|0;
       FUNCTION_TABLE_vii[$588 & 4095]($0,$475);
       $589 = HEAP32[$473>>2]|0;
       $590 = (($589) + 72|0);
       $591 = HEAP32[$590>>2]|0;
       FUNCTION_TABLE_vii[$591 & 4095]($1,$473);
       $592 = Math_fround(HEAPF32[$85>>2]);
       $593 = Math_fround($592 * Math_fround(2.0));
       $594 = Math_fround(HEAPF32[$86>>2]);
       $595 = Math_fround($594 * Math_fround(2.0));
       $596 = Math_fround(HEAPF32[$87>>2]);
       $597 = Math_fround($596 * Math_fround(2.0));
       $598 = Math_fround(HEAPF32[$88>>2]);
       $599 = Math_fround($598 * $598);
       $600 = Math_fround($599 + Math_fround(-0.5));
       $601 = Math_fround(HEAPF32[$0>>2]);
       $602 = Math_fround($593 * $601);
       $603 = Math_fround(HEAPF32[$89>>2]);
       $604 = Math_fround($595 * $603);
       $605 = Math_fround($602 + $604);
       $606 = Math_fround(HEAPF32[$90>>2]);
       $607 = Math_fround($597 * $606);
       $608 = Math_fround($605 + $607);
       $609 = Math_fround($593 * $600);
       $610 = Math_fround($597 * $603);
       $611 = Math_fround($595 * $606);
       $612 = Math_fround($610 - $611);
       $613 = Math_fround($598 * $612);
       $614 = Math_fround($609 + $613);
       $615 = Math_fround($601 * $608);
       $616 = Math_fround($615 + $614);
       $617 = Math_fround($595 * $600);
       $618 = Math_fround($593 * $606);
       $619 = Math_fround($597 * $601);
       $620 = Math_fround($618 - $619);
       $621 = Math_fround($598 * $620);
       $622 = Math_fround($617 + $621);
       $623 = Math_fround($603 * $608);
       $624 = Math_fround($623 + $622);
       $625 = Math_fround($597 * $600);
       $626 = Math_fround($595 * $601);
       $627 = Math_fround($593 * $603);
       $628 = Math_fround($626 - $627);
       $629 = Math_fround($598 * $628);
       $630 = Math_fround($625 + $629);
       $631 = Math_fround($606 * $608);
       $632 = Math_fround($630 + $631);
       $633 = Math_fround(HEAPF32[$91>>2]);
       $634 = Math_fround($633 + $616);
       $635 = Math_fround(HEAPF32[$92>>2]);
       $636 = Math_fround($635 + $624);
       $637 = Math_fround(HEAPF32[$93>>2]);
       $638 = Math_fround($637 + $632);
       $639 = Math_fround(HEAPF32[$1>>2]);
       $640 = Math_fround($598 * $639);
       $641 = Math_fround(HEAPF32[$94>>2]);
       $642 = Math_fround($601 * $641);
       $643 = Math_fround($640 + $642);
       $644 = Math_fround(HEAPF32[$95>>2]);
       $645 = Math_fround($603 * $644);
       $646 = Math_fround($643 + $645);
       $647 = Math_fround(HEAPF32[$96>>2]);
       $648 = Math_fround($606 * $647);
       $649 = Math_fround($646 - $648);
       $650 = Math_fround($598 * $647);
       $651 = Math_fround($603 * $641);
       $652 = Math_fround($651 + $650);
       $653 = Math_fround($606 * $639);
       $654 = Math_fround($653 + $652);
       $655 = Math_fround($601 * $644);
       $656 = Math_fround($654 - $655);
       $657 = Math_fround($598 * $644);
       $658 = Math_fround($606 * $641);
       $659 = Math_fround($658 + $657);
       $660 = Math_fround($601 * $647);
       $661 = Math_fround($660 + $659);
       $662 = Math_fround($603 * $639);
       $663 = Math_fround($661 - $662);
       $664 = Math_fround($598 * $641);
       $665 = Math_fround($601 * $639);
       $666 = Math_fround($664 - $665);
       $667 = Math_fround($603 * $647);
       $668 = Math_fround($666 - $667);
       $669 = Math_fround($606 * $644);
       $670 = Math_fround($668 - $669);
       $671 = +HEAPF64[$C>>3];
       $672 = Math_fround($671);
       $673 = +HEAPF64[$60>>3];
       $674 = Math_fround($673);
       $675 = +HEAPF64[$61>>3];
       $676 = Math_fround($675);
       HEAPF32[$97>>2] = $672;
       HEAPF32[$98>>2] = $674;
       HEAPF32[$99>>2] = $676;
       $677 = Math_fround($672 - $634);
       $678 = Math_fround($674 - $636);
       $679 = Math_fround($676 - $638);
       $680 = Math_fround($677 * Math_fround(2.0));
       $681 = Math_fround($678 * Math_fround(2.0));
       $682 = Math_fround($679 * Math_fround(2.0));
       $683 = Math_fround($670 * $670);
       $684 = Math_fround($683 + Math_fround(-0.5));
       $685 = Math_fround($649 * $680);
       $686 = Math_fround($656 * $681);
       $687 = Math_fround($685 + $686);
       $688 = Math_fround($663 * $682);
       $689 = Math_fround($687 + $688);
       $690 = Math_fround($684 * $680);
       $691 = Math_fround($656 * $682);
       $692 = Math_fround($663 * $681);
       $693 = Math_fround($691 - $692);
       $694 = Math_fround($670 * $693);
       $695 = Math_fround($690 - $694);
       $696 = Math_fround($649 * $689);
       $697 = Math_fround($696 + $695);
       $698 = Math_fround($684 * $681);
       $699 = Math_fround($663 * $680);
       $700 = Math_fround($649 * $682);
       $701 = Math_fround($699 - $700);
       $702 = Math_fround($670 * $701);
       $703 = Math_fround($698 - $702);
       $704 = Math_fround($656 * $689);
       $705 = Math_fround($704 + $703);
       $706 = Math_fround($684 * $682);
       $707 = Math_fround($649 * $681);
       $708 = Math_fround($656 * $680);
       $709 = Math_fround($707 - $708);
       $710 = Math_fround($670 * $709);
       $711 = Math_fround($706 - $710);
       $712 = Math_fround($663 * $689);
       $713 = Math_fround($711 + $712);
       HEAPF32[$100>>2] = $697;
       HEAPF32[$101>>2] = $705;
       HEAPF32[$102>>2] = $713;
       $preventVerticalMotion$0$off0 = 0;
      } else {
       if ($104) {
        $714 = (($475) + 4|0);
        $715 = HEAP16[$714>>1]|0;
        $716 = ($715<<16>>16)==(6);
        if ($716) {
         $717 = HEAP32[$41>>2]|0;
         $718 = ($717|0)==(-1);
         if ($718) {
          $preventVerticalMotion$0$off0 = 0;
         } else {
          $719 = HEAP32[$10>>2]|0;
          $720 = $719 | 8;
          HEAP32[$10>>2] = $720;
          $721 = HEAP32[$73>>2]|0;
          $722 = ((($721) + (($717*36)|0)|0) + 12|0);
          $723 = Math_fround(HEAPF32[$722>>2]);
          $724 = (($721) + (($717*36)|0)|0);
          $725 = Math_fround(HEAPF32[$724>>2]);
          $726 = Math_fround($723 - $725);
          $727 = ((($721) + (($717*36)|0)|0) + 16|0);
          $728 = Math_fround(HEAPF32[$727>>2]);
          $729 = ((($721) + (($717*36)|0)|0) + 4|0);
          $730 = Math_fround(HEAPF32[$729>>2]);
          $731 = Math_fround($728 - $730);
          $732 = ((($721) + (($717*36)|0)|0) + 20|0);
          $733 = Math_fround(HEAPF32[$732>>2]);
          $734 = ((($721) + (($717*36)|0)|0) + 8|0);
          $735 = Math_fround(HEAPF32[$734>>2]);
          $736 = Math_fround($733 - $735);
          $737 = ((($721) + (($717*36)|0)|0) + 24|0);
          $738 = Math_fround(HEAPF32[$737>>2]);
          $739 = Math_fround($738 - $725);
          $740 = ((($721) + (($717*36)|0)|0) + 28|0);
          $741 = Math_fround(HEAPF32[$740>>2]);
          $742 = Math_fround($741 - $730);
          $743 = ((($721) + (($717*36)|0)|0) + 32|0);
          $744 = Math_fround(HEAPF32[$743>>2]);
          $745 = Math_fround($744 - $735);
          $746 = Math_fround($731 * $745);
          $747 = Math_fround($736 * $742);
          $748 = Math_fround($746 - $747);
          $749 = Math_fround($736 * $739);
          $750 = Math_fround($726 * $745);
          $751 = Math_fround($749 - $750);
          $752 = Math_fround($726 * $742);
          $753 = Math_fround($731 * $739);
          $754 = Math_fround($752 - $753);
          HEAPF32[$105>>2] = $748;
          HEAPF32[$106>>2] = $751;
          HEAPF32[$107>>2] = $754;
          $755 = Math_fround($748 * $748);
          $756 = Math_fround($751 * $751);
          $757 = Math_fround($755 + $756);
          $758 = Math_fround($754 * $754);
          $759 = Math_fround($758 + $757);
          $760 = (Math_fround(Math_sqrt((Math_fround($759)))));
          $761 = $760 > Math_fround(0.0);
          if ($761) {
           $762 = Math_fround(Math_fround(1.0) / $760);
           $763 = Math_fround($748 * $762);
           HEAPF32[$105>>2] = $763;
           $764 = Math_fround($751 * $762);
           HEAPF32[$106>>2] = $764;
           $765 = Math_fround($754 * $762);
           HEAPF32[$107>>2] = $765;
           $770 = $763;$773 = $764;$777 = $765;
          } else {
           $770 = $748;$773 = $751;$777 = $754;
          }
          $766 = HEAP8[$108>>0]|0;
          $767 = ($766<<24>>24)==(0);
          if ($767) {
           $preventVerticalMotion$0$off0 = 0;
          } else {
           $768 = Math_fround(HEAPF32[$68>>2]);
           $769 = Math_fround($770 * $768);
           $771 = Math_fround(HEAPF32[$69>>2]);
           $772 = Math_fround($773 * $771);
           $774 = Math_fround($769 + $772);
           $775 = Math_fround(HEAPF32[$70>>2]);
           $776 = Math_fround($777 * $775);
           $778 = Math_fround($774 + $776);
           $779 = $778 < Math_fround(0.0);
           if ($779) {
            $preventVerticalMotion$0$off0 = 1;
           } else {
            $preventVerticalMotion$0$off0 = 0;
           }
          }
         }
        } else {
         $preventVerticalMotion$0$off0 = 0;
        }
       } else {
        $preventVerticalMotion$0$off0 = 0;
       }
      }
      if ($56) {
       $preventVerticalMotion$1$off0 = $preventVerticalMotion$0$off0;$stopSliding$0$off0 = 1;
      } else {
       $780 = (__ZN5physx3Cct16shapeHitCallbackEPKNS0_20InternalCBData_OnHitERKNS0_12SweptContactERKNS_6PxVec3Ef($userHitData,$C,$currentDirection,$134)|0);
       $781 = $780 & 2;
       $782 = ($781|0)==(0);
       $preventVerticalMotion$1$off0 = $preventVerticalMotion$0$off0;$stopSliding$0$off0 = $782;
      }
     }
    } while(0);
    $brmerge = $$not | $stopSliding$0$off0;
    $brmerge$not = $brmerge ^ 1;
    $783 = ($NbCollisions$079|0)==(0);
    $or$cond = $783 & $brmerge$not;
    $$13$v = $or$cond ? 8 : -1;
    $$13 = (($$13$v) + ($$0281))|0;
    $784 = (($NbCollisions$079) + 1)|0;
    $785 = +HEAPF64[$C>>3];
    $786 = Math_fround($785);
    $787 = +HEAPF64[$60>>3];
    $788 = Math_fround($787);
    $789 = +HEAPF64[$61>>3];
    $790 = Math_fround($789);
    $791 = Math_fround(HEAPF32[$68>>2]);
    $792 = Math_fround($786 * $791);
    $793 = Math_fround(HEAPF32[$69>>2]);
    $794 = Math_fround($788 * $793);
    $795 = Math_fround($792 + $794);
    $796 = Math_fround(HEAPF32[$70>>2]);
    $797 = Math_fround($790 * $796);
    $798 = Math_fround($795 + $797);
    HEAPF32[$71>>2] = $798;
    $799 = Math_fround(HEAPF32[$38>>2]);
    $800 = Math_fround(HEAPF32[$39>>2]);
    $801 = $800 > $799;
    if ($801) {
     $802 = Math_fround($800 - $799);
     $803 = Math_fround(HEAPF32[$currentDirection>>2]);
     $804 = Math_fround($802 * $803);
     $805 = Math_fround(HEAPF32[$36>>2]);
     $806 = Math_fround($802 * $805);
     $807 = Math_fround(HEAPF32[$37>>2]);
     $808 = Math_fround($802 * $807);
     $809 = +$804;
     $810 = +HEAPF64[$currentPosition>>3];
     $811 = $809 + $810;
     HEAPF64[$currentPosition>>3] = $811;
     $812 = +$806;
     $813 = +HEAPF64[$34>>3];
     $814 = $812 + $813;
     HEAPF64[$34>>3] = $814;
     $815 = +$808;
     $816 = +HEAPF64[$35>>3];
     $817 = $815 + $816;
     HEAPF64[$35>>3] = $817;
    }
    $818 = Math_fround(HEAPF32[$51>>2]);
    $819 = Math_fround(HEAPF32[$53>>2]);
    $820 = Math_fround(HEAPF32[$55>>2]);
    if ($preventVerticalMotion$1$off0) {
     label = 69;
    } else {
     $821 = HEAP32[$10>>2]|0;
     $822 = $821 & 2;
     $823 = ($822|0)==(0);
     if ($823) {
      $852 = $818;$854 = $819;$856 = $820;
     } else {
      $824 = HEAP32[$72>>2]|0;
      $825 = ($824|0)==(1);
      if ($825) {
       $852 = $818;$854 = $819;$856 = $820;
      } else {
       label = 69;
      }
     }
    }
    if ((label|0) == 69) {
     label = 0;
     $826 = Math_fround($818 * $791);
     $827 = Math_fround($819 * $793);
     $828 = Math_fround($826 + $827);
     $829 = Math_fround($820 * $796);
     $830 = Math_fround($828 + $829);
     $831 = Math_fround($791 * $830);
     $832 = Math_fround($793 * $830);
     $833 = Math_fround($796 * $830);
     $834 = Math_fround($818 - $831);
     $835 = Math_fround($819 - $832);
     $836 = Math_fround($820 - $833);
     $837 = Math_fround($834 * $834);
     $838 = Math_fround($835 * $835);
     $839 = Math_fround($837 + $838);
     $840 = Math_fround($836 * $836);
     $841 = Math_fround($840 + $839);
     $842 = (Math_fround(Math_sqrt((Math_fround($841)))));
     $843 = $842 > Math_fround(0.0);
     if ($843) {
      $844 = Math_fround(Math_fround(1.0) / $842);
      $845 = Math_fround($834 * $844);
      $846 = Math_fround($835 * $844);
      $847 = Math_fround($836 * $844);
      $852 = $845;$854 = $846;$856 = $847;
     } else {
      $852 = $834;$854 = $835;$856 = $836;
     }
    }
    $848 = HEAP32[$10>>2]|0;
    $849 = $848 & 64;
    $850 = ($849|0)==(0);
    $currentDirection$idx$val = Math_fround(HEAPF32[$currentDirection>>2]);
    $currentDirection$idx16$val = Math_fround(HEAPF32[$36>>2]);
    $currentDirection$idx17$val = Math_fround(HEAPF32[$37>>2]);
    $851 = Math_fround($852 * Math_fround(2.0));
    $853 = Math_fround($854 * Math_fround(2.0));
    $855 = Math_fround($856 * Math_fround(2.0));
    $857 = Math_fround($852 * $currentDirection$idx$val);
    $858 = Math_fround($854 * $currentDirection$idx16$val);
    $859 = Math_fround($857 + $858);
    $860 = Math_fround($856 * $currentDirection$idx17$val);
    $861 = Math_fround($859 + $860);
    $862 = Math_fround($851 * $861);
    $863 = Math_fround($853 * $861);
    $864 = Math_fround($855 * $861);
    $865 = Math_fround($currentDirection$idx$val - $862);
    $866 = Math_fround($currentDirection$idx16$val - $863);
    $867 = Math_fround($currentDirection$idx17$val - $864);
    $868 = Math_fround($865 * $865);
    $869 = Math_fround($866 * $866);
    $870 = Math_fround($868 + $869);
    $871 = Math_fround($867 * $867);
    $872 = Math_fround($871 + $870);
    $873 = (Math_fround(Math_sqrt((Math_fround($872)))));
    $874 = $873 > Math_fround(0.0);
    if ($874) {
     $875 = Math_fround(Math_fround(1.0) / $873);
     $876 = Math_fround($865 * $875);
     $877 = Math_fround($866 * $875);
     $878 = Math_fround($867 * $875);
     $880 = $876;$882 = $877;$885 = $878;
    } else {
     $880 = $865;$882 = $866;$885 = $867;
    }
    $879 = Math_fround($852 * $880);
    $881 = Math_fround($854 * $882);
    $883 = Math_fround($881 + $879);
    $884 = Math_fround($856 * $885);
    $886 = Math_fround($884 + $883);
    $887 = Math_fround($852 * $886);
    $888 = Math_fround($854 * $886);
    $889 = Math_fround($856 * $886);
    $890 = Math_fround($880 - $887);
    $891 = Math_fround($882 - $888);
    $892 = Math_fround($885 - $889);
    $893 = +HEAPF64[$currentPosition>>3];
    $894 = $113 - $893;
    $895 = +HEAPF64[$34>>3];
    $896 = $117 - $895;
    $897 = +HEAPF64[$35>>3];
    $898 = $121 - $897;
    $899 = $894 * $894;
    $900 = $896 * $896;
    $901 = $899 + $900;
    $902 = $898 * $898;
    $903 = $901 + $902;
    $904 = (+Math_sqrt((+$903)));
    if ($850) {
     $918 = $890;$920 = $891;$922 = $892;
    } else {
     $905 = Math_fround($890 * $890);
     $906 = Math_fround($891 * $891);
     $907 = Math_fround($905 + $906);
     $908 = Math_fround($892 * $892);
     $909 = Math_fround($908 + $907);
     $910 = (Math_fround(Math_sqrt((Math_fround($909)))));
     $911 = $910 > Math_fround(0.0);
     if ($911) {
      $912 = Math_fround(Math_fround(1.0) / $910);
      $913 = Math_fround($890 * $912);
      $914 = Math_fround($891 * $912);
      $915 = Math_fround($892 * $912);
      $918 = $913;$920 = $914;$922 = $915;
     } else {
      $918 = $890;$920 = $891;$922 = $892;
     }
    }
    $916 = Math_fround($904);
    $917 = Math_fround($916 * $918);
    $919 = Math_fround($916 * $920);
    $921 = Math_fround($916 * $922);
    $923 = +$917;
    $924 = $893 + $923;
    $925 = +$919;
    $926 = $895 + $925;
    $927 = +$921;
    $928 = $897 + $927;
    $929 = ($$13|0)==(0);
    if ($929) {
     $NbCollisions$062 = $784;$hasMoved$1$off0 = 1;
     break L6;
    } else {
     $$0281 = $$13;$112 = $893;$113 = $924;$116 = $895;$117 = $926;$120 = $897;$121 = $928;$NbCollisions$079 = $784;$hasMoved$0$off080 = 1;
    }
   }
   if ((label|0) == 77) {
    HEAPF64[$currentPosition>>3] = $113;
    HEAPF64[$34>>3] = $117;
    HEAPF64[$35>>3] = $121;
    $NbCollisions$062 = $NbCollisions$079;$hasMoved$1$off0 = 1;
    break;
   }
   $216 = Math_fround(HEAPF32[$38>>2]);
   $currentPosition$idx$val = +HEAPF64[$currentPosition>>3];
   $currentPosition$idx14$val = +HEAPF64[$34>>3];
   $currentPosition$idx15$val = +HEAPF64[$35>>3];
   $217 = Math_fround($currentPosition$idx$val);
   $218 = Math_fround($currentPosition$idx14$val);
   $219 = Math_fround($currentPosition$idx15$val);
   $220 = (($1) + 16|0);
   $221 = (($1) + 20|0);
   $222 = (($1) + 24|0);
   $223 = (($0) + 12|0);
   $224 = (($0) + 4|0);
   $225 = (($0) + 8|0);
   $226 = (($0) + 16|0);
   $227 = (($0) + 20|0);
   $228 = (($0) + 24|0);
   $229 = (($1) + 12|0);
   $230 = (($1) + 8|0);
   $231 = (($1) + 4|0);
   $232 = (($globalPose$i) + 4|0);
   $233 = (($globalPose$i) + 8|0);
   $234 = (($globalPose$i) + 12|0);
   $235 = (($globalPose$i) + 16|0);
   $236 = (($globalPose$i) + 20|0);
   $237 = (($globalPose$i) + 24|0);
   $238 = (($this) + 228|0);
   $239 = (($volumePose$i) + 4|0);
   $240 = (($this) + 232|0);
   $241 = (($volumePose$i) + 8|0);
   $242 = (($this) + 236|0);
   $243 = (($volumePose$i) + 12|0);
   $244 = (($this) + 240|0);
   $245 = (($volumePose$i) + 16|0);
   $246 = (($volumePose$i) + 20|0);
   $247 = (($volumePose$i) + 24|0);
   $248 = (($swept_volume) + 40|0);
   $249 = (($swept_volume) + 44|0);
   $250 = (($capsuleGeom$i) + 4|0);
   $251 = (($capsuleGeom$i) + 8|0);
   $252 = (($mtd$i) + 4|0);
   $253 = (($mtd$i) + 8|0);
   $254 = (($248) + 4|0);
   $255 = (($swept_volume) + 48|0);
   $256 = (($boxGeom$i) + 4|0);
   $257 = (($boxGeom$i) + 8|0);
   $258 = (($boxGeom$i) + 12|0);
   $931 = $219;$932 = $218;$933 = $217;$nbIter$013$i = 0;
   while(1) {
    $260 = HEAP32[$44>>2]|0;
    $261 = HEAP32[$45>>2]|0;
    $262 = (($260) + ($261<<2)|0);
    $263 = ($261|0)==(0);
    if ($263) {
     $397 = $933;$399 = $932;$401 = $931;$isValid$1$off0$lcssa$i = 1;$nbIter$1$lcssa$i = $nbIter$013$i;
    } else {
     $364 = $933;$365 = $932;$366 = $931;$Data$08$i = $260;$isValid$1$off09$i = 1;$nbIter$110$i = $nbIter$013$i;
     while(1) {
      $264 = HEAP32[$Data$08$i>>2]|0;
      $switch$i20 = ($264>>>0)<(2);
      do {
       if ($switch$i20) {
        $934 = $366;$935 = $365;$936 = $364;$isValid$3$off0$i = $isValid$1$off09$i;$nbIter$3$i = $nbIter$110$i;
       } else {
        $265 = (($Data$08$i) + 8|0);
        $266 = HEAP32[$265>>2]|0;
        $267 = (($266) + 4|0);
        $268 = HEAP16[$267>>1]|0;
        $269 = ($268<<16>>16)==(6);
        if ($269) {
         $270 = (($Data$08$i) + 4|0);
         $271 = HEAP32[$270>>2]|0;
         $272 = HEAP32[$271>>2]|0;
         $273 = (($272) + 32|0);
         $274 = HEAP32[$273>>2]|0;
         FUNCTION_TABLE_vii[$274 & 4095]($gh$i,$271);
         $275 = HEAP32[$266>>2]|0;
         $276 = (($275) + 84|0);
         $277 = HEAP32[$276>>2]|0;
         FUNCTION_TABLE_vii[$277 & 4095]($0,$266);
         $278 = HEAP32[$271>>2]|0;
         $279 = (($278) + 72|0);
         $280 = HEAP32[$279>>2]|0;
         FUNCTION_TABLE_vii[$280 & 4095]($1,$271);
         $281 = Math_fround(HEAPF32[$220>>2]);
         $282 = Math_fround($281 * Math_fround(2.0));
         $283 = Math_fround(HEAPF32[$221>>2]);
         $284 = Math_fround($283 * Math_fround(2.0));
         $285 = Math_fround(HEAPF32[$222>>2]);
         $286 = Math_fround($285 * Math_fround(2.0));
         $287 = Math_fround(HEAPF32[$223>>2]);
         $288 = Math_fround($287 * $287);
         $289 = Math_fround($288 + Math_fround(-0.5));
         $290 = Math_fround(HEAPF32[$0>>2]);
         $291 = Math_fround($282 * $290);
         $292 = Math_fround(HEAPF32[$224>>2]);
         $293 = Math_fround($284 * $292);
         $294 = Math_fround($291 + $293);
         $295 = Math_fround(HEAPF32[$225>>2]);
         $296 = Math_fround($286 * $295);
         $297 = Math_fround($294 + $296);
         $298 = Math_fround($282 * $289);
         $299 = Math_fround($286 * $292);
         $300 = Math_fround($284 * $295);
         $301 = Math_fround($299 - $300);
         $302 = Math_fround($287 * $301);
         $303 = Math_fround($298 + $302);
         $304 = Math_fround($290 * $297);
         $305 = Math_fround($304 + $303);
         $306 = Math_fround($284 * $289);
         $307 = Math_fround($282 * $295);
         $308 = Math_fround($286 * $290);
         $309 = Math_fround($307 - $308);
         $310 = Math_fround($287 * $309);
         $311 = Math_fround($306 + $310);
         $312 = Math_fround($292 * $297);
         $313 = Math_fround($312 + $311);
         $314 = Math_fround($286 * $289);
         $315 = Math_fround($284 * $290);
         $316 = Math_fround($282 * $292);
         $317 = Math_fround($315 - $316);
         $318 = Math_fround($287 * $317);
         $319 = Math_fround($314 + $318);
         $320 = Math_fround($295 * $297);
         $321 = Math_fround($319 + $320);
         $322 = Math_fround(HEAPF32[$226>>2]);
         $323 = Math_fround($322 + $305);
         $324 = Math_fround(HEAPF32[$227>>2]);
         $325 = Math_fround($324 + $313);
         $326 = Math_fround(HEAPF32[$228>>2]);
         $327 = Math_fround($326 + $321);
         $328 = Math_fround(HEAPF32[$1>>2]);
         $329 = Math_fround($287 * $328);
         $330 = Math_fround(HEAPF32[$229>>2]);
         $331 = Math_fround($290 * $330);
         $332 = Math_fround($329 + $331);
         $333 = Math_fround(HEAPF32[$230>>2]);
         $334 = Math_fround($292 * $333);
         $335 = Math_fround($332 + $334);
         $336 = Math_fround(HEAPF32[$231>>2]);
         $337 = Math_fround($295 * $336);
         $338 = Math_fround($335 - $337);
         $339 = Math_fround($287 * $336);
         $340 = Math_fround($292 * $330);
         $341 = Math_fround($340 + $339);
         $342 = Math_fround($295 * $328);
         $343 = Math_fround($342 + $341);
         $344 = Math_fround($290 * $333);
         $345 = Math_fround($343 - $344);
         $346 = Math_fround($287 * $333);
         $347 = Math_fround($295 * $330);
         $348 = Math_fround($347 + $346);
         $349 = Math_fround($290 * $336);
         $350 = Math_fround($349 + $348);
         $351 = Math_fround($292 * $328);
         $352 = Math_fround($350 - $351);
         $353 = Math_fround($287 * $330);
         $354 = Math_fround($290 * $328);
         $355 = Math_fround($353 - $354);
         $356 = Math_fround($292 * $336);
         $357 = Math_fround($355 - $356);
         $358 = Math_fround($295 * $333);
         $359 = Math_fround($357 - $358);
         HEAPF32[$globalPose$i>>2] = $338;
         HEAPF32[$232>>2] = $345;
         HEAPF32[$233>>2] = $352;
         HEAPF32[$234>>2] = $359;
         HEAPF32[$235>>2] = $323;
         HEAPF32[$236>>2] = $325;
         HEAPF32[$237>>2] = $327;
         $360 = Math_fround(HEAPF32[$238>>2]);
         HEAPF32[$volumePose$i>>2] = $360;
         $361 = Math_fround(HEAPF32[$240>>2]);
         HEAPF32[$239>>2] = $361;
         $362 = Math_fround(HEAPF32[$242>>2]);
         HEAPF32[$241>>2] = $362;
         $363 = Math_fround(HEAPF32[$244>>2]);
         HEAPF32[$243>>2] = $363;
         HEAPF32[$245>>2] = $364;
         HEAPF32[$246>>2] = $365;
         HEAPF32[$247>>2] = $366;
         $367 = HEAP32[$46>>2]|0;
         $368 = ($367|0)==(1);
         $369 = Math_fround(HEAPF32[$248>>2]);
         $370 = Math_fround($216 + $369);
         if ($368) {
          $371 = Math_fround(HEAPF32[$249>>2]);
          $372 = Math_fround($371 * Math_fround(0.5));
          HEAP32[$capsuleGeom$i>>2] = 2;
          HEAPF32[$250>>2] = $370;
          HEAPF32[$251>>2] = $372;
          $373 = (__ZN5physx15PxGeometryQuery18computePenetrationERNS_6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_($mtd$i,$depth$i,$capsuleGeom$i,$volumePose$i,$gh$i,$globalPose$i)|0);
          if (!($373)) {
           $934 = $366;$935 = $365;$936 = $364;$isValid$3$off0$i = 0;$nbIter$3$i = $nbIter$110$i;
           break;
          }
         } else {
          $374 = Math_fround(HEAPF32[$254>>2]);
          $375 = Math_fround($216 + $374);
          $376 = Math_fround(HEAPF32[$255>>2]);
          $377 = Math_fround($216 + $376);
          HEAP32[$boxGeom$i>>2] = 3;
          HEAPF32[$256>>2] = $370;
          HEAPF32[$257>>2] = $375;
          HEAPF32[$258>>2] = $377;
          $378 = (__ZN5physx15PxGeometryQuery18computePenetrationERNS_6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_($mtd$i,$depth$i,$boxGeom$i,$volumePose$i,$gh$i,$globalPose$i)|0);
          if (!($378)) {
           $934 = $366;$935 = $365;$936 = $364;$isValid$3$off0$i = 0;$nbIter$3$i = $nbIter$110$i;
           break;
          }
         }
         $379 = (($nbIter$110$i) + 1)|0;
         $380 = Math_fround(HEAPF32[$depth$i>>2]);
         $381 = Math_fround(HEAPF32[$mtd$i>>2]);
         $382 = Math_fround($380 * $381);
         $383 = Math_fround(HEAPF32[$252>>2]);
         $384 = Math_fround($380 * $383);
         $385 = Math_fround(HEAPF32[$253>>2]);
         $386 = Math_fround($380 * $385);
         $387 = Math_fround($364 + $382);
         $388 = Math_fround($365 + $384);
         $389 = Math_fround($366 + $386);
         $934 = $389;$935 = $388;$936 = $387;$isValid$3$off0$i = 1;$nbIter$3$i = $379;
        } else {
         $934 = $366;$935 = $365;$936 = $364;$isValid$3$off0$i = $isValid$1$off09$i;$nbIter$3$i = $nbIter$110$i;
        }
       }
      } while(0);
      $390 = HEAP32[$Data$08$i>>2]|0;
      $391 = (403952 + ($390<<2)|0);
      $392 = HEAP32[$391>>2]|0;
      $393 = (($Data$08$i) + ($392)|0);
      $394 = ($393|0)==($262|0);
      if ($394) {
       $397 = $936;$399 = $935;$401 = $934;$isValid$1$off0$lcssa$i = $isValid$3$off0$i;$nbIter$1$lcssa$i = $nbIter$3$i;
       break;
      } else {
       $364 = $936;$365 = $935;$366 = $934;$Data$08$i = $393;$isValid$1$off09$i = $isValid$3$off0$i;$nbIter$110$i = $nbIter$3$i;
      }
     }
    }
    $259 = ($nbIter$1$lcssa$i>>>0)<(4);
    $or$cond$i = $isValid$1$off0$lcssa$i & $259;
    if ($or$cond$i) {
     $931 = $401;$932 = $399;$933 = $397;$nbIter$013$i = $nbIter$1$lcssa$i;
    } else {
     break;
    }
   }
   $395 = ($nb_collisions|0)==(0|0);
   if (!($395)) {
    HEAP32[$nb_collisions>>2] = $NbCollisions$079;
   }
   $396 = +$397;
   HEAPF64[$16>>3] = $396;
   $398 = +$399;
   HEAPF64[$17>>3] = $398;
   $400 = +$401;
   HEAPF64[$18>>3] = $400;
   $$2 = 1;
   STACKTOP = sp;return ($$2|0);
  }
 } while(0);
 $930 = ($nb_collisions|0)==(0|0);
 if (!($930)) {
  HEAP32[$nb_collisions>>2] = $NbCollisions$062;
 }
 ;HEAP32[$16+0>>2]=HEAP32[$currentPosition+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$currentPosition+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$currentPosition+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$currentPosition+12>>2]|0;HEAP32[$16+16>>2]=HEAP32[$currentPosition+16>>2]|0;HEAP32[$16+20>>2]=HEAP32[$currentPosition+20>>2]|0;
 $$2 = $hasMoved$1$off0;
 STACKTOP = sp;return ($$2|0);
}
function __ZN5physx3Cct9SweepTest13moveCharacterEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERNS0_11SweptVolumeERKNS_6PxVec3ERKNS0_13UserObstaclesEfRKNS_19PxControllerFiltersEbb($agg$result,$this,$userData,$userHitData,$volume,$direction,$userObstacles,$min_dist,$filters,$constrainedClimbingMode,$standingOnMoving) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $userData = $userData|0;
 $userHitData = $userHitData|0;
 $volume = $volume|0;
 $direction = $direction|0;
 $userObstacles = $userObstacles|0;
 $min_dist = Math_fround($min_dist);
 $filters = $filters|0;
 $constrainedClimbingMode = $constrainedClimbingMode|0;
 $standingOnMoving = $standingOnMoving|0;
 var $$ = Math_fround(0), $$not = 0, $$not10 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = Math_fround(0), $102 = 0.0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0.0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0.0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0.0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0.0, $209 = 0.0, $21 = Math_fround(0), $210 = 0.0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0.0, $223 = 0.0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0.0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0.0, $252 = Math_fround(0), $253 = 0.0, $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0.0, $262 = 0.0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0.0, $273 = 0.0;
 var $274 = 0.0, $275 = 0.0, $276 = 0, $277 = 0.0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0.0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0;
 var $3 = 0, $30 = 0.0, $31 = 0, $32 = Math_fround(0), $33 = 0.0, $34 = 0.0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0.0;
 var $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0);
 var $84 = 0.0, $85 = 0, $86 = Math_fround(0), $87 = 0.0, $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = Math_fround(0), $DownVector = 0, $NbCollisions = 0, $RecoverPoint = 0;
 var $SideVector = 0, $UpVector = 0, $brmerge = 0, $brmerge11 = 0, $constrainedClimbingMode$not = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i13 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i14 = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i2$i15 = Math_fround(0), $maxIterUp$0 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond39 = 0, $or$cond5 = 0, $phitmp = 0, $saved = 0, $sensor = 0, $stepOffset$0 = Math_fround(0);
 var $stepOffset$1 = Math_fround(0), $temporalBox = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $UpVector = sp + 124|0;
 $DownVector = sp + 100|0;
 $SideVector = sp + 72|0;
 $temporalBox = sp;
 $NbCollisions = sp + 84|0;
 $sensor = sp + 88|0;
 $saved = sp + 48|0;
 $RecoverPoint = sp + 112|0;
 $0 = (($this) + 308|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -2;
 HEAP32[$0>>2] = $2;
 HEAP8[$agg$result>>0] = 0;
 $3 = $1 & 2;
 $4 = ($3|0)==(0);
 if ($4) {
  $175 = 1;
 } else {
  $5 = (($this) + 224|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(1);
  $phitmp = $7 ? 10 : 1;
  $175 = $phitmp;
 }
 $8 = (($this) + 264|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($volume) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = Math_fround($11);
 $13 = (($volume) + 16|0);
 $14 = +HEAPF64[$13>>3];
 $15 = Math_fround($14);
 $16 = (($volume) + 24|0);
 $17 = +HEAPF64[$16>>3];
 $18 = Math_fround($17);
 $19 = (($this) + 244|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($12 * $20);
 $22 = (($this) + 248|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($15 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($this) + 252|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($18 * $27);
 $29 = Math_fround($25 + $28);
 $30 = +$29;
 $31 = (($volume) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = +$32;
 $34 = $30 - $33;
 $35 = Math_fround(HEAPF32[$direction>>2]);
 $36 = Math_fround($20 * $35);
 $37 = (($direction) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($23 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($direction) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($27 * $42);
 $44 = Math_fround($40 + $43);
 $45 = $44 > Math_fround(0.0);
 if ($45) {
  $46 = $2 | 256;
  HEAP32[$0>>2] = $46;
  $$ = $standingOnMoving ? $9 : Math_fround(0.0);
  $stepOffset$0 = $$;
 } else {
  $47 = $1 & -258;
  HEAP32[$0>>2] = $47;
  $stepOffset$0 = $9;
 }
 HEAPF32[$UpVector>>2] = Math_fround(0.0);
 $48 = (($UpVector) + 4|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($UpVector) + 8|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 HEAPF32[$DownVector>>2] = Math_fround(0.0);
 $50 = (($DownVector) + 4|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($DownVector) + 8|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = Math_fround($20 * $44);
 $53 = Math_fround($23 * $44);
 $54 = Math_fround($27 * $44);
 $55 = Math_fround($35 - $52);
 $56 = Math_fround($38 - $53);
 $57 = Math_fround($42 - $54);
 $58 = $44 <= Math_fround(0.0);
 if ($58) {
  HEAPF32[$DownVector>>2] = $52;
  HEAPF32[$50>>2] = $53;
  HEAPF32[$51>>2] = $54;
  $165 = $52;$167 = $53;$169 = $54;$71 = Math_fround(0.0);$73 = Math_fround(0.0);$75 = Math_fround(0.0);
 } else {
  HEAPF32[$UpVector>>2] = $52;
  HEAPF32[$48>>2] = $53;
  HEAPF32[$49>>2] = $54;
  $165 = Math_fround(0.0);$167 = Math_fround(0.0);$169 = Math_fround(0.0);$71 = $52;$73 = $53;$75 = $54;
 }
 HEAPF32[$SideVector>>2] = $55;
 $59 = (($SideVector) + 4|0);
 HEAPF32[$59>>2] = $56;
 $60 = (($SideVector) + 8|0);
 HEAPF32[$60>>2] = $57;
 if ($standingOnMoving) {
  label = 13;
 } else {
  $fabsf$i$i$i13 = (Math_fround(Math_abs((Math_fround($55)))));
  $61 = +$fabsf$i$i$i13;
  $62 = $61 > 9.99999999999999954748E-7;
  if ($62) {
   label = 13;
  } else {
   $fabsf$i$i1$i14 = (Math_fround(Math_abs((Math_fround($56)))));
   $63 = +$fabsf$i$i1$i14;
   $64 = $63 > 9.99999999999999954748E-7;
   if ($64) {
    label = 13;
   } else {
    $fabsf$i$i2$i15 = (Math_fround(Math_abs((Math_fround($57)))));
    $65 = +$fabsf$i$i2$i15;
    $66 = $65 > 9.99999999999999954748E-7;
    if ($66) {
     label = 13;
    } else {
     $291 = 1;
    }
   }
  }
 }
 if ((label|0) == 13) {
  $67 = Math_fround($stepOffset$0 * $20);
  $68 = Math_fround($stepOffset$0 * $23);
  $69 = Math_fround($stepOffset$0 * $27);
  $70 = Math_fround($67 + $71);
  HEAPF32[$UpVector>>2] = $70;
  $72 = Math_fround($68 + $73);
  HEAPF32[$48>>2] = $72;
  $74 = Math_fround($69 + $75);
  HEAPF32[$49>>2] = $74;
  $291 = 0;
 }
 $76 = HEAP32[$volume>>2]|0;
 $77 = (($76) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 FUNCTION_TABLE_viiiii[$78 & 255]($volume,$this,$temporalBox,$10,$direction);
 __ZN5physx3Cct9SweepTest18updateTouchedGeomsEPKNS0_30InternalCBData_FindTouchedGeomERKNS0_13UserObstaclesERKNS_17PxExtendedBounds3ERKNS_19PxControllerFiltersERKNS_6PxVec3E($this,$userData,$userObstacles,$temporalBox,$filters,$SideVector);
 $79 = (($this) + 96|0);
 HEAP32[$79>>2] = 0;
 HEAP32[$NbCollisions>>2] = 0;
 $80 = (($this) + 284|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  $83 = Math_fround(HEAPF32[$SideVector>>2]);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($83)))));
  $84 = +$fabsf$i$i$i;
  $85 = $84 > 9.99999999999999954748E-7;
  if ($85) {
   $maxIterUp$0 = 1;
  } else {
   $86 = Math_fround(HEAPF32[$59>>2]);
   $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($86)))));
   $87 = +$fabsf$i$i1$i;
   $88 = $87 > 9.99999999999999954748E-7;
   if ($88) {
    $maxIterUp$0 = 1;
   } else {
    $89 = Math_fround(HEAPF32[$60>>2]);
    $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($89)))));
    $90 = +$fabsf$i$i2$i;
    $91 = $90 > 9.99999999999999954748E-7;
    if ($91) {
     $maxIterUp$0 = 1;
    } else {
     $maxIterUp$0 = 10;
    }
   }
  }
 } else {
  $maxIterUp$0 = 1;
 }
 $92 = HEAP32[$0>>2]|0;
 $93 = $92 & 2;
 $94 = ($93|0)==(0);
 if ($94) {
  $95 = (__ZN5physx3Cct9SweepTest11doSweepTestEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERKNS0_13UserObstaclesERNS0_11SweptVolumeERKNS_6PxVec3ESF_jPjfRKNS_19PxControllerFiltersENS0_9SweepPassE($this,$userData,$userHitData,$userObstacles,$volume,$UpVector,$SideVector,$maxIterUp$0,$NbCollisions,$min_dist,$filters,0)|0);
  $96 = HEAP32[$NbCollisions>>2]|0;
  $97 = ($96|0)!=(0);
  $or$cond = $95 & $97;
  if ($or$cond) {
   HEAP8[$agg$result>>0] = 2;
   $98 = +HEAPF64[$10>>3];
   $99 = Math_fround($98);
   $100 = +HEAPF64[$13>>3];
   $101 = Math_fround($100);
   $102 = +HEAPF64[$16>>3];
   $103 = Math_fround($102);
   $104 = Math_fround(HEAPF32[$19>>2]);
   $105 = Math_fround($99 * $104);
   $106 = Math_fround(HEAPF32[$22>>2]);
   $107 = Math_fround($101 * $106);
   $108 = Math_fround($105 + $107);
   $109 = Math_fround(HEAPF32[$26>>2]);
   $110 = Math_fround($103 * $109);
   $111 = Math_fround($108 + $110);
   $112 = +$111;
   $113 = $112 - $30;
   $114 = +$stepOffset$0;
   $115 = $113 < $114;
   if ($115) {
    $116 = Math_fround($113);
    $123 = 2;$stepOffset$1 = $116;
   } else {
    $123 = 2;$stepOffset$1 = $stepOffset$0;
   }
  } else {
   $123 = 0;$stepOffset$1 = $stepOffset$0;
  }
 } else {
  $123 = 0;$stepOffset$1 = $stepOffset$0;
 }
 HEAP32[$79>>2] = 1;
 $117 = HEAP32[$0>>2]|0;
 $118 = $117 & -9;
 HEAP32[$0>>2] = $118;
 HEAP32[$NbCollisions>>2] = 0;
 $119 = (__ZN5physx3Cct9SweepTest11doSweepTestEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERKNS0_13UserObstaclesERNS0_11SweptVolumeERKNS_6PxVec3ESF_jPjfRKNS_19PxControllerFiltersENS0_9SweepPassE($this,$userData,$userHitData,$userObstacles,$volume,$SideVector,$SideVector,10,$NbCollisions,$min_dist,$filters,1)|0);
 $120 = HEAP32[$NbCollisions>>2]|0;
 $121 = ($120|0)!=(0);
 $or$cond3 = $119 & $121;
 if ($or$cond3) {
  $122 = $123&255;
  $124 = $122 | 1;
  $125 = $124&255;
  HEAP8[$agg$result>>0] = $125;
  $180 = $125;
 } else {
  $180 = $123;
 }
 if ($constrainedClimbingMode) {
  $126 = (($volume) + 36|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ($127|0)==(1);
  if ($128) {
   $129 = HEAP32[$0>>2]|0;
   $130 = $129 & 8;
   $131 = ($130|0)==(0);
   if ($131) {
    $132 = (($volume) + 40|0);
    $133 = Math_fround(HEAPF32[$132>>2]);
    $134 = Math_fround(HEAPF32[$SideVector>>2]);
    $135 = Math_fround($134 * $134);
    $136 = Math_fround(HEAPF32[$59>>2]);
    $137 = Math_fround($136 * $136);
    $138 = Math_fround($135 + $137);
    $139 = Math_fround(HEAPF32[$60>>2]);
    $140 = Math_fround($139 * $139);
    $141 = Math_fround($138 + $140);
    $142 = (Math_fround(Math_sqrt((Math_fround($141)))));
    $143 = $142 < $133;
    if ($143) {
     $144 = $141 > Math_fround(0.0);
     if ($144) {
      $145 = Math_fround(Math_fround(1.0) / $142);
      $146 = Math_fround($134 * $145);
      $147 = Math_fround($136 * $145);
      $148 = Math_fround($139 * $145);
      $150 = $146;$152 = $147;$154 = $148;
     } else {
      $150 = Math_fround(0.0);$152 = Math_fround(0.0);$154 = Math_fround(0.0);
     }
     $149 = Math_fround($133 * $150);
     $151 = Math_fround($133 * $152);
     $153 = Math_fround($133 * $154);
     HEAPF32[$sensor>>2] = $149;
     $155 = (($sensor) + 4|0);
     HEAPF32[$155>>2] = $151;
     $156 = (($sensor) + 8|0);
     HEAPF32[$156>>2] = $153;
     $157 = $129 & -9;
     HEAP32[$0>>2] = $157;
     HEAP32[$NbCollisions>>2] = 0;
     ;HEAP32[$saved+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$saved+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$saved+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$saved+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$saved+16>>2]=HEAP32[$10+16>>2]|0;HEAP32[$saved+20>>2]=HEAP32[$10+20>>2]|0;
     (__ZN5physx3Cct9SweepTest11doSweepTestEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERKNS0_13UserObstaclesERNS0_11SweptVolumeERKNS_6PxVec3ESF_jPjfRKNS_19PxControllerFiltersENS0_9SweepPassE($this,$userData,$userHitData,$userObstacles,$volume,$sensor,$SideVector,1,$NbCollisions,$min_dist,$filters,3)|0);
     ;HEAP32[$10+0>>2]=HEAP32[$saved+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$saved+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$saved+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$saved+12>>2]|0;HEAP32[$10+16>>2]=HEAP32[$saved+16>>2]|0;HEAP32[$10+20>>2]=HEAP32[$saved+20>>2]|0;
    }
   }
  }
 }
 HEAP32[$79>>2] = 2;
 HEAP32[$NbCollisions>>2] = 0;
 if (!($291)) {
  $158 = Math_fround(HEAPF32[$19>>2]);
  $159 = Math_fround($stepOffset$1 * $158);
  $160 = Math_fround(HEAPF32[$22>>2]);
  $161 = Math_fround($stepOffset$1 * $160);
  $162 = Math_fround(HEAPF32[$26>>2]);
  $163 = Math_fround($stepOffset$1 * $162);
  $164 = Math_fround($165 - $159);
  HEAPF32[$DownVector>>2] = $164;
  $166 = Math_fround($167 - $161);
  HEAPF32[$50>>2] = $166;
  $168 = Math_fround($169 - $163);
  HEAPF32[$51>>2] = $168;
 }
 $170 = HEAP32[$0>>2]|0;
 $171 = $170 & -5;
 HEAP32[$0>>2] = $171;
 $172 = (($this) + 156|0);
 HEAP32[$172>>2] = 0;
 $173 = (($this) + 160|0);
 HEAP32[$173>>2] = 0;
 $174 = (($this) + 152|0);
 HEAP32[$174>>2] = -1;
 $176 = (__ZN5physx3Cct9SweepTest11doSweepTestEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERKNS0_13UserObstaclesERNS0_11SweptVolumeERKNS_6PxVec3ESF_jPjfRKNS_19PxControllerFiltersENS0_9SweepPassE($this,$userData,$userHitData,$userObstacles,$volume,$DownVector,$SideVector,$175,$NbCollisions,$min_dist,$filters,2)|0);
 $177 = HEAP32[$NbCollisions>>2]|0;
 $178 = ($177|0)!=(0);
 $or$cond5 = $176 & $178;
 if ($or$cond5) {
  if ($58) {
   $179 = $180&255;
   $181 = $179 | 4;
   $182 = $181&255;
   HEAP8[$agg$result>>0] = $182;
  }
  $183 = (($this) + 281|0);
  $184 = HEAP8[$183>>0]|0;
  $185 = ($184<<24>>24)==(0);
  if ($185) {
   STACKTOP = sp;return;
  }
  $186 = HEAP32[$0>>2]|0;
  $187 = $186 & 56;
  $188 = ($187|0)==(8);
  if ($188) {
   $189 = (($this) + 132|0);
   $190 = Math_fround(HEAPF32[$189>>2]);
   $191 = Math_fround(HEAPF32[$19>>2]);
   $192 = Math_fround($190 * $191);
   $193 = (($this) + 136|0);
   $194 = Math_fround(HEAPF32[$193>>2]);
   $195 = Math_fround(HEAPF32[$22>>2]);
   $196 = Math_fround($194 * $195);
   $197 = Math_fround($192 + $196);
   $198 = (($this) + 140|0);
   $199 = Math_fround(HEAPF32[$198>>2]);
   $200 = Math_fround(HEAPF32[$26>>2]);
   $201 = Math_fround($199 * $200);
   $202 = Math_fround($197 + $201);
   $203 = !($202 >= Math_fround(0.0));
   if (!($203)) {
    $204 = (($this) + 256|0);
    $205 = Math_fround(HEAPF32[$204>>2]);
    $$not = !($202 < $205);
    $constrainedClimbingMode$not = $constrainedClimbingMode ^ 1;
    $brmerge = $$not | $constrainedClimbingMode$not;
    if (!($brmerge)) {
     $206 = (($this) + 292|0);
     $207 = Math_fround(HEAPF32[$206>>2]);
     $208 = +$207;
     $209 = +$stepOffset$1;
     $210 = $34 + $209;
     $211 = $208 > $210;
     if ($211) {
      $212 = $186 | 1;
      HEAP32[$0>>2] = $212;
      $213 = $186 & 2;
      $214 = ($213|0)==(0);
      if ($214) {
       STACKTOP = sp;return;
      } else {
       $216 = $184;
       label = 44;
      }
     }
    }
   }
  }
 } else {
  $$phi$trans$insert = (($this) + 281|0);
  $$pre = HEAP8[$$phi$trans$insert>>0]|0;
  $216 = $$pre;
  label = 44;
 }
 if ((label|0) == 44) {
  $215 = ($216<<24>>24)==(0);
  if ($215) {
   STACKTOP = sp;return;
  }
 }
 $217 = HEAP32[$0>>2]|0;
 $218 = $217 & 52;
 $219 = ($218|0)!=(4);
 $$not10 = $58 ^ 1;
 $brmerge11 = $219 | $$not10;
 if ($brmerge11) {
  STACKTOP = sp;return;
 }
 $220 = (($this) + 148|0);
 $221 = Math_fround(HEAPF32[$220>>2]);
 $222 = +$221;
 $223 = $222 - $34;
 $224 = Math_fround($223);
 $225 = Math_fround(HEAPF32[$8>>2]);
 $226 = $224 > $225;
 if (!($226)) {
  STACKTOP = sp;return;
 }
 $227 = (($this) + 128|0);
 $228 = (($this) + 124|0);
 $229 = (($this) + 120|0);
 $230 = Math_fround(HEAPF32[$227>>2]);
 $231 = Math_fround(HEAPF32[$228>>2]);
 $232 = Math_fround(HEAPF32[$229>>2]);
 $233 = (($this) + 256|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = Math_fround(HEAPF32[$19>>2]);
 $236 = Math_fround($232 * $235);
 $237 = Math_fround(HEAPF32[$22>>2]);
 $238 = Math_fround($231 * $237);
 $239 = Math_fround($236 + $238);
 $240 = Math_fround(HEAPF32[$26>>2]);
 $241 = Math_fround($230 * $240);
 $242 = Math_fround($239 + $241);
 $243 = $242 >= Math_fround(0.0);
 $244 = $242 < $234;
 $or$cond39 = $243 & $244;
 if (!($or$cond39)) {
  STACKTOP = sp;return;
 }
 $245 = $217 | 1;
 HEAP32[$0>>2] = $245;
 $246 = $217 & 2;
 $247 = ($246|0)==(0);
 if ($247) {
  STACKTOP = sp;return;
 }
 $248 = $217 | 65;
 HEAP32[$0>>2] = $248;
 $249 = +HEAPF64[$10>>3];
 $250 = Math_fround($249);
 $251 = +HEAPF64[$13>>3];
 $252 = Math_fround($251);
 $253 = +HEAPF64[$16>>3];
 $254 = Math_fround($253);
 $255 = Math_fround($250 * $235);
 $256 = Math_fround($252 * $237);
 $257 = Math_fround($255 + $256);
 $258 = Math_fround($254 * $240);
 $259 = Math_fround($257 + $258);
 $260 = $259 > $29;
 if ($260) {
  $261 = +$259;
  $262 = $261 - $30;
  $274 = $262;
 } else {
  $274 = 0.0;
 }
 $263 = Math_fround(HEAPF32[$direction>>2]);
 $264 = Math_fround($263 * $235);
 $265 = Math_fround(HEAPF32[$37>>2]);
 $266 = Math_fround($265 * $237);
 $267 = Math_fround($264 + $266);
 $268 = Math_fround(HEAPF32[$41>>2]);
 $269 = Math_fround($268 * $240);
 $270 = Math_fround($267 + $269);
 $271 = (Math_fround(Math_abs((Math_fround($270)))));
 $272 = +$271;
 $273 = $274 + $272;
 HEAP32[$NbCollisions>>2] = 0;
 $275 = +$min_dist;
 $276 = $273 < $275;
 if ($276) {
  $277 = $273 / 10.0;
  $288 = $277;
 } else {
  $288 = $275;
 }
 $278 = (($RecoverPoint) + 4|0);
 $279 = (($RecoverPoint) + 8|0);
 $280 = Math_fround($273);
 $281 = Math_fround($280 * $235);
 $282 = Math_fround(-$281);
 $283 = Math_fround($280 * $237);
 $284 = Math_fround(-$283);
 $285 = Math_fround($280 * $240);
 $286 = Math_fround(-$285);
 HEAPF32[$RecoverPoint>>2] = $282;
 HEAPF32[$278>>2] = $284;
 HEAPF32[$279>>2] = $286;
 $287 = Math_fround($288);
 (__ZN5physx3Cct9SweepTest11doSweepTestEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERKNS0_13UserObstaclesERNS0_11SweptVolumeERKNS_6PxVec3ESF_jPjfRKNS_19PxControllerFiltersENS0_9SweepPassE($this,$userData,$userHitData,$userObstacles,$volume,$RecoverPoint,$SideVector,10,$NbCollisions,$287,$filters,0)|0);
 $289 = HEAP32[$0>>2]|0;
 $290 = $289 & -65;
 HEAP32[$0>>2] = $290;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10Controller17findTouchedObjectERKNS_19PxControllerFiltersEPKNS_17PxObstacleContextERKNS_6PxVec3E($this,$filters,$obstacleContext,$upDirection) {
 $this = $this|0;
 $filters = $filters|0;
 $obstacleContext = $obstacleContext|0;
 $upDirection = $upDirection|0;
 var $$33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = 0;
 var $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0.0, $290 = 0, $291 = 0, $292 = 0, $293 = 0.0, $294 = Math_fround(0), $295 = 0;
 var $296 = 0.0, $297 = Math_fround(0), $298 = 0, $299 = 0.0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0.0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = 0, $35 = 0.0;
 var $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0;
 var $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $filterData = 0, $hit = 0, $obstacleHandle = 0, $preFilter = 0, $rayOrigin = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $0 = sp + 216|0;
 $1 = sp + 184|0;
 $preFilter = sp + 168|0;
 $filterData = sp + 144|0;
 $2 = sp + 128|0;
 $rayOrigin = sp + 112|0;
 $hit = sp + 16|0;
 $3 = sp + 4|0;
 $4 = sp + 280|0;
 $obstacleHandle = sp;
 $5 = sp + 100|0;
 $6 = (($filters) + 8|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 & 2;
 $9 = ($8<<16>>16)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 HEAP32[$preFilter>>2] = ((404568 + 8|0));
 $10 = (($preFilter) + 12|0);
 $11 = (($this) + 464|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 76|0);
 $14 = (($preFilter) + 4|0);
 HEAP32[$14>>2] = $13;
 $15 = (($filters) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($preFilter) + 8|0);
 HEAP32[$17>>2] = $16;
 HEAP16[$10>>1] = $7;
 $18 = $7 & 8;
 $19 = $18 | 6;
 $20 = HEAP32[$filters>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 } else {
  ;HEAP32[$2+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$20+12>>2]|0;
 }
 ;HEAP32[$filterData+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$filterData+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$filterData+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$filterData+12>>2]=HEAP32[$2+12>>2]|0;
 $22 = (($filterData) + 16|0);
 HEAP16[$22>>1] = $19;
 $23 = (($filterData) + 18|0);
 HEAP8[$23>>0] = 0;
 $24 = HEAP32[$this>>2]|0;
 $25 = (($24) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (Math_fround(FUNCTION_TABLE_fi[$26 & 255]($this)));
 $28 = (($this) + 408|0);
 $29 = +HEAPF64[$28>>3];
 $30 = Math_fround($29);
 $31 = (($this) + 416|0);
 $32 = +HEAPF64[$31>>3];
 $33 = Math_fround($32);
 $34 = (($this) + 424|0);
 $35 = +HEAPF64[$34>>3];
 $36 = Math_fround($35);
 HEAPF32[$rayOrigin>>2] = $30;
 $37 = (($rayOrigin) + 4|0);
 HEAPF32[$37>>2] = $33;
 $38 = (($rayOrigin) + 8|0);
 HEAPF32[$38>>2] = $36;
 $39 = (($hit) + 4|0);
 HEAP32[$39>>2] = 0;
 $40 = (($hit) + 8|0);
 HEAP32[$40>>2] = 0;
 $41 = (($hit) + 12|0);
 HEAP32[$41>>2] = -1;
 $42 = (($hit) + 16|0);
 HEAP16[$42>>1] = 0;
 $43 = (($hit) + 20|0);
 $44 = (($hit) + 44|0);
 ;HEAP32[$43+0>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;HEAP32[$43+16>>2]=0|0;HEAP32[$43+20>>2]=0|0;
 $45 = (($hit) + 48|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($hit) + 52|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($hit) + 68|0);
 HEAP8[$47>>0] = 0;
 $48 = (($hit) + 72|0);
 HEAP32[$48>>2] = 0;
 $49 = (($hit) + 76|0);
 HEAP32[$49>>2] = 0;
 $50 = (($hit) + 80|0);
 HEAP32[$50>>2] = 0;
 HEAP32[$hit>>2] = ((404440 + 8|0));
 $51 = (($hit) + 4|0);
 HEAPF32[$44>>2] = Math_fround(3.40282346638528859812E+38);
 $52 = (($this) + 456|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 348|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = Math_fround(HEAPF32[$upDirection>>2]);
 $58 = Math_fround(-$57);
 $59 = (($upDirection) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround(-$60);
 $62 = (($upDirection) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(-$63);
 HEAPF32[$3>>2] = $58;
 $65 = (($3) + 4|0);
 HEAPF32[$65>>2] = $61;
 $66 = (($3) + 8|0);
 HEAPF32[$66>>2] = $64;
 $67 = Math_fround($27 + Math_fround(0.0));
 HEAP16[$4>>1] = 4;
 $68 = (FUNCTION_TABLE_iiiifiiiii[$56 & 1]($53,$rayOrigin,$3,$67,$hit,$4,$filterData,$preFilter,0)|0);
 if ($68) {
  $69 = HEAP32[$50>>2]|0;
  $70 = ($69|0)!=(0);
  $71 = HEAP32[$48>>2]|0;
  $$33 = $70 ? $71 : $51;
  ;HEAP32[$51+0>>2]=HEAP32[$$33+0>>2]|0;HEAP32[$51+4>>2]=HEAP32[$$33+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$$33+8>>2]|0;
  $72 = (($$33) + 12|0);
  $73 = HEAP16[$72>>1]|0;
  HEAP16[$42>>1] = $73;
  $74 = (($$33) + 16|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  HEAPF32[$43>>2] = $75;
  $76 = (($$33) + 20|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = (($hit) + 24|0);
  HEAPF32[$78>>2] = $77;
  $79 = (($$33) + 24|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (($hit) + 28|0);
  HEAPF32[$81>>2] = $80;
  $82 = (($$33) + 28|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($hit) + 32|0);
  HEAPF32[$84>>2] = $83;
  $85 = (($$33) + 32|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = (($hit) + 36|0);
  HEAPF32[$87>>2] = $86;
  $88 = (($$33) + 36|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = (($hit) + 40|0);
  HEAPF32[$90>>2] = $89;
  $91 = (($$33) + 40|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  HEAPF32[$44>>2] = $92;
  $93 = (($$33) + 44|0);
  ;HEAP32[$45+0>>2]=HEAP32[$93+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$93+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$93+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$93+12>>2]|0;HEAP32[$45+16>>2]=HEAP32[$93+16>>2]|0;
  $94 = HEAP32[$40>>2]|0;
  $95 = (($this) + 244|0);
  HEAP32[$95>>2] = $94;
  $96 = HEAP32[$51>>2]|0;
  $97 = (($this) + 248|0);
  HEAP32[$97>>2] = $96;
  $98 = HEAP32[$96>>2]|0;
  $99 = (($98) + 84|0);
  $100 = HEAP32[$99>>2]|0;
  FUNCTION_TABLE_vii[$100 & 4095]($0,$96);
  $101 = HEAP32[$94>>2]|0;
  $102 = (($101) + 72|0);
  $103 = HEAP32[$102>>2]|0;
  FUNCTION_TABLE_vii[$103 & 4095]($1,$94);
  $104 = (($1) + 16|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($105 * Math_fround(2.0));
  $107 = (($1) + 20|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($108 * Math_fround(2.0));
  $110 = (($1) + 24|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround($111 * Math_fround(2.0));
  $113 = (($0) + 12|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = Math_fround($114 * $114);
  $116 = Math_fround($115 + Math_fround(-0.5));
  $117 = Math_fround(HEAPF32[$0>>2]);
  $118 = Math_fround($106 * $117);
  $119 = (($0) + 4|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $121 = Math_fround($109 * $120);
  $122 = Math_fround($118 + $121);
  $123 = (($0) + 8|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = Math_fround($112 * $124);
  $126 = Math_fround($122 + $125);
  $127 = Math_fround($106 * $116);
  $128 = Math_fround($112 * $120);
  $129 = Math_fround($109 * $124);
  $130 = Math_fround($128 - $129);
  $131 = Math_fround($114 * $130);
  $132 = Math_fround($127 + $131);
  $133 = Math_fround($117 * $126);
  $134 = Math_fround($133 + $132);
  $135 = Math_fround($109 * $116);
  $136 = Math_fround($106 * $124);
  $137 = Math_fround($112 * $117);
  $138 = Math_fround($136 - $137);
  $139 = Math_fround($114 * $138);
  $140 = Math_fround($135 + $139);
  $141 = Math_fround($120 * $126);
  $142 = Math_fround($141 + $140);
  $143 = Math_fround($112 * $116);
  $144 = Math_fround($109 * $117);
  $145 = Math_fround($106 * $120);
  $146 = Math_fround($144 - $145);
  $147 = Math_fround($114 * $146);
  $148 = Math_fround($143 + $147);
  $149 = Math_fround($124 * $126);
  $150 = Math_fround($148 + $149);
  $151 = (($0) + 16|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = Math_fround($152 + $134);
  $154 = (($0) + 20|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = Math_fround($155 + $142);
  $157 = (($0) + 24|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = Math_fround($158 + $150);
  $160 = Math_fround(HEAPF32[$1>>2]);
  $161 = Math_fround($114 * $160);
  $162 = (($1) + 12|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = Math_fround($117 * $163);
  $165 = Math_fround($161 + $164);
  $166 = (($1) + 8|0);
  $167 = Math_fround(HEAPF32[$166>>2]);
  $168 = Math_fround($120 * $167);
  $169 = Math_fround($165 + $168);
  $170 = (($1) + 4|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = Math_fround($124 * $171);
  $173 = Math_fround($169 - $172);
  $174 = Math_fround($114 * $171);
  $175 = Math_fround($120 * $163);
  $176 = Math_fround($175 + $174);
  $177 = Math_fround($124 * $160);
  $178 = Math_fround($177 + $176);
  $179 = Math_fround($117 * $167);
  $180 = Math_fround($178 - $179);
  $181 = Math_fround($114 * $167);
  $182 = Math_fround($124 * $163);
  $183 = Math_fround($182 + $181);
  $184 = Math_fround($117 * $171);
  $185 = Math_fround($184 + $183);
  $186 = Math_fround($120 * $160);
  $187 = Math_fround($185 - $186);
  $188 = Math_fround($114 * $163);
  $189 = Math_fround($117 * $160);
  $190 = Math_fround($188 - $189);
  $191 = Math_fround($120 * $171);
  $192 = Math_fround($190 - $191);
  $193 = Math_fround($124 * $167);
  $194 = Math_fround($192 - $193);
  $195 = Math_fround(HEAPF32[$44>>2]);
  $196 = Math_fround($27 - $195);
  $197 = Math_fround(HEAPF32[$upDirection>>2]);
  $198 = Math_fround($197 * $196);
  $199 = Math_fround(HEAPF32[$59>>2]);
  $200 = Math_fround($196 * $199);
  $201 = Math_fround(HEAPF32[$62>>2]);
  $202 = Math_fround($196 * $201);
  $203 = Math_fround(Math_fround(0.0) - $198);
  $204 = Math_fround(Math_fround(0.0) - $200);
  $205 = Math_fround(Math_fround(0.0) - $202);
  $206 = (($this) + 276|0);
  HEAPF32[$206>>2] = $203;
  $207 = (($this) + 280|0);
  HEAPF32[$207>>2] = $204;
  $208 = (($this) + 284|0);
  HEAPF32[$208>>2] = $205;
  $209 = Math_fround(Math_fround(0.0) - $153);
  $210 = Math_fround(Math_fround(0.0) - $156);
  $211 = Math_fround(Math_fround(0.0) - $159);
  $212 = Math_fround($209 * Math_fround(2.0));
  $213 = Math_fround($210 * Math_fround(2.0));
  $214 = Math_fround($211 * Math_fround(2.0));
  $215 = Math_fround($194 * $194);
  $216 = Math_fround($215 + Math_fround(-0.5));
  $217 = Math_fround($212 * $173);
  $218 = Math_fround($213 * $180);
  $219 = Math_fround($217 + $218);
  $220 = Math_fround($214 * $187);
  $221 = Math_fround($220 + $219);
  $222 = Math_fround($212 * $216);
  $223 = Math_fround($214 * $180);
  $224 = Math_fround($213 * $187);
  $225 = Math_fround($223 - $224);
  $226 = Math_fround($194 * $225);
  $227 = Math_fround($222 - $226);
  $228 = Math_fround($173 * $221);
  $229 = Math_fround($228 + $227);
  $230 = Math_fround($213 * $216);
  $231 = Math_fround($212 * $187);
  $232 = Math_fround($214 * $173);
  $233 = Math_fround($231 - $232);
  $234 = Math_fround($194 * $233);
  $235 = Math_fround($230 - $234);
  $236 = Math_fround($180 * $221);
  $237 = Math_fround($235 + $236);
  $238 = Math_fround($214 * $216);
  $239 = Math_fround($213 * $173);
  $240 = Math_fround($212 * $180);
  $241 = Math_fround($239 - $240);
  $242 = Math_fround($194 * $241);
  $243 = Math_fround($238 - $242);
  $244 = Math_fround($187 * $221);
  $245 = Math_fround($243 + $244);
  $246 = (($this) + 264|0);
  HEAPF32[$246>>2] = $229;
  $247 = (($this) + 268|0);
  HEAPF32[$247>>2] = $237;
  $248 = (($this) + 272|0);
  HEAPF32[$248>>2] = $245;
  $249 = HEAP32[$52>>2]|0;
  $250 = HEAP32[$249>>2]|0;
  $251 = (($250) + 32|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = (FUNCTION_TABLE_ii[$252 & 4095]($249)|0);
  $254 = (($253) + -1)|0;
  $255 = (($this) + 460|0);
  HEAP32[$255>>2] = $254;
 }
 $256 = ($obstacleContext|0)==(0|0);
 if ($256) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 0;
 $257 = (($0) + 4|0);
 HEAP32[$257>>2] = 0;
 $258 = (($0) + 8|0);
 HEAP32[$258>>2] = -1;
 $259 = (($0) + 12|0);
 HEAP16[$259>>1] = 0;
 $260 = (($0) + 16|0);
 $261 = (($0) + 40|0);
 ;HEAP32[$260+0>>2]=0|0;HEAP32[$260+4>>2]=0|0;HEAP32[$260+8>>2]=0|0;HEAP32[$260+12>>2]=0|0;HEAP32[$260+16>>2]=0|0;HEAP32[$260+20>>2]=0|0;
 HEAPF32[$261>>2] = Math_fround(3.40282346638528859812E+38);
 $262 = (($0) + 44|0);
 HEAPF32[$262>>2] = Math_fround(0.0);
 $263 = (($0) + 48|0);
 HEAPF32[$263>>2] = Math_fround(0.0);
 $264 = Math_fround(HEAPF32[$upDirection>>2]);
 $265 = Math_fround(-$264);
 $266 = Math_fround(HEAPF32[$59>>2]);
 $267 = Math_fround(-$266);
 $268 = Math_fround(HEAPF32[$62>>2]);
 $269 = Math_fround(-$268);
 HEAPF32[$5>>2] = $265;
 $270 = (($5) + 4|0);
 HEAPF32[$270>>2] = $267;
 $271 = (($5) + 8|0);
 HEAPF32[$271>>2] = $269;
 $272 = (__ZNK5physx3Cct15ObstacleContext13raycastSingleERNS_12PxRaycastHitERKNS_6PxVec3ES6_fRj($obstacleContext,$0,$rayOrigin,$5,$67,$obstacleHandle)|0);
 $273 = ($272|0)==(0|0);
 if ($273) {
  STACKTOP = sp;return;
 }
 $274 = Math_fround(HEAPF32[$261>>2]);
 $275 = Math_fround(HEAPF32[$44>>2]);
 $276 = $274 < $275;
 if (!($276)) {
  STACKTOP = sp;return;
 }
 $277 = HEAP32[$obstacleHandle>>2]|0;
 $278 = (($this) + 240|0);
 HEAP32[$278>>2] = $277;
 $279 = Math_fround($27 - $274);
 $280 = Math_fround(HEAPF32[$upDirection>>2]);
 $281 = Math_fround($280 * $279);
 $282 = Math_fround(HEAPF32[$59>>2]);
 $283 = Math_fround($279 * $282);
 $284 = Math_fround(HEAPF32[$62>>2]);
 $285 = Math_fround($279 * $284);
 $286 = Math_fround(Math_fround(0.0) - $281);
 $287 = Math_fround(Math_fround(0.0) - $283);
 $288 = Math_fround(Math_fround(0.0) - $285);
 $289 = (($this) + 300|0);
 HEAPF32[$289>>2] = $286;
 $290 = (($this) + 304|0);
 HEAPF32[$290>>2] = $287;
 $291 = (($this) + 308|0);
 HEAPF32[$291>>2] = $288;
 $292 = (($272) + 8|0);
 $293 = +HEAPF64[$292>>3];
 $294 = Math_fround($293);
 $295 = (($272) + 16|0);
 $296 = +HEAPF64[$295>>3];
 $297 = Math_fround($296);
 $298 = (($272) + 24|0);
 $299 = +HEAPF64[$298>>3];
 $300 = Math_fround($299);
 $301 = (($272) + 32|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = (($272) + 36|0);
 $304 = Math_fround(HEAPF32[$303>>2]);
 $305 = (($272) + 40|0);
 $306 = Math_fround(HEAPF32[$305>>2]);
 $307 = (($272) + 44|0);
 $308 = Math_fround(HEAPF32[$307>>2]);
 $309 = Math_fround(Math_fround(0.0) - $294);
 $310 = Math_fround(Math_fround(0.0) - $297);
 $311 = Math_fround(Math_fround(0.0) - $300);
 $312 = Math_fround($309 * Math_fround(2.0));
 $313 = Math_fround($310 * Math_fround(2.0));
 $314 = Math_fround($311 * Math_fround(2.0));
 $315 = Math_fround($308 * $308);
 $316 = Math_fround($315 + Math_fround(-0.5));
 $317 = Math_fround($312 * $302);
 $318 = Math_fround($313 * $304);
 $319 = Math_fround($317 + $318);
 $320 = Math_fround($314 * $306);
 $321 = Math_fround($319 + $320);
 $322 = Math_fround($312 * $316);
 $323 = Math_fround($304 * $314);
 $324 = Math_fround($313 * $306);
 $325 = Math_fround($323 - $324);
 $326 = Math_fround($308 * $325);
 $327 = Math_fround($322 - $326);
 $328 = Math_fround($302 * $321);
 $329 = Math_fround($328 + $327);
 $330 = Math_fround($313 * $316);
 $331 = Math_fround($312 * $306);
 $332 = Math_fround($302 * $314);
 $333 = Math_fround($331 - $332);
 $334 = Math_fround($308 * $333);
 $335 = Math_fround($330 - $334);
 $336 = Math_fround($304 * $321);
 $337 = Math_fround($336 + $335);
 $338 = Math_fround($314 * $316);
 $339 = Math_fround($302 * $313);
 $340 = Math_fround($312 * $304);
 $341 = Math_fround($339 - $340);
 $342 = Math_fround($308 * $341);
 $343 = Math_fround($338 - $342);
 $344 = Math_fround($306 * $321);
 $345 = Math_fround($344 + $343);
 $346 = (($this) + 288|0);
 HEAPF32[$346>>2] = $329;
 $347 = (($this) + 292|0);
 HEAPF32[$347>>2] = $337;
 $348 = (($this) + 296|0);
 HEAPF32[$348>>2] = $345;
 STACKTOP = sp;return;
}
function __ZN5physx11PxHitBufferINS_12PxRaycastHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16ControllerFilterD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10Controller19rideOnTouchedObjectERNS0_11SweptVolumeERKNS_6PxVec3ERS4_PKNS_17PxObstacleContextE($this,$volume,$upDirection,$disp,$obstacleContext) {
 $this = $this|0;
 $volume = $volume|0;
 $upDirection = $upDirection|0;
 $disp = $disp|0;
 $obstacleContext = $obstacleContext|0;
 var $$idx = 0, $$idx$val = Math_fround(0), $$idx3 = 0, $$idx3$val = Math_fround(0), $$idx4 = 0, $$idx4$val = Math_fround(0), $$pn = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0;
 var $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0);
 var $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0;
 var $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0.0, $271 = 0;
 var $272 = Math_fround(0), $273 = 0.0, $274 = 0, $275 = Math_fround(0), $276 = 0.0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0;
 var $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0.0, $298 = 0, $299 = 0.0, $3 = 0, $30 = 0, $300 = 0.0, $301 = 0.0, $302 = 0, $303 = 0.0, $304 = 0.0, $305 = 0.0, $306 = 0, $307 = 0.0;
 var $308 = 0.0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0);
 var $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0);
 var $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0.0, $62 = Math_fround(0), $63 = 0, $64 = 0.0, $65 = Math_fround(0), $66 = 0, $67 = 0.0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0;
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $behaviorFlags$0 = 0, $behaviorFlags$1 = 0, $behaviorFlags$214 = 0, $behaviorFlags$21416 = 0, $extract$t = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $standingOnMoving$0$off0 = 0, $timeCoeff$013 = Math_fround(0), $timeCoeff$01317 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 28|0;
 $1 = sp;
 $2 = sp + 57|0;
 $3 = sp + 56|0;
 $4 = (($this) + 244|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $35 = (($this) + 468|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($this) + 472|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround($36 - $38);
  HEAPF32[$37>>2] = $36;
  $40 = HEAP32[$obstacleContext>>2]|0;
  $41 = (($40) + 36|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($this) + 240|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (FUNCTION_TABLE_iii[$42 & 4095]($obstacleContext,$44)|0);
  $46 = (($this) + 76|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  if ($48) {
   $behaviorFlags$1 = 1;
  } else {
   $49 = HEAP32[$47>>2]|0;
   $50 = (($49) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   FUNCTION_TABLE_viii[$51 & 4095]($3,$47,$45);
   $52 = HEAP8[$3>>0]|0;
   $53 = $52&255;
   $behaviorFlags$1 = $53;
  }
  $54 = (($this) + 300|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($this) + 304|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($this) + 308|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $$idx = (($this) + 288|0);
  $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
  $$idx3 = (($this) + 292|0);
  $$idx3$val = Math_fround(HEAPF32[$$idx3>>2]);
  $$idx4 = (($this) + 296|0);
  $$idx4$val = Math_fround(HEAPF32[$$idx4>>2]);
  $60 = (($45) + 8|0);
  $61 = +HEAPF64[$60>>3];
  $62 = Math_fround($61);
  $63 = (($45) + 16|0);
  $64 = +HEAPF64[$63>>3];
  $65 = Math_fround($64);
  $66 = (($45) + 24|0);
  $67 = +HEAPF64[$66>>3];
  $68 = Math_fround($67);
  $69 = (($45) + 32|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = (($45) + 36|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($45) + 40|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($45) + 44|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($$idx$val * Math_fround(2.0));
  $78 = Math_fround($$idx3$val * Math_fround(2.0));
  $79 = Math_fround($$idx4$val * Math_fround(2.0));
  $80 = Math_fround($76 * $76);
  $81 = Math_fround($80 + Math_fround(-0.5));
  $82 = Math_fround($77 * $70);
  $83 = Math_fround($78 * $72);
  $84 = Math_fround($82 + $83);
  $85 = Math_fround($79 * $74);
  $86 = Math_fround($84 + $85);
  $87 = Math_fround($77 * $81);
  $88 = Math_fround($79 * $72);
  $89 = Math_fround($78 * $74);
  $90 = Math_fround($88 - $89);
  $91 = Math_fround($76 * $90);
  $92 = Math_fround($91 + $87);
  $93 = Math_fround($70 * $86);
  $94 = Math_fround($93 + $92);
  $95 = Math_fround($78 * $81);
  $96 = Math_fround($77 * $74);
  $97 = Math_fround($79 * $70);
  $98 = Math_fround($96 - $97);
  $99 = Math_fround($76 * $98);
  $100 = Math_fround($99 + $95);
  $101 = Math_fround($72 * $86);
  $102 = Math_fround($101 + $100);
  $103 = Math_fround($79 * $81);
  $104 = Math_fround($78 * $70);
  $105 = Math_fround($77 * $72);
  $106 = Math_fround($104 - $105);
  $107 = Math_fround($76 * $106);
  $108 = Math_fround($107 + $103);
  $109 = Math_fround($74 * $86);
  $110 = Math_fround($109 + $108);
  $111 = Math_fround($62 + $94);
  $112 = Math_fround($65 + $102);
  $113 = Math_fround($68 + $110);
  $114 = Math_fround($111 - $55);
  $115 = Math_fround($112 - $57);
  $116 = Math_fround($113 - $59);
  $$pn = $39;$335 = $114;$336 = $115;$337 = $116;$behaviorFlags$214 = $behaviorFlags$1;
  label = 10;
 } else {
  $7 = (($this) + 248|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 4|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = ($10<<16>>16)==(6);
  if ($11) {
   $269 = Math_fround(0.0);$272 = Math_fround(0.0);$275 = Math_fround(0.0);$behaviorFlags$21416 = 0;$timeCoeff$01317 = Math_fround(1.0);
  } else {
   $12 = (($this) + 456|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 32|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
   $18 = (($this) + 460|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($17|0)==($19|0);
   if ($20) {
    label = 21;
   } else {
    HEAP32[$18>>2] = $17;
    $21 = (($this) + 468|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = (($this) + 472|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = Math_fround($22 - $24);
    HEAPF32[$23>>2] = $22;
    $26 = (($this) + 76|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     $behaviorFlags$0 = 0;
    } else {
     $29 = HEAP32[$27>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = HEAP32[$4>>2]|0;
     $32 = HEAP32[$7>>2]|0;
     FUNCTION_TABLE_viiii[$30 & 511]($2,$27,$31,$32);
     $33 = HEAP8[$2>>0]|0;
     $34 = $33&255;
     $behaviorFlags$0 = $34;
    }
    $117 = HEAP32[$4>>2]|0;
    $118 = HEAP32[$8>>2]|0;
    $119 = (($118) + 84|0);
    $120 = HEAP32[$119>>2]|0;
    FUNCTION_TABLE_vii[$120 & 4095]($0,$8);
    $121 = HEAP32[$117>>2]|0;
    $122 = (($121) + 72|0);
    $123 = HEAP32[$122>>2]|0;
    FUNCTION_TABLE_vii[$123 & 4095]($1,$117);
    $124 = (($1) + 16|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = Math_fround($125 * Math_fround(2.0));
    $127 = (($1) + 20|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $129 = Math_fround($128 * Math_fround(2.0));
    $130 = (($1) + 24|0);
    $131 = Math_fround(HEAPF32[$130>>2]);
    $132 = Math_fround($131 * Math_fround(2.0));
    $133 = (($0) + 12|0);
    $134 = Math_fround(HEAPF32[$133>>2]);
    $135 = Math_fround($134 * $134);
    $136 = Math_fround($135 + Math_fround(-0.5));
    $137 = Math_fround(HEAPF32[$0>>2]);
    $138 = Math_fround($126 * $137);
    $139 = (($0) + 4|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = Math_fround($129 * $140);
    $142 = Math_fround($138 + $141);
    $143 = (($0) + 8|0);
    $144 = Math_fround(HEAPF32[$143>>2]);
    $145 = Math_fround($132 * $144);
    $146 = Math_fround($142 + $145);
    $147 = Math_fround($126 * $136);
    $148 = Math_fround($132 * $140);
    $149 = Math_fround($129 * $144);
    $150 = Math_fround($148 - $149);
    $151 = Math_fround($134 * $150);
    $152 = Math_fround($147 + $151);
    $153 = Math_fround($137 * $146);
    $154 = Math_fround($153 + $152);
    $155 = Math_fround($129 * $136);
    $156 = Math_fround($126 * $144);
    $157 = Math_fround($132 * $137);
    $158 = Math_fround($156 - $157);
    $159 = Math_fround($134 * $158);
    $160 = Math_fround($155 + $159);
    $161 = Math_fround($140 * $146);
    $162 = Math_fround($161 + $160);
    $163 = Math_fround($132 * $136);
    $164 = Math_fround($129 * $137);
    $165 = Math_fround($126 * $140);
    $166 = Math_fround($164 - $165);
    $167 = Math_fround($134 * $166);
    $168 = Math_fround($163 + $167);
    $169 = Math_fround($144 * $146);
    $170 = Math_fround($168 + $169);
    $171 = (($0) + 16|0);
    $172 = Math_fround(HEAPF32[$171>>2]);
    $173 = Math_fround($172 + $154);
    $174 = (($0) + 20|0);
    $175 = Math_fround(HEAPF32[$174>>2]);
    $176 = Math_fround($175 + $162);
    $177 = (($0) + 24|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = Math_fround($178 + $170);
    $180 = Math_fround(HEAPF32[$1>>2]);
    $181 = Math_fround($134 * $180);
    $182 = (($1) + 12|0);
    $183 = Math_fround(HEAPF32[$182>>2]);
    $184 = Math_fround($137 * $183);
    $185 = Math_fround($181 + $184);
    $186 = (($1) + 8|0);
    $187 = Math_fround(HEAPF32[$186>>2]);
    $188 = Math_fround($140 * $187);
    $189 = Math_fround($185 + $188);
    $190 = (($1) + 4|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = Math_fround($144 * $191);
    $193 = Math_fround($189 - $192);
    $194 = Math_fround($134 * $191);
    $195 = Math_fround($140 * $183);
    $196 = Math_fround($195 + $194);
    $197 = Math_fround($144 * $180);
    $198 = Math_fround($197 + $196);
    $199 = Math_fround($137 * $187);
    $200 = Math_fround($198 - $199);
    $201 = Math_fround($134 * $187);
    $202 = Math_fround($144 * $183);
    $203 = Math_fround($202 + $201);
    $204 = Math_fround($137 * $191);
    $205 = Math_fround($204 + $203);
    $206 = Math_fround($140 * $180);
    $207 = Math_fround($205 - $206);
    $208 = Math_fround($134 * $183);
    $209 = Math_fround($137 * $180);
    $210 = Math_fround($208 - $209);
    $211 = Math_fround($140 * $191);
    $212 = Math_fround($210 - $211);
    $213 = Math_fround($144 * $187);
    $214 = Math_fround($212 - $213);
    $215 = (($this) + 276|0);
    $216 = Math_fround(HEAPF32[$215>>2]);
    $217 = (($this) + 280|0);
    $218 = Math_fround(HEAPF32[$217>>2]);
    $219 = (($this) + 284|0);
    $220 = Math_fround(HEAPF32[$219>>2]);
    $221 = (($this) + 264|0);
    $222 = Math_fround(HEAPF32[$221>>2]);
    $223 = Math_fround($222 * Math_fround(2.0));
    $224 = (($this) + 268|0);
    $225 = Math_fround(HEAPF32[$224>>2]);
    $226 = Math_fround($225 * Math_fround(2.0));
    $227 = (($this) + 272|0);
    $228 = Math_fround(HEAPF32[$227>>2]);
    $229 = Math_fround($228 * Math_fround(2.0));
    $230 = Math_fround($214 * $214);
    $231 = Math_fround($230 + Math_fround(-0.5));
    $232 = Math_fround($193 * $223);
    $233 = Math_fround($200 * $226);
    $234 = Math_fround($232 + $233);
    $235 = Math_fround($207 * $229);
    $236 = Math_fround($234 + $235);
    $237 = Math_fround($231 * $223);
    $238 = Math_fround($200 * $229);
    $239 = Math_fround($207 * $226);
    $240 = Math_fround($238 - $239);
    $241 = Math_fround($214 * $240);
    $242 = Math_fround($237 + $241);
    $243 = Math_fround($193 * $236);
    $244 = Math_fround($243 + $242);
    $245 = Math_fround($231 * $226);
    $246 = Math_fround($207 * $223);
    $247 = Math_fround($193 * $229);
    $248 = Math_fround($246 - $247);
    $249 = Math_fround($214 * $248);
    $250 = Math_fround($245 + $249);
    $251 = Math_fround($200 * $236);
    $252 = Math_fround($251 + $250);
    $253 = Math_fround($231 * $229);
    $254 = Math_fround($193 * $226);
    $255 = Math_fround($200 * $223);
    $256 = Math_fround($254 - $255);
    $257 = Math_fround($214 * $256);
    $258 = Math_fround($253 + $257);
    $259 = Math_fround($207 * $236);
    $260 = Math_fround($258 + $259);
    $261 = Math_fround($173 + $244);
    $262 = Math_fround($176 + $252);
    $263 = Math_fround($179 + $260);
    $264 = Math_fround($261 - $216);
    $265 = Math_fround($262 - $218);
    $266 = Math_fround($263 - $220);
    $$pn = $25;$335 = $264;$336 = $265;$337 = $266;$behaviorFlags$214 = $behaviorFlags$0;
    label = 10;
   }
  }
 }
 if ((label|0) == 10) {
  $timeCoeff$013 = Math_fround(Math_fround(1.0) / $$pn);
  $267 = $behaviorFlags$214 & 4;
  $268 = ($267|0)==(0);
  if ($268) {
   $269 = $335;$272 = $336;$275 = $337;$behaviorFlags$21416 = $behaviorFlags$214;$timeCoeff$01317 = $timeCoeff$013;
  } else {
   label = 21;
  }
 }
 if ((label|0) == 21) {
  $333 = (($this) + 485|0);
  $334 = HEAP8[$333>>0]|0;
  $extract$t = ($334<<24>>24)!=(0);
  $standingOnMoving$0$off0 = $extract$t;
  STACKTOP = sp;return ($standingOnMoving$0$off0|0);
 }
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($269)))));
 $270 = +$fabsf$i$i$i;
 $271 = $270 > 9.99999999999999954748E-7;
 if ($271) {
  label = 15;
 } else {
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($272)))));
  $273 = +$fabsf$i$i1$i;
  $274 = $273 > 9.99999999999999954748E-7;
  if ($274) {
   label = 15;
  } else {
   $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($275)))));
   $276 = +$fabsf$i$i2$i;
   $277 = $276 > 9.99999999999999954748E-7;
   if ($277) {
    label = 15;
   } else {
    $278 = (($this) + 485|0);
    HEAP8[$278>>0] = 0;
    $338 = 0;
   }
  }
 }
 if ((label|0) == 15) {
  $279 = (($this) + 485|0);
  HEAP8[$279>>0] = 1;
  $280 = Math_fround(HEAPF32[$upDirection>>2]);
  $281 = Math_fround($269 * $280);
  $282 = (($upDirection) + 4|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = Math_fround($272 * $283);
  $285 = Math_fround($281 + $284);
  $286 = (($upDirection) + 8|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $288 = Math_fround($275 * $287);
  $289 = Math_fround($285 + $288);
  $290 = $289 > Math_fround(0.0);
  $291 = Math_fround($280 * $289);
  $292 = Math_fround($283 * $289);
  $293 = Math_fround($287 * $289);
  $294 = Math_fround($269 - $291);
  $295 = Math_fround($272 - $292);
  $296 = Math_fround($275 - $293);
  if ($290) {
   $297 = +$291;
   $298 = (($volume) + 8|0);
   $299 = +HEAPF64[$298>>3];
   $300 = $297 + $299;
   HEAPF64[$298>>3] = $300;
   $301 = +$292;
   $302 = (($volume) + 16|0);
   $303 = +HEAPF64[$302>>3];
   $304 = $301 + $303;
   HEAPF64[$302>>3] = $304;
   $305 = +$293;
   $306 = (($volume) + 24|0);
   $307 = +HEAPF64[$306>>3];
   $308 = $305 + $307;
   HEAPF64[$306>>3] = $308;
  } else {
   $309 = Math_fround(HEAPF32[$disp>>2]);
   $310 = Math_fround($291 + $309);
   HEAPF32[$disp>>2] = $310;
   $311 = (($disp) + 4|0);
   $312 = Math_fround(HEAPF32[$311>>2]);
   $313 = Math_fround($292 + $312);
   HEAPF32[$311>>2] = $313;
   $314 = (($disp) + 8|0);
   $315 = Math_fround(HEAPF32[$314>>2]);
   $316 = Math_fround($293 + $315);
   HEAPF32[$314>>2] = $316;
  }
  $317 = $behaviorFlags$21416 & 1;
  $318 = ($317|0)==(0);
  if ($318) {
   $338 = 1;
  } else {
   $319 = Math_fround(HEAPF32[$disp>>2]);
   $320 = Math_fround($294 + $319);
   HEAPF32[$disp>>2] = $320;
   $321 = (($disp) + 4|0);
   $322 = Math_fround(HEAPF32[$321>>2]);
   $323 = Math_fround($295 + $322);
   HEAPF32[$321>>2] = $323;
   $324 = (($disp) + 8|0);
   $325 = Math_fround(HEAPF32[$324>>2]);
   $326 = Math_fround($296 + $325);
   HEAPF32[$324>>2] = $326;
   $338 = 1;
  }
 }
 $327 = Math_fround($269 * $timeCoeff$01317);
 $328 = Math_fround($272 * $timeCoeff$01317);
 $329 = Math_fround($275 * $timeCoeff$01317);
 $330 = (($this) + 432|0);
 HEAPF32[$330>>2] = $327;
 $331 = (($this) + 436|0);
 HEAPF32[$331>>2] = $328;
 $332 = (($this) + 440|0);
 HEAPF32[$332>>2] = $329;
 $standingOnMoving$0$off0 = $338;
 STACKTOP = sp;return ($standingOnMoving$0$off0|0);
}
function __ZN5physx3Cct10Controller4moveERNS0_11SweptVolumeERKNS_6PxVec3EffRKNS_19PxControllerFiltersEPKNS_17PxObstacleContextEb($agg$result,$this,$volume,$originalDisp,$minDist,$elapsedTime,$filters,$obstacleContext,$constrainedClimbingMode) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $volume = $volume|0;
 $originalDisp = $originalDisp|0;
 $minDist = Math_fround($minDist);
 $elapsedTime = Math_fround($elapsedTime);
 $filters = $filters|0;
 $obstacleContext = $obstacleContext|0;
 $constrainedClimbingMode = $constrainedClimbingMode|0;
 var $$pr = 0, $$pr$pre = 0, $$pre = 0, $$pre$i16 = 0, $$pre$i23 = 0, $$pre$i4 = 0, $$pre$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0.0, $334 = Math_fround(0), $335 = 0, $336 = 0.0, $337 = Math_fround(0), $338 = 0, $339 = 0.0, $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0);
 var $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0);
 var $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0);
 var $416 = Math_fround(0), $417 = 0, $418 = 0.0, $419 = 0.0, $42 = 0, $420 = 0.0, $421 = 0, $422 = 0.0, $423 = 0.0, $424 = 0.0, $425 = 0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0.0, $43 = Math_fround(0), $430 = 0.0, $431 = 0.0, $432 = 0, $433 = Math_fround(0);
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0;
 var $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = 0.0, $482 = Math_fround(0), $483 = 0.0, $484 = Math_fround(0), $485 = 0.0, $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0);
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0.0, $521 = 0, $522 = 0.0, $523 = 0;
 var $524 = 0.0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0);
 var $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = 0, $547 = 0, $548 = Math_fround(0), $549 = 0, $55 = 0, $550 = Math_fround(0), $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0.0, $562 = 0.0, $563 = Math_fround(0), $564 = 0.0, $565 = 0.0, $566 = Math_fround(0), $567 = 0.0, $568 = 0.0, $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0.0, $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = 0.0, $583 = Math_fround(0), $584 = 0, $585 = 0.0, $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = 0, $593 = Math_fround(0), $594 = 0, $595 = Math_fround(0), $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0);
 var $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $absPose = 0, $brmerge = 0, $brmerge68 = 0, $disp = 0, $exitcond = 0, $exitcond60 = 0, $exitcond61 = 0, $extraBox = 0, $filterData$i = 0, $findGeomData = 0, $hitFlags$i = 0;
 var $i$057 = 0, $i1$052 = 0, $i3$050 = 0, $i5$049 = 0, $not$$i = 0, $obb = 0, $obstacles$0 = 0, $out = 0, $phitmp = 0, $shape = 0, $standingOnMoving$0$off0 = 0, $targetPose = 0, $userHitData = 0, $userObstacles = 0, $worldCapule = 0, $xpDisp = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $filterData$i = sp + 528|0;
 $0 = sp + 512|0;
 $hitFlags$i = sp + 548|0;
 $disp = sp + 496|0;
 $shape = sp + 492|0;
 $1 = sp + 552|0;
 $obb = sp + 112|0;
 $2 = sp + 488|0;
 $worldCapule = sp + 56|0;
 $3 = sp + 484|0;
 $extraBox = sp;
 $4 = sp + 480|0;
 $out = sp + 376|0;
 $5 = sp + 200|0;
 $6 = sp + 172|0;
 $7 = sp + 168|0;
 $absPose = sp + 232|0;
 $userObstacles = sp + 280|0;
 $userHitData = sp + 304|0;
 $findGeomData = sp + 320|0;
 $8 = sp + 551|0;
 $xpDisp = sp + 332|0;
 $9 = sp + 550|0;
 $targetPose = sp + 344|0;
 $10 = (($this) + 468|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 + $elapsedTime);
 HEAPF32[$10>>2] = $12;
 $13 = (($this) + 464|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 88|0);
 HEAP32[$19>>2] = $16;
 $20 = (($this) + 92|0);
 HEAP32[$20>>2] = $18;
 $21 = (($this) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 312|0);
 HEAP32[$23>>2] = $22;
 $24 = (($this) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 316|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($this) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 320|0);
 HEAPF32[$29>>2] = $28;
 $30 = (($this) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 324|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($this) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($this) + 328|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($this) + 28|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($this) + 332|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($this) + 32|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 336|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($this) + 36|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($this) + 340|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($this) + 344|0);
 $46 = (($this) + 40|0);
 ;HEAP32[$45+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$46+12>>2]|0;HEAP32[$45+16>>2]=HEAP32[$46+16>>2]|0;HEAP32[$45+20>>2]=HEAP32[$46+20>>2]|0;HEAP32[$45+24>>2]=HEAP32[$46+24>>2]|0;HEAP8[$45+28>>0]=HEAP8[$46+28>>0]|0;
 $47 = (($this) + 396|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 | 128;
 HEAP32[$47>>2] = $49;
 $50 = (($14) + 128|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $51);
 $53 = (($this) + 364|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($14) + 132|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = (($this) + 368|0);
 HEAP8[$56>>0] = $55;
 $57 = (($14) + 133|0);
 $58 = HEAP8[$57>>0]|0;
 $59 = (($this) + 370|0);
 HEAP8[$59>>0] = $58;
 $60 = (($14) + 134|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = (($this) + 371|0);
 HEAP8[$62>>0] = $61;
 $63 = (($14) + 135|0);
 $64 = HEAP8[$63>>0]|0;
 $65 = (($this) + 372|0);
 HEAP8[$65>>0] = $64;
 $66 = (($this) + 388|0);
 $67 = $66;
 $68 = $67;
 HEAP16[$68>>1]=0&65535;HEAP16[$68+2>>1]=0>>>16;
 $69 = (($67) + 4)|0;
 $70 = $69;
 HEAP16[$70>>1]=0&65535;HEAP16[$70+2>>1]=0>>>16;
 $71 = (($this) + 28|0);
 $72 = Math_fround(HEAPF32[$originalDisp>>2]);
 $73 = (($this) + 444|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($72 + $74);
 $76 = (($originalDisp) + 4|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($this) + 448|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($77 + $79);
 $81 = (($originalDisp) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($this) + 452|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($82 + $84);
 HEAPF32[$disp>>2] = $75;
 $86 = (($disp) + 4|0);
 HEAPF32[$86>>2] = $80;
 $87 = (($disp) + 8|0);
 HEAPF32[$87>>2] = $85;
 HEAPF32[$73>>2] = Math_fround(0.0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $88 = (($this) + 248|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($89|0)==(0|0);
 $$pre = (($this) + 244|0);
 L1: do {
  if (!($90)) {
   $91 = HEAP32[$$pre>>2]|0;
   $92 = ($91|0)==(0|0);
   if (!($92)) {
    $93 = HEAP32[$89>>2]|0;
    $94 = (($93) + 104|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (FUNCTION_TABLE_ii[$95 & 4095]($89)|0);
    $97 = ($96|0)==(0);
    L4: do {
     if (!($97)) {
      $i$057 = 0;
      while(1) {
       HEAP32[$shape>>2] = 0;
       $100 = HEAP32[$88>>2]|0;
       $101 = HEAP32[$100>>2]|0;
       $102 = (($101) + 108|0);
       $103 = HEAP32[$102>>2]|0;
       (FUNCTION_TABLE_iiiii[$103 & 511]($100,$shape,1,$i$057)|0);
       $104 = HEAP32[$shape>>2]|0;
       $105 = HEAP32[$$pre>>2]|0;
       $106 = ($104|0)==($105|0);
       $99 = (($i$057) + 1)|0;
       if ($106) {
        break;
       }
       $98 = ($99>>>0)<($96>>>0);
       if ($98) {
        $i$057 = $99;
       } else {
        break L4;
       }
      }
      $107 = HEAP32[$88>>2]|0;
      $108 = HEAP32[$107>>2]|0;
      $109 = (($108) + 28|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = (FUNCTION_TABLE_ii[$110 & 4095]($107)|0);
      $112 = (($this) + 456|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = ($111|0)==($113|0);
      if (!($114)) {
       HEAP32[$$pre>>2] = 0;
       HEAP32[$88>>2] = 0;
       break L1;
      }
      $115 = HEAP32[$$pre>>2]|0;
      $116 = HEAP32[$115>>2]|0;
      $117 = (($116) + 136|0);
      $118 = HEAP32[$117>>2]|0;
      FUNCTION_TABLE_vii[$118 & 4095]($1,$115);
      $119 = HEAP8[$1>>0]|0;
      $120 = $119 & 2;
      $121 = ($120<<24>>24)==(0);
      if ($121) {
       HEAP32[$$pre>>2] = 0;
       HEAP32[$88>>2] = 0;
       break L1;
      }
      $122 = HEAP32[$filters>>2]|0;
      $123 = ($122|0)==(0|0);
      if ($123) {
       ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
      } else {
       ;HEAP32[$0+0>>2]=HEAP32[$122+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$122+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$122+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$122+12>>2]|0;
      }
      ;HEAP32[$filterData$i+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$filterData$i+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$filterData$i+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$filterData$i+12>>2]=HEAP32[$0+12>>2]|0;
      $124 = (($filterData$i) + 16|0);
      HEAP16[$124>>1] = 6;
      $125 = (($filterData$i) + 18|0);
      HEAP8[$125>>0] = 0;
      HEAP16[$hitFlags$i>>1] = 4;
      $126 = (($filters) + 4|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ($127|0)==(0|0);
      if ($128) {
       break L1;
      }
      $129 = HEAP32[$127>>2]|0;
      $130 = HEAP32[$129>>2]|0;
      $131 = HEAP32[$$pre>>2]|0;
      $132 = HEAP32[$88>>2]|0;
      $133 = (FUNCTION_TABLE_iiiiii[$130 & 255]($127,$filterData$i,$131,$132,$hitFlags$i)|0);
      $not$$i = ($133|0)==(0);
      if (!($not$$i)) {
       break L1;
      }
      HEAP32[$$pre>>2] = 0;
      HEAP32[$88>>2] = 0;
      break L1;
     }
    } while(0);
    HEAP32[$88>>2] = 0;
    HEAP32[$$pre>>2] = 0;
   }
  }
 } while(0);
 $134 = HEAP32[$$pre>>2]|0;
 $135 = ($134|0)==(0|0);
 if ($135) {
  $136 = (($this) + 240|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = ($137|0)==(-1);
  if ($138) {
   __ZN5physx3Cct10Controller17findTouchedObjectERKNS_19PxControllerFiltersEPKNS_17PxObstacleContextERKNS_6PxVec3E($this,$filters,$obstacleContext,$71);
   $$pr$pre = HEAP32[$$pre>>2]|0;
   $phitmp = ($$pr$pre|0)==(0|0);
   if ($phitmp) {
    $$pr = HEAP32[$136>>2]|0;
    $139 = ($$pr|0)==(-1);
    if ($139) {
     $141 = (($this) + 485|0);
     HEAP8[$141>>0] = 0;
     $142 = (($this) + 432|0);
     HEAPF32[$142>>2] = Math_fround(0.0);
     $143 = (($this) + 436|0);
     HEAPF32[$143>>2] = Math_fround(0.0);
     $144 = (($this) + 440|0);
     HEAPF32[$144>>2] = Math_fround(0.0);
     $standingOnMoving$0$off0 = 0;
    } else {
     label = 21;
    }
   } else {
    label = 21;
   }
  } else {
   label = 21;
  }
 } else {
  label = 21;
 }
 if ((label|0) == 21) {
  $140 = (__ZN5physx3Cct10Controller19rideOnTouchedObjectERNS0_11SweptVolumeERKNS_6PxVec3ERS4_PKNS_17PxObstacleContextE($this,$volume,$71,$disp,$obstacleContext)|0);
  $standingOnMoving$0$off0 = $140;
 }
 $145 = HEAP32[$13>>2]|0;
 $146 = (($145) + 16|0);
 $147 = (($145) + 28|0);
 $148 = (($145) + 40|0);
 $149 = (($145) + 52|0);
 $150 = HEAP32[$145>>2]|0;
 $151 = (($150) + 8|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = (FUNCTION_TABLE_ii[$152 & 4095]($145)|0);
 $154 = HEAP32[$13>>2]|0;
 $155 = (__ZN5physx3Cct26CharacterControllerManager14getControllersEv($154)|0);
 $156 = ($153|0)==(0);
 if (!($156)) {
  $157 = (($filters) + 12|0);
  $158 = (($145) + 36|0);
  $159 = (($145) + 32|0);
  $160 = (($obb) + 24|0);
  $161 = (($obb) + 28|0);
  $162 = (($obb) + 32|0);
  $163 = (($obb) + 36|0);
  $164 = (($obb) + 40|0);
  $165 = (($obb) + 44|0);
  $166 = (($obb) + 48|0);
  $167 = (($145) + 24|0);
  $168 = (($145) + 20|0);
  $169 = (($145) + 60|0);
  $170 = (($145) + 56|0);
  $171 = (($145) + 48|0);
  $172 = (($145) + 44|0);
  $i1$052 = 0;
  while(1) {
   $173 = (($155) + ($i1$052<<2)|0);
   $174 = HEAP32[$173>>2]|0;
   $175 = ($174|0)==($this|0);
   do {
    if (!($175)) {
     $176 = HEAP32[$157>>2]|0;
     $177 = ($176|0)==(0|0);
     if (!($177)) {
      $178 = HEAP32[$176>>2]|0;
      $179 = (($178) + 8|0);
      $180 = HEAP32[$179>>2]|0;
      $181 = HEAP32[$this>>2]|0;
      $182 = (($181) + 20|0);
      $183 = HEAP32[$182>>2]|0;
      $184 = (FUNCTION_TABLE_ii[$183 & 4095]($this)|0);
      $185 = HEAP32[$174>>2]|0;
      $186 = (($185) + 20|0);
      $187 = HEAP32[$186>>2]|0;
      $188 = (FUNCTION_TABLE_ii[$187 & 4095]($174)|0);
      $189 = (FUNCTION_TABLE_iiii[$180 & 2047]($176,$184,$188)|0);
      if (!($189)) {
       break;
      }
     }
     $190 = (($174) + 4|0);
     $191 = HEAP32[$190>>2]|0;
     if ((($191|0) == 0)) {
      $192 = ($174|0)==(0|0);
      if ($192) {
       $194 = 0;
      } else {
       $193 = (($174) + -8|0);
       $194 = $193;
      }
      __ZNK5physx3Cct13BoxController6getOBBERNS_13PxExtendedBoxE($194,$obb);
      $195 = HEAP32[$158>>2]|0;
      $196 = $195 & 2147483647;
      $197 = HEAP32[$159>>2]|0;
      $198 = ($196>>>0)>($197>>>0);
      if ($198) {
       $199 = HEAP32[$147>>2]|0;
       $200 = (($199) + (($197*56)|0)|0);
       $201 = ($200|0)==(0|0);
       if ($201) {
        $217 = $197;
       } else {
        ;HEAP32[$200+0>>2]=HEAP32[$obb+0>>2]|0;HEAP32[$200+4>>2]=HEAP32[$obb+4>>2]|0;HEAP32[$200+8>>2]=HEAP32[$obb+8>>2]|0;HEAP32[$200+12>>2]=HEAP32[$obb+12>>2]|0;HEAP32[$200+16>>2]=HEAP32[$obb+16>>2]|0;HEAP32[$200+20>>2]=HEAP32[$obb+20>>2]|0;
        $202 = ((($199) + (($197*56)|0)|0) + 24|0);
        $203 = Math_fround(HEAPF32[$160>>2]);
        HEAPF32[$202>>2] = $203;
        $204 = ((($199) + (($197*56)|0)|0) + 28|0);
        $205 = Math_fround(HEAPF32[$161>>2]);
        HEAPF32[$204>>2] = $205;
        $206 = ((($199) + (($197*56)|0)|0) + 32|0);
        $207 = Math_fround(HEAPF32[$162>>2]);
        HEAPF32[$206>>2] = $207;
        ;HEAP32[$200+0>>2]=HEAP32[$obb+0>>2]|0;HEAP32[$200+4>>2]=HEAP32[$obb+4>>2]|0;HEAP32[$200+8>>2]=HEAP32[$obb+8>>2]|0;HEAP32[$200+12>>2]=HEAP32[$obb+12>>2]|0;HEAP32[$200+16>>2]=HEAP32[$obb+16>>2]|0;HEAP32[$200+20>>2]=HEAP32[$obb+20>>2]|0;
        $208 = ((($199) + (($197*56)|0)|0) + 36|0);
        $209 = Math_fround(HEAPF32[$163>>2]);
        HEAPF32[$208>>2] = $209;
        $210 = ((($199) + (($197*56)|0)|0) + 40|0);
        $211 = Math_fround(HEAPF32[$164>>2]);
        HEAPF32[$210>>2] = $211;
        $212 = ((($199) + (($197*56)|0)|0) + 44|0);
        $213 = Math_fround(HEAPF32[$165>>2]);
        HEAPF32[$212>>2] = $213;
        $214 = ((($199) + (($197*56)|0)|0) + 48|0);
        $215 = Math_fround(HEAPF32[$166>>2]);
        HEAPF32[$214>>2] = $215;
        ;HEAP32[$200+0>>2]=HEAP32[$obb+0>>2]|0;HEAP32[$200+4>>2]=HEAP32[$obb+4>>2]|0;HEAP32[$200+8>>2]=HEAP32[$obb+8>>2]|0;HEAP32[$200+12>>2]=HEAP32[$obb+12>>2]|0;HEAP32[$200+16>>2]=HEAP32[$obb+16>>2]|0;HEAP32[$200+20>>2]=HEAP32[$obb+20>>2]|0;
        $$pre$i23 = HEAP32[$159>>2]|0;
        $217 = $$pre$i23;
       }
       $216 = (($217) + 1)|0;
       HEAP32[$159>>2] = $216;
      } else {
       (__ZN5physx6shdfnd5ArrayINS_13PxExtendedBoxENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($147,$obb)|0);
      }
      $218 = $i1$052 << 16;
      $219 = $218;
      HEAP32[$2>>2] = $219;
      $220 = HEAP32[$167>>2]|0;
      $221 = $220 & 2147483647;
      $222 = HEAP32[$168>>2]|0;
      $223 = ($221>>>0)>($222>>>0);
      if (!($223)) {
       (__ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($146,$2)|0);
       break;
      }
      $224 = HEAP32[$146>>2]|0;
      $225 = (($224) + ($222<<2)|0);
      $226 = ($225|0)==(0|0);
      if (!($226)) {
       HEAP32[$225>>2] = $219;
      }
      $227 = (($222) + 1)|0;
      HEAP32[$168>>2] = $227;
      break;
     } else if ((($191|0) == 1)) {
      $228 = ($174|0)==(0|0);
      if ($228) {
       $230 = 0;
      } else {
       $229 = (($174) + -8|0);
       $230 = $229;
      }
      __ZNK5physx3Cct17CapsuleController10getCapsuleERNS_17PxExtendedCapsuleE($230,$worldCapule);
      $231 = HEAP32[$169>>2]|0;
      $232 = $231 & 2147483647;
      $233 = HEAP32[$170>>2]|0;
      $234 = ($232>>>0)>($233>>>0);
      if ($234) {
       $235 = HEAP32[$149>>2]|0;
       $236 = (($235) + (($233*56)|0)|0);
       $237 = ($236|0)==(0|0);
       if ($237) {
        $239 = $233;
       } else {
        dest=$236+0|0; src=$worldCapule+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $$pre$i16 = HEAP32[$170>>2]|0;
        $239 = $$pre$i16;
       }
       $238 = (($239) + 1)|0;
       HEAP32[$170>>2] = $238;
      } else {
       (__ZN5physx6shdfnd5ArrayINS_17PxExtendedCapsuleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($149,$worldCapule)|0);
      }
      $240 = $i1$052 << 16;
      $241 = $240;
      HEAP32[$3>>2] = $241;
      $242 = HEAP32[$171>>2]|0;
      $243 = $242 & 2147483647;
      $244 = HEAP32[$172>>2]|0;
      $245 = ($243>>>0)>($244>>>0);
      if (!($245)) {
       (__ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($148,$3)|0);
       break;
      }
      $246 = HEAP32[$148>>2]|0;
      $247 = (($246) + ($244<<2)|0);
      $248 = ($247|0)==(0|0);
      if (!($248)) {
       HEAP32[$247>>2] = $241;
      }
      $249 = (($244) + 1)|0;
      HEAP32[$172>>2] = $249;
      break;
     } else {
      break;
     }
    }
   } while(0);
   $250 = (($i1$052) + 1)|0;
   $exitcond61 = ($250|0)==($153|0);
   if ($exitcond61) {
    break;
   } else {
    $i1$052 = $250;
   }
  }
 }
 $251 = ($obstacleContext|0)==(0|0);
 if ($251) {
  $obstacles$0 = 0;
 } else {
  $252 = (($obstacleContext) + 8|0);
  $253 = HEAP32[$252>>2]|0;
  $254 = ($253|0)==(0);
  if (!($254)) {
   $255 = (($obstacleContext) + 4|0);
   $256 = (($extraBox) + 24|0);
   $257 = (($extraBox) + 28|0);
   $258 = (($extraBox) + 32|0);
   $259 = (($extraBox) + 36|0);
   $260 = (($extraBox) + 40|0);
   $261 = (($extraBox) + 44|0);
   $262 = (($extraBox) + 48|0);
   $263 = (($145) + 36|0);
   $264 = (($145) + 32|0);
   $265 = (($145) + 24|0);
   $266 = (($145) + 20|0);
   $267 = ($16|0)==(0|0);
   $268 = $18 & 4;
   $269 = ($268|0)==(0);
   $270 = (($out) + 36|0);
   $271 = (($out) + 40|0);
   $272 = (($out) + 56|0);
   $273 = (($out) + 60|0);
   $274 = (($out) + 76|0);
   $275 = (($out) + 80|0);
   $276 = (($out) + 96|0);
   $277 = (($out) + 100|0);
   $278 = (($5) + 4|0);
   $279 = (($5) + 8|0);
   $280 = (($5) + 12|0);
   $281 = (($5) + 16|0);
   $282 = (($5) + 20|0);
   $283 = (($5) + 24|0);
   $284 = (($6) + 4|0);
   $285 = (($6) + 8|0);
   $286 = (($6) + 12|0);
   $287 = (($6) + 16|0);
   $288 = (($6) + 20|0);
   $289 = (($6) + 24|0);
   $i3$050 = 0;
   while(1) {
    $290 = HEAP32[$255>>2]|0;
    $291 = ((($290) + (($i3$050*72)|0)|0) + 16|0);
    ;HEAP32[$extraBox+0>>2]=HEAP32[$291+0>>2]|0;HEAP32[$extraBox+4>>2]=HEAP32[$291+4>>2]|0;HEAP32[$extraBox+8>>2]=HEAP32[$291+8>>2]|0;HEAP32[$extraBox+12>>2]=HEAP32[$291+12>>2]|0;HEAP32[$extraBox+16>>2]=HEAP32[$291+16>>2]|0;HEAP32[$extraBox+20>>2]=HEAP32[$291+20>>2]|0;
    $292 = ((($290) + (($i3$050*72)|0)|0) + 56|0);
    $293 = Math_fround(HEAPF32[$292>>2]);
    HEAPF32[$256>>2] = $293;
    $294 = ((($290) + (($i3$050*72)|0)|0) + 60|0);
    $295 = Math_fround(HEAPF32[$294>>2]);
    HEAPF32[$257>>2] = $295;
    $296 = ((($290) + (($i3$050*72)|0)|0) + 64|0);
    $297 = Math_fround(HEAPF32[$296>>2]);
    HEAPF32[$258>>2] = $297;
    $298 = ((($290) + (($i3$050*72)|0)|0) + 40|0);
    $299 = Math_fround(HEAPF32[$298>>2]);
    HEAPF32[$259>>2] = $299;
    $300 = ((($290) + (($i3$050*72)|0)|0) + 44|0);
    $301 = Math_fround(HEAPF32[$300>>2]);
    HEAPF32[$260>>2] = $301;
    $302 = ((($290) + (($i3$050*72)|0)|0) + 48|0);
    $303 = Math_fround(HEAPF32[$302>>2]);
    HEAPF32[$261>>2] = $303;
    $304 = ((($290) + (($i3$050*72)|0)|0) + 52|0);
    $305 = Math_fround(HEAPF32[$304>>2]);
    HEAPF32[$262>>2] = $305;
    $306 = HEAP32[$263>>2]|0;
    $307 = $306 & 2147483647;
    $308 = HEAP32[$264>>2]|0;
    $309 = ($307>>>0)>($308>>>0);
    if ($309) {
     $310 = HEAP32[$147>>2]|0;
     $311 = (($310) + (($308*56)|0)|0);
     $312 = ($311|0)==(0|0);
     if ($312) {
      $321 = $308;
     } else {
      $313 = ((($310) + (($308*56)|0)|0) + 24|0);
      HEAPF32[$313>>2] = $293;
      $314 = ((($310) + (($308*56)|0)|0) + 28|0);
      HEAPF32[$314>>2] = $295;
      $315 = ((($310) + (($308*56)|0)|0) + 32|0);
      HEAPF32[$315>>2] = $297;
      $316 = ((($310) + (($308*56)|0)|0) + 36|0);
      HEAPF32[$316>>2] = $299;
      $317 = ((($310) + (($308*56)|0)|0) + 40|0);
      HEAPF32[$317>>2] = $301;
      $318 = ((($310) + (($308*56)|0)|0) + 44|0);
      HEAPF32[$318>>2] = $303;
      $319 = ((($310) + (($308*56)|0)|0) + 48|0);
      HEAPF32[$319>>2] = $305;
      ;HEAP32[$311+0>>2]=HEAP32[$extraBox+0>>2]|0;HEAP32[$311+4>>2]=HEAP32[$extraBox+4>>2]|0;HEAP32[$311+8>>2]=HEAP32[$extraBox+8>>2]|0;HEAP32[$311+12>>2]=HEAP32[$extraBox+12>>2]|0;HEAP32[$311+16>>2]=HEAP32[$extraBox+16>>2]|0;HEAP32[$311+20>>2]=HEAP32[$extraBox+20>>2]|0;
      $$pre$i9 = HEAP32[$264>>2]|0;
      $321 = $$pre$i9;
     }
     $320 = (($321) + 1)|0;
     HEAP32[$264>>2] = $320;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_13PxExtendedBoxENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($147,$extraBox)|0);
    }
    $322 = $i3$050 << 16;
    $323 = $322 | 1;
    $324 = $323;
    HEAP32[$4>>2] = $324;
    $325 = HEAP32[$265>>2]|0;
    $326 = $325 & 2147483647;
    $327 = HEAP32[$266>>2]|0;
    $328 = ($326>>>0)>($327>>>0);
    if ($328) {
     $329 = HEAP32[$146>>2]|0;
     $330 = (($329) + ($327<<2)|0);
     $331 = ($330|0)==(0|0);
     if (!($331)) {
      HEAP32[$330>>2] = $324;
     }
     $332 = (($327) + 1)|0;
     HEAP32[$266>>2] = $332;
    } else {
     (__ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($146,$4)|0);
    }
    $brmerge = $267 | $269;
    if (!($brmerge)) {
     dest=$out+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAPF32[$270>>2] = Math_fround(1.0);
     ;HEAP32[$271+0>>2]=0|0;HEAP32[$271+4>>2]=0|0;HEAP32[$271+8>>2]=0|0;HEAP32[$271+12>>2]=0|0;
     HEAPF32[$272>>2] = Math_fround(1.0);
     ;HEAP32[$273+0>>2]=0|0;HEAP32[$273+4>>2]=0|0;HEAP32[$273+8>>2]=0|0;HEAP32[$273+12>>2]=0|0;
     HEAPF32[$274>>2] = Math_fround(1.0);
     ;HEAP32[$275+0>>2]=0|0;HEAP32[$275+4>>2]=0|0;HEAP32[$275+8>>2]=0|0;HEAP32[$275+12>>2]=0|0;
     HEAPF32[$276>>2] = Math_fround(1.0);
     HEAP32[$277>>2] = $16;
     (__ZN5physx2Cm12RenderOutputlsEj($out,-16711681)|0);
     $333 = +HEAPF64[$291>>3];
     $334 = Math_fround($333);
     $335 = ((($290) + (($i3$050*72)|0)|0) + 24|0);
     $336 = +HEAPF64[$335>>3];
     $337 = Math_fround($336);
     $338 = ((($290) + (($i3$050*72)|0)|0) + 32|0);
     $339 = +HEAPF64[$338>>3];
     $340 = Math_fround($339);
     $341 = Math_fround(HEAPF32[$298>>2]);
     HEAPF32[$5>>2] = $341;
     $342 = Math_fround(HEAPF32[$300>>2]);
     HEAPF32[$278>>2] = $342;
     $343 = Math_fround(HEAPF32[$302>>2]);
     HEAPF32[$279>>2] = $343;
     $344 = Math_fround(HEAPF32[$304>>2]);
     HEAPF32[$280>>2] = $344;
     HEAPF32[$281>>2] = $334;
     HEAPF32[$282>>2] = $337;
     HEAPF32[$283>>2] = $340;
     (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$5)|0);
     $345 = Math_fround(HEAPF32[$292>>2]);
     $346 = Math_fround(-$345);
     $347 = Math_fround(HEAPF32[$294>>2]);
     $348 = Math_fround(-$347);
     $349 = Math_fround(HEAPF32[$296>>2]);
     $350 = Math_fround(-$349);
     HEAPF32[$6>>2] = $346;
     HEAPF32[$284>>2] = $348;
     HEAPF32[$285>>2] = $350;
     $351 = Math_fround(HEAPF32[$292>>2]);
     HEAPF32[$286>>2] = $351;
     $352 = Math_fround(HEAPF32[$294>>2]);
     HEAPF32[$287>>2] = $352;
     $353 = Math_fround(HEAPF32[$296>>2]);
     HEAPF32[$288>>2] = $353;
     HEAP8[$289>>0] = 1;
     (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$6)|0);
    }
    $354 = (($i3$050) + 1)|0;
    $exitcond60 = ($354|0)==($253|0);
    if ($exitcond60) {
     break;
    } else {
     $i3$050 = $354;
    }
   }
  }
  $355 = (($obstacleContext) + 20|0);
  $356 = HEAP32[$355>>2]|0;
  $357 = ($356|0)==(0);
  if ($357) {
   $obstacles$0 = $obstacleContext;
  } else {
   $358 = (($obstacleContext) + 16|0);
   $359 = (($extraBox) + 8|0);
   $360 = (($extraBox) + 16|0);
   $361 = (($extraBox) + 24|0);
   $362 = (($extraBox) + 32|0);
   $363 = (($extraBox) + 40|0);
   $364 = (($extraBox) + 48|0);
   $365 = (($145) + 60|0);
   $366 = (($145) + 56|0);
   $367 = (($145) + 48|0);
   $368 = (($145) + 44|0);
   $369 = ($16|0)==(0|0);
   $370 = $18 & 4;
   $371 = ($370|0)==(0);
   $372 = (($out) + 36|0);
   $373 = (($out) + 40|0);
   $374 = (($out) + 56|0);
   $375 = (($out) + 60|0);
   $376 = (($out) + 76|0);
   $377 = (($out) + 80|0);
   $378 = (($out) + 96|0);
   $379 = (($out) + 100|0);
   $380 = (($absPose) + 4|0);
   $381 = (($absPose) + 8|0);
   $382 = (($absPose) + 12|0);
   $383 = (($absPose) + 16|0);
   $384 = (($absPose) + 20|0);
   $385 = (($absPose) + 24|0);
   $386 = (($absPose) + 28|0);
   $387 = (($absPose) + 32|0);
   $388 = (($absPose) + 36|0);
   $389 = (($absPose) + 40|0);
   $390 = (($absPose) + 44|0);
   $i5$049 = 0;
   while(1) {
    $391 = HEAP32[$358>>2]|0;
    $392 = ((($391) + ($i5$049<<6)|0) + 40|0);
    $393 = Math_fround(HEAPF32[$392>>2]);
    $394 = Math_fround($393 * Math_fround(2.0));
    $395 = ((($391) + ($i5$049<<6)|0) + 52|0);
    $396 = Math_fround(HEAPF32[$395>>2]);
    $397 = Math_fround($396 * Math_fround(2.0));
    $398 = Math_fround($396 * $397);
    $399 = Math_fround($398 + Math_fround(-1.0));
    $400 = Math_fround($393 * $394);
    $401 = Math_fround($400 + $399);
    $402 = ((($391) + ($i5$049<<6)|0) + 48|0);
    $403 = Math_fround(HEAPF32[$402>>2]);
    $404 = Math_fround($403 * $397);
    $405 = ((($391) + ($i5$049<<6)|0) + 44|0);
    $406 = Math_fround(HEAPF32[$405>>2]);
    $407 = Math_fround($394 * $406);
    $408 = Math_fround($404 + $407);
    $409 = Math_fround($397 * $406);
    $410 = Math_fround($394 * $403);
    $411 = Math_fround($410 - $409);
    $412 = ((($391) + ($i5$049<<6)|0) + 56|0);
    $413 = Math_fround(HEAPF32[$412>>2]);
    $414 = Math_fround($413 * $401);
    $415 = Math_fround($413 * $408);
    $416 = Math_fround($413 * $411);
    $417 = ((($391) + ($i5$049<<6)|0) + 16|0);
    $418 = +HEAPF64[$417>>3];
    $419 = +$414;
    $420 = $418 - $419;
    $421 = ((($391) + ($i5$049<<6)|0) + 24|0);
    $422 = +HEAPF64[$421>>3];
    $423 = +$415;
    $424 = $422 - $423;
    $425 = ((($391) + ($i5$049<<6)|0) + 32|0);
    $426 = +HEAPF64[$425>>3];
    $427 = +$416;
    $428 = $426 - $427;
    HEAPF64[$extraBox>>3] = $420;
    HEAPF64[$359>>3] = $424;
    HEAPF64[$360>>3] = $428;
    $429 = $419 + $418;
    $430 = $423 + $422;
    $431 = $427 + $426;
    HEAPF64[$361>>3] = $429;
    HEAPF64[$362>>3] = $430;
    HEAPF64[$363>>3] = $431;
    $432 = ((($391) + ($i5$049<<6)|0) + 60|0);
    $433 = Math_fround(HEAPF32[$432>>2]);
    HEAPF32[$364>>2] = $433;
    $434 = HEAP32[$365>>2]|0;
    $435 = $434 & 2147483647;
    $436 = HEAP32[$366>>2]|0;
    $437 = ($435>>>0)>($436>>>0);
    if ($437) {
     $438 = HEAP32[$149>>2]|0;
     $439 = (($438) + (($436*56)|0)|0);
     $440 = ($439|0)==(0|0);
     if ($440) {
      $442 = $436;
     } else {
      dest=$439+0|0; src=$extraBox+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $$pre$i4 = HEAP32[$366>>2]|0;
      $442 = $$pre$i4;
     }
     $441 = (($442) + 1)|0;
     HEAP32[$366>>2] = $441;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_17PxExtendedCapsuleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($149,$extraBox)|0);
    }
    $443 = $i5$049 << 16;
    $444 = $443 | 2;
    $445 = $444;
    HEAP32[$7>>2] = $445;
    $446 = HEAP32[$367>>2]|0;
    $447 = $446 & 2147483647;
    $448 = HEAP32[$368>>2]|0;
    $449 = ($447>>>0)>($448>>>0);
    if ($449) {
     $450 = HEAP32[$148>>2]|0;
     $451 = (($450) + ($448<<2)|0);
     $452 = ($451|0)==(0|0);
     if (!($452)) {
      HEAP32[$451>>2] = $445;
     }
     $453 = (($448) + 1)|0;
     HEAP32[$368>>2] = $453;
    } else {
     (__ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($148,$7)|0);
    }
    $brmerge68 = $369 | $371;
    if (!($brmerge68)) {
     dest=$out+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAPF32[$372>>2] = Math_fround(1.0);
     ;HEAP32[$373+0>>2]=0|0;HEAP32[$373+4>>2]=0|0;HEAP32[$373+8>>2]=0|0;HEAP32[$373+12>>2]=0|0;
     HEAPF32[$374>>2] = Math_fround(1.0);
     ;HEAP32[$375+0>>2]=0|0;HEAP32[$375+4>>2]=0|0;HEAP32[$375+8>>2]=0|0;HEAP32[$375+12>>2]=0|0;
     HEAPF32[$376>>2] = Math_fround(1.0);
     ;HEAP32[$377+0>>2]=0|0;HEAP32[$377+4>>2]=0|0;HEAP32[$377+8>>2]=0|0;HEAP32[$377+12>>2]=0|0;
     HEAPF32[$378>>2] = Math_fround(1.0);
     HEAP32[$379>>2] = $16;
     (__ZN5physx2Cm12RenderOutputlsEj($out,-16711681)|0);
     $454 = Math_fround(HEAPF32[$392>>2]);
     $455 = Math_fround(HEAPF32[$405>>2]);
     $456 = Math_fround(HEAPF32[$402>>2]);
     $457 = Math_fround(HEAPF32[$395>>2]);
     $458 = Math_fround($454 + $454);
     $459 = Math_fround($455 + $455);
     $460 = Math_fround($456 + $456);
     $461 = Math_fround($454 * $458);
     $462 = Math_fround($455 * $459);
     $463 = Math_fround($456 * $460);
     $464 = Math_fround($458 * $455);
     $465 = Math_fround($458 * $456);
     $466 = Math_fround($458 * $457);
     $467 = Math_fround($459 * $456);
     $468 = Math_fround($459 * $457);
     $469 = Math_fround($460 * $457);
     $470 = Math_fround(Math_fround(1.0) - $462);
     $471 = Math_fround($470 - $463);
     $472 = Math_fround($464 + $469);
     $473 = Math_fround($465 - $468);
     $474 = Math_fround($464 - $469);
     $475 = Math_fround(Math_fround(1.0) - $461);
     $476 = Math_fround($475 - $463);
     $477 = Math_fround($467 + $466);
     $478 = Math_fround($465 + $468);
     $479 = Math_fround($467 - $466);
     $480 = Math_fround($475 - $462);
     HEAPF32[$absPose>>2] = $471;
     HEAPF32[$380>>2] = $472;
     HEAPF32[$381>>2] = $473;
     HEAPF32[$382>>2] = $474;
     HEAPF32[$383>>2] = $476;
     HEAPF32[$384>>2] = $477;
     HEAPF32[$385>>2] = $478;
     HEAPF32[$386>>2] = $479;
     HEAPF32[$387>>2] = $480;
     $481 = +HEAPF64[$417>>3];
     $482 = Math_fround($481);
     $483 = +HEAPF64[$421>>3];
     $484 = Math_fround($483);
     $485 = +HEAPF64[$425>>3];
     $486 = Math_fround($485);
     HEAPF32[$388>>2] = $482;
     HEAPF32[$389>>2] = $484;
     HEAPF32[$390>>2] = $486;
     $487 = Math_fround(HEAPF32[$432>>2]);
     $488 = Math_fround(HEAPF32[$412>>2]);
     (__ZN5physx2Cm12RenderOutput13outputCapsuleEffRKNS0_8Matrix34E($out,$487,$488,$absPose)|0);
    }
    $489 = (($i5$049) + 1)|0;
    $exitcond = ($489|0)==($356|0);
    if ($exitcond) {
     $obstacles$0 = $obstacleContext;
     break;
    } else {
     $i5$049 = $489;
    }
   }
  }
 }
 $490 = (($145) + 32|0);
 $491 = HEAP32[$490>>2]|0;
 HEAP32[$userObstacles>>2] = $491;
 $492 = ($491|0)==(0);
 if ($492) {
  $496 = (($userObstacles) + 4|0);
  HEAP32[$496>>2] = 0;
  $498 = 0;
 } else {
  $493 = HEAP32[$147>>2]|0;
  $494 = (($userObstacles) + 4|0);
  HEAP32[$494>>2] = $493;
  $495 = HEAP32[$146>>2]|0;
  $498 = $495;
 }
 $497 = (($userObstacles) + 8|0);
 HEAP32[$497>>2] = $498;
 $499 = (($145) + 56|0);
 $500 = HEAP32[$499>>2]|0;
 $501 = (($userObstacles) + 12|0);
 HEAP32[$501>>2] = $500;
 $502 = ($500|0)==(0);
 if ($502) {
  $506 = (($userObstacles) + 16|0);
  HEAP32[$506>>2] = 0;
  $508 = 0;
 } else {
  $503 = HEAP32[$149>>2]|0;
  $504 = (($userObstacles) + 16|0);
  HEAP32[$504>>2] = $503;
  $505 = HEAP32[$148>>2]|0;
  $508 = $505;
 }
 $507 = (($userObstacles) + 20|0);
 HEAP32[$507>>2] = $508;
 HEAP32[$userHitData>>2] = $this;
 $509 = (($userHitData) + 4|0);
 HEAP32[$509>>2] = $obstacles$0;
 $510 = (($this) + 456|0);
 $511 = HEAP32[$510>>2]|0;
 HEAP32[$findGeomData>>2] = $511;
 $512 = (($findGeomData) + 4|0);
 HEAP32[$512>>2] = $16;
 $513 = HEAP32[$13>>2]|0;
 $514 = (($513) + 76|0);
 $515 = (($findGeomData) + 8|0);
 HEAP32[$515>>2] = $514;
 $516 = HEAP32[$47>>2]|0;
 $517 = $516 & -3;
 HEAP32[$47>>2] = $517;
 $518 = (($volume) + 8|0);
 $519 = (($volume) + 8|0);
 $520 = +HEAPF64[$519>>3];
 $521 = (($volume) + 16|0);
 $522 = +HEAPF64[$521>>3];
 $523 = (($volume) + 24|0);
 $524 = +HEAPF64[$523>>3];
 __ZN5physx3Cct9SweepTest13moveCharacterEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERNS0_11SweptVolumeERKNS_6PxVec3ERKNS0_13UserObstaclesEfRKNS_19PxControllerFiltersEbb($8,$19,$findGeomData,$userHitData,$volume,$disp,$userObstacles,$minDist,$filters,$constrainedClimbingMode,$standingOnMoving$0$off0);
 $525 = HEAP8[$8>>0]|0;
 HEAP8[$agg$result>>0] = $525;
 $526 = HEAP32[$47>>2]|0;
 $527 = $526 & 1;
 $528 = ($527|0)==(0);
 if ($528) {
  $556 = $525;
 } else {
  $529 = $526 | 2;
  HEAP32[$47>>2] = $529;
  HEAPF64[$519>>3] = $520;
  HEAPF64[$521>>3] = $522;
  HEAPF64[$523>>3] = $524;
  $530 = HEAP32[$21>>2]|0;
  $531 = ($530|0)==(1);
  $532 = Math_fround(HEAPF32[$disp>>2]);
  if ($531) {
   $533 = Math_fround(HEAPF32[$71>>2]);
   $534 = Math_fround($532 * $533);
   $535 = Math_fround(HEAPF32[$86>>2]);
   $536 = Math_fround(HEAPF32[$39>>2]);
   $537 = Math_fround($535 * $536);
   $538 = Math_fround($534 + $537);
   $539 = Math_fround(HEAPF32[$87>>2]);
   $540 = Math_fround(HEAPF32[$42>>2]);
   $541 = Math_fround($539 * $540);
   $542 = Math_fround($538 + $541);
   $543 = Math_fround($533 * $542);
   $544 = Math_fround($536 * $542);
   $545 = Math_fround($540 * $542);
   HEAPF32[$xpDisp>>2] = $543;
   $546 = (($xpDisp) + 4|0);
   HEAPF32[$546>>2] = $544;
   $547 = (($xpDisp) + 8|0);
   HEAPF32[$547>>2] = $545;
  } else {
   HEAPF32[$xpDisp>>2] = $532;
   $548 = Math_fround(HEAPF32[$86>>2]);
   $549 = (($xpDisp) + 4|0);
   HEAPF32[$549>>2] = $548;
   $550 = Math_fround(HEAPF32[$87>>2]);
   $551 = (($xpDisp) + 8|0);
   HEAPF32[$551>>2] = $550;
  }
  __ZN5physx3Cct9SweepTest13moveCharacterEPKNS0_30InternalCBData_FindTouchedGeomEPKNS0_20InternalCBData_OnHitERNS0_11SweptVolumeERKNS_6PxVec3ERKNS0_13UserObstaclesEfRKNS_19PxControllerFiltersEbb($9,$19,$findGeomData,$userHitData,$volume,$xpDisp,$userObstacles,$minDist,$filters,$constrainedClimbingMode,$standingOnMoving$0$off0);
  $552 = HEAP8[$9>>0]|0;
  HEAP8[$agg$result>>0] = $552;
  $553 = HEAP32[$47>>2]|0;
  $554 = $553 & -3;
  HEAP32[$47>>2] = $554;
  $556 = $552;
 }
 $555 = (($this) + 484|0);
 HEAP8[$555>>0] = $556;
 $557 = (($this) + 408|0);
 ;HEAP32[$557+0>>2]=HEAP32[$518+0>>2]|0;HEAP32[$557+4>>2]=HEAP32[$518+4>>2]|0;HEAP32[$557+8>>2]=HEAP32[$518+8>>2]|0;HEAP32[$557+12>>2]=HEAP32[$518+12>>2]|0;HEAP32[$557+16>>2]=HEAP32[$518+16>>2]|0;HEAP32[$557+20>>2]=HEAP32[$518+20>>2]|0;
 $558 = (($this) + 400|0);
 $559 = HEAP32[$558>>2]|0;
 $560 = ($559|0)==(0|0);
 if ($560) {
  $601 = HEAP32[$13>>2]|0;
  __ZN5physx3Cct26CharacterControllerManager21resetObstaclesBuffersEv($601);
  STACKTOP = sp;return;
 }
 $561 = +HEAPF64[$518>>3];
 $562 = $520 - $561;
 $563 = Math_fround($562);
 $564 = +HEAPF64[$521>>3];
 $565 = $522 - $564;
 $566 = Math_fround($565);
 $567 = +HEAPF64[$523>>3];
 $568 = $524 - $567;
 $569 = Math_fround($568);
 $570 = Math_fround($563 * $563);
 $571 = Math_fround($566 * $566);
 $572 = Math_fround($570 + $571);
 $573 = Math_fround($569 * $569);
 $574 = Math_fround($572 + $573);
 $575 = $574 != Math_fround(0.0);
 if (!($575)) {
  $601 = HEAP32[$13>>2]|0;
  __ZN5physx3Cct26CharacterControllerManager21resetObstaclesBuffersEv($601);
  STACKTOP = sp;return;
 }
 $576 = HEAP32[$559>>2]|0;
 $577 = (($576) + 84|0);
 $578 = HEAP32[$577>>2]|0;
 FUNCTION_TABLE_vii[$578 & 4095]($targetPose,$559);
 $579 = +HEAPF64[$557>>3];
 $580 = Math_fround($579);
 $581 = (($this) + 416|0);
 $582 = +HEAPF64[$581>>3];
 $583 = Math_fround($582);
 $584 = (($this) + 424|0);
 $585 = +HEAPF64[$584>>3];
 $586 = Math_fround($585);
 $587 = (($targetPose) + 16|0);
 HEAPF32[$587>>2] = $580;
 $588 = (($targetPose) + 20|0);
 HEAPF32[$588>>2] = $583;
 $589 = (($targetPose) + 24|0);
 HEAPF32[$589>>2] = $586;
 $590 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$targetPose>>2] = $590;
 $591 = Math_fround(HEAPF32[$27>>2]);
 $592 = (($targetPose) + 4|0);
 HEAPF32[$592>>2] = $591;
 $593 = Math_fround(HEAPF32[$30>>2]);
 $594 = (($targetPose) + 8|0);
 HEAPF32[$594>>2] = $593;
 $595 = Math_fround(HEAPF32[$33>>2]);
 $596 = (($targetPose) + 12|0);
 HEAPF32[$596>>2] = $595;
 $597 = HEAP32[$558>>2]|0;
 $598 = HEAP32[$597>>2]|0;
 $599 = (($598) + 224|0);
 $600 = HEAP32[$599>>2]|0;
 FUNCTION_TABLE_vii[$600 & 4095]($597,$targetPose);
 $601 = HEAP32[$13>>2]|0;
 __ZN5physx3Cct26CharacterControllerManager21resetObstaclesBuffersEv($601);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct13BoxController4moveERKNS_6PxVec3EffRKNS_19PxControllerFiltersEPKNS_17PxObstacleContextE($agg$result,$this,$disp,$minDist,$elapsedTime,$filters,$obstacles) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $disp = $disp|0;
 $minDist = Math_fround($minDist);
 $elapsedTime = Math_fround($elapsedTime);
 $filters = $filters|0;
 $obstacles = $obstacles|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $sweptBox = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $sweptBox = sp;
 __ZN5physx3Cct8SweptBoxC2Ev($sweptBox);
 $0 = (($sweptBox) + 8|0);
 $1 = (($this) + 8|0);
 $2 = (($this) + 416|0);
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$2+20>>2]|0;
 $3 = (($this) + 496|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 500|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 504|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($sweptBox) + 40|0);
 HEAPF32[$9>>2] = $4;
 $10 = (($sweptBox) + 44|0);
 HEAPF32[$10>>2] = $6;
 $11 = (($sweptBox) + 48|0);
 HEAPF32[$11>>2] = $8;
 $12 = (($sweptBox) + 32|0);
 HEAPF32[$12>>2] = $4;
 __ZN5physx3Cct10Controller4moveERNS0_11SweptVolumeERKNS_6PxVec3EffRKNS_19PxControllerFiltersEPKNS_17PxObstacleContextEb($agg$result,$1,$sweptBox,$disp,$minDist,$elapsedTime,$filters,$obstacles,0);
 __ZN5physx3Cct8SweptBoxD2Ev($sweptBox);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct17CapsuleController4moveERKNS_6PxVec3EffRKNS_19PxControllerFiltersEPKNS_17PxObstacleContextE($agg$result,$this,$disp,$minDist,$elapsedTime,$filters,$obstacles) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $disp = $disp|0;
 $minDist = Math_fround($minDist);
 $elapsedTime = Math_fround($elapsedTime);
 $filters = $filters|0;
 $obstacles = $obstacles|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $sweptCapsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $sweptCapsule = sp;
 __ZN5physx3Cct12SweptCapsuleC2Ev($sweptCapsule);
 $0 = (($sweptCapsule) + 8|0);
 $1 = (($this) + 8|0);
 $2 = (($this) + 416|0);
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$2+20>>2]|0;
 $3 = (($this) + 496|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($sweptCapsule) + 40|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($this) + 500|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($sweptCapsule) + 44|0);
 HEAPF32[$8>>2] = $7;
 $9 = Math_fround($7 * Math_fround(0.5));
 $10 = Math_fround($9 + $4);
 $11 = (($sweptCapsule) + 32|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($this) + 504|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(1);
 __ZN5physx3Cct10Controller4moveERNS0_11SweptVolumeERKNS_6PxVec3EffRKNS_19PxControllerFiltersEPKNS_17PxObstacleContextEb($agg$result,$1,$sweptCapsule,$disp,$minDist,$elapsedTime,$filters,$obstacles,$14);
 __ZN5physx3Cct12SweptCapsuleD2Ev($sweptCapsule);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_17PxExtendedCapsuleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*56)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 404088 : 404056;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,403976,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*56)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    dest=$$012$i+0|0; src=$$03$i+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $25 = (($$012$i) + 56|0);
   $26 = (($$03$i) + 56|0);
   $27 = ($25>>>0)<($20>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $19;
 }
 $28 = (($21) + (($29*56)|0)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  dest=$28+0|0; src=$a+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = HEAP32[$18>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$18>>2] = $40;
 $41 = (($21) + (($39*56)|0)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 404216 : 404056;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,403976,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayINS_13PxExtendedBoxENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0;
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*56)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 404320 : 404056;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,403976,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*56)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;
    $25 = (($$012$i) + 24|0);
    $26 = (($$03$i) + 24|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    HEAPF32[$25>>2] = $27;
    $28 = (($$012$i) + 28|0);
    $29 = (($$03$i) + 28|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$28>>2] = $30;
    $31 = (($$012$i) + 32|0);
    $32 = (($$03$i) + 32|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    HEAPF32[$31>>2] = $33;
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;
    $34 = (($$012$i) + 36|0);
    $35 = (($$03$i) + 36|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    HEAPF32[$34>>2] = $36;
    $37 = (($$012$i) + 40|0);
    $38 = (($$03$i) + 40|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    HEAPF32[$37>>2] = $39;
    $40 = (($$012$i) + 44|0);
    $41 = (($$03$i) + 44|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    HEAPF32[$40>>2] = $42;
    $43 = (($$012$i) + 48|0);
    $44 = (($$03$i) + 48|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$43>>2] = $45;
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;
   }
   $46 = (($$012$i) + 56|0);
   $47 = (($$03$i) + 56|0);
   $48 = ($46>>>0)<($20>>>0);
   if ($48) {
    $$012$i = $46;$$03$i = $47;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $50 = $$pre;
 } else {
  $50 = $19;
 }
 $49 = (($21) + (($50*56)|0)|0);
 $51 = ($49|0)==(0|0);
 if (!($51)) {
  ;HEAP32[$49+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$49+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$49+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$49+20>>2]=HEAP32[$a+20>>2]|0;
  $52 = ((($21) + (($50*56)|0)|0) + 24|0);
  $53 = (($a) + 24|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  HEAPF32[$52>>2] = $54;
  $55 = ((($21) + (($50*56)|0)|0) + 28|0);
  $56 = (($a) + 28|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  HEAPF32[$55>>2] = $57;
  $58 = ((($21) + (($50*56)|0)|0) + 32|0);
  $59 = (($a) + 32|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  HEAPF32[$58>>2] = $60;
  ;HEAP32[$49+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$49+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$49+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$49+20>>2]=HEAP32[$a+20>>2]|0;
  $61 = ((($21) + (($50*56)|0)|0) + 36|0);
  $62 = (($a) + 36|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  HEAPF32[$61>>2] = $63;
  $64 = ((($21) + (($50*56)|0)|0) + 40|0);
  $65 = (($a) + 40|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$64>>2] = $66;
  $67 = ((($21) + (($50*56)|0)|0) + 44|0);
  $68 = (($a) + 44|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  HEAPF32[$67>>2] = $69;
  $70 = ((($21) + (($50*56)|0)|0) + 48|0);
  $71 = (($a) + 48|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  HEAPF32[$70>>2] = $72;
  ;HEAP32[$49+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$49+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$49+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$49+20>>2]=HEAP32[$a+20>>2]|0;
 }
 $73 = HEAP32[$0>>2]|0;
 $74 = ($73|0)>(-1);
 if (!($74)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $81 = HEAP32[$18>>2]|0;
  $82 = (($81) + 1)|0;
  HEAP32[$18>>2] = $82;
  $83 = (($21) + (($81*56)|0)|0);
  STACKTOP = sp;return ($83|0);
 }
 $75 = HEAP32[$this>>2]|0;
 $76 = ($75|0)==(0|0);
 if ($76) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $81 = HEAP32[$18>>2]|0;
  $82 = (($81) + 1)|0;
  HEAP32[$18>>2] = $82;
  $83 = (($21) + (($81*56)|0)|0);
  STACKTOP = sp;return ($83|0);
 }
 $77 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 12|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($77,$75);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $81 = HEAP32[$18>>2]|0;
 $82 = (($81) + 1)|0;
 HEAP32[$18>>2] = $82;
 $83 = (($21) + (($81*56)|0)|0);
 STACKTOP = sp;return ($83|0);
}
function __ZN5physx11PxHitBufferINS_12PxRaycastHitEE14processTouchesEPKS1_j($this,$buffer,$nbHits) {
 $this = $this|0;
 $buffer = $buffer|0;
 $nbHits = $nbHits|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx13PxHitCallbackINS_12PxRaycastHitEE13finalizeQueryEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx11PxHitBufferINS_12PxRaycastHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 404464 : 404056;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,403976,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN16ControllerFilter9preFilterERKN5physx12PxFilterDataEPKNS0_7PxShapeEPKNS0_12PxRigidActorERNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEE($this,$filterData,$shape,$actor,$queryFlags) {
 $this = $this|0;
 $filterData = $filterData|0;
 $shape = $shape|0;
 $actor = $actor|0;
 $queryFlags = $queryFlags|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$i$i = 0, $index$02$i$i = 0, $index$03$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$shape>>2]|0;
 $2 = (($1) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$shape);
 $4 = HEAP8[$0>>0]|0;
 $5 = $4 & 4;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 L4: do {
  if (!($11)) {
   $12 = $shape;
   $13 = $12 << 15;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 10;
   $17 = $16 ^ $15;
   $18 = ($17*9)|0;
   $19 = $18 >>> 6;
   $20 = $19 ^ $18;
   $21 = $20 << 11;
   $22 = $21 ^ -1;
   $23 = (($20) + ($22))|0;
   $24 = $23 >>> 16;
   $25 = $24 ^ $23;
   $26 = (($10) + -1)|0;
   $27 = $26 & $25;
   $28 = (($8) + 12|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + ($27<<2)|0);
   $index$02$i$i = HEAP32[$30>>2]|0;
   $31 = ($index$02$i$i|0)==(-1);
   if (!($31)) {
    $32 = (($8) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($8) + 8|0);
    $index$03$i$i = $index$02$i$i;
    while(1) {
     $35 = (($33) + ($index$03$i$i<<2)|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==($shape|0);
     if ($37) {
      break;
     }
     $38 = HEAP32[$34>>2]|0;
     $39 = (($38) + ($index$03$i$i<<2)|0);
     $index$0$i$i = HEAP32[$39>>2]|0;
     $40 = ($index$0$i$i|0)==(-1);
     if ($40) {
      break L4;
     } else {
      $index$03$i$i = $index$0$i$i;
     }
    }
    $41 = ($35|0)==(0|0);
    if (!($41)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $42 = (($this) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = HEAP32[$43>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = (FUNCTION_TABLE_iiiiii[$46 & 255]($43,$filterData,$shape,$actor,$queryFlags)|0);
 $$0 = $47;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16ControllerFilter10postFilterERKN5physx12PxFilterDataERKNS0_10PxQueryHitE($this,$filterData,$hit) {
 $this = $this|0;
 $filterData = $filterData|0;
 $hit = $hit|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($1,$filterData,$hit)|0);
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16ControllerFilterD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZL15SweepBoxUserBoxPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$i = 0, $$idx$val = 0.0, $$idx$val$i = 0.0, $$idx1$i = 0, $$idx1$val$i = 0.0, $$idx2$val$i = 0.0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = Math_fround(0), $12 = 0;
 var $13 = 0.0, $14 = Math_fround(0), $15 = 0, $16 = 0.0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0.0, $41 = Math_fround(0), $42 = 0, $43 = 0.0, $44 = Math_fround(0), $45 = 0, $46 = 0.0, $47 = Math_fround(0), $48 = 0, $49 = 0;
 var $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0;
 var $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0.0, $85 = 0.0;
 var $86 = 0.0, $87 = 0, $88 = Math_fround(0), $89 = 0.0, $9 = Math_fround(0), $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0, $boxGeom0 = 0, $boxGeom1 = 0, $boxPose0 = 0, $boxPose1 = 0, $center$idx$val = 0.0, $center$idx1 = 0;
 var $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, $sweepHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $boxGeom0 = sp + 128|0;
 $boxPose0 = sp;
 $boxGeom1 = sp + 32|0;
 $boxPose1 = sp + 48|0;
 $sweepHit = sp + 80|0;
 $0 = sp + 144|0;
 HEAP32[$boxGeom0>>2] = 3;
 $1 = (($boxGeom0) + 4|0);
 $2 = (($boxGeom0) + 8|0);
 $3 = (($boxGeom0) + 12|0);
 $4 = (($volume) + 40|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx = (($geom) + 16|0);
 $$idx$val = +HEAPF64[$$idx>>3];
 $$idx3 = (($geom) + 24|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 32|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$1>>2] = $5;
 $6 = (($4) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$2>>2] = $7;
 $8 = (($volume) + 48|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$3>>2] = $9;
 $10 = $center$idx$val - $$idx$val;
 $11 = Math_fround($10);
 $12 = (($boxPose0) + 16|0);
 HEAPF32[$12>>2] = $11;
 $13 = $center$idx1$val - $$idx3$val;
 $14 = Math_fround($13);
 $15 = (($boxPose0) + 20|0);
 HEAPF32[$15>>2] = $14;
 $16 = $center$idx2$val - $$idx4$val;
 $17 = Math_fround($16);
 $18 = (($boxPose0) + 24|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($test) + 228|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$boxPose0>>2] = $20;
 $21 = (($test) + 232|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($boxPose0) + 4|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($test) + 236|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($boxPose0) + 8|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($test) + 240|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($boxPose0) + 12|0);
 HEAPF32[$29>>2] = $28;
 HEAP32[$boxGeom1>>2] = 3;
 $30 = (($boxGeom1) + 4|0);
 $31 = (($boxGeom1) + 8|0);
 $32 = (($boxGeom1) + 12|0);
 $$idx$i = (($geom) + 40|0);
 $$idx$val$i = +HEAPF64[$$idx$i>>3];
 $$idx1$i = (($geom) + 48|0);
 $$idx1$val$i = +HEAPF64[$$idx1$i>>3];
 $33 = (($geom) + 56|0);
 $$idx2$val$i = +HEAPF64[$33>>3];
 $34 = (($geom) + 64|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 HEAPF32[$30>>2] = $35;
 $36 = (($geom) + 68|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 HEAPF32[$31>>2] = $37;
 $38 = (($geom) + 72|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$32>>2] = $39;
 $40 = $$idx$val$i - $$idx$val;
 $41 = Math_fround($40);
 $42 = (($boxPose1) + 16|0);
 HEAPF32[$42>>2] = $41;
 $43 = $$idx1$val$i - $$idx3$val;
 $44 = Math_fround($43);
 $45 = (($boxPose1) + 20|0);
 HEAPF32[$45>>2] = $44;
 $46 = $$idx2$val$i - $$idx4$val;
 $47 = Math_fround($46);
 $48 = (($boxPose1) + 24|0);
 HEAPF32[$48>>2] = $47;
 $49 = (($geom) + 76|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 HEAPF32[$boxPose1>>2] = $50;
 $51 = (($geom) + 80|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($boxPose1) + 4|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($geom) + 84|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($boxPose1) + 8|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($geom) + 88|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($boxPose1) + 12|0);
 HEAPF32[$59>>2] = $58;
 HEAP32[$sweepHit>>2] = 0;
 $60 = (($sweepHit) + 4|0);
 HEAP32[$60>>2] = 0;
 $61 = (($sweepHit) + 8|0);
 HEAP32[$61>>2] = -1;
 $62 = (($sweepHit) + 12|0);
 HEAP16[$62>>1] = 0;
 $63 = (($sweepHit) + 16|0);
 $64 = (($sweepHit) + 40|0);
 ;HEAP32[$63+0>>2]=0|0;HEAP32[$63+4>>2]=0|0;HEAP32[$63+8>>2]=0|0;HEAP32[$63+12>>2]=0|0;HEAP32[$63+16>>2]=0|0;HEAP32[$63+20>>2]=0|0;
 HEAPF32[$64>>2] = Math_fround(3.40282346638528859812E+38);
 $65 = (($impact) + 36|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $$idx5 = (($test) + 283|0);
 $$idx5$val = HEAP8[$$idx5>>0]|0;
 $67 = ($$idx5$val<<24>>24)==(0);
 $$$i = $67 ? 7 : 263;
 HEAP16[$0>>1] = $$$i;
 $68 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$66,$boxGeom0,$boxPose0,$boxGeom1,$boxPose1,$sweepHit,$0,Math_fround(0.0))|0);
 if (!($68)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $69 = Math_fround(HEAPF32[$64>>2]);
 $70 = Math_fround(HEAPF32[$65>>2]);
 $71 = !($69 >= $70);
 if (!($71)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $72 = (($sweepHit) + 28|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($impact) + 24|0);
 HEAPF32[$74>>2] = $73;
 $75 = (($sweepHit) + 32|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($impact) + 28|0);
 HEAPF32[$77>>2] = $76;
 $78 = (($sweepHit) + 36|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($impact) + 32|0);
 HEAPF32[$80>>2] = $79;
 HEAPF32[$65>>2] = $69;
 $81 = (($impact) + 40|0);
 HEAP32[$81>>2] = -1;
 $82 = (($impact) + 44|0);
 HEAP32[$82>>2] = -1;
 $83 = Math_fround(HEAPF32[$63>>2]);
 $84 = +$83;
 $85 = +HEAPF64[$$idx>>3];
 $86 = $84 + $85;
 HEAPF64[$impact>>3] = $86;
 $87 = (($sweepHit) + 20|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = +$88;
 $90 = +HEAPF64[$$idx3>>3];
 $91 = $89 + $90;
 $92 = (($impact) + 8|0);
 HEAPF64[$92>>3] = $91;
 $93 = (($sweepHit) + 24|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = +$94;
 $96 = +HEAPF64[$$idx4>>3];
 $97 = $95 + $96;
 $98 = (($impact) + 16|0);
 HEAPF64[$98>>3] = $97;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL19SweepBoxUserCapsulePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0.0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0.0;
 var $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0.0, $110 = Math_fround(0), $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = Math_fround(0), $120 = 0, $13 = 0, $14 = 0.0, $15 = Math_fround(0), $16 = 0;
 var $17 = 0.0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0;
 var $35 = 0.0, $36 = Math_fround(0), $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0.0;
 var $53 = 0.0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0;
 var $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $boxGeom = 0, $boxPose = 0, $capsuleGeom = 0, $capsulePose = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0;
 var $p0$i = 0, $p1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $0 = sp + 112|0;
 $p0$i = sp;
 $p1$i = sp + 12|0;
 $boxGeom = sp + 24|0;
 $boxPose = sp + 40|0;
 $capsuleGeom = sp + 68|0;
 $capsulePose = sp + 80|0;
 $1 = sp + 160|0;
 HEAP32[$boxGeom>>2] = 3;
 $2 = (($boxGeom) + 4|0);
 $3 = (($boxGeom) + 8|0);
 $4 = (($boxGeom) + 12|0);
 $5 = (($volume) + 40|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx = (($geom) + 16|0);
 $$idx$val = +HEAPF64[$$idx>>3];
 $$idx3 = (($geom) + 24|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 32|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$2>>2] = $6;
 $7 = (($5) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$3>>2] = $8;
 $9 = (($volume) + 48|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$4>>2] = $10;
 $11 = $center$idx$val - $$idx$val;
 $12 = Math_fround($11);
 $13 = (($boxPose) + 16|0);
 HEAPF32[$13>>2] = $12;
 $14 = $center$idx1$val - $$idx3$val;
 $15 = Math_fround($14);
 $16 = (($boxPose) + 20|0);
 HEAPF32[$16>>2] = $15;
 $17 = $center$idx2$val - $$idx4$val;
 $18 = Math_fround($17);
 $19 = (($boxPose) + 24|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($test) + 228|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$boxPose>>2] = $21;
 $22 = (($test) + 232|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($boxPose) + 4|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($test) + 236|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($boxPose) + 8|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($test) + 240|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($boxPose) + 12|0);
 HEAPF32[$30>>2] = $29;
 HEAP32[$capsuleGeom>>2] = 2;
 $31 = (($capsuleGeom) + 4|0);
 $32 = (($capsuleGeom) + 8|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($geom) + 40|0);
 $34 = +HEAPF64[$33>>3];
 $35 = $34 - $$idx$val;
 $36 = Math_fround($35);
 HEAPF32[$p0$i>>2] = $36;
 $37 = (($geom) + 48|0);
 $38 = +HEAPF64[$37>>3];
 $39 = $38 - $$idx3$val;
 $40 = Math_fround($39);
 $41 = (($p0$i) + 4|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($geom) + 56|0);
 $43 = +HEAPF64[$42>>3];
 $44 = $43 - $$idx4$val;
 $45 = Math_fround($44);
 $46 = (($p0$i) + 8|0);
 HEAPF32[$46>>2] = $45;
 $47 = (($geom) + 64|0);
 $48 = +HEAPF64[$47>>3];
 $49 = $48 - $$idx$val;
 $50 = Math_fround($49);
 HEAPF32[$p1$i>>2] = $50;
 $51 = (($geom) + 72|0);
 $52 = +HEAPF64[$51>>3];
 $53 = $52 - $$idx3$val;
 $54 = Math_fround($53);
 $55 = (($p1$i) + 4|0);
 HEAPF32[$55>>2] = $54;
 $56 = (($geom) + 80|0);
 $57 = +HEAPF64[$56>>3];
 $58 = $57 - $$idx4$val;
 $59 = Math_fround($58);
 $60 = (($p1$i) + 8|0);
 HEAPF32[$60>>2] = $59;
 $61 = (($geom) + 88|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 HEAPF32[$31>>2] = $62;
 __ZN5physx22PxTransformFromSegmentERKNS_6PxVec3ES2_Pf($0,$p0$i,$p1$i,$32);
 $63 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$capsulePose>>2] = $63;
 $64 = (($0) + 4|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($capsulePose) + 4|0);
 HEAPF32[$66>>2] = $65;
 $67 = (($0) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($capsulePose) + 8|0);
 HEAPF32[$69>>2] = $68;
 $70 = (($0) + 12|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($capsulePose) + 12|0);
 HEAPF32[$72>>2] = $71;
 $73 = (($0) + 16|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($capsulePose) + 16|0);
 HEAPF32[$75>>2] = $74;
 $76 = (($0) + 20|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($capsulePose) + 20|0);
 HEAPF32[$78>>2] = $77;
 $79 = (($0) + 24|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($capsulePose) + 24|0);
 HEAPF32[$81>>2] = $80;
 HEAP32[$0>>2] = 0;
 $82 = (($0) + 4|0);
 HEAP32[$82>>2] = 0;
 $83 = (($0) + 8|0);
 HEAP32[$83>>2] = -1;
 $84 = (($0) + 12|0);
 HEAP16[$84>>1] = 0;
 $85 = (($0) + 16|0);
 $86 = (($0) + 40|0);
 ;HEAP32[$85+0>>2]=0|0;HEAP32[$85+4>>2]=0|0;HEAP32[$85+8>>2]=0|0;HEAP32[$85+12>>2]=0|0;HEAP32[$85+16>>2]=0|0;HEAP32[$85+20>>2]=0|0;
 HEAPF32[$86>>2] = Math_fround(3.40282346638528859812E+38);
 $87 = (($impact) + 36|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $$idx5 = (($test) + 283|0);
 $$idx5$val = HEAP8[$$idx5>>0]|0;
 $89 = ($$idx5$val<<24>>24)==(0);
 $$$i = $89 ? 7 : 263;
 HEAP16[$1>>1] = $$$i;
 $90 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$88,$boxGeom,$boxPose,$capsuleGeom,$capsulePose,$0,$1,Math_fround(0.0))|0);
 if (!($90)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $91 = Math_fround(HEAPF32[$86>>2]);
 $92 = Math_fround(HEAPF32[$87>>2]);
 $93 = !($91 >= $92);
 if (!($93)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$87>>2] = $91;
 $94 = (($0) + 28|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($impact) + 24|0);
 HEAPF32[$96>>2] = $95;
 $97 = (($0) + 32|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($impact) + 28|0);
 HEAPF32[$99>>2] = $98;
 $100 = (($0) + 36|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($impact) + 32|0);
 HEAPF32[$102>>2] = $101;
 $103 = (($impact) + 40|0);
 HEAP32[$103>>2] = -1;
 $104 = (($impact) + 44|0);
 HEAP32[$104>>2] = -1;
 $105 = Math_fround(HEAPF32[$85>>2]);
 $106 = +$105;
 $107 = +HEAPF64[$$idx>>3];
 $108 = $106 + $107;
 HEAPF64[$impact>>3] = $108;
 $109 = (($0) + 20|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = +$110;
 $112 = +HEAPF64[$$idx3>>3];
 $113 = $111 + $112;
 $114 = (($impact) + 8|0);
 HEAPF64[$114>>3] = $113;
 $115 = (($0) + 24|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = +$116;
 $118 = +HEAPF64[$$idx4>>3];
 $119 = $117 + $118;
 $120 = (($impact) + 16|0);
 HEAPF64[$120>>3] = $119;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL12SweepBoxMeshPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($sweep_test,$volume,$geom,$center,$dir,$impact) {
 $sweep_test = $sweep_test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0.0, $23 = 0, $24 = 0.0;
 var $25 = 0.0, $26 = Math_fround(0), $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = Math_fround(0), $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $boxGeom = 0, $boxPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $boxGeom = sp + 32|0;
 $boxPose = sp;
 $0 = (($geom) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($geom) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($sweep_test) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + (($4*36)|0)|0);
 $8 = (($sweep_test) + 96|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($sweep_test) + ($9<<2)|0) + 100|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)>=($1>>>0);
 $$ = $12 ? 0 : $11;
 HEAP32[$boxGeom>>2] = 3;
 $13 = (($boxGeom) + 4|0);
 $14 = (($boxGeom) + 8|0);
 $15 = (($boxGeom) + 12|0);
 $16 = (($volume) + 40|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$13>>2] = $17;
 $18 = (($16) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$14>>2] = $19;
 $20 = (($volume) + 48|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$15>>2] = $21;
 $22 = +HEAPF64[$center>>3];
 $23 = (($geom) + 16|0);
 $24 = +HEAPF64[$23>>3];
 $25 = $22 - $24;
 $26 = Math_fround($25);
 $27 = (($center) + 8|0);
 $28 = +HEAPF64[$27>>3];
 $29 = (($geom) + 24|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $28 - $30;
 $32 = Math_fround($31);
 $33 = (($center) + 16|0);
 $34 = +HEAPF64[$33>>3];
 $35 = (($geom) + 32|0);
 $36 = +HEAPF64[$35>>3];
 $37 = $34 - $36;
 $38 = Math_fround($37);
 $39 = (($sweep_test) + 228|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 HEAPF32[$boxPose>>2] = $40;
 $41 = (($boxPose) + 4|0);
 $42 = (($sweep_test) + 232|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$41>>2] = $43;
 $44 = (($boxPose) + 8|0);
 $45 = (($sweep_test) + 236|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 HEAPF32[$44>>2] = $46;
 $47 = (($boxPose) + 12|0);
 $48 = (($sweep_test) + 240|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$47>>2] = $49;
 $50 = (($boxPose) + 16|0);
 HEAPF32[$50>>2] = $26;
 $51 = (($boxPose) + 20|0);
 HEAPF32[$51>>2] = $32;
 $52 = (($boxPose) + 24|0);
 HEAPF32[$52>>2] = $38;
 $53 = (__ZL17sweepVolumeVsMeshPKN5physx3Cct9SweepTestEPKNS0_11TouchedMeshERNS0_12SweptContactERKNS_6PxVec3ERKNS_10PxGeometryERKNS_11PxTransformEjPKNS_10PxTriangleEj($sweep_test,$geom,$impact,$dir,$boxGeom,$boxPose,$1,$7,$$)|0);
 $$0 = $53;
 STACKTOP = sp;return ($$0|0);
}
function __ZL11SweepBoxBoxPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0.0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = Math_fround(0), $12 = 0, $13 = 0.0, $14 = Math_fround(0), $15 = 0, $16 = 0.0, $17 = Math_fround(0);
 var $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0;
 var $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = Math_fround(0), $88 = 0.0, $89 = 0.0, $9 = Math_fround(0);
 var $90 = 0.0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0, $boxGeom0 = 0, $boxGeom1 = 0, $boxPose0 = 0, $boxPose1 = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, $sweepHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $boxGeom0 = sp + 128|0;
 $boxPose0 = sp;
 $boxGeom1 = sp + 32|0;
 $boxPose1 = sp + 48|0;
 $sweepHit = sp + 80|0;
 $0 = sp + 144|0;
 HEAP32[$boxGeom0>>2] = 3;
 $1 = (($boxGeom0) + 4|0);
 $2 = (($boxGeom0) + 8|0);
 $3 = (($boxGeom0) + 12|0);
 $4 = (($volume) + 40|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx = (($geom) + 16|0);
 $$idx$val = +HEAPF64[$$idx>>3];
 $$idx3 = (($geom) + 24|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 32|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$1>>2] = $5;
 $6 = (($4) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$2>>2] = $7;
 $8 = (($volume) + 48|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$3>>2] = $9;
 $10 = $center$idx$val - $$idx$val;
 $11 = Math_fround($10);
 $12 = (($boxPose0) + 16|0);
 HEAPF32[$12>>2] = $11;
 $13 = $center$idx1$val - $$idx3$val;
 $14 = Math_fround($13);
 $15 = (($boxPose0) + 20|0);
 HEAPF32[$15>>2] = $14;
 $16 = $center$idx2$val - $$idx4$val;
 $17 = Math_fround($16);
 $18 = (($boxPose0) + 24|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($test) + 228|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$boxPose0>>2] = $20;
 $21 = (($test) + 232|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($boxPose0) + 4|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($test) + 236|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($boxPose0) + 8|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($test) + 240|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($boxPose0) + 12|0);
 HEAPF32[$29>>2] = $28;
 HEAP32[$boxGeom1>>2] = 3;
 $30 = (($boxGeom1) + 4|0);
 $31 = (($boxGeom1) + 8|0);
 $32 = (($boxGeom1) + 12|0);
 $33 = (($geom) + 52|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$30>>2] = $34;
 $35 = (($geom) + 56|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$31>>2] = $36;
 $37 = (($geom) + 60|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 HEAPF32[$32>>2] = $38;
 $39 = (($geom) + 40|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($boxPose1) + 16|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($geom) + 44|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($boxPose1) + 20|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($geom) + 48|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($boxPose1) + 24|0);
 HEAPF32[$47>>2] = $46;
 $48 = (($geom) + 64|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$boxPose1>>2] = $49;
 $50 = (($geom) + 68|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($boxPose1) + 4|0);
 HEAPF32[$52>>2] = $51;
 $53 = (($geom) + 72|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($boxPose1) + 8|0);
 HEAPF32[$55>>2] = $54;
 $56 = (($geom) + 76|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($boxPose1) + 12|0);
 HEAPF32[$58>>2] = $57;
 HEAP32[$sweepHit>>2] = 0;
 $59 = (($sweepHit) + 4|0);
 HEAP32[$59>>2] = 0;
 $60 = (($sweepHit) + 8|0);
 HEAP32[$60>>2] = -1;
 $61 = (($sweepHit) + 12|0);
 HEAP16[$61>>1] = 0;
 $62 = (($sweepHit) + 16|0);
 $63 = (($sweepHit) + 40|0);
 ;HEAP32[$62+0>>2]=0|0;HEAP32[$62+4>>2]=0|0;HEAP32[$62+8>>2]=0|0;HEAP32[$62+12>>2]=0|0;HEAP32[$62+16>>2]=0|0;HEAP32[$62+20>>2]=0|0;
 HEAPF32[$63>>2] = Math_fround(3.40282346638528859812E+38);
 $64 = (($impact) + 36|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $$idx5 = (($test) + 283|0);
 $$idx5$val = HEAP8[$$idx5>>0]|0;
 $66 = ($$idx5$val<<24>>24)==(0);
 $$$i = $66 ? 7 : 263;
 HEAP16[$0>>1] = $$$i;
 $67 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$65,$boxGeom0,$boxPose0,$boxGeom1,$boxPose1,$sweepHit,$0,Math_fround(0.0))|0);
 if (!($67)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $68 = Math_fround(HEAPF32[$63>>2]);
 $69 = Math_fround(HEAPF32[$64>>2]);
 $70 = !($68 >= $69);
 if (!($70)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = (($sweepHit) + 28|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($impact) + 24|0);
 HEAPF32[$73>>2] = $72;
 $74 = (($sweepHit) + 32|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($impact) + 28|0);
 HEAPF32[$76>>2] = $75;
 $77 = (($sweepHit) + 36|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($impact) + 32|0);
 HEAPF32[$79>>2] = $78;
 HEAPF32[$64>>2] = $68;
 $80 = (($impact) + 40|0);
 HEAP32[$80>>2] = -1;
 $81 = (($impact) + 44|0);
 HEAP32[$81>>2] = -1;
 $82 = Math_fround(HEAPF32[$62>>2]);
 $83 = +$82;
 $84 = +HEAPF64[$$idx>>3];
 $85 = $83 + $84;
 HEAPF64[$impact>>3] = $85;
 $86 = (($sweepHit) + 20|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = +$87;
 $89 = +HEAPF64[$$idx3>>3];
 $90 = $88 + $89;
 $91 = (($impact) + 8|0);
 HEAPF64[$91>>3] = $90;
 $92 = (($sweepHit) + 24|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = +$93;
 $95 = +HEAPF64[$$idx4>>3];
 $96 = $94 + $95;
 $97 = (($impact) + 16|0);
 HEAPF64[$97>>3] = $96;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL14SweepBoxSpherePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0.0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = Math_fround(0), $12 = 0, $13 = 0.0, $14 = Math_fround(0), $15 = 0, $16 = 0.0, $17 = Math_fround(0);
 var $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0);
 var $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $9 = Math_fround(0), $boxGeom = 0, $boxPose = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, $sphereGeom = 0;
 var $spherePose = 0, $sweepHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $boxGeom = sp + 120|0;
 $boxPose = sp;
 $sphereGeom = sp + 32|0;
 $spherePose = sp + 40|0;
 $sweepHit = sp + 72|0;
 $0 = sp + 136|0;
 HEAP32[$boxGeom>>2] = 3;
 $1 = (($boxGeom) + 4|0);
 $2 = (($boxGeom) + 8|0);
 $3 = (($boxGeom) + 12|0);
 $4 = (($volume) + 40|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx = (($geom) + 16|0);
 $$idx$val = +HEAPF64[$$idx>>3];
 $$idx3 = (($geom) + 24|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 32|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$1>>2] = $5;
 $6 = (($4) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$2>>2] = $7;
 $8 = (($volume) + 48|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$3>>2] = $9;
 $10 = $center$idx$val - $$idx$val;
 $11 = Math_fround($10);
 $12 = (($boxPose) + 16|0);
 HEAPF32[$12>>2] = $11;
 $13 = $center$idx1$val - $$idx3$val;
 $14 = Math_fround($13);
 $15 = (($boxPose) + 20|0);
 HEAPF32[$15>>2] = $14;
 $16 = $center$idx2$val - $$idx4$val;
 $17 = Math_fround($16);
 $18 = (($boxPose) + 24|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($test) + 228|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$boxPose>>2] = $20;
 $21 = (($test) + 232|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($boxPose) + 4|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($test) + 236|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($boxPose) + 8|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($test) + 240|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($boxPose) + 12|0);
 HEAPF32[$29>>2] = $28;
 HEAP32[$sphereGeom>>2] = 0;
 $30 = (($sphereGeom) + 4|0);
 $31 = (($geom) + 52|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$30>>2] = $32;
 $33 = (($geom) + 40|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($spherePose) + 16|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($geom) + 44|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($spherePose) + 20|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($geom) + 48|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($spherePose) + 24|0);
 HEAPF32[$41>>2] = $40;
 HEAPF32[$spherePose>>2] = Math_fround(0.0);
 $42 = (($spherePose) + 4|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($spherePose) + 8|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($spherePose) + 12|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 HEAP32[$sweepHit>>2] = 0;
 $45 = (($sweepHit) + 4|0);
 HEAP32[$45>>2] = 0;
 $46 = (($sweepHit) + 8|0);
 HEAP32[$46>>2] = -1;
 $47 = (($sweepHit) + 12|0);
 HEAP16[$47>>1] = 0;
 $48 = (($sweepHit) + 16|0);
 $49 = (($sweepHit) + 40|0);
 ;HEAP32[$48+0>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;HEAP32[$48+20>>2]=0|0;
 HEAPF32[$49>>2] = Math_fround(3.40282346638528859812E+38);
 $50 = (($impact) + 36|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $$idx5 = (($test) + 283|0);
 $$idx5$val = HEAP8[$$idx5>>0]|0;
 $52 = ($$idx5$val<<24>>24)==(0);
 $$$i = $52 ? 7 : 263;
 HEAP16[$0>>1] = $$$i;
 $53 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$51,$boxGeom,$boxPose,$sphereGeom,$spherePose,$sweepHit,$0,Math_fround(0.0))|0);
 if (!($53)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $54 = Math_fround(HEAPF32[$49>>2]);
 HEAPF32[$50>>2] = $54;
 $55 = (($sweepHit) + 28|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($impact) + 24|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($sweepHit) + 32|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($impact) + 28|0);
 HEAPF32[$60>>2] = $59;
 $61 = (($sweepHit) + 36|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($impact) + 32|0);
 HEAPF32[$63>>2] = $62;
 $64 = (($impact) + 40|0);
 HEAP32[$64>>2] = -1;
 $65 = (($impact) + 44|0);
 HEAP32[$65>>2] = -1;
 $66 = Math_fround(HEAPF32[$48>>2]);
 $67 = +$66;
 $68 = +HEAPF64[$$idx>>3];
 $69 = $67 + $68;
 HEAPF64[$impact>>3] = $69;
 $70 = (($sweepHit) + 20|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = +$71;
 $73 = +HEAPF64[$$idx3>>3];
 $74 = $72 + $73;
 $75 = (($impact) + 8|0);
 HEAPF64[$75>>3] = $74;
 $76 = (($sweepHit) + 24|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = +$77;
 $79 = +HEAPF64[$$idx4>>3];
 $80 = $78 + $79;
 $81 = (($impact) + 16|0);
 HEAPF64[$81>>3] = $80;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL15SweepBoxCapsulePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0.0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0.0, $12 = Math_fround(0), $13 = 0, $14 = 0.0, $15 = Math_fround(0), $16 = 0, $17 = 0.0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0;
 var $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = Math_fround(0), $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = Math_fround(0), $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0, $boxGeom = 0, $boxPose = 0, $capsuleGeom = 0, $capsulePose = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 88|0;
 $boxGeom = sp;
 $boxPose = sp + 16|0;
 $capsuleGeom = sp + 44|0;
 $capsulePose = sp + 56|0;
 $1 = sp + 136|0;
 HEAP32[$boxGeom>>2] = 3;
 $2 = (($boxGeom) + 4|0);
 $3 = (($boxGeom) + 8|0);
 $4 = (($boxGeom) + 12|0);
 $5 = (($volume) + 40|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx = (($geom) + 16|0);
 $$idx$val = +HEAPF64[$$idx>>3];
 $$idx3 = (($geom) + 24|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 32|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$2>>2] = $6;
 $7 = (($5) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$3>>2] = $8;
 $9 = (($volume) + 48|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$4>>2] = $10;
 $11 = $center$idx$val - $$idx$val;
 $12 = Math_fround($11);
 $13 = (($boxPose) + 16|0);
 HEAPF32[$13>>2] = $12;
 $14 = $center$idx1$val - $$idx3$val;
 $15 = Math_fround($14);
 $16 = (($boxPose) + 20|0);
 HEAPF32[$16>>2] = $15;
 $17 = $center$idx2$val - $$idx4$val;
 $18 = Math_fround($17);
 $19 = (($boxPose) + 24|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($test) + 228|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$boxPose>>2] = $21;
 $22 = (($test) + 232|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($boxPose) + 4|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($test) + 236|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($boxPose) + 8|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($test) + 240|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($boxPose) + 12|0);
 HEAPF32[$30>>2] = $29;
 HEAP32[$capsuleGeom>>2] = 2;
 $31 = (($capsuleGeom) + 4|0);
 $32 = (($capsuleGeom) + 8|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($geom) + 40|0);
 $34 = (($geom) + 52|0);
 $35 = (($geom) + 64|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$31>>2] = $36;
 __ZN5physx22PxTransformFromSegmentERKNS_6PxVec3ES2_Pf($0,$33,$34,$32);
 $37 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$capsulePose>>2] = $37;
 $38 = (($0) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($capsulePose) + 4|0);
 HEAPF32[$40>>2] = $39;
 $41 = (($0) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($capsulePose) + 8|0);
 HEAPF32[$43>>2] = $42;
 $44 = (($0) + 12|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($capsulePose) + 12|0);
 HEAPF32[$46>>2] = $45;
 $47 = (($0) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($capsulePose) + 16|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($0) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($capsulePose) + 20|0);
 HEAPF32[$52>>2] = $51;
 $53 = (($0) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($capsulePose) + 24|0);
 HEAPF32[$55>>2] = $54;
 HEAP32[$0>>2] = 0;
 $56 = (($0) + 4|0);
 HEAP32[$56>>2] = 0;
 $57 = (($0) + 8|0);
 HEAP32[$57>>2] = -1;
 $58 = (($0) + 12|0);
 HEAP16[$58>>1] = 0;
 $59 = (($0) + 16|0);
 $60 = (($0) + 40|0);
 ;HEAP32[$59+0>>2]=0|0;HEAP32[$59+4>>2]=0|0;HEAP32[$59+8>>2]=0|0;HEAP32[$59+12>>2]=0|0;HEAP32[$59+16>>2]=0|0;HEAP32[$59+20>>2]=0|0;
 HEAPF32[$60>>2] = Math_fround(3.40282346638528859812E+38);
 $61 = (($impact) + 36|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $$idx5 = (($test) + 283|0);
 $$idx5$val = HEAP8[$$idx5>>0]|0;
 $63 = ($$idx5$val<<24>>24)==(0);
 $$$i = $63 ? 7 : 263;
 HEAP16[$1>>1] = $$$i;
 $64 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$62,$boxGeom,$boxPose,$capsuleGeom,$capsulePose,$0,$1,Math_fround(0.0))|0);
 if (!($64)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $65 = Math_fround(HEAPF32[$60>>2]);
 $66 = Math_fround(HEAPF32[$61>>2]);
 $67 = !($65 >= $66);
 if (!($67)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$61>>2] = $65;
 $68 = (($0) + 28|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($impact) + 24|0);
 HEAPF32[$70>>2] = $69;
 $71 = (($0) + 32|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($impact) + 28|0);
 HEAPF32[$73>>2] = $72;
 $74 = (($0) + 36|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($impact) + 32|0);
 HEAPF32[$76>>2] = $75;
 $77 = (($impact) + 40|0);
 HEAP32[$77>>2] = -1;
 $78 = (($impact) + 44|0);
 HEAP32[$78>>2] = -1;
 $79 = Math_fround(HEAPF32[$59>>2]);
 $80 = +$79;
 $81 = +HEAPF64[$$idx>>3];
 $82 = $80 + $81;
 HEAPF64[$impact>>3] = $82;
 $83 = (($0) + 20|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = +$84;
 $86 = +HEAPF64[$$idx3>>3];
 $87 = $85 + $86;
 $88 = (($impact) + 8|0);
 HEAPF64[$88>>3] = $87;
 $89 = (($0) + 24|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = +$90;
 $92 = +HEAPF64[$$idx4>>3];
 $93 = $91 + $92;
 $94 = (($impact) + 16|0);
 HEAPF64[$94>>3] = $93;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL19SweepCapsuleUserBoxPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$i = 0, $$idx$val = 0, $$idx$val$i = 0.0, $$idx1$i = 0, $$idx1$val$i = 0.0, $$idx2$val$i = 0.0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = Math_fround(0);
 var $13 = 0, $14 = 0.0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0.0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0.0, $42 = Math_fround(0), $43 = 0, $44 = 0.0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0.0, $80 = 0, $81 = Math_fround(0), $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0;
 var $86 = Math_fround(0), $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $boxGeom = 0, $boxPose = 0, $capsuleGeom = 0, $capsulePose = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0;
 var $center$idx2$val = 0.0, $sweepHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $capsuleGeom = sp + 128|0;
 $capsulePose = sp;
 $boxGeom = sp + 32|0;
 $boxPose = sp + 48|0;
 $sweepHit = sp + 80|0;
 $0 = sp + 140|0;
 HEAP32[$capsuleGeom>>2] = 2;
 $1 = (($capsuleGeom) + 4|0);
 $2 = (($capsuleGeom) + 8|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx3 = (($geom) + 16|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 24|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $$idx5 = (($geom) + 32|0);
 $$idx5$val = +HEAPF64[$$idx5>>3];
 $3 = (($volume) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$1>>2] = $4;
 $5 = (($volume) + 44|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * Math_fround(0.5));
 HEAPF32[$2>>2] = $7;
 $8 = $center$idx$val - $$idx3$val;
 $9 = Math_fround($8);
 $10 = (($capsulePose) + 16|0);
 HEAPF32[$10>>2] = $9;
 $11 = $center$idx1$val - $$idx4$val;
 $12 = Math_fround($11);
 $13 = (($capsulePose) + 20|0);
 HEAPF32[$13>>2] = $12;
 $14 = $center$idx2$val - $$idx5$val;
 $15 = Math_fround($14);
 $16 = (($capsulePose) + 24|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($test) + 228|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$capsulePose>>2] = $18;
 $19 = (($test) + 232|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($capsulePose) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($test) + 236|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($capsulePose) + 8|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($test) + 240|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($capsulePose) + 12|0);
 HEAPF32[$27>>2] = $26;
 HEAP32[$boxGeom>>2] = 3;
 $28 = (($boxGeom) + 4|0);
 $29 = (($boxGeom) + 8|0);
 $30 = (($boxGeom) + 12|0);
 $$idx$i = (($geom) + 40|0);
 $$idx$val$i = +HEAPF64[$$idx$i>>3];
 $$idx1$i = (($geom) + 48|0);
 $$idx1$val$i = +HEAPF64[$$idx1$i>>3];
 $31 = (($geom) + 56|0);
 $$idx2$val$i = +HEAPF64[$31>>3];
 $32 = (($geom) + 64|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$28>>2] = $33;
 $34 = (($geom) + 68|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 HEAPF32[$29>>2] = $35;
 $36 = (($geom) + 72|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 HEAPF32[$30>>2] = $37;
 $38 = $$idx$val$i - $$idx3$val;
 $39 = Math_fround($38);
 $40 = (($boxPose) + 16|0);
 HEAPF32[$40>>2] = $39;
 $41 = $$idx1$val$i - $$idx4$val;
 $42 = Math_fround($41);
 $43 = (($boxPose) + 20|0);
 HEAPF32[$43>>2] = $42;
 $44 = $$idx2$val$i - $$idx5$val;
 $45 = Math_fround($44);
 $46 = (($boxPose) + 24|0);
 HEAPF32[$46>>2] = $45;
 $47 = (($geom) + 76|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$boxPose>>2] = $48;
 $49 = (($geom) + 80|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($boxPose) + 4|0);
 HEAPF32[$51>>2] = $50;
 $52 = (($geom) + 84|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($boxPose) + 8|0);
 HEAPF32[$54>>2] = $53;
 $55 = (($geom) + 88|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($boxPose) + 12|0);
 HEAPF32[$57>>2] = $56;
 HEAP32[$sweepHit>>2] = 0;
 $58 = (($sweepHit) + 4|0);
 HEAP32[$58>>2] = 0;
 $59 = (($sweepHit) + 8|0);
 HEAP32[$59>>2] = -1;
 $60 = (($sweepHit) + 12|0);
 HEAP16[$60>>1] = 0;
 $61 = (($sweepHit) + 16|0);
 $62 = (($sweepHit) + 40|0);
 ;HEAP32[$61+0>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;HEAP32[$61+12>>2]=0|0;HEAP32[$61+16>>2]=0|0;HEAP32[$61+20>>2]=0|0;
 HEAPF32[$62>>2] = Math_fround(3.40282346638528859812E+38);
 $63 = (($impact) + 36|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $$idx = (($test) + 283|0);
 $$idx$val = HEAP8[$$idx>>0]|0;
 $65 = ($$idx$val<<24>>24)==(0);
 $$$i = $65 ? 7 : 263;
 HEAP16[$0>>1] = $$$i;
 $66 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$64,$capsuleGeom,$capsulePose,$boxGeom,$boxPose,$sweepHit,$0,Math_fround(0.0))|0);
 if (!($66)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = Math_fround(HEAPF32[$62>>2]);
 $68 = Math_fround(HEAPF32[$63>>2]);
 $69 = !($67 >= $68);
 if (!($69)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$63>>2] = $67;
 $70 = (($sweepHit) + 28|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($impact) + 24|0);
 HEAPF32[$72>>2] = $71;
 $73 = (($sweepHit) + 32|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($impact) + 28|0);
 HEAPF32[$75>>2] = $74;
 $76 = (($sweepHit) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($impact) + 32|0);
 HEAPF32[$78>>2] = $77;
 $79 = (($impact) + 40|0);
 HEAP32[$79>>2] = -1;
 $80 = (($impact) + 44|0);
 HEAP32[$80>>2] = -1;
 $81 = Math_fround(HEAPF32[$61>>2]);
 $82 = +$81;
 $83 = +HEAPF64[$$idx3>>3];
 $84 = $82 + $83;
 HEAPF64[$impact>>3] = $84;
 $85 = (($sweepHit) + 20|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = +$86;
 $88 = +HEAPF64[$$idx4>>3];
 $89 = $87 + $88;
 $90 = (($impact) + 8|0);
 HEAPF64[$90>>3] = $89;
 $91 = (($sweepHit) + 24|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = +$92;
 $94 = +HEAPF64[$$idx5>>3];
 $95 = $93 + $94;
 $96 = (($impact) + 16|0);
 HEAPF64[$96>>3] = $95;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL23SweepCapsuleUserCapsulePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0.0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0.0, $105 = 0.0, $106 = 0.0;
 var $107 = 0, $108 = Math_fround(0), $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = 0.0, $16 = Math_fround(0), $17 = 0, $18 = 0;
 var $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = Math_fround(0), $35 = 0, $36 = 0.0;
 var $37 = 0.0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0.0, $51 = 0.0, $52 = Math_fround(0), $53 = 0, $54 = 0;
 var $55 = 0.0, $56 = 0.0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0);
 var $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0.0, $90 = Math_fround(0);
 var $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $capsuleGeom0 = 0, $capsuleGeom1 = 0, $capsulePose0 = 0, $capsulePose1 = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, $p0$i = 0, $p1$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 104|0;
 $p0$i = sp;
 $p1$i = sp + 12|0;
 $capsuleGeom0 = sp + 24|0;
 $capsulePose0 = sp + 36|0;
 $capsuleGeom1 = sp + 64|0;
 $capsulePose1 = sp + 76|0;
 $1 = sp + 152|0;
 HEAP32[$capsuleGeom0>>2] = 2;
 $2 = (($capsuleGeom0) + 4|0);
 $3 = (($capsuleGeom0) + 8|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx3 = (($geom) + 16|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 24|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $$idx5 = (($geom) + 32|0);
 $$idx5$val = +HEAPF64[$$idx5>>3];
 $4 = (($volume) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$2>>2] = $5;
 $6 = (($volume) + 44|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(0.5));
 HEAPF32[$3>>2] = $8;
 $9 = $center$idx$val - $$idx3$val;
 $10 = Math_fround($9);
 $11 = (($capsulePose0) + 16|0);
 HEAPF32[$11>>2] = $10;
 $12 = $center$idx1$val - $$idx4$val;
 $13 = Math_fround($12);
 $14 = (($capsulePose0) + 20|0);
 HEAPF32[$14>>2] = $13;
 $15 = $center$idx2$val - $$idx5$val;
 $16 = Math_fround($15);
 $17 = (($capsulePose0) + 24|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($test) + 228|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$capsulePose0>>2] = $19;
 $20 = (($test) + 232|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($capsulePose0) + 4|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($test) + 236|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($capsulePose0) + 8|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($test) + 240|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($capsulePose0) + 12|0);
 HEAPF32[$28>>2] = $27;
 HEAP32[$capsuleGeom1>>2] = 2;
 $29 = (($capsuleGeom1) + 4|0);
 $30 = (($capsuleGeom1) + 8|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($geom) + 40|0);
 $32 = +HEAPF64[$31>>3];
 $33 = $32 - $$idx3$val;
 $34 = Math_fround($33);
 HEAPF32[$p0$i>>2] = $34;
 $35 = (($geom) + 48|0);
 $36 = +HEAPF64[$35>>3];
 $37 = $36 - $$idx4$val;
 $38 = Math_fround($37);
 $39 = (($p0$i) + 4|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($geom) + 56|0);
 $41 = +HEAPF64[$40>>3];
 $42 = $41 - $$idx5$val;
 $43 = Math_fround($42);
 $44 = (($p0$i) + 8|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($geom) + 64|0);
 $46 = +HEAPF64[$45>>3];
 $47 = $46 - $$idx3$val;
 $48 = Math_fround($47);
 HEAPF32[$p1$i>>2] = $48;
 $49 = (($geom) + 72|0);
 $50 = +HEAPF64[$49>>3];
 $51 = $50 - $$idx4$val;
 $52 = Math_fround($51);
 $53 = (($p1$i) + 4|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($geom) + 80|0);
 $55 = +HEAPF64[$54>>3];
 $56 = $55 - $$idx5$val;
 $57 = Math_fround($56);
 $58 = (($p1$i) + 8|0);
 HEAPF32[$58>>2] = $57;
 $59 = (($geom) + 88|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 HEAPF32[$29>>2] = $60;
 __ZN5physx22PxTransformFromSegmentERKNS_6PxVec3ES2_Pf($0,$p0$i,$p1$i,$30);
 $61 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$capsulePose1>>2] = $61;
 $62 = (($0) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($capsulePose1) + 4|0);
 HEAPF32[$64>>2] = $63;
 $65 = (($0) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($capsulePose1) + 8|0);
 HEAPF32[$67>>2] = $66;
 $68 = (($0) + 12|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($capsulePose1) + 12|0);
 HEAPF32[$70>>2] = $69;
 $71 = (($0) + 16|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($capsulePose1) + 16|0);
 HEAPF32[$73>>2] = $72;
 $74 = (($0) + 20|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($capsulePose1) + 20|0);
 HEAPF32[$76>>2] = $75;
 $77 = (($0) + 24|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($capsulePose1) + 24|0);
 HEAPF32[$79>>2] = $78;
 HEAP32[$0>>2] = 0;
 $80 = (($0) + 4|0);
 HEAP32[$80>>2] = 0;
 $81 = (($0) + 8|0);
 HEAP32[$81>>2] = -1;
 $82 = (($0) + 12|0);
 HEAP16[$82>>1] = 0;
 $83 = (($0) + 16|0);
 $84 = (($0) + 40|0);
 ;HEAP32[$83+0>>2]=0|0;HEAP32[$83+4>>2]=0|0;HEAP32[$83+8>>2]=0|0;HEAP32[$83+12>>2]=0|0;HEAP32[$83+16>>2]=0|0;HEAP32[$83+20>>2]=0|0;
 HEAPF32[$84>>2] = Math_fround(3.40282346638528859812E+38);
 $85 = (($impact) + 36|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $$idx = (($test) + 283|0);
 $$idx$val = HEAP8[$$idx>>0]|0;
 $87 = ($$idx$val<<24>>24)==(0);
 $$$i = $87 ? 7 : 263;
 HEAP16[$1>>1] = $$$i;
 $88 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$86,$capsuleGeom0,$capsulePose0,$capsuleGeom1,$capsulePose1,$0,$1,Math_fround(0.0))|0);
 if (!($88)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $89 = Math_fround(HEAPF32[$84>>2]);
 $90 = Math_fround(HEAPF32[$85>>2]);
 $91 = !($89 >= $90);
 if (!($91)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$85>>2] = $89;
 $92 = (($0) + 28|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($impact) + 24|0);
 HEAPF32[$94>>2] = $93;
 $95 = (($0) + 32|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($impact) + 28|0);
 HEAPF32[$97>>2] = $96;
 $98 = (($0) + 36|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($impact) + 32|0);
 HEAPF32[$100>>2] = $99;
 $101 = (($impact) + 40|0);
 HEAP32[$101>>2] = -1;
 $102 = (($impact) + 44|0);
 HEAP32[$102>>2] = -1;
 $103 = Math_fround(HEAPF32[$83>>2]);
 $104 = +$103;
 $105 = +HEAPF64[$$idx3>>3];
 $106 = $104 + $105;
 HEAPF64[$impact>>3] = $106;
 $107 = (($0) + 20|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = +$108;
 $110 = +HEAPF64[$$idx4>>3];
 $111 = $109 + $110;
 $112 = (($impact) + 8|0);
 HEAPF64[$112>>3] = $111;
 $113 = (($0) + 24|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = +$114;
 $116 = +HEAPF64[$$idx5>>3];
 $117 = $115 + $116;
 $118 = (($impact) + 16|0);
 HEAPF64[$118>>3] = $117;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL16SweepCapsuleMeshPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($sweep_test,$volume,$geom,$center,$dir,$impact) {
 $sweep_test = $sweep_test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$ = 0, $$0 = 0, $$idx = 0, $$idx$val = 0.0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0);
 var $2 = 0, $20 = 0.0, $21 = Math_fround(0), $22 = 0, $23 = 0.0, $24 = Math_fround(0), $25 = 0, $26 = 0.0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0;
 var $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $capsuleGeom = 0, $capsulePose = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $capsuleGeom = sp + 28|0;
 $capsulePose = sp;
 $0 = (($geom) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($geom) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($sweep_test) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + (($4*36)|0)|0);
 $8 = (($sweep_test) + 96|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($sweep_test) + ($9<<2)|0) + 100|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)>=($1>>>0);
 $$ = $12 ? 0 : $11;
 HEAP32[$capsuleGeom>>2] = 2;
 $13 = (($capsuleGeom) + 4|0);
 $14 = (($capsuleGeom) + 8|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx = (($geom) + 16|0);
 $$idx$val = +HEAPF64[$$idx>>3];
 $$idx3 = (($geom) + 24|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 32|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $15 = (($volume) + 40|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$13>>2] = $16;
 $17 = (($volume) + 44|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * Math_fround(0.5));
 HEAPF32[$14>>2] = $19;
 $20 = $center$idx$val - $$idx$val;
 $21 = Math_fround($20);
 $22 = (($capsulePose) + 16|0);
 HEAPF32[$22>>2] = $21;
 $23 = $center$idx1$val - $$idx3$val;
 $24 = Math_fround($23);
 $25 = (($capsulePose) + 20|0);
 HEAPF32[$25>>2] = $24;
 $26 = $center$idx2$val - $$idx4$val;
 $27 = Math_fround($26);
 $28 = (($capsulePose) + 24|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($sweep_test) + 228|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$capsulePose>>2] = $30;
 $31 = (($sweep_test) + 232|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($capsulePose) + 4|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($sweep_test) + 236|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($capsulePose) + 8|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($sweep_test) + 240|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($capsulePose) + 12|0);
 HEAPF32[$39>>2] = $38;
 $40 = (__ZL17sweepVolumeVsMeshPKN5physx3Cct9SweepTestEPKNS0_11TouchedMeshERNS0_12SweptContactERKNS_6PxVec3ERKNS_10PxGeometryERKNS_11PxTransformEjPKNS_10PxTriangleEj($sweep_test,$geom,$impact,$dir,$capsuleGeom,$capsulePose,$1,$7,$$)|0);
 $$0 = $40;
 STACKTOP = sp;return ($$0|0);
}
function __ZL15SweepCapsuleBoxPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = Math_fround(0), $13 = 0, $14 = 0.0, $15 = Math_fround(0), $16 = 0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0;
 var $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0;
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0.0, $80 = Math_fround(0), $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = Math_fround(0), $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = Math_fround(0);
 var $90 = 0, $91 = Math_fround(0), $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0, $boxGeom = 0, $boxPose = 0, $capsuleGeom = 0, $capsulePose = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, $sweepHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $capsuleGeom = sp + 128|0;
 $capsulePose = sp;
 $boxGeom = sp + 32|0;
 $boxPose = sp + 48|0;
 $sweepHit = sp + 80|0;
 $0 = sp + 140|0;
 HEAP32[$capsuleGeom>>2] = 2;
 $1 = (($capsuleGeom) + 4|0);
 $2 = (($capsuleGeom) + 8|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx3 = (($geom) + 16|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 24|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $$idx5 = (($geom) + 32|0);
 $$idx5$val = +HEAPF64[$$idx5>>3];
 $3 = (($volume) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$1>>2] = $4;
 $5 = (($volume) + 44|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * Math_fround(0.5));
 HEAPF32[$2>>2] = $7;
 $8 = $center$idx$val - $$idx3$val;
 $9 = Math_fround($8);
 $10 = (($capsulePose) + 16|0);
 HEAPF32[$10>>2] = $9;
 $11 = $center$idx1$val - $$idx4$val;
 $12 = Math_fround($11);
 $13 = (($capsulePose) + 20|0);
 HEAPF32[$13>>2] = $12;
 $14 = $center$idx2$val - $$idx5$val;
 $15 = Math_fround($14);
 $16 = (($capsulePose) + 24|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($test) + 228|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$capsulePose>>2] = $18;
 $19 = (($test) + 232|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($capsulePose) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($test) + 236|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($capsulePose) + 8|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($test) + 240|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($capsulePose) + 12|0);
 HEAPF32[$27>>2] = $26;
 HEAP32[$boxGeom>>2] = 3;
 $28 = (($boxGeom) + 4|0);
 $29 = (($boxGeom) + 8|0);
 $30 = (($boxGeom) + 12|0);
 $31 = (($geom) + 52|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$28>>2] = $32;
 $33 = (($geom) + 56|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$29>>2] = $34;
 $35 = (($geom) + 60|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$30>>2] = $36;
 $37 = (($geom) + 40|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($boxPose) + 16|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($geom) + 44|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($boxPose) + 20|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($geom) + 48|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($boxPose) + 24|0);
 HEAPF32[$45>>2] = $44;
 $46 = (($geom) + 64|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$boxPose>>2] = $47;
 $48 = (($geom) + 68|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($boxPose) + 4|0);
 HEAPF32[$50>>2] = $49;
 $51 = (($geom) + 72|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($boxPose) + 8|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($geom) + 76|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($boxPose) + 12|0);
 HEAPF32[$56>>2] = $55;
 HEAP32[$sweepHit>>2] = 0;
 $57 = (($sweepHit) + 4|0);
 HEAP32[$57>>2] = 0;
 $58 = (($sweepHit) + 8|0);
 HEAP32[$58>>2] = -1;
 $59 = (($sweepHit) + 12|0);
 HEAP16[$59>>1] = 0;
 $60 = (($sweepHit) + 16|0);
 $61 = (($sweepHit) + 40|0);
 ;HEAP32[$60+0>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;HEAP32[$60+16>>2]=0|0;HEAP32[$60+20>>2]=0|0;
 HEAPF32[$61>>2] = Math_fround(3.40282346638528859812E+38);
 $62 = (($impact) + 36|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $$idx = (($test) + 283|0);
 $$idx$val = HEAP8[$$idx>>0]|0;
 $64 = ($$idx$val<<24>>24)==(0);
 $$$i = $64 ? 7 : 263;
 HEAP16[$0>>1] = $$$i;
 $65 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$63,$capsuleGeom,$capsulePose,$boxGeom,$boxPose,$sweepHit,$0,Math_fround(0.0))|0);
 if (!($65)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = Math_fround(HEAPF32[$61>>2]);
 $67 = Math_fround(HEAPF32[$62>>2]);
 $68 = !($66 >= $67);
 if (!($68)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$62>>2] = $66;
 $69 = (($sweepHit) + 28|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($impact) + 24|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($sweepHit) + 32|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($impact) + 28|0);
 HEAPF32[$74>>2] = $73;
 $75 = (($sweepHit) + 36|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($impact) + 32|0);
 HEAPF32[$77>>2] = $76;
 $78 = (($impact) + 40|0);
 HEAP32[$78>>2] = -1;
 $79 = (($impact) + 44|0);
 HEAP32[$79>>2] = -1;
 $80 = Math_fround(HEAPF32[$60>>2]);
 $81 = +$80;
 $82 = +HEAPF64[$$idx3>>3];
 $83 = $81 + $82;
 HEAPF64[$impact>>3] = $83;
 $84 = (($sweepHit) + 20|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = +$85;
 $87 = +HEAPF64[$$idx4>>3];
 $88 = $86 + $87;
 $89 = (($impact) + 8|0);
 HEAPF64[$89>>3] = $88;
 $90 = (($sweepHit) + 24|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = +$91;
 $93 = +HEAPF64[$$idx5>>3];
 $94 = $92 + $93;
 $95 = (($impact) + 16|0);
 HEAPF64[$95>>3] = $94;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL18SweepCapsuleSpherePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0.0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = 0.0, $16 = Math_fround(0), $17 = 0;
 var $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0;
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0.0, $79 = 0.0, $8 = Math_fround(0), $80 = 0.0, $81 = 0, $82 = Math_fround(0), $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0.0, $9 = 0.0;
 var $90 = 0.0, $91 = 0.0, $92 = 0, $capsuleGeom = 0, $capsulePose = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, $sphereGeom = 0, $spherePose = 0, $sweepHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $capsuleGeom = sp + 132|0;
 $capsulePose = sp;
 $sphereGeom = sp + 32|0;
 $spherePose = sp + 40|0;
 $sweepHit = sp + 72|0;
 $0 = sp + 120|0;
 $1 = sp + 144|0;
 HEAP32[$capsuleGeom>>2] = 2;
 $2 = (($capsuleGeom) + 4|0);
 $3 = (($capsuleGeom) + 8|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx3 = (($geom) + 16|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 24|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $$idx5 = (($geom) + 32|0);
 $$idx5$val = +HEAPF64[$$idx5>>3];
 $4 = (($volume) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$2>>2] = $5;
 $6 = (($volume) + 44|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(0.5));
 HEAPF32[$3>>2] = $8;
 $9 = $center$idx$val - $$idx3$val;
 $10 = Math_fround($9);
 $11 = (($capsulePose) + 16|0);
 HEAPF32[$11>>2] = $10;
 $12 = $center$idx1$val - $$idx4$val;
 $13 = Math_fround($12);
 $14 = (($capsulePose) + 20|0);
 HEAPF32[$14>>2] = $13;
 $15 = $center$idx2$val - $$idx5$val;
 $16 = Math_fround($15);
 $17 = (($capsulePose) + 24|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($test) + 228|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$capsulePose>>2] = $19;
 $20 = (($test) + 232|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($capsulePose) + 4|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($test) + 236|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($capsulePose) + 8|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($test) + 240|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($capsulePose) + 12|0);
 HEAPF32[$28>>2] = $27;
 HEAP32[$sphereGeom>>2] = 0;
 $29 = (($sphereGeom) + 4|0);
 $30 = (($geom) + 52|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$29>>2] = $31;
 $32 = (($geom) + 40|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($spherePose) + 16|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($geom) + 44|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($spherePose) + 20|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($geom) + 48|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($spherePose) + 24|0);
 HEAPF32[$40>>2] = $39;
 HEAPF32[$spherePose>>2] = Math_fround(0.0);
 $41 = (($spherePose) + 4|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($spherePose) + 8|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($spherePose) + 12|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 HEAP32[$sweepHit>>2] = 0;
 $44 = (($sweepHit) + 4|0);
 HEAP32[$44>>2] = 0;
 $45 = (($sweepHit) + 8|0);
 HEAP32[$45>>2] = -1;
 $46 = (($sweepHit) + 12|0);
 HEAP16[$46>>1] = 0;
 $47 = (($sweepHit) + 16|0);
 $48 = (($sweepHit) + 40|0);
 ;HEAP32[$47+0>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;HEAP32[$47+12>>2]=0|0;HEAP32[$47+16>>2]=0|0;HEAP32[$47+20>>2]=0|0;
 HEAPF32[$48>>2] = Math_fround(3.40282346638528859812E+38);
 $49 = Math_fround(HEAPF32[$dir>>2]);
 $50 = Math_fround(-$49);
 $51 = (($dir) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(-$52);
 $54 = (($dir) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround(-$55);
 HEAPF32[$0>>2] = $50;
 $57 = (($0) + 4|0);
 HEAPF32[$57>>2] = $53;
 $58 = (($0) + 8|0);
 HEAPF32[$58>>2] = $56;
 $59 = (($impact) + 36|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $$idx = (($test) + 283|0);
 $$idx$val = HEAP8[$$idx>>0]|0;
 $61 = ($$idx$val<<24>>24)==(0);
 $$$i = $61 ? 7 : 263;
 HEAP16[$1>>1] = $$$i;
 $62 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($0,$60,$sphereGeom,$spherePose,$capsuleGeom,$capsulePose,$sweepHit,$1,Math_fround(0.0))|0);
 if (!($62)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = Math_fround(HEAPF32[$48>>2]);
 $64 = Math_fround(HEAPF32[$59>>2]);
 $65 = !($63 >= $64);
 if (!($65)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$59>>2] = $63;
 $66 = (($sweepHit) + 28|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($impact) + 24|0);
 HEAPF32[$68>>2] = $67;
 $69 = (($sweepHit) + 32|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($impact) + 28|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($sweepHit) + 36|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($impact) + 32|0);
 HEAPF32[$74>>2] = $73;
 $75 = (($impact) + 40|0);
 HEAP32[$75>>2] = -1;
 $76 = (($impact) + 44|0);
 HEAP32[$76>>2] = -1;
 $77 = Math_fround(HEAPF32[$47>>2]);
 $78 = +$77;
 $79 = +HEAPF64[$$idx3>>3];
 $80 = $78 + $79;
 HEAPF64[$impact>>3] = $80;
 $81 = (($sweepHit) + 20|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = +$82;
 $84 = +HEAPF64[$$idx4>>3];
 $85 = $83 + $84;
 $86 = (($impact) + 8|0);
 HEAPF64[$86>>3] = $85;
 $87 = (($sweepHit) + 24|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = +$88;
 $90 = +HEAPF64[$$idx5>>3];
 $91 = $89 + $90;
 $92 = (($impact) + 16|0);
 HEAPF64[$92>>3] = $91;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL19SweepCapsuleCapsulePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE($test,$volume,$geom,$center,$dir,$impact) {
 $test = $test|0;
 $volume = $volume|0;
 $geom = $geom|0;
 $center = $center|0;
 $dir = $dir|0;
 $impact = $impact|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0, $$idx3 = 0, $$idx3$val = 0.0, $$idx4 = 0, $$idx4$val = 0.0, $$idx5 = 0, $$idx5$val = 0.0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = 0.0, $16 = Math_fround(0), $17 = 0;
 var $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0;
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0.0, $79 = 0.0, $8 = Math_fround(0), $80 = 0.0, $81 = 0, $82 = Math_fround(0), $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0.0, $9 = 0.0;
 var $90 = 0.0, $91 = 0.0, $92 = 0, $capsuleGeom0 = 0, $capsuleGeom1 = 0, $capsulePose0 = 0, $capsulePose1 = 0, $center$idx$val = 0.0, $center$idx1 = 0, $center$idx1$val = 0.0, $center$idx2 = 0, $center$idx2$val = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 80|0;
 $capsuleGeom0 = sp;
 $capsulePose0 = sp + 12|0;
 $capsuleGeom1 = sp + 40|0;
 $capsulePose1 = sp + 52|0;
 $1 = sp + 128|0;
 HEAP32[$capsuleGeom0>>2] = 2;
 $2 = (($capsuleGeom0) + 4|0);
 $3 = (($capsuleGeom0) + 8|0);
 $center$idx$val = +HEAPF64[$center>>3];
 $center$idx1 = (($center) + 8|0);
 $center$idx1$val = +HEAPF64[$center$idx1>>3];
 $center$idx2 = (($center) + 16|0);
 $center$idx2$val = +HEAPF64[$center$idx2>>3];
 $$idx3 = (($geom) + 16|0);
 $$idx3$val = +HEAPF64[$$idx3>>3];
 $$idx4 = (($geom) + 24|0);
 $$idx4$val = +HEAPF64[$$idx4>>3];
 $$idx5 = (($geom) + 32|0);
 $$idx5$val = +HEAPF64[$$idx5>>3];
 $4 = (($volume) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$2>>2] = $5;
 $6 = (($volume) + 44|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(0.5));
 HEAPF32[$3>>2] = $8;
 $9 = $center$idx$val - $$idx3$val;
 $10 = Math_fround($9);
 $11 = (($capsulePose0) + 16|0);
 HEAPF32[$11>>2] = $10;
 $12 = $center$idx1$val - $$idx4$val;
 $13 = Math_fround($12);
 $14 = (($capsulePose0) + 20|0);
 HEAPF32[$14>>2] = $13;
 $15 = $center$idx2$val - $$idx5$val;
 $16 = Math_fround($15);
 $17 = (($capsulePose0) + 24|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($test) + 228|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$capsulePose0>>2] = $19;
 $20 = (($test) + 232|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($capsulePose0) + 4|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($test) + 236|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($capsulePose0) + 8|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($test) + 240|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($capsulePose0) + 12|0);
 HEAPF32[$28>>2] = $27;
 HEAP32[$capsuleGeom1>>2] = 2;
 $29 = (($capsuleGeom1) + 4|0);
 $30 = (($capsuleGeom1) + 8|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($geom) + 40|0);
 $32 = (($geom) + 52|0);
 $33 = (($geom) + 64|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$29>>2] = $34;
 __ZN5physx22PxTransformFromSegmentERKNS_6PxVec3ES2_Pf($0,$31,$32,$30);
 $35 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$capsulePose1>>2] = $35;
 $36 = (($0) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($capsulePose1) + 4|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($0) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($capsulePose1) + 8|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($0) + 12|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($capsulePose1) + 12|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($0) + 16|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($capsulePose1) + 16|0);
 HEAPF32[$47>>2] = $46;
 $48 = (($0) + 20|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($capsulePose1) + 20|0);
 HEAPF32[$50>>2] = $49;
 $51 = (($0) + 24|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($capsulePose1) + 24|0);
 HEAPF32[$53>>2] = $52;
 HEAP32[$0>>2] = 0;
 $54 = (($0) + 4|0);
 HEAP32[$54>>2] = 0;
 $55 = (($0) + 8|0);
 HEAP32[$55>>2] = -1;
 $56 = (($0) + 12|0);
 HEAP16[$56>>1] = 0;
 $57 = (($0) + 16|0);
 $58 = (($0) + 40|0);
 ;HEAP32[$57+0>>2]=0|0;HEAP32[$57+4>>2]=0|0;HEAP32[$57+8>>2]=0|0;HEAP32[$57+12>>2]=0|0;HEAP32[$57+16>>2]=0|0;HEAP32[$57+20>>2]=0|0;
 HEAPF32[$58>>2] = Math_fround(3.40282346638528859812E+38);
 $59 = (($impact) + 36|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $$idx = (($test) + 283|0);
 $$idx$val = HEAP8[$$idx>>0]|0;
 $61 = ($$idx$val<<24>>24)==(0);
 $$$i = $61 ? 7 : 263;
 HEAP16[$1>>1] = $$$i;
 $62 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($dir,$60,$capsuleGeom0,$capsulePose0,$capsuleGeom1,$capsulePose1,$0,$1,Math_fround(0.0))|0);
 if (!($62)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = Math_fround(HEAPF32[$58>>2]);
 $64 = Math_fround(HEAPF32[$59>>2]);
 $65 = !($63 >= $64);
 if (!($65)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$59>>2] = $63;
 $66 = (($0) + 28|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($impact) + 24|0);
 HEAPF32[$68>>2] = $67;
 $69 = (($0) + 32|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($impact) + 28|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($0) + 36|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($impact) + 32|0);
 HEAPF32[$74>>2] = $73;
 $75 = (($impact) + 40|0);
 HEAP32[$75>>2] = -1;
 $76 = (($impact) + 44|0);
 HEAP32[$76>>2] = -1;
 $77 = Math_fround(HEAPF32[$57>>2]);
 $78 = +$77;
 $79 = +HEAPF64[$$idx3>>3];
 $80 = $78 + $79;
 HEAPF64[$impact>>3] = $80;
 $81 = (($0) + 20|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = +$82;
 $84 = +HEAPF64[$$idx4>>3];
 $85 = $83 + $84;
 $86 = (($impact) + 8|0);
 HEAPF64[$86>>3] = $85;
 $87 = (($0) + 24|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = +$88;
 $90 = +HEAPF64[$$idx5>>3];
 $91 = $89 + $90;
 $92 = (($impact) + 16|0);
 HEAPF64[$92>>3] = $91;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL17sweepVolumeVsMeshPKN5physx3Cct9SweepTestEPKNS0_11TouchedMeshERNS0_12SweptContactERKNS_6PxVec3ERKNS_10PxGeometryERKNS_11PxTransformEjPKNS_10PxTriangleEj($sweepTest,$touchedMesh,$impact,$unitDir,$geom,$pose,$nbTris,$triangles,$cachedIndex) {
 $sweepTest = $sweepTest|0;
 $touchedMesh = $touchedMesh|0;
 $impact = $impact|0;
 $unitDir = $unitDir|0;
 $geom = $geom|0;
 $pose = $pose|0;
 $nbTris = $nbTris|0;
 $triangles = $triangles|0;
 $cachedIndex = $cachedIndex|0;
 var $$$i = 0, $$0 = 0, $$idx = 0, $$idx$val = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0);
 var $22 = 0, $23 = Math_fround(0), $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0;
 var $40 = 0.0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0);
 var $9 = 0, $sweepHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $sweepHit = sp;
 $1 = sp + 52|0;
 HEAP32[$0>>2] = $cachedIndex;
 HEAP32[$sweepHit>>2] = 0;
 $2 = (($sweepHit) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($sweepHit) + 8|0);
 HEAP32[$3>>2] = -1;
 $4 = (($sweepHit) + 12|0);
 HEAP16[$4>>1] = 0;
 $5 = (($sweepHit) + 16|0);
 $6 = (($sweepHit) + 40|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAPF32[$6>>2] = Math_fround(3.40282346638528859812E+38);
 $7 = (($impact) + 36|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $$idx = (($sweepTest) + 283|0);
 $$idx$val = HEAP8[$$idx>>0]|0;
 $9 = ($$idx$val<<24>>24)==(0);
 $$$i = $9 ? 7 : 263;
 HEAP16[$1>>1] = $$$i;
 $10 = (__ZN5physx11PxMeshQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformEjPKNS_10PxTriangleERNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKjf($unitDir,$8,$geom,$pose,$nbTris,$triangles,$sweepHit,$1,$0,Math_fround(0.0))|0);
 if (!($10)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = Math_fround(HEAPF32[$6>>2]);
 $12 = Math_fround(HEAPF32[$7>>2]);
 $13 = !($11 >= $12);
 if (!($13)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$7>>2] = $11;
 $14 = (($sweepHit) + 28|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($impact) + 24|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($sweepHit) + 32|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($impact) + 28|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($sweepHit) + 36|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($impact) + 32|0);
 HEAPF32[$22>>2] = $21;
 $23 = Math_fround(HEAPF32[$5>>2]);
 $24 = +$23;
 $25 = (($touchedMesh) + 16|0);
 $26 = +HEAPF64[$25>>3];
 $27 = $24 + $26;
 HEAPF64[$impact>>3] = $27;
 $28 = (($sweepHit) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = +$29;
 $31 = (($touchedMesh) + 24|0);
 $32 = +HEAPF64[$31>>3];
 $33 = $30 + $32;
 $34 = (($impact) + 8|0);
 HEAPF64[$34>>3] = $33;
 $35 = (($sweepHit) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = +$36;
 $38 = (($touchedMesh) + 32|0);
 $39 = +HEAPF64[$38>>3];
 $40 = $37 + $39;
 $41 = (($impact) + 16|0);
 HEAPF64[$41>>3] = $40;
 $42 = HEAP32[$3>>2]|0;
 $43 = (($sweepTest) + 96|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($sweepTest) + ($44<<2)|0) + 100|0);
 HEAP32[$45>>2] = $42;
 $46 = (($touchedMesh) + 44|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + ($42))|0;
 $49 = (($impact) + 40|0);
 HEAP32[$49>>2] = $48;
 $50 = HEAP32[$46>>2]|0;
 $51 = (($sweepTest) + 20|0);
 $52 = HEAP32[$51>>2]|0;
 $$sum = (($42) + ($50))|0;
 $53 = (($52) + ($$sum<<2)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($impact) + 44|0);
 HEAP32[$55>>2] = $54;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Cct17getSceneTimestampEPKNS0_30InternalCBData_FindTouchedGeomE($userData) {
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$userData>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 360|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx3Cct19findTouchedGeometryEPKNS0_30InternalCBData_FindTouchedGeomERKNS_17PxExtendedBounds3ERNS_6shdfnd5ArrayINS_10PxTriangleENS7_19ReflectionAllocatorIS9_EEEERNS8_IjNSA_IjEEEESG_RKNS0_9CCTFilterERKNS0_9CCTParamsERt($userData,$worldBounds,$worldTriangles,$triIndicesArray,$geomStream,$filter,$params,$nbTessellation) {
 $userData = $userData|0;
 $worldBounds = $worldBounds|0;
 $worldTriangles = $worldTriangles|0;
 $triIndicesArray = $triIndicesArray|0;
 $geomStream = $geomStream|0;
 $filter = $filter|0;
 $params = $params|0;
 $nbTessellation = $nbTessellation|0;
 var $$ = 0, $$c$i = 0, $$c$i10 = 0, $$c$i2 = 0, $$c$i21 = 0, $$c$i40 = 0, $$c$i7 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert27$i = 0, $$phi$trans$insert29$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i25 = 0, $$pre$i$i4 = 0, $$pre$i$i69 = 0, $$pre$i18 = Math_fround(0), $$pre$i3$i = 0, $$pre$i5 = 0, $$pre$i5$i = 0, $$pre$i5$i51 = 0;
 var $$pre$i80 = 0, $$pre28$i = Math_fround(0), $$pre30$i = Math_fround(0), $$sum$i = 0, $$sum$i1 = 0, $$sum$i20 = 0, $$sum$i39 = 0, $$sum$i6 = 0, $$sum$i9 = 0, $$sum1$i = 0, $$sum10$i = 0, $$sum11$i = 0, $$sum13$i = 0, $$sum14$i = 0, $$sum15$i = 0, $$sum16$i = 0, $$sum17$i = 0, $$sum18$i = 0, $$sum2$i = 0, $$sum21$i = 0;
 var $$sum21$i41 = 0, $$sum22$i = 0, $$sum22$i43 = 0, $$sum23$i = 0, $$sum23$i44 = 0, $$sum24$i = 0, $$sum24$i45 = 0, $$sum3$i = 0, $$sum3$i11 = 0, $$sum37$i = 0, $$sum38$i = 0, $$sum39$i = 0, $$sum4$i = 0, $$sum4$i13 = 0, $$sum40$i = 0, $$sum41$i = 0, $$sum5$i = 0, $$sum5$i14 = 0, $$sum6$i = 0, $$sum6$i15 = 0;
 var $$sum7$i = 0, $$sum8$i = 0, $$sum9$i = 0, $0 = 0, $1 = 0, $10 = 0.0, $100 = 0, $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = Math_fround(0), $1011 = Math_fround(0);
 var $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0;
 var $1030 = 0, $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = 0, $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0);
 var $1049 = 0, $105 = 0, $1050 = 0.0, $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = 0.0, $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = 0.0, $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0;
 var $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = Math_fround(0), $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = Math_fround(0), $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = 0, $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0);
 var $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = 0, $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0;
 var $1102 = 0, $1103 = 0, $1104 = 0, $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = 0, $1108 = Math_fround(0), $1109 = 0, $111 = 0, $1110 = Math_fround(0), $1111 = 0, $1112 = Math_fround(0), $1113 = 0, $1114 = Math_fround(0), $1115 = 0, $1116 = Math_fround(0), $1117 = 0, $1118 = Math_fround(0), $1119 = 0, $112 = 0;
 var $1120 = Math_fround(0), $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = Math_fround(0);
 var $1139 = Math_fround(0), $114 = 0, $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = 0, $115 = 0, $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0);
 var $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = 0, $1163 = 0, $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0), $1169 = Math_fround(0), $117 = 0, $1170 = Math_fround(0), $1171 = Math_fround(0), $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = Math_fround(0);
 var $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = 0, $1180 = Math_fround(0), $1181 = Math_fround(0), $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0;
 var $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0.0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = 0, $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = 0, $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = 0;
 var $1210 = 0, $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = 0, $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = 0, $1217 = Math_fround(0), $1218 = Math_fround(0), $1219 = 0, $122 = 0, $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = 0, $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = 0, $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = 0;
 var $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = Math_fround(0), $1239 = Math_fround(0), $124 = 0, $1240 = Math_fround(0), $1241 = Math_fround(0), $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = Math_fround(0), $1245 = Math_fround(0), $1246 = Math_fround(0);
 var $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = 0, $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0), $1253 = 0, $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = 0, $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0);
 var $1265 = Math_fround(0), $1266 = 0, $1267 = 0, $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = Math_fround(0), $1276 = Math_fround(0), $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = 0, $1280 = Math_fround(0), $1281 = Math_fround(0), $1282 = Math_fround(0);
 var $1283 = Math_fround(0), $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = Math_fround(0), $1299 = Math_fround(0), $13 = 0, $130 = 0;
 var $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = Math_fround(0), $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0), $131 = 0, $1310 = Math_fround(0), $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = 0.0, $1314 = Math_fround(0), $1315 = 0.0, $1316 = Math_fround(0), $1317 = 0.0, $1318 = Math_fround(0);
 var $1319 = Math_fround(0), $132 = 0, $1320 = Math_fround(0), $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = Math_fround(0), $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = 0, $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0);
 var $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = 0, $1340 = Math_fround(0), $1341 = Math_fround(0), $1342 = Math_fround(0), $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0);
 var $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = 0, $136 = 0, $1360 = Math_fround(0), $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = 0, $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = 0;
 var $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = Math_fround(0), $1379 = Math_fround(0), $138 = 0, $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = 0, $1390 = Math_fround(0);
 var $1391 = Math_fround(0), $1392 = Math_fround(0), $1393 = Math_fround(0), $1394 = Math_fround(0), $1395 = Math_fround(0), $1396 = Math_fround(0), $1397 = Math_fround(0), $1398 = Math_fround(0), $1399 = Math_fround(0), $14 = 0.0, $140 = 0, $1400 = Math_fround(0), $1401 = Math_fround(0), $1402 = Math_fround(0), $1403 = Math_fround(0), $1404 = Math_fround(0), $1405 = Math_fround(0), $1406 = Math_fround(0), $1407 = Math_fround(0), $1408 = Math_fround(0);
 var $1409 = Math_fround(0), $141 = 0, $1410 = Math_fround(0), $1411 = Math_fround(0), $1412 = Math_fround(0), $1413 = Math_fround(0), $1414 = Math_fround(0), $1415 = Math_fround(0), $1416 = Math_fround(0), $1417 = Math_fround(0), $1418 = Math_fround(0), $1419 = Math_fround(0), $142 = 0, $1420 = Math_fround(0), $1421 = Math_fround(0), $1422 = Math_fround(0), $1423 = Math_fround(0), $1424 = Math_fround(0), $1425 = Math_fround(0), $1426 = Math_fround(0);
 var $1427 = Math_fround(0), $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0;
 var $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = Math_fround(0), $146 = 0, $1460 = Math_fround(0), $1461 = Math_fround(0), $1462 = 0;
 var $1463 = 0, $1464 = 0, $1465 = Math_fround(0), $1466 = Math_fround(0), $1467 = Math_fround(0), $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = Math_fround(0), $1472 = Math_fround(0), $1473 = Math_fround(0), $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0;
 var $1481 = 0, $1482 = 0, $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0), $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $15 = 0.0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0.0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0.0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0.0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0.0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0.0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0;
 var $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0);
 var $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0);
 var $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0);
 var $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = 0.0;
 var $462 = Math_fround(0), $463 = 0.0, $464 = Math_fround(0), $465 = 0.0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0.0, $475 = 0.0, $476 = Math_fround(0), $477 = 0, $478 = 0.0, $479 = 0.0, $48 = 0;
 var $480 = Math_fround(0), $481 = 0, $482 = 0.0, $483 = 0.0, $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0);
 var $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0);
 var $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0.0, $52 = Math_fround(0), $520 = 0.0, $521 = 0.0, $522 = 0.0, $523 = 0.0, $524 = 0.0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = 0.0;
 var $534 = 0.0, $535 = Math_fround(0), $536 = 0, $537 = 0.0, $538 = 0.0, $539 = Math_fround(0), $54 = Math_fround(0), $540 = 0, $541 = 0.0, $542 = 0.0, $543 = Math_fround(0), $544 = 0, $545 = 0.0, $546 = Math_fround(0), $547 = 0, $548 = 0.0, $549 = Math_fround(0), $55 = Math_fround(0), $550 = 0, $551 = 0.0;
 var $552 = Math_fround(0), $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = 0.0, $564 = Math_fround(0), $565 = 0.0, $566 = Math_fround(0), $567 = 0.0, $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0;
 var $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0);
 var $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0);
 var $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0);
 var $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0);
 var $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = Math_fround(0), $680 = Math_fround(0), $681 = 0, $682 = Math_fround(0), $683 = 0, $684 = Math_fround(0), $685 = 0, $686 = Math_fround(0), $687 = 0, $688 = Math_fround(0), $689 = 0, $69 = 0, $690 = Math_fround(0), $691 = 0, $692 = Math_fround(0), $693 = 0, $694 = Math_fround(0), $695 = 0, $696 = Math_fround(0);
 var $697 = 0, $698 = 0, $699 = 0, $7 = 0.0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0;
 var $714 = Math_fround(0), $715 = 0, $716 = 0, $717 = Math_fround(0), $718 = 0, $719 = 0, $72 = 0, $720 = Math_fround(0), $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = Math_fround(0), $726 = 0, $727 = 0, $728 = Math_fround(0), $729 = 0, $73 = 0, $730 = 0, $731 = Math_fround(0);
 var $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = Math_fround(0), $737 = 0, $738 = 0, $739 = Math_fround(0), $74 = 0, $740 = 0, $741 = 0, $742 = Math_fround(0), $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = Math_fround(0);
 var $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = Math_fround(0), $760 = 0, $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0);
 var $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = 0, $78 = Math_fround(0), $780 = 0.0, $781 = Math_fround(0), $782 = Math_fround(0), $783 = 0.0, $784 = Math_fround(0), $785 = Math_fround(0), $786 = 0.0;
 var $787 = Math_fround(0), $788 = Math_fround(0), $789 = 0, $79 = Math_fround(0), $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = 0, $802 = 0, $803 = 0;
 var $804 = 0, $805 = 0, $806 = 0, $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = Math_fround(0);
 var $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = Math_fround(0), $836 = Math_fround(0), $837 = 0, $838 = Math_fround(0), $839 = 0, $84 = 0;
 var $840 = Math_fround(0), $841 = 0, $842 = Math_fround(0), $843 = 0, $844 = Math_fround(0), $845 = 0, $846 = Math_fround(0), $847 = 0, $848 = Math_fround(0), $849 = 0, $85 = 0, $850 = Math_fround(0), $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0;
 var $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = 0, $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0);
 var $877 = Math_fround(0), $878 = Math_fround(0), $879 = 0, $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = Math_fround(0), $892 = 0, $893 = 0, $894 = Math_fround(0);
 var $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0.0, $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = Math_fround(0);
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = Math_fround(0), $933 = Math_fround(0), $934 = 0, $935 = Math_fround(0), $936 = Math_fround(0), $937 = 0, $938 = Math_fround(0), $939 = Math_fround(0), $94 = 0, $940 = 0, $941 = Math_fround(0), $942 = Math_fround(0), $943 = 0, $944 = Math_fround(0), $945 = Math_fround(0), $946 = 0, $947 = Math_fround(0), $948 = Math_fround(0);
 var $949 = 0, $95 = 0, $950 = Math_fround(0), $951 = Math_fround(0), $952 = 0, $953 = Math_fround(0), $954 = Math_fround(0), $955 = 0, $956 = Math_fround(0), $957 = Math_fround(0), $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0;
 var $967 = 0, $968 = Math_fround(0), $969 = Math_fround(0), $97 = 0, $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = 0, $984 = Math_fround(0);
 var $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0, $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = 0, $997 = 0, $998 = Math_fround(0), $999 = Math_fround(0), $Origin = 0, $TouchedTriangles$038$i = 0, $TouchedTriangles$038$i68 = 0, $actor$c$i = 0;
 var $actor$c$i12 = 0, $actor$c$i22 = 0, $actor$c$i3 = 0, $actor$c$i42 = 0, $actor$c$i8 = 0, $bg$i = 0, $boxGeom$i31 = 0, $boxPose$i32 = 0, $boxVerts$i = 0, $currentTriangle4$i36 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i26 = 0, $exitcond$i63 = 0, $exitcond25$i = 0, $exitcond26$i = 0, $exitcond42$i = 0, $exitcond42$i54 = 0, $exitcond43$i = 0, $exitcond43$i77 = 0;
 var $exitcond44$i = 0, $exitcond44$i70 = 0, $fabsf$i$i$i$i = Math_fround(0), $globalPose = 0, $hitBuffer = 0, $hits = 0, $i$024$i = 0, $i$027$i = 0, $i$027$i49 = 0, $i$095 = 0, $i1$022$i = 0, $i11$033$i = 0, $i11$033$i74 = 0, $i2$021$i = 0, $i2$025$i = 0, $i2$025$i60 = 0, $i6$039$i = 0, $i6$039$i67 = 0, $index$0$i$i = 0, $index$02$i$i = 0;
 var $index$03$i$i = 0, $nbCreatedTris$0$lcssa$i = 0, $nbCreatedTris$0$lcssa$i55 = 0, $nbCreatedTris$023$i = 0, $nbCreatedTris$028$i = 0, $nbCreatedTris$028$i48 = 0, $nbCreatedTris$1$i = 0, $nbCreatedTris$1$i53 = 0, $nbCreatedTris1$0$lcssa$i = 0, $nbCreatedTris1$0$lcssa$i64 = 0, $nbCreatedTris1$026$i = 0, $nbCreatedTris1$026$i59 = 0, $nbCreatedTris1$1$i = 0, $nbCreatedTris1$1$i62 = 0, $nbCreatedTris10$0$lcssa$i = 0, $nbCreatedTris10$0$lcssa$i78 = 0, $nbCreatedTris10$032$i = 0, $nbCreatedTris10$032$i75 = 0, $or$cond = 0, $overlapUtil$i33 = 0;
 var $params$idx$i23 = 0, $params$idx$val$i = Math_fround(0), $params$idx$val$i24 = Math_fround(0), $params$idx$val$i76 = Math_fround(0), $params$idx1$val$i = Math_fround(0), $params$idx1$val$i61 = Math_fround(0), $sceneQueryFilterData = 0, $tmpBounds = 0, $tp$i4$i29 = 0, $triGeom$i = 0, $triangleIndex$i34 = 0, $triangleIndex7$i37 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2352|0;
 $tp$i4$i29 = sp + 2296|0;
 $triGeom$i = sp + 2256|0;
 $boxGeom$i31 = sp + 2240|0;
 $boxPose$i32 = sp + 2208|0;
 $overlapUtil$i33 = sp + 1940|0;
 $triangleIndex$i34 = sp + 1936|0;
 $currentTriangle4$i36 = sp + 1900|0;
 $triangleIndex7$i37 = sp + 1896|0;
 $bg$i = sp + 1880|0;
 $boxVerts$i = sp + 56|0;
 $0 = sp + 24|0;
 $Origin = sp;
 $tmpBounds = sp + 32|0;
 $hits = sp + 152|0;
 $sceneQueryFilterData = sp + 1752|0;
 $hitBuffer = sp + 1772|0;
 $1 = sp + 1808|0;
 $2 = sp + 1824|0;
 $3 = sp + 2344|0;
 $globalPose = sp + 1852|0;
 $4 = HEAP32[$userData>>2]|0;
 $5 = (($userData) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = +HEAPF64[$worldBounds>>3];
 $8 = (($worldBounds) + 24|0);
 $9 = +HEAPF64[$8>>3];
 $10 = $7 + $9;
 $11 = (($worldBounds) + 8|0);
 $12 = +HEAPF64[$11>>3];
 $13 = (($worldBounds) + 32|0);
 $14 = +HEAPF64[$13>>3];
 $15 = $12 + $14;
 $16 = (($worldBounds) + 16|0);
 $17 = +HEAPF64[$16>>3];
 $18 = (($worldBounds) + 40|0);
 $19 = +HEAPF64[$18>>3];
 $20 = $17 + $19;
 $21 = (($Origin) + 8|0);
 $22 = (($Origin) + 16|0);
 $23 = $10 * 0.5;
 HEAPF64[$Origin>>3] = $23;
 $24 = $15 * 0.5;
 HEAPF64[$21>>3] = $24;
 $25 = $20 * 0.5;
 HEAPF64[$22>>3] = $25;
 $26 = (($filter) + 8|0);
 $27 = HEAP8[$26>>0]|0;
 $$ = $27&255;
 $28 = (($filter) + 9|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if ($30) {
  $41 = $$;
 } else {
  $31 = $27&255;
  $32 = $31 | 2;
  $33 = $32&65535;
  $41 = $33;
 }
 $34 = (($filter) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  $83 = $41;
 } else {
  $37 = (($filter) + 10|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $48 = $41;
  } else {
   $40 = $41&65535;
   $42 = $40 | 4;
   $43 = $42&65535;
   $48 = $43;
  }
  $44 = (($filter) + 11|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = ($45<<24>>24)==(0);
  if ($46) {
   $83 = $48;
  } else {
   $47 = $48&65535;
   $49 = $47 | 8;
   $50 = $49&65535;
   $83 = $50;
  }
 }
 $51 = Math_fround($7);
 $52 = Math_fround($12);
 $53 = Math_fround($17);
 $54 = Math_fround($9);
 $55 = Math_fround($14);
 $56 = Math_fround($19);
 HEAPF32[$tmpBounds>>2] = $51;
 $57 = (($tmpBounds) + 4|0);
 HEAPF32[$57>>2] = $52;
 $58 = (($tmpBounds) + 8|0);
 HEAPF32[$58>>2] = $53;
 $59 = (($tmpBounds) + 12|0);
 HEAPF32[$59>>2] = $54;
 $60 = (($tmpBounds) + 16|0);
 HEAPF32[$60>>2] = $55;
 $61 = (($tmpBounds) + 20|0);
 HEAPF32[$61>>2] = $56;
 $62 = Math_fround($51 + $54);
 $63 = Math_fround($56 + $53);
 $64 = Math_fround($62 * Math_fround(0.5));
 $65 = Math_fround($63 * Math_fround(0.5));
 $66 = Math_fround($55 - $52);
 $67 = Math_fround($56 - $53);
 $68 = Math_fround($66 * Math_fround(0.5));
 $69 = (($hits) + 1600|0);
 $70 = $hits;
 while(1) {
  HEAP32[$70>>2] = 0;
  $71 = (($70) + 4|0);
  HEAP32[$71>>2] = 0;
  $72 = (($70) + 8|0);
  HEAP32[$72>>2] = -1;
  $73 = (($70) + 16|0);
  $74 = ($73|0)==($69|0);
  if ($74) {
   break;
  } else {
   $70 = $73;
  }
 }
 $75 = Math_fround($52 + $55);
 $76 = Math_fround($75 * Math_fround(0.5));
 $77 = Math_fround($54 - $51);
 $78 = Math_fround($77 * Math_fround(0.5));
 $79 = Math_fround($67 * Math_fround(0.5));
 $80 = HEAP32[$filter>>2]|0;
 $81 = ($80|0)==(0|0);
 if ($81) {
  ;HEAP32[$sceneQueryFilterData+0>>2]=0|0;HEAP32[$sceneQueryFilterData+4>>2]=0|0;HEAP32[$sceneQueryFilterData+8>>2]=0|0;HEAP32[$sceneQueryFilterData+12>>2]=0|0;
  $85 = (($sceneQueryFilterData) + 16|0);
  HEAP16[$85>>1] = $83;
  $86 = (($sceneQueryFilterData) + 18|0);
  HEAP8[$86>>0] = 0;
 } else {
  ;HEAP32[$sceneQueryFilterData+0>>2]=HEAP32[$80+0>>2]|0;HEAP32[$sceneQueryFilterData+4>>2]=HEAP32[$80+4>>2]|0;HEAP32[$sceneQueryFilterData+8>>2]=HEAP32[$80+8>>2]|0;HEAP32[$sceneQueryFilterData+12>>2]=HEAP32[$80+12>>2]|0;
  $82 = (($sceneQueryFilterData) + 16|0);
  HEAP16[$82>>1] = $83;
  $84 = (($sceneQueryFilterData) + 18|0);
  HEAP8[$84>>0] = 0;
 }
 $87 = (($hitBuffer) + 4|0);
 HEAP32[$87>>2] = 0;
 $88 = (($hitBuffer) + 8|0);
 HEAP32[$88>>2] = 0;
 $89 = (($hitBuffer) + 12|0);
 HEAP32[$89>>2] = -1;
 $90 = (($hitBuffer) + 20|0);
 HEAP8[$90>>0] = 0;
 $91 = (($hitBuffer) + 24|0);
 HEAP32[$91>>2] = $hits;
 $92 = (($hitBuffer) + 28|0);
 HEAP32[$92>>2] = 100;
 $93 = (($hitBuffer) + 32|0);
 HEAP32[$93>>2] = 0;
 HEAP32[$hitBuffer>>2] = ((404640 + 8|0));
 $94 = (($sceneQueryFilterData) + 16|0);
 $95 = $83&65535;
 $96 = $95 | 32;
 $97 = $96&65535;
 HEAP16[$94>>1] = $97;
 $98 = HEAP32[$4>>2]|0;
 $99 = (($98) + 356|0);
 $100 = HEAP32[$99>>2]|0;
 HEAP32[$1>>2] = 3;
 $101 = (($1) + 4|0);
 HEAPF32[$101>>2] = $78;
 $102 = (($1) + 8|0);
 HEAPF32[$102>>2] = $68;
 $103 = (($1) + 12|0);
 HEAPF32[$103>>2] = $79;
 HEAPF32[$2>>2] = Math_fround(0.0);
 $104 = (($2) + 4|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($2) + 8|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = (($2) + 12|0);
 HEAPF32[$106>>2] = Math_fround(1.0);
 $107 = (($2) + 16|0);
 HEAPF32[$107>>2] = $64;
 $108 = (($2) + 20|0);
 HEAPF32[$108>>2] = $76;
 $109 = (($2) + 24|0);
 HEAPF32[$109>>2] = $65;
 $110 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiiiiii[$100 & 255]($4,$1,$2,$hitBuffer,$sceneQueryFilterData,$110)|0);
 $111 = HEAP32[$93>>2]|0;
 $112 = HEAP8[$90>>0]|0;
 $113 = $112&255;
 $114 = (($113) + ($111))|0;
 $115 = ($114|0)==(0);
 if ($115) {
  STACKTOP = sp;return;
 }
 $116 = (($userData) + 8|0);
 $117 = (($triGeom$i) + 16|0);
 $118 = (($triGeom$i) + 20|0);
 $119 = (($triGeom$i) + 24|0);
 $120 = (($tp$i4$i29) + 12|0);
 $121 = (($tp$i4$i29) + 4|0);
 $122 = (($tp$i4$i29) + 8|0);
 $123 = (($tp$i4$i29) + 16|0);
 $124 = (($tp$i4$i29) + 20|0);
 $125 = (($tp$i4$i29) + 24|0);
 $126 = (($triGeom$i) + 12|0);
 $127 = (($triGeom$i) + 8|0);
 $128 = (($triGeom$i) + 4|0);
 $129 = (($globalPose) + 4|0);
 $130 = (($globalPose) + 8|0);
 $131 = (($globalPose) + 12|0);
 $132 = (($globalPose) + 16|0);
 $133 = (($globalPose) + 20|0);
 $134 = (($globalPose) + 24|0);
 $135 = (($tp$i4$i29) + 4|0);
 $136 = (($geomStream) + 4|0);
 $137 = (($tp$i4$i29) + 4|0);
 $138 = (($tp$i4$i29) + 8|0);
 $139 = (($bg$i) + 4|0);
 $140 = (($bg$i) + 8|0);
 $141 = (($bg$i) + 12|0);
 $142 = (($boxVerts$i) + 4|0);
 $143 = (($boxVerts$i) + 8|0);
 $144 = (($boxVerts$i) + 12|0);
 $145 = (($boxVerts$i) + 16|0);
 $146 = (($boxVerts$i) + 20|0);
 $147 = (($boxVerts$i) + 24|0);
 $148 = (($boxVerts$i) + 28|0);
 $149 = (($boxVerts$i) + 32|0);
 $150 = (($boxVerts$i) + 36|0);
 $151 = (($boxVerts$i) + 40|0);
 $152 = (($boxVerts$i) + 44|0);
 $153 = (($boxVerts$i) + 48|0);
 $154 = (($boxVerts$i) + 52|0);
 $155 = (($boxVerts$i) + 56|0);
 $156 = (($boxVerts$i) + 60|0);
 $157 = (($boxVerts$i) + 64|0);
 $158 = (($boxVerts$i) + 68|0);
 $159 = (($boxVerts$i) + 72|0);
 $160 = (($boxVerts$i) + 76|0);
 $161 = (($boxVerts$i) + 80|0);
 $162 = (($boxVerts$i) + 84|0);
 $163 = (($boxVerts$i) + 88|0);
 $164 = (($boxVerts$i) + 92|0);
 $165 = (($worldTriangles) + 4|0);
 $166 = (($params) + 56|0);
 $167 = (($triIndicesArray) + 8|0);
 $168 = (($triIndicesArray) + 4|0);
 $169 = (($triGeom$i) + 4|0);
 $170 = (($triGeom$i) + 8|0);
 $171 = (($triGeom$i) + 12|0);
 $172 = (($triGeom$i) + 16|0);
 $173 = (($triGeom$i) + 20|0);
 $174 = (($triGeom$i) + 24|0);
 $175 = (($triGeom$i) + 28|0);
 $176 = (($triGeom$i) + 32|0);
 $params$idx$i23 = (($params) + 52|0);
 $177 = (($tp$i4$i29) + 4|0);
 $178 = (($tp$i4$i29) + 8|0);
 $179 = (($tp$i4$i29) + 12|0);
 $180 = (($tp$i4$i29) + 16|0);
 $181 = (($tp$i4$i29) + 20|0);
 $182 = (($tp$i4$i29) + 24|0);
 $183 = (($tp$i4$i29) + 28|0);
 $184 = (($tp$i4$i29) + 32|0);
 $185 = (($tp$i4$i29) + 36|0);
 $186 = (($tp$i4$i29) + 40|0);
 $187 = (($tp$i4$i29) + 44|0);
 $188 = (($triGeom$i) + 12|0);
 $189 = (($triGeom$i) + 24|0);
 $190 = (($triGeom$i) + 4|0);
 $191 = (($triGeom$i) + 8|0);
 $192 = (($triGeom$i) + 12|0);
 $193 = (($triGeom$i) + 16|0);
 $194 = (($triGeom$i) + 20|0);
 $195 = (($triGeom$i) + 24|0);
 $196 = (($triGeom$i) + 28|0);
 $197 = (($triGeom$i) + 32|0);
 $198 = (($boxGeom$i31) + 4|0);
 $199 = (($boxGeom$i31) + 8|0);
 $200 = (($boxGeom$i31) + 12|0);
 $201 = (($boxPose$i32) + 4|0);
 $202 = (($boxPose$i32) + 8|0);
 $203 = (($boxPose$i32) + 12|0);
 $204 = (($boxPose$i32) + 16|0);
 $205 = (($boxPose$i32) + 20|0);
 $206 = (($boxPose$i32) + 24|0);
 $207 = (($params) + 32|0);
 $208 = (($currentTriangle4$i36) + 4|0);
 $209 = (($currentTriangle4$i36) + 8|0);
 $210 = (($currentTriangle4$i36) + 12|0);
 $211 = (($currentTriangle4$i36) + 16|0);
 $212 = (($currentTriangle4$i36) + 20|0);
 $213 = (($currentTriangle4$i36) + 24|0);
 $214 = (($currentTriangle4$i36) + 28|0);
 $215 = (($currentTriangle4$i36) + 32|0);
 $216 = (($tp$i4$i29) + 4|0);
 $217 = (($tp$i4$i29) + 8|0);
 $218 = (($tp$i4$i29) + 12|0);
 $219 = (($tp$i4$i29) + 16|0);
 $220 = (($tp$i4$i29) + 20|0);
 $221 = (($tp$i4$i29) + 24|0);
 $222 = (($tp$i4$i29) + 28|0);
 $223 = (($tp$i4$i29) + 32|0);
 $224 = (($tp$i4$i29) + 36|0);
 $225 = (($tp$i4$i29) + 40|0);
 $226 = (($tp$i4$i29) + 44|0);
 $227 = (($tp$i4$i29) + 4|0);
 $228 = (($tp$i4$i29) + 8|0);
 $229 = (($tp$i4$i29) + 12|0);
 $230 = (($tp$i4$i29) + 16|0);
 $231 = (($tp$i4$i29) + 20|0);
 $232 = (($tp$i4$i29) + 24|0);
 $233 = (($tp$i4$i29) + 28|0);
 $234 = (($tp$i4$i29) + 32|0);
 $235 = (($worldTriangles) + 8|0);
 $236 = (($params) + 20|0);
 $237 = (($currentTriangle4$i36) + 4|0);
 $238 = (($currentTriangle4$i36) + 8|0);
 $239 = (($currentTriangle4$i36) + 12|0);
 $240 = (($currentTriangle4$i36) + 16|0);
 $241 = (($currentTriangle4$i36) + 20|0);
 $242 = (($currentTriangle4$i36) + 24|0);
 $243 = (($currentTriangle4$i36) + 28|0);
 $244 = (($currentTriangle4$i36) + 32|0);
 $245 = (($tp$i4$i29) + 4|0);
 $246 = (($tp$i4$i29) + 8|0);
 $247 = (($tp$i4$i29) + 12|0);
 $248 = (($tp$i4$i29) + 16|0);
 $249 = (($tp$i4$i29) + 20|0);
 $250 = (($tp$i4$i29) + 24|0);
 $251 = (($tp$i4$i29) + 28|0);
 $252 = (($tp$i4$i29) + 32|0);
 $253 = (($tp$i4$i29) + 36|0);
 $254 = (($tp$i4$i29) + 40|0);
 $255 = (($tp$i4$i29) + 44|0);
 $256 = (($triGeom$i) + 4|0);
 $257 = (($triGeom$i) + 8|0);
 $258 = (($triGeom$i) + 12|0);
 $259 = (($triGeom$i) + 16|0);
 $260 = (($triGeom$i) + 20|0);
 $261 = (($boxGeom$i31) + 4|0);
 $262 = (($boxGeom$i31) + 8|0);
 $263 = (($boxGeom$i31) + 12|0);
 $264 = (($boxPose$i32) + 4|0);
 $265 = (($boxPose$i32) + 8|0);
 $266 = (($boxPose$i32) + 12|0);
 $267 = (($boxPose$i32) + 16|0);
 $268 = (($boxPose$i32) + 20|0);
 $269 = (($boxPose$i32) + 24|0);
 $270 = (($currentTriangle4$i36) + 4|0);
 $271 = (($currentTriangle4$i36) + 8|0);
 $272 = (($currentTriangle4$i36) + 12|0);
 $273 = (($currentTriangle4$i36) + 16|0);
 $274 = (($currentTriangle4$i36) + 20|0);
 $275 = (($currentTriangle4$i36) + 24|0);
 $276 = (($currentTriangle4$i36) + 28|0);
 $277 = (($currentTriangle4$i36) + 32|0);
 $278 = (($tp$i4$i29) + 4|0);
 $279 = (($tp$i4$i29) + 8|0);
 $280 = (($tp$i4$i29) + 12|0);
 $281 = (($tp$i4$i29) + 16|0);
 $282 = (($tp$i4$i29) + 20|0);
 $283 = (($tp$i4$i29) + 24|0);
 $284 = (($tp$i4$i29) + 28|0);
 $285 = (($tp$i4$i29) + 32|0);
 $286 = (($tp$i4$i29) + 36|0);
 $287 = (($tp$i4$i29) + 40|0);
 $288 = (($tp$i4$i29) + 44|0);
 $289 = (($tp$i4$i29) + 4|0);
 $290 = (($tp$i4$i29) + 8|0);
 $291 = (($tp$i4$i29) + 12|0);
 $292 = (($tp$i4$i29) + 16|0);
 $293 = (($tp$i4$i29) + 20|0);
 $294 = (($tp$i4$i29) + 24|0);
 $295 = (($tp$i4$i29) + 28|0);
 $296 = (($tp$i4$i29) + 32|0);
 $297 = (($currentTriangle4$i36) + 4|0);
 $298 = (($currentTriangle4$i36) + 8|0);
 $299 = (($currentTriangle4$i36) + 12|0);
 $300 = (($currentTriangle4$i36) + 16|0);
 $301 = (($currentTriangle4$i36) + 20|0);
 $302 = (($currentTriangle4$i36) + 24|0);
 $303 = (($currentTriangle4$i36) + 28|0);
 $304 = (($currentTriangle4$i36) + 32|0);
 $305 = (($tp$i4$i29) + 4|0);
 $306 = (($tp$i4$i29) + 8|0);
 $307 = (($tp$i4$i29) + 12|0);
 $308 = (($tp$i4$i29) + 16|0);
 $309 = (($tp$i4$i29) + 20|0);
 $310 = (($tp$i4$i29) + 24|0);
 $311 = (($tp$i4$i29) + 28|0);
 $312 = (($tp$i4$i29) + 32|0);
 $313 = (($tp$i4$i29) + 36|0);
 $314 = (($tp$i4$i29) + 40|0);
 $315 = (($tp$i4$i29) + 44|0);
 $316 = (($hitBuffer) + 4|0);
 $i$095 = 0;
 while(1) {
  $317 = HEAP32[$93>>2]|0;
  $318 = ($317>>>0)>($i$095>>>0);
  if ($318) {
   $319 = HEAP32[$91>>2]|0;
   $320 = (($319) + ($i$095<<4)|0);
   $322 = $320;
  } else {
   $322 = $316;
  }
  $321 = (($322) + 4|0);
  $323 = HEAP32[$321>>2]|0;
  $324 = HEAP32[$322>>2]|0;
  $325 = ($323|0)==(0|0);
  $326 = ($324|0)==(0|0);
  $or$cond = $325 | $326;
  L26: do {
   if (!($or$cond)) {
    $327 = HEAP32[$116>>2]|0;
    $328 = (($327) + 20|0);
    $329 = HEAP32[$328>>2]|0;
    $330 = ($329|0)==(0);
    L28: do {
     if (!($330)) {
      $331 = $323;
      $332 = $331 << 15;
      $333 = $332 ^ -1;
      $334 = (($331) + ($333))|0;
      $335 = $334 >>> 10;
      $336 = $335 ^ $334;
      $337 = ($336*9)|0;
      $338 = $337 >>> 6;
      $339 = $338 ^ $337;
      $340 = $339 << 11;
      $341 = $340 ^ -1;
      $342 = (($339) + ($341))|0;
      $343 = $342 >>> 16;
      $344 = $343 ^ $342;
      $345 = (($329) + -1)|0;
      $346 = $345 & $344;
      $347 = (($327) + 12|0);
      $348 = HEAP32[$347>>2]|0;
      $349 = (($348) + ($346<<2)|0);
      $index$02$i$i = HEAP32[$349>>2]|0;
      $350 = ($index$02$i$i|0)==(-1);
      if (!($350)) {
       $351 = (($327) + 4|0);
       $352 = HEAP32[$351>>2]|0;
       $353 = (($327) + 8|0);
       $index$03$i$i = $index$02$i$i;
       while(1) {
        $354 = (($352) + ($index$03$i$i<<2)|0);
        $355 = HEAP32[$354>>2]|0;
        $356 = ($355|0)==($323|0);
        if ($356) {
         break;
        }
        $357 = HEAP32[$353>>2]|0;
        $358 = (($357) + ($index$03$i$i<<2)|0);
        $index$0$i$i = HEAP32[$358>>2]|0;
        $359 = ($index$0$i$i|0)==(-1);
        if ($359) {
         break L28;
        } else {
         $index$03$i$i = $index$0$i$i;
        }
       }
       $360 = ($354|0)==(0|0);
       if (!($360)) {
        break L26;
       }
      }
     }
    } while(0);
    $361 = HEAP32[$323>>2]|0;
    $362 = (($361) + 136|0);
    $363 = HEAP32[$362>>2]|0;
    FUNCTION_TABLE_vii[$363 & 4095]($3,$323);
    $364 = HEAP8[$3>>0]|0;
    $365 = $364 & 4;
    $366 = ($365<<24>>24)==(0);
    if ($366) {
     $367 = HEAP32[$324>>2]|0;
     $368 = (($367) + 84|0);
     $369 = HEAP32[$368>>2]|0;
     FUNCTION_TABLE_vii[$369 & 4095]($tp$i4$i29,$324);
     $370 = HEAP32[$323>>2]|0;
     $371 = (($370) + 72|0);
     $372 = HEAP32[$371>>2]|0;
     FUNCTION_TABLE_vii[$372 & 4095]($triGeom$i,$323);
     $373 = Math_fround(HEAPF32[$117>>2]);
     $374 = Math_fround($373 * Math_fround(2.0));
     $375 = Math_fround(HEAPF32[$118>>2]);
     $376 = Math_fround($375 * Math_fround(2.0));
     $377 = Math_fround(HEAPF32[$119>>2]);
     $378 = Math_fround($377 * Math_fround(2.0));
     $379 = Math_fround(HEAPF32[$120>>2]);
     $380 = Math_fround($379 * $379);
     $381 = Math_fround($380 + Math_fround(-0.5));
     $382 = Math_fround(HEAPF32[$tp$i4$i29>>2]);
     $383 = Math_fround($374 * $382);
     $384 = Math_fround(HEAPF32[$121>>2]);
     $385 = Math_fround($376 * $384);
     $386 = Math_fround($383 + $385);
     $387 = Math_fround(HEAPF32[$122>>2]);
     $388 = Math_fround($378 * $387);
     $389 = Math_fround($386 + $388);
     $390 = Math_fround($374 * $381);
     $391 = Math_fround($378 * $384);
     $392 = Math_fround($376 * $387);
     $393 = Math_fround($391 - $392);
     $394 = Math_fround($379 * $393);
     $395 = Math_fround($390 + $394);
     $396 = Math_fround($382 * $389);
     $397 = Math_fround($396 + $395);
     $398 = Math_fround($376 * $381);
     $399 = Math_fround($374 * $387);
     $400 = Math_fround($378 * $382);
     $401 = Math_fround($399 - $400);
     $402 = Math_fround($379 * $401);
     $403 = Math_fround($398 + $402);
     $404 = Math_fround($384 * $389);
     $405 = Math_fround($404 + $403);
     $406 = Math_fround($378 * $381);
     $407 = Math_fround($376 * $382);
     $408 = Math_fround($374 * $384);
     $409 = Math_fround($407 - $408);
     $410 = Math_fround($379 * $409);
     $411 = Math_fround($406 + $410);
     $412 = Math_fround($387 * $389);
     $413 = Math_fround($411 + $412);
     $414 = Math_fround(HEAPF32[$123>>2]);
     $415 = Math_fround($414 + $397);
     $416 = Math_fround(HEAPF32[$124>>2]);
     $417 = Math_fround($416 + $405);
     $418 = Math_fround(HEAPF32[$125>>2]);
     $419 = Math_fround($418 + $413);
     $420 = Math_fround(HEAPF32[$triGeom$i>>2]);
     $421 = Math_fround($379 * $420);
     $422 = Math_fround(HEAPF32[$126>>2]);
     $423 = Math_fround($382 * $422);
     $424 = Math_fround($421 + $423);
     $425 = Math_fround(HEAPF32[$127>>2]);
     $426 = Math_fround($384 * $425);
     $427 = Math_fround($424 + $426);
     $428 = Math_fround(HEAPF32[$128>>2]);
     $429 = Math_fround($387 * $428);
     $430 = Math_fround($427 - $429);
     $431 = Math_fround($379 * $428);
     $432 = Math_fround($384 * $422);
     $433 = Math_fround($432 + $431);
     $434 = Math_fround($387 * $420);
     $435 = Math_fround($434 + $433);
     $436 = Math_fround($382 * $425);
     $437 = Math_fround($435 - $436);
     $438 = Math_fround($379 * $425);
     $439 = Math_fround($387 * $422);
     $440 = Math_fround($439 + $438);
     $441 = Math_fround($382 * $428);
     $442 = Math_fround($441 + $440);
     $443 = Math_fround($384 * $420);
     $444 = Math_fround($442 - $443);
     $445 = Math_fround($379 * $422);
     $446 = Math_fround($382 * $420);
     $447 = Math_fround($445 - $446);
     $448 = Math_fround($384 * $428);
     $449 = Math_fround($447 - $448);
     $450 = Math_fround($387 * $425);
     $451 = Math_fround($449 - $450);
     HEAPF32[$globalPose>>2] = $430;
     HEAPF32[$129>>2] = $437;
     HEAPF32[$130>>2] = $444;
     HEAPF32[$131>>2] = $451;
     HEAPF32[$132>>2] = $415;
     HEAPF32[$133>>2] = $417;
     HEAPF32[$134>>2] = $419;
     $452 = HEAP32[$323>>2]|0;
     $453 = (($452) + 24|0);
     $454 = HEAP32[$453>>2]|0;
     $455 = (FUNCTION_TABLE_ii[$454 & 4095]($323)|0);
     switch ($455|0) {
     case 0:  {
      HEAP32[$tp$i4$i29>>2] = 0;
      HEAPF32[$135>>2] = Math_fround(0.0);
      $456 = HEAP32[$323>>2]|0;
      $457 = (($456) + 40|0);
      $458 = HEAP32[$457>>2]|0;
      (FUNCTION_TABLE_iii[$458 & 4095]($323,$tp$i4$i29)|0);
      $459 = Math_fround(HEAPF32[$135>>2]);
      $460 = Math_fround(HEAPF32[$132>>2]);
      $461 = +$460;
      $462 = Math_fround(HEAPF32[$133>>2]);
      $463 = +$462;
      $464 = Math_fround(HEAPF32[$134>>2]);
      $465 = +$464;
      $466 = HEAP32[$136>>2]|0;
      $467 = (($466) + 14)|0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($geomStream,$467);
      $468 = HEAP32[$geomStream>>2]|0;
      $469 = (($468) + ($466<<2)|0);
      HEAP32[$469>>2] = 4;
      $$sum$i6 = (($466) + 1)|0;
      $470 = (($468) + ($$sum$i6<<2)|0);
      $$c$i7 = $323;
      HEAP32[$470>>2] = $$c$i7;
      $$sum1$i = (($466) + 2)|0;
      $471 = (($468) + ($$sum1$i<<2)|0);
      $actor$c$i8 = $324;
      HEAP32[$471>>2] = $actor$c$i8;
      $$sum2$i = (($466) + 4)|0;
      $472 = (($468) + ($$sum2$i<<2)|0);
      ;HEAP32[$472+0>>2]=HEAP32[$Origin+0>>2]|0;HEAP32[$472+4>>2]=HEAP32[$Origin+4>>2]|0;HEAP32[$472+8>>2]=HEAP32[$Origin+8>>2]|0;HEAP32[$472+12>>2]=HEAP32[$Origin+12>>2]|0;HEAP32[$472+16>>2]=HEAP32[$Origin+16>>2]|0;HEAP32[$472+20>>2]=HEAP32[$Origin+20>>2]|0;
      $$sum3$i = (($466) + 13)|0;
      $473 = (($468) + ($$sum3$i<<2)|0);
      HEAPF32[$473>>2] = $459;
      $474 = +HEAPF64[$Origin>>3];
      $475 = $461 - $474;
      $476 = Math_fround($475);
      $$sum4$i = (($466) + 10)|0;
      $477 = (($468) + ($$sum4$i<<2)|0);
      HEAPF32[$477>>2] = $476;
      $478 = +HEAPF64[$21>>3];
      $479 = $463 - $478;
      $480 = Math_fround($479);
      $$sum5$i = (($466) + 11)|0;
      $481 = (($468) + ($$sum5$i<<2)|0);
      HEAPF32[$481>>2] = $480;
      $482 = +HEAPF64[$22>>3];
      $483 = $465 - $482;
      $484 = Math_fround($483);
      $$sum6$i = (($466) + 12)|0;
      $485 = (($468) + ($$sum6$i<<2)|0);
      HEAPF32[$485>>2] = $484;
      break L26;
      break;
     }
     case 2:  {
      HEAP32[$tp$i4$i29>>2] = 2;
      HEAPF32[$137>>2] = Math_fround(0.0);
      HEAPF32[$138>>2] = Math_fround(0.0);
      $486 = HEAP32[$323>>2]|0;
      $487 = (($486) + 44|0);
      $488 = HEAP32[$487>>2]|0;
      (FUNCTION_TABLE_iii[$488 & 4095]($323,$tp$i4$i29)|0);
      $489 = Math_fround(HEAPF32[$138>>2]);
      $490 = Math_fround(HEAPF32[$globalPose>>2]);
      $491 = Math_fround($490 * Math_fround(2.0));
      $492 = Math_fround(HEAPF32[$131>>2]);
      $493 = Math_fround($492 * Math_fround(2.0));
      $494 = Math_fround($492 * $493);
      $495 = Math_fround($494 + Math_fround(-1.0));
      $496 = Math_fround($490 * $491);
      $497 = Math_fround($496 + $495);
      $498 = Math_fround(HEAPF32[$130>>2]);
      $499 = Math_fround($498 * $493);
      $500 = Math_fround(HEAPF32[$129>>2]);
      $501 = Math_fround($491 * $500);
      $502 = Math_fround($499 + $501);
      $503 = Math_fround($493 * $500);
      $504 = Math_fround($491 * $498);
      $505 = Math_fround($504 - $503);
      $506 = Math_fround($489 * $497);
      $507 = Math_fround($489 * $502);
      $508 = Math_fround($489 * $505);
      $509 = Math_fround(HEAPF32[$132>>2]);
      $510 = Math_fround($509 + $506);
      $511 = Math_fround(HEAPF32[$133>>2]);
      $512 = Math_fround($511 + $507);
      $513 = Math_fround(HEAPF32[$134>>2]);
      $514 = Math_fround($513 + $508);
      $515 = Math_fround($509 - $506);
      $516 = Math_fround($511 - $507);
      $517 = Math_fround($513 - $508);
      $518 = Math_fround(HEAPF32[$137>>2]);
      $519 = +$510;
      $520 = +$512;
      $521 = +$514;
      $522 = +$515;
      $523 = +$516;
      $524 = +$517;
      $525 = HEAP32[$136>>2]|0;
      $526 = (($525) + 18)|0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($geomStream,$526);
      $527 = HEAP32[$geomStream>>2]|0;
      $528 = (($527) + ($525<<2)|0);
      HEAP32[$528>>2] = 5;
      $$sum$i9 = (($525) + 1)|0;
      $529 = (($527) + ($$sum$i9<<2)|0);
      $$c$i10 = $323;
      HEAP32[$529>>2] = $$c$i10;
      $$sum3$i11 = (($525) + 2)|0;
      $530 = (($527) + ($$sum3$i11<<2)|0);
      $actor$c$i12 = $324;
      HEAP32[$530>>2] = $actor$c$i12;
      $$sum4$i13 = (($525) + 4)|0;
      $531 = (($527) + ($$sum4$i13<<2)|0);
      ;HEAP32[$531+0>>2]=HEAP32[$Origin+0>>2]|0;HEAP32[$531+4>>2]=HEAP32[$Origin+4>>2]|0;HEAP32[$531+8>>2]=HEAP32[$Origin+8>>2]|0;HEAP32[$531+12>>2]=HEAP32[$Origin+12>>2]|0;HEAP32[$531+16>>2]=HEAP32[$Origin+16>>2]|0;HEAP32[$531+20>>2]=HEAP32[$Origin+20>>2]|0;
      $$sum5$i14 = (($525) + 16)|0;
      $532 = (($527) + ($$sum5$i14<<2)|0);
      HEAPF32[$532>>2] = $518;
      $533 = +HEAPF64[$Origin>>3];
      $534 = $519 - $533;
      $535 = Math_fround($534);
      $$sum6$i15 = (($525) + 10)|0;
      $536 = (($527) + ($$sum6$i15<<2)|0);
      HEAPF32[$536>>2] = $535;
      $537 = +HEAPF64[$21>>3];
      $538 = $520 - $537;
      $539 = Math_fround($538);
      $$sum7$i = (($525) + 11)|0;
      $540 = (($527) + ($$sum7$i<<2)|0);
      HEAPF32[$540>>2] = $539;
      $541 = +HEAPF64[$22>>3];
      $542 = $521 - $541;
      $543 = Math_fround($542);
      $$sum8$i = (($525) + 12)|0;
      $544 = (($527) + ($$sum8$i<<2)|0);
      HEAPF32[$544>>2] = $543;
      $545 = $522 - $533;
      $546 = Math_fround($545);
      $$sum9$i = (($525) + 13)|0;
      $547 = (($527) + ($$sum9$i<<2)|0);
      HEAPF32[$547>>2] = $546;
      $548 = $523 - $537;
      $549 = Math_fround($548);
      $$sum10$i = (($525) + 14)|0;
      $550 = (($527) + ($$sum10$i<<2)|0);
      HEAPF32[$550>>2] = $549;
      $551 = $524 - $541;
      $552 = Math_fround($551);
      $$sum11$i = (($525) + 15)|0;
      $553 = (($527) + ($$sum11$i<<2)|0);
      HEAPF32[$553>>2] = $552;
      break L26;
      break;
     }
     case 3:  {
      HEAP32[$bg$i>>2] = 3;
      HEAPF32[$139>>2] = Math_fround(0.0);
      HEAPF32[$140>>2] = Math_fround(0.0);
      HEAPF32[$141>>2] = Math_fround(0.0);
      $554 = HEAP32[$323>>2]|0;
      $555 = (($554) + 36|0);
      $556 = HEAP32[$555>>2]|0;
      (FUNCTION_TABLE_iii[$556 & 4095]($323,$bg$i)|0);
      $557 = Math_fround(HEAPF32[$139>>2]);
      $558 = Math_fround(HEAPF32[$140>>2]);
      $559 = Math_fround(HEAPF32[$141>>2]);
      $560 = Math_fround(-$557);
      $561 = Math_fround(-$558);
      $562 = Math_fround(-$559);
      HEAPF32[$boxVerts$i>>2] = $560;
      HEAPF32[$142>>2] = $561;
      HEAPF32[$143>>2] = $562;
      HEAPF32[$144>>2] = $557;
      HEAPF32[$145>>2] = $561;
      HEAPF32[$146>>2] = $562;
      HEAPF32[$147>>2] = $557;
      HEAPF32[$148>>2] = $558;
      HEAPF32[$149>>2] = $562;
      HEAPF32[$150>>2] = $560;
      HEAPF32[$151>>2] = $558;
      HEAPF32[$152>>2] = $562;
      HEAPF32[$153>>2] = $560;
      HEAPF32[$154>>2] = $561;
      HEAPF32[$155>>2] = $559;
      HEAPF32[$156>>2] = $557;
      HEAPF32[$157>>2] = $561;
      HEAPF32[$158>>2] = $559;
      HEAPF32[$159>>2] = $557;
      HEAPF32[$160>>2] = $558;
      HEAPF32[$161>>2] = $559;
      HEAPF32[$162>>2] = $560;
      HEAPF32[$163>>2] = $558;
      HEAPF32[$164>>2] = $559;
      $563 = +HEAPF64[$Origin>>3];
      $564 = Math_fround($563);
      $565 = +HEAPF64[$21>>3];
      $566 = Math_fround($565);
      $567 = +HEAPF64[$22>>3];
      $568 = Math_fround($567);
      $569 = Math_fround(HEAPF32[$131>>2]);
      $570 = Math_fround($569 * $569);
      $571 = Math_fround($570 + Math_fround(-0.5));
      $572 = Math_fround(HEAPF32[$globalPose>>2]);
      $573 = Math_fround(HEAPF32[$129>>2]);
      $574 = Math_fround(HEAPF32[$130>>2]);
      $575 = Math_fround(HEAPF32[$132>>2]);
      $576 = Math_fround(HEAPF32[$133>>2]);
      $577 = Math_fround(HEAPF32[$134>>2]);
      $580 = $560;$583 = $561;$586 = $562;$i$024$i = 0;
      while(1) {
       $578 = (($boxVerts$i) + (($i$024$i*12)|0)|0);
       $579 = Math_fround($580 * Math_fround(2.0));
       $581 = ((($boxVerts$i) + (($i$024$i*12)|0)|0) + 4|0);
       $582 = Math_fround($583 * Math_fround(2.0));
       $584 = ((($boxVerts$i) + (($i$024$i*12)|0)|0) + 8|0);
       $585 = Math_fround($586 * Math_fround(2.0));
       $587 = Math_fround($572 * $579);
       $588 = Math_fround($573 * $582);
       $589 = Math_fround($588 + $587);
       $590 = Math_fround($574 * $585);
       $591 = Math_fround($590 + $589);
       $592 = Math_fround($571 * $579);
       $593 = Math_fround($573 * $585);
       $594 = Math_fround($574 * $582);
       $595 = Math_fround($593 - $594);
       $596 = Math_fround($569 * $595);
       $597 = Math_fround($592 + $596);
       $598 = Math_fround($572 * $591);
       $599 = Math_fround($597 + $598);
       $600 = Math_fround($571 * $582);
       $601 = Math_fround($574 * $579);
       $602 = Math_fround($572 * $585);
       $603 = Math_fround($601 - $602);
       $604 = Math_fround($569 * $603);
       $605 = Math_fround($600 + $604);
       $606 = Math_fround($573 * $591);
       $607 = Math_fround($606 + $605);
       $608 = Math_fround($571 * $585);
       $609 = Math_fround($572 * $582);
       $610 = Math_fround($573 * $579);
       $611 = Math_fround($609 - $610);
       $612 = Math_fround($569 * $611);
       $613 = Math_fround($608 + $612);
       $614 = Math_fround($574 * $591);
       $615 = Math_fround($613 + $614);
       $616 = Math_fround($575 + $599);
       $617 = Math_fround($576 + $607);
       $618 = Math_fround($577 + $615);
       $619 = Math_fround($616 - $564);
       $620 = Math_fround($617 - $566);
       $621 = Math_fround($618 - $568);
       HEAPF32[$578>>2] = $619;
       HEAPF32[$581>>2] = $620;
       HEAPF32[$584>>2] = $621;
       $622 = (($i$024$i) + 1)|0;
       $exitcond26$i = ($622|0)==(8);
       if ($exitcond26$i) {
        break;
       }
       $$phi$trans$insert$i = (($boxVerts$i) + (($622*12)|0)|0);
       $$pre$i18 = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
       $$phi$trans$insert27$i = ((($boxVerts$i) + (($622*12)|0)|0) + 4|0);
       $$pre28$i = Math_fround(HEAPF32[$$phi$trans$insert27$i>>2]);
       $$phi$trans$insert29$i = ((($boxVerts$i) + (($622*12)|0)|0) + 8|0);
       $$pre30$i = Math_fround(HEAPF32[$$phi$trans$insert29$i>>2]);
       $580 = $$pre$i18;$583 = $$pre28$i;$586 = $$pre30$i;$i$024$i = $622;
      }
      $623 = HEAP32[$136>>2]|0;
      $624 = (($623) + 12)|0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($geomStream,$624);
      $625 = HEAP32[$geomStream>>2]|0;
      $626 = (($625) + ($623<<2)|0);
      HEAP32[$626>>2] = 2;
      $$sum$i20 = (($623) + 1)|0;
      $627 = (($625) + ($$sum$i20<<2)|0);
      $$c$i21 = $323;
      HEAP32[$627>>2] = $$c$i21;
      $$sum13$i = (($623) + 2)|0;
      $628 = (($625) + ($$sum13$i<<2)|0);
      $actor$c$i22 = $324;
      HEAP32[$628>>2] = $actor$c$i22;
      $$sum14$i = (($623) + 4)|0;
      $629 = (($625) + ($$sum14$i<<2)|0);
      ;HEAP32[$629+0>>2]=HEAP32[$Origin+0>>2]|0;HEAP32[$629+4>>2]=HEAP32[$Origin+4>>2]|0;HEAP32[$629+8>>2]=HEAP32[$Origin+8>>2]|0;HEAP32[$629+12>>2]=HEAP32[$Origin+12>>2]|0;HEAP32[$629+16>>2]=HEAP32[$Origin+16>>2]|0;HEAP32[$629+20>>2]=HEAP32[$Origin+20>>2]|0;
      $630 = HEAP32[$165>>2]|0;
      $$sum15$i = (($623) + 11)|0;
      $631 = (($625) + ($$sum15$i<<2)|0);
      HEAP32[$631>>2] = $630;
      $632 = HEAP8[$166>>0]|0;
      $633 = ($632<<24>>24)==(0);
      if (!($633)) {
       $634 = Math_fround(HEAPF32[$59>>2]);
       $635 = Math_fround(HEAPF32[$tmpBounds>>2]);
       $636 = Math_fround($634 - $635);
       $637 = Math_fround(HEAPF32[$60>>2]);
       $638 = Math_fround(HEAPF32[$57>>2]);
       $639 = Math_fround($637 - $638);
       $640 = Math_fround(HEAPF32[$61>>2]);
       $641 = Math_fround(HEAPF32[$58>>2]);
       $642 = Math_fround($640 - $641);
       $643 = Math_fround($636 * Math_fround(0.5));
       $644 = Math_fround($639 * Math_fround(0.5));
       $645 = Math_fround($642 * Math_fround(0.5));
       $646 = Math_fround($634 + $635);
       $647 = Math_fround($637 + $638);
       $648 = Math_fround($640 + $641);
       $649 = Math_fround($646 * Math_fround(0.5));
       $650 = Math_fround($647 * Math_fround(0.5));
       $651 = Math_fround($648 * Math_fround(0.5));
       $652 = Math_fround($649 - $564);
       $653 = Math_fround($650 - $566);
       $654 = Math_fround($651 - $568);
       $655 = Math_fround($652 - $643);
       $656 = Math_fround($653 - $644);
       $657 = Math_fround($654 - $645);
       $658 = Math_fround($643 + $652);
       $659 = Math_fround($644 + $653);
       $660 = Math_fround($645 + $654);
       $661 = Math_fround($655 + $658);
       $662 = Math_fround($656 + $659);
       $663 = Math_fround($657 + $660);
       $664 = Math_fround($661 * Math_fround(0.5));
       $665 = Math_fround($662 * Math_fround(0.5));
       $666 = Math_fround($663 * Math_fround(0.5));
       $667 = Math_fround($658 - $655);
       $668 = Math_fround($659 - $656);
       $669 = Math_fround($660 - $657);
       $670 = Math_fround($667 * Math_fround(0.5));
       $671 = Math_fround($668 * Math_fround(0.5));
       $672 = Math_fround($669 * Math_fround(0.5));
       $i1$022$i = 0;$nbCreatedTris$023$i = 0;
       while(1) {
        $673 = (404992 + (($i1$022$i*12)|0)|0);
        $674 = HEAP32[$673>>2]|0;
        $675 = ((404992 + (($i1$022$i*12)|0)|0) + 4|0);
        $676 = HEAP32[$675>>2]|0;
        $677 = ((404992 + (($i1$022$i*12)|0)|0) + 8|0);
        $678 = HEAP32[$677>>2]|0;
        $679 = (($boxVerts$i) + (($674*12)|0)|0);
        $680 = Math_fround(HEAPF32[$679>>2]);
        HEAPF32[$triGeom$i>>2] = $680;
        $681 = ((($boxVerts$i) + (($674*12)|0)|0) + 4|0);
        $682 = Math_fround(HEAPF32[$681>>2]);
        HEAPF32[$169>>2] = $682;
        $683 = ((($boxVerts$i) + (($674*12)|0)|0) + 8|0);
        $684 = Math_fround(HEAPF32[$683>>2]);
        HEAPF32[$170>>2] = $684;
        $685 = (($boxVerts$i) + (($676*12)|0)|0);
        $686 = Math_fround(HEAPF32[$685>>2]);
        HEAPF32[$171>>2] = $686;
        $687 = ((($boxVerts$i) + (($676*12)|0)|0) + 4|0);
        $688 = Math_fround(HEAPF32[$687>>2]);
        HEAPF32[$172>>2] = $688;
        $689 = ((($boxVerts$i) + (($676*12)|0)|0) + 8|0);
        $690 = Math_fround(HEAPF32[$689>>2]);
        HEAPF32[$173>>2] = $690;
        $691 = (($boxVerts$i) + (($678*12)|0)|0);
        $692 = Math_fround(HEAPF32[$691>>2]);
        HEAPF32[$174>>2] = $692;
        $693 = ((($boxVerts$i) + (($678*12)|0)|0) + 4|0);
        $694 = Math_fround(HEAPF32[$693>>2]);
        HEAPF32[$175>>2] = $694;
        $695 = ((($boxVerts$i) + (($678*12)|0)|0) + 8|0);
        $696 = Math_fround(HEAPF32[$695>>2]);
        HEAPF32[$176>>2] = $696;
        $params$idx$val$i24 = Math_fround(HEAPF32[$params$idx$i23>>2]);
        HEAP32[$tp$i4$i29>>2] = 0;
        HEAP32[$177>>2] = -1;
        HEAP32[$178>>2] = $worldTriangles;
        HEAP32[$179>>2] = $triIndicesArray;
        HEAPF32[$180>>2] = $664;
        HEAPF32[$181>>2] = $665;
        HEAPF32[$182>>2] = $666;
        HEAPF32[$183>>2] = $670;
        HEAPF32[$184>>2] = $671;
        HEAPF32[$185>>2] = $672;
        HEAPF32[$186>>2] = $params$idx$val$i24;
        HEAP16[$187>>1] = 0;
        __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp$i4$i29,$triGeom$i,$188,$189);
        $697 = HEAP32[$tp$i4$i29>>2]|0;
        $698 = HEAP16[$187>>1]|0;
        $699 = $698&65535;
        $700 = HEAP16[$nbTessellation>>1]|0;
        $701 = $700&65535;
        $702 = (($701) + ($699))|0;
        $703 = $702&65535;
        HEAP16[$nbTessellation>>1] = $703;
        $704 = (($697) + ($nbCreatedTris$023$i))|0;
        $705 = (($i1$022$i) + 1)|0;
        $exitcond25$i = ($705|0)==(12);
        if ($exitcond25$i) {
         break;
        } else {
         $i1$022$i = $705;$nbCreatedTris$023$i = $704;
        }
       }
       $$sum16$i = (($623) + 10)|0;
       $706 = (($625) + ($$sum16$i<<2)|0);
       HEAP32[$706>>2] = $704;
       break L26;
      }
      $$sum17$i = (($623) + 10)|0;
      $707 = (($625) + ($$sum17$i<<2)|0);
      HEAP32[$707>>2] = 12;
      $708 = HEAP32[$165>>2]|0;
      $709 = (($708) + 12)|0;
      __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($worldTriangles,$709);
      $710 = HEAP32[$worldTriangles>>2]|0;
      $i2$021$i = 0;
      while(1) {
       $$sum18$i = (($i2$021$i) + ($708))|0;
       $711 = (404992 + (($i2$021$i*12)|0)|0);
       $712 = HEAP32[$711>>2]|0;
       $713 = (($boxVerts$i) + (($712*12)|0)|0);
       $714 = Math_fround(HEAPF32[$713>>2]);
       $715 = (($710) + (($$sum18$i*36)|0)|0);
       HEAPF32[$715>>2] = $714;
       $716 = ((($boxVerts$i) + (($712*12)|0)|0) + 4|0);
       $717 = Math_fround(HEAPF32[$716>>2]);
       $718 = ((($710) + (($$sum18$i*36)|0)|0) + 4|0);
       HEAPF32[$718>>2] = $717;
       $719 = ((($boxVerts$i) + (($712*12)|0)|0) + 8|0);
       $720 = Math_fround(HEAPF32[$719>>2]);
       $721 = ((($710) + (($$sum18$i*36)|0)|0) + 8|0);
       HEAPF32[$721>>2] = $720;
       $722 = ((404992 + (($i2$021$i*12)|0)|0) + 4|0);
       $723 = HEAP32[$722>>2]|0;
       $724 = (($boxVerts$i) + (($723*12)|0)|0);
       $725 = Math_fround(HEAPF32[$724>>2]);
       $726 = ((($710) + (($$sum18$i*36)|0)|0) + 12|0);
       HEAPF32[$726>>2] = $725;
       $727 = ((($boxVerts$i) + (($723*12)|0)|0) + 4|0);
       $728 = Math_fround(HEAPF32[$727>>2]);
       $729 = ((($710) + (($$sum18$i*36)|0)|0) + 16|0);
       HEAPF32[$729>>2] = $728;
       $730 = ((($boxVerts$i) + (($723*12)|0)|0) + 8|0);
       $731 = Math_fround(HEAPF32[$730>>2]);
       $732 = ((($710) + (($$sum18$i*36)|0)|0) + 20|0);
       HEAPF32[$732>>2] = $731;
       $733 = ((404992 + (($i2$021$i*12)|0)|0) + 8|0);
       $734 = HEAP32[$733>>2]|0;
       $735 = (($boxVerts$i) + (($734*12)|0)|0);
       $736 = Math_fround(HEAPF32[$735>>2]);
       $737 = ((($710) + (($$sum18$i*36)|0)|0) + 24|0);
       HEAPF32[$737>>2] = $736;
       $738 = ((($boxVerts$i) + (($734*12)|0)|0) + 4|0);
       $739 = Math_fround(HEAPF32[$738>>2]);
       $740 = ((($710) + (($$sum18$i*36)|0)|0) + 28|0);
       HEAPF32[$740>>2] = $739;
       $741 = ((($boxVerts$i) + (($734*12)|0)|0) + 8|0);
       $742 = Math_fround(HEAPF32[$741>>2]);
       $743 = ((($710) + (($$sum18$i*36)|0)|0) + 32|0);
       HEAPF32[$743>>2] = $742;
       HEAP32[$0>>2] = -1;
       $744 = HEAP32[$167>>2]|0;
       $745 = $744 & 2147483647;
       $746 = HEAP32[$168>>2]|0;
       $747 = ($745>>>0)>($746>>>0);
       if ($747) {
        $748 = HEAP32[$triIndicesArray>>2]|0;
        $749 = (($748) + ($746<<2)|0);
        $750 = ($749|0)==(0|0);
        if ($750) {
         $752 = $746;
        } else {
         HEAP32[$749>>2] = -1;
         $$pre$i$i25 = HEAP32[$168>>2]|0;
         $752 = $$pre$i$i25;
        }
        $751 = (($752) + 1)|0;
        HEAP32[$168>>2] = $751;
       } else {
        (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$0)|0);
       }
       $753 = (($i2$021$i) + 1)|0;
       $exitcond$i26 = ($753|0)==(12);
       if ($exitcond$i26) {
        break;
       } else {
        $i2$021$i = $753;
       }
      }
      break;
     }
     case 5:  {
      HEAP32[$triGeom$i>>2] = 5;
      HEAPF32[$190>>2] = Math_fround(1.0);
      HEAPF32[$191>>2] = Math_fround(1.0);
      HEAPF32[$192>>2] = Math_fround(1.0);
      HEAPF32[$193>>2] = Math_fround(0.0);
      HEAPF32[$194>>2] = Math_fround(0.0);
      HEAPF32[$195>>2] = Math_fround(0.0);
      HEAPF32[$196>>2] = Math_fround(1.0);
      $754 = $197;
      $755 = $754;
      HEAP32[$755>>2] = 0;
      $756 = (($754) + 4)|0;
      $757 = $756;
      HEAP32[$757>>2] = 0;
      $758 = HEAP32[$323>>2]|0;
      $759 = (($758) + 56|0);
      $760 = HEAP32[$759>>2]|0;
      (FUNCTION_TABLE_iii[$760 & 4095]($323,$triGeom$i)|0);
      $761 = Math_fround(HEAPF32[$59>>2]);
      $762 = Math_fround(HEAPF32[$tmpBounds>>2]);
      $763 = Math_fround($761 - $762);
      $764 = Math_fround(HEAPF32[$60>>2]);
      $765 = Math_fround(HEAPF32[$57>>2]);
      $766 = Math_fround($764 - $765);
      $767 = Math_fround(HEAPF32[$61>>2]);
      $768 = Math_fround(HEAPF32[$58>>2]);
      $769 = Math_fround($767 - $768);
      $770 = Math_fround($763 * Math_fround(0.5));
      $771 = Math_fround($766 * Math_fround(0.5));
      $772 = Math_fround($769 * Math_fround(0.5));
      HEAP32[$boxGeom$i31>>2] = 3;
      HEAPF32[$198>>2] = $770;
      HEAPF32[$199>>2] = $771;
      HEAPF32[$200>>2] = $772;
      $773 = Math_fround($761 + $762);
      $774 = Math_fround($764 + $765);
      $775 = Math_fround($767 + $768);
      $776 = Math_fround($773 * Math_fround(0.5));
      $777 = Math_fround($774 * Math_fround(0.5));
      $778 = Math_fround($775 * Math_fround(0.5));
      HEAPF32[$boxPose$i32>>2] = Math_fround(0.0);
      HEAPF32[$201>>2] = Math_fround(0.0);
      HEAPF32[$202>>2] = Math_fround(0.0);
      HEAPF32[$203>>2] = Math_fround(1.0);
      HEAPF32[$204>>2] = $776;
      HEAPF32[$205>>2] = $777;
      HEAPF32[$206>>2] = $778;
      __ZN5physx17PxMeshOverlapUtilC2Ev($overlapUtil$i33);
      $779 = (__ZN5physx17PxMeshOverlapUtil11findOverlapERKNS_10PxGeometryERKNS_11PxTransformERKNS_22PxTriangleMeshGeometryES6_($overlapUtil$i33,$boxGeom$i31,$boxPose$i32,$triGeom$i,$globalPose)|0);
      $780 = +HEAPF64[$Origin>>3];
      $781 = Math_fround($780);
      $782 = Math_fround(-$781);
      $783 = +HEAPF64[$21>>3];
      $784 = Math_fround($783);
      $785 = Math_fround(-$784);
      $786 = +HEAPF64[$22>>3];
      $787 = Math_fround($786);
      $788 = Math_fround(-$787);
      $789 = HEAP32[$136>>2]|0;
      $790 = (($789) + 12)|0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($geomStream,$790);
      $791 = HEAP32[$geomStream>>2]|0;
      $792 = (($791) + ($789<<2)|0);
      HEAP32[$792>>2] = 2;
      $$sum$i39 = (($789) + 1)|0;
      $793 = (($791) + ($$sum$i39<<2)|0);
      $$c$i40 = $323;
      HEAP32[$793>>2] = $$c$i40;
      $$sum21$i41 = (($789) + 2)|0;
      $794 = (($791) + ($$sum21$i41<<2)|0);
      $actor$c$i42 = $324;
      HEAP32[$794>>2] = $actor$c$i42;
      $$sum22$i43 = (($789) + 4)|0;
      $795 = (($791) + ($$sum22$i43<<2)|0);
      ;HEAP32[$795+0>>2]=HEAP32[$Origin+0>>2]|0;HEAP32[$795+4>>2]=HEAP32[$Origin+4>>2]|0;HEAP32[$795+8>>2]=HEAP32[$Origin+8>>2]|0;HEAP32[$795+12>>2]=HEAP32[$Origin+12>>2]|0;HEAP32[$795+16>>2]=HEAP32[$Origin+16>>2]|0;HEAP32[$795+20>>2]=HEAP32[$Origin+20>>2]|0;
      $$sum23$i44 = (($789) + 10)|0;
      $796 = (($791) + ($$sum23$i44<<2)|0);
      HEAP32[$796>>2] = $779;
      $797 = HEAP32[$165>>2]|0;
      $$sum24$i45 = (($789) + 11)|0;
      $798 = (($791) + ($$sum24$i45<<2)|0);
      HEAP32[$798>>2] = $797;
      $799 = HEAP32[$overlapUtil$i33>>2]|0;
      $800 = Math_fround(HEAPF32[$207>>2]);
      $801 = $800 != Math_fround(0.0);
      $802 = HEAP8[$166>>0]|0;
      $803 = ($802<<24>>24)!=(0);
      do {
       if ($801) {
        if ($803) {
         $864 = Math_fround(HEAPF32[$204>>2]);
         $865 = Math_fround($864 - $781);
         $866 = Math_fround(HEAPF32[$205>>2]);
         $867 = Math_fround($866 - $784);
         $868 = Math_fround(HEAPF32[$206>>2]);
         $869 = Math_fround($868 - $787);
         $870 = Math_fround(HEAPF32[$198>>2]);
         $871 = Math_fround($865 - $870);
         $872 = Math_fround(HEAPF32[$199>>2]);
         $873 = Math_fround($867 - $872);
         $874 = Math_fround(HEAPF32[$200>>2]);
         $875 = Math_fround($869 - $874);
         $876 = Math_fround($865 + $870);
         $877 = Math_fround($867 + $872);
         $878 = Math_fround($869 + $874);
         $879 = ($779|0)==(0);
         if ($879) {
          $nbCreatedTris1$0$lcssa$i64 = 0;
         } else {
          $880 = Math_fround($871 + $876);
          $881 = Math_fround($873 + $877);
          $882 = Math_fround($875 + $878);
          $883 = Math_fround($880 * Math_fround(0.5));
          $884 = Math_fround($881 * Math_fround(0.5));
          $885 = Math_fround($882 * Math_fround(0.5));
          $886 = Math_fround($876 - $871);
          $887 = Math_fround($877 - $873);
          $888 = Math_fround($878 - $875);
          $889 = Math_fround($886 * Math_fround(0.5));
          $890 = Math_fround($887 * Math_fround(0.5));
          $891 = Math_fround($888 * Math_fround(0.5));
          $i2$025$i60 = 0;$nbCreatedTris1$026$i59 = 0;
          while(1) {
           $892 = (($799) + ($i2$025$i60<<2)|0);
           $893 = HEAP32[$892>>2]|0;
           __ZN5physx11PxMeshQuery11getTriangleERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom$i,$globalPose,$893,$currentTriangle4$i36,0,0);
           $894 = Math_fround(HEAPF32[$currentTriangle4$i36>>2]);
           $895 = Math_fround($894 - $781);
           HEAPF32[$currentTriangle4$i36>>2] = $895;
           $896 = Math_fround(HEAPF32[$208>>2]);
           $897 = Math_fround($896 - $784);
           HEAPF32[$208>>2] = $897;
           $898 = Math_fround(HEAPF32[$209>>2]);
           $899 = Math_fround($898 - $787);
           HEAPF32[$209>>2] = $899;
           $900 = Math_fround(HEAPF32[$210>>2]);
           $901 = Math_fround($900 - $781);
           HEAPF32[$210>>2] = $901;
           $902 = Math_fround(HEAPF32[$211>>2]);
           $903 = Math_fround($902 - $784);
           HEAPF32[$211>>2] = $903;
           $904 = Math_fround(HEAPF32[$212>>2]);
           $905 = Math_fround($904 - $787);
           HEAPF32[$212>>2] = $905;
           $906 = Math_fround(HEAPF32[$213>>2]);
           $907 = Math_fround($906 - $781);
           HEAPF32[$213>>2] = $907;
           $908 = Math_fround(HEAPF32[$214>>2]);
           $909 = Math_fround($908 - $784);
           HEAPF32[$214>>2] = $909;
           $910 = Math_fround(HEAPF32[$215>>2]);
           $911 = Math_fround($910 - $787);
           HEAPF32[$215>>2] = $911;
           $912 = (__ZL20createInvisibleWallsRKN5physx3Cct9CCTParamsERKNS_10PxTriangleERNS_6shdfnd5ArrayIS4_NS7_19ReflectionAllocatorIS4_EEEERNS8_IjNS9_IjEEEE($params,$currentTriangle4$i36,$worldTriangles,$triIndicesArray)|0);
           $913 = (($912) + ($nbCreatedTris1$026$i59))|0;
           $914 = ($912|0)==(0);
           if ($914) {
            $params$idx1$val$i61 = Math_fround(HEAPF32[$params$idx$i23>>2]);
            HEAP32[$tp$i4$i29>>2] = 0;
            HEAP32[$216>>2] = $893;
            HEAP32[$217>>2] = $worldTriangles;
            HEAP32[$218>>2] = $triIndicesArray;
            HEAPF32[$219>>2] = $883;
            HEAPF32[$220>>2] = $884;
            HEAPF32[$221>>2] = $885;
            HEAPF32[$222>>2] = $889;
            HEAPF32[$223>>2] = $890;
            HEAPF32[$224>>2] = $891;
            HEAPF32[$225>>2] = $params$idx1$val$i61;
            HEAP16[$226>>1] = 0;
            __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp$i4$i29,$currentTriangle4$i36,$210,$213);
            $915 = HEAP32[$tp$i4$i29>>2]|0;
            $916 = HEAP16[$226>>1]|0;
            $917 = $916&65535;
            $918 = HEAP16[$nbTessellation>>1]|0;
            $919 = $918&65535;
            $920 = (($919) + ($917))|0;
            $921 = $920&65535;
            HEAP16[$nbTessellation>>1] = $921;
            $922 = (($915) + ($913))|0;
            $nbCreatedTris1$1$i62 = $922;
           } else {
            $nbCreatedTris1$1$i62 = $913;
           }
           $923 = (($i2$025$i60) + 1)|0;
           $exitcond$i63 = ($923|0)==($779|0);
           if ($exitcond$i63) {
            $nbCreatedTris1$0$lcssa$i64 = $nbCreatedTris1$1$i62;
            break;
           } else {
            $i2$025$i60 = $923;$nbCreatedTris1$026$i59 = $nbCreatedTris1$1$i62;
           }
          }
         }
         HEAP32[$796>>2] = $nbCreatedTris1$0$lcssa$i64;
         $1027 = $nbCreatedTris1$0$lcssa$i64;
         break;
        }
        $804 = ($779|0)==(0);
        if ($804) {
         $nbCreatedTris$0$lcssa$i55 = 0;
        } else {
         $i$027$i49 = 0;$nbCreatedTris$028$i48 = 0;
         while(1) {
          $805 = (($799) + ($i$027$i49<<2)|0);
          $806 = HEAP32[$805>>2]|0;
          HEAP32[$triangleIndex$i34>>2] = $806;
          __ZN5physx11PxMeshQuery11getTriangleERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom$i,$globalPose,$806,$tp$i4$i29,0,0);
          $807 = Math_fround(HEAPF32[$tp$i4$i29>>2]);
          $808 = Math_fround($807 - $781);
          HEAPF32[$tp$i4$i29>>2] = $808;
          $809 = Math_fround(HEAPF32[$227>>2]);
          $810 = Math_fround($809 - $784);
          HEAPF32[$227>>2] = $810;
          $811 = Math_fround(HEAPF32[$228>>2]);
          $812 = Math_fround($811 - $787);
          HEAPF32[$228>>2] = $812;
          $813 = Math_fround(HEAPF32[$229>>2]);
          $814 = Math_fround($813 - $781);
          HEAPF32[$229>>2] = $814;
          $815 = Math_fround(HEAPF32[$230>>2]);
          $816 = Math_fround($815 - $784);
          HEAPF32[$230>>2] = $816;
          $817 = Math_fround(HEAPF32[$231>>2]);
          $818 = Math_fround($817 - $787);
          HEAPF32[$231>>2] = $818;
          $819 = Math_fround(HEAPF32[$232>>2]);
          $820 = Math_fround($819 - $781);
          HEAPF32[$232>>2] = $820;
          $821 = Math_fround(HEAPF32[$233>>2]);
          $822 = Math_fround($821 - $784);
          HEAPF32[$233>>2] = $822;
          $823 = Math_fround(HEAPF32[$234>>2]);
          $824 = Math_fround($823 - $787);
          HEAPF32[$234>>2] = $824;
          $825 = (__ZL20createInvisibleWallsRKN5physx3Cct9CCTParamsERKNS_10PxTriangleERNS_6shdfnd5ArrayIS4_NS7_19ReflectionAllocatorIS4_EEEERNS8_IjNS9_IjEEEE($params,$tp$i4$i29,$worldTriangles,$triIndicesArray)|0);
          $826 = (($825) + ($nbCreatedTris$028$i48))|0;
          $827 = ($825|0)==(0);
          if ($827) {
           $828 = HEAP32[$235>>2]|0;
           $829 = $828 & 2147483647;
           $830 = HEAP32[$165>>2]|0;
           $831 = ($829>>>0)>($830>>>0);
           if ($831) {
            $832 = HEAP32[$worldTriangles>>2]|0;
            $833 = (($832) + (($830*36)|0)|0);
            $834 = ($833|0)==(0|0);
            if (!($834)) {
             $835 = Math_fround(HEAPF32[$tp$i4$i29>>2]);
             HEAPF32[$833>>2] = $835;
             $836 = Math_fround(HEAPF32[$227>>2]);
             $837 = ((($832) + (($830*36)|0)|0) + 4|0);
             HEAPF32[$837>>2] = $836;
             $838 = Math_fround(HEAPF32[$228>>2]);
             $839 = ((($832) + (($830*36)|0)|0) + 8|0);
             HEAPF32[$839>>2] = $838;
             $840 = Math_fround(HEAPF32[$229>>2]);
             $841 = ((($832) + (($830*36)|0)|0) + 12|0);
             HEAPF32[$841>>2] = $840;
             $842 = Math_fround(HEAPF32[$230>>2]);
             $843 = ((($832) + (($830*36)|0)|0) + 16|0);
             HEAPF32[$843>>2] = $842;
             $844 = Math_fround(HEAPF32[$231>>2]);
             $845 = ((($832) + (($830*36)|0)|0) + 20|0);
             HEAPF32[$845>>2] = $844;
             $846 = Math_fround(HEAPF32[$232>>2]);
             $847 = ((($832) + (($830*36)|0)|0) + 24|0);
             HEAPF32[$847>>2] = $846;
             $848 = Math_fround(HEAPF32[$233>>2]);
             $849 = ((($832) + (($830*36)|0)|0) + 28|0);
             HEAPF32[$849>>2] = $848;
             $850 = Math_fround(HEAPF32[$234>>2]);
             $851 = ((($832) + (($830*36)|0)|0) + 32|0);
             HEAPF32[$851>>2] = $850;
            }
            $852 = (($830) + 1)|0;
            HEAP32[$165>>2] = $852;
           } else {
            (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($worldTriangles,$tp$i4$i29)|0);
           }
           $853 = HEAP32[$167>>2]|0;
           $854 = $853 & 2147483647;
           $855 = HEAP32[$168>>2]|0;
           $856 = ($854>>>0)>($855>>>0);
           if ($856) {
            $857 = HEAP32[$triIndicesArray>>2]|0;
            $858 = (($857) + ($855<<2)|0);
            $859 = ($858|0)==(0|0);
            if ($859) {
             $861 = $855;
            } else {
             HEAP32[$858>>2] = $806;
             $$pre$i5$i51 = HEAP32[$168>>2]|0;
             $861 = $$pre$i5$i51;
            }
            $860 = (($861) + 1)|0;
            HEAP32[$168>>2] = $860;
           } else {
            (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triangleIndex$i34)|0);
           }
           $862 = (($826) + 1)|0;
           $nbCreatedTris$1$i53 = $862;
          } else {
           $nbCreatedTris$1$i53 = $826;
          }
          $863 = (($i$027$i49) + 1)|0;
          $exitcond42$i54 = ($863|0)==($779|0);
          if ($exitcond42$i54) {
           $nbCreatedTris$0$lcssa$i55 = $nbCreatedTris$1$i53;
           break;
          } else {
           $i$027$i49 = $863;$nbCreatedTris$028$i48 = $nbCreatedTris$1$i53;
          }
         }
        }
        HEAP32[$796>>2] = $nbCreatedTris$0$lcssa$i55;
        $1027 = $nbCreatedTris$0$lcssa$i55;
       } else {
        if ($803) {
         $968 = Math_fround(HEAPF32[$204>>2]);
         $969 = Math_fround($968 - $781);
         $970 = Math_fround(HEAPF32[$205>>2]);
         $971 = Math_fround($970 - $784);
         $972 = Math_fround(HEAPF32[$206>>2]);
         $973 = Math_fround($972 - $787);
         $974 = Math_fround(HEAPF32[$198>>2]);
         $975 = Math_fround($969 - $974);
         $976 = Math_fround(HEAPF32[$199>>2]);
         $977 = Math_fround($971 - $976);
         $978 = Math_fround(HEAPF32[$200>>2]);
         $979 = Math_fround($973 - $978);
         $980 = Math_fround($969 + $974);
         $981 = Math_fround($971 + $976);
         $982 = Math_fround($973 + $978);
         $983 = ($779|0)==(0);
         if ($983) {
          $nbCreatedTris10$0$lcssa$i78 = 0;
         } else {
          $984 = Math_fround($975 + $980);
          $985 = Math_fround($977 + $981);
          $986 = Math_fround($979 + $982);
          $987 = Math_fround($984 * Math_fround(0.5));
          $988 = Math_fround($985 * Math_fround(0.5));
          $989 = Math_fround($986 * Math_fround(0.5));
          $990 = Math_fround($980 - $975);
          $991 = Math_fround($981 - $977);
          $992 = Math_fround($982 - $979);
          $993 = Math_fround($990 * Math_fround(0.5));
          $994 = Math_fround($991 * Math_fround(0.5));
          $995 = Math_fround($992 * Math_fround(0.5));
          $i11$033$i74 = 0;$nbCreatedTris10$032$i75 = 0;
          while(1) {
           $996 = (($799) + ($i11$033$i74<<2)|0);
           $997 = HEAP32[$996>>2]|0;
           __ZN5physx11PxMeshQuery11getTriangleERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom$i,$globalPose,$997,$currentTriangle4$i36,0,0);
           $998 = Math_fround(HEAPF32[$currentTriangle4$i36>>2]);
           $999 = Math_fround($998 - $781);
           HEAPF32[$currentTriangle4$i36>>2] = $999;
           $1000 = Math_fround(HEAPF32[$237>>2]);
           $1001 = Math_fround($1000 - $784);
           HEAPF32[$237>>2] = $1001;
           $1002 = Math_fround(HEAPF32[$238>>2]);
           $1003 = Math_fround($1002 - $787);
           HEAPF32[$238>>2] = $1003;
           $1004 = Math_fround(HEAPF32[$239>>2]);
           $1005 = Math_fround($1004 - $781);
           HEAPF32[$239>>2] = $1005;
           $1006 = Math_fround(HEAPF32[$240>>2]);
           $1007 = Math_fround($1006 - $784);
           HEAPF32[$240>>2] = $1007;
           $1008 = Math_fround(HEAPF32[$241>>2]);
           $1009 = Math_fround($1008 - $787);
           HEAPF32[$241>>2] = $1009;
           $1010 = Math_fround(HEAPF32[$242>>2]);
           $1011 = Math_fround($1010 - $781);
           HEAPF32[$242>>2] = $1011;
           $1012 = Math_fround(HEAPF32[$243>>2]);
           $1013 = Math_fround($1012 - $784);
           HEAPF32[$243>>2] = $1013;
           $1014 = Math_fround(HEAPF32[$244>>2]);
           $1015 = Math_fround($1014 - $787);
           HEAPF32[$244>>2] = $1015;
           $params$idx$val$i76 = Math_fround(HEAPF32[$params$idx$i23>>2]);
           HEAP32[$tp$i4$i29>>2] = 0;
           HEAP32[$245>>2] = $997;
           HEAP32[$246>>2] = $worldTriangles;
           HEAP32[$247>>2] = $triIndicesArray;
           HEAPF32[$248>>2] = $987;
           HEAPF32[$249>>2] = $988;
           HEAPF32[$250>>2] = $989;
           HEAPF32[$251>>2] = $993;
           HEAPF32[$252>>2] = $994;
           HEAPF32[$253>>2] = $995;
           HEAPF32[$254>>2] = $params$idx$val$i76;
           HEAP16[$255>>1] = 0;
           __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp$i4$i29,$currentTriangle4$i36,$239,$242);
           $1016 = HEAP32[$tp$i4$i29>>2]|0;
           $1017 = HEAP16[$255>>1]|0;
           $1018 = $1017&65535;
           $1019 = HEAP16[$nbTessellation>>1]|0;
           $1020 = $1019&65535;
           $1021 = (($1020) + ($1018))|0;
           $1022 = $1021&65535;
           HEAP16[$nbTessellation>>1] = $1022;
           $1023 = (($1016) + ($nbCreatedTris10$032$i75))|0;
           $1024 = (($i11$033$i74) + 1)|0;
           $exitcond43$i77 = ($1024|0)==($779|0);
           if ($exitcond43$i77) {
            $nbCreatedTris10$0$lcssa$i78 = $1023;
            break;
           } else {
            $i11$033$i74 = $1024;$nbCreatedTris10$032$i75 = $1023;
           }
          }
         }
         HEAP32[$796>>2] = $nbCreatedTris10$0$lcssa$i78;
         $1027 = $nbCreatedTris10$0$lcssa$i78;
         break;
        }
        $924 = HEAP32[$165>>2]|0;
        $925 = (($924) + ($779))|0;
        __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($worldTriangles,$925);
        $926 = ($779|0)==(0);
        if (!($926)) {
         $927 = HEAP32[$worldTriangles>>2]|0;
         $928 = (($927) + (($924*36)|0)|0);
         $TouchedTriangles$038$i68 = $928;$i6$039$i67 = 0;
         while(1) {
          $929 = (($799) + ($i6$039$i67<<2)|0);
          $930 = HEAP32[$929>>2]|0;
          HEAP32[$triangleIndex7$i37>>2] = $930;
          $931 = (($TouchedTriangles$038$i68) + 36|0);
          __ZN5physx11PxMeshQuery11getTriangleERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom$i,$globalPose,$930,$TouchedTriangles$038$i68,0,0);
          $932 = Math_fround(HEAPF32[$TouchedTriangles$038$i68>>2]);
          $933 = Math_fround($932 - $781);
          HEAPF32[$TouchedTriangles$038$i68>>2] = $933;
          $934 = (($TouchedTriangles$038$i68) + 4|0);
          $935 = Math_fround(HEAPF32[$934>>2]);
          $936 = Math_fround($935 - $784);
          HEAPF32[$934>>2] = $936;
          $937 = (($TouchedTriangles$038$i68) + 8|0);
          $938 = Math_fround(HEAPF32[$937>>2]);
          $939 = Math_fround($938 - $787);
          HEAPF32[$937>>2] = $939;
          $940 = (($TouchedTriangles$038$i68) + 12|0);
          $941 = Math_fround(HEAPF32[$940>>2]);
          $942 = Math_fround($941 - $781);
          HEAPF32[$940>>2] = $942;
          $943 = (($TouchedTriangles$038$i68) + 16|0);
          $944 = Math_fround(HEAPF32[$943>>2]);
          $945 = Math_fround($944 - $784);
          HEAPF32[$943>>2] = $945;
          $946 = (($TouchedTriangles$038$i68) + 20|0);
          $947 = Math_fround(HEAPF32[$946>>2]);
          $948 = Math_fround($947 - $787);
          HEAPF32[$946>>2] = $948;
          $949 = (($TouchedTriangles$038$i68) + 24|0);
          $950 = Math_fround(HEAPF32[$949>>2]);
          $951 = Math_fround($950 - $781);
          HEAPF32[$949>>2] = $951;
          $952 = (($TouchedTriangles$038$i68) + 28|0);
          $953 = Math_fround(HEAPF32[$952>>2]);
          $954 = Math_fround($953 - $784);
          HEAPF32[$952>>2] = $954;
          $955 = (($TouchedTriangles$038$i68) + 32|0);
          $956 = Math_fround(HEAPF32[$955>>2]);
          $957 = Math_fround($956 - $787);
          HEAPF32[$955>>2] = $957;
          $958 = HEAP32[$167>>2]|0;
          $959 = $958 & 2147483647;
          $960 = HEAP32[$168>>2]|0;
          $961 = ($959>>>0)>($960>>>0);
          if ($961) {
           $962 = HEAP32[$triIndicesArray>>2]|0;
           $963 = (($962) + ($960<<2)|0);
           $964 = ($963|0)==(0|0);
           if ($964) {
            $966 = $960;
           } else {
            HEAP32[$963>>2] = $930;
            $$pre$i$i69 = HEAP32[$168>>2]|0;
            $966 = $$pre$i$i69;
           }
           $965 = (($966) + 1)|0;
           HEAP32[$168>>2] = $965;
          } else {
           (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triangleIndex7$i37)|0);
          }
          $967 = (($i6$039$i67) + 1)|0;
          $exitcond44$i70 = ($967|0)==($779|0);
          if ($exitcond44$i70) {
           break;
          } else {
           $TouchedTriangles$038$i68 = $931;$i6$039$i67 = $967;
          }
         }
        }
        $$pre$i80 = HEAP32[$796>>2]|0;
        $1027 = $$pre$i80;
       }
      } while(0);
      $1025 = HEAP32[$798>>2]|0;
      $1026 = HEAP32[$worldTriangles>>2]|0;
      __ZL25visualizeTouchedTrianglesjjPKN5physx10PxTriangleEPNS_2Cm12RenderBufferERKNS_6PxVec3ES8_($1027,$1025,$1026,$6,$782,$785,$788,$236);
      __ZN5physx17PxMeshOverlapUtilD2Ev($overlapUtil$i33);
      break L26;
      break;
     }
     case 6:  {
      HEAP32[$triGeom$i>>2] = 6;
      HEAP32[$256>>2] = 0;
      HEAPF32[$257>>2] = Math_fround(1.0);
      HEAPF32[$258>>2] = Math_fround(1.0);
      HEAPF32[$259>>2] = Math_fround(1.0);
      HEAP32[$260>>2] = 0;
      $1028 = HEAP32[$323>>2]|0;
      $1029 = (($1028) + 60|0);
      $1030 = HEAP32[$1029>>2]|0;
      (FUNCTION_TABLE_iii[$1030 & 4095]($323,$triGeom$i)|0);
      $1031 = Math_fround(HEAPF32[$59>>2]);
      $1032 = Math_fround(HEAPF32[$tmpBounds>>2]);
      $1033 = Math_fround($1031 - $1032);
      $1034 = Math_fround(HEAPF32[$60>>2]);
      $1035 = Math_fround(HEAPF32[$57>>2]);
      $1036 = Math_fround($1034 - $1035);
      $1037 = Math_fround(HEAPF32[$61>>2]);
      $1038 = Math_fround(HEAPF32[$58>>2]);
      $1039 = Math_fround($1037 - $1038);
      $1040 = Math_fround($1033 * Math_fround(0.5));
      $1041 = Math_fround($1036 * Math_fround(0.5));
      $1042 = Math_fround($1039 * Math_fround(0.5));
      HEAP32[$boxGeom$i31>>2] = 3;
      HEAPF32[$261>>2] = $1040;
      HEAPF32[$262>>2] = $1041;
      HEAPF32[$263>>2] = $1042;
      $1043 = Math_fround($1031 + $1032);
      $1044 = Math_fround($1034 + $1035);
      $1045 = Math_fround($1037 + $1038);
      $1046 = Math_fround($1043 * Math_fround(0.5));
      $1047 = Math_fround($1044 * Math_fround(0.5));
      $1048 = Math_fround($1045 * Math_fround(0.5));
      HEAPF32[$boxPose$i32>>2] = Math_fround(0.0);
      HEAPF32[$264>>2] = Math_fround(0.0);
      HEAPF32[$265>>2] = Math_fround(0.0);
      HEAPF32[$266>>2] = Math_fround(1.0);
      HEAPF32[$267>>2] = $1046;
      HEAPF32[$268>>2] = $1047;
      HEAPF32[$269>>2] = $1048;
      __ZN5physx17PxMeshOverlapUtilC2Ev($overlapUtil$i33);
      $1049 = (__ZN5physx17PxMeshOverlapUtil11findOverlapERKNS_10PxGeometryERKNS_11PxTransformERKNS_21PxHeightFieldGeometryES6_($overlapUtil$i33,$boxGeom$i31,$boxPose$i32,$triGeom$i,$globalPose)|0);
      $1050 = +HEAPF64[$Origin>>3];
      $1051 = Math_fround($1050);
      $1052 = Math_fround(-$1051);
      $1053 = +HEAPF64[$21>>3];
      $1054 = Math_fround($1053);
      $1055 = Math_fround(-$1054);
      $1056 = +HEAPF64[$22>>3];
      $1057 = Math_fround($1056);
      $1058 = Math_fround(-$1057);
      $1059 = HEAP32[$136>>2]|0;
      $1060 = (($1059) + 12)|0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($geomStream,$1060);
      $1061 = HEAP32[$geomStream>>2]|0;
      $1062 = (($1061) + ($1059<<2)|0);
      HEAP32[$1062>>2] = 2;
      $$sum$i1 = (($1059) + 1)|0;
      $1063 = (($1061) + ($$sum$i1<<2)|0);
      $$c$i2 = $323;
      HEAP32[$1063>>2] = $$c$i2;
      $$sum21$i = (($1059) + 2)|0;
      $1064 = (($1061) + ($$sum21$i<<2)|0);
      $actor$c$i3 = $324;
      HEAP32[$1064>>2] = $actor$c$i3;
      $$sum22$i = (($1059) + 4)|0;
      $1065 = (($1061) + ($$sum22$i<<2)|0);
      ;HEAP32[$1065+0>>2]=HEAP32[$Origin+0>>2]|0;HEAP32[$1065+4>>2]=HEAP32[$Origin+4>>2]|0;HEAP32[$1065+8>>2]=HEAP32[$Origin+8>>2]|0;HEAP32[$1065+12>>2]=HEAP32[$Origin+12>>2]|0;HEAP32[$1065+16>>2]=HEAP32[$Origin+16>>2]|0;HEAP32[$1065+20>>2]=HEAP32[$Origin+20>>2]|0;
      $$sum23$i = (($1059) + 10)|0;
      $1066 = (($1061) + ($$sum23$i<<2)|0);
      HEAP32[$1066>>2] = $1049;
      $1067 = HEAP32[$165>>2]|0;
      $$sum24$i = (($1059) + 11)|0;
      $1068 = (($1061) + ($$sum24$i<<2)|0);
      HEAP32[$1068>>2] = $1067;
      $1069 = HEAP32[$overlapUtil$i33>>2]|0;
      $1070 = Math_fround(HEAPF32[$207>>2]);
      $1071 = $1070 != Math_fround(0.0);
      $1072 = HEAP8[$166>>0]|0;
      $1073 = ($1072<<24>>24)!=(0);
      do {
       if ($1071) {
        if ($1073) {
         $1134 = Math_fround(HEAPF32[$267>>2]);
         $1135 = Math_fround($1134 - $1051);
         $1136 = Math_fround(HEAPF32[$268>>2]);
         $1137 = Math_fround($1136 - $1054);
         $1138 = Math_fround(HEAPF32[$269>>2]);
         $1139 = Math_fround($1138 - $1057);
         $1140 = Math_fround(HEAPF32[$261>>2]);
         $1141 = Math_fround($1135 - $1140);
         $1142 = Math_fround(HEAPF32[$262>>2]);
         $1143 = Math_fround($1137 - $1142);
         $1144 = Math_fround(HEAPF32[$263>>2]);
         $1145 = Math_fround($1139 - $1144);
         $1146 = Math_fround($1135 + $1140);
         $1147 = Math_fround($1137 + $1142);
         $1148 = Math_fround($1139 + $1144);
         $1149 = ($1049|0)==(0);
         if ($1149) {
          $nbCreatedTris1$0$lcssa$i = 0;
         } else {
          $1150 = Math_fround($1141 + $1146);
          $1151 = Math_fround($1143 + $1147);
          $1152 = Math_fround($1145 + $1148);
          $1153 = Math_fround($1150 * Math_fround(0.5));
          $1154 = Math_fround($1151 * Math_fround(0.5));
          $1155 = Math_fround($1152 * Math_fround(0.5));
          $1156 = Math_fround($1146 - $1141);
          $1157 = Math_fround($1147 - $1143);
          $1158 = Math_fround($1148 - $1145);
          $1159 = Math_fround($1156 * Math_fround(0.5));
          $1160 = Math_fround($1157 * Math_fround(0.5));
          $1161 = Math_fround($1158 * Math_fround(0.5));
          $i2$025$i = 0;$nbCreatedTris1$026$i = 0;
          while(1) {
           $1162 = (($1069) + ($i2$025$i<<2)|0);
           $1163 = HEAP32[$1162>>2]|0;
           __ZN5physx11PxMeshQuery11getTriangleERKNS_21PxHeightFieldGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom$i,$globalPose,$1163,$currentTriangle4$i36,0,0);
           $1164 = Math_fround(HEAPF32[$currentTriangle4$i36>>2]);
           $1165 = Math_fround($1164 - $1051);
           HEAPF32[$currentTriangle4$i36>>2] = $1165;
           $1166 = Math_fround(HEAPF32[$270>>2]);
           $1167 = Math_fround($1166 - $1054);
           HEAPF32[$270>>2] = $1167;
           $1168 = Math_fround(HEAPF32[$271>>2]);
           $1169 = Math_fround($1168 - $1057);
           HEAPF32[$271>>2] = $1169;
           $1170 = Math_fround(HEAPF32[$272>>2]);
           $1171 = Math_fround($1170 - $1051);
           HEAPF32[$272>>2] = $1171;
           $1172 = Math_fround(HEAPF32[$273>>2]);
           $1173 = Math_fround($1172 - $1054);
           HEAPF32[$273>>2] = $1173;
           $1174 = Math_fround(HEAPF32[$274>>2]);
           $1175 = Math_fround($1174 - $1057);
           HEAPF32[$274>>2] = $1175;
           $1176 = Math_fround(HEAPF32[$275>>2]);
           $1177 = Math_fround($1176 - $1051);
           HEAPF32[$275>>2] = $1177;
           $1178 = Math_fround(HEAPF32[$276>>2]);
           $1179 = Math_fround($1178 - $1054);
           HEAPF32[$276>>2] = $1179;
           $1180 = Math_fround(HEAPF32[$277>>2]);
           $1181 = Math_fround($1180 - $1057);
           HEAPF32[$277>>2] = $1181;
           $1182 = (__ZL20createInvisibleWallsRKN5physx3Cct9CCTParamsERKNS_10PxTriangleERNS_6shdfnd5ArrayIS4_NS7_19ReflectionAllocatorIS4_EEEERNS8_IjNS9_IjEEEE($params,$currentTriangle4$i36,$worldTriangles,$triIndicesArray)|0);
           $1183 = (($1182) + ($nbCreatedTris1$026$i))|0;
           $1184 = ($1182|0)==(0);
           if ($1184) {
            $params$idx1$val$i = Math_fround(HEAPF32[$params$idx$i23>>2]);
            HEAP32[$tp$i4$i29>>2] = 0;
            HEAP32[$278>>2] = $1163;
            HEAP32[$279>>2] = $worldTriangles;
            HEAP32[$280>>2] = $triIndicesArray;
            HEAPF32[$281>>2] = $1153;
            HEAPF32[$282>>2] = $1154;
            HEAPF32[$283>>2] = $1155;
            HEAPF32[$284>>2] = $1159;
            HEAPF32[$285>>2] = $1160;
            HEAPF32[$286>>2] = $1161;
            HEAPF32[$287>>2] = $params$idx1$val$i;
            HEAP16[$288>>1] = 0;
            __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp$i4$i29,$currentTriangle4$i36,$272,$275);
            $1185 = HEAP32[$tp$i4$i29>>2]|0;
            $1186 = HEAP16[$288>>1]|0;
            $1187 = $1186&65535;
            $1188 = HEAP16[$nbTessellation>>1]|0;
            $1189 = $1188&65535;
            $1190 = (($1189) + ($1187))|0;
            $1191 = $1190&65535;
            HEAP16[$nbTessellation>>1] = $1191;
            $1192 = (($1185) + ($1183))|0;
            $nbCreatedTris1$1$i = $1192;
           } else {
            $nbCreatedTris1$1$i = $1183;
           }
           $1193 = (($i2$025$i) + 1)|0;
           $exitcond$i = ($1193|0)==($1049|0);
           if ($exitcond$i) {
            $nbCreatedTris1$0$lcssa$i = $nbCreatedTris1$1$i;
            break;
           } else {
            $i2$025$i = $1193;$nbCreatedTris1$026$i = $nbCreatedTris1$1$i;
           }
          }
         }
         HEAP32[$1066>>2] = $nbCreatedTris1$0$lcssa$i;
         $1297 = $nbCreatedTris1$0$lcssa$i;
         break;
        }
        $1074 = ($1049|0)==(0);
        if ($1074) {
         $nbCreatedTris$0$lcssa$i = 0;
        } else {
         $i$027$i = 0;$nbCreatedTris$028$i = 0;
         while(1) {
          $1075 = (($1069) + ($i$027$i<<2)|0);
          $1076 = HEAP32[$1075>>2]|0;
          HEAP32[$triangleIndex$i34>>2] = $1076;
          __ZN5physx11PxMeshQuery11getTriangleERKNS_21PxHeightFieldGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom$i,$globalPose,$1076,$tp$i4$i29,0,0);
          $1077 = Math_fround(HEAPF32[$tp$i4$i29>>2]);
          $1078 = Math_fround($1077 - $1051);
          HEAPF32[$tp$i4$i29>>2] = $1078;
          $1079 = Math_fround(HEAPF32[$289>>2]);
          $1080 = Math_fround($1079 - $1054);
          HEAPF32[$289>>2] = $1080;
          $1081 = Math_fround(HEAPF32[$290>>2]);
          $1082 = Math_fround($1081 - $1057);
          HEAPF32[$290>>2] = $1082;
          $1083 = Math_fround(HEAPF32[$291>>2]);
          $1084 = Math_fround($1083 - $1051);
          HEAPF32[$291>>2] = $1084;
          $1085 = Math_fround(HEAPF32[$292>>2]);
          $1086 = Math_fround($1085 - $1054);
          HEAPF32[$292>>2] = $1086;
          $1087 = Math_fround(HEAPF32[$293>>2]);
          $1088 = Math_fround($1087 - $1057);
          HEAPF32[$293>>2] = $1088;
          $1089 = Math_fround(HEAPF32[$294>>2]);
          $1090 = Math_fround($1089 - $1051);
          HEAPF32[$294>>2] = $1090;
          $1091 = Math_fround(HEAPF32[$295>>2]);
          $1092 = Math_fround($1091 - $1054);
          HEAPF32[$295>>2] = $1092;
          $1093 = Math_fround(HEAPF32[$296>>2]);
          $1094 = Math_fround($1093 - $1057);
          HEAPF32[$296>>2] = $1094;
          $1095 = (__ZL20createInvisibleWallsRKN5physx3Cct9CCTParamsERKNS_10PxTriangleERNS_6shdfnd5ArrayIS4_NS7_19ReflectionAllocatorIS4_EEEERNS8_IjNS9_IjEEEE($params,$tp$i4$i29,$worldTriangles,$triIndicesArray)|0);
          $1096 = (($1095) + ($nbCreatedTris$028$i))|0;
          $1097 = ($1095|0)==(0);
          if ($1097) {
           $1098 = HEAP32[$235>>2]|0;
           $1099 = $1098 & 2147483647;
           $1100 = HEAP32[$165>>2]|0;
           $1101 = ($1099>>>0)>($1100>>>0);
           if ($1101) {
            $1102 = HEAP32[$worldTriangles>>2]|0;
            $1103 = (($1102) + (($1100*36)|0)|0);
            $1104 = ($1103|0)==(0|0);
            if (!($1104)) {
             $1105 = Math_fround(HEAPF32[$tp$i4$i29>>2]);
             HEAPF32[$1103>>2] = $1105;
             $1106 = Math_fround(HEAPF32[$289>>2]);
             $1107 = ((($1102) + (($1100*36)|0)|0) + 4|0);
             HEAPF32[$1107>>2] = $1106;
             $1108 = Math_fround(HEAPF32[$290>>2]);
             $1109 = ((($1102) + (($1100*36)|0)|0) + 8|0);
             HEAPF32[$1109>>2] = $1108;
             $1110 = Math_fround(HEAPF32[$291>>2]);
             $1111 = ((($1102) + (($1100*36)|0)|0) + 12|0);
             HEAPF32[$1111>>2] = $1110;
             $1112 = Math_fround(HEAPF32[$292>>2]);
             $1113 = ((($1102) + (($1100*36)|0)|0) + 16|0);
             HEAPF32[$1113>>2] = $1112;
             $1114 = Math_fround(HEAPF32[$293>>2]);
             $1115 = ((($1102) + (($1100*36)|0)|0) + 20|0);
             HEAPF32[$1115>>2] = $1114;
             $1116 = Math_fround(HEAPF32[$294>>2]);
             $1117 = ((($1102) + (($1100*36)|0)|0) + 24|0);
             HEAPF32[$1117>>2] = $1116;
             $1118 = Math_fround(HEAPF32[$295>>2]);
             $1119 = ((($1102) + (($1100*36)|0)|0) + 28|0);
             HEAPF32[$1119>>2] = $1118;
             $1120 = Math_fround(HEAPF32[$296>>2]);
             $1121 = ((($1102) + (($1100*36)|0)|0) + 32|0);
             HEAPF32[$1121>>2] = $1120;
            }
            $1122 = (($1100) + 1)|0;
            HEAP32[$165>>2] = $1122;
           } else {
            (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($worldTriangles,$tp$i4$i29)|0);
           }
           $1123 = HEAP32[$167>>2]|0;
           $1124 = $1123 & 2147483647;
           $1125 = HEAP32[$168>>2]|0;
           $1126 = ($1124>>>0)>($1125>>>0);
           if ($1126) {
            $1127 = HEAP32[$triIndicesArray>>2]|0;
            $1128 = (($1127) + ($1125<<2)|0);
            $1129 = ($1128|0)==(0|0);
            if ($1129) {
             $1131 = $1125;
            } else {
             HEAP32[$1128>>2] = $1076;
             $$pre$i5$i = HEAP32[$168>>2]|0;
             $1131 = $$pre$i5$i;
            }
            $1130 = (($1131) + 1)|0;
            HEAP32[$168>>2] = $1130;
           } else {
            (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triangleIndex$i34)|0);
           }
           $1132 = (($1096) + 1)|0;
           $nbCreatedTris$1$i = $1132;
          } else {
           $nbCreatedTris$1$i = $1096;
          }
          $1133 = (($i$027$i) + 1)|0;
          $exitcond42$i = ($1133|0)==($1049|0);
          if ($exitcond42$i) {
           $nbCreatedTris$0$lcssa$i = $nbCreatedTris$1$i;
           break;
          } else {
           $i$027$i = $1133;$nbCreatedTris$028$i = $nbCreatedTris$1$i;
          }
         }
        }
        HEAP32[$1066>>2] = $nbCreatedTris$0$lcssa$i;
        $1297 = $nbCreatedTris$0$lcssa$i;
       } else {
        if ($1073) {
         $1238 = Math_fround(HEAPF32[$267>>2]);
         $1239 = Math_fround($1238 - $1051);
         $1240 = Math_fround(HEAPF32[$268>>2]);
         $1241 = Math_fround($1240 - $1054);
         $1242 = Math_fround(HEAPF32[$269>>2]);
         $1243 = Math_fround($1242 - $1057);
         $1244 = Math_fround(HEAPF32[$261>>2]);
         $1245 = Math_fround($1239 - $1244);
         $1246 = Math_fround(HEAPF32[$262>>2]);
         $1247 = Math_fround($1241 - $1246);
         $1248 = Math_fround(HEAPF32[$263>>2]);
         $1249 = Math_fround($1243 - $1248);
         $1250 = Math_fround($1239 + $1244);
         $1251 = Math_fround($1241 + $1246);
         $1252 = Math_fround($1243 + $1248);
         $1253 = ($1049|0)==(0);
         if ($1253) {
          $nbCreatedTris10$0$lcssa$i = 0;
         } else {
          $1254 = Math_fround($1245 + $1250);
          $1255 = Math_fround($1247 + $1251);
          $1256 = Math_fround($1249 + $1252);
          $1257 = Math_fround($1254 * Math_fround(0.5));
          $1258 = Math_fround($1255 * Math_fround(0.5));
          $1259 = Math_fround($1256 * Math_fround(0.5));
          $1260 = Math_fround($1250 - $1245);
          $1261 = Math_fround($1251 - $1247);
          $1262 = Math_fround($1252 - $1249);
          $1263 = Math_fround($1260 * Math_fround(0.5));
          $1264 = Math_fround($1261 * Math_fround(0.5));
          $1265 = Math_fround($1262 * Math_fround(0.5));
          $i11$033$i = 0;$nbCreatedTris10$032$i = 0;
          while(1) {
           $1266 = (($1069) + ($i11$033$i<<2)|0);
           $1267 = HEAP32[$1266>>2]|0;
           __ZN5physx11PxMeshQuery11getTriangleERKNS_21PxHeightFieldGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom$i,$globalPose,$1267,$currentTriangle4$i36,0,0);
           $1268 = Math_fround(HEAPF32[$currentTriangle4$i36>>2]);
           $1269 = Math_fround($1268 - $1051);
           HEAPF32[$currentTriangle4$i36>>2] = $1269;
           $1270 = Math_fround(HEAPF32[$297>>2]);
           $1271 = Math_fround($1270 - $1054);
           HEAPF32[$297>>2] = $1271;
           $1272 = Math_fround(HEAPF32[$298>>2]);
           $1273 = Math_fround($1272 - $1057);
           HEAPF32[$298>>2] = $1273;
           $1274 = Math_fround(HEAPF32[$299>>2]);
           $1275 = Math_fround($1274 - $1051);
           HEAPF32[$299>>2] = $1275;
           $1276 = Math_fround(HEAPF32[$300>>2]);
           $1277 = Math_fround($1276 - $1054);
           HEAPF32[$300>>2] = $1277;
           $1278 = Math_fround(HEAPF32[$301>>2]);
           $1279 = Math_fround($1278 - $1057);
           HEAPF32[$301>>2] = $1279;
           $1280 = Math_fround(HEAPF32[$302>>2]);
           $1281 = Math_fround($1280 - $1051);
           HEAPF32[$302>>2] = $1281;
           $1282 = Math_fround(HEAPF32[$303>>2]);
           $1283 = Math_fround($1282 - $1054);
           HEAPF32[$303>>2] = $1283;
           $1284 = Math_fround(HEAPF32[$304>>2]);
           $1285 = Math_fround($1284 - $1057);
           HEAPF32[$304>>2] = $1285;
           $params$idx$val$i = Math_fround(HEAPF32[$params$idx$i23>>2]);
           HEAP32[$tp$i4$i29>>2] = 0;
           HEAP32[$305>>2] = $1267;
           HEAP32[$306>>2] = $worldTriangles;
           HEAP32[$307>>2] = $triIndicesArray;
           HEAPF32[$308>>2] = $1257;
           HEAPF32[$309>>2] = $1258;
           HEAPF32[$310>>2] = $1259;
           HEAPF32[$311>>2] = $1263;
           HEAPF32[$312>>2] = $1264;
           HEAPF32[$313>>2] = $1265;
           HEAPF32[$314>>2] = $params$idx$val$i;
           HEAP16[$315>>1] = 0;
           __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp$i4$i29,$currentTriangle4$i36,$299,$302);
           $1286 = HEAP32[$tp$i4$i29>>2]|0;
           $1287 = HEAP16[$315>>1]|0;
           $1288 = $1287&65535;
           $1289 = HEAP16[$nbTessellation>>1]|0;
           $1290 = $1289&65535;
           $1291 = (($1290) + ($1288))|0;
           $1292 = $1291&65535;
           HEAP16[$nbTessellation>>1] = $1292;
           $1293 = (($1286) + ($nbCreatedTris10$032$i))|0;
           $1294 = (($i11$033$i) + 1)|0;
           $exitcond43$i = ($1294|0)==($1049|0);
           if ($exitcond43$i) {
            $nbCreatedTris10$0$lcssa$i = $1293;
            break;
           } else {
            $i11$033$i = $1294;$nbCreatedTris10$032$i = $1293;
           }
          }
         }
         HEAP32[$1066>>2] = $nbCreatedTris10$0$lcssa$i;
         $1297 = $nbCreatedTris10$0$lcssa$i;
         break;
        }
        $1194 = HEAP32[$165>>2]|0;
        $1195 = (($1194) + ($1049))|0;
        __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($worldTriangles,$1195);
        $1196 = ($1049|0)==(0);
        if (!($1196)) {
         $1197 = HEAP32[$worldTriangles>>2]|0;
         $1198 = (($1197) + (($1194*36)|0)|0);
         $TouchedTriangles$038$i = $1198;$i6$039$i = 0;
         while(1) {
          $1199 = (($1069) + ($i6$039$i<<2)|0);
          $1200 = HEAP32[$1199>>2]|0;
          HEAP32[$triangleIndex7$i37>>2] = $1200;
          $1201 = (($TouchedTriangles$038$i) + 36|0);
          __ZN5physx11PxMeshQuery11getTriangleERKNS_21PxHeightFieldGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom$i,$globalPose,$1200,$TouchedTriangles$038$i,0,0);
          $1202 = Math_fround(HEAPF32[$TouchedTriangles$038$i>>2]);
          $1203 = Math_fround($1202 - $1051);
          HEAPF32[$TouchedTriangles$038$i>>2] = $1203;
          $1204 = (($TouchedTriangles$038$i) + 4|0);
          $1205 = Math_fround(HEAPF32[$1204>>2]);
          $1206 = Math_fround($1205 - $1054);
          HEAPF32[$1204>>2] = $1206;
          $1207 = (($TouchedTriangles$038$i) + 8|0);
          $1208 = Math_fround(HEAPF32[$1207>>2]);
          $1209 = Math_fround($1208 - $1057);
          HEAPF32[$1207>>2] = $1209;
          $1210 = (($TouchedTriangles$038$i) + 12|0);
          $1211 = Math_fround(HEAPF32[$1210>>2]);
          $1212 = Math_fround($1211 - $1051);
          HEAPF32[$1210>>2] = $1212;
          $1213 = (($TouchedTriangles$038$i) + 16|0);
          $1214 = Math_fround(HEAPF32[$1213>>2]);
          $1215 = Math_fround($1214 - $1054);
          HEAPF32[$1213>>2] = $1215;
          $1216 = (($TouchedTriangles$038$i) + 20|0);
          $1217 = Math_fround(HEAPF32[$1216>>2]);
          $1218 = Math_fround($1217 - $1057);
          HEAPF32[$1216>>2] = $1218;
          $1219 = (($TouchedTriangles$038$i) + 24|0);
          $1220 = Math_fround(HEAPF32[$1219>>2]);
          $1221 = Math_fround($1220 - $1051);
          HEAPF32[$1219>>2] = $1221;
          $1222 = (($TouchedTriangles$038$i) + 28|0);
          $1223 = Math_fround(HEAPF32[$1222>>2]);
          $1224 = Math_fround($1223 - $1054);
          HEAPF32[$1222>>2] = $1224;
          $1225 = (($TouchedTriangles$038$i) + 32|0);
          $1226 = Math_fround(HEAPF32[$1225>>2]);
          $1227 = Math_fround($1226 - $1057);
          HEAPF32[$1225>>2] = $1227;
          $1228 = HEAP32[$167>>2]|0;
          $1229 = $1228 & 2147483647;
          $1230 = HEAP32[$168>>2]|0;
          $1231 = ($1229>>>0)>($1230>>>0);
          if ($1231) {
           $1232 = HEAP32[$triIndicesArray>>2]|0;
           $1233 = (($1232) + ($1230<<2)|0);
           $1234 = ($1233|0)==(0|0);
           if ($1234) {
            $1236 = $1230;
           } else {
            HEAP32[$1233>>2] = $1200;
            $$pre$i$i4 = HEAP32[$168>>2]|0;
            $1236 = $$pre$i$i4;
           }
           $1235 = (($1236) + 1)|0;
           HEAP32[$168>>2] = $1235;
          } else {
           (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triangleIndex7$i37)|0);
          }
          $1237 = (($i6$039$i) + 1)|0;
          $exitcond44$i = ($1237|0)==($1049|0);
          if ($exitcond44$i) {
           break;
          } else {
           $TouchedTriangles$038$i = $1201;$i6$039$i = $1237;
          }
         }
        }
        $$pre$i5 = HEAP32[$1066>>2]|0;
        $1297 = $$pre$i5;
       }
      } while(0);
      $1295 = HEAP32[$1068>>2]|0;
      $1296 = HEAP32[$worldTriangles>>2]|0;
      __ZL25visualizeTouchedTrianglesjjPKN5physx10PxTriangleEPNS_2Cm12RenderBufferERKNS_6PxVec3ES8_($1297,$1295,$1296,$6,$1052,$1055,$1058,$236);
      __ZN5physx17PxMeshOverlapUtilD2Ev($overlapUtil$i33);
      break L26;
      break;
     }
     case 4:  {
      __ZL20outputConvexToStreamPN5physx7PxShapeEPKNS_12PxRigidActorERKNS_11PxTransformERNS_6shdfnd5ArrayIjNS8_19ReflectionAllocatorIjEEEERNS9_INS_10PxTriangleENSA_ISE_EEEESD_RKNS_14PxExtendedVec3ERKNS_9PxBounds3ERKNS_3Cct9CCTParamsEPNS_2Cm12RenderBufferERt($323,$324,$globalPose,$geomStream,$worldTriangles,$triIndicesArray,$Origin,$tmpBounds,$params,$6,$nbTessellation);
      break L26;
      break;
     }
     case 1:  {
      $1298 = Math_fround(HEAPF32[$59>>2]);
      $1299 = Math_fround(HEAPF32[$tmpBounds>>2]);
      $1300 = Math_fround($1298 - $1299);
      $1301 = Math_fround(HEAPF32[$60>>2]);
      $1302 = Math_fround(HEAPF32[$57>>2]);
      $1303 = Math_fround($1301 - $1302);
      $1304 = Math_fround(HEAPF32[$61>>2]);
      $1305 = Math_fround(HEAPF32[$58>>2]);
      $1306 = Math_fround($1304 - $1305);
      $1307 = Math_fround($1300 * $1300);
      $1308 = Math_fround($1303 * $1303);
      $1309 = Math_fround($1307 + $1308);
      $1310 = Math_fround($1306 * $1306);
      $1311 = Math_fround($1309 + $1310);
      $1312 = (Math_fround(Math_sqrt((Math_fround($1311)))));
      $1313 = +HEAPF64[$Origin>>3];
      $1314 = Math_fround($1313);
      $1315 = +HEAPF64[$21>>3];
      $1316 = Math_fround($1315);
      $1317 = +HEAPF64[$22>>3];
      $1318 = Math_fround($1317);
      $1319 = Math_fround(HEAPF32[$131>>2]);
      $1320 = Math_fround($1319 * $1319);
      $1321 = Math_fround($1320 + Math_fround(-0.5));
      $1322 = Math_fround(HEAPF32[$globalPose>>2]);
      $1323 = Math_fround($1322 * Math_fround(2.0));
      $1324 = Math_fround(HEAPF32[$129>>2]);
      $1325 = Math_fround($1324 * Math_fround(0.0));
      $1326 = Math_fround($1323 + $1325);
      $1327 = Math_fround(HEAPF32[$130>>2]);
      $1328 = Math_fround($1327 * Math_fround(0.0));
      $1329 = Math_fround($1326 + $1328);
      $1330 = Math_fround($1321 * Math_fround(2.0));
      $1331 = Math_fround($1325 - $1328);
      $1332 = Math_fround($1319 * $1331);
      $1333 = Math_fround($1330 + $1332);
      $1334 = Math_fround($1322 * $1329);
      $1335 = Math_fround($1334 + $1333);
      $1336 = Math_fround($1321 * Math_fround(0.0));
      $1337 = Math_fround($1327 * Math_fround(2.0));
      $1338 = Math_fround($1322 * Math_fround(0.0));
      $1339 = Math_fround($1337 - $1338);
      $1340 = Math_fround($1319 * $1339);
      $1341 = Math_fround($1336 + $1340);
      $1342 = Math_fround($1324 * $1329);
      $1343 = Math_fround($1342 + $1341);
      $1344 = Math_fround($1324 * Math_fround(2.0));
      $1345 = Math_fround($1338 - $1344);
      $1346 = Math_fround($1319 * $1345);
      $1347 = Math_fround($1336 + $1346);
      $1348 = Math_fround($1327 * $1329);
      $1349 = Math_fround($1347 + $1348);
      $1350 = Math_fround(HEAPF32[$132>>2]);
      $1351 = Math_fround($1350 * $1335);
      $1352 = Math_fround(HEAPF32[$133>>2]);
      $1353 = Math_fround($1352 * $1343);
      $1354 = Math_fround($1351 + $1353);
      $1355 = Math_fround(HEAPF32[$134>>2]);
      $1356 = Math_fround($1355 * $1349);
      $1357 = Math_fround($1356 + $1354);
      $1358 = Math_fround(Math_fround(0.0) - $1357);
      $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($1343)))));
      $1359 = $fabsf$i$i$i$i > Math_fround(0.999899983406066894531);
      if ($1359) {
       $1378 = Math_fround(0.0);$1380 = Math_fround(0.0);$1383 = Math_fround(1.0);
      } else {
       $1360 = Math_fround($1343 * Math_fround(0.0));
       $1361 = Math_fround($1349 - $1360);
       $1362 = Math_fround($1335 * Math_fround(0.0));
       $1363 = Math_fround($1349 * Math_fround(0.0));
       $1364 = Math_fround($1362 - $1363);
       $1365 = Math_fround($1360 - $1335);
       $1366 = Math_fround($1361 * $1361);
       $1367 = Math_fround($1364 * $1364);
       $1368 = Math_fround($1366 + $1367);
       $1369 = Math_fround($1365 * $1365);
       $1370 = Math_fround($1369 + $1368);
       $1371 = (Math_fround(Math_sqrt((Math_fround($1370)))));
       $1372 = $1371 > Math_fround(0.0);
       if ($1372) {
        $1373 = Math_fround(Math_fround(1.0) / $1371);
        $1374 = Math_fround($1361 * $1373);
        $1375 = Math_fround($1364 * $1373);
        $1376 = Math_fround($1365 * $1373);
        $1378 = $1376;$1380 = $1375;$1383 = $1374;
       } else {
        $1378 = $1365;$1380 = $1364;$1383 = $1361;
       }
      }
      $1377 = Math_fround($1343 * $1378);
      $1379 = Math_fround($1349 * $1380);
      $1381 = Math_fround($1377 - $1379);
      $1382 = Math_fround($1349 * $1383);
      $1384 = Math_fround($1335 * $1378);
      $1385 = Math_fround($1382 - $1384);
      $1386 = Math_fround($1335 * $1380);
      $1387 = Math_fround($1343 * $1383);
      $1388 = Math_fround($1386 - $1387);
      $1389 = Math_fround($1312 * $1383);
      $1390 = Math_fround($1312 * $1380);
      $1391 = Math_fround($1312 * $1378);
      $1392 = Math_fround($1312 * $1381);
      $1393 = Math_fround($1312 * $1385);
      $1394 = Math_fround($1312 * $1388);
      $1395 = Math_fround($1314 * $1335);
      $1396 = Math_fround($1316 * $1343);
      $1397 = Math_fround($1395 + $1396);
      $1398 = Math_fround($1318 * $1349);
      $1399 = Math_fround($1398 + $1397);
      $1400 = Math_fround($1399 + $1358);
      $1401 = Math_fround($1335 * $1400);
      $1402 = Math_fround($1343 * $1400);
      $1403 = Math_fround($1349 * $1400);
      $1404 = Math_fround($1314 - $1401);
      $1405 = Math_fround($1316 - $1402);
      $1406 = Math_fround($1318 - $1403);
      $1407 = Math_fround($1404 - $1389);
      $1408 = Math_fround($1405 - $1390);
      $1409 = Math_fround($1406 - $1391);
      $1410 = Math_fround($1407 + $1392);
      $1411 = Math_fround($1408 + $1393);
      $1412 = Math_fround($1409 + $1394);
      $1413 = Math_fround($1407 - $1392);
      $1414 = Math_fround($1408 - $1393);
      $1415 = Math_fround($1409 - $1394);
      $1416 = Math_fround($1404 + $1389);
      $1417 = Math_fround($1405 + $1390);
      $1418 = Math_fround($1406 + $1391);
      $1419 = Math_fround($1416 - $1392);
      $1420 = Math_fround($1417 - $1393);
      $1421 = Math_fround($1418 - $1394);
      $1422 = Math_fround($1416 + $1392);
      $1423 = Math_fround($1417 + $1393);
      $1424 = Math_fround($1418 + $1394);
      $1425 = Math_fround(-$1314);
      $1426 = Math_fround(-$1316);
      $1427 = Math_fround(-$1318);
      $1428 = HEAP32[$136>>2]|0;
      $1429 = (($1428) + 12)|0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($geomStream,$1429);
      $1430 = HEAP32[$geomStream>>2]|0;
      $1431 = (($1430) + ($1428<<2)|0);
      HEAP32[$1431>>2] = 2;
      $$sum$i = (($1428) + 1)|0;
      $1432 = (($1430) + ($$sum$i<<2)|0);
      $$c$i = $323;
      HEAP32[$1432>>2] = $$c$i;
      $$sum37$i = (($1428) + 2)|0;
      $1433 = (($1430) + ($$sum37$i<<2)|0);
      $actor$c$i = $324;
      HEAP32[$1433>>2] = $actor$c$i;
      $$sum38$i = (($1428) + 4)|0;
      $1434 = (($1430) + ($$sum38$i<<2)|0);
      ;HEAP32[$1434+0>>2]=HEAP32[$Origin+0>>2]|0;HEAP32[$1434+4>>2]=HEAP32[$Origin+4>>2]|0;HEAP32[$1434+8>>2]=HEAP32[$Origin+8>>2]|0;HEAP32[$1434+12>>2]=HEAP32[$Origin+12>>2]|0;HEAP32[$1434+16>>2]=HEAP32[$Origin+16>>2]|0;HEAP32[$1434+20>>2]=HEAP32[$Origin+20>>2]|0;
      $$sum39$i = (($1428) + 10)|0;
      $1435 = (($1430) + ($$sum39$i<<2)|0);
      HEAP32[$1435>>2] = 2;
      $1436 = HEAP32[$165>>2]|0;
      $$sum40$i = (($1428) + 11)|0;
      $1437 = (($1430) + ($$sum40$i<<2)|0);
      HEAP32[$1437>>2] = $1436;
      $1438 = HEAP32[$165>>2]|0;
      $1439 = (($1438) + 2)|0;
      __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($worldTriangles,$1439);
      $1440 = HEAP32[$worldTriangles>>2]|0;
      HEAP32[$tp$i4$i29>>2] = 0;
      $1441 = HEAP32[$167>>2]|0;
      $1442 = $1441 & 2147483647;
      $1443 = HEAP32[$168>>2]|0;
      $1444 = ($1442>>>0)>($1443>>>0);
      if ($1444) {
       $1445 = HEAP32[$triIndicesArray>>2]|0;
       $1446 = (($1445) + ($1443<<2)|0);
       $1447 = ($1446|0)==(0|0);
       if ($1447) {
        $1449 = $1443;
       } else {
        HEAP32[$1446>>2] = 0;
        $$pre$i3$i = HEAP32[$168>>2]|0;
        $1449 = $$pre$i3$i;
       }
       $1448 = (($1449) + 1)|0;
       HEAP32[$168>>2] = $1448;
       $1453 = $1448;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$tp$i4$i29)|0);
       $$pre$i = HEAP32[$168>>2]|0;
       $1453 = $$pre$i;
      }
      HEAP32[$triGeom$i>>2] = 1;
      $1450 = HEAP32[$167>>2]|0;
      $1451 = $1450 & 2147483647;
      $1452 = ($1451>>>0)>($1453>>>0);
      if ($1452) {
       $1454 = HEAP32[$triIndicesArray>>2]|0;
       $1455 = (($1454) + ($1453<<2)|0);
       $1456 = ($1455|0)==(0|0);
       if ($1456) {
        $1458 = $1453;
       } else {
        HEAP32[$1455>>2] = 1;
        $$pre$i$i = HEAP32[$168>>2]|0;
        $1458 = $$pre$i$i;
       }
       $1457 = (($1458) + 1)|0;
       HEAP32[$168>>2] = $1457;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triGeom$i)|0);
      }
      $1459 = Math_fround($1410 - $1314);
      $1460 = Math_fround($1411 - $1316);
      $1461 = Math_fround($1412 - $1318);
      $1462 = (($1440) + (($1438*36)|0)|0);
      HEAPF32[$1462>>2] = $1459;
      $1463 = ((($1440) + (($1438*36)|0)|0) + 4|0);
      HEAPF32[$1463>>2] = $1460;
      $1464 = ((($1440) + (($1438*36)|0)|0) + 8|0);
      HEAPF32[$1464>>2] = $1461;
      $1465 = Math_fround($1413 - $1314);
      $1466 = Math_fround($1414 - $1316);
      $1467 = Math_fround($1415 - $1318);
      $1468 = ((($1440) + (($1438*36)|0)|0) + 12|0);
      HEAPF32[$1468>>2] = $1465;
      $1469 = ((($1440) + (($1438*36)|0)|0) + 16|0);
      HEAPF32[$1469>>2] = $1466;
      $1470 = ((($1440) + (($1438*36)|0)|0) + 20|0);
      HEAPF32[$1470>>2] = $1467;
      $1471 = Math_fround($1419 - $1314);
      $1472 = Math_fround($1420 - $1316);
      $1473 = Math_fround($1421 - $1318);
      $1474 = ((($1440) + (($1438*36)|0)|0) + 24|0);
      HEAPF32[$1474>>2] = $1471;
      $1475 = ((($1440) + (($1438*36)|0)|0) + 28|0);
      HEAPF32[$1475>>2] = $1472;
      $1476 = ((($1440) + (($1438*36)|0)|0) + 32|0);
      HEAPF32[$1476>>2] = $1473;
      $$sum41$i = (($1438) + 1)|0;
      $1477 = (($1440) + (($$sum41$i*36)|0)|0);
      HEAPF32[$1477>>2] = $1459;
      $1478 = ((($1440) + (($$sum41$i*36)|0)|0) + 4|0);
      HEAPF32[$1478>>2] = $1460;
      $1479 = ((($1440) + (($$sum41$i*36)|0)|0) + 8|0);
      HEAPF32[$1479>>2] = $1461;
      $1480 = ((($1440) + (($$sum41$i*36)|0)|0) + 12|0);
      HEAPF32[$1480>>2] = $1471;
      $1481 = ((($1440) + (($$sum41$i*36)|0)|0) + 16|0);
      HEAPF32[$1481>>2] = $1472;
      $1482 = ((($1440) + (($$sum41$i*36)|0)|0) + 20|0);
      HEAPF32[$1482>>2] = $1473;
      $1483 = Math_fround($1422 - $1314);
      $1484 = Math_fround($1423 - $1316);
      $1485 = Math_fround($1424 - $1318);
      $1486 = ((($1440) + (($$sum41$i*36)|0)|0) + 24|0);
      HEAPF32[$1486>>2] = $1483;
      $1487 = ((($1440) + (($$sum41$i*36)|0)|0) + 28|0);
      HEAPF32[$1487>>2] = $1484;
      $1488 = ((($1440) + (($$sum41$i*36)|0)|0) + 32|0);
      HEAPF32[$1488>>2] = $1485;
      $1489 = HEAP32[$1435>>2]|0;
      $1490 = HEAP32[$1437>>2]|0;
      $1491 = HEAP32[$worldTriangles>>2]|0;
      __ZL25visualizeTouchedTrianglesjjPKN5physx10PxTriangleEPNS_2Cm12RenderBufferERKNS_6PxVec3ES8_($1489,$1490,$1491,$6,$1425,$1426,$1427,$236);
      break L26;
      break;
     }
     default: {
      break L26;
     }
     }
    }
   }
  } while(0);
  $1492 = (($i$095) + 1)|0;
  $exitcond = ($1492|0)==($114|0);
  if ($exitcond) {
   break;
  } else {
   $i$095 = $1492;
  }
 }
 STACKTOP = sp;return;
}
function __ZL20outputConvexToStreamPN5physx7PxShapeEPKNS_12PxRigidActorERKNS_11PxTransformERNS_6shdfnd5ArrayIjNS8_19ReflectionAllocatorIjEEEERNS9_INS_10PxTriangleENSA_ISE_EEEESD_RKNS_14PxExtendedVec3ERKNS_9PxBounds3ERKNS_3Cct9CCTParamsEPNS_2Cm12RenderBufferERt($convexShape,$actor,$absPose_,$geomStream,$worldTriangles,$triIndicesArray,$origin,$tmpBounds,$params,$renderBuffer,$nbTessellation) {
 $convexShape = $convexShape|0;
 $actor = $actor|0;
 $absPose_ = $absPose_|0;
 $geomStream = $geomStream|0;
 $worldTriangles = $worldTriangles|0;
 $triIndicesArray = $triIndicesArray|0;
 $origin = $origin|0;
 $tmpBounds = $tmpBounds|0;
 $params = $params|0;
 $renderBuffer = $renderBuffer|0;
 $nbTessellation = $nbTessellation|0;
 var $$c = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum57 = 0, $$sum58 = 0, $$sum59 = 0, $$sum60 = 0, $$sum61 = 0, $$sum62 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0);
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0);
 var $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0);
 var $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0);
 var $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = Math_fround(0), $231 = 0.0, $232 = 0;
 var $233 = 0.0, $234 = 0.0, $235 = Math_fround(0), $236 = 0.0, $237 = 0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0;
 var $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0);
 var $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0;
 var $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0);
 var $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0);
 var $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0);
 var $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0);
 var $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0);
 var $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $Nb$0$lcssa93 = 0, $Nb$083 = 0, $Nb$167 = 0, $Nb$264 = 0, $TF$068 = 0, $TF$165 = 0, $TouchedTriangles$063 = 0, $actor$c = 0, $cg = 0, $currentTriangle = 0, $data = 0, $data2 = 0, $exitcond = 0, $exitcond90 = 0, $exitcond92 = 0, $i$082 = 0, $i1$076 = 0, $j$070 = 0, $nbCreatedTris$0$lcssa = 0, $nbCreatedTris$066 = 0;
 var $params$idx = 0, $params$idx$val = Math_fround(0), $polygons$078 = 0, $scevgep$sum = 0, $scevgep89 = 0, $t$077 = 0, $t$1$lcssa = 0, $t$171 = 0, $tp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $0 = sp + 164|0;
 $tp$i = sp;
 $cg = sp + 48|0;
 $data = sp + 84|0;
 $data2 = sp + 104|0;
 $currentTriangle = sp + 124|0;
 $1 = sp + 160|0;
 HEAP32[$cg>>2] = 4;
 $2 = (($cg) + 4|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($cg) + 8|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($cg) + 12|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($cg) + 16|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($cg) + 20|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($cg) + 24|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($cg) + 28|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($cg) + 32|0);
 HEAP32[$9>>2] = 0;
 $10 = HEAP32[$convexShape>>2]|0;
 $11 = (($10) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iii[$12 & 4095]($convexShape,$cg)|0);
 $13 = HEAP32[$9>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
 $18 = HEAP32[$13>>2]|0;
 $19 = (($18) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_ii[$20 & 4095]($13)|0);
 $22 = ($17|0)==(0);
 if ($22) {
  $529 = $0;$Nb$0$lcssa93 = 0;
 } else {
  $23 = (($data) + 16|0);
  $Nb$083 = 0;$i$082 = 0;
  while(1) {
   $24 = HEAP32[$13>>2]|0;
   $25 = (($24) + 40|0);
   $26 = HEAP32[$25>>2]|0;
   (FUNCTION_TABLE_iiii[$26 & 2047]($13,$i$082,$data)|0);
   $27 = HEAP16[$23>>1]|0;
   $28 = $27&65535;
   $29 = (($Nb$083) + -2)|0;
   $30 = (($29) + ($28))|0;
   $31 = (($i$082) + 1)|0;
   $exitcond92 = ($31|0)==($17|0);
   if ($exitcond92) {
    break;
   } else {
    $Nb$083 = $30;$i$082 = $31;
   }
  }
  $32 = ($30*12)|0;
  $33 = STACKTOP; STACKTOP = STACKTOP + ((((1*$32)|0)+15)&-16)|0;;
  if ($22) {
   $529 = $33;$Nb$0$lcssa93 = $30;
  } else {
   $34 = (($data2) + 16|0);
   $i1$076 = 0;$polygons$078 = $21;$t$077 = $33;
   while(1) {
    $35 = HEAP32[$13>>2]|0;
    $36 = (($35) + 40|0);
    $37 = HEAP32[$36>>2]|0;
    (FUNCTION_TABLE_iiii[$37 & 2047]($13,$i1$076,$data2)|0);
    $38 = HEAP16[$34>>1]|0;
    $39 = $38&65535;
    $40 = (($39) + -2)|0;
    $41 = ($40|0)==(0);
    if ($41) {
     $t$1$lcssa = $t$077;
    } else {
     $42 = HEAP8[$polygons$078>>0]|0;
     $43 = $42&255;
     $44 = ($39*3)|0;
     $j$070 = 0;$t$171 = $t$077;
     while(1) {
      $45 = (($j$070) + 1)|0;
      $46 = (($45>>>0) % ($39>>>0))&-1;
      $47 = (($polygons$078) + ($46)|0);
      $48 = HEAP8[$47>>0]|0;
      $49 = $48&255;
      $50 = (($j$070) + 2)|0;
      $51 = (($50>>>0) % ($39>>>0))&-1;
      $52 = (($polygons$078) + ($51)|0);
      $53 = HEAP8[$52>>0]|0;
      $54 = $53&255;
      $55 = (($t$171) + 4|0);
      HEAP32[$t$171>>2] = $43;
      $56 = (($t$171) + 8|0);
      HEAP32[$55>>2] = $49;
      $57 = (($t$171) + 12|0);
      HEAP32[$56>>2] = $54;
      $exitcond = ($45|0)==($40|0);
      if ($exitcond) {
       break;
      } else {
       $j$070 = $45;$t$171 = $57;
      }
     }
     $scevgep$sum = (($44) + -6)|0;
     $scevgep89 = (($t$077) + ($scevgep$sum<<2)|0);
     $t$1$lcssa = $scevgep89;
    }
    $58 = (($polygons$078) + ($39)|0);
    $59 = (($i1$076) + 1)|0;
    $exitcond90 = ($59|0)==($17|0);
    if ($exitcond90) {
     $529 = $33;$Nb$0$lcssa93 = $30;
     break;
    } else {
     $i1$076 = $59;$polygons$078 = $58;$t$077 = $t$1$lcssa;
    }
   }
  }
 }
 $60 = Math_fround(HEAPF32[$absPose_>>2]);
 $61 = (($absPose_) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($absPose_) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($absPose_) + 12|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($60 + $60);
 $68 = Math_fround($62 + $62);
 $69 = Math_fround($64 + $64);
 $70 = Math_fround($60 * $67);
 $71 = Math_fround($62 * $68);
 $72 = Math_fround($64 * $69);
 $73 = Math_fround($67 * $62);
 $74 = Math_fround($67 * $64);
 $75 = Math_fround($67 * $66);
 $76 = Math_fround($68 * $64);
 $77 = Math_fround($68 * $66);
 $78 = Math_fround($69 * $66);
 $79 = Math_fround(Math_fround(1.0) - $71);
 $80 = Math_fround($79 - $72);
 $81 = Math_fround($73 + $78);
 $82 = Math_fround($74 - $77);
 $83 = Math_fround($73 - $78);
 $84 = Math_fround(Math_fround(1.0) - $70);
 $85 = Math_fround($84 - $72);
 $86 = Math_fround($76 + $75);
 $87 = Math_fround($74 + $77);
 $88 = Math_fround($76 - $75);
 $89 = Math_fround($84 - $71);
 $90 = Math_fround(HEAPF32[$5>>2]);
 $91 = Math_fround(HEAPF32[$6>>2]);
 $92 = Math_fround(HEAPF32[$7>>2]);
 $93 = Math_fround(HEAPF32[$8>>2]);
 $94 = Math_fround($90 + $90);
 $95 = Math_fround($91 + $91);
 $96 = Math_fround($92 + $92);
 $97 = Math_fround($90 * $94);
 $98 = Math_fround($91 * $95);
 $99 = Math_fround($92 * $96);
 $100 = Math_fround($94 * $91);
 $101 = Math_fround($94 * $92);
 $102 = Math_fround($94 * $93);
 $103 = Math_fround($95 * $92);
 $104 = Math_fround($95 * $93);
 $105 = Math_fround($96 * $93);
 $106 = Math_fround(Math_fround(1.0) - $98);
 $107 = Math_fround($106 - $99);
 $108 = Math_fround($100 + $105);
 $109 = Math_fround($101 - $104);
 $110 = Math_fround($100 - $105);
 $111 = Math_fround(Math_fround(1.0) - $97);
 $112 = Math_fround($111 - $99);
 $113 = Math_fround($103 + $102);
 $114 = Math_fround($101 + $104);
 $115 = Math_fround($103 - $102);
 $116 = Math_fround($111 - $98);
 $117 = Math_fround(HEAPF32[$2>>2]);
 $118 = Math_fround($117 * $107);
 $119 = Math_fround($117 * $110);
 $120 = Math_fround($117 * $114);
 $121 = (($2) + 4|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround($108 * $122);
 $124 = Math_fround($112 * $122);
 $125 = Math_fround($115 * $122);
 $126 = (($2) + 8|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = Math_fround($109 * $127);
 $129 = Math_fround($113 * $127);
 $130 = Math_fround($116 * $127);
 $131 = Math_fround($107 * $118);
 $132 = Math_fround($107 * $119);
 $133 = Math_fround($107 * $120);
 $134 = Math_fround($108 * $123);
 $135 = Math_fround($108 * $124);
 $136 = Math_fround($108 * $125);
 $137 = Math_fround($131 + $134);
 $138 = Math_fround($132 + $135);
 $139 = Math_fround($133 + $136);
 $140 = Math_fround($109 * $128);
 $141 = Math_fround($109 * $129);
 $142 = Math_fround($109 * $130);
 $143 = Math_fround($137 + $140);
 $144 = Math_fround($138 + $141);
 $145 = Math_fround($139 + $142);
 $146 = Math_fround($110 * $118);
 $147 = Math_fround($110 * $119);
 $148 = Math_fround($110 * $120);
 $149 = Math_fround($112 * $123);
 $150 = Math_fround($112 * $124);
 $151 = Math_fround($112 * $125);
 $152 = Math_fround($146 + $149);
 $153 = Math_fround($147 + $150);
 $154 = Math_fround($148 + $151);
 $155 = Math_fround($113 * $128);
 $156 = Math_fround($113 * $129);
 $157 = Math_fround($113 * $130);
 $158 = Math_fround($152 + $155);
 $159 = Math_fround($153 + $156);
 $160 = Math_fround($154 + $157);
 $161 = Math_fround($114 * $118);
 $162 = Math_fround($114 * $119);
 $163 = Math_fround($114 * $120);
 $164 = Math_fround($115 * $123);
 $165 = Math_fround($115 * $124);
 $166 = Math_fround($115 * $125);
 $167 = Math_fround($161 + $164);
 $168 = Math_fround($162 + $165);
 $169 = Math_fround($163 + $166);
 $170 = Math_fround($116 * $128);
 $171 = Math_fround($116 * $129);
 $172 = Math_fround($116 * $130);
 $173 = Math_fround($167 + $170);
 $174 = Math_fround($168 + $171);
 $175 = Math_fround($169 + $172);
 $176 = Math_fround($80 * $143);
 $177 = Math_fround($81 * $143);
 $178 = Math_fround($82 * $143);
 $179 = Math_fround($83 * $144);
 $180 = Math_fround($85 * $144);
 $181 = Math_fround($86 * $144);
 $182 = Math_fround($176 + $179);
 $183 = Math_fround($177 + $180);
 $184 = Math_fround($178 + $181);
 $185 = Math_fround($87 * $145);
 $186 = Math_fround($88 * $145);
 $187 = Math_fround($89 * $145);
 $188 = Math_fround($185 + $182);
 $189 = Math_fround($186 + $183);
 $190 = Math_fround($187 + $184);
 $191 = Math_fround($80 * $158);
 $192 = Math_fround($81 * $158);
 $193 = Math_fround($82 * $158);
 $194 = Math_fround($83 * $159);
 $195 = Math_fround($85 * $159);
 $196 = Math_fround($86 * $159);
 $197 = Math_fround($191 + $194);
 $198 = Math_fround($192 + $195);
 $199 = Math_fround($193 + $196);
 $200 = Math_fround($87 * $160);
 $201 = Math_fround($88 * $160);
 $202 = Math_fround($89 * $160);
 $203 = Math_fround($200 + $197);
 $204 = Math_fround($201 + $198);
 $205 = Math_fround($202 + $199);
 $206 = Math_fround($80 * $173);
 $207 = Math_fround($81 * $173);
 $208 = Math_fround($82 * $173);
 $209 = Math_fround($83 * $174);
 $210 = Math_fround($85 * $174);
 $211 = Math_fround($86 * $174);
 $212 = Math_fround($206 + $209);
 $213 = Math_fround($207 + $210);
 $214 = Math_fround($208 + $211);
 $215 = Math_fround($87 * $175);
 $216 = Math_fround($88 * $175);
 $217 = Math_fround($89 * $175);
 $218 = Math_fround($215 + $212);
 $219 = Math_fround($216 + $213);
 $220 = Math_fround($217 + $214);
 $221 = (($absPose_) + 16|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = (($absPose_) + 20|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = (($absPose_) + 24|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = +$222;
 $228 = +HEAPF64[$origin>>3];
 $229 = $227 - $228;
 $230 = Math_fround($229);
 $231 = +$224;
 $232 = (($origin) + 8|0);
 $233 = +HEAPF64[$232>>3];
 $234 = $231 - $233;
 $235 = Math_fround($234);
 $236 = +$226;
 $237 = (($origin) + 16|0);
 $238 = +HEAPF64[$237>>3];
 $239 = $236 - $238;
 $240 = Math_fround($239);
 $241 = Math_fround($228);
 $242 = Math_fround(-$241);
 $243 = Math_fround($233);
 $244 = Math_fround(-$243);
 $245 = Math_fround($238);
 $246 = Math_fround(-$245);
 $247 = (($geomStream) + 4|0);
 $248 = HEAP32[$247>>2]|0;
 $249 = (($248) + 12)|0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE19resizeUninitializedEj($geomStream,$249);
 $250 = HEAP32[$geomStream>>2]|0;
 $251 = (($250) + ($248<<2)|0);
 HEAP32[$251>>2] = 2;
 $$sum = (($248) + 1)|0;
 $252 = (($250) + ($$sum<<2)|0);
 $$c = $convexShape;
 HEAP32[$252>>2] = $$c;
 $$sum57 = (($248) + 2)|0;
 $253 = (($250) + ($$sum57<<2)|0);
 $actor$c = $actor;
 HEAP32[$253>>2] = $actor$c;
 $$sum58 = (($248) + 4)|0;
 $254 = (($250) + ($$sum58<<2)|0);
 ;HEAP32[$254+0>>2]=HEAP32[$origin+0>>2]|0;HEAP32[$254+4>>2]=HEAP32[$origin+4>>2]|0;HEAP32[$254+8>>2]=HEAP32[$origin+8>>2]|0;HEAP32[$254+12>>2]=HEAP32[$origin+12>>2]|0;HEAP32[$254+16>>2]=HEAP32[$origin+16>>2]|0;HEAP32[$254+20>>2]=HEAP32[$origin+20>>2]|0;
 $255 = (($worldTriangles) + 4|0);
 $256 = HEAP32[$255>>2]|0;
 $$sum59 = (($248) + 11)|0;
 $257 = (($250) + ($$sum59<<2)|0);
 HEAP32[$257>>2] = $256;
 $258 = HEAP32[$13>>2]|0;
 $259 = (($258) + 28|0);
 $260 = HEAP32[$259>>2]|0;
 $261 = (FUNCTION_TABLE_ii[$260 & 4095]($13)|0);
 $262 = (($params) + 56|0);
 $263 = HEAP8[$262>>0]|0;
 $264 = ($263<<24>>24)==(0);
 if (!($264)) {
  $265 = (($tmpBounds) + 12|0);
  $266 = Math_fround(HEAPF32[$265>>2]);
  $267 = Math_fround(HEAPF32[$tmpBounds>>2]);
  $268 = Math_fround($266 - $267);
  $269 = (($tmpBounds) + 16|0);
  $270 = Math_fround(HEAPF32[$269>>2]);
  $271 = (($tmpBounds) + 4|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = Math_fround($270 - $272);
  $274 = (($tmpBounds) + 20|0);
  $275 = Math_fround(HEAPF32[$274>>2]);
  $276 = (($tmpBounds) + 8|0);
  $277 = Math_fround(HEAPF32[$276>>2]);
  $278 = Math_fround($275 - $277);
  $279 = Math_fround($268 * Math_fround(0.5));
  $280 = Math_fround($273 * Math_fround(0.5));
  $281 = Math_fround($278 * Math_fround(0.5));
  $282 = Math_fround($266 + $267);
  $283 = Math_fround($270 + $272);
  $284 = Math_fround($275 + $277);
  $285 = Math_fround($282 * Math_fround(0.5));
  $286 = Math_fround($283 * Math_fround(0.5));
  $287 = Math_fround($284 * Math_fround(0.5));
  $288 = Math_fround($285 - $241);
  $289 = Math_fround($286 - $243);
  $290 = Math_fround($287 - $245);
  $291 = Math_fround($288 - $279);
  $292 = Math_fround($289 - $280);
  $293 = Math_fround($290 - $281);
  $294 = Math_fround($279 + $288);
  $295 = Math_fround($280 + $289);
  $296 = Math_fround($281 + $290);
  $297 = ($Nb$0$lcssa93|0)==(0);
  if ($297) {
   $nbCreatedTris$0$lcssa = 0;
  } else {
   $298 = (($currentTriangle) + 4|0);
   $299 = (($currentTriangle) + 8|0);
   $300 = (($currentTriangle) + 12|0);
   $301 = (($currentTriangle) + 16|0);
   $302 = (($currentTriangle) + 20|0);
   $303 = (($currentTriangle) + 24|0);
   $304 = (($currentTriangle) + 28|0);
   $305 = (($currentTriangle) + 32|0);
   $params$idx = (($params) + 52|0);
   $306 = (($tp$i) + 4|0);
   $307 = (($tp$i) + 8|0);
   $308 = (($tp$i) + 12|0);
   $309 = Math_fround($291 + $294);
   $310 = Math_fround($292 + $295);
   $311 = Math_fround($293 + $296);
   $312 = Math_fround($309 * Math_fround(0.5));
   $313 = Math_fround($310 * Math_fround(0.5));
   $314 = Math_fround($311 * Math_fround(0.5));
   $315 = (($tp$i) + 16|0);
   $316 = (($tp$i) + 20|0);
   $317 = (($tp$i) + 24|0);
   $318 = Math_fround($294 - $291);
   $319 = Math_fround($295 - $292);
   $320 = Math_fround($296 - $293);
   $321 = Math_fround($318 * Math_fround(0.5));
   $322 = Math_fround($319 * Math_fround(0.5));
   $323 = Math_fround($320 * Math_fround(0.5));
   $324 = (($tp$i) + 28|0);
   $325 = (($tp$i) + 32|0);
   $326 = (($tp$i) + 36|0);
   $327 = (($tp$i) + 40|0);
   $328 = (($tp$i) + 44|0);
   $Nb$167 = $Nb$0$lcssa93;$TF$068 = $529;$nbCreatedTris$066 = 0;
   while(1) {
    $329 = (($Nb$167) + -1)|0;
    $330 = (($TF$068) + 4|0);
    $331 = HEAP32[$TF$068>>2]|0;
    $332 = (($TF$068) + 8|0);
    $333 = HEAP32[$330>>2]|0;
    $334 = (($TF$068) + 12|0);
    $335 = HEAP32[$332>>2]|0;
    $336 = (($261) + (($331*12)|0)|0);
    $337 = Math_fround(HEAPF32[$336>>2]);
    $338 = ((($261) + (($331*12)|0)|0) + 4|0);
    $339 = Math_fround(HEAPF32[$338>>2]);
    $340 = ((($261) + (($331*12)|0)|0) + 8|0);
    $341 = Math_fround(HEAPF32[$340>>2]);
    $342 = Math_fround($188 * $337);
    $343 = Math_fround($189 * $337);
    $344 = Math_fround($190 * $337);
    $345 = Math_fround($203 * $339);
    $346 = Math_fround($204 * $339);
    $347 = Math_fround($205 * $339);
    $348 = Math_fround($342 + $345);
    $349 = Math_fround($343 + $346);
    $350 = Math_fround($344 + $347);
    $351 = Math_fround($218 * $341);
    $352 = Math_fround($219 * $341);
    $353 = Math_fround($220 * $341);
    $354 = Math_fround($348 + $351);
    $355 = Math_fround($349 + $352);
    $356 = Math_fround($350 + $353);
    $357 = Math_fround($230 + $354);
    $358 = Math_fround($235 + $355);
    $359 = Math_fround($240 + $356);
    HEAPF32[$currentTriangle>>2] = $357;
    HEAPF32[$298>>2] = $358;
    HEAPF32[$299>>2] = $359;
    $360 = (($261) + (($333*12)|0)|0);
    $361 = Math_fround(HEAPF32[$360>>2]);
    $362 = ((($261) + (($333*12)|0)|0) + 4|0);
    $363 = Math_fround(HEAPF32[$362>>2]);
    $364 = ((($261) + (($333*12)|0)|0) + 8|0);
    $365 = Math_fround(HEAPF32[$364>>2]);
    $366 = Math_fround($188 * $361);
    $367 = Math_fround($189 * $361);
    $368 = Math_fround($190 * $361);
    $369 = Math_fround($203 * $363);
    $370 = Math_fround($204 * $363);
    $371 = Math_fround($205 * $363);
    $372 = Math_fround($366 + $369);
    $373 = Math_fround($367 + $370);
    $374 = Math_fround($368 + $371);
    $375 = Math_fround($218 * $365);
    $376 = Math_fround($219 * $365);
    $377 = Math_fround($220 * $365);
    $378 = Math_fround($372 + $375);
    $379 = Math_fround($373 + $376);
    $380 = Math_fround($374 + $377);
    $381 = Math_fround($230 + $378);
    $382 = Math_fround($235 + $379);
    $383 = Math_fround($240 + $380);
    HEAPF32[$300>>2] = $381;
    HEAPF32[$301>>2] = $382;
    HEAPF32[$302>>2] = $383;
    $384 = (($261) + (($335*12)|0)|0);
    $385 = Math_fround(HEAPF32[$384>>2]);
    $386 = ((($261) + (($335*12)|0)|0) + 4|0);
    $387 = Math_fround(HEAPF32[$386>>2]);
    $388 = ((($261) + (($335*12)|0)|0) + 8|0);
    $389 = Math_fround(HEAPF32[$388>>2]);
    $390 = Math_fround($188 * $385);
    $391 = Math_fround($189 * $385);
    $392 = Math_fround($190 * $385);
    $393 = Math_fround($203 * $387);
    $394 = Math_fround($204 * $387);
    $395 = Math_fround($205 * $387);
    $396 = Math_fround($390 + $393);
    $397 = Math_fround($391 + $394);
    $398 = Math_fround($392 + $395);
    $399 = Math_fround($218 * $389);
    $400 = Math_fround($219 * $389);
    $401 = Math_fround($220 * $389);
    $402 = Math_fround($396 + $399);
    $403 = Math_fround($397 + $400);
    $404 = Math_fround($398 + $401);
    $405 = Math_fround($230 + $402);
    $406 = Math_fround($235 + $403);
    $407 = Math_fround($240 + $404);
    HEAPF32[$303>>2] = $405;
    HEAPF32[$304>>2] = $406;
    HEAPF32[$305>>2] = $407;
    $params$idx$val = Math_fround(HEAPF32[$params$idx>>2]);
    HEAP32[$tp$i>>2] = 0;
    HEAP32[$306>>2] = -1;
    HEAP32[$307>>2] = $worldTriangles;
    HEAP32[$308>>2] = $triIndicesArray;
    HEAPF32[$315>>2] = $312;
    HEAPF32[$316>>2] = $313;
    HEAPF32[$317>>2] = $314;
    HEAPF32[$324>>2] = $321;
    HEAPF32[$325>>2] = $322;
    HEAPF32[$326>>2] = $323;
    HEAPF32[$327>>2] = $params$idx$val;
    HEAP16[$328>>1] = 0;
    __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp$i,$currentTriangle,$300,$303);
    $408 = HEAP32[$tp$i>>2]|0;
    $409 = HEAP16[$328>>1]|0;
    $410 = $409&65535;
    $411 = HEAP16[$nbTessellation>>1]|0;
    $412 = $411&65535;
    $413 = (($412) + ($410))|0;
    $414 = $413&65535;
    HEAP16[$nbTessellation>>1] = $414;
    $415 = (($408) + ($nbCreatedTris$066))|0;
    $416 = ($329|0)==(0);
    if ($416) {
     $nbCreatedTris$0$lcssa = $415;
     break;
    } else {
     $Nb$167 = $329;$TF$068 = $334;$nbCreatedTris$066 = $415;
    }
   }
  }
  $$sum60 = (($248) + 10)|0;
  $417 = (($250) + ($$sum60<<2)|0);
  HEAP32[$417>>2] = $nbCreatedTris$0$lcssa;
  $$pre$phiZ2D = $worldTriangles;
  $$sum61 = (($248) + 10)|0;
  $524 = (($250) + ($$sum61<<2)|0);
  $525 = HEAP32[$524>>2]|0;
  $526 = HEAP32[$257>>2]|0;
  $527 = HEAP32[$$pre$phiZ2D>>2]|0;
  $528 = (($params) + 20|0);
  __ZL25visualizeTouchedTrianglesjjPKN5physx10PxTriangleEPNS_2Cm12RenderBufferERKNS_6PxVec3ES8_($525,$526,$527,$renderBuffer,$242,$244,$246,$528);
  STACKTOP = sp;return;
 }
 $418 = HEAP32[$255>>2]|0;
 $419 = (($418) + ($Nb$0$lcssa93))|0;
 __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($worldTriangles,$419);
 $420 = HEAP32[$worldTriangles>>2]|0;
 $$sum62 = (($248) + 10)|0;
 $421 = (($250) + ($$sum62<<2)|0);
 HEAP32[$421>>2] = $Nb$0$lcssa93;
 $422 = ($Nb$0$lcssa93|0)==(0);
 if ($422) {
  $$pre$phiZ2D = $worldTriangles;
  $$sum61 = (($248) + 10)|0;
  $524 = (($250) + ($$sum61<<2)|0);
  $525 = HEAP32[$524>>2]|0;
  $526 = HEAP32[$257>>2]|0;
  $527 = HEAP32[$$pre$phiZ2D>>2]|0;
  $528 = (($params) + 20|0);
  __ZL25visualizeTouchedTrianglesjjPKN5physx10PxTriangleEPNS_2Cm12RenderBufferERKNS_6PxVec3ES8_($525,$526,$527,$renderBuffer,$242,$244,$246,$528);
  STACKTOP = sp;return;
 }
 $423 = (($420) + (($418*36)|0)|0);
 $424 = (($triIndicesArray) + 8|0);
 $425 = (($triIndicesArray) + 4|0);
 $Nb$264 = $Nb$0$lcssa93;$TF$165 = $529;$TouchedTriangles$063 = $423;
 while(1) {
  $426 = (($Nb$264) + -1)|0;
  $427 = (($TouchedTriangles$063) + 36|0);
  $428 = (($TF$165) + 4|0);
  $429 = HEAP32[$TF$165>>2]|0;
  $430 = (($TF$165) + 8|0);
  $431 = HEAP32[$428>>2]|0;
  $432 = (($TF$165) + 12|0);
  $433 = HEAP32[$430>>2]|0;
  $434 = (($261) + (($429*12)|0)|0);
  $435 = Math_fround(HEAPF32[$434>>2]);
  $436 = ((($261) + (($429*12)|0)|0) + 4|0);
  $437 = Math_fround(HEAPF32[$436>>2]);
  $438 = ((($261) + (($429*12)|0)|0) + 8|0);
  $439 = Math_fround(HEAPF32[$438>>2]);
  $440 = Math_fround($188 * $435);
  $441 = Math_fround($189 * $435);
  $442 = Math_fround($190 * $435);
  $443 = Math_fround($203 * $437);
  $444 = Math_fround($204 * $437);
  $445 = Math_fround($205 * $437);
  $446 = Math_fround($440 + $443);
  $447 = Math_fround($441 + $444);
  $448 = Math_fround($442 + $445);
  $449 = Math_fround($218 * $439);
  $450 = Math_fround($219 * $439);
  $451 = Math_fround($220 * $439);
  $452 = Math_fround($446 + $449);
  $453 = Math_fround($447 + $450);
  $454 = Math_fround($448 + $451);
  $455 = Math_fround($230 + $452);
  $456 = Math_fround($235 + $453);
  $457 = Math_fround($240 + $454);
  HEAPF32[$TouchedTriangles$063>>2] = $455;
  $458 = (($TouchedTriangles$063) + 4|0);
  HEAPF32[$458>>2] = $456;
  $459 = (($TouchedTriangles$063) + 8|0);
  HEAPF32[$459>>2] = $457;
  $460 = (($261) + (($431*12)|0)|0);
  $461 = Math_fround(HEAPF32[$460>>2]);
  $462 = ((($261) + (($431*12)|0)|0) + 4|0);
  $463 = Math_fround(HEAPF32[$462>>2]);
  $464 = ((($261) + (($431*12)|0)|0) + 8|0);
  $465 = Math_fround(HEAPF32[$464>>2]);
  $466 = Math_fround($188 * $461);
  $467 = Math_fround($189 * $461);
  $468 = Math_fround($190 * $461);
  $469 = Math_fround($203 * $463);
  $470 = Math_fround($204 * $463);
  $471 = Math_fround($205 * $463);
  $472 = Math_fround($466 + $469);
  $473 = Math_fround($467 + $470);
  $474 = Math_fround($468 + $471);
  $475 = Math_fround($218 * $465);
  $476 = Math_fround($219 * $465);
  $477 = Math_fround($220 * $465);
  $478 = Math_fround($472 + $475);
  $479 = Math_fround($473 + $476);
  $480 = Math_fround($474 + $477);
  $481 = Math_fround($230 + $478);
  $482 = Math_fround($235 + $479);
  $483 = Math_fround($240 + $480);
  $484 = (($TouchedTriangles$063) + 12|0);
  HEAPF32[$484>>2] = $481;
  $485 = (($TouchedTriangles$063) + 16|0);
  HEAPF32[$485>>2] = $482;
  $486 = (($TouchedTriangles$063) + 20|0);
  HEAPF32[$486>>2] = $483;
  $487 = (($261) + (($433*12)|0)|0);
  $488 = Math_fround(HEAPF32[$487>>2]);
  $489 = ((($261) + (($433*12)|0)|0) + 4|0);
  $490 = Math_fround(HEAPF32[$489>>2]);
  $491 = ((($261) + (($433*12)|0)|0) + 8|0);
  $492 = Math_fround(HEAPF32[$491>>2]);
  $493 = Math_fround($188 * $488);
  $494 = Math_fround($189 * $488);
  $495 = Math_fround($190 * $488);
  $496 = Math_fround($203 * $490);
  $497 = Math_fround($204 * $490);
  $498 = Math_fround($205 * $490);
  $499 = Math_fround($493 + $496);
  $500 = Math_fround($494 + $497);
  $501 = Math_fround($495 + $498);
  $502 = Math_fround($218 * $492);
  $503 = Math_fround($219 * $492);
  $504 = Math_fround($220 * $492);
  $505 = Math_fround($499 + $502);
  $506 = Math_fround($500 + $503);
  $507 = Math_fround($501 + $504);
  $508 = Math_fround($230 + $505);
  $509 = Math_fround($235 + $506);
  $510 = Math_fround($240 + $507);
  $511 = (($TouchedTriangles$063) + 24|0);
  HEAPF32[$511>>2] = $508;
  $512 = (($TouchedTriangles$063) + 28|0);
  HEAPF32[$512>>2] = $509;
  $513 = (($TouchedTriangles$063) + 32|0);
  HEAPF32[$513>>2] = $510;
  HEAP32[$1>>2] = -1;
  $514 = HEAP32[$424>>2]|0;
  $515 = $514 & 2147483647;
  $516 = HEAP32[$425>>2]|0;
  $517 = ($515>>>0)>($516>>>0);
  if ($517) {
   $519 = HEAP32[$triIndicesArray>>2]|0;
   $520 = (($519) + ($516<<2)|0);
   $521 = ($520|0)==(0|0);
   if ($521) {
    $523 = $516;
   } else {
    HEAP32[$520>>2] = -1;
    $$pre$i = HEAP32[$425>>2]|0;
    $523 = $$pre$i;
   }
   $522 = (($523) + 1)|0;
   HEAP32[$425>>2] = $522;
  } else {
   (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$1)|0);
  }
  $518 = ($426|0)==(0);
  if ($518) {
   $$pre$phiZ2D = $worldTriangles;
   break;
  } else {
   $Nb$264 = $426;$TF$165 = $432;$TouchedTriangles$063 = $427;
  }
 }
 $$sum61 = (($248) + 10)|0;
 $524 = (($250) + ($$sum61<<2)|0);
 $525 = HEAP32[$524>>2]|0;
 $526 = HEAP32[$257>>2]|0;
 $527 = HEAP32[$$pre$phiZ2D>>2]|0;
 $528 = (($params) + 20|0);
 __ZL25visualizeTouchedTrianglesjjPKN5physx10PxTriangleEPNS_2Cm12RenderBufferERKNS_6PxVec3ES8_($525,$526,$527,$renderBuffer,$242,$244,$246,$528);
 STACKTOP = sp;return;
}
function __ZN5physx11PxHitBufferINS_12PxOverlapHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct16shapeHitCallbackEPKNS0_20InternalCBData_OnHitERKNS0_12SweptContactERKNS_6PxVec3Ef($userData,$contact,$dir,$length) {
 $userData = $userData|0;
 $contact = $contact|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $hit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $hit = sp;
 $0 = sp + 72|0;
 $1 = HEAP32[$userData>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 HEAP32[$hit>>2] = $5;
 $6 = (($hit) + 8|0);
 ;HEAP32[$6+0>>2]=HEAP32[$contact+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$contact+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$contact+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$contact+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$contact+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$contact+20>>2]|0;
 $7 = (($contact) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($hit) + 32|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($contact) + 28|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($hit) + 36|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($contact) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($hit) + 40|0);
 HEAPF32[$15>>2] = $14;
 $16 = Math_fround(HEAPF32[$dir>>2]);
 $17 = (($hit) + 44|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($dir) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($hit) + 48|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($dir) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($hit) + 52|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($hit) + 56|0);
 HEAPF32[$24>>2] = $length;
 $25 = (($contact) + 48|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($hit) + 60|0);
 HEAP32[$29>>2] = $28;
 $30 = (($26) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($hit) + 64|0);
 HEAP32[$32>>2] = $31;
 $33 = (($contact) + 44|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($hit) + 68|0);
 HEAP32[$35>>2] = $34;
 $36 = (($1) + 72|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  $39 = HEAP32[$37>>2]|0;
  $40 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_vii[$40 & 4095]($37,$hit);
 }
 $41 = (($1) + 76|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $50 = 0;
  STACKTOP = sp;return ($50|0);
 }
 $44 = HEAP32[$42>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$29>>2]|0;
 $47 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_viiii[$45 & 511]($0,$42,$46,$47);
 $48 = HEAP8[$0>>0]|0;
 $49 = $48&255;
 $50 = $49;
 STACKTOP = sp;return ($50|0);
}
function __ZN5physx3Cct15userHitCallbackEPKNS0_20InternalCBData_OnHitERKNS0_12SweptContactERKNS_6PxVec3Ef($userData,$contact,$dir,$length) {
 $userData = $userData|0;
 $contact = $contact|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 var $$0 = 0, $$val = 0, $$val3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0);
 var $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $hit = 0, $hit1 = 0;
 var $hit2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 194|0;
 $1 = sp + 193|0;
 $hit = sp + 64|0;
 $2 = sp + 192|0;
 $hit1 = sp;
 $hit2 = sp + 128|0;
 $3 = HEAP32[$userData>>2]|0;
 $4 = (($contact) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 $9 = $8 & 65535;
 $10 = $8 >>> 16;
 if ((($9|0) == 1)) {
  $59 = HEAP32[$3>>2]|0;
  $60 = (($59) + 20|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (FUNCTION_TABLE_ii[$61 & 4095]($3)|0);
  HEAP32[$hit1>>2] = $62;
  $63 = (($hit1) + 8|0);
  ;HEAP32[$63+0>>2]=HEAP32[$contact+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$contact+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$contact+8>>2]|0;HEAP32[$63+12>>2]=HEAP32[$contact+12>>2]|0;HEAP32[$63+16>>2]=HEAP32[$contact+16>>2]|0;HEAP32[$63+20>>2]=HEAP32[$contact+20>>2]|0;
  $64 = (($contact) + 24|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = (($hit1) + 32|0);
  HEAPF32[$66>>2] = $65;
  $67 = (($contact) + 28|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($hit1) + 36|0);
  HEAPF32[$69>>2] = $68;
  $70 = (($contact) + 32|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = (($hit1) + 40|0);
  HEAPF32[$72>>2] = $71;
  $73 = Math_fround(HEAPF32[$dir>>2]);
  $74 = (($hit1) + 44|0);
  HEAPF32[$74>>2] = $73;
  $75 = (($dir) + 4|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($hit1) + 48|0);
  HEAPF32[$77>>2] = $76;
  $78 = (($dir) + 8|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = (($hit1) + 52|0);
  HEAPF32[$80>>2] = $79;
  $81 = (($hit1) + 56|0);
  HEAPF32[$81>>2] = $length;
  $82 = (($userData) + 4|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + 4|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ((($85) + (($10*72)|0)|0) + 8|0);
  $87 = (($85) + (($10*72)|0)|0);
  $$val3 = HEAP32[$87>>2]|0;
  $88 = ((($85) + (($10*72)|0)|0) + 12|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (($hit1) + 60|0);
  HEAP32[$90>>2] = $89;
  $91 = (($userData) + 8|0);
  HEAP32[$91>>2] = $86;
  $92 = (($userData) + 12|0);
  HEAP32[$92>>2] = $$val3;
  $93 = (($3) + 72|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)==(0|0);
  if (!($95)) {
   $96 = HEAP32[$94>>2]|0;
   $97 = (($96) + 8|0);
   $98 = HEAP32[$97>>2]|0;
   FUNCTION_TABLE_vii[$98 & 4095]($94,$hit1);
  }
  $99 = (($3) + 76|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0|0);
  if ($101) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $102 = HEAP32[$100>>2]|0;
  $103 = (($102) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  FUNCTION_TABLE_viii[$104 & 4095]($0,$100,$86);
  $105 = HEAP8[$0>>0]|0;
  $106 = $105&255;
  $$0 = $106;
  STACKTOP = sp;return ($$0|0);
 } else if ((($9|0) == 0)) {
  $11 = (($3) + 464|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (__ZN5physx3Cct26CharacterControllerManager14getControllersEv($12)|0);
  $14 = (($13) + ($10<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$3>>2]|0;
  $17 = (($16) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (FUNCTION_TABLE_ii[$18 & 4095]($3)|0);
  HEAP32[$hit>>2] = $19;
  $20 = (($hit) + 8|0);
  ;HEAP32[$20+0>>2]=HEAP32[$contact+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$contact+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$contact+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$contact+12>>2]|0;HEAP32[$20+16>>2]=HEAP32[$contact+16>>2]|0;HEAP32[$20+20>>2]=HEAP32[$contact+20>>2]|0;
  $21 = (($contact) + 24|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($hit) + 32|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($contact) + 28|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($hit) + 36|0);
  HEAPF32[$26>>2] = $25;
  $27 = (($contact) + 32|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($hit) + 40|0);
  HEAPF32[$29>>2] = $28;
  $30 = Math_fround(HEAPF32[$dir>>2]);
  $31 = (($hit) + 44|0);
  HEAPF32[$31>>2] = $30;
  $32 = (($dir) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($hit) + 48|0);
  HEAPF32[$34>>2] = $33;
  $35 = (($dir) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($hit) + 52|0);
  HEAPF32[$37>>2] = $36;
  $38 = (($hit) + 56|0);
  HEAPF32[$38>>2] = $length;
  $39 = HEAP32[$15>>2]|0;
  $40 = (($39) + 20|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (FUNCTION_TABLE_ii[$41 & 4095]($15)|0);
  $43 = (($hit) + 60|0);
  HEAP32[$43>>2] = $42;
  $44 = (($3) + 72|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  if (!($46)) {
   $47 = HEAP32[$45>>2]|0;
   $48 = (($47) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   FUNCTION_TABLE_vii[$49 & 4095]($45,$hit);
  }
  $50 = (($3) + 76|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0|0);
  if ($52) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $53 = HEAP32[$51>>2]|0;
  $54 = (($53) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = HEAP32[$43>>2]|0;
  FUNCTION_TABLE_viii[$55 & 4095]($2,$51,$56);
  $57 = HEAP8[$2>>0]|0;
  $58 = $57&255;
  $$0 = $58;
  STACKTOP = sp;return ($$0|0);
 } else if ((($9|0) == 2)) {
  $107 = HEAP32[$3>>2]|0;
  $108 = (($107) + 20|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (FUNCTION_TABLE_ii[$109 & 4095]($3)|0);
  HEAP32[$hit2>>2] = $110;
  $111 = (($hit2) + 8|0);
  ;HEAP32[$111+0>>2]=HEAP32[$contact+0>>2]|0;HEAP32[$111+4>>2]=HEAP32[$contact+4>>2]|0;HEAP32[$111+8>>2]=HEAP32[$contact+8>>2]|0;HEAP32[$111+12>>2]=HEAP32[$contact+12>>2]|0;HEAP32[$111+16>>2]=HEAP32[$contact+16>>2]|0;HEAP32[$111+20>>2]=HEAP32[$contact+20>>2]|0;
  $112 = (($contact) + 24|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = (($hit2) + 32|0);
  HEAPF32[$114>>2] = $113;
  $115 = (($contact) + 28|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = (($hit2) + 36|0);
  HEAPF32[$117>>2] = $116;
  $118 = (($contact) + 32|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = (($hit2) + 40|0);
  HEAPF32[$120>>2] = $119;
  $121 = Math_fround(HEAPF32[$dir>>2]);
  $122 = (($hit2) + 44|0);
  HEAPF32[$122>>2] = $121;
  $123 = (($dir) + 4|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = (($hit2) + 48|0);
  HEAPF32[$125>>2] = $124;
  $126 = (($dir) + 8|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = (($hit2) + 52|0);
  HEAPF32[$128>>2] = $127;
  $129 = (($hit2) + 56|0);
  HEAPF32[$129>>2] = $length;
  $130 = (($userData) + 4|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = (($131) + 16|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ((($133) + ($10<<6)|0) + 8|0);
  $135 = (($133) + ($10<<6)|0);
  $$val = HEAP32[$135>>2]|0;
  $136 = ((($133) + ($10<<6)|0) + 12|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = (($hit2) + 60|0);
  HEAP32[$138>>2] = $137;
  $139 = (($userData) + 8|0);
  HEAP32[$139>>2] = $134;
  $140 = (($userData) + 12|0);
  HEAP32[$140>>2] = $$val;
  $141 = (($3) + 72|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = ($142|0)==(0|0);
  if (!($143)) {
   $144 = HEAP32[$142>>2]|0;
   $145 = (($144) + 8|0);
   $146 = HEAP32[$145>>2]|0;
   FUNCTION_TABLE_vii[$146 & 4095]($142,$hit2);
  }
  $147 = (($3) + 76|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = ($148|0)==(0|0);
  if ($149) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $150 = HEAP32[$148>>2]|0;
  $151 = (($150) + 8|0);
  $152 = HEAP32[$151>>2]|0;
  FUNCTION_TABLE_viii[$152 & 4095]($1,$148,$134);
  $153 = HEAP8[$1>>0]|0;
  $154 = $153&255;
  $$0 = $154;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx11PxHitBufferINS_12PxOverlapHitEE14processTouchesEPKS1_j($this,$buffer,$nbHits) {
 $this = $this|0;
 $buffer = $buffer|0;
 $nbHits = $nbHits|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx13PxHitCallbackINS_12PxOverlapHitEE13finalizeQueryEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx11PxHitBufferINS_12PxOverlapHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZL25visualizeTouchedTrianglesjjPKN5physx10PxTriangleEPNS_2Cm12RenderBufferERKNS_6PxVec3ES8_($nbTrisToRender,$startIndex,$triangles,$renderBuffer,$offset$0$0$val,$offset$0$1$val,$offset$0$2$val,$upDirection) {
 $nbTrisToRender = $nbTrisToRender|0;
 $startIndex = $startIndex|0;
 $triangles = $triangles|0;
 $renderBuffer = $renderBuffer|0;
 $offset$0$0$val = Math_fround($offset$0$0$val);
 $offset$0$1$val = Math_fround($offset$0$1$val);
 $offset$0$2$val = Math_fround($offset$0$2$val);
 $upDirection = $upDirection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $exitcond = 0, $i$01 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $0 = sp + 72|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 $6 = sp + 60|0;
 $7 = ($renderBuffer|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = Math_fround(HEAPF32[$upDirection>>2]);
 $9 = Math_fround($8 * Math_fround(0.00999999977648258209228));
 $10 = (($upDirection) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * Math_fround(0.00999999977648258209228));
 $13 = (($upDirection) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * Math_fround(0.00999999977648258209228));
 $16 = Math_fround($9 - $offset$0$0$val);
 $17 = Math_fround($12 - $offset$0$1$val);
 $18 = Math_fround($15 - $offset$0$2$val);
 $19 = ($nbTrisToRender|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (($0) + 36|0);
 $21 = (($0) + 40|0);
 $22 = (($0) + 56|0);
 $23 = (($0) + 60|0);
 $24 = (($0) + 76|0);
 $25 = (($0) + 80|0);
 $26 = (($0) + 96|0);
 $27 = (($0) + 100|0);
 $28 = (($1) + 4|0);
 $29 = (($1) + 8|0);
 $30 = (($2) + 4|0);
 $31 = (($2) + 8|0);
 $32 = (($3) + 4|0);
 $33 = (($3) + 8|0);
 $34 = (($4) + 4|0);
 $35 = (($4) + 8|0);
 $36 = (($5) + 4|0);
 $37 = (($5) + 8|0);
 $38 = (($6) + 4|0);
 $39 = (($6) + 8|0);
 $i$01 = 0;
 while(1) {
  $40 = (($i$01) + ($startIndex))|0;
  dest=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAPF32[$20>>2] = Math_fround(1.0);
  ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
  HEAPF32[$22>>2] = Math_fround(1.0);
  ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;
  HEAPF32[$24>>2] = Math_fround(1.0);
  ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;
  HEAPF32[$26>>2] = Math_fround(1.0);
  HEAP32[$27>>2] = $renderBuffer;
  $41 = (__ZN5physx2Cm12RenderOutputlsEj($0,-16711936)|0);
  $42 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($41,1)|0);
  $43 = (($triangles) + (($40*36)|0)|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($16 + $44);
  $46 = ((($triangles) + (($40*36)|0)|0) + 4|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($17 + $47);
  $49 = ((($triangles) + (($40*36)|0)|0) + 8|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($18 + $50);
  HEAPF32[$1>>2] = $45;
  HEAPF32[$28>>2] = $48;
  HEAPF32[$29>>2] = $51;
  $52 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($42,$1)|0);
  $53 = ((($triangles) + (($40*36)|0)|0) + 12|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($16 + $54);
  $56 = ((($triangles) + (($40*36)|0)|0) + 16|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($17 + $57);
  $59 = ((($triangles) + (($40*36)|0)|0) + 20|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($18 + $60);
  HEAPF32[$2>>2] = $55;
  HEAPF32[$30>>2] = $58;
  HEAPF32[$31>>2] = $61;
  $62 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($52,$2)|0);
  $63 = Math_fround(HEAPF32[$53>>2]);
  $64 = Math_fround($16 + $63);
  $65 = Math_fround(HEAPF32[$56>>2]);
  $66 = Math_fround($17 + $65);
  $67 = Math_fround(HEAPF32[$59>>2]);
  $68 = Math_fround($18 + $67);
  HEAPF32[$3>>2] = $64;
  HEAPF32[$32>>2] = $66;
  HEAPF32[$33>>2] = $68;
  $69 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($62,$3)|0);
  $70 = ((($triangles) + (($40*36)|0)|0) + 24|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = Math_fround($16 + $71);
  $73 = ((($triangles) + (($40*36)|0)|0) + 28|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($17 + $74);
  $76 = ((($triangles) + (($40*36)|0)|0) + 32|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = Math_fround($18 + $77);
  HEAPF32[$4>>2] = $72;
  HEAPF32[$34>>2] = $75;
  HEAPF32[$35>>2] = $78;
  $79 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($69,$4)|0);
  $80 = Math_fround(HEAPF32[$70>>2]);
  $81 = Math_fround($16 + $80);
  $82 = Math_fround(HEAPF32[$73>>2]);
  $83 = Math_fround($17 + $82);
  $84 = Math_fround(HEAPF32[$76>>2]);
  $85 = Math_fround($18 + $84);
  HEAPF32[$5>>2] = $81;
  HEAPF32[$36>>2] = $83;
  HEAPF32[$37>>2] = $85;
  $86 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($79,$5)|0);
  $87 = Math_fround(HEAPF32[$43>>2]);
  $88 = Math_fround($16 + $87);
  $89 = Math_fround(HEAPF32[$46>>2]);
  $90 = Math_fround($17 + $89);
  $91 = Math_fround(HEAPF32[$49>>2]);
  $92 = Math_fround($18 + $91);
  HEAPF32[$6>>2] = $88;
  HEAPF32[$38>>2] = $90;
  HEAPF32[$39>>2] = $92;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($86,$6)|0);
  $93 = (($i$01) + 1)|0;
  $exitcond = ($93|0)==($nbTrisToRender|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $93;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 404776 : 404744;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,404664,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $30 = $$pre;
 } else {
  $30 = $19;
 }
 $29 = (($21) + ($30<<2)|0);
 $31 = ($29|0)==(0|0);
 if (!($31)) {
  $32 = HEAP32[$a>>2]|0;
  HEAP32[$29>>2] = $32;
 }
 $33 = HEAP32[$0>>2]|0;
 $34 = ($33|0)>(-1);
 if ($34) {
  $35 = HEAP32[$this>>2]|0;
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   $37 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + 12|0);
   $40 = HEAP32[$39>>2]|0;
   FUNCTION_TABLE_vii[$40 & 4095]($37,$35);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $41 = HEAP32[$18>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$18>>2] = $42;
 $43 = (($21) + ($41<<2)|0);
 STACKTOP = sp;return ($43|0);
}
function __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*36)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 404880 : 404744;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,404664,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*36)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$03$i) + 4|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = (($$012$i) + 4|0);
    HEAPF32[$23>>2] = $22;
    $24 = (($$03$i) + 8|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = (($$012$i) + 8|0);
    HEAPF32[$26>>2] = $25;
    $27 = (($$03$i) + 12|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = (($$012$i) + 12|0);
    HEAPF32[$29>>2] = $28;
    $30 = (($$03$i) + 16|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = (($$012$i) + 16|0);
    HEAPF32[$32>>2] = $31;
    $33 = (($$03$i) + 20|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($$012$i) + 20|0);
    HEAPF32[$35>>2] = $34;
    $36 = (($$03$i) + 24|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = (($$012$i) + 24|0);
    HEAPF32[$38>>2] = $37;
    $39 = (($$03$i) + 28|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = (($$012$i) + 28|0);
    HEAPF32[$41>>2] = $40;
    $42 = (($$03$i) + 32|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = (($$012$i) + 32|0);
    HEAPF32[$44>>2] = $43;
   }
   $45 = (($$012$i) + 36|0);
   $46 = (($$03$i) + 36|0);
   $47 = ($45>>>0)<($15>>>0);
   if ($47) {
    $$012$i = $45;$$03$i = $46;
   } else {
    break;
   }
  }
 }
 $48 = (($this) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)>(-1);
 if (!($50)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$48>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $51 = HEAP32[$this>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  HEAP32[$this>>2] = $16;
  HEAP32[$48>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $53 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vii[$56 & 4095]($53,$51);
 HEAP32[$this>>2] = $16;
 HEAP32[$48>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$v1,$v2) {
 $tp = $tp|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0;
 var $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $m0 = 0, $m1 = 0, $m2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $m0 = sp + 60|0;
 $m1 = sp;
 $m2 = sp + 12|0;
 $0 = sp + 24|0;
 $1 = (($tp) + 44|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = (($2) + 1)<<16>>16;
 HEAP16[$1>>1] = $3;
 $4 = (($tp) + 16|0);
 $5 = (($tp) + 28|0);
 $6 = (__ZN5physx2Gu20intersectTriangleBoxERKNS_6PxVec3ES3_S3_S3_S3_($4,$5,$v0,$v1,$v2)|0);
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = Math_fround(HEAPF32[$v0>>2]);
 $9 = Math_fround(HEAPF32[$v1>>2]);
 $10 = Math_fround($8 - $9);
 $11 = (($v0) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($v1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 - $14);
 $16 = (($v0) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($v1) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 - $19);
 $21 = Math_fround(HEAPF32[$v2>>2]);
 $22 = Math_fround($9 - $21);
 $23 = (($v2) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($14 - $24);
 $26 = (($v2) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($19 - $27);
 $29 = Math_fround($21 - $8);
 $30 = Math_fround($24 - $12);
 $31 = Math_fround($27 - $17);
 $32 = (($tp) + 40|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($10 * $10);
 $35 = Math_fround($15 * $15);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($20 * $20);
 $38 = Math_fround($36 + $37);
 $39 = $38 > $33;
 $40 = Math_fround($22 * $22);
 $41 = Math_fround($25 * $25);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($28 * $28);
 $44 = Math_fround($42 + $43);
 $45 = $44 > $33;
 $46 = Math_fround($29 * $29);
 $47 = Math_fround($30 * $30);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($31 * $31);
 $50 = Math_fround($48 + $49);
 $51 = $50 > $33;
 $52 = $51&1;
 $53 = $52 << 2;
 $54 = $45&1;
 $55 = $54 << 1;
 $56 = $39&1;
 $57 = $55 | $56;
 $58 = $57 | $53;
 $59 = Math_fround($8 + $9);
 $60 = Math_fround($12 + $14);
 $61 = Math_fround($17 + $19);
 $62 = Math_fround($59 * Math_fround(0.5));
 $63 = Math_fround($60 * Math_fround(0.5));
 $64 = Math_fround($61 * Math_fround(0.5));
 HEAPF32[$m0>>2] = $62;
 $65 = (($m0) + 4|0);
 HEAPF32[$65>>2] = $63;
 $66 = (($m0) + 8|0);
 HEAPF32[$66>>2] = $64;
 $67 = Math_fround($9 + $21);
 $68 = Math_fround($14 + $24);
 $69 = Math_fround($19 + $27);
 $70 = Math_fround($67 * Math_fround(0.5));
 $71 = Math_fround($68 * Math_fround(0.5));
 $72 = Math_fround($69 * Math_fround(0.5));
 HEAPF32[$m1>>2] = $70;
 $73 = (($m1) + 4|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($m1) + 8|0);
 HEAPF32[$74>>2] = $72;
 $75 = Math_fround($21 + $8);
 $76 = Math_fround($24 + $12);
 $77 = Math_fround($27 + $17);
 $78 = Math_fround($75 * Math_fround(0.5));
 $79 = Math_fround($76 * Math_fround(0.5));
 $80 = Math_fround($77 * Math_fround(0.5));
 HEAPF32[$m2>>2] = $78;
 $81 = (($m2) + 4|0);
 HEAPF32[$81>>2] = $79;
 $82 = (($m2) + 8|0);
 HEAPF32[$82>>2] = $80;
 switch ($58|0) {
 case 7:  {
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$m0,$m2);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$m0,$v1,$m1);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$m2,$m1,$v2);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$m0,$m1,$m2);
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$m0,$m2);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$m0,$v1,$m2);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$m2,$v1,$v2);
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$m0,$v2);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$m0,$v1,$v2);
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$v1,$m2);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v1,$v2,$m2);
  STACKTOP = sp;return;
  break;
 }
 case 2:  {
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$v1,$m1);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$m1,$v2);
  STACKTOP = sp;return;
  break;
 }
 case 3:  {
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$m0,$m1);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$m1,$v2);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$m0,$v1,$m1);
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$v1,$m1);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$v0,$m1,$m2);
  __ZL18tessellateTriangleP10TessParamsRKN5physx6PxVec3ES4_S4_($tp,$m2,$m1,$v2);
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  $83 = (($tp) + 8|0);
  $84 = HEAP32[$83>>2]|0;
  HEAPF32[$0>>2] = $8;
  $85 = (($0) + 4|0);
  HEAPF32[$85>>2] = $12;
  $86 = (($0) + 8|0);
  HEAPF32[$86>>2] = $17;
  $87 = (($0) + 12|0);
  HEAPF32[$87>>2] = $9;
  $88 = (($0) + 16|0);
  HEAPF32[$88>>2] = $14;
  $89 = (($0) + 20|0);
  HEAPF32[$89>>2] = $19;
  $90 = (($0) + 24|0);
  HEAPF32[$90>>2] = $21;
  $91 = (($0) + 28|0);
  HEAPF32[$91>>2] = $24;
  $92 = (($0) + 32|0);
  HEAPF32[$92>>2] = $27;
  $93 = (($84) + 8|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = $94 & 2147483647;
  $96 = (($84) + 4|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = ($95>>>0)>($97>>>0);
  if ($98) {
   $99 = HEAP32[$84>>2]|0;
   $100 = (($99) + (($97*36)|0)|0);
   $101 = ($100|0)==(0|0);
   if (!($101)) {
    HEAPF32[$100>>2] = $8;
    $102 = ((($99) + (($97*36)|0)|0) + 4|0);
    HEAPF32[$102>>2] = $12;
    $103 = ((($99) + (($97*36)|0)|0) + 8|0);
    HEAPF32[$103>>2] = $17;
    $104 = ((($99) + (($97*36)|0)|0) + 12|0);
    HEAPF32[$104>>2] = $9;
    $105 = ((($99) + (($97*36)|0)|0) + 16|0);
    HEAPF32[$105>>2] = $14;
    $106 = ((($99) + (($97*36)|0)|0) + 20|0);
    HEAPF32[$106>>2] = $19;
    $107 = ((($99) + (($97*36)|0)|0) + 24|0);
    HEAPF32[$107>>2] = $21;
    $108 = ((($99) + (($97*36)|0)|0) + 28|0);
    HEAPF32[$108>>2] = $24;
    $109 = ((($99) + (($97*36)|0)|0) + 32|0);
    HEAPF32[$109>>2] = $27;
   }
   $110 = (($97) + 1)|0;
   HEAP32[$96>>2] = $110;
  } else {
   (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($84,$0)|0);
  }
  $111 = (($tp) + 12|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = (($tp) + 4|0);
  $114 = (($112) + 8|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = $115 & 2147483647;
  $117 = (($112) + 4|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ($116>>>0)>($118>>>0);
  if ($119) {
   $120 = HEAP32[$112>>2]|0;
   $121 = (($120) + ($118<<2)|0);
   $122 = ($121|0)==(0|0);
   if ($122) {
    $125 = $118;
   } else {
    $123 = HEAP32[$113>>2]|0;
    HEAP32[$121>>2] = $123;
    $$pre$i = HEAP32[$117>>2]|0;
    $125 = $$pre$i;
   }
   $124 = (($125) + 1)|0;
   HEAP32[$117>>2] = $124;
  } else {
   (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($112,$113)|0);
  }
  $126 = HEAP32[$tp>>2]|0;
  $127 = (($126) + 1)|0;
  HEAP32[$tp>>2] = $127;
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0;
 var $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*36)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 404880 : 404744;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,404664,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*36)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$03$i) + 4|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = (($$012$i) + 4|0);
    HEAPF32[$28>>2] = $27;
    $29 = (($$03$i) + 8|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = (($$012$i) + 8|0);
    HEAPF32[$31>>2] = $30;
    $32 = (($$03$i) + 12|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = (($$012$i) + 12|0);
    HEAPF32[$34>>2] = $33;
    $35 = (($$03$i) + 16|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = (($$012$i) + 16|0);
    HEAPF32[$37>>2] = $36;
    $38 = (($$03$i) + 20|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = (($$012$i) + 20|0);
    HEAPF32[$40>>2] = $39;
    $41 = (($$03$i) + 24|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = (($$012$i) + 24|0);
    HEAPF32[$43>>2] = $42;
    $44 = (($$03$i) + 28|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = (($$012$i) + 28|0);
    HEAPF32[$46>>2] = $45;
    $47 = (($$03$i) + 32|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = (($$012$i) + 32|0);
    HEAPF32[$49>>2] = $48;
   }
   $50 = (($$012$i) + 36|0);
   $51 = (($$03$i) + 36|0);
   $52 = ($50>>>0)<($20>>>0);
   if ($52) {
    $$012$i = $50;$$03$i = $51;
   } else {
    break;
   }
  }
 }
 $53 = ($20|0)==(0|0);
 if (!($53)) {
  $54 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$20>>2] = $54;
  $55 = (($a) + 4|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = ((($21) + (($19*36)|0)|0) + 4|0);
  HEAPF32[$57>>2] = $56;
  $58 = (($a) + 8|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($21) + (($19*36)|0)|0) + 8|0);
  HEAPF32[$60>>2] = $59;
  $61 = (($a) + 12|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = ((($21) + (($19*36)|0)|0) + 12|0);
  HEAPF32[$63>>2] = $62;
  $64 = (($a) + 16|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($21) + (($19*36)|0)|0) + 16|0);
  HEAPF32[$66>>2] = $65;
  $67 = (($a) + 20|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = ((($21) + (($19*36)|0)|0) + 20|0);
  HEAPF32[$69>>2] = $68;
  $70 = (($a) + 24|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = ((($21) + (($19*36)|0)|0) + 24|0);
  HEAPF32[$72>>2] = $71;
  $73 = (($a) + 28|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = ((($21) + (($19*36)|0)|0) + 28|0);
  HEAPF32[$75>>2] = $74;
  $76 = (($a) + 32|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = ((($21) + (($19*36)|0)|0) + 32|0);
  HEAPF32[$78>>2] = $77;
 }
 $79 = HEAP32[$0>>2]|0;
 $80 = ($79|0)>(-1);
 if (!($80)) {
  $88 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $87 = (($88) + 1)|0;
  HEAP32[$18>>2] = $87;
  $89 = (($21) + (($88*36)|0)|0);
  STACKTOP = sp;return ($89|0);
 }
 $81 = HEAP32[$this>>2]|0;
 $82 = ($81|0)==(0|0);
 if ($82) {
  $88 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $87 = (($88) + 1)|0;
  HEAP32[$18>>2] = $87;
  $89 = (($21) + (($88*36)|0)|0);
  STACKTOP = sp;return ($89|0);
 }
 $83 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($84) + 12|0);
 $86 = HEAP32[$85>>2]|0;
 FUNCTION_TABLE_vii[$86 & 4095]($83,$81);
 $$pre = HEAP32[$18>>2]|0;
 $88 = $$pre;
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $87 = (($88) + 1)|0;
 HEAP32[$18>>2] = $87;
 $89 = (($21) + (($88*36)|0)|0);
 STACKTOP = sp;return ($89|0);
}
function __ZL20createInvisibleWallsRKN5physx3Cct9CCTParamsERKNS_10PxTriangleERNS_6shdfnd5ArrayIS4_NS7_19ReflectionAllocatorIS4_EEEERNS8_IjNS9_IjEEEE($params,$currentTriangle,$worldTriangles,$triIndicesArray) {
 $params = $params|0;
 $currentTriangle = $currentTriangle|0;
 $worldTriangles = $worldTriangles|0;
 $triIndicesArray = $triIndicesArray|0;
 var $$0 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$1 = 0, $$pre$i$2 = 0, $$pre$i$3 = 0, $$pre$i$4 = 0, $$pre$i$5 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0;
 var $$pre28 = 0, $$pre29 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0);
 var $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0);
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0);
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0);
 var $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0);
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0;
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $tri0_1_0p = 0, $tri0p_1_1p = 0, $triIndex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tri0_1_0p = sp + 40|0;
 $tri0p_1_1p = sp;
 $triIndex = sp + 36|0;
 $0 = (($params) + 44|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == Math_fround(0.0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($currentTriangle) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$currentTriangle>>2]);
 $6 = Math_fround($4 - $5);
 $7 = (($currentTriangle) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($currentTriangle) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 - $10);
 $12 = (($currentTriangle) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($currentTriangle) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = (($currentTriangle) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 - $5);
 $20 = (($currentTriangle) + 28|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 - $10);
 $23 = (($currentTriangle) + 32|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 - $15);
 $26 = Math_fround($11 * $25);
 $27 = Math_fround($16 * $22);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($16 * $19);
 $30 = Math_fround($6 * $25);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround($6 * $22);
 $33 = Math_fround($11 * $19);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($28 * $28);
 $36 = Math_fround($31 * $31);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($34 * $34);
 $39 = Math_fround($38 + $37);
 $40 = (Math_fround(Math_sqrt((Math_fround($39)))));
 $41 = $40 > Math_fround(0.0);
 if ($41) {
  $42 = Math_fround(Math_fround(1.0) / $40);
  $43 = Math_fround($28 * $42);
  $44 = Math_fround($31 * $42);
  $45 = Math_fround($34 * $42);
  $51 = $43;$55 = $44;$60 = $45;
 } else {
  $51 = $28;$55 = $31;$60 = $34;
 }
 $46 = (($params) + 32|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($params) + 20|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($51 * $49);
 $52 = (($params) + 24|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($55 * $53);
 $56 = Math_fround($50 + $54);
 $57 = (($params) + 28|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($60 * $58);
 $61 = Math_fround($56 + $59);
 $62 = $61 >= Math_fround(0.0);
 $63 = $61 < $47;
 $or$cond = $62 & $63;
 if (!($or$cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $64 = Math_fround($1 * $49);
 $65 = Math_fround($1 * $53);
 $66 = Math_fround($1 * $58);
 $67 = Math_fround($64 + $5);
 $68 = Math_fround($65 + $10);
 $69 = Math_fround($66 + $15);
 $70 = Math_fround($64 + $4);
 $71 = Math_fround($65 + $8);
 $72 = Math_fround($66 + $13);
 $73 = Math_fround($64 + $18);
 $74 = Math_fround($65 + $21);
 $75 = Math_fround($66 + $24);
 HEAPF32[$tri0_1_0p>>2] = $5;
 $76 = (($tri0_1_0p) + 4|0);
 HEAPF32[$76>>2] = $10;
 $77 = (($tri0_1_0p) + 8|0);
 HEAPF32[$77>>2] = $15;
 $78 = (($tri0_1_0p) + 12|0);
 HEAPF32[$78>>2] = $4;
 $79 = (($tri0_1_0p) + 16|0);
 HEAPF32[$79>>2] = $8;
 $80 = (($tri0_1_0p) + 20|0);
 HEAPF32[$80>>2] = $13;
 $81 = (($tri0_1_0p) + 24|0);
 HEAPF32[$81>>2] = $67;
 $82 = (($tri0_1_0p) + 28|0);
 HEAPF32[$82>>2] = $68;
 $83 = (($tri0_1_0p) + 32|0);
 HEAPF32[$83>>2] = $69;
 $84 = (($worldTriangles) + 8|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = $85 & 2147483647;
 $87 = (($worldTriangles) + 4|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($86>>>0)>($88>>>0);
 if ($89) {
  $90 = HEAP32[$worldTriangles>>2]|0;
  $91 = (($90) + (($88*36)|0)|0);
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   HEAPF32[$91>>2] = $5;
   $93 = ((($90) + (($88*36)|0)|0) + 4|0);
   HEAPF32[$93>>2] = $10;
   $94 = ((($90) + (($88*36)|0)|0) + 8|0);
   HEAPF32[$94>>2] = $15;
   $95 = ((($90) + (($88*36)|0)|0) + 12|0);
   HEAPF32[$95>>2] = $4;
   $96 = ((($90) + (($88*36)|0)|0) + 16|0);
   HEAPF32[$96>>2] = $8;
   $97 = ((($90) + (($88*36)|0)|0) + 20|0);
   HEAPF32[$97>>2] = $13;
   $98 = ((($90) + (($88*36)|0)|0) + 24|0);
   HEAPF32[$98>>2] = $67;
   $99 = ((($90) + (($88*36)|0)|0) + 28|0);
   HEAPF32[$99>>2] = $68;
   $100 = ((($90) + (($88*36)|0)|0) + 32|0);
   HEAPF32[$100>>2] = $69;
  }
  $101 = (($88) + 1)|0;
  HEAP32[$87>>2] = $101;
  $114 = $85;$116 = $101;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($worldTriangles,$tri0_1_0p)|0);
  $$pre = HEAP32[$84>>2]|0;
  $$pre16 = HEAP32[$87>>2]|0;
  $114 = $$pre;$116 = $$pre16;
 }
 HEAPF32[$tri0p_1_1p>>2] = $67;
 $102 = (($tri0p_1_1p) + 4|0);
 HEAPF32[$102>>2] = $68;
 $103 = (($tri0p_1_1p) + 8|0);
 HEAPF32[$103>>2] = $69;
 $104 = Math_fround(HEAPF32[$3>>2]);
 $105 = (($tri0p_1_1p) + 12|0);
 HEAPF32[$105>>2] = $104;
 $106 = Math_fround(HEAPF32[$7>>2]);
 $107 = (($tri0p_1_1p) + 16|0);
 HEAPF32[$107>>2] = $106;
 $108 = Math_fround(HEAPF32[$12>>2]);
 $109 = (($tri0p_1_1p) + 20|0);
 HEAPF32[$109>>2] = $108;
 $110 = (($tri0p_1_1p) + 24|0);
 HEAPF32[$110>>2] = $70;
 $111 = (($tri0p_1_1p) + 28|0);
 HEAPF32[$111>>2] = $71;
 $112 = (($tri0p_1_1p) + 32|0);
 HEAPF32[$112>>2] = $72;
 $113 = $114 & 2147483647;
 $115 = ($113>>>0)>($116>>>0);
 if ($115) {
  $117 = HEAP32[$worldTriangles>>2]|0;
  $118 = (($117) + (($116*36)|0)|0);
  $119 = ($118|0)==(0|0);
  if (!($119)) {
   HEAPF32[$118>>2] = $67;
   $120 = ((($117) + (($116*36)|0)|0) + 4|0);
   HEAPF32[$120>>2] = $68;
   $121 = ((($117) + (($116*36)|0)|0) + 8|0);
   HEAPF32[$121>>2] = $69;
   $122 = ((($117) + (($116*36)|0)|0) + 12|0);
   HEAPF32[$122>>2] = $104;
   $123 = ((($117) + (($116*36)|0)|0) + 16|0);
   HEAPF32[$123>>2] = $106;
   $124 = ((($117) + (($116*36)|0)|0) + 20|0);
   HEAPF32[$124>>2] = $108;
   $125 = ((($117) + (($116*36)|0)|0) + 24|0);
   HEAPF32[$125>>2] = $70;
   $126 = ((($117) + (($116*36)|0)|0) + 28|0);
   HEAPF32[$126>>2] = $71;
   $127 = ((($117) + (($116*36)|0)|0) + 32|0);
   HEAPF32[$127>>2] = $72;
  }
  $128 = (($116) + 1)|0;
  HEAP32[$87>>2] = $128;
  $141 = $114;$143 = $128;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($worldTriangles,$tri0p_1_1p)|0);
  $$pre17 = HEAP32[$84>>2]|0;
  $$pre18 = HEAP32[$87>>2]|0;
  $141 = $$pre17;$143 = $$pre18;
 }
 HEAPF32[$tri0_1_0p>>2] = $70;
 $129 = (($tri0_1_0p) + 4|0);
 HEAPF32[$129>>2] = $71;
 $130 = (($tri0_1_0p) + 8|0);
 HEAPF32[$130>>2] = $72;
 $131 = Math_fround(HEAPF32[$3>>2]);
 $132 = (($tri0_1_0p) + 12|0);
 HEAPF32[$132>>2] = $131;
 $133 = Math_fround(HEAPF32[$7>>2]);
 $134 = (($tri0_1_0p) + 16|0);
 HEAPF32[$134>>2] = $133;
 $135 = Math_fround(HEAPF32[$12>>2]);
 $136 = (($tri0_1_0p) + 20|0);
 HEAPF32[$136>>2] = $135;
 $137 = (($tri0_1_0p) + 24|0);
 HEAPF32[$137>>2] = $73;
 $138 = (($tri0_1_0p) + 28|0);
 HEAPF32[$138>>2] = $74;
 $139 = (($tri0_1_0p) + 32|0);
 HEAPF32[$139>>2] = $75;
 $140 = $141 & 2147483647;
 $142 = ($140>>>0)>($143>>>0);
 if ($142) {
  $144 = HEAP32[$worldTriangles>>2]|0;
  $145 = (($144) + (($143*36)|0)|0);
  $146 = ($145|0)==(0|0);
  if (!($146)) {
   HEAPF32[$145>>2] = $70;
   $147 = ((($144) + (($143*36)|0)|0) + 4|0);
   HEAPF32[$147>>2] = $71;
   $148 = ((($144) + (($143*36)|0)|0) + 8|0);
   HEAPF32[$148>>2] = $72;
   $149 = ((($144) + (($143*36)|0)|0) + 12|0);
   HEAPF32[$149>>2] = $131;
   $150 = ((($144) + (($143*36)|0)|0) + 16|0);
   HEAPF32[$150>>2] = $133;
   $151 = ((($144) + (($143*36)|0)|0) + 20|0);
   HEAPF32[$151>>2] = $135;
   $152 = ((($144) + (($143*36)|0)|0) + 24|0);
   HEAPF32[$152>>2] = $73;
   $153 = ((($144) + (($143*36)|0)|0) + 28|0);
   HEAPF32[$153>>2] = $74;
   $154 = ((($144) + (($143*36)|0)|0) + 32|0);
   HEAPF32[$154>>2] = $75;
  }
  $155 = (($143) + 1)|0;
  HEAP32[$87>>2] = $155;
  $171 = $141;$173 = $155;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($worldTriangles,$tri0_1_0p)|0);
  $$pre19 = HEAP32[$84>>2]|0;
  $$pre20 = HEAP32[$87>>2]|0;
  $171 = $$pre19;$173 = $$pre20;
 }
 HEAPF32[$tri0p_1_1p>>2] = $73;
 $156 = (($tri0p_1_1p) + 4|0);
 HEAPF32[$156>>2] = $74;
 $157 = (($tri0p_1_1p) + 8|0);
 HEAPF32[$157>>2] = $75;
 $158 = Math_fround(HEAPF32[$3>>2]);
 $159 = (($tri0p_1_1p) + 12|0);
 HEAPF32[$159>>2] = $158;
 $160 = Math_fround(HEAPF32[$7>>2]);
 $161 = (($tri0p_1_1p) + 16|0);
 HEAPF32[$161>>2] = $160;
 $162 = Math_fround(HEAPF32[$12>>2]);
 $163 = (($tri0p_1_1p) + 20|0);
 HEAPF32[$163>>2] = $162;
 $164 = Math_fround(HEAPF32[$17>>2]);
 $165 = (($tri0p_1_1p) + 24|0);
 HEAPF32[$165>>2] = $164;
 $166 = Math_fround(HEAPF32[$20>>2]);
 $167 = (($tri0p_1_1p) + 28|0);
 HEAPF32[$167>>2] = $166;
 $168 = Math_fround(HEAPF32[$23>>2]);
 $169 = (($tri0p_1_1p) + 32|0);
 HEAPF32[$169>>2] = $168;
 $170 = $171 & 2147483647;
 $172 = ($170>>>0)>($173>>>0);
 if ($172) {
  $174 = HEAP32[$worldTriangles>>2]|0;
  $175 = (($174) + (($173*36)|0)|0);
  $176 = ($175|0)==(0|0);
  if (!($176)) {
   HEAPF32[$175>>2] = $73;
   $177 = ((($174) + (($173*36)|0)|0) + 4|0);
   HEAPF32[$177>>2] = $74;
   $178 = ((($174) + (($173*36)|0)|0) + 8|0);
   HEAPF32[$178>>2] = $75;
   $179 = ((($174) + (($173*36)|0)|0) + 12|0);
   HEAPF32[$179>>2] = $158;
   $180 = ((($174) + (($173*36)|0)|0) + 16|0);
   HEAPF32[$180>>2] = $160;
   $181 = ((($174) + (($173*36)|0)|0) + 20|0);
   HEAPF32[$181>>2] = $162;
   $182 = ((($174) + (($173*36)|0)|0) + 24|0);
   HEAPF32[$182>>2] = $164;
   $183 = ((($174) + (($173*36)|0)|0) + 28|0);
   HEAPF32[$183>>2] = $166;
   $184 = ((($174) + (($173*36)|0)|0) + 32|0);
   HEAPF32[$184>>2] = $168;
  }
  $185 = (($173) + 1)|0;
  HEAP32[$87>>2] = $185;
  $201 = $171;$203 = $185;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($worldTriangles,$tri0p_1_1p)|0);
  $$pre21 = HEAP32[$84>>2]|0;
  $$pre22 = HEAP32[$87>>2]|0;
  $201 = $$pre21;$203 = $$pre22;
 }
 HEAPF32[$tri0_1_0p>>2] = $67;
 $186 = (($tri0_1_0p) + 4|0);
 HEAPF32[$186>>2] = $68;
 $187 = (($tri0_1_0p) + 8|0);
 HEAPF32[$187>>2] = $69;
 $188 = Math_fround(HEAPF32[$17>>2]);
 $189 = (($tri0_1_0p) + 12|0);
 HEAPF32[$189>>2] = $188;
 $190 = Math_fround(HEAPF32[$20>>2]);
 $191 = (($tri0_1_0p) + 16|0);
 HEAPF32[$191>>2] = $190;
 $192 = Math_fround(HEAPF32[$23>>2]);
 $193 = (($tri0_1_0p) + 20|0);
 HEAPF32[$193>>2] = $192;
 $194 = Math_fround(HEAPF32[$currentTriangle>>2]);
 $195 = (($tri0_1_0p) + 24|0);
 HEAPF32[$195>>2] = $194;
 $196 = Math_fround(HEAPF32[$9>>2]);
 $197 = (($tri0_1_0p) + 28|0);
 HEAPF32[$197>>2] = $196;
 $198 = Math_fround(HEAPF32[$14>>2]);
 $199 = (($tri0_1_0p) + 32|0);
 HEAPF32[$199>>2] = $198;
 $200 = $201 & 2147483647;
 $202 = ($200>>>0)>($203>>>0);
 if ($202) {
  $204 = HEAP32[$worldTriangles>>2]|0;
  $205 = (($204) + (($203*36)|0)|0);
  $206 = ($205|0)==(0|0);
  if (!($206)) {
   HEAPF32[$205>>2] = $67;
   $207 = ((($204) + (($203*36)|0)|0) + 4|0);
   HEAPF32[$207>>2] = $68;
   $208 = ((($204) + (($203*36)|0)|0) + 8|0);
   HEAPF32[$208>>2] = $69;
   $209 = ((($204) + (($203*36)|0)|0) + 12|0);
   HEAPF32[$209>>2] = $188;
   $210 = ((($204) + (($203*36)|0)|0) + 16|0);
   HEAPF32[$210>>2] = $190;
   $211 = ((($204) + (($203*36)|0)|0) + 20|0);
   HEAPF32[$211>>2] = $192;
   $212 = ((($204) + (($203*36)|0)|0) + 24|0);
   HEAPF32[$212>>2] = $194;
   $213 = ((($204) + (($203*36)|0)|0) + 28|0);
   HEAPF32[$213>>2] = $196;
   $214 = ((($204) + (($203*36)|0)|0) + 32|0);
   HEAPF32[$214>>2] = $198;
  }
  $215 = (($203) + 1)|0;
  HEAP32[$87>>2] = $215;
  $228 = $201;$230 = $215;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($worldTriangles,$tri0_1_0p)|0);
  $$pre23 = HEAP32[$84>>2]|0;
  $$pre24 = HEAP32[$87>>2]|0;
  $228 = $$pre23;$230 = $$pre24;
 }
 HEAPF32[$tri0p_1_1p>>2] = $67;
 $216 = (($tri0p_1_1p) + 4|0);
 HEAPF32[$216>>2] = $68;
 $217 = (($tri0p_1_1p) + 8|0);
 HEAPF32[$217>>2] = $69;
 $218 = (($tri0p_1_1p) + 12|0);
 HEAPF32[$218>>2] = $73;
 $219 = (($tri0p_1_1p) + 16|0);
 HEAPF32[$219>>2] = $74;
 $220 = (($tri0p_1_1p) + 20|0);
 HEAPF32[$220>>2] = $75;
 $221 = Math_fround(HEAPF32[$17>>2]);
 $222 = (($tri0p_1_1p) + 24|0);
 HEAPF32[$222>>2] = $221;
 $223 = Math_fround(HEAPF32[$20>>2]);
 $224 = (($tri0p_1_1p) + 28|0);
 HEAPF32[$224>>2] = $223;
 $225 = Math_fround(HEAPF32[$23>>2]);
 $226 = (($tri0p_1_1p) + 32|0);
 HEAPF32[$226>>2] = $225;
 $227 = $228 & 2147483647;
 $229 = ($227>>>0)>($230>>>0);
 if ($229) {
  $231 = HEAP32[$worldTriangles>>2]|0;
  $232 = (($231) + (($230*36)|0)|0);
  $233 = ($232|0)==(0|0);
  if (!($233)) {
   HEAPF32[$232>>2] = $67;
   $234 = ((($231) + (($230*36)|0)|0) + 4|0);
   HEAPF32[$234>>2] = $68;
   $235 = ((($231) + (($230*36)|0)|0) + 8|0);
   HEAPF32[$235>>2] = $69;
   $236 = ((($231) + (($230*36)|0)|0) + 12|0);
   HEAPF32[$236>>2] = $73;
   $237 = ((($231) + (($230*36)|0)|0) + 16|0);
   HEAPF32[$237>>2] = $74;
   $238 = ((($231) + (($230*36)|0)|0) + 20|0);
   HEAPF32[$238>>2] = $75;
   $239 = ((($231) + (($230*36)|0)|0) + 24|0);
   HEAPF32[$239>>2] = $221;
   $240 = ((($231) + (($230*36)|0)|0) + 28|0);
   HEAPF32[$240>>2] = $223;
   $241 = ((($231) + (($230*36)|0)|0) + 32|0);
   HEAPF32[$241>>2] = $225;
  }
  $242 = (($230) + 1)|0;
  HEAP32[$87>>2] = $242;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_10PxTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($worldTriangles,$tri0p_1_1p)|0);
 }
 HEAP32[$triIndex>>2] = -1;
 $243 = (($triIndicesArray) + 8|0);
 $244 = (($triIndicesArray) + 4|0);
 $245 = HEAP32[$243>>2]|0;
 $246 = $245 & 2147483647;
 $247 = HEAP32[$244>>2]|0;
 $248 = ($246>>>0)>($247>>>0);
 if ($248) {
  $249 = HEAP32[$triIndicesArray>>2]|0;
  $250 = (($249) + ($247<<2)|0);
  $251 = ($250|0)==(0|0);
  if ($251) {
   $253 = $247;
  } else {
   HEAP32[$250>>2] = -1;
   $$pre$i = HEAP32[$244>>2]|0;
   $253 = $$pre$i;
  }
  $252 = (($253) + 1)|0;
  HEAP32[$244>>2] = $252;
  $257 = $252;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triIndex)|0);
  $$pre25 = HEAP32[$244>>2]|0;
  $257 = $$pre25;
 }
 $254 = HEAP32[$243>>2]|0;
 $255 = $254 & 2147483647;
 $256 = ($255>>>0)>($257>>>0);
 if ($256) {
  $258 = HEAP32[$triIndicesArray>>2]|0;
  $259 = (($258) + ($257<<2)|0);
  $260 = ($259|0)==(0|0);
  if ($260) {
   $263 = $257;
  } else {
   $261 = HEAP32[$triIndex>>2]|0;
   HEAP32[$259>>2] = $261;
   $$pre$i$1 = HEAP32[$244>>2]|0;
   $263 = $$pre$i$1;
  }
  $262 = (($263) + 1)|0;
  HEAP32[$244>>2] = $262;
  $267 = $262;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triIndex)|0);
  $$pre26 = HEAP32[$244>>2]|0;
  $267 = $$pre26;
 }
 $264 = HEAP32[$243>>2]|0;
 $265 = $264 & 2147483647;
 $266 = ($265>>>0)>($267>>>0);
 if ($266) {
  $268 = HEAP32[$triIndicesArray>>2]|0;
  $269 = (($268) + ($267<<2)|0);
  $270 = ($269|0)==(0|0);
  if ($270) {
   $273 = $267;
  } else {
   $271 = HEAP32[$triIndex>>2]|0;
   HEAP32[$269>>2] = $271;
   $$pre$i$2 = HEAP32[$244>>2]|0;
   $273 = $$pre$i$2;
  }
  $272 = (($273) + 1)|0;
  HEAP32[$244>>2] = $272;
  $277 = $272;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triIndex)|0);
  $$pre27 = HEAP32[$244>>2]|0;
  $277 = $$pre27;
 }
 $274 = HEAP32[$243>>2]|0;
 $275 = $274 & 2147483647;
 $276 = ($275>>>0)>($277>>>0);
 if ($276) {
  $278 = HEAP32[$triIndicesArray>>2]|0;
  $279 = (($278) + ($277<<2)|0);
  $280 = ($279|0)==(0|0);
  if ($280) {
   $283 = $277;
  } else {
   $281 = HEAP32[$triIndex>>2]|0;
   HEAP32[$279>>2] = $281;
   $$pre$i$3 = HEAP32[$244>>2]|0;
   $283 = $$pre$i$3;
  }
  $282 = (($283) + 1)|0;
  HEAP32[$244>>2] = $282;
  $287 = $282;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triIndex)|0);
  $$pre28 = HEAP32[$244>>2]|0;
  $287 = $$pre28;
 }
 $284 = HEAP32[$243>>2]|0;
 $285 = $284 & 2147483647;
 $286 = ($285>>>0)>($287>>>0);
 if ($286) {
  $288 = HEAP32[$triIndicesArray>>2]|0;
  $289 = (($288) + ($287<<2)|0);
  $290 = ($289|0)==(0|0);
  if ($290) {
   $293 = $287;
  } else {
   $291 = HEAP32[$triIndex>>2]|0;
   HEAP32[$289>>2] = $291;
   $$pre$i$4 = HEAP32[$244>>2]|0;
   $293 = $$pre$i$4;
  }
  $292 = (($293) + 1)|0;
  HEAP32[$244>>2] = $292;
  $297 = $292;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triIndex)|0);
  $$pre29 = HEAP32[$244>>2]|0;
  $297 = $$pre29;
 }
 $294 = HEAP32[$243>>2]|0;
 $295 = $294 & 2147483647;
 $296 = ($295>>>0)>($297>>>0);
 if (!($296)) {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($triIndicesArray,$triIndex)|0);
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $298 = HEAP32[$triIndicesArray>>2]|0;
 $299 = (($298) + ($297<<2)|0);
 $300 = ($299|0)==(0|0);
 if ($300) {
  $303 = $297;
 } else {
  $301 = HEAP32[$triIndex>>2]|0;
  HEAP32[$299>>2] = $301;
  $$pre$i$5 = HEAP32[$244>>2]|0;
  $303 = $$pre$i$5;
 }
 $302 = (($303) + 1)|0;
 HEAP32[$244>>2] = $302;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Cct26CharacterControllerManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx3Cct26CharacterControllerManagerD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManagerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i3 = 0, $or$cond$i$i4 = 0, $or$cond$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((405136 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
  HEAP32[$0>>2] = 0;
 }
 $6 = (($this) + 124|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8|0)!=(0);
 $10 = ($7|0)>(-1);
 $or$cond$i$i = $9 & $10;
 if ($or$cond$i$i) {
  $11 = (($this) + 116|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vii[$17 & 4095]($14,$12);
  }
 }
 $18 = (($this) + 76|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($18,$19);
 }
 $21 = (($this) + 72|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 & 2147483647;
 $24 = ($23|0)!=(0);
 $25 = ($22|0)>(-1);
 $or$cond$i$i1 = $24 & $25;
 if ($or$cond$i$i1) {
  $26 = (($this) + 64|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if (!($28)) {
   $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
  }
 }
 $33 = (($this) + 60|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 2147483647;
 $36 = ($35|0)!=(0);
 $37 = ($34|0)>(-1);
 $or$cond$i$i2 = $36 & $37;
 if ($or$cond$i$i2) {
  $38 = (($this) + 52|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   $41 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 12|0);
   $44 = HEAP32[$43>>2]|0;
   FUNCTION_TABLE_vii[$44 & 4095]($41,$39);
  }
 }
 $45 = (($this) + 48|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 & 2147483647;
 $48 = ($47|0)!=(0);
 $49 = ($46|0)>(-1);
 $or$cond$i$i3 = $48 & $49;
 if ($or$cond$i$i3) {
  $50 = (($this) + 40|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0|0);
  if (!($52)) {
   $53 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 12|0);
   $56 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vii[$56 & 4095]($53,$51);
  }
 }
 $57 = (($this) + 36|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58 & 2147483647;
 $60 = ($59|0)!=(0);
 $61 = ($58|0)>(-1);
 $or$cond$i$i4 = $60 & $61;
 if ($or$cond$i$i4) {
  $62 = (($this) + 28|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($63|0)==(0|0);
  if (!($64)) {
   $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($66) + 12|0);
   $68 = HEAP32[$67>>2]|0;
   FUNCTION_TABLE_vii[$68 & 4095]($65,$63);
  }
 }
 $69 = (($this) + 24|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = $70 & 2147483647;
 $72 = ($71|0)!=(0);
 $73 = ($70|0)>(-1);
 $or$cond$i$i5 = $72 & $73;
 if (!($or$cond$i$i5)) {
  STACKTOP = sp;return;
 }
 $74 = (($this) + 16|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0|0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 12|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($77,$75);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManager7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  while(1) {
   $11 = HEAP32[$this>>2]|0;
   $12 = (($11) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_iii[$13 & 4095]($this,0)|0);
   __ZN5physx3Cct26CharacterControllerManager17releaseControllerERNS_12PxControllerE($this,$14);
   $15 = HEAP32[$this>>2]|0;
   $16 = (($15) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (FUNCTION_TABLE_ii[$17 & 4095]($this)|0);
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   }
  }
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($this)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($this) + 116|0);
  while(1) {
   $20 = HEAP32[$10>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_vi[$24 & 4095]($21);
   $25 = HEAP32[$this>>2]|0;
   $26 = (($25) + 36|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (FUNCTION_TABLE_ii[$27 & 4095]($this)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    break;
   }
  }
 }
 $30 = ($this|0)==(0|0);
 if ($30) {
  __ZN5physx6shdfnd10Foundation11decRefCountEv();
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$this>>2]|0;
 $32 = (($31) + 76|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vi[$33 & 4095]($this);
 __ZN5physx6shdfnd10Foundation11decRefCountEv();
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManager17releaseControllerERNS_12PxControllerE($this,$controller) {
 $this = $this|0;
 $controller = $controller|0;
 var $$pr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $i$05 = 0, $or$cond = 0, $ptr$02$i$i = 0, $shape = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $shape = sp;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = (($this) + 64|0);
   $i$05 = 0;
   while(1) {
    $7 = HEAP32[$3>>2]|0;
    $8 = (($7) + ($i$05<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + 20|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
    $14 = ($13|0)==($controller|0);
    $5 = (($i$05) + 1)|0;
    $6 = HEAP32[$0>>2]|0;
    if ($14) {
     break;
    }
    $4 = ($5>>>0)<($6>>>0);
    if ($4) {
     $i$05 = $5;
    } else {
     break L1;
    }
   }
   $15 = (($6) + -1)|0;
   HEAP32[$0>>2] = $15;
   $16 = HEAP32[$3>>2]|0;
   $17 = (($16) + ($15<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($16) + ($i$05<<2)|0);
   HEAP32[$19>>2] = $18;
  }
 } while(0);
 HEAP32[$shape>>2] = 0;
 $20 = HEAP32[$controller>>2]|0;
 $21 = (($20) + 36|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_ii[$22 & 4095]($controller)|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 108|0);
 $26 = HEAP32[$25>>2]|0;
 (FUNCTION_TABLE_iiiii[$26 & 511]($23,$shape,1,0)|0);
 $27 = (($this) + 96|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0);
 L8: do {
  if (!($29)) {
   $30 = HEAP32[$shape>>2]|0;
   $31 = $30;
   $32 = $31 << 15;
   $33 = $32 ^ -1;
   $34 = (($31) + ($33))|0;
   $35 = $34 >>> 10;
   $36 = $35 ^ $34;
   $37 = ($36*9)|0;
   $38 = $37 >>> 6;
   $39 = $38 ^ $37;
   $40 = $39 << 11;
   $41 = $40 ^ -1;
   $42 = (($39) + ($41))|0;
   $43 = $42 >>> 16;
   $44 = $43 ^ $42;
   $45 = (($28) + -1)|0;
   $46 = $44 & $45;
   $47 = (($this) + 88|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + ($46<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(-1);
   if (!($51)) {
    $52 = (($this) + 80|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($this) + 84|0);
    $$pr$i$i = $50;$ptr$02$i$i = $49;
    while(1) {
     $55 = (($53) + ($$pr$i$i<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($56|0)==($30|0);
     if ($57) {
      break;
     }
     $58 = HEAP32[$54>>2]|0;
     $59 = (($58) + ($$pr$i$i<<2)|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==(-1);
     if ($61) {
      break L8;
     } else {
      $$pr$i$i = $60;$ptr$02$i$i = $59;
     }
    }
    $62 = ($$pr$i$i|0)==(-1);
    if (!($62)) {
     $63 = HEAP32[$54>>2]|0;
     $64 = (($63) + ($$pr$i$i<<2)|0);
     $65 = HEAP32[$64>>2]|0;
     HEAP32[$ptr$02$i$i>>2] = $65;
     $66 = (($this) + 112|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($67) + -1)|0;
     HEAP32[$66>>2] = $68;
     $69 = (($this) + 108|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($70) + 1)|0;
     HEAP32[$69>>2] = $71;
     $72 = (($this) + 104|0);
     $73 = HEAP32[$72>>2]|0;
     HEAP32[$64>>2] = $73;
     HEAP32[$72>>2] = $$pr$i$i;
    }
   }
  }
 } while(0);
 $74 = HEAP32[$controller>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (FUNCTION_TABLE_ii[$76 & 4095]($controller)|0);
 $78 = ($77|0)==(1);
 if ($78) {
  $79 = ($controller|0)==(0|0);
  if ($79) {
   STACKTOP = sp;return;
  }
  $80 = HEAP32[$controller>>2]|0;
  $81 = (($80) + 4|0);
  $82 = HEAP32[$81>>2]|0;
  FUNCTION_TABLE_vi[$82 & 4095]($controller);
  STACKTOP = sp;return;
 } else {
  $83 = HEAP32[$controller>>2]|0;
  $84 = (($83) + 8|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (FUNCTION_TABLE_ii[$85 & 4095]($controller)|0);
  $87 = ($86|0)!=(0);
  $88 = ($controller|0)==(0|0);
  $or$cond = $87 | $88;
  if ($or$cond) {
   STACKTOP = sp;return;
  }
  $89 = HEAP32[$controller>>2]|0;
  $90 = (($89) + 4|0);
  $91 = HEAP32[$90>>2]|0;
  FUNCTION_TABLE_vi[$91 & 4095]($controller);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx3Cct26CharacterControllerManager8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct26CharacterControllerManager15getRenderBufferEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $14 = $1;
  STACKTOP = sp;return ($14|0);
 }
 $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__Z15PxGetFoundationv()|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $$$i$i$i = $11 ? 406824 : 405464;
 $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,64,$$$i$i$i,405224,92)|0);
 HEAP32[$12>>2] = ((407136 + 8|0));
 $13 = (($12) + 4|0);
 dest=$13+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$0>>2] = $12;
 $14 = $12;
 STACKTOP = sp;return ($14|0);
}
function __ZN5physx3Cct26CharacterControllerManager22setDebugRenderingFlagsENS_7PxFlagsINS_27PxControllerDebugRenderFlag4EnumEjEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$flags>>2]|0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = $0;
 $2 = HEAP32[$flags>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$9 & 4095]($5);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct26CharacterControllerManager16getNbControllersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct26CharacterControllerManager14getControllersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct26CharacterControllerManager13getControllerEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($index>>>0);
 if ($2) {
  $4 = (($this) + 64|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($index<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,4,405224,125,405336,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx3Cct26CharacterControllerManager16createControllerERKNS_16PxControllerDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$0 = 0, $$pre = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $exists$i = 0;
 var $newController = 0, $or$cond$i = 0, $shape = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp + 8|0;
 $newController = sp;
 $shape = sp + 4|0;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($desc)|0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$newController>>2] = 0;
 $4 = (($desc) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 if ((($5|0) == 0)) {
  $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__Z15PxGetFoundationv()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
  $$$i$i$i = $14 ? 406696 : 405464;
  $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,512,$$$i$i$i,405224,143)|0);
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 28|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_ii[$20 & 4095]($17)|0);
  $22 = HEAP32[$16>>2]|0;
  __ZN5physx3Cct13BoxControllerC2ERKNS_16PxControllerDescERNS_9PxPhysicsEPNS_7PxSceneE($15,$desc,$21,$22);
  $23 = ($15|0)==(0|0);
  if ($23) {
   $72 = 0;
  } else {
   $24 = (($15) + 8|0);
   $72 = $24;
  }
  $$sink = $15;$45 = $72;$storemerge = $72;
 } else if ((($5|0) == 1)) {
  $25 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (__Z15PxGetFoundationv()|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 24|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
  $$$i$i$i1 = $33 ? 406560 : 405464;
  $34 = (FUNCTION_TABLE_iiiiii[$28 & 255]($25,512,$$$i$i$i1,405224,149)|0);
  $35 = (($this) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 28|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (FUNCTION_TABLE_ii[$39 & 4095]($36)|0);
  $41 = HEAP32[$35>>2]|0;
  __ZN5physx3Cct17CapsuleControllerC2ERKNS_16PxControllerDescERNS_9PxPhysicsEPNS_7PxSceneE($34,$desc,$40,$41);
  $42 = ($34|0)==(0|0);
  if ($42) {
   $73 = 0;
  } else {
   $43 = (($34) + 8|0);
   $73 = $43;
  }
  $$sink = $34;$45 = $73;$storemerge = $73;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$newController>>2] = $storemerge;
 $44 = ($45|0)==(0|0);
 if ($44) {
  $$0 = $$sink;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = (($this) + 64|0);
 $47 = (($this) + 72|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 & 2147483647;
 $50 = (($this) + 68|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($49>>>0)>($51>>>0);
 if ($52) {
  $53 = HEAP32[$46>>2]|0;
  $54 = (($53) + ($51<<2)|0);
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   HEAP32[$54>>2] = $45;
  }
  $56 = (($51) + 1)|0;
  HEAP32[$50>>2] = $56;
  $58 = $45;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_3Cct10ControllerENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($46,$newController)|0);
  $$pre = HEAP32[$newController>>2]|0;
  $58 = $$pre;
 }
 $57 = (($58) + 464|0);
 HEAP32[$57>>2] = $this;
 HEAP32[$shape>>2] = 0;
 $59 = HEAP32[$$sink>>2]|0;
 $60 = (($59) + 36|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (FUNCTION_TABLE_ii[$61 & 4095]($$sink)|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 108|0);
 $65 = HEAP32[$64>>2]|0;
 (FUNCTION_TABLE_iiiii[$65 & 511]($62,$shape,1,0)|0);
 $66 = (($this) + 76|0);
 $67 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($66,$shape,$exists$i)|0);
 $68 = HEAP8[$exists$i>>0]|0;
 $69 = ($68<<24>>24)!=(0);
 $70 = ($67|0)==(0|0);
 $or$cond$i = $69 | $70;
 if ($or$cond$i) {
  $$0 = $$sink;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = HEAP32[$shape>>2]|0;
 HEAP32[$67>>2] = $71;
 $$0 = $$sink;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Cct26CharacterControllerManager16purgeControllersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 64|0);
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
  __ZN5physx3Cct26CharacterControllerManager17releaseControllerERNS_12PxControllerE($this,$9);
  $10 = HEAP32[$0>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct26CharacterControllerManager21getNbObstacleContextsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct26CharacterControllerManager18getObstacleContextEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($index>>>0);
 if ($2) {
  $4 = (($this) + 116|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($index<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,4,405224,215,405400,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx3Cct26CharacterControllerManager21createObstacleContextEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oc = sp;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 406216 : 405464;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,60,$$$i$i$i,405224,225)|0);
 __ZN5physx3Cct15ObstacleContextC2ERNS0_26CharacterControllerManagerE($9,$this);
 HEAP32[$oc>>2] = $9;
 $10 = (($this) + 116|0);
 $11 = (($this) + 124|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2147483647;
 $14 = (($this) + 120|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if (!($16)) {
  (__ZN5physx6shdfnd5ArrayIPNS_3Cct15ObstacleContextENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($10,$oc)|0);
  $$pre = HEAP32[$oc>>2]|0;
  $21 = $$pre;
  STACKTOP = sp;return ($21|0);
 }
 $17 = HEAP32[$10>>2]|0;
 $18 = (($17) + ($15<<2)|0);
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  HEAP32[$18>>2] = $9;
 }
 $20 = (($15) + 1)|0;
 HEAP32[$14>>2] = $20;
 $21 = $9;
 STACKTOP = sp;return ($21|0);
}
function __ZN5physx3Cct26CharacterControllerManager22releaseObstacleContextERNS0_15ObstacleContextE($this,$oc) {
 $this = $this|0;
 $oc = $oc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i = 0;
 var $index$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 116|0);
  $4 = HEAP32[$3>>2]|0;
  $index$01$i = 0;
  while(1) {
   $7 = (($4) + ($index$01$i<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==($oc|0);
   $6 = (($index$01$i) + 1)|0;
   if ($9) {
    $index$0$lcssa$i = $index$01$i;
    break;
   }
   $5 = ($6>>>0)<($1>>>0);
   if ($5) {
    $index$01$i = $6;
   } else {
    $index$0$lcssa$i = $6;
    break;
   }
  }
  $10 = ($index$0$lcssa$i|0)==($1|0);
  if (!($10)) {
   $11 = (($1) + -1)|0;
   HEAP32[$0>>2] = $11;
   $12 = (($4) + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($4) + ($index$0$lcssa$i<<2)|0);
   HEAP32[$14>>2] = $13;
  }
 }
 $15 = ($oc|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$oc>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($oc);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct26CharacterControllerManager17onObstacleRemovedEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 64|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 88|0);
  __ZN5physx3Cct9SweepTest17onObstacleRemovedEj($7,$index);
  $8 = (($i$01) + 1)|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = ($8>>>0)<($9>>>0);
  if ($10) {
   $i$01 = $8;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct26CharacterControllerManager17onObstacleUpdatedEjPKNS_17PxObstacleContextE($this,$index,$context) {
 $this = $this|0;
 $index = $index|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = Math_fround(0), $17 = 0, $18 = 0.0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0.0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (($this) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 64|0);
 $6 = (($0) + 4|0);
 $7 = (($0) + 8|0);
 $8 = (($1) + 4|0);
 $9 = (($1) + 8|0);
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$5>>2]|0;
  $11 = (($10) + ($i$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 88|0);
  $14 = (($12) + 408|0);
  $15 = +HEAPF64[$14>>3];
  $16 = Math_fround($15);
  $17 = (($12) + 416|0);
  $18 = +HEAPF64[$17>>3];
  $19 = Math_fround($18);
  $20 = (($12) + 424|0);
  $21 = +HEAPF64[$20>>3];
  $22 = Math_fround($21);
  HEAPF32[$0>>2] = $16;
  HEAPF32[$6>>2] = $19;
  HEAPF32[$7>>2] = $22;
  $23 = (($12) + 28|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround(-$24);
  $26 = (($12) + 32|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround(-$27);
  $29 = (($12) + 36|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround(-$30);
  HEAPF32[$1>>2] = $25;
  HEAPF32[$8>>2] = $28;
  HEAPF32[$9>>2] = $31;
  $32 = HEAP32[$12>>2]|0;
  $33 = (($32) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (Math_fround(FUNCTION_TABLE_fi[$34 & 255]($12)));
  __ZN5physx3Cct9SweepTest17onObstacleUpdatedEjPKNS_17PxObstacleContextERKNS_6PxVec3ES7_f($13,$index,$context,$0,$1,$35);
  $36 = (($i$01) + 1)|0;
  $37 = HEAP32[$2>>2]|0;
  $38 = ($36>>>0)<($37>>>0);
  if ($38) {
   $i$01 = $36;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct26CharacterControllerManager15onObstacleAddedEjPKNS_17PxObstacleContextE($this,$index,$context) {
 $this = $this|0;
 $index = $index|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = Math_fround(0), $17 = 0, $18 = 0.0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0.0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (($this) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 64|0);
 $6 = (($0) + 4|0);
 $7 = (($0) + 8|0);
 $8 = (($1) + 4|0);
 $9 = (($1) + 8|0);
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$5>>2]|0;
  $11 = (($10) + ($i$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 88|0);
  $14 = (($12) + 408|0);
  $15 = +HEAPF64[$14>>3];
  $16 = Math_fround($15);
  $17 = (($12) + 416|0);
  $18 = +HEAPF64[$17>>3];
  $19 = Math_fround($18);
  $20 = (($12) + 424|0);
  $21 = +HEAPF64[$20>>3];
  $22 = Math_fround($21);
  HEAPF32[$0>>2] = $16;
  HEAPF32[$6>>2] = $19;
  HEAPF32[$7>>2] = $22;
  $23 = (($12) + 28|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround(-$24);
  $26 = (($12) + 32|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround(-$27);
  $29 = (($12) + 36|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround(-$30);
  HEAPF32[$1>>2] = $25;
  HEAPF32[$8>>2] = $28;
  HEAPF32[$9>>2] = $31;
  $32 = HEAP32[$12>>2]|0;
  $33 = (($32) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (Math_fround(FUNCTION_TABLE_fi[$34 & 255]($12)));
  __ZN5physx3Cct9SweepTest15onObstacleAddedEjPKNS_17PxObstacleContextERKNS_6PxVec3ES7_f($13,$index,$context,$0,$1,$35);
  $36 = (($i$01) + 1)|0;
  $37 = HEAP32[$2>>2]|0;
  $38 = ($36>>>0)<($37>>>0);
  if ($38) {
   $i$01 = $36;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManager21resetObstaclesBuffersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4|0)==(0);
 do {
  if (!($5)) {
   $6 = (($this) + 20|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $4 >>> 1;
   $9 = ($7>>>0)>($8>>>0);
   if ($9) {
    HEAP32[$6>>2] = 0;
    break;
   } else {
    HEAP32[$0>>2] = 0;
    __ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($1,0,$0);
    $10 = HEAP32[$6>>2]|0;
    __ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE8recreateEj($1,$10);
    break;
   }
  }
 } while(0);
 $11 = (($this) + 28|0);
 $12 = (($this) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)==(0);
 do {
  if (!($15)) {
   $16 = (($this) + 32|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $14 >>> 1;
   $19 = ($17>>>0)>($18>>>0);
   if ($19) {
    HEAP32[$16>>2] = 0;
    break;
   } else {
    __ZN5physx6shdfnd5ArrayINS_13PxExtendedBoxENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($11,0,$0);
    $20 = HEAP32[$16>>2]|0;
    __ZN5physx6shdfnd5ArrayINS_13PxExtendedBoxENS0_19ReflectionAllocatorIS2_EEE8recreateEj($11,$20);
    break;
   }
  }
 } while(0);
 $21 = (($this) + 40|0);
 $22 = (($this) + 48|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($24|0)==(0);
 do {
  if (!($25)) {
   $26 = (($this) + 44|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $24 >>> 1;
   $29 = ($27>>>0)>($28>>>0);
   if ($29) {
    HEAP32[$26>>2] = 0;
    break;
   } else {
    HEAP32[$0>>2] = 0;
    __ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($21,0,$0);
    $30 = HEAP32[$26>>2]|0;
    __ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE8recreateEj($21,$30);
    break;
   }
  }
 } while(0);
 $31 = (($this) + 52|0);
 $32 = (($this) + 60|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 & 2147483647;
 $35 = ($34|0)==(0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (($this) + 56|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $34 >>> 1;
 $39 = ($37>>>0)>($38>>>0);
 if ($39) {
  HEAP32[$36>>2] = 0;
  STACKTOP = sp;return;
 } else {
  dest=$0+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  __ZN5physx6shdfnd5ArrayINS_17PxExtendedCapsuleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($31,0,$0);
  $40 = HEAP32[$36>>2]|0;
  __ZN5physx6shdfnd5ArrayINS_17PxExtendedCapsuleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($31,$40);
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Cct26CharacterControllerManager15setTessellationEbf($this,$flag,$maxEdgeLength) {
 $this = $this|0;
 $flag = $flag|0;
 $maxEdgeLength = Math_fround($maxEdgeLength);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = $flag&1;
 HEAP8[$0>>0] = $1;
 $2 = (($this) + 128|0);
 HEAPF32[$2>>2] = $maxEdgeLength;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManager24setOverlapRecoveryModuleEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 133|0);
 $1 = $flag&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManager16setPreciseSweepsEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 134|0);
 $1 = $flag&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManager39setPreventVerticalSlidingAgainstCeilingEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 135|0);
 $1 = $flag&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManager11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($this) + 64|0);
  $i$02 = 0;
  while(1) {
   $9 = HEAP32[$4>>2]|0;
   $10 = (($9) + ($i$02<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   __ZN5physx3Cct10Controller13onOriginShiftERKNS_6PxVec3E($11,$shift);
   $12 = (($i$02) + 1)|0;
   $13 = HEAP32[$1>>2]|0;
   $14 = ($12>>>0)<($13>>>0);
   if ($14) {
    $i$02 = $12;
   } else {
    break;
   }
  }
 }
 $5 = (($this) + 120|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($this) + 116|0);
  $i1$01 = 0;
  while(1) {
   $15 = HEAP32[$8>>2]|0;
   $16 = (($15) + ($i1$01<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   __ZN5physx3Cct15ObstacleContext13onOriginShiftERKNS_6PxVec3E($17,$shift);
   $18 = (($i1$01) + 1)|0;
   $19 = HEAP32[$5>>2]|0;
   $20 = ($18>>>0)<($19>>>0);
   if ($20) {
    $i1$01 = $18;
   } else {
    break;
   }
  }
 }
 $21 = (($this) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = Math_fround(HEAPF32[$shift>>2]);
 $25 = Math_fround(-$24);
 $26 = (($shift) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround(-$27);
 $29 = (($shift) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround(-$30);
 HEAPF32[$0>>2] = $25;
 $32 = (($0) + 4|0);
 HEAPF32[$32>>2] = $28;
 $33 = (($0) + 8|0);
 HEAPF32[$33>>2] = $31;
 __ZN5physx2Cm12RenderBuffer5shiftERKNS_6PxVec3E($22,$0);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12RenderBuffer5shiftERKNS_6PxVec3E($this,$delta) {
 $this = $this|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0);
 var $i$08 = 0, $i1$06 = 0, $i2$03 = 0, $i3$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($delta) + 4|0);
  $6 = (($delta) + 8|0);
  $i$08 = 0;
  while(1) {
   $14 = Math_fround(HEAPF32[$delta>>2]);
   $15 = (($4) + ($i$08<<4)|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($14 + $16);
   HEAPF32[$15>>2] = $17;
   $18 = Math_fround(HEAPF32[$5>>2]);
   $19 = ((($4) + ($i$08<<4)|0) + 4|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround($18 + $20);
   HEAPF32[$19>>2] = $21;
   $22 = Math_fround(HEAPF32[$6>>2]);
   $23 = ((($4) + ($i$08<<4)|0) + 8|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($22 + $24);
   HEAPF32[$23>>2] = $25;
   $26 = (($i$08) + 1)|0;
   $27 = ($26>>>0)<($1>>>0);
   if ($27) {
    $i$08 = $26;
   } else {
    break;
   }
  }
 }
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($delta) + 4|0);
  $13 = (($delta) + 8|0);
  $i1$06 = 0;
  while(1) {
   $35 = Math_fround(HEAPF32[$delta>>2]);
   $36 = (($11) + ($i1$06<<5)|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = Math_fround($35 + $37);
   HEAPF32[$36>>2] = $38;
   $39 = Math_fround(HEAPF32[$12>>2]);
   $40 = ((($11) + ($i1$06<<5)|0) + 4|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = Math_fround($39 + $41);
   HEAPF32[$40>>2] = $42;
   $43 = Math_fround(HEAPF32[$13>>2]);
   $44 = ((($11) + ($i1$06<<5)|0) + 8|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = Math_fround($43 + $45);
   HEAPF32[$44>>2] = $46;
   $47 = Math_fround(HEAPF32[$delta>>2]);
   $48 = ((($11) + ($i1$06<<5)|0) + 16|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = Math_fround($47 + $49);
   HEAPF32[$48>>2] = $50;
   $51 = Math_fround(HEAPF32[$12>>2]);
   $52 = ((($11) + ($i1$06<<5)|0) + 20|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = Math_fround($51 + $53);
   HEAPF32[$52>>2] = $54;
   $55 = Math_fround(HEAPF32[$13>>2]);
   $56 = ((($11) + ($i1$06<<5)|0) + 24|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround($55 + $57);
   HEAPF32[$56>>2] = $58;
   $59 = (($i1$06) + 1)|0;
   $60 = ($59>>>0)<($8>>>0);
   if ($60) {
    $i1$06 = $59;
   } else {
    break;
   }
  }
 }
 $28 = (($this) + 32|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = (($this) + 28|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($delta) + 4|0);
  $34 = (($delta) + 8|0);
  $i2$03 = 0;
  while(1) {
   $68 = Math_fround(HEAPF32[$delta>>2]);
   $69 = (($32) + (($i2$03*48)|0)|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = Math_fround($68 + $70);
   HEAPF32[$69>>2] = $71;
   $72 = Math_fround(HEAPF32[$33>>2]);
   $73 = ((($32) + (($i2$03*48)|0)|0) + 4|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = Math_fround($72 + $74);
   HEAPF32[$73>>2] = $75;
   $76 = Math_fround(HEAPF32[$34>>2]);
   $77 = ((($32) + (($i2$03*48)|0)|0) + 8|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = Math_fround($76 + $78);
   HEAPF32[$77>>2] = $79;
   $80 = Math_fround(HEAPF32[$delta>>2]);
   $81 = ((($32) + (($i2$03*48)|0)|0) + 16|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $83 = Math_fround($80 + $82);
   HEAPF32[$81>>2] = $83;
   $84 = Math_fround(HEAPF32[$33>>2]);
   $85 = ((($32) + (($i2$03*48)|0)|0) + 20|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   $87 = Math_fround($84 + $86);
   HEAPF32[$85>>2] = $87;
   $88 = Math_fround(HEAPF32[$34>>2]);
   $89 = ((($32) + (($i2$03*48)|0)|0) + 24|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = Math_fround($88 + $90);
   HEAPF32[$89>>2] = $91;
   $92 = Math_fround(HEAPF32[$delta>>2]);
   $93 = ((($32) + (($i2$03*48)|0)|0) + 32|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = Math_fround($92 + $94);
   HEAPF32[$93>>2] = $95;
   $96 = Math_fround(HEAPF32[$33>>2]);
   $97 = ((($32) + (($i2$03*48)|0)|0) + 36|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = Math_fround($96 + $98);
   HEAPF32[$97>>2] = $99;
   $100 = Math_fround(HEAPF32[$34>>2]);
   $101 = ((($32) + (($i2$03*48)|0)|0) + 40|0);
   $102 = Math_fround(HEAPF32[$101>>2]);
   $103 = Math_fround($100 + $102);
   HEAPF32[$101>>2] = $103;
   $104 = (($i2$03) + 1)|0;
   $105 = ($104>>>0)<($29>>>0);
   if ($105) {
    $i2$03 = $104;
   } else {
    break;
   }
  }
 }
 $61 = (($this) + 44|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  STACKTOP = sp;return;
 }
 $64 = (($this) + 40|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($delta) + 4|0);
 $67 = (($delta) + 8|0);
 $i3$01 = 0;
 while(1) {
  $106 = Math_fround(HEAPF32[$delta>>2]);
  $107 = (($65) + (($i3$01*24)|0)|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($106 + $108);
  HEAPF32[$107>>2] = $109;
  $110 = Math_fround(HEAPF32[$66>>2]);
  $111 = ((($65) + (($i3$01*24)|0)|0) + 4|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = Math_fround($110 + $112);
  HEAPF32[$111>>2] = $113;
  $114 = Math_fround(HEAPF32[$67>>2]);
  $115 = ((($65) + (($i3$01*24)|0)|0) + 8|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = Math_fround($114 + $116);
  HEAPF32[$115>>2] = $117;
  $118 = (($i3$01) + 1)|0;
  $119 = ($118>>>0)<($62>>>0);
  if ($119) {
   $i3$01 = $118;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx3Cct26CharacterControllerManager19computeInteractionsEfPNS_26PxControllerFilterCallbackE($this,$elapsedTime,$cctFilterCb) {
 $this = $this|0;
 $elapsedTime = Math_fround($elapsedTime);
 $cctFilterCb = $cctFilterCb|0;
 var $$0$i$i = 0, $$in = 0, $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert23 = 0, $$phi$trans$insert27$i$i = 0, $$phi$trans$insert29$i$i = 0, $$phi$trans$insert75$i = 0, $$phi$trans$insert77$i = 0, $$phi$trans$insert79$i = 0, $$phi$trans$insert81$i = 0, $$phi$trans$insert83$i = 0, $$pre = Math_fround(0), $$pre$i = Math_fround(0), $$pre24 = Math_fround(0), $$pre28$i$i = Math_fround(0), $$pre30$i$i = Math_fround(0), $$pre76$i = Math_fround(0), $$pre78$i = Math_fround(0), $$pre80$i = Math_fround(0);
 var $$pre82$i = Math_fround(0), $$pre84$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0.0;
 var $187 = Math_fround(0), $188 = 0.0, $189 = Math_fround(0), $19 = 0, $190 = 0.0, $191 = Math_fround(0), $192 = 0.0, $193 = Math_fround(0), $194 = 0.0, $195 = Math_fround(0), $196 = 0.0, $197 = Math_fround(0), $198 = 0.0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0.0, $201 = Math_fround(0), $202 = 0.0, $203 = Math_fround(0);
 var $204 = 0.0, $205 = Math_fround(0), $206 = 0.0, $207 = Math_fround(0), $208 = 0.0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0.0;
 var $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0.0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0.0, $280 = 0, $281 = 0, $282 = 0.0, $283 = Math_fround(0), $284 = 0.0, $285 = Math_fround(0), $286 = 0.0, $287 = Math_fround(0), $288 = 0.0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0.0, $291 = Math_fround(0), $292 = 0.0, $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0.0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0.0, $320 = Math_fround(0), $321 = 0.0, $322 = Math_fround(0), $323 = 0.0, $324 = Math_fround(0), $325 = 0.0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0.0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0;
 var $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0.0;
 var $385 = Math_fround(0), $386 = 0.0, $387 = Math_fround(0), $388 = 0.0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0.0, $418 = Math_fround(0), $419 = 0.0, $42 = 0;
 var $420 = Math_fround(0), $421 = 0.0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0);
 var $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0);
 var $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0);
 var $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0);
 var $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0;
 var $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0);
 var $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0);
 var $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = 0, $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0);
 var $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = 0, $581 = Math_fround(0), $582 = 0;
 var $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = 0.0, $588 = Math_fround(0), $589 = 0.0, $59 = 0, $590 = Math_fround(0), $591 = 0.0, $592 = Math_fround(0), $593 = 0.0, $594 = Math_fround(0), $595 = 0.0, $596 = Math_fround(0), $597 = 0.0, $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0;
 var $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = 0, $615 = Math_fround(0), $616 = 0, $617 = Math_fround(0), $618 = 0;
 var $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0);
 var $637 = Math_fround(0), $638 = Math_fround(0), $639 = 0, $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = 0, $646 = 0, $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0);
 var $655 = Math_fround(0), $656 = 0, $657 = Math_fround(0), $658 = Math_fround(0), $659 = 0, $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0), $664 = Math_fround(0), $665 = 0, $666 = Math_fround(0), $667 = Math_fround(0), $668 = 0, $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = 0, $672 = Math_fround(0);
 var $673 = Math_fround(0), $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $FR$i$i = 0, $M$i = 0, $R$i$i = 0, $T$i$i = 0, $boxCenter$i = 0, $capsule$i = 0, $capsule0$i = 0, $capsule1$i = 0;
 var $controllers$019 = 0, $entity0$entity1$i = 0, $entity1$entity0$i = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i1$i$i13 = Math_fround(0), $fabsf$i$i2$1$i$1$i = Math_fround(0), $fabsf$i$i2$1$i$2$i = Math_fround(0), $fabsf$i$i2$1$i$i = Math_fround(0), $fabsf$i$i2$2$i$1$i = Math_fround(0), $fabsf$i$i2$2$i$2$i = Math_fround(0), $fabsf$i$i2$2$i$i = Math_fround(0), $fabsf$i$i2$i$1$i = Math_fround(0), $fabsf$i$i2$i$2$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $i1$07$i$i14 = 0, $indices$016 = 0, $k2$04$i$i = 0, $minD$1$1$i$i = Math_fround(0), $minD$1$2$i$i = Math_fround(0);
 var $minD$1$3$i$i = Math_fround(0), $minD$1$4$i$i = Math_fround(0), $minD$1$4$i72$i = Math_fround(0), $minD$1$i$i = Math_fround(0), $minIndex$1$1$i$i = 0, $minIndex$1$2$i$i = 0, $minIndex$1$3$i$i = 0, $minIndex$1$4$i$i = 0, $minIndex$1$i$i = 0, $nbControllers$020 = 0, $obb$i = 0, $obb0$i = 0, $obb1$i = 0, $or$cond$i$i = 0, $overlap$3$i = Math_fround(0), $overlap$4$i = Math_fround(0), $overlap$i$i = 0, $p$i = 0, $p0$i = 0, $p00$i = 0;
 var $p00$idx$val$i = Math_fround(0), $p00$idx7$val$i = Math_fround(0), $p00$idx8$val$i = Math_fround(0), $p1$i = 0, $p10$i = 0, $p10$idx$val$i = Math_fround(0), $p10$idx3$val$i = Math_fround(0), $p10$idx4$val$i = Math_fround(0), $pairs = 0, $runningBoxes$0$lcssa = 0, $runningBoxes$018 = 0, $s$i = 0, $scevgep = 0, $t$i = 0, $t3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 688|0;
 $T$i$i = sp + 112|0;
 $R$i$i = sp + 408|0;
 $FR$i$i = sp + 444|0;
 $overlap$i$i = sp + 580|0;
 $capsule0$i = sp + 160|0;
 $capsule1$i = sp + 216|0;
 $p00$i = sp + 640|0;
 $p10$i = sp + 544|0;
 $s$i = sp + 680|0;
 $t$i = sp + 676|0;
 $0 = sp + 664|0;
 $1 = sp + 652|0;
 $obb$i = sp + 272|0;
 $capsule$i = sp + 328|0;
 $p0$i = sp + 568|0;
 $p1$i = sp + 556|0;
 $t3$i = sp + 540|0;
 $p$i = sp + 528|0;
 $M$i = sp + 492|0;
 $boxCenter$i = sp + 480|0;
 $obb0$i = sp + 56|0;
 $obb1$i = sp;
 $2 = sp + 685|0;
 $pairs = sp + 396|0;
 $3 = sp + 384|0;
 $4 = sp + 684|0;
 $5 = (($this) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6*24)|0;
 $10 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$9,405224,640)|0);
 $11 = ($6|0)==(0);
 if ($11) {
  $runningBoxes$0$lcssa = $10;
 } else {
  $12 = (($T$i$i) + 8|0);
  $13 = (($T$i$i) + 16|0);
  $14 = (($T$i$i) + 24|0);
  $15 = (($T$i$i) + 32|0);
  $16 = (($T$i$i) + 40|0);
  $scevgep = (($10) + ($9)|0);
  $controllers$019 = $8;$nbControllers$020 = $6;$runningBoxes$018 = $10;
  while(1) {
   $17 = (($nbControllers$020) + -1)|0;
   $18 = (($controllers$019) + 4|0);
   $19 = HEAP32[$controllers$019>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 16|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_iii[$22 & 4095]($19,$T$i$i)|0);
   $23 = (($runningBoxes$018) + 24|0);
   $24 = +HEAPF64[$T$i$i>>3];
   $25 = Math_fround($24);
   $26 = +HEAPF64[$12>>3];
   $27 = Math_fround($26);
   $28 = +HEAPF64[$13>>3];
   $29 = Math_fround($28);
   $30 = +HEAPF64[$14>>3];
   $31 = Math_fround($30);
   $32 = +HEAPF64[$15>>3];
   $33 = Math_fround($32);
   $34 = +HEAPF64[$16>>3];
   $35 = Math_fround($34);
   HEAPF32[$runningBoxes$018>>2] = $25;
   $36 = (($runningBoxes$018) + 4|0);
   HEAPF32[$36>>2] = $27;
   $37 = (($runningBoxes$018) + 8|0);
   HEAPF32[$37>>2] = $29;
   $38 = (($runningBoxes$018) + 12|0);
   HEAPF32[$38>>2] = $31;
   $39 = (($runningBoxes$018) + 16|0);
   HEAPF32[$39>>2] = $33;
   $40 = (($runningBoxes$018) + 20|0);
   HEAPF32[$40>>2] = $35;
   $41 = ($17|0)==(0);
   if ($41) {
    break;
   } else {
    $controllers$019 = $18;$nbControllers$020 = $17;$runningBoxes$018 = $23;
   }
  }
  $runningBoxes$0$lcssa = $scevgep;
 }
 $42 = $runningBoxes$0$lcssa;
 $43 = $10;
 $44 = (($42) - ($43))|0;
 $45 = (($44|0) / 24)&-1;
 HEAP32[$pairs>>2] = 0;
 $46 = (($pairs) + 4|0);
 HEAP32[$46>>2] = 0;
 $47 = (($pairs) + 8|0);
 HEAP32[$47>>2] = 0;
 HEAP32[$3>>2] = 0;
 $48 = (($3) + 4|0);
 HEAP32[$48>>2] = 2;
 $49 = (($3) + 8|0);
 HEAP32[$49>>2] = 1;
 (__ZN5physx2Gu18CompleteBoxPruningEPKNS_9PxBounds3EjRNS_6shdfnd5ArrayIjNS4_19ReflectionAllocatorIjEEEERKNS0_4AxesE($10,$45,$pairs,$3)|0);
 $50 = HEAP32[$46>>2]|0;
 $51 = $50 >>> 1;
 $52 = ($51|0)==(0);
 if (!($52)) {
  $53 = HEAP32[$pairs>>2]|0;
  $54 = ($cctFilterCb|0)==(0|0);
  $55 = (($obb0$i) + 8|0);
  $56 = (($obb0$i) + 16|0);
  $57 = (($obb0$i) + 36|0);
  $58 = (($obb0$i) + 40|0);
  $59 = (($obb0$i) + 44|0);
  $60 = (($obb0$i) + 48|0);
  $61 = (($obb1$i) + 8|0);
  $62 = (($obb1$i) + 16|0);
  $63 = (($obb1$i) + 36|0);
  $64 = (($obb1$i) + 40|0);
  $65 = (($obb1$i) + 44|0);
  $66 = (($obb1$i) + 48|0);
  $67 = (($T$i$i) + 4|0);
  $68 = (($T$i$i) + 8|0);
  $69 = (($R$i$i) + 4|0);
  $70 = (($FR$i$i) + 4|0);
  $71 = (($R$i$i) + 8|0);
  $72 = (($FR$i$i) + 8|0);
  $73 = (($R$i$i) + 12|0);
  $74 = (($FR$i$i) + 12|0);
  $75 = (($R$i$i) + 16|0);
  $76 = (($FR$i$i) + 16|0);
  $77 = (($R$i$i) + 20|0);
  $78 = (($FR$i$i) + 20|0);
  $79 = (($R$i$i) + 24|0);
  $80 = (($FR$i$i) + 24|0);
  $81 = (($R$i$i) + 28|0);
  $82 = (($FR$i$i) + 28|0);
  $83 = (($R$i$i) + 32|0);
  $84 = (($FR$i$i) + 32|0);
  $85 = (($obb0$i) + 24|0);
  $86 = (($obb1$i) + 24|0);
  $87 = (($86) + 4|0);
  $88 = (($86) + 8|0);
  $89 = (($85) + 4|0);
  $90 = (($85) + 8|0);
  $91 = (($overlap$i$i) + 4|0);
  $92 = (($overlap$i$i) + 8|0);
  $93 = (($overlap$i$i) + 12|0);
  $94 = (($overlap$i$i) + 16|0);
  $95 = (($overlap$i$i) + 20|0);
  $96 = Math_fround($elapsedTime * Math_fround(4.0));
  $97 = (($capsule0$i) + 48|0);
  $98 = (($capsule1$i) + 48|0);
  $99 = (($capsule0$i) + 8|0);
  $100 = (($capsule0$i) + 16|0);
  $101 = (($p00$i) + 4|0);
  $102 = (($p00$i) + 8|0);
  $103 = (($capsule0$i) + 24|0);
  $104 = (($capsule0$i) + 32|0);
  $105 = (($capsule0$i) + 40|0);
  $106 = (($capsule1$i) + 8|0);
  $107 = (($capsule1$i) + 16|0);
  $108 = (($p10$i) + 4|0);
  $109 = (($p10$i) + 8|0);
  $110 = (($capsule1$i) + 24|0);
  $111 = (($capsule1$i) + 32|0);
  $112 = (($capsule1$i) + 40|0);
  $113 = (($0) + 4|0);
  $114 = (($0) + 8|0);
  $115 = (($1) + 4|0);
  $116 = (($1) + 8|0);
  $117 = (($capsule$i) + 8|0);
  $118 = (($capsule$i) + 16|0);
  $119 = (($p0$i) + 4|0);
  $120 = (($p0$i) + 8|0);
  $121 = (($capsule$i) + 24|0);
  $122 = (($capsule$i) + 32|0);
  $123 = (($capsule$i) + 40|0);
  $124 = (($p1$i) + 4|0);
  $125 = (($p1$i) + 8|0);
  $126 = (($obb$i) + 36|0);
  $127 = (($obb$i) + 40|0);
  $128 = (($obb$i) + 44|0);
  $129 = (($obb$i) + 48|0);
  $130 = (($M$i) + 4|0);
  $131 = (($M$i) + 8|0);
  $132 = (($M$i) + 12|0);
  $133 = (($M$i) + 16|0);
  $134 = (($M$i) + 20|0);
  $135 = (($M$i) + 24|0);
  $136 = (($M$i) + 28|0);
  $137 = (($M$i) + 32|0);
  $138 = (($obb$i) + 8|0);
  $139 = (($obb$i) + 16|0);
  $140 = (($boxCenter$i) + 4|0);
  $141 = (($boxCenter$i) + 8|0);
  $142 = (($obb$i) + 24|0);
  $143 = (($capsule$i) + 48|0);
  $$in = $51;$indices$016 = $53;
  while(1) {
   $144 = (($$in) + -1)|0;
   $145 = (($indices$016) + 4|0);
   $146 = HEAP32[$indices$016>>2]|0;
   $147 = (($indices$016) + 8|0);
   $148 = HEAP32[$145>>2]|0;
   $149 = HEAP32[$7>>2]|0;
   $150 = (($149) + ($146<<2)|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (($149) + ($148<<2)|0);
   $153 = HEAP32[$152>>2]|0;
   if ($54) {
    label = 10;
   } else {
    $154 = HEAP32[$cctFilterCb>>2]|0;
    $155 = (($154) + 8|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = HEAP32[$151>>2]|0;
    $158 = (($157) + 20|0);
    $159 = HEAP32[$158>>2]|0;
    $160 = (FUNCTION_TABLE_ii[$159 & 4095]($151)|0);
    $161 = HEAP32[$153>>2]|0;
    $162 = (($161) + 20|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = (FUNCTION_TABLE_ii[$163 & 4095]($153)|0);
    $165 = (FUNCTION_TABLE_iiii[$156 & 2047]($cctFilterCb,$160,$164)|0);
    if ($165) {
     label = 10;
    }
   }
   do {
    if ((label|0) == 10) {
     label = 0;
     $167 = (($151) + 4|0);
     $168 = HEAP32[$167>>2]|0;
     $169 = (($153) + 4|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = ($168|0)>($170|0);
     $entity1$entity0$i = $171 ? $153 : $151;
     $entity0$entity1$i = $171 ? $151 : $153;
     $172 = (($entity1$entity0$i) + 4|0);
     $173 = HEAP32[$172>>2]|0;
     if ((($173|0) == 1)) {
      $174 = (($entity0$entity1$i) + 4|0);
      $175 = HEAP32[$174>>2]|0;
      $176 = ($175|0)==(1);
      if ($176) {
       $177 = ($entity1$entity0$i|0)==(0|0);
       if ($177) {
        $181 = 0;
       } else {
        $178 = (($entity1$entity0$i) + -8|0);
        $181 = $178;
       }
       $179 = ($entity0$entity1$i|0)==(0|0);
       if ($179) {
        $182 = 0;
       } else {
        $180 = (($entity0$entity1$i) + -8|0);
        $182 = $180;
       }
       __ZNK5physx3Cct17CapsuleController10getCapsuleERNS_17PxExtendedCapsuleE($181,$capsule0$i);
       __ZNK5physx3Cct17CapsuleController10getCapsuleERNS_17PxExtendedCapsuleE($182,$capsule1$i);
       $183 = Math_fround(HEAPF32[$97>>2]);
       $184 = Math_fround(HEAPF32[$98>>2]);
       $185 = Math_fround($183 + $184);
       $186 = +HEAPF64[$capsule0$i>>3];
       $187 = Math_fround($186);
       $188 = +HEAPF64[$99>>3];
       $189 = Math_fround($188);
       $190 = +HEAPF64[$100>>3];
       $191 = Math_fround($190);
       HEAPF32[$p00$i>>2] = $187;
       HEAPF32[$101>>2] = $189;
       HEAPF32[$102>>2] = $191;
       $192 = +HEAPF64[$103>>3];
       $193 = Math_fround($192);
       $194 = +HEAPF64[$104>>3];
       $195 = Math_fround($194);
       $196 = +HEAPF64[$105>>3];
       $197 = Math_fround($196);
       $198 = +HEAPF64[$capsule1$i>>3];
       $199 = Math_fround($198);
       $200 = +HEAPF64[$106>>3];
       $201 = Math_fround($200);
       $202 = +HEAPF64[$107>>3];
       $203 = Math_fround($202);
       HEAPF32[$p10$i>>2] = $199;
       HEAPF32[$108>>2] = $201;
       HEAPF32[$109>>2] = $203;
       $204 = +HEAPF64[$110>>3];
       $205 = Math_fround($204);
       $206 = +HEAPF64[$111>>3];
       $207 = Math_fround($206);
       $208 = +HEAPF64[$112>>3];
       $209 = Math_fround($208);
       $210 = Math_fround($193 - $187);
       $211 = Math_fround($195 - $189);
       $212 = Math_fround($197 - $191);
       HEAPF32[$0>>2] = $210;
       HEAPF32[$113>>2] = $211;
       HEAPF32[$114>>2] = $212;
       $213 = Math_fround($205 - $199);
       $214 = Math_fround($207 - $201);
       $215 = Math_fround($209 - $203);
       HEAPF32[$1>>2] = $213;
       HEAPF32[$115>>2] = $214;
       HEAPF32[$116>>2] = $215;
       $216 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($p00$i,$0,$p10$i,$1,$s$i,$t$i)));
       $217 = (Math_fround(Math_sqrt((Math_fround($216)))));
       $218 = $217 < $185;
       if (!($218)) {
        break;
       }
       $219 = Math_fround(HEAPF32[$s$i>>2]);
       $p00$idx$val$i = Math_fround(HEAPF32[$p00$i>>2]);
       $p00$idx7$val$i = Math_fround(HEAPF32[$101>>2]);
       $p00$idx8$val$i = Math_fround(HEAPF32[$102>>2]);
       $220 = Math_fround($219 * $p00$idx$val$i);
       $221 = Math_fround($219 * $p00$idx7$val$i);
       $222 = Math_fround($219 * $p00$idx8$val$i);
       $223 = Math_fround(Math_fround(1.0) - $219);
       $224 = Math_fround($193 * $223);
       $225 = Math_fround($195 * $223);
       $226 = Math_fround($197 * $223);
       $227 = Math_fround($220 + $224);
       $228 = Math_fround($225 + $221);
       $229 = Math_fround($226 + $222);
       $230 = Math_fround(HEAPF32[$t$i>>2]);
       $p10$idx$val$i = Math_fround(HEAPF32[$p10$i>>2]);
       $p10$idx3$val$i = Math_fround(HEAPF32[$108>>2]);
       $p10$idx4$val$i = Math_fround(HEAPF32[$109>>2]);
       $231 = Math_fround($230 * $p10$idx$val$i);
       $232 = Math_fround($230 * $p10$idx3$val$i);
       $233 = Math_fround($230 * $p10$idx4$val$i);
       $234 = Math_fround(Math_fround(1.0) - $230);
       $235 = Math_fround($205 * $234);
       $236 = Math_fround($207 * $234);
       $237 = Math_fround($209 * $234);
       $238 = Math_fround($231 + $235);
       $239 = Math_fround($236 + $232);
       $240 = Math_fround($237 + $233);
       $241 = (($entity1$entity0$i) + 332|0);
       $242 = Math_fround(HEAPF32[$241>>2]);
       $243 = (($entity1$entity0$i) + 336|0);
       $244 = Math_fround(HEAPF32[$243>>2]);
       $245 = (($entity1$entity0$i) + 340|0);
       $246 = Math_fround(HEAPF32[$245>>2]);
       $247 = Math_fround($227 - $238);
       $248 = Math_fround($228 - $239);
       $249 = Math_fround($229 - $240);
       $250 = Math_fround($247 * $242);
       $251 = Math_fround($248 * $244);
       $252 = Math_fround($250 + $251);
       $253 = Math_fround($249 * $246);
       $254 = Math_fround($252 + $253);
       $255 = Math_fround($242 * $254);
       $256 = Math_fround($244 * $254);
       $257 = Math_fround($246 * $254);
       $258 = Math_fround($247 - $255);
       $259 = Math_fround($248 - $256);
       $260 = Math_fround($249 - $257);
       $261 = Math_fround($258 * $258);
       $262 = Math_fround($259 * $259);
       $263 = Math_fround($261 + $262);
       $264 = Math_fround($260 * $260);
       $265 = Math_fround($264 + $263);
       $266 = $265 > Math_fround(0.0);
       if ($266) {
        $267 = (Math_fround(Math_sqrt((Math_fround($265)))));
        $268 = Math_fround(Math_fround(1.0) / $267);
        $269 = Math_fround($258 * $268);
        $270 = Math_fround($259 * $268);
        $271 = Math_fround($260 * $268);
        $684 = $271;$685 = $270;$686 = $269;
       } else {
        $684 = Math_fround(0.0);$685 = Math_fround(0.0);$686 = Math_fround(0.0);
       }
       $272 = Math_fround($185 - $217);
       $648 = $686;$650 = $685;$652 = $684;$overlap$3$i = $272;
      } else {
       label = 29;
      }
     } else if ((($173|0) == 0)) {
      $273 = (($entity0$entity1$i) + 4|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = ($274|0)==(1);
      if ($275) {
       $276 = ($entity1$entity0$i|0)==(0|0);
       if ($276) {
        $280 = 0;
       } else {
        $277 = (($entity1$entity0$i) + -8|0);
        $280 = $277;
       }
       $278 = ($entity0$entity1$i|0)==(0|0);
       if ($278) {
        $281 = 0;
       } else {
        $279 = (($entity0$entity1$i) + -8|0);
        $281 = $279;
       }
       __ZNK5physx3Cct13BoxController6getOBBERNS_13PxExtendedBoxE($280,$obb$i);
       __ZNK5physx3Cct17CapsuleController10getCapsuleERNS_17PxExtendedCapsuleE($281,$capsule$i);
       $282 = +HEAPF64[$capsule$i>>3];
       $283 = Math_fround($282);
       $284 = +HEAPF64[$117>>3];
       $285 = Math_fround($284);
       $286 = +HEAPF64[$118>>3];
       $287 = Math_fround($286);
       HEAPF32[$p0$i>>2] = $283;
       HEAPF32[$119>>2] = $285;
       HEAPF32[$120>>2] = $287;
       $288 = +HEAPF64[$121>>3];
       $289 = Math_fround($288);
       $290 = +HEAPF64[$122>>3];
       $291 = Math_fround($290);
       $292 = +HEAPF64[$123>>3];
       $293 = Math_fround($292);
       HEAPF32[$p1$i>>2] = $289;
       HEAPF32[$124>>2] = $291;
       HEAPF32[$125>>2] = $293;
       $294 = Math_fround(HEAPF32[$126>>2]);
       $295 = Math_fround(HEAPF32[$127>>2]);
       $296 = Math_fround(HEAPF32[$128>>2]);
       $297 = Math_fround(HEAPF32[$129>>2]);
       $298 = Math_fround($294 + $294);
       $299 = Math_fround($295 + $295);
       $300 = Math_fround($296 + $296);
       $301 = Math_fround($294 * $298);
       $302 = Math_fround($295 * $299);
       $303 = Math_fround($296 * $300);
       $304 = Math_fround($298 * $295);
       $305 = Math_fround($298 * $296);
       $306 = Math_fround($298 * $297);
       $307 = Math_fround($299 * $296);
       $308 = Math_fround($299 * $297);
       $309 = Math_fround($300 * $297);
       $310 = Math_fround(Math_fround(1.0) - $302);
       $311 = Math_fround($310 - $303);
       $312 = Math_fround($304 + $309);
       $313 = Math_fround($305 - $308);
       HEAPF32[$M$i>>2] = $311;
       HEAPF32[$130>>2] = $312;
       HEAPF32[$131>>2] = $313;
       $314 = Math_fround($304 - $309);
       $315 = Math_fround(Math_fround(1.0) - $301);
       $316 = Math_fround($315 - $303);
       $317 = Math_fround($307 + $306);
       HEAPF32[$132>>2] = $314;
       HEAPF32[$133>>2] = $316;
       HEAPF32[$134>>2] = $317;
       $318 = Math_fround($305 + $308);
       $319 = Math_fround($307 - $306);
       $320 = Math_fround($315 - $302);
       HEAPF32[$135>>2] = $318;
       HEAPF32[$136>>2] = $319;
       HEAPF32[$137>>2] = $320;
       $321 = +HEAPF64[$obb$i>>3];
       $322 = Math_fround($321);
       $323 = +HEAPF64[$138>>3];
       $324 = Math_fround($323);
       $325 = +HEAPF64[$139>>3];
       $326 = Math_fround($325);
       HEAPF32[$boxCenter$i>>2] = $322;
       HEAPF32[$140>>2] = $324;
       HEAPF32[$141>>2] = $326;
       $327 = (Math_fround(__ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($p0$i,$p1$i,$boxCenter$i,$142,$M$i,$t3$i,$p$i)));
       $328 = (Math_fround(Math_sqrt((Math_fround($327)))));
       $329 = Math_fround(HEAPF32[$143>>2]);
       $330 = $328 < $329;
       if (!($330)) {
        break;
       }
       $331 = Math_fround(HEAPF32[$boxCenter$i>>2]);
       $332 = Math_fround(HEAPF32[$140>>2]);
       $333 = Math_fround(HEAPF32[$141>>2]);
       $334 = Math_fround(HEAPF32[$p0$i>>2]);
       $335 = Math_fround(HEAPF32[$p1$i>>2]);
       $336 = Math_fround($334 + $335);
       $337 = Math_fround(HEAPF32[$119>>2]);
       $338 = Math_fround(HEAPF32[$124>>2]);
       $339 = Math_fround($337 + $338);
       $340 = Math_fround(HEAPF32[$120>>2]);
       $341 = Math_fround(HEAPF32[$125>>2]);
       $342 = Math_fround($340 + $341);
       $343 = Math_fround($336 * Math_fround(0.5));
       $344 = Math_fround($339 * Math_fround(0.5));
       $345 = Math_fround($342 * Math_fround(0.5));
       $346 = (($entity1$entity0$i) + 332|0);
       $347 = Math_fround(HEAPF32[$346>>2]);
       $348 = (($entity1$entity0$i) + 336|0);
       $349 = Math_fround(HEAPF32[$348>>2]);
       $350 = (($entity1$entity0$i) + 340|0);
       $351 = Math_fround(HEAPF32[$350>>2]);
       $352 = Math_fround($331 - $343);
       $353 = Math_fround($332 - $344);
       $354 = Math_fround($333 - $345);
       $355 = Math_fround($352 * $347);
       $356 = Math_fround($353 * $349);
       $357 = Math_fround($355 + $356);
       $358 = Math_fround($354 * $351);
       $359 = Math_fround($357 + $358);
       $360 = Math_fround($347 * $359);
       $361 = Math_fround($349 * $359);
       $362 = Math_fround($351 * $359);
       $363 = Math_fround($352 - $360);
       $364 = Math_fround($353 - $361);
       $365 = Math_fround($354 - $362);
       $366 = Math_fround($363 * $363);
       $367 = Math_fround($364 * $364);
       $368 = Math_fround($366 + $367);
       $369 = Math_fround($365 * $365);
       $370 = Math_fround($369 + $368);
       $371 = $370 > Math_fround(0.0);
       if ($371) {
        $372 = (Math_fround(Math_sqrt((Math_fround($370)))));
        $373 = Math_fround(Math_fround(1.0) / $372);
        $374 = Math_fround($363 * $373);
        $375 = Math_fround($364 * $373);
        $376 = Math_fround($365 * $373);
        $687 = $376;$688 = $375;$689 = $374;
       } else {
        $687 = Math_fround(0.0);$688 = Math_fround(0.0);$689 = Math_fround(0.0);
       }
       $377 = Math_fround($329 - $328);
       $648 = $689;$650 = $688;$652 = $687;$overlap$3$i = $377;
      } else {
       label = 29;
      }
     } else {
      label = 29;
     }
     if ((label|0) == 29) {
      label = 0;
      $378 = ($entity1$entity0$i|0)==(0|0);
      if ($378) {
       $382 = 0;
      } else {
       $379 = (($entity1$entity0$i) + -8|0);
       $382 = $379;
      }
      $380 = ($entity0$entity1$i|0)==(0|0);
      if ($380) {
       $383 = 0;
      } else {
       $381 = (($entity0$entity1$i) + -8|0);
       $383 = $381;
      }
      __ZNK5physx3Cct13BoxController6getOBBERNS_13PxExtendedBoxE($382,$obb0$i);
      __ZNK5physx3Cct13BoxController6getOBBERNS_13PxExtendedBoxE($383,$obb1$i);
      $384 = +HEAPF64[$obb0$i>>3];
      $385 = Math_fround($384);
      $386 = +HEAPF64[$55>>3];
      $387 = Math_fround($386);
      $388 = +HEAPF64[$56>>3];
      $389 = Math_fround($388);
      $390 = Math_fround(HEAPF32[$57>>2]);
      $391 = Math_fround(HEAPF32[$58>>2]);
      $392 = Math_fround(HEAPF32[$59>>2]);
      $393 = Math_fround(HEAPF32[$60>>2]);
      $394 = Math_fround($390 + $390);
      $395 = Math_fround($391 + $391);
      $396 = Math_fround($392 + $392);
      $397 = Math_fround($390 * $394);
      $398 = Math_fround($391 * $395);
      $399 = Math_fround($392 * $396);
      $400 = Math_fround($394 * $391);
      $401 = Math_fround($394 * $392);
      $402 = Math_fround($394 * $393);
      $403 = Math_fround($395 * $392);
      $404 = Math_fround($395 * $393);
      $405 = Math_fround($396 * $393);
      $406 = Math_fround(Math_fround(1.0) - $398);
      $407 = Math_fround($406 - $399);
      $408 = Math_fround($400 + $405);
      $409 = Math_fround($401 - $404);
      $410 = Math_fround($400 - $405);
      $411 = Math_fround(Math_fround(1.0) - $397);
      $412 = Math_fround($411 - $399);
      $413 = Math_fround($403 + $402);
      $414 = Math_fround($401 + $404);
      $415 = Math_fround($403 - $402);
      $416 = Math_fround($411 - $398);
      $417 = +HEAPF64[$obb1$i>>3];
      $418 = Math_fround($417);
      $419 = +HEAPF64[$61>>3];
      $420 = Math_fround($419);
      $421 = +HEAPF64[$62>>3];
      $422 = Math_fround($421);
      $423 = Math_fround(HEAPF32[$63>>2]);
      $424 = Math_fround(HEAPF32[$64>>2]);
      $425 = Math_fround(HEAPF32[$65>>2]);
      $426 = Math_fround(HEAPF32[$66>>2]);
      $427 = Math_fround($423 + $423);
      $428 = Math_fround($424 + $424);
      $429 = Math_fround($425 + $425);
      $430 = Math_fround($423 * $427);
      $431 = Math_fround($424 * $428);
      $432 = Math_fround($425 * $429);
      $433 = Math_fround($427 * $424);
      $434 = Math_fround($427 * $425);
      $435 = Math_fround($427 * $426);
      $436 = Math_fround($428 * $425);
      $437 = Math_fround($428 * $426);
      $438 = Math_fround($429 * $426);
      $439 = Math_fround(Math_fround(1.0) - $431);
      $440 = Math_fround($439 - $432);
      $441 = Math_fround($433 + $438);
      $442 = Math_fround($434 - $437);
      $443 = Math_fround($433 - $438);
      $444 = Math_fround(Math_fround(1.0) - $430);
      $445 = Math_fround($444 - $432);
      $446 = Math_fround($436 + $435);
      $447 = Math_fround($434 + $437);
      $448 = Math_fround($436 - $435);
      $449 = Math_fround($444 - $431);
      $450 = Math_fround($418 - $385);
      $451 = Math_fround($420 - $387);
      $452 = Math_fround($422 - $389);
      $453 = Math_fround($407 * $450);
      $454 = Math_fround($408 * $451);
      $455 = Math_fround($453 + $454);
      $456 = Math_fround($409 * $452);
      $457 = Math_fround($455 + $456);
      $458 = Math_fround($410 * $450);
      $459 = Math_fround($412 * $451);
      $460 = Math_fround($458 + $459);
      $461 = Math_fround($413 * $452);
      $462 = Math_fround($460 + $461);
      $463 = Math_fround($414 * $450);
      $464 = Math_fround($415 * $451);
      $465 = Math_fround($463 + $464);
      $466 = Math_fround($416 * $452);
      $467 = Math_fround($465 + $466);
      HEAPF32[$T$i$i>>2] = $457;
      HEAPF32[$67>>2] = $462;
      HEAPF32[$68>>2] = $467;
      $468 = Math_fround($407 * $440);
      $469 = Math_fround($408 * $441);
      $470 = Math_fround($468 + $469);
      $471 = Math_fround($409 * $442);
      $472 = Math_fround($471 + $470);
      HEAPF32[$R$i$i>>2] = $472;
      $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($472)))));
      $473 = Math_fround($fabsf$i$i2$i$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$FR$i$i>>2] = $473;
      $474 = Math_fround($407 * $443);
      $475 = Math_fround($408 * $445);
      $476 = Math_fround($474 + $475);
      $477 = Math_fround($409 * $446);
      $478 = Math_fround($477 + $476);
      HEAPF32[$69>>2] = $478;
      $fabsf$i$i2$1$i$i = (Math_fround(Math_abs((Math_fround($478)))));
      $479 = Math_fround($fabsf$i$i2$1$i$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$70>>2] = $479;
      $480 = Math_fround($407 * $447);
      $481 = Math_fround($408 * $448);
      $482 = Math_fround($480 + $481);
      $483 = Math_fround($409 * $449);
      $484 = Math_fround($483 + $482);
      HEAPF32[$71>>2] = $484;
      $fabsf$i$i2$2$i$i = (Math_fround(Math_abs((Math_fround($484)))));
      $485 = Math_fround($fabsf$i$i2$2$i$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$72>>2] = $485;
      $486 = Math_fround($410 * $440);
      $487 = Math_fround($412 * $441);
      $488 = Math_fround($486 + $487);
      $489 = Math_fround($413 * $442);
      $490 = Math_fround($489 + $488);
      HEAPF32[$73>>2] = $490;
      $fabsf$i$i2$i$1$i = (Math_fround(Math_abs((Math_fround($490)))));
      $491 = Math_fround($fabsf$i$i2$i$1$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$74>>2] = $491;
      $492 = Math_fround($410 * $443);
      $493 = Math_fround($412 * $445);
      $494 = Math_fround($492 + $493);
      $495 = Math_fround($413 * $446);
      $496 = Math_fround($495 + $494);
      HEAPF32[$75>>2] = $496;
      $fabsf$i$i2$1$i$1$i = (Math_fround(Math_abs((Math_fround($496)))));
      $497 = Math_fround($fabsf$i$i2$1$i$1$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$76>>2] = $497;
      $498 = Math_fround($410 * $447);
      $499 = Math_fround($412 * $448);
      $500 = Math_fround($498 + $499);
      $501 = Math_fround($413 * $449);
      $502 = Math_fround($501 + $500);
      HEAPF32[$77>>2] = $502;
      $fabsf$i$i2$2$i$1$i = (Math_fround(Math_abs((Math_fround($502)))));
      $503 = Math_fround($fabsf$i$i2$2$i$1$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$78>>2] = $503;
      $504 = Math_fround($414 * $440);
      $505 = Math_fround($415 * $441);
      $506 = Math_fround($504 + $505);
      $507 = Math_fround($416 * $442);
      $508 = Math_fround($507 + $506);
      HEAPF32[$79>>2] = $508;
      $fabsf$i$i2$i$2$i = (Math_fround(Math_abs((Math_fround($508)))));
      $509 = Math_fround($fabsf$i$i2$i$2$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$80>>2] = $509;
      $510 = Math_fround($414 * $443);
      $511 = Math_fround($415 * $445);
      $512 = Math_fround($510 + $511);
      $513 = Math_fround($416 * $446);
      $514 = Math_fround($513 + $512);
      HEAPF32[$81>>2] = $514;
      $fabsf$i$i2$1$i$2$i = (Math_fround(Math_abs((Math_fround($514)))));
      $515 = Math_fround($fabsf$i$i2$1$i$2$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$82>>2] = $515;
      $516 = Math_fround($414 * $447);
      $517 = Math_fround($415 * $448);
      $518 = Math_fround($516 + $517);
      $519 = Math_fround($416 * $449);
      $520 = Math_fround($519 + $518);
      HEAPF32[$83>>2] = $520;
      $fabsf$i$i2$2$i$2$i = (Math_fround(Math_abs((Math_fround($520)))));
      $521 = Math_fround($fabsf$i$i2$2$i$2$i + Math_fround(9.99999997475242707878E-7));
      HEAPF32[$84>>2] = $521;
      $522 = Math_fround(HEAPF32[$86>>2]);
      $523 = Math_fround(HEAPF32[$87>>2]);
      $524 = Math_fround(HEAPF32[$88>>2]);
      $525 = Math_fround(HEAPF32[$85>>2]);
      $526 = Math_fround($522 * $473);
      $527 = Math_fround($523 * $479);
      $528 = Math_fround($527 + $526);
      $529 = Math_fround($524 * $485);
      $530 = Math_fround($529 + $528);
      $fabsf$i$i1$i$i13 = (Math_fround(Math_abs((Math_fround($457)))));
      $531 = Math_fround($525 + $530);
      $532 = Math_fround($531 - $fabsf$i$i1$i$i13);
      $533 = $532 < Math_fround(0.0);
      L48: do {
       if ($533) {
        $$0$i$i = 0;$603 = Math_fround(0.0);$605 = Math_fround(0.0);$608 = Math_fround(0.0);$minD$1$4$i72$i = Math_fround(0.0);
       } else {
        $537 = $532;$i1$07$i$i14 = 0;
        while(1) {
         $536 = (($overlap$i$i) + ($i1$07$i$i14<<2)|0);
         HEAPF32[$536>>2] = $537;
         $538 = (($i1$07$i$i14) + 1)|0;
         $539 = ($538>>>0)<(3);
         if (!($539)) {
          break;
         }
         $$phi$trans$insert27$i$i = (($T$i$i) + ($538<<2)|0);
         $$pre28$i$i = Math_fround(HEAPF32[$$phi$trans$insert27$i$i>>2]);
         $$phi$trans$insert$i = ((($FR$i$i) + (($538*12)|0)|0) + 4|0);
         $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
         $$phi$trans$insert75$i = ((($FR$i$i) + (($538*12)|0)|0) + 8|0);
         $$pre76$i = Math_fround(HEAPF32[$$phi$trans$insert75$i>>2]);
         $540 = (($85) + ($538<<2)|0);
         $541 = Math_fround(HEAPF32[$540>>2]);
         $542 = (($FR$i$i) + (($538*12)|0)|0);
         $543 = Math_fround(HEAPF32[$542>>2]);
         $544 = Math_fround($522 * $543);
         $545 = Math_fround($523 * $$pre$i);
         $546 = Math_fround($545 + $544);
         $547 = Math_fround($524 * $$pre76$i);
         $548 = Math_fround($547 + $546);
         $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($$pre28$i$i)))));
         $549 = Math_fround($541 + $548);
         $550 = Math_fround($549 - $fabsf$i$i1$i$i);
         $551 = $550 < Math_fround(0.0);
         if ($551) {
          $$0$i$i = 0;$603 = Math_fround(0.0);$605 = Math_fround(0.0);$608 = Math_fround(0.0);$minD$1$4$i72$i = Math_fround(0.0);
          break L48;
         } else {
          $537 = $550;$i1$07$i$i14 = $538;
         }
        }
        $534 = Math_fround(HEAPF32[$89>>2]);
        $535 = Math_fround(HEAPF32[$90>>2]);
        $553 = $473;$555 = $491;$558 = $509;$561 = $472;$563 = $490;$566 = $508;$569 = $522;$k2$04$i$i = 0;
        while(1) {
         $552 = Math_fround($525 * $553);
         $554 = Math_fround($534 * $555);
         $556 = Math_fround($554 + $552);
         $557 = Math_fround($535 * $558);
         $559 = Math_fround($557 + $556);
         $560 = Math_fround($457 * $561);
         $562 = Math_fround($462 * $563);
         $564 = Math_fround($562 + $560);
         $565 = Math_fround($467 * $566);
         $567 = Math_fround($565 + $564);
         $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($567)))));
         $568 = Math_fround($569 + $559);
         $570 = Math_fround($568 - $fabsf$i$i$i$i);
         $571 = $570 < Math_fround(0.0);
         if ($571) {
          $$0$i$i = 0;$603 = Math_fround(0.0);$605 = Math_fround(0.0);$608 = Math_fround(0.0);$minD$1$4$i72$i = Math_fround(0.0);
          break L48;
         }
         $572 = (($k2$04$i$i) + 3)|0;
         $573 = (($overlap$i$i) + ($572<<2)|0);
         HEAPF32[$573>>2] = $570;
         $574 = (($k2$04$i$i) + 1)|0;
         $575 = ($574>>>0)<(3);
         if (!($575)) {
          break;
         }
         $$phi$trans$insert29$i$i = (($86) + ($574<<2)|0);
         $$pre30$i$i = Math_fround(HEAPF32[$$phi$trans$insert29$i$i>>2]);
         $$phi$trans$insert77$i = ((($FR$i$i) + ($574<<2)|0) + 12|0);
         $$pre78$i = Math_fround(HEAPF32[$$phi$trans$insert77$i>>2]);
         $$phi$trans$insert79$i = ((($FR$i$i) + ($574<<2)|0) + 24|0);
         $$pre80$i = Math_fround(HEAPF32[$$phi$trans$insert79$i>>2]);
         $$phi$trans$insert81$i = ((($R$i$i) + ($574<<2)|0) + 12|0);
         $$pre82$i = Math_fround(HEAPF32[$$phi$trans$insert81$i>>2]);
         $$phi$trans$insert83$i = ((($R$i$i) + ($574<<2)|0) + 24|0);
         $$pre84$i = Math_fround(HEAPF32[$$phi$trans$insert83$i>>2]);
         $$phi$trans$insert = (($FR$i$i) + ($574<<2)|0);
         $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
         $$phi$trans$insert23 = (($R$i$i) + ($574<<2)|0);
         $$pre24 = Math_fround(HEAPF32[$$phi$trans$insert23>>2]);
         $553 = $$pre;$555 = $$pre78$i;$558 = $$pre80$i;$561 = $$pre24;$563 = $$pre82$i;$566 = $$pre84$i;$569 = $$pre30$i$i;$k2$04$i$i = $574;
        }
        $576 = Math_fround(HEAPF32[$overlap$i$i>>2]);
        $577 = Math_fround(HEAPF32[$91>>2]);
        $578 = $577 < $576;
        $minIndex$1$i$i = $578&1;
        $minD$1$i$i = $578 ? $577 : $576;
        $579 = Math_fround(HEAPF32[$92>>2]);
        $580 = $579 < $minD$1$i$i;
        $minIndex$1$1$i$i = $580 ? 2 : $minIndex$1$i$i;
        $minD$1$1$i$i = $580 ? $579 : $minD$1$i$i;
        $581 = Math_fround(HEAPF32[$93>>2]);
        $582 = $581 < $minD$1$1$i$i;
        $minIndex$1$2$i$i = $582 ? 3 : $minIndex$1$1$i$i;
        $minD$1$2$i$i = $582 ? $581 : $minD$1$1$i$i;
        $583 = Math_fround(HEAPF32[$94>>2]);
        $584 = $583 < $minD$1$2$i$i;
        $minIndex$1$3$i$i = $584 ? 4 : $minIndex$1$2$i$i;
        $minD$1$3$i$i = $584 ? $583 : $minD$1$2$i$i;
        $585 = Math_fround(HEAPF32[$95>>2]);
        $586 = $585 < $minD$1$3$i$i;
        $minIndex$1$4$i$i = $586 ? 5 : $minIndex$1$3$i$i;
        $minD$1$4$i$i = $586 ? $585 : $minD$1$3$i$i;
        switch ($minIndex$1$4$i$i|0) {
        case 0:  {
         $$0$i$i = 1;$603 = $407;$605 = $408;$608 = $409;$minD$1$4$i72$i = $minD$1$4$i$i;
         break L48;
         break;
        }
        case 3:  {
         $$0$i$i = 1;$603 = $440;$605 = $441;$608 = $442;$minD$1$4$i72$i = $minD$1$4$i$i;
         break L48;
         break;
        }
        case 4:  {
         $$0$i$i = 1;$603 = $443;$605 = $445;$608 = $446;$minD$1$4$i72$i = $minD$1$4$i$i;
         break L48;
         break;
        }
        case 1:  {
         $$0$i$i = 1;$603 = $410;$605 = $412;$608 = $413;$minD$1$4$i72$i = $minD$1$4$i$i;
         break L48;
         break;
        }
        case 5:  {
         $$0$i$i = 1;$603 = $447;$605 = $448;$608 = $449;$minD$1$4$i72$i = $minD$1$4$i$i;
         break L48;
         break;
        }
        case 2:  {
         $$0$i$i = 1;$603 = $414;$605 = $415;$608 = $416;$minD$1$4$i72$i = $minD$1$4$i$i;
         break L48;
         break;
        }
        default: {
         $$0$i$i = 1;$603 = Math_fround(0.0);$605 = Math_fround(0.0);$608 = Math_fround(0.0);$minD$1$4$i72$i = $minD$1$4$i$i;
         break L48;
        }
        }
       }
      } while(0);
      if (!($$0$i$i)) {
       break;
      }
      $587 = +HEAPF64[$obb0$i>>3];
      $588 = Math_fround($587);
      $589 = +HEAPF64[$55>>3];
      $590 = Math_fround($589);
      $591 = +HEAPF64[$56>>3];
      $592 = Math_fround($591);
      $593 = +HEAPF64[$obb1$i>>3];
      $594 = Math_fround($593);
      $595 = +HEAPF64[$61>>3];
      $596 = Math_fround($595);
      $597 = +HEAPF64[$62>>3];
      $598 = Math_fround($597);
      $599 = Math_fround($588 - $594);
      $600 = Math_fround($590 - $596);
      $601 = Math_fround($592 - $598);
      $602 = Math_fround($603 * $599);
      $604 = Math_fround($605 * $600);
      $606 = Math_fround($602 + $604);
      $607 = Math_fround($608 * $601);
      $609 = Math_fround($606 + $607);
      $610 = $609 < Math_fround(0.0);
      if ($610) {
       $611 = Math_fround(-$603);
       $612 = Math_fround(-$605);
       $613 = Math_fround(-$608);
       $621 = $611;$623 = $612;$626 = $613;
      } else {
       $621 = $603;$623 = $605;$626 = $608;
      }
      $614 = (($entity1$entity0$i) + 332|0);
      $615 = Math_fround(HEAPF32[$614>>2]);
      $616 = (($entity1$entity0$i) + 336|0);
      $617 = Math_fround(HEAPF32[$616>>2]);
      $618 = (($entity1$entity0$i) + 340|0);
      $619 = Math_fround(HEAPF32[$618>>2]);
      $620 = Math_fround($621 * $615);
      $622 = Math_fround($623 * $617);
      $624 = Math_fround($620 + $622);
      $625 = Math_fround($626 * $619);
      $627 = Math_fround($624 + $625);
      $628 = Math_fround($615 * $627);
      $629 = Math_fround($617 * $627);
      $630 = Math_fround($619 * $627);
      $631 = Math_fround($621 - $628);
      $632 = Math_fround($623 - $629);
      $633 = Math_fround($626 - $630);
      $634 = Math_fround($631 * $631);
      $635 = Math_fround($632 * $632);
      $636 = Math_fround($634 + $635);
      $637 = Math_fround($633 * $633);
      $638 = Math_fround($637 + $636);
      $639 = $638 > Math_fround(0.0);
      if ($639) {
       $640 = (Math_fround(Math_sqrt((Math_fround($638)))));
       $641 = Math_fround(Math_fround(1.0) / $640);
       $642 = Math_fround($631 * $641);
       $643 = Math_fround($632 * $641);
       $644 = Math_fround($633 * $641);
       $648 = $642;$650 = $643;$652 = $644;$overlap$3$i = $minD$1$4$i72$i;
      } else {
       $648 = Math_fround(0.0);$650 = Math_fround(0.0);$652 = Math_fround(0.0);$overlap$3$i = $minD$1$4$i72$i;
      }
     }
     $645 = $overlap$3$i != Math_fround(0.0);
     if ($645) {
      $646 = $overlap$3$i > $96;
      $overlap$4$i = $646 ? $96 : $overlap$3$i;
      $647 = Math_fround($648 * $overlap$4$i);
      $649 = Math_fround($650 * $overlap$4$i);
      $651 = Math_fround($652 * $overlap$4$i);
      $653 = Math_fround($647 * Math_fround(0.5));
      $654 = Math_fround($649 * Math_fround(0.5));
      $655 = Math_fround($651 * Math_fround(0.5));
      $656 = (($entity1$entity0$i) + 444|0);
      $657 = Math_fround(HEAPF32[$656>>2]);
      $658 = Math_fround($653 + $657);
      HEAPF32[$656>>2] = $658;
      $659 = (($entity1$entity0$i) + 448|0);
      $660 = Math_fround(HEAPF32[$659>>2]);
      $661 = Math_fround($654 + $660);
      HEAPF32[$659>>2] = $661;
      $662 = (($entity1$entity0$i) + 452|0);
      $663 = Math_fround(HEAPF32[$662>>2]);
      $664 = Math_fround($655 + $663);
      HEAPF32[$662>>2] = $664;
      $665 = (($entity0$entity1$i) + 444|0);
      $666 = Math_fround(HEAPF32[$665>>2]);
      $667 = Math_fround($666 - $653);
      HEAPF32[$665>>2] = $667;
      $668 = (($entity0$entity1$i) + 448|0);
      $669 = Math_fround(HEAPF32[$668>>2]);
      $670 = Math_fround($669 - $654);
      HEAPF32[$668>>2] = $670;
      $671 = (($entity0$entity1$i) + 452|0);
      $672 = Math_fround(HEAPF32[$671>>2]);
      $673 = Math_fround($672 - $655);
      HEAPF32[$671>>2] = $673;
     }
    }
   } while(0);
   $166 = ($144|0)==(0);
   if ($166) {
    break;
   } else {
    $$in = $144;$indices$016 = $147;
   }
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$10);
 $674 = HEAP32[$47>>2]|0;
 $675 = $674 & 2147483647;
 $676 = ($675|0)!=(0);
 $677 = ($674|0)>(-1);
 $or$cond$i$i = $676 & $677;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $678 = HEAP32[$pairs>>2]|0;
 $679 = ($678|0)==(0|0);
 if ($679) {
  STACKTOP = sp;return;
 }
 $680 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $681 = HEAP32[$680>>2]|0;
 $682 = (($681) + 12|0);
 $683 = HEAP32[$682>>2]|0;
 FUNCTION_TABLE_vii[$683 & 4095]($680,$678);
 STACKTOP = sp;return;
}
function __Z25PxCreateControllerManagerRN5physx7PxSceneE($scene) {
 $scene = $scene|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN5physx6shdfnd10Foundation11incRefCountEv();
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 405496 : 405464;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,136,$$$i$i$i,405224,686)|0);
 HEAP32[$9>>2] = ((405136 + 8|0));
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $scene;
 $11 = (($9) + 8|0);
 $12 = (($9) + 100|0);
 dest=$11+0|0; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$12>>2] = Math_fround(0.75);
 $13 = (($9) + 104|0);
 HEAP32[$13>>2] = -1;
 $14 = (($9) + 108|0);
 HEAP32[$14>>2] = 0;
 $15 = (($9) + 112|0);
 HEAP32[$15>>2] = 0;
 $16 = (($9) + 76|0);
 __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($16,64);
 $17 = (($9) + 116|0);
 HEAP32[$17>>2] = 0;
 $18 = (($9) + 120|0);
 HEAP32[$18>>2] = 0;
 $19 = (($9) + 124|0);
 HEAP32[$19>>2] = 0;
 $20 = (($9) + 128|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($9) + 132|0);
 HEAP8[$21>>0] = 0;
 $22 = (($9) + 133|0);
 HEAP8[$22>>0] = 1;
 $23 = (($9) + 134|0);
 HEAP8[$23>>0] = 1;
 $24 = (($9) + 135|0);
 HEAP8[$24>>0] = 0;
 STACKTOP = sp;return ($9|0);
}
function __ZN5physx3Cct26CharacterControllerManager16createControllerERNS_9PxPhysicsEPNS_7PxSceneERKNS_16PxControllerDescE($this,$physics,$scene,$desc) {
 $this = $this|0;
 $physics = $physics|0;
 $scene = $scene|0;
 $desc = $desc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15PxGetFoundationv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_viiiii[$7 & 255]($4,2,406944,407040,136);
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iii[$10 & 4095]($this,$desc)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN5physx6shdfnd5ArrayINS_17PxExtendedCapsuleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_17PxExtendedCapsuleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*56)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*56)|0)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   dest=$$01$i+0|0; src=$a+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $11 = (($$01$i) + 56|0);
  $12 = ($11>>>0)<($7>>>0);
  if ($12) {
   $$01$i = $11;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_17PxExtendedCapsuleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*56)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 405728 : 405464;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,405648,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*56)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    dest=$$012$i+0|0; src=$$03$i+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $20 = (($$012$i) + 56|0);
   $21 = (($$03$i) + 56|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_13PxExtendedBoxENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_13PxExtendedBoxENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*56)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*56)|0)|0);
 $10 = (($a) + 24|0);
 $11 = (($a) + 28|0);
 $12 = (($a) + 32|0);
 $13 = (($a) + 36|0);
 $14 = (($a) + 40|0);
 $15 = (($a) + 44|0);
 $16 = (($a) + 48|0);
 $$01$i = $9;
 while(1) {
  $17 = ($$01$i|0)==(0|0);
  if (!($17)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$$01$i+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$$01$i+20>>2]=HEAP32[$a+20>>2]|0;
   $18 = (($$01$i) + 24|0);
   $19 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$18>>2] = $19;
   $20 = (($$01$i) + 28|0);
   $21 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$20>>2] = $21;
   $22 = (($$01$i) + 32|0);
   $23 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$22>>2] = $23;
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$$01$i+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$$01$i+20>>2]=HEAP32[$a+20>>2]|0;
   $24 = (($$01$i) + 36|0);
   $25 = Math_fround(HEAPF32[$13>>2]);
   HEAPF32[$24>>2] = $25;
   $26 = (($$01$i) + 40|0);
   $27 = Math_fround(HEAPF32[$14>>2]);
   HEAPF32[$26>>2] = $27;
   $28 = (($$01$i) + 44|0);
   $29 = Math_fround(HEAPF32[$15>>2]);
   HEAPF32[$28>>2] = $29;
   $30 = (($$01$i) + 48|0);
   $31 = Math_fround(HEAPF32[$16>>2]);
   HEAPF32[$30>>2] = $31;
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$$01$i+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$$01$i+20>>2]=HEAP32[$a+20>>2]|0;
  }
  $32 = (($$01$i) + 56|0);
  $33 = ($32>>>0)<($7>>>0);
  if ($33) {
   $$01$i = $32;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_13PxExtendedBoxENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*56)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 405856 : 405464;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,405648,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*56)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;
    $20 = (($$012$i) + 24|0);
    $21 = (($$03$i) + 24|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    HEAPF32[$20>>2] = $22;
    $23 = (($$012$i) + 28|0);
    $24 = (($$03$i) + 28|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    HEAPF32[$23>>2] = $25;
    $26 = (($$012$i) + 32|0);
    $27 = (($$03$i) + 32|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;
    $29 = (($$012$i) + 36|0);
    $30 = (($$03$i) + 36|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 40|0);
    $33 = (($$03$i) + 40|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
    $35 = (($$012$i) + 44|0);
    $36 = (($$03$i) + 44|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 48|0);
    $39 = (($$03$i) + 48|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;
   }
   $41 = (($$012$i) + 56|0);
   $42 = (($$03$i) + 56|0);
   $43 = ($41>>>0)<($15>>>0);
   if ($43) {
    $$012$i = $41;$$03$i = $42;
   } else {
    break;
   }
  }
 }
 $44 = (($this) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)>(-1);
 if (!($46)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$44>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $47 = HEAP32[$this>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  HEAP32[$this>>2] = $16;
  HEAP32[$44>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $49 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095]($49,$47);
 HEAP32[$this>>2] = $16;
 HEAP32[$44>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPKvNS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 405976 : 405464;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,405648,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_3Cct15ObstacleContextENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 406080 : 405464;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,405648,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre11 = 0, $$pre11$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $36 = $1 << 1;
  $$$i = $2 ? 16 : $36;
  $37 = ($1>>>0)<($$$i>>>0);
  if ($37) {
   __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $$pre11$pre = HEAP32[$33>>2]|0;
   $$pre11 = $$pre11$pre;$54 = $$pre;
  } else {
   $$pre11 = -1;$54 = $1;
  }
  $38 = HEAP32[$k>>2]|0;
  $39 = $38;
  $40 = $39 << 15;
  $41 = $40 ^ -1;
  $42 = (($39) + ($41))|0;
  $43 = $42 >>> 10;
  $44 = $43 ^ $42;
  $45 = ($44*9)|0;
  $46 = $45 >>> 6;
  $47 = $46 ^ $45;
  $48 = $47 << 11;
  $49 = $48 ^ -1;
  $50 = (($47) + ($49))|0;
  $51 = $50 >>> 16;
  $52 = $51 ^ $50;
  $53 = (($54) + -1)|0;
  $55 = $52 & $53;
  $59 = $$pre11;$h$1 = $55;
 } else {
  $59 = $34;$h$1 = $h$0;
 }
 $56 = (($this) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($59<<2)|0);
 $60 = HEAP32[$58>>2]|0;
 HEAP32[$33>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$58>>2] = $64;
 HEAP32[$63>>2] = $59;
 $65 = (($this) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $68 = (($this) + 32|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$68>>2] = $70;
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($59<<2)|0);
 $$0 = $73;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,406344,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
    $44 = $43 << 15;
    $45 = $44 ^ -1;
    $46 = (($43) + ($45))|0;
    $47 = $46 >>> 10;
    $48 = $47 ^ $46;
    $49 = ($48*9)|0;
    $50 = $49 >>> 6;
    $51 = $50 ^ $49;
    $52 = $51 << 11;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 16;
    $56 = $55 ^ $54;
    $57 = $56 & $39;
    $58 = (($32) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($33) + ($index$01<<2)|0);
    HEAP32[$60>>2] = $59;
    HEAP32[$58>>2] = $index$01;
    $61 = (($34) + ($index$01<<2)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     HEAP32[$61>>2] = $42;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre13 = (($this) + 20|0);
  $$pre14 = (($this) + 8|0);
  $$pre$phi15Z2D = $$pre14;$$pre$phiZ2D = $$pre13;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $117 = $71;$bucket$06 = 0;
   while(1) {
    $76 = HEAP32[$73>>2]|0;
    $77 = (($76) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$77>>2]|0;
    $78 = ($index1$02|0)==(-1);
    if ($78) {
     $107 = $117;
    } else {
     $index1$03 = $index1$02;
     while(1) {
      $79 = HEAP32[$74>>2]|0;
      $80 = (($79) + ($index1$03<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81;
      $83 = $82 << 15;
      $84 = $83 ^ -1;
      $85 = (($82) + ($84))|0;
      $86 = $85 >>> 10;
      $87 = $86 ^ $85;
      $88 = ($87*9)|0;
      $89 = $88 >>> 6;
      $90 = $89 ^ $88;
      $91 = $90 << 11;
      $92 = $91 ^ -1;
      $93 = (($90) + ($92))|0;
      $94 = $93 >>> 16;
      $95 = $94 ^ $93;
      $96 = $95 & $75;
      $97 = (($32) + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($33) + ($index1$03<<2)|0);
      HEAP32[$99>>2] = $98;
      HEAP32[$97>>2] = $index1$03;
      $100 = (($34) + ($index1$03<<2)|0);
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       HEAP32[$100>>2] = $81;
      }
      $102 = HEAP32[$66>>2]|0;
      $103 = (($102) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$103>>2]|0;
      $104 = ($index1$0|0)==(-1);
      if ($104) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre = HEAP32[$70>>2]|0;
     $107 = $$pre;
    }
    $105 = (($bucket$06) + 1)|0;
    $106 = ($105>>>0)<($107>>>0);
    if ($106) {
     $117 = $107;$bucket$06 = $105;
    } else {
     $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $108 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$108);
 HEAP32[$this>>2] = $32;
 $109 = (($this) + 12|0);
 HEAP32[$109>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi15Z2D>>2] = $33;
 $110 = (($this) + 4|0);
 HEAP32[$110>>2] = $34;
 HEAP32[$18>>2] = $24;
 $111 = (($24) + -1)|0;
 $112 = ($111>>>0)>($19>>>0);
 if ($112) {
  $i$01$i = $19;
 } else {
  $115 = HEAP32[$15>>2]|0;
  $116 = (($33) + ($111<<2)|0);
  HEAP32[$116>>2] = $115;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $113 = (($i$01$i) + 1)|0;
  $114 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$114>>2] = $113;
  $exitcond$i = ($113|0)==($111|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 $115 = HEAP32[$15>>2]|0;
 $116 = (($33) + ($111<<2)|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_3Cct10ControllerENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 406432 : 405464;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,405648,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx2Cm12RenderBufferD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Cm12RenderBufferD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12RenderBufferD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Cm12RenderBufferD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12RenderBuffer11getNbPointsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Cm12RenderBuffer9getPointsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Cm12RenderBuffer10getNbLinesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Cm12RenderBuffer8getLinesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Cm12RenderBuffer14getNbTrianglesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Cm12RenderBuffer12getTrianglesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Cm12RenderBuffer10getNbTextsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Cm12RenderBuffer8getTextsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12RenderBuffer6appendERKNS_14PxRenderBufferE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$01$i = 0, $$01$i1 = 0, $$01$i3 = 0, $$01$i6 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i7 = 0, $$pre$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0;
 var $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0;
 var $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0;
 var $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0;
 var $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$other>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($other)|0);
 $5 = HEAP32[$other>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($other)|0);
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($8))|0;
 $12 = (($this) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14>>>0)<($11>>>0);
 if ($15) {
  __ZN5physx6shdfnd5ArrayINS_12PxDebugPointENS0_19ReflectionAllocatorIS2_EEE8recreateEj($0,$11);
 }
 $16 = (($4) + ($8<<4)|0);
 $17 = ($8|0)>(0);
 if ($17) {
  $$01$i = $4;
  while(1) {
   $18 = HEAP32[$12>>2]|0;
   $19 = $18 & 2147483647;
   $20 = HEAP32[$9>>2]|0;
   $21 = ($19>>>0)>($20>>>0);
   if ($21) {
    $22 = HEAP32[$0>>2]|0;
    $23 = (($22) + ($20<<4)|0);
    $24 = ($23|0)==(0|0);
    if ($24) {
     $36 = $20;
    } else {
     $25 = Math_fround(HEAPF32[$$01$i>>2]);
     HEAPF32[$23>>2] = $25;
     $26 = ((($22) + ($20<<4)|0) + 4|0);
     $27 = (($$01$i) + 4|0);
     $28 = Math_fround(HEAPF32[$27>>2]);
     HEAPF32[$26>>2] = $28;
     $29 = ((($22) + ($20<<4)|0) + 8|0);
     $30 = (($$01$i) + 8|0);
     $31 = Math_fround(HEAPF32[$30>>2]);
     HEAPF32[$29>>2] = $31;
     $32 = ((($22) + ($20<<4)|0) + 12|0);
     $33 = (($$01$i) + 12|0);
     $34 = HEAP32[$33>>2]|0;
     HEAP32[$32>>2] = $34;
     $$pre$i$i = HEAP32[$9>>2]|0;
     $36 = $$pre$i$i;
    }
    $35 = (($36) + 1)|0;
    HEAP32[$9>>2] = $35;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_12PxDebugPointENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($0,$$01$i)|0);
   }
   $37 = (($$01$i) + 16|0);
   $38 = ($37>>>0)<($16>>>0);
   if ($38) {
    $$01$i = $37;
   } else {
    break;
   }
  }
 }
 $39 = (($this) + 16|0);
 $40 = HEAP32[$other>>2]|0;
 $41 = (($40) + 20|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (FUNCTION_TABLE_ii[$42 & 4095]($other)|0);
 $44 = HEAP32[$other>>2]|0;
 $45 = (($44) + 16|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (FUNCTION_TABLE_ii[$46 & 4095]($other)|0);
 $48 = (($this) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + ($47))|0;
 $51 = (($this) + 24|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 & 2147483647;
 $54 = ($53>>>0)<($50>>>0);
 if ($54) {
  __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE8recreateEj($39,$50);
 }
 $55 = (($43) + ($47<<5)|0);
 $56 = ($47|0)>(0);
 if ($56) {
  $$01$i1 = $43;
  while(1) {
   $57 = HEAP32[$51>>2]|0;
   $58 = $57 & 2147483647;
   $59 = HEAP32[$48>>2]|0;
   $60 = ($58>>>0)>($59>>>0);
   if ($60) {
    $61 = HEAP32[$39>>2]|0;
    $62 = (($61) + ($59<<5)|0);
    $63 = ($62|0)==(0|0);
    if ($63) {
     $87 = $59;
    } else {
     $64 = Math_fround(HEAPF32[$$01$i1>>2]);
     HEAPF32[$62>>2] = $64;
     $65 = ((($61) + ($59<<5)|0) + 4|0);
     $66 = (($$01$i1) + 4|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     HEAPF32[$65>>2] = $67;
     $68 = ((($61) + ($59<<5)|0) + 8|0);
     $69 = (($$01$i1) + 8|0);
     $70 = Math_fround(HEAPF32[$69>>2]);
     HEAPF32[$68>>2] = $70;
     $71 = ((($61) + ($59<<5)|0) + 12|0);
     $72 = (($$01$i1) + 12|0);
     $73 = HEAP32[$72>>2]|0;
     HEAP32[$71>>2] = $73;
     $74 = ((($61) + ($59<<5)|0) + 16|0);
     $75 = (($$01$i1) + 16|0);
     $76 = Math_fround(HEAPF32[$75>>2]);
     HEAPF32[$74>>2] = $76;
     $77 = ((($61) + ($59<<5)|0) + 20|0);
     $78 = (($$01$i1) + 20|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     HEAPF32[$77>>2] = $79;
     $80 = ((($61) + ($59<<5)|0) + 24|0);
     $81 = (($$01$i1) + 24|0);
     $82 = Math_fround(HEAPF32[$81>>2]);
     HEAPF32[$80>>2] = $82;
     $83 = ((($61) + ($59<<5)|0) + 28|0);
     $84 = (($$01$i1) + 28|0);
     $85 = HEAP32[$84>>2]|0;
     HEAP32[$83>>2] = $85;
     $$pre$i = HEAP32[$48>>2]|0;
     $87 = $$pre$i;
    }
    $86 = (($87) + 1)|0;
    HEAP32[$48>>2] = $86;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($39,$$01$i1)|0);
   }
   $88 = (($$01$i1) + 32|0);
   $89 = ($88>>>0)<($55>>>0);
   if ($89) {
    $$01$i1 = $88;
   } else {
    break;
   }
  }
 }
 $90 = (($this) + 28|0);
 $91 = HEAP32[$other>>2]|0;
 $92 = (($91) + 28|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (FUNCTION_TABLE_ii[$93 & 4095]($other)|0);
 $95 = HEAP32[$other>>2]|0;
 $96 = (($95) + 24|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = (FUNCTION_TABLE_ii[$97 & 4095]($other)|0);
 $99 = (($this) + 32|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) + ($98))|0;
 $102 = (($this) + 36|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = $103 & 2147483647;
 $105 = ($104>>>0)<($101>>>0);
 if ($105) {
  __ZN5physx6shdfnd5ArrayINS_15PxDebugTriangleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($90,$101);
 }
 $106 = (($94) + (($98*48)|0)|0);
 $107 = ($98|0)>(0);
 if ($107) {
  $$01$i3 = $94;
  while(1) {
   $108 = HEAP32[$102>>2]|0;
   $109 = $108 & 2147483647;
   $110 = HEAP32[$99>>2]|0;
   $111 = ($109>>>0)>($110>>>0);
   if ($111) {
    $112 = HEAP32[$90>>2]|0;
    $113 = (($112) + (($110*48)|0)|0);
    $114 = ($113|0)==(0|0);
    if ($114) {
     $150 = $110;
    } else {
     $115 = Math_fround(HEAPF32[$$01$i3>>2]);
     HEAPF32[$113>>2] = $115;
     $116 = ((($112) + (($110*48)|0)|0) + 4|0);
     $117 = (($$01$i3) + 4|0);
     $118 = Math_fround(HEAPF32[$117>>2]);
     HEAPF32[$116>>2] = $118;
     $119 = ((($112) + (($110*48)|0)|0) + 8|0);
     $120 = (($$01$i3) + 8|0);
     $121 = Math_fround(HEAPF32[$120>>2]);
     HEAPF32[$119>>2] = $121;
     $122 = ((($112) + (($110*48)|0)|0) + 12|0);
     $123 = (($$01$i3) + 12|0);
     $124 = HEAP32[$123>>2]|0;
     HEAP32[$122>>2] = $124;
     $125 = ((($112) + (($110*48)|0)|0) + 16|0);
     $126 = (($$01$i3) + 16|0);
     $127 = Math_fround(HEAPF32[$126>>2]);
     HEAPF32[$125>>2] = $127;
     $128 = ((($112) + (($110*48)|0)|0) + 20|0);
     $129 = (($$01$i3) + 20|0);
     $130 = Math_fround(HEAPF32[$129>>2]);
     HEAPF32[$128>>2] = $130;
     $131 = ((($112) + (($110*48)|0)|0) + 24|0);
     $132 = (($$01$i3) + 24|0);
     $133 = Math_fround(HEAPF32[$132>>2]);
     HEAPF32[$131>>2] = $133;
     $134 = ((($112) + (($110*48)|0)|0) + 28|0);
     $135 = (($$01$i3) + 28|0);
     $136 = HEAP32[$135>>2]|0;
     HEAP32[$134>>2] = $136;
     $137 = ((($112) + (($110*48)|0)|0) + 32|0);
     $138 = (($$01$i3) + 32|0);
     $139 = Math_fround(HEAPF32[$138>>2]);
     HEAPF32[$137>>2] = $139;
     $140 = ((($112) + (($110*48)|0)|0) + 36|0);
     $141 = (($$01$i3) + 36|0);
     $142 = Math_fround(HEAPF32[$141>>2]);
     HEAPF32[$140>>2] = $142;
     $143 = ((($112) + (($110*48)|0)|0) + 40|0);
     $144 = (($$01$i3) + 40|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     HEAPF32[$143>>2] = $145;
     $146 = ((($112) + (($110*48)|0)|0) + 44|0);
     $147 = (($$01$i3) + 44|0);
     $148 = HEAP32[$147>>2]|0;
     HEAP32[$146>>2] = $148;
     $$pre$i8 = HEAP32[$99>>2]|0;
     $150 = $$pre$i8;
    }
    $149 = (($150) + 1)|0;
    HEAP32[$99>>2] = $149;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_15PxDebugTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($90,$$01$i3)|0);
   }
   $151 = (($$01$i3) + 48|0);
   $152 = ($151>>>0)<($106>>>0);
   if ($152) {
    $$01$i3 = $151;
   } else {
    break;
   }
  }
 }
 $153 = (($this) + 40|0);
 $154 = HEAP32[$other>>2]|0;
 $155 = (($154) + 36|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = (FUNCTION_TABLE_ii[$156 & 4095]($other)|0);
 $158 = HEAP32[$other>>2]|0;
 $159 = (($158) + 32|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = (FUNCTION_TABLE_ii[$160 & 4095]($other)|0);
 $162 = (($this) + 44|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = (($163) + ($161))|0;
 $165 = (($this) + 48|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = $166 & 2147483647;
 $168 = ($167>>>0)<($164>>>0);
 if ($168) {
  __ZN5physx6shdfnd5ArrayINS_11PxDebugTextENS0_19ReflectionAllocatorIS2_EEE8recreateEj($153,$164);
 }
 $169 = (($157) + (($161*24)|0)|0);
 $170 = ($161|0)>(0);
 if (!($170)) {
  STACKTOP = sp;return;
 }
 $$01$i6 = $157;
 while(1) {
  $171 = HEAP32[$165>>2]|0;
  $172 = $171 & 2147483647;
  $173 = HEAP32[$162>>2]|0;
  $174 = ($172>>>0)>($173>>>0);
  if ($174) {
   $175 = HEAP32[$153>>2]|0;
   $176 = (($175) + (($173*24)|0)|0);
   $177 = ($176|0)==(0|0);
   if ($177) {
    $188 = $173;
   } else {
    $178 = Math_fround(HEAPF32[$$01$i6>>2]);
    HEAPF32[$176>>2] = $178;
    $179 = ((($175) + (($173*24)|0)|0) + 4|0);
    $180 = (($$01$i6) + 4|0);
    $181 = Math_fround(HEAPF32[$180>>2]);
    HEAPF32[$179>>2] = $181;
    $182 = ((($175) + (($173*24)|0)|0) + 8|0);
    $183 = (($$01$i6) + 8|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    HEAPF32[$182>>2] = $184;
    $185 = ((($175) + (($173*24)|0)|0) + 12|0);
    $186 = (($$01$i6) + 12|0);
    ;HEAP32[$185+0>>2]=HEAP32[$186+0>>2]|0;HEAP32[$185+4>>2]=HEAP32[$186+4>>2]|0;HEAP32[$185+8>>2]=HEAP32[$186+8>>2]|0;
    $$pre$i$i7 = HEAP32[$162>>2]|0;
    $188 = $$pre$i$i7;
   }
   $187 = (($188) + 1)|0;
   HEAP32[$162>>2] = $187;
  } else {
   (__ZN5physx6shdfnd5ArrayINS_11PxDebugTextENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($153,$$01$i6)|0);
  }
  $189 = (($$01$i6) + 24|0);
  $190 = ($189>>>0)<($169>>>0);
  if ($190) {
   $$01$i6 = $189;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12RenderBuffer5clearEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 44|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 56|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11PxDebugTextENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*24)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 407192 : 405464;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,405648,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*24)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    ;HEAP32[$32+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$33+8>>2]|0;
   }
   $34 = (($$012$i) + 24|0);
   $35 = (($$03$i) + 24|0);
   $36 = ($34>>>0)<($20>>>0);
   if ($36) {
    $$012$i = $34;$$03$i = $35;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $38 = $$pre;
 } else {
  $38 = $19;
 }
 $37 = (($21) + (($38*24)|0)|0);
 $39 = ($37|0)==(0|0);
 if (!($39)) {
  $40 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$37>>2] = $40;
  $41 = ((($21) + (($38*24)|0)|0) + 4|0);
  $42 = (($a) + 4|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  HEAPF32[$41>>2] = $43;
  $44 = ((($21) + (($38*24)|0)|0) + 8|0);
  $45 = (($a) + 8|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$44>>2] = $46;
  $47 = ((($21) + (($38*24)|0)|0) + 12|0);
  $48 = (($a) + 12|0);
  ;HEAP32[$47+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$48+8>>2]|0;
 }
 $49 = HEAP32[$0>>2]|0;
 $50 = ($49|0)>(-1);
 if (!($50)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $57 = HEAP32[$18>>2]|0;
  $58 = (($57) + 1)|0;
  HEAP32[$18>>2] = $58;
  $59 = (($21) + (($57*24)|0)|0);
  STACKTOP = sp;return ($59|0);
 }
 $51 = HEAP32[$this>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $57 = HEAP32[$18>>2]|0;
  $58 = (($57) + 1)|0;
  HEAP32[$18>>2] = $58;
  $59 = (($21) + (($57*24)|0)|0);
  STACKTOP = sp;return ($59|0);
 }
 $53 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vii[$56 & 4095]($53,$51);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $57 = HEAP32[$18>>2]|0;
 $58 = (($57) + 1)|0;
 HEAP32[$18>>2] = $58;
 $59 = (($21) + (($57*24)|0)|0);
 STACKTOP = sp;return ($59|0);
}
function __ZN5physx6shdfnd5ArrayINS_11PxDebugTextENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*24)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 407192 : 405464;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,405648,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*24)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    ;HEAP32[$27+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$28+8>>2]|0;
   }
   $29 = (($$012$i) + 24|0);
   $30 = (($$03$i) + 24|0);
   $31 = ($29>>>0)<($15>>>0);
   if ($31) {
    $$012$i = $29;$$03$i = $30;
   } else {
    break;
   }
  }
 }
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)>(-1);
 if (!($34)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$32>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = HEAP32[$this>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  HEAP32[$this>>2] = $16;
  HEAP32[$32>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $37 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_vii[$40 & 4095]($37,$35);
 HEAP32[$this>>2] = $16;
 HEAP32[$32>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_15PxDebugTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0;
 var $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0;
 var $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*48)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 407304 : 405464;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,405648,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*48)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $34;
    $35 = (($$012$i) + 16|0);
    $36 = (($$03$i) + 16|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 20|0);
    $39 = (($$03$i) + 20|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 24|0);
    $42 = (($$03$i) + 24|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$41>>2] = $43;
    $44 = (($$012$i) + 28|0);
    $45 = (($$03$i) + 28|0);
    $46 = HEAP32[$45>>2]|0;
    HEAP32[$44>>2] = $46;
    $47 = (($$012$i) + 32|0);
    $48 = (($$03$i) + 32|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$47>>2] = $49;
    $50 = (($$012$i) + 36|0);
    $51 = (($$03$i) + 36|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    HEAPF32[$50>>2] = $52;
    $53 = (($$012$i) + 40|0);
    $54 = (($$03$i) + 40|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    HEAPF32[$53>>2] = $55;
    $56 = (($$012$i) + 44|0);
    $57 = (($$03$i) + 44|0);
    $58 = HEAP32[$57>>2]|0;
    HEAP32[$56>>2] = $58;
   }
   $59 = (($$012$i) + 48|0);
   $60 = (($$03$i) + 48|0);
   $61 = ($59>>>0)<($20>>>0);
   if ($61) {
    $$012$i = $59;$$03$i = $60;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $63 = $$pre;
 } else {
  $63 = $19;
 }
 $62 = (($21) + (($63*48)|0)|0);
 $64 = ($62|0)==(0|0);
 if (!($64)) {
  $65 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$62>>2] = $65;
  $66 = ((($21) + (($63*48)|0)|0) + 4|0);
  $67 = (($a) + 4|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$66>>2] = $68;
  $69 = ((($21) + (($63*48)|0)|0) + 8|0);
  $70 = (($a) + 8|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  HEAPF32[$69>>2] = $71;
  $72 = ((($21) + (($63*48)|0)|0) + 12|0);
  $73 = (($a) + 12|0);
  $74 = HEAP32[$73>>2]|0;
  HEAP32[$72>>2] = $74;
  $75 = ((($21) + (($63*48)|0)|0) + 16|0);
  $76 = (($a) + 16|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  HEAPF32[$75>>2] = $77;
  $78 = ((($21) + (($63*48)|0)|0) + 20|0);
  $79 = (($a) + 20|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  HEAPF32[$78>>2] = $80;
  $81 = ((($21) + (($63*48)|0)|0) + 24|0);
  $82 = (($a) + 24|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  HEAPF32[$81>>2] = $83;
  $84 = ((($21) + (($63*48)|0)|0) + 28|0);
  $85 = (($a) + 28|0);
  $86 = HEAP32[$85>>2]|0;
  HEAP32[$84>>2] = $86;
  $87 = ((($21) + (($63*48)|0)|0) + 32|0);
  $88 = (($a) + 32|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  HEAPF32[$87>>2] = $89;
  $90 = ((($21) + (($63*48)|0)|0) + 36|0);
  $91 = (($a) + 36|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  HEAPF32[$90>>2] = $92;
  $93 = ((($21) + (($63*48)|0)|0) + 40|0);
  $94 = (($a) + 40|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  HEAPF32[$93>>2] = $95;
  $96 = ((($21) + (($63*48)|0)|0) + 44|0);
  $97 = (($a) + 44|0);
  $98 = HEAP32[$97>>2]|0;
  HEAP32[$96>>2] = $98;
 }
 $99 = HEAP32[$0>>2]|0;
 $100 = ($99|0)>(-1);
 if (!($100)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $107 = HEAP32[$18>>2]|0;
  $108 = (($107) + 1)|0;
  HEAP32[$18>>2] = $108;
  $109 = (($21) + (($107*48)|0)|0);
  STACKTOP = sp;return ($109|0);
 }
 $101 = HEAP32[$this>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $107 = HEAP32[$18>>2]|0;
  $108 = (($107) + 1)|0;
  HEAP32[$18>>2] = $108;
  $109 = (($21) + (($107*48)|0)|0);
  STACKTOP = sp;return ($109|0);
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $107 = HEAP32[$18>>2]|0;
 $108 = (($107) + 1)|0;
 HEAP32[$18>>2] = $108;
 $109 = (($21) + (($107*48)|0)|0);
 STACKTOP = sp;return ($109|0);
}
function __ZN5physx6shdfnd5ArrayINS_15PxDebugTriangleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*48)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 407304 : 405464;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,405648,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*48)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$27>>2] = $29;
    $30 = (($$012$i) + 16|0);
    $31 = (($$03$i) + 16|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    HEAPF32[$30>>2] = $32;
    $33 = (($$012$i) + 20|0);
    $34 = (($$03$i) + 20|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    HEAPF32[$33>>2] = $35;
    $36 = (($$012$i) + 24|0);
    $37 = (($$03$i) + 24|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    HEAPF32[$36>>2] = $38;
    $39 = (($$012$i) + 28|0);
    $40 = (($$03$i) + 28|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$39>>2] = $41;
    $42 = (($$012$i) + 32|0);
    $43 = (($$03$i) + 32|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    HEAPF32[$42>>2] = $44;
    $45 = (($$012$i) + 36|0);
    $46 = (($$03$i) + 36|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    HEAPF32[$45>>2] = $47;
    $48 = (($$012$i) + 40|0);
    $49 = (($$03$i) + 40|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    HEAPF32[$48>>2] = $50;
    $51 = (($$012$i) + 44|0);
    $52 = (($$03$i) + 44|0);
    $53 = HEAP32[$52>>2]|0;
    HEAP32[$51>>2] = $53;
   }
   $54 = (($$012$i) + 48|0);
   $55 = (($$03$i) + 48|0);
   $56 = ($54>>>0)<($15>>>0);
   if ($56) {
    $$012$i = $54;$$03$i = $55;
   } else {
    break;
   }
  }
 }
 $57 = (($this) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)>(-1);
 if (!($59)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$57>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $60 = HEAP32[$this>>2]|0;
 $61 = ($60|0)==(0|0);
 if ($61) {
  HEAP32[$this>>2] = $16;
  HEAP32[$57>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 12|0);
 $65 = HEAP32[$64>>2]|0;
 FUNCTION_TABLE_vii[$65 & 4095]($62,$60);
 HEAP32[$this>>2] = $16;
 HEAP32[$57>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0;
 var $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 5;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 407424 : 405464;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,405648,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<5)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $34;
    $35 = (($$012$i) + 16|0);
    $36 = (($$03$i) + 16|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 20|0);
    $39 = (($$03$i) + 20|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 24|0);
    $42 = (($$03$i) + 24|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$41>>2] = $43;
    $44 = (($$012$i) + 28|0);
    $45 = (($$03$i) + 28|0);
    $46 = HEAP32[$45>>2]|0;
    HEAP32[$44>>2] = $46;
   }
   $47 = (($$012$i) + 32|0);
   $48 = (($$03$i) + 32|0);
   $49 = ($47>>>0)<($20>>>0);
   if ($49) {
    $$012$i = $47;$$03$i = $48;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $51 = $$pre;
 } else {
  $51 = $19;
 }
 $50 = (($21) + ($51<<5)|0);
 $52 = ($50|0)==(0|0);
 if (!($52)) {
  $53 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$50>>2] = $53;
  $54 = ((($21) + ($51<<5)|0) + 4|0);
  $55 = (($a) + 4|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$54>>2] = $56;
  $57 = ((($21) + ($51<<5)|0) + 8|0);
  $58 = (($a) + 8|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  HEAPF32[$57>>2] = $59;
  $60 = ((($21) + ($51<<5)|0) + 12|0);
  $61 = (($a) + 12|0);
  $62 = HEAP32[$61>>2]|0;
  HEAP32[$60>>2] = $62;
  $63 = ((($21) + ($51<<5)|0) + 16|0);
  $64 = (($a) + 16|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  HEAPF32[$63>>2] = $65;
  $66 = ((($21) + ($51<<5)|0) + 20|0);
  $67 = (($a) + 20|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$66>>2] = $68;
  $69 = ((($21) + ($51<<5)|0) + 24|0);
  $70 = (($a) + 24|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  HEAPF32[$69>>2] = $71;
  $72 = ((($21) + ($51<<5)|0) + 28|0);
  $73 = (($a) + 28|0);
  $74 = HEAP32[$73>>2]|0;
  HEAP32[$72>>2] = $74;
 }
 $75 = HEAP32[$0>>2]|0;
 $76 = ($75|0)>(-1);
 if (!($76)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $83 = HEAP32[$18>>2]|0;
  $84 = (($83) + 1)|0;
  HEAP32[$18>>2] = $84;
  $85 = (($21) + ($83<<5)|0);
  STACKTOP = sp;return ($85|0);
 }
 $77 = HEAP32[$this>>2]|0;
 $78 = ($77|0)==(0|0);
 if ($78) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $83 = HEAP32[$18>>2]|0;
  $84 = (($83) + 1)|0;
  HEAP32[$18>>2] = $84;
  $85 = (($21) + ($83<<5)|0);
  STACKTOP = sp;return ($85|0);
 }
 $79 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + 12|0);
 $82 = HEAP32[$81>>2]|0;
 FUNCTION_TABLE_vii[$82 & 4095]($79,$77);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $83 = HEAP32[$18>>2]|0;
 $84 = (($83) + 1)|0;
 HEAP32[$18>>2] = $84;
 $85 = (($21) + ($83<<5)|0);
 STACKTOP = sp;return ($85|0);
}
function __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 407424 : 405464;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,405648,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<5)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$27>>2] = $29;
    $30 = (($$012$i) + 16|0);
    $31 = (($$03$i) + 16|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    HEAPF32[$30>>2] = $32;
    $33 = (($$012$i) + 20|0);
    $34 = (($$03$i) + 20|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    HEAPF32[$33>>2] = $35;
    $36 = (($$012$i) + 24|0);
    $37 = (($$03$i) + 24|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    HEAPF32[$36>>2] = $38;
    $39 = (($$012$i) + 28|0);
    $40 = (($$03$i) + 28|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$39>>2] = $41;
   }
   $42 = (($$012$i) + 32|0);
   $43 = (($$03$i) + 32|0);
   $44 = ($42>>>0)<($15>>>0);
   if ($44) {
    $$012$i = $42;$$03$i = $43;
   } else {
    break;
   }
  }
 }
 $45 = (($this) + 8|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)>(-1);
 if (!($47)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$45>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$this>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  HEAP32[$this>>2] = $16;
  HEAP32[$45>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $50 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vii[$53 & 4095]($50,$48);
 HEAP32[$this>>2] = $16;
 HEAP32[$45>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_12PxDebugPointENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 4;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 407536 : 405464;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,405648,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<4)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $34;
   }
   $35 = (($$012$i) + 16|0);
   $36 = (($$03$i) + 16|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<4)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$38>>2] = $41;
  $42 = ((($21) + ($39<<4)|0) + 4|0);
  $43 = (($a) + 4|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$42>>2] = $44;
  $45 = ((($21) + ($39<<4)|0) + 8|0);
  $46 = (($a) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  HEAPF32[$45>>2] = $47;
  $48 = ((($21) + ($39<<4)|0) + 12|0);
  $49 = (($a) + 12|0);
  $50 = HEAP32[$49>>2]|0;
  HEAP32[$48>>2] = $50;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if (!($52)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $59 = HEAP32[$18>>2]|0;
  $60 = (($59) + 1)|0;
  HEAP32[$18>>2] = $60;
  $61 = (($21) + ($59<<4)|0);
  STACKTOP = sp;return ($61|0);
 }
 $53 = HEAP32[$this>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $59 = HEAP32[$18>>2]|0;
  $60 = (($59) + 1)|0;
  HEAP32[$18>>2] = $60;
  $61 = (($21) + ($59<<4)|0);
  STACKTOP = sp;return ($61|0);
 }
 $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 12|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<4)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd5ArrayINS_12PxDebugPointENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 407536 : 405464;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,405648,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$27>>2] = $29;
   }
   $30 = (($$012$i) + 16|0);
   $31 = (($$03$i) + 16|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12RenderBufferD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs$i$i = 0, $notrhs$i$i = 0;
 var $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i3 = 0, $or$cond$not$i$i = 0, $or$cond2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((407136 + 8|0));
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $notlhs$i$i = ($4|0)==(0);
 $notrhs$i$i = ($3|0)<(0);
 $or$cond$not$i$i = $notrhs$i$i | $notlhs$i$i;
 $5 = ($1|0)==(0|0);
 $or$cond2$i$i = $or$cond$not$i$i | $5;
 if (!($or$cond2$i$i)) {
  $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$9 & 4095]($6,$1);
 }
 $10 = (($this) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 2147483647;
 $13 = ($12|0)!=(0);
 $14 = ($11|0)>(-1);
 $or$cond$i$i = $13 & $14;
 if ($or$cond$i$i) {
  $15 = (($this) + 40|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$21 & 4095]($18,$16);
  }
 }
 $22 = (($this) + 36|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($24|0)!=(0);
 $26 = ($23|0)>(-1);
 $or$cond$i$i1 = $25 & $26;
 if ($or$cond$i$i1) {
  $27 = (($this) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   FUNCTION_TABLE_vii[$33 & 4095]($30,$28);
  }
 }
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35 & 2147483647;
 $37 = ($36|0)!=(0);
 $38 = ($35|0)>(-1);
 $or$cond$i$i2 = $37 & $38;
 if ($or$cond$i$i2) {
  $39 = (($this) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($43) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   FUNCTION_TABLE_vii[$45 & 4095]($42,$40);
  }
 }
 $46 = (($this) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 & 2147483647;
 $49 = ($48|0)!=(0);
 $50 = ($47|0)>(-1);
 $or$cond$i$i3 = $49 & $50;
 if (!($or$cond$i$i3)) {
  STACKTOP = sp;return;
 }
 $51 = (($this) + 4|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  STACKTOP = sp;return;
 }
 $54 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 12|0);
 $57 = HEAP32[$56>>2]|0;
 FUNCTION_TABLE_vii[$57 & 4095]($54,$52);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10ControllerC2ERKNS_16PxControllerDescEPNS_7PxSceneE($this,$desc,$s) {
 $this = $this|0;
 $desc = $desc|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $q$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $q$i = sp + 16|0;
 $0 = sp;
 $1 = sp + 32|0;
 HEAP32[$this>>2] = ((407648 + 8|0));
 $2 = (($this) + 8|0);
 __ZN5physx3Cct9CCTParamsC2Ev($2);
 $3 = (($this) + 88|0);
 __ZN5physx3Cct9SweepTestC2Ev($3);
 $4 = (($this) + 408|0);
 $5 = (($this) + 456|0);
 HEAP32[$5>>2] = $s;
 $6 = (($this) + 460|0);
 HEAP32[$6>>2] = -1;
 $7 = (($this) + 464|0);
 $8 = (($this) + 476|0);
 $9 = (($this) + 480|0);
 $10 = (($this) + 4|0);
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP16[$7+20>>1]=0|0;
 HEAP32[$10>>2] = 2147483647;
 $11 = (($desc) + 88|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$2>>2] = $12;
 $13 = (($desc) + 44|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 40|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($desc) + 56|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 44|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($desc) + 60|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 48|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($desc) + 48|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 52|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($desc) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 56|0);
 HEAPF32[$27>>2] = $26;
 $28 = Math_fround(HEAPF32[$13>>2]);
 $29 = $28 != Math_fround(0.0);
 $30 = (($this) + 65|0);
 $31 = $29&1;
 HEAP8[$30>>0] = $31;
 $32 = (($desc) + 76|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 72|0);
 HEAP32[$34>>2] = $33;
 $35 = (($desc) + 84|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 76|0);
 HEAP32[$37>>2] = $36;
 $38 = (($desc) + 96|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($this) + 80|0);
 HEAP32[$40>>2] = $39;
 $41 = (($this) + 400|0);
 HEAP32[$41>>2] = 0;
 $42 = (($desc) + 8|0);
 ;HEAP32[$4+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$42+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$42+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$42+20>>2]|0;
 $43 = (($desc) + 64|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 HEAPF32[$8>>2] = $44;
 $45 = (($desc) + 68|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 HEAPF32[$9>>2] = $46;
 $47 = (($desc) + 72|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($this) + 376|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($this) + 432|0);
 $51 = (($this) + 28|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($this) + 32|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($this) + 36|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($desc) + 32|0);
 ;HEAP32[$50+0>>2]=0|0;HEAP32[$50+4>>2]=0|0;HEAP32[$50+8>>2]=0|0;HEAP32[$50+12>>2]=0|0;HEAP32[$50+16>>2]=0|0;HEAP32[$50+20>>2]=0|0;
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = $55 == Math_fround(0.0);
 $57 = (($desc) + 36|0);
 if ($56) {
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = $58 == Math_fround(0.0);
  if ($59) {
   $60 = (($desc) + 40|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = $61 == Math_fround(0.0);
   if ($62) {
    $80 = HEAP32[$s>>2]|0;
    $81 = (($80) + 28|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (FUNCTION_TABLE_ii[$82 & 4095]($s)|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($84) + 156|0);
    $86 = HEAP32[$85>>2]|0;
    HEAP8[$1>>0] = 1;
    FUNCTION_TABLE_viiii[$86 & 511]($83,$this,$1,0);
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$0>>2] = Math_fround(1.0);
 $63 = (($0) + 4|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($0) + 8|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd11rotationArcERKNS_6PxVec3ES3_($q$i,$0,$54);
 $65 = Math_fround(HEAPF32[$q$i>>2]);
 $66 = (($this) + 12|0);
 HEAPF32[$66>>2] = $65;
 $67 = (($q$i) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($this) + 16|0);
 HEAPF32[$69>>2] = $68;
 $70 = (($q$i) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($this) + 20|0);
 HEAPF32[$72>>2] = $71;
 $73 = (($q$i) + 12|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($this) + 24|0);
 HEAPF32[$75>>2] = $74;
 $76 = Math_fround(HEAPF32[$54>>2]);
 HEAPF32[$51>>2] = $76;
 $77 = Math_fround(HEAPF32[$57>>2]);
 HEAPF32[$52>>2] = $77;
 $78 = (($desc) + 40|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 HEAPF32[$53>>2] = $79;
 $80 = HEAP32[$s>>2]|0;
 $81 = (($80) + 28|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (FUNCTION_TABLE_ii[$82 & 4095]($s)|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($84) + 156|0);
 $86 = HEAP32[$85>>2]|0;
 HEAP8[$1>>0] = 1;
 FUNCTION_TABLE_viiii[$86 & 511]($83,$this,$1,0);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10Controller22setUpDirectionInternalERKNS_6PxVec3E($this,$up) {
 $this = $this|0;
 $up = $up|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0;
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $q = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $q = sp + 16|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(HEAPF32[$up>>2]);
 $4 = $2 == $3;
 if ($4) {
  $5 = (($this) + 32|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($up) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = $6 == $8;
  if ($9) {
   $10 = (($this) + 36|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = (($up) + 8|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = $11 == $13;
   if ($14) {
    STACKTOP = sp;return;
   } else {
    $$pre$phi2Z2D = $5;$$pre$phiZ2D = $7;
   }
  } else {
   $$pre$phi2Z2D = $5;$$pre$phiZ2D = $7;
  }
 } else {
  $$pre = (($up) + 4|0);
  $$pre1 = (($this) + 32|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;
 }
 HEAPF32[$0>>2] = Math_fround(1.0);
 $15 = (($0) + 4|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($0) + 8|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd11rotationArcERKNS_6PxVec3ES3_($q,$0,$up);
 $17 = Math_fround(HEAPF32[$q>>2]);
 $18 = (($this) + 12|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($q) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 16|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($q) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 20|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($q) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 24|0);
 HEAPF32[$27>>2] = $26;
 $28 = Math_fround(HEAPF32[$up>>2]);
 HEAPF32[$1>>2] = $28;
 $29 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 HEAPF32[$$pre$phi2Z2D>>2] = $29;
 $30 = (($up) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 36|0);
 HEAPF32[$32>>2] = $31;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10ControllerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((407648 + 8|0));
 $1 = (($this) + 456|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = (($4) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 4095]($2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 160|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 4095]($7,$this);
  $11 = (($this) + 400|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = HEAP32[$12>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_vi[$15 & 4095]($12);
  }
 }
 $16 = (($this) + 88|0);
 __ZN5physx3Cct9SweepTestD2Ev($16);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10ControllerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((407648 + 8|0));
 $0 = (($this) + 456|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 160|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$9 & 4095]($6,$this);
  $10 = (($this) + 400|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = HEAP32[$11>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vi[$14 & 4095]($11);
  }
 }
 $15 = (($this) + 88|0);
 __ZN5physx3Cct9SweepTestD2Ev($15);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10Controller9onReleaseEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($this,$observed,$0,$deletionEvent) {
 $this = $this|0;
 $observed = $observed|0;
 $0 = $0|0;
 $deletionEvent = $deletionEvent|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 88|0);
 __ZN5physx3Cct9SweepTest9onReleaseERKNS_6PxBaseE($1,$observed);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10Controller13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = Math_fround(0), $1 = 0.0, $10 = 0.0, $11 = 0, $12 = Math_fround(0), $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = Math_fround(0), $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$shift>>2]);
 $1 = +$0;
 $2 = (($this) + 408|0);
 $3 = +HEAPF64[$2>>3];
 $4 = $3 - $1;
 HEAPF64[$2>>3] = $4;
 $5 = (($shift) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = +$6;
 $8 = (($this) + 416|0);
 $9 = +HEAPF64[$8>>3];
 $10 = $9 - $7;
 HEAPF64[$8>>3] = $10;
 $11 = (($shift) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = +$12;
 $14 = (($this) + 424|0);
 $15 = +HEAPF64[$14>>3];
 $16 = $15 - $13;
 HEAPF64[$14>>3] = $16;
 $17 = (($this) + 88|0);
 __ZN5physx3Cct9SweepTest13onOriginShiftERKNS_6PxVec3E($17,$shift);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd11rotationArcERKNS_6PxVec3ES3_($agg$result,$v0,$v1) {
 $agg$result = $agg$result|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $fabsf$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($v0) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($v1) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($v0) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($v1) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(HEAPF32[$v1>>2]);
 $9 = Math_fround(HEAPF32[$v0>>2]);
 $10 = Math_fround($8 * $9);
 $11 = Math_fround($1 * $7);
 $12 = Math_fround($11 + $10);
 $13 = Math_fround($3 * $5);
 $14 = Math_fround($13 + $12);
 $15 = !($14 <= Math_fround(-0.999989986419677734375));
 if ($15) {
  $37 = Math_fround($1 * $8);
  $38 = Math_fround($7 * $9);
  $39 = Math_fround($3 * $9);
  $40 = Math_fround($5 * $8);
  $41 = Math_fround($5 * $7);
  $42 = Math_fround($1 * $3);
  $43 = Math_fround($38 - $37);
  $44 = Math_fround($40 - $39);
  $45 = Math_fround($42 - $41);
  $46 = Math_fround($14 + Math_fround(1.0));
  $47 = Math_fround($46 * Math_fround(2.0));
  $48 = (Math_fround(Math_sqrt((Math_fround($47)))));
  $49 = Math_fround(Math_fround(1.0) / $48);
  $50 = Math_fround($45 * $49);
  $51 = Math_fround($44 * $49);
  $52 = Math_fround($43 * $49);
  $53 = Math_fround($48 * Math_fround(0.5));
  $54 = Math_fround($50 * $50);
  $55 = Math_fround($51 * $51);
  $56 = Math_fround($54 + $55);
  $57 = Math_fround($52 * $52);
  $58 = Math_fround($57 + $56);
  $59 = Math_fround($53 * $53);
  $60 = Math_fround($59 + $58);
  $61 = (Math_fround(Math_sqrt((Math_fround($60)))));
  $62 = Math_fround(Math_fround(1.0) / $61);
  $63 = Math_fround($50 * $62);
  $64 = Math_fround($51 * $62);
  $65 = Math_fround($52 * $62);
  $66 = Math_fround($53 * $62);
  HEAPF32[$agg$result>>2] = $63;
  $67 = (($agg$result) + 4|0);
  HEAPF32[$67>>2] = $64;
  $68 = (($agg$result) + 8|0);
  HEAPF32[$68>>2] = $65;
  $69 = (($agg$result) + 12|0);
  HEAPF32[$69>>2] = $66;
  STACKTOP = sp;return;
 }
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($9)))));
 $16 = $fabsf$i$i < Math_fround(0.100000001490116119385);
 if ($16) {
  $17 = Math_fround(-$1);
  $20 = Math_fround(0.0);$22 = $5;$25 = $17;
 } else {
  $18 = Math_fround(-$9);
  $20 = $1;$22 = $18;$25 = Math_fround(0.0);
 }
 $19 = Math_fround($20 * $20);
 $21 = Math_fround($22 * $22);
 $23 = Math_fround($21 + $19);
 $24 = Math_fround($25 * $25);
 $26 = Math_fround($24 + $23);
 $27 = Math_fround($26 + Math_fround(0.0));
 $28 = (Math_fround(Math_sqrt((Math_fround($27)))));
 $29 = Math_fround(Math_fround(1.0) / $28);
 $30 = Math_fround($20 * $29);
 $31 = Math_fround($22 * $29);
 $32 = Math_fround($25 * $29);
 $33 = Math_fround($29 * Math_fround(0.0));
 HEAPF32[$agg$result>>2] = $30;
 $34 = (($agg$result) + 4|0);
 HEAPF32[$34>>2] = $31;
 $35 = (($agg$result) + 8|0);
 HEAPF32[$35>>2] = $32;
 $36 = (($agg$result) + 12|0);
 HEAPF32[$36>>2] = $33;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10Controller15releaseInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 464|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 __ZN5physx3Cct26CharacterControllerManager17releaseControllerERNS_12PxControllerE($1,$5);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct10Controller16getInternalStateERNS_17PxControllerStateE($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $$lobit = 0, $$lobit1 = 0, $$lobit2 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 432|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$state>>2] = $1;
 $2 = (($this) + 436|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($state) + 4|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($this) + 440|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($state) + 8|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($this) + 244|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($state) + 12|0);
 HEAP32[$10>>2] = $9;
 $11 = (($this) + 248|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($state) + 16|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 240|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($state) + 20|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 396|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($state) + 28|0);
 $20 = $18 >>> 4;
 $$lobit = $20 & 1;
 $21 = $$lobit&255;
 HEAP8[$19>>0] = $21;
 $22 = (($state) + 29|0);
 $23 = $18 >>> 5;
 $$lobit1 = $23 & 1;
 $24 = $$lobit1&255;
 HEAP8[$22>>0] = $24;
 $25 = (($state) + 30|0);
 $26 = $18 >>> 8;
 $$lobit2 = $26 & 1;
 $27 = $$lobit2&255;
 HEAP8[$25>>0] = $27;
 $28 = (($this) + 484|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = (($state) + 24|0);
 HEAP32[$31>>2] = $30;
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct10Controller16getInternalStatsERNS_17PxControllerStatsE($this,$stats) {
 $this = $this|0;
 $stats = $stats|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 388|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($stats) + 2|0);
 HEAP16[$2>>1] = $1;
 $3 = (($this) + 390|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = (($stats) + 4|0);
 HEAP16[$5>>1] = $4;
 $6 = (($this) + 394|0);
 $7 = HEAP16[$6>>1]|0;
 HEAP16[$stats>>1] = $7;
 $8 = (($this) + 392|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = (($stats) + 6|0);
 HEAP16[$10>>1] = $9;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct10Controller6setPosERKNS_14PxExtendedVec3E($this,$pos) {
 $this = $this|0;
 $pos = $pos|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = Math_fround(0), $12 = 0, $13 = 0.0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = Math_fround(0), $9 = 0, $targetPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $targetPose = sp;
 $0 = (($this) + 408|0);
 ;HEAP32[$0+0>>2]=HEAP32[$pos+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$pos+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$pos+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$pos+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$pos+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$pos+20>>2]|0;
 $1 = (($this) + 400|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($targetPose,$2);
 $7 = +HEAPF64[$0>>3];
 $8 = Math_fround($7);
 $9 = (($this) + 416|0);
 $10 = +HEAPF64[$9>>3];
 $11 = Math_fround($10);
 $12 = (($this) + 424|0);
 $13 = +HEAPF64[$12>>3];
 $14 = Math_fround($13);
 $15 = (($targetPose) + 16|0);
 HEAPF32[$15>>2] = $8;
 $16 = (($targetPose) + 20|0);
 HEAPF32[$16>>2] = $11;
 $17 = (($targetPose) + 24|0);
 HEAPF32[$17>>2] = $14;
 $18 = (($this) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$targetPose>>2] = $19;
 $20 = (($this) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($targetPose) + 4|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($this) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($targetPose) + 8|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($this) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($targetPose) + 12|0);
 HEAPF32[$28>>2] = $27;
 $29 = HEAP32[$1>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 224|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$targetPose);
 STACKTOP = sp;return 1;
}
function __ZN5physx3Cct10Controller16createProxyActorERNS_9PxPhysicsERKNS_10PxGeometryERKNS_10PxMaterialE($this,$sdk,$geometry,$material) {
 $this = $this|0;
 $sdk = $sdk|0;
 $geometry = $geometry|0;
 $material = $material|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0.0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0.0, $6 = Math_fround(0), $7 = 0, $8 = 0.0, $9 = Math_fround(0), $globalPose = 0, $materialPtr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $materialPtr$i = sp + 28|0;
 $0 = sp + 32|0;
 $globalPose = sp;
 $1 = (($this) + 408|0);
 $2 = +HEAPF64[$1>>3];
 $3 = Math_fround($2);
 $4 = (($this) + 416|0);
 $5 = +HEAPF64[$4>>3];
 $6 = Math_fround($5);
 $7 = (($this) + 424|0);
 $8 = +HEAPF64[$7>>3];
 $9 = Math_fround($8);
 $10 = (($globalPose) + 16|0);
 HEAPF32[$10>>2] = $3;
 $11 = (($globalPose) + 20|0);
 HEAPF32[$11>>2] = $6;
 $12 = (($globalPose) + 24|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($this) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$globalPose>>2] = $14;
 $15 = (($this) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($globalPose) + 4|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($this) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($globalPose) + 8|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($globalPose) + 12|0);
 HEAPF32[$23>>2] = $22;
 $24 = HEAP32[$sdk>>2]|0;
 $25 = (($24) + 108|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (FUNCTION_TABLE_iii[$26 & 4095]($sdk,$globalPose)|0);
 $28 = (($this) + 400|0);
 HEAP32[$28>>2] = $27;
 $29 = ($27|0)==(0|0);
 if ($29) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$materialPtr$i>>2] = $material;
 $30 = HEAP32[$27>>2]|0;
 $31 = (($30) + 92|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP8[$0>>0] = 11;
 (FUNCTION_TABLE_iiiiii[$32 & 255]($27,$geometry,$materialPtr$i,1,$0)|0);
 $33 = HEAP32[$28>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 192|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_viii[$36 & 4095]($33,1,1);
 $37 = HEAP32[$28>>2]|0;
 $38 = (($this) + 476|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 (__ZN5physx14PxRigidBodyExt20updateMassAndInertiaERNS_11PxRigidBodyEfPKNS_6PxVec3Eb($37,$39,0,0)|0);
 $40 = (($this) + 456|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 44|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($41,$45);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx3Cct10Controller12getKineShapeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $shape = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $shape = sp;
 HEAP32[$shape>>2] = 0;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 (FUNCTION_TABLE_iiiii[$4 & 511]($1,$shape,1,0)|0);
 $5 = HEAP32[$shape>>2]|0;
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx3Cct13HandleManager3AddEPv($this,$object) {
 $this = $this|0;
 $object = $object|0;
 var $$ = 0, $$0 = 0, $$pre = 0, $$pre$phi4Z2D = 0, $$pre$phi6Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 7|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = sp + 4|0;
 $6 = sp + 5|0;
 $7 = sp + 6|0;
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 if (!($10)) {
  $13 = (($this) + 16|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<1)|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = HEAP32[$this>>2]|0;
  $18 = (($17) + ($12<<2)|0);
  HEAP32[$18>>2] = $object;
  $19 = (($12) + 1)|0;
  HEAP32[$11>>2] = $19;
  $20 = $12&65535;
  $21 = $16&65535;
  $22 = (($this) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($21<<1)|0);
  HEAP16[$24>>1] = $20;
  $25 = (($9) + -1)|0;
  HEAP32[$8>>2] = $25;
  $26 = (($this) + 20|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + ($21<<1)|0);
  $29 = HEAP16[$28>>1]|0;
  $30 = $29&65535;
  $31 = $30 << 16;
  $32 = $31 | $21;
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($12|0)==($34|0);
 if ($35) {
  $36 = $12 << 1;
  $37 = ($36>>>0)>(65535);
  $$ = $37 ? 65535 : $36;
  HEAP32[$33>>2] = $$;
  $38 = $$ << 2;
  $39 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$38,407680,92)|0);
  $40 = HEAP32[$33>>2]|0;
  $41 = $40 << 1;
  $42 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,$41,407680,93)|0);
  $43 = HEAP32[$33>>2]|0;
  $44 = $43 << 1;
  $45 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($6,$44,407680,94)|0);
  $46 = HEAP32[$33>>2]|0;
  $47 = $46 << 1;
  $48 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($7,$47,407680,95)|0);
  $49 = HEAP32[$this>>2]|0;
  $50 = HEAP32[$11>>2]|0;
  $51 = $50 << 2;
  _memcpy(($39|0),($49|0),($51|0))|0;
  $52 = (($this) + 12|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = HEAP32[$11>>2]|0;
  $55 = $54 << 1;
  _memcpy(($42|0),($53|0),($55|0))|0;
  $56 = (($this) + 16|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = HEAP32[$11>>2]|0;
  $59 = $58 << 1;
  _memcpy(($45|0),($57|0),($59|0))|0;
  $60 = (($this) + 20|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = HEAP32[$11>>2]|0;
  $63 = $62 << 1;
  _memcpy(($48|0),($61|0),($63|0))|0;
  $64 = HEAP32[$11>>2]|0;
  $65 = (($42) + ($64<<1)|0);
  $66 = HEAP32[$33>>2]|0;
  $67 = (($66) - ($64))|0;
  $68 = $67 << 1;
  _memset(($65|0),-1,($68|0))|0;
  $69 = HEAP32[$11>>2]|0;
  $70 = (($45) + ($69<<1)|0);
  $71 = HEAP32[$33>>2]|0;
  $72 = (($71) - ($69))|0;
  $73 = $72 << 1;
  _memset(($70|0),-1,($73|0))|0;
  $74 = HEAP32[$11>>2]|0;
  $75 = (($48) + ($74<<1)|0);
  $76 = HEAP32[$33>>2]|0;
  $77 = (($76) - ($74))|0;
  $78 = $77 << 1;
  _memset(($75|0),0,($78|0))|0;
  $79 = HEAP32[$60>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$79);
  HEAP32[$60>>2] = 0;
  $80 = HEAP32[$56>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$80);
  HEAP32[$56>>2] = 0;
  $81 = HEAP32[$52>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$81);
  HEAP32[$52>>2] = 0;
  $82 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$82);
  HEAP32[$this>>2] = $39;
  HEAP32[$52>>2] = $42;
  HEAP32[$56>>2] = $45;
  HEAP32[$60>>2] = $48;
  $$pre = HEAP32[$11>>2]|0;
  $$pre$phi4Z2D = $56;$$pre$phi6Z2D = $60;$$pre$phiZ2D = $52;$84 = $39;$85 = $$pre;
 } else {
  $$pre1 = HEAP32[$this>>2]|0;
  $$pre2 = (($this) + 12|0);
  $$pre3 = (($this) + 16|0);
  $$pre5 = (($this) + 20|0);
  $$pre$phi4Z2D = $$pre3;$$pre$phi6Z2D = $$pre5;$$pre$phiZ2D = $$pre2;$84 = $$pre1;$85 = $12;
 }
 $83 = (($84) + ($85<<2)|0);
 HEAP32[$83>>2] = $object;
 $86 = $85&65535;
 $87 = HEAP32[$$pre$phiZ2D>>2]|0;
 $88 = (($87) + ($85<<1)|0);
 HEAP16[$88>>1] = $86;
 $89 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $90 = (($89) + ($85<<1)|0);
 HEAP16[$90>>1] = $86;
 $91 = (($85) + 1)|0;
 HEAP32[$11>>2] = $91;
 $92 = HEAP32[$$pre$phi6Z2D>>2]|0;
 $93 = (($92) + ($85<<1)|0);
 $94 = HEAP16[$93>>1]|0;
 $95 = $94&65535;
 $96 = $95 << 16;
 $97 = $96 | $85;
 $$0 = $97;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Cct15ObstacleContextC2ERNS0_26CharacterControllerManagerE($this,$cctMan) {
 $this = $this|0;
 $cctMan = $cctMan|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 HEAP32[$this>>2] = ((407784 + 8|0));
 $4 = (($this) + 4|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 52|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = 2;
 $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,8,407680,42)|0);
 $9 = (($this) + 28|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$7>>2]|0;
 $11 = $10 << 1;
 $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$11,407680,43)|0);
 $13 = (($this) + 40|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$7>>2]|0;
 $15 = $14 << 1;
 $16 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$15,407680,44)|0);
 $17 = (($this) + 44|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP32[$7>>2]|0;
 $19 = $18 << 1;
 $20 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$19,407680,45)|0);
 $21 = (($this) + 48|0);
 HEAP32[$21>>2] = $20;
 $22 = HEAP32[$13>>2]|0;
 $23 = HEAP32[$7>>2]|0;
 $24 = $23 << 1;
 _memset(($22|0),-1,($24|0))|0;
 $25 = HEAP32[$17>>2]|0;
 $26 = HEAP32[$7>>2]|0;
 $27 = $26 << 1;
 _memset(($25|0),-1,($27|0))|0;
 $28 = HEAP32[$21>>2]|0;
 $29 = HEAP32[$7>>2]|0;
 $30 = $29 << 1;
 _memset(($28|0),0,($30|0))|0;
 $31 = (($this) + 56|0);
 HEAP32[$31>>2] = $cctMan;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct15ObstacleContextD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx3Cct15ObstacleContextD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct15ObstacleContextD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 HEAP32[$this>>2] = ((407784 + 8|0));
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$5);
 HEAP32[$4>>2] = 0;
 $6 = (($this) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
 HEAP32[$6>>2] = 0;
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$9);
 HEAP32[$8>>2] = 0;
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$11);
 HEAP32[$10>>2] = 0;
 HEAP32[$8>>2] = 0;
 HEAP32[$6>>2] = 0;
 HEAP32[$4>>2] = 0;
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i = $15 & $16;
 if ($or$cond$i$i) {
  $17 = (($this) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i1 = $27 & $28;
 if (!($or$cond$i$i1)) {
  STACKTOP = sp;return;
 }
 $29 = (($this) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct15ObstacleContext7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx3Cct26CharacterControllerManager22releaseObstacleContextERNS0_15ObstacleContextE($1,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct15ObstacleContext20getControllerManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Cct15ObstacleContext11addObstacleERKNS_10PxObstacleE($this,$obstacle) {
 $this = $this|0;
 $obstacle = $obstacle|0;
 var $$0 = 0, $$pre$i = 0, $$pre$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0;
 var $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = HEAP32[$obstacle>>2]|0;
 if ((($2|0) == 2)) {
  $53 = (($this) + 16|0);
  $54 = (($this) + 20|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($this) + 28|0);
  $57 = $55 << 16;
  $58 = $57 | 3;
  $59 = $58;
  $60 = (__ZN5physx3Cct13HandleManager3AddEPv($56,$59)|0);
  HEAP32[$1>>2] = $60;
  $61 = (($1) + 8|0);
  ;HEAP32[$61+0>>2]=HEAP32[$obstacle+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$obstacle+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$obstacle+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$obstacle+12>>2]|0;HEAP32[$61+16>>2]=HEAP32[$obstacle+16>>2]|0;HEAP32[$61+20>>2]=HEAP32[$obstacle+20>>2]|0;HEAP32[$61+24>>2]=HEAP32[$obstacle+24>>2]|0;HEAP32[$61+28>>2]=HEAP32[$obstacle+28>>2]|0;
  $62 = (($1) + 40|0);
  $63 = (($obstacle) + 32|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$62>>2] = $64;
  $65 = (($1) + 44|0);
  $66 = (($obstacle) + 36|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$65>>2] = $67;
  $68 = (($1) + 48|0);
  $69 = (($obstacle) + 40|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$68>>2] = $70;
  $71 = (($1) + 52|0);
  $72 = (($obstacle) + 44|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  HEAPF32[$71>>2] = $73;
  $74 = (($1) + 56|0);
  $75 = (($obstacle) + 48|0);
  $76 = $75;
  $77 = $76;
  $78 = HEAP32[$77>>2]|0;
  $79 = (($76) + 4)|0;
  $80 = $79;
  $81 = HEAP32[$80>>2]|0;
  $82 = $74;
  $83 = $82;
  HEAP32[$83>>2] = $78;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $81;
  $86 = (($this) + 24|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = $87 & 2147483647;
  $89 = HEAP32[$54>>2]|0;
  $90 = ($88>>>0)>($89>>>0);
  if ($90) {
   $91 = HEAP32[$53>>2]|0;
   $92 = (($91) + ($89<<6)|0);
   $93 = ($92|0)==(0|0);
   if ($93) {
    $105 = $89;
   } else {
    $94 = ((($91) + ($89<<6)|0) + 8|0);
    ;HEAP32[$94+0>>2]=HEAP32[$61+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$61+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$61+8>>2]|0;HEAP32[$94+12>>2]=HEAP32[$61+12>>2]|0;HEAP32[$94+16>>2]=HEAP32[$61+16>>2]|0;HEAP32[$94+20>>2]=HEAP32[$61+20>>2]|0;HEAP32[$94+24>>2]=HEAP32[$61+24>>2]|0;HEAP32[$94+28>>2]=HEAP32[$61+28>>2]|0;
    $95 = ((($91) + ($89<<6)|0) + 40|0);
    HEAPF32[$95>>2] = $64;
    $96 = ((($91) + ($89<<6)|0) + 44|0);
    HEAPF32[$96>>2] = $67;
    $97 = ((($91) + ($89<<6)|0) + 48|0);
    HEAPF32[$97>>2] = $70;
    $98 = ((($91) + ($89<<6)|0) + 52|0);
    HEAPF32[$98>>2] = $73;
    $99 = ((($91) + ($89<<6)|0) + 56|0);
    $100 = $99;
    $101 = $100;
    HEAP32[$101>>2] = $78;
    $102 = (($100) + 4)|0;
    $103 = $102;
    HEAP32[$103>>2] = $81;
    HEAP32[$92>>2] = $60;
    $$pre$i = HEAP32[$54>>2]|0;
    $105 = $$pre$i;
   }
   $104 = (($105) + 1)|0;
   HEAP32[$54>>2] = $104;
  } else {
   (__ZN5physx6shdfnd5ArrayINS_3Cct15ObstacleContext23InternalCapsuleObstacleENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($53,$1)|0);
  }
  $106 = (($this) + 56|0);
  $107 = HEAP32[$106>>2]|0;
  __ZNK5physx3Cct26CharacterControllerManager15onObstacleAddedEjPKNS_17PxObstacleContextE($107,$60,$this);
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 } else if ((($2|0) == 3)) {
  $3 = (($this) + 4|0);
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 28|0);
  $7 = $5 << 16;
  $8 = $7 | 4;
  $9 = $8;
  $10 = (__ZN5physx3Cct13HandleManager3AddEPv($6,$9)|0);
  HEAP32[$0>>2] = $10;
  $11 = (($0) + 8|0);
  ;HEAP32[$11+0>>2]=HEAP32[$obstacle+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$obstacle+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$obstacle+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$obstacle+12>>2]|0;HEAP32[$11+16>>2]=HEAP32[$obstacle+16>>2]|0;HEAP32[$11+20>>2]=HEAP32[$obstacle+20>>2]|0;HEAP32[$11+24>>2]=HEAP32[$obstacle+24>>2]|0;HEAP32[$11+28>>2]=HEAP32[$obstacle+28>>2]|0;
  $12 = (($0) + 40|0);
  $13 = (($obstacle) + 32|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$12>>2] = $14;
  $15 = (($0) + 44|0);
  $16 = (($obstacle) + 36|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$15>>2] = $17;
  $18 = (($0) + 48|0);
  $19 = (($obstacle) + 40|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$18>>2] = $20;
  $21 = (($0) + 52|0);
  $22 = (($obstacle) + 44|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$21>>2] = $23;
  $24 = (($0) + 56|0);
  $25 = (($obstacle) + 48|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$24>>2] = $26;
  $27 = (($0) + 60|0);
  $28 = (($obstacle) + 52|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$27>>2] = $29;
  $30 = (($0) + 64|0);
  $31 = (($obstacle) + 56|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$30>>2] = $32;
  $33 = (($this) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $34 & 2147483647;
  $36 = HEAP32[$4>>2]|0;
  $37 = ($35>>>0)>($36>>>0);
  if ($37) {
   $38 = HEAP32[$3>>2]|0;
   $39 = (($38) + (($36*72)|0)|0);
   $40 = ($39|0)==(0|0);
   if ($40) {
    $50 = $36;
   } else {
    $41 = ((($38) + (($36*72)|0)|0) + 8|0);
    ;HEAP32[$41+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$41+16>>2]=HEAP32[$11+16>>2]|0;HEAP32[$41+20>>2]=HEAP32[$11+20>>2]|0;HEAP32[$41+24>>2]=HEAP32[$11+24>>2]|0;HEAP32[$41+28>>2]=HEAP32[$11+28>>2]|0;
    $42 = ((($38) + (($36*72)|0)|0) + 40|0);
    HEAPF32[$42>>2] = $14;
    $43 = ((($38) + (($36*72)|0)|0) + 44|0);
    HEAPF32[$43>>2] = $17;
    $44 = ((($38) + (($36*72)|0)|0) + 48|0);
    HEAPF32[$44>>2] = $20;
    $45 = ((($38) + (($36*72)|0)|0) + 52|0);
    HEAPF32[$45>>2] = $23;
    $46 = ((($38) + (($36*72)|0)|0) + 56|0);
    HEAPF32[$46>>2] = $26;
    $47 = ((($38) + (($36*72)|0)|0) + 60|0);
    HEAPF32[$47>>2] = $29;
    $48 = ((($38) + (($36*72)|0)|0) + 64|0);
    HEAPF32[$48>>2] = $32;
    HEAP32[$39>>2] = $10;
    $$pre$i1 = HEAP32[$4>>2]|0;
    $50 = $$pre$i1;
   }
   $49 = (($50) + 1)|0;
   HEAP32[$4>>2] = $49;
  } else {
   (__ZN5physx6shdfnd5ArrayINS_3Cct15ObstacleContext19InternalBoxObstacleENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($3,$0)|0);
  }
  $51 = (($this) + 56|0);
  $52 = HEAP32[$51>>2]|0;
  __ZNK5physx3Cct26CharacterControllerManager15onObstacleAddedEjPKNS_17PxObstacleContextE($52,$10,$this);
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx3Cct15ObstacleContext14removeObstacleEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$0 = 0, $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0);
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0);
 var $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $or$cond$i = 0, $or$cond$i1$i = 0, $or$cond$i1$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $handle & 65535;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)<($2>>>0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($0<<1)|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7&65535;
 $9 = ($7<<16>>16)!=(-1);
 $10 = ($8>>>0)<($2>>>0);
 $or$cond$i = $9 & $10;
 if (!($or$cond$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($0<<1)|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = $14&65535;
 $16 = $handle >>> 16;
 $17 = ($15|0)==($16|0);
 if (!($17)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($this) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($8<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = $21;
 $24 = $23 & 65535;
 $25 = $23 >>> 16;
 if ((($24|0) == 4)) {
  $26 = (($this) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($25>>>0)<($27>>>0);
  if (!($28)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $29 = (($this) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $61 = $5;$67 = $12;
  } else {
   $32 = $handle&65535;
   $33 = (($30) + -1)|0;
   HEAP32[$29>>2] = $33;
   $34 = (($19) + ($33<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   HEAP32[$20>>2] = $35;
   $36 = (($this) + 44|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + ($33<<1)|0);
   $39 = HEAP16[$38>>1]|0;
   $40 = $39&65535;
   $41 = HEAP32[$4>>2]|0;
   $42 = (($41) + ($40<<1)|0);
   HEAP16[$42>>1] = $7;
   $43 = HEAP16[$38>>1]|0;
   $44 = (($37) + ($8<<1)|0);
   HEAP16[$44>>1] = $43;
   HEAP16[$38>>1] = $32;
   $45 = (($41) + ($0<<1)|0);
   HEAP16[$45>>1] = -1;
   $46 = (($this) + 52|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($47) + 1)|0;
   HEAP32[$46>>2] = $48;
   $49 = HEAP32[$11>>2]|0;
   $50 = (($49) + ($0<<1)|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = (($51) + 1)<<16>>16;
   HEAP16[$50>>1] = $52;
   $61 = $41;$67 = $49;
  }
  $53 = (($27) + -1)|0;
  $54 = ($53|0)==($25|0);
  $$pre = (($this) + 4|0);
  if (!($54)) {
   $55 = HEAP32[$$pre>>2]|0;
   $56 = (($55) + (($53*72)|0)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $57 & 65535;
   $59 = ($58>>>0)<($2>>>0);
   if ($59) {
    $60 = (($61) + ($58<<1)|0);
    $62 = HEAP16[$60>>1]|0;
    $63 = $62&65535;
    $64 = ($62<<16>>16)!=(-1);
    $65 = ($63>>>0)<($2>>>0);
    $or$cond$i1$i3 = $64 & $65;
    if ($or$cond$i1$i3) {
     $66 = (($67) + ($58<<1)|0);
     $68 = HEAP16[$66>>1]|0;
     $69 = $68&65535;
     $70 = $57 >>> 16;
     $71 = ($69|0)==($70|0);
     if ($71) {
      $72 = HEAP32[$18>>2]|0;
      $73 = (($72) + ($63<<2)|0);
      HEAP32[$73>>2] = $21;
     }
    }
   }
  }
  $74 = HEAP32[$$pre>>2]|0;
  HEAP32[$26>>2] = $53;
  $75 = (($74) + (($53*72)|0)|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + (($25*72)|0)|0);
  HEAP32[$77>>2] = $76;
  $78 = ((($74) + (($25*72)|0)|0) + 8|0);
  $79 = ((($74) + (($53*72)|0)|0) + 8|0);
  ;HEAP32[$78+0>>2]=HEAP32[$79+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$79+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$79+8>>2]|0;HEAP32[$78+12>>2]=HEAP32[$79+12>>2]|0;HEAP32[$78+16>>2]=HEAP32[$79+16>>2]|0;HEAP32[$78+20>>2]=HEAP32[$79+20>>2]|0;HEAP32[$78+24>>2]=HEAP32[$79+24>>2]|0;HEAP32[$78+28>>2]=HEAP32[$79+28>>2]|0;
  $80 = ((($74) + (($53*72)|0)|0) + 40|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = ((($74) + (($25*72)|0)|0) + 40|0);
  HEAPF32[$82>>2] = $81;
  $83 = ((($74) + (($53*72)|0)|0) + 44|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = ((($74) + (($25*72)|0)|0) + 44|0);
  HEAPF32[$85>>2] = $84;
  $86 = ((($74) + (($53*72)|0)|0) + 48|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = ((($74) + (($25*72)|0)|0) + 48|0);
  HEAPF32[$88>>2] = $87;
  $89 = ((($74) + (($53*72)|0)|0) + 52|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = ((($74) + (($25*72)|0)|0) + 52|0);
  HEAPF32[$91>>2] = $90;
  $92 = ((($74) + (($53*72)|0)|0) + 56|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = ((($74) + (($25*72)|0)|0) + 56|0);
  HEAPF32[$94>>2] = $93;
  $95 = ((($74) + (($53*72)|0)|0) + 60|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = ((($74) + (($25*72)|0)|0) + 60|0);
  HEAPF32[$97>>2] = $96;
  $98 = ((($74) + (($53*72)|0)|0) + 64|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = ((($74) + (($25*72)|0)|0) + 64|0);
  HEAPF32[$100>>2] = $99;
  $101 = (($this) + 56|0);
  $102 = HEAP32[$101>>2]|0;
  __ZNK5physx3Cct26CharacterControllerManager17onObstacleRemovedEj($102,$handle);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($24|0) == 3)) {
  $103 = (($this) + 20|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ($25>>>0)<($104>>>0);
  if (!($105)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $106 = (($this) + 32|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ($107|0)==(0);
  if ($108) {
   $138 = $5;$144 = $12;
  } else {
   $109 = $handle&65535;
   $110 = (($107) + -1)|0;
   HEAP32[$106>>2] = $110;
   $111 = (($19) + ($110<<2)|0);
   $112 = HEAP32[$111>>2]|0;
   HEAP32[$20>>2] = $112;
   $113 = (($this) + 44|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = (($114) + ($110<<1)|0);
   $116 = HEAP16[$115>>1]|0;
   $117 = $116&65535;
   $118 = HEAP32[$4>>2]|0;
   $119 = (($118) + ($117<<1)|0);
   HEAP16[$119>>1] = $7;
   $120 = HEAP16[$115>>1]|0;
   $121 = (($114) + ($8<<1)|0);
   HEAP16[$121>>1] = $120;
   HEAP16[$115>>1] = $109;
   $122 = (($118) + ($0<<1)|0);
   HEAP16[$122>>1] = -1;
   $123 = (($this) + 52|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = (($124) + 1)|0;
   HEAP32[$123>>2] = $125;
   $126 = HEAP32[$11>>2]|0;
   $127 = (($126) + ($0<<1)|0);
   $128 = HEAP16[$127>>1]|0;
   $129 = (($128) + 1)<<16>>16;
   HEAP16[$127>>1] = $129;
   $138 = $118;$144 = $126;
  }
  $130 = (($104) + -1)|0;
  $131 = ($130|0)==($25|0);
  $$pre4 = (($this) + 16|0);
  if (!($131)) {
   $132 = HEAP32[$$pre4>>2]|0;
   $133 = (($132) + ($130<<6)|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = $134 & 65535;
   $136 = ($135>>>0)<($2>>>0);
   if ($136) {
    $137 = (($138) + ($135<<1)|0);
    $139 = HEAP16[$137>>1]|0;
    $140 = $139&65535;
    $141 = ($139<<16>>16)!=(-1);
    $142 = ($140>>>0)<($2>>>0);
    $or$cond$i1$i = $141 & $142;
    if ($or$cond$i1$i) {
     $143 = (($144) + ($135<<1)|0);
     $145 = HEAP16[$143>>1]|0;
     $146 = $145&65535;
     $147 = $134 >>> 16;
     $148 = ($146|0)==($147|0);
     if ($148) {
      $149 = HEAP32[$18>>2]|0;
      $150 = (($149) + ($140<<2)|0);
      HEAP32[$150>>2] = $21;
     }
    }
   }
  }
  $151 = HEAP32[$$pre4>>2]|0;
  HEAP32[$103>>2] = $130;
  $152 = (($151) + ($130<<6)|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = (($151) + ($25<<6)|0);
  HEAP32[$154>>2] = $153;
  $155 = ((($151) + ($25<<6)|0) + 8|0);
  $156 = ((($151) + ($130<<6)|0) + 8|0);
  ;HEAP32[$155+0>>2]=HEAP32[$156+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$156+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$156+8>>2]|0;HEAP32[$155+12>>2]=HEAP32[$156+12>>2]|0;HEAP32[$155+16>>2]=HEAP32[$156+16>>2]|0;HEAP32[$155+20>>2]=HEAP32[$156+20>>2]|0;HEAP32[$155+24>>2]=HEAP32[$156+24>>2]|0;HEAP32[$155+28>>2]=HEAP32[$156+28>>2]|0;
  $157 = ((($151) + ($130<<6)|0) + 40|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = ((($151) + ($25<<6)|0) + 40|0);
  HEAPF32[$159>>2] = $158;
  $160 = ((($151) + ($130<<6)|0) + 44|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = ((($151) + ($25<<6)|0) + 44|0);
  HEAPF32[$162>>2] = $161;
  $163 = ((($151) + ($130<<6)|0) + 48|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = ((($151) + ($25<<6)|0) + 48|0);
  HEAPF32[$165>>2] = $164;
  $166 = ((($151) + ($130<<6)|0) + 52|0);
  $167 = Math_fround(HEAPF32[$166>>2]);
  $168 = ((($151) + ($25<<6)|0) + 52|0);
  HEAPF32[$168>>2] = $167;
  $169 = ((($151) + ($25<<6)|0) + 56|0);
  $170 = ((($151) + ($130<<6)|0) + 56|0);
  $171 = $170;
  $172 = $171;
  $173 = HEAP32[$172>>2]|0;
  $174 = (($171) + 4)|0;
  $175 = $174;
  $176 = HEAP32[$175>>2]|0;
  $177 = $169;
  $178 = $177;
  HEAP32[$178>>2] = $173;
  $179 = (($177) + 4)|0;
  $180 = $179;
  HEAP32[$180>>2] = $176;
  $181 = (($this) + 56|0);
  $182 = HEAP32[$181>>2]|0;
  __ZNK5physx3Cct26CharacterControllerManager17onObstacleRemovedEj($182,$handle);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx3Cct15ObstacleContext14updateObstacleEjRKNS_10PxObstacleE($this,$handle,$obstacle) {
 $this = $this|0;
 $handle = $handle|0;
 $obstacle = $obstacle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $handle & 65535;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)<($2>>>0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($0<<1)|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7&65535;
 $9 = ($7<<16>>16)!=(-1);
 $10 = ($8>>>0)<($2>>>0);
 $or$cond$i = $9 & $10;
 if (!($or$cond$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($0<<1)|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = $14&65535;
 $16 = $handle >>> 16;
 $17 = ($15|0)==($16|0);
 if (!($17)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($this) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($8<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = $21;
 $24 = $23 & 65535;
 $25 = (($24) + -1)|0;
 $26 = HEAP32[$obstacle>>2]|0;
 $27 = ($25|0)==($26|0);
 if (!($27)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = $23 >>> 16;
 if ((($24|0) == 4)) {
  $29 = (($this) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28>>>0)<($30>>>0);
  if (!($31)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $32 = (($this) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($33) + (($28*72)|0)|0) + 8|0);
  ;HEAP32[$34+0>>2]=HEAP32[$obstacle+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$obstacle+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$obstacle+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$obstacle+12>>2]|0;HEAP32[$34+16>>2]=HEAP32[$obstacle+16>>2]|0;HEAP32[$34+20>>2]=HEAP32[$obstacle+20>>2]|0;HEAP32[$34+24>>2]=HEAP32[$obstacle+24>>2]|0;HEAP32[$34+28>>2]=HEAP32[$obstacle+28>>2]|0;
  $35 = (($obstacle) + 32|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = ((($33) + (($28*72)|0)|0) + 40|0);
  HEAPF32[$37>>2] = $36;
  $38 = (($obstacle) + 36|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = ((($33) + (($28*72)|0)|0) + 44|0);
  HEAPF32[$40>>2] = $39;
  $41 = (($obstacle) + 40|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = ((($33) + (($28*72)|0)|0) + 48|0);
  HEAPF32[$43>>2] = $42;
  $44 = (($obstacle) + 44|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = ((($33) + (($28*72)|0)|0) + 52|0);
  HEAPF32[$46>>2] = $45;
  $47 = (($obstacle) + 48|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = ((($33) + (($28*72)|0)|0) + 56|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($obstacle) + 52|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = ((($33) + (($28*72)|0)|0) + 60|0);
  HEAPF32[$52>>2] = $51;
  $53 = (($obstacle) + 56|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = ((($33) + (($28*72)|0)|0) + 64|0);
  HEAPF32[$55>>2] = $54;
  $56 = (($this) + 56|0);
  $57 = HEAP32[$56>>2]|0;
  __ZNK5physx3Cct26CharacterControllerManager17onObstacleUpdatedEjPKNS_17PxObstacleContextE($57,$handle,$this);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($24|0) == 3)) {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($28>>>0)<($59>>>0);
  if (!($60)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $61 = (($this) + 16|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($62) + ($28<<6)|0) + 8|0);
  ;HEAP32[$63+0>>2]=HEAP32[$obstacle+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$obstacle+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$obstacle+8>>2]|0;HEAP32[$63+12>>2]=HEAP32[$obstacle+12>>2]|0;HEAP32[$63+16>>2]=HEAP32[$obstacle+16>>2]|0;HEAP32[$63+20>>2]=HEAP32[$obstacle+20>>2]|0;HEAP32[$63+24>>2]=HEAP32[$obstacle+24>>2]|0;HEAP32[$63+28>>2]=HEAP32[$obstacle+28>>2]|0;
  $64 = (($obstacle) + 32|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($62) + ($28<<6)|0) + 40|0);
  HEAPF32[$66>>2] = $65;
  $67 = (($obstacle) + 36|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = ((($62) + ($28<<6)|0) + 44|0);
  HEAPF32[$69>>2] = $68;
  $70 = (($obstacle) + 40|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = ((($62) + ($28<<6)|0) + 48|0);
  HEAPF32[$72>>2] = $71;
  $73 = (($obstacle) + 44|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = ((($62) + ($28<<6)|0) + 52|0);
  HEAPF32[$75>>2] = $74;
  $76 = ((($62) + ($28<<6)|0) + 56|0);
  $77 = (($obstacle) + 48|0);
  $78 = $77;
  $79 = $78;
  $80 = HEAP32[$79>>2]|0;
  $81 = (($78) + 4)|0;
  $82 = $81;
  $83 = HEAP32[$82>>2]|0;
  $84 = $76;
  $85 = $84;
  HEAP32[$85>>2] = $80;
  $86 = (($84) + 4)|0;
  $87 = $86;
  HEAP32[$87>>2] = $83;
  $88 = (($this) + 56|0);
  $89 = HEAP32[$88>>2]|0;
  __ZNK5physx3Cct26CharacterControllerManager17onObstacleUpdatedEjPKNS_17PxObstacleContextE($89,$handle,$this);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx3Cct15ObstacleContext14getNbObstaclesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx3Cct15ObstacleContext11getObstacleEj($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($i>>>0);
 if ($2) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ((($4) + (($i*72)|0)|0) + 8|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($i) - ($1))|0;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($6<<6)|0) + 8|0);
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx3Cct15ObstacleContext19getObstacleByHandleEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $handle & 65535;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)<($2>>>0);
 do {
  if ($3) {
   $4 = (($this) + 40|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + ($0<<1)|0);
   $7 = HEAP16[$6>>1]|0;
   $8 = $7&65535;
   $9 = ($7<<16>>16)!=(-1);
   $10 = ($8>>>0)<($2>>>0);
   $or$cond$i = $9 & $10;
   if ($or$cond$i) {
    $11 = (($this) + 48|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + ($0<<1)|0);
    $14 = HEAP16[$13>>1]|0;
    $15 = $14&65535;
    $16 = $handle >>> 16;
    $17 = ($15|0)==($16|0);
    if ($17) {
     $18 = (($this) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($19) + ($8<<2)|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      $$0 = 0;
     } else {
      $23 = $21;
      $24 = $23 & 65535;
      $25 = $23 >>> 16;
      if ((($24|0) == 3)) {
       $32 = (($this) + 20|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = ($25>>>0)<($33>>>0);
       if (!($34)) {
        $$0 = 0;
        break;
       }
       $35 = (($this) + 16|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = ((($36) + ($25<<6)|0) + 8|0);
       $$0 = $37;
       break;
      } else if ((($24|0) == 4)) {
       $26 = (($this) + 8|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($25>>>0)<($27>>>0);
       if (!($28)) {
        $$0 = 0;
        break;
       }
       $29 = (($this) + 4|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ((($30) + (($25*72)|0)|0) + 8|0);
       $$0 = $31;
       break;
      } else {
       $$0 = 0;
       break;
      }
     }
    } else {
     $$0 = 0;
    }
   } else {
    $$0 = 0;
   }
  } else {
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx3Cct15ObstacleContext13raycastSingleERNS_12PxRaycastHitERKNS_6PxVec3ES6_fRj($this,$hit,$origin,$unitDir,$distance,$obstacleHandle) {
 $this = $this|0;
 $hit = $hit|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $obstacleHandle = $obstacleHandle|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0.0, $123 = Math_fround(0), $124 = 0, $125 = 0.0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0;
 var $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = Math_fround(0);
 var $54 = 0, $55 = 0.0, $56 = Math_fround(0), $57 = 0, $58 = 0.0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0;
 var $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond18 = 0, $i$010 = 0, $i1$07 = 0, $localHit = 0, $t$0$lcssa = Math_fround(0), $t$012 = Math_fround(0), $t$1 = Math_fround(0), $t$29 = Math_fround(0), $t$3 = Math_fround(0);
 var $touchedObstacle$0$lcssa = 0, $touchedObstacle$011 = 0, $touchedObstacle$1 = 0, $touchedObstacle$2$lcssa = 0, $touchedObstacle$28 = 0, $touchedObstacle$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $localHit = sp + 88|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = sp + 154|0;
 $3 = sp + 72|0;
 $4 = sp + 44|0;
 $5 = sp + 152|0;
 HEAP32[$localHit>>2] = 0;
 $6 = (($localHit) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($localHit) + 8|0);
 HEAP32[$7>>2] = -1;
 $8 = (($localHit) + 12|0);
 HEAP16[$8>>1] = 0;
 $9 = (($localHit) + 16|0);
 $10 = (($localHit) + 40|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;
 HEAPF32[$10>>2] = Math_fround(3.40282346638528859812E+38);
 $11 = (($localHit) + 44|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($localHit) + 48|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $t$0$lcssa = Math_fround(3.40282346638528859812E+38);$touchedObstacle$0$lcssa = 0;
 } else {
  $16 = (($this) + 4|0);
  $17 = (($0) + 4|0);
  $18 = (($0) + 8|0);
  $19 = (($0) + 12|0);
  $20 = (($1) + 4|0);
  $21 = (($1) + 8|0);
  $22 = (($1) + 12|0);
  $23 = (($1) + 16|0);
  $24 = (($1) + 20|0);
  $25 = (($1) + 24|0);
  $26 = (($hit) + 12|0);
  $27 = (($hit) + 16|0);
  $28 = (($localHit) + 20|0);
  $29 = (($hit) + 20|0);
  $30 = (($localHit) + 24|0);
  $31 = (($hit) + 24|0);
  $32 = (($localHit) + 28|0);
  $33 = (($hit) + 28|0);
  $34 = (($localHit) + 32|0);
  $35 = (($hit) + 32|0);
  $36 = (($localHit) + 36|0);
  $37 = (($hit) + 36|0);
  $38 = (($hit) + 40|0);
  $39 = (($hit) + 44|0);
  $i$010 = 0;$t$012 = Math_fround(3.40282346638528859812E+38);$touchedObstacle$011 = 0;
  while(1) {
   $40 = HEAP32[$16>>2]|0;
   $41 = (__ZN5physx2Gu19GetRaycastFuncTableEv()|0);
   $42 = (($41) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ((($40) + (($i$010*72)|0)|0) + 56|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = ((($40) + (($i$010*72)|0)|0) + 60|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = ((($40) + (($i$010*72)|0)|0) + 64|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   HEAP32[$0>>2] = 3;
   HEAPF32[$17>>2] = $45;
   HEAPF32[$18>>2] = $47;
   HEAPF32[$19>>2] = $49;
   $50 = ((($40) + (($i$010*72)|0)|0) + 8|0);
   $51 = ((($40) + (($i$010*72)|0)|0) + 16|0);
   $52 = +HEAPF64[$51>>3];
   $53 = Math_fround($52);
   $54 = ((($40) + (($i$010*72)|0)|0) + 24|0);
   $55 = +HEAPF64[$54>>3];
   $56 = Math_fround($55);
   $57 = ((($40) + (($i$010*72)|0)|0) + 32|0);
   $58 = +HEAPF64[$57>>3];
   $59 = Math_fround($58);
   $60 = ((($40) + (($i$010*72)|0)|0) + 40|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   HEAPF32[$1>>2] = $61;
   $62 = ((($40) + (($i$010*72)|0)|0) + 44|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   HEAPF32[$20>>2] = $63;
   $64 = ((($40) + (($i$010*72)|0)|0) + 48|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   HEAPF32[$21>>2] = $65;
   $66 = ((($40) + (($i$010*72)|0)|0) + 52|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   HEAPF32[$22>>2] = $67;
   HEAPF32[$23>>2] = $53;
   HEAPF32[$24>>2] = $56;
   HEAPF32[$25>>2] = $59;
   HEAP16[$2>>1] = 4;
   $68 = (FUNCTION_TABLE_iiiiifiiiiii[$43 & 7]($0,$1,$origin,$unitDir,$distance,$2,1,$localHit,0,0,0)|0);
   $69 = ($68|0)==(0);
   if ($69) {
    $t$1 = $t$012;$touchedObstacle$1 = $touchedObstacle$011;
   } else {
    $70 = Math_fround(HEAPF32[$10>>2]);
    $71 = $70 < $t$012;
    if ($71) {
     ;HEAP32[$hit+0>>2]=HEAP32[$localHit+0>>2]|0;HEAP32[$hit+4>>2]=HEAP32[$localHit+4>>2]|0;HEAP32[$hit+8>>2]=HEAP32[$localHit+8>>2]|0;
     $72 = HEAP16[$8>>1]|0;
     HEAP16[$26>>1] = $72;
     $73 = Math_fround(HEAPF32[$9>>2]);
     HEAPF32[$27>>2] = $73;
     $74 = Math_fround(HEAPF32[$28>>2]);
     HEAPF32[$29>>2] = $74;
     $75 = Math_fround(HEAPF32[$30>>2]);
     HEAPF32[$31>>2] = $75;
     $76 = Math_fround(HEAPF32[$32>>2]);
     HEAPF32[$33>>2] = $76;
     $77 = Math_fround(HEAPF32[$34>>2]);
     HEAPF32[$35>>2] = $77;
     $78 = Math_fround(HEAPF32[$36>>2]);
     HEAPF32[$37>>2] = $78;
     HEAPF32[$38>>2] = $70;
     ;HEAP32[$39+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$11+16>>2]|0;
     $79 = HEAP32[$16>>2]|0;
     $80 = (($79) + (($i$010*72)|0)|0);
     $81 = HEAP32[$80>>2]|0;
     HEAP32[$obstacleHandle>>2] = $81;
     $t$1 = $70;$touchedObstacle$1 = $50;
    } else {
     $t$1 = $t$012;$touchedObstacle$1 = $touchedObstacle$011;
    }
   }
   $82 = (($i$010) + 1)|0;
   $exitcond18 = ($82|0)==($14|0);
   if ($exitcond18) {
    $t$0$lcssa = $t$1;$touchedObstacle$0$lcssa = $touchedObstacle$1;
    break;
   } else {
    $i$010 = $82;$t$012 = $t$1;$touchedObstacle$011 = $touchedObstacle$1;
   }
  }
 }
 $83 = (($this) + 20|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(0);
 if ($85) {
  $touchedObstacle$2$lcssa = $touchedObstacle$0$lcssa;
  STACKTOP = sp;return ($touchedObstacle$2$lcssa|0);
 }
 $86 = (($this) + 16|0);
 $87 = (($3) + 4|0);
 $88 = (($3) + 8|0);
 $89 = (($4) + 4|0);
 $90 = (($4) + 8|0);
 $91 = (($4) + 12|0);
 $92 = (($4) + 16|0);
 $93 = (($4) + 20|0);
 $94 = (($4) + 24|0);
 $95 = (($hit) + 12|0);
 $96 = (($hit) + 16|0);
 $97 = (($localHit) + 20|0);
 $98 = (($hit) + 20|0);
 $99 = (($localHit) + 24|0);
 $100 = (($hit) + 24|0);
 $101 = (($localHit) + 28|0);
 $102 = (($hit) + 28|0);
 $103 = (($localHit) + 32|0);
 $104 = (($hit) + 32|0);
 $105 = (($localHit) + 36|0);
 $106 = (($hit) + 36|0);
 $107 = (($hit) + 40|0);
 $108 = (($hit) + 44|0);
 $i1$07 = 0;$t$29 = $t$0$lcssa;$touchedObstacle$28 = $touchedObstacle$0$lcssa;
 while(1) {
  $109 = HEAP32[$86>>2]|0;
  $110 = (__ZN5physx2Gu19GetRaycastFuncTableEv()|0);
  $111 = (($110) + 8|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = ((($109) + ($i1$07<<6)|0) + 60|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = ((($109) + ($i1$07<<6)|0) + 56|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  HEAP32[$3>>2] = 2;
  HEAPF32[$87>>2] = $114;
  HEAPF32[$88>>2] = $116;
  $117 = ((($109) + ($i1$07<<6)|0) + 8|0);
  $118 = ((($109) + ($i1$07<<6)|0) + 16|0);
  $119 = +HEAPF64[$118>>3];
  $120 = Math_fround($119);
  $121 = ((($109) + ($i1$07<<6)|0) + 24|0);
  $122 = +HEAPF64[$121>>3];
  $123 = Math_fround($122);
  $124 = ((($109) + ($i1$07<<6)|0) + 32|0);
  $125 = +HEAPF64[$124>>3];
  $126 = Math_fround($125);
  $127 = ((($109) + ($i1$07<<6)|0) + 40|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  HEAPF32[$4>>2] = $128;
  $129 = ((($109) + ($i1$07<<6)|0) + 44|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  HEAPF32[$89>>2] = $130;
  $131 = ((($109) + ($i1$07<<6)|0) + 48|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  HEAPF32[$90>>2] = $132;
  $133 = ((($109) + ($i1$07<<6)|0) + 52|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  HEAPF32[$91>>2] = $134;
  HEAPF32[$92>>2] = $120;
  HEAPF32[$93>>2] = $123;
  HEAPF32[$94>>2] = $126;
  HEAP16[$5>>1] = 4;
  $135 = (FUNCTION_TABLE_iiiiifiiiiii[$112 & 7]($3,$4,$origin,$unitDir,$distance,$5,1,$localHit,0,0,0)|0);
  $136 = ($135|0)==(0);
  if ($136) {
   $t$3 = $t$29;$touchedObstacle$3 = $touchedObstacle$28;
  } else {
   $137 = Math_fround(HEAPF32[$10>>2]);
   $138 = $137 < $t$29;
   if ($138) {
    ;HEAP32[$hit+0>>2]=HEAP32[$localHit+0>>2]|0;HEAP32[$hit+4>>2]=HEAP32[$localHit+4>>2]|0;HEAP32[$hit+8>>2]=HEAP32[$localHit+8>>2]|0;
    $139 = HEAP16[$8>>1]|0;
    HEAP16[$95>>1] = $139;
    $140 = Math_fround(HEAPF32[$9>>2]);
    HEAPF32[$96>>2] = $140;
    $141 = Math_fround(HEAPF32[$97>>2]);
    HEAPF32[$98>>2] = $141;
    $142 = Math_fround(HEAPF32[$99>>2]);
    HEAPF32[$100>>2] = $142;
    $143 = Math_fround(HEAPF32[$101>>2]);
    HEAPF32[$102>>2] = $143;
    $144 = Math_fround(HEAPF32[$103>>2]);
    HEAPF32[$104>>2] = $144;
    $145 = Math_fround(HEAPF32[$105>>2]);
    HEAPF32[$106>>2] = $145;
    HEAPF32[$107>>2] = $137;
    ;HEAP32[$108+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$108+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$108+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$108+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$108+16>>2]=HEAP32[$11+16>>2]|0;
    $146 = HEAP32[$86>>2]|0;
    $147 = (($146) + ($i1$07<<6)|0);
    $148 = HEAP32[$147>>2]|0;
    HEAP32[$obstacleHandle>>2] = $148;
    $t$3 = $137;$touchedObstacle$3 = $117;
   } else {
    $t$3 = $t$29;$touchedObstacle$3 = $touchedObstacle$28;
   }
  }
  $149 = (($i1$07) + 1)|0;
  $exitcond = ($149|0)==($84|0);
  if ($exitcond) {
   $touchedObstacle$2$lcssa = $touchedObstacle$3;
   break;
  } else {
   $i1$07 = $149;$t$29 = $t$3;$touchedObstacle$28 = $touchedObstacle$3;
  }
 }
 STACKTOP = sp;return ($touchedObstacle$2$lcssa|0);
}
function __ZNK5physx3Cct15ObstacleContext13raycastSingleERNS_12PxRaycastHitERKjRKNS_6PxVec3ES8_f($this,$hit,$obstacleHandle,$origin,$unitDir,$distance) {
 $this = $this|0;
 $hit = $hit|0;
 $obstacleHandle = $obstacleHandle|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0;
 var $50 = Math_fround(0), $51 = 0, $52 = 0.0, $53 = Math_fround(0), $54 = 0, $55 = 0.0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0.0;
 var $87 = Math_fround(0), $88 = 0, $89 = 0.0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0.0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 72|0;
 $1 = sp;
 $2 = sp + 90|0;
 $3 = sp + 56|0;
 $4 = sp + 28|0;
 $5 = sp + 88|0;
 $6 = HEAP32[$obstacleHandle>>2]|0;
 $7 = $6 & 65535;
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)<($9>>>0);
 if (!($10)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($7<<1)|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = $14&65535;
 $16 = ($14<<16>>16)!=(-1);
 $17 = ($15>>>0)<($9>>>0);
 $or$cond$i = $16 & $17;
 if (!($or$cond$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($this) + 48|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($7<<1)|0);
 $21 = HEAP16[$20>>1]|0;
 $22 = $21&65535;
 $23 = $6 >>> 16;
 $24 = ($22|0)==($23|0);
 if (!($24)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $25 = (($this) + 28|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + ($15<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = $28;
 $31 = $30 & 65535;
 $32 = $30 >>> 16;
 $33 = ($31|0)==(4);
 if ($33) {
  $34 = (($this) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (__ZN5physx2Gu19GetRaycastFuncTableEv()|0);
  $37 = (($36) + 12|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($35) + (($32*72)|0)|0) + 56|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = ((($35) + (($32*72)|0)|0) + 60|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = ((($35) + (($32*72)|0)|0) + 64|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  HEAP32[$0>>2] = 3;
  $45 = (($0) + 4|0);
  HEAPF32[$45>>2] = $40;
  $46 = (($0) + 8|0);
  HEAPF32[$46>>2] = $42;
  $47 = (($0) + 12|0);
  HEAPF32[$47>>2] = $44;
  $48 = ((($35) + (($32*72)|0)|0) + 16|0);
  $49 = +HEAPF64[$48>>3];
  $50 = Math_fround($49);
  $51 = ((($35) + (($32*72)|0)|0) + 24|0);
  $52 = +HEAPF64[$51>>3];
  $53 = Math_fround($52);
  $54 = ((($35) + (($32*72)|0)|0) + 32|0);
  $55 = +HEAPF64[$54>>3];
  $56 = Math_fround($55);
  $57 = ((($35) + (($32*72)|0)|0) + 40|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$1>>2] = $58;
  $59 = (($1) + 4|0);
  $60 = ((($35) + (($32*72)|0)|0) + 44|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  HEAPF32[$59>>2] = $61;
  $62 = (($1) + 8|0);
  $63 = ((($35) + (($32*72)|0)|0) + 48|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$62>>2] = $64;
  $65 = (($1) + 12|0);
  $66 = ((($35) + (($32*72)|0)|0) + 52|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$65>>2] = $67;
  $68 = (($1) + 16|0);
  HEAPF32[$68>>2] = $50;
  $69 = (($1) + 20|0);
  HEAPF32[$69>>2] = $53;
  $70 = (($1) + 24|0);
  HEAPF32[$70>>2] = $56;
  HEAP16[$2>>1] = 4;
  $71 = (FUNCTION_TABLE_iiiiifiiiiii[$38 & 7]($0,$1,$origin,$unitDir,$distance,$2,1,$hit,0,0,0)|0);
  $72 = ($71|0)==(0);
  $73 = ((($35) + (($32*72)|0)|0) + 8|0);
  $$ = $72 ? 0 : $73;
  STACKTOP = sp;return ($$|0);
 }
 $74 = (($this) + 16|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (__ZN5physx2Gu19GetRaycastFuncTableEv()|0);
 $77 = (($76) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ((($75) + ($32<<6)|0) + 60|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = ((($75) + ($32<<6)|0) + 56|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 HEAP32[$3>>2] = 2;
 $83 = (($3) + 4|0);
 HEAPF32[$83>>2] = $80;
 $84 = (($3) + 8|0);
 HEAPF32[$84>>2] = $82;
 $85 = ((($75) + ($32<<6)|0) + 16|0);
 $86 = +HEAPF64[$85>>3];
 $87 = Math_fround($86);
 $88 = ((($75) + ($32<<6)|0) + 24|0);
 $89 = +HEAPF64[$88>>3];
 $90 = Math_fround($89);
 $91 = ((($75) + ($32<<6)|0) + 32|0);
 $92 = +HEAPF64[$91>>3];
 $93 = Math_fround($92);
 $94 = ((($75) + ($32<<6)|0) + 40|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 HEAPF32[$4>>2] = $95;
 $96 = (($4) + 4|0);
 $97 = ((($75) + ($32<<6)|0) + 44|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 HEAPF32[$96>>2] = $98;
 $99 = (($4) + 8|0);
 $100 = ((($75) + ($32<<6)|0) + 48|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 HEAPF32[$99>>2] = $101;
 $102 = (($4) + 12|0);
 $103 = ((($75) + ($32<<6)|0) + 52|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 HEAPF32[$102>>2] = $104;
 $105 = (($4) + 16|0);
 HEAPF32[$105>>2] = $87;
 $106 = (($4) + 20|0);
 HEAPF32[$106>>2] = $90;
 $107 = (($4) + 24|0);
 HEAPF32[$107>>2] = $93;
 HEAP16[$5>>1] = 4;
 $108 = (FUNCTION_TABLE_iiiiifiiiiii[$78 & 7]($3,$4,$origin,$unitDir,$distance,$5,1,$hit,0,0,0)|0);
 $109 = ($108|0)==(0);
 $110 = ((($75) + ($32<<6)|0) + 8|0);
 $$1 = $109 ? 0 : $110;
 $$0 = $$1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Cct15ObstacleContext13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0.0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0.0, $23 = 0, $24 = Math_fround(0), $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0.0;
 var $45 = 0.0, $46 = 0, $47 = 0, $5 = Math_fround(0), $6 = 0.0, $7 = 0, $8 = Math_fround(0), $9 = 0.0, $i$02 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = Math_fround(HEAPF32[$shift>>2]);
  $6 = +$5;
  $7 = (($shift) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = +$8;
  $10 = (($shift) + 8|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = +$11;
  $i$02 = 0;
  while(1) {
   $26 = ((($4) + (($i$02*72)|0)|0) + 16|0);
   $27 = +HEAPF64[$26>>3];
   $28 = $27 - $6;
   HEAPF64[$26>>3] = $28;
   $29 = ((($4) + (($i$02*72)|0)|0) + 24|0);
   $30 = +HEAPF64[$29>>3];
   $31 = $30 - $9;
   HEAPF64[$29>>3] = $31;
   $32 = ((($4) + (($i$02*72)|0)|0) + 32|0);
   $33 = +HEAPF64[$32>>3];
   $34 = $33 - $12;
   HEAPF64[$32>>3] = $34;
   $35 = (($i$02) + 1)|0;
   $36 = ($35>>>0)<($1>>>0);
   if ($36) {
    $i$02 = $35;
   } else {
    break;
   }
  }
 }
 $13 = (($this) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($this) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = Math_fround(HEAPF32[$shift>>2]);
 $19 = +$18;
 $20 = (($shift) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = +$21;
 $23 = (($shift) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = +$24;
 $i1$01 = 0;
 while(1) {
  $37 = ((($17) + ($i1$01<<6)|0) + 16|0);
  $38 = +HEAPF64[$37>>3];
  $39 = $38 - $19;
  HEAPF64[$37>>3] = $39;
  $40 = ((($17) + ($i1$01<<6)|0) + 24|0);
  $41 = +HEAPF64[$40>>3];
  $42 = $41 - $22;
  HEAPF64[$40>>3] = $42;
  $43 = ((($17) + ($i1$01<<6)|0) + 32|0);
  $44 = +HEAPF64[$43>>3];
  $45 = $44 - $25;
  HEAPF64[$43>>3] = $45;
  $46 = (($i1$01) + 1)|0;
  $47 = ($46>>>0)<($14>>>0);
  if ($47) {
   $i1$01 = $46;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_3Cct15ObstacleContext23InternalCapsuleObstacleENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 6;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 407944 : 407912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,407832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<6)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 8|0);
    $27 = (($$03$i) + 8|0);
    ;HEAP32[$26+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$27+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$27+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$27+20>>2]|0;HEAP32[$26+24>>2]=HEAP32[$27+24>>2]|0;HEAP32[$26+28>>2]=HEAP32[$27+28>>2]|0;
    $28 = (($$012$i) + 40|0);
    $29 = (($$03$i) + 40|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$28>>2] = $30;
    $31 = (($$012$i) + 44|0);
    $32 = (($$03$i) + 44|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    HEAPF32[$31>>2] = $33;
    $34 = (($$012$i) + 48|0);
    $35 = (($$03$i) + 48|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    HEAPF32[$34>>2] = $36;
    $37 = (($$012$i) + 52|0);
    $38 = (($$03$i) + 52|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    HEAPF32[$37>>2] = $39;
    $40 = (($$012$i) + 56|0);
    $41 = (($$03$i) + 56|0);
    $42 = $41;
    $43 = $42;
    $44 = HEAP32[$43>>2]|0;
    $45 = (($42) + 4)|0;
    $46 = $45;
    $47 = HEAP32[$46>>2]|0;
    $48 = $40;
    $49 = $48;
    HEAP32[$49>>2] = $44;
    $50 = (($48) + 4)|0;
    $51 = $50;
    HEAP32[$51>>2] = $47;
    $52 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $52;
   }
   $53 = (($$012$i) + 64|0);
   $54 = (($$03$i) + 64|0);
   $55 = ($53>>>0)<($20>>>0);
   if ($55) {
    $$012$i = $53;$$03$i = $54;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $57 = $$pre;
 } else {
  $57 = $19;
 }
 $56 = (($21) + ($57<<6)|0);
 $58 = ($56|0)==(0|0);
 if (!($58)) {
  $59 = HEAP32[$a>>2]|0;
  HEAP32[$56>>2] = $59;
  $60 = ((($21) + ($57<<6)|0) + 8|0);
  $61 = (($a) + 8|0);
  ;HEAP32[$60+0>>2]=HEAP32[$61+0>>2]|0;HEAP32[$60+4>>2]=HEAP32[$61+4>>2]|0;HEAP32[$60+8>>2]=HEAP32[$61+8>>2]|0;HEAP32[$60+12>>2]=HEAP32[$61+12>>2]|0;HEAP32[$60+16>>2]=HEAP32[$61+16>>2]|0;HEAP32[$60+20>>2]=HEAP32[$61+20>>2]|0;HEAP32[$60+24>>2]=HEAP32[$61+24>>2]|0;HEAP32[$60+28>>2]=HEAP32[$61+28>>2]|0;
  $62 = ((($21) + ($57<<6)|0) + 40|0);
  $63 = (($a) + 40|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$62>>2] = $64;
  $65 = ((($21) + ($57<<6)|0) + 44|0);
  $66 = (($a) + 44|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$65>>2] = $67;
  $68 = ((($21) + ($57<<6)|0) + 48|0);
  $69 = (($a) + 48|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$68>>2] = $70;
  $71 = ((($21) + ($57<<6)|0) + 52|0);
  $72 = (($a) + 52|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  HEAPF32[$71>>2] = $73;
  $74 = ((($21) + ($57<<6)|0) + 56|0);
  $75 = (($a) + 56|0);
  $76 = $75;
  $77 = $76;
  $78 = HEAP32[$77>>2]|0;
  $79 = (($76) + 4)|0;
  $80 = $79;
  $81 = HEAP32[$80>>2]|0;
  $82 = $74;
  $83 = $82;
  HEAP32[$83>>2] = $78;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $81;
  $86 = HEAP32[$a>>2]|0;
  HEAP32[$56>>2] = $86;
 }
 $87 = HEAP32[$0>>2]|0;
 $88 = ($87|0)>(-1);
 if (!($88)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $95 = HEAP32[$18>>2]|0;
  $96 = (($95) + 1)|0;
  HEAP32[$18>>2] = $96;
  $97 = (($21) + ($95<<6)|0);
  STACKTOP = sp;return ($97|0);
 }
 $89 = HEAP32[$this>>2]|0;
 $90 = ($89|0)==(0|0);
 if ($90) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $95 = HEAP32[$18>>2]|0;
  $96 = (($95) + 1)|0;
  HEAP32[$18>>2] = $96;
  $97 = (($21) + ($95<<6)|0);
  STACKTOP = sp;return ($97|0);
 }
 $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + 12|0);
 $94 = HEAP32[$93>>2]|0;
 FUNCTION_TABLE_vii[$94 & 4095]($91,$89);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $95 = HEAP32[$18>>2]|0;
 $96 = (($95) + 1)|0;
 HEAP32[$18>>2] = $96;
 $97 = (($21) + ($95<<6)|0);
 STACKTOP = sp;return ($97|0);
}
function __ZN5physx6shdfnd5ArrayINS_3Cct15ObstacleContext19InternalBoxObstacleENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0);
 var $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*72)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 408128 : 407912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,407832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*72)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 8|0);
    $27 = (($$03$i) + 8|0);
    ;HEAP32[$26+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$27+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$27+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$27+20>>2]|0;HEAP32[$26+24>>2]=HEAP32[$27+24>>2]|0;HEAP32[$26+28>>2]=HEAP32[$27+28>>2]|0;
    $28 = (($$012$i) + 40|0);
    $29 = (($$03$i) + 40|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$28>>2] = $30;
    $31 = (($$012$i) + 44|0);
    $32 = (($$03$i) + 44|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    HEAPF32[$31>>2] = $33;
    $34 = (($$012$i) + 48|0);
    $35 = (($$03$i) + 48|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    HEAPF32[$34>>2] = $36;
    $37 = (($$012$i) + 52|0);
    $38 = (($$03$i) + 52|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    HEAPF32[$37>>2] = $39;
    $40 = (($$012$i) + 56|0);
    $41 = (($$03$i) + 56|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    HEAPF32[$40>>2] = $42;
    $43 = (($$012$i) + 60|0);
    $44 = (($$03$i) + 60|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$43>>2] = $45;
    $46 = (($$012$i) + 64|0);
    $47 = (($$03$i) + 64|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    HEAPF32[$46>>2] = $48;
    $49 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $49;
   }
   $50 = (($$012$i) + 72|0);
   $51 = (($$03$i) + 72|0);
   $52 = ($50>>>0)<($20>>>0);
   if ($52) {
    $$012$i = $50;$$03$i = $51;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $54 = $$pre;
 } else {
  $54 = $19;
 }
 $53 = (($21) + (($54*72)|0)|0);
 $55 = ($53|0)==(0|0);
 if (!($55)) {
  $56 = HEAP32[$a>>2]|0;
  HEAP32[$53>>2] = $56;
  $57 = ((($21) + (($54*72)|0)|0) + 8|0);
  $58 = (($a) + 8|0);
  ;HEAP32[$57+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$58+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$58+12>>2]|0;HEAP32[$57+16>>2]=HEAP32[$58+16>>2]|0;HEAP32[$57+20>>2]=HEAP32[$58+20>>2]|0;HEAP32[$57+24>>2]=HEAP32[$58+24>>2]|0;HEAP32[$57+28>>2]=HEAP32[$58+28>>2]|0;
  $59 = ((($21) + (($54*72)|0)|0) + 40|0);
  $60 = (($a) + 40|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  HEAPF32[$59>>2] = $61;
  $62 = ((($21) + (($54*72)|0)|0) + 44|0);
  $63 = (($a) + 44|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$62>>2] = $64;
  $65 = ((($21) + (($54*72)|0)|0) + 48|0);
  $66 = (($a) + 48|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$65>>2] = $67;
  $68 = ((($21) + (($54*72)|0)|0) + 52|0);
  $69 = (($a) + 52|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$68>>2] = $70;
  $71 = ((($21) + (($54*72)|0)|0) + 56|0);
  $72 = (($a) + 56|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  HEAPF32[$71>>2] = $73;
  $74 = ((($21) + (($54*72)|0)|0) + 60|0);
  $75 = (($a) + 60|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  HEAPF32[$74>>2] = $76;
  $77 = ((($21) + (($54*72)|0)|0) + 64|0);
  $78 = (($a) + 64|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  HEAPF32[$77>>2] = $79;
  $80 = HEAP32[$a>>2]|0;
  HEAP32[$53>>2] = $80;
 }
 $81 = HEAP32[$0>>2]|0;
 $82 = ($81|0)>(-1);
 if (!($82)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $89 = HEAP32[$18>>2]|0;
  $90 = (($89) + 1)|0;
  HEAP32[$18>>2] = $90;
  $91 = (($21) + (($89*72)|0)|0);
  STACKTOP = sp;return ($91|0);
 }
 $83 = HEAP32[$this>>2]|0;
 $84 = ($83|0)==(0|0);
 if ($84) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $89 = HEAP32[$18>>2]|0;
  $90 = (($89) + 1)|0;
  HEAP32[$18>>2] = $90;
  $91 = (($21) + (($89*72)|0)|0);
  STACKTOP = sp;return ($91|0);
 }
 $85 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + 12|0);
 $88 = HEAP32[$87>>2]|0;
 FUNCTION_TABLE_vii[$88 & 4095]($85,$83);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $89 = HEAP32[$18>>2]|0;
 $90 = (($89) + 1)|0;
 HEAP32[$18>>2] = $90;
 $91 = (($21) + (($89*72)|0)|0);
 STACKTOP = sp;return ($91|0);
}
function __ZN5physx3Cct8SweptBoxC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx3Cct11SweptVolumeC2Ev($this);
 HEAP32[$this>>2] = ((408304 + 8|0));
 $0 = (($this) + 36|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct8SweptBoxD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct8SweptBoxD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct8SweptBox18computeTemporalBoxERKNS0_9SweepTestERNS_17PxExtendedBounds3ERKNS_14PxExtendedVec3ERKNS_6PxVec3E($this,$test,$box,$center,$direction) {
 $this = $this|0;
 $test = $test|0;
 $box = $box|0;
 $center = $center|0;
 $direction = $direction|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 48|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $1 > $3;
 $5 = $4 ? $1 : $3;
 $6 = (($this) + 40|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(2.0));
 $9 = (($test) + 260|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($test) + 272|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($test) + 244|0);
 __ZN5physx3Cct18computeTemporalBoxERNS_17PxExtendedBounds3EffffRKNS_6PxVec3ERKNS_14PxExtendedVec3ES5_($box,$5,$8,$10,$12,$13,$center,$direction);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct12SweptCapsuleC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx3Cct11SweptVolumeC2Ev($this);
 HEAP32[$this>>2] = ((408328 + 8|0));
 $0 = (($this) + 36|0);
 HEAP32[$0>>2] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct12SweptCapsuleD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct12SweptCapsuleD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx3Cct12SweptCapsule18computeTemporalBoxERKNS0_9SweepTestERNS_17PxExtendedBounds3ERKNS_14PxExtendedVec3ERKNS_6PxVec3E($this,$test,$box,$center,$direction) {
 $this = $this|0;
 $test = $test|0;
 $box = $box|0;
 $center = $center|0;
 $direction = $direction|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 44|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($test) + 260|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($test) + 272|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($test) + 244|0);
 __ZN5physx3Cct18computeTemporalBoxERNS_17PxExtendedBounds3EffffRKNS_6PxVec3ERKNS_14PxExtendedVec3ES5_($box,$1,$3,$5,$7,$8,$center,$direction);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct11SweptVolumeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((408352 + 8|0));
 $0 = (($this) + 36|0);
 HEAP32[$0>>2] = 2;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct11SweptVolumeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx3Cct11SweptVolumeD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx3Cct18computeTemporalBoxERNS_17PxExtendedBounds3EffffRKNS_6PxVec3ERKNS_14PxExtendedVec3ES5_($_box,$radius,$height,$contactOffset,$maxJumpHeight,$upDirection,$center,$direction) {
 $_box = $_box|0;
 $radius = Math_fround($radius);
 $height = Math_fround($height);
 $contactOffset = Math_fround($contactOffset);
 $maxJumpHeight = Math_fround($maxJumpHeight);
 $upDirection = $upDirection|0;
 $center = $center|0;
 $direction = $direction|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0, $2 = Math_fround(0), $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0.0, $32 = 0.0, $33 = 0, $34 = Math_fround(0), $35 = 0.0, $36 = 0.0, $37 = 0, $38 = Math_fround(0), $39 = 0.0, $4 = Math_fround(0), $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0, $5 = Math_fround(0), $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = Math_fround(0), $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0, $8 = Math_fround(0), $80 = 0.0;
 var $81 = 0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0, $9 = Math_fround(0), $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($radius + $contactOffset);
 $1 = Math_fround($height * Math_fround(0.5));
 $2 = Math_fround(HEAPF32[$upDirection>>2]);
 $3 = (Math_fround(Math_abs((Math_fround($2)))));
 $4 = Math_fround($1 * $3);
 $5 = Math_fround($0 + $4);
 $6 = (($upDirection) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (Math_fround(Math_abs((Math_fround($7)))));
 $9 = Math_fround($1 * $8);
 $10 = Math_fround($0 + $9);
 $11 = (($upDirection) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (Math_fround(Math_abs((Math_fround($12)))));
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($0 + $14);
 $16 = +HEAPF64[$center>>3];
 $17 = (($center) + 8|0);
 $18 = +HEAPF64[$17>>3];
 $19 = (($center) + 16|0);
 $20 = +HEAPF64[$19>>3];
 $21 = +$5;
 $22 = $16 - $21;
 $23 = +$10;
 $24 = $18 - $23;
 $25 = +$15;
 $26 = $20 - $25;
 $27 = $21 + $16;
 $28 = $23 + $18;
 $29 = $20 + $25;
 $30 = Math_fround(HEAPF32[$direction>>2]);
 $31 = +$30;
 $32 = $16 + $31;
 $33 = (($direction) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = +$34;
 $36 = $18 + $35;
 $37 = (($direction) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = +$38;
 $40 = $20 + $39;
 $41 = $32 - $21;
 $42 = $36 - $23;
 $43 = $40 - $25;
 $44 = $21 + $32;
 $45 = $23 + $36;
 $46 = $25 + $40;
 $47 = $22 > $41;
 $48 = $47 ? $41 : $22;
 $49 = $24 > $42;
 $50 = $49 ? $42 : $24;
 $51 = $26 > $43;
 $52 = $51 ? $43 : $26;
 $53 = $27 < $44;
 $54 = $53 ? $44 : $27;
 $55 = $28 < $45;
 $56 = $55 ? $45 : $28;
 $57 = $29 < $46;
 $58 = $57 ? $46 : $29;
 $59 = $maxJumpHeight != Math_fround(0.0);
 if ($59) {
  $60 = Math_fround($2 * $maxJumpHeight);
  $61 = Math_fround($7 * $maxJumpHeight);
  $62 = Math_fround($12 * $maxJumpHeight);
  $63 = +$60;
  $64 = $16 - $63;
  $65 = +$61;
  $66 = $18 - $65;
  $67 = +$62;
  $68 = $20 - $67;
  $69 = $64 - $21;
  $70 = $66 - $23;
  $71 = $68 - $25;
  $72 = $21 + $64;
  $73 = $23 + $66;
  $74 = $25 + $68;
  $75 = $48 > $69;
  $76 = $75 ? $69 : $48;
  $77 = $50 > $70;
  $78 = $77 ? $70 : $50;
  $79 = $52 > $71;
  $80 = $79 ? $71 : $52;
  $81 = $54 < $72;
  $82 = $81 ? $72 : $54;
  $83 = $56 < $73;
  $84 = $83 ? $73 : $56;
  $85 = $58 < $74;
  if ($85) {
   $86 = $76;$88 = $78;$90 = $80;$92 = $82;$94 = $84;$96 = $74;
  } else {
   $86 = $76;$88 = $78;$90 = $80;$92 = $82;$94 = $84;$96 = $58;
  }
 } else {
  $86 = $48;$88 = $50;$90 = $52;$92 = $54;$94 = $56;$96 = $58;
 }
 HEAPF64[$_box>>3] = $86;
 $87 = (($_box) + 8|0);
 HEAPF64[$87>>3] = $88;
 $89 = (($_box) + 16|0);
 HEAPF64[$89>>3] = $90;
 $91 = (($_box) + 24|0);
 HEAPF64[$91>>3] = $92;
 $93 = (($_box) + 32|0);
 HEAPF64[$93>>3] = $94;
 $95 = (($_box) + 40|0);
 HEAPF64[$95>>3] = $96;
 STACKTOP = sp;return;
}
function __ZN5physx18PxFabricCookerImpl4cookERKNS_15PxClothMeshDescENS_6PxVec3Eb($this,$desc,$gravity,$useGeodesicTether) {
 $this = $this|0;
 $desc = $desc|0;
 $gravity = $gravity|0;
 $useGeodesicTether = $useGeodesicTether|0;
 var $$$i = 0, $$$i$i$i$i$i = 0, $$$i$i$i5$i$i = 0, $$0 = 0, $$0$i$i$i$i = 0, $$01$i = 0, $$01$i$i = 0, $$01$i$i46 = 0, $$01$i122 = 0, $$012$i$i$i = 0, $$012$i$i$i70 = 0, $$013$i = 0, $$013$i$i = 0, $$013$i$i41 = 0, $$013$i118 = 0, $$016$i = 0, $$016$i$i = 0, $$016$i$i43 = 0, $$016$i119 = 0, $$03$i$i$i = 0;
 var $$03$i$i$i69 = 0, $$05$i = 0, $$05$i$i = 0, $$05$i$i45 = 0, $$05$i121 = 0, $$idx$i108 = 0, $$idx$i86 = 0, $$idx$i93 = 0, $$idx$val$i = 0, $$idx$val$i109 = 0, $$idx$val$i87 = 0, $$idx$val$i94 = 0, $$idx3$i = 0, $$idx3$i110 = 0, $$idx3$i95 = 0, $$idx3$val$i = 0, $$idx3$val$i111 = 0, $$idx3$val$i96 = 0, $$idx4$i = 0, $$idx4$i106 = 0;
 var $$idx4$i92 = 0, $$idx4$val$i = 0, $$idx5$i = 0, $$idx5$val$i = 0, $$in = 0, $$in$i = 0, $$in$i29 = 0, $$in1225$i = 0, $$in1225$i38 = 0, $$in1320$i = 0, $$in1320$i54 = 0, $$in137224 = 0, $$in1416$i = 0, $$in1416$i59 = 0, $$in280 = 0, $$lcssa = 0, $$lcssa192 = 0, $$lcssa223 = 0, $$op$i = Math_fround(0), $$ph$be$i$i = 0;
 var $$ph$i$i = 0, $$ph10$be$i$i = 0, $$ph10$i$i = 0, $$ph11$be$i$i = 0, $$ph11$i$i = 0, $$ph12$be$i$i = 0, $$ph12$i$i = 0, $$ph13$be$i$i = 0, $$ph13$i$i = 0, $$ph198 = 0, $$ph199 = 0, $$ph200 = 0, $$ph201 = 0, $$ph9$be$i$i = 0, $$ph9$i$i = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0;
 var $$pre$i$i67 = 0, $$pre$i$i85 = 0, $$pre$i2$i$i = 0, $$pre$i26 = 0, $$pre$i48 = 0, $$pre$i77 = 0, $$pre$i80 = 0, $$pre$i83 = 0, $$pre1$i$i = 0, $$pre1$i$i$i$i = 0, $$pre2$i$i$i$i = 0, $$pre247 = 0, $$pre258 = 0, $$pre259 = 0, $$pre260 = 0, $$pre266 = 0, $$pre267 = 0, $$pre268 = 0, $$pre40$i = 0, $$pre40$i34 = 0;
 var $$sum = 0, $$sum$i = 0, $$sum138 = 0, $$sum139 = 0, $$sum140 = 0, $$sum141 = 0, $$sum142 = 0, $$sum143 = 0, $$sum144 = 0, $$sum145 = 0, $$sum146 = 0, $$sum147 = 0, $$sum148 = 0, $$sum149 = 0, $$sum150 = 0, $$sum151 = 0, $$sum152 = 0, $$sum153 = 0, $$sum154 = 0, $$sum155 = 0;
 var $$sum156 = 0, $$sum157 = 0, $$sum158 = 0, $$sum6$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0;
 var $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0;
 var $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0;
 var $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0;
 var $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = Math_fround(0), $1082 = 0, $1083 = Math_fround(0);
 var $1084 = Math_fround(0), $1085 = 0, $1086 = Math_fround(0), $1087 = 0, $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = 0, $1090 = 0, $1091 = Math_fround(0), $1092 = 0, $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = 0, $1100 = Math_fround(0);
 var $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0;
 var $112 = Math_fround(0), $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = Math_fround(0), $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0;
 var $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = Math_fround(0), $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0;
 var $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = Math_fround(0), $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0;
 var $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = Math_fround(0), $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0;
 var $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0;
 var $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0;
 var $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0;
 var $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0;
 var $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0;
 var $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0;
 var $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0;
 var $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0;
 var $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0;
 var $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = Math_fround(0), $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0;
 var $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0;
 var $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0;
 var $1408 = 0, $1409 = Math_fround(0), $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0;
 var $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0;
 var $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0;
 var $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0;
 var $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0;
 var $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0;
 var $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0;
 var $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0;
 var $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0;
 var $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0;
 var $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = Math_fround(0), $545 = Math_fround(0), $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0;
 var $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0);
 var $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0;
 var $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0);
 var $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = 0, $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = 0, $618 = Math_fround(0), $619 = 0, $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = 0, $623 = 0, $624 = 0, $625 = 0;
 var $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0;
 var $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = Math_fround(0), $654 = 0, $655 = Math_fround(0), $656 = Math_fround(0), $657 = 0, $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = 0, $661 = 0;
 var $662 = Math_fround(0), $663 = 0, $664 = 0, $665 = Math_fround(0), $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = Math_fround(0), $672 = 0, $673 = Math_fround(0), $674 = Math_fround(0), $675 = 0, $676 = Math_fround(0), $677 = 0, $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0;
 var $680 = 0, $681 = Math_fround(0), $682 = 0, $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = 0, $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0);
 var $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0;
 var $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0;
 var $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0;
 var $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = Math_fround(0);
 var $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = Math_fround(0), $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0;
 var $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = Math_fround(0), $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0;
 var $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = Math_fround(0), $820 = 0, $821 = 0, $822 = 0, $823 = 0;
 var $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = Math_fround(0), $840 = 0, $841 = 0;
 var $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = Math_fround(0), $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = Math_fround(0);
 var $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0;
 var $879 = 0, $88 = Math_fround(0), $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = Math_fround(0), $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0;
 var $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = Math_fround(0), $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = Math_fround(0), $910 = 0, $911 = 0, $912 = 0, $913 = 0;
 var $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = Math_fround(0), $92 = Math_fround(0), $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0, $931 = 0;
 var $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = Math_fround(0), $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = Math_fround(0);
 var $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0;
 var $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0;
 var $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $aIt$0183 = 0, $adjColorCount = 0, $adjacencies = 0, $back = 0, $child$0$i = 0, $color$0 = 0;
 var $colors = 0, $constraint$0 = 0, $constraintHeap = 0, $constraintHeap$idx$val = 0, $constraintHeap$idx$val190274$ph = 0, $constraintHeap$idx$val190274277 = 0, $constraintHeap$idx10$val = 0, $constraintHeap$idx8$val = 0, $constraints = 0, $current$05$i = 0, $current$05$i107 = 0, $current$07$i = 0, $dest$pn$i = 0, $dest$pn$i$i = 0, $dest$pn$i$i44 = 0, $dest$pn$i120 = 0, $eIt$idx7$val$idx = 0, $eIt$idx7$val$idx$val = 0, $edges = 0, $exitcond = 0;
 var $exitcond$i$i$i = 0, $exitcond243 = 0, $exitcond244 = 0, $heap$idx$val$i = 0, $heap$idx$val$i104$pre = 0, $heap$idx$val$i104272$ph = 0, $heap$idx$val$i104272278 = 0, $heap$idx$val$i89 = 0, $heap$idx$val$i89250 = 0, $heap$idx$val$i89251 = 0, $heap$idx$val$i89254 = 0, $heap$idx$val$i89255 = 0, $heap$idx2$val$i = 0, $heap$idx2$val$i90 = 0, $heap$idx2$val$pre$i = 0, $heap$idx2$val$pre$i99 = 0, $i$0$i$i$i = 0, $i$0$ph$i$i$i = 0, $i$0225 = 0, $i$03$i$i$i = 0;
 var $i$033$i = 0, $i$033$i30 = 0, $i1$0221 = 0, $i1$026$i = 0, $i1$026$i37 = 0, $i12$0177 = 0, $i2$0210 = 0, $i3$021$i = 0, $i3$021$i53 = 0, $i5$017$i = 0, $i5$017$i58 = 0, $i5$0193 = 0, $i9$0180 = 0, $j$0$m$0$i$i$i = 0, $j$0$ph$i$i$i = 0, $j$02$i$i$i = 0, $j$0220 = 0, $j$1$i$i$i = 0, $j$1$lcssa = 0, $j$1215 = 0;
 var $j3$0207 = 0, $j8$0187 = 0, $k = 0, $k4$0202 = 0, $m$01$i$i$i = 0, $mark = 0, $neighbors = 0, $newIndices = 0, $newRestValues = 0, $notlhs = 0, $notlhs$i = 0, $notrhs = 0, $notrhs$i = 0, $numConstraints = 0, $or$cond = 0, $or$cond$i$i = 0, $or$cond$i$i11 = 0, $or$cond$i$i12 = 0, $or$cond$i$i14 = 0, $or$cond$i$i16 = 0;
 var $or$cond$i$i19 = 0, $or$cond$i$i21 = 0, $or$cond$i$i23 = 0, $or$cond$i$i62 = 0, $or$cond$i$i64 = 0, $or$cond$i$i72$not = 0, $or$cond$i$i75 = 0, $or$cond$not$i = 0, $or$cond1$i$i = 0, $or$cond2$i = 0, $or$cond2$i$i = 0, $or$cond279 = 0, $particles = 0, $phase = 0, $phitmp = 0, $phitmp$i = 0, $phitmp$i49 = 0, $phitmp269 = 0, $r$0161 = 0, $r13$0175 = 0;
 var $reorder = 0, $tetherCooker = 0, $tetherCooker14 = 0, $this$idx$val$i$i = 0, $this$idx$val$i$i98 = 0, $valency = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $vararg_buffer = sp + 8|0;
 $0 = sp + 368|0;
 $1 = sp + 360|0;
 $2 = sp + 356|0;
 $particles = sp + 344|0;
 $3 = sp + 328|0;
 $valency = sp + 312|0;
 $4 = sp + 308|0;
 $adjacencies = sp + 296|0;
 $mark = sp + 284|0;
 $5 = sp + 280|0;
 $neighbors = sp + 268|0;
 $k = sp + 264|0;
 $edges = sp + 224|0;
 $6 = sp + 216|0;
 $7 = sp + 208|0;
 $constraints = sp + 196|0;
 $8 = sp + 192|0;
 $9 = sp + 188|0;
 $10 = sp + 176|0;
 $numConstraints = sp + 172|0;
 $11 = sp + 168|0;
 $12 = sp + 164|0;
 $colors = sp + 152|0;
 $13 = sp + 496|0;
 $14 = sp + 76|0;
 $adjColorCount = sp + 36|0;
 $15 = sp + 32|0;
 $constraintHeap = sp + 64|0;
 $16 = sp + 16|0;
 $17 = sp + 24|0;
 $phase = sp;
 $18 = sp + 48|0;
 $back = sp + 52|0;
 $19 = sp + 56|0;
 $20 = sp + 60|0;
 $newIndices = sp + 136|0;
 $21 = sp + 80|0;
 $newRestValues = sp + 84|0;
 $22 = sp + 96|0;
 $reorder = sp + 100|0;
 $23 = sp + 112|0;
 $tetherCooker = sp + 116|0;
 $24 = sp + 120|0;
 $25 = sp + 124|0;
 $tetherCooker14 = sp + 128|0;
 $26 = sp + 132|0;
 $27 = sp + 148|0;
 $28 = (($desc) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29>>>0)<(3);
 do {
  if (!($30)) {
   $31 = ($29>>>0)>(65535);
   if ($31) {
    $32 = (($desc) + 48|0);
    $33 = HEAP16[$32>>1]|0;
    $34 = $33 & 2;
    $35 = ($34<<16>>16)==(0);
    if (!($35)) {
     break;
    }
   }
   $36 = (($desc) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    $39 = HEAP32[$desc>>2]|0;
    $40 = ($39>>>0)<(12);
    if (!($40)) {
     $41 = (($desc) + 16|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0|0);
     if (!($43)) {
      $44 = (($desc) + 12|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45>>>0)<(4);
      if ($46) {
       break;
      }
      $47 = (($desc) + 20|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)==($29|0);
      if (!($49)) {
       break;
      }
     }
     $50 = (($desc) + 32|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0);
     if ($52) {
      $53 = (($desc) + 44|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($54|0)==(0);
      if ($55) {
       break;
      } else {
       label = 13;
      }
     } else {
      $56 = (($desc) + 28|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0|0);
      if ($58) {
       break;
      }
      $$phi$trans$insert$i = (($desc) + 44|0);
      $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
      $59 = ($$pre$i|0)==(0);
      if ($59) {
       $1536 = 1;
      } else {
       label = 13;
      }
     }
     if ((label|0) == 13) {
      $60 = (($desc) + 40|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       break;
      } else {
       $1536 = 0;
      }
     }
     $63 = (($desc) + 48|0);
     $64 = HEAP16[$63>>1]|0;
     $65 = $64 & 2;
     $66 = ($65<<16>>16)!=(0);
     $67 = $66 ? 2 : 4;
     if (!($52)) {
      $68 = (($desc) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($67*3)|0;
      $71 = ($69>>>0)<($70>>>0);
      if ($71) {
       break;
      }
     }
     if (!($1536)) {
      $72 = (($desc) + 36|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = $67 << 2;
      $75 = ($73>>>0)<($74>>>0);
      if ($75) {
       break;
      }
     }
     $77 = Math_fround(HEAPF32[$gravity>>2]);
     $78 = Math_fround($77 * $77);
     $79 = (($gravity) + 4|0);
     $80 = Math_fround(HEAPF32[$79>>2]);
     $81 = Math_fround($80 * $80);
     $82 = Math_fround($78 + $81);
     $83 = (($gravity) + 8|0);
     $84 = Math_fround(HEAPF32[$83>>2]);
     $85 = Math_fround($84 * $84);
     $86 = Math_fround($82 + $85);
     $87 = $86 > Math_fround(0.0);
     if ($87) {
      $88 = (Math_fround(Math_sqrt((Math_fround($86)))));
      $89 = Math_fround(Math_fround(1.0) / $88);
      $90 = Math_fround($77 * $89);
      $91 = Math_fround($80 * $89);
      $92 = Math_fround($84 * $89);
      $93 = $90;$94 = $91;$95 = $92;
     } else {
      $93 = Math_fround(0.0);$94 = Math_fround(0.0);$95 = Math_fround(0.0);
     }
     HEAPF32[$gravity>>2] = $93;
     HEAPF32[$79>>2] = $94;
     HEAPF32[$83>>2] = $95;
     HEAP32[$this>>2] = $29;
     HEAP32[$particles>>2] = 0;
     $96 = (($particles) + 4|0);
     HEAP32[$96>>2] = 0;
     $97 = (($particles) + 8|0);
     HEAP32[$97>>2] = 0;
     $98 = ($29|0)==(0);
     if ($98) {
      $$lcssa223 = 0;
     } else {
      __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($particles,$29);
      $$pre = HEAP32[$this>>2]|0;
      $99 = HEAP32[$desc>>2]|0;
      $100 = (($desc) + 12|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = ($$pre|0)==(0);
      if ($102) {
       $$lcssa223 = 0;
      } else {
       $103 = HEAP32[$41>>2]|0;
       $104 = HEAP32[$36>>2]|0;
       $105 = (($3) + 4|0);
       $106 = (($3) + 8|0);
       $107 = (($3) + 12|0);
       $$in137224 = $104;$110 = $103;$1537 = $$pre;$i$0225 = 0;
       while(1) {
        $108 = (($$in137224) + ($99)|0);
        $109 = ($110|0)==(0|0);
        if ($109) {
         $118 = Math_fround(1.0);$1538 = 0;
        } else {
         $111 = (($110) + ($101)|0);
         $112 = Math_fround(HEAPF32[$110>>2]);
         $118 = $112;$1538 = $111;
        }
        $113 = Math_fround(HEAPF32[$$in137224>>2]);
        HEAPF32[$3>>2] = $113;
        $114 = (($$in137224) + 4|0);
        $115 = Math_fround(HEAPF32[$114>>2]);
        HEAPF32[$105>>2] = $115;
        $116 = (($$in137224) + 8|0);
        $117 = Math_fround(HEAPF32[$116>>2]);
        HEAPF32[$106>>2] = $117;
        HEAPF32[$107>>2] = $118;
        $119 = HEAP32[$97>>2]|0;
        $120 = $119 & 2147483647;
        $121 = HEAP32[$96>>2]|0;
        $122 = ($120>>>0)>($121>>>0);
        if ($122) {
         $123 = HEAP32[$particles>>2]|0;
         $124 = (($123) + ($121<<4)|0);
         $125 = ($124|0)==(0|0);
         if (!($125)) {
          HEAPF32[$124>>2] = $113;
          $126 = ((($123) + ($121<<4)|0) + 4|0);
          HEAPF32[$126>>2] = $115;
          $127 = ((($123) + ($121<<4)|0) + 8|0);
          HEAPF32[$127>>2] = $117;
          $128 = ((($123) + ($121<<4)|0) + 12|0);
          HEAPF32[$128>>2] = $118;
         }
         $129 = (($121) + 1)|0;
         HEAP32[$96>>2] = $129;
         $132 = $1537;
        } else {
         (__ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($particles,$3)|0);
         $$pre260 = HEAP32[$this>>2]|0;
         $132 = $$pre260;
        }
        $130 = (($i$0225) + 1)|0;
        $131 = ($130>>>0)<($132>>>0);
        if ($131) {
         $$in137224 = $108;$110 = $1538;$1537 = $132;$i$0225 = $130;
        } else {
         $$lcssa223 = $132;
         break;
        }
       }
      }
     }
     $133 = (($$lcssa223) + 1)|0;
     HEAP32[$4>>2] = 0;
     HEAP32[$valency>>2] = 0;
     $134 = (($valency) + 4|0);
     HEAP32[$134>>2] = 0;
     $135 = (($valency) + 8|0);
     HEAP32[$135>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($valency,$133,$4);
     HEAP32[$adjacencies>>2] = 0;
     $136 = (($adjacencies) + 4|0);
     HEAP32[$136>>2] = 0;
     $137 = (($adjacencies) + 8|0);
     HEAP32[$137>>2] = 0;
     $138 = HEAP16[$63>>1]|0;
     $139 = $138 & 2;
     $140 = ($139<<16>>16)==(0);
     $141 = (($desc) + 24|0);
     $142 = (($desc) + 36|0);
     if ($140) {
      $303 = (($desc) + 28|0);
      $304 = HEAP32[$141>>2]|0;
      $305 = HEAP32[$50>>2]|0;
      $306 = ($305|0)==(0);
      if (!($306)) {
       $307 = HEAP32[$303>>2]|0;
       $308 = HEAP32[$valency>>2]|0;
       $$in$i29 = $307;$i$033$i30 = 0;
       while(1) {
        $309 = HEAP32[$$in$i29>>2]|0;
        $310 = (($308) + ($309<<2)|0);
        $311 = HEAP32[$310>>2]|0;
        $312 = (($311) + 2)|0;
        HEAP32[$310>>2] = $312;
        $313 = (($$in$i29) + 4|0);
        $314 = HEAP32[$313>>2]|0;
        $315 = (($308) + ($314<<2)|0);
        $316 = HEAP32[$315>>2]|0;
        $317 = (($316) + 2)|0;
        HEAP32[$315>>2] = $317;
        $318 = (($$in$i29) + 8|0);
        $319 = HEAP32[$318>>2]|0;
        $320 = (($308) + ($319<<2)|0);
        $321 = HEAP32[$320>>2]|0;
        $322 = (($321) + 2)|0;
        HEAP32[$320>>2] = $322;
        $323 = (($i$033$i30) + 1)|0;
        $324 = (($$in$i29) + ($304)|0);
        $325 = HEAP32[$50>>2]|0;
        $326 = ($323>>>0)<($325>>>0);
        if ($326) {
         $$in$i29 = $324;$i$033$i30 = $323;
        } else {
         break;
        }
       }
      }
      $327 = (($desc) + 40|0);
      $328 = HEAP32[$142>>2]|0;
      $329 = (($desc) + 44|0);
      $330 = HEAP32[$329>>2]|0;
      $331 = ($330|0)==(0);
      if ($331) {
       $$pre40$i34 = HEAP32[$valency>>2]|0;
       $359 = $$pre40$i34;
      } else {
       $332 = HEAP32[$327>>2]|0;
       $333 = HEAP32[$valency>>2]|0;
       $$in1225$i38 = $332;$i1$026$i37 = 0;
       while(1) {
        $334 = HEAP32[$$in1225$i38>>2]|0;
        $335 = (($333) + ($334<<2)|0);
        $336 = HEAP32[$335>>2]|0;
        $337 = (($336) + 2)|0;
        HEAP32[$335>>2] = $337;
        $338 = (($$in1225$i38) + 4|0);
        $339 = HEAP32[$338>>2]|0;
        $340 = (($333) + ($339<<2)|0);
        $341 = HEAP32[$340>>2]|0;
        $342 = (($341) + 2)|0;
        HEAP32[$340>>2] = $342;
        $343 = (($$in1225$i38) + 8|0);
        $344 = HEAP32[$343>>2]|0;
        $345 = (($333) + ($344<<2)|0);
        $346 = HEAP32[$345>>2]|0;
        $347 = (($346) + 2)|0;
        HEAP32[$345>>2] = $347;
        $348 = (($$in1225$i38) + 12|0);
        $349 = HEAP32[$348>>2]|0;
        $350 = (($333) + ($349<<2)|0);
        $351 = HEAP32[$350>>2]|0;
        $352 = (($351) + 2)|0;
        HEAP32[$350>>2] = $352;
        $353 = (($i1$026$i37) + 1)|0;
        $354 = (($$in1225$i38) + ($328)|0);
        $355 = HEAP32[$329>>2]|0;
        $356 = ($353>>>0)<($355>>>0);
        if ($356) {
         $$in1225$i38 = $354;$i1$026$i37 = $353;
        } else {
         $359 = $333;
         break;
        }
       }
      }
      $357 = HEAP32[$134>>2]|0;
      $358 = (($359) + ($357<<2)|0);
      $360 = ($357|0)==(0);
      if ($360) {
       $1540 = 0;$368 = -1;
      } else {
       $361 = ($357|0)==(1);
       if ($361) {
        $1540 = 1;$368 = 0;
       } else {
        $$013$i$i41 = (($359) + 4|0);
        $362 = HEAP32[$359>>2]|0;
        $$016$i$i43 = $$013$i$i41;$365 = $362;$dest$pn$i$i44 = $359;
        while(1) {
         $$05$i$i45 = (($dest$pn$i$i44) + 4|0);
         $363 = HEAP32[$$016$i$i43>>2]|0;
         $364 = (($363) + ($365))|0;
         HEAP32[$$05$i$i45>>2] = $364;
         $$01$i$i46 = (($$016$i$i43) + 4|0);
         $366 = ($$01$i$i46|0)==($358|0);
         if ($366) {
          break;
         } else {
          $$016$i$i43 = $$01$i$i46;$365 = $364;$dest$pn$i$i44 = $$05$i$i45;
         }
        }
        $$pre$i48 = HEAP32[$134>>2]|0;
        $phitmp$i49 = (($$pre$i48) + -1)|0;
        $1540 = $$pre$i48;$368 = $phitmp$i49;
       }
      }
      $367 = (($359) + ($368<<2)|0);
      $369 = HEAP32[$367>>2]|0;
      HEAP32[$1>>2] = 0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($adjacencies,$369,$1);
      $370 = HEAP32[$141>>2]|0;
      $371 = HEAP32[$50>>2]|0;
      $372 = ($371|0)==(0);
      if (!($372)) {
       $373 = HEAP32[$303>>2]|0;
       $374 = HEAP32[$adjacencies>>2]|0;
       $$in1320$i54 = $373;$i3$021$i53 = 0;
       while(1) {
        $375 = (($$in1320$i54) + 4|0);
        $376 = HEAP32[$375>>2]|0;
        $377 = HEAP32[$$in1320$i54>>2]|0;
        $378 = (($359) + ($377<<2)|0);
        $379 = HEAP32[$378>>2]|0;
        $380 = (($379) + -1)|0;
        HEAP32[$378>>2] = $380;
        $381 = (($374) + ($380<<2)|0);
        HEAP32[$381>>2] = $376;
        $382 = (($$in1320$i54) + 8|0);
        $383 = HEAP32[$382>>2]|0;
        $384 = HEAP32[$$in1320$i54>>2]|0;
        $385 = (($359) + ($384<<2)|0);
        $386 = HEAP32[$385>>2]|0;
        $387 = (($386) + -1)|0;
        HEAP32[$385>>2] = $387;
        $388 = (($374) + ($387<<2)|0);
        HEAP32[$388>>2] = $383;
        $389 = HEAP32[$382>>2]|0;
        $390 = HEAP32[$375>>2]|0;
        $391 = (($359) + ($390<<2)|0);
        $392 = HEAP32[$391>>2]|0;
        $393 = (($392) + -1)|0;
        HEAP32[$391>>2] = $393;
        $394 = (($374) + ($393<<2)|0);
        HEAP32[$394>>2] = $389;
        $395 = HEAP32[$$in1320$i54>>2]|0;
        $396 = HEAP32[$375>>2]|0;
        $397 = (($359) + ($396<<2)|0);
        $398 = HEAP32[$397>>2]|0;
        $399 = (($398) + -1)|0;
        HEAP32[$397>>2] = $399;
        $400 = (($374) + ($399<<2)|0);
        HEAP32[$400>>2] = $395;
        $401 = HEAP32[$$in1320$i54>>2]|0;
        $402 = HEAP32[$382>>2]|0;
        $403 = (($359) + ($402<<2)|0);
        $404 = HEAP32[$403>>2]|0;
        $405 = (($404) + -1)|0;
        HEAP32[$403>>2] = $405;
        $406 = (($374) + ($405<<2)|0);
        HEAP32[$406>>2] = $401;
        $407 = HEAP32[$375>>2]|0;
        $408 = HEAP32[$382>>2]|0;
        $409 = (($359) + ($408<<2)|0);
        $410 = HEAP32[$409>>2]|0;
        $411 = (($410) + -1)|0;
        HEAP32[$409>>2] = $411;
        $412 = (($374) + ($411<<2)|0);
        HEAP32[$412>>2] = $407;
        $413 = (($i3$021$i53) + 1)|0;
        $414 = (($$in1320$i54) + ($370)|0);
        $415 = HEAP32[$50>>2]|0;
        $416 = ($413>>>0)<($415>>>0);
        if ($416) {
         $$in1320$i54 = $414;$i3$021$i53 = $413;
        } else {
         break;
        }
       }
      }
      $417 = HEAP32[$142>>2]|0;
      $418 = HEAP32[$329>>2]|0;
      $419 = ($418|0)==(0);
      if ($419) {
       $479 = $1540;$488 = $359;
      } else {
       $420 = HEAP32[$327>>2]|0;
       $421 = HEAP32[$adjacencies>>2]|0;
       $$in1416$i59 = $420;$i5$017$i58 = 0;
       while(1) {
        $422 = (($$in1416$i59) + 4|0);
        $423 = HEAP32[$422>>2]|0;
        $424 = HEAP32[$$in1416$i59>>2]|0;
        $425 = (($359) + ($424<<2)|0);
        $426 = HEAP32[$425>>2]|0;
        $427 = (($426) + -1)|0;
        HEAP32[$425>>2] = $427;
        $428 = (($421) + ($427<<2)|0);
        HEAP32[$428>>2] = $423;
        $429 = (($$in1416$i59) + 12|0);
        $430 = HEAP32[$429>>2]|0;
        $431 = HEAP32[$$in1416$i59>>2]|0;
        $432 = (($359) + ($431<<2)|0);
        $433 = HEAP32[$432>>2]|0;
        $434 = (($433) + -1)|0;
        HEAP32[$432>>2] = $434;
        $435 = (($421) + ($434<<2)|0);
        HEAP32[$435>>2] = $430;
        $436 = (($$in1416$i59) + 8|0);
        $437 = HEAP32[$436>>2]|0;
        $438 = HEAP32[$422>>2]|0;
        $439 = (($359) + ($438<<2)|0);
        $440 = HEAP32[$439>>2]|0;
        $441 = (($440) + -1)|0;
        HEAP32[$439>>2] = $441;
        $442 = (($421) + ($441<<2)|0);
        HEAP32[$442>>2] = $437;
        $443 = HEAP32[$$in1416$i59>>2]|0;
        $444 = HEAP32[$422>>2]|0;
        $445 = (($359) + ($444<<2)|0);
        $446 = HEAP32[$445>>2]|0;
        $447 = (($446) + -1)|0;
        HEAP32[$445>>2] = $447;
        $448 = (($421) + ($447<<2)|0);
        HEAP32[$448>>2] = $443;
        $449 = HEAP32[$429>>2]|0;
        $450 = HEAP32[$436>>2]|0;
        $451 = (($359) + ($450<<2)|0);
        $452 = HEAP32[$451>>2]|0;
        $453 = (($452) + -1)|0;
        HEAP32[$451>>2] = $453;
        $454 = (($421) + ($453<<2)|0);
        HEAP32[$454>>2] = $449;
        $455 = HEAP32[$422>>2]|0;
        $456 = HEAP32[$436>>2]|0;
        $457 = (($359) + ($456<<2)|0);
        $458 = HEAP32[$457>>2]|0;
        $459 = (($458) + -1)|0;
        HEAP32[$457>>2] = $459;
        $460 = (($421) + ($459<<2)|0);
        HEAP32[$460>>2] = $455;
        $461 = HEAP32[$$in1416$i59>>2]|0;
        $462 = HEAP32[$429>>2]|0;
        $463 = (($359) + ($462<<2)|0);
        $464 = HEAP32[$463>>2]|0;
        $465 = (($464) + -1)|0;
        HEAP32[$463>>2] = $465;
        $466 = (($421) + ($465<<2)|0);
        HEAP32[$466>>2] = $461;
        $467 = HEAP32[$436>>2]|0;
        $468 = HEAP32[$429>>2]|0;
        $469 = (($359) + ($468<<2)|0);
        $470 = HEAP32[$469>>2]|0;
        $471 = (($470) + -1)|0;
        HEAP32[$469>>2] = $471;
        $472 = (($421) + ($471<<2)|0);
        HEAP32[$472>>2] = $467;
        $473 = (($i5$017$i58) + 1)|0;
        $474 = (($$in1416$i59) + ($417)|0);
        $475 = HEAP32[$329>>2]|0;
        $476 = ($473>>>0)<($475>>>0);
        if ($476) {
         $$in1416$i59 = $474;$i5$017$i58 = $473;
        } else {
         $479 = $1540;$488 = $359;
         break;
        }
       }
      }
     } else {
      $143 = (($desc) + 28|0);
      $144 = HEAP32[$141>>2]|0;
      $145 = HEAP32[$50>>2]|0;
      $146 = ($145|0)==(0);
      if (!($146)) {
       $147 = HEAP32[$143>>2]|0;
       $148 = HEAP32[$valency>>2]|0;
       $$in$i = $147;$i$033$i = 0;
       while(1) {
        $149 = HEAP16[$$in$i>>1]|0;
        $150 = $149&65535;
        $151 = (($148) + ($150<<2)|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = (($152) + 2)|0;
        HEAP32[$151>>2] = $153;
        $154 = (($$in$i) + 2|0);
        $155 = HEAP16[$154>>1]|0;
        $156 = $155&65535;
        $157 = (($148) + ($156<<2)|0);
        $158 = HEAP32[$157>>2]|0;
        $159 = (($158) + 2)|0;
        HEAP32[$157>>2] = $159;
        $160 = (($$in$i) + 4|0);
        $161 = HEAP16[$160>>1]|0;
        $162 = $161&65535;
        $163 = (($148) + ($162<<2)|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = (($164) + 2)|0;
        HEAP32[$163>>2] = $165;
        $166 = (($i$033$i) + 1)|0;
        $167 = (($$in$i) + ($144)|0);
        $168 = HEAP32[$50>>2]|0;
        $169 = ($166>>>0)<($168>>>0);
        if ($169) {
         $$in$i = $167;$i$033$i = $166;
        } else {
         break;
        }
       }
      }
      $170 = (($desc) + 40|0);
      $171 = HEAP32[$142>>2]|0;
      $172 = (($desc) + 44|0);
      $173 = HEAP32[$172>>2]|0;
      $174 = ($173|0)==(0);
      if ($174) {
       $$pre40$i = HEAP32[$valency>>2]|0;
       $206 = $$pre40$i;
      } else {
       $175 = HEAP32[$170>>2]|0;
       $176 = HEAP32[$valency>>2]|0;
       $$in1225$i = $175;$i1$026$i = 0;
       while(1) {
        $177 = HEAP16[$$in1225$i>>1]|0;
        $178 = $177&65535;
        $179 = (($176) + ($178<<2)|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = (($180) + 2)|0;
        HEAP32[$179>>2] = $181;
        $182 = (($$in1225$i) + 2|0);
        $183 = HEAP16[$182>>1]|0;
        $184 = $183&65535;
        $185 = (($176) + ($184<<2)|0);
        $186 = HEAP32[$185>>2]|0;
        $187 = (($186) + 2)|0;
        HEAP32[$185>>2] = $187;
        $188 = (($$in1225$i) + 4|0);
        $189 = HEAP16[$188>>1]|0;
        $190 = $189&65535;
        $191 = (($176) + ($190<<2)|0);
        $192 = HEAP32[$191>>2]|0;
        $193 = (($192) + 2)|0;
        HEAP32[$191>>2] = $193;
        $194 = (($$in1225$i) + 6|0);
        $195 = HEAP16[$194>>1]|0;
        $196 = $195&65535;
        $197 = (($176) + ($196<<2)|0);
        $198 = HEAP32[$197>>2]|0;
        $199 = (($198) + 2)|0;
        HEAP32[$197>>2] = $199;
        $200 = (($i1$026$i) + 1)|0;
        $201 = (($$in1225$i) + ($171)|0);
        $202 = HEAP32[$172>>2]|0;
        $203 = ($200>>>0)<($202>>>0);
        if ($203) {
         $$in1225$i = $201;$i1$026$i = $200;
        } else {
         $206 = $176;
         break;
        }
       }
      }
      $204 = HEAP32[$134>>2]|0;
      $205 = (($206) + ($204<<2)|0);
      $207 = ($204|0)==(0);
      if ($207) {
       $1539 = 0;$215 = -1;
      } else {
       $208 = ($204|0)==(1);
       if ($208) {
        $1539 = 1;$215 = 0;
       } else {
        $$013$i$i = (($206) + 4|0);
        $209 = HEAP32[$206>>2]|0;
        $$016$i$i = $$013$i$i;$212 = $209;$dest$pn$i$i = $206;
        while(1) {
         $$05$i$i = (($dest$pn$i$i) + 4|0);
         $210 = HEAP32[$$016$i$i>>2]|0;
         $211 = (($210) + ($212))|0;
         HEAP32[$$05$i$i>>2] = $211;
         $$01$i$i = (($$016$i$i) + 4|0);
         $213 = ($$01$i$i|0)==($205|0);
         if ($213) {
          break;
         } else {
          $$016$i$i = $$01$i$i;$212 = $211;$dest$pn$i$i = $$05$i$i;
         }
        }
        $$pre$i26 = HEAP32[$134>>2]|0;
        $phitmp$i = (($$pre$i26) + -1)|0;
        $1539 = $$pre$i26;$215 = $phitmp$i;
       }
      }
      $214 = (($206) + ($215<<2)|0);
      $216 = HEAP32[$214>>2]|0;
      HEAP32[$2>>2] = 0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($adjacencies,$216,$2);
      $217 = HEAP32[$141>>2]|0;
      $218 = HEAP32[$50>>2]|0;
      $219 = ($218|0)==(0);
      if (!($219)) {
       $220 = HEAP32[$143>>2]|0;
       $221 = HEAP32[$adjacencies>>2]|0;
       $$in1320$i = $220;$i3$021$i = 0;
       while(1) {
        $222 = (($$in1320$i) + 2|0);
        $223 = HEAP16[$222>>1]|0;
        $224 = $223&65535;
        $225 = HEAP16[$$in1320$i>>1]|0;
        $226 = $225&65535;
        $227 = (($206) + ($226<<2)|0);
        $228 = HEAP32[$227>>2]|0;
        $229 = (($228) + -1)|0;
        HEAP32[$227>>2] = $229;
        $230 = (($221) + ($229<<2)|0);
        HEAP32[$230>>2] = $224;
        $231 = (($$in1320$i) + 4|0);
        $232 = HEAP16[$231>>1]|0;
        $233 = $232&65535;
        $234 = HEAP32[$227>>2]|0;
        $235 = (($234) + -1)|0;
        HEAP32[$227>>2] = $235;
        $236 = (($221) + ($235<<2)|0);
        HEAP32[$236>>2] = $233;
        $237 = (($206) + ($224<<2)|0);
        $238 = HEAP32[$237>>2]|0;
        $239 = (($238) + -1)|0;
        HEAP32[$237>>2] = $239;
        $240 = (($221) + ($239<<2)|0);
        HEAP32[$240>>2] = $233;
        $241 = HEAP32[$237>>2]|0;
        $242 = (($241) + -1)|0;
        HEAP32[$237>>2] = $242;
        $243 = (($221) + ($242<<2)|0);
        HEAP32[$243>>2] = $226;
        $244 = (($206) + ($233<<2)|0);
        $245 = HEAP32[$244>>2]|0;
        $246 = (($245) + -1)|0;
        HEAP32[$244>>2] = $246;
        $247 = (($221) + ($246<<2)|0);
        HEAP32[$247>>2] = $226;
        $248 = HEAP32[$244>>2]|0;
        $249 = (($248) + -1)|0;
        HEAP32[$244>>2] = $249;
        $250 = (($221) + ($249<<2)|0);
        HEAP32[$250>>2] = $224;
        $251 = (($i3$021$i) + 1)|0;
        $252 = (($$in1320$i) + ($217)|0);
        $253 = HEAP32[$50>>2]|0;
        $254 = ($251>>>0)<($253>>>0);
        if ($254) {
         $$in1320$i = $252;$i3$021$i = $251;
        } else {
         break;
        }
       }
      }
      $255 = HEAP32[$142>>2]|0;
      $256 = HEAP32[$172>>2]|0;
      $257 = ($256|0)==(0);
      if ($257) {
       $479 = $1539;$488 = $206;
      } else {
       $258 = HEAP32[$170>>2]|0;
       $259 = HEAP32[$adjacencies>>2]|0;
       $$in1416$i = $258;$i5$017$i = 0;
       while(1) {
        $260 = (($$in1416$i) + 2|0);
        $261 = HEAP16[$260>>1]|0;
        $262 = $261&65535;
        $263 = HEAP16[$$in1416$i>>1]|0;
        $264 = $263&65535;
        $265 = (($206) + ($264<<2)|0);
        $266 = HEAP32[$265>>2]|0;
        $267 = (($266) + -1)|0;
        HEAP32[$265>>2] = $267;
        $268 = (($259) + ($267<<2)|0);
        HEAP32[$268>>2] = $262;
        $269 = (($$in1416$i) + 6|0);
        $270 = HEAP16[$269>>1]|0;
        $271 = $270&65535;
        $272 = HEAP32[$265>>2]|0;
        $273 = (($272) + -1)|0;
        HEAP32[$265>>2] = $273;
        $274 = (($259) + ($273<<2)|0);
        HEAP32[$274>>2] = $271;
        $275 = (($$in1416$i) + 4|0);
        $276 = HEAP16[$275>>1]|0;
        $277 = $276&65535;
        $278 = (($206) + ($262<<2)|0);
        $279 = HEAP32[$278>>2]|0;
        $280 = (($279) + -1)|0;
        HEAP32[$278>>2] = $280;
        $281 = (($259) + ($280<<2)|0);
        HEAP32[$281>>2] = $277;
        $282 = HEAP32[$278>>2]|0;
        $283 = (($282) + -1)|0;
        HEAP32[$278>>2] = $283;
        $284 = (($259) + ($283<<2)|0);
        HEAP32[$284>>2] = $264;
        $285 = (($206) + ($277<<2)|0);
        $286 = HEAP32[$285>>2]|0;
        $287 = (($286) + -1)|0;
        HEAP32[$285>>2] = $287;
        $288 = (($259) + ($287<<2)|0);
        HEAP32[$288>>2] = $271;
        $289 = HEAP32[$285>>2]|0;
        $290 = (($289) + -1)|0;
        HEAP32[$285>>2] = $290;
        $291 = (($259) + ($290<<2)|0);
        HEAP32[$291>>2] = $262;
        $292 = (($206) + ($271<<2)|0);
        $293 = HEAP32[$292>>2]|0;
        $294 = (($293) + -1)|0;
        HEAP32[$292>>2] = $294;
        $295 = (($259) + ($294<<2)|0);
        HEAP32[$295>>2] = $264;
        $296 = HEAP32[$292>>2]|0;
        $297 = (($296) + -1)|0;
        HEAP32[$292>>2] = $297;
        $298 = (($259) + ($297<<2)|0);
        HEAP32[$298>>2] = $277;
        $299 = (($i5$017$i) + 1)|0;
        $300 = (($$in1416$i) + ($255)|0);
        $301 = HEAP32[$172>>2]|0;
        $302 = ($299>>>0)<($301>>>0);
        if ($302) {
         $$in1416$i = $300;$i5$017$i = $299;
        } else {
         $479 = $1539;$488 = $206;
         break;
        }
       }
      }
     }
     HEAP32[$5>>2] = 0;
     HEAP32[$mark>>2] = 0;
     $477 = (($mark) + 4|0);
     HEAP32[$477>>2] = 0;
     $478 = (($mark) + 8|0);
     HEAP32[$478>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($mark,$479,$5);
     HEAP32[$neighbors>>2] = 0;
     $480 = (($neighbors) + 4|0);
     HEAP32[$480>>2] = 0;
     $481 = (($neighbors) + 8|0);
     HEAP32[$481>>2] = 0;
     $482 = HEAP32[$136>>2]|0;
     $483 = ($482|0)==(0);
     if (!($483)) {
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($neighbors,$482);
     }
     $484 = ($479>>>0)>(1);
     if ($484) {
      $485 = HEAP32[$adjacencies>>2]|0;
      $486 = HEAP32[$mark>>2]|0;
      $i1$0221 = 1;$j$0220 = 0;
      while(1) {
       $487 = (($488) + ($i1$0221<<2)|0);
       $489 = HEAP32[$487>>2]|0;
       $490 = ($j$0220>>>0)<($489>>>0);
       if ($490) {
        $j$1215 = $j$0220;
        while(1) {
         $491 = (($485) + ($j$1215<<2)|0);
         $492 = HEAP32[$491>>2]|0;
         HEAP32[$k>>2] = $492;
         $493 = (($486) + ($492<<2)|0);
         $494 = HEAP32[$493>>2]|0;
         $495 = ($494|0)==($i1$0221|0);
         do {
          if (!($495)) {
           HEAP32[$493>>2] = $i1$0221;
           $496 = HEAP32[$481>>2]|0;
           $497 = $496 & 2147483647;
           $498 = HEAP32[$480>>2]|0;
           $499 = ($497>>>0)>($498>>>0);
           if (!($499)) {
            (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($neighbors,$k)|0);
            break;
           }
           $500 = HEAP32[$neighbors>>2]|0;
           $501 = (($500) + ($498<<2)|0);
           $502 = ($501|0)==(0|0);
           if (!($502)) {
            HEAP32[$501>>2] = $492;
           }
           $503 = (($498) + 1)|0;
           HEAP32[$480>>2] = $503;
          }
         } while(0);
         $504 = (($j$1215) + 1)|0;
         $505 = HEAP32[$487>>2]|0;
         $506 = ($504>>>0)<($505>>>0);
         if ($506) {
          $j$1215 = $504;
         } else {
          $j$1$lcssa = $504;
          break;
         }
        }
       } else {
        $j$1$lcssa = $j$0220;
       }
       $507 = HEAP32[$480>>2]|0;
       HEAP32[$487>>2] = $507;
       $508 = (($i1$0221) + 1)|0;
       $509 = HEAP32[$134>>2]|0;
       $510 = ($508>>>0)<($509>>>0);
       if ($510) {
        $i1$0221 = $508;$j$0220 = $j$1$lcssa;
       } else {
        break;
       }
      }
     }
     $511 = (($edges) + 24|0);
     ;HEAP32[$edges+0>>2]=0|0;HEAP32[$edges+4>>2]=0|0;HEAP32[$edges+8>>2]=0|0;HEAP32[$edges+12>>2]=0|0;HEAP32[$edges+16>>2]=0|0;HEAP32[$edges+20>>2]=0|0;
     HEAPF32[$511>>2] = Math_fround(0.75);
     $512 = (($edges) + 28|0);
     HEAP32[$512>>2] = -1;
     $513 = (($edges) + 32|0);
     HEAP32[$513>>2] = 0;
     $514 = (($edges) + 36|0);
     HEAP32[$514>>2] = 0;
     __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IjjEEN12_GLOBAL__N_14EdgeEEES4_NS0_4HashIS4_EENS1_11HashMapBaseIS4_S7_SA_NS0_9AllocatorEE6GetKeyESC_Lb1EE15reserveInternalEj($edges,64);
     $515 = HEAP32[$this>>2]|0;
     $516 = ($515|0)==(0);
     if (!($516)) {
      $517 = HEAP32[$particles>>2]|0;
      $518 = HEAP32[$neighbors>>2]|0;
      $519 = (($6) + 4|0);
      $520 = (($7) + 4|0);
      $1541 = $515;$i2$0210 = 0;
      while(1) {
       $524 = ((($517) + ($i2$0210<<4)|0) + 12|0);
       $525 = Math_fround(HEAPF32[$524>>2]);
       $522 = (($i2$0210) + 1)|0;
       $526 = (($488) + ($522<<2)|0);
       $527 = HEAP32[$526>>2]|0;
       $528 = (($488) + ($i2$0210<<2)|0);
       $529 = HEAP32[$528>>2]|0;
       $530 = ($529>>>0)<($527>>>0);
       if ($530) {
        $531 = (($517) + ($i2$0210<<4)|0);
        $532 = ((($517) + ($i2$0210<<4)|0) + 4|0);
        $533 = ((($517) + ($i2$0210<<4)|0) + 8|0);
        $j3$0207 = $529;
        while(1) {
         $534 = (($518) + ($j3$0207<<2)|0);
         $535 = HEAP32[$534>>2]|0;
         $536 = ((($517) + ($535<<4)|0) + 12|0);
         $537 = Math_fround(HEAPF32[$536>>2]);
         $538 = Math_fround($525 + $537);
         $539 = $538 > Math_fround(0.0);
         if ($539) {
          $540 = ($i2$0210>>>0)<($535>>>0);
          $541 = $540 ? $i2$0210 : $535;
          $542 = $540 ? $535 : $i2$0210;
          HEAP32[$6>>2] = $541;
          HEAP32[$519>>2] = $542;
          $543 = (__ZN5physx6shdfnd8internal11HashMapBaseINS0_4PairIjjEEN12_GLOBAL__N_14EdgeENS0_4HashIS4_EENS0_9AllocatorEEixERKS4_($edges,$6)|0);
          $544 = Math_fround(HEAPF32[$543>>2]);
          $545 = Math_fround($544 + Math_fround(0.100000001490116119385));
          HEAPF32[$543>>2] = $545;
         }
         $546 = (($535) + 1)|0;
         $547 = (($488) + ($546<<2)|0);
         $548 = HEAP32[$547>>2]|0;
         $549 = (($488) + ($535<<2)|0);
         $550 = HEAP32[$549>>2]|0;
         $551 = ($550>>>0)<($548>>>0);
         if ($551) {
          $552 = (($517) + ($535<<4)|0);
          $553 = ((($517) + ($535<<4)|0) + 4|0);
          $554 = ((($517) + ($535<<4)|0) + 8|0);
          $k4$0202 = $550;
          while(1) {
           $555 = (($518) + ($k4$0202<<2)|0);
           $556 = HEAP32[$555>>2]|0;
           $557 = ($556|0)==($i2$0210|0);
           do {
            if (!($557)) {
             $558 = ((($517) + ($556<<4)|0) + 12|0);
             $559 = Math_fround(HEAPF32[$558>>2]);
             $560 = Math_fround($525 + $559);
             $561 = $560 > Math_fround(0.0);
             if (!($561)) {
              break;
             }
             $562 = ($i2$0210>>>0)<($556>>>0);
             $563 = $562 ? $i2$0210 : $556;
             $564 = $562 ? $556 : $i2$0210;
             HEAP32[$7>>2] = $563;
             HEAP32[$520>>2] = $564;
             $565 = (__ZN5physx6shdfnd8internal11HashMapBaseINS0_4PairIjjEEN12_GLOBAL__N_14EdgeENS0_4HashIS4_EENS0_9AllocatorEEixERKS4_($edges,$7)|0);
             $566 = Math_fround(HEAPF32[$552>>2]);
             $567 = Math_fround(HEAPF32[$531>>2]);
             $568 = Math_fround($566 - $567);
             $569 = Math_fround(HEAPF32[$553>>2]);
             $570 = Math_fround(HEAPF32[$532>>2]);
             $571 = Math_fround($569 - $570);
             $572 = Math_fround(HEAPF32[$554>>2]);
             $573 = Math_fround(HEAPF32[$533>>2]);
             $574 = Math_fround($572 - $573);
             $575 = (($517) + ($556<<4)|0);
             $576 = Math_fround(HEAPF32[$575>>2]);
             $577 = Math_fround($576 - $566);
             $578 = ((($517) + ($556<<4)|0) + 4|0);
             $579 = Math_fround(HEAPF32[$578>>2]);
             $580 = Math_fround($579 - $569);
             $581 = ((($517) + ($556<<4)|0) + 8|0);
             $582 = Math_fround(HEAPF32[$581>>2]);
             $583 = Math_fround($582 - $572);
             $584 = Math_fround($571 * $583);
             $585 = Math_fround($574 * $580);
             $586 = Math_fround($584 - $585);
             $587 = Math_fround($574 * $577);
             $588 = Math_fround($568 * $583);
             $589 = Math_fround($587 - $588);
             $590 = Math_fround($568 * $580);
             $591 = Math_fround($571 * $577);
             $592 = Math_fround($590 - $591);
             $593 = Math_fround($586 * $586);
             $594 = Math_fround($589 * $589);
             $595 = Math_fround($593 + $594);
             $596 = Math_fround($592 * $592);
             $597 = Math_fround($596 + $595);
             $598 = (Math_fround(Math_sqrt((Math_fround($597)))));
             $599 = Math_fround($576 - $567);
             $600 = Math_fround($579 - $570);
             $601 = Math_fround($582 - $573);
             $602 = Math_fround($599 * $599);
             $603 = Math_fround($600 * $600);
             $604 = Math_fround($602 + $603);
             $605 = Math_fround($601 * $601);
             $606 = Math_fround($604 + $605);
             $607 = Math_fround($598 / $606);
             $608 = Math_fround(Math_fround(0.449999988079071044922) - $607);
             $609 = (Math_fround(Math_abs((Math_fround($608)))));
             $610 = Math_fround(Math_fround(0.150000005960464477539) - $609);
             $611 = $610 < Math_fround(0.0);
             $612 = $611 ? Math_fround(0.0) : $610;
             $613 = (($565) + 8|0);
             $614 = Math_fround(HEAPF32[$613>>2]);
             $615 = Math_fround($614 + $612);
             HEAPF32[$613>>2] = $615;
             $616 = Math_fround(Math_fround(0.100000001490116119385) - $607);
             $617 = $616 < Math_fround(0.0);
             $$op$i = Math_fround($616 * Math_fround(3.0));
             $618 = $617 ? Math_fround(0.0) : $$op$i;
             $619 = (($565) + 4|0);
             $620 = Math_fround(HEAPF32[$619>>2]);
             $621 = Math_fround($620 + $618);
             HEAPF32[$619>>2] = $621;
            }
           } while(0);
           $622 = (($k4$0202) + 1)|0;
           $exitcond243 = ($622|0)==($548|0);
           if ($exitcond243) {
            break;
           } else {
            $k4$0202 = $622;
           }
          }
         }
         $623 = (($j3$0207) + 1)|0;
         $exitcond244 = ($623|0)==($527|0);
         if ($exitcond244) {
          break;
         } else {
          $j3$0207 = $623;
         }
        }
        $$pre259 = HEAP32[$this>>2]|0;
        $523 = $$pre259;
       } else {
        $523 = $1541;
       }
       $521 = ($522>>>0)<($523>>>0);
       if ($521) {
        $1541 = $523;$i2$0210 = $522;
       } else {
        break;
       }
      }
     }
     HEAP32[$constraints>>2] = 0;
     $624 = (($constraints) + 4|0);
     HEAP32[$624>>2] = 0;
     $625 = (($constraints) + 8|0);
     HEAP32[$625>>2] = 0;
     $$idx$val$i = HEAP32[$514>>2]|0;
     $626 = ($$idx$val$i|0)==(0);
     if (!($626)) {
      __ZN5physx6shdfnd5ArrayINS0_4PairINS2_IjjEENS_22PxClothFabricPhaseType4EnumEEENS0_19ReflectionAllocatorIS6_EEE8recreateEj($constraints,$$idx$val$i);
     }
     HEAP32[$8>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($valency,0,$8);
     $627 = HEAP32[$this>>2]|0;
     $628 = (($627) + 1)|0;
     HEAP32[$9>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($valency,$628,$9);
     $629 = (($edges) + 16|0);
     $630 = HEAP32[$629>>2]|0;
     $631 = ($630|0)==(0);
     $$pre268 = (($edges) + 12|0);
     L147: do {
      if ($631) {
       $$ph198 = -1;$$ph199 = 0;
      } else {
       $632 = HEAP32[$$pre268>>2]|0;
       $633 = HEAP32[$632>>2]|0;
       $634 = ($633|0)==(-1);
       if ($634) {
        $635 = (($edges) + 20|0);
        $636 = HEAP32[$635>>2]|0;
        $638 = 0;
        while(1) {
         $637 = (($638) + 1)|0;
         $639 = ($637|0)==($636|0);
         if ($639) {
          $$ph198 = -1;$$ph199 = $636;
          break L147;
         }
         $640 = (($632) + ($637<<2)|0);
         $641 = HEAP32[$640>>2]|0;
         $642 = ($641|0)==(-1);
         if ($642) {
          $638 = $637;
         } else {
          $$ph198 = $641;$$ph199 = $637;
          break;
         }
        }
       } else {
        $$ph198 = $633;$$ph199 = 0;
       }
      }
     } while(0);
     $eIt$idx7$val$idx = (($edges) + 4|0);
     $643 = HEAP32[$valency>>2]|0;
     $644 = (($10) + 4|0);
     $645 = (($10) + 8|0);
     $646 = HEAP32[$particles>>2]|0;
     $647 = (($edges) + 8|0);
     $648 = (($edges) + 20|0);
     $$ph200 = $$ph198;$$ph201 = $$ph199;
     L154: while(1) {
      $650 = $$ph200;
      while(1) {
       $649 = ($650|0)==(-1);
       if ($649) {
        break L154;
       }
       $eIt$idx7$val$idx$val = HEAP32[$eIt$idx7$val$idx>>2]|0;
       $651 = (($eIt$idx7$val$idx$val) + (($650*20)|0)|0);
       $652 = ((($eIt$idx7$val$idx$val) + (($650*20)|0)|0) + 8|0);
       $653 = Math_fround(HEAPF32[$652>>2]);
       $654 = ((($eIt$idx7$val$idx$val) + (($650*20)|0)|0) + 12|0);
       $655 = Math_fround(HEAPF32[$654>>2]);
       $656 = Math_fround($653 + $655);
       $657 = ((($eIt$idx7$val$idx$val) + (($650*20)|0)|0) + 16|0);
       $658 = Math_fround(HEAPF32[$657>>2]);
       $659 = Math_fround($656 + $658);
       $660 = $659 > Math_fround(0.0);
       do {
        if ($660) {
         $661 = $653 > $658;
         $662 = $661 ? $653 : $658;
         $663 = $655 > $662;
         do {
          if ($663) {
           $721 = 3;
          } else {
           $664 = $653 > $655;
           $665 = $664 ? $653 : $655;
           $666 = $658 > $665;
           if ($666) {
            $721 = 4;
            break;
           }
           $667 = HEAP32[$651>>2]|0;
           $668 = ((($eIt$idx7$val$idx$val) + (($650*20)|0)|0) + 4|0);
           $669 = HEAP32[$668>>2]|0;
           $670 = (($646) + ($667<<4)|0);
           $671 = Math_fround(HEAPF32[$670>>2]);
           $672 = (($646) + ($669<<4)|0);
           $673 = Math_fround(HEAPF32[$672>>2]);
           $674 = Math_fround($671 - $673);
           $675 = ((($646) + ($667<<4)|0) + 4|0);
           $676 = Math_fround(HEAPF32[$675>>2]);
           $677 = ((($646) + ($669<<4)|0) + 4|0);
           $678 = Math_fround(HEAPF32[$677>>2]);
           $679 = Math_fround($676 - $678);
           $680 = ((($646) + ($667<<4)|0) + 8|0);
           $681 = Math_fround(HEAPF32[$680>>2]);
           $682 = ((($646) + ($669<<4)|0) + 8|0);
           $683 = Math_fround(HEAPF32[$682>>2]);
           $684 = Math_fround($681 - $683);
           $685 = Math_fround($674 * $674);
           $686 = Math_fround($679 * $679);
           $687 = Math_fround($685 + $686);
           $688 = Math_fround($684 * $684);
           $689 = Math_fround($687 + $688);
           $690 = $689 > Math_fround(0.0);
           if ($690) {
            $691 = (Math_fround(Math_sqrt((Math_fround($689)))));
            $692 = Math_fround(Math_fround(1.0) / $691);
            $693 = Math_fround($674 * $692);
            $694 = Math_fround($679 * $692);
            $695 = Math_fround($684 * $692);
            $698 = $693;$701 = $694;$705 = $695;
           } else {
            $698 = Math_fround(0.0);$701 = Math_fround(0.0);$705 = Math_fround(0.0);
           }
           $696 = Math_fround(HEAPF32[$gravity>>2]);
           $697 = Math_fround($698 * $696);
           $699 = Math_fround(HEAPF32[$79>>2]);
           $700 = Math_fround($701 * $699);
           $702 = Math_fround($697 + $700);
           $703 = Math_fround(HEAPF32[$83>>2]);
           $704 = Math_fround($705 * $703);
           $706 = Math_fround($702 + $704);
           $707 = (Math_fround(Math_abs((Math_fround($706)))));
           $708 = $707 < Math_fround(0.632455527782440185546);
           $709 = $708 ? 2 : 1;
           $721 = $709;
          }
         } while(0);
         $710 = HEAP32[$651>>2]|0;
         $711 = (($643) + ($710<<2)|0);
         $712 = HEAP32[$711>>2]|0;
         $713 = (($712) + 1)|0;
         HEAP32[$711>>2] = $713;
         $714 = ((($eIt$idx7$val$idx$val) + (($650*20)|0)|0) + 4|0);
         $715 = HEAP32[$714>>2]|0;
         $716 = (($643) + ($715<<2)|0);
         $717 = HEAP32[$716>>2]|0;
         $718 = (($717) + 1)|0;
         HEAP32[$716>>2] = $718;
         $719 = HEAP32[$651>>2]|0;
         HEAP32[$10>>2] = $719;
         $720 = HEAP32[$714>>2]|0;
         HEAP32[$644>>2] = $720;
         HEAP32[$645>>2] = $721;
         $722 = HEAP32[$625>>2]|0;
         $723 = $722 & 2147483647;
         $724 = HEAP32[$624>>2]|0;
         $725 = ($723>>>0)>($724>>>0);
         if (!($725)) {
          (__ZN5physx6shdfnd5ArrayINS0_4PairINS2_IjjEENS_22PxClothFabricPhaseType4EnumEEENS0_19ReflectionAllocatorIS6_EEE15growAndPushBackERKS6_($constraints,$10)|0);
          break;
         }
         $726 = HEAP32[$constraints>>2]|0;
         $727 = (($726) + (($724*12)|0)|0);
         $728 = ($727|0)==(0|0);
         if (!($728)) {
          HEAP32[$727>>2] = $719;
          $729 = ((($726) + (($724*12)|0)|0) + 4|0);
          HEAP32[$729>>2] = $720;
          $730 = ((($726) + (($724*12)|0)|0) + 8|0);
          HEAP32[$730>>2] = $721;
         }
         $731 = (($724) + 1)|0;
         HEAP32[$624>>2] = $731;
        }
       } while(0);
       $732 = HEAP32[$647>>2]|0;
       $733 = (($732) + ($650<<2)|0);
       $734 = HEAP32[$733>>2]|0;
       $735 = ($734|0)==(-1);
       if ($735) {
        break;
       } else {
        $650 = $734;
       }
      }
      $736 = HEAP32[$648>>2]|0;
      $737 = HEAP32[$$pre268>>2]|0;
      $739 = $$ph201;
      while(1) {
       $738 = (($739) + 1)|0;
       $740 = ($738|0)==($736|0);
       if ($740) {
        $$ph200 = -1;$$ph201 = $736;
        continue L154;
       }
       $741 = (($737) + ($738<<2)|0);
       $742 = HEAP32[$741>>2]|0;
       $743 = ($742|0)==(-1);
       if ($743) {
        $739 = $738;
       } else {
        $$ph200 = $742;$$ph201 = $738;
        continue L154;
       }
      }
     }
     $744 = HEAP32[$134>>2]|0;
     $745 = (($643) + ($744<<2)|0);
     $746 = ($744|0)==(0);
     if ($746) {
      $755 = -1;
     } else {
      $747 = ($744|0)==(1);
      if ($747) {
       $755 = 0;
      } else {
       $$013$i118 = (($643) + 4|0);
       $748 = HEAP32[$643>>2]|0;
       $$016$i119 = $$013$i118;$751 = $748;$dest$pn$i120 = $643;
       while(1) {
        $$05$i121 = (($dest$pn$i120) + 4|0);
        $749 = HEAP32[$$016$i119>>2]|0;
        $750 = (($749) + ($751))|0;
        HEAP32[$$05$i121>>2] = $750;
        $$01$i122 = (($$016$i119) + 4|0);
        $752 = ($$01$i122|0)==($745|0);
        if ($752) {
         break;
        } else {
         $$016$i119 = $$01$i122;$751 = $750;$dest$pn$i120 = $$05$i121;
        }
       }
       $$pre247 = HEAP32[$134>>2]|0;
       $phitmp = (($$pre247) + -1)|0;
       $755 = $phitmp;
      }
     }
     $753 = HEAP32[$624>>2]|0;
     HEAP32[$numConstraints>>2] = $753;
     HEAP32[$11>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($adjacencies,0,$11);
     $754 = (($643) + ($755<<2)|0);
     $756 = HEAP32[$754>>2]|0;
     HEAP32[$12>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($adjacencies,$756,$12);
     $757 = ($753|0)==(0);
     if ($757) {
      $$pre266 = HEAP32[$adjacencies>>2]|0;
      $$lcssa192 = 0;$927 = $$pre266;
     } else {
      $758 = HEAP32[$constraints>>2]|0;
      $759 = HEAP32[$adjacencies>>2]|0;
      $i5$0193 = 0;
      while(1) {
       $760 = (($758) + (($i5$0193*12)|0)|0);
       $761 = HEAP32[$760>>2]|0;
       $762 = (($643) + ($761<<2)|0);
       $763 = HEAP32[$762>>2]|0;
       $764 = (($763) + -1)|0;
       HEAP32[$762>>2] = $764;
       $765 = (($759) + ($764<<2)|0);
       HEAP32[$765>>2] = $i5$0193;
       $766 = ((($758) + (($i5$0193*12)|0)|0) + 4|0);
       $767 = HEAP32[$766>>2]|0;
       $768 = (($643) + ($767<<2)|0);
       $769 = HEAP32[$768>>2]|0;
       $770 = (($769) + -1)|0;
       HEAP32[$768>>2] = $770;
       $771 = (($759) + ($770<<2)|0);
       HEAP32[$771>>2] = $i5$0193;
       $772 = (($i5$0193) + 1)|0;
       $773 = ($772>>>0)<($753>>>0);
       if ($773) {
        $i5$0193 = $772;
       } else {
        $$lcssa192 = $753;$927 = $759;
        break;
       }
      }
     }
     HEAP32[$colors>>2] = 0;
     $774 = (($colors) + 4|0);
     HEAP32[$774>>2] = 0;
     $775 = (($colors) + 8|0);
     HEAP32[$775>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($colors,$$lcssa192,$numConstraints);
     HEAP32[$13>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($mark,0,$13);
     $776 = HEAP32[$numConstraints>>2]|0;
     $777 = (($776) + 1)|0;
     HEAP32[$14>>2] = -1;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($mark,$777,$14);
     HEAP32[$15>>2] = 0;
     HEAP32[$adjColorCount>>2] = 0;
     $778 = (($adjColorCount) + 4|0);
     HEAP32[$778>>2] = 0;
     $779 = (($adjColorCount) + 8|0);
     HEAP32[$779>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($adjColorCount,$776,$15);
     HEAP32[$constraintHeap>>2] = 0;
     $780 = (($constraintHeap) + 4|0);
     HEAP32[$780>>2] = 0;
     $781 = (($constraintHeap) + 8|0);
     HEAP32[$781>>2] = 0;
     $782 = ($776|0)==(0);
     if (!($782)) {
      __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_125ConstraintGraphColorCountENS0_19ReflectionAllocatorIS3_EEE8recreateEj($constraintHeap,$776);
     }
     $783 = HEAP32[$colors>>2]|0;
     $784 = HEAP32[$adjColorCount>>2]|0;
     $785 = (($16) + 4|0);
     $786 = HEAP32[$constraints>>2]|0;
     $787 = HEAP32[$mark>>2]|0;
     $788 = (($17) + 4|0);
     $789 = (($this) + 4|0);
     $790 = (($this) + 8|0);
     $791 = (($phase) + 4|0);
     $792 = (($this) + 12|0);
     $793 = (($this) + 16|0);
     $794 = (($this) + 24|0);
     $795 = (($this) + 20|0);
     $796 = (($this) + 16|0);
     $constraint$0 = 0;
     L196: while(1) {
      $797 = ($constraint$0>>>0)<($776>>>0);
      if (!($797)) {
       break;
      }
      $798 = (($783) + ($constraint$0<<2)|0);
      $799 = HEAP32[$798>>2]|0;
      $800 = ($799|0)==($776|0);
      if (!($800)) {
       $801 = (($constraint$0) + 1)|0;
       $constraint$0 = $801;
       continue;
      }
      HEAP32[$780>>2] = 0;
      $802 = (($784) + ($constraint$0<<2)|0);
      $803 = HEAP32[$802>>2]|0;
      HEAP32[$16>>2] = $constraint$0;
      HEAP32[$785>>2] = $803;
      $this$idx$val$i$i98 = HEAP32[$781>>2]|0;
      $804 = $this$idx$val$i$i98 & 2147483647;
      $805 = ($804|0)==(0);
      L202: do {
       if ($805) {
        (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_125ConstraintGraphColorCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($constraintHeap,$16)|0);
        $heap$idx2$val$pre$i99 = HEAP32[$780>>2]|0;
        $heap$idx$val$i104$pre = HEAP32[$constraintHeap>>2]|0;
        $818 = ($heap$idx2$val$pre$i99|0)>(0);
        L204: do {
         if ($818) {
          $$idx4$i106 = $heap$idx2$val$pre$i99 << 3;
          $819 = $$idx4$i106 >> 3;
          $820 = (($819) + -1)|0;
          $821 = ($820|0)==(0);
          if ($821) {
           $constraintHeap$idx$val190274$ph = $heap$idx2$val$pre$i99;$heap$idx$val$i104272$ph = $heap$idx$val$i104$pre;
           label = 145;
           break L202;
          } else {
           $current$05$i107 = $820;
          }
          while(1) {
           $822 = (($current$05$i107) + -1)|0;
           $823 = $822 >>> 1;
           $$idx$i108 = ((($heap$idx$val$i104$pre) + ($823<<3)|0) + 4|0);
           $$idx$val$i109 = HEAP32[$$idx$i108>>2]|0;
           $$idx3$i110 = ((($heap$idx$val$i104$pre) + ($current$05$i107<<3)|0) + 4|0);
           $$idx3$val$i111 = HEAP32[$$idx3$i110>>2]|0;
           $824 = ($$idx$val$i109>>>0)<($$idx3$val$i111>>>0);
           if (!($824)) {
            break L204;
           }
           $825 = (($heap$idx$val$i104$pre) + ($current$05$i107<<3)|0);
           $826 = (($heap$idx$val$i104$pre) + ($823<<3)|0);
           $827 = $826;
           $828 = $827;
           $829 = HEAP32[$828>>2]|0;
           $830 = (($827) + 4)|0;
           $831 = $830;
           $832 = HEAP32[$831>>2]|0;
           $833 = $825;
           $834 = $833;
           $835 = HEAP32[$834>>2]|0;
           $836 = (($833) + 4)|0;
           $837 = $836;
           $838 = HEAP32[$837>>2]|0;
           $839 = $826;
           $840 = $839;
           HEAP32[$840>>2] = $835;
           $841 = (($839) + 4)|0;
           $842 = $841;
           HEAP32[$842>>2] = $838;
           $843 = $825;
           $844 = $843;
           HEAP32[$844>>2] = $829;
           $845 = (($843) + 4)|0;
           $846 = $845;
           HEAP32[$846>>2] = $832;
           $847 = ($823|0)==(0);
           if ($847) {
            break;
           } else {
            $current$05$i107 = $823;
           }
          }
         }
        } while(0);
        $848 = ($heap$idx2$val$pre$i99|0)==(0);
        if ($848) {
         $constraint$0 = 0;
         continue L196;
        } else {
         $constraintHeap$idx$val190274277 = $heap$idx2$val$pre$i99;$heap$idx$val$i104272278 = $heap$idx$val$i104$pre;
        }
       } else {
        $806 = HEAP32[$constraintHeap>>2]|0;
        $807 = ($806|0)==(0|0);
        if (!($807)) {
         $808 = $16;
         $809 = $808;
         $810 = HEAP32[$809>>2]|0;
         $811 = (($808) + 4)|0;
         $812 = $811;
         $813 = HEAP32[$812>>2]|0;
         $814 = $806;
         $815 = $814;
         HEAP32[$815>>2] = $810;
         $816 = (($814) + 4)|0;
         $817 = $816;
         HEAP32[$817>>2] = $813;
        }
        HEAP32[$780>>2] = 1;
        $constraintHeap$idx$val190274$ph = 1;$heap$idx$val$i104272$ph = $806;
        label = 145;
       }
      } while(0);
      if ((label|0) == 145) {
       label = 0;
       $constraintHeap$idx$val190274277 = $constraintHeap$idx$val190274$ph;$heap$idx$val$i104272278 = $heap$idx$val$i104272$ph;
      }
      $$in280 = ((($786) + (($constraint$0*12)|0)|0) + 8|0);
      $849 = HEAP32[$$in280>>2]|0;
      $heap$idx$val$i89 = $heap$idx$val$i104272278;$heap$idx2$val$i90 = $constraintHeap$idx$val190274277;
      while(1) {
       $$sum6$i = (($heap$idx2$val$i90) + -1)|0;
       $850 = (($heap$idx$val$i89) + ($$sum6$i<<3)|0);
       $851 = $heap$idx$val$i89;
       $852 = $851;
       $853 = HEAP32[$852>>2]|0;
       $854 = (($851) + 4)|0;
       $855 = $854;
       $856 = HEAP32[$855>>2]|0;
       $857 = $850;
       $858 = $857;
       $859 = HEAP32[$858>>2]|0;
       $860 = (($857) + 4)|0;
       $861 = $860;
       $862 = HEAP32[$861>>2]|0;
       $863 = $heap$idx$val$i89;
       $864 = $863;
       HEAP32[$864>>2] = $859;
       $865 = (($863) + 4)|0;
       $866 = $865;
       HEAP32[$866>>2] = $862;
       $867 = $850;
       $868 = $867;
       HEAP32[$868>>2] = $853;
       $869 = (($867) + 4)|0;
       $870 = $869;
       HEAP32[$870>>2] = $856;
       $871 = ($$sum6$i|0)>(1);
       L219: do {
        if ($871) {
         $872 = 1;$current$07$i = 0;
         while(1) {
          $$sum$i = (($872) + 1)|0;
          $873 = ($$sum$i|0)<($$sum6$i|0);
          if ($873) {
           $$idx4$i92 = ((($heap$idx$val$i89) + ($872<<3)|0) + 4|0);
           $$idx4$val$i = HEAP32[$$idx4$i92>>2]|0;
           $$idx5$i = ((($heap$idx$val$i89) + ($$sum$i<<3)|0) + 4|0);
           $$idx5$val$i = HEAP32[$$idx5$i>>2]|0;
           $874 = ($$idx4$val$i>>>0)<($$idx5$val$i>>>0);
           $$$i = $874 ? $$sum$i : $872;
           $child$0$i = $$$i;
          } else {
           $child$0$i = $872;
          }
          $$idx$i93 = ((($heap$idx$val$i89) + ($current$07$i<<3)|0) + 4|0);
          $$idx$val$i94 = HEAP32[$$idx$i93>>2]|0;
          $$idx3$i95 = ((($heap$idx$val$i89) + ($child$0$i<<3)|0) + 4|0);
          $$idx3$val$i96 = HEAP32[$$idx3$i95>>2]|0;
          $875 = ($$idx$val$i94>>>0)<($$idx3$val$i96>>>0);
          if (!($875)) {
           break L219;
          }
          $876 = (($heap$idx$val$i89) + ($child$0$i<<3)|0);
          $877 = (($heap$idx$val$i89) + ($current$07$i<<3)|0);
          $878 = $877;
          $879 = $878;
          $880 = HEAP32[$879>>2]|0;
          $881 = (($878) + 4)|0;
          $882 = $881;
          $883 = HEAP32[$882>>2]|0;
          $884 = $876;
          $885 = $884;
          $886 = HEAP32[$885>>2]|0;
          $887 = (($884) + 4)|0;
          $888 = $887;
          $889 = HEAP32[$888>>2]|0;
          $890 = $877;
          $891 = $890;
          HEAP32[$891>>2] = $886;
          $892 = (($890) + 4)|0;
          $893 = $892;
          HEAP32[$893>>2] = $889;
          $894 = $876;
          $895 = $894;
          HEAP32[$895>>2] = $880;
          $896 = (($894) + 4)|0;
          $897 = $896;
          HEAP32[$897>>2] = $883;
          $898 = $child$0$i << 1;
          $899 = $898 | 1;
          $900 = ($899|0)<($$sum6$i|0);
          if ($900) {
           $872 = $899;$current$07$i = $child$0$i;
          } else {
           break;
          }
         }
        }
       } while(0);
       $901 = HEAP32[$780>>2]|0;
       $902 = (($901) + -1)|0;
       $903 = HEAP32[$constraintHeap>>2]|0;
       $904 = (($903) + ($902<<3)|0);
       $905 = $904;
       $906 = $905;
       $907 = HEAP32[$906>>2]|0;
       $908 = (($905) + 4)|0;
       $909 = $908;
       $910 = HEAP32[$909>>2]|0;
       HEAP32[$780>>2] = $902;
       $911 = (($783) + ($907<<2)|0);
       $912 = HEAP32[$911>>2]|0;
       $913 = ($912|0)==($776|0);
       if ($913) {
        $914 = (($786) + (($907*12)|0)|0);
        $915 = ((($786) + (($907*12)|0)|0) + 4|0);
        $1542 = $902;$heap$idx$val$i89255 = $903;$j8$0187 = 0;
        while(1) {
         $916 = ($j8$0187|0)==(0);
         $$in = $916 ? $915 : $914;
         $917 = HEAP32[$$in>>2]|0;
         $918 = ((($646) + ($917<<4)|0) + 12|0);
         $919 = Math_fround(HEAPF32[$918>>2]);
         $920 = $919 == Math_fround(0.0);
         do {
          if ($920) {
           $1543 = $1542;$heap$idx$val$i89254 = $heap$idx$val$i89255;
          } else {
           $921 = (($643) + ($917<<2)|0);
           $922 = HEAP32[$921>>2]|0;
           $923 = (($917) + 1)|0;
           $924 = (($643) + ($923<<2)|0);
           $925 = HEAP32[$924>>2]|0;
           $926 = (($927) + ($925<<2)|0);
           $928 = ($922|0)==($925|0);
           if ($928) {
            $1543 = $1542;$heap$idx$val$i89254 = $heap$idx$val$i89255;
            break;
           }
           $929 = (($927) + ($922<<2)|0);
           $943 = $1542;$945 = $heap$idx$val$i89255;$aIt$0183 = $929;
           while(1) {
            $930 = HEAP32[$aIt$0183>>2]|0;
            $931 = ((($786) + (($930*12)|0)|0) + 8|0);
            $932 = HEAP32[$931>>2]|0;
            $933 = ($932|0)!=($849|0);
            $934 = ($930|0)==($907|0);
            $or$cond = $933 | $934;
            L236: do {
             if ($or$cond) {
              $1544 = $943;$heap$idx$val$i89251 = $945;
             } else {
              $935 = (($783) + ($930<<2)|0);
              $936 = HEAP32[$935>>2]|0;
              $937 = (($787) + ($936<<2)|0);
              HEAP32[$937>>2] = $907;
              $938 = (($784) + ($930<<2)|0);
              $939 = HEAP32[$938>>2]|0;
              $940 = (($939) + 1)|0;
              HEAP32[$938>>2] = $940;
              HEAP32[$17>>2] = $930;
              HEAP32[$788>>2] = $940;
              $this$idx$val$i$i = HEAP32[$781>>2]|0;
              $941 = $this$idx$val$i$i & 2147483647;
              $942 = ($941>>>0)>($943>>>0);
              if ($942) {
               $944 = (($945) + ($943<<3)|0);
               $946 = ($944|0)==(0|0);
               if ($946) {
                $958 = $943;
               } else {
                $947 = $17;
                $948 = $947;
                $949 = HEAP32[$948>>2]|0;
                $950 = (($947) + 4)|0;
                $951 = $950;
                $952 = HEAP32[$951>>2]|0;
                $953 = $944;
                $954 = $953;
                HEAP32[$954>>2] = $949;
                $955 = (($953) + 4)|0;
                $956 = $955;
                HEAP32[$956>>2] = $952;
                $$pre$i$i85 = HEAP32[$780>>2]|0;
                $958 = $$pre$i$i85;
               }
               $957 = (($958) + 1)|0;
               HEAP32[$780>>2] = $957;
               $heap$idx2$val$i = $957;
              } else {
               (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_125ConstraintGraphColorCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($constraintHeap,$17)|0);
               $heap$idx2$val$pre$i = HEAP32[$780>>2]|0;
               $heap$idx2$val$i = $heap$idx2$val$pre$i;
              }
              $heap$idx$val$i = HEAP32[$constraintHeap>>2]|0;
              $959 = ($heap$idx2$val$i|0)>(0);
              if (!($959)) {
               $1544 = $heap$idx2$val$i;$heap$idx$val$i89251 = $heap$idx$val$i;
               break;
              }
              $$idx4$i = $heap$idx2$val$i << 3;
              $960 = $$idx4$i >> 3;
              $961 = (($960) + -1)|0;
              $962 = ($961|0)==(0);
              if ($962) {
               $1544 = $heap$idx2$val$i;$heap$idx$val$i89251 = $heap$idx$val$i;
               break;
              } else {
               $current$05$i = $961;
              }
              while(1) {
               $963 = (($current$05$i) + -1)|0;
               $964 = $963 >>> 1;
               $$idx$i86 = ((($heap$idx$val$i) + ($964<<3)|0) + 4|0);
               $$idx$val$i87 = HEAP32[$$idx$i86>>2]|0;
               $$idx3$i = ((($heap$idx$val$i) + ($current$05$i<<3)|0) + 4|0);
               $$idx3$val$i = HEAP32[$$idx3$i>>2]|0;
               $965 = ($$idx$val$i87>>>0)<($$idx3$val$i>>>0);
               if (!($965)) {
                $1544 = $heap$idx2$val$i;$heap$idx$val$i89251 = $heap$idx$val$i;
                break L236;
               }
               $966 = (($heap$idx$val$i) + ($current$05$i<<3)|0);
               $967 = (($heap$idx$val$i) + ($964<<3)|0);
               $968 = $967;
               $969 = $968;
               $970 = HEAP32[$969>>2]|0;
               $971 = (($968) + 4)|0;
               $972 = $971;
               $973 = HEAP32[$972>>2]|0;
               $974 = $966;
               $975 = $974;
               $976 = HEAP32[$975>>2]|0;
               $977 = (($974) + 4)|0;
               $978 = $977;
               $979 = HEAP32[$978>>2]|0;
               $980 = $967;
               $981 = $980;
               HEAP32[$981>>2] = $976;
               $982 = (($980) + 4)|0;
               $983 = $982;
               HEAP32[$983>>2] = $979;
               $984 = $966;
               $985 = $984;
               HEAP32[$985>>2] = $970;
               $986 = (($984) + 4)|0;
               $987 = $986;
               HEAP32[$987>>2] = $973;
               $988 = ($964|0)==(0);
               if ($988) {
                $1544 = $heap$idx2$val$i;$heap$idx$val$i89251 = $heap$idx$val$i;
                break;
               } else {
                $current$05$i = $964;
               }
              }
             }
            } while(0);
            $989 = (($aIt$0183) + 4|0);
            $990 = ($989|0)==($926|0);
            if ($990) {
             $1543 = $1544;$heap$idx$val$i89254 = $heap$idx$val$i89251;
             break;
            } else {
             $943 = $1544;$945 = $heap$idx$val$i89251;$aIt$0183 = $989;
            }
           }
          }
         } while(0);
         $991 = (($j8$0187) + 1)|0;
         $exitcond = ($991|0)==(2);
         if ($exitcond) {
          break;
         } else {
          $1542 = $1543;$heap$idx$val$i89255 = $heap$idx$val$i89254;$j8$0187 = $991;
         }
        }
        $992 = HEAP32[$790>>2]|0;
        $color$0 = 0;
        while(1) {
         $993 = ($color$0>>>0)<($992>>>0);
         if ($993) {
          $994 = HEAP32[$789>>2]|0;
          $995 = (($994) + ($color$0<<3)|0);
          $996 = HEAP32[$995>>2]|0;
          $997 = ($996|0)==($849|0);
          if ($997) {
           label = 173;
          }
         } else {
          label = 173;
         }
         if ((label|0) == 173) {
          label = 0;
          $998 = (($787) + ($color$0<<2)|0);
          $999 = HEAP32[$998>>2]|0;
          $1000 = ($999|0)==($907|0);
          if (!($1000)) {
           break;
          }
         }
         $1001 = (($color$0) + 1)|0;
         $color$0 = $1001;
        }
        $1002 = ($color$0|0)==($992|0);
        do {
         if ($1002) {
          HEAP32[$phase>>2] = $849;
          HEAP32[$791>>2] = $992;
          $1003 = HEAP32[$792>>2]|0;
          $1004 = $1003 & 2147483647;
          $1005 = ($1004>>>0)>($992>>>0);
          if ($1005) {
           $1006 = HEAP32[$789>>2]|0;
           $1007 = (($1006) + ($992<<3)|0);
           $1008 = ($1007|0)==(0|0);
           if ($1008) {
            $1020 = $992;
           } else {
            $1009 = $phase;
            $1010 = $1009;
            $1011 = HEAP32[$1010>>2]|0;
            $1012 = (($1009) + 4)|0;
            $1013 = $1012;
            $1014 = HEAP32[$1013>>2]|0;
            $1015 = $1007;
            $1016 = $1015;
            HEAP32[$1016>>2] = $1011;
            $1017 = (($1015) + 4)|0;
            $1018 = $1017;
            HEAP32[$1018>>2] = $1014;
            $$pre$i83 = HEAP32[$790>>2]|0;
            $1020 = $$pre$i83;
           }
           $1019 = (($1020) + 1)|0;
           HEAP32[$790>>2] = $1019;
          } else {
           (__ZN5physx6shdfnd5ArrayINS_18PxClothFabricPhaseENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($789,$phase)|0);
          }
          HEAP32[$18>>2] = 0;
          $1021 = HEAP32[$794>>2]|0;
          $1022 = $1021 & 2147483647;
          $1023 = HEAP32[$795>>2]|0;
          $1024 = ($1022>>>0)>($1023>>>0);
          if (!($1024)) {
           (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($793,$18)|0);
           break;
          }
          $1025 = HEAP32[$793>>2]|0;
          $1026 = (($1025) + ($1023<<2)|0);
          $1027 = ($1026|0)==(0|0);
          if ($1027) {
           $1029 = $1023;
          } else {
           HEAP32[$1026>>2] = 0;
           $$pre$i80 = HEAP32[$795>>2]|0;
           $1029 = $$pre$i80;
          }
          $1028 = (($1029) + 1)|0;
          HEAP32[$795>>2] = $1028;
         }
        } while(0);
        HEAP32[$911>>2] = $color$0;
        $1030 = HEAP32[$796>>2]|0;
        $1031 = (($1030) + ($color$0<<2)|0);
        $1032 = HEAP32[$1031>>2]|0;
        $1033 = (($1032) + 1)|0;
        HEAP32[$1031>>2] = $1033;
        $constraintHeap$idx$val = $1543;$heap$idx$val$i89250 = $heap$idx$val$i89254;
       } else {
        $constraintHeap$idx$val = $902;$heap$idx$val$i89250 = $903;
       }
       $1034 = ($constraintHeap$idx$val|0)==(0);
       if ($1034) {
        $constraint$0 = 0;
        continue L196;
       } else {
        $heap$idx$val$i89 = $heap$idx$val$i89250;$heap$idx2$val$i90 = $constraintHeap$idx$val;
       }
      }
     }
     $1035 = HEAP32[$793>>2]|0;
     $1036 = HEAP32[$795>>2]|0;
     $1037 = (($1035) + ($1036<<2)|0);
     $1038 = ($1036|0)==(0);
     do {
      if ($1038) {
       $1046 = 0;
      } else {
       $1039 = ($1036|0)==(1);
       if ($1039) {
        $1046 = 1;
        break;
       }
       $$013$i = (($1035) + 4|0);
       $1040 = HEAP32[$1035>>2]|0;
       $$016$i = $$013$i;$1043 = $1040;$dest$pn$i = $1035;
       while(1) {
        $$05$i = (($dest$pn$i) + 4|0);
        $1041 = HEAP32[$$016$i>>2]|0;
        $1042 = (($1041) + ($1043))|0;
        HEAP32[$$05$i>>2] = $1042;
        $$01$i = (($$016$i) + 4|0);
        $1044 = ($$01$i|0)==($1037|0);
        if ($1044) {
         break;
        } else {
         $$016$i = $$01$i;$1043 = $1042;$dest$pn$i = $$05$i;
        }
       }
       $$pre258 = HEAP32[$795>>2]|0;
       $1046 = $$pre258;
      }
     } while(0);
     $1045 = (($1046) + -1)|0;
     $1047 = (($1035) + ($1045<<2)|0);
     $1048 = HEAP32[$1047>>2]|0;
     HEAP32[$back>>2] = $1048;
     $1049 = HEAP32[$794>>2]|0;
     $1050 = $1049 & 2147483647;
     $1051 = ($1050>>>0)>($1046>>>0);
     if ($1051) {
      $1052 = (($1035) + ($1046<<2)|0);
      $1053 = ($1052|0)==(0|0);
      if ($1053) {
       $1055 = $1046;
      } else {
       HEAP32[$1052>>2] = $1048;
       $$pre$i77 = HEAP32[$795>>2]|0;
       $1055 = $$pre$i77;
      }
      $1054 = (($1055) + 1)|0;
      HEAP32[$795>>2] = $1054;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($793,$back)|0);
     }
     $1056 = (($this) + 40|0);
     $1057 = HEAP32[$numConstraints>>2]|0;
     $1058 = $1057 << 1;
     HEAP32[$19>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($1056,$1058,$19);
     $1059 = (($this) + 28|0);
     HEAPF32[$20>>2] = Math_fround(0.0);
     __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($1059,$1057,$20);
     $1060 = ($1057|0)==(0);
     if (!($1060)) {
      $1061 = HEAP32[$constraints>>2]|0;
      $1062 = HEAP32[$colors>>2]|0;
      $1063 = HEAP32[$793>>2]|0;
      $1064 = HEAP32[$1056>>2]|0;
      $1065 = HEAP32[$particles>>2]|0;
      $1066 = HEAP32[$1059>>2]|0;
      $i9$0180 = 0;
      while(1) {
       $1067 = (($1061) + (($i9$0180*12)|0)|0);
       $1068 = HEAP32[$1067>>2]|0;
       $1069 = ((($1061) + (($i9$0180*12)|0)|0) + 4|0);
       $1070 = HEAP32[$1069>>2]|0;
       $1071 = (($1062) + ($i9$0180<<2)|0);
       $1072 = HEAP32[$1071>>2]|0;
       $1073 = (($1063) + ($1072<<2)|0);
       $1074 = HEAP32[$1073>>2]|0;
       $1075 = (($1074) + -1)|0;
       HEAP32[$1073>>2] = $1075;
       $1076 = $1075 << 1;
       $1077 = (($1064) + ($1076<<2)|0);
       HEAP32[$1077>>2] = $1068;
       $1078 = $1076 | 1;
       $1079 = (($1064) + ($1078<<2)|0);
       HEAP32[$1079>>2] = $1070;
       $1080 = (($1065) + ($1070<<4)|0);
       $1081 = Math_fround(HEAPF32[$1080>>2]);
       $1082 = (($1065) + ($1068<<4)|0);
       $1083 = Math_fround(HEAPF32[$1082>>2]);
       $1084 = Math_fround($1081 - $1083);
       $1085 = ((($1065) + ($1070<<4)|0) + 4|0);
       $1086 = Math_fround(HEAPF32[$1085>>2]);
       $1087 = ((($1065) + ($1068<<4)|0) + 4|0);
       $1088 = Math_fround(HEAPF32[$1087>>2]);
       $1089 = Math_fround($1086 - $1088);
       $1090 = ((($1065) + ($1070<<4)|0) + 8|0);
       $1091 = Math_fround(HEAPF32[$1090>>2]);
       $1092 = ((($1065) + ($1068<<4)|0) + 8|0);
       $1093 = Math_fround(HEAPF32[$1092>>2]);
       $1094 = Math_fround($1091 - $1093);
       $1095 = Math_fround($1084 * $1084);
       $1096 = Math_fround($1089 * $1089);
       $1097 = Math_fround($1095 + $1096);
       $1098 = Math_fround($1094 * $1094);
       $1099 = Math_fround($1097 + $1098);
       $1100 = (Math_fround(Math_sqrt((Math_fround($1099)))));
       $1101 = (($1066) + ($1075<<2)|0);
       HEAPF32[$1101>>2] = $1100;
       $1102 = (($i9$0180) + 1)|0;
       $1103 = ($1102>>>0)<($1057>>>0);
       if ($1103) {
        $i9$0180 = $1102;
       } else {
        break;
       }
      }
     }
     $1104 = (($this) + 44|0);
     $1105 = HEAP32[$1104>>2]|0;
     HEAP32[$21>>2] = 0;
     HEAP32[$newIndices>>2] = 0;
     $1106 = (($newIndices) + 4|0);
     HEAP32[$1106>>2] = 0;
     $1107 = (($newIndices) + 8|0);
     HEAP32[$1107>>2] = 0;
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($newIndices,$1105,$21);
     $1108 = (($this) + 32|0);
     $1109 = HEAP32[$1108>>2]|0;
     HEAPF32[$22>>2] = Math_fround(0.0);
     HEAP32[$newRestValues>>2] = 0;
     $1110 = (($newRestValues) + 4|0);
     HEAP32[$1110>>2] = 0;
     $1111 = (($newRestValues) + 8|0);
     HEAP32[$1111>>2] = 0;
     __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($newRestValues,$1109,$22);
     $1112 = HEAP32[$795>>2]|0;
     $1113 = ($1112|0)==(1);
     if (!($1113)) {
      $1114 = (($reorder) + 4|0);
      $1115 = (($reorder) + 8|0);
      $1116 = (($vararg_buffer) + 4|0);
      $i12$0177 = 0;
      while(1) {
       $1117 = (($i12$0177) + 1)|0;
       $1118 = HEAP32[$793>>2]|0;
       $1119 = (($1118) + ($1117<<2)|0);
       $1120 = HEAP32[$1119>>2]|0;
       $1121 = (($1118) + ($i12$0177<<2)|0);
       $1122 = HEAP32[$1121>>2]|0;
       $1123 = (($1120) - ($1122))|0;
       HEAP32[$23>>2] = 0;
       HEAP32[$reorder>>2] = 0;
       HEAP32[$1114>>2] = 0;
       HEAP32[$1115>>2] = 0;
       __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($reorder,$1123,$23);
       $1124 = HEAP32[$1114>>2]|0;
       $1125 = ($1124|0)==(0);
       $$pre267 = HEAP32[$reorder>>2]|0;
       if ($1125) {
        $$lcssa = -1;
       } else {
        $r$0161 = 0;
        while(1) {
         $1126 = (($$pre267) + ($r$0161<<2)|0);
         HEAP32[$1126>>2] = $r$0161;
         $1127 = (($r$0161) + 1)|0;
         $1128 = ($1127>>>0)<($1124>>>0);
         if ($1128) {
          $r$0161 = $1127;
         } else {
          break;
         }
        }
        $phitmp269 = (($1124) + -1)|0;
        $$lcssa = $phitmp269;
       }
       $1129 = HEAP32[$793>>2]|0;
       $1130 = (($1129) + ($i12$0177<<2)|0);
       $1131 = HEAP32[$1130>>2]|0;
       $1132 = $1131 << 1;
       $1133 = HEAP32[$1056>>2]|0;
       $1134 = $vararg_buffer;
       $1135 = $1134;
       HEAP32[$1135>>2] = 0;
       $1136 = (($1134) + 4)|0;
       $1137 = $1136;
       HEAP32[$1137>>2] = 0;
       HEAP8[$1116>>0] = 0;
       HEAP32[$vararg_buffer>>2] = $0;
       $1138 = ($$lcssa|0)>(0);
       do {
        if ($1138) {
         $$ph$i$i = 0;$$ph10$i$i = 32;$$ph11$i$i = 0;$$ph12$i$i = 0;$$ph13$i$i = $$lcssa;$$ph9$i$i = $0;
         L307: while(1) {
          $1140 = $$ph13$i$i;$1141 = $$ph12$i$i;$1268 = $$ph11$i$i;
          while(1) {
           $1139 = ($1140|0)>($1141|0);
           if ($1139) {
            $1142 = (($1140) - ($1141))|0;
            $1143 = ($1142>>>0)<(5);
            if ($1143) {
             $i$03$i$i$i = $1141;
            } else {
             break;
            }
            while(1) {
             $1144 = (($i$03$i$i$i) + 1)|0;
             $j$02$i$i$i = $1144;$m$01$i$i$i = $i$03$i$i$i;
             while(1) {
              $1145 = (($$pre267) + ($j$02$i$i$i<<2)|0);
              $1146 = HEAP32[$1145>>2]|0;
              $1147 = (($$pre267) + ($m$01$i$i$i<<2)|0);
              $1148 = HEAP32[$1147>>2]|0;
              $1149 = $1146 << 1;
              $1150 = $1148 << 1;
              $$sum155 = (($1149) + ($1132))|0;
              $1151 = (($1133) + ($$sum155<<2)|0);
              $1152 = HEAP32[$1151>>2]|0;
              $$sum156 = (($1150) + ($1132))|0;
              $1153 = (($1133) + ($$sum156<<2)|0);
              $1154 = HEAP32[$1153>>2]|0;
              $1155 = ($1152|0)==($1154|0);
              if ($1155) {
               $1156 = $1149 | 1;
               $$sum157 = (($1156) + ($1132))|0;
               $1157 = (($1133) + ($$sum157<<2)|0);
               $1158 = HEAP32[$1157>>2]|0;
               $1159 = $1150 | 1;
               $$sum158 = (($1159) + ($1132))|0;
               $1160 = (($1133) + ($$sum158<<2)|0);
               $1161 = HEAP32[$1160>>2]|0;
               $1162 = ($1158>>>0)<($1161>>>0);
               $$0$i$i$i$i = $1162;
              } else {
               $1163 = ($1152>>>0)<($1154>>>0);
               $$0$i$i$i$i = $1163;
              }
              $j$0$m$0$i$i$i = $$0$i$i$i$i ? $j$02$i$i$i : $m$01$i$i$i;
              $1164 = (($j$02$i$i$i) + 1)|0;
              $1165 = ($j$02$i$i$i|0)<($1140|0);
              if ($1165) {
               $j$02$i$i$i = $1164;$m$01$i$i$i = $j$0$m$0$i$i$i;
              } else {
               break;
              }
             }
             $1166 = (($$pre267) + ($j$0$m$0$i$i$i<<2)|0);
             $1167 = (($$pre267) + ($i$03$i$i$i<<2)|0);
             $1168 = HEAP32[$1166>>2]|0;
             $1169 = HEAP32[$1167>>2]|0;
             HEAP32[$1166>>2] = $1169;
             HEAP32[$1167>>2] = $1168;
             $exitcond$i$i$i = ($1144|0)==($1140|0);
             if ($exitcond$i$i$i) {
              break;
             } else {
              $i$03$i$i$i = $1144;
             }
            }
           }
           $1323 = ($1268|0)==(0);
           if ($1323) {
            break L307;
           }
           $1324 = (($1268) + -1)|0;
           $1325 = (($$ph9$i$i) + ($1324<<2)|0);
           $1326 = HEAP32[$1325>>2]|0;
           $1327 = (($1268) + -2)|0;
           $1328 = (($$ph9$i$i) + ($1327<<2)|0);
           $1329 = HEAP32[$1328>>2]|0;
           $1140 = $1326;$1141 = $1329;$1268 = $1327;
          }
          $1170 = (($1140) + ($1141))|0;
          $1171 = (($1170|0) / 2)&-1;
          $1172 = (($$pre267) + ($1171<<2)|0);
          $1173 = HEAP32[$1172>>2]|0;
          $1174 = (($$pre267) + ($1141<<2)|0);
          $1175 = HEAP32[$1174>>2]|0;
          $1176 = $1173 << 1;
          $1177 = $1175 << 1;
          $$sum = (($1176) + ($1132))|0;
          $1178 = (($1133) + ($$sum<<2)|0);
          $1179 = HEAP32[$1178>>2]|0;
          $$sum138 = (($1177) + ($1132))|0;
          $1180 = (($1133) + ($$sum138<<2)|0);
          $1181 = HEAP32[$1180>>2]|0;
          $1182 = ($1179|0)==($1181|0);
          if ($1182) {
           $1183 = $1176 | 1;
           $$sum153 = (($1183) + ($1132))|0;
           $1184 = (($1133) + ($$sum153<<2)|0);
           $1185 = HEAP32[$1184>>2]|0;
           $1186 = $1177 | 1;
           $$sum154 = (($1186) + ($1132))|0;
           $1187 = (($1133) + ($$sum154<<2)|0);
           $1188 = HEAP32[$1187>>2]|0;
           $1189 = ($1185>>>0)<($1188>>>0);
           if ($1189) {
            label = 219;
           } else {
            $1195 = $1175;$1545 = $1173;
           }
          } else {
           $1190 = ($1179>>>0)<($1181>>>0);
           if ($1190) {
            label = 219;
           } else {
            $1195 = $1175;$1545 = $1173;
           }
          }
          if ((label|0) == 219) {
           label = 0;
           HEAP32[$1174>>2] = $1173;
           HEAP32[$1172>>2] = $1175;
           $$pre$i$i$i$i = HEAP32[$1174>>2]|0;
           $1195 = $$pre$i$i$i$i;$1545 = $1175;
          }
          $1191 = (($$pre267) + ($1140<<2)|0);
          $1192 = HEAP32[$1191>>2]|0;
          $1193 = $1192 << 1;
          $1194 = $1195 << 1;
          $$sum139 = (($1193) + ($1132))|0;
          $1196 = (($1133) + ($$sum139<<2)|0);
          $1197 = HEAP32[$1196>>2]|0;
          $$sum140 = (($1194) + ($1132))|0;
          $1198 = (($1133) + ($$sum140<<2)|0);
          $1199 = HEAP32[$1198>>2]|0;
          $1200 = ($1197|0)==($1199|0);
          if ($1200) {
           $1201 = $1193 | 1;
           $$sum151 = (($1201) + ($1132))|0;
           $1202 = (($1133) + ($$sum151<<2)|0);
           $1203 = HEAP32[$1202>>2]|0;
           $1204 = $1194 | 1;
           $$sum152 = (($1204) + ($1132))|0;
           $1205 = (($1133) + ($$sum152<<2)|0);
           $1206 = HEAP32[$1205>>2]|0;
           $1207 = ($1203>>>0)<($1206>>>0);
           if ($1207) {
            label = 223;
           } else {
            $1210 = $1192;$1212 = $1545;
           }
          } else {
           $1208 = ($1197>>>0)<($1199>>>0);
           if ($1208) {
            label = 223;
           } else {
            $1210 = $1192;$1212 = $1545;
           }
          }
          if ((label|0) == 223) {
           label = 0;
           HEAP32[$1174>>2] = $1192;
           HEAP32[$1191>>2] = $1195;
           $$pre1$i$i$i$i = HEAP32[$1172>>2]|0;
           $1210 = $1195;$1212 = $$pre1$i$i$i$i;
          }
          $1209 = $1210 << 1;
          $1211 = $1212 << 1;
          $$sum141 = (($1209) + ($1132))|0;
          $1213 = (($1133) + ($$sum141<<2)|0);
          $1214 = HEAP32[$1213>>2]|0;
          $$sum142 = (($1211) + ($1132))|0;
          $1215 = (($1133) + ($$sum142<<2)|0);
          $1216 = HEAP32[$1215>>2]|0;
          $1217 = ($1214|0)==($1216|0);
          if ($1217) {
           $1218 = $1209 | 1;
           $$sum149 = (($1218) + ($1132))|0;
           $1219 = (($1133) + ($$sum149<<2)|0);
           $1220 = HEAP32[$1219>>2]|0;
           $1221 = $1211 | 1;
           $$sum150 = (($1221) + ($1132))|0;
           $1222 = (($1133) + ($$sum150<<2)|0);
           $1223 = HEAP32[$1222>>2]|0;
           $1224 = ($1220>>>0)<($1223>>>0);
           if ($1224) {
            label = 227;
           } else {
            $1229 = $1212;
           }
          } else {
           $1225 = ($1214>>>0)<($1216>>>0);
           if ($1225) {
            label = 227;
           } else {
            $1229 = $1212;
           }
          }
          if ((label|0) == 227) {
           label = 0;
           HEAP32[$1172>>2] = $1210;
           HEAP32[$1191>>2] = $1212;
           $$pre2$i$i$i$i = HEAP32[$1172>>2]|0;
           $1229 = $$pre2$i$i$i$i;
          }
          $1226 = (($1140) + -1)|0;
          $1227 = (($$pre267) + ($1226<<2)|0);
          $1228 = HEAP32[$1227>>2]|0;
          HEAP32[$1172>>2] = $1228;
          HEAP32[$1227>>2] = $1229;
          $1231 = $1229;$i$0$ph$i$i$i = $1141;$j$0$ph$i$i$i = $1226;
          while(1) {
           $1230 = $1231 << 1;
           $$sum143 = (($1230) + ($1132))|0;
           $1232 = (($1133) + ($$sum143<<2)|0);
           $1233 = HEAP32[$1232>>2]|0;
           $1234 = $1230 | 1;
           $$sum144 = (($1234) + ($1132))|0;
           $1235 = (($1133) + ($$sum144<<2)|0);
           $i$0$i$i$i = $i$0$ph$i$i$i;
           while(1) {
            $1236 = (($i$0$i$i$i) + 1)|0;
            $1237 = (($$pre267) + ($1236<<2)|0);
            $1238 = HEAP32[$1237>>2]|0;
            $1239 = $1238 << 1;
            $$sum145 = (($1239) + ($1132))|0;
            $1240 = (($1133) + ($$sum145<<2)|0);
            $1241 = HEAP32[$1240>>2]|0;
            $1242 = ($1241|0)==($1233|0);
            if ($1242) {
             $1243 = $1239 | 1;
             $$sum148 = (($1243) + ($1132))|0;
             $1244 = (($1133) + ($$sum148<<2)|0);
             $1245 = HEAP32[$1244>>2]|0;
             $1246 = HEAP32[$1235>>2]|0;
             $1247 = ($1245>>>0)<($1246>>>0);
             if ($1247) {
              $i$0$i$i$i = $1236;
              continue;
             } else {
              $j$1$i$i$i = $j$0$ph$i$i$i;
              break;
             }
            } else {
             $1248 = ($1241>>>0)<($1233>>>0);
             if ($1248) {
              $i$0$i$i$i = $1236;
              continue;
             } else {
              $j$1$i$i$i = $j$0$ph$i$i$i;
              break;
             }
            }
           }
           while(1) {
            $1249 = (($j$1$i$i$i) + -1)|0;
            $1250 = (($$pre267) + ($1249<<2)|0);
            $1251 = HEAP32[$1250>>2]|0;
            $1252 = $1251 << 1;
            $$sum146 = (($1252) + ($1132))|0;
            $1253 = (($1133) + ($$sum146<<2)|0);
            $1254 = HEAP32[$1253>>2]|0;
            $1255 = ($1233|0)==($1254|0);
            if ($1255) {
             $1256 = HEAP32[$1235>>2]|0;
             $1257 = $1252 | 1;
             $$sum147 = (($1257) + ($1132))|0;
             $1258 = (($1133) + ($$sum147<<2)|0);
             $1259 = HEAP32[$1258>>2]|0;
             $1260 = ($1256>>>0)<($1259>>>0);
             if ($1260) {
              $j$1$i$i$i = $1249;
              continue;
             } else {
              break;
             }
            } else {
             $1261 = ($1233>>>0)<($1254>>>0);
             if ($1261) {
              $j$1$i$i$i = $1249;
              continue;
             } else {
              break;
             }
            }
           }
           $1262 = ($1236|0)<($1249|0);
           if (!($1262)) {
            break;
           }
           HEAP32[$1237>>2] = $1251;
           HEAP32[$1250>>2] = $1238;
           $$pre$i2$i$i = HEAP32[$1227>>2]|0;
           $1231 = $$pre$i2$i$i;$i$0$ph$i$i$i = $1236;$j$0$ph$i$i$i = $1249;
          }
          HEAP32[$1237>>2] = $1231;
          HEAP32[$1227>>2] = $1238;
          $1263 = (($1236) - ($1141))|0;
          $1264 = (($1140) - ($1236))|0;
          $1265 = ($1263|0)<($1264|0);
          if ($1265) {
           $1266 = (($$ph10$i$i) + -1)|0;
           $1267 = ($1268>>>0)<($1266>>>0);
           do {
            if ($1267) {
             $1292 = $$ph9$i$i;$1546 = $$ph$i$i;$1547 = $$ph10$i$i;
            } else {
             $1269 = $$ph10$i$i << 1;
             $1270 = $$ph10$i$i << 3;
             $1271 = ($1270|0)==(0);
             if ($1271) {
              $1283 = 0;
             } else {
              $1272 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
              $1273 = HEAP32[$1272>>2]|0;
              $1274 = (($1273) + 8|0);
              $1275 = HEAP32[$1274>>2]|0;
              $1276 = (__Z15PxGetFoundationv()|0);
              $1277 = HEAP32[$1276>>2]|0;
              $1278 = (($1277) + 24|0);
              $1279 = HEAP32[$1278>>2]|0;
              $1280 = (FUNCTION_TABLE_ii[$1279 & 4095]($1276)|0);
              $$$i$i$i5$i$i = $1280 ? 408816 : 408608;
              $1281 = (FUNCTION_TABLE_iiiiii[$1275 & 255]($1272,$1270,$$$i$i$i5$i$i,408728,148)|0);
              $1283 = $1281;
             }
             $1282 = $1268 << 2;
             _memcpy(($1283|0),($$ph9$i$i|0),($1282|0))|0;
             $1284 = ($$ph$i$i<<24>>24)==(0);
             $1285 = ($$ph9$i$i|0)==(0|0);
             $or$cond$i$i75 = $1284 | $1285;
             if ($or$cond$i$i75) {
              $1292 = $1283;$1546 = 1;$1547 = $1269;
              break;
             }
             $1286 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
             $1287 = HEAP32[$1286>>2]|0;
             $1288 = (($1287) + 12|0);
             $1289 = HEAP32[$1288>>2]|0;
             FUNCTION_TABLE_vii[$1289 & 4095]($1286,$$ph9$i$i);
             $1292 = $1283;$1546 = 1;$1547 = $1269;
            }
           } while(0);
           $1290 = (($1268) + 1)|0;
           $1291 = (($1292) + ($1268<<2)|0);
           HEAP32[$1291>>2] = $1141;
           $1293 = (($1292) + ($1290<<2)|0);
           HEAP32[$1293>>2] = $i$0$i$i$i;
           $1294 = (($i$0$i$i$i) + 2)|0;
           $$ph$be$i$i = $1546;$$ph10$be$i$i = $1547;$$ph12$be$i$i = $1294;$$ph13$be$i$i = $1140;$$ph9$be$i$i = $1292;
          } else {
           $1295 = (($i$0$i$i$i) + 2)|0;
           $1296 = (($$ph10$i$i) + -1)|0;
           $1297 = ($1268>>>0)<($1296>>>0);
           do {
            if ($1297) {
             $1321 = $$ph9$i$i;$1548 = $$ph$i$i;$1549 = $$ph10$i$i;
            } else {
             $1298 = $$ph10$i$i << 1;
             $1299 = $$ph10$i$i << 3;
             $1300 = ($1299|0)==(0);
             if ($1300) {
              $1312 = 0;
             } else {
              $1301 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
              $1302 = HEAP32[$1301>>2]|0;
              $1303 = (($1302) + 8|0);
              $1304 = HEAP32[$1303>>2]|0;
              $1305 = (__Z15PxGetFoundationv()|0);
              $1306 = HEAP32[$1305>>2]|0;
              $1307 = (($1306) + 24|0);
              $1308 = HEAP32[$1307>>2]|0;
              $1309 = (FUNCTION_TABLE_ii[$1308 & 4095]($1305)|0);
              $$$i$i$i$i$i = $1309 ? 408816 : 408608;
              $1310 = (FUNCTION_TABLE_iiiiii[$1304 & 255]($1301,$1299,$$$i$i$i$i$i,408728,148)|0);
              $1312 = $1310;
             }
             $1311 = $1268 << 2;
             _memcpy(($1312|0),($$ph9$i$i|0),($1311|0))|0;
             $1313 = ($$ph$i$i<<24>>24)==(0);
             $1314 = ($$ph9$i$i|0)==(0|0);
             $or$cond1$i$i = $1313 | $1314;
             if ($or$cond1$i$i) {
              $1321 = $1312;$1548 = 1;$1549 = $1298;
              break;
             }
             $1315 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
             $1316 = HEAP32[$1315>>2]|0;
             $1317 = (($1316) + 12|0);
             $1318 = HEAP32[$1317>>2]|0;
             FUNCTION_TABLE_vii[$1318 & 4095]($1315,$$ph9$i$i);
             $1321 = $1312;$1548 = 1;$1549 = $1298;
            }
           } while(0);
           $1319 = (($1268) + 1)|0;
           $1320 = (($1321) + ($1268<<2)|0);
           HEAP32[$1320>>2] = $1295;
           $1322 = (($1321) + ($1319<<2)|0);
           HEAP32[$1322>>2] = $1140;
           $$ph$be$i$i = $1548;$$ph10$be$i$i = $1549;$$ph12$be$i$i = $1141;$$ph13$be$i$i = $i$0$i$i$i;$$ph9$be$i$i = $1321;
          }
          $$ph11$be$i$i = (($1268) + 2)|0;
          $$ph$i$i = $$ph$be$i$i;$$ph10$i$i = $$ph10$be$i$i;$$ph11$i$i = $$ph11$be$i$i;$$ph12$i$i = $$ph12$be$i$i;$$ph13$i$i = $$ph13$be$i$i;$$ph9$i$i = $$ph9$be$i$i;
         }
         $1330 = ($$ph$i$i<<24>>24)==(0);
         $1331 = ($$ph9$i$i|0)==(0|0);
         $or$cond2$i$i = $1330 | $1331;
         if ($or$cond2$i$i) {
          break;
         }
         $1332 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
         $1333 = HEAP32[$1332>>2]|0;
         $1334 = (($1333) + 12|0);
         $1335 = HEAP32[$1334>>2]|0;
         FUNCTION_TABLE_vii[$1335 & 4095]($1332,$$ph9$i$i);
        }
       } while(0);
       $1336 = HEAP8[$1116>>0]|0;
       $1337 = ($1336<<24>>24)==(0);
       if (!($1337)) {
        $1338 = HEAP32[$vararg_buffer>>2]|0;
        __ZN5physx6shdfnd13TempAllocator10deallocateEPv($vararg_buffer,$1338);
       }
       $1339 = HEAP32[$1114>>2]|0;
       $1340 = ($1339|0)==(0);
       if (!($1340)) {
        $1341 = HEAP32[$1056>>2]|0;
        $1342 = HEAP32[$newIndices>>2]|0;
        $1343 = HEAP32[$1059>>2]|0;
        $1344 = HEAP32[$newRestValues>>2]|0;
        $r13$0175 = 0;
        while(1) {
         $1345 = (($$pre267) + ($r13$0175<<2)|0);
         $1346 = HEAP32[$1345>>2]|0;
         $1347 = $1346 << 1;
         $1348 = (($1347) + ($1132))|0;
         $1349 = (($1341) + ($1348<<2)|0);
         $1350 = HEAP32[$1349>>2]|0;
         $1351 = $r13$0175 << 1;
         $1352 = (($1351) + ($1132))|0;
         $1353 = (($1342) + ($1352<<2)|0);
         HEAP32[$1353>>2] = $1350;
         $1354 = HEAP32[$1345>>2]|0;
         $1355 = $1354 << 1;
         $1356 = (($1355) + ($1132))|0;
         $1357 = $1356 | 1;
         $1358 = (($1341) + ($1357<<2)|0);
         $1359 = HEAP32[$1358>>2]|0;
         $1360 = $1352 | 1;
         $1361 = (($1342) + ($1360<<2)|0);
         HEAP32[$1361>>2] = $1359;
         $1362 = HEAP32[$1345>>2]|0;
         $1363 = (($1362) + ($1131))|0;
         $1364 = (($1343) + ($1363<<2)|0);
         $1365 = Math_fround(HEAPF32[$1364>>2]);
         $1366 = (($r13$0175) + ($1131))|0;
         $1367 = (($1344) + ($1366<<2)|0);
         HEAPF32[$1367>>2] = $1365;
         $1368 = (($r13$0175) + 1)|0;
         $1369 = ($1368>>>0)<($1339>>>0);
         if ($1369) {
          $r13$0175 = $1368;
         } else {
          break;
         }
        }
       }
       $1370 = HEAP32[$1115>>2]|0;
       $1371 = $1370 & 2147483647;
       $notlhs = ($1371|0)==(0);
       $notrhs = ($1370|0)<(0);
       $or$cond$i$i72$not = $notrhs | $notlhs;
       $1372 = ($$pre267|0)==(0|0);
       $or$cond279 = $or$cond$i$i72$not | $1372;
       if (!($or$cond279)) {
        $1376 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $1377 = HEAP32[$1376>>2]|0;
        $1378 = (($1377) + 12|0);
        $1379 = HEAP32[$1378>>2]|0;
        FUNCTION_TABLE_vii[$1379 & 4095]($1376,$$pre267);
       }
       $1373 = HEAP32[$795>>2]|0;
       $1374 = (($1373) + -1)|0;
       $1375 = ($1117>>>0)<($1374>>>0);
       if ($1375) {
        $i12$0177 = $1117;
       } else {
        break;
       }
      }
     }
     $1380 = ($newIndices|0)==($1056|0);
     if (!($1380)) {
      HEAP32[$1104>>2] = 0;
      $1381 = HEAP32[$1106>>2]|0;
      $1382 = (($this) + 48|0);
      $1383 = HEAP32[$1382>>2]|0;
      $1384 = $1383 & 2147483647;
      $1385 = ($1384>>>0)<($1381>>>0);
      if ($1385) {
       __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($1056,$1381);
       $$pre$i$i67 = HEAP32[$1106>>2]|0;
       $1388 = $$pre$i$i67;
      } else {
       $1388 = $1381;
      }
      $1386 = HEAP32[$1056>>2]|0;
      $1387 = (($1386) + ($1388<<2)|0);
      $1389 = ($1388|0)>(0);
      if ($1389) {
       $1390 = HEAP32[$newIndices>>2]|0;
       $$012$i$i$i70 = $1386;$$03$i$i$i69 = $1390;
       while(1) {
        $1391 = ($$012$i$i$i70|0)==(0|0);
        if (!($1391)) {
         $1392 = HEAP32[$$03$i$i$i69>>2]|0;
         HEAP32[$$012$i$i$i70>>2] = $1392;
        }
        $1393 = (($$012$i$i$i70) + 4|0);
        $1394 = (($$03$i$i$i69) + 4|0);
        $1395 = ($1393>>>0)<($1387>>>0);
        if ($1395) {
         $$012$i$i$i70 = $1393;$$03$i$i$i69 = $1394;
        } else {
         break;
        }
       }
       $$pre1$i$i = HEAP32[$1106>>2]|0;
       $1396 = $$pre1$i$i;
      } else {
       $1396 = $1388;
      }
      HEAP32[$1104>>2] = $1396;
     }
     $1397 = ($newRestValues|0)==($1059|0);
     if (!($1397)) {
      HEAP32[$1108>>2] = 0;
      $1398 = HEAP32[$1110>>2]|0;
      $1399 = (($this) + 36|0);
      $1400 = HEAP32[$1399>>2]|0;
      $1401 = $1400 & 2147483647;
      $1402 = ($1401>>>0)<($1398>>>0);
      if ($1402) {
       __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE8recreateEj($1059,$1398);
       $$pre$i$i = HEAP32[$1110>>2]|0;
       $1405 = $$pre$i$i;
      } else {
       $1405 = $1398;
      }
      $1403 = HEAP32[$1059>>2]|0;
      $1404 = (($1403) + ($1405<<2)|0);
      $1406 = ($1405|0)>(0);
      if ($1406) {
       $1407 = HEAP32[$newRestValues>>2]|0;
       $$012$i$i$i = $1403;$$03$i$i$i = $1407;
       while(1) {
        $1408 = ($$012$i$i$i|0)==(0|0);
        if (!($1408)) {
         $1409 = Math_fround(HEAPF32[$$03$i$i$i>>2]);
         HEAPF32[$$012$i$i$i>>2] = $1409;
        }
        $1410 = (($$012$i$i$i) + 4|0);
        $1411 = (($$03$i$i$i) + 4|0);
        $1412 = ($1410>>>0)<($1404>>>0);
        if ($1412) {
         $$012$i$i$i = $1410;$$03$i$i$i = $1411;
        } else {
         break;
        }
       }
      }
      HEAP32[$1108>>2] = $1405;
     }
     do {
      if ($useGeodesicTether) {
       __ZN5physx27PxClothGeodesicTetherCookerC2ERKNS_15PxClothMeshDescE($tetherCooker,$desc);
       $1413 = (__ZNK5physx27PxClothGeodesicTetherCooker15getCookerStatusEv($tetherCooker)|0);
       $1414 = ($1413|0)==(0);
       if ($1414) {
        $1415 = (__ZNK5physx27PxClothGeodesicTetherCooker23getNbTethersPerParticleEv($tetherCooker)|0);
        $1416 = HEAP32[$this>>2]|0;
        $1417 = Math_imul($1416, $1415)|0;
        $1418 = (($this) + 52|0);
        HEAP32[$24>>2] = 0;
        __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($1418,$1417,$24);
        $1419 = (($this) + 64|0);
        HEAPF32[$25>>2] = Math_fround(0.0);
        __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($1419,$1417,$25);
        $1420 = HEAP32[$1418>>2]|0;
        $1421 = HEAP32[$1419>>2]|0;
        __ZNK5physx27PxClothGeodesicTetherCooker13getTetherDataEPjPf($tetherCooker,$1420,$1421);
        __ZN5physx27PxClothGeodesicTetherCookerD2Ev($tetherCooker);
        break;
       } else {
        __ZN5physx27PxClothGeodesicTetherCookerD2Ev($tetherCooker);
        label = 287;
        break;
       }
      } else {
       label = 287;
      }
     } while(0);
     if ((label|0) == 287) {
      __ZN5physx25PxClothSimpleTetherCookerC2ERKNS_15PxClothMeshDescE($tetherCooker14,$desc);
      $1422 = (($this) + 52|0);
      $1423 = HEAP32[$this>>2]|0;
      HEAP32[$26>>2] = 0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($1422,$1423,$26);
      $1424 = (($this) + 64|0);
      $1425 = HEAP32[$this>>2]|0;
      HEAPF32[$27>>2] = Math_fround(0.0);
      __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($1424,$1425,$27);
      $1426 = HEAP32[$1422>>2]|0;
      $1427 = HEAP32[$1424>>2]|0;
      __ZNK5physx25PxClothSimpleTetherCooker13getTetherDataEPjPf($tetherCooker14,$1426,$1427);
      __ZN5physx25PxClothSimpleTetherCookerD2Ev($tetherCooker14);
     }
     $1428 = HEAP32[$1111>>2]|0;
     $1429 = $1428 & 2147483647;
     $1430 = ($1429|0)!=(0);
     $1431 = ($1428|0)>(-1);
     $or$cond$i$i64 = $1430 & $1431;
     do {
      if ($or$cond$i$i64) {
       $1432 = HEAP32[$newRestValues>>2]|0;
       $1433 = ($1432|0)==(0|0);
       if ($1433) {
        break;
       }
       $1434 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1435 = HEAP32[$1434>>2]|0;
       $1436 = (($1435) + 12|0);
       $1437 = HEAP32[$1436>>2]|0;
       FUNCTION_TABLE_vii[$1437 & 4095]($1434,$1432);
      }
     } while(0);
     $1438 = HEAP32[$1107>>2]|0;
     $1439 = $1438 & 2147483647;
     $1440 = ($1439|0)!=(0);
     $1441 = ($1438|0)>(-1);
     $or$cond$i$i62 = $1440 & $1441;
     do {
      if ($or$cond$i$i62) {
       $1442 = HEAP32[$newIndices>>2]|0;
       $1443 = ($1442|0)==(0|0);
       if ($1443) {
        break;
       }
       $1444 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1445 = HEAP32[$1444>>2]|0;
       $1446 = (($1445) + 12|0);
       $1447 = HEAP32[$1446>>2]|0;
       FUNCTION_TABLE_vii[$1447 & 4095]($1444,$1442);
      }
     } while(0);
     $constraintHeap$idx8$val = HEAP32[$constraintHeap>>2]|0;
     $constraintHeap$idx10$val = HEAP32[$781>>2]|0;
     $1448 = $constraintHeap$idx10$val & 2147483647;
     $notlhs$i = ($1448|0)==(0);
     $notrhs$i = ($constraintHeap$idx10$val|0)<(0);
     $or$cond$not$i = $notrhs$i | $notlhs$i;
     $1449 = ($constraintHeap$idx8$val|0)==(0|0);
     $or$cond2$i = $or$cond$not$i | $1449;
     if (!($or$cond2$i)) {
      $1450 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $1451 = HEAP32[$1450>>2]|0;
      $1452 = (($1451) + 12|0);
      $1453 = HEAP32[$1452>>2]|0;
      FUNCTION_TABLE_vii[$1453 & 4095]($1450,$constraintHeap$idx8$val);
     }
     $1454 = HEAP32[$779>>2]|0;
     $1455 = $1454 & 2147483647;
     $1456 = ($1455|0)!=(0);
     $1457 = ($1454|0)>(-1);
     $or$cond$i$i23 = $1456 & $1457;
     do {
      if ($or$cond$i$i23) {
       $1458 = HEAP32[$adjColorCount>>2]|0;
       $1459 = ($1458|0)==(0|0);
       if ($1459) {
        break;
       }
       $1460 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1461 = HEAP32[$1460>>2]|0;
       $1462 = (($1461) + 12|0);
       $1463 = HEAP32[$1462>>2]|0;
       FUNCTION_TABLE_vii[$1463 & 4095]($1460,$1458);
      }
     } while(0);
     $1464 = HEAP32[$775>>2]|0;
     $1465 = $1464 & 2147483647;
     $1466 = ($1465|0)!=(0);
     $1467 = ($1464|0)>(-1);
     $or$cond$i$i21 = $1466 & $1467;
     do {
      if ($or$cond$i$i21) {
       $1468 = HEAP32[$colors>>2]|0;
       $1469 = ($1468|0)==(0|0);
       if ($1469) {
        break;
       }
       $1470 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1471 = HEAP32[$1470>>2]|0;
       $1472 = (($1471) + 12|0);
       $1473 = HEAP32[$1472>>2]|0;
       FUNCTION_TABLE_vii[$1473 & 4095]($1470,$1468);
      }
     } while(0);
     $1474 = HEAP32[$625>>2]|0;
     $1475 = $1474 & 2147483647;
     $1476 = ($1475|0)!=(0);
     $1477 = ($1474|0)>(-1);
     $or$cond$i$i19 = $1476 & $1477;
     do {
      if ($or$cond$i$i19) {
       $1478 = HEAP32[$constraints>>2]|0;
       $1479 = ($1478|0)==(0|0);
       if ($1479) {
        break;
       }
       $1480 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1481 = HEAP32[$1480>>2]|0;
       $1482 = (($1481) + 12|0);
       $1483 = HEAP32[$1482>>2]|0;
       FUNCTION_TABLE_vii[$1483 & 4095]($1480,$1478);
      }
     } while(0);
     $1484 = HEAP32[$edges>>2]|0;
     $1485 = ($1484|0)==(0|0);
     if (!($1485)) {
      __ZN5physx6shdfnd9Allocator10deallocateEPv($edges,$1484);
     }
     $1486 = HEAP32[$481>>2]|0;
     $1487 = $1486 & 2147483647;
     $1488 = ($1487|0)!=(0);
     $1489 = ($1486|0)>(-1);
     $or$cond$i$i16 = $1488 & $1489;
     do {
      if ($or$cond$i$i16) {
       $1490 = HEAP32[$neighbors>>2]|0;
       $1491 = ($1490|0)==(0|0);
       if ($1491) {
        break;
       }
       $1492 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1493 = HEAP32[$1492>>2]|0;
       $1494 = (($1493) + 12|0);
       $1495 = HEAP32[$1494>>2]|0;
       FUNCTION_TABLE_vii[$1495 & 4095]($1492,$1490);
      }
     } while(0);
     $1496 = HEAP32[$478>>2]|0;
     $1497 = $1496 & 2147483647;
     $1498 = ($1497|0)!=(0);
     $1499 = ($1496|0)>(-1);
     $or$cond$i$i14 = $1498 & $1499;
     do {
      if ($or$cond$i$i14) {
       $1500 = HEAP32[$mark>>2]|0;
       $1501 = ($1500|0)==(0|0);
       if ($1501) {
        break;
       }
       $1502 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1503 = HEAP32[$1502>>2]|0;
       $1504 = (($1503) + 12|0);
       $1505 = HEAP32[$1504>>2]|0;
       FUNCTION_TABLE_vii[$1505 & 4095]($1502,$1500);
      }
     } while(0);
     $1506 = HEAP32[$137>>2]|0;
     $1507 = $1506 & 2147483647;
     $1508 = ($1507|0)!=(0);
     $1509 = ($1506|0)>(-1);
     $or$cond$i$i12 = $1508 & $1509;
     do {
      if ($or$cond$i$i12) {
       $1510 = HEAP32[$adjacencies>>2]|0;
       $1511 = ($1510|0)==(0|0);
       if ($1511) {
        break;
       }
       $1512 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1513 = HEAP32[$1512>>2]|0;
       $1514 = (($1513) + 12|0);
       $1515 = HEAP32[$1514>>2]|0;
       FUNCTION_TABLE_vii[$1515 & 4095]($1512,$1510);
      }
     } while(0);
     $1516 = HEAP32[$135>>2]|0;
     $1517 = $1516 & 2147483647;
     $1518 = ($1517|0)!=(0);
     $1519 = ($1516|0)>(-1);
     $or$cond$i$i11 = $1518 & $1519;
     do {
      if ($or$cond$i$i11) {
       $1520 = HEAP32[$valency>>2]|0;
       $1521 = ($1520|0)==(0|0);
       if ($1521) {
        break;
       }
       $1522 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $1523 = HEAP32[$1522>>2]|0;
       $1524 = (($1523) + 12|0);
       $1525 = HEAP32[$1524>>2]|0;
       FUNCTION_TABLE_vii[$1525 & 4095]($1522,$1520);
      }
     } while(0);
     $1526 = HEAP32[$97>>2]|0;
     $1527 = $1526 & 2147483647;
     $1528 = ($1527|0)!=(0);
     $1529 = ($1526|0)>(-1);
     $or$cond$i$i = $1528 & $1529;
     if (!($or$cond$i$i)) {
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
     $1530 = HEAP32[$particles>>2]|0;
     $1531 = ($1530|0)==(0|0);
     if ($1531) {
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
     $1532 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $1533 = HEAP32[$1532>>2]|0;
     $1534 = (($1533) + 12|0);
     $1535 = HEAP32[$1534>>2]|0;
     FUNCTION_TABLE_vii[$1535 & 4095]($1532,$1530);
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $76 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($76,4,408376,284,408472,$vararg_buffer);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx19PxClothFabricCreateERNS_9PxPhysicsERKNS_15PxClothMeshDescERKNS_6PxVec3Eb($physics,$desc,$gravity,$useGeodesicTether) {
 $physics = $physics|0;
 $desc = $desc|0;
 $gravity = $gravity|0;
 $useGeodesicTether = $useGeodesicTether|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $impl = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $impl = sp + 56|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = (($impl) + 4|0);
 dest=$2+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $3 = Math_fround(HEAPF32[$gravity>>2]);
 HEAPF32[$0>>2] = $3;
 $4 = (($0) + 4|0);
 $5 = (($gravity) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($0) + 8|0);
 $8 = (($gravity) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (__ZN5physx18PxFabricCookerImpl4cookERKNS_15PxClothMeshDescENS_6PxVec3Eb($impl,$desc,$0,$useGeodesicTether)|0);
 if (!($10)) {
  $$0 = 0;
  __ZN5physx18PxFabricCookerImplD2Ev($impl);
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$physics>>2]|0;
 $12 = (($11) + 80|0);
 $13 = HEAP32[$12>>2]|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;HEAP32[$1+28>>2]=0|0;
 $14 = HEAP32[$impl>>2]|0;
 HEAP32[$1>>2] = $14;
 $15 = (($impl) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($1) + 4|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP32[$2>>2]|0;
 $19 = (($1) + 8|0);
 HEAP32[$19>>2] = $18;
 $20 = (($impl) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + -1)|0;
 $23 = (($1) + 12|0);
 HEAP32[$23>>2] = $22;
 $24 = (($impl) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 4|0);
 $27 = (($1) + 16|0);
 HEAP32[$27>>2] = $26;
 $28 = (($impl) + 28|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($1) + 24|0);
 HEAP32[$30>>2] = $29;
 $31 = (($impl) + 40|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($1) + 20|0);
 HEAP32[$33>>2] = $32;
 $34 = (($impl) + 56|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($1) + 28|0);
 HEAP32[$36>>2] = $35;
 $37 = (($impl) + 52|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($1) + 32|0);
 HEAP32[$39>>2] = $38;
 $40 = (($impl) + 64|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($1) + 36|0);
 HEAP32[$42>>2] = $41;
 $43 = (FUNCTION_TABLE_iii[$13 & 4095]($physics,$1)|0);
 $$0 = $43;
 __ZN5physx18PxFabricCookerImplD2Ev($impl);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal11HashMapBaseINS0_4PairIjjEEN12_GLOBAL__N_14EdgeENS0_4HashIS4_EENS0_9AllocatorEEixERKS4_($this,$k) {
 $this = $this|0;
 $k = $k|0;
 var $$$i$i = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $h$0$i = 0, $h$1$i = 0, $index$0$i = 0, $index$011$i = 0;
 var $index$012$i = 0, $k$idx$val$i = 0, $k$idx2$i = 0, $k$idx2$val$i = 0, $k$idx4$val$i = 0, $k$idx5$i = 0, $k$idx5$val$i = 0, $this$idx$val$i = 0, $this$idx$val$pre$i = 0, $this$idx6$i = 0, $this$idx6$val$i = 0, $this$idx7$i = 0, $this$idx7$val$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $53 = 0;$h$0$i = 0;
  } else {
   $k$idx4$val$i = HEAP32[$k>>2]|0;
   $k$idx5$i = (($k) + 4|0);
   $k$idx5$val$i = HEAP32[$k$idx5$i>>2]|0;
   $3 = $k$idx5$val$i << 15;
   $4 = $3 ^ -1;
   $5 = (($k$idx5$val$i) + ($4))|0;
   $6 = $5 >>> 10;
   $7 = $6 ^ $5;
   $8 = ($7*9)|0;
   $9 = $8 >>> 6;
   $10 = $9 ^ $8;
   $11 = $10 << 11;
   $12 = $11 ^ -1;
   $13 = (($10) + ($12))|0;
   $14 = $13 >>> 16;
   $15 = $14 ^ $13;
   $16 = $k$idx4$val$i << 15;
   $17 = $16 ^ -1;
   $18 = (($k$idx4$val$i) + ($17))|0;
   $19 = $18 >>> 10;
   $20 = $19 ^ $18;
   $21 = ($20*9)|0;
   $22 = $21 >>> 6;
   $23 = $22 ^ $21;
   $24 = $23 << 11;
   $25 = $24 ^ -1;
   $26 = (($23) + ($25))|0;
   $27 = $26 >>> 16;
   $28 = $26 ^ -57320555;
   $29 = $28 ^ $27;
   $30 = ($29*1000007)|0;
   $31 = $15 ^ $30;
   $32 = (($1) + -1)|0;
   $33 = $31 & $32;
   $34 = (($this) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + ($33<<2)|0);
   $index$011$i = HEAP32[$36>>2]|0;
   $37 = ($index$011$i|0)==(-1);
   if ($37) {
    $53 = $1;$h$0$i = $33;
   } else {
    $38 = (($this) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($this) + 8|0);
    $index$012$i = $index$011$i;
    while(1) {
     $41 = (($39) + (($index$012$i*20)|0)|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==($k$idx4$val$i|0);
     if ($43) {
      $44 = ((($39) + (($index$012$i*20)|0)|0) + 4|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45|0)==($k$idx5$val$i|0);
      if ($46) {
       break;
      }
     }
     $47 = HEAP32[$40>>2]|0;
     $48 = (($47) + ($index$012$i<<2)|0);
     $index$0$i = HEAP32[$48>>2]|0;
     $49 = ($index$0$i|0)==(-1);
     if ($49) {
      $53 = $1;$h$0$i = $33;
      break L1;
     } else {
      $index$012$i = $index$0$i;
     }
    }
    $50 = (($39) + (($index$012$i*20)|0)|0);
    $$0$i2 = $50;
    $113 = (($$0$i2) + 8|0);
    STACKTOP = sp;return ($113|0);
   }
  }
 } while(0);
 $this$idx6$i = (($this) + 16|0);
 $this$idx6$val$i = HEAP32[$this$idx6$i>>2]|0;
 $this$idx7$i = (($this) + 36|0);
 $this$idx7$val$i = HEAP32[$this$idx7$i>>2]|0;
 $51 = ($this$idx7$val$i|0)==($this$idx6$val$i|0);
 if ($51) {
  $52 = ($53|0)==(0);
  $54 = $53 << 1;
  $$$i$i = $52 ? 16 : $54;
  $55 = ($53>>>0)<($$$i$i>>>0);
  if ($55) {
   __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IjjEEN12_GLOBAL__N_14EdgeEEES4_NS0_4HashIS4_EENS1_11HashMapBaseIS4_S7_SA_NS0_9AllocatorEE6GetKeyESC_Lb1EE15reserveInternalEj($this,$$$i$i);
   $this$idx$val$pre$i = HEAP32[$0>>2]|0;
   $this$idx$val$i = $this$idx$val$pre$i;
  } else {
   $this$idx$val$i = $53;
  }
  $k$idx$val$i = HEAP32[$k>>2]|0;
  $k$idx2$i = (($k) + 4|0);
  $k$idx2$val$i = HEAP32[$k$idx2$i>>2]|0;
  $56 = $k$idx2$val$i << 15;
  $57 = $56 ^ -1;
  $58 = (($k$idx2$val$i) + ($57))|0;
  $59 = $58 >>> 10;
  $60 = $59 ^ $58;
  $61 = ($60*9)|0;
  $62 = $61 >>> 6;
  $63 = $62 ^ $61;
  $64 = $63 << 11;
  $65 = $64 ^ -1;
  $66 = (($63) + ($65))|0;
  $67 = $66 >>> 16;
  $68 = $67 ^ $66;
  $69 = $k$idx$val$i << 15;
  $70 = $69 ^ -1;
  $71 = (($k$idx$val$i) + ($70))|0;
  $72 = $71 >>> 10;
  $73 = $72 ^ $71;
  $74 = ($73*9)|0;
  $75 = $74 >>> 6;
  $76 = $75 ^ $74;
  $77 = $76 << 11;
  $78 = $77 ^ -1;
  $79 = (($76) + ($78))|0;
  $80 = $79 >>> 16;
  $81 = $79 ^ -57320555;
  $82 = $81 ^ $80;
  $83 = ($82*1000007)|0;
  $84 = $68 ^ $83;
  $85 = (($this$idx$val$i) + -1)|0;
  $86 = $84 & $85;
  $h$1$i = $86;
 } else {
  $h$1$i = $h$0$i;
 }
 $87 = (($this) + 28|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($88) + 1)|0;
 HEAP32[$87>>2] = $89;
 $90 = (($this) + 12|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (($91) + ($h$1$i<<2)|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($this) + 8|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = (($95) + ($88<<2)|0);
 HEAP32[$96>>2] = $93;
 HEAP32[$92>>2] = $88;
 $97 = HEAP32[$this$idx7$i>>2]|0;
 $98 = (($97) + 1)|0;
 HEAP32[$this$idx7$i>>2] = $98;
 $99 = (($this) + 32|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) + 1)|0;
 HEAP32[$99>>2] = $101;
 $102 = (($this) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + (($88*20)|0)|0);
 $105 = ($104|0)==(0|0);
 if ($105) {
  $$0$i2 = 0;
  $113 = (($$0$i2) + 8|0);
  STACKTOP = sp;return ($113|0);
 }
 $106 = HEAP32[$k>>2]|0;
 HEAP32[$104>>2] = $106;
 $107 = ((($103) + (($88*20)|0)|0) + 4|0);
 $108 = (($k) + 4|0);
 $109 = HEAP32[$108>>2]|0;
 HEAP32[$107>>2] = $109;
 $110 = ((($103) + (($88*20)|0)|0) + 8|0);
 HEAPF32[$110>>2] = Math_fround(0.0);
 $111 = ((($103) + (($88*20)|0)|0) + 12|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = ((($103) + (($88*20)|0)|0) + 16|0);
 HEAPF32[$112>>2] = Math_fround(0.0);
 $$0$i2 = $104;
 $113 = (($$0$i2) + 8|0);
 STACKTOP = sp;return ($113|0);
}
function __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 408640 : 408608;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,408528,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_18PxClothFabricPhaseENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 408920 : 408608;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,408528,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_125ConstraintGraphColorCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $this$idx$val = 0, $this$idx1 = 0, $this$idx1$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $this$idx1 = (($this) + 8|0);
 $this$idx1$val = HEAP32[$this$idx1>>2]|0;
 $0 = $this$idx1$val & 2147483647;
 $1 = ($0|0)==(0);
 $2 = $this$idx1$val << 1;
 $$$i = $1 ? 1 : $2;
 $3 = ($$$i|0)==(0);
 if ($3) {
  $19 = 0;
 } else {
  $4 = $$$i << 3;
  $5 = ($4|0)==(0);
  if ($5) {
   $19 = 0;
  } else {
   $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (__Z15PxGetFoundationv()|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 24|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
   $$$i$i$i = $14 ? 409048 : 408608;
   $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,$4,$$$i$i$i,408528,558)|0);
   $19 = $15;
  }
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($19) + ($17<<3)|0);
 $20 = ($17|0)>(0);
 if ($20) {
  $21 = HEAP32[$this>>2]|0;
  $$012$i = $19;$$03$i = $21;
  while(1) {
   $22 = ($$012$i|0)==(0|0);
   if (!($22)) {
    $23 = $$03$i;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 4)|0;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = $$012$i;
    $30 = $29;
    HEAP32[$30>>2] = $25;
    $31 = (($29) + 4)|0;
    $32 = $31;
    HEAP32[$32>>2] = $28;
   }
   $33 = (($$012$i) + 8|0);
   $34 = (($$03$i) + 8|0);
   $35 = ($33>>>0)<($18>>>0);
   if ($35) {
    $$012$i = $33;$$03$i = $34;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$16>>2]|0;
  $37 = $$pre;
 } else {
  $37 = $17;
 }
 $36 = (($19) + ($37<<3)|0);
 $38 = ($36|0)==(0|0);
 if (!($38)) {
  $39 = $a;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + 4)|0;
  $43 = $42;
  $44 = HEAP32[$43>>2]|0;
  $45 = $36;
  $46 = $45;
  HEAP32[$46>>2] = $41;
  $47 = (($45) + 4)|0;
  $48 = $47;
  HEAP32[$48>>2] = $44;
 }
 $this$idx$val = HEAP32[$this$idx1>>2]|0;
 $49 = ($this$idx$val|0)>(-1);
 if ($49) {
  $50 = HEAP32[$this>>2]|0;
  $51 = ($50|0)==(0|0);
  if (!($51)) {
   $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vii[$55 & 4095]($52,$50);
  }
 }
 HEAP32[$this>>2] = $19;
 HEAP32[$this$idx1>>2] = $$$i;
 $56 = HEAP32[$16>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$16>>2] = $57;
 $58 = (($19) + ($56<<3)|0);
 STACKTOP = sp;return ($58|0);
}
function __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_125ConstraintGraphColorCountENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $this$idx = 0, $this$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 409048 : 408608;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,408528,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = $$03$i;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = $$012$i;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
   }
   $30 = (($$012$i) + 8|0);
   $31 = (($$03$i) + 8|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $this$idx = (($this) + 8|0);
 $this$idx$val = HEAP32[$this$idx>>2]|0;
 $33 = ($this$idx$val|0)>(-1);
 if (!($33)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$this$idx>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$this>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  HEAP32[$this>>2] = $16;
  HEAP32[$this$idx>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vii[$39 & 4095]($36,$34);
 HEAP32[$this>>2] = $16;
 HEAP32[$this$idx>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS0_4PairINS2_IjjEENS_22PxClothFabricPhaseType4EnumEEENS0_19ReflectionAllocatorIS6_EEE15growAndPushBackERKS6_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*12)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 409200 : 408608;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,408528,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*12)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    HEAP32[$29>>2] = $31;
   }
   $32 = (($$012$i) + 12|0);
   $33 = (($$03$i) + 12|0);
   $34 = ($32>>>0)<($20>>>0);
   if ($34) {
    $$012$i = $32;$$03$i = $33;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $36 = $$pre;
 } else {
  $36 = $19;
 }
 $35 = (($21) + (($36*12)|0)|0);
 $37 = ($35|0)==(0|0);
 if (!($37)) {
  $38 = HEAP32[$a>>2]|0;
  HEAP32[$35>>2] = $38;
  $39 = ((($21) + (($36*12)|0)|0) + 4|0);
  $40 = (($a) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$39>>2] = $41;
  $42 = ((($21) + (($36*12)|0)|0) + 8|0);
  $43 = (($a) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  HEAP32[$42>>2] = $44;
 }
 $45 = HEAP32[$0>>2]|0;
 $46 = ($45|0)>(-1);
 if (!($46)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $53 = HEAP32[$18>>2]|0;
  $54 = (($53) + 1)|0;
  HEAP32[$18>>2] = $54;
  $55 = (($21) + (($53*12)|0)|0);
  STACKTOP = sp;return ($55|0);
 }
 $47 = HEAP32[$this>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $53 = HEAP32[$18>>2]|0;
  $54 = (($53) + 1)|0;
  HEAP32[$18>>2] = $54;
  $55 = (($21) + (($53*12)|0)|0);
  STACKTOP = sp;return ($55|0);
 }
 $49 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095]($49,$47);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $53 = HEAP32[$18>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$18>>2] = $54;
 $55 = (($21) + (($53*12)|0)|0);
 STACKTOP = sp;return ($55|0);
}
function __ZN5physx6shdfnd5ArrayINS0_4PairINS2_IjjEENS_22PxClothFabricPhaseType4EnumEEENS0_19ReflectionAllocatorIS6_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*12)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 409200 : 408608;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,408528,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*12)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    HEAP32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP32[$24>>2] = $26;
   }
   $27 = (($$012$i) + 12|0);
   $28 = (($$03$i) + 12|0);
   $29 = ($27>>>0)<($15>>>0);
   if ($29) {
    $$012$i = $27;$$03$i = $28;
   } else {
    break;
   }
  }
 }
 $30 = (($this) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)>(-1);
 if (!($32)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$30>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$this>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  HEAP32[$this>>2] = $16;
  HEAP32[$30>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
 HEAP32[$this>>2] = $16;
 HEAP32[$30>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IjjEEN12_GLOBAL__N_14EdgeEEES4_NS0_4HashIS4_EENS1_11HashMapBaseIS4_S7_SA_NS0_9AllocatorEE6GetKeyESC_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $index$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = ($21*20)|0;
 $29 = (($27) + ($28))|0;
 $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$29,409488,354)|0);
 $31 = (($30) + ($22)|0);
 $32 = (($30) + ($27)|0);
 _memset(($30|0),-1,($22|0))|0;
 $33 = (($this) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 $$pre = (($this) + 4|0);
 if (!($35)) {
  $36 = (($$0) + -1)|0;
  $index$02 = 0;
  while(1) {
   $37 = HEAP32[$$pre>>2]|0;
   $$idx = (($37) + (($index$02*20)|0)|0);
   $$idx$val = HEAP32[$$idx>>2]|0;
   $$idx1 = ((($37) + (($index$02*20)|0)|0) + 4|0);
   $$idx1$val = HEAP32[$$idx1>>2]|0;
   $38 = $$idx1$val << 15;
   $39 = $38 ^ -1;
   $40 = (($$idx1$val) + ($39))|0;
   $41 = $40 >>> 10;
   $42 = $41 ^ $40;
   $43 = ($42*9)|0;
   $44 = $43 >>> 6;
   $45 = $44 ^ $43;
   $46 = $45 << 11;
   $47 = $46 ^ -1;
   $48 = (($45) + ($47))|0;
   $49 = $48 >>> 16;
   $50 = $49 ^ $48;
   $51 = $$idx$val << 15;
   $52 = $51 ^ -1;
   $53 = (($$idx$val) + ($52))|0;
   $54 = $53 >>> 10;
   $55 = $54 ^ $53;
   $56 = ($55*9)|0;
   $57 = $56 >>> 6;
   $58 = $57 ^ $56;
   $59 = $58 << 11;
   $60 = $59 ^ -1;
   $61 = (($58) + ($60))|0;
   $62 = $61 >>> 16;
   $63 = $61 ^ -57320555;
   $64 = $63 ^ $62;
   $65 = ($64*1000007)|0;
   $66 = $50 ^ $65;
   $67 = $66 & $36;
   $68 = (($30) + ($67<<2)|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($31) + ($index$02<<2)|0);
   HEAP32[$70>>2] = $69;
   HEAP32[$68>>2] = $index$02;
   $71 = (($32) + (($index$02*20)|0)|0);
   $72 = ($71|0)==(0|0);
   if (!($72)) {
    $73 = HEAP32[$$idx>>2]|0;
    HEAP32[$71>>2] = $73;
    $74 = ((($32) + (($index$02*20)|0)|0) + 4|0);
    $75 = HEAP32[$$idx1>>2]|0;
    HEAP32[$74>>2] = $75;
    $76 = ((($32) + (($index$02*20)|0)|0) + 8|0);
    $77 = ((($37) + (($index$02*20)|0)|0) + 8|0);
    ;HEAP32[$76+0>>2]=HEAP32[$77+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$77+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$77+8>>2]|0;
   }
   $78 = (($index$02) + 1)|0;
   $79 = HEAP32[$33>>2]|0;
   $80 = ($78>>>0)<($79>>>0);
   if ($80) {
    $index$02 = $78;
   } else {
    break;
   }
  }
 }
 $81 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$81);
 HEAP32[$this>>2] = $30;
 $82 = (($this) + 12|0);
 HEAP32[$82>>2] = $30;
 $83 = (($this) + 20|0);
 HEAP32[$83>>2] = $$0;
 $84 = (($this) + 8|0);
 HEAP32[$84>>2] = $31;
 HEAP32[$$pre>>2] = $32;
 HEAP32[$15>>2] = $21;
 $85 = (($this) + 28|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(-1);
 if (!($87)) {
  STACKTOP = sp;return;
 }
 HEAP32[$85>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 4;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 409576 : 408608;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,408528,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<4)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
   }
   $35 = (($$012$i) + 16|0);
   $36 = (($$03$i) + 16|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
 }
 $38 = ($20|0)==(0|0);
 if (!($38)) {
  $39 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$20>>2] = $39;
  $40 = ((($21) + ($19<<4)|0) + 4|0);
  $41 = (($a) + 4|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$40>>2] = $42;
  $43 = ((($21) + ($19<<4)|0) + 8|0);
  $44 = (($a) + 8|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$43>>2] = $45;
  $46 = ((($21) + ($19<<4)|0) + 12|0);
  $47 = (($a) + 12|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  HEAPF32[$46>>2] = $48;
 }
 $49 = HEAP32[$0>>2]|0;
 $50 = ($49|0)>(-1);
 if (!($50)) {
  $58 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $57 = (($58) + 1)|0;
  HEAP32[$18>>2] = $57;
  $59 = (($21) + ($58<<4)|0);
  STACKTOP = sp;return ($59|0);
 }
 $51 = HEAP32[$this>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  $58 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $57 = (($58) + 1)|0;
  HEAP32[$18>>2] = $57;
  $59 = (($21) + ($58<<4)|0);
  STACKTOP = sp;return ($59|0);
 }
 $53 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vii[$56 & 4095]($53,$51);
 $$pre = HEAP32[$18>>2]|0;
 $58 = $$pre;
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $57 = (($58) + 1)|0;
 HEAP32[$18>>2] = $57;
 $59 = (($21) + ($58<<4)|0);
 STACKTOP = sp;return ($59|0);
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 409576 : 408608;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,408528,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
   }
   $30 = (($$012$i) + 16|0);
   $31 = (($$03$i) + 16|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx18PxFabricCookerImplD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i4 = 0, $or$cond$i$i6 = 0, $or$cond$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 64|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i1 = $15 & $16;
 if ($or$cond$i$i1) {
  $17 = (($this) + 52|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 48|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i2 = $27 & $28;
 if ($or$cond$i$i2) {
  $29 = (($this) + 40|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38|0)!=(0);
 $40 = ($37|0)>(-1);
 $or$cond$i$i4 = $39 & $40;
 if ($or$cond$i$i4) {
  $41 = (($this) + 28|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($44,$42);
  }
 }
 $48 = (($this) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49 & 2147483647;
 $51 = ($50|0)!=(0);
 $52 = ($49|0)>(-1);
 $or$cond$i$i6 = $51 & $52;
 if ($or$cond$i$i6) {
  $53 = (($this) + 16|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   FUNCTION_TABLE_vii[$59 & 4095]($56,$54);
  }
 }
 $60 = (($this) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = $61 & 2147483647;
 $63 = ($62|0)!=(0);
 $64 = ($61|0)>(-1);
 $or$cond$i$i8 = $63 & $64;
 if (!($or$cond$i$i8)) {
  STACKTOP = sp;return;
 }
 $65 = (($this) + 4|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $68 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 12|0);
 $71 = HEAP32[$70>>2]|0;
 FUNCTION_TABLE_vii[$71 & 4095]($68,$66);
 STACKTOP = sp;return;
}
function __ZN5physx27PxClothGeodesicTetherCookerC2ERKNS_15PxClothMeshDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $0 = 0, $1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__Znwj(108)|0);
 HEAP32[$0>>2] = $desc;
 $1 = (($0) + 8|0);
 dest=$1+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx31PxClothGeodesicTetherCookerImpl16createTetherDataERKNS_15PxClothMeshDescE($0,$desc);
 HEAP32[$this>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN5physx27PxClothGeodesicTetherCookerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __ZN5physx31PxClothGeodesicTetherCookerImplD2Ev($0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZNK5physx27PxClothGeodesicTetherCooker15getCookerStatusEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx27PxClothGeodesicTetherCooker23getNbTethersPerParticleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2>>>0) / ($4>>>0))&-1;
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx27PxClothGeodesicTetherCooker13getTetherDataEPjPf($this,$userTetherAnchors,$userTetherLengths) {
 $this = $this|0;
 $userTetherAnchors = $userTetherAnchors|0;
 $userTetherLengths = $userTetherLengths|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 2;
 _memcpy(($userTetherAnchors|0),($2|0),($5|0))|0;
 $6 = (($0) + 96|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($0) + 100|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 << 2;
 _memcpy(($userTetherLengths|0),($7|0),($10|0))|0;
 STACKTOP = sp;return;
}
function __ZN5physx31PxClothGeodesicTetherCookerImpl16createTetherDataERKNS_15PxClothMeshDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$ = Math_fround(0), $$$i = 0, $$$i138 = 0, $$$i183 = 0, $$01$i$i = 0, $$01$i$i84 = 0, $$013$i$i = 0, $$013$i$i79 = 0, $$016$i$i = 0, $$016$i$i81 = 0, $$05$i$i = 0, $$05$i$i83 = 0, $$idx$i = 0, $$idx$i120 = 0, $$idx$i140 = 0, $$idx$i161 = 0, $$idx$i185 = 0, $$idx$i213 = 0, $$idx$val$i = Math_fround(0), $$idx$val$i121 = Math_fround(0);
 var $$idx$val$i141 = Math_fround(0), $$idx$val$i162 = Math_fround(0), $$idx$val$i186 = Math_fround(0), $$idx$val$i214 = Math_fround(0), $$idx3$i = 0, $$idx3$i122 = 0, $$idx3$i142 = 0, $$idx3$i163 = 0, $$idx3$i187 = 0, $$idx3$i215 = 0, $$idx3$val$i = Math_fround(0), $$idx3$val$i123 = Math_fround(0), $$idx3$val$i143 = Math_fround(0), $$idx3$val$i164 = Math_fround(0), $$idx3$val$i188 = Math_fround(0), $$idx3$val$i216 = Math_fround(0), $$idx4$i = 0, $$idx4$i118 = 0, $$idx4$i134 = 0, $$idx4$i158 = 0;
 var $$idx4$i179 = 0, $$idx4$i210 = 0, $$idx4$val$i = Math_fround(0), $$idx4$val$i135 = Math_fround(0), $$idx4$val$i180 = Math_fround(0), $$idx5$i = 0, $$idx5$i136 = 0, $$idx5$i181 = 0, $$idx5$val$i = Math_fround(0), $$idx5$val$i137 = Math_fround(0), $$idx5$val$i182 = Math_fround(0), $$in$i = 0, $$in$i67 = 0, $$in1225$i = 0, $$in1225$i76 = 0, $$in1320$i = 0, $$in1320$i92 = 0, $$in1416$i = 0, $$in1416$i97 = 0, $$in268 = 0;
 var $$in3031$i = 0, $$in3031$i44 = 0, $$in33$i = 0, $$in33$i31 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i115 = 0, $$pre$i$i153 = 0, $$pre$i$i205 = 0, $$pre$i$i60 = 0, $$pre$i10$i = 0, $$pre$i10$i52 = 0, $$pre$i13$i = 0, $$pre$i13$i33 = 0, $$pre$i16$i = 0, $$pre$i16$i49 = 0, $$pre$i19$i = 0, $$pre$i19$i35 = 0, $$pre$i22$i = 0;
 var $$pre$i22$i46 = 0, $$pre$i25$i = 0, $$pre$i25$i37 = 0, $$pre$i27 = 0, $$pre$i4$i = 0, $$pre$i4$i58 = 0, $$pre$i64 = 0, $$pre$i7$i = 0, $$pre$i7$i55 = 0, $$pre$i86 = 0, $$pre303 = 0, $$pre37$i = 0, $$pre38$i = 0, $$pre38$i45 = 0, $$pre39$i = 0, $$pre39$i48 = 0, $$pre40$i = 0, $$pre40$i51 = 0, $$pre40$i63 = 0, $$pre40$i72 = 0;
 var $$pre41$i = 0, $$pre41$i54 = 0, $$pre42$i = 0, $$pre42$i57 = 0, $$pre43$i = 0, $$pre43$i32 = 0, $$pre44$i = 0, $$sum = 0, $$sum$i = 0, $$sum$i133 = 0, $$sum$i178 = 0, $$sum1 = 0, $$sum4 = 0, $$sum5 = 0, $$sum7$i = 0, $$sum7$i130 = 0, $$sum7$i175 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0;
 var $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = Math_fround(0), $1026 = 0, $1027 = 0, $1028 = Math_fround(0), $1029 = 0, $103 = 0, $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = 0, $1033 = Math_fround(0), $1034 = 0, $1035 = Math_fround(0);
 var $1036 = Math_fround(0), $1037 = 0, $1038 = Math_fround(0), $1039 = 0, $104 = 0, $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = Math_fround(0), $1053 = 0;
 var $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0;
 var $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0;
 var $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0;
 var $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0;
 var $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0;
 var $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0;
 var $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0;
 var $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0;
 var $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = Math_fround(0), $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0;
 var $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = Math_fround(0);
 var $795 = Math_fround(0), $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0;
 var $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0;
 var $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0;
 var $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0;
 var $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0;
 var $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0;
 var $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = Math_fround(0), $909 = 0, $91 = 0, $910 = Math_fround(0), $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0;
 var $920 = 0, $921 = 0, $922 = 0, $923 = Math_fround(0), $924 = 0, $925 = Math_fround(0), $926 = Math_fround(0), $927 = 0, $928 = Math_fround(0), $929 = 0, $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = 0, $933 = Math_fround(0), $934 = 0, $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0);
 var $939 = Math_fround(0), $94 = 0, $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = 0, $945 = Math_fround(0), $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0;
 var $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0;
 var $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = Math_fround(0), $992 = 0;
 var $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $adjacencies = 0, $child$0$i = 0, $child$0$i139 = 0, $child$0$i184 = 0, $current$05$i = 0, $current$05$i160 = 0, $current$05$i212 = 0, $current$08$i = 0, $current$08$i132 = 0, $current$08$i177 = 0, $dest$pn$i$i = 0, $dest$pn$i$i82 = 0, $distance$0 = Math_fround(0);
 var $errorCode = 0, $exitcond = 0, $exitcond273 = 0, $exitcond274 = 0, $exitcond275 = 0, $exitcond276 = 0, $exitcond277 = 0, $heap$idx$val$i = 0, $heap$idx$val$i117 = 0, $heap$idx$val$i117$pre = 0, $heap$idx$val$i127 = 0, $heap$idx$val$i127$pre = 0, $heap$idx$val$i127293 = 0, $heap$idx$val$i127294 = 0, $heap$idx$val$i156 = 0, $heap$idx$val$i172 = 0, $heap$idx$val$i172$pre = 0, $heap$idx$val$i172284 = 0, $heap$idx$val$i172286 = 0, $heap$idx$val$i208 = 0;
 var $heap$idx2$i$promoted = 0, $heap$idx2$val$i116 = 0, $heap$idx2$val$i129 = 0, $heap$idx2$val$i155 = 0, $heap$idx2$val$i174 = 0, $heap$idx2$val$i207 = 0, $heap$idx2$val$pre$i = 0, $heap$idx2$val$pre$i151 = 0, $heap$idx2$val$pre$i203 = 0, $i$0269 = 0, $i$033$i = 0, $i$033$i68 = 0, $i$034$i = 0, $i$034$i30 = 0, $i1$026$i = 0, $i1$026$i75 = 0, $i1$0265 = 0, $i1$032$i = 0, $i1$032$i43 = 0, $i13$0227 = 0;
 var $i2$0253 = 0, $i3$021$i = 0, $i3$021$i91 = 0, $i4$0245 = 0, $i5$017$i = 0, $i5$017$i96 = 0, $islandCnt$0251 = 0, $islandCnt$1 = 0, $islandFirst = 0, $islandIndexCnt = 0, $islandIndices = 0, $j$0264 = 0, $j$1$lcssa = 0, $j$1259 = 0, $j11$0240 = 0, $j14$0224 = 0, $j15$0225 = 0, $j3$0248 = 0, $j5$0232 = 0, $j6$0236 = 0;
 var $k = 0, $mark = 0, $neighbors = 0, $notlhs = 0, $notlhs$i = 0, $notlhs$i106 = 0, $notrhs = 0, $notrhs$i = 0, $notrhs$i107 = 0, $or$cond = 0, $or$cond$i$i$not = 0, $or$cond$i$i100 = 0, $or$cond$i$i102 = 0, $or$cond$i$i104 = 0, $or$cond$i$i16 = 0, $or$cond$i$i18 = 0, $or$cond$i$i20 = 0, $or$cond$i$i23 = 0, $or$cond$i$i25 = 0, $or$cond$not$i = 0;
 var $or$cond$not$i108 = 0, $or$cond2$i = 0, $or$cond2$i109 = 0, $phitmp = 0, $phitmp$i = 0, $phitmp$i39 = 0, $phitmp$i65 = 0, $phitmp$i87 = 0, $phitmp44$i = 0, $phitmp45$i = 0, $this$idx$val$i = 0, $this$idx$val$i$i = 0, $this$idx$val$i$i150 = 0, $this$idx$val$i$i202 = 0, $this$idx$val$i191 = 0, $tmp$i$i200 = 0, $umax = 0, $valency = 0, $vertexDistanceBuffer = 0, $vertexHeap = 0;
 var $vertexHeap$idx$val$pr = 0, $vertexHeap$idx$val$pr289 = 0, $vertexHeap$idx10$val = 0, $vertexHeap$idx12$val = 0, $vertexHeap$idx7$val$pre = 0, $vertexIsland = 0, $vertexIslandHeap = 0, $vertexIslandHeap$idx$val$pre = 0, $vertexIslandHeap$idx13$val = 0, $vertexIslandHeap$idx15$val = 0, $vertexIslandHeap$idx8$val = 0, $vertexIslandHeap$idx8$val298 = 0, $vertexParentBuffer = 0, $vj = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $tmp$i$i200 = sp + 264|0;
 $0 = sp + 244|0;
 $1 = sp + 248|0;
 $2 = sp + 252|0;
 $3 = sp + 256|0;
 $4 = sp + 260|0;
 $5 = sp + 276|0;
 $6 = sp + 280|0;
 $7 = sp + 284|0;
 $8 = sp + 288|0;
 $9 = sp + 292|0;
 $10 = sp + 296|0;
 $11 = sp + 300|0;
 $12 = sp + 312|0;
 $valency = sp + 232|0;
 $13 = sp + 228|0;
 $adjacencies = sp + 216|0;
 $mark = sp + 204|0;
 $14 = sp + 200|0;
 $neighbors = sp + 188|0;
 $k = sp + 184|0;
 $vertexIsland = sp + 172|0;
 $15 = sp + 76|0;
 $vertexIslandHeap = sp + 64|0;
 $16 = sp + 52|0;
 $islandIndices = sp + 40|0;
 $islandFirst = sp + 28|0;
 $islandIndexCnt = sp + 24|0;
 $17 = sp + 8|0;
 $18 = sp + 4|0;
 $vj = sp;
 $19 = sp + 12|0;
 $vertexDistanceBuffer = sp + 80|0;
 $20 = sp + 92|0;
 $vertexParentBuffer = sp + 96|0;
 $21 = sp + 108|0;
 $vertexHeap = sp + 112|0;
 $22 = sp + 124|0;
 $23 = sp + 136|0;
 $24 = sp + 148|0;
 $25 = sp + 152|0;
 $26 = sp + 156|0;
 $errorCode = sp + 168|0;
 $27 = (($desc) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 4|0);
 HEAP32[$29>>2] = $28;
 $30 = (($desc) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 8|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($33,$28,$11);
 $34 = (($this) + 32|0);
 $35 = HEAP32[$29>>2]|0;
 HEAP8[$12>>0] = 0;
 __ZN5physx6shdfnd5ArrayIhNS0_19ReflectionAllocatorIhEEE6resizeEjRKh($34,$35,$12);
 $36 = HEAP32[$desc>>2]|0;
 $37 = (($desc) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$29>>2]|0;
 $40 = ($39|0)==(0);
 if (!($40)) {
  $41 = HEAP32[$30>>2]|0;
  $42 = (($desc) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $$in268 = $43;$55 = $41;$i$0269 = 0;
  while(1) {
   $44 = HEAP32[$33>>2]|0;
   $45 = (($$in268) + ($36)|0);
   $46 = Math_fround(HEAPF32[$$in268>>2]);
   $47 = (($44) + (($i$0269*12)|0)|0);
   HEAPF32[$47>>2] = $46;
   $48 = (($$in268) + 4|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = ((($44) + (($i$0269*12)|0)|0) + 4|0);
   HEAPF32[$50>>2] = $49;
   $51 = (($$in268) + 8|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $53 = ((($44) + (($i$0269*12)|0)|0) + 8|0);
   HEAPF32[$53>>2] = $52;
   $54 = ($55|0)==(0|0);
   if ($54) {
    $1164 = 0;$61 = 0;
   } else {
    $56 = (($55) + ($38)|0);
    $57 = Math_fround(HEAPF32[$55>>2]);
    $58 = $57 == Math_fround(0.0);
    $phitmp = $58&1;
    $1164 = $56;$61 = $phitmp;
   }
   $59 = HEAP32[$34>>2]|0;
   $60 = (($59) + ($i$0269)|0);
   HEAP8[$60>>0] = $61;
   $62 = (($i$0269) + 1)|0;
   $63 = HEAP32[$29>>2]|0;
   $64 = ($62>>>0)<($63>>>0);
   if ($64) {
    $$in268 = $45;$55 = $1164;$i$0269 = $62;
   } else {
    break;
   }
  }
 }
 $65 = (($desc) + 48|0);
 $66 = HEAP16[$65>>1]|0;
 $67 = $66 & 2;
 $68 = ($67<<16>>16)==(0);
 $69 = (($this) + 20|0);
 $70 = (($desc) + 24|0);
 $71 = (($desc) + 36|0);
 L12: do {
  if ($68) {
   $205 = (($desc) + 32|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = ($206*3)|0;
   $208 = (($desc) + 44|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = ($209*6)|0;
   $211 = (($210) + ($207))|0;
   $212 = (($this) + 28|0);
   $213 = HEAP32[$212>>2]|0;
   $214 = $213 & 2147483647;
   $215 = ($214>>>0)<($211>>>0);
   if ($215) {
    __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($69,$211);
    $$pre$i27 = HEAP32[$205>>2]|0;
    $218 = $$pre$i27;
   } else {
    $218 = $206;
   }
   $216 = HEAP32[$70>>2]|0;
   $217 = ($218|0)==(0);
   L94: do {
    if (!($217)) {
     $219 = (($desc) + 28|0);
     $220 = HEAP32[$219>>2]|0;
     $221 = (($this) + 24|0);
     $$in33$i31 = $220;$i$034$i30 = 1;
     while(1) {
      $222 = HEAP32[$212>>2]|0;
      $223 = $222 & 2147483647;
      $224 = HEAP32[$221>>2]|0;
      $225 = ($223>>>0)>($224>>>0);
      if ($225) {
       $226 = HEAP32[$69>>2]|0;
       $227 = (($226) + ($224<<2)|0);
       $228 = ($227|0)==(0|0);
       if ($228) {
        $231 = $224;
       } else {
        $229 = HEAP32[$$in33$i31>>2]|0;
        HEAP32[$227>>2] = $229;
        $$pre$i13$i33 = HEAP32[$221>>2]|0;
        $231 = $$pre$i13$i33;
       }
       $230 = (($231) + 1)|0;
       HEAP32[$221>>2] = $230;
       $236 = $230;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$$in33$i31)|0);
       $$pre43$i32 = HEAP32[$221>>2]|0;
       $236 = $$pre43$i32;
      }
      $232 = (($$in33$i31) + 4|0);
      $233 = HEAP32[$212>>2]|0;
      $234 = $233 & 2147483647;
      $235 = ($234>>>0)>($236>>>0);
      if ($235) {
       $237 = HEAP32[$69>>2]|0;
       $238 = (($237) + ($236<<2)|0);
       $239 = ($238|0)==(0|0);
       if ($239) {
        $242 = $236;
       } else {
        $240 = HEAP32[$232>>2]|0;
        HEAP32[$238>>2] = $240;
        $$pre$i19$i35 = HEAP32[$221>>2]|0;
        $242 = $$pre$i19$i35;
       }
       $241 = (($242) + 1)|0;
       HEAP32[$221>>2] = $241;
       $247 = $241;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$232)|0);
       $$pre44$i = HEAP32[$221>>2]|0;
       $247 = $$pre44$i;
      }
      $243 = (($$in33$i31) + 8|0);
      $244 = HEAP32[$212>>2]|0;
      $245 = $244 & 2147483647;
      $246 = ($245>>>0)>($247>>>0);
      if ($246) {
       $248 = HEAP32[$69>>2]|0;
       $249 = (($248) + ($247<<2)|0);
       $250 = ($249|0)==(0|0);
       if ($250) {
        $253 = $247;
       } else {
        $251 = HEAP32[$243>>2]|0;
        HEAP32[$249>>2] = $251;
        $$pre$i25$i37 = HEAP32[$221>>2]|0;
        $253 = $$pre$i25$i37;
       }
       $252 = (($253) + 1)|0;
       HEAP32[$221>>2] = $252;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$243)|0);
      }
      $254 = HEAP32[$205>>2]|0;
      $255 = ($i$034$i30>>>0)<($254>>>0);
      if (!($255)) {
       break L94;
      }
      $256 = (($$in33$i31) + ($216)|0);
      $phitmp$i39 = (($i$034$i30) + 1)|0;
      $$in33$i31 = $256;$i$034$i30 = $phitmp$i39;
     }
    }
   } while(0);
   $257 = HEAP32[$71>>2]|0;
   $258 = HEAP32[$208>>2]|0;
   $259 = ($258|0)==(0);
   if (!($259)) {
    $260 = (($desc) + 40|0);
    $261 = HEAP32[$260>>2]|0;
    $262 = (($this) + 24|0);
    $$in3031$i44 = $261;$i1$032$i43 = 1;
    while(1) {
     $263 = HEAP32[$212>>2]|0;
     $264 = $263 & 2147483647;
     $265 = HEAP32[$262>>2]|0;
     $266 = ($264>>>0)>($265>>>0);
     if ($266) {
      $267 = HEAP32[$69>>2]|0;
      $268 = (($267) + ($265<<2)|0);
      $269 = ($268|0)==(0|0);
      if ($269) {
       $272 = $265;
      } else {
       $270 = HEAP32[$$in3031$i44>>2]|0;
       HEAP32[$268>>2] = $270;
       $$pre$i22$i46 = HEAP32[$262>>2]|0;
       $272 = $$pre$i22$i46;
      }
      $271 = (($272) + 1)|0;
      HEAP32[$262>>2] = $271;
      $277 = $271;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$$in3031$i44)|0);
      $$pre38$i45 = HEAP32[$262>>2]|0;
      $277 = $$pre38$i45;
     }
     $273 = (($$in3031$i44) + 4|0);
     $274 = HEAP32[$212>>2]|0;
     $275 = $274 & 2147483647;
     $276 = ($275>>>0)>($277>>>0);
     if ($276) {
      $278 = HEAP32[$69>>2]|0;
      $279 = (($278) + ($277<<2)|0);
      $280 = ($279|0)==(0|0);
      if ($280) {
       $283 = $277;
      } else {
       $281 = HEAP32[$273>>2]|0;
       HEAP32[$279>>2] = $281;
       $$pre$i16$i49 = HEAP32[$262>>2]|0;
       $283 = $$pre$i16$i49;
      }
      $282 = (($283) + 1)|0;
      HEAP32[$262>>2] = $282;
      $288 = $282;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$273)|0);
      $$pre39$i48 = HEAP32[$262>>2]|0;
      $288 = $$pre39$i48;
     }
     $284 = (($$in3031$i44) + 8|0);
     $285 = HEAP32[$212>>2]|0;
     $286 = $285 & 2147483647;
     $287 = ($286>>>0)>($288>>>0);
     if ($287) {
      $289 = HEAP32[$69>>2]|0;
      $290 = (($289) + ($288<<2)|0);
      $291 = ($290|0)==(0|0);
      if ($291) {
       $294 = $288;
      } else {
       $292 = HEAP32[$284>>2]|0;
       HEAP32[$290>>2] = $292;
       $$pre$i10$i52 = HEAP32[$262>>2]|0;
       $294 = $$pre$i10$i52;
      }
      $293 = (($294) + 1)|0;
      HEAP32[$262>>2] = $293;
      $298 = $293;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$284)|0);
      $$pre40$i51 = HEAP32[$262>>2]|0;
      $298 = $$pre40$i51;
     }
     $295 = HEAP32[$212>>2]|0;
     $296 = $295 & 2147483647;
     $297 = ($296>>>0)>($298>>>0);
     if ($297) {
      $299 = HEAP32[$69>>2]|0;
      $300 = (($299) + ($298<<2)|0);
      $301 = ($300|0)==(0|0);
      if ($301) {
       $304 = $298;
      } else {
       $302 = HEAP32[$$in3031$i44>>2]|0;
       HEAP32[$300>>2] = $302;
       $$pre$i7$i55 = HEAP32[$262>>2]|0;
       $304 = $$pre$i7$i55;
      }
      $303 = (($304) + 1)|0;
      HEAP32[$262>>2] = $303;
      $308 = $303;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$$in3031$i44)|0);
      $$pre41$i54 = HEAP32[$262>>2]|0;
      $308 = $$pre41$i54;
     }
     $305 = HEAP32[$212>>2]|0;
     $306 = $305 & 2147483647;
     $307 = ($306>>>0)>($308>>>0);
     if ($307) {
      $309 = HEAP32[$69>>2]|0;
      $310 = (($309) + ($308<<2)|0);
      $311 = ($310|0)==(0|0);
      if ($311) {
       $314 = $308;
      } else {
       $312 = HEAP32[$284>>2]|0;
       HEAP32[$310>>2] = $312;
       $$pre$i4$i58 = HEAP32[$262>>2]|0;
       $314 = $$pre$i4$i58;
      }
      $313 = (($314) + 1)|0;
      HEAP32[$262>>2] = $313;
      $319 = $313;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$284)|0);
      $$pre42$i57 = HEAP32[$262>>2]|0;
      $319 = $$pre42$i57;
     }
     $315 = (($$in3031$i44) + 12|0);
     $316 = HEAP32[$212>>2]|0;
     $317 = $316 & 2147483647;
     $318 = ($317>>>0)>($319>>>0);
     if ($318) {
      $320 = HEAP32[$69>>2]|0;
      $321 = (($320) + ($319<<2)|0);
      $322 = ($321|0)==(0|0);
      if ($322) {
       $325 = $319;
      } else {
       $323 = HEAP32[$315>>2]|0;
       HEAP32[$321>>2] = $323;
       $$pre$i$i60 = HEAP32[$262>>2]|0;
       $325 = $$pre$i$i60;
      }
      $324 = (($325) + 1)|0;
      HEAP32[$262>>2] = $324;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$315)|0);
     }
     $326 = HEAP32[$208>>2]|0;
     $327 = ($i1$032$i43>>>0)<($326>>>0);
     if (!($327)) {
      break L12;
     }
     $328 = (($$in3031$i44) + ($257)|0);
     $phitmp45$i = (($i1$032$i43) + 1)|0;
     $$in3031$i44 = $328;$i1$032$i43 = $phitmp45$i;
    }
   }
  } else {
   $72 = (($desc) + 32|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73*3)|0;
   $75 = (($desc) + 44|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76*6)|0;
   $78 = (($77) + ($74))|0;
   $79 = (($this) + 28|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = $80 & 2147483647;
   $82 = ($81>>>0)<($78>>>0);
   if ($82) {
    __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($69,$78);
    $$pre$i = HEAP32[$72>>2]|0;
    $85 = $$pre$i;
   } else {
    $85 = $73;
   }
   $83 = HEAP32[$70>>2]|0;
   $84 = ($85|0)==(0);
   L17: do {
    if (!($84)) {
     $86 = (($desc) + 28|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = (($this) + 24|0);
     $$in33$i = $87;$i$034$i = 1;
     while(1) {
      $89 = HEAP16[$$in33$i>>1]|0;
      $90 = $89&65535;
      HEAP32[$2>>2] = $90;
      $91 = HEAP32[$79>>2]|0;
      $92 = $91 & 2147483647;
      $93 = HEAP32[$88>>2]|0;
      $94 = ($92>>>0)>($93>>>0);
      if ($94) {
       $95 = HEAP32[$69>>2]|0;
       $96 = (($95) + ($93<<2)|0);
       $97 = ($96|0)==(0|0);
       if ($97) {
        $99 = $93;
       } else {
        HEAP32[$96>>2] = $90;
        $$pre$i13$i = HEAP32[$88>>2]|0;
        $99 = $$pre$i13$i;
       }
       $98 = (($99) + 1)|0;
       HEAP32[$88>>2] = $98;
       $106 = $98;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$2)|0);
       $$pre42$i = HEAP32[$88>>2]|0;
       $106 = $$pre42$i;
      }
      $100 = (($$in33$i) + 2|0);
      $101 = HEAP16[$100>>1]|0;
      $102 = $101&65535;
      HEAP32[$3>>2] = $102;
      $103 = HEAP32[$79>>2]|0;
      $104 = $103 & 2147483647;
      $105 = ($104>>>0)>($106>>>0);
      if ($105) {
       $107 = HEAP32[$69>>2]|0;
       $108 = (($107) + ($106<<2)|0);
       $109 = ($108|0)==(0|0);
       if ($109) {
        $111 = $106;
       } else {
        HEAP32[$108>>2] = $102;
        $$pre$i19$i = HEAP32[$88>>2]|0;
        $111 = $$pre$i19$i;
       }
       $110 = (($111) + 1)|0;
       HEAP32[$88>>2] = $110;
       $118 = $110;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$3)|0);
       $$pre43$i = HEAP32[$88>>2]|0;
       $118 = $$pre43$i;
      }
      $112 = (($$in33$i) + 4|0);
      $113 = HEAP16[$112>>1]|0;
      $114 = $113&65535;
      HEAP32[$4>>2] = $114;
      $115 = HEAP32[$79>>2]|0;
      $116 = $115 & 2147483647;
      $117 = ($116>>>0)>($118>>>0);
      if ($117) {
       $119 = HEAP32[$69>>2]|0;
       $120 = (($119) + ($118<<2)|0);
       $121 = ($120|0)==(0|0);
       if ($121) {
        $123 = $118;
       } else {
        HEAP32[$120>>2] = $114;
        $$pre$i25$i = HEAP32[$88>>2]|0;
        $123 = $$pre$i25$i;
       }
       $122 = (($123) + 1)|0;
       HEAP32[$88>>2] = $122;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$4)|0);
      }
      $124 = HEAP32[$72>>2]|0;
      $125 = ($i$034$i>>>0)<($124>>>0);
      if (!($125)) {
       break L17;
      }
      $126 = (($$in33$i) + ($83)|0);
      $phitmp$i = (($i$034$i) + 1)|0;
      $$in33$i = $126;$i$034$i = $phitmp$i;
     }
    }
   } while(0);
   $127 = HEAP32[$71>>2]|0;
   $128 = HEAP32[$75>>2]|0;
   $129 = ($128|0)==(0);
   if (!($129)) {
    $130 = (($desc) + 40|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($this) + 24|0);
    $$in3031$i = $131;$i1$032$i = 1;
    while(1) {
     $133 = HEAP16[$$in3031$i>>1]|0;
     $134 = $133&65535;
     HEAP32[$5>>2] = $134;
     $135 = HEAP32[$79>>2]|0;
     $136 = $135 & 2147483647;
     $137 = HEAP32[$132>>2]|0;
     $138 = ($136>>>0)>($137>>>0);
     if ($138) {
      $139 = HEAP32[$69>>2]|0;
      $140 = (($139) + ($137<<2)|0);
      $141 = ($140|0)==(0|0);
      if ($141) {
       $143 = $137;
      } else {
       HEAP32[$140>>2] = $134;
       $$pre$i22$i = HEAP32[$132>>2]|0;
       $143 = $$pre$i22$i;
      }
      $142 = (($143) + 1)|0;
      HEAP32[$132>>2] = $142;
      $150 = $142;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$5)|0);
      $$pre37$i = HEAP32[$132>>2]|0;
      $150 = $$pre37$i;
     }
     $144 = (($$in3031$i) + 2|0);
     $145 = HEAP16[$144>>1]|0;
     $146 = $145&65535;
     HEAP32[$6>>2] = $146;
     $147 = HEAP32[$79>>2]|0;
     $148 = $147 & 2147483647;
     $149 = ($148>>>0)>($150>>>0);
     if ($149) {
      $151 = HEAP32[$69>>2]|0;
      $152 = (($151) + ($150<<2)|0);
      $153 = ($152|0)==(0|0);
      if ($153) {
       $155 = $150;
      } else {
       HEAP32[$152>>2] = $146;
       $$pre$i16$i = HEAP32[$132>>2]|0;
       $155 = $$pre$i16$i;
      }
      $154 = (($155) + 1)|0;
      HEAP32[$132>>2] = $154;
      $162 = $154;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$6)|0);
      $$pre38$i = HEAP32[$132>>2]|0;
      $162 = $$pre38$i;
     }
     $156 = (($$in3031$i) + 4|0);
     $157 = HEAP16[$156>>1]|0;
     $158 = $157&65535;
     HEAP32[$7>>2] = $158;
     $159 = HEAP32[$79>>2]|0;
     $160 = $159 & 2147483647;
     $161 = ($160>>>0)>($162>>>0);
     if ($161) {
      $163 = HEAP32[$69>>2]|0;
      $164 = (($163) + ($162<<2)|0);
      $165 = ($164|0)==(0|0);
      if ($165) {
       $167 = $162;
      } else {
       HEAP32[$164>>2] = $158;
       $$pre$i10$i = HEAP32[$132>>2]|0;
       $167 = $$pre$i10$i;
      }
      $166 = (($167) + 1)|0;
      HEAP32[$132>>2] = $166;
      $173 = $166;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$7)|0);
      $$pre39$i = HEAP32[$132>>2]|0;
      $173 = $$pre39$i;
     }
     $168 = HEAP16[$$in3031$i>>1]|0;
     $169 = $168&65535;
     HEAP32[$8>>2] = $169;
     $170 = HEAP32[$79>>2]|0;
     $171 = $170 & 2147483647;
     $172 = ($171>>>0)>($173>>>0);
     if ($172) {
      $174 = HEAP32[$69>>2]|0;
      $175 = (($174) + ($173<<2)|0);
      $176 = ($175|0)==(0|0);
      if ($176) {
       $178 = $173;
      } else {
       HEAP32[$175>>2] = $169;
       $$pre$i7$i = HEAP32[$132>>2]|0;
       $178 = $$pre$i7$i;
      }
      $177 = (($178) + 1)|0;
      HEAP32[$132>>2] = $177;
      $184 = $177;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$8)|0);
      $$pre40$i = HEAP32[$132>>2]|0;
      $184 = $$pre40$i;
     }
     $179 = HEAP16[$156>>1]|0;
     $180 = $179&65535;
     HEAP32[$9>>2] = $180;
     $181 = HEAP32[$79>>2]|0;
     $182 = $181 & 2147483647;
     $183 = ($182>>>0)>($184>>>0);
     if ($183) {
      $185 = HEAP32[$69>>2]|0;
      $186 = (($185) + ($184<<2)|0);
      $187 = ($186|0)==(0|0);
      if ($187) {
       $189 = $184;
      } else {
       HEAP32[$186>>2] = $180;
       $$pre$i4$i = HEAP32[$132>>2]|0;
       $189 = $$pre$i4$i;
      }
      $188 = (($189) + 1)|0;
      HEAP32[$132>>2] = $188;
      $196 = $188;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$9)|0);
      $$pre41$i = HEAP32[$132>>2]|0;
      $196 = $$pre41$i;
     }
     $190 = (($$in3031$i) + 6|0);
     $191 = HEAP16[$190>>1]|0;
     $192 = $191&65535;
     HEAP32[$10>>2] = $192;
     $193 = HEAP32[$79>>2]|0;
     $194 = $193 & 2147483647;
     $195 = ($194>>>0)>($196>>>0);
     if ($195) {
      $197 = HEAP32[$69>>2]|0;
      $198 = (($197) + ($196<<2)|0);
      $199 = ($198|0)==(0|0);
      if ($199) {
       $201 = $196;
      } else {
       HEAP32[$198>>2] = $192;
       $$pre$i$i = HEAP32[$132>>2]|0;
       $201 = $$pre$i$i;
      }
      $200 = (($201) + 1)|0;
      HEAP32[$132>>2] = $200;
     } else {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($69,$10)|0);
     }
     $202 = HEAP32[$75>>2]|0;
     $203 = ($i1$032$i>>>0)<($202>>>0);
     if (!($203)) {
      break L12;
     }
     $204 = (($$in3031$i) + ($127)|0);
     $phitmp44$i = (($i1$032$i) + 1)|0;
     $$in3031$i = $204;$i1$032$i = $phitmp44$i;
    }
   }
  }
 } while(0);
 __ZN5physx31PxClothGeodesicTetherCookerImpl20findVertTriNeighborsEv($this);
 $329 = (__ZN5physx31PxClothGeodesicTetherCookerImpl16findTriNeighborsEv($this)|0);
 $330 = (($this) + 80|0);
 HEAP32[$330>>2] = $329;
 $331 = ($329|0)==(0);
 if (!($331)) {
  STACKTOP = sp;return;
 }
 $332 = HEAP32[$29>>2]|0;
 $333 = (($332) + 1)|0;
 HEAP32[$13>>2] = 0;
 HEAP32[$valency>>2] = 0;
 $334 = (($valency) + 4|0);
 HEAP32[$334>>2] = 0;
 $335 = (($valency) + 8|0);
 HEAP32[$335>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($valency,$333,$13);
 HEAP32[$adjacencies>>2] = 0;
 $336 = (($adjacencies) + 4|0);
 HEAP32[$336>>2] = 0;
 $337 = (($adjacencies) + 8|0);
 HEAP32[$337>>2] = 0;
 $338 = HEAP16[$65>>1]|0;
 $339 = $338 & 2;
 $340 = ($339<<16>>16)==(0);
 if ($340) {
  $502 = (($desc) + 28|0);
  $503 = HEAP32[$70>>2]|0;
  $504 = (($desc) + 32|0);
  $505 = HEAP32[$504>>2]|0;
  $506 = ($505|0)==(0);
  if (!($506)) {
   $507 = HEAP32[$502>>2]|0;
   $508 = HEAP32[$valency>>2]|0;
   $$in$i67 = $507;$i$033$i68 = 0;
   while(1) {
    $509 = HEAP32[$$in$i67>>2]|0;
    $510 = (($508) + ($509<<2)|0);
    $511 = HEAP32[$510>>2]|0;
    $512 = (($511) + 2)|0;
    HEAP32[$510>>2] = $512;
    $513 = (($$in$i67) + 4|0);
    $514 = HEAP32[$513>>2]|0;
    $515 = (($508) + ($514<<2)|0);
    $516 = HEAP32[$515>>2]|0;
    $517 = (($516) + 2)|0;
    HEAP32[$515>>2] = $517;
    $518 = (($$in$i67) + 8|0);
    $519 = HEAP32[$518>>2]|0;
    $520 = (($508) + ($519<<2)|0);
    $521 = HEAP32[$520>>2]|0;
    $522 = (($521) + 2)|0;
    HEAP32[$520>>2] = $522;
    $523 = (($i$033$i68) + 1)|0;
    $524 = (($$in$i67) + ($503)|0);
    $525 = HEAP32[$504>>2]|0;
    $526 = ($523>>>0)<($525>>>0);
    if ($526) {
     $$in$i67 = $524;$i$033$i68 = $523;
    } else {
     break;
    }
   }
  }
  $527 = (($desc) + 40|0);
  $528 = HEAP32[$71>>2]|0;
  $529 = (($desc) + 44|0);
  $530 = HEAP32[$529>>2]|0;
  $531 = ($530|0)==(0);
  if ($531) {
   $$pre40$i72 = HEAP32[$valency>>2]|0;
   $559 = $$pre40$i72;
  } else {
   $532 = HEAP32[$527>>2]|0;
   $533 = HEAP32[$valency>>2]|0;
   $$in1225$i76 = $532;$i1$026$i75 = 0;
   while(1) {
    $534 = HEAP32[$$in1225$i76>>2]|0;
    $535 = (($533) + ($534<<2)|0);
    $536 = HEAP32[$535>>2]|0;
    $537 = (($536) + 2)|0;
    HEAP32[$535>>2] = $537;
    $538 = (($$in1225$i76) + 4|0);
    $539 = HEAP32[$538>>2]|0;
    $540 = (($533) + ($539<<2)|0);
    $541 = HEAP32[$540>>2]|0;
    $542 = (($541) + 2)|0;
    HEAP32[$540>>2] = $542;
    $543 = (($$in1225$i76) + 8|0);
    $544 = HEAP32[$543>>2]|0;
    $545 = (($533) + ($544<<2)|0);
    $546 = HEAP32[$545>>2]|0;
    $547 = (($546) + 2)|0;
    HEAP32[$545>>2] = $547;
    $548 = (($$in1225$i76) + 12|0);
    $549 = HEAP32[$548>>2]|0;
    $550 = (($533) + ($549<<2)|0);
    $551 = HEAP32[$550>>2]|0;
    $552 = (($551) + 2)|0;
    HEAP32[$550>>2] = $552;
    $553 = (($i1$026$i75) + 1)|0;
    $554 = (($$in1225$i76) + ($528)|0);
    $555 = HEAP32[$529>>2]|0;
    $556 = ($553>>>0)<($555>>>0);
    if ($556) {
     $$in1225$i76 = $554;$i1$026$i75 = $553;
    } else {
     $559 = $533;
     break;
    }
   }
  }
  $557 = HEAP32[$334>>2]|0;
  $558 = (($559) + ($557<<2)|0);
  $560 = ($557|0)==(0);
  if ($560) {
   $1166 = 0;$568 = -1;
  } else {
   $561 = ($557|0)==(1);
   if ($561) {
    $1166 = 1;$568 = 0;
   } else {
    $$013$i$i79 = (($559) + 4|0);
    $562 = HEAP32[$559>>2]|0;
    $$016$i$i81 = $$013$i$i79;$565 = $562;$dest$pn$i$i82 = $559;
    while(1) {
     $$05$i$i83 = (($dest$pn$i$i82) + 4|0);
     $563 = HEAP32[$$016$i$i81>>2]|0;
     $564 = (($563) + ($565))|0;
     HEAP32[$$05$i$i83>>2] = $564;
     $$01$i$i84 = (($$016$i$i81) + 4|0);
     $566 = ($$01$i$i84|0)==($558|0);
     if ($566) {
      break;
     } else {
      $$016$i$i81 = $$01$i$i84;$565 = $564;$dest$pn$i$i82 = $$05$i$i83;
     }
    }
    $$pre$i86 = HEAP32[$334>>2]|0;
    $phitmp$i87 = (($$pre$i86) + -1)|0;
    $1166 = $$pre$i86;$568 = $phitmp$i87;
   }
  }
  $567 = (($559) + ($568<<2)|0);
  $569 = HEAP32[$567>>2]|0;
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($adjacencies,$569,$0);
  $570 = HEAP32[$70>>2]|0;
  $571 = HEAP32[$504>>2]|0;
  $572 = ($571|0)==(0);
  if (!($572)) {
   $573 = HEAP32[$502>>2]|0;
   $574 = HEAP32[$adjacencies>>2]|0;
   $$in1320$i92 = $573;$i3$021$i91 = 0;
   while(1) {
    $575 = (($$in1320$i92) + 4|0);
    $576 = HEAP32[$575>>2]|0;
    $577 = HEAP32[$$in1320$i92>>2]|0;
    $578 = (($559) + ($577<<2)|0);
    $579 = HEAP32[$578>>2]|0;
    $580 = (($579) + -1)|0;
    HEAP32[$578>>2] = $580;
    $581 = (($574) + ($580<<2)|0);
    HEAP32[$581>>2] = $576;
    $582 = (($$in1320$i92) + 8|0);
    $583 = HEAP32[$582>>2]|0;
    $584 = HEAP32[$$in1320$i92>>2]|0;
    $585 = (($559) + ($584<<2)|0);
    $586 = HEAP32[$585>>2]|0;
    $587 = (($586) + -1)|0;
    HEAP32[$585>>2] = $587;
    $588 = (($574) + ($587<<2)|0);
    HEAP32[$588>>2] = $583;
    $589 = HEAP32[$582>>2]|0;
    $590 = HEAP32[$575>>2]|0;
    $591 = (($559) + ($590<<2)|0);
    $592 = HEAP32[$591>>2]|0;
    $593 = (($592) + -1)|0;
    HEAP32[$591>>2] = $593;
    $594 = (($574) + ($593<<2)|0);
    HEAP32[$594>>2] = $589;
    $595 = HEAP32[$$in1320$i92>>2]|0;
    $596 = HEAP32[$575>>2]|0;
    $597 = (($559) + ($596<<2)|0);
    $598 = HEAP32[$597>>2]|0;
    $599 = (($598) + -1)|0;
    HEAP32[$597>>2] = $599;
    $600 = (($574) + ($599<<2)|0);
    HEAP32[$600>>2] = $595;
    $601 = HEAP32[$$in1320$i92>>2]|0;
    $602 = HEAP32[$582>>2]|0;
    $603 = (($559) + ($602<<2)|0);
    $604 = HEAP32[$603>>2]|0;
    $605 = (($604) + -1)|0;
    HEAP32[$603>>2] = $605;
    $606 = (($574) + ($605<<2)|0);
    HEAP32[$606>>2] = $601;
    $607 = HEAP32[$575>>2]|0;
    $608 = HEAP32[$582>>2]|0;
    $609 = (($559) + ($608<<2)|0);
    $610 = HEAP32[$609>>2]|0;
    $611 = (($610) + -1)|0;
    HEAP32[$609>>2] = $611;
    $612 = (($574) + ($611<<2)|0);
    HEAP32[$612>>2] = $607;
    $613 = (($i3$021$i91) + 1)|0;
    $614 = (($$in1320$i92) + ($570)|0);
    $615 = HEAP32[$504>>2]|0;
    $616 = ($613>>>0)<($615>>>0);
    if ($616) {
     $$in1320$i92 = $614;$i3$021$i91 = $613;
    } else {
     break;
    }
   }
  }
  $617 = HEAP32[$71>>2]|0;
  $618 = HEAP32[$529>>2]|0;
  $619 = ($618|0)==(0);
  if ($619) {
   $679 = $1166;$688 = $559;
  } else {
   $620 = HEAP32[$527>>2]|0;
   $621 = HEAP32[$adjacencies>>2]|0;
   $$in1416$i97 = $620;$i5$017$i96 = 0;
   while(1) {
    $622 = (($$in1416$i97) + 4|0);
    $623 = HEAP32[$622>>2]|0;
    $624 = HEAP32[$$in1416$i97>>2]|0;
    $625 = (($559) + ($624<<2)|0);
    $626 = HEAP32[$625>>2]|0;
    $627 = (($626) + -1)|0;
    HEAP32[$625>>2] = $627;
    $628 = (($621) + ($627<<2)|0);
    HEAP32[$628>>2] = $623;
    $629 = (($$in1416$i97) + 12|0);
    $630 = HEAP32[$629>>2]|0;
    $631 = HEAP32[$$in1416$i97>>2]|0;
    $632 = (($559) + ($631<<2)|0);
    $633 = HEAP32[$632>>2]|0;
    $634 = (($633) + -1)|0;
    HEAP32[$632>>2] = $634;
    $635 = (($621) + ($634<<2)|0);
    HEAP32[$635>>2] = $630;
    $636 = (($$in1416$i97) + 8|0);
    $637 = HEAP32[$636>>2]|0;
    $638 = HEAP32[$622>>2]|0;
    $639 = (($559) + ($638<<2)|0);
    $640 = HEAP32[$639>>2]|0;
    $641 = (($640) + -1)|0;
    HEAP32[$639>>2] = $641;
    $642 = (($621) + ($641<<2)|0);
    HEAP32[$642>>2] = $637;
    $643 = HEAP32[$$in1416$i97>>2]|0;
    $644 = HEAP32[$622>>2]|0;
    $645 = (($559) + ($644<<2)|0);
    $646 = HEAP32[$645>>2]|0;
    $647 = (($646) + -1)|0;
    HEAP32[$645>>2] = $647;
    $648 = (($621) + ($647<<2)|0);
    HEAP32[$648>>2] = $643;
    $649 = HEAP32[$629>>2]|0;
    $650 = HEAP32[$636>>2]|0;
    $651 = (($559) + ($650<<2)|0);
    $652 = HEAP32[$651>>2]|0;
    $653 = (($652) + -1)|0;
    HEAP32[$651>>2] = $653;
    $654 = (($621) + ($653<<2)|0);
    HEAP32[$654>>2] = $649;
    $655 = HEAP32[$622>>2]|0;
    $656 = HEAP32[$636>>2]|0;
    $657 = (($559) + ($656<<2)|0);
    $658 = HEAP32[$657>>2]|0;
    $659 = (($658) + -1)|0;
    HEAP32[$657>>2] = $659;
    $660 = (($621) + ($659<<2)|0);
    HEAP32[$660>>2] = $655;
    $661 = HEAP32[$$in1416$i97>>2]|0;
    $662 = HEAP32[$629>>2]|0;
    $663 = (($559) + ($662<<2)|0);
    $664 = HEAP32[$663>>2]|0;
    $665 = (($664) + -1)|0;
    HEAP32[$663>>2] = $665;
    $666 = (($621) + ($665<<2)|0);
    HEAP32[$666>>2] = $661;
    $667 = HEAP32[$636>>2]|0;
    $668 = HEAP32[$629>>2]|0;
    $669 = (($559) + ($668<<2)|0);
    $670 = HEAP32[$669>>2]|0;
    $671 = (($670) + -1)|0;
    HEAP32[$669>>2] = $671;
    $672 = (($621) + ($671<<2)|0);
    HEAP32[$672>>2] = $667;
    $673 = (($i5$017$i96) + 1)|0;
    $674 = (($$in1416$i97) + ($617)|0);
    $675 = HEAP32[$529>>2]|0;
    $676 = ($673>>>0)<($675>>>0);
    if ($676) {
     $$in1416$i97 = $674;$i5$017$i96 = $673;
    } else {
     $679 = $1166;$688 = $559;
     break;
    }
   }
  }
 } else {
  $341 = (($desc) + 28|0);
  $342 = HEAP32[$70>>2]|0;
  $343 = (($desc) + 32|0);
  $344 = HEAP32[$343>>2]|0;
  $345 = ($344|0)==(0);
  if (!($345)) {
   $346 = HEAP32[$341>>2]|0;
   $347 = HEAP32[$valency>>2]|0;
   $$in$i = $346;$i$033$i = 0;
   while(1) {
    $348 = HEAP16[$$in$i>>1]|0;
    $349 = $348&65535;
    $350 = (($347) + ($349<<2)|0);
    $351 = HEAP32[$350>>2]|0;
    $352 = (($351) + 2)|0;
    HEAP32[$350>>2] = $352;
    $353 = (($$in$i) + 2|0);
    $354 = HEAP16[$353>>1]|0;
    $355 = $354&65535;
    $356 = (($347) + ($355<<2)|0);
    $357 = HEAP32[$356>>2]|0;
    $358 = (($357) + 2)|0;
    HEAP32[$356>>2] = $358;
    $359 = (($$in$i) + 4|0);
    $360 = HEAP16[$359>>1]|0;
    $361 = $360&65535;
    $362 = (($347) + ($361<<2)|0);
    $363 = HEAP32[$362>>2]|0;
    $364 = (($363) + 2)|0;
    HEAP32[$362>>2] = $364;
    $365 = (($i$033$i) + 1)|0;
    $366 = (($$in$i) + ($342)|0);
    $367 = HEAP32[$343>>2]|0;
    $368 = ($365>>>0)<($367>>>0);
    if ($368) {
     $$in$i = $366;$i$033$i = $365;
    } else {
     break;
    }
   }
  }
  $369 = (($desc) + 40|0);
  $370 = HEAP32[$71>>2]|0;
  $371 = (($desc) + 44|0);
  $372 = HEAP32[$371>>2]|0;
  $373 = ($372|0)==(0);
  if ($373) {
   $$pre40$i63 = HEAP32[$valency>>2]|0;
   $405 = $$pre40$i63;
  } else {
   $374 = HEAP32[$369>>2]|0;
   $375 = HEAP32[$valency>>2]|0;
   $$in1225$i = $374;$i1$026$i = 0;
   while(1) {
    $376 = HEAP16[$$in1225$i>>1]|0;
    $377 = $376&65535;
    $378 = (($375) + ($377<<2)|0);
    $379 = HEAP32[$378>>2]|0;
    $380 = (($379) + 2)|0;
    HEAP32[$378>>2] = $380;
    $381 = (($$in1225$i) + 2|0);
    $382 = HEAP16[$381>>1]|0;
    $383 = $382&65535;
    $384 = (($375) + ($383<<2)|0);
    $385 = HEAP32[$384>>2]|0;
    $386 = (($385) + 2)|0;
    HEAP32[$384>>2] = $386;
    $387 = (($$in1225$i) + 4|0);
    $388 = HEAP16[$387>>1]|0;
    $389 = $388&65535;
    $390 = (($375) + ($389<<2)|0);
    $391 = HEAP32[$390>>2]|0;
    $392 = (($391) + 2)|0;
    HEAP32[$390>>2] = $392;
    $393 = (($$in1225$i) + 6|0);
    $394 = HEAP16[$393>>1]|0;
    $395 = $394&65535;
    $396 = (($375) + ($395<<2)|0);
    $397 = HEAP32[$396>>2]|0;
    $398 = (($397) + 2)|0;
    HEAP32[$396>>2] = $398;
    $399 = (($i1$026$i) + 1)|0;
    $400 = (($$in1225$i) + ($370)|0);
    $401 = HEAP32[$371>>2]|0;
    $402 = ($399>>>0)<($401>>>0);
    if ($402) {
     $$in1225$i = $400;$i1$026$i = $399;
    } else {
     $405 = $375;
     break;
    }
   }
  }
  $403 = HEAP32[$334>>2]|0;
  $404 = (($405) + ($403<<2)|0);
  $406 = ($403|0)==(0);
  if ($406) {
   $1165 = 0;$414 = -1;
  } else {
   $407 = ($403|0)==(1);
   if ($407) {
    $1165 = 1;$414 = 0;
   } else {
    $$013$i$i = (($405) + 4|0);
    $408 = HEAP32[$405>>2]|0;
    $$016$i$i = $$013$i$i;$411 = $408;$dest$pn$i$i = $405;
    while(1) {
     $$05$i$i = (($dest$pn$i$i) + 4|0);
     $409 = HEAP32[$$016$i$i>>2]|0;
     $410 = (($409) + ($411))|0;
     HEAP32[$$05$i$i>>2] = $410;
     $$01$i$i = (($$016$i$i) + 4|0);
     $412 = ($$01$i$i|0)==($404|0);
     if ($412) {
      break;
     } else {
      $$016$i$i = $$01$i$i;$411 = $410;$dest$pn$i$i = $$05$i$i;
     }
    }
    $$pre$i64 = HEAP32[$334>>2]|0;
    $phitmp$i65 = (($$pre$i64) + -1)|0;
    $1165 = $$pre$i64;$414 = $phitmp$i65;
   }
  }
  $413 = (($405) + ($414<<2)|0);
  $415 = HEAP32[$413>>2]|0;
  HEAP32[$1>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($adjacencies,$415,$1);
  $416 = HEAP32[$70>>2]|0;
  $417 = HEAP32[$343>>2]|0;
  $418 = ($417|0)==(0);
  if (!($418)) {
   $419 = HEAP32[$341>>2]|0;
   $420 = HEAP32[$adjacencies>>2]|0;
   $$in1320$i = $419;$i3$021$i = 0;
   while(1) {
    $421 = (($$in1320$i) + 2|0);
    $422 = HEAP16[$421>>1]|0;
    $423 = $422&65535;
    $424 = HEAP16[$$in1320$i>>1]|0;
    $425 = $424&65535;
    $426 = (($405) + ($425<<2)|0);
    $427 = HEAP32[$426>>2]|0;
    $428 = (($427) + -1)|0;
    HEAP32[$426>>2] = $428;
    $429 = (($420) + ($428<<2)|0);
    HEAP32[$429>>2] = $423;
    $430 = (($$in1320$i) + 4|0);
    $431 = HEAP16[$430>>1]|0;
    $432 = $431&65535;
    $433 = HEAP32[$426>>2]|0;
    $434 = (($433) + -1)|0;
    HEAP32[$426>>2] = $434;
    $435 = (($420) + ($434<<2)|0);
    HEAP32[$435>>2] = $432;
    $436 = (($405) + ($423<<2)|0);
    $437 = HEAP32[$436>>2]|0;
    $438 = (($437) + -1)|0;
    HEAP32[$436>>2] = $438;
    $439 = (($420) + ($438<<2)|0);
    HEAP32[$439>>2] = $432;
    $440 = HEAP32[$436>>2]|0;
    $441 = (($440) + -1)|0;
    HEAP32[$436>>2] = $441;
    $442 = (($420) + ($441<<2)|0);
    HEAP32[$442>>2] = $425;
    $443 = (($405) + ($432<<2)|0);
    $444 = HEAP32[$443>>2]|0;
    $445 = (($444) + -1)|0;
    HEAP32[$443>>2] = $445;
    $446 = (($420) + ($445<<2)|0);
    HEAP32[$446>>2] = $425;
    $447 = HEAP32[$443>>2]|0;
    $448 = (($447) + -1)|0;
    HEAP32[$443>>2] = $448;
    $449 = (($420) + ($448<<2)|0);
    HEAP32[$449>>2] = $423;
    $450 = (($i3$021$i) + 1)|0;
    $451 = (($$in1320$i) + ($416)|0);
    $452 = HEAP32[$343>>2]|0;
    $453 = ($450>>>0)<($452>>>0);
    if ($453) {
     $$in1320$i = $451;$i3$021$i = $450;
    } else {
     break;
    }
   }
  }
  $454 = HEAP32[$71>>2]|0;
  $455 = HEAP32[$371>>2]|0;
  $456 = ($455|0)==(0);
  if ($456) {
   $679 = $1165;$688 = $405;
  } else {
   $457 = HEAP32[$369>>2]|0;
   $458 = HEAP32[$adjacencies>>2]|0;
   $$in1416$i = $457;$i5$017$i = 0;
   while(1) {
    $459 = (($$in1416$i) + 2|0);
    $460 = HEAP16[$459>>1]|0;
    $461 = $460&65535;
    $462 = HEAP16[$$in1416$i>>1]|0;
    $463 = $462&65535;
    $464 = (($405) + ($463<<2)|0);
    $465 = HEAP32[$464>>2]|0;
    $466 = (($465) + -1)|0;
    HEAP32[$464>>2] = $466;
    $467 = (($458) + ($466<<2)|0);
    HEAP32[$467>>2] = $461;
    $468 = (($$in1416$i) + 6|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = $469&65535;
    $471 = HEAP32[$464>>2]|0;
    $472 = (($471) + -1)|0;
    HEAP32[$464>>2] = $472;
    $473 = (($458) + ($472<<2)|0);
    HEAP32[$473>>2] = $470;
    $474 = (($$in1416$i) + 4|0);
    $475 = HEAP16[$474>>1]|0;
    $476 = $475&65535;
    $477 = (($405) + ($461<<2)|0);
    $478 = HEAP32[$477>>2]|0;
    $479 = (($478) + -1)|0;
    HEAP32[$477>>2] = $479;
    $480 = (($458) + ($479<<2)|0);
    HEAP32[$480>>2] = $476;
    $481 = HEAP32[$477>>2]|0;
    $482 = (($481) + -1)|0;
    HEAP32[$477>>2] = $482;
    $483 = (($458) + ($482<<2)|0);
    HEAP32[$483>>2] = $463;
    $484 = (($405) + ($476<<2)|0);
    $485 = HEAP32[$484>>2]|0;
    $486 = (($485) + -1)|0;
    HEAP32[$484>>2] = $486;
    $487 = (($458) + ($486<<2)|0);
    HEAP32[$487>>2] = $470;
    $488 = HEAP32[$484>>2]|0;
    $489 = (($488) + -1)|0;
    HEAP32[$484>>2] = $489;
    $490 = (($458) + ($489<<2)|0);
    HEAP32[$490>>2] = $461;
    $491 = (($405) + ($470<<2)|0);
    $492 = HEAP32[$491>>2]|0;
    $493 = (($492) + -1)|0;
    HEAP32[$491>>2] = $493;
    $494 = (($458) + ($493<<2)|0);
    HEAP32[$494>>2] = $463;
    $495 = HEAP32[$491>>2]|0;
    $496 = (($495) + -1)|0;
    HEAP32[$491>>2] = $496;
    $497 = (($458) + ($496<<2)|0);
    HEAP32[$497>>2] = $476;
    $498 = (($i5$017$i) + 1)|0;
    $499 = (($$in1416$i) + ($454)|0);
    $500 = HEAP32[$371>>2]|0;
    $501 = ($498>>>0)<($500>>>0);
    if ($501) {
     $$in1416$i = $499;$i5$017$i = $498;
    } else {
     $679 = $1165;$688 = $405;
     break;
    }
   }
  }
 }
 HEAP32[$14>>2] = 0;
 HEAP32[$mark>>2] = 0;
 $677 = (($mark) + 4|0);
 HEAP32[$677>>2] = 0;
 $678 = (($mark) + 8|0);
 HEAP32[$678>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($mark,$679,$14);
 HEAP32[$neighbors>>2] = 0;
 $680 = (($neighbors) + 4|0);
 HEAP32[$680>>2] = 0;
 $681 = (($neighbors) + 8|0);
 HEAP32[$681>>2] = 0;
 $682 = HEAP32[$336>>2]|0;
 $683 = ($682|0)==(0);
 if (!($683)) {
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($neighbors,$682);
 }
 $684 = ($679>>>0)>(1);
 if ($684) {
  $685 = HEAP32[$adjacencies>>2]|0;
  $686 = HEAP32[$mark>>2]|0;
  $i1$0265 = 1;$j$0264 = 0;
  while(1) {
   $687 = (($688) + ($i1$0265<<2)|0);
   $689 = HEAP32[$687>>2]|0;
   $690 = ($j$0264>>>0)<($689>>>0);
   if ($690) {
    $j$1259 = $j$0264;
    while(1) {
     $691 = (($685) + ($j$1259<<2)|0);
     $692 = HEAP32[$691>>2]|0;
     HEAP32[$k>>2] = $692;
     $693 = (($686) + ($692<<2)|0);
     $694 = HEAP32[$693>>2]|0;
     $695 = ($694|0)==($i1$0265|0);
     do {
      if (!($695)) {
       HEAP32[$693>>2] = $i1$0265;
       $696 = HEAP32[$681>>2]|0;
       $697 = $696 & 2147483647;
       $698 = HEAP32[$680>>2]|0;
       $699 = ($697>>>0)>($698>>>0);
       if (!($699)) {
        (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($neighbors,$k)|0);
        break;
       }
       $700 = HEAP32[$neighbors>>2]|0;
       $701 = (($700) + ($698<<2)|0);
       $702 = ($701|0)==(0|0);
       if (!($702)) {
        HEAP32[$701>>2] = $692;
       }
       $703 = (($698) + 1)|0;
       HEAP32[$680>>2] = $703;
      }
     } while(0);
     $704 = (($j$1259) + 1)|0;
     $705 = HEAP32[$687>>2]|0;
     $706 = ($704>>>0)<($705>>>0);
     if ($706) {
      $j$1259 = $704;
     } else {
      $j$1$lcssa = $704;
      break;
     }
    }
   } else {
    $j$1$lcssa = $j$0264;
   }
   $707 = HEAP32[$680>>2]|0;
   HEAP32[$687>>2] = $707;
   $708 = (($i1$0265) + 1)|0;
   $709 = HEAP32[$334>>2]|0;
   $710 = ($708>>>0)<($709>>>0);
   if ($710) {
    $i1$0265 = $708;$j$0264 = $j$1$lcssa;
   } else {
    break;
   }
  }
 }
 $711 = HEAP32[$29>>2]|0;
 HEAP32[$15>>2] = 0;
 HEAP32[$vertexIsland>>2] = 0;
 $712 = (($vertexIsland) + 4|0);
 HEAP32[$712>>2] = 0;
 $713 = (($vertexIsland) + 8|0);
 HEAP32[$713>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($vertexIsland,$711,$15);
 HEAP32[$vertexIslandHeap>>2] = 0;
 $714 = (($vertexIslandHeap) + 4|0);
 HEAP32[$714>>2] = 0;
 $715 = (($vertexIslandHeap) + 8|0);
 HEAP32[$715>>2] = 0;
 $716 = HEAP32[$29>>2]|0;
 $717 = ($716|0)==(0);
 if (!($717)) {
  $718 = HEAP32[$vertexIsland>>2]|0;
  $719 = (($16) + 4|0);
  $720 = (($16) + 8|0);
  $i2$0253 = 0;
  while(1) {
   $721 = (($718) + ($i2$0253<<2)|0);
   HEAP32[$721>>2] = -1;
   $722 = HEAP32[$34>>2]|0;
   $723 = (($722) + ($i2$0253)|0);
   $724 = HEAP8[$723>>0]|0;
   $725 = ($724<<24>>24)==(0);
   do {
    if (!($725)) {
     HEAP32[$16>>2] = $i2$0253;
     HEAPF32[$719>>2] = Math_fround(3.40282346638528859812E+38);
     HEAP32[$720>>2] = 0;
     $this$idx$val$i = HEAP32[$715>>2]|0;
     $726 = $this$idx$val$i & 2147483647;
     $727 = HEAP32[$714>>2]|0;
     $728 = ($726>>>0)>($727>>>0);
     if (!($728)) {
      (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_119VertexDistanceCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($vertexIslandHeap,$16)|0);
      break;
     }
     $729 = HEAP32[$vertexIslandHeap>>2]|0;
     $730 = (($729) + (($727*12)|0)|0);
     $731 = ($730|0)==(0|0);
     if (!($731)) {
      ;HEAP32[$730+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$730+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$730+8>>2]=HEAP32[$16+8>>2]|0;
     }
     $732 = (($727) + 1)|0;
     HEAP32[$714>>2] = $732;
    }
   } while(0);
   $733 = (($i2$0253) + 1)|0;
   $734 = HEAP32[$29>>2]|0;
   $735 = ($733>>>0)<($734>>>0);
   if ($735) {
    $i2$0253 = $733;
   } else {
    break;
   }
  }
  $vertexIslandHeap$idx$val$pre = HEAP32[$714>>2]|0;
  $736 = ($vertexIslandHeap$idx$val$pre|0)==(0);
  if (!($736)) {
   HEAP32[$islandIndices>>2] = 0;
   $737 = (($islandIndices) + 4|0);
   HEAP32[$737>>2] = 0;
   $738 = (($islandIndices) + 8|0);
   HEAP32[$738>>2] = 0;
   HEAP32[$islandFirst>>2] = 0;
   $739 = (($islandFirst) + 4|0);
   HEAP32[$739>>2] = 0;
   $740 = (($islandFirst) + 8|0);
   HEAP32[$740>>2] = 0;
   HEAP32[$islandIndexCnt>>2] = 0;
   __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($islandIndices,$vertexIslandHeap$idx$val$pre);
   $741 = (($vertexIslandHeap$idx$val$pre) + 1)|0;
   $742 = ($741|0)==(0);
   if (!($742)) {
    __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($islandFirst,$741);
   }
   $743 = HEAP32[$vertexIsland>>2]|0;
   $744 = HEAP32[$neighbors>>2]|0;
   $745 = (($19) + 4|0);
   $746 = (($19) + 8|0);
   $heap$idx$val$i127$pre = HEAP32[$vertexIslandHeap>>2]|0;
   $770 = 0;$heap$idx$val$i127 = $heap$idx$val$i127$pre;$heap$idx2$val$i129 = $vertexIslandHeap$idx$val$pre;$islandCnt$0251 = 0;
   while(1) {
    $$sum7$i130 = (($heap$idx2$val$i129) + -1)|0;
    $748 = (($heap$idx$val$i127) + (($$sum7$i130*12)|0)|0);
    ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$heap$idx$val$i127+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$heap$idx$val$i127+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$heap$idx$val$i127+8>>2]|0;
    ;HEAP32[$heap$idx$val$i127+0>>2]=HEAP32[$748+0>>2]|0;HEAP32[$heap$idx$val$i127+4>>2]=HEAP32[$748+4>>2]|0;HEAP32[$heap$idx$val$i127+8>>2]=HEAP32[$748+8>>2]|0;
    ;HEAP32[$748+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$748+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$748+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
    $749 = ($$sum7$i130|0)>(1);
    L268: do {
     if ($749) {
      $750 = 1;$current$08$i132 = 0;
      while(1) {
       $$sum$i133 = (($750) + 1)|0;
       $751 = ($$sum$i133|0)<($$sum7$i130|0);
       if ($751) {
        $$idx4$i134 = ((($heap$idx$val$i127) + (($750*12)|0)|0) + 4|0);
        $$idx4$val$i135 = Math_fround(HEAPF32[$$idx4$i134>>2]);
        $$idx5$i136 = ((($heap$idx$val$i127) + (($$sum$i133*12)|0)|0) + 4|0);
        $$idx5$val$i137 = Math_fround(HEAPF32[$$idx5$i136>>2]);
        $752 = $$idx5$val$i137 < $$idx4$val$i135;
        $$$i138 = $752 ? $$sum$i133 : $750;
        $child$0$i139 = $$$i138;
       } else {
        $child$0$i139 = $750;
       }
       $$idx$i140 = ((($heap$idx$val$i127) + (($current$08$i132*12)|0)|0) + 4|0);
       $$idx$val$i141 = Math_fround(HEAPF32[$$idx$i140>>2]);
       $$idx3$i142 = ((($heap$idx$val$i127) + (($child$0$i139*12)|0)|0) + 4|0);
       $$idx3$val$i143 = Math_fround(HEAPF32[$$idx3$i142>>2]);
       $753 = $$idx3$val$i143 < $$idx$val$i141;
       if (!($753)) {
        break L268;
       }
       $754 = (($heap$idx$val$i127) + (($child$0$i139*12)|0)|0);
       $755 = (($heap$idx$val$i127) + (($current$08$i132*12)|0)|0);
       ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$755+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$755+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$755+8>>2]|0;
       ;HEAP32[$755+0>>2]=HEAP32[$754+0>>2]|0;HEAP32[$755+4>>2]=HEAP32[$754+4>>2]|0;HEAP32[$755+8>>2]=HEAP32[$754+8>>2]|0;
       ;HEAP32[$754+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$754+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$754+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
       $756 = $child$0$i139 << 1;
       $757 = $756 | 1;
       $758 = ($757|0)<($$sum7$i130|0);
       if ($758) {
        $750 = $757;$current$08$i132 = $child$0$i139;
       } else {
        break;
       }
      }
     }
    } while(0);
    $759 = HEAP32[$714>>2]|0;
    $760 = (($759) + -1)|0;
    $761 = HEAP32[$vertexIslandHeap>>2]|0;
    $762 = (($761) + (($760*12)|0)|0);
    $763 = HEAP32[$762>>2]|0;
    $764 = ((($761) + (($760*12)|0)|0) + 4|0);
    $765 = Math_fround(HEAPF32[$764>>2]);
    HEAP32[$714>>2] = $760;
    $766 = (($743) + ($763<<2)|0);
    $767 = HEAP32[$766>>2]|0;
    $768 = ($767|0)==(-1);
    do {
     if ($768) {
      $769 = (($770) + 1)|0;
      HEAP32[$islandIndexCnt>>2] = $769;
      HEAP32[$17>>2] = $770;
      $771 = HEAP32[$740>>2]|0;
      $772 = $771 & 2147483647;
      $773 = HEAP32[$739>>2]|0;
      $774 = ($772>>>0)>($773>>>0);
      if ($774) {
       $775 = HEAP32[$islandFirst>>2]|0;
       $776 = (($775) + ($773<<2)|0);
       $777 = ($776|0)==(0|0);
       if (!($777)) {
        HEAP32[$776>>2] = $770;
       }
       $778 = (($773) + 1)|0;
       HEAP32[$739>>2] = $778;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($islandFirst,$17)|0);
      }
      $779 = (($islandCnt$0251) + 1)|0;
      HEAP32[$766>>2] = $islandCnt$0251;
      HEAP32[$18>>2] = $763;
      $780 = HEAP32[$738>>2]|0;
      $781 = $780 & 2147483647;
      $782 = HEAP32[$737>>2]|0;
      $783 = ($781>>>0)>($782>>>0);
      if (!($783)) {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($islandIndices,$18)|0);
       $1167 = $769;$795 = Math_fround(0.0);$islandCnt$1 = $779;
       break;
      }
      $784 = HEAP32[$islandIndices>>2]|0;
      $785 = (($784) + ($782<<2)|0);
      $786 = ($785|0)==(0|0);
      if (!($786)) {
       HEAP32[$785>>2] = $763;
      }
      $787 = (($782) + 1)|0;
      HEAP32[$737>>2] = $787;
      $1167 = $769;$795 = Math_fround(0.0);$islandCnt$1 = $779;
     } else {
      $1167 = $770;$795 = $765;$islandCnt$1 = $islandCnt$0251;
     }
    } while(0);
    $788 = (($688) + ($763<<2)|0);
    $789 = HEAP32[$788>>2]|0;
    $790 = (($763) + 1)|0;
    $791 = (($688) + ($790<<2)|0);
    $792 = HEAP32[$791>>2]|0;
    $793 = ($789>>>0)<($792>>>0);
    if ($793) {
     $794 = Math_fround($795 + Math_fround(1.0));
     $814 = $1167;$820 = $760;$822 = $761;$j3$0248 = $789;
     while(1) {
      $796 = (($744) + ($j3$0248<<2)|0);
      $797 = HEAP32[$796>>2]|0;
      HEAP32[$vj>>2] = $797;
      $798 = HEAP32[$34>>2]|0;
      $799 = (($798) + ($797)|0);
      $800 = HEAP8[$799>>0]|0;
      $801 = ($800<<24>>24)==(0);
      L296: do {
       if ($801) {
        $1168 = $814;$heap$idx$val$i127294 = $822;$vertexIslandHeap$idx8$val298 = $820;
       } else {
        $802 = (($743) + ($797<<2)|0);
        $803 = HEAP32[$802>>2]|0;
        $804 = ($803|0)==(-1);
        if ($804) {
         $805 = HEAP32[$738>>2]|0;
         $806 = $805 & 2147483647;
         $807 = HEAP32[$737>>2]|0;
         $808 = ($806>>>0)>($807>>>0);
         if ($808) {
          $809 = HEAP32[$islandIndices>>2]|0;
          $810 = (($809) + ($807<<2)|0);
          $811 = ($810|0)==(0|0);
          if (!($811)) {
           HEAP32[$810>>2] = $797;
          }
          $812 = (($807) + 1)|0;
          HEAP32[$737>>2] = $812;
          $817 = $797;
         } else {
          (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($islandIndices,$vj)|0);
          $$pre = HEAP32[$vj>>2]|0;
          $817 = $$pre;
         }
         $813 = (($814) + 1)|0;
         HEAP32[$islandIndexCnt>>2] = $813;
         $815 = HEAP32[$766>>2]|0;
         $816 = (($743) + ($817<<2)|0);
         HEAP32[$816>>2] = $815;
         HEAP32[$19>>2] = $817;
         HEAPF32[$745>>2] = $794;
         HEAP32[$746>>2] = 0;
         $this$idx$val$i$i202 = HEAP32[$715>>2]|0;
         $818 = $this$idx$val$i$i202 & 2147483647;
         $819 = ($818>>>0)>($820>>>0);
         if ($819) {
          $821 = (($822) + (($820*12)|0)|0);
          $823 = ($821|0)==(0|0);
          if ($823) {
           $825 = $820;
          } else {
           ;HEAP32[$821+0>>2]=HEAP32[$19+0>>2]|0;HEAP32[$821+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$821+8>>2]=HEAP32[$19+8>>2]|0;
           $$pre$i$i205 = HEAP32[$714>>2]|0;
           $825 = $$pre$i$i205;
          }
          $824 = (($825) + 1)|0;
          HEAP32[$714>>2] = $824;
          $heap$idx2$val$i207 = $824;
         } else {
          (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_119VertexDistanceCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($vertexIslandHeap,$19)|0);
          $heap$idx2$val$pre$i203 = HEAP32[$714>>2]|0;
          $heap$idx2$val$i207 = $heap$idx2$val$pre$i203;
         }
         $heap$idx$val$i208 = HEAP32[$vertexIslandHeap>>2]|0;
         $826 = ($heap$idx2$val$i207|0)>(0);
         if (!($826)) {
          $1168 = $813;$heap$idx$val$i127294 = $heap$idx$val$i208;$vertexIslandHeap$idx8$val298 = $heap$idx2$val$i207;
          break;
         }
         $$idx4$i210 = ($heap$idx2$val$i207*12)|0;
         $827 = (($$idx4$i210|0) / 12)&-1;
         $828 = (($827) + -1)|0;
         $829 = ($828|0)==(0);
         if ($829) {
          $1168 = $813;$heap$idx$val$i127294 = $heap$idx$val$i208;$vertexIslandHeap$idx8$val298 = $heap$idx2$val$i207;
          break;
         } else {
          $current$05$i212 = $828;
         }
         while(1) {
          $830 = (($current$05$i212) + -1)|0;
          $831 = $830 >>> 1;
          $$idx$i213 = ((($heap$idx$val$i208) + (($831*12)|0)|0) + 4|0);
          $$idx$val$i214 = Math_fround(HEAPF32[$$idx$i213>>2]);
          $$idx3$i215 = ((($heap$idx$val$i208) + (($current$05$i212*12)|0)|0) + 4|0);
          $$idx3$val$i216 = Math_fround(HEAPF32[$$idx3$i215>>2]);
          $832 = $$idx3$val$i216 < $$idx$val$i214;
          if (!($832)) {
           $1168 = $813;$heap$idx$val$i127294 = $heap$idx$val$i208;$vertexIslandHeap$idx8$val298 = $heap$idx2$val$i207;
           break L296;
          }
          $833 = (($heap$idx$val$i208) + (($current$05$i212*12)|0)|0);
          $834 = (($heap$idx$val$i208) + (($831*12)|0)|0);
          ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$834+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$834+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$834+8>>2]|0;
          ;HEAP32[$834+0>>2]=HEAP32[$833+0>>2]|0;HEAP32[$834+4>>2]=HEAP32[$833+4>>2]|0;HEAP32[$834+8>>2]=HEAP32[$833+8>>2]|0;
          ;HEAP32[$833+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$833+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$833+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
          $835 = ($831|0)==(0);
          if ($835) {
           $1168 = $813;$heap$idx$val$i127294 = $heap$idx$val$i208;$vertexIslandHeap$idx8$val298 = $heap$idx2$val$i207;
           break;
          } else {
           $current$05$i212 = $831;
          }
         }
        } else {
         $1168 = $814;$heap$idx$val$i127294 = $822;$vertexIslandHeap$idx8$val298 = $820;
        }
       }
      } while(0);
      $836 = (($j3$0248) + 1)|0;
      $exitcond277 = ($836|0)==($792|0);
      if ($exitcond277) {
       $844 = $1168;$heap$idx$val$i127293 = $heap$idx$val$i127294;$vertexIslandHeap$idx8$val = $vertexIslandHeap$idx8$val298;
       break;
      } else {
       $814 = $1168;$820 = $vertexIslandHeap$idx8$val298;$822 = $heap$idx$val$i127294;$j3$0248 = $836;
      }
     }
    } else {
     $844 = $1167;$heap$idx$val$i127293 = $761;$vertexIslandHeap$idx8$val = $760;
    }
    $747 = ($vertexIslandHeap$idx8$val|0)==(0);
    if ($747) {
     break;
    } else {
     $770 = $844;$heap$idx$val$i127 = $heap$idx$val$i127293;$heap$idx2$val$i129 = $vertexIslandHeap$idx8$val;$islandCnt$0251 = $islandCnt$1;
    }
   }
   $837 = HEAP32[$740>>2]|0;
   $838 = $837 & 2147483647;
   $839 = HEAP32[$739>>2]|0;
   $840 = ($838>>>0)>($839>>>0);
   if ($840) {
    $841 = HEAP32[$islandFirst>>2]|0;
    $842 = (($841) + ($839<<2)|0);
    $843 = ($842|0)==(0|0);
    if (!($843)) {
     HEAP32[$842>>2] = $844;
    }
    $845 = (($839) + 1)|0;
    HEAP32[$739>>2] = $845;
   } else {
    (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($islandFirst,$islandIndexCnt)|0);
   }
   $846 = HEAP32[$29>>2]|0;
   $847 = Math_imul($846, $islandCnt$1)|0;
   HEAPF32[$20>>2] = Math_fround(3.40282346638528859812E+38);
   HEAP32[$vertexDistanceBuffer>>2] = 0;
   $848 = (($vertexDistanceBuffer) + 4|0);
   HEAP32[$848>>2] = 0;
   $849 = (($vertexDistanceBuffer) + 8|0);
   HEAP32[$849>>2] = 0;
   __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($vertexDistanceBuffer,$847,$20);
   HEAP32[$21>>2] = 0;
   HEAP32[$vertexParentBuffer>>2] = 0;
   $850 = (($vertexParentBuffer) + 4|0);
   HEAP32[$850>>2] = 0;
   $851 = (($vertexParentBuffer) + 8|0);
   HEAP32[$851>>2] = 0;
   __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($vertexParentBuffer,$847,$21);
   HEAP32[$vertexHeap>>2] = 0;
   $852 = (($vertexHeap) + 4|0);
   HEAP32[$852>>2] = 0;
   $853 = (($vertexHeap) + 8|0);
   HEAP32[$853>>2] = 0;
   $854 = ($islandCnt$1|0)==(0);
   if (!($854)) {
    $855 = HEAP32[$vertexDistanceBuffer>>2]|0;
    $856 = HEAP32[$vertexParentBuffer>>2]|0;
    $857 = HEAP32[$islandFirst>>2]|0;
    $858 = HEAP32[$neighbors>>2]|0;
    $859 = (($23) + 4|0);
    $860 = (($23) + 8|0);
    $861 = HEAP32[$islandIndices>>2]|0;
    $862 = (($22) + 4|0);
    $863 = (($22) + 8|0);
    $i4$0245 = 0;
    while(1) {
     HEAP32[$852>>2] = 0;
     $864 = HEAP32[$29>>2]|0;
     $865 = Math_imul($864, $i4$0245)|0;
     $866 = ($864|0)==(0);
     if (!($866)) {
      $j5$0232 = 0;
      while(1) {
       $$sum5 = (($j5$0232) + ($865))|0;
       $867 = (($856) + ($$sum5<<2)|0);
       HEAP32[$867>>2] = $j5$0232;
       $868 = (($855) + ($$sum5<<2)|0);
       HEAPF32[$868>>2] = Math_fround(3.40282346638528859812E+38);
       $869 = (($j5$0232) + 1)|0;
       $870 = HEAP32[$29>>2]|0;
       $871 = ($869>>>0)<($870>>>0);
       if ($871) {
        $j5$0232 = $869;
       } else {
        break;
       }
      }
     }
     $872 = (($857) + ($i4$0245<<2)|0);
     $873 = HEAP32[$872>>2]|0;
     $874 = (($i4$0245) + 1)|0;
     $875 = (($857) + ($874<<2)|0);
     $876 = HEAP32[$875>>2]|0;
     $877 = ($873>>>0)<($876>>>0);
     if ($877) {
      $883 = 0;$j6$0236 = $873;
      while(1) {
       $878 = (($861) + ($j6$0236<<2)|0);
       $879 = HEAP32[$878>>2]|0;
       $$sum4 = (($879) + ($865))|0;
       $880 = (($855) + ($$sum4<<2)|0);
       HEAPF32[$880>>2] = Math_fround(0.0);
       HEAP32[$22>>2] = $879;
       HEAPF32[$862>>2] = Math_fround(0.0);
       HEAP32[$863>>2] = 0;
       $this$idx$val$i191 = HEAP32[$853>>2]|0;
       $881 = $this$idx$val$i191 & 2147483647;
       $882 = ($881>>>0)>($883>>>0);
       if ($882) {
        $884 = HEAP32[$vertexHeap>>2]|0;
        $885 = (($884) + (($883*12)|0)|0);
        $886 = ($885|0)==(0|0);
        if (!($886)) {
         ;HEAP32[$885+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$885+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$885+8>>2]=HEAP32[$22+8>>2]|0;
        }
        $887 = (($883) + 1)|0;
        HEAP32[$852>>2] = $887;
       } else {
        (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_119VertexDistanceCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($vertexHeap,$22)|0);
       }
       $888 = (($j6$0236) + 1)|0;
       $exitcond274 = ($888|0)==($876|0);
       $vertexHeap$idx7$val$pre = HEAP32[$852>>2]|0;
       if ($exitcond274) {
        break;
       } else {
        $883 = $vertexHeap$idx7$val$pre;$j6$0236 = $888;
       }
      }
      $889 = ($vertexHeap$idx7$val$pre|0)==(0);
      if (!($889)) {
       $heap$idx$val$i172$pre = HEAP32[$vertexHeap>>2]|0;
       $heap$idx$val$i172 = $heap$idx$val$i172$pre;$heap$idx2$val$i174 = $vertexHeap$idx7$val$pre;
       while(1) {
        $$sum7$i175 = (($heap$idx2$val$i174) + -1)|0;
        $891 = (($heap$idx$val$i172) + (($$sum7$i175*12)|0)|0);
        ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$heap$idx$val$i172+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$heap$idx$val$i172+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$heap$idx$val$i172+8>>2]|0;
        ;HEAP32[$heap$idx$val$i172+0>>2]=HEAP32[$891+0>>2]|0;HEAP32[$heap$idx$val$i172+4>>2]=HEAP32[$891+4>>2]|0;HEAP32[$heap$idx$val$i172+8>>2]=HEAP32[$891+8>>2]|0;
        ;HEAP32[$891+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$891+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$891+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
        $892 = ($$sum7$i175|0)>(1);
        L349: do {
         if ($892) {
          $893 = 1;$current$08$i177 = 0;
          while(1) {
           $$sum$i178 = (($893) + 1)|0;
           $894 = ($$sum$i178|0)<($$sum7$i175|0);
           if ($894) {
            $$idx4$i179 = ((($heap$idx$val$i172) + (($893*12)|0)|0) + 4|0);
            $$idx4$val$i180 = Math_fround(HEAPF32[$$idx4$i179>>2]);
            $$idx5$i181 = ((($heap$idx$val$i172) + (($$sum$i178*12)|0)|0) + 4|0);
            $$idx5$val$i182 = Math_fround(HEAPF32[$$idx5$i181>>2]);
            $895 = $$idx5$val$i182 < $$idx4$val$i180;
            $$$i183 = $895 ? $$sum$i178 : $893;
            $child$0$i184 = $$$i183;
           } else {
            $child$0$i184 = $893;
           }
           $$idx$i185 = ((($heap$idx$val$i172) + (($current$08$i177*12)|0)|0) + 4|0);
           $$idx$val$i186 = Math_fround(HEAPF32[$$idx$i185>>2]);
           $$idx3$i187 = ((($heap$idx$val$i172) + (($child$0$i184*12)|0)|0) + 4|0);
           $$idx3$val$i188 = Math_fround(HEAPF32[$$idx3$i187>>2]);
           $896 = $$idx3$val$i188 < $$idx$val$i186;
           if (!($896)) {
            break L349;
           }
           $897 = (($heap$idx$val$i172) + (($child$0$i184*12)|0)|0);
           $898 = (($heap$idx$val$i172) + (($current$08$i177*12)|0)|0);
           ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$898+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$898+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$898+8>>2]|0;
           ;HEAP32[$898+0>>2]=HEAP32[$897+0>>2]|0;HEAP32[$898+4>>2]=HEAP32[$897+4>>2]|0;HEAP32[$898+8>>2]=HEAP32[$897+8>>2]|0;
           ;HEAP32[$897+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$897+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$897+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
           $899 = $child$0$i184 << 1;
           $900 = $899 | 1;
           $901 = ($900|0)<($$sum7$i175|0);
           if ($901) {
            $893 = $900;$current$08$i177 = $child$0$i184;
           } else {
            break;
           }
          }
         }
        } while(0);
        $902 = HEAP32[$852>>2]|0;
        $903 = (($902) + -1)|0;
        $904 = HEAP32[$vertexHeap>>2]|0;
        $905 = (($904) + (($903*12)|0)|0);
        $906 = HEAP32[$905>>2]|0;
        $907 = ((($904) + (($903*12)|0)|0) + 4|0);
        $908 = Math_fround(HEAPF32[$907>>2]);
        HEAP32[$852>>2] = $903;
        $$sum = (($906) + ($865))|0;
        $909 = (($855) + ($$sum<<2)|0);
        $910 = Math_fround(HEAPF32[$909>>2]);
        $911 = $908 > $910;
        do {
         if ($911) {
          $heap$idx$val$i172286 = $904;$vertexHeap$idx$val$pr = $903;
         } else {
          $912 = (($688) + ($906<<2)|0);
          $913 = HEAP32[$912>>2]|0;
          $914 = (($906) + 1)|0;
          $915 = (($688) + ($914<<2)|0);
          $916 = HEAP32[$915>>2]|0;
          $917 = ($913|0)<($916|0);
          if (!($917)) {
           $heap$idx$val$i172286 = $904;$vertexHeap$idx$val$pr = $903;
           break;
          }
          $918 = (($856) + ($$sum<<2)|0);
          $951 = $903;$953 = $904;$j11$0240 = $913;
          while(1) {
           $919 = (($858) + ($j11$0240<<2)|0);
           $920 = HEAP32[$919>>2]|0;
           $921 = HEAP32[$33>>2]|0;
           $922 = (($921) + (($920*12)|0)|0);
           $923 = Math_fround(HEAPF32[$922>>2]);
           $924 = (($921) + (($906*12)|0)|0);
           $925 = Math_fround(HEAPF32[$924>>2]);
           $926 = Math_fround($923 - $925);
           $927 = ((($921) + (($920*12)|0)|0) + 4|0);
           $928 = Math_fround(HEAPF32[$927>>2]);
           $929 = ((($921) + (($906*12)|0)|0) + 4|0);
           $930 = Math_fround(HEAPF32[$929>>2]);
           $931 = Math_fround($928 - $930);
           $932 = ((($921) + (($920*12)|0)|0) + 8|0);
           $933 = Math_fround(HEAPF32[$932>>2]);
           $934 = ((($921) + (($906*12)|0)|0) + 8|0);
           $935 = Math_fround(HEAPF32[$934>>2]);
           $936 = Math_fround($933 - $935);
           $937 = Math_fround($926 * $926);
           $938 = Math_fround($931 * $931);
           $939 = Math_fround($937 + $938);
           $940 = Math_fround($936 * $936);
           $941 = Math_fround($939 + $940);
           $942 = (Math_fround(Math_sqrt((Math_fround($941)))));
           $943 = Math_fround($908 + $942);
           $$sum1 = (($920) + ($865))|0;
           $944 = (($855) + ($$sum1<<2)|0);
           $945 = Math_fround(HEAPF32[$944>>2]);
           $946 = $943 < $945;
           L362: do {
            if ($946) {
             HEAPF32[$944>>2] = $943;
             $947 = HEAP32[$918>>2]|0;
             $948 = (($856) + ($$sum1<<2)|0);
             HEAP32[$948>>2] = $947;
             HEAP32[$23>>2] = $920;
             HEAPF32[$859>>2] = $943;
             HEAP32[$860>>2] = 0;
             $this$idx$val$i$i150 = HEAP32[$853>>2]|0;
             $949 = $this$idx$val$i$i150 & 2147483647;
             $950 = ($949>>>0)>($951>>>0);
             if ($950) {
              $952 = (($953) + (($951*12)|0)|0);
              $954 = ($952|0)==(0|0);
              if ($954) {
               $956 = $951;
              } else {
               ;HEAP32[$952+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$952+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$952+8>>2]=HEAP32[$23+8>>2]|0;
               $$pre$i$i153 = HEAP32[$852>>2]|0;
               $956 = $$pre$i$i153;
              }
              $955 = (($956) + 1)|0;
              HEAP32[$852>>2] = $955;
              $heap$idx2$val$i155 = $955;
             } else {
              (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_119VertexDistanceCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($vertexHeap,$23)|0);
              $heap$idx2$val$pre$i151 = HEAP32[$852>>2]|0;
              $heap$idx2$val$i155 = $heap$idx2$val$pre$i151;
             }
             $heap$idx$val$i156 = HEAP32[$vertexHeap>>2]|0;
             $957 = ($heap$idx2$val$i155|0)>(0);
             if (!($957)) {
              $heap$idx$val$i172284 = $heap$idx$val$i156;$vertexHeap$idx$val$pr289 = $heap$idx2$val$i155;
              break;
             }
             $$idx4$i158 = ($heap$idx2$val$i155*12)|0;
             $958 = (($$idx4$i158|0) / 12)&-1;
             $959 = (($958) + -1)|0;
             $960 = ($959|0)==(0);
             if ($960) {
              $heap$idx$val$i172284 = $heap$idx$val$i156;$vertexHeap$idx$val$pr289 = $heap$idx2$val$i155;
              break;
             } else {
              $current$05$i160 = $959;
             }
             while(1) {
              $961 = (($current$05$i160) + -1)|0;
              $962 = $961 >>> 1;
              $$idx$i161 = ((($heap$idx$val$i156) + (($962*12)|0)|0) + 4|0);
              $$idx$val$i162 = Math_fround(HEAPF32[$$idx$i161>>2]);
              $$idx3$i163 = ((($heap$idx$val$i156) + (($current$05$i160*12)|0)|0) + 4|0);
              $$idx3$val$i164 = Math_fround(HEAPF32[$$idx3$i163>>2]);
              $963 = $$idx3$val$i164 < $$idx$val$i162;
              if (!($963)) {
               $heap$idx$val$i172284 = $heap$idx$val$i156;$vertexHeap$idx$val$pr289 = $heap$idx2$val$i155;
               break L362;
              }
              $964 = (($heap$idx$val$i156) + (($current$05$i160*12)|0)|0);
              $965 = (($heap$idx$val$i156) + (($962*12)|0)|0);
              ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$965+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$965+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$965+8>>2]|0;
              ;HEAP32[$965+0>>2]=HEAP32[$964+0>>2]|0;HEAP32[$965+4>>2]=HEAP32[$964+4>>2]|0;HEAP32[$965+8>>2]=HEAP32[$964+8>>2]|0;
              ;HEAP32[$964+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$964+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$964+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
              $966 = ($962|0)==(0);
              if ($966) {
               $heap$idx$val$i172284 = $heap$idx$val$i156;$vertexHeap$idx$val$pr289 = $heap$idx2$val$i155;
               break;
              } else {
               $current$05$i160 = $962;
              }
             }
            } else {
             $heap$idx$val$i172284 = $953;$vertexHeap$idx$val$pr289 = $951;
            }
           } while(0);
           $967 = (($j11$0240) + 1)|0;
           $exitcond275 = ($967|0)==($916|0);
           if ($exitcond275) {
            $heap$idx$val$i172286 = $heap$idx$val$i172284;$vertexHeap$idx$val$pr = $vertexHeap$idx$val$pr289;
            break;
           } else {
            $951 = $vertexHeap$idx$val$pr289;$953 = $heap$idx$val$i172284;$j11$0240 = $967;
           }
          }
         }
        } while(0);
        $890 = ($vertexHeap$idx$val$pr|0)==(0);
        if ($890) {
         break;
        } else {
         $heap$idx$val$i172 = $heap$idx$val$i172286;$heap$idx2$val$i174 = $vertexHeap$idx$val$pr;
        }
       }
      }
     }
     $exitcond276 = ($874|0)==($islandCnt$1|0);
     if ($exitcond276) {
      break;
     } else {
      $i4$0245 = $874;
     }
    }
   }
   $968 = ($islandCnt$1>>>0)>(4);
   $969 = $968 ? 4 : $islandCnt$1;
   $970 = HEAP32[$29>>2]|0;
   $971 = Math_imul($970, $969)|0;
   $972 = (($this) + 84|0);
   HEAP32[$24>>2] = 0;
   __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($972,$971,$24);
   $973 = (($this) + 96|0);
   HEAPF32[$25>>2] = Math_fround(0.0);
   __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($973,$971,$25);
   $974 = HEAP32[$29>>2]|0;
   $975 = ($974|0)==(0);
   if (!($975)) {
    $976 = ($969|0)==(0);
    $977 = HEAP32[$vertexParentBuffer>>2]|0;
    $978 = HEAP32[$vertexDistanceBuffer>>2]|0;
    $979 = (($26) + 4|0);
    $980 = (($26) + 8|0);
    $981 = $islandCnt$1 ^ -1;
    $982 = ($981>>>0)>(4294967291);
    $umax = $982 ? $981 : -5;
    $983 = (($umax) + 1)|0;
    $984 = $umax ^ -1;
    $1169 = $974;$i13$0227 = 0;
    while(1) {
     HEAP32[$852>>2] = 0;
     L383: do {
      if ($854) {
       $heap$idx2$i$promoted = 0;
      } else {
       $$pre$i$i115 = 0;$986 = $1169;$j14$0224 = 0;
       while(1) {
        $985 = Math_imul($986, $j14$0224)|0;
        $987 = (($985) + ($i13$0227))|0;
        $988 = (($977) + ($987<<2)|0);
        $989 = HEAP32[$988>>2]|0;
        $990 = (($978) + ($987<<2)|0);
        $991 = Math_fround(HEAPF32[$990>>2]);
        HEAP32[$26>>2] = $989;
        HEAPF32[$979>>2] = $991;
        HEAP32[$980>>2] = 0;
        $this$idx$val$i$i = HEAP32[$853>>2]|0;
        $992 = $this$idx$val$i$i & 2147483647;
        $993 = ($992>>>0)>($$pre$i$i115>>>0);
        if ($993) {
         $994 = HEAP32[$vertexHeap>>2]|0;
         $995 = (($994) + (($$pre$i$i115*12)|0)|0);
         $996 = ($995|0)==(0|0);
         if (!($996)) {
          ;HEAP32[$995+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$995+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$995+8>>2]=HEAP32[$26+8>>2]|0;
         }
         $997 = (($$pre$i$i115) + 1)|0;
         HEAP32[$852>>2] = $997;
         $heap$idx$val$i117 = $994;$heap$idx2$val$i116 = $997;
        } else {
         (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_119VertexDistanceCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($vertexHeap,$26)|0);
         $heap$idx2$val$pre$i = HEAP32[$852>>2]|0;
         $heap$idx$val$i117$pre = HEAP32[$vertexHeap>>2]|0;
         $heap$idx$val$i117 = $heap$idx$val$i117$pre;$heap$idx2$val$i116 = $heap$idx2$val$pre$i;
        }
        $998 = ($heap$idx2$val$i116|0)>(0);
        L393: do {
         if ($998) {
          $$idx4$i118 = ($heap$idx2$val$i116*12)|0;
          $999 = (($$idx4$i118|0) / 12)&-1;
          $1000 = (($999) + -1)|0;
          $1001 = ($1000|0)==(0);
          if ($1001) {
           break;
          } else {
           $current$05$i = $1000;
          }
          while(1) {
           $1002 = (($current$05$i) + -1)|0;
           $1003 = $1002 >>> 1;
           $$idx$i120 = ((($heap$idx$val$i117) + (($1003*12)|0)|0) + 4|0);
           $$idx$val$i121 = Math_fround(HEAPF32[$$idx$i120>>2]);
           $$idx3$i122 = ((($heap$idx$val$i117) + (($current$05$i*12)|0)|0) + 4|0);
           $$idx3$val$i123 = Math_fround(HEAPF32[$$idx3$i122>>2]);
           $1004 = $$idx3$val$i123 < $$idx$val$i121;
           if (!($1004)) {
            break L393;
           }
           $1005 = (($heap$idx$val$i117) + (($current$05$i*12)|0)|0);
           $1006 = (($heap$idx$val$i117) + (($1003*12)|0)|0);
           ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$1006+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$1006+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$1006+8>>2]|0;
           ;HEAP32[$1006+0>>2]=HEAP32[$1005+0>>2]|0;HEAP32[$1006+4>>2]=HEAP32[$1005+4>>2]|0;HEAP32[$1006+8>>2]=HEAP32[$1005+8>>2]|0;
           ;HEAP32[$1005+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$1005+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$1005+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
           $1007 = ($1003|0)==(0);
           if ($1007) {
            break;
           } else {
            $current$05$i = $1003;
           }
          }
         }
        } while(0);
        $1008 = (($j14$0224) + 1)|0;
        $exitcond = ($1008|0)==($islandCnt$1|0);
        if ($exitcond) {
         $heap$idx2$i$promoted = $heap$idx2$val$i116;
         break L383;
        }
        $$pre303 = HEAP32[$29>>2]|0;
        $$pre$i$i115 = $heap$idx2$val$i116;$986 = $$pre303;$j14$0224 = $1008;
       }
      }
     } while(0);
     if (!($976)) {
      $heap$idx$val$i = HEAP32[$vertexHeap>>2]|0;
      $1009 = $heap$idx2$i$promoted;$j15$0225 = 0;
      while(1) {
       $$sum7$i = (($1009) + -1)|0;
       $1010 = (($heap$idx$val$i) + (($$sum7$i*12)|0)|0);
       ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$heap$idx$val$i+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$heap$idx$val$i+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$heap$idx$val$i+8>>2]|0;
       ;HEAP32[$heap$idx$val$i+0>>2]=HEAP32[$1010+0>>2]|0;HEAP32[$heap$idx$val$i+4>>2]=HEAP32[$1010+4>>2]|0;HEAP32[$heap$idx$val$i+8>>2]=HEAP32[$1010+8>>2]|0;
       ;HEAP32[$1010+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$1010+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$1010+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
       $1011 = ($$sum7$i|0)>(1);
       L405: do {
        if ($1011) {
         $1012 = 1;$current$08$i = 0;
         while(1) {
          $$sum$i = (($1012) + 1)|0;
          $1013 = ($$sum$i|0)<($$sum7$i|0);
          if ($1013) {
           $$idx4$i = ((($heap$idx$val$i) + (($1012*12)|0)|0) + 4|0);
           $$idx4$val$i = Math_fround(HEAPF32[$$idx4$i>>2]);
           $$idx5$i = ((($heap$idx$val$i) + (($$sum$i*12)|0)|0) + 4|0);
           $$idx5$val$i = Math_fround(HEAPF32[$$idx5$i>>2]);
           $1014 = $$idx5$val$i < $$idx4$val$i;
           $$$i = $1014 ? $$sum$i : $1012;
           $child$0$i = $$$i;
          } else {
           $child$0$i = $1012;
          }
          $$idx$i = ((($heap$idx$val$i) + (($current$08$i*12)|0)|0) + 4|0);
          $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
          $$idx3$i = ((($heap$idx$val$i) + (($child$0$i*12)|0)|0) + 4|0);
          $$idx3$val$i = Math_fround(HEAPF32[$$idx3$i>>2]);
          $1015 = $$idx3$val$i < $$idx$val$i;
          if (!($1015)) {
           break L405;
          }
          $1016 = (($heap$idx$val$i) + (($child$0$i*12)|0)|0);
          $1017 = (($heap$idx$val$i) + (($current$08$i*12)|0)|0);
          ;HEAP32[$tmp$i$i200+0>>2]=HEAP32[$1017+0>>2]|0;HEAP32[$tmp$i$i200+4>>2]=HEAP32[$1017+4>>2]|0;HEAP32[$tmp$i$i200+8>>2]=HEAP32[$1017+8>>2]|0;
          ;HEAP32[$1017+0>>2]=HEAP32[$1016+0>>2]|0;HEAP32[$1017+4>>2]=HEAP32[$1016+4>>2]|0;HEAP32[$1017+8>>2]=HEAP32[$1016+8>>2]|0;
          ;HEAP32[$1016+0>>2]=HEAP32[$tmp$i$i200+0>>2]|0;HEAP32[$1016+4>>2]=HEAP32[$tmp$i$i200+4>>2]|0;HEAP32[$1016+8>>2]=HEAP32[$tmp$i$i200+8>>2]|0;
          $1018 = $child$0$i << 1;
          $1019 = $1018 | 1;
          $1020 = ($1019|0)<($$sum7$i|0);
          if ($1020) {
           $1012 = $1019;$current$08$i = $child$0$i;
          } else {
           break;
          }
         }
        }
       } while(0);
       $1021 = (($heap$idx$val$i) + (($$sum7$i*12)|0)|0);
       $1022 = HEAP32[$1021>>2]|0;
       $1023 = ($1022|0)==($i13$0227|0);
       if ($1023) {
        $distance$0 = Math_fround(0.0);
       } else {
        $1024 = ((($heap$idx$val$i) + (($$sum7$i*12)|0)|0) + 4|0);
        $1025 = Math_fround(HEAPF32[$1024>>2]);
        $1026 = HEAP32[$33>>2]|0;
        $1027 = (($1026) + (($i13$0227*12)|0)|0);
        $1028 = Math_fround(HEAPF32[$1027>>2]);
        $1029 = (($1026) + (($1022*12)|0)|0);
        $1030 = Math_fround(HEAPF32[$1029>>2]);
        $1031 = Math_fround($1028 - $1030);
        $1032 = ((($1026) + (($i13$0227*12)|0)|0) + 4|0);
        $1033 = Math_fround(HEAPF32[$1032>>2]);
        $1034 = ((($1026) + (($1022*12)|0)|0) + 4|0);
        $1035 = Math_fround(HEAPF32[$1034>>2]);
        $1036 = Math_fround($1033 - $1035);
        $1037 = ((($1026) + (($i13$0227*12)|0)|0) + 8|0);
        $1038 = Math_fround(HEAPF32[$1037>>2]);
        $1039 = ((($1026) + (($1022*12)|0)|0) + 8|0);
        $1040 = Math_fround(HEAPF32[$1039>>2]);
        $1041 = Math_fround($1038 - $1040);
        $1042 = Math_fround($1031 * $1031);
        $1043 = Math_fround($1036 * $1036);
        $1044 = Math_fround($1042 + $1043);
        $1045 = Math_fround($1041 * $1041);
        $1046 = Math_fround($1044 + $1045);
        $1047 = (Math_fround(Math_sqrt((Math_fround($1046)))));
        HEAP32[$errorCode>>2] = 0;
        $1048 = (Math_fround(__ZN5physx31PxClothGeodesicTetherCookerImpl23computeGeodesicDistanceEjjRi($this,$i13$0227,$1022,$errorCode)));
        $1049 = HEAP32[$errorCode>>2]|0;
        $1050 = ($1049|0)<(0);
        $$ = $1050 ? $1025 : $1048;
        $1051 = $1047 > $$;
        $1052 = $1051 ? $1047 : $$;
        $distance$0 = $1052;
       }
       $1053 = HEAP32[$29>>2]|0;
       $1054 = Math_imul($1053, $j15$0225)|0;
       $1055 = (($1054) + ($i13$0227))|0;
       $1056 = HEAP32[$972>>2]|0;
       $1057 = (($1056) + ($1055<<2)|0);
       HEAP32[$1057>>2] = $1022;
       $1058 = HEAP32[$973>>2]|0;
       $1059 = (($1058) + ($1055<<2)|0);
       HEAPF32[$1059>>2] = $distance$0;
       $1060 = (($j15$0225) + 1)|0;
       $exitcond273 = ($1060|0)==($984|0);
       if ($exitcond273) {
        break;
       } else {
        $1009 = $$sum7$i;$j15$0225 = $1060;
       }
      }
      $1061 = (($983) + ($heap$idx2$i$promoted))|0;
      HEAP32[$852>>2] = $1061;
     }
     $1062 = (($i13$0227) + 1)|0;
     $1063 = HEAP32[$29>>2]|0;
     $1064 = ($1062>>>0)<($1063>>>0);
     if ($1064) {
      $1169 = $1063;$i13$0227 = $1062;
     } else {
      break;
     }
    }
   }
   $vertexHeap$idx10$val = HEAP32[$vertexHeap>>2]|0;
   $vertexHeap$idx12$val = HEAP32[$853>>2]|0;
   $1065 = $vertexHeap$idx12$val & 2147483647;
   $notlhs$i106 = ($1065|0)==(0);
   $notrhs$i107 = ($vertexHeap$idx12$val|0)<(0);
   $or$cond$not$i108 = $notrhs$i107 | $notlhs$i106;
   $1066 = ($vertexHeap$idx10$val|0)==(0|0);
   $or$cond2$i109 = $or$cond$not$i108 | $1066;
   if (!($or$cond2$i109)) {
    $1067 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $1068 = HEAP32[$1067>>2]|0;
    $1069 = (($1068) + 12|0);
    $1070 = HEAP32[$1069>>2]|0;
    FUNCTION_TABLE_vii[$1070 & 4095]($1067,$vertexHeap$idx10$val);
   }
   $1071 = HEAP32[$851>>2]|0;
   $1072 = $1071 & 2147483647;
   $1073 = ($1072|0)!=(0);
   $1074 = ($1071|0)>(-1);
   $or$cond$i$i104 = $1073 & $1074;
   if ($or$cond$i$i104) {
    $1075 = HEAP32[$vertexParentBuffer>>2]|0;
    $1076 = ($1075|0)==(0|0);
    if (!($1076)) {
     $1077 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $1078 = HEAP32[$1077>>2]|0;
     $1079 = (($1078) + 12|0);
     $1080 = HEAP32[$1079>>2]|0;
     FUNCTION_TABLE_vii[$1080 & 4095]($1077,$1075);
    }
   }
   $1081 = HEAP32[$849>>2]|0;
   $1082 = $1081 & 2147483647;
   $1083 = ($1082|0)!=(0);
   $1084 = ($1081|0)>(-1);
   $or$cond$i$i102 = $1083 & $1084;
   if ($or$cond$i$i102) {
    $1085 = HEAP32[$vertexDistanceBuffer>>2]|0;
    $1086 = ($1085|0)==(0|0);
    if (!($1086)) {
     $1087 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $1088 = HEAP32[$1087>>2]|0;
     $1089 = (($1088) + 12|0);
     $1090 = HEAP32[$1089>>2]|0;
     FUNCTION_TABLE_vii[$1090 & 4095]($1087,$1085);
    }
   }
   $1091 = HEAP32[$740>>2]|0;
   $1092 = $1091 & 2147483647;
   $1093 = ($1092|0)!=(0);
   $1094 = ($1091|0)>(-1);
   $or$cond$i$i100 = $1093 & $1094;
   if ($or$cond$i$i100) {
    $1095 = HEAP32[$islandFirst>>2]|0;
    $1096 = ($1095|0)==(0|0);
    if (!($1096)) {
     $1097 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $1098 = HEAP32[$1097>>2]|0;
     $1099 = (($1098) + 12|0);
     $1100 = HEAP32[$1099>>2]|0;
     FUNCTION_TABLE_vii[$1100 & 4095]($1097,$1095);
    }
   }
   $1101 = HEAP32[$738>>2]|0;
   $1102 = $1101 & 2147483647;
   $1103 = ($1102|0)!=(0);
   $1104 = ($1101|0)>(-1);
   $or$cond$i$i25 = $1103 & $1104;
   if ($or$cond$i$i25) {
    $1105 = HEAP32[$islandIndices>>2]|0;
    $1106 = ($1105|0)==(0|0);
    if (!($1106)) {
     $1107 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $1108 = HEAP32[$1107>>2]|0;
     $1109 = (($1108) + 12|0);
     $1110 = HEAP32[$1109>>2]|0;
     FUNCTION_TABLE_vii[$1110 & 4095]($1107,$1105);
    }
   }
  }
 }
 $vertexIslandHeap$idx13$val = HEAP32[$vertexIslandHeap>>2]|0;
 $vertexIslandHeap$idx15$val = HEAP32[$715>>2]|0;
 $1111 = $vertexIslandHeap$idx15$val & 2147483647;
 $notlhs$i = ($1111|0)==(0);
 $notrhs$i = ($vertexIslandHeap$idx15$val|0)<(0);
 $or$cond$not$i = $notrhs$i | $notlhs$i;
 $1112 = ($vertexIslandHeap$idx13$val|0)==(0|0);
 $or$cond2$i = $or$cond$not$i | $1112;
 if (!($or$cond2$i)) {
  $1113 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $1114 = HEAP32[$1113>>2]|0;
  $1115 = (($1114) + 12|0);
  $1116 = HEAP32[$1115>>2]|0;
  FUNCTION_TABLE_vii[$1116 & 4095]($1113,$vertexIslandHeap$idx13$val);
 }
 $1117 = HEAP32[$713>>2]|0;
 $1118 = $1117 & 2147483647;
 $1119 = ($1118|0)!=(0);
 $1120 = ($1117|0)>(-1);
 $or$cond$i$i23 = $1119 & $1120;
 if ($or$cond$i$i23) {
  $1121 = HEAP32[$vertexIsland>>2]|0;
  $1122 = ($1121|0)==(0|0);
  if (!($1122)) {
   $1123 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $1124 = HEAP32[$1123>>2]|0;
   $1125 = (($1124) + 12|0);
   $1126 = HEAP32[$1125>>2]|0;
   FUNCTION_TABLE_vii[$1126 & 4095]($1123,$1121);
  }
 }
 $1127 = HEAP32[$681>>2]|0;
 $1128 = $1127 & 2147483647;
 $1129 = ($1128|0)!=(0);
 $1130 = ($1127|0)>(-1);
 $or$cond$i$i20 = $1129 & $1130;
 if ($or$cond$i$i20) {
  $1131 = HEAP32[$neighbors>>2]|0;
  $1132 = ($1131|0)==(0|0);
  if (!($1132)) {
   $1133 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $1134 = HEAP32[$1133>>2]|0;
   $1135 = (($1134) + 12|0);
   $1136 = HEAP32[$1135>>2]|0;
   FUNCTION_TABLE_vii[$1136 & 4095]($1133,$1131);
  }
 }
 $1137 = HEAP32[$678>>2]|0;
 $1138 = $1137 & 2147483647;
 $1139 = ($1138|0)!=(0);
 $1140 = ($1137|0)>(-1);
 $or$cond$i$i18 = $1139 & $1140;
 if ($or$cond$i$i18) {
  $1141 = HEAP32[$mark>>2]|0;
  $1142 = ($1141|0)==(0|0);
  if (!($1142)) {
   $1143 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $1144 = HEAP32[$1143>>2]|0;
   $1145 = (($1144) + 12|0);
   $1146 = HEAP32[$1145>>2]|0;
   FUNCTION_TABLE_vii[$1146 & 4095]($1143,$1141);
  }
 }
 $1147 = HEAP32[$337>>2]|0;
 $1148 = $1147 & 2147483647;
 $1149 = ($1148|0)!=(0);
 $1150 = ($1147|0)>(-1);
 $or$cond$i$i16 = $1149 & $1150;
 if ($or$cond$i$i16) {
  $1151 = HEAP32[$adjacencies>>2]|0;
  $1152 = ($1151|0)==(0|0);
  if (!($1152)) {
   $1153 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $1154 = HEAP32[$1153>>2]|0;
   $1155 = (($1154) + 12|0);
   $1156 = HEAP32[$1155>>2]|0;
   FUNCTION_TABLE_vii[$1156 & 4095]($1153,$1151);
  }
 }
 $1157 = HEAP32[$335>>2]|0;
 $1158 = $1157 & 2147483647;
 $notlhs = ($1158|0)==(0);
 $notrhs = ($1157|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $1159 = ($688|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $1159;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $1160 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1161 = HEAP32[$1160>>2]|0;
 $1162 = (($1161) + 12|0);
 $1163 = HEAP32[$1162>>2]|0;
 FUNCTION_TABLE_vii[$1163 & 4095]($1160,$688);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*12)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*12)|0)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $$01$i = $9;
 while(1) {
  $12 = ($$01$i|0)==(0|0);
  if (!($12)) {
   $13 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $13;
   $14 = (($$01$i) + 4|0);
   $15 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$14>>2] = $15;
   $16 = (($$01$i) + 8|0);
   $17 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$16>>2] = $17;
  }
  $18 = (($$01$i) + 12|0);
  $19 = ($18>>>0)<($7>>>0);
  if ($19) {
   $$01$i = $18;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIhNS0_19ReflectionAllocatorIhEEE6resizeEjRKh($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIhNS0_19ReflectionAllocatorIhEEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP8[$a>>0]|0;
   HEAP8[$$01$i>>0] = $11;
  }
  $12 = (($$01$i) + 1|0);
  $exitcond$i = ($12|0)==($7|0);
  if ($exitcond$i) {
   break;
  } else {
   $$01$i = $12;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx31PxClothGeodesicTetherCookerImpl20findVertTriNeighborsEv($this) {
 $this = $this|0;
 var $$$i$i$i$i$i$i = 0, $$$i$i$i$i9$i$i = 0, $$ph$be$i$i = 0, $$ph$i$i = 0, $$ph23$be$i$i = 0, $$ph23$i$i = 0, $$ph24$be$i$i = 0, $$ph24$i$i = 0, $$ph25$be$i$i = 0, $$ph25$i$i = 0, $$ph26$be$i$i = 0, $$ph26$i$i = 0, $$ph27$be$i$i = 0, $$ph27$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i14 = 0, $$pre$i18 = 0, $$pre$i5$i$i = 0;
 var $$pre3$i$i$i$i = 0, $$pre56 = 0, $$pre58 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i = 0, $i$0$i$i$i = 0, $i$0$ph$i$i$i = 0, $i$03$i$i$i = 0, $i$040 = 0, $i1$025 = 0, $i1$1$lcssa = 0, $i1$122 = 0, $j$0$m$0$i$i$i = 0, $j$0$ph$i$i$i = 0, $j$02$i$i$i = 0, $j$1$i$i$i = 0, $m$01$i$i$i = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0;
 var $or$cond$not$i = 0, $or$cond17$i$i = 0, $or$cond2$i = 0, $stackMem$i$i = 0, $this$idx$val$i10 = 0, $this$idx$val$i13 = 0, $this$idx$val$i13$pre = 0, $this$idx$val$i17 = 0, $this$idx$val$i17$pre = 0, $vertTriangles = 0, $vertTriangles$idx$val = 0, $vertTriangles$idx1$val23 = 0, $vertTriangles$idx2$val = 0, $vertTriangles$idx8$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $stackMem$i$i = sp + 24|0;
 $0 = sp + 56|0;
 $vertTriangles = sp + 32|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = sp + 44|0;
 $5 = sp + 48|0;
 HEAP32[$vertTriangles>>2] = 0;
 $6 = (($vertTriangles) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($vertTriangles) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_112VertTriangleENS0_19ReflectionAllocatorIS3_EEE8recreateEj($vertTriangles,$9);
  $$pre = HEAP32[$8>>2]|0;
  $11 = (($$pre|0) / 3)&-1;
  $12 = ($$pre|0)>(2);
  if ($12) {
   $13 = (($this) + 20|0);
   $14 = (($1) + 4|0);
   $15 = (($2) + 4|0);
   $16 = (($3) + 4|0);
   $i$040 = 0;
   while(1) {
    $17 = ($i$040*3)|0;
    $18 = HEAP32[$13>>2]|0;
    $19 = (($18) + ($17<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$1>>2] = $20;
    HEAP32[$14>>2] = $i$040;
    $this$idx$val$i10 = HEAP32[$7>>2]|0;
    $21 = $this$idx$val$i10 & 2147483647;
    $22 = HEAP32[$6>>2]|0;
    $23 = ($21>>>0)>($22>>>0);
    if ($23) {
     $24 = HEAP32[$vertTriangles>>2]|0;
     $25 = (($24) + ($22<<3)|0);
     $26 = ($25|0)==(0|0);
     if (!($26)) {
      $27 = $1;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = (($27) + 4)|0;
      $31 = $30;
      $32 = HEAP32[$31>>2]|0;
      $33 = $25;
      $34 = $33;
      HEAP32[$34>>2] = $29;
      $35 = (($33) + 4)|0;
      $36 = $35;
      HEAP32[$36>>2] = $32;
     }
     $37 = (($22) + 1)|0;
     HEAP32[$6>>2] = $37;
     $$pre$i14 = $37;$this$idx$val$i13 = $this$idx$val$i10;
    } else {
     (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_112VertTriangleENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($vertTriangles,$1)|0);
     $this$idx$val$i13$pre = HEAP32[$7>>2]|0;
     $$pre56 = HEAP32[$6>>2]|0;
     $$pre$i14 = $$pre56;$this$idx$val$i13 = $this$idx$val$i13$pre;
    }
    $38 = (($17) + 1)|0;
    $39 = HEAP32[$13>>2]|0;
    $40 = (($39) + ($38<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$2>>2] = $41;
    HEAP32[$15>>2] = $i$040;
    $42 = $this$idx$val$i13 & 2147483647;
    $43 = ($42>>>0)>($$pre$i14>>>0);
    if ($43) {
     $44 = HEAP32[$vertTriangles>>2]|0;
     $45 = (($44) + ($$pre$i14<<3)|0);
     $46 = ($45|0)==(0|0);
     if (!($46)) {
      $47 = $2;
      $48 = $47;
      $49 = HEAP32[$48>>2]|0;
      $50 = (($47) + 4)|0;
      $51 = $50;
      $52 = HEAP32[$51>>2]|0;
      $53 = $45;
      $54 = $53;
      HEAP32[$54>>2] = $49;
      $55 = (($53) + 4)|0;
      $56 = $55;
      HEAP32[$56>>2] = $52;
     }
     $57 = (($$pre$i14) + 1)|0;
     HEAP32[$6>>2] = $57;
     $$pre$i18 = $57;$this$idx$val$i17 = $this$idx$val$i13;
    } else {
     (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_112VertTriangleENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($vertTriangles,$2)|0);
     $this$idx$val$i17$pre = HEAP32[$7>>2]|0;
     $$pre58 = HEAP32[$6>>2]|0;
     $$pre$i18 = $$pre58;$this$idx$val$i17 = $this$idx$val$i17$pre;
    }
    $58 = (($17) + 2)|0;
    $59 = HEAP32[$13>>2]|0;
    $60 = (($59) + ($58<<2)|0);
    $61 = HEAP32[$60>>2]|0;
    HEAP32[$3>>2] = $61;
    HEAP32[$16>>2] = $i$040;
    $62 = $this$idx$val$i17 & 2147483647;
    $63 = ($62>>>0)>($$pre$i18>>>0);
    if ($63) {
     $64 = HEAP32[$vertTriangles>>2]|0;
     $65 = (($64) + ($$pre$i18<<3)|0);
     $66 = ($65|0)==(0|0);
     if (!($66)) {
      $67 = $3;
      $68 = $67;
      $69 = HEAP32[$68>>2]|0;
      $70 = (($67) + 4)|0;
      $71 = $70;
      $72 = HEAP32[$71>>2]|0;
      $73 = $65;
      $74 = $73;
      HEAP32[$74>>2] = $69;
      $75 = (($73) + 4)|0;
      $76 = $75;
      HEAP32[$76>>2] = $72;
     }
     $77 = (($$pre$i18) + 1)|0;
     HEAP32[$6>>2] = $77;
    } else {
     (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_112VertTriangleENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($vertTriangles,$3)|0);
    }
    $78 = (($i$040) + 1)|0;
    $79 = ($78|0)<($11|0);
    if ($79) {
     $i$040 = $78;
    } else {
     break;
    }
   }
  }
 }
 $vertTriangles$idx$val = HEAP32[$vertTriangles>>2]|0;
 $vertTriangles$idx2$val = HEAP32[$6>>2]|0;
 $80 = $stackMem$i$i;
 $81 = $80;
 HEAP32[$81>>2] = 0;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = 0;
 $84 = (($stackMem$i$i) + 4|0);
 HEAP8[$84>>0] = 0;
 HEAP32[$stackMem$i$i>>2] = $0;
 $85 = (($vertTriangles$idx2$val) + -1)|0;
 $86 = ($85|0)>(0);
 if ($86) {
  $$ph$i$i = 0;$$ph23$i$i = $0;$$ph24$i$i = 32;$$ph25$i$i = 0;$$ph26$i$i = 0;$$ph27$i$i = $85;
  L29: while(1) {
   $303 = $$ph25$i$i;$88 = $$ph27$i$i;$89 = $$ph26$i$i;
   while(1) {
    $87 = ($88|0)>($89|0);
    if ($87) {
     $90 = (($88) - ($89))|0;
     $91 = ($90>>>0)<(5);
     if ($91) {
      $i$03$i$i$i = $89;
     } else {
      break;
     }
     while(1) {
      $92 = (($i$03$i$i$i) + 1)|0;
      $j$02$i$i$i = $92;$m$01$i$i$i = $i$03$i$i$i;
      while(1) {
       $93 = (($vertTriangles$idx$val) + ($j$02$i$i$i<<3)|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = (($vertTriangles$idx$val) + ($m$01$i$i$i<<3)|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = ($94|0)==($96|0);
       if ($97) {
        $98 = ((($vertTriangles$idx$val) + ($j$02$i$i$i<<3)|0) + 4|0);
        $99 = HEAP32[$98>>2]|0;
        $100 = ((($vertTriangles$idx$val) + ($m$01$i$i$i<<3)|0) + 4|0);
        $101 = HEAP32[$100>>2]|0;
        $102 = ($99|0)<($101|0);
        $104 = $102;
       } else {
        $103 = ($94|0)<($96|0);
        $104 = $103;
       }
       $j$0$m$0$i$i$i = $104 ? $j$02$i$i$i : $m$01$i$i$i;
       $105 = (($j$02$i$i$i) + 1)|0;
       $106 = ($j$02$i$i$i|0)<($88|0);
       if ($106) {
        $j$02$i$i$i = $105;$m$01$i$i$i = $j$0$m$0$i$i$i;
       } else {
        break;
       }
      }
      $107 = (($vertTriangles$idx$val) + ($j$0$m$0$i$i$i<<3)|0);
      $108 = (($vertTriangles$idx$val) + ($i$03$i$i$i<<3)|0);
      $109 = $107;
      $110 = $109;
      $111 = HEAP32[$110>>2]|0;
      $112 = (($109) + 4)|0;
      $113 = $112;
      $114 = HEAP32[$113>>2]|0;
      $115 = $108;
      $116 = $115;
      $117 = HEAP32[$116>>2]|0;
      $118 = (($115) + 4)|0;
      $119 = $118;
      $120 = HEAP32[$119>>2]|0;
      $121 = $107;
      $122 = $121;
      HEAP32[$122>>2] = $117;
      $123 = (($121) + 4)|0;
      $124 = $123;
      HEAP32[$124>>2] = $120;
      $125 = $108;
      $126 = $125;
      HEAP32[$126>>2] = $111;
      $127 = (($125) + 4)|0;
      $128 = $127;
      HEAP32[$128>>2] = $114;
      $exitcond$i$i$i = ($92|0)==($88|0);
      if ($exitcond$i$i$i) {
       break;
      } else {
       $i$03$i$i$i = $92;
      }
     }
    }
    $358 = ($303|0)==(0);
    if ($358) {
     break L29;
    }
    $359 = (($303) + -1)|0;
    $360 = (($$ph23$i$i) + ($359<<2)|0);
    $361 = HEAP32[$360>>2]|0;
    $362 = (($303) + -2)|0;
    $363 = (($$ph23$i$i) + ($362<<2)|0);
    $364 = HEAP32[$363>>2]|0;
    $303 = $362;$88 = $361;$89 = $364;
   }
   $129 = (($88) + ($89))|0;
   $130 = (($129|0) / 2)&-1;
   $131 = (($vertTriangles$idx$val) + ($130<<3)|0);
   $132 = (($vertTriangles$idx$val) + ($89<<3)|0);
   $133 = HEAP32[$131>>2]|0;
   $134 = HEAP32[$132>>2]|0;
   $135 = ($133|0)==($134|0);
   if ($135) {
    $136 = ((($vertTriangles$idx$val) + ($130<<3)|0) + 4|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = ((($vertTriangles$idx$val) + ($89<<3)|0) + 4|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = ($137|0)<($139|0);
    if ($140) {
     label = 33;
    } else {
     $165 = $133;$415 = $133;
    }
   } else {
    $141 = ($133|0)<($134|0);
    if ($141) {
     label = 33;
    } else {
     $165 = $134;$415 = $133;
    }
   }
   if ((label|0) == 33) {
    label = 0;
    $142 = $132;
    $143 = $142;
    $144 = HEAP32[$143>>2]|0;
    $145 = (($142) + 4)|0;
    $146 = $145;
    $147 = HEAP32[$146>>2]|0;
    $148 = $131;
    $149 = $148;
    $150 = HEAP32[$149>>2]|0;
    $151 = (($148) + 4)|0;
    $152 = $151;
    $153 = HEAP32[$152>>2]|0;
    $154 = $132;
    $155 = $154;
    HEAP32[$155>>2] = $150;
    $156 = (($154) + 4)|0;
    $157 = $156;
    HEAP32[$157>>2] = $153;
    $158 = $131;
    $159 = $158;
    HEAP32[$159>>2] = $144;
    $160 = (($158) + 4)|0;
    $161 = $160;
    HEAP32[$161>>2] = $147;
    $$pre$i$i$i$i = HEAP32[$132>>2]|0;
    $165 = $$pre$i$i$i$i;$415 = $144;
   }
   $162 = (($vertTriangles$idx$val) + ($88<<3)|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ($163|0)==($165|0);
   if ($164) {
    $166 = ((($vertTriangles$idx$val) + ($88<<3)|0) + 4|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = ((($vertTriangles$idx$val) + ($89<<3)|0) + 4|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = ($167|0)<($169|0);
    if ($170) {
     label = 37;
    } else {
     $193 = $165;$194 = $415;
    }
   } else {
    $171 = ($163|0)<($165|0);
    if ($171) {
     label = 37;
    } else {
     $193 = $163;$194 = $415;
    }
   }
   if ((label|0) == 37) {
    label = 0;
    $172 = $132;
    $173 = $172;
    $174 = HEAP32[$173>>2]|0;
    $175 = (($172) + 4)|0;
    $176 = $175;
    $177 = HEAP32[$176>>2]|0;
    $178 = $162;
    $179 = $178;
    $180 = HEAP32[$179>>2]|0;
    $181 = (($178) + 4)|0;
    $182 = $181;
    $183 = HEAP32[$182>>2]|0;
    $184 = $132;
    $185 = $184;
    HEAP32[$185>>2] = $180;
    $186 = (($184) + 4)|0;
    $187 = $186;
    HEAP32[$187>>2] = $183;
    $188 = $162;
    $189 = $188;
    HEAP32[$189>>2] = $174;
    $190 = (($188) + 4)|0;
    $191 = $190;
    HEAP32[$191>>2] = $177;
    $$pre3$i$i$i$i = HEAP32[$131>>2]|0;
    $193 = $174;$194 = $$pre3$i$i$i$i;
   }
   $192 = ($193|0)==($194|0);
   if ($192) {
    $195 = ((($vertTriangles$idx$val) + ($88<<3)|0) + 4|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = ((($vertTriangles$idx$val) + ($130<<3)|0) + 4|0);
    $198 = HEAP32[$197>>2]|0;
    $199 = ($196|0)<($198|0);
    if ($199) {
     label = 41;
    }
   } else {
    $200 = ($193|0)<($194|0);
    if ($200) {
     label = 41;
    }
   }
   if ((label|0) == 41) {
    label = 0;
    $201 = $131;
    $202 = $201;
    $203 = HEAP32[$202>>2]|0;
    $204 = (($201) + 4)|0;
    $205 = $204;
    $206 = HEAP32[$205>>2]|0;
    $207 = $162;
    $208 = $207;
    $209 = HEAP32[$208>>2]|0;
    $210 = (($207) + 4)|0;
    $211 = $210;
    $212 = HEAP32[$211>>2]|0;
    $213 = $131;
    $214 = $213;
    HEAP32[$214>>2] = $209;
    $215 = (($213) + 4)|0;
    $216 = $215;
    HEAP32[$216>>2] = $212;
    $217 = $162;
    $218 = $217;
    HEAP32[$218>>2] = $203;
    $219 = (($217) + 4)|0;
    $220 = $219;
    HEAP32[$220>>2] = $206;
   }
   $221 = (($88) + -1)|0;
   $222 = (($vertTriangles$idx$val) + ($221<<3)|0);
   $223 = $131;
   $224 = $223;
   $225 = HEAP32[$224>>2]|0;
   $226 = (($223) + 4)|0;
   $227 = $226;
   $228 = HEAP32[$227>>2]|0;
   $229 = $222;
   $230 = $229;
   $231 = HEAP32[$230>>2]|0;
   $232 = (($229) + 4)|0;
   $233 = $232;
   $234 = HEAP32[$233>>2]|0;
   $235 = $131;
   $236 = $235;
   HEAP32[$236>>2] = $231;
   $237 = (($235) + 4)|0;
   $238 = $237;
   HEAP32[$238>>2] = $234;
   $239 = $222;
   $240 = $239;
   HEAP32[$240>>2] = $225;
   $241 = (($239) + 4)|0;
   $242 = $241;
   HEAP32[$242>>2] = $228;
   $243 = ((($vertTriangles$idx$val) + ($221<<3)|0) + 4|0);
   $248 = $225;$i$0$ph$i$i$i = $89;$j$0$ph$i$i$i = $221;
   while(1) {
    $i$0$i$i$i = $i$0$ph$i$i$i;
    while(1) {
     $244 = (($i$0$i$i$i) + 1)|0;
     $245 = (($vertTriangles$idx$val) + ($244<<3)|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = ($246|0)==($248|0);
     if ($247) {
      $249 = ((($vertTriangles$idx$val) + ($244<<3)|0) + 4|0);
      $250 = HEAP32[$249>>2]|0;
      $251 = HEAP32[$243>>2]|0;
      $252 = ($250|0)<($251|0);
      if ($252) {
       $i$0$i$i$i = $244;
       continue;
      } else {
       $j$1$i$i$i = $j$0$ph$i$i$i;
       break;
      }
     } else {
      $253 = ($246|0)<($248|0);
      if ($253) {
       $i$0$i$i$i = $244;
       continue;
      } else {
       $j$1$i$i$i = $j$0$ph$i$i$i;
       break;
      }
     }
    }
    while(1) {
     $254 = (($j$1$i$i$i) + -1)|0;
     $255 = (($vertTriangles$idx$val) + ($254<<3)|0);
     $256 = HEAP32[$255>>2]|0;
     $257 = ($248|0)==($256|0);
     if ($257) {
      $258 = HEAP32[$243>>2]|0;
      $259 = ((($vertTriangles$idx$val) + ($254<<3)|0) + 4|0);
      $260 = HEAP32[$259>>2]|0;
      $261 = ($258|0)<($260|0);
      if ($261) {
       $j$1$i$i$i = $254;
       continue;
      } else {
       break;
      }
     } else {
      $262 = ($248|0)<($256|0);
      if ($262) {
       $j$1$i$i$i = $254;
       continue;
      } else {
       break;
      }
     }
    }
    $263 = ($244|0)<($254|0);
    $264 = $245;
    $265 = $264;
    $266 = HEAP32[$265>>2]|0;
    $267 = (($264) + 4)|0;
    $268 = $267;
    $269 = HEAP32[$268>>2]|0;
    if (!($263)) {
     break;
    }
    $270 = $255;
    $271 = $270;
    $272 = HEAP32[$271>>2]|0;
    $273 = (($270) + 4)|0;
    $274 = $273;
    $275 = HEAP32[$274>>2]|0;
    $276 = $245;
    $277 = $276;
    HEAP32[$277>>2] = $272;
    $278 = (($276) + 4)|0;
    $279 = $278;
    HEAP32[$279>>2] = $275;
    $280 = $255;
    $281 = $280;
    HEAP32[$281>>2] = $266;
    $282 = (($280) + 4)|0;
    $283 = $282;
    HEAP32[$283>>2] = $269;
    $$pre$i5$i$i = HEAP32[$222>>2]|0;
    $248 = $$pre$i5$i$i;$i$0$ph$i$i$i = $244;$j$0$ph$i$i$i = $254;
   }
   $284 = $222;
   $285 = $284;
   $286 = HEAP32[$285>>2]|0;
   $287 = (($284) + 4)|0;
   $288 = $287;
   $289 = HEAP32[$288>>2]|0;
   $290 = $245;
   $291 = $290;
   HEAP32[$291>>2] = $286;
   $292 = (($290) + 4)|0;
   $293 = $292;
   HEAP32[$293>>2] = $289;
   $294 = $222;
   $295 = $294;
   HEAP32[$295>>2] = $266;
   $296 = (($294) + 4)|0;
   $297 = $296;
   HEAP32[$297>>2] = $269;
   $298 = (($244) - ($89))|0;
   $299 = (($88) - ($244))|0;
   $300 = ($298|0)<($299|0);
   if ($300) {
    $301 = (($$ph24$i$i) + -1)|0;
    $302 = ($303>>>0)<($301>>>0);
    if ($302) {
     $327 = $$ph23$i$i;$416 = $$ph$i$i;$417 = $$ph24$i$i;
    } else {
     $304 = $$ph24$i$i << 1;
     $305 = $$ph24$i$i << 3;
     $306 = ($305|0)==(0);
     if ($306) {
      $318 = 0;
     } else {
      $307 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $308 = HEAP32[$307>>2]|0;
      $309 = (($308) + 8|0);
      $310 = HEAP32[$309>>2]|0;
      $311 = (__Z15PxGetFoundationv()|0);
      $312 = HEAP32[$311>>2]|0;
      $313 = (($312) + 24|0);
      $314 = HEAP32[$313>>2]|0;
      $315 = (FUNCTION_TABLE_ii[$314 & 4095]($311)|0);
      $$$i$i$i$i9$i$i = $315 ? 409800 : 409768;
      $316 = (FUNCTION_TABLE_iiiiii[$310 & 255]($307,$305,$$$i$i$i$i9$i$i,409680,148)|0);
      $318 = $316;
     }
     $317 = $303 << 2;
     _memcpy(($318|0),($$ph23$i$i|0),($317|0))|0;
     $319 = ($$ph$i$i<<24>>24)==(0);
     $320 = ($$ph23$i$i|0)==(0|0);
     $or$cond$i$i = $319 | $320;
     if ($or$cond$i$i) {
      $327 = $318;$416 = 1;$417 = $304;
     } else {
      $321 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $322 = HEAP32[$321>>2]|0;
      $323 = (($322) + 12|0);
      $324 = HEAP32[$323>>2]|0;
      FUNCTION_TABLE_vii[$324 & 4095]($321,$$ph23$i$i);
      $327 = $318;$416 = 1;$417 = $304;
     }
    }
    $325 = (($303) + 1)|0;
    $326 = (($327) + ($303<<2)|0);
    HEAP32[$326>>2] = $89;
    $328 = (($327) + ($325<<2)|0);
    HEAP32[$328>>2] = $i$0$i$i$i;
    $329 = (($i$0$i$i$i) + 2)|0;
    $$ph$be$i$i = $416;$$ph23$be$i$i = $327;$$ph24$be$i$i = $417;$$ph26$be$i$i = $329;$$ph27$be$i$i = $88;
   } else {
    $330 = (($i$0$i$i$i) + 2)|0;
    $331 = (($$ph24$i$i) + -1)|0;
    $332 = ($303>>>0)<($331>>>0);
    if ($332) {
     $356 = $$ph23$i$i;$418 = $$ph$i$i;$419 = $$ph24$i$i;
    } else {
     $333 = $$ph24$i$i << 1;
     $334 = $$ph24$i$i << 3;
     $335 = ($334|0)==(0);
     if ($335) {
      $347 = 0;
     } else {
      $336 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $337 = HEAP32[$336>>2]|0;
      $338 = (($337) + 8|0);
      $339 = HEAP32[$338>>2]|0;
      $340 = (__Z15PxGetFoundationv()|0);
      $341 = HEAP32[$340>>2]|0;
      $342 = (($341) + 24|0);
      $343 = HEAP32[$342>>2]|0;
      $344 = (FUNCTION_TABLE_ii[$343 & 4095]($340)|0);
      $$$i$i$i$i$i$i = $344 ? 409800 : 409768;
      $345 = (FUNCTION_TABLE_iiiiii[$339 & 255]($336,$334,$$$i$i$i$i$i$i,409680,148)|0);
      $347 = $345;
     }
     $346 = $303 << 2;
     _memcpy(($347|0),($$ph23$i$i|0),($346|0))|0;
     $348 = ($$ph$i$i<<24>>24)==(0);
     $349 = ($$ph23$i$i|0)==(0|0);
     $or$cond17$i$i = $348 | $349;
     if ($or$cond17$i$i) {
      $356 = $347;$418 = 1;$419 = $333;
     } else {
      $350 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $351 = HEAP32[$350>>2]|0;
      $352 = (($351) + 12|0);
      $353 = HEAP32[$352>>2]|0;
      FUNCTION_TABLE_vii[$353 & 4095]($350,$$ph23$i$i);
      $356 = $347;$418 = 1;$419 = $333;
     }
    }
    $354 = (($303) + 1)|0;
    $355 = (($356) + ($303<<2)|0);
    HEAP32[$355>>2] = $330;
    $357 = (($356) + ($354<<2)|0);
    HEAP32[$357>>2] = $88;
    $$ph$be$i$i = $418;$$ph23$be$i$i = $356;$$ph24$be$i$i = $419;$$ph26$be$i$i = $89;$$ph27$be$i$i = $i$0$i$i$i;
   }
   $$ph25$be$i$i = (($303) + 2)|0;
   $$ph$i$i = $$ph$be$i$i;$$ph23$i$i = $$ph23$be$i$i;$$ph24$i$i = $$ph24$be$i$i;$$ph25$i$i = $$ph25$be$i$i;$$ph26$i$i = $$ph26$be$i$i;$$ph27$i$i = $$ph27$be$i$i;
  }
  $365 = ($$ph$i$i<<24>>24)==(0);
  $366 = ($$ph23$i$i|0)==(0|0);
  $or$cond$i$i$i = $365 | $366;
  if (!($or$cond$i$i$i)) {
   $367 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $368 = HEAP32[$367>>2]|0;
   $369 = (($368) + 12|0);
   $370 = HEAP32[$369>>2]|0;
   FUNCTION_TABLE_vii[$370 & 4095]($367,$$ph23$i$i);
  }
 }
 $371 = HEAP8[$84>>0]|0;
 $372 = ($371<<24>>24)==(0);
 if (!($372)) {
  $373 = HEAP32[$stackMem$i$i>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem$i$i,$373);
 }
 $374 = (($this) + 44|0);
 $375 = (($this) + 4|0);
 $376 = HEAP32[$375>>2]|0;
 HEAP32[$4>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($374,$376,$4);
 $377 = (($this) + 56|0);
 $378 = HEAP32[$8>>2]|0;
 $379 = (($this) + 64|0);
 $380 = HEAP32[$379>>2]|0;
 $381 = $380 & 2147483647;
 $382 = ($381>>>0)<($378>>>0);
 if ($382) {
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($377,$378);
 }
 $vertTriangles$idx1$val23 = HEAP32[$6>>2]|0;
 $383 = ($vertTriangles$idx1$val23|0)==(0);
 if (!($383)) {
  $384 = (($this) + 60|0);
  $i1$025 = 0;
  while(1) {
   $386 = (($vertTriangles$idx$val) + ($i1$025<<3)|0);
   $387 = HEAP32[$386>>2]|0;
   $388 = HEAP32[$374>>2]|0;
   $389 = (($388) + ($387<<2)|0);
   HEAP32[$389>>2] = $i1$025;
   $390 = HEAP32[$8>>2]|0;
   $391 = ($i1$025>>>0)<($390>>>0);
   L111: do {
    if ($391) {
     $i1$122 = $i1$025;
     while(1) {
      $392 = (($vertTriangles$idx$val) + ($i1$122<<3)|0);
      $393 = HEAP32[$392>>2]|0;
      $394 = ($393|0)==($387|0);
      if (!($394)) {
       $i1$1$lcssa = $i1$122;
       break L111;
      }
      $395 = ((($vertTriangles$idx$val) + ($i1$122<<3)|0) + 4|0);
      $396 = HEAP32[$395>>2]|0;
      HEAP32[$5>>2] = $396;
      $397 = HEAP32[$379>>2]|0;
      $398 = $397 & 2147483647;
      $399 = HEAP32[$384>>2]|0;
      $400 = ($398>>>0)>($399>>>0);
      if ($400) {
       $401 = HEAP32[$377>>2]|0;
       $402 = (($401) + ($399<<2)|0);
       $403 = ($402|0)==(0|0);
       if ($403) {
        $405 = $399;
       } else {
        HEAP32[$402>>2] = $396;
        $$pre$i = HEAP32[$384>>2]|0;
        $405 = $$pre$i;
       }
       $404 = (($405) + 1)|0;
       HEAP32[$384>>2] = $404;
      } else {
       (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($377,$5)|0);
      }
      $406 = (($i1$122) + 1)|0;
      $407 = HEAP32[$8>>2]|0;
      $408 = ($406>>>0)<($407>>>0);
      if ($408) {
       $i1$122 = $406;
      } else {
       $i1$1$lcssa = $406;
       break;
      }
     }
    } else {
     $i1$1$lcssa = $i1$025;
    }
   } while(0);
   $385 = ($i1$1$lcssa>>>0)<($vertTriangles$idx1$val23>>>0);
   if ($385) {
    $i1$025 = $i1$1$lcssa;
   } else {
    break;
   }
  }
 }
 $vertTriangles$idx8$val = HEAP32[$7>>2]|0;
 $409 = $vertTriangles$idx8$val & 2147483647;
 $notlhs$i = ($409|0)==(0);
 $notrhs$i = ($vertTriangles$idx8$val|0)<(0);
 $or$cond$not$i = $notrhs$i | $notlhs$i;
 $410 = ($vertTriangles$idx$val|0)==(0|0);
 $or$cond2$i = $or$cond$not$i | $410;
 if ($or$cond2$i) {
  STACKTOP = sp;return;
 }
 $411 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $412 = HEAP32[$411>>2]|0;
 $413 = (($412) + 12|0);
 $414 = HEAP32[$413>>2]|0;
 FUNCTION_TABLE_vii[$414 & 4095]($411,$vertTriangles$idx$val);
 STACKTOP = sp;return;
}
function __ZN5physx31PxClothGeodesicTetherCookerImpl16findTriNeighborsEv($this) {
 $this = $this|0;
 var $$$i$i$i$i$i$i = 0, $$$i$i$i$i9$i$i = 0, $$0 = 0, $$0$i = 0, $$0$i10 = 0, $$idx6$val = 0, $$ph$be$i$i = 0, $$ph$i$i = 0, $$ph20$be$i$i = 0, $$ph20$i$i = 0, $$ph21$be$i$i = 0, $$ph21$i$i = 0, $$ph22$be$i$i = 0, $$ph22$i$i = 0, $$ph23$be$i$i = 0, $$ph23$i$i = 0, $$ph24$be$i$i = 0, $$ph24$i$i = 0, $$pre$i$i$i$i = 0, $$pre$phiZ2D = 0;
 var $$pre$pre = 0, $$pre$pre$phiZZ2D = 0, $$pre6$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $edges = 0, $edges$idx$val$pre = 0, $edges$idx1$val = 0, $edges$idx2$val = 0, $edges$idx2$val$pre = 0, $edges$idx5$val = 0, $edges$idx9$val = 0, $exitcond$i$i$i = 0, $i$0$i$i$i = 0, $i$0$ph$i$i$i = 0, $i$03$i$i$i = 0, $i$035 = 0, $i3$024 = 0, $i3$1 = 0, $j$0 = 0, $j$0$m$0$i$i$i = 0, $j$0$ph$i$i$i = 0, $j$02$i$i$i = 0;
 var $j$1$i$i$i = 0, $m$01$i$i$i = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, $or$cond$not$i = 0, $or$cond16$i$i = 0, $or$cond2$i = 0, $phitmp = 0, $stackMem$i$i = 0, $this$idx$val$i = 0, $this$idx$val$i14 = 0, $this$idx$val$i19 = 0, $tmp = 0, $tmp$i1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $tmp$i1$i$i$i = sp + 188|0;
 $stackMem$i$i = sp;
 $0 = sp + 8|0;
 $edges = sp + 136|0;
 $1 = sp + 148|0;
 $2 = sp + 152|0;
 $3 = sp + 164|0;
 $4 = sp + 176|0;
 HEAP32[$edges>>2] = 0;
 $5 = (($edges) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($edges) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 68|0);
 $8 = (($this) + 20|0);
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$1>>2] = -1;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($7,$10,$1);
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11>>>0) / 3)&-1;
 $13 = ($11>>>0)>(2);
 if ($13) {
  $14 = (($2) + 4|0);
  $15 = (($2) + 8|0);
  $16 = (($3) + 4|0);
  $17 = (($3) + 8|0);
  $18 = (($4) + 4|0);
  $19 = (($4) + 8|0);
  $i$035 = 0;
  while(1) {
   $20 = ($i$035*3)|0;
   $21 = HEAP32[$8>>2]|0;
   $22 = (($21) + ($20<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($20) + 1)|0;
   $25 = (($21) + ($24<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($20) + 2)|0;
   $28 = (($21) + ($27<<2)|0);
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$2>>2] = $23;
   HEAP32[$14>>2] = $26;
   HEAP32[$15>>2] = $20;
   $30 = ($23|0)>($26|0);
   if ($30) {
    HEAP32[$2>>2] = $26;
    HEAP32[$14>>2] = $23;
   }
   $this$idx$val$i = HEAP32[$6>>2]|0;
   $31 = $this$idx$val$i & 2147483647;
   $32 = HEAP32[$5>>2]|0;
   $33 = ($31>>>0)>($32>>>0);
   if ($33) {
    $34 = HEAP32[$edges>>2]|0;
    $35 = (($34) + (($32*12)|0)|0);
    $36 = ($35|0)==(0|0);
    if (!($36)) {
     ;HEAP32[$35+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$2+8>>2]|0;
    }
    $37 = (($32) + 1)|0;
    HEAP32[$5>>2] = $37;
   } else {
    (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_18MeshEdgeENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($edges,$2)|0);
   }
   HEAP32[$3>>2] = $26;
   HEAP32[$16>>2] = $29;
   HEAP32[$17>>2] = $24;
   $38 = ($26|0)>($29|0);
   if ($38) {
    HEAP32[$3>>2] = $29;
    HEAP32[$16>>2] = $26;
   }
   $this$idx$val$i14 = HEAP32[$6>>2]|0;
   $39 = $this$idx$val$i14 & 2147483647;
   $40 = HEAP32[$5>>2]|0;
   $41 = ($39>>>0)>($40>>>0);
   if ($41) {
    $42 = HEAP32[$edges>>2]|0;
    $43 = (($42) + (($40*12)|0)|0);
    $44 = ($43|0)==(0|0);
    if (!($44)) {
     ;HEAP32[$43+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$3+8>>2]|0;
    }
    $45 = (($40) + 1)|0;
    HEAP32[$5>>2] = $45;
   } else {
    (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_18MeshEdgeENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($edges,$3)|0);
   }
   HEAP32[$4>>2] = $29;
   HEAP32[$18>>2] = $23;
   HEAP32[$19>>2] = $27;
   $46 = ($29|0)>($23|0);
   if ($46) {
    HEAP32[$4>>2] = $23;
    HEAP32[$18>>2] = $29;
   }
   $this$idx$val$i19 = HEAP32[$6>>2]|0;
   $47 = $this$idx$val$i19 & 2147483647;
   $48 = HEAP32[$5>>2]|0;
   $49 = ($47>>>0)>($48>>>0);
   if ($49) {
    $50 = HEAP32[$edges>>2]|0;
    $51 = (($50) + (($48*12)|0)|0);
    $52 = ($51|0)==(0|0);
    if (!($52)) {
     ;HEAP32[$51+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$51+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$4+8>>2]|0;
    }
    $53 = (($48) + 1)|0;
    HEAP32[$5>>2] = $53;
   } else {
    (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_18MeshEdgeENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($edges,$4)|0);
   }
   $54 = (($i$035) + 1)|0;
   $55 = ($54>>>0)<($12>>>0);
   if ($55) {
    $i$035 = $54;
   } else {
    break;
   }
  }
  $edges$idx$val$pre = HEAP32[$edges>>2]|0;
  $edges$idx2$val$pre = HEAP32[$5>>2]|0;
  $phitmp = (($edges$idx2$val$pre) + -1)|0;
  $edges$idx2$val = $phitmp;$edges$idx5$val = $edges$idx$val$pre;
 } else {
  $edges$idx2$val = -1;$edges$idx5$val = 0;
 }
 $56 = $stackMem$i$i;
 $57 = $56;
 HEAP32[$57>>2] = 0;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = 0;
 $60 = (($stackMem$i$i) + 4|0);
 HEAP8[$60>>0] = 0;
 HEAP32[$stackMem$i$i>>2] = $0;
 $61 = ($edges$idx2$val|0)>(0);
 if ($61) {
  $$ph$i$i = 0;$$ph20$i$i = $0;$$ph21$i$i = 32;$$ph22$i$i = 0;$$ph23$i$i = 0;$$ph24$i$i = $edges$idx2$val;
  L39: while(1) {
   $144 = $$ph22$i$i;$63 = $$ph24$i$i;$64 = $$ph23$i$i;
   while(1) {
    $62 = ($63|0)>($64|0);
    if ($62) {
     $65 = (($63) - ($64))|0;
     $66 = ($65>>>0)<(5);
     if ($66) {
      $i$03$i$i$i = $64;
     } else {
      break;
     }
     while(1) {
      $67 = (($i$03$i$i$i) + 1)|0;
      $j$02$i$i$i = $67;$m$01$i$i$i = $i$03$i$i$i;
      while(1) {
       $68 = (($edges$idx5$val) + (($j$02$i$i$i*12)|0)|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = (($edges$idx5$val) + (($m$01$i$i$i*12)|0)|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = ($69|0)==($71|0);
       if ($72) {
        $73 = ((($edges$idx5$val) + (($j$02$i$i$i*12)|0)|0) + 4|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ((($edges$idx5$val) + (($m$01$i$i$i*12)|0)|0) + 4|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($74|0)<($76|0);
        $79 = $77;
       } else {
        $78 = ($69|0)<($71|0);
        $79 = $78;
       }
       $j$0$m$0$i$i$i = $79 ? $j$02$i$i$i : $m$01$i$i$i;
       $80 = (($j$02$i$i$i) + 1)|0;
       $81 = ($j$02$i$i$i|0)<($63|0);
       if ($81) {
        $j$02$i$i$i = $80;$m$01$i$i$i = $j$0$m$0$i$i$i;
       } else {
        break;
       }
      }
      $82 = (($edges$idx5$val) + (($j$0$m$0$i$i$i*12)|0)|0);
      $83 = (($edges$idx5$val) + (($i$03$i$i$i*12)|0)|0);
      ;HEAP32[$tmp$i1$i$i$i+0>>2]=HEAP32[$82+0>>2]|0;HEAP32[$tmp$i1$i$i$i+4>>2]=HEAP32[$82+4>>2]|0;HEAP32[$tmp$i1$i$i$i+8>>2]=HEAP32[$82+8>>2]|0;
      ;HEAP32[$82+0>>2]=HEAP32[$83+0>>2]|0;HEAP32[$82+4>>2]=HEAP32[$83+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$83+8>>2]|0;
      ;HEAP32[$83+0>>2]=HEAP32[$tmp$i1$i$i$i+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$tmp$i1$i$i$i+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$tmp$i1$i$i$i+8>>2]|0;
      $exitcond$i$i$i = ($67|0)==($63|0);
      if ($exitcond$i$i$i) {
       break;
      } else {
       $i$03$i$i$i = $67;
      }
     }
    }
    $199 = ($144|0)==(0);
    if ($199) {
     break L39;
    }
    $200 = (($144) + -1)|0;
    $201 = (($$ph20$i$i) + ($200<<2)|0);
    $202 = HEAP32[$201>>2]|0;
    $203 = (($144) + -2)|0;
    $204 = (($$ph20$i$i) + ($203<<2)|0);
    $205 = HEAP32[$204>>2]|0;
    $144 = $203;$63 = $202;$64 = $205;
   }
   $84 = (($63) + ($64))|0;
   $85 = (($84|0) / 2)&-1;
   $86 = (($edges$idx5$val) + (($85*12)|0)|0);
   $87 = (($edges$idx5$val) + (($64*12)|0)|0);
   $88 = HEAP32[$86>>2]|0;
   $89 = HEAP32[$87>>2]|0;
   $90 = ($88|0)==($89|0);
   if ($90) {
    $91 = ((($edges$idx5$val) + (($85*12)|0)|0) + 4|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ((($edges$idx5$val) + (($64*12)|0)|0) + 4|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($92|0)<($94|0);
    if ($95) {
     label = 40;
    } else {
     $100 = $88;
    }
   } else {
    $96 = ($88|0)<($89|0);
    if ($96) {
     label = 40;
    } else {
     $100 = $89;
    }
   }
   if ((label|0) == 40) {
    label = 0;
    ;HEAP32[$tmp$i1$i$i$i+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$tmp$i1$i$i$i+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$tmp$i1$i$i$i+8>>2]=HEAP32[$87+8>>2]|0;
    ;HEAP32[$87+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$86+8>>2]|0;
    ;HEAP32[$86+0>>2]=HEAP32[$tmp$i1$i$i$i+0>>2]|0;HEAP32[$86+4>>2]=HEAP32[$tmp$i1$i$i$i+4>>2]|0;HEAP32[$86+8>>2]=HEAP32[$tmp$i1$i$i$i+8>>2]|0;
    $$pre$i$i$i$i = HEAP32[$87>>2]|0;
    $100 = $$pre$i$i$i$i;
   }
   $97 = (($edges$idx5$val) + (($63*12)|0)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==($100|0);
   if ($99) {
    $101 = ((($edges$idx5$val) + (($63*12)|0)|0) + 4|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ((($edges$idx5$val) + (($64*12)|0)|0) + 4|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($102|0)<($104|0);
    if ($105) {
     label = 44;
    } else {
     $109 = $100;
    }
   } else {
    $106 = ($98|0)<($100|0);
    if ($106) {
     label = 44;
    } else {
     $109 = $98;
    }
   }
   if ((label|0) == 44) {
    label = 0;
    ;HEAP32[$tmp$i1$i$i$i+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$tmp$i1$i$i$i+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$tmp$i1$i$i$i+8>>2]=HEAP32[$87+8>>2]|0;
    ;HEAP32[$87+0>>2]=HEAP32[$97+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$97+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$97+8>>2]|0;
    ;HEAP32[$97+0>>2]=HEAP32[$tmp$i1$i$i$i+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$tmp$i1$i$i$i+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$tmp$i1$i$i$i+8>>2]|0;
    $$pre6$i$i$i$i = HEAP32[$97>>2]|0;
    $109 = $$pre6$i$i$i$i;
   }
   $107 = HEAP32[$86>>2]|0;
   $108 = ($109|0)==($107|0);
   if ($108) {
    $110 = ((($edges$idx5$val) + (($63*12)|0)|0) + 4|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = ((($edges$idx5$val) + (($85*12)|0)|0) + 4|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = ($111|0)<($113|0);
    if ($114) {
     label = 48;
    }
   } else {
    $115 = ($109|0)<($107|0);
    if ($115) {
     label = 48;
    }
   }
   if ((label|0) == 48) {
    label = 0;
    ;HEAP32[$tmp$i1$i$i$i+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$tmp$i1$i$i$i+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$tmp$i1$i$i$i+8>>2]=HEAP32[$86+8>>2]|0;
    ;HEAP32[$86+0>>2]=HEAP32[$97+0>>2]|0;HEAP32[$86+4>>2]=HEAP32[$97+4>>2]|0;HEAP32[$86+8>>2]=HEAP32[$97+8>>2]|0;
    ;HEAP32[$97+0>>2]=HEAP32[$tmp$i1$i$i$i+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$tmp$i1$i$i$i+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$tmp$i1$i$i$i+8>>2]|0;
   }
   $116 = (($63) + -1)|0;
   $117 = (($edges$idx5$val) + (($116*12)|0)|0);
   ;HEAP32[$tmp$i1$i$i$i+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$tmp$i1$i$i$i+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$tmp$i1$i$i$i+8>>2]=HEAP32[$86+8>>2]|0;
   ;HEAP32[$86+0>>2]=HEAP32[$117+0>>2]|0;HEAP32[$86+4>>2]=HEAP32[$117+4>>2]|0;HEAP32[$86+8>>2]=HEAP32[$117+8>>2]|0;
   ;HEAP32[$117+0>>2]=HEAP32[$tmp$i1$i$i$i+0>>2]|0;HEAP32[$117+4>>2]=HEAP32[$tmp$i1$i$i$i+4>>2]|0;HEAP32[$117+8>>2]=HEAP32[$tmp$i1$i$i$i+8>>2]|0;
   $118 = ((($edges$idx5$val) + (($116*12)|0)|0) + 4|0);
   $i$0$ph$i$i$i = $64;$j$0$ph$i$i$i = $116;
   while(1) {
    $119 = HEAP32[$117>>2]|0;
    $i$0$i$i$i = $i$0$ph$i$i$i;
    while(1) {
     $120 = (($i$0$i$i$i) + 1)|0;
     $121 = (($edges$idx5$val) + (($120*12)|0)|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ($122|0)==($119|0);
     if ($123) {
      $124 = ((($edges$idx5$val) + (($120*12)|0)|0) + 4|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = HEAP32[$118>>2]|0;
      $127 = ($125|0)<($126|0);
      if ($127) {
       $i$0$i$i$i = $120;
       continue;
      } else {
       $j$1$i$i$i = $j$0$ph$i$i$i;
       break;
      }
     } else {
      $128 = ($122|0)<($119|0);
      if ($128) {
       $i$0$i$i$i = $120;
       continue;
      } else {
       $j$1$i$i$i = $j$0$ph$i$i$i;
       break;
      }
     }
    }
    while(1) {
     $129 = (($j$1$i$i$i) + -1)|0;
     $130 = (($edges$idx5$val) + (($129*12)|0)|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($119|0)==($131|0);
     if ($132) {
      $133 = HEAP32[$118>>2]|0;
      $134 = ((($edges$idx5$val) + (($129*12)|0)|0) + 4|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ($133|0)<($135|0);
      if ($136) {
       $j$1$i$i$i = $129;
       continue;
      } else {
       break;
      }
     } else {
      $137 = ($119|0)<($131|0);
      if ($137) {
       $j$1$i$i$i = $129;
       continue;
      } else {
       break;
      }
     }
    }
    $138 = ($120|0)<($129|0);
    if (!($138)) {
     break;
    }
    ;HEAP32[$tmp$i1$i$i$i+0>>2]=HEAP32[$121+0>>2]|0;HEAP32[$tmp$i1$i$i$i+4>>2]=HEAP32[$121+4>>2]|0;HEAP32[$tmp$i1$i$i$i+8>>2]=HEAP32[$121+8>>2]|0;
    ;HEAP32[$121+0>>2]=HEAP32[$130+0>>2]|0;HEAP32[$121+4>>2]=HEAP32[$130+4>>2]|0;HEAP32[$121+8>>2]=HEAP32[$130+8>>2]|0;
    ;HEAP32[$130+0>>2]=HEAP32[$tmp$i1$i$i$i+0>>2]|0;HEAP32[$130+4>>2]=HEAP32[$tmp$i1$i$i$i+4>>2]|0;HEAP32[$130+8>>2]=HEAP32[$tmp$i1$i$i$i+8>>2]|0;
    $i$0$ph$i$i$i = $120;$j$0$ph$i$i$i = $129;
   }
   ;HEAP32[$tmp$i1$i$i$i+0>>2]=HEAP32[$121+0>>2]|0;HEAP32[$tmp$i1$i$i$i+4>>2]=HEAP32[$121+4>>2]|0;HEAP32[$tmp$i1$i$i$i+8>>2]=HEAP32[$121+8>>2]|0;
   ;HEAP32[$121+0>>2]=HEAP32[$117+0>>2]|0;HEAP32[$121+4>>2]=HEAP32[$117+4>>2]|0;HEAP32[$121+8>>2]=HEAP32[$117+8>>2]|0;
   ;HEAP32[$117+0>>2]=HEAP32[$tmp$i1$i$i$i+0>>2]|0;HEAP32[$117+4>>2]=HEAP32[$tmp$i1$i$i$i+4>>2]|0;HEAP32[$117+8>>2]=HEAP32[$tmp$i1$i$i$i+8>>2]|0;
   $139 = (($120) - ($64))|0;
   $140 = (($63) - ($120))|0;
   $141 = ($139|0)<($140|0);
   if ($141) {
    $142 = (($$ph21$i$i) + -1)|0;
    $143 = ($144>>>0)<($142>>>0);
    if ($143) {
     $168 = $$ph20$i$i;$275 = $$ph$i$i;$276 = $$ph21$i$i;
    } else {
     $145 = $$ph21$i$i << 1;
     $146 = $$ph21$i$i << 3;
     $147 = ($146|0)==(0);
     if ($147) {
      $159 = 0;
     } else {
      $148 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = (($149) + 8|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = (__Z15PxGetFoundationv()|0);
      $153 = HEAP32[$152>>2]|0;
      $154 = (($153) + 24|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = (FUNCTION_TABLE_ii[$155 & 4095]($152)|0);
      $$$i$i$i$i9$i$i = $156 ? 410008 : 409768;
      $157 = (FUNCTION_TABLE_iiiiii[$151 & 255]($148,$146,$$$i$i$i$i9$i$i,409680,148)|0);
      $159 = $157;
     }
     $158 = $144 << 2;
     _memcpy(($159|0),($$ph20$i$i|0),($158|0))|0;
     $160 = ($$ph$i$i<<24>>24)==(0);
     $161 = ($$ph20$i$i|0)==(0|0);
     $or$cond$i$i = $160 | $161;
     if ($or$cond$i$i) {
      $168 = $159;$275 = 1;$276 = $145;
     } else {
      $162 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $163 = HEAP32[$162>>2]|0;
      $164 = (($163) + 12|0);
      $165 = HEAP32[$164>>2]|0;
      FUNCTION_TABLE_vii[$165 & 4095]($162,$$ph20$i$i);
      $168 = $159;$275 = 1;$276 = $145;
     }
    }
    $166 = (($144) + 1)|0;
    $167 = (($168) + ($144<<2)|0);
    HEAP32[$167>>2] = $64;
    $169 = (($168) + ($166<<2)|0);
    HEAP32[$169>>2] = $i$0$i$i$i;
    $170 = (($i$0$i$i$i) + 2)|0;
    $$ph$be$i$i = $275;$$ph20$be$i$i = $168;$$ph21$be$i$i = $276;$$ph23$be$i$i = $170;$$ph24$be$i$i = $63;
   } else {
    $171 = (($i$0$i$i$i) + 2)|0;
    $172 = (($$ph21$i$i) + -1)|0;
    $173 = ($144>>>0)<($172>>>0);
    if ($173) {
     $197 = $$ph20$i$i;$277 = $$ph$i$i;$278 = $$ph21$i$i;
    } else {
     $174 = $$ph21$i$i << 1;
     $175 = $$ph21$i$i << 3;
     $176 = ($175|0)==(0);
     if ($176) {
      $188 = 0;
     } else {
      $177 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $178 = HEAP32[$177>>2]|0;
      $179 = (($178) + 8|0);
      $180 = HEAP32[$179>>2]|0;
      $181 = (__Z15PxGetFoundationv()|0);
      $182 = HEAP32[$181>>2]|0;
      $183 = (($182) + 24|0);
      $184 = HEAP32[$183>>2]|0;
      $185 = (FUNCTION_TABLE_ii[$184 & 4095]($181)|0);
      $$$i$i$i$i$i$i = $185 ? 410008 : 409768;
      $186 = (FUNCTION_TABLE_iiiiii[$180 & 255]($177,$175,$$$i$i$i$i$i$i,409680,148)|0);
      $188 = $186;
     }
     $187 = $144 << 2;
     _memcpy(($188|0),($$ph20$i$i|0),($187|0))|0;
     $189 = ($$ph$i$i<<24>>24)==(0);
     $190 = ($$ph20$i$i|0)==(0|0);
     $or$cond16$i$i = $189 | $190;
     if ($or$cond16$i$i) {
      $197 = $188;$277 = 1;$278 = $174;
     } else {
      $191 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $192 = HEAP32[$191>>2]|0;
      $193 = (($192) + 12|0);
      $194 = HEAP32[$193>>2]|0;
      FUNCTION_TABLE_vii[$194 & 4095]($191,$$ph20$i$i);
      $197 = $188;$277 = 1;$278 = $174;
     }
    }
    $195 = (($144) + 1)|0;
    $196 = (($197) + ($144<<2)|0);
    HEAP32[$196>>2] = $171;
    $198 = (($197) + ($195<<2)|0);
    HEAP32[$198>>2] = $63;
    $$ph$be$i$i = $277;$$ph20$be$i$i = $197;$$ph21$be$i$i = $278;$$ph23$be$i$i = $64;$$ph24$be$i$i = $i$0$i$i$i;
   }
   $$ph22$be$i$i = (($144) + 2)|0;
   $$ph$i$i = $$ph$be$i$i;$$ph20$i$i = $$ph20$be$i$i;$$ph21$i$i = $$ph21$be$i$i;$$ph22$i$i = $$ph22$be$i$i;$$ph23$i$i = $$ph23$be$i$i;$$ph24$i$i = $$ph24$be$i$i;
  }
  $206 = ($$ph$i$i<<24>>24)==(0);
  $207 = ($$ph20$i$i|0)==(0|0);
  $or$cond$i$i$i = $206 | $207;
  if (!($or$cond$i$i$i)) {
   $208 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = (($209) + 12|0);
   $211 = HEAP32[$210>>2]|0;
   FUNCTION_TABLE_vii[$211 & 4095]($208,$$ph20$i$i);
  }
 }
 $212 = HEAP8[$60>>0]|0;
 $213 = ($212<<24>>24)==(0);
 if (!($213)) {
  $214 = HEAP32[$stackMem$i$i>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem$i$i,$214);
 }
 $edges$idx1$val = HEAP32[$5>>2]|0;
 $215 = ($edges$idx1$val|0)>(0);
 L114: do {
  if ($215) {
   $$idx6$val = HEAP32[$8>>2]|0;
   $i3$024 = 0;
   while(1) {
    $216 = ((($edges$idx5$val) + (($i3$024*12)|0)|0) + 8|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = (($$idx6$val) + ($217<<2)|0);
    $219 = HEAP32[$218>>2]|0;
    $220 = (($edges$idx5$val) + (($i3$024*12)|0)|0);
    $221 = HEAP32[$220>>2]|0;
    $222 = ($221|0)==($219|0);
    if ($222) {
     $223 = (($217|0) % 3)&-1;
     $224 = ($223|0)<(2);
     $225 = $224 ? 1 : -2;
     $226 = (($225) + ($217))|0;
     $227 = (($$idx6$val) + ($226<<2)|0);
     $228 = HEAP32[$227>>2]|0;
     $229 = ((($edges$idx5$val) + (($i3$024*12)|0)|0) + 4|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = ($230|0)==($228|0);
     if ($231) {
      $$0$i10 = 1;$$pre$phiZ2D = $229;
     } else {
      $$pre$pre$phiZZ2D = $229;
      label = 85;
     }
    } else {
     $$pre$pre = ((($edges$idx5$val) + (($i3$024*12)|0)|0) + 4|0);
     $$pre$pre$phiZZ2D = $$pre$pre;
     label = 85;
    }
    if ((label|0) == 85) {
     label = 0;
     $$0$i10 = 0;$$pre$phiZ2D = $$pre$pre$phiZZ2D;
    }
    $i3$1 = $i3$024;
    while(1) {
     $232 = (($i3$1) + 1)|0;
     $233 = ($232|0)<($edges$idx1$val|0);
     if (!($233)) {
      break;
     }
     $234 = (($edges$idx5$val) + (($232*12)|0)|0);
     $235 = HEAP32[$234>>2]|0;
     $236 = ($235|0)==($221|0);
     if (!($236)) {
      break;
     }
     $237 = ((($edges$idx5$val) + (($232*12)|0)|0) + 4|0);
     $238 = HEAP32[$237>>2]|0;
     $239 = HEAP32[$$pre$phiZ2D>>2]|0;
     $240 = ($238|0)==($239|0);
     if ($240) {
      $i3$1 = $232;
     } else {
      break;
     }
    }
    $241 = (($232) - ($i3$024))|0;
    $242 = ($241|0)>(2);
    if ($242) {
     $$0 = 1;
     break L114;
    } else {
     $j$0 = $i3$024;
    }
    while(1) {
     $243 = (($j$0) + 1)|0;
     $244 = ($243|0)<($232|0);
     if (!($244)) {
      break;
     }
     $245 = ((($edges$idx5$val) + (($243*12)|0)|0) + 8|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = (($$idx6$val) + ($246<<2)|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = (($edges$idx5$val) + (($243*12)|0)|0);
     $250 = HEAP32[$249>>2]|0;
     $251 = ($250|0)==($248|0);
     if ($251) {
      $252 = (($246|0) % 3)&-1;
      $253 = ($252|0)<(2);
      $254 = $253 ? 1 : -2;
      $255 = (($254) + ($246))|0;
      $256 = (($$idx6$val) + ($255<<2)|0);
      $257 = HEAP32[$256>>2]|0;
      $258 = ((($edges$idx5$val) + (($243*12)|0)|0) + 4|0);
      $259 = HEAP32[$258>>2]|0;
      $260 = ($259|0)==($257|0);
      if ($260) {
       $$0$i = 1;
      } else {
       label = 94;
      }
     } else {
      label = 94;
     }
     if ((label|0) == 94) {
      label = 0;
      $$0$i = 0;
     }
     $261 = (($246>>>0) / 3)&-1;
     $262 = HEAP32[$216>>2]|0;
     $263 = HEAP32[$7>>2]|0;
     $264 = (($263) + ($262<<2)|0);
     HEAP32[$264>>2] = $261;
     $265 = HEAP32[$216>>2]|0;
     $266 = (($265>>>0) / 3)&-1;
     $267 = HEAP32[$245>>2]|0;
     $268 = (($263) + ($267<<2)|0);
     HEAP32[$268>>2] = $266;
     $tmp = $$0$i10 ^ $$0$i;
     if ($tmp) {
      $j$0 = $243;
     } else {
      $$0 = 2;
      break L114;
     }
    }
    if ($233) {
     $i3$024 = $232;
    } else {
     $$0 = 0;
     break;
    }
   }
  } else {
   $$0 = 0;
  }
 } while(0);
 $edges$idx9$val = HEAP32[$6>>2]|0;
 $269 = $edges$idx9$val & 2147483647;
 $notlhs$i = ($269|0)==(0);
 $notrhs$i = ($edges$idx9$val|0)<(0);
 $or$cond$not$i = $notrhs$i | $notlhs$i;
 $270 = ($edges$idx5$val|0)==(0|0);
 $or$cond2$i = $or$cond$not$i | $270;
 if ($or$cond2$i) {
  STACKTOP = sp;return ($$0|0);
 }
 $271 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $272 = HEAP32[$271>>2]|0;
 $273 = (($272) + 12|0);
 $274 = HEAP32[$273>>2]|0;
 FUNCTION_TABLE_vii[$274 & 4095]($271,$edges$idx5$val);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx31PxClothGeodesicTetherCookerImpl23computeGeodesicDistanceEjjRi($this,$i,$parent,$errorCode) {
 $this = $this|0;
 $i = $i|0;
 $parent = $parent|0;
 $errorCode = $errorCode|0;
 var $$$$i$i = 0, $$$i = 0, $$$i$i = 0, $$$i38$i = 0, $$$i41$i = 0, $$0 = Math_fround(0), $$1$i = 0, $$2$i = 0, $$3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0;
 var $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0;
 var $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0);
 var $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0);
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0;
 var $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0);
 var $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0);
 var $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0);
 var $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = 0, $365 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eid$0$i = 0, $fabsf$i$i = Math_fround(0), $fabsf$i33$i = Math_fround(0), $geodesicDistance$05 = Math_fround(0), $i0$0$i = 0;
 var $i1$0$i = 0, $i2$0$i = 0, $or$cond$i$i = 0, $or$cond$i37$i = 0, $or$cond$i40$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond130$i = 0, $or$cond15$i = 0, $or$cond3$i = 0, $or$cond5$i = 0, $or$cond7$i = 0, $path = 0, $pathcnt$04 = 0, $status$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $path = sp;
 $0 = ($i|0)==($parent|0);
 if ($0) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 HEAP32[$errorCode>>2] = 0;
 $1 = (__ZN5physx31PxClothGeodesicTetherCookerImpl25computeVertexIntersectionEjjRN12_GLOBAL__N_116PathIntersectionE($this,$parent,$i,$path)|0);
 $2 = ($1|0)<(0);
 if ($2) {
  HEAP32[$errorCode>>2] = -1;
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $3 = ($1|0)>(0);
 if (!($3)) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $4 = (($path) + 12|0);
 $5 = (($path) + 4|0);
 $6 = (($path) + 8|0);
 $7 = (($this) + 20|0);
 $8 = (($this) + 8|0);
 $9 = (($this) + 68|0);
 $geodesicDistance$05 = Math_fround(0.0);$pathcnt$04 = 0;
 L11: while(1) {
  $12 = Math_fround(HEAPF32[$4>>2]);
  $13 = Math_fround($geodesicDistance$05 + $12);
  $14 = HEAP32[$path>>2]|0;
  $15 = ($14|0)==(0);
  $16 = HEAP32[$5>>2]|0;
  do {
   if ($15) {
    $17 = Math_fround(HEAPF32[$6>>2]);
    $18 = (($16|0) % 3)&-1;
    $19 = (($16) - ($18))|0;
    $20 = HEAP32[$7>>2]|0;
    $21 = (($20) + ($16<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($18) + 1)|0;
    $24 = (($23|0) % 3)&-1;
    $25 = (($19) + ($24))|0;
    $26 = (($20) + ($25<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = HEAP32[$8>>2]|0;
    $29 = (($28) + (($22*12)|0)|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = ((($28) + (($22*12)|0)|0) + 4|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = ((($28) + (($22*12)|0)|0) + 8|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($28) + (($27*12)|0)|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = ((($28) + (($27*12)|0)|0) + 4|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = ((($28) + (($27*12)|0)|0) + 8|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = Math_fround($36 - $30);
    $42 = Math_fround($38 - $32);
    $43 = Math_fround($40 - $34);
    $44 = Math_fround($17 * $41);
    $45 = Math_fround($17 * $42);
    $46 = Math_fround($17 * $43);
    $47 = Math_fround($30 + $44);
    $48 = Math_fround($32 + $45);
    $49 = Math_fround($34 + $46);
    $50 = (($28) + (($parent*12)|0)|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = Math_fround($51 - $47);
    $53 = ((($28) + (($parent*12)|0)|0) + 4|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = Math_fround($54 - $48);
    $56 = ((($28) + (($parent*12)|0)|0) + 8|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = Math_fround($57 - $49);
    $59 = HEAP32[$9>>2]|0;
    $60 = (($59) + ($16<<2)|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)==(-1);
    if ($62) {
     $63 = Math_fround($41 * $52);
     $64 = Math_fround($42 * $55);
     $65 = Math_fround($63 + $64);
     $66 = Math_fround($43 * $58);
     $67 = Math_fround($65 + $66);
     $68 = $67 > Math_fround(0.0);
     $69 = $68 ? $27 : $22;
     $70 = (($28) + (($69*12)|0)|0);
     $71 = Math_fround(HEAPF32[$70>>2]);
     $72 = Math_fround($71 - $47);
     $73 = ((($28) + (($69*12)|0)|0) + 4|0);
     $74 = Math_fround(HEAPF32[$73>>2]);
     $75 = Math_fround($74 - $48);
     $76 = ((($28) + (($69*12)|0)|0) + 8|0);
     $77 = Math_fround(HEAPF32[$76>>2]);
     $78 = Math_fround($77 - $49);
     $79 = Math_fround($72 * $72);
     $80 = Math_fround($75 * $75);
     $81 = Math_fround($79 + $80);
     $82 = Math_fround($78 * $78);
     $83 = Math_fround($81 + $82);
     $84 = (Math_fround(Math_sqrt((Math_fround($83)))));
     HEAP32[$path>>2] = 1;
     HEAP32[$5>>2] = $69;
     HEAPF32[$6>>2] = Math_fround(0.0);
     HEAPF32[$4>>2] = $84;
     $status$11 = 1;
     break;
    }
    $85 = ($61*3)|0;
    $86 = (($20) + ($85<<2)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = (($85) + 1)|0;
    $89 = (($20) + ($88<<2)|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = (($85) + 2)|0;
    $92 = (($20) + ($91<<2)|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ($87|0)==($22|0);
    $95 = ($90|0)==($27|0);
    $or$cond$i40$i = $94 & $95;
    if ($or$cond$i40$i) {
     $eid$0$i = 0;$i0$0$i = $22;$i1$0$i = $27;$i2$0$i = $93;
    } else {
     $96 = ($87|0)==($27|0);
     $97 = ($90|0)==($22|0);
     $$$i41$i = $96 & $97;
     if ($$$i41$i) {
      $eid$0$i = 0;$i0$0$i = $27;$i1$0$i = $22;$i2$0$i = $93;
     } else {
      $98 = ($93|0)==($27|0);
      $or$cond$i37$i = $97 & $98;
      $99 = ($93|0)==($22|0);
      $$$i38$i = $95 & $99;
      $or$cond130$i = $or$cond$i37$i | $$$i38$i;
      if ($or$cond130$i) {
       $eid$0$i = 1;$i0$0$i = $90;$i1$0$i = $93;$i2$0$i = $87;
      } else {
       $or$cond$i$i = $99 & $96;
       $$$i$i = $98 & $94;
       $$$$i$i = $or$cond$i$i | $$$i$i;
       $$$i = $$$$i$i ? $90 : $93;
       $$1$i = $$$$i$i ? $87 : $90;
       $$2$i = $$$$i$i ? $93 : $87;
       $$3$i = $$$$i$i ? 2 : $18;
       $eid$0$i = $$3$i;$i0$0$i = $$2$i;$i1$0$i = $$1$i;$i2$0$i = $$$i;
      }
     }
    }
    $100 = ($i2$0$i|0)==($parent|0);
    if ($100) {
     $101 = Math_fround($52 * $52);
     $102 = Math_fround($55 * $55);
     $103 = Math_fround($101 + $102);
     $104 = Math_fround($58 * $58);
     $105 = Math_fround($103 + $104);
     $106 = (Math_fround(Math_sqrt((Math_fround($105)))));
     HEAP32[$path>>2] = 1;
     HEAP32[$5>>2] = $parent;
     HEAPF32[$6>>2] = Math_fround(0.0);
     HEAPF32[$4>>2] = $106;
     $status$11 = 1;
     break;
    }
    $107 = (($28) + (($i0$0$i*12)|0)|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $109 = ((($28) + (($i0$0$i*12)|0)|0) + 4|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $111 = ((($28) + (($i0$0$i*12)|0)|0) + 8|0);
    $112 = Math_fround(HEAPF32[$111>>2]);
    $113 = (($28) + (($i1$0$i*12)|0)|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = ((($28) + (($i1$0$i*12)|0)|0) + 4|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = ((($28) + (($i1$0$i*12)|0)|0) + 8|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = (($28) + (($i2$0$i*12)|0)|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = ((($28) + (($i2$0$i*12)|0)|0) + 4|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = ((($28) + (($i2$0$i*12)|0)|0) + 8|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = Math_fround($108 - $120);
    $126 = Math_fround($110 - $122);
    $127 = Math_fround($112 - $124);
    $128 = Math_fround($114 - $120);
    $129 = Math_fround($116 - $122);
    $130 = Math_fround($118 - $124);
    $131 = Math_fround($126 * $130);
    $132 = Math_fround($129 * $127);
    $133 = Math_fround($131 - $132);
    $134 = Math_fround($128 * $127);
    $135 = Math_fround($125 * $130);
    $136 = Math_fround($134 - $135);
    $137 = Math_fround($125 * $129);
    $138 = Math_fround($128 * $126);
    $139 = Math_fround($137 - $138);
    $140 = Math_fround($133 * $133);
    $141 = Math_fround($136 * $136);
    $142 = Math_fround($140 + $141);
    $143 = Math_fround($139 * $139);
    $144 = Math_fround($143 + $142);
    $145 = $144 > Math_fround(0.0);
    if ($145) {
     $146 = (Math_fround(Math_sqrt((Math_fround($144)))));
     $147 = Math_fround(Math_fround(1.0) / $146);
     $148 = Math_fround($133 * $147);
     $149 = Math_fround($136 * $147);
     $150 = Math_fround($139 * $147);
     $152 = $148;$154 = $149;$157 = $150;
    } else {
     $152 = Math_fround(0.0);$154 = Math_fround(0.0);$157 = Math_fround(0.0);
    }
    $151 = Math_fround($52 * $152);
    $153 = Math_fround($55 * $154);
    $155 = Math_fround($153 + $151);
    $156 = Math_fround($58 * $157);
    $158 = Math_fround($156 + $155);
    $159 = Math_fround($152 * $158);
    $160 = Math_fround($154 * $158);
    $161 = Math_fround($157 * $158);
    $162 = Math_fround($52 - $159);
    $163 = Math_fround($55 - $160);
    $164 = Math_fround($58 - $161);
    $165 = Math_fround($162 * $162);
    $166 = Math_fround($163 * $163);
    $167 = Math_fround($165 + $166);
    $168 = Math_fround($164 * $164);
    $169 = Math_fround($168 + $167);
    $170 = $169 > Math_fround(0.0);
    if ($170) {
     $171 = (Math_fround(Math_sqrt((Math_fround($169)))));
     $172 = Math_fround(Math_fround(1.0) / $171);
     $173 = Math_fround($162 * $172);
     $174 = Math_fround($163 * $172);
     $175 = Math_fround($164 * $172);
     $185 = $173;$187 = $174;$190 = $175;
    } else {
     $185 = Math_fround(0.0);$187 = Math_fround(0.0);$190 = Math_fround(0.0);
    }
    $176 = Math_fround($47 - $120);
    $177 = Math_fround($48 - $122);
    $178 = Math_fround($49 - $124);
    $179 = Math_fround($125 * $125);
    $180 = Math_fround($126 * $126);
    $181 = Math_fround($179 + $180);
    $182 = Math_fround($127 * $127);
    $183 = Math_fround($181 + $182);
    $184 = Math_fround($125 * $185);
    $186 = Math_fround($126 * $187);
    $188 = Math_fround($186 + $184);
    $189 = Math_fround($127 * $190);
    $191 = Math_fround($189 + $188);
    $192 = Math_fround($185 * $185);
    $193 = Math_fround($187 * $187);
    $194 = Math_fround($193 + $192);
    $195 = Math_fround($190 * $190);
    $196 = Math_fround($195 + $194);
    $197 = Math_fround($176 * $125);
    $198 = Math_fround($177 * $126);
    $199 = Math_fround($197 + $198);
    $200 = Math_fround($178 * $127);
    $201 = Math_fround($199 + $200);
    $202 = Math_fround($176 * $185);
    $203 = Math_fround($177 * $187);
    $204 = Math_fround($203 + $202);
    $205 = Math_fround($178 * $190);
    $206 = Math_fround($205 + $204);
    $207 = Math_fround(-$206);
    $208 = Math_fround($183 * $196);
    $209 = Math_fround($191 * $191);
    $210 = Math_fround($208 - $209);
    $fabsf$i33$i = (Math_fround(Math_abs((Math_fround($210)))));
    $211 = $fabsf$i33$i < Math_fround(9.99999974737875163555E-5);
    if (!($211)) {
     $212 = Math_fround(Math_fround(1.0) / $210);
     $213 = Math_fround($196 * $212);
     $214 = Math_fround($201 * $213);
     $215 = Math_fround($191 * $212);
     $216 = Math_fround($215 * $207);
     $217 = Math_fround($214 + $216);
     $218 = Math_fround($201 * $215);
     $219 = Math_fround($183 * $212);
     $220 = Math_fround($219 * $207);
     $221 = Math_fround($218 + $220);
     $222 = $217 >= Math_fround(-9.99999974737875163555E-6);
     $223 = $217 <= Math_fround(1.00001001358032226563);
     $or$cond3$i = $222 & $223;
     $224 = $221 > Math_fround(-9.99999974737875163555E-6);
     $or$cond5$i = $or$cond3$i & $224;
     if ($or$cond5$i) {
      $225 = $217 < Math_fround(9.99999974737875163555E-6);
      $226 = $217 > Math_fround(0.999989986419677734375);
      $or$cond7$i = $225 | $226;
      if ($or$cond7$i) {
       HEAP32[$path>>2] = 1;
       $227 = $225 ? $i2$0$i : $i0$0$i;
       HEAP32[$5>>2] = $227;
       $228 = (($28) + (($227*12)|0)|0);
       $229 = Math_fround(HEAPF32[$228>>2]);
       $230 = Math_fround($229 - $47);
       $231 = ((($28) + (($227*12)|0)|0) + 4|0);
       $232 = Math_fround(HEAPF32[$231>>2]);
       $233 = Math_fround($232 - $48);
       $234 = ((($28) + (($227*12)|0)|0) + 8|0);
       $235 = Math_fround(HEAPF32[$234>>2]);
       $236 = Math_fround($235 - $49);
       $237 = Math_fround($230 * $230);
       $238 = Math_fround($233 * $233);
       $239 = Math_fround($237 + $238);
       $240 = Math_fround($236 * $236);
       $241 = Math_fround($239 + $240);
       $242 = (Math_fround(Math_sqrt((Math_fround($241)))));
       HEAPF32[$4>>2] = $242;
       $status$11 = 1;
       break;
      } else {
       $243 = Math_fround($125 * $217);
       $244 = Math_fround($126 * $217);
       $245 = Math_fround($127 * $217);
       $246 = Math_fround($120 + $243);
       $247 = Math_fround($122 + $244);
       $248 = Math_fround($124 + $245);
       $249 = (($eid$0$i) + 2)|0;
       $250 = (($249|0) % 3)&-1;
       $251 = (($250) + ($85))|0;
       $252 = Math_fround($246 - $47);
       $253 = Math_fround($247 - $48);
       $254 = Math_fround($248 - $49);
       $255 = Math_fround($252 * $252);
       $256 = Math_fround($253 * $253);
       $257 = Math_fround($255 + $256);
       $258 = Math_fround($254 * $254);
       $259 = Math_fround($258 + $257);
       $260 = (Math_fround(Math_sqrt((Math_fround($259)))));
       HEAP32[$path>>2] = 0;
       HEAP32[$5>>2] = $251;
       HEAPF32[$6>>2] = $217;
       HEAPF32[$4>>2] = $260;
       $status$11 = 1;
       break;
      }
     }
    }
    $261 = Math_fround($47 - $114);
    $262 = Math_fround($48 - $116);
    $263 = Math_fround($49 - $118);
    $264 = Math_fround($120 - $114);
    $265 = Math_fround($122 - $116);
    $266 = Math_fround($124 - $118);
    $267 = Math_fround($264 * $264);
    $268 = Math_fround($265 * $265);
    $269 = Math_fround($267 + $268);
    $270 = Math_fround($266 * $266);
    $271 = Math_fround($269 + $270);
    $272 = Math_fround($264 * $185);
    $273 = Math_fround($265 * $187);
    $274 = Math_fround($273 + $272);
    $275 = Math_fround($266 * $190);
    $276 = Math_fround($275 + $274);
    $277 = Math_fround($261 * $264);
    $278 = Math_fround($262 * $265);
    $279 = Math_fround($277 + $278);
    $280 = Math_fround($263 * $266);
    $281 = Math_fround($279 + $280);
    $282 = Math_fround($261 * $185);
    $283 = Math_fround($262 * $187);
    $284 = Math_fround($283 + $282);
    $285 = Math_fround($263 * $190);
    $286 = Math_fround($285 + $284);
    $287 = Math_fround(-$286);
    $288 = Math_fround($271 * $196);
    $289 = Math_fround($276 * $276);
    $290 = Math_fround($288 - $289);
    $fabsf$i$i = (Math_fround(Math_abs((Math_fround($290)))));
    $291 = $fabsf$i$i < Math_fround(9.99999974737875163555E-5);
    if (!($291)) {
     $292 = Math_fround(Math_fround(1.0) / $290);
     $293 = Math_fround($196 * $292);
     $294 = Math_fround($281 * $293);
     $295 = Math_fround($276 * $292);
     $296 = Math_fround($295 * $287);
     $297 = Math_fround($294 + $296);
     $298 = Math_fround($281 * $295);
     $299 = Math_fround($271 * $292);
     $300 = Math_fround($299 * $287);
     $301 = Math_fround($298 + $300);
     $302 = $297 >= Math_fround(-9.99999974737875163555E-6);
     $303 = $297 <= Math_fround(1.00001001358032226563);
     $or$cond11$i = $302 & $303;
     $304 = $301 > Math_fround(-9.99999974737875163555E-6);
     $or$cond13$i = $or$cond11$i & $304;
     if ($or$cond13$i) {
      $305 = $297 < Math_fround(9.99999974737875163555E-6);
      $306 = $297 > Math_fround(0.999989986419677734375);
      $or$cond15$i = $305 | $306;
      if ($or$cond15$i) {
       HEAP32[$path>>2] = 1;
       $307 = $305 ? $i1$0$i : $i2$0$i;
       HEAP32[$5>>2] = $307;
       $308 = (($28) + (($307*12)|0)|0);
       $309 = Math_fround(HEAPF32[$308>>2]);
       $310 = Math_fround($309 - $47);
       $311 = ((($28) + (($307*12)|0)|0) + 4|0);
       $312 = Math_fround(HEAPF32[$311>>2]);
       $313 = Math_fround($312 - $48);
       $314 = ((($28) + (($307*12)|0)|0) + 8|0);
       $315 = Math_fround(HEAPF32[$314>>2]);
       $316 = Math_fround($315 - $49);
       $317 = Math_fround($310 * $310);
       $318 = Math_fround($313 * $313);
       $319 = Math_fround($317 + $318);
       $320 = Math_fround($316 * $316);
       $321 = Math_fround($319 + $320);
       $322 = (Math_fround(Math_sqrt((Math_fround($321)))));
       HEAPF32[$4>>2] = $322;
       $status$11 = 1;
       break;
      } else {
       $323 = Math_fround($264 * $297);
       $324 = Math_fround($265 * $297);
       $325 = Math_fround($266 * $297);
       $326 = Math_fround($114 + $323);
       $327 = Math_fround($116 + $324);
       $328 = Math_fround($118 + $325);
       $329 = (($eid$0$i) + 1)|0;
       $330 = (($329|0) % 3)&-1;
       $331 = (($330) + ($85))|0;
       $332 = Math_fround($326 - $47);
       $333 = Math_fround($327 - $48);
       $334 = Math_fround($328 - $49);
       $335 = Math_fround($332 * $332);
       $336 = Math_fround($333 * $333);
       $337 = Math_fround($335 + $336);
       $338 = Math_fround($334 * $334);
       $339 = Math_fround($338 + $337);
       $340 = (Math_fround(Math_sqrt((Math_fround($339)))));
       HEAP32[$path>>2] = 0;
       HEAP32[$5>>2] = $331;
       HEAPF32[$6>>2] = $297;
       HEAPF32[$4>>2] = $340;
       $status$11 = 1;
       break;
      }
     }
    }
    $341 = Math_fround($41 * $185);
    $342 = Math_fround($42 * $187);
    $343 = Math_fround($342 + $341);
    $344 = Math_fround($43 * $190);
    $345 = Math_fround($344 + $343);
    HEAP32[$path>>2] = 1;
    $346 = $345 > Math_fround(0.0);
    $347 = $346 ? $27 : $22;
    HEAP32[$5>>2] = $347;
    $348 = (($28) + (($347*12)|0)|0);
    $349 = Math_fround(HEAPF32[$348>>2]);
    $350 = Math_fround($349 - $47);
    $351 = ((($28) + (($347*12)|0)|0) + 4|0);
    $352 = Math_fround(HEAPF32[$351>>2]);
    $353 = Math_fround($352 - $48);
    $354 = ((($28) + (($347*12)|0)|0) + 8|0);
    $355 = Math_fround(HEAPF32[$354>>2]);
    $356 = Math_fround($355 - $49);
    $357 = Math_fround($350 * $350);
    $358 = Math_fround($353 * $353);
    $359 = Math_fround($357 + $358);
    $360 = Math_fround($356 * $356);
    $361 = Math_fround($359 + $360);
    $362 = (Math_fround(Math_sqrt((Math_fround($361)))));
    HEAPF32[$4>>2] = $362;
    $status$11 = 1;
   } else {
    $363 = (__ZN5physx31PxClothGeodesicTetherCookerImpl25computeVertexIntersectionEjjRN12_GLOBAL__N_116PathIntersectionE($this,$parent,$16,$path)|0);
    $364 = ($363|0)<(0);
    if ($364) {
     label = 33;
     break L11;
    } else {
     $status$11 = $363;
    }
   }
  } while(0);
  $365 = ($pathcnt$04|0)>(1000);
  if ($365) {
   label = 35;
   break;
  }
  $10 = ($status$11|0)>(0);
  if (!($10)) {
   $$0 = $13;
   label = 36;
   break;
  }
  $11 = (($pathcnt$04) + 1)|0;
  $geodesicDistance$05 = $13;$pathcnt$04 = $11;
 }
 if ((label|0) == 33) {
  HEAP32[$errorCode>>2] = -2;
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 else if ((label|0) == 35) {
  HEAP32[$errorCode>>2] = -3;
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 else if ((label|0) == 36) {
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZN5physx31PxClothGeodesicTetherCookerImpl25computeVertexIntersectionEjjRN12_GLOBAL__N_116PathIntersectionE($this,$parent,$src,$path) {
 $this = $this|0;
 $parent = $parent|0;
 $src = $src|0;
 $path = $path|0;
 var $$0 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0;
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0;
 var $312 = 0, $313 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $adj$0123 = 0, $closestVert$0124 = 0, $closestVert$1 = 0, $closestVert$2 = 0;
 var $eid$0 = 0, $fabsf$i = Math_fround(0), $maxdot$0125 = Math_fround(0), $maxdot$1 = Math_fround(0), $maxdot$2 = Math_fround(0), $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($src|0)==($parent|0);
 if ($0) {
  HEAP32[$path>>2] = 1;
  $1 = (($path) + 4|0);
  HEAP32[$1>>2] = $src;
  $2 = (($path) + 8|0);
  HEAPF32[$2>>2] = Math_fround(0.0);
  $3 = (($path) + 12|0);
  HEAPF32[$3>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + (($parent*12)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($5) + (($src*12)|0)|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 - $9);
 $11 = ((($5) + (($parent*12)|0)|0) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = ((($5) + (($src*12)|0)|0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 - $14);
 $16 = ((($5) + (($parent*12)|0)|0) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = ((($5) + (($src*12)|0)|0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 - $19);
 $21 = Math_fround($10 * $10);
 $22 = Math_fround($15 * $15);
 $23 = Math_fround($21 + $22);
 $24 = Math_fround($20 * $20);
 $25 = Math_fround($23 + $24);
 $26 = $25 > Math_fround(0.0);
 if ($26) {
  $27 = (Math_fround(Math_sqrt((Math_fround($25)))));
  $28 = Math_fround(Math_fround(1.0) / $27);
  $29 = Math_fround($10 * $28);
  $30 = Math_fround($15 * $28);
  $31 = Math_fround($20 * $28);
  $137 = $29;$140 = $30;$144 = $31;
 } else {
  $137 = Math_fround(0.0);$140 = Math_fround(0.0);$144 = Math_fround(0.0);
 }
 $32 = (($this) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + ($src<<2)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + -1)|0;
 $39 = ($38>>>0)>($src>>>0);
 if ($39) {
  $40 = (($src) + 1)|0;
  $41 = (($33) + ($40<<2)|0);
  $$in = $41;
 } else {
  $42 = (($this) + 60|0);
  $$in = $42;
 }
 $43 = HEAP32[$$in>>2]|0;
 $44 = ($35>>>0)<($43>>>0);
 if (!($44)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($this) + 56|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 20|0);
 $48 = HEAP32[$47>>2]|0;
 $adj$0123 = $35;$closestVert$0124 = -1;$maxdot$0125 = Math_fround(-1.0);
 while(1) {
  $49 = (($46) + ($adj$0123<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50*3)|0;
  $52 = (($48) + ($51<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 2)|0;
  $55 = (($48) + ($54<<2)|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($53|0)==($src|0);
  if ($57) {
   $eid$0 = 1;
   label = 13;
  } else {
   $58 = (($51) + 1)|0;
   $59 = (($48) + ($58<<2)|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==($src|0);
   if ($61) {
    $eid$0 = 2;
    label = 13;
   } else {
    $62 = ($56|0)==($src|0);
    if ($62) {
     $eid$0 = 0;
     label = 13;
    } else {
     $closestVert$2 = $closestVert$0124;$maxdot$2 = $maxdot$0125;
    }
   }
  }
  if ((label|0) == 13) {
   label = 0;
   $63 = (($eid$0) + ($51))|0;
   $64 = (($48) + ($63<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($eid$0) + 1)|0;
   $67 = (($66>>>0) % 3)&-1;
   $68 = (($67) + ($51))|0;
   $69 = (($48) + ($68<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($5) + (($65*12)|0)|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = ((($5) + (($65*12)|0)|0) + 4|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = ((($5) + (($65*12)|0)|0) + 8|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = (($5) + (($70*12)|0)|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = ((($5) + (($70*12)|0)|0) + 4|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = ((($5) + (($70*12)|0)|0) + 8|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $83 = ($65|0)==($parent|0);
   if ($83) {
    label = 14;
    break;
   }
   $96 = ($70|0)==($parent|0);
   if ($96) {
    label = 16;
    break;
   }
   $109 = Math_fround($72 - $9);
   $110 = Math_fround($74 - $14);
   $111 = Math_fround($76 - $19);
   $112 = Math_fround($78 - $9);
   $113 = Math_fround($80 - $14);
   $114 = Math_fround($82 - $19);
   $115 = Math_fround($110 * $114);
   $116 = Math_fround($113 * $111);
   $117 = Math_fround($115 - $116);
   $118 = Math_fround($112 * $111);
   $119 = Math_fround($109 * $114);
   $120 = Math_fround($118 - $119);
   $121 = Math_fround($109 * $113);
   $122 = Math_fround($112 * $110);
   $123 = Math_fround($121 - $122);
   $124 = Math_fround($117 * $117);
   $125 = Math_fround($120 * $120);
   $126 = Math_fround($124 + $125);
   $127 = Math_fround($123 * $123);
   $128 = Math_fround($127 + $126);
   $129 = $128 > Math_fround(0.0);
   if ($129) {
    $130 = (Math_fround(Math_sqrt((Math_fround($128)))));
    $131 = Math_fround(Math_fround(1.0) / $130);
    $132 = Math_fround($117 * $131);
    $133 = Math_fround($120 * $131);
    $134 = Math_fround($123 * $131);
    $136 = $132;$139 = $133;$143 = $134;
   } else {
    $136 = Math_fround(0.0);$139 = Math_fround(0.0);$143 = Math_fround(0.0);
   }
   $135 = Math_fround($137 * $136);
   $138 = Math_fround($140 * $139);
   $141 = Math_fround($138 + $135);
   $142 = Math_fround($144 * $143);
   $145 = Math_fround($142 + $141);
   $146 = Math_fround($136 * $145);
   $147 = Math_fround($139 * $145);
   $148 = Math_fround($143 * $145);
   $149 = Math_fround($137 - $146);
   $150 = Math_fround($140 - $147);
   $151 = Math_fround($144 - $148);
   $152 = Math_fround($149 * $149);
   $153 = Math_fround($150 * $150);
   $154 = Math_fround($152 + $153);
   $155 = Math_fround($151 * $151);
   $156 = Math_fround($155 + $154);
   $157 = $156 > Math_fround(0.0);
   if ($157) {
    $158 = (Math_fround(Math_sqrt((Math_fround($156)))));
    $159 = Math_fround(Math_fround(1.0) / $158);
    $160 = Math_fround($149 * $159);
    $161 = Math_fround($150 * $159);
    $162 = Math_fround($151 * $159);
    $175 = $160;$177 = $161;$180 = $162;
   } else {
    $175 = Math_fround(0.0);$177 = Math_fround(0.0);$180 = Math_fround(0.0);
   }
   $163 = Math_fround($9 - $72);
   $164 = Math_fround($14 - $74);
   $165 = Math_fround($19 - $76);
   $166 = Math_fround($78 - $72);
   $167 = Math_fround($80 - $74);
   $168 = Math_fround($82 - $76);
   $169 = Math_fround($166 * $166);
   $170 = Math_fround($167 * $167);
   $171 = Math_fround($169 + $170);
   $172 = Math_fround($168 * $168);
   $173 = Math_fround($171 + $172);
   $174 = Math_fround($166 * $175);
   $176 = Math_fround($167 * $177);
   $178 = Math_fround($176 + $174);
   $179 = Math_fround($168 * $180);
   $181 = Math_fround($179 + $178);
   $182 = Math_fround($175 * $175);
   $183 = Math_fround($177 * $177);
   $184 = Math_fround($183 + $182);
   $185 = Math_fround($180 * $180);
   $186 = Math_fround($185 + $184);
   $187 = Math_fround($166 * $163);
   $188 = Math_fround($167 * $164);
   $189 = Math_fround($187 + $188);
   $190 = Math_fround($168 * $165);
   $191 = Math_fround($189 + $190);
   $192 = Math_fround($163 * $175);
   $193 = Math_fround($164 * $177);
   $194 = Math_fround($193 + $192);
   $195 = Math_fround($165 * $180);
   $196 = Math_fround($195 + $194);
   $197 = Math_fround(-$196);
   $198 = Math_fround($173 * $186);
   $199 = Math_fround($181 * $181);
   $200 = Math_fround($198 - $199);
   $fabsf$i = (Math_fround(Math_abs((Math_fround($200)))));
   $201 = $fabsf$i < Math_fround(9.99999974737875163555E-5);
   if ($201) {
    $closestVert$2 = $closestVert$0124;$maxdot$2 = $maxdot$0125;
   } else {
    $202 = Math_fround(Math_fround(1.0) / $200);
    $203 = Math_fround($186 * $202);
    $204 = Math_fround($191 * $203);
    $205 = Math_fround($181 * $202);
    $206 = Math_fround($205 * $197);
    $207 = Math_fround($204 + $206);
    $208 = Math_fround($191 * $205);
    $209 = Math_fround($173 * $202);
    $210 = Math_fround($209 * $197);
    $211 = Math_fround($208 + $210);
    $212 = $211 > Math_fround(-9.99999974737875163555E-6);
    if ($212) {
     $213 = $207 > Math_fround(-9.99999974737875163555E-6);
     $214 = $207 < Math_fround(1.00001001358032226563);
     $or$cond = $213 & $214;
     if ($or$cond) {
      label = 24;
      break;
     }
    }
    $253 = Math_fround($109 * $109);
    $254 = Math_fround($110 * $110);
    $255 = Math_fround($253 + $254);
    $256 = Math_fround($111 * $111);
    $257 = Math_fround($255 + $256);
    $258 = $257 > Math_fround(0.0);
    if ($258) {
     $259 = (Math_fround(Math_sqrt((Math_fround($257)))));
     $260 = Math_fround(Math_fround(1.0) / $259);
     $261 = Math_fround($109 * $260);
     $262 = Math_fround($110 * $260);
     $263 = Math_fround($111 * $260);
     $276 = $261;$278 = $262;$281 = $263;
    } else {
     $276 = Math_fround(0.0);$278 = Math_fround(0.0);$281 = Math_fround(0.0);
    }
    $264 = Math_fround($112 * $112);
    $265 = Math_fround($113 * $113);
    $266 = Math_fround($264 + $265);
    $267 = Math_fround($114 * $114);
    $268 = Math_fround($266 + $267);
    $269 = $268 > Math_fround(0.0);
    if ($269) {
     $270 = (Math_fround(Math_sqrt((Math_fround($268)))));
     $271 = Math_fround(Math_fround(1.0) / $270);
     $272 = Math_fround($112 * $271);
     $273 = Math_fround($113 * $271);
     $274 = Math_fround($114 * $271);
     $284 = $272;$286 = $273;$289 = $274;
    } else {
     $284 = Math_fround(0.0);$286 = Math_fround(0.0);$289 = Math_fround(0.0);
    }
    $275 = Math_fround($175 * $276);
    $277 = Math_fround($177 * $278);
    $279 = Math_fround($277 + $275);
    $280 = Math_fround($180 * $281);
    $282 = Math_fround($280 + $279);
    $283 = Math_fround($175 * $284);
    $285 = Math_fround($177 * $286);
    $287 = Math_fround($285 + $283);
    $288 = Math_fround($180 * $289);
    $290 = Math_fround($288 + $287);
    $291 = $282 > $maxdot$0125;
    $closestVert$1 = $291 ? $65 : $closestVert$0124;
    $maxdot$1 = $291 ? $282 : $maxdot$0125;
    $292 = $290 > $maxdot$1;
    if ($292) {
     $closestVert$2 = $70;$maxdot$2 = $290;
    } else {
     $closestVert$2 = $closestVert$1;$maxdot$2 = $maxdot$1;
    }
   }
  }
  $293 = (($adj$0123) + 1)|0;
  $294 = ($293>>>0)<($43>>>0);
  if ($294) {
   $adj$0123 = $293;$closestVert$0124 = $closestVert$2;$maxdot$0125 = $maxdot$2;
  } else {
   label = 34;
   break;
  }
 }
 if ((label|0) == 14) {
  $84 = Math_fround($72 - $9);
  $85 = Math_fround($74 - $14);
  $86 = Math_fround($76 - $19);
  $87 = Math_fround($84 * $84);
  $88 = Math_fround($85 * $85);
  $89 = Math_fround($87 + $88);
  $90 = Math_fround($86 * $86);
  $91 = Math_fround($89 + $90);
  $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
  HEAP32[$path>>2] = 1;
  $93 = (($path) + 4|0);
  HEAP32[$93>>2] = $parent;
  $94 = (($path) + 8|0);
  HEAPF32[$94>>2] = Math_fround(0.0);
  $95 = (($path) + 12|0);
  HEAPF32[$95>>2] = $92;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 16) {
  $97 = Math_fround($78 - $9);
  $98 = Math_fround($80 - $14);
  $99 = Math_fround($82 - $19);
  $100 = Math_fround($97 * $97);
  $101 = Math_fround($98 * $98);
  $102 = Math_fround($100 + $101);
  $103 = Math_fround($99 * $99);
  $104 = Math_fround($102 + $103);
  $105 = (Math_fround(Math_sqrt((Math_fround($104)))));
  HEAP32[$path>>2] = 1;
  $106 = (($path) + 4|0);
  HEAP32[$106>>2] = $parent;
  $107 = (($path) + 8|0);
  HEAPF32[$107>>2] = Math_fround(0.0);
  $108 = (($path) + 12|0);
  HEAPF32[$108>>2] = $105;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 24) {
  $215 = $207 < Math_fround(9.99999974737875163555E-6);
  $216 = $207 > Math_fround(0.999989986419677734375);
  $or$cond3 = $215 | $216;
  if ($or$cond3) {
   HEAP32[$path>>2] = 1;
   $217 = $215 ? $65 : $70;
   $218 = (($path) + 4|0);
   HEAP32[$218>>2] = $217;
   $219 = (($5) + (($217*12)|0)|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = Math_fround($9 - $220);
   $222 = ((($5) + (($217*12)|0)|0) + 4|0);
   $223 = Math_fround(HEAPF32[$222>>2]);
   $224 = Math_fround($14 - $223);
   $225 = ((($5) + (($217*12)|0)|0) + 8|0);
   $226 = Math_fround(HEAPF32[$225>>2]);
   $227 = Math_fround($19 - $226);
   $228 = Math_fround($221 * $221);
   $229 = Math_fround($224 * $224);
   $230 = Math_fround($228 + $229);
   $231 = Math_fround($227 * $227);
   $232 = Math_fround($230 + $231);
   $233 = (Math_fround(Math_sqrt((Math_fround($232)))));
   $234 = (($path) + 12|0);
   HEAPF32[$234>>2] = $233;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $235 = Math_fround($166 * $207);
   $236 = Math_fround($167 * $207);
   $237 = Math_fround($168 * $207);
   $238 = Math_fround($72 + $235);
   $239 = Math_fround($74 + $236);
   $240 = Math_fround($76 + $237);
   $241 = Math_fround($9 - $238);
   $242 = Math_fround($14 - $239);
   $243 = Math_fround($19 - $240);
   $244 = Math_fround($241 * $241);
   $245 = Math_fround($242 * $242);
   $246 = Math_fround($244 + $245);
   $247 = Math_fround($243 * $243);
   $248 = Math_fround($247 + $246);
   $249 = (Math_fround(Math_sqrt((Math_fround($248)))));
   HEAP32[$path>>2] = 0;
   $250 = (($path) + 4|0);
   HEAP32[$250>>2] = $63;
   $251 = (($path) + 8|0);
   HEAPF32[$251>>2] = $207;
   $252 = (($path) + 12|0);
   HEAPF32[$252>>2] = $249;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 34) {
  $295 = ($closestVert$2|0)>(0);
  if (!($295)) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $296 = (($5) + (($closestVert$2*12)|0)|0);
  $297 = Math_fround(HEAPF32[$296>>2]);
  $298 = Math_fround($9 - $297);
  $299 = ((($5) + (($closestVert$2*12)|0)|0) + 4|0);
  $300 = Math_fround(HEAPF32[$299>>2]);
  $301 = Math_fround($14 - $300);
  $302 = ((($5) + (($closestVert$2*12)|0)|0) + 8|0);
  $303 = Math_fround(HEAPF32[$302>>2]);
  $304 = Math_fround($19 - $303);
  $305 = Math_fround($298 * $298);
  $306 = Math_fround($301 * $301);
  $307 = Math_fround($305 + $306);
  $308 = Math_fround($304 * $304);
  $309 = Math_fround($307 + $308);
  $310 = (Math_fround(Math_sqrt((Math_fround($309)))));
  HEAP32[$path>>2] = 1;
  $311 = (($path) + 4|0);
  HEAP32[$311>>2] = $closestVert$2;
  $312 = (($path) + 8|0);
  HEAPF32[$312>>2] = Math_fround(0.0);
  $313 = (($path) + 12|0);
  HEAPF32[$313>>2] = $310;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_112VertTriangleENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $this$idx$val = 0, $this$idx1 = 0, $this$idx1$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $this$idx1 = (($this) + 8|0);
 $this$idx1$val = HEAP32[$this$idx1>>2]|0;
 $0 = $this$idx1$val & 2147483647;
 $1 = ($0|0)==(0);
 $2 = $this$idx1$val << 1;
 $$$i = $1 ? 1 : $2;
 $3 = ($$$i|0)==(0);
 if ($3) {
  $19 = 0;
 } else {
  $4 = $$$i << 3;
  $5 = ($4|0)==(0);
  if ($5) {
   $19 = 0;
  } else {
   $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (__Z15PxGetFoundationv()|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 24|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
   $$$i$i$i = $14 ? 409800 : 409768;
   $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,$4,$$$i$i$i,409928,558)|0);
   $19 = $15;
  }
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($19) + ($17<<3)|0);
 $20 = ($17|0)>(0);
 if ($20) {
  $21 = HEAP32[$this>>2]|0;
  $$012$i = $19;$$03$i = $21;
  while(1) {
   $22 = ($$012$i|0)==(0|0);
   if (!($22)) {
    $23 = $$03$i;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 4)|0;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = $$012$i;
    $30 = $29;
    HEAP32[$30>>2] = $25;
    $31 = (($29) + 4)|0;
    $32 = $31;
    HEAP32[$32>>2] = $28;
   }
   $33 = (($$012$i) + 8|0);
   $34 = (($$03$i) + 8|0);
   $35 = ($33>>>0)<($18>>>0);
   if ($35) {
    $$012$i = $33;$$03$i = $34;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$16>>2]|0;
  $37 = $$pre;
 } else {
  $37 = $17;
 }
 $36 = (($19) + ($37<<3)|0);
 $38 = ($36|0)==(0|0);
 if (!($38)) {
  $39 = $a;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + 4)|0;
  $43 = $42;
  $44 = HEAP32[$43>>2]|0;
  $45 = $36;
  $46 = $45;
  HEAP32[$46>>2] = $41;
  $47 = (($45) + 4)|0;
  $48 = $47;
  HEAP32[$48>>2] = $44;
 }
 $this$idx$val = HEAP32[$this$idx1>>2]|0;
 $49 = ($this$idx$val|0)>(-1);
 if ($49) {
  $50 = HEAP32[$this>>2]|0;
  $51 = ($50|0)==(0|0);
  if (!($51)) {
   $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vii[$55 & 4095]($52,$50);
  }
 }
 HEAP32[$this>>2] = $19;
 HEAP32[$this$idx1>>2] = $$$i;
 $56 = HEAP32[$16>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$16>>2] = $57;
 $58 = (($19) + ($56<<3)|0);
 STACKTOP = sp;return ($58|0);
}
function __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_112VertTriangleENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $this$idx = 0, $this$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 409800 : 409768;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,409928,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = $$03$i;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = $$012$i;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
   }
   $30 = (($$012$i) + 8|0);
   $31 = (($$03$i) + 8|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $this$idx = (($this) + 8|0);
 $this$idx$val = HEAP32[$this$idx>>2]|0;
 $33 = ($this$idx$val|0)>(-1);
 if (!($33)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$this$idx>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$this>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  HEAP32[$this>>2] = $16;
  HEAP32[$this$idx>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vii[$39 & 4095]($36,$34);
 HEAP32[$this>>2] = $16;
 HEAP32[$this$idx>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_18MeshEdgeENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $this$idx = 0, $this$idx$val = 0, $this$idx1$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $this$idx = (($this) + 8|0);
 $this$idx$val = HEAP32[$this$idx>>2]|0;
 $0 = $this$idx$val & 2147483647;
 $1 = ($0|0)==(0);
 $2 = $this$idx$val << 1;
 $$$i = $1 ? 1 : $2;
 $3 = ($$$i|0)==(0);
 if ($3) {
  $19 = 0;
 } else {
  $4 = ($$$i*12)|0;
  $5 = ($4|0)==(0);
  if ($5) {
   $19 = 0;
  } else {
   $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (__Z15PxGetFoundationv()|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 24|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
   $$$i$i$i = $14 ? 410008 : 409768;
   $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,$4,$$$i$i$i,409928,558)|0);
   $19 = $15;
  }
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($19) + (($17*12)|0)|0);
 $20 = ($17|0)>(0);
 if ($20) {
  $21 = HEAP32[$this>>2]|0;
  $$012$i = $19;$$03$i = $21;
  while(1) {
   $22 = ($$012$i|0)==(0|0);
   if (!($22)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;
   }
   $23 = (($$012$i) + 12|0);
   $24 = (($$03$i) + 12|0);
   $25 = ($23>>>0)<($18>>>0);
   if ($25) {
    $$012$i = $23;$$03$i = $24;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$16>>2]|0;
  $27 = $$pre;
 } else {
  $27 = $17;
 }
 $26 = (($19) + (($27*12)|0)|0);
 $28 = ($26|0)==(0|0);
 if (!($28)) {
  ;HEAP32[$26+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$a+8>>2]|0;
 }
 $this$idx1$val = HEAP32[$this$idx>>2]|0;
 $29 = ($this$idx1$val|0)>(-1);
 if ($29) {
  $30 = HEAP32[$this>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
  }
 }
 HEAP32[$this>>2] = $19;
 HEAP32[$this$idx>>2] = $$$i;
 $36 = HEAP32[$16>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$16>>2] = $37;
 $38 = (($19) + (($36*12)|0)|0);
 STACKTOP = sp;return ($38|0);
}
function __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_119VertexDistanceCountENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $this$idx = 0, $this$idx$val = 0, $this$idx1$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $this$idx = (($this) + 8|0);
 $this$idx$val = HEAP32[$this$idx>>2]|0;
 $0 = $this$idx$val & 2147483647;
 $1 = ($0|0)==(0);
 $2 = $this$idx$val << 1;
 $$$i = $1 ? 1 : $2;
 $3 = ($$$i|0)==(0);
 if ($3) {
  $19 = 0;
 } else {
  $4 = ($$$i*12)|0;
  $5 = ($4|0)==(0);
  if ($5) {
   $19 = 0;
  } else {
   $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (__Z15PxGetFoundationv()|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 24|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
   $$$i$i$i = $14 ? 410128 : 409768;
   $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,$4,$$$i$i$i,409928,558)|0);
   $19 = $15;
  }
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($19) + (($17*12)|0)|0);
 $20 = ($17|0)>(0);
 if ($20) {
  $21 = HEAP32[$this>>2]|0;
  $$012$i = $19;$$03$i = $21;
  while(1) {
   $22 = ($$012$i|0)==(0|0);
   if (!($22)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;
   }
   $23 = (($$012$i) + 12|0);
   $24 = (($$03$i) + 12|0);
   $25 = ($23>>>0)<($18>>>0);
   if ($25) {
    $$012$i = $23;$$03$i = $24;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$16>>2]|0;
  $27 = $$pre;
 } else {
  $27 = $17;
 }
 $26 = (($19) + (($27*12)|0)|0);
 $28 = ($26|0)==(0|0);
 if (!($28)) {
  ;HEAP32[$26+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$a+8>>2]|0;
 }
 $this$idx1$val = HEAP32[$this$idx>>2]|0;
 $29 = ($this$idx1$val|0)>(-1);
 if ($29) {
  $30 = HEAP32[$this>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
  }
 }
 HEAP32[$this>>2] = $19;
 HEAP32[$this$idx>>2] = $$$i;
 $36 = HEAP32[$16>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$16>>2] = $37;
 $38 = (($19) + (($36*12)|0)|0);
 STACKTOP = sp;return ($38|0);
}
function __ZN5physx6shdfnd5ArrayIhNS0_19ReflectionAllocatorIhEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $14 = 0;
 } else {
  $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__Z15PxGetFoundationv()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
  $$$i$i$i = $9 ? 410272 : 409768;
  $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,$capacity,$$$i$i$i,409928,558)|0);
  $14 = $10;
 }
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($14) + ($12)|0);
 $15 = HEAP32[$this>>2]|0;
 $16 = ($12|0)>(0);
 if ($16) {
  $$012$i = $14;$$03$i = $15;
  while(1) {
   $17 = ($$012$i|0)==(0|0);
   if (!($17)) {
    $18 = HEAP8[$$03$i>>0]|0;
    HEAP8[$$012$i>>0] = $18;
   }
   $19 = (($$012$i) + 1|0);
   $20 = (($$03$i) + 1|0);
   $exitcond$i = ($19|0)==($13|0);
   if ($exitcond$i) {
    break;
   } else {
    $$012$i = $19;$$03$i = $20;
   }
  }
  $$pr = HEAP32[$this>>2]|0;
  $25 = $$pr;
 } else {
  $25 = $15;
 }
 $21 = (($this) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)<(0);
 $24 = ($25|0)==(0|0);
 $or$cond = $23 | $24;
 if ($or$cond) {
  HEAP32[$this>>2] = $14;
  HEAP32[$21>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$29 & 4095]($26,$25);
 HEAP32[$this>>2] = $14;
 HEAP32[$21>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*12)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 410376 : 409768;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,409928,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*12)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
   }
   $27 = (($$012$i) + 12|0);
   $28 = (($$03$i) + 12|0);
   $29 = ($27>>>0)<($15>>>0);
   if ($29) {
    $$012$i = $27;$$03$i = $28;
   } else {
    break;
   }
  }
 }
 $30 = (($this) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)>(-1);
 if (!($32)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$30>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$this>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  HEAP32[$this>>2] = $16;
  HEAP32[$30>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
 HEAP32[$this>>2] = $16;
 HEAP32[$30>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx31PxClothGeodesicTetherCookerImplD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $notlhs$i$i = 0, $notrhs$i$i = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i10 = 0, $or$cond$i$i2 = 0;
 var $or$cond$i$i4 = 0, $or$cond$i$i6 = 0, $or$cond$i$i8 = 0, $or$cond$not$i$i = 0, $or$cond2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 96|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 92|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i1 = $15 & $16;
 if ($or$cond$i$i1) {
  $17 = (($this) + 84|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 76|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i2 = $27 & $28;
 if ($or$cond$i$i2) {
  $29 = (($this) + 68|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
  }
 }
 $36 = (($this) + 64|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38|0)!=(0);
 $40 = ($37|0)>(-1);
 $or$cond$i$i4 = $39 & $40;
 if ($or$cond$i$i4) {
  $41 = (($this) + 56|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($44,$42);
  }
 }
 $48 = (($this) + 52|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49 & 2147483647;
 $51 = ($50|0)!=(0);
 $52 = ($49|0)>(-1);
 $or$cond$i$i6 = $51 & $52;
 if ($or$cond$i$i6) {
  $53 = (($this) + 44|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   FUNCTION_TABLE_vii[$59 & 4095]($56,$54);
  }
 }
 $60 = (($this) + 32|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($this) + 40|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = $63 & 2147483647;
 $notlhs$i$i = ($64|0)==(0);
 $notrhs$i$i = ($63|0)<(0);
 $or$cond$not$i$i = $notrhs$i$i | $notlhs$i$i;
 $65 = ($61|0)==(0|0);
 $or$cond2$i$i = $or$cond$not$i$i | $65;
 if (!($or$cond2$i$i)) {
  $66 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($67) + 12|0);
  $69 = HEAP32[$68>>2]|0;
  FUNCTION_TABLE_vii[$69 & 4095]($66,$61);
 }
 $70 = (($this) + 28|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = $71 & 2147483647;
 $73 = ($72|0)!=(0);
 $74 = ($71|0)>(-1);
 $or$cond$i$i8 = $73 & $74;
 if ($or$cond$i$i8) {
  $75 = (($this) + 20|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0|0);
  if (!($77)) {
   $78 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($79) + 12|0);
   $81 = HEAP32[$80>>2]|0;
   FUNCTION_TABLE_vii[$81 & 4095]($78,$76);
  }
 }
 $82 = (($this) + 16|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = $83 & 2147483647;
 $85 = ($84|0)!=(0);
 $86 = ($83|0)>(-1);
 $or$cond$i$i10 = $85 & $86;
 if (!($or$cond$i$i10)) {
  STACKTOP = sp;return;
 }
 $87 = (($this) + 8|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0|0);
 if ($89) {
  STACKTOP = sp;return;
 }
 $90 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (($91) + 12|0);
 $93 = HEAP32[$92>>2]|0;
 FUNCTION_TABLE_vii[$93 & 4095]($90,$88);
 STACKTOP = sp;return;
}
function __ZN5physx25PxClothSimpleTetherCookerC2ERKNS_15PxClothMeshDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(24)|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 __ZN5physx29PxClothSimpleTetherCookerImpl16createTetherDataERKNS_15PxClothMeshDescE($0,$desc);
 HEAP32[$this>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN5physx25PxClothSimpleTetherCookerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4|0)!=(0);
 $6 = ($3|0)>(-1);
 $or$cond$i$i$i$i = $5 & $6;
 if ($or$cond$i$i$i$i) {
  $7 = (($0) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vii[$13 & 4095]($10,$8);
  }
 }
 $14 = (($0) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16|0)!=(0);
 $18 = ($15|0)>(-1);
 $or$cond$i$i1$i$i = $17 & $18;
 if ($or$cond$i$i1$i$i) {
  $19 = HEAP32[$0>>2]|0;
  $20 = ($19|0)==(0|0);
  if (!($20)) {
   $21 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_vii[$24 & 4095]($21,$19);
  }
 }
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZNK5physx25PxClothSimpleTetherCooker13getTetherDataEPjPf($this,$userTetherAnchors,$userTetherLengths) {
 $this = $this|0;
 $userTetherAnchors = $userTetherAnchors|0;
 $userTetherLengths = $userTetherLengths|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 2;
 _memcpy(($userTetherAnchors|0),($1|0),($4|0))|0;
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 2;
 _memcpy(($userTetherLengths|0),($6|0),($9|0))|0;
 STACKTOP = sp;return;
}
function __ZN5physx29PxClothSimpleTetherCookerImpl16createTetherDataERKNS_15PxClothMeshDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$in22 = 0, $$pre = 0, $$pre$i = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $aIt$013 = 0, $attachedIndices = 0, $exitcond = 0, $exitcond26 = 0, $i$023 = 0, $i1 = 0, $i2$014 = 0, $minIndex = 0, $minSqrDist$0$lcssa = Math_fround(0), $minSqrDist$012 = Math_fround(0), $minSqrDist$1 = Math_fround(0), $or$cond$i$i = 0, $or$cond$i$i1 = 0;
 var $particles = 0, $storemerge18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $particles = sp + 40|0;
 $0 = sp;
 $attachedIndices = sp + 16|0;
 $i1 = sp + 28|0;
 $minIndex = sp + 32|0;
 $1 = sp + 36|0;
 $2 = (($desc) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($desc) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 HEAP32[$particles>>2] = 0;
 $7 = (($particles) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($particles) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = ($3|0)==(0);
 if (!($9)) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($particles,$3);
  $10 = HEAP32[$desc>>2]|0;
  $11 = (($desc) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$4>>2]|0;
  $14 = (($desc) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($0) + 4|0);
  $17 = (($0) + 8|0);
  $18 = (($0) + 12|0);
  $$in22 = $15;$21 = $13;$i$023 = 0;
  while(1) {
   $19 = (($$in22) + ($10)|0);
   $20 = ($21|0)==(0|0);
   if ($20) {
    $140 = 0;$29 = Math_fround(1.0);
   } else {
    $22 = (($21) + ($12)|0);
    $23 = Math_fround(HEAPF32[$21>>2]);
    $140 = $22;$29 = $23;
   }
   $24 = Math_fround(HEAPF32[$$in22>>2]);
   HEAPF32[$0>>2] = $24;
   $25 = (($$in22) + 4|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   HEAPF32[$16>>2] = $26;
   $27 = (($$in22) + 8|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   HEAPF32[$17>>2] = $28;
   HEAPF32[$18>>2] = $29;
   $30 = HEAP32[$8>>2]|0;
   $31 = $30 & 2147483647;
   $32 = HEAP32[$7>>2]|0;
   $33 = ($31>>>0)>($32>>>0);
   if ($33) {
    $34 = HEAP32[$particles>>2]|0;
    $35 = (($34) + ($32<<4)|0);
    $36 = ($35|0)==(0|0);
    if (!($36)) {
     HEAPF32[$35>>2] = $24;
     $37 = ((($34) + ($32<<4)|0) + 4|0);
     HEAPF32[$37>>2] = $26;
     $38 = ((($34) + ($32<<4)|0) + 8|0);
     HEAPF32[$38>>2] = $28;
     $39 = ((($34) + ($32<<4)|0) + 12|0);
     HEAPF32[$39>>2] = $29;
    }
    $40 = (($32) + 1)|0;
    HEAP32[$7>>2] = $40;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($particles,$0)|0);
   }
   $41 = (($i$023) + 1)|0;
   $exitcond26 = ($41|0)==($3|0);
   if ($exitcond26) {
    break;
   } else {
    $$in22 = $19;$21 = $140;$i$023 = $41;
   }
  }
 }
 HEAP32[$attachedIndices>>2] = 0;
 $42 = (($attachedIndices) + 4|0);
 HEAP32[$42>>2] = 0;
 $43 = (($attachedIndices) + 8|0);
 HEAP32[$43>>2] = 0;
 HEAP32[$i1>>2] = 0;
 if (!($9)) {
  $44 = HEAP32[$particles>>2]|0;
  $storemerge18 = 0;
  while(1) {
   $45 = ((($44) + ($storemerge18<<4)|0) + 12|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = $46 == Math_fround(0.0);
   do {
    if ($47) {
     $48 = HEAP32[$43>>2]|0;
     $49 = $48 & 2147483647;
     $50 = HEAP32[$42>>2]|0;
     $51 = ($49>>>0)>($50>>>0);
     if (!($51)) {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($attachedIndices,$i1)|0);
      $$pre27 = HEAP32[$i1>>2]|0;
      $57 = $$pre27;
      break;
     }
     $52 = HEAP32[$attachedIndices>>2]|0;
     $53 = (($52) + ($50<<2)|0);
     $54 = ($53|0)==(0|0);
     if (!($54)) {
      HEAP32[$53>>2] = $storemerge18;
     }
     $55 = (($50) + 1)|0;
     HEAP32[$42>>2] = $55;
     $57 = $storemerge18;
    } else {
     $57 = $storemerge18;
    }
   } while(0);
   $56 = (($57) + 1)|0;
   HEAP32[$i1>>2] = $56;
   $58 = ($56>>>0)<($3>>>0);
   if ($58) {
    $storemerge18 = $56;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$42>>2]|0;
  $59 = ($$pre|0)==(0);
  $60 = $59 ? 0 : $3;
  $61 = ($60|0)==(0);
  if (!($61)) {
   $62 = (($this) + 8|0);
   $63 = (($this) + 12|0);
   $64 = (($this) + 20|0);
   $65 = HEAP32[$particles>>2]|0;
   $66 = HEAP32[$attachedIndices>>2]|0;
   $67 = (($this) + 4|0);
   $68 = (($this) + 16|0);
   $i2$014 = 0;
   while(1) {
    $69 = HEAP32[$62>>2]|0;
    $70 = $69 & 2147483647;
    $71 = ($70>>>0)<($3>>>0);
    if ($71) {
     __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($this,$3);
    }
    $72 = HEAP32[$64>>2]|0;
    $73 = $72 & 2147483647;
    $74 = ($73>>>0)<($3>>>0);
    if ($74) {
     __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE8recreateEj($63,$3);
    }
    $75 = (($65) + ($i2$014<<4)|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = ((($65) + ($i2$014<<4)|0) + 4|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = ((($65) + ($i2$014<<4)|0) + 8|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    HEAP32[$minIndex>>2] = $3;
    $81 = (($66) + ($$pre<<2)|0);
    if ($59) {
     $107 = $3;$minSqrDist$0$lcssa = Math_fround(3.40282346638528859812E+38);
    } else {
     $141 = $3;$aIt$013 = $66;$minSqrDist$012 = Math_fround(3.40282346638528859812E+38);
     while(1) {
      $82 = HEAP32[$aIt$013>>2]|0;
      $83 = (($65) + ($82<<4)|0);
      $84 = Math_fround(HEAPF32[$83>>2]);
      $85 = Math_fround($84 - $76);
      $86 = ((($65) + ($82<<4)|0) + 4|0);
      $87 = Math_fround(HEAPF32[$86>>2]);
      $88 = Math_fround($87 - $78);
      $89 = ((($65) + ($82<<4)|0) + 8|0);
      $90 = Math_fround(HEAPF32[$89>>2]);
      $91 = Math_fround($90 - $80);
      $92 = Math_fround($85 * $85);
      $93 = Math_fround($88 * $88);
      $94 = Math_fround($92 + $93);
      $95 = Math_fround($91 * $91);
      $96 = Math_fround($94 + $95);
      $97 = $minSqrDist$012 > $96;
      if ($97) {
       HEAP32[$minIndex>>2] = $82;
       $142 = $82;$minSqrDist$1 = $96;
      } else {
       $142 = $141;$minSqrDist$1 = $minSqrDist$012;
      }
      $98 = (($aIt$013) + 4|0);
      $99 = ($98|0)==($81|0);
      if ($99) {
       $107 = $142;$minSqrDist$0$lcssa = $minSqrDist$1;
       break;
      } else {
       $141 = $142;$aIt$013 = $98;$minSqrDist$012 = $minSqrDist$1;
      }
     }
    }
    $100 = HEAP32[$62>>2]|0;
    $101 = $100 & 2147483647;
    $102 = HEAP32[$67>>2]|0;
    $103 = ($101>>>0)>($102>>>0);
    if ($103) {
     $104 = HEAP32[$this>>2]|0;
     $105 = (($104) + ($102<<2)|0);
     $106 = ($105|0)==(0|0);
     if ($106) {
      $109 = $102;
     } else {
      HEAP32[$105>>2] = $107;
      $$pre$i = HEAP32[$67>>2]|0;
      $109 = $$pre$i;
     }
     $108 = (($109) + 1)|0;
     HEAP32[$67>>2] = $108;
    } else {
     (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($this,$minIndex)|0);
    }
    $110 = (Math_fround(Math_sqrt((Math_fround($minSqrDist$0$lcssa)))));
    HEAPF32[$1>>2] = $110;
    $111 = HEAP32[$64>>2]|0;
    $112 = $111 & 2147483647;
    $113 = HEAP32[$68>>2]|0;
    $114 = ($112>>>0)>($113>>>0);
    if ($114) {
     $115 = HEAP32[$63>>2]|0;
     $116 = (($115) + ($113<<2)|0);
     $117 = ($116|0)==(0|0);
     if (!($117)) {
      HEAPF32[$116>>2] = $110;
     }
     $118 = (($113) + 1)|0;
     HEAP32[$68>>2] = $118;
    } else {
     (__ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE15growAndPushBackERKf($63,$1)|0);
    }
    $119 = (($i2$014) + 1)|0;
    $exitcond = ($119|0)==($60|0);
    if ($exitcond) {
     break;
    } else {
     $i2$014 = $119;
    }
   }
  }
 }
 $120 = HEAP32[$43>>2]|0;
 $121 = $120 & 2147483647;
 $122 = ($121|0)!=(0);
 $123 = ($120|0)>(-1);
 $or$cond$i$i1 = $122 & $123;
 if ($or$cond$i$i1) {
  $124 = HEAP32[$attachedIndices>>2]|0;
  $125 = ($124|0)==(0|0);
  if (!($125)) {
   $126 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($127) + 12|0);
   $129 = HEAP32[$128>>2]|0;
   FUNCTION_TABLE_vii[$129 & 4095]($126,$124);
  }
 }
 $130 = HEAP32[$8>>2]|0;
 $131 = $130 & 2147483647;
 $132 = ($131|0)!=(0);
 $133 = ($130|0)>(-1);
 $or$cond$i$i = $132 & $133;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $134 = HEAP32[$particles>>2]|0;
 $135 = ($134|0)==(0|0);
 if ($135) {
  STACKTOP = sp;return;
 }
 $136 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (($137) + 12|0);
 $139 = HEAP32[$138>>2]|0;
 FUNCTION_TABLE_vii[$139 & 4095]($136,$134);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE15growAndPushBackERKf($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 410592 : 410560;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,410480,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_11PxAggregateENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 410792 : 410760;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,410680,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_14PxArticulationENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 410912 : 410760;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,410680,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_12PxConstraintENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 411032 : 410760;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,410680,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_7PxActorENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 411152 : 410760;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,410680,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZNK5physx6PxBase12isReleasableEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx2Cm15ConeLimitHelper8getLimitERKNS_6PxQuatERNS_6PxVec3ERf($this,$swing,$axis,$error) {
 $this = $this|0;
 $swing = $swing|0;
 $axis = $axis|0;
 $error = $error|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0);
 var $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $clamped = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $tanQSwing = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $tanQSwing = sp;
 $clamped = sp + 12|0;
 $1 = Math_fround(HEAPF32[$swing>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($swing) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = (($swing) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($swing) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($4 + Math_fround(1.0));
 $11 = Math_fround($7 / $10);
 $12 = Math_fround($9 / $10);
 $13 = Math_fround(-$12);
 HEAPF32[$tanQSwing>>2] = Math_fround(0.0);
 $14 = (($tanQSwing) + 4|0);
 HEAPF32[$14>>2] = $11;
 $15 = (($tanQSwing) + 8|0);
 HEAPF32[$15>>2] = $13;
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($11)))));
 $16 = (($this) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($fabsf$i$i$i + $17);
 $19 = Math_fround($fabsf$i$i$i * $17);
 $20 = Math_fround(Math_fround(1.0) - $19);
 $21 = Math_fround($18 / $20);
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($13)))));
 $22 = Math_fround($17 + $fabsf$i$i1$i);
 $23 = Math_fround($17 * $fabsf$i$i1$i);
 $24 = Math_fround(Math_fround(1.0) - $23);
 $25 = Math_fround($22 / $24);
 $26 = Math_fround(HEAPF32[$this>>2]);
 $27 = Math_fround($21 / $26);
 $28 = Math_fround($27 * $27);
 $29 = (($this) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($25 / $30);
 $32 = Math_fround($31 * $31);
 $33 = Math_fround($28 + $32);
 $34 = !($33 <= Math_fround(1.0));
 if (!($34)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $35 = Math_fround($4 * $5);
 $36 = Math_fround($2 * $7);
 $37 = Math_fround($5 * $9);
 $38 = Math_fround($2 * $9);
 $39 = Math_fround($7 * $5);
 $40 = Math_fround($1 * $2);
 $41 = Math_fround($35 + Math_fround(-1.0));
 $42 = Math_fround($36 - $37);
 $43 = Math_fround($39 + $38);
 $44 = Math_fround($40 + $41);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $45 = (($0) + 4|0);
 HEAPF32[$45>>2] = $26;
 $46 = (($0) + 8|0);
 HEAPF32[$46>>2] = $30;
 __ZN5physx6shdfnd12ellipseClampERKNS_6PxVec3ES3_($clamped,$tanQSwing,$0);
 $47 = (($clamped) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround(HEAPF32[$this>>2]);
 $50 = Math_fround($49 * $49);
 $51 = Math_fround($48 / $50);
 $52 = (($clamped) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround(HEAPF32[$29>>2]);
 $55 = Math_fround($54 * $54);
 $56 = Math_fround($53 / $55);
 $57 = Math_fround($53 * $53);
 $58 = Math_fround($57 + Math_fround(0.0));
 $59 = Math_fround($48 * $48);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround(Math_fround(1.0) - $60);
 $62 = Math_fround($60 + Math_fround(1.0));
 $63 = Math_fround(Math_fround(1.0) / $62);
 $64 = Math_fround($63 * $63);
 $65 = Math_fround($61 * Math_fround(2.0));
 $66 = Math_fround($64 * $65);
 $67 = Math_fround($48 * Math_fround(2.0));
 $68 = Math_fround($53 * Math_fround(2.0));
 $69 = Math_fround($61 * $66);
 $70 = Math_fround($67 * $66);
 $71 = Math_fround($68 * $66);
 $72 = Math_fround($69 + Math_fround(-1.0));
 $73 = Math_fround($56 * $53);
 $74 = Math_fround($73 + Math_fround(0.0));
 $75 = Math_fround($51 * $48);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($76 * Math_fround(-4.0));
 $78 = Math_fround(Math_fround(3.0) - $60);
 $79 = Math_fround($77 * $78);
 $80 = Math_fround($64 * $79);
 $81 = Math_fround($63 * $80);
 $82 = Math_fround($76 * Math_fround(-2.0));
 $83 = Math_fround($51 * Math_fround(2.0));
 $84 = Math_fround($56 * Math_fround(2.0));
 $85 = Math_fround($82 * $66);
 $86 = Math_fround($83 * $66);
 $87 = Math_fround($84 * $66);
 $88 = Math_fround($61 * $81);
 $89 = Math_fround($67 * $81);
 $90 = Math_fround($68 * $81);
 $91 = Math_fround($85 + $88);
 $92 = Math_fround($86 + $89);
 $93 = Math_fround($87 + $90);
 $94 = Math_fround($70 * $93);
 $95 = Math_fround($71 * $92);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($71 * $91);
 $98 = Math_fround($72 * $93);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($72 * $92);
 $101 = Math_fround($70 * $91);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($91 * $91);
 $104 = Math_fround($92 * $92);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($93 * $93);
 $107 = Math_fround($106 + $105);
 $108 = (Math_fround(Math_sqrt((Math_fround($107)))));
 $109 = Math_fround(Math_fround(1.0) / $108);
 $110 = Math_fround($109 * $96);
 $111 = Math_fround($109 * $99);
 $112 = Math_fround($109 * $102);
 HEAPF32[$axis>>2] = $110;
 $113 = (($axis) + 4|0);
 HEAPF32[$113>>2] = $111;
 $114 = (($axis) + 8|0);
 HEAPF32[$114>>2] = $112;
 $115 = Math_fround($70 * $112);
 $116 = Math_fround($111 * $71);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($110 * $71);
 $119 = Math_fround($72 * $112);
 $120 = Math_fround($118 - $119);
 $121 = Math_fround($111 * $72);
 $122 = Math_fround($110 * $70);
 $123 = Math_fround($121 - $122);
 $124 = Math_fround($44 * $117);
 $125 = Math_fround($43 * $120);
 $126 = Math_fround($124 + $125);
 $127 = Math_fround($42 * $123);
 $128 = Math_fround($127 + $126);
 HEAPF32[$error>>2] = $128;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd12ellipseClampERKNS_6PxVec3ES3_($agg$result,$point,$radii) {
 $agg$result = $agg$result|0;
 $point = $point|0;
 $radii = $radii|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = 0, $9 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i1 = Math_fround(0), $i$013 = 0, $t$014 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($point) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($1)))));
 $2 = (($point) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $fabsf$i$i1 = (Math_fround(Math_abs((Math_fround($3)))));
 $4 = (($radii) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($radii) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = !($5 >= $7);
 if ($8) {
  $15 = $fabsf$i$i < Math_fround(9.99999997475242707878E-7);
  if ($15) {
   $16 = $3 > Math_fround(0.0);
   if ($16) {
    $20 = $7;
   } else {
    $17 = Math_fround(-$7);
    $20 = $17;
   }
   HEAPF32[$agg$result>>2] = Math_fround(0.0);
   $18 = (($agg$result) + 4|0);
   HEAPF32[$18>>2] = Math_fround(0.0);
   $19 = (($agg$result) + 8|0);
   HEAPF32[$19>>2] = $20;
   STACKTOP = sp;return;
  }
 } else {
  $9 = $fabsf$i$i1 < Math_fround(9.99999997475242707878E-7);
  if ($9) {
   $10 = $1 > Math_fround(0.0);
   if ($10) {
    $13 = $5;
   } else {
    $11 = Math_fround(-$5);
    $13 = $11;
   }
   HEAPF32[$agg$result>>2] = Math_fround(0.0);
   $12 = (($agg$result) + 4|0);
   HEAPF32[$12>>2] = $13;
   $14 = (($agg$result) + 8|0);
   HEAPF32[$14>>2] = Math_fround(0.0);
   STACKTOP = sp;return;
  }
 }
 $21 = Math_fround(HEAPF32[$radii>>2]);
 $22 = Math_fround($21 * $21);
 $23 = Math_fround($5 * $5);
 $24 = Math_fround($7 * $7);
 $25 = Math_fround($21 * Math_fround(0.0));
 $26 = Math_fround($fabsf$i$i * $5);
 $27 = Math_fround($fabsf$i$i1 * $7);
 $28 = Math_fround($26 - $23);
 $29 = Math_fround($27 - $24);
 $30 = $28 > $29;
 $31 = $30 ? $28 : $29;
 $32 = Math_fround($25 * Math_fround(0.0));
 $33 = Math_fround($32 * $32);
 $34 = Math_fround($33 * Math_fround(0.0));
 $i$013 = 0;$t$014 = $31;
 while(1) {
  $35 = Math_fround($23 + $t$014);
  $36 = Math_fround(Math_fround(1.0) / $35);
  $37 = Math_fround($24 + $t$014);
  $38 = Math_fround(Math_fround(1.0) / $37);
  $39 = Math_fround($26 * $36);
  $40 = Math_fround($27 * $38);
  $41 = Math_fround($39 * $39);
  $42 = Math_fround($40 * $40);
  $43 = Math_fround($41 + $42);
  $44 = Math_fround($43 + Math_fround(-1.0));
  $45 = $44 < Math_fround(9.99999974737875163555E-5);
  if ($45) {
   label = 12;
   break;
  }
  $55 = Math_fround($36 * $41);
  $56 = Math_fround($34 + $55);
  $57 = Math_fround($38 * $42);
  $58 = Math_fround($56 + $57);
  $59 = Math_fround($58 * Math_fround(-2.0));
  $60 = Math_fround($44 / $59);
  $61 = Math_fround($t$014 - $60);
  $62 = (($i$013) + 1)|0;
  $63 = ($62>>>0)<(20);
  if ($63) {
   $i$013 = $62;$t$014 = $61;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 12) {
  $46 = Math_fround(HEAPF32[$point>>2]);
  $47 = Math_fround($22 * $46);
  $48 = Math_fround($23 * $1);
  $49 = Math_fround($24 * $3);
  $50 = Math_fround($47 * Math_fround(0.0));
  $51 = Math_fround($36 * $48);
  $52 = Math_fround($38 * $49);
  HEAPF32[$agg$result>>2] = $50;
  $53 = (($agg$result) + 4|0);
  HEAPF32[$53>>2] = $51;
  $54 = (($agg$result) + 8|0);
  HEAPF32[$54>>2] = $52;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $64 = Math_fround(HEAPF32[$point>>2]);
  $65 = Math_fround($22 * $64);
  $66 = Math_fround($23 * $1);
  $67 = Math_fround($24 * $3);
  $68 = Math_fround($65 * Math_fround(0.0));
  $69 = Math_fround($36 * $66);
  $70 = Math_fround($38 * $67);
  $71 = Math_fround($69 / $5);
  $72 = Math_fround($71 * $71);
  $73 = Math_fround($70 / $7);
  $74 = Math_fround($73 * $73);
  $75 = Math_fround($72 + $74);
  $76 = (Math_fround(Math_sqrt((Math_fround($75)))));
  $77 = Math_fround(Math_fround(1.0) / $76);
  $78 = Math_fround($68 * $77);
  $79 = Math_fround($69 * $77);
  $80 = Math_fround($70 * $77);
  HEAPF32[$agg$result>>2] = $78;
  $81 = (($agg$result) + 4|0);
  HEAPF32[$81>>2] = $79;
  $82 = (($agg$result) + 8|0);
  HEAPF32[$82>>2] = $80;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6string9sprintf_sEPcjPKcz($_DstBuf,$_DstSize,$_Format,$varargs) {
 $_DstBuf = $_DstBuf|0;
 $_DstSize = $_DstSize|0;
 $_Format = $_Format|0;
 $varargs = $varargs|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $arg = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $arg = sp;
 $0 = ($_DstBuf|0)==(0|0);
 $1 = ($_Format|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$arg>>2] = $varargs;
 $2 = (_vsprintf($_DstBuf,$_Format,$arg)|0);
 $$0 = $2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx31PxDefaultSimulationFilterShaderEjNS_12PxFilterDataEjS0_RNS_7PxFlagsINS_10PxPairFlag4EnumEtEEPKvj($agg$result,$attributes0,$filterData0,$attributes1,$filterData1,$pairFlags,$constantBlock,$constantBlockSize) {
 $agg$result = $agg$result|0;
 $attributes0 = $attributes0|0;
 $filterData0 = $filterData0|0;
 $attributes1 = $attributes1|0;
 $filterData1 = $filterData1|0;
 $pairFlags = $pairFlags|0;
 $constantBlock = $constantBlock|0;
 $constantBlockSize = $constantBlockSize|0;
 var $$ = 0, $$idx = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $filterData0$idx = 0, $filterData0$idx$val = 0, $filterData0$idx2 = 0, $filterData0$idx2$val = 0, $filterData1$idx = 0, $filterData1$idx$val = 0, $filterData1$idx1 = 0, $filterData1$idx1$val = 0, $final = 0, $g0 = 0, $g0k0 = 0, $g1 = 0, $g1k1 = 0, $not$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $g0 = sp + 32|0;
 $g1 = sp;
 $g0k0 = sp + 8|0;
 $g1k1 = sp + 16|0;
 $final = sp + 24|0;
 $0 = $attributes0 & 32;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = $attributes1 & 32;
  $3 = ($2|0)==(0);
  if ($3) {
   $4 = HEAP32[$filterData1>>2]|0;
   $5 = HEAP32[$filterData0>>2]|0;
   $$idx = ((411264 + ($5<<5)|0) + ($4)|0);
   $$idx$val = HEAP8[$$idx>>0]|0;
   $6 = ($$idx$val<<24>>24)==(0);
   if ($6) {
    HEAP16[$agg$result>>1] = 2;
    STACKTOP = sp;return;
   }
   $filterData0$idx = (($filterData0) + 8|0);
   $filterData0$idx$val = HEAP32[$filterData0$idx>>2]|0;
   $filterData0$idx2 = (($filterData0) + 12|0);
   $filterData0$idx2$val = HEAP32[$filterData0$idx2>>2]|0;
   $7 = $g0;
   $8 = $7;
   HEAP32[$8>>2] = 0;
   $9 = (($7) + 4)|0;
   $10 = $9;
   HEAP32[$10>>2] = 0;
   $11 = $filterData0$idx$val&65535;
   HEAP16[$g0>>1] = $11;
   $12 = $filterData0$idx$val >>> 16;
   $13 = $12&65535;
   $14 = (($g0) + 2|0);
   HEAP16[$14>>1] = $13;
   $15 = $filterData0$idx2$val&65535;
   $16 = (($g0) + 4|0);
   HEAP16[$16>>1] = $15;
   $17 = $filterData0$idx2$val >>> 16;
   $18 = $17&65535;
   $19 = (($g0) + 6|0);
   HEAP16[$19>>1] = $18;
   $filterData1$idx = (($filterData1) + 8|0);
   $filterData1$idx$val = HEAP32[$filterData1$idx>>2]|0;
   $filterData1$idx1 = (($filterData1) + 12|0);
   $filterData1$idx1$val = HEAP32[$filterData1$idx1>>2]|0;
   $20 = $g1;
   $21 = $20;
   HEAP32[$21>>2] = 0;
   $22 = (($20) + 4)|0;
   $23 = $22;
   HEAP32[$23>>2] = 0;
   $24 = $filterData1$idx$val&65535;
   HEAP16[$g1>>1] = $24;
   $25 = $filterData1$idx$val >>> 16;
   $26 = $25&65535;
   $27 = (($g1) + 2|0);
   HEAP16[$27>>1] = $26;
   $28 = $filterData1$idx1$val&65535;
   $29 = (($g1) + 4|0);
   HEAP16[$29>>1] = $28;
   $30 = $filterData1$idx1$val >>> 16;
   $31 = $30&65535;
   $32 = (($g1) + 6|0);
   HEAP16[$32>>1] = $31;
   $33 = $g0k0;
   $34 = $33;
   HEAP32[$34>>2] = 0;
   $35 = (($33) + 4)|0;
   $36 = $35;
   HEAP32[$36>>2] = 0;
   $37 = HEAP32[412304>>2]|0;
   FUNCTION_TABLE_viii[$37 & 4095]($g0k0,$g0,412288);
   $38 = $g1k1;
   $39 = $38;
   HEAP32[$39>>2] = 0;
   $40 = (($38) + 4)|0;
   $41 = $40;
   HEAP32[$41>>2] = 0;
   $42 = HEAP32[412304>>2]|0;
   FUNCTION_TABLE_viii[$42 & 4095]($g1k1,$g1,((412288 + 8|0)));
   $43 = $final;
   $44 = $43;
   HEAP32[$44>>2] = 0;
   $45 = (($43) + 4)|0;
   $46 = $45;
   HEAP32[$46>>2] = 0;
   $47 = HEAP32[412304>>2]|0;
   FUNCTION_TABLE_viii[$47 & 4095]($final,$g0k0,$g1k1);
   $48 = HEAP32[$final>>2]|0;
   $49 = $48&65535;
   $50 = ($49<<16>>16)==(0);
   $51 = ($48>>>0)<(65536);
   $or$cond = $50 & $51;
   if ($or$cond) {
    $52 = (($final) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = $53&65535;
    $55 = ($53>>>0)>(65535);
    $not$ = ($54<<16>>16)!=(0);
    $$ = $55 | $not$;
    $57 = $$;
   } else {
    $57 = 1;
   }
   $56 = $57&1;
   $58 = 0;
   $59 = ($56|0)==($58|0);
   if ($59) {
    HEAP16[$pairFlags>>1] = 1025;
    HEAP16[$agg$result>>1] = 0;
    STACKTOP = sp;return;
   } else {
    HEAP16[$agg$result>>1] = 2;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP16[$pairFlags>>1] = 20;
 HEAP16[$agg$result>>1] = 0;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_1L4gANDERN5physx12PxGroupsMaskERKS1_S4_($results,$mask0,$mask1) {
 $results = $results|0;
 $mask0 = $mask0|0;
 $mask1 = $mask1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$mask0>>1]|0;
 $1 = HEAP16[$mask1>>1]|0;
 $2 = $1 & $0;
 HEAP16[$results>>1] = $2;
 $3 = (($mask0) + 2|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = (($mask1) + 2|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6 & $4;
 $8 = (($results) + 2|0);
 HEAP16[$8>>1] = $7;
 $9 = (($mask0) + 4|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = (($mask1) + 4|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12 & $10;
 $14 = (($results) + 4|0);
 HEAP16[$14>>1] = $13;
 $15 = (($mask0) + 6|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($mask1) + 6|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 & $16;
 $20 = (($results) + 6|0);
 HEAP16[$20>>1] = $19;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_1L3gORERN5physx12PxGroupsMaskERKS1_S4_($results,$mask0,$mask1) {
 $results = $results|0;
 $mask0 = $mask0|0;
 $mask1 = $mask1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$mask0>>1]|0;
 $1 = HEAP16[$mask1>>1]|0;
 $2 = $1 | $0;
 HEAP16[$results>>1] = $2;
 $3 = (($mask0) + 2|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = (($mask1) + 2|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6 | $4;
 $8 = (($results) + 2|0);
 HEAP16[$8>>1] = $7;
 $9 = (($mask0) + 4|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = (($mask1) + 4|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12 | $10;
 $14 = (($results) + 4|0);
 HEAP16[$14>>1] = $13;
 $15 = (($mask0) + 6|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($mask1) + 6|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 | $16;
 $20 = (($results) + 6|0);
 HEAP16[$20>>1] = $19;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_1L4gXORERN5physx12PxGroupsMaskERKS1_S4_($results,$mask0,$mask1) {
 $results = $results|0;
 $mask0 = $mask0|0;
 $mask1 = $mask1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$mask0>>1]|0;
 $1 = HEAP16[$mask1>>1]|0;
 $2 = $1 ^ $0;
 HEAP16[$results>>1] = $2;
 $3 = (($mask0) + 2|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = (($mask1) + 2|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6 ^ $4;
 $8 = (($results) + 2|0);
 HEAP16[$8>>1] = $7;
 $9 = (($mask0) + 4|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = (($mask1) + 4|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12 ^ $10;
 $14 = (($results) + 4|0);
 HEAP16[$14>>1] = $13;
 $15 = (($mask0) + 6|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($mask1) + 6|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 ^ $16;
 $20 = (($results) + 6|0);
 HEAP16[$20>>1] = $19;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_1L5gNANDERN5physx12PxGroupsMaskERKS1_S4_($results,$mask0,$mask1) {
 $results = $results|0;
 $mask0 = $mask0|0;
 $mask1 = $mask1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$mask0>>1]|0;
 $1 = HEAP16[$mask1>>1]|0;
 $2 = $1 & $0;
 $3 = $2&65535;
 $4 = $3 ^ 65535;
 $5 = $4&65535;
 HEAP16[$results>>1] = $5;
 $6 = (($mask0) + 2|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = (($mask1) + 2|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9 & $7;
 $11 = $10&65535;
 $12 = $11 ^ 65535;
 $13 = $12&65535;
 $14 = (($results) + 2|0);
 HEAP16[$14>>1] = $13;
 $15 = (($mask0) + 4|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($mask1) + 4|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 & $16;
 $20 = $19&65535;
 $21 = $20 ^ 65535;
 $22 = $21&65535;
 $23 = (($results) + 4|0);
 HEAP16[$23>>1] = $22;
 $24 = (($mask0) + 6|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = (($mask1) + 6|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = $27 & $25;
 $29 = $28&65535;
 $30 = $29 ^ 65535;
 $31 = $30&65535;
 $32 = (($results) + 6|0);
 HEAP16[$32>>1] = $31;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_1L4gNORERN5physx12PxGroupsMaskERKS1_S4_($results,$mask0,$mask1) {
 $results = $results|0;
 $mask0 = $mask0|0;
 $mask1 = $mask1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$mask0>>1]|0;
 $1 = HEAP16[$mask1>>1]|0;
 $2 = $1 | $0;
 $3 = $2&65535;
 $4 = $3 ^ 65535;
 $5 = $4&65535;
 HEAP16[$results>>1] = $5;
 $6 = (($mask0) + 2|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = (($mask1) + 2|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9 | $7;
 $11 = $10&65535;
 $12 = $11 ^ 65535;
 $13 = $12&65535;
 $14 = (($results) + 2|0);
 HEAP16[$14>>1] = $13;
 $15 = (($mask0) + 4|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($mask1) + 4|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 | $16;
 $20 = $19&65535;
 $21 = $20 ^ 65535;
 $22 = $21&65535;
 $23 = (($results) + 4|0);
 HEAP16[$23>>1] = $22;
 $24 = (($mask0) + 6|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = (($mask1) + 6|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = $27 | $25;
 $29 = $28&65535;
 $30 = $29 ^ 65535;
 $31 = $30&65535;
 $32 = (($results) + 6|0);
 HEAP16[$32>>1] = $31;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_1L5gNXORERN5physx12PxGroupsMaskERKS1_S4_($results,$mask0,$mask1) {
 $results = $results|0;
 $mask0 = $mask0|0;
 $mask1 = $mask1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$mask0>>1]|0;
 $1 = HEAP16[$mask1>>1]|0;
 $2 = $1 ^ $0;
 $3 = $2&65535;
 $4 = $3 ^ 65535;
 $5 = $4&65535;
 HEAP16[$results>>1] = $5;
 $6 = (($mask0) + 2|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = (($mask1) + 2|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9 ^ $7;
 $11 = $10&65535;
 $12 = $11 ^ 65535;
 $13 = $12&65535;
 $14 = (($results) + 2|0);
 HEAP16[$14>>1] = $13;
 $15 = (($mask0) + 4|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($mask1) + 4|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 ^ $16;
 $20 = $19&65535;
 $21 = $20 ^ 65535;
 $22 = $21&65535;
 $23 = (($results) + 4|0);
 HEAP16[$23>>1] = $22;
 $24 = (($mask0) + 6|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = (($mask1) + 6|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = $27 ^ $25;
 $29 = $28&65535;
 $30 = $29 ^ 65535;
 $31 = $30&65535;
 $32 = (($results) + 6|0);
 HEAP16[$32>>1] = $31;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_1L9gSWAP_ANDERN5physx12PxGroupsMaskERKS1_S4_($results,$mask0,$mask1) {
 $results = $results|0;
 $mask0 = $mask0|0;
 $mask1 = $mask1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$mask0>>1]|0;
 $1 = (($mask1) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & $0;
 HEAP16[$results>>1] = $3;
 $4 = (($mask0) + 2|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = (($mask1) + 6|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 & $5;
 $9 = (($results) + 2|0);
 HEAP16[$9>>1] = $8;
 $10 = (($mask0) + 4|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = HEAP16[$mask1>>1]|0;
 $13 = $12 & $11;
 $14 = (($results) + 4|0);
 HEAP16[$14>>1] = $13;
 $15 = (($mask0) + 6|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($mask1) + 2|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 & $16;
 $20 = (($results) + 6|0);
 HEAP16[$20>>1] = $19;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a1253() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 _memset((411264|0),1,1024)|0;
 ;HEAP32[412288+0>>2]=0|0;HEAP32[412288+4>>2]=0|0;HEAP32[412288+8>>2]=0|0;HEAP32[412288+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __Z16PxInitExtensionsRN5physx9PxPhysicsE($physics) {
 $physics = $physics|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx6shdfnd10Foundation11incRefCountEv();
 STACKTOP = sp;return 1;
}
function __Z17PxCloseExtensionsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx6shdfnd10Foundation11decRefCountEv();
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $16 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = HEAP32[$this>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,412416,412336,558)|0);
  $16 = $12;
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = (($this) + 4|0);
 $18 = ($14|0)>(0);
 if ($18) {
  $19 = HEAP32[$17>>2]|0;
  $$012$i = $16;$$03$i = $19;
  while(1) {
   $20 = ($$012$i|0)==(0|0);
   if (!($20)) {
    $21 = $$03$i;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + 4)|0;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    $27 = $$012$i;
    $28 = $27;
    HEAP32[$28>>2] = $23;
    $29 = (($27) + 4)|0;
    $30 = $29;
    HEAP32[$30>>2] = $26;
   }
   $31 = (($$012$i) + 8|0);
   $32 = (($$03$i) + 8|0);
   $33 = ($31>>>0)<($15>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$13>>2]|0;
  $35 = $$pre;
 } else {
  $35 = $14;
 }
 $34 = (($16) + ($35<<3)|0);
 $36 = ($34|0)==(0|0);
 if (!($36)) {
  $37 = $a;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + 4)|0;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = $34;
  $44 = $43;
  HEAP32[$44>>2] = $39;
  $45 = (($43) + 4)|0;
  $46 = $45;
  HEAP32[$46>>2] = $42;
 }
 $47 = HEAP32[$0>>2]|0;
 $48 = ($47|0)>(-1);
 if ($48) {
  $49 = HEAP32[$17>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = HEAP32[$this>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  }
 }
 HEAP32[$17>>2] = $16;
 HEAP32[$0>>2] = $$$i;
 $56 = HEAP32[$13>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$13>>2] = $57;
 $58 = (($16) + ($56<<3)|0);
 STACKTOP = sp;return ($58|0);
}
function __ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $16 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = HEAP32[$this>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,412416,412336,558)|0);
  $16 = $12;
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = (($this) + 4|0);
 $18 = ($14|0)>(0);
 if ($18) {
  $19 = HEAP32[$17>>2]|0;
  $$012$i = $16;$$03$i = $19;
  while(1) {
   $20 = ($$012$i|0)==(0|0);
   if (!($20)) {
    $21 = $$03$i;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + 4)|0;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    $27 = $$012$i;
    $28 = $27;
    HEAP32[$28>>2] = $23;
    $29 = (($27) + 4)|0;
    $30 = $29;
    HEAP32[$30>>2] = $26;
   }
   $31 = (($$012$i) + 8|0);
   $32 = (($$03$i) + 8|0);
   $33 = ($31>>>0)<($15>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$13>>2]|0;
  $35 = $$pre;
 } else {
  $35 = $14;
 }
 $34 = (($16) + ($35<<3)|0);
 $36 = ($34|0)==(0|0);
 if (!($36)) {
  $37 = $a;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + 4)|0;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = $34;
  $44 = $43;
  HEAP32[$44>>2] = $39;
  $45 = (($43) + 4)|0;
  $46 = $45;
  HEAP32[$46>>2] = $42;
 }
 $47 = HEAP32[$0>>2]|0;
 $48 = ($47|0)>(-1);
 if ($48) {
  $49 = HEAP32[$17>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = HEAP32[$this>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  }
 }
 HEAP32[$17>>2] = $16;
 HEAP32[$0>>2] = $$$i;
 $56 = HEAP32[$13>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$13>>2] = $57;
 $58 = (($16) + ($56<<3)|0);
 STACKTOP = sp;return ($58|0);
}
function __ZN5physxlsERNS_14PxOutputStreamERKNS_6PxVec3E($ioStream,$inData) {
 $ioStream = $ioStream|0;
 $inData = $inData|0;
 var $0 = Math_fround(0), $1 = 0.0, $10 = Math_fround(0), $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i = 0, $vararg_buffer4 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer4 = sp;
 $buffer$i$i = sp + 8|0;
 $0 = Math_fround(HEAPF32[$inData>>2]);
 $1 = +$0;
 dest=$buffer$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$1;HEAP32[$vararg_buffer4>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer4+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i,0,412456,$vararg_buffer4)|0);
 $2 = HEAP8[$buffer$i$i>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = HEAP32[$ioStream>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (_strlen(($buffer$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$5 & 2047]($ioStream,$buffer$i$i,$6)|0);
 }
 $7 = HEAP32[$ioStream>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 (FUNCTION_TABLE_iiii[$8 & 2047]($ioStream,412464,1)|0);
 $9 = (($inData) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = +$10;
 dest=$buffer$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$11;HEAP32[$vararg_buffer4>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer4+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i,0,412456,$vararg_buffer4)|0);
 $12 = HEAP8[$buffer$i$i>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if (!($13)) {
  $14 = HEAP32[$ioStream>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (_strlen(($buffer$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$15 & 2047]($ioStream,$buffer$i$i,$16)|0);
 }
 $17 = HEAP32[$ioStream>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_iiii[$18 & 2047]($ioStream,412464,1)|0);
 $19 = (($inData) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = +$20;
 dest=$buffer$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$21;HEAP32[$vararg_buffer4>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer4+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i,0,412456,$vararg_buffer4)|0);
 $22 = HEAP8[$buffer$i$i>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  STACKTOP = sp;return ($ioStream|0);
 }
 $24 = HEAP32[$ioStream>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (_strlen(($buffer$i$i|0))|0);
 (FUNCTION_TABLE_iiii[$25 & 2047]($ioStream,$buffer$i$i,$26)|0);
 STACKTOP = sp;return ($ioStream|0);
}
function __ZN5physx2Sn9StrToImplINS_6PxVec3EE5strtoERS2_RPKc($this,$ioDatatype,$ioData) {
 $this = $this|0;
 $ioDatatype = $ioDatatype|0;
 $ioData = $ioData|0;
 var $$0$lcssa$i$i = 0, $$0$lcssa$i$i17 = 0, $$0$lcssa$i$i5 = 0, $$05$i$i = 0, $$05$i$i15 = 0, $$05$i$i3 = 0, $$14$i$i = 0, $$14$i$i19 = 0, $$14$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0.0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $dest$0$lcssa$i$i = 0, $dest$0$lcssa$i$i10 = 0, $dest$0$lcssa$i$i22 = 0, $dest$03$i$i = 0, $dest$03$i$i20 = 0, $dest$03$i$i8 = 0, $end$i$i14 = 0, $temp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $end$i$i14 = sp;
 $temp$i$i = sp + 8|0;
 $0 = HEAP32[$ioData>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 L1: do {
  if ($2) {
   $$0$lcssa$i$i5 = $0;
  } else {
   $$05$i$i3 = $0;$7 = $1;
   while(1) {
    $6 = $7&255;
    $8 = (_isspace($6)|0);
    $9 = ($8|0)==(0);
    $4 = (($$05$i$i3) + 1|0);
    if ($9) {
     $$0$lcssa$i$i5 = $$05$i$i3;
     break L1;
    }
    $3 = HEAP8[$4>>0]|0;
    $5 = ($3<<24>>24)==(0);
    if ($5) {
     $$0$lcssa$i$i5 = $4;
     break;
    } else {
     $$05$i$i3 = $4;$7 = $3;
    }
   }
  }
 } while(0);
 _memset(($temp$i$i|0),0,256)|0;
 $10 = (($temp$i$i) + 255|0);
 HEAP32[$end$i$i14>>2] = $10;
 $11 = HEAP8[$$0$lcssa$i$i5>>0]|0;
 $12 = ($11<<24>>24)==(0);
 L6: do {
  if ($12) {
   $dest$0$lcssa$i$i10 = $temp$i$i;
  } else {
   $$14$i$i7 = $$0$lcssa$i$i5;$14 = $11;$dest$03$i$i8 = $temp$i$i;
   while(1) {
    $13 = $14&255;
    $15 = (_isspace($13)|0);
    $16 = ($15|0)==(0);
    if (!($16)) {
     $dest$0$lcssa$i$i10 = $dest$03$i$i8;
     break L6;
    }
    $17 = HEAP32[$end$i$i14>>2]|0;
    $18 = ($dest$03$i$i8>>>0)<($17>>>0);
    if (!($18)) {
     $dest$0$lcssa$i$i10 = $dest$03$i$i8;
     break L6;
    }
    $19 = (($$14$i$i7) + 1|0);
    $20 = HEAP8[$$14$i$i7>>0]|0;
    $21 = (($dest$03$i$i8) + 1|0);
    HEAP8[$dest$03$i$i8>>0] = $20;
    $22 = HEAP8[$19>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     $dest$0$lcssa$i$i10 = $21;
     break;
    } else {
     $$14$i$i7 = $19;$14 = $22;$dest$03$i$i8 = $21;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i10>>0] = 0;
 $24 = (+_strtod($temp$i$i,$end$i$i14));
 $25 = Math_fround($24);
 $26 = ($ioData|0)==(0|0);
 if ($26) {
  $34 = 0;
 } else {
  $27 = HEAP32[$end$i$i14>>2]|0;
  $28 = $27;
  $29 = $temp$i$i;
  $30 = (($28) - ($29))|0;
  $31 = (($$0$lcssa$i$i5) + ($30)|0);
  HEAP32[$ioData>>2] = $31;
  $34 = $31;
 }
 HEAPF32[$ioDatatype>>2] = $25;
 $32 = (($ioDatatype) + 4|0);
 $33 = HEAP8[$34>>0]|0;
 $35 = ($33<<24>>24)==(0);
 L15: do {
  if ($35) {
   $$0$lcssa$i$i17 = $34;
  } else {
   $$05$i$i15 = $34;$40 = $33;
   while(1) {
    $39 = $40&255;
    $41 = (_isspace($39)|0);
    $42 = ($41|0)==(0);
    $37 = (($$05$i$i15) + 1|0);
    if ($42) {
     $$0$lcssa$i$i17 = $$05$i$i15;
     break L15;
    }
    $36 = HEAP8[$37>>0]|0;
    $38 = ($36<<24>>24)==(0);
    if ($38) {
     $$0$lcssa$i$i17 = $37;
     break;
    } else {
     $$05$i$i15 = $37;$40 = $36;
    }
   }
  }
 } while(0);
 _memset(($temp$i$i|0),0,256)|0;
 HEAP32[$end$i$i14>>2] = $10;
 $43 = HEAP8[$$0$lcssa$i$i17>>0]|0;
 $44 = ($43<<24>>24)==(0);
 L20: do {
  if ($44) {
   $dest$0$lcssa$i$i22 = $temp$i$i;
  } else {
   $$14$i$i19 = $$0$lcssa$i$i17;$46 = $43;$dest$03$i$i20 = $temp$i$i;
   while(1) {
    $45 = $46&255;
    $47 = (_isspace($45)|0);
    $48 = ($47|0)==(0);
    if (!($48)) {
     $dest$0$lcssa$i$i22 = $dest$03$i$i20;
     break L20;
    }
    $49 = HEAP32[$end$i$i14>>2]|0;
    $50 = ($dest$03$i$i20>>>0)<($49>>>0);
    if (!($50)) {
     $dest$0$lcssa$i$i22 = $dest$03$i$i20;
     break L20;
    }
    $51 = (($$14$i$i19) + 1|0);
    $52 = HEAP8[$$14$i$i19>>0]|0;
    $53 = (($dest$03$i$i20) + 1|0);
    HEAP8[$dest$03$i$i20>>0] = $52;
    $54 = HEAP8[$51>>0]|0;
    $55 = ($54<<24>>24)==(0);
    if ($55) {
     $dest$0$lcssa$i$i22 = $53;
     break;
    } else {
     $$14$i$i19 = $51;$46 = $54;$dest$03$i$i20 = $53;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i22>>0] = 0;
 $56 = (+_strtod($temp$i$i,$end$i$i14));
 $57 = Math_fround($56);
 if ($26) {
  $65 = 0;
 } else {
  $58 = HEAP32[$end$i$i14>>2]|0;
  $59 = $58;
  $60 = $temp$i$i;
  $61 = (($59) - ($60))|0;
  $62 = (($$0$lcssa$i$i17) + ($61)|0);
  HEAP32[$ioData>>2] = $62;
  $65 = $62;
 }
 HEAPF32[$32>>2] = $57;
 $63 = (($ioDatatype) + 8|0);
 $64 = HEAP8[$65>>0]|0;
 $66 = ($64<<24>>24)==(0);
 L29: do {
  if ($66) {
   $$0$lcssa$i$i = $65;
  } else {
   $$05$i$i = $65;$71 = $64;
   while(1) {
    $70 = $71&255;
    $72 = (_isspace($70)|0);
    $73 = ($72|0)==(0);
    $68 = (($$05$i$i) + 1|0);
    if ($73) {
     $$0$lcssa$i$i = $$05$i$i;
     break L29;
    }
    $67 = HEAP8[$68>>0]|0;
    $69 = ($67<<24>>24)==(0);
    if ($69) {
     $$0$lcssa$i$i = $68;
     break;
    } else {
     $$05$i$i = $68;$71 = $67;
    }
   }
  }
 } while(0);
 _memset(($temp$i$i|0),0,256)|0;
 HEAP32[$end$i$i14>>2] = $10;
 $74 = HEAP8[$$0$lcssa$i$i>>0]|0;
 $75 = ($74<<24>>24)==(0);
 L34: do {
  if ($75) {
   $dest$0$lcssa$i$i = $temp$i$i;
  } else {
   $$14$i$i = $$0$lcssa$i$i;$77 = $74;$dest$03$i$i = $temp$i$i;
   while(1) {
    $76 = $77&255;
    $78 = (_isspace($76)|0);
    $79 = ($78|0)==(0);
    if (!($79)) {
     $dest$0$lcssa$i$i = $dest$03$i$i;
     break L34;
    }
    $80 = HEAP32[$end$i$i14>>2]|0;
    $81 = ($dest$03$i$i>>>0)<($80>>>0);
    if (!($81)) {
     $dest$0$lcssa$i$i = $dest$03$i$i;
     break L34;
    }
    $82 = (($$14$i$i) + 1|0);
    $83 = HEAP8[$$14$i$i>>0]|0;
    $84 = (($dest$03$i$i) + 1|0);
    HEAP8[$dest$03$i$i>>0] = $83;
    $85 = HEAP8[$82>>0]|0;
    $86 = ($85<<24>>24)==(0);
    if ($86) {
     $dest$0$lcssa$i$i = $84;
     break;
    } else {
     $$14$i$i = $82;$77 = $85;$dest$03$i$i = $84;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i>>0] = 0;
 $87 = (+_strtod($temp$i$i,$end$i$i14));
 $88 = Math_fround($87);
 if ($26) {
  HEAPF32[$63>>2] = $88;
  STACKTOP = sp;return;
 }
 $89 = HEAP32[$end$i$i14>>2]|0;
 $90 = $89;
 $91 = $temp$i$i;
 $92 = (($90) - ($91))|0;
 $93 = (($$0$lcssa$i$i) + ($92)|0);
 HEAP32[$ioData>>2] = $93;
 HEAPF32[$63>>2] = $88;
 STACKTOP = sp;return;
}
function __ZN5physxlsERNS_14PxOutputStreamERKNS_12PxFilterDataE($ioStream,$inData) {
 $ioStream = $ioStream|0;
 $inData = $inData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i = 0, $vararg_buffer7 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer7 = sp;
 $buffer$i$i = sp + 8|0;
 $0 = HEAP32[$inData>>2]|0;
 dest=$buffer$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer7>>2] = $0;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i,0,412472,$vararg_buffer7)|0);
 $1 = HEAP8[$buffer$i$i>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = HEAP32[$ioStream>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = (_strlen(($buffer$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$4 & 2047]($ioStream,$buffer$i$i,$5)|0);
 }
 $6 = HEAP32[$ioStream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($ioStream,412464,1)|0);
 $8 = (($inData) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 dest=$buffer$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer7>>2] = $9;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i,0,412472,$vararg_buffer7)|0);
 $10 = HEAP8[$buffer$i$i>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = HEAP32[$ioStream>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (_strlen(($buffer$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$13 & 2047]($ioStream,$buffer$i$i,$14)|0);
 }
 $15 = HEAP32[$ioStream>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 (FUNCTION_TABLE_iiii[$16 & 2047]($ioStream,412464,1)|0);
 $17 = (($inData) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 dest=$buffer$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer7>>2] = $18;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i,0,412472,$vararg_buffer7)|0);
 $19 = HEAP8[$buffer$i$i>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  $21 = HEAP32[$ioStream>>2]|0;
  $22 = HEAP32[$21>>2]|0;
  $23 = (_strlen(($buffer$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$22 & 2047]($ioStream,$buffer$i$i,$23)|0);
 }
 $24 = HEAP32[$ioStream>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_iiii[$25 & 2047]($ioStream,412464,1)|0);
 $26 = (($inData) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 dest=$buffer$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer7>>2] = $27;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i,0,412472,$vararg_buffer7)|0);
 $28 = HEAP8[$buffer$i$i>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  STACKTOP = sp;return ($ioStream|0);
 }
 $30 = HEAP32[$ioStream>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (_strlen(($buffer$i$i|0))|0);
 (FUNCTION_TABLE_iiii[$31 & 2047]($ioStream,$buffer$i$i,$32)|0);
 STACKTOP = sp;return ($ioStream|0);
}
function __ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $16 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = HEAP32[$this>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,412416,412336,558)|0);
  $16 = $12;
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = (($this) + 4|0);
 $18 = ($14|0)>(0);
 if ($18) {
  $19 = HEAP32[$17>>2]|0;
  $$012$i = $16;$$03$i = $19;
  while(1) {
   $20 = ($$012$i|0)==(0|0);
   if (!($20)) {
    $21 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $21;
   }
   $22 = (($$012$i) + 4|0);
   $23 = (($$03$i) + 4|0);
   $24 = ($22>>>0)<($15>>>0);
   if ($24) {
    $$012$i = $22;$$03$i = $23;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$13>>2]|0;
  $26 = $$pre;
 } else {
  $26 = $14;
 }
 $25 = (($16) + ($26<<2)|0);
 $27 = ($25|0)==(0|0);
 if (!($27)) {
  $28 = HEAP32[$a>>2]|0;
  HEAP32[$25>>2] = $28;
 }
 $29 = HEAP32[$0>>2]|0;
 $30 = ($29|0)>(-1);
 if ($30) {
  $31 = HEAP32[$17>>2]|0;
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   $33 = HEAP32[$this>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   FUNCTION_TABLE_vii[$37 & 4095]($34,$31);
  }
 }
 HEAP32[$17>>2] = $16;
 HEAP32[$0>>2] = $$$i;
 $38 = HEAP32[$13>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$13>>2] = $39;
 $40 = (($16) + ($38<<2)|0);
 STACKTOP = sp;return ($40|0);
}
function __ZN5physx6PxQuatC2ERKNS_7PxMat33E($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0;
 var $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $i$0 = 0, $i$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$m>>2]);
 $1 = (($m) + 12|0);
 $2 = (($1) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($0 + $3);
 $5 = (($m) + 24|0);
 $6 = (($5) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($4 + $7);
 $9 = !($8 >= Math_fround(0.0));
 if (!($9)) {
  $10 = Math_fround($8 + Math_fround(1.0));
  $11 = (Math_fround(Math_sqrt((Math_fround($10)))));
  $12 = Math_fround($11 * Math_fround(0.5));
  $13 = (($this) + 12|0);
  HEAPF32[$13>>2] = $12;
  $14 = Math_fround(Math_fround(0.5) / $11);
  $15 = (($1) + 8|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($5) + 4|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($16 - $18);
  $20 = Math_fround($14 * $19);
  HEAPF32[$this>>2] = $20;
  $21 = Math_fround(HEAPF32[$5>>2]);
  $22 = (($m) + 8|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($21 - $23);
  $25 = Math_fround($14 * $24);
  $26 = (($this) + 4|0);
  HEAPF32[$26>>2] = $25;
  $27 = (($m) + 4|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround(HEAPF32[$1>>2]);
  $30 = Math_fround($28 - $29);
  $31 = Math_fround($14 * $30);
  $32 = (($this) + 8|0);
  HEAPF32[$32>>2] = $31;
  STACKTOP = sp;return;
 }
 $33 = $3 > $0;
 $i$0 = $33&1;
 $34 = (($m) + (($i$0*12)|0)|0);
 $35 = (($34) + ($i$0<<2)|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = $7 > $36;
 $i$1 = $37 ? 2 : $i$0;
 if ((($i$1|0) == 1)) {
  $63 = Math_fround($0 + $7);
  $64 = Math_fround($3 - $63);
  $65 = Math_fround($64 + Math_fround(1.0));
  $66 = (Math_fround(Math_sqrt((Math_fround($65)))));
  $67 = Math_fround($66 * Math_fround(0.5));
  $68 = (($this) + 4|0);
  HEAPF32[$68>>2] = $67;
  $69 = Math_fround(Math_fround(0.5) / $66);
  $70 = (($5) + 4|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = (($1) + 8|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($71 + $73);
  $75 = Math_fround($69 * $74);
  $76 = (($this) + 8|0);
  HEAPF32[$76>>2] = $75;
  $77 = Math_fround(HEAPF32[$1>>2]);
  $78 = (($m) + 4|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($77 + $79);
  $81 = Math_fround($69 * $80);
  HEAPF32[$this>>2] = $81;
  $82 = Math_fround(HEAPF32[$5>>2]);
  $83 = (($m) + 8|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = Math_fround($82 - $84);
  $86 = Math_fround($69 * $85);
  $87 = (($this) + 12|0);
  HEAPF32[$87>>2] = $86;
  STACKTOP = sp;return;
 } else if ((($i$1|0) == 0)) {
  $38 = Math_fround($3 + $7);
  $39 = Math_fround($0 - $38);
  $40 = Math_fround($39 + Math_fround(1.0));
  $41 = (Math_fround(Math_sqrt((Math_fround($40)))));
  $42 = Math_fround($41 * Math_fround(0.5));
  HEAPF32[$this>>2] = $42;
  $43 = Math_fround(Math_fround(0.5) / $41);
  $44 = Math_fround(HEAPF32[$1>>2]);
  $45 = (($m) + 4|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($44 + $46);
  $48 = Math_fround($43 * $47);
  $49 = (($this) + 4|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($m) + 8|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround(HEAPF32[$5>>2]);
  $53 = Math_fround($51 + $52);
  $54 = Math_fround($43 * $53);
  $55 = (($this) + 8|0);
  HEAPF32[$55>>2] = $54;
  $56 = (($1) + 8|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($5) + 4|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($57 - $59);
  $61 = Math_fround($43 * $60);
  $62 = (($this) + 12|0);
  HEAPF32[$62>>2] = $61;
  STACKTOP = sp;return;
 } else if ((($i$1|0) == 2)) {
  $88 = Math_fround($7 - $4);
  $89 = Math_fround($88 + Math_fround(1.0));
  $90 = (Math_fround(Math_sqrt((Math_fround($89)))));
  $91 = Math_fround($90 * Math_fround(0.5));
  $92 = (($this) + 8|0);
  HEAPF32[$92>>2] = $91;
  $93 = Math_fround(Math_fround(0.5) / $90);
  $94 = (($m) + 8|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = Math_fround(HEAPF32[$5>>2]);
  $97 = Math_fround($95 + $96);
  $98 = Math_fround($93 * $97);
  HEAPF32[$this>>2] = $98;
  $99 = (($5) + 4|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($1) + 8|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($100 + $102);
  $104 = Math_fround($93 * $103);
  $105 = (($this) + 4|0);
  HEAPF32[$105>>2] = $104;
  $106 = (($m) + 4|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = Math_fround(HEAPF32[$1>>2]);
  $109 = Math_fround($107 - $108);
  $110 = Math_fround($93 * $109);
  $111 = (($this) + 12|0);
  HEAPF32[$111>>2] = $110;
  STACKTOP = sp;return;
 } else {
  ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS_7profile26WrapperReflectionAllocatorIjEEE6GetKeyESD_Lb1EE6createERS6_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0 = 0, $h$0$lcssa$i$i$i = 0, $h$0$lcssa$i$i$i5 = 0, $h$01$i$i$i = 0, $h$01$i$i$i3 = 0, $h$1 = 0, $index$0 = 0, $index$011 = 0, $index$012 = 0;
 var $ptr$02$i$i$i = 0, $ptr$02$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $h$0$lcssa$i$i$i = 5381;
   } else {
    $8 = $4;$h$01$i$i$i = 5381;$ptr$02$i$i$i = $3;
    while(1) {
     $6 = ($h$01$i$i$i*33)|0;
     $7 = $8 << 24 >> 24;
     $9 = $6 ^ $7;
     $10 = (($ptr$02$i$i$i) + 1|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $h$0$lcssa$i$i$i = $9;
      break;
     } else {
      $8 = $11;$h$01$i$i$i = $9;$ptr$02$i$i$i = $10;
     }
    }
   }
   $13 = (($1) + -1)|0;
   $14 = $h$0$lcssa$i$i$i & $13;
   $15 = (($this) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($14<<2)|0);
   $index$011 = HEAP32[$17>>2]|0;
   $18 = ($index$011|0)==(-1);
   if ($18) {
    $h$0 = $14;
   } else {
    $19 = (($this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($this) + 12|0);
    $index$012 = $index$011;
    while(1) {
     $22 = (($20) + ($index$012<<3)|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (_strcmp($23,$3)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      break;
     }
     $26 = HEAP32[$21>>2]|0;
     $27 = (($26) + ($index$012<<2)|0);
     $index$0 = HEAP32[$27>>2]|0;
     $28 = ($index$0|0)==(-1);
     if ($28) {
      $h$0 = $14;
      break L1;
     } else {
      $index$012 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $29 = (($20) + ($index$012<<3)|0);
    $$0 = $29;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $30 = (($this) + 40|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($31|0)==($33|0);
 if ($34) {
  $35 = $1 << 1;
  $$$i = $2 ? 16 : $35;
  $36 = ($1>>>0)<($$$i>>>0);
  if ($36) {
   __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS_7profile26WrapperReflectionAllocatorIjEEE6GetKeyESD_Lb1EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $48 = $$pre;
  } else {
   $48 = $1;
  }
  $37 = HEAP32[$k>>2]|0;
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $h$0$lcssa$i$i$i5 = 5381;
  } else {
   $42 = $38;$h$01$i$i$i3 = 5381;$ptr$02$i$i$i2 = $37;
   while(1) {
    $40 = ($h$01$i$i$i3*33)|0;
    $41 = $42 << 24 >> 24;
    $43 = $40 ^ $41;
    $44 = (($ptr$02$i$i$i2) + 1|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = ($45<<24>>24)==(0);
    if ($46) {
     $h$0$lcssa$i$i$i5 = $43;
     break;
    } else {
     $42 = $45;$h$01$i$i$i3 = $43;$ptr$02$i$i$i2 = $44;
    }
   }
  }
  $47 = (($48) + -1)|0;
  $49 = $h$0$lcssa$i$i$i5 & $47;
  $h$1 = $49;
 } else {
  $h$1 = $h$0;
 }
 $50 = (($this) + 32|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 1)|0;
 HEAP32[$50>>2] = $52;
 $53 = (($this) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + ($h$1<<2)|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($this) + 12|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + ($51<<2)|0);
 HEAP32[$59>>2] = $56;
 HEAP32[$55>>2] = $51;
 $60 = HEAP32[$30>>2]|0;
 $61 = (($60) + 1)|0;
 HEAP32[$30>>2] = $61;
 $62 = (($this) + 36|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 1)|0;
 HEAP32[$62>>2] = $64;
 $65 = (($this) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($51<<3)|0);
 $$0 = $67;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS_7profile26WrapperReflectionAllocatorIjEEE6GetKeyESD_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $h$0$lcssa$i$i = 0, $h$01$i$i = 0, $index$01 = 0, $ptr$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 28|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = $21 << 3;
 $29 = (($27) + ($28))|0;
 $30 = HEAP32[$this>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (FUNCTION_TABLE_iiiiii[$34 & 255]($31,$29,412608,412648,354)|0);
 $36 = (($35) + ($22)|0);
 $37 = (($35) + ($27)|0);
 _memset(($35|0),-1,($22|0))|0;
 $38 = (($this) + 40|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 if (!($40)) {
  $41 = (($this) + 8|0);
  $42 = (($$0) + -1)|0;
  $index$01 = 0;
  while(1) {
   $43 = HEAP32[$41>>2]|0;
   $44 = (($43) + ($index$01<<3)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP8[$45>>0]|0;
   $47 = ($46<<24>>24)==(0);
   if ($47) {
    $h$0$lcssa$i$i = 5381;
   } else {
    $50 = $46;$h$01$i$i = 5381;$ptr$02$i$i = $45;
    while(1) {
     $48 = ($h$01$i$i*33)|0;
     $49 = $50 << 24 >> 24;
     $51 = $48 ^ $49;
     $52 = (($ptr$02$i$i) + 1|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = ($53<<24>>24)==(0);
     if ($54) {
      $h$0$lcssa$i$i = $51;
      break;
     } else {
      $50 = $53;$h$01$i$i = $51;$ptr$02$i$i = $52;
     }
    }
   }
   $55 = $h$0$lcssa$i$i & $42;
   $56 = (($35) + ($55<<2)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($36) + ($index$01<<2)|0);
   HEAP32[$58>>2] = $57;
   HEAP32[$56>>2] = $index$01;
   $59 = (($37) + ($index$01<<3)|0);
   $60 = ($59|0)==(0|0);
   if (!($60)) {
    HEAP32[$59>>2] = $45;
    $61 = ((($37) + ($index$01<<3)|0) + 4|0);
    $62 = ((($43) + ($index$01<<3)|0) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    HEAP32[$61>>2] = $63;
   }
   $64 = (($index$01) + 1)|0;
   $65 = HEAP32[$38>>2]|0;
   $66 = ($64>>>0)<($65>>>0);
   if ($66) {
    $index$01 = $64;
   } else {
    break;
   }
  }
 }
 $67 = (($this) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0|0);
 if (!($69)) {
  $70 = HEAP32[$this>>2]|0;
  $71 = HEAP32[$70>>2]|0;
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + 12|0);
  $74 = HEAP32[$73>>2]|0;
  FUNCTION_TABLE_vii[$74 & 4095]($71,$68);
 }
 HEAP32[$67>>2] = $35;
 $75 = (($this) + 16|0);
 HEAP32[$75>>2] = $35;
 $76 = (($this) + 24|0);
 HEAP32[$76>>2] = $$0;
 $77 = (($this) + 12|0);
 HEAP32[$77>>2] = $36;
 $78 = (($this) + 8|0);
 HEAP32[$78>>2] = $37;
 HEAP32[$15>>2] = $21;
 $79 = (($this) + 32|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(-1);
 if (!($81)) {
  STACKTOP = sp;return;
 }
 HEAP32[$79>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx3Ext21InertiaTensorComputer9translateERKNS_6PxVec3E($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $or$cond = 0, $or$cond65 = 0, $or$cond67 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$t>>2]);
 $1 = $0 == Math_fround(0.0);
 $2 = (($t) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $3 == Math_fround(0.0);
 $or$cond67 = $1 & $4;
 if ($or$cond67) {
  $5 = (($t) + 8|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = $6 == Math_fround(0.0);
  if ($7) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 44|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 40|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 36|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 + $0);
 $15 = (($t) + 4|0);
 $16 = Math_fround($11 + $3);
 $17 = (($t) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($9 + $18);
 $20 = $14 == Math_fround(0.0);
 $21 = $16 == Math_fround(0.0);
 $or$cond = $20 & $21;
 $22 = $19 == Math_fround(0.0);
 $or$cond65 = $or$cond & $22;
 $23 = Math_fround($9 * Math_fround(0.0));
 $24 = Math_fround($11 * Math_fround(-0.0));
 $25 = Math_fround($9 * $9);
 $26 = Math_fround($9 * $13);
 $27 = Math_fround(Math_fround(0.0) - $25);
 $28 = Math_fround($23 + $23);
 $29 = Math_fround($24 + $26);
 $30 = Math_fround($11 * $11);
 $31 = Math_fround($11 * $13);
 $32 = Math_fround($27 - $30);
 $33 = Math_fround($28 + $31);
 $34 = Math_fround($24 + $29);
 $35 = Math_fround($9 * Math_fround(-0.0));
 $36 = Math_fround($9 * $11);
 $37 = Math_fround($13 * Math_fround(0.0));
 $38 = Math_fround($35 + $35);
 $39 = Math_fround($36 + $37);
 $40 = Math_fround($13 * $13);
 $41 = Math_fround(-$40);
 $42 = Math_fround($38 + $31);
 $43 = Math_fround($27 - $40);
 $44 = Math_fround($37 + $39);
 $45 = Math_fround($11 * Math_fround(0.0));
 $46 = Math_fround($13 * Math_fround(-0.0));
 $47 = Math_fround($45 + $26);
 $48 = Math_fround($36 + $46);
 $49 = Math_fround($41 - $30);
 $50 = Math_fround($45 + $47);
 $51 = Math_fround($46 + $48);
 $52 = Math_fround($49 + Math_fround(0.0));
 if ($or$cond65) {
  $53 = (($this) + 48|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($32 * $54);
  $56 = Math_fround($33 * $54);
  $57 = Math_fround($34 * $54);
  $58 = Math_fround($42 * $54);
  $59 = Math_fround($43 * $54);
  $60 = Math_fround($44 * $54);
  $61 = Math_fround($50 * $54);
  $62 = Math_fround($51 * $54);
  $63 = Math_fround($52 * $54);
  $64 = Math_fround(HEAPF32[$this>>2]);
  $65 = Math_fround($55 + $64);
  HEAPF32[$this>>2] = $65;
  $66 = (($this) + 4|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($56 + $67);
  HEAPF32[$66>>2] = $68;
  $69 = (($this) + 8|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($57 + $70);
  HEAPF32[$69>>2] = $71;
  $72 = (($this) + 12|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($58 + $73);
  HEAPF32[$72>>2] = $74;
  $75 = (($this) + 16|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($59 + $76);
  HEAPF32[$75>>2] = $77;
  $78 = (($this) + 20|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($60 + $79);
  HEAPF32[$78>>2] = $80;
  $81 = (($this) + 24|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($61 + $82);
  HEAPF32[$81>>2] = $83;
  $84 = (($this) + 28|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($62 + $85);
  HEAPF32[$84>>2] = $86;
  $87 = (($this) + 32|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($63 + $88);
  HEAPF32[$87>>2] = $89;
 } else {
  $90 = Math_fround($19 * Math_fround(0.0));
  $91 = Math_fround($16 * Math_fround(-0.0));
  $92 = Math_fround($19 * $19);
  $93 = Math_fround($14 * $19);
  $94 = Math_fround(Math_fround(0.0) - $92);
  $95 = Math_fround($90 + $90);
  $96 = Math_fround($91 + $93);
  $97 = Math_fround($16 * $16);
  $98 = Math_fround($14 * $16);
  $99 = Math_fround($94 - $97);
  $100 = Math_fround($98 + $95);
  $101 = Math_fround($91 + $96);
  $102 = Math_fround($19 * Math_fround(-0.0));
  $103 = Math_fround($16 * $19);
  $104 = Math_fround($14 * Math_fround(0.0));
  $105 = Math_fround($102 + $102);
  $106 = Math_fround($104 + $103);
  $107 = Math_fround($14 * $14);
  $108 = Math_fround(-$107);
  $109 = Math_fround($98 + $105);
  $110 = Math_fround($94 - $107);
  $111 = Math_fround($104 + $106);
  $112 = Math_fround($16 * Math_fround(0.0));
  $113 = Math_fround($14 * Math_fround(-0.0));
  $114 = Math_fround($112 + $93);
  $115 = Math_fround($113 + $103);
  $116 = Math_fround($108 - $97);
  $117 = Math_fround($112 + $114);
  $118 = Math_fround($113 + $115);
  $119 = Math_fround($116 + Math_fround(0.0));
  $120 = Math_fround($32 - $99);
  $121 = Math_fround($33 - $100);
  $122 = Math_fround($34 - $101);
  $123 = Math_fround($42 - $109);
  $124 = Math_fround($43 - $110);
  $125 = Math_fround($44 - $111);
  $126 = Math_fround($50 - $117);
  $127 = Math_fround($51 - $118);
  $128 = Math_fround($52 - $119);
  $129 = (($this) + 48|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($120 * $130);
  $132 = Math_fround($121 * $130);
  $133 = Math_fround($122 * $130);
  $134 = Math_fround($123 * $130);
  $135 = Math_fround($124 * $130);
  $136 = Math_fround($125 * $130);
  $137 = Math_fround($126 * $130);
  $138 = Math_fround($127 * $130);
  $139 = Math_fround($128 * $130);
  $140 = Math_fround(HEAPF32[$this>>2]);
  $141 = Math_fround($131 + $140);
  HEAPF32[$this>>2] = $141;
  $142 = (($this) + 4|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = Math_fround($132 + $143);
  HEAPF32[$142>>2] = $144;
  $145 = (($this) + 8|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = Math_fround($133 + $146);
  HEAPF32[$145>>2] = $147;
  $148 = (($this) + 12|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = Math_fround($134 + $149);
  HEAPF32[$148>>2] = $150;
  $151 = (($this) + 16|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = Math_fround($135 + $152);
  HEAPF32[$151>>2] = $153;
  $154 = (($this) + 20|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = Math_fround($136 + $155);
  HEAPF32[$154>>2] = $156;
  $157 = (($this) + 24|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = Math_fround($137 + $158);
  HEAPF32[$157>>2] = $159;
  $160 = (($this) + 28|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = Math_fround($138 + $161);
  HEAPF32[$160>>2] = $162;
  $163 = (($this) + 32|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = Math_fround($139 + $164);
  HEAPF32[$163>>2] = $165;
 }
 $166 = Math_fround(HEAPF32[$t>>2]);
 $167 = Math_fround($166 + $13);
 HEAPF32[$12>>2] = $167;
 $168 = Math_fround(HEAPF32[$15>>2]);
 $169 = Math_fround($168 + $11);
 HEAPF32[$10>>2] = $169;
 $170 = Math_fround(HEAPF32[$17>>2]);
 $171 = Math_fround($170 + $9);
 HEAPF32[$8>>2] = $171;
 STACKTOP = sp;return;
}
function __ZL20updateMassAndInertiabRN5physx11PxRigidBodyEPKfjPKNS_6PxVec3Eb($multipleMassOrDensity,$body,$densities,$densityCount,$massLocalPose,$includeNonSimShapes) {
 $multipleMassOrDensity = $multipleMassOrDensity|0;
 $body = $body|0;
 $densities = $densities|0;
 $densityCount = $densityCount|0;
 $massLocalPose = $massLocalPose|0;
 $includeNonSimShapes = $includeNonSimShapes|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert3 = 0, $$pre = Math_fround(0), $$pre1 = Math_fround(0), $$pre2 = Math_fround(0), $$pre4 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0;
 var $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $com = 0, $diagTensor = 0, $inertiaComp = 0, $massOut = 0;
 var $or$cond = 0, $orient = 0, $success$1$off0 = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $vararg_buffer1 = sp;
 $massOut = sp + 124|0;
 $diagTensor = sp + 4|0;
 $orient = sp + 16|0;
 $com = sp + 32|0;
 $inertiaComp = sp + 44|0;
 $0 = sp + 96|0;
 HEAPF32[$massOut>>2] = Math_fround(1.0);
 HEAPF32[$diagTensor>>2] = Math_fround(1.0);
 $1 = (($diagTensor) + 4|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($diagTensor) + 8|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 HEAPF32[$orient>>2] = Math_fround(0.0);
 $3 = (($orient) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($orient) + 8|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($orient) + 12|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = ($massLocalPose|0)!=(0|0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$massLocalPose>>2]);
  HEAPF32[$com>>2] = $7;
  $8 = (($com) + 4|0);
  $9 = (($massLocalPose) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$8>>2] = $10;
  $11 = (($com) + 8|0);
  $12 = (($massLocalPose) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $13;
  $47 = $13;$48 = $10;$49 = $7;
 } else {
  HEAPF32[$com>>2] = Math_fround(0.0);
  $14 = (($com) + 4|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
  $15 = (($com) + 8|0);
  HEAPF32[$15>>2] = Math_fround(0.0);
  $47 = Math_fround(0.0);$48 = Math_fround(0.0);$49 = Math_fround(0.0);
 }
 $16 = ($densities|0)==(0|0);
 $17 = ($densityCount|0)==(0);
 $or$cond = $16 | $17;
 do {
  if ($or$cond) {
   $23 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   HEAP32[$vararg_buffer1>>2] = 413728;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($23,4,412760,291,413768,$vararg_buffer1);
   $27 = Math_fround(1.0);$42 = $49;$44 = $48;$46 = $47;$success$1$off0 = 0;
  } else {
   dest=$inertiaComp+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $18 = (__ZL21computeMassAndInertiabRN5physx11PxRigidBodyEPKfS3_jbRNS_3Ext21InertiaTensorComputerE($multipleMassOrDensity,$body,$densities,0,$densityCount,$includeNonSimShapes,$inertiaComp)|0);
   if (!($18)) {
    $22 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    HEAP32[$vararg_buffer1>>2] = 413728;
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($22,4,412760,283,412976,$vararg_buffer1);
    $27 = Math_fround(1.0);$42 = $49;$44 = $48;$46 = $47;$success$1$off0 = 0;
    break;
   }
   $19 = (($inertiaComp) + 48|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = $20 != Math_fround(0.0);
   if ($21) {
    __ZL25computeMassAndDiagInertiaRN5physx3Ext21InertiaTensorComputerERNS_6PxVec3ERNS_6PxQuatERfS4_bRKNS_11PxRigidBodyEPKc($inertiaComp,$diagTensor,$orient,$massOut,$com,$6,$body,413728);
    $$pre = Math_fround(HEAPF32[$massOut>>2]);
    $$pre1 = Math_fround(HEAPF32[$com>>2]);
    $$phi$trans$insert = (($com) + 4|0);
    $$pre2 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
    $$phi$trans$insert3 = (($com) + 8|0);
    $$pre4 = Math_fround(HEAPF32[$$phi$trans$insert3>>2]);
    $27 = $$pre;$42 = $$pre1;$44 = $$pre2;$46 = $$pre4;$success$1$off0 = 1;
   } else {
    $27 = Math_fround(1.0);$42 = $49;$44 = $48;$46 = $47;$success$1$off0 = 0;
   }
  }
 } while(0);
 $24 = HEAP32[$body>>2]|0;
 $25 = (($24) + 128|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vif[$26 & 255]($body,$27);
 $28 = HEAP32[$body>>2]|0;
 $29 = (($28) + 140|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($body,$diagTensor);
 $31 = HEAP32[$body>>2]|0;
 $32 = (($31) + 120|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = Math_fround(HEAPF32[$orient>>2]);
 HEAPF32[$0>>2] = $34;
 $35 = (($0) + 4|0);
 $36 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$35>>2] = $36;
 $37 = (($0) + 8|0);
 $38 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$37>>2] = $38;
 $39 = (($0) + 12|0);
 $40 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$39>>2] = $40;
 $41 = (($0) + 16|0);
 HEAPF32[$41>>2] = $42;
 $43 = (($0) + 20|0);
 HEAPF32[$43>>2] = $44;
 $45 = (($0) + 24|0);
 HEAPF32[$45>>2] = $46;
 FUNCTION_TABLE_vii[$33 & 4095]($body,$0);
 STACKTOP = sp;return ($success$1$off0|0);
}
function __ZN5physx14PxRigidBodyExt20updateMassAndInertiaERNS_11PxRigidBodyEfPKNS_6PxVec3Eb($body,$density,$massLocalPose,$includeNonSimShapes) {
 $body = $body|0;
 $density = Math_fround($density);
 $massLocalPose = $massLocalPose|0;
 $includeNonSimShapes = $includeNonSimShapes|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAPF32[$0>>2] = $density;
 $1 = (__ZL20updateMassAndInertiabRN5physx11PxRigidBodyEPKfjPKNS_6PxVec3Eb(0,$body,$0,1,$massLocalPose,$includeNonSimShapes)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL23setMassAndUpdateInertiabRN5physx11PxRigidBodyEPKfjPKNS_6PxVec3Eb($multipleMassOrDensity,$body,$masses,$massCount,$massLocalPose,$includeNonSimShapes) {
 $multipleMassOrDensity = $multipleMassOrDensity|0;
 $body = $body|0;
 $masses = $masses|0;
 $massCount = $massCount|0;
 $massLocalPose = $massLocalPose|0;
 $includeNonSimShapes = $includeNonSimShapes|0;
 var $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $com = 0, $diagTensor = 0, $inertiaComp = 0, $massOut = 0, $or$cond = 0, $orient = 0, $success$2$off0 = 0, $vararg_buffer1 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $vararg_buffer1 = sp;
 $massOut = sp + 124|0;
 $diagTensor = sp + 4|0;
 $orient = sp + 16|0;
 $com = sp + 32|0;
 $inertiaComp = sp + 44|0;
 $0 = sp + 96|0;
 HEAPF32[$massOut>>2] = Math_fround(1.0);
 HEAPF32[$diagTensor>>2] = Math_fround(1.0);
 $1 = (($diagTensor) + 4|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($diagTensor) + 8|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 HEAPF32[$orient>>2] = Math_fround(0.0);
 $3 = (($orient) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($orient) + 8|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($orient) + 12|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = ($massLocalPose|0)!=(0|0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$massLocalPose>>2]);
  HEAPF32[$com>>2] = $7;
  $8 = (($com) + 4|0);
  $9 = (($massLocalPose) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$8>>2] = $10;
  $11 = (($com) + 8|0);
  $12 = (($massLocalPose) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $13;
 } else {
  HEAPF32[$com>>2] = Math_fround(0.0);
  $14 = (($com) + 4|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
  $15 = (($com) + 8|0);
  HEAPF32[$15>>2] = Math_fround(0.0);
 }
 $16 = ($masses|0)==(0|0);
 $17 = ($massCount|0)==(0);
 $or$cond = $16 | $17;
 do {
  if ($or$cond) {
   $25 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   HEAP32[$vararg_buffer1>>2] = 412936;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($25,4,412760,353,413064,$vararg_buffer1);
   $29 = Math_fround(1.0);$success$2$off0 = 0;
  } else {
   dest=$inertiaComp+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $18 = (__ZL21computeMassAndInertiabRN5physx11PxRigidBodyEPKfS3_jbRNS_3Ext21InertiaTensorComputerE($multipleMassOrDensity,$body,0,$masses,$massCount,$includeNonSimShapes,$inertiaComp)|0);
   if (!($18)) {
    $24 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    HEAP32[$vararg_buffer1>>2] = 412936;
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($24,4,412760,345,412976,$vararg_buffer1);
    $29 = Math_fround(1.0);$success$2$off0 = 0;
    break;
   }
   $19 = (($inertiaComp) + 48|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = $20 != Math_fround(0.0);
   if ($21) {
    __ZL25computeMassAndDiagInertiaRN5physx3Ext21InertiaTensorComputerERNS_6PxVec3ERNS_6PxQuatERfS4_bRKNS_11PxRigidBodyEPKc($inertiaComp,$diagTensor,$orient,$massOut,$com,$6,$body,412936);
   }
   $22 = ($massCount|0)==(1);
   if ($22) {
    $23 = Math_fround(HEAPF32[$masses>>2]);
    HEAPF32[$massOut>>2] = $23;
    $29 = $23;$success$2$off0 = 1;
    break;
   } else {
    $$pre = Math_fround(HEAPF32[$massOut>>2]);
    $29 = $$pre;$success$2$off0 = 1;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$body>>2]|0;
 $27 = (($26) + 128|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vif[$28 & 255]($body,$29);
 $30 = HEAP32[$body>>2]|0;
 $31 = (($30) + 140|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($body,$diagTensor);
 $33 = HEAP32[$body>>2]|0;
 $34 = (($33) + 120|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = Math_fround(HEAPF32[$orient>>2]);
 HEAPF32[$0>>2] = $36;
 $37 = (($0) + 4|0);
 $38 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$37>>2] = $38;
 $39 = (($0) + 8|0);
 $40 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$39>>2] = $40;
 $41 = (($0) + 12|0);
 $42 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$41>>2] = $42;
 $43 = (($0) + 16|0);
 $44 = Math_fround(HEAPF32[$com>>2]);
 HEAPF32[$43>>2] = $44;
 $45 = (($0) + 20|0);
 $46 = (($com) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$45>>2] = $47;
 $48 = (($0) + 24|0);
 $49 = (($com) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 HEAPF32[$48>>2] = $50;
 FUNCTION_TABLE_vii[$35 & 4095]($body,$0);
 STACKTOP = sp;return ($success$2$off0|0);
}
function __ZN5physx14PxRigidBodyExt23setMassAndUpdateInertiaERNS_11PxRigidBodyEfPKNS_6PxVec3Eb($body,$mass,$massLocalPose,$includeNonSimShapes) {
 $body = $body|0;
 $mass = Math_fround($mass);
 $massLocalPose = $massLocalPose|0;
 $includeNonSimShapes = $includeNonSimShapes|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAPF32[$0>>2] = $mass;
 $1 = (__ZL23setMassAndUpdateInertiabRN5physx11PxRigidBodyEPKfjPKNS_6PxVec3Eb(0,$body,$0,1,$massLocalPose,$includeNonSimShapes)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx14PxRigidBodyExt13addForceAtPosERNS_11PxRigidBodyERKNS_6PxVec3ES5_NS_11PxForceMode4EnumEb($body,$force,$pos,$mode,$wakeup) {
 $body = $body|0;
 $force = $force|0;
 $pos = $pos|0;
 $mode = $mode|0;
 $wakeup = $wakeup|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z21addForceAtPosInternalRN5physx11PxRigidBodyERKNS_6PxVec3ES4_NS_11PxForceMode4EnumEb($body,$force,$pos,$mode,$wakeup);
 STACKTOP = sp;return;
}
function __Z21addForceAtPosInternalRN5physx11PxRigidBodyERKNS_6PxVec3ES4_NS_11PxForceMode4EnumEb($body,$force,$pos,$mode,$wakeup) {
 $body = $body|0;
 $force = $force|0;
 $pos = $pos|0;
 $mode = $mode|0;
 $wakeup = $wakeup|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $globalPose = 0, $torque = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer = sp;
 $globalPose = sp + 44|0;
 $0 = sp + 4|0;
 $torque = sp + 32|0;
 $1 = $mode & -2;
 $2 = ($1|0)==(2);
 if ($2) {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,4,412760,382,412848,$vararg_buffer);
  STACKTOP = sp;return;
 } else {
  $4 = HEAP32[$body>>2]|0;
  $5 = (($4) + 84|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($globalPose,$body);
  $7 = HEAP32[$body>>2]|0;
  $8 = (($7) + 124|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$9 & 4095]($0,$body);
  $10 = (($0) + 16|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($11 * Math_fround(2.0));
  $13 = (($0) + 20|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($14 * Math_fround(2.0));
  $16 = (($0) + 24|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($17 * Math_fround(2.0));
  $19 = (($globalPose) + 12|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($20 * $20);
  $22 = Math_fround($21 + Math_fround(-0.5));
  $23 = Math_fround(HEAPF32[$globalPose>>2]);
  $24 = Math_fround($12 * $23);
  $25 = (($globalPose) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($15 * $26);
  $28 = Math_fround($24 + $27);
  $29 = (($globalPose) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($18 * $30);
  $32 = Math_fround($28 + $31);
  $33 = Math_fround($12 * $22);
  $34 = Math_fround($18 * $26);
  $35 = Math_fround($15 * $30);
  $36 = Math_fround($34 - $35);
  $37 = Math_fround($20 * $36);
  $38 = Math_fround($33 + $37);
  $39 = Math_fround($23 * $32);
  $40 = Math_fround($39 + $38);
  $41 = Math_fround($15 * $22);
  $42 = Math_fround($12 * $30);
  $43 = Math_fround($18 * $23);
  $44 = Math_fround($42 - $43);
  $45 = Math_fround($20 * $44);
  $46 = Math_fround($41 + $45);
  $47 = Math_fround($26 * $32);
  $48 = Math_fround($47 + $46);
  $49 = Math_fround($18 * $22);
  $50 = Math_fround($15 * $23);
  $51 = Math_fround($12 * $26);
  $52 = Math_fround($50 - $51);
  $53 = Math_fround($20 * $52);
  $54 = Math_fround($49 + $53);
  $55 = Math_fround($30 * $32);
  $56 = Math_fround($54 + $55);
  $57 = (($globalPose) + 16|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($58 + $40);
  $60 = (($globalPose) + 20|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($61 + $48);
  $63 = (($globalPose) + 24|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($64 + $56);
  $66 = Math_fround(HEAPF32[$pos>>2]);
  $67 = Math_fround($66 - $59);
  $68 = (($pos) + 4|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($69 - $62);
  $71 = (($pos) + 8|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($72 - $65);
  $74 = (($force) + 8|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($70 * $75);
  $77 = (($force) + 4|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($73 * $78);
  $80 = Math_fround($76 - $79);
  $81 = Math_fround(HEAPF32[$force>>2]);
  $82 = Math_fround($73 * $81);
  $83 = Math_fround($75 * $67);
  $84 = Math_fround($82 - $83);
  $85 = Math_fround($67 * $78);
  $86 = Math_fround($70 * $81);
  $87 = Math_fround($85 - $86);
  HEAPF32[$torque>>2] = $80;
  $88 = (($torque) + 4|0);
  HEAPF32[$88>>2] = $84;
  $89 = (($torque) + 8|0);
  HEAPF32[$89>>2] = $87;
  $90 = HEAP32[$body>>2]|0;
  $91 = (($90) + 168|0);
  $92 = HEAP32[$91>>2]|0;
  FUNCTION_TABLE_viiii[$92 & 511]($body,$force,$mode,$wakeup);
  $93 = HEAP32[$body>>2]|0;
  $94 = (($93) + 172|0);
  $95 = HEAP32[$94>>2]|0;
  FUNCTION_TABLE_viiii[$95 & 511]($body,$torque,$mode,$wakeup);
  STACKTOP = sp;return;
 }
}
function __ZN5physx14PxRigidBodyExt16getVelocityAtPosERKNS_11PxRigidBodyERKNS_6PxVec3E($agg$result,$body,$point) {
 $agg$result = $agg$result|0;
 $body = $body|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0);
 var $globalPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 56|0;
 $globalPose = sp;
 $1 = sp + 28|0;
 $2 = HEAP32[$body>>2]|0;
 $3 = (($2) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($globalPose,$body);
 $5 = HEAP32[$body>>2]|0;
 $6 = (($5) + 124|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($1,$body);
 $8 = (($1) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * Math_fround(2.0));
 $11 = (($1) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * Math_fround(2.0));
 $14 = (($1) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * Math_fround(2.0));
 $17 = (($globalPose) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * $18);
 $20 = Math_fround($19 + Math_fround(-0.5));
 $21 = Math_fround(HEAPF32[$globalPose>>2]);
 $22 = Math_fround($10 * $21);
 $23 = (($globalPose) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($13 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($globalPose) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($16 * $28);
 $30 = Math_fround($26 + $29);
 $31 = Math_fround($10 * $20);
 $32 = Math_fround($16 * $24);
 $33 = Math_fround($13 * $28);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($18 * $34);
 $36 = Math_fround($31 + $35);
 $37 = Math_fround($21 * $30);
 $38 = Math_fround($37 + $36);
 $39 = Math_fround($13 * $20);
 $40 = Math_fround($10 * $28);
 $41 = Math_fround($16 * $21);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($18 * $42);
 $44 = Math_fround($39 + $43);
 $45 = Math_fround($24 * $30);
 $46 = Math_fround($45 + $44);
 $47 = Math_fround($16 * $20);
 $48 = Math_fround($13 * $21);
 $49 = Math_fround($10 * $24);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($18 * $50);
 $52 = Math_fround($47 + $51);
 $53 = Math_fround($28 * $30);
 $54 = Math_fround($52 + $53);
 $55 = (($globalPose) + 16|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 + $38);
 $58 = (($globalPose) + 20|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 + $46);
 $61 = (($globalPose) + 24|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 + $54);
 $64 = Math_fround(HEAPF32[$point>>2]);
 $65 = Math_fround($64 - $57);
 $66 = (($point) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 - $60);
 $69 = (($point) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 - $63);
 $72 = HEAP32[$body>>2]|0;
 $73 = (($72) + 152|0);
 $74 = HEAP32[$73>>2]|0;
 FUNCTION_TABLE_vii[$74 & 4095]($agg$result,$body);
 $75 = HEAP32[$body>>2]|0;
 $76 = (($75) + 160|0);
 $77 = HEAP32[$76>>2]|0;
 FUNCTION_TABLE_vii[$77 & 4095]($0,$body);
 $78 = (($0) + 4|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($71 * $79);
 $81 = (($0) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($68 * $82);
 $84 = Math_fround($80 - $83);
 $85 = Math_fround($65 * $82);
 $86 = Math_fround(HEAPF32[$0>>2]);
 $87 = Math_fround($71 * $86);
 $88 = Math_fround($85 - $87);
 $89 = Math_fround($68 * $86);
 $90 = Math_fround($65 * $79);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround(HEAPF32[$agg$result>>2]);
 $93 = Math_fround($84 + $92);
 HEAPF32[$agg$result>>2] = $93;
 $94 = (($agg$result) + 4|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($88 + $95);
 HEAPF32[$94>>2] = $96;
 $97 = (($agg$result) + 8|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($91 + $98);
 HEAPF32[$97>>2] = $99;
 STACKTOP = sp;return;
}
function __ZN5physx11PxHitBufferINS_10PxSweepHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx11PxHitBufferINS_10PxSweepHitEE14processTouchesEPKS1_j($this,$buffer,$nbHits) {
 $this = $this|0;
 $buffer = $buffer|0;
 $nbHits = $nbHits|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx13PxHitCallbackINS_10PxSweepHitEE13finalizeQueryEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx11PxHitBufferINS_10PxSweepHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZL21computeMassAndInertiabRN5physx11PxRigidBodyEPKfS3_jbRNS_3Ext21InertiaTensorComputerE($multipleMassOrDensity,$body,$densities,$masses,$densityOrMassCount,$includeNonSimShapes,$computer) {
 $multipleMassOrDensity = $multipleMassOrDensity|0;
 $body = $body|0;
 $densities = $densities|0;
 $masses = $masses|0;
 $densityOrMassCount = $densityOrMassCount|0;
 $includeNonSimShapes = $includeNonSimShapes|0;
 $computer = $computer|0;
 var $$3 = 0, $$lcssa16127 = Math_fround(0), $$lcssa20126 = Math_fround(0), $$lcssa24125 = Math_fround(0), $$pre104 = Math_fround(0), $$pre105 = Math_fround(0), $$pre106 = Math_fround(0), $$pre107 = Math_fround(0), $$pre108 = Math_fround(0), $$pre109 = Math_fround(0), $$pre110 = Math_fround(0), $$pre111 = Math_fround(0), $$pre112 = Math_fround(0), $$pre113 = Math_fround(0), $$pre114 = Math_fround(0), $$pre115 = Math_fround(0), $$pre116 = Math_fround(0), $$pre117 = Math_fround(0), $$pre118 = Math_fround(0), $$pre119 = Math_fround(0);
 var $$pre120 = Math_fround(0), $$pre121 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0;
 var $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0;
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0;
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0);
 var $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0;
 var $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0);
 var $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0);
 var $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0);
 var $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0);
 var $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0;
 var $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0);
 var $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0);
 var $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0);
 var $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0);
 var $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0;
 var $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0);
 var $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0);
 var $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = 0;
 var $655 = Math_fround(0), $656 = 0, $657 = Math_fround(0), $658 = 0, $659 = Math_fround(0), $66 = 0, $660 = 0, $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0), $664 = 0, $665 = Math_fround(0), $666 = 0, $667 = Math_fround(0), $668 = 0, $669 = Math_fround(0), $67 = 0, $670 = 0, $671 = 0, $672 = 0;
 var $673 = 0, $674 = Math_fround(0), $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge2 = 0, $convCoM = 0, $convInertia = 0, $convMass = 0, $currentMassOrDensity$0 = Math_fround(0), $currentMassOrDensity$172 = Math_fround(0), $currentMassOrDensity$2 = Math_fround(0), $currentMassOrDensity$3 = Math_fround(0);
 var $densities$masses = 0, $g = 0, $g1 = 0, $g4 = 0, $g7 = 0, $i$073 = 0, $it = 0, $or$cond = 0, $or$cond$i$i$i = 0, $or$cond128 = 0, $shapes = 0, $temp = 0, $temp3 = 0, $temp6 = 0, $v$0$i$i$i$i = Math_fround(0), $v$1$i$i$i$i = Math_fround(0), $v$2$i$i$i$i = Math_fround(0), $validShapeIndex$071 = 0, $validShapeIndex$2 = 0, $vararg_buffer5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $vararg_buffer5 = sp;
 $0 = sp + 448|0;
 $1 = sp + 432|0;
 $shapes = sp + 352|0;
 $2 = sp + 348|0;
 $3 = sp + 504|0;
 $it = sp + 296|0;
 $g = sp + 288|0;
 $temp = sp + 256|0;
 $g1 = sp + 488|0;
 $temp3 = sp + 112|0;
 $g4 = sp + 100|0;
 $temp6 = sp + 36|0;
 $g7 = sp + 64|0;
 $convMass = sp + 224|0;
 $convInertia = sp + 140|0;
 $convCoM = sp + 176|0;
 $4 = sp + 188|0;
 $5 = sp + 228|0;
 $6 = (($shapes) + 64|0);
 $7 = (($shapes) + 68|0);
 $8 = (($shapes) + 72|0);
 HEAP32[$8>>2] = 0;
 $9 = (($shapes) + 76|0);
 HEAP8[$6>>0] = 1;
 HEAP32[$7>>2] = $shapes;
 HEAP32[$9>>2] = 16;
 $10 = HEAP32[$body>>2]|0;
 $11 = (($10) + 104|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($body)|0);
 HEAP32[$2>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_7PxShapeENS0_15InlineAllocatorILj64ENS0_19ReflectionAllocatorIS3_EEEEE6resizeEjRKS3_($shapes,$13,$2);
 $14 = HEAP32[$body>>2]|0;
 $15 = (($14) + 108|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$7>>2]|0;
 $18 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiiii[$16 & 511]($body,$17,$18,0)|0);
 $19 = ($densities|0)!=(0|0);
 $densities$masses = $19 ? $densities : $masses;
 $currentMassOrDensity$0 = Math_fround(HEAPF32[$densities$masses>>2]);
 $20 = (HEAPF32[tempDoublePtr>>2]=$currentMassOrDensity$0,HEAP32[tempDoublePtr>>2]|0);
 $21 = $20 & 2139095040;
 $22 = ($21>>>0)<(2139095040);
 L1: do {
  if ($22) {
   $23 = HEAP32[$8>>2]|0;
   $24 = ($23|0)==(0);
   do {
    if ($24) {
     $$lcssa16127 = Math_fround(0.0);$$lcssa20126 = Math_fround(0.0);$$lcssa24125 = Math_fround(0.0);$653 = Math_fround(0.0);$655 = Math_fround(0.0);$657 = Math_fround(0.0);$659 = Math_fround(0.0);$661 = Math_fround(0.0);$663 = Math_fround(0.0);$665 = Math_fround(0.0);$667 = Math_fround(0.0);$669 = Math_fround(0.0);$674 = Math_fround(0.0);
    } else {
     $25 = (($g) + 4|0);
     $26 = (($it) + 48|0);
     $27 = (($it) + 4|0);
     $28 = (($it) + 8|0);
     $29 = (($it) + 12|0);
     $30 = (($it) + 16|0);
     $31 = (($it) + 20|0);
     $32 = (($it) + 24|0);
     $33 = (($it) + 28|0);
     $34 = (($it) + 32|0);
     $35 = (($it) + 36|0);
     $36 = (($it) + 40|0);
     $37 = (($it) + 44|0);
     $38 = (($temp) + 4|0);
     $39 = (($temp) + 8|0);
     $40 = (($temp) + 12|0);
     $41 = (($vararg_buffer5) + 4|0);
     $42 = (($vararg_buffer5) + 8|0);
     $43 = (($vararg_buffer5) + 12|0);
     $44 = (($vararg_buffer5) + 16|0);
     $45 = (($vararg_buffer5) + 20|0);
     $46 = (($vararg_buffer5) + 24|0);
     $47 = (($vararg_buffer5) + 28|0);
     $48 = (($vararg_buffer5) + 32|0);
     $49 = (($temp) + 16|0);
     $50 = (($g1) + 4|0);
     $51 = (($g1) + 8|0);
     $52 = (($g1) + 12|0);
     $53 = (($temp3) + 4|0);
     $54 = (($temp3) + 8|0);
     $55 = (($temp3) + 12|0);
     $56 = (($vararg_buffer5) + 4|0);
     $57 = (($vararg_buffer5) + 8|0);
     $58 = (($vararg_buffer5) + 12|0);
     $59 = (($vararg_buffer5) + 16|0);
     $60 = (($vararg_buffer5) + 20|0);
     $61 = (($vararg_buffer5) + 24|0);
     $62 = (($vararg_buffer5) + 28|0);
     $63 = (($vararg_buffer5) + 32|0);
     $64 = (($temp3) + 16|0);
     $65 = (($g4) + 4|0);
     $66 = (($g4) + 8|0);
     $67 = (($temp6) + 4|0);
     $68 = (($temp6) + 8|0);
     $69 = (($temp6) + 12|0);
     $70 = (($vararg_buffer5) + 4|0);
     $71 = (($vararg_buffer5) + 8|0);
     $72 = (($vararg_buffer5) + 12|0);
     $73 = (($vararg_buffer5) + 16|0);
     $74 = (($vararg_buffer5) + 20|0);
     $75 = (($vararg_buffer5) + 24|0);
     $76 = (($vararg_buffer5) + 28|0);
     $77 = (($vararg_buffer5) + 32|0);
     $78 = (($temp6) + 16|0);
     $79 = (($g7) + 4|0);
     $80 = (($g7) + 8|0);
     $81 = (($g7) + 12|0);
     $82 = (($g7) + 16|0);
     $83 = (($g7) + 20|0);
     $84 = (($g7) + 24|0);
     $85 = (($g7) + 28|0);
     $86 = (($g7) + 32|0);
     $87 = (($g7) + 4|0);
     $88 = (($convInertia) + 4|0);
     $89 = (($convInertia) + 8|0);
     $90 = (($convInertia) + 12|0);
     $91 = (($convInertia) + 16|0);
     $92 = (($convInertia) + 20|0);
     $93 = (($convInertia) + 24|0);
     $94 = (($convInertia) + 28|0);
     $95 = (($convInertia) + 32|0);
     $96 = (($convCoM) + 4|0);
     $97 = (($convCoM) + 8|0);
     $98 = (($5) + 4|0);
     $99 = (($5) + 8|0);
     $100 = (($5) + 12|0);
     $101 = (($vararg_buffer5) + 4|0);
     $102 = (($vararg_buffer5) + 8|0);
     $103 = (($vararg_buffer5) + 12|0);
     $104 = (($vararg_buffer5) + 16|0);
     $105 = (($vararg_buffer5) + 20|0);
     $106 = (($vararg_buffer5) + 24|0);
     $107 = (($vararg_buffer5) + 28|0);
     $108 = (($vararg_buffer5) + 32|0);
     $109 = (($5) + 16|0);
     $110 = (($g7) + 16|0);
     $111 = (($vararg_buffer5) + 12|0);
     $112 = (($111) + 4|0);
     $113 = (($vararg_buffer5) + 24|0);
     $114 = (($113) + 8|0);
     $115 = (($vararg_buffer5) + 4|0);
     $116 = (($vararg_buffer5) + 8|0);
     $117 = (($111) + 8|0);
     $118 = (($0) + 4|0);
     $119 = (($0) + 8|0);
     $120 = (($0) + 12|0);
     $121 = (($0) + 16|0);
     $122 = (($0) + 20|0);
     $123 = (($0) + 24|0);
     $124 = (($0) + 28|0);
     $125 = (($0) + 32|0);
     $126 = (($1) + 4|0);
     $127 = (($1) + 8|0);
     $128 = (($1) + 12|0);
     $129 = (($4) + 4|0);
     $130 = (($4) + 8|0);
     $131 = (($4) + 12|0);
     $132 = (($4) + 16|0);
     $133 = (($4) + 20|0);
     $134 = (($4) + 24|0);
     $135 = (($4) + 28|0);
     $136 = (($4) + 32|0);
     $578 = Math_fround(0.0);$580 = Math_fround(0.0);$582 = Math_fround(0.0);$584 = Math_fround(0.0);$600 = Math_fround(0.0);$603 = Math_fround(0.0);$606 = Math_fround(0.0);$609 = Math_fround(0.0);$612 = Math_fround(0.0);$615 = Math_fround(0.0);$618 = Math_fround(0.0);$621 = Math_fround(0.0);$624 = Math_fround(0.0);$currentMassOrDensity$172 = $currentMassOrDensity$0;$i$073 = 0;$validShapeIndex$071 = 0;
     while(1) {
      $138 = HEAP32[$7>>2]|0;
      $139 = (($138) + ($i$073<<2)|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = HEAP32[$140>>2]|0;
      $142 = (($141) + 136|0);
      $143 = HEAP32[$142>>2]|0;
      FUNCTION_TABLE_vii[$143 & 4095]($3,$140);
      $144 = HEAP8[$3>>0]|0;
      $145 = $144 & 1;
      $146 = ($145<<24>>24)!=(0);
      $brmerge = $146 | $includeNonSimShapes;
      if ($brmerge) {
       if ($multipleMassOrDensity) {
        $147 = ($validShapeIndex$071>>>0)<($densityOrMassCount>>>0);
        if (!($147)) {
         label = 10;
         break;
        }
        $148 = (($densities$masses) + ($validShapeIndex$071<<2)|0);
        $149 = Math_fround(HEAPF32[$148>>2]);
        $150 = (HEAPF32[tempDoublePtr>>2]=$149,HEAP32[tempDoublePtr>>2]|0);
        $151 = $150 & 2139095040;
        $152 = ($151>>>0)<(2139095040);
        if ($152) {
         $currentMassOrDensity$2 = $149;
        } else {
         label = 9;
         break;
        }
       } else {
        $currentMassOrDensity$2 = $currentMassOrDensity$172;
       }
       $155 = HEAP32[$7>>2]|0;
       $156 = (($155) + ($i$073<<2)|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = HEAP32[$157>>2]|0;
       $159 = (($158) + 24|0);
       $160 = HEAP32[$159>>2]|0;
       $161 = (FUNCTION_TABLE_ii[$160 & 4095]($157)|0);
       if ((($161|0) == 0)) {
        HEAP32[$g>>2] = 0;
        HEAPF32[$25>>2] = Math_fround(0.0);
        $162 = HEAP32[$7>>2]|0;
        $163 = (($162) + ($i$073<<2)|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = HEAP32[$164>>2]|0;
        $166 = (($165) + 40|0);
        $167 = HEAP32[$166>>2]|0;
        (FUNCTION_TABLE_iii[$167 & 4095]($164,$g)|0);
        $168 = HEAP32[$7>>2]|0;
        $169 = (($168) + ($i$073<<2)|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = HEAP32[$170>>2]|0;
        $172 = (($171) + 72|0);
        $173 = HEAP32[$172>>2]|0;
        FUNCTION_TABLE_vii[$173 & 4095]($temp,$170);
        $174 = Math_fround(HEAPF32[$25>>2]);
        $175 = Math_fround($174 * Math_fround(4.18879032135009765625));
        $176 = Math_fround($174 * $175);
        $177 = Math_fround($174 * $176);
        $178 = Math_fround($174 * $177);
        $179 = Math_fround($174 * $178);
        $180 = Math_fround($179 * Math_fround(0.400000005960464477539));
        HEAPF32[$26>>2] = $177;
        HEAPF32[$it>>2] = $180;
        HEAPF32[$27>>2] = Math_fround(0.0);
        HEAPF32[$28>>2] = Math_fround(0.0);
        HEAPF32[$29>>2] = Math_fround(0.0);
        HEAPF32[$30>>2] = $180;
        HEAPF32[$31>>2] = Math_fround(0.0);
        HEAPF32[$32>>2] = Math_fround(0.0);
        HEAPF32[$33>>2] = Math_fround(0.0);
        HEAPF32[$34>>2] = $180;
        HEAPF32[$35>>2] = Math_fround(0.0);
        HEAPF32[$36>>2] = Math_fround(0.0);
        HEAPF32[$37>>2] = Math_fround(0.0);
        $181 = Math_fround(HEAPF32[$temp>>2]);
        $182 = Math_fround(HEAPF32[$38>>2]);
        $183 = Math_fround(HEAPF32[$39>>2]);
        $184 = Math_fround(HEAPF32[$40>>2]);
        $185 = Math_fround($181 + $181);
        $186 = Math_fround($182 + $182);
        $187 = Math_fround($183 + $183);
        $188 = Math_fround($181 * $185);
        $189 = Math_fround($182 * $186);
        $190 = Math_fround($183 * $187);
        $191 = Math_fround($185 * $182);
        $192 = Math_fround($185 * $183);
        $193 = Math_fround($185 * $184);
        $194 = Math_fround($186 * $183);
        $195 = Math_fround($186 * $184);
        $196 = Math_fround($187 * $184);
        $197 = Math_fround(Math_fround(1.0) - $189);
        $198 = Math_fround($197 - $190);
        $199 = Math_fround($191 + $196);
        $200 = Math_fround($192 - $195);
        HEAPF32[$vararg_buffer5>>2] = $198;
        HEAPF32[$41>>2] = $199;
        HEAPF32[$42>>2] = $200;
        $201 = Math_fround($191 - $196);
        $202 = Math_fround(Math_fround(1.0) - $188);
        $203 = Math_fround($202 - $190);
        $204 = Math_fround($194 + $193);
        HEAPF32[$43>>2] = $201;
        HEAPF32[$44>>2] = $203;
        HEAPF32[$45>>2] = $204;
        $205 = Math_fround($192 + $195);
        $206 = Math_fround($194 - $193);
        $207 = Math_fround($202 - $189);
        HEAPF32[$46>>2] = $205;
        HEAPF32[$47>>2] = $206;
        HEAPF32[$48>>2] = $207;
        __ZN5physx3Ext21InertiaTensorComputer6rotateERKNS_7PxMat33E($it,$vararg_buffer5);
        __ZN5physx3Ext21InertiaTensorComputer9translateERKNS_6PxVec3E($it,$49);
       } else if ((($161|0) == 2)) {
        HEAP32[$g4>>2] = 2;
        HEAPF32[$65>>2] = Math_fround(0.0);
        HEAPF32[$66>>2] = Math_fround(0.0);
        $266 = HEAP32[$7>>2]|0;
        $267 = (($266) + ($i$073<<2)|0);
        $268 = HEAP32[$267>>2]|0;
        $269 = HEAP32[$268>>2]|0;
        $270 = (($269) + 44|0);
        $271 = HEAP32[$270>>2]|0;
        (FUNCTION_TABLE_iii[$271 & 4095]($268,$g4)|0);
        $272 = HEAP32[$7>>2]|0;
        $273 = (($272) + ($i$073<<2)|0);
        $274 = HEAP32[$273>>2]|0;
        $275 = HEAP32[$274>>2]|0;
        $276 = (($275) + 72|0);
        $277 = HEAP32[$276>>2]|0;
        FUNCTION_TABLE_vii[$277 & 4095]($temp6,$274);
        $278 = Math_fround(HEAPF32[$65>>2]);
        $279 = Math_fround(HEAPF32[$66>>2]);
        $280 = Math_fround($278 * Math_fround(4.18879032135009765625));
        $281 = Math_fround($278 * $280);
        $282 = Math_fround($278 * $281);
        $283 = Math_fround($278 * Math_fround(3.14159274101257324219));
        $284 = Math_fround($278 * $283);
        $285 = Math_fround($279 * Math_fround(2.0));
        $286 = Math_fround($284 * $285);
        $287 = Math_fround($282 + $286);
        $288 = Math_fround($278 * $278);
        $289 = Math_fround($278 * $288);
        $290 = Math_fround($289 * Math_fround(8.0));
        $291 = Math_fround($290 / Math_fround(15.0));
        $292 = Math_fround($278 * $279);
        $293 = Math_fround($278 * $292);
        $294 = Math_fround($291 + $293);
        $295 = Math_fround($284 * $294);
        $296 = Math_fround($293 * Math_fround(3.0));
        $297 = Math_fround($296 * Math_fround(0.5));
        $298 = Math_fround($291 + $297);
        $299 = Math_fround($279 * $279);
        $300 = Math_fround($278 * $299);
        $301 = Math_fround($300 * Math_fround(4.0));
        $302 = Math_fround($301 / Math_fround(3.0));
        $303 = Math_fround($302 + $298);
        $304 = Math_fround($279 * $299);
        $305 = Math_fround($304 * Math_fround(2.0));
        $306 = Math_fround($305 / Math_fround(3.0));
        $307 = Math_fround($306 + $303);
        $308 = Math_fround($284 * $307);
        HEAPF32[$26>>2] = $287;
        HEAPF32[$it>>2] = $295;
        HEAPF32[$27>>2] = Math_fround(0.0);
        HEAPF32[$28>>2] = Math_fround(0.0);
        HEAPF32[$29>>2] = Math_fround(0.0);
        HEAPF32[$30>>2] = $308;
        HEAPF32[$31>>2] = Math_fround(0.0);
        HEAPF32[$32>>2] = Math_fround(0.0);
        HEAPF32[$33>>2] = Math_fround(0.0);
        HEAPF32[$34>>2] = $308;
        HEAPF32[$35>>2] = Math_fround(0.0);
        HEAPF32[$36>>2] = Math_fround(0.0);
        HEAPF32[$37>>2] = Math_fround(0.0);
        $309 = Math_fround(HEAPF32[$temp6>>2]);
        $310 = Math_fround(HEAPF32[$67>>2]);
        $311 = Math_fround(HEAPF32[$68>>2]);
        $312 = Math_fround(HEAPF32[$69>>2]);
        $313 = Math_fround($309 + $309);
        $314 = Math_fround($310 + $310);
        $315 = Math_fround($311 + $311);
        $316 = Math_fround($309 * $313);
        $317 = Math_fround($310 * $314);
        $318 = Math_fround($311 * $315);
        $319 = Math_fround($313 * $310);
        $320 = Math_fround($313 * $311);
        $321 = Math_fround($313 * $312);
        $322 = Math_fround($314 * $311);
        $323 = Math_fround($314 * $312);
        $324 = Math_fround($315 * $312);
        $325 = Math_fround(Math_fround(1.0) - $317);
        $326 = Math_fround($325 - $318);
        $327 = Math_fround($319 + $324);
        $328 = Math_fround($320 - $323);
        HEAPF32[$vararg_buffer5>>2] = $326;
        HEAPF32[$70>>2] = $327;
        HEAPF32[$71>>2] = $328;
        $329 = Math_fround($319 - $324);
        $330 = Math_fround(Math_fround(1.0) - $316);
        $331 = Math_fround($330 - $318);
        $332 = Math_fround($322 + $321);
        HEAPF32[$72>>2] = $329;
        HEAPF32[$73>>2] = $331;
        HEAPF32[$74>>2] = $332;
        $333 = Math_fround($320 + $323);
        $334 = Math_fround($322 - $321);
        $335 = Math_fround($330 - $317);
        HEAPF32[$75>>2] = $333;
        HEAPF32[$76>>2] = $334;
        HEAPF32[$77>>2] = $335;
        __ZN5physx3Ext21InertiaTensorComputer6rotateERKNS_7PxMat33E($it,$vararg_buffer5);
        __ZN5physx3Ext21InertiaTensorComputer9translateERKNS_6PxVec3E($it,$78);
       } else if ((($161|0) == 3)) {
        HEAP32[$g1>>2] = 3;
        HEAPF32[$50>>2] = Math_fround(0.0);
        HEAPF32[$51>>2] = Math_fround(0.0);
        HEAPF32[$52>>2] = Math_fround(0.0);
        $208 = HEAP32[$7>>2]|0;
        $209 = (($208) + ($i$073<<2)|0);
        $210 = HEAP32[$209>>2]|0;
        $211 = HEAP32[$210>>2]|0;
        $212 = (($211) + 36|0);
        $213 = HEAP32[$212>>2]|0;
        (FUNCTION_TABLE_iii[$213 & 4095]($210,$g1)|0);
        $214 = HEAP32[$7>>2]|0;
        $215 = (($214) + ($i$073<<2)|0);
        $216 = HEAP32[$215>>2]|0;
        $217 = HEAP32[$216>>2]|0;
        $218 = (($217) + 72|0);
        $219 = HEAP32[$218>>2]|0;
        FUNCTION_TABLE_vii[$219 & 4095]($temp3,$216);
        $220 = Math_fround(HEAPF32[$50>>2]);
        $221 = $220 != Math_fround(0.0);
        $v$0$i$i$i$i = $221 ? $220 : Math_fround(1.0);
        $222 = Math_fround(HEAPF32[$51>>2]);
        $223 = $222 != Math_fround(0.0);
        if ($223) {
         $224 = Math_fround($222 * $v$0$i$i$i$i);
         $v$1$i$i$i$i = $224;
        } else {
         $v$1$i$i$i$i = $v$0$i$i$i$i;
        }
        $225 = Math_fround(HEAPF32[$52>>2]);
        $226 = $225 != Math_fround(0.0);
        if ($226) {
         $227 = Math_fround($v$1$i$i$i$i * $225);
         $v$2$i$i$i$i = $227;
        } else {
         $v$2$i$i$i$i = $v$1$i$i$i$i;
        }
        $228 = Math_fround($v$2$i$i$i$i * Math_fround(8.0));
        $229 = Math_fround($228 * Math_fround(0.333333343267440795898));
        $230 = Math_fround($220 * $220);
        $231 = Math_fround($222 * $222);
        $232 = Math_fround($225 * $225);
        $233 = Math_fround($231 + $232);
        $234 = Math_fround($230 + $232);
        $235 = Math_fround($230 + $231);
        $236 = Math_fround($233 * $229);
        $237 = Math_fround($234 * $229);
        $238 = Math_fround($235 * $229);
        HEAPF32[$26>>2] = $228;
        HEAPF32[$it>>2] = $236;
        HEAPF32[$27>>2] = Math_fround(0.0);
        HEAPF32[$28>>2] = Math_fround(0.0);
        HEAPF32[$29>>2] = Math_fround(0.0);
        HEAPF32[$30>>2] = $237;
        HEAPF32[$31>>2] = Math_fround(0.0);
        HEAPF32[$32>>2] = Math_fround(0.0);
        HEAPF32[$33>>2] = Math_fround(0.0);
        HEAPF32[$34>>2] = $238;
        HEAPF32[$35>>2] = Math_fround(0.0);
        HEAPF32[$36>>2] = Math_fround(0.0);
        HEAPF32[$37>>2] = Math_fround(0.0);
        $239 = Math_fround(HEAPF32[$temp3>>2]);
        $240 = Math_fround(HEAPF32[$53>>2]);
        $241 = Math_fround(HEAPF32[$54>>2]);
        $242 = Math_fround(HEAPF32[$55>>2]);
        $243 = Math_fround($239 + $239);
        $244 = Math_fround($240 + $240);
        $245 = Math_fround($241 + $241);
        $246 = Math_fround($239 * $243);
        $247 = Math_fround($240 * $244);
        $248 = Math_fround($241 * $245);
        $249 = Math_fround($243 * $240);
        $250 = Math_fround($243 * $241);
        $251 = Math_fround($243 * $242);
        $252 = Math_fround($244 * $241);
        $253 = Math_fround($244 * $242);
        $254 = Math_fround($245 * $242);
        $255 = Math_fround(Math_fround(1.0) - $247);
        $256 = Math_fround($255 - $248);
        $257 = Math_fround($249 + $254);
        $258 = Math_fround($250 - $253);
        HEAPF32[$vararg_buffer5>>2] = $256;
        HEAPF32[$56>>2] = $257;
        HEAPF32[$57>>2] = $258;
        $259 = Math_fround($249 - $254);
        $260 = Math_fround(Math_fround(1.0) - $246);
        $261 = Math_fround($260 - $248);
        $262 = Math_fround($252 + $251);
        HEAPF32[$58>>2] = $259;
        HEAPF32[$59>>2] = $261;
        HEAPF32[$60>>2] = $262;
        $263 = Math_fround($250 + $253);
        $264 = Math_fround($252 - $251);
        $265 = Math_fround($260 - $247);
        HEAPF32[$61>>2] = $263;
        HEAPF32[$62>>2] = $264;
        HEAPF32[$63>>2] = $265;
        __ZN5physx3Ext21InertiaTensorComputer6rotateERKNS_7PxMat33E($it,$vararg_buffer5);
        __ZN5physx3Ext21InertiaTensorComputer9translateERKNS_6PxVec3E($it,$64);
       } else if ((($161|0) == 4)) {
        HEAP32[$g7>>2] = 4;
        HEAPF32[$79>>2] = Math_fround(1.0);
        HEAPF32[$80>>2] = Math_fround(1.0);
        HEAPF32[$81>>2] = Math_fround(1.0);
        HEAPF32[$82>>2] = Math_fround(0.0);
        HEAPF32[$83>>2] = Math_fround(0.0);
        HEAPF32[$84>>2] = Math_fround(0.0);
        HEAPF32[$85>>2] = Math_fround(1.0);
        HEAP32[$86>>2] = 0;
        $336 = HEAP32[$7>>2]|0;
        $337 = (($336) + ($i$073<<2)|0);
        $338 = HEAP32[$337>>2]|0;
        $339 = HEAP32[$338>>2]|0;
        $340 = (($339) + 52|0);
        $341 = HEAP32[$340>>2]|0;
        (FUNCTION_TABLE_iii[$341 & 4095]($338,$g7)|0);
        $342 = HEAP32[$86>>2]|0;
        $343 = HEAP32[$342>>2]|0;
        $344 = (($343) + 48|0);
        $345 = HEAP32[$344>>2]|0;
        FUNCTION_TABLE_viiii[$345 & 511]($342,$convMass,$convInertia,$convCoM);
        $346 = Math_fround(HEAPF32[$87>>2]);
        $347 = $346 == Math_fround(1.0);
        $348 = Math_fround(HEAPF32[$80>>2]);
        $349 = $348 == Math_fround(1.0);
        $or$cond128 = $347 & $349;
        if ($or$cond128) {
         $350 = Math_fround(HEAPF32[$81>>2]);
         $351 = $350 == Math_fround(1.0);
         if ($351) {
          $$pre113 = Math_fround(HEAPF32[$convInertia>>2]);
          $$pre114 = Math_fround(HEAPF32[$88>>2]);
          $$pre115 = Math_fround(HEAPF32[$89>>2]);
          $$pre116 = Math_fround(HEAPF32[$90>>2]);
          $$pre117 = Math_fround(HEAPF32[$91>>2]);
          $$pre118 = Math_fround(HEAPF32[$92>>2]);
          $$pre119 = Math_fround(HEAPF32[$93>>2]);
          $$pre120 = Math_fround(HEAPF32[$94>>2]);
          $$pre121 = Math_fround(HEAPF32[$95>>2]);
          $493 = $$pre113;$494 = $$pre114;$495 = $$pre115;$496 = $$pre116;$497 = $$pre117;$498 = $$pre118;$499 = $$pre119;$500 = $$pre120;$501 = $$pre121;
         } else {
          label = 22;
         }
        } else {
         label = 22;
        }
        if ((label|0) == 22) {
         label = 0;
         $352 = Math_fround($346 * $348);
         $353 = Math_fround(HEAPF32[$81>>2]);
         $354 = Math_fround($352 * $353);
         $355 = Math_fround(HEAPF32[$convMass>>2]);
         $356 = Math_fround($355 * $354);
         HEAPF32[$convMass>>2] = $356;
         $357 = Math_fround(HEAPF32[$convCoM>>2]);
         $358 = Math_fround($357 * Math_fround(2.0));
         $359 = Math_fround(HEAPF32[$96>>2]);
         $360 = Math_fround($359 * Math_fround(2.0));
         $361 = Math_fround(HEAPF32[$97>>2]);
         $362 = Math_fround($361 * Math_fround(2.0));
         $363 = Math_fround(HEAPF32[$85>>2]);
         $364 = Math_fround($363 * $363);
         $365 = Math_fround($364 + Math_fround(-0.5));
         $366 = Math_fround(HEAPF32[$110>>2]);
         $367 = Math_fround($358 * $366);
         $368 = Math_fround(HEAPF32[$83>>2]);
         $369 = Math_fround($360 * $368);
         $370 = Math_fround($367 + $369);
         $371 = Math_fround(HEAPF32[$84>>2]);
         $372 = Math_fround($362 * $371);
         $373 = Math_fround($370 + $372);
         $374 = Math_fround($358 * $365);
         $375 = Math_fround($362 * $368);
         $376 = Math_fround($360 * $371);
         $377 = Math_fround($375 - $376);
         $378 = Math_fround($363 * $377);
         $379 = Math_fround($374 + $378);
         $380 = Math_fround($366 * $373);
         $381 = Math_fround($380 + $379);
         $382 = Math_fround($360 * $365);
         $383 = Math_fround($358 * $371);
         $384 = Math_fround($362 * $366);
         $385 = Math_fround($383 - $384);
         $386 = Math_fround($363 * $385);
         $387 = Math_fround($382 + $386);
         $388 = Math_fround($368 * $373);
         $389 = Math_fround($388 + $387);
         $390 = Math_fround($362 * $365);
         $391 = Math_fround($360 * $366);
         $392 = Math_fround($358 * $368);
         $393 = Math_fround($391 - $392);
         $394 = Math_fround($363 * $393);
         $395 = Math_fround($390 + $394);
         $396 = Math_fround($371 * $373);
         $397 = Math_fround($395 + $396);
         $398 = Math_fround($346 * $381);
         $399 = Math_fround($348 * $389);
         $400 = Math_fround($353 * $397);
         $401 = Math_fround($398 * Math_fround(2.0));
         $402 = Math_fround($399 * Math_fround(2.0));
         $403 = Math_fround($400 * Math_fround(2.0));
         $404 = Math_fround($366 * $401);
         $405 = Math_fround($368 * $402);
         $406 = Math_fround($404 + $405);
         $407 = Math_fround($371 * $403);
         $408 = Math_fround($407 + $406);
         $409 = Math_fround($365 * $401);
         $410 = Math_fround($368 * $403);
         $411 = Math_fround($371 * $402);
         $412 = Math_fround($410 - $411);
         $413 = Math_fround($363 * $412);
         $414 = Math_fround($409 - $413);
         $415 = Math_fround($366 * $408);
         $416 = Math_fround($415 + $414);
         $417 = Math_fround($365 * $402);
         $418 = Math_fround($371 * $401);
         $419 = Math_fround($366 * $403);
         $420 = Math_fround($418 - $419);
         $421 = Math_fround($363 * $420);
         $422 = Math_fround($417 - $421);
         $423 = Math_fround($368 * $408);
         $424 = Math_fround($423 + $422);
         $425 = Math_fround($365 * $403);
         $426 = Math_fround($366 * $402);
         $427 = Math_fround($368 * $401);
         $428 = Math_fround($426 - $427);
         $429 = Math_fround($363 * $428);
         $430 = Math_fround($425 - $429);
         $431 = Math_fround($371 * $408);
         $432 = Math_fround($430 + $431);
         HEAPF32[$convCoM>>2] = $416;
         HEAPF32[$96>>2] = $424;
         HEAPF32[$97>>2] = $432;
         __ZN5physx3Ext9MassProps13rotateInertiaERKNS_7PxMat33ERKNS_6PxQuatE($vararg_buffer5,$convInertia,$110);
         $433 = Math_fround(HEAPF32[$vararg_buffer5>>2]);
         $434 = Math_fround(HEAPF32[$112>>2]);
         $435 = Math_fround(HEAPF32[$114>>2]);
         $436 = Math_fround($433 * Math_fround(0.5));
         $437 = Math_fround($434 * Math_fround(0.5));
         $438 = Math_fround($436 + $437);
         $439 = Math_fround($435 * Math_fround(0.5));
         $440 = Math_fround($438 + $439);
         $441 = Math_fround($440 - $433);
         $442 = Math_fround($440 - $434);
         $443 = Math_fround($440 - $435);
         $444 = Math_fround(HEAPF32[$87>>2]);
         $445 = Math_fround($444 * $441);
         $446 = Math_fround(HEAPF32[$80>>2]);
         $447 = Math_fround($446 * $442);
         $448 = Math_fround(HEAPF32[$81>>2]);
         $449 = Math_fround($443 * $448);
         $450 = Math_fround($444 * $445);
         $451 = Math_fround($446 * $447);
         $452 = Math_fround($448 * $449);
         $453 = Math_fround($451 + $452);
         $454 = Math_fround($452 + $450);
         $455 = Math_fround($450 + $451);
         $456 = Math_fround(HEAPF32[$115>>2]);
         $457 = Math_fround($444 * $456);
         $458 = Math_fround($446 * $457);
         $459 = Math_fround(HEAPF32[$116>>2]);
         $460 = Math_fround($444 * $459);
         $461 = Math_fround($448 * $460);
         $462 = Math_fround(HEAPF32[$117>>2]);
         $463 = Math_fround($446 * $462);
         $464 = Math_fround($448 * $463);
         $465 = Math_fround($444 * $446);
         $466 = Math_fround($465 * $448);
         $467 = Math_fround($466 * $453);
         $468 = Math_fround($466 * $458);
         $469 = Math_fround($466 * $461);
         $470 = Math_fround($466 * $454);
         $471 = Math_fround($466 * $464);
         $472 = Math_fround($466 * $455);
         HEAPF32[$0>>2] = $467;
         HEAPF32[$118>>2] = $468;
         HEAPF32[$119>>2] = $469;
         HEAPF32[$120>>2] = $468;
         HEAPF32[$121>>2] = $470;
         HEAPF32[$122>>2] = $471;
         HEAPF32[$123>>2] = $469;
         HEAPF32[$124>>2] = $471;
         HEAPF32[$125>>2] = $472;
         $473 = Math_fround(HEAPF32[$110>>2]);
         $474 = Math_fround(-$473);
         $475 = Math_fround(HEAPF32[$83>>2]);
         $476 = Math_fround(-$475);
         $477 = Math_fround(HEAPF32[$84>>2]);
         $478 = Math_fround(-$477);
         $479 = Math_fround(HEAPF32[$85>>2]);
         HEAPF32[$1>>2] = $474;
         HEAPF32[$126>>2] = $476;
         HEAPF32[$127>>2] = $478;
         HEAPF32[$128>>2] = $479;
         __ZN5physx3Ext9MassProps13rotateInertiaERKNS_7PxMat33ERKNS_6PxQuatE($4,$0,$1);
         $480 = Math_fround(HEAPF32[$4>>2]);
         HEAPF32[$convInertia>>2] = $480;
         $481 = Math_fround(HEAPF32[$129>>2]);
         HEAPF32[$88>>2] = $481;
         $482 = Math_fround(HEAPF32[$130>>2]);
         HEAPF32[$89>>2] = $482;
         $483 = Math_fround(HEAPF32[$131>>2]);
         HEAPF32[$90>>2] = $483;
         $484 = Math_fround(HEAPF32[$132>>2]);
         HEAPF32[$91>>2] = $484;
         $485 = Math_fround(HEAPF32[$133>>2]);
         HEAPF32[$92>>2] = $485;
         $486 = Math_fround(HEAPF32[$134>>2]);
         HEAPF32[$93>>2] = $486;
         $487 = Math_fround(HEAPF32[$135>>2]);
         HEAPF32[$94>>2] = $487;
         $488 = Math_fround(HEAPF32[$136>>2]);
         HEAPF32[$95>>2] = $488;
         $493 = $480;$494 = $481;$495 = $482;$496 = $483;$497 = $484;$498 = $485;$499 = $486;$500 = $487;$501 = $488;
        }
        $489 = Math_fround(HEAPF32[$convMass>>2]);
        $490 = Math_fround(HEAPF32[$convCoM>>2]);
        $491 = Math_fround(HEAPF32[$96>>2]);
        $492 = Math_fround(HEAPF32[$97>>2]);
        HEAPF32[$it>>2] = $493;
        HEAPF32[$27>>2] = $494;
        HEAPF32[$28>>2] = $495;
        HEAPF32[$29>>2] = $496;
        HEAPF32[$30>>2] = $497;
        HEAPF32[$31>>2] = $498;
        HEAPF32[$32>>2] = $499;
        HEAPF32[$33>>2] = $500;
        HEAPF32[$34>>2] = $501;
        HEAPF32[$35>>2] = $490;
        HEAPF32[$36>>2] = $491;
        HEAPF32[$37>>2] = $492;
        HEAPF32[$26>>2] = $489;
        $502 = HEAP32[$7>>2]|0;
        $503 = (($502) + ($i$073<<2)|0);
        $504 = HEAP32[$503>>2]|0;
        $505 = HEAP32[$504>>2]|0;
        $506 = (($505) + 72|0);
        $507 = HEAP32[$506>>2]|0;
        FUNCTION_TABLE_vii[$507 & 4095]($5,$504);
        $508 = Math_fround(HEAPF32[$5>>2]);
        $509 = Math_fround(HEAPF32[$98>>2]);
        $510 = Math_fround(HEAPF32[$99>>2]);
        $511 = Math_fround(HEAPF32[$100>>2]);
        $512 = Math_fround($508 + $508);
        $513 = Math_fround($509 + $509);
        $514 = Math_fround($510 + $510);
        $515 = Math_fround($508 * $512);
        $516 = Math_fround($509 * $513);
        $517 = Math_fround($510 * $514);
        $518 = Math_fround($512 * $509);
        $519 = Math_fround($512 * $510);
        $520 = Math_fround($512 * $511);
        $521 = Math_fround($513 * $510);
        $522 = Math_fround($513 * $511);
        $523 = Math_fround($514 * $511);
        $524 = Math_fround(Math_fround(1.0) - $516);
        $525 = Math_fround($524 - $517);
        $526 = Math_fround($518 + $523);
        $527 = Math_fround($519 - $522);
        HEAPF32[$vararg_buffer5>>2] = $525;
        HEAPF32[$101>>2] = $526;
        HEAPF32[$102>>2] = $527;
        $528 = Math_fround($518 - $523);
        $529 = Math_fround(Math_fround(1.0) - $515);
        $530 = Math_fround($529 - $517);
        $531 = Math_fround($521 + $520);
        HEAPF32[$103>>2] = $528;
        HEAPF32[$104>>2] = $530;
        HEAPF32[$105>>2] = $531;
        $532 = Math_fround($519 + $522);
        $533 = Math_fround($521 - $520);
        $534 = Math_fround($529 - $516);
        HEAPF32[$106>>2] = $532;
        HEAPF32[$107>>2] = $533;
        HEAPF32[$108>>2] = $534;
        __ZN5physx3Ext21InertiaTensorComputer6rotateERKNS_7PxMat33E($it,$vararg_buffer5);
        __ZN5physx3Ext21InertiaTensorComputer9translateERKNS_6PxVec3E($it,$109);
       } else {
        label = 30;
        break;
       }
       do {
        if ($19) {
         $535 = Math_fround(HEAPF32[$it>>2]);
         $536 = Math_fround($currentMassOrDensity$2 * $535);
         HEAPF32[$it>>2] = $536;
         $537 = Math_fround(HEAPF32[$27>>2]);
         $538 = Math_fround($currentMassOrDensity$2 * $537);
         HEAPF32[$27>>2] = $538;
         $539 = Math_fround(HEAPF32[$28>>2]);
         $540 = Math_fround($currentMassOrDensity$2 * $539);
         HEAPF32[$28>>2] = $540;
         $541 = Math_fround(HEAPF32[$29>>2]);
         $542 = Math_fround($currentMassOrDensity$2 * $541);
         HEAPF32[$29>>2] = $542;
         $543 = Math_fround(HEAPF32[$30>>2]);
         $544 = Math_fround($currentMassOrDensity$2 * $543);
         HEAPF32[$30>>2] = $544;
         $545 = Math_fround(HEAPF32[$31>>2]);
         $546 = Math_fround($currentMassOrDensity$2 * $545);
         HEAPF32[$31>>2] = $546;
         $547 = Math_fround(HEAPF32[$32>>2]);
         $548 = Math_fround($currentMassOrDensity$2 * $547);
         HEAPF32[$32>>2] = $548;
         $549 = Math_fround(HEAPF32[$33>>2]);
         $550 = Math_fround($currentMassOrDensity$2 * $549);
         HEAPF32[$33>>2] = $550;
         $551 = Math_fround(HEAPF32[$34>>2]);
         $552 = Math_fround($currentMassOrDensity$2 * $551);
         HEAPF32[$34>>2] = $552;
         $553 = Math_fround(HEAPF32[$26>>2]);
         $554 = Math_fround($currentMassOrDensity$2 * $553);
         HEAPF32[$26>>2] = $554;
         $577 = $554;$599 = $536;$602 = $538;$605 = $540;$608 = $542;$611 = $544;$614 = $546;$617 = $548;$620 = $550;$623 = $552;
        } else {
         $555 = Math_fround(HEAPF32[$26>>2]);
         if ($multipleMassOrDensity) {
          $556 = Math_fround($currentMassOrDensity$2 / $555);
          $557 = Math_fround(HEAPF32[$it>>2]);
          $558 = Math_fround($556 * $557);
          HEAPF32[$it>>2] = $558;
          $559 = Math_fround(HEAPF32[$27>>2]);
          $560 = Math_fround($556 * $559);
          HEAPF32[$27>>2] = $560;
          $561 = Math_fround(HEAPF32[$28>>2]);
          $562 = Math_fround($556 * $561);
          HEAPF32[$28>>2] = $562;
          $563 = Math_fround(HEAPF32[$29>>2]);
          $564 = Math_fround($556 * $563);
          HEAPF32[$29>>2] = $564;
          $565 = Math_fround(HEAPF32[$30>>2]);
          $566 = Math_fround($556 * $565);
          HEAPF32[$30>>2] = $566;
          $567 = Math_fround(HEAPF32[$31>>2]);
          $568 = Math_fround($556 * $567);
          HEAPF32[$31>>2] = $568;
          $569 = Math_fround(HEAPF32[$32>>2]);
          $570 = Math_fround($556 * $569);
          HEAPF32[$32>>2] = $570;
          $571 = Math_fround(HEAPF32[$33>>2]);
          $572 = Math_fround($556 * $571);
          HEAPF32[$33>>2] = $572;
          $573 = Math_fround(HEAPF32[$34>>2]);
          $574 = Math_fround($556 * $573);
          HEAPF32[$34>>2] = $574;
          $575 = Math_fround($556 * $555);
          HEAPF32[$26>>2] = $575;
          $577 = $575;$599 = $558;$602 = $560;$605 = $562;$608 = $564;$611 = $566;$614 = $568;$617 = $570;$620 = $572;$623 = $574;
          break;
         } else {
          $$pre104 = Math_fround(HEAPF32[$it>>2]);
          $$pre105 = Math_fround(HEAPF32[$27>>2]);
          $$pre106 = Math_fround(HEAPF32[$28>>2]);
          $$pre107 = Math_fround(HEAPF32[$29>>2]);
          $$pre108 = Math_fround(HEAPF32[$30>>2]);
          $$pre109 = Math_fround(HEAPF32[$31>>2]);
          $$pre110 = Math_fround(HEAPF32[$32>>2]);
          $$pre111 = Math_fround(HEAPF32[$33>>2]);
          $$pre112 = Math_fround(HEAPF32[$34>>2]);
          $577 = $555;$599 = $$pre104;$602 = $$pre105;$605 = $$pre106;$608 = $$pre107;$611 = $$pre108;$614 = $$pre109;$617 = $$pre110;$620 = $$pre111;$623 = $$pre112;
          break;
         }
        }
       } while(0);
       $576 = Math_fround($578 + $577);
       $579 = Math_fround($578 * $580);
       $581 = Math_fround($578 * $582);
       $583 = Math_fround($578 * $584);
       $585 = Math_fround(HEAPF32[$35>>2]);
       $586 = Math_fround($577 * $585);
       $587 = Math_fround(HEAPF32[$36>>2]);
       $588 = Math_fround($577 * $587);
       $589 = Math_fround(HEAPF32[$37>>2]);
       $590 = Math_fround($577 * $589);
       $591 = Math_fround($579 + $586);
       $592 = Math_fround($581 + $588);
       $593 = Math_fround($583 + $590);
       $594 = Math_fround(Math_fround(1.0) / $576);
       $595 = Math_fround($591 * $594);
       $596 = Math_fround($594 * $592);
       $597 = Math_fround($594 * $593);
       $598 = Math_fround($600 + $599);
       $601 = Math_fround($603 + $602);
       $604 = Math_fround($606 + $605);
       $607 = Math_fround($609 + $608);
       $610 = Math_fround($612 + $611);
       $613 = Math_fround($615 + $614);
       $616 = Math_fround($618 + $617);
       $619 = Math_fround($621 + $620);
       $622 = Math_fround($624 + $623);
       $625 = (($validShapeIndex$071) + 1)|0;
       $633 = $576;$635 = $598;$637 = $601;$639 = $604;$641 = $607;$643 = $610;$645 = $613;$647 = $616;$649 = $619;$651 = $622;$686 = $597;$687 = $596;$688 = $595;$currentMassOrDensity$3 = $currentMassOrDensity$2;$validShapeIndex$2 = $625;
      } else {
       $633 = $578;$635 = $600;$637 = $603;$639 = $606;$641 = $609;$643 = $612;$645 = $615;$647 = $618;$649 = $621;$651 = $624;$686 = $584;$687 = $582;$688 = $580;$currentMassOrDensity$3 = $currentMassOrDensity$172;$validShapeIndex$2 = $validShapeIndex$071;
      }
      $627 = (($i$073) + 1)|0;
      $628 = HEAP32[$8>>2]|0;
      $629 = ($627>>>0)<($628>>>0);
      if ($629) {
       $578 = $633;$580 = $688;$582 = $687;$584 = $686;$600 = $635;$603 = $637;$606 = $639;$609 = $641;$612 = $643;$615 = $645;$618 = $647;$621 = $649;$624 = $651;$currentMassOrDensity$172 = $currentMassOrDensity$3;$i$073 = $627;$validShapeIndex$071 = $validShapeIndex$2;
      } else {
       label = 32;
       break;
      }
     }
     if ((label|0) == 9) {
      $153 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
      __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($153,4,412760,148,413264,$vararg_buffer5);
      $$3 = 0;
      break L1;
     }
     else if ((label|0) == 10) {
      $154 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
      __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($154,4,412760,155,413336,$vararg_buffer5);
      $$3 = 0;
      break L1;
     }
     else if ((label|0) == 30) {
      $626 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
      __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($626,4,412760,234,413432,$vararg_buffer5);
      $$3 = 0;
      break L1;
     }
     else if ((label|0) == 32) {
      $630 = ($validShapeIndex$2|0)==(0);
      $631 = ($masses|0)==(0|0);
      $or$cond = $630 | $631;
      $brmerge2 = $or$cond | $multipleMassOrDensity;
      if ($brmerge2) {
       $$lcssa16127 = $686;$$lcssa20126 = $687;$$lcssa24125 = $688;$653 = $635;$655 = $637;$657 = $639;$659 = $641;$661 = $643;$663 = $645;$665 = $647;$667 = $649;$669 = $651;$674 = $633;
       break;
      }
      $632 = Math_fround($currentMassOrDensity$3 / $633);
      $634 = Math_fround($635 * $632);
      $636 = Math_fround($637 * $632);
      $638 = Math_fround($639 * $632);
      $640 = Math_fround($641 * $632);
      $642 = Math_fround($643 * $632);
      $644 = Math_fround($645 * $632);
      $646 = Math_fround($647 * $632);
      $648 = Math_fround($649 * $632);
      $650 = Math_fround($651 * $632);
      $652 = Math_fround($633 * $632);
      $$lcssa16127 = $686;$$lcssa20126 = $687;$$lcssa24125 = $688;$653 = $634;$655 = $636;$657 = $638;$659 = $640;$661 = $642;$663 = $644;$665 = $646;$667 = $648;$669 = $650;$674 = $652;
      break;
     }
    }
   } while(0);
   HEAPF32[$computer>>2] = $653;
   $654 = (($computer) + 4|0);
   HEAPF32[$654>>2] = $655;
   $656 = (($computer) + 8|0);
   HEAPF32[$656>>2] = $657;
   $658 = (($computer) + 12|0);
   HEAPF32[$658>>2] = $659;
   $660 = (($computer) + 16|0);
   HEAPF32[$660>>2] = $661;
   $662 = (($computer) + 20|0);
   HEAPF32[$662>>2] = $663;
   $664 = (($computer) + 24|0);
   HEAPF32[$664>>2] = $665;
   $666 = (($computer) + 28|0);
   HEAPF32[$666>>2] = $667;
   $668 = (($computer) + 32|0);
   HEAPF32[$668>>2] = $669;
   $670 = (($computer) + 36|0);
   HEAPF32[$670>>2] = $$lcssa24125;
   $671 = (($computer) + 40|0);
   HEAPF32[$671>>2] = $$lcssa20126;
   $672 = (($computer) + 44|0);
   HEAPF32[$672>>2] = $$lcssa16127;
   $673 = (($computer) + 48|0);
   HEAPF32[$673>>2] = $674;
   $$3 = 1;
  } else {
   $137 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($137,4,412760,130,413264,$vararg_buffer5);
   $$3 = 0;
  }
 } while(0);
 $675 = HEAP32[$9>>2]|0;
 $676 = $675 & 2147483647;
 $677 = ($676|0)!=(0);
 $678 = ($675|0)>(-1);
 $or$cond$i$i$i = $677 & $678;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return ($$3|0);
 }
 $679 = HEAP32[$7>>2]|0;
 $680 = ($shapes|0)==($679|0);
 if ($680) {
  HEAP8[$6>>0] = 0;
  STACKTOP = sp;return ($$3|0);
 }
 $681 = ($679|0)==(0|0);
 if ($681) {
  STACKTOP = sp;return ($$3|0);
 }
 $682 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $683 = HEAP32[$682>>2]|0;
 $684 = (($683) + 12|0);
 $685 = HEAP32[$684>>2]|0;
 FUNCTION_TABLE_vii[$685 & 4095]($682,$679);
 STACKTOP = sp;return ($$3|0);
}
function __ZL25computeMassAndDiagInertiaRN5physx3Ext21InertiaTensorComputerERNS_6PxVec3ERNS_6PxQuatERfS4_bRKNS_11PxRigidBodyEPKc($inertiaComp,$diagTensor,$orient,$massOut,$coM,$lockCOM,$body,$errorStr) {
 $inertiaComp = $inertiaComp|0;
 $diagTensor = $diagTensor|0;
 $orient = $orient|0;
 $massOut = $massOut|0;
 $coM = $coM|0;
 $lockCOM = $lockCOM|0;
 $body = $body|0;
 $errorStr = $errorStr|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0;
 var $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $bounds = 0, $or$cond = 0, $pose = 0;
 var $v$0$i$i$i = Math_fround(0), $v$1$i$i$i = Math_fround(0), $v$2$i$i$i = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $vararg_buffer = sp;
 $0 = sp + 172|0;
 $1 = sp + 12|0;
 $2 = sp + 24|0;
 $bounds = sp + 64|0;
 $pose = sp + 88|0;
 $3 = sp + 120|0;
 $4 = sp + 144|0;
 if ($lockCOM) {
  $5 = Math_fround(HEAPF32[$coM>>2]);
  $6 = Math_fround(-$5);
  $7 = (($coM) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround(-$8);
  $10 = (($coM) + 8|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround(-$11);
  HEAPF32[$0>>2] = $6;
  $13 = (($0) + 4|0);
  HEAPF32[$13>>2] = $9;
  $14 = (($0) + 8|0);
  HEAPF32[$14>>2] = $12;
  __ZN5physx3Ext21InertiaTensorComputer9translateERKNS_6PxVec3E($inertiaComp,$0);
 } else {
  $15 = (($inertiaComp) + 36|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($inertiaComp) + 40|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($inertiaComp) + 44|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$coM>>2] = $16;
  $21 = (($coM) + 4|0);
  HEAPF32[$21>>2] = $18;
  $22 = (($coM) + 8|0);
  HEAPF32[$22>>2] = $20;
  $23 = Math_fround(HEAPF32[$15>>2]);
  $24 = Math_fround(-$23);
  $25 = Math_fround(HEAPF32[$17>>2]);
  $26 = Math_fround(-$25);
  $27 = Math_fround(HEAPF32[$19>>2]);
  $28 = Math_fround(-$27);
  HEAPF32[$vararg_buffer>>2] = $24;
  $29 = (($vararg_buffer) + 4|0);
  HEAPF32[$29>>2] = $26;
  $30 = (($vararg_buffer) + 8|0);
  HEAPF32[$30>>2] = $28;
  __ZN5physx3Ext21InertiaTensorComputer9translateERKNS_6PxVec3E($inertiaComp,$vararg_buffer);
 }
 $31 = (($inertiaComp) + 48|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$massOut>>2] = $32;
 $33 = Math_fround(HEAPF32[$inertiaComp>>2]);
 HEAPF32[$2>>2] = $33;
 $34 = (($2) + 4|0);
 $35 = (($inertiaComp) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 $37 = (($2) + 8|0);
 $38 = (($inertiaComp) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$37>>2] = $39;
 $40 = (($2) + 12|0);
 $41 = (($inertiaComp) + 12|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$40>>2] = $42;
 $43 = (($2) + 16|0);
 $44 = (($inertiaComp) + 16|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 HEAPF32[$43>>2] = $45;
 $46 = (($2) + 20|0);
 $47 = (($inertiaComp) + 20|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$46>>2] = $48;
 $49 = (($2) + 24|0);
 $50 = (($inertiaComp) + 24|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$49>>2] = $51;
 $52 = (($2) + 28|0);
 $53 = (($inertiaComp) + 28|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 HEAPF32[$52>>2] = $54;
 $55 = (($2) + 32|0);
 $56 = (($inertiaComp) + 32|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 HEAPF32[$55>>2] = $57;
 __ZN5physx13PxDiagonalizeERKNS_7PxMat33ERNS_6PxQuatE($1,$2,$orient);
 $58 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$diagTensor>>2] = $58;
 $59 = (($1) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($diagTensor) + 4|0);
 HEAPF32[$61>>2] = $60;
 $62 = (($1) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($diagTensor) + 8|0);
 HEAPF32[$64>>2] = $63;
 $65 = $58 > Math_fround(0.0);
 if ($65) {
  $66 = $60 > Math_fround(0.0);
  $67 = $63 > Math_fround(0.0);
  $or$cond = $66 & $67;
  if ($or$cond) {
   STACKTOP = sp;return;
  }
 }
 $68 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 HEAP32[$vararg_buffer>>2] = $errorStr;
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($68,2,412760,86,413128,$vararg_buffer);
 $69 = HEAP32[$body>>2]|0;
 $70 = (($69) + 40|0);
 $71 = HEAP32[$70>>2]|0;
 FUNCTION_TABLE_viif[$71 & 63]($bounds,$body,Math_fround(1.00999999046325683594));
 $72 = HEAP32[$body>>2]|0;
 $73 = (($72) + 84|0);
 $74 = HEAP32[$73>>2]|0;
 FUNCTION_TABLE_vii[$74 & 4095]($pose,$body);
 $75 = (($pose) + 16|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($pose) + 20|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($pose) + 24|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($76 * Math_fround(-2.0));
 $82 = Math_fround($78 * Math_fround(-2.0));
 $83 = Math_fround($80 * Math_fround(-2.0));
 $84 = (($pose) + 12|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($85 * $85);
 $87 = Math_fround($86 + Math_fround(-0.5));
 $88 = Math_fround(HEAPF32[$pose>>2]);
 $89 = Math_fround($81 * $88);
 $90 = (($pose) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($82 * $91);
 $93 = Math_fround($89 + $92);
 $94 = (($pose) + 8|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($83 * $95);
 $97 = Math_fround($93 + $96);
 $98 = Math_fround($81 * $87);
 $99 = Math_fround($83 * $91);
 $100 = Math_fround($82 * $95);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($85 * $101);
 $103 = Math_fround($98 - $102);
 $104 = Math_fround($88 * $97);
 $105 = Math_fround($104 + $103);
 $106 = Math_fround($82 * $87);
 $107 = Math_fround($81 * $95);
 $108 = Math_fround($83 * $88);
 $109 = Math_fround($107 - $108);
 $110 = Math_fround($85 * $109);
 $111 = Math_fround($106 - $110);
 $112 = Math_fround($91 * $97);
 $113 = Math_fround($112 + $111);
 $114 = Math_fround($83 * $87);
 $115 = Math_fround($82 * $88);
 $116 = Math_fround($81 * $91);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($85 * $117);
 $119 = Math_fround($114 - $118);
 $120 = Math_fround($95 * $97);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround(-$88);
 $123 = Math_fround(-$91);
 $124 = Math_fround(-$95);
 HEAPF32[$4>>2] = $122;
 $125 = (($4) + 4|0);
 HEAPF32[$125>>2] = $123;
 $126 = (($4) + 8|0);
 HEAPF32[$126>>2] = $124;
 $127 = (($4) + 12|0);
 HEAPF32[$127>>2] = $85;
 $128 = (($4) + 16|0);
 HEAPF32[$128>>2] = $105;
 $129 = (($4) + 20|0);
 HEAPF32[$129>>2] = $113;
 $130 = (($4) + 24|0);
 HEAPF32[$130>>2] = $121;
 __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($3,$4,$bounds);
 $131 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$bounds>>2] = $131;
 $132 = (($3) + 4|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($bounds) + 4|0);
 HEAPF32[$134>>2] = $133;
 $135 = (($3) + 8|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($bounds) + 8|0);
 HEAPF32[$137>>2] = $136;
 $138 = (($3) + 12|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = (($bounds) + 12|0);
 HEAPF32[$140>>2] = $139;
 $141 = (($3) + 16|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($bounds) + 16|0);
 HEAPF32[$143>>2] = $142;
 $144 = (($3) + 20|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($bounds) + 20|0);
 HEAPF32[$146>>2] = $145;
 $147 = Math_fround($139 - $131);
 $148 = Math_fround($142 - $133);
 $149 = Math_fround($145 - $136);
 $150 = Math_fround($147 * Math_fround(0.5));
 $151 = Math_fround($148 * Math_fround(0.5));
 $152 = Math_fround($149 * Math_fround(0.5));
 $153 = $150 != Math_fround(0.0);
 $v$0$i$i$i = $153 ? $150 : Math_fround(1.0);
 $154 = $151 != Math_fround(0.0);
 if ($154) {
  $155 = Math_fround($151 * $v$0$i$i$i);
  $v$1$i$i$i = $155;
 } else {
  $v$1$i$i$i = $v$0$i$i$i;
 }
 $156 = $152 != Math_fround(0.0);
 if ($156) {
  $157 = Math_fround($152 * $v$1$i$i$i);
  $v$2$i$i$i = $157;
 } else {
  $v$2$i$i$i = $v$1$i$i$i;
 }
 $158 = Math_fround($v$2$i$i$i * Math_fround(8.0));
 $159 = Math_fround($158 * Math_fround(0.333333343267440795898));
 $160 = Math_fround($150 * $150);
 $161 = Math_fround($151 * $151);
 $162 = Math_fround($152 * $152);
 $163 = Math_fround($161 + $162);
 $164 = Math_fround($160 + $162);
 $165 = Math_fround($160 + $161);
 $166 = Math_fround($163 * $159);
 $167 = Math_fround($164 * $159);
 $168 = Math_fround($165 * $159);
 $169 = Math_fround(HEAPF32[$massOut>>2]);
 $170 = Math_fround($169 / $158);
 $171 = Math_fround($170 * $166);
 $172 = Math_fround($170 * $167);
 $173 = Math_fround($170 * $168);
 HEAPF32[$diagTensor>>2] = $171;
 HEAPF32[$61>>2] = $172;
 HEAPF32[$64>>2] = $173;
 HEAPF32[$orient>>2] = Math_fround(0.0);
 $174 = (($orient) + 4|0);
 HEAPF32[$174>>2] = Math_fround(0.0);
 $175 = (($orient) + 8|0);
 HEAPF32[$175>>2] = Math_fround(0.0);
 $176 = (($orient) + 12|0);
 HEAPF32[$176>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($agg$result,$transform,$bounds) {
 $agg$result = $agg$result|0;
 $transform = $transform|0;
 $bounds = $bounds|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$bounds>>2]);
 $1 = (($bounds) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 $4 = (($bounds) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($bounds) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 $9 = (($bounds) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($bounds) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = Math_fround($3 * Math_fround(0.5));
 $15 = Math_fround($8 * Math_fround(0.5));
 $16 = Math_fround($13 * Math_fround(0.5));
 $17 = Math_fround($14 * Math_fround(2.0));
 $18 = Math_fround($15 * Math_fround(2.0));
 $19 = Math_fround($16 * Math_fround(2.0));
 $20 = (($transform) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $21);
 $23 = Math_fround($22 + Math_fround(-0.5));
 $24 = Math_fround(HEAPF32[$transform>>2]);
 $25 = Math_fround($17 * $24);
 $26 = (($transform) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($18 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($transform) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($19 * $31);
 $33 = Math_fround($29 + $32);
 $34 = Math_fround($17 * $23);
 $35 = Math_fround($19 * $27);
 $36 = Math_fround($18 * $31);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($21 * $37);
 $39 = Math_fround($34 + $38);
 $40 = Math_fround($24 * $33);
 $41 = Math_fround($40 + $39);
 $42 = Math_fround($18 * $23);
 $43 = Math_fround($17 * $31);
 $44 = Math_fround($24 * $19);
 $45 = Math_fround($43 - $44);
 $46 = Math_fround($21 * $45);
 $47 = Math_fround($42 + $46);
 $48 = Math_fround($27 * $33);
 $49 = Math_fround($48 + $47);
 $50 = Math_fround($19 * $23);
 $51 = Math_fround($18 * $24);
 $52 = Math_fround($17 * $27);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($21 * $53);
 $55 = Math_fround($50 + $54);
 $56 = Math_fround($31 * $33);
 $57 = Math_fround($55 + $56);
 $58 = (($transform) + 16|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 + $41);
 $61 = (($transform) + 20|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 + $49);
 $64 = (($transform) + 24|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 + $57);
 $67 = Math_fround($24 + $24);
 $68 = Math_fround($27 + $27);
 $69 = Math_fround($31 + $31);
 $70 = Math_fround($24 * $67);
 $71 = Math_fround($27 * $68);
 $72 = Math_fround($31 * $69);
 $73 = Math_fround($67 * $27);
 $74 = Math_fround($67 * $31);
 $75 = Math_fround($67 * $21);
 $76 = Math_fround($68 * $31);
 $77 = Math_fround($68 * $21);
 $78 = Math_fround($69 * $21);
 $79 = Math_fround(Math_fround(1.0) - $71);
 $80 = Math_fround($79 - $72);
 $81 = Math_fround($73 + $78);
 $82 = Math_fround($74 - $77);
 $83 = Math_fround($73 - $78);
 $84 = Math_fround(Math_fround(1.0) - $70);
 $85 = Math_fround($84 - $72);
 $86 = Math_fround($76 + $75);
 $87 = Math_fround($74 + $77);
 $88 = Math_fround($76 - $75);
 $89 = Math_fround($84 - $71);
 $90 = Math_fround($2 - $0);
 $91 = Math_fround($7 - $5);
 $92 = Math_fround($12 - $10);
 $93 = Math_fround($90 * Math_fround(0.5));
 $94 = Math_fround($91 * Math_fround(0.5));
 $95 = Math_fround($92 * Math_fround(0.5));
 $96 = Math_fround($93 * $80);
 $97 = Math_fround($93 * $81);
 $98 = Math_fround($93 * $82);
 $99 = Math_fround($94 * $83);
 $100 = Math_fround($94 * $85);
 $101 = Math_fround($94 * $86);
 $102 = Math_fround($95 * $87);
 $103 = Math_fround($95 * $88);
 $104 = Math_fround($95 * $89);
 $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($96)))));
 $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($99)))));
 $105 = Math_fround($fabsf$i$i4$i + $fabsf$i$i5$i);
 $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($102)))));
 $106 = Math_fround($105 + $fabsf$i$i6$i);
 $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($97)))));
 $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($100)))));
 $107 = Math_fround($fabsf$i$i7$i + $fabsf$i$i8$i);
 $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($103)))));
 $108 = Math_fround($107 + $fabsf$i$i3$i);
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($98)))));
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($101)))));
 $109 = Math_fround($fabsf$i$i2$i + $fabsf$i$i1$i);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($104)))));
 $110 = Math_fround($109 + $fabsf$i$i$i);
 $111 = Math_fround($60 - $106);
 $112 = Math_fround($63 - $108);
 $113 = Math_fround($66 - $110);
 $114 = Math_fround($60 + $106);
 $115 = Math_fround($63 + $108);
 $116 = Math_fround($66 + $110);
 HEAPF32[$agg$result>>2] = $111;
 $117 = (($agg$result) + 4|0);
 HEAPF32[$117>>2] = $112;
 $118 = (($agg$result) + 8|0);
 HEAPF32[$118>>2] = $113;
 $119 = (($agg$result) + 12|0);
 HEAPF32[$119>>2] = $114;
 $120 = (($agg$result) + 16|0);
 HEAPF32[$120>>2] = $115;
 $121 = (($agg$result) + 20|0);
 HEAPF32[$121>>2] = $116;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_7PxShapeENS0_15InlineAllocatorILj64ENS0_19ReflectionAllocatorIS3_EEEEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_7PxShapeENS0_15InlineAllocatorILj64ENS0_19ReflectionAllocatorIS3_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($size<<2)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + ($7<<2)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $12;
  }
  $13 = (($$01$i) + 4|0);
  $14 = ($13>>>0)<($8>>>0);
  if ($14) {
   $$01$i = $13;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx3Ext21InertiaTensorComputer6rotateERKNS_7PxMat33E($this,$rot) {
 $this = $this|0;
 $rot = $rot|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0);
 var $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$this>>2]);
 $1 = Math_fround(HEAPF32[$rot>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($rot) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($0 * $4);
 $6 = (($rot) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($0 * $7);
 $9 = (($this) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($rot) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = (($rot) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($10 * $15);
 $17 = (($rot) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($10 * $18);
 $20 = Math_fround($2 + $13);
 $21 = Math_fround($5 + $16);
 $22 = Math_fround($8 + $19);
 $23 = (($this) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($rot) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($24 * $26);
 $28 = (($rot) + 28|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($24 * $29);
 $31 = (($rot) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 * $32);
 $34 = Math_fround($20 + $27);
 $35 = Math_fround($21 + $30);
 $36 = Math_fround($22 + $33);
 $37 = (($this) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($1 * $38);
 $40 = Math_fround($4 * $38);
 $41 = Math_fround($7 * $38);
 $42 = (($this) + 16|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($12 * $43);
 $45 = Math_fround($15 * $43);
 $46 = Math_fround($18 * $43);
 $47 = Math_fround($39 + $44);
 $48 = Math_fround($40 + $45);
 $49 = Math_fround($41 + $46);
 $50 = (($this) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($26 * $51);
 $53 = Math_fround($29 * $51);
 $54 = Math_fround($32 * $51);
 $55 = Math_fround($47 + $52);
 $56 = Math_fround($48 + $53);
 $57 = Math_fround($49 + $54);
 $58 = (($this) + 24|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($1 * $59);
 $61 = Math_fround($4 * $59);
 $62 = Math_fround($7 * $59);
 $63 = (($this) + 28|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($12 * $64);
 $66 = Math_fround($15 * $64);
 $67 = Math_fround($18 * $64);
 $68 = Math_fround($60 + $65);
 $69 = Math_fround($61 + $66);
 $70 = Math_fround($62 + $67);
 $71 = (($this) + 32|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($26 * $72);
 $74 = Math_fround($29 * $72);
 $75 = Math_fround($32 * $72);
 $76 = Math_fround($68 + $73);
 $77 = Math_fround($69 + $74);
 $78 = Math_fround($70 + $75);
 $79 = Math_fround($1 * $34);
 $80 = Math_fround($1 * $35);
 $81 = Math_fround($1 * $36);
 $82 = Math_fround($12 * $55);
 $83 = Math_fround($12 * $56);
 $84 = Math_fround($12 * $57);
 $85 = Math_fround($79 + $82);
 $86 = Math_fround($80 + $83);
 $87 = Math_fround($81 + $84);
 $88 = Math_fround($26 * $76);
 $89 = Math_fround($26 * $77);
 $90 = Math_fround($26 * $78);
 $91 = Math_fround($85 + $88);
 $92 = Math_fround($86 + $89);
 $93 = Math_fround($87 + $90);
 $94 = Math_fround($4 * $34);
 $95 = Math_fround($4 * $35);
 $96 = Math_fround($4 * $36);
 $97 = Math_fround($15 * $55);
 $98 = Math_fround($15 * $56);
 $99 = Math_fround($15 * $57);
 $100 = Math_fround($94 + $97);
 $101 = Math_fround($95 + $98);
 $102 = Math_fround($96 + $99);
 $103 = Math_fround($29 * $76);
 $104 = Math_fround($29 * $77);
 $105 = Math_fround($29 * $78);
 $106 = Math_fround($100 + $103);
 $107 = Math_fround($101 + $104);
 $108 = Math_fround($102 + $105);
 $109 = Math_fround($7 * $34);
 $110 = Math_fround($7 * $35);
 $111 = Math_fround($7 * $36);
 $112 = Math_fround($18 * $55);
 $113 = Math_fround($18 * $56);
 $114 = Math_fround($18 * $57);
 $115 = Math_fround($109 + $112);
 $116 = Math_fround($110 + $113);
 $117 = Math_fround($111 + $114);
 $118 = Math_fround($32 * $76);
 $119 = Math_fround($32 * $77);
 $120 = Math_fround($32 * $78);
 $121 = Math_fround($115 + $118);
 $122 = Math_fround($116 + $119);
 $123 = Math_fround($117 + $120);
 HEAPF32[$this>>2] = $91;
 HEAPF32[$9>>2] = $92;
 HEAPF32[$23>>2] = $93;
 HEAPF32[$37>>2] = $106;
 HEAPF32[$42>>2] = $107;
 HEAPF32[$50>>2] = $108;
 HEAPF32[$58>>2] = $121;
 HEAPF32[$63>>2] = $122;
 HEAPF32[$71>>2] = $123;
 $124 = (($this) + 36|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = Math_fround(HEAPF32[$rot>>2]);
 $127 = Math_fround($125 * $126);
 $128 = Math_fround(HEAPF32[$3>>2]);
 $129 = Math_fround($125 * $128);
 $130 = Math_fround(HEAPF32[$6>>2]);
 $131 = Math_fround($125 * $130);
 $132 = (($this) + 40|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround(HEAPF32[$11>>2]);
 $135 = Math_fround($133 * $134);
 $136 = Math_fround(HEAPF32[$14>>2]);
 $137 = Math_fround($133 * $136);
 $138 = Math_fround(HEAPF32[$17>>2]);
 $139 = Math_fround($133 * $138);
 $140 = Math_fround($127 + $135);
 $141 = Math_fround($129 + $137);
 $142 = Math_fround($131 + $139);
 $143 = (($this) + 44|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround(HEAPF32[$25>>2]);
 $146 = Math_fround($144 * $145);
 $147 = Math_fround(HEAPF32[$28>>2]);
 $148 = Math_fround($144 * $147);
 $149 = Math_fround(HEAPF32[$31>>2]);
 $150 = Math_fround($144 * $149);
 $151 = Math_fround($140 + $146);
 $152 = Math_fround($141 + $148);
 $153 = Math_fround($142 + $150);
 HEAPF32[$124>>2] = $151;
 HEAPF32[$132>>2] = $152;
 HEAPF32[$143>>2] = $153;
 STACKTOP = sp;return;
}
function __ZN5physx3Ext9MassProps13rotateInertiaERKNS_7PxMat33ERKNS_6PxQuatE($agg$result,$inertia,$q) {
 $agg$result = $agg$result|0;
 $inertia = $inertia|0;
 $q = $q|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0);
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$q>>2]);
 $1 = (($q) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($q) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($q) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 + $0);
 $8 = Math_fround($2 + $2);
 $9 = Math_fround($4 + $4);
 $10 = Math_fround($0 * $7);
 $11 = Math_fround($2 * $8);
 $12 = Math_fround($4 * $9);
 $13 = Math_fround($7 * $2);
 $14 = Math_fround($7 * $4);
 $15 = Math_fround($7 * $6);
 $16 = Math_fround($8 * $4);
 $17 = Math_fround($8 * $6);
 $18 = Math_fround($9 * $6);
 $19 = Math_fround(Math_fround(1.0) - $11);
 $20 = Math_fround($19 - $12);
 $21 = Math_fround($13 + $18);
 $22 = Math_fround($14 - $17);
 $23 = Math_fround($13 - $18);
 $24 = Math_fround(Math_fround(1.0) - $10);
 $25 = Math_fround($24 - $12);
 $26 = Math_fround($16 + $15);
 $27 = Math_fround($14 + $17);
 $28 = Math_fround($16 - $15);
 $29 = Math_fround($24 - $11);
 $30 = Math_fround(HEAPF32[$inertia>>2]);
 $31 = Math_fround($30 * $20);
 $32 = Math_fround($30 * $21);
 $33 = Math_fround($30 * $22);
 $34 = (($inertia) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * $23);
 $37 = Math_fround($35 * $25);
 $38 = Math_fround($35 * $26);
 $39 = Math_fround($31 + $36);
 $40 = Math_fround($32 + $37);
 $41 = Math_fround($33 + $38);
 $42 = (($inertia) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($27 * $43);
 $45 = Math_fround($28 * $43);
 $46 = Math_fround($29 * $43);
 $47 = Math_fround($39 + $44);
 $48 = Math_fround($40 + $45);
 $49 = Math_fround($41 + $46);
 $50 = (($inertia) + 12|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($20 * $51);
 $53 = Math_fround($21 * $51);
 $54 = Math_fround($22 * $51);
 $55 = (($inertia) + 16|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($23 * $56);
 $58 = Math_fround($25 * $56);
 $59 = Math_fround($26 * $56);
 $60 = Math_fround($52 + $57);
 $61 = Math_fround($53 + $58);
 $62 = Math_fround($54 + $59);
 $63 = (($inertia) + 20|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($27 * $64);
 $66 = Math_fround($28 * $64);
 $67 = Math_fround($29 * $64);
 $68 = Math_fround($60 + $65);
 $69 = Math_fround($61 + $66);
 $70 = Math_fround($62 + $67);
 $71 = (($inertia) + 24|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($20 * $72);
 $74 = Math_fround($21 * $72);
 $75 = Math_fround($22 * $72);
 $76 = (($inertia) + 28|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($23 * $77);
 $79 = Math_fround($25 * $77);
 $80 = Math_fround($26 * $77);
 $81 = Math_fround($73 + $78);
 $82 = Math_fround($74 + $79);
 $83 = Math_fround($75 + $80);
 $84 = (($inertia) + 32|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($27 * $85);
 $87 = Math_fround($28 * $85);
 $88 = Math_fround($29 * $85);
 $89 = Math_fround($81 + $86);
 $90 = Math_fround($82 + $87);
 $91 = Math_fround($83 + $88);
 $92 = Math_fround($20 * $47);
 $93 = Math_fround($20 * $48);
 $94 = Math_fround($20 * $49);
 $95 = Math_fround($23 * $68);
 $96 = Math_fround($23 * $69);
 $97 = Math_fround($23 * $70);
 $98 = Math_fround($92 + $95);
 $99 = Math_fround($93 + $96);
 $100 = Math_fround($94 + $97);
 $101 = Math_fround($27 * $89);
 $102 = Math_fround($27 * $90);
 $103 = Math_fround($27 * $91);
 $104 = Math_fround($98 + $101);
 $105 = Math_fround($99 + $102);
 $106 = Math_fround($100 + $103);
 $107 = Math_fround($21 * $47);
 $108 = Math_fround($21 * $48);
 $109 = Math_fround($21 * $49);
 $110 = Math_fround($25 * $68);
 $111 = Math_fround($25 * $69);
 $112 = Math_fround($25 * $70);
 $113 = Math_fround($107 + $110);
 $114 = Math_fround($108 + $111);
 $115 = Math_fround($109 + $112);
 $116 = Math_fround($28 * $89);
 $117 = Math_fround($28 * $90);
 $118 = Math_fround($28 * $91);
 $119 = Math_fround($113 + $116);
 $120 = Math_fround($114 + $117);
 $121 = Math_fround($115 + $118);
 $122 = Math_fround($22 * $47);
 $123 = Math_fround($22 * $48);
 $124 = Math_fround($22 * $49);
 $125 = Math_fround($26 * $68);
 $126 = Math_fround($26 * $69);
 $127 = Math_fround($26 * $70);
 $128 = Math_fround($122 + $125);
 $129 = Math_fround($123 + $126);
 $130 = Math_fround($124 + $127);
 $131 = Math_fround($29 * $89);
 $132 = Math_fround($29 * $90);
 $133 = Math_fround($29 * $91);
 $134 = Math_fround($128 + $131);
 $135 = Math_fround($129 + $132);
 $136 = Math_fround($130 + $133);
 HEAPF32[$agg$result>>2] = $104;
 $137 = (($agg$result) + 4|0);
 HEAPF32[$137>>2] = $105;
 $138 = (($agg$result) + 8|0);
 HEAPF32[$138>>2] = $106;
 $139 = (($agg$result) + 12|0);
 HEAPF32[$139>>2] = $119;
 $140 = (($agg$result) + 16|0);
 HEAPF32[$140>>2] = $120;
 $141 = (($agg$result) + 20|0);
 HEAPF32[$141>>2] = $121;
 $142 = (($agg$result) + 24|0);
 HEAPF32[$142>>2] = $134;
 $143 = (($agg$result) + 28|0);
 HEAPF32[$143>>2] = $135;
 $144 = (($agg$result) + 32|0);
 HEAPF32[$144>>2] = $136;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_7PxShapeENS0_15InlineAllocatorILj64ENS0_19ReflectionAllocatorIS3_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = (($this) + 64|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(65);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 413616 : 413584;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,413504,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 72|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<2)|0);
 $21 = (($this) + 68|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($19>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = (($this) + 76|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(-1);
 if (!($31)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$21>>2]|0;
 $33 = ($this|0)==($32|0);
 if ($33) {
  $34 = (($this) + 64|0);
  HEAP8[$34>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = ($32|0)==(0|0);
 if ($35) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vii[$39 & 4095]($36,$32);
 HEAP32[$21>>2] = $20;
 HEAP32[$29>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx17PxMeshOverlapUtilC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$this>>2] = $0;
 $1 = (($this) + 260|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 264|0);
 HEAP32[$2>>2] = 64;
 STACKTOP = sp;return;
}
function __ZN5physx17PxMeshOverlapUtilD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx17PxMeshOverlapUtil11findOverlapERKNS_10PxGeometryERKNS_11PxTransformERKNS_22PxTriangleMeshGeometryES6_($this,$geom,$geomPose,$meshGeom,$meshPose) {
 $this = $this|0;
 $geom = $geom|0;
 $geomPose = $geomPose|0;
 $meshGeom = $meshGeom|0;
 $meshPose = $meshPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $nbTouchedTris$0 = 0, $overflow = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $overflow = sp + 2|0;
 $0 = sp;
 $1 = sp + 1|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN5physx11PxMeshQuery23findOverlapTriangleMeshERKNS_10PxGeometryERKNS_11PxTransformERKNS_22PxTriangleMeshGeometryES6_PjjjRb($geom,$geomPose,$meshGeom,$meshPose,$2,$4,0,$overflow)|0);
 $6 = HEAP8[$overflow>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $nbTouchedTris$0 = $5;
 } else {
  $8 = (($meshGeom) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 32|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
  $14 = ($13|0)==(0);
  if ($14) {
   $15 = (($this) + 260|0);
   HEAP32[$15>>2] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $16 = HEAP32[$3>>2]|0;
  $17 = ($16>>>0)<($13>>>0);
  $18 = HEAP32[$this>>2]|0;
  if ($17) {
   $19 = (($this) + 4|0);
   $20 = ($18|0)==($19|0);
   if (!($20)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$18);
   }
   $21 = $13 << 2;
   $22 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$21,413840,70)|0);
   HEAP32[$this>>2] = $22;
   HEAP32[$3>>2] = $13;
   $23 = $22;$24 = $13;
  } else {
   $23 = $18;$24 = $16;
  }
  $25 = (__ZN5physx11PxMeshQuery23findOverlapTriangleMeshERKNS_10PxGeometryERKNS_11PxTransformERKNS_22PxTriangleMeshGeometryES6_PjjjRb($geom,$geomPose,$meshGeom,$meshPose,$23,$24,0,$overflow)|0);
  $nbTouchedTris$0 = $25;
 }
 $26 = (($this) + 260|0);
 HEAP32[$26>>2] = $nbTouchedTris$0;
 $$0 = $nbTouchedTris$0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17PxMeshOverlapUtil11findOverlapERKNS_10PxGeometryERKNS_11PxTransformERKNS_21PxHeightFieldGeometryES6_($this,$geom,$geomPose,$hfGeom,$hfPose) {
 $this = $this|0;
 $geom = $geom|0;
 $geomPose = $geomPose|0;
 $hfGeom = $hfGeom|0;
 $hfPose = $hfPose|0;
 var $$pr = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $overflow = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $overflow = sp + 2|0;
 $0 = sp;
 $1 = sp + 1|0;
 HEAP8[$overflow>>0] = 1;
 $2 = (($this) + 264|0);
 $3 = (($this) + 4|0);
 $$pre = HEAP32[$this>>2]|0;
 $$pre1 = HEAP32[$2>>2]|0;
 $4 = $$pre;$5 = $$pre1;
 while(1) {
  $6 = (__ZN5physx11PxMeshQuery22findOverlapHeightFieldERKNS_10PxGeometryERKNS_11PxTransformERKNS_21PxHeightFieldGeometryES6_PjjjRb($geom,$geomPose,$hfGeom,$hfPose,$4,$5,0,$overflow)|0);
  $7 = HEAP8[$overflow>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 6;
   break;
  }
  $9 = HEAP32[$2>>2]|0;
  $10 = $9 << 1;
  $11 = HEAP32[$this>>2]|0;
  $12 = ($11|0)==($3|0);
  if (!($12)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
  }
  $13 = $9 << 3;
  $14 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$13,413840,95)|0);
  HEAP32[$this>>2] = $14;
  HEAP32[$2>>2] = $10;
  $$pr = HEAP8[$overflow>>0]|0;
  $15 = ($$pr<<24>>24)==(0);
  if ($15) {
   label = 6;
   break;
  } else {
   $4 = $14;$5 = $10;
  }
 }
 if ((label|0) == 6) {
  $16 = (($this) + 260|0);
  HEAP32[$16>>2] = $6;
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*12)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 414048 : 414016;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,413936,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*12)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
   }
   $32 = (($$012$i) + 12|0);
   $33 = (($$03$i) + 12|0);
   $34 = ($32>>>0)<($20>>>0);
   if ($34) {
    $$012$i = $32;$$03$i = $33;
   } else {
    break;
   }
  }
 }
 $35 = ($20|0)==(0|0);
 if (!($35)) {
  $36 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$20>>2] = $36;
  $37 = ((($21) + (($19*12)|0)|0) + 4|0);
  $38 = (($a) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[$37>>2] = $39;
  $40 = ((($21) + (($19*12)|0)|0) + 8|0);
  $41 = (($a) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$40>>2] = $42;
 }
 $43 = HEAP32[$0>>2]|0;
 $44 = ($43|0)>(-1);
 if (!($44)) {
  $52 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $51 = (($52) + 1)|0;
  HEAP32[$18>>2] = $51;
  $53 = (($21) + (($52*12)|0)|0);
  STACKTOP = sp;return ($53|0);
 }
 $45 = HEAP32[$this>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  $52 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $51 = (($52) + 1)|0;
  HEAP32[$18>>2] = $51;
  $53 = (($21) + (($52*12)|0)|0);
  STACKTOP = sp;return ($53|0);
 }
 $47 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + 12|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_vii[$50 & 4095]($47,$45);
 $$pre = HEAP32[$18>>2]|0;
 $52 = $$pre;
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $51 = (($52) + 1)|0;
 HEAP32[$18>>2] = $51;
 $53 = (($21) + (($52*12)|0)|0);
 STACKTOP = sp;return ($53|0);
}
function __ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i($errCode,$context,$file,$line) {
 $errCode = $errCode|0;
 $context = $context|0;
 $file = $file|0;
 $line = $line|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($errCode|0)==(0);
 if ($0) {
  STACKTOP = sp;return ($errCode|0);
 }
 $1 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 $2 = (($1) + 116|0);
 $3 = (414152 + ($errCode<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd12ErrorHandler11reportErrorENS_11PxErrorCode4EnumEPKcS5_i($2,8,$4,$file,$line);
 $5 = ($context|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return ($errCode|0);
 }
 __ZN5physx6shdfnd12ErrorHandler11reportErrorENS_11PxErrorCode4EnumEPKcS5_i($2,1,$context,$file,$line);
 STACKTOP = sp;return ($errCode|0);
}
function __ZN5physx7NpActorC2EPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $name;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx7NpActorD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $exitcond = 0, $exitcond7 = 0, $exportConnectorArray$0 = 0, $i$02 = 0, $i1$01 = 0, $missedCount$0$ = 0, $missedCount$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$stream>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($stream)|0);
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $81 = HEAP32[$stream>>2]|0;
  $82 = (($81) + 16|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = HEAP32[$this>>2]|0;
  FUNCTION_TABLE_vii[$83 & 4095]($stream,$84);
  STACKTOP = sp;return;
 }
 $7 = (($5) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $85 = 0;$exportConnectorArray$0 = $5;
 } else {
  $11 = $5;$i$02 = 0;$missedCount$03 = 0;
  while(1) {
   $10 = (($11) + 36|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ((($12) + ($i$02<<3)|0) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$3>>2]|0;
   $16 = (($15) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (FUNCTION_TABLE_iii[$17 & 4095]($3,$14)|0);
   $19 = $18&1;
   $20 = $19 ^ 1;
   $missedCount$0$ = (($20) + ($missedCount$03))|0;
   $21 = (($i$02) + 1)|0;
   $22 = HEAP32[$4>>2]|0;
   $exitcond7 = ($21|0)==($8|0);
   if ($exitcond7) {
    break;
   } else {
    $11 = $22;$i$02 = $21;$missedCount$03 = $missedCount$0$;
   }
  }
  $23 = ($missedCount$0$|0)!=(0);
  if ($23) {
   $24 = HEAP32[420520>>2]|0;
   $25 = (__ZN5physx9NpFactory21acquireConnectorArrayEv($24)|0);
   $26 = ($missedCount$0$>>>0)<($8>>>0);
   if ($26) {
    $27 = (($8) - ($missedCount$0$))|0;
    $28 = (($25) + 44|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = $29 & 2147483647;
    $31 = ($30>>>0)<($27>>>0);
    if ($31) {
     __ZN5physx6shdfnd5ArrayINS_11NpConnectorENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($25,$27);
    }
    if ($9) {
     $85 = $23;$exportConnectorArray$0 = $25;
    } else {
     $32 = (($25) + 40|0);
     $33 = (($25) + 36|0);
     $i1$01 = 0;
     while(1) {
      $34 = HEAP32[$4>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($36) + ($i1$01<<3)|0);
      $38 = ((($36) + ($i1$01<<3)|0) + 4|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = HEAP32[$3>>2]|0;
      $41 = (($40) + 8|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (FUNCTION_TABLE_iii[$42 & 4095]($3,$39)|0);
      do {
       if ($43) {
        $44 = HEAP32[$28>>2]|0;
        $45 = $44 & 2147483647;
        $46 = HEAP32[$32>>2]|0;
        $47 = ($45>>>0)>($46>>>0);
        if (!($47)) {
         (__ZN5physx6shdfnd5ArrayINS_11NpConnectorENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE15growAndPushBackERKS2_($25,$37)|0);
         break;
        }
        $48 = HEAP32[$33>>2]|0;
        $49 = (($48) + ($46<<3)|0);
        $50 = ($49|0)==(0|0);
        if ($50) {
         $55 = $46;
        } else {
         $51 = HEAP8[$37>>0]|0;
         HEAP8[$49>>0] = $51;
         $52 = HEAP32[$38>>2]|0;
         $53 = (($49) + 4|0);
         HEAP32[$53>>2] = $52;
         $$pre$i = HEAP32[$32>>2]|0;
         $55 = $$pre$i;
        }
        $54 = (($55) + 1)|0;
        HEAP32[$32>>2] = $54;
       }
      } while(0);
      $56 = (($i1$01) + 1)|0;
      $exitcond = ($56|0)==($8|0);
      if ($exitcond) {
       $85 = $23;$exportConnectorArray$0 = $25;
       break;
      } else {
       $i1$01 = $56;
      }
     }
    }
   } else {
    $85 = 1;$exportConnectorArray$0 = $25;
   }
  } else {
   $85 = 0;$exportConnectorArray$0 = $22;
  }
 }
 $57 = HEAP32[$stream>>2]|0;
 $58 = (($57) + 12|0);
 $59 = HEAP32[$58>>2]|0;
 FUNCTION_TABLE_vii[$59 & 4095]($stream,16);
 $60 = HEAP32[$stream>>2]|0;
 $61 = (($60) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 FUNCTION_TABLE_viii[$62 & 4095]($stream,$exportConnectorArray$0,48);
 $63 = (($exportConnectorArray$0) + 32|0);
 $64 = HEAP8[$63>>0]|0;
 $65 = ($64<<24>>24)==(0);
 do {
  if ($65) {
   $66 = (($exportConnectorArray$0) + 36|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(0|0);
   if (!($68)) {
    $69 = (($exportConnectorArray$0) + 40|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==(0);
    $72 = (($exportConnectorArray$0) + 44|0);
    $73 = HEAP32[$72>>2]|0;
    if ($71) {
     $74 = $73 & 2147483647;
     $75 = ($74|0)==(0);
     if ($75) {
      break;
     }
    }
    $76 = HEAP32[$stream>>2]|0;
    $77 = (($76) + 8|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = $73 << 3;
    FUNCTION_TABLE_viii[$78 & 4095]($stream,$67,$79);
   }
  }
 } while(0);
 if (!($85)) {
  $81 = HEAP32[$stream>>2]|0;
  $82 = (($81) + 16|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = HEAP32[$this>>2]|0;
  FUNCTION_TABLE_vii[$83 & 4095]($stream,$84);
  STACKTOP = sp;return;
 }
 $80 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory21releaseConnectorArrayEPNS_16NpConnectorArrayE($80,$exportConnectorArray$0);
 $81 = HEAP32[$stream>>2]|0;
 $82 = (($81) + 16|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = HEAP32[$this>>2]|0;
 FUNCTION_TABLE_vii[$83 & 4095]($stream,$84);
 STACKTOP = sp;return;
}
function __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $7 = $1;$i$01 = 0;
 while(1) {
  $6 = (($7) + 36|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = ((($8) + ($i$01<<3)|0) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$context>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = $10;
   $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($context,-2147483648,$14)|0);
   HEAP32[$9>>2] = $15;
  }
  $16 = (($i$01) + 1)|0;
  $exitcond = ($16|0)==($4|0);
  if ($exitcond) {
   break;
  }
  $$pre = HEAP32[$0>>2]|0;
  $7 = $$pre;$i$01 = $16;
 }
 STACKTOP = sp;return;
}
function __ZN5physx7NpActor18releaseConstraintsERNS_12PxRigidActorE($this,$owner) {
 $this = $this|0;
 $owner = $owner|0;
 var $$in = 0, $$in3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $currentIndex$0$ph2 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $$in = $4;$63 = $1;$currentIndex$0$ph2 = 0;
 }
 L6: while(1) {
  $$in3 = $$in;$8 = $63;
  while(1) {
   $6 = (($$in3) + -1)|0;
   $7 = (($8) + 36|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = (($9) + ($currentIndex$0$ph2<<3)|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)==(0);
   if (!($12)) {
    break;
   }
   $13 = ((($9) + ($currentIndex$0$ph2<<3)|0) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   __ZN5physx12NpConstraint12actorDeletedEPNS_12PxRigidActorE($14,$owner);
   $15 = (__ZNK5physx12NpConstraint10getNpSceneEv($14)|0);
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = (($15) + 16|0);
    $18 = (($14) + 16|0);
    __ZN5physx3Scb5Scene16removeConstraintERNS0_10ConstraintE($17,$18);
    $19 = (($15) + 3528|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0);
    if (!($21)) {
     $22 = (($15) + 3524|0);
     $23 = HEAP32[$22>>2]|0;
     $index$01$i$i = 0;
     while(1) {
      $26 = (($23) + ($index$01$i$i<<2)|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==($14|0);
      $25 = (($index$01$i$i) + 1)|0;
      if ($28) {
       $index$0$lcssa$i$i = $index$01$i$i;
       break;
      }
      $24 = ($25>>>0)<($20>>>0);
      if ($24) {
       $index$01$i$i = $25;
      } else {
       $index$0$lcssa$i$i = $25;
       break;
      }
     }
     $29 = ($index$0$lcssa$i$i|0)==($20|0);
     if (!($29)) {
      $30 = (($20) + -1)|0;
      HEAP32[$19>>2] = $30;
      $31 = (($23) + ($30<<2)|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($23) + ($index$0$lcssa$i$i<<2)|0);
      HEAP32[$33>>2] = $32;
     }
    }
   }
   $34 = HEAP32[$0>>2]|0;
   $35 = (($34) + 36|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 40|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + -1)|0;
   HEAP32[$37>>2] = $39;
   $40 = (($36) + ($currentIndex$0$ph2<<3)|0);
   $41 = (($36) + ($39<<3)|0);
   $42 = $41;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = (($42) + 4)|0;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = $40;
   $49 = $48;
   HEAP32[$49>>2] = $44;
   $50 = (($48) + 4)|0;
   $51 = $50;
   HEAP32[$51>>2] = $47;
   $52 = HEAP32[$0>>2]|0;
   $53 = (($52) + 40|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   if ($55) {
    $57 = (($52) + 44|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($58|0)>(-1);
    if ($59) {
     $60 = HEAP32[420520>>2]|0;
     __ZN5physx9NpFactory21releaseConnectorArrayEPNS_16NpConnectorArrayE($60,$52);
    }
    HEAP32[$0>>2] = 0;
    $64 = 0;
   } else {
    $64 = $52;
   }
   $56 = ($6|0)==(0);
   if ($56) {
    label = 18;
    break L6;
   } else {
    $$in3 = $6;$8 = $64;
   }
  }
  $61 = (($currentIndex$0$ph2) + 1)|0;
  $62 = ($6|0)==(0);
  if ($62) {
   label = 18;
   break;
  } else {
   $$in = $6;$63 = $8;$currentIndex$0$ph2 = $61;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpActor7releaseERNS_7PxActorE($this,$owner) {
 $this = $this|0;
 $owner = $owner|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 (__ZN5physx11NpAggregate22removeActorAndReinsertERNS_7PxActorEb($6,$owner,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpActor13findConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseE($this,$type,$object) {
 $this = $this|0;
 $type = $type|0;
 $object = $object|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($1) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $$phi$trans$insert = (($1) + 36|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 $i$01 = 0;
 while(1) {
  $6 = (($$pre) + ($i$01<<3)|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  $9 = ($8|0)==($type|0);
  if ($9) {
   $10 = ((($$pre) + ($i$01<<3)|0) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==($object|0);
   if ($12) {
    $$0 = $i$01;
    label = 7;
    break;
   }
  }
  $13 = (($i$01) + 1)|0;
  $14 = ($13>>>0)<($4>>>0);
  if ($14) {
   $i$01 = $13;
  } else {
   $$0 = -1;
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx7NpActor12addConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($this,$type,$object,$errMsg) {
 $this = $this|0;
 $type = $type|0;
 $object = $object|0;
 $errMsg = $errMsg|0;
 var $$012$i$i = 0, $$03$i$i = 0, $$idx = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $c = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[420520>>2]|0;
  $4 = (__ZN5physx9NpFactory21acquireConnectorArrayEv($3)|0);
  HEAP32[$0>>2] = $4;
  $6 = $4;
 } else {
  $6 = $1;
 }
 $5 = (($6) + 44|0);
 $7 = HEAP32[$5>>2]|0;
 $8 = ($7|0)>(-1);
 if ($8) {
  $53 = $6;
 } else {
  $9 = (($6) + 40|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $7 & 2147483647;
  $12 = ($10|0)==($11|0);
  if ($12) {
   $13 = HEAP32[420520>>2]|0;
   $14 = (__ZN5physx9NpFactory21acquireConnectorArrayEv($13)|0);
   $15 = HEAP32[$0>>2]|0;
   $16 = (($15) + 36|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($15) + 40|0);
   $19 = HEAP32[$18>>2]|0;
   $$idx = $19 << 3;
   $20 = $$idx >> 3;
   __ZN5physx6shdfnd5ArrayINS_11NpConnectorENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE19resizeUninitializedEj($14,$20);
   $21 = (($14) + 36|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($14) + 40|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($22) + ($24<<3)|0);
   $26 = ($24|0)>(0);
   if ($26) {
    $$012$i$i = $22;$$03$i$i = $17;
    while(1) {
     $27 = ($$012$i$i|0)==(0|0);
     if (!($27)) {
      $28 = HEAP8[$$03$i$i>>0]|0;
      HEAP8[$$012$i$i>>0] = $28;
      $29 = (($$03$i$i) + 4|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($$012$i$i) + 4|0);
      HEAP32[$31>>2] = $30;
     }
     $32 = (($$012$i$i) + 8|0);
     $33 = (($$03$i$i) + 8|0);
     $34 = ($32>>>0)<($25>>>0);
     if ($34) {
      $$012$i$i = $32;$$03$i$i = $33;
     } else {
      break;
     }
    }
   }
   $35 = HEAP32[$0>>2]|0;
   $36 = (($35) + 44|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = $37 & 2147483647;
   $39 = ($38|0)!=(0);
   $40 = ($37|0)>(-1);
   $or$cond$i$i$i$i = $39 & $40;
   do {
    if ($or$cond$i$i$i$i) {
     $41 = (($35) + 36|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($35|0)==($42|0);
     if ($43) {
      $44 = (($35) + 32|0);
      HEAP8[$44>>0] = 0;
      break;
     }
     $45 = ($42|0)==(0|0);
     if (!($45)) {
      $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + 12|0);
      $49 = HEAP32[$48>>2]|0;
      FUNCTION_TABLE_vii[$49 & 4095]($46,$42);
     }
    }
   } while(0);
   HEAP32[$0>>2] = $14;
   $53 = $14;
  } else {
   $53 = $6;
  }
 }
 $50 = $type&255;
 HEAP8[$c>>0] = $50;
 $51 = (($c) + 4|0);
 HEAP32[$51>>2] = $object;
 $52 = (($53) + 44|0);
 $54 = HEAP32[$52>>2]|0;
 $55 = $54 & 2147483647;
 $56 = (($53) + 40|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($55>>>0)>($57>>>0);
 if (!($58)) {
  (__ZN5physx6shdfnd5ArrayINS_11NpConnectorENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE15growAndPushBackERKS2_($53,$c)|0);
  STACKTOP = sp;return;
 }
 $59 = (($53) + 36|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + ($57<<3)|0);
 $62 = ($61|0)==(0|0);
 if ($62) {
  $65 = $57;
 } else {
  HEAP8[$61>>0] = $50;
  $63 = (($61) + 4|0);
  HEAP32[$63>>2] = $object;
  $$pre$i = HEAP32[$56>>2]|0;
  $65 = $$pre$i;
 }
 $64 = (($65) + 1)|0;
 HEAP32[$56>>2] = $64;
 STACKTOP = sp;return;
}
function __ZN5physx7NpActor15removeConnectorERNS_7PxActorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($this,$owner,$type,$object,$errorMsg) {
 $this = $this|0;
 $owner = $owner|0;
 $type = $type|0;
 $object = $object|0;
 $errorMsg = $errorMsg|0;
 var $$0$i = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 $$phi$trans$insert = (($1) + 36|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 L4: do {
  if ($5) {
   $$0$i = -1;
  } else {
   $i$01$i = 0;
   while(1) {
    $6 = (($$pre) + ($i$01$i<<3)|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = $7&255;
    $9 = ($8|0)==($type|0);
    if ($9) {
     $10 = ((($$pre) + ($i$01$i<<3)|0) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==($object|0);
     if ($12) {
      $$0$i = $i$01$i;
      break L4;
     }
    }
    $13 = (($i$01$i) + 1)|0;
    $14 = ($13>>>0)<($4>>>0);
    if ($14) {
     $i$01$i = $13;
    } else {
     $$0$i = -1;
     break;
    }
   }
  }
 } while(0);
 $15 = (($4) + -1)|0;
 HEAP32[$3>>2] = $15;
 $16 = (($$pre) + ($$0$i<<3)|0);
 $17 = (($$pre) + ($15<<3)|0);
 $18 = $17;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $16;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = HEAP32[$0>>2]|0;
 $29 = (($28) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = (($28) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)>(-1);
 if ($34) {
  $35 = HEAP32[420520>>2]|0;
  __ZN5physx9NpFactory21releaseConnectorArrayEPNS_16NpConnectorArrayE($35,$28);
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx7NpActor15getNbConnectorsENS_15NpConnectorType4EnumE($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $$nbConnectors$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $nbConnectors$01 = 0, $nbConnectors$2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $nbConnectors$2 = 0;
  STACKTOP = sp;return ($nbConnectors$2|0);
 }
 $3 = (($1) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $nbConnectors$2 = 0;
  STACKTOP = sp;return ($nbConnectors$2|0);
 }
 $$phi$trans$insert = (($1) + 36|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 $i$02 = 0;$nbConnectors$01 = 0;
 while(1) {
  $6 = (($$pre) + ($i$02<<3)|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  $9 = ($8|0)==($type|0);
  $10 = $9&1;
  $$nbConnectors$0 = (($10) + ($nbConnectors$01))|0;
  $11 = (($i$02) + 1)|0;
  $12 = ($11>>>0)<($4>>>0);
  if ($12) {
   $i$02 = $11;$nbConnectors$01 = $$nbConnectors$0;
  } else {
   $nbConnectors$2 = $$nbConnectors$0;
   break;
  }
 }
 STACKTOP = sp;return ($nbConnectors$2|0);
}
function __ZN5physx7NpActor12setAggregateEPNS_11NpAggregateERNS_7PxActorE($this,$np,$owner) {
 $this = $this|0;
 $np = $np|0;
 $owner = $owner|0;
 var $$phi$trans$insert$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if (!($2)) {
   $3 = (($1) + 40|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0);
   if (!($5)) {
    $$phi$trans$insert$i = (($1) + 36|0);
    $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $i$02$i = 0;
    while(1) {
     $8 = (($$pre$i) + ($i$02$i<<3)|0);
     $9 = HEAP8[$8>>0]|0;
     $10 = ($9<<24>>24)==(1);
     $7 = (($i$02$i) + 1)|0;
     if ($10) {
      break;
     }
     $6 = ($7>>>0)<($4>>>0);
     if ($6) {
      $i$02$i = $7;
     } else {
      break L1;
     }
    }
    $11 = ((($$pre$i) + ($i$02$i<<3)|0) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     $14 = ($np|0)==(0|0);
     if (!($14)) {
      HEAP32[$11>>2] = $np;
      STACKTOP = sp;return;
     }
     $15 = (($4) + -1)|0;
     HEAP32[$3>>2] = $15;
     $16 = (($$pre$i) + ($15<<3)|0);
     $17 = $16;
     $18 = $17;
     $19 = HEAP32[$18>>2]|0;
     $20 = (($17) + 4)|0;
     $21 = $20;
     $22 = HEAP32[$21>>2]|0;
     $23 = $8;
     $24 = $23;
     HEAP32[$24>>2] = $19;
     $25 = (($23) + 4)|0;
     $26 = $25;
     HEAP32[$26>>2] = $22;
     $27 = HEAP32[$0>>2]|0;
     $28 = (($27) + 40|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($29|0)==(0);
     if (!($30)) {
      STACKTOP = sp;return;
     }
     $31 = (($27) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)>(-1);
     if ($33) {
      $34 = HEAP32[420520>>2]|0;
      __ZN5physx9NpFactory21releaseConnectorArrayEPNS_16NpConnectorArrayE($34,$27);
     }
     HEAP32[$0>>2] = 0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 __ZN5physx7NpActor12addConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($this,1,$np,414232);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpActor12getAggregateEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   $$0$i = 0;
  } else {
   $3 = (($1) + 40|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0);
   if ($5) {
    $$0$i = 0;
   } else {
    $$phi$trans$insert$i = (($1) + 36|0);
    $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $i$02$i = 0;
    while(1) {
     $8 = (($$pre$i) + ($i$02$i<<3)|0);
     $9 = HEAP8[$8>>0]|0;
     $10 = ($9<<24>>24)==(1);
     $7 = (($i$02$i) + 1)|0;
     if ($10) {
      break;
     }
     $6 = ($7>>>0)<($4>>>0);
     if ($6) {
      $i$02$i = $7;
     } else {
      $$0$i = 0;
      break L1;
     }
    }
    $11 = ((($$pre$i) + ($i$02$i<<3)|0) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $$0$i = $12;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx7NpActor26removeConstraintsFromSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $9 = 0;
 }
 while(1) {
  $8 = (($9) + 1)|0;
  $10 = (($4) + ($9<<3)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $14 = ((($4) + ($9<<3)|0) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    label = 14;
    break;
   }
   $17 = (__ZNK5physx12NpConstraint10getNpSceneEv($15)|0);
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $19 = (($17) + 3528|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0);
    if (!($21)) {
     $22 = (($17) + 3524|0);
     $23 = HEAP32[$22>>2]|0;
     $index$01$i$i = 0;
     while(1) {
      $26 = (($23) + ($index$01$i$i<<2)|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==($15|0);
      $25 = (($index$01$i$i) + 1)|0;
      if ($28) {
       $index$0$lcssa$i$i = $index$01$i$i;
       break;
      }
      $24 = ($25>>>0)<($20>>>0);
      if ($24) {
       $index$01$i$i = $25;
      } else {
       $index$0$lcssa$i$i = $25;
       break;
      }
     }
     $29 = ($index$0$lcssa$i$i|0)==($20|0);
     if (!($29)) {
      $30 = (($20) + -1)|0;
      HEAP32[$19>>2] = $30;
      $31 = (($23) + ($30<<2)|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($23) + ($index$0$lcssa$i$i<<2)|0);
      HEAP32[$33>>2] = $32;
     }
    }
    $34 = (($17) + 16|0);
    $35 = (($15) + 16|0);
    __ZN5physx3Scb5Scene16removeConstraintERNS0_10ConstraintE($34,$35);
   }
  }
  $13 = ($8>>>0)<($6>>>0);
  if ($13) {
   $9 = $8;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpActor29addConstraintsToSceneInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $10 = 0;
 while(1) {
  $9 = (($10) + 1)|0;
  $11 = (($5) + ($10<<3)|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $15 = ((($5) + ($10<<3)|0) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    label = 14;
    break;
   }
   $18 = HEAP32[$16>>2]|0;
   $19 = (($18) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vi[$20 & 4095]($16);
   $21 = (__ZN5physx12NpConstraint18checkActorsInSceneEv($16)|0);
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    $23 = (($21) + 3524|0);
    HEAP32[$0>>2] = $16;
    $24 = (($21) + 3532|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = $25 & 2147483647;
    $27 = (($21) + 3528|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($26>>>0)>($28>>>0);
    if ($29) {
     $30 = HEAP32[$23>>2]|0;
     $31 = (($30) + ($28<<2)|0);
     $32 = ($31|0)==(0|0);
     if (!($32)) {
      HEAP32[$31>>2] = $16;
     }
     $33 = (($28) + 1)|0;
     HEAP32[$27>>2] = $33;
    } else {
     (__ZN5physx6shdfnd5ArrayIPNS_12PxConstraintENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($23,$0)|0);
    }
    $34 = (($21) + 16|0);
    $35 = (($16) + 16|0);
    __ZN5physx3Scb5Scene13addConstraintERNS0_10ConstraintE($34,$35);
   }
  }
  $14 = ($9>>>0)<($7>>>0);
  if ($14) {
   $10 = $9;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpActor15getShapeManagerERNS_12PxRigidActorE($actor) {
 $actor = $actor|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($actor) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 if ((($1<<16>>16) == 6)) {
  $3 = (($actor) + 20|0);
  $$0 = $3;
 } else if ((($1<<16>>16) == 5)) {
  $2 = (($actor) + 20|0);
  $$0 = $2;
 } else if ((($1<<16>>16) == 15)) {
  $4 = (($actor) + 20|0);
  $$0 = $4;
 } else {
  $$0 = (1);
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($actor) {
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($actor) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($actor) + ($4)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $9 = 0;
  STACKTOP = sp;return ($9|0);
 }
 $8 = (__ZN5physx3Scb5Scene10getPxSceneEv($6)|0);
 $9 = $8;
 STACKTOP = sp;return ($9|0);
}
function __ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($actor) {
 $actor = $actor|0;
 var $$off$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($actor) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $$sum = (($4) + 4)|0;
 $5 = (($actor) + ($$sum)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 >>> 30;
 $$off$i = (($7) + -1)|0;
 $8 = ($$off$i>>>0)<(2);
 if (!($8)) {
  $13 = 0;
  STACKTOP = sp;return ($13|0);
 }
 $9 = (($actor) + ($4)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $13 = 0;
  STACKTOP = sp;return ($13|0);
 }
 $12 = (__ZN5physx3Scb5Scene10getPxSceneEv($10)|0);
 $13 = $12;
 STACKTOP = sp;return ($13|0);
}
function __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($actor) {
 $actor = $actor|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory14onActorReleaseEPNS_7PxActorE($0,$actor);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11NpConnectorENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_11NpConnectorENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 40|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11NpConnectorENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = (($this) + 32|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(33);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 414512 : 414480;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,414400,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<3)|0);
 $26 = (($this) + 36|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP8[$$03$i>>0]|0;
    HEAP8[$$012$i>>0] = $30;
    $31 = (($$03$i) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($$012$i) + 4|0);
    HEAP32[$33>>2] = $32;
   }
   $34 = (($$012$i) + 8|0);
   $35 = (($$03$i) + 8|0);
   $36 = ($34>>>0)<($24>>>0);
   if ($36) {
    $$012$i = $34;$$03$i = $35;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$22>>2]|0;
  $38 = $$pre;
 } else {
  $38 = $23;
 }
 $37 = (($25) + ($38<<3)|0);
 $39 = ($37|0)==(0|0);
 if (!($39)) {
  $40 = HEAP8[$a>>0]|0;
  HEAP8[$37>>0] = $40;
  $41 = (($a) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($37) + 4|0);
  HEAP32[$43>>2] = $42;
 }
 $44 = HEAP32[$0>>2]|0;
 $45 = ($44|0)>(-1);
 do {
  if ($45) {
   $46 = HEAP32[$26>>2]|0;
   $47 = ($this|0)==($46|0);
   if ($47) {
    $48 = (($this) + 32|0);
    HEAP8[$48>>0] = 0;
    break;
   }
   $49 = ($46|0)==(0|0);
   if (!($49)) {
    $50 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) + 12|0);
    $53 = HEAP32[$52>>2]|0;
    FUNCTION_TABLE_vii[$53 & 4095]($50,$46);
   }
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $54 = HEAP32[$22>>2]|0;
 $55 = (($54) + 1)|0;
 HEAP32[$22>>2] = $55;
 $56 = (($25) + ($54<<3)|0);
 STACKTOP = sp;return ($56|0);
}
function __ZN5physx6shdfnd5ArrayINS_11NpConnectorENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = (($this) + 32|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(33);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 414512 : 414480;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,414400,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<3)|0);
 $21 = (($this) + 36|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP8[$$03$i>>0]|0;
    HEAP8[$$012$i>>0] = $25;
    $26 = (($$03$i) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($$012$i) + 4|0);
    HEAP32[$28>>2] = $27;
   }
   $29 = (($$012$i) + 8|0);
   $30 = (($$03$i) + 8|0);
   $31 = ($29>>>0)<($19>>>0);
   if ($31) {
    $$012$i = $29;$$03$i = $30;
   } else {
    break;
   }
  }
 }
 $32 = (($this) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)>(-1);
 if (!($34)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$32>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = HEAP32[$21>>2]|0;
 $36 = ($this|0)==($35|0);
 if ($36) {
  $37 = (($this) + 32|0);
  HEAP8[$37>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$32>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = ($35|0)==(0|0);
 if ($38) {
  HEAP32[$21>>2] = $20;
  HEAP32[$32>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $39 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vii[$42 & 4095]($39,$35);
 HEAP32[$21>>2] = $20;
 HEAP32[$32>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_12PxConstraintENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 414624 : 414480;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,414400,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx11NpAggregateC2Ejb($this,$maxActors,$selfCollisions) {
 $this = $this|0;
 $maxActors = $maxActors|0;
 $selfCollisions = $selfCollisions|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP16[$1>>1] = 13;
 $2 = (($this) + 6|0);
 HEAP16[$2>>1] = 3;
 HEAP32[$this>>2] = ((414744 + 8|0));
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 12|0);
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = $this;
 $7 = (($this) + 24|0);
 HEAP32[$7>>2] = -1;
 $8 = (($this) + 28|0);
 HEAP32[$8>>2] = $maxActors;
 $9 = (($this) + 32|0);
 $10 = $selfCollisions&1;
 HEAP8[$9>>0] = $10;
 HEAP32[$5>>2] = 167772160;
 $11 = (($this) + 36|0);
 HEAP32[$11>>2] = 0;
 $12 = $maxActors << 2;
 $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$12,414824,58)|0);
 $14 = (($this) + 40|0);
 HEAP32[$14>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN5physx11NpAggregateD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((414744 + 8|0));
 $1 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory18onAggregateReleaseEPNS_11PxAggregateE($1,$this);
 $2 = (($this) + 6|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & 1;
 $5 = ($4<<16>>16)==(0);
 if ($5) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
  STACKTOP = sp;return;
 }
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx11NpAggregateD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((414744 + 8|0));
 $1 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory18onAggregateReleaseEPNS_11PxAggregateE($1,$this);
 $2 = (($this) + 6|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & 1;
 $5 = ($4<<16>>16)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
 STACKTOP = sp;return;
}
function __ZN5physx11NpAggregate7releaseEv($this) {
 $this = $this|0;
 var $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $44 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $44 = $7;
  }
 } else {
  $44 = 0;
 }
 $8 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($8,$this,0,1);
 $9 = (($this) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = (($this) + 40|0);
  $13 = (($this) + 8|0);
  $i$01 = 0;
  while(1) {
   $14 = HEAP32[$12>>2]|0;
   $15 = (($14) + ($i$01<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 24|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
   $21 = ($20|0)==(4);
   if ($21) {
    $22 = HEAP32[$12>>2]|0;
    $23 = (($22) + ($i$01<<2)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($24) + 288|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($26) + 100|0);
    HEAP32[$27>>2] = 0;
   }
   $28 = HEAP32[$12>>2]|0;
   $29 = (($28) + ($i$01<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 4|0);
   $32 = HEAP16[$31>>1]|0;
   $33 = $32&65535;
   $34 = (414264 + ($33<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($30) + ($35)|0);
   $37 = ((414264 + ($33<<2)|0) + 68|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($30) + ($38)|0);
   __ZN5physx7NpActor12setAggregateEPNS_11NpAggregateERNS_7PxActorE($36,0,$30);
   __ZN5physx3Scb9Aggregate11removeActorERNS0_5ActorEb($13,$39,1);
   $40 = (($i$01) + 1)|0;
   $41 = HEAP32[$9>>2]|0;
   $42 = ($40>>>0)<($41>>>0);
   if ($42) {
    $i$01 = $40;
   } else {
    break;
   }
  }
 }
 $43 = ($44|0)==(0|0);
 if ($43) {
  $62 = (($this) + 8|0);
  __ZN5physx3Scb4Base7destroyEv($62);
  STACKTOP = sp;return;
 }
 $45 = (($44) + 16|0);
 $46 = (($this) + 8|0);
 __ZN5physx3Scb5Scene15removeAggregateERNS0_9AggregateE($45,$46);
 $47 = (($44) + 3564|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0);
 if ($49) {
  $62 = (($this) + 8|0);
  __ZN5physx3Scb4Base7destroyEv($62);
  STACKTOP = sp;return;
 }
 $50 = (($44) + 3560|0);
 $51 = HEAP32[$50>>2]|0;
 $index$01$i$i = 0;
 while(1) {
  $54 = (($51) + ($index$01$i$i<<2)|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==($this|0);
  $53 = (($index$01$i$i) + 1)|0;
  if ($56) {
   $index$0$lcssa$i$i = $index$01$i$i;
   break;
  }
  $52 = ($53>>>0)<($48>>>0);
  if ($52) {
   $index$01$i$i = $53;
  } else {
   $index$0$lcssa$i$i = $53;
   break;
  }
 }
 $57 = ($index$0$lcssa$i$i|0)==($48|0);
 if ($57) {
  $62 = (($this) + 8|0);
  __ZN5physx3Scb4Base7destroyEv($62);
  STACKTOP = sp;return;
 }
 $58 = (($48) + -1)|0;
 HEAP32[$47>>2] = $58;
 $59 = (($51) + ($58<<2)|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($51) + ($index$0$lcssa$i$i<<2)|0);
 HEAP32[$61>>2] = $60;
 $62 = (($this) + 8|0);
 __ZN5physx3Scb4Base7destroyEv($62);
 STACKTOP = sp;return;
}
function __ZN5physx11NpAggregate16addActorInternalERNS_7PxActorERNS_7NpSceneE($this,$actor,$s) {
 $this = $this|0;
 $actor = $actor|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$actor>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($actor)|0);
 $4 = ($3|0)==(4);
 if (!($4)) {
  $5 = (($actor) + 4|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = $6&65535;
  $8 = ((414264 + ($7<<2)|0) + 68|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($actor) + ($9)|0);
  $11 = (($this) + 8|0);
  __ZN5physx3Scb9Aggregate8addActorERNS0_5ActorE($11,$10);
  __ZN5physx7NpScene16addActorInternalERNS_7PxActorE($s,$actor);
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$actor>>2]|0;
 $13 = (($12) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($actor)|0);
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = (($actor) + 288|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 88|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$18>>2]|0;
 $22 = (($21) + 108|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 4095]($18)|0);
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = (($this) + 8|0);
  $i$01 = 0;
  while(1) {
   $27 = (($20) + ($i$01<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 48|0);
   __ZN5physx3Scb9Aggregate8addActorERNS0_5ActorE($26,$29);
   $30 = (($i$01) + 1)|0;
   $31 = HEAP32[$18>>2]|0;
   $32 = (($31) + 108|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (FUNCTION_TABLE_ii[$33 & 4095]($18)|0);
   $35 = ($30>>>0)<($34>>>0);
   if ($35) {
    $i$01 = $30;
   } else {
    break;
   }
  }
 }
 __ZN5physx7NpScene23addArticulationInternalERNS_14PxArticulationE($s,$18);
 STACKTOP = sp;return;
}
function __ZN5physx11NpAggregate8addActorERNS_7PxActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $$0 = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer5 = sp;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $44 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $44 = $7;
  }
 } else {
  $44 = 0;
 }
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 if ($12) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($13,2,414824,145,414904,$vararg_buffer5);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = HEAP32[$actor>>2]|0;
 $15 = (($14) + 80|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($actor)|0);
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($19,2,414824,151,414976,$vararg_buffer5);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$actor>>2]|0;
 $21 = (($20) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_ii[$22 & 4095]($actor)|0);
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($25,2,414824,157,415064,$vararg_buffer5);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = HEAP32[$actor>>2]|0;
 $27 = (($26) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 4095]($actor)|0);
 $30 = ($29|0)==(4);
 if ($30) {
  $31 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($31,2,414824,163,415144,$vararg_buffer5);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = (($actor) + 4|0);
 $33 = HEAP16[$32>>1]|0;
 $34 = $33&65535;
 $35 = (414264 + ($34<<2)|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($actor) + ($36)|0);
 __ZN5physx7NpActor12setAggregateEPNS_11NpAggregateERNS_7PxActorE($37,$this,$actor);
 $38 = HEAP32[$8>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$8>>2] = $39;
 $40 = (($this) + 40|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + ($38<<2)|0);
 HEAP32[$42>>2] = $actor;
 $43 = ($44|0)==(0|0);
 if ($43) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx11NpAggregate16addActorInternalERNS_7PxActorERNS_7NpSceneE($this,$actor,$44);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11NpAggregate22removeActorAndReinsertERNS_7PxActorEb($this,$actor,$reinsert) {
 $this = $this|0;
 $actor = $actor|0;
 $reinsert = $reinsert|0;
 var $$0 = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = (($this) + 40|0);
   $4 = HEAP32[$3>>2]|0;
   $i$04 = 0;
   while(1) {
    $7 = (($4) + ($i$04<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==($actor|0);
    $6 = (($i$04) + 1)|0;
    if ($9) {
     break;
    }
    $5 = ($6>>>0)<($1>>>0);
    if ($5) {
     $i$04 = $6;
    } else {
     break L1;
    }
   }
   $10 = (($1) + -1)|0;
   HEAP32[$0>>2] = $10;
   $11 = (($4) + ($10<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$7>>2] = $12;
   $13 = (($this) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $14 >>> 30;
   $$off$i$i = (($15) + -1)|0;
   $16 = ($$off$i$i>>>0)<(2);
   if ($16) {
    $17 = (($this) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     (__ZN5physx3Scb5Scene10getPxSceneEv($18)|0);
    }
   }
   $20 = (($actor) + 4|0);
   $21 = HEAP16[$20>>1]|0;
   $22 = $21&65535;
   $23 = (414264 + ($22<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($actor) + ($24)|0);
   $26 = ((414264 + ($22<<2)|0) + 68|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($actor) + ($27)|0);
   __ZN5physx7NpActor12setAggregateEPNS_11NpAggregateERNS_7PxActorE($25,0,$actor);
   $29 = (($this) + 8|0);
   __ZN5physx3Scb9Aggregate11removeActorERNS0_5ActorEb($29,$28,$reinsert);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $30 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($30,2,414824,194,415240,$vararg_buffer);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11NpAggregate11removeActorERNS_7PxActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $$0 = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
  }
 }
 $7 = HEAP32[$actor>>2]|0;
 $8 = (($7) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($actor)|0);
 $11 = ($10|0)==(4);
 if ($11) {
  $12 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($12,2,414824,206,415312,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $13 = (__ZN5physx11NpAggregate22removeActorAndReinsertERNS_7PxActorEb($this,$actor,1)|0);
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx11NpAggregate15addArticulationERNS_14PxArticulationE($this,$art) {
 $this = $this|0;
 $art = $art|0;
 var $$0 = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer3 = sp;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $61 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $61 = $7;
  }
 } else {
  $61 = 0;
 }
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$art>>2]|0;
 $11 = (($10) + 108|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($art)|0);
 $14 = (($13) + ($9))|0;
 $15 = (($this) + 8|0);
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($14>>>0)>($17>>>0);
 if ($18) {
  $19 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($19,2,414824,227,415400,$vararg_buffer3);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$art>>2]|0;
 $21 = (($20) + 128|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_ii[$22 & 4095]($art)|0);
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($25,2,414824,233,415472,$vararg_buffer3);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = HEAP32[$art>>2]|0;
 $27 = (($26) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 4095]($art)|0);
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($31,2,414824,239,415568,$vararg_buffer3);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = (($art) + 100|0);
 HEAP32[$32>>2] = $this;
 $33 = (($art) + 88|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$art>>2]|0;
 $36 = (($35) + 108|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (FUNCTION_TABLE_ii[$37 & 4095]($art)|0);
 $39 = ($38|0)==(0);
 if (!($39)) {
  $40 = (($this) + 40|0);
  $i$01 = 0;
  while(1) {
   $41 = (($34) + ($i$01<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 4|0);
   $44 = HEAP16[$43>>1]|0;
   $45 = $44&65535;
   $46 = (414264 + ($45<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($42) + ($47)|0);
   __ZN5physx7NpActor12setAggregateEPNS_11NpAggregateERNS_7PxActorE($48,$this,$42);
   $49 = HEAP32[$8>>2]|0;
   $50 = (($49) + 1)|0;
   HEAP32[$8>>2] = $50;
   $51 = HEAP32[$40>>2]|0;
   $52 = (($51) + ($49<<2)|0);
   HEAP32[$52>>2] = $42;
   $53 = (($42) + 48|0);
   __ZN5physx3Scb9Aggregate8addActorERNS0_5ActorE($15,$53);
   $54 = (($i$01) + 1)|0;
   $55 = HEAP32[$art>>2]|0;
   $56 = (($55) + 108|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (FUNCTION_TABLE_ii[$57 & 4095]($art)|0);
   $59 = ($54>>>0)<($58>>>0);
   if ($59) {
    $i$01 = $54;
   } else {
    break;
   }
  }
 }
 $60 = ($61|0)==(0|0);
 if ($60) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx7NpScene23addArticulationInternalERNS_14PxArticulationE($61,$art);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11NpAggregate29removeArticulationAndReinsertERNS_14PxArticulationEb($this,$art,$reinsert) {
 $this = $this|0;
 $art = $art|0;
 $reinsert = $reinsert|0;
 var $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $found$0$off0$lcssa8 = 0, $found$0$off0$ph5 = 0, $found$0$off02 = 0, $idx$0$ph4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   $3 = (($art) + 100|0);
   HEAP32[$3>>2] = 0;
  } else {
   $4 = (($this) + 40|0);
   $5 = (($this) + 12|0);
   $6 = (($this) + 8|0);
   $7 = (($this) + 8|0);
   $found$0$off0$ph5 = 0;$idx$0$ph4 = 0;
   L3: while(1) {
    $found$0$off02 = $found$0$off0$ph5;
    while(1) {
     $8 = HEAP32[$4>>2]|0;
     $9 = (($8) + ($idx$0$ph4<<2)|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = HEAP32[$10>>2]|0;
     $12 = (($11) + 24|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
     $15 = ($14|0)==(4);
     if (!($15)) {
      break;
     }
     $16 = HEAP32[$4>>2]|0;
     $17 = (($16) + ($idx$0$ph4<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + 288|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==($art|0);
     if (!($21)) {
      break;
     }
     $22 = HEAP32[$0>>2]|0;
     $23 = (($22) + -1)|0;
     HEAP32[$0>>2] = $23;
     $24 = (($16) + ($23<<2)|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$17>>2] = $25;
     $26 = HEAP32[$5>>2]|0;
     $27 = $26 >>> 30;
     $$off$i$i = (($27) + -1)|0;
     $28 = ($$off$i$i>>>0)<(2);
     if ($28) {
      $29 = HEAP32[$6>>2]|0;
      $30 = ($29|0)==(0|0);
      if (!($30)) {
       (__ZN5physx3Scb5Scene10getPxSceneEv($29)|0);
      }
     }
     $31 = (($18) + 4|0);
     $32 = HEAP16[$31>>1]|0;
     $33 = $32&65535;
     $34 = (414264 + ($33<<2)|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($18) + ($35)|0);
     $37 = ((414264 + ($33<<2)|0) + 68|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($18) + ($38)|0);
     __ZN5physx7NpActor12setAggregateEPNS_11NpAggregateERNS_7PxActorE($36,0,$18);
     __ZN5physx3Scb9Aggregate11removeActorERNS0_5ActorEb($7,$39,$reinsert);
     $40 = HEAP32[$0>>2]|0;
     $41 = ($idx$0$ph4>>>0)<($40>>>0);
     if ($41) {
      $found$0$off02 = 1;
     } else {
      label = 11;
      break L3;
     }
    }
    $43 = (($idx$0$ph4) + 1)|0;
    $44 = HEAP32[$0>>2]|0;
    $45 = ($43>>>0)<($44>>>0);
    if ($45) {
     $found$0$off0$ph5 = $found$0$off02;$idx$0$ph4 = $43;
    } else {
     label = 13;
     break;
    }
   }
   if ((label|0) == 11) {
    $42 = (($art) + 100|0);
    HEAP32[$42>>2] = 0;
    $found$0$off0$lcssa8 = 1;
    STACKTOP = sp;return ($found$0$off0$lcssa8|0);
   }
   else if ((label|0) == 13) {
    $46 = (($art) + 100|0);
    HEAP32[$46>>2] = 0;
    if ($found$0$off02) {
     $found$0$off0$lcssa8 = 1;
    } else {
     break;
    }
    STACKTOP = sp;return ($found$0$off0$lcssa8|0);
   }
  }
 } while(0);
 $47 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($47,2,414824,289,415664,$vararg_buffer);
 $found$0$off0$lcssa8 = 0;
 STACKTOP = sp;return ($found$0$off0$lcssa8|0);
}
function __ZN5physx11NpAggregate18removeArticulationERNS_14PxArticulationE($this,$art) {
 $this = $this|0;
 $art = $art|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx11NpAggregate29removeArticulationAndReinsertERNS_14PxArticulationEb($this,$art,1)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx11NpAggregate11getNbActorsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx11NpAggregate14getMaxNbActorsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx11NpAggregate9getActorsEPPNS_7PxActorEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($startIndex<<2)|0);
 $5 = (($1) - ($startIndex))|0;
 $6 = ($5|0)<(0);
 $7 = $6 ? 0 : $5;
 $8 = ($7>>>0)<($bufferSize>>>0);
 $9 = $8 ? $7 : $bufferSize;
 $10 = $9 << 2;
 _memcpy(($userBuffer|0),($4|0),($10|0))|0;
 STACKTOP = sp;return ($9|0);
}
function __ZN5physx11NpAggregate8getSceneEv($this) {
 $this = $this|0;
 var $$off$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $8 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $8 = $7;
  }
 } else {
  $8 = 0;
 }
 STACKTOP = sp;return ($8|0);
}
function __ZNK5physx11NpAggregate16getSelfCollisionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx11NpAggregate15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$stream>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($stream,16);
 $6 = HEAP32[$stream>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($this) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 << 2;
 FUNCTION_TABLE_viii[$8 & 4095]($stream,$9,$12);
 STACKTOP = sp;return;
}
function __ZN5physx11NpAggregate8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 40|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 4|0);
  $8 = HEAP16[$7>>1]|0;
  $9 = ($8<<16>>16)!=(15);
  $10 = ($6|0)==(0|0);
  $or$cond = $9 | $10;
  if ($or$cond) {
   $18 = HEAP32[$c>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$20 & 4095]($c,$6);
  } else {
   $11 = HEAP32[$6>>2]|0;
   $12 = (($11) + 224|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_ii[$13 & 4095]($6)|0);
   $15 = HEAP32[$c>>2]|0;
   $16 = (($15) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vii[$17 & 4095]($c,$14);
  }
  $21 = (($i$01) + 1)|0;
  $22 = HEAP32[$0>>2]|0;
  $23 = ($21>>>0)<($22>>>0);
  if ($23) {
   $i$01 = $21;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx11PxAggregate19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (415752|0);
}
function __ZNK5physx11PxAggregate8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(415752,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,415768)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx14NpArticulation8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 88|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$c>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  $8 = (($7) + ($i$01<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($c,$9);
  $10 = (($i$01) + 1)|0;
  $exitcond = ($10|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14NpArticulation15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (($this) + 88|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = (($this) + 92|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==(0);
    $9 = (($this) + 96|0);
    $10 = HEAP32[$9>>2]|0;
    if ($8) {
     $11 = $10 & 2147483647;
     $12 = ($11|0)==(0);
     if ($12) {
      break;
     }
    }
    $13 = HEAP32[$stream>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $10 << 2;
    FUNCTION_TABLE_viii[$15 & 4095]($stream,$4,$16);
   }
  }
 } while(0);
 $17 = HEAP32[$stream>>2]|0;
 $18 = (($17) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 104|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vii[$19 & 4095]($stream,$21);
 STACKTOP = sp;return;
}
function __ZN5physx14NpArticulationC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 14;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 HEAP32[$this>>2] = ((415776 + 8|0));
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 20|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 __ZN5physx2Sc16ArticulationCoreC2Ev($5);
 $6 = HEAP32[$4>>2]|0;
 $7 = $6 & -251658241;
 $8 = $7 | 134217728;
 HEAP32[$4>>2] = $8;
 $9 = (Math_fround(__ZNK5physx2Sc16ArticulationCore14getWakeCounterEv($5)));
 $10 = (($this) + 60|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($this) + 64|0);
 HEAP8[$11>>0] = 1;
 $12 = (($this) + 68|0);
 $13 = (($this) + 84|0);
 $14 = (($this) + 88|0);
 $15 = (($this) + 92|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 96|0);
 HEAP8[$13>>0] = 1;
 HEAP32[$14>>2] = $12;
 HEAP32[$16>>2] = 4;
 $17 = (($this) + 100|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 104|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 8|0);
 HEAP32[$19>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx14NpArticulationD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((415776 + 8|0));
 $1 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory21onArticulationReleaseEPNS_14PxArticulationE($1,$this);
 $2 = (($this) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4|0)!=(0);
 $6 = ($3|0)>(-1);
 $or$cond$i$i$i$i$i = $5 & $6;
 do {
  if ($or$cond$i$i$i$i$i) {
   $7 = (($this) + 88|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 68|0);
   $10 = ($9|0)==($8|0);
   if ($10) {
    $11 = (($this) + 84|0);
    HEAP8[$11>>0] = 0;
    break;
   }
   $12 = ($8|0)==(0|0);
   if (!($12)) {
    $13 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($14) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    FUNCTION_TABLE_vii[$16 & 4095]($13,$8);
   }
  }
 } while(0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx14NpArticulationD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((415776 + 8|0));
 $0 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory21onArticulationReleaseEPNS_14PxArticulationE($0,$this);
 $1 = (($this) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3|0)!=(0);
 $5 = ($2|0)>(-1);
 $or$cond$i$i$i$i = $4 & $5;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = ($8|0)==($7|0);
 if ($9) {
  $10 = (($this) + 84|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $11 = ($7|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($12,$7);
 STACKTOP = sp;return;
}
function __ZN5physx14NpArticulation7releaseEv($this) {
 $this = $this|0;
 var $$c = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$0$be = 0, $idx$01 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (($this) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($this) + 88|0);
  $8 = $4;$idx$01 = 0;
  while(1) {
   $7 = (($idx$01>>>0) % ($8>>>0))&-1;
   $9 = HEAP32[$6>>2]|0;
   $10 = (($9) + ($7<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 232|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = HEAP32[$6>>2]|0;
    $18 = (($17) + ($7<<2)|0);
    $19 = HEAP32[$18>>2]|0;
    __ZN5physx18NpArticulationLink15releaseInternalEv($19);
    $idx$0$be = $7;
   } else {
    $20 = (($7) + 1)|0;
    $idx$0$be = $20;
   }
   $21 = HEAP32[$3>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    break;
   } else {
    $8 = $21;$idx$01 = $idx$0$be;
   }
  }
 }
 $23 = (($this) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 >>> 30;
 $$off$i$i = (($25) + -1)|0;
 $26 = ($$off$i$i>>>0)<(2);
 if ($26) {
  $27 = (($this) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = (__ZN5physx3Scb5Scene10getPxSceneEv($28)|0);
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    $32 = (($30) + 16|0);
    $33 = (($this) + 12|0);
    __ZN5physx3Scb5Scene18removeArticulationERNS0_12ArticulationE($32,$33);
    $34 = (($30) + 3552|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==(0);
    if (!($36)) {
     $37 = (($30) + 3548|0);
     $38 = HEAP32[$37>>2]|0;
     $index$01$i$i = 0;
     while(1) {
      $41 = (($38) + ($index$01$i$i<<2)|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==($this|0);
      $40 = (($index$01$i$i) + 1)|0;
      if ($43) {
       $index$0$lcssa$i$i = $index$01$i$i;
       break;
      }
      $39 = ($40>>>0)<($35>>>0);
      if ($39) {
       $index$01$i$i = $40;
      } else {
       $index$0$lcssa$i$i = $40;
       break;
      }
     }
     $44 = ($index$0$lcssa$i$i|0)==($35|0);
     if (!($44)) {
      $45 = (($35) + -1)|0;
      $$c = $45;
      HEAP32[$34>>2] = $$c;
      $46 = (($38) + ($45<<2)|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = (($38) + ($index$0$lcssa$i$i<<2)|0);
      HEAP32[$48>>2] = $47;
     }
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $49 = (($this) + 12|0);
 __ZN5physx3Scb4Base7destroyEv($49);
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation8getSceneEv($this) {
 $this = $this|0;
 var $$off$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $8 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $8 = $7;
  }
 } else {
  $8 = 0;
 }
 STACKTOP = sp;return ($8|0);
}
function __ZNK5physx14NpArticulation26getInternalDriveIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 24|0);
  $15 = (__ZNK5physx2Sc16ArticulationCore26getInternalDriveIterationsEv($14)|0);
  $16 = $15;
  STACKTOP = sp;return ($16|0);
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = HEAP32[$13>>2]|0;
 $16 = $12;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx14NpArticulation26setInternalDriveIterationsEj($this,$iterations) {
 $this = $this|0;
 $iterations = $iterations|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 24|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc16ArticulationCore26setInternalDriveIterationsEj($1,$iterations);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $16 = $15;
 } else {
  $16 = $10;
 }
 HEAP32[$16>>2] = $iterations;
 $17 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($17,$0);
 $18 = HEAP32[$2>>2]|0;
 $19 = $18 | 1;
 HEAP32[$2>>2] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation26getExternalDriveIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 24|0);
  $16 = (__ZNK5physx2Sc16ArticulationCore26getExternalDriveIterationsEv($15)|0);
  $17 = $16;
  STACKTOP = sp;return ($17|0);
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 4|0);
 $14 = HEAP32[$12>>2]|0;
 $17 = $14;
 STACKTOP = sp;return ($17|0);
}
function __ZN5physx14NpArticulation26setExternalDriveIterationsEj($this,$iterations) {
 $this = $this|0;
 $iterations = $iterations|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 24|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc16ArticulationCore26setExternalDriveIterationsEj($1,$iterations);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 4|0);
 HEAP32[$16>>2] = $iterations;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 2;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation26getMaxProjectionIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 24|0);
  $16 = (__ZNK5physx2Sc16ArticulationCore26getMaxProjectionIterationsEv($15)|0);
  $17 = $16;
  STACKTOP = sp;return ($17|0);
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 8|0);
 $14 = HEAP32[$12>>2]|0;
 $17 = $14;
 STACKTOP = sp;return ($17|0);
}
function __ZN5physx14NpArticulation26setMaxProjectionIterationsEj($this,$iterations) {
 $this = $this|0;
 $iterations = $iterations|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 24|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc16ArticulationCore26setMaxProjectionIterationsEj($1,$iterations);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 8|0);
 HEAP32[$16>>2] = $iterations;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 4;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation22getSeparationToleranceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 8;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 24|0);
  $16 = (Math_fround(__ZNK5physx2Sc16ArticulationCore22getSeparationToleranceEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 12|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx14NpArticulation22setSeparationToleranceEf($this,$tolerance) {
 $this = $this|0;
 $tolerance = Math_fround($tolerance);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 24|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc16ArticulationCore22setSeparationToleranceEf($1,$tolerance);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 12|0);
 HEAPF32[$16>>2] = $tolerance;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 8;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN5physx14NpArticulation24setSolverIterationCountsEjj($this,$positionIters,$velocityIters) {
 $this = $this|0;
 $positionIters = $positionIters|0;
 $velocityIters = $velocityIters|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = $velocityIters << 8;
 $2 = $positionIters & 255;
 $3 = $1 | $2;
 $4 = $3&65535;
 $5 = (($this) + 24|0);
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 30;
 if ((($8|0) == 2)) {
  $9 = HEAP32[$0>>2]|0;
  $10 = (($9) + 2417|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($8|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc16ArticulationCore24setSolverIterationCountsEt($5,$4);
  STACKTOP = sp;return;
 }
 $13 = (($this) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  $16 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $17 = $7 >>> 24;
  $18 = $17 & 15;
  $19 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($16,$18)|0);
  HEAP32[$13>>2] = $19;
  $21 = $19;
 } else {
  $21 = $14;
 }
 $20 = (($21) + 20|0);
 HEAP16[$20>>1] = $4;
 $22 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($22,$0);
 $23 = HEAP32[$6>>2]|0;
 $24 = $23 | 32;
 HEAP32[$6>>2] = $24;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation24getSolverIterationCountsERjS1_($this,$positionIters,$velocityIters) {
 $this = $this|0;
 $positionIters = $positionIters|0;
 $velocityIters = $velocityIters|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 24|0);
  $16 = (__ZNK5physx2Sc16ArticulationCore24getSolverIterationCountsEv($15)|0);
  $18 = $16;
 } else {
  $4 = (($this) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 20|0);
  $14 = HEAP16[$12>>1]|0;
  $18 = $14;
 }
 $17 = $18&65535;
 $19 = $17 >>> 8;
 HEAP32[$velocityIters>>2] = $19;
 $20 = $17 & 255;
 HEAP32[$positionIters>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation10isSleepingEv($this) {
 $this = $this|0;
 var $$off$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
  }
 }
 $7 = (($this) + 64|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 STACKTOP = sp;return ($9|0);
}
function __ZN5physx14NpArticulation17setSleepThresholdEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 24|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc16ArticulationCore17setSleepThresholdEf($1,$threshold);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 16|0);
 HEAPF32[$16>>2] = $threshold;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 16;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation17getSleepThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 24|0);
  $16 = (Math_fround(__ZNK5physx2Sc16ArticulationCore17getSleepThresholdEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 16|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx14NpArticulation25setStabilizationThresholdEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 24|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc16ArticulationCore17setSleepThresholdEf($1,$threshold);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 16|0);
 HEAPF32[$16>>2] = $threshold;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 16;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation25getStabilizationThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 24|0);
  $16 = (Math_fround(__ZNK5physx2Sc16ArticulationCore17getSleepThresholdEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 16|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx14NpArticulation14setWakeCounterEf($this,$wakeCounterValue) {
 $this = $this|0;
 $wakeCounterValue = Math_fround($wakeCounterValue);
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 88|0);
  $i$01 = 0;
  while(1) {
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + ($i$01<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 48|0);
   __ZN5physx3Scb4Body14setWakeCounterEf($7,$wakeCounterValue);
   $8 = (($i$01) + 1)|0;
   $9 = HEAP32[$0>>2]|0;
   $10 = ($8>>>0)<($9>>>0);
   if ($10) {
    $i$01 = $8;
   } else {
    break;
   }
  }
 }
 $11 = (($this) + 12|0);
 $12 = (($this) + 60|0);
 HEAPF32[$12>>2] = $wakeCounterValue;
 $13 = (($this) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 >>> 30;
 if ((($15|0) == 2)) {
  $16 = HEAP32[$11>>2]|0;
  $17 = (($16) + 2416|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $21 = $16;
   label = 7;
  }
 } else if (!((($15|0) == 3))) {
  $$pre$i = HEAP32[$11>>2]|0;
  $21 = $$pre$i;
  label = 7;
 }
 if ((label|0) == 7) {
  $20 = ($21|0)!=(0|0);
  $22 = $wakeCounterValue > Math_fround(0.0);
  $or$cond$i = $20 & $22;
  if ($or$cond$i) {
   $23 = (($this) + 64|0);
   HEAP8[$23>>0] = 0;
  }
  $24 = (($this) + 24|0);
  __ZN5physx2Sc16ArticulationCore14setWakeCounterEf($24,$wakeCounterValue);
  STACKTOP = sp;return;
 }
 $25 = $wakeCounterValue > Math_fround(0.0);
 if ($25) {
  $26 = (($this) + 64|0);
  HEAP8[$26>>0] = 0;
  $27 = HEAP32[$11>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($27,$11);
  $28 = HEAP32[$13>>2]|0;
  $29 = $28 & -897;
  $30 = $29 | 640;
  HEAP32[$13>>2] = $30;
  STACKTOP = sp;return;
 } else {
  $31 = HEAP32[$11>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($31,$11);
  $32 = HEAP32[$13>>2]|0;
  $33 = $32 | 128;
  HEAP32[$13>>2] = $33;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb4Body14setWakeCounterEf($this,$w) {
 $this = $this|0;
 $w = Math_fround($w);
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 228|0);
 HEAPF32[$0>>2] = $w;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 if ((($3|0) == 2)) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 2416|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   $9 = $4;
   label = 4;
  }
 } else if (!((($3|0) == 3))) {
  $$pre = HEAP32[$this>>2]|0;
  $9 = $$pre;
  label = 4;
 }
 if ((label|0) == 4) {
  $8 = ($9|0)!=(0|0);
  $10 = $w > Math_fround(0.0);
  $or$cond = $8 & $10;
  if ($or$cond) {
   $11 = (($this) + 232|0);
   HEAP32[$11>>2] = 0;
  }
  $12 = (($this) + 16|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($12,$w,0);
  STACKTOP = sp;return;
 }
 $13 = $w > Math_fround(0.0);
 if (!($13)) {
  $26 = HEAP32[$this>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($26,$this);
  $27 = (($this) + 236|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 | 1048576;
  HEAP32[$27>>2] = $29;
  STACKTOP = sp;return;
 }
 if ((($3|0) == 2)) {
  $14 = HEAP32[$this>>2]|0;
  $15 = (($14) + 2416|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   label = 11;
  } else {
   $21 = $14;
   label = 12;
  }
 } else if ((($3|0) == 3)) {
  $$pre$i = HEAP32[$this>>2]|0;
  $21 = $$pre$i;
  label = 12;
 } else {
  label = 11;
 }
 if ((label|0) == 11) {
  $18 = (($this) + 232|0);
  HEAP32[$18>>2] = 0;
  HEAPF32[$0>>2] = $w;
  $19 = (($this) + 16|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($19,$w,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  $20 = (($this) + 232|0);
  HEAP32[$20>>2] = 0;
  HEAPF32[$0>>2] = $w;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($21,$this);
  $22 = (($this) + 236|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & -7340033;
  $25 = $24 | 5242880;
  HEAP32[$22>>2] = $25;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx14NpArticulation14getWakeCounterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx14NpArticulation14wakeUpInternalEbb($this,$forceWakeUp,$autowake) {
 $this = $this|0;
 $forceWakeUp = $forceWakeUp|0;
 $autowake = $autowake|0;
 var $$forceWakeUp = 0, $$forceWakeUp$ = 0, $$pre$i = 0, $$pre$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $i$09 = 0, $needsWakingUp$0$off0 = 0;
 var $or$cond = 0, $wakeCounter$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx3Scb5Scene10getPxSceneEv($1)|0);
 $3 = (($2) + 2860|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 12|0);
 $6 = (($this) + 60|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
 $$forceWakeUp = $autowake | $forceWakeUp;
 $$forceWakeUp$ = $11 & $$forceWakeUp;
 $12 = $7 < $4;
 $or$cond = $12 & $autowake;
 $wakeCounter$0 = $or$cond ? $4 : $7;
 $needsWakingUp$0$off0 = $or$cond | $$forceWakeUp$;
 if (!($needsWakingUp$0$off0)) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 92|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = (($this) + 88|0);
  $i$09 = 0;
  while(1) {
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + ($i$09<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 48|0);
   $21 = (($19) + 52|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = $22 >>> 30;
   if ((($23|0) == 3)) {
    $$pre$i4 = HEAP32[$20>>2]|0;
    $33 = $$pre$i4;
    label = 8;
   } else if ((($23|0) == 2)) {
    $24 = HEAP32[$20>>2]|0;
    $25 = (($24) + 2416|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     label = 7;
    } else {
     $33 = $24;
     label = 8;
    }
   } else {
    label = 7;
   }
   if ((label|0) == 7) {
    label = 0;
    $28 = (($19) + 280|0);
    HEAP32[$28>>2] = 0;
    $29 = (($19) + 276|0);
    HEAPF32[$29>>2] = $wakeCounter$0;
    $30 = (($19) + 64|0);
    __ZN5physx2Sc8BodyCore14setWakeCounterEfb($30,$wakeCounter$0,1);
   }
   else if ((label|0) == 8) {
    label = 0;
    $31 = (($19) + 280|0);
    HEAP32[$31>>2] = 0;
    $32 = (($19) + 276|0);
    HEAPF32[$32>>2] = $wakeCounter$0;
    __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($33,$20);
    $34 = (($19) + 284|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $35 & -7340033;
    $37 = $36 | 5242880;
    HEAP32[$34>>2] = $37;
   }
   $38 = (($i$09) + 1)|0;
   $39 = HEAP32[$13>>2]|0;
   $40 = ($38>>>0)<($39>>>0);
   if ($40) {
    $i$09 = $38;
   } else {
    break;
   }
  }
 }
 HEAPF32[$6>>2] = $wakeCounter$0;
 $41 = (($this) + 64|0);
 HEAP8[$41>>0] = 0;
 $42 = (($this) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 >>> 30;
 if ((($44|0) == 2)) {
  $45 = HEAP32[$5>>2]|0;
  $46 = (($45) + 2416|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   label = 13;
  } else {
   $50 = $45;
   label = 14;
  }
 } else if ((($44|0) == 3)) {
  $$pre$i = HEAP32[$5>>2]|0;
  $50 = $$pre$i;
  label = 14;
 } else {
  label = 13;
 }
 if ((label|0) == 13) {
  $49 = (($this) + 24|0);
  __ZN5physx2Sc16ArticulationCore6wakeUpEf($49,$wakeCounter$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($50,$5);
  $51 = HEAP32[$42>>2]|0;
  $52 = $51 & -897;
  $53 = $52 | 640;
  HEAP32[$42>>2] = $53;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpArticulation6wakeUpEv($this) {
 $this = $this|0;
 var $$off$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $13 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $13 = $7;
  }
 } else {
  $13 = 0;
 }
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (($this) + 88|0);
  $12 = (($13) + 2860|0);
  $i$01 = 0;
  while(1) {
   $14 = HEAP32[$11>>2]|0;
   $15 = (($14) + ($i$01<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 48|0);
   $18 = Math_fround(HEAPF32[$12>>2]);
   $19 = (($16) + 52|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20 >>> 30;
   if ((($21|0) == 2)) {
    $22 = HEAP32[$17>>2]|0;
    $23 = (($22) + 2416|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     label = 9;
    } else {
     $31 = $22;
     label = 10;
    }
   } else if ((($21|0) == 3)) {
    $$pre$i = HEAP32[$17>>2]|0;
    $31 = $$pre$i;
    label = 10;
   } else {
    label = 9;
   }
   if ((label|0) == 9) {
    label = 0;
    $26 = (($16) + 280|0);
    HEAP32[$26>>2] = 0;
    $27 = (($16) + 276|0);
    HEAPF32[$27>>2] = $18;
    $28 = (($16) + 64|0);
    __ZN5physx2Sc8BodyCore14setWakeCounterEfb($28,$18,1);
   }
   else if ((label|0) == 10) {
    label = 0;
    $29 = (($16) + 280|0);
    HEAP32[$29>>2] = 0;
    $30 = (($16) + 276|0);
    HEAPF32[$30>>2] = $18;
    __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($31,$17);
    $32 = (($16) + 284|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = $33 & -7340033;
    $35 = $34 | 5242880;
    HEAP32[$32>>2] = $35;
   }
   $36 = (($i$01) + 1)|0;
   $37 = HEAP32[$8>>2]|0;
   $38 = ($36>>>0)<($37>>>0);
   if ($38) {
    $i$01 = $36;
   } else {
    break;
   }
  }
 }
 $39 = (($this) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 2844|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 60|0);
 HEAPF32[$43>>2] = $42;
 $44 = (($this) + 64|0);
 HEAP8[$44>>0] = 0;
 $45 = HEAP32[$0>>2]|0;
 $46 = $45 >>> 30;
 if ((($46|0) == 3)) {
  label = 15;
 } else if ((($46|0) == 2)) {
  $47 = (($40) + 2416|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48<<24>>24)==(0);
  if ($49) {
   label = 14;
  } else {
   label = 15;
  }
 } else {
  label = 14;
 }
 if ((label|0) == 14) {
  $50 = (($this) + 24|0);
  __ZN5physx2Sc16ArticulationCore6wakeUpEf($50,$42);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($40,$39);
  $51 = HEAP32[$0>>2]|0;
  $52 = $51 & -897;
  $53 = $52 | 640;
  HEAP32[$0>>2] = $53;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpArticulation10putToSleepEv($this) {
 $this = $this|0;
 var $$off$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
  }
 }
 $7 = (($this) + 92|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($this) + 88|0);
  $i$01 = 0;
  while(1) {
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + ($i$01<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 48|0);
   __ZN5physx3Scb4Body18putToSleepInternalEv($14);
   $15 = (($i$01) + 1)|0;
   $16 = HEAP32[$7>>2]|0;
   $17 = ($15>>>0)<($16>>>0);
   if ($17) {
    $i$01 = $15;
   } else {
    break;
   }
  }
 }
 $18 = (($this) + 12|0);
 $19 = (($this) + 60|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($this) + 64|0);
 HEAP8[$20>>0] = 1;
 $21 = HEAP32[$0>>2]|0;
 $22 = $21 >>> 30;
 if ((($22|0) == 3)) {
  $$pre$i = HEAP32[$18>>2]|0;
  $28 = $$pre$i;
  label = 11;
 } else if ((($22|0) == 2)) {
  $23 = HEAP32[$18>>2]|0;
  $24 = (($23) + 2416|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   label = 10;
  } else {
   $28 = $23;
   label = 11;
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = (($this) + 24|0);
  __ZN5physx2Sc16ArticulationCore10putToSleepEv($27);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$18);
  $29 = HEAP32[$0>>2]|0;
  $30 = $29 & -897;
  $31 = $30 | 384;
  HEAP32[$0>>2] = $31;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb4Body18putToSleepInternalEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i2 = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 2416|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   label = 3;
  }
 } else if (!((($2|0) == 3))) {
  label = 3;
 }
 if ((label|0) == 3) {
  $7 = (($this) + 232|0);
  HEAP32[$7>>2] = 1;
  $8 = (($this) + 204|0);
  ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;
  $9 = (($this) + 16|0);
  __ZN5physx2Sc8BodyCore10putToSleepEv($9);
  STACKTOP = sp;return;
 }
 $10 = (($this) + 232|0);
 HEAP32[$10>>2] = 1;
 $11 = (($this) + 228|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 204|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 208|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($this) + 212|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 if ((($2|0) == 3)) {
  $$pre$i2 = HEAP32[$this>>2]|0;
  $22 = $$pre$i2;
  label = 8;
 } else if ((($2|0) == 2)) {
  $15 = HEAP32[$this>>2]|0;
  $16 = (($15) + 2416|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   label = 7;
  } else {
   $22 = $15;
   label = 8;
  }
 } else {
  label = 7;
 }
 if ((label|0) == 7) {
  $19 = (($this) + 96|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = (($this) + 100|0);
  HEAPF32[$20>>2] = Math_fround(0.0);
  $21 = (($this) + 104|0);
  HEAPF32[$21>>2] = Math_fround(0.0);
  $30 = $1;
 }
 else if ((label|0) == 8) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($22,$this);
  $23 = (($this) + 236|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 | 262144;
  HEAP32[$23>>2] = $25;
  $$pre = HEAP32[$0>>2]|0;
  $30 = $$pre;
 }
 $26 = (($this) + 216|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 220|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 224|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = $30 >>> 30;
 if ((($29|0) == 3)) {
  $$pre$i = HEAP32[$this>>2]|0;
  $38 = $$pre$i;
  label = 13;
 } else if ((($29|0) == 2)) {
  $31 = HEAP32[$this>>2]|0;
  $32 = (($31) + 2416|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   label = 12;
  } else {
   $38 = $31;
   label = 13;
  }
 } else {
  label = 12;
 }
 if ((label|0) == 12) {
  $35 = (($this) + 112|0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  $36 = (($this) + 116|0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $37 = (($this) + 120|0);
  HEAPF32[$37>>2] = Math_fround(0.0);
  $$phi$trans$insert = (($this) + 236|0);
  $$pre11 = HEAP32[$$phi$trans$insert>>2]|0;
  $44 = $$pre11;
 }
 else if ((label|0) == 13) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($38,$this);
  $39 = (($this) + 236|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 | 524288;
  HEAP32[$39>>2] = $41;
  $44 = $41;
 }
 $42 = (($this) + 236|0);
 $43 = $44 & -57345;
 HEAP32[$42>>2] = $43;
 $45 = HEAP32[$this>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($45,$this);
 $46 = HEAP32[$42>>2]|0;
 $47 = $46 & -7340033;
 $48 = $47 | 3145728;
 HEAP32[$42>>2] = $48;
 STACKTOP = sp;return;
}
function __ZN5physx14NpArticulation10createLinkEPNS_18PxArticulationLinkERKNS_11PxTransformE($this,$parent,$pose) {
 $this = $this|0;
 $parent = $parent|0;
 $pose = $pose|0;
 var $$0 = 0, $$off$i$i = 0, $$off$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0);
 var $9 = Math_fround(0), $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer1 = sp;
 $0 = sp + 4|0;
 $1 = ($parent|0)==(0|0);
 $2 = (($this) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($1) {
  if (!($4)) {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,415944,348,416080,$vararg_buffer1);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  if ($4) {
   $5 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($5,8,415944,342,416024,$vararg_buffer1);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $7 = HEAP32[420520>>2]|0;
 $8 = Math_fround(HEAPF32[$pose>>2]);
 $9 = Math_fround($8 * $8);
 $10 = (($pose) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (($pose) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $15);
 $17 = Math_fround($13 + $16);
 $18 = (($pose) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (Math_fround(Math_sqrt((Math_fround($21)))));
 $23 = Math_fround(Math_fround(1.0) / $22);
 $24 = Math_fround($8 * $23);
 $25 = Math_fround($11 * $23);
 $26 = Math_fround($15 * $23);
 $27 = Math_fround($19 * $23);
 HEAPF32[$0>>2] = $24;
 $28 = (($0) + 4|0);
 HEAPF32[$28>>2] = $25;
 $29 = (($0) + 8|0);
 HEAPF32[$29>>2] = $26;
 $30 = (($0) + 12|0);
 HEAPF32[$30>>2] = $27;
 $31 = (($0) + 16|0);
 $32 = (($pose) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($0) + 20|0);
 $35 = (($pose) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 $37 = (($0) + 24|0);
 $38 = (($pose) + 24|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$37>>2] = $39;
 $40 = (__ZN5physx9NpFactory22createArticulationLinkERNS_14NpArticulationEPNS_18NpArticulationLinkERKNS_11PxTransformE($7,$this,$parent,$0)|0);
 $41 = ($40|0)==(0|0);
 if ($41) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = (($this) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 >>> 30;
 $$off$i$i1 = (($44) + -1)|0;
 $45 = ($$off$i$i1>>>0)<(2);
 if (!($45)) {
  $$0 = $40;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = (($this) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  $$0 = $40;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = (__ZN5physx3Scb5Scene10getPxSceneEv($47)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $$0 = $40;
  STACKTOP = sp;return ($$0|0);
 }
 $51 = HEAP32[$42>>2]|0;
 $52 = $51 >>> 30;
 $$off$i$i = (($52) + -1)|0;
 $53 = ($$off$i$i>>>0)<(2);
 if ($53) {
  $54 = HEAP32[$46>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $57 = 0;
  } else {
   $56 = (__ZN5physx3Scb5Scene10getPxSceneEv($54)|0);
   $57 = $56;
  }
 } else {
  $57 = 0;
 }
 __ZN5physx7NpScene19addArticulationLinkERNS_18NpArticulationLinkE($57,$40);
 $$0 = $40;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx14NpArticulation10getNbLinksEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx14NpArticulation8getLinksEPPNS_18PxArticulationLinkEj($this,$buffer,$bufferSize) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($bufferSize>>>0);
 $3 = $2 ? $1 : $bufferSize;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = (($this) + 88|0);
 $6 = $1 ^ -1;
 $7 = $bufferSize ^ -1;
 $8 = ($6>>>0)>($7>>>0);
 $umax = $8 ? $6 : $7;
 $9 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$5>>2]|0;
  $11 = (($10) + ($i$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($buffer) + ($i$01<<2)|0);
  HEAP32[$13>>2] = $12;
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($9|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $14;
  }
 }
 STACKTOP = sp;return ($3|0);
}
function __ZNK5physx14NpArticulation14getWorldBoundsEf($agg$result,$this,$inflation) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inflation = Math_fround($inflation);
 var $$lcssa = Math_fround(0), $$lcssa1 = Math_fround(0), $$lcssa2 = Math_fround(0), $$lcssa3 = Math_fround(0), $$lcssa4 = Math_fround(0), $$lcssa5 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$lcssa = Math_fround(-8.50705866596322149529E+37);$$lcssa1 = Math_fround(-8.50705866596322149529E+37);$$lcssa2 = Math_fround(-8.50705866596322149529E+37);$$lcssa3 = Math_fround(8.50705866596322149529E+37);$$lcssa4 = Math_fround(8.50705866596322149529E+37);$$lcssa5 = Math_fround(8.50705866596322149529E+37);
 } else {
  $4 = (($this) + 88|0);
  $5 = (($0) + 4|0);
  $6 = (($0) + 8|0);
  $7 = (($0) + 12|0);
  $8 = (($0) + 16|0);
  $9 = (($0) + 20|0);
  $18 = Math_fround(8.50705866596322149529E+37);$22 = Math_fround(8.50705866596322149529E+37);$26 = Math_fround(8.50705866596322149529E+37);$30 = Math_fround(-8.50705866596322149529E+37);$34 = Math_fround(-8.50705866596322149529E+37);$38 = Math_fround(-8.50705866596322149529E+37);$i$06 = 0;
  while(1) {
   $10 = HEAP32[$4>>2]|0;
   $11 = (($10) + ($i$06<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 40|0);
   $15 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_viif[$15 & 63]($0,$12,Math_fround(1.00999999046325683594));
   $16 = Math_fround(HEAPF32[$0>>2]);
   $17 = $18 < $16;
   $19 = $17 ? $18 : $16;
   $20 = Math_fround(HEAPF32[$5>>2]);
   $21 = $22 < $20;
   $23 = $21 ? $22 : $20;
   $24 = Math_fround(HEAPF32[$6>>2]);
   $25 = $26 < $24;
   $27 = $25 ? $26 : $24;
   $28 = Math_fround(HEAPF32[$7>>2]);
   $29 = $30 > $28;
   $31 = $29 ? $30 : $28;
   $32 = Math_fround(HEAPF32[$8>>2]);
   $33 = $34 > $32;
   $35 = $33 ? $34 : $32;
   $36 = Math_fround(HEAPF32[$9>>2]);
   $37 = $38 > $36;
   $39 = $37 ? $38 : $36;
   $40 = (($i$06) + 1)|0;
   $41 = HEAP32[$1>>2]|0;
   $42 = ($40>>>0)<($41>>>0);
   if ($42) {
    $18 = $19;$22 = $23;$26 = $27;$30 = $31;$34 = $35;$38 = $39;$i$06 = $40;
   } else {
    $$lcssa = $39;$$lcssa1 = $35;$$lcssa2 = $31;$$lcssa3 = $27;$$lcssa4 = $23;$$lcssa5 = $19;
    break;
   }
  }
 }
 $43 = Math_fround($$lcssa2 + $$lcssa5);
 $44 = Math_fround($$lcssa1 + $$lcssa4);
 $45 = Math_fround($$lcssa + $$lcssa3);
 $46 = Math_fround($43 * Math_fround(0.5));
 $47 = Math_fround($44 * Math_fround(0.5));
 $48 = Math_fround($45 * Math_fround(0.5));
 $49 = Math_fround($$lcssa2 - $$lcssa5);
 $50 = Math_fround($$lcssa1 - $$lcssa4);
 $51 = Math_fround($$lcssa - $$lcssa3);
 $52 = Math_fround($49 * Math_fround(0.5));
 $53 = Math_fround($50 * Math_fround(0.5));
 $54 = Math_fround($51 * Math_fround(0.5));
 $55 = Math_fround($52 * $inflation);
 $56 = Math_fround($53 * $inflation);
 $57 = Math_fround($54 * $inflation);
 $58 = Math_fround($46 - $55);
 $59 = Math_fround($47 - $56);
 $60 = Math_fround($48 - $57);
 $61 = Math_fround($46 + $55);
 $62 = Math_fround($47 + $56);
 $63 = Math_fround($48 + $57);
 HEAPF32[$agg$result>>2] = $58;
 $64 = (($agg$result) + 4|0);
 HEAPF32[$64>>2] = $59;
 $65 = (($agg$result) + 8|0);
 HEAPF32[$65>>2] = $60;
 $66 = (($agg$result) + 12|0);
 HEAPF32[$66>>2] = $61;
 $67 = (($agg$result) + 16|0);
 HEAPF32[$67>>2] = $62;
 $68 = (($agg$result) + 20|0);
 HEAPF32[$68>>2] = $63;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation12getAggregateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx14NpArticulation7setNameEPKc($this,$debugName) {
 $this = $this|0;
 $debugName = $debugName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 HEAP32[$0>>2] = $debugName;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx14NpArticulation9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$scene) {
 $this = $this|0;
 $out = $out|0;
 $scene = $scene|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 88|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN5physx18NpArticulationLink9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($6,$out,$scene);
  $7 = (($i$01) + 1)|0;
  $8 = HEAP32[$0>>2]|0;
  $9 = ($7>>>0)<($8>>>0);
  if ($9) {
   $i$01 = $7;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation16createDriveCacheEfj($this,$compliance,$driveIterations) {
 $this = $this|0;
 $compliance = Math_fround($compliance);
 $driveIterations = $driveIterations|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = (__ZNK5physx2Sc16ArticulationCore16createDriveCacheEfj($0,$compliance,$driveIterations)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx14NpArticulation16updateDriveCacheERNS_24PxArticulationDriveCacheEfj($this,$cache,$compliance,$driveIterations) {
 $this = $this|0;
 $cache = $cache|0;
 $compliance = Math_fround($compliance);
 $driveIterations = $driveIterations|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 __ZNK5physx2Sc16ArticulationCore16updateDriveCacheERNS_9PxcFsDataEfj($0,$cache,$compliance,$driveIterations);
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation17releaseDriveCacheERNS_24PxArticulationDriveCacheE($this,$cache) {
 $this = $this|0;
 $cache = $cache|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 __ZNK5physx2Sc16ArticulationCore17releaseDriveCacheERNS_9PxcFsDataE($0,$cache);
 STACKTOP = sp;return;
}
function __ZN5physx14NpArticulation12applyImpulseEPNS_18PxArticulationLinkERKNS_24PxArticulationDriveCacheERKNS_6PxVec3ES8_($this,$link,$driveCache,$force,$torque) {
 $this = $this|0;
 $link = $link|0;
 $driveCache = $driveCache|0;
 $force = $force|0;
 $torque = $torque|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $av = 0, $i$01 = 0, $lv = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $lv = sp + 12|0;
 $av = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if ($3) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 96|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($this);
 }
 $7 = (($this) + 24|0);
 $8 = (($link) + 64|0);
 __ZN5physx2Sc16ArticulationCore12applyImpulseERNS0_8BodyCoreERKNS_9PxcFsDataERKNS_6PxVec3ES9_($7,$8,$driveCache,$force,$torque);
 $9 = (($this) + 92|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 88|0);
 $13 = (($lv) + 4|0);
 $14 = (($lv) + 8|0);
 $15 = (($av) + 4|0);
 $16 = (($av) + 8|0);
 $i$01 = 0;
 while(1) {
  $17 = HEAP32[$12>>2]|0;
  $18 = (($17) + ($i$01<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 144|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$lv>>2] = $21;
  $22 = (($19) + 148|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$13>>2] = $23;
  $24 = (($19) + 152|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$14>>2] = $25;
  $26 = (($19) + 160|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  HEAPF32[$av>>2] = $27;
  $28 = (($19) + 164|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$15>>2] = $29;
  $30 = (($19) + 168|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$16>>2] = $31;
  $32 = HEAP32[$19>>2]|0;
  $33 = (($32) + 156|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viii[$34 & 4095]($19,$lv,1);
  $35 = HEAP32[$12>>2]|0;
  $36 = (($35) + ($i$01<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 164|0);
  $40 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_viii[$40 & 4095]($37,$av,1);
  $41 = (($i$01) + 1)|0;
  $42 = HEAP32[$9>>2]|0;
  $43 = ($41>>>0)<($42>>>0);
  if ($43) {
   $i$01 = $41;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx14NpArticulation22computeImpulseResponseEPNS_18PxArticulationLinkERNS_6PxVec3ES4_RKNS_24PxArticulationDriveCacheERKS3_S9_($this,$link,$linearResponse,$angularResponse,$driveCache,$force,$torque) {
 $this = $this|0;
 $link = $link|0;
 $linearResponse = $linearResponse|0;
 $angularResponse = $angularResponse|0;
 $driveCache = $driveCache|0;
 $force = $force|0;
 $torque = $torque|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = (($link) + 64|0);
 __ZNK5physx2Sc16ArticulationCore22computeImpulseResponseERNS0_8BodyCoreERNS_6PxVec3ES5_RKNS_9PxcFsDataERKS4_SA_($0,$1,$linearResponse,$angularResponse,$driveCache,$force,$torque);
 STACKTOP = sp;return;
}
function __ZN5physx28NpArticulationGetRootFromScbERNS_3Scb12ArticulationE($c) {
 $c = $c|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -12|0);
 $1 = (($0) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (0|0);
 } else {
  $4 = (($0) + 88|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  $8 = (($6) + 48|0);
  $$ = $7 ? 0 : $8;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function __ZNK5physx14PxArticulation19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (416144|0);
}
function __ZNK5physx14PxArticulation8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(416144,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,416160)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx19NpArticulationJoint17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 196|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$context>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = $1;
  $6 = (FUNCTION_TABLE_iiii[$4 & 2047]($context,-2147483648,$5)|0);
  HEAP32[$0>>2] = $6;
 }
 $7 = (($this) + 200|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$context>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = $8;
 $13 = (FUNCTION_TABLE_iiii[$11 & 2047]($context,-2147483648,$12)|0);
 HEAP32[$7>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJointC2ERNS_18NpArticulationLinkERKNS_11PxTransformES2_S5_($this,$parent,$parentFrame,$child,$childFrame) {
 $this = $this|0;
 $parent = $parent|0;
 $parentFrame = $parentFrame|0;
 $child = $child|0;
 $childFrame = $childFrame|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 16;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 1;
 HEAP32[$this>>2] = ((416168 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 20|0);
 __ZN5physx2Sc21ArticulationJointCoreC2ERKNS_11PxTransformES4_($5,$parentFrame,$childFrame);
 $6 = HEAP32[$4>>2]|0;
 $7 = $6 & -251658241;
 $8 = $7 | 150994944;
 HEAP32[$4>>2] = $8;
 $9 = (($this) + 196|0);
 HEAP32[$9>>2] = $parent;
 $10 = (($this) + 200|0);
 HEAP32[$10>>2] = $child;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJointD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((416168 + 8|0));
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJointD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((416168 + 8|0));
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJoint7releaseEv($this) {
 $this = $this|0;
 var $$off$i1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,0,1);
 $1 = (($this) + 8|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 $$off$i1 = (($4) + -1)|0;
 $5 = ($$off$i1>>>0)<(2);
 if ($5) {
  $6 = HEAP32[$1>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   __ZN5physx3Scb5Scene23removeArticulationJointERNS0_17ArticulationJointE($6,$1);
  }
 }
 __ZN5physx3Scb4Base7destroyEv($1);
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint13getParentPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0);
 var $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0;
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $18 = (($this) + 24|0);
  $20 = $18;
 } else {
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $13 = (($this) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $7 >>> 24;
   $16 = $15 & 15;
   $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
   HEAP32[$10>>2] = $17;
   $117 = $17;
  } else {
   $117 = $11;
  }
  $20 = $117;
 }
 $19 = Math_fround(HEAPF32[$20>>2]);
 $21 = (($20) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($20) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($20) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($20) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($20) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($20) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($28 * Math_fround(2.0));
 $34 = Math_fround($30 * Math_fround(2.0));
 $35 = Math_fround($32 * Math_fround(2.0));
 $36 = (($0) + 12|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * $37);
 $39 = Math_fround($38 + Math_fround(-0.5));
 $40 = Math_fround(HEAPF32[$0>>2]);
 $41 = Math_fround($33 * $40);
 $42 = (($0) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($34 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($0) + 8|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($35 * $47);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround($33 * $39);
 $51 = Math_fround($35 * $43);
 $52 = Math_fround($34 * $47);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($37 * $53);
 $55 = Math_fround($50 + $54);
 $56 = Math_fround($40 * $49);
 $57 = Math_fround($56 + $55);
 $58 = Math_fround($34 * $39);
 $59 = Math_fround($33 * $47);
 $60 = Math_fround($35 * $40);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($37 * $61);
 $63 = Math_fround($58 + $62);
 $64 = Math_fround($43 * $49);
 $65 = Math_fround($64 + $63);
 $66 = Math_fround($35 * $39);
 $67 = Math_fround($34 * $40);
 $68 = Math_fround($33 * $43);
 $69 = Math_fround($67 - $68);
 $70 = Math_fround($37 * $69);
 $71 = Math_fround($66 + $70);
 $72 = Math_fround($47 * $49);
 $73 = Math_fround($71 + $72);
 $74 = (($0) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 + $57);
 $77 = (($0) + 20|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($78 + $65);
 $80 = (($0) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 + $73);
 $83 = Math_fround($19 * $37);
 $84 = Math_fround($26 * $40);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($24 * $43);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($22 * $47);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($22 * $37);
 $91 = Math_fround($26 * $43);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($19 * $47);
 $94 = Math_fround($93 + $92);
 $95 = Math_fround($24 * $40);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($24 * $37);
 $98 = Math_fround($26 * $47);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($22 * $40);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($19 * $43);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($26 * $37);
 $105 = Math_fround($19 * $40);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($22 * $43);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($24 * $47);
 $110 = Math_fround($108 - $109);
 HEAPF32[$agg$result>>2] = $89;
 $111 = (($agg$result) + 4|0);
 HEAPF32[$111>>2] = $96;
 $112 = (($agg$result) + 8|0);
 HEAPF32[$112>>2] = $103;
 $113 = (($agg$result) + 12|0);
 HEAPF32[$113>>2] = $110;
 $114 = (($agg$result) + 16|0);
 HEAPF32[$114>>2] = $76;
 $115 = (($agg$result) + 20|0);
 HEAPF32[$115>>2] = $79;
 $116 = (($agg$result) + 24|0);
 HEAPF32[$116>>2] = $82;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJoint13setParentPoseERKNS_11PxTransformE($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = Math_fround(0), $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 28|0;
 $1 = sp;
 $2 = (($this) + 196|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 8|0);
 $6 = HEAP32[$3>>2]|0;
 $7 = (($6) + 124|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095]($1,$3);
 $9 = Math_fround(HEAPF32[$t>>2]);
 $10 = Math_fround($9 * $9);
 $11 = (($t) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($t) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($t) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (Math_fround(Math_sqrt((Math_fround($22)))));
 $24 = Math_fround(Math_fround(1.0) / $23);
 $25 = Math_fround($9 * $24);
 $26 = Math_fround($12 * $24);
 $27 = Math_fround($16 * $24);
 $28 = Math_fround($20 * $24);
 $29 = (($t) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($t) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($t) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround(HEAPF32[$1>>2]);
 $36 = Math_fround(-$35);
 $37 = (($1) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(-$38);
 $40 = (($1) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround(-$41);
 $43 = (($1) + 12|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($1) + 16|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($30 - $46);
 $48 = (($1) + 20|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($32 - $49);
 $51 = (($1) + 24|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($34 - $52);
 $54 = Math_fround($47 * Math_fround(2.0));
 $55 = Math_fround($50 * Math_fround(2.0));
 $56 = Math_fround($53 * Math_fround(2.0));
 $57 = Math_fround($44 * $44);
 $58 = Math_fround($57 + Math_fround(-0.5));
 $59 = Math_fround($54 * $36);
 $60 = Math_fround($55 * $39);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($56 * $42);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($58 * $54);
 $65 = Math_fround($56 * $39);
 $66 = Math_fround($55 * $42);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($44 * $67);
 $69 = Math_fround($64 + $68);
 $70 = Math_fround($63 * $36);
 $71 = Math_fround($70 + $69);
 $72 = Math_fround($58 * $55);
 $73 = Math_fround($54 * $42);
 $74 = Math_fround($56 * $36);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($44 * $75);
 $77 = Math_fround($72 + $76);
 $78 = Math_fround($63 * $39);
 $79 = Math_fround($78 + $77);
 $80 = Math_fround($58 * $56);
 $81 = Math_fround($55 * $36);
 $82 = Math_fround($54 * $39);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($44 * $83);
 $85 = Math_fround($80 + $84);
 $86 = Math_fround($63 * $42);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($25 * $44);
 $89 = Math_fround($28 * $36);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($27 * $39);
 $92 = Math_fround($91 + $90);
 $93 = Math_fround($26 * $42);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($26 * $44);
 $96 = Math_fround($28 * $39);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($25 * $42);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($27 * $36);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($27 * $44);
 $103 = Math_fround($28 * $42);
 $104 = Math_fround($103 + $102);
 $105 = Math_fround($26 * $36);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($25 * $39);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($28 * $44);
 $110 = Math_fround($25 * $36);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($26 * $39);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($27 * $42);
 $115 = Math_fround($113 - $114);
 HEAPF32[$0>>2] = $94;
 $116 = (($0) + 4|0);
 HEAPF32[$116>>2] = $101;
 $117 = (($0) + 8|0);
 HEAPF32[$117>>2] = $108;
 $118 = (($0) + 12|0);
 HEAPF32[$118>>2] = $115;
 $119 = (($0) + 16|0);
 HEAPF32[$119>>2] = $71;
 $120 = (($0) + 20|0);
 HEAPF32[$120>>2] = $79;
 $121 = (($0) + 24|0);
 HEAPF32[$121>>2] = $87;
 $122 = (($this) + 20|0);
 $123 = (($this) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = $124 >>> 30;
 if ((($125|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($125|0) == 2)) {
  $126 = HEAP32[$5>>2]|0;
  $127 = (($126) + 2417|0);
  $128 = HEAP8[$127>>0]|0;
  $129 = ($128<<24>>24)==(0);
  if ($129) {
   label = 5;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  __ZN5physx2Sc21ArticulationJointCore13setParentPoseERKNS_11PxTransformE($122,$0);
  STACKTOP = sp;return;
 }
 $130 = (($this) + 16|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ($131|0)==(0|0);
 if ($132) {
  $133 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $134 = $124 >>> 24;
  $135 = $134 & 15;
  $136 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($133,$135)|0);
  HEAP32[$130>>2] = $136;
  $$pre = Math_fround(HEAPF32[$0>>2]);
  $137 = $$pre;$138 = $136;
 } else {
  $137 = $94;$138 = $131;
 }
 HEAPF32[$138>>2] = $137;
 $139 = Math_fround(HEAPF32[$116>>2]);
 $140 = (($138) + 4|0);
 HEAPF32[$140>>2] = $139;
 $141 = Math_fround(HEAPF32[$117>>2]);
 $142 = (($138) + 8|0);
 HEAPF32[$142>>2] = $141;
 $143 = Math_fround(HEAPF32[$118>>2]);
 $144 = (($138) + 12|0);
 HEAPF32[$144>>2] = $143;
 $145 = Math_fround(HEAPF32[$119>>2]);
 $146 = (($138) + 16|0);
 HEAPF32[$146>>2] = $145;
 $147 = Math_fround(HEAPF32[$120>>2]);
 $148 = (($138) + 20|0);
 HEAPF32[$148>>2] = $147;
 $149 = Math_fround(HEAPF32[$121>>2]);
 $150 = (($138) + 24|0);
 HEAPF32[$150>>2] = $149;
 $151 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($151,$5);
 $152 = HEAP32[$123>>2]|0;
 $153 = $152 | 1;
 HEAP32[$123>>2] = $153;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint12getChildPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0;
 var $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 200|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $20 = (($this) + 52|0);
  $22 = $20;
 } else {
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $13 = (($this) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $7 >>> 24;
   $16 = $15 & 15;
   $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
   HEAP32[$10>>2] = $17;
   $19 = $17;
  } else {
   $19 = $11;
  }
  $18 = (($19) + 28|0);
  $22 = $18;
 }
 $21 = Math_fround(HEAPF32[$22>>2]);
 $23 = (($22) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($22) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($22) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($22) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($22) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($22) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($30 * Math_fround(2.0));
 $36 = Math_fround($32 * Math_fround(2.0));
 $37 = Math_fround($34 * Math_fround(2.0));
 $38 = (($0) + 12|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $39);
 $41 = Math_fround($40 + Math_fround(-0.5));
 $42 = Math_fround(HEAPF32[$0>>2]);
 $43 = Math_fround($35 * $42);
 $44 = (($0) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($36 * $45);
 $47 = Math_fround($43 + $46);
 $48 = (($0) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($37 * $49);
 $51 = Math_fround($47 + $50);
 $52 = Math_fround($35 * $41);
 $53 = Math_fround($37 * $45);
 $54 = Math_fround($36 * $49);
 $55 = Math_fround($53 - $54);
 $56 = Math_fround($39 * $55);
 $57 = Math_fround($52 + $56);
 $58 = Math_fround($42 * $51);
 $59 = Math_fround($58 + $57);
 $60 = Math_fround($36 * $41);
 $61 = Math_fround($35 * $49);
 $62 = Math_fround($37 * $42);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($39 * $63);
 $65 = Math_fround($60 + $64);
 $66 = Math_fround($45 * $51);
 $67 = Math_fround($66 + $65);
 $68 = Math_fround($37 * $41);
 $69 = Math_fround($36 * $42);
 $70 = Math_fround($35 * $45);
 $71 = Math_fround($69 - $70);
 $72 = Math_fround($39 * $71);
 $73 = Math_fround($68 + $72);
 $74 = Math_fround($49 * $51);
 $75 = Math_fround($73 + $74);
 $76 = (($0) + 16|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 + $59);
 $79 = (($0) + 20|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($80 + $67);
 $82 = (($0) + 24|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($83 + $75);
 $85 = Math_fround($21 * $39);
 $86 = Math_fround($28 * $42);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($26 * $45);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($24 * $49);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($24 * $39);
 $93 = Math_fround($28 * $45);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($21 * $49);
 $96 = Math_fround($95 + $94);
 $97 = Math_fround($26 * $42);
 $98 = Math_fround($96 - $97);
 $99 = Math_fround($26 * $39);
 $100 = Math_fround($28 * $49);
 $101 = Math_fround($99 + $100);
 $102 = Math_fround($24 * $42);
 $103 = Math_fround($102 + $101);
 $104 = Math_fround($21 * $45);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($28 * $39);
 $107 = Math_fround($21 * $42);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($24 * $45);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($26 * $49);
 $112 = Math_fround($110 - $111);
 HEAPF32[$agg$result>>2] = $91;
 $113 = (($agg$result) + 4|0);
 HEAPF32[$113>>2] = $98;
 $114 = (($agg$result) + 8|0);
 HEAPF32[$114>>2] = $105;
 $115 = (($agg$result) + 12|0);
 HEAPF32[$115>>2] = $112;
 $116 = (($agg$result) + 16|0);
 HEAPF32[$116>>2] = $78;
 $117 = (($agg$result) + 20|0);
 HEAPF32[$117>>2] = $81;
 $118 = (($agg$result) + 24|0);
 HEAPF32[$118>>2] = $84;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJoint12setChildPoseERKNS_11PxTransformE($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = Math_fround(0), $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 28|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = (($this) + 200|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 124|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($1,$4);
 $8 = Math_fround(HEAPF32[$t>>2]);
 $9 = Math_fround($8 * $8);
 $10 = (($t) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (($t) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $15);
 $17 = Math_fround($13 + $16);
 $18 = (($t) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (Math_fround(Math_sqrt((Math_fround($21)))));
 $23 = Math_fround(Math_fround(1.0) / $22);
 $24 = Math_fround($8 * $23);
 $25 = Math_fround($11 * $23);
 $26 = Math_fround($15 * $23);
 $27 = Math_fround($19 * $23);
 $28 = (($t) + 16|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($t) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($t) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround(HEAPF32[$1>>2]);
 $35 = Math_fround(-$34);
 $36 = (($1) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround(-$37);
 $39 = (($1) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround(-$40);
 $42 = (($1) + 12|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($1) + 16|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($29 - $45);
 $47 = (($1) + 20|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($31 - $48);
 $50 = (($1) + 24|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($33 - $51);
 $53 = Math_fround($46 * Math_fround(2.0));
 $54 = Math_fround($49 * Math_fround(2.0));
 $55 = Math_fround($52 * Math_fround(2.0));
 $56 = Math_fround($43 * $43);
 $57 = Math_fround($56 + Math_fround(-0.5));
 $58 = Math_fround($53 * $35);
 $59 = Math_fround($54 * $38);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($55 * $41);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($57 * $53);
 $64 = Math_fround($55 * $38);
 $65 = Math_fround($54 * $41);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround($43 * $66);
 $68 = Math_fround($63 + $67);
 $69 = Math_fround($62 * $35);
 $70 = Math_fround($69 + $68);
 $71 = Math_fround($57 * $54);
 $72 = Math_fround($53 * $41);
 $73 = Math_fround($55 * $35);
 $74 = Math_fround($72 - $73);
 $75 = Math_fround($43 * $74);
 $76 = Math_fround($71 + $75);
 $77 = Math_fround($62 * $38);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($57 * $55);
 $80 = Math_fround($54 * $35);
 $81 = Math_fround($53 * $38);
 $82 = Math_fround($80 - $81);
 $83 = Math_fround($43 * $82);
 $84 = Math_fround($79 + $83);
 $85 = Math_fround($62 * $41);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($24 * $43);
 $88 = Math_fround($27 * $35);
 $89 = Math_fround($88 + $87);
 $90 = Math_fround($26 * $38);
 $91 = Math_fround($90 + $89);
 $92 = Math_fround($25 * $41);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($25 * $43);
 $95 = Math_fround($27 * $38);
 $96 = Math_fround($95 + $94);
 $97 = Math_fround($24 * $41);
 $98 = Math_fround($97 + $96);
 $99 = Math_fround($26 * $35);
 $100 = Math_fround($98 - $99);
 $101 = Math_fround($26 * $43);
 $102 = Math_fround($27 * $41);
 $103 = Math_fround($102 + $101);
 $104 = Math_fround($25 * $35);
 $105 = Math_fround($104 + $103);
 $106 = Math_fround($24 * $38);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($27 * $43);
 $109 = Math_fround($24 * $35);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($25 * $38);
 $112 = Math_fround($110 - $111);
 $113 = Math_fround($26 * $41);
 $114 = Math_fround($112 - $113);
 HEAPF32[$0>>2] = $93;
 $115 = (($0) + 4|0);
 HEAPF32[$115>>2] = $100;
 $116 = (($0) + 8|0);
 HEAPF32[$116>>2] = $107;
 $117 = (($0) + 12|0);
 HEAPF32[$117>>2] = $114;
 $118 = (($0) + 16|0);
 HEAPF32[$118>>2] = $70;
 $119 = (($0) + 20|0);
 HEAPF32[$119>>2] = $78;
 $120 = (($0) + 24|0);
 HEAPF32[$120>>2] = $86;
 $121 = (($this) + 20|0);
 $122 = (($this) + 12|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = $123 >>> 30;
 if ((($124|0) == 2)) {
  $125 = HEAP32[$2>>2]|0;
  $126 = (($125) + 2417|0);
  $127 = HEAP8[$126>>0]|0;
  $128 = ($127<<24>>24)==(0);
  if ($128) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $2;
  }
 } else if ((($124|0) == 3)) {
  $$pre$phi$i$iZ2D = $2;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore12setChildPoseERKNS_11PxTransformE($121,$0);
  STACKTOP = sp;return;
 }
 $129 = (($this) + 16|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($130|0)==(0|0);
 if ($131) {
  $132 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $133 = $123 >>> 24;
  $134 = $133 & 15;
  $135 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($132,$134)|0);
  HEAP32[$129>>2] = $135;
  $$pre = Math_fround(HEAPF32[$0>>2]);
  $137 = $135;$138 = $$pre;
 } else {
  $137 = $130;$138 = $93;
 }
 $136 = (($137) + 28|0);
 HEAPF32[$136>>2] = $138;
 $139 = Math_fround(HEAPF32[$115>>2]);
 $140 = (($137) + 32|0);
 HEAPF32[$140>>2] = $139;
 $141 = Math_fround(HEAPF32[$116>>2]);
 $142 = (($137) + 36|0);
 HEAPF32[$142>>2] = $141;
 $143 = Math_fround(HEAPF32[$117>>2]);
 $144 = (($137) + 40|0);
 HEAPF32[$144>>2] = $143;
 $145 = Math_fround(HEAPF32[$118>>2]);
 $146 = (($137) + 44|0);
 HEAPF32[$146>>2] = $145;
 $147 = Math_fround(HEAPF32[$119>>2]);
 $148 = (($137) + 48|0);
 HEAPF32[$148>>2] = $147;
 $149 = Math_fround(HEAPF32[$120>>2]);
 $150 = (($137) + 52|0);
 HEAPF32[$150>>2] = $149;
 $151 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($151,$2);
 $152 = HEAP32[$122>>2]|0;
 $153 = $152 | 2;
 HEAP32[$122>>2] = $153;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJoint20setTargetOrientationERKNS_6PxQuatE($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore20setTargetOrientationERKNS_6PxQuatE($1,$p);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $18 = $15;
 } else {
  $18 = $10;
 }
 $16 = Math_fround(HEAPF32[$p>>2]);
 $17 = (($18) + 56|0);
 HEAPF32[$17>>2] = $16;
 $19 = (($p) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($18) + 60|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($p) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($18) + 64|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($p) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($18) + 68|0);
 HEAPF32[$27>>2] = $26;
 $28 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$0);
 $29 = HEAP32[$2>>2]|0;
 $30 = $29 | 4;
 HEAP32[$2>>2] = $30;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint20getTargetOrientationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 80|0);
  $16 = $14;
 } else {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 56|0);
  $16 = $12;
 }
 $15 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$agg$result>>2] = $15;
 $17 = (($agg$result) + 4|0);
 $18 = (($16) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$17>>2] = $19;
 $20 = (($agg$result) + 8|0);
 $21 = (($16) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = (($agg$result) + 12|0);
 $24 = (($16) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$23>>2] = $25;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJoint17setTargetVelocityERKNS_6PxVec3E($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore17setTargetVelocityERKNS_6PxVec3E($1,$v);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $18 = $15;
 } else {
  $18 = $10;
 }
 $16 = Math_fround(HEAPF32[$v>>2]);
 $17 = (($18) + 72|0);
 HEAPF32[$17>>2] = $16;
 $19 = (($v) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($18) + 76|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($v) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($18) + 80|0);
 HEAPF32[$24>>2] = $23;
 $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($25,$0);
 $26 = HEAP32[$2>>2]|0;
 $27 = $26 | 8;
 HEAP32[$2>>2] = $27;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint17getTargetVelocityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 8;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 96|0);
  $16 = $14;
 } else {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 72|0);
  $16 = $12;
 }
 $15 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$agg$result>>2] = $15;
 $17 = (($agg$result) + 4|0);
 $18 = (($16) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$17>>2] = $19;
 $20 = (($agg$result) + 8|0);
 $21 = (($16) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJoint12setStiffnessEf($this,$s) {
 $this = $this|0;
 $s = Math_fround($s);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore12setStiffnessEf($1,$s);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 84|0);
 HEAPF32[$16>>2] = $s;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 16;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint12getStiffnessEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 108|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 84|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx19NpArticulationJoint10setDampingEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore10setDampingEf($1,$d);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 88|0);
 HEAPF32[$16>>2] = $d;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 32;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint10getDampingEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 112|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 88|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx19NpArticulationJoint28setSwingLimitContactDistanceEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore28setSwingLimitContactDistanceEf($1,$d);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 100|0);
 HEAPF32[$16>>2] = $d;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 256;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint28getSwingLimitContactDistanceEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 256;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 140|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 100|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx19NpArticulationJoint28setTwistLimitContactDistanceEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore28setTwistLimitContactDistanceEf($1,$d);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 116|0);
 HEAPF32[$16>>2] = $d;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 4096;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint28getTwistLimitContactDistanceEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 164|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 116|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx19NpArticulationJoint21setInternalComplianceEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore21setInternalComplianceEf($1,$r);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 92|0);
 HEAPF32[$16>>2] = $r;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 64;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint21getInternalComplianceEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 124|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 92|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx19NpArticulationJoint21setExternalComplianceEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore21setExternalComplianceEf($1,$r);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 96|0);
 HEAPF32[$16>>2] = $r;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 128;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint21getExternalComplianceEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 128;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 128|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 96|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx19NpArticulationJoint13setSwingLimitEff($this,$yLimit,$zLimit) {
 $this = $this|0;
 $yLimit = Math_fround($yLimit);
 $zLimit = Math_fround($zLimit);
 var $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 if ((($3|0) == 2)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  }
 } else if (!((($3|0) == 3))) {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 20|0);
  __ZN5physx2Sc21ArticulationJointCore13setSwingLimitEff($8,$yLimit,$zLimit);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $13 = HEAP32[$0>>2]|0;
  $14 = $2 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$9>>2] = $16;
  $17 = (($16) + 124|0);
  HEAPF32[$17>>2] = $yLimit;
  $18 = ($16|0)==(0|0);
  if ($18) {
   $19 = HEAP32[$0>>2]|0;
   $20 = HEAP32[$1>>2]|0;
   $21 = $20 >>> 24;
   $22 = $21 & 15;
   $23 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($19,$22)|0);
   HEAP32[$9>>2] = $23;
   $$pre$phi$iZ2D = $0;$25 = $23;
  } else {
   $$pre$phi$iZ2D = $0;$25 = $16;
  }
 } else {
  $12 = (($10) + 124|0);
  HEAPF32[$12>>2] = $yLimit;
  $$pre$phi$iZ2D = $0;$25 = $10;
 }
 $24 = (($25) + 128|0);
 HEAPF32[$24>>2] = $zLimit;
 $26 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($26,$0);
 $27 = HEAP32[$1>>2]|0;
 $28 = $27 | 16384;
 HEAP32[$1>>2] = $28;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint13getSwingLimitERfS1_($this,$yLimit,$zLimit) {
 $this = $this|0;
 $yLimit = $yLimit|0;
 $zLimit = $zLimit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $storemerge$i = Math_fround(0), $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16384;
 $3 = ($2|0)==(0);
 if ($3) {
  $24 = (($this) + 132|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$yLimit>>2] = $25;
  $26 = (($this) + 136|0);
  $storemerge$in$i = $26;
  $storemerge$i = Math_fround(HEAPF32[$storemerge$in$i>>2]);
  HEAPF32[$zLimit>>2] = $storemerge$i;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $1 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($10,$12)|0);
  HEAP32[$4>>2] = $13;
  $14 = (($13) + 124|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$yLimit>>2] = $15;
  $16 = ($13|0)==(0|0);
  if ($16) {
   $17 = HEAP32[$9>>2]|0;
   $18 = HEAP32[$0>>2]|0;
   $19 = $18 >>> 24;
   $20 = $19 & 15;
   $21 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($17,$20)|0);
   HEAP32[$4>>2] = $21;
   $23 = $21;
  } else {
   $23 = $13;
  }
 } else {
  $7 = (($5) + 124|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$yLimit>>2] = $8;
  $23 = $5;
 }
 $22 = (($23) + 128|0);
 $storemerge$in$i = $22;
 $storemerge$i = Math_fround(HEAPF32[$storemerge$in$i>>2]);
 HEAPF32[$zLimit>>2] = $storemerge$i;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJoint22setTangentialStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore22setTangentialStiffnessEf($1,$stiffness);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 108|0);
 HEAPF32[$16>>2] = $stiffness;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 1024;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint22getTangentialStiffnessEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1024;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 148|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 108|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx19NpArticulationJoint20setTangentialDampingEf($this,$damping) {
 $this = $this|0;
 $damping = Math_fround($damping);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore20setTangentialDampingEf($1,$damping);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 112|0);
 HEAPF32[$16>>2] = $damping;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 2048;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint20getTangentialDampingEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2048;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 152|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 112|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx19NpArticulationJoint20setSwingLimitEnabledEb($this,$e) {
 $this = $this|0;
 $e = $e|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore20setSwingLimitEnabledEb($1,$e);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 104|0);
 $18 = $e&1;
 HEAP8[$16>>0] = $18;
 $19 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($19,$0);
 $20 = HEAP32[$2>>2]|0;
 $21 = $20 | 512;
 HEAP32[$2>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint20getSwingLimitEnabledEv($this) {
 $this = $this|0;
 var $$sink$i$i$i = 0, $$sink$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 512;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 144|0);
  $$sink$in$i$i$i = $14;
 } else {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 104|0);
  $$sink$in$i$i$i = $12;
 }
 $$sink$i$i$i = HEAP8[$$sink$in$i$i$i>>0]|0;
 $15 = ($$sink$i$i$i<<24>>24)!=(0);
 STACKTOP = sp;return ($15|0);
}
function __ZN5physx19NpArticulationJoint13setTwistLimitEff($this,$lower,$upper) {
 $this = $this|0;
 $lower = Math_fround($lower);
 $upper = Math_fround($upper);
 var $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 if ((($3|0) == 2)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  }
 } else if (!((($3|0) == 3))) {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 20|0);
  __ZN5physx2Sc21ArticulationJointCore13setTwistLimitEff($8,$lower,$upper);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $13 = HEAP32[$0>>2]|0;
  $14 = $2 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$9>>2] = $16;
  $17 = (($16) + 132|0);
  HEAPF32[$17>>2] = $lower;
  $18 = ($16|0)==(0|0);
  if ($18) {
   $19 = HEAP32[$0>>2]|0;
   $20 = HEAP32[$1>>2]|0;
   $21 = $20 >>> 24;
   $22 = $21 & 15;
   $23 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($19,$22)|0);
   HEAP32[$9>>2] = $23;
   $$pre$phi$iZ2D = $0;$25 = $23;
  } else {
   $$pre$phi$iZ2D = $0;$25 = $16;
  }
 } else {
  $12 = (($10) + 132|0);
  HEAPF32[$12>>2] = $lower;
  $$pre$phi$iZ2D = $0;$25 = $10;
 }
 $24 = (($25) + 136|0);
 HEAPF32[$24>>2] = $upper;
 $26 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($26,$0);
 $27 = HEAP32[$1>>2]|0;
 $28 = $27 | 32768;
 HEAP32[$1>>2] = $28;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint13getTwistLimitERfS1_($this,$lower,$upper) {
 $this = $this|0;
 $lower = $lower|0;
 $upper = $upper|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $storemerge$i = Math_fround(0), $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32768;
 $3 = ($2|0)==(0);
 if ($3) {
  $24 = (($this) + 160|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$lower>>2] = $25;
  $26 = (($this) + 156|0);
  $storemerge$in$i = $26;
  $storemerge$i = Math_fround(HEAPF32[$storemerge$in$i>>2]);
  HEAPF32[$upper>>2] = $storemerge$i;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $1 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($10,$12)|0);
  HEAP32[$4>>2] = $13;
  $14 = (($13) + 132|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$lower>>2] = $15;
  $16 = ($13|0)==(0|0);
  if ($16) {
   $17 = HEAP32[$9>>2]|0;
   $18 = HEAP32[$0>>2]|0;
   $19 = $18 >>> 24;
   $20 = $19 & 15;
   $21 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($17,$20)|0);
   HEAP32[$4>>2] = $21;
   $23 = $21;
  } else {
   $23 = $13;
  }
 } else {
  $7 = (($5) + 132|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$lower>>2] = $8;
  $23 = $5;
 }
 $22 = (($23) + 136|0);
 $storemerge$in$i = $22;
 $storemerge$i = Math_fround(HEAPF32[$storemerge$in$i>>2]);
 HEAPF32[$upper>>2] = $storemerge$i;
 STACKTOP = sp;return;
}
function __ZN5physx19NpArticulationJoint20setTwistLimitEnabledEb($this,$e) {
 $this = $this|0;
 $e = $e|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc21ArticulationJointCore20setTwistLimitEnabledEb($1,$e);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 120|0);
 $18 = $e&1;
 HEAP8[$16>>0] = $18;
 $19 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($19,$0);
 $20 = HEAP32[$2>>2]|0;
 $21 = $20 | 8192;
 HEAP32[$2>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint20getTwistLimitEnabledEv($this) {
 $this = $this|0;
 var $$sink$i$i$i = 0, $$sink$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 8192;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 168|0);
  $$sink$in$i$i$i = $14;
 } else {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 120|0);
  $$sink$in$i$i$i = $12;
 }
 $$sink$i$i$i = HEAP8[$$sink$in$i$i$i>>0]|0;
 $15 = ($$sink$i$i$i<<24>>24)!=(0);
 STACKTOP = sp;return ($15|0);
}
function __ZN5physx35NpArticulationJointGetBodiesFromScbERNS_3Scb17ArticulationJointERPNS0_4BodyES5_($c,$b0,$b1) {
 $c = $c|0;
 $b0 = $b0|0;
 $b1 = $b1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -8|0);
 $1 = (($0) + 196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 200|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 48|0);
 HEAP32[$b0>>2] = $5;
 $6 = (($4) + 48|0);
 HEAP32[$b1>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNK5physx19PxArticulationJoint19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (416344|0);
}
function __ZNK5physx19PxArticulationJoint8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(416344,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,416368)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx19NpArticulationJoint8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpArticulationJoint13isSubordinateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx18NpArticulationLink8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(0);
 L1: do {
  if (!($3)) {
   $4 = $2&65535;
   $6 = $2;$i$01$i = 0;
   while(1) {
    $5 = ($6<<16>>16)==(1);
    if ($5) {
     $9 = $0;
    } else {
     $7 = HEAP32[$0>>2]|0;
     $9 = $7;
    }
    $8 = (($9) + ($i$01$i<<2)|0);
    $10 = HEAP32[$8>>2]|0;
    $11 = HEAP32[$c>>2]|0;
    $12 = (($11) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vii[$13 & 4095]($c,$10);
    $14 = (($i$01$i) + 1)|0;
    $exitcond$i = ($14|0)==($4|0);
    if ($exitcond$i) {
     break L1;
    }
    $$pre$i = HEAP16[$1>>1]|0;
    $6 = $$pre$i;$i$01$i = $14;
   }
  }
 } while(0);
 $15 = (($this) + 292|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$c>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vii[$20 & 4095]($c,$16);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $2&65535;
 $6 = $2;$i$01 = 0;
 while(1) {
  $5 = ($6<<16>>16)==(1);
  if ($5) {
   $9 = $0;
  } else {
   $7 = HEAP32[$0>>2]|0;
   $9 = $7;
  }
  $8 = (($9) + ($i$01<<2)|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$c>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($c,$10);
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($4|0);
  if ($exitcond) {
   break;
  }
  $$pre = HEAP16[$1>>1]|0;
  $6 = $$pre;$i$01 = $14;
 }
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 $1 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($1,$stream);
 $2 = (($this) + 316|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 320|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 324|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 $11 = (($this) + 328|0);
 $12 = HEAP32[$11>>2]|0;
 if ($10) {
  $13 = $12 & 2147483647;
  $14 = ($13|0)==(0);
  if ($14) {
   STACKTOP = sp;return;
  }
 }
 $15 = HEAP32[$stream>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $12 << 2;
 FUNCTION_TABLE_viii[$17 & 4095]($stream,$6,$18);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 $1 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($1,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond$i = 0, $i$02 = 0, $j$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 288|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$context>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = $1;
  $6 = (FUNCTION_TABLE_iiii[$4 & 2047]($context,-2147483648,$5)|0);
  HEAP32[$0>>2] = $6;
 }
 $7 = (($this) + 292|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$context>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = $8;
  $13 = (FUNCTION_TABLE_iiii[$11 & 2047]($context,-2147483648,$12)|0);
  HEAP32[$7>>2] = $13;
 }
 $14 = (($this) + 296|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $17 = HEAP32[$context>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = $15;
  $20 = (FUNCTION_TABLE_iiii[$18 & 2047]($context,-2147483648,$19)|0);
  HEAP32[$14>>2] = $20;
 }
 $21 = (($this) + 20|0);
 $22 = (($this) + 24|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = ($23<<16>>16)==(1);
 if ($24) {
  $29 = $21;
  label = 10;
 } else {
  $25 = HEAP32[$21>>2]|0;
  $26 = ($23<<16>>16)==(0);
  if (!($26)) {
   $29 = $25;
   label = 10;
  }
 }
 if ((label|0) == 10) {
  $27 = $23&65535;
  $j$01$i = 0;
  while(1) {
   $28 = (($29) + ($j$01$i<<2)|0);
   $30 = HEAP32[$28>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $37 = 0;
   } else {
    $32 = HEAP32[$context>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = $30;
    $35 = (FUNCTION_TABLE_iiii[$33 & 2047]($context,-2147483648,$34)|0);
    HEAP32[$28>>2] = $35;
    $37 = $35;
   }
   $36 = (($37) + 16|0);
   (__ZN5physx6shdfnd15atomicIncrementEPVi($36)|0);
   $38 = (($j$01$i) + 1)|0;
   $exitcond$i = ($38|0)==($27|0);
   if ($exitcond$i) {
    break;
   } else {
    $j$01$i = $38;
   }
  }
 }
 $39 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($39,$context);
 $40 = (($this) + 324|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = (($this) + 320|0);
 $i$02 = 0;
 while(1) {
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + ($i$02<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if (!($47)) {
   $48 = HEAP32[$context>>2]|0;
   $49 = HEAP32[$48>>2]|0;
   $50 = $46;
   $51 = (FUNCTION_TABLE_iiii[$49 & 2047]($context,-2147483648,$50)|0);
   HEAP32[$45>>2] = $51;
  }
  $52 = (($i$02) + 1)|0;
  $exitcond = ($52|0)==($41|0);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $52;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(1);
 if ($3) {
  $8 = $0;
  label = 4;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($2<<16>>16)==(0);
  if (!($5)) {
   $8 = $4;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $6 = $2&65535;
  $j$01 = 0;
  while(1) {
   $7 = (($8) + ($j$01<<2)|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $16 = 0;
   } else {
    $11 = HEAP32[$context>>2]|0;
    $12 = HEAP32[$11>>2]|0;
    $13 = $9;
    $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($context,-2147483648,$13)|0);
    HEAP32[$7>>2] = $14;
    $16 = $14;
   }
   $15 = (($16) + 16|0);
   (__ZN5physx6shdfnd15atomicIncrementEPVi($15)|0);
   $17 = (($j$01) + 1)|0;
   $exitcond = ($17|0)==($6|0);
   if ($exitcond) {
    break;
   } else {
    $j$01 = $17;
   }
  }
 }
 $18 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($18,$context);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLinkC2ERKNS_11PxTransformERNS_14NpArticulationEPS0_($this,$bodyPose,$root,$parent) {
 $this = $this|0;
 $bodyPose = $bodyPose|0;
 $root = $root|0;
 $parent = $parent|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP16[$1>>1] = 15;
 $2 = (($this) + 6|0);
 HEAP16[$2>>1] = 1;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((418176 + 8|0));
 $4 = (($this) + 12|0);
 __ZN5physx7NpActorC2EPKc($4,0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((417648 + 8|0));
 $5 = (($this) + 20|0);
 __ZN5physx14NpShapeManagerC2Ev($5);
 HEAP32[$this>>2] = ((417376 + 8|0));
 $6 = (($this) + 48|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 56|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 52|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreC2ENS_11PxActorType4EnumERKNS_11PxTransformE($9,4,$bodyPose);
 $10 = HEAP32[$8>>2]|0;
 $11 = $10 & -251658241;
 $12 = $11 | 50331648;
 HEAP32[$8>>2] = $12;
 $13 = (($this) + 80|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 224|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($this) + 84|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 228|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($this) + 88|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 232|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($this) + 92|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 236|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($this) + 96|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 240|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($this) + 100|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($this) + 244|0);
 HEAPF32[$30>>2] = $29;
 $31 = (($this) + 104|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 248|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($this) + 144|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($this) + 252|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($this) + 148|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($this) + 256|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($this) + 152|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($this) + 260|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($this) + 160|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($this) + 264|0);
 HEAPF32[$45>>2] = $44;
 $46 = (($this) + 164|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($this) + 268|0);
 HEAPF32[$48>>2] = $47;
 $49 = (($this) + 168|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($this) + 272|0);
 HEAPF32[$51>>2] = $50;
 $52 = (Math_fround(__ZNK5physx2Sc8BodyCore14getWakeCounterEv($9)));
 $53 = (($this) + 276|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($this) + 280|0);
 HEAP32[$54>>2] = 1;
 $55 = (($this) + 284|0);
 HEAP32[$55>>2] = 0;
 HEAP32[$this>>2] = ((416376 + 8|0));
 $56 = (($this) + 288|0);
 HEAP32[$56>>2] = $root;
 $57 = (($this) + 292|0);
 HEAP32[$57>>2] = 0;
 $58 = (($this) + 296|0);
 HEAP32[$58>>2] = $parent;
 $59 = (($this) + 300|0);
 $60 = (($this) + 316|0);
 $61 = (($this) + 320|0);
 $62 = (($this) + 324|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 328|0);
 HEAP8[$60>>0] = 1;
 HEAP32[$61>>2] = $59;
 HEAP32[$63>>2] = 4;
 $64 = HEAP32[$8>>2]|0;
 $65 = $64 & -251658241;
 $66 = $65 | 67108864;
 HEAP32[$8>>2] = $66;
 HEAP32[$0>>2] = $this;
 $67 = (($root) + 96|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68 & 2147483647;
 $70 = (($root) + 92|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($69>>>0)>($71>>>0);
 if ($72) {
  $74 = (($root) + 88|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($75) + ($71<<2)|0);
  $77 = ($76|0)==(0|0);
  if (!($77)) {
   HEAP32[$76>>2] = $this;
  }
  $78 = (($71) + 1)|0;
  HEAP32[$70>>2] = $78;
 } else {
  $73 = (($root) + 68|0);
  (__ZN5physx6shdfnd5ArrayIPNS_18NpArticulationLinkENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($73,$0)|0);
 }
 $79 = ($parent|0)==(0|0);
 if ($79) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $this;
 $80 = (($parent) + 328|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = $81 & 2147483647;
 $83 = (($parent) + 324|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($82>>>0)>($84>>>0);
 if (!($85)) {
  $86 = (($parent) + 300|0);
  (__ZN5physx6shdfnd5ArrayIPNS_18NpArticulationLinkENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($86,$0)|0);
  STACKTOP = sp;return;
 }
 $87 = (($parent) + 320|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($88) + ($84<<2)|0);
 $90 = ($89|0)==(0|0);
 if (!($90)) {
  HEAP32[$89>>2] = $this;
 }
 $91 = (($84) + 1)|0;
 HEAP32[$83>>2] = $91;
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLinkD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx18NpArticulationLinkD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLinkD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((416376 + 8|0));
 $0 = (($this) + 328|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i$i$i = $3 & $4;
 do {
  if ($or$cond$i$i$i$i) {
   $5 = (($this) + 320|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($this) + 300|0);
   $8 = ($7|0)==($6|0);
   if ($8) {
    $9 = (($this) + 316|0);
    HEAP8[$9>>0] = 0;
    break;
   }
   $10 = ($6|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$6);
   }
  }
 } while(0);
 HEAP32[$this>>2] = ((417376 + 8|0));
 $15 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreD2Ev($15);
 HEAP32[$this>>2] = ((417648 + 8|0));
 $16 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($16);
 $17 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($17);
 HEAP32[$this>>2] = ((417920 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __Z31NpGetPxActorForArticulationLinkRN5physx2Sc8BodyCoreE($scBody) {
 $scBody = $scBody|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scBody) + -64|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx18NpArticulationLink15releaseInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i$i = 0, $index$0$lcssa$i$i3 = 0, $index$01$i$i = 0, $index$01$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (($this) + 12|0);
 __ZN5physx7NpActor18releaseConstraintsERNS_12PxRigidActorE($3,$this);
 $4 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $5 = (($this) + 20|0);
 __ZN5physx14NpShapeManager9detachAllEPNS_7NpSceneE($5,$4);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($3,$this);
 $6 = (($this) + 288|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (($7) + 88|0);
  $12 = HEAP32[$11>>2]|0;
  $index$01$i$i = 0;
  while(1) {
   $15 = (($12) + ($index$01$i$i<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($this|0);
   $14 = (($index$01$i$i) + 1)|0;
   if ($17) {
    $index$0$lcssa$i$i = $index$01$i$i;
    break;
   }
   $13 = ($14>>>0)<($9>>>0);
   if ($13) {
    $index$01$i$i = $14;
   } else {
    $index$0$lcssa$i$i = $14;
    break;
   }
  }
  $18 = ($index$0$lcssa$i$i|0)==($9|0);
  if (!($18)) {
   $19 = (($9) + -1)|0;
   HEAP32[$8>>2] = $19;
   $20 = (($12) + ($19<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($12) + ($index$0$lcssa$i$i<<2)|0);
   HEAP32[$22>>2] = $21;
  }
 }
 $23 = (($this) + 296|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = (($24) + 324|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0);
  if (!($28)) {
   $29 = (($24) + 320|0);
   $30 = HEAP32[$29>>2]|0;
   $index$01$i$i2 = 0;
   while(1) {
    $33 = (($30) + ($index$01$i$i2<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==($this|0);
    $32 = (($index$01$i$i2) + 1)|0;
    if ($35) {
     $index$0$lcssa$i$i3 = $index$01$i$i2;
     break;
    }
    $31 = ($32>>>0)<($27>>>0);
    if ($31) {
     $index$01$i$i2 = $32;
    } else {
     $index$0$lcssa$i$i3 = $32;
     break;
    }
   }
   $36 = ($index$0$lcssa$i$i3|0)==($27|0);
   if (!($36)) {
    $37 = (($27) + -1)|0;
    HEAP32[$26>>2] = $37;
    $38 = (($30) + ($37<<2)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($30) + ($index$0$lcssa$i$i3<<2)|0);
    HEAP32[$40>>2] = $39;
   }
  }
 }
 $41 = (($this) + 292|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if (!($43)) {
  $44 = HEAP32[$42>>2]|0;
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vi[$45 & 4095]($42);
 }
 $46 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $47 = ($46|0)==(0|0);
 if ($47) {
  $50 = (($this) + 48|0);
  __ZN5physx3Scb4Base7destroyEv($50);
  STACKTOP = sp;return;
 }
 $48 = (($46) + 16|0);
 $49 = (($this) + 48|0);
 __ZN5physx3Scb5Scene15removeRigidBodyERNS0_4BodyEbb($48,$49,1,0);
 $50 = (($this) + 48|0);
 __ZN5physx3Scb4Base7destroyEv($50);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor18releaseConstraintsERNS_12PxRigidActorE($0,$this);
 $1 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $2 = (($this) + 20|0);
 __ZN5physx14NpShapeManager9detachAllEPNS_7NpSceneE($2,$1);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 324|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  __ZN5physx18NpArticulationLink15releaseInternalEv($this);
  STACKTOP = sp;return;
 } else {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,8,416656,151,416736,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx18NpArticulationLink13getGlobalPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 512;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 112|0);
  $18 = $16;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 144|0);
  $18 = $14;
 }
 $17 = (($18) + 16|0);
 $19 = Math_fround(HEAPF32[$17>>2]);
 $20 = (($18) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($18) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($19 * Math_fround(-2.0));
 $25 = Math_fround($21 * Math_fround(-2.0));
 $26 = Math_fround($23 * Math_fround(-2.0));
 $27 = (($18) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $28);
 $30 = Math_fround($29 + Math_fround(-0.5));
 $31 = Math_fround(HEAPF32[$18>>2]);
 $32 = Math_fround($24 * $31);
 $33 = (($18) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($25 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($18) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($26 * $38);
 $40 = Math_fround($36 + $39);
 $41 = Math_fround($24 * $30);
 $42 = Math_fround($26 * $34);
 $43 = Math_fround($25 * $38);
 $44 = Math_fround($42 - $43);
 $45 = Math_fround($28 * $44);
 $46 = Math_fround($41 - $45);
 $47 = Math_fround($31 * $40);
 $48 = Math_fround($47 + $46);
 $49 = Math_fround($25 * $30);
 $50 = Math_fround($24 * $38);
 $51 = Math_fround($26 * $31);
 $52 = Math_fround($50 - $51);
 $53 = Math_fround($28 * $52);
 $54 = Math_fround($49 - $53);
 $55 = Math_fround($34 * $40);
 $56 = Math_fround($55 + $54);
 $57 = Math_fround($26 * $30);
 $58 = Math_fround($25 * $31);
 $59 = Math_fround($24 * $34);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($28 * $60);
 $62 = Math_fround($57 - $61);
 $63 = Math_fround($38 * $40);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround(-$31);
 $66 = Math_fround(-$34);
 $67 = Math_fround(-$38);
 $68 = Math_fround($48 * Math_fround(2.0));
 $69 = Math_fround($56 * Math_fround(2.0));
 $70 = Math_fround($64 * Math_fround(2.0));
 $71 = (($this) + 236|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 * $72);
 $74 = Math_fround($73 + Math_fround(-0.5));
 $75 = (($this) + 224|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($76 * $68);
 $78 = (($this) + 228|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 * $69);
 $81 = Math_fround($77 + $80);
 $82 = (($this) + 232|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($83 * $70);
 $85 = Math_fround($84 + $81);
 $86 = Math_fround($74 * $68);
 $87 = Math_fround($79 * $70);
 $88 = Math_fround($83 * $69);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($72 * $89);
 $91 = Math_fround($86 + $90);
 $92 = Math_fround($76 * $85);
 $93 = Math_fround($92 + $91);
 $94 = Math_fround($74 * $69);
 $95 = Math_fround($83 * $68);
 $96 = Math_fround($76 * $70);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($72 * $97);
 $99 = Math_fround($94 + $98);
 $100 = Math_fround($79 * $85);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($74 * $70);
 $103 = Math_fround($76 * $69);
 $104 = Math_fround($79 * $68);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($102 + $106);
 $108 = Math_fround($83 * $85);
 $109 = Math_fround($107 + $108);
 $110 = (($this) + 240|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($111 + $93);
 $113 = (($this) + 244|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($114 + $101);
 $116 = (($this) + 248|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($117 + $109);
 $119 = Math_fround($72 * $65);
 $120 = Math_fround($28 * $76);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($79 * $67);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($83 * $66);
 $125 = Math_fround($123 - $124);
 $126 = Math_fround($72 * $66);
 $127 = Math_fround($28 * $79);
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($83 * $65);
 $130 = Math_fround($129 + $128);
 $131 = Math_fround($76 * $67);
 $132 = Math_fround($130 - $131);
 $133 = Math_fround($72 * $67);
 $134 = Math_fround($28 * $83);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround($76 * $66);
 $137 = Math_fround($136 + $135);
 $138 = Math_fround($79 * $65);
 $139 = Math_fround($137 - $138);
 $140 = Math_fround($28 * $72);
 $141 = Math_fround($76 * $65);
 $142 = Math_fround($140 - $141);
 $143 = Math_fround($79 * $66);
 $144 = Math_fround($142 - $143);
 $145 = Math_fround($83 * $67);
 $146 = Math_fround($144 - $145);
 HEAPF32[$agg$result>>2] = $125;
 $147 = (($agg$result) + 4|0);
 HEAPF32[$147>>2] = $132;
 $148 = (($agg$result) + 8|0);
 HEAPF32[$148>>2] = $139;
 $149 = (($agg$result) + 12|0);
 HEAPF32[$149>>2] = $146;
 $150 = (($agg$result) + 16|0);
 HEAPF32[$150>>2] = $112;
 $151 = (($agg$result) + 20|0);
 HEAPF32[$151>>2] = $115;
 $152 = (($agg$result) + 24|0);
 HEAPF32[$152>>2] = $118;
 STACKTOP = sp;return;
}
function __ZNK5physx18NpArticulationLink15getArticulationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 288|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx18NpArticulationLink15getInboundJointEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 292|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx18NpArticulationLink13getNbChildrenEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 324|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx18NpArticulationLink11getChildrenEPPNS_18PxArticulationLinkEj($this,$buffer,$bufferSize) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 324|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($bufferSize>>>0);
 $3 = $2 ? $1 : $bufferSize;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = (($this) + 320|0);
 $6 = $1 ^ -1;
 $7 = $bufferSize ^ -1;
 $8 = ($6>>>0)>($7>>>0);
 $umax = $8 ? $6 : $7;
 $9 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$5>>2]|0;
  $11 = (($10) + ($i$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($buffer) + ($i$01<<2)|0);
  HEAP32[$13>>2] = $12;
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($9|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $14;
  }
 }
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx18NpArticulationLink17setCMassLocalPoseERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $$pre = Math_fround(0), $$pre$phi$i$i7Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre$pre = Math_fround(0), $$pre19 = Math_fround(0), $$pre19$pre = Math_fround(0), $$pre20 = Math_fround(0), $$pre20$pre = Math_fround(0), $$pre21 = Math_fround(0), $$pre21$pre = Math_fround(0), $$pre22 = Math_fround(0), $$pre22$pre = Math_fround(0), $$pre23 = Math_fround(0), $$pre23$pre = Math_fround(0), $$pre24 = Math_fround(0), $$pre24$pre = Math_fround(0), $$pre25 = 0, $$pre25$pre = 0, $$pre26 = Math_fround(0), $$pre28 = 0;
 var $$pre28$pre = 0, $$pre29 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0);
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0;
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = 0;
 var $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0;
 var $402 = Math_fround(0), $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $i$018 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $p = sp + 56|0;
 $0 = sp;
 $1 = sp + 28|0;
 $2 = Math_fround(HEAPF32[$pose>>2]);
 $3 = Math_fround($2 * $2);
 $4 = (($pose) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $5);
 $7 = Math_fround($3 + $6);
 $8 = (($pose) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($pose) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (Math_fround(Math_sqrt((Math_fround($15)))));
 $17 = Math_fround(Math_fround(1.0) / $16);
 $18 = Math_fround($2 * $17);
 $19 = Math_fround($5 * $17);
 $20 = Math_fround($9 * $17);
 $21 = Math_fround($13 * $17);
 HEAPF32[$p>>2] = $18;
 $22 = (($p) + 4|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($p) + 8|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($p) + 12|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($p) + 16|0);
 $26 = (($pose) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($p) + 20|0);
 $29 = (($pose) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($p) + 24|0);
 $32 = (($pose) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($this) + 284|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35 & 512;
 $37 = ($36|0)==(0);
 if ($37) {
  $50 = (($this) + 112|0);
  $52 = $50;$66 = $18;$68 = $19;$70 = $20;$72 = $27;$74 = $30;$76 = $33;$81 = $21;
 } else {
  $38 = (($this) + 56|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  if ($40) {
   $41 = (($this) + 48|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($this) + 52|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = $44 >>> 24;
   $46 = $45 & 15;
   $47 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($42,$46)|0);
   HEAP32[$38>>2] = $47;
   $$pre$pre = Math_fround(HEAPF32[$p>>2]);
   $$pre19$pre = Math_fround(HEAPF32[$22>>2]);
   $$pre20$pre = Math_fround(HEAPF32[$23>>2]);
   $$pre21$pre = Math_fround(HEAPF32[$24>>2]);
   $$pre22$pre = Math_fround(HEAPF32[$25>>2]);
   $$pre23$pre = Math_fround(HEAPF32[$28>>2]);
   $$pre24$pre = Math_fround(HEAPF32[$31>>2]);
   $$pre = $$pre$pre;$$pre19 = $$pre19$pre;$$pre20 = $$pre20$pre;$$pre21 = $$pre21$pre;$$pre22 = $$pre22$pre;$$pre23 = $$pre23$pre;$$pre24 = $$pre24$pre;$49 = $47;
  } else {
   $$pre = $18;$$pre19 = $19;$$pre20 = $20;$$pre21 = $21;$$pre22 = $27;$$pre23 = $30;$$pre24 = $33;$49 = $39;
  }
  $48 = (($49) + 144|0);
  $52 = $48;$66 = $$pre;$68 = $$pre19;$70 = $$pre20;$72 = $$pre22;$74 = $$pre23;$76 = $$pre24;$81 = $$pre21;
 }
 $51 = Math_fround(HEAPF32[$52>>2]);
 $53 = (($52) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($52) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($52) + 12|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($52) + 16|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($52) + 20|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($52) + 24|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(-$66);
 $67 = Math_fround(-$68);
 $69 = Math_fround(-$70);
 $71 = Math_fround($60 - $72);
 $73 = Math_fround($62 - $74);
 $75 = Math_fround($64 - $76);
 $77 = Math_fround($71 * Math_fround(2.0));
 $78 = Math_fround($73 * Math_fround(2.0));
 $79 = Math_fround($75 * Math_fround(2.0));
 $80 = Math_fround($81 * $81);
 $82 = Math_fround($80 + Math_fround(-0.5));
 $83 = Math_fround($77 * $65);
 $84 = Math_fround($78 * $67);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($79 * $69);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($82 * $77);
 $89 = Math_fround($79 * $67);
 $90 = Math_fround($78 * $69);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($81 * $91);
 $93 = Math_fround($88 + $92);
 $94 = Math_fround($87 * $65);
 $95 = Math_fround($94 + $93);
 $96 = Math_fround($82 * $78);
 $97 = Math_fround($77 * $69);
 $98 = Math_fround($79 * $65);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($81 * $99);
 $101 = Math_fround($96 + $100);
 $102 = Math_fround($87 * $67);
 $103 = Math_fround($102 + $101);
 $104 = Math_fround($82 * $79);
 $105 = Math_fround($78 * $65);
 $106 = Math_fround($77 * $67);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($81 * $107);
 $109 = Math_fround($104 + $108);
 $110 = Math_fround($87 * $69);
 $111 = Math_fround($109 + $110);
 $112 = Math_fround($51 * $81);
 $113 = Math_fround($58 * $65);
 $114 = Math_fround($113 + $112);
 $115 = Math_fround($56 * $67);
 $116 = Math_fround($115 + $114);
 $117 = Math_fround($54 * $69);
 $118 = Math_fround($116 - $117);
 $119 = Math_fround($54 * $81);
 $120 = Math_fround($58 * $67);
 $121 = Math_fround($120 + $119);
 $122 = Math_fround($51 * $69);
 $123 = Math_fround($122 + $121);
 $124 = Math_fround($56 * $65);
 $125 = Math_fround($123 - $124);
 $126 = Math_fround($56 * $81);
 $127 = Math_fround($58 * $69);
 $128 = Math_fround($127 + $126);
 $129 = Math_fround($54 * $65);
 $130 = Math_fround($129 + $128);
 $131 = Math_fround($51 * $67);
 $132 = Math_fround($130 - $131);
 $133 = Math_fround($58 * $81);
 $134 = Math_fround($51 * $65);
 $135 = Math_fround($133 - $134);
 $136 = Math_fround($54 * $67);
 $137 = Math_fround($135 - $136);
 $138 = Math_fround($56 * $69);
 $139 = Math_fround($137 - $138);
 __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25setCMassLocalPoseInternalERKNS_11PxTransformE($this,$p);
 $140 = (($this) + 292|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = ($141|0)==(0|0);
 do {
  if (!($142)) {
   $143 = (($141) + 8|0);
   $144 = (($141) + 12|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = $145 & 2;
   $147 = ($146|0)==(0);
   if ($147) {
    $157 = (($141) + 52|0);
    $159 = $157;$245 = $145;
   } else {
    $148 = (($141) + 16|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = ($149|0)==(0|0);
    if ($150) {
     $151 = HEAP32[$143>>2]|0;
     $152 = $145 >>> 24;
     $153 = $152 & 15;
     $154 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($151,$153)|0);
     HEAP32[$148>>2] = $154;
     $$pre25$pre = HEAP32[$144>>2]|0;
     $$pre25 = $$pre25$pre;$156 = $154;
    } else {
     $$pre25 = $145;$156 = $149;
    }
    $155 = (($156) + 28|0);
    $159 = $155;$245 = $$pre25;
   }
   $158 = Math_fround(HEAPF32[$159>>2]);
   $160 = (($159) + 4|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = (($159) + 8|0);
   $163 = Math_fround(HEAPF32[$162>>2]);
   $164 = (($159) + 12|0);
   $165 = Math_fround(HEAPF32[$164>>2]);
   $166 = (($159) + 16|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = (($159) + 20|0);
   $169 = Math_fround(HEAPF32[$168>>2]);
   $170 = (($159) + 24|0);
   $171 = Math_fround(HEAPF32[$170>>2]);
   $172 = Math_fround($167 * Math_fround(2.0));
   $173 = Math_fround($169 * Math_fround(2.0));
   $174 = Math_fround($171 * Math_fround(2.0));
   $175 = Math_fround($139 * $139);
   $176 = Math_fround($175 + Math_fround(-0.5));
   $177 = Math_fround($118 * $172);
   $178 = Math_fround($125 * $173);
   $179 = Math_fround($177 + $178);
   $180 = Math_fround($132 * $174);
   $181 = Math_fround($179 + $180);
   $182 = Math_fround($176 * $172);
   $183 = Math_fround($125 * $174);
   $184 = Math_fround($132 * $173);
   $185 = Math_fround($183 - $184);
   $186 = Math_fround($139 * $185);
   $187 = Math_fround($182 + $186);
   $188 = Math_fround($118 * $181);
   $189 = Math_fround($188 + $187);
   $190 = Math_fround($176 * $173);
   $191 = Math_fround($132 * $172);
   $192 = Math_fround($118 * $174);
   $193 = Math_fround($191 - $192);
   $194 = Math_fround($139 * $193);
   $195 = Math_fround($190 + $194);
   $196 = Math_fround($125 * $181);
   $197 = Math_fround($196 + $195);
   $198 = Math_fround($176 * $174);
   $199 = Math_fround($118 * $173);
   $200 = Math_fround($125 * $172);
   $201 = Math_fround($199 - $200);
   $202 = Math_fround($139 * $201);
   $203 = Math_fround($198 + $202);
   $204 = Math_fround($132 * $181);
   $205 = Math_fround($203 + $204);
   $206 = Math_fround($95 + $189);
   $207 = Math_fround($103 + $197);
   $208 = Math_fround($111 + $205);
   $209 = Math_fround($139 * $158);
   $210 = Math_fround($118 * $165);
   $211 = Math_fround($209 + $210);
   $212 = Math_fround($125 * $163);
   $213 = Math_fround($212 + $211);
   $214 = Math_fround($132 * $161);
   $215 = Math_fround($213 - $214);
   $216 = Math_fround($139 * $161);
   $217 = Math_fround($125 * $165);
   $218 = Math_fround($216 + $217);
   $219 = Math_fround($132 * $158);
   $220 = Math_fround($219 + $218);
   $221 = Math_fround($118 * $163);
   $222 = Math_fround($220 - $221);
   $223 = Math_fround($139 * $163);
   $224 = Math_fround($132 * $165);
   $225 = Math_fround($223 + $224);
   $226 = Math_fround($118 * $161);
   $227 = Math_fround($226 + $225);
   $228 = Math_fround($125 * $158);
   $229 = Math_fround($227 - $228);
   $230 = Math_fround($139 * $165);
   $231 = Math_fround($118 * $158);
   $232 = Math_fround($230 - $231);
   $233 = Math_fround($125 * $161);
   $234 = Math_fround($232 - $233);
   $235 = Math_fround($132 * $163);
   $236 = Math_fround($234 - $235);
   HEAPF32[$0>>2] = $215;
   $237 = (($0) + 4|0);
   HEAPF32[$237>>2] = $222;
   $238 = (($0) + 8|0);
   HEAPF32[$238>>2] = $229;
   $239 = (($0) + 12|0);
   HEAPF32[$239>>2] = $236;
   $240 = (($0) + 16|0);
   HEAPF32[$240>>2] = $206;
   $241 = (($0) + 20|0);
   HEAPF32[$241>>2] = $207;
   $242 = (($0) + 24|0);
   HEAPF32[$242>>2] = $208;
   $243 = (($141) + 20|0);
   $244 = $245 >>> 30;
   if ((($244|0) == 2)) {
    $246 = HEAP32[$143>>2]|0;
    $247 = (($246) + 2417|0);
    $248 = HEAP8[$247>>0]|0;
    $249 = ($248<<24>>24)==(0);
    if ($249) {
     label = 15;
    } else {
     $$pre$phi$i$i7Z2D = $143;
    }
   } else if ((($244|0) == 3)) {
    $$pre$phi$i$i7Z2D = $143;
   } else {
    label = 15;
   }
   if ((label|0) == 15) {
    __ZN5physx2Sc21ArticulationJointCore12setChildPoseERKNS_11PxTransformE($243,$0);
    break;
   }
   $250 = (($141) + 16|0);
   $251 = HEAP32[$250>>2]|0;
   $252 = ($251|0)==(0|0);
   if ($252) {
    $253 = HEAP32[$$pre$phi$i$i7Z2D>>2]|0;
    $254 = $245 >>> 24;
    $255 = $254 & 15;
    $256 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($253,$255)|0);
    HEAP32[$250>>2] = $256;
    $$pre26 = Math_fround(HEAPF32[$0>>2]);
    $258 = $256;$259 = $$pre26;
   } else {
    $258 = $251;$259 = $215;
   }
   $257 = (($258) + 28|0);
   HEAPF32[$257>>2] = $259;
   $260 = Math_fround(HEAPF32[$237>>2]);
   $261 = (($258) + 32|0);
   HEAPF32[$261>>2] = $260;
   $262 = Math_fround(HEAPF32[$238>>2]);
   $263 = (($258) + 36|0);
   HEAPF32[$263>>2] = $262;
   $264 = Math_fround(HEAPF32[$239>>2]);
   $265 = (($258) + 40|0);
   HEAPF32[$265>>2] = $264;
   $266 = Math_fround(HEAPF32[$240>>2]);
   $267 = (($258) + 44|0);
   HEAPF32[$267>>2] = $266;
   $268 = Math_fround(HEAPF32[$241>>2]);
   $269 = (($258) + 48|0);
   HEAPF32[$269>>2] = $268;
   $270 = Math_fround(HEAPF32[$242>>2]);
   $271 = (($258) + 52|0);
   HEAPF32[$271>>2] = $270;
   $272 = HEAP32[$$pre$phi$i$i7Z2D>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($272,$143);
   $273 = HEAP32[$144>>2]|0;
   $274 = $273 | 2;
   HEAP32[$144>>2] = $274;
  }
 } while(0);
 $275 = (($this) + 324|0);
 $276 = HEAP32[$275>>2]|0;
 $277 = ($276|0)==(0);
 if ($277) {
  STACKTOP = sp;return;
 }
 $278 = (($this) + 320|0);
 $279 = Math_fround($139 * $139);
 $280 = Math_fround($279 + Math_fround(-0.5));
 $281 = (($1) + 4|0);
 $282 = (($1) + 8|0);
 $283 = (($1) + 12|0);
 $284 = (($1) + 16|0);
 $285 = (($1) + 20|0);
 $286 = (($1) + 24|0);
 $i$018 = 0;
 while(1) {
  $287 = HEAP32[$278>>2]|0;
  $288 = (($287) + ($i$018<<2)|0);
  $289 = HEAP32[$288>>2]|0;
  $290 = HEAP32[$289>>2]|0;
  $291 = (($290) + 228|0);
  $292 = HEAP32[$291>>2]|0;
  $293 = (FUNCTION_TABLE_ii[$292 & 4095]($289)|0);
  $294 = (($293) + 8|0);
  $295 = (($293) + 12|0);
  $296 = HEAP32[$295>>2]|0;
  $297 = $296 & 1;
  $298 = ($297|0)==(0);
  if ($298) {
   $306 = (($293) + 24|0);
   $308 = $306;$386 = $296;
  } else {
   $299 = (($293) + 16|0);
   $300 = HEAP32[$299>>2]|0;
   $301 = ($300|0)==(0|0);
   if ($301) {
    $302 = HEAP32[$294>>2]|0;
    $303 = $296 >>> 24;
    $304 = $303 & 15;
    $305 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($302,$304)|0);
    HEAP32[$299>>2] = $305;
    $$pre28$pre = HEAP32[$295>>2]|0;
    $$pre28 = $$pre28$pre;$418 = $305;
   } else {
    $$pre28 = $296;$418 = $300;
   }
   $308 = $418;$386 = $$pre28;
  }
  $307 = Math_fround(HEAPF32[$308>>2]);
  $309 = (($308) + 4|0);
  $310 = Math_fround(HEAPF32[$309>>2]);
  $311 = (($308) + 8|0);
  $312 = Math_fround(HEAPF32[$311>>2]);
  $313 = (($308) + 12|0);
  $314 = Math_fround(HEAPF32[$313>>2]);
  $315 = (($308) + 16|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = (($308) + 20|0);
  $318 = Math_fround(HEAPF32[$317>>2]);
  $319 = (($308) + 24|0);
  $320 = Math_fround(HEAPF32[$319>>2]);
  $321 = Math_fround($316 * Math_fround(2.0));
  $322 = Math_fround($318 * Math_fround(2.0));
  $323 = Math_fround($320 * Math_fround(2.0));
  $324 = Math_fround($118 * $321);
  $325 = Math_fround($125 * $322);
  $326 = Math_fround($324 + $325);
  $327 = Math_fround($132 * $323);
  $328 = Math_fround($326 + $327);
  $329 = Math_fround($280 * $321);
  $330 = Math_fround($125 * $323);
  $331 = Math_fround($132 * $322);
  $332 = Math_fround($330 - $331);
  $333 = Math_fround($139 * $332);
  $334 = Math_fround($329 + $333);
  $335 = Math_fround($118 * $328);
  $336 = Math_fround($335 + $334);
  $337 = Math_fround($280 * $322);
  $338 = Math_fround($132 * $321);
  $339 = Math_fround($118 * $323);
  $340 = Math_fround($338 - $339);
  $341 = Math_fround($139 * $340);
  $342 = Math_fround($337 + $341);
  $343 = Math_fround($125 * $328);
  $344 = Math_fround($343 + $342);
  $345 = Math_fround($280 * $323);
  $346 = Math_fround($118 * $322);
  $347 = Math_fround($125 * $321);
  $348 = Math_fround($346 - $347);
  $349 = Math_fround($139 * $348);
  $350 = Math_fround($345 + $349);
  $351 = Math_fround($132 * $328);
  $352 = Math_fround($350 + $351);
  $353 = Math_fround($95 + $336);
  $354 = Math_fround($103 + $344);
  $355 = Math_fround($111 + $352);
  $356 = Math_fround($139 * $307);
  $357 = Math_fround($118 * $314);
  $358 = Math_fround($356 + $357);
  $359 = Math_fround($125 * $312);
  $360 = Math_fround($359 + $358);
  $361 = Math_fround($132 * $310);
  $362 = Math_fround($360 - $361);
  $363 = Math_fround($139 * $310);
  $364 = Math_fround($125 * $314);
  $365 = Math_fround($363 + $364);
  $366 = Math_fround($132 * $307);
  $367 = Math_fround($366 + $365);
  $368 = Math_fround($118 * $312);
  $369 = Math_fround($367 - $368);
  $370 = Math_fround($139 * $312);
  $371 = Math_fround($132 * $314);
  $372 = Math_fround($370 + $371);
  $373 = Math_fround($118 * $310);
  $374 = Math_fround($373 + $372);
  $375 = Math_fround($125 * $307);
  $376 = Math_fround($374 - $375);
  $377 = Math_fround($139 * $314);
  $378 = Math_fround($118 * $307);
  $379 = Math_fround($377 - $378);
  $380 = Math_fround($125 * $310);
  $381 = Math_fround($379 - $380);
  $382 = Math_fround($132 * $312);
  $383 = Math_fround($381 - $382);
  HEAPF32[$1>>2] = $362;
  HEAPF32[$281>>2] = $369;
  HEAPF32[$282>>2] = $376;
  HEAPF32[$283>>2] = $383;
  HEAPF32[$284>>2] = $353;
  HEAPF32[$285>>2] = $354;
  HEAPF32[$286>>2] = $355;
  $384 = (($293) + 20|0);
  $385 = $386 >>> 30;
  if ((($385|0) == 3)) {
   $$pre$phi$i$iZ2D = $294;
   label = 30;
  } else if ((($385|0) == 2)) {
   $387 = HEAP32[$294>>2]|0;
   $388 = (($387) + 2417|0);
   $389 = HEAP8[$388>>0]|0;
   $390 = ($389<<24>>24)==(0);
   if ($390) {
    label = 29;
   } else {
    $$pre$phi$i$iZ2D = $294;
    label = 30;
   }
  } else {
   label = 29;
  }
  if ((label|0) == 29) {
   label = 0;
   __ZN5physx2Sc21ArticulationJointCore13setParentPoseERKNS_11PxTransformE($384,$1);
  }
  else if ((label|0) == 30) {
   label = 0;
   $391 = (($293) + 16|0);
   $392 = HEAP32[$391>>2]|0;
   $393 = ($392|0)==(0|0);
   if ($393) {
    $394 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
    $395 = $386 >>> 24;
    $396 = $395 & 15;
    $397 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($394,$396)|0);
    HEAP32[$391>>2] = $397;
    $$pre29 = Math_fround(HEAPF32[$1>>2]);
    $398 = $$pre29;$399 = $397;
   } else {
    $398 = $362;$399 = $392;
   }
   HEAPF32[$399>>2] = $398;
   $400 = Math_fround(HEAPF32[$281>>2]);
   $401 = (($399) + 4|0);
   HEAPF32[$401>>2] = $400;
   $402 = Math_fround(HEAPF32[$282>>2]);
   $403 = (($399) + 8|0);
   HEAPF32[$403>>2] = $402;
   $404 = Math_fround(HEAPF32[$283>>2]);
   $405 = (($399) + 12|0);
   HEAPF32[$405>>2] = $404;
   $406 = Math_fround(HEAPF32[$284>>2]);
   $407 = (($399) + 16|0);
   HEAPF32[$407>>2] = $406;
   $408 = Math_fround(HEAPF32[$285>>2]);
   $409 = (($399) + 20|0);
   HEAPF32[$409>>2] = $408;
   $410 = Math_fround(HEAPF32[$286>>2]);
   $411 = (($399) + 24|0);
   HEAPF32[$411>>2] = $410;
   $412 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($412,$294);
   $413 = HEAP32[$295>>2]|0;
   $414 = $413 | 1;
   HEAP32[$295>>2] = $414;
  }
  $415 = (($i$018) + 1)|0;
  $416 = HEAP32[$275>>2]|0;
  $417 = ($415>>>0)<($416>>>0);
  if ($417) {
   $i$018 = $415;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25setCMassLocalPoseInternalERKNS_11PxTransformE($this,$body2Actor) {
 $this = $this|0;
 $body2Actor = $body2Actor|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0;
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $newBody2World = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $newBody2World = sp + 28|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$this);
 $4 = (($body2Actor) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = (($body2Actor) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * Math_fround(2.0));
 $10 = (($body2Actor) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * Math_fround(2.0));
 $13 = (($0) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $14);
 $16 = Math_fround($15 + Math_fround(-0.5));
 $17 = Math_fround(HEAPF32[$0>>2]);
 $18 = Math_fround($6 * $17);
 $19 = (($0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($9 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($0) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($12 * $24);
 $26 = Math_fround($22 + $25);
 $27 = Math_fround($6 * $16);
 $28 = Math_fround($12 * $20);
 $29 = Math_fround($9 * $24);
 $30 = Math_fround($28 - $29);
 $31 = Math_fround($14 * $30);
 $32 = Math_fround($27 + $31);
 $33 = Math_fround($17 * $26);
 $34 = Math_fround($33 + $32);
 $35 = Math_fround($9 * $16);
 $36 = Math_fround($6 * $24);
 $37 = Math_fround($12 * $17);
 $38 = Math_fround($36 - $37);
 $39 = Math_fround($14 * $38);
 $40 = Math_fround($35 + $39);
 $41 = Math_fround($20 * $26);
 $42 = Math_fround($41 + $40);
 $43 = Math_fround($12 * $16);
 $44 = Math_fround($9 * $17);
 $45 = Math_fround($6 * $20);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($14 * $46);
 $48 = Math_fround($43 + $47);
 $49 = Math_fround($24 * $26);
 $50 = Math_fround($48 + $49);
 $51 = (($0) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 + $34);
 $54 = (($0) + 20|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 + $42);
 $57 = (($0) + 24|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 + $50);
 $60 = Math_fround(HEAPF32[$body2Actor>>2]);
 $61 = Math_fround($14 * $60);
 $62 = (($body2Actor) + 12|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($17 * $63);
 $65 = Math_fround($61 + $64);
 $66 = (($body2Actor) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($20 * $67);
 $69 = Math_fround($65 + $68);
 $70 = (($body2Actor) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($24 * $71);
 $73 = Math_fround($69 - $72);
 $74 = Math_fround($14 * $71);
 $75 = Math_fround($20 * $63);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($24 * $60);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($17 * $67);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($14 * $67);
 $82 = Math_fround($24 * $63);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($17 * $71);
 $85 = Math_fround($84 + $83);
 $86 = Math_fround($20 * $60);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($14 * $63);
 $89 = Math_fround($17 * $60);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($20 * $71);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($24 * $67);
 $94 = Math_fround($92 - $93);
 HEAPF32[$newBody2World>>2] = $73;
 $95 = (($newBody2World) + 4|0);
 HEAPF32[$95>>2] = $80;
 $96 = (($newBody2World) + 8|0);
 HEAPF32[$96>>2] = $87;
 $97 = (($newBody2World) + 12|0);
 HEAPF32[$97>>2] = $94;
 $98 = (($newBody2World) + 16|0);
 HEAPF32[$98>>2] = $53;
 $99 = (($newBody2World) + 20|0);
 HEAPF32[$99>>2] = $56;
 $100 = (($newBody2World) + 24|0);
 HEAPF32[$100>>2] = $59;
 $101 = (($this) + 48|0);
 $102 = (($this) + 224|0);
 HEAPF32[$102>>2] = $73;
 $103 = (($this) + 228|0);
 HEAPF32[$103>>2] = $80;
 $104 = (($this) + 232|0);
 HEAPF32[$104>>2] = $87;
 $105 = (($this) + 236|0);
 HEAPF32[$105>>2] = $94;
 $106 = (($this) + 240|0);
 HEAPF32[$106>>2] = $53;
 $107 = (($this) + 244|0);
 HEAPF32[$107>>2] = $56;
 $108 = (($this) + 248|0);
 HEAPF32[$108>>2] = $59;
 $109 = (($this) + 52|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = $110 >>> 30;
 if ((($111|0) == 2)) {
  $112 = HEAP32[$101>>2]|0;
  $113 = (($112) + 2417|0);
  $114 = HEAP8[$113>>0]|0;
  $115 = ($114<<24>>24)==(0);
  if ($115) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($111|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $116 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore13setBody2WorldERKNS_11PxTransformE($116,$newBody2World);
 }
 else if ((label|0) == 4) {
  $117 = (($this) + 284|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = $118 & 65536;
  $120 = ($119|0)==(0);
  if ($120) {
   $121 = $118 | 131072;
   HEAP32[$117>>2] = $121;
  }
  $122 = HEAP32[$101>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($122,$101);
  $123 = HEAP32[$117>>2]|0;
  $124 = $123 | 65536;
  HEAP32[$117>>2] = $124;
 }
 $125 = HEAP32[$109>>2]|0;
 $126 = $125 >>> 30;
 if ((($126|0) == 2)) {
  $127 = HEAP32[$101>>2]|0;
  $128 = (($127) + 2417|0);
  $129 = HEAP8[$128>>0]|0;
  $130 = ($129<<24>>24)==(0);
  if ($130) {
   label = 10;
  } else {
   $$pre$phi$i$iZ2D = $101;
   label = 11;
  }
 } else if ((($126|0) == 3)) {
  $$pre$phi$i$iZ2D = $101;
  label = 11;
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $131 = Math_fround(HEAPF32[$body2Actor>>2]);
  $132 = (($this) + 112|0);
  HEAPF32[$132>>2] = $131;
  $133 = Math_fround(HEAPF32[$70>>2]);
  $134 = (($this) + 116|0);
  HEAPF32[$134>>2] = $133;
  $135 = Math_fround(HEAPF32[$66>>2]);
  $136 = (($this) + 120|0);
  HEAPF32[$136>>2] = $135;
  $137 = Math_fround(HEAPF32[$62>>2]);
  $138 = (($this) + 124|0);
  HEAPF32[$138>>2] = $137;
  $139 = Math_fround(HEAPF32[$4>>2]);
  $140 = (($this) + 128|0);
  HEAPF32[$140>>2] = $139;
  $141 = Math_fround(HEAPF32[$7>>2]);
  $142 = (($this) + 132|0);
  HEAPF32[$142>>2] = $141;
  $143 = Math_fround(HEAPF32[$10>>2]);
  $144 = (($this) + 136|0);
  HEAPF32[$144>>2] = $143;
 }
 else if ((label|0) == 11) {
  $145 = (($this) + 56|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = ($146|0)==(0|0);
  if ($147) {
   $148 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $149 = $125 >>> 24;
   $150 = $149 & 15;
   $151 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($148,$150)|0);
   HEAP32[$145>>2] = $151;
   $154 = $151;
  } else {
   $154 = $146;
  }
  $152 = Math_fround(HEAPF32[$body2Actor>>2]);
  $153 = (($154) + 144|0);
  HEAPF32[$153>>2] = $152;
  $155 = Math_fround(HEAPF32[$70>>2]);
  $156 = (($154) + 148|0);
  HEAPF32[$156>>2] = $155;
  $157 = Math_fround(HEAPF32[$66>>2]);
  $158 = (($154) + 152|0);
  HEAPF32[$158>>2] = $157;
  $159 = Math_fround(HEAPF32[$62>>2]);
  $160 = (($154) + 156|0);
  HEAPF32[$160>>2] = $159;
  $161 = Math_fround(HEAPF32[$4>>2]);
  $162 = (($154) + 160|0);
  HEAPF32[$162>>2] = $161;
  $163 = Math_fround(HEAPF32[$7>>2]);
  $164 = (($154) + 164|0);
  HEAPF32[$164>>2] = $163;
  $165 = Math_fround(HEAPF32[$10>>2]);
  $166 = (($154) + 168|0);
  HEAPF32[$166>>2] = $165;
  $167 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($167,$101);
  $168 = (($this) + 284|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = $169 | 512;
  HEAP32[$168>>2] = $170;
 }
 $171 = (($this) + 16|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = ($172|0)==(0|0);
 if ($173) {
  STACKTOP = sp;return;
 }
 $174 = (($172) + 36|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = (($172) + 40|0);
 $177 = HEAP32[$176>>2]|0;
 $178 = ($177|0)==(0);
 if ($178) {
  STACKTOP = sp;return;
 }
 $180 = 0;
 while(1) {
  $179 = (($180) + 1)|0;
  $181 = (($175) + ($180<<3)|0);
  $182 = HEAP8[$181>>0]|0;
  $183 = ($182<<24>>24)==(0);
  if ($183) {
   $185 = ((($175) + ($180<<3)|0) + 4|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = ($186|0)==(0|0);
   if ($187) {
    label = 21;
    break;
   }
   __ZN5physx12NpConstraint8comShiftEPNS_12PxRigidActorE($186,$this);
  }
  $184 = ($179>>>0)<($177>>>0);
  if ($184) {
   $180 = $179;
  } else {
   label = 21;
   break;
  }
 }
 if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx18NpArticulationLink8addForceERKNS_6PxVec3ENS_11PxForceMode4EnumEb($this,$force,$mode,$autowake) {
 $this = $this|0;
 $force = $force|0;
 $mode = $mode|0;
 $autowake = $autowake|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE15addSpatialForceEPKNS_6PxVec3ES5_NS_11PxForceMode4EnumE($this,$force,0,$mode);
 $0 = (($this) + 288|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$force>>2]);
 $3 = $2 == Math_fround(0.0);
 if ($3) {
  $4 = (($force) + 4|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = $5 == Math_fround(0.0);
  if ($6) {
   $7 = (($force) + 8|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $phitmp = $8 != Math_fround(0.0);
   $9 = $phitmp;
  } else {
   $9 = 1;
  }
 } else {
  $9 = 1;
 }
 __ZN5physx14NpArticulation14wakeUpInternalEbb($1,$9,$autowake);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE15addSpatialForceEPKNS_6PxVec3ES5_NS_11PxForceMode4EnumE($this,$force,$torque,$mode) {
 $this = $this|0;
 $force = $force|0;
 $torque = $torque|0;
 $mode = $mode|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$pre = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0;
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $angAcc = 0, $angVelDelta = 0, $linAcc = 0, $linVelDelta = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $linAcc = sp + 108|0;
 $angAcc = sp;
 $0 = sp + 12|0;
 $linVelDelta = sp + 48|0;
 $angVelDelta = sp + 60|0;
 $1 = sp + 72|0;
 if ((($mode|0) == 2)) {
  $145 = (($this) + 48|0);
  __ZN5physx3Scb4Body18addSpatialVelocityEPKNS_6PxVec3ES4_($145,$force,$torque);
  STACKTOP = sp;return;
 } else if ((($mode|0) == 1)) {
  $74 = ($force|0)==(0|0);
  if ($74) {
   $$1 = 0;
  } else {
   $75 = (($this) + 284|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = $76 & 1;
   $78 = ($77|0)==(0);
   if ($78) {
    $92 = (($this) + 64|0);
    $93 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($92)));
    $96 = $93;
   } else {
    $79 = (($this) + 56|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ($80|0)==(0|0);
    if ($81) {
     $82 = (($this) + 48|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (($this) + 52|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = $85 >>> 24;
     $87 = $86 & 15;
     $88 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($83,$87)|0);
     HEAP32[$79>>2] = $88;
     $90 = $88;
    } else {
     $90 = $80;
    }
    $89 = (($90) + 92|0);
    $91 = Math_fround(HEAPF32[$89>>2]);
    $96 = $91;
   }
   $94 = Math_fround(HEAPF32[$force>>2]);
   $95 = Math_fround($96 * $94);
   $97 = (($force) + 4|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = Math_fround($96 * $98);
   $100 = (($force) + 8|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = Math_fround($96 * $101);
   HEAPF32[$linVelDelta>>2] = $95;
   $103 = (($linVelDelta) + 4|0);
   HEAPF32[$103>>2] = $99;
   $104 = (($linVelDelta) + 8|0);
   HEAPF32[$104>>2] = $102;
   $$1 = $linVelDelta;
  }
  $105 = ($torque|0)==(0|0);
  $$pre15 = (($this) + 48|0);
  if ($105) {
   $$12 = 0;
  } else {
   __ZNK5physx3Scb4Body29getGlobalInertiaTensorInverseEv($1,$$pre15);
   $106 = Math_fround(HEAPF32[$torque>>2]);
   $107 = Math_fround(HEAPF32[$1>>2]);
   $108 = Math_fround($106 * $107);
   $109 = (($1) + 4|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = Math_fround($106 * $110);
   $112 = (($1) + 8|0);
   $113 = Math_fround(HEAPF32[$112>>2]);
   $114 = Math_fround($106 * $113);
   $115 = (($torque) + 4|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   $117 = (($1) + 12|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = Math_fround($116 * $118);
   $120 = (($1) + 16|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = Math_fround($116 * $121);
   $123 = (($1) + 20|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = Math_fround($116 * $124);
   $126 = Math_fround($108 + $119);
   $127 = Math_fround($111 + $122);
   $128 = Math_fround($114 + $125);
   $129 = (($torque) + 8|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = (($1) + 24|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = Math_fround($130 * $132);
   $134 = (($1) + 28|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = Math_fround($130 * $135);
   $137 = (($1) + 32|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   $139 = Math_fround($130 * $138);
   $140 = Math_fround($126 + $133);
   $141 = Math_fround($127 + $136);
   $142 = Math_fround($128 + $139);
   HEAPF32[$angVelDelta>>2] = $140;
   $143 = (($angVelDelta) + 4|0);
   HEAPF32[$143>>2] = $141;
   $144 = (($angVelDelta) + 8|0);
   HEAPF32[$144>>2] = $142;
   $$12 = $angVelDelta;
  }
  __ZN5physx3Scb4Body18addSpatialVelocityEPKNS_6PxVec3ES4_($$pre15,$$1,$$12);
  STACKTOP = sp;return;
 } else if ((($mode|0) == 3)) {
  $73 = (($this) + 48|0);
  __ZN5physx3Scb4Body22addSpatialAccelerationEPKNS_6PxVec3ES4_($73,$force,$torque);
  STACKTOP = sp;return;
 } else if ((($mode|0) == 0)) {
  $2 = ($force|0)==(0|0);
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (($this) + 284|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = $4 & 1;
   $6 = ($5|0)==(0);
   if ($6) {
    $20 = (($this) + 64|0);
    $21 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($20)));
    $24 = $21;
   } else {
    $7 = (($this) + 56|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $10 = (($this) + 48|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($this) + 52|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = $13 >>> 24;
     $15 = $14 & 15;
     $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$15)|0);
     HEAP32[$7>>2] = $16;
     $18 = $16;
    } else {
     $18 = $8;
    }
    $17 = (($18) + 92|0);
    $19 = Math_fround(HEAPF32[$17>>2]);
    $24 = $19;
   }
   $22 = Math_fround(HEAPF32[$force>>2]);
   $23 = Math_fround($24 * $22);
   $25 = (($force) + 4|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = Math_fround($24 * $26);
   $28 = (($force) + 8|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($24 * $29);
   HEAPF32[$linAcc>>2] = $23;
   $31 = (($linAcc) + 4|0);
   HEAPF32[$31>>2] = $27;
   $32 = (($linAcc) + 8|0);
   HEAPF32[$32>>2] = $30;
   $$0 = $linAcc;
  }
  $33 = ($torque|0)==(0|0);
  $$pre = (($this) + 48|0);
  if ($33) {
   $$01 = 0;
  } else {
   __ZNK5physx3Scb4Body29getGlobalInertiaTensorInverseEv($0,$$pre);
   $34 = Math_fround(HEAPF32[$torque>>2]);
   $35 = Math_fround(HEAPF32[$0>>2]);
   $36 = Math_fround($34 * $35);
   $37 = (($0) + 4|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($34 * $38);
   $40 = (($0) + 8|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = Math_fround($34 * $41);
   $43 = (($torque) + 4|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($0) + 12|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = Math_fround($44 * $46);
   $48 = (($0) + 16|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = Math_fround($44 * $49);
   $51 = (($0) + 20|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $53 = Math_fround($44 * $52);
   $54 = Math_fround($36 + $47);
   $55 = Math_fround($39 + $50);
   $56 = Math_fround($42 + $53);
   $57 = (($torque) + 8|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = (($0) + 24|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround($58 * $60);
   $62 = (($0) + 28|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = Math_fround($58 * $63);
   $65 = (($0) + 32|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = Math_fround($58 * $66);
   $68 = Math_fround($54 + $61);
   $69 = Math_fround($55 + $64);
   $70 = Math_fround($56 + $67);
   HEAPF32[$angAcc>>2] = $68;
   $71 = (($angAcc) + 4|0);
   HEAPF32[$71>>2] = $69;
   $72 = (($angAcc) + 8|0);
   HEAPF32[$72>>2] = $70;
   $$01 = $angAcc;
  }
  __ZN5physx3Scb4Body22addSpatialAccelerationEPKNS_6PxVec3ES4_($$pre,$$0,$$01);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx18NpArticulationLink9addTorqueERKNS_6PxVec3ENS_11PxForceMode4EnumEb($this,$torque,$mode,$autowake) {
 $this = $this|0;
 $torque = $torque|0;
 $mode = $mode|0;
 $autowake = $autowake|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE15addSpatialForceEPKNS_6PxVec3ES5_NS_11PxForceMode4EnumE($this,0,$torque,$mode);
 $0 = (($this) + 288|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$torque>>2]);
 $3 = $2 == Math_fround(0.0);
 if ($3) {
  $4 = (($torque) + 4|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = $5 == Math_fround(0.0);
  if ($6) {
   $7 = (($torque) + 8|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $phitmp = $8 != Math_fround(0.0);
   $9 = $phitmp;
  } else {
   $9 = 1;
  }
 } else {
  $9 = 1;
 }
 __ZN5physx14NpArticulation14wakeUpInternalEbb($1,$9,$autowake);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink10clearForceENS_11PxForceMode4EnumE($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17clearSpatialForceENS_11PxForceMode4EnumE($this,$mode);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17clearSpatialForceENS_11PxForceMode4EnumE($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($mode|0) == 0)) {
  $0 = (($this) + 48|0);
  $1 = (($this) + 52|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = $2 >>> 30;
  if ((($3|0) == 2)) {
   $4 = HEAP32[$0>>2]|0;
   $5 = (($4) + 2416|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 4;
   }
  } else if (!((($3|0) == 3))) {
   label = 4;
  }
  if ((label|0) == 4) {
   $8 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore24clearSpatialAccelerationEv($8);
   STACKTOP = sp;return;
  }
  $9 = (($this) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $12 = HEAP32[$0>>2]|0;
   $13 = $2 >>> 24;
   $14 = $13 & 15;
   $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
   HEAP32[$9>>2] = $15;
   $17 = $15;
  } else {
   $17 = $10;
  }
  $16 = (($17) + 220|0);
  $18 = (($this) + 284|0);
  ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & -16385;
  HEAP32[$18>>2] = $20;
  STACKTOP = sp;return;
 } else if ((($mode|0) == 1)) {
  $42 = (($this) + 48|0);
  $43 = (($this) + 52|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 >>> 30;
  if ((($45|0) == 2)) {
   $46 = HEAP32[$42>>2]|0;
   $47 = (($46) + 2416|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    label = 16;
   }
  } else if (!((($45|0) == 3))) {
   label = 16;
  }
  if ((label|0) == 16) {
   $50 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore20clearSpatialVelocityEv($50);
   STACKTOP = sp;return;
  }
  $51 = (($this) + 56|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   $54 = HEAP32[$42>>2]|0;
   $55 = $44 >>> 24;
   $56 = $55 & 15;
   $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
   HEAP32[$51>>2] = $57;
   $59 = $57;
  } else {
   $59 = $52;
  }
  $58 = (($59) + 244|0);
  $60 = (($this) + 284|0);
  ;HEAP32[$58+0>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;HEAP32[$58+12>>2]=0|0;HEAP32[$58+16>>2]=0|0;HEAP32[$58+20>>2]=0|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = $61 & -32769;
  HEAP32[$60>>2] = $62;
  STACKTOP = sp;return;
 } else if ((($mode|0) == 2)) {
  $63 = (($this) + 48|0);
  $64 = (($this) + 52|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = $65 >>> 30;
  if ((($66|0) == 2)) {
   $67 = HEAP32[$63>>2]|0;
   $68 = (($67) + 2416|0);
   $69 = HEAP8[$68>>0]|0;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    label = 22;
   }
  } else if (!((($66|0) == 3))) {
   label = 22;
  }
  if ((label|0) == 22) {
   $71 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore20clearSpatialVelocityEv($71);
   STACKTOP = sp;return;
  }
  $72 = (($this) + 56|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==(0|0);
  if ($74) {
   $75 = HEAP32[$63>>2]|0;
   $76 = $65 >>> 24;
   $77 = $76 & 15;
   $78 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($75,$77)|0);
   HEAP32[$72>>2] = $78;
   $80 = $78;
  } else {
   $80 = $73;
  }
  $79 = (($80) + 244|0);
  $81 = (($this) + 284|0);
  ;HEAP32[$79+0>>2]=0|0;HEAP32[$79+4>>2]=0|0;HEAP32[$79+8>>2]=0|0;HEAP32[$79+12>>2]=0|0;HEAP32[$79+16>>2]=0|0;HEAP32[$79+20>>2]=0|0;
  $82 = HEAP32[$81>>2]|0;
  $83 = $82 & -32769;
  HEAP32[$81>>2] = $83;
  STACKTOP = sp;return;
 } else if ((($mode|0) == 3)) {
  $21 = (($this) + 48|0);
  $22 = (($this) + 52|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 >>> 30;
  if ((($24|0) == 2)) {
   $25 = HEAP32[$21>>2]|0;
   $26 = (($25) + 2416|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    label = 10;
   }
  } else if (!((($24|0) == 3))) {
   label = 10;
  }
  if ((label|0) == 10) {
   $29 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore24clearSpatialAccelerationEv($29);
   STACKTOP = sp;return;
  }
  $30 = (($this) + 56|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0|0);
  if ($32) {
   $33 = HEAP32[$21>>2]|0;
   $34 = $23 >>> 24;
   $35 = $34 & 15;
   $36 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($33,$35)|0);
   HEAP32[$30>>2] = $36;
   $38 = $36;
  } else {
   $38 = $31;
  }
  $37 = (($38) + 220|0);
  $39 = (($this) + 284|0);
  ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP32[$37+16>>2]=0|0;HEAP32[$37+20>>2]=0|0;
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & -16385;
  HEAP32[$39>>2] = $41;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx18NpArticulationLink11clearTorqueENS_11PxForceMode4EnumE($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17clearSpatialForceENS_11PxForceMode4EnumE($this,$mode);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink13setGlobalPoseERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($this,$pose,1);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink13setGlobalPoseERKNS_11PxTransformEb($this,$pose,$autowake) {
 $this = $this|0;
 $pose = $pose|0;
 $autowake = $autowake|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $autowake$not = 0, $body2World = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $body2World = sp;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = (($this) + 48|0);
 $2 = (($this) + 284|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 512;
 $5 = ($4|0)==(0);
 if ($5) {
  $17 = (($this) + 112|0);
  $19 = $17;
 } else {
  $6 = (($this) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $9 = HEAP32[$1>>2]|0;
   $10 = (($this) + 52|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $11 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($9,$13)|0);
   HEAP32[$6>>2] = $14;
   $16 = $14;
  } else {
   $16 = $7;
  }
  $15 = (($16) + 144|0);
  $19 = $15;
 }
 $18 = (($19) + 16|0);
 $20 = Math_fround(HEAPF32[$18>>2]);
 $21 = Math_fround($20 * Math_fround(2.0));
 $22 = (($19) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * Math_fround(2.0));
 $25 = (($19) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * Math_fround(2.0));
 $28 = (($pose) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $29);
 $31 = Math_fround($30 + Math_fround(-0.5));
 $32 = Math_fround(HEAPF32[$pose>>2]);
 $33 = Math_fround($21 * $32);
 $34 = (($pose) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($24 * $35);
 $37 = Math_fround($33 + $36);
 $38 = (($pose) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($27 * $39);
 $41 = Math_fround($37 + $40);
 $42 = Math_fround($21 * $31);
 $43 = Math_fround($27 * $35);
 $44 = Math_fround($24 * $39);
 $45 = Math_fround($43 - $44);
 $46 = Math_fround($29 * $45);
 $47 = Math_fround($42 + $46);
 $48 = Math_fround($32 * $41);
 $49 = Math_fround($48 + $47);
 $50 = Math_fround($24 * $31);
 $51 = Math_fround($21 * $39);
 $52 = Math_fround($27 * $32);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($29 * $53);
 $55 = Math_fround($50 + $54);
 $56 = Math_fround($35 * $41);
 $57 = Math_fround($56 + $55);
 $58 = Math_fround($27 * $31);
 $59 = Math_fround($24 * $32);
 $60 = Math_fround($21 * $35);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($29 * $61);
 $63 = Math_fround($58 + $62);
 $64 = Math_fround($39 * $41);
 $65 = Math_fround($63 + $64);
 $66 = (($pose) + 16|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 + $49);
 $69 = (($pose) + 20|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 + $57);
 $72 = (($pose) + 24|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 + $65);
 $75 = Math_fround(HEAPF32[$19>>2]);
 $76 = Math_fround($29 * $75);
 $77 = (($19) + 12|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($32 * $78);
 $80 = Math_fround($76 + $79);
 $81 = (($19) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($35 * $82);
 $84 = Math_fround($80 + $83);
 $85 = (($19) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($39 * $86);
 $88 = Math_fround($84 - $87);
 $89 = Math_fround($29 * $86);
 $90 = Math_fround($35 * $78);
 $91 = Math_fround($90 + $89);
 $92 = Math_fround($39 * $75);
 $93 = Math_fround($92 + $91);
 $94 = Math_fround($32 * $82);
 $95 = Math_fround($93 - $94);
 $96 = Math_fround($29 * $82);
 $97 = Math_fround($39 * $78);
 $98 = Math_fround($97 + $96);
 $99 = Math_fround($32 * $86);
 $100 = Math_fround($99 + $98);
 $101 = Math_fround($35 * $75);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($29 * $78);
 $104 = Math_fround($32 * $75);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($35 * $86);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($39 * $82);
 $109 = Math_fround($107 - $108);
 HEAPF32[$body2World>>2] = $88;
 $110 = (($body2World) + 4|0);
 HEAPF32[$110>>2] = $95;
 $111 = (($body2World) + 8|0);
 HEAPF32[$111>>2] = $102;
 $112 = (($body2World) + 12|0);
 HEAPF32[$112>>2] = $109;
 $113 = (($body2World) + 16|0);
 HEAPF32[$113>>2] = $68;
 $114 = (($body2World) + 20|0);
 HEAPF32[$114>>2] = $71;
 $115 = (($body2World) + 24|0);
 HEAPF32[$115>>2] = $74;
 $116 = (($this) + 224|0);
 HEAPF32[$116>>2] = $88;
 $117 = (($this) + 228|0);
 HEAPF32[$117>>2] = $95;
 $118 = (($this) + 232|0);
 HEAPF32[$118>>2] = $102;
 $119 = (($this) + 236|0);
 HEAPF32[$119>>2] = $109;
 $120 = (($this) + 240|0);
 HEAPF32[$120>>2] = $68;
 $121 = (($this) + 244|0);
 HEAPF32[$121>>2] = $71;
 $122 = (($this) + 248|0);
 HEAPF32[$122>>2] = $74;
 $123 = (($this) + 52|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = $124 >>> 30;
 if ((($125|0) == 3)) {
  $$pre = HEAP32[$1>>2]|0;
  $133 = $$pre;
  label = 10;
 } else if ((($125|0) == 2)) {
  $126 = HEAP32[$1>>2]|0;
  $127 = (($126) + 2417|0);
  $128 = HEAP8[$127>>0]|0;
  $129 = ($128<<24>>24)==(0);
  if ($129) {
   label = 9;
  } else {
   $133 = $126;
   label = 10;
  }
 } else {
  label = 9;
 }
 if ((label|0) == 9) {
  $130 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore13setBody2WorldERKNS_11PxTransformE($130,$body2World);
 }
 else if ((label|0) == 10) {
  $131 = HEAP32[$2>>2]|0;
  $132 = $131 & -131073;
  HEAP32[$2>>2] = $132;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($133,$1);
  $134 = HEAP32[$2>>2]|0;
  $135 = $134 | 65536;
  HEAP32[$2>>2] = $135;
 }
 $136 = ($0|0)==(0|0);
 $autowake$not = $autowake ^ 1;
 $brmerge = $136 | $autowake$not;
 if ($brmerge) {
  STACKTOP = sp;return;
 }
 $137 = (($this) + 288|0);
 $138 = HEAP32[$137>>2]|0;
 __ZN5physx14NpArticulation14wakeUpInternalEbb($138,0,1);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink17setLinearVelocityERKNS_6PxVec3Eb($this,$velocity,$autowake) {
 $this = $this|0;
 $velocity = $velocity|0;
 $autowake = $autowake|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = (($this) + 48|0);
 $2 = Math_fround(HEAPF32[$velocity>>2]);
 $3 = (($this) + 252|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($velocity) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 256|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($velocity) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 260|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($this) + 52|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 3)) {
  $$pre$i = HEAP32[$1>>2]|0;
  $23 = $$pre$i;
  label = 5;
 } else if ((($12|0) == 2)) {
  $13 = HEAP32[$1>>2]|0;
  $14 = (($13) + 2416|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   label = 4;
  } else {
   $23 = $13;
   label = 5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $17 = Math_fround(HEAPF32[$velocity>>2]);
  $18 = (($this) + 144|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround(HEAPF32[$4>>2]);
  $20 = (($this) + 148|0);
  HEAPF32[$20>>2] = $19;
  $21 = Math_fround(HEAPF32[$7>>2]);
  $22 = (($this) + 152|0);
  HEAPF32[$22>>2] = $21;
 }
 else if ((label|0) == 5) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($23,$1);
  $24 = (($this) + 284|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 | 262144;
  HEAP32[$24>>2] = $26;
 }
 $27 = ($0|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (($this) + 288|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = Math_fround(HEAPF32[$velocity>>2]);
 $31 = $30 == Math_fround(0.0);
 if ($31) {
  $32 = Math_fround(HEAPF32[$4>>2]);
  $33 = $32 == Math_fround(0.0);
  if ($33) {
   $34 = Math_fround(HEAPF32[$7>>2]);
   $phitmp = $34 != Math_fround(0.0);
   $35 = $phitmp;
  } else {
   $35 = 1;
  }
 } else {
  $35 = 1;
 }
 __ZN5physx14NpArticulation14wakeUpInternalEbb($29,$35,$autowake);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink18setAngularVelocityERKNS_6PxVec3Eb($this,$velocity,$autowake) {
 $this = $this|0;
 $velocity = $velocity|0;
 $autowake = $autowake|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = (($this) + 48|0);
 $2 = Math_fround(HEAPF32[$velocity>>2]);
 $3 = (($this) + 264|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($velocity) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 268|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($velocity) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 272|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($this) + 52|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 2)) {
  $13 = HEAP32[$1>>2]|0;
  $14 = (($13) + 2416|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   label = 4;
  } else {
   $23 = $13;
   label = 5;
  }
 } else if ((($12|0) == 3)) {
  $$pre$i = HEAP32[$1>>2]|0;
  $23 = $$pre$i;
  label = 5;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $17 = Math_fround(HEAPF32[$velocity>>2]);
  $18 = (($this) + 160|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround(HEAPF32[$4>>2]);
  $20 = (($this) + 164|0);
  HEAPF32[$20>>2] = $19;
  $21 = Math_fround(HEAPF32[$7>>2]);
  $22 = (($this) + 168|0);
  HEAPF32[$22>>2] = $21;
 }
 else if ((label|0) == 5) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($23,$1);
  $24 = (($this) + 284|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 | 524288;
  HEAP32[$24>>2] = $26;
 }
 $27 = ($0|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (($this) + 288|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = Math_fround(HEAPF32[$velocity>>2]);
 $31 = $30 == Math_fround(0.0);
 if ($31) {
  $32 = Math_fround(HEAPF32[$4>>2]);
  $33 = $32 == Math_fround(0.0);
  if ($33) {
   $34 = Math_fround(HEAPF32[$7>>2]);
   $phitmp = $34 != Math_fround(0.0);
   $35 = $phitmp;
  } else {
   $35 = 1;
  }
 } else {
  $35 = 1;
 }
 __ZN5physx14NpArticulation14wakeUpInternalEbb($29,$35,$autowake);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$scene) {
 $this = $this|0;
 $out = $out|0;
 $scene = $scene|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $or$cond = 0, $viz = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 48|0;
 $1 = sp;
 $viz = sp + 32|0;
 __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$scene);
 $2 = (($this) + 48|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $14 = $4 >>> 24;
  $15 = $14 & 15;
  $16 = ((444424 + ($15<<2)|0) + 24|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $2;
  $19 = (($17) + ($18))|0;
  $20 = $19;
  $21 = (($20) + 8|0);
  $$in = $21;
 } else {
  $7 = (($this) + 56|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = $4 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($10,$12)|0);
   HEAP32[$7>>2] = $13;
   $143 = $13;
  } else {
   $143 = $8;
  }
  $$in = $143;
 }
 $22 = HEAP16[$$in>>1]|0;
 $23 = $22 & 1;
 $24 = ($23<<16>>16)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (FUNCTION_TABLE_ii[$27 & 4095]($this)|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 296|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (Math_fround(FUNCTION_TABLE_fii[$31 & 63]($28,0)));
 $33 = HEAP32[$this>>2]|0;
 $34 = (($33) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (FUNCTION_TABLE_ii[$35 & 4095]($this)|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 296|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (Math_fround(FUNCTION_TABLE_fii[$39 & 63]($36,3)));
 $41 = Math_fround($32 * $40);
 $42 = $41 != Math_fround(0.0);
 if ($42) {
  $43 = (($this) + 284|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & 2;
  $46 = ($45|0)==(0);
  if ($46) {
   $57 = (($this) + 64|0);
   $58 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($57)|0);
   $60 = $58;
  } else {
   $47 = (($this) + 56|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if ($49) {
    $50 = HEAP32[$2>>2]|0;
    $51 = HEAP32[$3>>2]|0;
    $52 = $51 >>> 24;
    $53 = $52 & 15;
    $54 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($50,$53)|0);
    HEAP32[$47>>2] = $54;
    $56 = $54;
   } else {
    $56 = $48;
   }
   $55 = (($56) + 96|0);
   $60 = $55;
  }
  $59 = Math_fround(HEAPF32[$60>>2]);
  $61 = (($60) + 4|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = (($60) + 8|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = $59 == Math_fround(0.0);
  if ($65) {
   $91 = Math_fround(0.0);
  } else {
   $66 = Math_fround(Math_fround(1.0) / $59);
   $91 = $66;
  }
  $67 = $62 == Math_fround(0.0);
  if ($67) {
   $93 = Math_fround(0.0);
  } else {
   $68 = Math_fround(Math_fround(1.0) / $62);
   $93 = $68;
  }
  $69 = $64 == Math_fround(0.0);
  if ($69) {
   $95 = Math_fround(0.0);
  } else {
   $70 = Math_fround(Math_fround(1.0) / $64);
   $95 = $70;
  }
  $71 = HEAP32[$43>>2]|0;
  $72 = $71 & 1;
  $73 = ($72|0)==(0);
  if ($73) {
   $85 = (($this) + 64|0);
   $86 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($85)));
   $88 = $86;
  } else {
   $74 = (($this) + 56|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($75|0)==(0|0);
   if ($76) {
    $77 = HEAP32[$2>>2]|0;
    $78 = HEAP32[$3>>2]|0;
    $79 = $78 >>> 24;
    $80 = $79 & 15;
    $81 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($77,$80)|0);
    HEAP32[$74>>2] = $81;
    $83 = $81;
   } else {
    $83 = $75;
   }
   $82 = (($83) + 92|0);
   $84 = Math_fround(HEAPF32[$82>>2]);
   $88 = $84;
  }
  $87 = Math_fround(Math_fround(1.0) / $88);
  $89 = Math_fround(Math_fround(6.0) / $87);
  $90 = Math_fround($91 * $89);
  $92 = Math_fround($93 * $89);
  $94 = Math_fround($95 * $89);
  $96 = Math_fround($92 - $90);
  $97 = Math_fround($94 + $96);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($97)))));
  $98 = (Math_fround(Math_sqrt((Math_fround($fabsf$i$i$i)))));
  $99 = Math_fround($90 - $92);
  $100 = Math_fround($94 + $99);
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($100)))));
  $101 = (Math_fround(Math_sqrt((Math_fround($fabsf$i$i1$i)))));
  $102 = Math_fround($90 + $92);
  $103 = Math_fround($102 - $94);
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($103)))));
  $104 = (Math_fround(Math_sqrt((Math_fround($fabsf$i$i2$i)))));
  $105 = (__ZN5physx2Cm12RenderOutputlsEj($out,16777215)|0);
  $106 = (($this) + 224|0);
  __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($0,$106);
  $107 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($105,$0)|0);
  $108 = Math_fround($98 * Math_fround(0.5));
  $109 = Math_fround($101 * Math_fround(0.5));
  $110 = Math_fround($104 * Math_fround(0.5));
  $111 = Math_fround(-$108);
  $112 = Math_fround(-$109);
  $113 = Math_fround(-$110);
  HEAPF32[$1>>2] = $111;
  $114 = (($1) + 4|0);
  HEAPF32[$114>>2] = $112;
  $115 = (($1) + 8|0);
  HEAPF32[$115>>2] = $113;
  $116 = (($1) + 12|0);
  HEAPF32[$116>>2] = $108;
  $117 = (($1) + 16|0);
  HEAPF32[$117>>2] = $109;
  $118 = (($1) + 20|0);
  HEAPF32[$118>>2] = $110;
  $119 = (($1) + 24|0);
  HEAP8[$119>>0] = 1;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($107,$1)|0);
 }
 $120 = HEAP32[$this>>2]|0;
 $121 = (($120) + 28|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (FUNCTION_TABLE_ii[$122 & 4095]($this)|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($124) + 296|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (Math_fround(FUNCTION_TABLE_fii[$126 & 63]($123,21)));
 $128 = Math_fround($32 * $127);
 $129 = HEAP32[$this>>2]|0;
 $130 = (($129) + 28|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = (FUNCTION_TABLE_ii[$131 & 4095]($this)|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (($133) + 296|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (Math_fround(FUNCTION_TABLE_fii[$135 & 63]($132,22)));
 $137 = Math_fround($32 * $136);
 $138 = $128 != Math_fround(0.0);
 $139 = $137 != Math_fround(0.0);
 $or$cond = $138 | $139;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 HEAP32[$viz>>2] = ((418496 + 8|0));
 $140 = (($viz) + 4|0);
 HEAPF32[$140>>2] = $128;
 $141 = (($viz) + 8|0);
 HEAPF32[$141>>2] = $137;
 $142 = (($viz) + 12|0);
 HEAP32[$142>>2] = $out;
 __ZN5physx18NpArticulationLink14visualizeJointERNS_22PxConstraintVisualizerE($this,$viz);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$scene) {
 $this = $this|0;
 $out = $out|0;
 $scene = $scene|0;
 var $$0$i = Math_fround(0), $$0$i1 = Math_fround(0), $$0$i3 = Math_fround(0), $$0$i5 = Math_fround(0), $$0$i7 = Math_fround(0), $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0);
 var $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $0 = sp + 336|0;
 $1 = sp + 304|0;
 $2 = sp + 280|0;
 $3 = sp + 216|0;
 $4 = sp + 192|0;
 $5 = sp + 96|0;
 $6 = sp + 64|0;
 $7 = sp;
 $8 = sp + 160|0;
 $9 = (($this) + 20|0);
 __ZN5physx14NpShapeManager9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneERKNS_12PxRigidActorE($9,$out,$scene,$this);
 $10 = (($this) + 48|0);
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 1;
 $14 = ($13|0)==(0);
 if ($14) {
  $22 = $12 >>> 24;
  $23 = $22 & 15;
  $24 = ((444424 + ($23<<2)|0) + 24|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $10;
  $27 = (($25) + ($26))|0;
  $28 = $27;
  $29 = (($28) + 8|0);
  $$in = $29;
 } else {
  $15 = (($this) + 56|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $18 = HEAP32[$10>>2]|0;
   $19 = $12 >>> 24;
   $20 = $19 & 15;
   $21 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($18,$20)|0);
   HEAP32[$15>>2] = $21;
   $174 = $21;
  } else {
   $174 = $16;
  }
  $$in = $174;
 }
 $30 = HEAP16[$$in>>1]|0;
 $31 = $30 & 1;
 $32 = ($31<<16>>16)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($scene) + 3372|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 64;
 $36 = ($35|0)==(0);
 if ($36) {
  label = 10;
 } else {
  $37 = (($scene) + 3012|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   label = 10;
  } else {
   $40 = (($scene) + 2864|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $$0$i5 = $41;$45 = $34;
  }
 }
 if ((label|0) == 10) {
  $42 = (($scene) + 32|0);
  $43 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($42,0)));
  $$pre = HEAP32[$33>>2]|0;
  $$0$i5 = $43;$45 = $$pre;
 }
 $44 = $45 & 64;
 $46 = ($44|0)==(0);
 if ($46) {
  label = 14;
 } else {
  $47 = (($scene) + 3023|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48<<24>>24)==(0);
  if ($49) {
   label = 14;
  } else {
   $50 = (($scene) + 2908|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $$0$i7 = $51;
  }
 }
 if ((label|0) == 14) {
  $52 = (($scene) + 32|0);
  $53 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($52,11)));
  $$0$i7 = $53;
 }
 $54 = Math_fround($$0$i5 * $$0$i7);
 $55 = $54 != Math_fround(0.0);
 if ($55) {
  $56 = HEAP32[$this>>2]|0;
  $57 = (($56) + 84|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 4095]($1,$this);
  __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($0,$1);
  $59 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$0)|0);
  HEAPF32[$2>>2] = $54;
  $60 = (($2) + 4|0);
  HEAPF32[$60>>2] = $54;
  $61 = (($2) + 8|0);
  HEAPF32[$61>>2] = $54;
  $62 = (($2) + 12|0);
  HEAP32[$62>>2] = -65536;
  $63 = (($2) + 16|0);
  HEAP32[$63>>2] = -16711936;
  $64 = (($2) + 20|0);
  HEAP32[$64>>2] = -16776961;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($59,$2)|0);
 }
 $65 = HEAP32[$33>>2]|0;
 $66 = $65 & 64;
 $67 = ($66|0)==(0);
 if ($67) {
  label = 20;
 } else {
  $68 = (($scene) + 3014|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = ($69<<24>>24)==(0);
  if ($70) {
   label = 20;
  } else {
   $71 = (($scene) + 2872|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $$0$i3 = $72;
  }
 }
 if ((label|0) == 20) {
  $73 = (($scene) + 32|0);
  $74 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($73,2)));
  $$0$i3 = $74;
 }
 $75 = Math_fround($$0$i5 * $$0$i3);
 $76 = $75 != Math_fround(0.0);
 if ($76) {
  $77 = (($this) + 224|0);
  __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($3,$77);
  $78 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$3)|0);
  HEAPF32[$4>>2] = $75;
  $79 = (($4) + 4|0);
  HEAPF32[$79>>2] = $75;
  $80 = (($4) + 8|0);
  HEAPF32[$80>>2] = $75;
  $81 = (($4) + 12|0);
  HEAP32[$81>>2] = -65536;
  $82 = (($4) + 16|0);
  HEAP32[$82>>2] = -16711936;
  $83 = (($4) + 20|0);
  HEAP32[$83>>2] = -16776961;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($78,$4)|0);
 }
 $84 = HEAP32[$33>>2]|0;
 $85 = $84 & 64;
 $86 = ($85|0)==(0);
 if ($86) {
  label = 26;
 } else {
  $87 = (($scene) + 3016|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = ($88<<24>>24)==(0);
  if ($89) {
   label = 26;
  } else {
   $90 = (($scene) + 2880|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $$0$i1 = $91;
  }
 }
 if ((label|0) == 26) {
  $92 = (($scene) + 32|0);
  $93 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($92,4)));
  $$0$i1 = $93;
 }
 $94 = Math_fround($$0$i5 * $$0$i1);
 $95 = $94 != Math_fround(0.0);
 if ($95) {
  $96 = (__ZN5physx2Cm12RenderOutputlsEj($out,16777215)|0);
  HEAPF32[$5>>2] = Math_fround(1.0);
  $97 = (($5) + 4|0);
  $98 = (($5) + 20|0);
  ;HEAP32[$97+0>>2]=0|0;HEAP32[$97+4>>2]=0|0;HEAP32[$97+8>>2]=0|0;HEAP32[$97+12>>2]=0|0;
  HEAPF32[$98>>2] = Math_fround(1.0);
  $99 = (($5) + 24|0);
  $100 = (($5) + 40|0);
  ;HEAP32[$99+0>>2]=0|0;HEAP32[$99+4>>2]=0|0;HEAP32[$99+8>>2]=0|0;HEAP32[$99+12>>2]=0|0;
  HEAPF32[$100>>2] = Math_fround(1.0);
  $101 = (($5) + 44|0);
  $102 = (($5) + 60|0);
  ;HEAP32[$101+0>>2]=0|0;HEAP32[$101+4>>2]=0|0;HEAP32[$101+8>>2]=0|0;HEAP32[$101+12>>2]=0|0;
  HEAPF32[$102>>2] = Math_fround(1.0);
  $103 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($96,$5)|0);
  $104 = (($this) + 252|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($94 * $105);
  $107 = (($this) + 256|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($94 * $108);
  $110 = (($this) + 260|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround($94 * $111);
  $113 = Math_fround($94 * Math_fround(0.20000000298023223877));
  $114 = (($this) + 240|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  HEAPF32[$6>>2] = $115;
  $116 = (($6) + 4|0);
  $117 = (($this) + 244|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  HEAPF32[$116>>2] = $118;
  $119 = (($6) + 8|0);
  $120 = (($this) + 248|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  HEAPF32[$119>>2] = $121;
  $122 = Math_fround($106 + $115);
  $123 = Math_fround($109 + $118);
  $124 = Math_fround($112 + $121);
  $125 = (($6) + 12|0);
  HEAPF32[$125>>2] = $122;
  $126 = (($6) + 16|0);
  HEAPF32[$126>>2] = $123;
  $127 = (($6) + 20|0);
  HEAPF32[$127>>2] = $124;
  $128 = (($6) + 24|0);
  HEAPF32[$128>>2] = $113;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($103,$6)|0);
 }
 $129 = HEAP32[$33>>2]|0;
 $130 = $129 & 64;
 $131 = ($130|0)==(0);
 if ($131) {
  label = 32;
 } else {
  $132 = (($scene) + 3017|0);
  $133 = HEAP8[$132>>0]|0;
  $134 = ($133<<24>>24)==(0);
  if ($134) {
   label = 32;
  } else {
   $135 = (($scene) + 2884|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $$0$i = $136;
  }
 }
 if ((label|0) == 32) {
  $137 = (($scene) + 32|0);
  $138 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($137,5)));
  $$0$i = $138;
 }
 $139 = Math_fround($$0$i5 * $$0$i);
 $140 = $139 != Math_fround(0.0);
 if (!($140)) {
  STACKTOP = sp;return;
 }
 $141 = (__ZN5physx2Cm12RenderOutputlsEj($out,0)|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $142 = (($7) + 4|0);
 $143 = (($7) + 20|0);
 ;HEAP32[$142+0>>2]=0|0;HEAP32[$142+4>>2]=0|0;HEAP32[$142+8>>2]=0|0;HEAP32[$142+12>>2]=0|0;
 HEAPF32[$143>>2] = Math_fround(1.0);
 $144 = (($7) + 24|0);
 $145 = (($7) + 40|0);
 ;HEAP32[$144+0>>2]=0|0;HEAP32[$144+4>>2]=0|0;HEAP32[$144+8>>2]=0|0;HEAP32[$144+12>>2]=0|0;
 HEAPF32[$145>>2] = Math_fround(1.0);
 $146 = (($7) + 44|0);
 $147 = (($7) + 60|0);
 ;HEAP32[$146+0>>2]=0|0;HEAP32[$146+4>>2]=0|0;HEAP32[$146+8>>2]=0|0;HEAP32[$146+12>>2]=0|0;
 HEAPF32[$147>>2] = Math_fround(1.0);
 $148 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($141,$7)|0);
 $149 = (($this) + 264|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = Math_fround($139 * $150);
 $152 = (($this) + 268|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = Math_fround($139 * $153);
 $155 = (($this) + 272|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = Math_fround($139 * $156);
 $158 = Math_fround($139 * Math_fround(0.20000000298023223877));
 $159 = (($this) + 240|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 HEAPF32[$8>>2] = $160;
 $161 = (($8) + 4|0);
 $162 = (($this) + 244|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 HEAPF32[$161>>2] = $163;
 $164 = (($8) + 8|0);
 $165 = (($this) + 248|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 HEAPF32[$164>>2] = $166;
 $167 = Math_fround($151 + $160);
 $168 = Math_fround($154 + $163);
 $169 = Math_fround($157 + $166);
 $170 = (($8) + 12|0);
 HEAPF32[$170>>2] = $167;
 $171 = (($8) + 16|0);
 HEAPF32[$171>>2] = $168;
 $172 = (($8) + 20|0);
 HEAPF32[$172>>2] = $169;
 $173 = (($8) + 24|0);
 HEAPF32[$173>>2] = $158;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($148,$8)|0);
 STACKTOP = sp;return;
}
function __ZN5physx18NpArticulationLink14visualizeJointERNS_22PxConstraintVisualizerE($this,$jointViz) {
 $this = $this|0;
 $jointViz = $jointViz|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0);
 var $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = Math_fround(0);
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0.0, $344 = 0.0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0.0, $354 = 0.0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = 0.0, $359 = 0.0, $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0.0, $363 = 0.0, $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = 0, $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $cA2w = 0, $cB2w = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $lower = 0, $parentFrame = 0, $upper = 0, $yLimit = 0, $zLimit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $cA2w = sp + 184|0;
 $0 = sp + 156|0;
 $1 = sp + 128|0;
 $cB2w = sp + 100|0;
 $2 = sp + 72|0;
 $3 = sp + 44|0;
 $parentFrame = sp + 12|0;
 $lower = sp + 8|0;
 $upper = sp + 4|0;
 $yLimit = sp;
 $zLimit = sp + 40|0;
 $4 = (($this) + 296|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($0,$this);
 $10 = (($this) + 292|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($1,$11);
 $15 = (($1) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * Math_fround(2.0));
 $18 = (($1) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * Math_fround(2.0));
 $21 = (($1) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * Math_fround(2.0));
 $24 = (($0) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $25);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround(HEAPF32[$0>>2]);
 $29 = Math_fround($17 * $28);
 $30 = (($0) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($20 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($0) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($23 * $35);
 $37 = Math_fround($33 + $36);
 $38 = Math_fround($17 * $27);
 $39 = Math_fround($23 * $31);
 $40 = Math_fround($20 * $35);
 $41 = Math_fround($39 - $40);
 $42 = Math_fround($25 * $41);
 $43 = Math_fround($38 + $42);
 $44 = Math_fround($28 * $37);
 $45 = Math_fround($44 + $43);
 $46 = Math_fround($20 * $27);
 $47 = Math_fround($17 * $35);
 $48 = Math_fround($23 * $28);
 $49 = Math_fround($47 - $48);
 $50 = Math_fround($25 * $49);
 $51 = Math_fround($46 + $50);
 $52 = Math_fround($31 * $37);
 $53 = Math_fround($52 + $51);
 $54 = Math_fround($23 * $27);
 $55 = Math_fround($20 * $28);
 $56 = Math_fround($17 * $31);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($25 * $57);
 $59 = Math_fround($54 + $58);
 $60 = Math_fround($35 * $37);
 $61 = Math_fround($59 + $60);
 $62 = (($0) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 + $45);
 $65 = (($0) + 20|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 + $53);
 $68 = (($0) + 24|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $61);
 $71 = Math_fround(HEAPF32[$1>>2]);
 $72 = Math_fround($25 * $71);
 $73 = (($1) + 12|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($28 * $74);
 $76 = Math_fround($72 + $75);
 $77 = (($1) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($31 * $78);
 $80 = Math_fround($76 + $79);
 $81 = (($1) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($35 * $82);
 $84 = Math_fround($80 - $83);
 $85 = Math_fround($25 * $82);
 $86 = Math_fround($31 * $74);
 $87 = Math_fround($86 + $85);
 $88 = Math_fround($35 * $71);
 $89 = Math_fround($88 + $87);
 $90 = Math_fround($28 * $78);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($25 * $78);
 $93 = Math_fround($35 * $74);
 $94 = Math_fround($93 + $92);
 $95 = Math_fround($28 * $82);
 $96 = Math_fround($95 + $94);
 $97 = Math_fround($31 * $71);
 $98 = Math_fround($96 - $97);
 $99 = Math_fround($25 * $74);
 $100 = Math_fround($28 * $71);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($31 * $82);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($35 * $78);
 $105 = Math_fround($103 - $104);
 HEAPF32[$cA2w>>2] = $84;
 $106 = (($cA2w) + 4|0);
 HEAPF32[$106>>2] = $91;
 $107 = (($cA2w) + 8|0);
 HEAPF32[$107>>2] = $98;
 $108 = (($cA2w) + 12|0);
 HEAPF32[$108>>2] = $105;
 $109 = (($cA2w) + 16|0);
 HEAPF32[$109>>2] = $64;
 $110 = (($cA2w) + 20|0);
 HEAPF32[$110>>2] = $67;
 $111 = (($cA2w) + 24|0);
 HEAPF32[$111>>2] = $70;
 $112 = HEAP32[$5>>2]|0;
 $113 = (($112) + 84|0);
 $114 = HEAP32[$113>>2]|0;
 FUNCTION_TABLE_vii[$114 & 4095]($2,$5);
 $115 = HEAP32[$10>>2]|0;
 $116 = HEAP32[$115>>2]|0;
 $117 = (($116) + 28|0);
 $118 = HEAP32[$117>>2]|0;
 FUNCTION_TABLE_vii[$118 & 4095]($3,$115);
 $119 = (($3) + 16|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($120 * Math_fround(2.0));
 $122 = (($3) + 20|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($123 * Math_fround(2.0));
 $125 = (($3) + 24|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($126 * Math_fround(2.0));
 $128 = (($2) + 12|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($129 * $129);
 $131 = Math_fround($130 + Math_fround(-0.5));
 $132 = Math_fround(HEAPF32[$2>>2]);
 $133 = Math_fround($121 * $132);
 $134 = (($2) + 4|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($124 * $135);
 $137 = Math_fround($133 + $136);
 $138 = (($2) + 8|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($127 * $139);
 $141 = Math_fround($137 + $140);
 $142 = Math_fround($121 * $131);
 $143 = Math_fround($127 * $135);
 $144 = Math_fround($124 * $139);
 $145 = Math_fround($143 - $144);
 $146 = Math_fround($129 * $145);
 $147 = Math_fround($142 + $146);
 $148 = Math_fround($132 * $141);
 $149 = Math_fround($148 + $147);
 $150 = Math_fround($124 * $131);
 $151 = Math_fround($121 * $139);
 $152 = Math_fround($127 * $132);
 $153 = Math_fround($151 - $152);
 $154 = Math_fround($129 * $153);
 $155 = Math_fround($150 + $154);
 $156 = Math_fround($135 * $141);
 $157 = Math_fround($156 + $155);
 $158 = Math_fround($127 * $131);
 $159 = Math_fround($124 * $132);
 $160 = Math_fround($121 * $135);
 $161 = Math_fround($159 - $160);
 $162 = Math_fround($129 * $161);
 $163 = Math_fround($158 + $162);
 $164 = Math_fround($139 * $141);
 $165 = Math_fround($163 + $164);
 $166 = (($2) + 16|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = Math_fround($167 + $149);
 $169 = (($2) + 20|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = Math_fround($170 + $157);
 $172 = (($2) + 24|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround($173 + $165);
 $175 = Math_fround(HEAPF32[$3>>2]);
 $176 = Math_fround($129 * $175);
 $177 = (($3) + 12|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = Math_fround($132 * $178);
 $180 = Math_fround($176 + $179);
 $181 = (($3) + 8|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = Math_fround($135 * $182);
 $184 = Math_fround($180 + $183);
 $185 = (($3) + 4|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = Math_fround($139 * $186);
 $188 = Math_fround($184 - $187);
 $189 = Math_fround($129 * $186);
 $190 = Math_fround($135 * $178);
 $191 = Math_fround($190 + $189);
 $192 = Math_fround($139 * $175);
 $193 = Math_fround($192 + $191);
 $194 = Math_fround($132 * $182);
 $195 = Math_fround($193 - $194);
 $196 = Math_fround($129 * $182);
 $197 = Math_fround($139 * $178);
 $198 = Math_fround($197 + $196);
 $199 = Math_fround($132 * $186);
 $200 = Math_fround($199 + $198);
 $201 = Math_fround($135 * $175);
 $202 = Math_fround($200 - $201);
 $203 = Math_fround($129 * $178);
 $204 = Math_fround($132 * $175);
 $205 = Math_fround($203 - $204);
 $206 = Math_fround($135 * $186);
 $207 = Math_fround($205 - $206);
 $208 = Math_fround($139 * $182);
 $209 = Math_fround($207 - $208);
 HEAPF32[$cB2w>>2] = $188;
 $210 = (($cB2w) + 4|0);
 HEAPF32[$210>>2] = $195;
 $211 = (($cB2w) + 8|0);
 HEAPF32[$211>>2] = $202;
 $212 = (($cB2w) + 12|0);
 HEAPF32[$212>>2] = $209;
 $213 = (($cB2w) + 16|0);
 HEAPF32[$213>>2] = $168;
 $214 = (($cB2w) + 20|0);
 HEAPF32[$214>>2] = $171;
 $215 = (($cB2w) + 24|0);
 HEAPF32[$215>>2] = $174;
 $216 = HEAP32[$jointViz>>2]|0;
 $217 = (($216) + 8|0);
 $218 = HEAP32[$217>>2]|0;
 FUNCTION_TABLE_viii[$218 & 4095]($jointViz,$cA2w,$cB2w);
 $219 = Math_fround(HEAPF32[$cB2w>>2]);
 HEAPF32[$parentFrame>>2] = $219;
 $220 = (($parentFrame) + 4|0);
 $221 = Math_fround(HEAPF32[$210>>2]);
 HEAPF32[$220>>2] = $221;
 $222 = (($parentFrame) + 8|0);
 $223 = Math_fround(HEAPF32[$211>>2]);
 HEAPF32[$222>>2] = $223;
 $224 = (($parentFrame) + 12|0);
 $225 = Math_fround(HEAPF32[$212>>2]);
 HEAPF32[$224>>2] = $225;
 $226 = (($parentFrame) + 16|0);
 $227 = Math_fround(HEAPF32[$213>>2]);
 HEAPF32[$226>>2] = $227;
 $228 = (($parentFrame) + 20|0);
 $229 = Math_fround(HEAPF32[$214>>2]);
 HEAPF32[$228>>2] = $229;
 $230 = (($parentFrame) + 24|0);
 $231 = Math_fround(HEAPF32[$215>>2]);
 HEAPF32[$230>>2] = $231;
 $232 = Math_fround(HEAPF32[$cA2w>>2]);
 $233 = Math_fround($232 * $219);
 $234 = Math_fround(HEAPF32[$106>>2]);
 $235 = Math_fround($234 * $221);
 $236 = Math_fround($233 + $235);
 $237 = Math_fround(HEAPF32[$107>>2]);
 $238 = Math_fround($237 * $223);
 $239 = Math_fround($236 + $238);
 $240 = Math_fround(HEAPF32[$108>>2]);
 $241 = Math_fround($240 * $225);
 $242 = Math_fround($239 + $241);
 $243 = $242 < Math_fround(0.0);
 if ($243) {
  $244 = Math_fround(-$219);
  $245 = Math_fround(-$221);
  $246 = Math_fround(-$223);
  $247 = Math_fround(-$225);
  HEAPF32[$cB2w>>2] = $244;
  HEAPF32[$210>>2] = $245;
  HEAPF32[$211>>2] = $246;
  HEAPF32[$212>>2] = $247;
  $252 = $244;$254 = $247;$257 = $246;$260 = $245;
 } else {
  $252 = $219;$254 = $225;$257 = $223;$260 = $221;
 }
 $248 = Math_fround(-$232);
 $249 = Math_fround(-$234);
 $250 = Math_fround(-$237);
 $251 = Math_fround($240 * $252);
 $253 = Math_fround($254 * $248);
 $255 = Math_fround($251 + $253);
 $256 = Math_fround($257 * $249);
 $258 = Math_fround($255 + $256);
 $259 = Math_fround($260 * $250);
 $261 = Math_fround($258 - $259);
 $262 = Math_fround($240 * $260);
 $263 = Math_fround($254 * $249);
 $264 = Math_fround($263 + $262);
 $265 = Math_fround($252 * $250);
 $266 = Math_fround($265 + $264);
 $267 = Math_fround($257 * $248);
 $268 = Math_fround($266 - $267);
 $269 = Math_fround($240 * $257);
 $270 = Math_fround($254 * $250);
 $271 = Math_fround($270 + $269);
 $272 = Math_fround($260 * $248);
 $273 = Math_fround($272 + $271);
 $274 = Math_fround($252 * $249);
 $275 = Math_fround($273 - $274);
 $276 = Math_fround($240 * $254);
 $277 = Math_fround($252 * $248);
 $278 = Math_fround($276 - $277);
 $279 = Math_fround($260 * $249);
 $280 = Math_fround($278 - $279);
 $281 = Math_fround($257 * $250);
 $282 = Math_fround($280 - $281);
 $283 = $261 != Math_fround(0.0);
 if ($283) {
  $284 = Math_fround($261 * $261);
  $285 = Math_fround($284 + Math_fround(0.0));
  $286 = Math_fround($282 * $282);
  $287 = Math_fround($285 + $286);
  $288 = (Math_fround(Math_sqrt((Math_fround($287)))));
  $289 = Math_fround(Math_fround(1.0) / $288);
  $290 = Math_fround($261 * $289);
  $291 = Math_fround($289 * Math_fround(0.0));
  $292 = Math_fround($282 * $289);
  $294 = $290;$296 = $291;$301 = $292;
 } else {
  $294 = Math_fround(0.0);$296 = Math_fround(0.0);$301 = Math_fround(1.0);
 }
 $293 = Math_fround(-$294);
 $295 = Math_fround(-$296);
 $297 = Math_fround($268 * $295);
 $298 = Math_fround($275 * $295);
 $299 = Math_fround($282 * $295);
 $300 = Math_fround($268 * $301);
 $302 = Math_fround($300 + $299);
 $303 = Math_fround($275 * $293);
 $304 = Math_fround($302 + $303);
 $305 = Math_fround($261 * $295);
 $306 = Math_fround($304 - $305);
 $307 = Math_fround($275 * $301);
 $308 = Math_fround($307 + $299);
 $309 = Math_fround($305 + $308);
 $310 = Math_fround($268 * $293);
 $311 = Math_fround($309 - $310);
 $312 = Math_fround($282 * $301);
 $313 = Math_fround($261 * $293);
 $314 = Math_fround($312 - $313);
 $315 = Math_fround($314 - $297);
 $316 = Math_fround($315 - $298);
 $317 = Math_fround($301 + Math_fround(1.0));
 $318 = Math_fround($294 / $317);
 $319 = HEAP32[$10>>2]|0;
 $320 = HEAP32[$319>>2]|0;
 $321 = (($320) + 132|0);
 $322 = HEAP32[$321>>2]|0;
 FUNCTION_TABLE_viii[$322 & 4095]($319,$lower,$upper);
 $323 = HEAP32[$10>>2]|0;
 $324 = HEAP32[$323>>2]|0;
 $325 = (($324) + 92|0);
 $326 = HEAP32[$325>>2]|0;
 FUNCTION_TABLE_viii[$326 & 4095]($323,$yLimit,$zLimit);
 $327 = HEAP32[$10>>2]|0;
 $328 = HEAP32[$327>>2]|0;
 $329 = (($328) + 116|0);
 $330 = HEAP32[$329>>2]|0;
 $331 = (Math_fround(FUNCTION_TABLE_fi[$330 & 255]($327)));
 $332 = HEAP32[$10>>2]|0;
 $333 = HEAP32[$332>>2]|0;
 $334 = (($333) + 148|0);
 $335 = HEAP32[$334>>2]|0;
 $336 = (Math_fround(FUNCTION_TABLE_fi[$335 & 255]($332)));
 $337 = HEAP32[$jointViz>>2]|0;
 $338 = (($337) + 16|0);
 $339 = HEAP32[$338>>2]|0;
 $340 = Math_fround(HEAPF32[$lower>>2]);
 $341 = Math_fround(HEAPF32[$upper>>2]);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($318)))));
 $342 = Math_fround($341 - $336);
 $343 = +$342;
 $344 = (+Math_tan((+$343)));
 $345 = Math_fround($344);
 $346 = $fabsf$i$i > $345;
 FUNCTION_TABLE_viiffi[$339 & 3]($jointViz,$parentFrame,$340,$341,$346);
 $347 = Math_fround($316 + Math_fround(1.0));
 $348 = Math_fround($311 / $347);
 $349 = Math_fround($306 / $347);
 $350 = Math_fround(-$349);
 $351 = Math_fround(HEAPF32[$yLimit>>2]);
 $352 = Math_fround($351 * Math_fround(0.25));
 $353 = +$352;
 $354 = (+Math_tan((+$353)));
 $355 = Math_fround($354);
 $356 = Math_fround(HEAPF32[$zLimit>>2]);
 $357 = Math_fround($356 * Math_fround(0.25));
 $358 = +$357;
 $359 = (+Math_tan((+$358)));
 $360 = Math_fround($359);
 $361 = Math_fround($331 * Math_fround(0.25));
 $362 = +$361;
 $363 = (+Math_tan((+$362)));
 $364 = Math_fround($363);
 $365 = HEAP32[$jointViz>>2]|0;
 $366 = (($365) + 20|0);
 $367 = HEAP32[$366>>2]|0;
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($348)))));
 $368 = Math_fround($364 + $fabsf$i$i$i);
 $369 = Math_fround($364 * $fabsf$i$i$i);
 $370 = Math_fround(Math_fround(1.0) - $369);
 $371 = Math_fround($368 / $370);
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($350)))));
 $372 = Math_fround($364 + $fabsf$i$i1$i);
 $373 = Math_fround($364 * $fabsf$i$i1$i);
 $374 = Math_fround(Math_fround(1.0) - $373);
 $375 = Math_fround($372 / $374);
 $376 = Math_fround($371 / $355);
 $377 = Math_fround($376 * $376);
 $378 = Math_fround($375 / $360);
 $379 = Math_fround($378 * $378);
 $380 = Math_fround($377 + $379);
 $381 = !($380 <= Math_fround(1.0));
 FUNCTION_TABLE_viiffi[$367 & 3]($jointViz,$parentFrame,$355,$360,$381);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm29ConstraintImmediateVisualizerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx18PxArticulationLink19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (418472|0);
}
function __ZNK5physx18PxArticulationLink8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(418472,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $10 = 1;
 } else {
  $2 = (_strcmp(418424,$name)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $10 = 1;
  } else {
   $4 = (_strcmp(418440,$name)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $10 = 1;
   } else {
    $6 = (_strcmp(418456,$name)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     $10 = 1;
    } else {
     $8 = (_strcmp($name,418464)|0);
     $9 = ($8|0)==(0);
     $10 = $9;
    }
   }
  }
 }
 STACKTOP = sp;return ($10|0);
}
function __ZNK5physx18NpArticulationLink7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 4;
}
function __ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE7setNameEPKc($this,$debugName) {
 $this = $this|0;
 $debugName = $debugName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $debugName;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE14getWorldBoundsEf($agg$result,$this,$inflation) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inflation = Math_fround($inflation);
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $bounds = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bounds = sp;
 $0 = (($this) + 20|0);
 __ZNK5physx14NpShapeManager14getWorldBoundsERKNS_12PxRigidActorE($bounds,$0,$this);
 $1 = Math_fround(HEAPF32[$bounds>>2]);
 $2 = (($bounds) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = (($bounds) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($bounds) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 + $8);
 $10 = (($bounds) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($bounds) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 + $13);
 $15 = Math_fround($4 * Math_fround(0.5));
 $16 = Math_fround($9 * Math_fround(0.5));
 $17 = Math_fround($14 * Math_fround(0.5));
 $18 = Math_fround($3 - $1);
 $19 = Math_fround($8 - $6);
 $20 = Math_fround($13 - $11);
 $21 = Math_fround($18 * Math_fround(0.5));
 $22 = Math_fround($19 * Math_fround(0.5));
 $23 = Math_fround($20 * Math_fround(0.5));
 $24 = Math_fround($21 * $inflation);
 $25 = Math_fround($22 * $inflation);
 $26 = Math_fround($23 * $inflation);
 $27 = Math_fround($15 - $24);
 $28 = Math_fround($16 - $25);
 $29 = Math_fround($17 - $26);
 $30 = Math_fround($15 + $24);
 $31 = Math_fround($16 + $25);
 $32 = Math_fround($17 + $26);
 HEAPF32[$agg$result>>2] = $27;
 $33 = (($agg$result) + 4|0);
 HEAPF32[$33>>2] = $28;
 $34 = (($agg$result) + 8|0);
 HEAPF32[$34>>2] = $29;
 $35 = (($agg$result) + 12|0);
 HEAPF32[$35>>2] = $30;
 $36 = (($agg$result) + 16|0);
 HEAPF32[$36>>2] = $31;
 $37 = (($agg$result) + 20|0);
 HEAPF32[$37>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($flag|0)==(8);
 if ($0) {
  __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE15setActorSimFlagEb($this,$value);
 }
 __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = $1 & 8;
 $3 = ($2<<16>>16)!=(0);
 __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE15setActorSimFlagEb($this,$3);
 $4 = HEAP16[$inFlags>>1]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6&65535;
 $8 = ((414264 + ($7<<2)|0) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + ($9)|0);
 $11 = $10;
 $$sum$i = (($9) + 4)|0;
 $12 = (($this) + ($$sum$i)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 24;
 $15 = $14 & 15;
 $16 = ((444424 + ($15<<2)|0) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($11))|0;
 $19 = $18;
 $20 = $13 >>> 30;
 if ((($20|0) == 2)) {
  $21 = HEAP32[$10>>2]|0;
  $22 = (($21) + 2417|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $10;
  }
 } else if ((($20|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $10;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $4;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($19,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($9) + 8)|0;
 $25 = (($this) + ($$sum1$i)|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $29 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($28,$15)|0);
  HEAP32[$25>>2] = $29;
  $30 = $29;
 } else {
  $30 = $26;
 }
 HEAP16[$30>>1] = $4;
 $31 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($31,$10);
 $32 = HEAP32[$12>>2]|0;
 $33 = $32 | 1;
 HEAP32[$12>>2] = $33;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE13getActorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $27 = HEAP16[$26>>1]|0;
  HEAP16[$agg$result>>1] = $27;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = HEAP16[$18>>1]|0;
 HEAP16[$agg$result>>1] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE17setDominanceGroupEh($this,$dominanceGroup) {
 $this = $this|0;
 $dominanceGroup = $dominanceGroup|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = $8 >>> 30;
 if ((($15|0) == 2)) {
  $16 = HEAP32[$5>>2]|0;
  $17 = (($16) + 2417|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else if ((($15|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc9ActorCore17setDominanceGroupEh($14,$dominanceGroup);
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $20 = (($this) + ($$sum1)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $23 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $24 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($23,$10)|0);
  HEAP32[$20>>2] = $24;
  $26 = $24;
 } else {
  $26 = $21;
 }
 $25 = (($26) + 2|0);
 HEAP8[$25>>0] = $dominanceGroup;
 $27 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($27,$5);
 $28 = HEAP32[$7>>2]|0;
 $29 = $28 | 2;
 HEAP32[$7>>2] = $29;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE17getDominanceGroupEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 12|0);
  $$in$i$i$i = $26;
  $27 = HEAP8[$$in$i$i$i>>0]|0;
  STACKTOP = sp;return ($27|0);
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 2|0);
 $$in$i$i$i = $17;
 $27 = HEAP8[$$in$i$i$i>>0]|0;
 STACKTOP = sp;return ($27|0);
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE14setOwnerClientEh($this,$inId) {
 $this = $this|0;
 $inId = $inId|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,417088,198,417168,$vararg_buffer1);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = ((414264 + ($5<<2)|0) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + ($7)|0);
 $$sum = (($7) + 4)|0;
 $9 = (($this) + ($$sum)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 2)) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 5;
  } else {
   label = 6;
  }
 } else if ((($11|0) == 3)) {
  label = 6;
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = $8;
  $17 = $10 >>> 24;
  $18 = $17 & 15;
  $19 = ((444424 + ($18<<2)|0) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($16))|0;
  $22 = $21;
  $23 = (($22) + 13|0);
  HEAP8[$23>>0] = $inId;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $24 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($24,8,417240,153,417320,$vararg_buffer1);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE14getOwnerClientEv($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = (($14) + 13|0);
 $16 = HEAP8[$15>>0]|0;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $$in = 0, $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 11|0);
  $$in = $26;
 } else {
  $$sum2 = (($4) + 8)|0;
  $10 = (($this) + ($$sum2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $13 = HEAP32[$5>>2]|0;
   $14 = $7 >>> 24;
   $15 = $14 & 15;
   $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
   HEAP32[$10>>2] = $16;
   $18 = $16;
  } else {
   $18 = $11;
  }
  $17 = (($18) + 3|0);
  $$in = $17;
 }
 $27 = HEAP8[$$in>>0]|0;
 $28 = HEAP8[$b>>0]|0;
 $29 = ($27<<24>>24)==($28<<24>>24);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = $5;
 $31 = HEAP32[$6>>2]|0;
 $32 = $31 >>> 24;
 $33 = $32 & 15;
 $34 = ((444424 + ($33<<2)|0) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + ($30))|0;
 $37 = $36;
 $38 = $31 >>> 30;
 if ((($38|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($38|0) == 2)) {
  $39 = HEAP32[$5>>2]|0;
  $40 = (($39) + 2417|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = ($41<<24>>24)==(0);
  if ($42) {
   label = 10;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $43 = (($37) + 11|0);
  HEAP8[$43>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum3 = (($4) + 8)|0;
 $44 = (($this) + ($$sum3)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  $47 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $48 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($47,$33)|0);
  HEAP32[$44>>2] = $48;
  $50 = $48;
 } else {
  $50 = $45;
 }
 $49 = (($50) + 3|0);
 HEAP8[$49>>0] = $28;
 $51 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($51,$5);
 $52 = HEAP32[$6>>2]|0;
 $53 = $52 | 4;
 HEAP32[$6>>2] = $53;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE22getClientBehaviorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $20 = $7 >>> 24;
  $21 = $20 & 15;
  $22 = ((444424 + ($21<<2)|0) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $5;
  $25 = (($23) + ($24))|0;
  $26 = $25;
  $27 = (($26) + 11|0);
  $28 = HEAP8[$27>>0]|0;
  HEAP8[$agg$result>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 3|0);
 $19 = HEAP8[$17>>0]|0;
 HEAP8[$agg$result>>0] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE12getAggregateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor12getAggregateEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE11createShapeERKNS_10PxGeometryEPKPNS_10PxMaterialEtNS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$geometry,$materials,$materialCount,$shapeFlags) {
 $this = $this|0;
 $geometry = $geometry|0;
 $materials = $materials|0;
 $materialCount = $materialCount|0;
 $shapeFlags = $shapeFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[424544>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$shapeFlags>>0]|0;
 HEAP8[$0>>0] = $5;
 $6 = (FUNCTION_TABLE_iiiiiii[$4 & 255]($1,$geometry,$materials,$materialCount,1,$0)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($8,$6,$this);
 __ZN5physx7NpShape15releaseInternalEv($6);
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE11attachShapeERNS_7PxShapeE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($0,$shape,$this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE11detachShapeERNS_7PxShapeEb($this,$shape,$wakeOnLostTouch) {
 $this = $this|0;
 $shape = $shape|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11detachShapeERNS_7NpShapeERNS_12PxRigidActorEb($0,$shape,$this,$wakeOnLostTouch);
 STACKTOP = sp;return;
}
function __ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE11getNbShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE9getShapesEPPNS_7PxShapeEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (__ZNK5physx14NpShapeManager9getShapesEPPNS_7PxShapeEjj($0,$buffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE16getNbConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor15getNbConnectorsENS_15NpConnectorType4EnumE($0,0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE14getConstraintsEPPNS_12PxConstraintEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$02$i = 0, $nbConnectors$03$i = 0, $nbConnectors$1$i = 0, $nbConnectors$2$i = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$not$i = 0, $or$cond1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $nbConnectors$2$i = 0;
  STACKTOP = sp;return ($nbConnectors$2$i|0);
 }
 $3 = (($1) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $nbConnectors$2$i = 0;
  STACKTOP = sp;return ($nbConnectors$2$i|0);
 } else {
  $7 = $1;$i$02$i = 0;$nbConnectors$03$i = 0;
 }
 while(1) {
  $6 = (($7) + 36|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + ($i$02$i<<3)|0);
  $10 = HEAP8[$9>>0]|0;
  $notlhs$i = ($10<<24>>24)!=(0);
  $notrhs$i = ($nbConnectors$03$i>>>0)>=($bufferSize>>>0);
  $or$cond$not$i = $notrhs$i | $notlhs$i;
  $11 = ($i$02$i>>>0)<($startIndex>>>0);
  $or$cond1$i = $or$cond$not$i | $11;
  if ($or$cond1$i) {
   $18 = $7;$nbConnectors$1$i = $nbConnectors$03$i;
  } else {
   $12 = ((($8) + ($i$02$i<<3)|0) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($buffer) + ($nbConnectors$03$i<<2)|0);
   HEAP32[$14>>2] = $13;
   $15 = (($nbConnectors$03$i) + 1)|0;
   $$pre$i = HEAP32[$0>>2]|0;
   $18 = $$pre$i;$nbConnectors$1$i = $15;
  }
  $16 = (($i$02$i) + 1)|0;
  $17 = (($18) + 40|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ($16>>>0)<($19>>>0);
  if ($20) {
   $7 = $18;$i$02$i = $16;$nbConnectors$03$i = $nbConnectors$1$i;
  } else {
   $nbConnectors$2$i = $nbConnectors$1$i;
   break;
  }
 }
 STACKTOP = sp;return ($nbConnectors$2$i|0);
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17getCMassLocalPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 512;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 112|0);
  $18 = $16;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 144|0);
  $18 = $14;
 }
 $17 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$agg$result>>2] = $17;
 $19 = (($agg$result) + 4|0);
 $20 = (($18) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 $22 = (($agg$result) + 8|0);
 $23 = (($18) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$22>>2] = $24;
 $25 = (($agg$result) + 12|0);
 $26 = (($18) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($agg$result) + 16|0);
 $29 = (($18) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($agg$result) + 20|0);
 $32 = (($18) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($agg$result) + 24|0);
 $35 = (($18) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE7setMassEf($this,$mass) {
 $this = $this|0;
 $mass = Math_fround($mass);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = $mass > Math_fround(0.0);
 if ($1) {
  $2 = Math_fround(Math_fround(1.0) / $mass);
  $11 = $2;
 } else {
  $11 = Math_fround(0.0);
 }
 $3 = (($this) + 64|0);
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 30;
 if ((($6|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($6|0) == 2)) {
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 2417|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if ($10) {
   label = 6;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  __ZN5physx2Sc8BodyCore14setInverseMassEf($3,$11);
  STACKTOP = sp;return;
 }
 $12 = (($this) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $16 = $5 >>> 24;
  $17 = $16 & 15;
  $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($15,$17)|0);
  HEAP32[$12>>2] = $18;
  $20 = $18;
 } else {
  $20 = $13;
 }
 $19 = (($20) + 92|0);
 HEAPF32[$19>>2] = $11;
 $21 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($21,$0);
 $22 = (($this) + 284|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 | 1;
 HEAP32[$22>>2] = $24;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE7getMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 64|0);
  $18 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($17)));
  $20 = $18;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 92|0);
  $16 = Math_fround(HEAPF32[$14>>2]);
  $20 = $16;
 }
 $19 = $20 > Math_fround(0.0);
 if (!($19)) {
  $22 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($22));
 }
 $21 = Math_fround(Math_fround(1.0) / $20);
 $22 = $21;
 STACKTOP = sp;return (Math_fround($22));
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE10getInvMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 64|0);
  $18 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($17)));
  $19 = $18;
  STACKTOP = sp;return (Math_fround($19));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 92|0);
 $16 = Math_fround(HEAPF32[$14>>2]);
 $19 = $16;
 STACKTOP = sp;return (Math_fround($19));
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25setMassSpaceInertiaTensorERKNS_6PxVec3E($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $$pre = Math_fround(0), $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 48|0);
 $2 = Math_fround(HEAPF32[$m>>2]);
 $3 = $2 == Math_fround(0.0);
 if ($3) {
  $13 = Math_fround(0.0);
 } else {
  $4 = Math_fround(Math_fround(1.0) / $2);
  $13 = $4;
 }
 $5 = (($m) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $6 == Math_fround(0.0);
 if ($7) {
  $15 = Math_fround(0.0);
 } else {
  $8 = Math_fround(Math_fround(1.0) / $6);
  $15 = $8;
 }
 $9 = (($m) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = $10 == Math_fround(0.0);
 if ($11) {
  $17 = Math_fround(0.0);
 } else {
  $12 = Math_fround(Math_fround(1.0) / $10);
  $17 = $12;
 }
 HEAPF32[$0>>2] = $13;
 $14 = (($0) + 4|0);
 HEAPF32[$14>>2] = $15;
 $16 = (($0) + 8|0);
 HEAPF32[$16>>2] = $17;
 $18 = (($this) + 64|0);
 $19 = (($this) + 52|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 >>> 30;
 if ((($21|0) == 3)) {
  $$pre$phi$i$iZ2D = $1;
 } else if ((($21|0) == 2)) {
  $22 = HEAP32[$1>>2]|0;
  $23 = (($22) + 2417|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   label = 10;
  } else {
   $$pre$phi$i$iZ2D = $1;
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  __ZN5physx2Sc8BodyCore17setInverseInertiaERKNS_6PxVec3E($18,$0);
  STACKTOP = sp;return;
 }
 $26 = (($this) + 56|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $29 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $30 = $20 >>> 24;
  $31 = $30 & 15;
  $32 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($29,$31)|0);
  HEAP32[$26>>2] = $32;
  $$pre = Math_fround(HEAPF32[$0>>2]);
  $34 = $32;$35 = $$pre;
 } else {
  $34 = $27;$35 = $13;
 }
 $33 = (($34) + 96|0);
 HEAPF32[$33>>2] = $35;
 $36 = Math_fround(HEAPF32[$14>>2]);
 $37 = (($34) + 100|0);
 HEAPF32[$37>>2] = $36;
 $38 = Math_fround(HEAPF32[$16>>2]);
 $39 = (($34) + 104|0);
 HEAPF32[$39>>2] = $38;
 $40 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($40,$1);
 $41 = (($this) + 284|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 | 2;
 HEAP32[$41>>2] = $43;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25getMassSpaceInertiaTensorEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 64|0);
  $17 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($16)|0);
  $19 = $17;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 96|0);
  $19 = $14;
 }
 $18 = Math_fround(HEAPF32[$19>>2]);
 $20 = (($19) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($19) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = $18 == Math_fround(0.0);
 if ($24) {
  $30 = Math_fround(0.0);
 } else {
  $25 = Math_fround(Math_fround(1.0) / $18);
  $30 = $25;
 }
 $26 = $21 == Math_fround(0.0);
 if ($26) {
  $32 = Math_fround(0.0);
 } else {
  $27 = Math_fround(Math_fround(1.0) / $21);
  $32 = $27;
 }
 $28 = $23 == Math_fround(0.0);
 if ($28) {
  $34 = Math_fround(0.0);
  HEAPF32[$agg$result>>2] = $30;
  $31 = (($agg$result) + 4|0);
  HEAPF32[$31>>2] = $32;
  $33 = (($agg$result) + 8|0);
  HEAPF32[$33>>2] = $34;
  STACKTOP = sp;return;
 }
 $29 = Math_fround(Math_fround(1.0) / $23);
 $34 = $29;
 HEAPF32[$agg$result>>2] = $30;
 $31 = (($agg$result) + 4|0);
 HEAPF32[$31>>2] = $32;
 $33 = (($agg$result) + 8|0);
 HEAPF32[$33>>2] = $34;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE28getMassSpaceInvInertiaTensorEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 64|0);
  $17 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($16)|0);
  $19 = $17;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 96|0);
  $19 = $14;
 }
 $18 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$agg$result>>2] = $18;
 $20 = (($agg$result) + 4|0);
 $21 = (($19) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = (($agg$result) + 8|0);
 $24 = (($19) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$23>>2] = $25;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17getLinearVelocityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 252|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 256|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 260|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE18getAngularVelocityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 264|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 268|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 272|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE19setRigidDynamicFlagENS_15PxRigidBodyFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 192|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE20setRigidDynamicFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP8[$inFlags>>0]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 196|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP8[$0>>0] = $1;
 FUNCTION_TABLE_vii[$4 & 4095]($this,$0);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE16setRigidBodyFlagENS_15PxRigidBodyFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currentFlags = 0, $newFlags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $currentFlags = sp + 1|0;
 $newFlags = sp;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 108|0);
  $18 = HEAP8[$17>>0]|0;
  HEAP8[$currentFlags>>0] = $18;
  $20 = $18;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 268|0);
  $16 = HEAP8[$14>>0]|0;
  HEAP8[$currentFlags>>0] = $16;
  $20 = $16;
 }
 if ($value) {
  $19 = $20&255;
  $21 = $19 | $flag;
  $22 = $21&255;
  HEAP8[$newFlags>>0] = $22;
 } else {
  $23 = $flag ^ 255;
  $24 = $23&255;
  $25 = $20 & $24;
  HEAP8[$newFlags>>0] = $25;
 }
 __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25setRigidBodyFlagsInternalERKNS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEES8_($this,$currentFlags,$newFlags);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17setRigidBodyFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currentFlags = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $currentFlags = sp;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 108|0);
  $18 = HEAP8[$17>>0]|0;
  HEAP8[$currentFlags>>0] = $18;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 268|0);
  $16 = HEAP8[$14>>0]|0;
  HEAP8[$currentFlags>>0] = $16;
 }
 __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25setRigidBodyFlagsInternalERKNS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEES8_($this,$currentFlags,$inFlags);
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE20getRigidDynamicFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 108|0);
  $18 = HEAP8[$17>>0]|0;
  HEAP8[$agg$result>>0] = $18;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 268|0);
 $16 = HEAP8[$14>>0]|0;
 HEAP8[$agg$result>>0] = $16;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17getRigidBodyFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 108|0);
  $18 = HEAP8[$17>>0]|0;
  HEAP8[$agg$result>>0] = $18;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 268|0);
 $16 = HEAP8[$14>>0]|0;
 HEAP8[$agg$result>>0] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE27setMinCCDAdvanceCoefficientEf($this,$minCCDAdvanceCoefficient) {
 $this = $this|0;
 $minCCDAdvanceCoefficient = Math_fround($minCCDAdvanceCoefficient);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = (($this) + 64|0);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc8BodyCore24setCCDAdvanceCoefficientEf($1,$minCCDAdvanceCoefficient);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 124|0);
 HEAPF32[$16>>2] = $minCCDAdvanceCoefficient;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = (($this) + 284|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 | 64;
 HEAP32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE27getMinCCDAdvanceCoefficientEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 140|0);
  $$in$i$i$i = $16;
  $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 124|0);
 $$in$i$i$i = $14;
 $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE27setMaxDepenetrationVelocityEf($this,$maxDepenVel) {
 $this = $this|0;
 $maxDepenVel = Math_fround($maxDepenVel);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = Math_fround(-$maxDepenVel);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $9 = (($this) + 156|0);
  HEAPF32[$9>>2] = $1;
  STACKTOP = sp;return;
 }
 $10 = (($this) + 56|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $14 = $3 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 172|0);
 HEAPF32[$17>>2] = $1;
 $19 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($19,$0);
 $20 = (($this) + 284|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 | 1024;
 HEAP32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE27getMaxDepenetrationVelocityEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1024;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 156|0);
  $$in$i$i$i = $16;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 172|0);
  $$in$i$i$i = $14;
 }
 $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 $18 = Math_fround(-$17);
 STACKTOP = sp;return (Math_fround($18));
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE13switchToNoSimEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE15switchFromNoSimEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx18NpArticulationLink13isSubordinateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25setRigidBodyFlagsInternalERKNS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEES8_($this,$currentFlags,$newFlags) {
 $this = $this|0;
 $currentFlags = $currentFlags|0;
 $newFlags = $newFlags|0;
 var $$ = 0, $$0$i = 0, $$0$i10 = 0, $$mask$i = 0, $$mask$i$i = 0, $$mask$i$i6 = 0, $$mask$i9 = 0, $$not1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0);
 var $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $bodyTarget = 0, $bodyTarget1 = 0, $brmerge = 0, $i$022 = 0, $not$ = 0, $or$cond = 0, $or$cond5 = 0, $phitmp = 0, $phitmp21 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer1 = sp;
 $0 = sp + 61|0;
 $bodyTarget = sp + 4|0;
 $bodyTarget1 = sp + 32|0;
 $1 = sp + 60|0;
 $2 = (($this) + 48|0);
 $3 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $4 = HEAP8[$currentFlags>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)!=(0);
 $7 = HEAP8[$newFlags>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)!=(0);
 $10 = $9 ^ 1;
 $$ = $6 & $10;
 do {
  if ($$) {
   $11 = (($this) + 20|0);
   $12 = (($this) + 24|0);
   $13 = HEAP16[$12>>1]|0;
   $14 = $13&65535;
   $15 = ($13<<16>>16)==(1);
   if ($15) {
    $19 = $11;
    label = 5;
   } else {
    $16 = HEAP32[$11>>2]|0;
    $17 = ($13<<16>>16)==(0);
    if ($17) {
     $34 = $4;
    } else {
     $19 = $16;
     label = 5;
    }
   }
   do {
    if ((label|0) == 5) {
     $i$022 = 0;
     while(1) {
      $18 = (($19) + ($i$022<<2)|0);
      $20 = HEAP32[$18>>2]|0;
      $21 = HEAP32[$20>>2]|0;
      $22 = (($21) + 136|0);
      $23 = HEAP32[$22>>2]|0;
      FUNCTION_TABLE_vii[$23 & 4095]($0,$20);
      $24 = HEAP8[$0>>0]|0;
      $25 = $24 & 1;
      $26 = ($25<<24>>24)==(0);
      if (!($26)) {
       $27 = HEAP32[$18>>2]|0;
       $28 = (($27) + 116|0);
       $29 = HEAP32[$28>>2]|0;
       if ((($29|0) == 6) | (($29|0) == 1) | (($29|0) == 5)) {
        break;
       }
      }
      $30 = (($i$022) + 1)|0;
      $31 = ($30>>>0)<($14>>>0);
      if ($31) {
       $i$022 = $30;
      } else {
       label = 10;
       break;
      }
     }
     if ((label|0) == 10) {
      $$pre = HEAP8[$currentFlags>>0]|0;
      $34 = $$pre;
      break;
     }
     $32 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
     __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($32,4,416840,478,416920,$vararg_buffer1);
     STACKTOP = sp;return;
    }
   } while(0);
   $33 = $34 & 2;
   $35 = ($33<<24>>24)==(0);
   do {
    if (!($35)) {
     $36 = (($this) + 284|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = $37 & 8192;
     $39 = ($38|0)==(0);
     if ($39) {
      $70 = (($this) + 52|0);
      $71 = HEAP32[$70>>2]|0;
      $$mask$i9 = $71 & -1073741824;
      $72 = ($$mask$i9|0)==(-1073741824);
      if ($72) {
       break;
      }
      $73 = (($this) + 64|0);
      $74 = (__ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($73,$bodyTarget)|0);
      $phitmp21 = $74 ^ 1;
      $$0$i10 = $phitmp21;
     } else {
      $40 = (($this) + 56|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41|0)==(0|0);
      if ($42) {
       $43 = HEAP32[$2>>2]|0;
       $44 = (($this) + 52|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = $45 >>> 24;
       $47 = $46 & 15;
       $48 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($43,$47)|0);
       HEAP32[$40>>2] = $48;
       $50 = $48;
      } else {
       $50 = $41;
      }
      $49 = (($50) + 192|0);
      $51 = Math_fround(HEAPF32[$49>>2]);
      HEAPF32[$bodyTarget>>2] = $51;
      $52 = (($50) + 196|0);
      $53 = Math_fround(HEAPF32[$52>>2]);
      $54 = (($bodyTarget) + 4|0);
      HEAPF32[$54>>2] = $53;
      $55 = (($50) + 200|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      $57 = (($bodyTarget) + 8|0);
      HEAPF32[$57>>2] = $56;
      $58 = (($50) + 204|0);
      $59 = Math_fround(HEAPF32[$58>>2]);
      $60 = (($bodyTarget) + 12|0);
      HEAPF32[$60>>2] = $59;
      $61 = (($50) + 208|0);
      $62 = Math_fround(HEAPF32[$61>>2]);
      $63 = (($bodyTarget) + 16|0);
      HEAPF32[$63>>2] = $62;
      $64 = (($50) + 212|0);
      $65 = Math_fround(HEAPF32[$64>>2]);
      $66 = (($bodyTarget) + 20|0);
      HEAPF32[$66>>2] = $65;
      $67 = (($50) + 216|0);
      $68 = Math_fround(HEAPF32[$67>>2]);
      $69 = (($bodyTarget) + 24|0);
      HEAPF32[$69>>2] = $68;
      $$0$i10 = 0;
     }
     $75 = ($3|0)==(0|0);
     $or$cond = $$0$i10 | $75;
     if (!($or$cond)) {
      $76 = (($3) + 3376|0);
      __ZN5physx14NpShapeManager26markAllSceneQueryForUpdateERNS_2Sq17SceneQueryManagerE($11,$76);
      $77 = (($3) + 3400|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($78) + 1)|0;
      HEAP32[$77>>2] = $79;
     }
    }
   } while(0);
   $80 = (($this) + 64|0);
   $81 = (($this) + 52|0);
   $82 = HEAP32[$81>>2]|0;
   $$mask$i$i6 = $82 & -1073741824;
   $83 = ($$mask$i$i6|0)==(1073741824);
   if ($83) {
    $84 = (($this) + 220|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($85|0)==(0|0);
    if (!($86)) {
     $87 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($80,1)|0);
     $88 = HEAP32[$84>>2]|0;
     $89 = ($88|0)==(0|0);
     if ($87) {
      if ($89) {
       break;
      }
      $90 = HEAP32[$2>>2]|0;
      $91 = (($90) + 1256|0);
      $92 = HEAP32[$91>>2]|0;
      __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($80,$92,1);
      break;
     }
     if (!($89)) {
      $93 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($80,0)|0);
      if ($93) {
       $94 = HEAP32[$84>>2]|0;
       $95 = ($94|0)==(0|0);
       if (!($95)) {
        $96 = HEAP32[$2>>2]|0;
        $97 = (($96) + 1256|0);
        $98 = HEAP32[$97>>2]|0;
        __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($80,$98,0);
       }
      }
     }
    }
   }
  } else {
   $not$ = $6 ^ 1;
   $99 = $9 & $not$;
   if ($99) {
    $100 = HEAP32[$this>>2]|0;
    $101 = (($100) + 24|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (FUNCTION_TABLE_ii[$102 & 4095]($this)|0);
    $104 = ($103|0)==(4);
    if ($104) {
     $118 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
     __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($118,4,416840,499,417008,$vararg_buffer1);
     STACKTOP = sp;return;
    }
    $105 = (($this) + 64|0);
    $106 = (($this) + 52|0);
    $107 = HEAP32[$106>>2]|0;
    $$mask$i$i = $107 & -1073741824;
    $108 = ($$mask$i$i|0)==(1073741824);
    if ($108) {
     $109 = (($this) + 220|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0|0);
     if (!($111)) {
      $112 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($105,0)|0);
      if ($112) {
       $113 = HEAP32[$109>>2]|0;
       $114 = ($113|0)==(0|0);
       if (!($114)) {
        $115 = HEAP32[$2>>2]|0;
        $116 = (($115) + 1256|0);
        $117 = HEAP32[$116>>2]|0;
        (__ZN5physx2Sc8BodyCore17setupSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEbb($105,$117,1,0)|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $$not1 = $6 ^ 1;
 $brmerge = $$not1 | $10;
 do {
  if (!($brmerge)) {
   $119 = HEAP8[$currentFlags>>0]|0;
   $120 = $119&255;
   $121 = $120 & 2;
   $122 = $121&255;
   $123 = HEAP8[$newFlags>>0]|0;
   $124 = $123&255;
   $125 = $124 & 2;
   $126 = $125&255;
   $127 = ($122<<24>>24)==($126<<24>>24);
   if (!($127)) {
    $128 = (($this) + 284|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = $129 & 8192;
    $131 = ($130|0)==(0);
    if ($131) {
     $162 = (($this) + 52|0);
     $163 = HEAP32[$162>>2]|0;
     $$mask$i = $163 & -1073741824;
     $164 = ($$mask$i|0)==(-1073741824);
     if ($164) {
      break;
     }
     $165 = (($this) + 64|0);
     $166 = (__ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($165,$bodyTarget1)|0);
     $phitmp = $166 ^ 1;
     $$0$i = $phitmp;
    } else {
     $132 = (($this) + 56|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($133|0)==(0|0);
     if ($134) {
      $135 = HEAP32[$2>>2]|0;
      $136 = (($this) + 52|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = $137 >>> 24;
      $139 = $138 & 15;
      $140 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($135,$139)|0);
      HEAP32[$132>>2] = $140;
      $142 = $140;
     } else {
      $142 = $133;
     }
     $141 = (($142) + 192|0);
     $143 = Math_fround(HEAPF32[$141>>2]);
     HEAPF32[$bodyTarget1>>2] = $143;
     $144 = (($142) + 196|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = (($bodyTarget1) + 4|0);
     HEAPF32[$146>>2] = $145;
     $147 = (($142) + 200|0);
     $148 = Math_fround(HEAPF32[$147>>2]);
     $149 = (($bodyTarget1) + 8|0);
     HEAPF32[$149>>2] = $148;
     $150 = (($142) + 204|0);
     $151 = Math_fround(HEAPF32[$150>>2]);
     $152 = (($bodyTarget1) + 12|0);
     HEAPF32[$152>>2] = $151;
     $153 = (($142) + 208|0);
     $154 = Math_fround(HEAPF32[$153>>2]);
     $155 = (($bodyTarget1) + 16|0);
     HEAPF32[$155>>2] = $154;
     $156 = (($142) + 212|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = (($bodyTarget1) + 20|0);
     HEAPF32[$158>>2] = $157;
     $159 = (($142) + 216|0);
     $160 = Math_fround(HEAPF32[$159>>2]);
     $161 = (($bodyTarget1) + 24|0);
     HEAPF32[$161>>2] = $160;
     $$0$i = 0;
    }
    $167 = ($3|0)==(0|0);
    $or$cond5 = $$0$i | $167;
    if (!($or$cond5)) {
     $168 = (($this) + 20|0);
     $169 = (($3) + 3376|0);
     __ZN5physx14NpShapeManager26markAllSceneQueryForUpdateERNS_2Sq17SceneQueryManagerE($168,$169);
     $170 = (($3) + 3400|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = (($171) + 1)|0;
     HEAP32[$170>>2] = $172;
    }
   }
  }
 } while(0);
 $173 = HEAP8[$newFlags>>0]|0;
 HEAP8[$1>>0] = $173;
 __ZN5physx3Scb4Body8setFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($2,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb4Body8setFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $$ = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 236|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 4096;
 $4 = ($3|0)==(0);
 if ($4) {
  $16 = (($this) + 60|0);
  $$in = $16;
 } else {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $8 = HEAP32[$this>>2]|0;
   $9 = (($this) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$5>>2] = $13;
   $15 = $13;
  } else {
   $15 = $6;
  }
  $14 = (($15) + 268|0);
  $$in = $14;
 }
 $17 = HEAP8[$$in>>0]|0;
 $18 = HEAP8[$f>>0]|0;
 $19 = $18&255;
 $20 = $19 & 1;
 $21 = $17 & 1;
 $22 = ($21<<24>>24)!=(0);
 $23 = ($20|0)!=(0);
 $not$ = $22 ^ 1;
 $$ = $23 & $not$;
 $24 = ($20|0)==(0);
 $25 = $22 & $24;
 $26 = (($this) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 >>> 30;
 if ((($28|0) == 2)) {
  $29 = HEAP32[$this>>2]|0;
  $30 = (($29) + 2417|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   label = 8;
  }
 } else if (!((($28|0) == 3))) {
  label = 8;
 }
 if ((label|0) == 8) {
  if ($$) {
   $33 = (($this) + 232|0);
   HEAP32[$33>>2] = 1;
   $34 = (($this) + 204|0);
   ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;HEAP32[$34+24>>2]=0|0;
  }
  $35 = (($this) + 16|0);
  $36 = HEAP32[$this>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   $41 = 0;
  } else {
   $38 = (($36) + 1256|0);
   $39 = HEAP32[$38>>2]|0;
   $41 = $39;
  }
  $40 = HEAP8[$f>>0]|0;
  HEAP8[$0>>0] = $40;
  __ZN5physx2Sc8BodyCore8setFlagsEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($35,$41,$0);
  STACKTOP = sp;return;
 }
 if ($$) {
  __ZN5physx3Scb4Body18putToSleepInternalEv($this);
 } else {
  if ($25) {
   $42 = HEAP32[$1>>2]|0;
   $43 = $42 & -8193;
   HEAP32[$1>>2] = $43;
  }
 }
 $44 = (($this) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  $47 = HEAP32[$this>>2]|0;
  $48 = HEAP32[$26>>2]|0;
  $49 = $48 >>> 24;
  $50 = $49 & 15;
  $51 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($47,$50)|0);
  HEAP32[$44>>2] = $51;
  $53 = $51;
 } else {
  $53 = $45;
 }
 $52 = (($53) + 268|0);
 $54 = HEAP8[$f>>0]|0;
 HEAP8[$52>>0] = $54;
 $55 = HEAP32[$this>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($55,$this);
 $56 = HEAP32[$1>>2]|0;
 $57 = $56 | 4096;
 HEAP32[$1>>2] = $57;
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE11attachShapeERNS_7PxShapeE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($0,$shape,$this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE15setActorSimFlagEb($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $$in = 0, $$not = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum$i2 = 0, $$sum$i4 = 0, $$sum1$i = 0, $$sum1$i10 = 0, $$sum1$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge1 = 0, $value$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $$sum$i = (($6) + 4)|0;
 $8 = (($this) + ($$sum$i)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 1;
 $11 = ($10|0)==(0);
 if ($11) {
  $19 = $9 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $7;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $$in = $26;
 } else {
  $$sum1$i = (($6) + 8)|0;
  $12 = (($this) + ($$sum1$i)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $15 = HEAP32[$7>>2]|0;
   $16 = $9 >>> 24;
   $17 = $16 & 15;
   $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($15,$17)|0);
   HEAP32[$12>>2] = $18;
   $103 = $18;
  } else {
   $103 = $13;
  }
  $$in = $103;
 }
 $27 = HEAP16[$$in>>1]|0;
 $28 = $27&65535;
 $29 = $28 & 8;
 $30 = ($29|0)!=(0);
 $$not = $30 ^ 1;
 $brmerge = $$not | $value;
 if ($brmerge) {
  $value$not = $value ^ 1;
  $brmerge1 = $30 | $value$not;
  if ($brmerge1) {
   STACKTOP = sp;return;
  }
  $68 = ($1|0)==(0|0);
  if (!($68)) {
   $69 = (($this) + 12|0);
   __ZN5physx7NpActor26removeConstraintsFromSceneEv($69);
  }
  $70 = $28 | 8;
  $71 = $70&65535;
  $72 = HEAP16[$2>>1]|0;
  $73 = $72&65535;
  $74 = ((414264 + ($73<<2)|0) + 68|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($this) + ($75)|0);
  $77 = $76;
  $$sum$i2 = (($75) + 4)|0;
  $78 = (($this) + ($$sum$i2)|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = $79 >>> 24;
  $81 = $80 & 15;
  $82 = ((444424 + ($81<<2)|0) + 24|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + ($77))|0;
  $85 = $84;
  $86 = $79 >>> 30;
  if ((($86|0) == 2)) {
   $87 = HEAP32[$76>>2]|0;
   $88 = (($87) + 2417|0);
   $89 = HEAP8[$88>>0]|0;
   $90 = ($89<<24>>24)==(0);
   if ($90) {
    label = 23;
   } else {
    $$pre$phi$i$i$iZ2D = $76;
    label = 24;
   }
  } else if ((($86|0) == 3)) {
   $$pre$phi$i$i$iZ2D = $76;
   label = 24;
  } else {
   label = 23;
  }
  if ((label|0) == 23) {
   HEAP16[$0>>1] = $71;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($85,$0);
  }
  else if ((label|0) == 24) {
   $$sum1$i3 = (($75) + 8)|0;
   $91 = (($this) + ($$sum1$i3)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ($92|0)==(0|0);
   if ($93) {
    $94 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
    $95 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($94,$81)|0);
    HEAP32[$91>>2] = $95;
    $96 = $95;
   } else {
    $96 = $92;
   }
   HEAP16[$96>>1] = $71;
   $97 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($97,$76);
   $98 = HEAP32[$78>>2]|0;
   $99 = $98 | 1;
   HEAP32[$78>>2] = $99;
  }
  $100 = HEAP32[$this>>2]|0;
  $101 = (($100) + 252|0);
  $102 = HEAP32[$101>>2]|0;
  FUNCTION_TABLE_vi[$102 & 4095]($this);
  STACKTOP = sp;return;
 } else {
  $31 = HEAP32[$this>>2]|0;
  $32 = (($31) + 256|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_vi[$33 & 4095]($this);
  $34 = $27 & -9;
  $35 = HEAP16[$2>>1]|0;
  $36 = $35&65535;
  $37 = ((414264 + ($36<<2)|0) + 68|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($this) + ($38)|0);
  $40 = $39;
  $$sum$i4 = (($38) + 4)|0;
  $41 = (($this) + ($$sum$i4)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 >>> 24;
  $44 = $43 & 15;
  $45 = ((444424 + ($44<<2)|0) + 24|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + ($40))|0;
  $48 = $47;
  $49 = $42 >>> 30;
  if ((($49|0) == 2)) {
   $50 = HEAP32[$39>>2]|0;
   $51 = (($50) + 2417|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    label = 10;
   } else {
    $$pre$phi$i$i$i9Z2D = $39;
    label = 11;
   }
  } else if ((($49|0) == 3)) {
   $$pre$phi$i$i$i9Z2D = $39;
   label = 11;
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $34;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($48,$0);
  }
  else if ((label|0) == 11) {
   $$sum1$i10 = (($38) + 8)|0;
   $54 = (($this) + ($$sum1$i10)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0|0);
   if ($56) {
    $57 = HEAP32[$$pre$phi$i$i$i9Z2D>>2]|0;
    $58 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($57,$44)|0);
    HEAP32[$54>>2] = $58;
    $59 = $58;
   } else {
    $59 = $55;
   }
   HEAP16[$59>>1] = $34;
   $60 = HEAP32[$$pre$phi$i$i$i9Z2D>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($60,$39);
   $61 = HEAP32[$41>>2]|0;
   $62 = $61 | 1;
   HEAP32[$41>>2] = $62;
  }
  $63 = ($1|0)==(0|0);
  if ($63) {
   STACKTOP = sp;return;
  }
  $64 = (($this) + 16|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $67 = (($this) + 12|0);
  __ZN5physx7NpActor29addConstraintsToSceneInternalEv($67);
  STACKTOP = sp;return;
 }
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$in = 0, $$in19 = 0, $$pre = 0, $$pre$phi$i$i5Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre22 = 0, $$pre22$pre = 0, $$pre24 = 0, $$pre25 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum20 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = ((414264 + ($3<<2)|0) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + ($5)|0);
 $$sum = (($5) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($value) {
  if ($10) {
   $18 = $8 >>> 24;
   $19 = $18 & 15;
   $20 = ((444424 + ($19<<2)|0) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $6;
   $23 = (($21) + ($22))|0;
   $24 = $23;
   $25 = (($24) + 8|0);
   $$in19 = $25;$$pre$phiZ2D = $22;$31 = $8;
  } else {
   $$sum18 = (($5) + 8)|0;
   $11 = (($this) + ($$sum18)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[$6>>2]|0;
    $15 = $8 >>> 24;
    $16 = $15 & 15;
    $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
    HEAP32[$11>>2] = $17;
    $$pre$pre = HEAP32[$7>>2]|0;
    $$pre = $$pre$pre;$91 = $17;
   } else {
    $$pre = $8;$91 = $12;
   }
   $$pre24 = $6;
   $$in19 = $91;$$pre$phiZ2D = $$pre24;$31 = $$pre;
  }
  $26 = HEAP16[$$in19>>1]|0;
  $27 = $26&65535;
  $28 = $27 | $flag;
  $29 = $28&65535;
  $30 = $31 >>> 24;
  $32 = $30 & 15;
  $33 = ((444424 + ($32<<2)|0) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($$pre$phiZ2D))|0;
  $36 = $35;
  $37 = $31 >>> 30;
  if ((($37|0) == 3)) {
   $$pre$phi$i$i5Z2D = $6;
  } else if ((($37|0) == 2)) {
   $38 = HEAP32[$6>>2]|0;
   $39 = (($38) + 2417|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    label = 10;
   } else {
    $$pre$phi$i$i5Z2D = $6;
   }
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $29;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($36,$0);
   STACKTOP = sp;return;
  }
  $$sum20 = (($5) + 8)|0;
  $42 = (($this) + ($$sum20)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   $45 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
   $46 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($45,$32)|0);
   HEAP32[$42>>2] = $46;
   $47 = $46;
  } else {
   $47 = $43;
  }
  HEAP16[$47>>1] = $29;
  $48 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($48,$6);
  $49 = HEAP32[$7>>2]|0;
  $50 = $49 | 1;
  HEAP32[$7>>2] = $50;
  STACKTOP = sp;return;
 } else {
  if ($10) {
   $58 = $8 >>> 24;
   $59 = $58 & 15;
   $60 = ((444424 + ($59<<2)|0) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $6;
   $63 = (($61) + ($62))|0;
   $64 = $63;
   $65 = (($64) + 8|0);
   $$in = $65;$$pre$phi26Z2D = $62;$71 = $8;
  } else {
   $$sum16 = (($5) + 8)|0;
   $51 = (($this) + ($$sum16)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $54 = HEAP32[$6>>2]|0;
    $55 = $8 >>> 24;
    $56 = $55 & 15;
    $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
    HEAP32[$51>>2] = $57;
    $$pre22$pre = HEAP32[$7>>2]|0;
    $$pre22 = $$pre22$pre;$92 = $57;
   } else {
    $$pre22 = $8;$92 = $52;
   }
   $$pre25 = $6;
   $$in = $92;$$pre$phi26Z2D = $$pre25;$71 = $$pre22;
  }
  $66 = HEAP16[$$in>>1]|0;
  $67 = $flag ^ 65535;
  $68 = $67&65535;
  $69 = $66 & $68;
  $70 = $71 >>> 24;
  $72 = $70 & 15;
  $73 = ((444424 + ($72<<2)|0) + 24|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + ($$pre$phi26Z2D))|0;
  $76 = $75;
  $77 = $71 >>> 30;
  if ((($77|0) == 3)) {
   $$pre$phi$i$iZ2D = $6;
  } else if ((($77|0) == 2)) {
   $78 = HEAP32[$6>>2]|0;
   $79 = (($78) + 2417|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    label = 22;
   } else {
    $$pre$phi$i$iZ2D = $6;
   }
  } else {
   label = 22;
  }
  if ((label|0) == 22) {
   HEAP16[$0>>1] = $69;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($76,$0);
   STACKTOP = sp;return;
  }
  $$sum17 = (($5) + 8)|0;
  $82 = (($this) + ($$sum17)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $85 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $86 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($85,$72)|0);
   HEAP32[$82>>2] = $86;
   $87 = $86;
  } else {
   $87 = $83;
  }
  HEAP16[$87>>1] = $69;
  $88 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($88,$6);
  $89 = HEAP32[$7>>2]|0;
  $90 = $89 | 1;
  HEAP32[$7>>2] = $90;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx3Scb4Body29getGlobalInertiaTensorInverseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 236|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 16|0);
  $16 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($15)|0);
  $18 = $16;
 } else {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = HEAP32[$this>>2]|0;
   $8 = (($this) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 >>> 24;
   $11 = $10 & 15;
   $12 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($7,$11)|0);
   HEAP32[$4>>2] = $12;
   $14 = $12;
  } else {
   $14 = $5;
  }
  $13 = (($14) + 96|0);
  $18 = $13;
 }
 $17 = Math_fround(HEAPF32[$18>>2]);
 $19 = (($18) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($18) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 176|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($this) + 180|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 184|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 188|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($24 + $24);
 $32 = Math_fround($26 + $26);
 $33 = Math_fround($28 + $28);
 $34 = Math_fround($24 * $31);
 $35 = Math_fround($26 * $32);
 $36 = Math_fround($28 * $33);
 $37 = Math_fround($31 * $26);
 $38 = Math_fround($31 * $28);
 $39 = Math_fround($31 * $30);
 $40 = Math_fround($32 * $28);
 $41 = Math_fround($32 * $30);
 $42 = Math_fround($33 * $30);
 $43 = Math_fround(Math_fround(1.0) - $35);
 $44 = Math_fround($43 - $36);
 $45 = Math_fround($37 + $42);
 $46 = Math_fround($38 - $41);
 $47 = Math_fround($37 - $42);
 $48 = Math_fround(Math_fround(1.0) - $34);
 $49 = Math_fround($48 - $36);
 $50 = Math_fround($40 + $39);
 $51 = Math_fround($38 + $41);
 $52 = Math_fround($40 - $39);
 $53 = Math_fround($48 - $35);
 $54 = Math_fround($17 * $44);
 $55 = Math_fround($17 * $45);
 $56 = Math_fround($17 * $46);
 $57 = Math_fround($20 * $47);
 $58 = Math_fround($20 * $49);
 $59 = Math_fround($20 * $50);
 $60 = Math_fround($22 * $51);
 $61 = Math_fround($22 * $52);
 $62 = Math_fround($22 * $53);
 $63 = Math_fround($44 * $54);
 $64 = Math_fround($47 * $57);
 $65 = Math_fround($63 + $64);
 $66 = Math_fround($51 * $60);
 $67 = Math_fround($66 + $65);
 HEAPF32[$agg$result>>2] = $67;
 $68 = Math_fround($45 * $55);
 $69 = Math_fround($49 * $58);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($52 * $61);
 $72 = Math_fround($71 + $70);
 $73 = (($agg$result) + 12|0);
 $74 = (($73) + 4|0);
 HEAPF32[$74>>2] = $72;
 $75 = Math_fround($46 * $56);
 $76 = Math_fround($50 * $59);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($53 * $62);
 $79 = Math_fround($78 + $77);
 $80 = (($agg$result) + 24|0);
 $81 = (($80) + 8|0);
 HEAPF32[$81>>2] = $79;
 $82 = Math_fround($45 * $54);
 $83 = Math_fround($49 * $57);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($52 * $60);
 $86 = Math_fround($85 + $84);
 $87 = (($agg$result) + 4|0);
 HEAPF32[$87>>2] = $86;
 HEAPF32[$73>>2] = $86;
 $88 = Math_fround($46 * $54);
 $89 = Math_fround($50 * $57);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround($53 * $60);
 $92 = Math_fround($91 + $90);
 $93 = (($agg$result) + 8|0);
 HEAPF32[$93>>2] = $92;
 HEAPF32[$80>>2] = $92;
 $94 = Math_fround($46 * $55);
 $95 = Math_fround($50 * $58);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($53 * $61);
 $98 = Math_fround($97 + $96);
 $99 = (($73) + 8|0);
 HEAPF32[$99>>2] = $98;
 $100 = (($80) + 4|0);
 HEAPF32[$100>>2] = $98;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb4Body22addSpatialAccelerationEPKNS_6PxVec3ES4_($this,$linAcc,$angAcc) {
 $this = $this|0;
 $linAcc = $linAcc|0;
 $angAcc = $angAcc|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 2416|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $9 = $3;
   label = 4;
  }
 } else if (!((($2|0) == 3))) {
  $$pre = HEAP32[$this>>2]|0;
  $9 = $$pre;
  label = 4;
 }
 if ((label|0) == 4) {
  $7 = (($this) + 16|0);
  $8 = (($9) + 1256|0);
  $10 = HEAP32[$8>>2]|0;
  __ZN5physx2Sc8BodyCore22addSpatialAccelerationEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEPKNS_6PxVec3ESB_($7,$10,$linAcc,$angAcc);
  STACKTOP = sp;return;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $14 = HEAP32[$this>>2]|0;
  $15 = $1 >>> 24;
  $16 = $15 & 15;
  $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
  HEAP32[$11>>2] = $17;
  $19 = $17;
 } else {
  $19 = $12;
 }
 $18 = (($19) + 232|0);
 $20 = ($linAcc|0)==(0|0);
 if (!($20)) {
  $21 = (($19) + 220|0);
  $22 = Math_fround(HEAPF32[$linAcc>>2]);
  $23 = Math_fround(HEAPF32[$21>>2]);
  $24 = Math_fround($22 + $23);
  HEAPF32[$21>>2] = $24;
  $25 = (($linAcc) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($19) + 224|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround($26 + $28);
  HEAPF32[$27>>2] = $29;
  $30 = (($linAcc) + 8|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($19) + 228|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($31 + $33);
  HEAPF32[$32>>2] = $34;
 }
 $35 = ($angAcc|0)==(0|0);
 if (!($35)) {
  $36 = Math_fround(HEAPF32[$angAcc>>2]);
  $37 = Math_fround(HEAPF32[$18>>2]);
  $38 = Math_fround($36 + $37);
  HEAPF32[$18>>2] = $38;
  $39 = (($angAcc) + 4|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($19) + 236|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($40 + $42);
  HEAPF32[$41>>2] = $43;
  $44 = (($angAcc) + 8|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($19) + 240|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($45 + $47);
  HEAPF32[$46>>2] = $48;
 }
 $49 = HEAP32[$this>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($49,$this);
 $50 = (($this) + 236|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = $51 | 16384;
 HEAP32[$50>>2] = $52;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb4Body18addSpatialVelocityEPKNS_6PxVec3ES4_($this,$linVelDelta,$angVelDelta) {
 $this = $this|0;
 $linVelDelta = $linVelDelta|0;
 $angVelDelta = $angVelDelta|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 2416|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $9 = $3;
   label = 4;
  }
 } else if (!((($2|0) == 3))) {
  $$pre = HEAP32[$this>>2]|0;
  $9 = $$pre;
  label = 4;
 }
 if ((label|0) == 4) {
  $7 = (($this) + 16|0);
  $8 = (($9) + 1256|0);
  $10 = HEAP32[$8>>2]|0;
  __ZN5physx2Sc8BodyCore18addSpatialVelocityEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEPKNS_6PxVec3ESB_($7,$10,$linVelDelta,$angVelDelta);
  STACKTOP = sp;return;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $14 = HEAP32[$this>>2]|0;
  $15 = $1 >>> 24;
  $16 = $15 & 15;
  $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
  HEAP32[$11>>2] = $17;
  $19 = $17;
 } else {
  $19 = $12;
 }
 $18 = (($19) + 256|0);
 $20 = ($linVelDelta|0)==(0|0);
 if (!($20)) {
  $21 = (($19) + 244|0);
  $22 = Math_fround(HEAPF32[$linVelDelta>>2]);
  $23 = Math_fround(HEAPF32[$21>>2]);
  $24 = Math_fround($22 + $23);
  HEAPF32[$21>>2] = $24;
  $25 = (($linVelDelta) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($19) + 248|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround($26 + $28);
  HEAPF32[$27>>2] = $29;
  $30 = (($linVelDelta) + 8|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($19) + 252|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($31 + $33);
  HEAPF32[$32>>2] = $34;
 }
 $35 = ($angVelDelta|0)==(0|0);
 if (!($35)) {
  $36 = Math_fround(HEAPF32[$angVelDelta>>2]);
  $37 = Math_fround(HEAPF32[$18>>2]);
  $38 = Math_fround($36 + $37);
  HEAPF32[$18>>2] = $38;
  $39 = (($angVelDelta) + 4|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($19) + 260|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($40 + $42);
  HEAPF32[$41>>2] = $43;
  $44 = (($angVelDelta) + 8|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($19) + 264|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($45 + $47);
  HEAPF32[$46>>2] = $48;
 }
 $49 = HEAP32[$this>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($49,$this);
 $50 = (($this) + 236|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = $51 | 32768;
 HEAP32[$50>>2] = $52;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((417376 + 8|0));
 $0 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreD2Ev($0);
 HEAP32[$this>>2] = ((417648 + 8|0));
 $1 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 $2 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 HEAP32[$this>>2] = ((417920 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((417376 + 8|0));
 $1 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreD2Ev($1);
 HEAP32[$this>>2] = ((417648 + 8|0));
 $2 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 $3 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($3);
 HEAP32[$this>>2] = ((417920 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((417648 + 8|0));
 $0 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($0);
 $1 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 HEAP32[$this>>2] = ((417920 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((417648 + 8|0));
 $1 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 $2 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 HEAP32[$this>>2] = ((417920 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((417920 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((417920 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $8 = $7;
 $$sum$i = (($6) + 4)|0;
 $9 = (($this) + ($$sum$i)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 24;
 $12 = $11 & 15;
 $13 = ((444424 + ($12<<2)|0) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($8))|0;
 $16 = $15;
 $17 = $10 >>> 30;
 if ((($17|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $7;
 } else if ((($17|0) == 2)) {
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 2417|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $7;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $1;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($16,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($6) + 8)|0;
 $22 = (($this) + ($$sum1$i)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$12)|0);
  HEAP32[$22>>2] = $26;
  $27 = $26;
 } else {
  $27 = $23;
 }
 HEAP16[$27>>1] = $1;
 $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$7);
 $29 = HEAP32[$9>>2]|0;
 $30 = $29 | 1;
 HEAP32[$9>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$bits) {
 $this = $this|0;
 $bits = $bits|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = HEAP8[$bits>>0]|0;
 $7 = $5;
 $$sum = (($4) + 4)|0;
 $8 = (($this) + ($$sum)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($7))|0;
 $15 = $14;
 $16 = $9 >>> 30;
 if ((($16|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($16|0) == 2)) {
  $17 = HEAP32[$5>>2]|0;
  $18 = (($17) + 2417|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $21 = (($15) + 11|0);
  HEAP8[$21>>0] = $6;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $22 = (($this) + ($$sum1)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$11)|0);
  HEAP32[$22>>2] = $26;
  $28 = $26;
 } else {
  $28 = $23;
 }
 $27 = (($28) + 3|0);
 HEAP8[$27>>0] = $6;
 $29 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($29,$5);
 $30 = HEAP32[$8>>2]|0;
 $31 = $30 | 4;
 HEAP32[$8>>2] = $31;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($0,$context);
 STACKTOP = sp;return;
}
function __ZN5physx18PxArticulationLinkD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx18PxArticulationLinkD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm29ConstraintImmediateVisualizerD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm29ConstraintImmediateVisualizer20visualizeJointFramesERKNS_11PxTransformES4_($this,$parent,$child) {
 $this = $this|0;
 $parent = $parent|0;
 $child = $child|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 __ZN5physx2Cm20visualizeJointFramesERNS0_12RenderOutputEfRKNS_11PxTransformES5_($1,$3,$parent,$child);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm29ConstraintImmediateVisualizer20visualizeLinearLimitERKNS_11PxTransformES4_fb($this,$t0,$t1,$value,$active) {
 $this = $this|0;
 $t0 = $t0|0;
 $t1 = $t1|0;
 $value = Math_fround($value);
 $active = $active|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 __ZN5physx2Cm20visualizeLinearLimitERNS0_12RenderOutputEfRKNS_11PxTransformES5_fb($1,$3,$t0,$t1,$value,$active);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm29ConstraintImmediateVisualizer21visualizeAngularLimitERKNS_11PxTransformEffb($this,$t0,$lower,$upper,$active) {
 $this = $this|0;
 $t0 = $t0|0;
 $lower = Math_fround($lower);
 $upper = Math_fround($upper);
 $active = $active|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 __ZN5physx2Cm21visualizeAngularLimitERNS0_12RenderOutputEfRKNS_11PxTransformEffb($1,$3,$t0,$lower,$upper,$active);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm29ConstraintImmediateVisualizer18visualizeLimitConeERKNS_11PxTransformEffb($this,$t,$ySwing,$zSwing,$active) {
 $this = $this|0;
 $t = $t|0;
 $ySwing = Math_fround($ySwing);
 $zSwing = Math_fround($zSwing);
 $active = $active|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 __ZN5physx2Cm18visualizeLimitConeERNS0_12RenderOutputEfRKNS_11PxTransformEffb($1,$3,$t,$ySwing,$zSwing,$active);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm29ConstraintImmediateVisualizer19visualizeDoubleConeERKNS_11PxTransformEfb($this,$t,$angle,$active) {
 $this = $this|0;
 $t = $t|0;
 $angle = Math_fround($angle);
 $active = $active|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 __ZN5physx2Cm19visualizeDoubleConeERNS0_12RenderOutputEfRKNS_11PxTransformEfb($1,$3,$t,$angle,$active);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_18NpArticulationLinkENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 16|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(17);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 418648 : 418616;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,418536,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 20|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 16|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx12NpBatchQueryC2ERNS_7NpSceneERKNS_16PxBatchQueryDescE($this,$owner,$d) {
 $this = $this|0;
 $owner = $owner|0;
 $d = $d|0;
 var $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((418776 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (__ZN5physx6shdfnd8SyncImpl7getSizeEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$0>>2] = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i$i$i = $12 ? 420072 : 419800;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i$i$i,419992,100)|0);
  HEAP32[$0>>2] = $13;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   __ZN5physx6shdfnd8SyncImplC2Ev($13);
  }
 }
 $15 = (($this) + 8|0);
 HEAP32[$15>>2] = $owner;
 $16 = (($this) + 12|0);
 $17 = (($this) + 40|0);
 ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;HEAP32[$16+24>>2]=0|0;
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 44|0);
 dest=$18+0|0; src=$d+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $19 = (($this) + 144|0);
 HEAP32[$19>>2] = -16;
 $20 = (($this) + 132|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 136|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 140|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 148|0);
 HEAP8[$23>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx12NpBatchQueryD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $notlhs$i$i$i$i = 0, $notrhs$i$i$i$i = 0, $or$cond$not$i$i$i$i = 0, $or$cond2$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((418776 + 8|0));
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager12freeSPUTasksEPNS_12NpBatchQueryE($3,$this);
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $notlhs$i$i$i$i = ($8|0)==(0);
 $notrhs$i$i$i$i = ($7|0)<(0);
 $or$cond$not$i$i$i$i = $notrhs$i$i$i$i | $notlhs$i$i$i$i;
 $9 = ($5|0)==(0|0);
 $or$cond2$i$i$i$i = $or$cond$not$i$i$i$i | $9;
 if (!($or$cond2$i$i$i$i)) {
  $10 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($10,$5);
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx6shdfnd8SyncImplD2Ev($15);
 $16 = HEAP32[$14>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
  STACKTOP = sp;return;
 }
 $18 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vii[$21 & 4095]($18,$16);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx12NpBatchQueryD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $notlhs$i$i$i = 0, $notrhs$i$i$i = 0, $or$cond$not$i$i$i = 0, $or$cond2$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((418776 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager12freeSPUTasksEPNS_12NpBatchQueryE($2,$this);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $notlhs$i$i$i = ($7|0)==(0);
 $notrhs$i$i$i = ($6|0)<(0);
 $or$cond$not$i$i$i = $notrhs$i$i$i | $notlhs$i$i$i;
 $8 = ($4|0)==(0|0);
 $or$cond2$i$i$i = $or$cond$not$i$i$i | $8;
 if (!($or$cond2$i$i$i)) {
  $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 4095]($9,$4);
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN5physx6shdfnd8SyncImplD2Ev($14);
 $15 = HEAP32[$13>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vii[$20 & 4095]($17,$15);
 STACKTOP = sp;return;
}
function __ZN5physx12NpBatchQuery13setUserMemoryERKNS_18PxBatchQueryMemoryE($this,$userMem) {
 $this = $this|0;
 $userMem = $userMem|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 40|0);
 $1 = (__ZN5physx6shdfnd21atomicCompareExchangeEPViii($0,0,0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $4 = (($this) + 80|0);
  dest=$4+0|0; src=$userMem+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 } else {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,8,418856,77,418936,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx12NpBatchQuery13getUserMemoryEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx12NpBatchQuery18resetResultBuffersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, $i1$03 = 0, $i2$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 80|0);
  $i$05 = 0;
  while(1) {
   $8 = HEAP32[$3>>2]|0;
   $9 = ((($8) + (($i$05*80)|0)|0) + 76|0);
   HEAP8[$9>>0] = 0;
   $10 = HEAP32[$3>>2]|0;
   $11 = ((($10) + (($i$05*80)|0)|0) + 77|0);
   HEAP8[$11>>0] = 0;
   $12 = ((($10) + (($i$05*80)|0)|0) + 68|0);
   HEAP32[$12>>2] = 0;
   $13 = ((($10) + (($i$05*80)|0)|0) + 64|0);
   HEAP32[$13>>2] = 0;
   $14 = HEAP32[$3>>2]|0;
   $15 = ((($14) + (($i$05*80)|0)|0) + 72|0);
   HEAP32[$15>>2] = 0;
   $16 = (($i$05) + 1)|0;
   $17 = HEAP32[$0>>2]|0;
   $18 = ($16>>>0)<($17>>>0);
   if ($18) {
    $i$05 = $16;
   } else {
    break;
   }
  }
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($this) + 96|0);
  $i1$03 = 0;
  while(1) {
   $23 = HEAP32[$7>>2]|0;
   $24 = ((($23) + ($i1$03<<5)|0) + 28|0);
   HEAP8[$24>>0] = 0;
   $25 = HEAP32[$7>>2]|0;
   $26 = ((($25) + ($i1$03<<5)|0) + 29|0);
   HEAP8[$26>>0] = 0;
   $27 = ((($25) + ($i1$03<<5)|0) + 20|0);
   HEAP32[$27>>2] = 0;
   $28 = ((($25) + ($i1$03<<5)|0) + 16|0);
   HEAP32[$28>>2] = 0;
   $29 = HEAP32[$7>>2]|0;
   $30 = ((($29) + ($i1$03<<5)|0) + 24|0);
   HEAP32[$30>>2] = 0;
   $31 = (($i1$03) + 1)|0;
   $32 = HEAP32[$4>>2]|0;
   $33 = ($31>>>0)<($32>>>0);
   if ($33) {
    $i1$03 = $31;
   } else {
    break;
   }
  }
 }
 $19 = (($this) + 36|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 88|0);
 $i2$01 = 0;
 while(1) {
  $34 = HEAP32[$22>>2]|0;
  $35 = ((($34) + ($i2$01<<6)|0) + 60|0);
  HEAP8[$35>>0] = 0;
  $36 = HEAP32[$22>>2]|0;
  $37 = ((($36) + ($i2$01<<6)|0) + 61|0);
  HEAP8[$37>>0] = 0;
  $38 = ((($36) + ($i2$01<<6)|0) + 52|0);
  HEAP32[$38>>2] = 0;
  $39 = ((($36) + ($i2$01<<6)|0) + 48|0);
  HEAP32[$39>>2] = 0;
  $40 = HEAP32[$22>>2]|0;
  $41 = ((($40) + ($i2$01<<6)|0) + 56|0);
  HEAP32[$41>>2] = 0;
  $42 = (($i2$01) + 1)|0;
  $43 = HEAP32[$19>>2]|0;
  $44 = ($42>>>0)<($43>>>0);
  if ($44) {
   $i2$01 = $42;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx12NpBatchQuery7executeEv($this) {
 $this = $this|0;
 var $$ = 0, $$30 = 0, $$31 = 0, $$pre = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0;
 var $$sum25 = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0;
 var $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0);
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $anyGeom$0$i$i = 0;
 var $bfd = 0, $curQueryOffset$0 = 0, $or$cond$i = 0, $or$cond$i2 = 0, $or$cond$i3 = 0, $queryCount$0 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $vararg_buffer1 = sp;
 $bfd = sp + 168|0;
 $0 = sp + 188|0;
 $1 = sp + 184|0;
 $2 = sp + 186|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1216|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 1208|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$6>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_viiii[$16 & 511]($6,136,$10,$13);
 $17 = (($this) + 40|0);
 $18 = (__ZN5physx6shdfnd21atomicCompareExchangeEPViii($17,1,0)|0);
 if ((($18|0) == -1)) {
  $23 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($23,8,418856,347,419080,$vararg_buffer1);
  $24 = HEAP32[$6>>2]|0;
  $25 = (($24) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  FUNCTION_TABLE_viiii[$26 & 511]($6,136,$10,$13);
  STACKTOP = sp;return;
 } else if ((($18|0) == 1)) {
  $19 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($19,8,418856,342,419024,$vararg_buffer1);
  $20 = HEAP32[$6>>2]|0;
  $21 = (($20) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_viiii[$22 & 511]($6,136,$10,$13);
  STACKTOP = sp;return;
 } else {
  __ZN5physx12NpBatchQuery18resetResultBuffersEv($this);
  $27 = HEAP32[$6>>2]|0;
  $28 = (($27) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_viiii[$29 & 511]($6,136,$10,$13);
  $30 = (($this) + 76|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = (($this) + 84|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($this) + 80|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($this) + 104|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($this) + 100|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($this) + 96|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($this) + 112|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($this) + 92|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($this) + 88|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($this) + 108|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($this) + 44|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($this) + 48|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($this) + 52|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($this) + 56|0);
  $57 = HEAP32[$56>>2]|0;
  HEAP32[$bfd>>2] = $51;
  $58 = (($bfd) + 4|0);
  HEAP32[$58>>2] = $53;
  $59 = (($bfd) + 8|0);
  HEAP32[$59>>2] = $55;
  $60 = (($bfd) + 12|0);
  HEAP32[$60>>2] = $57;
  $61 = (($this) + 144|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==(-16);
  if ($63) {
   HEAP32[$61>>2] = -16;
   $64 = (($this) + 24|0);
   $65 = (($this) + 148|0);
   HEAP8[$65>>0] = 0;
   ;HEAP32[$64+0>>2]=0|0;HEAP32[$64+4>>2]=0|0;HEAP32[$64+8>>2]=0|0;HEAP32[$64+12>>2]=0|0;
   (__ZN5physx6shdfnd14atomicExchangeEPVii($17,0)|0);
   STACKTOP = sp;return;
  }
  $66 = (($this) + 12|0);
  $67 = (($vararg_buffer1) + 4|0);
  $68 = (($vararg_buffer1) + 8|0);
  $69 = (($vararg_buffer1) + 12|0);
  $70 = (($vararg_buffer1) + 16|0);
  $71 = (($vararg_buffer1) + 20|0);
  $72 = (($vararg_buffer1) + 44|0);
  $73 = (($vararg_buffer1) + 48|0);
  $74 = (($vararg_buffer1) + 52|0);
  $75 = (($vararg_buffer1) + 68|0);
  $76 = (($vararg_buffer1) + 72|0);
  $77 = (($vararg_buffer1) + 76|0);
  $78 = (($vararg_buffer1) + 80|0);
  $79 = (($vararg_buffer1) + 84|0);
  $80 = (($vararg_buffer1) + 92|0);
  $81 = (($vararg_buffer1) + 96|0);
  $82 = (($vararg_buffer1) + 100|0);
  $83 = (($vararg_buffer1) + 104|0);
  $84 = (($vararg_buffer1) + 108|0);
  $85 = (($vararg_buffer1) + 132|0);
  $86 = (($vararg_buffer1) + 136|0);
  $87 = (($vararg_buffer1) + 140|0);
  $88 = (($vararg_buffer1) + 160|0);
  $89 = (($vararg_buffer1) + 4|0);
  $90 = (($vararg_buffer1) + 24|0);
  $91 = (($vararg_buffer1) + 28|0);
  $92 = (($vararg_buffer1) + 32|0);
  $93 = (($vararg_buffer1) + 36|0);
  $94 = (($vararg_buffer1) + 40|0);
  $95 = (($vararg_buffer1) + 4|0);
  $96 = (($vararg_buffer1) + 8|0);
  $97 = (($vararg_buffer1) + 12|0);
  $98 = (($vararg_buffer1) + 20|0);
  $99 = (($vararg_buffer1) + 24|0);
  $100 = (($vararg_buffer1) + 28|0);
  $101 = (($vararg_buffer1) + 32|0);
  $102 = (($vararg_buffer1) + 36|0);
  $103 = (($vararg_buffer1) + 44|0);
  $104 = (($vararg_buffer1) + 48|0);
  $105 = (($vararg_buffer1) + 52|0);
  $106 = (($vararg_buffer1) + 64|0);
  $107 = (($vararg_buffer1) + 4|0);
  $108 = (($vararg_buffer1) + 4|0);
  $109 = (($vararg_buffer1) + 8|0);
  $110 = (($vararg_buffer1) + 12|0);
  $111 = (($vararg_buffer1) + 16|0);
  $112 = (($vararg_buffer1) + 20|0);
  $113 = (($vararg_buffer1) + 44|0);
  $114 = (($vararg_buffer1) + 52|0);
  $115 = (($vararg_buffer1) + 56|0);
  $116 = (($vararg_buffer1) + 60|0);
  $117 = (($vararg_buffer1) + 64|0);
  $118 = (($vararg_buffer1) + 68|0);
  $119 = (($vararg_buffer1) + 76|0);
  $120 = (($vararg_buffer1) + 80|0);
  $121 = (($vararg_buffer1) + 84|0);
  $122 = (($vararg_buffer1) + 88|0);
  $123 = (($vararg_buffer1) + 92|0);
  $124 = (($vararg_buffer1) + 116|0);
  $125 = (($vararg_buffer1) + 128|0);
  $126 = (($vararg_buffer1) + 4|0);
  $127 = (($vararg_buffer1) + 24|0);
  $128 = (($vararg_buffer1) + 28|0);
  $129 = (($vararg_buffer1) + 32|0);
  $130 = (($vararg_buffer1) + 36|0);
  $131 = (($vararg_buffer1) + 40|0);
  $132 = (($vararg_buffer1) + 48|0);
  $174 = $33;$199 = $35;$234 = $39;$259 = $41;$277 = $45;$302 = $47;$curQueryOffset$0 = 0;$queryCount$0 = 0;
  while(1) {
   $133 = HEAP32[$66>>2]|0;
   $134 = (($133) + ($curQueryOffset$0)|0);
   $$sum = (($curQueryOffset$0) + 8)|0;
   $135 = (($133) + ($$sum)|0);
   $$sum4 = (($curQueryOffset$0) + 26)|0;
   $136 = (($133) + ($$sum4)|0);
   $137 = HEAP8[$136>>0]|0;
   $138 = ($137<<24>>24)==(0);
   if ($138) {
    HEAP8[$136>>0] = $31;
    $$pre = HEAP32[$66>>2]|0;
    $141 = $$pre;
   } else {
    $141 = $133;
   }
   $139 = HEAP32[$134>>2]|0;
   $140 = (($141) + ($139)|0);
   $$sum5 = (($curQueryOffset$0) + 40)|0;
   $142 = (($133) + ($$sum5)|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = ($143|0)==(0|0);
   if ($144) {
    $149 = 64;
   } else {
    $$sum6 = (($curQueryOffset$0) + 64)|0;
    $145 = (($133) + ($$sum6)|0);
    HEAP32[$142>>2] = $145;
    $149 = 76;
   }
   $$sum7 = (($curQueryOffset$0) + 44)|0;
   $146 = (($133) + ($$sum7)|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ($147|0)==(0|0);
   if ($148) {
    $155 = $149;
   } else {
    $$sum8 = (($149) + ($curQueryOffset$0))|0;
    $150 = (($133) + ($$sum8)|0);
    $151 = (($149) + 12)|0;
    HEAP32[$146>>2] = $150;
    $155 = $151;
   }
   $$sum9 = (($curQueryOffset$0) + 56)|0;
   $152 = (($133) + ($$sum9)|0);
   $153 = HEAP32[$152>>2]|0;
   $154 = ($153|0)==(0|0);
   if ($154) {
    $161 = $155;
   } else {
    $$sum10 = (($155) + ($curQueryOffset$0))|0;
    $156 = (($133) + ($$sum10)|0);
    $157 = (($155) + 28)|0;
    HEAP32[$152>>2] = $156;
    $161 = $157;
   }
   $$sum11 = (($curQueryOffset$0) + 52)|0;
   $158 = (($133) + ($$sum11)|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = ($159|0)==(0|0);
   if (!($160)) {
    $$sum12 = (($161) + ($curQueryOffset$0))|0;
    $162 = (($133) + ($$sum12)|0);
    $163 = (($161) + 4)|0;
    $164 = HEAP32[$162>>2]|0;
    if ((($164|0) == 2)) {
     $$sum29 = (($163) + ($curQueryOffset$0))|0;
     $165 = (($133) + ($$sum29)|0);
     $anyGeom$0$i$i = $165;
    } else if ((($164|0) == 4)) {
     $$sum27 = (($163) + ($curQueryOffset$0))|0;
     $167 = (($133) + ($$sum27)|0);
     $anyGeom$0$i$i = $167;
    } else if ((($164|0) == 0)) {
     $$sum28 = (($163) + ($curQueryOffset$0))|0;
     $166 = (($133) + ($$sum28)|0);
     $anyGeom$0$i$i = $166;
    } else if ((($164|0) == 3)) {
     $$sum13 = (($163) + ($curQueryOffset$0))|0;
     $168 = (($133) + ($$sum13)|0);
     $anyGeom$0$i$i = $168;
    } else {
     $anyGeom$0$i$i = 0;
    }
    HEAP32[$158>>2] = $anyGeom$0$i$i;
   }
   $$sum14 = (($curQueryOffset$0) + 38)|0;
   $169 = (($133) + ($$sum14)|0);
   $170 = HEAP8[$169>>0]|0;
   $171 = $170 << 24 >> 24;
   if ((($171|0) == 1)) {
    $232 = HEAP32[$38>>2]|0;
    $233 = $234;
    $235 = $232;
    $236 = (($233) - ($235))|0;
    $237 = $236 >> 4;
    $238 = (($43) - ($237))|0;
    $$sum19 = (($curQueryOffset$0) + 36)|0;
    $239 = (($133) + ($$sum19)|0);
    $240 = HEAP16[$239>>1]|0;
    $241 = $240&65535;
    $242 = ($241>>>0)<($238>>>0);
    $243 = $242 ? $241 : $238;
    HEAP32[$95>>2] = 0;
    HEAP32[$96>>2] = 0;
    HEAP32[$97>>2] = -1;
    HEAP8[$98>>0] = 0;
    HEAP32[$99>>2] = $234;
    HEAP32[$100>>2] = $243;
    HEAP32[$101>>2] = 0;
    HEAP32[$vararg_buffer1>>2] = ((419944 + 8|0));
    HEAP8[$102>>0] = 0;
    HEAP32[$103>>2] = 0;
    HEAP32[$104>>2] = 0;
    HEAP32[$105>>2] = -1;
    HEAP8[$106>>0] = 0;
    $244 = HEAP32[$3>>2]|0;
    $$sum20 = (($curQueryOffset$0) + 4)|0;
    $245 = (($133) + ($$sum20)|0);
    $246 = HEAP16[$245>>1]|0;
    HEAP16[$1>>1] = $246;
    $$sum21 = (($curQueryOffset$0) + 32)|0;
    $247 = (($133) + ($$sum21)|0);
    $248 = HEAP32[$247>>2]|0;
    (__ZNK5physx14NpSceneQueries10multiQueryINS_12PxOverlapHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($244,$142,$vararg_buffer1,$1,$248,$135,0,$bfd)|0);
    $249 = ($43|0)==($237|0);
    if ($249) {
     $250 = HEAP16[$239>>1]|0;
     $251 = ($250<<16>>16)!=(0);
     $253 = $251;
    } else {
     $253 = 0;
    }
    $252 = $253&1;
    $254 = HEAP8[$102>>0]|0;
    $255 = $254&255;
    $256 = $255 | $252;
    $257 = $256&255;
    HEAP8[$102>>0] = $257;
    $258 = (($259) + 32|0);
    $$sum22 = (($curQueryOffset$0) + 28)|0;
    $260 = (($133) + ($$sum22)|0);
    $261 = HEAP32[$260>>2]|0;
    $262 = ($257<<24>>24)!=(0);
    $263 = (($259) + 24|0);
    HEAP32[$263>>2] = $261;
    ;HEAP32[$259+0>>2]=HEAP32[$107+0>>2]|0;HEAP32[$259+4>>2]=HEAP32[$107+4>>2]|0;HEAP32[$259+8>>2]=HEAP32[$107+8>>2]|0;HEAP32[$259+12>>2]=HEAP32[$107+12>>2]|0;
    $264 = HEAP8[$98>>0]|0;
    $265 = (($259) + 29|0);
    HEAP8[$265>>0] = $264;
    $266 = HEAP32[$101>>2]|0;
    $267 = (($259) + 20|0);
    HEAP32[$267>>2] = $266;
    $268 = $262 ? 2 : 1;
    $269 = (($259) + 28|0);
    HEAP8[$269>>0] = $268;
    $270 = ($266|0)==(0);
    $or$cond$i2 = $270 & $262;
    $271 = HEAP32[$99>>2]|0;
    $$30 = $or$cond$i2 ? 0 : $271;
    $272 = (($259) + 16|0);
    HEAP32[$272>>2] = $$30;
    $273 = HEAP32[$101>>2]|0;
    $274 = (($234) + ($273<<4)|0);
    $342 = $174;$343 = $199;$344 = $274;$345 = $258;$346 = $277;$347 = $302;
   } else if ((($171|0) == 2)) {
    $275 = HEAP32[$44>>2]|0;
    $276 = $277;
    $278 = $275;
    $279 = (($276) - ($278))|0;
    $280 = (($279|0) / 48)&-1;
    $281 = (($49) - ($280))|0;
    $$sum15 = (($curQueryOffset$0) + 36)|0;
    $282 = (($133) + ($$sum15)|0);
    $283 = HEAP16[$282>>1]|0;
    $284 = $283&65535;
    $285 = ($284>>>0)<($281>>>0);
    $286 = $285 ? $284 : $281;
    HEAP32[$108>>2] = 0;
    HEAP32[$109>>2] = 0;
    HEAP32[$110>>2] = -1;
    HEAP16[$111>>1] = 0;
    ;HEAP32[$112+0>>2]=0|0;HEAP32[$112+4>>2]=0|0;HEAP32[$112+8>>2]=0|0;HEAP32[$112+12>>2]=0|0;HEAP32[$112+16>>2]=0|0;HEAP32[$112+20>>2]=0|0;
    HEAPF32[$113>>2] = Math_fround(3.40282346638528859812E+38);
    HEAP8[$114>>0] = 0;
    HEAP32[$115>>2] = $277;
    HEAP32[$116>>2] = $286;
    HEAP32[$117>>2] = 0;
    HEAP32[$vararg_buffer1>>2] = ((419920 + 8|0));
    HEAP8[$118>>0] = 0;
    HEAP32[$119>>2] = 0;
    HEAP32[$120>>2] = 0;
    HEAP32[$121>>2] = -1;
    HEAP16[$122>>1] = 0;
    ;HEAP32[$123+0>>2]=0|0;HEAP32[$123+4>>2]=0|0;HEAP32[$123+8>>2]=0|0;HEAP32[$123+12>>2]=0|0;HEAP32[$123+16>>2]=0|0;HEAP32[$123+20>>2]=0|0;
    HEAPF32[$124>>2] = Math_fround(3.40282346638528859812E+38);
    HEAP8[$125>>0] = 0;
    $287 = HEAP32[$3>>2]|0;
    $$sum16 = (($curQueryOffset$0) + 4)|0;
    $288 = (($133) + ($$sum16)|0);
    $289 = HEAP16[$288>>1]|0;
    HEAP16[$2>>1] = $289;
    $$sum17 = (($curQueryOffset$0) + 32)|0;
    $290 = (($133) + ($$sum17)|0);
    $291 = HEAP32[$290>>2]|0;
    (__ZNK5physx14NpSceneQueries10multiQueryINS_10PxSweepHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($287,$142,$vararg_buffer1,$2,$291,$135,0,$bfd)|0);
    $292 = ($49|0)==($280|0);
    if ($292) {
     $293 = HEAP16[$282>>1]|0;
     $294 = ($293<<16>>16)!=(0);
     $296 = $294;
    } else {
     $296 = 0;
    }
    $295 = $296&1;
    $297 = HEAP8[$118>>0]|0;
    $298 = $297&255;
    $299 = $298 | $295;
    $300 = $299&255;
    HEAP8[$118>>0] = $300;
    $301 = (($302) + 64|0);
    $$sum18 = (($curQueryOffset$0) + 28)|0;
    $303 = (($133) + ($$sum18)|0);
    $304 = HEAP32[$303>>2]|0;
    $305 = ($300<<24>>24)!=(0);
    $306 = (($302) + 56|0);
    HEAP32[$306>>2] = $304;
    ;HEAP32[$302+0>>2]=HEAP32[$126+0>>2]|0;HEAP32[$302+4>>2]=HEAP32[$126+4>>2]|0;HEAP32[$302+8>>2]=HEAP32[$126+8>>2]|0;
    $307 = HEAP16[$111>>1]|0;
    $308 = (($302) + 12|0);
    HEAP16[$308>>1] = $307;
    $309 = Math_fround(HEAPF32[$112>>2]);
    $310 = (($302) + 16|0);
    HEAPF32[$310>>2] = $309;
    $311 = Math_fround(HEAPF32[$127>>2]);
    $312 = (($302) + 20|0);
    HEAPF32[$312>>2] = $311;
    $313 = Math_fround(HEAPF32[$128>>2]);
    $314 = (($302) + 24|0);
    HEAPF32[$314>>2] = $313;
    $315 = Math_fround(HEAPF32[$129>>2]);
    $316 = (($302) + 28|0);
    HEAPF32[$316>>2] = $315;
    $317 = Math_fround(HEAPF32[$130>>2]);
    $318 = (($302) + 32|0);
    HEAPF32[$318>>2] = $317;
    $319 = Math_fround(HEAPF32[$131>>2]);
    $320 = (($302) + 36|0);
    HEAPF32[$320>>2] = $319;
    $321 = Math_fround(HEAPF32[$113>>2]);
    $322 = (($302) + 40|0);
    HEAPF32[$322>>2] = $321;
    $323 = HEAP32[$132>>2]|0;
    $324 = (($302) + 44|0);
    HEAP32[$324>>2] = $323;
    $325 = HEAP8[$114>>0]|0;
    $326 = (($302) + 61|0);
    HEAP8[$326>>0] = $325;
    $327 = HEAP32[$117>>2]|0;
    $328 = (($302) + 52|0);
    HEAP32[$328>>2] = $327;
    $329 = $305 ? 2 : 1;
    $330 = (($302) + 60|0);
    HEAP8[$330>>0] = $329;
    $331 = ($327|0)==(0);
    $or$cond$i = $331 & $305;
    $332 = HEAP32[$115>>2]|0;
    $$31 = $or$cond$i ? 0 : $332;
    $333 = (($302) + 48|0);
    HEAP32[$333>>2] = $$31;
    $334 = HEAP32[$117>>2]|0;
    $335 = (($277) + (($334*48)|0)|0);
    $342 = $174;$343 = $199;$344 = $234;$345 = $259;$346 = $335;$347 = $301;
   } else if ((($171|0) == 0)) {
    $172 = HEAP32[$32>>2]|0;
    $173 = $174;
    $175 = $172;
    $176 = (($173) - ($175))|0;
    $177 = $176 >> 6;
    $178 = (($37) - ($177))|0;
    $$sum23 = (($curQueryOffset$0) + 36)|0;
    $179 = (($133) + ($$sum23)|0);
    $180 = HEAP16[$179>>1]|0;
    $181 = $180&65535;
    $182 = ($181>>>0)<($178>>>0);
    $183 = $182 ? $181 : $178;
    HEAP32[$67>>2] = 0;
    HEAP32[$68>>2] = 0;
    HEAP32[$69>>2] = -1;
    HEAP16[$70>>1] = 0;
    ;HEAP32[$71+0>>2]=0|0;HEAP32[$71+4>>2]=0|0;HEAP32[$71+8>>2]=0|0;HEAP32[$71+12>>2]=0|0;HEAP32[$71+16>>2]=0|0;HEAP32[$71+20>>2]=0|0;
    HEAPF32[$72>>2] = Math_fround(3.40282346638528859812E+38);
    HEAPF32[$73>>2] = Math_fround(0.0);
    HEAPF32[$74>>2] = Math_fround(0.0);
    HEAP8[$75>>0] = 0;
    HEAP32[$76>>2] = $174;
    HEAP32[$77>>2] = $183;
    HEAP32[$78>>2] = 0;
    HEAP32[$vararg_buffer1>>2] = ((419968 + 8|0));
    HEAP8[$79>>0] = 0;
    HEAP32[$80>>2] = 0;
    HEAP32[$81>>2] = 0;
    HEAP32[$82>>2] = -1;
    HEAP16[$83>>1] = 0;
    ;HEAP32[$84+0>>2]=0|0;HEAP32[$84+4>>2]=0|0;HEAP32[$84+8>>2]=0|0;HEAP32[$84+12>>2]=0|0;HEAP32[$84+16>>2]=0|0;HEAP32[$84+20>>2]=0|0;
    HEAPF32[$85>>2] = Math_fround(3.40282346638528859812E+38);
    HEAPF32[$86>>2] = Math_fround(0.0);
    HEAPF32[$87>>2] = Math_fround(0.0);
    HEAP8[$88>>0] = 0;
    $184 = HEAP32[$3>>2]|0;
    $$sum24 = (($curQueryOffset$0) + 4)|0;
    $185 = (($133) + ($$sum24)|0);
    $186 = HEAP16[$185>>1]|0;
    HEAP16[$0>>1] = $186;
    $$sum25 = (($curQueryOffset$0) + 32)|0;
    $187 = (($133) + ($$sum25)|0);
    $188 = HEAP32[$187>>2]|0;
    (__ZNK5physx14NpSceneQueries10multiQueryINS_12PxRaycastHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($184,$142,$vararg_buffer1,$0,$188,$135,0,$bfd)|0);
    $189 = ($37|0)==($177|0);
    if ($189) {
     $190 = HEAP16[$179>>1]|0;
     $191 = ($190<<16>>16)!=(0);
     $193 = $191;
    } else {
     $193 = 0;
    }
    $192 = $193&1;
    $194 = HEAP8[$79>>0]|0;
    $195 = $194&255;
    $196 = $195 | $192;
    $197 = $196&255;
    HEAP8[$79>>0] = $197;
    $198 = (($199) + 80|0);
    $$sum26 = (($curQueryOffset$0) + 28)|0;
    $200 = (($133) + ($$sum26)|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = ($197<<24>>24)!=(0);
    $203 = (($199) + 72|0);
    HEAP32[$203>>2] = $201;
    ;HEAP32[$199+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$199+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$199+8>>2]=HEAP32[$89+8>>2]|0;
    $204 = HEAP16[$70>>1]|0;
    $205 = (($199) + 12|0);
    HEAP16[$205>>1] = $204;
    $206 = Math_fround(HEAPF32[$71>>2]);
    $207 = (($199) + 16|0);
    HEAPF32[$207>>2] = $206;
    $208 = Math_fround(HEAPF32[$90>>2]);
    $209 = (($199) + 20|0);
    HEAPF32[$209>>2] = $208;
    $210 = Math_fround(HEAPF32[$91>>2]);
    $211 = (($199) + 24|0);
    HEAPF32[$211>>2] = $210;
    $212 = Math_fround(HEAPF32[$92>>2]);
    $213 = (($199) + 28|0);
    HEAPF32[$213>>2] = $212;
    $214 = Math_fround(HEAPF32[$93>>2]);
    $215 = (($199) + 32|0);
    HEAPF32[$215>>2] = $214;
    $216 = Math_fround(HEAPF32[$94>>2]);
    $217 = (($199) + 36|0);
    HEAPF32[$217>>2] = $216;
    $218 = Math_fround(HEAPF32[$72>>2]);
    $219 = (($199) + 40|0);
    HEAPF32[$219>>2] = $218;
    $220 = (($199) + 44|0);
    ;HEAP32[$220+0>>2]=HEAP32[$73+0>>2]|0;HEAP32[$220+4>>2]=HEAP32[$73+4>>2]|0;HEAP32[$220+8>>2]=HEAP32[$73+8>>2]|0;HEAP32[$220+12>>2]=HEAP32[$73+12>>2]|0;HEAP32[$220+16>>2]=HEAP32[$73+16>>2]|0;
    $221 = HEAP8[$75>>0]|0;
    $222 = (($199) + 77|0);
    HEAP8[$222>>0] = $221;
    $223 = HEAP32[$78>>2]|0;
    $224 = (($199) + 68|0);
    HEAP32[$224>>2] = $223;
    $225 = $202 ? 2 : 1;
    $226 = (($199) + 76|0);
    HEAP8[$226>>0] = $225;
    $227 = ($223|0)==(0);
    $or$cond$i3 = $227 & $202;
    $228 = HEAP32[$76>>2]|0;
    $$ = $or$cond$i3 ? 0 : $228;
    $229 = (($199) + 64|0);
    HEAP32[$229>>2] = $$;
    $230 = HEAP32[$78>>2]|0;
    $231 = (($174) + ($230<<6)|0);
    $342 = $231;$343 = $198;$344 = $234;$345 = $259;$346 = $277;$347 = $302;
   } else {
    $342 = $174;$343 = $199;$344 = $234;$345 = $259;$346 = $277;$347 = $302;
   }
   $336 = HEAP32[$134>>2]|0;
   $337 = ($336|0)==(-16);
   if ($337) {
    break;
   }
   $338 = (($queryCount$0) + 1)|0;
   $339 = ($338>>>0)<(1000000);
   if ($339) {
    $174 = $342;$199 = $343;$234 = $344;$259 = $345;$277 = $346;$302 = $347;$curQueryOffset$0 = $139;$queryCount$0 = $338;
   } else {
    break;
   }
  }
  HEAP32[$61>>2] = -16;
  $340 = (($this) + 24|0);
  $341 = (($this) + 148|0);
  HEAP8[$341>>0] = 0;
  ;HEAP32[$340+0>>2]=0|0;HEAP32[$340+4>>2]=0|0;HEAP32[$340+8>>2]=0|0;HEAP32[$340+12>>2]=0|0;
  (__ZN5physx6shdfnd14atomicExchangeEPVii($17,0)|0);
  STACKTOP = sp;return;
 }
}
function __ZN16PxOverflowBufferIN5physx12PxRaycastHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16PxOverflowBufferIN5physx12PxOverlapHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16PxOverflowBufferIN5physx10PxSweepHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx12NpBatchQuery7raycastERKNS_6PxVec3ES3_ftNS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPvPKNS_12PxQueryCacheE($this,$origin,$unitDir,$distance,$maxTouchHits,$hitFlags,$fd,$userData,$cache) {
 $this = $this|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $maxTouchHits = $maxTouchHits|0;
 $hitFlags = $hitFlags|0;
 $fd = $fd|0;
 $userData = $userData|0;
 $cache = $cache|0;
 var $$sroa$2 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer = sp;
 $$sroa$2 = sp + 32|0;
 $0 = sp + 8|0;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 40|0);
 $7 = (__ZN5physx6shdfnd21atomicCompareExchangeEPViii($6,-1,0)|0);
 $8 = ($7|0)==(1);
 if ($8) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,418856,551,419160,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$1>>2] = $11;
 $12 = HEAP16[$hitFlags>>1]|0;
 $13 = (($$sroa$2) + 2|0);
 ;HEAP16[$13+0>>1]=HEAP16[$fd+0>>1]|0;HEAP16[$13+2>>1]=HEAP16[$fd+2>>1]|0;HEAP16[$13+4>>1]=HEAP16[$fd+4>>1]|0;HEAP16[$13+6>>1]=HEAP16[$fd+6>>1]|0;HEAP16[$13+8>>1]=HEAP16[$fd+8>>1]|0;HEAP16[$13+10>>1]=HEAP16[$fd+10>>1]|0;HEAP16[$13+12>>1]=HEAP16[$fd+12>>1]|0;HEAP16[$13+14>>1]=HEAP16[$fd+14>>1]|0;
 $14 = (($fd) + 16|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = (($fd) + 18|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = (($this) + 12|0);
 $19 = (($this) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 40)|0;
 $22 = (($this) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($21>>>0)>($24>>>0);
 if ($25) {
  $26 = ($21*3)|0;
  $27 = (($26) + 256)|0;
  $28 = ($24>>>0)<($27>>>0);
  if ($28) {
   __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($18,$27);
  }
 }
 __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($18,$21);
 $29 = HEAP32[$19>>2]|0;
 $30 = HEAP32[$18>>2]|0;
 $31 = (($30) + ($29)|0);
 HEAP32[$31>>2] = -16;
 $$sum = (($29) + 4)|0;
 $32 = (($30) + ($$sum)|0);
 HEAP16[$32>>1] = $12;
 $$sum2 = (($29) + 6)|0;
 $33 = (($30) + ($$sum2)|0);
 dest=$33+0|0; src=$$sroa$2+0|0; stop=dest+18|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
 $$sum3 = (($29) + 24)|0;
 $34 = (($30) + ($$sum3)|0);
 HEAP16[$34>>1] = $15;
 $$sum4 = (($29) + 26)|0;
 $35 = (($30) + ($$sum4)|0);
 HEAP8[$35>>0] = $17;
 $$sum6 = (($29) + 28)|0;
 $36 = (($30) + ($$sum6)|0);
 HEAP32[$36>>2] = $userData;
 $$sum7 = (($29) + 32)|0;
 $37 = (($30) + ($$sum7)|0);
 HEAP32[$37>>2] = $cache;
 $$sum8 = (($29) + 36)|0;
 $38 = (($30) + ($$sum8)|0);
 HEAP16[$38>>1] = $maxTouchHits;
 $$sum9 = (($29) + 38)|0;
 $39 = (($30) + ($$sum9)|0);
 HEAP8[$39>>0] = 0;
 HEAP32[$19>>2] = $21;
 $40 = (($this) + 144|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(-16);
 if ($42) {
  $45 = $40;
 } else {
  $43 = HEAP32[$18>>2]|0;
  $44 = (($43) + ($41)|0);
  $45 = $44;
 }
 HEAP32[$45>>2] = $20;
 HEAP32[$40>>2] = $20;
 HEAP32[$0>>2] = $origin;
 $46 = (($0) + 4|0);
 HEAP32[$46>>2] = $unitDir;
 $47 = (($0) + 8|0);
 HEAPF32[$47>>2] = $distance;
 $48 = (($0) + 12|0);
 HEAP32[$48>>2] = 0;
 $49 = (($0) + 16|0);
 HEAP32[$49>>2] = 0;
 $50 = (($0) + 20|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 __ZL15writeQueryInputRN5physx16BatchQueryStreamERKNS_15MultiQueryInputE($18,$0);
 (__ZN5physx6shdfnd14atomicExchangeEPVii($6,0)|0);
 STACKTOP = sp;return;
}
function __ZL15writeQueryInputRN5physx16BatchQueryStreamERKNS_15MultiQueryInputE($stream,$input) {
 $stream = $stream|0;
 $input = $input|0;
 var $$sum = 0, $$sum$i$i = 0, $$sum$i1$i = 0, $$sum1$i$i = 0, $$sum1$i2$i = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum2$i$i = 0, $$sum2$i3$i = 0, $$sum3$i$i = 0, $$sum4$i$i = 0, $$sum5$i$i = 0, $$sum6$i$i = 0;
 var $$sum7$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0;
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0;
 var $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 24)|0;
 $3 = (($stream) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = ($2>>>0)>($5>>>0);
 if ($6) {
  $7 = ($2*3)|0;
  $8 = (($7) + 256)|0;
  $9 = ($5>>>0)<($8>>>0);
  if ($9) {
   __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$8);
  }
 }
 __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$2);
 $10 = HEAP32[$0>>2]|0;
 $11 = HEAP32[$stream>>2]|0;
 $12 = (($11) + ($10)|0);
 ;HEAP32[$12+0>>2]=HEAP32[$input+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$input+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$input+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$input+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$input+16>>2]|0;HEAP32[$12+20>>2]=HEAP32[$input+20>>2]|0;
 HEAP32[$0>>2] = $2;
 $13 = HEAP32[$input>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $36 = $2;
 } else {
  $15 = (($1) + 36)|0;
  $16 = HEAP32[$3>>2]|0;
  $17 = $16 & 2147483647;
  $18 = ($15>>>0)>($17>>>0);
  if ($18) {
   $19 = ($15*3)|0;
   $20 = (($19) + 256)|0;
   $21 = ($17>>>0)<($20>>>0);
   if ($21) {
    __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$20);
   }
  }
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$15);
  $22 = HEAP32[$0>>2]|0;
  $23 = HEAP32[$stream>>2]|0;
  $24 = (($23) + ($22)|0);
  $25 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$24>>2] = $25;
  $26 = (($13) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $$sum = (($22) + 4)|0;
  $28 = (($23) + ($$sum)|0);
  HEAPF32[$28>>2] = $27;
  $29 = (($13) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $$sum10 = (($22) + 8)|0;
  $31 = (($23) + ($$sum10)|0);
  HEAPF32[$31>>2] = $30;
  HEAP32[$0>>2] = $15;
  $36 = $15;
 }
 $32 = (($input) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  $57 = $36;
 } else {
  $35 = (($36) + 12)|0;
  $37 = HEAP32[$3>>2]|0;
  $38 = $37 & 2147483647;
  $39 = ($35>>>0)>($38>>>0);
  if ($39) {
   $40 = ($35*3)|0;
   $41 = (($40) + 256)|0;
   $42 = ($38>>>0)<($41>>>0);
   if ($42) {
    __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$41);
   }
  }
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$35);
  $43 = HEAP32[$0>>2]|0;
  $44 = HEAP32[$stream>>2]|0;
  $45 = (($44) + ($43)|0);
  $46 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$45>>2] = $46;
  $47 = (($33) + 4|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $$sum11 = (($43) + 4)|0;
  $49 = (($44) + ($$sum11)|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($33) + 8|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $$sum12 = (($43) + 8)|0;
  $52 = (($44) + ($$sum12)|0);
  HEAPF32[$52>>2] = $51;
  HEAP32[$0>>2] = $35;
  $57 = $35;
 }
 $53 = (($input) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0|0);
 if ($55) {
  $91 = $57;
 } else {
  $56 = (($57) + 28)|0;
  $58 = HEAP32[$3>>2]|0;
  $59 = $58 & 2147483647;
  $60 = ($56>>>0)>($59>>>0);
  if ($60) {
   $61 = ($56*3)|0;
   $62 = (($61) + 256)|0;
   $63 = ($59>>>0)<($62>>>0);
   if ($63) {
    __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$62);
   }
  }
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$56);
  $64 = HEAP32[$0>>2]|0;
  $65 = HEAP32[$stream>>2]|0;
  $66 = (($65) + ($64)|0);
  $67 = Math_fround(HEAPF32[$54>>2]);
  HEAPF32[$66>>2] = $67;
  $68 = (($54) + 4|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $$sum13 = (($64) + 4)|0;
  $70 = (($65) + ($$sum13)|0);
  HEAPF32[$70>>2] = $69;
  $71 = (($54) + 8|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $$sum14 = (($64) + 8)|0;
  $73 = (($65) + ($$sum14)|0);
  HEAPF32[$73>>2] = $72;
  $74 = (($54) + 12|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $$sum15 = (($64) + 12)|0;
  $76 = (($65) + ($$sum15)|0);
  HEAPF32[$76>>2] = $75;
  $77 = (($54) + 16|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $$sum16 = (($64) + 16)|0;
  $79 = (($65) + ($$sum16)|0);
  HEAPF32[$79>>2] = $78;
  $80 = (($54) + 20|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $$sum17 = (($64) + 20)|0;
  $82 = (($65) + ($$sum17)|0);
  HEAPF32[$82>>2] = $81;
  $83 = (($54) + 24|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $$sum18 = (($64) + 24)|0;
  $85 = (($65) + ($$sum18)|0);
  HEAPF32[$85>>2] = $84;
  HEAP32[$0>>2] = $56;
  $91 = $56;
 }
 $86 = (($input) + 12|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(0|0);
 if ($88) {
  STACKTOP = sp;return;
 }
 $89 = HEAP32[$87>>2]|0;
 $90 = (($91) + 4)|0;
 $92 = HEAP32[$3>>2]|0;
 $93 = $92 & 2147483647;
 $94 = ($90>>>0)>($93>>>0);
 if ($94) {
  $95 = ($90*3)|0;
  $96 = (($95) + 256)|0;
  $97 = ($93>>>0)<($96>>>0);
  if ($97) {
   __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$96);
  }
 }
 __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$90);
 $98 = HEAP32[$0>>2]|0;
 $99 = HEAP32[$stream>>2]|0;
 $100 = (($99) + ($98)|0);
 HEAP32[$100>>2] = $89;
 HEAP32[$0>>2] = $90;
 if ((($89|0) == 3)) {
  $166 = (($91) + 20)|0;
  $167 = HEAP32[$3>>2]|0;
  $168 = $167 & 2147483647;
  $169 = ($166>>>0)>($168>>>0);
  if ($169) {
   $170 = ($166*3)|0;
   $171 = (($170) + 256)|0;
   $172 = ($168>>>0)<($171>>>0);
   if ($172) {
    __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$171);
   }
  }
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$166);
  $173 = HEAP32[$0>>2]|0;
  $174 = HEAP32[$stream>>2]|0;
  $175 = (($174) + ($173)|0);
  $176 = HEAP32[$87>>2]|0;
  HEAP32[$175>>2] = $176;
  $177 = (($87) + 4|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $$sum$i$i = (($173) + 4)|0;
  $179 = (($174) + ($$sum$i$i)|0);
  HEAPF32[$179>>2] = $178;
  $180 = (($87) + 8|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $$sum1$i$i = (($173) + 8)|0;
  $182 = (($174) + ($$sum1$i$i)|0);
  HEAPF32[$182>>2] = $181;
  $183 = (($87) + 12|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $$sum2$i$i = (($173) + 12)|0;
  $185 = (($174) + ($$sum2$i$i)|0);
  HEAPF32[$185>>2] = $184;
  HEAP32[$0>>2] = $166;
  STACKTOP = sp;return;
 } else if ((($89|0) == 4)) {
  $131 = (($91) + 40)|0;
  $132 = HEAP32[$3>>2]|0;
  $133 = $132 & 2147483647;
  $134 = ($131>>>0)>($133>>>0);
  if ($134) {
   $135 = ($131*3)|0;
   $136 = (($135) + 256)|0;
   $137 = ($133>>>0)<($136>>>0);
   if ($137) {
    __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$136);
   }
  }
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$131);
  $138 = HEAP32[$0>>2]|0;
  $139 = HEAP32[$stream>>2]|0;
  $140 = (($139) + ($138)|0);
  $141 = HEAP32[$87>>2]|0;
  HEAP32[$140>>2] = $141;
  $142 = (($87) + 4|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $$sum$i1$i = (($138) + 4)|0;
  $144 = (($139) + ($$sum$i1$i)|0);
  HEAPF32[$144>>2] = $143;
  $145 = (($87) + 8|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $$sum1$i2$i = (($138) + 8)|0;
  $147 = (($139) + ($$sum1$i2$i)|0);
  HEAPF32[$147>>2] = $146;
  $148 = (($87) + 12|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $$sum2$i3$i = (($138) + 12)|0;
  $150 = (($139) + ($$sum2$i3$i)|0);
  HEAPF32[$150>>2] = $149;
  $151 = (($87) + 16|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $$sum3$i$i = (($138) + 16)|0;
  $153 = (($139) + ($$sum3$i$i)|0);
  HEAPF32[$153>>2] = $152;
  $154 = (($87) + 20|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $$sum4$i$i = (($138) + 20)|0;
  $156 = (($139) + ($$sum4$i$i)|0);
  HEAPF32[$156>>2] = $155;
  $157 = (($87) + 24|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $$sum5$i$i = (($138) + 24)|0;
  $159 = (($139) + ($$sum5$i$i)|0);
  HEAPF32[$159>>2] = $158;
  $160 = (($87) + 28|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $$sum6$i$i = (($138) + 28)|0;
  $162 = (($139) + ($$sum6$i$i)|0);
  HEAPF32[$162>>2] = $161;
  $163 = (($87) + 32|0);
  $164 = HEAP32[$163>>2]|0;
  $$sum7$i$i = (($138) + 32)|0;
  $165 = (($139) + ($$sum7$i$i)|0);
  HEAP32[$165>>2] = $164;
  HEAP32[$0>>2] = $131;
  STACKTOP = sp;return;
 } else if ((($89|0) == 0)) {
  $111 = (($91) + 12)|0;
  $112 = HEAP32[$3>>2]|0;
  $113 = $112 & 2147483647;
  $114 = ($111>>>0)>($113>>>0);
  if ($114) {
   $115 = ($111*3)|0;
   $116 = (($115) + 256)|0;
   $117 = ($113>>>0)<($116>>>0);
   if ($117) {
    __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$116);
   }
  }
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$111);
  $118 = HEAP32[$0>>2]|0;
  $119 = HEAP32[$stream>>2]|0;
  $120 = (($119) + ($118)|0);
  $121 = $87;
  $122 = $121;
  $123 = HEAP32[$122>>2]|0;
  $124 = (($121) + 4)|0;
  $125 = $124;
  $126 = HEAP32[$125>>2]|0;
  $127 = $120;
  $128 = $127;
  HEAP32[$128>>2] = $123;
  $129 = (($127) + 4)|0;
  $130 = $129;
  HEAP32[$130>>2] = $126;
  HEAP32[$0>>2] = $111;
  STACKTOP = sp;return;
 } else if ((($89|0) == 2)) {
  $101 = (($91) + 16)|0;
  $102 = HEAP32[$3>>2]|0;
  $103 = $102 & 2147483647;
  $104 = ($101>>>0)>($103>>>0);
  if ($104) {
   $105 = ($101*3)|0;
   $106 = (($105) + 256)|0;
   $107 = ($103>>>0)<($106>>>0);
   if ($107) {
    __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($stream,$106);
   }
  }
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($stream,$101);
  $108 = HEAP32[$0>>2]|0;
  $109 = HEAP32[$stream>>2]|0;
  $110 = (($109) + ($108)|0);
  ;HEAP32[$110+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$110+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$110+8>>2]=HEAP32[$87+8>>2]|0;
  HEAP32[$0>>2] = $101;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx12NpBatchQuery7overlapERKNS_10PxGeometryERKNS_11PxTransformEtRKNS_17PxQueryFilterDataEPvPKNS_12PxQueryCacheE($this,$geometry,$pose,$maxTouchHits,$fd,$userData,$cache) {
 $this = $this|0;
 $geometry = $geometry|0;
 $pose = $pose|0;
 $maxTouchHits = $maxTouchHits|0;
 $fd = $fd|0;
 $userData = $userData|0;
 $cache = $cache|0;
 var $$sroa$2 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer = sp;
 $$sroa$2 = sp + 32|0;
 $0 = sp + 8|0;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 40|0);
 $7 = (__ZN5physx6shdfnd21atomicCompareExchangeEPViii($6,-1,0)|0);
 $8 = ($7|0)==(1);
 if ($8) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,418856,572,419232,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$1>>2] = $11;
 $12 = (($$sroa$2) + 2|0);
 ;HEAP16[$12+0>>1]=HEAP16[$fd+0>>1]|0;HEAP16[$12+2>>1]=HEAP16[$fd+2>>1]|0;HEAP16[$12+4>>1]=HEAP16[$fd+4>>1]|0;HEAP16[$12+6>>1]=HEAP16[$fd+6>>1]|0;HEAP16[$12+8>>1]=HEAP16[$fd+8>>1]|0;HEAP16[$12+10>>1]=HEAP16[$fd+10>>1]|0;HEAP16[$12+12>>1]=HEAP16[$fd+12>>1]|0;HEAP16[$12+14>>1]=HEAP16[$fd+14>>1]|0;
 $13 = (($fd) + 16|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = (($fd) + 18|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = (($this) + 12|0);
 $18 = (($this) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 40)|0;
 $21 = (($this) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 & 2147483647;
 $24 = ($20>>>0)>($23>>>0);
 if ($24) {
  $25 = ($20*3)|0;
  $26 = (($25) + 256)|0;
  $27 = ($23>>>0)<($26>>>0);
  if ($27) {
   __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($17,$26);
  }
 }
 __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($17,$20);
 $28 = HEAP32[$18>>2]|0;
 $29 = HEAP32[$17>>2]|0;
 $30 = (($29) + ($28)|0);
 HEAP32[$30>>2] = -16;
 $$sum = (($28) + 4)|0;
 $31 = (($29) + ($$sum)|0);
 HEAP16[$31>>1] = 0;
 $$sum2 = (($28) + 6)|0;
 $32 = (($29) + ($$sum2)|0);
 dest=$32+0|0; src=$$sroa$2+0|0; stop=dest+18|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
 $$sum3 = (($28) + 24)|0;
 $33 = (($29) + ($$sum3)|0);
 HEAP16[$33>>1] = $14;
 $$sum4 = (($28) + 26)|0;
 $34 = (($29) + ($$sum4)|0);
 HEAP8[$34>>0] = $16;
 $$sum6 = (($28) + 28)|0;
 $35 = (($29) + ($$sum6)|0);
 HEAP32[$35>>2] = $userData;
 $$sum7 = (($28) + 32)|0;
 $36 = (($29) + ($$sum7)|0);
 HEAP32[$36>>2] = $cache;
 $$sum8 = (($28) + 36)|0;
 $37 = (($29) + ($$sum8)|0);
 HEAP16[$37>>1] = $maxTouchHits;
 $$sum9 = (($28) + 38)|0;
 $38 = (($29) + ($$sum9)|0);
 HEAP8[$38>>0] = 1;
 HEAP32[$18>>2] = $20;
 $39 = (($this) + 144|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(-16);
 if ($41) {
  $44 = $39;
 } else {
  $42 = HEAP32[$17>>2]|0;
  $43 = (($42) + ($40)|0);
  $44 = $43;
 }
 HEAP32[$44>>2] = $19;
 HEAP32[$39>>2] = $19;
 $45 = (($0) + 12|0);
 HEAP32[$45>>2] = $geometry;
 $46 = (($0) + 16|0);
 HEAP32[$46>>2] = $pose;
 $47 = (($0) + 20|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($0) + 4|0);
 HEAP32[$48>>2] = 0;
 HEAP32[$0>>2] = 0;
 __ZL15writeQueryInputRN5physx16BatchQueryStreamERKNS_15MultiQueryInputE($17,$0);
 (__ZN5physx6shdfnd14atomicExchangeEPVii($6,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx12NpBatchQuery5sweepERKNS_10PxGeometryERKNS_11PxTransformERKNS_6PxVec3EftNS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPvPKNS_12PxQueryCacheEf($this,$geometry,$pose,$unitDir,$distance,$maxTouchHits,$hitFlags,$fd,$userData,$cache,$inflation) {
 $this = $this|0;
 $geometry = $geometry|0;
 $pose = $pose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $maxTouchHits = $maxTouchHits|0;
 $hitFlags = $hitFlags|0;
 $fd = $fd|0;
 $userData = $userData|0;
 $cache = $cache|0;
 $inflation = Math_fround($inflation);
 var $$lobit = 0, $$sroa$2 = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $or$cond = 0, $realInflation$0 = Math_fround(0), $vararg_buffer5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer5 = sp;
 $$sroa$2 = sp + 32|0;
 $0 = sp + 8|0;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 40|0);
 $7 = (__ZN5physx6shdfnd21atomicCompareExchangeEPViii($6,-1,0)|0);
 $8 = ($7|0)==(1);
 if ($8) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,418856,600,419304,$vararg_buffer5);
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$1>>2] = $11;
 $12 = HEAP16[$hitFlags>>1]|0;
 $13 = (($$sroa$2) + 2|0);
 ;HEAP16[$13+0>>1]=HEAP16[$fd+0>>1]|0;HEAP16[$13+2>>1]=HEAP16[$fd+2>>1]|0;HEAP16[$13+4>>1]=HEAP16[$fd+4>>1]|0;HEAP16[$13+6>>1]=HEAP16[$fd+6>>1]|0;HEAP16[$13+8>>1]=HEAP16[$fd+8>>1]|0;HEAP16[$13+10>>1]=HEAP16[$fd+10>>1]|0;HEAP16[$13+12>>1]=HEAP16[$fd+12>>1]|0;HEAP16[$13+14>>1]=HEAP16[$fd+14>>1]|0;
 $14 = (($fd) + 16|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = (($fd) + 18|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = (($this) + 12|0);
 $19 = (($this) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 40)|0;
 $22 = (($this) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($21>>>0)>($24>>>0);
 if ($25) {
  $26 = ($21*3)|0;
  $27 = (($26) + 256)|0;
  $28 = ($24>>>0)<($27>>>0);
  if ($28) {
   __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($18,$27);
  }
 }
 __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($18,$21);
 $29 = HEAP32[$19>>2]|0;
 $30 = HEAP32[$18>>2]|0;
 $31 = (($30) + ($29)|0);
 HEAP32[$31>>2] = -16;
 $$sum = (($29) + 4)|0;
 $32 = (($30) + ($$sum)|0);
 HEAP16[$32>>1] = $12;
 $$sum10 = (($29) + 6)|0;
 $33 = (($30) + ($$sum10)|0);
 dest=$33+0|0; src=$$sroa$2+0|0; stop=dest+18|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
 $$sum11 = (($29) + 24)|0;
 $34 = (($30) + ($$sum11)|0);
 HEAP16[$34>>1] = $15;
 $$sum12 = (($29) + 26)|0;
 $35 = (($30) + ($$sum12)|0);
 HEAP8[$35>>0] = $17;
 $$sum14 = (($29) + 28)|0;
 $36 = (($30) + ($$sum14)|0);
 HEAP32[$36>>2] = $userData;
 $$sum15 = (($29) + 32)|0;
 $37 = (($30) + ($$sum15)|0);
 HEAP32[$37>>2] = $cache;
 $$sum16 = (($29) + 36)|0;
 $38 = (($30) + ($$sum16)|0);
 HEAP16[$38>>1] = $maxTouchHits;
 $$sum17 = (($29) + 38)|0;
 $39 = (($30) + ($$sum17)|0);
 HEAP8[$39>>0] = 2;
 HEAP32[$19>>2] = $21;
 $40 = (($this) + 144|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(-16);
 if ($42) {
  $45 = $40;
 } else {
  $43 = HEAP32[$18>>2]|0;
  $44 = (($43) + ($41)|0);
  $45 = $44;
 }
 HEAP32[$45>>2] = $20;
 HEAP32[$40>>2] = $20;
 $46 = HEAP16[$hitFlags>>1]|0;
 $47 = ($46&65535) >>> 9;
 $$lobit = $47 & 1;
 $48 = $$lobit&65535;
 $49 = (($this) + 148|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = $50&255;
 $52 = $48 | $51;
 $53 = $52&255;
 HEAP8[$49>>0] = $53;
 $54 = $46 & 768;
 $55 = ($54<<16>>16)==(768);
 if ($55) {
  $56 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($56,4,418856,610,419376,$vararg_buffer5);
  $57 = HEAP16[$hitFlags>>1]|0;
  $58 = $57 & -257;
  HEAP16[$hitFlags>>1] = $58;
  $60 = $58;
 } else {
  $60 = $46;
 }
 $59 = $60 & 528;
 $61 = ($59<<16>>16)==(528);
 if ($61) {
  $62 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($62,4,418856,616,419448,$vararg_buffer5);
  $63 = HEAP16[$hitFlags>>1]|0;
  $64 = $63 & -17;
  HEAP16[$hitFlags>>1] = $64;
  $66 = $64;
 } else {
  $66 = $60;
 }
 $65 = $66 & 256;
 $67 = ($65<<16>>16)!=(0);
 $68 = $inflation > Math_fround(0.0);
 $or$cond = $67 & $68;
 if ($or$cond) {
  $69 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($69,4,418856,624,419560,$vararg_buffer5);
  $realInflation$0 = Math_fround(0.0);
 } else {
  $realInflation$0 = $inflation;
 }
 HEAP32[$0>>2] = 0;
 $70 = (($0) + 8|0);
 HEAPF32[$70>>2] = $distance;
 $71 = (($0) + 4|0);
 HEAP32[$71>>2] = $unitDir;
 $72 = (($0) + 12|0);
 HEAP32[$72>>2] = $geometry;
 $73 = (($0) + 16|0);
 HEAP32[$73>>2] = $pose;
 $74 = (($0) + 20|0);
 HEAPF32[$74>>2] = $realInflation$0;
 __ZL15writeQueryInputRN5physx16BatchQueryStreamERKNS_15MultiQueryInputE($18,$0);
 (__ZN5physx6shdfnd14atomicExchangeEPVii($6,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx12NpBatchQuery7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 40|0);
 $1 = (__ZN5physx6shdfnd21atomicCompareExchangeEPViii($0,0,0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN5physx7NpScene17releaseBatchQueryEPNS_12PxBatchQueryE($5,$this);
  STACKTOP = sp;return;
 } else {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,8,418856,636,419648,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx12NpBatchQuery18getPreFilterShaderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx12NpBatchQuery19getPostFilterShaderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx12NpBatchQuery19getFilterShaderDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx12NpBatchQuery23getFilterShaderDataSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx12NpBatchQuery14getOwnerClientEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP8[$0>>0]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx12NpBatchQuery11setRunOnSpuEb($this,$runOnSpu) {
 $this = $this|0;
 $runOnSpu = $runOnSpu|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = $runOnSpu&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx12NpBatchQuery11getRunOnSpuEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx12NpBatchQuery7getDescEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $14 = 0;
 } else {
  $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__Z15PxGetFoundationv()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
  $$$i$i$i = $9 ? 419832 : 419800;
  $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,$capacity,$$$i$i$i,419720,558)|0);
  $14 = $10;
 }
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($14) + ($12)|0);
 $15 = HEAP32[$this>>2]|0;
 $16 = ($12|0)>(0);
 if ($16) {
  $$012$i = $14;$$03$i = $15;
  while(1) {
   $17 = ($$012$i|0)==(0|0);
   if (!($17)) {
    $18 = HEAP8[$$03$i>>0]|0;
    HEAP8[$$012$i>>0] = $18;
   }
   $19 = (($$012$i) + 1|0);
   $20 = (($$03$i) + 1|0);
   $exitcond$i = ($19|0)==($13|0);
   if ($exitcond$i) {
    break;
   } else {
    $$012$i = $19;$$03$i = $20;
   }
  }
  $$pr = HEAP32[$this>>2]|0;
  $25 = $$pr;
 } else {
  $25 = $15;
 }
 $21 = (($this) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)<(0);
 $24 = ($25|0)==(0|0);
 $or$cond = $23 | $24;
 if ($or$cond) {
  HEAP32[$this>>2] = $14;
  HEAP32[$21>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$29 & 4095]($26,$25);
 HEAP32[$this>>2] = $14;
 HEAP32[$21>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN16PxOverflowBufferIN5physx10PxSweepHitEE14processTouchesEPKS1_j($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 128|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 124|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 72|0);
 HEAP32[$10>>2] = $9;
 HEAP8[$2>>0] = 1;
 $11 = (($this) + 76|0);
 HEAP32[$5>>2] = $11;
 $12 = (($this) + 60|0);
 HEAP32[$12>>2] = 1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16PxOverflowBufferIN5physx10PxSweepHitEE13finalizeQueryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(0);
 $6 = (($this) + 68|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = (($this) + 72|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$3>>2] = $9;
 $10 = (($this) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 56|0);
 HEAP32[$12>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN16PxOverflowBufferIN5physx10PxSweepHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16PxOverflowBufferIN5physx12PxOverlapHitEE14processTouchesEPKS1_j($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 64|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 60|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 40|0);
 HEAP32[$10>>2] = $9;
 HEAP8[$2>>0] = 1;
 $11 = (($this) + 44|0);
 HEAP32[$5>>2] = $11;
 $12 = (($this) + 28|0);
 HEAP32[$12>>2] = 1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16PxOverflowBufferIN5physx12PxOverlapHitEE13finalizeQueryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(0);
 $6 = (($this) + 36|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$3>>2] = $9;
 $10 = (($this) + 60|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 24|0);
 HEAP32[$12>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN16PxOverflowBufferIN5physx12PxOverlapHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16PxOverflowBufferIN5physx12PxRaycastHitEE14processTouchesEPKS1_j($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 160|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 156|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 88|0);
 HEAP32[$10>>2] = $9;
 HEAP8[$2>>0] = 1;
 $11 = (($this) + 92|0);
 HEAP32[$5>>2] = $11;
 $12 = (($this) + 76|0);
 HEAP32[$12>>2] = 1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16PxOverflowBufferIN5physx12PxRaycastHitEE13finalizeQueryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(0);
 $6 = (($this) + 84|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = (($this) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$3>>2] = $9;
 $10 = (($this) + 156|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 72|0);
 HEAP32[$12>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN16PxOverflowBufferIN5physx12PxRaycastHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint22setConstraintFunctionsERNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableE($this,$n,$shaders) {
 $this = $this|0;
 $n = $n|0;
 $shaders = $shaders|0;
 var $$0$i = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bNeedUpdate$0$off0 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, $or$cond$i = 0, $or$cond1$i = 0, $s0$0$i = 0, $s1$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 16|0);
 $3 = (($this) + 56|0);
 HEAP32[$3>>2] = $n;
 $4 = HEAP32[$shaders>>2]|0;
 $5 = (($this) + 64|0);
 HEAP32[$5>>2] = $4;
 $6 = (($shaders) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 HEAP32[$8>>2] = $7;
 $9 = (($shaders) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 72|0);
 HEAP32[$11>>2] = $10;
 $12 = (($shaders) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = $13;
 $15 = (($shaders) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 76|0);
 HEAP32[$17>>2] = $16;
 $18 = (($this) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $bNeedUpdate$0$off0 = 0;
 } else {
  $21 = (($19) + 4|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22&65535;
  $24 = (414264 + ($23<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($19) + ($25)|0);
  $27 = (__ZNK5physx7NpActor13findConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseE($26,0,$this)|0);
  $28 = ($27|0)==(-1);
  if ($28) {
   $29 = HEAP32[$18>>2]|0;
   $30 = (($29) + 4|0);
   $31 = HEAP16[$30>>1]|0;
   $32 = $31&65535;
   $33 = (414264 + ($32<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($29) + ($34)|0);
   __ZN5physx7NpActor12addConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($35,0,$this,420192);
   $bNeedUpdate$0$off0 = 1;
  } else {
   $bNeedUpdate$0$off0 = 0;
  }
 }
 $36 = (($this) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  label = 7;
 } else {
  $39 = (($37) + 4|0);
  $40 = HEAP16[$39>>1]|0;
  $41 = $40&65535;
  $42 = (414264 + ($41<<2)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($37) + ($43)|0);
  $45 = (__ZNK5physx7NpActor13findConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseE($44,0,$this)|0);
  $46 = ($45|0)==(-1);
  if ($46) {
   $47 = HEAP32[$36>>2]|0;
   $48 = (($47) + 4|0);
   $49 = HEAP16[$48>>1]|0;
   $50 = $49&65535;
   $51 = (414264 + ($50<<2)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($47) + ($52)|0);
   __ZN5physx7NpActor12addConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($53,0,$this,420192);
  } else {
   label = 7;
  }
 }
 if ((label|0) == 7) {
  if (!($bNeedUpdate$0$off0)) {
   STACKTOP = sp;return;
  }
 }
 $54 = HEAP32[$18>>2]|0;
 $55 = ($54|0)==(0|0);
 if ($55) {
  $s0$0$i = 0;
 } else {
  $56 = HEAP32[$54>>2]|0;
  $57 = (($56) + 52|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 4095]($0,$54);
  $59 = HEAP16[$0>>1]|0;
  $60 = $59 & 8;
  $61 = ($60<<16>>16)==(0);
  if ($61) {
   $62 = HEAP32[$18>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = (($63) + 28|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (FUNCTION_TABLE_ii[$65 & 4095]($62)|0);
   $s0$0$i = $66;
  } else {
   $s0$0$i = 0;
  }
 }
 $67 = HEAP32[$36>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  $s1$0$i = 0;
 } else {
  $69 = HEAP32[$67>>2]|0;
  $70 = (($69) + 52|0);
  $71 = HEAP32[$70>>2]|0;
  FUNCTION_TABLE_vii[$71 & 4095]($1,$67);
  $72 = HEAP16[$1>>1]|0;
  $73 = $72 & 8;
  $74 = ($73<<16>>16)==(0);
  if ($74) {
   $75 = HEAP32[$36>>2]|0;
   $76 = HEAP32[$75>>2]|0;
   $77 = (($76) + 28|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (FUNCTION_TABLE_ii[$78 & 4095]($75)|0);
   $s1$0$i = $79;
  } else {
   $s1$0$i = 0;
  }
 }
 $80 = HEAP32[$18>>2]|0;
 $81 = ($80|0)!=(0|0);
 $82 = ($s0$0$i|0)==(0|0);
 $or$cond$i = $81 & $82;
 if ($or$cond$i) {
  $$0$i = 0;
 } else {
  $83 = HEAP32[$36>>2]|0;
  $84 = ($83|0)!=(0|0);
  $85 = ($s1$0$i|0)==(0|0);
  $or$cond1$i = $84 & $85;
  if ($or$cond1$i) {
   $$0$i = 0;
  } else {
   $86 = ($s0$0$i|0)!=(0|0);
   $87 = $86 ? $s0$0$i : $s1$0$i;
   $$0$i = $87;
  }
 }
 $88 = (($this) + 20|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = $89 >>> 30;
 $$off$i$i = (($90) + -1)|0;
 $91 = ($$off$i$i>>>0)<(2);
 if ($91) {
  $92 = (($this) + 16|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = ($93|0)==(0|0);
  if ($94) {
   $97 = 0;
  } else {
   $95 = (__ZN5physx3Scb5Scene10getPxSceneEv($93)|0);
   $97 = $95;
  }
 } else {
  $97 = 0;
 }
 $96 = ($97|0)==($$0$i|0);
 if ($96) {
  STACKTOP = sp;return;
 }
 $98 = ($97|0)==(0|0);
 if (!($98)) {
  $99 = (($97) + 3528|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0);
  if (!($101)) {
   $102 = (($97) + 3524|0);
   $103 = HEAP32[$102>>2]|0;
   $index$01$i$i = 0;
   while(1) {
    $106 = (($103) + ($index$01$i$i<<2)|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = ($107|0)==($this|0);
    $105 = (($index$01$i$i) + 1)|0;
    if ($108) {
     $index$0$lcssa$i$i = $index$01$i$i;
     break;
    }
    $104 = ($105>>>0)<($100>>>0);
    if ($104) {
     $index$01$i$i = $105;
    } else {
     $index$0$lcssa$i$i = $105;
     break;
    }
   }
   $109 = ($index$0$lcssa$i$i|0)==($100|0);
   if (!($109)) {
    $110 = (($100) + -1)|0;
    HEAP32[$99>>2] = $110;
    $111 = (($103) + ($110<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($103) + ($index$0$lcssa$i$i<<2)|0);
    HEAP32[$113>>2] = $112;
   }
  }
  $114 = (($97) + 16|0);
  __ZN5physx3Scb5Scene16removeConstraintERNS0_10ConstraintE($114,$2);
 }
 $115 = ($$0$i|0)==(0|0);
 if ($115) {
  STACKTOP = sp;return;
 }
 $116 = (($$0$i) + 3524|0);
 HEAP32[$0>>2] = $this;
 $117 = (($$0$i) + 3532|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = $118 & 2147483647;
 $120 = (($$0$i) + 3528|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($119>>>0)>($121>>>0);
 if ($122) {
  $123 = HEAP32[$116>>2]|0;
  $124 = (($123) + ($121<<2)|0);
  $125 = ($124|0)==(0|0);
  if (!($125)) {
   HEAP32[$124>>2] = $this;
  }
  $126 = (($121) + 1)|0;
  HEAP32[$120>>2] = $126;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_12PxConstraintENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($116,$0)|0);
 }
 $127 = (($$0$i) + 16|0);
 __ZN5physx3Scb5Scene13addConstraintERNS0_10ConstraintE($127,$2);
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint18checkActorsInSceneEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond1 = 0, $s0$0 = 0, $s1$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $s0$0 = 0;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 52|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 4095]($0,$3);
  $8 = HEAP16[$0>>1]|0;
  $9 = $8 & 8;
  $10 = ($9<<16>>16)==(0);
  if ($10) {
   $11 = HEAP32[$2>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 28|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
   $s0$0 = $15;
  } else {
   $s0$0 = 0;
  }
 }
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $s1$0 = 0;
 } else {
  $19 = HEAP32[$17>>2]|0;
  $20 = (($19) + 52|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_vii[$21 & 4095]($1,$17);
  $22 = HEAP16[$1>>1]|0;
  $23 = $22 & 8;
  $24 = ($23<<16>>16)==(0);
  if ($24) {
   $25 = HEAP32[$16>>2]|0;
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + 28|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (FUNCTION_TABLE_ii[$28 & 4095]($25)|0);
   $s1$0 = $29;
  } else {
   $s1$0 = 0;
  }
 }
 $30 = HEAP32[$2>>2]|0;
 $31 = ($30|0)!=(0|0);
 $32 = ($s0$0|0)==(0|0);
 $or$cond = $31 & $32;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP32[$16>>2]|0;
 $34 = ($33|0)!=(0|0);
 $35 = ($s1$0|0)==(0|0);
 $or$cond1 = $34 & $35;
 if ($or$cond1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = ($s0$0|0)!=(0|0);
 $37 = $36 ? $s0$0 : $s1$0;
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx12NpConstraint10getNpSceneEv($this) {
 $this = $this|0;
 var $$off$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i = (($2) + -1)|0;
 $3 = ($$off$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $8 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $8 = $7;
  }
 } else {
  $8 = 0;
 }
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx12NpConstraintC2EPNS_12PxRigidActorES2_RNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableEj($this,$actor0,$actor1,$connector,$shaders,$dataSize) {
 $this = $this|0;
 $actor0 = $actor0|0;
 $actor1 = $actor1|0;
 $connector = $connector|0;
 $shaders = $shaders|0;
 $dataSize = $dataSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond1$i = 0, $s0$0$i = 0, $s1$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 HEAP16[$2>>1] = 9;
 $3 = (($this) + 6|0);
 HEAP16[$3>>1] = 1;
 HEAP32[$this>>2] = ((420256 + 8|0));
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = $actor0;
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = $actor1;
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 24|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 20|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 28|0);
 __ZN5physx2Sc14ConstraintCoreC2ERNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableEj($9,$connector,$shaders,$dataSize);
 $10 = (($this) + 96|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;HEAP16[$10+24>>1]=0|0;
 $11 = HEAP32[$8>>2]|0;
 $12 = $11 & -251658241;
 $13 = $12 | 100663296;
 HEAP32[$8>>2] = $13;
 $14 = (($this) + 124|0);
 HEAP8[$14>>0] = 1;
 $15 = ($actor0|0)==(0|0);
 if (!($15)) {
  $16 = (($actor0) + 4|0);
  $17 = HEAP16[$16>>1]|0;
  $18 = $17&65535;
  $19 = (414264 + ($18<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($actor0) + ($20)|0);
  __ZN5physx7NpActor12addConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($21,0,$this,420192);
 }
 $22 = ($actor1|0)==(0|0);
 if (!($22)) {
  $23 = (($actor1) + 4|0);
  $24 = HEAP16[$23>>1]|0;
  $25 = $24&65535;
  $26 = (414264 + ($25<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($actor1) + ($27)|0);
  __ZN5physx7NpActor12addConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($28,0,$this,420344);
 }
 $29 = HEAP32[$4>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  $s0$0$i = 0;
 } else {
  $31 = HEAP32[$29>>2]|0;
  $32 = (($31) + 52|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_vii[$33 & 4095]($0,$29);
  $34 = HEAP16[$0>>1]|0;
  $35 = $34 & 8;
  $36 = ($35<<16>>16)==(0);
  if ($36) {
   $37 = HEAP32[$4>>2]|0;
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + 28|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (FUNCTION_TABLE_ii[$40 & 4095]($37)|0);
   $s0$0$i = $41;
  } else {
   $s0$0$i = 0;
  }
 }
 $42 = HEAP32[$5>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $s1$0$i = 0;
 } else {
  $44 = HEAP32[$42>>2]|0;
  $45 = (($44) + 52|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 4095]($1,$42);
  $47 = HEAP16[$1>>1]|0;
  $48 = $47 & 8;
  $49 = ($48<<16>>16)==(0);
  if ($49) {
   $50 = HEAP32[$5>>2]|0;
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + 28|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (FUNCTION_TABLE_ii[$53 & 4095]($50)|0);
   $s1$0$i = $54;
  } else {
   $s1$0$i = 0;
  }
 }
 $55 = HEAP32[$4>>2]|0;
 $56 = ($55|0)!=(0|0);
 $57 = ($s0$0$i|0)==(0|0);
 $or$cond$i = $56 & $57;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 }
 $58 = HEAP32[$5>>2]|0;
 $59 = ($58|0)!=(0|0);
 $60 = ($s1$0$i|0)==(0|0);
 $or$cond1$i = $59 & $60;
 if ($or$cond1$i) {
  STACKTOP = sp;return;
 }
 $61 = ($s0$0$i|0)!=(0|0);
 $62 = $61 ? $s0$0$i : $s1$0$i;
 $63 = ($62|0)==(0|0);
 if ($63) {
  STACKTOP = sp;return;
 }
 $64 = (($62) + 3524|0);
 HEAP32[$0>>2] = $this;
 $65 = (($62) + 3532|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 & 2147483647;
 $68 = (($62) + 3528|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($67>>>0)>($69>>>0);
 if ($70) {
  $71 = HEAP32[$64>>2]|0;
  $72 = (($71) + ($69<<2)|0);
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   HEAP32[$72>>2] = $this;
  }
  $74 = (($69) + 1)|0;
  HEAP32[$68>>2] = $74;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_12PxConstraintENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($64,$0)|0);
 }
 $75 = (($62) + 16|0);
 __ZN5physx3Scb5Scene13addConstraintERNS0_10ConstraintE($75,$6);
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraintD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((420256 + 8|0));
 $1 = (($this) + 6|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & 1;
 $4 = ($3<<16>>16)==(0);
 if (!($4)) {
  $5 = (($this) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 4095]($6);
 }
 $10 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory19onConstraintReleaseEPNS_12PxConstraintE($10,$this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraintD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((420256 + 8|0));
 $0 = (($this) + 6|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 1;
 $3 = ($2<<16>>16)==(0);
 if (!($3)) {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vi[$8 & 4095]($5);
 }
 $9 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory19onConstraintReleaseEPNS_12PxConstraintE($9,$this);
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint7releaseEv($this) {
 $this = $this|0;
 var $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $28 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $28 = $7;
  }
 } else {
  $28 = 0;
 }
 $8 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($8,$this,0,1);
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = (($10) + 4|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = (414264 + ($14<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($10) + ($16)|0);
  __ZN5physx7NpActor15removeConnectorERNS_7PxActorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($17,$10,0,$this,420192);
 }
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = (($19) + 4|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22&65535;
  $24 = (414264 + ($23<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($19) + ($25)|0);
  __ZN5physx7NpActor15removeConnectorERNS_7PxActorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($26,$19,0,$this,420344);
 }
 $27 = ($28|0)==(0|0);
 if ($27) {
  $46 = (($this) + 16|0);
  __ZN5physx3Scb4Base7destroyEv($46);
  STACKTOP = sp;return;
 }
 $29 = (($28) + 3528|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if (!($31)) {
  $32 = (($28) + 3524|0);
  $33 = HEAP32[$32>>2]|0;
  $index$01$i$i = 0;
  while(1) {
   $36 = (($33) + ($index$01$i$i<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==($this|0);
   $35 = (($index$01$i$i) + 1)|0;
   if ($38) {
    $index$0$lcssa$i$i = $index$01$i$i;
    break;
   }
   $34 = ($35>>>0)<($30>>>0);
   if ($34) {
    $index$01$i$i = $35;
   } else {
    $index$0$lcssa$i$i = $35;
    break;
   }
  }
  $39 = ($index$0$lcssa$i$i|0)==($30|0);
  if (!($39)) {
   $40 = (($30) + -1)|0;
   HEAP32[$29>>2] = $40;
   $41 = (($33) + ($40<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($33) + ($index$0$lcssa$i$i<<2)|0);
   HEAP32[$43>>2] = $42;
  }
 }
 $44 = (($28) + 16|0);
 $45 = (($this) + 16|0);
 __ZN5physx3Scb5Scene16removeConstraintERNS0_10ConstraintE($44,$45);
 $46 = (($this) + 16|0);
 __ZN5physx3Scb4Base7destroyEv($46);
 STACKTOP = sp;return;
}
function __Z17NpGetPxConstraintRN5physx2Sc14ConstraintCoreE($constraint) {
 $constraint = $constraint|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($constraint) + -28|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx12NpConstraint8getSceneEv($this) {
 $this = $this|0;
 var $$off$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 $$off$i$i = (($2) + -1)|0;
 $3 = ($$off$i$i>>>0)<(2);
 if ($3) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $8 = 0;
  } else {
   $7 = (__ZN5physx3Scb5Scene10getPxSceneEv($5)|0);
   $8 = $7;
  }
 } else {
  $8 = 0;
 }
 STACKTOP = sp;return ($8|0);
}
function __ZNK5physx12NpConstraint9getActorsERPNS_12PxRigidActorES3_($this,$actor0,$actor1) {
 $this = $this|0;
 $actor0 = $actor0|0;
 $actor1 = $actor1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$actor0>>2] = $1;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$actor1>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint9setActorsEPNS_12PxRigidActorES2_($this,$actor0,$actor1) {
 $this = $this|0;
 $actor0 = $actor0|0;
 $actor1 = $actor1|0;
 var $$0$i = 0, $$0$i1 = 0, $$0$i2 = 0, $$off$i$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, $or$cond$i = 0, $or$cond1$i = 0, $s0$0$i = 0, $s1$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 4|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = $6&65535;
  $8 = (414264 + ($7<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($3) + ($9)|0);
  __ZN5physx7NpActor15removeConnectorERNS_7PxActorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($10,$3,0,$this,420192);
 }
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = (($12) + 4|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = $15&65535;
  $17 = (414264 + ($16<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($12) + ($18)|0);
  __ZN5physx7NpActor15removeConnectorERNS_7PxActorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($19,$12,0,$this,420344);
 }
 $20 = ($actor0|0)==(0|0);
 if (!($20)) {
  $21 = (($actor0) + 4|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22&65535;
  $24 = (414264 + ($23<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($actor0) + ($25)|0);
  __ZN5physx7NpActor12addConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($26,0,$this,420192);
 }
 $27 = ($actor1|0)==(0|0);
 if (!($27)) {
  $28 = (($actor1) + 4|0);
  $29 = HEAP16[$28>>1]|0;
  $30 = $29&65535;
  $31 = (414264 + ($30<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($actor1) + ($32)|0);
  __ZN5physx7NpActor12addConnectorENS_15NpConnectorType4EnumEPNS_6PxBaseEPKc($33,0,$this,420344);
 }
 HEAP32[$2>>2] = $actor0;
 HEAP32[$11>>2] = $actor1;
 $34 = (($this) + 16|0);
 do {
  if ($20) {
   $$0$i1 = 0;
  } else {
   $35 = (($actor0) + 4|0);
   $36 = HEAP16[$35>>1]|0;
   if ((($36<<16>>16) == 15)) {
    $38 = (($actor0) + 48|0);
    $$0$i1 = $38;
    break;
   } else if ((($36<<16>>16) == 5)) {
    $37 = (($actor0) + 48|0);
    $$0$i1 = $37;
    break;
   } else {
    $39 = (($actor0) + 48|0);
    $$0$i1 = $39;
    break;
   }
  }
 } while(0);
 do {
  if ($27) {
   $$0$i2 = 0;
  } else {
   $40 = (($actor1) + 4|0);
   $41 = HEAP16[$40>>1]|0;
   if ((($41<<16>>16) == 15)) {
    $43 = (($actor1) + 48|0);
    $$0$i2 = $43;
    break;
   } else if ((($41<<16>>16) == 5)) {
    $42 = (($actor1) + 48|0);
    $$0$i2 = $42;
    break;
   } else {
    $44 = (($actor1) + 48|0);
    $$0$i2 = $44;
    break;
   }
  }
 } while(0);
 $45 = ($$0$i1|0)==(0|0);
 if ($45) {
  $73 = 0;
 } else {
  $46 = $$0$i1;
  $47 = (($$0$i1) + 4|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = $48 >>> 24;
  $50 = $49 & 15;
  $51 = ((444424 + ($50<<2)|0) + 24|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + ($46))|0;
  $54 = $53;
  $73 = $54;
 }
 $55 = ($$0$i2|0)==(0|0);
 if ($55) {
  $74 = 0;
 } else {
  $56 = $$0$i2;
  $57 = (($$0$i2) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = $58 >>> 24;
  $60 = $59 & 15;
  $61 = ((444424 + ($60<<2)|0) + 24|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + ($56))|0;
  $64 = $63;
  $74 = $64;
 }
 $65 = (($this) + 20|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 >>> 30;
 if ((($67|0) == 2)) {
  $68 = HEAP32[$34>>2]|0;
  $69 = (($68) + 2417|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = ($70<<24>>24)==(0);
  if ($71) {
   label = 26;
  } else {
   $$pre$phiZ2D = $34;
   label = 27;
  }
 } else if ((($67|0) == 3)) {
  $$pre$phiZ2D = $34;
  label = 27;
 } else {
  label = 26;
 }
 if ((label|0) == 26) {
  $72 = (($this) + 28|0);
  __ZN5physx2Sc14ConstraintCore9setBodiesEPNS0_9RigidCoreES3_($72,$73,$74);
 }
 else if ((label|0) == 27) {
  $75 = (($this) + 24|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0|0);
  if ($77) {
   $78 = HEAP32[$$pre$phiZ2D>>2]|0;
   $79 = $66 >>> 24;
   $80 = $79 & 15;
   $81 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($78,$80)|0);
   HEAP32[$75>>2] = $81;
   $82 = $81;
  } else {
   $82 = $76;
  }
  HEAP32[$82>>2] = $73;
  $83 = (($82) + 4|0);
  HEAP32[$83>>2] = $74;
  $84 = HEAP32[$$pre$phiZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($84,$34);
  $85 = HEAP32[$65>>2]|0;
  $86 = $85 | 1;
  HEAP32[$65>>2] = $86;
 }
 $87 = (($this) + 96|0);
 ;HEAP32[$87+0>>2]=0|0;HEAP32[$87+4>>2]=0|0;HEAP32[$87+8>>2]=0|0;HEAP32[$87+12>>2]=0|0;HEAP32[$87+16>>2]=0|0;HEAP32[$87+20>>2]=0|0;
 $88 = HEAP32[$2>>2]|0;
 $89 = ($88|0)==(0|0);
 if ($89) {
  $s0$0$i = 0;
 } else {
  $90 = HEAP32[$88>>2]|0;
  $91 = (($90) + 52|0);
  $92 = HEAP32[$91>>2]|0;
  FUNCTION_TABLE_vii[$92 & 4095]($0,$88);
  $93 = HEAP16[$0>>1]|0;
  $94 = $93 & 8;
  $95 = ($94<<16>>16)==(0);
  if ($95) {
   $96 = HEAP32[$2>>2]|0;
   $97 = HEAP32[$96>>2]|0;
   $98 = (($97) + 28|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (FUNCTION_TABLE_ii[$99 & 4095]($96)|0);
   $s0$0$i = $100;
  } else {
   $s0$0$i = 0;
  }
 }
 $101 = HEAP32[$11>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  $s1$0$i = 0;
 } else {
  $103 = HEAP32[$101>>2]|0;
  $104 = (($103) + 52|0);
  $105 = HEAP32[$104>>2]|0;
  FUNCTION_TABLE_vii[$105 & 4095]($1,$101);
  $106 = HEAP16[$1>>1]|0;
  $107 = $106 & 8;
  $108 = ($107<<16>>16)==(0);
  if ($108) {
   $109 = HEAP32[$11>>2]|0;
   $110 = HEAP32[$109>>2]|0;
   $111 = (($110) + 28|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = (FUNCTION_TABLE_ii[$112 & 4095]($109)|0);
   $s1$0$i = $113;
  } else {
   $s1$0$i = 0;
  }
 }
 $114 = HEAP32[$2>>2]|0;
 $115 = ($114|0)!=(0|0);
 $116 = ($s0$0$i|0)==(0|0);
 $or$cond$i = $115 & $116;
 if ($or$cond$i) {
  $$0$i = 0;
 } else {
  $117 = HEAP32[$11>>2]|0;
  $118 = ($117|0)!=(0|0);
  $119 = ($s1$0$i|0)==(0|0);
  $or$cond1$i = $118 & $119;
  if ($or$cond1$i) {
   $$0$i = 0;
  } else {
   $120 = ($s0$0$i|0)!=(0|0);
   $121 = $120 ? $s0$0$i : $s1$0$i;
   $$0$i = $121;
  }
 }
 $122 = HEAP32[$65>>2]|0;
 $123 = $122 >>> 30;
 $$off$i$i = (($123) + -1)|0;
 $124 = ($$off$i$i>>>0)<(2);
 if ($124) {
  $125 = (($this) + 16|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ($126|0)==(0|0);
  if ($127) {
   $130 = 0;
  } else {
   $128 = (__ZN5physx3Scb5Scene10getPxSceneEv($126)|0);
   $130 = $128;
  }
 } else {
  $130 = 0;
 }
 $129 = ($130|0)==($$0$i|0);
 if ($129) {
  STACKTOP = sp;return;
 }
 $131 = ($130|0)==(0|0);
 if (!($131)) {
  $132 = (($130) + 3528|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(0);
  if (!($134)) {
   $135 = (($130) + 3524|0);
   $136 = HEAP32[$135>>2]|0;
   $index$01$i$i = 0;
   while(1) {
    $139 = (($136) + ($index$01$i$i<<2)|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = ($140|0)==($this|0);
    $138 = (($index$01$i$i) + 1)|0;
    if ($141) {
     $index$0$lcssa$i$i = $index$01$i$i;
     break;
    }
    $137 = ($138>>>0)<($133>>>0);
    if ($137) {
     $index$01$i$i = $138;
    } else {
     $index$0$lcssa$i$i = $138;
     break;
    }
   }
   $142 = ($index$0$lcssa$i$i|0)==($133|0);
   if (!($142)) {
    $143 = (($133) + -1)|0;
    HEAP32[$132>>2] = $143;
    $144 = (($136) + ($143<<2)|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = (($136) + ($index$0$lcssa$i$i<<2)|0);
    HEAP32[$146>>2] = $145;
   }
  }
  $147 = (($130) + 16|0);
  __ZN5physx3Scb5Scene16removeConstraintERNS0_10ConstraintE($147,$34);
 }
 $148 = ($$0$i|0)==(0|0);
 if ($148) {
  STACKTOP = sp;return;
 }
 $149 = (($$0$i) + 3524|0);
 HEAP32[$0>>2] = $this;
 $150 = (($$0$i) + 3532|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = $151 & 2147483647;
 $153 = (($$0$i) + 3528|0);
 $154 = HEAP32[$153>>2]|0;
 $155 = ($152>>>0)>($154>>>0);
 if ($155) {
  $156 = HEAP32[$149>>2]|0;
  $157 = (($156) + ($154<<2)|0);
  $158 = ($157|0)==(0|0);
  if (!($158)) {
   HEAP32[$157>>2] = $this;
  }
  $159 = (($154) + 1)|0;
  HEAP32[$153>>2] = $159;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_12PxConstraintENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($149,$0)|0);
 }
 $160 = (($$0$i) + 16|0);
 __ZN5physx3Scb5Scene13addConstraintERNS0_10ConstraintE($160,$34);
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint9markDirtyEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint8setFlagsENS_7PxFlagsINS_16PxConstraintFlag4EnumEtEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP16[$flags>>1]|0;
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 >>> 30;
 if ((($5|0) == 3)) {
  $$pre$phiZ2D = $1;
 } else if ((($5|0) == 2)) {
  $6 = HEAP32[$1>>2]|0;
  $7 = (($6) + 2417|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   label = 4;
  } else {
   $$pre$phiZ2D = $1;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $10 = (($this) + 28|0);
  HEAP16[$0>>1] = $2;
  __ZN5physx2Sc14ConstraintCore8setFlagsENS_7PxFlagsINS_16PxConstraintFlag4EnumEtEE($10,$0);
  STACKTOP = sp;return;
 }
 $11 = (($this) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $14 = HEAP32[$$pre$phiZ2D>>2]|0;
  $15 = $4 >>> 24;
  $16 = $15 & 15;
  $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
  HEAP32[$11>>2] = $17;
  $19 = $17;
 } else {
  $19 = $12;
 }
 $18 = (($19) + 16|0);
 HEAP16[$18>>1] = $2;
 $20 = HEAP32[$$pre$phiZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($20,$1);
 $21 = HEAP32[$3>>2]|0;
 $22 = $21 | 4;
 HEAP32[$3>>2] = $22;
 STACKTOP = sp;return;
}
function __ZNK5physx12NpConstraint8getFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 if ($3) {
  $19 = (($this) + 28|0);
  $20 = HEAP16[$19>>1]|0;
  $21 = (($this) + 120|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22 | -2;
  $24 = $23 & $20;
  HEAP16[$agg$result>>1] = $24;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 16|0);
 $14 = (($this) + 120|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15 | -2;
 $17 = HEAP16[$12>>1]|0;
 $18 = $16 & $17;
 HEAP16[$agg$result>>1] = $18;
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint7setFlagENS_16PxConstraintFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if ($5) {
  $20 = (($this) + 28|0);
  $21 = HEAP16[$20>>1]|0;
  $22 = (($this) + 120|0);
  $23 = HEAP16[$22>>1]|0;
  $24 = $23 | -2;
  $25 = $24 & $21;
  $27 = $25;
 } else {
  $6 = (($this) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $9 = HEAP32[$1>>2]|0;
   $10 = $3 >>> 24;
   $11 = $10 & 15;
   $12 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($9,$11)|0);
   HEAP32[$6>>2] = $12;
   $14 = $12;
  } else {
   $14 = $7;
  }
  $13 = (($14) + 16|0);
  $15 = (($this) + 120|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = $16 | -2;
  $18 = HEAP16[$13>>1]|0;
  $19 = $17 & $18;
  $27 = $19;
 }
 if ($value) {
  $26 = $27&65535;
  $28 = $26 | $flag;
  $29 = $28&65535;
  $40 = $29;
 } else {
  $30 = $flag ^ 65535;
  $31 = $30&65535;
  $32 = $27 & $31;
  $40 = $32;
 }
 $33 = HEAP32[$2>>2]|0;
 $34 = $33 >>> 30;
 if ((($34|0) == 3)) {
  $$pre$phiZ2D = $1;
 } else if ((($34|0) == 2)) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (($35) + 2417|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($37<<24>>24)==(0);
  if ($38) {
   label = 12;
  } else {
   $$pre$phiZ2D = $1;
  }
 } else {
  label = 12;
 }
 if ((label|0) == 12) {
  $39 = (($this) + 28|0);
  HEAP16[$0>>1] = $40;
  __ZN5physx2Sc14ConstraintCore8setFlagsENS_7PxFlagsINS_16PxConstraintFlag4EnumEtEE($39,$0);
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $44 = HEAP32[$$pre$phiZ2D>>2]|0;
  $45 = $33 >>> 24;
  $46 = $45 & 15;
  $47 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($44,$46)|0);
  HEAP32[$41>>2] = $47;
  $49 = $47;
 } else {
  $49 = $42;
 }
 $48 = (($49) + 16|0);
 HEAP16[$48>>1] = $40;
 $50 = HEAP32[$$pre$phiZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($50,$1);
 $51 = HEAP32[$2>>2]|0;
 $52 = $51 | 4;
 HEAP32[$2>>2] = $52;
 STACKTOP = sp;return;
}
function __ZNK5physx12NpConstraint8getForceERNS_6PxVec3ES2_($this,$linear,$angular) {
 $this = $this|0;
 $linear = $linear|0;
 $angular = $angular|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$linear>>2] = $1;
 $2 = (($this) + 100|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($linear) + 4|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($this) + 104|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($linear) + 8|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($this) + 108|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$angular>>2] = $9;
 $10 = (($this) + 112|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($angular) + 4|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($this) + 116|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($angular) + 8|0);
 HEAPF32[$15>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint15updateConstantsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($4)|0);
 $8 = (($this) + 28|0);
 $9 = (__ZN5physx2Sc14ConstraintCore15updateConstantsEPv($8,$7)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint13setBreakForceEff($this,$linear,$angular) {
 $this = $this|0;
 $linear = Math_fround($linear);
 $angular = Math_fround($angular);
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 if ((($3|0) == 3)) {
  $$pre$phiZ2D = $0;
 } else if ((($3|0) == 2)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 4;
  } else {
   $$pre$phiZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $8 = (($this) + 28|0);
  __ZN5physx2Sc14ConstraintCore13setBreakForceEff($8,$linear,$angular);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phiZ2D>>2]|0;
  $13 = $2 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 8|0);
 HEAPF32[$16>>2] = $linear;
 $18 = (($17) + 12|0);
 HEAPF32[$18>>2] = $angular;
 $19 = HEAP32[$$pre$phiZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($19,$0);
 $20 = HEAP32[$1>>2]|0;
 $21 = $20 | 2;
 HEAP32[$1>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx12NpConstraint13getBreakForceERfS1_($this,$linear,$angular) {
 $this = $this|0;
 $linear = $linear|0;
 $angular = $angular|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 28|0);
  __ZNK5physx2Sc14ConstraintCore13getBreakForceERfS2_($17,$linear,$angular);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 8|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$linear>>2] = $14;
 $15 = (($13) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$angular>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint20getExternalReferenceERj($this,$typeID) {
 $this = $this|0;
 $typeID = $typeID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$4 & 4095]($1,$typeID)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx12NpConstraint8comShiftEPNS_12PxRigidActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($actor|0);
 if ($4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = (($5) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 4095]($1,0);
 }
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($actor|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$1>>2]|0;
 $12 = (($11) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$13 & 4095]($1,1);
 STACKTOP = sp;return;
}
function __ZN5physx12NpConstraint12actorDeletedEPNS_12PxRigidActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($actor|0);
 if ($2) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $3 = (($this) + 12|0);
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx34NpConstraintGetRigidObjectsFromScbERKNS_3Scb10ConstraintERPNS0_11RigidObjectES6_($c,$b0,$b1) {
 $c = $c|0;
 $b0 = $b0|0;
 $b1 = $b1|0;
 var $$0$i = 0, $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $a0 = 0, $a1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $a0 = sp + 4|0;
 $a1 = sp;
 $0 = (($c) + -16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($0,$a0,$a1);
 $4 = HEAP32[$a0>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $$0$i1 = 0;
  } else {
   $6 = (($4) + 4|0);
   $7 = HEAP16[$6>>1]|0;
   if ((($7<<16>>16) == 5)) {
    $8 = (($4) + 48|0);
    $$0$i1 = $8;
    break;
   } else if ((($7<<16>>16) == 15)) {
    $9 = (($4) + 48|0);
    $$0$i1 = $9;
    break;
   } else {
    $10 = (($4) + 48|0);
    $$0$i1 = $10;
    break;
   }
  }
 } while(0);
 HEAP32[$b0>>2] = $$0$i1;
 $11 = HEAP32[$a1>>2]|0;
 $12 = ($11|0)==(0|0);
 do {
  if ($12) {
   $$0$i = 0;
  } else {
   $13 = (($11) + 4|0);
   $14 = HEAP16[$13>>1]|0;
   if ((($14<<16>>16) == 15)) {
    $16 = (($11) + 48|0);
    $$0$i = $16;
    break;
   } else if ((($14<<16>>16) == 5)) {
    $15 = (($11) + 48|0);
    $$0$i = $15;
    break;
   } else {
    $17 = (($11) + 48|0);
    $$0$i = $17;
    break;
   }
  }
 } while(0);
 HEAP32[$b1>>2] = $$0$i;
 STACKTOP = sp;return;
}
function __ZNK5physx12PxConstraint19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (420408|0);
}
function __ZNK5physx12PxConstraint8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(420408,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,420424)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx12NpConstraint8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx12NpConstraint13isSubordinateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx9NpFactoryC2Ev($this) {
 $this = $this|0;
 var $$$i$i$i$i = 0, $$$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((546808 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$0>>2] = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i$i$i$i = $12 ? 422976 : 421040;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i$i$i$i,422896,111)|0);
  HEAP32[$0>>2] = $13;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($13);
  }
 }
 $15 = (($this) + 8|0);
 dest=$15+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$this>>2] = ((420432 + 8|0));
 $16 = (($this) + 60|0);
 $17 = (($this) + 316|0);
 $18 = (($this) + 320|0);
 $19 = (($this) + 324|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 328|0);
 HEAP8[$17>>0] = 1;
 HEAP32[$18>>2] = $16;
 HEAP32[$20>>2] = 64;
 $21 = (($this) + 332|0);
 HEAP32[$21>>2] = 32;
 $22 = (($this) + 336|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 340|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 344|0);
 HEAP32[$24>>2] = 1536;
 $25 = (($this) + 348|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 352|0);
 $27 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0);
 if ($29) {
  HEAP32[$26>>2] = 0;
 } else {
  $30 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (__Z15PxGetFoundationv()|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + 24|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (FUNCTION_TABLE_ii[$37 & 4095]($34)|0);
  $$$i$i$i$i = $38 ? 422976 : 421040;
  $39 = (FUNCTION_TABLE_iiiiii[$33 & 255]($30,$28,$$$i$i$i$i,422896,111)|0);
  HEAP32[$26>>2] = $39;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($39);
  }
 }
 $41 = (($this) + 356|0);
 $42 = (($this) + 380|0);
 ;HEAP32[$41+0>>2]=0|0;HEAP32[$41+4>>2]=0|0;HEAP32[$41+8>>2]=0|0;HEAP32[$41+12>>2]=0|0;HEAP32[$41+16>>2]=0|0;HEAP32[$41+20>>2]=0|0;
 HEAPF32[$42>>2] = Math_fround(0.75);
 $43 = (($this) + 384|0);
 HEAP32[$43>>2] = -1;
 $44 = (($this) + 388|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 392|0);
 HEAP32[$45>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_11PxAggregateES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($41,64);
 $46 = (($this) + 396|0);
 $47 = (($this) + 420|0);
 ;HEAP32[$46+0>>2]=0|0;HEAP32[$46+4>>2]=0|0;HEAP32[$46+8>>2]=0|0;HEAP32[$46+12>>2]=0|0;HEAP32[$46+16>>2]=0|0;HEAP32[$46+20>>2]=0|0;
 HEAPF32[$47>>2] = Math_fround(0.75);
 $48 = (($this) + 424|0);
 HEAP32[$48>>2] = -1;
 $49 = (($this) + 428|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 432|0);
 HEAP32[$50>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_14PxArticulationES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($46,64);
 $51 = (($this) + 436|0);
 $52 = (($this) + 460|0);
 ;HEAP32[$51+0>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;HEAP32[$51+12>>2]=0|0;HEAP32[$51+16>>2]=0|0;HEAP32[$51+20>>2]=0|0;
 HEAPF32[$52>>2] = Math_fround(0.75);
 $53 = (($this) + 464|0);
 HEAP32[$53>>2] = -1;
 $54 = (($this) + 468|0);
 HEAP32[$54>>2] = 0;
 $55 = (($this) + 472|0);
 HEAP32[$55>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_12PxConstraintES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($51,64);
 $56 = (($this) + 476|0);
 $57 = (($this) + 500|0);
 ;HEAP32[$56+0>>2]=0|0;HEAP32[$56+4>>2]=0|0;HEAP32[$56+8>>2]=0|0;HEAP32[$56+12>>2]=0|0;HEAP32[$56+16>>2]=0|0;HEAP32[$56+20>>2]=0|0;
 HEAPF32[$57>>2] = Math_fround(0.75);
 $58 = (($this) + 504|0);
 HEAP32[$58>>2] = -1;
 $59 = (($this) + 508|0);
 HEAP32[$59>>2] = 0;
 $60 = (($this) + 512|0);
 HEAP32[$60>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($56,64);
 $61 = (($this) + 516|0);
 $62 = (($this) + 540|0);
 ;HEAP32[$61+0>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;HEAP32[$61+12>>2]=0|0;HEAP32[$61+16>>2]=0|0;HEAP32[$61+20>>2]=0|0;
 HEAPF32[$62>>2] = Math_fround(0.75);
 $63 = (($this) + 544|0);
 HEAP32[$63>>2] = -1;
 $64 = (($this) + 548|0);
 HEAP32[$64>>2] = 0;
 $65 = (($this) + 552|0);
 HEAP32[$65>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_10PxMaterialES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($61,64);
 $66 = (($this) + 556|0);
 $67 = (($this) + 580|0);
 ;HEAP32[$66+0>>2]=0|0;HEAP32[$66+4>>2]=0|0;HEAP32[$66+8>>2]=0|0;HEAP32[$66+12>>2]=0|0;HEAP32[$66+16>>2]=0|0;HEAP32[$66+20>>2]=0|0;
 HEAPF32[$67>>2] = Math_fround(0.75);
 $68 = (($this) + 584|0);
 HEAP32[$68>>2] = -1;
 $69 = (($this) + 588|0);
 HEAP32[$69>>2] = 0;
 $70 = (($this) + 592|0);
 HEAP32[$70>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb1EE6GetKeyES8_Lb1EE15reserveInternalEj($66,64);
 $71 = (($this) + 596|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 600|0);
 HEAP32[$72>>2] = 0;
 $73 = (($this) + 604|0);
 HEAP32[$73>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactoryD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx9NpFactoryD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactoryD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((420432 + 8|0));
 $0 = (($this) + 604|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 596|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 556|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($12,$13);
 }
 $15 = (($this) + 516|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($15,$16);
 }
 $18 = (($this) + 476|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($18,$19);
 }
 $21 = (($this) + 436|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($21,$22);
 }
 $24 = (($this) + 396|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($24,$25);
 }
 $27 = (($this) + 356|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($27,$28);
 }
 $30 = (($this) + 352|0);
 $31 = HEAP32[$30>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($31);
 $32 = HEAP32[$30>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $38 = (($this) + 56|0);
  __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEED2Ev($38);
  __ZN5physx13GuMeshFactoryD2Ev($this);
  STACKTOP = sp;return;
 }
 $34 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($34,$32);
 $38 = (($this) + 56|0);
 __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEED2Ev($38);
 __ZN5physx13GuMeshFactoryD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory7releaseEv($this) {
 $this = $this|0;
 var $$ph2$i = 0, $$ph2$i17 = 0, $$ph2$i30 = 0, $$ph2$i4 = 0, $$ph3$i = 0, $$ph3$i18 = 0, $$ph3$i31 = 0, $$ph3$i5 = 0, $$ph4$i = 0, $$ph4$i19 = 0, $$ph4$i32 = 0, $$ph4$i6 = 0, $$ph5$i = 0, $$ph5$i20 = 0, $$ph5$i33 = 0, $$ph5$i7 = 0, $$pre$i = 0, $$pre$i15 = 0, $$pre$i2 = 0, $$pre$i28 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0;
 var $exitcond41 = 0, $exitcond42 = 0, $exitcond43 = 0, $i$01$i = 0, $i$01$i11 = 0, $i$01$i24 = 0, $i$01$i37 = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i12 = 0, $or$cond$i$i$i25 = 0, $or$cond$i$i$i38 = 0, $tmp$i27 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmp$i27 = sp + 4|0;
 $0 = sp;
 HEAP32[$tmp$i27>>2] = 0;
 $1 = (($tmp$i27) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($tmp$i27) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 392|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  __ZN5physx6shdfnd5ArrayIPNS_11PxAggregateENS0_19ReflectionAllocatorIS3_EEE8recreateEj($tmp$i27,$4);
 }
 $6 = (($this) + 372|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $$pre$i = (($this) + 368|0);
 L4: do {
  if ($8) {
   $$ph2$i = -1;$$ph3$i = 0;
  } else {
   $9 = HEAP32[$$pre$i>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(-1);
   if ($11) {
    $12 = (($this) + 376|0);
    $13 = HEAP32[$12>>2]|0;
    $15 = 0;
    while(1) {
     $14 = (($15) + 1)|0;
     $16 = ($14|0)==($13|0);
     if ($16) {
      $$ph2$i = -1;$$ph3$i = $13;
      break L4;
     }
     $17 = (($9) + ($14<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(-1);
     if ($19) {
      $15 = $14;
     } else {
      $$ph2$i = $18;$$ph3$i = $14;
      break;
     }
    }
   } else {
    $$ph2$i = $10;$$ph3$i = 0;
   }
  }
 } while(0);
 $20 = (($this) + 360|0);
 $21 = (($this) + 364|0);
 $22 = (($this) + 376|0);
 $$ph4$i = $$ph2$i;$$ph5$i = $$ph3$i;
 L11: while(1) {
  $24 = $$ph4$i;
  while(1) {
   $23 = ($24|0)==(-1);
   if ($23) {
    break L11;
   }
   $28 = HEAP32[$20>>2]|0;
   $29 = (($28) + ($24<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$0>>2] = $30;
   $31 = HEAP32[$2>>2]|0;
   $32 = $31 & 2147483647;
   $33 = HEAP32[$1>>2]|0;
   $34 = ($32>>>0)>($33>>>0);
   if ($34) {
    $35 = HEAP32[$tmp$i27>>2]|0;
    $36 = (($35) + ($33<<2)|0);
    $37 = ($36|0)==(0|0);
    if (!($37)) {
     HEAP32[$36>>2] = $30;
    }
    $38 = (($33) + 1)|0;
    HEAP32[$1>>2] = $38;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_11PxAggregateENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($tmp$i27,$0)|0);
   }
   $39 = HEAP32[$21>>2]|0;
   $40 = (($39) + ($24<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(-1);
   if ($42) {
    break;
   } else {
    $24 = $41;
   }
  }
  $43 = HEAP32[$22>>2]|0;
  $45 = $$ph5$i;
  while(1) {
   $44 = (($45) + 1)|0;
   $46 = ($44|0)==($43|0);
   if ($46) {
    $$ph4$i = -1;$$ph5$i = $43;
    continue L11;
   }
   $47 = HEAP32[$$pre$i>>2]|0;
   $48 = (($47) + ($44<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==(-1);
   if ($50) {
    $45 = $44;
   } else {
    $$ph4$i = $49;$$ph5$i = $44;
    continue L11;
   }
  }
 }
 $25 = HEAP32[$1>>2]|0;
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = HEAP32[$tmp$i27>>2]|0;
  $i$01$i = 0;
  while(1) {
   $51 = (($27) + ($i$01$i<<2)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$53>>2]|0;
   FUNCTION_TABLE_vi[$54 & 4095]($52);
   $55 = (($i$01$i) + 1)|0;
   $exitcond43 = ($55|0)==($25|0);
   if ($exitcond43) {
    break;
   } else {
    $i$01$i = $55;
   }
  }
 }
 $56 = HEAP32[$2>>2]|0;
 $57 = $56 & 2147483647;
 $58 = ($57|0)!=(0);
 $59 = ($56|0)>(-1);
 $or$cond$i$i$i = $58 & $59;
 if ($or$cond$i$i$i) {
  $60 = HEAP32[$tmp$i27>>2]|0;
  $61 = ($60|0)==(0|0);
  if (!($61)) {
   $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($63) + 12|0);
   $65 = HEAP32[$64>>2]|0;
   FUNCTION_TABLE_vii[$65 & 4095]($62,$60);
  }
 }
 HEAP32[$tmp$i27>>2] = 0;
 $66 = (($tmp$i27) + 4|0);
 HEAP32[$66>>2] = 0;
 $67 = (($tmp$i27) + 8|0);
 HEAP32[$67>>2] = 0;
 $68 = (($this) + 472|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0);
 if (!($70)) {
  __ZN5physx6shdfnd5ArrayIPNS_12PxConstraintENS0_19ReflectionAllocatorIS3_EEE8recreateEj($tmp$i27,$69);
 }
 $71 = (($this) + 452|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0);
 $$pre$i2 = (($this) + 448|0);
 L40: do {
  if ($73) {
   $$ph2$i4 = -1;$$ph3$i5 = 0;
  } else {
   $74 = HEAP32[$$pre$i2>>2]|0;
   $75 = HEAP32[$74>>2]|0;
   $76 = ($75|0)==(-1);
   if ($76) {
    $77 = (($this) + 456|0);
    $78 = HEAP32[$77>>2]|0;
    $80 = 0;
    while(1) {
     $79 = (($80) + 1)|0;
     $81 = ($79|0)==($78|0);
     if ($81) {
      $$ph2$i4 = -1;$$ph3$i5 = $78;
      break L40;
     }
     $82 = (($74) + ($79<<2)|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==(-1);
     if ($84) {
      $80 = $79;
     } else {
      $$ph2$i4 = $83;$$ph3$i5 = $79;
      break;
     }
    }
   } else {
    $$ph2$i4 = $75;$$ph3$i5 = 0;
   }
  }
 } while(0);
 $85 = (($this) + 440|0);
 $86 = (($this) + 444|0);
 $87 = (($this) + 456|0);
 $$ph4$i6 = $$ph2$i4;$$ph5$i7 = $$ph3$i5;
 L47: while(1) {
  $89 = $$ph4$i6;
  while(1) {
   $88 = ($89|0)==(-1);
   if ($88) {
    break L47;
   }
   $93 = HEAP32[$85>>2]|0;
   $94 = (($93) + ($89<<2)|0);
   $95 = HEAP32[$94>>2]|0;
   HEAP32[$0>>2] = $95;
   $96 = HEAP32[$67>>2]|0;
   $97 = $96 & 2147483647;
   $98 = HEAP32[$66>>2]|0;
   $99 = ($97>>>0)>($98>>>0);
   if ($99) {
    $100 = HEAP32[$tmp$i27>>2]|0;
    $101 = (($100) + ($98<<2)|0);
    $102 = ($101|0)==(0|0);
    if (!($102)) {
     HEAP32[$101>>2] = $95;
    }
    $103 = (($98) + 1)|0;
    HEAP32[$66>>2] = $103;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_12PxConstraintENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($tmp$i27,$0)|0);
   }
   $104 = HEAP32[$86>>2]|0;
   $105 = (($104) + ($89<<2)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($106|0)==(-1);
   if ($107) {
    break;
   } else {
    $89 = $106;
   }
  }
  $108 = HEAP32[$87>>2]|0;
  $110 = $$ph5$i7;
  while(1) {
   $109 = (($110) + 1)|0;
   $111 = ($109|0)==($108|0);
   if ($111) {
    $$ph4$i6 = -1;$$ph5$i7 = $108;
    continue L47;
   }
   $112 = HEAP32[$$pre$i2>>2]|0;
   $113 = (($112) + ($109<<2)|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==(-1);
   if ($115) {
    $110 = $109;
   } else {
    $$ph4$i6 = $114;$$ph5$i7 = $109;
    continue L47;
   }
  }
 }
 $90 = HEAP32[$66>>2]|0;
 $91 = ($90|0)==(0);
 if (!($91)) {
  $92 = HEAP32[$tmp$i27>>2]|0;
  $i$01$i11 = 0;
  while(1) {
   $116 = (($92) + ($i$01$i11<<2)|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = HEAP32[$117>>2]|0;
   $119 = HEAP32[$118>>2]|0;
   FUNCTION_TABLE_vi[$119 & 4095]($117);
   $120 = (($i$01$i11) + 1)|0;
   $exitcond42 = ($120|0)==($90|0);
   if ($exitcond42) {
    break;
   } else {
    $i$01$i11 = $120;
   }
  }
 }
 $121 = HEAP32[$67>>2]|0;
 $122 = $121 & 2147483647;
 $123 = ($122|0)!=(0);
 $124 = ($121|0)>(-1);
 $or$cond$i$i$i12 = $123 & $124;
 if ($or$cond$i$i$i12) {
  $125 = HEAP32[$tmp$i27>>2]|0;
  $126 = ($125|0)==(0|0);
  if (!($126)) {
   $127 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = (($128) + 12|0);
   $130 = HEAP32[$129>>2]|0;
   FUNCTION_TABLE_vii[$130 & 4095]($127,$125);
  }
 }
 HEAP32[$tmp$i27>>2] = 0;
 $131 = (($tmp$i27) + 4|0);
 HEAP32[$131>>2] = 0;
 $132 = (($tmp$i27) + 8|0);
 HEAP32[$132>>2] = 0;
 $133 = (($this) + 432|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = ($134|0)==(0);
 if (!($135)) {
  __ZN5physx6shdfnd5ArrayIPNS_14PxArticulationENS0_19ReflectionAllocatorIS3_EEE8recreateEj($tmp$i27,$134);
 }
 $136 = (($this) + 412|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($137|0)==(0);
 $$pre$i15 = (($this) + 408|0);
 L76: do {
  if ($138) {
   $$ph2$i17 = -1;$$ph3$i18 = 0;
  } else {
   $139 = HEAP32[$$pre$i15>>2]|0;
   $140 = HEAP32[$139>>2]|0;
   $141 = ($140|0)==(-1);
   if ($141) {
    $142 = (($this) + 416|0);
    $143 = HEAP32[$142>>2]|0;
    $145 = 0;
    while(1) {
     $144 = (($145) + 1)|0;
     $146 = ($144|0)==($143|0);
     if ($146) {
      $$ph2$i17 = -1;$$ph3$i18 = $143;
      break L76;
     }
     $147 = (($139) + ($144<<2)|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = ($148|0)==(-1);
     if ($149) {
      $145 = $144;
     } else {
      $$ph2$i17 = $148;$$ph3$i18 = $144;
      break;
     }
    }
   } else {
    $$ph2$i17 = $140;$$ph3$i18 = 0;
   }
  }
 } while(0);
 $150 = (($this) + 400|0);
 $151 = (($this) + 404|0);
 $152 = (($this) + 416|0);
 $$ph4$i19 = $$ph2$i17;$$ph5$i20 = $$ph3$i18;
 L83: while(1) {
  $154 = $$ph4$i19;
  while(1) {
   $153 = ($154|0)==(-1);
   if ($153) {
    break L83;
   }
   $158 = HEAP32[$150>>2]|0;
   $159 = (($158) + ($154<<2)|0);
   $160 = HEAP32[$159>>2]|0;
   HEAP32[$0>>2] = $160;
   $161 = HEAP32[$132>>2]|0;
   $162 = $161 & 2147483647;
   $163 = HEAP32[$131>>2]|0;
   $164 = ($162>>>0)>($163>>>0);
   if ($164) {
    $165 = HEAP32[$tmp$i27>>2]|0;
    $166 = (($165) + ($163<<2)|0);
    $167 = ($166|0)==(0|0);
    if (!($167)) {
     HEAP32[$166>>2] = $160;
    }
    $168 = (($163) + 1)|0;
    HEAP32[$131>>2] = $168;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_14PxArticulationENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($tmp$i27,$0)|0);
   }
   $169 = HEAP32[$151>>2]|0;
   $170 = (($169) + ($154<<2)|0);
   $171 = HEAP32[$170>>2]|0;
   $172 = ($171|0)==(-1);
   if ($172) {
    break;
   } else {
    $154 = $171;
   }
  }
  $173 = HEAP32[$152>>2]|0;
  $175 = $$ph5$i20;
  while(1) {
   $174 = (($175) + 1)|0;
   $176 = ($174|0)==($173|0);
   if ($176) {
    $$ph4$i19 = -1;$$ph5$i20 = $173;
    continue L83;
   }
   $177 = HEAP32[$$pre$i15>>2]|0;
   $178 = (($177) + ($174<<2)|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = ($179|0)==(-1);
   if ($180) {
    $175 = $174;
   } else {
    $$ph4$i19 = $179;$$ph5$i20 = $174;
    continue L83;
   }
  }
 }
 $155 = HEAP32[$131>>2]|0;
 $156 = ($155|0)==(0);
 if (!($156)) {
  $157 = HEAP32[$tmp$i27>>2]|0;
  $i$01$i24 = 0;
  while(1) {
   $181 = (($157) + ($i$01$i24<<2)|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = HEAP32[$182>>2]|0;
   $184 = HEAP32[$183>>2]|0;
   FUNCTION_TABLE_vi[$184 & 4095]($182);
   $185 = (($i$01$i24) + 1)|0;
   $exitcond41 = ($185|0)==($155|0);
   if ($exitcond41) {
    break;
   } else {
    $i$01$i24 = $185;
   }
  }
 }
 $186 = HEAP32[$132>>2]|0;
 $187 = $186 & 2147483647;
 $188 = ($187|0)!=(0);
 $189 = ($186|0)>(-1);
 $or$cond$i$i$i25 = $188 & $189;
 if ($or$cond$i$i$i25) {
  $190 = HEAP32[$tmp$i27>>2]|0;
  $191 = ($190|0)==(0|0);
  if (!($191)) {
   $192 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = (($193) + 12|0);
   $195 = HEAP32[$194>>2]|0;
   FUNCTION_TABLE_vii[$195 & 4095]($192,$190);
  }
 }
 HEAP32[$tmp$i27>>2] = 0;
 $196 = (($tmp$i27) + 4|0);
 HEAP32[$196>>2] = 0;
 $197 = (($tmp$i27) + 8|0);
 HEAP32[$197>>2] = 0;
 $198 = (($this) + 512|0);
 $199 = HEAP32[$198>>2]|0;
 $200 = ($199|0)==(0);
 if (!($200)) {
  __ZN5physx6shdfnd5ArrayIPNS_7PxActorENS0_19ReflectionAllocatorIS3_EEE8recreateEj($tmp$i27,$199);
 }
 $201 = (($this) + 492|0);
 $202 = HEAP32[$201>>2]|0;
 $203 = ($202|0)==(0);
 $$pre$i28 = (($this) + 488|0);
 L112: do {
  if ($203) {
   $$ph2$i30 = -1;$$ph3$i31 = 0;
  } else {
   $204 = HEAP32[$$pre$i28>>2]|0;
   $205 = HEAP32[$204>>2]|0;
   $206 = ($205|0)==(-1);
   if ($206) {
    $207 = (($this) + 496|0);
    $208 = HEAP32[$207>>2]|0;
    $210 = 0;
    while(1) {
     $209 = (($210) + 1)|0;
     $211 = ($209|0)==($208|0);
     if ($211) {
      $$ph2$i30 = -1;$$ph3$i31 = $208;
      break L112;
     }
     $212 = (($204) + ($209<<2)|0);
     $213 = HEAP32[$212>>2]|0;
     $214 = ($213|0)==(-1);
     if ($214) {
      $210 = $209;
     } else {
      $$ph2$i30 = $213;$$ph3$i31 = $209;
      break;
     }
    }
   } else {
    $$ph2$i30 = $205;$$ph3$i31 = 0;
   }
  }
 } while(0);
 $215 = (($this) + 480|0);
 $216 = (($this) + 484|0);
 $217 = (($this) + 496|0);
 $$ph4$i32 = $$ph2$i30;$$ph5$i33 = $$ph3$i31;
 L119: while(1) {
  $219 = $$ph4$i32;
  while(1) {
   $218 = ($219|0)==(-1);
   if ($218) {
    break L119;
   }
   $223 = HEAP32[$215>>2]|0;
   $224 = (($223) + ($219<<2)|0);
   $225 = HEAP32[$224>>2]|0;
   HEAP32[$0>>2] = $225;
   $226 = HEAP32[$197>>2]|0;
   $227 = $226 & 2147483647;
   $228 = HEAP32[$196>>2]|0;
   $229 = ($227>>>0)>($228>>>0);
   if ($229) {
    $230 = HEAP32[$tmp$i27>>2]|0;
    $231 = (($230) + ($228<<2)|0);
    $232 = ($231|0)==(0|0);
    if (!($232)) {
     HEAP32[$231>>2] = $225;
    }
    $233 = (($228) + 1)|0;
    HEAP32[$196>>2] = $233;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_7PxActorENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($tmp$i27,$0)|0);
   }
   $234 = HEAP32[$216>>2]|0;
   $235 = (($234) + ($219<<2)|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ($236|0)==(-1);
   if ($237) {
    break;
   } else {
    $219 = $236;
   }
  }
  $238 = HEAP32[$217>>2]|0;
  $240 = $$ph5$i33;
  while(1) {
   $239 = (($240) + 1)|0;
   $241 = ($239|0)==($238|0);
   if ($241) {
    $$ph4$i32 = -1;$$ph5$i33 = $238;
    continue L119;
   }
   $242 = HEAP32[$$pre$i28>>2]|0;
   $243 = (($242) + ($239<<2)|0);
   $244 = HEAP32[$243>>2]|0;
   $245 = ($244|0)==(-1);
   if ($245) {
    $240 = $239;
   } else {
    $$ph4$i32 = $244;$$ph5$i33 = $239;
    continue L119;
   }
  }
 }
 $220 = HEAP32[$196>>2]|0;
 $221 = ($220|0)==(0);
 if (!($221)) {
  $222 = HEAP32[$tmp$i27>>2]|0;
  $i$01$i37 = 0;
  while(1) {
   $246 = (($222) + ($i$01$i37<<2)|0);
   $247 = HEAP32[$246>>2]|0;
   $248 = HEAP32[$247>>2]|0;
   $249 = HEAP32[$248>>2]|0;
   FUNCTION_TABLE_vi[$249 & 4095]($247);
   $250 = (($i$01$i37) + 1)|0;
   $exitcond = ($250|0)==($220|0);
   if ($exitcond) {
    break;
   } else {
    $i$01$i37 = $250;
   }
  }
 }
 $251 = HEAP32[$197>>2]|0;
 $252 = $251 & 2147483647;
 $253 = ($252|0)!=(0);
 $254 = ($251|0)>(-1);
 $or$cond$i$i$i38 = $253 & $254;
 if ($or$cond$i$i$i38) {
  $255 = HEAP32[$tmp$i27>>2]|0;
  $256 = ($255|0)==(0|0);
  if (!($256)) {
   $257 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $258 = HEAP32[$257>>2]|0;
   $259 = (($258) + 12|0);
   $260 = HEAP32[$259>>2]|0;
   FUNCTION_TABLE_vii[$260 & 4095]($257,$255);
  }
 }
 $261 = (($this) + 592|0);
 $262 = HEAP32[$261>>2]|0;
 $263 = ($262|0)==(0);
 if (!($263)) {
  $264 = (($this) + 560|0);
  while(1) {
   $269 = HEAP32[$264>>2]|0;
   $270 = HEAP32[$269>>2]|0;
   __ZN5physx7NpShape15releaseInternalEv($270);
   $271 = HEAP32[$261>>2]|0;
   $272 = ($271|0)==(0);
   if ($272) {
    break;
   }
  }
 }
 $265 = (($this) + 600|0);
 $266 = HEAP32[$265>>2]|0;
 $267 = ($266|0)==(0);
 if ($267) {
  __ZN5physx13GuMeshFactory7releaseEv($this);
  STACKTOP = sp;return;
 }
 $268 = (($this) + 596|0);
 while(1) {
  $273 = HEAP32[$268>>2]|0;
  $274 = HEAP32[$273>>2]|0;
  $275 = HEAP32[$274>>2]|0;
  $276 = HEAP32[$275>>2]|0;
  FUNCTION_TABLE_vi[$276 & 4095]($274);
  $277 = HEAP32[$265>>2]|0;
  $278 = ($277|0)==(0);
  if ($278) {
   break;
  }
 }
 __ZN5physx13GuMeshFactory7releaseEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory14createInstanceEv() {
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 422432 : 421040;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,608,$$$i$i$i,420448,138)|0);
 __ZN5physx9NpFactoryC2Ev($9);
 HEAP32[420520>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory15destroyInstanceEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory7releaseEv($0);
 HEAP32[420520>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory17registerParticlesEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[420528>>2] = 2344;
 HEAP32[420536>>2] = 2345;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_120createParticleSystemEjb($maxParticles,$perParticleRestOffset) {
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 424024 : 421040;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,200,$$$i$i$i,420448,205)|0);
 __ZN5physx16NpParticleSystemC2Ejb($9,$maxParticles,$perParticleRestOffset);
 STACKTOP = sp;return ($9|0);
}
function __ZN12_GLOBAL__N_119createParticleFluidEjb($maxParticles,$perParticleRestOffset) {
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 423904 : 421040;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,200,$$$i$i$i,420448,210)|0);
 __ZN5physx15NpParticleFluidC2Ejb($9,$maxParticles,$perParticleRestOffset);
 STACKTOP = sp;return ($9|0);
}
function __ZN5physx9NpFactory19createParticleFluidEjb($this,$maxParticles,$perParticleRestOffset) {
 $this = $this|0;
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $$$i$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[420536>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,32,420448,238,420544,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z15PxGetFoundationv()|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
 $$$i$i$i$i = $12 ? 423904 : 421040;
 $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,200,$$$i$i$i$i,420448,210)|0);
 __ZN5physx15NpParticleFluidC2Ejb($13,$maxParticles,$perParticleRestOffset);
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($15,32,420448,246,420648,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $13;
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($17);
 $18 = (($this) + 476|0);
 $19 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($18,$0,$vararg_buffer1)|0);
 $20 = HEAP8[$vararg_buffer1>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = ($19|0)==(0|0);
 $or$cond$i$i$i = $21 | $22;
 if (!($or$cond$i$i$i)) {
  $23 = HEAP32[$0>>2]|0;
  HEAP32[$19>>2] = $23;
 }
 $24 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($24);
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpFactory20createParticleSystemEjb($this,$maxParticles,$perParticleRestOffset) {
 $this = $this|0;
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $$$i$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[420528>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,32,420448,259,420704,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z15PxGetFoundationv()|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
 $$$i$i$i$i = $12 ? 424024 : 421040;
 $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,200,$$$i$i$i$i,420448,205)|0);
 __ZN5physx16NpParticleSystemC2Ejb($13,$maxParticles,$perParticleRestOffset);
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($15,32,420448,267,420808,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $13;
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($17);
 $18 = (($this) + 476|0);
 $19 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($18,$0,$vararg_buffer1)|0);
 $20 = HEAP8[$vararg_buffer1>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = ($19|0)==(0|0);
 $or$cond$i$i$i = $21 | $22;
 if (!($or$cond$i$i$i)) {
  $23 = HEAP32[$0>>2]|0;
  HEAP32[$19>>2] = $23;
 }
 $24 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($24);
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpFactory13registerClothEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[420864>>2] = 228;
 HEAP32[420872>>2] = 3168;
 HEAP32[420880>>2] = 3169;
 $0 = HEAP32[463296>>2]|0;
 __ZN5physx2Sc7Physics13registerClothEv($0);
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_111createClothERKN5physx11PxTransformERNS0_13PxClothFabricEPKNS0_15PxClothParticleENS0_7PxFlagsINS0_11PxClothFlag4EnumEtEE($globalPose,$fabric,$particles,$flags) {
 $globalPose = $globalPose|0;
 $fabric = $fabric|0;
 $particles = $particles|0;
 $flags = $flags|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 423800 : 421040;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,152,$$$i$i$i,420448,285)|0);
 $11 = HEAP16[$flags>>1]|0;
 HEAP16[$0>>1] = $11;
 __ZN5physx7NpClothC2ERKNS_11PxTransformERNS_13NpClothFabricEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($10,$globalPose,$fabric,$particles,$0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12_GLOBAL__N_117createClothFabricERN5physx13PxInputStreamE($stream) {
 $stream = $stream|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 423680 : 421040;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,36,$$$i$i$i,420448,290)|0);
 __ZN5physx13NpClothFabricC2Ev($9);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (__ZN5physx13NpClothFabric4loadERNS_13PxInputStreamE($9,$stream)|0);
 if ($11) {
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($9) + 8|0);
 $13 = (($9) + 12|0);
 $14 = (__ZN5physx6shdfnd15atomicDecrementEPVi($13)|0);
 $15 = ($14|0)==(0);
 if (!($15)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($12);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12_GLOBAL__N_117createClothFabricERKN5physx17PxClothFabricDescE($desc) {
 $desc = $desc|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 423680 : 421040;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,36,$$$i$i$i,420448,301)|0);
 __ZN5physx13NpClothFabricC2Ev($9);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (__ZN5physx13NpClothFabric4loadERKNS_17PxClothFabricDescE($9,$desc)|0);
 if ($11) {
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($9) + 8|0);
 $13 = (($9) + 12|0);
 $14 = (__ZN5physx6shdfnd15atomicDecrementEPVi($13)|0);
 $15 = ($14|0)==(0);
 if (!($15)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($12);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpFactory14addClothFabricEPNS_13NpClothFabricEb($this,$cf,$lock) {
 $this = $this|0;
 $cf = $cf|0;
 $lock = $lock|0;
 var $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $cf;
 if ($lock) {
  $1 = (($this) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($2);
  $3 = (($this) + 596|0);
  $4 = (($this) + 600|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0);
  $7 = (($this) + 604|0);
  if ($6) {
   $8 = HEAP32[$7>>2]|0;
   $9 = $8 & 2147483584;
   $10 = ($9>>>0)<(64);
   if ($10) {
    __ZN5physx6shdfnd5ArrayIPNS_13NpClothFabricENS0_19ReflectionAllocatorIS3_EEE8recreateEj($3,64);
    $$pre = HEAP32[$4>>2]|0;
    $14 = $$pre;
   } else {
    $14 = 0;
   }
  } else {
   $14 = $5;
  }
  $11 = HEAP32[$7>>2]|0;
  $12 = $11 & 2147483647;
  $13 = ($12>>>0)>($14>>>0);
  if ($13) {
   $15 = HEAP32[$3>>2]|0;
   $16 = (($15) + ($14<<2)|0);
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    HEAP32[$16>>2] = $cf;
   }
   $18 = (($14) + 1)|0;
   HEAP32[$4>>2] = $18;
  } else {
   (__ZN5physx6shdfnd5ArrayIPNS_13NpClothFabricENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($3,$0)|0);
  }
  $19 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($19);
  STACKTOP = sp;return;
 } else {
  $20 = (($this) + 596|0);
  $21 = (($this) + 600|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0);
  $24 = (($this) + 604|0);
  if ($23) {
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 & 2147483584;
   $27 = ($26>>>0)<(64);
   if ($27) {
    __ZN5physx6shdfnd5ArrayIPNS_13NpClothFabricENS0_19ReflectionAllocatorIS3_EEE8recreateEj($20,64);
    $$pre5 = HEAP32[$21>>2]|0;
    $31 = $$pre5;
   } else {
    $31 = 0;
   }
  } else {
   $31 = $22;
  }
  $28 = HEAP32[$24>>2]|0;
  $29 = $28 & 2147483647;
  $30 = ($29>>>0)>($31>>>0);
  if (!($30)) {
   (__ZN5physx6shdfnd5ArrayIPNS_13NpClothFabricENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($20,$0)|0);
   STACKTOP = sp;return;
  }
  $32 = HEAP32[$20>>2]|0;
  $33 = (($32) + ($31<<2)|0);
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   HEAP32[$33>>2] = $cf;
  }
  $35 = (($31) + 1)|0;
  HEAP32[$21>>2] = $35;
  STACKTOP = sp;return;
 }
}
function __ZN5physx9NpFactory17createClothFabricERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[420872>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,420448,353,420888,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZN12_GLOBAL__N_117createClothFabricERN5physx13PxInputStreamE($stream)|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5physx9NpFactory14addClothFabricEPNS_13NpClothFabricEb($this,$3,1);
 }
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpFactory17createClothFabricERKNS_17PxClothFabricDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[420880>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,420448,370,420888,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZN12_GLOBAL__N_117createClothFabricERKN5physx17PxClothFabricDescE($desc)|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5physx9NpFactory14addClothFabricEPNS_13NpClothFabricEb($this,$3,1);
 }
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpFactory17removeClothFabricERNS_13PxClothFabricE($this,$cf) {
 $this = $this|0;
 $cf = $cf|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 600|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0 = 0;
  } else {
   $5 = (($this) + 596|0);
   $6 = HEAP32[$5>>2]|0;
   $i$04 = 0;
   while(1) {
    $9 = (($6) + ($i$04<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($cf|0);
    $8 = (($i$04) + 1)|0;
    if ($11) {
     break;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $i$04 = $8;
    } else {
     $$0 = 0;
     break L1;
    }
   }
   $12 = (($3) + -1)|0;
   HEAP32[$2>>2] = $12;
   $13 = (($6) + ($12<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$9>>2] = $14;
   $$0 = 1;
  }
 } while(0);
 $15 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($15);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx9NpFactory17getNbClothFabricsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 600|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpFactory15getClothFabricsEPPNS_13PxClothFabricEj($this,$userBuffer,$bufferSize) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 600|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($bufferSize>>>0);
 $3 = $2 ? $1 : $bufferSize;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = (($this) + 596|0);
 $6 = $1 ^ -1;
 $7 = $bufferSize ^ -1;
 $8 = ($6>>>0)>($7>>>0);
 $umax = $8 ? $6 : $7;
 $9 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$5>>2]|0;
  $11 = (($10) + ($i$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($userBuffer) + ($i$01<<2)|0);
  HEAP32[$13>>2] = $12;
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($9|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $14;
  }
 }
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx9NpFactory11createClothERKNS_11PxTransformERNS_13PxClothFabricEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($this,$globalPose,$fabric,$particles,$flags) {
 $this = $this|0;
 $globalPose = $globalPose|0;
 $fabric = $fabric|0;
 $particles = $particles|0;
 $flags = $flags|0;
 var $$$i$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[420864>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,8,420448,432,420888,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP16[$flags>>1]|0;
 $5 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__Z15PxGetFoundationv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $$$i$i$i$i = $13 ? 423800 : 421040;
 $14 = (FUNCTION_TABLE_iiiiii[$8 & 255]($5,152,$$$i$i$i$i,420448,285)|0);
 HEAP16[$vararg_buffer1>>1] = $4;
 __ZN5physx7NpClothC2ERKNS_11PxTransformERNS_13NpClothFabricEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($14,$globalPose,$fabric,$particles,$vararg_buffer1);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $25 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($25,32,420448,446,420928,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $14;
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($17);
 $18 = (($this) + 476|0);
 $19 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($18,$0,$vararg_buffer1)|0);
 $20 = HEAP8[$vararg_buffer1>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = ($19|0)==(0|0);
 $or$cond$i$i = $21 | $22;
 if (!($or$cond$i$i)) {
  $23 = HEAP32[$0>>2]|0;
  HEAP32[$19>>2] = $23;
 }
 $24 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($24);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpFactory14onActorReleaseEPNS_7PxActorE($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$pr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ptr$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 496|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = $a;
   $6 = $5 << 15;
   $7 = $6 ^ -1;
   $8 = (($5) + ($7))|0;
   $9 = $8 >>> 10;
   $10 = $9 ^ $8;
   $11 = ($10*9)|0;
   $12 = $11 >>> 6;
   $13 = $12 ^ $11;
   $14 = $13 << 11;
   $15 = $14 ^ -1;
   $16 = (($13) + ($15))|0;
   $17 = $16 >>> 16;
   $18 = $17 ^ $16;
   $19 = (($3) + -1)|0;
   $20 = $19 & $18;
   $21 = (($this) + 488|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + ($20<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(-1);
   if (!($25)) {
    $26 = (($this) + 480|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($this) + 484|0);
    $$pr$i$i = $24;$ptr$02$i$i = $23;
    while(1) {
     $29 = (($27) + ($$pr$i$i<<2)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($a|0);
     if ($31) {
      break;
     }
     $32 = HEAP32[$28>>2]|0;
     $33 = (($32) + ($$pr$i$i<<2)|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(-1);
     if ($35) {
      break L1;
     } else {
      $$pr$i$i = $34;$ptr$02$i$i = $33;
     }
    }
    $36 = ($$pr$i$i|0)==(-1);
    if (!($36)) {
     $37 = HEAP32[$28>>2]|0;
     $38 = (($37) + ($$pr$i$i<<2)|0);
     $39 = HEAP32[$38>>2]|0;
     HEAP32[$ptr$02$i$i>>2] = $39;
     $40 = (($this) + 512|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + -1)|0;
     HEAP32[$40>>2] = $42;
     $43 = (($this) + 508|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + 1)|0;
     HEAP32[$43>>2] = $45;
     $46 = (($this) + 504|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$38>>2] = $47;
     HEAP32[$46>>2] = $$pr$i$i;
    }
   }
  }
 } while(0);
 $48 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($48);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory14onShapeReleaseEPNS_7PxShapeE($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $a;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = (($this) + 556|0);
 (__ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb1EE6GetKeyES8_Lb1EE5eraseERKS4_($3,$0)|0);
 $4 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($4);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory21registerArticulationsEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[420976>>2] = 53;
 HEAP32[420984>>2] = 1525;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_118createArticulationEv() {
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 423560 : 421040;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,108,$$$i$i$i,420448,475)|0);
 __ZN5physx14NpArticulationC2Ev($9);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  STACKTOP = sp;return ($9|0);
 }
 $11 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($11,32,420448,477,423504,$vararg_buffer);
 STACKTOP = sp;return ($9|0);
}
function __ZN12_GLOBAL__N_122createArticulationLinkERN5physx14NpArticulationEPNS0_18NpArticulationLinkERKNS0_11PxTransformE($root,$parent,$pose) {
 $root = $root|0;
 $parent = $parent|0;
 $pose = $pose|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $childPose = 0, $parentPose = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $vararg_buffer1 = sp;
 $parentPose = sp + 60|0;
 $0 = sp + 4|0;
 $childPose = sp + 32|0;
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 423376 : 421040;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,336,$$$i$i$i,420448,487)|0);
 __ZN5physx18NpArticulationLinkC2ERKNS_11PxTransformERNS_14NpArticulationEPS0_($10,$pose,$root,$parent);
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($12,32,420448,490,423104,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = ($parent|0)==(0|0);
 if ($13) {
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = HEAP32[$parent>>2]|0;
 $15 = (($14) + 124|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($0,$parent);
 $17 = Math_fround(HEAPF32[$0>>2]);
 $18 = Math_fround(-$17);
 $19 = (($0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(-$20);
 $22 = (($0) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(-$23);
 $25 = (($0) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($pose) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($0) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 - $30);
 $32 = (($pose) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($0) + 20|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 - $35);
 $37 = (($pose) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($0) + 24|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 - $40);
 $42 = Math_fround($31 * Math_fround(2.0));
 $43 = Math_fround($36 * Math_fround(2.0));
 $44 = Math_fround($41 * Math_fround(2.0));
 $45 = Math_fround($26 * $26);
 $46 = Math_fround($45 + Math_fround(-0.5));
 $47 = Math_fround($42 * $18);
 $48 = Math_fround($43 * $21);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($44 * $24);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($46 * $42);
 $53 = Math_fround($44 * $21);
 $54 = Math_fround($43 * $24);
 $55 = Math_fround($53 - $54);
 $56 = Math_fround($26 * $55);
 $57 = Math_fround($52 + $56);
 $58 = Math_fround($51 * $18);
 $59 = Math_fround($58 + $57);
 $60 = Math_fround($46 * $43);
 $61 = Math_fround($42 * $24);
 $62 = Math_fround($44 * $18);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($26 * $63);
 $65 = Math_fround($60 + $64);
 $66 = Math_fround($51 * $21);
 $67 = Math_fround($66 + $65);
 $68 = Math_fround($46 * $44);
 $69 = Math_fround($43 * $18);
 $70 = Math_fround($42 * $21);
 $71 = Math_fround($69 - $70);
 $72 = Math_fround($26 * $71);
 $73 = Math_fround($68 + $72);
 $74 = Math_fround($51 * $24);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround(HEAPF32[$pose>>2]);
 $77 = Math_fround($26 * $76);
 $78 = (($pose) + 12|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 * $18);
 $81 = Math_fround($77 + $80);
 $82 = (($pose) + 8|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($83 * $21);
 $85 = Math_fround($81 + $84);
 $86 = (($pose) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($87 * $24);
 $89 = Math_fround($85 - $88);
 $90 = Math_fround($26 * $87);
 $91 = Math_fround($79 * $21);
 $92 = Math_fround($91 + $90);
 $93 = Math_fround($76 * $24);
 $94 = Math_fround($93 + $92);
 $95 = Math_fround($83 * $18);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($26 * $83);
 $98 = Math_fround($79 * $24);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($87 * $18);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($76 * $21);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($26 * $79);
 $105 = Math_fround($76 * $18);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($87 * $21);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($83 * $24);
 $110 = Math_fround($108 - $109);
 HEAPF32[$parentPose>>2] = $89;
 $111 = (($parentPose) + 4|0);
 HEAPF32[$111>>2] = $96;
 $112 = (($parentPose) + 8|0);
 HEAPF32[$112>>2] = $103;
 $113 = (($parentPose) + 12|0);
 HEAPF32[$113>>2] = $110;
 $114 = (($parentPose) + 16|0);
 HEAPF32[$114>>2] = $59;
 $115 = (($parentPose) + 20|0);
 HEAPF32[$115>>2] = $67;
 $116 = (($parentPose) + 24|0);
 HEAPF32[$116>>2] = $75;
 HEAPF32[$childPose>>2] = Math_fround(0.0);
 $117 = (($childPose) + 4|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 $118 = (($childPose) + 8|0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 $119 = (($childPose) + 12|0);
 HEAPF32[$119>>2] = Math_fround(1.0);
 $120 = (($childPose) + 16|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($childPose) + 20|0);
 HEAPF32[$121>>2] = Math_fround(0.0);
 $122 = (($childPose) + 24|0);
 HEAPF32[$122>>2] = Math_fround(0.0);
 $123 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($124) + 8|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (__Z15PxGetFoundationv()|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = (($128) + 24|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (FUNCTION_TABLE_ii[$130 & 4095]($127)|0);
 $$$i$i$i1 = $131 ? 423248 : 421040;
 $132 = (FUNCTION_TABLE_iiiiii[$126 & 255]($123,204,$$$i$i$i1,420448,500)|0);
 __ZN5physx19NpArticulationJointC2ERNS_18NpArticulationLinkERKNS_11PxTransformES2_S5_($132,$parent,$parentPose,$10,$childPose);
 $133 = ($132|0)==(0|0);
 if ($133) {
  $134 = HEAP32[$10>>2]|0;
  $135 = (($134) + 16|0);
  $136 = HEAP32[$135>>2]|0;
  FUNCTION_TABLE_vi[$136 & 4095]($10);
  $137 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($137,32,420448,505,423160,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $138 = (($10) + 292|0);
  HEAP32[$138>>2] = $132;
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx9NpFactory18createArticulationEv($this) {
 $this = $this|0;
 var $$$i$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $or$cond$i$i$i = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[420976>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,8,420448,531,420992,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z15PxGetFoundationv()|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
 $$$i$i$i$i = $12 ? 423560 : 421040;
 $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,108,$$$i$i$i$i,420448,475)|0);
 __ZN5physx14NpArticulationC2Ev($13);
 $cond = ($13|0)==(0|0);
 if ($cond) {
  $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,32,420448,477,423504,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $13;
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($16);
 $17 = (($this) + 396|0);
 $18 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_14PxArticulationES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($17,$0,$vararg_buffer1)|0);
 $19 = HEAP8[$vararg_buffer1>>0]|0;
 $20 = ($19<<24>>24)!=(0);
 $21 = ($18|0)==(0|0);
 $or$cond$i$i$i = $20 | $21;
 if (!($or$cond$i$i$i)) {
  $22 = HEAP32[$0>>2]|0;
  HEAP32[$18>>2] = $22;
 }
 $23 = HEAP32[$15>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($23);
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpFactory21onArticulationReleaseEPNS_14PxArticulationE($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$pr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ptr$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 416|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = $a;
   $6 = $5 << 15;
   $7 = $6 ^ -1;
   $8 = (($5) + ($7))|0;
   $9 = $8 >>> 10;
   $10 = $9 ^ $8;
   $11 = ($10*9)|0;
   $12 = $11 >>> 6;
   $13 = $12 ^ $11;
   $14 = $13 << 11;
   $15 = $14 ^ -1;
   $16 = (($13) + ($15))|0;
   $17 = $16 >>> 16;
   $18 = $17 ^ $16;
   $19 = (($3) + -1)|0;
   $20 = $19 & $18;
   $21 = (($this) + 408|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + ($20<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(-1);
   if (!($25)) {
    $26 = (($this) + 400|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($this) + 404|0);
    $$pr$i$i = $24;$ptr$02$i$i = $23;
    while(1) {
     $29 = (($27) + ($$pr$i$i<<2)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($a|0);
     if ($31) {
      break;
     }
     $32 = HEAP32[$28>>2]|0;
     $33 = (($32) + ($$pr$i$i<<2)|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(-1);
     if ($35) {
      break L1;
     } else {
      $$pr$i$i = $34;$ptr$02$i$i = $33;
     }
    }
    $36 = ($$pr$i$i|0)==(-1);
    if (!($36)) {
     $37 = HEAP32[$28>>2]|0;
     $38 = (($37) + ($$pr$i$i<<2)|0);
     $39 = HEAP32[$38>>2]|0;
     HEAP32[$ptr$02$i$i>>2] = $39;
     $40 = (($this) + 432|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + -1)|0;
     HEAP32[$40>>2] = $42;
     $43 = (($this) + 428|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + 1)|0;
     HEAP32[$43>>2] = $45;
     $46 = (($this) + 424|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$38>>2] = $47;
     HEAP32[$46>>2] = $$pr$i$i;
    }
   }
  }
 } while(0);
 $48 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($48);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory22createArticulationLinkERNS_14NpArticulationEPNS_18NpArticulationLinkERKNS_11PxTransformE($this,$root,$parent,$pose) {
 $this = $this|0;
 $root = $root|0;
 $parent = $parent|0;
 $pose = $pose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[420984>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,420448,554,420992,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (__ZN12_GLOBAL__N_122createArticulationLinkERN5physx14NpArticulationEPNS0_18NpArticulationLinkERKNS0_11PxTransformE($root,$parent,$pose)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx9NpFactory16createConstraintEPNS_12PxRigidActorES2_RNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableEj($this,$actor0,$actor1,$connector,$shaders,$dataSize) {
 $this = $this|0;
 $actor0 = $actor0|0;
 $actor1 = $actor1|0;
 $connector = $connector|0;
 $shaders = $shaders|0;
 $dataSize = $dataSize|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exists$i$i$i = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i$i = sp + 4|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 422200 : 421040;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,128,$$$i$i$i,420448,580)|0);
 __ZN5physx12NpConstraintC2EPNS_12PxRigidActorES2_RNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableEj($10,$actor0,$actor1,$connector,$shaders,$dataSize);
 HEAP32[$0>>2] = $10;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return ($10|0);
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($13);
 $14 = (($this) + 436|0);
 $15 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_12PxConstraintES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($14,$0,$exists$i$i$i)|0);
 $16 = HEAP8[$exists$i$i$i>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = ($15|0)==(0|0);
 $or$cond$i$i$i = $17 | $18;
 if (!($or$cond$i$i$i)) {
  $19 = HEAP32[$0>>2]|0;
  HEAP32[$15>>2] = $19;
 }
 $20 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($20);
 STACKTOP = sp;return ($10|0);
}
function __ZN5physx9NpFactory19onConstraintReleaseEPNS_12PxConstraintE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$pr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ptr$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 456|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = $c;
   $6 = $5 << 15;
   $7 = $6 ^ -1;
   $8 = (($5) + ($7))|0;
   $9 = $8 >>> 10;
   $10 = $9 ^ $8;
   $11 = ($10*9)|0;
   $12 = $11 >>> 6;
   $13 = $12 ^ $11;
   $14 = $13 << 11;
   $15 = $14 ^ -1;
   $16 = (($13) + ($15))|0;
   $17 = $16 >>> 16;
   $18 = $17 ^ $16;
   $19 = (($3) + -1)|0;
   $20 = $19 & $18;
   $21 = (($this) + 448|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + ($20<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(-1);
   if (!($25)) {
    $26 = (($this) + 440|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($this) + 444|0);
    $$pr$i$i = $24;$ptr$02$i$i = $23;
    while(1) {
     $29 = (($27) + ($$pr$i$i<<2)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($c|0);
     if ($31) {
      break;
     }
     $32 = HEAP32[$28>>2]|0;
     $33 = (($32) + ($$pr$i$i<<2)|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(-1);
     if ($35) {
      break L1;
     } else {
      $$pr$i$i = $34;$ptr$02$i$i = $33;
     }
    }
    $36 = ($$pr$i$i|0)==(-1);
    if (!($36)) {
     $37 = HEAP32[$28>>2]|0;
     $38 = (($37) + ($$pr$i$i<<2)|0);
     $39 = HEAP32[$38>>2]|0;
     HEAP32[$ptr$02$i$i>>2] = $39;
     $40 = (($this) + 472|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + -1)|0;
     HEAP32[$40>>2] = $42;
     $43 = (($this) + 468|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + 1)|0;
     HEAP32[$43>>2] = $45;
     $46 = (($this) + 464|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$38>>2] = $47;
     HEAP32[$46>>2] = $$pr$i$i;
    }
   }
  }
 } while(0);
 $48 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($48);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory15createAggregateEjb($this,$maxActors,$selfCollisions) {
 $this = $this|0;
 $maxActors = $maxActors|0;
 $selfCollisions = $selfCollisions|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exists$i$i$i = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i$i = sp + 4|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 422000 : 421040;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,44,$$$i$i$i,420448,603)|0);
 __ZN5physx11NpAggregateC2Ejb($10,$maxActors,$selfCollisions);
 HEAP32[$0>>2] = $10;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return ($10|0);
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($13);
 $14 = (($this) + 356|0);
 $15 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_11PxAggregateES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($14,$0,$exists$i$i$i)|0);
 $16 = HEAP8[$exists$i$i$i>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = ($15|0)==(0|0);
 $or$cond$i$i$i = $17 | $18;
 if (!($or$cond$i$i$i)) {
  $19 = HEAP32[$0>>2]|0;
  HEAP32[$15>>2] = $19;
 }
 $20 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($20);
 STACKTOP = sp;return ($10|0);
}
function __ZN5physx9NpFactory18onAggregateReleaseEPNS_11PxAggregateE($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$pr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ptr$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 376|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = $a;
   $6 = $5 << 15;
   $7 = $6 ^ -1;
   $8 = (($5) + ($7))|0;
   $9 = $8 >>> 10;
   $10 = $9 ^ $8;
   $11 = ($10*9)|0;
   $12 = $11 >>> 6;
   $13 = $12 ^ $11;
   $14 = $13 << 11;
   $15 = $14 ^ -1;
   $16 = (($13) + ($15))|0;
   $17 = $16 >>> 16;
   $18 = $17 ^ $16;
   $19 = (($3) + -1)|0;
   $20 = $19 & $18;
   $21 = (($this) + 368|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + ($20<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(-1);
   if (!($25)) {
    $26 = (($this) + 360|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($this) + 364|0);
    $$pr$i$i = $24;$ptr$02$i$i = $23;
    while(1) {
     $29 = (($27) + ($$pr$i$i<<2)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($a|0);
     if ($31) {
      break;
     }
     $32 = HEAP32[$28>>2]|0;
     $33 = (($32) + ($$pr$i$i<<2)|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(-1);
     if ($35) {
      break L1;
     } else {
      $$pr$i$i = $34;$ptr$02$i$i = $33;
     }
    }
    $36 = ($$pr$i$i|0)==(-1);
    if (!($36)) {
     $37 = HEAP32[$28>>2]|0;
     $38 = (($37) + ($$pr$i$i<<2)|0);
     $39 = HEAP32[$38>>2]|0;
     HEAP32[$ptr$02$i$i>>2] = $39;
     $40 = (($this) + 392|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + -1)|0;
     HEAP32[$40>>2] = $42;
     $43 = (($this) + 388|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + 1)|0;
     HEAP32[$43>>2] = $45;
     $46 = (($this) + 384|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$38>>2] = $47;
     HEAP32[$46>>2] = $$pr$i$i;
    }
   }
  }
 } while(0);
 $48 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($48);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory14createMaterialEfff($this,$staticFriction,$dynamicFriction,$restitution) {
 $this = $this|0;
 $staticFriction = Math_fround($staticFriction);
 $dynamicFriction = Math_fround($dynamicFriction);
 $restitution = Math_fround($restitution);
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $data = sp + 32|0;
 $0 = sp;
 ;HEAP32[$data+0>>2]=0|0;HEAP32[$data+4>>2]=0|0;HEAP32[$data+8>>2]=0|0;HEAP16[$data+12>>1]=0|0;HEAP8[$data+14>>0]=0|0;
 $1 = (($data) + 4|0);
 HEAPF32[$1>>2] = $staticFriction;
 HEAPF32[$data>>2] = $dynamicFriction;
 $2 = (($data) + 8|0);
 HEAPF32[$2>>2] = $restitution;
 $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__Z15PxGetFoundationv()|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $$$i$i$i = $11 ? 421888 : 421040;
 $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,64,$$$i$i$i,420448,629)|0);
 __ZN5physx2Sc12MaterialCoreC2ERKNS_15PxsMaterialDataE($0,$data);
 __ZN5physx10NpMaterialC2ERKNS_2Sc12MaterialCoreE($12,$0);
 STACKTOP = sp;return ($12|0);
}
function __ZN5physx9NpFactory21acquireConnectorArrayEv($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 352|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 348|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (($this) + 56|0);
  __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEE12allocateSlabEv($5);
  $$pre$i$i = HEAP32[$2>>2]|0;
  $7 = $$pre$i$i;
 } else {
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 HEAP32[$2>>2] = $6;
 $8 = (($this) + 336|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = (($this) + 340|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + -1)|0;
 HEAP32[$11>>2] = $13;
 $14 = ($7|0)==(0|0);
 if ($14) {
  $20 = 0;
  $19 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($19);
  STACKTOP = sp;return ($20|0);
 }
 $15 = (($7) + 32|0);
 $16 = (($7) + 40|0);
 HEAP32[$16>>2] = 0;
 HEAP8[$15>>0] = 1;
 $17 = (($7) + 36|0);
 HEAP32[$17>>2] = $7;
 $18 = (($7) + 44|0);
 HEAP32[$18>>2] = (4);
 $20 = $7;
 $19 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($19);
 STACKTOP = sp;return ($20|0);
}
function __ZN5physx9NpFactory21releaseConnectorArrayEPNS_16NpConnectorArrayE($this,$array) {
 $this = $this|0;
 $array = $array|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 352|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 56|0);
 $3 = ($array|0)==(0|0);
 if ($3) {
  $30 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($30);
  STACKTOP = sp;return;
 }
 $4 = (($array) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($6|0)!=(0);
 $8 = ($5|0)>(-1);
 $or$cond$i$i$i$i$i = $7 & $8;
 do {
  if ($or$cond$i$i$i$i$i) {
   $9 = (($array) + 36|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($array|0)==($10|0);
   if ($11) {
    $17 = (($array) + 32|0);
    HEAP8[$17>>0] = 0;
    break;
   }
   $12 = ($10|0)==(0|0);
   if (!($12)) {
    $13 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($14) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    FUNCTION_TABLE_vii[$16 & 4095]($13,$10);
   }
  }
 } while(0);
 $18 = (($this) + 336|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + -1)|0;
 HEAP32[$18>>2] = $20;
 $21 = (($this) + 348|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$array>>2] = $22;
 HEAP32[$21>>2] = $array;
 $23 = (($this) + 340|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$23>>2] = $25;
 $26 = (($this) + 332|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27*50)|0;
 $29 = ($24|0)<($28|0);
 if ($29) {
  $30 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($30);
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEE17releaseEmptySlabsEv($2);
 HEAP32[$23>>2] = 0;
 $30 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($30);
 STACKTOP = sp;return;
}
function __ZN5physx9NpFactory11createShapeERKNS_10PxGeometryENS_7PxFlagsINS_11PxShapeFlag4EnumEhEEPKPNS_10PxMaterialEtb($this,$geometry,$shapeFlags,$materials,$materialCount,$isExclusive) {
 $this = $this|0;
 $geometry = $geometry|0;
 $shapeFlags = $shapeFlags|0;
 $materials = $materials|0;
 $materialCount = $materialCount|0;
 $isExclusive = $isExclusive|0;
 var $$$i$i$i = 0, $$0 = 0, $$0$i$i$i = 0, $$pn$i$i = 0, $$pn$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $exists$i$i = 0, $exitcond = 0, $exitcond$i = 0, $i$01 = 0, $i$01$i = 0, $materialIndices = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $exists$i$i = sp + 35|0;
 $0 = sp;
 $materialIndices = sp + 8|0;
 $1 = sp + 32|0;
 $2 = sp + 34|0;
 $3 = (($materialIndices) + 8|0);
 $4 = (($materialIndices) + 12|0);
 $5 = (($materialIndices) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($materialIndices) + 20|0);
 HEAP8[$3>>0] = 1;
 HEAP32[$4>>2] = $materialIndices;
 HEAP32[$6>>2] = 4;
 $7 = $materialCount&65535;
 HEAP16[$1>>1] = 0;
 __ZN5physx6shdfnd5ArrayItNS0_15InlineAllocatorILj8ENS0_19ReflectionAllocatorItEEEEE6resizeEjRKt($materialIndices,$7,$1);
 $8 = ($materialCount<<16>>16)==(1);
 if ($8) {
  $9 = HEAP32[$materials>>2]|0;
  $10 = (($9) + 52|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11&65535;
  $13 = HEAP32[$4>>2]|0;
  HEAP16[$13>>1] = $12;
 } else {
  $14 = HEAP32[$4>>2]|0;
  $15 = ($materialCount<<16>>16)==(0);
  if (!($15)) {
   $i$01$i = 0;
   while(1) {
    $16 = (($materials) + ($i$01$i<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 52|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = $19&65535;
    $21 = (($14) + ($i$01$i<<1)|0);
    HEAP16[$21>>1] = $20;
    $22 = (($i$01$i) + 1)|0;
    $exitcond$i = ($22|0)==($7|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $22;
    }
   }
  }
 }
 $23 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (__Z15PxGetFoundationv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (FUNCTION_TABLE_ii[$30 & 4095]($27)|0);
 $$$i$i$i = $31 ? 421312 : 421040;
 $32 = (FUNCTION_TABLE_iiiiii[$26 & 255]($23,208,$$$i$i$i,420448,703)|0);
 $33 = HEAP8[$shapeFlags>>0]|0;
 HEAP8[$2>>0] = $33;
 $34 = HEAP32[$4>>2]|0;
 __ZN5physx7NpShapeC2ERKNS_10PxGeometryENS_7PxFlagsINS_11PxShapeFlag4EnumEhEEPKttb($32,$geometry,$2,$34,$materialCount,$isExclusive);
 $35 = ($32|0)==(0|0);
 if ($35) {
  $$0 = 0;
 } else {
  $36 = ($materialCount<<16>>16)==(0);
  if (!($36)) {
   $37 = (($32) + 36|0);
   $38 = (($32) + 48|0);
   $39 = (($32) + 32|0);
   $40 = (($32) + 40|0);
   $i$01 = 0;
   while(1) {
    $41 = HEAP32[424544>>2]|0;
    $42 = HEAP32[$37>>2]|0;
    $43 = $42 & 2;
    $44 = ($43|0)==(0);
    if ($44) {
     $66 = (__ZNK5physx2Sc9ShapeCore18getMaterialIndicesEv($38)|0);
     $67 = (($66) + ($i$01<<1)|0);
     $68 = HEAP16[$67>>1]|0;
     $69 = $68&65535;
     $70 = (($41) + 52|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = (($71) + ($69<<2)|0);
     $$pn$in$i$i = $72;
    } else {
     $45 = HEAP32[$39>>2]|0;
     $46 = HEAP32[$40>>2]|0;
     $47 = ($46|0)==(0|0);
     if ($47) {
      $48 = $42 >>> 24;
      $49 = $48 & 15;
      $50 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($45,$49)|0);
      HEAP32[$40>>2] = $50;
      $52 = $50;
     } else {
      $52 = $46;
     }
     $51 = (($52) + 60|0);
     $53 = HEAP16[$51>>1]|0;
     $54 = ($53<<16>>16)==(1);
     $55 = (($52) + 56|0);
     if ($54) {
      $$0$i$i$i = $55;
     } else {
      $56 = HEAP32[$55>>2]|0;
      $57 = (($45) + 2488|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (($58) + ($56<<1)|0);
      $$0$i$i$i = $59;
     }
     $60 = (($$0$i$i$i) + ($i$01<<1)|0);
     $61 = HEAP16[$60>>1]|0;
     $62 = $61&65535;
     $63 = (($41) + 52|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($64) + ($62<<2)|0);
     $$pn$in$i$i = $65;
    }
    $$pn$i$i = HEAP32[$$pn$in$i$i>>2]|0;
    $73 = (($$pn$i$i) + 16|0);
    (__ZN5physx6shdfnd15atomicIncrementEPVi($73)|0);
    $74 = (($i$01) + 1)|0;
    $exitcond = ($74|0)==($7|0);
    if ($exitcond) {
     break;
    } else {
     $i$01 = $74;
    }
   }
  }
  HEAP32[$0>>2] = $32;
  $75 = (($this) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($76);
  $77 = (($this) + 556|0);
  $78 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb1EE6GetKeyES8_Lb1EE6createERKS4_Rb($77,$0,$exists$i$i)|0);
  $79 = HEAP8[$exists$i$i>>0]|0;
  $80 = ($79<<24>>24)!=(0);
  $81 = ($78|0)==(0|0);
  $or$cond$i$i = $80 | $81;
  if (!($or$cond$i$i)) {
   $82 = HEAP32[$0>>2]|0;
   HEAP32[$78>>2] = $82;
  }
  $83 = HEAP32[$75>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($83);
  $$0 = $32;
 }
 $84 = HEAP32[$6>>2]|0;
 $85 = $84 & 2147483647;
 $86 = ($85|0)!=(0);
 $87 = ($84|0)>(-1);
 $or$cond$i$i$i = $86 & $87;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return ($$0|0);
 }
 $88 = HEAP32[$4>>2]|0;
 $89 = ($materialIndices|0)==($88|0);
 if ($89) {
  HEAP8[$3>>0] = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $90 = ($88|0)==(0|0);
 if ($90) {
  STACKTOP = sp;return ($$0|0);
 }
 $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + 12|0);
 $94 = HEAP32[$93>>2]|0;
 FUNCTION_TABLE_vii[$94 & 4095]($91,$88);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayItNS0_15InlineAllocatorILj8ENS0_19ReflectionAllocatorItEEEEE6resizeEjRKt($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayItNS0_15InlineAllocatorILj8ENS0_19ReflectionAllocatorItEEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($size<<1)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + ($7<<1)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   $12 = HEAP16[$a>>1]|0;
   HEAP16[$$01$i>>1] = $12;
  }
  $13 = (($$01$i) + 2|0);
  $14 = ($13>>>0)<($8>>>0);
  if ($14) {
   $$01$i = $13;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx9NpFactory11getNbShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 592|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpFactory9getShapesEPPNS_7PxShapeEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 592|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($startIndex>>>0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($1) - ($startIndex))|0;
 $4 = ($3>>>0)>($bufferSize>>>0);
 $5 = $4 ? $3 : $bufferSize;
 $6 = (($this) + 560|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$01 = 0;
 }
 while(1) {
  $9 = (($i$01) + ($startIndex))|0;
  $10 = (($7) + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($userBuffer) + ($i$01<<2)|0);
  HEAP32[$12>>2] = $11;
  $13 = (($i$01) + 1)|0;
  $14 = ($13>>>0)<($5>>>0);
  if ($14) {
   $i$01 = $13;
  } else {
   $$0 = $5;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpFactory17createRigidStaticERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exists$i$i$i = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i$i = sp + 4|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 421192 : 421040;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,112,$$$i$i$i,420448,737)|0);
 __ZN5physx13NpRigidStaticC2ERKNS_11PxTransformE($10,$pose);
 HEAP32[$0>>2] = $10;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return ($10|0);
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($13);
 $14 = (($this) + 476|0);
 $15 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($14,$0,$exists$i$i$i)|0);
 $16 = HEAP8[$exists$i$i$i>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = ($15|0)==(0|0);
 $or$cond$i$i$i = $17 | $18;
 if (!($or$cond$i$i$i)) {
  $19 = HEAP32[$0>>2]|0;
  HEAP32[$15>>2] = $19;
 }
 $20 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($20);
 STACKTOP = sp;return ($10|0);
}
function __ZN5physx9NpFactory18createRigidDynamicERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exists$i$i$i = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i$i = sp + 4|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 421072 : 421040;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,288,$$$i$i$i,420448,746)|0);
 __ZN5physx14NpRigidDynamicC2ERKNS_11PxTransformE($10,$pose);
 HEAP32[$0>>2] = $10;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return ($10|0);
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($13);
 $14 = (($this) + 476|0);
 $15 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($14,$0,$exists$i$i$i)|0);
 $16 = HEAP8[$exists$i$i$i>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = ($15|0)==(0|0);
 $or$cond$i$i$i = $17 | $18;
 if (!($or$cond$i$i$i)) {
  $19 = HEAP32[$0>>2]|0;
  HEAP32[$15>>2] = $19;
 }
 $20 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($20);
 STACKTOP = sp;return ($10|0);
}
function __ZN5physx9NpDestroyERNS_3Scb4BaseE($base) {
 $base = $base|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($base) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 24;
 $3 = $2 & 15;
 do {
  switch ($3|0) {
  case 11:  {
   $115 = (($base) + -20|0);
   $116 = (($base) + -12|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = (($115) + 6|0);
   $119 = HEAP16[$118>>1]|0;
   $120 = $119 & 1;
   $121 = ($120<<16>>16)==(0);
   $122 = HEAP32[$115>>2]|0;
   if ($121) {
    $125 = (($122) + 12|0);
    $126 = HEAP32[$125>>2]|0;
    FUNCTION_TABLE_vi[$126 & 4095]($115);
   } else {
    $123 = (($122) + 16|0);
    $124 = HEAP32[$123>>2]|0;
    FUNCTION_TABLE_vi[$124 & 4095]($115);
   }
   $127 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($127,$115,$117,2);
   STACKTOP = sp;return;
   break;
  }
  case 10:  {
   $104 = (($base) + -8|0);
   $105 = (($104) + 6|0);
   $106 = HEAP16[$105>>1]|0;
   $107 = $106 & 1;
   $108 = ($107<<16>>16)==(0);
   $109 = HEAP32[$104>>2]|0;
   if ($108) {
    $112 = (($109) + 12|0);
    $113 = HEAP32[$112>>2]|0;
    FUNCTION_TABLE_vi[$113 & 4095]($104);
   } else {
    $110 = (($109) + 16|0);
    $111 = HEAP32[$110>>2]|0;
    FUNCTION_TABLE_vi[$111 & 4095]($104);
   }
   $114 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($114,$104,0,2);
   STACKTOP = sp;return;
   break;
  }
  case 5:  {
   $43 = (($base) + -48|0);
   $44 = (($base) + -40|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($43) + 6|0);
   $47 = HEAP16[$46>>1]|0;
   $48 = $47 & 1;
   $49 = ($48<<16>>16)==(0);
   $50 = HEAP32[$43>>2]|0;
   if ($49) {
    $53 = (($50) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    FUNCTION_TABLE_vi[$54 & 4095]($43);
   } else {
    $51 = (($50) + 16|0);
    $52 = HEAP32[$51>>2]|0;
    FUNCTION_TABLE_vi[$52 & 4095]($43);
   }
   $55 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($55,$43,$45,2);
   STACKTOP = sp;return;
   break;
  }
  case 3:  {
   $17 = (($base) + -48|0);
   $18 = (($base) + -40|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + 6|0);
   $21 = HEAP16[$20>>1]|0;
   $22 = $21 & 1;
   $23 = ($22<<16>>16)==(0);
   $24 = HEAP32[$17>>2]|0;
   if ($23) {
    $27 = (($24) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    FUNCTION_TABLE_vi[$28 & 4095]($17);
   } else {
    $25 = (($24) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    FUNCTION_TABLE_vi[$26 & 4095]($17);
   }
   $29 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($29,$17,$19,2);
   STACKTOP = sp;return;
   break;
  }
  case 6:  {
   $56 = (($base) + -16|0);
   $57 = (($56) + 6|0);
   $58 = HEAP16[$57>>1]|0;
   $59 = $58 & 1;
   $60 = ($59<<16>>16)==(0);
   $61 = HEAP32[$56>>2]|0;
   if ($60) {
    $64 = (($61) + 12|0);
    $65 = HEAP32[$64>>2]|0;
    FUNCTION_TABLE_vi[$65 & 4095]($56);
   } else {
    $62 = (($61) + 16|0);
    $63 = HEAP32[$62>>2]|0;
    FUNCTION_TABLE_vi[$63 & 4095]($56);
   }
   $66 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($66,$56,0,2);
   STACKTOP = sp;return;
   break;
  }
  case 7:  {
   $67 = (($base) + -20|0);
   $68 = (($base) + -12|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($67) + 6|0);
   $71 = HEAP16[$70>>1]|0;
   $72 = $71 & 1;
   $73 = ($72<<16>>16)==(0);
   $74 = HEAP32[$67>>2]|0;
   if ($73) {
    $77 = (($74) + 12|0);
    $78 = HEAP32[$77>>2]|0;
    FUNCTION_TABLE_vi[$78 & 4095]($67);
   } else {
    $75 = (($74) + 16|0);
    $76 = HEAP32[$75>>2]|0;
    FUNCTION_TABLE_vi[$76 & 4095]($67);
   }
   $79 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($79,$67,$69,2);
   STACKTOP = sp;return;
   break;
  }
  case 9:  {
   $93 = (($base) + -8|0);
   $94 = (($93) + 6|0);
   $95 = HEAP16[$94>>1]|0;
   $96 = $95 & 1;
   $97 = ($96<<16>>16)==(0);
   $98 = HEAP32[$93>>2]|0;
   if ($97) {
    $101 = (($98) + 12|0);
    $102 = HEAP32[$101>>2]|0;
    FUNCTION_TABLE_vi[$102 & 4095]($93);
   } else {
    $99 = (($98) + 16|0);
    $100 = HEAP32[$99>>2]|0;
    FUNCTION_TABLE_vi[$100 & 4095]($93);
   }
   $103 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($103,$93,0,2);
   STACKTOP = sp;return;
   break;
  }
  case 2: case 1:  {
   $4 = (($base) + -32|0);
   $5 = (($base) + -24|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($base) + -26|0);
   $8 = HEAP16[$7>>1]|0;
   $9 = $8 & 1;
   $10 = ($9<<16>>16)==(0);
   $11 = HEAP32[$4>>2]|0;
   if ($10) {
    $14 = (($11) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vi[$15 & 4095]($4);
   } else {
    $12 = (($11) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vi[$13 & 4095]($4);
   }
   $16 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($16,$4,$6,2);
   STACKTOP = sp;return;
   break;
  }
  case 4:  {
   $30 = (($base) + -48|0);
   $31 = (($base) + -40|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 6|0);
   $34 = HEAP16[$33>>1]|0;
   $35 = $34 & 1;
   $36 = ($35<<16>>16)==(0);
   $37 = HEAP32[$30>>2]|0;
   if ($36) {
    $40 = (($37) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    FUNCTION_TABLE_vi[$41 & 4095]($30);
   } else {
    $38 = (($37) + 16|0);
    $39 = HEAP32[$38>>2]|0;
    FUNCTION_TABLE_vi[$39 & 4095]($30);
   }
   $42 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($42,$30,$32,2);
   STACKTOP = sp;return;
   break;
  }
  case 8:  {
   $80 = (($base) + -12|0);
   $81 = (($base) + -4|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($80) + 6|0);
   $84 = HEAP16[$83>>1]|0;
   $85 = $84 & 1;
   $86 = ($85<<16>>16)==(0);
   $87 = HEAP32[$80>>2]|0;
   if ($86) {
    $90 = (($87) + 12|0);
    $91 = HEAP32[$90>>2]|0;
    FUNCTION_TABLE_vi[$91 & 4095]($80);
   } else {
    $88 = (($87) + 16|0);
    $89 = HEAP32[$88>>2]|0;
    FUNCTION_TABLE_vi[$89 & 4095]($80);
   }
   $92 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($92,$80,$82,2);
   STACKTOP = sp;return;
   break;
  }
  default: {
   STACKTOP = sp;return;
  }
  }
 } while(0);
}
function __ZN5physx6shdfnd5ArrayItNS0_15InlineAllocatorILj8ENS0_19ReflectionAllocatorItEEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 1;
  $2 = (($this) + 8|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(9);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 421496 : 421040;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,421416,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<1)|0);
 $21 = (($this) + 12|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP16[$$03$i>>1]|0;
    HEAP16[$$012$i>>1] = $25;
   }
   $26 = (($$012$i) + 2|0);
   $27 = (($$03$i) + 2|0);
   $28 = ($26>>>0)<($19>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = (($this) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(-1);
 if (!($31)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$21>>2]|0;
 $33 = ($this|0)==($32|0);
 if ($33) {
  $34 = (($this) + 8|0);
  HEAP8[$34>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = ($32|0)==(0|0);
 if ($35) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vii[$39 & 4095]($36,$32);
 HEAP32[$21>>2] = $20;
 HEAP32[$29>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEE4copyINS0_15InlineAllocatorILj256ES5_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 48)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 421600 : 421040;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,421720,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 421600 : 421040;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,421720,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 421600 : 421040;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,421416,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 421600 : 421040;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,421416,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEE4copyINS0_15InlineAllocatorILj256ES5_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 421600 : 421040;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,421416,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 421600 : 421040;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,421808,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*48)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -48|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_11PxAggregateES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre11 = 0, $$pre11$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $36 = $1 << 1;
  $$$i = $2 ? 16 : $36;
  $37 = ($1>>>0)<($$$i>>>0);
  if ($37) {
   __ZN5physx6shdfnd8internal8HashBaseIPNS_11PxAggregateES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $$pre11$pre = HEAP32[$33>>2]|0;
   $$pre11 = $$pre11$pre;$54 = $$pre;
  } else {
   $$pre11 = -1;$54 = $1;
  }
  $38 = HEAP32[$k>>2]|0;
  $39 = $38;
  $40 = $39 << 15;
  $41 = $40 ^ -1;
  $42 = (($39) + ($41))|0;
  $43 = $42 >>> 10;
  $44 = $43 ^ $42;
  $45 = ($44*9)|0;
  $46 = $45 >>> 6;
  $47 = $46 ^ $45;
  $48 = $47 << 11;
  $49 = $48 ^ -1;
  $50 = (($47) + ($49))|0;
  $51 = $50 >>> 16;
  $52 = $51 ^ $50;
  $53 = (($54) + -1)|0;
  $55 = $52 & $53;
  $59 = $$pre11;$h$1 = $55;
 } else {
  $59 = $34;$h$1 = $h$0;
 }
 $56 = (($this) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($59<<2)|0);
 $60 = HEAP32[$58>>2]|0;
 HEAP32[$33>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$58>>2] = $64;
 HEAP32[$63>>2] = $59;
 $65 = (($this) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $68 = (($this) + 32|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$68>>2] = $70;
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($59<<2)|0);
 $$0 = $73;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_11PxAggregateES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,422112,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
    $44 = $43 << 15;
    $45 = $44 ^ -1;
    $46 = (($43) + ($45))|0;
    $47 = $46 >>> 10;
    $48 = $47 ^ $46;
    $49 = ($48*9)|0;
    $50 = $49 >>> 6;
    $51 = $50 ^ $49;
    $52 = $51 << 11;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 16;
    $56 = $55 ^ $54;
    $57 = $56 & $39;
    $58 = (($32) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($33) + ($index$01<<2)|0);
    HEAP32[$60>>2] = $59;
    HEAP32[$58>>2] = $index$01;
    $61 = (($34) + ($index$01<<2)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     HEAP32[$61>>2] = $42;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre13 = (($this) + 20|0);
  $$pre14 = (($this) + 8|0);
  $$pre$phi15Z2D = $$pre14;$$pre$phiZ2D = $$pre13;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $117 = $71;$bucket$06 = 0;
   while(1) {
    $76 = HEAP32[$73>>2]|0;
    $77 = (($76) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$77>>2]|0;
    $78 = ($index1$02|0)==(-1);
    if ($78) {
     $107 = $117;
    } else {
     $index1$03 = $index1$02;
     while(1) {
      $79 = HEAP32[$74>>2]|0;
      $80 = (($79) + ($index1$03<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81;
      $83 = $82 << 15;
      $84 = $83 ^ -1;
      $85 = (($82) + ($84))|0;
      $86 = $85 >>> 10;
      $87 = $86 ^ $85;
      $88 = ($87*9)|0;
      $89 = $88 >>> 6;
      $90 = $89 ^ $88;
      $91 = $90 << 11;
      $92 = $91 ^ -1;
      $93 = (($90) + ($92))|0;
      $94 = $93 >>> 16;
      $95 = $94 ^ $93;
      $96 = $95 & $75;
      $97 = (($32) + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($33) + ($index1$03<<2)|0);
      HEAP32[$99>>2] = $98;
      HEAP32[$97>>2] = $index1$03;
      $100 = (($34) + ($index1$03<<2)|0);
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       HEAP32[$100>>2] = $81;
      }
      $102 = HEAP32[$66>>2]|0;
      $103 = (($102) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$103>>2]|0;
      $104 = ($index1$0|0)==(-1);
      if ($104) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre = HEAP32[$70>>2]|0;
     $107 = $$pre;
    }
    $105 = (($bucket$06) + 1)|0;
    $106 = ($105>>>0)<($107>>>0);
    if ($106) {
     $117 = $107;$bucket$06 = $105;
    } else {
     $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $108 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$108);
 HEAP32[$this>>2] = $32;
 $109 = (($this) + 12|0);
 HEAP32[$109>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi15Z2D>>2] = $33;
 $110 = (($this) + 4|0);
 HEAP32[$110>>2] = $34;
 HEAP32[$18>>2] = $24;
 $111 = (($24) + -1)|0;
 $112 = ($111>>>0)>($19>>>0);
 if ($112) {
  $i$01$i = $19;
 } else {
  $115 = HEAP32[$15>>2]|0;
  $116 = (($33) + ($111<<2)|0);
  HEAP32[$116>>2] = $115;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $113 = (($i$01$i) + 1)|0;
  $114 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$114>>2] = $113;
  $exitcond$i = ($113|0)==($111|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 $115 = HEAP32[$15>>2]|0;
 $116 = (($33) + ($111<<2)|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_12PxConstraintES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre11 = 0, $$pre11$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $36 = $1 << 1;
  $$$i = $2 ? 16 : $36;
  $37 = ($1>>>0)<($$$i>>>0);
  if ($37) {
   __ZN5physx6shdfnd8internal8HashBaseIPNS_12PxConstraintES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $$pre11$pre = HEAP32[$33>>2]|0;
   $$pre11 = $$pre11$pre;$54 = $$pre;
  } else {
   $$pre11 = -1;$54 = $1;
  }
  $38 = HEAP32[$k>>2]|0;
  $39 = $38;
  $40 = $39 << 15;
  $41 = $40 ^ -1;
  $42 = (($39) + ($41))|0;
  $43 = $42 >>> 10;
  $44 = $43 ^ $42;
  $45 = ($44*9)|0;
  $46 = $45 >>> 6;
  $47 = $46 ^ $45;
  $48 = $47 << 11;
  $49 = $48 ^ -1;
  $50 = (($47) + ($49))|0;
  $51 = $50 >>> 16;
  $52 = $51 ^ $50;
  $53 = (($54) + -1)|0;
  $55 = $52 & $53;
  $59 = $$pre11;$h$1 = $55;
 } else {
  $59 = $34;$h$1 = $h$0;
 }
 $56 = (($this) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($59<<2)|0);
 $60 = HEAP32[$58>>2]|0;
 HEAP32[$33>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$58>>2] = $64;
 HEAP32[$63>>2] = $59;
 $65 = (($this) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $68 = (($this) + 32|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$68>>2] = $70;
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($59<<2)|0);
 $$0 = $73;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_12PxConstraintES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,422112,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
    $44 = $43 << 15;
    $45 = $44 ^ -1;
    $46 = (($43) + ($45))|0;
    $47 = $46 >>> 10;
    $48 = $47 ^ $46;
    $49 = ($48*9)|0;
    $50 = $49 >>> 6;
    $51 = $50 ^ $49;
    $52 = $51 << 11;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 16;
    $56 = $55 ^ $54;
    $57 = $56 & $39;
    $58 = (($32) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($33) + ($index$01<<2)|0);
    HEAP32[$60>>2] = $59;
    HEAP32[$58>>2] = $index$01;
    $61 = (($34) + ($index$01<<2)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     HEAP32[$61>>2] = $42;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre13 = (($this) + 20|0);
  $$pre14 = (($this) + 8|0);
  $$pre$phi15Z2D = $$pre14;$$pre$phiZ2D = $$pre13;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $117 = $71;$bucket$06 = 0;
   while(1) {
    $76 = HEAP32[$73>>2]|0;
    $77 = (($76) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$77>>2]|0;
    $78 = ($index1$02|0)==(-1);
    if ($78) {
     $107 = $117;
    } else {
     $index1$03 = $index1$02;
     while(1) {
      $79 = HEAP32[$74>>2]|0;
      $80 = (($79) + ($index1$03<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81;
      $83 = $82 << 15;
      $84 = $83 ^ -1;
      $85 = (($82) + ($84))|0;
      $86 = $85 >>> 10;
      $87 = $86 ^ $85;
      $88 = ($87*9)|0;
      $89 = $88 >>> 6;
      $90 = $89 ^ $88;
      $91 = $90 << 11;
      $92 = $91 ^ -1;
      $93 = (($90) + ($92))|0;
      $94 = $93 >>> 16;
      $95 = $94 ^ $93;
      $96 = $95 & $75;
      $97 = (($32) + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($33) + ($index1$03<<2)|0);
      HEAP32[$99>>2] = $98;
      HEAP32[$97>>2] = $index1$03;
      $100 = (($34) + ($index1$03<<2)|0);
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       HEAP32[$100>>2] = $81;
      }
      $102 = HEAP32[$66>>2]|0;
      $103 = (($102) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$103>>2]|0;
      $104 = ($index1$0|0)==(-1);
      if ($104) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre = HEAP32[$70>>2]|0;
     $107 = $$pre;
    }
    $105 = (($bucket$06) + 1)|0;
    $106 = ($105>>>0)<($107>>>0);
    if ($106) {
     $117 = $107;$bucket$06 = $105;
    } else {
     $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $108 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$108);
 HEAP32[$this>>2] = $32;
 $109 = (($this) + 12|0);
 HEAP32[$109>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi15Z2D>>2] = $33;
 $110 = (($this) + 4|0);
 HEAP32[$110>>2] = $34;
 HEAP32[$18>>2] = $24;
 $111 = (($24) + -1)|0;
 $112 = ($111>>>0)>($19>>>0);
 if ($112) {
  $i$01$i = $19;
 } else {
  $115 = HEAP32[$15>>2]|0;
  $116 = (($33) + ($111<<2)|0);
  HEAP32[$116>>2] = $115;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $113 = (($i$01$i) + 1)|0;
  $114 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$114>>2] = $113;
  $exitcond$i = ($113|0)==($111|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 $115 = HEAP32[$15>>2]|0;
 $116 = (($33) + ($111<<2)|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_14PxArticulationES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre11 = 0, $$pre11$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $36 = $1 << 1;
  $$$i = $2 ? 16 : $36;
  $37 = ($1>>>0)<($$$i>>>0);
  if ($37) {
   __ZN5physx6shdfnd8internal8HashBaseIPNS_14PxArticulationES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $$pre11$pre = HEAP32[$33>>2]|0;
   $$pre11 = $$pre11$pre;$54 = $$pre;
  } else {
   $$pre11 = -1;$54 = $1;
  }
  $38 = HEAP32[$k>>2]|0;
  $39 = $38;
  $40 = $39 << 15;
  $41 = $40 ^ -1;
  $42 = (($39) + ($41))|0;
  $43 = $42 >>> 10;
  $44 = $43 ^ $42;
  $45 = ($44*9)|0;
  $46 = $45 >>> 6;
  $47 = $46 ^ $45;
  $48 = $47 << 11;
  $49 = $48 ^ -1;
  $50 = (($47) + ($49))|0;
  $51 = $50 >>> 16;
  $52 = $51 ^ $50;
  $53 = (($54) + -1)|0;
  $55 = $52 & $53;
  $59 = $$pre11;$h$1 = $55;
 } else {
  $59 = $34;$h$1 = $h$0;
 }
 $56 = (($this) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($59<<2)|0);
 $60 = HEAP32[$58>>2]|0;
 HEAP32[$33>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$58>>2] = $64;
 HEAP32[$63>>2] = $59;
 $65 = (($this) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $68 = (($this) + 32|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$68>>2] = $70;
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($59<<2)|0);
 $$0 = $73;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_14PxArticulationES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,422112,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
    $44 = $43 << 15;
    $45 = $44 ^ -1;
    $46 = (($43) + ($45))|0;
    $47 = $46 >>> 10;
    $48 = $47 ^ $46;
    $49 = ($48*9)|0;
    $50 = $49 >>> 6;
    $51 = $50 ^ $49;
    $52 = $51 << 11;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 16;
    $56 = $55 ^ $54;
    $57 = $56 & $39;
    $58 = (($32) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($33) + ($index$01<<2)|0);
    HEAP32[$60>>2] = $59;
    HEAP32[$58>>2] = $index$01;
    $61 = (($34) + ($index$01<<2)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     HEAP32[$61>>2] = $42;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre13 = (($this) + 20|0);
  $$pre14 = (($this) + 8|0);
  $$pre$phi15Z2D = $$pre14;$$pre$phiZ2D = $$pre13;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $117 = $71;$bucket$06 = 0;
   while(1) {
    $76 = HEAP32[$73>>2]|0;
    $77 = (($76) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$77>>2]|0;
    $78 = ($index1$02|0)==(-1);
    if ($78) {
     $107 = $117;
    } else {
     $index1$03 = $index1$02;
     while(1) {
      $79 = HEAP32[$74>>2]|0;
      $80 = (($79) + ($index1$03<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81;
      $83 = $82 << 15;
      $84 = $83 ^ -1;
      $85 = (($82) + ($84))|0;
      $86 = $85 >>> 10;
      $87 = $86 ^ $85;
      $88 = ($87*9)|0;
      $89 = $88 >>> 6;
      $90 = $89 ^ $88;
      $91 = $90 << 11;
      $92 = $91 ^ -1;
      $93 = (($90) + ($92))|0;
      $94 = $93 >>> 16;
      $95 = $94 ^ $93;
      $96 = $95 & $75;
      $97 = (($32) + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($33) + ($index1$03<<2)|0);
      HEAP32[$99>>2] = $98;
      HEAP32[$97>>2] = $index1$03;
      $100 = (($34) + ($index1$03<<2)|0);
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       HEAP32[$100>>2] = $81;
      }
      $102 = HEAP32[$66>>2]|0;
      $103 = (($102) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$103>>2]|0;
      $104 = ($index1$0|0)==(-1);
      if ($104) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre = HEAP32[$70>>2]|0;
     $107 = $$pre;
    }
    $105 = (($bucket$06) + 1)|0;
    $106 = ($105>>>0)<($107>>>0);
    if ($106) {
     $117 = $107;$bucket$06 = $105;
    } else {
     $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $108 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$108);
 HEAP32[$this>>2] = $32;
 $109 = (($this) + 12|0);
 HEAP32[$109>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi15Z2D>>2] = $33;
 $110 = (($this) + 4|0);
 HEAP32[$110>>2] = $34;
 HEAP32[$18>>2] = $24;
 $111 = (($24) + -1)|0;
 $112 = ($111>>>0)>($19>>>0);
 if ($112) {
  $i$01$i = $19;
 } else {
  $115 = HEAP32[$15>>2]|0;
  $116 = (($33) + ($111<<2)|0);
  HEAP32[$116>>2] = $115;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $113 = (($i$01$i) + 1)|0;
  $114 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$114>>2] = $113;
  $exitcond$i = ($113|0)==($111|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 $115 = HEAP32[$15>>2]|0;
 $116 = (($33) + ($111<<2)|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb1EE6GetKeyES8_Lb1EE5eraseERKS4_($this,$k) {
 $this = $this|0;
 $k = $k|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $ptr$0$lcssa$i = 0, $ptr$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$k>>2]|0;
 $4 = $3;
 $5 = $4 << 15;
 $6 = $5 ^ -1;
 $7 = (($4) + ($6))|0;
 $8 = $7 >>> 10;
 $9 = $8 ^ $7;
 $10 = ($9*9)|0;
 $11 = $10 >>> 6;
 $12 = $11 ^ $10;
 $13 = $12 << 11;
 $14 = $13 ^ -1;
 $15 = (($12) + ($14))|0;
 $16 = $15 >>> 16;
 $17 = $16 ^ $15;
 $18 = (($1) + -1)|0;
 $19 = $17 & $18;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19<<2)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(-1);
 if ($24) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $25 = (($this) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 8|0);
 $$pr = $23;$ptr$02 = $22;
 while(1) {
  $28 = (($26) + ($$pr<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==($3|0);
  if ($30) {
   break;
  }
  $31 = HEAP32[$27>>2]|0;
  $32 = (($31) + ($$pr<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(-1);
  if ($34) {
   $$0 = 0;
   label = 14;
   break;
  } else {
   $$pr = $33;$ptr$02 = $32;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return ($$0|0);
 }
 $35 = ($$pr|0)==(-1);
 if ($35) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = HEAP32[$27>>2]|0;
 $37 = (($36) + ($$pr<<2)|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$ptr$02>>2] = $38;
 $39 = (($this) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + -1)|0;
 HEAP32[$39>>2] = $41;
 $42 = (($this) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 1)|0;
 HEAP32[$42>>2] = $44;
 $45 = ($$pr|0)==($41|0);
 if (!($45)) {
  $46 = ($28|0)==(0|0);
  if ($46) {
   $50 = $36;$55 = $3;$72 = $21;
  } else {
   $47 = (($26) + ($41<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$28>>2] = $48;
   $$pre$i = HEAP32[$25>>2]|0;
   $$pre = HEAP32[$27>>2]|0;
   $$phi$trans$insert = (($$pre$i) + ($$pr<<2)|0);
   $$pre4 = HEAP32[$$phi$trans$insert>>2]|0;
   $$pre5 = HEAP32[$20>>2]|0;
   $50 = $$pre;$55 = $$pre4;$72 = $$pre5;
  }
  $49 = (($50) + ($41<<2)|0);
  $51 = HEAP32[$49>>2]|0;
  $52 = (($50) + ($$pr<<2)|0);
  HEAP32[$52>>2] = $51;
  $53 = HEAP32[$0>>2]|0;
  $54 = $55;
  $56 = $54 << 15;
  $57 = $56 ^ -1;
  $58 = (($54) + ($57))|0;
  $59 = $58 >>> 10;
  $60 = $59 ^ $58;
  $61 = ($60*9)|0;
  $62 = $61 >>> 6;
  $63 = $62 ^ $61;
  $64 = $63 << 11;
  $65 = $64 ^ -1;
  $66 = (($63) + ($65))|0;
  $67 = $66 >>> 16;
  $68 = $67 ^ $66;
  $69 = (($53) + -1)|0;
  $70 = $68 & $69;
  $71 = (($72) + ($70<<2)|0);
  $73 = HEAP32[$71>>2]|0;
  $74 = HEAP32[$39>>2]|0;
  $75 = ($73|0)==($74|0);
  if ($75) {
   $ptr$0$lcssa$i = $71;
  } else {
   $77 = $73;
   while(1) {
    $76 = (($50) + ($77<<2)|0);
    $78 = HEAP32[$76>>2]|0;
    $79 = ($78|0)==($74|0);
    if ($79) {
     $ptr$0$lcssa$i = $76;
     break;
    } else {
     $77 = $78;
    }
   }
  }
  HEAP32[$ptr$0$lcssa$i>>2] = $$pr;
 }
 $80 = (($this) + 28|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + -1)|0;
 HEAP32[$80>>2] = $82;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_13NpClothFabricENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 422312 : 421040;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,421416,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_13NpClothFabricENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 422312 : 421040;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,421416,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb1EE6GetKeyES8_Lb1EE6createERKS4_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 16|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 if ($37) {
  $38 = $1 << 1;
  $$$i = $2 ? 16 : $38;
  $39 = ($1>>>0)<($$$i>>>0);
  if ($39) {
   __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb1EE6GetKeyES8_Lb1EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $56 = $$pre;
  } else {
   $56 = $1;
  }
  $40 = HEAP32[$k>>2]|0;
  $41 = $40;
  $42 = $41 << 15;
  $43 = $42 ^ -1;
  $44 = (($41) + ($43))|0;
  $45 = $44 >>> 10;
  $46 = $45 ^ $44;
  $47 = ($46*9)|0;
  $48 = $47 >>> 6;
  $49 = $48 ^ $47;
  $50 = $49 << 11;
  $51 = $50 ^ -1;
  $52 = (($49) + ($51))|0;
  $53 = $52 >>> 16;
  $54 = $53 ^ $52;
  $55 = (($56) + -1)|0;
  $57 = $54 & $55;
  $h$1 = $57;
 } else {
  $h$1 = $h$0;
 }
 $58 = (($this) + 28|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$58>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($this) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($59<<2)|0);
 HEAP32[$67>>2] = $64;
 HEAP32[$63>>2] = $59;
 $68 = HEAP32[$33>>2]|0;
 $69 = (($68) + 1)|0;
 HEAP32[$33>>2] = $69;
 $70 = (($this) + 32|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + 1)|0;
 HEAP32[$70>>2] = $72;
 $73 = (($this) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($74) + ($59<<2)|0);
 $$0 = $75;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxShapeES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb1EE6GetKeyES8_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $index$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = (($27) + ($23))|0;
 $29 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$28,422112,354)|0);
 $30 = (($29) + ($22)|0);
 $31 = (($29) + ($27)|0);
 _memset(($29|0),-1,($22|0))|0;
 $32 = (($this) + 36|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 $$pre = (($this) + 4|0);
 if (!($34)) {
  $35 = (($$0) + -1)|0;
  $index$01 = 0;
  while(1) {
   $36 = HEAP32[$$pre>>2]|0;
   $37 = (($36) + ($index$01<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38;
   $40 = $39 << 15;
   $41 = $40 ^ -1;
   $42 = (($39) + ($41))|0;
   $43 = $42 >>> 10;
   $44 = $43 ^ $42;
   $45 = ($44*9)|0;
   $46 = $45 >>> 6;
   $47 = $46 ^ $45;
   $48 = $47 << 11;
   $49 = $48 ^ -1;
   $50 = (($47) + ($49))|0;
   $51 = $50 >>> 16;
   $52 = $51 ^ $50;
   $53 = $52 & $35;
   $54 = (($29) + ($53<<2)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($30) + ($index$01<<2)|0);
   HEAP32[$56>>2] = $55;
   HEAP32[$54>>2] = $index$01;
   $57 = (($31) + ($index$01<<2)|0);
   $58 = ($57|0)==(0|0);
   if (!($58)) {
    HEAP32[$57>>2] = $38;
   }
   $59 = (($index$01) + 1)|0;
   $60 = HEAP32[$32>>2]|0;
   $61 = ($59>>>0)<($60>>>0);
   if ($61) {
    $index$01 = $59;
   } else {
    break;
   }
  }
 }
 $62 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$62);
 HEAP32[$this>>2] = $29;
 $63 = (($this) + 12|0);
 HEAP32[$63>>2] = $29;
 $64 = (($this) + 20|0);
 HEAP32[$64>>2] = $$0;
 $65 = (($this) + 8|0);
 HEAP32[$65>>2] = $30;
 HEAP32[$$pre>>2] = $31;
 HEAP32[$15>>2] = $21;
 $66 = (($this) + 28|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(-1);
 if (!($68)) {
  STACKTOP = sp;return;
 }
 HEAP32[$66>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre11 = 0, $$pre11$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $36 = $1 << 1;
  $$$i = $2 ? 16 : $36;
  $37 = ($1>>>0)<($$$i>>>0);
  if ($37) {
   __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $$pre11$pre = HEAP32[$33>>2]|0;
   $$pre11 = $$pre11$pre;$54 = $$pre;
  } else {
   $$pre11 = -1;$54 = $1;
  }
  $38 = HEAP32[$k>>2]|0;
  $39 = $38;
  $40 = $39 << 15;
  $41 = $40 ^ -1;
  $42 = (($39) + ($41))|0;
  $43 = $42 >>> 10;
  $44 = $43 ^ $42;
  $45 = ($44*9)|0;
  $46 = $45 >>> 6;
  $47 = $46 ^ $45;
  $48 = $47 << 11;
  $49 = $48 ^ -1;
  $50 = (($47) + ($49))|0;
  $51 = $50 >>> 16;
  $52 = $51 ^ $50;
  $53 = (($54) + -1)|0;
  $55 = $52 & $53;
  $59 = $$pre11;$h$1 = $55;
 } else {
  $59 = $34;$h$1 = $h$0;
 }
 $56 = (($this) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($59<<2)|0);
 $60 = HEAP32[$58>>2]|0;
 HEAP32[$33>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$58>>2] = $64;
 HEAP32[$63>>2] = $59;
 $65 = (($this) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $68 = (($this) + 32|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$68>>2] = $70;
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($59<<2)|0);
 $$0 = $73;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_7PxActorES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,422112,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
    $44 = $43 << 15;
    $45 = $44 ^ -1;
    $46 = (($43) + ($45))|0;
    $47 = $46 >>> 10;
    $48 = $47 ^ $46;
    $49 = ($48*9)|0;
    $50 = $49 >>> 6;
    $51 = $50 ^ $49;
    $52 = $51 << 11;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 16;
    $56 = $55 ^ $54;
    $57 = $56 & $39;
    $58 = (($32) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($33) + ($index$01<<2)|0);
    HEAP32[$60>>2] = $59;
    HEAP32[$58>>2] = $index$01;
    $61 = (($34) + ($index$01<<2)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     HEAP32[$61>>2] = $42;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre13 = (($this) + 20|0);
  $$pre14 = (($this) + 8|0);
  $$pre$phi15Z2D = $$pre14;$$pre$phiZ2D = $$pre13;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $117 = $71;$bucket$06 = 0;
   while(1) {
    $76 = HEAP32[$73>>2]|0;
    $77 = (($76) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$77>>2]|0;
    $78 = ($index1$02|0)==(-1);
    if ($78) {
     $107 = $117;
    } else {
     $index1$03 = $index1$02;
     while(1) {
      $79 = HEAP32[$74>>2]|0;
      $80 = (($79) + ($index1$03<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81;
      $83 = $82 << 15;
      $84 = $83 ^ -1;
      $85 = (($82) + ($84))|0;
      $86 = $85 >>> 10;
      $87 = $86 ^ $85;
      $88 = ($87*9)|0;
      $89 = $88 >>> 6;
      $90 = $89 ^ $88;
      $91 = $90 << 11;
      $92 = $91 ^ -1;
      $93 = (($90) + ($92))|0;
      $94 = $93 >>> 16;
      $95 = $94 ^ $93;
      $96 = $95 & $75;
      $97 = (($32) + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($33) + ($index1$03<<2)|0);
      HEAP32[$99>>2] = $98;
      HEAP32[$97>>2] = $index1$03;
      $100 = (($34) + ($index1$03<<2)|0);
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       HEAP32[$100>>2] = $81;
      }
      $102 = HEAP32[$66>>2]|0;
      $103 = (($102) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$103>>2]|0;
      $104 = ($index1$0|0)==(-1);
      if ($104) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre = HEAP32[$70>>2]|0;
     $107 = $$pre;
    }
    $105 = (($bucket$06) + 1)|0;
    $106 = ($105>>>0)<($107>>>0);
    if ($106) {
     $117 = $107;$bucket$06 = $105;
    } else {
     $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $108 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$108);
 HEAP32[$this>>2] = $32;
 $109 = (($this) + 12|0);
 HEAP32[$109>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi15Z2D>>2] = $33;
 $110 = (($this) + 4|0);
 HEAP32[$110>>2] = $34;
 HEAP32[$18>>2] = $24;
 $111 = (($24) + -1)|0;
 $112 = ($111>>>0)>($19>>>0);
 if ($112) {
  $i$01$i = $19;
 } else {
  $115 = HEAP32[$15>>2]|0;
  $116 = (($33) + ($111<<2)|0);
  HEAP32[$116>>2] = $115;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $113 = (($i$01$i) + 1)|0;
  $114 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$114>>2] = $113;
  $exitcond$i = ($113|0)==($111|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 $115 = HEAP32[$15>>2]|0;
 $116 = (($33) + ($111<<2)|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_7PxActorENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 422544 : 421040;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,421416,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_14PxArticulationENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 422656 : 421040;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,421416,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_11PxAggregateENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 422776 : 421040;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,421416,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_10PxMaterialES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,422112,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
    $44 = $43 << 15;
    $45 = $44 ^ -1;
    $46 = (($43) + ($45))|0;
    $47 = $46 >>> 10;
    $48 = $47 ^ $46;
    $49 = ($48*9)|0;
    $50 = $49 >>> 6;
    $51 = $50 ^ $49;
    $52 = $51 << 11;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 16;
    $56 = $55 ^ $54;
    $57 = $56 & $39;
    $58 = (($32) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($33) + ($index$01<<2)|0);
    HEAP32[$60>>2] = $59;
    HEAP32[$58>>2] = $index$01;
    $61 = (($34) + ($index$01<<2)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     HEAP32[$61>>2] = $42;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre13 = (($this) + 20|0);
  $$pre14 = (($this) + 8|0);
  $$pre$phi15Z2D = $$pre14;$$pre$phiZ2D = $$pre13;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $117 = $71;$bucket$06 = 0;
   while(1) {
    $76 = HEAP32[$73>>2]|0;
    $77 = (($76) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$77>>2]|0;
    $78 = ($index1$02|0)==(-1);
    if ($78) {
     $107 = $117;
    } else {
     $index1$03 = $index1$02;
     while(1) {
      $79 = HEAP32[$74>>2]|0;
      $80 = (($79) + ($index1$03<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81;
      $83 = $82 << 15;
      $84 = $83 ^ -1;
      $85 = (($82) + ($84))|0;
      $86 = $85 >>> 10;
      $87 = $86 ^ $85;
      $88 = ($87*9)|0;
      $89 = $88 >>> 6;
      $90 = $89 ^ $88;
      $91 = $90 << 11;
      $92 = $91 ^ -1;
      $93 = (($90) + ($92))|0;
      $94 = $93 >>> 16;
      $95 = $94 ^ $93;
      $96 = $95 & $75;
      $97 = (($32) + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($33) + ($index1$03<<2)|0);
      HEAP32[$99>>2] = $98;
      HEAP32[$97>>2] = $index1$03;
      $100 = (($34) + ($index1$03<<2)|0);
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       HEAP32[$100>>2] = $81;
      }
      $102 = HEAP32[$66>>2]|0;
      $103 = (($102) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$103>>2]|0;
      $104 = ($index1$0|0)==(-1);
      if ($104) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre = HEAP32[$70>>2]|0;
     $107 = $$pre;
    }
    $105 = (($bucket$06) + 1)|0;
    $106 = ($105>>>0)<($107>>>0);
    if ($106) {
     $117 = $107;$bucket$06 = $105;
    } else {
     $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $108 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$108);
 HEAP32[$this>>2] = $32;
 $109 = (($this) + 12|0);
 HEAP32[$109>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi15Z2D>>2] = $33;
 $110 = (($this) + 4|0);
 HEAP32[$110>>2] = $34;
 HEAP32[$18>>2] = $24;
 $111 = (($24) + -1)|0;
 $112 = ($111>>>0)>($19>>>0);
 if ($112) {
  $i$01$i = $19;
 } else {
  $115 = HEAP32[$15>>2]|0;
  $116 = (($33) + ($111<<2)|0);
  HEAP32[$116>>2] = $115;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $113 = (($i$01$i) + 1)|0;
  $114 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$114>>2] = $113;
  $exitcond$i = ($113|0)==($111|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 $115 = HEAP32[$15>>2]|0;
 $116 = (($33) + ($111<<2)|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_16NpConnectorArrayENS0_19ReflectionAllocatorIS2_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0;
 var $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_16NpConnectorArrayEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + (($31*48)|0)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     do {
      if ((label|0) == 16) {
       label = 0;
       $39 = (($tIt$02) + 44|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = $40 & 2147483647;
       $42 = ($41|0)!=(0);
       $43 = ($40|0)>(-1);
       $or$cond$i$i$i$i = $42 & $43;
       if ($or$cond$i$i$i$i) {
        $44 = (($tIt$02) + 36|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ($tIt$02|0)==($45|0);
        if ($46) {
         $47 = (($tIt$02) + 32|0);
         HEAP8[$47>>0] = 0;
         $freeIt$2 = $freeIt$11;
         break;
        }
        $48 = ($45|0)==(0|0);
        if ($48) {
         $freeIt$2 = $freeIt$11;
        } else {
         $49 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = (($50) + 12|0);
         $52 = HEAP32[$51>>2]|0;
         FUNCTION_TABLE_vii[$52 & 4095]($49,$45);
         $freeIt$2 = $freeIt$11;
        }
       } else {
        $freeIt$2 = $freeIt$11;
       }
      }
     } while(0);
     $53 = (($tIt$02) + 48|0);
     $54 = ($53|0)==($32|0);
     if ($54) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $53;
     }
    }
   }
   $55 = (($slabIt$05) + 4|0);
   $56 = ($55|0)==($27|0);
   if ($56) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $55;
   }
  }
 }
 $57 = HEAP32[$4>>2]|0;
 $58 = $57 & 2147483647;
 $notlhs = ($58|0)==(0);
 $notrhs = ($57|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $59 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $59;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $60 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($61) + 12|0);
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_vii[$63 & 4095]($60,$19);
 STACKTOP = sp;return;
}
function __ZN5physx10NpMaterialC2ERKNS_2Sc12MaterialCoreE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 8;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 HEAP32[$this>>2] = ((424456 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = ((424432 + 8|0));
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 1;
 HEAP32[$this>>2] = ((424144 + 8|0));
 HEAP32[$3>>2] = ((424144 + 108|0));
 $5 = (($this) + 32|0);
 ;HEAP32[$5+0>>2]=HEAP32[$desc+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$desc+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$desc+8>>2]|0;
 $6 = (($desc) + 12|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = (($this) + 44|0);
 HEAP16[$8>>1] = $7;
 $9 = (($this) + 46|0);
 $10 = (($desc) + 14|0);
 $11 = HEAPU8[$10>>0]|(HEAPU8[$10+1>>0]<<8);
 HEAP8[$9>>0]=$11&255;HEAP8[$9+1>>0]=$11>>8;
 $12 = (($this) + 48|0);
 $13 = (($desc) + 16|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $12;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 HEAP32[$12>>2] = $this;
 STACKTOP = sp;return;
}
function __ZN5physx10NpMaterialD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((424144 + 8|0));
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = ((424144 + 108|0));
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn12_N5physx10NpMaterialD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -12|0);
 HEAP32[$1>>2] = (((424144 + 8|0)));
 $2 = (($1) + 12|0);
 HEAP32[$2>>2] = (((424144 + 108|0)));
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx10NpMaterialD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((424144 + 8|0));
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = ((424144 + 108|0));
 STACKTOP = sp;return;
}
function __ZThn12_N5physx10NpMaterialD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -12|0);
 HEAP32[$0>>2] = (((424144 + 8|0)));
 $1 = (($0) + 12|0);
 HEAP32[$1>>2] = (((424144 + 108|0)));
 STACKTOP = sp;return;
}
function __ZN5physx10NpMaterial17resolveReferencesERNS_24PxDeserializationContextE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 48|0);
 HEAP32[$1>>2] = $this;
 $2 = HEAP32[424544>>2]|0;
 (__ZN5physx9NpPhysics11addMaterialEPNS_10NpMaterialE($2,$this)|0);
 STACKTOP = sp;return;
}
function __ZN5physx10NpMaterial14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23removeMaterialFromTableERNS_10NpMaterialE($2,$this);
 $3 = (($this) + 6|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 1;
 $6 = ($5<<16>>16)==(0);
 $7 = HEAP32[$this>>2]|0;
 if ($6) {
  $10 = (($7) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($this);
 } else {
  $8 = (($7) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 4095]($this);
 }
 $12 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($12,$this,$1,2);
 STACKTOP = sp;return;
}
function __ZThn12_N5physx10NpMaterial14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -12|0);
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23removeMaterialFromTableERNS_10NpMaterialE($3,$0);
 $4 = (($0) + 6|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 & 1;
 $7 = ($6<<16>>16)==(0);
 $8 = HEAP32[$0>>2]|0;
 if ($7) {
  $11 = (($8) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($0);
 } else {
  $9 = (($8) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 4095]($0);
 }
 $13 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($13,$0,$2,2);
 STACKTOP = sp;return;
}
function __ZN5physx10NpMaterial7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (($this) + 6|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & -3;
 HEAP16[$3>>1] = $5;
 $6 = (($this) + 12|0);
 $7 = (($this) + 16|0);
 $8 = (__ZN5physx6shdfnd15atomicDecrementEPVi($7)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vi[$12 & 4095]($6);
 STACKTOP = sp;return;
}
function __ZNK5physx10NpMaterial17getReferenceCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx10NpMaterial18setDynamicFrictionEf($this,$x) {
 $this = $this|0;
 $x = Math_fround($x);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 HEAPF32[$0>>2] = $x;
 $1 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics14updateMaterialERNS_10NpMaterialE($1,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx10NpMaterial18getDynamicFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx10NpMaterial17setStaticFrictionEf($this,$x) {
 $this = $this|0;
 $x = Math_fround($x);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 HEAPF32[$0>>2] = $x;
 $1 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics14updateMaterialERNS_10NpMaterialE($1,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx10NpMaterial17getStaticFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx10NpMaterial14setRestitutionEf($this,$x) {
 $this = $this|0;
 $x = Math_fround($x);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = $x < Math_fround(0.0);
 $1 = $x > Math_fround(1.0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  $3 = +$x;
  HEAPF64[tempDoublePtr>>3]=$3;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,4,424264,136,424336,$vararg_buffer);
 }
 $4 = (($this) + 40|0);
 HEAPF32[$4>>2] = $x;
 $5 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics14updateMaterialERNS_10NpMaterialE($5,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx10NpMaterial14getRestitutionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx10NpMaterial7setFlagENS_14PxMaterialFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 if ($value) {
  $1 = HEAP16[$0>>1]|0;
  $2 = $1&65535;
  $3 = $2 | $flag;
  $4 = $3&65535;
  HEAP16[$0>>1] = $4;
 } else {
  $5 = $flag ^ 65535;
  $6 = $5&65535;
  $7 = HEAP16[$0>>1]|0;
  $8 = $7 & $6;
  HEAP16[$0>>1] = $8;
 }
 $9 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics14updateMaterialERNS_10NpMaterialE($9,$this);
 STACKTOP = sp;return;
}
function __ZN5physx10NpMaterial8setFlagsENS_7PxFlagsINS_14PxMaterialFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$inFlags>>1]|0;
 $1 = (($this) + 44|0);
 HEAP16[$1>>1] = $0;
 $2 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics14updateMaterialERNS_10NpMaterialE($2,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx10NpMaterial8getFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP16[$0>>1]|0;
 HEAP16[$agg$result>>1] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx10NpMaterial22setFrictionCombineModeENS_13PxCombineMode4EnumE($this,$x) {
 $this = $this|0;
 $x = $x|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 46|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 & 15;
 $4 = $x << 4;
 $5 = $3 | $4;
 $6 = $5&255;
 HEAP8[$0>>0] = $6;
 $7 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics14updateMaterialERNS_10NpMaterialE($7,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx10NpMaterial22getFrictionCombineModeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 46|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 >>> 4;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx10NpMaterial25setRestitutionCombineModeENS_13PxCombineMode4EnumE($this,$x) {
 $this = $this|0;
 $x = $x|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 46|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 & 240;
 $4 = $3 | $x;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics14updateMaterialERNS_10NpMaterialE($6,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx10NpMaterial25getRestitutionCombineModeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 46|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 & 15;
 STACKTOP = sp;return ($3|0);
}
function __ZNK5physx10PxMaterial19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (424408|0);
}
function __ZNK5physx10PxMaterial8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(424408,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,424424)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx10NpMaterial8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12RefCountableD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12RefCountableD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12RefCountable14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN5physx10PxMaterialD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx10PxMaterialD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm19CmEventNameProviderD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysicsC2ERKNS_17PxTolerancesScaleEbPNS_20PxProfileZoneManagerE($this,$scale,$trackOutstandingAllocations,$profileZoneManager) {
 $this = $this|0;
 $scale = $scale|0;
 $trackOutstandingAllocations = $trackOutstandingAllocations|0;
 $profileZoneManager = $profileZoneManager|0;
 var $$$i$i$i$i = 0, $$$i$i$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((424568 + 8|0));
 $1 = (($this) + 4|0);
 $2 = (($this) + 20|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 __ZN5physx2Sc7PhysicsC2ERKNS_17PxTolerancesScaleE($2,$scale);
 $3 = (($this) + 36|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 $4 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,512,426048,100)|0);
 $5 = (($this) + 52|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 56|0);
 HEAP32[$6>>2] = 128;
 _memset(($4|0),0,512)|0;
 $7 = (($this) + 60|0);
 HEAP32[$7>>2] = ((426152 + 8|0));
 $8 = (($this) + 64|0);
 $9 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  HEAP32[$8>>2] = 0;
 } else {
  $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (__Z15PxGetFoundationv()|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
  $$$i$i$i$i2 = $20 ? 425920 : 425176;
  $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$10,$$$i$i$i$i2,425840,111)|0);
  HEAP32[$8>>2] = $21;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($21);
  }
 }
 $23 = (($this) + 68|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 72|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 76|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 80|0);
 HEAP32[$26>>2] = ((426128 + 8|0));
 $27 = (($this) + 84|0);
 HEAP8[$27>>0] = 0;
 $28 = (($this) + 88|0);
 $29 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if ($31) {
  HEAP32[$28>>2] = 0;
 } else {
  $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (__Z15PxGetFoundationv()|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 24|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (FUNCTION_TABLE_ii[$39 & 4095]($36)|0);
  $$$i$i$i$i = $40 ? 425920 : 425176;
  $41 = (FUNCTION_TABLE_iiiiii[$35 & 255]($32,$30,$$$i$i$i$i,425840,111)|0);
  HEAP32[$28>>2] = $41;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($41);
  }
 }
 $43 = HEAP32[$this>>2]|0;
 $44 = (($43) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (FUNCTION_TABLE_ii[$45 & 4095]($this)|0);
 $47 = (__ZN5physx13PxProfileZone17createProfileZoneEPNS_12PxFoundationEPKcRNS_21PxProfileNameProviderEj($46,424760,424560,16384)|0);
 $48 = (($this) + 92|0);
 HEAP32[$48>>2] = $47;
 $49 = ($profileZoneManager|0)==(0|0);
 if ($49) {
  $53 = (($this) + 96|0);
  HEAP32[$53>>2] = $profileZoneManager;
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$profileZoneManager>>2]|0;
 $51 = (($50) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095]($profileZoneManager,$47);
 $53 = (($this) + 96|0);
 HEAP32[$53>>2] = $profileZoneManager;
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysicsD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx9NpPhysicsD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysicsD2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $exitcond = 0, $i$06 = 0;
 var $i1$04 = 0, $or$cond$i$i = 0, $or$cond$i$i$i$i$i$i = 0, $or$cond$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((424568 + 8|0));
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==(0);
 if (!($5)) {
  $i$06 = 0;
  while(1) {
   $6 = (($4) + ($i$06<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    $9 = HEAP32[$7>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    FUNCTION_TABLE_vi[$11 & 4095]($7);
   }
   HEAP32[$6>>2] = 0;
   $12 = (($i$06) + 1)|0;
   $exitcond = ($12|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $i$06 = $12;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 $13 = (($this) + 36|0);
 __ZN5physx17NpMaterialManager16releaseMaterialsEv($13);
 $14 = (($this) + 92|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $17 = HEAP32[$15>>2]|0;
  $18 = (($17) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vi[$19 & 4095]($15);
 }
 HEAP32[$14>>2] = 0;
 $20 = (($this) + 96|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 68|0);
 $22 = (($this) + 72|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $96 = $23;$i1$04 = 0;
  while(1) {
   $25 = HEAP32[$21>>2]|0;
   $26 = (($25) + ($i1$04<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $33 = $96;
   } else {
    $29 = HEAP32[$27>>2]|0;
    $30 = ($29|0)==(0|0);
    if (!($30)) {
     __ZN5physx6shdfnd9Allocator10deallocateEPv($27,$29);
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$27);
    $$pre = HEAP32[$22>>2]|0;
    $33 = $$pre;
   }
   $31 = (($i1$04) + 1)|0;
   $32 = ($31>>>0)<($33>>>0);
   if ($32) {
    $96 = $33;$i1$04 = $31;
   } else {
    break;
   }
  }
 }
 HEAP32[$22>>2] = 0;
 $34 = (($this) + 16|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  $37 = HEAP32[$35>>2]|0;
  __ZN5physx6shdfnd9MutexImplD2Ev($37);
  $38 = HEAP32[$35>>2]|0;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   $40 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   FUNCTION_TABLE_vii[$43 & 4095]($40,$38);
  }
  $44 = HEAP32[$34>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$44);
  HEAP32[$34>>2] = 0;
 }
 $45 = (($this) + 88|0);
 $46 = HEAP32[$45>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($46);
 $47 = HEAP32[$45>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + 12|0);
  $52 = HEAP32[$51>>2]|0;
  FUNCTION_TABLE_vii[$52 & 4095]($49,$47);
 }
 $53 = (($this) + 76|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 & 2147483647;
 $56 = ($55|0)!=(0);
 $57 = ($54|0)>(-1);
 $or$cond$i$i2 = $56 & $57;
 if ($or$cond$i$i2) {
  $58 = HEAP32[$21>>2]|0;
  $59 = ($58|0)==(0|0);
  if (!($59)) {
   $60 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($61) + 12|0);
   $63 = HEAP32[$62>>2]|0;
   FUNCTION_TABLE_vii[$63 & 4095]($60,$58);
  }
 }
 $64 = (($this) + 64|0);
 $65 = HEAP32[$64>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($65);
 $66 = HEAP32[$64>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($69) + 12|0);
  $71 = HEAP32[$70>>2]|0;
  FUNCTION_TABLE_vii[$71 & 4095]($68,$66);
 }
 $72 = (($this) + 48|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73 & 2147483647;
 $75 = ($74|0)!=(0);
 $76 = ($73|0)>(-1);
 $or$cond$i$i$i$i$i$i = $75 & $76;
 if ($or$cond$i$i$i$i$i$i) {
  $77 = (($this) + 40|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0|0);
  if (!($79)) {
   $80 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($81) + 12|0);
   $83 = HEAP32[$82>>2]|0;
   FUNCTION_TABLE_vii[$83 & 4095]($80,$78);
  }
 }
 $84 = (($this) + 20|0);
 __ZN5physx2Sc7PhysicsD2Ev($84);
 $85 = (($this) + 12|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = $86 & 2147483647;
 $88 = ($87|0)!=(0);
 $89 = ($86|0)>(-1);
 $or$cond$i$i = $88 & $89;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $90 = HEAP32[$3>>2]|0;
 $91 = ($90|0)==(0|0);
 if ($91) {
  STACKTOP = sp;return;
 }
 $92 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($93) + 12|0);
 $95 = HEAP32[$94>>2]|0;
 FUNCTION_TABLE_vii[$95 & 4095]($92,$90);
 STACKTOP = sp;return;
}
function __ZN5physx17NpMaterialManager16releaseMaterialsEv($this) {
 $this = $this|0;
 var $$lcssa = 0, $$pre = 0, $$pre$i$i = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 if ($4) {
  $$lcssa = $6;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$$lcssa);
  STACKTOP = sp;return;
 }
 $7 = (($this) + 4|0);
 $8 = (($this) + 12|0);
 $9 = (($this) + 8|0);
 $11 = $6;$38 = $3;$i$01 = 0;
 while(1) {
  $10 = (($11) + ($i$01<<2)|0);
  $12 = HEAP32[$10>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $37 = $38;$39 = $11;
  } else {
   $14 = (($12) + 52|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$0>>2] = $15;
   $16 = HEAP32[$this>>2]|0;
   $17 = (($16) + -1)|0;
   $18 = ($17|0)==($15|0);
   do {
    if ($18) {
     HEAP32[$this>>2] = $15;
     $29 = $11;
    } else {
     $19 = HEAP32[$8>>2]|0;
     $20 = $19 & 2147483647;
     $21 = HEAP32[$9>>2]|0;
     $22 = ($20>>>0)>($21>>>0);
     if (!($22)) {
      (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($7,$0)|0);
      $$pre4 = HEAP32[$5>>2]|0;
      $29 = $$pre4;
      break;
     }
     $23 = HEAP32[$7>>2]|0;
     $24 = (($23) + ($21<<2)|0);
     $25 = ($24|0)==(0|0);
     if ($25) {
      $27 = $21;
     } else {
      HEAP32[$24>>2] = $15;
      $$pre$i$i = HEAP32[$9>>2]|0;
      $27 = $$pre$i$i;
     }
     $26 = (($27) + 1)|0;
     HEAP32[$9>>2] = $26;
     $29 = $11;
    }
   } while(0);
   $28 = (($29) + ($i$01<<2)|0);
   $30 = HEAP32[$28>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[$31>>2]|0;
   FUNCTION_TABLE_vi[$32 & 4095]($30);
   $33 = HEAP32[$5>>2]|0;
   $34 = (($33) + ($i$01<<2)|0);
   HEAP32[$34>>2] = 0;
   $$pre = HEAP32[$2>>2]|0;
   $$pre3 = HEAP32[$5>>2]|0;
   $37 = $$pre;$39 = $$pre3;
  }
  $35 = (($i$01) + 1)|0;
  $36 = ($35>>>0)<($37>>>0);
  if ($36) {
   $11 = $39;$38 = $37;$i$01 = $35;
  } else {
   $$lcssa = $39;
   break;
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$$lcssa);
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics20MeshDeletionListenerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx26NpPhysicsInsertionCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics14createInstanceEjRNS_12PxFoundationERKNS_17PxTolerancesScaleEbPNS_20PxProfileZoneManagerE($version,$foundation,$scale,$trackOutstandingAllocations,$profileZoneManager) {
 $version = $version|0;
 $foundation = $foundation|0;
 $scale = $scale|0;
 $trackOutstandingAllocations = $trackOutstandingAllocations|0;
 $profileZoneManager = $profileZoneManager|0;
 var $$$i$i$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0);
 var $9 = 0, $buffer = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $vararg_buffer = sp;
 $buffer = sp + 8|0;
 $0 = ($version|0)==(50528512);
 if (!($0)) {
  HEAP32[$vararg_buffer>>2] = 50528512;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $version;
  (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,424776,$vararg_buffer)|0);
  $1 = HEAP32[$foundation>>2]|0;
  $2 = (($1) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (FUNCTION_TABLE_ii[$3 & 4095]($foundation)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viiiii[$7 & 255]($4,4,$buffer,424840,176);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = Math_fround(HEAPF32[$scale>>2]);
 $9 = $8 > Math_fround(0.0);
 if ($9) {
  $10 = (($scale) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = $11 > Math_fround(0.0);
  if ($12) {
   $20 = HEAP32[424552>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    __ZN5physx6shdfnd10Foundation11incRefCountEv();
    $22 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (__Z15PxGetFoundationv()|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 24|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (FUNCTION_TABLE_ii[$29 & 4095]($26)|0);
    $$$i$i$i = $30 ? 425728 : 425176;
    $31 = (FUNCTION_TABLE_iiiiii[$25 & 255]($22,100,$$$i$i$i,424840,193)|0);
    __ZN5physx9NpPhysicsC2ERKNS_17PxTolerancesScaleEbPNS_20PxProfileZoneManagerE($31,$scale,$trackOutstandingAllocations,$profileZoneManager);
    HEAP32[424544>>2] = $31;
    __ZN5physx9NpFactory14createInstanceEv();
    $32 = HEAP32[420520>>2]|0;
    $33 = HEAP32[424544>>2]|0;
    $34 = (($33) + 80|0);
    __ZN5physx13GuMeshFactory18addFactoryListenerERNS_21GuMeshFactoryListenerE($32,$34);
    $$pre = HEAP32[424552>>2]|0;
    $36 = $$pre;
   } else {
    $36 = $20;
   }
   $35 = (($36) + 1)|0;
   HEAP32[424552>>2] = $35;
   $37 = HEAP32[424544>>2]|0;
   $$0 = $37;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $13 = HEAP32[$foundation>>2]|0;
 $14 = (($13) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($foundation)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_viiiii[$19 & 255]($16,4,424912,424840,182);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpPhysics7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424552>>2]|0;
 $1 = (($0) + -1)|0;
 HEAP32[424552>>2] = $1;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN5physx9NpFactory15destroyInstanceEv();
 $3 = HEAP32[424544>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 4095]($3);
 }
 HEAP32[424544>>2] = 0;
 __ZN5physx6shdfnd10Foundation11decRefCountEv();
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics11createSceneERKNS_11PxSceneDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$$i$i$i = 0, $$0 = 0, $$phi$trans$insert8$i$i = 0, $$pre = 0, $$pre9$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $npScene = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer3 = sp;
 $npScene = sp + 4|0;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__Z15PxGetFoundationv()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $$$i$i$i = $10 ? 425624 : 425176;
 $11 = (FUNCTION_TABLE_iiiiii[$5 & 255]($2,3856,$$$i$i$i,424840,234)|0);
 __ZN5physx7NpSceneC2ERKNS_11PxSceneDescE($11,$desc);
 HEAP32[$npScene>>2] = $11;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($13,32,424840,237,424928,$vararg_buffer3);
  $$0 = 0;
  $55 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($55);
  STACKTOP = sp;return ($$0|0);
 }
 $14 = HEAP32[$11>>2]|0;
 $15 = (($14) + 444|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($11)|0);
 $18 = ($17|0)==(0|0);
 if ($18) {
  $19 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($19,32,424840,242,424952,$vararg_buffer3);
  $$0 = 0;
  $55 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($55);
  STACKTOP = sp;return ($$0|0);
 }
 (__ZN5physx7NpScene12loadFromDescERKNS_11PxSceneDescE($11,$desc)|0);
 $20 = (($this) + 56|0);
 $$phi$trans$insert8$i$i = (($this) + 52|0);
 $23 = 0;
 while(1) {
  $21 = HEAP32[$20>>2]|0;
  $22 = ($23>>>0)<($21>>>0);
  L11: do {
   if ($22) {
    $$pre9$i$i = HEAP32[$$phi$trans$insert8$i$i>>2]|0;
    $25 = $23;
    while(1) {
     $24 = (($$pre9$i$i) + ($25<<2)|0);
     $26 = HEAP32[$24>>2]|0;
     $27 = ($26|0)==(0|0);
     if (!($27)) {
      $31 = $25;
      break L11;
     }
     $28 = (($25) + 1)|0;
     $29 = ($28>>>0)<($21>>>0);
     if ($29) {
      $25 = $28;
     } else {
      $31 = $28;
      break;
     }
    }
   } else {
    $31 = $23;
   }
  } while(0);
  $30 = ($31>>>0)<($21>>>0);
  if (!($30)) {
   label = 12;
   break;
  }
  $32 = (($31) + 1)|0;
  $33 = HEAP32[$$phi$trans$insert8$i$i>>2]|0;
  $34 = (($33) + ($31<<2)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (__ZN5physx7NpScene11addMaterialERNS_10NpMaterialE($11,$35)|0);
  if ($36) {
   $23 = $32;
  } else {
   break;
  }
 }
 if ((label|0) == 12) {
  $37 = (($11) + 32|0);
  $38 = (__ZNK5physx2Sc5Scene7isValidEv($37)|0);
  if ($38) {
   $44 = (($this) + 4|0);
   $45 = (($this) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = $46 & 2147483647;
   $48 = (($this) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($47>>>0)>($49>>>0);
   if ($50) {
    $51 = HEAP32[$44>>2]|0;
    $52 = (($51) + ($49<<2)|0);
    $53 = ($52|0)==(0|0);
    if (!($53)) {
     HEAP32[$52>>2] = $11;
    }
    $54 = (($49) + 1)|0;
    HEAP32[$48>>2] = $54;
    $56 = $11;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_7NpSceneENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($44,$npScene)|0);
    $$pre = HEAP32[$npScene>>2]|0;
    $56 = $$pre;
   }
   $$0 = $56;
   $55 = HEAP32[$0>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($55);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $39 = ($11|0)==(0|0);
 if (!($39)) {
  $40 = HEAP32[$11>>2]|0;
  $41 = (($40) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  FUNCTION_TABLE_vi[$42 & 4095]($11);
 }
 $43 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($43,16,424840,274,424928,$vararg_buffer3);
 $$0 = 0;
 $55 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($55);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9NpPhysics20releaseSceneInternalERNS_7PxSceneE($this,$scene) {
 $this = $this|0;
 $scene = $scene|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = (($this) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $i$04 = 0;
   while(1) {
    $9 = (($6) + ($i$04<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($scene|0);
    $8 = (($i$04) + 1)|0;
    if ($11) {
     break;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $i$04 = $8;
    } else {
     break L1;
    }
   }
   $12 = (($3) + -1)|0;
   HEAP32[$2>>2] = $12;
   $13 = (($6) + ($12<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$9>>2] = $14;
   $15 = ($scene|0)==(0|0);
   if (!($15)) {
    $16 = HEAP32[$scene>>2]|0;
    $17 = (($16) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    FUNCTION_TABLE_vi[$18 & 4095]($scene);
   }
  }
 } while(0);
 $19 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($19);
 STACKTOP = sp;return;
}
function __ZNK5physx9NpPhysics11getNbScenesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($4);
 STACKTOP = sp;return ($3|0);
}
function __ZNK5physx9NpPhysics9getScenesEPPNS_7PxSceneEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) - ($startIndex))|0;
 $5 = ($4|0)<(0);
 $6 = $5 ? 0 : $4;
 $7 = ($6>>>0)<($bufferSize>>>0);
 $8 = $7 ? $6 : $bufferSize;
 $9 = ($8|0)==(0);
 if ($9) {
  $22 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
  STACKTOP = sp;return ($8|0);
 }
 $10 = (($this) + 4|0);
 $11 = $bufferSize ^ -1;
 $12 = ($4|0)>(0);
 $$op = $4 ^ -1;
 $13 = $12 ? $$op : -1;
 $14 = ($13>>>0)<($11>>>0);
 $umax = $14 ? $11 : $13;
 $15 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $16 = (($i$01) + ($startIndex))|0;
  $17 = HEAP32[$10>>2]|0;
  $18 = (($17) + ($16<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($userBuffer) + ($i$01<<2)|0);
  HEAP32[$20>>2] = $19;
  $21 = (($i$01) + 1)|0;
  $exitcond = ($21|0)==($15|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $21;
  }
 }
 $22 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx9NpPhysics17createRigidStaticERKNS_11PxTransformE($this,$globalPose) {
 $this = $this|0;
 $globalPose = $globalPose|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = HEAP32[420520>>2]|0;
 $2 = Math_fround(HEAPF32[$globalPose>>2]);
 $3 = Math_fround($2 * $2);
 $4 = (($globalPose) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $5);
 $7 = Math_fround($3 + $6);
 $8 = (($globalPose) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($globalPose) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (Math_fround(Math_sqrt((Math_fround($15)))));
 $17 = Math_fround(Math_fround(1.0) / $16);
 $18 = Math_fround($2 * $17);
 $19 = Math_fround($5 * $17);
 $20 = Math_fround($9 * $17);
 $21 = Math_fround($13 * $17);
 HEAPF32[$0>>2] = $18;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($0) + 16|0);
 $26 = (($globalPose) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($0) + 20|0);
 $29 = (($globalPose) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($0) + 24|0);
 $32 = (($globalPose) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (__ZN5physx9NpFactory17createRigidStaticERKNS_11PxTransformE($1,$0)|0);
 STACKTOP = sp;return ($34|0);
}
function __ZN5physx9NpPhysics11createShapeERKNS_10PxGeometryEPKPNS_10PxMaterialEtbNS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$geometry,$materials,$materialCount,$isExclusive,$shapeFlags) {
 $this = $this|0;
 $geometry = $geometry|0;
 $materials = $materials|0;
 $materialCount = $materialCount|0;
 $isExclusive = $isExclusive|0;
 $shapeFlags = $shapeFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[420520>>2]|0;
 $2 = HEAP8[$shapeFlags>>0]|0;
 HEAP8[$0>>0] = $2;
 $3 = (__ZN5physx9NpFactory11createShapeERKNS_10PxGeometryENS_7PxFlagsINS_11PxShapeFlag4EnumEhEEPKPNS_10PxMaterialEtb($1,$geometry,$0,$materials,$materialCount,$isExclusive)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNK5physx9NpPhysics11getNbShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx9NpFactory11getNbShapesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics9getShapesEPPNS_7PxShapeEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx9NpFactory9getShapesEPPNS_7PxShapeEjj($0,$userBuffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics18createRigidDynamicERKNS_11PxTransformE($this,$globalPose) {
 $this = $this|0;
 $globalPose = $globalPose|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = HEAP32[420520>>2]|0;
 $2 = Math_fround(HEAPF32[$globalPose>>2]);
 $3 = Math_fround($2 * $2);
 $4 = (($globalPose) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $5);
 $7 = Math_fround($3 + $6);
 $8 = (($globalPose) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($globalPose) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (Math_fround(Math_sqrt((Math_fround($15)))));
 $17 = Math_fround(Math_fround(1.0) / $16);
 $18 = Math_fround($2 * $17);
 $19 = Math_fround($5 * $17);
 $20 = Math_fround($9 * $17);
 $21 = Math_fround($13 * $17);
 HEAPF32[$0>>2] = $18;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($0) + 16|0);
 $26 = (($globalPose) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($0) + 20|0);
 $29 = (($globalPose) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($0) + 24|0);
 $32 = (($globalPose) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (__ZN5physx9NpFactory18createRigidDynamicERKNS_11PxTransformE($1,$0)|0);
 STACKTOP = sp;return ($34|0);
}
function __ZN5physx9NpPhysics16createConstraintEPNS_12PxRigidActorES2_RNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableEj($this,$actor0,$actor1,$connector,$shaders,$dataSize) {
 $this = $this|0;
 $actor0 = $actor0|0;
 $actor1 = $actor1|0;
 $connector = $connector|0;
 $shaders = $shaders|0;
 $dataSize = $dataSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory16createConstraintEPNS_12PxRigidActorES2_RNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableEj($0,$actor0,$actor1,$connector,$shaders,$dataSize)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics18createArticulationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory18createArticulationEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics15createAggregateEjb($this,$maxSize,$selfCollisionEnabled) {
 $this = $this|0;
 $maxSize = $maxSize|0;
 $selfCollisionEnabled = $selfCollisionEnabled|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory15createAggregateEjb($0,$maxSize,$selfCollisionEnabled)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics20createParticleSystemEjb($this,$maxParticles,$perParticleRestOffset) {
 $this = $this|0;
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory20createParticleSystemEjb($0,$maxParticles,$perParticleRestOffset)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics19createParticleFluidEjb($this,$maxParticles,$perParticleRestOffset) {
 $this = $this|0;
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory19createParticleFluidEjb($0,$maxParticles,$perParticleRestOffset)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics11createClothERKNS_11PxTransformERNS_13PxClothFabricEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($this,$globalPose,$fabric,$particles,$flags) {
 $this = $this|0;
 $globalPose = $globalPose|0;
 $fabric = $fabric|0;
 $particles = $particles|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = sp + 28|0;
 $2 = HEAP32[420520>>2]|0;
 $3 = Math_fround(HEAPF32[$globalPose>>2]);
 $4 = Math_fround($3 * $3);
 $5 = (($globalPose) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $6);
 $8 = Math_fround($4 + $7);
 $9 = (($globalPose) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $10);
 $12 = Math_fround($8 + $11);
 $13 = (($globalPose) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (Math_fround(Math_sqrt((Math_fround($16)))));
 $18 = Math_fround(Math_fround(1.0) / $17);
 $19 = Math_fround($3 * $18);
 $20 = Math_fround($6 * $18);
 $21 = Math_fround($10 * $18);
 $22 = Math_fround($14 * $18);
 HEAPF32[$0>>2] = $19;
 $23 = (($0) + 4|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($0) + 8|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($0) + 12|0);
 HEAPF32[$25>>2] = $22;
 $26 = (($0) + 16|0);
 $27 = (($globalPose) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$26>>2] = $28;
 $29 = (($0) + 20|0);
 $30 = (($globalPose) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$29>>2] = $31;
 $32 = (($0) + 24|0);
 $33 = (($globalPose) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$32>>2] = $34;
 $35 = HEAP16[$flags>>1]|0;
 HEAP16[$1>>1] = $35;
 $36 = (__ZN5physx9NpFactory11createClothERKNS_11PxTransformERNS_13PxClothFabricEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($2,$0,$fabric,$particles,$1)|0);
 STACKTOP = sp;return ($36|0);
}
function __ZN5physx9NpPhysics11addMaterialEPNS_10NpMaterialE($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $$0 = 0, $$0$i$i = 0, $$1 = 0, $$lcssa1$i = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond$i = 0, $i$01 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = ($m|0)==(0|0);
 if ($2) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $3 = (($this) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $13 = (($this) + 36|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 1)|0;
  HEAP32[$13>>2] = $15;
  $$0$i$i = $14;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($this) + 40|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  HEAP32[$5>>2] = $8;
  $$0$i$i = $12;
 }
 $16 = (($this) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($$0$i$i>>>0)<($17>>>0);
 do {
  if ($18) {
   $$phi$trans$insert = (($this) + 52|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $36 = $$pre;
   label = 11;
  } else {
   $19 = ($17>>>0)<(65535);
   if (!($19)) {
    $51 = HEAP32[$m>>2]|0;
    $52 = HEAP32[$51>>2]|0;
    FUNCTION_TABLE_vi[$52 & 4095]($m);
    $$0 = 0;
    break;
   }
   $20 = $17 << 1;
   HEAP32[$16>>2] = $20;
   $21 = $17 << 3;
   $22 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$21,426048,189)|0);
   $23 = HEAP32[$16>>2]|0;
   $24 = $23 << 2;
   _memset(($22|0),0,($24|0))|0;
   $25 = ($17|0)==(0);
   $26 = (($this) + 52|0);
   $27 = HEAP32[$26>>2]|0;
   if ($25) {
    $$lcssa1$i = $27;
   } else {
    $29 = $27;$i$02$i = 0;
    while(1) {
     $28 = (($29) + ($i$02$i<<2)|0);
     $30 = HEAP32[$28>>2]|0;
     $31 = (($22) + ($i$02$i<<2)|0);
     HEAP32[$31>>2] = $30;
     $32 = (($i$02$i) + 1)|0;
     $33 = HEAP32[$26>>2]|0;
     $exitcond$i = ($32|0)==($17|0);
     if ($exitcond$i) {
      $$lcssa1$i = $33;
      break;
     } else {
      $29 = $33;$i$02$i = $32;
     }
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$$lcssa1$i);
   HEAP32[$26>>2] = $22;
   $36 = $22;
   label = 11;
  }
 } while(0);
 if ((label|0) == 11) {
  $34 = (($this) + 52|0);
  $35 = (($36) + ($$0$i$i<<2)|0);
  HEAP32[$35>>2] = $m;
  $37 = HEAP32[$34>>2]|0;
  $38 = (($37) + ($$0$i$i<<2)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 52|0);
  HEAP32[$40>>2] = $$0$i$i;
  $41 = (($this) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0);
  if ($43) {
   $$0 = $m;
  } else {
   $44 = (($this) + 4|0);
   $i$01 = 0;
   while(1) {
    $45 = HEAP32[$44>>2]|0;
    $46 = (($45) + ($i$01<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    (__ZN5physx7NpScene11addMaterialERNS_10NpMaterialE($47,$m)|0);
    $48 = (($i$01) + 1)|0;
    $49 = HEAP32[$41>>2]|0;
    $50 = ($48>>>0)<($49>>>0);
    if ($50) {
     $i$01 = $48;
    } else {
     $$0 = $m;
     break;
    }
   }
  }
 }
 $53 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($53);
 $$1 = $$0;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx9NpPhysics14createMaterialEfff($this,$staticFriction,$dynamicFriction,$restitution) {
 $this = $this|0;
 $staticFriction = Math_fround($staticFriction);
 $dynamicFriction = Math_fround($dynamicFriction);
 $restitution = Math_fround($restitution);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory14createMaterialEfff($0,$staticFriction,$dynamicFriction,$restitution)|0);
 $2 = (__ZN5physx9NpPhysics11addMaterialEPNS_10NpMaterialE($this,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx9NpPhysics14getNbMaterialsEv($this) {
 $this = $this|0;
 var $$phi$trans$insert$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02$i = 0, $not$$i = 0, $numMaterials$0$$i = 0, $numMaterials$0$lcssa$i = 0, $numMaterials$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $numMaterials$0$lcssa$i = 0;
 } else {
  $$phi$trans$insert$i = (($this) + 52|0);
  $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
  $i$02$i = 0;$numMaterials$01$i = 0;
  while(1) {
   $5 = (($i$02$i) + 1)|0;
   $6 = (($$pre$i) + ($i$02$i<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $not$$i = ($7|0)!=(0|0);
   $8 = $not$$i&1;
   $numMaterials$0$$i = (($8) + ($numMaterials$01$i))|0;
   $exitcond = ($5|0)==($3|0);
   if ($exitcond) {
    $numMaterials$0$lcssa$i = $numMaterials$0$$i;
    break;
   } else {
    $i$02$i = $5;$numMaterials$01$i = $numMaterials$0$$i;
   }
  }
 }
 $9 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($9);
 STACKTOP = sp;return ($numMaterials$0$lcssa$i|0);
}
function __ZNK5physx9NpPhysics12getMaterialsEPPNS_10PxMaterialEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$ph2 = 0, $$phi$trans$insert8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0 = 0, $index$0$ph = 0, $writeCount$0$ph = 0, $writeCount$0$ph9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $$phi$trans$insert8$i = (($this) + 52|0);
 $$ph2 = 0;$index$0$ph = 0;$writeCount$0$ph = 0;
 L1: while(1) {
  $5 = $$ph2;$index$0 = $index$0$ph;
  while(1) {
   $4 = ($5>>>0)<($3>>>0);
   L5: do {
    if ($4) {
     $$pre9$i = HEAP32[$$phi$trans$insert8$i>>2]|0;
     $7 = $5;
     while(1) {
      $6 = (($$pre9$i) + ($7<<2)|0);
      $8 = HEAP32[$6>>2]|0;
      $9 = ($8|0)==(0|0);
      if (!($9)) {
       $13 = $7;
       break L5;
      }
      $10 = (($7) + 1)|0;
      $11 = ($10>>>0)<($3>>>0);
      if ($11) {
       $7 = $10;
      } else {
       $13 = $10;
       break;
      }
     }
    } else {
     $13 = $5;
    }
   } while(0);
   $12 = ($13>>>0)<($3>>>0);
   if (!($12)) {
    $writeCount$0$ph9 = $writeCount$0$ph;
    label = 11;
    break L1;
   }
   $14 = (($index$0) + 1)|0;
   $15 = ($index$0>>>0)<($startIndex>>>0);
   if ($15) {
    $5 = $13;$index$0 = $14;
   } else {
    break;
   }
  }
  $16 = ($writeCount$0$ph|0)==($bufferSize|0);
  if ($16) {
   $writeCount$0$ph9 = $bufferSize;
   label = 11;
   break;
  }
  $17 = (($13) + 1)|0;
  $18 = HEAP32[$$phi$trans$insert8$i>>2]|0;
  $19 = (($18) + ($13<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($writeCount$0$ph) + 1)|0;
  $22 = (($userBuffer) + ($writeCount$0$ph<<2)|0);
  HEAP32[$22>>2] = $20;
  $$ph2 = $17;$index$0$ph = $14;$writeCount$0$ph = $21;
 }
 if ((label|0) == 11) {
  $23 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($23);
  STACKTOP = sp;return ($writeCount$0$ph9|0);
 }
 return 0|0;
}
function __ZN5physx9NpPhysics23removeMaterialFromTableERNS_10NpMaterialE($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($this) + 4|0);
  $i$01 = 0;
  while(1) {
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + ($i$01<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   __ZN5physx7NpScene14removeMaterialERNS_10NpMaterialE($9,$m);
   $10 = (($i$01) + 1)|0;
   $11 = HEAP32[$3>>2]|0;
   $12 = ($10>>>0)<($11>>>0);
   if ($12) {
    $i$01 = $10;
   } else {
    break;
   }
  }
 }
 $13 = (($m) + 52|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(-1);
 do {
  if (!($15)) {
   $16 = (($this) + 52|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + ($14<<2)|0);
   HEAP32[$18>>2] = 0;
   HEAP32[$0>>2] = $14;
   $19 = (($this) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + -1)|0;
   $22 = ($21|0)==($14|0);
   if ($22) {
    HEAP32[$19>>2] = $14;
    break;
   }
   $23 = (($this) + 40|0);
   $24 = (($this) + 48|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 & 2147483647;
   $27 = (($this) + 44|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($26>>>0)>($28>>>0);
   if (!($29)) {
    (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($23,$0)|0);
    break;
   }
   $30 = HEAP32[$23>>2]|0;
   $31 = (($30) + ($28<<2)|0);
   $32 = ($31|0)==(0|0);
   if ($32) {
    $34 = $28;
   } else {
    HEAP32[$31>>2] = $14;
    $$pre$i$i$i = HEAP32[$27>>2]|0;
    $34 = $$pre$i$i$i;
   }
   $33 = (($34) + 1)|0;
   HEAP32[$27>>2] = $33;
  }
 } while(0);
 $35 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($35);
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics14updateMaterialERNS_10NpMaterialE($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($this) + 4|0);
  $i$01 = 0;
  while(1) {
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + ($i$01<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   __ZN5physx7NpScene14updateMaterialERNS_10NpMaterialE($8,$m);
   $9 = (($i$01) + 1)|0;
   $10 = HEAP32[$2>>2]|0;
   $11 = ($9>>>0)<($10>>>0);
   if ($11) {
    $i$01 = $9;
   } else {
    break;
   }
  }
 }
 $12 = (($m) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($13<<2)|0);
 HEAP32[$16>>2] = $m;
 $17 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($17);
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics18createTriangleMeshERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx13GuMeshFactory18createTriangleMeshERNS_13PxInputStreamE($0,$stream)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics19getNbTriangleMeshesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx13GuMeshFactory19getNbTriangleMeshesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics17getTriangleMeshesEPPNS_14PxTriangleMeshEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx13GuMeshFactory17getTriangleMeshesEPPNS_14PxTriangleMeshEjj($0,$userBuffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics17createHeightFieldERKNS_17PxHeightFieldDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx13GuMeshFactory17createHeightFieldERKNS_17PxHeightFieldDescE($0,$desc)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics17createHeightFieldERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx13GuMeshFactory17createHeightFieldERNS_13PxInputStreamE($0,$stream)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics17getNbHeightFieldsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx13GuMeshFactory17getNbHeightFieldsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics15getHeightFieldsEPPNS_13PxHeightFieldEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx13GuMeshFactory15getHeightFieldsEPPNS_13PxHeightFieldEjj($0,$userBuffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics16createConvexMeshERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx13GuMeshFactory16createConvexMeshERNS_13PxInputStreamE($0,$stream)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics17getNbConvexMeshesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx13GuMeshFactory17getNbConvexMeshesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics15getConvexMeshesEPPNS_12PxConvexMeshEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx13GuMeshFactory15getConvexMeshesEPPNS_12PxConvexMeshEjj($0,$userBuffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics17createClothFabricERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory17createClothFabricERNS_13PxInputStreamE($0,$stream)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics17createClothFabricERKNS_17PxClothFabricDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory17createClothFabricERKNS_17PxClothFabricDescE($0,$desc)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics17getNbClothFabricsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx9NpFactory17getNbClothFabricsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9NpPhysics15getClothFabricsEPPNS_13PxClothFabricEj($this,$userBuffer,$bufferSize) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZNK5physx9NpFactory15getClothFabricsEPPNS_13PxClothFabricEj($0,$userBuffer,$bufferSize)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics24registerDeletionListenerERNS_18PxDeletionListenerERKNS_7PxFlagsINS_19PxDeletionEventFlag4EnumEhEEb($this,$observer,$deletionEvents,$restrictedObjectSet) {
 $this = $this|0;
 $observer = $observer|0;
 $deletionEvents = $deletionEvents|0;
 $restrictedObjectSet = $restrictedObjectSet|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $e = 0, $i$0$lcssa$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $e = sp;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 68|0);
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 L1: do {
  if ($5) {
   $i$0$lcssa$i = 0;
  } else {
   $6 = HEAP32[$2>>2]|0;
   $i$01$i = 0;
   while(1) {
    $9 = (($6) + ($i$01$i<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + 40|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($observer|0);
    $8 = (($i$01$i) + 1)|0;
    if ($13) {
     $i$0$lcssa$i = $i$01$i;
     break L1;
    }
    $7 = ($8>>>0)<($4>>>0);
    if ($7) {
     $i$01$i = $8;
    } else {
     $i$0$lcssa$i = $8;
     break;
    }
   }
  }
 } while(0);
 $14 = ($i$0$lcssa$i|0)==($4|0);
 if (!($14)) {
  $45 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($45);
  STACKTOP = sp;return;
 }
 $15 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (__Z15PxGetFoundationv()|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
 $$$i$i$i = $23 ? 425360 : 425176;
 $24 = (FUNCTION_TABLE_iiiiii[$18 & 255]($15,48,$$$i$i$i,424840,645)|0);
 $25 = (($24) + 24|0);
 ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;HEAP32[$24+16>>2]=0|0;HEAP32[$24+20>>2]=0|0;
 HEAPF32[$25>>2] = Math_fround(0.75);
 $26 = (($24) + 28|0);
 HEAP32[$26>>2] = -1;
 $27 = (($24) + 32|0);
 HEAP32[$27>>2] = 0;
 $28 = (($24) + 36|0);
 HEAP32[$28>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPKNS_6PxBaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb0EE6GetKeyES9_Lb0EE15reserveInternalEj($24,64);
 $29 = (($24) + 40|0);
 HEAP32[$29>>2] = $observer;
 $30 = HEAP8[$deletionEvents>>0]|0;
 $31 = (($24) + 44|0);
 HEAP8[$31>>0] = $30;
 $32 = (($24) + 45|0);
 HEAP8[$32>>0] = 0;
 HEAP32[$e>>2] = $24;
 $33 = ($24|0)==(0|0);
 if ($33) {
  $45 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($45);
  STACKTOP = sp;return;
 }
 $34 = $restrictedObjectSet&1;
 HEAP8[$32>>0] = $34;
 $35 = (($this) + 76|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 2147483647;
 $38 = HEAP32[$3>>2]|0;
 $39 = ($37>>>0)>($38>>>0);
 if ($39) {
  $40 = HEAP32[$2>>2]|0;
  $41 = (($40) + ($38<<2)|0);
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   HEAP32[$41>>2] = $24;
  }
  $43 = (($38) + 1)|0;
  HEAP32[$3>>2] = $43;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_9NpPhysics18NpDelListenerEntryENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($2,$e)|0);
 }
 $44 = (($this) + 84|0);
 HEAP8[$44>>0] = 1;
 $45 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($45);
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics26unregisterDeletionListenerERNS_18PxDeletionListenerE($this,$observer) {
 $this = $this|0;
 $observer = $observer|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$lcssa$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = (($this) + 68|0);
 $4 = (($this) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 L1: do {
  if ($6) {
   $i$0$lcssa$i = 0;
  } else {
   $7 = HEAP32[$3>>2]|0;
   $i$01$i = 0;
   while(1) {
    $10 = (($7) + ($i$01$i<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($11) + 40|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==($observer|0);
    $9 = (($i$01$i) + 1)|0;
    if ($14) {
     $i$0$lcssa$i = $i$01$i;
     break L1;
    }
    $8 = ($9>>>0)<($5>>>0);
    if ($8) {
     $i$01$i = $9;
    } else {
     $i$0$lcssa$i = $9;
     break;
    }
   }
  }
 } while(0);
 $15 = ($i$0$lcssa$i>>>0)<($5>>>0);
 if (!($15)) {
  $29 = $5;
  $28 = ($29|0)!=(0);
  $30 = (($this) + 84|0);
  $31 = $28&1;
  HEAP8[$30>>0] = $31;
  $32 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($32);
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + ($i$0$lcssa$i<<2)|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $23 = $5;$25 = $16;
 } else {
  $20 = HEAP32[$18>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($18,$20);
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$18);
  $$pre = HEAP32[$4>>2]|0;
  $$pre1 = HEAP32[$3>>2]|0;
  $23 = $$pre;$25 = $$pre1;
 }
 $22 = (($23) + -1)|0;
 HEAP32[$4>>2] = $22;
 $24 = (($25) + ($22<<2)|0);
 $26 = HEAP32[$24>>2]|0;
 $27 = (($25) + ($i$0$lcssa$i<<2)|0);
 HEAP32[$27>>2] = $26;
 $29 = $22;
 $28 = ($29|0)!=(0);
 $30 = (($this) + 84|0);
 $31 = $28&1;
 HEAP8[$30>>0] = $31;
 $32 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($32);
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics31registerDeletionListenerObjectsERNS_18PxDeletionListenerEPKPKNS_6PxBaseEj($this,$observer,$observables,$observableCount) {
 $this = $this|0;
 $observer = $observer|0;
 $observables = $observables|0;
 $observableCount = $observableCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exists$i = 0, $exitcond = 0, $i$0$lcssa$i = 0, $i$01 = 0, $i$01$i = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp;
 $0 = (($this) + 68|0);
 $1 = (($this) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $i$0$lcssa$i = 0;
  } else {
   $4 = HEAP32[$0>>2]|0;
   $i$01$i = 0;
   while(1) {
    $7 = (($4) + ($i$01$i<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 40|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($observer|0);
    $6 = (($i$01$i) + 1)|0;
    if ($11) {
     $i$0$lcssa$i = $i$01$i;
     break L1;
    }
    $5 = ($6>>>0)<($2>>>0);
    if ($5) {
     $i$01$i = $6;
    } else {
     $i$0$lcssa$i = $6;
     break;
    }
   }
  }
 } while(0);
 $12 = ($i$0$lcssa$i>>>0)>=($2>>>0);
 $13 = ($observableCount|0)==(0);
 $or$cond = $12 | $13;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = (($14) + ($i$0$lcssa$i<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $i$01 = 0;
 while(1) {
  $17 = (($observables) + ($i$01<<2)|0);
  $18 = (__ZN5physx6shdfnd8internal8HashBaseIPKNS_6PxBaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb0EE6GetKeyES9_Lb0EE6createERKS5_Rb($16,$17,$exists$i)|0);
  $19 = HEAP8[$exists$i>>0]|0;
  $20 = ($19<<24>>24)!=(0);
  $21 = ($18|0)==(0|0);
  $or$cond$i = $20 | $21;
  if (!($or$cond$i)) {
   $22 = HEAP32[$17>>2]|0;
   HEAP32[$18>>2] = $22;
  }
  $23 = (($i$01) + 1)|0;
  $exitcond = ($23|0)==($observableCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $23;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics33unregisterDeletionListenerObjectsERNS_18PxDeletionListenerEPKPKNS_6PxBaseEj($this,$observer,$observables,$observableCount) {
 $this = $this|0;
 $observer = $observer|0;
 $observables = $observables|0;
 $observableCount = $observableCount|0;
 var $$pr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$0$lcssa$i = 0, $i$01$i = 0, $i$03 = 0, $or$cond = 0, $ptr$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = (($this) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $i$0$lcssa$i = 0;
  } else {
   $4 = HEAP32[$0>>2]|0;
   $i$01$i = 0;
   while(1) {
    $7 = (($4) + ($i$01$i<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 40|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($observer|0);
    $6 = (($i$01$i) + 1)|0;
    if ($11) {
     $i$0$lcssa$i = $i$01$i;
     break L1;
    }
    $5 = ($6>>>0)<($2>>>0);
    if ($5) {
     $i$01$i = $6;
    } else {
     $i$0$lcssa$i = $6;
     break;
    }
   }
  }
 } while(0);
 $12 = ($i$0$lcssa$i>>>0)<($2>>>0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = (($13) + ($i$0$lcssa$i<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 45|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 $19 = ($observableCount|0)==(0);
 $or$cond = $18 | $19;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $20 = (($15) + 20|0);
 $21 = (($15) + 12|0);
 $22 = (($15) + 4|0);
 $23 = (($15) + 8|0);
 $24 = (($15) + 36|0);
 $25 = (($15) + 32|0);
 $26 = (($15) + 28|0);
 $i$03 = 0;
 while(1) {
  $27 = HEAP32[$20>>2]|0;
  $28 = ($27|0)==(0);
  L15: do {
   if (!($28)) {
    $29 = (($observables) + ($i$03<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = $30;
    $32 = $31 << 15;
    $33 = $32 ^ -1;
    $34 = (($31) + ($33))|0;
    $35 = $34 >>> 10;
    $36 = $35 ^ $34;
    $37 = ($36*9)|0;
    $38 = $37 >>> 6;
    $39 = $38 ^ $37;
    $40 = $39 << 11;
    $41 = $40 ^ -1;
    $42 = (($39) + ($41))|0;
    $43 = $42 >>> 16;
    $44 = $43 ^ $42;
    $45 = (($27) + -1)|0;
    $46 = $44 & $45;
    $47 = HEAP32[$21>>2]|0;
    $48 = (($47) + ($46<<2)|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==(-1);
    if (!($50)) {
     $51 = HEAP32[$22>>2]|0;
     $$pr$i$i = $49;$ptr$02$i$i = $48;
     while(1) {
      $52 = (($51) + ($$pr$i$i<<2)|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==($30|0);
      if ($54) {
       break;
      }
      $55 = HEAP32[$23>>2]|0;
      $56 = (($55) + ($$pr$i$i<<2)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(-1);
      if ($58) {
       break L15;
      } else {
       $$pr$i$i = $57;$ptr$02$i$i = $56;
      }
     }
     $59 = ($$pr$i$i|0)==(-1);
     if (!($59)) {
      $60 = HEAP32[$23>>2]|0;
      $61 = (($60) + ($$pr$i$i<<2)|0);
      $62 = HEAP32[$61>>2]|0;
      HEAP32[$ptr$02$i$i>>2] = $62;
      $63 = HEAP32[$24>>2]|0;
      $64 = (($63) + -1)|0;
      HEAP32[$24>>2] = $64;
      $65 = HEAP32[$25>>2]|0;
      $66 = (($65) + 1)|0;
      HEAP32[$25>>2] = $66;
      $67 = HEAP32[$26>>2]|0;
      HEAP32[$61>>2] = $67;
      HEAP32[$26>>2] = $$pr$i$i;
     }
    }
   }
  } while(0);
  $68 = (($i$03) + 1)|0;
  $exitcond = ($68|0)==($observableCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $68;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($this,$base,$userData,$deletionEvent) {
 $this = $this|0;
 $base = $base|0;
 $userData = $userData|0;
 $deletionEvent = $deletionEvent|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $index$0$i$i = 0, $index$02$i$i = 0, $index$03$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($4);
 $5 = (($this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($this) + 68|0);
  $9 = $base;
  $10 = $9 << 15;
  $11 = $10 ^ -1;
  $12 = (($9) + ($11))|0;
  $13 = $12 >>> 10;
  $14 = $13 ^ $12;
  $15 = ($14*9)|0;
  $16 = $15 >>> 6;
  $17 = $16 ^ $15;
  $18 = $17 << 11;
  $19 = $18 ^ -1;
  $20 = (($17) + ($19))|0;
  $21 = $20 >>> 16;
  $22 = $21 ^ $20;
  $i$02 = 0;
  while(1) {
   $23 = HEAP32[$8>>2]|0;
   $24 = (($23) + ($i$02<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 44|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   $29 = $28 & $deletionEvent;
   $30 = ($29|0)==(0);
   L8: do {
    if (!($30)) {
     $31 = (($25) + 45|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = ($32<<24>>24)==(0);
     if ($33) {
      $57 = (($25) + 40|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = HEAP32[$58>>2]|0;
      $60 = HEAP32[$59>>2]|0;
      FUNCTION_TABLE_viiii[$60 & 511]($58,$base,$userData,$deletionEvent);
      break;
     }
     $34 = (($25) + 20|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)==(0);
     if (!($36)) {
      $37 = (($35) + -1)|0;
      $38 = $37 & $22;
      $39 = (($25) + 12|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + ($38<<2)|0);
      $index$02$i$i = HEAP32[$41>>2]|0;
      $42 = ($index$02$i$i|0)==(-1);
      if (!($42)) {
       $43 = (($25) + 4|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = (($25) + 8|0);
       $index$03$i$i = $index$02$i$i;
       while(1) {
        $46 = (($44) + ($index$03$i$i<<2)|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = ($47|0)==($base|0);
        if ($48) {
         break;
        }
        $49 = HEAP32[$45>>2]|0;
        $50 = (($49) + ($index$03$i$i<<2)|0);
        $index$0$i$i = HEAP32[$50>>2]|0;
        $51 = ($index$0$i$i|0)==(-1);
        if ($51) {
         break L8;
        } else {
         $index$03$i$i = $index$0$i$i;
        }
       }
       $52 = ($46|0)==(0|0);
       if (!($52)) {
        $53 = (($25) + 40|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = HEAP32[$54>>2]|0;
        $56 = HEAP32[$55>>2]|0;
        FUNCTION_TABLE_viiii[$56 & 511]($54,$base,$userData,$deletionEvent);
       }
      }
     }
    }
   } while(0);
   $61 = (($i$02) + 1)|0;
   $62 = HEAP32[$5>>2]|0;
   $63 = ($61>>>0)<($62>>>0);
   if ($63) {
    $i$02 = $61;
   } else {
    break;
   }
  }
 }
 $64 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($64);
 STACKTOP = sp;return;
}
function __ZNK5physx9NpPhysics18getTolerancesScaleEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx9NpPhysics14getProfileZoneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics21getProfileZoneManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx9NpPhysics17getVisualDebuggerEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN5physx9NpPhysics23getPvdConnectionManagerEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN5physx9NpPhysics13getFoundationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __Z19PxCreateBasePhysicsjRN5physx12PxFoundationERKNS_17PxTolerancesScaleEbPNS_20PxProfileZoneManagerE($version,$foundation,$scale,$trackOutstandingAllocations,$profileZoneManager) {
 $version = $version|0;
 $foundation = $foundation|0;
 $scale = $scale|0;
 $trackOutstandingAllocations = $trackOutstandingAllocations|0;
 $profileZoneManager = $profileZoneManager|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx9NpPhysics14createInstanceEjRNS_12PxFoundationERKNS_17PxTolerancesScaleEbPNS_20PxProfileZoneManagerE($version,$foundation,$scale,$trackOutstandingAllocations,$profileZoneManager)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z23PxRegisterArticulationsRN5physx9PxPhysicsE($physics) {
 $physics = $physics|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx24PxvRegisterArticulationsEv();
 __ZN5physx9NpFactory21registerArticulationsEv();
 STACKTOP = sp;return;
}
function __Z22PxRegisterHeightFieldsRN5physx9PxPhysicsE($physics) {
 $physics = $physics|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx29PxvRegisterLegacyHeightFieldsEv();
 __ZN5physx2Gu20registerHeightFieldsEv();
 STACKTOP = sp;return;
}
function __Z15PxRegisterClothRN5physx9PxPhysicsE($physics) {
 $physics = $physics|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx9NpFactory13registerClothEv();
 $0 = (($physics) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($physics) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $13 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($13);
  STACKTOP = sp;return;
 }
 $5 = (($physics) + 4|0);
 $i$01$i = 0;
 while(1) {
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($i$01$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 32|0);
  __ZN5physx2Sc5Scene17createClothSolverEv($9);
  $10 = (($i$01$i) + 1)|0;
  $11 = HEAP32[$2>>2]|0;
  $12 = ($10>>>0)<($11>>>0);
  if ($12) {
   $i$01$i = $10;
  } else {
   break;
  }
 }
 $13 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($13);
 STACKTOP = sp;return;
}
function __Z19PxRegisterParticlesRN5physx9PxPhysicsE($physics) {
 $physics = $physics|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx20PxvRegisterParticlesEv();
 __ZN5physx9NpFactory17registerParticlesEv();
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics27getPhysicsInsertionCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPKNS_6PxBaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb0EE6GetKeyES9_Lb0EE6createERKS5_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre11 = 0, $$pre11$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $36 = $1 << 1;
  $$$i = $2 ? 16 : $36;
  $37 = ($1>>>0)<($$$i>>>0);
  if ($37) {
   __ZN5physx6shdfnd8internal8HashBaseIPKNS_6PxBaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb0EE6GetKeyES9_Lb0EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $$pre11$pre = HEAP32[$33>>2]|0;
   $$pre11 = $$pre11$pre;$54 = $$pre;
  } else {
   $$pre11 = -1;$54 = $1;
  }
  $38 = HEAP32[$k>>2]|0;
  $39 = $38;
  $40 = $39 << 15;
  $41 = $40 ^ -1;
  $42 = (($39) + ($41))|0;
  $43 = $42 >>> 10;
  $44 = $43 ^ $42;
  $45 = ($44*9)|0;
  $46 = $45 >>> 6;
  $47 = $46 ^ $45;
  $48 = $47 << 11;
  $49 = $48 ^ -1;
  $50 = (($47) + ($49))|0;
  $51 = $50 >>> 16;
  $52 = $51 ^ $50;
  $53 = (($54) + -1)|0;
  $55 = $52 & $53;
  $59 = $$pre11;$h$1 = $55;
 } else {
  $59 = $34;$h$1 = $h$0;
 }
 $56 = (($this) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($59<<2)|0);
 $60 = HEAP32[$58>>2]|0;
 HEAP32[$33>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$58>>2] = $64;
 HEAP32[$63>>2] = $59;
 $65 = (($this) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $68 = (($this) + 32|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$68>>2] = $70;
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($59<<2)|0);
 $$0 = $73;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPKNS_6PxBaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb0EE6GetKeyES9_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,425008,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
    $44 = $43 << 15;
    $45 = $44 ^ -1;
    $46 = (($43) + ($45))|0;
    $47 = $46 >>> 10;
    $48 = $47 ^ $46;
    $49 = ($48*9)|0;
    $50 = $49 >>> 6;
    $51 = $50 ^ $49;
    $52 = $51 << 11;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 16;
    $56 = $55 ^ $54;
    $57 = $56 & $39;
    $58 = (($32) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($33) + ($index$01<<2)|0);
    HEAP32[$60>>2] = $59;
    HEAP32[$58>>2] = $index$01;
    $61 = (($34) + ($index$01<<2)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     HEAP32[$61>>2] = $42;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre13 = (($this) + 20|0);
  $$pre14 = (($this) + 8|0);
  $$pre$phi15Z2D = $$pre14;$$pre$phiZ2D = $$pre13;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $117 = $71;$bucket$06 = 0;
   while(1) {
    $76 = HEAP32[$73>>2]|0;
    $77 = (($76) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$77>>2]|0;
    $78 = ($index1$02|0)==(-1);
    if ($78) {
     $107 = $117;
    } else {
     $index1$03 = $index1$02;
     while(1) {
      $79 = HEAP32[$74>>2]|0;
      $80 = (($79) + ($index1$03<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81;
      $83 = $82 << 15;
      $84 = $83 ^ -1;
      $85 = (($82) + ($84))|0;
      $86 = $85 >>> 10;
      $87 = $86 ^ $85;
      $88 = ($87*9)|0;
      $89 = $88 >>> 6;
      $90 = $89 ^ $88;
      $91 = $90 << 11;
      $92 = $91 ^ -1;
      $93 = (($90) + ($92))|0;
      $94 = $93 >>> 16;
      $95 = $94 ^ $93;
      $96 = $95 & $75;
      $97 = (($32) + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($33) + ($index1$03<<2)|0);
      HEAP32[$99>>2] = $98;
      HEAP32[$97>>2] = $index1$03;
      $100 = (($34) + ($index1$03<<2)|0);
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       HEAP32[$100>>2] = $81;
      }
      $102 = HEAP32[$66>>2]|0;
      $103 = (($102) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$103>>2]|0;
      $104 = ($index1$0|0)==(-1);
      if ($104) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre = HEAP32[$70>>2]|0;
     $107 = $$pre;
    }
    $105 = (($bucket$06) + 1)|0;
    $106 = ($105>>>0)<($107>>>0);
    if ($106) {
     $117 = $107;$bucket$06 = $105;
    } else {
     $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $108 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$108);
 HEAP32[$this>>2] = $32;
 $109 = (($this) + 12|0);
 HEAP32[$109>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi15Z2D>>2] = $33;
 $110 = (($this) + 4|0);
 HEAP32[$110>>2] = $34;
 HEAP32[$18>>2] = $24;
 $111 = (($24) + -1)|0;
 $112 = ($111>>>0)>($19>>>0);
 if ($112) {
  $i$01$i = $19;
 } else {
  $115 = HEAP32[$15>>2]|0;
  $116 = (($33) + ($111<<2)|0);
  HEAP32[$116>>2] = $115;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $113 = (($i$01$i) + 1)|0;
  $114 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$114>>2] = $113;
  $exitcond$i = ($113|0)==($111|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 $115 = HEAP32[$15>>2]|0;
 $116 = (($33) + ($111<<2)|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_9NpPhysics18NpDelListenerEntryENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 425208 : 425176;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,425096,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_7NpSceneENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 425512 : 425176;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,425096,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx9NpPhysics20MeshDeletionListenerD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx9NpPhysics20MeshDeletionListener28onGuMeshFactoryBufferReleaseEPKNS_6PxBaseEtb($this,$object,$type,$memRelease) {
 $this = $this|0;
 $object = $object|0;
 $type = $type|0;
 $memRelease = $memRelease|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = $memRelease ? 2 : 1;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$object,0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx26NpPhysicsInsertionCallback12insertObjectERNS_6PxBaseE($this,$insertable) {
 $this = $this|0;
 $insertable = $insertable|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($insertable) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(3);
 if ($2) {
  $3 = HEAP32[420520>>2]|0;
  $4 = (($insertable) + 224|0);
  HEAP32[$4>>2] = $3;
  __ZN5physx2Gu12TriangleMesh18setupMeshInterfaceEv($insertable);
  $5 = HEAP32[420520>>2]|0;
  __ZN5physx13GuMeshFactory15addTriangleMeshEPNS_2Gu12TriangleMeshEb($5,$insertable,1);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ($1<<16>>16)==(1);
 if ($6) {
  $7 = HEAP32[420520>>2]|0;
  $8 = (($insertable) + 112|0);
  HEAP32[$8>>2] = $7;
  $9 = HEAP32[420520>>2]|0;
  __ZN5physx13GuMeshFactory14addHeightFieldEPNS_2Gu11HeightFieldEb($9,$insertable,1);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,32,426176,67,426264,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx26NpPhysicsInsertionCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm19CmEventNameProviderD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamicC2ERKNS_11PxTransformE($this,$bodyPose) {
 $this = $this|0;
 $bodyPose = $bodyPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 5;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((428216 + 8|0));
 $3 = (($this) + 12|0);
 __ZN5physx7NpActorC2EPKc($3,0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((427552 + 8|0));
 $4 = (($this) + 20|0);
 __ZN5physx14NpShapeManagerC2Ev($4);
 HEAP32[$this>>2] = ((427216 + 8|0));
 $5 = (($this) + 48|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 56|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 52|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreC2ENS_11PxActorType4EnumERKNS_11PxTransformE($8,1,$bodyPose);
 $9 = HEAP32[$7>>2]|0;
 $10 = $9 & -251658241;
 $11 = $10 | 50331648;
 HEAP32[$7>>2] = $11;
 $12 = (($this) + 80|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 224|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($this) + 84|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 228|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($this) + 88|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 232|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($this) + 92|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 236|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($this) + 96|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 240|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($this) + 100|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 244|0);
 HEAPF32[$29>>2] = $28;
 $30 = (($this) + 104|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 248|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($this) + 144|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($this) + 252|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($this) + 148|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($this) + 256|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($this) + 152|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 260|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($this) + 160|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($this) + 264|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($this) + 164|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($this) + 268|0);
 HEAPF32[$47>>2] = $46;
 $48 = (($this) + 168|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($this) + 272|0);
 HEAPF32[$50>>2] = $49;
 $51 = (Math_fround(__ZNK5physx2Sc8BodyCore14getWakeCounterEv($8)));
 $52 = (($this) + 276|0);
 HEAPF32[$52>>2] = $51;
 $53 = (($this) + 280|0);
 HEAP32[$53>>2] = 1;
 $54 = (($this) + 284|0);
 HEAP32[$54>>2] = 0;
 HEAP32[$this>>2] = ((426344 + 8|0));
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamicD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((427216 + 8|0));
 $1 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreD2Ev($1);
 HEAP32[$this>>2] = ((427552 + 8|0));
 $2 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 $3 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($3);
 HEAP32[$this>>2] = ((427888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamicD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((427216 + 8|0));
 $0 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreD2Ev($0);
 HEAP32[$this>>2] = ((427552 + 8|0));
 $1 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 $2 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 HEAP32[$this>>2] = ((427888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamic8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $2&65535;
 $6 = $2;$i$01$i = 0;
 while(1) {
  $5 = ($6<<16>>16)==(1);
  if ($5) {
   $9 = $0;
  } else {
   $7 = HEAP32[$0>>2]|0;
   $9 = $7;
  }
  $8 = (($9) + ($i$01$i<<2)|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$c>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($c,$10);
  $14 = (($i$01$i) + 1)|0;
  $exitcond$i = ($14|0)==($4|0);
  if ($exitcond$i) {
   break;
  }
  $$pre$i = HEAP16[$1>>1]|0;
  $6 = $$pre$i;$i$01$i = $14;
 }
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $2&65535;
 $6 = $2;$i$01 = 0;
 while(1) {
  $5 = ($6<<16>>16)==(1);
  if ($5) {
   $9 = $0;
  } else {
   $7 = HEAP32[$0>>2]|0;
   $9 = $7;
  }
  $8 = (($9) + ($i$01<<2)|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$c>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($c,$10);
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($4|0);
  if ($exitcond) {
   break;
  }
  $$pre = HEAP16[$1>>1]|0;
  $6 = $$pre;$i$01 = $14;
 }
 STACKTOP = sp;return;
}
function __Z14NpGetPxActorBCRN5physx2Sc8BodyCoreE($scBody) {
 $scBody = $scBody|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scBody) + -64|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx14NpRigidDynamic7releaseEv($this) {
 $this = $this|0;
 var $$off$i = 0, $$pre$phi3Z2D = 0, $$pre$phiZ2D = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge$demorgan = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (($this) + 48|0);
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 30;
 $$off$i = (($6) + -1)|0;
 $7 = ($$off$i>>>0)<(2);
 if ($7) {
  $8 = HEAP32[$3>>2]|0;
  $21 = $8;
 } else {
  $21 = 0;
 }
 $9 = $3;
 $10 = $5 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($9))|0;
 $15 = $14;
 $16 = (($15) + 8|0);
 $17 = HEAP16[$16>>1]|0;
 $18 = $17 & 8;
 $19 = ($18<<16>>16)!=(0);
 $20 = ($21|0)!=(0|0);
 $brmerge$demorgan = $20 & $19;
 if ($brmerge$demorgan) {
  $22 = (($this) + 20|0);
  __ZN5physx14NpShapeManager20clearShapesOnReleaseERNS_3Scb5SceneERNS_12PxRigidActorE($22,$21,$this);
  $$pre$phi3Z2D = $22;$$pre$phiZ2D = $this;
 } else {
  $$pre2 = (($this) + 20|0);
  $$pre$phi3Z2D = $$pre2;$$pre$phiZ2D = $this;
 }
 $23 = (($this) + 12|0);
 __ZN5physx7NpActor18releaseConstraintsERNS_12PxRigidActorE($23,$$pre$phiZ2D);
 $24 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 __ZN5physx14NpShapeManager9detachAllEPNS_7NpSceneE($$pre$phi3Z2D,$24);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($23,$this);
 if (!($20)) {
  __ZN5physx3Scb4Base7destroyEv($3);
  STACKTOP = sp;return;
 }
 __ZN5physx3Scb5Scene15removeRigidBodyERNS0_4BodyEbb($21,$3,1,$19);
 $25 = (__ZN5physx3Scb5Scene10getPxSceneEv($21)|0);
 $26 = (($this) + 36|0);
 __ZN5physx7NpScene24removeFromRigidActorListERKj($25,$26);
 __ZN5physx3Scb4Base7destroyEv($3);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor18releaseConstraintsERNS_12PxRigidActorE($0,$this);
 $1 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $2 = (($this) + 20|0);
 __ZN5physx14NpShapeManager9detachAllEPNS_7NpSceneE($2,$1);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamic13setGlobalPoseERKNS_11PxTransformEb($this,$pose,$autowake) {
 $this = $this|0;
 $pose = $pose|0;
 $autowake = $autowake|0;
 var $$in$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre9 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0);
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0;
 var $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $body2World = 0, $needsWakingUp$0$off0$i = 0, $not$$i = 0, $wakeCounter$0$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $body2World = sp;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = Math_fround(HEAPF32[$pose>>2]);
 $2 = Math_fround($1 * $1);
 $3 = (($pose) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $4);
 $6 = Math_fround($2 + $5);
 $7 = (($pose) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($pose) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (Math_fround(Math_sqrt((Math_fround($14)))));
 $16 = Math_fround(Math_fround(1.0) / $15);
 $17 = Math_fround($1 * $16);
 $18 = Math_fround($4 * $16);
 $19 = Math_fround($8 * $16);
 $20 = Math_fround($12 * $16);
 $21 = (($pose) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($pose) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($pose) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = ($0|0)==(0|0);
 if ($27) {
  $209 = Math_fround($17 * $17);
  $210 = Math_fround($18 * $18);
  $211 = Math_fround($209 + $210);
  $212 = Math_fround($19 * $19);
  $213 = Math_fround($212 + $211);
  $214 = Math_fround($20 * $20);
  $215 = Math_fround($214 + $213);
  $216 = (Math_fround(Math_sqrt((Math_fround($215)))));
  $217 = $216 != Math_fround(0.0);
  if ($217) {
   $218 = Math_fround(Math_fround(1.0) / $216);
   $219 = Math_fround($17 * $218);
   $220 = Math_fround($18 * $218);
   $221 = Math_fround($19 * $218);
   $222 = Math_fround($20 * $218);
   $251 = $222;$254 = $219;$256 = $220;$259 = $221;
  } else {
   $251 = $20;$254 = $17;$256 = $18;$259 = $19;
  }
  $223 = (($this) + 48|0);
  $224 = (($this) + 284|0);
  $225 = HEAP32[$224>>2]|0;
  $226 = $225 & 512;
  $227 = ($226|0)==(0);
  if ($227) {
   $239 = (($this) + 112|0);
   $241 = $239;
  } else {
   $228 = (($this) + 56|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = ($229|0)==(0|0);
   if ($230) {
    $231 = HEAP32[$223>>2]|0;
    $232 = (($this) + 52|0);
    $233 = HEAP32[$232>>2]|0;
    $234 = $233 >>> 24;
    $235 = $234 & 15;
    $236 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($231,$235)|0);
    HEAP32[$228>>2] = $236;
    $238 = $236;
   } else {
    $238 = $229;
   }
   $237 = (($238) + 144|0);
   $241 = $237;
  }
  $240 = (($241) + 16|0);
  $242 = Math_fround(HEAPF32[$240>>2]);
  $243 = Math_fround($242 * Math_fround(2.0));
  $244 = (($241) + 20|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = Math_fround($245 * Math_fround(2.0));
  $247 = (($241) + 24|0);
  $248 = Math_fround(HEAPF32[$247>>2]);
  $249 = Math_fround($248 * Math_fround(2.0));
  $250 = Math_fround($251 * $251);
  $252 = Math_fround($250 + Math_fround(-0.5));
  $253 = Math_fround($254 * $243);
  $255 = Math_fround($256 * $246);
  $257 = Math_fround($253 + $255);
  $258 = Math_fround($259 * $249);
  $260 = Math_fround($257 + $258);
  $261 = Math_fround($252 * $243);
  $262 = Math_fround($256 * $249);
  $263 = Math_fround($259 * $246);
  $264 = Math_fround($262 - $263);
  $265 = Math_fround($251 * $264);
  $266 = Math_fround($261 + $265);
  $267 = Math_fround($254 * $260);
  $268 = Math_fround($267 + $266);
  $269 = Math_fround($252 * $246);
  $270 = Math_fround($259 * $243);
  $271 = Math_fround($254 * $249);
  $272 = Math_fround($270 - $271);
  $273 = Math_fround($251 * $272);
  $274 = Math_fround($269 + $273);
  $275 = Math_fround($256 * $260);
  $276 = Math_fround($275 + $274);
  $277 = Math_fround($252 * $249);
  $278 = Math_fround($254 * $246);
  $279 = Math_fround($256 * $243);
  $280 = Math_fround($278 - $279);
  $281 = Math_fround($251 * $280);
  $282 = Math_fround($277 + $281);
  $283 = Math_fround($259 * $260);
  $284 = Math_fround($282 + $283);
  $285 = Math_fround($22 + $268);
  $286 = Math_fround($24 + $276);
  $287 = Math_fround($26 + $284);
  $288 = Math_fround(HEAPF32[$241>>2]);
  $289 = Math_fround($251 * $288);
  $290 = (($241) + 12|0);
  $291 = Math_fround(HEAPF32[$290>>2]);
  $292 = Math_fround($254 * $291);
  $293 = Math_fround($289 + $292);
  $294 = (($241) + 8|0);
  $295 = Math_fround(HEAPF32[$294>>2]);
  $296 = Math_fround($256 * $295);
  $297 = Math_fround($293 + $296);
  $298 = (($241) + 4|0);
  $299 = Math_fround(HEAPF32[$298>>2]);
  $300 = Math_fround($259 * $299);
  $301 = Math_fround($297 - $300);
  $302 = Math_fround($251 * $299);
  $303 = Math_fround($256 * $291);
  $304 = Math_fround($303 + $302);
  $305 = Math_fround($259 * $288);
  $306 = Math_fround($305 + $304);
  $307 = Math_fround($254 * $295);
  $308 = Math_fround($306 - $307);
  $309 = Math_fround($251 * $295);
  $310 = Math_fround($259 * $291);
  $311 = Math_fround($310 + $309);
  $312 = Math_fround($254 * $299);
  $313 = Math_fround($312 + $311);
  $314 = Math_fround($256 * $288);
  $315 = Math_fround($313 - $314);
  $316 = Math_fround($251 * $291);
  $317 = Math_fround($254 * $288);
  $318 = Math_fround($316 - $317);
  $319 = Math_fround($256 * $299);
  $320 = Math_fround($318 - $319);
  $321 = Math_fround($259 * $295);
  $322 = Math_fround($320 - $321);
  HEAPF32[$body2World>>2] = $301;
  $323 = (($body2World) + 4|0);
  HEAPF32[$323>>2] = $308;
  $324 = (($body2World) + 8|0);
  HEAPF32[$324>>2] = $315;
  $325 = (($body2World) + 12|0);
  HEAPF32[$325>>2] = $322;
  $326 = (($body2World) + 16|0);
  HEAPF32[$326>>2] = $285;
  $327 = (($body2World) + 20|0);
  HEAPF32[$327>>2] = $286;
  $328 = (($body2World) + 24|0);
  HEAPF32[$328>>2] = $287;
  $329 = (($this) + 224|0);
  HEAPF32[$329>>2] = $301;
  $330 = (($this) + 228|0);
  HEAPF32[$330>>2] = $308;
  $331 = (($this) + 232|0);
  HEAPF32[$331>>2] = $315;
  $332 = (($this) + 236|0);
  HEAPF32[$332>>2] = $322;
  $333 = (($this) + 240|0);
  HEAPF32[$333>>2] = $285;
  $334 = (($this) + 244|0);
  HEAPF32[$334>>2] = $286;
  $335 = (($this) + 248|0);
  HEAPF32[$335>>2] = $287;
  $336 = (($this) + 52|0);
  $337 = HEAP32[$336>>2]|0;
  $338 = $337 >>> 30;
  if ((($338|0) == 2)) {
   $339 = HEAP32[$223>>2]|0;
   $340 = (($339) + 2417|0);
   $341 = HEAP8[$340>>0]|0;
   $342 = ($341<<24>>24)==(0);
   if ($342) {
    label = 37;
   } else {
    $346 = $339;
    label = 38;
   }
  } else if ((($338|0) == 3)) {
   $$pre9 = HEAP32[$223>>2]|0;
   $346 = $$pre9;
   label = 38;
  } else {
   label = 37;
  }
  if ((label|0) == 37) {
   $343 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore13setBody2WorldERKNS_11PxTransformE($343,$body2World);
   STACKTOP = sp;return;
  }
  else if ((label|0) == 38) {
   $344 = HEAP32[$224>>2]|0;
   $345 = $344 & -131073;
   HEAP32[$224>>2] = $345;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($346,$223);
   $347 = HEAP32[$224>>2]|0;
   $348 = $347 | 65536;
   HEAP32[$224>>2] = $348;
   STACKTOP = sp;return;
  }
 }
 $28 = (($this) + 20|0);
 $29 = (($0) + 3376|0);
 __ZN5physx14NpShapeManager26markAllSceneQueryForUpdateERNS_2Sq17SceneQueryManagerE($28,$29);
 $30 = (($0) + 3400|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 1)|0;
 HEAP32[$30>>2] = $32;
 $33 = Math_fround($17 * $17);
 $34 = Math_fround($18 * $18);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($19 * $19);
 $37 = Math_fround($36 + $35);
 $38 = Math_fround($20 * $20);
 $39 = Math_fround($38 + $37);
 $40 = (Math_fround(Math_sqrt((Math_fround($39)))));
 $41 = $40 != Math_fround(0.0);
 if ($41) {
  $42 = Math_fround(Math_fround(1.0) / $40);
  $43 = Math_fround($17 * $42);
  $44 = Math_fround($18 * $42);
  $45 = Math_fround($19 * $42);
  $46 = Math_fround($20 * $42);
  $75 = $46;$78 = $43;$80 = $44;$83 = $45;
 } else {
  $75 = $20;$78 = $17;$80 = $18;$83 = $19;
 }
 $47 = (($this) + 48|0);
 $48 = (($this) + 284|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49 & 512;
 $51 = ($50|0)==(0);
 if ($51) {
  $63 = (($this) + 112|0);
  $65 = $63;
 } else {
  $52 = (($this) + 56|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $55 = HEAP32[$47>>2]|0;
   $56 = (($this) + 52|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $57 >>> 24;
   $59 = $58 & 15;
   $60 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($55,$59)|0);
   HEAP32[$52>>2] = $60;
   $62 = $60;
  } else {
   $62 = $53;
  }
  $61 = (($62) + 144|0);
  $65 = $61;
 }
 $64 = (($65) + 16|0);
 $66 = Math_fround(HEAPF32[$64>>2]);
 $67 = Math_fround($66 * Math_fround(2.0));
 $68 = (($65) + 20|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 * Math_fround(2.0));
 $71 = (($65) + 24|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 * Math_fround(2.0));
 $74 = Math_fround($75 * $75);
 $76 = Math_fround($74 + Math_fround(-0.5));
 $77 = Math_fround($78 * $67);
 $79 = Math_fround($80 * $70);
 $81 = Math_fround($77 + $79);
 $82 = Math_fround($83 * $73);
 $84 = Math_fround($81 + $82);
 $85 = Math_fround($76 * $67);
 $86 = Math_fround($80 * $73);
 $87 = Math_fround($83 * $70);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($75 * $88);
 $90 = Math_fround($85 + $89);
 $91 = Math_fround($78 * $84);
 $92 = Math_fround($91 + $90);
 $93 = Math_fround($76 * $70);
 $94 = Math_fround($83 * $67);
 $95 = Math_fround($78 * $73);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($75 * $96);
 $98 = Math_fround($93 + $97);
 $99 = Math_fround($80 * $84);
 $100 = Math_fround($99 + $98);
 $101 = Math_fround($76 * $73);
 $102 = Math_fround($78 * $70);
 $103 = Math_fround($80 * $67);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($75 * $104);
 $106 = Math_fround($101 + $105);
 $107 = Math_fround($83 * $84);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($22 + $92);
 $110 = Math_fround($24 + $100);
 $111 = Math_fround($26 + $108);
 $112 = Math_fround(HEAPF32[$65>>2]);
 $113 = Math_fround($75 * $112);
 $114 = (($65) + 12|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($78 * $115);
 $117 = Math_fround($113 + $116);
 $118 = (($65) + 8|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($80 * $119);
 $121 = Math_fround($117 + $120);
 $122 = (($65) + 4|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($83 * $123);
 $125 = Math_fround($121 - $124);
 $126 = Math_fround($75 * $123);
 $127 = Math_fround($80 * $115);
 $128 = Math_fround($127 + $126);
 $129 = Math_fround($83 * $112);
 $130 = Math_fround($129 + $128);
 $131 = Math_fround($78 * $119);
 $132 = Math_fround($130 - $131);
 $133 = Math_fround($75 * $119);
 $134 = Math_fround($83 * $115);
 $135 = Math_fround($134 + $133);
 $136 = Math_fround($78 * $123);
 $137 = Math_fround($136 + $135);
 $138 = Math_fround($80 * $112);
 $139 = Math_fround($137 - $138);
 $140 = Math_fround($75 * $115);
 $141 = Math_fround($78 * $112);
 $142 = Math_fround($140 - $141);
 $143 = Math_fround($80 * $123);
 $144 = Math_fround($142 - $143);
 $145 = Math_fround($83 * $119);
 $146 = Math_fround($144 - $145);
 HEAPF32[$body2World>>2] = $125;
 $147 = (($body2World) + 4|0);
 HEAPF32[$147>>2] = $132;
 $148 = (($body2World) + 8|0);
 HEAPF32[$148>>2] = $139;
 $149 = (($body2World) + 12|0);
 HEAPF32[$149>>2] = $146;
 $150 = (($body2World) + 16|0);
 HEAPF32[$150>>2] = $109;
 $151 = (($body2World) + 20|0);
 HEAPF32[$151>>2] = $110;
 $152 = (($body2World) + 24|0);
 HEAPF32[$152>>2] = $111;
 $153 = (($this) + 224|0);
 HEAPF32[$153>>2] = $125;
 $154 = (($this) + 228|0);
 HEAPF32[$154>>2] = $132;
 $155 = (($this) + 232|0);
 HEAPF32[$155>>2] = $139;
 $156 = (($this) + 236|0);
 HEAPF32[$156>>2] = $146;
 $157 = (($this) + 240|0);
 HEAPF32[$157>>2] = $109;
 $158 = (($this) + 244|0);
 HEAPF32[$158>>2] = $110;
 $159 = (($this) + 248|0);
 HEAPF32[$159>>2] = $111;
 $160 = (($this) + 52|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = $161 >>> 30;
 if ((($162|0) == 2)) {
  $163 = HEAP32[$47>>2]|0;
  $164 = (($163) + 2417|0);
  $165 = HEAP8[$164>>0]|0;
  $166 = ($165<<24>>24)==(0);
  if ($166) {
   label = 12;
  } else {
   $170 = $163;
   label = 13;
  }
 } else if ((($162|0) == 3)) {
  $$pre = HEAP32[$47>>2]|0;
  $170 = $$pre;
  label = 13;
 } else {
  label = 12;
 }
 if ((label|0) == 12) {
  $167 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore13setBody2WorldERKNS_11PxTransformE($167,$body2World);
 }
 else if ((label|0) == 13) {
  $168 = HEAP32[$48>>2]|0;
  $169 = $168 & -131073;
  HEAP32[$48>>2] = $169;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($170,$47);
  $171 = HEAP32[$48>>2]|0;
  $172 = $171 | 65536;
  HEAP32[$48>>2] = $172;
 }
 if (!($autowake)) {
  STACKTOP = sp;return;
 }
 $173 = HEAP32[$48>>2]|0;
 $174 = $173 & 4096;
 $175 = ($174|0)==(0);
 if ($175) {
  $186 = (($this) + 108|0);
  $$in$i = $186;
 } else {
  $176 = (($this) + 56|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = ($177|0)==(0|0);
  if ($178) {
   $179 = HEAP32[$47>>2]|0;
   $180 = HEAP32[$160>>2]|0;
   $181 = $180 >>> 24;
   $182 = $181 & 15;
   $183 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($179,$182)|0);
   HEAP32[$176>>2] = $183;
   $185 = $183;
  } else {
   $185 = $177;
  }
  $184 = (($185) + 268|0);
  $$in$i = $184;
 }
 $187 = HEAP8[$$in$i>>0]|0;
 $188 = $187 & 1;
 $189 = ($188<<24>>24)==(0);
 if (!($189)) {
  STACKTOP = sp;return;
 }
 $190 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $191 = (($190) + 2860|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($this) + 276|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($this) + 280|0);
 $196 = HEAP32[$195>>2]|0;
 $not$$i = ($196|0)!=(0);
 $197 = $194 < $192;
 $wakeCounter$0$i = $197 ? $192 : $194;
 $needsWakingUp$0$off0$i = $197 | $not$$i;
 if (!($needsWakingUp$0$off0$i)) {
  STACKTOP = sp;return;
 }
 $198 = HEAP32[$160>>2]|0;
 $199 = $198 >>> 30;
 if ((($199|0) == 2)) {
  $200 = HEAP32[$47>>2]|0;
  $201 = (($200) + 2416|0);
  $202 = HEAP8[$201>>0]|0;
  $203 = ($202<<24>>24)==(0);
  if ($203) {
   label = 25;
  } else {
   $205 = $200;
   label = 26;
  }
 } else if ((($199|0) == 3)) {
  $$pre$i$i = HEAP32[$47>>2]|0;
  $205 = $$pre$i$i;
  label = 26;
 } else {
  label = 25;
 }
 if ((label|0) == 25) {
  HEAP32[$195>>2] = 0;
  HEAPF32[$193>>2] = $wakeCounter$0$i;
  $204 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($204,$wakeCounter$0$i,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 26) {
  HEAP32[$195>>2] = 0;
  HEAPF32[$193>>2] = $wakeCounter$0$i;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($205,$47);
  $206 = HEAP32[$48>>2]|0;
  $207 = $206 & -7340033;
  $208 = $207 | 5242880;
  HEAP32[$48>>2] = $208;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic18setKinematicTargetERKNS_11PxTransformE($this,$destination) {
 $this = $this|0;
 $destination = $destination|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = Math_fround(HEAPF32[$destination>>2]);
 $2 = Math_fround($1 * $1);
 $3 = (($destination) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $4);
 $6 = Math_fround($2 + $5);
 $7 = (($destination) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($destination) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (Math_fround(Math_sqrt((Math_fround($14)))));
 $16 = Math_fround(Math_fround(1.0) / $15);
 $17 = Math_fround($1 * $16);
 $18 = Math_fround($4 * $16);
 $19 = Math_fround($8 * $16);
 $20 = Math_fround($12 * $16);
 HEAPF32[$0>>2] = $17;
 $21 = (($0) + 4|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($0) + 8|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($0) + 12|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($0) + 16|0);
 $25 = (($destination) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 HEAPF32[$24>>2] = $26;
 $27 = (($0) + 20|0);
 $28 = (($destination) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$27>>2] = $29;
 $30 = (($0) + 24|0);
 $31 = (($destination) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$30>>2] = $32;
 __ZN5physx14NpRigidDynamic26setKinematicTargetInternalERKNS_11PxTransformE($this,$0);
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamic26setKinematicTargetInternalERKNS_11PxTransformE($this,$targetPose) {
 $this = $this|0;
 $targetPose = $targetPose|0;
 var $$in = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $bodyTarget = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bodyTarget = sp;
 $0 = (($this) + 48|0);
 $1 = (($this) + 284|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 512;
 $4 = ($3|0)==(0);
 if ($4) {
  $16 = (($this) + 112|0);
  $18 = $16;
 } else {
  $5 = (($this) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $8 = HEAP32[$0>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$5>>2] = $13;
   $15 = $13;
  } else {
   $15 = $6;
  }
  $14 = (($15) + 144|0);
  $18 = $14;
 }
 $17 = (($18) + 16|0);
 $19 = Math_fround(HEAPF32[$17>>2]);
 $20 = Math_fround($19 * Math_fround(2.0));
 $21 = (($18) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * Math_fround(2.0));
 $24 = (($18) + 24|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * Math_fround(2.0));
 $27 = (($targetPose) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $28);
 $30 = Math_fround($29 + Math_fround(-0.5));
 $31 = Math_fround(HEAPF32[$targetPose>>2]);
 $32 = Math_fround($20 * $31);
 $33 = (($targetPose) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($23 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($targetPose) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($26 * $38);
 $40 = Math_fround($36 + $39);
 $41 = Math_fround($20 * $30);
 $42 = Math_fround($26 * $34);
 $43 = Math_fround($23 * $38);
 $44 = Math_fround($42 - $43);
 $45 = Math_fround($28 * $44);
 $46 = Math_fround($41 + $45);
 $47 = Math_fround($31 * $40);
 $48 = Math_fround($47 + $46);
 $49 = Math_fround($23 * $30);
 $50 = Math_fround($20 * $38);
 $51 = Math_fround($26 * $31);
 $52 = Math_fround($50 - $51);
 $53 = Math_fround($28 * $52);
 $54 = Math_fround($49 + $53);
 $55 = Math_fround($34 * $40);
 $56 = Math_fround($55 + $54);
 $57 = Math_fround($26 * $30);
 $58 = Math_fround($23 * $31);
 $59 = Math_fround($20 * $34);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($28 * $60);
 $62 = Math_fround($57 + $61);
 $63 = Math_fround($38 * $40);
 $64 = Math_fround($62 + $63);
 $65 = (($targetPose) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 + $48);
 $68 = (($targetPose) + 20|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $56);
 $71 = (($targetPose) + 24|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 + $64);
 $74 = Math_fround(HEAPF32[$18>>2]);
 $75 = Math_fround($28 * $74);
 $76 = (($18) + 12|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($31 * $77);
 $79 = Math_fround($75 + $78);
 $80 = (($18) + 8|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($34 * $81);
 $83 = Math_fround($79 + $82);
 $84 = (($18) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($38 * $85);
 $87 = Math_fround($83 - $86);
 $88 = Math_fround($28 * $85);
 $89 = Math_fround($34 * $77);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($38 * $74);
 $92 = Math_fround($91 + $90);
 $93 = Math_fround($31 * $81);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($28 * $81);
 $96 = Math_fround($38 * $77);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($31 * $85);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($34 * $74);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($28 * $77);
 $103 = Math_fround($31 * $74);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($34 * $85);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($38 * $81);
 $108 = Math_fround($106 - $107);
 HEAPF32[$bodyTarget>>2] = $87;
 $109 = (($bodyTarget) + 4|0);
 HEAPF32[$109>>2] = $94;
 $110 = (($bodyTarget) + 8|0);
 HEAPF32[$110>>2] = $101;
 $111 = (($bodyTarget) + 12|0);
 HEAPF32[$111>>2] = $108;
 $112 = (($bodyTarget) + 16|0);
 HEAPF32[$112>>2] = $67;
 $113 = (($bodyTarget) + 20|0);
 HEAPF32[$113>>2] = $70;
 $114 = (($bodyTarget) + 24|0);
 HEAPF32[$114>>2] = $73;
 __ZN5physx3Scb4Body18setKinematicTargetERKNS_11PxTransformE($0,$bodyTarget);
 $115 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $116 = HEAP32[$1>>2]|0;
 $117 = $116 & 4096;
 $118 = ($117|0)==(0);
 if ($118) {
  $130 = (($this) + 108|0);
  $$in = $130;
 } else {
  $119 = (($this) + 56|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ($120|0)==(0|0);
  if ($121) {
   $122 = HEAP32[$0>>2]|0;
   $123 = (($this) + 52|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = $124 >>> 24;
   $126 = $125 & 15;
   $127 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($122,$126)|0);
   HEAP32[$119>>2] = $127;
   $129 = $127;
  } else {
   $129 = $120;
  }
  $128 = (($129) + 268|0);
  $$in = $128;
 }
 $131 = HEAP8[$$in>>0]|0;
 $132 = $131 & 2;
 $$not = ($132<<24>>24)==(0);
 $133 = ($115|0)==(0|0);
 $or$cond = $$not | $133;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $134 = (($this) + 20|0);
 $135 = (($115) + 3376|0);
 __ZN5physx14NpShapeManager26markAllSceneQueryForUpdateERNS_2Sq17SceneQueryManagerE($134,$135);
 $136 = (($115) + 3400|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (($137) + 1)|0;
 HEAP32[$136>>2] = $138;
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamic18getKinematicTargetERNS_11PxTransformE($this,$target) {
 $this = $this|0;
 $target = $target|0;
 var $$0 = 0, $$in = 0, $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0);
 var $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0;
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $actorTarget = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $actorTarget = sp;
 $0 = (($this) + 48|0);
 $1 = (($this) + 284|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 4096;
 $4 = ($3|0)==(0);
 if ($4) {
  $16 = (($this) + 108|0);
  $$in = $16;
 } else {
  $5 = (($this) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $8 = HEAP32[$0>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$5>>2] = $13;
   $15 = $13;
  } else {
   $15 = $6;
  }
  $14 = (($15) + 268|0);
  $$in = $14;
 }
 $17 = HEAP8[$$in>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$1>>2]|0;
 $21 = $20 & 8192;
 $22 = ($21|0)==(0);
 if ($22) {
  $53 = (($this) + 52|0);
  $54 = HEAP32[$53>>2]|0;
  $$mask$i = $54 & -1073741824;
  $55 = ($$mask$i|0)==(-1073741824);
  if ($55) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $56 = (($this) + 64|0);
  $57 = (__ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($56,$actorTarget)|0);
  if (!($57)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $23 = (($this) + 56|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $26 = HEAP32[$0>>2]|0;
   $27 = (($this) + 52|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $28 >>> 24;
   $30 = $29 & 15;
   $31 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($26,$30)|0);
   HEAP32[$23>>2] = $31;
   $33 = $31;
  } else {
   $33 = $24;
  }
  $32 = (($33) + 192|0);
  $34 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$actorTarget>>2] = $34;
  $35 = (($33) + 196|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($actorTarget) + 4|0);
  HEAPF32[$37>>2] = $36;
  $38 = (($33) + 200|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($actorTarget) + 8|0);
  HEAPF32[$40>>2] = $39;
  $41 = (($33) + 204|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($actorTarget) + 12|0);
  HEAPF32[$43>>2] = $42;
  $44 = (($33) + 208|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($actorTarget) + 16|0);
  HEAPF32[$46>>2] = $45;
  $47 = (($33) + 212|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($actorTarget) + 20|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($33) + 216|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($actorTarget) + 24|0);
  HEAPF32[$52>>2] = $51;
 }
 $58 = HEAP32[$1>>2]|0;
 $59 = $58 & 512;
 $60 = ($59|0)==(0);
 if ($60) {
  $72 = (($this) + 112|0);
  $74 = $72;
 } else {
  $61 = (($this) + 56|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==(0|0);
  if ($63) {
   $64 = HEAP32[$0>>2]|0;
   $65 = (($this) + 52|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = $66 >>> 24;
   $68 = $67 & 15;
   $69 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($64,$68)|0);
   HEAP32[$61>>2] = $69;
   $71 = $69;
  } else {
   $71 = $62;
  }
  $70 = (($71) + 144|0);
  $74 = $70;
 }
 $73 = (($74) + 16|0);
 $75 = Math_fround(HEAPF32[$73>>2]);
 $76 = (($74) + 20|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($74) + 24|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($75 * Math_fround(-2.0));
 $81 = Math_fround($77 * Math_fround(-2.0));
 $82 = Math_fround($79 * Math_fround(-2.0));
 $83 = (($74) + 12|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 * $84);
 $86 = Math_fround($85 + Math_fround(-0.5));
 $87 = Math_fround(HEAPF32[$74>>2]);
 $88 = Math_fround($80 * $87);
 $89 = (($74) + 4|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($81 * $90);
 $92 = Math_fround($88 + $91);
 $93 = (($74) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($82 * $94);
 $96 = Math_fround($92 + $95);
 $97 = Math_fround($80 * $86);
 $98 = Math_fround($82 * $90);
 $99 = Math_fround($81 * $94);
 $100 = Math_fround($98 - $99);
 $101 = Math_fround($84 * $100);
 $102 = Math_fround($97 - $101);
 $103 = Math_fround($87 * $96);
 $104 = Math_fround($103 + $102);
 $105 = Math_fround($81 * $86);
 $106 = Math_fround($80 * $94);
 $107 = Math_fround($82 * $87);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($84 * $108);
 $110 = Math_fround($105 - $109);
 $111 = Math_fround($90 * $96);
 $112 = Math_fround($111 + $110);
 $113 = Math_fround($82 * $86);
 $114 = Math_fround($81 * $87);
 $115 = Math_fround($80 * $90);
 $116 = Math_fround($114 - $115);
 $117 = Math_fround($84 * $116);
 $118 = Math_fround($113 - $117);
 $119 = Math_fround($94 * $96);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround(-$87);
 $122 = Math_fround(-$90);
 $123 = Math_fround(-$94);
 $124 = Math_fround($104 * Math_fround(2.0));
 $125 = Math_fround($112 * Math_fround(2.0));
 $126 = Math_fround($120 * Math_fround(2.0));
 $127 = (($actorTarget) + 12|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($128 * $128);
 $130 = Math_fround($129 + Math_fround(-0.5));
 $131 = Math_fround(HEAPF32[$actorTarget>>2]);
 $132 = Math_fround($131 * $124);
 $133 = (($actorTarget) + 4|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($134 * $125);
 $136 = Math_fround($132 + $135);
 $137 = (($actorTarget) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($138 * $126);
 $140 = Math_fround($139 + $136);
 $141 = Math_fround($130 * $124);
 $142 = Math_fround($134 * $126);
 $143 = Math_fround($138 * $125);
 $144 = Math_fround($142 - $143);
 $145 = Math_fround($128 * $144);
 $146 = Math_fround($141 + $145);
 $147 = Math_fround($131 * $140);
 $148 = Math_fround($147 + $146);
 $149 = Math_fround($130 * $125);
 $150 = Math_fround($138 * $124);
 $151 = Math_fround($131 * $126);
 $152 = Math_fround($150 - $151);
 $153 = Math_fround($128 * $152);
 $154 = Math_fround($149 + $153);
 $155 = Math_fround($134 * $140);
 $156 = Math_fround($155 + $154);
 $157 = Math_fround($130 * $126);
 $158 = Math_fround($131 * $125);
 $159 = Math_fround($134 * $124);
 $160 = Math_fround($158 - $159);
 $161 = Math_fround($128 * $160);
 $162 = Math_fround($157 + $161);
 $163 = Math_fround($138 * $140);
 $164 = Math_fround($162 + $163);
 $165 = (($actorTarget) + 16|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = Math_fround($166 + $148);
 $168 = (($actorTarget) + 20|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = Math_fround($169 + $156);
 $171 = (($actorTarget) + 24|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = Math_fround($172 + $164);
 $174 = Math_fround($128 * $121);
 $175 = Math_fround($84 * $131);
 $176 = Math_fround($174 + $175);
 $177 = Math_fround($134 * $123);
 $178 = Math_fround($176 + $177);
 $179 = Math_fround($138 * $122);
 $180 = Math_fround($178 - $179);
 $181 = Math_fround($128 * $122);
 $182 = Math_fround($84 * $134);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround($138 * $121);
 $185 = Math_fround($184 + $183);
 $186 = Math_fround($131 * $123);
 $187 = Math_fround($185 - $186);
 $188 = Math_fround($128 * $123);
 $189 = Math_fround($84 * $138);
 $190 = Math_fround($188 + $189);
 $191 = Math_fround($131 * $122);
 $192 = Math_fround($191 + $190);
 $193 = Math_fround($134 * $121);
 $194 = Math_fround($192 - $193);
 $195 = Math_fround($84 * $128);
 $196 = Math_fround($131 * $121);
 $197 = Math_fround($195 - $196);
 $198 = Math_fround($134 * $122);
 $199 = Math_fround($197 - $198);
 $200 = Math_fround($138 * $123);
 $201 = Math_fround($199 - $200);
 HEAPF32[$target>>2] = $180;
 $202 = (($target) + 4|0);
 HEAPF32[$202>>2] = $187;
 $203 = (($target) + 8|0);
 HEAPF32[$203>>2] = $194;
 $204 = (($target) + 12|0);
 HEAPF32[$204>>2] = $201;
 $205 = (($target) + 16|0);
 HEAPF32[$205>>2] = $167;
 $206 = (($target) + 20|0);
 HEAPF32[$206>>2] = $170;
 $207 = (($target) + 24|0);
 HEAPF32[$207>>2] = $173;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx14NpRigidDynamic17setCMassLocalPoseERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $$in = 0, $$mask$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert11 = 0, $$phi$trans$insert13 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert7 = 0, $$phi$trans$insert9 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre12 = Math_fround(0), $$pre14 = Math_fround(0), $$pre16 = Math_fround(0), $$pre6 = Math_fround(0), $$pre8 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0;
 var $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0);
 var $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0);
 var $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0);
 var $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0);
 var $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0);
 var $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0;
 var $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $actorTarget = 0, $bodyTarget = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $p = sp + 56|0;
 $bodyTarget = sp;
 $actorTarget = sp + 28|0;
 $0 = Math_fround(HEAPF32[$pose>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($pose) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($pose) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (($pose) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (Math_fround(Math_sqrt((Math_fround($13)))));
 $15 = Math_fround(Math_fround(1.0) / $14);
 $16 = Math_fround($0 * $15);
 $17 = Math_fround($3 * $15);
 $18 = Math_fround($7 * $15);
 $19 = Math_fround($11 * $15);
 HEAPF32[$p>>2] = $16;
 $20 = (($p) + 4|0);
 HEAPF32[$20>>2] = $17;
 $21 = (($p) + 8|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($p) + 12|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($p) + 16|0);
 $24 = (($pose) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$23>>2] = $25;
 $26 = (($p) + 20|0);
 $27 = (($pose) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$26>>2] = $28;
 $29 = (($p) + 24|0);
 $30 = (($pose) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$29>>2] = $31;
 $32 = (($this) + 48|0);
 $33 = (($this) + 284|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 512;
 $36 = ($35|0)==(0);
 if ($36) {
  $48 = (($this) + 112|0);
  $50 = $48;
 } else {
  $37 = (($this) + 56|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0|0);
  if ($39) {
   $40 = HEAP32[$32>>2]|0;
   $41 = (($this) + 52|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = $42 >>> 24;
   $44 = $43 & 15;
   $45 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($40,$44)|0);
   HEAP32[$37>>2] = $45;
   $47 = $45;
  } else {
   $47 = $38;
  }
  $46 = (($47) + 144|0);
  $50 = $46;
 }
 $49 = Math_fround(HEAPF32[$50>>2]);
 $51 = (($50) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($50) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($50) + 12|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($50) + 16|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($50) + 20|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($50) + 24|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25setCMassLocalPoseInternalERKNS_11PxTransformE($this,$p);
 $63 = HEAP32[$33>>2]|0;
 $64 = $63 & 4096;
 $65 = ($64|0)==(0);
 if ($65) {
  $77 = (($this) + 108|0);
  $$in = $77;
 } else {
  $66 = (($this) + 56|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  if ($68) {
   $69 = HEAP32[$32>>2]|0;
   $70 = (($this) + 52|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = $71 >>> 24;
   $73 = $72 & 15;
   $74 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($69,$73)|0);
   HEAP32[$66>>2] = $74;
   $76 = $74;
  } else {
   $76 = $67;
  }
  $75 = (($76) + 268|0);
  $$in = $75;
 }
 $78 = HEAP8[$$in>>0]|0;
 $79 = $78 & 1;
 $80 = ($79<<24>>24)==(0);
 if ($80) {
  STACKTOP = sp;return;
 }
 $81 = HEAP32[$33>>2]|0;
 $82 = $81 & 8192;
 $83 = ($82|0)==(0);
 do {
  if ($83) {
   $114 = (($this) + 52|0);
   $115 = HEAP32[$114>>2]|0;
   $$mask$i = $115 & -1073741824;
   $116 = ($$mask$i|0)==(-1073741824);
   if ($116) {
    STACKTOP = sp;return;
   }
   $117 = (($this) + 64|0);
   $118 = (__ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($117,$bodyTarget)|0);
   if ($118) {
    $$phi$trans$insert = (($bodyTarget) + 12|0);
    $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
    $$pre6 = Math_fround(HEAPF32[$bodyTarget>>2]);
    $$phi$trans$insert7 = (($bodyTarget) + 4|0);
    $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
    $$phi$trans$insert9 = (($bodyTarget) + 8|0);
    $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert9>>2]);
    $$phi$trans$insert11 = (($bodyTarget) + 16|0);
    $$pre12 = Math_fround(HEAPF32[$$phi$trans$insert11>>2]);
    $$phi$trans$insert13 = (($bodyTarget) + 20|0);
    $$pre14 = Math_fround(HEAPF32[$$phi$trans$insert13>>2]);
    $$phi$trans$insert15 = (($bodyTarget) + 24|0);
    $$pre16 = Math_fround(HEAPF32[$$phi$trans$insert15>>2]);
    $160 = $$pre;$163 = $$pre6;$165 = $$pre8;$168 = $$pre10;$195 = $$pre12;$197 = $$pre14;$199 = $$pre16;
    break;
   } else {
    STACKTOP = sp;return;
   }
  } else {
   $84 = (($this) + 56|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($85|0)==(0|0);
   if ($86) {
    $87 = HEAP32[$32>>2]|0;
    $88 = (($this) + 52|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = $89 >>> 24;
    $91 = $90 & 15;
    $92 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($87,$91)|0);
    HEAP32[$84>>2] = $92;
    $94 = $92;
   } else {
    $94 = $85;
   }
   $93 = (($94) + 192|0);
   $95 = Math_fround(HEAPF32[$93>>2]);
   HEAPF32[$bodyTarget>>2] = $95;
   $96 = (($94) + 196|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = (($bodyTarget) + 4|0);
   HEAPF32[$98>>2] = $97;
   $99 = (($94) + 200|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = (($bodyTarget) + 8|0);
   HEAPF32[$101>>2] = $100;
   $102 = (($94) + 204|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = (($bodyTarget) + 12|0);
   HEAPF32[$104>>2] = $103;
   $105 = (($94) + 208|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = (($bodyTarget) + 16|0);
   HEAPF32[$107>>2] = $106;
   $108 = (($94) + 212|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = (($bodyTarget) + 20|0);
   HEAPF32[$110>>2] = $109;
   $111 = (($94) + 216|0);
   $112 = Math_fround(HEAPF32[$111>>2]);
   $113 = (($bodyTarget) + 24|0);
   HEAPF32[$113>>2] = $112;
   $160 = $103;$163 = $95;$165 = $97;$168 = $100;$195 = $106;$197 = $109;$199 = $112;
  }
 } while(0);
 $119 = Math_fround($58 * Math_fround(-2.0));
 $120 = Math_fround($60 * Math_fround(-2.0));
 $121 = Math_fround($62 * Math_fround(-2.0));
 $122 = Math_fround($56 * $56);
 $123 = Math_fround($122 + Math_fround(-0.5));
 $124 = Math_fround($49 * $119);
 $125 = Math_fround($52 * $120);
 $126 = Math_fround($124 + $125);
 $127 = Math_fround($54 * $121);
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($119 * $123);
 $130 = Math_fround($52 * $121);
 $131 = Math_fround($54 * $120);
 $132 = Math_fround($130 - $131);
 $133 = Math_fround($56 * $132);
 $134 = Math_fround($129 - $133);
 $135 = Math_fround($49 * $128);
 $136 = Math_fround($135 + $134);
 $137 = Math_fround($123 * $120);
 $138 = Math_fround($54 * $119);
 $139 = Math_fround($49 * $121);
 $140 = Math_fround($138 - $139);
 $141 = Math_fround($56 * $140);
 $142 = Math_fround($137 - $141);
 $143 = Math_fround($52 * $128);
 $144 = Math_fround($143 + $142);
 $145 = Math_fround($123 * $121);
 $146 = Math_fround($49 * $120);
 $147 = Math_fround($52 * $119);
 $148 = Math_fround($146 - $147);
 $149 = Math_fround($56 * $148);
 $150 = Math_fround($145 - $149);
 $151 = Math_fround($54 * $128);
 $152 = Math_fround($150 + $151);
 $153 = Math_fround(-$49);
 $154 = Math_fround(-$52);
 $155 = Math_fround(-$54);
 $156 = Math_fround($136 * Math_fround(2.0));
 $157 = Math_fround($144 * Math_fround(2.0));
 $158 = Math_fround($152 * Math_fround(2.0));
 $159 = Math_fround($160 * $160);
 $161 = Math_fround($159 + Math_fround(-0.5));
 $162 = Math_fround($156 * $163);
 $164 = Math_fround($157 * $165);
 $166 = Math_fround($162 + $164);
 $167 = Math_fround($158 * $168);
 $169 = Math_fround($166 + $167);
 $170 = Math_fround($156 * $161);
 $171 = Math_fround($158 * $165);
 $172 = Math_fround($157 * $168);
 $173 = Math_fround($171 - $172);
 $174 = Math_fround($160 * $173);
 $175 = Math_fround($170 + $174);
 $176 = Math_fround($163 * $169);
 $177 = Math_fround($176 + $175);
 $178 = Math_fround($157 * $161);
 $179 = Math_fround($156 * $168);
 $180 = Math_fround($158 * $163);
 $181 = Math_fround($179 - $180);
 $182 = Math_fround($160 * $181);
 $183 = Math_fround($178 + $182);
 $184 = Math_fround($165 * $169);
 $185 = Math_fround($184 + $183);
 $186 = Math_fround($158 * $161);
 $187 = Math_fround($157 * $163);
 $188 = Math_fround($156 * $165);
 $189 = Math_fround($187 - $188);
 $190 = Math_fround($160 * $189);
 $191 = Math_fround($186 + $190);
 $192 = Math_fround($168 * $169);
 $193 = Math_fround($191 + $192);
 $194 = Math_fround($195 + $177);
 $196 = Math_fround($197 + $185);
 $198 = Math_fround($199 + $193);
 $200 = Math_fround($160 * $153);
 $201 = Math_fround($56 * $163);
 $202 = Math_fround($200 + $201);
 $203 = Math_fround($165 * $155);
 $204 = Math_fround($202 + $203);
 $205 = Math_fround($168 * $154);
 $206 = Math_fround($204 - $205);
 $207 = Math_fround($160 * $154);
 $208 = Math_fround($56 * $165);
 $209 = Math_fround($207 + $208);
 $210 = Math_fround($168 * $153);
 $211 = Math_fround($210 + $209);
 $212 = Math_fround($163 * $155);
 $213 = Math_fround($211 - $212);
 $214 = Math_fround($160 * $155);
 $215 = Math_fround($56 * $168);
 $216 = Math_fround($214 + $215);
 $217 = Math_fround($163 * $154);
 $218 = Math_fround($217 + $216);
 $219 = Math_fround($165 * $153);
 $220 = Math_fround($218 - $219);
 $221 = Math_fround($56 * $160);
 $222 = Math_fround($163 * $153);
 $223 = Math_fround($221 - $222);
 $224 = Math_fround($165 * $154);
 $225 = Math_fround($223 - $224);
 $226 = Math_fround($168 * $155);
 $227 = Math_fround($225 - $226);
 HEAPF32[$actorTarget>>2] = $206;
 $228 = (($actorTarget) + 4|0);
 HEAPF32[$228>>2] = $213;
 $229 = (($actorTarget) + 8|0);
 HEAPF32[$229>>2] = $220;
 $230 = (($actorTarget) + 12|0);
 HEAPF32[$230>>2] = $227;
 $231 = (($actorTarget) + 16|0);
 HEAPF32[$231>>2] = $194;
 $232 = (($actorTarget) + 20|0);
 HEAPF32[$232>>2] = $196;
 $233 = (($actorTarget) + 24|0);
 HEAPF32[$233>>2] = $198;
 __ZN5physx14NpRigidDynamic26setKinematicTargetInternalERKNS_11PxTransformE($this,$actorTarget);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25setCMassLocalPoseInternalERKNS_11PxTransformE($this,$body2Actor) {
 $this = $this|0;
 $body2Actor = $body2Actor|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0;
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $newBody2World = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $newBody2World = sp + 28|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$this);
 $4 = (($body2Actor) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = (($body2Actor) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * Math_fround(2.0));
 $10 = (($body2Actor) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * Math_fround(2.0));
 $13 = (($0) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $14);
 $16 = Math_fround($15 + Math_fround(-0.5));
 $17 = Math_fround(HEAPF32[$0>>2]);
 $18 = Math_fround($6 * $17);
 $19 = (($0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($9 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($0) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($12 * $24);
 $26 = Math_fround($22 + $25);
 $27 = Math_fround($6 * $16);
 $28 = Math_fround($12 * $20);
 $29 = Math_fround($9 * $24);
 $30 = Math_fround($28 - $29);
 $31 = Math_fround($14 * $30);
 $32 = Math_fround($27 + $31);
 $33 = Math_fround($17 * $26);
 $34 = Math_fround($33 + $32);
 $35 = Math_fround($9 * $16);
 $36 = Math_fround($6 * $24);
 $37 = Math_fround($12 * $17);
 $38 = Math_fround($36 - $37);
 $39 = Math_fround($14 * $38);
 $40 = Math_fround($35 + $39);
 $41 = Math_fround($20 * $26);
 $42 = Math_fround($41 + $40);
 $43 = Math_fround($12 * $16);
 $44 = Math_fround($9 * $17);
 $45 = Math_fround($6 * $20);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($14 * $46);
 $48 = Math_fround($43 + $47);
 $49 = Math_fround($24 * $26);
 $50 = Math_fround($48 + $49);
 $51 = (($0) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 + $34);
 $54 = (($0) + 20|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 + $42);
 $57 = (($0) + 24|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 + $50);
 $60 = Math_fround(HEAPF32[$body2Actor>>2]);
 $61 = Math_fround($14 * $60);
 $62 = (($body2Actor) + 12|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($17 * $63);
 $65 = Math_fround($61 + $64);
 $66 = (($body2Actor) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($20 * $67);
 $69 = Math_fround($65 + $68);
 $70 = (($body2Actor) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($24 * $71);
 $73 = Math_fround($69 - $72);
 $74 = Math_fround($14 * $71);
 $75 = Math_fround($20 * $63);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($24 * $60);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($17 * $67);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($14 * $67);
 $82 = Math_fround($24 * $63);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($17 * $71);
 $85 = Math_fround($84 + $83);
 $86 = Math_fround($20 * $60);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($14 * $63);
 $89 = Math_fround($17 * $60);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($20 * $71);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($24 * $67);
 $94 = Math_fround($92 - $93);
 HEAPF32[$newBody2World>>2] = $73;
 $95 = (($newBody2World) + 4|0);
 HEAPF32[$95>>2] = $80;
 $96 = (($newBody2World) + 8|0);
 HEAPF32[$96>>2] = $87;
 $97 = (($newBody2World) + 12|0);
 HEAPF32[$97>>2] = $94;
 $98 = (($newBody2World) + 16|0);
 HEAPF32[$98>>2] = $53;
 $99 = (($newBody2World) + 20|0);
 HEAPF32[$99>>2] = $56;
 $100 = (($newBody2World) + 24|0);
 HEAPF32[$100>>2] = $59;
 $101 = (($this) + 48|0);
 $102 = (($this) + 224|0);
 HEAPF32[$102>>2] = $73;
 $103 = (($this) + 228|0);
 HEAPF32[$103>>2] = $80;
 $104 = (($this) + 232|0);
 HEAPF32[$104>>2] = $87;
 $105 = (($this) + 236|0);
 HEAPF32[$105>>2] = $94;
 $106 = (($this) + 240|0);
 HEAPF32[$106>>2] = $53;
 $107 = (($this) + 244|0);
 HEAPF32[$107>>2] = $56;
 $108 = (($this) + 248|0);
 HEAPF32[$108>>2] = $59;
 $109 = (($this) + 52|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = $110 >>> 30;
 if ((($111|0) == 2)) {
  $112 = HEAP32[$101>>2]|0;
  $113 = (($112) + 2417|0);
  $114 = HEAP8[$113>>0]|0;
  $115 = ($114<<24>>24)==(0);
  if ($115) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($111|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $116 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore13setBody2WorldERKNS_11PxTransformE($116,$newBody2World);
 }
 else if ((label|0) == 4) {
  $117 = (($this) + 284|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = $118 & 65536;
  $120 = ($119|0)==(0);
  if ($120) {
   $121 = $118 | 131072;
   HEAP32[$117>>2] = $121;
  }
  $122 = HEAP32[$101>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($122,$101);
  $123 = HEAP32[$117>>2]|0;
  $124 = $123 | 65536;
  HEAP32[$117>>2] = $124;
 }
 $125 = HEAP32[$109>>2]|0;
 $126 = $125 >>> 30;
 if ((($126|0) == 2)) {
  $127 = HEAP32[$101>>2]|0;
  $128 = (($127) + 2417|0);
  $129 = HEAP8[$128>>0]|0;
  $130 = ($129<<24>>24)==(0);
  if ($130) {
   label = 10;
  } else {
   $$pre$phi$i$iZ2D = $101;
   label = 11;
  }
 } else if ((($126|0) == 3)) {
  $$pre$phi$i$iZ2D = $101;
  label = 11;
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $131 = Math_fround(HEAPF32[$body2Actor>>2]);
  $132 = (($this) + 112|0);
  HEAPF32[$132>>2] = $131;
  $133 = Math_fround(HEAPF32[$70>>2]);
  $134 = (($this) + 116|0);
  HEAPF32[$134>>2] = $133;
  $135 = Math_fround(HEAPF32[$66>>2]);
  $136 = (($this) + 120|0);
  HEAPF32[$136>>2] = $135;
  $137 = Math_fround(HEAPF32[$62>>2]);
  $138 = (($this) + 124|0);
  HEAPF32[$138>>2] = $137;
  $139 = Math_fround(HEAPF32[$4>>2]);
  $140 = (($this) + 128|0);
  HEAPF32[$140>>2] = $139;
  $141 = Math_fround(HEAPF32[$7>>2]);
  $142 = (($this) + 132|0);
  HEAPF32[$142>>2] = $141;
  $143 = Math_fround(HEAPF32[$10>>2]);
  $144 = (($this) + 136|0);
  HEAPF32[$144>>2] = $143;
 }
 else if ((label|0) == 11) {
  $145 = (($this) + 56|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = ($146|0)==(0|0);
  if ($147) {
   $148 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $149 = $125 >>> 24;
   $150 = $149 & 15;
   $151 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($148,$150)|0);
   HEAP32[$145>>2] = $151;
   $154 = $151;
  } else {
   $154 = $146;
  }
  $152 = Math_fround(HEAPF32[$body2Actor>>2]);
  $153 = (($154) + 144|0);
  HEAPF32[$153>>2] = $152;
  $155 = Math_fround(HEAPF32[$70>>2]);
  $156 = (($154) + 148|0);
  HEAPF32[$156>>2] = $155;
  $157 = Math_fround(HEAPF32[$66>>2]);
  $158 = (($154) + 152|0);
  HEAPF32[$158>>2] = $157;
  $159 = Math_fround(HEAPF32[$62>>2]);
  $160 = (($154) + 156|0);
  HEAPF32[$160>>2] = $159;
  $161 = Math_fround(HEAPF32[$4>>2]);
  $162 = (($154) + 160|0);
  HEAPF32[$162>>2] = $161;
  $163 = Math_fround(HEAPF32[$7>>2]);
  $164 = (($154) + 164|0);
  HEAPF32[$164>>2] = $163;
  $165 = Math_fround(HEAPF32[$10>>2]);
  $166 = (($154) + 168|0);
  HEAPF32[$166>>2] = $165;
  $167 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($167,$101);
  $168 = (($this) + 284|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = $169 | 512;
  HEAP32[$168>>2] = $170;
 }
 $171 = (($this) + 16|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = ($172|0)==(0|0);
 if ($173) {
  STACKTOP = sp;return;
 }
 $174 = (($172) + 36|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = (($172) + 40|0);
 $177 = HEAP32[$176>>2]|0;
 $178 = ($177|0)==(0);
 if ($178) {
  STACKTOP = sp;return;
 }
 $180 = 0;
 while(1) {
  $179 = (($180) + 1)|0;
  $181 = (($175) + ($180<<3)|0);
  $182 = HEAP8[$181>>0]|0;
  $183 = ($182<<24>>24)==(0);
  if ($183) {
   $185 = ((($175) + ($180<<3)|0) + 4|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = ($186|0)==(0|0);
   if ($187) {
    label = 21;
    break;
   }
   __ZN5physx12NpConstraint8comShiftEPNS_12PxRigidActorE($186,$this);
  }
  $184 = ($179>>>0)<($177>>>0);
  if ($184) {
   $180 = $179;
  } else {
   label = 21;
   break;
  }
 }
 if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic16setLinearDampingEf($this,$linearDamping) {
 $this = $this|0;
 $linearDamping = Math_fround($linearDamping);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = (($this) + 64|0);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc8BodyCore16setLinearDampingEf($1,$linearDamping);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 108|0);
 HEAPF32[$16>>2] = $linearDamping;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = (($this) + 284|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 | 4;
 HEAP32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic16getLinearDampingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 64|0);
  $18 = (Math_fround(__ZNK5physx2Sc8BodyCore16getLinearDampingEv($17)));
  $19 = $18;
  STACKTOP = sp;return (Math_fround($19));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 108|0);
 $16 = Math_fround(HEAPF32[$14>>2]);
 $19 = $16;
 STACKTOP = sp;return (Math_fround($19));
}
function __ZN5physx14NpRigidDynamic17setAngularDampingEf($this,$angularDamping) {
 $this = $this|0;
 $angularDamping = Math_fround($angularDamping);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = (($this) + 64|0);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc8BodyCore17setAngularDampingEf($1,$angularDamping);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 112|0);
 HEAPF32[$16>>2] = $angularDamping;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = (($this) + 284|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 | 8;
 HEAP32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic17getAngularDampingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 8;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 64|0);
  $18 = (Math_fround(__ZNK5physx2Sc8BodyCore17getAngularDampingEv($17)));
  $19 = $18;
  STACKTOP = sp;return (Math_fround($19));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 112|0);
 $16 = Math_fround(HEAPF32[$14>>2]);
 $19 = $16;
 STACKTOP = sp;return (Math_fround($19));
}
function __ZN5physx14NpRigidDynamic17setLinearVelocityERKNS_6PxVec3Eb($this,$velocity,$autowake) {
 $this = $this|0;
 $velocity = $velocity|0;
 $autowake = $autowake|0;
 var $$$forceWakeUp$i = 0, $$forceWakeUp$i = 0, $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $needsWakingUp$0$off0$i = 0, $not$$i = 0;
 var $or$cond$i = 0, $phitmp = 0, $wakeCounter$0$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = (($this) + 48|0);
 $2 = Math_fround(HEAPF32[$velocity>>2]);
 $3 = (($this) + 252|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($velocity) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 256|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($velocity) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 260|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($this) + 52|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 3)) {
  $$pre$i = HEAP32[$1>>2]|0;
  $23 = $$pre$i;
  label = 5;
 } else if ((($12|0) == 2)) {
  $13 = HEAP32[$1>>2]|0;
  $14 = (($13) + 2416|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   label = 4;
  } else {
   $23 = $13;
   label = 5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $17 = Math_fround(HEAPF32[$velocity>>2]);
  $18 = (($this) + 144|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround(HEAPF32[$4>>2]);
  $20 = (($this) + 148|0);
  HEAPF32[$20>>2] = $19;
  $21 = Math_fround(HEAPF32[$7>>2]);
  $22 = (($this) + 152|0);
  HEAPF32[$22>>2] = $21;
 }
 else if ((label|0) == 5) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($23,$1);
  $24 = (($this) + 284|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 | 262144;
  HEAP32[$24>>2] = $26;
 }
 $27 = ($0|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = Math_fround(HEAPF32[$velocity>>2]);
 $29 = $28 == Math_fround(0.0);
 if ($29) {
  $30 = Math_fround(HEAPF32[$4>>2]);
  $31 = $30 == Math_fround(0.0);
  if ($31) {
   $32 = Math_fround(HEAPF32[$7>>2]);
   $phitmp = $32 != Math_fround(0.0);
   $40 = $phitmp;
  } else {
   $40 = 1;
  }
 } else {
  $40 = 1;
 }
 $33 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $34 = (($33) + 2860|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($this) + 276|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($this) + 280|0);
 $39 = HEAP32[$38>>2]|0;
 $$forceWakeUp$i = $40 | $autowake;
 $not$$i = ($39|0)!=(0);
 $$$forceWakeUp$i = $$forceWakeUp$i & $not$$i;
 $41 = $37 < $35;
 $or$cond$i = $41 & $autowake;
 $wakeCounter$0$i = $or$cond$i ? $35 : $37;
 $needsWakingUp$0$off0$i = $or$cond$i | $$$forceWakeUp$i;
 if (!($needsWakingUp$0$off0$i)) {
  STACKTOP = sp;return;
 }
 $42 = HEAP32[$10>>2]|0;
 $43 = $42 >>> 30;
 if ((($43|0) == 3)) {
  $$pre$i$i = HEAP32[$1>>2]|0;
  $49 = $$pre$i$i;
  label = 15;
 } else if ((($43|0) == 2)) {
  $44 = HEAP32[$1>>2]|0;
  $45 = (($44) + 2416|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   label = 14;
  } else {
   $49 = $44;
   label = 15;
  }
 } else {
  label = 14;
 }
 if ((label|0) == 14) {
  HEAP32[$38>>2] = 0;
  HEAPF32[$36>>2] = $wakeCounter$0$i;
  $48 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($48,$wakeCounter$0$i,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  HEAP32[$38>>2] = 0;
  HEAPF32[$36>>2] = $wakeCounter$0$i;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($49,$1);
  $50 = (($this) + 284|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = $51 & -7340033;
  $53 = $52 | 5242880;
  HEAP32[$50>>2] = $53;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic29wakeUpInternalNoKinematicTestERNS_3Scb4BodyEbb($this,$body,$forceWakeUp,$autowake) {
 $this = $this|0;
 $body = $body|0;
 $forceWakeUp = $forceWakeUp|0;
 $autowake = $autowake|0;
 var $$$forceWakeUp = 0, $$forceWakeUp = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $needsWakingUp$0$off0 = 0, $not$ = 0, $or$cond = 0, $wakeCounter$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = (($0) + 2860|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($body) + 228|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($body) + 232|0);
 $6 = HEAP32[$5>>2]|0;
 $$forceWakeUp = $autowake | $forceWakeUp;
 $not$ = ($6|0)!=(0);
 $$$forceWakeUp = $$forceWakeUp & $not$;
 $7 = $4 < $2;
 $or$cond = $7 & $autowake;
 $wakeCounter$0 = $or$cond ? $2 : $4;
 $needsWakingUp$0$off0 = $or$cond | $$$forceWakeUp;
 if (!($needsWakingUp$0$off0)) {
  STACKTOP = sp;return;
 }
 $8 = (($body) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 30;
 if ((($10|0) == 3)) {
  $$pre$i = HEAP32[$body>>2]|0;
  $16 = $$pre$i;
  label = 6;
 } else if ((($10|0) == 2)) {
  $11 = HEAP32[$body>>2]|0;
  $12 = (($11) + 2416|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   label = 5;
  } else {
   $16 = $11;
   label = 6;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  HEAP32[$5>>2] = 0;
  HEAPF32[$3>>2] = $wakeCounter$0;
  $15 = (($body) + 16|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($15,$wakeCounter$0,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  HEAP32[$5>>2] = 0;
  HEAPF32[$3>>2] = $wakeCounter$0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($16,$body);
  $17 = (($body) + 236|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & -7340033;
  $20 = $19 | 5242880;
  HEAP32[$17>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic18setAngularVelocityERKNS_6PxVec3Eb($this,$velocity,$autowake) {
 $this = $this|0;
 $velocity = $velocity|0;
 $autowake = $autowake|0;
 var $$$forceWakeUp$i = 0, $$forceWakeUp$i = 0, $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $needsWakingUp$0$off0$i = 0, $not$$i = 0;
 var $or$cond$i = 0, $phitmp = 0, $wakeCounter$0$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = (($this) + 48|0);
 $2 = Math_fround(HEAPF32[$velocity>>2]);
 $3 = (($this) + 264|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($velocity) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 268|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($velocity) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 272|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($this) + 52|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 3)) {
  $$pre$i = HEAP32[$1>>2]|0;
  $23 = $$pre$i;
  label = 5;
 } else if ((($12|0) == 2)) {
  $13 = HEAP32[$1>>2]|0;
  $14 = (($13) + 2416|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   label = 4;
  } else {
   $23 = $13;
   label = 5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $17 = Math_fround(HEAPF32[$velocity>>2]);
  $18 = (($this) + 160|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround(HEAPF32[$4>>2]);
  $20 = (($this) + 164|0);
  HEAPF32[$20>>2] = $19;
  $21 = Math_fround(HEAPF32[$7>>2]);
  $22 = (($this) + 168|0);
  HEAPF32[$22>>2] = $21;
 }
 else if ((label|0) == 5) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($23,$1);
  $24 = (($this) + 284|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 | 524288;
  HEAP32[$24>>2] = $26;
 }
 $27 = ($0|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = Math_fround(HEAPF32[$velocity>>2]);
 $29 = $28 == Math_fround(0.0);
 if ($29) {
  $30 = Math_fround(HEAPF32[$4>>2]);
  $31 = $30 == Math_fround(0.0);
  if ($31) {
   $32 = Math_fround(HEAPF32[$7>>2]);
   $phitmp = $32 != Math_fround(0.0);
   $40 = $phitmp;
  } else {
   $40 = 1;
  }
 } else {
  $40 = 1;
 }
 $33 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $34 = (($33) + 2860|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($this) + 276|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($this) + 280|0);
 $39 = HEAP32[$38>>2]|0;
 $$forceWakeUp$i = $40 | $autowake;
 $not$$i = ($39|0)!=(0);
 $$$forceWakeUp$i = $$forceWakeUp$i & $not$$i;
 $41 = $37 < $35;
 $or$cond$i = $41 & $autowake;
 $wakeCounter$0$i = $or$cond$i ? $35 : $37;
 $needsWakingUp$0$off0$i = $or$cond$i | $$$forceWakeUp$i;
 if (!($needsWakingUp$0$off0$i)) {
  STACKTOP = sp;return;
 }
 $42 = HEAP32[$10>>2]|0;
 $43 = $42 >>> 30;
 if ((($43|0) == 3)) {
  $$pre$i$i = HEAP32[$1>>2]|0;
  $49 = $$pre$i$i;
  label = 15;
 } else if ((($43|0) == 2)) {
  $44 = HEAP32[$1>>2]|0;
  $45 = (($44) + 2416|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   label = 14;
  } else {
   $49 = $44;
   label = 15;
  }
 } else {
  label = 14;
 }
 if ((label|0) == 14) {
  HEAP32[$38>>2] = 0;
  HEAPF32[$36>>2] = $wakeCounter$0$i;
  $48 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($48,$wakeCounter$0$i,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  HEAP32[$38>>2] = 0;
  HEAPF32[$36>>2] = $wakeCounter$0$i;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($49,$1);
  $50 = (($this) + 284|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = $51 & -7340033;
  $53 = $52 | 5242880;
  HEAP32[$50>>2] = $53;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic21setMaxAngularVelocityEf($this,$maxAngularVelocity) {
 $this = $this|0;
 $maxAngularVelocity = Math_fround($maxAngularVelocity);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = Math_fround($maxAngularVelocity * $maxAngularVelocity);
 $2 = (($this) + 64|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 >>> 30;
 if ((($5|0) == 2)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = (($6) + 2417|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($5|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc8BodyCore14setMaxAngVelSqEf($2,$1);
  STACKTOP = sp;return;
 }
 $10 = (($this) + 56|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $14 = $4 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 116|0);
 HEAPF32[$17>>2] = $1;
 $19 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($19,$0);
 $20 = (($this) + 284|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 | 16;
 HEAP32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic21getMaxAngularVelocityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 64|0);
  $18 = (Math_fround(__ZNK5physx2Sc8BodyCore14getMaxAngVelSqEv($17)));
  $19 = $18;
  $20 = (Math_fround(Math_sqrt((Math_fround($19)))));
  STACKTOP = sp;return (Math_fround($20));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 116|0);
 $16 = Math_fround(HEAPF32[$14>>2]);
 $19 = $16;
 $20 = (Math_fround(Math_sqrt((Math_fround($19)))));
 STACKTOP = sp;return (Math_fround($20));
}
function __ZN5physx14NpRigidDynamic8addForceERKNS_6PxVec3ENS_11PxForceMode4EnumEb($this,$force,$mode,$autowake) {
 $this = $this|0;
 $force = $force|0;
 $mode = $mode|0;
 $autowake = $autowake|0;
 var $$$forceWakeUp$i = 0, $$forceWakeUp$i = 0, $$pre$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $needsWakingUp$0$off0$i = 0, $not$$i = 0, $or$cond$i = 0, $phitmp = 0, $wakeCounter$0$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $0 = (($this) + 48|0);
 __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE15addSpatialForceEPKNS_6PxVec3ES5_NS_11PxForceMode4EnumE($this,$force,0,$mode);
 $1 = Math_fround(HEAPF32[$force>>2]);
 $2 = $1 == Math_fround(0.0);
 if ($2) {
  $3 = (($force) + 4|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(0.0);
  if ($5) {
   $6 = (($force) + 8|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $phitmp = $7 != Math_fround(0.0);
   $15 = $phitmp;
  } else {
   $15 = 1;
  }
 } else {
  $15 = 1;
 }
 $8 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $9 = (($8) + 2860|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 276|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 280|0);
 $14 = HEAP32[$13>>2]|0;
 $$forceWakeUp$i = $15 | $autowake;
 $not$$i = ($14|0)!=(0);
 $$$forceWakeUp$i = $$forceWakeUp$i & $not$$i;
 $16 = $12 < $10;
 $or$cond$i = $16 & $autowake;
 $wakeCounter$0$i = $or$cond$i ? $10 : $12;
 $needsWakingUp$0$off0$i = $or$cond$i | $$$forceWakeUp$i;
 if (!($needsWakingUp$0$off0$i)) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 >>> 30;
 if ((($19|0) == 3)) {
  $$pre$i$i = HEAP32[$0>>2]|0;
  $25 = $$pre$i$i;
  label = 9;
 } else if ((($19|0) == 2)) {
  $20 = HEAP32[$0>>2]|0;
  $21 = (($20) + 2416|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   label = 8;
  } else {
   $25 = $20;
   label = 9;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  HEAP32[$13>>2] = 0;
  HEAPF32[$11>>2] = $wakeCounter$0$i;
  $24 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($24,$wakeCounter$0$i,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 9) {
  HEAP32[$13>>2] = 0;
  HEAPF32[$11>>2] = $wakeCounter$0$i;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($25,$0);
  $26 = (($this) + 284|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 & -7340033;
  $29 = $28 | 5242880;
  HEAP32[$26>>2] = $29;
  STACKTOP = sp;return;
 }
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE15addSpatialForceEPKNS_6PxVec3ES5_NS_11PxForceMode4EnumE($this,$force,$torque,$mode) {
 $this = $this|0;
 $force = $force|0;
 $torque = $torque|0;
 $mode = $mode|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$pre = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0;
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $angAcc = 0, $angVelDelta = 0, $linAcc = 0, $linVelDelta = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $linAcc = sp + 108|0;
 $angAcc = sp;
 $0 = sp + 12|0;
 $linVelDelta = sp + 48|0;
 $angVelDelta = sp + 60|0;
 $1 = sp + 72|0;
 if ((($mode|0) == 0)) {
  $2 = ($force|0)==(0|0);
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (($this) + 284|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = $4 & 1;
   $6 = ($5|0)==(0);
   if ($6) {
    $20 = (($this) + 64|0);
    $21 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($20)));
    $24 = $21;
   } else {
    $7 = (($this) + 56|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $10 = (($this) + 48|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($this) + 52|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = $13 >>> 24;
     $15 = $14 & 15;
     $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$15)|0);
     HEAP32[$7>>2] = $16;
     $18 = $16;
    } else {
     $18 = $8;
    }
    $17 = (($18) + 92|0);
    $19 = Math_fround(HEAPF32[$17>>2]);
    $24 = $19;
   }
   $22 = Math_fround(HEAPF32[$force>>2]);
   $23 = Math_fround($24 * $22);
   $25 = (($force) + 4|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = Math_fround($24 * $26);
   $28 = (($force) + 8|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($24 * $29);
   HEAPF32[$linAcc>>2] = $23;
   $31 = (($linAcc) + 4|0);
   HEAPF32[$31>>2] = $27;
   $32 = (($linAcc) + 8|0);
   HEAPF32[$32>>2] = $30;
   $$0 = $linAcc;
  }
  $33 = ($torque|0)==(0|0);
  $$pre = (($this) + 48|0);
  if ($33) {
   $$01 = 0;
  } else {
   __ZNK5physx3Scb4Body29getGlobalInertiaTensorInverseEv($0,$$pre);
   $34 = Math_fround(HEAPF32[$torque>>2]);
   $35 = Math_fround(HEAPF32[$0>>2]);
   $36 = Math_fround($34 * $35);
   $37 = (($0) + 4|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($34 * $38);
   $40 = (($0) + 8|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = Math_fround($34 * $41);
   $43 = (($torque) + 4|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($0) + 12|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = Math_fround($44 * $46);
   $48 = (($0) + 16|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = Math_fround($44 * $49);
   $51 = (($0) + 20|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $53 = Math_fround($44 * $52);
   $54 = Math_fround($36 + $47);
   $55 = Math_fround($39 + $50);
   $56 = Math_fround($42 + $53);
   $57 = (($torque) + 8|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = (($0) + 24|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround($58 * $60);
   $62 = (($0) + 28|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = Math_fround($58 * $63);
   $65 = (($0) + 32|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = Math_fround($58 * $66);
   $68 = Math_fround($54 + $61);
   $69 = Math_fround($55 + $64);
   $70 = Math_fround($56 + $67);
   HEAPF32[$angAcc>>2] = $68;
   $71 = (($angAcc) + 4|0);
   HEAPF32[$71>>2] = $69;
   $72 = (($angAcc) + 8|0);
   HEAPF32[$72>>2] = $70;
   $$01 = $angAcc;
  }
  __ZN5physx3Scb4Body22addSpatialAccelerationEPKNS_6PxVec3ES4_($$pre,$$0,$$01);
  STACKTOP = sp;return;
 } else if ((($mode|0) == 1)) {
  $74 = ($force|0)==(0|0);
  if ($74) {
   $$1 = 0;
  } else {
   $75 = (($this) + 284|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = $76 & 1;
   $78 = ($77|0)==(0);
   if ($78) {
    $92 = (($this) + 64|0);
    $93 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($92)));
    $96 = $93;
   } else {
    $79 = (($this) + 56|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ($80|0)==(0|0);
    if ($81) {
     $82 = (($this) + 48|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (($this) + 52|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = $85 >>> 24;
     $87 = $86 & 15;
     $88 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($83,$87)|0);
     HEAP32[$79>>2] = $88;
     $90 = $88;
    } else {
     $90 = $80;
    }
    $89 = (($90) + 92|0);
    $91 = Math_fround(HEAPF32[$89>>2]);
    $96 = $91;
   }
   $94 = Math_fround(HEAPF32[$force>>2]);
   $95 = Math_fround($96 * $94);
   $97 = (($force) + 4|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = Math_fround($96 * $98);
   $100 = (($force) + 8|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = Math_fround($96 * $101);
   HEAPF32[$linVelDelta>>2] = $95;
   $103 = (($linVelDelta) + 4|0);
   HEAPF32[$103>>2] = $99;
   $104 = (($linVelDelta) + 8|0);
   HEAPF32[$104>>2] = $102;
   $$1 = $linVelDelta;
  }
  $105 = ($torque|0)==(0|0);
  $$pre15 = (($this) + 48|0);
  if ($105) {
   $$12 = 0;
  } else {
   __ZNK5physx3Scb4Body29getGlobalInertiaTensorInverseEv($1,$$pre15);
   $106 = Math_fround(HEAPF32[$torque>>2]);
   $107 = Math_fround(HEAPF32[$1>>2]);
   $108 = Math_fround($106 * $107);
   $109 = (($1) + 4|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = Math_fround($106 * $110);
   $112 = (($1) + 8|0);
   $113 = Math_fround(HEAPF32[$112>>2]);
   $114 = Math_fround($106 * $113);
   $115 = (($torque) + 4|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   $117 = (($1) + 12|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = Math_fround($116 * $118);
   $120 = (($1) + 16|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = Math_fround($116 * $121);
   $123 = (($1) + 20|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = Math_fround($116 * $124);
   $126 = Math_fround($108 + $119);
   $127 = Math_fround($111 + $122);
   $128 = Math_fround($114 + $125);
   $129 = (($torque) + 8|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = (($1) + 24|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = Math_fround($130 * $132);
   $134 = (($1) + 28|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = Math_fround($130 * $135);
   $137 = (($1) + 32|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   $139 = Math_fround($130 * $138);
   $140 = Math_fround($126 + $133);
   $141 = Math_fround($127 + $136);
   $142 = Math_fround($128 + $139);
   HEAPF32[$angVelDelta>>2] = $140;
   $143 = (($angVelDelta) + 4|0);
   HEAPF32[$143>>2] = $141;
   $144 = (($angVelDelta) + 8|0);
   HEAPF32[$144>>2] = $142;
   $$12 = $angVelDelta;
  }
  __ZN5physx3Scb4Body18addSpatialVelocityEPKNS_6PxVec3ES4_($$pre15,$$1,$$12);
  STACKTOP = sp;return;
 } else if ((($mode|0) == 2)) {
  $145 = (($this) + 48|0);
  __ZN5physx3Scb4Body18addSpatialVelocityEPKNS_6PxVec3ES4_($145,$force,$torque);
  STACKTOP = sp;return;
 } else if ((($mode|0) == 3)) {
  $73 = (($this) + 48|0);
  __ZN5physx3Scb4Body22addSpatialAccelerationEPKNS_6PxVec3ES4_($73,$force,$torque);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic9addTorqueERKNS_6PxVec3ENS_11PxForceMode4EnumEb($this,$torque,$mode,$autowake) {
 $this = $this|0;
 $torque = $torque|0;
 $mode = $mode|0;
 $autowake = $autowake|0;
 var $$$forceWakeUp$i = 0, $$forceWakeUp$i = 0, $$pre$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $needsWakingUp$0$off0$i = 0, $not$$i = 0, $or$cond$i = 0, $phitmp = 0, $wakeCounter$0$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $0 = (($this) + 48|0);
 __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE15addSpatialForceEPKNS_6PxVec3ES5_NS_11PxForceMode4EnumE($this,0,$torque,$mode);
 $1 = Math_fround(HEAPF32[$torque>>2]);
 $2 = $1 == Math_fround(0.0);
 if ($2) {
  $3 = (($torque) + 4|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(0.0);
  if ($5) {
   $6 = (($torque) + 8|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $phitmp = $7 != Math_fround(0.0);
   $15 = $phitmp;
  } else {
   $15 = 1;
  }
 } else {
  $15 = 1;
 }
 $8 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $9 = (($8) + 2860|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 276|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 280|0);
 $14 = HEAP32[$13>>2]|0;
 $$forceWakeUp$i = $15 | $autowake;
 $not$$i = ($14|0)!=(0);
 $$$forceWakeUp$i = $$forceWakeUp$i & $not$$i;
 $16 = $12 < $10;
 $or$cond$i = $16 & $autowake;
 $wakeCounter$0$i = $or$cond$i ? $10 : $12;
 $needsWakingUp$0$off0$i = $or$cond$i | $$$forceWakeUp$i;
 if (!($needsWakingUp$0$off0$i)) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 >>> 30;
 if ((($19|0) == 2)) {
  $20 = HEAP32[$0>>2]|0;
  $21 = (($20) + 2416|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   label = 8;
  } else {
   $25 = $20;
   label = 9;
  }
 } else if ((($19|0) == 3)) {
  $$pre$i$i = HEAP32[$0>>2]|0;
  $25 = $$pre$i$i;
  label = 9;
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  HEAP32[$13>>2] = 0;
  HEAPF32[$11>>2] = $wakeCounter$0$i;
  $24 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($24,$wakeCounter$0$i,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 9) {
  HEAP32[$13>>2] = 0;
  HEAPF32[$11>>2] = $wakeCounter$0$i;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($25,$0);
  $26 = (($this) + 284|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 & -7340033;
  $29 = $28 | 5242880;
  HEAP32[$26>>2] = $29;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic10clearForceENS_11PxForceMode4EnumE($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17clearSpatialForceENS_11PxForceMode4EnumE($this,$mode);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17clearSpatialForceENS_11PxForceMode4EnumE($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($mode|0) == 2)) {
  $63 = (($this) + 48|0);
  $64 = (($this) + 52|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = $65 >>> 30;
  if ((($66|0) == 2)) {
   $67 = HEAP32[$63>>2]|0;
   $68 = (($67) + 2416|0);
   $69 = HEAP8[$68>>0]|0;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    label = 22;
   }
  } else if (!((($66|0) == 3))) {
   label = 22;
  }
  if ((label|0) == 22) {
   $71 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore20clearSpatialVelocityEv($71);
   STACKTOP = sp;return;
  }
  $72 = (($this) + 56|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==(0|0);
  if ($74) {
   $75 = HEAP32[$63>>2]|0;
   $76 = $65 >>> 24;
   $77 = $76 & 15;
   $78 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($75,$77)|0);
   HEAP32[$72>>2] = $78;
   $80 = $78;
  } else {
   $80 = $73;
  }
  $79 = (($80) + 244|0);
  $81 = (($this) + 284|0);
  ;HEAP32[$79+0>>2]=0|0;HEAP32[$79+4>>2]=0|0;HEAP32[$79+8>>2]=0|0;HEAP32[$79+12>>2]=0|0;HEAP32[$79+16>>2]=0|0;HEAP32[$79+20>>2]=0|0;
  $82 = HEAP32[$81>>2]|0;
  $83 = $82 & -32769;
  HEAP32[$81>>2] = $83;
  STACKTOP = sp;return;
 } else if ((($mode|0) == 0)) {
  $0 = (($this) + 48|0);
  $1 = (($this) + 52|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = $2 >>> 30;
  if ((($3|0) == 2)) {
   $4 = HEAP32[$0>>2]|0;
   $5 = (($4) + 2416|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    label = 4;
   }
  } else if (!((($3|0) == 3))) {
   label = 4;
  }
  if ((label|0) == 4) {
   $8 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore24clearSpatialAccelerationEv($8);
   STACKTOP = sp;return;
  }
  $9 = (($this) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $12 = HEAP32[$0>>2]|0;
   $13 = $2 >>> 24;
   $14 = $13 & 15;
   $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
   HEAP32[$9>>2] = $15;
   $17 = $15;
  } else {
   $17 = $10;
  }
  $16 = (($17) + 220|0);
  $18 = (($this) + 284|0);
  ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & -16385;
  HEAP32[$18>>2] = $20;
  STACKTOP = sp;return;
 } else if ((($mode|0) == 3)) {
  $21 = (($this) + 48|0);
  $22 = (($this) + 52|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 >>> 30;
  if ((($24|0) == 2)) {
   $25 = HEAP32[$21>>2]|0;
   $26 = (($25) + 2416|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    label = 10;
   }
  } else if (!((($24|0) == 3))) {
   label = 10;
  }
  if ((label|0) == 10) {
   $29 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore24clearSpatialAccelerationEv($29);
   STACKTOP = sp;return;
  }
  $30 = (($this) + 56|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0|0);
  if ($32) {
   $33 = HEAP32[$21>>2]|0;
   $34 = $23 >>> 24;
   $35 = $34 & 15;
   $36 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($33,$35)|0);
   HEAP32[$30>>2] = $36;
   $38 = $36;
  } else {
   $38 = $31;
  }
  $37 = (($38) + 220|0);
  $39 = (($this) + 284|0);
  ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP32[$37+16>>2]=0|0;HEAP32[$37+20>>2]=0|0;
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & -16385;
  HEAP32[$39>>2] = $41;
  STACKTOP = sp;return;
 } else if ((($mode|0) == 1)) {
  $42 = (($this) + 48|0);
  $43 = (($this) + 52|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 >>> 30;
  if ((($45|0) == 2)) {
   $46 = HEAP32[$42>>2]|0;
   $47 = (($46) + 2416|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    label = 16;
   }
  } else if (!((($45|0) == 3))) {
   label = 16;
  }
  if ((label|0) == 16) {
   $50 = (($this) + 64|0);
   __ZN5physx2Sc8BodyCore20clearSpatialVelocityEv($50);
   STACKTOP = sp;return;
  }
  $51 = (($this) + 56|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   $54 = HEAP32[$42>>2]|0;
   $55 = $44 >>> 24;
   $56 = $55 & 15;
   $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
   HEAP32[$51>>2] = $57;
   $59 = $57;
  } else {
   $59 = $52;
  }
  $58 = (($59) + 244|0);
  $60 = (($this) + 284|0);
  ;HEAP32[$58+0>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;HEAP32[$58+12>>2]=0|0;HEAP32[$58+16>>2]=0|0;HEAP32[$58+20>>2]=0|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = $61 & -32769;
  HEAP32[$60>>2] = $62;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic11clearTorqueENS_11PxForceMode4EnumE($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17clearSpatialForceENS_11PxForceMode4EnumE($this,$mode);
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic10isSleepingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx14NpRigidDynamic17setSleepThresholdEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 if ((($3|0) == 2)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($3|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $8 = (($this) + 208|0);
  HEAPF32[$8>>2] = $threshold;
  STACKTOP = sp;return;
 }
 $9 = (($this) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $2 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 120|0);
 HEAPF32[$16>>2] = $threshold;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = (($this) + 284|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 | 32;
 HEAP32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic17getSleepThresholdEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 208|0);
  $$in$i$i$i = $16;
  $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 120|0);
 $$in$i$i$i = $14;
 $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx14NpRigidDynamic25setStabilizationThresholdEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 if ((($3|0) == 2)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($3|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $8 = (($this) + 212|0);
  HEAPF32[$8>>2] = $threshold;
  STACKTOP = sp;return;
 }
 $9 = (($this) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $2 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 176|0);
 HEAPF32[$16>>2] = $threshold;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = (($this) + 284|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 | 2048;
 HEAP32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic25getStabilizationThresholdEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2048;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 212|0);
  $$in$i$i$i = $16;
  $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 176|0);
 $$in$i$i$i = $14;
 $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx14NpRigidDynamic14setWakeCounterEf($this,$wakeCounterValue) {
 $this = $this|0;
 $wakeCounterValue = Math_fround($wakeCounterValue);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 __ZN5physx3Scb4Body14setWakeCounterEf($0,$wakeCounterValue);
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic14getWakeCounterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 276|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx14NpRigidDynamic6wakeUpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 2844|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 30;
 if ((($6|0) == 2)) {
  $7 = (($1) + 2416|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($6|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $10 = (($this) + 280|0);
  HEAP32[$10>>2] = 0;
  $11 = (($this) + 276|0);
  HEAPF32[$11>>2] = $3;
  $12 = (($this) + 64|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($12,$3,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $13 = (($this) + 280|0);
  HEAP32[$13>>2] = 0;
  $14 = (($this) + 276|0);
  HEAPF32[$14>>2] = $3;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($1,$0);
  $15 = (($this) + 284|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16 & -7340033;
  $18 = $17 | 5242880;
  HEAP32[$15>>2] = $18;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpRigidDynamic10putToSleepEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $0 = (($this) + 48|0);
 __ZN5physx3Scb4Body18putToSleepInternalEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamic24setSolverIterationCountsEjj($this,$positionIters,$velocityIters) {
 $this = $this|0;
 $positionIters = $positionIters|0;
 $velocityIters = $velocityIters|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = $velocityIters << 8;
 $2 = $positionIters & 255;
 $3 = $1 | $2;
 $4 = $3&65535;
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 >>> 30;
 if ((($7|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($7|0) == 2)) {
  $8 = HEAP32[$0>>2]|0;
  $9 = (($8) + 2417|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $12 = (($this) + 110|0);
  HEAP16[$12>>1] = $4;
  STACKTOP = sp;return;
 }
 $13 = (($this) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  $16 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $17 = $6 >>> 24;
  $18 = $17 & 15;
  $19 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($16,$18)|0);
  HEAP32[$13>>2] = $19;
  $21 = $19;
 } else {
  $21 = $14;
 }
 $20 = (($21) + 132|0);
 HEAP16[$20>>1] = $4;
 $22 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($22,$0);
 $23 = (($this) + 284|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 | 256;
 HEAP32[$23>>2] = $25;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic24getSolverIterationCountsERjS1_($this,$positionIters,$velocityIters) {
 $this = $this|0;
 $positionIters = $positionIters|0;
 $velocityIters = $velocityIters|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 256;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 110|0);
  $$in$i$i$i = $16;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 132|0);
  $$in$i$i$i = $14;
 }
 $17 = HEAP16[$$in$i$i$i>>1]|0;
 $18 = $17&65535;
 $19 = $18 >>> 8;
 HEAP32[$velocityIters>>2] = $19;
 $20 = $18 & 255;
 HEAP32[$positionIters>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamic25setContactReportThresholdEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = $threshold < Math_fround(0.0);
 $2 = $1 ? Math_fround(0.0) : $threshold;
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 >>> 30;
 if ((($5|0) == 2)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = (($6) + 2417|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($5|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $10 = (($this) + 172|0);
  HEAPF32[$10>>2] = $2;
  STACKTOP = sp;return;
 }
 $11 = (($this) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $14 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $15 = $4 >>> 24;
  $16 = $15 & 15;
  $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
  HEAP32[$11>>2] = $17;
  $19 = $17;
 } else {
  $19 = $12;
 }
 $18 = (($19) + 128|0);
 HEAPF32[$18>>2] = $2;
 $20 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($20,$0);
 $21 = (($this) + 284|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 | 128;
 HEAP32[$21>>2] = $23;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic25getContactReportThresholdEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 128;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 172|0);
  $$in$i$i$i = $16;
  $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 128|0);
 $$in$i$i$i = $14;
 $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($body,$shapes) {
 $body = $body|0;
 $shapes = $shapes|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($body) + 16|0);
 $1 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($0)|0);
 $2 = (($1) + 20|0);
 $3 = (($2) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(1);
 if ($5) {
  $7 = $2;
 } else {
  $6 = HEAP32[$2>>2]|0;
  $7 = $6;
 }
 HEAP32[$shapes>>2] = $7;
 $8 = $4&65535;
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx14NpRigidDynamic13switchToNoSimEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 __ZN5physx3Scb4Body17switchBodyToNoSimEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb4Body17switchBodyToNoSimEv($this) {
 $this = $this|0;
 var $$mask$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $9 = (($this) + 232|0);
  HEAP32[$9>>2] = 1;
  $10 = (($this) + 204|0);
  ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;HEAP32[$10+24>>2]=0|0;
  $11 = (($this) + 16|0);
  __ZN5physx2Sc8BodyCore10putToSleepEv($11);
  STACKTOP = sp;return;
 }
 $2 = (($0) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZN5physx3Scb5Scene18switchRigidToNoSimERNS0_11RigidObjectEb($0,$this,1);
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 2417|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $12 = (($this) + 232|0);
  HEAP32[$12>>2] = 1;
  $13 = (($this) + 204|0);
  ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;HEAP32[$13+16>>2]=0|0;HEAP32[$13+20>>2]=0|0;HEAP32[$13+24>>2]=0|0;
  $14 = (($this) + 16|0);
  __ZN5physx2Sc8BodyCore10putToSleepEv($14);
 } else {
  __ZN5physx3Scb4Body18putToSleepInternalEv($this);
 }
 $15 = (($this) + 16|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $$mask$i$i = $17 & -1073741824;
 $18 = ($$mask$i$i|0)==(1073741824);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $19 = (($this) + 172|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($15,1)|0);
 $23 = HEAP32[$19>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($22) {
  if ($24) {
   STACKTOP = sp;return;
  }
  $25 = HEAP32[$this>>2]|0;
  $26 = (($25) + 1256|0);
  $27 = HEAP32[$26>>2]|0;
  __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($15,$27,1);
  STACKTOP = sp;return;
 }
 if ($24) {
  STACKTOP = sp;return;
 }
 $28 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($15,0)|0);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$19>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$this>>2]|0;
 $32 = (($31) + 1256|0);
 $33 = HEAP32[$32>>2]|0;
 __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($15,$33,0);
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamic15switchFromNoSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 2417|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 __ZN5physx3Scb5Scene20switchRigidFromNoSimERNS0_11RigidObjectEb($1,$0,1);
 STACKTOP = sp;return;
}
function __ZN5physx14NpRigidDynamic9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$npScene) {
 $this = $this|0;
 $out = $out|0;
 $npScene = $npScene|0;
 var $$in = 0, $$op = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0;
 var $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0;
 var $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 32|0;
 $1 = sp;
 __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$npScene);
 $2 = (($this) + 48|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $14 = $4 >>> 24;
  $15 = $14 & 15;
  $16 = ((444424 + ($15<<2)|0) + 24|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $2;
  $19 = (($17) + ($18))|0;
  $20 = $19;
  $21 = (($20) + 8|0);
  $$in = $21;
 } else {
  $7 = (($this) + 56|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = $4 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($10,$12)|0);
   HEAP32[$7>>2] = $13;
   $128 = $13;
  } else {
   $128 = $8;
  }
  $$in = $128;
 }
 $22 = HEAP16[$$in>>1]|0;
 $23 = $22 & 1;
 $24 = ($23<<16>>16)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$npScene>>2]|0;
 $26 = (($25) + 296|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (Math_fround(FUNCTION_TABLE_fii[$27 & 63]($npScene,0)));
 $29 = HEAP32[$npScene>>2]|0;
 $30 = (($29) + 296|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (Math_fround(FUNCTION_TABLE_fii[$31 & 63]($npScene,3)));
 $33 = Math_fround($28 * $32);
 $34 = $33 != Math_fround(0.0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 $35 = (($this) + 276|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($npScene) + 2860|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 / $38);
 $40 = $39 > Math_fround(1.0);
 $$op = Math_fround($39 * Math_fround(255.0));
 $41 = (~~(($$op))>>>0);
 $42 = $40 ? 255 : $41;
 $43 = (($this) + 280|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0);
 if ($45) {
  $46 = $42 << 16;
  $47 = $42 << 8;
  $48 = $47 | $42;
  $49 = $48 | $46;
  $112 = $49;
 } else {
  $112 = 16711680;
 }
 $50 = (($this) + 284|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = $51 & 2;
 $53 = ($52|0)==(0);
 if ($53) {
  $64 = (($this) + 64|0);
  $65 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($64)|0);
  $67 = $65;
 } else {
  $54 = (($this) + 56|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0|0);
  if ($56) {
   $57 = HEAP32[$2>>2]|0;
   $58 = HEAP32[$3>>2]|0;
   $59 = $58 >>> 24;
   $60 = $59 & 15;
   $61 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($57,$60)|0);
   HEAP32[$54>>2] = $61;
   $63 = $61;
  } else {
   $63 = $55;
  }
  $62 = (($63) + 96|0);
  $67 = $62;
 }
 $66 = Math_fround(HEAPF32[$67>>2]);
 $68 = (($67) + 4|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($67) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = $66 == Math_fround(0.0);
 if ($72) {
  $98 = Math_fround(0.0);
 } else {
  $73 = Math_fround(Math_fround(1.0) / $66);
  $98 = $73;
 }
 $74 = $69 == Math_fround(0.0);
 if ($74) {
  $100 = Math_fround(0.0);
 } else {
  $75 = Math_fround(Math_fround(1.0) / $69);
  $100 = $75;
 }
 $76 = $71 == Math_fround(0.0);
 if ($76) {
  $102 = Math_fround(0.0);
 } else {
  $77 = Math_fround(Math_fround(1.0) / $71);
  $102 = $77;
 }
 $78 = HEAP32[$50>>2]|0;
 $79 = $78 & 1;
 $80 = ($79|0)==(0);
 if ($80) {
  $92 = (($this) + 64|0);
  $93 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($92)));
  $95 = $93;
 } else {
  $81 = (($this) + 56|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(0|0);
  if ($83) {
   $84 = HEAP32[$2>>2]|0;
   $85 = HEAP32[$3>>2]|0;
   $86 = $85 >>> 24;
   $87 = $86 & 15;
   $88 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($84,$87)|0);
   HEAP32[$81>>2] = $88;
   $90 = $88;
  } else {
   $90 = $82;
  }
  $89 = (($90) + 92|0);
  $91 = Math_fround(HEAPF32[$89>>2]);
  $95 = $91;
 }
 $94 = Math_fround(Math_fround(1.0) / $95);
 $96 = Math_fround(Math_fround(6.0) / $94);
 $97 = Math_fround($98 * $96);
 $99 = Math_fround($100 * $96);
 $101 = Math_fround($102 * $96);
 $103 = Math_fround($99 - $97);
 $104 = Math_fround($101 + $103);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($104)))));
 $105 = (Math_fround(Math_sqrt((Math_fround($fabsf$i$i$i)))));
 $106 = Math_fround($97 - $99);
 $107 = Math_fround($101 + $106);
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($107)))));
 $108 = (Math_fround(Math_sqrt((Math_fround($fabsf$i$i1$i)))));
 $109 = Math_fround($97 + $99);
 $110 = Math_fround($109 - $101);
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($110)))));
 $111 = (Math_fround(Math_sqrt((Math_fround($fabsf$i$i2$i)))));
 $113 = (__ZN5physx2Cm12RenderOutputlsEj($out,$112)|0);
 $114 = (($this) + 224|0);
 __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($0,$114);
 $115 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($113,$0)|0);
 $116 = Math_fround($105 * Math_fround(0.5));
 $117 = Math_fround($108 * Math_fround(0.5));
 $118 = Math_fround($111 * Math_fround(0.5));
 $119 = Math_fround(-$116);
 $120 = Math_fround(-$117);
 $121 = Math_fround(-$118);
 HEAPF32[$1>>2] = $119;
 $122 = (($1) + 4|0);
 HEAPF32[$122>>2] = $120;
 $123 = (($1) + 8|0);
 HEAPF32[$123>>2] = $121;
 $124 = (($1) + 12|0);
 HEAPF32[$124>>2] = $116;
 $125 = (($1) + 16|0);
 HEAPF32[$125>>2] = $117;
 $126 = (($1) + 20|0);
 HEAPF32[$126>>2] = $118;
 $127 = (($1) + 24|0);
 HEAP8[$127>>0] = 1;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($115,$1)|0);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$scene) {
 $this = $this|0;
 $out = $out|0;
 $scene = $scene|0;
 var $$0$i = Math_fround(0), $$0$i1 = Math_fround(0), $$0$i3 = Math_fround(0), $$0$i5 = Math_fround(0), $$0$i7 = Math_fround(0), $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0);
 var $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $0 = sp + 336|0;
 $1 = sp + 304|0;
 $2 = sp + 280|0;
 $3 = sp + 216|0;
 $4 = sp + 192|0;
 $5 = sp + 96|0;
 $6 = sp + 64|0;
 $7 = sp;
 $8 = sp + 160|0;
 $9 = (($this) + 20|0);
 __ZN5physx14NpShapeManager9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneERKNS_12PxRigidActorE($9,$out,$scene,$this);
 $10 = (($this) + 48|0);
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 1;
 $14 = ($13|0)==(0);
 if ($14) {
  $22 = $12 >>> 24;
  $23 = $22 & 15;
  $24 = ((444424 + ($23<<2)|0) + 24|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $10;
  $27 = (($25) + ($26))|0;
  $28 = $27;
  $29 = (($28) + 8|0);
  $$in = $29;
 } else {
  $15 = (($this) + 56|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $18 = HEAP32[$10>>2]|0;
   $19 = $12 >>> 24;
   $20 = $19 & 15;
   $21 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($18,$20)|0);
   HEAP32[$15>>2] = $21;
   $174 = $21;
  } else {
   $174 = $16;
  }
  $$in = $174;
 }
 $30 = HEAP16[$$in>>1]|0;
 $31 = $30 & 1;
 $32 = ($31<<16>>16)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($scene) + 3372|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 64;
 $36 = ($35|0)==(0);
 if ($36) {
  label = 10;
 } else {
  $37 = (($scene) + 3012|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   label = 10;
  } else {
   $40 = (($scene) + 2864|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $$0$i5 = $41;$45 = $34;
  }
 }
 if ((label|0) == 10) {
  $42 = (($scene) + 32|0);
  $43 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($42,0)));
  $$pre = HEAP32[$33>>2]|0;
  $$0$i5 = $43;$45 = $$pre;
 }
 $44 = $45 & 64;
 $46 = ($44|0)==(0);
 if ($46) {
  label = 14;
 } else {
  $47 = (($scene) + 3023|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48<<24>>24)==(0);
  if ($49) {
   label = 14;
  } else {
   $50 = (($scene) + 2908|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $$0$i7 = $51;
  }
 }
 if ((label|0) == 14) {
  $52 = (($scene) + 32|0);
  $53 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($52,11)));
  $$0$i7 = $53;
 }
 $54 = Math_fround($$0$i5 * $$0$i7);
 $55 = $54 != Math_fround(0.0);
 if ($55) {
  $56 = HEAP32[$this>>2]|0;
  $57 = (($56) + 84|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 4095]($1,$this);
  __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($0,$1);
  $59 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$0)|0);
  HEAPF32[$2>>2] = $54;
  $60 = (($2) + 4|0);
  HEAPF32[$60>>2] = $54;
  $61 = (($2) + 8|0);
  HEAPF32[$61>>2] = $54;
  $62 = (($2) + 12|0);
  HEAP32[$62>>2] = -65536;
  $63 = (($2) + 16|0);
  HEAP32[$63>>2] = -16711936;
  $64 = (($2) + 20|0);
  HEAP32[$64>>2] = -16776961;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($59,$2)|0);
 }
 $65 = HEAP32[$33>>2]|0;
 $66 = $65 & 64;
 $67 = ($66|0)==(0);
 if ($67) {
  label = 20;
 } else {
  $68 = (($scene) + 3014|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = ($69<<24>>24)==(0);
  if ($70) {
   label = 20;
  } else {
   $71 = (($scene) + 2872|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $$0$i3 = $72;
  }
 }
 if ((label|0) == 20) {
  $73 = (($scene) + 32|0);
  $74 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($73,2)));
  $$0$i3 = $74;
 }
 $75 = Math_fround($$0$i5 * $$0$i3);
 $76 = $75 != Math_fround(0.0);
 if ($76) {
  $77 = (($this) + 224|0);
  __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($3,$77);
  $78 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$3)|0);
  HEAPF32[$4>>2] = $75;
  $79 = (($4) + 4|0);
  HEAPF32[$79>>2] = $75;
  $80 = (($4) + 8|0);
  HEAPF32[$80>>2] = $75;
  $81 = (($4) + 12|0);
  HEAP32[$81>>2] = -65536;
  $82 = (($4) + 16|0);
  HEAP32[$82>>2] = -16711936;
  $83 = (($4) + 20|0);
  HEAP32[$83>>2] = -16776961;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($78,$4)|0);
 }
 $84 = HEAP32[$33>>2]|0;
 $85 = $84 & 64;
 $86 = ($85|0)==(0);
 if ($86) {
  label = 26;
 } else {
  $87 = (($scene) + 3016|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = ($88<<24>>24)==(0);
  if ($89) {
   label = 26;
  } else {
   $90 = (($scene) + 2880|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $$0$i1 = $91;
  }
 }
 if ((label|0) == 26) {
  $92 = (($scene) + 32|0);
  $93 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($92,4)));
  $$0$i1 = $93;
 }
 $94 = Math_fround($$0$i5 * $$0$i1);
 $95 = $94 != Math_fround(0.0);
 if ($95) {
  $96 = (__ZN5physx2Cm12RenderOutputlsEj($out,16777215)|0);
  HEAPF32[$5>>2] = Math_fround(1.0);
  $97 = (($5) + 4|0);
  $98 = (($5) + 20|0);
  ;HEAP32[$97+0>>2]=0|0;HEAP32[$97+4>>2]=0|0;HEAP32[$97+8>>2]=0|0;HEAP32[$97+12>>2]=0|0;
  HEAPF32[$98>>2] = Math_fround(1.0);
  $99 = (($5) + 24|0);
  $100 = (($5) + 40|0);
  ;HEAP32[$99+0>>2]=0|0;HEAP32[$99+4>>2]=0|0;HEAP32[$99+8>>2]=0|0;HEAP32[$99+12>>2]=0|0;
  HEAPF32[$100>>2] = Math_fround(1.0);
  $101 = (($5) + 44|0);
  $102 = (($5) + 60|0);
  ;HEAP32[$101+0>>2]=0|0;HEAP32[$101+4>>2]=0|0;HEAP32[$101+8>>2]=0|0;HEAP32[$101+12>>2]=0|0;
  HEAPF32[$102>>2] = Math_fround(1.0);
  $103 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($96,$5)|0);
  $104 = (($this) + 252|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($94 * $105);
  $107 = (($this) + 256|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($94 * $108);
  $110 = (($this) + 260|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround($94 * $111);
  $113 = Math_fround($94 * Math_fround(0.20000000298023223877));
  $114 = (($this) + 240|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  HEAPF32[$6>>2] = $115;
  $116 = (($6) + 4|0);
  $117 = (($this) + 244|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  HEAPF32[$116>>2] = $118;
  $119 = (($6) + 8|0);
  $120 = (($this) + 248|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  HEAPF32[$119>>2] = $121;
  $122 = Math_fround($106 + $115);
  $123 = Math_fround($109 + $118);
  $124 = Math_fround($112 + $121);
  $125 = (($6) + 12|0);
  HEAPF32[$125>>2] = $122;
  $126 = (($6) + 16|0);
  HEAPF32[$126>>2] = $123;
  $127 = (($6) + 20|0);
  HEAPF32[$127>>2] = $124;
  $128 = (($6) + 24|0);
  HEAPF32[$128>>2] = $113;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($103,$6)|0);
 }
 $129 = HEAP32[$33>>2]|0;
 $130 = $129 & 64;
 $131 = ($130|0)==(0);
 if ($131) {
  label = 32;
 } else {
  $132 = (($scene) + 3017|0);
  $133 = HEAP8[$132>>0]|0;
  $134 = ($133<<24>>24)==(0);
  if ($134) {
   label = 32;
  } else {
   $135 = (($scene) + 2884|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $$0$i = $136;
  }
 }
 if ((label|0) == 32) {
  $137 = (($scene) + 32|0);
  $138 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($137,5)));
  $$0$i = $138;
 }
 $139 = Math_fround($$0$i5 * $$0$i);
 $140 = $139 != Math_fround(0.0);
 if (!($140)) {
  STACKTOP = sp;return;
 }
 $141 = (__ZN5physx2Cm12RenderOutputlsEj($out,0)|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $142 = (($7) + 4|0);
 $143 = (($7) + 20|0);
 ;HEAP32[$142+0>>2]=0|0;HEAP32[$142+4>>2]=0|0;HEAP32[$142+8>>2]=0|0;HEAP32[$142+12>>2]=0|0;
 HEAPF32[$143>>2] = Math_fround(1.0);
 $144 = (($7) + 24|0);
 $145 = (($7) + 40|0);
 ;HEAP32[$144+0>>2]=0|0;HEAP32[$144+4>>2]=0|0;HEAP32[$144+8>>2]=0|0;HEAP32[$144+12>>2]=0|0;
 HEAPF32[$145>>2] = Math_fround(1.0);
 $146 = (($7) + 44|0);
 $147 = (($7) + 60|0);
 ;HEAP32[$146+0>>2]=0|0;HEAP32[$146+4>>2]=0|0;HEAP32[$146+8>>2]=0|0;HEAP32[$146+12>>2]=0|0;
 HEAPF32[$147>>2] = Math_fround(1.0);
 $148 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($141,$7)|0);
 $149 = (($this) + 264|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = Math_fround($139 * $150);
 $152 = (($this) + 268|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = Math_fround($139 * $153);
 $155 = (($this) + 272|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = Math_fround($139 * $156);
 $158 = Math_fround($139 * Math_fround(0.20000000298023223877));
 $159 = (($this) + 240|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 HEAPF32[$8>>2] = $160;
 $161 = (($8) + 4|0);
 $162 = (($this) + 244|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 HEAPF32[$161>>2] = $163;
 $164 = (($8) + 8|0);
 $165 = (($this) + 248|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 HEAPF32[$164>>2] = $166;
 $167 = Math_fround($151 + $160);
 $168 = Math_fround($154 + $163);
 $169 = Math_fround($157 + $166);
 $170 = (($8) + 12|0);
 HEAPF32[$170>>2] = $167;
 $171 = (($8) + 16|0);
 HEAPF32[$171>>2] = $168;
 $172 = (($8) + 20|0);
 HEAPF32[$172>>2] = $169;
 $173 = (($8) + 24|0);
 HEAPF32[$173>>2] = $158;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($148,$8)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx14PxRigidDynamic19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (428584|0);
}
function __ZNK5physx14PxRigidDynamic8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(428584,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $10 = 1;
 } else {
  $2 = (_strcmp(428536,$name)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $10 = 1;
  } else {
   $4 = (_strcmp(428552,$name)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $10 = 1;
   } else {
    $6 = (_strcmp(428568,$name)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     $10 = 1;
    } else {
     $8 = (_strcmp($name,428576)|0);
     $9 = ($8|0)==(0);
     $10 = $9;
    }
   }
  }
 }
 STACKTOP = sp;return ($10|0);
}
function __ZNK5physx14NpRigidDynamic7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE7setNameEPKc($this,$debugName) {
 $this = $this|0;
 $debugName = $debugName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $debugName;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE14getWorldBoundsEf($agg$result,$this,$inflation) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inflation = Math_fround($inflation);
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $bounds = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bounds = sp;
 $0 = (($this) + 20|0);
 __ZNK5physx14NpShapeManager14getWorldBoundsERKNS_12PxRigidActorE($bounds,$0,$this);
 $1 = Math_fround(HEAPF32[$bounds>>2]);
 $2 = (($bounds) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = (($bounds) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($bounds) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 + $8);
 $10 = (($bounds) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($bounds) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 + $13);
 $15 = Math_fround($4 * Math_fround(0.5));
 $16 = Math_fround($9 * Math_fround(0.5));
 $17 = Math_fround($14 * Math_fround(0.5));
 $18 = Math_fround($3 - $1);
 $19 = Math_fround($8 - $6);
 $20 = Math_fround($13 - $11);
 $21 = Math_fround($18 * Math_fround(0.5));
 $22 = Math_fround($19 * Math_fround(0.5));
 $23 = Math_fround($20 * Math_fround(0.5));
 $24 = Math_fround($21 * $inflation);
 $25 = Math_fround($22 * $inflation);
 $26 = Math_fround($23 * $inflation);
 $27 = Math_fround($15 - $24);
 $28 = Math_fround($16 - $25);
 $29 = Math_fround($17 - $26);
 $30 = Math_fround($15 + $24);
 $31 = Math_fround($16 + $25);
 $32 = Math_fround($17 + $26);
 HEAPF32[$agg$result>>2] = $27;
 $33 = (($agg$result) + 4|0);
 HEAPF32[$33>>2] = $28;
 $34 = (($agg$result) + 8|0);
 HEAPF32[$34>>2] = $29;
 $35 = (($agg$result) + 12|0);
 HEAPF32[$35>>2] = $30;
 $36 = (($agg$result) + 16|0);
 HEAPF32[$36>>2] = $31;
 $37 = (($agg$result) + 20|0);
 HEAPF32[$37>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($flag|0)==(8);
 if ($0) {
  __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE15setActorSimFlagEb($this,$value);
 }
 __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = $1 & 8;
 $3 = ($2<<16>>16)!=(0);
 __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE15setActorSimFlagEb($this,$3);
 $4 = HEAP16[$inFlags>>1]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6&65535;
 $8 = ((414264 + ($7<<2)|0) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + ($9)|0);
 $11 = $10;
 $$sum$i = (($9) + 4)|0;
 $12 = (($this) + ($$sum$i)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 24;
 $15 = $14 & 15;
 $16 = ((444424 + ($15<<2)|0) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($11))|0;
 $19 = $18;
 $20 = $13 >>> 30;
 if ((($20|0) == 2)) {
  $21 = HEAP32[$10>>2]|0;
  $22 = (($21) + 2417|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $10;
  }
 } else if ((($20|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $10;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $4;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($19,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($9) + 8)|0;
 $25 = (($this) + ($$sum1$i)|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $29 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($28,$15)|0);
  HEAP32[$25>>2] = $29;
  $30 = $29;
 } else {
  $30 = $26;
 }
 HEAP16[$30>>1] = $4;
 $31 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($31,$10);
 $32 = HEAP32[$12>>2]|0;
 $33 = $32 | 1;
 HEAP32[$12>>2] = $33;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE13getActorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $27 = HEAP16[$26>>1]|0;
  HEAP16[$agg$result>>1] = $27;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = HEAP16[$18>>1]|0;
 HEAP16[$agg$result>>1] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE17setDominanceGroupEh($this,$dominanceGroup) {
 $this = $this|0;
 $dominanceGroup = $dominanceGroup|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = $8 >>> 30;
 if ((($15|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($15|0) == 2)) {
  $16 = HEAP32[$5>>2]|0;
  $17 = (($16) + 2417|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc9ActorCore17setDominanceGroupEh($14,$dominanceGroup);
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $20 = (($this) + ($$sum1)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $23 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $24 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($23,$10)|0);
  HEAP32[$20>>2] = $24;
  $26 = $24;
 } else {
  $26 = $21;
 }
 $25 = (($26) + 2|0);
 HEAP8[$25>>0] = $dominanceGroup;
 $27 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($27,$5);
 $28 = HEAP32[$7>>2]|0;
 $29 = $28 | 2;
 HEAP32[$7>>2] = $29;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE17getDominanceGroupEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 12|0);
  $$in$i$i$i = $26;
  $27 = HEAP8[$$in$i$i$i>>0]|0;
  STACKTOP = sp;return ($27|0);
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 2|0);
 $$in$i$i$i = $17;
 $27 = HEAP8[$$in$i$i$i>>0]|0;
 STACKTOP = sp;return ($27|0);
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE14setOwnerClientEh($this,$inId) {
 $this = $this|0;
 $inId = $inId|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,426928,198,427008,$vararg_buffer1);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = ((414264 + ($5<<2)|0) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + ($7)|0);
 $$sum = (($7) + 4)|0;
 $9 = (($this) + ($$sum)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 3)) {
  label = 6;
 } else if ((($11|0) == 2)) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 5;
  } else {
   label = 6;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = $8;
  $17 = $10 >>> 24;
  $18 = $17 & 15;
  $19 = ((444424 + ($18<<2)|0) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($16))|0;
  $22 = $21;
  $23 = (($22) + 13|0);
  HEAP8[$23>>0] = $inId;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $24 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($24,8,427080,153,427160,$vararg_buffer1);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE14getOwnerClientEv($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = (($14) + 13|0);
 $16 = HEAP8[$15>>0]|0;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $$in = 0, $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 11|0);
  $$in = $26;
 } else {
  $$sum2 = (($4) + 8)|0;
  $10 = (($this) + ($$sum2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $13 = HEAP32[$5>>2]|0;
   $14 = $7 >>> 24;
   $15 = $14 & 15;
   $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
   HEAP32[$10>>2] = $16;
   $18 = $16;
  } else {
   $18 = $11;
  }
  $17 = (($18) + 3|0);
  $$in = $17;
 }
 $27 = HEAP8[$$in>>0]|0;
 $28 = HEAP8[$b>>0]|0;
 $29 = ($27<<24>>24)==($28<<24>>24);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = $5;
 $31 = HEAP32[$6>>2]|0;
 $32 = $31 >>> 24;
 $33 = $32 & 15;
 $34 = ((444424 + ($33<<2)|0) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + ($30))|0;
 $37 = $36;
 $38 = $31 >>> 30;
 if ((($38|0) == 2)) {
  $39 = HEAP32[$5>>2]|0;
  $40 = (($39) + 2417|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = ($41<<24>>24)==(0);
  if ($42) {
   label = 10;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else if ((($38|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $43 = (($37) + 11|0);
  HEAP8[$43>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum3 = (($4) + 8)|0;
 $44 = (($this) + ($$sum3)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  $47 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $48 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($47,$33)|0);
  HEAP32[$44>>2] = $48;
  $50 = $48;
 } else {
  $50 = $45;
 }
 $49 = (($50) + 3|0);
 HEAP8[$49>>0] = $28;
 $51 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($51,$5);
 $52 = HEAP32[$6>>2]|0;
 $53 = $52 | 4;
 HEAP32[$6>>2] = $53;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE22getClientBehaviorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $20 = $7 >>> 24;
  $21 = $20 & 15;
  $22 = ((444424 + ($21<<2)|0) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $5;
  $25 = (($23) + ($24))|0;
  $26 = $25;
  $27 = (($26) + 11|0);
  $28 = HEAP8[$27>>0]|0;
  HEAP8[$agg$result>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 3|0);
 $19 = HEAP8[$17>>0]|0;
 HEAP8[$agg$result>>0] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE12getAggregateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor12getAggregateEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx14NpRigidDynamic13getGlobalPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK5physx14NpRigidDynamic17getGlobalPoseFastEv($agg$result,$this);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE11createShapeERKNS_10PxGeometryEPKPNS_10PxMaterialEtNS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$geometry,$materials,$materialCount,$shapeFlags) {
 $this = $this|0;
 $geometry = $geometry|0;
 $materials = $materials|0;
 $materialCount = $materialCount|0;
 $shapeFlags = $shapeFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[424544>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$shapeFlags>>0]|0;
 HEAP8[$0>>0] = $5;
 $6 = (FUNCTION_TABLE_iiiiiii[$4 & 255]($1,$geometry,$materials,$materialCount,1,$0)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($8,$6,$this);
 __ZN5physx7NpShape15releaseInternalEv($6);
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE11attachShapeERNS_7PxShapeE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($0,$shape,$this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE11detachShapeERNS_7PxShapeEb($this,$shape,$wakeOnLostTouch) {
 $this = $this|0;
 $shape = $shape|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11detachShapeERNS_7NpShapeERNS_12PxRigidActorEb($0,$shape,$this,$wakeOnLostTouch);
 STACKTOP = sp;return;
}
function __ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE11getNbShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE9getShapesEPPNS_7PxShapeEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (__ZNK5physx14NpShapeManager9getShapesEPPNS_7PxShapeEjj($0,$buffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE16getNbConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor15getNbConnectorsENS_15NpConnectorType4EnumE($0,0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE14getConstraintsEPPNS_12PxConstraintEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$02$i = 0, $nbConnectors$03$i = 0, $nbConnectors$1$i = 0, $nbConnectors$2$i = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$not$i = 0, $or$cond1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $nbConnectors$2$i = 0;
  STACKTOP = sp;return ($nbConnectors$2$i|0);
 }
 $3 = (($1) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $nbConnectors$2$i = 0;
  STACKTOP = sp;return ($nbConnectors$2$i|0);
 } else {
  $7 = $1;$i$02$i = 0;$nbConnectors$03$i = 0;
 }
 while(1) {
  $6 = (($7) + 36|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + ($i$02$i<<3)|0);
  $10 = HEAP8[$9>>0]|0;
  $notlhs$i = ($10<<24>>24)!=(0);
  $notrhs$i = ($nbConnectors$03$i>>>0)>=($bufferSize>>>0);
  $or$cond$not$i = $notrhs$i | $notlhs$i;
  $11 = ($i$02$i>>>0)<($startIndex>>>0);
  $or$cond1$i = $or$cond$not$i | $11;
  if ($or$cond1$i) {
   $18 = $7;$nbConnectors$1$i = $nbConnectors$03$i;
  } else {
   $12 = ((($8) + ($i$02$i<<3)|0) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($buffer) + ($nbConnectors$03$i<<2)|0);
   HEAP32[$14>>2] = $13;
   $15 = (($nbConnectors$03$i) + 1)|0;
   $$pre$i = HEAP32[$0>>2]|0;
   $18 = $$pre$i;$nbConnectors$1$i = $15;
  }
  $16 = (($i$02$i) + 1)|0;
  $17 = (($18) + 40|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ($16>>>0)<($19>>>0);
  if ($20) {
   $7 = $18;$i$02$i = $16;$nbConnectors$03$i = $nbConnectors$1$i;
  } else {
   $nbConnectors$2$i = $nbConnectors$1$i;
   break;
  }
 }
 STACKTOP = sp;return ($nbConnectors$2$i|0);
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17getCMassLocalPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 512;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 112|0);
  $18 = $16;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 144|0);
  $18 = $14;
 }
 $17 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$agg$result>>2] = $17;
 $19 = (($agg$result) + 4|0);
 $20 = (($18) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 $22 = (($agg$result) + 8|0);
 $23 = (($18) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$22>>2] = $24;
 $25 = (($agg$result) + 12|0);
 $26 = (($18) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($agg$result) + 16|0);
 $29 = (($18) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($agg$result) + 20|0);
 $32 = (($18) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($agg$result) + 24|0);
 $35 = (($18) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE7setMassEf($this,$mass) {
 $this = $this|0;
 $mass = Math_fround($mass);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = $mass > Math_fround(0.0);
 if ($1) {
  $2 = Math_fround(Math_fround(1.0) / $mass);
  $11 = $2;
 } else {
  $11 = Math_fround(0.0);
 }
 $3 = (($this) + 64|0);
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 30;
 if ((($6|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($6|0) == 2)) {
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 2417|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if ($10) {
   label = 6;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  __ZN5physx2Sc8BodyCore14setInverseMassEf($3,$11);
  STACKTOP = sp;return;
 }
 $12 = (($this) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $16 = $5 >>> 24;
  $17 = $16 & 15;
  $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($15,$17)|0);
  HEAP32[$12>>2] = $18;
  $20 = $18;
 } else {
  $20 = $13;
 }
 $19 = (($20) + 92|0);
 HEAPF32[$19>>2] = $11;
 $21 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($21,$0);
 $22 = (($this) + 284|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 | 1;
 HEAP32[$22>>2] = $24;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE7getMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 64|0);
  $18 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($17)));
  $20 = $18;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 92|0);
  $16 = Math_fround(HEAPF32[$14>>2]);
  $20 = $16;
 }
 $19 = $20 > Math_fround(0.0);
 if (!($19)) {
  $22 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($22));
 }
 $21 = Math_fround(Math_fround(1.0) / $20);
 $22 = $21;
 STACKTOP = sp;return (Math_fround($22));
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE10getInvMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 64|0);
  $18 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($17)));
  $19 = $18;
  STACKTOP = sp;return (Math_fround($19));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 92|0);
 $16 = Math_fround(HEAPF32[$14>>2]);
 $19 = $16;
 STACKTOP = sp;return (Math_fround($19));
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25setMassSpaceInertiaTensorERKNS_6PxVec3E($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $$pre = Math_fround(0), $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 48|0);
 $2 = Math_fround(HEAPF32[$m>>2]);
 $3 = $2 == Math_fround(0.0);
 if ($3) {
  $13 = Math_fround(0.0);
 } else {
  $4 = Math_fround(Math_fround(1.0) / $2);
  $13 = $4;
 }
 $5 = (($m) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $6 == Math_fround(0.0);
 if ($7) {
  $15 = Math_fround(0.0);
 } else {
  $8 = Math_fround(Math_fround(1.0) / $6);
  $15 = $8;
 }
 $9 = (($m) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = $10 == Math_fround(0.0);
 if ($11) {
  $17 = Math_fround(0.0);
 } else {
  $12 = Math_fround(Math_fround(1.0) / $10);
  $17 = $12;
 }
 HEAPF32[$0>>2] = $13;
 $14 = (($0) + 4|0);
 HEAPF32[$14>>2] = $15;
 $16 = (($0) + 8|0);
 HEAPF32[$16>>2] = $17;
 $18 = (($this) + 64|0);
 $19 = (($this) + 52|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 >>> 30;
 if ((($21|0) == 3)) {
  $$pre$phi$i$iZ2D = $1;
 } else if ((($21|0) == 2)) {
  $22 = HEAP32[$1>>2]|0;
  $23 = (($22) + 2417|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   label = 10;
  } else {
   $$pre$phi$i$iZ2D = $1;
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  __ZN5physx2Sc8BodyCore17setInverseInertiaERKNS_6PxVec3E($18,$0);
  STACKTOP = sp;return;
 }
 $26 = (($this) + 56|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $29 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $30 = $20 >>> 24;
  $31 = $30 & 15;
  $32 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($29,$31)|0);
  HEAP32[$26>>2] = $32;
  $$pre = Math_fround(HEAPF32[$0>>2]);
  $34 = $32;$35 = $$pre;
 } else {
  $34 = $27;$35 = $13;
 }
 $33 = (($34) + 96|0);
 HEAPF32[$33>>2] = $35;
 $36 = Math_fround(HEAPF32[$14>>2]);
 $37 = (($34) + 100|0);
 HEAPF32[$37>>2] = $36;
 $38 = Math_fround(HEAPF32[$16>>2]);
 $39 = (($34) + 104|0);
 HEAPF32[$39>>2] = $38;
 $40 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($40,$1);
 $41 = (($this) + 284|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 | 2;
 HEAP32[$41>>2] = $43;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25getMassSpaceInertiaTensorEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 64|0);
  $17 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($16)|0);
  $19 = $17;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 96|0);
  $19 = $14;
 }
 $18 = Math_fround(HEAPF32[$19>>2]);
 $20 = (($19) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($19) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = $18 == Math_fround(0.0);
 if ($24) {
  $30 = Math_fround(0.0);
 } else {
  $25 = Math_fround(Math_fround(1.0) / $18);
  $30 = $25;
 }
 $26 = $21 == Math_fround(0.0);
 if ($26) {
  $32 = Math_fround(0.0);
 } else {
  $27 = Math_fround(Math_fround(1.0) / $21);
  $32 = $27;
 }
 $28 = $23 == Math_fround(0.0);
 if ($28) {
  $34 = Math_fround(0.0);
  HEAPF32[$agg$result>>2] = $30;
  $31 = (($agg$result) + 4|0);
  HEAPF32[$31>>2] = $32;
  $33 = (($agg$result) + 8|0);
  HEAPF32[$33>>2] = $34;
  STACKTOP = sp;return;
 }
 $29 = Math_fround(Math_fround(1.0) / $23);
 $34 = $29;
 HEAPF32[$agg$result>>2] = $30;
 $31 = (($agg$result) + 4|0);
 HEAPF32[$31>>2] = $32;
 $33 = (($agg$result) + 8|0);
 HEAPF32[$33>>2] = $34;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE28getMassSpaceInvInertiaTensorEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 64|0);
  $17 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($16)|0);
  $19 = $17;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 96|0);
  $19 = $14;
 }
 $18 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$agg$result>>2] = $18;
 $20 = (($agg$result) + 4|0);
 $21 = (($19) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = (($agg$result) + 8|0);
 $24 = (($19) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$23>>2] = $25;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17getLinearVelocityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 252|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 256|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 260|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE18getAngularVelocityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 264|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 268|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 272|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE19setRigidDynamicFlagENS_15PxRigidBodyFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 192|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE20setRigidDynamicFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP8[$inFlags>>0]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 196|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP8[$0>>0] = $1;
 FUNCTION_TABLE_vii[$4 & 4095]($this,$0);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE16setRigidBodyFlagENS_15PxRigidBodyFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currentFlags = 0, $newFlags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $currentFlags = sp + 1|0;
 $newFlags = sp;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 108|0);
  $18 = HEAP8[$17>>0]|0;
  HEAP8[$currentFlags>>0] = $18;
  $20 = $18;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 268|0);
  $16 = HEAP8[$14>>0]|0;
  HEAP8[$currentFlags>>0] = $16;
  $20 = $16;
 }
 if ($value) {
  $19 = $20&255;
  $21 = $19 | $flag;
  $22 = $21&255;
  HEAP8[$newFlags>>0] = $22;
 } else {
  $23 = $flag ^ 255;
  $24 = $23&255;
  $25 = $20 & $24;
  HEAP8[$newFlags>>0] = $25;
 }
 __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25setRigidBodyFlagsInternalERKNS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEES8_($this,$currentFlags,$newFlags);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17setRigidBodyFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currentFlags = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $currentFlags = sp;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 108|0);
  $18 = HEAP8[$17>>0]|0;
  HEAP8[$currentFlags>>0] = $18;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 268|0);
  $16 = HEAP8[$14>>0]|0;
  HEAP8[$currentFlags>>0] = $16;
 }
 __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25setRigidBodyFlagsInternalERKNS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEES8_($this,$currentFlags,$inFlags);
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE20getRigidDynamicFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 108|0);
  $18 = HEAP8[$17>>0]|0;
  HEAP8[$agg$result>>0] = $18;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 268|0);
 $16 = HEAP8[$14>>0]|0;
 HEAP8[$agg$result>>0] = $16;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17getRigidBodyFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $17 = (($this) + 108|0);
  $18 = HEAP8[$17>>0]|0;
  HEAP8[$agg$result>>0] = $18;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 268|0);
 $16 = HEAP8[$14>>0]|0;
 HEAP8[$agg$result>>0] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE27setMinCCDAdvanceCoefficientEf($this,$minCCDAdvanceCoefficient) {
 $this = $this|0;
 $minCCDAdvanceCoefficient = Math_fround($minCCDAdvanceCoefficient);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = (($this) + 64|0);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc8BodyCore24setCCDAdvanceCoefficientEf($1,$minCCDAdvanceCoefficient);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 124|0);
 HEAPF32[$16>>2] = $minCCDAdvanceCoefficient;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = (($this) + 284|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 | 64;
 HEAP32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE27getMinCCDAdvanceCoefficientEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 140|0);
  $$in$i$i$i = $16;
  $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 >>> 24;
  $12 = $11 & 15;
  $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
  HEAP32[$4>>2] = $13;
  $15 = $13;
 } else {
  $15 = $5;
 }
 $14 = (($15) + 124|0);
 $$in$i$i$i = $14;
 $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE27setMaxDepenetrationVelocityEf($this,$maxDepenVel) {
 $this = $this|0;
 $maxDepenVel = Math_fround($maxDepenVel);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = Math_fround(-$maxDepenVel);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $9 = (($this) + 156|0);
  HEAPF32[$9>>2] = $1;
  STACKTOP = sp;return;
 }
 $10 = (($this) + 56|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $14 = $3 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 172|0);
 HEAPF32[$17>>2] = $1;
 $19 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($19,$0);
 $20 = (($this) + 284|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 | 1024;
 HEAP32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE27getMaxDepenetrationVelocityEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1024;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 156|0);
  $$in$i$i$i = $16;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 172|0);
  $$in$i$i$i = $14;
 }
 $17 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 $18 = Math_fround(-$17);
 STACKTOP = sp;return (Math_fround($18));
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 $1 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($1,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(1);
 if ($3) {
  $8 = $0;
  label = 4;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($2<<16>>16)==(0);
  if (!($5)) {
   $8 = $4;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $6 = $2&65535;
  $j$01 = 0;
  while(1) {
   $7 = (($8) + ($j$01<<2)|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $16 = 0;
   } else {
    $11 = HEAP32[$context>>2]|0;
    $12 = HEAP32[$11>>2]|0;
    $13 = $9;
    $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($context,-2147483648,$13)|0);
    HEAP32[$7>>2] = $14;
    $16 = $14;
   }
   $15 = (($16) + 16|0);
   (__ZN5physx6shdfnd15atomicIncrementEPVi($15)|0);
   $17 = (($j$01) + 1)|0;
   $exitcond = ($17|0)==($6|0);
   if ($exitcond) {
    break;
   } else {
    $j$01 = $17;
   }
  }
 }
 $18 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($18,$context);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25setRigidBodyFlagsInternalERKNS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEES8_($this,$currentFlags,$newFlags) {
 $this = $this|0;
 $currentFlags = $currentFlags|0;
 $newFlags = $newFlags|0;
 var $$ = 0, $$0$i = 0, $$0$i10 = 0, $$mask$i = 0, $$mask$i$i = 0, $$mask$i$i6 = 0, $$mask$i9 = 0, $$not1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0);
 var $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $bodyTarget = 0, $bodyTarget1 = 0, $brmerge = 0, $i$022 = 0, $not$ = 0, $or$cond = 0, $or$cond5 = 0, $phitmp = 0, $phitmp21 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer1 = sp;
 $0 = sp + 61|0;
 $bodyTarget = sp + 4|0;
 $bodyTarget1 = sp + 32|0;
 $1 = sp + 60|0;
 $2 = (($this) + 48|0);
 $3 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $4 = HEAP8[$currentFlags>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)!=(0);
 $7 = HEAP8[$newFlags>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)!=(0);
 $10 = $9 ^ 1;
 $$ = $6 & $10;
 do {
  if ($$) {
   $11 = (($this) + 20|0);
   $12 = (($this) + 24|0);
   $13 = HEAP16[$12>>1]|0;
   $14 = $13&65535;
   $15 = ($13<<16>>16)==(1);
   if ($15) {
    $19 = $11;
    label = 5;
   } else {
    $16 = HEAP32[$11>>2]|0;
    $17 = ($13<<16>>16)==(0);
    if ($17) {
     $34 = $4;
    } else {
     $19 = $16;
     label = 5;
    }
   }
   do {
    if ((label|0) == 5) {
     $i$022 = 0;
     while(1) {
      $18 = (($19) + ($i$022<<2)|0);
      $20 = HEAP32[$18>>2]|0;
      $21 = HEAP32[$20>>2]|0;
      $22 = (($21) + 136|0);
      $23 = HEAP32[$22>>2]|0;
      FUNCTION_TABLE_vii[$23 & 4095]($0,$20);
      $24 = HEAP8[$0>>0]|0;
      $25 = $24 & 1;
      $26 = ($25<<24>>24)==(0);
      if (!($26)) {
       $27 = HEAP32[$18>>2]|0;
       $28 = (($27) + 116|0);
       $29 = HEAP32[$28>>2]|0;
       if ((($29|0) == 6) | (($29|0) == 1) | (($29|0) == 5)) {
        break;
       }
      }
      $30 = (($i$022) + 1)|0;
      $31 = ($30>>>0)<($14>>>0);
      if ($31) {
       $i$022 = $30;
      } else {
       label = 10;
       break;
      }
     }
     if ((label|0) == 10) {
      $$pre = HEAP8[$currentFlags>>0]|0;
      $34 = $$pre;
      break;
     }
     $32 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
     __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($32,4,426680,478,426760,$vararg_buffer1);
     STACKTOP = sp;return;
    }
   } while(0);
   $33 = $34 & 2;
   $35 = ($33<<24>>24)==(0);
   do {
    if (!($35)) {
     $36 = (($this) + 284|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = $37 & 8192;
     $39 = ($38|0)==(0);
     if ($39) {
      $70 = (($this) + 52|0);
      $71 = HEAP32[$70>>2]|0;
      $$mask$i9 = $71 & -1073741824;
      $72 = ($$mask$i9|0)==(-1073741824);
      if ($72) {
       break;
      }
      $73 = (($this) + 64|0);
      $74 = (__ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($73,$bodyTarget)|0);
      $phitmp21 = $74 ^ 1;
      $$0$i10 = $phitmp21;
     } else {
      $40 = (($this) + 56|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41|0)==(0|0);
      if ($42) {
       $43 = HEAP32[$2>>2]|0;
       $44 = (($this) + 52|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = $45 >>> 24;
       $47 = $46 & 15;
       $48 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($43,$47)|0);
       HEAP32[$40>>2] = $48;
       $50 = $48;
      } else {
       $50 = $41;
      }
      $49 = (($50) + 192|0);
      $51 = Math_fround(HEAPF32[$49>>2]);
      HEAPF32[$bodyTarget>>2] = $51;
      $52 = (($50) + 196|0);
      $53 = Math_fround(HEAPF32[$52>>2]);
      $54 = (($bodyTarget) + 4|0);
      HEAPF32[$54>>2] = $53;
      $55 = (($50) + 200|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      $57 = (($bodyTarget) + 8|0);
      HEAPF32[$57>>2] = $56;
      $58 = (($50) + 204|0);
      $59 = Math_fround(HEAPF32[$58>>2]);
      $60 = (($bodyTarget) + 12|0);
      HEAPF32[$60>>2] = $59;
      $61 = (($50) + 208|0);
      $62 = Math_fround(HEAPF32[$61>>2]);
      $63 = (($bodyTarget) + 16|0);
      HEAPF32[$63>>2] = $62;
      $64 = (($50) + 212|0);
      $65 = Math_fround(HEAPF32[$64>>2]);
      $66 = (($bodyTarget) + 20|0);
      HEAPF32[$66>>2] = $65;
      $67 = (($50) + 216|0);
      $68 = Math_fround(HEAPF32[$67>>2]);
      $69 = (($bodyTarget) + 24|0);
      HEAPF32[$69>>2] = $68;
      $$0$i10 = 0;
     }
     $75 = ($3|0)==(0|0);
     $or$cond = $$0$i10 | $75;
     if (!($or$cond)) {
      $76 = (($3) + 3376|0);
      __ZN5physx14NpShapeManager26markAllSceneQueryForUpdateERNS_2Sq17SceneQueryManagerE($11,$76);
      $77 = (($3) + 3400|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($78) + 1)|0;
      HEAP32[$77>>2] = $79;
     }
    }
   } while(0);
   $80 = (($this) + 64|0);
   $81 = (($this) + 52|0);
   $82 = HEAP32[$81>>2]|0;
   $$mask$i$i6 = $82 & -1073741824;
   $83 = ($$mask$i$i6|0)==(1073741824);
   if ($83) {
    $84 = (($this) + 220|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($85|0)==(0|0);
    if (!($86)) {
     $87 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($80,1)|0);
     $88 = HEAP32[$84>>2]|0;
     $89 = ($88|0)==(0|0);
     if ($87) {
      if ($89) {
       break;
      }
      $90 = HEAP32[$2>>2]|0;
      $91 = (($90) + 1256|0);
      $92 = HEAP32[$91>>2]|0;
      __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($80,$92,1);
      break;
     }
     if (!($89)) {
      $93 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($80,0)|0);
      if ($93) {
       $94 = HEAP32[$84>>2]|0;
       $95 = ($94|0)==(0|0);
       if (!($95)) {
        $96 = HEAP32[$2>>2]|0;
        $97 = (($96) + 1256|0);
        $98 = HEAP32[$97>>2]|0;
        __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($80,$98,0);
       }
      }
     }
    }
   }
  } else {
   $not$ = $6 ^ 1;
   $99 = $9 & $not$;
   if ($99) {
    $100 = HEAP32[$this>>2]|0;
    $101 = (($100) + 24|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (FUNCTION_TABLE_ii[$102 & 4095]($this)|0);
    $104 = ($103|0)==(4);
    if ($104) {
     $118 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
     __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($118,4,426680,499,426848,$vararg_buffer1);
     STACKTOP = sp;return;
    }
    $105 = (($this) + 64|0);
    $106 = (($this) + 52|0);
    $107 = HEAP32[$106>>2]|0;
    $$mask$i$i = $107 & -1073741824;
    $108 = ($$mask$i$i|0)==(1073741824);
    if ($108) {
     $109 = (($this) + 220|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0|0);
     if (!($111)) {
      $112 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($105,0)|0);
      if ($112) {
       $113 = HEAP32[$109>>2]|0;
       $114 = ($113|0)==(0|0);
       if (!($114)) {
        $115 = HEAP32[$2>>2]|0;
        $116 = (($115) + 1256|0);
        $117 = HEAP32[$116>>2]|0;
        (__ZN5physx2Sc8BodyCore17setupSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEbb($105,$117,1,0)|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $$not1 = $6 ^ 1;
 $brmerge = $$not1 | $10;
 do {
  if (!($brmerge)) {
   $119 = HEAP8[$currentFlags>>0]|0;
   $120 = $119&255;
   $121 = $120 & 2;
   $122 = $121&255;
   $123 = HEAP8[$newFlags>>0]|0;
   $124 = $123&255;
   $125 = $124 & 2;
   $126 = $125&255;
   $127 = ($122<<24>>24)==($126<<24>>24);
   if (!($127)) {
    $128 = (($this) + 284|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = $129 & 8192;
    $131 = ($130|0)==(0);
    if ($131) {
     $162 = (($this) + 52|0);
     $163 = HEAP32[$162>>2]|0;
     $$mask$i = $163 & -1073741824;
     $164 = ($$mask$i|0)==(-1073741824);
     if ($164) {
      break;
     }
     $165 = (($this) + 64|0);
     $166 = (__ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($165,$bodyTarget1)|0);
     $phitmp = $166 ^ 1;
     $$0$i = $phitmp;
    } else {
     $132 = (($this) + 56|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($133|0)==(0|0);
     if ($134) {
      $135 = HEAP32[$2>>2]|0;
      $136 = (($this) + 52|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = $137 >>> 24;
      $139 = $138 & 15;
      $140 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($135,$139)|0);
      HEAP32[$132>>2] = $140;
      $142 = $140;
     } else {
      $142 = $133;
     }
     $141 = (($142) + 192|0);
     $143 = Math_fround(HEAPF32[$141>>2]);
     HEAPF32[$bodyTarget1>>2] = $143;
     $144 = (($142) + 196|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = (($bodyTarget1) + 4|0);
     HEAPF32[$146>>2] = $145;
     $147 = (($142) + 200|0);
     $148 = Math_fround(HEAPF32[$147>>2]);
     $149 = (($bodyTarget1) + 8|0);
     HEAPF32[$149>>2] = $148;
     $150 = (($142) + 204|0);
     $151 = Math_fround(HEAPF32[$150>>2]);
     $152 = (($bodyTarget1) + 12|0);
     HEAPF32[$152>>2] = $151;
     $153 = (($142) + 208|0);
     $154 = Math_fround(HEAPF32[$153>>2]);
     $155 = (($bodyTarget1) + 16|0);
     HEAPF32[$155>>2] = $154;
     $156 = (($142) + 212|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = (($bodyTarget1) + 20|0);
     HEAPF32[$158>>2] = $157;
     $159 = (($142) + 216|0);
     $160 = Math_fround(HEAPF32[$159>>2]);
     $161 = (($bodyTarget1) + 24|0);
     HEAPF32[$161>>2] = $160;
     $$0$i = 0;
    }
    $167 = ($3|0)==(0|0);
    $or$cond5 = $$0$i | $167;
    if (!($or$cond5)) {
     $168 = (($this) + 20|0);
     $169 = (($3) + 3376|0);
     __ZN5physx14NpShapeManager26markAllSceneQueryForUpdateERNS_2Sq17SceneQueryManagerE($168,$169);
     $170 = (($3) + 3400|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = (($171) + 1)|0;
     HEAP32[$170>>2] = $172;
    }
   }
  }
 } while(0);
 $173 = HEAP8[$newFlags>>0]|0;
 HEAP8[$1>>0] = $173;
 __ZN5physx3Scb4Body8setFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($2,$1);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE11attachShapeERNS_7PxShapeE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($0,$shape,$this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE15setActorSimFlagEb($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $$in = 0, $$not = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum$i2 = 0, $$sum$i4 = 0, $$sum1$i = 0, $$sum1$i10 = 0, $$sum1$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge1 = 0, $value$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $$sum$i = (($6) + 4)|0;
 $8 = (($this) + ($$sum$i)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 1;
 $11 = ($10|0)==(0);
 if ($11) {
  $19 = $9 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $7;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $$in = $26;
 } else {
  $$sum1$i = (($6) + 8)|0;
  $12 = (($this) + ($$sum1$i)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $15 = HEAP32[$7>>2]|0;
   $16 = $9 >>> 24;
   $17 = $16 & 15;
   $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($15,$17)|0);
   HEAP32[$12>>2] = $18;
   $103 = $18;
  } else {
   $103 = $13;
  }
  $$in = $103;
 }
 $27 = HEAP16[$$in>>1]|0;
 $28 = $27&65535;
 $29 = $28 & 8;
 $30 = ($29|0)!=(0);
 $$not = $30 ^ 1;
 $brmerge = $$not | $value;
 if ($brmerge) {
  $value$not = $value ^ 1;
  $brmerge1 = $30 | $value$not;
  if ($brmerge1) {
   STACKTOP = sp;return;
  }
  $68 = ($1|0)==(0|0);
  if (!($68)) {
   $69 = (($this) + 12|0);
   __ZN5physx7NpActor26removeConstraintsFromSceneEv($69);
  }
  $70 = $28 | 8;
  $71 = $70&65535;
  $72 = HEAP16[$2>>1]|0;
  $73 = $72&65535;
  $74 = ((414264 + ($73<<2)|0) + 68|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($this) + ($75)|0);
  $77 = $76;
  $$sum$i2 = (($75) + 4)|0;
  $78 = (($this) + ($$sum$i2)|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = $79 >>> 24;
  $81 = $80 & 15;
  $82 = ((444424 + ($81<<2)|0) + 24|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + ($77))|0;
  $85 = $84;
  $86 = $79 >>> 30;
  if ((($86|0) == 3)) {
   $$pre$phi$i$i$iZ2D = $76;
   label = 24;
  } else if ((($86|0) == 2)) {
   $87 = HEAP32[$76>>2]|0;
   $88 = (($87) + 2417|0);
   $89 = HEAP8[$88>>0]|0;
   $90 = ($89<<24>>24)==(0);
   if ($90) {
    label = 23;
   } else {
    $$pre$phi$i$i$iZ2D = $76;
    label = 24;
   }
  } else {
   label = 23;
  }
  if ((label|0) == 23) {
   HEAP16[$0>>1] = $71;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($85,$0);
  }
  else if ((label|0) == 24) {
   $$sum1$i3 = (($75) + 8)|0;
   $91 = (($this) + ($$sum1$i3)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ($92|0)==(0|0);
   if ($93) {
    $94 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
    $95 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($94,$81)|0);
    HEAP32[$91>>2] = $95;
    $96 = $95;
   } else {
    $96 = $92;
   }
   HEAP16[$96>>1] = $71;
   $97 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($97,$76);
   $98 = HEAP32[$78>>2]|0;
   $99 = $98 | 1;
   HEAP32[$78>>2] = $99;
  }
  $100 = HEAP32[$this>>2]|0;
  $101 = (($100) + 320|0);
  $102 = HEAP32[$101>>2]|0;
  FUNCTION_TABLE_vi[$102 & 4095]($this);
  STACKTOP = sp;return;
 } else {
  $31 = HEAP32[$this>>2]|0;
  $32 = (($31) + 324|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_vi[$33 & 4095]($this);
  $34 = $27 & -9;
  $35 = HEAP16[$2>>1]|0;
  $36 = $35&65535;
  $37 = ((414264 + ($36<<2)|0) + 68|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($this) + ($38)|0);
  $40 = $39;
  $$sum$i4 = (($38) + 4)|0;
  $41 = (($this) + ($$sum$i4)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 >>> 24;
  $44 = $43 & 15;
  $45 = ((444424 + ($44<<2)|0) + 24|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + ($40))|0;
  $48 = $47;
  $49 = $42 >>> 30;
  if ((($49|0) == 3)) {
   $$pre$phi$i$i$i9Z2D = $39;
   label = 11;
  } else if ((($49|0) == 2)) {
   $50 = HEAP32[$39>>2]|0;
   $51 = (($50) + 2417|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    label = 10;
   } else {
    $$pre$phi$i$i$i9Z2D = $39;
    label = 11;
   }
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $34;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($48,$0);
  }
  else if ((label|0) == 11) {
   $$sum1$i10 = (($38) + 8)|0;
   $54 = (($this) + ($$sum1$i10)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0|0);
   if ($56) {
    $57 = HEAP32[$$pre$phi$i$i$i9Z2D>>2]|0;
    $58 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($57,$44)|0);
    HEAP32[$54>>2] = $58;
    $59 = $58;
   } else {
    $59 = $55;
   }
   HEAP16[$59>>1] = $34;
   $60 = HEAP32[$$pre$phi$i$i$i9Z2D>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($60,$39);
   $61 = HEAP32[$41>>2]|0;
   $62 = $61 | 1;
   HEAP32[$41>>2] = $62;
  }
  $63 = ($1|0)==(0|0);
  if ($63) {
   STACKTOP = sp;return;
  }
  $64 = (($this) + 16|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $67 = (($this) + 12|0);
  __ZN5physx7NpActor29addConstraintsToSceneInternalEv($67);
  STACKTOP = sp;return;
 }
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$in = 0, $$in19 = 0, $$pre = 0, $$pre$phi$i$i5Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre22 = 0, $$pre22$pre = 0, $$pre24 = 0, $$pre25 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum20 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = ((414264 + ($3<<2)|0) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + ($5)|0);
 $$sum = (($5) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($value) {
  if ($10) {
   $18 = $8 >>> 24;
   $19 = $18 & 15;
   $20 = ((444424 + ($19<<2)|0) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $6;
   $23 = (($21) + ($22))|0;
   $24 = $23;
   $25 = (($24) + 8|0);
   $$in19 = $25;$$pre$phiZ2D = $22;$31 = $8;
  } else {
   $$sum18 = (($5) + 8)|0;
   $11 = (($this) + ($$sum18)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[$6>>2]|0;
    $15 = $8 >>> 24;
    $16 = $15 & 15;
    $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
    HEAP32[$11>>2] = $17;
    $$pre$pre = HEAP32[$7>>2]|0;
    $$pre = $$pre$pre;$91 = $17;
   } else {
    $$pre = $8;$91 = $12;
   }
   $$pre24 = $6;
   $$in19 = $91;$$pre$phiZ2D = $$pre24;$31 = $$pre;
  }
  $26 = HEAP16[$$in19>>1]|0;
  $27 = $26&65535;
  $28 = $27 | $flag;
  $29 = $28&65535;
  $30 = $31 >>> 24;
  $32 = $30 & 15;
  $33 = ((444424 + ($32<<2)|0) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($$pre$phiZ2D))|0;
  $36 = $35;
  $37 = $31 >>> 30;
  if ((($37|0) == 3)) {
   $$pre$phi$i$i5Z2D = $6;
  } else if ((($37|0) == 2)) {
   $38 = HEAP32[$6>>2]|0;
   $39 = (($38) + 2417|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    label = 10;
   } else {
    $$pre$phi$i$i5Z2D = $6;
   }
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $29;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($36,$0);
   STACKTOP = sp;return;
  }
  $$sum20 = (($5) + 8)|0;
  $42 = (($this) + ($$sum20)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   $45 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
   $46 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($45,$32)|0);
   HEAP32[$42>>2] = $46;
   $47 = $46;
  } else {
   $47 = $43;
  }
  HEAP16[$47>>1] = $29;
  $48 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($48,$6);
  $49 = HEAP32[$7>>2]|0;
  $50 = $49 | 1;
  HEAP32[$7>>2] = $50;
  STACKTOP = sp;return;
 } else {
  if ($10) {
   $58 = $8 >>> 24;
   $59 = $58 & 15;
   $60 = ((444424 + ($59<<2)|0) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $6;
   $63 = (($61) + ($62))|0;
   $64 = $63;
   $65 = (($64) + 8|0);
   $$in = $65;$$pre$phi26Z2D = $62;$71 = $8;
  } else {
   $$sum16 = (($5) + 8)|0;
   $51 = (($this) + ($$sum16)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $54 = HEAP32[$6>>2]|0;
    $55 = $8 >>> 24;
    $56 = $55 & 15;
    $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
    HEAP32[$51>>2] = $57;
    $$pre22$pre = HEAP32[$7>>2]|0;
    $$pre22 = $$pre22$pre;$92 = $57;
   } else {
    $$pre22 = $8;$92 = $52;
   }
   $$pre25 = $6;
   $$in = $92;$$pre$phi26Z2D = $$pre25;$71 = $$pre22;
  }
  $66 = HEAP16[$$in>>1]|0;
  $67 = $flag ^ 65535;
  $68 = $67&65535;
  $69 = $66 & $68;
  $70 = $71 >>> 24;
  $72 = $70 & 15;
  $73 = ((444424 + ($72<<2)|0) + 24|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + ($$pre$phi26Z2D))|0;
  $76 = $75;
  $77 = $71 >>> 30;
  if ((($77|0) == 3)) {
   $$pre$phi$i$iZ2D = $6;
  } else if ((($77|0) == 2)) {
   $78 = HEAP32[$6>>2]|0;
   $79 = (($78) + 2417|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    label = 22;
   } else {
    $$pre$phi$i$iZ2D = $6;
   }
  } else {
   label = 22;
  }
  if ((label|0) == 22) {
   HEAP16[$0>>1] = $69;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($76,$0);
   STACKTOP = sp;return;
  }
  $$sum17 = (($5) + 8)|0;
  $82 = (($this) + ($$sum17)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $85 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $86 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($85,$72)|0);
   HEAP32[$82>>2] = $86;
   $87 = $86;
  } else {
   $87 = $83;
  }
  HEAP16[$87>>1] = $69;
  $88 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($88,$6);
  $89 = HEAP32[$7>>2]|0;
  $90 = $89 | 1;
  HEAP32[$7>>2] = $90;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($0,$context);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((427216 + 8|0));
 $0 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreD2Ev($0);
 HEAP32[$this>>2] = ((427552 + 8|0));
 $1 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 $2 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 HEAP32[$this>>2] = ((427888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((427216 + 8|0));
 $1 = (($this) + 64|0);
 __ZN5physx2Sc8BodyCoreD2Ev($1);
 HEAP32[$this>>2] = ((427552 + 8|0));
 $2 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 $3 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($3);
 HEAP32[$this>>2] = ((427888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE13switchToNoSimEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE15switchFromNoSimEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((427552 + 8|0));
 $0 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($0);
 $1 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 HEAP32[$this>>2] = ((427888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((427552 + 8|0));
 $1 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 $2 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 HEAP32[$this>>2] = ((427888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((427888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((427888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $8 = $7;
 $$sum$i = (($6) + 4)|0;
 $9 = (($this) + ($$sum$i)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 24;
 $12 = $11 & 15;
 $13 = ((444424 + ($12<<2)|0) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($8))|0;
 $16 = $15;
 $17 = $10 >>> 30;
 if ((($17|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $7;
 } else if ((($17|0) == 2)) {
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 2417|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $7;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $1;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($16,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($6) + 8)|0;
 $22 = (($this) + ($$sum1$i)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$12)|0);
  HEAP32[$22>>2] = $26;
  $27 = $26;
 } else {
  $27 = $23;
 }
 HEAP16[$27>>1] = $1;
 $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$7);
 $29 = HEAP32[$9>>2]|0;
 $30 = $29 | 1;
 HEAP32[$9>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$bits) {
 $this = $this|0;
 $bits = $bits|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = HEAP8[$bits>>0]|0;
 $7 = $5;
 $$sum = (($4) + 4)|0;
 $8 = (($this) + ($$sum)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($7))|0;
 $15 = $14;
 $16 = $9 >>> 30;
 if ((($16|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($16|0) == 2)) {
  $17 = HEAP32[$5>>2]|0;
  $18 = (($17) + 2417|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $21 = (($15) + 11|0);
  HEAP8[$21>>0] = $6;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $22 = (($this) + ($$sum1)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$11)|0);
  HEAP32[$22>>2] = $26;
  $28 = $26;
 } else {
  $28 = $23;
 }
 $27 = (($28) + 3|0);
 HEAP8[$27>>0] = $6;
 $29 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($29,$5);
 $30 = HEAP32[$8>>2]|0;
 $31 = $30 | 4;
 HEAP32[$8>>2] = $31;
 STACKTOP = sp;return;
}
function __ZN5physx14PxRigidDynamicD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx14PxRigidDynamicD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx14NpRigidDynamic17getGlobalPoseFastEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 512;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = (($this) + 112|0);
  $18 = $16;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$12)|0);
   HEAP32[$4>>2] = $13;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = (($15) + 144|0);
  $18 = $14;
 }
 $17 = (($18) + 16|0);
 $19 = Math_fround(HEAPF32[$17>>2]);
 $20 = (($18) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($18) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($19 * Math_fround(-2.0));
 $25 = Math_fround($21 * Math_fround(-2.0));
 $26 = Math_fround($23 * Math_fround(-2.0));
 $27 = (($18) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $28);
 $30 = Math_fround($29 + Math_fround(-0.5));
 $31 = Math_fround(HEAPF32[$18>>2]);
 $32 = Math_fround($24 * $31);
 $33 = (($18) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($25 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($18) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($26 * $38);
 $40 = Math_fround($36 + $39);
 $41 = Math_fround($24 * $30);
 $42 = Math_fround($26 * $34);
 $43 = Math_fround($25 * $38);
 $44 = Math_fround($42 - $43);
 $45 = Math_fround($28 * $44);
 $46 = Math_fround($41 - $45);
 $47 = Math_fround($31 * $40);
 $48 = Math_fround($47 + $46);
 $49 = Math_fround($25 * $30);
 $50 = Math_fround($24 * $38);
 $51 = Math_fround($26 * $31);
 $52 = Math_fround($50 - $51);
 $53 = Math_fround($28 * $52);
 $54 = Math_fround($49 - $53);
 $55 = Math_fround($34 * $40);
 $56 = Math_fround($55 + $54);
 $57 = Math_fround($26 * $30);
 $58 = Math_fround($25 * $31);
 $59 = Math_fround($24 * $34);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($28 * $60);
 $62 = Math_fround($57 - $61);
 $63 = Math_fround($38 * $40);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround(-$31);
 $66 = Math_fround(-$34);
 $67 = Math_fround(-$38);
 $68 = Math_fround($48 * Math_fround(2.0));
 $69 = Math_fround($56 * Math_fround(2.0));
 $70 = Math_fround($64 * Math_fround(2.0));
 $71 = (($this) + 236|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 * $72);
 $74 = Math_fround($73 + Math_fround(-0.5));
 $75 = (($this) + 224|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($76 * $68);
 $78 = (($this) + 228|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 * $69);
 $81 = Math_fround($77 + $80);
 $82 = (($this) + 232|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($83 * $70);
 $85 = Math_fround($84 + $81);
 $86 = Math_fround($74 * $68);
 $87 = Math_fround($79 * $70);
 $88 = Math_fround($83 * $69);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($72 * $89);
 $91 = Math_fround($86 + $90);
 $92 = Math_fround($76 * $85);
 $93 = Math_fround($92 + $91);
 $94 = Math_fround($74 * $69);
 $95 = Math_fround($83 * $68);
 $96 = Math_fround($76 * $70);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($72 * $97);
 $99 = Math_fround($94 + $98);
 $100 = Math_fround($79 * $85);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($74 * $70);
 $103 = Math_fround($76 * $69);
 $104 = Math_fround($79 * $68);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($102 + $106);
 $108 = Math_fround($83 * $85);
 $109 = Math_fround($107 + $108);
 $110 = (($this) + 240|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($111 + $93);
 $113 = (($this) + 244|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($114 + $101);
 $116 = (($this) + 248|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($117 + $109);
 $119 = Math_fround($72 * $65);
 $120 = Math_fround($28 * $76);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($79 * $67);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($83 * $66);
 $125 = Math_fround($123 - $124);
 $126 = Math_fround($72 * $66);
 $127 = Math_fround($28 * $79);
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($83 * $65);
 $130 = Math_fround($129 + $128);
 $131 = Math_fround($76 * $67);
 $132 = Math_fround($130 - $131);
 $133 = Math_fround($72 * $67);
 $134 = Math_fround($28 * $83);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround($76 * $66);
 $137 = Math_fround($136 + $135);
 $138 = Math_fround($79 * $65);
 $139 = Math_fround($137 - $138);
 $140 = Math_fround($28 * $72);
 $141 = Math_fround($76 * $65);
 $142 = Math_fround($140 - $141);
 $143 = Math_fround($79 * $66);
 $144 = Math_fround($142 - $143);
 $145 = Math_fround($83 * $67);
 $146 = Math_fround($144 - $145);
 HEAPF32[$agg$result>>2] = $125;
 $147 = (($agg$result) + 4|0);
 HEAPF32[$147>>2] = $132;
 $148 = (($agg$result) + 8|0);
 HEAPF32[$148>>2] = $139;
 $149 = (($agg$result) + 12|0);
 HEAPF32[$149>>2] = $146;
 $150 = (($agg$result) + 16|0);
 HEAPF32[$150>>2] = $112;
 $151 = (($agg$result) + 20|0);
 HEAPF32[$151>>2] = $115;
 $152 = (($agg$result) + 24|0);
 HEAPF32[$152>>2] = $118;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb4Body18setKinematicTargetERKNS_11PxTransformE($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 2844|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 >>> 30;
 if ((($5|0) == 2)) {
  $6 = (($0) + 2416|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 3;
  }
 } else if (!((($5|0) == 3))) {
  label = 3;
 }
 if ((label|0) == 3) {
  $9 = (($this) + 16|0);
  $10 = (($0) + 1256|0);
  $11 = HEAP32[$10>>2]|0;
  __ZN5physx2Sc8BodyCore18setKinematicTargetEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEERKNS_11PxTransformEf($9,$11,$p,$2);
  $12 = (($this) + 232|0);
  HEAP32[$12>>2] = 0;
  $13 = (($this) + 228|0);
  HEAPF32[$13>>2] = $2;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $17 = $4 >>> 24;
  $18 = $17 & 15;
  $19 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($0,$18)|0);
  HEAP32[$14>>2] = $19;
  $$pre = HEAP32[$this>>2]|0;
  $21 = $19;$41 = $$pre;
 } else {
  $21 = $15;$41 = $0;
 }
 $20 = (($21) + 192|0);
 $22 = Math_fround(HEAPF32[$p>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = (($p) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($21) + 196|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($p) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($21) + 200|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($p) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($21) + 204|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($p) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($21) + 208|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($p) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($21) + 212|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($p) + 24|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($21) + 216|0);
 HEAPF32[$40>>2] = $39;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($41,$this);
 $42 = (($this) + 236|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 | 8192;
 HEAP32[$42>>2] = $44;
 $45 = HEAP32[$3>>2]|0;
 $46 = $45 >>> 30;
 if ((($46|0) == 2)) {
  $47 = HEAP32[$this>>2]|0;
  $48 = (($47) + 2416|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = ($49<<24>>24)==(0);
  if ($50) {
   label = 9;
  } else {
   $56 = $47;
   label = 10;
  }
 } else if ((($46|0) == 3)) {
  $$pre$i = HEAP32[$this>>2]|0;
  $56 = $$pre$i;
  label = 10;
 } else {
  label = 9;
 }
 if ((label|0) == 9) {
  $51 = (($this) + 232|0);
  HEAP32[$51>>2] = 0;
  $52 = (($this) + 228|0);
  HEAPF32[$52>>2] = $2;
  $53 = (($this) + 16|0);
  __ZN5physx2Sc8BodyCore14setWakeCounterEfb($53,$2,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  $54 = (($this) + 232|0);
  HEAP32[$54>>2] = 0;
  $55 = (($this) + 228|0);
  HEAPF32[$55>>2] = $2;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($56,$this);
  $57 = HEAP32[$42>>2]|0;
  $58 = $57 & -7340033;
  $59 = $58 | 5242880;
  HEAP32[$42>>2] = $59;
  STACKTOP = sp;return;
 }
}
function __ZN5physx13NpRigidStaticC2ERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 6;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((429480 + 8|0));
 $3 = (($this) + 12|0);
 __ZN5physx7NpActorC2EPKc($3,0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((429192 + 8|0));
 $4 = (($this) + 20|0);
 __ZN5physx14NpShapeManagerC2Ev($4);
 HEAP32[$this>>2] = ((428600 + 8|0));
 $5 = (($this) + 48|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 56|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 52|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 64|0);
 __ZN5physx2Sc9RigidCoreC2ENS_11PxActorType4EnumE($8,0);
 $9 = (($this) + 108|0);
 HEAP8[$9>>0] = 0;
 $10 = Math_fround(HEAPF32[$pose>>2]);
 $11 = (($this) + 80|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($pose) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 84|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($pose) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 88|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($pose) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 92|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($pose) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 96|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($pose) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 100|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($pose) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 104|0);
 HEAPF32[$29>>2] = $28;
 HEAP8[$9>>0] = 0;
 $30 = HEAP32[$7>>2]|0;
 $31 = $30 & -251658241;
 $32 = $31 | 83886080;
 HEAP32[$7>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN5physx13NpRigidStaticD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((428600 + 8|0));
 $1 = (($this) + 64|0);
 __ZN5physx2Sc9RigidCoreD2Ev($1);
 HEAP32[$this>>2] = ((429192 + 8|0));
 $2 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 $3 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($3);
 HEAP32[$this>>2] = ((429344 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx13NpRigidStaticD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((428600 + 8|0));
 $0 = (($this) + 64|0);
 __ZN5physx2Sc9RigidCoreD2Ev($0);
 HEAP32[$this>>2] = ((429192 + 8|0));
 $1 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 $2 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 HEAP32[$this>>2] = ((429344 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx13NpRigidStatic8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $2&65535;
 $6 = $2;$i$01$i = 0;
 while(1) {
  $5 = ($6<<16>>16)==(1);
  if ($5) {
   $9 = $0;
  } else {
   $7 = HEAP32[$0>>2]|0;
   $9 = $7;
  }
  $8 = (($9) + ($i$01$i<<2)|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$c>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($c,$10);
  $14 = (($i$01$i) + 1)|0;
  $exitcond$i = ($14|0)==($4|0);
  if ($exitcond$i) {
   break;
  }
  $$pre$i = HEAP16[$1>>1]|0;
  $6 = $$pre$i;$i$01$i = $14;
 }
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $2&65535;
 $6 = $2;$i$01 = 0;
 while(1) {
  $5 = ($6<<16>>16)==(1);
  if ($5) {
   $9 = $0;
  } else {
   $7 = HEAP32[$0>>2]|0;
   $9 = $7;
  }
  $8 = (($9) + ($i$01<<2)|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$c>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($c,$10);
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($4|0);
  if ($exitcond) {
   break;
  }
  $$pre = HEAP16[$1>>1]|0;
  $6 = $$pre;$i$01 = $14;
 }
 STACKTOP = sp;return;
}
function __Z14NpGetPxActorSCRN5physx2Sc10StaticCoreE($scStatic) {
 $scStatic = $scStatic|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scStatic) + -64|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx13NpRigidStatic7releaseEv($this) {
 $this = $this|0;
 var $$off$i = 0, $$pre$phi3Z2D = 0, $$pre$phiZ2D = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge$demorgan = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (($this) + 48|0);
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 30;
 $$off$i = (($6) + -1)|0;
 $7 = ($$off$i>>>0)<(2);
 if ($7) {
  $8 = HEAP32[$3>>2]|0;
  $21 = $8;
 } else {
  $21 = 0;
 }
 $9 = $3;
 $10 = $5 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($9))|0;
 $15 = $14;
 $16 = (($15) + 8|0);
 $17 = HEAP16[$16>>1]|0;
 $18 = $17 & 8;
 $19 = ($18<<16>>16)!=(0);
 $20 = ($21|0)!=(0|0);
 $brmerge$demorgan = $20 & $19;
 if ($brmerge$demorgan) {
  $22 = (($this) + 20|0);
  __ZN5physx14NpShapeManager20clearShapesOnReleaseERNS_3Scb5SceneERNS_12PxRigidActorE($22,$21,$this);
  $$pre$phi3Z2D = $22;$$pre$phiZ2D = $this;
 } else {
  $$pre2 = (($this) + 20|0);
  $$pre$phi3Z2D = $$pre2;$$pre$phiZ2D = $this;
 }
 $23 = (($this) + 12|0);
 __ZN5physx7NpActor18releaseConstraintsERNS_12PxRigidActorE($23,$$pre$phiZ2D);
 $24 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 __ZN5physx14NpShapeManager9detachAllEPNS_7NpSceneE($$pre$phi3Z2D,$24);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($23,$this);
 if (!($20)) {
  __ZN5physx3Scb4Base7destroyEv($3);
  STACKTOP = sp;return;
 }
 __ZN5physx3Scb5Scene17removeRigidStaticERNS0_11RigidStaticEbb($21,$3,1,$19);
 $25 = (__ZN5physx3Scb5Scene10getPxSceneEv($21)|0);
 $26 = (($this) + 36|0);
 __ZN5physx7NpScene24removeFromRigidActorListERKj($25,$26);
 __ZN5physx3Scb4Base7destroyEv($3);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor18releaseConstraintsERNS_12PxRigidActorE($0,$this);
 $1 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $2 = (($this) + 20|0);
 __ZN5physx14NpShapeManager9detachAllEPNS_7NpSceneE($2,$1);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx13NpRigidStatic13setGlobalPoseERKNS_11PxTransformEb($this,$pose,$0) {
 $this = $this|0;
 $pose = $pose|0;
 $0 = $0|0;
 var $$pre = Math_fround(0), $$pre$phi$i$iZ2D = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0);
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $1 = sp + 4|0;
 $2 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $3 = (($this) + 48|0);
 $4 = Math_fround(HEAPF32[$pose>>2]);
 $5 = Math_fround($4 * $4);
 $6 = (($pose) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (($pose) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (($pose) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $15);
 $17 = Math_fround($13 + $16);
 $18 = (Math_fround(Math_sqrt((Math_fround($17)))));
 $19 = Math_fround(Math_fround(1.0) / $18);
 $20 = Math_fround($4 * $19);
 $21 = Math_fround($7 * $19);
 $22 = Math_fround($11 * $19);
 $23 = Math_fround($15 * $19);
 HEAPF32[$1>>2] = $20;
 $24 = (($1) + 4|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($1) + 8|0);
 HEAPF32[$25>>2] = $22;
 $26 = (($1) + 12|0);
 HEAPF32[$26>>2] = $23;
 $27 = (($1) + 16|0);
 $28 = (($pose) + 16|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$27>>2] = $29;
 $30 = (($1) + 20|0);
 $31 = (($pose) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$30>>2] = $32;
 $33 = (($1) + 24|0);
 $34 = (($pose) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 HEAPF32[$33>>2] = $35;
 $36 = (($this) + 64|0);
 $37 = (($this) + 52|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 >>> 30;
 if ((($39|0) == 3)) {
  $$pre$phi$i$iZ2D = $3;
  label = 5;
 } else if ((($39|0) == 2)) {
  $40 = HEAP32[$3>>2]|0;
  $41 = (($40) + 2417|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $3;
   label = 5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc10StaticCore14setActor2WorldERKNS_11PxTransformE($36,$1);
 }
 else if ((label|0) == 5) {
  $44 = (($this) + 56|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  if ($46) {
   $47 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $48 = $38 >>> 24;
   $49 = $48 & 15;
   $50 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($47,$49)|0);
   HEAP32[$44>>2] = $50;
   $$pre = Math_fround(HEAPF32[$1>>2]);
   $52 = $50;$53 = $$pre;
  } else {
   $52 = $45;$53 = $20;
  }
  $51 = (($52) + 96|0);
  HEAPF32[$51>>2] = $53;
  $54 = Math_fround(HEAPF32[$24>>2]);
  $55 = (($52) + 100|0);
  HEAPF32[$55>>2] = $54;
  $56 = Math_fround(HEAPF32[$25>>2]);
  $57 = (($52) + 104|0);
  HEAPF32[$57>>2] = $56;
  $58 = Math_fround(HEAPF32[$26>>2]);
  $59 = (($52) + 108|0);
  HEAPF32[$59>>2] = $58;
  $60 = Math_fround(HEAPF32[$27>>2]);
  $61 = (($52) + 112|0);
  HEAPF32[$61>>2] = $60;
  $62 = Math_fround(HEAPF32[$30>>2]);
  $63 = (($52) + 116|0);
  HEAPF32[$63>>2] = $62;
  $64 = Math_fround(HEAPF32[$33>>2]);
  $65 = (($52) + 120|0);
  HEAPF32[$65>>2] = $64;
  $66 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($66,$3);
  $67 = HEAP32[$37>>2]|0;
  $68 = $67 | 64;
  HEAP32[$37>>2] = $68;
 }
 $69 = ($2|0)==(0|0);
 if (!($69)) {
  $70 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($70,128,428752,113,428832,$vararg_buffer);
  $71 = (($this) + 20|0);
  $72 = (($2) + 3376|0);
  __ZN5physx14NpShapeManager26markAllSceneQueryForUpdateERNS_2Sq17SceneQueryManagerE($71,$72);
  $73 = (($2) + 3396|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + 1)|0;
  HEAP32[$73>>2] = $75;
 }
 $76 = (($this) + 16|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0|0);
 if ($78) {
  STACKTOP = sp;return;
 }
 $79 = (($77) + 36|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($77) + 40|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)==(0);
 if ($83) {
  STACKTOP = sp;return;
 }
 $85 = 0;
 while(1) {
  $84 = (($85) + 1)|0;
  $86 = (($80) + ($85<<3)|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = ($87<<24>>24)==(0);
  if ($88) {
   $90 = ((($80) + ($85<<3)|0) + 4|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(0|0);
   if ($92) {
    label = 17;
    break;
   }
   __ZN5physx12NpConstraint8comShiftEPNS_12PxRigidActorE($91,$this);
  }
  $89 = ($84>>>0)<($82>>>0);
  if ($89) {
   $85 = $84;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx13NpRigidStatic13getGlobalPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 80|0);
  $16 = $14;
 } else {
  $4 = (($this) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 96|0);
  $16 = $12;
 }
 $15 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$agg$result>>2] = $15;
 $17 = (($agg$result) + 4|0);
 $18 = (($16) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$17>>2] = $19;
 $20 = (($agg$result) + 8|0);
 $21 = (($16) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = (($agg$result) + 12|0);
 $24 = (($16) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$23>>2] = $25;
 $26 = (($agg$result) + 16|0);
 $27 = (($16) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$26>>2] = $28;
 $29 = (($agg$result) + 20|0);
 $30 = (($16) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$29>>2] = $31;
 $32 = (($agg$result) + 24|0);
 $33 = (($16) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$32>>2] = $34;
 STACKTOP = sp;return;
}
function __ZN5physx13NpRigidStatic11createShapeERKNS_10PxGeometryEPKPNS_10PxMaterialEtNS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$geometry,$materials,$materialCount,$shapeFlags) {
 $this = $this|0;
 $geometry = $geometry|0;
 $materials = $materials|0;
 $materialCount = $materialCount|0;
 $shapeFlags = $shapeFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[424544>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$shapeFlags>>0]|0;
 HEAP8[$0>>0] = $5;
 $6 = (FUNCTION_TABLE_iiiiiii[$4 & 255]($1,$geometry,$materials,$materialCount,1,$0)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($8,$6,$this);
 __ZN5physx7NpShape15releaseInternalEv($6);
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($rigid,$shapes) {
 $rigid = $rigid|0;
 $shapes = $shapes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $rigid;
 $1 = (($rigid) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 24;
 $4 = $3 & 15;
 $5 = ((444424 + ($4<<2)|0) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($0))|0;
 $8 = $7;
 $9 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($8)|0);
 $10 = (($9) + 20|0);
 $11 = (($10) + 4|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = ($12<<16>>16)==(1);
 if ($13) {
  $15 = $10;
  HEAP32[$shapes>>2] = $15;
  $16 = $12&65535;
  STACKTOP = sp;return ($16|0);
 }
 $14 = HEAP32[$10>>2]|0;
 $15 = $14;
 HEAP32[$shapes>>2] = $15;
 $16 = $12&65535;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx13NpRigidStatic13switchToNoSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 2417|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 __ZN5physx3Scb5Scene18switchRigidToNoSimERNS0_11RigidObjectEb($1,$0,0);
 STACKTOP = sp;return;
}
function __ZN5physx13NpRigidStatic15switchFromNoSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 2417|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 __ZN5physx3Scb5Scene20switchRigidFromNoSimERNS0_11RigidObjectEb($1,$0,0);
 STACKTOP = sp;return;
}
function __ZN5physx13NpRigidStatic9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$scene) {
 $this = $this|0;
 $out = $out|0;
 $scene = $scene|0;
 var $$0$i = Math_fround(0), $$0$i1 = Math_fround(0), $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 56|0;
 $1 = sp;
 $2 = sp + 32|0;
 $3 = (($this) + 20|0);
 __ZN5physx14NpShapeManager9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneERKNS_12PxRigidActorE($3,$out,$scene,$this);
 $4 = (($this) + 48|0);
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 1;
 $8 = ($7|0)==(0);
 if ($8) {
  $16 = $6 >>> 24;
  $17 = $16 & 15;
  $18 = ((444424 + ($17<<2)|0) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $4;
  $21 = (($19) + ($20))|0;
  $22 = $21;
  $23 = (($22) + 8|0);
  $$in = $23;
 } else {
  $9 = (($this) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $12 = HEAP32[$4>>2]|0;
   $13 = $6 >>> 24;
   $14 = $13 & 15;
   $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
   HEAP32[$9>>2] = $15;
   $59 = $15;
  } else {
   $59 = $10;
  }
  $$in = $59;
 }
 $24 = HEAP16[$$in>>1]|0;
 $25 = $24 & 1;
 $26 = ($25<<16>>16)==(0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (($scene) + 3372|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 & 64;
 $30 = ($29|0)==(0);
 if ($30) {
  label = 10;
 } else {
  $31 = (($scene) + 3012|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   label = 10;
  } else {
   $34 = (($scene) + 2864|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $$0$i1 = $35;$39 = $28;
  }
 }
 if ((label|0) == 10) {
  $36 = (($scene) + 32|0);
  $37 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($36,0)));
  $$pre = HEAP32[$27>>2]|0;
  $$0$i1 = $37;$39 = $$pre;
 }
 $38 = $39 & 64;
 $40 = ($38|0)==(0);
 if ($40) {
  label = 14;
 } else {
  $41 = (($scene) + 3023|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   label = 14;
  } else {
   $44 = (($scene) + 2908|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $$0$i = $45;
  }
 }
 if ((label|0) == 14) {
  $46 = (($scene) + 32|0);
  $47 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($46,11)));
  $$0$i = $47;
 }
 $48 = Math_fround($$0$i1 * $$0$i);
 $49 = $48 != Math_fround(0.0);
 if (!($49)) {
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$this>>2]|0;
 $51 = (($50) + 84|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095]($1,$this);
 __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($0,$1);
 $53 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$0)|0);
 HEAPF32[$2>>2] = $48;
 $54 = (($2) + 4|0);
 HEAPF32[$54>>2] = $48;
 $55 = (($2) + 8|0);
 HEAPF32[$55>>2] = $48;
 $56 = (($2) + 12|0);
 HEAP32[$56>>2] = -65536;
 $57 = (($2) + 16|0);
 HEAP32[$57>>2] = -16711936;
 $58 = (($2) + 20|0);
 HEAP32[$58>>2] = -16776961;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($53,$2)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx13PxRigidStatic19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (429640|0);
}
function __ZNK5physx13PxRigidStatic8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(429640,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $8 = 1;
 } else {
  $2 = (_strcmp(429608,$name)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $8 = 1;
  } else {
   $4 = (_strcmp(429624,$name)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $8 = 1;
   } else {
    $6 = (_strcmp($name,429632)|0);
    $7 = ($6|0)==(0);
    $8 = $7;
   }
  }
 }
 STACKTOP = sp;return ($8|0);
}
function __ZNK5physx13NpRigidStatic7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE7setNameEPKc($this,$debugName) {
 $this = $this|0;
 $debugName = $debugName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $debugName;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE14getWorldBoundsEf($agg$result,$this,$inflation) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inflation = Math_fround($inflation);
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $bounds = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bounds = sp;
 $0 = (($this) + 20|0);
 __ZNK5physx14NpShapeManager14getWorldBoundsERKNS_12PxRigidActorE($bounds,$0,$this);
 $1 = Math_fround(HEAPF32[$bounds>>2]);
 $2 = (($bounds) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = (($bounds) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($bounds) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 + $8);
 $10 = (($bounds) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($bounds) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 + $13);
 $15 = Math_fround($4 * Math_fround(0.5));
 $16 = Math_fround($9 * Math_fround(0.5));
 $17 = Math_fround($14 * Math_fround(0.5));
 $18 = Math_fround($3 - $1);
 $19 = Math_fround($8 - $6);
 $20 = Math_fround($13 - $11);
 $21 = Math_fround($18 * Math_fround(0.5));
 $22 = Math_fround($19 * Math_fround(0.5));
 $23 = Math_fround($20 * Math_fround(0.5));
 $24 = Math_fround($21 * $inflation);
 $25 = Math_fround($22 * $inflation);
 $26 = Math_fround($23 * $inflation);
 $27 = Math_fround($15 - $24);
 $28 = Math_fround($16 - $25);
 $29 = Math_fround($17 - $26);
 $30 = Math_fround($15 + $24);
 $31 = Math_fround($16 + $25);
 $32 = Math_fround($17 + $26);
 HEAPF32[$agg$result>>2] = $27;
 $33 = (($agg$result) + 4|0);
 HEAPF32[$33>>2] = $28;
 $34 = (($agg$result) + 8|0);
 HEAPF32[$34>>2] = $29;
 $35 = (($agg$result) + 12|0);
 HEAPF32[$35>>2] = $30;
 $36 = (($agg$result) + 16|0);
 HEAPF32[$36>>2] = $31;
 $37 = (($agg$result) + 20|0);
 HEAPF32[$37>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($flag|0)==(8);
 if ($0) {
  __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE15setActorSimFlagEb($this,$value);
 }
 __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = $1 & 8;
 $3 = ($2<<16>>16)!=(0);
 __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE15setActorSimFlagEb($this,$3);
 $4 = HEAP16[$inFlags>>1]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6&65535;
 $8 = ((414264 + ($7<<2)|0) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + ($9)|0);
 $11 = $10;
 $$sum$i = (($9) + 4)|0;
 $12 = (($this) + ($$sum$i)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 24;
 $15 = $14 & 15;
 $16 = ((444424 + ($15<<2)|0) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($11))|0;
 $19 = $18;
 $20 = $13 >>> 30;
 if ((($20|0) == 2)) {
  $21 = HEAP32[$10>>2]|0;
  $22 = (($21) + 2417|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $10;
  }
 } else if ((($20|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $10;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $4;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($19,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($9) + 8)|0;
 $25 = (($this) + ($$sum1$i)|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $29 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($28,$15)|0);
  HEAP32[$25>>2] = $29;
  $30 = $29;
 } else {
  $30 = $26;
 }
 HEAP16[$30>>1] = $4;
 $31 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($31,$10);
 $32 = HEAP32[$12>>2]|0;
 $33 = $32 | 1;
 HEAP32[$12>>2] = $33;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE13getActorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $27 = HEAP16[$26>>1]|0;
  HEAP16[$agg$result>>1] = $27;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = HEAP16[$18>>1]|0;
 HEAP16[$agg$result>>1] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE17setDominanceGroupEh($this,$dominanceGroup) {
 $this = $this|0;
 $dominanceGroup = $dominanceGroup|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = $8 >>> 30;
 if ((($15|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($15|0) == 2)) {
  $16 = HEAP32[$5>>2]|0;
  $17 = (($16) + 2417|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc9ActorCore17setDominanceGroupEh($14,$dominanceGroup);
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $20 = (($this) + ($$sum1)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $23 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $24 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($23,$10)|0);
  HEAP32[$20>>2] = $24;
  $26 = $24;
 } else {
  $26 = $21;
 }
 $25 = (($26) + 2|0);
 HEAP8[$25>>0] = $dominanceGroup;
 $27 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($27,$5);
 $28 = HEAP32[$7>>2]|0;
 $29 = $28 | 2;
 HEAP32[$7>>2] = $29;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE17getDominanceGroupEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 12|0);
  $$in$i$i$i = $26;
  $27 = HEAP8[$$in$i$i$i>>0]|0;
  STACKTOP = sp;return ($27|0);
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 2|0);
 $$in$i$i$i = $17;
 $27 = HEAP8[$$in$i$i$i>>0]|0;
 STACKTOP = sp;return ($27|0);
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE14setOwnerClientEh($this,$inId) {
 $this = $this|0;
 $inId = $inId|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,428904,198,428984,$vararg_buffer1);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = ((414264 + ($5<<2)|0) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + ($7)|0);
 $$sum = (($7) + 4)|0;
 $9 = (($this) + ($$sum)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 2)) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 5;
  } else {
   label = 6;
  }
 } else if ((($11|0) == 3)) {
  label = 6;
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = $8;
  $17 = $10 >>> 24;
  $18 = $17 & 15;
  $19 = ((444424 + ($18<<2)|0) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($16))|0;
  $22 = $21;
  $23 = (($22) + 13|0);
  HEAP8[$23>>0] = $inId;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $24 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($24,8,429056,153,429136,$vararg_buffer1);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE14getOwnerClientEv($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = (($14) + 13|0);
 $16 = HEAP8[$15>>0]|0;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $$in = 0, $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 11|0);
  $$in = $26;
 } else {
  $$sum2 = (($4) + 8)|0;
  $10 = (($this) + ($$sum2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $13 = HEAP32[$5>>2]|0;
   $14 = $7 >>> 24;
   $15 = $14 & 15;
   $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
   HEAP32[$10>>2] = $16;
   $18 = $16;
  } else {
   $18 = $11;
  }
  $17 = (($18) + 3|0);
  $$in = $17;
 }
 $27 = HEAP8[$$in>>0]|0;
 $28 = HEAP8[$b>>0]|0;
 $29 = ($27<<24>>24)==($28<<24>>24);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = $5;
 $31 = HEAP32[$6>>2]|0;
 $32 = $31 >>> 24;
 $33 = $32 & 15;
 $34 = ((444424 + ($33<<2)|0) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + ($30))|0;
 $37 = $36;
 $38 = $31 >>> 30;
 if ((($38|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($38|0) == 2)) {
  $39 = HEAP32[$5>>2]|0;
  $40 = (($39) + 2417|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = ($41<<24>>24)==(0);
  if ($42) {
   label = 10;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $43 = (($37) + 11|0);
  HEAP8[$43>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum3 = (($4) + 8)|0;
 $44 = (($this) + ($$sum3)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  $47 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $48 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($47,$33)|0);
  HEAP32[$44>>2] = $48;
  $50 = $48;
 } else {
  $50 = $45;
 }
 $49 = (($50) + 3|0);
 HEAP8[$49>>0] = $28;
 $51 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($51,$5);
 $52 = HEAP32[$6>>2]|0;
 $53 = $52 | 4;
 HEAP32[$6>>2] = $53;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE22getClientBehaviorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $20 = $7 >>> 24;
  $21 = $20 & 15;
  $22 = ((444424 + ($21<<2)|0) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $5;
  $25 = (($23) + ($24))|0;
  $26 = $25;
  $27 = (($26) + 11|0);
  $28 = HEAP8[$27>>0]|0;
  HEAP8[$agg$result>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 3|0);
 $19 = HEAP8[$17>>0]|0;
 HEAP8[$agg$result>>0] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE12getAggregateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor12getAggregateEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE11attachShapeERNS_7PxShapeE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($0,$shape,$this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE11detachShapeERNS_7PxShapeEb($this,$shape,$wakeOnLostTouch) {
 $this = $this|0;
 $shape = $shape|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager11detachShapeERNS_7NpShapeERNS_12PxRigidActorEb($0,$shape,$this,$wakeOnLostTouch);
 STACKTOP = sp;return;
}
function __ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE11getNbShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE9getShapesEPPNS_7PxShapeEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (__ZNK5physx14NpShapeManager9getShapesEPPNS_7PxShapeEjj($0,$buffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE16getNbConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor15getNbConnectorsENS_15NpConnectorType4EnumE($0,0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE14getConstraintsEPPNS_12PxConstraintEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$02$i = 0, $nbConnectors$03$i = 0, $nbConnectors$1$i = 0, $nbConnectors$2$i = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$not$i = 0, $or$cond1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $nbConnectors$2$i = 0;
  STACKTOP = sp;return ($nbConnectors$2$i|0);
 }
 $3 = (($1) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $nbConnectors$2$i = 0;
  STACKTOP = sp;return ($nbConnectors$2$i|0);
 } else {
  $7 = $1;$i$02$i = 0;$nbConnectors$03$i = 0;
 }
 while(1) {
  $6 = (($7) + 36|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + ($i$02$i<<3)|0);
  $10 = HEAP8[$9>>0]|0;
  $notlhs$i = ($10<<24>>24)!=(0);
  $notrhs$i = ($nbConnectors$03$i>>>0)>=($bufferSize>>>0);
  $or$cond$not$i = $notrhs$i | $notlhs$i;
  $11 = ($i$02$i>>>0)<($startIndex>>>0);
  $or$cond1$i = $or$cond$not$i | $11;
  if ($or$cond1$i) {
   $18 = $7;$nbConnectors$1$i = $nbConnectors$03$i;
  } else {
   $12 = ((($8) + ($i$02$i<<3)|0) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($buffer) + ($nbConnectors$03$i<<2)|0);
   HEAP32[$14>>2] = $13;
   $15 = (($nbConnectors$03$i) + 1)|0;
   $$pre$i = HEAP32[$0>>2]|0;
   $18 = $$pre$i;$nbConnectors$1$i = $15;
  }
  $16 = (($i$02$i) + 1)|0;
  $17 = (($18) + 40|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = ($16>>>0)<($19>>>0);
  if ($20) {
   $7 = $18;$i$02$i = $16;$nbConnectors$03$i = $nbConnectors$1$i;
  } else {
   $nbConnectors$2$i = $nbConnectors$1$i;
   break;
  }
 }
 STACKTOP = sp;return ($nbConnectors$2$i|0);
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx14NpShapeManager15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 $1 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($1,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 24|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(1);
 if ($3) {
  $8 = $0;
  label = 4;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($2<<16>>16)==(0);
  if (!($5)) {
   $8 = $4;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $6 = $2&65535;
  $j$01 = 0;
  while(1) {
   $7 = (($8) + ($j$01<<2)|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $16 = 0;
   } else {
    $11 = HEAP32[$context>>2]|0;
    $12 = HEAP32[$11>>2]|0;
    $13 = $9;
    $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($context,-2147483648,$13)|0);
    HEAP32[$7>>2] = $14;
    $16 = $14;
   }
   $15 = (($16) + 16|0);
   (__ZN5physx6shdfnd15atomicIncrementEPVi($15)|0);
   $17 = (($j$01) + 1)|0;
   $exitcond = ($17|0)==($6|0);
   if ($exitcond) {
    break;
   } else {
    $j$01 = $17;
   }
  }
 }
 $18 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($18,$context);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE15setActorSimFlagEb($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $$in = 0, $$not = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum$i2 = 0, $$sum$i4 = 0, $$sum1$i = 0, $$sum1$i10 = 0, $$sum1$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge1 = 0, $value$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $$sum$i = (($6) + 4)|0;
 $8 = (($this) + ($$sum$i)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 1;
 $11 = ($10|0)==(0);
 if ($11) {
  $19 = $9 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $7;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $$in = $26;
 } else {
  $$sum1$i = (($6) + 8)|0;
  $12 = (($this) + ($$sum1$i)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $15 = HEAP32[$7>>2]|0;
   $16 = $9 >>> 24;
   $17 = $16 & 15;
   $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($15,$17)|0);
   HEAP32[$12>>2] = $18;
   $103 = $18;
  } else {
   $103 = $13;
  }
  $$in = $103;
 }
 $27 = HEAP16[$$in>>1]|0;
 $28 = $27&65535;
 $29 = $28 & 8;
 $30 = ($29|0)!=(0);
 $$not = $30 ^ 1;
 $brmerge = $$not | $value;
 if ($brmerge) {
  $value$not = $value ^ 1;
  $brmerge1 = $30 | $value$not;
  if ($brmerge1) {
   STACKTOP = sp;return;
  }
  $68 = ($1|0)==(0|0);
  if (!($68)) {
   $69 = (($this) + 12|0);
   __ZN5physx7NpActor26removeConstraintsFromSceneEv($69);
  }
  $70 = $28 | 8;
  $71 = $70&65535;
  $72 = HEAP16[$2>>1]|0;
  $73 = $72&65535;
  $74 = ((414264 + ($73<<2)|0) + 68|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($this) + ($75)|0);
  $77 = $76;
  $$sum$i2 = (($75) + 4)|0;
  $78 = (($this) + ($$sum$i2)|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = $79 >>> 24;
  $81 = $80 & 15;
  $82 = ((444424 + ($81<<2)|0) + 24|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + ($77))|0;
  $85 = $84;
  $86 = $79 >>> 30;
  if ((($86|0) == 2)) {
   $87 = HEAP32[$76>>2]|0;
   $88 = (($87) + 2417|0);
   $89 = HEAP8[$88>>0]|0;
   $90 = ($89<<24>>24)==(0);
   if ($90) {
    label = 23;
   } else {
    $$pre$phi$i$i$iZ2D = $76;
    label = 24;
   }
  } else if ((($86|0) == 3)) {
   $$pre$phi$i$i$iZ2D = $76;
   label = 24;
  } else {
   label = 23;
  }
  if ((label|0) == 23) {
   HEAP16[$0>>1] = $71;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($85,$0);
  }
  else if ((label|0) == 24) {
   $$sum1$i3 = (($75) + 8)|0;
   $91 = (($this) + ($$sum1$i3)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ($92|0)==(0|0);
   if ($93) {
    $94 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
    $95 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($94,$81)|0);
    HEAP32[$91>>2] = $95;
    $96 = $95;
   } else {
    $96 = $92;
   }
   HEAP16[$96>>1] = $71;
   $97 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($97,$76);
   $98 = HEAP32[$78>>2]|0;
   $99 = $98 | 1;
   HEAP32[$78>>2] = $99;
  }
  $100 = HEAP32[$this>>2]|0;
  $101 = (($100) + 132|0);
  $102 = HEAP32[$101>>2]|0;
  FUNCTION_TABLE_vi[$102 & 4095]($this);
  STACKTOP = sp;return;
 } else {
  $31 = HEAP32[$this>>2]|0;
  $32 = (($31) + 136|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_vi[$33 & 4095]($this);
  $34 = $27 & -9;
  $35 = HEAP16[$2>>1]|0;
  $36 = $35&65535;
  $37 = ((414264 + ($36<<2)|0) + 68|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($this) + ($38)|0);
  $40 = $39;
  $$sum$i4 = (($38) + 4)|0;
  $41 = (($this) + ($$sum$i4)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 >>> 24;
  $44 = $43 & 15;
  $45 = ((444424 + ($44<<2)|0) + 24|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + ($40))|0;
  $48 = $47;
  $49 = $42 >>> 30;
  if ((($49|0) == 2)) {
   $50 = HEAP32[$39>>2]|0;
   $51 = (($50) + 2417|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    label = 10;
   } else {
    $$pre$phi$i$i$i9Z2D = $39;
    label = 11;
   }
  } else if ((($49|0) == 3)) {
   $$pre$phi$i$i$i9Z2D = $39;
   label = 11;
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $34;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($48,$0);
  }
  else if ((label|0) == 11) {
   $$sum1$i10 = (($38) + 8)|0;
   $54 = (($this) + ($$sum1$i10)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0|0);
   if ($56) {
    $57 = HEAP32[$$pre$phi$i$i$i9Z2D>>2]|0;
    $58 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($57,$44)|0);
    HEAP32[$54>>2] = $58;
    $59 = $58;
   } else {
    $59 = $55;
   }
   HEAP16[$59>>1] = $34;
   $60 = HEAP32[$$pre$phi$i$i$i9Z2D>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($60,$39);
   $61 = HEAP32[$41>>2]|0;
   $62 = $61 | 1;
   HEAP32[$41>>2] = $62;
  }
  $63 = ($1|0)==(0|0);
  if ($63) {
   STACKTOP = sp;return;
  }
  $64 = (($this) + 16|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $67 = (($this) + 12|0);
  __ZN5physx7NpActor29addConstraintsToSceneInternalEv($67);
  STACKTOP = sp;return;
 }
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$in = 0, $$in19 = 0, $$pre = 0, $$pre$phi$i$i5Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre22 = 0, $$pre22$pre = 0, $$pre24 = 0, $$pre25 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum20 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = ((414264 + ($3<<2)|0) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + ($5)|0);
 $$sum = (($5) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($value) {
  if ($10) {
   $18 = $8 >>> 24;
   $19 = $18 & 15;
   $20 = ((444424 + ($19<<2)|0) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $6;
   $23 = (($21) + ($22))|0;
   $24 = $23;
   $25 = (($24) + 8|0);
   $$in19 = $25;$$pre$phiZ2D = $22;$31 = $8;
  } else {
   $$sum18 = (($5) + 8)|0;
   $11 = (($this) + ($$sum18)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[$6>>2]|0;
    $15 = $8 >>> 24;
    $16 = $15 & 15;
    $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
    HEAP32[$11>>2] = $17;
    $$pre$pre = HEAP32[$7>>2]|0;
    $$pre = $$pre$pre;$91 = $17;
   } else {
    $$pre = $8;$91 = $12;
   }
   $$pre24 = $6;
   $$in19 = $91;$$pre$phiZ2D = $$pre24;$31 = $$pre;
  }
  $26 = HEAP16[$$in19>>1]|0;
  $27 = $26&65535;
  $28 = $27 | $flag;
  $29 = $28&65535;
  $30 = $31 >>> 24;
  $32 = $30 & 15;
  $33 = ((444424 + ($32<<2)|0) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($$pre$phiZ2D))|0;
  $36 = $35;
  $37 = $31 >>> 30;
  if ((($37|0) == 2)) {
   $38 = HEAP32[$6>>2]|0;
   $39 = (($38) + 2417|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    label = 10;
   } else {
    $$pre$phi$i$i5Z2D = $6;
   }
  } else if ((($37|0) == 3)) {
   $$pre$phi$i$i5Z2D = $6;
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $29;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($36,$0);
   STACKTOP = sp;return;
  }
  $$sum20 = (($5) + 8)|0;
  $42 = (($this) + ($$sum20)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   $45 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
   $46 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($45,$32)|0);
   HEAP32[$42>>2] = $46;
   $47 = $46;
  } else {
   $47 = $43;
  }
  HEAP16[$47>>1] = $29;
  $48 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($48,$6);
  $49 = HEAP32[$7>>2]|0;
  $50 = $49 | 1;
  HEAP32[$7>>2] = $50;
  STACKTOP = sp;return;
 } else {
  if ($10) {
   $58 = $8 >>> 24;
   $59 = $58 & 15;
   $60 = ((444424 + ($59<<2)|0) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $6;
   $63 = (($61) + ($62))|0;
   $64 = $63;
   $65 = (($64) + 8|0);
   $$in = $65;$$pre$phi26Z2D = $62;$71 = $8;
  } else {
   $$sum16 = (($5) + 8)|0;
   $51 = (($this) + ($$sum16)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $54 = HEAP32[$6>>2]|0;
    $55 = $8 >>> 24;
    $56 = $55 & 15;
    $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
    HEAP32[$51>>2] = $57;
    $$pre22$pre = HEAP32[$7>>2]|0;
    $$pre22 = $$pre22$pre;$92 = $57;
   } else {
    $$pre22 = $8;$92 = $52;
   }
   $$pre25 = $6;
   $$in = $92;$$pre$phi26Z2D = $$pre25;$71 = $$pre22;
  }
  $66 = HEAP16[$$in>>1]|0;
  $67 = $flag ^ 65535;
  $68 = $67&65535;
  $69 = $66 & $68;
  $70 = $71 >>> 24;
  $72 = $70 & 15;
  $73 = ((444424 + ($72<<2)|0) + 24|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + ($$pre$phi26Z2D))|0;
  $76 = $75;
  $77 = $71 >>> 30;
  if ((($77|0) == 3)) {
   $$pre$phi$i$iZ2D = $6;
  } else if ((($77|0) == 2)) {
   $78 = HEAP32[$6>>2]|0;
   $79 = (($78) + 2417|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    label = 22;
   } else {
    $$pre$phi$i$iZ2D = $6;
   }
  } else {
   label = 22;
  }
  if ((label|0) == 22) {
   HEAP16[$0>>1] = $69;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($76,$0);
   STACKTOP = sp;return;
  }
  $$sum17 = (($5) + 8)|0;
  $82 = (($this) + ($$sum17)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $85 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $86 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($85,$72)|0);
   HEAP32[$82>>2] = $86;
   $87 = $86;
  } else {
   $87 = $83;
  }
  HEAP16[$87>>1] = $69;
  $88 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($88,$6);
  $89 = HEAP32[$7>>2]|0;
  $90 = $89 | 1;
  HEAP32[$7>>2] = $90;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($0,$context);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((429192 + 8|0));
 $0 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($0);
 $1 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 HEAP32[$this>>2] = ((429344 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((429192 + 8|0));
 $1 = (($this) + 28|0);
 __ZN5physx2Cm8PtrTable5clearEv($1);
 $2 = (($this) + 20|0);
 __ZN5physx2Cm8PtrTable5clearEv($2);
 HEAP32[$this>>2] = ((429344 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE13switchToNoSimEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE15switchFromNoSimEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((429344 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((429344 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $8 = $7;
 $$sum$i = (($6) + 4)|0;
 $9 = (($this) + ($$sum$i)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 24;
 $12 = $11 & 15;
 $13 = ((444424 + ($12<<2)|0) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($8))|0;
 $16 = $15;
 $17 = $10 >>> 30;
 if ((($17|0) == 2)) {
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 2417|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $7;
  }
 } else if ((($17|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $7;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $1;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($16,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($6) + 8)|0;
 $22 = (($this) + ($$sum1$i)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$12)|0);
  HEAP32[$22>>2] = $26;
  $27 = $26;
 } else {
  $27 = $23;
 }
 HEAP16[$27>>1] = $1;
 $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$7);
 $29 = HEAP32[$9>>2]|0;
 $30 = $29 | 1;
 HEAP32[$9>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_13PxRigidStaticEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$bits) {
 $this = $this|0;
 $bits = $bits|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = HEAP8[$bits>>0]|0;
 $7 = $5;
 $$sum = (($4) + 4)|0;
 $8 = (($this) + ($$sum)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($7))|0;
 $15 = $14;
 $16 = $9 >>> 30;
 if ((($16|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($16|0) == 2)) {
  $17 = HEAP32[$5>>2]|0;
  $18 = (($17) + 2417|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $21 = (($15) + 11|0);
  HEAP8[$21>>0] = $6;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $22 = (($this) + ($$sum1)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$11)|0);
  HEAP32[$22>>2] = $26;
  $28 = $26;
 } else {
  $28 = $23;
 }
 $27 = (($28) + 3|0);
 HEAP8[$27>>0] = $6;
 $29 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($29,$5);
 $30 = HEAP32[$8>>2]|0;
 $31 = $30 | 4;
 HEAP32[$8>>2] = $31;
 STACKTOP = sp;return;
}
function __ZN5physx13PxRigidStaticD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx13PxRigidStaticD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx7NpSceneC2ERKNS_11PxSceneDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$$i$i$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 0;
 HEAP32[$this>>2] = ((429656 + 8|0));
 $2 = (($this) + 16|0);
 $3 = HEAP32[424544>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 176|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 $8 = ($7|0)==(0|0);
 $9 = (($7) + 8|0);
 $$$i = $8 ? 0 : $9;
 $10 = $this;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $10;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = 0;
 $15 = (($0) + 8|0);
 HEAP32[$15>>2] = $$$i;
 __ZN5physx3Scb5SceneC2ERKNS_11PxSceneDescENS_2Cm13EventProfilerE($2,$desc,$0);
 $16 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManagerC2ERNS_3Scb5SceneERKNS_11PxSceneDescE($16,$2,$desc);
 HEAP32[$this>>2] = ((430104 + 8|0));
 $17 = (($this) + 3460|0);
 HEAP32[$17>>2] = ((407136 + 8|0));
 $18 = (($this) + 3464|0);
 $19 = (($this) + 3596|0);
 _memset(($18|0),0,132)|0;
 HEAPF32[$19>>2] = Math_fround(0.75);
 $20 = (($this) + 3600|0);
 HEAP32[$20>>2] = -1;
 $21 = (($this) + 3604|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 3608|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 3572|0);
 __ZN5physx6shdfnd8internal8HashBaseIPNS_13NpVolumeCacheES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($23,64);
 $24 = (($this) + 3612|0);
 $25 = (($this) + 3648|0);
 dest=$24+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $26 = (__ZN5physx6shdfnd8SyncImpl7getSizeEv()|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  HEAP32[$25>>2] = 0;
 } else {
  $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (__Z15PxGetFoundationv()|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 24|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (FUNCTION_TABLE_ii[$36 & 4095]($33)|0);
  $$$i$i$i$i2 = $37 ? 434728 : 433312;
  $38 = (FUNCTION_TABLE_iiiiii[$32 & 255]($29,$27,$$$i$i$i$i2,434648,100)|0);
  HEAP32[$25>>2] = $38;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   __ZN5physx6shdfnd8SyncImplC2Ev($38);
  }
 }
 $40 = (($this) + 3652|0);
 $41 = (__ZN5physx6shdfnd8SyncImpl7getSizeEv()|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if ($43) {
  HEAP32[$40>>2] = 0;
 } else {
  $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (__Z15PxGetFoundationv()|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 24|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (FUNCTION_TABLE_ii[$51 & 4095]($48)|0);
  $$$i$i$i$i = $52 ? 434728 : 433312;
  $53 = (FUNCTION_TABLE_iiiiii[$47 & 255]($44,$42,$$$i$i$i$i,434648,100)|0);
  HEAP32[$40>>2] = $53;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   __ZN5physx6shdfnd8SyncImplC2Ev($53);
  }
 }
 $55 = (($this) + 3656|0);
 HEAP8[$55>>0] = 0;
 $56 = (($this) + 3657|0);
 $57 = (($desc) + 152|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(1);
 $60 = $59&1;
 HEAP8[$56>>0] = $60;
 $61 = (($this) + 3658|0);
 HEAP8[$61>>0] = 0;
 $62 = (($this) + 3664|0);
 HEAP32[$62>>2] = 1;
 $63 = (($this) + 3668|0);
 HEAP32[$63>>2] = 0;
 $64 = (($this) + 3672|0);
 HEAP32[$64>>2] = 0;
 $65 = (($this) + 3676|0);
 HEAP32[$65>>2] = 0;
 $66 = (($this) + 3684|0);
 $67 = (($this) + 3688|0);
 HEAP16[$67>>1] = -1;
 $68 = (($this) + 3690|0);
 HEAP16[$68>>1] = 0;
 $69 = (($this) + 3692|0);
 HEAP32[$69>>2] = 0;
 HEAP32[$66>>2] = ((434896 + 8|0));
 $70 = (($this) + 3696|0);
 HEAP32[$70>>2] = 0;
 $71 = (($this) + 3700|0);
 HEAP32[$71>>2] = 0;
 HEAP32[$66>>2] = ((437152 + 8|0));
 $72 = (($this) + 3704|0);
 HEAP32[$72>>2] = $25;
 $73 = (($this) + 3708|0);
 $74 = (($this) + 3712|0);
 HEAP16[$74>>1] = -1;
 $75 = (($this) + 3714|0);
 HEAP16[$75>>1] = 0;
 $76 = (($this) + 3716|0);
 HEAP32[$76>>2] = 0;
 HEAP32[$73>>2] = ((434896 + 8|0));
 $77 = (($this) + 3720|0);
 HEAP32[$77>>2] = 0;
 $78 = (($this) + 3724|0);
 HEAP32[$78>>2] = 0;
 HEAP32[$73>>2] = ((437152 + 8|0));
 $79 = (($this) + 3728|0);
 HEAP32[$79>>2] = $40;
 $80 = (($this) + 3732|0);
 $81 = (($this) + 3736|0);
 HEAP16[$81>>1] = -1;
 $82 = (($this) + 3738|0);
 HEAP16[$82>>1] = 0;
 $83 = (($this) + 3740|0);
 HEAP32[$83>>2] = 0;
 HEAP32[$80>>2] = ((434896 + 8|0));
 $84 = (($this) + 3744|0);
 HEAP32[$84>>2] = 0;
 $85 = (($this) + 3748|0);
 HEAP32[$85>>2] = 0;
 HEAP32[$80>>2] = ((434984 + 8|0));
 $86 = (($this) + 3752|0);
 HEAP32[$86>>2] = 0;
 $87 = (($this) + 3756|0);
 HEAP32[$87>>2] = 430560;
 $88 = (($this) + 3760|0);
 $89 = (($this) + 3764|0);
 HEAP16[$89>>1] = -1;
 $90 = (($this) + 3766|0);
 HEAP16[$90>>1] = 0;
 $91 = (($this) + 3768|0);
 HEAP32[$91>>2] = 0;
 HEAP32[$88>>2] = ((434896 + 8|0));
 $92 = (($this) + 3772|0);
 HEAP32[$92>>2] = 0;
 $93 = (($this) + 3776|0);
 HEAP32[$93>>2] = 0;
 HEAP32[$88>>2] = ((434936 + 8|0));
 $94 = (($this) + 3780|0);
 HEAP32[$94>>2] = 0;
 $95 = (($this) + 3784|0);
 HEAP32[$95>>2] = 430584;
 $96 = (($this) + 3788|0);
 $97 = (($this) + 3792|0);
 HEAP16[$97>>1] = -1;
 $98 = (($this) + 3794|0);
 HEAP16[$98>>1] = 0;
 $99 = (($this) + 3796|0);
 HEAP32[$99>>2] = 0;
 HEAP32[$96>>2] = ((434896 + 8|0));
 $100 = (($this) + 3800|0);
 HEAP32[$100>>2] = 0;
 $101 = (($this) + 3804|0);
 HEAP32[$101>>2] = 0;
 HEAP32[$96>>2] = ((434848 + 8|0));
 $102 = (($this) + 3808|0);
 HEAP32[$102>>2] = 0;
 $103 = (($this) + 3812|0);
 HEAP32[$103>>2] = 430600;
 $104 = (($this) + 3816|0);
 HEAP8[$104>>0] = 0;
 $105 = (($this) + 3820|0);
 HEAP32[$105>>2] = 0;
 $106 = (($this) + 3824|0);
 HEAP32[$106>>2] = 0;
 $107 = (($this) + 3828|0);
 HEAP32[$107>>2] = 0;
 $108 = (($this) + 3832|0);
 HEAP32[$108>>2] = 0;
 $109 = (($this) + 3840|0);
 HEAP32[$109>>2] = 0;
 $110 = (($this) + 3844|0);
 __ZN5physx6shdfnd13ReadWriteLockC2Ev($110);
 $111 = (($this) + 3848|0);
 HEAP8[$111>>0] = 0;
 HEAP32[$86>>2] = $this;
 HEAP32[$94>>2] = $this;
 HEAP32[$102>>2] = $this;
 $112 = (($this) + 2400|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($this) + 3680|0);
 HEAP32[$114>>2] = $113;
 $115 = (__ZN5physx6shdfnd8TlsAllocEv()|0);
 $116 = (($this) + 3836|0);
 HEAP32[$116>>2] = $115;
 STACKTOP = sp;return;
}
function __ZN5physx14NpSceneQueriesD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((429656 + 8|0));
 $0 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManagerD2Ev($0);
 $1 = (($this) + 16|0);
 __ZN5physx3Scb5SceneD2Ev($1);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx14NpSceneQueriesD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((429656 + 8|0));
 $0 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManagerD2Ev($0);
 $1 = (($this) + 16|0);
 __ZN5physx3Scb5SceneD2Ev($1);
 STACKTOP = sp;return;
}
function __ZN5physx7NpSceneD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx7NpSceneD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx7NpSceneD2Ev($this) {
 $this = $this|0;
 var $$in$in = 0, $$in38 = 0, $$ph14 = 0, $$ph15 = 0, $$ph16 = 0, $$ph17 = 0, $$pre = 0, $$pre45 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $caches = 0, $i$012 = 0;
 var $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i3 = 0, $or$cond$i$i4 = 0, $or$cond$i$i5 = 0, $or$cond$i$i6 = 0, $or$cond$i$i8 = 0, $or$cond$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $caches = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((430104 + 8|0));
 $1 = (($this) + 3560|0);
 $2 = (($this) + 3564|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $10 = ((430104 + 8|0));
   while(1) {
    $9 = (($10) + 64|0);
    $11 = HEAP32[$9>>2]|0;
    $12 = HEAP32[$1>>2]|0;
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_viii[$11 & 4095]($this,$13,0);
    $14 = HEAP32[$2>>2]|0;
    $15 = ($14|0)==(0);
    if ($15) {
     break L1;
    }
    $$pre = HEAP32[$this>>2]|0;
    $10 = $$pre;
   }
  }
 } while(0);
 $5 = (($this) + 3624|0);
 $6 = (($this) + 3628|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  while(1) {
   $20 = HEAP32[$this>>2]|0;
   $21 = (($20) + 52|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = HEAP32[$5>>2]|0;
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_viii[$22 & 4095]($this,$24,0);
   $25 = HEAP32[$6>>2]|0;
   $26 = ($25|0)==(0);
   if ($26) {
    break;
   }
  }
 }
 $16 = (($this) + 3636|0);
 $17 = (($this) + 3640|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 if (!($19)) {
  while(1) {
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 52|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP32[$16>>2]|0;
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_viii[$33 & 4095]($this,$35,0);
   $36 = HEAP32[$17>>2]|0;
   $37 = ($36|0)==(0);
   if ($37) {
    break;
   }
  }
 }
 $27 = (($this) + 3536|0);
 $28 = (($this) + 3540|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  while(1) {
   $42 = HEAP32[$this>>2]|0;
   $43 = (($42) + 52|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = HEAP32[$27>>2]|0;
   $46 = HEAP32[$45>>2]|0;
   FUNCTION_TABLE_viii[$44 & 4095]($this,$46,0);
   $47 = HEAP32[$28>>2]|0;
   $48 = ($47|0)==(0);
   if ($48) {
    break;
   }
  }
 }
 $38 = (($this) + 3548|0);
 $39 = (($this) + 3552|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0);
 if (!($41)) {
  while(1) {
   $49 = HEAP32[$this>>2]|0;
   $50 = (($49) + 40|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = HEAP32[$38>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   FUNCTION_TABLE_viii[$51 & 4095]($this,$53,0);
   $54 = HEAP32[$39>>2]|0;
   $55 = ($54|0)==(0);
   if ($55) {
    break;
   }
  }
 }
 HEAP32[$caches>>2] = 0;
 $56 = (($caches) + 4|0);
 HEAP32[$56>>2] = 0;
 $57 = (($caches) + 8|0);
 HEAP32[$57>>2] = 0;
 $58 = (($this) + 3572|0);
 $59 = (($this) + 3608|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0);
 if (!($61)) {
  __ZN5physx6shdfnd5ArrayIPNS_13NpVolumeCacheENS0_19ReflectionAllocatorIS3_EEE8recreateEj($caches,$60);
 }
 $62 = (($this) + 3588|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0);
 $$pre45 = (($this) + 3584|0);
 L30: do {
  if ($64) {
   $$ph14 = -1;$$ph15 = 0;
  } else {
   $65 = HEAP32[$$pre45>>2]|0;
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(-1);
   if ($67) {
    $68 = (($this) + 3592|0);
    $69 = HEAP32[$68>>2]|0;
    $71 = 0;
    while(1) {
     $70 = (($71) + 1)|0;
     $72 = ($70|0)==($69|0);
     if ($72) {
      $$ph14 = -1;$$ph15 = $69;
      break L30;
     }
     $73 = (($65) + ($70<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==(-1);
     if ($75) {
      $71 = $70;
     } else {
      $$ph14 = $74;$$ph15 = $70;
      break;
     }
    }
   } else {
    $$ph14 = $66;$$ph15 = 0;
   }
  }
 } while(0);
 $76 = (($this) + 3576|0);
 $77 = (($this) + 3580|0);
 $78 = (($this) + 3592|0);
 $$ph16 = $$ph14;$$ph17 = $$ph15;
 L37: while(1) {
  $80 = $$ph16;
  while(1) {
   $79 = ($80|0)==(-1);
   if ($79) {
    break L37;
   }
   $84 = HEAP32[$76>>2]|0;
   $85 = (($84) + ($80<<2)|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$0>>2] = $86;
   $87 = HEAP32[$57>>2]|0;
   $88 = $87 & 2147483647;
   $89 = HEAP32[$56>>2]|0;
   $90 = ($88>>>0)>($89>>>0);
   if ($90) {
    $91 = HEAP32[$caches>>2]|0;
    $92 = (($91) + ($89<<2)|0);
    $93 = ($92|0)==(0|0);
    if (!($93)) {
     HEAP32[$92>>2] = $86;
    }
    $94 = (($89) + 1)|0;
    HEAP32[$56>>2] = $94;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_13NpVolumeCacheENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($caches,$0)|0);
   }
   $95 = HEAP32[$77>>2]|0;
   $96 = (($95) + ($80<<2)|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(-1);
   if ($98) {
    break;
   } else {
    $80 = $97;
   }
  }
  $99 = HEAP32[$78>>2]|0;
  $101 = $$ph17;
  while(1) {
   $100 = (($101) + 1)|0;
   $102 = ($100|0)==($99|0);
   if ($102) {
    $$ph16 = -1;$$ph17 = $99;
    continue L37;
   }
   $103 = HEAP32[$$pre45>>2]|0;
   $104 = (($103) + ($100<<2)|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ($105|0)==(-1);
   if ($106) {
    $101 = $100;
   } else {
    $$ph16 = $105;$$ph17 = $100;
    continue L37;
   }
  }
 }
 $81 = HEAP32[$56>>2]|0;
 $82 = ($81|0)==(0);
 if (!($82)) {
  $83 = HEAP32[$caches>>2]|0;
  $i$012 = 0;
  while(1) {
   $107 = (($83) + ($i$012<<2)|0);
   $108 = HEAP32[$107>>2]|0;
   __ZN5physx7NpScene18releaseVolumeCacheEPNS_13NpVolumeCacheE($this,$108);
   $109 = (($i$012) + 1)|0;
   $110 = ($109>>>0)<($81>>>0);
   if ($110) {
    $i$012 = $109;
   } else {
    break;
   }
  }
 }
 $111 = (($this) + 16|0);
 $112 = (($this) + 3372|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = $113 & 4;
 $115 = ($114|0)==(0);
 $116 = (($this) + 3348|0);
 $117 = (($this) + 1232|0);
 $$in$in = $115 ? $117 : $116;
 $118 = HEAP16[$$in$in>>1]|0;
 $119 = $118 & 4096;
 $120 = ($119<<16>>16)==(0);
 $121 = (($this) + 3612|0);
 $122 = (($this) + 3616|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ($123|0)==(0);
 if (!($124)) {
  $$in38 = $123;
  while(1) {
   $125 = (($$in38) + -1)|0;
   $126 = HEAP32[$121>>2]|0;
   $127 = (($126) + ($125<<2)|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = ($128|0)==(0|0);
   if (!($129)) {
    $130 = HEAP32[$128>>2]|0;
    $131 = (($130) + 60|0);
    $132 = HEAP32[$131>>2]|0;
    FUNCTION_TABLE_vi[$132 & 4095]($128);
   }
   $133 = ($125|0)==(0);
   if ($133) {
    break;
   } else {
    $$in38 = $125;
   }
  }
 }
 HEAP32[$122>>2] = 0;
 __ZN5physx3Scb5Scene7releaseEv($111);
 if (!($120)) {
  $134 = HEAP32[$this>>2]|0;
  $135 = (($134) + 404|0);
  $136 = HEAP32[$135>>2]|0;
  FUNCTION_TABLE_vi[$136 & 4095]($this);
 }
 $137 = (($this) + 3836|0);
 $138 = HEAP32[$137>>2]|0;
 __ZN5physx6shdfnd7TlsFreeEj($138);
 $139 = HEAP32[$57>>2]|0;
 $140 = $139 & 2147483647;
 $141 = ($140|0)!=(0);
 $142 = ($139|0)>(-1);
 $or$cond$i$i9 = $141 & $142;
 if ($or$cond$i$i9) {
  $143 = HEAP32[$caches>>2]|0;
  $144 = ($143|0)==(0|0);
  if (!($144)) {
   $145 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = (($146) + 12|0);
   $148 = HEAP32[$147>>2]|0;
   FUNCTION_TABLE_vii[$148 & 4095]($145,$143);
  }
 }
 $149 = (($this) + 3844|0);
 __ZN5physx6shdfnd13ReadWriteLockD2Ev($149);
 $150 = (($this) + 3788|0);
 HEAP32[$150>>2] = ((434896 + 8|0));
 $151 = (($this) + 3796|0);
 HEAP32[$151>>2] = 0;
 $152 = (($this) + 3760|0);
 HEAP32[$152>>2] = ((434896 + 8|0));
 $153 = (($this) + 3768|0);
 HEAP32[$153>>2] = 0;
 $154 = (($this) + 3732|0);
 HEAP32[$154>>2] = ((434896 + 8|0));
 $155 = (($this) + 3740|0);
 HEAP32[$155>>2] = 0;
 $156 = (($this) + 3708|0);
 HEAP32[$156>>2] = ((434896 + 8|0));
 $157 = (($this) + 3716|0);
 HEAP32[$157>>2] = 0;
 $158 = (($this) + 3684|0);
 HEAP32[$158>>2] = ((434896 + 8|0));
 $159 = (($this) + 3692|0);
 HEAP32[$159>>2] = 0;
 $160 = (($this) + 3676|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = $161 & 2147483647;
 $163 = ($162|0)!=(0);
 $164 = ($161|0)>(-1);
 $or$cond$i$i8 = $163 & $164;
 if ($or$cond$i$i8) {
  $165 = (($this) + 3668|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ($166|0)==(0|0);
  if (!($167)) {
   $168 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $169 = HEAP32[$168>>2]|0;
   $170 = (($169) + 12|0);
   $171 = HEAP32[$170>>2]|0;
   FUNCTION_TABLE_vii[$171 & 4095]($168,$166);
  }
 }
 $172 = (($this) + 3652|0);
 $173 = HEAP32[$172>>2]|0;
 __ZN5physx6shdfnd8SyncImplD2Ev($173);
 $174 = HEAP32[$172>>2]|0;
 $175 = ($174|0)==(0|0);
 if (!($175)) {
  $176 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($177) + 12|0);
  $179 = HEAP32[$178>>2]|0;
  FUNCTION_TABLE_vii[$179 & 4095]($176,$174);
 }
 $180 = (($this) + 3648|0);
 $181 = HEAP32[$180>>2]|0;
 __ZN5physx6shdfnd8SyncImplD2Ev($181);
 $182 = HEAP32[$180>>2]|0;
 $183 = ($182|0)==(0|0);
 if (!($183)) {
  $184 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $185 = HEAP32[$184>>2]|0;
  $186 = (($185) + 12|0);
  $187 = HEAP32[$186>>2]|0;
  FUNCTION_TABLE_vii[$187 & 4095]($184,$182);
 }
 $188 = (($this) + 3644|0);
 $189 = HEAP32[$188>>2]|0;
 $190 = $189 & 2147483647;
 $191 = ($190|0)!=(0);
 $192 = ($189|0)>(-1);
 $or$cond$i$i6 = $191 & $192;
 if ($or$cond$i$i6) {
  $193 = HEAP32[$16>>2]|0;
  $194 = ($193|0)==(0|0);
  if (!($194)) {
   $195 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $196 = HEAP32[$195>>2]|0;
   $197 = (($196) + 12|0);
   $198 = HEAP32[$197>>2]|0;
   FUNCTION_TABLE_vii[$198 & 4095]($195,$193);
  }
 }
 $199 = (($this) + 3632|0);
 $200 = HEAP32[$199>>2]|0;
 $201 = $200 & 2147483647;
 $202 = ($201|0)!=(0);
 $203 = ($200|0)>(-1);
 $or$cond$i$i5 = $202 & $203;
 if ($or$cond$i$i5) {
  $204 = HEAP32[$5>>2]|0;
  $205 = ($204|0)==(0|0);
  if (!($205)) {
   $206 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $207 = HEAP32[$206>>2]|0;
   $208 = (($207) + 12|0);
   $209 = HEAP32[$208>>2]|0;
   FUNCTION_TABLE_vii[$209 & 4095]($206,$204);
  }
 }
 $210 = (($this) + 3620|0);
 $211 = HEAP32[$210>>2]|0;
 $212 = $211 & 2147483647;
 $213 = ($212|0)!=(0);
 $214 = ($211|0)>(-1);
 $or$cond$i$i4 = $213 & $214;
 if ($or$cond$i$i4) {
  $215 = HEAP32[$121>>2]|0;
  $216 = ($215|0)==(0|0);
  if (!($216)) {
   $217 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = (($218) + 12|0);
   $220 = HEAP32[$219>>2]|0;
   FUNCTION_TABLE_vii[$220 & 4095]($217,$215);
  }
 }
 $221 = HEAP32[$58>>2]|0;
 $222 = ($221|0)==(0|0);
 if (!($222)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($58,$221);
 }
 $223 = (($this) + 3568|0);
 $224 = HEAP32[$223>>2]|0;
 $225 = $224 & 2147483647;
 $226 = ($225|0)!=(0);
 $227 = ($224|0)>(-1);
 $or$cond$i$i3 = $226 & $227;
 do {
  if ($or$cond$i$i3) {
   $228 = HEAP32[$1>>2]|0;
   $229 = ($228|0)==(0|0);
   if ($229) {
    break;
   }
   $230 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $231 = HEAP32[$230>>2]|0;
   $232 = (($231) + 12|0);
   $233 = HEAP32[$232>>2]|0;
   FUNCTION_TABLE_vii[$233 & 4095]($230,$228);
  }
 } while(0);
 $234 = (($this) + 3556|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = $235 & 2147483647;
 $237 = ($236|0)!=(0);
 $238 = ($235|0)>(-1);
 $or$cond$i$i2 = $237 & $238;
 do {
  if ($or$cond$i$i2) {
   $239 = HEAP32[$38>>2]|0;
   $240 = ($239|0)==(0|0);
   if ($240) {
    break;
   }
   $241 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $242 = HEAP32[$241>>2]|0;
   $243 = (($242) + 12|0);
   $244 = HEAP32[$243>>2]|0;
   FUNCTION_TABLE_vii[$244 & 4095]($241,$239);
  }
 } while(0);
 $245 = (($this) + 3544|0);
 $246 = HEAP32[$245>>2]|0;
 $247 = $246 & 2147483647;
 $248 = ($247|0)!=(0);
 $249 = ($246|0)>(-1);
 $or$cond$i$i1 = $248 & $249;
 do {
  if ($or$cond$i$i1) {
   $250 = HEAP32[$27>>2]|0;
   $251 = ($250|0)==(0|0);
   if ($251) {
    break;
   }
   $252 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $253 = HEAP32[$252>>2]|0;
   $254 = (($253) + 12|0);
   $255 = HEAP32[$254>>2]|0;
   FUNCTION_TABLE_vii[$255 & 4095]($252,$250);
  }
 } while(0);
 $256 = (($this) + 3532|0);
 $257 = HEAP32[$256>>2]|0;
 $258 = $257 & 2147483647;
 $259 = ($258|0)!=(0);
 $260 = ($257|0)>(-1);
 $or$cond$i$i = $259 & $260;
 if (!($or$cond$i$i)) {
  $268 = (($this) + 3460|0);
  __ZN5physx2Cm12RenderBufferD2Ev($268);
  HEAP32[$this>>2] = ((429656 + 8|0));
  $269 = (($this) + 3376|0);
  __ZN5physx2Sq17SceneQueryManagerD2Ev($269);
  __ZN5physx3Scb5SceneD2Ev($111);
  STACKTOP = sp;return;
 }
 $261 = (($this) + 3524|0);
 $262 = HEAP32[$261>>2]|0;
 $263 = ($262|0)==(0|0);
 if ($263) {
  $268 = (($this) + 3460|0);
  __ZN5physx2Cm12RenderBufferD2Ev($268);
  HEAP32[$this>>2] = ((429656 + 8|0));
  $269 = (($this) + 3376|0);
  __ZN5physx2Sq17SceneQueryManagerD2Ev($269);
  __ZN5physx3Scb5SceneD2Ev($111);
  STACKTOP = sp;return;
 }
 $264 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = (($265) + 12|0);
 $267 = HEAP32[$266>>2]|0;
 FUNCTION_TABLE_vii[$267 & 4095]($264,$262);
 $268 = (($this) + 3460|0);
 __ZN5physx2Cm12RenderBufferD2Ev($268);
 HEAP32[$this>>2] = ((429656 + 8|0));
 $269 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManagerD2Ev($269);
 __ZN5physx3Scb5SceneD2Ev($111);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene18releaseVolumeCacheEPNS_13NpVolumeCacheE($this,$volumeCache) {
 $this = $this|0;
 $volumeCache = $volumeCache|0;
 var $$pr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ptr$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3592|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = $volumeCache;
   $4 = $3 << 15;
   $5 = $4 ^ -1;
   $6 = (($3) + ($5))|0;
   $7 = $6 >>> 10;
   $8 = $7 ^ $6;
   $9 = ($8*9)|0;
   $10 = $9 >>> 6;
   $11 = $10 ^ $9;
   $12 = $11 << 11;
   $13 = $12 ^ -1;
   $14 = (($11) + ($13))|0;
   $15 = $14 >>> 16;
   $16 = $15 ^ $14;
   $17 = (($1) + -1)|0;
   $18 = $17 & $16;
   $19 = (($this) + 3584|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + ($18<<2)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(-1);
   if (!($23)) {
    $24 = (($this) + 3576|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 3580|0);
    $$pr$i$i = $22;$ptr$02$i$i = $21;
    while(1) {
     $27 = (($25) + ($$pr$i$i<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($volumeCache|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($$pr$i$i<<2)|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(-1);
     if ($33) {
      break L1;
     } else {
      $$pr$i$i = $32;$ptr$02$i$i = $31;
     }
    }
    $34 = ($$pr$i$i|0)==(-1);
    if (!($34)) {
     $35 = HEAP32[$26>>2]|0;
     $36 = (($35) + ($$pr$i$i<<2)|0);
     $37 = HEAP32[$36>>2]|0;
     HEAP32[$ptr$02$i$i>>2] = $37;
     $38 = (($this) + 3608|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + -1)|0;
     HEAP32[$38>>2] = $40;
     $41 = (($this) + 3604|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($42) + 1)|0;
     HEAP32[$41>>2] = $43;
     $44 = (($this) + 3600|0);
     $45 = HEAP32[$44>>2]|0;
     HEAP32[$36>>2] = $45;
     HEAP32[$44>>2] = $$pr$i$i;
    }
   }
  }
 } while(0);
 $46 = ($volumeCache|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = HEAP32[$volumeCache>>2]|0;
 $48 = (($47) + 60|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vi[$49 & 4095]($volumeCache);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSolveEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_14executeCollideEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSceneEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene15SceneCompletionD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene7releaseEv($this) {
 $this = $this|0;
 var $$in$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 3372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 $4 = (($this) + 3348|0);
 $5 = (($this) + 1232|0);
 $$in$in = $3 ? $5 : $4;
 $6 = HEAP16[$$in$in>>1]|0;
 $7 = $6 & 4096;
 $8 = ($7<<16>>16)==(0);
 if (!($8)) {
  $9 = HEAP32[$this>>2]|0;
  $10 = (($9) + 400|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viii[$11 & 4095]($this,430616,225);
 }
 $12 = (($this) + 3656|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $15 = (($this) + 3657|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $22 = HEAP32[424544>>2]|0;
   __ZN5physx9NpPhysics20releaseSceneInternalERNS_7PxSceneE($22,$this);
   STACKTOP = sp;return;
  }
 }
 $18 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($18,8,430616,233,430688,$vararg_buffer);
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 236|0);
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($this,1,0)|0);
 $22 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics20releaseSceneInternalERNS_7PxSceneE($22,$this);
 STACKTOP = sp;return;
}
function __ZN5physx12NpGetPxSceneERNS_3Scb5SceneE($scene) {
 $scene = $scene|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scene) + -16|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx7NpScene12loadFromDescERKNS_11PxSceneDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($desc) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $17 = 0;
 } else {
  $3 = (($this) + 3544|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4 & 2147483647;
  $6 = ($5>>>0)<($1>>>0);
  if ($6) {
   $7 = (($this) + 3536|0);
   __ZN5physx6shdfnd5ArrayIPNS_12PxRigidActorENS0_19ReflectionAllocatorIS3_EEE8recreateEj($7,$1);
   $$pre = HEAP32[$0>>2]|0;
   $17 = $$pre;
  } else {
   $17 = $1;
  }
 }
 $8 = (($this) + 32|0);
 $9 = (($desc) + 52|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($desc) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($desc) + 60|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($desc) + 64|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN5physx2Sc5Scene11preAllocateEjjjjj($8,$17,$10,$12,$14,$16);
 $18 = (($desc) + 128|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 4|0);
 HEAP32[$20>>2] = $19;
 STACKTOP = sp;return 1;
}
function __ZN5physx7NpScene10setGravityERKNS_6PxVec3E($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0;
 var $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2432|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = Math_fround(HEAPF32[$g>>2]);
 if ($2) {
  $4 = (($this) + 64|0);
  HEAPF32[$4>>2] = $3;
  $5 = (($g) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($this) + 68|0);
  HEAPF32[$7>>2] = $6;
  $8 = (($g) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($this) + 72|0);
  HEAPF32[$10>>2] = $9;
  $11 = (($this) + 76|0);
  HEAP32[$11>>2] = 1;
  STACKTOP = sp;return;
 } else {
  $12 = (($this) + 3332|0);
  HEAPF32[$12>>2] = $3;
  $13 = (($g) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($this) + 3336|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($g) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($this) + 3340|0);
  HEAPF32[$18>>2] = $17;
  $19 = (($this) + 3372|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20 | 1;
  HEAP32[$19>>2] = $21;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene10getGravityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $12 = (($this) + 64|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$agg$result>>2] = $13;
  $14 = (($agg$result) + 4|0);
  $15 = (($this) + 68|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$14>>2] = $16;
  $17 = (($agg$result) + 8|0);
  $18 = (($this) + 72|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$17>>2] = $19;
  STACKTOP = sp;return;
 } else {
  $4 = (($this) + 3332|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$agg$result>>2] = $5;
  $6 = (($agg$result) + 4|0);
  $7 = (($this) + 3336|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$6>>2] = $8;
  $9 = (($agg$result) + 8|0);
  $10 = (($this) + 3340|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$9>>2] = $11;
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene26setBounceThresholdVelocityEf($this,$t) {
 $this = $this|0;
 $t = Math_fround($t);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2432|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene26setBounceThresholdVelocityEf($3,$t);
  STACKTOP = sp;return;
 } else {
  $4 = (($this) + 3344|0);
  HEAPF32[$4>>2] = $t;
  $5 = (($this) + 3372|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 | 2;
  HEAP32[$5>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene26getBounceThresholdVelocityEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $6 = (($this) + 32|0);
  $7 = (Math_fround(__ZNK5physx2Sc5Scene26getBounceThresholdVelocityEv($6)));
  $$0$i = $7;
  STACKTOP = sp;return (Math_fround($$0$i));
 } else {
  $4 = (($this) + 3344|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $$0$i = $5;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpScene9setLimitsERKNS_13PxSceneLimitsE($this,$limits) {
 $this = $this|0;
 $limits = $limits|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$limits>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $16 = 0;
 } else {
  $2 = (($this) + 3544|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = $3 & 2147483647;
  $5 = ($4>>>0)<($0>>>0);
  if ($5) {
   $6 = (($this) + 3536|0);
   __ZN5physx6shdfnd5ArrayIPNS_12PxRigidActorENS0_19ReflectionAllocatorIS3_EEE8recreateEj($6,$0);
   $$pre = HEAP32[$limits>>2]|0;
   $16 = $$pre;
  } else {
   $16 = $0;
  }
 }
 $7 = (($this) + 32|0);
 $8 = (($limits) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($limits) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($limits) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($limits) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx2Sc5Scene11preAllocateEjjjjj($7,$16,$9,$11,$13,$15);
 __ZN5physx2Sc5Scene9setLimitsERKNS_13PxSceneLimitsE($7,$limits);
 $17 = (($this) + 3376|0);
 $18 = HEAP32[$10>>2]|0;
 $19 = HEAP32[$12>>2]|0;
 __ZN5physx2Sq17SceneQueryManager11preallocateEjj($17,$18,$19);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene9getLimitsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene9getLimitsEv($0)|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$agg$result+24>>2]=HEAP32[$1+24>>2]|0;HEAP32[$agg$result+28>>2]=HEAP32[$1+28>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene7setFlagENS_11PxSceneFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$in$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 $4 = (($this) + 3348|0);
 $5 = (($this) + 1232|0);
 $$in$in = $3 ? $5 : $4;
 $6 = HEAP16[$$in$in>>1]|0;
 if ($value) {
  $7 = $6&65535;
  $8 = $7 | $flag;
  $9 = $8&65535;
  $17 = $9;
 } else {
  $10 = $flag ^ 65535;
  $11 = $10&65535;
  $12 = $6 & $11;
  $17 = $12;
 }
 $13 = (($this) + 2433|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $16 = (($this) + 32|0);
  HEAP16[$5>>1] = $17;
  $18 = $17 & 512;
  $19 = ($18<<16>>16)!=(0);
  __ZN5physx2Sc5Scene6setPCMEb($16,$19);
  $20 = $17 & 2048;
  $21 = ($20<<16>>16)==(0);
  __ZN5physx2Sc5Scene15setContactCacheEb($16,$21);
  STACKTOP = sp;return;
 } else {
  HEAP16[$4>>1] = $17;
  $22 = $1 | 4;
  HEAP32[$0>>2] = $22;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene8getFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 if ($3) {
  $6 = (($this) + 1232|0);
  $7 = HEAP16[$6>>1]|0;
  HEAP16[$agg$result>>1] = $7;
  STACKTOP = sp;return;
 } else {
  $4 = (($this) + 3348|0);
  $5 = HEAP16[$4>>1]|0;
  HEAP16[$agg$result>>1] = $5;
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene8addActorERNS_7PxActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 1216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1208|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 511]($1,48,$5,$8);
 $12 = (($actor) + 4|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13&65535;
 $15 = ((414264 + ($14<<2)|0) + 68|0);
 $16 = HEAP32[$15>>2]|0;
 $$sum = (($16) + 4)|0;
 $17 = (($actor) + ($$sum)|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 >>> 30;
 if ((($19|0) == 3)) {
  $20 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($actor)|0);
  $21 = ($20|0)==($this|0);
  if ($21) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($19|0) == 0)) {
  label = 3;
 } else {
  label = 4;
 }
 if ((label|0) == 3) {
  __ZN5physx7NpScene16addActorInternalERNS_7PxActorE($this,$actor);
  $23 = HEAP32[$1>>2]|0;
  $24 = (($23) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_viiii[$25 & 511]($1,48,$5,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $22 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($22,8,430616,355,430792,$vararg_buffer);
  $23 = HEAP32[$1>>2]|0;
  $24 = (($23) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_viiii[$25 & 511]($1,48,$5,$8);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene16addActorInternalERNS_7PxActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 8|0;
 $1 = sp + 4|0;
 $2 = (($actor) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 switch ($4|0) {
 case 15:  {
  $49 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($49,2,430616,408,430936,$vararg_buffer1);
  STACKTOP = sp;return;
  break;
 }
 case 10:  {
  $36 = (($this) + 16|0);
  $37 = (($actor) + 20|0);
  __ZN5physx3Scb5Scene8addClothERNS0_5ClothE($36,$37);
  $38 = (($this) + 3636|0);
  HEAP32[$1>>2] = $actor;
  $39 = (($this) + 3644|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & 2147483647;
  $42 = (($this) + 3640|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($41>>>0)>($43>>>0);
  if (!($44)) {
   (__ZN5physx6shdfnd5ArrayIPNS_7PxClothENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($38,$1)|0);
   STACKTOP = sp;return;
  }
  $45 = HEAP32[$38>>2]|0;
  $46 = (($45) + ($43<<2)|0);
  $47 = ($46|0)==(0|0);
  if (!($47)) {
   HEAP32[$46>>2] = $actor;
  }
  $48 = (($43) + 1)|0;
  HEAP32[$42>>2] = $48;
  STACKTOP = sp;return;
  break;
 }
 case 11:  {
  $10 = (($this) + 16|0);
  $11 = (($actor) + 20|0);
  __ZN5physx3Scb5Scene17addParticleSystemERNS0_14ParticleSystemE($10,$11);
  $12 = (($this) + 3624|0);
  HEAP32[$0>>2] = $actor;
  $13 = (($this) + 3632|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & 2147483647;
  $16 = (($this) + 3628|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($15>>>0)>($17>>>0);
  if (!($18)) {
   (__ZN5physx6shdfnd5ArrayIPNS_14PxParticleBaseENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($12,$0)|0);
   STACKTOP = sp;return;
  }
  $19 = HEAP32[$12>>2]|0;
  $20 = (($19) + ($17<<2)|0);
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   HEAP32[$20>>2] = $actor;
  }
  $22 = (($17) + 1)|0;
  HEAP32[$16>>2] = $22;
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  $5 = (($actor) + 20|0);
  $6 = (($5) + 4|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = ($7<<16>>16)==(0);
  if ($8) {
   $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,2,430616,366,430872,$vararg_buffer1);
  }
  __ZN5physx7NpScene14addRigidStaticERNS_13NpRigidStaticE($this,$actor);
  STACKTOP = sp;return;
  break;
 }
 case 12:  {
  $23 = (($this) + 16|0);
  $24 = (($actor) + 20|0);
  __ZN5physx3Scb5Scene17addParticleSystemERNS0_14ParticleSystemE($23,$24);
  $25 = (($this) + 3624|0);
  HEAP32[$vararg_buffer1>>2] = $actor;
  $26 = (($this) + 3632|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 & 2147483647;
  $29 = (($this) + 3628|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28>>>0)>($30>>>0);
  if (!($31)) {
   (__ZN5physx6shdfnd5ArrayIPNS_14PxParticleBaseENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($25,$vararg_buffer1)|0);
   STACKTOP = sp;return;
  }
  $32 = HEAP32[$25>>2]|0;
  $33 = (($32) + ($30<<2)|0);
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   HEAP32[$33>>2] = $actor;
  }
  $35 = (($30) + 1)|0;
  HEAP32[$29>>2] = $35;
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  __ZN5physx7NpScene15addRigidDynamicERNS_14NpRigidDynamicE($this,$actor);
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZN5physx7NpScene14addRigidStaticERNS_13NpRigidStaticE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = HEAP32[$actor>>2]|0;
 $3 = (($2) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($0,$actor);
 $5 = HEAP16[$0>>1]|0;
 $6 = $5 & 8;
 $7 = ($6<<16>>16)!=(0);
 $8 = (($this) + 16|0);
 $9 = (($actor) + 48|0);
 __ZN5physx3Scb5Scene14addRigidStaticERNS0_11RigidStaticEb($8,$9,$7);
 $10 = (($actor) + 20|0);
 __ZN5physx14NpShapeManager18setupAllSceneQueryERKNS_12PxRigidActorE($10,$actor);
 if (!($7)) {
  $11 = (($actor) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = (($actor) + 12|0);
   __ZN5physx7NpActor29addConstraintsToSceneInternalEv($14);
  }
 }
 $15 = (($this) + 3536|0);
 $16 = (($this) + 3540|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($actor) + 36|0);
 HEAP32[$18>>2] = $17;
 HEAP32[$1>>2] = $actor;
 $19 = (($this) + 3544|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 2147483647;
 $22 = HEAP32[$16>>2]|0;
 $23 = ($21>>>0)>($22>>>0);
 if (!($23)) {
  (__ZN5physx6shdfnd5ArrayIPNS_12PxRigidActorENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($15,$1)|0);
  STACKTOP = sp;return;
 }
 $24 = HEAP32[$15>>2]|0;
 $25 = (($24) + ($22<<2)|0);
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  HEAP32[$25>>2] = $actor;
 }
 $27 = (($22) + 1)|0;
 HEAP32[$16>>2] = $27;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene15addRigidDynamicERNS_14NpRigidDynamicE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = HEAP32[$body>>2]|0;
 $3 = (($2) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($0,$body);
 $5 = HEAP16[$0>>1]|0;
 $6 = $5 & 8;
 $7 = ($6<<16>>16)!=(0);
 $8 = (($this) + 16|0);
 $9 = (($body) + 48|0);
 __ZN5physx3Scb5Scene12addRigidBodyERNS0_4BodyEb($8,$9,$7);
 $10 = (($body) + 20|0);
 __ZN5physx14NpShapeManager18setupAllSceneQueryERKNS_12PxRigidActorE($10,$body);
 if (!($7)) {
  $11 = (($body) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = (($body) + 12|0);
   __ZN5physx7NpActor29addConstraintsToSceneInternalEv($14);
  }
 }
 $15 = (($this) + 3536|0);
 $16 = (($this) + 3540|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($body) + 36|0);
 HEAP32[$18>>2] = $17;
 HEAP32[$1>>2] = $body;
 $19 = (($this) + 3544|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 2147483647;
 $22 = HEAP32[$16>>2]|0;
 $23 = ($21>>>0)>($22>>>0);
 if (!($23)) {
  (__ZN5physx6shdfnd5ArrayIPNS_12PxRigidActorENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($15,$1)|0);
  STACKTOP = sp;return;
 }
 $24 = HEAP32[$15>>2]|0;
 $25 = (($24) + ($22<<2)|0);
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  HEAP32[$25>>2] = $body;
 }
 $27 = (($22) + 1)|0;
 HEAP32[$16>>2] = $27;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene24updateScbStateAndSetupSqERKNS_12PxRigidActorERNS_3Scb5ActorERNS_14NpShapeManagerEbPNS_9PxBounds3E($this,$rigidActor,$scbActor,$shapeManager,$actorDynamic,$bounds) {
 $this = $this|0;
 $rigidActor = $rigidActor|0;
 $scbActor = $scbActor|0;
 $shapeManager = $shapeManager|0;
 $actorDynamic = $actorDynamic|0;
 $bounds = $bounds|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3376|0);
 $1 = (($this) + 16|0);
 HEAP32[$scbActor>>2] = $1;
 $2 = (($scbActor) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1073741823;
 $5 = $4 | -2147483648;
 HEAP32[$2>>2] = $5;
 $6 = (($shapeManager) + 4|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = ($7<<16>>16)==(1);
 if ($8) {
  $15 = $shapeManager;
 } else {
  $9 = HEAP32[$shapeManager>>2]|0;
  $10 = ($7<<16>>16)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $15 = $9;
  }
 }
 $11 = (($shapeManager) + 8|0);
 $12 = (($shapeManager) + 12|0);
 $13 = $7&65535;
 $i$04 = 0;
 while(1) {
  $14 = (($15) + ($i$04<<2)|0);
  $16 = HEAP32[$14>>2]|0;
  $17 = (($16) + 112|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = (($16) + 16|0);
  (__ZN5physx6shdfnd15atomicIncrementEPVi($19)|0);
  $20 = (__ZNK5physx7NpShape11isExclusiveEv($16)|0);
  if ($20) {
   $21 = (($16) + 32|0);
   HEAP32[$21>>2] = $1;
   $22 = (($16) + 36|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23 & 1073741823;
   $25 = $24 | -2147483648;
   HEAP32[$22>>2] = $25;
  }
  $26 = $18 & 2;
  $27 = ($26<<24>>24)==(0);
  if (!($27)) {
   $28 = HEAP32[$14>>2]|0;
   $29 = $18 & 5;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $32 = 0;
   } else {
    $31 = (($bounds) + (($i$04*24)|0)|0);
    $32 = $31;
   }
   $33 = (__ZN5physx2Sq17SceneQueryManager8addShapeERKNS_7NpShapeERKNS_12PxRigidActorEbPNS_9PxBounds3E($0,$28,$rigidActor,$actorDynamic,$32)|0);
   $34 = HEAP16[$12>>1]|0;
   $35 = ($34<<16>>16)==(1);
   if ($35) {
    $38 = $11;
   } else {
    $36 = HEAP32[$11>>2]|0;
    $38 = $36;
   }
   $37 = (($38) + ($i$04<<2)|0);
   HEAP32[$37>>2] = $33;
  }
  $39 = (($i$04) + 1)|0;
  $exitcond = ($39|0)==($13|0);
  if ($exitcond) {
   break;
  } else {
   $i$04 = $39;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene9addActorsEPKPNS_7PxActorEj($this,$actors,$nbActors) {
 $this = $this|0;
 $actors = $actors|0;
 $nbActors = $nbActors|0;
 var $$c = 0, $$c11 = 0, $$in = 0, $$in10 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $cp$0$i = 0, $exitcond = 0, $indvars$iv = 0, $indvars$iv$next = 0, $j$012 = 0, $or$cond$i$i$i = 0, $scState = 0, $shapeBounds = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $vararg_buffer3 = sp;
 $scState = sp + 224|0;
 $shapeBounds = sp + 8|0;
 $0 = sp + 216|0;
 $1 = sp + 220|0;
 $2 = (($this) + 1216|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 1208|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiii[$13 & 511]($3,48,$7,$10);
 $14 = (($this) + 3656|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if (!($16)) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,2,430616,456,431024,$vararg_buffer3);
  $173 = HEAP32[$3>>2]|0;
  $174 = (($173) + 12|0);
  $175 = HEAP32[$174>>2]|0;
  FUNCTION_TABLE_viiii[$175 & 511]($3,48,$7,$10);
  STACKTOP = sp;return;
 }
 $18 = (($this) + 32|0);
 __ZN5physx2Sc5Scene19startBatchInsertionERNS0_19BatchInsertionStateE($18,$scState);
 $19 = (($scState) + 12|0);
 HEAP32[$19>>2] = 64;
 $20 = (($scState) + 16|0);
 HEAP32[$20>>2] = 20;
 $21 = (($scState) + 20|0);
 HEAP32[$21>>2] = 64;
 $22 = (($scState) + 24|0);
 HEAP32[$22>>2] = 20;
 $23 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $24 = (($scState) + 28|0);
 HEAP32[$24>>2] = $23;
 $25 = (($shapeBounds) + 192|0);
 $26 = (($shapeBounds) + 196|0);
 $27 = (($shapeBounds) + 200|0);
 HEAP32[$27>>2] = 0;
 $28 = (($shapeBounds) + 204|0);
 HEAP8[$25>>0] = 1;
 HEAP32[$26>>2] = $shapeBounds;
 HEAP32[$28>>2] = 8;
 $29 = ($nbActors|0)==(0);
 L5: do {
  if ($29) {
   label = 45;
  } else {
   $30 = (($this) + 3536|0);
   $31 = (($this) + 3540|0);
   $32 = (($this) + 3544|0);
   $indvars$iv = 0;
   L7: while(1) {
    $indvars$iv$next = (($indvars$iv) + 1)|0;
    $33 = ($indvars$iv$next>>>0)<($nbActors>>>0);
    if ($33) {
     $34 = (($actors) + ($indvars$iv$next<<2)|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = $35;
     $37 = (_bitshift64Lshr(($36|0),0,6)|0);
     $38 = tempRet0;
     $39 = (_i64Add(($36|0),0,287,0)|0);
     $40 = tempRet0;
     $41 = (_bitshift64Lshr(($39|0),($40|0),6)|0);
     $42 = tempRet0;
     $43 = (_i64Subtract(1,0,($37|0),($38|0))|0);
     $44 = tempRet0;
     $45 = (_i64Add(($43|0),($44|0),($41|0),($42|0))|0);
     $46 = tempRet0;
     $48 = $45;$49 = $46;$cp$0$i = $35;
     while(1) {
      $47 = (($cp$0$i) + 64|0);
      $50 = (_i64Add(($48|0),($49|0),-1,-1)|0);
      $51 = tempRet0;
      $52 = ($50|0)==(0);
      $53 = ($51|0)==(0);
      $54 = $52 & $53;
      if ($54) {
       break;
      } else {
       $48 = $50;$49 = $51;$cp$0$i = $47;
      }
     }
    }
    $55 = (($actors) + ($indvars$iv<<2)|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($56) + 4|0);
    $58 = HEAP16[$57>>1]|0;
    $59 = $58&65535;
    $60 = ((414264 + ($59<<2)|0) + 68|0);
    $61 = HEAP32[$60>>2]|0;
    $$sum = (($61) + 4)|0;
    $62 = (($56) + ($$sum)|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = $63 >>> 30;
    if ((($64|0) == 3)) {
     $65 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($56)|0);
     $66 = ($65|0)==($this|0);
     if (!($66)) {
      label = 10;
      break;
     }
    } else if (!((($64|0) == 0))) {
     label = 10;
     break;
    }
    L17: do {
     switch ($58<<16>>16) {
     case 12: case 11: case 10:  {
      $156 = HEAP32[$55>>2]|0;
      __ZN5physx7NpScene16addActorInternalERNS_7PxActorE($this,$156);
      break;
     }
     case 6:  {
      $68 = HEAP32[$55>>2]|0;
      $69 = (($68) + 48|0);
      $70 = (($68) + 52|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = $71 & 1;
      $73 = ($72|0)==(0);
      if ($73) {
       $81 = $71 >>> 24;
       $82 = $81 & 15;
       $83 = ((444424 + ($82<<2)|0) + 24|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = $69;
       $86 = (($84) + ($85))|0;
       $87 = $86;
       $88 = (($87) + 8|0);
       $$in10 = $88;
      } else {
       $74 = (($68) + 56|0);
       $75 = HEAP32[$74>>2]|0;
       $76 = ($75|0)==(0|0);
       if ($76) {
        $77 = HEAP32[$69>>2]|0;
        $78 = $71 >>> 24;
        $79 = $78 & 15;
        $80 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($77,$79)|0);
        HEAP32[$74>>2] = $80;
        $176 = $80;
       } else {
        $176 = $75;
       }
       $$in10 = $176;
      }
      $89 = HEAP16[$$in10>>1]|0;
      $90 = $89 & 8;
      $91 = ($90<<16>>16)==(0);
      if (!($91)) {
       __ZN5physx7NpScene14addRigidStaticERNS_13NpRigidStaticE($this,$68);
       break L17;
      }
      $92 = (($68) + 24|0);
      $93 = HEAP16[$92>>1]|0;
      $94 = $93&65535;
      __ZN5physx6shdfnd5ArrayINS_9PxBounds3ENS0_15InlineAllocatorILj192ENS0_19ReflectionAllocatorIS2_EEEEE19resizeUninitializedEj($shapeBounds,$94);
      $95 = HEAP32[$26>>2]|0;
      __ZN5physx2Sc5Scene9addStaticEPNS_7PxActorERNS0_19BatchInsertionStateEPNS_9PxBounds3E($18,$68,$scState,$95);
      $96 = (($68) + 20|0);
      $97 = HEAP32[$26>>2]|0;
      __ZN5physx7NpScene24updateScbStateAndSetupSqERKNS_12PxRigidActorERNS_3Scb5ActorERNS_14NpShapeManagerEbPNS_9PxBounds3E($this,$68,$69,$96,0,$97);
      $98 = HEAP32[$31>>2]|0;
      $99 = (($68) + 36|0);
      $$c11 = $98;
      HEAP32[$99>>2] = $$c11;
      HEAP32[$0>>2] = $68;
      $100 = HEAP32[$32>>2]|0;
      $101 = $100 & 2147483647;
      $102 = HEAP32[$31>>2]|0;
      $103 = ($101>>>0)>($102>>>0);
      if ($103) {
       $104 = HEAP32[$30>>2]|0;
       $105 = (($104) + ($102<<2)|0);
       $106 = ($105|0)==(0|0);
       if (!($106)) {
        HEAP32[$105>>2] = $68;
       }
       $107 = (($102) + 1)|0;
       HEAP32[$31>>2] = $107;
      } else {
       (__ZN5physx6shdfnd5ArrayIPNS_12PxRigidActorENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
      }
      $108 = (($68) + 16|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($109|0)==(0|0);
      if (!($110)) {
       $111 = (($68) + 12|0);
       __ZN5physx7NpActor29addConstraintsToSceneInternalEv($111);
      }
      break;
     }
     case 5:  {
      $112 = HEAP32[$55>>2]|0;
      $113 = (($112) + 48|0);
      $114 = (($112) + 52|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = $115 & 1;
      $117 = ($116|0)==(0);
      if ($117) {
       $125 = $115 >>> 24;
       $126 = $125 & 15;
       $127 = ((444424 + ($126<<2)|0) + 24|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = $113;
       $130 = (($128) + ($129))|0;
       $131 = $130;
       $132 = (($131) + 8|0);
       $$in = $132;
      } else {
       $118 = (($112) + 56|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==(0|0);
       if ($120) {
        $121 = HEAP32[$113>>2]|0;
        $122 = $115 >>> 24;
        $123 = $122 & 15;
        $124 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($121,$123)|0);
        HEAP32[$118>>2] = $124;
        $177 = $124;
       } else {
        $177 = $119;
       }
       $$in = $177;
      }
      $133 = HEAP16[$$in>>1]|0;
      $134 = $133 & 8;
      $135 = ($134<<16>>16)==(0);
      if (!($135)) {
       __ZN5physx7NpScene15addRigidDynamicERNS_14NpRigidDynamicE($this,$112);
       break L17;
      }
      $136 = (($112) + 24|0);
      $137 = HEAP16[$136>>1]|0;
      $138 = $137&65535;
      __ZN5physx6shdfnd5ArrayINS_9PxBounds3ENS0_15InlineAllocatorILj192ENS0_19ReflectionAllocatorIS2_EEEEE19resizeUninitializedEj($shapeBounds,$138);
      $139 = HEAP32[$26>>2]|0;
      __ZN5physx2Sc5Scene7addBodyEPNS_7PxActorERNS0_19BatchInsertionStateEPNS_9PxBounds3E($18,$112,$scState,$139);
      $140 = (($112) + 20|0);
      $141 = HEAP32[$26>>2]|0;
      __ZN5physx7NpScene24updateScbStateAndSetupSqERKNS_12PxRigidActorERNS_3Scb5ActorERNS_14NpShapeManagerEbPNS_9PxBounds3E($this,$112,$113,$140,1,$141);
      $142 = HEAP32[$31>>2]|0;
      $143 = (($112) + 36|0);
      $$c = $142;
      HEAP32[$143>>2] = $$c;
      HEAP32[$1>>2] = $112;
      $144 = HEAP32[$32>>2]|0;
      $145 = $144 & 2147483647;
      $146 = HEAP32[$31>>2]|0;
      $147 = ($145>>>0)>($146>>>0);
      if ($147) {
       $148 = HEAP32[$30>>2]|0;
       $149 = (($148) + ($146<<2)|0);
       $150 = ($149|0)==(0|0);
       if (!($150)) {
        HEAP32[$149>>2] = $112;
       }
       $151 = (($146) + 1)|0;
       HEAP32[$31>>2] = $151;
      } else {
       (__ZN5physx6shdfnd5ArrayIPNS_12PxRigidActorENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$1)|0);
      }
      $152 = (($112) + 16|0);
      $153 = HEAP32[$152>>2]|0;
      $154 = ($153|0)==(0|0);
      if (!($154)) {
       $155 = (($112) + 12|0);
       __ZN5physx7NpActor29addConstraintsToSceneInternalEv($155);
      }
      break;
     }
     default: {
      label = 42;
      break L7;
     }
     }
    } while(0);
    if ($33) {
     $indvars$iv = $indvars$iv$next;
    } else {
     label = 45;
     break L5;
    }
   }
   if ((label|0) == 10) {
    $67 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($67,8,430616,485,431088,$vararg_buffer3);
   }
   else if ((label|0) == 42) {
    $157 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($157,2,430616,526,431168,$vararg_buffer3);
   }
   __ZN5physx2Sc5Scene20finishBatchInsertionERNS0_19BatchInsertionStateE($18,$scState);
   $158 = ($indvars$iv|0)==(0);
   if (!($158)) {
    $j$012 = 0;
    while(1) {
     $159 = (($actors) + ($j$012<<2)|0);
     $160 = HEAP32[$159>>2]|0;
     __ZN5physx7NpScene19removeActorInternalERNS_7PxActorEbb($this,$160,0,1);
     $161 = (($j$012) + 1)|0;
     $exitcond = ($161|0)==($indvars$iv|0);
     if ($exitcond) {
      break;
     } else {
      $j$012 = $161;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 45) {
  __ZN5physx2Sc5Scene20finishBatchInsertionERNS0_19BatchInsertionStateE($18,$scState);
 }
 $162 = HEAP32[$28>>2]|0;
 $163 = $162 & 2147483647;
 $164 = ($163|0)!=(0);
 $165 = ($162|0)>(-1);
 $or$cond$i$i$i = $164 & $165;
 if (!($or$cond$i$i$i)) {
  $173 = HEAP32[$3>>2]|0;
  $174 = (($173) + 12|0);
  $175 = HEAP32[$174>>2]|0;
  FUNCTION_TABLE_viiii[$175 & 511]($3,48,$7,$10);
  STACKTOP = sp;return;
 }
 $166 = HEAP32[$26>>2]|0;
 $167 = ($shapeBounds|0)==($166|0);
 if ($167) {
  HEAP8[$25>>0] = 0;
  $173 = HEAP32[$3>>2]|0;
  $174 = (($173) + 12|0);
  $175 = HEAP32[$174>>2]|0;
  FUNCTION_TABLE_viiii[$175 & 511]($3,48,$7,$10);
  STACKTOP = sp;return;
 }
 $168 = ($166|0)==(0|0);
 if ($168) {
  $173 = HEAP32[$3>>2]|0;
  $174 = (($173) + 12|0);
  $175 = HEAP32[$174>>2]|0;
  FUNCTION_TABLE_viiii[$175 & 511]($3,48,$7,$10);
  STACKTOP = sp;return;
 }
 $169 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = (($170) + 12|0);
 $172 = HEAP32[$171>>2]|0;
 FUNCTION_TABLE_vii[$172 & 4095]($169,$166);
 $173 = HEAP32[$3>>2]|0;
 $174 = (($173) + 12|0);
 $175 = HEAP32[$174>>2]|0;
 FUNCTION_TABLE_viiii[$175 & 511]($3,48,$7,$10);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_9PxBounds3ENS0_15InlineAllocatorILj192ENS0_19ReflectionAllocatorIS2_EEEEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 204|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_9PxBounds3ENS0_15InlineAllocatorILj192ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 200|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene19removeActorInternalERNS_7PxActorEbb($this,$actor,$wakeOnLostTouch,$removeFromAggregate) {
 $this = $this|0;
 $actor = $actor|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 $removeFromAggregate = $removeFromAggregate|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i$i$i = 0, $index$0$lcssa$i$i$i3 = 0, $index$0$lcssa$i$i$i7 = 0, $index$01$i$i$i = 0;
 var $index$01$i$i$i2 = 0, $index$01$i$i$i6 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$actor>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($actor)|0);
 switch ($3|0) {
 case 3:  {
  $21 = (($this) + 16|0);
  $22 = (($actor) + 20|0);
  __ZN5physx3Scb5Scene20removeParticleSystemERNS0_14ParticleSystemEb($21,$22,0);
  $23 = (($this) + 3628|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0);
  if ($25) {
   STACKTOP = sp;return;
  }
  $26 = (($this) + 3624|0);
  $27 = HEAP32[$26>>2]|0;
  $index$01$i$i$i2 = 0;
  while(1) {
   $30 = (($27) + ($index$01$i$i$i2<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($actor|0);
   $29 = (($index$01$i$i$i2) + 1)|0;
   if ($32) {
    $index$0$lcssa$i$i$i3 = $index$01$i$i$i2;
    break;
   }
   $28 = ($29>>>0)<($24>>>0);
   if ($28) {
    $index$01$i$i$i2 = $29;
   } else {
    $index$0$lcssa$i$i$i3 = $29;
    break;
   }
  }
  $33 = ($index$0$lcssa$i$i$i3|0)==($24|0);
  if ($33) {
   STACKTOP = sp;return;
  }
  $34 = (($24) + -1)|0;
  HEAP32[$23>>2] = $34;
  $35 = (($27) + ($34<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($27) + ($index$0$lcssa$i$i$i3<<2)|0);
  HEAP32[$37>>2] = $36;
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  __ZN5physx7NpScene17removeRigidStaticERNS_13NpRigidStaticEbb($this,$actor,$wakeOnLostTouch,$removeFromAggregate);
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  $38 = (($this) + 16|0);
  $39 = (($actor) + 20|0);
  __ZN5physx3Scb5Scene11removeClothERNS0_5ClothE($38,$39);
  $40 = (($this) + 3640|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $43 = (($this) + 3636|0);
  $44 = HEAP32[$43>>2]|0;
  $index$01$i$i$i6 = 0;
  while(1) {
   $47 = (($44) + ($index$01$i$i$i6<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($actor|0);
   $46 = (($index$01$i$i$i6) + 1)|0;
   if ($49) {
    $index$0$lcssa$i$i$i7 = $index$01$i$i$i6;
    break;
   }
   $45 = ($46>>>0)<($41>>>0);
   if ($45) {
    $index$01$i$i$i6 = $46;
   } else {
    $index$0$lcssa$i$i$i7 = $46;
    break;
   }
  }
  $50 = ($index$0$lcssa$i$i$i7|0)==($41|0);
  if ($50) {
   STACKTOP = sp;return;
  }
  $51 = (($41) + -1)|0;
  HEAP32[$40>>2] = $51;
  $52 = (($44) + ($51<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($44) + ($index$0$lcssa$i$i$i7<<2)|0);
  HEAP32[$54>>2] = $53;
  STACKTOP = sp;return;
  break;
 }
 case 2:  {
  $4 = (($this) + 16|0);
  $5 = (($actor) + 20|0);
  __ZN5physx3Scb5Scene20removeParticleSystemERNS0_14ParticleSystemEb($4,$5,0);
  $6 = (($this) + 3628|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   STACKTOP = sp;return;
  }
  $9 = (($this) + 3624|0);
  $10 = HEAP32[$9>>2]|0;
  $index$01$i$i$i = 0;
  while(1) {
   $13 = (($10) + ($index$01$i$i$i<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($actor|0);
   $12 = (($index$01$i$i$i) + 1)|0;
   if ($15) {
    $index$0$lcssa$i$i$i = $index$01$i$i$i;
    break;
   }
   $11 = ($12>>>0)<($7>>>0);
   if ($11) {
    $index$01$i$i$i = $12;
   } else {
    $index$0$lcssa$i$i$i = $12;
    break;
   }
  }
  $16 = ($index$0$lcssa$i$i$i|0)==($7|0);
  if ($16) {
   STACKTOP = sp;return;
  }
  $17 = (($7) + -1)|0;
  HEAP32[$6>>2] = $17;
  $18 = (($10) + ($17<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($10) + ($index$0$lcssa$i$i$i<<2)|0);
  HEAP32[$20>>2] = $19;
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  $55 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($55,2,430616,696,431264,$vararg_buffer);
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  __ZN5physx7NpScene18removeRigidDynamicERNS_14NpRigidDynamicEbb($this,$actor,$wakeOnLostTouch,$removeFromAggregate);
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZN5physx7NpScene12removeActorsEPKPNS_7PxActorEjb($this,$actors,$nbActors,$wakeOnLostTouch) {
 $this = $this|0;
 $actors = $actors|0;
 $nbActors = $nbActors|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $$c$i = 0, $$c$i8 = 0, $$c1$i = 0, $$c1$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $actorFlags = 0, $actorFlags2 = 0, $actorsDone$021 = 0, $cp$0$i = 0, $cp$0$i1 = 0, $cp$0$i11 = 0, $cp$0$i14 = 0, $cp$0$i4 = 0, $or$cond$i$i$i$i$i = 0, $or$cond$i$i$i1$i$i = 0, $removeState = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $vararg_buffer1 = sp;
 $removeState = sp + 8|0;
 $actorFlags = sp + 554|0;
 $actorFlags2 = sp + 552|0;
 $0 = (($this) + 16|0);
 $1 = (($this) + 1216|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1208|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,49,$6,$9);
 $13 = (($this) + 32|0);
 $14 = (($this) + 3540|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx2Sc5Scene24resizeReleasedBodyIDMapsEjj($13,$15,$nbActors);
 $16 = (($removeState) + 256|0);
 $17 = (($removeState) + 260|0);
 $18 = (($removeState) + 264|0);
 HEAP32[$18>>2] = 0;
 $19 = (($removeState) + 268|0);
 HEAP8[$16>>0] = 1;
 HEAP32[$17>>2] = $removeState;
 HEAP32[$19>>2] = 64;
 $20 = (($removeState) + 272|0);
 $21 = (($removeState) + 528|0);
 $22 = (($removeState) + 532|0);
 $23 = (($removeState) + 536|0);
 HEAP32[$23>>2] = 0;
 $24 = (($removeState) + 540|0);
 HEAP8[$21>>0] = 1;
 HEAP32[$22>>2] = $20;
 HEAP32[$24>>2] = 64;
 $25 = (($this) + 1276|0);
 HEAP32[$25>>2] = $removeState;
 $26 = ($nbActors|0)==(0);
 L1: do {
  if (!($26)) {
   $27 = (($this) + 3536|0);
   $28 = (($this) + 3376|0);
   $29 = (($this) + 3536|0);
   $actorsDone$021 = 0;
   L3: while(1) {
    $30 = (($actorsDone$021) + 1)|0;
    $31 = ($30>>>0)<($nbActors>>>0);
    if ($31) {
     $32 = (($actors) + ($30<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = $33;
     $35 = (_bitshift64Lshr(($34|0),0,6)|0);
     $36 = tempRet0;
     $37 = (_i64Add(($34|0),0,287,0)|0);
     $38 = tempRet0;
     $39 = (_bitshift64Lshr(($37|0),($38|0),6)|0);
     $40 = tempRet0;
     $41 = (_i64Subtract(1,0,($35|0),($36|0))|0);
     $42 = tempRet0;
     $43 = (_i64Add(($41|0),($42|0),($39|0),($40|0))|0);
     $44 = tempRet0;
     $46 = $43;$47 = $44;$cp$0$i = $33;
     while(1) {
      $45 = (($cp$0$i) + 64|0);
      $48 = (_i64Add(($46|0),($47|0),-1,-1)|0);
      $49 = tempRet0;
      $50 = ($48|0)==(0);
      $51 = ($49|0)==(0);
      $52 = $50 & $51;
      if ($52) {
       break;
      } else {
       $46 = $48;$47 = $49;$cp$0$i = $45;
      }
     }
    }
    $53 = (($actors) + ($actorsDone$021<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + 4|0);
    $56 = HEAP16[$55>>1]|0;
    $57 = HEAP32[$54>>2]|0;
    $58 = (($57) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (FUNCTION_TABLE_ii[$59 & 4095]($54)|0);
    $61 = ($this|0)==($60|0);
    if (!($61)) {
     label = 7;
     break;
    }
    HEAP32[$18>>2] = 0;
    HEAP32[$23>>2] = 0;
    L11: do {
     switch ($56<<16>>16) {
     case 12: case 11: case 10:  {
      $251 = HEAP32[$53>>2]|0;
      __ZN5physx7NpScene19removeActorInternalERNS_7PxActorEbb($this,$251,$wakeOnLostTouch,1);
      break;
     }
     case 5:  {
      $157 = HEAP32[$53>>2]|0;
      $158 = HEAP32[$157>>2]|0;
      $159 = (($158) + 52|0);
      $160 = HEAP32[$159>>2]|0;
      FUNCTION_TABLE_vii[$160 & 4095]($actorFlags2,$157);
      $161 = (($157) + 20|0);
      $162 = (($161) + 4|0);
      $163 = HEAP16[$162>>1]|0;
      if ((($163<<16>>16) == 1)) {
       $166 = $161;
       label = 24;
      } else if (!((($163<<16>>16) == 0))) {
       $164 = HEAP32[$161>>2]|0;
       $166 = $164;
       label = 24;
      }
      if ((label|0) == 24) {
       label = 0;
       $165 = HEAP32[$166>>2]|0;
       $167 = $165;
       $168 = (_bitshift64Lshr(($167|0),0,6)|0);
       $169 = tempRet0;
       $170 = (_i64Add(($167|0),0,207,0)|0);
       $171 = tempRet0;
       $172 = (_bitshift64Lshr(($170|0),($171|0),6)|0);
       $173 = tempRet0;
       $174 = (_i64Subtract(1,0,($168|0),($169|0))|0);
       $175 = tempRet0;
       $176 = (_i64Add(($174|0),($175|0),($172|0),($173|0))|0);
       $177 = tempRet0;
       $179 = $176;$180 = $177;$cp$0$i4 = $165;
       while(1) {
        $178 = (($cp$0$i4) + 64|0);
        $181 = (_i64Add(($179|0),($180|0),-1,-1)|0);
        $182 = tempRet0;
        $183 = ($181|0)==(0);
        $184 = ($182|0)==(0);
        $185 = $183 & $184;
        if ($185) {
         break;
        } else {
         $179 = $181;$180 = $182;$cp$0$i4 = $178;
        }
       }
      }
      $186 = (($157) + 48|0);
      $187 = (($157) + 64|0);
      __ZNK5physx2Sc5Scene17prefetchForRemoveERKNS0_8BodyCoreE($13,$187);
      $188 = HEAP32[$14>>2]|0;
      $189 = (($188) + -1)|0;
      $190 = HEAP32[$27>>2]|0;
      $191 = (($190) + ($189<<2)|0);
      $192 = HEAP32[$191>>2]|0;
      $193 = $192;
      $194 = (_bitshift64Lshr(($193|0),0,6)|0);
      $195 = tempRet0;
      $196 = (_i64Add(($193|0),0,287,0)|0);
      $197 = tempRet0;
      $198 = (_bitshift64Lshr(($196|0),($197|0),6)|0);
      $199 = tempRet0;
      $200 = (_i64Subtract(1,0,($194|0),($195|0))|0);
      $201 = tempRet0;
      $202 = (_i64Add(($200|0),($201|0),($198|0),($199|0))|0);
      $203 = tempRet0;
      $205 = $202;$206 = $203;$cp$0$i1 = $192;
      while(1) {
       $204 = (($cp$0$i1) + 64|0);
       $207 = (_i64Add(($205|0),($206|0),-1,-1)|0);
       $208 = tempRet0;
       $209 = ($207|0)==(0);
       $210 = ($208|0)==(0);
       $211 = $209 & $210;
       if ($211) {
        break;
       } else {
        $205 = $207;$206 = $208;$cp$0$i1 = $204;
       }
      }
      $212 = HEAP16[$actorFlags2>>1]|0;
      $213 = $212 & 8;
      $214 = ($213<<16>>16)==(0);
      if ($214) {
       $215 = (($157) + 12|0);
       __ZN5physx7NpActor26removeConstraintsFromSceneEv($215);
      }
      __ZN5physx14NpShapeManager21teardownAllSceneQueryERNS_2Sq17SceneQueryManagerE($161,$28);
      $216 = $186;
      $217 = (($157) + 52|0);
      $218 = HEAP32[$217>>2]|0;
      $219 = $218 >>> 24;
      $220 = $219 & 15;
      $221 = ((444424 + ($220<<2)|0) + 24|0);
      $222 = HEAP32[$221>>2]|0;
      $223 = (($222) + ($216))|0;
      $224 = $223;
      $225 = (($224) + 8|0);
      $226 = HEAP16[$225>>1]|0;
      $227 = $226 & 8;
      $228 = ($227<<16>>16)!=(0);
      __ZN5physx3Scb5Scene15removeRigidBodyERNS0_4BodyEbb($0,$186,$wakeOnLostTouch,$228);
      $229 = (($157) + 36|0);
      $230 = HEAP32[$14>>2]|0;
      $231 = (($230) + -1)|0;
      $232 = HEAP32[$229>>2]|0;
      HEAP32[$14>>2] = $231;
      $233 = HEAP32[$29>>2]|0;
      $234 = (($233) + ($231<<2)|0);
      $235 = HEAP32[$234>>2]|0;
      $236 = (($233) + ($232<<2)|0);
      HEAP32[$236>>2] = $235;
      $237 = ($231|0)==(0);
      if (!($237)) {
       $238 = HEAP32[$229>>2]|0;
       $239 = ($231|0)==($238|0);
       if (!($239)) {
        $240 = HEAP32[$29>>2]|0;
        $241 = (($240) + ($238<<2)|0);
        $242 = HEAP32[$241>>2]|0;
        $243 = HEAP32[$242>>2]|0;
        $244 = (($243) + 24|0);
        $245 = HEAP32[$244>>2]|0;
        $246 = (FUNCTION_TABLE_ii[$245 & 4095]($242)|0);
        if ((($246|0) == 0)) {
         $247 = HEAP32[$229>>2]|0;
         $248 = (($242) + 36|0);
         $$c1$i = $247;
         HEAP32[$248>>2] = $$c1$i;
         break L11;
        } else if ((($246|0) == 1)) {
         $249 = HEAP32[$229>>2]|0;
         $250 = (($242) + 36|0);
         $$c$i = $249;
         HEAP32[$250>>2] = $$c$i;
         break L11;
        } else {
         break L11;
        }
       }
      }
      break;
     }
     case 6:  {
      $63 = HEAP32[$53>>2]|0;
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 52|0);
      $66 = HEAP32[$65>>2]|0;
      FUNCTION_TABLE_vii[$66 & 4095]($actorFlags,$63);
      $67 = (($63) + 20|0);
      $68 = (($67) + 4|0);
      $69 = HEAP16[$68>>1]|0;
      if ((($69<<16>>16) == 1)) {
       $72 = $67;
       label = 11;
      } else if (!((($69<<16>>16) == 0))) {
       $70 = HEAP32[$67>>2]|0;
       $72 = $70;
       label = 11;
      }
      if ((label|0) == 11) {
       label = 0;
       $71 = HEAP32[$72>>2]|0;
       $73 = $71;
       $74 = (_bitshift64Lshr(($73|0),0,6)|0);
       $75 = tempRet0;
       $76 = (_i64Add(($73|0),0,207,0)|0);
       $77 = tempRet0;
       $78 = (_bitshift64Lshr(($76|0),($77|0),6)|0);
       $79 = tempRet0;
       $80 = (_i64Subtract(1,0,($74|0),($75|0))|0);
       $81 = tempRet0;
       $82 = (_i64Add(($80|0),($81|0),($78|0),($79|0))|0);
       $83 = tempRet0;
       $85 = $82;$86 = $83;$cp$0$i14 = $71;
       while(1) {
        $84 = (($cp$0$i14) + 64|0);
        $87 = (_i64Add(($85|0),($86|0),-1,-1)|0);
        $88 = tempRet0;
        $89 = ($87|0)==(0);
        $90 = ($88|0)==(0);
        $91 = $89 & $90;
        if ($91) {
         break;
        } else {
         $85 = $87;$86 = $88;$cp$0$i14 = $84;
        }
       }
      }
      $92 = (($63) + 48|0);
      $93 = (($63) + 64|0);
      __ZNK5physx2Sc5Scene17prefetchForRemoveERKNS0_10StaticCoreE($13,$93);
      $94 = HEAP32[$14>>2]|0;
      $95 = (($94) + -1)|0;
      $96 = HEAP32[$27>>2]|0;
      $97 = (($96) + ($95<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = $98;
      $100 = (_bitshift64Lshr(($99|0),0,6)|0);
      $101 = tempRet0;
      $102 = (_i64Add(($99|0),0,287,0)|0);
      $103 = tempRet0;
      $104 = (_bitshift64Lshr(($102|0),($103|0),6)|0);
      $105 = tempRet0;
      $106 = (_i64Subtract(1,0,($100|0),($101|0))|0);
      $107 = tempRet0;
      $108 = (_i64Add(($106|0),($107|0),($104|0),($105|0))|0);
      $109 = tempRet0;
      $111 = $108;$112 = $109;$cp$0$i11 = $98;
      while(1) {
       $110 = (($cp$0$i11) + 64|0);
       $113 = (_i64Add(($111|0),($112|0),-1,-1)|0);
       $114 = tempRet0;
       $115 = ($113|0)==(0);
       $116 = ($114|0)==(0);
       $117 = $115 & $116;
       if ($117) {
        break;
       } else {
        $111 = $113;$112 = $114;$cp$0$i11 = $110;
       }
      }
      $118 = HEAP16[$actorFlags>>1]|0;
      $119 = $118 & 8;
      $120 = ($119<<16>>16)==(0);
      if ($120) {
       $121 = (($63) + 12|0);
       __ZN5physx7NpActor26removeConstraintsFromSceneEv($121);
      }
      __ZN5physx14NpShapeManager21teardownAllSceneQueryERNS_2Sq17SceneQueryManagerE($67,$28);
      $122 = $92;
      $123 = (($63) + 52|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = $124 >>> 24;
      $126 = $125 & 15;
      $127 = ((444424 + ($126<<2)|0) + 24|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = (($128) + ($122))|0;
      $130 = $129;
      $131 = (($130) + 8|0);
      $132 = HEAP16[$131>>1]|0;
      $133 = $132 & 8;
      $134 = ($133<<16>>16)!=(0);
      __ZN5physx3Scb5Scene17removeRigidStaticERNS0_11RigidStaticEbb($0,$92,$wakeOnLostTouch,$134);
      $135 = (($63) + 36|0);
      $136 = HEAP32[$14>>2]|0;
      $137 = (($136) + -1)|0;
      $138 = HEAP32[$135>>2]|0;
      HEAP32[$14>>2] = $137;
      $139 = HEAP32[$29>>2]|0;
      $140 = (($139) + ($137<<2)|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = (($139) + ($138<<2)|0);
      HEAP32[$142>>2] = $141;
      $143 = ($137|0)==(0);
      if (!($143)) {
       $144 = HEAP32[$135>>2]|0;
       $145 = ($137|0)==($144|0);
       if (!($145)) {
        $146 = HEAP32[$29>>2]|0;
        $147 = (($146) + ($144<<2)|0);
        $148 = HEAP32[$147>>2]|0;
        $149 = HEAP32[$148>>2]|0;
        $150 = (($149) + 24|0);
        $151 = HEAP32[$150>>2]|0;
        $152 = (FUNCTION_TABLE_ii[$151 & 4095]($148)|0);
        if ((($152|0) == 1)) {
         $155 = HEAP32[$135>>2]|0;
         $156 = (($148) + 36|0);
         $$c$i8 = $155;
         HEAP32[$156>>2] = $$c$i8;
         break L11;
        } else if ((($152|0) == 0)) {
         $153 = HEAP32[$135>>2]|0;
         $154 = (($148) + 36|0);
         $$c1$i7 = $153;
         HEAP32[$154>>2] = $$c1$i7;
         break L11;
        } else {
         break L11;
        }
       }
      }
      break;
     }
     default: {
      label = 37;
      break L3;
     }
     }
    } while(0);
    if ($31) {
     $actorsDone$021 = $30;
    } else {
     break L1;
    }
   }
   if ((label|0) == 7) {
    $62 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    HEAP32[$vararg_buffer1>>2] = 431232;
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($62,8,430616,92,436368,$vararg_buffer1);
    break;
   }
   else if ((label|0) == 37) {
    $252 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($252,2,430616,634,431264,$vararg_buffer1);
    break;
   }
  }
 } while(0);
 HEAP32[$25>>2] = 0;
 $253 = HEAP32[$24>>2]|0;
 $254 = $253 & 2147483647;
 $255 = ($254|0)!=(0);
 $256 = ($253|0)>(-1);
 $or$cond$i$i$i$i$i = $255 & $256;
 do {
  if ($or$cond$i$i$i$i$i) {
   $257 = HEAP32[$22>>2]|0;
   $258 = (($removeState) + 272|0);
   $259 = ($258|0)==($257|0);
   if ($259) {
    HEAP8[$21>>0] = 0;
    break;
   }
   $260 = ($257|0)==(0|0);
   if (!($260)) {
    $261 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $262 = HEAP32[$261>>2]|0;
    $263 = (($262) + 12|0);
    $264 = HEAP32[$263>>2]|0;
    FUNCTION_TABLE_vii[$264 & 4095]($261,$257);
   }
  }
 } while(0);
 $265 = HEAP32[$19>>2]|0;
 $266 = $265 & 2147483647;
 $267 = ($266|0)!=(0);
 $268 = ($265|0)>(-1);
 $or$cond$i$i$i1$i$i = $267 & $268;
 if (!($or$cond$i$i$i1$i$i)) {
  $276 = HEAP32[$2>>2]|0;
  $277 = (($276) + 12|0);
  $278 = HEAP32[$277>>2]|0;
  FUNCTION_TABLE_viiii[$278 & 511]($2,49,$6,$9);
  STACKTOP = sp;return;
 }
 $269 = HEAP32[$17>>2]|0;
 $270 = ($removeState|0)==($269|0);
 if ($270) {
  HEAP8[$16>>0] = 0;
  $276 = HEAP32[$2>>2]|0;
  $277 = (($276) + 12|0);
  $278 = HEAP32[$277>>2]|0;
  FUNCTION_TABLE_viiii[$278 & 511]($2,49,$6,$9);
  STACKTOP = sp;return;
 }
 $271 = ($269|0)==(0|0);
 if ($271) {
  $276 = HEAP32[$2>>2]|0;
  $277 = (($276) + 12|0);
  $278 = HEAP32[$277>>2]|0;
  FUNCTION_TABLE_viiii[$278 & 511]($2,49,$6,$9);
  STACKTOP = sp;return;
 }
 $272 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = (($273) + 12|0);
 $275 = HEAP32[$274>>2]|0;
 FUNCTION_TABLE_vii[$275 & 4095]($272,$269);
 $276 = HEAP32[$2>>2]|0;
 $277 = (($276) + 12|0);
 $278 = HEAP32[$277>>2]|0;
 FUNCTION_TABLE_viiii[$278 & 511]($2,49,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene24removeFromRigidActorListERKj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$c = 0, $$c1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3540|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$index>>2]|0;
 HEAP32[$0>>2] = $2;
 $4 = (($this) + 3536|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($3<<2)|0);
 HEAP32[$8>>2] = $7;
 $9 = ($2|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$index>>2]|0;
 $11 = ($2|0)==($10|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$4>>2]|0;
 $13 = (($12) + ($10<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($14)|0);
 if ((($18|0) == 0)) {
  $19 = HEAP32[$index>>2]|0;
  $20 = (($14) + 36|0);
  $$c1 = $19;
  HEAP32[$20>>2] = $$c1;
  STACKTOP = sp;return;
 } else if ((($18|0) == 1)) {
  $21 = HEAP32[$index>>2]|0;
  $22 = (($14) + 36|0);
  $$c = $21;
  HEAP32[$22>>2] = $$c;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene11removeActorERNS_7PxActorEb($this,$actor,$wakeOnLostTouch) {
 $this = $this|0;
 $actor = $actor|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 1216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1208|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 511]($1,49,$5,$8);
 $12 = HEAP32[$actor>>2]|0;
 $13 = (($12) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($actor)|0);
 $16 = ($this|0)==($15|0);
 if ($16) {
  __ZN5physx7NpScene19removeActorInternalERNS_7PxActorEbb($this,$actor,$wakeOnLostTouch,1);
  $18 = HEAP32[$1>>2]|0;
  $19 = (($18) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiii[$20 & 511]($1,49,$5,$8);
  STACKTOP = sp;return;
 } else {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  HEAP32[$vararg_buffer>>2] = 431352;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,430616,92,436368,$vararg_buffer);
  $18 = HEAP32[$1>>2]|0;
  $19 = (($18) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiii[$20 & 511]($1,49,$5,$8);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene17removeRigidStaticERNS_13NpRigidStaticEbb($this,$actor,$wakeOnLostTouch,$removeFromAggregate) {
 $this = $this|0;
 $actor = $actor|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 $removeFromAggregate = $removeFromAggregate|0;
 var $$c$i = 0, $$c1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$actor>>2]|0;
 $2 = (($1) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$actor);
 $4 = HEAP16[$0>>1]|0;
 $5 = $4 & 8;
 $6 = ($5<<16>>16)==(0);
 if ($removeFromAggregate) {
  $7 = HEAP32[$actor>>2]|0;
  $8 = (($7) + 80|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 4095]($actor)|0);
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$actor>>2]|0;
   $13 = (($12) + 80|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (FUNCTION_TABLE_ii[$14 & 4095]($actor)|0);
   (__ZN5physx11NpAggregate22removeActorAndReinsertERNS_7PxActorEb($15,$actor,0)|0);
  }
 }
 $16 = (($actor) + 20|0);
 $17 = (($this) + 3376|0);
 __ZN5physx14NpShapeManager21teardownAllSceneQueryERNS_2Sq17SceneQueryManagerE($16,$17);
 if ($6) {
  $18 = (($actor) + 12|0);
  __ZN5physx7NpActor26removeConstraintsFromSceneEv($18);
 }
 $19 = (($this) + 16|0);
 $20 = (($actor) + 48|0);
 $21 = $20;
 $22 = (($actor) + 52|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 >>> 24;
 $25 = $24 & 15;
 $26 = ((444424 + ($25<<2)|0) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + ($21))|0;
 $29 = $28;
 $30 = (($29) + 8|0);
 $31 = HEAP16[$30>>1]|0;
 $32 = $31 & 8;
 $33 = ($32<<16>>16)!=(0);
 __ZN5physx3Scb5Scene17removeRigidStaticERNS0_11RigidStaticEbb($19,$20,$wakeOnLostTouch,$33);
 $34 = (($actor) + 36|0);
 $35 = (($this) + 3540|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + -1)|0;
 $38 = HEAP32[$34>>2]|0;
 HEAP32[$35>>2] = $37;
 $39 = (($this) + 3536|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($37<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + ($38<<2)|0);
 HEAP32[$43>>2] = $42;
 $44 = ($37|0)==(0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$34>>2]|0;
 $46 = ($37|0)==($45|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = HEAP32[$39>>2]|0;
 $48 = (($47) + ($45<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 24|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (FUNCTION_TABLE_ii[$52 & 4095]($49)|0);
 if ((($53|0) == 0)) {
  $54 = HEAP32[$34>>2]|0;
  $55 = (($49) + 36|0);
  $$c1$i = $54;
  HEAP32[$55>>2] = $$c1$i;
  STACKTOP = sp;return;
 } else if ((($53|0) == 1)) {
  $56 = HEAP32[$34>>2]|0;
  $57 = (($49) + 36|0);
  $$c$i = $56;
  HEAP32[$57>>2] = $$c$i;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene18removeRigidDynamicERNS_14NpRigidDynamicEbb($this,$body,$wakeOnLostTouch,$removeFromAggregate) {
 $this = $this|0;
 $body = $body|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 $removeFromAggregate = $removeFromAggregate|0;
 var $$c$i = 0, $$c1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$body>>2]|0;
 $2 = (($1) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$body);
 $4 = HEAP16[$0>>1]|0;
 $5 = $4 & 8;
 $6 = ($5<<16>>16)==(0);
 if ($removeFromAggregate) {
  $7 = HEAP32[$body>>2]|0;
  $8 = (($7) + 80|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 4095]($body)|0);
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$body>>2]|0;
   $13 = (($12) + 80|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (FUNCTION_TABLE_ii[$14 & 4095]($body)|0);
   (__ZN5physx11NpAggregate22removeActorAndReinsertERNS_7PxActorEb($15,$body,0)|0);
  }
 }
 $16 = (($body) + 20|0);
 $17 = (($this) + 3376|0);
 __ZN5physx14NpShapeManager21teardownAllSceneQueryERNS_2Sq17SceneQueryManagerE($16,$17);
 if ($6) {
  $18 = (($body) + 12|0);
  __ZN5physx7NpActor26removeConstraintsFromSceneEv($18);
 }
 $19 = (($this) + 16|0);
 $20 = (($body) + 48|0);
 $21 = $20;
 $22 = (($body) + 52|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 >>> 24;
 $25 = $24 & 15;
 $26 = ((444424 + ($25<<2)|0) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + ($21))|0;
 $29 = $28;
 $30 = (($29) + 8|0);
 $31 = HEAP16[$30>>1]|0;
 $32 = $31 & 8;
 $33 = ($32<<16>>16)!=(0);
 __ZN5physx3Scb5Scene15removeRigidBodyERNS0_4BodyEbb($19,$20,$wakeOnLostTouch,$33);
 $34 = (($body) + 36|0);
 $35 = (($this) + 3540|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + -1)|0;
 $38 = HEAP32[$34>>2]|0;
 HEAP32[$35>>2] = $37;
 $39 = (($this) + 3536|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($37<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + ($38<<2)|0);
 HEAP32[$43>>2] = $42;
 $44 = ($37|0)==(0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$34>>2]|0;
 $46 = ($37|0)==($45|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = HEAP32[$39>>2]|0;
 $48 = (($47) + ($45<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 24|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (FUNCTION_TABLE_ii[$52 & 4095]($49)|0);
 if ((($53|0) == 1)) {
  $56 = HEAP32[$34>>2]|0;
  $57 = (($49) + 36|0);
  $$c$i = $56;
  HEAP32[$57>>2] = $$c$i;
  STACKTOP = sp;return;
 } else if ((($53|0) == 0)) {
  $54 = HEAP32[$34>>2]|0;
  $55 = (($49) + 36|0);
  $$c1$i = $54;
  HEAP32[$55>>2] = $$c1$i;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene11removeClothERNS_7NpClothE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($cloth) + 20|0);
 __ZN5physx3Scb5Scene11removeClothERNS0_5ClothE($0,$1);
 $2 = (($this) + 3640|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 3636|0);
 $6 = HEAP32[$5>>2]|0;
 $index$01$i$i = 0;
 while(1) {
  $9 = (($6) + ($index$01$i$i<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($cloth|0);
  $8 = (($index$01$i$i) + 1)|0;
  if ($11) {
   $index$0$lcssa$i$i = $index$01$i$i;
   break;
  }
  $7 = ($8>>>0)<($3>>>0);
  if ($7) {
   $index$01$i$i = $8;
  } else {
   $index$0$lcssa$i$i = $8;
   break;
  }
 }
 $12 = ($index$0$lcssa$i$i|0)==($3|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($3) + -1)|0;
 HEAP32[$2>>2] = $13;
 $14 = (($6) + ($13<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($6) + ($index$0$lcssa$i$i<<2)|0);
 HEAP32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene15addArticulationERNS_14PxArticulationE($this,$articulation) {
 $this = $this|0;
 $articulation = $articulation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($articulation) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 0)) {
  label = 3;
 } else if ((($2|0) == 3)) {
  $3 = (($articulation) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN5physx3Scb5Scene10getPxSceneEv($4)|0);
  $6 = ($5|0)==($this|0);
  if ($6) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 3) {
  __ZN5physx7NpScene23addArticulationInternalERNS_14PxArticulationE($this,$articulation);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $7 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,8,430616,850,431384,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene23addArticulationInternalERNS_14PxArticulationE($this,$articulation) {
 $this = $this|0;
 $articulation = $articulation|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0);
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0);
 var $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $curLink$012 = 0, $exitcond = 0;
 var $i$08 = 0, $inertia = 0, $inertia0 = 0, $linkStack = 0, $linkTriggersWakeUp$0$off0$lcssa = 0, $linkTriggersWakeUp$0$off0$not = 0, $linkTriggersWakeUp$0$off013 = 0, $linkTriggersWakeUp$1$off0$lcssa = 0, $linkTriggersWakeUp$1$off09 = 0, $phitmp = 0, $phitmp6 = 0, $stackSize$011 = 0, $stackSize$1$lcssa = 0, $stackSize$17 = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer5 = sp;
 $inertia0 = sp + 52|0;
 $0 = sp + 4|0;
 $linkStack = sp + 16|0;
 $1 = sp + 64|0;
 $inertia = sp + 28|0;
 $2 = sp + 40|0;
 $3 = sp + 24|0;
 $4 = HEAP32[$articulation>>2]|0;
 $5 = (($4) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($articulation)|0);
 $8 = (($articulation) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 132|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (Math_fround(FUNCTION_TABLE_fi[$13 & 255]($10)));
 $15 = $14 == Math_fround(0.0);
 if ($15) {
  $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,2,430616,864,431480,$vararg_buffer5);
  $17 = HEAP32[$10>>2]|0;
  $18 = (($17) + 128|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vif[$19 & 255]($10,Math_fround(1.0));
 }
 $20 = HEAP32[$10>>2]|0;
 $21 = (($20) + 144|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vii[$22 & 4095]($inertia0,$10);
 $23 = Math_fround(HEAPF32[$inertia0>>2]);
 $24 = $23 == Math_fround(0.0);
 if ($24) {
  label = 6;
 } else {
  $25 = (($inertia0) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = $26 == Math_fround(0.0);
  if ($27) {
   label = 6;
  } else {
   $28 = (($inertia0) + 8|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = $29 == Math_fround(0.0);
   if ($30) {
    label = 6;
   }
  }
 }
 if ((label|0) == 6) {
  $31 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($31,2,430616,871,431584,$vararg_buffer5);
  $32 = HEAP32[$10>>2]|0;
  $33 = (($32) + 140|0);
  $34 = HEAP32[$33>>2]|0;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $35 = (($0) + 4|0);
  HEAPF32[$35>>2] = Math_fround(1.0);
  $36 = (($0) + 8|0);
  HEAPF32[$36>>2] = Math_fround(1.0);
  FUNCTION_TABLE_vii[$34 & 4095]($10,$0);
 }
 $37 = (($10) + 252|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = $38 == Math_fround(0.0);
 if ($39) {
  $40 = (($10) + 256|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = $41 == Math_fround(0.0);
  if ($42) {
   $43 = (($10) + 260|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = $44 == Math_fround(0.0);
   if ($45) {
    $46 = (($10) + 264|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = $47 == Math_fround(0.0);
    if ($48) {
     $49 = (($10) + 268|0);
     $50 = Math_fround(HEAPF32[$49>>2]);
     $51 = $50 == Math_fround(0.0);
     if ($51) {
      $52 = (($10) + 272|0);
      $53 = Math_fround(HEAPF32[$52>>2]);
      $phitmp = $53 != Math_fround(0.0);
      $174 = $phitmp;
     } else {
      $174 = 1;
     }
    } else {
     $174 = 1;
    }
   } else {
    $174 = 1;
   }
  } else {
   $174 = 1;
  }
 } else {
  $174 = 1;
 }
 $54 = (($this) + 16|0);
 $55 = (($10) + 48|0);
 __ZN5physx3Scb5Scene12addRigidBodyERNS0_4BodyEb($54,$55,0);
 $56 = (($10) + 20|0);
 __ZN5physx14NpShapeManager18setupAllSceneQueryERKNS_12PxRigidActorE($56,$10);
 $57 = (($articulation) + 12|0);
 __ZN5physx3Scb5Scene15addArticulationERNS0_12ArticulationE($54,$57);
 $58 = HEAP32[$10>>2]|0;
 $59 = (($58) + 228|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (FUNCTION_TABLE_ii[$60 & 4095]($10)|0);
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  $63 = (($61) + 8|0);
  __ZN5physx3Scb5Scene20addArticulationJointERNS0_17ArticulationJointE($54,$63);
 }
 $64 = (($10) + 16|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if (!($66)) {
  $67 = (($10) + 12|0);
  __ZN5physx7NpActor29addConstraintsToSceneInternalEv($67);
 }
 $68 = $7 << 2;
 $69 = ($68>>>0)>(1024);
 $70 = (($linkStack) + 4|0);
 $71 = $69&1;
 HEAP8[$70>>0] = $71;
 if ($69) {
  $72 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,$68,430616,887)|0);
  HEAP32[$linkStack>>2] = $72;
  $74 = $72;
 } else {
  $73 = STACKTOP; STACKTOP = STACKTOP + ((((1*$68)|0)+15)&-16)|0;;
  HEAP32[$linkStack>>2] = $73;
  $74 = $73;
 }
 HEAP32[$74>>2] = $10;
 $75 = (($7) + -1)|0;
 $76 = ($75|0)==(0);
 if ($76) {
  $linkTriggersWakeUp$0$off0$lcssa = $174;
 } else {
  $77 = (($2) + 4|0);
  $78 = (($2) + 8|0);
  $79 = (($inertia) + 4|0);
  $80 = (($inertia) + 8|0);
  $curLink$012 = 0;$linkTriggersWakeUp$0$off013 = $174;$stackSize$011 = 1;
  while(1) {
   $81 = HEAP32[$linkStack>>2]|0;
   $82 = (($81) + ($curLink$012<<2)|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($83) + 324|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($85|0)==(0);
   if ($86) {
    $95 = 0;
   } else {
    $87 = (($83) + 320|0);
    $88 = HEAP32[$87>>2]|0;
    $95 = $88;
   }
   $89 = HEAP32[$83>>2]|0;
   $90 = (($89) + 232|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (FUNCTION_TABLE_ii[$91 & 4095]($83)|0);
   $93 = ($92|0)==(0);
   if ($93) {
    $linkTriggersWakeUp$1$off0$lcssa = $linkTriggersWakeUp$0$off013;$stackSize$1$lcssa = $stackSize$011;
   } else {
    $i$08 = 0;$linkTriggersWakeUp$1$off09 = $linkTriggersWakeUp$0$off013;$stackSize$17 = $stackSize$011;
    while(1) {
     $94 = (($95) + ($i$08<<2)|0);
     $96 = HEAP32[$94>>2]|0;
     $97 = HEAP32[$96>>2]|0;
     $98 = (($97) + 132|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = (Math_fround(FUNCTION_TABLE_fi[$99 & 255]($96)));
     $101 = $100 == Math_fround(0.0);
     if ($101) {
      $102 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
      __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($102,2,430616,903,431480,$vararg_buffer5);
      $103 = HEAP32[$96>>2]|0;
      $104 = (($103) + 128|0);
      $105 = HEAP32[$104>>2]|0;
      FUNCTION_TABLE_vif[$105 & 255]($96,Math_fround(1.0));
     }
     $106 = HEAP32[$96>>2]|0;
     $107 = (($106) + 144|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vii[$108 & 4095]($inertia,$96);
     $109 = Math_fround(HEAPF32[$inertia>>2]);
     $110 = $109 == Math_fround(0.0);
     if ($110) {
      label = 30;
     } else {
      $111 = Math_fround(HEAPF32[$79>>2]);
      $112 = $111 == Math_fround(0.0);
      if ($112) {
       label = 30;
      } else {
       $113 = Math_fround(HEAPF32[$80>>2]);
       $114 = $113 == Math_fround(0.0);
       if ($114) {
        label = 30;
       }
      }
     }
     if ((label|0) == 30) {
      label = 0;
      $115 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
      __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($115,2,430616,910,431584,$vararg_buffer5);
      $116 = HEAP32[$96>>2]|0;
      $117 = (($116) + 140|0);
      $118 = HEAP32[$117>>2]|0;
      HEAPF32[$2>>2] = Math_fround(1.0);
      HEAPF32[$77>>2] = Math_fround(1.0);
      HEAPF32[$78>>2] = Math_fround(1.0);
      FUNCTION_TABLE_vii[$118 & 4095]($96,$2);
     }
     do {
      if ($linkTriggersWakeUp$1$off09) {
       $175 = 1;
      } else {
       $119 = (($96) + 252|0);
       $120 = Math_fround(HEAPF32[$119>>2]);
       $121 = $120 == Math_fround(0.0);
       if ($121) {
        $122 = (($96) + 256|0);
        $123 = Math_fround(HEAPF32[$122>>2]);
        $124 = $123 == Math_fround(0.0);
        if ($124) {
         $125 = (($96) + 260|0);
         $126 = Math_fround(HEAPF32[$125>>2]);
         $127 = $126 == Math_fround(0.0);
         if ($127) {
          $128 = (($96) + 264|0);
          $129 = Math_fround(HEAPF32[$128>>2]);
          $130 = $129 == Math_fround(0.0);
          if (!($130)) {
           $175 = 1;
           break;
          }
          $131 = (($96) + 268|0);
          $132 = Math_fround(HEAPF32[$131>>2]);
          $133 = $132 == Math_fround(0.0);
          if (!($133)) {
           $175 = 1;
           break;
          }
          $134 = (($96) + 272|0);
          $135 = Math_fround(HEAPF32[$134>>2]);
          $phitmp6 = $135 != Math_fround(0.0);
          $175 = $phitmp6;
         } else {
          $175 = 1;
         }
        } else {
         $175 = 1;
        }
       } else {
        $175 = 1;
       }
      }
     } while(0);
     $136 = (($96) + 48|0);
     __ZN5physx3Scb5Scene12addRigidBodyERNS0_4BodyEb($54,$136,0);
     $137 = (($96) + 20|0);
     __ZN5physx14NpShapeManager18setupAllSceneQueryERKNS_12PxRigidActorE($137,$96);
     $138 = HEAP32[$96>>2]|0;
     $139 = (($138) + 228|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = (FUNCTION_TABLE_ii[$140 & 4095]($96)|0);
     $142 = ($141|0)==(0|0);
     if (!($142)) {
      $143 = (($141) + 8|0);
      __ZN5physx3Scb5Scene20addArticulationJointERNS0_17ArticulationJointE($54,$143);
     }
     $144 = (($96) + 16|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = ($145|0)==(0|0);
     if (!($146)) {
      $147 = (($96) + 12|0);
      __ZN5physx7NpActor29addConstraintsToSceneInternalEv($147);
     }
     $148 = HEAP32[$linkStack>>2]|0;
     $149 = (($148) + ($stackSize$17<<2)|0);
     HEAP32[$149>>2] = $96;
     $150 = (($stackSize$17) + 1)|0;
     $151 = (($i$08) + 1)|0;
     $152 = HEAP32[$83>>2]|0;
     $153 = (($152) + 232|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (FUNCTION_TABLE_ii[$154 & 4095]($83)|0);
     $156 = ($151>>>0)<($155>>>0);
     if ($156) {
      $i$08 = $151;$linkTriggersWakeUp$1$off09 = $175;$stackSize$17 = $150;
     } else {
      $linkTriggersWakeUp$1$off0$lcssa = $175;$stackSize$1$lcssa = $150;
      break;
     }
    }
   }
   $157 = (($curLink$012) + 1)|0;
   $exitcond = ($157|0)==($75|0);
   if ($exitcond) {
    $linkTriggersWakeUp$0$off0$lcssa = $linkTriggersWakeUp$1$off0$lcssa;
    break;
   } else {
    $curLink$012 = $157;$linkTriggersWakeUp$0$off013 = $linkTriggersWakeUp$1$off0$lcssa;$stackSize$011 = $stackSize$1$lcssa;
   }
  }
 }
 $158 = (($articulation) + 60|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $$not = $159 != Math_fround(0.0);
 $linkTriggersWakeUp$0$off0$not = $linkTriggersWakeUp$0$off0$lcssa ^ 1;
 $brmerge = $$not | $linkTriggersWakeUp$0$off0$not;
 if (!($brmerge)) {
  __ZN5physx14NpArticulation14wakeUpInternalEbb($articulation,1,0);
 }
 $160 = (($this) + 3548|0);
 HEAP32[$3>>2] = $articulation;
 $161 = (($this) + 3556|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = $162 & 2147483647;
 $164 = (($this) + 3552|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = ($163>>>0)>($165>>>0);
 if ($166) {
  $167 = HEAP32[$160>>2]|0;
  $168 = (($167) + ($165<<2)|0);
  $169 = ($168|0)==(0|0);
  if (!($169)) {
   HEAP32[$168>>2] = $articulation;
  }
  $170 = (($165) + 1)|0;
  HEAP32[$164>>2] = $170;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_14PxArticulationENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($160,$3)|0);
 }
 $171 = HEAP8[$70>>0]|0;
 $172 = ($171<<24>>24)==(0);
 if ($172) {
  STACKTOP = sp;return;
 }
 $173 = HEAP32[$linkStack>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($linkStack,$173);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene19addArticulationLinkERNS_18NpArticulationLinkE($this,$link) {
 $this = $this|0;
 $link = $link|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($link) + 48|0);
 __ZN5physx3Scb5Scene12addRigidBodyERNS0_4BodyEb($0,$1,0);
 $2 = (($link) + 20|0);
 __ZN5physx14NpShapeManager18setupAllSceneQueryERKNS_12PxRigidActorE($2,$link);
 $3 = HEAP32[$link>>2]|0;
 $4 = (($3) + 228|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($link)|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($6) + 8|0);
  __ZN5physx3Scb5Scene20addArticulationJointERNS0_17ArticulationJointE($0,$8);
 }
 $9 = (($link) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($link) + 12|0);
 __ZN5physx7NpActor29addConstraintsToSceneInternalEv($12);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene18removeArticulationERNS_14PxArticulationEb($this,$articulation,$wakeOnLostTouch) {
 $this = $this|0;
 $articulation = $articulation|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$articulation>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($articulation)|0);
 $4 = ($this|0)==($3|0);
 if ($4) {
  __ZN5physx7NpScene26removeArticulationInternalERNS_14PxArticulationEbb($this,$articulation,$wakeOnLostTouch,1);
  STACKTOP = sp;return;
 } else {
  $5 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  HEAP32[$vararg_buffer>>2] = 431704;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($5,8,430616,92,436368,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene26removeArticulationInternalERNS_14PxArticulationEbb($this,$articulation,$wakeOnLostTouch,$removeFromAggregate) {
 $this = $this|0;
 $articulation = $articulation|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 $removeFromAggregate = $removeFromAggregate|0;
 var $$in = 0, $$pre = 0, $$pre$i = 0, $$pre$phi10Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $curLink$06 = 0, $exitcond = 0, $i$02 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, $linkStack = 0, $stackSize$05 = 0, $stackSize$1$lcssa = 0, $stackSize$11 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $linkStack = sp;
 $0 = sp + 8|0;
 $1 = HEAP32[$articulation>>2]|0;
 $2 = (($1) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($articulation)|0);
 if ($removeFromAggregate) {
  $5 = HEAP32[$articulation>>2]|0;
  $6 = (($5) + 128|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 4095]($articulation)|0);
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = HEAP32[$articulation>>2]|0;
   $11 = (($10) + 128|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (FUNCTION_TABLE_ii[$12 & 4095]($articulation)|0);
   (__ZN5physx11NpAggregate29removeArticulationAndReinsertERNS_14PxArticulationEb($13,$articulation,0)|0);
  }
 }
 $14 = $4 << 2;
 $15 = ($14>>>0)>(1024);
 $16 = (($linkStack) + 4|0);
 $17 = $15&1;
 HEAP8[$16>>0] = $17;
 if ($15) {
  $18 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$14,430616,963)|0);
  HEAP32[$linkStack>>2] = $18;
  $23 = $18;
 } else {
  $19 = STACKTOP; STACKTOP = STACKTOP + ((((1*$14)|0)+15)&-16)|0;;
  HEAP32[$linkStack>>2] = $19;
  $23 = $19;
 }
 $20 = (($articulation) + 88|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$23>>2] = $22;
 $24 = (($4) + -1)|0;
 $25 = ($24|0)==(0);
 if (!($25)) {
  $curLink$06 = 0;$stackSize$05 = 1;
  while(1) {
   $28 = HEAP32[$linkStack>>2]|0;
   $29 = (($28) + ($curLink$06<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 324|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0);
   if ($33) {
    $42 = 0;
   } else {
    $34 = (($30) + 320|0);
    $35 = HEAP32[$34>>2]|0;
    $42 = $35;
   }
   $36 = HEAP32[$30>>2]|0;
   $37 = (($36) + 232|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (FUNCTION_TABLE_ii[$38 & 4095]($30)|0);
   $40 = ($39|0)==(0);
   if ($40) {
    $stackSize$1$lcssa = $stackSize$05;
   } else {
    $i$02 = 0;$stackSize$11 = $stackSize$05;
    while(1) {
     $41 = (($42) + ($i$02<<2)|0);
     $43 = HEAP32[$41>>2]|0;
     $44 = HEAP32[$linkStack>>2]|0;
     $45 = (($44) + ($stackSize$11<<2)|0);
     HEAP32[$45>>2] = $43;
     $46 = (($stackSize$11) + 1)|0;
     $47 = (($i$02) + 1)|0;
     $48 = HEAP32[$30>>2]|0;
     $49 = (($48) + 232|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (FUNCTION_TABLE_ii[$50 & 4095]($30)|0);
     $52 = ($47>>>0)<($51>>>0);
     if ($52) {
      $i$02 = $47;$stackSize$11 = $46;
     } else {
      $stackSize$1$lcssa = $46;
      break;
     }
    }
   }
   $53 = (($curLink$06) + 1)|0;
   $exitcond = ($53|0)==($24|0);
   if ($exitcond) {
    break;
   } else {
    $curLink$06 = $53;$stackSize$05 = $stackSize$1$lcssa;
   }
  }
 }
 $26 = ($4|0)>(0);
 if ($26) {
  $27 = (($this) + 3376|0);
  $$pre$i = (($this) + 16|0);
  $$in = $4;
  while(1) {
   $54 = (($$in) + -1)|0;
   $55 = HEAP32[$linkStack>>2]|0;
   $56 = (($55) + ($54<<2)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = HEAP32[$57>>2]|0;
   $59 = (($58) + 228|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (FUNCTION_TABLE_ii[$60 & 4095]($57)|0);
   $62 = (($57) + 12|0);
   __ZN5physx7NpActor26removeConstraintsFromSceneEv($62);
   $63 = (($57) + 20|0);
   __ZN5physx14NpShapeManager21teardownAllSceneQueryERNS_2Sq17SceneQueryManagerE($63,$27);
   $64 = ($61|0)==(0|0);
   if (!($64)) {
    $65 = (($61) + 8|0);
    __ZN5physx3Scb5Scene23removeArticulationJointERNS0_17ArticulationJointE($$pre$i,$65);
   }
   $66 = (($57) + 48|0);
   __ZN5physx3Scb5Scene15removeRigidBodyERNS0_4BodyEbb($$pre$i,$66,$wakeOnLostTouch,0);
   $67 = ($54|0)>(0);
   if ($67) {
    $$in = $54;
   } else {
    $$pre$phi10Z2D = $$pre$i;
    break;
   }
  }
 } else {
  $$pre = (($this) + 16|0);
  $$pre$phi10Z2D = $$pre;
 }
 $68 = (($articulation) + 12|0);
 __ZN5physx3Scb5Scene18removeArticulationERNS0_12ArticulationE($$pre$phi10Z2D,$68);
 $69 = (($this) + 3552|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(0);
 if (!($71)) {
  $72 = (($this) + 3548|0);
  $73 = HEAP32[$72>>2]|0;
  $index$01$i$i = 0;
  while(1) {
   $76 = (($73) + ($index$01$i$i<<2)|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==($articulation|0);
   $75 = (($index$01$i$i) + 1)|0;
   if ($78) {
    $index$0$lcssa$i$i = $index$01$i$i;
    break;
   }
   $74 = ($75>>>0)<($70>>>0);
   if ($74) {
    $index$01$i$i = $75;
   } else {
    $index$0$lcssa$i$i = $75;
    break;
   }
  }
  $79 = ($index$0$lcssa$i$i|0)==($70|0);
  if (!($79)) {
   $80 = (($70) + -1)|0;
   HEAP32[$69>>2] = $80;
   $81 = (($73) + ($80<<2)|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($73) + ($index$0$lcssa$i$i<<2)|0);
   HEAP32[$83>>2] = $82;
  }
 }
 $84 = HEAP8[$16>>0]|0;
 $85 = ($84<<24>>24)==(0);
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = HEAP32[$linkStack>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($linkStack,$86);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene12addAggregateERNS_11PxAggregateE($this,$aggregate) {
 $this = $this|0;
 $aggregate = $aggregate|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 16|0);
 $2 = (($this) + 1216|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 1208|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiii[$13 & 511]($3,50,$7,$10);
 $14 = (($aggregate) + 8|0);
 $15 = (($aggregate) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 >>> 30;
 if ((($17|0) == 3)) {
  $18 = HEAP32[$14>>2]|0;
  $19 = (__ZN5physx3Scb5Scene10getPxSceneEv($18)|0);
  $20 = ($19|0)==($this|0);
  if (!($20)) {
   label = 11;
  }
 } else if (!((($17|0) == 0))) {
  label = 11;
 }
 if ((label|0) == 11) {
  $40 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($40,8,430616,1058,431752,$vararg_buffer);
  $41 = HEAP32[$3>>2]|0;
  $42 = (($41) + 12|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_viiii[$43 & 511]($3,50,$7,$10);
  STACKTOP = sp;return;
 }
 __ZN5physx3Scb5Scene12addAggregateERNS0_9AggregateE($1,$14);
 $21 = (($aggregate) + 36|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if (!($23)) {
  $24 = (($aggregate) + 40|0);
  $i$01 = 0;
  while(1) {
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + ($i$01<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx11NpAggregate16addActorInternalERNS_7PxActorERNS_7NpSceneE($aggregate,$27,$this);
   $28 = (($i$01) + 1)|0;
   $exitcond = ($28|0)==($22|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $28;
   }
  }
 }
 $29 = (($this) + 3560|0);
 HEAP32[$0>>2] = $aggregate;
 $30 = (($this) + 3568|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($this) + 3564|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32>>>0)>($34>>>0);
 if (!($35)) {
  (__ZN5physx6shdfnd5ArrayIPNS_11PxAggregateENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($29,$0)|0);
  $41 = HEAP32[$3>>2]|0;
  $42 = (($41) + 12|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_viiii[$43 & 511]($3,50,$7,$10);
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$29>>2]|0;
 $37 = (($36) + ($34<<2)|0);
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  HEAP32[$37>>2] = $aggregate;
 }
 $39 = (($34) + 1)|0;
 HEAP32[$33>>2] = $39;
 $41 = HEAP32[$3>>2]|0;
 $42 = (($41) + 12|0);
 $43 = HEAP32[$42>>2]|0;
 FUNCTION_TABLE_viiii[$43 & 511]($3,50,$7,$10);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene15removeAggregateERNS_11PxAggregateEb($this,$aggregate,$wakeOnLostTouch) {
 $this = $this|0;
 $aggregate = $aggregate|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $$pre = 0, $$pre$phi8Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $index$0$lcssa$i$i = 0, $index$01$i$i = 0, $j$02 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 16|0);
 $1 = (($this) + 1216|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1208|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,51,$6,$9);
 $13 = HEAP32[$aggregate>>2]|0;
 $14 = (($13) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($aggregate)|0);
 $17 = ($this|0)==($16|0);
 if (!($17)) {
  $18 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  HEAP32[$vararg_buffer>>2] = 431840;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($18,8,430616,92,436368,$vararg_buffer);
  $82 = HEAP32[$2>>2]|0;
  $83 = (($82) + 12|0);
  $84 = HEAP32[$83>>2]|0;
  FUNCTION_TABLE_viiii[$84 & 511]($2,51,$6,$9);
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$aggregate>>2]|0;
 $20 = (($19) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 4095]($aggregate)|0);
 $23 = ($22|0)==($16|0);
 if (!($23)) {
  $82 = HEAP32[$2>>2]|0;
  $83 = (($82) + 12|0);
  $84 = HEAP32[$83>>2]|0;
  FUNCTION_TABLE_viiii[$84 & 511]($2,51,$6,$9);
  STACKTOP = sp;return;
 }
 $24 = (($aggregate) + 36|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  $$pre = (($aggregate) + 8|0);
  $$pre$phi8Z2D = $$pre;
 } else {
  $27 = (($aggregate) + 40|0);
  $28 = (($aggregate) + 8|0);
  $j$02 = 0;
  while(1) {
   $29 = HEAP32[$27>>2]|0;
   $30 = (($29) + ($j$02<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 24|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (FUNCTION_TABLE_ii[$34 & 4095]($31)|0);
   $36 = ($35|0)==(4);
   if ($36) {
    $43 = HEAP32[$31>>2]|0;
    $44 = (($43) + 28|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (FUNCTION_TABLE_ii[$45 & 4095]($31)|0);
    $47 = ($46|0)==(0|0);
    if (!($47)) {
     $48 = (($31) + 288|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = (($49) + 88|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = HEAP32[$49>>2]|0;
     $53 = (($52) + 108|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = (FUNCTION_TABLE_ii[$54 & 4095]($49)|0);
     $56 = ($55|0)==(0);
     if (!($56)) {
      $i$01 = 0;
      while(1) {
       $57 = (($51) + ($i$01<<2)|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($58) + 48|0);
       __ZN5physx3Scb9Aggregate11removeActorERNS0_5ActorEb($28,$59,0);
       $60 = (($i$01) + 1)|0;
       $61 = HEAP32[$49>>2]|0;
       $62 = (($61) + 108|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = (FUNCTION_TABLE_ii[$63 & 4095]($49)|0);
       $65 = ($60>>>0)<($64>>>0);
       if ($65) {
        $i$01 = $60;
       } else {
        break;
       }
      }
     }
     __ZN5physx7NpScene26removeArticulationInternalERNS_14PxArticulationEbb($this,$49,$wakeOnLostTouch,0);
    }
   } else {
    $37 = (($31) + 4|0);
    $38 = HEAP16[$37>>1]|0;
    $39 = $38&65535;
    $40 = ((414264 + ($39<<2)|0) + 68|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($31) + ($41)|0);
    __ZN5physx3Scb9Aggregate11removeActorERNS0_5ActorEb($28,$42,0);
    __ZN5physx7NpScene19removeActorInternalERNS_7PxActorEbb($this,$31,$wakeOnLostTouch,0);
   }
   $66 = (($j$02) + 1)|0;
   $exitcond = ($66|0)==($25|0);
   if ($exitcond) {
    $$pre$phi8Z2D = $28;
    break;
   } else {
    $j$02 = $66;
   }
  }
 }
 __ZN5physx3Scb5Scene15removeAggregateERNS0_9AggregateE($0,$$pre$phi8Z2D);
 $67 = (($this) + 3564|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0);
 if ($69) {
  $82 = HEAP32[$2>>2]|0;
  $83 = (($82) + 12|0);
  $84 = HEAP32[$83>>2]|0;
  FUNCTION_TABLE_viiii[$84 & 511]($2,51,$6,$9);
  STACKTOP = sp;return;
 }
 $70 = (($this) + 3560|0);
 $71 = HEAP32[$70>>2]|0;
 $index$01$i$i = 0;
 while(1) {
  $74 = (($71) + ($index$01$i$i<<2)|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)==($aggregate|0);
  $73 = (($index$01$i$i) + 1)|0;
  if ($76) {
   $index$0$lcssa$i$i = $index$01$i$i;
   break;
  }
  $72 = ($73>>>0)<($68>>>0);
  if ($72) {
   $index$01$i$i = $73;
  } else {
   $index$0$lcssa$i$i = $73;
   break;
  }
 }
 $77 = ($index$0$lcssa$i$i|0)==($68|0);
 if ($77) {
  $82 = HEAP32[$2>>2]|0;
  $83 = (($82) + 12|0);
  $84 = HEAP32[$83>>2]|0;
  FUNCTION_TABLE_viiii[$84 & 511]($2,51,$6,$9);
  STACKTOP = sp;return;
 }
 $78 = (($68) + -1)|0;
 HEAP32[$67>>2] = $78;
 $79 = (($71) + ($78<<2)|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($71) + ($index$0$lcssa$i$i<<2)|0);
 HEAP32[$81>>2] = $80;
 $82 = HEAP32[$2>>2]|0;
 $83 = (($82) + 12|0);
 $84 = HEAP32[$83>>2]|0;
 FUNCTION_TABLE_viiii[$84 & 511]($2,51,$6,$9);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene15getNbAggregatesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3564|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene13getAggregatesEPPNS_11PxAggregateEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3564|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($startIndex))|0;
 $3 = ($2|0)<(0);
 $4 = $3 ? 0 : $2;
 $5 = ($4>>>0)<($bufferSize>>>0);
 $6 = $5 ? $4 : $bufferSize;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 3560|0);
 $9 = $bufferSize ^ -1;
 $10 = ($2|0)>(0);
 $$op = $2 ^ -1;
 $11 = $10 ? $$op : -1;
 $12 = ($11>>>0)<($9>>>0);
 $umax = $12 ? $9 : $11;
 $13 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $14 = (($i$01) + ($startIndex))|0;
  $15 = HEAP32[$8>>2]|0;
  $16 = (($15) + ($14<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($buffer) + ($i$01<<2)|0);
  HEAP32[$18>>2] = $17;
  $19 = (($i$01) + 1)|0;
  $exitcond = ($19|0)==($13|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $19;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx7NpScene13addCollectionERKNS_12PxCollectionE($this,$collection) {
 $this = $this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($collection) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($collection) + 48|0);
 $i$05 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($i$05<<4)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 4|0);
  $8 = HEAP16[$7>>1]|0;
  switch ($8<<16>>16) {
  case 5:  {
   $9 = HEAP32[$6>>2]|0;
   $10 = (($9) + 80|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (FUNCTION_TABLE_ii[$11 & 4095]($6)|0);
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[$this>>2]|0;
    $15 = (($14) + 44|0);
    $16 = HEAP32[$15>>2]|0;
    FUNCTION_TABLE_vii[$16 & 4095]($this,$6);
   }
   break;
  }
  case 13:  {
   $57 = HEAP32[$this>>2]|0;
   $58 = (($57) + 60|0);
   $59 = HEAP32[$58>>2]|0;
   FUNCTION_TABLE_vii[$59 & 4095]($this,$6);
   break;
  }
  case 14:  {
   $49 = HEAP32[$6>>2]|0;
   $50 = (($49) + 128|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (FUNCTION_TABLE_ii[$51 & 4095]($6)|0);
   $53 = ($52|0)==(0|0);
   if ($53) {
    $54 = HEAP32[$this>>2]|0;
    $55 = (($54) + 36|0);
    $56 = HEAP32[$55>>2]|0;
    FUNCTION_TABLE_vii[$56 & 4095]($this,$6);
   }
   break;
  }
  case 10:  {
   $25 = HEAP32[$6>>2]|0;
   $26 = (($25) + 80|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (FUNCTION_TABLE_ii[$27 & 4095]($6)|0);
   $29 = ($28|0)==(0|0);
   if ($29) {
    $30 = HEAP32[$this>>2]|0;
    $31 = (($30) + 44|0);
    $32 = HEAP32[$31>>2]|0;
    FUNCTION_TABLE_vii[$32 & 4095]($this,$6);
   }
   break;
  }
  case 6:  {
   $17 = HEAP32[$6>>2]|0;
   $18 = (($17) + 80|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (FUNCTION_TABLE_ii[$19 & 4095]($6)|0);
   $21 = ($20|0)==(0|0);
   if ($21) {
    $22 = HEAP32[$this>>2]|0;
    $23 = (($22) + 44|0);
    $24 = HEAP32[$23>>2]|0;
    FUNCTION_TABLE_vii[$24 & 4095]($this,$6);
   }
   break;
  }
  case 11:  {
   $33 = HEAP32[$6>>2]|0;
   $34 = (($33) + 80|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (FUNCTION_TABLE_ii[$35 & 4095]($6)|0);
   $37 = ($36|0)==(0|0);
   if ($37) {
    $38 = HEAP32[$this>>2]|0;
    $39 = (($38) + 44|0);
    $40 = HEAP32[$39>>2]|0;
    FUNCTION_TABLE_vii[$40 & 4095]($this,$6);
   }
   break;
  }
  case 12:  {
   $41 = HEAP32[$6>>2]|0;
   $42 = (($41) + 80|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (FUNCTION_TABLE_ii[$43 & 4095]($6)|0);
   $45 = ($44|0)==(0|0);
   if ($45) {
    $46 = HEAP32[$this>>2]|0;
    $47 = (($46) + 44|0);
    $48 = HEAP32[$47>>2]|0;
    FUNCTION_TABLE_vii[$48 & 4095]($this,$6);
   }
   break;
  }
  default: {
  }
  }
  $60 = (($i$05) + 1)|0;
  $exitcond = ($60|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$05 = $60;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene11getNbActorsENS_7PxFlagsINS_15PxActorTypeFlag4EnumEtEE($this,$types) {
 $this = $this|0;
 $types = $types|0;
 var $$in = 0, $$in21 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $i2$013 = 0, $i3$09 = 0, $nbActors$0$ = 0, $nbActors$019 = 0, $nbActors$1 = 0, $nbActors$10 = 0, $nbActors$2$ = 0, $nbActors$216 = 0, $nbActors$3 = 0, $nbActors$4$ = 0, $nbActors$412 = 0, $nbActors$6 = 0;
 var $nbActors$7$ = 0, $nbActors$78 = 0, $nbActors$9 = 0, $not$ = 0, $not$22 = 0, $not$23 = 0, $not$24 = 0, $phitmp = 0, $phitmp$ = 0, $phitmp5 = 0, $phitmp5$ = 0, $phitmp6 = 0, $phitmp6$ = 0, $phitmp7 = 0, $phitmp7$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$types>>1]|0;
 $1 = $0 & 1;
 $2 = ($1<<16>>16)==(0);
 if ($2) {
  $nbActors$1 = 0;
 } else {
  $3 = (($this) + 3540|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   $nbActors$1 = 0;
  } else {
   $6 = (($this) + 3536|0);
   $7 = HEAP32[$6>>2]|0;
   $$in = $4;$nbActors$019 = 0;
   while(1) {
    $8 = (($$in) + -1)|0;
    $9 = (($7) + ($8<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + 4|0);
    $12 = HEAP16[$11>>1]|0;
    $phitmp7 = ($10|0)==(0|0);
    $not$ = ($12<<16>>16)!=(6);
    $phitmp7$ = $phitmp7 | $not$;
    $13 = $phitmp7$&1;
    $14 = $13 ^ 1;
    $nbActors$0$ = (($14) + ($nbActors$019))|0;
    $15 = ($8|0)==(0);
    if ($15) {
     $nbActors$1 = $nbActors$0$;
     break;
    } else {
     $$in = $8;$nbActors$019 = $nbActors$0$;
    }
   }
  }
 }
 $16 = $0 & 2;
 $17 = ($16<<16>>16)==(0);
 if ($17) {
  $nbActors$3 = $nbActors$1;
 } else {
  $18 = (($this) + 3540|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0);
  if ($20) {
   $nbActors$3 = $nbActors$1;
  } else {
   $21 = (($this) + 3536|0);
   $22 = HEAP32[$21>>2]|0;
   $$in21 = $19;$nbActors$216 = $nbActors$1;
   while(1) {
    $23 = (($$in21) + -1)|0;
    $24 = (($22) + ($23<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 4|0);
    $27 = HEAP16[$26>>1]|0;
    $phitmp6 = ($25|0)==(0|0);
    $not$22 = ($27<<16>>16)!=(5);
    $phitmp6$ = $phitmp6 | $not$22;
    $28 = $phitmp6$&1;
    $29 = $28 ^ 1;
    $nbActors$2$ = (($29) + ($nbActors$216))|0;
    $30 = ($23|0)==(0);
    if ($30) {
     $nbActors$3 = $nbActors$2$;
     break;
    } else {
     $$in21 = $23;$nbActors$216 = $nbActors$2$;
    }
   }
  }
 }
 $31 = $0 & 4;
 $32 = ($31<<16>>16)==(0);
 if ($32) {
  $nbActors$6 = $nbActors$3;
 } else {
  $33 = (($this) + 3628|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0);
  if ($35) {
   $nbActors$6 = $nbActors$3;
  } else {
   $36 = (($this) + 3624|0);
   $37 = HEAP32[$36>>2]|0;
   $i2$013 = 0;$nbActors$412 = $nbActors$3;
   while(1) {
    $38 = (($37) + ($i2$013<<2)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 4|0);
    $41 = HEAP16[$40>>1]|0;
    $phitmp5 = ($39|0)==(0|0);
    $not$24 = ($41<<16>>16)!=(11);
    $phitmp5$ = $phitmp5 | $not$24;
    $42 = $phitmp5$&1;
    $43 = $42 ^ 1;
    $nbActors$4$ = (($43) + ($nbActors$412))|0;
    $44 = (($i2$013) + 1)|0;
    $45 = ($44>>>0)<($34>>>0);
    if ($45) {
     $i2$013 = $44;$nbActors$412 = $nbActors$4$;
    } else {
     $nbActors$6 = $nbActors$4$;
     break;
    }
   }
  }
 }
 $46 = $0 & 8;
 $47 = ($46<<16>>16)==(0);
 if ($47) {
  $nbActors$9 = $nbActors$6;
 } else {
  $48 = (($this) + 3628|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0);
  if ($50) {
   $nbActors$9 = $nbActors$6;
  } else {
   $51 = (($this) + 3624|0);
   $52 = HEAP32[$51>>2]|0;
   $i3$09 = 0;$nbActors$78 = $nbActors$6;
   while(1) {
    $53 = (($52) + ($i3$09<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + 4|0);
    $56 = HEAP16[$55>>1]|0;
    $phitmp = ($54|0)==(0|0);
    $not$23 = ($56<<16>>16)!=(12);
    $phitmp$ = $phitmp | $not$23;
    $57 = $phitmp$&1;
    $58 = $57 ^ 1;
    $nbActors$7$ = (($58) + ($nbActors$78))|0;
    $59 = (($i3$09) + 1)|0;
    $60 = ($59>>>0)<($49>>>0);
    if ($60) {
     $i3$09 = $59;$nbActors$78 = $nbActors$7$;
    } else {
     $nbActors$9 = $nbActors$7$;
     break;
    }
   }
  }
 }
 $61 = $0 & 32;
 $62 = ($61<<16>>16)==(0);
 if ($62) {
  $nbActors$10 = $nbActors$9;
  STACKTOP = sp;return ($nbActors$10|0);
 }
 $63 = (($this) + 3640|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + ($nbActors$9))|0;
 $nbActors$10 = $65;
 STACKTOP = sp;return ($nbActors$10|0);
}
function __ZNK5physx7NpScene9getActorsENS_7PxFlagsINS_15PxActorTypeFlag4EnumEtEEPPNS_7PxActorEjj($this,$types,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $types = $types|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $i$034 = 0, $i$034$us = 0, $i2$027 = 0, $i2$027$us = 0, $i4$024 = 0, $or$cond = 0, $or$cond$us = 0, $or$cond14 = 0, $or$cond16 = 0, $or$cond16$us = 0, $or$cond18 = 0, $or$cond20 = 0, $or$cond20$us = 0, $or$cond3 = 0, $or$cond3$us = 0, $or$cond325 = 0, $or$cond33 = 0, $or$cond4 = 0;
 var $or$cond421 = 0, $virtualIndex$036 = 0, $virtualIndex$036$us = 0, $virtualIndex$1 = 0, $virtualIndex$1$us = 0, $virtualIndex$2 = 0, $virtualIndex$326 = 0, $virtualIndex$326$us = 0, $virtualIndex$4 = 0, $virtualIndex$4$us = 0, $virtualIndex$5 = 0, $virtualIndex$622 = 0, $writeCount$037 = 0, $writeCount$037$us = 0, $writeCount$1 = 0, $writeCount$1023 = 0, $writeCount$11 = 0, $writeCount$12 = 0, $writeCount$2 = 0, $writeCount$2$us = 0;
 var $writeCount$3 = 0, $writeCount$3$us = 0, $writeCount$4 = 0, $writeCount$529 = 0, $writeCount$529$us = 0, $writeCount$6 = 0, $writeCount$7 = 0, $writeCount$7$us = 0, $writeCount$8 = 0, $writeCount$8$us = 0, $writeCount$9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$types>>1]|0;
 $1 = $0 & 3;
 $2 = ($1<<16>>16)==(0);
 L1: do {
  if ($2) {
   $virtualIndex$2 = 0;$writeCount$4 = 0;
  } else {
   $3 = (($this) + 3540|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)!=(0);
   $6 = ($bufferSize|0)!=(0);
   $or$cond33 = $5 & $6;
   if ($or$cond33) {
    $7 = $0 & 1;
    $8 = ($7<<16>>16)==(0);
    $9 = (($this) + 3536|0);
    if ($8) {
     $i$034$us = 0;$virtualIndex$036$us = 0;$writeCount$037$us = 0;
     while(1) {
      $10 = $0 & 2;
      $11 = ($10<<16>>16)==(0);
      if ($11) {
       $virtualIndex$1$us = $virtualIndex$036$us;$writeCount$3$us = $writeCount$037$us;
      } else {
       $12 = HEAP32[$9>>2]|0;
       $13 = (($12) + ($i$034$us<<2)|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = (($14) + 4|0);
       $16 = HEAP16[$15>>1]|0;
       $17 = ($16<<16>>16)!=(5);
       $18 = ($14|0)==(0|0);
       $or$cond16$us = $17 | $18;
       if ($or$cond16$us) {
        $virtualIndex$1$us = $virtualIndex$036$us;$writeCount$3$us = $writeCount$037$us;
       } else {
        $19 = ($virtualIndex$036$us>>>0)<($startIndex>>>0);
        if ($19) {
         $writeCount$2$us = $writeCount$037$us;
        } else {
         $20 = (($writeCount$037$us) + 1)|0;
         $21 = (($buffer) + ($writeCount$037$us<<2)|0);
         HEAP32[$21>>2] = $14;
         $writeCount$2$us = $20;
        }
        $22 = (($virtualIndex$036$us) + 1)|0;
        $virtualIndex$1$us = $22;$writeCount$3$us = $writeCount$2$us;
       }
      }
      $23 = (($i$034$us) + 1)|0;
      $24 = ($23>>>0)<($4>>>0);
      $25 = ($writeCount$3$us>>>0)<($bufferSize>>>0);
      $or$cond$us = $24 & $25;
      if ($or$cond$us) {
       $i$034$us = $23;$virtualIndex$036$us = $virtualIndex$1$us;$writeCount$037$us = $writeCount$3$us;
      } else {
       $virtualIndex$2 = $virtualIndex$1$us;$writeCount$4 = $writeCount$3$us;
       break L1;
      }
     }
    } else {
     $i$034 = 0;$virtualIndex$036 = 0;$writeCount$037 = 0;
    }
    while(1) {
     $26 = HEAP32[$9>>2]|0;
     $27 = (($26) + ($i$034<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($28) + 4|0);
     $30 = HEAP16[$29>>1]|0;
     $31 = ($30<<16>>16)!=(6);
     $32 = ($28|0)==(0|0);
     $or$cond14 = $31 | $32;
     if ($or$cond14) {
      $37 = $0 & 2;
      $38 = ($37<<16>>16)==(0);
      if ($38) {
       $virtualIndex$1 = $virtualIndex$036;$writeCount$3 = $writeCount$037;
      } else {
       $39 = HEAP32[$9>>2]|0;
       $40 = (($39) + ($i$034<<2)|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = (($41) + 4|0);
       $43 = HEAP16[$42>>1]|0;
       $44 = ($43<<16>>16)!=(5);
       $45 = ($41|0)==(0|0);
       $or$cond16 = $44 | $45;
       if ($or$cond16) {
        $virtualIndex$1 = $virtualIndex$036;$writeCount$3 = $writeCount$037;
       } else {
        $46 = ($virtualIndex$036>>>0)<($startIndex>>>0);
        if ($46) {
         $writeCount$2 = $writeCount$037;
        } else {
         $47 = (($writeCount$037) + 1)|0;
         $48 = (($buffer) + ($writeCount$037<<2)|0);
         HEAP32[$48>>2] = $41;
         $writeCount$2 = $47;
        }
        $49 = (($virtualIndex$036) + 1)|0;
        $virtualIndex$1 = $49;$writeCount$3 = $writeCount$2;
       }
      }
     } else {
      $33 = ($virtualIndex$036>>>0)<($startIndex>>>0);
      if ($33) {
       $writeCount$1 = $writeCount$037;
      } else {
       $34 = (($writeCount$037) + 1)|0;
       $35 = (($buffer) + ($writeCount$037<<2)|0);
       HEAP32[$35>>2] = $28;
       $writeCount$1 = $34;
      }
      $36 = (($virtualIndex$036) + 1)|0;
      $virtualIndex$1 = $36;$writeCount$3 = $writeCount$1;
     }
     $50 = (($i$034) + 1)|0;
     $51 = ($50>>>0)<($4>>>0);
     $52 = ($writeCount$3>>>0)<($bufferSize>>>0);
     $or$cond = $51 & $52;
     if ($or$cond) {
      $i$034 = $50;$virtualIndex$036 = $virtualIndex$1;$writeCount$037 = $writeCount$3;
     } else {
      $virtualIndex$2 = $virtualIndex$1;$writeCount$4 = $writeCount$3;
      break;
     }
    }
   } else {
    $virtualIndex$2 = 0;$writeCount$4 = 0;
   }
  }
 } while(0);
 $53 = $0 & 12;
 $54 = ($53<<16>>16)==(0);
 L29: do {
  if ($54) {
   $virtualIndex$5 = $virtualIndex$2;$writeCount$9 = $writeCount$4;
  } else {
   $55 = (($this) + 3628|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)!=(0);
   $58 = ($writeCount$4>>>0)<($bufferSize>>>0);
   $or$cond325 = $57 & $58;
   if ($or$cond325) {
    $59 = $0 & 4;
    $60 = ($59<<16>>16)==(0);
    $61 = (($this) + 3624|0);
    if ($60) {
     $i2$027$us = 0;$virtualIndex$326$us = $virtualIndex$2;$writeCount$529$us = $writeCount$4;
     while(1) {
      $62 = $0 & 8;
      $63 = ($62<<16>>16)==(0);
      if ($63) {
       $virtualIndex$4$us = $virtualIndex$326$us;$writeCount$8$us = $writeCount$529$us;
      } else {
       $64 = HEAP32[$61>>2]|0;
       $65 = (($64) + ($i2$027$us<<2)|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = (($66) + 4|0);
       $68 = HEAP16[$67>>1]|0;
       $69 = ($68<<16>>16)!=(12);
       $70 = ($66|0)==(0|0);
       $or$cond20$us = $69 | $70;
       if ($or$cond20$us) {
        $virtualIndex$4$us = $virtualIndex$326$us;$writeCount$8$us = $writeCount$529$us;
       } else {
        $71 = ($virtualIndex$326$us>>>0)<($startIndex>>>0);
        if ($71) {
         $writeCount$7$us = $writeCount$529$us;
        } else {
         $72 = (($writeCount$529$us) + 1)|0;
         $73 = (($buffer) + ($writeCount$529$us<<2)|0);
         HEAP32[$73>>2] = $66;
         $writeCount$7$us = $72;
        }
        $74 = (($virtualIndex$326$us) + 1)|0;
        $virtualIndex$4$us = $74;$writeCount$8$us = $writeCount$7$us;
       }
      }
      $75 = (($i2$027$us) + 1)|0;
      $76 = ($75>>>0)<($56>>>0);
      $77 = ($writeCount$8$us>>>0)<($bufferSize>>>0);
      $or$cond3$us = $76 & $77;
      if ($or$cond3$us) {
       $i2$027$us = $75;$virtualIndex$326$us = $virtualIndex$4$us;$writeCount$529$us = $writeCount$8$us;
      } else {
       $virtualIndex$5 = $virtualIndex$4$us;$writeCount$9 = $writeCount$8$us;
       break L29;
      }
     }
    } else {
     $i2$027 = 0;$virtualIndex$326 = $virtualIndex$2;$writeCount$529 = $writeCount$4;
    }
    while(1) {
     $78 = HEAP32[$61>>2]|0;
     $79 = (($78) + ($i2$027<<2)|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (($80) + 4|0);
     $82 = HEAP16[$81>>1]|0;
     $83 = ($82<<16>>16)!=(11);
     $84 = ($80|0)==(0|0);
     $or$cond18 = $83 | $84;
     if ($or$cond18) {
      $89 = $0 & 8;
      $90 = ($89<<16>>16)==(0);
      if ($90) {
       $virtualIndex$4 = $virtualIndex$326;$writeCount$8 = $writeCount$529;
      } else {
       $91 = HEAP32[$61>>2]|0;
       $92 = (($91) + ($i2$027<<2)|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = (($93) + 4|0);
       $95 = HEAP16[$94>>1]|0;
       $96 = ($95<<16>>16)!=(12);
       $97 = ($93|0)==(0|0);
       $or$cond20 = $96 | $97;
       if ($or$cond20) {
        $virtualIndex$4 = $virtualIndex$326;$writeCount$8 = $writeCount$529;
       } else {
        $98 = ($virtualIndex$326>>>0)<($startIndex>>>0);
        if ($98) {
         $writeCount$7 = $writeCount$529;
        } else {
         $99 = (($writeCount$529) + 1)|0;
         $100 = (($buffer) + ($writeCount$529<<2)|0);
         HEAP32[$100>>2] = $93;
         $writeCount$7 = $99;
        }
        $101 = (($virtualIndex$326) + 1)|0;
        $virtualIndex$4 = $101;$writeCount$8 = $writeCount$7;
       }
      }
     } else {
      $85 = ($virtualIndex$326>>>0)<($startIndex>>>0);
      if ($85) {
       $writeCount$6 = $writeCount$529;
      } else {
       $86 = (($writeCount$529) + 1)|0;
       $87 = (($buffer) + ($writeCount$529<<2)|0);
       HEAP32[$87>>2] = $80;
       $writeCount$6 = $86;
      }
      $88 = (($virtualIndex$326) + 1)|0;
      $virtualIndex$4 = $88;$writeCount$8 = $writeCount$6;
     }
     $102 = (($i2$027) + 1)|0;
     $103 = ($102>>>0)<($56>>>0);
     $104 = ($writeCount$8>>>0)<($bufferSize>>>0);
     $or$cond3 = $103 & $104;
     if ($or$cond3) {
      $i2$027 = $102;$virtualIndex$326 = $virtualIndex$4;$writeCount$529 = $writeCount$8;
     } else {
      $virtualIndex$5 = $virtualIndex$4;$writeCount$9 = $writeCount$8;
      break;
     }
    }
   } else {
    $virtualIndex$5 = $virtualIndex$2;$writeCount$9 = $writeCount$4;
   }
  }
 } while(0);
 $105 = $0 & 32;
 $106 = ($105<<16>>16)==(0);
 if ($106) {
  $writeCount$12 = $writeCount$9;
  STACKTOP = sp;return ($writeCount$12|0);
 }
 $107 = (($this) + 3640|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108|0)!=(0);
 $110 = ($writeCount$9>>>0)<($bufferSize>>>0);
 $or$cond421 = $109 & $110;
 if (!($or$cond421)) {
  $writeCount$12 = $writeCount$9;
  STACKTOP = sp;return ($writeCount$12|0);
 }
 $111 = (($this) + 3636|0);
 $i4$024 = 0;$virtualIndex$622 = $virtualIndex$5;$writeCount$1023 = $writeCount$9;
 while(1) {
  $112 = ($virtualIndex$622>>>0)<($startIndex>>>0);
  if ($112) {
   $writeCount$11 = $writeCount$1023;
  } else {
   $113 = HEAP32[$111>>2]|0;
   $114 = (($113) + ($i4$024<<2)|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = (($writeCount$1023) + 1)|0;
   $117 = (($buffer) + ($writeCount$1023<<2)|0);
   HEAP32[$117>>2] = $115;
   $writeCount$11 = $116;
  }
  $118 = (($virtualIndex$622) + 1)|0;
  $119 = (($i4$024) + 1)|0;
  $120 = ($119>>>0)<($108>>>0);
  $121 = ($writeCount$11>>>0)<($bufferSize>>>0);
  $or$cond4 = $120 & $121;
  if ($or$cond4) {
   $i4$024 = $119;$virtualIndex$622 = $118;$writeCount$1023 = $writeCount$11;
  } else {
   $writeCount$12 = $writeCount$11;
   break;
  }
 }
 STACKTOP = sp;return ($writeCount$12|0);
}
function __ZN5physx7NpScene19getActiveTransformsERjh($this,$nbTransformsOut,$client) {
 $this = $this|0;
 $nbTransformsOut = $nbTransformsOut|0;
 $client = $client|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2432|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  $4 = (__ZN5physx2Sc5Scene19getActiveTransformsERjh($3,$nbTransformsOut,$client)|0);
  $$0$i = $4;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $5 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($5,2,435248,795,436272,$vararg_buffer);
  HEAP32[$nbTransformsOut>>2] = 0;
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpScene18getNbArticulationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3552|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene16getArticulationsEPPNS_14PxArticulationEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3552|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($startIndex))|0;
 $3 = ($2|0)<(0);
 $4 = $3 ? 0 : $2;
 $5 = ($4>>>0)<($bufferSize>>>0);
 $6 = $5 ? $4 : $bufferSize;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 3548|0);
 $9 = $bufferSize ^ -1;
 $10 = ($2|0)>(0);
 $$op = $2 ^ -1;
 $11 = $10 ? $$op : -1;
 $12 = ($11>>>0)<($9>>>0);
 $umax = $12 ? $9 : $11;
 $13 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $14 = (($i$01) + ($startIndex))|0;
  $15 = HEAP32[$8>>2]|0;
  $16 = (($15) + ($14<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($buffer) + ($i$01<<2)|0);
  HEAP32[$18>>2] = $17;
  $19 = (($i$01) + 1)|0;
  $exitcond = ($19|0)==($13|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $19;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZNK5physx7NpScene16getNbConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3528|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene14getConstraintsEPPNS_12PxConstraintEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3528|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($startIndex))|0;
 $3 = ($2|0)<(0);
 $4 = $3 ? 0 : $2;
 $5 = ($4>>>0)<($bufferSize>>>0);
 $6 = $5 ? $4 : $bufferSize;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 3524|0);
 $9 = $bufferSize ^ -1;
 $10 = ($2|0)>(0);
 $$op = $2 ^ -1;
 $11 = $10 ? $$op : -1;
 $12 = ($11>>>0)<($9>>>0);
 $umax = $12 ? $9 : $11;
 $13 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $14 = (($i$01) + ($startIndex))|0;
  $15 = HEAP32[$8>>2]|0;
  $16 = (($15) + ($14<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($buffer) + ($i$01<<2)|0);
  HEAP32[$18>>2] = $17;
  $19 = (($i$01) + 1)|0;
  $exitcond = ($19|0)==($13|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $19;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx7NpScene15getRenderBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 3656|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $4 = (($this) + 3460|0);
  STACKTOP = sp;return ($4|0);
 }
 $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,2,430616,1378,431880,$vararg_buffer);
 $4 = (($this) + 3460|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx7NpScene9visualizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $actorIt$02 = 0, $exitcond = 0, $i$08 = 0, $i1$04 = 0, $i2$01 = 0, $info = 0, $out = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $out = sp + 128|0;
 $0 = sp;
 $1 = sp + 24|0;
 $info = sp + 56|0;
 $2 = sp + 96|0;
 $3 = (($this) + 3468|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 3480|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 3492|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 3504|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 3516|0);
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 296|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (Math_fround(FUNCTION_TABLE_fii[$10 & 63]($this,0)));
 $12 = $11 == Math_fround(0.0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 3460|0);
 $14 = (($out) + 36|0);
 dest=$out+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($out) + 40|0);
 $16 = (($out) + 56|0);
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($out) + 60|0);
 $18 = (($out) + 76|0);
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($out) + 80|0);
 $20 = (($out) + 96|0);
 ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($out) + 100|0);
 HEAP32[$21>>2] = $13;
 $22 = HEAP32[$this>>2]|0;
 $23 = (($22) + 296|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (Math_fround(FUNCTION_TABLE_fii[$24 & 63]($this,1)));
 $26 = $25 != Math_fround(0.0);
 if ($26) {
  HEAPF32[$0>>2] = $25;
  $27 = (($0) + 4|0);
  HEAPF32[$27>>2] = $25;
  $28 = (($0) + 8|0);
  HEAPF32[$28>>2] = $25;
  $29 = (($0) + 12|0);
  HEAP32[$29>>2] = -65536;
  $30 = (($0) + 16|0);
  HEAP32[$30>>2] = -16711936;
  $31 = (($0) + 20|0);
  HEAP32[$31>>2] = -16776961;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($out,$0)|0);
 }
 $32 = (($this) + 3552|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 if (!($34)) {
  $35 = (($this) + 3548|0);
  $i$08 = 0;
  while(1) {
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + ($i$08<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   __ZN5physx14NpArticulation9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($38,$out,$this);
   $39 = (($i$08) + 1)|0;
   $40 = HEAP32[$32>>2]|0;
   $41 = ($39>>>0)<($40>>>0);
   if ($41) {
    $i$08 = $39;
   } else {
    break;
   }
  }
 }
 $42 = (($this) + 3536|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 3540|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + ($45<<2)|0);
 $47 = (($this) + 3640|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0);
 if (!($49)) {
  $50 = (($this) + 3636|0);
  $i1$04 = 0;
  while(1) {
   $52 = HEAP32[$50>>2]|0;
   $53 = (($52) + ($i1$04<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = HEAP32[$54>>2]|0;
   $56 = (($55) + 492|0);
   $57 = HEAP32[$56>>2]|0;
   FUNCTION_TABLE_viii[$57 & 4095]($54,$out,$this);
   $58 = (($i1$04) + 1)|0;
   $59 = HEAP32[$47>>2]|0;
   $60 = ($58>>>0)<($59>>>0);
   if ($60) {
    $i1$04 = $58;
   } else {
    break;
   }
  }
 }
 $51 = ($45|0)==(0);
 if (!($51)) {
  $actorIt$02 = $43;
  while(1) {
   $61 = HEAP32[$actorIt$02>>2]|0;
   $62 = HEAP32[$61>>2]|0;
   $63 = (($62) + 24|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (FUNCTION_TABLE_ii[$64 & 4095]($61)|0);
   $66 = ($65|0)==(1);
   $67 = HEAP32[$actorIt$02>>2]|0;
   if ($66) {
    __ZN5physx14NpRigidDynamic9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($67,$out,$this);
   } else {
    __ZN5physx13NpRigidStatic9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($67,$out,$this);
   }
   $68 = (($actorIt$02) + 4|0);
   $69 = ($68|0)==($46|0);
   if ($69) {
    break;
   } else {
    $actorIt$02 = $68;
   }
  }
 }
 $70 = HEAP32[$this>>2]|0;
 $71 = (($70) + 296|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (Math_fround(FUNCTION_TABLE_fii[$72 & 63]($this,18)));
 $74 = $73 != Math_fround(0.0);
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 296|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (Math_fround(FUNCTION_TABLE_fii[$77 & 63]($this,19)));
 $79 = $78 != Math_fround(0.0);
 if ($74) {
  $80 = (($this) + 3388|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)==(0|0);
  if (!($82)) {
   $83 = HEAP32[$81>>2]|0;
   $84 = (($83) + 48|0);
   $85 = HEAP32[$84>>2]|0;
   FUNCTION_TABLE_viii[$85 & 4095]($81,$out,-16776961);
  }
 }
 if ($79) {
  $86 = (($this) + 3392|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==(0|0);
  if (!($88)) {
   $89 = HEAP32[$87>>2]|0;
   $90 = (($89) + 48|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_viii[$91 & 4095]($87,$out,-65536);
  }
 }
 $92 = HEAP32[$this>>2]|0;
 $93 = (($92) + 296|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (Math_fround(FUNCTION_TABLE_fii[$94 & 63]($this,36)));
 $96 = $95 != Math_fround(0.0);
 if (!($96)) {
  STACKTOP = sp;return;
 }
 HEAPF32[$1>>2] = Math_fround(0.0);
 $97 = (($1) + 4|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 $98 = (($1) + 8|0);
 HEAPF32[$98>>2] = Math_fround(0.0);
 $99 = (($1) + 12|0);
 HEAPF32[$99>>2] = Math_fround(1.0);
 $100 = (($1) + 16|0);
 HEAPF32[$100>>2] = Math_fround(0.0);
 $101 = (($1) + 20|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = (($1) + 24|0);
 HEAPF32[$102>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$1)|0);
 $103 = (($this) + 16|0);
 $104 = (__ZNK5physx3Scb5Scene22getNbBroadPhaseRegionsEv($103)|0);
 $105 = ($104|0)==(0);
 if ($105) {
  STACKTOP = sp;return;
 }
 $106 = (($info) + 36|0);
 $107 = (($2) + 4|0);
 $108 = (($info) + 4|0);
 $109 = (($2) + 8|0);
 $110 = (($info) + 8|0);
 $111 = (($2) + 12|0);
 $112 = (($info) + 12|0);
 $113 = (($2) + 16|0);
 $114 = (($info) + 16|0);
 $115 = (($2) + 20|0);
 $116 = (($info) + 20|0);
 $117 = (($2) + 24|0);
 $i2$01 = 0;
 while(1) {
  (__ZNK5physx3Scb5Scene20getBroadPhaseRegionsEPNS_22PxBroadPhaseRegionInfoEjj($103,$info,1,$i2$01)|0);
  $118 = HEAP8[$106>>0]|0;
  $119 = ($118<<24>>24)==(0);
  if ($119) {
   (__ZN5physx2Cm12RenderOutputlsEj($out,-16777216)|0);
  } else {
   (__ZN5physx2Cm12RenderOutputlsEj($out,-256)|0);
  }
  $120 = Math_fround(HEAPF32[$info>>2]);
  HEAPF32[$2>>2] = $120;
  $121 = Math_fround(HEAPF32[$108>>2]);
  HEAPF32[$107>>2] = $121;
  $122 = Math_fround(HEAPF32[$110>>2]);
  HEAPF32[$109>>2] = $122;
  $123 = Math_fround(HEAPF32[$112>>2]);
  HEAPF32[$111>>2] = $123;
  $124 = Math_fround(HEAPF32[$114>>2]);
  HEAPF32[$113>>2] = $124;
  $125 = Math_fround(HEAPF32[$116>>2]);
  HEAPF32[$115>>2] = $125;
  HEAP8[$117>>0] = 1;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$2)|0);
  $126 = (($i2$01) + 1)|0;
  $exitcond = ($126|0)==($104|0);
  if ($exitcond) {
   break;
  } else {
   $i2$01 = $126;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene23getSimulationStatisticsERNS_22PxSimulationStatisticsE($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 3656|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZNK5physx2Sc5Scene8getStatsERNS_22PxSimulationStatisticsE($3,$s);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,430616,1468,431952,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene12createClientEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 3664|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 3360|0);
 HEAP8[$0>>0] = -1;
 $5 = (($this) + 3368|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = (($this) + 3364|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  $11 = HEAP32[$4>>2]|0;
  $12 = (($11) + ($9)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   $15 = $9;
  } else {
   HEAP8[$12>>0] = -1;
   $$pre$i$i = HEAP32[$8>>2]|0;
   $15 = $$pre$i$i;
  }
  $14 = (($15) + 1)|0;
  HEAP32[$8>>2] = $14;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_7PxFlagsINS_20PxClientBehaviorFlag4EnumEhEENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($4,$0)|0);
 }
 $16 = (($this) + 2433|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $19 = (($this) + 32|0);
  $20 = (__ZN5physx2Sc5Scene12createClientEv($19)|0);
  $$0$i = $20;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $21 = (($this) + 3356|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 1)|0;
  HEAP32[$21>>2] = $23;
  $24 = HEAP32[$8>>2]|0;
  $25 = (($24) + 255)|0;
  $26 = $25&255;
  $$0$i = $26;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN5physx7NpScene22setClientBehaviorFlagsEhNS_7PxFlagsINS_20PxClientBehaviorFlag4EnumEhEE($this,$client,$clientBehaviorFlags) {
 $this = $this|0;
 $client = $client|0;
 $clientBehaviorFlags = $clientBehaviorFlags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP8[$clientBehaviorFlags>>0]|0;
 $2 = (($this) + 2433|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 32|0);
  HEAP8[$0>>0] = $1;
  __ZN5physx2Sc5Scene22setClientBehaviorFlagsEhNS_7PxFlagsINS_20PxClientBehaviorFlag4EnumEhEE($5,$client,$0);
  STACKTOP = sp;return;
 } else {
  $6 = $client&255;
  $7 = (($this) + 3360|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($6)|0);
  HEAP8[$9>>0] = $1;
  $10 = (($this) + 3372|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 | 32;
  HEAP32[$10>>2] = $12;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene22getClientBehaviorFlagsEh($agg$result,$this,$client) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = $client&255;
  $5 = (($this) + 3360|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($4)|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(-1);
  if (!($9)) {
   HEAP8[$agg$result>>0] = $8;
   STACKTOP = sp;return;
  }
 }
 $10 = (($this) + 32|0);
 __ZNK5physx2Sc5Scene22getClientBehaviorFlagsEh($agg$result,$10,$client);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene15setFrictionTypeENS_14PxFrictionType4EnumE($this,$frictionType) {
 $this = $this|0;
 $frictionType = $frictionType|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN5physx2Sc5Scene15setFrictionTypeENS_14PxFrictionType4EnumE($0,$frictionType);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene15getFrictionTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene15getFrictionTypeEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene30setClothInterCollisionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene30setClothInterCollisionDistanceEf($3,$distance);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,435248,852,435952,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene30getClothInterCollisionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc5Scene30getClothInterCollisionDistanceEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx7NpScene31setClothInterCollisionStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene31setClothInterCollisionStiffnessEf($3,$stiffness);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,435248,869,435840,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene31getClothInterCollisionStiffnessEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc5Scene31getClothInterCollisionStiffnessEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx7NpScene34setClothInterCollisionNbIterationsEj($this,$nbIterations) {
 $this = $this|0;
 $nbIterations = $nbIterations|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene34setClothInterCollisionNbIterationsEj($3,$nbIterations);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,435248,886,435728,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene34getClothInterCollisionNbIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene34getClothInterCollisionNbIterationsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene26setSimulationEventCallbackEPNS_25PxSimulationEventCallbackEh($this,$callback,$client) {
 $this = $this|0;
 $callback = $callback|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene26setSimulationEventCallbackEPNS_25PxSimulationEventCallbackEh($3,$callback,$client);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,435248,564,435624,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene26getSimulationEventCallbackEh($this,$client) {
 $this = $this|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene26getSimulationEventCallbackEh($0,$client)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene24setContactModifyCallbackEPNS_23PxContactModifyCallbackE($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene24setContactModifyCallbackEPNS_23PxContactModifyCallbackE($3,$callback);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,435248,577,435520,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene24getContactModifyCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene24getContactModifyCallbackEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene27setCCDContactModifyCallbackEPNS_26PxCCDContactModifyCallbackE($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene27setCCDContactModifyCallbackEPNS_26PxCCDContactModifyCallbackE($3,$callback);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,435248,590,435520,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene27getCCDContactModifyCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene27getCCDContactModifyCallbackEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene21setBroadPhaseCallbackEPNS_20PxBroadPhaseCallbackEh($this,$callback,$client) {
 $this = $this|0;
 $callback = $callback|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene21setBroadPhaseCallbackEPNS_20PxBroadPhaseCallbackEh($3,$callback,$client);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,435248,616,435424,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene21getBroadPhaseCallbackEh($this,$client) {
 $this = $this|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene21getBroadPhaseCallbackEh($0,$client)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene15setCCDMaxPassesEj($this,$ccdMaxPasses) {
 $this = $this|0;
 $ccdMaxPasses = $ccdMaxPasses|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene15setCCDMaxPassesEj($3,$ccdMaxPasses);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,2,435248,603,435328,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene15getCCDMaxPassesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene15getCCDMaxPassesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene17getBroadPhaseTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx3Scb5Scene17getBroadPhaseTypeEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene17getBroadPhaseCapsERNS_16PxBroadPhaseCapsE($this,$caps) {
 $this = $this|0;
 $caps = $caps|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx3Scb5Scene17getBroadPhaseCapsERNS_16PxBroadPhaseCapsE($0,$caps)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene22getNbBroadPhaseRegionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx3Scb5Scene22getNbBroadPhaseRegionsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene20getBroadPhaseRegionsEPNS_22PxBroadPhaseRegionInfoEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx3Scb5Scene20getBroadPhaseRegionsEPNS_22PxBroadPhaseRegionInfoEjj($0,$userBuffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene19addBroadPhaseRegionERKNS_18PxBroadPhaseRegionEb($this,$region,$populateRegion) {
 $this = $this|0;
 $region = $region|0;
 $populateRegion = $populateRegion|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = Math_fround(HEAPF32[$region>>2]);
 $1 = (($region) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $0 > $2;
 if ($3) {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,4,430616,1659,432056,$vararg_buffer);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $5 = (($this) + 16|0);
  $6 = (__ZN5physx3Scb5Scene19addBroadPhaseRegionERKNS_18PxBroadPhaseRegionEb($5,$region,$populateRegion)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx7NpScene22removeBroadPhaseRegionEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZN5physx3Scb5Scene22removeBroadPhaseRegionEj($0,$handle)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene19getFilterShaderDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1124|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene23getFilterShaderDataSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1128|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene15getFilterShaderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1132|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene17getFilterCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1136|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene14resetFilteringERNS_7PxActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $$c = 0, $$c9 = 0, $$in = 0, $$in$i = 0, $$in11 = 0, $$phi$trans$insert$i110 = 0, $$phi$trans$insert$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($actor) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 switch ($2|0) {
 case 5:  {
  $4 = (($actor) + 48|0);
  (__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($actor,$4,0,0)|0);
  $5 = (($actor) + 284|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 & 4096;
  $8 = ($7|0)==(0);
  if ($8) {
   $20 = (($actor) + 108|0);
   $$in$i = $20;
  } else {
   $9 = (($actor) + 56|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $12 = HEAP32[$4>>2]|0;
    $13 = (($actor) + 52|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 >>> 24;
    $16 = $15 & 15;
    $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$16)|0);
    HEAP32[$9>>2] = $17;
    $19 = $17;
   } else {
    $19 = $10;
   }
   $18 = (($19) + 268|0);
   $$in$i = $18;
  }
  $21 = HEAP8[$$in$i>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if (!($23)) {
   STACKTOP = sp;return;
  }
  __ZN5physx14NpRigidDynamic29wakeUpInternalNoKinematicTestERNS_3Scb4BodyEbb($actor,$4,0,1);
  STACKTOP = sp;return;
  break;
 }
 case 12:  {
  $38 = (($actor) + 20|0);
  $39 = (($38) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 >>> 30;
  if ((($41|0) == 3)) {
   $$phi$trans$insert$i8 = HEAP32[$38>>2]|0;
   $$in = $$phi$trans$insert$i8;
   label = 20;
  } else if ((($41|0) == 2)) {
   $42 = HEAP32[$38>>2]|0;
   $43 = (($42) + 2417|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($44<<24>>24)==(0);
   if ($45) {
    label = 19;
   } else {
    $$in = $42;
    label = 20;
   }
  } else {
   label = 19;
  }
  if ((label|0) == 19) {
   $46 = (($38) + 12|0);
   __ZN5physx2Sc18ParticleSystemCore14resetFilteringEv($46);
   STACKTOP = sp;return;
  }
  else if ((label|0) == 20) {
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($$in,$38);
   $47 = HEAP32[$39>>2]|0;
   $48 = $47 | 65536;
   $$c = $48;
   HEAP32[$39>>2] = $$c;
   STACKTOP = sp;return;
  }
  break;
 }
 case 6:  {
  $3 = (($actor) + 48|0);
  (__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($actor,$3,0,0)|0);
  STACKTOP = sp;return;
  break;
 }
 case 11:  {
  $27 = (($actor) + 20|0);
  $28 = (($27) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $29 >>> 30;
  if ((($30|0) == 2)) {
   $31 = HEAP32[$27>>2]|0;
   $32 = (($31) + 2417|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    label = 14;
   } else {
    $$in11 = $31;
    label = 15;
   }
  } else if ((($30|0) == 3)) {
   $$phi$trans$insert$i110 = HEAP32[$27>>2]|0;
   $$in11 = $$phi$trans$insert$i110;
   label = 15;
  } else {
   label = 14;
  }
  if ((label|0) == 14) {
   $35 = (($27) + 12|0);
   __ZN5physx2Sc18ParticleSystemCore14resetFilteringEv($35);
   STACKTOP = sp;return;
  }
  else if ((label|0) == 15) {
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($$in11,$27);
   $36 = HEAP32[$28>>2]|0;
   $37 = $36 | 65536;
   $$c9 = $37;
   HEAP32[$28>>2] = $$c9;
   STACKTOP = sp;return;
  }
  break;
 }
 case 15:  {
  $24 = (($actor) + 48|0);
  (__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($actor,$24,0,0)|0);
  $25 = (($actor) + 288|0);
  $26 = HEAP32[$25>>2]|0;
  __ZN5physx14NpArticulation14wakeUpInternalEbb($26,0,1);
  STACKTOP = sp;return;
  break;
 }
 default: {
  $49 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($49,4,430616,1750,432136,$vararg_buffer);
  STACKTOP = sp;return;
 }
 }
}
function __ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($this,$ro,$shapes,$shapeCount) {
 $this = $this|0;
 $ro = $ro|0;
 $shapes = $shapes|0;
 $shapeCount = $shapeCount|0;
 var $$in = 0, $$mask = 0, $$mask3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond12 = 0, $i1$05 = 0, $i3$09 = 0, $sAccepted$06 = 0, $sAccepted$1 = 0, $sAccepted2$08 = 0, $sAccepted2$1 = 0, $sCount$0 = 0, $sCount$1 = 0, $scbShapes = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scbShapes = sp;
 $0 = sp + 8|0;
 $1 = ($shapes|0)!=(0|0);
 if ($1) {
  $sCount$0 = $shapeCount;
 } else {
  $2 = (($this) + 24|0);
  $3 = HEAP16[$2>>1]|0;
  $4 = $3&65535;
  $sCount$0 = $4;
 }
 $5 = $scbShapes;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = $sCount$0 << 2;
 $10 = ($9>>>0)>(1024);
 $11 = (($scbShapes) + 4|0);
 $12 = $10&1;
 HEAP8[$11>>0] = $12;
 if ($10) {
  $14 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$9,434104,393)|0);
  HEAP32[$scbShapes>>2] = $14;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $65 = $scbShapes;
  } else {
   $24 = $scbShapes;
   label = 6;
  }
 } else {
  $13 = STACKTOP; STACKTOP = STACKTOP + ((((1*$9)|0)+15)&-16)|0;;
  HEAP32[$scbShapes>>2] = $13;
  $24 = $scbShapes;
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   if ($1) {
    $16 = ($sCount$0|0)==(0);
    if ($16) {
     $65 = $24;
     break;
    } else {
     $i1$05 = 0;$sAccepted$06 = 0;
    }
    while(1) {
     $17 = (($shapes) + ($i1$05<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + 32|0);
     $20 = (($19) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $$mask3 = $21 & -1073741824;
     $22 = ($$mask3|0)==(1073741824);
     if ($22) {
      $sAccepted$1 = $sAccepted$06;
     } else {
      $23 = HEAP32[$24>>2]|0;
      $25 = (($23) + ($i1$05<<2)|0);
      HEAP32[$25>>2] = $19;
      $26 = (($sAccepted$06) + 1)|0;
      $sAccepted$1 = $26;
     }
     $27 = (($i1$05) + 1)|0;
     $exitcond = ($27|0)==($sCount$0|0);
     if ($exitcond) {
      $sCount$1 = $sAccepted$1;
      break;
     } else {
      $i1$05 = $27;$sAccepted$06 = $sAccepted$1;
     }
    }
   } else {
    $28 = (($this) + 20|0);
    $29 = (($this) + 24|0);
    $30 = HEAP16[$29>>1]|0;
    $31 = ($30<<16>>16)==(1);
    if ($31) {
     $35 = $28;
    } else {
     $32 = HEAP32[$28>>2]|0;
     $35 = $32;
    }
    $33 = ($sCount$0|0)==(0);
    if ($33) {
     $65 = $24;
     break;
    } else {
     $i3$09 = 0;$sAccepted2$08 = 0;
    }
    while(1) {
     $34 = (($35) + ($i3$09<<2)|0);
     $36 = HEAP32[$34>>2]|0;
     $37 = (($36) + 32|0);
     $38 = (($36) + 36|0);
     $39 = HEAP32[$38>>2]|0;
     $$mask = $39 & -1073741824;
     $40 = ($$mask|0)==(1073741824);
     if ($40) {
      $sAccepted2$1 = $sAccepted2$08;
     } else {
      $41 = $39 & 64;
      $42 = ($41|0)==(0);
      if ($42) {
       $52 = (($36) + 112|0);
       $$in = $52;
      } else {
       $43 = (($36) + 40|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ($44|0)==(0|0);
       if ($45) {
        $46 = HEAP32[$37>>2]|0;
        $47 = $39 >>> 24;
        $48 = $47 & 15;
        $49 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($46,$48)|0);
        HEAP32[$43>>2] = $49;
        $51 = $49;
       } else {
        $51 = $44;
       }
       $50 = (($51) + 116|0);
       $$in = $50;
      }
      $53 = HEAP8[$$in>>0]|0;
      $54 = $53 & 5;
      $55 = ($54<<24>>24)==(0);
      if ($55) {
       $sAccepted2$1 = $sAccepted2$08;
      } else {
       $56 = HEAP32[$24>>2]|0;
       $57 = (($56) + ($sAccepted2$08<<2)|0);
       HEAP32[$57>>2] = $37;
       $58 = (($sAccepted2$08) + 1)|0;
       $sAccepted2$1 = $58;
      }
     }
     $59 = (($i3$09) + 1)|0;
     $exitcond12 = ($59|0)==($sCount$0|0);
     if ($exitcond12) {
      $sCount$1 = $sAccepted2$1;
      break;
     } else {
      $i3$09 = $59;$sAccepted2$08 = $sAccepted2$1;
     }
    }
   }
   $60 = ($sCount$1|0)==(0);
   if ($60) {
    $65 = $24;
   } else {
    $61 = HEAP32[$24>>2]|0;
    __ZN5physx3Scb11RigidObject14resetFilteringEPKPNS0_5ShapeEj($ro,$61,$sCount$1);
    $65 = $24;
   }
  }
 } while(0);
 $62 = HEAP8[$11>>0]|0;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  STACKTOP = sp;return 1;
 }
 $64 = HEAP32[$65>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($scbShapes,$64);
 STACKTOP = sp;return 1;
}
function __ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($this,$ro,$shapes,$shapeCount) {
 $this = $this|0;
 $ro = $ro|0;
 $shapes = $shapes|0;
 $shapeCount = $shapeCount|0;
 var $$in = 0, $$mask = 0, $$mask3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond12 = 0, $i1$05 = 0, $i3$09 = 0, $sAccepted$06 = 0, $sAccepted$1 = 0, $sAccepted2$08 = 0, $sAccepted2$1 = 0, $sCount$0 = 0, $sCount$1 = 0, $scbShapes = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scbShapes = sp;
 $0 = sp + 8|0;
 $1 = ($shapes|0)!=(0|0);
 if ($1) {
  $sCount$0 = $shapeCount;
 } else {
  $2 = (($this) + 24|0);
  $3 = HEAP16[$2>>1]|0;
  $4 = $3&65535;
  $sCount$0 = $4;
 }
 $5 = $scbShapes;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = $sCount$0 << 2;
 $10 = ($9>>>0)>(1024);
 $11 = (($scbShapes) + 4|0);
 $12 = $10&1;
 HEAP8[$11>>0] = $12;
 if ($10) {
  $14 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$9,434104,393)|0);
  HEAP32[$scbShapes>>2] = $14;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $65 = $scbShapes;
  } else {
   $24 = $scbShapes;
   label = 6;
  }
 } else {
  $13 = STACKTOP; STACKTOP = STACKTOP + ((((1*$9)|0)+15)&-16)|0;;
  HEAP32[$scbShapes>>2] = $13;
  $24 = $scbShapes;
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   if ($1) {
    $16 = ($sCount$0|0)==(0);
    if ($16) {
     $65 = $24;
     break;
    } else {
     $i1$05 = 0;$sAccepted$06 = 0;
    }
    while(1) {
     $17 = (($shapes) + ($i1$05<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + 32|0);
     $20 = (($19) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $$mask3 = $21 & -1073741824;
     $22 = ($$mask3|0)==(1073741824);
     if ($22) {
      $sAccepted$1 = $sAccepted$06;
     } else {
      $23 = HEAP32[$24>>2]|0;
      $25 = (($23) + ($i1$05<<2)|0);
      HEAP32[$25>>2] = $19;
      $26 = (($sAccepted$06) + 1)|0;
      $sAccepted$1 = $26;
     }
     $27 = (($i1$05) + 1)|0;
     $exitcond = ($27|0)==($sCount$0|0);
     if ($exitcond) {
      $sCount$1 = $sAccepted$1;
      break;
     } else {
      $i1$05 = $27;$sAccepted$06 = $sAccepted$1;
     }
    }
   } else {
    $28 = (($this) + 20|0);
    $29 = (($this) + 24|0);
    $30 = HEAP16[$29>>1]|0;
    $31 = ($30<<16>>16)==(1);
    if ($31) {
     $35 = $28;
    } else {
     $32 = HEAP32[$28>>2]|0;
     $35 = $32;
    }
    $33 = ($sCount$0|0)==(0);
    if ($33) {
     $65 = $24;
     break;
    } else {
     $i3$09 = 0;$sAccepted2$08 = 0;
    }
    while(1) {
     $34 = (($35) + ($i3$09<<2)|0);
     $36 = HEAP32[$34>>2]|0;
     $37 = (($36) + 32|0);
     $38 = (($36) + 36|0);
     $39 = HEAP32[$38>>2]|0;
     $$mask = $39 & -1073741824;
     $40 = ($$mask|0)==(1073741824);
     if ($40) {
      $sAccepted2$1 = $sAccepted2$08;
     } else {
      $41 = $39 & 64;
      $42 = ($41|0)==(0);
      if ($42) {
       $52 = (($36) + 112|0);
       $$in = $52;
      } else {
       $43 = (($36) + 40|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ($44|0)==(0|0);
       if ($45) {
        $46 = HEAP32[$37>>2]|0;
        $47 = $39 >>> 24;
        $48 = $47 & 15;
        $49 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($46,$48)|0);
        HEAP32[$43>>2] = $49;
        $51 = $49;
       } else {
        $51 = $44;
       }
       $50 = (($51) + 116|0);
       $$in = $50;
      }
      $53 = HEAP8[$$in>>0]|0;
      $54 = $53 & 5;
      $55 = ($54<<24>>24)==(0);
      if ($55) {
       $sAccepted2$1 = $sAccepted2$08;
      } else {
       $56 = HEAP32[$24>>2]|0;
       $57 = (($56) + ($sAccepted2$08<<2)|0);
       HEAP32[$57>>2] = $37;
       $58 = (($sAccepted2$08) + 1)|0;
       $sAccepted2$1 = $58;
      }
     }
     $59 = (($i3$09) + 1)|0;
     $exitcond12 = ($59|0)==($sCount$0|0);
     if ($exitcond12) {
      $sCount$1 = $sAccepted2$1;
      break;
     } else {
      $i3$09 = $59;$sAccepted2$08 = $sAccepted2$1;
     }
    }
   }
   $60 = ($sCount$1|0)==(0);
   if ($60) {
    $65 = $24;
   } else {
    $61 = HEAP32[$24>>2]|0;
    __ZN5physx3Scb11RigidObject14resetFilteringEPKPNS0_5ShapeEj($ro,$61,$sCount$1);
    $65 = $24;
   }
  }
 } while(0);
 $62 = HEAP8[$11>>0]|0;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  STACKTOP = sp;return 1;
 }
 $64 = HEAP32[$65>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($scbShapes,$64);
 STACKTOP = sp;return 1;
}
function __ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($this,$ro,$shapes,$shapeCount) {
 $this = $this|0;
 $ro = $ro|0;
 $shapes = $shapes|0;
 $shapeCount = $shapeCount|0;
 var $$in = 0, $$mask = 0, $$mask3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond12 = 0, $i1$05 = 0, $i3$09 = 0, $sAccepted$06 = 0, $sAccepted$1 = 0, $sAccepted2$08 = 0, $sAccepted2$1 = 0, $sCount$0 = 0, $sCount$1 = 0, $scbShapes = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scbShapes = sp;
 $0 = sp + 8|0;
 $1 = ($shapes|0)!=(0|0);
 if ($1) {
  $sCount$0 = $shapeCount;
 } else {
  $2 = (($this) + 24|0);
  $3 = HEAP16[$2>>1]|0;
  $4 = $3&65535;
  $sCount$0 = $4;
 }
 $5 = $scbShapes;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = $sCount$0 << 2;
 $10 = ($9>>>0)>(1024);
 $11 = (($scbShapes) + 4|0);
 $12 = $10&1;
 HEAP8[$11>>0] = $12;
 if ($10) {
  $14 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$9,434104,393)|0);
  HEAP32[$scbShapes>>2] = $14;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $65 = $scbShapes;
  } else {
   $24 = $scbShapes;
   label = 6;
  }
 } else {
  $13 = STACKTOP; STACKTOP = STACKTOP + ((((1*$9)|0)+15)&-16)|0;;
  HEAP32[$scbShapes>>2] = $13;
  $24 = $scbShapes;
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   if ($1) {
    $16 = ($sCount$0|0)==(0);
    if ($16) {
     $65 = $24;
     break;
    } else {
     $i1$05 = 0;$sAccepted$06 = 0;
    }
    while(1) {
     $17 = (($shapes) + ($i1$05<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + 32|0);
     $20 = (($19) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $$mask3 = $21 & -1073741824;
     $22 = ($$mask3|0)==(1073741824);
     if ($22) {
      $sAccepted$1 = $sAccepted$06;
     } else {
      $23 = HEAP32[$24>>2]|0;
      $25 = (($23) + ($i1$05<<2)|0);
      HEAP32[$25>>2] = $19;
      $26 = (($sAccepted$06) + 1)|0;
      $sAccepted$1 = $26;
     }
     $27 = (($i1$05) + 1)|0;
     $exitcond = ($27|0)==($sCount$0|0);
     if ($exitcond) {
      $sCount$1 = $sAccepted$1;
      break;
     } else {
      $i1$05 = $27;$sAccepted$06 = $sAccepted$1;
     }
    }
   } else {
    $28 = (($this) + 20|0);
    $29 = (($this) + 24|0);
    $30 = HEAP16[$29>>1]|0;
    $31 = ($30<<16>>16)==(1);
    if ($31) {
     $35 = $28;
    } else {
     $32 = HEAP32[$28>>2]|0;
     $35 = $32;
    }
    $33 = ($sCount$0|0)==(0);
    if ($33) {
     $65 = $24;
     break;
    } else {
     $i3$09 = 0;$sAccepted2$08 = 0;
    }
    while(1) {
     $34 = (($35) + ($i3$09<<2)|0);
     $36 = HEAP32[$34>>2]|0;
     $37 = (($36) + 32|0);
     $38 = (($36) + 36|0);
     $39 = HEAP32[$38>>2]|0;
     $$mask = $39 & -1073741824;
     $40 = ($$mask|0)==(1073741824);
     if ($40) {
      $sAccepted2$1 = $sAccepted2$08;
     } else {
      $41 = $39 & 64;
      $42 = ($41|0)==(0);
      if ($42) {
       $52 = (($36) + 112|0);
       $$in = $52;
      } else {
       $43 = (($36) + 40|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ($44|0)==(0|0);
       if ($45) {
        $46 = HEAP32[$37>>2]|0;
        $47 = $39 >>> 24;
        $48 = $47 & 15;
        $49 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($46,$48)|0);
        HEAP32[$43>>2] = $49;
        $51 = $49;
       } else {
        $51 = $44;
       }
       $50 = (($51) + 116|0);
       $$in = $50;
      }
      $53 = HEAP8[$$in>>0]|0;
      $54 = $53 & 5;
      $55 = ($54<<24>>24)==(0);
      if ($55) {
       $sAccepted2$1 = $sAccepted2$08;
      } else {
       $56 = HEAP32[$24>>2]|0;
       $57 = (($56) + ($sAccepted2$08<<2)|0);
       HEAP32[$57>>2] = $37;
       $58 = (($sAccepted2$08) + 1)|0;
       $sAccepted2$1 = $58;
      }
     }
     $59 = (($i3$09) + 1)|0;
     $exitcond12 = ($59|0)==($sCount$0|0);
     if ($exitcond12) {
      $sCount$1 = $sAccepted2$1;
      break;
     } else {
      $i3$09 = $59;$sAccepted2$08 = $sAccepted2$1;
     }
    }
   }
   $60 = ($sCount$1|0)==(0);
   if ($60) {
    $65 = $24;
   } else {
    $61 = HEAP32[$24>>2]|0;
    __ZN5physx3Scb11RigidObject14resetFilteringEPKPNS0_5ShapeEj($ro,$61,$sCount$1);
    $65 = $24;
   }
  }
 } while(0);
 $62 = HEAP8[$11>>0]|0;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  STACKTOP = sp;return 1;
 }
 $64 = HEAP32[$65>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($scbShapes,$64);
 STACKTOP = sp;return 1;
}
function __ZN5physx7NpScene14resetFilteringERNS_12PxRigidActorEPKPNS_7PxShapeEj($this,$actor,$shapes,$shapeCount) {
 $this = $this|0;
 $actor = $actor|0;
 $shapes = $shapes|0;
 $shapeCount = $shapeCount|0;
 var $$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($actor) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 if ((($2|0) == 15)) {
  $24 = (($actor) + 48|0);
  (__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($actor,$24,$shapes,$shapeCount)|0);
  $25 = (($actor) + 288|0);
  $26 = HEAP32[$25>>2]|0;
  __ZN5physx14NpArticulation14wakeUpInternalEbb($26,0,1);
  STACKTOP = sp;return;
 } else if ((($2|0) == 6)) {
  $3 = (($actor) + 48|0);
  (__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($actor,$3,$shapes,$shapeCount)|0);
  STACKTOP = sp;return;
 } else if ((($2|0) == 5)) {
  $4 = (($actor) + 48|0);
  (__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE14resetFilteringERNS_3Scb11RigidObjectEPKPNS_7PxShapeEj($actor,$4,$shapes,$shapeCount)|0);
  $5 = (($actor) + 284|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 & 4096;
  $8 = ($7|0)==(0);
  if ($8) {
   $20 = (($actor) + 108|0);
   $$in$i = $20;
  } else {
   $9 = (($actor) + 56|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $12 = HEAP32[$4>>2]|0;
    $13 = (($actor) + 52|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 >>> 24;
    $16 = $15 & 15;
    $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$16)|0);
    HEAP32[$9>>2] = $17;
    $19 = $17;
   } else {
    $19 = $10;
   }
   $18 = (($19) + 268|0);
   $$in$i = $18;
  }
  $21 = HEAP8[$$in$i>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if (!($23)) {
   STACKTOP = sp;return;
  }
  __ZN5physx14NpRigidDynamic29wakeUpInternalNoKinematicTestERNS_3Scb4BodyEbb($actor,$4,0,1);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene10getPhysicsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx7NpScene8simulateEfPNS_10PxBaseTaskEPvjb($this,$_elapsedTime,$completionTask,$scratchBlock,$scratchBlockSize,$controlSimulation) {
 $this = $this|0;
 $_elapsedTime = Math_fround($_elapsedTime);
 $completionTask = $completionTask|0;
 $scratchBlock = $scratchBlock|0;
 $scratchBlockSize = $scratchBlockSize|0;
 $controlSimulation = $controlSimulation|0;
 var $$pre = 0, $$pre$phi4Z2D = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[((545696 + 2|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 $$pre = (($this) + 1216|0);
 if (!($1)) {
  $2 = HEAP32[$$pre>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($this) + 1208|0);
   $5 = HEAP32[$2>>2]|0;
   $6 = (($5) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP16[545696>>1]|0;
   $9 = $4;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + 4)|0;
   $13 = $12;
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_viiiii[$7 & 255]($2,$8,$11,$14,99999789);
  }
 }
 __ZN5physx7NpScene9visualizeEv($this);
 $15 = (($this) + 3656|0);
 HEAP8[$15>>0] = 1;
 $16 = (($this) + 3657|0);
 HEAP8[$16>>0] = 1;
 $17 = (($this) + 3658|0);
 HEAP8[$17>>0] = 1;
 $18 = (($this) + 3660|0);
 HEAPF32[$18>>2] = $_elapsedTime;
 $19 = (($this) + 3848|0);
 HEAP8[$19>>0] = 1;
 $20 = (($this) + 16|0);
 $21 = HEAP32[$$pre>>2]|0;
 $22 = (($this) + 1208|0);
 $23 = $22;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$21>>2]|0;
 $30 = (($29) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_viiii[$31 & 511]($21,61,$25,$28);
 $32 = (($this) + 3528|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 if (!($34)) {
  $35 = (($this) + 3524|0);
  $i$01$i = 0;
  while(1) {
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + ($i$01$i<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   __ZN5physx12NpConstraint15updateConstantsEv($38);
   $39 = (($i$01$i) + 1)|0;
   $40 = HEAP32[$32>>2]|0;
   $41 = ($39>>>0)<($40>>>0);
   if ($41) {
    $i$01$i = $39;
   } else {
    break;
   }
  }
 }
 $42 = HEAP32[$21>>2]|0;
 $43 = (($42) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_viiii[$44 & 511]($21,61,$25,$28);
 $45 = HEAP32[$this>>2]|0;
 $46 = (($45) + 28|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (FUNCTION_TABLE_ii[$47 & 4095]($this)|0);
 $49 = (($48) + 52|0);
 $50 = HEAP32[$49>>2]|0;
 __ZN5physx3Scb5Scene22updateLowLevelMaterialEPPNS_10NpMaterialE($20,$50);
 __ZN5physx3Scb5Scene26preSimulateUpdateAppThreadEf($20,$_elapsedTime);
 $51 = (($this) + 2432|0);
 HEAP8[$51>>0] = 1;
 $52 = (($this) + 2433|0);
 HEAP8[$52>>0] = 1;
 $53 = (($this) + 32|0);
 __ZN5physx2Sc5Scene15setScratchBlockEPvj($53,$scratchBlock,$scratchBlockSize);
 $54 = HEAP32[$$pre>>2]|0;
 $55 = $22;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$54>>2]|0;
 $62 = (($61) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_viiii[$63 & 511]($54,62,$57,$60);
 if ($controlSimulation) {
  $64 = HEAP32[$$pre>>2]|0;
  $65 = $22;
  $66 = $65;
  $67 = HEAP32[$66>>2]|0;
  $68 = (($65) + 4)|0;
  $69 = $68;
  $70 = HEAP32[$69>>2]|0;
  $71 = HEAP32[$64>>2]|0;
  $72 = (($71) + 8|0);
  $73 = HEAP32[$72>>2]|0;
  FUNCTION_TABLE_viiii[$73 & 511]($64,63,$67,$70);
  $74 = (($this) + 3680|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = HEAP32[$75>>2]|0;
  $77 = (($76) + 28|0);
  $78 = HEAP32[$77>>2]|0;
  FUNCTION_TABLE_vi[$78 & 4095]($75);
  $79 = HEAP32[$64>>2]|0;
  $80 = (($79) + 12|0);
  $81 = HEAP32[$80>>2]|0;
  FUNCTION_TABLE_viiii[$81 & 511]($64,63,$67,$70);
  $82 = HEAP32[$74>>2]|0;
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + 32|0);
  $85 = HEAP32[$84>>2]|0;
  FUNCTION_TABLE_vi[$85 & 4095]($82);
  $$pre$phi4Z2D = $74;
 } else {
  $$pre3 = (($this) + 3680|0);
  $$pre$phi4Z2D = $$pre3;
 }
 $86 = (($this) + 3816|0);
 $87 = $controlSimulation&1;
 HEAP8[$86>>0] = $87;
 $88 = (($this) + 3684|0);
 $89 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $90 = (($this) + 3700|0);
 HEAP32[$90>>2] = 1;
 $91 = (($this) + 3696|0);
 HEAP32[$91>>2] = $completionTask;
 $92 = (($this) + 3692|0);
 HEAP32[$92>>2] = $89;
 $93 = ($completionTask|0)==(0|0);
 if ($93) {
  $97 = (($this) + 3732|0);
  $98 = HEAP32[$$pre$phi4Z2D>>2]|0;
  $99 = (($this) + 3748|0);
  HEAP32[$99>>2] = 1;
  $100 = (($this) + 3744|0);
  HEAP32[$100>>2] = $88;
  $101 = (($this) + 3740|0);
  HEAP32[$101>>2] = $98;
  $102 = HEAP32[$88>>2]|0;
  $103 = (($102) + 16|0);
  $104 = HEAP32[$103>>2]|0;
  FUNCTION_TABLE_vi[$104 & 4095]($88);
  $105 = HEAP32[$88>>2]|0;
  $106 = (($105) + 20|0);
  $107 = HEAP32[$106>>2]|0;
  FUNCTION_TABLE_vi[$107 & 4095]($88);
  $108 = HEAP32[$97>>2]|0;
  $109 = (($108) + 20|0);
  $110 = HEAP32[$109>>2]|0;
  FUNCTION_TABLE_vi[$110 & 4095]($97);
  $111 = HEAP32[$54>>2]|0;
  $112 = (($111) + 12|0);
  $113 = HEAP32[$112>>2]|0;
  FUNCTION_TABLE_viiii[$113 & 511]($54,62,$57,$60);
  STACKTOP = sp;return;
 }
 $94 = HEAP32[$completionTask>>2]|0;
 $95 = (($94) + 16|0);
 $96 = HEAP32[$95>>2]|0;
 FUNCTION_TABLE_vi[$96 & 4095]($completionTask);
 $97 = (($this) + 3732|0);
 $98 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $99 = (($this) + 3748|0);
 HEAP32[$99>>2] = 1;
 $100 = (($this) + 3744|0);
 HEAP32[$100>>2] = $88;
 $101 = (($this) + 3740|0);
 HEAP32[$101>>2] = $98;
 $102 = HEAP32[$88>>2]|0;
 $103 = (($102) + 16|0);
 $104 = HEAP32[$103>>2]|0;
 FUNCTION_TABLE_vi[$104 & 4095]($88);
 $105 = HEAP32[$88>>2]|0;
 $106 = (($105) + 20|0);
 $107 = HEAP32[$106>>2]|0;
 FUNCTION_TABLE_vi[$107 & 4095]($88);
 $108 = HEAP32[$97>>2]|0;
 $109 = (($108) + 20|0);
 $110 = HEAP32[$109>>2]|0;
 FUNCTION_TABLE_vi[$110 & 4095]($97);
 $111 = HEAP32[$54>>2]|0;
 $112 = (($111) + 12|0);
 $113 = HEAP32[$112>>2]|0;
 FUNCTION_TABLE_viiii[$113 & 511]($54,62,$57,$60);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene5solveEfPNS_10PxBaseTaskEPvjb($this,$_elapsedTime,$completionTask,$scratchBlock,$scratchBlockSize,$controlSimulation) {
 $this = $this|0;
 $_elapsedTime = Math_fround($_elapsedTime);
 $completionTask = $completionTask|0;
 $scratchBlock = $scratchBlock|0;
 $scratchBlockSize = $scratchBlockSize|0;
 $controlSimulation = $controlSimulation|0;
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($0,32,430616,2017,432224,$vararg_buffer);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene7collideEfPNS_10PxBaseTaskEPvj($this,$_elapsedTime,$completionTask,$scratchBlock,$scratchBlockSize) {
 $this = $this|0;
 $_elapsedTime = Math_fround($_elapsedTime);
 $completionTask = $completionTask|0;
 $scratchBlock = $scratchBlock|0;
 $scratchBlockSize = $scratchBlockSize|0;
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($0,32,430616,2062,432224,$vararg_buffer);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene12checkResultsEb($this,$block) {
 $this = $this|0;
 $block = $block|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret$0$in$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1208|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 511]($1,46,$5,$8);
 $12 = (($this) + 3648|0);
 $13 = HEAP32[$12>>2]|0;
 if ($block) {
  $14 = (__ZN5physx6shdfnd8SyncImpl4waitEj($13,-1)|0);
  $ret$0$in$i = $14;
 } else {
  $15 = (__ZN5physx6shdfnd8SyncImpl4waitEj($13,0)|0);
  $ret$0$in$i = $15;
 }
 $16 = HEAP32[$1>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_viiii[$18 & 511]($1,46,$5,$8);
 STACKTOP = sp;return ($ret$0$in$i|0);
}
function __ZN5physx7NpScene14checkCollisionEb($this,$block) {
 $this = $this|0;
 $block = $block|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret$0$in$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1208|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 511]($1,46,$5,$8);
 $12 = (($this) + 3652|0);
 $13 = HEAP32[$12>>2]|0;
 if ($block) {
  $14 = (__ZN5physx6shdfnd8SyncImpl4waitEj($13,-1)|0);
  $ret$0$in$i = $14;
 } else {
  $15 = (__ZN5physx6shdfnd8SyncImpl4waitEj($13,0)|0);
  $ret$0$in$i = $15;
 }
 $16 = HEAP32[$1>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_viiii[$18 & 511]($1,46,$5,$8);
 STACKTOP = sp;return ($ret$0$in$i|0);
}
function __ZN5physx7NpScene20fireCallBacksPreSyncEv($this) {
 $this = $this|0;
 var $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond14 = 0, $flags = 0, $i$010 = 0, $j$08 = 0, $outputWarning$0$off0$lcssa = 0, $outputWarning$0$off011 = 0, $outputWarning$1$off09 = 0;
 var $outputWarning$2$off0 = 0, $outputWarning$3$off0 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $flags = sp + 8|0;
 $0 = (($this) + 1216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1208|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 511]($1,110,$5,$8);
 $12 = (($this) + 32|0);
 $13 = (__ZN5physx2Sc5Scene24fireOutOfBoundsCallbacksEv($12)|0);
 $14 = (__ZN5physx2Sc5Scene24getOutOfBoundsAggregatesEv($12)|0);
 $15 = (($14) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $outputWarning$0$off0$lcssa = $13;
 } else {
  $i$010 = 0;$outputWarning$0$off011 = $13;
  while(1) {
   $18 = HEAP32[$14>>2]|0;
   $19 = (($18) + ($i$010<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $$mask = $22 & -1073741824;
   $23 = ($$mask|0)==(-1073741824);
   if ($23) {
    $outputWarning$3$off0 = $outputWarning$0$off011;
   } else {
    dest=$flags+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
    $24 = (($20) + 36|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(0);
    if ($26) {
     $outputWarning$3$off0 = $outputWarning$0$off011;
    } else {
     $27 = (($20) + 40|0);
     $j$08 = 0;$outputWarning$1$off09 = $outputWarning$0$off011;
     while(1) {
      $28 = HEAP32[$27>>2]|0;
      $29 = (($28) + ($j$08<<2)|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = HEAP32[$30>>2]|0;
      $32 = (($31) + 68|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
      $35 = $34&255;
      $36 = (($flags) + ($35)|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = ($37<<24>>24)==(0);
      if ($38) {
       HEAP8[$36>>0] = 1;
       $39 = (__ZNK5physx2Sc5Scene21getBroadPhaseCallbackEh($12,$34)|0);
       $40 = ($39|0)==(0|0);
       if ($40) {
        $outputWarning$2$off0 = 1;
       } else {
        $41 = HEAP32[$39>>2]|0;
        $42 = (($41) + 12|0);
        $43 = HEAP32[$42>>2]|0;
        FUNCTION_TABLE_vii[$43 & 4095]($39,$20);
        $outputWarning$2$off0 = $outputWarning$1$off09;
       }
      } else {
       $outputWarning$2$off0 = $outputWarning$1$off09;
      }
      $44 = (($j$08) + 1)|0;
      $exitcond = ($44|0)==($25|0);
      if ($exitcond) {
       $outputWarning$3$off0 = $outputWarning$2$off0;
       break;
      } else {
       $j$08 = $44;$outputWarning$1$off09 = $outputWarning$2$off0;
      }
     }
    }
   }
   $45 = (($i$010) + 1)|0;
   $exitcond14 = ($45|0)==($16|0);
   if ($exitcond14) {
    $outputWarning$0$off0$lcssa = $outputWarning$3$off0;
    break;
   } else {
    $i$010 = $45;$outputWarning$0$off011 = $outputWarning$3$off0;
   }
  }
 }
 HEAP32[$vararg_buffer>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($14,0,$vararg_buffer);
 $46 = HEAP32[$15>>2]|0;
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE8recreateEj($14,$46);
 if (!($outputWarning$0$off0$lcssa)) {
  __ZN5physx2Sc5Scene20fireCallBacksPreSyncEv($12);
  $48 = HEAP32[$1>>2]|0;
  $49 = (($48) + 12|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_viiii[$50 & 511]($1,110,$5,$8);
  STACKTOP = sp;return;
 }
 $47 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($47,2,430616,2212,432264,$vararg_buffer);
 __ZN5physx2Sc5Scene20fireCallBacksPreSyncEv($12);
 $48 = HEAP32[$1>>2]|0;
 $49 = (($48) + 12|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_viiii[$50 & 511]($1,110,$5,$8);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene12fetchResultsEbPj($this,$block,$errorState) {
 $this = $this|0;
 $block = $block|0;
 $errorState = $errorState|0;
 var $$1 = 0, $$in$in = 0, $$pr = 0, $$pr$pre = 0, $$pre = 0, $$pre$phi11Z2D = 0, $$pre$phi7Z2D = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, $ret$0$in$i = 0, $ret$0$in$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3656|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = (($this) + 3658|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    label = 9;
   } else {
    $6 = (($this) + 1216|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($this) + 1208|0);
    $9 = $8;
    $10 = $9;
    $11 = HEAP32[$10>>2]|0;
    $12 = (($9) + 4)|0;
    $13 = $12;
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$7>>2]|0;
    $16 = (($15) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    FUNCTION_TABLE_viiii[$17 & 511]($7,46,$11,$14);
    $18 = (($this) + 3652|0);
    $19 = HEAP32[$18>>2]|0;
    if ($block) {
     $20 = (__ZN5physx6shdfnd8SyncImpl4waitEj($19,-1)|0);
     $ret$0$in$i = $20;
    } else {
     $21 = (__ZN5physx6shdfnd8SyncImpl4waitEj($19,0)|0);
     $ret$0$in$i = $21;
    }
    $22 = HEAP32[$7>>2]|0;
    $23 = (($22) + 12|0);
    $24 = HEAP32[$23>>2]|0;
    FUNCTION_TABLE_viiii[$24 & 511]($7,46,$11,$14);
    if (!($ret$0$in$i)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $$pr$pre = HEAP8[$0>>0]|0;
    $phitmp = ($$pr$pre<<24>>24)==(0);
    if (!($phitmp)) {
     label = 11;
     break;
    }
    $$pr = HEAP8[$3>>0]|0;
    $25 = ($$pr<<24>>24)==(0);
    if ($25) {
     label = 9;
    }
   }
   if ((label|0) == 9) {
    $26 = (($this) + 3657|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
   }
   $$pre = (($this) + 1216|0);
   $$pre8 = (($this) + 1208|0);
   $$pre$phi11Z2D = $$pre8;$$pre$phi7Z2D = $$pre;
  } else {
   label = 11;
  }
 } while(0);
 if ((label|0) == 11) {
  $29 = (($this) + 1216|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($this) + 1208|0);
  $32 = $31;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$30>>2]|0;
  $39 = (($38) + 8|0);
  $40 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_viiii[$40 & 511]($30,46,$34,$37);
  $41 = (($this) + 3648|0);
  $42 = HEAP32[$41>>2]|0;
  if ($block) {
   $43 = (__ZN5physx6shdfnd8SyncImpl4waitEj($42,-1)|0);
   $ret$0$in$i1 = $43;
  } else {
   $44 = (__ZN5physx6shdfnd8SyncImpl4waitEj($42,0)|0);
   $ret$0$in$i1 = $44;
  }
  $45 = HEAP32[$30>>2]|0;
  $46 = (($45) + 12|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_viiii[$47 & 511]($30,46,$34,$37);
  if ($ret$0$in$i1) {
   $$pre$phi11Z2D = $31;$$pre$phi7Z2D = $29;
  } else {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $48 = (($this) + 16|0);
 $49 = HEAP32[$$pre$phi7Z2D>>2]|0;
 $50 = $$pre$phi11Z2D;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 4)|0;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$49>>2]|0;
 $57 = (($56) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_viiii[$58 & 511]($49,47,$52,$55);
 $59 = (($this) + 32|0);
 __ZN5physx2Sc5Scene27prepareOutOfBoundsCallbacksEv($59);
 __ZN5physx3Scb5Scene20processPendingRemoveEv($48);
 __ZN5physx2Sc5Scene13endSimulationEv($59);
 __ZN5physx7NpScene20fireCallBacksPreSyncEv($this);
 __ZN5physx2Sc5Scene20postCallbacksPreSyncEv($59);
 $60 = (($this) + 2432|0);
 HEAP8[$60>>0] = 0;
 $61 = (($this) + 2433|0);
 HEAP8[$61>>0] = 0;
 $62 = HEAP32[$$pre$phi7Z2D>>2]|0;
 $63 = $$pre$phi11Z2D;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = HEAP32[$62>>2]|0;
 $70 = (($69) + 8|0);
 $71 = HEAP32[$70>>2]|0;
 FUNCTION_TABLE_viiii[$71 & 511]($62,113,$65,$68);
 __ZN5physx3Scb5Scene15syncEntireSceneEPj($48,$errorState);
 $72 = HEAP32[$62>>2]|0;
 $73 = (($72) + 12|0);
 $74 = HEAP32[$73>>2]|0;
 FUNCTION_TABLE_viiii[$74 & 511]($62,113,$65,$68);
 $75 = HEAP32[$$pre$phi7Z2D>>2]|0;
 $76 = $$pre$phi11Z2D;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = (($76) + 4)|0;
 $80 = $79;
 $81 = HEAP32[$80>>2]|0;
 $82 = HEAP32[$75>>2]|0;
 $83 = (($82) + 8|0);
 $84 = HEAP32[$83>>2]|0;
 FUNCTION_TABLE_viiii[$84 & 511]($75,111,$78,$81);
 $85 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager17processSimUpdatesEv($85);
 $86 = HEAP32[$75>>2]|0;
 $87 = (($86) + 12|0);
 $88 = HEAP32[$87>>2]|0;
 FUNCTION_TABLE_viiii[$88 & 511]($75,111,$78,$81);
 $89 = HEAP32[$$pre$phi7Z2D>>2]|0;
 $90 = $$pre$phi11Z2D;
 $91 = $90;
 $92 = HEAP32[$91>>2]|0;
 $93 = (($90) + 4)|0;
 $94 = $93;
 $95 = HEAP32[$94>>2]|0;
 $96 = HEAP32[$89>>2]|0;
 $97 = (($96) + 8|0);
 $98 = HEAP32[$97>>2]|0;
 FUNCTION_TABLE_viiii[$98 & 511]($89,112,$92,$95);
 __ZN5physx2Sc5Scene21fireCallBacksPostSyncEv($59);
 $99 = HEAP32[$89>>2]|0;
 $100 = (($99) + 12|0);
 $101 = HEAP32[$100>>2]|0;
 FUNCTION_TABLE_viiii[$101 & 511]($89,112,$92,$95);
 __ZN5physx2Sc5Scene18postReportsCleanupEv($59);
 $102 = HEAP32[$$pre$phi7Z2D>>2]|0;
 $103 = $$pre$phi11Z2D;
 $104 = $103;
 $105 = HEAP32[$104>>2]|0;
 $106 = (($103) + 4)|0;
 $107 = $106;
 $108 = HEAP32[$107>>2]|0;
 $109 = HEAP32[$102>>2]|0;
 $110 = (($109) + 8|0);
 $111 = HEAP32[$110>>2]|0;
 FUNCTION_TABLE_viiii[$111 & 511]($102,114,$105,$108);
 $112 = (($this) + 3372|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = $113 & 4;
 $115 = ($114|0)==(0);
 $116 = (($this) + 3348|0);
 $117 = (($this) + 1232|0);
 $$in$in = $115 ? $117 : $116;
 $118 = HEAP16[$$in$in>>1]|0;
 $119 = $118 & 2;
 $120 = ($119<<16>>16)==(0);
 if (!($120)) {
  __ZN5physx2Sc5Scene21buildActiveTransformsEv($59);
 }
 $121 = HEAP32[$102>>2]|0;
 $122 = (($121) + 12|0);
 $123 = HEAP32[$122>>2]|0;
 FUNCTION_TABLE_viiii[$123 & 511]($102,114,$105,$108);
 $124 = (($this) + 3460|0);
 $125 = (__ZN5physx2Sc5Scene15getRenderBufferEv($59)|0);
 __ZN5physx2Cm12RenderBuffer6appendERKNS_14PxRenderBufferE($124,$125);
 $126 = HEAP8[$0>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if (!($127)) {
  $128 = (($this) + 3816|0);
  $129 = HEAP8[$128>>0]|0;
  $130 = ($129<<24>>24)==(0);
  if (!($130)) {
   $131 = (($this) + 3680|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = HEAP32[$132>>2]|0;
   $134 = (($133) + 36|0);
   $135 = HEAP32[$134>>2]|0;
   FUNCTION_TABLE_vi[$135 & 4095]($132);
  }
 }
 HEAP8[$0>>0] = 0;
 $136 = (($this) + 3657|0);
 HEAP8[$136>>0] = 0;
 $137 = (($this) + 3658|0);
 HEAP8[$137>>0] = 0;
 $138 = (($this) + 3648|0);
 $139 = HEAP32[$138>>2]|0;
 __ZN5physx6shdfnd8SyncImpl5resetEv($139);
 $140 = (($this) + 3652|0);
 $141 = HEAP32[$140>>2]|0;
 __ZN5physx6shdfnd8SyncImpl5resetEv($141);
 $142 = HEAP8[((545696 + 2|0))>>0]|0;
 $143 = ($142<<24>>24)==(0);
 if (!($143)) {
  $144 = HEAP32[$$pre$phi7Z2D>>2]|0;
  $145 = ($144|0)==(0|0);
  if (!($145)) {
   $146 = HEAP32[$144>>2]|0;
   $147 = (($146) + 20|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = HEAP16[545696>>1]|0;
   $150 = $$pre$phi11Z2D;
   $151 = $150;
   $152 = HEAP32[$151>>2]|0;
   $153 = (($150) + 4)|0;
   $154 = $153;
   $155 = HEAP32[$154>>2]|0;
   FUNCTION_TABLE_viiiii[$148 & 255]($144,$149,$152,$155,99999789);
  }
 }
 $156 = HEAP32[$49>>2]|0;
 $157 = (($156) + 12|0);
 $158 = HEAP32[$157>>2]|0;
 FUNCTION_TABLE_viiii[$158 & 511]($49,47,$52,$55);
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx7NpScene15flushSimulationEb($this,$sendPendingReports) {
 $this = $this|0;
 $sendPendingReports = $sendPendingReports|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 3656|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $4 = (($this) + 2504|0);
  HEAP16[$vararg_buffer>>1] = 0;
  __ZN5physx6shdfnd5ArrayItNS0_19ReflectionAllocatorItEEE6resizeEjRKt($4,0,$vararg_buffer);
  $5 = (($this) + 2508|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN5physx6shdfnd5ArrayItNS0_19ReflectionAllocatorItEEE8recreateEj($4,$6);
  $7 = (($this) + 2516|0);
  HEAP32[$vararg_buffer>>2] = 0;
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($7,0,$vararg_buffer);
  $8 = (($this) + 2520|0);
  $9 = HEAP32[$8>>2]|0;
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_19ReflectionAllocatorIS4_EEE8recreateEj($7,$9);
  $10 = (($this) + 2528|0);
  HEAP32[$vararg_buffer>>2] = 0;
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ActorENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($10,0,$vararg_buffer);
  $11 = (($this) + 2532|0);
  $12 = HEAP32[$11>>2]|0;
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ActorENS0_19ReflectionAllocatorIS4_EEE8recreateEj($10,$12);
  $13 = (($this) + 32|0);
  __ZN5physx2Sc5Scene5flushEb($13,$sendPendingReports);
  STACKTOP = sp;return;
 } else {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,2,430616,2341,432400,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene17flushQueryUpdatesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 3656|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $4 = (($this) + 3376|0);
  __ZN5physx2Sq17SceneQueryManager12flushUpdatesEv($4);
  STACKTOP = sp;return;
 } else {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,2,430616,2360,432512,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpScene11addMaterialERNS_10NpMaterialE($this,$mat) {
 $this = $this|0;
 $mat = $mat|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($mat) + 32|0);
 $2 = (__ZN5physx3Scb5Scene11addMaterialERNS_2Sc12MaterialCoreE($0,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx7NpScene14updateMaterialERNS_10NpMaterialE($this,$mat) {
 $this = $this|0;
 $mat = $mat|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($mat) + 32|0);
 __ZN5physx3Scb5Scene14updateMaterialERNS_2Sc12MaterialCoreE($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene14removeMaterialERNS_10NpMaterialE($this,$mat) {
 $this = $this|0;
 $mat = $mat|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($mat) + 32|0);
 __ZN5physx3Scb5Scene14removeMaterialERNS_2Sc12MaterialCoreE($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene21setDominanceGroupPairEhhRKNS_20PxDominanceGroupPairE($this,$group1,$group2,$dominance) {
 $this = $this|0;
 $group1 = $group1|0;
 $group2 = $group2|0;
 $dominance = $dominance|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i$i = 0, $storemerge1$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 2433|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $4 = (($this) + 32|0);
  __ZN5physx2Sc5Scene21setDominanceGroupPairEhhRKNS_20PxDominanceGroupPairE($4,$group1,$group2,$dominance);
  STACKTOP = sp;return;
 }
 $5 = $group1&255;
 $6 = $group2&255;
 $7 = ($group1&255)<($group2&255);
 if ($7) {
  $8 = ((($0) + ($5<<2)|0) + 3064|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = 1 << $6;
  $11 = $9 | $10;
  HEAP32[$8>>2] = $11;
  $$pre$phi$i$iZ2D = $10;
 } else {
  $12 = ((($0) + ($6<<2)|0) + 3064|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = 1 << $5;
  $15 = $13 | $14;
  HEAP32[$12>>2] = $15;
  $$pre$i$i = 1 << $6;
  $$pre$phi$i$iZ2D = $$pre$i$i;
 }
 $16 = Math_fround(HEAPF32[$dominance>>2]);
 $17 = $16 != Math_fround(0.0);
 $18 = ((($0) + ($5<<2)|0) + 3188|0);
 $19 = HEAP32[$18>>2]|0;
 if ($17) {
  $20 = $19 | $$pre$phi$i$iZ2D;
  $storemerge$i$i = $20;
 } else {
  $21 = $$pre$phi$i$iZ2D ^ -1;
  $22 = $19 & $21;
  $storemerge$i$i = $22;
 }
 HEAP32[$18>>2] = $storemerge$i$i;
 $23 = (($dominance) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $24 != Math_fround(0.0);
 $26 = ((($0) + ($6<<2)|0) + 3188|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = 1 << $5;
 if ($25) {
  $29 = $27 | $28;
  $storemerge1$i$i = $29;
 } else {
  $30 = $28 ^ -1;
  $31 = $27 & $30;
  $storemerge1$i$i = $31;
 }
 HEAP32[$26>>2] = $storemerge1$i$i;
 $32 = (($this) + 3372|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 | 8;
 HEAP32[$32>>2] = $34;
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene21getDominanceGroupPairEhh($agg$result,$this,$group1,$group2) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $group1 = $group1|0;
 $group2 = $group2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isBuffered$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 3372|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 8;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = $group1&255;
  $6 = $group2&255;
  $7 = ($group1&255)<($group2&255);
  if ($7) {
   $8 = ((($0) + ($5<<2)|0) + 3064|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = 1 << $6;
   $11 = $9 & $10;
   $isBuffered$0$i$i = $11;
  } else {
   $12 = ((($0) + ($6<<2)|0) + 3064|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = 1 << $5;
   $15 = $13 & $14;
   $isBuffered$0$i$i = $15;
  }
  $16 = ($isBuffered$0$i$i|0)==(0);
  if (!($16)) {
   $17 = ((($0) + ($5<<2)|0) + 3188|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = 1 << $6;
   $20 = $18 & $19;
   $21 = $20 >>> $6;
   $22 = (Math_fround(($21>>>0)));
   $23 = ((($0) + ($6<<2)|0) + 3188|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = 1 << $5;
   $26 = $24 & $25;
   $27 = $26 >>> $5;
   $28 = (Math_fround(($27>>>0)));
   $29 = (HEAPF32[tempDoublePtr>>2]=$22,HEAP32[tempDoublePtr>>2]|0);
   $30 = (HEAPF32[tempDoublePtr>>2]=$28,HEAP32[tempDoublePtr>>2]|0);
   $31 = $agg$result;
   $32 = $31;
   HEAP32[$32>>2] = $29;
   $33 = (($31) + 4)|0;
   $34 = $33;
   HEAP32[$34>>2] = $30;
   STACKTOP = sp;return;
  }
 }
 $35 = (($this) + 32|0);
 __ZNK5physx2Sc5Scene21getDominanceGroupPairEhh($agg$result,$35,$group1,$group2);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene26removeFromParticleBaseListERNS_14PxParticleBaseE($this,$particleBase) {
 $this = $this|0;
 $particleBase = $particleBase|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i = 0, $index$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3628|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 3624|0);
 $4 = HEAP32[$3>>2]|0;
 $index$01$i = 0;
 while(1) {
  $7 = (($4) + ($index$01$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($particleBase|0);
  $6 = (($index$01$i) + 1)|0;
  if ($9) {
   $index$0$lcssa$i = $index$01$i;
   break;
  }
  $5 = ($6>>>0)<($1>>>0);
  if ($5) {
   $index$01$i = $6;
  } else {
   $index$0$lcssa$i = $6;
   break;
  }
 }
 $10 = ($index$0$lcssa$i|0)==($1|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($1) + -1)|0;
 HEAP32[$0>>2] = $11;
 $12 = (($4) + ($11<<2)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($4) + ($index$0$lcssa$i<<2)|0);
 HEAP32[$14>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene17createVolumeCacheEjj($this,$maxStaticShapes,$maxDynamicShapes) {
 $this = $this|0;
 $maxStaticShapes = $maxStaticShapes|0;
 $maxDynamicShapes = $maxDynamicShapes|0;
 var $$$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cache = 0, $exists$i = 0;
 var $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp + 4|0;
 $cache = sp;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 433664 : 433312;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,120,$$$i$i$i,430616,2556)|0);
 $10 = (($this) + 3376|0);
 __ZN5physx13NpVolumeCacheC2EPNS_2Sq17SceneQueryManagerEjj($9,$10,$maxStaticShapes,$maxDynamicShapes);
 HEAP32[$cache>>2] = $9;
 $11 = (($this) + 3572|0);
 $12 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_13NpVolumeCacheES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($11,$cache,$exists$i)|0);
 $13 = HEAP8[$exists$i>>0]|0;
 $14 = ($13<<24>>24)!=(0);
 $15 = ($12|0)==(0|0);
 $or$cond$i = $14 | $15;
 $$pre = HEAP32[$cache>>2]|0;
 if ($or$cond$i) {
  STACKTOP = sp;return ($$pre|0);
 }
 HEAP32[$12>>2] = $$pre;
 STACKTOP = sp;return ($$pre|0);
}
function __ZN5physx7NpScene29setDynamicTreeRebuildRateHintEj($this,$dynamicTreeRebuildRateHint) {
 $this = $this|0;
 $dynamicTreeRebuildRateHint = $dynamicTreeRebuildRateHint|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager29setDynamicTreeRebuildRateHintEj($0,$dynamicTreeRebuildRateHint);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene29getDynamicTreeRebuildRateHintEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3448|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene23forceDynamicTreeRebuildEbb($this,$rebuildStaticStructure,$rebuildDynamicStructure) {
 $this = $this|0;
 $rebuildStaticStructure = $rebuildStaticStructure|0;
 $rebuildDynamicStructure = $rebuildDynamicStructure|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager23forceDynamicTreeRebuildEbb($0,$rebuildStaticStructure,$rebuildDynamicStructure);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene18setSolverBatchSizeEj($this,$solverBatchSize) {
 $this = $this|0;
 $solverBatchSize = $solverBatchSize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene18setSolverBatchSizeEj($3,$solverBatchSize);
  STACKTOP = sp;return;
 } else {
  $4 = (($this) + 3352|0);
  HEAP32[$4>>2] = $solverBatchSize;
  $5 = (($this) + 3372|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 | 16;
  HEAP32[$5>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene18getSolverBatchSizeEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16;
 $3 = ($2|0)==(0);
 if ($3) {
  $6 = (($this) + 32|0);
  $7 = (__ZNK5physx2Sc5Scene18getSolverBatchSizeEv($6)|0);
  $$0$i = $7;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $4 = (($this) + 3352|0);
  $5 = HEAP32[$4>>2]|0;
  $$0$i = $5;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN5physx7NpScene25setVisualizationParameterENS_24PxVisualizationParameter4EnumEf($this,$param,$value) {
 $this = $this|0;
 $param = $param|0;
 $value = Math_fround($value);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = ($param|0)>(36);
 if ($0) {
  $1 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($1,4,430616,2609,432624,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $value < Math_fround(0.0);
 if ($2) {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,4,430616,2614,432680,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 16|0);
 $5 = (($this) + 2433|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc5Scene25setVisualizationParameterENS_24PxVisualizationParameter4EnumEf($8,$param,$value);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $9 = ((($4) + ($param)|0) + 2996|0);
  HEAP8[$9>>0] = 1;
  $10 = ((($4) + ($param<<2)|0) + 2848|0);
  HEAPF32[$10>>2] = $value;
  $11 = (($this) + 3372|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 | 64;
  HEAP32[$11>>2] = $13;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx7NpScene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($this,$param) {
 $this = $this|0;
 $param = $param|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($param|0)<(37);
 if (!($0)) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($13,4,430616,2629,432744,$vararg_buffer);
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $1 = (($this) + 16|0);
 $2 = (($this) + 3372|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 64;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = ((($1) + ($param)|0) + 2996|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   $9 = ((($1) + ($param<<2)|0) + 2848|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $$0 = $10;
   STACKTOP = sp;return (Math_fround($$0));
  }
 }
 $11 = (($this) + 32|0);
 $12 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($11,$param)));
 $$0 = $12;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx7NpScene26setVisualizationCullingBoxERKNS_9PxBounds3E($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2433|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 32|0);
  __ZN5physx2Sc5Scene26setVisualizationCullingBoxERKNS_9PxBounds3E($3,$box);
  STACKTOP = sp;return;
 } else {
  $4 = (($this) + 3076|0);
  HEAP8[$4>>0] = 1;
  $5 = Math_fround(HEAPF32[$box>>2]);
  $6 = (($this) + 3052|0);
  HEAPF32[$6>>2] = $5;
  $7 = (($box) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($this) + 3056|0);
  HEAPF32[$9>>2] = $8;
  $10 = (($box) + 8|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($this) + 3060|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($box) + 12|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($this) + 3064|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($box) + 16|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($this) + 3068|0);
  HEAPF32[$18>>2] = $17;
  $19 = (($box) + 20|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($this) + 3072|0);
  HEAPF32[$21>>2] = $20;
  $22 = (($this) + 3372|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 | 64;
  HEAP32[$22>>2] = $24;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpScene26getVisualizationCullingBoxEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($this) + 3076|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   $7 = (($this) + 3052|0);
   $$0$i = $7;
   STACKTOP = sp;return ($$0$i|0);
  }
 }
 $8 = (($this) + 32|0);
 $9 = (__ZNK5physx2Sc5Scene26getVisualizationCullingBoxEv($8)|0);
 $$0$i = $9;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx7NpScene22setNbContactDataBlocksEj($this,$numBlocks) {
 $this = $this|0;
 $numBlocks = $numBlocks|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN5physx2Sc5Scene22setNbContactDataBlocksEj($0,$numBlocks);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene26getNbContactDataBlocksUsedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene26getNbContactDataBlocksUsedEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene29getMaxNbContactDataBlocksUsedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene29getMaxNbContactDataBlocksUsedEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene12getTimestampEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene28getSceneQueryStaticTimestampEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3396|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene20getMeshContactMarginEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc5Scene20getMeshContactMarginEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx7NpScene16getCpuDispatcherEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 388|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZNK5physx7NpScene16getGpuDispatcherEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 388|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZNK5physx7NpScene16getSpuDispatcherEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 388|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZNK5physx7NpScene18getStaticStructureEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3440|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene19getDynamicStructureEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3444|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx7NpScene29getContactCorrelationDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc5Scene29getContactCorrelationDistanceEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx7NpScene26getFrictionOffsetThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc5Scene26getFrictionOffsetThresholdEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx7NpScene32getContactReportStreamBufferSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc5Scene39getDefaultContactReportStreamBufferSizeEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene8lockReadEPKcj($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 3836|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN5physx6shdfnd6TlsGetEj($3)|0);
 $5 = $4;
 $6 = $5 >>> 16;
 $7 = $6&255;
 $8 = HEAP32[$2>>2]|0;
 $9 = $6 << 16;
 $10 = (($9) + 65536)|0;
 $11 = $10 & 16711680;
 $12 = $5 & -16711681;
 $13 = $12 | $11;
 $14 = $13;
 (__ZN5physx6shdfnd6TlsSetEjPv($8,$14)|0);
 $15 = (($this) + 3840|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__ZN5physx6shdfnd10ThreadImpl5getIdEv()|0);
 $18 = ($16|0)!=($17|0);
 $19 = ($7<<24>>24)==(0);
 $or$cond = $18 & $19;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $20 = (($this) + 3844|0);
 __ZN5physx6shdfnd13ReadWriteLock10lockReaderEv($20);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene10unlockReadEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 3836|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx6shdfnd6TlsGetEj($1)|0);
 $3 = $2;
 $4 = $3 >>> 16;
 $5 = $4&255;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,8,430616,2899,432800,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $8 = (($5) + -1)<<24>>24;
 $9 = HEAP32[$0>>2]|0;
 $10 = $8&255;
 $11 = $10 << 16;
 $12 = $3 & -16711681;
 $13 = $12 | $11;
 $14 = $13;
 (__ZN5physx6shdfnd6TlsSetEjPv($9,$14)|0);
 $15 = (($this) + 3840|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__ZN5physx6shdfnd10ThreadImpl5getIdEv()|0);
 $18 = ($16|0)!=($17|0);
 $19 = ($8<<24>>24)==(0);
 $or$cond = $18 & $19;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $20 = (($this) + 3844|0);
 __ZN5physx6shdfnd13ReadWriteLock12unlockReaderEv($20);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene9lockWriteEPKcj($this,$file,$line) {
 $this = $this|0;
 $file = $file|0;
 $line = $line|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 3836|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx6shdfnd6TlsGetEj($1)|0);
 $3 = $2;
 $4 = $3 >>> 24;
 $5 = $4&255;
 $6 = ($5<<24>>24)!=(0);
 $7 = $3 & 16711680;
 $8 = ($7|0)==(0);
 $or$cond = $6 | $8;
 if (!($or$cond)) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  $10 = ($file|0)!=(0|0);
  $11 = $10 ? $file : 430616;
  $12 = $10 ? $line : 2920;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,$11,$12,432904,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = $4 << 24;
 $15 = (($14) + 16777216)|0;
 $16 = $3 & 16777215;
 $17 = $16 | $15;
 $18 = $17;
 (__ZN5physx6shdfnd6TlsSetEjPv($13,$18)|0);
 $19 = ($5<<24>>24)==(0);
 if ($19) {
  $20 = (($this) + 3844|0);
  __ZN5physx6shdfnd13ReadWriteLock10lockWriterEv($20);
 }
 $21 = (__ZN5physx6shdfnd10ThreadImpl5getIdEv()|0);
 $22 = (($this) + 3840|0);
 HEAP32[$22>>2] = $21;
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene11unlockWriteEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 3836|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx6shdfnd6TlsGetEj($1)|0);
 $3 = $2;
 $4 = $3 >>> 24;
 $5 = $4&255;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,8,430616,2942,433032,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $8 = (($5) + -1)<<24>>24;
 $9 = HEAP32[$0>>2]|0;
 $10 = $8&255;
 $11 = $10 << 24;
 $12 = $3 & 16777215;
 $13 = $11 | $12;
 $14 = $13;
 (__ZN5physx6shdfnd6TlsSetEjPv($9,$14)|0);
 $15 = ($8<<24>>24)==(0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = (($this) + 3840|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 3844|0);
 __ZN5physx6shdfnd13ReadWriteLock12unlockWriterEv($17);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene24getWakeCounterResetValueEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2860|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx7NpScene11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$lcssa$i3$ph = 0, $$lcssa$i3$ph8 = 0, $$ph6 = 0, $$ph7 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0);
 var $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0;
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $exitcond27 = 0, $i$023 = 0, $i1$014 = 0, $i2$010 = 0, $idx$0$lcssa = 0, $idx$024 = 0, $j$020 = 0, $j3$09 = 0, $k$017 = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 16|0);
 $2 = (($this) + 2433|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($5,2,430616,2994,433144,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $6 = (($this) + 1216|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 1208|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$7>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_viiii[$17 & 511]($7,52,$11,$14);
 $18 = (($this) + 3536|0);
 $19 = (($this) + 3540|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 >>> 2;
 $22 = ($21|0)==(0);
 if ($22) {
  $idx$0$lcssa = 0;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($shift) + 4|0);
  $25 = (($shift) + 8|0);
  $i$023 = 0;$idx$024 = 0;
  while(1) {
   $30 = ($i$023>>>0)<($23>>>0);
   $31 = (($idx$024) + 4)|0;
   if ($30) {
    $33 = HEAP32[$18>>2]|0;
    $34 = (($33) + ($31<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = HEAP32[$18>>2]|0;
    $37 = (($36) + ($31<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 128|0);
    $40 = (($idx$024) + 5)|0;
    $41 = HEAP32[$18>>2]|0;
    $42 = (($41) + ($40<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$18>>2]|0;
    $45 = (($44) + ($40<<2)|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + 128|0);
    $48 = (($idx$024) + 6)|0;
    $49 = HEAP32[$18>>2]|0;
    $50 = (($49) + ($48<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = HEAP32[$18>>2]|0;
    $53 = (($52) + ($48<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + 128|0);
    $56 = (($idx$024) + 7)|0;
    $57 = HEAP32[$18>>2]|0;
    $58 = (($57) + ($56<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = HEAP32[$18>>2]|0;
    $61 = (($60) + ($56<<2)|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($62) + 128|0);
    $j$020 = $idx$024;
   } else {
    $32 = ($31>>>0)<($20>>>0);
    if ($32) {
     $k$017 = $31;
     while(1) {
      $64 = HEAP32[$18>>2]|0;
      $65 = (($64) + ($k$017<<2)|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = HEAP32[$18>>2]|0;
      $68 = (($67) + ($k$017<<2)|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($69) + 128|0);
      $71 = (($k$017) + 1)|0;
      $exitcond27 = ($71|0)==($20|0);
      if ($exitcond27) {
       $j$020 = $idx$024;
       break;
      } else {
       $k$017 = $71;
      }
     }
    } else {
     $j$020 = $idx$024;
    }
   }
   while(1) {
    $72 = HEAP32[$18>>2]|0;
    $73 = (($72) + ($j$020<<2)|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = HEAP32[$74>>2]|0;
    $76 = (($75) + 24|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (FUNCTION_TABLE_ii[$77 & 4095]($74)|0);
    if ((($78|0) == 0)) {
     $92 = Math_fround(HEAPF32[$shift>>2]);
     $93 = (($74) + 96|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = Math_fround($94 - $92);
     HEAPF32[$93>>2] = $95;
     $96 = Math_fround(HEAPF32[$24>>2]);
     $97 = (($74) + 100|0);
     $98 = Math_fround(HEAPF32[$97>>2]);
     $99 = Math_fround($98 - $96);
     HEAPF32[$97>>2] = $99;
     $100 = Math_fround(HEAPF32[$25>>2]);
     $101 = (($74) + 104|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = Math_fround($102 - $100);
     HEAPF32[$101>>2] = $103;
    } else if ((($78|0) == 1)) {
     $79 = Math_fround(HEAPF32[$shift>>2]);
     $80 = (($74) + 240|0);
     $81 = Math_fround(HEAPF32[$80>>2]);
     $82 = Math_fround($81 - $79);
     HEAPF32[$80>>2] = $82;
     $83 = Math_fround(HEAPF32[$24>>2]);
     $84 = (($74) + 244|0);
     $85 = Math_fround(HEAPF32[$84>>2]);
     $86 = Math_fround($85 - $83);
     HEAPF32[$84>>2] = $86;
     $87 = Math_fround(HEAPF32[$25>>2]);
     $88 = (($74) + 248|0);
     $89 = Math_fround(HEAPF32[$88>>2]);
     $90 = Math_fround($89 - $87);
     HEAPF32[$88>>2] = $90;
     $91 = (($74) + 64|0);
     __ZN5physx2Sc8BodyCore13onOriginShiftERKNS_6PxVec3E($91,$shift);
    } else {
     $104 = Math_fround(HEAPF32[$shift>>2]);
     $105 = (($74) + 240|0);
     $106 = Math_fround(HEAPF32[$105>>2]);
     $107 = Math_fround($106 - $104);
     HEAPF32[$105>>2] = $107;
     $108 = Math_fround(HEAPF32[$24>>2]);
     $109 = (($74) + 244|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = Math_fround($110 - $108);
     HEAPF32[$109>>2] = $111;
     $112 = Math_fround(HEAPF32[$25>>2]);
     $113 = (($74) + 248|0);
     $114 = Math_fround(HEAPF32[$113>>2]);
     $115 = Math_fround($114 - $112);
     HEAPF32[$113>>2] = $115;
     $116 = (($74) + 64|0);
     __ZN5physx2Sc8BodyCore13onOriginShiftERKNS_6PxVec3E($116,$shift);
    }
    $117 = (($j$020) + 1)|0;
    $118 = ($117>>>0)<($31>>>0);
    if ($118) {
     $j$020 = $117;
    } else {
     break;
    }
   }
   $119 = (($i$023) + 1)|0;
   $120 = ($119>>>0)<($21>>>0);
   if ($120) {
    $i$023 = $119;$idx$024 = $31;
   } else {
    break;
   }
  }
  $26 = $21 << 2;
  $idx$0$lcssa = $26;
 }
 $27 = ($idx$0$lcssa>>>0)<($20>>>0);
 if ($27) {
  $28 = (($shift) + 4|0);
  $29 = (($shift) + 8|0);
  $i1$014 = $idx$0$lcssa;
  while(1) {
   $127 = HEAP32[$18>>2]|0;
   $128 = (($127) + ($i1$014<<2)|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = HEAP32[$129>>2]|0;
   $131 = (($130) + 24|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = (FUNCTION_TABLE_ii[$132 & 4095]($129)|0);
   if ((($133|0) == 0)) {
    $147 = Math_fround(HEAPF32[$shift>>2]);
    $148 = (($129) + 96|0);
    $149 = Math_fround(HEAPF32[$148>>2]);
    $150 = Math_fround($149 - $147);
    HEAPF32[$148>>2] = $150;
    $151 = Math_fround(HEAPF32[$28>>2]);
    $152 = (($129) + 100|0);
    $153 = Math_fround(HEAPF32[$152>>2]);
    $154 = Math_fround($153 - $151);
    HEAPF32[$152>>2] = $154;
    $155 = Math_fround(HEAPF32[$29>>2]);
    $156 = (($129) + 104|0);
    $157 = Math_fround(HEAPF32[$156>>2]);
    $158 = Math_fround($157 - $155);
    HEAPF32[$156>>2] = $158;
   } else if ((($133|0) == 1)) {
    $134 = Math_fround(HEAPF32[$shift>>2]);
    $135 = (($129) + 240|0);
    $136 = Math_fround(HEAPF32[$135>>2]);
    $137 = Math_fround($136 - $134);
    HEAPF32[$135>>2] = $137;
    $138 = Math_fround(HEAPF32[$28>>2]);
    $139 = (($129) + 244|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = Math_fround($140 - $138);
    HEAPF32[$139>>2] = $141;
    $142 = Math_fround(HEAPF32[$29>>2]);
    $143 = (($129) + 248|0);
    $144 = Math_fround(HEAPF32[$143>>2]);
    $145 = Math_fround($144 - $142);
    HEAPF32[$143>>2] = $145;
    $146 = (($129) + 64|0);
    __ZN5physx2Sc8BodyCore13onOriginShiftERKNS_6PxVec3E($146,$shift);
   } else {
    $159 = Math_fround(HEAPF32[$shift>>2]);
    $160 = (($129) + 240|0);
    $161 = Math_fround(HEAPF32[$160>>2]);
    $162 = Math_fround($161 - $159);
    HEAPF32[$160>>2] = $162;
    $163 = Math_fround(HEAPF32[$28>>2]);
    $164 = (($129) + 244|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = Math_fround($165 - $163);
    HEAPF32[$164>>2] = $166;
    $167 = Math_fround(HEAPF32[$29>>2]);
    $168 = (($129) + 248|0);
    $169 = Math_fround(HEAPF32[$168>>2]);
    $170 = Math_fround($169 - $167);
    HEAPF32[$168>>2] = $170;
    $171 = (($129) + 64|0);
    __ZN5physx2Sc8BodyCore13onOriginShiftERKNS_6PxVec3E($171,$shift);
   }
   $172 = (($i1$014) + 1)|0;
   $exitcond = ($172|0)==($20|0);
   if ($exitcond) {
    break;
   } else {
    $i1$014 = $172;
   }
  }
 }
 $121 = (($this) + 3552|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($122|0)==(0);
 if (!($123)) {
  $124 = (($this) + 3548|0);
  $125 = (($shift) + 4|0);
  $126 = (($shift) + 8|0);
  $i2$010 = 0;
  while(1) {
   $173 = HEAP32[$124>>2]|0;
   $174 = (($173) + ($i2$010<<2)|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = (($175) + 88|0);
   $177 = HEAP32[$176>>2]|0;
   $178 = HEAP32[$175>>2]|0;
   $179 = (($178) + 108|0);
   $180 = HEAP32[$179>>2]|0;
   $181 = (FUNCTION_TABLE_ii[$180 & 4095]($175)|0);
   $182 = ($181|0)==(0);
   if (!($182)) {
    $j3$09 = 0;
    while(1) {
     $183 = (($177) + ($j3$09<<2)|0);
     $184 = HEAP32[$183>>2]|0;
     $185 = HEAP32[$184>>2]|0;
     $186 = (($185) + 24|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = (FUNCTION_TABLE_ii[$187 & 4095]($184)|0);
     if ((($188|0) == 0)) {
      $202 = Math_fround(HEAPF32[$shift>>2]);
      $203 = (($184) + 96|0);
      $204 = Math_fround(HEAPF32[$203>>2]);
      $205 = Math_fround($204 - $202);
      HEAPF32[$203>>2] = $205;
      $206 = Math_fround(HEAPF32[$125>>2]);
      $207 = (($184) + 100|0);
      $208 = Math_fround(HEAPF32[$207>>2]);
      $209 = Math_fround($208 - $206);
      HEAPF32[$207>>2] = $209;
      $210 = Math_fround(HEAPF32[$126>>2]);
      $211 = (($184) + 104|0);
      $212 = Math_fround(HEAPF32[$211>>2]);
      $213 = Math_fround($212 - $210);
      HEAPF32[$211>>2] = $213;
     } else if ((($188|0) == 1)) {
      $189 = Math_fround(HEAPF32[$shift>>2]);
      $190 = (($184) + 240|0);
      $191 = Math_fround(HEAPF32[$190>>2]);
      $192 = Math_fround($191 - $189);
      HEAPF32[$190>>2] = $192;
      $193 = Math_fround(HEAPF32[$125>>2]);
      $194 = (($184) + 244|0);
      $195 = Math_fround(HEAPF32[$194>>2]);
      $196 = Math_fround($195 - $193);
      HEAPF32[$194>>2] = $196;
      $197 = Math_fround(HEAPF32[$126>>2]);
      $198 = (($184) + 248|0);
      $199 = Math_fround(HEAPF32[$198>>2]);
      $200 = Math_fround($199 - $197);
      HEAPF32[$198>>2] = $200;
      $201 = (($184) + 64|0);
      __ZN5physx2Sc8BodyCore13onOriginShiftERKNS_6PxVec3E($201,$shift);
     } else {
      $214 = Math_fround(HEAPF32[$shift>>2]);
      $215 = (($184) + 240|0);
      $216 = Math_fround(HEAPF32[$215>>2]);
      $217 = Math_fround($216 - $214);
      HEAPF32[$215>>2] = $217;
      $218 = Math_fround(HEAPF32[$125>>2]);
      $219 = (($184) + 244|0);
      $220 = Math_fround(HEAPF32[$219>>2]);
      $221 = Math_fround($220 - $218);
      HEAPF32[$219>>2] = $221;
      $222 = Math_fround(HEAPF32[$126>>2]);
      $223 = (($184) + 248|0);
      $224 = Math_fround(HEAPF32[$223>>2]);
      $225 = Math_fround($224 - $222);
      HEAPF32[$223>>2] = $225;
      $226 = (($184) + 64|0);
      __ZN5physx2Sc8BodyCore13onOriginShiftERKNS_6PxVec3E($226,$shift);
     }
     $227 = (($j3$09) + 1)|0;
     $228 = HEAP32[$175>>2]|0;
     $229 = (($228) + 108|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = (FUNCTION_TABLE_ii[$230 & 4095]($175)|0);
     $232 = ($227>>>0)<($231>>>0);
     if ($232) {
      $j3$09 = $227;
     } else {
      break;
     }
    }
   }
   $233 = (($i2$010) + 1)|0;
   $234 = HEAP32[$121>>2]|0;
   $235 = ($233>>>0)<($234>>>0);
   if ($235) {
    $i2$010 = $233;
   } else {
    break;
   }
  }
 }
 __ZN5physx3Scb5Scene11shiftOriginERKNS_6PxVec3E($1,$shift);
 $236 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager11shiftOriginERKNS_6PxVec3E($236,$shift);
 $237 = (($this) + 3588|0);
 $238 = HEAP32[$237>>2]|0;
 $239 = ($238|0)==(0);
 $$pre = (($this) + 3584|0);
 L48: do {
  if ($239) {
   $$lcssa$i3$ph = 0;$$ph6 = -1;
  } else {
   $240 = HEAP32[$$pre>>2]|0;
   $241 = HEAP32[$240>>2]|0;
   $242 = ($241|0)==(-1);
   if ($242) {
    $243 = (($this) + 3592|0);
    $244 = HEAP32[$243>>2]|0;
    $246 = 0;
    while(1) {
     $245 = (($246) + 1)|0;
     $247 = ($245|0)==($244|0);
     if ($247) {
      $$lcssa$i3$ph = $244;$$ph6 = -1;
      break L48;
     }
     $248 = (($240) + ($245<<2)|0);
     $249 = HEAP32[$248>>2]|0;
     $250 = ($249|0)==(-1);
     if ($250) {
      $246 = $245;
     } else {
      $$lcssa$i3$ph = $245;$$ph6 = $249;
      break;
     }
    }
   } else {
    $$lcssa$i3$ph = 0;$$ph6 = $241;
   }
  }
 } while(0);
 $251 = (($this) + 3576|0);
 $252 = (($this) + 3580|0);
 $253 = (($this) + 3592|0);
 $$lcssa$i3$ph8 = $$lcssa$i3$ph;$$ph7 = $$ph6;
 L55: while(1) {
  $255 = $$ph7;
  while(1) {
   $254 = ($255|0)==(-1);
   if ($254) {
    break L55;
   }
   $256 = HEAP32[$251>>2]|0;
   $257 = (($256) + ($255<<2)|0);
   $258 = HEAP32[$257>>2]|0;
   __ZN5physx13NpVolumeCache13onOriginShiftERKNS_6PxVec3E($258,$shift);
   $259 = HEAP32[$252>>2]|0;
   $260 = (($259) + ($255<<2)|0);
   $261 = HEAP32[$260>>2]|0;
   $262 = ($261|0)==(-1);
   if ($262) {
    break;
   } else {
    $255 = $261;
   }
  }
  $263 = HEAP32[$253>>2]|0;
  $265 = $$lcssa$i3$ph8;
  while(1) {
   $264 = (($265) + 1)|0;
   $266 = ($264|0)==($263|0);
   if ($266) {
    $$lcssa$i3$ph8 = $263;$$ph7 = -1;
    continue L55;
   }
   $267 = HEAP32[$$pre>>2]|0;
   $268 = (($267) + ($264<<2)|0);
   $269 = HEAP32[$268>>2]|0;
   $270 = ($269|0)==(-1);
   if ($270) {
    $265 = $264;
   } else {
    $$lcssa$i3$ph8 = $264;$$ph7 = $269;
    continue L55;
   }
  }
 }
 $271 = (($this) + 3460|0);
 $272 = Math_fround(HEAPF32[$shift>>2]);
 $273 = Math_fround(-$272);
 $274 = (($shift) + 4|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = Math_fround(-$275);
 $277 = (($shift) + 8|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = Math_fround(-$278);
 HEAPF32[$0>>2] = $273;
 $280 = (($0) + 4|0);
 HEAPF32[$280>>2] = $276;
 $281 = (($0) + 8|0);
 HEAPF32[$281>>2] = $279;
 __ZN5physx2Cm12RenderBuffer5shiftERKNS_6PxVec3E($271,$0);
 $282 = HEAP32[$7>>2]|0;
 $283 = (($282) + 12|0);
 $284 = HEAP32[$283>>2]|0;
 FUNCTION_TABLE_viiii[$284 & 511]($7,52,$11,$14);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene16createBatchQueryERKNS_16PxBatchQueryDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bq = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $bq = sp;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 433464 : 433312;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,152,$$$i$i$i,430616,3145)|0);
 __ZN5physx12NpBatchQueryC2ERNS_7NpSceneERKNS_16PxBatchQueryDescE($9,$this,$desc);
 HEAP32[$bq>>2] = $9;
 $10 = (($this) + 3612|0);
 $11 = (($this) + 3620|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2147483647;
 $14 = (($this) + 3616|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if (!($16)) {
  (__ZN5physx6shdfnd5ArrayIPNS_12NpBatchQueryENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($10,$bq)|0);
  $$pre = HEAP32[$bq>>2]|0;
  $21 = $$pre;
  STACKTOP = sp;return ($21|0);
 }
 $17 = HEAP32[$10>>2]|0;
 $18 = (($17) + ($15<<2)|0);
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  HEAP32[$18>>2] = $9;
 }
 $20 = (($15) + 1)|0;
 HEAP32[$14>>2] = $20;
 $21 = $9;
 STACKTOP = sp;return ($21|0);
}
function __ZN5physx7NpScene17releaseBatchQueryEPNS_12PxBatchQueryE($this,$sq) {
 $this = $this|0;
 $sq = $sq|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i = 0;
 var $index$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3616|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 3612|0);
  $4 = HEAP32[$3>>2]|0;
  $index$01$i = 0;
  while(1) {
   $7 = (($4) + ($index$01$i<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==($sq|0);
   $6 = (($index$01$i) + 1)|0;
   if ($9) {
    $index$0$lcssa$i = $index$01$i;
    break;
   }
   $5 = ($6>>>0)<($1>>>0);
   if ($5) {
    $index$01$i = $6;
   } else {
    $index$0$lcssa$i = $6;
    break;
   }
  }
  $10 = ($index$0$lcssa$i|0)==($1|0);
  if (!($10)) {
   $11 = (($1) + -1)|0;
   HEAP32[$0>>2] = $11;
   $12 = (($4) + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($4) + ($index$0$lcssa$i<<2)|0);
   HEAP32[$14>>2] = $13;
  }
 }
 $15 = ($sq|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$sq>>2]|0;
 $17 = (($16) + 60|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($sq);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene5flushEb($this,$sendPendingReports) {
 $this = $this|0;
 $sendPendingReports = $sendPendingReports|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 244|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($this,$sendPendingReports);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene14getTaskManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3680|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpScene14getTaskManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3680|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_12NpBatchQueryENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 433344 : 433312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,433232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_13NpVolumeCacheES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE6createERKS4_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre11 = 0, $$pre11$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $36 = $1 << 1;
  $$$i = $2 ? 16 : $36;
  $37 = ($1>>>0)<($$$i>>>0);
  if ($37) {
   __ZN5physx6shdfnd8internal8HashBaseIPNS_13NpVolumeCacheES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $$pre11$pre = HEAP32[$33>>2]|0;
   $$pre11 = $$pre11$pre;$54 = $$pre;
  } else {
   $$pre11 = -1;$54 = $1;
  }
  $38 = HEAP32[$k>>2]|0;
  $39 = $38;
  $40 = $39 << 15;
  $41 = $40 ^ -1;
  $42 = (($39) + ($41))|0;
  $43 = $42 >>> 10;
  $44 = $43 ^ $42;
  $45 = ($44*9)|0;
  $46 = $45 >>> 6;
  $47 = $46 ^ $45;
  $48 = $47 << 11;
  $49 = $48 ^ -1;
  $50 = (($47) + ($49))|0;
  $51 = $50 >>> 16;
  $52 = $51 ^ $50;
  $53 = (($54) + -1)|0;
  $55 = $52 & $53;
  $59 = $$pre11;$h$1 = $55;
 } else {
  $59 = $34;$h$1 = $h$0;
 }
 $56 = (($this) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($59<<2)|0);
 $60 = HEAP32[$58>>2]|0;
 HEAP32[$33>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$58>>2] = $64;
 HEAP32[$63>>2] = $59;
 $65 = (($this) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $68 = (($this) + 32|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$68>>2] = $70;
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($59<<2)|0);
 $$0 = $73;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_13NpVolumeCacheES4_NS0_4HashIS4_EENS1_11HashSetBaseIS4_S6_NS0_9AllocatorELb0EE6GetKeyES8_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,433576,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
    $44 = $43 << 15;
    $45 = $44 ^ -1;
    $46 = (($43) + ($45))|0;
    $47 = $46 >>> 10;
    $48 = $47 ^ $46;
    $49 = ($48*9)|0;
    $50 = $49 >>> 6;
    $51 = $50 ^ $49;
    $52 = $51 << 11;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 16;
    $56 = $55 ^ $54;
    $57 = $56 & $39;
    $58 = (($32) + ($57<<2)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($33) + ($index$01<<2)|0);
    HEAP32[$60>>2] = $59;
    HEAP32[$58>>2] = $index$01;
    $61 = (($34) + ($index$01<<2)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     HEAP32[$61>>2] = $42;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre13 = (($this) + 20|0);
  $$pre14 = (($this) + 8|0);
  $$pre$phi15Z2D = $$pre14;$$pre$phiZ2D = $$pre13;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $117 = $71;$bucket$06 = 0;
   while(1) {
    $76 = HEAP32[$73>>2]|0;
    $77 = (($76) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$77>>2]|0;
    $78 = ($index1$02|0)==(-1);
    if ($78) {
     $107 = $117;
    } else {
     $index1$03 = $index1$02;
     while(1) {
      $79 = HEAP32[$74>>2]|0;
      $80 = (($79) + ($index1$03<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81;
      $83 = $82 << 15;
      $84 = $83 ^ -1;
      $85 = (($82) + ($84))|0;
      $86 = $85 >>> 10;
      $87 = $86 ^ $85;
      $88 = ($87*9)|0;
      $89 = $88 >>> 6;
      $90 = $89 ^ $88;
      $91 = $90 << 11;
      $92 = $91 ^ -1;
      $93 = (($90) + ($92))|0;
      $94 = $93 >>> 16;
      $95 = $94 ^ $93;
      $96 = $95 & $75;
      $97 = (($32) + ($96<<2)|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($33) + ($index1$03<<2)|0);
      HEAP32[$99>>2] = $98;
      HEAP32[$97>>2] = $index1$03;
      $100 = (($34) + ($index1$03<<2)|0);
      $101 = ($100|0)==(0|0);
      if (!($101)) {
       HEAP32[$100>>2] = $81;
      }
      $102 = HEAP32[$66>>2]|0;
      $103 = (($102) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$103>>2]|0;
      $104 = ($index1$0|0)==(-1);
      if ($104) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre = HEAP32[$70>>2]|0;
     $107 = $$pre;
    }
    $105 = (($bucket$06) + 1)|0;
    $106 = ($105>>>0)<($107>>>0);
    if ($106) {
     $117 = $107;$bucket$06 = $105;
    } else {
     $$pre$phi15Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $108 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$108);
 HEAP32[$this>>2] = $32;
 $109 = (($this) + 12|0);
 HEAP32[$109>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi15Z2D>>2] = $33;
 $110 = (($this) + 4|0);
 HEAP32[$110>>2] = $34;
 HEAP32[$18>>2] = $24;
 $111 = (($24) + -1)|0;
 $112 = ($111>>>0)>($19>>>0);
 if ($112) {
  $i$01$i = $19;
 } else {
  $115 = HEAP32[$15>>2]|0;
  $116 = (($33) + ($111<<2)|0);
  HEAP32[$116>>2] = $115;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $113 = (($i$01$i) + 1)|0;
  $114 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$114>>2] = $113;
  $exitcond$i = ($113|0)==($111|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 $115 = HEAP32[$15>>2]|0;
 $116 = (($33) + ($111<<2)|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_7PxClothENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 433784 : 433312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,433232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_14PxParticleBaseENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 433896 : 433312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,433232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 434016 : 433312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,433232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb11RigidObject14resetFilteringEPKPNS0_5ShapeEj($this,$shapes,$shapeCount) {
 $this = $this|0;
 $shapes = $shapes|0;
 $shapeCount = $shapeCount|0;
 var $$c = 0, $$pre = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond19 = 0, $exitcond6$i = 0, $i$015 = 0, $i$02$i = 0, $i1$01$i = 0, $i3$016 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 >>> 30;
 if ((($5|0) == 2)) {
  $6 = HEAP32[$this>>2]|0;
  $7 = (($6) + 2417|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   label = 3;
  }
 } else if (!((($5|0) == 3))) {
  label = 3;
 }
 if ((label|0) == 3) {
  $10 = ($shapeCount|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  }
  $11 = $this;
  $13 = $4;$i$015 = 0;
  while(1) {
   $12 = $13 >>> 24;
   $14 = $12 & 15;
   $15 = ((444424 + ($14<<2)|0) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($11))|0;
   $18 = $17;
   $19 = (($shapes) + ($i$015<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 16|0);
   HEAP32[$1>>2] = 128;
   HEAP8[$2>>0] = 0;
   __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($18,$21,$1,$2);
   $22 = (($i$015) + 1)|0;
   $exitcond = ($22|0)==($shapeCount|0);
   if ($exitcond) {
    break;
   }
   $$pre = HEAP32[$3>>2]|0;
   $13 = $$pre;$i$015 = $22;
  }
  STACKTOP = sp;return;
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $26 = HEAP32[$this>>2]|0;
  $27 = $4 >>> 24;
  $28 = $27 & 15;
  $29 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($26,$28)|0);
  HEAP32[$23>>2] = $29;
  $32 = $29;
 } else {
  $32 = $24;
 }
 $30 = ($shapeCount|0)==(1);
 $31 = (($32) + 88|0);
 $33 = HEAP32[$31>>2]|0;
 $34 = ($33|0)==(0);
 if ($30) {
  if ($34) {
   $35 = HEAP32[$shapes>>2]|0;
   $36 = (($32) + 84|0);
   $$c = $35;
   HEAP32[$36>>2] = $$c;
   HEAP32[$31>>2] = 1;
   $37 = HEAP32[$this>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($37,$this);
   $38 = HEAP32[$3>>2]|0;
   $39 = $38 | 32;
   HEAP32[$3>>2] = $39;
   STACKTOP = sp;return;
  }
  $40 = HEAP32[$this>>2]|0;
  $41 = (($40) + 2500|0);
  $42 = (($40) + 2504|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 2)|0;
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($41,$44,$0);
  $45 = HEAP32[$41>>2]|0;
  $46 = (($45) + ($43<<2)|0);
  $47 = ($46|0)==(0|0);
  if ($47) {
   STACKTOP = sp;return;
  }
  $48 = (($32) + 84|0);
  $49 = HEAP32[$48>>2]|0;
  HEAP32[$46>>2] = $49;
  $50 = HEAP32[$shapes>>2]|0;
  $$sum14 = (($43) + 1)|0;
  $51 = (($45) + ($$sum14<<2)|0);
  HEAP32[$51>>2] = $50;
  HEAP32[$48>>2] = $43;
  HEAP32[$31>>2] = 2;
  $52 = HEAP32[$this>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($52,$this);
  $53 = HEAP32[$3>>2]|0;
  $54 = $53 | 32;
  HEAP32[$3>>2] = $54;
  STACKTOP = sp;return;
 }
 if ($34) {
  $55 = HEAP32[$this>>2]|0;
  $56 = (($55) + 2500|0);
  $57 = (($55) + 2504|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + ($shapeCount))|0;
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($56,$59,$0);
  $60 = HEAP32[$56>>2]|0;
  $61 = (($60) + ($58<<2)|0);
  $62 = ($61|0)==(0|0);
  if ($62) {
   STACKTOP = sp;return;
  }
  $63 = ($shapeCount|0)==(0);
  if (!($63)) {
   $i3$016 = 0;
   while(1) {
    $64 = (($shapes) + ($i3$016<<2)|0);
    $65 = HEAP32[$64>>2]|0;
    $$sum12 = (($i3$016) + ($58))|0;
    $66 = (($60) + ($$sum12<<2)|0);
    HEAP32[$66>>2] = $65;
    $67 = (($i3$016) + 1)|0;
    $exitcond19 = ($67|0)==($shapeCount|0);
    if ($exitcond19) {
     break;
    } else {
     $i3$016 = $67;
    }
   }
  }
  $68 = (($32) + 84|0);
  HEAP32[$68>>2] = $58;
  HEAP32[$31>>2] = $shapeCount;
  $69 = HEAP32[$this>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($69,$this);
  $70 = HEAP32[$3>>2]|0;
  $71 = $70 | 32;
  HEAP32[$3>>2] = $71;
  STACKTOP = sp;return;
 }
 $72 = (($33) + ($shapeCount))|0;
 $73 = HEAP32[$this>>2]|0;
 $74 = (($73) + 2500|0);
 $75 = (($73) + 2504|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + ($72))|0;
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($74,$77,$0);
 $78 = HEAP32[$74>>2]|0;
 $79 = (($78) + ($76<<2)|0);
 $80 = ($79|0)==(0|0);
 if ($80) {
  STACKTOP = sp;return;
 }
 $81 = HEAP32[$this>>2]|0;
 $82 = (($32) + 84|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($81) + 2500|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = HEAP32[$31>>2]|0;
 $87 = ($86|0)==(0);
 if (!($87)) {
  $i$02$i = 0;
  while(1) {
   $$sum = (($i$02$i) + ($83))|0;
   $90 = (($85) + ($$sum<<2)|0);
   $91 = HEAP32[$90>>2]|0;
   $$sum10 = (($i$02$i) + ($76))|0;
   $92 = (($78) + ($$sum10<<2)|0);
   HEAP32[$92>>2] = $91;
   $93 = (($i$02$i) + 1)|0;
   $exitcond6$i = ($93|0)==($86|0);
   if ($exitcond6$i) {
    break;
   } else {
    $i$02$i = $93;
   }
  }
 }
 $88 = ($shapeCount|0)==(0);
 if (!($88)) {
  $89 = (($86) + ($76))|0;
  $i1$01$i = 0;
  while(1) {
   $94 = (($shapes) + ($i1$01$i<<2)|0);
   $95 = HEAP32[$94>>2]|0;
   $$sum11 = (($89) + ($i1$01$i))|0;
   $96 = (($78) + ($$sum11<<2)|0);
   HEAP32[$96>>2] = $95;
   $97 = (($i1$01$i) + 1)|0;
   $exitcond$i = ($97|0)==($shapeCount|0);
   if ($exitcond$i) {
    break;
   } else {
    $i1$01$i = $97;
   }
  }
 }
 HEAP32[$82>>2] = $76;
 HEAP32[$31>>2] = $72;
 $98 = HEAP32[$this>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($98,$this);
 $99 = HEAP32[$3>>2]|0;
 $100 = $99 | 32;
 HEAP32[$3>>2] = $100;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 434184 : 433312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,433232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_12PxRigidActorENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 434296 : 433312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,433232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayINS_9PxBounds3ENS0_15InlineAllocatorILj192ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0);
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = ($capacity*24)|0;
  $2 = (($this) + 192|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(193);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 434416 : 433312;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,433232,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 200|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + (($18*24)|0)|0);
 $21 = (($this) + 196|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
    $35 = (($$012$i) + 16|0);
    $36 = (($$03$i) + 16|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 20|0);
    $39 = (($$03$i) + 20|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
   }
   $41 = (($$012$i) + 24|0);
   $42 = (($$03$i) + 24|0);
   $43 = ($41>>>0)<($19>>>0);
   if ($43) {
    $$012$i = $41;$$03$i = $42;
   } else {
    break;
   }
  }
 }
 $44 = (($this) + 204|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)>(-1);
 if (!($46)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$44>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $47 = HEAP32[$21>>2]|0;
 $48 = ($this|0)==($47|0);
 if ($48) {
  $49 = (($this) + 192|0);
  HEAP8[$49>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$44>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $50 = ($47|0)==(0|0);
 if ($50) {
  HEAP32[$21>>2] = $20;
  HEAP32[$44>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $51 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 FUNCTION_TABLE_vii[$54 & 4095]($51,$47);
 HEAP32[$21>>2] = $20;
 HEAP32[$44>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_12PxRigidActorENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 434296 : 433312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,433232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_13NpVolumeCacheENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 434528 : 433312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,433232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_13NpVolumeCacheENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 434528 : 433312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,433232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSolveEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm4Task3runEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSolveEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx14PxLightCpuTask12addReferenceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$this);
 STACKTOP = sp;return;
}
function __ZN5physx14PxLightCpuTask15removeReferenceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx14PxLightCpuTask12getReferenceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx14PxLightCpuTask7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSolveEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 3660|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 32|0);
 __ZN5physx2Sc5Scene5solveEfPNS_10PxBaseTaskE($6,$5,$3);
 STACKTOP = sp;return;
}
function __ZN5physx14PxLightCpuTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx14PxLightCpuTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_14executeCollideEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_14executeCollideEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_14executeCollideEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 3660|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 32|0);
 __ZN5physx2Sc5Scene7collideEfPNS_10PxBaseTaskE($6,$5,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSceneEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSceneEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSceneEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 3660|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 32|0);
 __ZN5physx2Sc5Scene8simulateEfPNS_10PxBaseTaskE($6,$5,$3);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_3Scb5ActorENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ActorENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_3Scb5ActorENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 435032 : 433312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,433232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayItNS0_19ReflectionAllocatorItEEE6resizeEjRKt($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayItNS0_19ReflectionAllocatorItEEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<1)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<1)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP16[$a>>1]|0;
   HEAP16[$$01$i>>1] = $11;
  }
  $12 = (($$01$i) + 2|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayItNS0_19ReflectionAllocatorItEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 1;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 435144 : 433312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,433232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<1)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP16[$$03$i>>1]|0;
    HEAP16[$$012$i>>1] = $20;
   }
   $21 = (($$012$i) + 2|0);
   $22 = (($$03$i) + 2|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_7PxFlagsINS_20PxClientBehaviorFlag4EnumEhEENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $19 = 0;
 } else {
  $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__Z15PxGetFoundationv()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
  $$$i$i$i = $14 ? 436064 : 433312;
  $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,$$$i,$$$i$i$i,433232,558)|0);
  $19 = $15;
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($19) + ($17)|0);
 $20 = ($17|0)>(0);
 if ($20) {
  $21 = HEAP32[$this>>2]|0;
  $$012$i = $19;$$03$i = $21;
  while(1) {
   $22 = ($$012$i|0)==(0|0);
   if (!($22)) {
    $23 = HEAP8[$$03$i>>0]|0;
    HEAP8[$$012$i>>0] = $23;
   }
   $24 = (($$012$i) + 1|0);
   $25 = (($$03$i) + 1|0);
   $exitcond$i = ($24|0)==($18|0);
   if ($exitcond$i) {
    break;
   } else {
    $$012$i = $24;$$03$i = $25;
   }
  }
  $$pre = HEAP32[$16>>2]|0;
  $27 = $$pre;
 } else {
  $27 = $17;
 }
 $26 = (($19) + ($27)|0);
 $28 = ($26|0)==(0|0);
 if (!($28)) {
  $29 = HEAP8[$a>>0]|0;
  HEAP8[$26>>0] = $29;
 }
 $30 = HEAP32[$0>>2]|0;
 $31 = ($30|0)>(-1);
 if ($31) {
  $32 = HEAP32[$this>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $34 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   FUNCTION_TABLE_vii[$37 & 4095]($34,$32);
  }
 }
 HEAP32[$this>>2] = $19;
 HEAP32[$0>>2] = $$$i;
 $38 = HEAP32[$16>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$16>>2] = $39;
 $40 = (($19) + ($38)|0);
 STACKTOP = sp;return ($40|0);
}
function __ZN5physx3Scb5SceneD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $or$cond$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i11 = 0;
 var $or$cond$i$i8 = 0, $or$cond$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3352|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i$i$i = $3 & $4;
 if ($or$cond$i$i$i$i) {
  $5 = (($this) + 3344|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 2804|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($12,$13);
 }
 $15 = (($this) + 2764|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($15,$16);
 }
 $18 = (($this) + 2724|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($18,$19);
 }
 $21 = (($this) + 2684|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($21,$22);
 }
 $24 = (($this) + 2644|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($24,$25);
 }
 $27 = (($this) + 2604|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($27,$28);
 }
 $30 = (($this) + 2564|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($30,$31);
 }
 $33 = (($this) + 2524|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($33,$34);
 }
 $36 = (($this) + 2520|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38|0)!=(0);
 $40 = ($37|0)>(-1);
 $or$cond$i$i = $39 & $40;
 if ($or$cond$i$i) {
  $41 = (($this) + 2512|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($44,$42);
  }
 }
 $48 = (($this) + 2508|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49 & 2147483647;
 $51 = ($50|0)!=(0);
 $52 = ($49|0)>(-1);
 $or$cond$i$i8 = $51 & $52;
 if ($or$cond$i$i8) {
  $53 = (($this) + 2500|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   FUNCTION_TABLE_vii[$59 & 4095]($56,$54);
  }
 }
 $60 = (($this) + 2496|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = $61 & 2147483647;
 $63 = ($62|0)!=(0);
 $64 = ($61|0)>(-1);
 $or$cond$i$i9 = $63 & $64;
 if ($or$cond$i$i9) {
  $65 = (($this) + 2488|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==(0|0);
  if (!($67)) {
   $68 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($69) + 12|0);
   $71 = HEAP32[$70>>2]|0;
   FUNCTION_TABLE_vii[$71 & 4095]($68,$66);
  }
 }
 $72 = (($this) + 2448|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(0|0);
 if (!($74)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($72,$73);
 }
 $75 = (($this) + 2420|0);
 __ZN5physx2Cm9FlushPoolD2Ev($75);
 $76 = (($this) + 2412|0);
 $77 = HEAP32[$76>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($77);
 $78 = HEAP32[$76>>2]|0;
 $79 = ($78|0)==(0|0);
 if (!($79)) {
  $80 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($81) + 12|0);
  $83 = HEAP32[$82>>2]|0;
  FUNCTION_TABLE_vii[$83 & 4095]($80,$78);
 }
 $84 = (($this) + 2408|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = $85 & 2147483647;
 $87 = ($86|0)!=(0);
 $88 = ($85|0)>(-1);
 $or$cond$i$i11 = $87 & $88;
 if (!($or$cond$i$i11)) {
  $96 = (($this) + 16|0);
  __ZN5physx2Sc5SceneD2Ev($96);
  STACKTOP = sp;return;
 }
 $89 = (($this) + 2400|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($90|0)==(0|0);
 if ($91) {
  $96 = (($this) + 16|0);
  __ZN5physx2Sc5SceneD2Ev($96);
  STACKTOP = sp;return;
 }
 $92 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($93) + 12|0);
 $95 = HEAP32[$94>>2]|0;
 FUNCTION_TABLE_vii[$95 & 4095]($92,$90);
 $96 = (($this) + 16|0);
 __ZN5physx2Sc5SceneD2Ev($96);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5SceneD2Ev($this) {
 $this = $this|0;
 var $$01$i$i$i = 0, $$01$i$i$i6 = 0, $$01$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i11 = 0, $or$cond$i$i12 = 0, $or$cond$i$i13 = 0, $or$cond$i$i14 = 0, $or$cond$i$i15 = 0, $or$cond$i$i16 = 0;
 var $or$cond$i$i18 = 0, $or$cond$i$i19 = 0, $or$cond$i$i2 = 0, $or$cond$i$i21 = 0, $or$cond$i$i3 = 0, $or$cond$i$i4 = 0, $or$cond$i$i5 = 0, $or$cond$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 2340|0);
 __ZN5physx2Cm9FlushPoolD2Ev($1);
 $2 = (($this) + 2312|0);
 HEAP32[$2>>2] = ((434896 + 8|0));
 $3 = (($this) + 2320|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 2284|0);
 HEAP32[$4>>2] = ((434896 + 8|0));
 $5 = (($this) + 2292|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 2256|0);
 HEAP32[$6>>2] = ((434896 + 8|0));
 $7 = (($this) + 2264|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 2160|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($8);
 $9 = (($this) + 2132|0);
 HEAP32[$9>>2] = ((434896 + 8|0));
 $10 = (($this) + 2140|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 2104|0);
 HEAP32[$11>>2] = ((434896 + 8|0));
 $12 = (($this) + 2112|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 2076|0);
 HEAP32[$13>>2] = ((434896 + 8|0));
 $14 = (($this) + 2084|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 2048|0);
 HEAP32[$15>>2] = ((434896 + 8|0));
 $16 = (($this) + 2056|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 2020|0);
 HEAP32[$17>>2] = ((434896 + 8|0));
 $18 = (($this) + 2028|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 1992|0);
 HEAP32[$19>>2] = ((434896 + 8|0));
 $20 = (($this) + 2000|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 1964|0);
 HEAP32[$21>>2] = ((434896 + 8|0));
 $22 = (($this) + 1972|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 1948|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 1952|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + (($26*28)|0)|0);
 $28 = ($26|0)>(0);
 if ($28) {
  $$01$i$i$i = $24;
  while(1) {
   $29 = HEAP32[$$01$i$i$i>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vi[$30 & 4095]($$01$i$i$i);
   $31 = (($$01$i$i$i) + 28|0);
   $32 = ($31>>>0)<($27>>>0);
   if ($32) {
    $$01$i$i$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 1956|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 2147483647;
 $36 = ($35|0)!=(0);
 $37 = ($34|0)>(-1);
 $or$cond$i$i5 = $36 & $37;
 if ($or$cond$i$i5) {
  $38 = HEAP32[$23>>2]|0;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   $40 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   FUNCTION_TABLE_vii[$43 & 4095]($40,$38);
  }
 }
 $44 = (($this) + 1936|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($this) + 1940|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($45) + (($47*28)|0)|0);
 $49 = ($47|0)>(0);
 if ($49) {
  $$01$i$i$i6 = $45;
  while(1) {
   $50 = HEAP32[$$01$i$i$i6>>2]|0;
   $51 = HEAP32[$50>>2]|0;
   FUNCTION_TABLE_vi[$51 & 4095]($$01$i$i$i6);
   $52 = (($$01$i$i$i6) + 28|0);
   $53 = ($52>>>0)<($48>>>0);
   if ($53) {
    $$01$i$i$i6 = $52;
   } else {
    break;
   }
  }
 }
 $54 = (($this) + 1944|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 & 2147483647;
 $57 = ($56|0)!=(0);
 $58 = ($55|0)>(-1);
 $or$cond$i$i8 = $57 & $58;
 if ($or$cond$i$i8) {
  $59 = HEAP32[$44>>2]|0;
  $60 = ($59|0)==(0|0);
  if (!($60)) {
   $61 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($62) + 12|0);
   $64 = HEAP32[$63>>2]|0;
   FUNCTION_TABLE_vii[$64 & 4095]($61,$59);
  }
 }
 $65 = (($this) + 1924|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($this) + 1928|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + (($68*28)|0)|0);
 $70 = ($68|0)>(0);
 if ($70) {
  $$01$i$i$i9 = $66;
  while(1) {
   $71 = HEAP32[$$01$i$i$i9>>2]|0;
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_vi[$72 & 4095]($$01$i$i$i9);
   $73 = (($$01$i$i$i9) + 28|0);
   $74 = ($73>>>0)<($69>>>0);
   if ($74) {
    $$01$i$i$i9 = $73;
   } else {
    break;
   }
  }
 }
 $75 = (($this) + 1932|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = $76 & 2147483647;
 $78 = ($77|0)!=(0);
 $79 = ($76|0)>(-1);
 $or$cond$i$i11 = $78 & $79;
 if ($or$cond$i$i11) {
  $80 = HEAP32[$65>>2]|0;
  $81 = ($80|0)==(0|0);
  if (!($81)) {
   $82 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($83) + 12|0);
   $85 = HEAP32[$84>>2]|0;
   FUNCTION_TABLE_vii[$85 & 4095]($82,$80);
  }
 }
 $86 = (($this) + 1896|0);
 HEAP32[$86>>2] = ((434896 + 8|0));
 $87 = (($this) + 1904|0);
 HEAP32[$87>>2] = 0;
 $88 = (($this) + 1800|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($88);
 $89 = (($this) + 1704|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($89);
 $90 = (($this) + 1612|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($90);
 $91 = (($this) + 1584|0);
 HEAP32[$91>>2] = ((434896 + 8|0));
 $92 = (($this) + 1592|0);
 HEAP32[$92>>2] = 0;
 $93 = (($this) + 1556|0);
 HEAP32[$93>>2] = ((434896 + 8|0));
 $94 = (($this) + 1564|0);
 HEAP32[$94>>2] = 0;
 $95 = (($this) + 1464|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($95);
 $96 = (($this) + 1280|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i12 = $99 & $100;
 if ($or$cond$i$i12) {
  $101 = (($this) + 1272|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)==(0|0);
  if (!($103)) {
   $104 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + 12|0);
   $107 = HEAP32[$106>>2]|0;
   FUNCTION_TABLE_vii[$107 & 4095]($104,$102);
  }
 }
 $108 = (($this) + 1260|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ($109|0)==(0|0);
 if (!($110)) {
  $111 = (($this) + 1264|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = ($112|0)>(-1);
  if ($113) {
   $114 = (($this) + 1268|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($114,$109);
  }
 }
 $115 = (($this) + 1256|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = $116 & 2147483647;
 $118 = ($117|0)!=(0);
 $119 = ($116|0)>(-1);
 $or$cond$i$i13 = $118 & $119;
 if ($or$cond$i$i13) {
  $120 = (($this) + 1248|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ($121|0)==(0|0);
  if (!($122)) {
   $123 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = (($124) + 12|0);
   $126 = HEAP32[$125>>2]|0;
   FUNCTION_TABLE_vii[$126 & 4095]($123,$121);
  }
 }
 $127 = (($this) + 1172|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = $128 & 2147483647;
 $130 = ($129|0)!=(0);
 $131 = ($128|0)>(-1);
 $or$cond$i$i14 = $130 & $131;
 if ($or$cond$i$i14) {
  $132 = (($this) + 1164|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(0|0);
  if (!($134)) {
   $135 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = (($136) + 12|0);
   $138 = HEAP32[$137>>2]|0;
   FUNCTION_TABLE_vii[$138 & 4095]($135,$133);
  }
 }
 $139 = (($this) + 1156|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = $140 & 2147483647;
 $142 = ($141|0)!=(0);
 $143 = ($140|0)>(-1);
 $or$cond$i$i15 = $142 & $143;
 if ($or$cond$i$i15) {
  $144 = (($this) + 1148|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = ($145|0)==(0|0);
  if (!($146)) {
   $147 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = (($148) + 12|0);
   $150 = HEAP32[$149>>2]|0;
   FUNCTION_TABLE_vii[$150 & 4095]($147,$145);
  }
 }
 $151 = (($this) + 1144|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = $152 & 2147483647;
 $154 = ($153|0)!=(0);
 $155 = ($152|0)>(-1);
 $or$cond$i$i16 = $154 & $155;
 if ($or$cond$i$i16) {
  $156 = (($this) + 1136|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = ($157|0)==(0|0);
  if (!($158)) {
   $159 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = (($160) + 12|0);
   $162 = HEAP32[$161>>2]|0;
   FUNCTION_TABLE_vii[$162 & 4095]($159,$157);
  }
 }
 $163 = (($this) + 1120|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ($164|0)==(0|0);
 if (!($165)) {
  $166 = (($164) + -4|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = (0 - ($167))|0;
  $169 = (($164) + ($168)|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$169);
 }
 $170 = (($this) + 792|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj384EEENS0_19ReflectionAllocatorIS4_EEED2Ev($170);
 $171 = (($this) + 496|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj256EEENS0_19ReflectionAllocatorIS4_EEED2Ev($171);
 $172 = (($this) + 200|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj128EEENS0_19ReflectionAllocatorIS4_EEED2Ev($172);
 $173 = (($this) + 196|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = $174 & 2147483647;
 $176 = ($175|0)!=(0);
 $177 = ($174|0)>(-1);
 $or$cond$i$i18 = $176 & $177;
 if ($or$cond$i$i18) {
  $178 = (($this) + 188|0);
  $179 = HEAP32[$178>>2]|0;
  $180 = ($179|0)==(0|0);
  if (!($180)) {
   $181 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = (($182) + 12|0);
   $184 = HEAP32[$183>>2]|0;
   FUNCTION_TABLE_vii[$184 & 4095]($181,$179);
  }
 }
 $185 = (($this) + 184|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = $186 & 2147483647;
 $188 = ($187|0)!=(0);
 $189 = ($186|0)>(-1);
 $or$cond$i$i19 = $188 & $189;
 if ($or$cond$i$i19) {
  $190 = (($this) + 176|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = ($191|0)==(0|0);
  if (!($192)) {
   $193 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = (($194) + 12|0);
   $196 = HEAP32[$195>>2]|0;
   FUNCTION_TABLE_vii[$196 & 4095]($193,$191);
  }
 }
 $197 = (($this) + 148|0);
 $198 = HEAP32[$197>>2]|0;
 $199 = $198 & 2147483647;
 $200 = ($199|0)!=(0);
 $201 = ($198|0)>(-1);
 $or$cond$i$i21 = $200 & $201;
 if ($or$cond$i$i21) {
  $202 = (($this) + 140|0);
  $203 = HEAP32[$202>>2]|0;
  $204 = ($203|0)==(0|0);
  if (!($204)) {
   $205 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = (($206) + 12|0);
   $208 = HEAP32[$207>>2]|0;
   FUNCTION_TABLE_vii[$208 & 4095]($205,$203);
  }
 }
 $209 = (($this) + 136|0);
 $210 = HEAP32[$209>>2]|0;
 $211 = $210 & 2147483647;
 $212 = ($211|0)!=(0);
 $213 = ($210|0)>(-1);
 $or$cond$i$i4 = $212 & $213;
 if ($or$cond$i$i4) {
  $214 = (($this) + 128|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = ($215|0)==(0|0);
  if (!($216)) {
   $217 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = (($218) + 12|0);
   $220 = HEAP32[$219>>2]|0;
   FUNCTION_TABLE_vii[$220 & 4095]($217,$215);
  }
 }
 $221 = (($this) + 124|0);
 $222 = HEAP32[$221>>2]|0;
 $223 = $222 & 2147483647;
 $224 = ($223|0)!=(0);
 $225 = ($222|0)>(-1);
 $or$cond$i$i3 = $224 & $225;
 if ($or$cond$i$i3) {
  $226 = (($this) + 116|0);
  $227 = HEAP32[$226>>2]|0;
  $228 = ($227|0)==(0|0);
  if (!($228)) {
   $229 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $230 = HEAP32[$229>>2]|0;
   $231 = (($230) + 12|0);
   $232 = HEAP32[$231>>2]|0;
   FUNCTION_TABLE_vii[$232 & 4095]($229,$227);
  }
 }
 $233 = (($this) + 112|0);
 $234 = HEAP32[$233>>2]|0;
 $235 = $234 & 2147483647;
 $236 = ($235|0)!=(0);
 $237 = ($234|0)>(-1);
 $or$cond$i$i2 = $236 & $237;
 do {
  if ($or$cond$i$i2) {
   $238 = (($this) + 104|0);
   $239 = HEAP32[$238>>2]|0;
   $240 = ($239|0)==(0|0);
   if ($240) {
    break;
   }
   $241 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $242 = HEAP32[$241>>2]|0;
   $243 = (($242) + 12|0);
   $244 = HEAP32[$243>>2]|0;
   FUNCTION_TABLE_vii[$244 & 4095]($241,$239);
  }
 } while(0);
 $245 = (($this) + 92|0);
 $246 = HEAP32[$245>>2]|0;
 $247 = $246 & 2147483647;
 $248 = ($247|0)!=(0);
 $249 = ($246|0)>(-1);
 $or$cond$i$i1 = $248 & $249;
 do {
  if ($or$cond$i$i1) {
   $250 = (($this) + 84|0);
   $251 = HEAP32[$250>>2]|0;
   $252 = ($251|0)==(0|0);
   if ($252) {
    break;
   }
   $253 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $254 = HEAP32[$253>>2]|0;
   $255 = (($254) + 12|0);
   $256 = HEAP32[$255>>2]|0;
   FUNCTION_TABLE_vii[$256 & 4095]($253,$251);
  }
 } while(0);
 $257 = (($this) + 76|0);
 $258 = HEAP32[$257>>2]|0;
 $259 = $258 & 2147483647;
 $260 = ($259|0)!=(0);
 $261 = ($258|0)>(-1);
 $or$cond$i$i = $260 & $261;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $262 = (($this) + 68|0);
 $263 = HEAP32[$262>>2]|0;
 $264 = ($263|0)==(0|0);
 if ($264) {
  STACKTOP = sp;return;
 }
 $265 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $266 = HEAP32[$265>>2]|0;
 $267 = (($266) + 12|0);
 $268 = HEAP32[$267>>2]|0;
 FUNCTION_TABLE_vii[$268 & 4095]($265,$263);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm10FanoutTaskD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Cm10FanoutTaskD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj128EEENS0_19ReflectionAllocatorIS4_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj128EEENS0_19ReflectionAllocatorIS4_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj128EEENS0_19ReflectionAllocatorIS4_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<7)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 128|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 436536 : 433312;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,436448,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 436536 : 433312;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,436448,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 436536 : 433312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,433232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj256EEENS0_19ReflectionAllocatorIS4_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj256EEENS0_19ReflectionAllocatorIS4_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj256EEENS0_19ReflectionAllocatorIS4_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<8)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 256|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 436688 : 433312;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,436448,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 436688 : 433312;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,436448,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 436688 : 433312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,433232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj384EEENS0_19ReflectionAllocatorIS4_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj384EEENS0_19ReflectionAllocatorIS4_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj384EEENS0_19ReflectionAllocatorIS4_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + (($30*384)|0)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 384|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 436840 : 433312;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,436448,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 436840 : 433312;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,436448,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 436840 : 433312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,433232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx2Cm10FanoutTaskD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((436992 + 8|0));
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($1);
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 4095]($4,$2);
 }
 $8 = (($this) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($10|0)!=(0);
 $12 = ($9|0)>(-1);
 $or$cond$i$i$i = $11 & $12;
 do {
  if ($or$cond$i$i$i) {
   $13 = (($this) + 72|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($this) + 52|0);
   $16 = ($15|0)==($14|0);
   if ($16) {
    $17 = (($this) + 68|0);
    HEAP8[$17>>0] = 0;
    break;
   }
   $18 = ($14|0)==(0|0);
   if (!($18)) {
    $19 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    FUNCTION_TABLE_vii[$22 & 4095]($19,$14);
   }
  }
 } while(0);
 $23 = (($this) + 48|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 & 2147483647;
 $26 = ($25|0)!=(0);
 $27 = ($24|0)>(-1);
 $or$cond$i$i$i1 = $26 & $27;
 if (!($or$cond$i$i$i1)) {
  STACKTOP = sp;return;
 }
 $28 = (($this) + 40|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 20|0);
 $31 = ($30|0)==($29|0);
 if ($31) {
  $32 = (($this) + 36|0);
  HEAP8[$32>>0] = 0;
  STACKTOP = sp;return;
 }
 $33 = ($29|0)==(0|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($34,$29);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm10FanoutTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Cm10FanoutTaskD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm8BaseTask3runEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm10FanoutTask7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm10FanoutTask12addReferenceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 12|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($2)|0);
 $3 = (($this) + 84|0);
 HEAP8[$3>>0] = 1;
 $4 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($4);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm10FanoutTask15removeReferenceEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 12|0);
 $3 = (__ZN5physx6shdfnd15atomicDecrementEPVi($2)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $36 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($36);
  STACKTOP = sp;return;
 }
 (__ZN5physx6shdfnd15atomicIncrementEPVi($2)|0);
 $5 = (($this) + 84|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = (($this) + 40|0);
  $10 = (($this) + 80|0);
  $11 = (($this) + 76|0);
  $12 = (($this) + 72|0);
  $13 = (($this) + 52|0);
  $37 = $7;$i$01 = 0;
  while(1) {
   $14 = HEAP32[$9>>2]|0;
   $15 = (($14) + ($i$01<<2)|0);
   $16 = HEAP32[$10>>2]|0;
   $17 = $16 & 2147483647;
   $18 = HEAP32[$11>>2]|0;
   $19 = ($17>>>0)>($18>>>0);
   if ($19) {
    $20 = HEAP32[$12>>2]|0;
    $21 = (($20) + ($18<<2)|0);
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = HEAP32[$15>>2]|0;
     HEAP32[$21>>2] = $23;
    }
    $24 = (($18) + 1)|0;
    HEAP32[$11>>2] = $24;
    $27 = $37;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($13,$15)|0);
    $$pre = HEAP32[$6>>2]|0;
    $27 = $$pre;
   }
   $25 = (($i$01) + 1)|0;
   $26 = ($25>>>0)<($27>>>0);
   if ($26) {
    $37 = $27;$i$01 = $25;
   } else {
    break;
   }
  }
 }
 HEAP32[$6>>2] = 0;
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$35 & 4095]($33,$this);
 $36 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($36);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm10FanoutTask12getReferenceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm10FanoutTask7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($this) + 72|0);
  $i$01 = 0;
  while(1) {
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + ($i$01<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 20|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vi[$11 & 4095]($8);
   $12 = (($i$01) + 1)|0;
   $exitcond = ($12|0)==($3|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $12;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 $13 = (($this) + 84|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $19 = (($this) + 12|0);
  (__ZN5physx6shdfnd15atomicDecrementEPVi($19)|0);
  $20 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($20);
  STACKTOP = sp;return;
 } else {
  $16 = HEAP32[$this>>2]|0;
  $17 = (($16) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vi[$18 & 4095]($this);
  $20 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($20);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Cm10FanoutTask11runInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 16|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(17);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 437040 : 433312;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,433232,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 20|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 16|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx2Cm9FlushPoolD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $i$01 = 0;
  while(1) {
   $5 = HEAP32[$1>>2]|0;
   $6 = (($5) + ($i$01<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
   $8 = (($i$01) + 1)|0;
   $9 = HEAP32[$2>>2]|0;
   $10 = ($8>>>0)<($9>>>0);
   if ($10) {
    $i$01 = $8;
   } else {
    break;
   }
  }
 }
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2147483647;
 $14 = ($13|0)!=(0);
 $15 = ($12|0)>(-1);
 $or$cond$i$i = $14 & $15;
 if ($or$cond$i$i) {
  $16 = HEAP32[$1>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$21 & 4095]($18,$16);
  }
 }
 $22 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($22);
 $23 = HEAP32[$this>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 4095]($25,$23);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene15SceneCompletionD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpScene15SceneCompletion7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (437200|0);
}
function __ZN5physx7NpScene15SceneCompletion7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd8SyncImpl3setEv($4);
 $5 = ($1|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$1>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx7NpScene15SceneCompletion11runInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx14NpSceneQueries7raycastERKNS_6PxVec3ES3_fRNS_13PxHitCallbackINS_12PxRaycastHitEEENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPKNS_12PxQueryCacheE($this,$origin,$unitDir,$distance,$hits,$hitFlags,$filterData,$filterCall,$cache) {
 $this = $this|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $hits = $hits|0;
 $hitFlags = $hitFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $input = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $input = sp;
 $0 = sp + 24|0;
 $1 = (($this) + 1216|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1208|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,127,$6,$9);
 HEAP32[$input>>2] = $origin;
 $13 = (($input) + 4|0);
 HEAP32[$13>>2] = $unitDir;
 $14 = (($input) + 8|0);
 HEAPF32[$14>>2] = $distance;
 $15 = (($input) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($input) + 16|0);
 HEAP32[$16>>2] = 0;
 $17 = (($input) + 20|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = HEAP16[$hitFlags>>1]|0;
 HEAP16[$0>>1] = $18;
 $19 = (__ZNK5physx14NpSceneQueries10multiQueryINS_12PxRaycastHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($this,$input,$hits,$0,$cache,$filterData,$filterCall,0)|0);
 $20 = HEAP32[$2>>2]|0;
 $21 = (($20) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_viiii[$22 & 511]($2,127,$6,$9);
 STACKTOP = sp;return ($19|0);
}
function __ZNK5physx14NpSceneQueries10multiQueryINS_12PxRaycastHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($this,$input,$hits,$hitFlags,$cache,$filterData,$filterCall,$bfd) {
 $this = $this|0;
 $input = $input|0;
 $hits = $hits|0;
 $hitFlags = $hitFlags|0;
 $cache = $cache|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $bfd = $bfd|0;
 var $$$i$i = 0, $$0 = 0, $$01014 = 0, $$01018 = 0, $$011 = 0, $$pr = 0, $$pr17 = 0, $$pr19 = 0, $$pre = 0, $$sink = 0, $$tr = 0, $$tr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0;
 var $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $again$0$off0 = 0, $dummyDist = 0, $exitcond$i = 0, $i$02$i = 0, $newCount$01$i = 0, $newCount$1$i = 0, $pcb = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $pcb = sp + 4|0;
 $dummyDist = sp;
 $0 = (($filterData) + 16|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($cache|0)==(0|0);
 if ($2) {
  $38 = 0;
 } else {
  $3 = (($cache) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN5physx7NpActor15getShapeManagerERNS_12PxRigidActorE($4)|0);
  $6 = HEAP32[$cache>>2]|0;
  $7 = (__ZN5physx14NpShapeManager18findSceneQueryDataERKNS_7NpShapeE($5,$6)|0);
  $38 = $7;
 }
 $8 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager12flushUpdatesEv($8);
 $9 = (($hits) + 68|0);
 HEAP8[$9>>0] = 0;
 $10 = (($hits) + 80|0);
 HEAP32[$10>>2] = 0;
 $11 = (($input) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = HEAP16[$hitFlags>>1]|0;
 HEAP32[$pcb>>2] = ((437736 + 8|0));
 $14 = (($pcb) + 4|0);
 HEAP32[$14>>2] = $this;
 $15 = (($pcb) + 8|0);
 HEAP32[$15>>2] = $input;
 $16 = (($pcb) + 12|0);
 HEAP32[$16>>2] = $hits;
 $17 = (($pcb) + 16|0);
 HEAP16[$17>>1] = $13;
 $18 = (($pcb) + 20|0);
 HEAP32[$18>>2] = $filterData;
 $19 = (($pcb) + 24|0);
 HEAP32[$19>>2] = $filterCall;
 $20 = (($pcb) + 28|0);
 HEAPF32[$20>>2] = $12;
 $21 = (($pcb) + 32|0);
 HEAP32[$21>>2] = $bfd;
 $22 = (($pcb) + 36|0);
 HEAP8[$22>>0] = 1;
 $23 = (($pcb) + 37|0);
 $24 = (($pcb) + 68|0);
 HEAP8[$24>>0] = 0;
 $25 = (($pcb) + 72|0);
 HEAP32[$25>>2] = 0;
 $26 = (($pcb) + 41|0);
 HEAP8[$26>>0] = 0;
 $27 = (($pcb) + 39|0);
 $28 = ($1&65535) >>> 4;
 $$tr = $28&255;
 $29 = $$tr & 1;
 HEAP8[$27>>0] = $29;
 $30 = $13 & 64;
 $31 = ($30<<16>>16)!=(0);
 $$$i$i = $31 ? 1 : $29;
 $32 = (($pcb) + 40|0);
 HEAP8[$32>>0] = $$$i$i;
 $33 = HEAP16[$0>>1]|0;
 $34 = (($pcb) + 38|0);
 $35 = ($33&65535) >>> 5;
 $$tr$i$i = $35&255;
 $36 = $$tr$i$i & 1;
 HEAP8[$34>>0] = $36;
 HEAP8[$23>>0] = $36;
 $37 = ($38|0)==(0|0);
 do {
  if ($37) {
   $52 = $33;
   label = 9;
  } else {
   $39 = (($hits) + 76|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0);
   if ($41) {
    $42 = (__ZN5physx2Sq8populateEPKNS0_10ActorShapeE($38)|0);
    $43 = (__ZNK5physx2Sq17SceneQueryManager10getPayloadEPKNS0_10ActorShapeE($8,$42)|0);
    HEAP8[$26>>0] = 1;
    $44 = (__ZN18MultiQueryCallbackIN5physx12PxRaycastHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj($pcb,$dummyDist,$43,1)|0);
    HEAP8[$26>>0] = 0;
    if ($44) {
     $$pre = HEAP16[$0>>1]|0;
     $52 = $$pre;
     label = 9;
     break;
    }
    $45 = HEAP8[$9>>0]|0;
    $46 = ($45<<24>>24)==(0);
    if ($46) {
     label = 18;
    } else {
     label = 19;
    }
   } else {
    $52 = $33;
    label = 9;
   }
  }
 } while(0);
 do {
  if ((label|0) == 9) {
   $47 = (($this) + 3388|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($this) + 3392|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $52&65535;
   $53 = $51 & 1;
   $54 = $51 & 2;
   $55 = ($53|0)==(0);
   if (!($55)) {
    $56 = HEAP32[$48>>2]|0;
    $57 = (($56) + 16|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = HEAP32[$input>>2]|0;
    $60 = (($input) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (FUNCTION_TABLE_iiiiii[$58 & 255]($48,$59,$61,$20,$pcb)|0);
    if (!($62)) {
     $63 = HEAP8[$9>>0]|0;
     $64 = ($63<<24>>24)==(0);
     if (!($64)) {
      label = 19;
      break;
     }
     label = 18;
     break;
    }
   }
   $65 = ($54|0)==(0);
   if ($65) {
    $again$0$off0 = 1;
   } else {
    $66 = HEAP32[$50>>2]|0;
    $67 = (($66) + 16|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = HEAP32[$input>>2]|0;
    $70 = (($input) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (FUNCTION_TABLE_iiiiii[$68 & 255]($50,$69,$71,$20,$pcb)|0);
    $phitmp = $72&1;
    $again$0$off0 = $phitmp;
   }
   $73 = HEAP8[$9>>0]|0;
   $74 = ($73<<24>>24)==(0);
   if ($74) {
    $75 = HEAP32[$10>>2]|0;
    $76 = ($75|0)!=(0);
    $$0 = $76;
   } else {
    $$0 = 1;
   }
   $77 = ($again$0$off0<<24>>24)==(0);
   if ($77) {
    $$011 = $$0;
    $125 = HEAP32[$hits>>2]|0;
    $126 = (($125) + 4|0);
    $127 = HEAP32[$126>>2]|0;
    FUNCTION_TABLE_vi[$127 & 4095]($hits);
    STACKTOP = sp;return ($$011|0);
   } else {
    $79 = ($73<<24>>24)==(0);
    $$pr = HEAP32[$10>>2]|0;
    if ($79) {
     $$01014 = $$0;$119 = $$pr;
     break;
    } else {
     $$01018 = $$0;$$pr19 = $$pr;
     label = 21;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $$sink = HEAP32[$10>>2]|0;
  $78 = ($$sink|0)!=(0);
  $$01014 = $78;$119 = $$sink;
 }
 else if ((label|0) == 19) {
  $$pr17 = HEAP32[$10>>2]|0;
  $$01018 = 1;$$pr19 = $$pr17;
  label = 21;
 }
 if ((label|0) == 21) {
  $80 = ($$pr19|0)==(0);
  if ($80) {
   $$011 = $$01018;
   $125 = HEAP32[$hits>>2]|0;
   $126 = (($125) + 4|0);
   $127 = HEAP32[$126>>2]|0;
   FUNCTION_TABLE_vi[$127 & 4095]($hits);
   STACKTOP = sp;return ($$011|0);
  }
  $81 = (($hits) + 72|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($hits) + 4|0);
  $84 = (($83) + 40|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $i$02$i = 0;$newCount$01$i = $$pr19;
  while(1) {
   $86 = ((($82) + ($i$02$i<<6)|0) + 40|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = $87 > $85;
   if ($88) {
    $89 = ((($82) + ($i$02$i<<6)|0) + 44|0);
    $90 = (($82) + ($i$02$i<<6)|0);
    $91 = ((($82) + ($i$02$i<<6)|0) + 36|0);
    $92 = ((($82) + ($i$02$i<<6)|0) + 32|0);
    $93 = ((($82) + ($i$02$i<<6)|0) + 28|0);
    $94 = ((($82) + ($i$02$i<<6)|0) + 24|0);
    $95 = ((($82) + ($i$02$i<<6)|0) + 20|0);
    $96 = ((($82) + ($i$02$i<<6)|0) + 16|0);
    $97 = ((($82) + ($i$02$i<<6)|0) + 12|0);
    $98 = (($newCount$01$i) + -1)|0;
    $99 = (($82) + ($98<<6)|0);
    $100 = ((($82) + ($98<<6)|0) + 12|0);
    $101 = HEAP16[$100>>1]|0;
    $102 = ((($82) + ($98<<6)|0) + 16|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = ((($82) + ($98<<6)|0) + 20|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = ((($82) + ($98<<6)|0) + 24|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = ((($82) + ($98<<6)|0) + 28|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = ((($82) + ($98<<6)|0) + 32|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = ((($82) + ($98<<6)|0) + 36|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = ((($82) + ($98<<6)|0) + 40|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = ((($82) + ($98<<6)|0) + 44|0);
    _memmove(($90|0),($99|0),12)|0;
    HEAP16[$97>>1] = $101;
    HEAPF32[$96>>2] = $103;
    HEAPF32[$95>>2] = $105;
    HEAPF32[$94>>2] = $107;
    HEAPF32[$93>>2] = $109;
    HEAPF32[$92>>2] = $111;
    HEAPF32[$91>>2] = $113;
    HEAPF32[$86>>2] = $115;
    _memmove(($89|0),($116|0),20)|0;
    $newCount$1$i = $98;
   } else {
    $newCount$1$i = $newCount$01$i;
   }
   $117 = (($i$02$i) + 1)|0;
   $exitcond$i = ($117|0)==($$pr19|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$02$i = $117;$newCount$01$i = $newCount$1$i;
   }
  }
  HEAP32[$10>>2] = $newCount$1$i;
  $$01014 = $$01018;$119 = $newCount$1$i;
 }
 $118 = ($119|0)==(0);
 if ($118) {
  $$011 = $$01014;
  $125 = HEAP32[$hits>>2]|0;
  $126 = (($125) + 4|0);
  $127 = HEAP32[$126>>2]|0;
  FUNCTION_TABLE_vi[$127 & 4095]($hits);
  STACKTOP = sp;return ($$011|0);
 }
 $120 = HEAP32[$hits>>2]|0;
 $121 = HEAP32[$120>>2]|0;
 $122 = (($hits) + 72|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (FUNCTION_TABLE_iiii[$121 & 2047]($hits,$123,$119)|0);
 if (!($124)) {
  $$011 = $$01014;
  $125 = HEAP32[$hits>>2]|0;
  $126 = (($125) + 4|0);
  $127 = HEAP32[$126>>2]|0;
  FUNCTION_TABLE_vi[$127 & 4095]($hits);
  STACKTOP = sp;return ($$011|0);
 }
 HEAP32[$10>>2] = 0;
 $$011 = $$01014;
 $125 = HEAP32[$hits>>2]|0;
 $126 = (($125) + 4|0);
 $127 = HEAP32[$126>>2]|0;
 FUNCTION_TABLE_vi[$127 & 4095]($hits);
 STACKTOP = sp;return ($$011|0);
}
function __ZNK5physx14NpSceneQueries7overlapERKNS_10PxGeometryERKNS_11PxTransformERNS_13PxHitCallbackINS_12PxOverlapHitEEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackE($this,$geometry,$pose,$hits,$filterData,$filterCall) {
 $this = $this|0;
 $geometry = $geometry|0;
 $pose = $pose|0;
 $hits = $hits|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $input = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $input = sp;
 $0 = sp + 24|0;
 $1 = (($this) + 1216|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1208|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,128,$6,$9);
 $13 = (($input) + 12|0);
 HEAP32[$13>>2] = $geometry;
 $14 = (($input) + 16|0);
 HEAP32[$14>>2] = $pose;
 $15 = (($input) + 20|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($input) + 4|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$input>>2] = 0;
 HEAP16[$0>>1] = 0;
 $17 = (__ZNK5physx14NpSceneQueries10multiQueryINS_12PxOverlapHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($this,$input,$hits,$0,0,$filterData,$filterCall,0)|0);
 $18 = HEAP32[$2>>2]|0;
 $19 = (($18) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_viiii[$20 & 511]($2,128,$6,$9);
 STACKTOP = sp;return ($17|0);
}
function __ZNK5physx14NpSceneQueries10multiQueryINS_12PxOverlapHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($this,$input,$hits,$hitFlags,$cache,$filterData,$filterCall,$bfd) {
 $this = $this|0;
 $input = $input|0;
 $hits = $hits|0;
 $hitFlags = $hitFlags|0;
 $cache = $cache|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $bfd = $bfd|0;
 var $$$i$i = 0, $$1 = 0, $$110$ph = 0, $$110$ph$in = 0, $$11016 = 0, $$1102225 = 0, $$111 = 0, $$pr = 0, $$pr14 = 0, $$pr17 = 0, $$pr21 = 0, $$pr2324 = 0, $$pre = 0, $$tr = 0, $$tr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $again$0$off0 = 0, $pcb = 0, $phitmp = 0, $sd = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $pcb = sp + 208|0;
 $sd = sp;
 $0 = (($filterData) + 16|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($cache|0)==(0|0);
 if ($2) {
  $36 = 0;
 } else {
  $3 = (($cache) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN5physx7NpActor15getShapeManagerERNS_12PxRigidActorE($4)|0);
  $6 = HEAP32[$cache>>2]|0;
  $7 = (__ZN5physx14NpShapeManager18findSceneQueryDataERKNS_7NpShapeE($5,$6)|0);
  $36 = $7;
 }
 $8 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager12flushUpdatesEv($8);
 $9 = (($hits) + 20|0);
 HEAP8[$9>>0] = 0;
 $10 = (($hits) + 32|0);
 HEAP32[$10>>2] = 0;
 $11 = HEAP16[$hitFlags>>1]|0;
 HEAP32[$pcb>>2] = ((437712 + 8|0));
 $12 = (($pcb) + 4|0);
 HEAP32[$12>>2] = $this;
 $13 = (($pcb) + 8|0);
 HEAP32[$13>>2] = $input;
 $14 = (($pcb) + 12|0);
 HEAP32[$14>>2] = $hits;
 $15 = (($pcb) + 16|0);
 HEAP16[$15>>1] = $11;
 $16 = (($pcb) + 20|0);
 HEAP32[$16>>2] = $filterData;
 $17 = (($pcb) + 24|0);
 HEAP32[$17>>2] = $filterCall;
 $18 = (($pcb) + 28|0);
 HEAPF32[$18>>2] = Math_fround(3.40282346638528859812E+38);
 $19 = (($pcb) + 32|0);
 HEAP32[$19>>2] = $bfd;
 $20 = (($pcb) + 36|0);
 HEAP8[$20>>0] = 1;
 $21 = (($pcb) + 37|0);
 $22 = (($pcb) + 68|0);
 HEAP8[$22>>0] = 0;
 $23 = (($pcb) + 72|0);
 HEAP32[$23>>2] = 0;
 $24 = (($pcb) + 41|0);
 HEAP8[$24>>0] = 0;
 $25 = (($pcb) + 39|0);
 $26 = ($1&65535) >>> 4;
 $$tr = $26&255;
 $27 = $$tr & 1;
 HEAP8[$25>>0] = $27;
 $28 = $11 & 64;
 $29 = ($28<<16>>16)!=(0);
 $$$i$i = $29 ? 1 : $27;
 $30 = (($pcb) + 40|0);
 HEAP8[$30>>0] = $$$i$i;
 $31 = HEAP16[$0>>1]|0;
 $32 = (($pcb) + 38|0);
 $33 = ($31&65535) >>> 5;
 $$tr$i$i = $33&255;
 $34 = $$tr$i$i & 1;
 HEAP8[$32>>0] = $34;
 HEAP8[$21>>0] = $34;
 $35 = ($36|0)==(0|0);
 do {
  if ($35) {
   $51 = $31;
   label = 9;
  } else {
   $37 = (($hits) + 28|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0);
   if ($39) {
    $40 = (__ZN5physx2Sq8populateEPKNS0_10ActorShapeE($36)|0);
    $41 = (__ZNK5physx2Sq17SceneQueryManager10getPayloadEPKNS0_10ActorShapeE($8,$40)|0);
    HEAP8[$24>>0] = 1;
    $42 = (__ZN18MultiQueryCallbackIN5physx12PxOverlapHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj($pcb,0,$41,1)|0);
    HEAP8[$24>>0] = 0;
    if ($42) {
     $$pre = HEAP16[$0>>1]|0;
     $51 = $$pre;
     label = 9;
     break;
    }
    $43 = HEAP8[$9>>0]|0;
    $44 = ($43<<24>>24)==(0);
    if ($44) {
     $45 = HEAP32[$10>>2]|0;
     $$110$ph$in = $45;$$pr14 = $45;
     label = 18;
    } else {
     label = 19;
    }
   } else {
    $51 = $31;
    label = 9;
   }
  }
 } while(0);
 do {
  if ((label|0) == 9) {
   $46 = (($this) + 3388|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($this) + 3392|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = $51&65535;
   $52 = $50 & 1;
   $53 = $50 & 2;
   $54 = (($input) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($input) + 16|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($input) + 20|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   __ZN5physx2Sq9ShapeDataC2ERKNS_10PxGeometryERKNS_11PxTransformEf($sd,$55,$57,$59);
   HEAP32[$23>>2] = $sd;
   $60 = ($52|0)==(0);
   if (!($60)) {
    $61 = HEAP32[$47>>2]|0;
    $62 = (($61) + 20|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (FUNCTION_TABLE_iiii[$63 & 2047]($47,$sd,$pcb)|0);
    if (!($64)) {
     $65 = HEAP8[$9>>0]|0;
     $66 = ($65<<24>>24)==(0);
     if (!($66)) {
      label = 19;
      break;
     }
     $67 = HEAP32[$10>>2]|0;
     $$110$ph$in = $67;$$pr14 = $67;
     label = 18;
     break;
    }
   }
   $68 = ($53|0)==(0);
   if ($68) {
    $again$0$off0 = 1;
   } else {
    $69 = HEAP32[$49>>2]|0;
    $70 = (($69) + 20|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (FUNCTION_TABLE_iiii[$71 & 2047]($49,$sd,$pcb)|0);
    $phitmp = $72&1;
    $again$0$off0 = $phitmp;
   }
   $73 = HEAP8[$9>>0]|0;
   $74 = ($73<<24>>24)==(0);
   if ($74) {
    $75 = HEAP32[$10>>2]|0;
    $76 = ($75|0)!=(0);
    $$1 = $76;
   } else {
    $$1 = 1;
   }
   $77 = ($again$0$off0<<24>>24)==(0);
   if ($77) {
    $$111 = $$1;
   } else {
    $80 = ($73<<24>>24)==(0);
    $$pr = HEAP32[$10>>2]|0;
    $81 = ($$pr|0)==(0);
    if ($80) {
     if ($81) {
      $$111 = $$1;
      break;
     } else {
      $$11016 = $$1;$$pr17 = $$pr;
      label = 24;
      break;
     }
    } else {
     if ($81) {
      $$111 = $$1;
      break;
     } else {
      $$1102225 = $$1;$$pr2324 = $$pr;
      label = 22;
      break;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $$110$ph = ($$110$ph$in|0)!=(0);
  $78 = ($$pr14|0)==(0);
  if ($78) {
   $$111 = $$110$ph;
  } else {
   $$11016 = $$110$ph;$$pr17 = $$pr14;
   label = 24;
  }
 }
 else if ((label|0) == 19) {
  $$pr21 = HEAP32[$10>>2]|0;
  $79 = ($$pr21|0)==(0);
  if ($79) {
   $$111 = 1;
  } else {
   $$1102225 = 1;$$pr2324 = $$pr21;
   label = 22;
  }
 }
 if ((label|0) == 22) {
  HEAP32[$10>>2] = $$pr2324;
  $$11016 = $$1102225;$$pr17 = $$pr2324;
  label = 24;
 }
 if ((label|0) == 24) {
  $82 = HEAP32[$hits>>2]|0;
  $83 = HEAP32[$82>>2]|0;
  $84 = (($hits) + 24|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (FUNCTION_TABLE_iiii[$83 & 2047]($hits,$85,$$pr17)|0);
  if ($86) {
   HEAP32[$10>>2] = 0;
   $$111 = $$11016;
  } else {
   $$111 = $$11016;
  }
 }
 $87 = HEAP32[$hits>>2]|0;
 $88 = (($87) + 4|0);
 $89 = HEAP32[$88>>2]|0;
 FUNCTION_TABLE_vi[$89 & 4095]($hits);
 STACKTOP = sp;return ($$111|0);
}
function __ZNK5physx14NpSceneQueries5sweepERKNS_10PxGeometryERKNS_11PxTransformERKNS_6PxVec3EfRNS_13PxHitCallbackINS_10PxSweepHitEEENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPKNS_12PxQueryCacheEf($this,$geometry,$pose,$unitDir,$distance,$hits,$hitFlags,$filterData,$filterCall,$cache,$inflation) {
 $this = $this|0;
 $geometry = $geometry|0;
 $pose = $pose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $hits = $hits|0;
 $hitFlags = $hitFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $cache = $cache|0;
 $inflation = Math_fround($inflation);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $input = 0, $or$cond = 0, $realInflation$0 = Math_fround(0), $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer3 = sp;
 $input = sp + 8|0;
 $0 = sp + 32|0;
 $1 = (($this) + 1216|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1208|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,133,$6,$9);
 $13 = HEAP16[$hitFlags>>1]|0;
 $14 = $13 & 768;
 $15 = ($14<<16>>16)==(768);
 if ($15) {
  $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,4,437224,104,437304,$vararg_buffer3);
  $17 = HEAP16[$hitFlags>>1]|0;
  $18 = $17 & -257;
  HEAP16[$hitFlags>>1] = $18;
  $20 = $18;
 } else {
  $20 = $13;
 }
 $19 = $20 & 528;
 $21 = ($19<<16>>16)==(528);
 if ($21) {
  $22 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($22,4,437224,110,437376,$vararg_buffer3);
  $23 = HEAP16[$hitFlags>>1]|0;
  $24 = $23 & -17;
  HEAP16[$hitFlags>>1] = $24;
  $26 = $24;
 } else {
  $26 = $20;
 }
 $25 = $26 & 256;
 $27 = ($25<<16>>16)!=(0);
 $28 = $inflation > Math_fround(0.0);
 $or$cond = $27 & $28;
 if ($or$cond) {
  $29 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($29,4,437224,118,437488,$vararg_buffer3);
  $realInflation$0 = Math_fround(0.0);
 } else {
  $realInflation$0 = $inflation;
 }
 HEAP32[$input>>2] = 0;
 $30 = (($input) + 8|0);
 HEAPF32[$30>>2] = $distance;
 $31 = (($input) + 4|0);
 HEAP32[$31>>2] = $unitDir;
 $32 = (($input) + 12|0);
 HEAP32[$32>>2] = $geometry;
 $33 = (($input) + 16|0);
 HEAP32[$33>>2] = $pose;
 $34 = (($input) + 20|0);
 HEAPF32[$34>>2] = $realInflation$0;
 $35 = HEAP16[$hitFlags>>1]|0;
 HEAP16[$0>>1] = $35;
 $36 = (__ZNK5physx14NpSceneQueries10multiQueryINS_10PxSweepHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($this,$input,$hits,$0,$cache,$filterData,$filterCall,0)|0);
 $37 = HEAP32[$2>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_viiii[$39 & 511]($2,133,$6,$9);
 STACKTOP = sp;return ($36|0);
}
function __ZNK5physx14NpSceneQueries10multiQueryINS_10PxSweepHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($this,$input,$hits,$hitFlags,$cache,$filterData,$filterCall,$bfd) {
 $this = $this|0;
 $input = $input|0;
 $hits = $hits|0;
 $hitFlags = $hitFlags|0;
 $cache = $cache|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $bfd = $bfd|0;
 var $$$i$i = 0, $$1 = 0, $$11014 = 0, $$11018 = 0, $$111 = 0, $$pr = 0, $$pr17 = 0, $$pr19 = 0, $$pre = 0, $$sink = 0, $$tr = 0, $$tr$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0);
 var $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0;
 var $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0;
 var $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $again$0$off0 = 0, $dummyDist = 0, $exitcond$i = 0, $i$02$i = 0, $newCount$01$i = 0, $newCount$1$i = 0, $pcb = 0, $phitmp = 0, $sd = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $pcb = sp + 216|0;
 $dummyDist = sp;
 $sd = sp + 8|0;
 $0 = (($filterData) + 16|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($cache|0)==(0|0);
 if ($2) {
  $40 = 0;
 } else {
  $3 = (($cache) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN5physx7NpActor15getShapeManagerERNS_12PxRigidActorE($4)|0);
  $6 = HEAP32[$cache>>2]|0;
  $7 = (__ZN5physx14NpShapeManager18findSceneQueryDataERKNS_7NpShapeE($5,$6)|0);
  $40 = $7;
 }
 $8 = (($this) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager12flushUpdatesEv($8);
 $9 = (($hits) + 52|0);
 HEAP8[$9>>0] = 0;
 $10 = (($hits) + 64|0);
 HEAP32[$10>>2] = 0;
 $11 = (($input) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = $12 < Math_fround(1.0E+8);
 $14 = $13 ? $12 : Math_fround(1.0E+8);
 $15 = HEAP16[$hitFlags>>1]|0;
 HEAP32[$pcb>>2] = ((437688 + 8|0));
 $16 = (($pcb) + 4|0);
 HEAP32[$16>>2] = $this;
 $17 = (($pcb) + 8|0);
 HEAP32[$17>>2] = $input;
 $18 = (($pcb) + 12|0);
 HEAP32[$18>>2] = $hits;
 $19 = (($pcb) + 16|0);
 HEAP16[$19>>1] = $15;
 $20 = (($pcb) + 20|0);
 HEAP32[$20>>2] = $filterData;
 $21 = (($pcb) + 24|0);
 HEAP32[$21>>2] = $filterCall;
 $22 = (($pcb) + 28|0);
 HEAPF32[$22>>2] = $14;
 $23 = (($pcb) + 32|0);
 HEAP32[$23>>2] = $bfd;
 $24 = (($pcb) + 36|0);
 HEAP8[$24>>0] = 1;
 $25 = (($pcb) + 37|0);
 $26 = (($pcb) + 68|0);
 HEAP8[$26>>0] = 0;
 $27 = (($pcb) + 72|0);
 HEAP32[$27>>2] = 0;
 $28 = (($pcb) + 41|0);
 HEAP8[$28>>0] = 0;
 $29 = (($pcb) + 39|0);
 $30 = ($1&65535) >>> 4;
 $$tr = $30&255;
 $31 = $$tr & 1;
 HEAP8[$29>>0] = $31;
 $32 = $15 & 64;
 $33 = ($32<<16>>16)!=(0);
 $$$i$i = $33 ? 1 : $31;
 $34 = (($pcb) + 40|0);
 HEAP8[$34>>0] = $$$i$i;
 $35 = HEAP16[$0>>1]|0;
 $36 = (($pcb) + 38|0);
 $37 = ($35&65535) >>> 5;
 $$tr$i$i = $37&255;
 $38 = $$tr$i$i & 1;
 HEAP8[$36>>0] = $38;
 HEAP8[$25>>0] = $38;
 $39 = ($40|0)==(0|0);
 do {
  if ($39) {
   $78 = $35;
   label = 9;
  } else {
   $41 = (($hits) + 60|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0);
   if ($43) {
    $44 = (__ZN5physx2Sq8populateEPKNS0_10ActorShapeE($40)|0);
    $45 = (__ZNK5physx2Sq17SceneQueryManager10getPayloadEPKNS0_10ActorShapeE($8,$44)|0);
    HEAP8[$28>>0] = 1;
    $46 = (($input) + 12|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($input) + 16|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($input) + 20|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    __ZN5physx2Sq9ShapeDataC2ERKNS_10PxGeometryERKNS_11PxTransformEf($sd,$47,$49,$51);
    $52 = (($sd) + 120|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = (($pcb) + 44|0);
    HEAPF32[$54>>2] = $53;
    $55 = (($sd) + 124|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = (($pcb) + 48|0);
    HEAPF32[$57>>2] = $56;
    $58 = (($sd) + 128|0);
    $59 = Math_fround(HEAPF32[$58>>2]);
    $60 = (($pcb) + 52|0);
    HEAPF32[$60>>2] = $59;
    $61 = (($sd) + 132|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = (($pcb) + 56|0);
    HEAPF32[$63>>2] = $62;
    $64 = (($sd) + 136|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    $66 = (($pcb) + 60|0);
    HEAPF32[$66>>2] = $65;
    $67 = (($sd) + 140|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = (($pcb) + 64|0);
    HEAPF32[$69>>2] = $68;
    HEAP8[$26>>0] = 1;
    HEAP32[$27>>2] = $sd;
    $70 = (__ZN18MultiQueryCallbackIN5physx10PxSweepHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj($pcb,$dummyDist,$45,1)|0);
    HEAP32[$27>>2] = 0;
    HEAP8[$28>>0] = 0;
    if ($70) {
     $$pre = HEAP16[$0>>1]|0;
     $78 = $$pre;
     label = 9;
     break;
    }
    $71 = HEAP8[$9>>0]|0;
    $72 = ($71<<24>>24)==(0);
    if ($72) {
     label = 18;
    } else {
     label = 19;
    }
   } else {
    $78 = $35;
    label = 9;
   }
  }
 } while(0);
 do {
  if ((label|0) == 9) {
   $73 = (($this) + 3388|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($this) + 3392|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = $78&65535;
   $79 = $77 & 1;
   $80 = $77 & 2;
   $81 = (($input) + 12|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($input) + 16|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($input) + 20|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   __ZN5physx2Sq9ShapeDataC2ERKNS_10PxGeometryERKNS_11PxTransformEf($sd,$82,$84,$86);
   $87 = (($sd) + 120|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = (($pcb) + 44|0);
   HEAPF32[$89>>2] = $88;
   $90 = (($sd) + 124|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = (($pcb) + 48|0);
   HEAPF32[$92>>2] = $91;
   $93 = (($sd) + 128|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = (($pcb) + 52|0);
   HEAPF32[$95>>2] = $94;
   $96 = (($sd) + 132|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = (($pcb) + 56|0);
   HEAPF32[$98>>2] = $97;
   $99 = (($sd) + 136|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = (($pcb) + 60|0);
   HEAPF32[$101>>2] = $100;
   $102 = (($sd) + 140|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = (($pcb) + 64|0);
   HEAPF32[$104>>2] = $103;
   HEAP8[$26>>0] = 1;
   HEAP32[$27>>2] = $sd;
   $105 = ($79|0)==(0);
   if (!($105)) {
    $106 = HEAP32[$74>>2]|0;
    $107 = (($106) + 24|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = (($input) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = (FUNCTION_TABLE_iiiiii[$108 & 255]($74,$sd,$110,$22,$pcb)|0);
    if (!($111)) {
     $112 = HEAP8[$9>>0]|0;
     $113 = ($112<<24>>24)==(0);
     if (!($113)) {
      label = 19;
      break;
     }
     label = 18;
     break;
    }
   }
   $114 = ($80|0)==(0);
   if ($114) {
    $again$0$off0 = 1;
   } else {
    $115 = HEAP32[$76>>2]|0;
    $116 = (($115) + 24|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = (($input) + 4|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (FUNCTION_TABLE_iiiiii[$117 & 255]($76,$sd,$119,$22,$pcb)|0);
    $phitmp = $120&1;
    $again$0$off0 = $phitmp;
   }
   $121 = HEAP8[$9>>0]|0;
   $122 = ($121<<24>>24)==(0);
   if ($122) {
    $123 = HEAP32[$10>>2]|0;
    $124 = ($123|0)!=(0);
    $$1 = $124;
   } else {
    $$1 = 1;
   }
   $125 = ($again$0$off0<<24>>24)==(0);
   if ($125) {
    $$111 = $$1;
    $174 = HEAP32[$hits>>2]|0;
    $175 = (($174) + 4|0);
    $176 = HEAP32[$175>>2]|0;
    FUNCTION_TABLE_vi[$176 & 4095]($hits);
    STACKTOP = sp;return ($$111|0);
   } else {
    $127 = ($121<<24>>24)==(0);
    $$pr = HEAP32[$10>>2]|0;
    if ($127) {
     $$11014 = $$1;$168 = $$pr;
     break;
    } else {
     $$11018 = $$1;$$pr19 = $$pr;
     label = 21;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $$sink = HEAP32[$10>>2]|0;
  $126 = ($$sink|0)!=(0);
  $$11014 = $126;$168 = $$sink;
 }
 else if ((label|0) == 19) {
  $$pr17 = HEAP32[$10>>2]|0;
  $$11018 = 1;$$pr19 = $$pr17;
  label = 21;
 }
 if ((label|0) == 21) {
  $128 = ($$pr19|0)==(0);
  if ($128) {
   $$111 = $$11018;
   $174 = HEAP32[$hits>>2]|0;
   $175 = (($174) + 4|0);
   $176 = HEAP32[$175>>2]|0;
   FUNCTION_TABLE_vi[$176 & 4095]($hits);
   STACKTOP = sp;return ($$111|0);
  }
  $129 = (($hits) + 56|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($hits) + 4|0);
  $132 = (($131) + 40|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $i$02$i = 0;$newCount$01$i = $$pr19;
  while(1) {
   $134 = ((($130) + (($i$02$i*48)|0)|0) + 40|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = $135 > $133;
   if ($136) {
    $137 = (($130) + (($i$02$i*48)|0)|0);
    $138 = ((($130) + (($i$02$i*48)|0)|0) + 44|0);
    $139 = ((($130) + (($i$02$i*48)|0)|0) + 36|0);
    $140 = ((($130) + (($i$02$i*48)|0)|0) + 32|0);
    $141 = ((($130) + (($i$02$i*48)|0)|0) + 28|0);
    $142 = ((($130) + (($i$02$i*48)|0)|0) + 24|0);
    $143 = ((($130) + (($i$02$i*48)|0)|0) + 20|0);
    $144 = ((($130) + (($i$02$i*48)|0)|0) + 16|0);
    $145 = ((($130) + (($i$02$i*48)|0)|0) + 12|0);
    $146 = (($newCount$01$i) + -1)|0;
    $147 = (($130) + (($146*48)|0)|0);
    $148 = ((($130) + (($146*48)|0)|0) + 12|0);
    $149 = HEAP16[$148>>1]|0;
    $150 = ((($130) + (($146*48)|0)|0) + 16|0);
    $151 = Math_fround(HEAPF32[$150>>2]);
    $152 = ((($130) + (($146*48)|0)|0) + 20|0);
    $153 = Math_fround(HEAPF32[$152>>2]);
    $154 = ((($130) + (($146*48)|0)|0) + 24|0);
    $155 = Math_fround(HEAPF32[$154>>2]);
    $156 = ((($130) + (($146*48)|0)|0) + 28|0);
    $157 = Math_fround(HEAPF32[$156>>2]);
    $158 = ((($130) + (($146*48)|0)|0) + 32|0);
    $159 = Math_fround(HEAPF32[$158>>2]);
    $160 = ((($130) + (($146*48)|0)|0) + 36|0);
    $161 = Math_fround(HEAPF32[$160>>2]);
    $162 = ((($130) + (($146*48)|0)|0) + 40|0);
    $163 = Math_fround(HEAPF32[$162>>2]);
    $164 = ((($130) + (($146*48)|0)|0) + 44|0);
    $165 = HEAP32[$164>>2]|0;
    _memmove(($137|0),($147|0),12)|0;
    HEAP16[$145>>1] = $149;
    HEAPF32[$144>>2] = $151;
    HEAPF32[$143>>2] = $153;
    HEAPF32[$142>>2] = $155;
    HEAPF32[$141>>2] = $157;
    HEAPF32[$140>>2] = $159;
    HEAPF32[$139>>2] = $161;
    HEAPF32[$134>>2] = $163;
    HEAP32[$138>>2] = $165;
    $newCount$1$i = $146;
   } else {
    $newCount$1$i = $newCount$01$i;
   }
   $166 = (($i$02$i) + 1)|0;
   $exitcond$i = ($166|0)==($$pr19|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$02$i = $166;$newCount$01$i = $newCount$1$i;
   }
  }
  HEAP32[$10>>2] = $newCount$1$i;
  $$11014 = $$11018;$168 = $newCount$1$i;
 }
 $167 = ($168|0)==(0);
 if ($167) {
  $$111 = $$11014;
  $174 = HEAP32[$hits>>2]|0;
  $175 = (($174) + 4|0);
  $176 = HEAP32[$175>>2]|0;
  FUNCTION_TABLE_vi[$176 & 4095]($hits);
  STACKTOP = sp;return ($$111|0);
 }
 $169 = HEAP32[$hits>>2]|0;
 $170 = HEAP32[$169>>2]|0;
 $171 = (($hits) + 56|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = (FUNCTION_TABLE_iiii[$170 & 2047]($hits,$172,$168)|0);
 if (!($173)) {
  $$111 = $$11014;
  $174 = HEAP32[$hits>>2]|0;
  $175 = (($174) + 4|0);
  $176 = HEAP32[$175>>2]|0;
  FUNCTION_TABLE_vi[$176 & 4095]($hits);
  STACKTOP = sp;return ($$111|0);
 }
 HEAP32[$10>>2] = 0;
 $$111 = $$11014;
 $174 = HEAP32[$hits>>2]|0;
 $175 = (($174) + 4|0);
 $176 = HEAP32[$175>>2]|0;
 FUNCTION_TABLE_vi[$176 & 4095]($hits);
 STACKTOP = sp;return ($$111|0);
}
function __ZN18MultiQueryCallbackIN5physx12PxRaycastHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj($this,$aDist,$aPayload,$aCount) {
 $this = $this|0;
 $aDist = $aDist|0;
 $aPayload = $aPayload|0;
 $aCount = $aCount|0;
 var $$ = 0, $$$ = 0, $$0 = 0, $$2 = 0, $$9 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$not = 0, $$old = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre27 = Math_fround(0), $$pre28 = 0, $$pre29 = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0;
 var $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0);
 var $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0;
 var $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $as = 0, $brmerge = 0, $exitcond$i = 0, $fd1 = 0, $filterFlags = 0, $filteredHitFlags = 0;
 var $globalPose = 0, $hitType$0 = 0, $hitType$0$ = 0, $i$02$i = 0, $iShape$020 = 0, $iSubHit$014 = 0, $maxSubHits1$1 = 0, $newCount$0$lcssa$i = 0, $newCount$01$i = 0, $newCount$1$i = 0, $or$cond = 0, $or$cond39 = 0, $or$cond4 = 0, $phitmp = 0, $shapeHitType = 0, $tempBuf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy1 = sp + 184|0;
 $$byval_copy = sp + 168|0;
 $tempBuf = sp + 104|0;
 $as = sp + 88|0;
 $filterFlags = sp + 270|0;
 $shapeHitType = sp + 44|0;
 $filteredHitFlags = sp + 272|0;
 $globalPose = sp + 16|0;
 $0 = sp;
 $1 = sp + 72|0;
 $fd1 = sp + 48|0;
 $2 = sp + 268|0;
 HEAP32[$tempBuf>>2] = 0;
 $3 = (($tempBuf) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tempBuf) + 8|0);
 HEAP32[$4>>2] = -1;
 $5 = (($tempBuf) + 12|0);
 HEAP16[$5>>1] = 0;
 $6 = (($tempBuf) + 16|0);
 $7 = (($tempBuf) + 40|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 HEAPF32[$7>>2] = Math_fround(3.40282346638528859812E+38);
 $8 = (($tempBuf) + 44|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($tempBuf) + 48|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = ($aCount|0)==(0);
 if ($10) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($as) + 4|0);
 $12 = (($this) + 20|0);
 $13 = (($this) + 12|0);
 $14 = (($this) + 41|0);
 $15 = (($this) + 16|0);
 $16 = (($this) + 24|0);
 $17 = (($this) + 4|0);
 $18 = (($this) + 32|0);
 $19 = (($as) + 8|0);
 $20 = (($as) + 12|0);
 $21 = (($this) + 8|0);
 $22 = (($this) + 39|0);
 $23 = (($this) + 28|0);
 $24 = (($this) + 40|0);
 $25 = (($this) + 38|0);
 $26 = (($this) + 36|0);
 $27 = (($fd1) + 16|0);
 $28 = (($fd1) + 18|0);
 $29 = (($$byval_copy1) + 4|0);
 $30 = (($$byval_copy1) + 8|0);
 $31 = (($$byval_copy1) + 12|0);
 $32 = (($$byval_copy1) + 16|0);
 $33 = (($$byval_copy1) + 20|0);
 $34 = (($$byval_copy1) + 44|0);
 $35 = (($$byval_copy1) + 48|0);
 $36 = (($$byval_copy1) + 52|0);
 $37 = (($$byval_copy1) + 68|0);
 $38 = (($$byval_copy1) + 72|0);
 $39 = (($$byval_copy1) + 76|0);
 $40 = (($$byval_copy1) + 80|0);
 $41 = (($this) + 37|0);
 $42 = (($$byval_copy1) + 4|0);
 $43 = (($$byval_copy1) + 24|0);
 $44 = (($$byval_copy1) + 28|0);
 $45 = (($$byval_copy1) + 32|0);
 $46 = (($$byval_copy1) + 36|0);
 $47 = (($$byval_copy1) + 40|0);
 $48 = (($42) + 40|0);
 $iShape$020 = 0;
 L4: while(1) {
  HEAP32[$as>>2] = 0;
  HEAP32[$11>>2] = 0;
  $49 = (($aPayload) + ($iShape$020<<3)|0);
  __ZN5physx2Sq8populateERKNS0_13PrunerPayloadERNS0_13PxActorShape2E($49,$as);
  $50 = HEAP32[$12>>2]|0;
  $51 = (($50) + 16|0);
  $52 = HEAP16[$51>>1]|0;
  HEAP16[$filterFlags>>1] = $52;
  $53 = HEAP32[$13>>2]|0;
  $54 = (($53) + 76|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)!=(0);
  $57 = ($52<<16>>16)<(0);
  $or$cond39 = $56 | $57;
  $58 = HEAP8[$14>>0]|0;
  if ($or$cond39) {
   $59 = ($58<<24>>24)!=(0);
   $phitmp = $59 ? 2 : 1;
   $$old = $phitmp;
  } else {
   $$old = 2;
  }
  HEAP32[$shapeHitType>>2] = $$old;
  $60 = HEAP16[$15>>1]|0;
  HEAP16[$filteredHitFlags>>1] = $60;
  $61 = ($58<<24>>24)==(0);
  if ($61) {
   $62 = HEAP32[$16>>2]|0;
   $63 = HEAP32[$17>>2]|0;
   $64 = HEAP32[$18>>2]|0;
   $65 = (__ZL20applyAllPreFiltersSQPKN5physx2Sq13PxActorShape2ERNS_14PxQueryHitType4EnumERKNS_7PxFlagsINS_11PxQueryFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackERKNS_14NpSceneQueriesEPNS_20BatchQueryFilterDataERNS7_INS_9PxHitFlag4EnumEtEEj($as,$shapeHitType,$filterFlags,$50,$62,$63,$64,$filteredHitFlags)|0);
   $$not = $65 ^ 1;
   $66 = HEAP32[$shapeHitType>>2]|0;
   $67 = ($66|0)==(0);
   $or$cond = $67 | $$not;
   if (!($or$cond)) {
    $357 = $66;
    label = 7;
   }
  } else {
   $357 = $$old;
   label = 7;
  }
  if ((label|0) == 7) {
   label = 0;
   $68 = HEAP32[$19>>2]|0;
   $69 = HEAP32[$20>>2]|0;
   __ZN5physx2Sq13getGlobalPoseERKNS_3Scb5ShapeERKNS1_5ActorE($globalPose,$68,$69);
   $70 = (($68) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = $71 & 1;
   $73 = ($72|0)==(0);
   if ($73) {
    $81 = (($68) + 84|0);
    $$sink$i = $81;
   } else {
    $74 = (($68) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($75|0)==(0|0);
    if ($76) {
     $77 = HEAP32[$68>>2]|0;
     $78 = $71 >>> 24;
     $79 = $78 & 15;
     $80 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($77,$79)|0);
     HEAP32[$74>>2] = $80;
     $358 = $80;
    } else {
     $358 = $75;
    }
    $$sink$i = $358;
   }
   $82 = HEAP32[$13>>2]|0;
   $83 = (($82) + 76|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($82) + 80|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($84) - ($86))|0;
   $88 = (($82) + 72|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($89) + ($86<<6)|0);
   $91 = ($86>>>0)<($84>>>0);
   $$ = $91 ? $87 : 1;
   $$2 = $91 ? $90 : $tempBuf;
   $92 = HEAP32[$$sink$i>>2]|0;
   $93 = ($92|0)==(5);
   $94 = HEAP16[$filteredHitFlags>>1]|0;
   if ($93) {
    $95 = $94 & 32;
    $96 = ($95<<16>>16)!=(0);
    $$$ = $96 ? $$ : 1;
    $maxSubHits1$1 = $$$;
   } else {
    $maxSubHits1$1 = $$;
   }
   $97 = HEAP32[$17>>2]|0;
   $98 = HEAP32[$21>>2]|0;
   $99 = HEAP8[$22>>0]|0;
   $100 = ($99<<24>>24)==(0);
   $$9 = $100 ? 4 : 64;
   $101 = $$9 | $94;
   $102 = Math_fround(HEAPF32[$23>>2]);
   $103 = HEAP8[$24>>0]|0;
   $104 = ($103<<24>>24)!=(0);
   $105 = (($97) + 3376|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = (($106) + ($92<<2)|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = HEAP32[$98>>2]|0;
   $110 = (($98) + 4|0);
   $111 = HEAP32[$110>>2]|0;
   HEAP16[$$byval_copy1>>1] = $101;
   $112 = (FUNCTION_TABLE_iiiiifiiiiii[$108 & 7]($$sink$i,$globalPose,$109,$111,$102,$$byval_copy1,$maxSubHits1$1,$$2,$104,0,0)|0);
   $113 = ($112|0)==(0);
   if (!($113)) {
    $114 = HEAP16[$filterFlags>>1]|0;
    $115 = $114 & 8;
    $116 = ($115<<16>>16)==(0);
    $iSubHit$014 = 0;
    while(1) {
     $117 = (($$2) + ($iSubHit$014<<6)|0);
     $118 = HEAP32[$as>>2]|0;
     HEAP32[$117>>2] = $118;
     $119 = HEAP32[$11>>2]|0;
     $120 = ((($$2) + ($iSubHit$014<<6)|0) + 4|0);
     HEAP32[$120>>2] = $119;
     $121 = HEAP8[$14>>0]|0;
     $122 = ($121<<24>>24)==(0);
     do {
      if ($122) {
       $123 = HEAP32[$16>>2]|0;
       $124 = ($123|0)==(0|0);
       if ($124) {
        $125 = HEAP32[$18>>2]|0;
        $126 = ($125|0)==(0|0);
        $brmerge = $126 | $116;
        if ($brmerge) {
         $hitType$0 = $357;
         break;
        }
       } else {
        if ($116) {
         $hitType$0 = $357;
         break;
        }
       }
       if (!($124)) {
        $127 = HEAP32[$123>>2]|0;
        $128 = (($127) + 4|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = HEAP32[$12>>2]|0;
        $131 = (FUNCTION_TABLE_iiii[$129 & 2047]($123,$130,$117)|0);
        $hitType$0 = $131;
        break;
       }
       $132 = HEAP32[$18>>2]|0;
       $133 = (($132) + 12|0);
       $134 = HEAP32[$133>>2]|0;
       $135 = ($134|0)==(0|0);
       if ($135) {
        $hitType$0 = $357;
       } else {
        $136 = HEAP32[$12>>2]|0;
        ;HEAP32[$0+0>>2]=HEAP32[$136+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$136+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$136+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$136+12>>2]|0;
        $137 = HEAP32[$19>>2]|0;
        $138 = (($137) + 16|0);
        ;HEAP32[$1+0>>2]=HEAP32[$138+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$138+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$138+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$138+12>>2]|0;
        $139 = HEAP32[$132>>2]|0;
        $140 = (($132) + 4|0);
        $141 = HEAP32[$140>>2]|0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$1+12>>2]|0;
        $142 = (FUNCTION_TABLE_iiiiii[$134 & 255]($$byval_copy,$$byval_copy1,$139,$141,$117)|0);
        $hitType$0 = $142;
       }
      } else {
       $hitType$0 = $357;
      }
     } while(0);
     $143 = HEAP8[$22>>0]|0;
     $144 = ($143<<24>>24)==(0);
     $145 = ($hitType$0|0)==(0);
     $or$cond4 = $144 | $145;
     if (!($or$cond4)) {
      label = 25;
      break L4;
     }
     $176 = HEAP8[$25>>0]|0;
     $177 = ($176<<24>>24)==(0);
     $hitType$0$ = $177 ? $hitType$0 : 1;
     if ((($hitType$0$|0) == 2)) {
      $319 = (($117) + 40|0);
      $320 = Math_fround(HEAPF32[$319>>2]);
      $321 = Math_fround(HEAPF32[$23>>2]);
      $322 = !($320 <= $321);
      if (!($322)) {
       HEAPF32[$23>>2] = $320;
       HEAPF32[$aDist>>2] = $320;
       $323 = HEAP32[$13>>2]|0;
       $324 = (($323) + 4|0);
       ;HEAP32[$324+0>>2]=HEAP32[$117+0>>2]|0;HEAP32[$324+4>>2]=HEAP32[$117+4>>2]|0;HEAP32[$324+8>>2]=HEAP32[$117+8>>2]|0;
       $325 = ((($$2) + ($iSubHit$014<<6)|0) + 12|0);
       $326 = HEAP16[$325>>1]|0;
       $327 = (($323) + 16|0);
       HEAP16[$327>>1] = $326;
       $328 = ((($$2) + ($iSubHit$014<<6)|0) + 16|0);
       $329 = Math_fround(HEAPF32[$328>>2]);
       $330 = (($323) + 20|0);
       HEAPF32[$330>>2] = $329;
       $331 = ((($$2) + ($iSubHit$014<<6)|0) + 20|0);
       $332 = Math_fround(HEAPF32[$331>>2]);
       $333 = (($323) + 24|0);
       HEAPF32[$333>>2] = $332;
       $334 = ((($$2) + ($iSubHit$014<<6)|0) + 24|0);
       $335 = Math_fround(HEAPF32[$334>>2]);
       $336 = (($323) + 28|0);
       HEAPF32[$336>>2] = $335;
       $337 = ((($$2) + ($iSubHit$014<<6)|0) + 28|0);
       $338 = Math_fround(HEAPF32[$337>>2]);
       $339 = (($323) + 32|0);
       HEAPF32[$339>>2] = $338;
       $340 = ((($$2) + ($iSubHit$014<<6)|0) + 32|0);
       $341 = Math_fround(HEAPF32[$340>>2]);
       $342 = (($323) + 36|0);
       HEAPF32[$342>>2] = $341;
       $343 = ((($$2) + ($iSubHit$014<<6)|0) + 36|0);
       $344 = Math_fround(HEAPF32[$343>>2]);
       $345 = (($323) + 40|0);
       HEAPF32[$345>>2] = $344;
       $346 = ((($$2) + ($iSubHit$014<<6)|0) + 40|0);
       $347 = Math_fround(HEAPF32[$346>>2]);
       $348 = (($323) + 44|0);
       HEAPF32[$348>>2] = $347;
       $349 = (($323) + 48|0);
       $350 = ((($$2) + ($iSubHit$014<<6)|0) + 44|0);
       ;HEAP32[$349+0>>2]=HEAP32[$350+0>>2]|0;HEAP32[$349+4>>2]=HEAP32[$350+4>>2]|0;HEAP32[$349+8>>2]=HEAP32[$350+8>>2]|0;HEAP32[$349+12>>2]=HEAP32[$350+12>>2]|0;HEAP32[$349+16>>2]=HEAP32[$350+16>>2]|0;
       $351 = HEAP32[$13>>2]|0;
       $352 = (($351) + 68|0);
       HEAP8[$352>>0] = 1;
      }
     } else if ((($hitType$0$|0) == 1)) {
      $178 = HEAP32[$13>>2]|0;
      $179 = (($178) + 76|0);
      $180 = HEAP32[$179>>2]|0;
      $181 = ($180|0)==(0);
      if (!($181)) {
       $182 = HEAP8[$26>>0]|0;
       $183 = ($182<<24>>24)==(0);
       if (!($183)) {
        $184 = (($117) + 40|0);
        $185 = Math_fround(HEAPF32[$184>>2]);
        $186 = Math_fround(HEAPF32[$23>>2]);
        $187 = !($185 <= $186);
        if (!($187)) {
         $188 = (($178) + 80|0);
         $189 = HEAP32[$188>>2]|0;
         $190 = ($189|0)==($180|0);
         if ($190) {
          $191 = HEAP32[$12>>2]|0;
          ;HEAP32[$fd1+0>>2]=HEAP32[$191+0>>2]|0;HEAP32[$fd1+4>>2]=HEAP32[$191+4>>2]|0;HEAP32[$fd1+8>>2]=HEAP32[$191+8>>2]|0;HEAP32[$fd1+12>>2]=HEAP32[$191+12>>2]|0;
          $192 = (($191) + 16|0);
          $193 = HEAP16[$192>>1]|0;
          HEAP16[$27>>1] = $193;
          $194 = (($191) + 18|0);
          $195 = HEAP8[$194>>0]|0;
          HEAP8[$28>>0] = $195;
          $196 = $193&65535;
          $197 = $196 | 32768;
          $198 = $197&65535;
          HEAP16[$27>>1] = $198;
          HEAP32[$29>>2] = 0;
          HEAP32[$30>>2] = 0;
          HEAP32[$31>>2] = -1;
          HEAP16[$32>>1] = 0;
          ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;HEAP32[$33+16>>2]=0|0;HEAP32[$33+20>>2]=0|0;
          HEAPF32[$34>>2] = Math_fround(3.40282346638528859812E+38);
          HEAPF32[$35>>2] = Math_fround(0.0);
          HEAPF32[$36>>2] = Math_fround(0.0);
          HEAP8[$37>>0] = 0;
          HEAP32[$38>>2] = 0;
          HEAP32[$39>>2] = 0;
          HEAP32[$40>>2] = 0;
          HEAP32[$$byval_copy1>>2] = ((404440 + 8|0));
          $199 = HEAP8[$41>>0]|0;
          $200 = ($199<<24>>24)==(0);
          do {
           if ($200) {
            $201 = HEAP32[$179>>2]|0;
            $202 = ($201|0)==(0);
            if (!($202)) {
             $203 = HEAP32[$17>>2]|0;
             $204 = HEAP32[$21>>2]|0;
             $205 = HEAP16[$15>>1]|0;
             HEAP16[$2>>1] = $205;
             $206 = HEAP32[$16>>2]|0;
             $207 = HEAP32[$18>>2]|0;
             $208 = (__ZNK5physx14NpSceneQueries10multiQueryINS_12PxRaycastHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($203,$204,$$byval_copy1,$2,0,$fd1,$206,$207)|0);
             if (!($208)) {
              break;
             }
             $209 = HEAP32[$13>>2]|0;
             $210 = (($209) + 4|0);
             ;HEAP32[$210+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$210+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$210+8>>2]=HEAP32[$42+8>>2]|0;
             $211 = HEAP16[$32>>1]|0;
             $212 = (($209) + 16|0);
             HEAP16[$212>>1] = $211;
             $213 = Math_fround(HEAPF32[$33>>2]);
             $214 = (($209) + 20|0);
             HEAPF32[$214>>2] = $213;
             $215 = Math_fround(HEAPF32[$43>>2]);
             $216 = (($209) + 24|0);
             HEAPF32[$216>>2] = $215;
             $217 = Math_fround(HEAPF32[$44>>2]);
             $218 = (($209) + 28|0);
             HEAPF32[$218>>2] = $217;
             $219 = Math_fround(HEAPF32[$45>>2]);
             $220 = (($209) + 32|0);
             HEAPF32[$220>>2] = $219;
             $221 = Math_fround(HEAPF32[$46>>2]);
             $222 = (($209) + 36|0);
             HEAPF32[$222>>2] = $221;
             $223 = Math_fround(HEAPF32[$47>>2]);
             $224 = (($209) + 40|0);
             HEAPF32[$224>>2] = $223;
             $225 = Math_fround(HEAPF32[$34>>2]);
             $226 = (($209) + 44|0);
             HEAPF32[$226>>2] = $225;
             $227 = (($209) + 48|0);
             ;HEAP32[$227+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$227+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$227+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$227+12>>2]=HEAP32[$35+12>>2]|0;HEAP32[$227+16>>2]=HEAP32[$35+16>>2]|0;
             $228 = HEAP32[$13>>2]|0;
             $229 = (($228) + 68|0);
             HEAP8[$229>>0] = 1;
             $230 = HEAP32[$13>>2]|0;
             $231 = (($230) + 72|0);
             $232 = HEAP32[$231>>2]|0;
             $233 = (($230) + 80|0);
             $234 = HEAP32[$233>>2]|0;
             $235 = Math_fround(HEAPF32[$48>>2]);
             $236 = ($234|0)==(0);
             if ($236) {
              $270 = $230;$271 = $235;$newCount$0$lcssa$i = 0;
             } else {
              $i$02$i = 0;$newCount$01$i = $234;
              while(1) {
               $237 = ((($232) + ($i$02$i<<6)|0) + 40|0);
               $238 = Math_fround(HEAPF32[$237>>2]);
               $239 = $238 > $235;
               if ($239) {
                $240 = ((($232) + ($i$02$i<<6)|0) + 44|0);
                $241 = (($232) + ($i$02$i<<6)|0);
                $242 = ((($232) + ($i$02$i<<6)|0) + 36|0);
                $243 = ((($232) + ($i$02$i<<6)|0) + 32|0);
                $244 = ((($232) + ($i$02$i<<6)|0) + 28|0);
                $245 = ((($232) + ($i$02$i<<6)|0) + 24|0);
                $246 = ((($232) + ($i$02$i<<6)|0) + 20|0);
                $247 = ((($232) + ($i$02$i<<6)|0) + 16|0);
                $248 = ((($232) + ($i$02$i<<6)|0) + 12|0);
                $249 = (($newCount$01$i) + -1)|0;
                $250 = (($232) + ($249<<6)|0);
                $251 = ((($232) + ($249<<6)|0) + 12|0);
                $252 = HEAP16[$251>>1]|0;
                $253 = ((($232) + ($249<<6)|0) + 16|0);
                $254 = Math_fround(HEAPF32[$253>>2]);
                $255 = ((($232) + ($249<<6)|0) + 20|0);
                $256 = Math_fround(HEAPF32[$255>>2]);
                $257 = ((($232) + ($249<<6)|0) + 24|0);
                $258 = Math_fround(HEAPF32[$257>>2]);
                $259 = ((($232) + ($249<<6)|0) + 28|0);
                $260 = Math_fround(HEAPF32[$259>>2]);
                $261 = ((($232) + ($249<<6)|0) + 32|0);
                $262 = Math_fround(HEAPF32[$261>>2]);
                $263 = ((($232) + ($249<<6)|0) + 36|0);
                $264 = Math_fround(HEAPF32[$263>>2]);
                $265 = ((($232) + ($249<<6)|0) + 40|0);
                $266 = Math_fround(HEAPF32[$265>>2]);
                $267 = ((($232) + ($249<<6)|0) + 44|0);
                _memmove(($241|0),($250|0),12)|0;
                HEAP16[$248>>1] = $252;
                HEAPF32[$247>>2] = $254;
                HEAPF32[$246>>2] = $256;
                HEAPF32[$245>>2] = $258;
                HEAPF32[$244>>2] = $260;
                HEAPF32[$243>>2] = $262;
                HEAPF32[$242>>2] = $264;
                HEAPF32[$237>>2] = $266;
                _memmove(($240|0),($267|0),20)|0;
                $newCount$1$i = $249;
               } else {
                $newCount$1$i = $newCount$01$i;
               }
               $268 = (($i$02$i) + 1)|0;
               $exitcond$i = ($268|0)==($234|0);
               if ($exitcond$i) {
                break;
               } else {
                $i$02$i = $268;$newCount$01$i = $newCount$1$i;
               }
              }
              $$pre = HEAP32[$13>>2]|0;
              $$pre27 = Math_fround(HEAPF32[$48>>2]);
              $270 = $$pre;$271 = $$pre27;$newCount$0$lcssa$i = $newCount$1$i;
             }
             $269 = (($270) + 80|0);
             HEAP32[$269>>2] = $newCount$0$lcssa$i;
             HEAPF32[$23>>2] = $271;
             HEAPF32[$aDist>>2] = $271;
            }
           }
          } while(0);
          HEAP8[$41>>0] = 1;
          $272 = HEAP32[$13>>2]|0;
          $273 = (($272) + 80|0);
          $274 = HEAP32[$273>>2]|0;
          $275 = (($272) + 76|0);
          $276 = HEAP32[$275>>2]|0;
          $277 = ($274|0)==($276|0);
          if ($277) {
           $278 = HEAP32[$272>>2]|0;
           $279 = HEAP32[$278>>2]|0;
           $280 = (($272) + 72|0);
           $281 = HEAP32[$280>>2]|0;
           $282 = (FUNCTION_TABLE_iiii[$279 & 2047]($272,$281,$274)|0);
           $283 = $282&1;
           HEAP8[$26>>0] = $283;
           if (!($282)) {
            $$0 = 0;
            label = 48;
            break L4;
           }
           $284 = HEAP32[$13>>2]|0;
           $285 = (($284) + 80|0);
           HEAP32[$285>>2] = 0;
           $$pre28 = HEAP32[$13>>2]|0;
           $$phi$trans$insert = (($$pre28) + 80|0);
           $$pre29 = HEAP32[$$phi$trans$insert>>2]|0;
           $287 = $$pre28;$291 = $$pre29;
          } else {
           $287 = $272;$291 = $274;
          }
         } else {
          $287 = $178;$291 = $189;
         }
         $286 = (($287) + 72|0);
         $288 = HEAP32[$286>>2]|0;
         $289 = (($287) + 80|0);
         $290 = (($291) + 1)|0;
         HEAP32[$289>>2] = $290;
         $292 = (($288) + ($291<<6)|0);
         ;HEAP32[$292+0>>2]=HEAP32[$117+0>>2]|0;HEAP32[$292+4>>2]=HEAP32[$117+4>>2]|0;HEAP32[$292+8>>2]=HEAP32[$117+8>>2]|0;
         $293 = ((($$2) + ($iSubHit$014<<6)|0) + 12|0);
         $294 = HEAP16[$293>>1]|0;
         $295 = ((($288) + ($291<<6)|0) + 12|0);
         HEAP16[$295>>1] = $294;
         $296 = ((($$2) + ($iSubHit$014<<6)|0) + 16|0);
         $297 = Math_fround(HEAPF32[$296>>2]);
         $298 = ((($288) + ($291<<6)|0) + 16|0);
         HEAPF32[$298>>2] = $297;
         $299 = ((($$2) + ($iSubHit$014<<6)|0) + 20|0);
         $300 = Math_fround(HEAPF32[$299>>2]);
         $301 = ((($288) + ($291<<6)|0) + 20|0);
         HEAPF32[$301>>2] = $300;
         $302 = ((($$2) + ($iSubHit$014<<6)|0) + 24|0);
         $303 = Math_fround(HEAPF32[$302>>2]);
         $304 = ((($288) + ($291<<6)|0) + 24|0);
         HEAPF32[$304>>2] = $303;
         $305 = ((($$2) + ($iSubHit$014<<6)|0) + 28|0);
         $306 = Math_fround(HEAPF32[$305>>2]);
         $307 = ((($288) + ($291<<6)|0) + 28|0);
         HEAPF32[$307>>2] = $306;
         $308 = ((($$2) + ($iSubHit$014<<6)|0) + 32|0);
         $309 = Math_fround(HEAPF32[$308>>2]);
         $310 = ((($288) + ($291<<6)|0) + 32|0);
         HEAPF32[$310>>2] = $309;
         $311 = ((($$2) + ($iSubHit$014<<6)|0) + 36|0);
         $312 = Math_fround(HEAPF32[$311>>2]);
         $313 = ((($288) + ($291<<6)|0) + 36|0);
         HEAPF32[$313>>2] = $312;
         $314 = ((($$2) + ($iSubHit$014<<6)|0) + 40|0);
         $315 = Math_fround(HEAPF32[$314>>2]);
         $316 = ((($288) + ($291<<6)|0) + 40|0);
         HEAPF32[$316>>2] = $315;
         $317 = ((($288) + ($291<<6)|0) + 44|0);
         $318 = ((($$2) + ($iSubHit$014<<6)|0) + 44|0);
         ;HEAP32[$317+0>>2]=HEAP32[$318+0>>2]|0;HEAP32[$317+4>>2]=HEAP32[$318+4>>2]|0;HEAP32[$317+8>>2]=HEAP32[$318+8>>2]|0;HEAP32[$317+12>>2]=HEAP32[$318+12>>2]|0;HEAP32[$317+16>>2]=HEAP32[$318+16>>2]|0;
        }
       }
      }
     }
     $353 = (($iSubHit$014) + 1)|0;
     $354 = ($353>>>0)<($112>>>0);
     if ($354) {
      $iSubHit$014 = $353;
     } else {
      break;
     }
    }
   }
  }
  $355 = (($iShape$020) + 1)|0;
  $356 = ($355>>>0)<($aCount>>>0);
  if ($356) {
   $iShape$020 = $355;
  } else {
   $$0 = 1;
   label = 48;
   break;
  }
 }
 if ((label|0) == 25) {
  $146 = HEAP32[$13>>2]|0;
  $147 = (($146) + 4|0);
  ;HEAP32[$147+0>>2]=HEAP32[$117+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$117+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$117+8>>2]|0;
  $148 = ((($$2) + ($iSubHit$014<<6)|0) + 12|0);
  $149 = HEAP16[$148>>1]|0;
  $150 = (($146) + 16|0);
  HEAP16[$150>>1] = $149;
  $151 = ((($$2) + ($iSubHit$014<<6)|0) + 16|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = (($146) + 20|0);
  HEAPF32[$153>>2] = $152;
  $154 = ((($$2) + ($iSubHit$014<<6)|0) + 20|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = (($146) + 24|0);
  HEAPF32[$156>>2] = $155;
  $157 = ((($$2) + ($iSubHit$014<<6)|0) + 24|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = (($146) + 28|0);
  HEAPF32[$159>>2] = $158;
  $160 = ((($$2) + ($iSubHit$014<<6)|0) + 28|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = (($146) + 32|0);
  HEAPF32[$162>>2] = $161;
  $163 = ((($$2) + ($iSubHit$014<<6)|0) + 32|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = (($146) + 36|0);
  HEAPF32[$165>>2] = $164;
  $166 = ((($$2) + ($iSubHit$014<<6)|0) + 36|0);
  $167 = Math_fround(HEAPF32[$166>>2]);
  $168 = (($146) + 40|0);
  HEAPF32[$168>>2] = $167;
  $169 = ((($$2) + ($iSubHit$014<<6)|0) + 40|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = (($146) + 44|0);
  HEAPF32[$171>>2] = $170;
  $172 = (($146) + 48|0);
  $173 = ((($$2) + ($iSubHit$014<<6)|0) + 44|0);
  ;HEAP32[$172+0>>2]=HEAP32[$173+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$173+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$173+8>>2]|0;HEAP32[$172+12>>2]=HEAP32[$173+12>>2]|0;HEAP32[$172+16>>2]=HEAP32[$173+16>>2]|0;
  $174 = HEAP32[$13>>2]|0;
  $175 = (($174) + 68|0);
  HEAP8[$175>>0] = 1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 48) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN18MultiQueryCallbackIN5physx12PxRaycastHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18MultiQueryCallbackIN5physx12PxOverlapHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj($this,$aDist,$aPayload,$aCount) {
 $this = $this|0;
 $aDist = $aDist|0;
 $aPayload = $aPayload|0;
 $aCount = $aCount|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$not = 0, $$old = 0, $$phi$trans$insert = 0, $$phi$trans$insert28 = 0, $$pre = 0, $$pre26 = 0, $$pre27 = 0, $$pre29 = 0, $$sink$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0);
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $as = 0, $filterFlags = 0, $filteredHitFlags = 0, $globalPose = 0, $hitType$0 = 0, $hitType$0$ = 0, $hitType$0$$us = 0, $iShape$018 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond3$us = 0, $or$cond42 = 0, $phitmp = 0, $shapeHitType = 0, $tempBuf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy1 = sp + 120|0;
 $$byval_copy = sp + 88|0;
 $tempBuf = sp + 104|0;
 $as = sp + 72|0;
 $filterFlags = sp + 138|0;
 $shapeHitType = sp + 64|0;
 $filteredHitFlags = sp + 136|0;
 $globalPose = sp + 16|0;
 $0 = sp;
 $1 = sp + 48|0;
 HEAP32[$tempBuf>>2] = 0;
 $2 = (($tempBuf) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($tempBuf) + 8|0);
 HEAP32[$3>>2] = -1;
 $4 = ($aCount|0)==(0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($as) + 4|0);
 $6 = (($this) + 20|0);
 $7 = (($this) + 12|0);
 $8 = (($this) + 41|0);
 $9 = (($this) + 16|0);
 $10 = (($this) + 24|0);
 $11 = (($this) + 4|0);
 $12 = (($this) + 32|0);
 $13 = (($as) + 8|0);
 $14 = (($as) + 12|0);
 $15 = (($this) + 8|0);
 $16 = (($this) + 39|0);
 $17 = (($this) + 28|0);
 $18 = (($this) + 38|0);
 $19 = (($this) + 36|0);
 $iShape$018 = 0;
 L4: while(1) {
  HEAP32[$as>>2] = 0;
  HEAP32[$5>>2] = 0;
  $20 = (($aPayload) + ($iShape$018<<3)|0);
  __ZN5physx2Sq8populateERKNS0_13PrunerPayloadERNS0_13PxActorShape2E($20,$as);
  $21 = HEAP32[$6>>2]|0;
  $22 = (($21) + 16|0);
  $23 = HEAP16[$22>>1]|0;
  HEAP16[$filterFlags>>1] = $23;
  $24 = HEAP32[$7>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)!=(0);
  $28 = ($23<<16>>16)<(0);
  $or$cond42 = $27 | $28;
  $29 = HEAP8[$8>>0]|0;
  if ($or$cond42) {
   $30 = ($29<<24>>24)!=(0);
   $phitmp = $30 ? 2 : 1;
   $$old = $phitmp;
  } else {
   $$old = 2;
  }
  HEAP32[$shapeHitType>>2] = $$old;
  $31 = HEAP16[$9>>1]|0;
  HEAP16[$filteredHitFlags>>1] = $31;
  $32 = ($29<<24>>24)==(0);
  if ($32) {
   $33 = HEAP32[$10>>2]|0;
   $34 = HEAP32[$11>>2]|0;
   $35 = HEAP32[$12>>2]|0;
   $36 = (__ZL20applyAllPreFiltersSQPKN5physx2Sq13PxActorShape2ERNS_14PxQueryHitType4EnumERKNS_7PxFlagsINS_11PxQueryFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackERKNS_14NpSceneQueriesEPNS_20BatchQueryFilterDataERNS7_INS_9PxHitFlag4EnumEtEEj($as,$shapeHitType,$filterFlags,$21,$33,$34,$35,$filteredHitFlags)|0);
   $$not = $36 ^ 1;
   $37 = HEAP32[$shapeHitType>>2]|0;
   $38 = ($37|0)==(0);
   $or$cond = $38 | $$not;
   if (!($or$cond)) {
    $88 = $37;
    label = 7;
   }
  } else {
   $88 = $$old;
   label = 7;
  }
  do {
   if ((label|0) == 7) {
    label = 0;
    $39 = HEAP32[$13>>2]|0;
    $40 = HEAP32[$14>>2]|0;
    __ZN5physx2Sq13getGlobalPoseERKNS_3Scb5ShapeERKNS1_5ActorE($globalPose,$39,$40);
    $41 = (($39) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42 & 1;
    $44 = ($43|0)==(0);
    if ($44) {
     $52 = (($39) + 84|0);
     $$sink$i4 = $52;
    } else {
     $45 = (($39) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==(0|0);
     if ($47) {
      $48 = HEAP32[$39>>2]|0;
      $49 = $42 >>> 24;
      $50 = $49 & 15;
      $51 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($48,$50)|0);
      HEAP32[$45>>2] = $51;
      $188 = $51;
     } else {
      $188 = $46;
     }
     $$sink$i4 = $188;
    }
    $53 = HEAP32[$7>>2]|0;
    $54 = (($53) + 28|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($53) + 32|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($53) + 24|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($59) + ($57<<4)|0);
    $61 = ($57>>>0)<($55>>>0);
    $$ = $61 ? $60 : $tempBuf;
    $62 = HEAP32[$11>>2]|0;
    $63 = HEAP32[$15>>2]|0;
    $64 = (($63) + 12|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($63) + 16|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($62) + 3384|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = HEAP32[$65>>2]|0;
    $71 = HEAP32[$$sink$i4>>2]|0;
    $72 = ($70|0)>($71|0);
    if ($72) {
     $73 = ((($69) + (($71*28)|0)|0) + ($70<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (FUNCTION_TABLE_iiiiii[$74 & 255]($$sink$i4,$globalPose,$65,$67,0)|0);
     if (!($75)) {
      break;
     }
    } else {
     $76 = ((($69) + (($70*28)|0)|0) + ($71<<2)|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (FUNCTION_TABLE_iiiiii[$77 & 255]($65,$67,$$sink$i4,$globalPose,0)|0);
     if (!($78)) {
      break;
     }
    }
    $79 = HEAP16[$filterFlags>>1]|0;
    $80 = $79 & 8;
    $81 = ($80<<16>>16)==(0);
    $82 = HEAP32[$as>>2]|0;
    HEAP32[$$>>2] = $82;
    $83 = HEAP32[$5>>2]|0;
    $84 = (($$) + 4|0);
    HEAP32[$84>>2] = $83;
    if ($81) {
     $85 = HEAP8[$16>>0]|0;
     $86 = ($85<<24>>24)==(0);
     $87 = ($88|0)==(0);
     $or$cond3$us = $86 | $87;
     if (!($or$cond3$us)) {
      label = 34;
      break L4;
     }
     $89 = HEAP8[$18>>0]|0;
     $90 = ($89<<24>>24)==(0);
     $hitType$0$$us = $90 ? $88 : 1;
     if ((($hitType$0$$us|0) == 2)) {
      $91 = Math_fround(HEAPF32[$17>>2]);
      $92 = !($91 >= Math_fround(-1.0));
      if ($92) {
       break;
      }
      $93 = HEAP32[$7>>2]|0;
      $94 = (($93) + 4|0);
      ;HEAP32[$94+0>>2]=HEAP32[$$+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$$+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$$+8>>2]|0;HEAP32[$94+12>>2]=HEAP32[$$+12>>2]|0;
      $95 = HEAP32[$7>>2]|0;
      $96 = (($95) + 20|0);
      HEAP8[$96>>0] = 1;
      break;
     } else if (!((($hitType$0$$us|0) == 1))) {
      break;
     }
     $97 = HEAP32[$7>>2]|0;
     $98 = (($97) + 28|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ($99|0)==(0);
     if ($100) {
      break;
     }
     $101 = HEAP8[$19>>0]|0;
     $102 = ($101<<24>>24)==(0);
     if ($102) {
      break;
     }
     $103 = Math_fround(HEAPF32[$17>>2]);
     $104 = !($103 >= Math_fround(-1.0));
     if ($104) {
      break;
     }
     $105 = (($97) + 32|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ($106|0)==($99|0);
     if ($107) {
      $108 = HEAP32[$97>>2]|0;
      $109 = HEAP32[$108>>2]|0;
      $110 = (($97) + 24|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = (FUNCTION_TABLE_iiii[$109 & 2047]($97,$111,$99)|0);
      $113 = $112&1;
      HEAP8[$19>>0] = $113;
      if (!($112)) {
       $$0 = 0;
       label = 46;
       break L4;
      }
      $114 = HEAP32[$7>>2]|0;
      $115 = (($114) + 32|0);
      HEAP32[$115>>2] = 0;
      $$pre = HEAP32[$7>>2]|0;
      $$phi$trans$insert = (($$pre) + 32|0);
      $$pre26 = HEAP32[$$phi$trans$insert>>2]|0;
      $117 = $$pre;$121 = $$pre26;
     } else {
      $117 = $97;$121 = $106;
     }
     $116 = (($117) + 24|0);
     $118 = HEAP32[$116>>2]|0;
     $119 = (($117) + 32|0);
     $120 = (($121) + 1)|0;
     HEAP32[$119>>2] = $120;
     $122 = (($118) + ($121<<4)|0);
     ;HEAP32[$122+0>>2]=HEAP32[$$+0>>2]|0;HEAP32[$122+4>>2]=HEAP32[$$+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$$+8>>2]|0;HEAP32[$122+12>>2]=HEAP32[$$+12>>2]|0;
     break;
    }
    $123 = HEAP8[$8>>0]|0;
    $124 = ($123<<24>>24)==(0);
    do {
     if ($124) {
      $125 = HEAP32[$10>>2]|0;
      $126 = ($125|0)==(0|0);
      if (!($126)) {
       $129 = HEAP32[$125>>2]|0;
       $130 = (($129) + 4|0);
       $131 = HEAP32[$130>>2]|0;
       $132 = HEAP32[$6>>2]|0;
       $133 = (FUNCTION_TABLE_iiii[$131 & 2047]($125,$132,$$)|0);
       $hitType$0 = $133;
       break;
      }
      $127 = HEAP32[$12>>2]|0;
      $128 = ($127|0)==(0|0);
      if ($128) {
       $hitType$0 = $88;
      } else {
       $134 = HEAP32[$12>>2]|0;
       $135 = (($134) + 12|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = ($136|0)==(0|0);
       if ($137) {
        $hitType$0 = $88;
       } else {
        $138 = HEAP32[$6>>2]|0;
        ;HEAP32[$0+0>>2]=HEAP32[$138+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$138+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$138+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$138+12>>2]|0;
        $139 = HEAP32[$13>>2]|0;
        $140 = (($139) + 16|0);
        ;HEAP32[$1+0>>2]=HEAP32[$140+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$140+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$140+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$140+12>>2]|0;
        $141 = HEAP32[$134>>2]|0;
        $142 = (($134) + 4|0);
        $143 = HEAP32[$142>>2]|0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$1+12>>2]|0;
        $144 = (FUNCTION_TABLE_iiiiii[$136 & 255]($$byval_copy,$$byval_copy1,$141,$143,$$)|0);
        $hitType$0 = $144;
       }
      }
     } else {
      $hitType$0 = $88;
     }
    } while(0);
    $145 = HEAP8[$16>>0]|0;
    $146 = ($145<<24>>24)==(0);
    $147 = ($hitType$0|0)==(0);
    $or$cond3 = $146 | $147;
    if (!($or$cond3)) {
     label = 34;
     break L4;
    }
    $152 = HEAP8[$18>>0]|0;
    $153 = ($152<<24>>24)==(0);
    $hitType$0$ = $153 ? $hitType$0 : 1;
    if ((($hitType$0$|0) == 2)) {
     $180 = Math_fround(HEAPF32[$17>>2]);
     $181 = !($180 >= Math_fround(-1.0));
     if ($181) {
      break;
     }
     $182 = HEAP32[$7>>2]|0;
     $183 = (($182) + 4|0);
     ;HEAP32[$183+0>>2]=HEAP32[$$+0>>2]|0;HEAP32[$183+4>>2]=HEAP32[$$+4>>2]|0;HEAP32[$183+8>>2]=HEAP32[$$+8>>2]|0;HEAP32[$183+12>>2]=HEAP32[$$+12>>2]|0;
     $184 = HEAP32[$7>>2]|0;
     $185 = (($184) + 20|0);
     HEAP8[$185>>0] = 1;
     break;
    } else if (!((($hitType$0$|0) == 1))) {
     break;
    }
    $154 = HEAP32[$7>>2]|0;
    $155 = (($154) + 28|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = ($156|0)==(0);
    if (!($157)) {
     $158 = HEAP8[$19>>0]|0;
     $159 = ($158<<24>>24)==(0);
     if (!($159)) {
      $160 = Math_fround(HEAPF32[$17>>2]);
      $161 = !($160 >= Math_fround(-1.0));
      if (!($161)) {
       $162 = (($154) + 32|0);
       $163 = HEAP32[$162>>2]|0;
       $164 = ($163|0)==($156|0);
       if ($164) {
        $165 = HEAP32[$154>>2]|0;
        $166 = HEAP32[$165>>2]|0;
        $167 = (($154) + 24|0);
        $168 = HEAP32[$167>>2]|0;
        $169 = (FUNCTION_TABLE_iiii[$166 & 2047]($154,$168,$156)|0);
        $170 = $169&1;
        HEAP8[$19>>0] = $170;
        if (!($169)) {
         $$0 = 0;
         label = 46;
         break L4;
        }
        $171 = HEAP32[$7>>2]|0;
        $172 = (($171) + 32|0);
        HEAP32[$172>>2] = 0;
        $$pre27 = HEAP32[$7>>2]|0;
        $$phi$trans$insert28 = (($$pre27) + 32|0);
        $$pre29 = HEAP32[$$phi$trans$insert28>>2]|0;
        $174 = $$pre27;$178 = $$pre29;
       } else {
        $174 = $154;$178 = $163;
       }
       $173 = (($174) + 24|0);
       $175 = HEAP32[$173>>2]|0;
       $176 = (($174) + 32|0);
       $177 = (($178) + 1)|0;
       HEAP32[$176>>2] = $177;
       $179 = (($175) + ($178<<4)|0);
       ;HEAP32[$179+0>>2]=HEAP32[$$+0>>2]|0;HEAP32[$179+4>>2]=HEAP32[$$+4>>2]|0;HEAP32[$179+8>>2]=HEAP32[$$+8>>2]|0;HEAP32[$179+12>>2]=HEAP32[$$+12>>2]|0;
      }
     }
    }
   }
  } while(0);
  $186 = (($iShape$018) + 1)|0;
  $187 = ($186>>>0)<($aCount>>>0);
  if ($187) {
   $iShape$018 = $186;
  } else {
   $$0 = 1;
   label = 46;
   break;
  }
 }
 if ((label|0) == 34) {
  $148 = HEAP32[$7>>2]|0;
  $149 = (($148) + 4|0);
  ;HEAP32[$149+0>>2]=HEAP32[$$+0>>2]|0;HEAP32[$149+4>>2]=HEAP32[$$+4>>2]|0;HEAP32[$149+8>>2]=HEAP32[$$+8>>2]|0;HEAP32[$149+12>>2]=HEAP32[$$+12>>2]|0;
  $150 = HEAP32[$7>>2]|0;
  $151 = (($150) + 20|0);
  HEAP8[$151>>0] = 1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 46) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN18MultiQueryCallbackIN5physx12PxOverlapHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18MultiQueryCallbackIN5physx10PxSweepHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj($this,$aDist,$aPayload,$aCount) {
 $this = $this|0;
 $aDist = $aDist|0;
 $aPayload = $aPayload|0;
 $aCount = $aCount|0;
 var $$ = 0, $$0 = 0, $$8 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$not = 0, $$old = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre26 = Math_fround(0), $$pre27 = 0, $$pre28 = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0);
 var $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0;
 var $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0;
 var $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0;
 var $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0;
 var $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = 0;
 var $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = Math_fround(0), $as = 0, $brmerge = 0, $exitcond$i = 0, $fd1 = 0, $filterFlags = 0, $filteredHitFlags = 0, $globalPose = 0, $hitType$0 = 0, $hitType$0$ = 0, $i$02$i = 0, $iShape$019 = 0, $iSubHit$013 = 0, $newCount$0$lcssa$i = 0, $newCount$01$i = 0, $newCount$1$i = 0, $or$cond = 0, $or$cond3 = 0;
 var $or$cond37 = 0, $phitmp = 0, $shapeHitType = 0, $tempBuf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy1 = sp + 168|0;
 $$byval_copy = sp + 152|0;
 $tempBuf = sp + 104|0;
 $as = sp + 88|0;
 $filterFlags = sp + 240|0;
 $shapeHitType = sp + 44|0;
 $filteredHitFlags = sp + 242|0;
 $globalPose = sp + 16|0;
 $0 = sp + 236|0;
 $1 = sp;
 $2 = sp + 72|0;
 $fd1 = sp + 48|0;
 $3 = sp + 238|0;
 HEAP32[$tempBuf>>2] = 0;
 $4 = (($tempBuf) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($tempBuf) + 8|0);
 HEAP32[$5>>2] = -1;
 $6 = (($tempBuf) + 12|0);
 HEAP16[$6>>1] = 0;
 $7 = (($tempBuf) + 16|0);
 $8 = (($tempBuf) + 40|0);
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;
 HEAPF32[$8>>2] = Math_fround(3.40282346638528859812E+38);
 $9 = ($aCount|0)==(0);
 if ($9) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($as) + 4|0);
 $11 = (($this) + 20|0);
 $12 = (($this) + 12|0);
 $13 = (($this) + 41|0);
 $14 = (($this) + 16|0);
 $15 = (($this) + 24|0);
 $16 = (($this) + 4|0);
 $17 = (($this) + 32|0);
 $18 = (($as) + 8|0);
 $19 = (($as) + 12|0);
 $20 = (($this) + 8|0);
 $21 = (($this) + 72|0);
 $22 = (($this) + 39|0);
 $23 = (($this) + 28|0);
 $24 = (($this) + 68|0);
 $25 = (($this) + 44|0);
 $26 = (($this) + 38|0);
 $27 = (($this) + 36|0);
 $28 = (($fd1) + 16|0);
 $29 = (($fd1) + 18|0);
 $30 = (($$byval_copy1) + 4|0);
 $31 = (($$byval_copy1) + 8|0);
 $32 = (($$byval_copy1) + 12|0);
 $33 = (($$byval_copy1) + 16|0);
 $34 = (($$byval_copy1) + 20|0);
 $35 = (($$byval_copy1) + 44|0);
 $36 = (($$byval_copy1) + 52|0);
 $37 = (($$byval_copy1) + 56|0);
 $38 = (($$byval_copy1) + 60|0);
 $39 = (($$byval_copy1) + 64|0);
 $40 = (($this) + 37|0);
 $41 = (($$byval_copy1) + 4|0);
 $42 = (($$byval_copy1) + 24|0);
 $43 = (($$byval_copy1) + 28|0);
 $44 = (($$byval_copy1) + 32|0);
 $45 = (($$byval_copy1) + 36|0);
 $46 = (($$byval_copy1) + 40|0);
 $47 = (($$byval_copy1) + 48|0);
 $48 = (($41) + 40|0);
 $iShape$019 = 0;
 L4: while(1) {
  HEAP32[$as>>2] = 0;
  HEAP32[$10>>2] = 0;
  $49 = (($aPayload) + ($iShape$019<<3)|0);
  __ZN5physx2Sq8populateERKNS0_13PrunerPayloadERNS0_13PxActorShape2E($49,$as);
  $50 = HEAP32[$11>>2]|0;
  $51 = (($50) + 16|0);
  $52 = HEAP16[$51>>1]|0;
  HEAP16[$filterFlags>>1] = $52;
  $53 = HEAP32[$12>>2]|0;
  $54 = (($53) + 60|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)!=(0);
  $57 = ($52<<16>>16)<(0);
  $or$cond37 = $56 | $57;
  $58 = HEAP8[$13>>0]|0;
  if ($or$cond37) {
   $59 = ($58<<24>>24)!=(0);
   $phitmp = $59 ? 2 : 1;
   $$old = $phitmp;
  } else {
   $$old = 2;
  }
  HEAP32[$shapeHitType>>2] = $$old;
  $60 = HEAP16[$14>>1]|0;
  HEAP16[$filteredHitFlags>>1] = $60;
  $61 = ($58<<24>>24)==(0);
  if ($61) {
   $62 = HEAP32[$15>>2]|0;
   $63 = HEAP32[$16>>2]|0;
   $64 = HEAP32[$17>>2]|0;
   $65 = (__ZL20applyAllPreFiltersSQPKN5physx2Sq13PxActorShape2ERNS_14PxQueryHitType4EnumERKNS_7PxFlagsINS_11PxQueryFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackERKNS_14NpSceneQueriesEPNS_20BatchQueryFilterDataERNS7_INS_9PxHitFlag4EnumEtEEj($as,$shapeHitType,$filterFlags,$50,$62,$63,$64,$filteredHitFlags)|0);
   $$not = $65 ^ 1;
   $66 = HEAP32[$shapeHitType>>2]|0;
   $67 = ($66|0)==(0);
   $or$cond = $67 | $$not;
   if (!($or$cond)) {
    $368 = $66;
    label = 7;
   }
  } else {
   $368 = $$old;
   label = 7;
  }
  if ((label|0) == 7) {
   label = 0;
   $68 = HEAP32[$18>>2]|0;
   $69 = HEAP32[$19>>2]|0;
   __ZN5physx2Sq13getGlobalPoseERKNS_3Scb5ShapeERKNS1_5ActorE($globalPose,$68,$69);
   $70 = (($68) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = $71 & 1;
   $73 = ($72|0)==(0);
   if ($73) {
    $81 = (($68) + 84|0);
    $$sink$i = $81;
   } else {
    $74 = (($68) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($75|0)==(0|0);
    if ($76) {
     $77 = HEAP32[$68>>2]|0;
     $78 = $71 >>> 24;
     $79 = $78 & 15;
     $80 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($77,$79)|0);
     HEAP32[$74>>2] = $80;
     $369 = $80;
    } else {
     $369 = $75;
    }
    $$sink$i = $369;
   }
   $82 = HEAP32[$12>>2]|0;
   $83 = (($82) + 60|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($82) + 64|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($82) + 56|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($88) + (($86*48)|0)|0);
   $90 = ($86>>>0)<($84>>>0);
   $$ = $90 ? $89 : $tempBuf;
   $91 = HEAP32[$16>>2]|0;
   $92 = (($91) + 3376|0);
   $93 = HEAP32[$20>>2]|0;
   $94 = HEAP32[$21>>2]|0;
   $95 = HEAP8[$22>>0]|0;
   $96 = ($95<<24>>24)==(0);
   $$8 = $96 ? 4 : 64;
   $97 = HEAP16[$filteredHitFlags>>1]|0;
   $98 = $$8 | $97;
   HEAP16[$0>>1] = $98;
   $99 = Math_fround(HEAPF32[$23>>2]);
   $100 = HEAP8[$24>>0]|0;
   $101 = ($100<<24>>24)!=(0);
   $102 = $101 ? $25 : 0;
   $103 = (__ZN12GeomQueryAnyIN5physx10PxSweepHitEE7geomHitERKNS0_2Sq17SceneQueryManagerERKNS0_15MultiQueryInputERKNS3_9ShapeDataERKNS0_10PxGeometryERKNS0_11PxTransformENS0_7PxFlagsINS0_9PxHitFlag4EnumEtEEjPS1_fbPNS0_9PxBounds3E($92,$93,$94,$$sink$i,$globalPose,$0,0,$$,$99,0,$102)|0);
   $104 = ($103|0)==(0);
   if (!($104)) {
    $105 = HEAP16[$filterFlags>>1]|0;
    $106 = $105 & 8;
    $107 = ($106<<16>>16)==(0);
    $iSubHit$013 = 0;
    while(1) {
     $108 = (($$) + (($iSubHit$013*48)|0)|0);
     $109 = HEAP32[$as>>2]|0;
     HEAP32[$108>>2] = $109;
     $110 = HEAP32[$10>>2]|0;
     $111 = ((($$) + (($iSubHit$013*48)|0)|0) + 4|0);
     HEAP32[$111>>2] = $110;
     $112 = (($108) + 40|0);
     $113 = Math_fround(HEAPF32[$112>>2]);
     $114 = $113 == Math_fround(0.0);
     if ($114) {
      $115 = HEAP32[$20>>2]|0;
      $116 = (($115) + 4|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = Math_fround(HEAPF32[$117>>2]);
      $119 = Math_fround(-$118);
      $120 = (($117) + 4|0);
      $121 = Math_fround(HEAPF32[$120>>2]);
      $122 = Math_fround(-$121);
      $123 = (($117) + 8|0);
      $124 = Math_fround(HEAPF32[$123>>2]);
      $125 = Math_fround(-$124);
      $126 = ((($$) + (($iSubHit$013*48)|0)|0) + 28|0);
      HEAPF32[$126>>2] = $119;
      $127 = ((($$) + (($iSubHit$013*48)|0)|0) + 32|0);
      HEAPF32[$127>>2] = $122;
      $128 = ((($$) + (($iSubHit$013*48)|0)|0) + 36|0);
      HEAPF32[$128>>2] = $125;
     }
     $129 = HEAP8[$13>>0]|0;
     $130 = ($129<<24>>24)==(0);
     do {
      if ($130) {
       $131 = HEAP32[$15>>2]|0;
       $132 = ($131|0)==(0|0);
       if ($132) {
        $133 = HEAP32[$17>>2]|0;
        $134 = ($133|0)==(0|0);
        $brmerge = $134 | $107;
        if ($brmerge) {
         $hitType$0 = $368;
         break;
        }
       } else {
        if ($107) {
         $hitType$0 = $368;
         break;
        }
       }
       if (!($132)) {
        $135 = HEAP32[$131>>2]|0;
        $136 = (($135) + 4|0);
        $137 = HEAP32[$136>>2]|0;
        $138 = HEAP32[$11>>2]|0;
        $139 = (FUNCTION_TABLE_iiii[$137 & 2047]($131,$138,$108)|0);
        $hitType$0 = $139;
        break;
       }
       $140 = HEAP32[$17>>2]|0;
       $141 = (($140) + 12|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ($142|0)==(0|0);
       if ($143) {
        $hitType$0 = $368;
       } else {
        $144 = HEAP32[$11>>2]|0;
        ;HEAP32[$1+0>>2]=HEAP32[$144+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$144+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$144+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$144+12>>2]|0;
        $145 = HEAP32[$18>>2]|0;
        $146 = (($145) + 16|0);
        ;HEAP32[$2+0>>2]=HEAP32[$146+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$146+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$146+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$146+12>>2]|0;
        $147 = HEAP32[$140>>2]|0;
        $148 = (($140) + 4|0);
        $149 = HEAP32[$148>>2]|0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$2+12>>2]|0;
        $150 = (FUNCTION_TABLE_iiiiii[$142 & 255]($$byval_copy,$$byval_copy1,$147,$149,$108)|0);
        $hitType$0 = $150;
       }
      } else {
       $hitType$0 = $368;
      }
     } while(0);
     $151 = HEAP8[$22>>0]|0;
     $152 = ($151<<24>>24)==(0);
     $153 = ($hitType$0|0)==(0);
     $or$cond3 = $152 | $153;
     if (!($or$cond3)) {
      label = 25;
      break L4;
     }
     $185 = HEAP8[$26>>0]|0;
     $186 = ($185<<24>>24)==(0);
     $hitType$0$ = $186 ? $hitType$0 : 1;
     if ((($hitType$0$|0) == 1)) {
      $187 = HEAP32[$12>>2]|0;
      $188 = (($187) + 60|0);
      $189 = HEAP32[$188>>2]|0;
      $190 = ($189|0)==(0);
      if (!($190)) {
       $191 = HEAP8[$27>>0]|0;
       $192 = ($191<<24>>24)==(0);
       if (!($192)) {
        $193 = Math_fround(HEAPF32[$112>>2]);
        $194 = Math_fround(HEAPF32[$23>>2]);
        $195 = !($193 <= $194);
        if (!($195)) {
         $196 = (($187) + 64|0);
         $197 = HEAP32[$196>>2]|0;
         $198 = ($197|0)==($189|0);
         if ($198) {
          $199 = HEAP32[$11>>2]|0;
          ;HEAP32[$fd1+0>>2]=HEAP32[$199+0>>2]|0;HEAP32[$fd1+4>>2]=HEAP32[$199+4>>2]|0;HEAP32[$fd1+8>>2]=HEAP32[$199+8>>2]|0;HEAP32[$fd1+12>>2]=HEAP32[$199+12>>2]|0;
          $200 = (($199) + 16|0);
          $201 = HEAP16[$200>>1]|0;
          HEAP16[$28>>1] = $201;
          $202 = (($199) + 18|0);
          $203 = HEAP8[$202>>0]|0;
          HEAP8[$29>>0] = $203;
          $204 = $201&65535;
          $205 = $204 | 32768;
          $206 = $205&65535;
          HEAP16[$28>>1] = $206;
          HEAP32[$30>>2] = 0;
          HEAP32[$31>>2] = 0;
          HEAP32[$32>>2] = -1;
          HEAP16[$33>>1] = 0;
          ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;
          HEAPF32[$35>>2] = Math_fround(3.40282346638528859812E+38);
          HEAP8[$36>>0] = 0;
          HEAP32[$37>>2] = 0;
          HEAP32[$38>>2] = 0;
          HEAP32[$39>>2] = 0;
          HEAP32[$$byval_copy1>>2] = ((412736 + 8|0));
          $207 = HEAP8[$40>>0]|0;
          $208 = ($207<<24>>24)==(0);
          do {
           if ($208) {
            $209 = HEAP32[$188>>2]|0;
            $210 = ($209|0)==(0);
            if (!($210)) {
             $211 = HEAP32[$16>>2]|0;
             $212 = HEAP32[$20>>2]|0;
             $213 = HEAP16[$14>>1]|0;
             HEAP16[$3>>1] = $213;
             $214 = HEAP32[$15>>2]|0;
             $215 = HEAP32[$17>>2]|0;
             $216 = (__ZNK5physx14NpSceneQueries10multiQueryINS_10PxSweepHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKNS_12PxQueryCacheERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPNS_20BatchQueryFilterDataE($211,$212,$$byval_copy1,$3,0,$fd1,$214,$215)|0);
             if (!($216)) {
              break;
             }
             $217 = HEAP32[$12>>2]|0;
             $218 = (($217) + 4|0);
             ;HEAP32[$218+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$218+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$218+8>>2]=HEAP32[$41+8>>2]|0;
             $219 = HEAP16[$33>>1]|0;
             $220 = (($217) + 16|0);
             HEAP16[$220>>1] = $219;
             $221 = Math_fround(HEAPF32[$34>>2]);
             $222 = (($217) + 20|0);
             HEAPF32[$222>>2] = $221;
             $223 = Math_fround(HEAPF32[$42>>2]);
             $224 = (($217) + 24|0);
             HEAPF32[$224>>2] = $223;
             $225 = Math_fround(HEAPF32[$43>>2]);
             $226 = (($217) + 28|0);
             HEAPF32[$226>>2] = $225;
             $227 = Math_fround(HEAPF32[$44>>2]);
             $228 = (($217) + 32|0);
             HEAPF32[$228>>2] = $227;
             $229 = Math_fround(HEAPF32[$45>>2]);
             $230 = (($217) + 36|0);
             HEAPF32[$230>>2] = $229;
             $231 = Math_fround(HEAPF32[$46>>2]);
             $232 = (($217) + 40|0);
             HEAPF32[$232>>2] = $231;
             $233 = Math_fround(HEAPF32[$35>>2]);
             $234 = (($217) + 44|0);
             HEAPF32[$234>>2] = $233;
             $235 = HEAP32[$47>>2]|0;
             $236 = (($217) + 48|0);
             HEAP32[$236>>2] = $235;
             $237 = HEAP32[$12>>2]|0;
             $238 = (($237) + 52|0);
             HEAP8[$238>>0] = 1;
             $239 = HEAP32[$12>>2]|0;
             $240 = (($239) + 56|0);
             $241 = HEAP32[$240>>2]|0;
             $242 = (($239) + 64|0);
             $243 = HEAP32[$242>>2]|0;
             $244 = Math_fround(HEAPF32[$48>>2]);
             $245 = ($243|0)==(0);
             if ($245) {
              $280 = $239;$281 = $244;$newCount$0$lcssa$i = 0;
             } else {
              $i$02$i = 0;$newCount$01$i = $243;
              while(1) {
               $246 = ((($241) + (($i$02$i*48)|0)|0) + 40|0);
               $247 = Math_fround(HEAPF32[$246>>2]);
               $248 = $247 > $244;
               if ($248) {
                $249 = (($241) + (($i$02$i*48)|0)|0);
                $250 = ((($241) + (($i$02$i*48)|0)|0) + 44|0);
                $251 = ((($241) + (($i$02$i*48)|0)|0) + 36|0);
                $252 = ((($241) + (($i$02$i*48)|0)|0) + 32|0);
                $253 = ((($241) + (($i$02$i*48)|0)|0) + 28|0);
                $254 = ((($241) + (($i$02$i*48)|0)|0) + 24|0);
                $255 = ((($241) + (($i$02$i*48)|0)|0) + 20|0);
                $256 = ((($241) + (($i$02$i*48)|0)|0) + 16|0);
                $257 = ((($241) + (($i$02$i*48)|0)|0) + 12|0);
                $258 = (($newCount$01$i) + -1)|0;
                $259 = (($241) + (($258*48)|0)|0);
                $260 = ((($241) + (($258*48)|0)|0) + 12|0);
                $261 = HEAP16[$260>>1]|0;
                $262 = ((($241) + (($258*48)|0)|0) + 16|0);
                $263 = Math_fround(HEAPF32[$262>>2]);
                $264 = ((($241) + (($258*48)|0)|0) + 20|0);
                $265 = Math_fround(HEAPF32[$264>>2]);
                $266 = ((($241) + (($258*48)|0)|0) + 24|0);
                $267 = Math_fround(HEAPF32[$266>>2]);
                $268 = ((($241) + (($258*48)|0)|0) + 28|0);
                $269 = Math_fround(HEAPF32[$268>>2]);
                $270 = ((($241) + (($258*48)|0)|0) + 32|0);
                $271 = Math_fround(HEAPF32[$270>>2]);
                $272 = ((($241) + (($258*48)|0)|0) + 36|0);
                $273 = Math_fround(HEAPF32[$272>>2]);
                $274 = ((($241) + (($258*48)|0)|0) + 40|0);
                $275 = Math_fround(HEAPF32[$274>>2]);
                $276 = ((($241) + (($258*48)|0)|0) + 44|0);
                $277 = HEAP32[$276>>2]|0;
                _memmove(($249|0),($259|0),12)|0;
                HEAP16[$257>>1] = $261;
                HEAPF32[$256>>2] = $263;
                HEAPF32[$255>>2] = $265;
                HEAPF32[$254>>2] = $267;
                HEAPF32[$253>>2] = $269;
                HEAPF32[$252>>2] = $271;
                HEAPF32[$251>>2] = $273;
                HEAPF32[$246>>2] = $275;
                HEAP32[$250>>2] = $277;
                $newCount$1$i = $258;
               } else {
                $newCount$1$i = $newCount$01$i;
               }
               $278 = (($i$02$i) + 1)|0;
               $exitcond$i = ($278|0)==($243|0);
               if ($exitcond$i) {
                break;
               } else {
                $i$02$i = $278;$newCount$01$i = $newCount$1$i;
               }
              }
              $$pre = HEAP32[$12>>2]|0;
              $$pre26 = Math_fround(HEAPF32[$48>>2]);
              $280 = $$pre;$281 = $$pre26;$newCount$0$lcssa$i = $newCount$1$i;
             }
             $279 = (($280) + 64|0);
             HEAP32[$279>>2] = $newCount$0$lcssa$i;
             HEAPF32[$23>>2] = $281;
             HEAPF32[$aDist>>2] = $281;
            }
           }
          } while(0);
          HEAP8[$40>>0] = 1;
          $282 = HEAP32[$12>>2]|0;
          $283 = (($282) + 64|0);
          $284 = HEAP32[$283>>2]|0;
          $285 = (($282) + 60|0);
          $286 = HEAP32[$285>>2]|0;
          $287 = ($284|0)==($286|0);
          if ($287) {
           $288 = HEAP32[$282>>2]|0;
           $289 = HEAP32[$288>>2]|0;
           $290 = (($282) + 56|0);
           $291 = HEAP32[$290>>2]|0;
           $292 = (FUNCTION_TABLE_iiii[$289 & 2047]($282,$291,$284)|0);
           $293 = $292&1;
           HEAP8[$27>>0] = $293;
           if (!($292)) {
            $$0 = 0;
            label = 48;
            break L4;
           }
           $294 = HEAP32[$12>>2]|0;
           $295 = (($294) + 64|0);
           HEAP32[$295>>2] = 0;
           $$pre27 = HEAP32[$12>>2]|0;
           $$phi$trans$insert = (($$pre27) + 64|0);
           $$pre28 = HEAP32[$$phi$trans$insert>>2]|0;
           $297 = $$pre27;$301 = $$pre28;
          } else {
           $297 = $282;$301 = $284;
          }
         } else {
          $297 = $187;$301 = $197;
         }
         $296 = (($297) + 56|0);
         $298 = HEAP32[$296>>2]|0;
         $299 = (($297) + 64|0);
         $300 = (($301) + 1)|0;
         HEAP32[$299>>2] = $300;
         $302 = (($298) + (($301*48)|0)|0);
         ;HEAP32[$302+0>>2]=HEAP32[$108+0>>2]|0;HEAP32[$302+4>>2]=HEAP32[$108+4>>2]|0;HEAP32[$302+8>>2]=HEAP32[$108+8>>2]|0;
         $303 = ((($$) + (($iSubHit$013*48)|0)|0) + 12|0);
         $304 = HEAP16[$303>>1]|0;
         $305 = ((($298) + (($301*48)|0)|0) + 12|0);
         HEAP16[$305>>1] = $304;
         $306 = ((($$) + (($iSubHit$013*48)|0)|0) + 16|0);
         $307 = Math_fround(HEAPF32[$306>>2]);
         $308 = ((($298) + (($301*48)|0)|0) + 16|0);
         HEAPF32[$308>>2] = $307;
         $309 = ((($$) + (($iSubHit$013*48)|0)|0) + 20|0);
         $310 = Math_fround(HEAPF32[$309>>2]);
         $311 = ((($298) + (($301*48)|0)|0) + 20|0);
         HEAPF32[$311>>2] = $310;
         $312 = ((($$) + (($iSubHit$013*48)|0)|0) + 24|0);
         $313 = Math_fround(HEAPF32[$312>>2]);
         $314 = ((($298) + (($301*48)|0)|0) + 24|0);
         HEAPF32[$314>>2] = $313;
         $315 = ((($$) + (($iSubHit$013*48)|0)|0) + 28|0);
         $316 = Math_fround(HEAPF32[$315>>2]);
         $317 = ((($298) + (($301*48)|0)|0) + 28|0);
         HEAPF32[$317>>2] = $316;
         $318 = ((($$) + (($iSubHit$013*48)|0)|0) + 32|0);
         $319 = Math_fround(HEAPF32[$318>>2]);
         $320 = ((($298) + (($301*48)|0)|0) + 32|0);
         HEAPF32[$320>>2] = $319;
         $321 = ((($$) + (($iSubHit$013*48)|0)|0) + 36|0);
         $322 = Math_fround(HEAPF32[$321>>2]);
         $323 = ((($298) + (($301*48)|0)|0) + 36|0);
         HEAPF32[$323>>2] = $322;
         $324 = ((($$) + (($iSubHit$013*48)|0)|0) + 40|0);
         $325 = Math_fround(HEAPF32[$324>>2]);
         $326 = ((($298) + (($301*48)|0)|0) + 40|0);
         HEAPF32[$326>>2] = $325;
         $327 = ((($$) + (($iSubHit$013*48)|0)|0) + 44|0);
         $328 = HEAP32[$327>>2]|0;
         $329 = ((($298) + (($301*48)|0)|0) + 44|0);
         HEAP32[$329>>2] = $328;
        }
       }
      }
     } else if ((($hitType$0$|0) == 2)) {
      $330 = Math_fround(HEAPF32[$112>>2]);
      $331 = Math_fround(HEAPF32[$23>>2]);
      $332 = !($330 <= $331);
      if (!($332)) {
       HEAPF32[$23>>2] = $330;
       HEAPF32[$aDist>>2] = $330;
       $333 = HEAP32[$12>>2]|0;
       $334 = (($333) + 4|0);
       ;HEAP32[$334+0>>2]=HEAP32[$108+0>>2]|0;HEAP32[$334+4>>2]=HEAP32[$108+4>>2]|0;HEAP32[$334+8>>2]=HEAP32[$108+8>>2]|0;
       $335 = ((($$) + (($iSubHit$013*48)|0)|0) + 12|0);
       $336 = HEAP16[$335>>1]|0;
       $337 = (($333) + 16|0);
       HEAP16[$337>>1] = $336;
       $338 = ((($$) + (($iSubHit$013*48)|0)|0) + 16|0);
       $339 = Math_fround(HEAPF32[$338>>2]);
       $340 = (($333) + 20|0);
       HEAPF32[$340>>2] = $339;
       $341 = ((($$) + (($iSubHit$013*48)|0)|0) + 20|0);
       $342 = Math_fround(HEAPF32[$341>>2]);
       $343 = (($333) + 24|0);
       HEAPF32[$343>>2] = $342;
       $344 = ((($$) + (($iSubHit$013*48)|0)|0) + 24|0);
       $345 = Math_fround(HEAPF32[$344>>2]);
       $346 = (($333) + 28|0);
       HEAPF32[$346>>2] = $345;
       $347 = ((($$) + (($iSubHit$013*48)|0)|0) + 28|0);
       $348 = Math_fround(HEAPF32[$347>>2]);
       $349 = (($333) + 32|0);
       HEAPF32[$349>>2] = $348;
       $350 = ((($$) + (($iSubHit$013*48)|0)|0) + 32|0);
       $351 = Math_fround(HEAPF32[$350>>2]);
       $352 = (($333) + 36|0);
       HEAPF32[$352>>2] = $351;
       $353 = ((($$) + (($iSubHit$013*48)|0)|0) + 36|0);
       $354 = Math_fround(HEAPF32[$353>>2]);
       $355 = (($333) + 40|0);
       HEAPF32[$355>>2] = $354;
       $356 = ((($$) + (($iSubHit$013*48)|0)|0) + 40|0);
       $357 = Math_fround(HEAPF32[$356>>2]);
       $358 = (($333) + 44|0);
       HEAPF32[$358>>2] = $357;
       $359 = ((($$) + (($iSubHit$013*48)|0)|0) + 44|0);
       $360 = HEAP32[$359>>2]|0;
       $361 = (($333) + 48|0);
       HEAP32[$361>>2] = $360;
       $362 = HEAP32[$12>>2]|0;
       $363 = (($362) + 52|0);
       HEAP8[$363>>0] = 1;
      }
     }
     $364 = (($iSubHit$013) + 1)|0;
     $365 = ($364>>>0)<($103>>>0);
     if ($365) {
      $iSubHit$013 = $364;
     } else {
      break;
     }
    }
   }
  }
  $366 = (($iShape$019) + 1)|0;
  $367 = ($366>>>0)<($aCount>>>0);
  if ($367) {
   $iShape$019 = $366;
  } else {
   $$0 = 1;
   label = 48;
   break;
  }
 }
 if ((label|0) == 25) {
  $154 = HEAP32[$12>>2]|0;
  $155 = (($154) + 4|0);
  ;HEAP32[$155+0>>2]=HEAP32[$108+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$108+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$108+8>>2]|0;
  $156 = ((($$) + (($iSubHit$013*48)|0)|0) + 12|0);
  $157 = HEAP16[$156>>1]|0;
  $158 = (($154) + 16|0);
  HEAP16[$158>>1] = $157;
  $159 = ((($$) + (($iSubHit$013*48)|0)|0) + 16|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = (($154) + 20|0);
  HEAPF32[$161>>2] = $160;
  $162 = ((($$) + (($iSubHit$013*48)|0)|0) + 20|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = (($154) + 24|0);
  HEAPF32[$164>>2] = $163;
  $165 = ((($$) + (($iSubHit$013*48)|0)|0) + 24|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($154) + 28|0);
  HEAPF32[$167>>2] = $166;
  $168 = ((($$) + (($iSubHit$013*48)|0)|0) + 28|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = (($154) + 32|0);
  HEAPF32[$170>>2] = $169;
  $171 = ((($$) + (($iSubHit$013*48)|0)|0) + 32|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = (($154) + 36|0);
  HEAPF32[$173>>2] = $172;
  $174 = ((($$) + (($iSubHit$013*48)|0)|0) + 36|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (($154) + 40|0);
  HEAPF32[$176>>2] = $175;
  $177 = ((($$) + (($iSubHit$013*48)|0)|0) + 40|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = (($154) + 44|0);
  HEAPF32[$179>>2] = $178;
  $180 = ((($$) + (($iSubHit$013*48)|0)|0) + 44|0);
  $181 = HEAP32[$180>>2]|0;
  $182 = (($154) + 48|0);
  HEAP32[$182>>2] = $181;
  $183 = HEAP32[$12>>2]|0;
  $184 = (($183) + 52|0);
  HEAP8[$184>>0] = 1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 48) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN18MultiQueryCallbackIN5physx10PxSweepHitEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL20applyAllPreFiltersSQPKN5physx2Sq13PxActorShape2ERNS_14PxQueryHitType4EnumERKNS_7PxFlagsINS_11PxQueryFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackERKNS_14NpSceneQueriesEPNS_20BatchQueryFilterDataERNS7_INS_9PxHitFlag4EnumEtEEj($as,$hitType,$inFilterFlags,$filterData,$filterCall,$scene,$bfd,$queryFlags) {
 $as = $as|0;
 $hitType = $hitType|0;
 $inFilterFlags = $inFilterFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $scene = $scene|0;
 $bfd = $bfd|0;
 $queryFlags = $queryFlags|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge2 = 0, $outQueryFlags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 48|0;
 $$byval_copy = sp;
 $0 = sp + 66|0;
 $outQueryFlags = sp + 64|0;
 $1 = sp + 32|0;
 $2 = sp + 16|0;
 $3 = (($filterData) + 18|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = (($as) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 $8 = (($6) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($7))|0;
 $15 = $14;
 $16 = (($15) + 13|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($4<<24>>24)==($17<<24>>24);
 if (!($18)) {
  $19 = HEAP32[$scene>>2]|0;
  $20 = (($19) + 136|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_viii[$21 & 4095]($0,$scene,$4);
  $22 = HEAP8[$0>>0]|0;
  $23 = HEAP32[$5>>2]|0;
  $24 = (($23) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 & 4;
  $27 = ($26|0)==(0);
  if ($27) {
   $37 = $25 >>> 24;
   $38 = $37 & 15;
   $39 = ((444424 + ($38<<2)|0) + 24|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $23;
   $42 = (($40) + ($41))|0;
   $43 = $42;
   $44 = (($43) + 11|0);
   $$in = $44;
  } else {
   $28 = (($23) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $31 = HEAP32[$23>>2]|0;
    $32 = $25 >>> 24;
    $33 = $32 & 15;
    $34 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($31,$33)|0);
    HEAP32[$28>>2] = $34;
    $36 = $34;
   } else {
    $36 = $29;
   }
   $35 = (($36) + 3|0);
   $$in = $35;
  }
  $45 = HEAP8[$$in>>0]|0;
  $46 = $22 & 8;
  $47 = $46 & $45;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $49 = ($bfd|0)!=(0|0);
 if (!($49)) {
  $50 = HEAP32[$filterData>>2]|0;
  $51 = (($filterData) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 | $50;
  $54 = (($filterData) + 8|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = $53 | $55;
  $57 = (($filterData) + 12|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = $56 | $58;
  $60 = ($59|0)==(0);
  if (!($60)) {
   $61 = (($as) + 8|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($62) + 16|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = $64 & $50;
   $66 = (($62) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = $67 & $52;
   $69 = $68 | $65;
   $70 = (($62) + 24|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = $71 & $55;
   $73 = $69 | $72;
   $74 = (($62) + 28|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = $75 & $58;
   $77 = $73 | $76;
   $78 = ($77|0)==(0);
   if ($78) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $79 = HEAP16[$inFilterFlags>>1]|0;
 $80 = $79 & 4;
 $81 = ($80<<16>>16)==(0);
 if ($81) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $82 = ($filterCall|0)!=(0|0);
 $brmerge2 = $82 | $49;
 if (!($brmerge2)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $83 = HEAP16[$queryFlags>>1]|0;
 HEAP16[$outQueryFlags>>1] = $83;
 if ($82) {
  $84 = HEAP32[$filterCall>>2]|0;
  $85 = HEAP32[$84>>2]|0;
  $86 = (($as) + 4|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = HEAP32[$as>>2]|0;
  $89 = (FUNCTION_TABLE_iiiiii[$85 & 255]($filterCall,$filterData,$87,$88,$outQueryFlags)|0);
  HEAP32[$hitType>>2] = $89;
 } else {
  $90 = (($bfd) + 8|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   ;HEAP32[$1+0>>2]=HEAP32[$filterData+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$filterData+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$filterData+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$filterData+12>>2]|0;
   $93 = (($as) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 16|0);
   ;HEAP32[$2+0>>2]=HEAP32[$95+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$95+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$95+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$95+12>>2]|0;
   $96 = HEAP32[$bfd>>2]|0;
   $97 = (($bfd) + 4|0);
   $98 = HEAP32[$97>>2]|0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$2+12>>2]|0;
   $99 = (FUNCTION_TABLE_iiiiii[$91 & 255]($$byval_copy,$$byval_copy1,$96,$98,$outQueryFlags)|0);
   HEAP32[$hitType>>2] = $99;
  }
 }
 $100 = HEAP16[$queryFlags>>1]|0;
 $101 = $100 & -433;
 $102 = HEAP16[$outQueryFlags>>1]|0;
 $103 = $102&65535;
 $104 = $103 & 432;
 $105 = $104&65535;
 $106 = $105 | $101;
 HEAP16[$queryFlags>>1] = $106;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12GeomQueryAnyIN5physx10PxSweepHitEE7geomHitERKNS0_2Sq17SceneQueryManagerERKNS0_15MultiQueryInputERKNS3_9ShapeDataERKNS0_10PxGeometryERKNS0_11PxTransformENS0_7PxFlagsINS0_9PxHitFlag4EnumEtEEjPS1_fbPNS0_9PxBounds3E($sqm,$input,$sd,$sceneGeom,$pose,$hitFlags,$maxHits,$hits,$shrunkMaxDistance,$anyHit,$precomputedBounds) {
 $sqm = $sqm|0;
 $input = $input|0;
 $sd = $sd|0;
 $sceneGeom = $sceneGeom|0;
 $pose = $pose|0;
 $hitFlags = $hitFlags|0;
 $maxHits = $maxHits|0;
 $hits = $hits|0;
 $shrunkMaxDistance = Math_fround($shrunkMaxDistance);
 $anyHit = $anyHit|0;
 $precomputedBounds = $precomputedBounds|0;
 var $$0 = 0, $$in = 0, $$in1 = 0, $$in2 = 0, $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0;
 var $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $b1 = 0;
 var $mn = 0, $mx = 0, $tfar = 0, $tnear = 0, $vararg_buffer = 0, $worldCapsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $vararg_buffer = sp;
 $b1 = sp + 64|0;
 $mn = sp + 52|0;
 $mx = sp + 8|0;
 $tnear = sp + 20|0;
 $tfar = sp + 4|0;
 $worldCapsule = sp + 24|0;
 $0 = sp + 94|0;
 $1 = sp + 88|0;
 $2 = sp + 90|0;
 $3 = sp + 92|0;
 $4 = (($input) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($input) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = Math_fround(HEAPF32[$precomputedBounds>>2]);
 $9 = (($precomputedBounds) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($precomputedBounds) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($precomputedBounds) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($precomputedBounds) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($precomputedBounds) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($sceneGeom,$b1,$pose,Math_fround(0.0),0);
 $19 = Math_fround($14 - $8);
 $20 = Math_fround($16 - $10);
 $21 = Math_fround($18 - $12);
 $22 = Math_fround($19 * Math_fround(0.5));
 $23 = Math_fround($20 * Math_fround(0.5));
 $24 = Math_fround($21 * Math_fround(0.5));
 $25 = (($b1) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(HEAPF32[$b1>>2]);
 $28 = Math_fround($26 - $27);
 $29 = (($b1) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($b1) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($30 - $32);
 $34 = (($b1) + 20|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($b1) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 - $37);
 $39 = Math_fround($28 * Math_fround(0.5));
 $40 = Math_fround($33 * Math_fround(0.5));
 $41 = Math_fround($38 * Math_fround(0.5));
 $42 = Math_fround($22 + $39);
 $43 = Math_fround($23 + $40);
 $44 = Math_fround($24 + $41);
 $45 = Math_fround($42 * Math_fround(1.00999999046325683594));
 $46 = Math_fround($43 * Math_fround(1.00999999046325683594));
 $47 = Math_fround($44 * Math_fround(1.00999999046325683594));
 $48 = Math_fround($26 + $27);
 $49 = Math_fround($30 + $32);
 $50 = Math_fround($35 + $37);
 $51 = Math_fround($48 * Math_fround(0.5));
 $52 = Math_fround($49 * Math_fround(0.5));
 $53 = Math_fround($50 * Math_fround(0.5));
 $54 = Math_fround($51 - $45);
 $55 = Math_fround($52 - $46);
 $56 = Math_fround($53 - $47);
 HEAPF32[$mn>>2] = $54;
 $57 = (($mn) + 4|0);
 HEAPF32[$57>>2] = $55;
 $58 = (($mn) + 8|0);
 HEAPF32[$58>>2] = $56;
 $59 = Math_fround($45 + $51);
 $60 = Math_fround($46 + $52);
 $61 = Math_fround($47 + $53);
 HEAPF32[$mx>>2] = $59;
 $62 = (($mx) + 4|0);
 HEAPF32[$62>>2] = $60;
 $63 = (($mx) + 8|0);
 HEAPF32[$63>>2] = $61;
 $64 = HEAP32[$6>>2]|0;
 $65 = (($64) + 16|0);
 $66 = (($input) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (__ZN5physx2Gu17intersectRayAABB2ERKNS_6PxVec3ES3_S3_S3_fRfS4_($mn,$mx,$65,$67,$shrunkMaxDistance,$tnear,$tfar)|0);
 if ($68) {
  $$pre = Math_fround(HEAPF32[$tfar>>2]);
  $74 = $$pre;
 } else {
  $69 = Math_fround(HEAPF32[$tnear>>2]);
  $70 = Math_fround(HEAPF32[$tfar>>2]);
  $71 = $69 > $70;
  if ($71) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $74 = $70;
  }
 }
 $72 = HEAP32[$66>>2]|0;
 $73 = $74 < $shrunkMaxDistance;
 $75 = $73 ? $74 : $shrunkMaxDistance;
 $76 = (($input) + 20|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($sqm) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = HEAP32[$5>>2]|0;
 if ((($80|0) == 4)) {
  $127 = HEAP32[$sceneGeom>>2]|0;
  $128 = ((($79) + ($127<<2)|0) + 112|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = HEAP16[$hitFlags>>1]|0;
  HEAP16[$3>>1] = $130;
  $131 = (FUNCTION_TABLE_iiiiiifiif[$129 & 7]($sceneGeom,$pose,$5,$7,$72,$75,$hits,$3,$77)|0);
  $132 = $131&1;
  $$0 = $132;
  STACKTOP = sp;return ($$0|0);
 } else if ((($80|0) == 2)) {
  $107 = HEAP16[$hitFlags>>1]|0;
  $108 = $107 & 256;
  $109 = ($108<<16>>16)==(0);
  $110 = HEAP32[$sceneGeom>>2]|0;
  if ($109) {
   $112 = (($79) + ($110<<2)|0);
   $$in1 = $112;
  } else {
   $111 = ((($79) + ($110<<2)|0) + 28|0);
   $$in1 = $111;
  }
  $113 = HEAP32[$$in1>>2]|0;
  $114 = (($sd) + 148|0);
  HEAP16[$1>>1] = $107;
  $115 = (FUNCTION_TABLE_iiiiifiif[$113 & 31]($sceneGeom,$pose,$114,$72,$75,$hits,$1,$77)|0);
  $116 = $115&1;
  $$0 = $116;
  STACKTOP = sp;return ($$0|0);
 } else if ((($80|0) == 3)) {
  $117 = HEAP16[$hitFlags>>1]|0;
  $118 = $117 & 256;
  $119 = ($118<<16>>16)==(0);
  $120 = HEAP32[$sceneGeom>>2]|0;
  if ($119) {
   $122 = ((($79) + ($120<<2)|0) + 56|0);
   $$in = $122;
  } else {
   $121 = ((($79) + ($120<<2)|0) + 84|0);
   $$in = $121;
  }
  $123 = HEAP32[$$in>>2]|0;
  $124 = (($sd) + 148|0);
  HEAP16[$2>>1] = $117;
  $125 = (FUNCTION_TABLE_iiiiifiif[$123 & 31]($sceneGeom,$pose,$124,$72,$75,$hits,$2,$77)|0);
  $126 = $125&1;
  $$0 = $126;
  STACKTOP = sp;return ($$0|0);
 } else if ((($80|0) == 0)) {
  $81 = (($5) + 4|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = (($7) + 16|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$worldCapsule>>2] = $84;
  $85 = (($worldCapsule) + 4|0);
  $86 = (($7) + 20|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  HEAPF32[$85>>2] = $87;
  $88 = (($worldCapsule) + 8|0);
  $89 = (($7) + 24|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  HEAPF32[$88>>2] = $90;
  $91 = (($worldCapsule) + 12|0);
  $92 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$91>>2] = $92;
  $93 = (($worldCapsule) + 16|0);
  $94 = Math_fround(HEAPF32[$86>>2]);
  HEAPF32[$93>>2] = $94;
  $95 = (($worldCapsule) + 20|0);
  $96 = Math_fround(HEAPF32[$89>>2]);
  HEAPF32[$95>>2] = $96;
  $97 = (($worldCapsule) + 24|0);
  HEAPF32[$97>>2] = $82;
  $98 = HEAP16[$hitFlags>>1]|0;
  $99 = $98 & 256;
  $100 = ($99<<16>>16)==(0);
  $101 = HEAP32[$sceneGeom>>2]|0;
  if ($100) {
   $103 = (($79) + ($101<<2)|0);
   $$in2 = $103;
  } else {
   $102 = ((($79) + ($101<<2)|0) + 28|0);
   $$in2 = $102;
  }
  $104 = HEAP32[$$in2>>2]|0;
  HEAP16[$0>>1] = $98;
  $105 = (FUNCTION_TABLE_iiiiifiif[$104 & 31]($sceneGeom,$pose,$worldCapsule,$72,$75,$hits,$0,$77)|0);
  $106 = $105&1;
  $$0 = $106;
  STACKTOP = sp;return ($$0|0);
 } else {
  $133 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($133,4,437224,301,437576,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN18MultiQueryCallbackIN5physx10PxSweepHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN18MultiQueryCallbackIN5physx12PxOverlapHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN18MultiQueryCallbackIN5physx12PxRaycastHitEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq9ShapeDataC2ERKNS_10PxGeometryERKNS_11PxTransformEf($this,$g,$t,$inflation) {
 $this = $this|0;
 $g = $g|0;
 $t = $t|0;
 $inflation = Math_fround($inflation);
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0;
 var $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0;
 var $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0);
 var $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aabb = 0, $newBoxPrunerVolume = 0, $prunerBox = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 120|0;
 $aabb = sp;
 $newBoxPrunerVolume = sp + 24|0;
 $prunerBox = sp + 40|0;
 $1 = sp + 104|0;
 HEAP32[$this>>2] = (-1);
 $2 = (($this) + 56|0);
 $3 = Math_fround(HEAPF32[$t>>2]);
 HEAPF32[$2>>2] = $3;
 $4 = (($this) + 60|0);
 $5 = (($t) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($this) + 64|0);
 $8 = (($t) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($this) + 68|0);
 $11 = (($t) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$10>>2] = $12;
 $13 = (($this) + 72|0);
 $14 = (($t) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$13>>2] = $15;
 $16 = (($this) + 76|0);
 $17 = (($t) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $18;
 $19 = (($this) + 80|0);
 $20 = (($t) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 $22 = (($this) + 144|0);
 HEAP32[$22>>2] = $g;
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($this,$g);
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($this,$aabb,$2,$inflation,0);
 $23 = Math_fround(HEAPF32[$2>>2]);
 $24 = Math_fround(HEAPF32[$4>>2]);
 $25 = Math_fround(HEAPF32[$7>>2]);
 $26 = Math_fround(HEAPF32[$10>>2]);
 $27 = Math_fround($23 + $23);
 $28 = Math_fround($24 + $24);
 $29 = Math_fround($25 + $25);
 $30 = Math_fround($23 * $27);
 $31 = Math_fround($24 * $28);
 $32 = Math_fround($25 * $29);
 $33 = Math_fround($27 * $24);
 $34 = Math_fround($27 * $25);
 $35 = Math_fround($27 * $26);
 $36 = Math_fround($28 * $25);
 $37 = Math_fround($28 * $26);
 $38 = Math_fround($29 * $26);
 $39 = Math_fround(Math_fround(1.0) - $31);
 $40 = Math_fround($39 - $32);
 $41 = Math_fround($33 + $38);
 $42 = Math_fround($34 - $37);
 $43 = Math_fround($33 - $38);
 $44 = Math_fround(Math_fround(1.0) - $30);
 $45 = Math_fround($44 - $32);
 $46 = Math_fround($36 + $35);
 $47 = Math_fround($34 + $37);
 $48 = Math_fround($36 - $35);
 $49 = Math_fround($44 - $31);
 $50 = (($this) + 84|0);
 HEAPF32[$50>>2] = $40;
 $51 = (($this) + 88|0);
 HEAPF32[$51>>2] = $41;
 $52 = (($this) + 92|0);
 HEAPF32[$52>>2] = $42;
 $53 = (($this) + 96|0);
 HEAPF32[$53>>2] = $43;
 $54 = (($this) + 100|0);
 HEAPF32[$54>>2] = $45;
 $55 = (($this) + 104|0);
 HEAPF32[$55>>2] = $46;
 $56 = (($this) + 108|0);
 HEAPF32[$56>>2] = $47;
 $57 = (($this) + 112|0);
 HEAPF32[$57>>2] = $48;
 $58 = (($this) + 116|0);
 HEAPF32[$58>>2] = $49;
 $59 = Math_fround(HEAPF32[$aabb>>2]);
 $60 = (($aabb) + 12|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($59 + $61);
 $63 = (($aabb) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($aabb) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($64 + $66);
 $68 = (($aabb) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($aabb) + 20|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($69 + $71);
 $73 = Math_fround($62 * Math_fround(0.5));
 $74 = Math_fround($67 * Math_fround(0.5));
 $75 = Math_fround($72 * Math_fround(0.5));
 $76 = Math_fround($61 - $59);
 $77 = Math_fround($66 - $64);
 $78 = Math_fround($71 - $69);
 $79 = Math_fround($76 * Math_fround(0.5));
 $80 = Math_fround($77 * Math_fround(0.5));
 $81 = Math_fround($78 * Math_fround(0.5));
 $82 = Math_fround($79 * Math_fround(1.00999999046325683594));
 $83 = Math_fround($80 * Math_fround(1.00999999046325683594));
 $84 = Math_fround($81 * Math_fround(1.00999999046325683594));
 $85 = Math_fround($73 - $82);
 $86 = Math_fround($74 - $83);
 $87 = Math_fround($75 - $84);
 $88 = Math_fround($73 + $82);
 $89 = Math_fround($74 + $83);
 $90 = Math_fround($75 + $84);
 $91 = (($this) + 120|0);
 HEAPF32[$91>>2] = $85;
 $92 = (($this) + 124|0);
 HEAPF32[$92>>2] = $86;
 $93 = (($this) + 128|0);
 HEAPF32[$93>>2] = $87;
 $94 = (($this) + 132|0);
 HEAPF32[$94>>2] = $88;
 $95 = (($this) + 136|0);
 HEAPF32[$95>>2] = $89;
 $96 = (($this) + 140|0);
 HEAPF32[$96>>2] = $90;
 $97 = HEAP32[$g>>2]|0;
 if ((($97|0) == 3)) {
  $98 = (($this) + 148|0);
  $99 = (($this) + 184|0);
  $100 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$99>>2] = $100;
  $101 = Math_fround(HEAPF32[$16>>2]);
  $102 = (($this) + 188|0);
  HEAPF32[$102>>2] = $101;
  $103 = Math_fround(HEAPF32[$19>>2]);
  $104 = (($this) + 192|0);
  HEAPF32[$104>>2] = $103;
  $105 = (($this) + 196|0);
  $106 = (($this) + 4|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  HEAPF32[$105>>2] = $107;
  $108 = (($this) + 8|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($this) + 200|0);
  HEAPF32[$110>>2] = $109;
  $111 = (($this) + 12|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($this) + 204|0);
  HEAPF32[$113>>2] = $112;
  HEAPF32[$98>>2] = $40;
  $114 = (($this) + 152|0);
  HEAPF32[$114>>2] = $41;
  $115 = (($this) + 156|0);
  HEAPF32[$115>>2] = $42;
  $116 = (($this) + 160|0);
  HEAPF32[$116>>2] = $43;
  $117 = (($this) + 164|0);
  HEAPF32[$117>>2] = $45;
  $118 = (($this) + 168|0);
  HEAPF32[$118>>2] = $46;
  $119 = (($this) + 172|0);
  HEAPF32[$119>>2] = $47;
  $120 = (($this) + 176|0);
  HEAPF32[$120>>2] = $48;
  $121 = (($this) + 180|0);
  HEAPF32[$121>>2] = $49;
  STACKTOP = sp;return;
 } else if ((($97|0) == 4)) {
  $165 = (($this) + 32|0);
  $166 = HEAP32[$165>>2]|0;
  __ZN5physx2Gu22computeOBBAroundConvexERNS0_3BoxERKNS_20PxConvexMeshGeometryEPKNS_12PxConvexMeshERKNS_11PxTransformE($prunerBox,$this,$166,$2);
  $167 = Math_fround(HEAPF32[$prunerBox>>2]);
  HEAPF32[$50>>2] = $167;
  $168 = (($prunerBox) + 4|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  HEAPF32[$51>>2] = $169;
  $170 = (($prunerBox) + 8|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  HEAPF32[$52>>2] = $171;
  $172 = (($prunerBox) + 12|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  HEAPF32[$53>>2] = $173;
  $174 = (($prunerBox) + 16|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  HEAPF32[$54>>2] = $175;
  $176 = (($prunerBox) + 20|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  HEAPF32[$55>>2] = $177;
  $178 = (($prunerBox) + 24|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  HEAPF32[$56>>2] = $179;
  $180 = (($prunerBox) + 28|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  HEAPF32[$57>>2] = $181;
  $182 = (($prunerBox) + 32|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  HEAPF32[$58>>2] = $183;
  $184 = (($prunerBox) + 48|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = (($prunerBox) + 52|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = (($prunerBox) + 56|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  HEAP32[$1>>2] = 3;
  $190 = (($1) + 4|0);
  HEAPF32[$190>>2] = $185;
  $191 = (($1) + 8|0);
  HEAPF32[$191>>2] = $187;
  $192 = (($1) + 12|0);
  HEAPF32[$192>>2] = $189;
  __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($this,$1);
  __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$prunerBox);
  $193 = Math_fround(HEAPF32[$0>>2]);
  $194 = (($0) + 4|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($0) + 8|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = (($0) + 12|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = (($prunerBox) + 36|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (($prunerBox) + 40|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = (($prunerBox) + 44|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  HEAPF32[$2>>2] = $193;
  HEAPF32[$4>>2] = $195;
  HEAPF32[$7>>2] = $197;
  HEAPF32[$10>>2] = $199;
  HEAPF32[$13>>2] = $201;
  HEAPF32[$16>>2] = $203;
  HEAPF32[$19>>2] = $205;
  STACKTOP = sp;return;
 } else if ((($97|0) == 2)) {
  $122 = (($this) + 148|0);
  $123 = Math_fround($23 * Math_fround(2.0));
  $124 = Math_fround($26 * Math_fround(2.0));
  $125 = Math_fround($26 * $124);
  $126 = Math_fround($125 + Math_fround(-1.0));
  $127 = Math_fround($23 * $123);
  $128 = Math_fround($127 + $126);
  $129 = Math_fround($25 * $124);
  $130 = Math_fround($123 * $24);
  $131 = Math_fround($129 + $130);
  $132 = Math_fround($124 * $24);
  $133 = Math_fround($123 * $25);
  $134 = Math_fround($133 - $132);
  $135 = (($this) + 8|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = Math_fround($136 * $128);
  $138 = Math_fround($136 * $131);
  $139 = Math_fround($136 * $134);
  $140 = Math_fround(HEAPF32[$13>>2]);
  $141 = Math_fround($140 + $137);
  $142 = Math_fround(HEAPF32[$16>>2]);
  $143 = Math_fround($142 + $138);
  $144 = Math_fround(HEAPF32[$19>>2]);
  $145 = Math_fround($139 + $144);
  HEAPF32[$122>>2] = $141;
  $146 = (($this) + 152|0);
  HEAPF32[$146>>2] = $143;
  $147 = (($this) + 156|0);
  HEAPF32[$147>>2] = $145;
  $148 = Math_fround($140 - $137);
  $149 = Math_fround($142 - $138);
  $150 = Math_fround($144 - $139);
  $151 = (($this) + 160|0);
  HEAPF32[$151>>2] = $148;
  $152 = (($this) + 164|0);
  HEAPF32[$152>>2] = $149;
  $153 = (($this) + 168|0);
  HEAPF32[$153>>2] = $150;
  $154 = (($this) + 4|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = (($this) + 172|0);
  HEAPF32[$156>>2] = $155;
  HEAP32[$newBoxPrunerVolume>>2] = 3;
  $157 = (($newBoxPrunerVolume) + 4|0);
  $158 = (($newBoxPrunerVolume) + 8|0);
  $159 = (($newBoxPrunerVolume) + 12|0);
  $160 = (($g) + 4|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = (($g) + 8|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = Math_fround($161 + $163);
  HEAPF32[$157>>2] = $164;
  HEAPF32[$158>>2] = $161;
  HEAPF32[$159>>2] = $161;
  __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($this,$newBoxPrunerVolume);
  STACKTOP = sp;return;
 } else if ((($97|0) == 0)) {
  $206 = (($this) + 148|0);
  $207 = (($this) + 4|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = Math_fround(HEAPF32[$13>>2]);
  $210 = Math_fround(HEAPF32[$16>>2]);
  $211 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$206>>2] = $209;
  $212 = (($this) + 152|0);
  HEAPF32[$212>>2] = $210;
  $213 = (($this) + 156|0);
  HEAPF32[$213>>2] = $211;
  $214 = (($this) + 160|0);
  HEAPF32[$214>>2] = $208;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpShapeC2ERKNS_10PxGeometryENS_7PxFlagsINS_11PxShapeFlag4EnumEhEEPKttb($this,$geometry,$shapeFlags,$materialIndices,$materialCount,$isExclusive) {
 $this = $this|0;
 $geometry = $geometry|0;
 $shapeFlags = $shapeFlags|0;
 $materialIndices = $materialIndices|0;
 $materialCount = $materialCount|0;
 $isExclusive = $isExclusive|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $storemerge$i$i = 0, $storemerge$v$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP16[$1>>1] = 7;
 $2 = (($this) + 6|0);
 HEAP16[$2>>1] = 3;
 HEAP32[$this>>2] = ((438792 + 8|0));
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = ((424432 + 8|0));
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = 1;
 HEAP32[$this>>2] = ((437760 + 8|0));
 HEAP32[$4>>2] = ((437760 + 184|0));
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP8[$shapeFlags>>0]|0;
 $8 = (($this) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 36|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 48|0);
 HEAP8[$0>>0] = $7;
 __ZN5physx2Sc9ShapeCoreC2ERKNS_10PxGeometryENS_7PxFlagsINS_11PxShapeFlag4EnumEhEEPKtt($11,$geometry,$0,$materialIndices,$materialCount);
 $12 = HEAP32[$10>>2]|0;
 $13 = $12 & -251658241;
 $storemerge$v$i$i = $isExclusive ? 16777216 : 33554432;
 $storemerge$i$i = $13 | $storemerge$v$i$i;
 HEAP32[$10>>2] = $storemerge$i$i;
 $14 = (($this) + 192|0);
 HEAP32[$14>>2] = 0;
 $15 = $isExclusive&1;
 $16 = (($this) + 196|0);
 HEAP8[$16>>0] = $15;
 HEAP32[$3>>2] = 0;
 $17 = (__ZN5physx7NpShape19getMeshRefCountableEv($this)|0);
 $18 = ($17|0)==(0|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($17) + 4|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($19)|0);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShapeD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx7NpShapeD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn12_N5physx7NpShapeD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -12|0);
 __ZN5physx7NpShapeD2Ev($1);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShapeD2Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$0$i$i = 0, $$pn$i = 0, $$pn$in$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((437760 + 8|0));
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = ((437760 + 184|0));
 $1 = (__ZN5physx7NpShape19getMeshRefCountableEv($this)|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 4|0);
  $4 = (__ZN5physx6shdfnd15atomicDecrementEPVi($3)|0);
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = HEAP32[$1>>2]|0;
   $7 = (($6) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vi[$8 & 4095]($1);
  }
 }
 $9 = (($this) + 32|0);
 $10 = (($this) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 2;
 $13 = ($12|0)==(0);
 if ($13) {
  $24 = (($this) + 48|0);
  $25 = (__ZNK5physx2Sc9ShapeCore20getNbMaterialIndicesEv($24)|0);
  $$0$i = $25;
 } else {
  $14 = (($this) + 40|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $17 = HEAP32[$9>>2]|0;
   $18 = $11 >>> 24;
   $19 = $18 & 15;
   $20 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($17,$19)|0);
   HEAP32[$14>>2] = $20;
   $22 = $20;
  } else {
   $22 = $15;
  }
  $21 = (($22) + 60|0);
  $23 = HEAP16[$21>>1]|0;
  $$0$i = $23;
 }
 $26 = ($$0$i<<16>>16)==(0);
 $$pre = (($this) + 48|0);
 if ($26) {
  __ZN5physx2Sc9ShapeCoreD2Ev($$pre);
  STACKTOP = sp;return;
 }
 $27 = (($this) + 40|0);
 $28 = $$0$i&65535;
 $i$03 = 0;
 while(1) {
  $29 = HEAP32[424544>>2]|0;
  $30 = HEAP32[$10>>2]|0;
  $31 = $30 & 2;
  $32 = ($31|0)==(0);
  if ($32) {
   $54 = (__ZNK5physx2Sc9ShapeCore18getMaterialIndicesEv($$pre)|0);
   $55 = (($54) + ($i$03<<1)|0);
   $56 = HEAP16[$55>>1]|0;
   $57 = $56&65535;
   $58 = (($29) + 52|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + ($57<<2)|0);
   $$pn$in$i = $60;
  } else {
   $33 = HEAP32[$9>>2]|0;
   $34 = HEAP32[$27>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    $36 = $30 >>> 24;
    $37 = $36 & 15;
    $38 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($33,$37)|0);
    HEAP32[$27>>2] = $38;
    $40 = $38;
   } else {
    $40 = $34;
   }
   $39 = (($40) + 60|0);
   $41 = HEAP16[$39>>1]|0;
   $42 = ($41<<16>>16)==(1);
   $43 = (($40) + 56|0);
   if ($42) {
    $$0$i$i = $43;
   } else {
    $44 = HEAP32[$43>>2]|0;
    $45 = (($33) + 2488|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + ($44<<1)|0);
    $$0$i$i = $47;
   }
   $48 = (($$0$i$i) + ($i$03<<1)|0);
   $49 = HEAP16[$48>>1]|0;
   $50 = $49&65535;
   $51 = (($29) + 52|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + ($50<<2)|0);
   $$pn$in$i = $53;
  }
  $$pn$i = HEAP32[$$pn$in$i>>2]|0;
  $61 = (($$pn$i) + 12|0);
  $62 = (($$pn$i) + 16|0);
  $63 = (__ZN5physx6shdfnd15atomicDecrementEPVi($62)|0);
  $64 = ($63|0)==(0);
  if ($64) {
   $65 = HEAP32[$61>>2]|0;
   $66 = (($65) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($61);
  }
  $68 = (($i$03) + 1)|0;
  $exitcond = ($68|0)==($28|0);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $68;
  }
 }
 __ZN5physx2Sc9ShapeCoreD2Ev($$pre);
 STACKTOP = sp;return;
}
function __ZThn12_N5physx7NpShapeD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -12|0);
 __ZN5physx7NpShapeD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory14onShapeReleaseEPNS_7PxShapeE($0,$this);
 $1 = (($this) + 32|0);
 __ZN5physx9NpDestroyERNS_3Scb4BaseE($1);
 STACKTOP = sp;return;
}
function __ZThn12_N5physx7NpShape14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -12|0);
 $1 = HEAP32[420520>>2]|0;
 __ZN5physx9NpFactory14onShapeReleaseEPNS_7PxShapeE($1,$0);
 $2 = (($0) + 32|0);
 __ZN5physx9NpDestroyERNS_3Scb4BaseE($2);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 __ZN5physx2Sc9ShapeCore15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 $1 = HEAP32[$stream>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 192|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($stream,$5);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$0$i = 0, $$0$i$i = 0, $$pn$i = 0, $$pn$in$i = 0, $$sink$i = 0, $$sink$i2 = 0, $$sink$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$010 = 0, $mesh$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (($this) + 116|0);
 $2 = HEAP32[$1>>2]|0;
 if ((($2|0) == 4)) {
  $3 = (($this) + 36|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4 & 1;
  $6 = ($5|0)==(0);
  if ($6) {
   $$sink$i = $1;
  } else {
   $7 = (($this) + 40|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $10 = HEAP32[$0>>2]|0;
    $11 = $4 >>> 24;
    $12 = $11 & 15;
    $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($10,$12)|0);
    HEAP32[$7>>2] = $13;
    $102 = $13;
   } else {
    $102 = $8;
   }
   $$sink$i = $102;
  }
  $14 = (($$sink$i) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $mesh$0 = $15;
  label = 17;
 } else if ((($2|0) == 6)) {
  $16 = (($this) + 36|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17 & 1;
  $19 = ($18|0)==(0);
  if ($19) {
   $$sink$i2 = $1;
  } else {
   $20 = (($this) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   if ($22) {
    $23 = HEAP32[$0>>2]|0;
    $24 = $17 >>> 24;
    $25 = $24 & 15;
    $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($23,$25)|0);
    HEAP32[$20>>2] = $26;
    $103 = $26;
   } else {
    $103 = $21;
   }
   $$sink$i2 = $103;
  }
  $27 = (($$sink$i2) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $mesh$0 = $28;
  label = 17;
 } else if ((($2|0) == 5)) {
  $29 = (($this) + 36|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = $30 & 1;
  $32 = ($31|0)==(0);
  if ($32) {
   $$sink$i5 = $1;
  } else {
   $33 = (($this) + 40|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    $36 = HEAP32[$0>>2]|0;
    $37 = $30 >>> 24;
    $38 = $37 & 15;
    $39 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($36,$38)|0);
    HEAP32[$33>>2] = $39;
    $104 = $39;
   } else {
    $104 = $34;
   }
   $$sink$i5 = $104;
  }
  $40 = (($$sink$i5) + 36|0);
  $41 = HEAP32[$40>>2]|0;
  $mesh$0 = $41;
  label = 17;
 }
 if ((label|0) == 17) {
  $42 = ($mesh$0|0)==(0|0);
  if (!($42)) {
   $43 = HEAP32[$c>>2]|0;
   $44 = (($43) + 8|0);
   $45 = HEAP32[$44>>2]|0;
   FUNCTION_TABLE_vii[$45 & 4095]($c,$mesh$0);
  }
 }
 $46 = (($this) + 36|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 & 2;
 $49 = ($48|0)==(0);
 if ($49) {
  $60 = (($this) + 48|0);
  $61 = (__ZNK5physx2Sc9ShapeCore20getNbMaterialIndicesEv($60)|0);
  $$0$i = $61;
 } else {
  $50 = (($this) + 40|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0|0);
  if ($52) {
   $53 = HEAP32[$0>>2]|0;
   $54 = $47 >>> 24;
   $55 = $54 & 15;
   $56 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($53,$55)|0);
   HEAP32[$50>>2] = $56;
   $58 = $56;
  } else {
   $58 = $51;
  }
  $57 = (($58) + 60|0);
  $59 = HEAP16[$57>>1]|0;
  $$0$i = $59;
 }
 $62 = ($$0$i<<16>>16)==(0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 48|0);
 $64 = (($this) + 40|0);
 $65 = $$0$i&65535;
 $i$010 = 0;
 while(1) {
  $66 = HEAP32[424544>>2]|0;
  $67 = HEAP32[$46>>2]|0;
  $68 = $67 & 2;
  $69 = ($68|0)==(0);
  if ($69) {
   $91 = (__ZNK5physx2Sc9ShapeCore18getMaterialIndicesEv($63)|0);
   $92 = (($91) + ($i$010<<1)|0);
   $93 = HEAP16[$92>>1]|0;
   $94 = $93&65535;
   $95 = (($66) + 52|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = (($96) + ($94<<2)|0);
   $$pn$in$i = $97;
  } else {
   $70 = HEAP32[$0>>2]|0;
   $71 = HEAP32[$64>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    $73 = $67 >>> 24;
    $74 = $73 & 15;
    $75 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($70,$74)|0);
    HEAP32[$64>>2] = $75;
    $77 = $75;
   } else {
    $77 = $71;
   }
   $76 = (($77) + 60|0);
   $78 = HEAP16[$76>>1]|0;
   $79 = ($78<<16>>16)==(1);
   $80 = (($77) + 56|0);
   if ($79) {
    $$0$i$i = $80;
   } else {
    $81 = HEAP32[$80>>2]|0;
    $82 = (($70) + 2488|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($83) + ($81<<1)|0);
    $$0$i$i = $84;
   }
   $85 = (($$0$i$i) + ($i$010<<1)|0);
   $86 = HEAP16[$85>>1]|0;
   $87 = $86&65535;
   $88 = (($66) + 52|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($89) + ($87<<2)|0);
   $$pn$in$i = $90;
  }
  $$pn$i = HEAP32[$$pn$in$i>>2]|0;
  $98 = HEAP32[$c>>2]|0;
  $99 = (($98) + 8|0);
  $100 = HEAP32[$99>>2]|0;
  FUNCTION_TABLE_vii[$100 & 4095]($c,$$pn$i);
  $101 = (($i$010) + 1)|0;
  $exitcond = ($101|0)==($65|0);
  if ($exitcond) {
   break;
  } else {
   $i$010 = $101;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape7releaseEv($this) {
 $this = $this|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (($this) + 6|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)!=(0);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 140|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
 $$not = $7 ^ 1;
 $brmerge = $3 | $$not;
 if (!($brmerge)) {
  $8 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($8,8,437960,187,438032,$vararg_buffer1);
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__ZN5physx7NpActor15getShapeManagerERNS_12PxRigidActorE($10)|0);
  $12 = HEAP32[$9>>2]|0;
  __ZN5physx14NpShapeManager11detachShapeERNS_7NpShapeERNS_12PxRigidActorEb($11,$this,$12,1);
  STACKTOP = sp;return;
 }
 if (!($3)) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($13,8,437960,193,438152,$vararg_buffer1);
  STACKTOP = sp;return;
 }
 $14 = HEAP32[424544>>2]|0;
 $15 = (($this) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($14,$this,$16,1);
 $17 = HEAP16[$0>>1]|0;
 $18 = $17 & -3;
 HEAP16[$0>>1] = $18;
 $19 = (($this) + 12|0);
 $20 = (($this) + 16|0);
 $21 = (__ZN5physx6shdfnd15atomicDecrementEPVi($20)|0);
 $22 = ($21|0)==(0);
 if (!($22)) {
  STACKTOP = sp;return;
 }
 $23 = HEAP32[$19>>2]|0;
 $24 = (($23) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vi[$25 & 4095]($19);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape15releaseInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (($this) + 6|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & -3;
 HEAP16[$3>>1] = $5;
 $6 = (($this) + 12|0);
 $7 = (($this) + 16|0);
 $8 = (__ZN5physx6shdfnd15atomicDecrementEPVi($7)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vi[$12 & 4095]($6);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape15getGeometryTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpShape11setGeometryERKNS_10PxGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$g>>2]|0;
 $1 = (($this) + 116|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if (!($3)) {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,4,437960,236,438216,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $5 = (__ZN5physx7NpShape19getMeshRefCountableEv($this)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($5) + 4|0);
  $8 = (__ZN5physx6shdfnd15atomicDecrementEPVi($7)|0);
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = HEAP32[$5>>2]|0;
   $11 = (($10) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vi[$12 & 4095]($5);
  }
 }
 $13 = (($this) + 32|0);
 (__ZN5physx3Scb5Shape11setGeometryERKNS_10PxGeometryE($13,$g)|0);
 $14 = (__ZN5physx7NpShape19getMeshRefCountableEv($this)|0);
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = (($14) + 4|0);
  (__ZN5physx6shdfnd15atomicIncrementEPVi($16)|0);
 }
 $17 = (($this) + 36|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 64;
 $20 = ($19|0)==(0);
 if ($20) {
  $30 = (($this) + 112|0);
  $$in = $30;
 } else {
  $21 = (($this) + 40|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   $24 = HEAP32[$13>>2]|0;
   $25 = $18 >>> 24;
   $26 = $25 & 15;
   $27 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($24,$26)|0);
   HEAP32[$21>>2] = $27;
   $29 = $27;
  } else {
   $29 = $22;
  }
  $28 = (($29) + 116|0);
  $$in = $28;
 }
 $31 = HEAP8[$$in>>0]|0;
 $32 = $31 & 2;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = (($this) + 20|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($35)|0);
 $38 = ($37|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = HEAP32[$34>>2]|0;
 $40 = (__ZN5physx7NpActor15getShapeManagerERNS_12PxRigidActorE($39)|0);
 $41 = (__ZN5physx14NpShapeManager18findSceneQueryDataERKNS_7NpShapeE($40,$this)|0);
 $42 = (($37) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager13markForUpdateEPNS0_10ActorShapeE($42,$41);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Shape11setGeometryERKNS_10PxGeometryE($this,$geom) {
 $this = $this|0;
 $geom = $geom|0;
 var $$0$in$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $shapeBuffer$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$this>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $13 = $5;
   label = 6;
  }
 } else if ((($4|0) == 3)) {
  $$pre = HEAP32[$this>>2]|0;
  $13 = $$pre;
  label = 6;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $9 = (($this) + 16|0);
  __ZN5physx2Sc9ShapeCore11setGeometryERKNS_10PxGeometryE($9,$geom);
  $10 = (($this) + -12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $shapeBuffer$0 = 0;
   STACKTOP = sp;return ($shapeBuffer$0|0);
  }
  $$0$in$i$i = (($11) + 64|0);
  HEAP32[$0>>2] = 1;
  HEAP8[$1>>0] = 0;
  __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($$0$in$i$i,$9,$0,$1);
  $shapeBuffer$0 = 0;
  STACKTOP = sp;return ($shapeBuffer$0|0);
 }
 else if ((label|0) == 6) {
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($13,$this);
  $14 = HEAP32[$2>>2]|0;
  $15 = $14 | 1;
  HEAP32[$2>>2] = $15;
  $16 = (($this) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = HEAP32[$this>>2]|0;
   $20 = $14 >>> 24;
   $21 = $20 & 15;
   $22 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($19,$21)|0);
   HEAP32[$16>>2] = $22;
   $23 = $22;
  } else {
   $23 = $17;
  }
  __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($23,$geom);
  $shapeBuffer$0 = $23;
  STACKTOP = sp;return ($shapeBuffer$0|0);
 }
 return 0|0;
}
function __ZNK5physx7NpShape11getGeometryEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $12 = (($this) + 116|0);
  $$sink$i = $12;
 } else {
  $4 = (($this) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 32|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $$sink$i = $13;
 }
 dest=$agg$result+0|0; src=$$sink$i+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape14getBoxGeometryERNS_13PxBoxGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $$0 = 0, $$pre = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $$sink$i = $0;$16 = 3;
 } else {
  $7 = (($this) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (($this) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $4 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$7>>2] = $14;
   $15 = $14;
  } else {
   $15 = $8;
  }
  $$pre = HEAP32[$15>>2]|0;
  $$sink$i = $15;$16 = $$pre;
 }
 HEAP32[$g>>2] = $16;
 $17 = (($$sink$i) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($g) + 4|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($$sink$i) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($g) + 8|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($$sink$i) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($g) + 12|0);
 HEAPF32[$25>>2] = $24;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx7NpShape17getSphereGeometryERNS_16PxSphereGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $$0 = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $$sink$i = $0;
 } else {
  $7 = (($this) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (($this) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $4 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$7>>2] = $14;
   $25 = $14;
  } else {
   $25 = $8;
  }
  $$sink$i = $25;
 }
 $15 = $$sink$i;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $g;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx7NpShape18getCapsuleGeometryERNS_17PxCapsuleGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $$0 = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $$sink$i = $0;
 } else {
  $7 = (($this) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (($this) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $4 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$7>>2] = $14;
   $15 = $14;
  } else {
   $15 = $8;
  }
  $$sink$i = $15;
 }
 ;HEAP32[$g+0>>2]=HEAP32[$$sink$i+0>>2]|0;HEAP32[$g+4>>2]=HEAP32[$$sink$i+4>>2]|0;HEAP32[$g+8>>2]=HEAP32[$$sink$i+8>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx7NpShape16getPlaneGeometryERNS_15PxPlaneGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $16 = 1;
 } else {
  $7 = (($this) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (($this) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $4 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$7>>2] = $14;
   $15 = $14;
  } else {
   $15 = $8;
  }
  $$pre = HEAP32[$15>>2]|0;
  $16 = $$pre;
 }
 HEAP32[$g>>2] = $16;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx7NpShape21getConvexMeshGeometryERNS_20PxConvexMeshGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $$0 = 0, $$pre = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(4);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $$sink$i = $0;$16 = 4;
 } else {
  $7 = (($this) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (($this) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $4 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$7>>2] = $14;
   $15 = $14;
  } else {
   $15 = $8;
  }
  $$pre = HEAP32[$15>>2]|0;
  $$sink$i = $15;$16 = $$pre;
 }
 HEAP32[$g>>2] = $16;
 $17 = (($$sink$i) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($g) + 4|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($$sink$i) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($g) + 8|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($$sink$i) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($g) + 12|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($$sink$i) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($g) + 16|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($$sink$i) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($g) + 20|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($$sink$i) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($g) + 24|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($$sink$i) + 28|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($g) + 28|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($$sink$i) + 32|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($g) + 32|0);
 HEAP32[$40>>2] = $39;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx7NpShape23getTriangleMeshGeometryERNS_22PxTriangleMeshGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $$0 = 0, $$pre = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(5);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $$sink$i = $0;$16 = 5;
 } else {
  $7 = (($this) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (($this) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $4 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$7>>2] = $14;
   $15 = $14;
  } else {
   $15 = $8;
  }
  $$pre = HEAP32[$15>>2]|0;
  $$sink$i = $15;$16 = $$pre;
 }
 HEAP32[$g>>2] = $16;
 $17 = (($$sink$i) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($g) + 4|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($$sink$i) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($g) + 8|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($$sink$i) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($g) + 12|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($$sink$i) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($g) + 16|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($$sink$i) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($g) + 20|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($$sink$i) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($g) + 24|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($$sink$i) + 28|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($g) + 28|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($g) + 32|0);
 $39 = (($$sink$i) + 32|0);
 $40 = $39;
 $41 = $40;
 $42 = HEAPU8[$41>>0]|(HEAPU8[$41+1>>0]<<8)|(HEAPU8[$41+2>>0]<<16)|(HEAPU8[$41+3>>0]<<24);
 $43 = (($40) + 4)|0;
 $44 = $43;
 $45 = HEAPU8[$44>>0]|(HEAPU8[$44+1>>0]<<8)|(HEAPU8[$44+2>>0]<<16)|(HEAPU8[$44+3>>0]<<24);
 $46 = $38;
 $47 = $46;
 HEAP8[$47>>0]=$42&255;HEAP8[$47+1>>0]=($42>>8)&255;HEAP8[$47+2>>0]=($42>>16)&255;HEAP8[$47+3>>0]=$42>>24;
 $48 = (($46) + 4)|0;
 $49 = $48;
 HEAP8[$49>>0]=$45&255;HEAP8[$49+1>>0]=($45>>8)&255;HEAP8[$49+2>>0]=($45>>16)&255;HEAP8[$49+3>>0]=$45>>24;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx7NpShape22getHeightFieldGeometryERNS_21PxHeightFieldGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $$0 = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(6);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $$sink$i = $0;
 } else {
  $7 = (($this) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (($this) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $4 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$7>>2] = $14;
   $15 = $14;
  } else {
   $15 = $8;
  }
  $$sink$i = $15;
 }
 ;HEAP32[$g+0>>2]=HEAP32[$$sink$i+0>>2]|0;HEAP32[$g+4>>2]=HEAP32[$$sink$i+4>>2]|0;HEAP32[$g+8>>2]=HEAP32[$$sink$i+8>>2]|0;HEAP32[$g+12>>2]=HEAP32[$$sink$i+12>>2]|0;HEAP32[$g+16>>2]=HEAP32[$$sink$i+16>>2]|0;HEAP32[$g+20>>2]=HEAP32[$$sink$i+20>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx7NpShape8getActorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpShape12setLocalPoseERKNS_11PxTransformE($this,$newShape2Actor) {
 $this = $this|0;
 $newShape2Actor = $newShape2Actor|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $7 = Math_fround(0);
 var $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = Math_fround(HEAPF32[$newShape2Actor>>2]);
 $3 = Math_fround($2 * $2);
 $4 = (($newShape2Actor) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $5);
 $7 = Math_fround($3 + $6);
 $8 = (($newShape2Actor) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($newShape2Actor) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (Math_fround(Math_sqrt((Math_fround($15)))));
 $17 = Math_fround(Math_fround(1.0) / $16);
 $18 = Math_fround($2 * $17);
 $19 = Math_fround($5 * $17);
 $20 = Math_fround($9 * $17);
 $21 = Math_fround($13 * $17);
 HEAPF32[$0>>2] = $18;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($0) + 16|0);
 $26 = (($newShape2Actor) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($0) + 20|0);
 $29 = (($newShape2Actor) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($0) + 24|0);
 $32 = (($newShape2Actor) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($this) + 48|0);
 __ZN5physx3Scb5Shape6Access5writeINS0_11ShapeBuffer3FnsILj4ELj0EEEEEvRS1_RNS_2Sc9ShapeCoreENT_3ArgE($1,$34,$0);
 $35 = (($this) + 36|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 64;
 $38 = ($37|0)==(0);
 if ($38) {
  $48 = (($this) + 112|0);
  $$in = $48;
 } else {
  $39 = (($this) + 40|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==(0|0);
  if ($41) {
   $42 = HEAP32[$1>>2]|0;
   $43 = $36 >>> 24;
   $44 = $43 & 15;
   $45 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($42,$44)|0);
   HEAP32[$39>>2] = $45;
   $47 = $45;
  } else {
   $47 = $40;
  }
  $46 = (($47) + 116|0);
  $$in = $46;
 }
 $49 = HEAP8[$$in>>0]|0;
 $50 = $49 & 2;
 $51 = ($50<<24>>24)==(0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $52 = (($this) + 20|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  STACKTOP = sp;return;
 }
 $55 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($53)|0);
 $56 = ($55|0)==(0|0);
 if ($56) {
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$52>>2]|0;
 $58 = (__ZN5physx7NpActor15getShapeManagerERNS_12PxRigidActorE($57)|0);
 $59 = (__ZN5physx14NpShapeManager18findSceneQueryDataERKNS_7NpShapeE($58,$this)|0);
 $60 = (($55) + 3376|0);
 __ZN5physx2Sq17SceneQueryManager13markForUpdateEPNS0_10ActorShapeE($60,$59);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape12getLocalPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 80|0);
  $16 = $14;
 } else {
  $4 = (($this) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 32|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 64|0);
  $16 = $12;
 }
 $15 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$agg$result>>2] = $15;
 $17 = (($agg$result) + 4|0);
 $18 = (($16) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$17>>2] = $19;
 $20 = (($agg$result) + 8|0);
 $21 = (($16) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = (($agg$result) + 12|0);
 $24 = (($16) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$23>>2] = $25;
 $26 = (($agg$result) + 16|0);
 $27 = (($16) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$26>>2] = $28;
 $29 = (($agg$result) + 20|0);
 $30 = (($16) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$29>>2] = $31;
 $32 = (($agg$result) + 24|0);
 $33 = (($16) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$32>>2] = $34;
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape23setSimulationFilterDataERKNS_12PxFilterDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (($this) + 48|0);
 __ZN5physx3Scb5Shape6Access5writeINS0_11ShapeBuffer3FnsILj8ELj0EEEEEvRS1_RNS_2Sc9ShapeCoreENT_3ArgE($0,$1,$data);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape23getSimulationFilterDataEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 8;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 64|0);
  $15 = $14;
 } else {
  $4 = (($this) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 32|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 92|0);
  $15 = $12;
 }
 ;HEAP32[$agg$result+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$15+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape14resetFilteringEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $shape = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $shape = sp + 4|0;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($0,1,437960,454,438312,$vararg_buffer);
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($2)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 HEAP32[$shape>>2] = $this;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + 216|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$8 & 511]($4,$9,$shape,1);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape18setQueryFilterDataERKNS_12PxFilterDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 ;HEAP32[$0+0>>2]=HEAP32[$data+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$data+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$data+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$data+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape18getQueryFilterDataEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape12setMaterialsEPKPNS_10PxMaterialEt($this,$materials,$materialCount) {
 $this = $this|0;
 $materials = $materials|0;
 $materialCount = $materialCount|0;
 var $$0$i = 0, $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond6 = 0, $i$01$i = 0, $i$04 = 0, $i1$02 = 0, $materialIndices$0$i = 0, $oldMaterials = 0;
 var $umax$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldMaterials = sp;
 $0 = sp + 8|0;
 $1 = (($this) + 32|0);
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2;
 $5 = ($4|0)==(0);
 if ($5) {
  $16 = (($this) + 48|0);
  $17 = (__ZNK5physx2Sc9ShapeCore20getNbMaterialIndicesEv($16)|0);
  $$0$i = $17;
 } else {
  $6 = (($this) + 40|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $9 = HEAP32[$1>>2]|0;
   $10 = $3 >>> 24;
   $11 = $10 & 15;
   $12 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($9,$11)|0);
   HEAP32[$6>>2] = $12;
   $14 = $12;
  } else {
   $14 = $7;
  }
  $13 = (($14) + 60|0);
  $15 = HEAP16[$13>>1]|0;
  $$0$i = $15;
 }
 $18 = $$0$i&65535;
 $19 = $18 << 2;
 $20 = ($19>>>0)>(1024);
 $21 = (($oldMaterials) + 4|0);
 $22 = $20&1;
 HEAP8[$21>>0] = $22;
 if ($20) {
  $23 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$19,437960,503)|0);
  HEAP32[$oldMaterials>>2] = $23;
  $66 = $23;
 } else {
  $24 = STACKTOP; STACKTOP = STACKTOP + ((((4*$18)|0)+15)&-16)|0;;
  HEAP32[$oldMaterials>>2] = $24;
  $66 = $24;
 }
 $25 = HEAP32[424544>>2]|0;
 $26 = HEAP32[$2>>2]|0;
 $27 = $26 & 2;
 $28 = ($27|0)==(0);
 do {
  if ($28) {
   $47 = (($this) + 48|0);
   $48 = (__ZNK5physx2Sc9ShapeCore18getMaterialIndicesEv($47)|0);
   $49 = (__ZNK5physx2Sc9ShapeCore20getNbMaterialIndicesEv($47)|0);
   $$sink$i = $49;$materialIndices$0$i = $48;
  } else {
   $29 = (($this) + 40|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $32 = HEAP32[$1>>2]|0;
    $33 = $26 >>> 24;
    $34 = $33 & 15;
    $35 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($32,$34)|0);
    HEAP32[$29>>2] = $35;
    $37 = $35;
   } else {
    $37 = $30;
   }
   $36 = (($37) + 60|0);
   $38 = HEAP16[$36>>1]|0;
   $39 = ($38<<16>>16)==(1);
   if ($39) {
    $40 = (($37) + 56|0);
    $$sink$i = 1;$materialIndices$0$i = $40;
    break;
   } else {
    $41 = HEAP32[$1>>2]|0;
    $42 = (($37) + 56|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($41) + 2488|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($45) + ($43<<1)|0);
    $$sink$i = $38;$materialIndices$0$i = $46;
    break;
   }
  }
 } while(0);
 $50 = $$sink$i&65535;
 $51 = ($50>>>0)<($18>>>0);
 $52 = $51 ? $50 : $18;
 $53 = ($52|0)==(0);
 if (!($53)) {
  $54 = (($25) + 52|0);
  $55 = $18 ^ -1;
  $56 = $50 ^ -1;
  $57 = ($55>>>0)>($56>>>0);
  $umax$i = $57 ? $55 : $56;
  $58 = $umax$i ^ -1;
  $i$01$i = 0;
  while(1) {
   $59 = (($materialIndices$0$i) + ($i$01$i<<1)|0);
   $60 = HEAP16[$59>>1]|0;
   $61 = $60&65535;
   $62 = HEAP32[$54>>2]|0;
   $63 = (($62) + ($61<<2)|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($66) + ($i$01$i<<2)|0);
   HEAP32[$65>>2] = $64;
   $67 = (($i$01$i) + 1)|0;
   $exitcond$i = ($67|0)==($58|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $67;
   }
  }
 }
 $68 = (__ZN5physx3Scb5Shape12setMaterialsEPKPNS_10PxMaterialEt($1,$materials,$materialCount)|0);
 if ($68) {
  $69 = ($materialCount<<16>>16)==(0);
  if (!($69)) {
   $70 = $materialCount&65535;
   $i$04 = 0;
   while(1) {
    $72 = (($materials) + ($i$04<<2)|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($73) + 16|0);
    (__ZN5physx6shdfnd15atomicIncrementEPVi($74)|0);
    $75 = (($i$04) + 1)|0;
    $exitcond6 = ($75|0)==($70|0);
    if ($exitcond6) {
     break;
    } else {
     $i$04 = $75;
    }
   }
  }
  $71 = ($$0$i<<16>>16)==(0);
  if (!($71)) {
   $i1$02 = 0;
   while(1) {
    $76 = HEAP32[$oldMaterials>>2]|0;
    $77 = (($76) + ($i1$02<<2)|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (($78) + 12|0);
    $80 = (($78) + 16|0);
    $81 = (__ZN5physx6shdfnd15atomicDecrementEPVi($80)|0);
    $82 = ($81|0)==(0);
    if ($82) {
     $83 = HEAP32[$79>>2]|0;
     $84 = (($83) + 8|0);
     $85 = HEAP32[$84>>2]|0;
     FUNCTION_TABLE_vi[$85 & 4095]($79);
    }
    $86 = (($i1$02) + 1)|0;
    $exitcond = ($86|0)==($18|0);
    if ($exitcond) {
     break;
    } else {
     $i1$02 = $86;
    }
   }
  }
 }
 $87 = HEAP8[$21>>0]|0;
 $88 = ($87<<24>>24)==(0);
 if ($88) {
  STACKTOP = sp;return;
 }
 $89 = HEAP32[$oldMaterials>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($oldMaterials,$89);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Shape12setMaterialsEPKPNS_10PxMaterialEt($this,$materials,$materialCount) {
 $this = $this|0;
 $materials = $materials|0;
 $materialCount = $materialCount|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $materialIndices$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 if ((($3|0) == 2)) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  }
 } else if (!((($3|0) == 3))) {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (__ZN5physx3Scb5Shape18setMaterialsHelperEPKPNS_10PxMaterialEt($this,$materials,$materialCount)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$this>>2]|0;
  $13 = $2 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $19 = $15;
 } else {
  $19 = $10;
 }
 $16 = $materialCount&65535;
 $17 = ($materialCount<<16>>16)==(1);
 if ($17) {
  $18 = (($19) + 56|0);
  $20 = (($19) + 60|0);
  HEAP16[$20>>1] = $materialCount;
  $materialIndices$02 = $18;
  label = 9;
 } else {
  $21 = HEAP32[$this>>2]|0;
  $22 = (($21) + 2488|0);
  $23 = (($21) + 2492|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($16))|0;
  HEAP16[$0>>1] = 0;
  __ZN5physx6shdfnd5ArrayItNS0_19ReflectionAllocatorItEEE6resizeEjRKt($22,$25,$0);
  $26 = HEAP32[$22>>2]|0;
  $27 = (($26) + ($24<<1)|0);
  $28 = (($19) + 56|0);
  HEAP32[$28>>2] = $24;
  $29 = (($19) + 60|0);
  HEAP16[$29>>1] = $materialCount;
  $30 = ($materialCount<<16>>16)==(0);
  if (!($30)) {
   $materialIndices$02 = $27;
   label = 9;
  }
 }
 if ((label|0) == 9) {
  $i$01$i = 0;
  while(1) {
   $31 = (($materials) + ($i$01$i<<2)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 52|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = $34&65535;
   $36 = (($materialIndices$02) + ($i$01$i<<1)|0);
   HEAP16[$36>>1] = $35;
   $37 = (($i$01$i) + 1)|0;
   $exitcond$i = ($37|0)==($16|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $37;
   }
  }
 }
 $38 = HEAP32[$this>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($38,$this);
 $39 = HEAP32[$1>>2]|0;
 $40 = $39 | 2;
 HEAP32[$1>>2] = $40;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx7NpShape14getNbMaterialsEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 48|0);
  $16 = (__ZNK5physx2Sc9ShapeCore20getNbMaterialIndicesEv($15)|0);
  $$0$i = $16;
  STACKTOP = sp;return ($$0$i|0);
 }
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 60|0);
 $14 = HEAP16[$12>>1]|0;
 $$0$i = $14;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK5physx7NpShape12getMaterialsEPPNS_10PxMaterialEj($this,$userBuffer,$bufferSize) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 var $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $materialIndices$0$i = 0, $umax$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[424544>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2;
 $5 = ($4|0)==(0);
 do {
  if ($5) {
   $24 = (($this) + 48|0);
   $25 = (__ZNK5physx2Sc9ShapeCore18getMaterialIndicesEv($24)|0);
   $26 = (__ZNK5physx2Sc9ShapeCore20getNbMaterialIndicesEv($24)|0);
   $$sink$i = $26;$materialIndices$0$i = $25;
  } else {
   $6 = (($this) + 40|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $9 = HEAP32[$0>>2]|0;
    $10 = $3 >>> 24;
    $11 = $10 & 15;
    $12 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($9,$11)|0);
    HEAP32[$6>>2] = $12;
    $14 = $12;
   } else {
    $14 = $7;
   }
   $13 = (($14) + 60|0);
   $15 = HEAP16[$13>>1]|0;
   $16 = ($15<<16>>16)==(1);
   if ($16) {
    $17 = (($14) + 56|0);
    $$sink$i = 1;$materialIndices$0$i = $17;
    break;
   } else {
    $18 = HEAP32[$0>>2]|0;
    $19 = (($14) + 56|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($18) + 2488|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + ($20<<1)|0);
    $$sink$i = $15;$materialIndices$0$i = $23;
    break;
   }
  }
 } while(0);
 $27 = $$sink$i&65535;
 $28 = ($27>>>0)<($bufferSize>>>0);
 $29 = $28 ? $27 : $bufferSize;
 $30 = ($29|0)==(0);
 if ($30) {
  STACKTOP = sp;return ($29|0);
 }
 $31 = (($1) + 52|0);
 $32 = $bufferSize ^ -1;
 $33 = $27 ^ -1;
 $34 = ($32>>>0)>($33>>>0);
 $umax$i = $34 ? $32 : $33;
 $35 = $umax$i ^ -1;
 $i$01$i = 0;
 while(1) {
  $36 = (($materialIndices$0$i) + ($i$01$i<<1)|0);
  $37 = HEAP16[$36>>1]|0;
  $38 = $37&65535;
  $39 = HEAP32[$31>>2]|0;
  $40 = (($39) + ($38<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($userBuffer) + ($i$01$i<<2)|0);
  HEAP32[$42>>2] = $41;
  $43 = (($i$01$i) + 1)|0;
  $exitcond$i = ($43|0)==($35|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $43;
  }
 }
 STACKTOP = sp;return ($29|0);
}
function __ZNK5physx7NpShape32getMaterialFromInternalFaceIndexEj($this,$faceIndex) {
 $this = $this|0;
 $faceIndex = $faceIndex|0;
 var $$0 = 0, $$0$i$i$i = 0, $$pn$i$i = 0, $$pn$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $brmerge = 0, $hfGeom = 0, $hitMatTableId$1 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer = sp;
 $hfGeom = sp + 40|0;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = ($3|0)==(6);
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($this)|0);
 $9 = ($8|0)==(5);
 $10 = ($faceIndex|0)==(-1);
 $brmerge = $4 | $9;
 $or$cond = $10 & $brmerge;
 if ($or$cond) {
  $11 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($11,2,437960,544,438376,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ($4) {
  HEAP32[$hfGeom>>2] = 6;
  $12 = (($hfGeom) + 4|0);
  HEAP32[$12>>2] = 0;
  $13 = (($hfGeom) + 8|0);
  HEAPF32[$13>>2] = Math_fround(1.0);
  $14 = (($hfGeom) + 12|0);
  HEAPF32[$14>>2] = Math_fround(1.0);
  $15 = (($hfGeom) + 16|0);
  HEAPF32[$15>>2] = Math_fround(1.0);
  $16 = (($hfGeom) + 20|0);
  HEAP32[$16>>2] = 0;
  $17 = HEAP32[$this>>2]|0;
  $18 = (($17) + 60|0);
  $19 = HEAP32[$18>>2]|0;
  (FUNCTION_TABLE_iii[$19 & 4095]($this,$hfGeom)|0);
  $20 = HEAP32[$12>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 68|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (FUNCTION_TABLE_iii[$23 & 4095]($20,$faceIndex)|0);
  $hitMatTableId$1 = $24;
 } else {
  if ($9) {
   HEAP32[$vararg_buffer>>2] = 5;
   $25 = (($vararg_buffer) + 4|0);
   HEAPF32[$25>>2] = Math_fround(1.0);
   $26 = (($vararg_buffer) + 8|0);
   HEAPF32[$26>>2] = Math_fround(1.0);
   $27 = (($vararg_buffer) + 12|0);
   HEAPF32[$27>>2] = Math_fround(1.0);
   $28 = (($vararg_buffer) + 16|0);
   HEAPF32[$28>>2] = Math_fround(0.0);
   $29 = (($vararg_buffer) + 20|0);
   HEAPF32[$29>>2] = Math_fround(0.0);
   $30 = (($vararg_buffer) + 24|0);
   HEAPF32[$30>>2] = Math_fround(0.0);
   $31 = (($vararg_buffer) + 28|0);
   HEAPF32[$31>>2] = Math_fround(1.0);
   $32 = (($vararg_buffer) + 32|0);
   $33 = $32;
   $34 = $33;
   HEAP32[$34>>2] = 0;
   $35 = (($33) + 4)|0;
   $36 = $35;
   HEAP32[$36>>2] = 0;
   $37 = HEAP32[$this>>2]|0;
   $38 = (($37) + 56|0);
   $39 = HEAP32[$38>>2]|0;
   (FUNCTION_TABLE_iii[$39 & 4095]($this,$vararg_buffer)|0);
   $40 = (($vararg_buffer) + 36|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 176|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    $hitMatTableId$1 = 0;
   } else {
    $45 = HEAP32[$41>>2]|0;
    $46 = (($45) + 48|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (FUNCTION_TABLE_iii[$47 & 4095]($41,$faceIndex)|0);
    $hitMatTableId$1 = $48;
   }
  } else {
   $hitMatTableId$1 = 0;
  }
 }
 $49 = $hitMatTableId$1&65535;
 $50 = HEAP32[424544>>2]|0;
 $51 = (($this) + 36|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 & 2;
 $54 = ($53|0)==(0);
 if ($54) {
  $78 = (($this) + 48|0);
  $79 = (__ZNK5physx2Sc9ShapeCore18getMaterialIndicesEv($78)|0);
  $80 = (($79) + ($49<<1)|0);
  $81 = HEAP16[$80>>1]|0;
  $82 = $81&65535;
  $83 = (($50) + 52|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + ($82<<2)|0);
  $$pn$in$i$i = $85;
 } else {
  $55 = (($this) + 32|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($this) + 40|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   $60 = $52 >>> 24;
   $61 = $60 & 15;
   $62 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($56,$61)|0);
   HEAP32[$57>>2] = $62;
   $64 = $62;
  } else {
   $64 = $58;
  }
  $63 = (($64) + 60|0);
  $65 = HEAP16[$63>>1]|0;
  $66 = ($65<<16>>16)==(1);
  $67 = (($64) + 56|0);
  if ($66) {
   $$0$i$i$i = $67;
  } else {
   $68 = HEAP32[$67>>2]|0;
   $69 = (($56) + 2488|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + ($68<<1)|0);
   $$0$i$i$i = $71;
  }
  $72 = (($$0$i$i$i) + ($49<<1)|0);
  $73 = HEAP16[$72>>1]|0;
  $74 = $73&65535;
  $75 = (($50) + 52|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($76) + ($74<<2)|0);
  $$pn$in$i$i = $77;
 }
 $$pn$i$i = HEAP32[$$pn$in$i$i>>2]|0;
 $$0 = $$pn$i$i;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx7NpShape16setContactOffsetEf($this,$contactOffset) {
 $this = $this|0;
 $contactOffset = Math_fround($contactOffset);
 var $$0$in$i$i$i$i$i = 0, $$mask$i$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 32|0);
 $3 = (($this) + 48|0);
 $4 = (($this) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 30;
 if ((($6|0) == 2)) {
  $7 = HEAP32[$2>>2]|0;
  $8 = (($7) + 2417|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if (!($10)) {
   $$pre$phi$i$iZ2D = $2;
   label = 7;
  }
 } else if ((($6|0) == 3)) {
  $$pre$phi$i$iZ2D = $2;
  label = 7;
 }
 if ((label|0) == 7) {
  $18 = (($this) + 40|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $21 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $22 = $5 >>> 24;
   $23 = $22 & 15;
   $24 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($21,$23)|0);
   HEAP32[$18>>2] = $24;
   $26 = $24;
  } else {
   $26 = $19;
  }
  $25 = (($26) + 108|0);
  HEAPF32[$25>>2] = $contactOffset;
  $27 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($27,$2);
  $28 = HEAP32[$4>>2]|0;
  $29 = $28 | 16;
  HEAP32[$4>>2] = $29;
  STACKTOP = sp;return;
 }
 $11 = (($this) + 112|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = (($this) + 108|0);
 HEAPF32[$13>>2] = $contactOffset;
 $14 = (($2) + -12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $$mask$i$i$i = $5 & -1073741824;
 $17 = ($$mask$i$i$i|0)==(1073741824);
 if ($17) {
  STACKTOP = sp;return;
 }
 $$0$in$i$i$i$i$i = (($15) + 64|0);
 HEAP32[$0>>2] = 16;
 HEAP8[$1>>0] = $12;
 __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($$0$in$i$i$i$i$i,$3,$0,$1);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape16getContactOffsetEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 108|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 108|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx7NpShape13setRestOffsetEf($this,$restOffset) {
 $this = $this|0;
 $restOffset = Math_fround($restOffset);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (($this) + 48|0);
 __ZN5physx3Scb5Shape6Access5writeINS0_11ShapeBuffer3FnsILj32ELj0EEEEEvRS1_RNS_2Sc9ShapeCoreENT_3ArgE($0,$1,$restOffset);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape13getRestOffsetEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 176|0);
  $$in$i$i$i = $14;
  $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
  STACKTOP = sp;return (Math_fround($15));
 }
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 112|0);
 $$in$i$i$i = $12;
 $15 = Math_fround(HEAPF32[$$in$i$i$i>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZN5physx7NpShape8setActorEPNS_12PxRigidActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 HEAP32[$0>>2] = $actor;
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape16setFlagsInternalENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$in = 0, $$not = 0, $$off = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $brmerge1 = 0, $brmerge2 = 0, $isKinematic$0$off0 = 0, $switch = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer3 = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 32|0);
 $2 = (($this) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $$off = (($3) + -5)|0;
 $switch = ($$off>>>0)<(2);
 $4 = HEAP8[$inFlags>>0]|0;
 if ($switch) {
  $5 = $4 & 4;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $62 = 1;
  } else {
   $7 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,4,437960,626,438472,$vararg_buffer3);
   STACKTOP = sp;return;
  }
 } else {
  $62 = 0;
 }
 $8 = $4 & 5;
 $9 = ($8<<24>>24)==(5);
 if ($9) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,4,437960,633,438552,$vararg_buffer3);
  STACKTOP = sp;return;
 }
 $11 = (($this) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 64;
 $14 = ($13|0)==(0);
 if ($14) {
  $24 = (($this) + 112|0);
  $$in = $24;$30 = $4;
 } else {
  $15 = (($this) + 40|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $18 = HEAP32[$1>>2]|0;
   $19 = $12 >>> 24;
   $20 = $19 & 15;
   $21 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($18,$20)|0);
   HEAP32[$15>>2] = $21;
   $$pre$pre = HEAP8[$inFlags>>0]|0;
   $$pre = $$pre$pre;$23 = $21;
  } else {
   $$pre = $4;$23 = $16;
  }
  $22 = (($23) + 116|0);
  $$in = $22;$30 = $$pre;
 }
 $25 = HEAP8[$$in>>0]|0;
 $26 = $25&255;
 $27 = $26 & 1;
 $28 = ($27|0)!=(0);
 $29 = $30 & 1;
 $31 = (($this) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 do {
  if (!($33)) {
   $34 = (($32) + 4|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = ($35<<16>>16)==(5);
   if ($36) {
    $37 = HEAP32[$32>>2]|0;
    $38 = (($37) + 204|0);
    $39 = HEAP32[$38>>2]|0;
    FUNCTION_TABLE_vii[$39 & 4095]($0,$32);
    $40 = HEAP8[$0>>0]|0;
    $41 = $40 & 1;
    $42 = ($41<<24>>24)!=(0);
    $isKinematic$0$off0 = $42;
   } else {
    $isKinematic$0$off0 = 0;
   }
   $43 = ($35<<16>>16)==(6);
   $brmerge = $43 | $isKinematic$0$off0;
   $$not = ($29<<24>>24)==(0);
   $brmerge1 = $brmerge | $$not;
   $brmerge2 = $brmerge1 | $28;
   if (!($brmerge2)) {
    if (!($62)) {
     $44 = HEAP32[$2>>2]|0;
     $45 = ($44|0)==(1);
     if (!($45)) {
      break;
     }
    }
    $46 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($46,4,437960,657,438648,$vararg_buffer3);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $47 = $26 & 2;
 $48 = ($47|0)!=(0);
 $49 = HEAP8[$inFlags>>0]|0;
 $50 = $49 & 2;
 $51 = ($50<<24>>24)!=(0);
 $52 = (($this) + 48|0);
 HEAP8[$vararg_buffer3>>0] = $49;
 __ZN5physx3Scb5Shape6Access5writeINS0_11ShapeBuffer3FnsILj64ELj0EEEEEvRS1_RNS_2Sc9ShapeCoreENT_3ArgE($1,$52,$vararg_buffer3);
 $53 = $48 ^ $51;
 if (!($53)) {
  STACKTOP = sp;return;
 }
 $54 = HEAP32[$31>>2]|0;
 $55 = ($54|0)==(0|0);
 if ($55) {
  STACKTOP = sp;return;
 }
 $56 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($54)|0);
 $57 = ($56|0)==(0|0);
 if ($57) {
  STACKTOP = sp;return;
 }
 $58 = HEAP32[$31>>2]|0;
 $59 = (__ZN5physx7NpActor15getShapeManagerERNS_12PxRigidActorE($58)|0);
 $60 = (($56) + 3376|0);
 if ($51) {
  $61 = HEAP32[$31>>2]|0;
  __ZN5physx14NpShapeManager15setupSceneQueryERNS_2Sq17SceneQueryManagerERKNS_12PxRigidActorERKNS_7NpShapeE($59,$60,$61,$this);
  STACKTOP = sp;return;
 } else {
  __ZN5physx14NpShapeManager18teardownSceneQueryERNS_2Sq17SceneQueryManagerERKNS_7NpShapeE($59,$60,$this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpShape7setFlagENS_11PxShapeFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 64;
 $4 = ($3|0)==(0);
 if ($4) {
  $15 = (($this) + 112|0);
  $$in = $15;
 } else {
  $5 = (($this) + 40|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $8 = (($this) + 32|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $2 >>> 24;
   $11 = $10 & 15;
   $12 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($9,$11)|0);
   HEAP32[$5>>2] = $12;
   $14 = $12;
  } else {
   $14 = $6;
  }
  $13 = (($14) + 116|0);
  $$in = $13;
 }
 $16 = HEAP8[$$in>>0]|0;
 if ($value) {
  $17 = $16&255;
  $18 = $17 | $flag;
  $19 = $18&255;
  $23 = $19;
 } else {
  $20 = $flag ^ 255;
  $21 = $20&255;
  $22 = $16 & $21;
  $23 = $22;
 }
 HEAP8[$0>>0] = $23;
 __ZN5physx7NpShape16setFlagsInternalENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$0);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape8setFlagsENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP8[$inFlags>>0]|0;
 HEAP8[$0>>0] = $1;
 __ZN5physx7NpShape16setFlagsInternalENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$0);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape8getFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 112|0);
  $16 = HEAP8[$15>>0]|0;
  HEAP8[$agg$result>>0] = $16;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 116|0);
 $14 = HEAP8[$12>>0]|0;
 HEAP8[$agg$result>>0] = $14;
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape11isExclusiveEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 196|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx7NpShape7setNameEPKc($this,$debugName) {
 $this = $this|0;
 $debugName = $debugName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 192|0);
 HEAP32[$0>>2] = $debugName;
 STACKTOP = sp;return;
}
function __ZNK5physx7NpShape7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 192|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx34NpShapeGetScRigidObjectFromScbSLOWERKNS_3Scb5ShapeE($scb) {
 $scb = $scb|0;
 var $$0$in$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scb) + -12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = 0;
 } else {
  $$0$in$i = (($1) + 64|0);
  $3 = $$0$in$i;
 }
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx21NpShapeGetScPtrOffsetEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 48;
}
function __ZN5physx12NpGetPxShapeERNS_2Sc9ShapeCoreE($shape) {
 $shape = $shape|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + -48|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($scb) {
 $scb = $scb|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scb) + -16|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx18NpShapeDecRefCountERNS_3Scb5ShapeE($scb) {
 $scb = $scb|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scb) + -20|0);
 $1 = (($scb) + -16|0);
 $2 = (__ZN5physx6shdfnd15atomicDecrementEPVi($1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vi[$6 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZN5physx7NpShape19getMeshRefCountableEv($this) {
 $this = $this|0;
 var $$0 = 0, $$sink$i = 0, $$sink$i2 = 0, $$sink$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (($this) + 116|0);
 $2 = HEAP32[$1>>2]|0;
 if ((($2|0) == 4)) {
  $3 = (($this) + 36|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4 & 1;
  $6 = ($5|0)==(0);
  if ($6) {
   $$sink$i2 = $1;
  } else {
   $7 = (($this) + 40|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $10 = HEAP32[$0>>2]|0;
    $11 = $4 >>> 24;
    $12 = $11 & 15;
    $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($10,$12)|0);
    HEAP32[$7>>2] = $13;
    $48 = $13;
   } else {
    $48 = $8;
   }
   $$sink$i2 = $48;
  }
  $14 = (($$sink$i2) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $17 = (($15) + 8|0);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 } else if ((($2|0) == 6)) {
  $18 = (($this) + 36|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & 1;
  $21 = ($20|0)==(0);
  if ($21) {
   $$sink$i5 = $1;
  } else {
   $22 = (($this) + 40|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $25 = HEAP32[$0>>2]|0;
    $26 = $19 >>> 24;
    $27 = $26 & 15;
    $28 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$27)|0);
    HEAP32[$22>>2] = $28;
    $49 = $28;
   } else {
    $49 = $23;
   }
   $$sink$i5 = $49;
  }
  $29 = (($$sink$i5) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $32 = (($30) + 8|0);
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 } else if ((($2|0) == 5)) {
  $33 = (($this) + 36|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $34 & 1;
  $36 = ($35|0)==(0);
  if ($36) {
   $$sink$i = $1;
  } else {
   $37 = (($this) + 40|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $40 = HEAP32[$0>>2]|0;
    $41 = $34 >>> 24;
    $42 = $41 & 15;
    $43 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($40,$42)|0);
    HEAP32[$37>>2] = $43;
    $50 = $43;
   } else {
    $50 = $38;
   }
   $$sink$i = $50;
  }
  $44 = (($$sink$i) + 36|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  if ($46) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $47 = (($45) + 8|0);
  $$0 = $47;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx7NpShape9visualizeERNS_2Cm12RenderOutputERKNS_12PxRigidActorE($this,$out,$actor) {
 $this = $this|0;
 $out = $out|0;
 $actor = $actor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0;
 var $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0;
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0);
 var $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0);
 var $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = Math_fround(0), $492 = 0, $493 = Math_fround(0);
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0);
 var $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0);
 var $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0);
 var $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0);
 var $566 = Math_fround(0), $567 = 0, $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0);
 var $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0);
 var $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0);
 var $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0);
 var $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0);
 var $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = 0, $668 = 0, $669 = 0, $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0;
 var $674 = 0, $675 = 0, $676 = Math_fround(0), $677 = 0, $678 = Math_fround(0), $679 = 0, $68 = Math_fround(0), $680 = Math_fround(0), $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $absPose = 0, $pose34 = 0, $tmp = 0, $tmp1 = 0, $tmp2 = 0, $tmp3 = 0, $tmp4 = 0, $tmp6 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $absPose = sp + 484|0;
 $0 = sp + 456|0;
 $1 = sp + 392|0;
 $2 = sp + 360|0;
 $3 = sp + 336|0;
 $4 = sp + 272|0;
 $5 = sp + 248|0;
 $pose34 = sp + 200|0;
 $tmp = sp + 192|0;
 $tmp1 = sp + 164|0;
 $tmp2 = sp + 152|0;
 $tmp3 = sp + 136|0;
 $tmp4 = sp + 96|0;
 $6 = sp + 48|0;
 $7 = sp;
 $tmp6 = sp + 168|0;
 $8 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($actor)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 296|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (Math_fround(FUNCTION_TABLE_fii[$11 & 63]($8,0)));
 $13 = $12 != Math_fround(0.0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$actor>>2]|0;
 $15 = (($14) + 84|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($0,$actor);
 $17 = (($this) + 32|0);
 $18 = (($this) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & 4;
 $21 = ($20|0)==(0);
 if ($21) {
  $31 = (($this) + 80|0);
  $33 = $31;
 } else {
  $22 = (($this) + 40|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $25 = HEAP32[$17>>2]|0;
   $26 = $19 >>> 24;
   $27 = $26 & 15;
   $28 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$27)|0);
   HEAP32[$22>>2] = $28;
   $30 = $28;
  } else {
   $30 = $23;
  }
  $29 = (($30) + 64|0);
  $33 = $29;
 }
 $32 = (($33) + 16|0);
 $34 = Math_fround(HEAPF32[$32>>2]);
 $35 = Math_fround($34 * Math_fround(2.0));
 $36 = (($33) + 20|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * Math_fround(2.0));
 $39 = (($33) + 24|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($40 * Math_fround(2.0));
 $42 = (($0) + 12|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $43);
 $45 = Math_fround($44 + Math_fround(-0.5));
 $46 = Math_fround(HEAPF32[$0>>2]);
 $47 = Math_fround($35 * $46);
 $48 = (($0) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($38 * $49);
 $51 = Math_fround($47 + $50);
 $52 = (($0) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($41 * $53);
 $55 = Math_fround($51 + $54);
 $56 = Math_fround($35 * $45);
 $57 = Math_fround($41 * $49);
 $58 = Math_fround($38 * $53);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($43 * $59);
 $61 = Math_fround($56 + $60);
 $62 = Math_fround($46 * $55);
 $63 = Math_fround($62 + $61);
 $64 = Math_fround($38 * $45);
 $65 = Math_fround($35 * $53);
 $66 = Math_fround($41 * $46);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($43 * $67);
 $69 = Math_fround($64 + $68);
 $70 = Math_fround($49 * $55);
 $71 = Math_fround($70 + $69);
 $72 = Math_fround($41 * $45);
 $73 = Math_fround($38 * $46);
 $74 = Math_fround($35 * $49);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($43 * $75);
 $77 = Math_fround($72 + $76);
 $78 = Math_fround($53 * $55);
 $79 = Math_fround($77 + $78);
 $80 = (($0) + 16|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 + $63);
 $83 = (($0) + 20|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 + $71);
 $86 = (($0) + 24|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($87 + $79);
 $89 = Math_fround(HEAPF32[$33>>2]);
 $90 = Math_fround($43 * $89);
 $91 = (($33) + 12|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($46 * $92);
 $94 = Math_fround($90 + $93);
 $95 = (($33) + 8|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($49 * $96);
 $98 = Math_fround($94 + $97);
 $99 = (($33) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($53 * $100);
 $102 = Math_fround($98 - $101);
 $103 = Math_fround($43 * $100);
 $104 = Math_fround($49 * $92);
 $105 = Math_fround($104 + $103);
 $106 = Math_fround($53 * $89);
 $107 = Math_fround($106 + $105);
 $108 = Math_fround($46 * $96);
 $109 = Math_fround($107 - $108);
 $110 = Math_fround($43 * $96);
 $111 = Math_fround($53 * $92);
 $112 = Math_fround($111 + $110);
 $113 = Math_fround($46 * $100);
 $114 = Math_fround($113 + $112);
 $115 = Math_fround($49 * $89);
 $116 = Math_fround($114 - $115);
 $117 = Math_fround($43 * $92);
 $118 = Math_fround($46 * $89);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($49 * $100);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($53 * $96);
 $123 = Math_fround($121 - $122);
 HEAPF32[$absPose>>2] = $102;
 $124 = (($absPose) + 4|0);
 HEAPF32[$124>>2] = $109;
 $125 = (($absPose) + 8|0);
 HEAPF32[$125>>2] = $116;
 $126 = (($absPose) + 12|0);
 HEAPF32[$126>>2] = $123;
 $127 = (($absPose) + 16|0);
 HEAPF32[$127>>2] = $82;
 $128 = (($absPose) + 20|0);
 HEAPF32[$128>>2] = $85;
 $129 = (($absPose) + 24|0);
 HEAPF32[$129>>2] = $88;
 $130 = HEAP32[$8>>2]|0;
 $131 = (($130) + 296|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = (Math_fround(FUNCTION_TABLE_fii[$132 & 63]($8,12)));
 $134 = $133 != Math_fround(0.0);
 if ($134) {
  $135 = (__ZN5physx2Cm12RenderOutputlsEj($out,-256)|0);
  HEAPF32[$1>>2] = Math_fround(1.0);
  $136 = (($1) + 4|0);
  $137 = (($1) + 20|0);
  ;HEAP32[$136+0>>2]=0|0;HEAP32[$136+4>>2]=0|0;HEAP32[$136+8>>2]=0|0;HEAP32[$136+12>>2]=0|0;
  HEAPF32[$137>>2] = Math_fround(1.0);
  $138 = (($1) + 24|0);
  $139 = (($1) + 40|0);
  ;HEAP32[$138+0>>2]=0|0;HEAP32[$138+4>>2]=0|0;HEAP32[$138+8>>2]=0|0;HEAP32[$138+12>>2]=0|0;
  HEAPF32[$139>>2] = Math_fround(1.0);
  $140 = (($1) + 44|0);
  $141 = (($1) + 60|0);
  ;HEAP32[$140+0>>2]=0|0;HEAP32[$140+4>>2]=0|0;HEAP32[$140+8>>2]=0|0;HEAP32[$140+12>>2]=0|0;
  HEAPF32[$141>>2] = Math_fround(1.0);
  $142 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($135,$1)|0);
  $143 = HEAP32[$18>>2]|0;
  $144 = $143 & 1;
  $145 = ($144|0)==(0);
  if ($145) {
   $153 = (($this) + 116|0);
   $$0$i = $153;
  } else {
   $146 = (($this) + 40|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ($147|0)==(0|0);
   if ($148) {
    $149 = HEAP32[$17>>2]|0;
    $150 = $143 >>> 24;
    $151 = $150 & 15;
    $152 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($149,$151)|0);
    HEAP32[$146>>2] = $152;
    $689 = $152;
   } else {
    $689 = $147;
   }
   $$0$i = $689;
  }
  __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($$0$i,$3,$absPose,Math_fround(0.0),0);
  $154 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$2>>2] = $154;
  $155 = (($2) + 4|0);
  $156 = (($3) + 4|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  HEAPF32[$155>>2] = $157;
  $158 = (($2) + 8|0);
  $159 = (($3) + 8|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  HEAPF32[$158>>2] = $160;
  $161 = (($2) + 12|0);
  $162 = (($3) + 12|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  HEAPF32[$161>>2] = $163;
  $164 = (($2) + 16|0);
  $165 = (($3) + 16|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  HEAPF32[$164>>2] = $166;
  $167 = (($2) + 20|0);
  $168 = (($3) + 20|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  HEAPF32[$167>>2] = $169;
  $170 = (($2) + 24|0);
  HEAP8[$170>>0] = 1;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($142,$2)|0);
 }
 $171 = HEAP32[$8>>2]|0;
 $172 = (($171) + 296|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = (Math_fround(FUNCTION_TABLE_fii[$173 & 63]($8,14)));
 $175 = Math_fround($12 * $174);
 $176 = $175 != Math_fround(0.0);
 if ($176) {
  __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($4,$absPose);
  $177 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$4)|0);
  HEAPF32[$5>>2] = $175;
  $178 = (($5) + 4|0);
  HEAPF32[$178>>2] = $175;
  $179 = (($5) + 8|0);
  HEAPF32[$179>>2] = $175;
  $180 = (($5) + 12|0);
  HEAP32[$180>>2] = 13565952;
  $181 = (($5) + 16|0);
  HEAP32[$181>>2] = 52992;
  $182 = (($5) + 20|0);
  HEAP32[$182>>2] = 207;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($177,$5)|0);
 }
 $183 = HEAP32[$8>>2]|0;
 $184 = (($183) + 296|0);
 $185 = HEAP32[$184>>2]|0;
 $186 = (Math_fround(FUNCTION_TABLE_fii[$185 & 63]($8,13)));
 $187 = $186 != Math_fround(0.0);
 if (!($187)) {
  $188 = HEAP32[$8>>2]|0;
  $189 = (($188) + 296|0);
  $190 = HEAP32[$189>>2]|0;
  $191 = (Math_fround(FUNCTION_TABLE_fii[$190 & 63]($8,16)));
  $192 = $191 != Math_fround(0.0);
  if (!($192)) {
   $193 = HEAP32[$8>>2]|0;
   $194 = (($193) + 296|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = (Math_fround(FUNCTION_TABLE_fii[$195 & 63]($8,17)));
   $197 = $196 != Math_fround(0.0);
   if (!($197)) {
    STACKTOP = sp;return;
   }
  }
 }
 $198 = HEAP32[$8>>2]|0;
 $199 = (($198) + 304|0);
 $200 = HEAP32[$199>>2]|0;
 $201 = (FUNCTION_TABLE_ii[$200 & 4095]($8)|0);
 $202 = HEAP32[$8>>2]|0;
 $203 = (($202) + 296|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = (Math_fround(FUNCTION_TABLE_fii[$204 & 63]($8,16)));
 $206 = Math_fround($12 * $205);
 $207 = HEAP32[$8>>2]|0;
 $208 = (($207) + 296|0);
 $209 = HEAP32[$208>>2]|0;
 $210 = (Math_fround(FUNCTION_TABLE_fii[$209 & 63]($8,30)));
 $211 = $210 != Math_fround(0.0);
 $212 = $211&1;
 $213 = (_bitshift64Shl(($212|0),0,30)|0);
 $214 = tempRet0;
 $215 = HEAP32[$8>>2]|0;
 $216 = (($215) + 296|0);
 $217 = HEAP32[$216>>2]|0;
 $218 = (Math_fround(FUNCTION_TABLE_fii[$217 & 63]($8,16)));
 $219 = $218 != Math_fround(0.0);
 $220 = $219&1;
 $221 = (_bitshift64Shl(($220|0),0,16)|0);
 $222 = tempRet0;
 $223 = $221 | $213;
 $224 = $222 | $214;
 $225 = HEAP32[$8>>2]|0;
 $226 = (($225) + 296|0);
 $227 = HEAP32[$226>>2]|0;
 $228 = (Math_fround(FUNCTION_TABLE_fii[$227 & 63]($8,17)));
 $229 = $228 != Math_fround(0.0);
 $230 = $229&1;
 $231 = (_bitshift64Shl(($230|0),0,17)|0);
 $232 = tempRet0;
 $233 = $223 | $231;
 $234 = $224 | $232;
 $235 = HEAP32[$8>>2]|0;
 $236 = (($235) + 296|0);
 $237 = HEAP32[$236>>2]|0;
 $238 = (Math_fround(FUNCTION_TABLE_fii[$237 & 63]($8,13)));
 $239 = $238 != Math_fround(0.0);
 $240 = $239&1;
 $241 = (_bitshift64Shl(($240|0),0,13)|0);
 $242 = tempRet0;
 $243 = $233 | $241;
 $244 = $234 | $242;
 $245 = Math_fround(HEAPF32[$absPose>>2]);
 $246 = Math_fround($245 + $245);
 $247 = Math_fround(HEAPF32[$124>>2]);
 $248 = Math_fround($247 + $247);
 $249 = Math_fround(HEAPF32[$125>>2]);
 $250 = Math_fround($249 + $249);
 $251 = Math_fround(HEAPF32[$126>>2]);
 $252 = Math_fround($246 * $251);
 $253 = Math_fround($248 * $251);
 $254 = Math_fround($251 * $250);
 $255 = Math_fround($245 * $246);
 $256 = Math_fround($245 * $248);
 $257 = Math_fround($245 * $250);
 $258 = Math_fround($247 * $248);
 $259 = Math_fround($247 * $250);
 $260 = Math_fround($249 * $250);
 $261 = Math_fround(Math_fround(1.0) - $258);
 $262 = Math_fround($261 - $260);
 HEAPF32[$pose34>>2] = $262;
 $263 = Math_fround($256 + $254);
 $264 = (($pose34) + 4|0);
 HEAPF32[$264>>2] = $263;
 $265 = Math_fround($257 - $253);
 $266 = (($pose34) + 8|0);
 HEAPF32[$266>>2] = $265;
 $267 = Math_fround($256 - $254);
 $268 = (($pose34) + 12|0);
 HEAPF32[$268>>2] = $267;
 $269 = Math_fround(Math_fround(1.0) - $255);
 $270 = Math_fround($269 - $260);
 $271 = (($pose34) + 16|0);
 HEAPF32[$271>>2] = $270;
 $272 = Math_fround($259 + $252);
 $273 = (($pose34) + 20|0);
 HEAPF32[$273>>2] = $272;
 $274 = Math_fround($257 + $253);
 $275 = (($pose34) + 24|0);
 HEAPF32[$275>>2] = $274;
 $276 = Math_fround($259 - $252);
 $277 = (($pose34) + 28|0);
 HEAPF32[$277>>2] = $276;
 $278 = Math_fround($269 - $258);
 $279 = (($pose34) + 32|0);
 HEAPF32[$279>>2] = $278;
 $280 = (($pose34) + 36|0);
 $281 = (($pose34) + 40|0);
 $282 = (($pose34) + 44|0);
 $283 = Math_fround(HEAPF32[$127>>2]);
 HEAPF32[$280>>2] = $283;
 $284 = Math_fround(HEAPF32[$128>>2]);
 HEAPF32[$281>>2] = $284;
 $285 = Math_fround(HEAPF32[$129>>2]);
 HEAPF32[$282>>2] = $285;
 $286 = (($this) + 48|0);
 $287 = (__ZNK5physx2Sc9ShapeCore20getNbMaterialIndicesEv($286)|0);
 $288 = $287&65535;
 $289 = HEAP32[$this>>2]|0;
 $290 = (($289) + 24|0);
 $291 = HEAP32[$290>>2]|0;
 $292 = (FUNCTION_TABLE_ii[$291 & 4095]($this)|0);
 switch ($292|0) {
 case 3:  {
  HEAP32[$tmp3>>2] = 3;
  $305 = (($tmp3) + 4|0);
  HEAPF32[$305>>2] = Math_fround(0.0);
  $306 = (($tmp3) + 8|0);
  HEAPF32[$306>>2] = Math_fround(0.0);
  $307 = (($tmp3) + 12|0);
  HEAPF32[$307>>2] = Math_fround(0.0);
  $308 = HEAP32[$this>>2]|0;
  $309 = (($308) + 36|0);
  $310 = HEAP32[$309>>2]|0;
  (FUNCTION_TABLE_iii[$310 & 4095]($this,$tmp3)|0);
  __ZN5physx2Gu5Debug9visualizeERKNS_13PxBoxGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($tmp3,$out,$pose34,$201,$243,$244,$206,$288);
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  HEAP32[$tmp6>>2] = 6;
  $681 = (($tmp6) + 4|0);
  HEAP32[$681>>2] = 0;
  $682 = (($tmp6) + 8|0);
  HEAPF32[$682>>2] = Math_fround(1.0);
  $683 = (($tmp6) + 12|0);
  HEAPF32[$683>>2] = Math_fround(1.0);
  $684 = (($tmp6) + 16|0);
  HEAPF32[$684>>2] = Math_fround(1.0);
  $685 = (($tmp6) + 20|0);
  HEAP32[$685>>2] = 0;
  $686 = HEAP32[$this>>2]|0;
  $687 = (($686) + 60|0);
  $688 = HEAP32[$687>>2]|0;
  (FUNCTION_TABLE_iii[$688 & 4095]($this,$tmp6)|0);
  __ZN5physx2Gu5Debug9visualizeERKNS_21PxHeightFieldGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($tmp6,$out,$pose34,$201,$243,$244,$206,$288);
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  HEAP32[$tmp4>>2] = 4;
  $311 = (($tmp4) + 4|0);
  HEAPF32[$311>>2] = Math_fround(1.0);
  $312 = (($tmp4) + 8|0);
  HEAPF32[$312>>2] = Math_fround(1.0);
  $313 = (($tmp4) + 12|0);
  HEAPF32[$313>>2] = Math_fround(1.0);
  $314 = (($tmp4) + 16|0);
  HEAPF32[$314>>2] = Math_fround(0.0);
  $315 = (($tmp4) + 20|0);
  HEAPF32[$315>>2] = Math_fround(0.0);
  $316 = (($tmp4) + 24|0);
  HEAPF32[$316>>2] = Math_fround(0.0);
  $317 = (($tmp4) + 28|0);
  HEAPF32[$317>>2] = Math_fround(1.0);
  $318 = (($tmp4) + 32|0);
  HEAP32[$318>>2] = 0;
  $319 = HEAP32[$this>>2]|0;
  $320 = (($319) + 52|0);
  $321 = HEAP32[$320>>2]|0;
  (FUNCTION_TABLE_iii[$321 & 4095]($this,$tmp4)|0);
  $322 = Math_fround(HEAPF32[$absPose>>2]);
  $323 = Math_fround(HEAPF32[$124>>2]);
  $324 = Math_fround(HEAPF32[$125>>2]);
  $325 = Math_fround(HEAPF32[$126>>2]);
  $326 = Math_fround($322 + $322);
  $327 = Math_fround($323 + $323);
  $328 = Math_fround($324 + $324);
  $329 = Math_fround($322 * $326);
  $330 = Math_fround($323 * $327);
  $331 = Math_fround($324 * $328);
  $332 = Math_fround($326 * $323);
  $333 = Math_fround($326 * $324);
  $334 = Math_fround($326 * $325);
  $335 = Math_fround($327 * $324);
  $336 = Math_fround($327 * $325);
  $337 = Math_fround($328 * $325);
  $338 = Math_fround(Math_fround(1.0) - $330);
  $339 = Math_fround($338 - $331);
  $340 = Math_fround($332 + $337);
  $341 = Math_fround($333 - $336);
  $342 = Math_fround($332 - $337);
  $343 = Math_fround(Math_fround(1.0) - $329);
  $344 = Math_fround($343 - $331);
  $345 = Math_fround($335 + $334);
  $346 = Math_fround($333 + $336);
  $347 = Math_fround($335 - $334);
  $348 = Math_fround($343 - $330);
  $349 = Math_fround(HEAPF32[$314>>2]);
  $350 = Math_fround(HEAPF32[$315>>2]);
  $351 = Math_fround(HEAPF32[$316>>2]);
  $352 = Math_fround(HEAPF32[$317>>2]);
  $353 = Math_fround($349 + $349);
  $354 = Math_fround($350 + $350);
  $355 = Math_fround($351 + $351);
  $356 = Math_fround($349 * $353);
  $357 = Math_fround($350 * $354);
  $358 = Math_fround($351 * $355);
  $359 = Math_fround($353 * $350);
  $360 = Math_fround($353 * $351);
  $361 = Math_fround($353 * $352);
  $362 = Math_fround($354 * $351);
  $363 = Math_fround($354 * $352);
  $364 = Math_fround($355 * $352);
  $365 = Math_fround(Math_fround(1.0) - $357);
  $366 = Math_fround($365 - $358);
  $367 = Math_fround($359 + $364);
  $368 = Math_fround($360 - $363);
  $369 = Math_fround($359 - $364);
  $370 = Math_fround(Math_fround(1.0) - $356);
  $371 = Math_fround($370 - $358);
  $372 = Math_fround($362 + $361);
  $373 = Math_fround($360 + $363);
  $374 = Math_fround($362 - $361);
  $375 = Math_fround($370 - $357);
  $376 = Math_fround(HEAPF32[$311>>2]);
  $377 = Math_fround($376 * $366);
  $378 = Math_fround($376 * $369);
  $379 = Math_fround($376 * $373);
  $380 = (($311) + 4|0);
  $381 = Math_fround(HEAPF32[$380>>2]);
  $382 = Math_fround($367 * $381);
  $383 = Math_fround($371 * $381);
  $384 = Math_fround($374 * $381);
  $385 = (($311) + 8|0);
  $386 = Math_fround(HEAPF32[$385>>2]);
  $387 = Math_fround($368 * $386);
  $388 = Math_fround($372 * $386);
  $389 = Math_fround($375 * $386);
  $390 = Math_fround($366 * $377);
  $391 = Math_fround($366 * $378);
  $392 = Math_fround($366 * $379);
  $393 = Math_fround($367 * $382);
  $394 = Math_fround($367 * $383);
  $395 = Math_fround($367 * $384);
  $396 = Math_fround($390 + $393);
  $397 = Math_fround($391 + $394);
  $398 = Math_fround($392 + $395);
  $399 = Math_fround($368 * $387);
  $400 = Math_fround($368 * $388);
  $401 = Math_fround($368 * $389);
  $402 = Math_fround($396 + $399);
  $403 = Math_fround($397 + $400);
  $404 = Math_fround($398 + $401);
  $405 = Math_fround($369 * $377);
  $406 = Math_fround($369 * $378);
  $407 = Math_fround($369 * $379);
  $408 = Math_fround($371 * $382);
  $409 = Math_fround($371 * $383);
  $410 = Math_fround($371 * $384);
  $411 = Math_fround($405 + $408);
  $412 = Math_fround($406 + $409);
  $413 = Math_fround($407 + $410);
  $414 = Math_fround($372 * $387);
  $415 = Math_fround($372 * $388);
  $416 = Math_fround($372 * $389);
  $417 = Math_fround($411 + $414);
  $418 = Math_fround($412 + $415);
  $419 = Math_fround($413 + $416);
  $420 = Math_fround($373 * $377);
  $421 = Math_fround($373 * $378);
  $422 = Math_fround($373 * $379);
  $423 = Math_fround($374 * $382);
  $424 = Math_fround($374 * $383);
  $425 = Math_fround($374 * $384);
  $426 = Math_fround($420 + $423);
  $427 = Math_fround($421 + $424);
  $428 = Math_fround($422 + $425);
  $429 = Math_fround($375 * $387);
  $430 = Math_fround($375 * $388);
  $431 = Math_fround($375 * $389);
  $432 = Math_fround($426 + $429);
  $433 = Math_fround($427 + $430);
  $434 = Math_fround($428 + $431);
  $435 = Math_fround($339 * $402);
  $436 = Math_fround($340 * $402);
  $437 = Math_fround($341 * $402);
  $438 = Math_fround($342 * $403);
  $439 = Math_fround($344 * $403);
  $440 = Math_fround($345 * $403);
  $441 = Math_fround($435 + $438);
  $442 = Math_fround($436 + $439);
  $443 = Math_fround($437 + $440);
  $444 = Math_fround($346 * $404);
  $445 = Math_fround($347 * $404);
  $446 = Math_fround($348 * $404);
  $447 = Math_fround($444 + $441);
  $448 = Math_fround($445 + $442);
  $449 = Math_fround($446 + $443);
  $450 = Math_fround($339 * $417);
  $451 = Math_fround($340 * $417);
  $452 = Math_fround($341 * $417);
  $453 = Math_fround($342 * $418);
  $454 = Math_fround($344 * $418);
  $455 = Math_fround($345 * $418);
  $456 = Math_fround($450 + $453);
  $457 = Math_fround($451 + $454);
  $458 = Math_fround($452 + $455);
  $459 = Math_fround($346 * $419);
  $460 = Math_fround($347 * $419);
  $461 = Math_fround($348 * $419);
  $462 = Math_fround($459 + $456);
  $463 = Math_fround($460 + $457);
  $464 = Math_fround($461 + $458);
  $465 = Math_fround($339 * $432);
  $466 = Math_fround($340 * $432);
  $467 = Math_fround($341 * $432);
  $468 = Math_fround($342 * $433);
  $469 = Math_fround($344 * $433);
  $470 = Math_fround($345 * $433);
  $471 = Math_fround($465 + $468);
  $472 = Math_fround($466 + $469);
  $473 = Math_fround($467 + $470);
  $474 = Math_fround($346 * $434);
  $475 = Math_fround($347 * $434);
  $476 = Math_fround($348 * $434);
  $477 = Math_fround($474 + $471);
  $478 = Math_fround($475 + $472);
  $479 = Math_fround($476 + $473);
  HEAPF32[$6>>2] = $447;
  $480 = (($6) + 4|0);
  HEAPF32[$480>>2] = $448;
  $481 = (($6) + 8|0);
  HEAPF32[$481>>2] = $449;
  $482 = (($6) + 12|0);
  HEAPF32[$482>>2] = $462;
  $483 = (($6) + 16|0);
  HEAPF32[$483>>2] = $463;
  $484 = (($6) + 20|0);
  HEAPF32[$484>>2] = $464;
  $485 = (($6) + 24|0);
  HEAPF32[$485>>2] = $477;
  $486 = (($6) + 28|0);
  HEAPF32[$486>>2] = $478;
  $487 = (($6) + 32|0);
  HEAPF32[$487>>2] = $479;
  $488 = (($6) + 36|0);
  $489 = Math_fround(HEAPF32[$127>>2]);
  HEAPF32[$488>>2] = $489;
  $490 = (($6) + 40|0);
  $491 = Math_fround(HEAPF32[$128>>2]);
  HEAPF32[$490>>2] = $491;
  $492 = (($6) + 44|0);
  $493 = Math_fround(HEAPF32[$129>>2]);
  HEAPF32[$492>>2] = $493;
  __ZN5physx2Gu5Debug9visualizeERKNS_20PxConvexMeshGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($tmp4,$out,$6,$201,$243,$244,$206,$288);
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  HEAP32[$tmp>>2] = 0;
  $293 = (($tmp) + 4|0);
  HEAPF32[$293>>2] = Math_fround(0.0);
  $294 = HEAP32[$this>>2]|0;
  $295 = (($294) + 40|0);
  $296 = HEAP32[$295>>2]|0;
  (FUNCTION_TABLE_iii[$296 & 4095]($this,$tmp)|0);
  __ZN5physx2Gu5Debug9visualizeERKNS_16PxSphereGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($tmp,$out,$pose34,$201,$243,$244,$206,$288);
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  HEAP32[$tmp4>>2] = 5;
  $494 = (($tmp4) + 4|0);
  HEAPF32[$494>>2] = Math_fround(1.0);
  $495 = (($tmp4) + 8|0);
  HEAPF32[$495>>2] = Math_fround(1.0);
  $496 = (($tmp4) + 12|0);
  HEAPF32[$496>>2] = Math_fround(1.0);
  $497 = (($tmp4) + 16|0);
  HEAPF32[$497>>2] = Math_fround(0.0);
  $498 = (($tmp4) + 20|0);
  HEAPF32[$498>>2] = Math_fround(0.0);
  $499 = (($tmp4) + 24|0);
  HEAPF32[$499>>2] = Math_fround(0.0);
  $500 = (($tmp4) + 28|0);
  HEAPF32[$500>>2] = Math_fround(1.0);
  $501 = (($tmp4) + 32|0);
  $502 = $501;
  $503 = $502;
  HEAP32[$503>>2] = 0;
  $504 = (($502) + 4)|0;
  $505 = $504;
  HEAP32[$505>>2] = 0;
  $506 = HEAP32[$this>>2]|0;
  $507 = (($506) + 56|0);
  $508 = HEAP32[$507>>2]|0;
  (FUNCTION_TABLE_iii[$508 & 4095]($this,$tmp4)|0);
  $509 = Math_fround(HEAPF32[$absPose>>2]);
  $510 = Math_fround(HEAPF32[$124>>2]);
  $511 = Math_fround(HEAPF32[$125>>2]);
  $512 = Math_fround(HEAPF32[$126>>2]);
  $513 = Math_fround($509 + $509);
  $514 = Math_fround($510 + $510);
  $515 = Math_fround($511 + $511);
  $516 = Math_fround($509 * $513);
  $517 = Math_fround($510 * $514);
  $518 = Math_fround($511 * $515);
  $519 = Math_fround($513 * $510);
  $520 = Math_fround($513 * $511);
  $521 = Math_fround($513 * $512);
  $522 = Math_fround($514 * $511);
  $523 = Math_fround($514 * $512);
  $524 = Math_fround($515 * $512);
  $525 = Math_fround(Math_fround(1.0) - $517);
  $526 = Math_fround($525 - $518);
  $527 = Math_fround($519 + $524);
  $528 = Math_fround($520 - $523);
  $529 = Math_fround($519 - $524);
  $530 = Math_fround(Math_fround(1.0) - $516);
  $531 = Math_fround($530 - $518);
  $532 = Math_fround($522 + $521);
  $533 = Math_fround($520 + $523);
  $534 = Math_fround($522 - $521);
  $535 = Math_fround($530 - $517);
  $536 = Math_fround(HEAPF32[$497>>2]);
  $537 = Math_fround(HEAPF32[$498>>2]);
  $538 = Math_fround(HEAPF32[$499>>2]);
  $539 = Math_fround(HEAPF32[$500>>2]);
  $540 = Math_fround($536 + $536);
  $541 = Math_fround($537 + $537);
  $542 = Math_fround($538 + $538);
  $543 = Math_fround($536 * $540);
  $544 = Math_fround($537 * $541);
  $545 = Math_fround($538 * $542);
  $546 = Math_fround($540 * $537);
  $547 = Math_fround($540 * $538);
  $548 = Math_fround($540 * $539);
  $549 = Math_fround($541 * $538);
  $550 = Math_fround($541 * $539);
  $551 = Math_fround($542 * $539);
  $552 = Math_fround(Math_fround(1.0) - $544);
  $553 = Math_fround($552 - $545);
  $554 = Math_fround($546 + $551);
  $555 = Math_fround($547 - $550);
  $556 = Math_fround($546 - $551);
  $557 = Math_fround(Math_fround(1.0) - $543);
  $558 = Math_fround($557 - $545);
  $559 = Math_fround($549 + $548);
  $560 = Math_fround($547 + $550);
  $561 = Math_fround($549 - $548);
  $562 = Math_fround($557 - $544);
  $563 = Math_fround(HEAPF32[$494>>2]);
  $564 = Math_fround($563 * $553);
  $565 = Math_fround($563 * $556);
  $566 = Math_fround($563 * $560);
  $567 = (($494) + 4|0);
  $568 = Math_fround(HEAPF32[$567>>2]);
  $569 = Math_fround($554 * $568);
  $570 = Math_fround($558 * $568);
  $571 = Math_fround($561 * $568);
  $572 = (($494) + 8|0);
  $573 = Math_fround(HEAPF32[$572>>2]);
  $574 = Math_fround($555 * $573);
  $575 = Math_fround($559 * $573);
  $576 = Math_fround($562 * $573);
  $577 = Math_fround($553 * $564);
  $578 = Math_fround($553 * $565);
  $579 = Math_fround($553 * $566);
  $580 = Math_fround($554 * $569);
  $581 = Math_fround($554 * $570);
  $582 = Math_fround($554 * $571);
  $583 = Math_fround($577 + $580);
  $584 = Math_fround($578 + $581);
  $585 = Math_fround($579 + $582);
  $586 = Math_fround($555 * $574);
  $587 = Math_fround($555 * $575);
  $588 = Math_fround($555 * $576);
  $589 = Math_fround($583 + $586);
  $590 = Math_fround($584 + $587);
  $591 = Math_fround($585 + $588);
  $592 = Math_fround($556 * $564);
  $593 = Math_fround($556 * $565);
  $594 = Math_fround($556 * $566);
  $595 = Math_fround($558 * $569);
  $596 = Math_fround($558 * $570);
  $597 = Math_fround($558 * $571);
  $598 = Math_fround($592 + $595);
  $599 = Math_fround($593 + $596);
  $600 = Math_fround($594 + $597);
  $601 = Math_fround($559 * $574);
  $602 = Math_fround($559 * $575);
  $603 = Math_fround($559 * $576);
  $604 = Math_fround($598 + $601);
  $605 = Math_fround($599 + $602);
  $606 = Math_fround($600 + $603);
  $607 = Math_fround($560 * $564);
  $608 = Math_fround($560 * $565);
  $609 = Math_fround($560 * $566);
  $610 = Math_fround($561 * $569);
  $611 = Math_fround($561 * $570);
  $612 = Math_fround($561 * $571);
  $613 = Math_fround($607 + $610);
  $614 = Math_fround($608 + $611);
  $615 = Math_fround($609 + $612);
  $616 = Math_fround($562 * $574);
  $617 = Math_fround($562 * $575);
  $618 = Math_fround($562 * $576);
  $619 = Math_fround($613 + $616);
  $620 = Math_fround($614 + $617);
  $621 = Math_fround($615 + $618);
  $622 = Math_fround($526 * $589);
  $623 = Math_fround($527 * $589);
  $624 = Math_fround($528 * $589);
  $625 = Math_fround($529 * $590);
  $626 = Math_fround($531 * $590);
  $627 = Math_fround($532 * $590);
  $628 = Math_fround($622 + $625);
  $629 = Math_fround($623 + $626);
  $630 = Math_fround($624 + $627);
  $631 = Math_fround($533 * $591);
  $632 = Math_fround($534 * $591);
  $633 = Math_fround($535 * $591);
  $634 = Math_fround($631 + $628);
  $635 = Math_fround($632 + $629);
  $636 = Math_fround($633 + $630);
  $637 = Math_fround($526 * $604);
  $638 = Math_fround($527 * $604);
  $639 = Math_fround($528 * $604);
  $640 = Math_fround($529 * $605);
  $641 = Math_fround($531 * $605);
  $642 = Math_fround($532 * $605);
  $643 = Math_fround($637 + $640);
  $644 = Math_fround($638 + $641);
  $645 = Math_fround($639 + $642);
  $646 = Math_fround($533 * $606);
  $647 = Math_fround($534 * $606);
  $648 = Math_fround($535 * $606);
  $649 = Math_fround($646 + $643);
  $650 = Math_fround($647 + $644);
  $651 = Math_fround($648 + $645);
  $652 = Math_fround($526 * $619);
  $653 = Math_fround($527 * $619);
  $654 = Math_fround($528 * $619);
  $655 = Math_fround($529 * $620);
  $656 = Math_fround($531 * $620);
  $657 = Math_fround($532 * $620);
  $658 = Math_fround($652 + $655);
  $659 = Math_fround($653 + $656);
  $660 = Math_fround($654 + $657);
  $661 = Math_fround($533 * $621);
  $662 = Math_fround($534 * $621);
  $663 = Math_fround($535 * $621);
  $664 = Math_fround($661 + $658);
  $665 = Math_fround($662 + $659);
  $666 = Math_fround($663 + $660);
  HEAPF32[$7>>2] = $634;
  $667 = (($7) + 4|0);
  HEAPF32[$667>>2] = $635;
  $668 = (($7) + 8|0);
  HEAPF32[$668>>2] = $636;
  $669 = (($7) + 12|0);
  HEAPF32[$669>>2] = $649;
  $670 = (($7) + 16|0);
  HEAPF32[$670>>2] = $650;
  $671 = (($7) + 20|0);
  HEAPF32[$671>>2] = $651;
  $672 = (($7) + 24|0);
  HEAPF32[$672>>2] = $664;
  $673 = (($7) + 28|0);
  HEAPF32[$673>>2] = $665;
  $674 = (($7) + 32|0);
  HEAPF32[$674>>2] = $666;
  $675 = (($7) + 36|0);
  $676 = Math_fround(HEAPF32[$127>>2]);
  HEAPF32[$675>>2] = $676;
  $677 = (($7) + 40|0);
  $678 = Math_fround(HEAPF32[$128>>2]);
  HEAPF32[$677>>2] = $678;
  $679 = (($7) + 44|0);
  $680 = Math_fround(HEAPF32[$129>>2]);
  HEAPF32[$679>>2] = $680;
  __ZN5physx2Gu5Debug9visualizeERKNS_22PxTriangleMeshGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($tmp4,$out,$7,$201,$243,$244,$206,$288);
  STACKTOP = sp;return;
  break;
 }
 case 2:  {
  HEAP32[$tmp2>>2] = 2;
  $300 = (($tmp2) + 4|0);
  HEAPF32[$300>>2] = Math_fround(0.0);
  $301 = (($tmp2) + 8|0);
  HEAPF32[$301>>2] = Math_fround(0.0);
  $302 = HEAP32[$this>>2]|0;
  $303 = (($302) + 44|0);
  $304 = HEAP32[$303>>2]|0;
  (FUNCTION_TABLE_iii[$304 & 4095]($this,$tmp2)|0);
  __ZN5physx2Gu5Debug9visualizeERKNS_17PxCapsuleGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($tmp2,$out,$pose34,$201,$243,$244,$206,$288);
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  HEAP32[$tmp1>>2] = 1;
  $297 = HEAP32[$this>>2]|0;
  $298 = (($297) + 48|0);
  $299 = HEAP32[$298>>2]|0;
  (FUNCTION_TABLE_iii[$299 & 4095]($this,$tmp1)|0);
  __ZN5physx2Gu5Debug9visualizeERKNS_15PxPlaneGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($tmp1,$out,$pose34,$201,$243,$244,$206,$288);
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZNK5physx7PxShape19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (438776|0);
}
function __ZNK5physx7PxShape8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(438776,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,438784)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx3Scb5Shape6Access5writeINS0_11ShapeBuffer3FnsILj64ELj0EEEEEvRS1_RNS_2Sc9ShapeCoreENT_3ArgE($base,$core,$v) {
 $base = $base|0;
 $core = $core|0;
 $v = $v|0;
 var $$0$in$i$i = 0, $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = (($base) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 >>> 30;
 if ((($5|0) == 3)) {
  label = 6;
 } else if ((($5|0) == 2)) {
  $6 = HEAP32[$base>>2]|0;
  $7 = (($6) + 2417|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if (!($9)) {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $18 = (($base) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $21 = HEAP32[$base>>2]|0;
   $22 = $4 >>> 24;
   $23 = $22 & 15;
   $24 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($21,$23)|0);
   HEAP32[$18>>2] = $24;
   $27 = $24;
  } else {
   $27 = $19;
  }
  $25 = HEAP8[$v>>0]|0;
  $26 = (($27) + 116|0);
  HEAP8[$26>>0] = $25;
  $28 = HEAP32[$base>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$base);
  $29 = HEAP32[$3>>2]|0;
  $30 = $29 | 64;
  HEAP32[$3>>2] = $30;
  STACKTOP = sp;return;
 }
 $10 = (($core) + 64|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = HEAP8[$v>>0]|0;
 HEAP8[$0>>0] = $12;
 __ZN5physx2Sc9ShapeCore8setFlagsENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($core,$0);
 $13 = (($base) + -12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$3>>2]|0;
 $$mask = $16 & -1073741824;
 $17 = ($$mask|0)==(1073741824);
 if ($17) {
  STACKTOP = sp;return;
 }
 $$0$in$i$i = (($14) + 64|0);
 HEAP32[$1>>2] = 64;
 HEAP8[$2>>0] = $11;
 __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($$0$in$i$i,$core,$1,$2);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Shape6Access5writeINS0_11ShapeBuffer3FnsILj32ELj0EEEEEvRS1_RNS_2Sc9ShapeCoreENT_3ArgE($base,$core,$v) {
 $base = $base|0;
 $core = $core|0;
 $v = Math_fround($v);
 var $$0$in$i$i = 0, $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($base) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$base>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   label = 6;
  }
 } else if ((($4|0) == 3)) {
  label = 6;
 }
 if ((label|0) == 6) {
  $16 = (($base) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = HEAP32[$base>>2]|0;
   $20 = $3 >>> 24;
   $21 = $20 & 15;
   $22 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($19,$21)|0);
   HEAP32[$16>>2] = $22;
   $24 = $22;
  } else {
   $24 = $17;
  }
  $23 = (($24) + 112|0);
  HEAPF32[$23>>2] = $v;
  $25 = HEAP32[$base>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($25,$base);
  $26 = HEAP32[$2>>2]|0;
  $27 = $26 | 32;
  HEAP32[$2>>2] = $27;
  STACKTOP = sp;return;
 }
 $9 = (($core) + 64|0);
 $10 = HEAP8[$9>>0]|0;
 __ZN5physx2Sc9ShapeCore13setRestOffsetEf($core,$v);
 $11 = (($base) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$2>>2]|0;
 $$mask = $14 & -1073741824;
 $15 = ($$mask|0)==(1073741824);
 if ($15) {
  STACKTOP = sp;return;
 }
 $$0$in$i$i = (($12) + 64|0);
 HEAP32[$0>>2] = 32;
 HEAP8[$1>>0] = $10;
 __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($$0$in$i$i,$core,$0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Shape6Access5writeINS0_11ShapeBuffer3FnsILj8ELj0EEEEEvRS1_RNS_2Sc9ShapeCoreENT_3ArgE($base,$core,$v) {
 $base = $base|0;
 $core = $core|0;
 $v = $v|0;
 var $$0$in$i$i = 0, $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($base) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$base>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   label = 6;
  }
 } else if ((($4|0) == 3)) {
  label = 6;
 }
 if ((label|0) == 6) {
  $16 = (($base) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = HEAP32[$base>>2]|0;
   $20 = $3 >>> 24;
   $21 = $20 & 15;
   $22 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($19,$21)|0);
   HEAP32[$16>>2] = $22;
   $24 = $22;
  } else {
   $24 = $17;
  }
  $23 = (($24) + 92|0);
  ;HEAP32[$23+0>>2]=HEAP32[$v+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$v+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$v+12>>2]|0;
  $25 = HEAP32[$base>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($25,$base);
  $26 = HEAP32[$2>>2]|0;
  $27 = $26 | 8;
  HEAP32[$2>>2] = $27;
  STACKTOP = sp;return;
 }
 $9 = (($core) + 64|0);
 $10 = HEAP8[$9>>0]|0;
 __ZN5physx2Sc9ShapeCore23setSimulationFilterDataERKNS_12PxFilterDataE($core,$v);
 $11 = (($base) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$2>>2]|0;
 $$mask = $14 & -1073741824;
 $15 = ($$mask|0)==(1073741824);
 if ($15) {
  STACKTOP = sp;return;
 }
 $$0$in$i$i = (($12) + 64|0);
 HEAP32[$0>>2] = 8;
 HEAP8[$1>>0] = $10;
 __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($$0$in$i$i,$core,$0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Shape6Access5writeINS0_11ShapeBuffer3FnsILj4ELj0EEEEEvRS1_RNS_2Sc9ShapeCoreENT_3ArgE($base,$core,$v) {
 $base = $base|0;
 $core = $core|0;
 $v = $v|0;
 var $$0$in$i$i = 0, $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($base) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  label = 6;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$base>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $16 = (($base) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = HEAP32[$base>>2]|0;
   $20 = $3 >>> 24;
   $21 = $20 & 15;
   $22 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($19,$21)|0);
   HEAP32[$16>>2] = $22;
   $25 = $22;
  } else {
   $25 = $17;
  }
  $23 = Math_fround(HEAPF32[$v>>2]);
  $24 = (($25) + 64|0);
  HEAPF32[$24>>2] = $23;
  $26 = (($v) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($25) + 68|0);
  HEAPF32[$28>>2] = $27;
  $29 = (($v) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($25) + 72|0);
  HEAPF32[$31>>2] = $30;
  $32 = (($v) + 12|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($25) + 76|0);
  HEAPF32[$34>>2] = $33;
  $35 = (($v) + 16|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($25) + 80|0);
  HEAPF32[$37>>2] = $36;
  $38 = (($v) + 20|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($25) + 84|0);
  HEAPF32[$40>>2] = $39;
  $41 = (($v) + 24|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($25) + 88|0);
  HEAPF32[$43>>2] = $42;
  $44 = HEAP32[$base>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($44,$base);
  $45 = HEAP32[$2>>2]|0;
  $46 = $45 | 4;
  HEAP32[$2>>2] = $46;
  STACKTOP = sp;return;
 }
 $9 = (($core) + 64|0);
 $10 = HEAP8[$9>>0]|0;
 __ZN5physx2Sc9ShapeCore14setShape2ActorERKNS_11PxTransformE($core,$v);
 $11 = (($base) + -12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$2>>2]|0;
 $$mask = $14 & -1073741824;
 $15 = ($$mask|0)==(1073741824);
 if ($15) {
  STACKTOP = sp;return;
 }
 $$0$in$i$i = (($12) + 64|0);
 HEAP32[$0>>2] = 4;
 HEAP8[$1>>0] = $10;
 __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($$0$in$i$i,$core,$0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx7PxShapeD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx7PxShapeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManagerC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 0;
 $1 = (($this) + 6|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 7|0);
 HEAP8[$2>>0] = 0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 12|0);
 HEAP16[$4>>1] = 0;
 $5 = (($this) + 14|0);
 HEAP8[$5>>0] = 1;
 $6 = (($this) + 15|0);
 HEAP8[$6>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Cm8PtrTable15exportExtraDataERNS_22PxSerializationContextE($this,$stream);
 $0 = (($this) + 8|0);
 __ZN5physx2Cm8PtrTable15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager11attachShapeERNS_7NpShapeERNS_12PxRigidActorE($this,$shape,$actor) {
 $this = $this|0;
 $shape = $shape|0;
 $actor = $actor|0;
 var $$$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 __ZN5physx2Cm8PtrTable6addPtrEPv($this,$shape);
 $4 = (($this) + 8|0);
 __ZN5physx2Cm8PtrTable6addPtrEPv($4,0);
 $5 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($actor)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZNK5physx7NpShape8getFlagsEv($0,$shape);
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 2;
  $9 = ($8<<24>>24)==(0);
  if (!($9)) {
   $10 = (($5) + 3376|0);
   $11 = (($actor) + 4|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = ($12<<16>>16)==(5);
   $14 = ($12<<16>>16)==(15);
   $$$i = $13 | $14;
   $15 = HEAP16[$1>>1]|0;
   $16 = ($15<<16>>16)==(1);
   if ($16) {
    $19 = $this;
   } else {
    $17 = HEAP32[$this>>2]|0;
    $19 = $17;
   }
   $18 = (($19) + ($3<<2)|0);
   $20 = HEAP32[$18>>2]|0;
   $21 = (__ZN5physx2Sq17SceneQueryManager8addShapeERKNS_7NpShapeERKNS_12PxRigidActorEbPNS_9PxBounds3E($10,$20,$actor,$$$i,0)|0);
   $22 = (($this) + 12|0);
   $23 = HEAP16[$22>>1]|0;
   $24 = ($23<<16>>16)==(1);
   if ($24) {
    $27 = $4;
   } else {
    $25 = HEAP32[$4>>2]|0;
    $27 = $25;
   }
   $26 = (($27) + ($3<<2)|0);
   HEAP32[$26>>2] = $21;
  }
 }
 $28 = (($actor) + 4|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = $29&65535;
 $31 = ((414264 + ($30<<2)|0) + 68|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($actor) + ($32)|0);
 $34 = (($shape) + 32|0);
 __ZN5physx3Scb11RigidObject13onShapeAttachERNS0_5ShapeE($33,$34);
 $35 = (($shape) + 16|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($35)|0);
 $36 = HEAP32[$shape>>2]|0;
 $37 = (($36) + 140|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 4095]($shape)|0);
 if (!($39)) {
  STACKTOP = sp;return;
 }
 __ZN5physx7NpShape8setActorEPNS_12PxRigidActorE($shape,$actor);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb11RigidObject13onShapeAttachERNS0_5ShapeE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$in = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $index$0$lcssa$i = 0, $index$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 2417|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $9 = $2 & 1;
  $10 = ($9|0)==(0);
  if ($10) {
   $17 = $2 >>> 24;
   $18 = $17 & 15;
   $19 = ((444424 + ($18<<2)|0) + 24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $this;
   $22 = (($20) + ($21))|0;
   $23 = $22;
   $24 = (($23) + 8|0);
   $$in = $24;
  } else {
   $11 = (($this) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = $2 >>> 24;
    $15 = $14 & 15;
    $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($5,$15)|0);
    HEAP32[$11>>2] = $16;
    $99 = $16;
   } else {
    $99 = $12;
   }
   $$in = $99;
  }
  $25 = HEAP16[$$in>>1]|0;
  $26 = $25 & 8;
  $27 = ($26<<16>>16)==(0);
  if ($27) {
   __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($shape);
   $28 = $this;
   $29 = HEAP32[$1>>2]|0;
   $30 = $29 >>> 24;
   $31 = $30 & 15;
   $32 = ((444424 + ($31<<2)|0) + 24|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + ($28))|0;
   $35 = $34;
   $36 = (($shape) + 16|0);
   __ZN5physx2Sc9RigidCore15addShapeToSceneERNS0_9ShapeCoreE($35,$36);
   $$pre$phiZ2D = $28;
  } else {
   $$pre = $this;
   $$pre$phiZ2D = $$pre;
  }
  $37 = HEAP32[$1>>2]|0;
  $38 = $37 >>> 24;
  $39 = $38 & 15;
  $40 = ((444424 + ($39<<2)|0) + 24|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + ($$pre$phiZ2D))|0;
  $43 = $42;
  (__ZNK5physx2Sc9RigidCore10getPxActorEv($43)|0);
  $44 = (($shape) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $45 & 251658240;
  $47 = ($46|0)==(16777216);
  if (!($47)) {
   STACKTOP = sp;return;
  }
  $48 = $45 & 1073741823;
  $49 = $48 | -2147483648;
  HEAP32[$44>>2] = $49;
  HEAP32[$shape>>2] = $5;
  STACKTOP = sp;return;
 }
 $50 = ($3|0)==(1);
 if ($50) {
  $51 = (($shape) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 & 251658240;
  $54 = ($53|0)==(16777216);
  if (!($54)) {
   STACKTOP = sp;return;
  }
  $55 = $52 & 1073741823;
  $56 = $55 | 1073741824;
  HEAP32[$51>>2] = $56;
  HEAP32[$shape>>2] = $5;
  STACKTOP = sp;return;
 }
 $57 = (($this) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  $60 = $2 >>> 24;
  $61 = $60 & 15;
  $62 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($5,$61)|0);
  HEAP32[$57>>2] = $62;
  $64 = $62;
 } else {
  $64 = $58;
 }
 $63 = (($64) + 76|0);
 $65 = HEAP32[$63>>2]|0;
 $66 = ($65|0)==(0);
 if ($66) {
  label = 24;
 } else {
  $67 = (($64) + 72|0);
  $68 = HEAP32[$67>>2]|0;
  $index$01$i = 0;
  while(1) {
   $71 = (($68) + ($index$01$i<<3)|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==($shape|0);
   $70 = (($index$01$i) + 1)|0;
   if ($73) {
    $index$0$lcssa$i = $index$01$i;
    break;
   }
   $69 = ($70>>>0)<($65>>>0);
   if ($69) {
    $index$01$i = $70;
   } else {
    $index$0$lcssa$i = $70;
    break;
   }
  }
  $74 = ($index$0$lcssa$i|0)==($65|0);
  if ($74) {
   label = 24;
  } else {
   $75 = (($68) + ($index$0$lcssa$i<<3)|0);
   $76 = (($65) + -1)|0;
   HEAP32[$63>>2] = $76;
   $77 = (($68) + ($76<<3)|0);
   ;HEAP32[$75+0>>2]=HEAP32[$77+0>>2]|0;HEAP8[$75+4>>0]=HEAP8[$77+4>>0]|0;
  }
 }
 do {
  if ((label|0) == 24) {
   HEAP32[$0>>2] = $shape;
   $78 = (($64) + 32|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = $79 & 2147483647;
   $81 = (($64) + 28|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($80>>>0)>($82>>>0);
   if (!($83)) {
    $84 = (($64) + 4|0);
    (__ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS4_EEEEE15growAndPushBackERKS4_($84,$0)|0);
    break;
   }
   $85 = (($64) + 24|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + ($82<<2)|0);
   $88 = ($87|0)==(0|0);
   if (!($88)) {
    HEAP32[$87>>2] = $shape;
   }
   $89 = (($82) + 1)|0;
   HEAP32[$81>>2] = $89;
  }
 } while(0);
 $90 = HEAP32[$this>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($90,$this);
 $91 = HEAP32[$1>>2]|0;
 $92 = $91 | 8;
 HEAP32[$1>>2] = $92;
 $93 = (($shape) + 4|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = $94 & 251658240;
 $96 = ($95|0)==(16777216);
 if (!($96)) {
  STACKTOP = sp;return;
 }
 $97 = $94 & 1073741823;
 $98 = $97 | 1073741824;
 HEAP32[$93>>2] = $98;
 HEAP32[$shape>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager11detachShapeERNS_7NpShapeERNS_12PxRigidActorEb($this,$s,$actor,$wakeOnLostTouch) {
 $this = $this|0;
 $s = $s|0;
 $actor = $actor|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZNK5physx2Cm8PtrTable4findEPKv($this,$s)|0);
 $2 = (($actor) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($actor) + ($6)|0);
 $8 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($actor)|0);
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  __ZNK5physx7NpShape8getFlagsEv($0,$s);
  $10 = HEAP8[$0>>0]|0;
  $11 = $10 & 2;
  $12 = ($11<<24>>24)==(0);
  if (!($12)) {
   $13 = (($8) + 3376|0);
   $14 = (($this) + 8|0);
   $15 = (($this) + 12|0);
   $16 = HEAP16[$15>>1]|0;
   $17 = ($16<<16>>16)==(1);
   if ($17) {
    $20 = $14;
   } else {
    $18 = HEAP32[$14>>2]|0;
    $20 = $18;
   }
   $19 = (($20) + ($1<<2)|0);
   $21 = HEAP32[$19>>2]|0;
   __ZN5physx2Sq17SceneQueryManager11removeShapeEPNS0_10ActorShapeE($13,$21);
  }
 }
 $22 = (($s) + 32|0);
 $23 = (($s) + 12|0);
 $24 = (($s) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(1);
 __ZN5physx3Scb11RigidObject13onShapeDetachERNS0_5ShapeEbb($7,$22,$wakeOnLostTouch,$26);
 __ZN5physx2Cm8PtrTable6removeEj($this,$1);
 $27 = (($this) + 8|0);
 __ZN5physx2Cm8PtrTable6removeEj($27,$1);
 $28 = (__ZNK5physx7NpShape11isExclusiveEv($s)|0);
 if ($28) {
  __ZN5physx7NpShape8setActorEPNS_12PxRigidActorE($s,0);
 }
 $29 = (__ZN5physx6shdfnd15atomicDecrementEPVi($24)|0);
 $30 = ($29|0)==(0);
 if (!($30)) {
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$23>>2]|0;
 $32 = (($31) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vi[$33 & 4095]($23);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb11RigidObject13onShapeDetachERNS0_5ShapeEbb($this,$shape,$wakeOnLostTouch,$toBeReleased) {
 $this = $this|0;
 $shape = $shape|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 $toBeReleased = $toBeReleased|0;
 var $$c = 0, $$in = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre15 = 0, $$sum = 0, $$sum11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $idx$012 = 0, $idx$1 = 0, $index$0$lcssa$i = 0, $index$01$i = 0, $k$014 = 0, $lastIdx$013 = 0, $lastIdx$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 2417|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $10 = $this;
  $11 = $3 >>> 24;
  $12 = $11 & 15;
  $13 = ((444424 + ($12<<2)|0) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($10))|0;
  $16 = $15;
  (__ZNK5physx2Sc9RigidCore10getPxActorEv($16)|0);
  $17 = HEAP32[$2>>2]|0;
  $18 = $17 & 1;
  $19 = ($18|0)==(0);
  if ($19) {
   $27 = $17 >>> 24;
   $28 = $27 & 15;
   $29 = ((444424 + ($28<<2)|0) + 24|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + ($10))|0;
   $32 = $31;
   $33 = (($32) + 8|0);
   $$in = $33;
  } else {
   $20 = (($this) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   if ($22) {
    $23 = HEAP32[$this>>2]|0;
    $24 = $17 >>> 24;
    $25 = $24 & 15;
    $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($23,$25)|0);
    HEAP32[$20>>2] = $26;
    $193 = $26;
   } else {
    $193 = $21;
   }
   $$in = $193;
  }
  $34 = HEAP16[$$in>>1]|0;
  $35 = $34 & 8;
  $36 = ($35<<16>>16)==(0);
  if ($36) {
   $37 = HEAP32[$2>>2]|0;
   $38 = $37 >>> 24;
   $39 = $38 & 15;
   $40 = ((444424 + ($39<<2)|0) + 24|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + ($10))|0;
   $43 = $42;
   $44 = (($shape) + 16|0);
   __ZN5physx2Sc9RigidCore20removeShapeFromSceneERNS0_9ShapeCoreEb($43,$44,$wakeOnLostTouch);
   __ZN5physx18NpShapeDecRefCountERNS_3Scb5ShapeE($shape);
  }
  $45 = (($shape) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46 & 251658240;
  $48 = ($47|0)==(16777216);
  if (!($48)) {
   STACKTOP = sp;return;
  }
  $49 = $46 & 1073741823;
  HEAP32[$45>>2] = $49;
  HEAP32[$shape>>2] = 0;
  STACKTOP = sp;return;
 }
 $50 = ($4|0)==(1);
 if ($50) {
  $51 = (($shape) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 & 251658240;
  $54 = ($53|0)==(16777216);
  if (!($54)) {
   STACKTOP = sp;return;
  }
  $55 = $52 & 1073741823;
  HEAP32[$51>>2] = $55;
  HEAP32[$shape>>2] = 0;
  STACKTOP = sp;return;
 }
 $56 = (($this) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 if ($58) {
  $59 = $3 >>> 24;
  $60 = $59 & 15;
  $61 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($6,$60)|0);
  HEAP32[$56>>2] = $61;
  $$pre = HEAP32[$2>>2]|0;
  $63 = $$pre;$66 = $61;
 } else {
  $63 = $3;$66 = $57;
 }
 $62 = $63 & 32;
 $64 = ($62|0)==(0);
 L31: do {
  if (!($64)) {
   $65 = (($66) + 88|0);
   $67 = HEAP32[$65>>2]|0;
   $68 = ($67|0)==(1);
   $69 = (($66) + 84|0);
   if ($68) {
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==($shape|0);
    if (!($71)) {
     break;
    }
    HEAP32[$65>>2] = 0;
    HEAP32[$69>>2] = 0;
    $72 = HEAP32[$2>>2]|0;
    $73 = $72 & -33;
    HEAP32[$2>>2] = $73;
    break;
   }
   $74 = HEAP32[$69>>2]|0;
   $75 = (($6) + 2500|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($76) + ($74<<2)|0);
   $78 = ($67|0)==(0);
   do {
    if ($78) {
     HEAP32[$65>>2] = 0;
    } else {
     $idx$012 = 0;$k$014 = 0;$lastIdx$013 = $67;
     while(1) {
      $$sum = (($idx$012) + ($74))|0;
      $79 = (($76) + ($$sum<<2)|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)==($shape|0);
      if ($81) {
       $83 = (($lastIdx$013) + -1)|0;
       $$sum11 = (($83) + ($74))|0;
       $84 = (($76) + ($$sum11<<2)|0);
       $85 = HEAP32[$84>>2]|0;
       HEAP32[$79>>2] = $85;
       $idx$1 = $idx$012;$lastIdx$1 = $83;
      } else {
       $82 = (($idx$012) + 1)|0;
       $idx$1 = $82;$lastIdx$1 = $lastIdx$013;
      }
      $86 = (($k$014) + 1)|0;
      $87 = ($86>>>0)<($67>>>0);
      if ($87) {
       $idx$012 = $idx$1;$k$014 = $86;$lastIdx$013 = $lastIdx$1;
      } else {
       break;
      }
     }
     HEAP32[$65>>2] = $idx$1;
     if ((($idx$1|0) == 0)) {
      break;
     } else if (!((($idx$1|0) == 1))) {
      break L31;
     }
     $90 = HEAP32[$77>>2]|0;
     $$c = $90;
     HEAP32[$69>>2] = $$c;
     break L31;
    }
   } while(0);
   HEAP32[$69>>2] = 0;
   $88 = HEAP32[$2>>2]|0;
   $89 = $88 & -33;
   HEAP32[$2>>2] = $89;
  }
 } while(0);
 $91 = (($66) + 28|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0);
 if ($93) {
  label = 37;
 } else {
  $94 = (($66) + 24|0);
  $95 = HEAP32[$94>>2]|0;
  $index$01$i = 0;
  while(1) {
   $98 = (($95) + ($index$01$i<<2)|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)==($shape|0);
   $97 = (($index$01$i) + 1)|0;
   if ($100) {
    $index$0$lcssa$i = $index$01$i;
    break;
   }
   $96 = ($97>>>0)<($92>>>0);
   if ($96) {
    $index$01$i = $97;
   } else {
    $index$0$lcssa$i = $97;
    break;
   }
  }
  $101 = ($index$0$lcssa$i|0)==($92|0);
  if ($101) {
   label = 37;
  } else {
   $102 = (($92) + -1)|0;
   HEAP32[$91>>2] = $102;
   $103 = (($95) + ($102<<2)|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = (($95) + ($index$0$lcssa$i<<2)|0);
   HEAP32[$105>>2] = $104;
   $106 = (($shape) + 4|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = $107 & 251658240;
   $109 = ($108|0)==(16777216);
   if ($109) {
    $110 = $107 & 1073741823;
    $111 = $110 | -2147483648;
    HEAP32[$106>>2] = $111;
    HEAP32[$shape>>2] = $6;
   }
  }
 }
 if ((label|0) == 37) {
  $112 = $this;
  $113 = HEAP32[$2>>2]|0;
  $114 = $113 >>> 24;
  $115 = $114 & 15;
  $116 = ((444424 + ($115<<2)|0) + 24|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = (($117) + ($112))|0;
  $119 = $118;
  $120 = (($119) + 8|0);
  $121 = HEAP16[$120>>1]|0;
  $122 = $121 & 8;
  $123 = ($122<<16>>16)==(0);
  do {
   if ($123) {
    $124 = $wakeOnLostTouch&1;
    HEAP32[$0>>2] = $shape;
    $125 = (($0) + 4|0);
    HEAP8[$125>>0] = $124;
    $126 = (($66) + 80|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = $127 & 2147483647;
    $129 = (($66) + 76|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = ($128>>>0)>($130>>>0);
    if (!($131)) {
     $132 = (($66) + 36|0);
     (__ZN5physx6shdfnd5ArrayINS_3Scb12RemovedShapeENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($132,$0)|0);
     break;
    }
    $133 = (($66) + 72|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = (($134) + ($130<<3)|0);
    $136 = ($135|0)==(0|0);
    if ($136) {
     $148 = $130;
    } else {
     $137 = $0;
     $138 = $137;
     $139 = HEAP32[$138>>2]|0;
     $140 = (($137) + 4)|0;
     $141 = $140;
     $142 = HEAP32[$141>>2]|0;
     $143 = $135;
     $144 = $143;
     HEAP32[$144>>2] = $139;
     $145 = (($143) + 4)|0;
     $146 = $145;
     HEAP32[$146>>2] = $142;
     $$pre$i1 = HEAP32[$129>>2]|0;
     $148 = $$pre$i1;
    }
    $147 = (($148) + 1)|0;
    HEAP32[$129>>2] = $147;
   } else {
    if ($toBeReleased) {
     $149 = (($shape) + 4|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = $150 & 268435456;
     $152 = ($151|0)==(0);
     if ($152) {
      $155 = $113;
     } else {
      $153 = (($6) + 2448|0);
      __ZN5physx3Scb13ObjectTracker6removeERNS0_4BaseE($153,$shape);
      $$pre15 = HEAP32[$2>>2]|0;
      $155 = $$pre15;
     }
     $154 = $155 >>> 24;
     $156 = $154 & 15;
     $157 = ((444424 + ($156<<2)|0) + 24|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (($158) + ($112))|0;
     $160 = $159;
     (__ZNK5physx2Sc9RigidCore10getPxActorEv($160)|0);
     break;
    }
    HEAP32[$1>>2] = $shape;
    $161 = (($1) + 4|0);
    HEAP8[$161>>0] = 0;
    $162 = (($66) + 80|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = $163 & 2147483647;
    $165 = (($66) + 76|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = ($164>>>0)>($166>>>0);
    if (!($167)) {
     $168 = (($66) + 36|0);
     (__ZN5physx6shdfnd5ArrayINS_3Scb12RemovedShapeENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($168,$1)|0);
     break;
    }
    $169 = (($66) + 72|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = (($170) + ($166<<3)|0);
    $172 = ($171|0)==(0|0);
    if ($172) {
     $184 = $166;
    } else {
     $173 = $1;
     $174 = $173;
     $175 = HEAP32[$174>>2]|0;
     $176 = (($173) + 4)|0;
     $177 = $176;
     $178 = HEAP32[$177>>2]|0;
     $179 = $171;
     $180 = $179;
     HEAP32[$180>>2] = $175;
     $181 = (($179) + 4)|0;
     $182 = $181;
     HEAP32[$182>>2] = $178;
     $$pre$i = HEAP32[$165>>2]|0;
     $184 = $$pre$i;
    }
    $183 = (($184) + 1)|0;
    HEAP32[$165>>2] = $183;
   }
  } while(0);
  $185 = (($shape) + 4|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = $186 & 251658240;
  $188 = ($187|0)==(16777216);
  if ($188) {
   $189 = $186 | -1073741824;
   HEAP32[$185>>2] = $189;
   HEAP32[$shape>>2] = $6;
  }
 }
 $190 = HEAP32[$this>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($190,$this);
 $191 = HEAP32[$2>>2]|0;
 $192 = $191 | 8;
 HEAP32[$2>>2] = $192;
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager9detachAllEPNS_7NpSceneE($this,$scene) {
 $this = $this|0;
 $scene = $scene|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(1);
 if ($2) {
  $9 = $this;
 } else {
  $3 = HEAP32[$this>>2]|0;
  $9 = $3;
 }
 $4 = ($scene|0)==(0|0);
 if (!($4)) {
  $5 = (($scene) + 3376|0);
  __ZN5physx14NpShapeManager21teardownAllSceneQueryERNS_2Sq17SceneQueryManagerE($this,$5);
 }
 $6 = ($1<<16>>16)==(0);
 if ($6) {
  __ZN5physx2Cm8PtrTable5clearEv($this);
  $20 = (($this) + 8|0);
  __ZN5physx2Cm8PtrTable5clearEv($20);
  STACKTOP = sp;return;
 }
 $7 = $1&65535;
 $i$01 = 0;
 while(1) {
  $8 = (($9) + ($i$01<<2)|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = (__ZNK5physx7NpShape11isExclusiveEv($10)|0);
  if ($11) {
   __ZN5physx7NpShape8setActorEPNS_12PxRigidActorE($10,0);
  }
  $12 = (($10) + 12|0);
  $13 = (($10) + 16|0);
  $14 = (__ZN5physx6shdfnd15atomicDecrementEPVi($13)|0);
  $15 = ($14|0)==(0);
  if ($15) {
   $16 = HEAP32[$12>>2]|0;
   $17 = (($16) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vi[$18 & 4095]($12);
  }
  $19 = (($i$01) + 1)|0;
  $exitcond = ($19|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $19;
  }
 }
 __ZN5physx2Cm8PtrTable5clearEv($this);
 $20 = (($this) + 8|0);
 __ZN5physx2Cm8PtrTable5clearEv($20);
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager21teardownAllSceneQueryERNS_2Sq17SceneQueryManagerE($this,$sqManager) {
 $this = $this|0;
 $sqManager = $sqManager|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cp$0$i = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(1);
 if ($3) {
  $16 = $this;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $16 = $4;
 }
 $5 = $2&65535;
 $6 = (($this) + 8|0);
 $7 = (($this) + 12|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = ($8<<16>>16)==(1);
 if ($9) {
  $42 = $6;
 } else {
  $10 = HEAP32[$6>>2]|0;
  $42 = $10;
 }
 $11 = ($2<<16>>16)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($5) + -1)|0;
 $i$01 = 0;
 while(1) {
  $13 = ($i$01>>>0)<($12>>>0);
  if ($13) {
   $14 = (($i$01) + 1)|0;
   $15 = (($16) + ($14<<2)|0);
   $17 = HEAP32[$15>>2]|0;
   $18 = $17;
   $19 = (_bitshift64Lshr(($18|0),0,6)|0);
   $20 = tempRet0;
   $21 = (_i64Add(($18|0),0,207,0)|0);
   $22 = tempRet0;
   $23 = (_bitshift64Lshr(($21|0),($22|0),6)|0);
   $24 = tempRet0;
   $25 = (_i64Subtract(1,0,($19|0),($20|0))|0);
   $26 = tempRet0;
   $27 = (_i64Add(($25|0),($26|0),($23|0),($24|0))|0);
   $28 = tempRet0;
   $30 = $27;$31 = $28;$cp$0$i = $17;
   while(1) {
    $29 = (($cp$0$i) + 64|0);
    $32 = (_i64Add(($30|0),($31|0),-1,-1)|0);
    $33 = tempRet0;
    $34 = ($32|0)==(0);
    $35 = ($33|0)==(0);
    $36 = $34 & $35;
    if ($36) {
     break;
    } else {
     $30 = $32;$31 = $33;$cp$0$i = $29;
    }
   }
  }
  $37 = (($16) + ($i$01<<2)|0);
  $38 = HEAP32[$37>>2]|0;
  __ZNK5physx7NpShape8getFlagsEv($0,$38);
  $39 = HEAP8[$0>>0]|0;
  $40 = $39 & 2;
  $41 = ($40<<24>>24)==(0);
  $$pre = (($42) + ($i$01<<2)|0);
  if (!($41)) {
   $43 = HEAP32[$$pre>>2]|0;
   __ZN5physx2Sq17SceneQueryManager11removeShapeEPNS0_10ActorShapeE($sqManager,$43);
  }
  HEAP32[$$pre>>2] = 0;
  $44 = (($i$01) + 1)|0;
  $exitcond = ($44|0)==($5|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $44;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx14NpShapeManager9getShapesEPPNS_7PxShapeEjj($this,$buffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $buffer = $buffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ($1<<16>>16)==(1);
 if ($3) {
  $6 = $this;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $6 = $4;
 }
 $5 = (($6) + ($startIndex<<2)|0);
 $7 = (($2) - ($startIndex))|0;
 $8 = ($7|0)<(0);
 $9 = $8 ? 0 : $7;
 $10 = ($9>>>0)<($bufferSize>>>0);
 $11 = $10 ? $9 : $bufferSize;
 $12 = $11 << 2;
 _memcpy(($buffer|0),($5|0),($12|0))|0;
 STACKTOP = sp;return ($11|0);
}
function __ZNK5physx14NpShapeManager14getWorldBoundsERKNS_12PxRigidActorE($agg$result,$this,$actor) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $actor = $actor|0;
 var $$0$i$i$in = 0, $$in = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $actorPose = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $actorPose = sp + 52|0;
 $0 = sp;
 $1 = sp + 24|0;
 HEAPF32[$agg$result>>2] = Math_fround(8.50705866596322149529E+37);
 $2 = (($agg$result) + 4|0);
 HEAPF32[$2>>2] = Math_fround(8.50705866596322149529E+37);
 $3 = (($agg$result) + 8|0);
 HEAPF32[$3>>2] = Math_fround(8.50705866596322149529E+37);
 $4 = (($agg$result) + 12|0);
 HEAPF32[$4>>2] = Math_fround(-8.50705866596322149529E+37);
 $5 = (($agg$result) + 16|0);
 HEAPF32[$5>>2] = Math_fround(-8.50705866596322149529E+37);
 $6 = (($agg$result) + 20|0);
 HEAPF32[$6>>2] = Math_fround(-8.50705866596322149529E+37);
 $7 = (($this) + 4|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = HEAP32[$actor>>2]|0;
 $10 = (($9) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095]($actorPose,$actor);
 $12 = HEAP16[$7>>1]|0;
 $13 = ($12<<16>>16)==(1);
 if ($13) {
  $35 = $this;
 } else {
  $14 = HEAP32[$this>>2]|0;
  $35 = $14;
 }
 $15 = ($8<<16>>16)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($actorPose) + 12|0);
 $17 = (($actorPose) + 4|0);
 $18 = (($actorPose) + 8|0);
 $19 = (($actorPose) + 16|0);
 $20 = (($actorPose) + 20|0);
 $21 = (($actorPose) + 24|0);
 $22 = (($1) + 4|0);
 $23 = (($1) + 8|0);
 $24 = (($1) + 12|0);
 $25 = (($1) + 16|0);
 $26 = (($1) + 20|0);
 $27 = (($1) + 24|0);
 $28 = (($0) + 4|0);
 $29 = (($0) + 8|0);
 $30 = (($0) + 12|0);
 $31 = (($0) + 16|0);
 $32 = (($0) + 20|0);
 $33 = $8&65535;
 $152 = Math_fround(8.50705866596322149529E+37);$i$01 = 0;
 while(1) {
  $34 = (($35) + ($i$01<<2)|0);
  $36 = HEAP32[$34>>2]|0;
  $37 = (($36) + 36|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38 & 1;
  $40 = ($39|0)==(0);
  if ($40) {
   $49 = (($36) + 116|0);
   $$0$i$i$in = $49;$51 = $38;$54 = $36;
  } else {
   $41 = (($36) + 40|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    $44 = (($36) + 32|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = $38 >>> 24;
    $47 = $46 & 15;
    $48 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($45,$47)|0);
    HEAP32[$41>>2] = $48;
    $$pre = HEAP32[$34>>2]|0;
    $$phi$trans$insert = (($$pre) + 36|0);
    $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
    $$0$i$i$in = $48;$51 = $$pre3;$54 = $$pre;
   } else {
    $$0$i$i$in = $42;$51 = $38;$54 = $36;
   }
  }
  $50 = $51 & 4;
  $52 = ($50|0)==(0);
  if ($52) {
   $64 = (($54) + 80|0);
   $$in = $64;
  } else {
   $53 = (($54) + 40|0);
   $55 = HEAP32[$53>>2]|0;
   $56 = ($55|0)==(0|0);
   if ($56) {
    $57 = (($54) + 32|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = $51 >>> 24;
    $60 = $59 & 15;
    $61 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($58,$60)|0);
    HEAP32[$53>>2] = $61;
    $63 = $61;
   } else {
    $63 = $55;
   }
   $62 = (($63) + 64|0);
   $$in = $62;
  }
  $65 = (($$in) + 16|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($66 * Math_fround(2.0));
  $68 = (($$in) + 20|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($69 * Math_fround(2.0));
  $71 = (($$in) + 24|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($72 * Math_fround(2.0));
  $74 = Math_fround(HEAPF32[$16>>2]);
  $75 = Math_fround($74 * $74);
  $76 = Math_fround($75 + Math_fround(-0.5));
  $77 = Math_fround(HEAPF32[$actorPose>>2]);
  $78 = Math_fround($67 * $77);
  $79 = Math_fround(HEAPF32[$17>>2]);
  $80 = Math_fround($70 * $79);
  $81 = Math_fround($78 + $80);
  $82 = Math_fround(HEAPF32[$18>>2]);
  $83 = Math_fround($73 * $82);
  $84 = Math_fround($81 + $83);
  $85 = Math_fround($67 * $76);
  $86 = Math_fround($73 * $79);
  $87 = Math_fround($70 * $82);
  $88 = Math_fround($86 - $87);
  $89 = Math_fround($74 * $88);
  $90 = Math_fround($85 + $89);
  $91 = Math_fround($77 * $84);
  $92 = Math_fround($91 + $90);
  $93 = Math_fround($70 * $76);
  $94 = Math_fround($67 * $82);
  $95 = Math_fround($73 * $77);
  $96 = Math_fround($94 - $95);
  $97 = Math_fround($74 * $96);
  $98 = Math_fround($93 + $97);
  $99 = Math_fround($79 * $84);
  $100 = Math_fround($99 + $98);
  $101 = Math_fround($73 * $76);
  $102 = Math_fround($70 * $77);
  $103 = Math_fround($67 * $79);
  $104 = Math_fround($102 - $103);
  $105 = Math_fround($74 * $104);
  $106 = Math_fround($101 + $105);
  $107 = Math_fround($82 * $84);
  $108 = Math_fround($106 + $107);
  $109 = Math_fround(HEAPF32[$19>>2]);
  $110 = Math_fround($109 + $92);
  $111 = Math_fround(HEAPF32[$20>>2]);
  $112 = Math_fround($111 + $100);
  $113 = Math_fround(HEAPF32[$21>>2]);
  $114 = Math_fround($113 + $108);
  $115 = Math_fround(HEAPF32[$$in>>2]);
  $116 = Math_fround($74 * $115);
  $117 = (($$in) + 12|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = Math_fround($77 * $118);
  $120 = Math_fround($116 + $119);
  $121 = (($$in) + 8|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround($79 * $122);
  $124 = Math_fround($120 + $123);
  $125 = (($$in) + 4|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = Math_fround($82 * $126);
  $128 = Math_fround($124 - $127);
  $129 = Math_fround($74 * $126);
  $130 = Math_fround($79 * $118);
  $131 = Math_fround($130 + $129);
  $132 = Math_fround($82 * $115);
  $133 = Math_fround($132 + $131);
  $134 = Math_fround($77 * $122);
  $135 = Math_fround($133 - $134);
  $136 = Math_fround($74 * $122);
  $137 = Math_fround($82 * $118);
  $138 = Math_fround($137 + $136);
  $139 = Math_fround($77 * $126);
  $140 = Math_fround($139 + $138);
  $141 = Math_fround($79 * $115);
  $142 = Math_fround($140 - $141);
  $143 = Math_fround($74 * $118);
  $144 = Math_fround($77 * $115);
  $145 = Math_fround($143 - $144);
  $146 = Math_fround($79 * $126);
  $147 = Math_fround($145 - $146);
  $148 = Math_fround($82 * $122);
  $149 = Math_fround($147 - $148);
  HEAPF32[$1>>2] = $128;
  HEAPF32[$22>>2] = $135;
  HEAPF32[$23>>2] = $142;
  HEAPF32[$24>>2] = $149;
  HEAPF32[$25>>2] = $110;
  HEAPF32[$26>>2] = $112;
  HEAPF32[$27>>2] = $114;
  __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($$0$i$i$in,$0,$1,Math_fround(0.0),0);
  $150 = Math_fround(HEAPF32[$0>>2]);
  $151 = $152 < $150;
  $153 = $151 ? $152 : $150;
  $154 = Math_fround(HEAPF32[$2>>2]);
  $155 = Math_fround(HEAPF32[$28>>2]);
  $156 = $154 < $155;
  $157 = $156 ? $154 : $155;
  $158 = Math_fround(HEAPF32[$3>>2]);
  $159 = Math_fround(HEAPF32[$29>>2]);
  $160 = $158 < $159;
  $161 = $160 ? $158 : $159;
  HEAPF32[$2>>2] = $157;
  HEAPF32[$3>>2] = $161;
  $162 = Math_fround(HEAPF32[$4>>2]);
  $163 = Math_fround(HEAPF32[$30>>2]);
  $164 = $162 > $163;
  $165 = $164 ? $162 : $163;
  $166 = Math_fround(HEAPF32[$5>>2]);
  $167 = Math_fround(HEAPF32[$31>>2]);
  $168 = $166 > $167;
  $169 = $168 ? $166 : $167;
  $170 = Math_fround(HEAPF32[$6>>2]);
  $171 = Math_fround(HEAPF32[$32>>2]);
  $172 = $170 > $171;
  $173 = $172 ? $170 : $171;
  HEAPF32[$4>>2] = $165;
  HEAPF32[$5>>2] = $169;
  HEAPF32[$6>>2] = $173;
  $174 = (($i$01) + 1)|0;
  $exitcond = ($174|0)==($33|0);
  if ($exitcond) {
   break;
  } else {
   $152 = $153;$i$01 = $174;
  }
 }
 HEAPF32[$agg$result>>2] = $153;
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager20clearShapesOnReleaseERNS_3Scb5SceneERNS_12PxRigidActorE($this,$s,$r) {
 $this = $this|0;
 $s = $s|0;
 $r = $r|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(1);
 if ($2) {
  $8 = $this;
 } else {
  $3 = HEAP32[$this>>2]|0;
  $4 = ($1<<16>>16)==(0);
  if ($4) {
   STACKTOP = sp;return;
  } else {
   $8 = $3;
  }
 }
 $5 = (($s) + 2448|0);
 $6 = $1&65535;
 $i$01 = 0;
 while(1) {
  $7 = (($8) + ($i$01<<2)|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 32|0);
  $11 = (($9) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 & 268435456;
  $14 = ($13|0)==(0);
  if (!($14)) {
   __ZN5physx3Scb13ObjectTracker6removeERNS0_4BaseE($5,$10);
  }
  $15 = (($i$01) + 1)|0;
  $exitcond = ($15|0)==($6|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager15setupSceneQueryERNS_2Sq17SceneQueryManagerERKNS_12PxRigidActorERKNS_7NpShapeE($this,$sqManager,$actor,$shape) {
 $this = $this|0;
 $sqManager = $sqManager|0;
 $actor = $actor|0;
 $shape = $shape|0;
 var $$$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Cm8PtrTable4findEPKv($this,$shape)|0);
 $1 = (($actor) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(5);
 $4 = ($2<<16>>16)==(15);
 $$$i = $3 | $4;
 $5 = (($this) + 4|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = ($6<<16>>16)==(1);
 if ($7) {
  $10 = $this;
 } else {
  $8 = HEAP32[$this>>2]|0;
  $10 = $8;
 }
 $9 = (($10) + ($0<<2)|0);
 $11 = HEAP32[$9>>2]|0;
 $12 = (__ZN5physx2Sq17SceneQueryManager8addShapeERKNS_7NpShapeERKNS_12PxRigidActorEbPNS_9PxBounds3E($sqManager,$11,$actor,$$$i,0)|0);
 $13 = (($this) + 8|0);
 $14 = (($this) + 12|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = ($15<<16>>16)==(1);
 if ($16) {
  $19 = $13;
  $18 = (($19) + ($0<<2)|0);
  HEAP32[$18>>2] = $12;
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$13>>2]|0;
  $19 = $17;
  $18 = (($19) + ($0<<2)|0);
  HEAP32[$18>>2] = $12;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpShapeManager18teardownSceneQueryERNS_2Sq17SceneQueryManagerERKNS_7NpShapeE($this,$sqManager,$shape) {
 $this = $this|0;
 $sqManager = $sqManager|0;
 $shape = $shape|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Cm8PtrTable4findEPKv($this,$shape)|0);
 $1 = (($this) + 8|0);
 $2 = (($this) + 12|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(1);
 if ($4) {
  $7 = $1;
 } else {
  $5 = HEAP32[$1>>2]|0;
  $7 = $5;
 }
 $6 = (($7) + ($0<<2)|0);
 $8 = HEAP32[$6>>2]|0;
 __ZN5physx2Sq17SceneQueryManager11removeShapeEPNS0_10ActorShapeE($sqManager,$8);
 $9 = HEAP16[$2>>1]|0;
 $10 = ($9<<16>>16)==(1);
 if ($10) {
  $13 = $1;
  $12 = (($13) + ($0<<2)|0);
  HEAP32[$12>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $11 = HEAP32[$1>>2]|0;
  $13 = $11;
  $12 = (($13) + ($0<<2)|0);
  HEAP32[$12>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14NpShapeManager18setupAllSceneQueryERKNS_12PxRigidActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $$ = 0, $$2 = 0, $$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($actor)|0);
 $2 = (($1) + 3376|0);
 $3 = (($this) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(1);
 if ($5) {
  $6 = (($actor) + 4|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = ($7<<16>>16)==(5);
  $9 = ($7<<16>>16)==(15);
  $$2 = $8 | $9;
  $$3 = $$2;$20 = $this;
 } else {
  $10 = HEAP32[$this>>2]|0;
  $11 = (($actor) + 4|0);
  $12 = HEAP16[$11>>1]|0;
  $13 = ($12<<16>>16)==(5);
  $14 = ($12<<16>>16)==(15);
  $$ = $13 | $14;
  $15 = ($4<<16>>16)==(0);
  if ($15) {
   STACKTOP = sp;return;
  } else {
   $$3 = $$;$20 = $10;
  }
 }
 $16 = (($this) + 8|0);
 $17 = (($this) + 12|0);
 $18 = $4&65535;
 $i$01 = 0;
 while(1) {
  $19 = (($20) + ($i$01<<2)|0);
  $21 = HEAP32[$19>>2]|0;
  __ZNK5physx7NpShape8getFlagsEv($0,$21);
  $22 = HEAP8[$0>>0]|0;
  $23 = $22 & 2;
  $24 = ($23<<24>>24)==(0);
  if (!($24)) {
   $25 = HEAP32[$19>>2]|0;
   $26 = (__ZN5physx2Sq17SceneQueryManager8addShapeERKNS_7NpShapeERKNS_12PxRigidActorEbPNS_9PxBounds3E($2,$25,$actor,$$3,0)|0);
   $27 = HEAP16[$17>>1]|0;
   $28 = ($27<<16>>16)==(1);
   if ($28) {
    $31 = $16;
   } else {
    $29 = HEAP32[$16>>2]|0;
    $31 = $29;
   }
   $30 = (($31) + ($i$01<<2)|0);
   HEAP32[$30>>2] = $26;
  }
  $32 = (($i$01) + 1)|0;
  $exitcond = ($32|0)==($18|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager26markAllSceneQueryForUpdateERNS_2Sq17SceneQueryManagerE($this,$sqManager) {
 $this = $this|0;
 $sqManager = $sqManager|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($this) + 8|0);
 $3 = (($this) + 12|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(1);
 if ($5) {
  $10 = $2;
 } else {
  $6 = HEAP32[$2>>2]|0;
  $10 = $6;
 }
 $7 = ($1<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = $1&65535;
 $i$01 = 0;
 while(1) {
  $9 = (($10) + ($i$01<<2)|0);
  $11 = HEAP32[$9>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   __ZN5physx2Sq17SceneQueryManager13markForUpdateEPNS0_10ActorShapeE($sqManager,$11);
  }
  $13 = (($i$01) + 1)|0;
  $exitcond = ($13|0)==($8|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $13;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14NpShapeManager18findSceneQueryDataERKNS_7NpShapeE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Cm8PtrTable4findEPKv($this,$shape)|0);
 $1 = (($this) + 8|0);
 $2 = (($this) + 12|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(1);
 if ($4) {
  $7 = $1;
 } else {
  $5 = HEAP32[$1>>2]|0;
  $7 = $5;
 }
 $6 = (($7) + ($0<<2)|0);
 $8 = HEAP32[$6>>2]|0;
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx14NpShapeManager9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneERKNS_12PxRigidActorE($this,$out,$scene,$actor) {
 $this = $this|0;
 $out = $out|0;
 $scene = $scene|0;
 $actor = $actor|0;
 var $$0$i$i$in$us = 0, $$in = 0, $$in$us = 0, $$off0 = 0, $$off0$not = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0;
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $actorPose = 0, $exitcond = 0, $exitcond25 = 0, $i$07 = 0, $i$07$us = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $actorPose = sp + 172|0;
 $0 = sp;
 $1 = sp + 24|0;
 $2 = sp + 52|0;
 $3 = sp + 80|0;
 $4 = sp + 144|0;
 $5 = (($this) + 4|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = ($6<<16>>16)==(1);
 if ($7) {
  $44 = $this;
 } else {
  $8 = HEAP32[$this>>2]|0;
  $44 = $8;
 }
 $9 = HEAP32[$actor>>2]|0;
 $10 = (($9) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095]($actorPose,$actor);
 $12 = ($6&65535)>(1);
 if ($12) {
  $13 = HEAP32[$scene>>2]|0;
  $14 = (($13) + 296|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (Math_fround(FUNCTION_TABLE_fii[$15 & 63]($scene,15)));
  $17 = $16 != Math_fround(0.0);
  $$off0 = $17;
 } else {
  $$off0 = 0;
 }
 $18 = ($6<<16>>16)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($2) + 16|0);
 $20 = (($2) + 20|0);
 $21 = (($2) + 24|0);
 $22 = (($actorPose) + 12|0);
 $23 = (($actorPose) + 4|0);
 $24 = (($actorPose) + 8|0);
 $25 = (($actorPose) + 16|0);
 $26 = (($actorPose) + 20|0);
 $27 = (($actorPose) + 24|0);
 $28 = (($2) + 12|0);
 $29 = (($2) + 8|0);
 $30 = (($2) + 4|0);
 $31 = (($1) + 4|0);
 $32 = (($1) + 8|0);
 $33 = (($1) + 12|0);
 $34 = (($1) + 16|0);
 $35 = (($1) + 20|0);
 $36 = (($1) + 24|0);
 $37 = (($0) + 4|0);
 $38 = (($0) + 8|0);
 $39 = (($0) + 12|0);
 $40 = (($0) + 16|0);
 $41 = (($0) + 20|0);
 $42 = $6&65535;
 if ($$off0) {
  $167 = Math_fround(8.50705866596322149529E+37);$171 = Math_fround(8.50705866596322149529E+37);$175 = Math_fround(8.50705866596322149529E+37);$179 = Math_fround(-8.50705866596322149529E+37);$183 = Math_fround(-8.50705866596322149529E+37);$187 = Math_fround(-8.50705866596322149529E+37);$i$07$us = 0;
 } else {
  $i$07 = 0;
  while(1) {
   $190 = (($44) + ($i$07<<2)|0);
   $191 = HEAP32[$190>>2]|0;
   $192 = (($191) + 32|0);
   $193 = (($191) + 36|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = $194 & 64;
   $196 = ($195|0)==(0);
   if ($196) {
    $206 = (($191) + 112|0);
    $$in = $206;
   } else {
    $197 = (($191) + 40|0);
    $198 = HEAP32[$197>>2]|0;
    $199 = ($198|0)==(0|0);
    if ($199) {
     $200 = HEAP32[$192>>2]|0;
     $201 = $194 >>> 24;
     $202 = $201 & 15;
     $203 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($200,$202)|0);
     HEAP32[$197>>2] = $203;
     $205 = $203;
    } else {
     $205 = $198;
    }
    $204 = (($205) + 116|0);
    $$in = $204;
   }
   $207 = HEAP8[$$in>>0]|0;
   $208 = $207 & 8;
   $209 = ($208<<24>>24)==(0);
   if (!($209)) {
    $210 = HEAP32[$190>>2]|0;
    $211 = HEAP32[$210>>2]|0;
    $212 = (($211) + 164|0);
    $213 = HEAP32[$212>>2]|0;
    FUNCTION_TABLE_viii[$213 & 4095]($210,$out,$actor);
   }
   $214 = (($i$07) + 1)|0;
   $exitcond = ($214|0)==($42|0);
   if ($exitcond) {
    break;
   } else {
    $i$07 = $214;
   }
  }
  STACKTOP = sp;return;
 }
 while(1) {
  $43 = (($44) + ($i$07$us<<2)|0);
  $45 = HEAP32[$43>>2]|0;
  $46 = (($45) + 32|0);
  $47 = (($45) + 36|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = $48 & 64;
  $50 = ($49|0)==(0);
  if ($50) {
   $60 = (($45) + 112|0);
   $$in$us = $60;
  } else {
   $51 = (($45) + 40|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = $48 >>> 24;
    $56 = $55 & 15;
    $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
    HEAP32[$51>>2] = $57;
    $59 = $57;
   } else {
    $59 = $52;
   }
   $58 = (($59) + 116|0);
   $$in$us = $58;
  }
  $61 = HEAP8[$$in$us>>0]|0;
  $62 = $61 & 8;
  $63 = ($62<<24>>24)==(0);
  if ($63) {
   $216 = $167;$217 = $179;$227 = $171;$229 = $175;$232 = $183;$234 = $187;
  } else {
   $64 = HEAP32[$43>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 164|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_viii[$67 & 4095]($64,$out,$actor);
   $68 = HEAP32[$43>>2]|0;
   $69 = (($68) + 36|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = $70 & 1;
   $72 = ($71|0)==(0);
   if ($72) {
    $81 = (($68) + 116|0);
    $$0$i$i$in$us = $81;$83 = $68;
   } else {
    $73 = (($68) + 40|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)==(0|0);
    if ($75) {
     $76 = (($68) + 32|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = $70 >>> 24;
     $79 = $78 & 15;
     $80 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($77,$79)|0);
     HEAP32[$73>>2] = $80;
     $$pre = HEAP32[$43>>2]|0;
     $$0$i$i$in$us = $80;$83 = $$pre;
    } else {
     $$0$i$i$in$us = $74;$83 = $68;
    }
   }
   $82 = HEAP32[$83>>2]|0;
   $84 = (($82) + 72|0);
   $85 = HEAP32[$84>>2]|0;
   FUNCTION_TABLE_vii[$85 & 4095]($2,$83);
   $86 = Math_fround(HEAPF32[$19>>2]);
   $87 = Math_fround($86 * Math_fround(2.0));
   $88 = Math_fround(HEAPF32[$20>>2]);
   $89 = Math_fround($88 * Math_fround(2.0));
   $90 = Math_fround(HEAPF32[$21>>2]);
   $91 = Math_fround($90 * Math_fround(2.0));
   $92 = Math_fround(HEAPF32[$22>>2]);
   $93 = Math_fround($92 * $92);
   $94 = Math_fround($93 + Math_fround(-0.5));
   $95 = Math_fround(HEAPF32[$actorPose>>2]);
   $96 = Math_fround($87 * $95);
   $97 = Math_fround(HEAPF32[$23>>2]);
   $98 = Math_fround($89 * $97);
   $99 = Math_fround($96 + $98);
   $100 = Math_fround(HEAPF32[$24>>2]);
   $101 = Math_fround($91 * $100);
   $102 = Math_fround($99 + $101);
   $103 = Math_fround($87 * $94);
   $104 = Math_fround($91 * $97);
   $105 = Math_fround($89 * $100);
   $106 = Math_fround($104 - $105);
   $107 = Math_fround($92 * $106);
   $108 = Math_fround($103 + $107);
   $109 = Math_fround($95 * $102);
   $110 = Math_fround($109 + $108);
   $111 = Math_fround($89 * $94);
   $112 = Math_fround($87 * $100);
   $113 = Math_fround($91 * $95);
   $114 = Math_fround($112 - $113);
   $115 = Math_fround($92 * $114);
   $116 = Math_fround($111 + $115);
   $117 = Math_fround($97 * $102);
   $118 = Math_fround($117 + $116);
   $119 = Math_fround($91 * $94);
   $120 = Math_fround($89 * $95);
   $121 = Math_fround($87 * $97);
   $122 = Math_fround($120 - $121);
   $123 = Math_fround($92 * $122);
   $124 = Math_fround($119 + $123);
   $125 = Math_fround($100 * $102);
   $126 = Math_fround($124 + $125);
   $127 = Math_fround(HEAPF32[$25>>2]);
   $128 = Math_fround($127 + $110);
   $129 = Math_fround(HEAPF32[$26>>2]);
   $130 = Math_fround($129 + $118);
   $131 = Math_fround(HEAPF32[$27>>2]);
   $132 = Math_fround($131 + $126);
   $133 = Math_fround(HEAPF32[$2>>2]);
   $134 = Math_fround($92 * $133);
   $135 = Math_fround(HEAPF32[$28>>2]);
   $136 = Math_fround($95 * $135);
   $137 = Math_fround($134 + $136);
   $138 = Math_fround(HEAPF32[$29>>2]);
   $139 = Math_fround($97 * $138);
   $140 = Math_fround($137 + $139);
   $141 = Math_fround(HEAPF32[$30>>2]);
   $142 = Math_fround($100 * $141);
   $143 = Math_fround($140 - $142);
   $144 = Math_fround($92 * $141);
   $145 = Math_fround($97 * $135);
   $146 = Math_fround($145 + $144);
   $147 = Math_fround($100 * $133);
   $148 = Math_fround($147 + $146);
   $149 = Math_fround($95 * $138);
   $150 = Math_fround($148 - $149);
   $151 = Math_fround($92 * $138);
   $152 = Math_fround($100 * $135);
   $153 = Math_fround($152 + $151);
   $154 = Math_fround($95 * $141);
   $155 = Math_fround($154 + $153);
   $156 = Math_fround($97 * $133);
   $157 = Math_fround($155 - $156);
   $158 = Math_fround($92 * $135);
   $159 = Math_fround($95 * $133);
   $160 = Math_fround($158 - $159);
   $161 = Math_fround($97 * $141);
   $162 = Math_fround($160 - $161);
   $163 = Math_fround($100 * $138);
   $164 = Math_fround($162 - $163);
   HEAPF32[$1>>2] = $143;
   HEAPF32[$31>>2] = $150;
   HEAPF32[$32>>2] = $157;
   HEAPF32[$33>>2] = $164;
   HEAPF32[$34>>2] = $128;
   HEAPF32[$35>>2] = $130;
   HEAPF32[$36>>2] = $132;
   __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($$0$i$i$in$us,$0,$1,Math_fround(0.0),0);
   $165 = Math_fround(HEAPF32[$0>>2]);
   $166 = $167 < $165;
   $168 = $166 ? $167 : $165;
   $169 = Math_fround(HEAPF32[$37>>2]);
   $170 = $171 < $169;
   $172 = $170 ? $171 : $169;
   $173 = Math_fround(HEAPF32[$38>>2]);
   $174 = $175 < $173;
   $176 = $174 ? $175 : $173;
   $177 = Math_fround(HEAPF32[$39>>2]);
   $178 = $179 > $177;
   $180 = $178 ? $179 : $177;
   $181 = Math_fround(HEAPF32[$40>>2]);
   $182 = $183 > $181;
   $184 = $182 ? $183 : $181;
   $185 = Math_fround(HEAPF32[$41>>2]);
   $186 = $187 > $185;
   $188 = $186 ? $187 : $185;
   $216 = $168;$217 = $180;$227 = $172;$229 = $176;$232 = $184;$234 = $188;
  }
  $189 = (($i$07$us) + 1)|0;
  $exitcond25 = ($189|0)==($42|0);
  if ($exitcond25) {
   break;
  } else {
   $167 = $216;$171 = $227;$175 = $229;$179 = $217;$183 = $232;$187 = $234;$i$07$us = $189;
  }
 }
 $$off0$not = $$off0 ^ 1;
 $215 = $216 > $217;
 $or$cond = $215 | $$off0$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $218 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $219 = (($3) + 4|0);
 $220 = (($3) + 20|0);
 ;HEAP32[$219+0>>2]=0|0;HEAP32[$219+4>>2]=0|0;HEAP32[$219+8>>2]=0|0;HEAP32[$219+12>>2]=0|0;
 HEAPF32[$220>>2] = Math_fround(1.0);
 $221 = (($3) + 24|0);
 $222 = (($3) + 40|0);
 ;HEAP32[$221+0>>2]=0|0;HEAP32[$221+4>>2]=0|0;HEAP32[$221+8>>2]=0|0;HEAP32[$221+12>>2]=0|0;
 HEAPF32[$222>>2] = Math_fround(1.0);
 $223 = (($3) + 44|0);
 $224 = (($3) + 60|0);
 ;HEAP32[$223+0>>2]=0|0;HEAP32[$223+4>>2]=0|0;HEAP32[$223+8>>2]=0|0;HEAP32[$223+12>>2]=0|0;
 HEAPF32[$224>>2] = Math_fround(1.0);
 $225 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($218,$3)|0);
 HEAPF32[$4>>2] = $216;
 $226 = (($4) + 4|0);
 HEAPF32[$226>>2] = $227;
 $228 = (($4) + 8|0);
 HEAPF32[$228>>2] = $229;
 $230 = (($4) + 12|0);
 HEAPF32[$230>>2] = $217;
 $231 = (($4) + 16|0);
 HEAPF32[$231>>2] = $232;
 $233 = (($4) + 20|0);
 HEAPF32[$233>>2] = $234;
 $235 = (($4) + 24|0);
 HEAP8[$235>>0] = 1;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($225,$4)|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_3Scb12RemovedShapeENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = (($this) + 32|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(33);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 439064 : 439032;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,438952,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<3)|0);
 $26 = (($this) + 36|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = $$03$i;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = $$012$i;
    $37 = $36;
    HEAP32[$37>>2] = $32;
    $38 = (($36) + 4)|0;
    $39 = $38;
    HEAP32[$39>>2] = $35;
   }
   $40 = (($$012$i) + 8|0);
   $41 = (($$03$i) + 8|0);
   $42 = ($40>>>0)<($24>>>0);
   if ($42) {
    $$012$i = $40;$$03$i = $41;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$22>>2]|0;
  $44 = $$pre;
 } else {
  $44 = $23;
 }
 $43 = (($25) + ($44<<3)|0);
 $45 = ($43|0)==(0|0);
 if (!($45)) {
  $46 = $a;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) + 4)|0;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = $43;
  $53 = $52;
  HEAP32[$53>>2] = $48;
  $54 = (($52) + 4)|0;
  $55 = $54;
  HEAP32[$55>>2] = $51;
 }
 $56 = HEAP32[$0>>2]|0;
 $57 = ($56|0)>(-1);
 do {
  if ($57) {
   $58 = HEAP32[$26>>2]|0;
   $59 = ($this|0)==($58|0);
   if ($59) {
    $60 = (($this) + 32|0);
    HEAP8[$60>>0] = 0;
    break;
   }
   $61 = ($58|0)==(0|0);
   if (!($61)) {
    $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($63) + 12|0);
    $65 = HEAP32[$64>>2]|0;
    FUNCTION_TABLE_vii[$65 & 4095]($62,$58);
   }
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $66 = HEAP32[$22>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$22>>2] = $67;
 $68 = (($25) + ($66<<3)|0);
 STACKTOP = sp;return ($68|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS4_EEEEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 16|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(17);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 439192 : 439032;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,438952,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 20|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 16|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx13NpVolumeCacheC2EPNS_2Sq17SceneQueryManagerEjj($this,$sqm,$maxStaticShapes,$maxDynamicShapes) {
 $this = $this|0;
 $sqm = $sqm|0;
 $maxStaticShapes = $maxStaticShapes|0;
 $maxDynamicShapes = $maxDynamicShapes|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((439304 + 8|0));
 $0 = (($this) + 80|0);
 HEAP32[$0>>2] = $sqm;
 $1 = (($this) + 84|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 88|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 92|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 96|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 100|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 104|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = -1;
 $8 = (($this) + 72|0);
 HEAP32[$8>>2] = $maxStaticShapes;
 $9 = (($this) + 76|0);
 HEAP32[$9>>2] = $maxDynamicShapes;
 $10 = (($this) + 117|0);
 HEAP8[$10>>0] = 1;
 $11 = (($this) + 116|0);
 HEAP8[$11>>0] = 1;
 $12 = ($maxStaticShapes|0)==(0);
 if ($12) {
  $14 = 0;
 } else {
  __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE8recreateEj($1,$maxStaticShapes);
  $$phi$trans$insert = (($this) + 104|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $phitmp = $$pre & 2147483647;
  $14 = $phitmp;
 }
 $13 = ($14>>>0)<($maxDynamicShapes>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 96|0);
 __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE8recreateEj($15,$maxDynamicShapes);
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCacheD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$1$i = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((439304 + 8|0));
 $1 = (($this) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3|0)!=(0);
 $5 = ($2|0)>(-1);
 $or$cond$i$i$i = $4 & $5;
 if ($or$cond$i$i$i) {
  $6 = (($this) + 96|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vii[$12 & 4095]($9,$7);
  }
 }
 $13 = (($this) + 92|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 2147483647;
 $16 = ($15|0)!=(0);
 $17 = ($14|0)>(-1);
 $or$cond$i$i$1$i = $16 & $17;
 if (!($or$cond$i$i$1$i)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
  STACKTOP = sp;return;
 }
 $18 = (($this) + 84|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
  STACKTOP = sp;return;
 }
 $21 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_vii[$24 & 4095]($21,$19);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCacheD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((439304 + 8|0));
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 96|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 92|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i$1 = $15 & $16;
 if (!($or$cond$i$i$1)) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 84|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCache10invalidateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = -1;
 $1 = (($this) + 88|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 100|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 117|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 116|0);
 HEAP8[$4>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCache7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($1)|0);
 __ZN5physx7NpScene18releaseVolumeCacheEPNS_13NpVolumeCacheE($2,$this);
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCache17getNbCachedShapesEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 100|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5))|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx13NpVolumeCache7isValidEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 117|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $6 = (($this) + 80|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 108|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($9|0)==($11|0);
   if ($12) {
    $13 = (($7) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($this) + 112|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($14|0)==($16|0);
    $$0 = $17;
   } else {
    $$0 = 0;
   }
  } else {
   $$0 = 0;
  }
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13NpVolumeCache4fillERKNS_10PxGeometryERKNS_11PxTransformE($this,$cacheVolume,$pose) {
 $this = $this|0;
 $cacheVolume = $cacheVolume|0;
 $pose = $pose|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = Math_fround(HEAPF32[$pose>>2]);
 $1 = (($this) + 44|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($pose) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 48|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($pose) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 52|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($pose) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 56|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($pose) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 60|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($pose) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 64|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($pose) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 68|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($this) + 4|0);
 $21 = HEAP32[$cacheVolume>>2]|0;
 HEAP32[$20>>2] = $21;
 $22 = HEAP32[$cacheVolume>>2]|0;
 if ((($22|0) == 2)) {
  ;HEAP32[$20+0>>2]=HEAP32[$cacheVolume+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$cacheVolume+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$cacheVolume+8>>2]|0;
 } else if ((($22|0) == 0)) {
  $32 = $cacheVolume;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $20;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
 } else if ((($22|0) == 3)) {
  HEAP32[$20>>2] = 3;
  $23 = (($cacheVolume) + 4|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($this) + 8|0);
  HEAPF32[$25>>2] = $24;
  $26 = (($cacheVolume) + 8|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($this) + 12|0);
  HEAPF32[$28>>2] = $27;
  $29 = (($cacheVolume) + 12|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($this) + 16|0);
  HEAPF32[$31>>2] = $30;
 } else {
  HEAP32[$20>>2] = -1;
  $42 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($42,4,439376,152,439456,$vararg_buffer);
  $43 = (($this) + 117|0);
  HEAP8[$43>>0] = 1;
  $44 = (($this) + 116|0);
  HEAP8[$44>>0] = 1;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($this) + 117|0);
 HEAP8[$45>>0] = 1;
 $46 = (($this) + 116|0);
 HEAP8[$46>>0] = 1;
 $47 = (__ZN5physx13NpVolumeCache12fillInternalEjPKNS_12PxOverlapHitEi($this,0,0,0)|0);
 $48 = (__ZN5physx13NpVolumeCache12fillInternalEjPKNS_12PxOverlapHitEi($this,1,0,0)|0);
 $49 = ($47|0)<($48|0);
 $50 = $49 ? $48 : $47;
 $$0 = $50;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13NpVolumeCache12fillInternalEjPKNS_12PxOverlapHitEi($this,$isDynamic,$prefilledBuffer,$prefilledCount) {
 $this = $this|0;
 $isDynamic = $isDynamic|0;
 $prefilledBuffer = $prefilledBuffer|0;
 $prefilledCount = $prefilledCount|0;
 var $$1 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $as = 0, $exitcond = 0, $fd = 0, $hitBuffer$0 = 0, $hitBufferAlloca$0$off0 = 0, $iHit$02 = 0, $or$cond = 0, $or$cond1 = 0, $resultCount$0 = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer = sp + 8|0;
 $0 = sp + 74|0;
 $1 = sp + 64|0;
 $fd = sp + 44|0;
 $2 = sp + 72|0;
 $as = sp;
 $3 = sp + 73|0;
 $4 = ($prefilledBuffer|0)==(0|0);
 $5 = ((($this) + ($isDynamic<<2)|0) + 72|0);
 do {
  if ($4) {
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 1)|0;
   $8 = ($7>>>0)<(65);
   if ($8) {
    $9 = $7 << 4;
    $10 = STACKTOP; STACKTOP = STACKTOP + ((((1*$9)|0)+15)&-16)|0;;
    $hitBuffer$0 = $10;$hitBufferAlloca$0$off0 = 1;
    break;
   }
   $11 = $6 << 4;
   $12 = (($11) + 16)|0;
   $13 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$12,439376,188)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    $15 = ((($this) + ($isDynamic)|0) + 116|0);
    HEAP8[$15>>0] = 1;
    $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    $17 = HEAP32[$5>>2]|0;
    HEAP32[$vararg_buffer>>2] = $17;
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,16,439376,192,439520,$vararg_buffer);
    $$1 = 3;
    STACKTOP = sp;return ($$1|0);
   } else {
    $hitBuffer$0 = $13;$hitBufferAlloca$0$off0 = 0;
   }
  } else {
   $hitBuffer$0 = $prefilledBuffer;$hitBufferAlloca$0$off0 = 0;
  }
 } while(0);
 $18 = ((($this) + (($isDynamic*12)|0)|0) + 84|0);
 HEAP32[$1>>2] = 0;
 $19 = (($1) + 4|0);
 HEAP32[$19>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($18,0,$1);
 $20 = ($isDynamic|0)!=(0);
 $21 = $20 ? 2 : 1;
 ;HEAP32[$fd+0>>2]=0|0;HEAP32[$fd+4>>2]=0|0;HEAP32[$fd+8>>2]=0|0;HEAP32[$fd+12>>2]=0|0;
 $22 = (($fd) + 16|0);
 HEAP16[$22>>1] = $21;
 $23 = (($fd) + 18|0);
 HEAP8[$23>>0] = 0;
 $24 = HEAP32[$5>>2]|0;
 $25 = (($24) + 1)|0;
 $26 = (($vararg_buffer) + 4|0);
 HEAP32[$26>>2] = 0;
 $27 = (($vararg_buffer) + 8|0);
 HEAP32[$27>>2] = 0;
 $28 = (($vararg_buffer) + 12|0);
 HEAP32[$28>>2] = -1;
 $29 = (($vararg_buffer) + 20|0);
 HEAP8[$29>>0] = 0;
 $30 = (($vararg_buffer) + 24|0);
 HEAP32[$30>>2] = $hitBuffer$0;
 $31 = (($vararg_buffer) + 28|0);
 HEAP32[$31>>2] = $25;
 $32 = (($vararg_buffer) + 32|0);
 HEAP32[$32>>2] = 0;
 HEAP32[$vararg_buffer>>2] = ((404640 + 8|0));
 if ($4) {
  $33 = (($this) + 80|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($34)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 356|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($this) + 4|0);
  $40 = (($this) + 44|0);
  (FUNCTION_TABLE_iiiiiii[$38 & 255]($35,$39,$40,$vararg_buffer,$fd,0)|0);
  $41 = HEAP32[$32>>2]|0;
  $42 = HEAP8[$29>>0]|0;
  $43 = $42&255;
  $44 = (($43) + ($41))|0;
  $$pre = HEAP32[$5>>2]|0;
  $46 = $$pre;$resultCount$0 = $44;
 } else {
  $46 = $24;$resultCount$0 = $prefilledCount;
 }
 $45 = ($resultCount$0|0)>($46|0);
 if ($45) {
  $51 = ($hitBuffer$0|0)==($prefilledBuffer|0);
  $or$cond = $hitBufferAlloca$0$off0 | $51;
  if (!($or$cond)) {
   __ZN5physx6shdfnd13TempAllocator10deallocateEPv($2,$hitBuffer$0);
  }
  $52 = ((($this) + ($isDynamic)|0) + 116|0);
  HEAP8[$52>>0] = 1;
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $47 = ($resultCount$0|0)>(0);
 if ($47) {
  $48 = (($as) + 4|0);
  $49 = ((($this) + (($isDynamic*12)|0)|0) + 92|0);
  $50 = ((($this) + (($isDynamic*12)|0)|0) + 88|0);
  $iHit$02 = 0;
  while(1) {
   $53 = (($hitBuffer$0) + ($iHit$02<<4)|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$as>>2] = $54;
   $55 = ((($hitBuffer$0) + ($iHit$02<<4)|0) + 4|0);
   $56 = HEAP32[$55>>2]|0;
   HEAP32[$48>>2] = $56;
   $57 = HEAP32[$49>>2]|0;
   $58 = $57 & 2147483647;
   $59 = HEAP32[$50>>2]|0;
   $60 = ($58>>>0)>($59>>>0);
   if ($60) {
    $61 = HEAP32[$18>>2]|0;
    $62 = (($61) + ($59<<3)|0);
    $63 = ($62|0)==(0|0);
    if ($63) {
     $75 = $59;
    } else {
     $64 = $as;
     $65 = $64;
     $66 = HEAP32[$65>>2]|0;
     $67 = (($64) + 4)|0;
     $68 = $67;
     $69 = HEAP32[$68>>2]|0;
     $70 = $62;
     $71 = $70;
     HEAP32[$71>>2] = $66;
     $72 = (($70) + 4)|0;
     $73 = $72;
     HEAP32[$73>>2] = $69;
     $$pre$i = HEAP32[$50>>2]|0;
     $75 = $$pre$i;
    }
    $74 = (($75) + 1)|0;
    HEAP32[$50>>2] = $74;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($18,$as)|0);
   }
   $76 = (($iHit$02) + 1)|0;
   $exitcond = ($76|0)==($resultCount$0|0);
   if ($exitcond) {
    break;
   } else {
    $iHit$02 = $76;
   }
  }
 }
 $77 = (($this) + 80|0);
 $78 = HEAP32[$77>>2]|0;
 if ($20) {
  $79 = (($78) + 24|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($this) + 112|0);
  HEAP32[$81>>2] = $80;
 } else {
  $82 = (($78) + 20|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($this) + 108|0);
  HEAP32[$84>>2] = $83;
 }
 $85 = ((($this) + ($isDynamic)|0) + 116|0);
 HEAP8[$85>>0] = 0;
 $86 = ($hitBuffer$0|0)==($prefilledBuffer|0);
 $or$cond1 = $hitBufferAlloca$0$off0 | $86;
 if ($or$cond1) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($3,$hitBuffer$0);
 $$1 = 0;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<3)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<3)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = $a;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = $$01$i;
   $18 = $17;
   HEAP32[$18>>2] = $13;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = $16;
  }
  $21 = (($$01$i) + 8|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCache14getCacheVolumeERNS_16PxGeometryHolderERNS_11PxTransformE($this,$resultVolume,$resultPose) {
 $this = $this|0;
 $resultVolume = $resultVolume|0;
 $resultPose = $resultPose|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = Math_fround(0);
 var $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 dest=$resultVolume+0|0; src=$0+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (($this) + 44|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$resultPose>>2] = $2;
 $3 = (($this) + 48|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($resultPose) + 4|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($this) + 52|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($resultPose) + 8|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($this) + 56|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($resultPose) + 12|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($this) + 60|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($resultPose) + 16|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($this) + 64|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($resultPose) + 20|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($this) + 68|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($resultPose) + 24|0);
 HEAPF32[$20>>2] = $19;
 $21 = HEAP32[$this>>2]|0;
 $22 = (($21) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 4095]($this)|0);
 STACKTOP = sp;return ($24|0);
}
function __ZN5physx13NpVolumeCache7forEachERNS_13PxVolumeCache8IteratorE($this,$iter) {
 $this = $this|0;
 $iter = $iter|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $cacheSqCallback = 0, $fd = 0, $localBuffer$0 = 0, $localBuffer$0$1 = 0, $reportBuffer$0 = 0, $reportBuffer$0$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $fd = sp + 56|0;
 $0 = sp + 77|0;
 $cacheSqCallback = sp;
 $1 = sp + 76|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 80|0);
 $6 = (($this) + 112|0);
 $7 = (($fd) + 16|0);
 $8 = (($fd) + 18|0);
 $9 = (($cacheSqCallback) + 4|0);
 $10 = (($cacheSqCallback) + 8|0);
 $11 = (($cacheSqCallback) + 12|0);
 $12 = (($cacheSqCallback) + 20|0);
 $13 = (($cacheSqCallback) + 24|0);
 $14 = (($cacheSqCallback) + 28|0);
 $15 = (($cacheSqCallback) + 32|0);
 $16 = (($cacheSqCallback) + 36|0);
 $17 = (($cacheSqCallback) + 40|0);
 $18 = (($cacheSqCallback) + 44|0);
 $19 = (($cacheSqCallback) + 48|0);
 $20 = (($cacheSqCallback) + 52|0);
 $21 = (($this) + 44|0);
 $22 = (($this) + 116|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $25 = (($this) + 108|0);
  $26 = HEAP32[$5>>2]|0;
  $27 = (($26) + 20|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$25>>2]|0;
  $30 = ($28|0)==($29|0);
  if ($30) {
   $91 = 0;
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $31 = (($this) + 72|0);
  $32 = HEAP32[$31>>2]|0;
  ;HEAP32[$fd+0>>2]=0|0;HEAP32[$fd+4>>2]=0|0;HEAP32[$fd+8>>2]=0|0;HEAP32[$fd+12>>2]=0|0;
  HEAP16[$7>>1] = 1;
  HEAP8[$8>>0] = 0;
  $33 = (($32) + 1)|0;
  $34 = ($33>>>0)<(66);
  if ($34) {
   $35 = STACKTOP; STACKTOP = STACKTOP + 1568|0;;
   $36 = (($35) + 1040|0);
   $localBuffer$0 = $35;$reportBuffer$0 = $36;
  } else {
   $37 = ($33*24)|0;
   $38 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$37,439376,343)|0);
   $39 = (($38) + ($33<<4)|0);
   $localBuffer$0 = $38;$reportBuffer$0 = $39;
  }
  HEAP32[$9>>2] = 0;
  HEAP32[$10>>2] = 0;
  HEAP32[$11>>2] = -1;
  HEAP8[$12>>0] = 0;
  HEAP32[$13>>2] = $localBuffer$0;
  HEAP32[$14>>2] = $33;
  HEAP32[$15>>2] = 0;
  HEAP32[$cacheSqCallback>>2] = ((439936 + 8|0));
  HEAP32[$16>>2] = $this;
  HEAP32[$17>>2] = $iter;
  HEAP32[$18>>2] = 0;
  HEAP32[$19>>2] = $reportBuffer$0;
  HEAP8[$20>>0] = 0;
  $40 = HEAP32[$5>>2]|0;
  $41 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($40)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + 356|0);
  $44 = HEAP32[$43>>2]|0;
  (FUNCTION_TABLE_iiiiiii[$44 & 255]($41,$2,$21,$cacheSqCallback,$fd,0)|0);
  $45 = HEAP8[$20>>0]|0;
  $46 = ($32>>>0)>(64);
  if ($46) {
   __ZN5physx6shdfnd13TempAllocator10deallocateEPv($1,$localBuffer$0);
   $91 = $45;
  } else {
   $91 = $45;
  }
 }
 $47 = (($this) + 117|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  $69 = HEAP32[$5>>2]|0;
  $70 = (($69) + 24|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = HEAP32[$6>>2]|0;
  $73 = ($71|0)==($72|0);
  if ($73) {
   $58 = 0;
  } else {
   label = 18;
  }
 } else {
  label = 18;
 }
 if ((label|0) == 18) {
  $74 = (($this) + 76|0);
  $75 = HEAP32[$74>>2]|0;
  ;HEAP32[$fd+0>>2]=0|0;HEAP32[$fd+4>>2]=0|0;HEAP32[$fd+8>>2]=0|0;HEAP32[$fd+12>>2]=0|0;
  HEAP16[$7>>1] = 2;
  HEAP8[$8>>0] = 0;
  $76 = (($75) + 1)|0;
  $77 = ($76>>>0)<(66);
  if ($77) {
   $81 = STACKTOP; STACKTOP = STACKTOP + 1568|0;;
   $82 = (($81) + 1040|0);
   $localBuffer$0$1 = $81;$reportBuffer$0$1 = $82;
  } else {
   $78 = ($76*24)|0;
   $79 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$78,439376,343)|0);
   $80 = (($79) + ($76<<4)|0);
   $localBuffer$0$1 = $79;$reportBuffer$0$1 = $80;
  }
  HEAP32[$9>>2] = 0;
  HEAP32[$10>>2] = 0;
  HEAP32[$11>>2] = -1;
  HEAP8[$12>>0] = 0;
  HEAP32[$13>>2] = $localBuffer$0$1;
  HEAP32[$14>>2] = $76;
  HEAP32[$15>>2] = 0;
  HEAP32[$cacheSqCallback>>2] = ((439936 + 8|0));
  HEAP32[$16>>2] = $this;
  HEAP32[$17>>2] = $iter;
  HEAP32[$18>>2] = 1;
  HEAP32[$19>>2] = $reportBuffer$0$1;
  HEAP8[$20>>0] = 0;
  $83 = HEAP32[$5>>2]|0;
  $84 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($83)|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($85) + 356|0);
  $87 = HEAP32[$86>>2]|0;
  (FUNCTION_TABLE_iiiiiii[$87 & 255]($84,$2,$21,$cacheSqCallback,$fd,0)|0);
  $88 = HEAP8[$20>>0]|0;
  $89 = ($75>>>0)>(64);
  if ($89) {
   __ZN5physx6shdfnd13TempAllocator10deallocateEPv($1,$localBuffer$0$1);
   $58 = $88;
  } else {
   $58 = $88;
  }
 }
 $90 = ($91<<24>>24)==(0);
 if ($90) {
  $50 = (($this) + 88|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0);
  if (!($52)) {
   $53 = HEAP32[$iter>>2]|0;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($this) + 84|0);
   $56 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_viii[$54 & 4095]($iter,$51,$56);
  }
 }
 $57 = ($58<<24>>24)==(0);
 if ($57) {
  $59 = (($this) + 100|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(0);
  if (!($61)) {
   $62 = HEAP32[$iter>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = (($this) + 96|0);
   $65 = HEAP32[$64>>2]|0;
   FUNCTION_TABLE_viii[$63 & 4095]($iter,$60,$65);
  }
 }
 $66 = HEAP32[$iter>>2]|0;
 $67 = (($66) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vi[$68 & 4095]($iter);
 STACKTOP = sp;return;
}
function __ZN5physx23NpVolumeCacheSqCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCache20setMaxNbStaticShapesEj($this,$maxCount) {
 $this = $this|0;
 $maxCount = $maxCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>($maxCount>>>0);
 if ($3) {
  $4 = (($this) + 116|0);
  HEAP8[$4>>0] = 1;
  HEAP32[$1>>2] = 0;
 }
 $5 = (($this) + 72|0);
 HEAP32[$5>>2] = $maxCount;
 $6 = (($this) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($maxCount>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE8recreateEj($0,$maxCount);
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCache20getMaxNbStaticShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx13NpVolumeCache21setMaxNbDynamicShapesEj($this,$maxCount) {
 $this = $this|0;
 $maxCount = $maxCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = (($this) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>($maxCount>>>0);
 if ($3) {
  $4 = (($this) + 117|0);
  HEAP8[$4>>0] = 1;
  HEAP32[$1>>2] = 0;
 }
 $5 = (($this) + 76|0);
 HEAP32[$5>>2] = $maxCount;
 $6 = (($this) + 104|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($maxCount>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE8recreateEj($0,$maxCount);
 STACKTOP = sp;return;
}
function __ZN5physx13NpVolumeCache21getMaxNbDynamicShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpVolumeCache7raycastERKNS_6PxVec3ES3_fRNS_13PxHitCallbackINS_12PxRaycastHitEEENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackE($this,$origin,$unitDir,$distance,$hitCall,$hitFlags,$filterData,$filterCall) {
 $this = $this|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $hitCall = $hitCall|0;
 $hitFlags = $hitFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $input = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $input = sp;
 $0 = sp + 24|0;
 HEAP32[$input>>2] = $origin;
 $1 = (($input) + 4|0);
 HEAP32[$1>>2] = $unitDir;
 $2 = (($input) + 8|0);
 HEAPF32[$2>>2] = $distance;
 $3 = (($input) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($input) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($input) + 20|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = HEAP16[$hitFlags>>1]|0;
 HEAP16[$0>>1] = $6;
 $7 = (__ZNK5physx13NpVolumeCache10multiQueryINS_12PxRaycastHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$hitCall,$0,$filterData,$filterCall,Math_fround(0.0))|0);
 STACKTOP = sp;return ($7|0);
}
function __ZNK5physx13NpVolumeCache10multiQueryINS_12PxRaycastHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$hitCall,$hitFlags,$filterData,$filterCall,$inflation) {
 $this = $this|0;
 $input = $input|0;
 $hitCall = $hitCall|0;
 $hitFlags = $hitFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $inflation = Math_fround($inflation);
 var $$0$i$i = 0, $$7 = 0, $$8 = 0, $$hitType$0 = 0, $$lcssa30 = Math_fround(0), $$not = 0, $$phi$trans$insert = 0, $$pr = 0, $$pre = 0, $$pre54 = 0, $$pre55 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0;
 var $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0;
 var $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = 0;
 var $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0;
 var $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0;
 var $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $buf1 = 0, $cacheSize = 0, $exitcond$i = 0, $exitcond$i8 = 0, $filterFlags = 0, $globalPose = 0, $hitType$0 = 0;
 var $i$02$i = 0, $i$02$i4 = 0, $iCachedShape$033 = 0, $iSubHit$028 = 0, $isDynamic$037 = 0, $isDynamic1$036 = 0, $newCount$0$lcssa$i9 = 0, $newCount$01$i = 0, $newCount$01$i5 = 0, $newCount$1$i = 0, $newCount$1$i7 = 0, $or$cond = 0, $or$cond3 = 0, $phitmp = 0, $phitmp18 = 0, $phitmp56 = 0, $shapeHitType = 0, $subHits$0 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $0 = sp + 133|0;
 $filterFlags = sp + 130|0;
 $cacheSize = sp + 32|0;
 $1 = sp + 132|0;
 $shapeHitType = sp + 40|0;
 $globalPose = sp + 4|0;
 $buf1 = sp + 44|0;
 $2 = sp + 128|0;
 $3 = (($hitCall) + 68|0);
 HEAP8[$3>>0] = 0;
 $4 = (($hitCall) + 80|0);
 HEAP32[$4>>2] = 0;
 $5 = (($filterData) + 16|0);
 $6 = HEAP16[$5>>1]|0;
 HEAP16[$filterFlags>>1] = $6;
 $7 = (($this) + 80|0);
 $8 = (($this) + 108|0);
 $9 = (($this) + 112|0);
 $10 = $6&65535;
 $11 = (($this) + 4|0);
 $isDynamic$037 = 0;
 L1: while(1) {
  $12 = ((($this) + ($isDynamic$037)|0) + 116|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  do {
   if ($14) {
    $15 = ($isDynamic$037|0)==(0);
    $16 = HEAP32[$7>>2]|0;
    if (!($15)) {
     $17 = (($16) + 24|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = HEAP32[$9>>2]|0;
     $20 = ($18|0)==($19|0);
     if ($20) {
      break;
     } else {
      label = 7;
      break;
     }
    }
    $21 = (($16) + 20|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$8>>2]|0;
    $24 = ($22|0)==($23|0);
    if ($24) {
     $25 = (($isDynamic$037) + 1)|0;
     $isDynamic$037 = $25;
     continue L1;
    } else {
     label = 7;
    }
   } else {
    label = 7;
   }
  } while(0);
  if ((label|0) == 7) {
   label = 0;
   $26 = (($isDynamic$037) + 1)|0;
   $27 = $10 & $26;
   $28 = ($27|0)==(0);
   if (!($28)) {
    $29 = (__ZN5physx13NpVolumeCache12fillInternalEjPKNS_12PxOverlapHitEi($this,$isDynamic$037,0,0)|0);
    $30 = ($29|0)==(1);
    $$pre55 = HEAP32[$11>>2]|0;
    $phitmp56 = ($$pre55|0)==(-1);
    if ($30) {
     label = 10;
     break;
    }
    if ($phitmp56) {
     label = 11;
     break;
    }
   }
  }
  $47 = (($isDynamic$037) + 1)|0;
  $48 = ($47>>>0)<(2);
  if ($48) {
   $isDynamic$037 = $47;
  } else {
   label = 15;
   break;
  }
 }
 if ((label|0) == 10) {
  if ($phitmp56) {
   label = 11;
  }
 }
 else if ((label|0) == 15) {
  $49 = (($this) + 88|0);
  $50 = HEAP32[$49>>2]|0;
  HEAP32[$cacheSize>>2] = $50;
  $51 = (($cacheSize) + 4|0);
  $52 = (($this) + 100|0);
  $53 = HEAP32[$52>>2]|0;
  HEAP32[$51>>2] = $53;
  $54 = $50 | $53;
  $55 = ($54|0)==(0);
  if ($55) {
   $$8 = 0;
   STACKTOP = sp;return ($$8|0);
  }
  $56 = (($input) + 8|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = HEAP32[$7>>2]|0;
  $59 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($58)|0);
  $60 = (($this) + 72|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($this) + 76|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($61>>>0)<($63>>>0);
  $65 = $64 ? $63 : $61;
  $66 = ($65>>>0)<(128);
  $67 = $65 << 6;
  if ($66) {
   $68 = STACKTOP; STACKTOP = STACKTOP + ((((1*$67)|0)+15)&-16)|0;;
   $376 = 0;$subHits$0 = $68;
  } else {
   $69 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,$67,439376,632)|0);
   $376 = $69;$subHits$0 = $69;
  }
  $70 = HEAP16[$5>>1]|0;
  $71 = $70 & 32;
  $72 = ($71<<16>>16)!=(0);
  $73 = (($hitCall) + 76|0);
  $74 = (($input) + 4|0);
  $75 = ($filterCall|0)==(0|0);
  $76 = (($buf1) + 4|0);
  $77 = (($buf1) + 8|0);
  $78 = (($buf1) + 12|0);
  $79 = (($buf1) + 16|0);
  $80 = (($buf1) + 20|0);
  $81 = (($buf1) + 44|0);
  $82 = (($buf1) + 48|0);
  $83 = (($buf1) + 52|0);
  $84 = (($buf1) + 68|0);
  $85 = (($buf1) + 72|0);
  $86 = (($buf1) + 76|0);
  $87 = (($buf1) + 80|0);
  $88 = (($hitCall) + 4|0);
  $89 = (($buf1) + 4|0);
  $90 = (($hitCall) + 16|0);
  $91 = (($hitCall) + 20|0);
  $92 = (($buf1) + 24|0);
  $93 = (($hitCall) + 24|0);
  $94 = (($buf1) + 28|0);
  $95 = (($hitCall) + 28|0);
  $96 = (($buf1) + 32|0);
  $97 = (($hitCall) + 32|0);
  $98 = (($buf1) + 36|0);
  $99 = (($hitCall) + 36|0);
  $100 = (($buf1) + 40|0);
  $101 = (($hitCall) + 40|0);
  $102 = (($hitCall) + 44|0);
  $103 = (($hitCall) + 48|0);
  $104 = (($hitCall) + 72|0);
  $106 = $50;$377 = $57;$isDynamic1$036 = 0;
  L24: while(1) {
   $105 = ($106|0)==(0);
   if ($105) {
    $$lcssa30 = $377;
   } else {
    $107 = ((($this) + (($isDynamic1$036*12)|0)|0) + 84|0);
    $150 = $377;$iCachedShape$033 = 0;
    while(1) {
     $108 = HEAP32[$107>>2]|0;
     $109 = (($108) + ($iCachedShape$033<<3)|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = (($110) + 4|0);
     $112 = HEAP16[$111>>1]|0;
     $113 = ($112<<16>>16)==(5);
     if ($113) {
      $phitmp = ($110|0)!=(0|0);
      $phitmp18 = $phitmp ? 2 : 1;
      $117 = $phitmp18;
     } else {
      $117 = 1;
     }
     $114 = HEAP16[$filterFlags>>1]|0;
     $115 = $114&65535;
     $116 = $115 & $117;
     $118 = ($116|0)==(0);
     if ($118) {
      $378 = $150;
     } else {
      $119 = HEAP32[$73>>2]|0;
      $120 = ($119|0)!=(0);
      $121 = $120 ? 1 : 2;
      HEAP32[$shapeHitType>>2] = $121;
      $122 = HEAP16[$hitFlags>>1]|0;
      $123 = (__ZN5physxL20applyAllPreFiltersVCEPNS_12PxActorShapeERNS_14PxQueryHitType4EnumERKNS_7PxFlagsINS_11PxQueryFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackERKNS_7NpSceneERNS5_INS_9PxHitFlag4EnumEtEE($109,$shapeHitType,$filterFlags,$filterData,$filterCall,$59,$hitFlags)|0);
      $124 = ($123|0)==(0|0);
      $125 = HEAP32[$shapeHitType>>2]|0;
      $126 = ($125|0)==(0);
      $or$cond = $124 | $126;
      if ($or$cond) {
       $378 = $150;
      } else {
       $127 = (($123) + 4|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = HEAP32[$123>>2]|0;
       __ZN5physx2Sq13getGlobalPoseERKNS_7NpShapeERKNS_12PxRigidActorE($globalPose,$128,$129);
       $130 = (($128) + 36|0);
       $131 = HEAP32[$130>>2]|0;
       $132 = $131 & 1;
       $133 = ($132|0)==(0);
       if ($133) {
        $142 = (($128) + 116|0);
        $$0$i$i = $142;
       } else {
        $134 = (($128) + 40|0);
        $135 = HEAP32[$134>>2]|0;
        $136 = ($135|0)==(0|0);
        if ($136) {
         $137 = (($128) + 32|0);
         $138 = HEAP32[$137>>2]|0;
         $139 = $131 >>> 24;
         $140 = $139 & 15;
         $141 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($138,$140)|0);
         HEAP32[$134>>2] = $141;
         $379 = $141;
        } else {
         $379 = $135;
        }
        $$0$i$i = $379;
       }
       $143 = HEAP32[$$0$i$i>>2]|0;
       $144 = ($143|0)==(5);
       if ($144) {
        $145 = HEAP16[$hitFlags>>1]|0;
        $146 = $145 & 32;
        $147 = ($146<<16>>16)==(0);
        if ($147) {
         $151 = 1;
        } else {
         label = 33;
        }
       } else {
        label = 33;
       }
       if ((label|0) == 33) {
        label = 0;
        $151 = $65;
       }
       $148 = HEAP32[$input>>2]|0;
       $149 = HEAP32[$74>>2]|0;
       HEAP16[$vararg_buffer>>1] = $122;
       $152 = (__ZN5physx15PxGeometryQuery7raycastERKNS_6PxVec3ES3_RKNS_10PxGeometryERKNS_11PxTransformEfNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEb($148,$149,$$0$i$i,$globalPose,$150,$vararg_buffer,$151,$subHits$0,0)|0);
       $153 = ($152|0)==(0);
       if ($153) {
        $378 = $150;
       } else {
        $154 = HEAP16[$filterFlags>>1]|0;
        $155 = $154 & 8;
        $156 = ($155<<16>>16)==(0);
        $211 = $150;$iSubHit$028 = 0;
        while(1) {
         $157 = (($subHits$0) + ($iSubHit$028<<6)|0);
         $158 = HEAP32[$123>>2]|0;
         HEAP32[$157>>2] = $158;
         $159 = HEAP32[$127>>2]|0;
         $160 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 4|0);
         HEAP32[$160>>2] = $159;
         $161 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 12|0);
         $162 = HEAP16[$161>>1]|0;
         $163 = $162 & 4;
         $164 = ($163<<16>>16)==(0);
         if ($164) {
          $165 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 40|0);
          HEAPF32[$165>>2] = Math_fround(0.0);
         }
         $166 = $162 & 1;
         $167 = ($166<<16>>16)==(0);
         if ($167) {
          $168 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 16|0);
          HEAPF32[$168>>2] = Math_fround(0.0);
          $169 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 20|0);
          HEAPF32[$169>>2] = Math_fround(0.0);
          $170 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 24|0);
          HEAPF32[$170>>2] = Math_fround(0.0);
         }
         $171 = $162 & 2;
         $172 = ($171<<16>>16)==(0);
         if ($172) {
          $173 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 28|0);
          HEAPF32[$173>>2] = Math_fround(0.0);
          $174 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 32|0);
          HEAPF32[$174>>2] = Math_fround(0.0);
          $175 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 36|0);
          HEAPF32[$175>>2] = Math_fround(0.0);
         }
         $176 = $162 & 8;
         $177 = ($176<<16>>16)==(0);
         if ($177) {
          $178 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 44|0);
          HEAPF32[$178>>2] = Math_fround(0.0);
          $179 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 48|0);
          HEAPF32[$179>>2] = Math_fround(0.0);
         }
         $brmerge = $75 | $156;
         if ($brmerge) {
          $hitType$0 = $125;
         } else {
          $180 = HEAP32[$filterCall>>2]|0;
          $181 = (($180) + 4|0);
          $182 = HEAP32[$181>>2]|0;
          $183 = (FUNCTION_TABLE_iiii[$182 & 2047]($filterCall,$filterData,$157)|0);
          $hitType$0 = $183;
         }
         $184 = HEAP16[$5>>1]|0;
         $185 = $184 & 16;
         $$not = ($185<<16>>16)==(0);
         $186 = ($hitType$0|0)==(0);
         $or$cond3 = $$not | $186;
         if (!($or$cond3)) {
          label = 47;
          break L24;
         }
         $$hitType$0 = $72 ? 1 : $hitType$0;
         do {
          if ((($$hitType$0|0) == 1)) {
           $206 = HEAP32[$73>>2]|0;
           $207 = ($206|0)==(0);
           if ($207) {
            $380 = $211;
            break;
           }
           $208 = (($157) + 40|0);
           $209 = Math_fround(HEAPF32[$208>>2]);
           $210 = !($209 <= $211);
           if ($210) {
            $380 = $211;
            break;
           }
           $212 = HEAP32[$4>>2]|0;
           $213 = ($212|0)==($206|0);
           do {
            if ($213) {
             HEAP32[$76>>2] = 0;
             HEAP32[$77>>2] = 0;
             HEAP32[$78>>2] = -1;
             HEAP16[$79>>1] = 0;
             ;HEAP32[$80+0>>2]=0|0;HEAP32[$80+4>>2]=0|0;HEAP32[$80+8>>2]=0|0;HEAP32[$80+12>>2]=0|0;HEAP32[$80+16>>2]=0|0;HEAP32[$80+20>>2]=0|0;
             HEAPF32[$81>>2] = Math_fround(3.40282346638528859812E+38);
             HEAPF32[$82>>2] = Math_fround(0.0);
             HEAPF32[$83>>2] = Math_fround(0.0);
             HEAP8[$84>>0] = 0;
             HEAP32[$85>>2] = 0;
             HEAP32[$86>>2] = 0;
             HEAP32[$87>>2] = 0;
             HEAP32[$buf1>>2] = ((404440 + 8|0));
             $214 = HEAP16[$hitFlags>>1]|0;
             HEAP16[$2>>1] = $214;
             $215 = (__ZNK5physx13NpVolumeCache10multiQueryINS_12PxRaycastHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$buf1,$2,$filterData,$filterCall,$inflation)|0);
             if ($215) {
              ;HEAP32[$88+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$89+8>>2]|0;
              $216 = HEAP16[$79>>1]|0;
              HEAP16[$90>>1] = $216;
              $217 = Math_fround(HEAPF32[$80>>2]);
              HEAPF32[$91>>2] = $217;
              $218 = Math_fround(HEAPF32[$92>>2]);
              HEAPF32[$93>>2] = $218;
              $219 = Math_fround(HEAPF32[$94>>2]);
              HEAPF32[$95>>2] = $219;
              $220 = Math_fround(HEAPF32[$96>>2]);
              HEAPF32[$97>>2] = $220;
              $221 = Math_fround(HEAPF32[$98>>2]);
              HEAPF32[$99>>2] = $221;
              $222 = Math_fround(HEAPF32[$100>>2]);
              HEAPF32[$101>>2] = $222;
              $223 = Math_fround(HEAPF32[$81>>2]);
              HEAPF32[$102>>2] = $223;
              ;HEAP32[$103+0>>2]=HEAP32[$82+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$82+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$82+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$82+12>>2]|0;HEAP32[$103+16>>2]=HEAP32[$82+16>>2]|0;
              HEAP8[$3>>0] = 1;
              $224 = HEAP32[$104>>2]|0;
              $225 = HEAP32[$4>>2]|0;
              $226 = ($225|0)==(0);
              if ($226) {
               $newCount$0$lcssa$i9 = 0;
              } else {
               $i$02$i4 = 0;$newCount$01$i5 = $225;
               while(1) {
                $227 = ((($224) + ($i$02$i4<<6)|0) + 40|0);
                $228 = Math_fround(HEAPF32[$227>>2]);
                $229 = $228 > $223;
                if ($229) {
                 $230 = ((($224) + ($i$02$i4<<6)|0) + 44|0);
                 $231 = (($224) + ($i$02$i4<<6)|0);
                 $232 = ((($224) + ($i$02$i4<<6)|0) + 36|0);
                 $233 = ((($224) + ($i$02$i4<<6)|0) + 32|0);
                 $234 = ((($224) + ($i$02$i4<<6)|0) + 28|0);
                 $235 = ((($224) + ($i$02$i4<<6)|0) + 24|0);
                 $236 = ((($224) + ($i$02$i4<<6)|0) + 20|0);
                 $237 = ((($224) + ($i$02$i4<<6)|0) + 16|0);
                 $238 = ((($224) + ($i$02$i4<<6)|0) + 12|0);
                 $239 = (($newCount$01$i5) + -1)|0;
                 $240 = (($224) + ($239<<6)|0);
                 $241 = ((($224) + ($239<<6)|0) + 12|0);
                 $242 = HEAP16[$241>>1]|0;
                 $243 = ((($224) + ($239<<6)|0) + 16|0);
                 $244 = Math_fround(HEAPF32[$243>>2]);
                 $245 = ((($224) + ($239<<6)|0) + 20|0);
                 $246 = Math_fround(HEAPF32[$245>>2]);
                 $247 = ((($224) + ($239<<6)|0) + 24|0);
                 $248 = Math_fround(HEAPF32[$247>>2]);
                 $249 = ((($224) + ($239<<6)|0) + 28|0);
                 $250 = Math_fround(HEAPF32[$249>>2]);
                 $251 = ((($224) + ($239<<6)|0) + 32|0);
                 $252 = Math_fround(HEAPF32[$251>>2]);
                 $253 = ((($224) + ($239<<6)|0) + 36|0);
                 $254 = Math_fround(HEAPF32[$253>>2]);
                 $255 = ((($224) + ($239<<6)|0) + 40|0);
                 $256 = Math_fround(HEAPF32[$255>>2]);
                 $257 = ((($224) + ($239<<6)|0) + 44|0);
                 _memmove(($231|0),($240|0),12)|0;
                 HEAP16[$238>>1] = $242;
                 HEAPF32[$237>>2] = $244;
                 HEAPF32[$236>>2] = $246;
                 HEAPF32[$235>>2] = $248;
                 HEAPF32[$234>>2] = $250;
                 HEAPF32[$233>>2] = $252;
                 HEAPF32[$232>>2] = $254;
                 HEAPF32[$227>>2] = $256;
                 _memmove(($230|0),($257|0),20)|0;
                 $newCount$1$i7 = $239;
                } else {
                 $newCount$1$i7 = $newCount$01$i5;
                }
                $258 = (($i$02$i4) + 1)|0;
                $exitcond$i8 = ($258|0)==($225|0);
                if ($exitcond$i8) {
                 $newCount$0$lcssa$i9 = $newCount$1$i7;
                 break;
                } else {
                 $i$02$i4 = $258;$newCount$01$i5 = $newCount$1$i7;
                }
               }
              }
              HEAP32[$4>>2] = $newCount$0$lcssa$i9;
              $261 = $newCount$0$lcssa$i9;
             } else {
              $$pre54 = HEAP32[$4>>2]|0;
              $261 = $$pre54;
             }
             $259 = HEAP32[$73>>2]|0;
             $260 = ($261|0)==($259|0);
             if (!($260)) {
              $272 = $261;
              break;
             }
             $262 = HEAP32[$hitCall>>2]|0;
             $263 = HEAP32[$262>>2]|0;
             $264 = HEAP32[$104>>2]|0;
             $265 = (FUNCTION_TABLE_iiii[$263 & 2047]($hitCall,$264,$261)|0);
             if (!($265)) {
              label = 62;
              break L24;
             }
             HEAP32[$4>>2] = 0;
             $272 = 0;
            } else {
             $272 = $212;
            }
           } while(0);
           $271 = (($272) + 1)|0;
           HEAP32[$4>>2] = $271;
           $273 = HEAP32[$104>>2]|0;
           $274 = (($273) + ($272<<6)|0);
           ;HEAP32[$274+0>>2]=HEAP32[$157+0>>2]|0;HEAP32[$274+4>>2]=HEAP32[$157+4>>2]|0;HEAP32[$274+8>>2]=HEAP32[$157+8>>2]|0;
           $275 = HEAP16[$161>>1]|0;
           $276 = ((($273) + ($272<<6)|0) + 12|0);
           HEAP16[$276>>1] = $275;
           $277 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 16|0);
           $278 = Math_fround(HEAPF32[$277>>2]);
           $279 = ((($273) + ($272<<6)|0) + 16|0);
           HEAPF32[$279>>2] = $278;
           $280 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 20|0);
           $281 = Math_fround(HEAPF32[$280>>2]);
           $282 = ((($273) + ($272<<6)|0) + 20|0);
           HEAPF32[$282>>2] = $281;
           $283 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 24|0);
           $284 = Math_fround(HEAPF32[$283>>2]);
           $285 = ((($273) + ($272<<6)|0) + 24|0);
           HEAPF32[$285>>2] = $284;
           $286 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 28|0);
           $287 = Math_fround(HEAPF32[$286>>2]);
           $288 = ((($273) + ($272<<6)|0) + 28|0);
           HEAPF32[$288>>2] = $287;
           $289 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 32|0);
           $290 = Math_fround(HEAPF32[$289>>2]);
           $291 = ((($273) + ($272<<6)|0) + 32|0);
           HEAPF32[$291>>2] = $290;
           $292 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 36|0);
           $293 = Math_fround(HEAPF32[$292>>2]);
           $294 = ((($273) + ($272<<6)|0) + 36|0);
           HEAPF32[$294>>2] = $293;
           $295 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 40|0);
           $296 = Math_fround(HEAPF32[$295>>2]);
           $297 = ((($273) + ($272<<6)|0) + 40|0);
           HEAPF32[$297>>2] = $296;
           $298 = ((($273) + ($272<<6)|0) + 44|0);
           $299 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 44|0);
           ;HEAP32[$298+0>>2]=HEAP32[$299+0>>2]|0;HEAP32[$298+4>>2]=HEAP32[$299+4>>2]|0;HEAP32[$298+8>>2]=HEAP32[$299+8>>2]|0;HEAP32[$298+12>>2]=HEAP32[$299+12>>2]|0;HEAP32[$298+16>>2]=HEAP32[$299+16>>2]|0;
           $380 = $211;
          } else if ((($$hitType$0|0) == 2)) {
           $300 = (($157) + 40|0);
           $301 = Math_fround(HEAPF32[$300>>2]);
           $302 = !($301 <= $211);
           if ($302) {
            $380 = $211;
            break;
           }
           ;HEAP32[$88+0>>2]=HEAP32[$157+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$157+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$157+8>>2]|0;
           $303 = HEAP16[$161>>1]|0;
           HEAP16[$90>>1] = $303;
           $304 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 16|0);
           $305 = Math_fround(HEAPF32[$304>>2]);
           HEAPF32[$91>>2] = $305;
           $306 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 20|0);
           $307 = Math_fround(HEAPF32[$306>>2]);
           HEAPF32[$93>>2] = $307;
           $308 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 24|0);
           $309 = Math_fround(HEAPF32[$308>>2]);
           HEAPF32[$95>>2] = $309;
           $310 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 28|0);
           $311 = Math_fround(HEAPF32[$310>>2]);
           HEAPF32[$97>>2] = $311;
           $312 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 32|0);
           $313 = Math_fround(HEAPF32[$312>>2]);
           HEAPF32[$99>>2] = $313;
           $314 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 36|0);
           $315 = Math_fround(HEAPF32[$314>>2]);
           HEAPF32[$101>>2] = $315;
           $316 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 40|0);
           $317 = Math_fround(HEAPF32[$316>>2]);
           HEAPF32[$102>>2] = $317;
           $318 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 44|0);
           ;HEAP32[$103+0>>2]=HEAP32[$318+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$318+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$318+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$318+12>>2]|0;HEAP32[$103+16>>2]=HEAP32[$318+16>>2]|0;
           HEAP8[$3>>0] = 1;
           $380 = $301;
          } else {
           $380 = $211;
          }
         } while(0);
         $319 = (($iSubHit$028) + 1)|0;
         $320 = ($319>>>0)<($152>>>0);
         if ($320) {
          $211 = $380;$iSubHit$028 = $319;
         } else {
          $378 = $380;
          break;
         }
        }
       }
      }
     }
     $321 = (($iCachedShape$033) + 1)|0;
     $322 = ($321>>>0)<($106>>>0);
     if ($322) {
      $150 = $378;$iCachedShape$033 = $321;
     } else {
      $$lcssa30 = $378;
      break;
     }
    }
   }
   $323 = (($isDynamic1$036) + 1)|0;
   $324 = ($323>>>0)<(2);
   if (!($324)) {
    label = 70;
    break;
   }
   $$phi$trans$insert = (($cacheSize) + ($323<<2)|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $106 = $$pre;$377 = $$lcssa30;$isDynamic1$036 = $323;
  }
  if ((label|0) == 47) {
   ;HEAP32[$88+0>>2]=HEAP32[$157+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$157+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$157+8>>2]|0;
   $187 = HEAP16[$161>>1]|0;
   HEAP16[$90>>1] = $187;
   $188 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 16|0);
   $189 = Math_fround(HEAPF32[$188>>2]);
   HEAPF32[$91>>2] = $189;
   $190 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 20|0);
   $191 = Math_fround(HEAPF32[$190>>2]);
   HEAPF32[$93>>2] = $191;
   $192 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 24|0);
   $193 = Math_fround(HEAPF32[$192>>2]);
   HEAPF32[$95>>2] = $193;
   $194 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 28|0);
   $195 = Math_fround(HEAPF32[$194>>2]);
   HEAPF32[$97>>2] = $195;
   $196 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 32|0);
   $197 = Math_fround(HEAPF32[$196>>2]);
   HEAPF32[$99>>2] = $197;
   $198 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 36|0);
   $199 = Math_fround(HEAPF32[$198>>2]);
   HEAPF32[$101>>2] = $199;
   $200 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 40|0);
   $201 = Math_fround(HEAPF32[$200>>2]);
   HEAPF32[$102>>2] = $201;
   $202 = ((($subHits$0) + ($iSubHit$028<<6)|0) + 44|0);
   ;HEAP32[$103+0>>2]=HEAP32[$202+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$202+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$202+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$202+12>>2]|0;HEAP32[$103+16>>2]=HEAP32[$202+16>>2]|0;
   $203 = HEAP32[$hitCall>>2]|0;
   $204 = (($203) + 4|0);
   $205 = HEAP32[$204>>2]|0;
   FUNCTION_TABLE_vi[$205 & 4095]($hitCall);
   HEAP8[$3>>0] = 1;
   $$7 = 1;
  }
  else if ((label|0) == 62) {
   $266 = HEAP32[$hitCall>>2]|0;
   $267 = (($266) + 4|0);
   $268 = HEAP32[$267>>2]|0;
   FUNCTION_TABLE_vi[$268 & 4095]($hitCall);
   $269 = HEAP8[$3>>0]|0;
   $270 = ($269<<24>>24)!=(0);
   $$7 = $270;
  }
  else if ((label|0) == 70) {
   $325 = HEAP8[$3>>0]|0;
   $326 = ($325<<24>>24)==(0);
   $$pr = HEAP32[$4>>2]|0;
   if ($326) {
    $365 = $$pr;
    label = 77;
   } else {
    $327 = ($$pr|0)==(0);
    if (!($327)) {
     $328 = HEAP32[$104>>2]|0;
     $329 = (($hitCall) + 4|0);
     $330 = (($329) + 40|0);
     $331 = Math_fround(HEAPF32[$330>>2]);
     $i$02$i = 0;$newCount$01$i = $$pr;
     while(1) {
      $332 = ((($328) + ($i$02$i<<6)|0) + 40|0);
      $333 = Math_fround(HEAPF32[$332>>2]);
      $334 = $333 > $331;
      if ($334) {
       $335 = ((($328) + ($i$02$i<<6)|0) + 44|0);
       $336 = (($328) + ($i$02$i<<6)|0);
       $337 = ((($328) + ($i$02$i<<6)|0) + 36|0);
       $338 = ((($328) + ($i$02$i<<6)|0) + 32|0);
       $339 = ((($328) + ($i$02$i<<6)|0) + 28|0);
       $340 = ((($328) + ($i$02$i<<6)|0) + 24|0);
       $341 = ((($328) + ($i$02$i<<6)|0) + 20|0);
       $342 = ((($328) + ($i$02$i<<6)|0) + 16|0);
       $343 = ((($328) + ($i$02$i<<6)|0) + 12|0);
       $344 = (($newCount$01$i) + -1)|0;
       $345 = (($328) + ($344<<6)|0);
       $346 = ((($328) + ($344<<6)|0) + 12|0);
       $347 = HEAP16[$346>>1]|0;
       $348 = ((($328) + ($344<<6)|0) + 16|0);
       $349 = Math_fround(HEAPF32[$348>>2]);
       $350 = ((($328) + ($344<<6)|0) + 20|0);
       $351 = Math_fround(HEAPF32[$350>>2]);
       $352 = ((($328) + ($344<<6)|0) + 24|0);
       $353 = Math_fround(HEAPF32[$352>>2]);
       $354 = ((($328) + ($344<<6)|0) + 28|0);
       $355 = Math_fround(HEAPF32[$354>>2]);
       $356 = ((($328) + ($344<<6)|0) + 32|0);
       $357 = Math_fround(HEAPF32[$356>>2]);
       $358 = ((($328) + ($344<<6)|0) + 36|0);
       $359 = Math_fround(HEAPF32[$358>>2]);
       $360 = ((($328) + ($344<<6)|0) + 40|0);
       $361 = Math_fround(HEAPF32[$360>>2]);
       $362 = ((($328) + ($344<<6)|0) + 44|0);
       _memmove(($336|0),($345|0),12)|0;
       HEAP16[$343>>1] = $347;
       HEAPF32[$342>>2] = $349;
       HEAPF32[$341>>2] = $351;
       HEAPF32[$340>>2] = $353;
       HEAPF32[$339>>2] = $355;
       HEAPF32[$338>>2] = $357;
       HEAPF32[$337>>2] = $359;
       HEAPF32[$332>>2] = $361;
       _memmove(($335|0),($362|0),20)|0;
       $newCount$1$i = $344;
      } else {
       $newCount$1$i = $newCount$01$i;
      }
      $363 = (($i$02$i) + 1)|0;
      $exitcond$i = ($363|0)==($$pr|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$02$i = $363;$newCount$01$i = $newCount$1$i;
      }
     }
     HEAP32[$4>>2] = $newCount$1$i;
     $365 = $newCount$1$i;
     label = 77;
    }
   }
   if ((label|0) == 77) {
    $364 = ($365|0)==(0);
    if (!($364)) {
     $366 = HEAP32[$hitCall>>2]|0;
     $367 = HEAP32[$366>>2]|0;
     $368 = HEAP32[$104>>2]|0;
     $369 = (FUNCTION_TABLE_iiii[$367 & 2047]($hitCall,$368,$365)|0);
     if ($369) {
      HEAP32[$4>>2] = 0;
     }
    }
   }
   $370 = HEAP32[$hitCall>>2]|0;
   $371 = (($370) + 4|0);
   $372 = HEAP32[$371>>2]|0;
   FUNCTION_TABLE_vi[$372 & 4095]($hitCall);
   $373 = HEAP8[$3>>0]|0;
   $374 = ($373<<24>>24)!=(0);
   $$7 = $374;
  }
  $375 = ($376|0)==(0|0);
  if ($375) {
   $$8 = $$7;
   STACKTOP = sp;return ($$8|0);
  }
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($0,$376);
  $$8 = $$7;
  STACKTOP = sp;return ($$8|0);
 }
 if ((label|0) == 11) {
  $31 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($31,128,439376,599,439632,$vararg_buffer);
 }
 $32 = HEAP32[$7>>2]|0;
 $33 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($32)|0);
 $34 = HEAP16[$hitFlags>>1]|0;
 $35 = HEAP32[$33>>2]|0;
 $36 = (($35) + 348|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$input>>2]|0;
 $39 = (($input) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($input) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAP16[$vararg_buffer>>1] = $34;
 (FUNCTION_TABLE_iiiifiiiii[$37 & 1]($33,$38,$40,$42,$hitCall,$vararg_buffer,$filterData,$filterCall,0)|0);
 $43 = HEAP8[$3>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  $$8 = 1;
  STACKTOP = sp;return ($$8|0);
 }
 $45 = HEAP32[$4>>2]|0;
 $46 = ($45|0)!=(0);
 $$8 = $46;
 STACKTOP = sp;return ($$8|0);
}
function __ZNK5physx13NpVolumeCache5sweepERKNS_10PxGeometryERKNS_11PxTransformERKNS_6PxVec3EfRNS_13PxHitCallbackINS_10PxSweepHitEEENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$geometry,$pose,$unitDir,$distance,$hitCall,$hitFlags,$filterData,$filterCall,$inflation) {
 $this = $this|0;
 $geometry = $geometry|0;
 $pose = $pose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $hitCall = $hitCall|0;
 $hitFlags = $hitFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $inflation = Math_fround($inflation);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $input = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $input = sp;
 $0 = sp + 24|0;
 HEAP32[$input>>2] = 0;
 $1 = (($input) + 8|0);
 HEAPF32[$1>>2] = $distance;
 $2 = (($input) + 4|0);
 HEAP32[$2>>2] = $unitDir;
 $3 = (($input) + 12|0);
 HEAP32[$3>>2] = $geometry;
 $4 = (($input) + 16|0);
 HEAP32[$4>>2] = $pose;
 $5 = (($input) + 20|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = HEAP16[$hitFlags>>1]|0;
 HEAP16[$0>>1] = $6;
 $7 = (__ZNK5physx13NpVolumeCache10multiQueryINS_10PxSweepHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$hitCall,$0,$filterData,$filterCall,$inflation)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZNK5physx13NpVolumeCache10multiQueryINS_10PxSweepHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$hitCall,$hitFlags,$filterData,$filterCall,$inflation) {
 $this = $this|0;
 $input = $input|0;
 $hitCall = $hitCall|0;
 $hitFlags = $hitFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $inflation = Math_fround($inflation);
 var $$0$i$i = 0, $$7 = 0, $$8 = 0, $$hitType$0 = 0, $$lcssa31 = Math_fround(0), $$not = 0, $$phi$trans$insert = 0, $$pr = 0, $$pre = 0, $$pre56 = 0, $$pre57 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0);
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = Math_fround(0);
 var $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0);
 var $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = Math_fround(0);
 var $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $brmerge = 0, $buf1 = 0, $cacheSize = 0, $exitcond$i = 0, $exitcond$i8 = 0, $filterFlags = 0, $globalPose = 0, $hitType$0 = 0, $i$02$i = 0, $i$02$i4 = 0, $iCachedShape$034 = 0, $isDynamic$038 = 0, $isDynamic1$037 = 0, $newCount$0$lcssa$i9 = 0, $newCount$01$i = 0, $newCount$01$i5 = 0, $newCount$1$i = 0, $newCount$1$i7 = 0, $or$cond = 0;
 var $or$cond3 = 0, $phitmp = 0, $phitmp19 = 0, $phitmp58 = 0, $shapeHitType = 0, $subHits$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $vararg_buffer = sp;
 $0 = sp + 117|0;
 $filterFlags = sp + 114|0;
 $cacheSize = sp + 32|0;
 $1 = sp + 116|0;
 $shapeHitType = sp + 40|0;
 $globalPose = sp + 4|0;
 $buf1 = sp + 44|0;
 $2 = sp + 112|0;
 $3 = (($hitCall) + 52|0);
 HEAP8[$3>>0] = 0;
 $4 = (($hitCall) + 64|0);
 HEAP32[$4>>2] = 0;
 $5 = (($filterData) + 16|0);
 $6 = HEAP16[$5>>1]|0;
 HEAP16[$filterFlags>>1] = $6;
 $7 = (($this) + 80|0);
 $8 = (($this) + 108|0);
 $9 = (($this) + 112|0);
 $10 = $6&65535;
 $11 = (($this) + 4|0);
 $isDynamic$038 = 0;
 L1: while(1) {
  $12 = ((($this) + ($isDynamic$038)|0) + 116|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  do {
   if ($14) {
    $15 = ($isDynamic$038|0)==(0);
    $16 = HEAP32[$7>>2]|0;
    if (!($15)) {
     $17 = (($16) + 24|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = HEAP32[$9>>2]|0;
     $20 = ($18|0)==($19|0);
     if ($20) {
      break;
     } else {
      label = 7;
      break;
     }
    }
    $21 = (($16) + 20|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$8>>2]|0;
    $24 = ($22|0)==($23|0);
    if ($24) {
     $25 = (($isDynamic$038) + 1)|0;
     $isDynamic$038 = $25;
     continue L1;
    } else {
     label = 7;
    }
   } else {
    label = 7;
   }
  } while(0);
  if ((label|0) == 7) {
   label = 0;
   $26 = (($isDynamic$038) + 1)|0;
   $27 = $10 & $26;
   $28 = ($27|0)==(0);
   if (!($28)) {
    $29 = (__ZN5physx13NpVolumeCache12fillInternalEjPKNS_12PxOverlapHitEi($this,$isDynamic$038,0,0)|0);
    $30 = ($29|0)==(1);
    $$pre57 = HEAP32[$11>>2]|0;
    $phitmp58 = ($$pre57|0)==(-1);
    if ($30) {
     label = 10;
     break;
    }
    if ($phitmp58) {
     label = 11;
     break;
    }
   }
  }
  $50 = (($isDynamic$038) + 1)|0;
  $51 = ($50>>>0)<(2);
  if ($51) {
   $isDynamic$038 = $50;
  } else {
   label = 15;
   break;
  }
 }
 if ((label|0) == 10) {
  if ($phitmp58) {
   label = 11;
  }
 }
 else if ((label|0) == 15) {
  $52 = (($this) + 88|0);
  $53 = HEAP32[$52>>2]|0;
  HEAP32[$cacheSize>>2] = $53;
  $54 = (($cacheSize) + 4|0);
  $55 = (($this) + 100|0);
  $56 = HEAP32[$55>>2]|0;
  HEAP32[$54>>2] = $56;
  $57 = $53 | $56;
  $58 = ($57|0)==(0);
  if ($58) {
   $$8 = 0;
   STACKTOP = sp;return ($$8|0);
  }
  $59 = (($input) + 8|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = HEAP32[$7>>2]|0;
  $62 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($61)|0);
  $63 = (($this) + 72|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($this) + 76|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($64>>>0)<($66>>>0);
  $68 = $67 ? $66 : $64;
  $69 = ($68>>>0)<(128);
  $70 = ($68*48)|0;
  if ($69) {
   $71 = STACKTOP; STACKTOP = STACKTOP + ((((1*$70)|0)+15)&-16)|0;;
   $386 = 0;$subHits$0 = $71;
  } else {
   $72 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,$70,439376,632)|0);
   $386 = $72;$subHits$0 = $72;
  }
  $73 = HEAP16[$5>>1]|0;
  $74 = $73 & 32;
  $75 = ($74<<16>>16)!=(0);
  $76 = (($hitCall) + 60|0);
  $77 = (($input) + 4|0);
  $78 = (($input) + 12|0);
  $79 = (($input) + 16|0);
  $80 = ($filterCall|0)==(0|0);
  $81 = (($buf1) + 4|0);
  $82 = (($buf1) + 8|0);
  $83 = (($buf1) + 12|0);
  $84 = (($buf1) + 16|0);
  $85 = (($buf1) + 20|0);
  $86 = (($buf1) + 44|0);
  $87 = (($buf1) + 52|0);
  $88 = (($buf1) + 56|0);
  $89 = (($buf1) + 60|0);
  $90 = (($buf1) + 64|0);
  $91 = (($hitCall) + 4|0);
  $92 = (($buf1) + 4|0);
  $93 = (($hitCall) + 16|0);
  $94 = (($hitCall) + 20|0);
  $95 = (($buf1) + 24|0);
  $96 = (($hitCall) + 24|0);
  $97 = (($buf1) + 28|0);
  $98 = (($hitCall) + 28|0);
  $99 = (($buf1) + 32|0);
  $100 = (($hitCall) + 32|0);
  $101 = (($buf1) + 36|0);
  $102 = (($hitCall) + 36|0);
  $103 = (($buf1) + 40|0);
  $104 = (($hitCall) + 40|0);
  $105 = (($hitCall) + 44|0);
  $106 = (($buf1) + 48|0);
  $107 = (($hitCall) + 48|0);
  $108 = (($hitCall) + 56|0);
  $110 = $53;$387 = $60;$isDynamic1$037 = 0;
  L23: while(1) {
   $109 = ($110|0)==(0);
   if ($109) {
    $$lcssa31 = $387;
   } else {
    $111 = ((($this) + (($isDynamic1$037*12)|0)|0) + 84|0);
    $219 = $387;$iCachedShape$034 = 0;
    while(1) {
     $112 = HEAP32[$111>>2]|0;
     $113 = (($112) + ($iCachedShape$034<<3)|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (($114) + 4|0);
     $116 = HEAP16[$115>>1]|0;
     $117 = ($116<<16>>16)==(5);
     if ($117) {
      $phitmp = ($114|0)!=(0|0);
      $phitmp19 = $phitmp ? 2 : 1;
      $121 = $phitmp19;
     } else {
      $121 = 1;
     }
     $118 = HEAP16[$filterFlags>>1]|0;
     $119 = $118&65535;
     $120 = $119 & $121;
     $122 = ($120|0)==(0);
     do {
      if ($122) {
       $388 = $219;
      } else {
       $123 = HEAP32[$76>>2]|0;
       $124 = ($123|0)!=(0);
       $125 = $124 ? 1 : 2;
       HEAP32[$shapeHitType>>2] = $125;
       $126 = HEAP16[$hitFlags>>1]|0;
       $127 = (__ZN5physxL20applyAllPreFiltersVCEPNS_12PxActorShapeERNS_14PxQueryHitType4EnumERKNS_7PxFlagsINS_11PxQueryFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackERKNS_7NpSceneERNS5_INS_9PxHitFlag4EnumEtEE($113,$shapeHitType,$filterFlags,$filterData,$filterCall,$62,$hitFlags)|0);
       $128 = ($127|0)==(0|0);
       $129 = HEAP32[$shapeHitType>>2]|0;
       $130 = ($129|0)==(0);
       $or$cond = $128 | $130;
       if ($or$cond) {
        $388 = $219;
       } else {
        $131 = (($127) + 4|0);
        $132 = HEAP32[$131>>2]|0;
        $133 = HEAP32[$127>>2]|0;
        __ZN5physx2Sq13getGlobalPoseERKNS_7NpShapeERKNS_12PxRigidActorE($globalPose,$132,$133);
        $134 = (($132) + 36|0);
        $135 = HEAP32[$134>>2]|0;
        $136 = $135 & 1;
        $137 = ($136|0)==(0);
        if ($137) {
         $146 = (($132) + 116|0);
         $$0$i$i = $146;
        } else {
         $138 = (($132) + 40|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = ($139|0)==(0|0);
         if ($140) {
          $141 = (($132) + 32|0);
          $142 = HEAP32[$141>>2]|0;
          $143 = $135 >>> 24;
          $144 = $143 & 15;
          $145 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($142,$144)|0);
          HEAP32[$138>>2] = $145;
          $389 = $145;
         } else {
          $389 = $139;
         }
         $$0$i$i = $389;
        }
        $147 = HEAP32[$77>>2]|0;
        $148 = Math_fround(HEAPF32[$59>>2]);
        $149 = HEAP32[$78>>2]|0;
        $150 = HEAP32[$79>>2]|0;
        HEAP16[$vararg_buffer>>1] = $126;
        $151 = (__ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($147,$148,$149,$150,$$0$i$i,$globalPose,$subHits$0,$vararg_buffer,Math_fround(0.0))|0);
        if ($151) {
         $152 = HEAP16[$filterFlags>>1]|0;
         $153 = $152 & 8;
         $154 = ($153<<16>>16)==(0);
         $155 = HEAP32[$127>>2]|0;
         HEAP32[$subHits$0>>2] = $155;
         $156 = HEAP32[$131>>2]|0;
         $157 = (($subHits$0) + 4|0);
         HEAP32[$157>>2] = $156;
         $158 = (($subHits$0) + 12|0);
         $159 = HEAP16[$158>>1]|0;
         $160 = $159 & 4;
         $161 = ($160<<16>>16)==(0);
         if ($161) {
          $162 = (($subHits$0) + 40|0);
          HEAPF32[$162>>2] = Math_fround(0.0);
         }
         $163 = $159 & 1;
         $164 = ($163<<16>>16)==(0);
         if ($164) {
          $165 = (($subHits$0) + 16|0);
          HEAPF32[$165>>2] = Math_fround(0.0);
          $166 = (($subHits$0) + 20|0);
          HEAPF32[$166>>2] = Math_fround(0.0);
          $167 = (($subHits$0) + 24|0);
          HEAPF32[$167>>2] = Math_fround(0.0);
         }
         $168 = $159 & 2;
         $169 = ($168<<16>>16)==(0);
         if ($169) {
          $170 = (($subHits$0) + 28|0);
          HEAPF32[$170>>2] = Math_fround(0.0);
          $171 = (($subHits$0) + 32|0);
          HEAPF32[$171>>2] = Math_fround(0.0);
          $172 = (($subHits$0) + 36|0);
          HEAPF32[$172>>2] = Math_fround(0.0);
         }
         $173 = (($subHits$0) + 40|0);
         $174 = Math_fround(HEAPF32[$173>>2]);
         $175 = $174 == Math_fround(0.0);
         if ($175) {
          $176 = HEAP32[$77>>2]|0;
          $177 = Math_fround(HEAPF32[$176>>2]);
          $178 = Math_fround(-$177);
          $179 = (($176) + 4|0);
          $180 = Math_fround(HEAPF32[$179>>2]);
          $181 = Math_fround(-$180);
          $182 = (($176) + 8|0);
          $183 = Math_fround(HEAPF32[$182>>2]);
          $184 = Math_fround(-$183);
          $185 = (($subHits$0) + 28|0);
          HEAPF32[$185>>2] = $178;
          $186 = (($subHits$0) + 32|0);
          HEAPF32[$186>>2] = $181;
          $187 = (($subHits$0) + 36|0);
          HEAPF32[$187>>2] = $184;
         }
         $brmerge = $80 | $154;
         if ($brmerge) {
          $hitType$0 = $129;
         } else {
          $188 = HEAP32[$filterCall>>2]|0;
          $189 = (($188) + 4|0);
          $190 = HEAP32[$189>>2]|0;
          $191 = (FUNCTION_TABLE_iiii[$190 & 2047]($filterCall,$filterData,$subHits$0)|0);
          $hitType$0 = $191;
         }
         $192 = HEAP16[$5>>1]|0;
         $193 = $192 & 16;
         $$not = ($193<<16>>16)==(0);
         $194 = ($hitType$0|0)==(0);
         $or$cond3 = $$not | $194;
         if (!($or$cond3)) {
          label = 43;
          break L23;
         }
         $$hitType$0 = $75 ? 1 : $hitType$0;
         if ((($$hitType$0|0) == 2)) {
          $311 = Math_fround(HEAPF32[$173>>2]);
          $312 = !($311 <= $219);
          if ($312) {
           $388 = $219;
           break;
          }
          ;HEAP32[$91+0>>2]=HEAP32[$subHits$0+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$subHits$0+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$subHits$0+8>>2]|0;
          $313 = HEAP16[$158>>1]|0;
          HEAP16[$93>>1] = $313;
          $314 = (($subHits$0) + 16|0);
          $315 = Math_fround(HEAPF32[$314>>2]);
          HEAPF32[$94>>2] = $315;
          $316 = (($subHits$0) + 20|0);
          $317 = Math_fround(HEAPF32[$316>>2]);
          HEAPF32[$96>>2] = $317;
          $318 = (($subHits$0) + 24|0);
          $319 = Math_fround(HEAPF32[$318>>2]);
          HEAPF32[$98>>2] = $319;
          $320 = (($subHits$0) + 28|0);
          $321 = Math_fround(HEAPF32[$320>>2]);
          HEAPF32[$100>>2] = $321;
          $322 = (($subHits$0) + 32|0);
          $323 = Math_fround(HEAPF32[$322>>2]);
          HEAPF32[$102>>2] = $323;
          $324 = (($subHits$0) + 36|0);
          $325 = Math_fround(HEAPF32[$324>>2]);
          HEAPF32[$104>>2] = $325;
          $326 = (($subHits$0) + 40|0);
          $327 = Math_fround(HEAPF32[$326>>2]);
          HEAPF32[$105>>2] = $327;
          $328 = (($subHits$0) + 44|0);
          $329 = HEAP32[$328>>2]|0;
          HEAP32[$107>>2] = $329;
          HEAP8[$3>>0] = 1;
          $388 = $311;
          break;
         } else if (!((($$hitType$0|0) == 1))) {
          $388 = $219;
          break;
         }
         $215 = HEAP32[$76>>2]|0;
         $216 = ($215|0)==(0);
         if ($216) {
          $388 = $219;
         } else {
          $217 = Math_fround(HEAPF32[$173>>2]);
          $218 = !($217 <= $219);
          if ($218) {
           $388 = $219;
           break;
          }
          $220 = HEAP32[$4>>2]|0;
          $221 = ($220|0)==($215|0);
          do {
           if ($221) {
            HEAP32[$81>>2] = 0;
            HEAP32[$82>>2] = 0;
            HEAP32[$83>>2] = -1;
            HEAP16[$84>>1] = 0;
            ;HEAP32[$85+0>>2]=0|0;HEAP32[$85+4>>2]=0|0;HEAP32[$85+8>>2]=0|0;HEAP32[$85+12>>2]=0|0;HEAP32[$85+16>>2]=0|0;HEAP32[$85+20>>2]=0|0;
            HEAPF32[$86>>2] = Math_fround(3.40282346638528859812E+38);
            HEAP8[$87>>0] = 0;
            HEAP32[$88>>2] = 0;
            HEAP32[$89>>2] = 0;
            HEAP32[$90>>2] = 0;
            HEAP32[$buf1>>2] = ((412736 + 8|0));
            $222 = HEAP16[$hitFlags>>1]|0;
            HEAP16[$2>>1] = $222;
            $223 = (__ZNK5physx13NpVolumeCache10multiQueryINS_10PxSweepHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$buf1,$2,$filterData,$filterCall,$inflation)|0);
            if ($223) {
             ;HEAP32[$91+0>>2]=HEAP32[$92+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$92+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$92+8>>2]|0;
             $224 = HEAP16[$84>>1]|0;
             HEAP16[$93>>1] = $224;
             $225 = Math_fround(HEAPF32[$85>>2]);
             HEAPF32[$94>>2] = $225;
             $226 = Math_fround(HEAPF32[$95>>2]);
             HEAPF32[$96>>2] = $226;
             $227 = Math_fround(HEAPF32[$97>>2]);
             HEAPF32[$98>>2] = $227;
             $228 = Math_fround(HEAPF32[$99>>2]);
             HEAPF32[$100>>2] = $228;
             $229 = Math_fround(HEAPF32[$101>>2]);
             HEAPF32[$102>>2] = $229;
             $230 = Math_fround(HEAPF32[$103>>2]);
             HEAPF32[$104>>2] = $230;
             $231 = Math_fround(HEAPF32[$86>>2]);
             HEAPF32[$105>>2] = $231;
             $232 = HEAP32[$106>>2]|0;
             HEAP32[$107>>2] = $232;
             HEAP8[$3>>0] = 1;
             $233 = HEAP32[$108>>2]|0;
             $234 = HEAP32[$4>>2]|0;
             $235 = ($234|0)==(0);
             if ($235) {
              $newCount$0$lcssa$i9 = 0;
             } else {
              $i$02$i4 = 0;$newCount$01$i5 = $234;
              while(1) {
               $236 = ((($233) + (($i$02$i4*48)|0)|0) + 40|0);
               $237 = Math_fround(HEAPF32[$236>>2]);
               $238 = $237 > $231;
               if ($238) {
                $239 = (($233) + (($i$02$i4*48)|0)|0);
                $240 = ((($233) + (($i$02$i4*48)|0)|0) + 44|0);
                $241 = ((($233) + (($i$02$i4*48)|0)|0) + 36|0);
                $242 = ((($233) + (($i$02$i4*48)|0)|0) + 32|0);
                $243 = ((($233) + (($i$02$i4*48)|0)|0) + 28|0);
                $244 = ((($233) + (($i$02$i4*48)|0)|0) + 24|0);
                $245 = ((($233) + (($i$02$i4*48)|0)|0) + 20|0);
                $246 = ((($233) + (($i$02$i4*48)|0)|0) + 16|0);
                $247 = ((($233) + (($i$02$i4*48)|0)|0) + 12|0);
                $248 = (($newCount$01$i5) + -1)|0;
                $249 = (($233) + (($248*48)|0)|0);
                $250 = ((($233) + (($248*48)|0)|0) + 12|0);
                $251 = HEAP16[$250>>1]|0;
                $252 = ((($233) + (($248*48)|0)|0) + 16|0);
                $253 = Math_fround(HEAPF32[$252>>2]);
                $254 = ((($233) + (($248*48)|0)|0) + 20|0);
                $255 = Math_fround(HEAPF32[$254>>2]);
                $256 = ((($233) + (($248*48)|0)|0) + 24|0);
                $257 = Math_fround(HEAPF32[$256>>2]);
                $258 = ((($233) + (($248*48)|0)|0) + 28|0);
                $259 = Math_fround(HEAPF32[$258>>2]);
                $260 = ((($233) + (($248*48)|0)|0) + 32|0);
                $261 = Math_fround(HEAPF32[$260>>2]);
                $262 = ((($233) + (($248*48)|0)|0) + 36|0);
                $263 = Math_fround(HEAPF32[$262>>2]);
                $264 = ((($233) + (($248*48)|0)|0) + 40|0);
                $265 = Math_fround(HEAPF32[$264>>2]);
                $266 = ((($233) + (($248*48)|0)|0) + 44|0);
                $267 = HEAP32[$266>>2]|0;
                _memmove(($239|0),($249|0),12)|0;
                HEAP16[$247>>1] = $251;
                HEAPF32[$246>>2] = $253;
                HEAPF32[$245>>2] = $255;
                HEAPF32[$244>>2] = $257;
                HEAPF32[$243>>2] = $259;
                HEAPF32[$242>>2] = $261;
                HEAPF32[$241>>2] = $263;
                HEAPF32[$236>>2] = $265;
                HEAP32[$240>>2] = $267;
                $newCount$1$i7 = $248;
               } else {
                $newCount$1$i7 = $newCount$01$i5;
               }
               $268 = (($i$02$i4) + 1)|0;
               $exitcond$i8 = ($268|0)==($234|0);
               if ($exitcond$i8) {
                $newCount$0$lcssa$i9 = $newCount$1$i7;
                break;
               } else {
                $i$02$i4 = $268;$newCount$01$i5 = $newCount$1$i7;
               }
              }
             }
             HEAP32[$4>>2] = $newCount$0$lcssa$i9;
             $271 = $newCount$0$lcssa$i9;
            } else {
             $$pre56 = HEAP32[$4>>2]|0;
             $271 = $$pre56;
            }
            $269 = HEAP32[$76>>2]|0;
            $270 = ($271|0)==($269|0);
            if (!($270)) {
             $282 = $271;
             break;
            }
            $272 = HEAP32[$hitCall>>2]|0;
            $273 = HEAP32[$272>>2]|0;
            $274 = HEAP32[$108>>2]|0;
            $275 = (FUNCTION_TABLE_iiii[$273 & 2047]($hitCall,$274,$271)|0);
            if (!($275)) {
             label = 58;
             break L23;
            }
            HEAP32[$4>>2] = 0;
            $282 = 0;
           } else {
            $282 = $220;
           }
          } while(0);
          $281 = (($282) + 1)|0;
          HEAP32[$4>>2] = $281;
          $283 = HEAP32[$108>>2]|0;
          $284 = (($283) + (($282*48)|0)|0);
          ;HEAP32[$284+0>>2]=HEAP32[$subHits$0+0>>2]|0;HEAP32[$284+4>>2]=HEAP32[$subHits$0+4>>2]|0;HEAP32[$284+8>>2]=HEAP32[$subHits$0+8>>2]|0;
          $285 = HEAP16[$158>>1]|0;
          $286 = ((($283) + (($282*48)|0)|0) + 12|0);
          HEAP16[$286>>1] = $285;
          $287 = (($subHits$0) + 16|0);
          $288 = Math_fround(HEAPF32[$287>>2]);
          $289 = ((($283) + (($282*48)|0)|0) + 16|0);
          HEAPF32[$289>>2] = $288;
          $290 = (($subHits$0) + 20|0);
          $291 = Math_fround(HEAPF32[$290>>2]);
          $292 = ((($283) + (($282*48)|0)|0) + 20|0);
          HEAPF32[$292>>2] = $291;
          $293 = (($subHits$0) + 24|0);
          $294 = Math_fround(HEAPF32[$293>>2]);
          $295 = ((($283) + (($282*48)|0)|0) + 24|0);
          HEAPF32[$295>>2] = $294;
          $296 = (($subHits$0) + 28|0);
          $297 = Math_fround(HEAPF32[$296>>2]);
          $298 = ((($283) + (($282*48)|0)|0) + 28|0);
          HEAPF32[$298>>2] = $297;
          $299 = (($subHits$0) + 32|0);
          $300 = Math_fround(HEAPF32[$299>>2]);
          $301 = ((($283) + (($282*48)|0)|0) + 32|0);
          HEAPF32[$301>>2] = $300;
          $302 = (($subHits$0) + 36|0);
          $303 = Math_fround(HEAPF32[$302>>2]);
          $304 = ((($283) + (($282*48)|0)|0) + 36|0);
          HEAPF32[$304>>2] = $303;
          $305 = (($subHits$0) + 40|0);
          $306 = Math_fround(HEAPF32[$305>>2]);
          $307 = ((($283) + (($282*48)|0)|0) + 40|0);
          HEAPF32[$307>>2] = $306;
          $308 = (($subHits$0) + 44|0);
          $309 = HEAP32[$308>>2]|0;
          $310 = ((($283) + (($282*48)|0)|0) + 44|0);
          HEAP32[$310>>2] = $309;
          $388 = $219;
         }
        } else {
         $388 = $219;
        }
       }
      }
     } while(0);
     $330 = (($iCachedShape$034) + 1)|0;
     $331 = ($330>>>0)<($110>>>0);
     if ($331) {
      $219 = $388;$iCachedShape$034 = $330;
     } else {
      $$lcssa31 = $388;
      break;
     }
    }
   }
   $332 = (($isDynamic1$037) + 1)|0;
   $333 = ($332>>>0)<(2);
   if (!($333)) {
    label = 65;
    break;
   }
   $$phi$trans$insert = (($cacheSize) + ($332<<2)|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $110 = $$pre;$387 = $$lcssa31;$isDynamic1$037 = $332;
  }
  if ((label|0) == 43) {
   ;HEAP32[$91+0>>2]=HEAP32[$subHits$0+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$subHits$0+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$subHits$0+8>>2]|0;
   $195 = HEAP16[$158>>1]|0;
   HEAP16[$93>>1] = $195;
   $196 = (($subHits$0) + 16|0);
   $197 = Math_fround(HEAPF32[$196>>2]);
   HEAPF32[$94>>2] = $197;
   $198 = (($subHits$0) + 20|0);
   $199 = Math_fround(HEAPF32[$198>>2]);
   HEAPF32[$96>>2] = $199;
   $200 = (($subHits$0) + 24|0);
   $201 = Math_fround(HEAPF32[$200>>2]);
   HEAPF32[$98>>2] = $201;
   $202 = (($subHits$0) + 28|0);
   $203 = Math_fround(HEAPF32[$202>>2]);
   HEAPF32[$100>>2] = $203;
   $204 = (($subHits$0) + 32|0);
   $205 = Math_fround(HEAPF32[$204>>2]);
   HEAPF32[$102>>2] = $205;
   $206 = (($subHits$0) + 36|0);
   $207 = Math_fround(HEAPF32[$206>>2]);
   HEAPF32[$104>>2] = $207;
   $208 = (($subHits$0) + 40|0);
   $209 = Math_fround(HEAPF32[$208>>2]);
   HEAPF32[$105>>2] = $209;
   $210 = (($subHits$0) + 44|0);
   $211 = HEAP32[$210>>2]|0;
   HEAP32[$107>>2] = $211;
   $212 = HEAP32[$hitCall>>2]|0;
   $213 = (($212) + 4|0);
   $214 = HEAP32[$213>>2]|0;
   FUNCTION_TABLE_vi[$214 & 4095]($hitCall);
   HEAP8[$3>>0] = 1;
   $$7 = 1;
  }
  else if ((label|0) == 58) {
   $276 = HEAP32[$hitCall>>2]|0;
   $277 = (($276) + 4|0);
   $278 = HEAP32[$277>>2]|0;
   FUNCTION_TABLE_vi[$278 & 4095]($hitCall);
   $279 = HEAP8[$3>>0]|0;
   $280 = ($279<<24>>24)!=(0);
   $$7 = $280;
  }
  else if ((label|0) == 65) {
   $334 = HEAP8[$3>>0]|0;
   $335 = ($334<<24>>24)==(0);
   $$pr = HEAP32[$4>>2]|0;
   if ($335) {
    $375 = $$pr;
    label = 72;
   } else {
    $336 = ($$pr|0)==(0);
    if (!($336)) {
     $337 = HEAP32[$108>>2]|0;
     $338 = (($hitCall) + 4|0);
     $339 = (($338) + 40|0);
     $340 = Math_fround(HEAPF32[$339>>2]);
     $i$02$i = 0;$newCount$01$i = $$pr;
     while(1) {
      $341 = ((($337) + (($i$02$i*48)|0)|0) + 40|0);
      $342 = Math_fround(HEAPF32[$341>>2]);
      $343 = $342 > $340;
      if ($343) {
       $344 = (($337) + (($i$02$i*48)|0)|0);
       $345 = ((($337) + (($i$02$i*48)|0)|0) + 44|0);
       $346 = ((($337) + (($i$02$i*48)|0)|0) + 36|0);
       $347 = ((($337) + (($i$02$i*48)|0)|0) + 32|0);
       $348 = ((($337) + (($i$02$i*48)|0)|0) + 28|0);
       $349 = ((($337) + (($i$02$i*48)|0)|0) + 24|0);
       $350 = ((($337) + (($i$02$i*48)|0)|0) + 20|0);
       $351 = ((($337) + (($i$02$i*48)|0)|0) + 16|0);
       $352 = ((($337) + (($i$02$i*48)|0)|0) + 12|0);
       $353 = (($newCount$01$i) + -1)|0;
       $354 = (($337) + (($353*48)|0)|0);
       $355 = ((($337) + (($353*48)|0)|0) + 12|0);
       $356 = HEAP16[$355>>1]|0;
       $357 = ((($337) + (($353*48)|0)|0) + 16|0);
       $358 = Math_fround(HEAPF32[$357>>2]);
       $359 = ((($337) + (($353*48)|0)|0) + 20|0);
       $360 = Math_fround(HEAPF32[$359>>2]);
       $361 = ((($337) + (($353*48)|0)|0) + 24|0);
       $362 = Math_fround(HEAPF32[$361>>2]);
       $363 = ((($337) + (($353*48)|0)|0) + 28|0);
       $364 = Math_fround(HEAPF32[$363>>2]);
       $365 = ((($337) + (($353*48)|0)|0) + 32|0);
       $366 = Math_fround(HEAPF32[$365>>2]);
       $367 = ((($337) + (($353*48)|0)|0) + 36|0);
       $368 = Math_fround(HEAPF32[$367>>2]);
       $369 = ((($337) + (($353*48)|0)|0) + 40|0);
       $370 = Math_fround(HEAPF32[$369>>2]);
       $371 = ((($337) + (($353*48)|0)|0) + 44|0);
       $372 = HEAP32[$371>>2]|0;
       _memmove(($344|0),($354|0),12)|0;
       HEAP16[$352>>1] = $356;
       HEAPF32[$351>>2] = $358;
       HEAPF32[$350>>2] = $360;
       HEAPF32[$349>>2] = $362;
       HEAPF32[$348>>2] = $364;
       HEAPF32[$347>>2] = $366;
       HEAPF32[$346>>2] = $368;
       HEAPF32[$341>>2] = $370;
       HEAP32[$345>>2] = $372;
       $newCount$1$i = $353;
      } else {
       $newCount$1$i = $newCount$01$i;
      }
      $373 = (($i$02$i) + 1)|0;
      $exitcond$i = ($373|0)==($$pr|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$02$i = $373;$newCount$01$i = $newCount$1$i;
      }
     }
     HEAP32[$4>>2] = $newCount$1$i;
     $375 = $newCount$1$i;
     label = 72;
    }
   }
   if ((label|0) == 72) {
    $374 = ($375|0)==(0);
    if (!($374)) {
     $376 = HEAP32[$hitCall>>2]|0;
     $377 = HEAP32[$376>>2]|0;
     $378 = HEAP32[$108>>2]|0;
     $379 = (FUNCTION_TABLE_iiii[$377 & 2047]($hitCall,$378,$375)|0);
     if ($379) {
      HEAP32[$4>>2] = 0;
     }
    }
   }
   $380 = HEAP32[$hitCall>>2]|0;
   $381 = (($380) + 4|0);
   $382 = HEAP32[$381>>2]|0;
   FUNCTION_TABLE_vi[$382 & 4095]($hitCall);
   $383 = HEAP8[$3>>0]|0;
   $384 = ($383<<24>>24)!=(0);
   $$7 = $384;
  }
  $385 = ($386|0)==(0|0);
  if ($385) {
   $$8 = $$7;
   STACKTOP = sp;return ($$8|0);
  }
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($0,$386);
  $$8 = $$7;
  STACKTOP = sp;return ($$8|0);
 }
 if ((label|0) == 11) {
  $31 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($31,128,439376,599,439632,$vararg_buffer);
 }
 $32 = HEAP32[$7>>2]|0;
 $33 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($32)|0);
 $34 = HEAP16[$hitFlags>>1]|0;
 $35 = HEAP32[$33>>2]|0;
 $36 = (($35) + 352|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($input) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($input) + 16|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($input) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($input) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 HEAP16[$vararg_buffer>>1] = $34;
 (FUNCTION_TABLE_iiiiifiiiiif[$37 & 1]($33,$39,$41,$43,$45,$hitCall,$vararg_buffer,$filterData,$filterCall,0,Math_fround(0.0))|0);
 $46 = HEAP8[$3>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if (!($47)) {
  $$8 = 1;
  STACKTOP = sp;return ($$8|0);
 }
 $48 = HEAP32[$4>>2]|0;
 $49 = ($48|0)!=(0);
 $$8 = $49;
 STACKTOP = sp;return ($$8|0);
}
function __ZNK5physx13NpVolumeCache7overlapERKNS_10PxGeometryERKNS_11PxTransformERNS_13PxHitCallbackINS_12PxOverlapHitEEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackE($this,$geometry,$transform,$hitCall,$filterData,$filterCall) {
 $this = $this|0;
 $geometry = $geometry|0;
 $transform = $transform|0;
 $hitCall = $hitCall|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $input = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $input = sp;
 $0 = sp + 24|0;
 $1 = (($input) + 12|0);
 HEAP32[$1>>2] = $geometry;
 $2 = (($input) + 16|0);
 HEAP32[$2>>2] = $transform;
 $3 = (($input) + 20|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($input) + 4|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$input>>2] = 0;
 HEAP16[$0>>1] = 0;
 $5 = (__ZNK5physx13NpVolumeCache10multiQueryINS_12PxOverlapHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$hitCall,$0,$filterData,$filterCall,Math_fround(0.0))|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx13NpVolumeCache10multiQueryINS_12PxOverlapHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$hitCall,$hitFlags,$filterData,$filterCall,$inflation) {
 $this = $this|0;
 $input = $input|0;
 $hitCall = $hitCall|0;
 $hitFlags = $hitFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $inflation = Math_fround($inflation);
 var $$0$i$i = 0, $$7 = 0, $$8 = 0, $$hitType$0 = 0, $$hitType$0$us = 0, $$lcssa21 = Math_fround(0), $$not = 0, $$not$us = 0, $$phi$trans$insert = 0, $$pr = 0, $$pre = 0, $$pre47 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf1 = 0, $cacheSize = 0, $filterFlags = 0;
 var $globalPose = 0, $hitType$0 = 0, $iCachedShape$026 = 0, $isDynamic$030 = 0, $isDynamic1$029 = 0, $or$cond = 0, $or$cond12 = 0, $or$cond12$us = 0, $or$cond3 = 0, $phitmp = 0, $phitmp13 = 0, $phitmp48 = 0, $shapeHitType = 0, $subHits$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $vararg_buffer = sp;
 $filterFlags = sp + 86|0;
 $cacheSize = sp + 8|0;
 $0 = sp + 88|0;
 $shapeHitType = sp + 44|0;
 $globalPose = sp + 16|0;
 $buf1 = sp + 48|0;
 $1 = sp + 84|0;
 $2 = (($hitCall) + 20|0);
 HEAP8[$2>>0] = 0;
 $3 = (($hitCall) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = (($filterData) + 16|0);
 $5 = HEAP16[$4>>1]|0;
 HEAP16[$filterFlags>>1] = $5;
 $6 = (($this) + 80|0);
 $7 = (($this) + 108|0);
 $8 = (($this) + 112|0);
 $9 = $5&65535;
 $10 = (($this) + 4|0);
 $isDynamic$030 = 0;
 L1: while(1) {
  $11 = ((($this) + ($isDynamic$030)|0) + 116|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  do {
   if ($13) {
    $14 = ($isDynamic$030|0)==(0);
    $15 = HEAP32[$6>>2]|0;
    if (!($14)) {
     $16 = (($15) + 24|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = HEAP32[$8>>2]|0;
     $19 = ($17|0)==($18|0);
     if ($19) {
      break;
     } else {
      label = 7;
      break;
     }
    }
    $20 = (($15) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$7>>2]|0;
    $23 = ($21|0)==($22|0);
    if ($23) {
     $24 = (($isDynamic$030) + 1)|0;
     $isDynamic$030 = $24;
     continue L1;
    } else {
     label = 7;
    }
   } else {
    label = 7;
   }
  } while(0);
  if ((label|0) == 7) {
   label = 0;
   $25 = (($isDynamic$030) + 1)|0;
   $26 = $9 & $25;
   $27 = ($26|0)==(0);
   if (!($27)) {
    $28 = (__ZN5physx13NpVolumeCache12fillInternalEjPKNS_12PxOverlapHitEi($this,$isDynamic$030,0,0)|0);
    $29 = ($28|0)==(1);
    $$pre47 = HEAP32[$10>>2]|0;
    $phitmp48 = ($$pre47|0)==(-1);
    if ($29) {
     label = 10;
     break;
    }
    if ($phitmp48) {
     label = 11;
     break;
    }
   }
  }
  $44 = (($isDynamic$030) + 1)|0;
  $45 = ($44>>>0)<(2);
  if ($45) {
   $isDynamic$030 = $44;
  } else {
   label = 15;
   break;
  }
 }
 if ((label|0) == 10) {
  if ($phitmp48) {
   label = 11;
  }
 }
 else if ((label|0) == 15) {
  $46 = (($this) + 88|0);
  $47 = HEAP32[$46>>2]|0;
  HEAP32[$cacheSize>>2] = $47;
  $48 = (($cacheSize) + 4|0);
  $49 = (($this) + 100|0);
  $50 = HEAP32[$49>>2]|0;
  HEAP32[$48>>2] = $50;
  $51 = $47 | $50;
  $52 = ($51|0)==(0);
  if ($52) {
   $$8 = 0;
   STACKTOP = sp;return ($$8|0);
  }
  $53 = HEAP32[$6>>2]|0;
  $54 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($53)|0);
  $55 = (($this) + 72|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($this) + 76|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($56>>>0)<($58>>>0);
  $60 = $59 ? $58 : $56;
  $61 = ($60>>>0)<(128);
  $62 = $60 << 4;
  if ($61) {
   $63 = STACKTOP; STACKTOP = STACKTOP + ((((1*$62)|0)+15)&-16)|0;;
   $201 = 0;$subHits$0 = $63;
  } else {
   $64 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$62,439376,632)|0);
   $201 = $64;$subHits$0 = $64;
  }
  $65 = HEAP16[$4>>1]|0;
  $66 = $65 & 32;
  $67 = ($66<<16>>16)!=(0);
  $68 = (($hitCall) + 28|0);
  $69 = (($input) + 12|0);
  $70 = (($input) + 16|0);
  $71 = ($filterCall|0)==(0|0);
  $72 = (($buf1) + 4|0);
  $73 = (($buf1) + 8|0);
  $74 = (($buf1) + 12|0);
  $75 = (($buf1) + 20|0);
  $76 = (($buf1) + 24|0);
  $77 = (($buf1) + 28|0);
  $78 = (($buf1) + 32|0);
  $79 = (($hitCall) + 4|0);
  $80 = (($buf1) + 4|0);
  $81 = (($hitCall) + 24|0);
  $202 = Math_fround(3.40282346638528859812E+38);$83 = $47;$isDynamic1$029 = 0;
  L24: while(1) {
   $82 = ($83|0)==(0);
   if ($82) {
    $$lcssa21 = $202;
   } else {
    $84 = ((($this) + (($isDynamic1$029*12)|0)|0) + 84|0);
    $129 = $202;$iCachedShape$026 = 0;
    while(1) {
     $85 = HEAP32[$84>>2]|0;
     $86 = (($85) + ($iCachedShape$026<<3)|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = (($87) + 4|0);
     $89 = HEAP16[$88>>1]|0;
     $90 = ($89<<16>>16)==(5);
     if ($90) {
      $phitmp = ($87|0)!=(0|0);
      $phitmp13 = $phitmp ? 2 : 1;
      $94 = $phitmp13;
     } else {
      $94 = 1;
     }
     $91 = HEAP16[$filterFlags>>1]|0;
     $92 = $91&65535;
     $93 = $92 & $94;
     $95 = ($93|0)==(0);
     do {
      if ($95) {
       $203 = $129;
      } else {
       $96 = HEAP32[$68>>2]|0;
       $97 = ($96|0)!=(0);
       $98 = $97 ? 1 : 2;
       HEAP32[$shapeHitType>>2] = $98;
       $99 = (__ZN5physxL20applyAllPreFiltersVCEPNS_12PxActorShapeERNS_14PxQueryHitType4EnumERKNS_7PxFlagsINS_11PxQueryFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackERKNS_7NpSceneERNS5_INS_9PxHitFlag4EnumEtEE($86,$shapeHitType,$filterFlags,$filterData,$filterCall,$54,$hitFlags)|0);
       $100 = ($99|0)==(0|0);
       $101 = HEAP32[$shapeHitType>>2]|0;
       $102 = ($101|0)==(0);
       $or$cond = $100 | $102;
       if ($or$cond) {
        $203 = $129;
       } else {
        $103 = (($99) + 4|0);
        $104 = HEAP32[$103>>2]|0;
        $105 = HEAP32[$99>>2]|0;
        __ZN5physx2Sq13getGlobalPoseERKNS_7NpShapeERKNS_12PxRigidActorE($globalPose,$104,$105);
        $106 = (($104) + 36|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = $107 & 1;
        $109 = ($108|0)==(0);
        if ($109) {
         $118 = (($104) + 116|0);
         $$0$i$i = $118;
        } else {
         $110 = (($104) + 40|0);
         $111 = HEAP32[$110>>2]|0;
         $112 = ($111|0)==(0|0);
         if ($112) {
          $113 = (($104) + 32|0);
          $114 = HEAP32[$113>>2]|0;
          $115 = $107 >>> 24;
          $116 = $115 & 15;
          $117 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($114,$116)|0);
          HEAP32[$110>>2] = $117;
          $204 = $117;
         } else {
          $204 = $111;
         }
         $$0$i$i = $204;
        }
        $119 = HEAP32[$69>>2]|0;
        $120 = HEAP32[$70>>2]|0;
        $121 = (__ZN5physx15PxGeometryQuery7overlapERKNS_10PxGeometryERKNS_11PxTransformES3_S6_($119,$120,$$0$i$i,$globalPose)|0);
        if ($121) {
         $122 = HEAP16[$filterFlags>>1]|0;
         $123 = HEAP32[$99>>2]|0;
         HEAP32[$subHits$0>>2] = $123;
         $124 = HEAP32[$103>>2]|0;
         $125 = (($subHits$0) + 4|0);
         HEAP32[$125>>2] = $124;
         if ($71) {
          $126 = HEAP16[$4>>1]|0;
          $127 = $126 & 16;
          $$not$us = ($127<<16>>16)==(0);
          if (!($$not$us)) {
           label = 48;
           break L24;
          }
          $$hitType$0$us = $67 ? 1 : $101;
          if ((($$hitType$0$us|0) == 2)) {
           $128 = !($129 >= Math_fround(-1.0));
           if ($128) {
            $203 = $129;
            break;
           }
           ;HEAP32[$79+0>>2]=HEAP32[$subHits$0+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$subHits$0+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$subHits$0+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$subHits$0+12>>2]|0;
           HEAP8[$2>>0] = 1;
           $203 = Math_fround(-1.0);
           break;
          } else if (!((($$hitType$0$us|0) == 1))) {
           $203 = $129;
           break;
          }
          $130 = HEAP32[$68>>2]|0;
          $131 = ($130|0)==(0);
          $132 = !($129 >= Math_fround(-1.0));
          $or$cond12$us = $131 | $132;
          if ($or$cond12$us) {
           $203 = $129;
           break;
          }
          $133 = HEAP32[$3>>2]|0;
          $134 = ($133|0)==($130|0);
          do {
           if ($134) {
            HEAP32[$72>>2] = 0;
            HEAP32[$73>>2] = 0;
            HEAP32[$74>>2] = -1;
            HEAP8[$75>>0] = 0;
            HEAP32[$76>>2] = 0;
            HEAP32[$77>>2] = 0;
            HEAP32[$78>>2] = 0;
            HEAP32[$buf1>>2] = ((404640 + 8|0));
            $135 = HEAP16[$hitFlags>>1]|0;
            HEAP16[$1>>1] = $135;
            $136 = (__ZNK5physx13NpVolumeCache10multiQueryINS_12PxOverlapHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$buf1,$1,$filterData,0,$inflation)|0);
            if ($136) {
             ;HEAP32[$79+0>>2]=HEAP32[$80+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$80+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$80+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$80+12>>2]|0;
             HEAP8[$2>>0] = 1;
            }
            $137 = HEAP32[$3>>2]|0;
            $138 = HEAP32[$68>>2]|0;
            $139 = ($137|0)==($138|0);
            if (!($139)) {
             $145 = $137;
             break;
            }
            $140 = HEAP32[$hitCall>>2]|0;
            $141 = HEAP32[$140>>2]|0;
            $142 = HEAP32[$81>>2]|0;
            $143 = (FUNCTION_TABLE_iiii[$141 & 2047]($hitCall,$142,$137)|0);
            if (!($143)) {
             label = 57;
             break L24;
            }
            HEAP32[$3>>2] = 0;
            $145 = 0;
           } else {
            $145 = $133;
           }
          } while(0);
          $144 = (($145) + 1)|0;
          HEAP32[$3>>2] = $144;
          $146 = HEAP32[$81>>2]|0;
          $147 = (($146) + ($145<<4)|0);
          ;HEAP32[$147+0>>2]=HEAP32[$subHits$0+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$subHits$0+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$subHits$0+8>>2]|0;HEAP32[$147+12>>2]=HEAP32[$subHits$0+12>>2]|0;
          $203 = $129;
          break;
         }
         $148 = $122 & 8;
         $149 = ($148<<16>>16)==(0);
         if ($149) {
          $hitType$0 = $101;
         } else {
          $150 = HEAP32[$filterCall>>2]|0;
          $151 = (($150) + 4|0);
          $152 = HEAP32[$151>>2]|0;
          $153 = (FUNCTION_TABLE_iiii[$152 & 2047]($filterCall,$filterData,$subHits$0)|0);
          $hitType$0 = $153;
         }
         $154 = HEAP16[$4>>1]|0;
         $155 = $154 & 16;
         $$not = ($155<<16>>16)==(0);
         $156 = ($hitType$0|0)==(0);
         $or$cond3 = $$not | $156;
         if (!($or$cond3)) {
          label = 48;
          break L24;
         }
         $$hitType$0 = $67 ? 1 : $hitType$0;
         if ((($$hitType$0|0) == 2)) {
          $183 = !($129 >= Math_fround(-1.0));
          if ($183) {
           $203 = $129;
           break;
          }
          ;HEAP32[$79+0>>2]=HEAP32[$subHits$0+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$subHits$0+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$subHits$0+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$subHits$0+12>>2]|0;
          HEAP8[$2>>0] = 1;
          $203 = Math_fround(-1.0);
          break;
         } else if (!((($$hitType$0|0) == 1))) {
          $203 = $129;
          break;
         }
         $160 = HEAP32[$68>>2]|0;
         $161 = ($160|0)==(0);
         $162 = !($129 >= Math_fround(-1.0));
         $or$cond12 = $161 | $162;
         if ($or$cond12) {
          $203 = $129;
         } else {
          $163 = HEAP32[$3>>2]|0;
          $164 = ($163|0)==($160|0);
          do {
           if ($164) {
            HEAP32[$72>>2] = 0;
            HEAP32[$73>>2] = 0;
            HEAP32[$74>>2] = -1;
            HEAP8[$75>>0] = 0;
            HEAP32[$76>>2] = 0;
            HEAP32[$77>>2] = 0;
            HEAP32[$78>>2] = 0;
            HEAP32[$buf1>>2] = ((404640 + 8|0));
            $165 = HEAP16[$hitFlags>>1]|0;
            HEAP16[$1>>1] = $165;
            $166 = (__ZNK5physx13NpVolumeCache10multiQueryINS_12PxOverlapHitEEEbRKNS_15MultiQueryInputERNS_13PxHitCallbackIT_EENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf($this,$input,$buf1,$1,$filterData,$filterCall,$inflation)|0);
            if ($166) {
             ;HEAP32[$79+0>>2]=HEAP32[$80+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$80+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$80+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$80+12>>2]|0;
             HEAP8[$2>>0] = 1;
            }
            $167 = HEAP32[$3>>2]|0;
            $168 = HEAP32[$68>>2]|0;
            $169 = ($167|0)==($168|0);
            if (!($169)) {
             $180 = $167;
             break;
            }
            $170 = HEAP32[$hitCall>>2]|0;
            $171 = HEAP32[$170>>2]|0;
            $172 = HEAP32[$81>>2]|0;
            $173 = (FUNCTION_TABLE_iiii[$171 & 2047]($hitCall,$172,$167)|0);
            if (!($173)) {
             label = 57;
             break L24;
            }
            HEAP32[$3>>2] = 0;
            $180 = 0;
           } else {
            $180 = $163;
           }
          } while(0);
          $179 = (($180) + 1)|0;
          HEAP32[$3>>2] = $179;
          $181 = HEAP32[$81>>2]|0;
          $182 = (($181) + ($180<<4)|0);
          ;HEAP32[$182+0>>2]=HEAP32[$subHits$0+0>>2]|0;HEAP32[$182+4>>2]=HEAP32[$subHits$0+4>>2]|0;HEAP32[$182+8>>2]=HEAP32[$subHits$0+8>>2]|0;HEAP32[$182+12>>2]=HEAP32[$subHits$0+12>>2]|0;
          $203 = $129;
         }
        } else {
         $203 = $129;
        }
       }
      }
     } while(0);
     $184 = (($iCachedShape$026) + 1)|0;
     $185 = ($184>>>0)<($83>>>0);
     if ($185) {
      $129 = $203;$iCachedShape$026 = $184;
     } else {
      $$lcssa21 = $203;
      break;
     }
    }
   }
   $186 = (($isDynamic1$029) + 1)|0;
   $187 = ($186>>>0)<(2);
   if (!($187)) {
    label = 64;
    break;
   }
   $$phi$trans$insert = (($cacheSize) + ($186<<2)|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $202 = $$lcssa21;$83 = $$pre;$isDynamic1$029 = $186;
  }
  if ((label|0) == 48) {
   ;HEAP32[$79+0>>2]=HEAP32[$subHits$0+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$subHits$0+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$subHits$0+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$subHits$0+12>>2]|0;
   $157 = HEAP32[$hitCall>>2]|0;
   $158 = (($157) + 4|0);
   $159 = HEAP32[$158>>2]|0;
   FUNCTION_TABLE_vi[$159 & 4095]($hitCall);
   HEAP8[$2>>0] = 1;
   $$7 = 1;
  }
  else if ((label|0) == 57) {
   $174 = HEAP32[$hitCall>>2]|0;
   $175 = (($174) + 4|0);
   $176 = HEAP32[$175>>2]|0;
   FUNCTION_TABLE_vi[$176 & 4095]($hitCall);
   $177 = HEAP8[$2>>0]|0;
   $178 = ($177<<24>>24)!=(0);
   $$7 = $178;
  }
  else if ((label|0) == 64) {
   $188 = HEAP8[$2>>0]|0;
   $189 = ($188<<24>>24)==(0);
   $$pr = HEAP32[$3>>2]|0;
   $190 = ($$pr|0)==(0);
   if ($189) {
    if (!($190)) {
     label = 68;
    }
   } else {
    if (!($190)) {
     HEAP32[$3>>2] = $$pr;
     label = 68;
    }
   }
   if ((label|0) == 68) {
    $191 = HEAP32[$hitCall>>2]|0;
    $192 = HEAP32[$191>>2]|0;
    $193 = HEAP32[$81>>2]|0;
    $194 = (FUNCTION_TABLE_iiii[$192 & 2047]($hitCall,$193,$$pr)|0);
    if ($194) {
     HEAP32[$3>>2] = 0;
    }
   }
   $195 = HEAP32[$hitCall>>2]|0;
   $196 = (($195) + 4|0);
   $197 = HEAP32[$196>>2]|0;
   FUNCTION_TABLE_vi[$197 & 4095]($hitCall);
   $198 = HEAP8[$2>>0]|0;
   $199 = ($198<<24>>24)!=(0);
   $$7 = $199;
  }
  $200 = ($201|0)==(0|0);
  if ($200) {
   $$8 = $$7;
   STACKTOP = sp;return ($$8|0);
  }
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($vararg_buffer,$201);
  $$8 = $$7;
  STACKTOP = sp;return ($$8|0);
 }
 if ((label|0) == 11) {
  $30 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($30,128,439376,599,439632,$vararg_buffer);
 }
 $31 = HEAP32[$6>>2]|0;
 $32 = (__ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($31)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 356|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($input) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($input) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_iiiiiii[$35 & 255]($32,$37,$39,$hitCall,$filterData,$filterCall)|0);
 $40 = HEAP8[$2>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if (!($41)) {
  $$8 = 1;
  STACKTOP = sp;return ($$8|0);
 }
 $42 = HEAP32[$3>>2]|0;
 $43 = ($42|0)!=(0);
 $$8 = $43;
 STACKTOP = sp;return ($$8|0);
}
function __ZN5physx13NpVolumeCache13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$shift>>2]);
 $1 = (($this) + 60|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($2 - $0);
 HEAPF32[$1>>2] = $3;
 $4 = (($shift) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 64|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 - $5);
 HEAPF32[$6>>2] = $8;
 $9 = (($shift) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 68|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 - $10);
 HEAPF32[$11>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN5physxL20applyAllPreFiltersVCEPNS_12PxActorShapeERNS_14PxQueryHitType4EnumERKNS_7PxFlagsINS_11PxQueryFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackERKNS_7NpSceneERNS5_INS_9PxHitFlag4EnumEtEE($as,$hitType,$inFilterFlags,$filterData,$filterCall,$scene,$hitFlags) {
 $as = $as|0;
 $hitType = $hitType|0;
 $inFilterFlags = $inFilterFlags|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $scene = $scene|0;
 $hitFlags = $hitFlags|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $outHitFlags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp + 2|0;
 $outHitFlags = sp;
 $2 = (($filterData) + 18|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = HEAP32[$as>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $9 = ($3<<24>>24)==($8<<24>>24);
 if (!($9)) {
  $10 = HEAP32[$scene>>2]|0;
  $11 = (($10) + 136|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP8[$2>>0]|0;
  FUNCTION_TABLE_viii[$12 & 4095]($0,$scene,$13);
  $14 = HEAP8[$0>>0]|0;
  $15 = HEAP32[$as>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 76|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vii[$18 & 4095]($1,$15);
  $19 = HEAP8[$1>>0]|0;
  $20 = $14 & 8;
  $21 = $20 & $19;
  $22 = ($21<<24>>24)==(0);
  if ($22) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $23 = HEAP32[$filterData>>2]|0;
 $24 = (($filterData) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 | $23;
 $27 = (($filterData) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $26 | $28;
 $30 = (($filterData) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $29 | $31;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = (($as) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + 48|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = $37 & $23;
  $39 = (($35) + 52|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & $25;
  $42 = $41 | $38;
  $43 = (($35) + 56|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & $28;
  $46 = $42 | $45;
  $47 = (($35) + 60|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = $48 & $31;
  $50 = $46 | $49;
  $51 = ($50|0)==(0);
  if ($51) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $52 = ($filterCall|0)==(0|0);
 if ($52) {
  $$0 = $as;
  STACKTOP = sp;return ($$0|0);
 }
 $53 = HEAP16[$inFilterFlags>>1]|0;
 $54 = $53 & 4;
 $55 = ($54<<16>>16)==(0);
 if ($55) {
  $$0 = $as;
  STACKTOP = sp;return ($$0|0);
 }
 $56 = HEAP16[$hitFlags>>1]|0;
 HEAP16[$outHitFlags>>1] = $56;
 $57 = HEAP32[$filterCall>>2]|0;
 $58 = HEAP32[$57>>2]|0;
 $59 = (($as) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$as>>2]|0;
 $62 = (FUNCTION_TABLE_iiiiii[$58 & 255]($filterCall,$filterData,$60,$61,$outHitFlags)|0);
 HEAP32[$hitType>>2] = $62;
 $63 = HEAP16[$hitFlags>>1]|0;
 $64 = $63 & -433;
 $65 = HEAP16[$outHitFlags>>1]|0;
 $66 = $65&65535;
 $67 = $66 & 432;
 $68 = $67&65535;
 $69 = $68 | $64;
 HEAP16[$hitFlags>>1] = $69;
 $$0 = $as;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 439824 : 439792;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,439712,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd5ArrayINS_12PxActorShapeENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 439824 : 439792;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,439712,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = $$03$i;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = $$012$i;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
   }
   $30 = (($$012$i) + 8|0);
   $31 = (($$03$i) + 8|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx23NpVolumeCacheSqCallback14processTouchesEPKNS_12PxOverlapHitEj($this,$buffer,$nbHits) {
 $this = $this|0;
 $buffer = $buffer|0;
 $nbHits = $nbHits|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $4 = (($this) + 44|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7) + ($5<<2)|0) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9>>>0)<($nbHits>>>0);
  if (!($10)) {
   (__ZN5physx13NpVolumeCache12fillInternalEjPKNS_12PxOverlapHitEi($7,$5,$buffer,$nbHits)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $3 = ($nbHits|0)==(0);
 $$pre = (($this) + 48|0);
 if (!($3)) {
  $j$01 = 0;
  while(1) {
   $11 = (($buffer) + ($j$01<<4)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$$pre>>2]|0;
   $14 = (($13) + ($j$01<<3)|0);
   HEAP32[$14>>2] = $12;
   $15 = ((($buffer) + ($j$01<<4)|0) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$$pre>>2]|0;
   $18 = ((($17) + ($j$01<<3)|0) + 4|0);
   HEAP32[$18>>2] = $16;
   $19 = (($j$01) + 1)|0;
   $exitcond = ($19|0)==($nbHits|0);
   if ($exitcond) {
    break;
   } else {
    $j$01 = $19;
   }
  }
 }
 $20 = (($this) + 40|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$$pre>>2]|0;
 FUNCTION_TABLE_viii[$23 & 4095]($21,$nbHits,$24);
 HEAP8[$0>>0] = 1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx23NpVolumeCacheSqCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpParticleFluidC2Ejb($this,$maxParticles,$perParticleRestOffset) {
 $this = $this|0;
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = 3;
 $1 = (($this) + 4|0);
 HEAP16[$1>>1] = 12;
 $2 = (($this) + 6|0);
 HEAP16[$2>>1] = 3;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((442176 + 8|0));
 $4 = (($this) + 12|0);
 __ZN5physx7NpActorC2EPKc($4,0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((441600 + 8|0));
 $5 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemC2ERKNS_11PxActorType4EnumEjb($5,$0,$maxParticles,$perParticleRestOffset);
 HEAP32[$this>>2] = ((439960 + 8|0));
 STACKTOP = sp;return;
}
function __ZN5physx15NpParticleFluidD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((441600 + 8|0));
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemD2Ev($1);
 HEAP32[$this>>2] = ((441888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpParticleFluidD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((441600 + 8|0));
 $0 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemD2Ev($0);
 HEAP32[$this>>2] = ((441888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __Z20NpGetNxParticleFluidRN5physx2Sc18ParticleSystemCoreE($ps) {
 $ps = $ps|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ps) + -32|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx15NpParticleFluid25lockParticleFluidReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$flags>>0]|0;
 HEAP8[$0>>0] = $4;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($this,$0)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx15NpParticleFluid25lockParticleFluidReadDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx15NpParticleFluid2isENS_11PxActorType4EnumE($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $$0 = 0, $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($type|0)==(3);
 if ($0) {
  $$0 = $this;
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx15NpParticleFluid2isENS_11PxActorType4EnumE($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $$0 = 0, $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($type|0)==(3);
 if ($0) {
  $$0 = $this;
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx15NpParticleFluid12getStiffnessEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore12getStiffnessEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 4|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx15NpParticleFluid12setStiffnessEf($this,$s) {
 $this = $this|0;
 $s = Math_fround($s);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore12setStiffnessEf($1,$s);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 4|0);
 HEAPF32[$16>>2] = $s;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 32;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpParticleFluid12getViscosityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore12getViscosityEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 8|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx15NpParticleFluid12setViscosityEf($this,$v) {
 $this = $this|0;
 $v = Math_fround($v);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore12setViscosityEf($1,$v);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 8|0);
 HEAPF32[$16>>2] = $v;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 64;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpParticleFluid23getRestParticleDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore23getRestParticleDistanceEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx15NpParticleFluid23setRestParticleDistanceEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  label = 2;
 } else if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore23setRestParticleDistanceEf($8,$r);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (($this) + 12|0);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($3,$this);
 $4 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $8 = (($this) + 20|0);
  __ZN5physx3Scb4Base7destroyEv($8);
  STACKTOP = sp;return;
 }
 __ZN5physx7NpScene26removeFromParticleBaseListERNS_14PxParticleBaseE($4,$this);
 $6 = (($4) + 16|0);
 $7 = (($this) + 20|0);
 __ZN5physx3Scb5Scene20removeParticleSystemERNS0_14ParticleSystemEb($6,$7,1);
 $8 = (($this) + 20|0);
 __ZN5physx3Scb4Base7destroyEv($8);
 STACKTOP = sp;return;
}
function __ZNK5physx15PxParticleFluid19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (442488|0);
}
function __ZNK5physx15PxParticleFluid8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(442488,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $8 = 1;
 } else {
  $2 = (_strcmp(442456,$name)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $8 = 1;
  } else {
   $4 = (_strcmp(442472,$name)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $8 = 1;
   } else {
    $6 = (_strcmp($name,442480)|0);
    $7 = ($6|0)==(0);
    $8 = $7;
   }
  }
 }
 STACKTOP = sp;return ($8|0);
}
function __ZNK5physx15NpParticleFluid7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 3;
}
function __ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE7setNameEPKc($this,$debugName) {
 $this = $this|0;
 $debugName = $debugName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $debugName;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14getWorldBoundsEf($agg$result,$this,$inflation) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inflation = Math_fround($inflation);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bounds = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $bounds = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 4;
  } else {
   label = 3;
  }
 } else if ((($2|0) == 3)) {
  label = 3;
 } else {
  label = 4;
 }
 if ((label|0) == 3) {
  $8 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($8,2,440896,452,440984,$vararg_buffer);
 }
 else if ((label|0) == 4) {
  $9 = (($this) + 32|0);
  __ZNK5physx2Sc18ParticleSystemCore14getWorldBoundsEv($bounds,$9);
 }
 $10 = Math_fround(HEAPF32[$bounds>>2]);
 $11 = (($bounds) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = (($bounds) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($bounds) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 + $17);
 $19 = (($bounds) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($bounds) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 + $22);
 $24 = Math_fround($13 * Math_fround(0.5));
 $25 = Math_fround($18 * Math_fround(0.5));
 $26 = Math_fround($23 * Math_fround(0.5));
 $27 = Math_fround($12 - $10);
 $28 = Math_fround($17 - $15);
 $29 = Math_fround($22 - $20);
 $30 = Math_fround($27 * Math_fround(0.5));
 $31 = Math_fround($28 * Math_fround(0.5));
 $32 = Math_fround($29 * Math_fround(0.5));
 $33 = Math_fround($30 * $inflation);
 $34 = Math_fround($31 * $inflation);
 $35 = Math_fround($32 * $inflation);
 $36 = Math_fround($24 - $33);
 $37 = Math_fround($25 - $34);
 $38 = Math_fround($26 - $35);
 $39 = Math_fround($24 + $33);
 $40 = Math_fround($25 + $34);
 $41 = Math_fround($26 + $35);
 HEAPF32[$agg$result>>2] = $36;
 $42 = (($agg$result) + 4|0);
 HEAPF32[$42>>2] = $37;
 $43 = (($agg$result) + 8|0);
 HEAPF32[$43>>2] = $38;
 $44 = (($agg$result) + 12|0);
 HEAPF32[$44>>2] = $39;
 $45 = (($agg$result) + 16|0);
 HEAPF32[$45>>2] = $40;
 $46 = (($agg$result) + 20|0);
 HEAPF32[$46>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $8 = $7;
 $$sum$i = (($6) + 4)|0;
 $9 = (($this) + ($$sum$i)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 24;
 $12 = $11 & 15;
 $13 = ((444424 + ($12<<2)|0) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($8))|0;
 $16 = $15;
 $17 = $10 >>> 30;
 if ((($17|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $7;
 } else if ((($17|0) == 2)) {
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 2417|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $7;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $1;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($16,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($6) + 8)|0;
 $22 = (($this) + ($$sum1$i)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$12)|0);
  HEAP32[$22>>2] = $26;
  $27 = $26;
 } else {
  $27 = $23;
 }
 HEAP16[$27>>1] = $1;
 $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$7);
 $29 = HEAP32[$9>>2]|0;
 $30 = $29 | 1;
 HEAP32[$9>>2] = $30;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE13getActorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $27 = HEAP16[$26>>1]|0;
  HEAP16[$agg$result>>1] = $27;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = HEAP16[$18>>1]|0;
 HEAP16[$agg$result>>1] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE17setDominanceGroupEh($this,$dominanceGroup) {
 $this = $this|0;
 $dominanceGroup = $dominanceGroup|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = $8 >>> 30;
 if ((($15|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($15|0) == 2)) {
  $16 = HEAP32[$5>>2]|0;
  $17 = (($16) + 2417|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc9ActorCore17setDominanceGroupEh($14,$dominanceGroup);
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $20 = (($this) + ($$sum1)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $23 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $24 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($23,$10)|0);
  HEAP32[$20>>2] = $24;
  $26 = $24;
 } else {
  $26 = $21;
 }
 $25 = (($26) + 2|0);
 HEAP8[$25>>0] = $dominanceGroup;
 $27 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($27,$5);
 $28 = HEAP32[$7>>2]|0;
 $29 = $28 | 2;
 HEAP32[$7>>2] = $29;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE17getDominanceGroupEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 12|0);
  $$in$i$i$i = $26;
  $27 = HEAP8[$$in$i$i$i>>0]|0;
  STACKTOP = sp;return ($27|0);
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 2|0);
 $$in$i$i$i = $17;
 $27 = HEAP8[$$in$i$i$i>>0]|0;
 STACKTOP = sp;return ($27|0);
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE14setOwnerClientEh($this,$inId) {
 $this = $this|0;
 $inId = $inId|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,440608,198,440688,$vararg_buffer1);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = ((414264 + ($5<<2)|0) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + ($7)|0);
 $$sum = (($7) + 4)|0;
 $9 = (($this) + ($$sum)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 3)) {
  label = 6;
 } else if ((($11|0) == 2)) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 5;
  } else {
   label = 6;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = $8;
  $17 = $10 >>> 24;
  $18 = $17 & 15;
  $19 = ((444424 + ($18<<2)|0) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($16))|0;
  $22 = $21;
  $23 = (($22) + 13|0);
  HEAP8[$23>>0] = $inId;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $24 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($24,8,440760,153,440840,$vararg_buffer1);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE14getOwnerClientEv($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = (($14) + 13|0);
 $16 = HEAP8[$15>>0]|0;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$bits) {
 $this = $this|0;
 $bits = $bits|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = HEAP8[$bits>>0]|0;
 $7 = $5;
 $$sum = (($4) + 4)|0;
 $8 = (($this) + ($$sum)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($7))|0;
 $15 = $14;
 $16 = $9 >>> 30;
 if ((($16|0) == 2)) {
  $17 = HEAP32[$5>>2]|0;
  $18 = (($17) + 2417|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else if ((($16|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $21 = (($15) + 11|0);
  HEAP8[$21>>0] = $6;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $22 = (($this) + ($$sum1)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$11)|0);
  HEAP32[$22>>2] = $26;
  $28 = $26;
 } else {
  $28 = $23;
 }
 $27 = (($28) + 3|0);
 HEAP8[$27>>0] = $6;
 $29 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($29,$5);
 $30 = HEAP32[$8>>2]|0;
 $31 = $30 | 4;
 HEAP32[$8>>2] = $31;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE22getClientBehaviorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $20 = $7 >>> 24;
  $21 = $20 & 15;
  $22 = ((444424 + ($21<<2)|0) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $5;
  $25 = (($23) + ($24))|0;
  $26 = $25;
  $27 = (($26) + 11|0);
  $28 = HEAP8[$27>>0]|0;
  HEAP8[$agg$result>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 3|0);
 $19 = HEAP8[$17>>0]|0;
 HEAP8[$agg$result>>0] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE12getAggregateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor12getAggregateEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$flags>>0]|0;
 HEAP8[$0>>0] = $2;
 $3 = (__ZN5physx3Scb14ParticleSystem20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($1,$0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20lockParticleReadDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 HEAP8[$0>>0] = 1;
 $2 = (__ZN5physx3Scb14ParticleSystem20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($1,$0)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE15createParticlesERKNS_22PxParticleCreationDataE($this,$creationData) {
 $this = $this|0;
 $creationData = $creationData|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$creationData>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 32768;
 $7 = ($6|0)==(0);
 if ($7) {
  $18 = (($this) + 32|0);
  __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($0,$18);
 } else {
  $8 = (($this) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $11 = HEAP32[$3>>2]|0;
   $12 = $5 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$8>>2] = $14;
   $16 = $14;
  } else {
   $16 = $9;
  }
  $15 = (($16) + 76|0);
  $17 = HEAP16[$15>>1]|0;
  HEAP16[$0>>1] = $17;
 }
 $19 = (__ZN5physx3Scb14ParticleSystem15createParticlesERKNS_22PxParticleCreationDataE($3,$creationData)|0);
 $$0 = $19;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE($this,$numParticles,$indices) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numParticles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE($1,$numParticles,$indices);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE16releaseParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem16releaseParticlesEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEE($this,$numParticles,$indexBuffer,$positionBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $positionBuffer = $positionBuffer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numParticles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($1,$numParticles,$indexBuffer,$positionBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEE($this,$numParticles,$indexBuffer,$velocityBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $velocityBuffer = $velocityBuffer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numParticles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($1,$numParticles,$indexBuffer,$velocityBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS4_IKfEE($this,$numParticles,$indexBuffer,$restOffsetBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $restOffsetBuffer = $restOffsetBuffer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numParticles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKfEE($1,$numParticles,$indexBuffer,$restOffsetBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE9addForcesEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEENS_11PxForceMode4EnumE($this,$numParticles,$indexBuffer,$forceBuffer,$forceMode) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $forceBuffer = $forceBuffer|0;
 $forceMode = $forceMode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,440264,436,440528,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $3 = ($numParticles|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem9addForcesEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEENS_11PxForceMode4EnumE($4,$numParticles,$indexBuffer,$forceBuffer,$forceMode);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE10getDampingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 128;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore10getDampingEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 12|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE10setDampingEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore10setDampingEf($1,$d);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 12|0);
 HEAPF32[$16>>2] = $d;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 128;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23getExternalAccelerationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 256;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 32|0);
  $15 = (__ZNK5physx2Sc18ParticleSystemCore23getExternalAccelerationEv($14)|0);
  $17 = $15;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 16|0);
  $17 = $12;
 }
 $16 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$agg$result>>2] = $16;
 $18 = (($agg$result) + 4|0);
 $19 = (($17) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$18>>2] = $20;
 $21 = (($agg$result) + 8|0);
 $22 = (($17) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 HEAPF32[$21>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23setExternalAccelerationERKNS_6PxVec3E($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore23setExternalAccelerationERKNS_6PxVec3E($1,$a);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $18 = $15;
 } else {
  $18 = $10;
 }
 $16 = Math_fround(HEAPF32[$a>>2]);
 $17 = (($18) + 16|0);
 HEAPF32[$17>>2] = $16;
 $19 = (($a) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($18) + 20|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($a) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($18) + 24|0);
 HEAPF32[$24>>2] = $23;
 $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($25,$0);
 $26 = HEAP32[$2>>2]|0;
 $27 = $26 | 256;
 HEAP32[$2>>2] = $27;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE18getProjectionPlaneERNS_6PxVec3ERf($this,$normal,$d) {
 $this = $this|0;
 $normal = $normal|0;
 $d = $d|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 512;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 32|0);
  $15 = (__ZNK5physx2Sc18ParticleSystemCore18getProjectionPlaneEv($14)|0);
  $17 = $15;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 28|0);
  $17 = $12;
 }
 $16 = Math_fround(HEAPF32[$17>>2]);
 $18 = (($17) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($17) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($17) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 HEAPF32[$normal>>2] = $16;
 $24 = (($normal) + 4|0);
 HEAPF32[$24>>2] = $19;
 $25 = (($normal) + 8|0);
 HEAPF32[$25>>2] = $21;
 HEAPF32[$d>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE18setProjectionPlaneERKNS_6PxVec3Ef($this,$normal,$d) {
 $this = $this|0;
 $normal = $normal|0;
 $d = Math_fround($d);
 var $$pre = Math_fround(0), $$pre$phi$i$iZ2D = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $p = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $p = sp;
 $0 = Math_fround(HEAPF32[$normal>>2]);
 HEAPF32[$p>>2] = $0;
 $1 = (($p) + 4|0);
 $2 = (($normal) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$1>>2] = $3;
 $4 = (($p) + 8|0);
 $5 = (($normal) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($p) + 12|0);
 HEAPF32[$7>>2] = $d;
 $8 = (($this) + 20|0);
 $9 = (($this) + 32|0);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 3)) {
  $$pre$phi$i$iZ2D = $8;
 } else if ((($12|0) == 2)) {
  $13 = HEAP32[$8>>2]|0;
  $14 = (($13) + 2417|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $8;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore18setProjectionPlaneERKNS_7PxPlaneE($9,$p);
  STACKTOP = sp;return;
 }
 $17 = (($this) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $20 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $21 = $11 >>> 24;
  $22 = $21 & 15;
  $23 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($20,$22)|0);
  HEAP32[$17>>2] = $23;
  $$pre = Math_fround(HEAPF32[$p>>2]);
  $25 = $23;$26 = $$pre;
 } else {
  $25 = $18;$26 = $0;
 }
 $24 = (($25) + 28|0);
 HEAPF32[$24>>2] = $26;
 $27 = Math_fround(HEAPF32[$1>>2]);
 $28 = (($25) + 32|0);
 HEAPF32[$28>>2] = $27;
 $29 = Math_fround(HEAPF32[$4>>2]);
 $30 = (($25) + 36|0);
 HEAPF32[$30>>2] = $29;
 $31 = Math_fround(HEAPF32[$7>>2]);
 $32 = (($25) + 40|0);
 HEAPF32[$32>>2] = $31;
 $33 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($33,$8);
 $34 = HEAP32[$10>>2]|0;
 $35 = $34 | 512;
 HEAP32[$10>>2] = $35;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE15getParticleMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1024;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore15getParticleMassEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 44|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE15setParticleMassEf($this,$m) {
 $this = $this|0;
 $m = Math_fround($m);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore15setParticleMassEf($1,$m);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 44|0);
 HEAPF32[$16>>2] = $m;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 1024;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14getRestitutionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2048;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore14getRestitutionEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 48|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14setRestitutionEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore14setRestitutionEf($1,$r);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 48|0);
 HEAPF32[$16>>2] = $r;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 2048;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE18getDynamicFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore18getDynamicFrictionEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 52|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE18setDynamicFrictionEf($this,$a) {
 $this = $this|0;
 $a = Math_fround($a);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore18setDynamicFrictionEf($1,$a);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 52|0);
 HEAPF32[$16>>2] = $a;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 4096;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE17getStaticFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 8192;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore17getStaticFrictionEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 56|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE17setStaticFrictionEf($this,$a) {
 $this = $this|0;
 $a = Math_fround($a);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore17setStaticFrictionEf($1,$a);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 56|0);
 HEAPF32[$16>>2] = $a;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 8192;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23setSimulationFilterDataERKNS_12PxFilterDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore23setSimulationFilterDataERKNS_12PxFilterDataE($1,$data);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 60|0);
 ;HEAP32[$16+0>>2]=HEAP32[$data+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$data+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$data+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$data+12>>2]|0;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 16384;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23getSimulationFilterDataEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16384;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 32|0);
  $15 = (__ZNK5physx2Sc18ParticleSystemCore23getSimulationFilterDataEv($14)|0);
  $16 = $15;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 60|0);
  $16 = $12;
 }
 ;HEAP32[$agg$result+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$16+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14resetFilteringEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($0,1,440264,611,440456,$vararg_buffer);
 $1 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 212|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($1,$this);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE19setParticleBaseFlagENS_18PxParticleBaseFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $flags = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $flags = sp + 4|0;
 $0 = ($flag|0)==(16);
 if ($0) {
  $1 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($1,2,440264,627,440360,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $2 = (($this) + 20|0);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 32768;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = (($this) + 32|0);
  __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($flags,$17);
 } else {
  $7 = (($this) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = $4 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($10,$12)|0);
   HEAP32[$7>>2] = $13;
   $15 = $13;
  } else {
   $15 = $8;
  }
  $14 = (($15) + 76|0);
  $16 = HEAP16[$14>>1]|0;
  HEAP16[$flags>>1] = $16;
 }
 if ($value) {
  $18 = HEAP16[$flags>>1]|0;
  $19 = $18&65535;
  $20 = $19 | $flag;
  $21 = $20&65535;
  HEAP16[$flags>>1] = $21;
  $33 = $21;
 } else {
  $22 = $flag ^ 65535;
  $23 = $22&65535;
  $24 = HEAP16[$flags>>1]|0;
  $25 = $24 & $23;
  HEAP16[$flags>>1] = $25;
  $33 = $25;
 }
 $26 = (($this) + 32|0);
 $27 = HEAP32[$3>>2]|0;
 $28 = $27 >>> 30;
 if ((($28|0) == 3)) {
  $$pre$phi$i$iZ2D = $2;
  label = 15;
 } else if ((($28|0) == 2)) {
  $29 = HEAP32[$2>>2]|0;
  $30 = (($29) + 2417|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   label = 14;
  } else {
   $$pre$phi$i$iZ2D = $2;
   label = 15;
  }
 } else {
  label = 14;
 }
 if ((label|0) == 14) {
  HEAP16[$vararg_buffer>>1] = $33;
  __ZN5physx2Sc18ParticleSystemCore8setFlagsENS_7PxFlagsINS_18PxParticleBaseFlag4EnumEtEE($26,$vararg_buffer);
 }
 else if ((label|0) == 15) {
  $34 = (($this) + 28|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   $37 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $38 = $27 >>> 24;
   $39 = $38 & 15;
   $40 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($37,$39)|0);
   HEAP32[$34>>2] = $40;
   $42 = $40;
  } else {
   $42 = $35;
  }
  $41 = (($42) + 76|0);
  HEAP16[$41>>1] = $33;
  $43 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($43,$2);
  $44 = HEAP32[$3>>2]|0;
  $45 = $44 | 32768;
  HEAP32[$3>>2] = $45;
 }
 $46 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $47 = ($46|0)==(0|0);
 if ($47) {
  STACKTOP = sp;return;
 }
 (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20getParticleBaseFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32768;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($agg$result,$15);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 76|0);
 $14 = HEAP16[$12>>1]|0;
 HEAP16[$agg$result>>1] = $14;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE15getMaxParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc18ParticleSystemCore15getMaxParticlesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20getMaxMotionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore20getMaxMotionDistanceEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20setMaxMotionDistanceEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  label = 2;
 } else if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore20setMaxMotionDistanceEf($8,$d);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE13getRestOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore13getRestOffsetEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE13setRestOffsetEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  label = 2;
 } else if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore13setRestOffsetEf($8,$r);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE16getContactOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore16getContactOffsetEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE16setContactOffsetEf($this,$c) {
 $this = $this|0;
 $c = Math_fround($c);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  label = 2;
 } else if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore16setContactOffsetEf($8,$c);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE11getGridSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore11getGridSizeEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE11setGridSizeEf($this,$g) {
 $this = $this|0;
 $g = Math_fround($g);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 } else if ((($2|0) == 2)) {
  label = 2;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore11setGridSizeEf($8,$g);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE24getParticleReadDataFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23setParticleReadDataFlagENS_22PxParticleReadDataFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $flags = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $flags = sp;
 $1 = (($this) + 32|0);
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($flags,$1);
 if ($value) {
  $2 = HEAP16[$flags>>1]|0;
  $3 = $2&65535;
  $4 = $3 | $flag;
  $5 = $4&65535;
  HEAP16[$flags>>1] = $5;
  $18 = $5;
 } else {
  $6 = $flag ^ 65535;
  $7 = $6&65535;
  $8 = HEAP16[$flags>>1]|0;
  $9 = $8 & $7;
  HEAP16[$flags>>1] = $9;
  $18 = $9;
 }
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 2)) {
  label = 5;
 } else if ((($12|0) == 3)) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 5) {
  $13 = (($this) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 2417|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
 }
 HEAP16[$0>>1] = $18;
 __ZN5physx2Sc18ParticleSystemCore24setParticleReadDataFlagsENS_7PxFlagsINS_22PxParticleReadDataFlag4EnumEtEE($1,$0);
 STACKTOP = sp;return;
}
function __ZN5physx15NpParticleFluid15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($0,$context);
 STACKTOP = sp;return;
}
function __ZN5physx15NpParticleFluid8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$in = 0, $$in19 = 0, $$pre = 0, $$pre$phi$i$i5Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre22 = 0, $$pre22$pre = 0, $$pre24 = 0, $$pre25 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum20 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = ((414264 + ($3<<2)|0) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + ($5)|0);
 $$sum = (($5) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($value) {
  if ($10) {
   $18 = $8 >>> 24;
   $19 = $18 & 15;
   $20 = ((444424 + ($19<<2)|0) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $6;
   $23 = (($21) + ($22))|0;
   $24 = $23;
   $25 = (($24) + 8|0);
   $$in19 = $25;$$pre$phiZ2D = $22;$31 = $8;
  } else {
   $$sum18 = (($5) + 8)|0;
   $11 = (($this) + ($$sum18)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[$6>>2]|0;
    $15 = $8 >>> 24;
    $16 = $15 & 15;
    $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
    HEAP32[$11>>2] = $17;
    $$pre$pre = HEAP32[$7>>2]|0;
    $$pre = $$pre$pre;$91 = $17;
   } else {
    $$pre = $8;$91 = $12;
   }
   $$pre24 = $6;
   $$in19 = $91;$$pre$phiZ2D = $$pre24;$31 = $$pre;
  }
  $26 = HEAP16[$$in19>>1]|0;
  $27 = $26&65535;
  $28 = $27 | $flag;
  $29 = $28&65535;
  $30 = $31 >>> 24;
  $32 = $30 & 15;
  $33 = ((444424 + ($32<<2)|0) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($$pre$phiZ2D))|0;
  $36 = $35;
  $37 = $31 >>> 30;
  if ((($37|0) == 3)) {
   $$pre$phi$i$i5Z2D = $6;
  } else if ((($37|0) == 2)) {
   $38 = HEAP32[$6>>2]|0;
   $39 = (($38) + 2417|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    label = 10;
   } else {
    $$pre$phi$i$i5Z2D = $6;
   }
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $29;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($36,$0);
   STACKTOP = sp;return;
  }
  $$sum20 = (($5) + 8)|0;
  $42 = (($this) + ($$sum20)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   $45 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
   $46 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($45,$32)|0);
   HEAP32[$42>>2] = $46;
   $47 = $46;
  } else {
   $47 = $43;
  }
  HEAP16[$47>>1] = $29;
  $48 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($48,$6);
  $49 = HEAP32[$7>>2]|0;
  $50 = $49 | 1;
  HEAP32[$7>>2] = $50;
  STACKTOP = sp;return;
 } else {
  if ($10) {
   $58 = $8 >>> 24;
   $59 = $58 & 15;
   $60 = ((444424 + ($59<<2)|0) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $6;
   $63 = (($61) + ($62))|0;
   $64 = $63;
   $65 = (($64) + 8|0);
   $$in = $65;$$pre$phi26Z2D = $62;$71 = $8;
  } else {
   $$sum16 = (($5) + 8)|0;
   $51 = (($this) + ($$sum16)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $54 = HEAP32[$6>>2]|0;
    $55 = $8 >>> 24;
    $56 = $55 & 15;
    $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
    HEAP32[$51>>2] = $57;
    $$pre22$pre = HEAP32[$7>>2]|0;
    $$pre22 = $$pre22$pre;$92 = $57;
   } else {
    $$pre22 = $8;$92 = $52;
   }
   $$pre25 = $6;
   $$in = $92;$$pre$phi26Z2D = $$pre25;$71 = $$pre22;
  }
  $66 = HEAP16[$$in>>1]|0;
  $67 = $flag ^ 65535;
  $68 = $67&65535;
  $69 = $66 & $68;
  $70 = $71 >>> 24;
  $72 = $70 & 15;
  $73 = ((444424 + ($72<<2)|0) + 24|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + ($$pre$phi26Z2D))|0;
  $76 = $75;
  $77 = $71 >>> 30;
  if ((($77|0) == 2)) {
   $78 = HEAP32[$6>>2]|0;
   $79 = (($78) + 2417|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    label = 22;
   } else {
    $$pre$phi$i$iZ2D = $6;
   }
  } else if ((($77|0) == 3)) {
   $$pre$phi$i$iZ2D = $6;
  } else {
   label = 22;
  }
  if ((label|0) == 22) {
   HEAP16[$0>>1] = $69;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($76,$0);
   STACKTOP = sp;return;
  }
  $$sum17 = (($5) + 8)|0;
  $82 = (($this) + ($$sum17)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $85 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $86 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($85,$72)|0);
   HEAP32[$82>>2] = $86;
   $87 = $86;
  } else {
   $87 = $83;
  }
  HEAP16[$87>>1] = $69;
  $88 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($88,$6);
  $89 = HEAP32[$7>>2]|0;
  $90 = $89 | 1;
  HEAP32[$7>>2] = $90;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $$$i$i$i = 0, $$0 = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, $vararg_ptr3 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 8|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 if ((($3|0) == 2)) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   label = 3;
  }
 } else if ((($3|0) == 3)) {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($8,8,440896,313,441104,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($this) + 152|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (__Z15PxGetFoundationv()|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
  $$$i$i$i = $20 ? 441464 : 441432;
  $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,204,$$$i$i$i,440896,319)|0);
  $22 = (($21) + 16|0);
  HEAP32[$22>>2] = 0;
  $23 = (($21) + 20|0);
  HEAP32[$23>>2] = 12;
  $24 = (($21) + 24|0);
  HEAP32[$24>>2] = 0;
  $25 = (($21) + 28|0);
  HEAP32[$25>>2] = 12;
  $26 = (($21) + 32|0);
  HEAP32[$26>>2] = 0;
  $27 = (($21) + 36|0);
  HEAP32[$27>>2] = 4;
  $28 = (($21) + 40|0);
  HEAP32[$28>>2] = 0;
  $29 = (($21) + 44|0);
  HEAP32[$29>>2] = 2;
  $30 = (($21) + 48|0);
  HEAP32[$30>>2] = 0;
  $31 = (($21) + 52|0);
  HEAP32[$31>>2] = 12;
  $32 = (($21) + 56|0);
  HEAP32[$32>>2] = 0;
  $33 = (($21) + 60|0);
  HEAP32[$33>>2] = 12;
  $34 = (($21) + 64|0);
  HEAP32[$34>>2] = 0;
  $35 = (($21) + 68|0);
  HEAP32[$35>>2] = 4;
  HEAP32[$21>>2] = ((441384 + 8|0));
  $36 = (($21) + 72|0);
  HEAP8[$36>>0] = 0;
  $37 = (($21) + 201|0);
  HEAP8[$37>>0] = 1;
  $38 = (($21) + 73|0);
  (_strncpy(($38|0),(441416|0),128)|0);
  HEAP32[$9>>2] = $21;
  $40 = $21;
 } else {
  $40 = $10;
 }
 $39 = (($40) + 72|0);
 $41 = HEAP8[$39>>0]|0;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  $$pre$i = (($40) + 73|0);
  $$pre$phi$iZ2D = $$pre$i;
 } else {
  $43 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  $44 = (($40) + 73|0);
  HEAP32[$vararg_buffer1>>2] = 441168;
  $vararg_ptr3 = (($vararg_buffer1) + 4|0);
  HEAP32[$vararg_ptr3>>2] = $44;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($43,8,441208,67,441304,$vararg_buffer1);
  $$pre$phi$iZ2D = $44;
 }
 (_strncpy(($$pre$phi$iZ2D|0),(441168|0),128)|0);
 $45 = (($40) + 200|0);
 HEAP8[$45>>0] = 0;
 HEAP8[$39>>0] = 1;
 $46 = HEAP32[$9>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 16|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP8[$flags>>0]|0;
 HEAP8[$0>>0] = $50;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$0);
 $51 = (($this) + 12|0);
 $52 = HEAP32[$9>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore19getParticleReadDataERNS_23PxParticleFluidReadDataE($51,$52);
 $53 = HEAP32[$9>>2]|0;
 $$0 = $53;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx23NpParticleFluidReadData18getDataAccessFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 201|0);
 $1 = HEAP8[$0>>0]|0;
 HEAP8[$agg$result>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx23NpParticleFluidReadData6unlockEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23NpParticleFluidReadDataD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx23NpParticleFluidReadDataD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx23NpParticleFluidReadData18setDataAccessFlagsENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 201|0);
 $1 = HEAP8[$flags>>0]|0;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((441600 + 8|0));
 $0 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemD2Ev($0);
 HEAP32[$this>>2] = ((441888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((441600 + 8|0));
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemD2Ev($1);
 HEAP32[$this>>2] = ((441888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2;
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((441888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_15PxParticleFluidEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((441888 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15PxParticleFluidD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx15PxParticleFluidD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx16NpParticleSystemC2Ejb($this,$maxParticles,$perParticleRestOffset) {
 $this = $this|0;
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = 2;
 $1 = (($this) + 4|0);
 HEAP16[$1>>1] = 11;
 $2 = (($this) + 6|0);
 HEAP16[$2>>1] = 3;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((444120 + 8|0));
 $4 = (($this) + 12|0);
 __ZN5physx7NpActorC2EPKc($4,0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((443608 + 8|0));
 $5 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemC2ERKNS_11PxActorType4EnumEjb($5,$0,$maxParticles,$perParticleRestOffset);
 HEAP32[$this>>2] = ((442504 + 8|0));
 STACKTOP = sp;return;
}
function __ZN5physx16NpParticleSystemD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((443608 + 8|0));
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemD2Ev($1);
 HEAP32[$this>>2] = ((443864 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx16NpParticleSystemD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((443608 + 8|0));
 $0 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemD2Ev($0);
 HEAP32[$this>>2] = ((443864 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __Z21NpGetNxParticleSystemRN5physx2Sc18ParticleSystemCoreE($ps) {
 $ps = $ps|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ps) + -32|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx16NpParticleSystem23setParticleReadDataFlagENS_22PxParticleReadDataFlag4EnumEb($this,$flag,$val) {
 $this = $this|0;
 $flag = $flag|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $flags$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $flags$i = sp;
 $1 = (($this) + 32|0);
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($flags$i,$1);
 if ($val) {
  $2 = HEAP16[$flags$i>>1]|0;
  $3 = $2&65535;
  $4 = $3 | $flag;
  $5 = $4&65535;
  HEAP16[$flags$i>>1] = $5;
  $18 = $5;
 } else {
  $6 = $flag ^ 65535;
  $7 = $6&65535;
  $8 = HEAP16[$flags$i>>1]|0;
  $9 = $8 & $7;
  HEAP16[$flags$i>>1] = $9;
  $18 = $9;
 }
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 3)) {
  STACKTOP = sp;return;
 } else if ((($12|0) == 2)) {
  label = 5;
 }
 if ((label|0) == 5) {
  $13 = (($this) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 2417|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
 }
 HEAP16[$0>>1] = $18;
 __ZN5physx2Sc18ParticleSystemCore24setParticleReadDataFlagsENS_7PxFlagsINS_22PxParticleReadDataFlag4EnumEtEE($1,$0);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23setParticleReadDataFlagENS_22PxParticleReadDataFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $flags = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $flags = sp;
 $1 = (($this) + 32|0);
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($flags,$1);
 if ($value) {
  $2 = HEAP16[$flags>>1]|0;
  $3 = $2&65535;
  $4 = $3 | $flag;
  $5 = $4&65535;
  HEAP16[$flags>>1] = $5;
  $18 = $5;
 } else {
  $6 = $flag ^ 65535;
  $7 = $6&65535;
  $8 = HEAP16[$flags>>1]|0;
  $9 = $8 & $7;
  HEAP16[$flags>>1] = $9;
  $18 = $9;
 }
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 2)) {
  label = 5;
 } else if ((($12|0) == 3)) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 5) {
  $13 = (($this) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 2417|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
 }
 HEAP16[$0>>1] = $18;
 __ZN5physx2Sc18ParticleSystemCore24setParticleReadDataFlagsENS_7PxFlagsINS_22PxParticleReadDataFlag4EnumEtEE($1,$0);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (($this) + 12|0);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($3,$this);
 $4 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $8 = (($this) + 20|0);
  __ZN5physx3Scb4Base7destroyEv($8);
  STACKTOP = sp;return;
 }
 __ZN5physx7NpScene26removeFromParticleBaseListERNS_14PxParticleBaseE($4,$this);
 $6 = (($4) + 16|0);
 $7 = (($this) + 20|0);
 __ZN5physx3Scb5Scene20removeParticleSystemERNS0_14ParticleSystemEb($6,$7,1);
 $8 = (($this) + 20|0);
 __ZN5physx3Scb4Base7destroyEv($8);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxParticleSystem19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (444400|0);
}
function __ZNK5physx16PxParticleSystem8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(444400,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $8 = 1;
 } else {
  $2 = (_strcmp(444368,$name)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $8 = 1;
  } else {
   $4 = (_strcmp(444384,$name)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $8 = 1;
   } else {
    $6 = (_strcmp($name,444392)|0);
    $7 = ($6|0)==(0);
    $8 = $7;
   }
  }
 }
 STACKTOP = sp;return ($8|0);
}
function __ZNK5physx16NpParticleSystem7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2;
}
function __ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE7setNameEPKc($this,$debugName) {
 $this = $this|0;
 $debugName = $debugName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $debugName;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14getWorldBoundsEf($agg$result,$this,$inflation) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inflation = Math_fround($inflation);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bounds = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $bounds = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 4;
  } else {
   label = 3;
  }
 } else if ((($2|0) == 3)) {
  label = 3;
 } else {
  label = 4;
 }
 if ((label|0) == 3) {
  $8 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($8,2,443112,452,443488,$vararg_buffer);
 }
 else if ((label|0) == 4) {
  $9 = (($this) + 32|0);
  __ZNK5physx2Sc18ParticleSystemCore14getWorldBoundsEv($bounds,$9);
 }
 $10 = Math_fround(HEAPF32[$bounds>>2]);
 $11 = (($bounds) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = (($bounds) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($bounds) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 + $17);
 $19 = (($bounds) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($bounds) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 + $22);
 $24 = Math_fround($13 * Math_fround(0.5));
 $25 = Math_fround($18 * Math_fround(0.5));
 $26 = Math_fround($23 * Math_fround(0.5));
 $27 = Math_fround($12 - $10);
 $28 = Math_fround($17 - $15);
 $29 = Math_fround($22 - $20);
 $30 = Math_fround($27 * Math_fround(0.5));
 $31 = Math_fround($28 * Math_fround(0.5));
 $32 = Math_fround($29 * Math_fround(0.5));
 $33 = Math_fround($30 * $inflation);
 $34 = Math_fround($31 * $inflation);
 $35 = Math_fround($32 * $inflation);
 $36 = Math_fround($24 - $33);
 $37 = Math_fround($25 - $34);
 $38 = Math_fround($26 - $35);
 $39 = Math_fround($24 + $33);
 $40 = Math_fround($25 + $34);
 $41 = Math_fround($26 + $35);
 HEAPF32[$agg$result>>2] = $36;
 $42 = (($agg$result) + 4|0);
 HEAPF32[$42>>2] = $37;
 $43 = (($agg$result) + 8|0);
 HEAPF32[$43>>2] = $38;
 $44 = (($agg$result) + 12|0);
 HEAPF32[$44>>2] = $39;
 $45 = (($agg$result) + 16|0);
 HEAPF32[$45>>2] = $40;
 $46 = (($agg$result) + 20|0);
 HEAPF32[$46>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $8 = $7;
 $$sum$i = (($6) + 4)|0;
 $9 = (($this) + ($$sum$i)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 24;
 $12 = $11 & 15;
 $13 = ((444424 + ($12<<2)|0) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($8))|0;
 $16 = $15;
 $17 = $10 >>> 30;
 if ((($17|0) == 2)) {
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 2417|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $7;
  }
 } else if ((($17|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $7;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $1;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($16,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($6) + 8)|0;
 $22 = (($this) + ($$sum1$i)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$12)|0);
  HEAP32[$22>>2] = $26;
  $27 = $26;
 } else {
  $27 = $23;
 }
 HEAP16[$27>>1] = $1;
 $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$7);
 $29 = HEAP32[$9>>2]|0;
 $30 = $29 | 1;
 HEAP32[$9>>2] = $30;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE13getActorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $27 = HEAP16[$26>>1]|0;
  HEAP16[$agg$result>>1] = $27;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = HEAP16[$18>>1]|0;
 HEAP16[$agg$result>>1] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE17setDominanceGroupEh($this,$dominanceGroup) {
 $this = $this|0;
 $dominanceGroup = $dominanceGroup|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = $8 >>> 30;
 if ((($15|0) == 2)) {
  $16 = HEAP32[$5>>2]|0;
  $17 = (($16) + 2417|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else if ((($15|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc9ActorCore17setDominanceGroupEh($14,$dominanceGroup);
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $20 = (($this) + ($$sum1)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $23 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $24 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($23,$10)|0);
  HEAP32[$20>>2] = $24;
  $26 = $24;
 } else {
  $26 = $21;
 }
 $25 = (($26) + 2|0);
 HEAP8[$25>>0] = $dominanceGroup;
 $27 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($27,$5);
 $28 = HEAP32[$7>>2]|0;
 $29 = $28 | 2;
 HEAP32[$7>>2] = $29;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE17getDominanceGroupEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 12|0);
  $$in$i$i$i = $26;
  $27 = HEAP8[$$in$i$i$i>>0]|0;
  STACKTOP = sp;return ($27|0);
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 2|0);
 $$in$i$i$i = $17;
 $27 = HEAP8[$$in$i$i$i>>0]|0;
 STACKTOP = sp;return ($27|0);
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE14setOwnerClientEh($this,$inId) {
 $this = $this|0;
 $inId = $inId|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,443200,198,443280,$vararg_buffer1);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = ((414264 + ($5<<2)|0) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + ($7)|0);
 $$sum = (($7) + 4)|0;
 $9 = (($this) + ($$sum)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 3)) {
  label = 6;
 } else if ((($11|0) == 2)) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 5;
  } else {
   label = 6;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = $8;
  $17 = $10 >>> 24;
  $18 = $17 & 15;
  $19 = ((444424 + ($18<<2)|0) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($16))|0;
  $22 = $21;
  $23 = (($22) + 13|0);
  HEAP8[$23>>0] = $inId;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $24 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($24,8,443352,153,443432,$vararg_buffer1);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE14getOwnerClientEv($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = (($14) + 13|0);
 $16 = HEAP8[$15>>0]|0;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$bits) {
 $this = $this|0;
 $bits = $bits|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = HEAP8[$bits>>0]|0;
 $7 = $5;
 $$sum = (($4) + 4)|0;
 $8 = (($this) + ($$sum)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($7))|0;
 $15 = $14;
 $16 = $9 >>> 30;
 if ((($16|0) == 2)) {
  $17 = HEAP32[$5>>2]|0;
  $18 = (($17) + 2417|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else if ((($16|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $21 = (($15) + 11|0);
  HEAP8[$21>>0] = $6;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $22 = (($this) + ($$sum1)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$11)|0);
  HEAP32[$22>>2] = $26;
  $28 = $26;
 } else {
  $28 = $23;
 }
 $27 = (($28) + 3|0);
 HEAP8[$27>>0] = $6;
 $29 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($29,$5);
 $30 = HEAP32[$8>>2]|0;
 $31 = $30 | 4;
 HEAP32[$8>>2] = $31;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE22getClientBehaviorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $20 = $7 >>> 24;
  $21 = $20 & 15;
  $22 = ((444424 + ($21<<2)|0) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $5;
  $25 = (($23) + ($24))|0;
  $26 = $25;
  $27 = (($26) + 11|0);
  $28 = HEAP8[$27>>0]|0;
  HEAP8[$agg$result>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 3|0);
 $19 = HEAP8[$17>>0]|0;
 HEAP8[$agg$result>>0] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE12getAggregateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor12getAggregateEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$flags>>0]|0;
 HEAP8[$0>>0] = $2;
 $3 = (__ZN5physx3Scb14ParticleSystem20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($1,$0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20lockParticleReadDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 HEAP8[$0>>0] = 1;
 $2 = (__ZN5physx3Scb14ParticleSystem20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($1,$0)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE15createParticlesERKNS_22PxParticleCreationDataE($this,$creationData) {
 $this = $this|0;
 $creationData = $creationData|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$creationData>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 32768;
 $7 = ($6|0)==(0);
 if ($7) {
  $18 = (($this) + 32|0);
  __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($0,$18);
 } else {
  $8 = (($this) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $11 = HEAP32[$3>>2]|0;
   $12 = $5 >>> 24;
   $13 = $12 & 15;
   $14 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($11,$13)|0);
   HEAP32[$8>>2] = $14;
   $16 = $14;
  } else {
   $16 = $9;
  }
  $15 = (($16) + 76|0);
  $17 = HEAP16[$15>>1]|0;
  HEAP16[$0>>1] = $17;
 }
 $19 = (__ZN5physx3Scb14ParticleSystem15createParticlesERKNS_22PxParticleCreationDataE($3,$creationData)|0);
 $$0 = $19;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE($this,$numParticles,$indices) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numParticles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE($1,$numParticles,$indices);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE16releaseParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem16releaseParticlesEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEE($this,$numParticles,$indexBuffer,$positionBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $positionBuffer = $positionBuffer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numParticles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($1,$numParticles,$indexBuffer,$positionBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEE($this,$numParticles,$indexBuffer,$velocityBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $velocityBuffer = $velocityBuffer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numParticles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($1,$numParticles,$indexBuffer,$velocityBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS4_IKfEE($this,$numParticles,$indexBuffer,$restOffsetBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $restOffsetBuffer = $restOffsetBuffer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numParticles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKfEE($1,$numParticles,$indexBuffer,$restOffsetBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE9addForcesEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEENS_11PxForceMode4EnumE($this,$numParticles,$indexBuffer,$forceBuffer,$forceMode) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $forceBuffer = $forceBuffer|0;
 $forceMode = $forceMode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,442768,436,443032,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $3 = ($numParticles|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystem9addForcesEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEENS_11PxForceMode4EnumE($4,$numParticles,$indexBuffer,$forceBuffer,$forceMode);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE10getDampingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 128;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore10getDampingEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 12|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE10setDampingEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore10setDampingEf($1,$d);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 12|0);
 HEAPF32[$16>>2] = $d;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 128;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23getExternalAccelerationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 256;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 32|0);
  $15 = (__ZNK5physx2Sc18ParticleSystemCore23getExternalAccelerationEv($14)|0);
  $17 = $15;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 16|0);
  $17 = $12;
 }
 $16 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$agg$result>>2] = $16;
 $18 = (($agg$result) + 4|0);
 $19 = (($17) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$18>>2] = $20;
 $21 = (($agg$result) + 8|0);
 $22 = (($17) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 HEAPF32[$21>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23setExternalAccelerationERKNS_6PxVec3E($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore23setExternalAccelerationERKNS_6PxVec3E($1,$a);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $18 = $15;
 } else {
  $18 = $10;
 }
 $16 = Math_fround(HEAPF32[$a>>2]);
 $17 = (($18) + 16|0);
 HEAPF32[$17>>2] = $16;
 $19 = (($a) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($18) + 20|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($a) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($18) + 24|0);
 HEAPF32[$24>>2] = $23;
 $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($25,$0);
 $26 = HEAP32[$2>>2]|0;
 $27 = $26 | 256;
 HEAP32[$2>>2] = $27;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE18getProjectionPlaneERNS_6PxVec3ERf($this,$normal,$d) {
 $this = $this|0;
 $normal = $normal|0;
 $d = $d|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 512;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 32|0);
  $15 = (__ZNK5physx2Sc18ParticleSystemCore18getProjectionPlaneEv($14)|0);
  $17 = $15;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 28|0);
  $17 = $12;
 }
 $16 = Math_fround(HEAPF32[$17>>2]);
 $18 = (($17) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($17) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($17) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 HEAPF32[$normal>>2] = $16;
 $24 = (($normal) + 4|0);
 HEAPF32[$24>>2] = $19;
 $25 = (($normal) + 8|0);
 HEAPF32[$25>>2] = $21;
 HEAPF32[$d>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE18setProjectionPlaneERKNS_6PxVec3Ef($this,$normal,$d) {
 $this = $this|0;
 $normal = $normal|0;
 $d = Math_fround($d);
 var $$pre = Math_fround(0), $$pre$phi$i$iZ2D = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $p = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $p = sp;
 $0 = Math_fround(HEAPF32[$normal>>2]);
 HEAPF32[$p>>2] = $0;
 $1 = (($p) + 4|0);
 $2 = (($normal) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$1>>2] = $3;
 $4 = (($p) + 8|0);
 $5 = (($normal) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($p) + 12|0);
 HEAPF32[$7>>2] = $d;
 $8 = (($this) + 20|0);
 $9 = (($this) + 32|0);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 2)) {
  $13 = HEAP32[$8>>2]|0;
  $14 = (($13) + 2417|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $8;
  }
 } else if ((($12|0) == 3)) {
  $$pre$phi$i$iZ2D = $8;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore18setProjectionPlaneERKNS_7PxPlaneE($9,$p);
  STACKTOP = sp;return;
 }
 $17 = (($this) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $20 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $21 = $11 >>> 24;
  $22 = $21 & 15;
  $23 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($20,$22)|0);
  HEAP32[$17>>2] = $23;
  $$pre = Math_fround(HEAPF32[$p>>2]);
  $25 = $23;$26 = $$pre;
 } else {
  $25 = $18;$26 = $0;
 }
 $24 = (($25) + 28|0);
 HEAPF32[$24>>2] = $26;
 $27 = Math_fround(HEAPF32[$1>>2]);
 $28 = (($25) + 32|0);
 HEAPF32[$28>>2] = $27;
 $29 = Math_fround(HEAPF32[$4>>2]);
 $30 = (($25) + 36|0);
 HEAPF32[$30>>2] = $29;
 $31 = Math_fround(HEAPF32[$7>>2]);
 $32 = (($25) + 40|0);
 HEAPF32[$32>>2] = $31;
 $33 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($33,$8);
 $34 = HEAP32[$10>>2]|0;
 $35 = $34 | 512;
 HEAP32[$10>>2] = $35;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE15getParticleMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1024;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore15getParticleMassEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 44|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE15setParticleMassEf($this,$m) {
 $this = $this|0;
 $m = Math_fround($m);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore15setParticleMassEf($1,$m);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 44|0);
 HEAPF32[$16>>2] = $m;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 1024;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14getRestitutionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2048;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore14getRestitutionEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 48|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14setRestitutionEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore14setRestitutionEf($1,$r);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 48|0);
 HEAPF32[$16>>2] = $r;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 2048;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE18getDynamicFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4096;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore18getDynamicFrictionEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 52|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE18setDynamicFrictionEf($this,$a) {
 $this = $this|0;
 $a = Math_fround($a);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore18setDynamicFrictionEf($1,$a);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 52|0);
 HEAPF32[$16>>2] = $a;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 4096;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE17getStaticFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 8192;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  $16 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore17getStaticFrictionEv($15)));
  $17 = $16;
  STACKTOP = sp;return (Math_fround($17));
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 56|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $17 = $14;
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE17setStaticFrictionEf($this,$a) {
 $this = $this|0;
 $a = Math_fround($a);
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore17setStaticFrictionEf($1,$a);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 56|0);
 HEAPF32[$16>>2] = $a;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 8192;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23setSimulationFilterDataERKNS_12PxFilterDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $0;
  }
 } else if ((($4|0) == 3)) {
  $$pre$phi$i$iZ2D = $0;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc18ParticleSystemCore23setSimulationFilterDataERKNS_12PxFilterDataE($1,$data);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($12,$14)|0);
  HEAP32[$9>>2] = $15;
  $17 = $15;
 } else {
  $17 = $10;
 }
 $16 = (($17) + 60|0);
 ;HEAP32[$16+0>>2]=HEAP32[$data+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$data+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$data+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$data+12>>2]|0;
 $18 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($18,$0);
 $19 = HEAP32[$2>>2]|0;
 $20 = $19 | 16384;
 HEAP32[$2>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23getSimulationFilterDataEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16384;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = (($this) + 32|0);
  $15 = (__ZNK5physx2Sc18ParticleSystemCore23getSimulationFilterDataEv($14)|0);
  $16 = $15;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (($this) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $1 >>> 24;
   $10 = $9 & 15;
   $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
   HEAP32[$4>>2] = $11;
   $13 = $11;
  } else {
   $13 = $5;
  }
  $12 = (($13) + 60|0);
  $16 = $12;
 }
 ;HEAP32[$agg$result+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$16+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14resetFilteringEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($0,1,442768,611,442960,$vararg_buffer);
 $1 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 212|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($1,$this);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE19setParticleBaseFlagENS_18PxParticleBaseFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $flags = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $flags = sp + 4|0;
 $0 = ($flag|0)==(16);
 if ($0) {
  $1 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($1,2,442768,627,442864,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $2 = (($this) + 20|0);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 32768;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = (($this) + 32|0);
  __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($flags,$17);
 } else {
  $7 = (($this) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = $4 >>> 24;
   $12 = $11 & 15;
   $13 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($10,$12)|0);
   HEAP32[$7>>2] = $13;
   $15 = $13;
  } else {
   $15 = $8;
  }
  $14 = (($15) + 76|0);
  $16 = HEAP16[$14>>1]|0;
  HEAP16[$flags>>1] = $16;
 }
 if ($value) {
  $18 = HEAP16[$flags>>1]|0;
  $19 = $18&65535;
  $20 = $19 | $flag;
  $21 = $20&65535;
  HEAP16[$flags>>1] = $21;
  $33 = $21;
 } else {
  $22 = $flag ^ 65535;
  $23 = $22&65535;
  $24 = HEAP16[$flags>>1]|0;
  $25 = $24 & $23;
  HEAP16[$flags>>1] = $25;
  $33 = $25;
 }
 $26 = (($this) + 32|0);
 $27 = HEAP32[$3>>2]|0;
 $28 = $27 >>> 30;
 if ((($28|0) == 2)) {
  $29 = HEAP32[$2>>2]|0;
  $30 = (($29) + 2417|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   label = 14;
  } else {
   $$pre$phi$i$iZ2D = $2;
   label = 15;
  }
 } else if ((($28|0) == 3)) {
  $$pre$phi$i$iZ2D = $2;
  label = 15;
 } else {
  label = 14;
 }
 if ((label|0) == 14) {
  HEAP16[$vararg_buffer>>1] = $33;
  __ZN5physx2Sc18ParticleSystemCore8setFlagsENS_7PxFlagsINS_18PxParticleBaseFlag4EnumEtEE($26,$vararg_buffer);
 }
 else if ((label|0) == 15) {
  $34 = (($this) + 28|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   $37 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $38 = $27 >>> 24;
   $39 = $38 & 15;
   $40 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($37,$39)|0);
   HEAP32[$34>>2] = $40;
   $42 = $40;
  } else {
   $42 = $35;
  }
  $41 = (($42) + 76|0);
  HEAP16[$41>>1] = $33;
  $43 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($43,$2);
  $44 = HEAP32[$3>>2]|0;
  $45 = $44 | 32768;
  HEAP32[$3>>2] = $45;
 }
 $46 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $47 = ($46|0)==(0|0);
 if ($47) {
  STACKTOP = sp;return;
 }
 (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20getParticleBaseFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32768;
 $3 = ($2|0)==(0);
 if ($3) {
  $15 = (($this) + 32|0);
  __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($agg$result,$15);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (($this) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $1 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$4>>2] = $11;
  $13 = $11;
 } else {
  $13 = $5;
 }
 $12 = (($13) + 76|0);
 $14 = HEAP16[$12>>1]|0;
 HEAP16[$agg$result>>1] = $14;
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE15getMaxParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc18ParticleSystemCore15getMaxParticlesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20getMaxMotionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore20getMaxMotionDistanceEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20setMaxMotionDistanceEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  label = 2;
 } else if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore20setMaxMotionDistanceEf($8,$d);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE13getRestOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore13getRestOffsetEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE13setRestOffsetEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  label = 2;
 } else if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore13setRestOffsetEf($8,$r);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE16getContactOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore16getContactOffsetEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE16setContactOffsetEf($this,$c) {
 $this = $this|0;
 $c = Math_fround($c);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 } else if ((($2|0) == 2)) {
  label = 2;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore16setContactOffsetEf($8,$c);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE11getGridSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore11getGridSizeEv($0)));
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE11setGridSizeEf($this,$g) {
 $this = $this|0;
 $g = Math_fround($g);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  STACKTOP = sp;return;
 } else if ((($2|0) == 2)) {
  label = 2;
 }
 if ((label|0) == 2) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore11setGridSizeEf($8,$g);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE24getParticleReadDataFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZN5physx16NpParticleSystem15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN5physx2Sc18ParticleSystemCore15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($0,$context);
 STACKTOP = sp;return;
}
function __ZN5physx16NpParticleSystem8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$in = 0, $$in19 = 0, $$pre = 0, $$pre$phi$i$i5Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre22 = 0, $$pre22$pre = 0, $$pre24 = 0, $$pre25 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum20 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = ((414264 + ($3<<2)|0) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + ($5)|0);
 $$sum = (($5) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($value) {
  if ($10) {
   $18 = $8 >>> 24;
   $19 = $18 & 15;
   $20 = ((444424 + ($19<<2)|0) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $6;
   $23 = (($21) + ($22))|0;
   $24 = $23;
   $25 = (($24) + 8|0);
   $$in19 = $25;$$pre$phiZ2D = $22;$31 = $8;
  } else {
   $$sum18 = (($5) + 8)|0;
   $11 = (($this) + ($$sum18)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[$6>>2]|0;
    $15 = $8 >>> 24;
    $16 = $15 & 15;
    $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
    HEAP32[$11>>2] = $17;
    $$pre$pre = HEAP32[$7>>2]|0;
    $$pre = $$pre$pre;$91 = $17;
   } else {
    $$pre = $8;$91 = $12;
   }
   $$pre24 = $6;
   $$in19 = $91;$$pre$phiZ2D = $$pre24;$31 = $$pre;
  }
  $26 = HEAP16[$$in19>>1]|0;
  $27 = $26&65535;
  $28 = $27 | $flag;
  $29 = $28&65535;
  $30 = $31 >>> 24;
  $32 = $30 & 15;
  $33 = ((444424 + ($32<<2)|0) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($$pre$phiZ2D))|0;
  $36 = $35;
  $37 = $31 >>> 30;
  if ((($37|0) == 2)) {
   $38 = HEAP32[$6>>2]|0;
   $39 = (($38) + 2417|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    label = 10;
   } else {
    $$pre$phi$i$i5Z2D = $6;
   }
  } else if ((($37|0) == 3)) {
   $$pre$phi$i$i5Z2D = $6;
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $29;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($36,$0);
   STACKTOP = sp;return;
  }
  $$sum20 = (($5) + 8)|0;
  $42 = (($this) + ($$sum20)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   $45 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
   $46 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($45,$32)|0);
   HEAP32[$42>>2] = $46;
   $47 = $46;
  } else {
   $47 = $43;
  }
  HEAP16[$47>>1] = $29;
  $48 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($48,$6);
  $49 = HEAP32[$7>>2]|0;
  $50 = $49 | 1;
  HEAP32[$7>>2] = $50;
  STACKTOP = sp;return;
 } else {
  if ($10) {
   $58 = $8 >>> 24;
   $59 = $58 & 15;
   $60 = ((444424 + ($59<<2)|0) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $6;
   $63 = (($61) + ($62))|0;
   $64 = $63;
   $65 = (($64) + 8|0);
   $$in = $65;$$pre$phi26Z2D = $62;$71 = $8;
  } else {
   $$sum16 = (($5) + 8)|0;
   $51 = (($this) + ($$sum16)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $54 = HEAP32[$6>>2]|0;
    $55 = $8 >>> 24;
    $56 = $55 & 15;
    $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
    HEAP32[$51>>2] = $57;
    $$pre22$pre = HEAP32[$7>>2]|0;
    $$pre22 = $$pre22$pre;$92 = $57;
   } else {
    $$pre22 = $8;$92 = $52;
   }
   $$pre25 = $6;
   $$in = $92;$$pre$phi26Z2D = $$pre25;$71 = $$pre22;
  }
  $66 = HEAP16[$$in>>1]|0;
  $67 = $flag ^ 65535;
  $68 = $67&65535;
  $69 = $66 & $68;
  $70 = $71 >>> 24;
  $72 = $70 & 15;
  $73 = ((444424 + ($72<<2)|0) + 24|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + ($$pre$phi26Z2D))|0;
  $76 = $75;
  $77 = $71 >>> 30;
  if ((($77|0) == 3)) {
   $$pre$phi$i$iZ2D = $6;
  } else if ((($77|0) == 2)) {
   $78 = HEAP32[$6>>2]|0;
   $79 = (($78) + 2417|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    label = 22;
   } else {
    $$pre$phi$i$iZ2D = $6;
   }
  } else {
   label = 22;
  }
  if ((label|0) == 22) {
   HEAP16[$0>>1] = $69;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($76,$0);
   STACKTOP = sp;return;
  }
  $$sum17 = (($5) + 8)|0;
  $82 = (($this) + ($$sum17)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $85 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $86 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($85,$72)|0);
   HEAP32[$82>>2] = $86;
   $87 = $86;
  } else {
   $87 = $83;
  }
  HEAP16[$87>>1] = $69;
  $88 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($88,$6);
  $89 = HEAP32[$7>>2]|0;
  $90 = $89 | 1;
  HEAP32[$7>>2] = $90;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((443608 + 8|0));
 $0 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemD2Ev($0);
 HEAP32[$this>>2] = ((443864 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((443608 + 8|0));
 $1 = (($this) + 20|0);
 __ZN5physx3Scb14ParticleSystemD2Ev($1);
 HEAP32[$this>>2] = ((443864 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2;
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((443864 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_16PxParticleSystemEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((443864 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx16PxParticleSystemD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx16PxParticleSystemD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb9Aggregate8addActorERNS0_5ActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $$off$i$i = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $actorBuffer$0 = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 $$off$i$i = (($3) + -1)|0;
 $4 = ($$off$i$i>>>0)<(2);
 if ($4) {
  $5 = HEAP32[$this>>2]|0;
  $8 = $5;
 } else {
  $8 = 0;
 }
 $6 = ($3|0)==(3);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ($8|0)==(0|0);
 if (!($7)) {
  $9 = (($8) + 2417|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $23 = (($this) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    $26 = HEAP32[$this>>2]|0;
    $27 = $2 >>> 24;
    $28 = $27 & 15;
    $29 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($26,$28)|0);
    HEAP32[$23>>2] = $29;
    $31 = $29;
   } else {
    $31 = $24;
   }
   $30 = (($31) + 8|0);
   $32 = HEAP32[$30>>2]|0;
   $33 = ($32|0)==(-1);
   L13: do {
    if (!($33)) {
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 2512|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($31) + 12|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0);
     if (!($39)) {
      $i$05 = 0;
      while(1) {
       $$sum = (($i$05) + ($32))|0;
       $42 = (($36) + ($$sum<<2)|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = ($43|0)==($actor|0);
       $41 = (($i$05) + 1)|0;
       if ($44) {
        break;
       }
       $40 = ($41>>>0)<($38>>>0);
       if ($40) {
        $i$05 = $41;
       } else {
        break L13;
       }
      }
      $45 = (($32) + -1)|0;
      $$sum2 = (($45) + ($38))|0;
      $46 = (($36) + ($$sum2<<2)|0);
      $47 = HEAP32[$46>>2]|0;
      HEAP32[$42>>2] = $47;
      $48 = (($38) + -1)|0;
      HEAP32[$37>>2] = $48;
     }
    }
   } while(0);
   $49 = HEAP32[$31>>2]|0;
   $50 = ($49|0)==(-1);
   $51 = HEAP32[$this>>2]|0;
   if ($50) {
    $52 = (($this) + 20|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($51) + 2512|0);
    $55 = (($51) + 2516|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($56) + ($53))|0;
    HEAP32[$0>>2] = 0;
    __ZN5physx6shdfnd5ArrayIPNS_3Scb5ActorENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($54,$57,$0);
    HEAP32[$31>>2] = $56;
    $58 = HEAP32[$54>>2]|0;
    $59 = (($58) + ($56<<2)|0);
    $actorBuffer$0 = $59;
   } else {
    $60 = (($51) + 2512|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61) + ($49<<2)|0);
    $actorBuffer$0 = $62;
   }
   $63 = (($31) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($actorBuffer$0) + ($64<<2)|0);
   HEAP32[$65>>2] = $actor;
   $66 = (($64) + 1)|0;
   HEAP32[$63>>2] = $66;
   $67 = ($3|0)==(1);
   if ($67) {
    $71 = HEAP32[$1>>2]|0;
    $72 = $71 | 1;
    HEAP32[$1>>2] = $72;
    STACKTOP = sp;return;
   } else {
    $68 = HEAP32[$this>>2]|0;
    __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($68,$this);
    $69 = HEAP32[$1>>2]|0;
    $70 = $69 | 1;
    HEAP32[$1>>2] = $70;
    STACKTOP = sp;return;
   }
  }
 }
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $actor;
 $15 = (($actor) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 >>> 24;
 $18 = $17 & 15;
 $19 = ((444424 + ($18<<2)|0) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($14))|0;
 $22 = $21;
 HEAP32[$22>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb9Aggregate11removeActorERNS0_5ActorEb($this,$actor,$reinsert) {
 $this = $this|0;
 $actor = $actor|0;
 $reinsert = $reinsert|0;
 var $$mask = 0, $$off$i = 0, $$off$i$i = 0, $$pre = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $actorBuffer$0 = 0, $brmerge = 0, $i$08 = 0;
 var $reinsert$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 30;
 $$off$i$i = (($3) + -1)|0;
 $4 = ($$off$i$i>>>0)<(2);
 if ($4) {
  $5 = HEAP32[$this>>2]|0;
  $8 = $5;
 } else {
  $8 = 0;
 }
 $$mask = $2 & -1073741824;
 $6 = ($$mask|0)==(-1073741824);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ($8|0)==(0|0);
 if (!($7)) {
  $9 = (($8) + 2417|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $26 = (($this) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $29 = HEAP32[$this>>2]|0;
    $30 = $2 >>> 24;
    $31 = $30 & 15;
    $32 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($29,$31)|0);
    HEAP32[$26>>2] = $32;
    $34 = $32;
   } else {
    $34 = $27;
   }
   $33 = HEAP32[$34>>2]|0;
   $35 = ($33|0)==(-1);
   $$pre = HEAP32[$this>>2]|0;
   L13: do {
    if (!($35)) {
     $36 = (($$pre) + 2512|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0);
     if (!($40)) {
      $i$08 = 0;
      while(1) {
       $$sum = (($i$08) + ($33))|0;
       $43 = (($37) + ($$sum<<2)|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ($44|0)==($actor|0);
       $42 = (($i$08) + 1)|0;
       if ($45) {
        break;
       }
       $41 = ($42>>>0)<($39>>>0);
       if ($41) {
        $i$08 = $42;
       } else {
        break L13;
       }
      }
      $46 = (($33) + -1)|0;
      $$sum5 = (($46) + ($39))|0;
      $47 = (($37) + ($$sum5<<2)|0);
      $48 = HEAP32[$47>>2]|0;
      HEAP32[$43>>2] = $48;
      $49 = (($39) + -1)|0;
      HEAP32[$38>>2] = $49;
      STACKTOP = sp;return;
     }
    }
   } while(0);
   $50 = (($34) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(-1);
   if ($52) {
    $53 = (($this) + 20|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($$pre) + 2512|0);
    $56 = (($$pre) + 2516|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($57) + ($54))|0;
    HEAP32[$0>>2] = 0;
    __ZN5physx6shdfnd5ArrayIPNS_3Scb5ActorENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($55,$58,$0);
    HEAP32[$50>>2] = $57;
    $59 = HEAP32[$55>>2]|0;
    $60 = (($59) + ($57<<2)|0);
    $actorBuffer$0 = $60;
   } else {
    $61 = (($$pre) + 2512|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($62) + ($51<<2)|0);
    $actorBuffer$0 = $63;
   }
   $64 = (($34) + 12|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($actorBuffer$0) + ($65<<2)|0);
   HEAP32[$66>>2] = $actor;
   $67 = (($65) + 1)|0;
   HEAP32[$64>>2] = $67;
   $68 = HEAP32[$this>>2]|0;
   __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($68,$this);
   $69 = HEAP32[$1>>2]|0;
   $70 = $69 | 2;
   HEAP32[$1>>2] = $70;
   STACKTOP = sp;return;
  }
 }
 $12 = $actor;
 $13 = (($actor) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 >>> 24;
 $16 = $15 & 15;
 $17 = ((444424 + ($16<<2)|0) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + ($12))|0;
 $20 = $19;
 HEAP32[$20>>2] = -1;
 $21 = HEAP32[$1>>2]|0;
 $22 = $21 >>> 30;
 $$off$i = (($22) + -1)|0;
 $23 = ($$off$i>>>0)<(2);
 if (!($23)) {
  STACKTOP = sp;return;
 }
 $24 = HEAP32[$this>>2]|0;
 $25 = ($24|0)==(0|0);
 $reinsert$not = $reinsert ^ 1;
 $brmerge = $25 | $reinsert$not;
 if ($brmerge) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc9ActorCore14reinsertShapesEv($20);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb4Base7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 2417|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  __ZN5physx9NpDestroyERNS_3Scb4BaseE($this);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $7 = $1 | 536870912;
  HEAP32[$0>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5ClothC2ERKNS_11PxTransformERNS_2Sc15ClothFabricCoreEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($this,$globalPose,$fabric,$particles,$flags) {
 $this = $this|0;
 $globalPose = $globalPose|0;
 $fabric = $fabric|0;
 $particles = $particles|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 12|0);
 $4 = HEAP16[$flags>>1]|0;
 HEAP16[$0>>1] = $4;
 __ZN5physx2Sc9ClothCoreC2ERKNS_11PxTransformERNS0_15ClothFabricCoreEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($3,$globalPose,$fabric,$particles,$0);
 $5 = HEAP32[$2>>2]|0;
 $6 = $5 & -251658241;
 $7 = $6 | 184549376;
 HEAP32[$2>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5ClothD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx2Sc9ClothCoreD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem12ForceUpdates10initializeEj($this,$maxParticles) {
 $this = $this|0;
 $maxParticles = $maxParticles|0;
 var $$$i$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = ($maxParticles*12)|0;
 $5 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$4,444496,48)|0);
 HEAP32[$1>>2] = $5;
 $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__Z15PxGetFoundationv()|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
 $$$i$i$i = $14 ? 445000 : 444968;
 $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,12,$$$i$i$i,444496,49)|0);
 HEAP32[$15>>2] = 0;
 $16 = (($15) + 4|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$this>>2] = $15;
 $17 = (($maxParticles) + 31)|0;
 $18 = $17 >>> 5;
 $19 = ($18|0)==(0);
 $20 = HEAP32[$15>>2]|0;
 if ($19) {
  $25 = $20;$26 = 0;
 } else {
  $21 = ($20|0)==(0|0);
  $22 = (($15) + 8|0);
  if (!($21)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($22,$20);
  }
  HEAP32[$16>>2] = $18;
  $23 = $18 << 2;
  $24 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($22,$23,445176,362)|0);
  HEAP32[$15>>2] = $24;
  $$pre$i = HEAP32[$16>>2]|0;
  $phitmp = $$pre$i << 2;
  $25 = $24;$26 = $phitmp;
 }
 _memset(($25|0),0,($26|0))|0;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem12ForceUpdates7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $12 = (($this) + 8|0);
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($2) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)>(-1);
  if ($8) {
   $9 = (($2) + 8|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($9,$4);
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 HEAP32[$this>>2] = 0;
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$11);
 HEAP32[$10>>2] = 0;
 $12 = (($this) + 8|0);
 HEAP8[$12>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystemC2ERKNS_11PxActorType4EnumEjb($this,$actorType,$maxParticles,$perParticleRestOffset) {
 $this = $this|0;
 $actorType = $actorType|0;
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 __ZN5physx2Sc18ParticleSystemCoreC2ERKNS_11PxActorType4EnumEjb($2,$actorType,$maxParticles,$perParticleRestOffset);
 $3 = (($this) + 152|0);
 $4 = (($this) + 168|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 172|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 176|0);
 HEAP8[$6>>0] = 0;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP8[$3+12>>0]=0|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = $7 & -251658241;
 $9 = $8 | 117440512;
 HEAP32[$1>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystemD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
  HEAP32[$0>>2] = 0;
 }
 $6 = (($this) + 12|0);
 __ZN5physx2Sc18ParticleSystemCoreD2Ev($6);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem15createParticlesERKNS_22PxParticleCreationDataE($this,$creationData) {
 $this = $this|0;
 $creationData = $creationData|0;
 var $$0 = 0, $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 3;
 } else if ((($2|0) == 2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 2417|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $7 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,8,444496,92,444592,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 152|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (($this) + 12|0);
  $12 = (__ZN5physx2Sc18ParticleSystemCore15createParticlesERKNS_22PxParticleCreationDataE($11,$creationData)|0);
  $$0 = $12;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($9) + 72|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $$pre$i$i$i = (($9) + 73|0);
  $$pre$phi$i$i$iZ2D = $$pre$i$i$i;
 } else {
  $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  $17 = (($9) + 73|0);
  HEAP32[$vararg_buffer1>>2] = 444664;
  $vararg_ptr3 = (($vararg_buffer1) + 4|0);
  HEAP32[$vararg_ptr3>>2] = $17;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,8,445248,67,445344,$vararg_buffer1);
  $$pre$phi$i$i$iZ2D = $17;
 }
 (_strncpy(($$pre$phi$i$i$iZ2D|0),(444664|0),128)|0);
 $18 = (($9) + 200|0);
 HEAP8[$18>>0] = 0;
 HEAP8[$13>>0] = 1;
 $19 = (($this) + 12|0);
 $20 = (__ZN5physx2Sc18ParticleSystemCore15createParticlesERKNS_22PxParticleCreationDataE($19,$creationData)|0);
 $21 = HEAP32[$9>>2]|0;
 $22 = (($21) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vi[$23 & 4095]($9);
 $$0 = $20;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Scb14ParticleSystem16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE($this,$numParticles,$indexBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 var $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond7 = 0, $i$05 = 0, $i1$02 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 72|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $$pre$i$i$i = (($1) + 73|0);
   $$pre$phi$i$i$iZ2D = $$pre$i$i$i;
  } else {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   $7 = (($1) + 73|0);
   HEAP32[$vararg_buffer2>>2] = 444704;
   $vararg_ptr1 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $7;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,445248,67,445344,$vararg_buffer2);
   $$pre$phi$i$i$iZ2D = $7;
  }
  (_strncpy(($$pre$phi$i$i$iZ2D|0),(444704|0),128)|0);
  $8 = (($1) + 200|0);
  HEAP8[$8>>0] = 0;
  HEAP8[$3>>0] = 1;
 }
 $9 = ($numParticles|0)==(0);
 do {
  if (!($9)) {
   $10 = (($this) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $11 >>> 30;
   if ((($12|0) == 3)) {
    label = 9;
   } else if ((($12|0) == 2)) {
    $13 = HEAP32[$this>>2]|0;
    $14 = (($13) + 2417|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = ($15<<24>>24)==(0);
    if (!($16)) {
     label = 9;
    }
   }
   if ((label|0) == 9) {
    $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,444496,117,444592,$vararg_buffer2);
    break;
   }
   $18 = (($this) + 12|0);
   __ZN5physx2Sc18ParticleSystemCore16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE($18,$numParticles,$indexBuffer);
   $19 = (($this) + 164|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)==(0);
   if (!($21)) {
    $22 = HEAP32[$indexBuffer>>2]|0;
    $23 = (($indexBuffer) + 4|0);
    $24 = (($this) + 156|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$25>>2]|0;
    $i$05 = 0;
    while(1) {
     $27 = HEAP32[$23>>2]|0;
     $28 = Math_imul($27, $i$05)|0;
     $29 = (($22) + ($28)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = $30 & 31;
     $32 = 1 << $31;
     $33 = $32 ^ -1;
     $34 = $30 >>> 5;
     $35 = (($26) + ($34<<2)|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = $36 & $33;
     HEAP32[$35>>2] = $37;
     $38 = (($i$05) + 1)|0;
     $exitcond7 = ($38|0)==($numParticles|0);
     if ($exitcond7) {
      break;
     } else {
      $i$05 = $38;
     }
    }
   }
   $39 = (($this) + 176|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if (!($41)) {
    $42 = HEAP32[$indexBuffer>>2]|0;
    $43 = (($indexBuffer) + 4|0);
    $44 = (($this) + 168|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = HEAP32[$45>>2]|0;
    $i1$02 = 0;
    while(1) {
     $47 = HEAP32[$43>>2]|0;
     $48 = Math_imul($47, $i1$02)|0;
     $49 = (($42) + ($48)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = $50 & 31;
     $52 = 1 << $51;
     $53 = $52 ^ -1;
     $54 = $50 >>> 5;
     $55 = (($46) + ($54<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = $56 & $53;
     HEAP32[$55>>2] = $57;
     $58 = (($i1$02) + 1)|0;
     $exitcond = ($58|0)==($numParticles|0);
     if ($exitcond) {
      break;
     } else {
      $i1$02 = $58;
     }
    }
   }
  }
 } while(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $59 = HEAP32[$1>>2]|0;
 $60 = (($59) + 4|0);
 $61 = HEAP32[$60>>2]|0;
 FUNCTION_TABLE_vi[$61 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem16releaseParticlesEv($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 72|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $$pre$i$i$i = (($1) + 73|0);
   $$pre$phi$i$i$iZ2D = $$pre$i$i$i;
  } else {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   $7 = (($1) + 73|0);
   HEAP32[$vararg_buffer2>>2] = 444704;
   $vararg_ptr1 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $7;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,445248,67,445344,$vararg_buffer2);
   $$pre$phi$i$i$iZ2D = $7;
  }
  (_strncpy(($$pre$phi$i$i$iZ2D|0),(444704|0),128)|0);
  $8 = (($1) + 200|0);
  HEAP8[$8>>0] = 0;
  HEAP8[$3>>0] = 1;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 2)) {
  $12 = HEAP32[$this>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 9;
  } else {
   label = 8;
  }
 } else if ((($11|0) == 3)) {
  label = 8;
 } else {
  label = 9;
 }
 if ((label|0) == 8) {
  $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,8,444496,143,444592,$vararg_buffer2);
 }
 else if ((label|0) == 9) {
  $17 = (($this) + 12|0);
  __ZN5physx2Sc18ParticleSystemCore16releaseParticlesEv($17);
  $18 = (($this) + 164|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(0);
  if (!($20)) {
   $21 = (($this) + 156|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$22>>2]|0;
   $26 = $24 << 2;
   _memset(($25|0),0,($26|0))|0;
   HEAP8[$18>>0] = 0;
  }
  $27 = (($this) + 176|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if (!($29)) {
   $30 = (($this) + 168|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP32[$31>>2]|0;
   $35 = $33 << 2;
   _memset(($34|0),0,($35|0))|0;
   HEAP8[$27>>0] = 0;
  }
 }
 if ($2) {
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$1>>2]|0;
 $37 = (($36) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vi[$38 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($this,$numParticles,$indexBuffer,$positionBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $positionBuffer = $positionBuffer|0;
 var $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 72|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $$pre$i$i$i = (($1) + 73|0);
   $$pre$phi$i$i$iZ2D = $$pre$i$i$i;
  } else {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   $7 = (($1) + 73|0);
   HEAP32[$vararg_buffer2>>2] = 444744;
   $vararg_ptr1 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $7;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,445248,67,445344,$vararg_buffer2);
   $$pre$phi$i$i$iZ2D = $7;
  }
  (_strncpy(($$pre$phi$i$i$iZ2D|0),(444744|0),128)|0);
  $8 = (($1) + 200|0);
  HEAP8[$8>>0] = 0;
  HEAP8[$3>>0] = 1;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 3)) {
  label = 8;
 } else if ((($11|0) == 2)) {
  $12 = HEAP32[$this>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 9;
  } else {
   label = 8;
  }
 } else {
  label = 9;
 }
 if ((label|0) == 8) {
  $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,8,444496,165,444592,$vararg_buffer2);
 }
 else if ((label|0) == 9) {
  $17 = (($this) + 12|0);
  __ZN5physx2Sc18ParticleSystemCore12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($17,$numParticles,$indexBuffer,$positionBuffer);
 }
 if ($2) {
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$1>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vi[$20 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($this,$numParticles,$indexBuffer,$velocityBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $velocityBuffer = $velocityBuffer|0;
 var $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 72|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $$pre$i$i$i = (($1) + 73|0);
   $$pre$phi$i$i$iZ2D = $$pre$i$i$i;
  } else {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   $7 = (($1) + 73|0);
   HEAP32[$vararg_buffer2>>2] = 444776;
   $vararg_ptr1 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $7;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,445248,67,445344,$vararg_buffer2);
   $$pre$phi$i$i$iZ2D = $7;
  }
  (_strncpy(($$pre$phi$i$i$iZ2D|0),(444776|0),128)|0);
  $8 = (($1) + 200|0);
  HEAP8[$8>>0] = 0;
  HEAP8[$3>>0] = 1;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 3)) {
  label = 8;
 } else if ((($11|0) == 2)) {
  $12 = HEAP32[$this>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 9;
  } else {
   label = 8;
  }
 } else {
  label = 9;
 }
 if ((label|0) == 8) {
  $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,8,444496,184,444592,$vararg_buffer2);
 }
 else if ((label|0) == 9) {
  $17 = (($this) + 12|0);
  __ZN5physx2Sc18ParticleSystemCore13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($17,$numParticles,$indexBuffer,$velocityBuffer);
 }
 if ($2) {
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$1>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vi[$20 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKfEE($this,$numParticles,$indexBuffer,$restOffsetBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $restOffsetBuffer = $restOffsetBuffer|0;
 var $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 72|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $$pre$i$i$i = (($1) + 73|0);
   $$pre$phi$i$i$iZ2D = $$pre$i$i$i;
  } else {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   $7 = (($1) + 73|0);
   HEAP32[$vararg_buffer2>>2] = 444808;
   $vararg_ptr1 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $7;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,445248,67,445344,$vararg_buffer2);
   $$pre$phi$i$i$iZ2D = $7;
  }
  (_strncpy(($$pre$phi$i$i$iZ2D|0),(444808|0),128)|0);
  $8 = (($1) + 200|0);
  HEAP8[$8>>0] = 0;
  HEAP8[$3>>0] = 1;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 2)) {
  $12 = HEAP32[$this>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 9;
  } else {
   label = 8;
  }
 } else if ((($11|0) == 3)) {
  label = 8;
 } else {
  label = 9;
 }
 if ((label|0) == 8) {
  $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,8,444496,203,444592,$vararg_buffer2);
 }
 else if ((label|0) == 9) {
  $17 = (($this) + 12|0);
  __ZN5physx2Sc18ParticleSystemCore14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKfEE($17,$numParticles,$indexBuffer,$restOffsetBuffer);
 }
 if ($2) {
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$1>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vi[$20 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem9addForcesEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEENS_11PxForceMode4EnumE($this,$numParticles,$indexBuffer,$forceBuffer,$forceMode) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $forceBuffer = $forceBuffer|0;
 $forceMode = $forceMode|0;
 var $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$03 = 0, $isAcceleration$0$off0 = 0, $unitMult$0 = Math_fround(0), $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 3;
 } else if ((($2|0) == 2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 2417|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $7 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,8,444496,220,444592,$vararg_buffer1);
  STACKTOP = sp;return;
 }
 $8 = $1 & 1024;
 $9 = ($8|0)==(0);
 if ($9) {
  $20 = (($this) + 12|0);
  $21 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore15getParticleMassEv($20)));
  $23 = $21;
 } else {
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $13 = HEAP32[$this>>2]|0;
   $14 = $1 >>> 24;
   $15 = $14 & 15;
   $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
   HEAP32[$10>>2] = $16;
   $18 = $16;
  } else {
   $18 = $11;
  }
  $17 = (($18) + 44|0);
  $19 = Math_fround(HEAPF32[$17>>2]);
  $23 = $19;
 }
 if ((($forceMode|0) == 0)) {
  $22 = Math_fround(Math_fround(1.0) / $23);
  $isAcceleration$0$off0 = 1;$unitMult$0 = $22;
 } else if ((($forceMode|0) == 2)) {
  $isAcceleration$0$off0 = 0;$unitMult$0 = Math_fround(1.0);
 } else if ((($forceMode|0) == 1)) {
  $24 = Math_fround(Math_fround(1.0) / $23);
  $isAcceleration$0$off0 = 0;$unitMult$0 = $24;
 } else if ((($forceMode|0) == 3)) {
  $isAcceleration$0$off0 = 1;$unitMult$0 = Math_fround(1.0);
 } else {
  $25 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($25,2,444496,250,444848,$vararg_buffer1);
  $26 = Math_fround(Math_fround(1.0) / $23);
  $isAcceleration$0$off0 = 1;$unitMult$0 = $26;
 }
 $27 = (($this) + 156|0);
 $28 = (($this) + 168|0);
 $29 = $isAcceleration$0$off0 ? $27 : $28;
 $30 = (($this) + 12|0);
 $31 = (__ZNK5physx2Sc18ParticleSystemCore15getMaxParticlesEv($30)|0);
 __ZN5physx3Scb14ParticleSystem12ForceUpdates10initializeEj($29,$31);
 $32 = ($numParticles|0)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$indexBuffer>>2]|0;
 $34 = (($indexBuffer) + 4|0);
 $35 = HEAP32[$forceBuffer>>2]|0;
 $36 = (($forceBuffer) + 4|0);
 $37 = HEAP32[$29>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($29) + 4|0);
 $i$03 = 0;
 while(1) {
  $40 = HEAP32[$34>>2]|0;
  $41 = Math_imul($40, $i$03)|0;
  $42 = (($33) + ($41)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = HEAP32[$36>>2]|0;
  $45 = Math_imul($44, $i$03)|0;
  $46 = (($35) + ($45)|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($unitMult$0 * $47);
  $$sum = (($45) + 4)|0;
  $49 = (($35) + ($$sum)|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($unitMult$0 * $50);
  $$sum2 = (($45) + 8)|0;
  $52 = (($35) + ($$sum2)|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($unitMult$0 * $53);
  $55 = $43 >>> 5;
  $56 = (($38) + ($55<<2)|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = $43 & 31;
  $59 = 1 << $58;
  $60 = $57 & $59;
  $61 = ($60|0)==(0);
  if ($61) {
   $62 = $57 | $59;
   HEAP32[$56>>2] = $62;
   $63 = HEAP32[$39>>2]|0;
   $64 = (($63) + (($43*12)|0)|0);
   HEAPF32[$64>>2] = $48;
   $65 = ((($63) + (($43*12)|0)|0) + 4|0);
   HEAPF32[$65>>2] = $51;
   $66 = ((($63) + (($43*12)|0)|0) + 8|0);
   HEAPF32[$66>>2] = $54;
  } else {
   $67 = HEAP32[$39>>2]|0;
   $68 = (($67) + (($43*12)|0)|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($48 + $69);
   HEAPF32[$68>>2] = $70;
   $71 = ((($67) + (($43*12)|0)|0) + 4|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = Math_fround($51 + $72);
   HEAPF32[$71>>2] = $73;
   $74 = ((($67) + (($43*12)|0)|0) + 8|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = Math_fround($54 + $75);
   HEAPF32[$74>>2] = $76;
  }
  $77 = (($i$03) + 1)|0;
  $exitcond = ($77|0)==($numParticles|0);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $77;
  }
 }
 $78 = (($29) + 8|0);
 HEAP8[$78>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem18submitForceUpdatesEf($this,$timeStep) {
 $this = $this|0;
 $timeStep = Math_fround($timeStep);
 var $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 72|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $$pre$i$i$i = (($1) + 73|0);
   $$pre$phi$i$i$iZ2D = $$pre$i$i$i;
  } else {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   $7 = (($1) + 73|0);
   HEAP32[$vararg_buffer>>2] = 444912;
   $vararg_ptr1 = (($vararg_buffer) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $7;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,445248,67,445344,$vararg_buffer);
   $$pre$phi$i$i$iZ2D = $7;
  }
  (_strncpy(($$pre$phi$i$i$iZ2D|0),(444912|0),128)|0);
  $8 = (($1) + 200|0);
  HEAP8[$8>>0] = 0;
  HEAP8[$3>>0] = 1;
 }
 $9 = (($this) + 164|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = (($this) + 12|0);
  $13 = (($this) + 156|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($this) + 160|0);
  $16 = HEAP32[$15>>2]|0;
  __ZN5physx2Sc18ParticleSystemCore18addDeltaVelocitiesERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKNS_6PxVec3Ef($12,$14,$16,$timeStep);
  $17 = HEAP8[$9>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if (!($18)) {
   $19 = HEAP32[$13>>2]|0;
   $20 = (($19) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$19>>2]|0;
   $23 = $21 << 2;
   _memset(($22|0),0,($23|0))|0;
   HEAP8[$9>>0] = 0;
  }
 }
 $24 = (($this) + 176|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if (!($26)) {
  $27 = (($this) + 12|0);
  $28 = (($this) + 168|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($this) + 172|0);
  $31 = HEAP32[$30>>2]|0;
  __ZN5physx2Sc18ParticleSystemCore18addDeltaVelocitiesERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKNS_6PxVec3Ef($27,$29,$31,Math_fround(1.0));
  $32 = HEAP8[$24>>0]|0;
  $33 = ($32<<24>>24)==(0);
  if (!($33)) {
   $34 = HEAP32[$28>>2]|0;
   $35 = (($34) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = HEAP32[$34>>2]|0;
   $38 = $36 << 2;
   _memset(($37|0),0,($38|0))|0;
   HEAP8[$24>>0] = 0;
  }
 }
 if ($2) {
  STACKTOP = sp;return;
 }
 $39 = HEAP32[$1>>2]|0;
 $40 = (($39) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vi[$41 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb14ParticleSystem9syncStateEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $$pre1 = 0, $$pre1$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre2 = 0, $$pre2$i = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_buffer = 0;
 var $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 72|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $$pre$i$i$i = (($1) + 73|0);
   $$pre$phi$i$i$iZ2D = $$pre$i$i$i;
  } else {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   $7 = (($1) + 73|0);
   HEAP32[$vararg_buffer>>2] = 444944;
   $vararg_ptr1 = (($vararg_buffer) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $7;
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,445248,67,445344,$vararg_buffer);
   $$pre$phi$i$i$iZ2D = $7;
  }
  (_strncpy(($$pre$phi$i$i$iZ2D|0),(444944|0),128)|0);
  $8 = (($1) + 200|0);
  HEAP8[$8>>0] = 0;
  HEAP8[$3>>0] = 1;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 16777215;
 $12 = ($11|0)==(0);
 $$pre12 = (($this) + 8|0);
 do {
  if ($12) {
   $117 = $10;
  } else {
   $13 = HEAP32[$$pre12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $15 = HEAP32[$this>>2]|0;
    $16 = $10 >>> 24;
    $17 = $16 & 15;
    $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($15,$17)|0);
    HEAP32[$$pre12>>2] = $18;
    $$pre1 = HEAP32[$9>>2]|0;
    $20 = $$pre1;$24 = $18;
   } else {
    $20 = $10;$24 = $13;
   }
   $19 = $20 & 32;
   $21 = ($19|0)==(0);
   if ($21) {
    $27 = $20;
   } else {
    $22 = (($this) + 12|0);
    $23 = (($24) + 4|0);
    $25 = Math_fround(HEAPF32[$23>>2]);
    __ZN5physx2Sc18ParticleSystemCore12setStiffnessEf($22,$25);
    $$pre2 = HEAP32[$9>>2]|0;
    $27 = $$pre2;
   }
   $26 = $27 & 64;
   $28 = ($26|0)==(0);
   if ($28) {
    $33 = $27;
   } else {
    $29 = (($this) + 12|0);
    $30 = (($24) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    __ZN5physx2Sc18ParticleSystemCore12setViscosityEf($29,$31);
    $$pre3 = HEAP32[$9>>2]|0;
    $33 = $$pre3;
   }
   $32 = $33 & 128;
   $34 = ($32|0)==(0);
   if ($34) {
    $39 = $33;
   } else {
    $35 = (($this) + 12|0);
    $36 = (($24) + 12|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    __ZN5physx2Sc18ParticleSystemCore10setDampingEf($35,$37);
    $$pre4 = HEAP32[$9>>2]|0;
    $39 = $$pre4;
   }
   $38 = $39 & 256;
   $40 = ($38|0)==(0);
   if ($40) {
    $44 = $39;
   } else {
    $41 = (($this) + 12|0);
    $42 = (($24) + 16|0);
    __ZN5physx2Sc18ParticleSystemCore23setExternalAccelerationERKNS_6PxVec3E($41,$42);
    $$pre5 = HEAP32[$9>>2]|0;
    $44 = $$pre5;
   }
   $43 = $44 & 512;
   $45 = ($43|0)==(0);
   if ($45) {
    $49 = $44;
   } else {
    $46 = (($this) + 12|0);
    $47 = (($24) + 28|0);
    __ZN5physx2Sc18ParticleSystemCore18setProjectionPlaneERKNS_7PxPlaneE($46,$47);
    $$pre6 = HEAP32[$9>>2]|0;
    $49 = $$pre6;
   }
   $48 = $49 & 1024;
   $50 = ($48|0)==(0);
   if ($50) {
    $55 = $49;
   } else {
    $51 = (($this) + 12|0);
    $52 = (($24) + 44|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    __ZN5physx2Sc18ParticleSystemCore15setParticleMassEf($51,$53);
    $$pre7 = HEAP32[$9>>2]|0;
    $55 = $$pre7;
   }
   $54 = $55 & 2048;
   $56 = ($54|0)==(0);
   if ($56) {
    $61 = $55;
   } else {
    $57 = (($this) + 12|0);
    $58 = (($24) + 48|0);
    $59 = Math_fround(HEAPF32[$58>>2]);
    __ZN5physx2Sc18ParticleSystemCore14setRestitutionEf($57,$59);
    $$pre8 = HEAP32[$9>>2]|0;
    $61 = $$pre8;
   }
   $60 = $61 & 4096;
   $62 = ($60|0)==(0);
   if ($62) {
    $67 = $61;
   } else {
    $63 = (($this) + 12|0);
    $64 = (($24) + 52|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    __ZN5physx2Sc18ParticleSystemCore18setDynamicFrictionEf($63,$65);
    $$pre9 = HEAP32[$9>>2]|0;
    $67 = $$pre9;
   }
   $66 = $67 & 8192;
   $68 = ($66|0)==(0);
   if (!($68)) {
    $69 = (($this) + 12|0);
    $70 = (($24) + 56|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    __ZN5physx2Sc18ParticleSystemCore17setStaticFrictionEf($69,$71);
   }
   $72 = $10 & 65536;
   $73 = ($72|0)==(0);
   if (!($73)) {
    $74 = (($this) + 12|0);
    __ZN5physx2Sc18ParticleSystemCore14resetFilteringEv($74);
   }
   $75 = HEAP32[$9>>2]|0;
   $76 = $75 & 16384;
   $77 = ($76|0)==(0);
   if ($77) {
    $81 = $75;
   } else {
    $78 = (($this) + 12|0);
    $79 = (($24) + 60|0);
    __ZN5physx2Sc18ParticleSystemCore23setSimulationFilterDataERKNS_12PxFilterDataE($78,$79);
    $$pre10 = HEAP32[$9>>2]|0;
    $81 = $$pre10;
   }
   $80 = $81 & 32768;
   $82 = ($80|0)==(0);
   if ($82) {
    $87 = $81;
   } else {
    $83 = (($this) + 12|0);
    $84 = (($24) + 76|0);
    $85 = HEAP16[$84>>1]|0;
    HEAP16[$vararg_buffer>>1] = $85;
    __ZN5physx2Sc18ParticleSystemCore8setFlagsENS_7PxFlagsINS_18PxParticleBaseFlag4EnumEtEE($83,$vararg_buffer);
    $$pre11 = HEAP32[$9>>2]|0;
    $87 = $$pre11;
   }
   $86 = $87 & 7;
   $88 = ($86|0)==(0);
   if ($88) {
    $117 = $87;
   } else {
    $89 = $this;
    $90 = $87 >>> 24;
    $91 = $90 & 15;
    $92 = ((444424 + ($91<<2)|0) + 24|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($93) + ($89))|0;
    $95 = $94;
    $96 = HEAP32[$$pre12>>2]|0;
    $97 = ($96|0)==(0|0);
    if ($97) {
     $98 = HEAP32[$this>>2]|0;
     $99 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($98,$91)|0);
     HEAP32[$$pre12>>2] = $99;
     $$pre$i = HEAP32[$9>>2]|0;
     $101 = $$pre$i;$104 = $99;
    } else {
     $101 = $87;$104 = $96;
    }
    $100 = $101 & 1;
    $102 = ($100|0)==(0);
    if ($102) {
     $106 = $101;
    } else {
     $103 = HEAP16[$104>>1]|0;
     HEAP16[$vararg_buffer>>1] = $103;
     __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($95,$vararg_buffer);
     $$pre1$i = HEAP32[$9>>2]|0;
     $106 = $$pre1$i;
    }
    $105 = $106 & 2;
    $107 = ($105|0)==(0);
    if ($107) {
     $111 = $106;
    } else {
     $108 = (($104) + 2|0);
     $109 = HEAP8[$108>>0]|0;
     __ZN5physx2Sc9ActorCore17setDominanceGroupEh($95,$109);
     $$pre2$i = HEAP32[$9>>2]|0;
     $111 = $$pre2$i;
    }
    $110 = $111 & 4;
    $112 = ($110|0)==(0);
    if ($112) {
     $117 = $111;
     break;
    }
    $113 = (($104) + 3|0);
    $114 = HEAP8[$113>>0]|0;
    $115 = (($95) + 11|0);
    HEAP8[$115>>0] = $114;
    $$pre = HEAP32[$9>>2]|0;
    $117 = $$pre;
   }
  }
 } while(0);
 HEAP32[$$pre12>>2] = 0;
 $116 = $117 & -16777216;
 HEAP32[$9>>2] = $116;
 if ($2) {
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$1>>2]|0;
 $119 = (($118) + 4|0);
 $120 = HEAP32[$119>>2]|0;
 FUNCTION_TABLE_vi[$120 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb13ObjectTracker6removeERNS0_4BaseE($this,$element) {
 $this = $this|0;
 $element = $element|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $element;
 (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($this,$0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb13ObjectTracker5clearEv($this) {
 $this = $this|0;
 var $$off = 0, $$phi$trans$insert$i$i = 0, $$pre$i$i = 0, $$pre4$i$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $i$04 = 0, $or$cond = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $i$04 = 0;
 }
 while(1) {
  $5 = (($1) + ($i$04<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 >>> 30;
  $$off = (($9) + -1)|0;
  $10 = ($$off>>>0)<(2);
  $11 = $8 & 268435455;
  if ($10) {
   $12 = $11 | -2147483648;
   HEAP32[$7>>2] = $12;
  } else {
   HEAP32[$7>>2] = $11;
   HEAP32[$6>>2] = 0;
  }
  $13 = $8 & 536870912;
  $14 = ($13|0)==(0);
  if (!($14)) {
   $15 = HEAP32[$5>>2]|0;
   __ZN5physx9NpDestroyERNS_3Scb4BaseE($15);
  }
  $16 = (($i$04) + 1)|0;
  $17 = HEAP32[$2>>2]|0;
  $18 = ($16>>>0)<($17>>>0);
  if ($18) {
   $i$04 = $16;
  } else {
   break;
  }
 }
 $phitmp = ($17|0)==(0);
 $19 = (($this) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 $or$cond = $21 | $phitmp;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $20 << 2;
 _memset(($23|0),-1,($24|0))|0;
 $25 = (($this) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + -1)|0;
 $28 = ($27|0)==(0);
 $$phi$trans$insert$i$i = (($this) + 8|0);
 $$pre4$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
 if ($28) {
  $35 = $26;$37 = $$pre4$i$i;
 } else {
  $30 = $$pre4$i$i;$i$01$i$i = 0;
  while(1) {
   $$sum$i$i = (($i$01$i$i) + 32)|0;
   $29 = (($30) + ($$sum$i$i<<2)|0);
   $31 = (($i$01$i$i) + 1)|0;
   $32 = HEAP32[$$phi$trans$insert$i$i>>2]|0;
   $33 = (($32) + ($i$01$i$i<<2)|0);
   HEAP32[$33>>2] = $31;
   $exitcond$i$i = ($31|0)==($27|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $30 = $32;$i$01$i$i = $31;
   }
  }
  $$pre$i$i = HEAP32[$25>>2]|0;
  $35 = $$pre$i$i;$37 = $32;
 }
 $34 = (($35) + -1)|0;
 $36 = (($37) + ($34<<2)|0);
 HEAP32[$36>>2] = -1;
 $38 = (($this) + 28|0);
 HEAP32[$38>>2] = 0;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5SceneC2ERKNS_11PxSceneDescENS_2Cm13EventProfilerE($this,$desc,$eventBuffer) {
 $this = $this|0;
 $desc = $desc|0;
 $eventBuffer = $eventBuffer|0;
 var $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 __ZN5physx2Sc5SceneC2ERKNS_11PxSceneDescERNS_2Cm13EventProfilerE($1,$desc,$eventBuffer);
 $2 = (($this) + 2400|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 2404|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 2408|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 2412|0);
 $6 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  HEAP32[$5>>2] = 0;
 } else {
  $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (__Z15PxGetFoundationv()|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
  $$$i$i$i$i = $17 ? 446528 : 445824;
  $18 = (FUNCTION_TABLE_iiiiii[$12 & 255]($9,$7,$$$i$i$i$i,446448,111)|0);
  HEAP32[$5>>2] = $18;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($18);
  }
 }
 $20 = (($this) + 2416|0);
 HEAP8[$20>>0] = 0;
 $21 = (($this) + 2417|0);
 $22 = (($desc) + 152|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(1);
 $25 = $24&1;
 HEAP8[$21>>0] = $25;
 $26 = (($this) + 2420|0);
 __ZN5physx2Cm9FlushPoolC2Ej($26,16384);
 $27 = (($this) + 2448|0);
 $28 = (($this) + 2472|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;HEAP32[$27+16>>2]=0|0;HEAP32[$27+20>>2]=0|0;
 HEAPF32[$28>>2] = Math_fround(0.75);
 $29 = (($this) + 2476|0);
 HEAP32[$29>>2] = -1;
 $30 = (($this) + 2480|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 2484|0);
 HEAP32[$31>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($27,64);
 $32 = (($this) + 2488|0);
 $33 = (($this) + 2548|0);
 dest=$32+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$33>>2] = Math_fround(0.75);
 $34 = (($this) + 2552|0);
 HEAP32[$34>>2] = -1;
 $35 = (($this) + 2556|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 2560|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 2524|0);
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($37,64);
 $38 = (($this) + 2564|0);
 $39 = (($this) + 2588|0);
 ;HEAP32[$38+0>>2]=0|0;HEAP32[$38+4>>2]=0|0;HEAP32[$38+8>>2]=0|0;HEAP32[$38+12>>2]=0|0;HEAP32[$38+16>>2]=0|0;HEAP32[$38+20>>2]=0|0;
 HEAPF32[$39>>2] = Math_fround(0.75);
 $40 = (($this) + 2592|0);
 HEAP32[$40>>2] = -1;
 $41 = (($this) + 2596|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 2600|0);
 HEAP32[$42>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($38,64);
 $43 = (($this) + 2604|0);
 $44 = (($this) + 2628|0);
 ;HEAP32[$43+0>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;HEAP32[$43+16>>2]=0|0;HEAP32[$43+20>>2]=0|0;
 HEAPF32[$44>>2] = Math_fround(0.75);
 $45 = (($this) + 2632|0);
 HEAP32[$45>>2] = -1;
 $46 = (($this) + 2636|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 2640|0);
 HEAP32[$47>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($43,64);
 $48 = (($this) + 2644|0);
 $49 = (($this) + 2668|0);
 ;HEAP32[$48+0>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;HEAP32[$48+20>>2]=0|0;
 HEAPF32[$49>>2] = Math_fround(0.75);
 $50 = (($this) + 2672|0);
 HEAP32[$50>>2] = -1;
 $51 = (($this) + 2676|0);
 HEAP32[$51>>2] = 0;
 $52 = (($this) + 2680|0);
 HEAP32[$52>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($48,64);
 $53 = (($this) + 2684|0);
 $54 = (($this) + 2708|0);
 ;HEAP32[$53+0>>2]=0|0;HEAP32[$53+4>>2]=0|0;HEAP32[$53+8>>2]=0|0;HEAP32[$53+12>>2]=0|0;HEAP32[$53+16>>2]=0|0;HEAP32[$53+20>>2]=0|0;
 HEAPF32[$54>>2] = Math_fround(0.75);
 $55 = (($this) + 2712|0);
 HEAP32[$55>>2] = -1;
 $56 = (($this) + 2716|0);
 HEAP32[$56>>2] = 0;
 $57 = (($this) + 2720|0);
 HEAP32[$57>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($53,64);
 $58 = (($this) + 2724|0);
 $59 = (($this) + 2748|0);
 ;HEAP32[$58+0>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;HEAP32[$58+12>>2]=0|0;HEAP32[$58+16>>2]=0|0;HEAP32[$58+20>>2]=0|0;
 HEAPF32[$59>>2] = Math_fround(0.75);
 $60 = (($this) + 2752|0);
 HEAP32[$60>>2] = -1;
 $61 = (($this) + 2756|0);
 HEAP32[$61>>2] = 0;
 $62 = (($this) + 2760|0);
 HEAP32[$62>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($58,64);
 $63 = (($this) + 2764|0);
 $64 = (($this) + 2788|0);
 ;HEAP32[$63+0>>2]=0|0;HEAP32[$63+4>>2]=0|0;HEAP32[$63+8>>2]=0|0;HEAP32[$63+12>>2]=0|0;HEAP32[$63+16>>2]=0|0;HEAP32[$63+20>>2]=0|0;
 HEAPF32[$64>>2] = Math_fround(0.75);
 $65 = (($this) + 2792|0);
 HEAP32[$65>>2] = -1;
 $66 = (($this) + 2796|0);
 HEAP32[$66>>2] = 0;
 $67 = (($this) + 2800|0);
 HEAP32[$67>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($63,64);
 $68 = (($this) + 2804|0);
 $69 = (($this) + 2828|0);
 ;HEAP32[$68+0>>2]=0|0;HEAP32[$68+4>>2]=0|0;HEAP32[$68+8>>2]=0|0;HEAP32[$68+12>>2]=0|0;HEAP32[$68+16>>2]=0|0;HEAP32[$68+20>>2]=0|0;
 HEAPF32[$69>>2] = Math_fround(0.75);
 $70 = (($this) + 2832|0);
 HEAP32[$70>>2] = -1;
 $71 = (($this) + 2836|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 2840|0);
 HEAP32[$72>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($68,64);
 $73 = (($this) + 2844|0);
 $74 = (($desc) + 156|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 HEAPF32[$73>>2] = $75;
 $76 = (($this) + 3332|0);
 HEAP16[$76>>1] = 0;
 $77 = (($this) + 3064|0);
 dest=$77+0|0; stop=dest+124|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $78 = (($this) + 2996|0);
 dest=$78+0|0; stop=dest+37|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $79 = (($this) + 3340|0);
 ;HEAP32[$79+0>>2]=0|0;HEAP32[$79+4>>2]=0|0;HEAP32[$79+8>>2]=0|0;HEAP32[$79+12>>2]=0|0;
 HEAP8[$0>>0] = -1;
 $80 = (($this) + 3344|0);
 (__ZN5physx6shdfnd5ArrayINS_7PxFlagsINS_20PxClientBehaviorFlag4EnumEhEENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($80,$0)|0);
 $81 = (($this) + 3356|0);
 HEAP32[$81>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 __ZN5physx2Sc5Scene7releaseEv($1);
 $2 = (($this) + 2492|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 2504|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 2516|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 2420|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($6);
 $7 = (($this) + 2436|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 2)|0;
 $10 = (($this) + 2428|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)>($9>>>0);
 if (!($12)) {
  HEAP32[$7>>2] = 0;
  $21 = (($this) + 2440|0);
  HEAP32[$21>>2] = 0;
  $22 = HEAP32[$5>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
  STACKTOP = sp;return;
 }
 $13 = (($this) + 2424|0);
 $15 = $11;
 while(1) {
  $14 = (($15) + -1)|0;
  $16 = HEAP32[$13>>2]|0;
  $17 = (($16) + ($14<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$10>>2] = $14;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$18);
  $19 = HEAP32[$10>>2]|0;
  $20 = ($19>>>0)>($9>>>0);
  if ($20) {
   $15 = $19;
  } else {
   break;
  }
 }
 HEAP32[$7>>2] = 0;
 $21 = (($this) + 2440|0);
 HEAP32[$21>>2] = 0;
 $22 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene10getPxSceneEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx12NpGetPxSceneERNS_3Scb5SceneE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx3Scb5Scene18switchRigidToNoSimERNS0_11RigidObjectEb($this,$r,$isDynamic) {
 $this = $this|0;
 $r = $r|0;
 $isDynamic = $isDynamic|0;
 var $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $or$cond$i$i$i = 0, $scShapes = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $scShapes = sp;
 $0 = (($r) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $$mask = $1 & -1073741824;
 $2 = ($$mask|0)==(-2147483648);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($scShapes) + 256|0);
 $4 = (($scShapes) + 260|0);
 $5 = (($scShapes) + 264|0);
 HEAP32[$5>>2] = 0;
 $6 = (($scShapes) + 268|0);
 HEAP8[$3>>0] = 1;
 HEAP32[$4>>2] = $scShapes;
 HEAP32[$6>>2] = 64;
 $7 = (($this) + 16|0);
 $8 = $r;
 $9 = $1 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($8))|0;
 if ($isDynamic) {
  $14 = $13;
  __ZN5physx2Sc5Scene10removeBodyERNS0_8BodyCoreERNS_6shdfnd11InlineArrayIPKNS0_9ShapeCoreELj64ENS4_19ReflectionAllocatorIS8_EEEEb($7,$14,$scShapes,1);
 } else {
  $15 = $13;
  __ZN5physx2Sc5Scene12removeStaticERNS0_10StaticCoreERNS_6shdfnd11InlineArrayIPKNS0_9ShapeCoreELj64ENS4_19ReflectionAllocatorIS8_EEEEb($7,$15,$scShapes,1);
 }
 $16 = HEAP32[$4>>2]|0;
 $17 = HEAP32[$5>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $i$01 = 0;
  while(1) {
   $19 = (($16) + ($i$01<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + -16|0);
   __ZN5physx18NpShapeDecRefCountERNS_3Scb5ShapeE($21);
   $22 = (($i$01) + 1)|0;
   $23 = HEAP32[$5>>2]|0;
   $24 = ($22>>>0)<($23>>>0);
   if ($24) {
    $i$01 = $22;
   } else {
    break;
   }
  }
 }
 $25 = HEAP32[$6>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i$i = $27 & $28;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$4>>2]|0;
 $30 = ($scShapes|0)==($29|0);
 if ($30) {
  HEAP8[$3>>0] = 0;
  STACKTOP = sp;return;
 }
 $31 = ($29|0)==(0|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$35 & 4095]($32,$29);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene20switchRigidFromNoSimERNS0_11RigidObjectEb($this,$r,$isDynamic) {
 $this = $this|0;
 $r = $r|0;
 $isDynamic = $isDynamic|0;
 var $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $nbShapes$0 = 0, $shapes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $shapes = sp;
 $0 = (($r) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $$mask = $1 & -1073741824;
 $2 = ($$mask|0)==(-2147483648);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $4 = (($3) + -16)|0;
 if ($isDynamic) {
  $5 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($r,$shapes)|0);
  $6 = (($this) + 16|0);
  $7 = $r;
  $8 = HEAP32[$0>>2]|0;
  $9 = $8 >>> 24;
  $10 = $9 & 15;
  $11 = ((444424 + ($10<<2)|0) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($7))|0;
  $14 = $13;
  $15 = HEAP32[$shapes>>2]|0;
  __ZN5physx2Sc5Scene7addBodyERNS0_8BodyCoreEPKPvjj($6,$14,$15,$5,$3);
  $nbShapes$0 = $5;
 } else {
  $16 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($r,$shapes)|0);
  $17 = (($this) + 16|0);
  $18 = $r;
  $19 = HEAP32[$0>>2]|0;
  $20 = $19 >>> 24;
  $21 = $20 & 15;
  $22 = ((444424 + ($21<<2)|0) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($18))|0;
  $25 = $24;
  $26 = HEAP32[$shapes>>2]|0;
  __ZN5physx2Sc5Scene9addStaticERNS0_10StaticCoreEPKPvjj($17,$25,$26,$16,$3);
  $nbShapes$0 = $16;
 }
 $27 = ($nbShapes$0|0)==(0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $28 = HEAP32[$shapes>>2]|0;
  $29 = (($28) + ($i$01<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + ($4)|0);
  __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($31);
  $32 = (($i$01) + 1)|0;
  $exitcond = ($32|0)==($nbShapes$0|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene14addRigidStaticERNS0_11RigidStaticEb($this,$rigidStatic,$noSim) {
 $this = $this|0;
 $rigidStatic = $rigidStatic|0;
 $noSim = $noSim|0;
 var $$idx = 0, $$idx$val = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $exitcond$i$i = 0, $exitcond$i8$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i11$i = 0;
 var $scShapes$i = 0, $shapes$i3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $shapes$i3$i = sp + 816|0;
 $0 = sp;
 $scShapes$i = sp + 272|0;
 $1 = sp + 544|0;
 $2 = (($this) + 2524|0);
 if ($noSim) {
  __ZN5physx3Scb5Scene13addRigidNoSimINS0_11RigidStaticELb0ELb1EEEvRT_RNS0_13ObjectTrackerE($this,$rigidStatic,$2);
  STACKTOP = sp;return;
 }
 __ZN5physx3Scb5Scene3addINS0_11RigidStaticELb1EEEvRT_RNS0_13ObjectTrackerE($this,$rigidStatic,$2);
 $3 = (($this) + 2417|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $$idx = (($this) + 1260|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $6 = ($$idx$val|0)==(0|0);
 if (!($6)) {
  $7 = (($$idx$val) + 272|0);
  $8 = (($0) + 256|0);
  HEAP8[$8>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$7);
  $9 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $10 = (($9) + -16)|0;
  $11 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($rigidStatic,$shapes$i3$i)|0);
  $12 = HEAP32[$rigidStatic>>2]|0;
  $13 = (($rigidStatic) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & -1073741824;
  $16 = ($11|0)==(0);
  if (!($16)) {
   $$sum$i$i = (($9) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $17 = HEAP32[$shapes$i3$i>>2]|0;
    $18 = (($17) + ($i$01$i$i<<2)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + ($$sum$i$i)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 & 251658240;
    $23 = ($22|0)==(16777216);
    if ($23) {
     $24 = (($19) + ($10)|0);
     $25 = $21 & 1073741823;
     $26 = $25 | $15;
     HEAP32[$20>>2] = $26;
     HEAP32[$24>>2] = $12;
    }
    $27 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($27|0)==($11|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $27;
    }
   }
  }
  $28 = (($0) + 268|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $29 & 2147483647;
  $31 = ($30|0)!=(0);
  $32 = ($29|0)>(-1);
  $or$cond$i$i$i1$i = $31 & $32;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $33 = (($0) + 260|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($0|0)==($34|0);
  if ($35) {
   HEAP8[$8>>0] = 0;
   STACKTOP = sp;return;
  }
  $36 = ($34|0)==(0|0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $37 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_vii[$40 & 4095]($37,$34);
  STACKTOP = sp;return;
 }
 $41 = (($scShapes$i) + 256|0);
 $42 = (($scShapes$i) + 260|0);
 $43 = (($scShapes$i) + 264|0);
 HEAP32[$43>>2] = 0;
 $44 = (($scShapes$i) + 268|0);
 HEAP8[$41>>0] = 1;
 HEAP32[$42>>2] = $scShapes$i;
 HEAP32[$44>>2] = 64;
 $45 = (($1) + 256|0);
 HEAP8[$45>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes$i);
 $46 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $47 = (($46) + -16)|0;
 $48 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($rigidStatic,$shapes$i3$i)|0);
 $49 = HEAP32[$rigidStatic>>2]|0;
 $50 = (($rigidStatic) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = $51 & -1073741824;
 $53 = ($48|0)==(0);
 if (!($53)) {
  $$sum$i4$i = (($46) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $54 = HEAP32[$shapes$i3$i>>2]|0;
   $55 = (($54) + ($i$01$i6$i<<2)|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + ($$sum$i4$i)|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = $58 & 251658240;
   $60 = ($59|0)==(16777216);
   if ($60) {
    $61 = (($56) + ($47)|0);
    $62 = $58 & 1073741823;
    $63 = $62 | $52;
    HEAP32[$57>>2] = $63;
    HEAP32[$61>>2] = $49;
   }
   $64 = (($i$01$i6$i) + 1)|0;
   $exitcond$i8$i = ($64|0)==($48|0);
   if ($exitcond$i8$i) {
    break;
   } else {
    $i$01$i6$i = $64;
   }
  }
 }
 $65 = (($1) + 268|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 & 2147483647;
 $68 = ($67|0)!=(0);
 $69 = ($66|0)>(-1);
 $or$cond$i$i$i11$i = $68 & $69;
 do {
  if ($or$cond$i$i$i11$i) {
   $70 = (($1) + 260|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($1|0)==($71|0);
   if ($72) {
    HEAP8[$45>>0] = 0;
    break;
   }
   $73 = ($71|0)==(0|0);
   if (!($73)) {
    $74 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($75) + 12|0);
    $77 = HEAP32[$76>>2]|0;
    FUNCTION_TABLE_vii[$77 & 4095]($74,$71);
   }
  }
 } while(0);
 $78 = HEAP32[$44>>2]|0;
 $79 = $78 & 2147483647;
 $80 = ($79|0)!=(0);
 $81 = ($78|0)>(-1);
 $or$cond$i$i$i$i = $80 & $81;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $82 = HEAP32[$42>>2]|0;
 $83 = ($scShapes$i|0)==($82|0);
 if ($83) {
  HEAP8[$41>>0] = 0;
  STACKTOP = sp;return;
 }
 $84 = ($82|0)==(0|0);
 if ($84) {
  STACKTOP = sp;return;
 }
 $85 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + 12|0);
 $88 = HEAP32[$87>>2]|0;
 FUNCTION_TABLE_vii[$88 & 4095]($85,$82);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene3addINS0_11RigidStaticELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 HEAP32[$v>>2] = $this;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 if ($4) {
  $7 = $6 & 268435455;
  $8 = $7 | -2147483648;
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 16|0);
  __ZN10ScSceneFnsIN5physx3Scb11RigidStaticEE6insertERNS0_2Sc5SceneERS2_($9,$v);
  STACKTOP = sp;return;
 }
 $$mask$i = $6 & -1073741824;
 $10 = ($$mask$i|0)==(-1073741824);
 $11 = $6 & 1073741823;
 if ($10) {
  $12 = $11 | -2147483648;
  HEAP32[$5>>2] = $12;
  $13 = $6 & 268435456;
  $14 = ($13|0)==(0);
  if (!($14)) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
  STACKTOP = sp;return;
 } else {
  $15 = $11 | 1073741824;
  HEAP32[$5>>2] = $15;
  HEAP32[$1>>2] = $v;
  $16 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
  $17 = HEAP8[$0>>0]|0;
  $18 = ($17<<24>>24)!=(0);
  $19 = ($16|0)==(0|0);
  $or$cond$i$i$i = $18 | $19;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $20 = HEAP32[$1>>2]|0;
  HEAP32[$16>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene13addRigidNoSimINS0_11RigidStaticELb0ELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$mask$i = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i8$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i11$i = 0, $scShapes$i = 0, $shapes$i3$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $0 = sp + 824|0;
 $1 = sp;
 $shapes$i3$i = sp + 4|0;
 $2 = sp + 8|0;
 $scShapes$i = sp + 280|0;
 $3 = sp + 552|0;
 HEAP32[$v>>2] = $this;
 $4 = (($this) + 2417|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $7 = (($v) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $9 = $8 & 268435455;
  $10 = $9 | -2147483648;
  HEAP32[$7>>2] = $10;
  $$idx = (($this) + 1260|0);
  $$idx$val = HEAP32[$$idx>>2]|0;
  __ZL22addOrRemoveRigidObjectILb0ELb1ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_b($$idx$val,$v);
  STACKTOP = sp;return;
 }
 $$mask$i = $8 & -1073741824;
 $11 = ($$mask$i|0)==(-1073741824);
 $12 = $8 & 1073741823;
 if ($11) {
  $13 = $12 | -2147483648;
  HEAP32[$7>>2] = $13;
  $14 = $8 & 268435456;
  $15 = ($14|0)==(0);
  if ($15) {
   HEAP32[$0>>2] = $v;
   (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
  }
 } else {
  $16 = $12 | 1073741824;
  HEAP32[$7>>2] = $16;
  HEAP32[$1>>2] = $v;
  $17 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
  $18 = HEAP8[$0>>0]|0;
  $19 = ($18<<24>>24)!=(0);
  $20 = ($17|0)==(0|0);
  $or$cond$i$i$i = $19 | $20;
  if (!($or$cond$i$i$i)) {
   $21 = HEAP32[$1>>2]|0;
   HEAP32[$17>>2] = $21;
  }
 }
 $$idx1 = (($this) + 1260|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $22 = ($$idx1$val|0)==(0|0);
 if (!($22)) {
  $23 = (($$idx1$val) + 272|0);
  $24 = (($2) + 256|0);
  HEAP8[$24>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($2,$23);
  $25 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $26 = (($25) + -16)|0;
  $27 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($v,$shapes$i3$i)|0);
  $28 = HEAP32[$v>>2]|0;
  $29 = HEAP32[$7>>2]|0;
  $30 = $29 & -1073741824;
  $31 = ($27|0)==(0);
  if (!($31)) {
   $$sum$i$i = (($25) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $32 = HEAP32[$shapes$i3$i>>2]|0;
    $33 = (($32) + ($i$01$i$i<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + ($$sum$i$i)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36 & 251658240;
    $38 = ($37|0)==(16777216);
    if ($38) {
     $39 = (($34) + ($26)|0);
     $40 = $36 & 1073741823;
     $41 = $40 | $30;
     HEAP32[$35>>2] = $41;
     HEAP32[$39>>2] = $28;
    }
    $42 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($42|0)==($27|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $42;
    }
   }
  }
  $43 = (($2) + 268|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & 2147483647;
  $46 = ($45|0)!=(0);
  $47 = ($44|0)>(-1);
  $or$cond$i$i$i1$i = $46 & $47;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $48 = (($2) + 260|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($2|0)==($49|0);
  if ($50) {
   HEAP8[$24>>0] = 0;
   STACKTOP = sp;return;
  }
  $51 = ($49|0)==(0|0);
  if ($51) {
   STACKTOP = sp;return;
  }
  $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  STACKTOP = sp;return;
 }
 $56 = (($scShapes$i) + 256|0);
 $57 = (($scShapes$i) + 260|0);
 $58 = (($scShapes$i) + 264|0);
 HEAP32[$58>>2] = 0;
 $59 = (($scShapes$i) + 268|0);
 HEAP8[$56>>0] = 1;
 HEAP32[$57>>2] = $scShapes$i;
 HEAP32[$59>>2] = 64;
 $60 = (($3) + 256|0);
 HEAP8[$60>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($3,$scShapes$i);
 $61 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $62 = (($61) + -16)|0;
 $63 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($v,$shapes$i3$i)|0);
 $64 = HEAP32[$v>>2]|0;
 $65 = HEAP32[$7>>2]|0;
 $66 = $65 & -1073741824;
 $67 = ($63|0)==(0);
 if (!($67)) {
  $$sum$i4$i = (($61) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $68 = HEAP32[$shapes$i3$i>>2]|0;
   $69 = (($68) + ($i$01$i6$i<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + ($$sum$i4$i)|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = $72 & 251658240;
   $74 = ($73|0)==(16777216);
   if ($74) {
    $75 = (($70) + ($62)|0);
    $76 = $72 & 1073741823;
    $77 = $76 | $66;
    HEAP32[$71>>2] = $77;
    HEAP32[$75>>2] = $64;
   }
   $78 = (($i$01$i6$i) + 1)|0;
   $exitcond$i8$i = ($78|0)==($63|0);
   if ($exitcond$i8$i) {
    break;
   } else {
    $i$01$i6$i = $78;
   }
  }
 }
 $79 = (($3) + 268|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = $80 & 2147483647;
 $82 = ($81|0)!=(0);
 $83 = ($80|0)>(-1);
 $or$cond$i$i$i11$i = $82 & $83;
 do {
  if ($or$cond$i$i$i11$i) {
   $84 = (($3) + 260|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($3|0)==($85|0);
   if ($86) {
    HEAP8[$60>>0] = 0;
    break;
   }
   $87 = ($85|0)==(0|0);
   if (!($87)) {
    $88 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($89) + 12|0);
    $91 = HEAP32[$90>>2]|0;
    FUNCTION_TABLE_vii[$91 & 4095]($88,$85);
   }
  }
 } while(0);
 $92 = HEAP32[$59>>2]|0;
 $93 = $92 & 2147483647;
 $94 = ($93|0)!=(0);
 $95 = ($92|0)>(-1);
 $or$cond$i$i$i$i = $94 & $95;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $96 = HEAP32[$57>>2]|0;
 $97 = ($scShapes$i|0)==($96|0);
 if ($97) {
  HEAP8[$56>>0] = 0;
  STACKTOP = sp;return;
 }
 $98 = ($96|0)==(0|0);
 if ($98) {
  STACKTOP = sp;return;
 }
 $99 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) + 12|0);
 $102 = HEAP32[$101>>2]|0;
 FUNCTION_TABLE_vii[$102 & 4095]($99,$96);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene17removeRigidStaticERNS0_11RigidStaticEbb($this,$rigidStatic,$wakeOnLostTouch,$noSim) {
 $this = $this|0;
 $rigidStatic = $rigidStatic|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 $noSim = $noSim|0;
 var $$idx = 0, $$idx$val = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exists$i$i$i$i = 0, $exitcond$i$i = 0;
 var $exitcond$i8$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i$i1 = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i11$i = 0, $scShapes$i = 0, $shapes$i3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $shapes$i3$i = sp + 820|0;
 $0 = sp;
 $scShapes$i = sp + 272|0;
 $1 = sp + 544|0;
 $exists$i$i$i$i = sp + 824|0;
 $2 = sp + 816|0;
 $3 = (($this) + 2524|0);
 do {
  if ($noSim) {
   __ZN5physx3Scb5Scene16removeRigidNoSimINS0_11RigidStaticELb0ELb1EEEvRT_RNS0_13ObjectTrackerE($this,$rigidStatic,$3);
  } else {
   $4 = (($this) + 2417|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   do {
    if ($6) {
     $7 = (($this) + 16|0);
     __ZN10ScSceneFnsIN5physx3Scb11RigidStaticEE6removeERNS0_2Sc5SceneERS2_b($7,$rigidStatic,$wakeOnLostTouch);
     $8 = (($rigidStatic) + 4|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = $9 & 268435455;
     HEAP32[$8>>2] = $10;
     HEAP32[$rigidStatic>>2] = 0;
    } else {
     $11 = (($rigidStatic) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = $12 >>> 30;
     if ((($13|0) == 1)) {
      $14 = $12 & 1073741823;
      HEAP32[$11>>2] = $14;
      HEAP32[$shapes$i3$i>>2] = $rigidStatic;
      (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($3,$shapes$i3$i)|0);
      break;
     } else if (!((($13|0) == 2))) {
      break;
     }
     $15 = $12 | -1073741824;
     HEAP32[$11>>2] = $15;
     $16 = $12 & 268435456;
     $17 = ($16|0)==(0);
     if ($17) {
      HEAP32[$2>>2] = $rigidStatic;
      $18 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($3,$2,$exists$i$i$i$i)|0);
      $19 = HEAP8[$exists$i$i$i$i>>0]|0;
      $20 = ($19<<24>>24)!=(0);
      $21 = ($18|0)==(0|0);
      $or$cond$i$i$i$i = $20 | $21;
      if (!($or$cond$i$i$i$i)) {
       $22 = HEAP32[$2>>2]|0;
       HEAP32[$18>>2] = $22;
      }
     }
    }
   } while(0);
   $23 = HEAP8[$4>>0]|0;
   $24 = ($23<<24>>24)==(0);
   if (!($24)) {
    if ($wakeOnLostTouch) {
     $25 = (($rigidStatic) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = $26 | 16;
     HEAP32[$25>>2] = $27;
    }
    $$idx = (($this) + 1260|0);
    $$idx$val = HEAP32[$$idx>>2]|0;
    $28 = ($$idx$val|0)==(0|0);
    if (!($28)) {
     $29 = (($$idx$val) + 272|0);
     $30 = (($0) + 256|0);
     HEAP8[$30>>0] = 0;
     __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$29);
     $31 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
     $32 = (($31) + -16)|0;
     $33 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($rigidStatic,$shapes$i3$i)|0);
     $34 = HEAP32[$rigidStatic>>2]|0;
     $35 = (($rigidStatic) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = $36 & -1073741824;
     $38 = ($33|0)==(0);
     if (!($38)) {
      $$sum$i$i = (($31) + -12)|0;
      $i$01$i$i = 0;
      while(1) {
       $39 = HEAP32[$shapes$i3$i>>2]|0;
       $40 = (($39) + ($i$01$i$i<<2)|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = (($41) + ($$sum$i$i)|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = $43 & 251658240;
       $45 = ($44|0)==(16777216);
       if ($45) {
        $46 = (($41) + ($32)|0);
        $47 = $43 & 1073741823;
        $48 = $47 | $37;
        HEAP32[$42>>2] = $48;
        HEAP32[$46>>2] = $34;
       }
       $49 = (($i$01$i$i) + 1)|0;
       $exitcond$i$i = ($49|0)==($33|0);
       if ($exitcond$i$i) {
        break;
       } else {
        $i$01$i$i = $49;
       }
      }
     }
     $50 = (($0) + 268|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = $51 & 2147483647;
     $53 = ($52|0)!=(0);
     $54 = ($51|0)>(-1);
     $or$cond$i$i$i1$i = $53 & $54;
     if (!($or$cond$i$i$i1$i)) {
      break;
     }
     $55 = (($0) + 260|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($0|0)==($56|0);
     if ($57) {
      HEAP8[$30>>0] = 0;
      break;
     }
     $58 = ($56|0)==(0|0);
     if ($58) {
      break;
     }
     $59 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (($60) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     FUNCTION_TABLE_vii[$62 & 4095]($59,$56);
     break;
    }
    $63 = (($scShapes$i) + 256|0);
    $64 = (($scShapes$i) + 260|0);
    $65 = (($scShapes$i) + 264|0);
    HEAP32[$65>>2] = 0;
    $66 = (($scShapes$i) + 268|0);
    HEAP8[$63>>0] = 1;
    HEAP32[$64>>2] = $scShapes$i;
    HEAP32[$66>>2] = 64;
    $67 = (($1) + 256|0);
    HEAP8[$67>>0] = 0;
    __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes$i);
    $68 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
    $69 = (($68) + -16)|0;
    $70 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($rigidStatic,$shapes$i3$i)|0);
    $71 = HEAP32[$rigidStatic>>2]|0;
    $72 = (($rigidStatic) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = $73 & -1073741824;
    $75 = ($70|0)==(0);
    if (!($75)) {
     $$sum$i4$i = (($68) + -12)|0;
     $i$01$i6$i = 0;
     while(1) {
      $76 = HEAP32[$shapes$i3$i>>2]|0;
      $77 = (($76) + ($i$01$i6$i<<2)|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($78) + ($$sum$i4$i)|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = $80 & 251658240;
      $82 = ($81|0)==(16777216);
      if ($82) {
       $83 = (($78) + ($69)|0);
       $84 = $80 & 1073741823;
       $85 = $84 | $74;
       HEAP32[$79>>2] = $85;
       HEAP32[$83>>2] = $71;
      }
      $86 = (($i$01$i6$i) + 1)|0;
      $exitcond$i8$i = ($86|0)==($70|0);
      if ($exitcond$i8$i) {
       break;
      } else {
       $i$01$i6$i = $86;
      }
     }
    }
    $87 = (($1) + 268|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = $88 & 2147483647;
    $90 = ($89|0)!=(0);
    $91 = ($88|0)>(-1);
    $or$cond$i$i$i11$i = $90 & $91;
    do {
     if ($or$cond$i$i$i11$i) {
      $92 = (($1) + 260|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = ($1|0)==($93|0);
      if ($94) {
       HEAP8[$67>>0] = 0;
       break;
      }
      $95 = ($93|0)==(0|0);
      if (!($95)) {
       $96 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = (($97) + 12|0);
       $99 = HEAP32[$98>>2]|0;
       FUNCTION_TABLE_vii[$99 & 4095]($96,$93);
      }
     }
    } while(0);
    $100 = HEAP32[$66>>2]|0;
    $101 = $100 & 2147483647;
    $102 = ($101|0)!=(0);
    $103 = ($100|0)>(-1);
    $or$cond$i$i$i$i1 = $102 & $103;
    if ($or$cond$i$i$i$i1) {
     $104 = HEAP32[$64>>2]|0;
     $105 = ($scShapes$i|0)==($104|0);
     if ($105) {
      HEAP8[$63>>0] = 0;
      break;
     }
     $106 = ($104|0)==(0|0);
     if (!($106)) {
      $107 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = (($108) + 12|0);
      $110 = HEAP32[$109>>2]|0;
      FUNCTION_TABLE_vii[$110 & 4095]($107,$104);
     }
    }
   }
  }
 } while(0);
 $111 = (($rigidStatic) + 4|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = $112 & -33;
 HEAP32[$111>>2] = $113;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene16removeRigidNoSimINS0_11RigidStaticELb0ELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i8$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i11$i = 0, $scShapes$i = 0, $shapes$i3$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $0 = sp + 824|0;
 $1 = sp;
 $shapes$i3$i = sp + 4|0;
 $2 = sp + 8|0;
 $scShapes$i = sp + 280|0;
 $3 = sp + 552|0;
 $4 = (($this) + 2417|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $$idx = (($this) + 1260|0);
  $$idx$val = HEAP32[$$idx>>2]|0;
  __ZL22addOrRemoveRigidObjectILb0ELb0ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_b($$idx$val,$v);
  $7 = (($v) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 268435455;
  HEAP32[$7>>2] = $9;
  HEAP32[$v>>2] = 0;
  STACKTOP = sp;return;
 }
 $10 = (($v) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 1)) {
  $13 = $11 & 1073741823;
  HEAP32[$10>>2] = $13;
  HEAP32[$0>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
 } else if ((($12|0) == 2)) {
  $14 = $11 | -1073741824;
  HEAP32[$10>>2] = $14;
  $15 = $11 & 268435456;
  $16 = ($15|0)==(0);
  if ($16) {
   HEAP32[$1>>2] = $v;
   $17 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
   $18 = HEAP8[$0>>0]|0;
   $19 = ($18<<24>>24)!=(0);
   $20 = ($17|0)==(0|0);
   $or$cond$i$i$i = $19 | $20;
   if (!($or$cond$i$i$i)) {
    $21 = HEAP32[$1>>2]|0;
    HEAP32[$17>>2] = $21;
   }
  }
 }
 $$idx1 = (($this) + 1260|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $22 = ($$idx1$val|0)==(0|0);
 if (!($22)) {
  $23 = (($$idx1$val) + 272|0);
  $24 = (($2) + 256|0);
  HEAP8[$24>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($2,$23);
  $25 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $26 = (($25) + -16)|0;
  $27 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($v,$shapes$i3$i)|0);
  $28 = HEAP32[$v>>2]|0;
  $29 = HEAP32[$10>>2]|0;
  $30 = $29 & -1073741824;
  $31 = ($27|0)==(0);
  if (!($31)) {
   $$sum$i$i = (($25) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $32 = HEAP32[$shapes$i3$i>>2]|0;
    $33 = (($32) + ($i$01$i$i<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + ($$sum$i$i)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36 & 251658240;
    $38 = ($37|0)==(16777216);
    if ($38) {
     $39 = (($34) + ($26)|0);
     $40 = $36 & 1073741823;
     $41 = $40 | $30;
     HEAP32[$35>>2] = $41;
     HEAP32[$39>>2] = $28;
    }
    $42 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($42|0)==($27|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $42;
    }
   }
  }
  $43 = (($2) + 268|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & 2147483647;
  $46 = ($45|0)!=(0);
  $47 = ($44|0)>(-1);
  $or$cond$i$i$i1$i = $46 & $47;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $48 = (($2) + 260|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($2|0)==($49|0);
  if ($50) {
   HEAP8[$24>>0] = 0;
   STACKTOP = sp;return;
  }
  $51 = ($49|0)==(0|0);
  if ($51) {
   STACKTOP = sp;return;
  }
  $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  STACKTOP = sp;return;
 }
 $56 = (($scShapes$i) + 256|0);
 $57 = (($scShapes$i) + 260|0);
 $58 = (($scShapes$i) + 264|0);
 HEAP32[$58>>2] = 0;
 $59 = (($scShapes$i) + 268|0);
 HEAP8[$56>>0] = 1;
 HEAP32[$57>>2] = $scShapes$i;
 HEAP32[$59>>2] = 64;
 $60 = (($3) + 256|0);
 HEAP8[$60>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($3,$scShapes$i);
 $61 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $62 = (($61) + -16)|0;
 $63 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($v,$shapes$i3$i)|0);
 $64 = HEAP32[$v>>2]|0;
 $65 = HEAP32[$10>>2]|0;
 $66 = $65 & -1073741824;
 $67 = ($63|0)==(0);
 if (!($67)) {
  $$sum$i4$i = (($61) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $68 = HEAP32[$shapes$i3$i>>2]|0;
   $69 = (($68) + ($i$01$i6$i<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + ($$sum$i4$i)|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = $72 & 251658240;
   $74 = ($73|0)==(16777216);
   if ($74) {
    $75 = (($70) + ($62)|0);
    $76 = $72 & 1073741823;
    $77 = $76 | $66;
    HEAP32[$71>>2] = $77;
    HEAP32[$75>>2] = $64;
   }
   $78 = (($i$01$i6$i) + 1)|0;
   $exitcond$i8$i = ($78|0)==($63|0);
   if ($exitcond$i8$i) {
    break;
   } else {
    $i$01$i6$i = $78;
   }
  }
 }
 $79 = (($3) + 268|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = $80 & 2147483647;
 $82 = ($81|0)!=(0);
 $83 = ($80|0)>(-1);
 $or$cond$i$i$i11$i = $82 & $83;
 do {
  if ($or$cond$i$i$i11$i) {
   $84 = (($3) + 260|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($3|0)==($85|0);
   if ($86) {
    HEAP8[$60>>0] = 0;
    break;
   }
   $87 = ($85|0)==(0|0);
   if (!($87)) {
    $88 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($89) + 12|0);
    $91 = HEAP32[$90>>2]|0;
    FUNCTION_TABLE_vii[$91 & 4095]($88,$85);
   }
  }
 } while(0);
 $92 = HEAP32[$59>>2]|0;
 $93 = $92 & 2147483647;
 $94 = ($93|0)!=(0);
 $95 = ($92|0)>(-1);
 $or$cond$i$i$i$i = $94 & $95;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $96 = HEAP32[$57>>2]|0;
 $97 = ($scShapes$i|0)==($96|0);
 if ($97) {
  HEAP8[$56>>0] = 0;
  STACKTOP = sp;return;
 }
 $98 = ($96|0)==(0|0);
 if ($98) {
  STACKTOP = sp;return;
 }
 $99 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) + 12|0);
 $102 = HEAP32[$101>>2]|0;
 FUNCTION_TABLE_vii[$102 & 4095]($99,$96);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene12addRigidBodyERNS0_4BodyEb($this,$body,$noSim) {
 $this = $this|0;
 $body = $body|0;
 $noSim = $noSim|0;
 var $$idx = 0, $$idx$val = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0);
 var $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0;
 var $exitcond$i8$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i11$i = 0, $scShapes$i = 0, $shapes$i3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $shapes$i3$i = sp + 816|0;
 $0 = sp;
 $scShapes$i = sp + 272|0;
 $1 = sp + 544|0;
 $2 = (($this) + 2564|0);
 if ($noSim) {
  __ZN5physx3Scb5Scene13addRigidNoSimINS0_4BodyELb1ELb1EEEvRT_RNS0_13ObjectTrackerE($this,$body,$2);
  $112 = (($body) + 228|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = $113 == Math_fround(0.0);
  if ($114) {
   $115 = (($body) + 204|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   $117 = $116 == Math_fround(0.0);
   if ($117) {
    $118 = (($body) + 208|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = $119 == Math_fround(0.0);
    if ($120) {
     $121 = (($body) + 212|0);
     $122 = Math_fround(HEAPF32[$121>>2]);
     $123 = $122 == Math_fround(0.0);
     if ($123) {
      $124 = (($body) + 216|0);
      $125 = Math_fround(HEAPF32[$124>>2]);
      $126 = $125 == Math_fround(0.0);
      if ($126) {
       $127 = (($body) + 220|0);
       $128 = Math_fround(HEAPF32[$127>>2]);
       $129 = $128 == Math_fround(0.0);
       if ($129) {
        $130 = (($body) + 224|0);
        $131 = Math_fround(HEAPF32[$130>>2]);
        $132 = $131 == Math_fround(0.0);
        if ($132) {
         $133 = (($body) + 232|0);
         HEAP32[$133>>2] = 1;
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
  $134 = (($body) + 232|0);
  HEAP32[$134>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZN5physx3Scb5Scene3addINS0_4BodyELb1EEEvRT_RNS0_13ObjectTrackerE($this,$body,$2);
 $3 = (($body) + 228|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = $4 == Math_fround(0.0);
 if ($5) {
  $6 = (($body) + 204|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = $7 == Math_fround(0.0);
  if ($8) {
   $9 = (($body) + 208|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = $10 == Math_fround(0.0);
   if ($11) {
    $12 = (($body) + 212|0);
    $13 = Math_fround(HEAPF32[$12>>2]);
    $14 = $13 == Math_fround(0.0);
    if ($14) {
     $15 = (($body) + 216|0);
     $16 = Math_fround(HEAPF32[$15>>2]);
     $17 = $16 == Math_fround(0.0);
     if ($17) {
      $18 = (($body) + 220|0);
      $19 = Math_fround(HEAPF32[$18>>2]);
      $20 = $19 == Math_fround(0.0);
      if ($20) {
       $21 = (($body) + 224|0);
       $22 = Math_fround(HEAPF32[$21>>2]);
       $23 = $22 == Math_fround(0.0);
       if ($23) {
        $24 = (($body) + 232|0);
        HEAP32[$24>>2] = 1;
       } else {
        label = 10;
       }
      } else {
       label = 10;
      }
     } else {
      label = 10;
     }
    } else {
     label = 10;
    }
   } else {
    label = 10;
   }
  } else {
   label = 10;
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $25 = (($body) + 232|0);
  HEAP32[$25>>2] = 0;
 }
 $26 = (($this) + 2417|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $$idx = (($this) + 1260|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $29 = ($$idx$val|0)==(0|0);
 if (!($29)) {
  $30 = (($$idx$val) + 272|0);
  $31 = (($0) + 256|0);
  HEAP8[$31>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$30);
  $32 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $33 = (($32) + -16)|0;
  $34 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($body,$shapes$i3$i)|0);
  $35 = HEAP32[$body>>2]|0;
  $36 = (($body) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = $37 & -1073741824;
  $39 = ($34|0)==(0);
  if (!($39)) {
   $$sum$i$i = (($32) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $40 = HEAP32[$shapes$i3$i>>2]|0;
    $41 = (($40) + ($i$01$i$i<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + ($$sum$i$i)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = $44 & 251658240;
    $46 = ($45|0)==(16777216);
    if ($46) {
     $47 = (($42) + ($33)|0);
     $48 = $44 & 1073741823;
     $49 = $48 | $38;
     HEAP32[$43>>2] = $49;
     HEAP32[$47>>2] = $35;
    }
    $50 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($50|0)==($34|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $50;
    }
   }
  }
  $51 = (($0) + 268|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 & 2147483647;
  $54 = ($53|0)!=(0);
  $55 = ($52|0)>(-1);
  $or$cond$i$i$i1$i = $54 & $55;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $56 = (($0) + 260|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($0|0)==($57|0);
  if ($58) {
   HEAP8[$31>>0] = 0;
   STACKTOP = sp;return;
  }
  $59 = ($57|0)==(0|0);
  if ($59) {
   STACKTOP = sp;return;
  }
  $60 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 12|0);
  $63 = HEAP32[$62>>2]|0;
  FUNCTION_TABLE_vii[$63 & 4095]($60,$57);
  STACKTOP = sp;return;
 }
 $64 = (($scShapes$i) + 256|0);
 $65 = (($scShapes$i) + 260|0);
 $66 = (($scShapes$i) + 264|0);
 HEAP32[$66>>2] = 0;
 $67 = (($scShapes$i) + 268|0);
 HEAP8[$64>>0] = 1;
 HEAP32[$65>>2] = $scShapes$i;
 HEAP32[$67>>2] = 64;
 $68 = (($1) + 256|0);
 HEAP8[$68>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes$i);
 $69 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $70 = (($69) + -16)|0;
 $71 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($body,$shapes$i3$i)|0);
 $72 = HEAP32[$body>>2]|0;
 $73 = (($body) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $74 & -1073741824;
 $76 = ($71|0)==(0);
 if (!($76)) {
  $$sum$i4$i = (($69) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $77 = HEAP32[$shapes$i3$i>>2]|0;
   $78 = (($77) + ($i$01$i6$i<<2)|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($79) + ($$sum$i4$i)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = $81 & 251658240;
   $83 = ($82|0)==(16777216);
   if ($83) {
    $84 = (($79) + ($70)|0);
    $85 = $81 & 1073741823;
    $86 = $85 | $75;
    HEAP32[$80>>2] = $86;
    HEAP32[$84>>2] = $72;
   }
   $87 = (($i$01$i6$i) + 1)|0;
   $exitcond$i8$i = ($87|0)==($71|0);
   if ($exitcond$i8$i) {
    break;
   } else {
    $i$01$i6$i = $87;
   }
  }
 }
 $88 = (($1) + 268|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = $89 & 2147483647;
 $91 = ($90|0)!=(0);
 $92 = ($89|0)>(-1);
 $or$cond$i$i$i11$i = $91 & $92;
 do {
  if ($or$cond$i$i$i11$i) {
   $93 = (($1) + 260|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($1|0)==($94|0);
   if ($95) {
    HEAP8[$68>>0] = 0;
    break;
   }
   $96 = ($94|0)==(0|0);
   if (!($96)) {
    $97 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (($98) + 12|0);
    $100 = HEAP32[$99>>2]|0;
    FUNCTION_TABLE_vii[$100 & 4095]($97,$94);
   }
  }
 } while(0);
 $101 = HEAP32[$67>>2]|0;
 $102 = $101 & 2147483647;
 $103 = ($102|0)!=(0);
 $104 = ($101|0)>(-1);
 $or$cond$i$i$i$i = $103 & $104;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $105 = HEAP32[$65>>2]|0;
 $106 = ($scShapes$i|0)==($105|0);
 if ($106) {
  HEAP8[$64>>0] = 0;
  STACKTOP = sp;return;
 }
 $107 = ($105|0)==(0|0);
 if ($107) {
  STACKTOP = sp;return;
 }
 $108 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = (($109) + 12|0);
 $111 = HEAP32[$110>>2]|0;
 FUNCTION_TABLE_vii[$111 & 4095]($108,$105);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene3addINS0_4BodyELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 HEAP32[$v>>2] = $this;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 if ($4) {
  $7 = $6 & 268435455;
  $8 = $7 | -2147483648;
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 16|0);
  __ZN10ScSceneFnsIN5physx3Scb4BodyEE6insertERNS0_2Sc5SceneERS2_($9,$v);
  STACKTOP = sp;return;
 }
 $$mask$i = $6 & -1073741824;
 $10 = ($$mask$i|0)==(-1073741824);
 $11 = $6 & 1073741823;
 if ($10) {
  $12 = $11 | -2147483648;
  HEAP32[$5>>2] = $12;
  $13 = $6 & 268435456;
  $14 = ($13|0)==(0);
  if (!($14)) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
  STACKTOP = sp;return;
 } else {
  $15 = $11 | 1073741824;
  HEAP32[$5>>2] = $15;
  HEAP32[$1>>2] = $v;
  $16 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
  $17 = HEAP8[$0>>0]|0;
  $18 = ($17<<24>>24)!=(0);
  $19 = ($16|0)==(0|0);
  $or$cond$i$i$i = $18 | $19;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $20 = HEAP32[$1>>2]|0;
  HEAP32[$16>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene13addRigidNoSimINS0_4BodyELb1ELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$mask$i = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i8$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i11$i = 0, $scShapes$i = 0, $shapes$i3$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $0 = sp + 824|0;
 $1 = sp;
 $shapes$i3$i = sp + 4|0;
 $2 = sp + 8|0;
 $scShapes$i = sp + 280|0;
 $3 = sp + 552|0;
 HEAP32[$v>>2] = $this;
 $4 = (($this) + 2417|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $7 = (($v) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $9 = $8 & 268435455;
  $10 = $9 | -2147483648;
  HEAP32[$7>>2] = $10;
  $$idx = (($this) + 1260|0);
  $$idx$val = HEAP32[$$idx>>2]|0;
  __ZL22addOrRemoveRigidObjectILb0ELb1ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_b($$idx$val,$v);
  STACKTOP = sp;return;
 }
 $$mask$i = $8 & -1073741824;
 $11 = ($$mask$i|0)==(-1073741824);
 $12 = $8 & 1073741823;
 if ($11) {
  $13 = $12 | -2147483648;
  HEAP32[$7>>2] = $13;
  $14 = $8 & 268435456;
  $15 = ($14|0)==(0);
  if ($15) {
   HEAP32[$0>>2] = $v;
   (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
  }
 } else {
  $16 = $12 | 1073741824;
  HEAP32[$7>>2] = $16;
  HEAP32[$1>>2] = $v;
  $17 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
  $18 = HEAP8[$0>>0]|0;
  $19 = ($18<<24>>24)!=(0);
  $20 = ($17|0)==(0|0);
  $or$cond$i$i$i = $19 | $20;
  if (!($or$cond$i$i$i)) {
   $21 = HEAP32[$1>>2]|0;
   HEAP32[$17>>2] = $21;
  }
 }
 $$idx1 = (($this) + 1260|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $22 = ($$idx1$val|0)==(0|0);
 if (!($22)) {
  $23 = (($$idx1$val) + 272|0);
  $24 = (($2) + 256|0);
  HEAP8[$24>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($2,$23);
  $25 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $26 = (($25) + -16)|0;
  $27 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($v,$shapes$i3$i)|0);
  $28 = HEAP32[$v>>2]|0;
  $29 = HEAP32[$7>>2]|0;
  $30 = $29 & -1073741824;
  $31 = ($27|0)==(0);
  if (!($31)) {
   $$sum$i$i = (($25) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $32 = HEAP32[$shapes$i3$i>>2]|0;
    $33 = (($32) + ($i$01$i$i<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + ($$sum$i$i)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36 & 251658240;
    $38 = ($37|0)==(16777216);
    if ($38) {
     $39 = (($34) + ($26)|0);
     $40 = $36 & 1073741823;
     $41 = $40 | $30;
     HEAP32[$35>>2] = $41;
     HEAP32[$39>>2] = $28;
    }
    $42 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($42|0)==($27|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $42;
    }
   }
  }
  $43 = (($2) + 268|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & 2147483647;
  $46 = ($45|0)!=(0);
  $47 = ($44|0)>(-1);
  $or$cond$i$i$i1$i = $46 & $47;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $48 = (($2) + 260|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($2|0)==($49|0);
  if ($50) {
   HEAP8[$24>>0] = 0;
   STACKTOP = sp;return;
  }
  $51 = ($49|0)==(0|0);
  if ($51) {
   STACKTOP = sp;return;
  }
  $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  STACKTOP = sp;return;
 }
 $56 = (($scShapes$i) + 256|0);
 $57 = (($scShapes$i) + 260|0);
 $58 = (($scShapes$i) + 264|0);
 HEAP32[$58>>2] = 0;
 $59 = (($scShapes$i) + 268|0);
 HEAP8[$56>>0] = 1;
 HEAP32[$57>>2] = $scShapes$i;
 HEAP32[$59>>2] = 64;
 $60 = (($3) + 256|0);
 HEAP8[$60>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($3,$scShapes$i);
 $61 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $62 = (($61) + -16)|0;
 $63 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($v,$shapes$i3$i)|0);
 $64 = HEAP32[$v>>2]|0;
 $65 = HEAP32[$7>>2]|0;
 $66 = $65 & -1073741824;
 $67 = ($63|0)==(0);
 if (!($67)) {
  $$sum$i4$i = (($61) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $68 = HEAP32[$shapes$i3$i>>2]|0;
   $69 = (($68) + ($i$01$i6$i<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + ($$sum$i4$i)|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = $72 & 251658240;
   $74 = ($73|0)==(16777216);
   if ($74) {
    $75 = (($70) + ($62)|0);
    $76 = $72 & 1073741823;
    $77 = $76 | $66;
    HEAP32[$71>>2] = $77;
    HEAP32[$75>>2] = $64;
   }
   $78 = (($i$01$i6$i) + 1)|0;
   $exitcond$i8$i = ($78|0)==($63|0);
   if ($exitcond$i8$i) {
    break;
   } else {
    $i$01$i6$i = $78;
   }
  }
 }
 $79 = (($3) + 268|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = $80 & 2147483647;
 $82 = ($81|0)!=(0);
 $83 = ($80|0)>(-1);
 $or$cond$i$i$i11$i = $82 & $83;
 do {
  if ($or$cond$i$i$i11$i) {
   $84 = (($3) + 260|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($3|0)==($85|0);
   if ($86) {
    HEAP8[$60>>0] = 0;
    break;
   }
   $87 = ($85|0)==(0|0);
   if (!($87)) {
    $88 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($89) + 12|0);
    $91 = HEAP32[$90>>2]|0;
    FUNCTION_TABLE_vii[$91 & 4095]($88,$85);
   }
  }
 } while(0);
 $92 = HEAP32[$59>>2]|0;
 $93 = $92 & 2147483647;
 $94 = ($93|0)!=(0);
 $95 = ($92|0)>(-1);
 $or$cond$i$i$i$i = $94 & $95;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $96 = HEAP32[$57>>2]|0;
 $97 = ($scShapes$i|0)==($96|0);
 if ($97) {
  HEAP8[$56>>0] = 0;
  STACKTOP = sp;return;
 }
 $98 = ($96|0)==(0|0);
 if ($98) {
  STACKTOP = sp;return;
 }
 $99 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) + 12|0);
 $102 = HEAP32[$101>>2]|0;
 FUNCTION_TABLE_vii[$102 & 4095]($99,$96);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene15removeRigidBodyERNS0_4BodyEbb($this,$body,$wakeOnLostTouch,$noSim) {
 $this = $this|0;
 $body = $body|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 $noSim = $noSim|0;
 var $$idx = 0, $$idx$val = 0, $$in$i = 0, $$in$i3 = 0, $$mask$i$i = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exists$i$i$i$i = 0, $exitcond$i$i = 0, $exitcond$i8$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i$i1 = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i11$i = 0, $scShapes$i = 0, $shapes$i3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $shapes$i3$i = sp + 820|0;
 $0 = sp;
 $scShapes$i = sp + 272|0;
 $1 = sp + 544|0;
 $exists$i$i$i$i = sp + 824|0;
 $2 = sp + 816|0;
 if ($noSim) {
  $147 = (($this) + 2564|0);
  __ZN5physx3Scb5Scene16removeRigidNoSimINS0_4BodyELb1ELb1EEEvRT_RNS0_13ObjectTrackerE($this,$body,$147);
  $148 = (($body) + 236|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = $149 & 4096;
  $151 = ($150|0)==(0);
  if ($151) {
   $163 = (($body) + 60|0);
   $$in$i3 = $163;
  } else {
   $152 = (($body) + 8|0);
   $153 = HEAP32[$152>>2]|0;
   $154 = ($153|0)==(0|0);
   if ($154) {
    $155 = HEAP32[$body>>2]|0;
    $156 = (($body) + 4|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = $157 >>> 24;
    $159 = $158 & 15;
    $160 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($155,$159)|0);
    HEAP32[$152>>2] = $160;
    $162 = $160;
   } else {
    $162 = $153;
   }
   $161 = (($162) + 268|0);
   $$in$i3 = $161;
  }
  $164 = HEAP8[$$in$i3>>0]|0;
  $165 = $164 & 1;
  $166 = ($165<<24>>24)==(0);
  if ($166) {
   $167 = (($body) + 232|0);
   HEAP32[$167>>2] = 1;
   $168 = HEAP32[$148>>2]|0;
   $169 = $168 & -49153;
   HEAP32[$148>>2] = $169;
  } else {
   __ZN5physx3Scb4Body18putToSleepInternalEv($body);
  }
  $170 = (($body) + 4|0);
  $171 = HEAP32[$170>>2]|0;
  $172 = $171 & -33;
  HEAP32[$170>>2] = $172;
  STACKTOP = sp;return;
 }
 $3 = (($body) + 16|0);
 $4 = (($body) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $$mask$i$i = $5 & -1073741824;
 $6 = ($$mask$i$i|0)==(1073741824);
 do {
  if ($6) {
   $7 = (($body) + 172|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($3,1)|0);
    $11 = HEAP32[$7>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($10) {
     if ($12) {
      break;
     }
     $13 = HEAP32[$body>>2]|0;
     $14 = (($13) + 1256|0);
     $15 = HEAP32[$14>>2]|0;
     __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($3,$15,1);
     break;
    }
    if (!($12)) {
     $16 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($3,0)|0);
     if ($16) {
      $17 = HEAP32[$7>>2]|0;
      $18 = ($17|0)==(0|0);
      if (!($18)) {
       $19 = HEAP32[$body>>2]|0;
       $20 = (($19) + 1256|0);
       $21 = HEAP32[$20>>2]|0;
       __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($3,$21,0);
      }
     }
    }
   }
  }
 } while(0);
 $22 = (($this) + 2564|0);
 $23 = (($this) + 2417|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 do {
  if ($25) {
   $26 = (($this) + 16|0);
   __ZN10ScSceneFnsIN5physx3Scb4BodyEE6removeERNS0_2Sc5SceneERS2_b($26,$body,$wakeOnLostTouch);
   $27 = HEAP32[$4>>2]|0;
   $28 = $27 & 268435455;
   HEAP32[$4>>2] = $28;
   HEAP32[$body>>2] = 0;
  } else {
   $29 = HEAP32[$4>>2]|0;
   $30 = $29 >>> 30;
   if ((($30|0) == 1)) {
    $31 = $29 & 1073741823;
    HEAP32[$4>>2] = $31;
    HEAP32[$shapes$i3$i>>2] = $body;
    (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($22,$shapes$i3$i)|0);
    break;
   } else if (!((($30|0) == 2))) {
    break;
   }
   $32 = $29 | -1073741824;
   HEAP32[$4>>2] = $32;
   $33 = $29 & 268435456;
   $34 = ($33|0)==(0);
   if ($34) {
    HEAP32[$2>>2] = $body;
    $35 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($22,$2,$exists$i$i$i$i)|0);
    $36 = HEAP8[$exists$i$i$i$i>>0]|0;
    $37 = ($36<<24>>24)!=(0);
    $38 = ($35|0)==(0|0);
    $or$cond$i$i$i$i = $37 | $38;
    if (!($or$cond$i$i$i$i)) {
     $39 = HEAP32[$2>>2]|0;
     HEAP32[$35>>2] = $39;
    }
   }
  }
 } while(0);
 $40 = (($body) + 236|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 4096;
 $43 = ($42|0)==(0);
 if ($43) {
  $54 = (($body) + 60|0);
  $$in$i = $54;
 } else {
  $44 = (($body) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  if ($46) {
   $47 = HEAP32[$body>>2]|0;
   $48 = HEAP32[$4>>2]|0;
   $49 = $48 >>> 24;
   $50 = $49 & 15;
   $51 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($47,$50)|0);
   HEAP32[$44>>2] = $51;
   $53 = $51;
  } else {
   $53 = $45;
  }
  $52 = (($53) + 268|0);
  $$in$i = $52;
 }
 $55 = HEAP8[$$in$i>>0]|0;
 $56 = $55 & 1;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $58 = (($body) + 232|0);
  HEAP32[$58>>2] = 1;
  $59 = HEAP32[$40>>2]|0;
  $60 = $59 & -49153;
  HEAP32[$40>>2] = $60;
 } else {
  __ZN5physx3Scb4Body18putToSleepInternalEv($body);
 }
 $61 = HEAP32[$4>>2]|0;
 $62 = $61 & -33;
 HEAP32[$4>>2] = $62;
 $63 = HEAP8[$23>>0]|0;
 $64 = ($63<<24>>24)==(0);
 if ($64) {
  STACKTOP = sp;return;
 }
 if ($wakeOnLostTouch) {
  $65 = $62 | 16;
  HEAP32[$4>>2] = $65;
 }
 $$idx = (($this) + 1260|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $66 = ($$idx$val|0)==(0|0);
 if (!($66)) {
  $67 = (($$idx$val) + 272|0);
  $68 = (($0) + 256|0);
  HEAP8[$68>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$67);
  $69 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $70 = (($69) + -16)|0;
  $71 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($body,$shapes$i3$i)|0);
  $72 = HEAP32[$body>>2]|0;
  $73 = HEAP32[$4>>2]|0;
  $74 = $73 & -1073741824;
  $75 = ($71|0)==(0);
  if (!($75)) {
   $$sum$i$i = (($69) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $76 = HEAP32[$shapes$i3$i>>2]|0;
    $77 = (($76) + ($i$01$i$i<<2)|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (($78) + ($$sum$i$i)|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = $80 & 251658240;
    $82 = ($81|0)==(16777216);
    if ($82) {
     $83 = (($78) + ($70)|0);
     $84 = $80 & 1073741823;
     $85 = $84 | $74;
     HEAP32[$79>>2] = $85;
     HEAP32[$83>>2] = $72;
    }
    $86 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($86|0)==($71|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $86;
    }
   }
  }
  $87 = (($0) + 268|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = $88 & 2147483647;
  $90 = ($89|0)!=(0);
  $91 = ($88|0)>(-1);
  $or$cond$i$i$i1$i = $90 & $91;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $92 = (($0) + 260|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = ($0|0)==($93|0);
  if ($94) {
   HEAP8[$68>>0] = 0;
   STACKTOP = sp;return;
  }
  $95 = ($93|0)==(0|0);
  if ($95) {
   STACKTOP = sp;return;
  }
  $96 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($97) + 12|0);
  $99 = HEAP32[$98>>2]|0;
  FUNCTION_TABLE_vii[$99 & 4095]($96,$93);
  STACKTOP = sp;return;
 }
 $100 = (($scShapes$i) + 256|0);
 $101 = (($scShapes$i) + 260|0);
 $102 = (($scShapes$i) + 264|0);
 HEAP32[$102>>2] = 0;
 $103 = (($scShapes$i) + 268|0);
 HEAP8[$100>>0] = 1;
 HEAP32[$101>>2] = $scShapes$i;
 HEAP32[$103>>2] = 64;
 $104 = (($1) + 256|0);
 HEAP8[$104>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes$i);
 $105 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $106 = (($105) + -16)|0;
 $107 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($body,$shapes$i3$i)|0);
 $108 = HEAP32[$body>>2]|0;
 $109 = HEAP32[$4>>2]|0;
 $110 = $109 & -1073741824;
 $111 = ($107|0)==(0);
 if (!($111)) {
  $$sum$i4$i = (($105) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $112 = HEAP32[$shapes$i3$i>>2]|0;
   $113 = (($112) + ($i$01$i6$i<<2)|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = (($114) + ($$sum$i4$i)|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = $116 & 251658240;
   $118 = ($117|0)==(16777216);
   if ($118) {
    $119 = (($114) + ($106)|0);
    $120 = $116 & 1073741823;
    $121 = $120 | $110;
    HEAP32[$115>>2] = $121;
    HEAP32[$119>>2] = $108;
   }
   $122 = (($i$01$i6$i) + 1)|0;
   $exitcond$i8$i = ($122|0)==($107|0);
   if ($exitcond$i8$i) {
    break;
   } else {
    $i$01$i6$i = $122;
   }
  }
 }
 $123 = (($1) + 268|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = $124 & 2147483647;
 $126 = ($125|0)!=(0);
 $127 = ($124|0)>(-1);
 $or$cond$i$i$i11$i = $126 & $127;
 do {
  if ($or$cond$i$i$i11$i) {
   $128 = (($1) + 260|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($1|0)==($129|0);
   if ($130) {
    HEAP8[$104>>0] = 0;
    break;
   }
   $131 = ($129|0)==(0|0);
   if (!($131)) {
    $132 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = (($133) + 12|0);
    $135 = HEAP32[$134>>2]|0;
    FUNCTION_TABLE_vii[$135 & 4095]($132,$129);
   }
  }
 } while(0);
 $136 = HEAP32[$103>>2]|0;
 $137 = $136 & 2147483647;
 $138 = ($137|0)!=(0);
 $139 = ($136|0)>(-1);
 $or$cond$i$i$i$i1 = $138 & $139;
 if (!($or$cond$i$i$i$i1)) {
  STACKTOP = sp;return;
 }
 $140 = HEAP32[$101>>2]|0;
 $141 = ($scShapes$i|0)==($140|0);
 if ($141) {
  HEAP8[$100>>0] = 0;
  STACKTOP = sp;return;
 }
 $142 = ($140|0)==(0|0);
 if ($142) {
  STACKTOP = sp;return;
 }
 $143 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = (($144) + 12|0);
 $146 = HEAP32[$145>>2]|0;
 FUNCTION_TABLE_vii[$146 & 4095]($143,$140);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene16removeRigidNoSimINS0_4BodyELb1ELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i8$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i11$i = 0, $scShapes$i = 0, $shapes$i3$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $0 = sp + 824|0;
 $1 = sp;
 $shapes$i3$i = sp + 4|0;
 $2 = sp + 8|0;
 $scShapes$i = sp + 280|0;
 $3 = sp + 552|0;
 $4 = (($this) + 2417|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $$idx = (($this) + 1260|0);
  $$idx$val = HEAP32[$$idx>>2]|0;
  __ZL22addOrRemoveRigidObjectILb0ELb0ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_b($$idx$val,$v);
  $7 = (($v) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 268435455;
  HEAP32[$7>>2] = $9;
  HEAP32[$v>>2] = 0;
  STACKTOP = sp;return;
 }
 $10 = (($v) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 30;
 if ((($12|0) == 1)) {
  $13 = $11 & 1073741823;
  HEAP32[$10>>2] = $13;
  HEAP32[$0>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
 } else if ((($12|0) == 2)) {
  $14 = $11 | -1073741824;
  HEAP32[$10>>2] = $14;
  $15 = $11 & 268435456;
  $16 = ($15|0)==(0);
  if ($16) {
   HEAP32[$1>>2] = $v;
   $17 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
   $18 = HEAP8[$0>>0]|0;
   $19 = ($18<<24>>24)!=(0);
   $20 = ($17|0)==(0|0);
   $or$cond$i$i$i = $19 | $20;
   if (!($or$cond$i$i$i)) {
    $21 = HEAP32[$1>>2]|0;
    HEAP32[$17>>2] = $21;
   }
  }
 }
 $$idx1 = (($this) + 1260|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $22 = ($$idx1$val|0)==(0|0);
 if (!($22)) {
  $23 = (($$idx1$val) + 272|0);
  $24 = (($2) + 256|0);
  HEAP8[$24>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($2,$23);
  $25 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $26 = (($25) + -16)|0;
  $27 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($v,$shapes$i3$i)|0);
  $28 = HEAP32[$v>>2]|0;
  $29 = HEAP32[$10>>2]|0;
  $30 = $29 & -1073741824;
  $31 = ($27|0)==(0);
  if (!($31)) {
   $$sum$i$i = (($25) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $32 = HEAP32[$shapes$i3$i>>2]|0;
    $33 = (($32) + ($i$01$i$i<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + ($$sum$i$i)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36 & 251658240;
    $38 = ($37|0)==(16777216);
    if ($38) {
     $39 = (($34) + ($26)|0);
     $40 = $36 & 1073741823;
     $41 = $40 | $30;
     HEAP32[$35>>2] = $41;
     HEAP32[$39>>2] = $28;
    }
    $42 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($42|0)==($27|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $42;
    }
   }
  }
  $43 = (($2) + 268|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & 2147483647;
  $46 = ($45|0)!=(0);
  $47 = ($44|0)>(-1);
  $or$cond$i$i$i1$i = $46 & $47;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $48 = (($2) + 260|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($2|0)==($49|0);
  if ($50) {
   HEAP8[$24>>0] = 0;
   STACKTOP = sp;return;
  }
  $51 = ($49|0)==(0|0);
  if ($51) {
   STACKTOP = sp;return;
  }
  $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  STACKTOP = sp;return;
 }
 $56 = (($scShapes$i) + 256|0);
 $57 = (($scShapes$i) + 260|0);
 $58 = (($scShapes$i) + 264|0);
 HEAP32[$58>>2] = 0;
 $59 = (($scShapes$i) + 268|0);
 HEAP8[$56>>0] = 1;
 HEAP32[$57>>2] = $scShapes$i;
 HEAP32[$59>>2] = 64;
 $60 = (($3) + 256|0);
 HEAP8[$60>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($3,$scShapes$i);
 $61 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $62 = (($61) + -16)|0;
 $63 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($v,$shapes$i3$i)|0);
 $64 = HEAP32[$v>>2]|0;
 $65 = HEAP32[$10>>2]|0;
 $66 = $65 & -1073741824;
 $67 = ($63|0)==(0);
 if (!($67)) {
  $$sum$i4$i = (($61) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $68 = HEAP32[$shapes$i3$i>>2]|0;
   $69 = (($68) + ($i$01$i6$i<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + ($$sum$i4$i)|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = $72 & 251658240;
   $74 = ($73|0)==(16777216);
   if ($74) {
    $75 = (($70) + ($62)|0);
    $76 = $72 & 1073741823;
    $77 = $76 | $66;
    HEAP32[$71>>2] = $77;
    HEAP32[$75>>2] = $64;
   }
   $78 = (($i$01$i6$i) + 1)|0;
   $exitcond$i8$i = ($78|0)==($63|0);
   if ($exitcond$i8$i) {
    break;
   } else {
    $i$01$i6$i = $78;
   }
  }
 }
 $79 = (($3) + 268|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = $80 & 2147483647;
 $82 = ($81|0)!=(0);
 $83 = ($80|0)>(-1);
 $or$cond$i$i$i11$i = $82 & $83;
 do {
  if ($or$cond$i$i$i11$i) {
   $84 = (($3) + 260|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($3|0)==($85|0);
   if ($86) {
    HEAP8[$60>>0] = 0;
    break;
   }
   $87 = ($85|0)==(0|0);
   if (!($87)) {
    $88 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($89) + 12|0);
    $91 = HEAP32[$90>>2]|0;
    FUNCTION_TABLE_vii[$91 & 4095]($88,$85);
   }
  }
 } while(0);
 $92 = HEAP32[$59>>2]|0;
 $93 = $92 & 2147483647;
 $94 = ($93|0)!=(0);
 $95 = ($92|0)>(-1);
 $or$cond$i$i$i$i = $94 & $95;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $96 = HEAP32[$57>>2]|0;
 $97 = ($scShapes$i|0)==($96|0);
 if ($97) {
  HEAP8[$56>>0] = 0;
  STACKTOP = sp;return;
 }
 $98 = ($96|0)==(0|0);
 if ($98) {
  STACKTOP = sp;return;
 }
 $99 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) + 12|0);
 $102 = HEAP32[$101>>2]|0;
 FUNCTION_TABLE_vii[$102 & 4095]($99,$96);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene13addConstraintERNS0_10ConstraintE($this,$constraint) {
 $this = $this|0;
 $constraint = $constraint|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2644|0);
 __ZN5physx3Scb5Scene3addINS0_10ConstraintELb1EEEvRT_RNS0_13ObjectTrackerE($this,$constraint,$0);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene3addINS0_10ConstraintELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $scb0$i = 0, $scb1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scb0$i = sp + 4|0;
 $scb1$i = sp;
 HEAP32[$v>>2] = $this;
 $0 = (($this) + 2417|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 if ($2) {
  $5 = $4 & 268435455;
  $6 = $5 | -2147483648;
  HEAP32[$3>>2] = $6;
  $7 = (($this) + 16|0);
  __ZN5physx34NpConstraintGetRigidObjectsFromScbERKNS_3Scb10ConstraintERPNS0_11RigidObjectES6_($v,$scb0$i,$scb1$i);
  $8 = (($v) + 12|0);
  $9 = HEAP32[$scb0$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $31 = 0;
  } else {
   $11 = $9;
   $12 = (($9) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 >>> 24;
   $15 = $14 & 15;
   $16 = ((444424 + ($15<<2)|0) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + ($11))|0;
   $19 = $18;
   $31 = $19;
  }
  $20 = HEAP32[$scb1$i>>2]|0;
  $21 = ($20|0)==(0|0);
  if ($21) {
   $32 = 0;
  } else {
   $22 = $20;
   $23 = (($20) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $24 >>> 24;
   $26 = $25 & 15;
   $27 = ((444424 + ($26<<2)|0) + 24|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + ($22))|0;
   $30 = $29;
   $32 = $30;
  }
  __ZN5physx2Sc5Scene13addConstraintERNS0_14ConstraintCoreEPNS0_9RigidCoreES5_($7,$8,$31,$32);
  STACKTOP = sp;return;
 }
 $$mask$i = $4 & -1073741824;
 $33 = ($$mask$i|0)==(-1073741824);
 $34 = $4 & 1073741823;
 if ($33) {
  $35 = $34 | -2147483648;
  HEAP32[$3>>2] = $35;
  $36 = $4 & 268435456;
  $37 = ($36|0)==(0);
  if (!($37)) {
   STACKTOP = sp;return;
  }
  HEAP32[$scb0$i>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$scb0$i)|0);
  STACKTOP = sp;return;
 } else {
  $38 = $34 | 1073741824;
  HEAP32[$3>>2] = $38;
  HEAP32[$scb1$i>>2] = $v;
  $39 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$scb1$i,$scb0$i)|0);
  $40 = HEAP8[$scb0$i>>0]|0;
  $41 = ($40<<24>>24)!=(0);
  $42 = ($39|0)==(0|0);
  $or$cond$i$i$i = $41 | $42;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $43 = HEAP32[$scb1$i>>2]|0;
  HEAP32[$39>>2] = $43;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene16removeConstraintERNS0_10ConstraintE($this,$constraint) {
 $this = $this|0;
 $constraint = $constraint|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 16|0);
  $6 = (($constraint) + 12|0);
  __ZN5physx2Sc5Scene16removeConstraintERNS0_14ConstraintCoreE($5,$6);
  $7 = (($constraint) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 268435455;
  HEAP32[$7>>2] = $9;
  HEAP32[$constraint>>2] = 0;
  STACKTOP = sp;return;
 }
 $10 = (($this) + 2644|0);
 $11 = (($constraint) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 >>> 30;
 if ((($13|0) == 1)) {
  $14 = $12 & 1073741823;
  HEAP32[$11>>2] = $14;
  HEAP32[$0>>2] = $constraint;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($10,$0)|0);
  STACKTOP = sp;return;
 } else if ((($13|0) == 2)) {
  $15 = $12 | -1073741824;
  HEAP32[$11>>2] = $15;
  $16 = $12 & 268435456;
  $17 = ($16|0)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
  HEAP32[$1>>2] = $constraint;
  $18 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($10,$1,$0)|0);
  $19 = HEAP8[$0>>0]|0;
  $20 = ($19<<24>>24)!=(0);
  $21 = ($18|0)==(0|0);
  $or$cond$i$i$i = $20 | $21;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $22 = HEAP32[$1>>2]|0;
  HEAP32[$18>>2] = $22;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene15addArticulationERNS0_12ArticulationE($this,$articulation) {
 $this = $this|0;
 $articulation = $articulation|0;
 var $$$i = 0, $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2684|0);
 __ZN5physx3Scb5Scene3addINS0_12ArticulationELb1EEEvRT_RNS0_13ObjectTrackerE($this,$articulation,$0);
 $1 = (($articulation) + 48|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 == Math_fround(0.0);
 $4 = (($articulation) + 52|0);
 $$$i = $3&1;
 HEAP8[$4>>0] = $$$i;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene3addINS0_12ArticulationELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 HEAP32[$v>>2] = $this;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 if ($4) {
  $7 = $6 & 268435455;
  $8 = $7 | -2147483648;
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 16|0);
  $10 = (__ZN5physx28NpArticulationGetRootFromScbERNS_3Scb12ArticulationE($v)|0);
  $11 = (($v) + 12|0);
  $12 = (($10) + 16|0);
  __ZN5physx2Sc5Scene15addArticulationERNS0_16ArticulationCoreERNS0_8BodyCoreE($9,$11,$12);
  STACKTOP = sp;return;
 }
 $$mask$i = $6 & -1073741824;
 $13 = ($$mask$i|0)==(-1073741824);
 $14 = $6 & 1073741823;
 if ($13) {
  $15 = $14 | -2147483648;
  HEAP32[$5>>2] = $15;
  $16 = $6 & 268435456;
  $17 = ($16|0)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
  STACKTOP = sp;return;
 } else {
  $18 = $14 | 1073741824;
  HEAP32[$5>>2] = $18;
  HEAP32[$1>>2] = $v;
  $19 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
  $20 = HEAP8[$0>>0]|0;
  $21 = ($20<<24>>24)!=(0);
  $22 = ($19|0)==(0|0);
  $or$cond$i$i$i = $21 | $22;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$1>>2]|0;
  HEAP32[$19>>2] = $23;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene18removeArticulationERNS0_12ArticulationE($this,$articulation) {
 $this = $this|0;
 $articulation = $articulation|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2684|0);
 __ZN5physx3Scb5Scene6removeINS0_12ArticulationELb1EEEvRT_RNS0_13ObjectTrackerEb($this,$articulation,$0,0);
 $1 = (($articulation) + 52|0);
 HEAP8[$1>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene6removeINS0_12ArticulationELb1EEEvRT_RNS0_13ObjectTrackerEb($this,$v,$tracker,$wakeOnLostTouch) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 16|0);
  $6 = (($v) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & -769;
  HEAP32[$6>>2] = $8;
  $9 = (($v) + 12|0);
  __ZN5physx2Sc5Scene18removeArticulationERNS0_16ArticulationCoreE($5,$9);
  $10 = HEAP32[$6>>2]|0;
  $11 = $10 & 268435455;
  HEAP32[$6>>2] = $11;
  HEAP32[$v>>2] = 0;
  STACKTOP = sp;return;
 }
 $12 = (($v) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 30;
 if ((($14|0) == 1)) {
  $15 = $13 & 1073741823;
  HEAP32[$12>>2] = $15;
  HEAP32[$0>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
  STACKTOP = sp;return;
 } else if ((($14|0) == 2)) {
  $16 = $13 | -1073741824;
  HEAP32[$12>>2] = $16;
  $17 = $13 & 268435456;
  $18 = ($17|0)==(0);
  if (!($18)) {
   STACKTOP = sp;return;
  }
  HEAP32[$1>>2] = $v;
  $19 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
  $20 = HEAP8[$0>>0]|0;
  $21 = ($20<<24>>24)!=(0);
  $22 = ($19|0)==(0|0);
  $or$cond$i$i$i = $21 | $22;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$1>>2]|0;
  HEAP32[$19>>2] = $23;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene20addArticulationJointERNS0_17ArticulationJointE($this,$joint) {
 $this = $this|0;
 $joint = $joint|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2724|0);
 __ZN5physx3Scb5Scene3addINS0_17ArticulationJointELb0EEEvRT_RNS0_13ObjectTrackerE($this,$joint,$0);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene3addINS0_17ArticulationJointELb0EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $scb0$i = 0, $scb1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scb0$i = sp + 4|0;
 $scb1$i = sp;
 HEAP32[$v>>2] = $this;
 $0 = (($this) + 2417|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 if ($2) {
  $5 = $4 & 268435455;
  $6 = $5 | -2147483648;
  HEAP32[$3>>2] = $6;
  $7 = (($this) + 16|0);
  __ZN5physx35NpArticulationJointGetBodiesFromScbERNS_3Scb17ArticulationJointERPNS0_4BodyES5_($v,$scb0$i,$scb1$i);
  $8 = (($v) + 12|0);
  $9 = HEAP32[$scb0$i>>2]|0;
  $10 = (($9) + 16|0);
  $11 = HEAP32[$scb1$i>>2]|0;
  $12 = (($11) + 16|0);
  __ZN5physx2Sc5Scene20addArticulationJointERNS0_21ArticulationJointCoreERNS0_8BodyCoreES5_($7,$8,$10,$12);
  STACKTOP = sp;return;
 }
 $$mask$i = $4 & -1073741824;
 $13 = ($$mask$i|0)==(-1073741824);
 $14 = $4 & 1073741823;
 if ($13) {
  $15 = $14 | -2147483648;
  HEAP32[$3>>2] = $15;
  $16 = $4 & 268435456;
  $17 = ($16|0)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
  HEAP32[$scb0$i>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$scb0$i)|0);
  STACKTOP = sp;return;
 } else {
  $18 = $14 | 1073741824;
  HEAP32[$3>>2] = $18;
  HEAP32[$scb1$i>>2] = $v;
  $19 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$scb1$i,$scb0$i)|0);
  $20 = HEAP8[$scb0$i>>0]|0;
  $21 = ($20<<24>>24)!=(0);
  $22 = ($19|0)==(0|0);
  $or$cond$i$i$i = $21 | $22;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$scb1$i>>2]|0;
  HEAP32[$19>>2] = $23;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene23removeArticulationJointERNS0_17ArticulationJointE($this,$joint) {
 $this = $this|0;
 $joint = $joint|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 2724|0);
 $3 = (($this) + 2417|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (($this) + 16|0);
  $7 = (($joint) + 12|0);
  __ZN5physx2Sc5Scene23removeArticulationJointERNS0_21ArticulationJointCoreE($6,$7);
  $8 = (($joint) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 268435455;
  HEAP32[$8>>2] = $10;
  HEAP32[$joint>>2] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($joint) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 >>> 30;
 if ((($13|0) == 1)) {
  $14 = $12 & 1073741823;
  HEAP32[$11>>2] = $14;
  HEAP32[$0>>2] = $joint;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($2,$0)|0);
  STACKTOP = sp;return;
 } else if ((($13|0) == 2)) {
  $15 = $12 | -1073741824;
  HEAP32[$11>>2] = $15;
  $16 = $12 & 268435456;
  $17 = ($16|0)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
  HEAP32[$1>>2] = $joint;
  $18 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($2,$1,$0)|0);
  $19 = HEAP8[$0>>0]|0;
  $20 = ($19<<24>>24)!=(0);
  $21 = ($18|0)==(0|0);
  $or$cond$i$i$i$i = $20 | $21;
  if ($or$cond$i$i$i$i) {
   STACKTOP = sp;return;
  }
  $22 = HEAP32[$1>>2]|0;
  HEAP32[$18>>2] = $22;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene12addAggregateERNS0_9AggregateE($this,$agg) {
 $this = $this|0;
 $agg = $agg|0;
 var $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 HEAP32[$agg>>2] = $this;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 16|0);
  $6 = (($agg) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($agg) + 24|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)!=(0);
  $11 = (__ZN5physx2Sc5Scene15createAggregateEPvb($5,$7,$10)|0);
  $12 = (($agg) + 16|0);
  HEAP32[$12>>2] = $11;
  $13 = (($agg) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & 268435455;
  $16 = $15 | -2147483648;
  HEAP32[$13>>2] = $16;
  STACKTOP = sp;return;
 }
 $17 = (($this) + 2764|0);
 $18 = (($agg) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $$mask$i = $19 & -1073741824;
 $20 = ($$mask$i|0)==(-1073741824);
 $21 = $19 & 1073741823;
 if ($20) {
  $22 = $21 | -2147483648;
  HEAP32[$18>>2] = $22;
  $23 = $19 & 268435456;
  $24 = ($23|0)==(0);
  if (!($24)) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $agg;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($17,$0)|0);
  STACKTOP = sp;return;
 } else {
  $25 = $21 | 1073741824;
  HEAP32[$18>>2] = $25;
  HEAP32[$1>>2] = $agg;
  $26 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($17,$1,$0)|0);
  $27 = HEAP8[$0>>0]|0;
  $28 = ($27<<24>>24)!=(0);
  $29 = ($26|0)==(0|0);
  $or$cond$i$i$i = $28 | $29;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $30 = HEAP32[$1>>2]|0;
  HEAP32[$26>>2] = $30;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene15removeAggregateERNS0_9AggregateE($this,$agg) {
 $this = $this|0;
 $agg = $agg|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 16|0);
  $6 = (($agg) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  __ZN5physx2Sc5Scene15deleteAggregateEj($5,$7);
  $8 = (($agg) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 268435455;
  HEAP32[$8>>2] = $10;
  HEAP32[$agg>>2] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($this) + 2764|0);
 $12 = (($agg) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 30;
 if ((($14|0) == 2)) {
  $16 = $13 | -1073741824;
  HEAP32[$12>>2] = $16;
  $17 = $13 & 268435456;
  $18 = ($17|0)==(0);
  if (!($18)) {
   STACKTOP = sp;return;
  }
  HEAP32[$1>>2] = $agg;
  $19 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($11,$1,$0)|0);
  $20 = HEAP8[$0>>0]|0;
  $21 = ($20<<24>>24)!=(0);
  $22 = ($19|0)==(0|0);
  $or$cond$i$i$i = $21 | $22;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$1>>2]|0;
  HEAP32[$19>>2] = $23;
  STACKTOP = sp;return;
 } else if ((($14|0) == 1)) {
  $15 = $13 & 1073741823;
  HEAP32[$12>>2] = $15;
  HEAP32[$0>>2] = $agg;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($11,$0)|0);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene11addMaterialERNS_2Sc12MaterialCoreE($this,$material) {
 $this = $this|0;
 $material = $material|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mEvent = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mEvent = sp;
 $0 = (($this) + 2412|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($mEvent) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($material) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$mEvent>>2] = $4;
 $5 = (($this) + 2400|0);
 $6 = (($this) + 2408|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($this) + 2404|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if (!($11)) {
  (__ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($5,$mEvent)|0);
  $27 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($27);
  STACKTOP = sp;return 1;
 }
 $12 = HEAP32[$5>>2]|0;
 $13 = (($12) + ($10<<3)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  $26 = $10;
 } else {
  $15 = $mEvent;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + 4)|0;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = $13;
  $22 = $21;
  HEAP32[$22>>2] = $17;
  $23 = (($21) + 4)|0;
  $24 = $23;
  HEAP32[$24>>2] = $20;
  $$pre$i = HEAP32[$9>>2]|0;
  $26 = $$pre$i;
 }
 $25 = (($26) + 1)|0;
 HEAP32[$9>>2] = $25;
 $27 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($27);
 STACKTOP = sp;return 1;
}
function __ZN5physx3Scb5Scene14updateMaterialERNS_2Sc12MaterialCoreE($this,$material) {
 $this = $this|0;
 $material = $material|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mEvent = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mEvent = sp;
 $0 = (($this) + 2412|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($mEvent) + 4|0);
 HEAP32[$2>>2] = 1;
 $3 = (($material) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$mEvent>>2] = $4;
 $5 = (($this) + 2400|0);
 $6 = (($this) + 2408|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($this) + 2404|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if (!($11)) {
  (__ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($5,$mEvent)|0);
  $27 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($27);
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$5>>2]|0;
 $13 = (($12) + ($10<<3)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  $26 = $10;
 } else {
  $15 = $mEvent;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + 4)|0;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = $13;
  $22 = $21;
  HEAP32[$22>>2] = $17;
  $23 = (($21) + 4)|0;
  $24 = $23;
  HEAP32[$24>>2] = $20;
  $$pre$i = HEAP32[$9>>2]|0;
  $26 = $$pre$i;
 }
 $25 = (($26) + 1)|0;
 HEAP32[$9>>2] = $25;
 $27 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($27);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene14removeMaterialERNS_2Sc12MaterialCoreE($this,$material) {
 $this = $this|0;
 $material = $material|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mEvent = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mEvent = sp;
 $0 = (($material) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 2412|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($4);
 $5 = (($mEvent) + 4|0);
 HEAP32[$5>>2] = 2;
 $6 = HEAP32[$0>>2]|0;
 HEAP32[$mEvent>>2] = $6;
 $7 = (($this) + 2400|0);
 $8 = (($this) + 2408|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = (($this) + 2404|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($13) {
  $14 = HEAP32[$7>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $28 = $12;
  } else {
   $17 = $mEvent;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + 4)|0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = $15;
   $24 = $23;
   HEAP32[$24>>2] = $19;
   $25 = (($23) + 4)|0;
   $26 = $25;
   HEAP32[$26>>2] = $22;
   $$pre$i = HEAP32[$11>>2]|0;
   $28 = $$pre$i;
  }
  $27 = (($28) + 1)|0;
  HEAP32[$11>>2] = $27;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($7,$mEvent)|0);
 }
 $29 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($29);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene17addParticleSystemERNS0_14ParticleSystemE($this,$ps) {
 $this = $this|0;
 $ps = $ps|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2604|0);
 __ZN5physx3Scb5Scene3addINS0_14ParticleSystemELb1EEEvRT_RNS0_13ObjectTrackerE($this,$ps,$0);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene3addINS0_14ParticleSystemELb1EEEvRT_RNS0_13ObjectTrackerE($this,$v,$tracker) {
 $this = $this|0;
 $v = $v|0;
 $tracker = $tracker|0;
 var $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 HEAP32[$v>>2] = $this;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 if ($4) {
  $7 = $6 & 268435455;
  $8 = $7 | -2147483648;
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 16|0);
  $10 = (($v) + 12|0);
  __ZN5physx2Sc5Scene17addParticleSystemERNS0_18ParticleSystemCoreE($9,$10);
  STACKTOP = sp;return;
 }
 $$mask$i = $6 & -1073741824;
 $11 = ($$mask$i|0)==(-1073741824);
 $12 = $6 & 1073741823;
 if ($11) {
  $13 = $12 | -2147483648;
  HEAP32[$5>>2] = $13;
  $14 = $6 & 268435456;
  $15 = ($14|0)==(0);
  if (!($15)) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $v;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($tracker,$0)|0);
  STACKTOP = sp;return;
 } else {
  $16 = $12 | 1073741824;
  HEAP32[$5>>2] = $16;
  HEAP32[$1>>2] = $v;
  $17 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($tracker,$1,$0)|0);
  $18 = HEAP8[$0>>0]|0;
  $19 = ($18<<24>>24)!=(0);
  $20 = ($17|0)==(0|0);
  $or$cond$i$i$i = $19 | $20;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $21 = HEAP32[$1>>2]|0;
  HEAP32[$17>>2] = $21;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene20removeParticleSystemERNS0_14ParticleSystemEb($this,$ps,$isRelease) {
 $this = $this|0;
 $ps = $ps|0;
 $isRelease = $isRelease|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($ps) + 156|0);
  __ZN5physx3Scb14ParticleSystem12ForceUpdates7destroyEv($5);
  $6 = (($ps) + 168|0);
  __ZN5physx3Scb14ParticleSystem12ForceUpdates7destroyEv($6);
  $7 = (($this) + 16|0);
  $8 = (($ps) + 12|0);
  __ZN5physx2Sc5Scene20removeParticleSystemERNS0_18ParticleSystemCoreEb($7,$8,$isRelease);
  $9 = (($ps) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & 268435455;
  HEAP32[$9>>2] = $11;
  HEAP32[$ps>>2] = 0;
  STACKTOP = sp;return;
 }
 $12 = (($this) + 2604|0);
 $13 = (($ps) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 >>> 30;
 if ((($15|0) == 1)) {
  $16 = $14 & 1073741823;
  HEAP32[$13>>2] = $16;
  HEAP32[$0>>2] = $ps;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($12,$0)|0);
  STACKTOP = sp;return;
 } else if ((($15|0) == 2)) {
  $17 = $14 | -1073741824;
  HEAP32[$13>>2] = $17;
  $18 = $14 & 268435456;
  $19 = ($18|0)==(0);
  if (!($19)) {
   STACKTOP = sp;return;
  }
  HEAP32[$1>>2] = $ps;
  $20 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($12,$1,$0)|0);
  $21 = HEAP8[$0>>0]|0;
  $22 = ($21<<24>>24)!=(0);
  $23 = ($20|0)==(0|0);
  $or$cond$i$i$i = $22 | $23;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $24 = HEAP32[$1>>2]|0;
  HEAP32[$20>>2] = $24;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene8addClothERNS0_5ClothE($this,$cl) {
 $this = $this|0;
 $cl = $cl|0;
 var $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 HEAP32[$cl>>2] = $this;
 $1 = (($this) + 2417|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $4 = (($this) + 16|0);
  $5 = (($cl) + 12|0);
  $6 = (__ZN5physx2Sc5Scene8addClothERNS0_9ClothCoreE($4,$5)|0);
  if ($6) {
   $7 = (($cl) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8 & 268435455;
   $10 = $9 | -2147483648;
   HEAP32[$7>>2] = $10;
   STACKTOP = sp;return;
  } else {
   $11 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($11,32,445424,810,445504,$vararg_buffer);
   STACKTOP = sp;return;
  }
 }
 $12 = (($this) + 2804|0);
 $13 = (($cl) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $$mask$i = $14 & -1073741824;
 $15 = ($$mask$i|0)==(-1073741824);
 $16 = $14 & 1073741823;
 if ($15) {
  $17 = $16 | -2147483648;
  HEAP32[$13>>2] = $17;
  $18 = $14 & 268435456;
  $19 = ($18|0)==(0);
  if (!($19)) {
   STACKTOP = sp;return;
  }
  HEAP32[$vararg_buffer>>2] = $cl;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($12,$vararg_buffer)|0);
  STACKTOP = sp;return;
 } else {
  $20 = $16 | 1073741824;
  HEAP32[$13>>2] = $20;
  HEAP32[$0>>2] = $cl;
  $21 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($12,$0,$vararg_buffer)|0);
  $22 = HEAP8[$vararg_buffer>>0]|0;
  $23 = ($22<<24>>24)!=(0);
  $24 = ($21|0)==(0|0);
  $or$cond$i$i$i = $23 | $24;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $25 = HEAP32[$0>>2]|0;
  HEAP32[$21>>2] = $25;
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene11removeClothERNS0_5ClothE($this,$cl) {
 $this = $this|0;
 $cl = $cl|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 2417|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 16|0);
  $6 = (($cl) + 12|0);
  __ZN5physx2Sc5Scene11removeClothERNS0_9ClothCoreE($5,$6);
  $7 = (($cl) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 268435455;
  HEAP32[$7>>2] = $9;
  HEAP32[$cl>>2] = 0;
  STACKTOP = sp;return;
 }
 $10 = (($this) + 2804|0);
 $11 = (($cl) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 >>> 30;
 if ((($13|0) == 1)) {
  $14 = $12 & 1073741823;
  HEAP32[$11>>2] = $14;
  HEAP32[$0>>2] = $cl;
  (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($10,$0)|0);
  STACKTOP = sp;return;
 } else if ((($13|0) == 2)) {
  $15 = $12 | -1073741824;
  HEAP32[$11>>2] = $15;
  $16 = $12 & 268435456;
  $17 = ($16|0)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
  HEAP32[$1>>2] = $cl;
  $18 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($10,$1,$0)|0);
  $19 = HEAP8[$0>>0]|0;
  $20 = ($19<<24>>24)!=(0);
  $21 = ($18|0)==(0|0);
  $or$cond$i$i$i = $20 | $21;
  if ($or$cond$i$i$i) {
   STACKTOP = sp;return;
  }
  $22 = HEAP32[$1>>2]|0;
  HEAP32[$18>>2] = $22;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Scb5Scene22updateLowLevelMaterialEPPNS_10NpMaterialE($this,$masterMaterial) {
 $this = $this|0;
 $masterMaterial = $masterMaterial|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 2412|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = (($this) + 1136|0);
 $4 = (($this) + 2400|0);
 $5 = (($this) + 2404|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $36 = $0;
  $37 = $36;
  HEAP32[$37>>2] = 0;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = 0;
  __ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($4,0,$0);
  $40 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($40);
  STACKTOP = sp;return;
 }
 $8 = (($this) + 1140|0);
 $i$01 = 0;
 while(1) {
  $9 = HEAP32[$4>>2]|0;
  $10 = (($9) + ($i$01<<3)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($masterMaterial) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($9) + ($i$01<<3)|0) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  if ((($15|0) == 0)) {
   $16 = ($13|0)==(0|0);
   if (!($16)) {
    $17 = (($13) + 32|0);
    $18 = (($13) + 52|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 1)|0;
    __ZN5physx18PxsMaterialManager6resizeEj($3,$20);
    $21 = HEAP32[$3>>2]|0;
    $22 = (($21) + ($19<<5)|0);
    ;HEAP32[$22+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$17+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$17+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$17+20>>2]|0;
   }
  } else if ((($15|0) == 1)) {
   $23 = ($13|0)==(0|0);
   if (!($23)) {
    $24 = (($13) + 32|0);
    $25 = (($13) + 52|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$3>>2]|0;
    $28 = (($27) + ($26<<5)|0);
    ;HEAP32[$28+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$28+16>>2]=HEAP32[$24+16>>2]|0;HEAP32[$28+20>>2]=HEAP32[$24+20>>2]|0;
   }
  } else if ((($15|0) == 2)) {
   $29 = HEAP32[$8>>2]|0;
   $30 = ($11>>>0)<($29>>>0);
   if ($30) {
    $31 = HEAP32[$3>>2]|0;
    $32 = ((($31) + ($11<<5)|0) + 20|0);
    HEAP32[$32>>2] = -1;
   }
  }
  $33 = (($i$01) + 1)|0;
  $34 = HEAP32[$5>>2]|0;
  $35 = ($33>>>0)<($34>>>0);
  if ($35) {
   $i$01 = $33;
  } else {
   break;
  }
 }
 $36 = $0;
 $37 = $36;
 HEAP32[$37>>2] = 0;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($4,0,$0);
 $40 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($40);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<3)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<3)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = $a;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = $$01$i;
   $18 = $17;
   HEAP32[$18>>2] = $13;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = $16;
  }
  $21 = (($$01$i) + 8|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene26preSimulateUpdateAppThreadEf($this,$timeStep) {
 $this = $this|0;
 $timeStep = Math_fround($timeStep);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc5Scene20getNbParticleSystemsEv($0)|0);
 $2 = (__ZN5physx2Sc5Scene18getParticleSystemsEv($0)|0);
 $3 = ($1|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $4 = (($2) + ($i$01<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5;
  $7 = (($5) + 10|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = $8&255;
  $10 = (444424 + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($6) - ($11))|0;
  $13 = $12;
  __ZN5physx3Scb14ParticleSystem18submitForceUpdatesEf($13,$timeStep);
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $14;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene9syncStateEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i = 0, $$pre10$pre = 0, $$pre12 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dominance$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond6$i = 0, $i$03$i = 0, $i$06 = 0, $i1$03 = 0, $isBuffered$0$i$i = 0, $j$0$i = 0, $j$02$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dominance$i = sp;
 $0 = sp + 8|0;
 $1 = (($this) + 3340|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($this) + 16|0);
  while(1) {
   (__ZN5physx2Sc5Scene12createClientEv($4)|0);
   $5 = HEAP32[$1>>2]|0;
   $6 = (($5) + -1)|0;
   HEAP32[$1>>2] = $6;
   $7 = ($6|0)==(0);
   if ($7) {
    break;
   }
  }
 }
 $8 = (($this) + 3356|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  HEAP32[$8>>2] = 0;
  $97 = (($this) + 3064|0);
  dest=$97+0|0; stop=dest+124|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  $98 = (($this) + 2996|0);
  dest=$98+0|0; stop=dest+37|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $11 = $9 & 1;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $13 = (($this) + 3316|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($this) + 48|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($this) + 3320|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($this) + 52|0);
  HEAPF32[$18>>2] = $17;
  $19 = (($this) + 3324|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($this) + 56|0);
  HEAPF32[$21>>2] = $20;
  $22 = (($this) + 60|0);
  HEAP32[$22>>2] = 1;
 }
 $23 = $9 & 2;
 $24 = ($23|0)==(0);
 if ($24) {
  $29 = $9;
 } else {
  $25 = (($this) + 16|0);
  $26 = (($this) + 3328|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  __ZN5physx2Sc5Scene26setBounceThresholdVelocityEf($25,$27);
  $$pre = HEAP32[$8>>2]|0;
  $29 = $$pre;
 }
 $28 = $29 & 4;
 $30 = ($28|0)==(0);
 if (!($30)) {
  $31 = (($this) + 3332|0);
  $32 = HEAP16[$31>>1]|0;
  $33 = (($this) + 1216|0);
  HEAP16[$33>>1] = $32;
 }
 $34 = $29 & 8;
 $35 = ($34|0)==(0);
 if ($35) {
  $64 = $29;
 } else {
  $36 = (($this) + 16|0);
  $37 = (($dominance$i) + 4|0);
  $i$03$i = 0;
  while(1) {
   $38 = ((($this) + ($i$03$i<<2)|0) + 3064|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0);
   $$pre$i = (($i$03$i) + 1)|0;
   if (!($40)) {
    $41 = ((($this) + ($i$03$i<<2)|0) + 3188|0);
    $42 = 1 << $i$03$i;
    $43 = $i$03$i&255;
    $j$02$i = $$pre$i;
    while(1) {
     HEAPF32[$dominance$i>>2] = Math_fround(0.0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     $44 = ($i$03$i>>>0)<($j$02$i>>>0);
     if ($44) {
      $45 = HEAP32[$38>>2]|0;
      $46 = 1 << $j$02$i;
      $47 = $45 & $46;
      $isBuffered$0$i$i = $47;
     } else {
      $48 = ((($this) + ($j$02$i<<2)|0) + 3064|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = $49 & $42;
      $isBuffered$0$i$i = $50;
     }
     $51 = ($isBuffered$0$i$i|0)==(0);
     if (!($51)) {
      $52 = HEAP32[$41>>2]|0;
      $53 = 1 << $j$02$i;
      $54 = $52 & $53;
      $55 = $54 >>> $j$02$i;
      $56 = (Math_fround(($55>>>0)));
      HEAPF32[$dominance$i>>2] = $56;
      $57 = ((($this) + ($j$02$i<<2)|0) + 3188|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = $58 & $42;
      $60 = $59 >>> $i$03$i;
      $61 = (Math_fround(($60>>>0)));
      HEAPF32[$37>>2] = $61;
      $62 = $j$02$i&255;
      __ZN5physx2Sc5Scene21setDominanceGroupPairEhhRKNS_20PxDominanceGroupPairE($36,$43,$62,$dominance$i);
     }
     $j$0$i = (($j$02$i) + 1)|0;
     $exitcond$i = ($j$0$i|0)==(32);
     if ($exitcond$i) {
      break;
     } else {
      $j$02$i = $j$0$i;
     }
    }
   }
   $exitcond6$i = ($$pre$i|0)==(31);
   if ($exitcond6$i) {
    break;
   } else {
    $i$03$i = $$pre$i;
   }
  }
  $$pre8 = HEAP32[$8>>2]|0;
  $64 = $$pre8;
 }
 $63 = $64 & 16;
 $65 = ($63|0)==(0);
 if ($65) {
  $70 = $64;
 } else {
  $66 = (($this) + 16|0);
  $67 = (($this) + 3336|0);
  $68 = HEAP32[$67>>2]|0;
  __ZN5physx2Sc5Scene18setSolverBatchSizeEj($66,$68);
  $$pre9 = HEAP32[$8>>2]|0;
  $70 = $$pre9;
 }
 $69 = $70 & 32;
 $71 = ($69|0)==(0);
 if ($71) {
  $88 = $70;
 } else {
  $72 = (($this) + 3348|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==(0);
  if ($74) {
   $88 = $70;
  } else {
   $75 = (($this) + 3344|0);
   $76 = (($this) + 16|0);
   $99 = $73;$i$06 = 0;
   while(1) {
    $77 = HEAP32[$75>>2]|0;
    $78 = (($77) + ($i$06)|0);
    $79 = HEAP8[$78>>0]|0;
    $80 = ($79<<24>>24)==(-1);
    if ($80) {
     $86 = $99;
    } else {
     $81 = $i$06&255;
     HEAP8[$0>>0] = $79;
     __ZN5physx2Sc5Scene22setClientBehaviorFlagsEhNS_7PxFlagsINS_20PxClientBehaviorFlag4EnumEhEE($76,$81,$0);
     $82 = HEAP32[$75>>2]|0;
     $83 = (($82) + ($i$06)|0);
     HEAP8[$83>>0] = -1;
     $$pre12 = HEAP32[$72>>2]|0;
     $86 = $$pre12;
    }
    $84 = (($i$06) + 1)|0;
    $85 = ($84>>>0)<($86>>>0);
    if ($85) {
     $99 = $86;$i$06 = $84;
    } else {
     break;
    }
   }
   $$pre10$pre = HEAP32[$8>>2]|0;
   $88 = $$pre10$pre;
  }
 }
 $87 = $88 & 64;
 $89 = ($87|0)==(0);
 if ($89) {
  HEAP32[$8>>2] = 0;
  $97 = (($this) + 3064|0);
  dest=$97+0|0; stop=dest+124|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  $98 = (($this) + 2996|0);
  dest=$98+0|0; stop=dest+37|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $90 = (($this) + 16|0);
 $i1$03 = 0;
 while(1) {
  $91 = ((($this) + ($i1$03)|0) + 2996|0);
  $92 = HEAP8[$91>>0]|0;
  $93 = ($92<<24>>24)==(0);
  if (!($93)) {
   $94 = ((($this) + ($i1$03<<2)|0) + 2848|0);
   $95 = Math_fround(HEAPF32[$94>>2]);
   __ZN5physx2Sc5Scene25setVisualizationParameterENS_24PxVisualizationParameter4EnumEf($90,$i1$03,$95);
  }
  $96 = (($i1$03) + 1)|0;
  $exitcond = ($96|0)==(37);
  if ($exitcond) {
   break;
  } else {
   $i1$03 = $96;
  }
 }
 HEAP32[$8>>2] = 0;
 $97 = (($this) + 3064|0);
 dest=$97+0|0; stop=dest+124|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $98 = (($this) + 2996|0);
 dest=$98+0|0; stop=dest+37|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene13addShapeToPvdERNS0_5ShapeERNS_7PxActorE($this,$shape,$owner) {
 $this = $this|0;
 $shape = $shape|0;
 $owner = $owner|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene18removeShapeFromPvdERNS0_5ShapeERNS_7PxActorE($this,$shape,$owner) {
 $this = $this|0;
 $shape = $shape|0;
 $owner = $owner|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Sc5Scene11shiftOriginERKNS_6PxVec3E($0,$shift);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene15syncEntireSceneEPj($this,$error) {
 $this = $this|0;
 $error = $error|0;
 var $$mask = 0, $$mask$i = 0, $$mask$i12 = 0, $$mask$i18 = 0, $$mask$i4 = 0, $$mask$i7 = 0, $$mask22 = 0, $$pre = 0, $$pre44 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $body$032 = 0, $bodyIterator = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i15 = 0, $exitcond$i21 = 0, $i$01$i = 0;
 var $i$01$i11 = 0, $i$01$i13 = 0, $i$01$i17 = 0, $i$01$i19 = 0, $i$01$i3 = 0, $i$01$i6 = 0, $i$01$i8 = 0, $i$035 = 0, $i1$029 = 0, $i2$027 = 0, $i3$024 = 0, $i4$023 = 0, $scb1$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $scb1$i = sp + 16|0;
 $bodyIterator = sp + 8|0;
 $0 = ($error|0)==(0|0);
 if (!($0)) {
  $1 = (($this) + 16|0);
  $2 = (__ZN5physx2Sc5Scene13getErrorStateEv($1)|0);
  HEAP32[$error>>2] = $2;
 }
 $3 = (($this) + 2420|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($4);
 __ZN5physx3Scb5Scene9syncStateEv($this);
 $5 = (($this) + 2800|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($this) + 2768|0);
  $9 = (($this) + 16|0);
  $i$035 = 0;
  while(1) {
   $10 = HEAP32[$8>>2]|0;
   $11 = (($10) + ($i$035<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $$mask22 = $14 & -1073741824;
   $15 = ($$mask22|0)==(1073741824);
   if ($15) {
    $16 = (($12) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($12) + 24|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19<<24>>24)!=(0);
    $21 = (__ZN5physx2Sc5Scene15createAggregateEPvb($9,$17,$20)|0);
    $22 = (($12) + 16|0);
    HEAP32[$22>>2] = $21;
    __ZN5physx3Scb9Aggregate9syncStateERNS0_5SceneE($12,$this);
   } else {
    $23 = $14 & 268435456;
    $24 = ($23|0)==(0);
    if (!($24)) {
     __ZN5physx3Scb9Aggregate9syncStateERNS0_5SceneE($12,$this);
    }
   }
   $25 = (($i$035) + 1)|0;
   $26 = HEAP32[$5>>2]|0;
   $27 = ($25>>>0)<($26>>>0);
   if ($27) {
    $i$035 = $25;
   } else {
    break;
   }
  }
 }
 $28 = (($this) + 2764|0);
 __ZN5physx3Scb13ObjectTracker5clearEv($28);
 $29 = (($this) + 2516|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 2524|0);
 $31 = (($this) + 2528|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($this) + 2560|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 $$pre44 = (($this) + 16|0);
 if (!($35)) {
  $i$01$i3 = 0;
  while(1) {
   $36 = (($32) + ($i$01$i3<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $$mask$i4 = $39 & -1073741824;
   $40 = ($$mask$i4|0)==(1073741824);
   if ($40) {
    __ZN10ScSceneFnsIN5physx3Scb11RigidStaticEE6insertERNS0_2Sc5SceneERS2_($$pre44,$37);
   } else {
    $41 = $39 & 268435456;
    $42 = ($41|0)==(0);
    if (!($42)) {
     __ZN5physx3Scb11RigidStatic9syncStateEv($37);
    }
   }
   $43 = (($i$01$i3) + 1)|0;
   $44 = HEAP32[$33>>2]|0;
   $45 = ($43>>>0)<($44>>>0);
   if ($45) {
    $i$01$i3 = $43;
   } else {
    break;
   }
  }
 }
 __ZN5physx3Scb13ObjectTracker5clearEv($30);
 HEAP32[$bodyIterator>>2] = 0;
 $46 = (($bodyIterator) + 4|0);
 HEAP32[$46>>2] = 0;
 __ZN5physx2Sc5Scene24initActiveBodiesIteratorERNS0_12BodyIteratorE($$pre44,$bodyIterator);
 $47 = (__ZN5physx2Sc12BodyIterator7getNextEv($bodyIterator)|0);
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $body$032 = $47;
  while(1) {
   $49 = $body$032;
   $50 = (($body$032) + 10|0);
   $51 = HEAP8[$50>>0]|0;
   $52 = $51&255;
   $53 = (444424 + ($52<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($49) - ($54))|0;
   $56 = $55;
   $57 = (($56) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = $58 & 268435456;
   $60 = ($59|0)==(0);
   if ($60) {
    __ZN5physx3Scb4Body9syncStateEv($56);
   }
   $61 = (__ZN5physx2Sc12BodyIterator7getNextEv($bodyIterator)|0);
   $62 = ($61|0)==(0|0);
   if ($62) {
    break;
   } else {
    $body$032 = $61;
   }
  }
 }
 $63 = (($this) + 1156|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($this) + 1152|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($64|0)==(0);
 if (!($67)) {
  $i$01$i8 = 0;
  while(1) {
   $68 = (($66) + ($i$01$i8<<2)|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = $69;
   $71 = (($69) + 10|0);
   $72 = HEAP8[$71>>0]|0;
   $73 = $72&255;
   $74 = (444424 + ($73<<2)|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($70) - ($75))|0;
   $77 = $76;
   $78 = (($77) + 4|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = $79 & 268435456;
   $81 = ($80|0)==(0);
   if ($81) {
    __ZN5physx3Scb4Body9syncStateEv($77);
   }
   $82 = (($i$01$i8) + 1)|0;
   $exitcond$i = ($82|0)==($64|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i8 = $82;
   }
  }
 }
 $83 = (($this) + 2564|0);
 $84 = (($this) + 2568|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($this) + 2600|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(0);
 if (!($88)) {
  $i$01$i11 = 0;
  while(1) {
   $89 = (($85) + ($i$01$i11<<2)|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($90) + 4|0);
   $92 = HEAP32[$91>>2]|0;
   $$mask$i12 = $92 & -1073741824;
   $93 = ($$mask$i12|0)==(1073741824);
   if ($93) {
    __ZN10ScSceneFnsIN5physx3Scb4BodyEE6insertERNS0_2Sc5SceneERS2_($$pre44,$90);
   } else {
    $94 = $92 & 268435456;
    $95 = ($94|0)==(0);
    if (!($95)) {
     __ZN5physx3Scb4Body9syncStateEv($90);
    }
   }
   $96 = (($i$01$i11) + 1)|0;
   $97 = HEAP32[$86>>2]|0;
   $98 = ($96>>>0)<($97>>>0);
   if ($98) {
    $i$01$i11 = $96;
   } else {
    break;
   }
  }
 }
 __ZN5physx3Scb13ObjectTracker5clearEv($83);
 $99 = (($this) + 2504|0);
 HEAP32[$99>>2] = 0;
 $100 = (($this) + 2484|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==(0);
 if (!($102)) {
  $103 = (($this) + 2452|0);
  $283 = $101;$i1$029 = 0;
  while(1) {
   $104 = HEAP32[$103>>2]|0;
   $105 = (($104) + ($i1$029<<2)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = (($106) + 4|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = $108 & 268435456;
   $110 = ($109|0)==(0);
   if ($110) {
    $113 = $283;
   } else {
    __ZN5physx3Scb5Shape9syncStateEv($106);
    $$pre = HEAP32[$100>>2]|0;
    $113 = $$pre;
   }
   $111 = (($i1$029) + 1)|0;
   $112 = ($111>>>0)<($113>>>0);
   if ($112) {
    $283 = $113;$i1$029 = $111;
   } else {
    break;
   }
  }
 }
 $114 = (($this) + 2448|0);
 __ZN5physx3Scb13ObjectTracker5clearEv($114);
 $115 = (($this) + 2492|0);
 HEAP32[$115>>2] = 0;
 $116 = (__ZN5physx2Sc5Scene14getConstraintsEv($$pre44)|0);
 $117 = (__ZNK5physx2Sc5Scene16getNbConstraintsEv($$pre44)|0);
 $118 = ($117|0)==(0);
 if (!($118)) {
  $i$01$i19 = 0;
  while(1) {
   $119 = (($116) + ($i$01$i19<<2)|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = (($120) + -12|0);
   $122 = (($121) + 4|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = $123 & 268435456;
   $125 = ($124|0)==(0);
   if ($125) {
    __ZN5physx3Scb10Constraint9syncStateEv($121);
   }
   $126 = (($i$01$i19) + 1)|0;
   $exitcond$i21 = ($126|0)==($117|0);
   if ($exitcond$i21) {
    break;
   } else {
    $i$01$i19 = $126;
   }
  }
 }
 $127 = (($this) + 2644|0);
 $128 = (($this) + 2648|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = (($this) + 2680|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ($131|0)==(0);
 if (!($132)) {
  $i$01$i17 = 0;
  while(1) {
   $133 = (($129) + ($i$01$i17<<2)|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 4|0);
   $136 = HEAP32[$135>>2]|0;
   $$mask$i18 = $136 & -1073741824;
   $137 = ($$mask$i18|0)==(1073741824);
   if ($137) {
    __ZN5physx34NpConstraintGetRigidObjectsFromScbERKNS_3Scb10ConstraintERPNS0_11RigidObjectES6_($134,$vararg_buffer,$scb1$i);
    $138 = (($134) + 12|0);
    $139 = HEAP32[$vararg_buffer>>2]|0;
    $140 = ($139|0)==(0|0);
    if ($140) {
     $161 = 0;
    } else {
     $141 = $139;
     $142 = (($139) + 4|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = $143 >>> 24;
     $145 = $144 & 15;
     $146 = ((444424 + ($145<<2)|0) + 24|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = (($147) + ($141))|0;
     $149 = $148;
     $161 = $149;
    }
    $150 = HEAP32[$scb1$i>>2]|0;
    $151 = ($150|0)==(0|0);
    if ($151) {
     $162 = 0;
    } else {
     $152 = $150;
     $153 = (($150) + 4|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = $154 >>> 24;
     $156 = $155 & 15;
     $157 = ((444424 + ($156<<2)|0) + 24|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (($158) + ($152))|0;
     $160 = $159;
     $162 = $160;
    }
    __ZN5physx2Sc5Scene13addConstraintERNS0_14ConstraintCoreEPNS0_9RigidCoreES5_($$pre44,$138,$161,$162);
   } else {
    $163 = $136 & 268435456;
    $164 = ($163|0)==(0);
    if (!($164)) {
     __ZN5physx3Scb10Constraint9syncStateEv($134);
    }
   }
   $165 = (($i$01$i17) + 1)|0;
   $166 = HEAP32[$130>>2]|0;
   $167 = ($165>>>0)<($166>>>0);
   if ($167) {
    $i$01$i17 = $165;
   } else {
    break;
   }
  }
 }
 __ZN5physx3Scb13ObjectTracker5clearEv($127);
 $168 = (__ZN5physx2Sc5Scene16getArticulationsEv($$pre44)|0);
 $169 = (__ZNK5physx2Sc5Scene18getNbArticulationsEv($$pre44)|0);
 $170 = ($169|0)==(0);
 if (!($170)) {
  $i$01$i13 = 0;
  while(1) {
   $171 = (($168) + ($i$01$i13<<2)|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = (($172) + -12|0);
   $174 = (($173) + 4|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = $175 & 268435456;
   $177 = ($176|0)==(0);
   if ($177) {
    __ZN5physx3Scb12Articulation9syncStateEv($173);
   }
   $178 = (($i$01$i13) + 1)|0;
   $exitcond$i15 = ($178|0)==($169|0);
   if ($exitcond$i15) {
    break;
   } else {
    $i$01$i13 = $178;
   }
  }
 }
 $179 = (($this) + 2684|0);
 $180 = (($this) + 2688|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = (($this) + 2720|0);
 $183 = HEAP32[$182>>2]|0;
 $184 = ($183|0)==(0);
 if (!($184)) {
  $i$01$i6 = 0;
  while(1) {
   $185 = (($181) + ($i$01$i6<<2)|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = (($186) + 4|0);
   $188 = HEAP32[$187>>2]|0;
   $$mask$i7 = $188 & -1073741824;
   $189 = ($$mask$i7|0)==(1073741824);
   if ($189) {
    $190 = (__ZN5physx28NpArticulationGetRootFromScbERNS_3Scb12ArticulationE($186)|0);
    $191 = (($186) + 12|0);
    $192 = (($190) + 16|0);
    __ZN5physx2Sc5Scene15addArticulationERNS0_16ArticulationCoreERNS0_8BodyCoreE($$pre44,$191,$192);
   } else {
    $193 = $188 & 268435456;
    $194 = ($193|0)==(0);
    if (!($194)) {
     __ZN5physx3Scb12Articulation9syncStateEv($186);
    }
   }
   $195 = (($i$01$i6) + 1)|0;
   $196 = HEAP32[$182>>2]|0;
   $197 = ($195>>>0)<($196>>>0);
   if ($197) {
    $i$01$i6 = $195;
   } else {
    break;
   }
  }
 }
 __ZN5physx3Scb13ObjectTracker5clearEv($179);
 $198 = (($this) + 2724|0);
 $199 = (($this) + 2728|0);
 $200 = HEAP32[$199>>2]|0;
 $201 = (($this) + 2760|0);
 $202 = HEAP32[$201>>2]|0;
 $203 = ($202|0)==(0);
 if (!($203)) {
  $i$01$i = 0;
  while(1) {
   $204 = (($200) + ($i$01$i<<2)|0);
   $205 = HEAP32[$204>>2]|0;
   $206 = (($205) + 4|0);
   $207 = HEAP32[$206>>2]|0;
   $$mask$i = $207 & -1073741824;
   $208 = ($$mask$i|0)==(1073741824);
   if ($208) {
    __ZN5physx35NpArticulationJointGetBodiesFromScbERNS_3Scb17ArticulationJointERPNS0_4BodyES5_($205,$vararg_buffer,$scb1$i);
    $209 = (($205) + 12|0);
    $210 = HEAP32[$vararg_buffer>>2]|0;
    $211 = (($210) + 16|0);
    $212 = HEAP32[$scb1$i>>2]|0;
    $213 = (($212) + 16|0);
    __ZN5physx2Sc5Scene20addArticulationJointERNS0_21ArticulationJointCoreERNS0_8BodyCoreES5_($$pre44,$209,$211,$213);
   } else {
    $214 = $207 & 268435456;
    $215 = ($214|0)==(0);
    if (!($215)) {
     __ZN5physx3Scb17ArticulationJoint9syncStateEv($205);
    }
   }
   $216 = (($i$01$i) + 1)|0;
   $217 = HEAP32[$201>>2]|0;
   $218 = ($216>>>0)<($217>>>0);
   if ($218) {
    $i$01$i = $216;
   } else {
    break;
   }
  }
 }
 __ZN5physx3Scb13ObjectTracker5clearEv($198);
 $219 = (__ZNK5physx2Sc5Scene20getNbParticleSystemsEv($$pre44)|0);
 $220 = (__ZN5physx2Sc5Scene18getParticleSystemsEv($$pre44)|0);
 $221 = ($219|0)==(0);
 if (!($221)) {
  $i2$027 = 0;
  while(1) {
   $226 = (($220) + ($i2$027<<2)|0);
   $227 = HEAP32[$226>>2]|0;
   $228 = $227;
   $229 = (($227) + 10|0);
   $230 = HEAP8[$229>>0]|0;
   $231 = $230&255;
   $232 = (444424 + ($231<<2)|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = (($228) - ($233))|0;
   $235 = $234;
   __ZN5physx3Scb14ParticleSystem9syncStateEv($235);
   $236 = (($i2$027) + 1)|0;
   $exitcond = ($236|0)==($219|0);
   if ($exitcond) {
    break;
   } else {
    $i2$027 = $236;
   }
  }
 }
 $222 = (($this) + 2640|0);
 $223 = HEAP32[$222>>2]|0;
 $224 = ($223|0)==(0);
 if (!($224)) {
  $225 = (($this) + 2608|0);
  $i3$024 = 0;
  while(1) {
   $237 = HEAP32[$225>>2]|0;
   $238 = (($237) + ($i3$024<<2)|0);
   $239 = HEAP32[$238>>2]|0;
   $240 = (($239) + 4|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = $241 >>> 30;
   if ((($242|0) == 1)) {
    $245 = (($239) + 12|0);
    __ZN5physx2Sc5Scene17addParticleSystemERNS0_18ParticleSystemCoreE($$pre44,$245);
   } else if ((($242|0) == 3)) {
    $243 = (($239) + 156|0);
    __ZN5physx3Scb14ParticleSystem12ForceUpdates7destroyEv($243);
    $244 = (($239) + 168|0);
    __ZN5physx3Scb14ParticleSystem12ForceUpdates7destroyEv($244);
   }
   $246 = (($i3$024) + 1)|0;
   $247 = HEAP32[$222>>2]|0;
   $248 = ($246>>>0)<($247>>>0);
   if ($248) {
    $i3$024 = $246;
   } else {
    break;
   }
  }
 }
 $249 = (($this) + 2604|0);
 __ZN5physx3Scb13ObjectTracker5clearEv($249);
 $250 = (($this) + 2840|0);
 $251 = HEAP32[$250>>2]|0;
 $252 = ($251|0)==(0);
 if (!($252)) {
  $253 = (($this) + 2808|0);
  $i4$023 = 0;
  while(1) {
   $254 = HEAP32[$253>>2]|0;
   $255 = (($254) + ($i4$023<<2)|0);
   $256 = HEAP32[$255>>2]|0;
   $257 = (($256) + 4|0);
   $258 = HEAP32[$257>>2]|0;
   $$mask = $258 & -1073741824;
   $259 = ($$mask|0)==(1073741824);
   if ($259) {
    $260 = (($256) + 12|0);
    $261 = (__ZN5physx2Sc5Scene8addClothERNS0_9ClothCoreE($$pre44,$260)|0);
    if (!($261)) {
     $262 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
     __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($262,32,445424,1274,445504,$vararg_buffer);
    }
   }
   $263 = (($i4$023) + 1)|0;
   $264 = HEAP32[$250>>2]|0;
   $265 = ($263>>>0)<($264>>>0);
   if ($265) {
    $i4$023 = $263;
   } else {
    break;
   }
  }
 }
 $266 = (($this) + 2804|0);
 __ZN5physx3Scb13ObjectTracker5clearEv($266);
 $267 = (($this) + 2436|0);
 $268 = HEAP32[$267>>2]|0;
 $269 = (($268) + 2)|0;
 $270 = (($this) + 2428|0);
 $271 = HEAP32[$270>>2]|0;
 $272 = ($271>>>0)>($269>>>0);
 if (!($272)) {
  HEAP32[$267>>2] = 0;
  $281 = (($this) + 2440|0);
  HEAP32[$281>>2] = 0;
  $282 = HEAP32[$3>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($282);
  STACKTOP = sp;return;
 }
 $273 = (($this) + 2424|0);
 $275 = $271;
 while(1) {
  $274 = (($275) + -1)|0;
  $276 = HEAP32[$273>>2]|0;
  $277 = (($276) + ($274<<2)|0);
  $278 = HEAP32[$277>>2]|0;
  HEAP32[$270>>2] = $274;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$278);
  $279 = HEAP32[$270>>2]|0;
  $280 = ($279>>>0)>($269>>>0);
  if ($280) {
   $275 = $279;
  } else {
   break;
  }
 }
 HEAP32[$267>>2] = 0;
 $281 = (($this) + 2440|0);
 HEAP32[$281>>2] = 0;
 $282 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($282);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb9Aggregate9syncStateERNS0_5SceneE($this,$scene) {
 $this = $this|0;
 $scene = $scene|0;
 var $$off = 0, $$pre = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, $i2$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16777215;
 $3 = ($2|0)==(0);
 $$pre = (($this) + 8|0);
 if ($3) {
  HEAP32[$$pre>>2] = 0;
  $60 = HEAP32[$0>>2]|0;
  $61 = $60 & -16777216;
  HEAP32[$0>>2] = $61;
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$$pre>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  $7 = $1 >>> 24;
  $8 = $7 & 15;
  $9 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($6,$8)|0);
  HEAP32[$$pre>>2] = $9;
  $13 = $9;
 } else {
  $13 = $4;
 }
 $10 = $1 & 1;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = HEAP32[$13>>2]|0;
  $14 = (($scene) + 2512|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if (!($18)) {
   $19 = (($this) + 16|0);
   $i$05 = 0;
   while(1) {
    $20 = HEAP32[$19>>2]|0;
    $$sum2 = (($i$05) + ($12))|0;
    $21 = (($15) + ($$sum2<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = $22;
    $24 = (($22) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = $25 >>> 24;
    $27 = $26 & 15;
    $28 = ((444424 + ($27<<2)|0) + 24|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($29) + ($23))|0;
    $31 = $30;
    HEAP32[$31>>2] = $20;
    $32 = (($i$05) + 1)|0;
    $33 = HEAP32[$16>>2]|0;
    $34 = ($32>>>0)<($33>>>0);
    if ($34) {
     $i$05 = $32;
    } else {
     break;
    }
   }
  }
 }
 $35 = $1 & 2;
 $36 = ($35|0)==(0);
 if ($36) {
  HEAP32[$$pre>>2] = 0;
  $60 = HEAP32[$0>>2]|0;
  $61 = $60 & -16777216;
  HEAP32[$0>>2] = $61;
  STACKTOP = sp;return;
 }
 $37 = (($13) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($scene) + 2512|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($13) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if ($43) {
  HEAP32[$$pre>>2] = 0;
  $60 = HEAP32[$0>>2]|0;
  $61 = $60 & -16777216;
  HEAP32[$0>>2] = $61;
  STACKTOP = sp;return;
 } else {
  $i2$03 = 0;
 }
 while(1) {
  $$sum = (($i2$03) + ($38))|0;
  $44 = (($40) + ($$sum<<2)|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = $47 >>> 30;
  $49 = $45;
  $50 = $47 >>> 24;
  $51 = $50 & 15;
  $52 = ((444424 + ($51<<2)|0) + 24|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + ($49))|0;
  $55 = $54;
  HEAP32[$55>>2] = -1;
  $$off = (($48) + -1)|0;
  $56 = ($$off>>>0)<(2);
  if ($56) {
   __ZN5physx2Sc9ActorCore14reinsertShapesEv($55);
  }
  $57 = (($i2$03) + 1)|0;
  $58 = HEAP32[$41>>2]|0;
  $59 = ($57>>>0)<($58>>>0);
  if ($59) {
   $i2$03 = $57;
  } else {
   break;
  }
 }
 HEAP32[$$pre>>2] = 0;
 $60 = HEAP32[$0>>2]|0;
 $61 = $60 & -16777216;
 HEAP32[$0>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb4Body9syncStateEv($this) {
 $this = $this|0;
 var $$mask = 0, $$mask$i = 0, $$not$i = 0, $$not1$i = 0, $$pre = 0, $$pre$phi9Z2D = 0, $$pre$phiZ2D = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0;
 var $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0;
 var $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0);
 var $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0);
 var $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0);
 var $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0;
 var $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0);
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = 0, $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = Math_fround(0);
 var $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = Math_fround(0), $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = 0, $456 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $b2w = 0, $brmerge$i = 0, $brmerge2$i = 0, $exitcond$i = 0, $i$01$i = 0, $shapes$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $shapes$i = sp + 28|0;
 $b2w = sp;
 $0 = sp + 32|0;
 $1 = (($this) + 236|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2 & 65536;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $7 = (($this) + 32|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = (($this) + 176|0);
   HEAPF32[$9>>2] = $8;
   $10 = (($this) + 36|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = (($this) + 180|0);
   HEAPF32[$12>>2] = $11;
   $13 = (($this) + 40|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = (($this) + 184|0);
   HEAPF32[$15>>2] = $14;
   $16 = (($this) + 44|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = (($this) + 188|0);
   HEAPF32[$18>>2] = $17;
   $19 = (($this) + 48|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = (($this) + 192|0);
   HEAPF32[$21>>2] = $20;
   $22 = (($this) + 52|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = (($this) + 196|0);
   HEAPF32[$24>>2] = $23;
   $25 = (($this) + 56|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = (($this) + 200|0);
   HEAPF32[$27>>2] = $26;
  } else {
   $28 = $2 & 131072;
   $29 = ($28|0)==(0);
   if ($29) {
    $30 = (($this) + 16|0);
    $31 = (($this) + 176|0);
    __ZN5physx2Sc8BodyCore13setBody2WorldERKNS_11PxTransformE($30,$31);
    break;
   }
   $32 = (($this) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    $35 = HEAP32[$this>>2]|0;
    $36 = $4 >>> 24;
    $37 = $36 & 15;
    $38 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($35,$37)|0);
    HEAP32[$32>>2] = $38;
    $41 = $38;
   } else {
    $41 = $33;
   }
   $39 = (($this) + 16|0);
   $40 = (($41) + 144|0);
   $42 = (($this) + 64|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = Math_fround(-$43);
   $45 = (($this) + 68|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = Math_fround(-$46);
   $48 = (($this) + 72|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = Math_fround(-$49);
   $51 = (($this) + 76|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $53 = (($41) + 160|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = (($this) + 80|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = Math_fround($54 - $56);
   $58 = (($41) + 164|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = (($this) + 84|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = Math_fround($59 - $61);
   $63 = (($41) + 168|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = (($this) + 88|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = Math_fround($64 - $66);
   $68 = Math_fround($57 * Math_fround(2.0));
   $69 = Math_fround($62 * Math_fround(2.0));
   $70 = Math_fround($67 * Math_fround(2.0));
   $71 = Math_fround($52 * $52);
   $72 = Math_fround($71 + Math_fround(-0.5));
   $73 = Math_fround($68 * $44);
   $74 = Math_fround($69 * $47);
   $75 = Math_fround($73 + $74);
   $76 = Math_fround($70 * $50);
   $77 = Math_fround($75 + $76);
   $78 = Math_fround($72 * $68);
   $79 = Math_fround($70 * $47);
   $80 = Math_fround($69 * $50);
   $81 = Math_fround($79 - $80);
   $82 = Math_fround($52 * $81);
   $83 = Math_fround($78 + $82);
   $84 = Math_fround($77 * $44);
   $85 = Math_fround($84 + $83);
   $86 = Math_fround($72 * $69);
   $87 = Math_fround($68 * $50);
   $88 = Math_fround($70 * $44);
   $89 = Math_fround($87 - $88);
   $90 = Math_fround($52 * $89);
   $91 = Math_fround($86 + $90);
   $92 = Math_fround($77 * $47);
   $93 = Math_fround($92 + $91);
   $94 = Math_fround($72 * $70);
   $95 = Math_fround($69 * $44);
   $96 = Math_fround($68 * $47);
   $97 = Math_fround($95 - $96);
   $98 = Math_fround($52 * $97);
   $99 = Math_fround($94 + $98);
   $100 = Math_fround($77 * $50);
   $101 = Math_fround($99 + $100);
   $102 = Math_fround(HEAPF32[$40>>2]);
   $103 = Math_fround($52 * $102);
   $104 = (($41) + 156|0);
   $105 = Math_fround(HEAPF32[$104>>2]);
   $106 = Math_fround($105 * $44);
   $107 = Math_fround($103 + $106);
   $108 = (($41) + 152|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = Math_fround($109 * $47);
   $111 = Math_fround($107 + $110);
   $112 = (($41) + 148|0);
   $113 = Math_fround(HEAPF32[$112>>2]);
   $114 = Math_fround($113 * $50);
   $115 = Math_fround($111 - $114);
   $116 = Math_fround($52 * $113);
   $117 = Math_fround($105 * $47);
   $118 = Math_fround($117 + $116);
   $119 = Math_fround($102 * $50);
   $120 = Math_fround($119 + $118);
   $121 = Math_fround($109 * $44);
   $122 = Math_fround($120 - $121);
   $123 = Math_fround($52 * $109);
   $124 = Math_fround($105 * $50);
   $125 = Math_fround($124 + $123);
   $126 = Math_fround($113 * $44);
   $127 = Math_fround($126 + $125);
   $128 = Math_fround($102 * $47);
   $129 = Math_fround($127 - $128);
   $130 = Math_fround($52 * $105);
   $131 = Math_fround($102 * $44);
   $132 = Math_fround($130 - $131);
   $133 = Math_fround($113 * $47);
   $134 = Math_fround($132 - $133);
   $135 = Math_fround($109 * $50);
   $136 = Math_fround($134 - $135);
   $137 = (($this) + 32|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   $139 = (($b2w) + 4|0);
   $140 = (($this) + 36|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = (($b2w) + 8|0);
   $143 = (($this) + 40|0);
   $144 = Math_fround(HEAPF32[$143>>2]);
   $145 = (($b2w) + 12|0);
   $146 = (($this) + 44|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = (($b2w) + 16|0);
   $149 = (($this) + 48|0);
   $150 = Math_fround(HEAPF32[$149>>2]);
   $151 = (($b2w) + 20|0);
   $152 = (($this) + 52|0);
   $153 = Math_fround(HEAPF32[$152>>2]);
   $154 = (($b2w) + 24|0);
   $155 = (($this) + 56|0);
   $156 = Math_fround(HEAPF32[$155>>2]);
   $157 = Math_fround($85 * Math_fround(2.0));
   $158 = Math_fround($93 * Math_fround(2.0));
   $159 = Math_fround($101 * Math_fround(2.0));
   $160 = Math_fround($147 * $147);
   $161 = Math_fround($160 + Math_fround(-0.5));
   $162 = Math_fround($157 * $138);
   $163 = Math_fround($158 * $141);
   $164 = Math_fround($162 + $163);
   $165 = Math_fround($159 * $144);
   $166 = Math_fround($164 + $165);
   $167 = Math_fround($157 * $161);
   $168 = Math_fround($159 * $141);
   $169 = Math_fround($158 * $144);
   $170 = Math_fround($168 - $169);
   $171 = Math_fround($147 * $170);
   $172 = Math_fround($167 + $171);
   $173 = Math_fround($138 * $166);
   $174 = Math_fround($173 + $172);
   $175 = Math_fround($158 * $161);
   $176 = Math_fround($157 * $144);
   $177 = Math_fround($159 * $138);
   $178 = Math_fround($176 - $177);
   $179 = Math_fround($147 * $178);
   $180 = Math_fround($175 + $179);
   $181 = Math_fround($141 * $166);
   $182 = Math_fround($181 + $180);
   $183 = Math_fround($159 * $161);
   $184 = Math_fround($158 * $138);
   $185 = Math_fround($157 * $141);
   $186 = Math_fround($184 - $185);
   $187 = Math_fround($147 * $186);
   $188 = Math_fround($183 + $187);
   $189 = Math_fround($144 * $166);
   $190 = Math_fround($188 + $189);
   $191 = Math_fround($150 + $174);
   $192 = Math_fround($153 + $182);
   $193 = Math_fround($156 + $190);
   $194 = Math_fround($115 * $147);
   $195 = Math_fround($136 * $138);
   $196 = Math_fround($194 + $195);
   $197 = Math_fround($129 * $141);
   $198 = Math_fround($196 + $197);
   $199 = Math_fround($122 * $144);
   $200 = Math_fround($198 - $199);
   $201 = Math_fround($122 * $147);
   $202 = Math_fround($136 * $141);
   $203 = Math_fround($201 + $202);
   $204 = Math_fround($115 * $144);
   $205 = Math_fround($204 + $203);
   $206 = Math_fround($129 * $138);
   $207 = Math_fround($205 - $206);
   $208 = Math_fround($129 * $147);
   $209 = Math_fround($136 * $144);
   $210 = Math_fround($208 + $209);
   $211 = Math_fround($122 * $138);
   $212 = Math_fround($211 + $210);
   $213 = Math_fround($115 * $141);
   $214 = Math_fround($212 - $213);
   $215 = Math_fround($136 * $147);
   $216 = Math_fround($115 * $138);
   $217 = Math_fround($215 - $216);
   $218 = Math_fround($122 * $141);
   $219 = Math_fround($217 - $218);
   $220 = Math_fround($129 * $144);
   $221 = Math_fround($219 - $220);
   HEAPF32[$b2w>>2] = $200;
   HEAPF32[$139>>2] = $207;
   HEAPF32[$142>>2] = $214;
   HEAPF32[$145>>2] = $221;
   HEAPF32[$148>>2] = $191;
   HEAPF32[$151>>2] = $192;
   HEAPF32[$154>>2] = $193;
   $222 = (($this) + 176|0);
   HEAPF32[$222>>2] = $200;
   $223 = (($this) + 180|0);
   HEAPF32[$223>>2] = $207;
   $224 = (($this) + 184|0);
   HEAPF32[$224>>2] = $214;
   $225 = (($this) + 188|0);
   HEAPF32[$225>>2] = $221;
   $226 = (($this) + 192|0);
   HEAPF32[$226>>2] = $191;
   $227 = (($this) + 196|0);
   HEAPF32[$227>>2] = $192;
   $228 = (($this) + 200|0);
   HEAPF32[$228>>2] = $193;
   __ZN5physx2Sc8BodyCore13setBody2WorldERKNS_11PxTransformE($39,$b2w);
  }
 } while(0);
 $229 = $2 & 262144;
 $230 = ($229|0)==(0);
 if ($230) {
  $231 = (($this) + 96|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = (($this) + 204|0);
  HEAPF32[$233>>2] = $232;
  $234 = (($this) + 100|0);
  $235 = Math_fround(HEAPF32[$234>>2]);
  $236 = (($this) + 208|0);
  HEAPF32[$236>>2] = $235;
  $237 = (($this) + 104|0);
  $238 = Math_fround(HEAPF32[$237>>2]);
  $239 = (($this) + 212|0);
  HEAPF32[$239>>2] = $238;
 } else {
  $240 = (($this) + 204|0);
  $241 = Math_fround(HEAPF32[$240>>2]);
  $242 = (($this) + 96|0);
  HEAPF32[$242>>2] = $241;
  $243 = (($this) + 208|0);
  $244 = Math_fround(HEAPF32[$243>>2]);
  $245 = (($this) + 100|0);
  HEAPF32[$245>>2] = $244;
  $246 = (($this) + 212|0);
  $247 = Math_fround(HEAPF32[$246>>2]);
  $248 = (($this) + 104|0);
  HEAPF32[$248>>2] = $247;
 }
 $249 = $2 & 524288;
 $250 = ($249|0)==(0);
 if ($250) {
  $251 = (($this) + 112|0);
  $252 = Math_fround(HEAPF32[$251>>2]);
  $253 = (($this) + 216|0);
  HEAPF32[$253>>2] = $252;
  $254 = (($this) + 116|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = (($this) + 220|0);
  HEAPF32[$256>>2] = $255;
  $257 = (($this) + 120|0);
  $258 = Math_fround(HEAPF32[$257>>2]);
  $259 = (($this) + 224|0);
  HEAPF32[$259>>2] = $258;
 } else {
  $260 = (($this) + 216|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = (($this) + 112|0);
  HEAPF32[$262>>2] = $261;
  $263 = (($this) + 220|0);
  $264 = Math_fround(HEAPF32[$263>>2]);
  $265 = (($this) + 116|0);
  HEAPF32[$265>>2] = $264;
  $266 = (($this) + 224|0);
  $267 = Math_fround(HEAPF32[$266>>2]);
  $268 = (($this) + 120|0);
  HEAPF32[$268>>2] = $267;
 }
 $269 = $4 & 1;
 $270 = ($269|0)==(0);
 do {
  if (!($270)) {
   $271 = (($this) + 8|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = ($272|0)==(0|0);
   if ($273) {
    $274 = HEAP32[$this>>2]|0;
    $275 = HEAP32[$3>>2]|0;
    $276 = $275 >>> 24;
    $277 = $276 & 15;
    $278 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($274,$277)|0);
    HEAP32[$271>>2] = $278;
    $284 = $278;
   } else {
    $284 = $272;
   }
   $279 = (($this) + 24|0);
   $280 = HEAP16[$279>>1]|0;
   $281 = $280 & 8;
   $282 = ($281<<16>>16)!=(0);
   $283 = HEAP16[$284>>1]|0;
   $285 = $283 & 8;
   $286 = ($285<<16>>16)!=(0);
   $$not$i = $282 ^ 1;
   $brmerge$i = $286 | $$not$i;
   if ($brmerge$i) {
    $$not1$i = $286 ^ 1;
    $brmerge2$i = $282 | $$not1$i;
    if ($brmerge2$i) {
     break;
    }
    $309 = HEAP32[$this>>2]|0;
    __ZN5physx3Scb5Scene18switchRigidToNoSimERNS0_11RigidObjectEb($309,$this,1);
    break;
   }
   $287 = HEAP32[$this>>2]|0;
   $288 = HEAP32[$3>>2]|0;
   $$mask$i = $288 & -1073741824;
   $289 = ($$mask$i|0)==(-2147483648);
   if ($289) {
    $290 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
    $291 = (($290) + -16)|0;
    $292 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($this,$shapes$i)|0);
    $293 = (($287) + 16|0);
    $294 = $this;
    $295 = HEAP32[$3>>2]|0;
    $296 = $295 >>> 24;
    $297 = $296 & 15;
    $298 = ((444424 + ($297<<2)|0) + 24|0);
    $299 = HEAP32[$298>>2]|0;
    $300 = (($299) + ($294))|0;
    $301 = $300;
    $302 = HEAP32[$shapes$i>>2]|0;
    __ZN5physx2Sc5Scene7addBodyERNS0_8BodyCoreEPKPvjj($293,$301,$302,$292,$290);
    $303 = ($292|0)==(0);
    if (!($303)) {
     $i$01$i = 0;
     while(1) {
      $304 = HEAP32[$shapes$i>>2]|0;
      $305 = (($304) + ($i$01$i<<2)|0);
      $306 = HEAP32[$305>>2]|0;
      $307 = (($306) + ($291)|0);
      __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($307);
      $308 = (($i$01$i) + 1)|0;
      $exitcond$i = ($308|0)==($292|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$01$i = $308;
      }
     }
    }
   }
  }
 } while(0);
 $310 = $2 & -8192002;
 $311 = ($310|0)==(0);
 do {
  if (!($311)) {
   $312 = (($this) + 8|0);
   $313 = HEAP32[$312>>2]|0;
   $314 = ($313|0)==(0|0);
   if ($314) {
    $315 = HEAP32[$this>>2]|0;
    $316 = HEAP32[$3>>2]|0;
    $317 = $316 >>> 24;
    $318 = $317 & 15;
    $319 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($315,$318)|0);
    HEAP32[$312>>2] = $319;
    $325 = $319;
   } else {
    $325 = $313;
   }
   $320 = HEAP32[$1>>2]|0;
   $321 = $320 & 1;
   $322 = ($321|0)==(0);
   if ($322) {
    $328 = $320;
   } else {
    $323 = (($this) + 16|0);
    $324 = (($325) + 92|0);
    $326 = Math_fround(HEAPF32[$324>>2]);
    __ZN5physx2Sc8BodyCore14setInverseMassEf($323,$326);
    $$pre = HEAP32[$1>>2]|0;
    $328 = $$pre;
   }
   $327 = $328 & 2;
   $329 = ($327|0)==(0);
   if ($329) {
    $333 = $328;
   } else {
    $330 = (($this) + 16|0);
    $331 = (($325) + 96|0);
    __ZN5physx2Sc8BodyCore17setInverseInertiaERKNS_6PxVec3E($330,$331);
    $$pre3 = HEAP32[$1>>2]|0;
    $333 = $$pre3;
   }
   $332 = $333 & 4;
   $334 = ($332|0)==(0);
   if ($334) {
    $339 = $333;
   } else {
    $335 = (($this) + 16|0);
    $336 = (($325) + 108|0);
    $337 = Math_fround(HEAPF32[$336>>2]);
    __ZN5physx2Sc8BodyCore16setLinearDampingEf($335,$337);
    $$pre4 = HEAP32[$1>>2]|0;
    $339 = $$pre4;
   }
   $338 = $339 & 8;
   $340 = ($338|0)==(0);
   if ($340) {
    $345 = $339;
   } else {
    $341 = (($this) + 16|0);
    $342 = (($325) + 112|0);
    $343 = Math_fround(HEAPF32[$342>>2]);
    __ZN5physx2Sc8BodyCore17setAngularDampingEf($341,$343);
    $$pre5 = HEAP32[$1>>2]|0;
    $345 = $$pre5;
   }
   $344 = $345 & 16;
   $346 = ($344|0)==(0);
   if ($346) {
    $351 = $345;
   } else {
    $347 = (($this) + 16|0);
    $348 = (($325) + 116|0);
    $349 = Math_fround(HEAPF32[$348>>2]);
    __ZN5physx2Sc8BodyCore14setMaxAngVelSqEf($347,$349);
    $$pre6 = HEAP32[$1>>2]|0;
    $351 = $$pre6;
   }
   $350 = $351 & 32;
   $352 = ($350|0)==(0);
   if (!($352)) {
    $353 = (($325) + 120|0);
    $354 = Math_fround(HEAPF32[$353>>2]);
    $355 = (($this) + 160|0);
    HEAPF32[$355>>2] = $354;
   }
   $356 = $351 & 256;
   $357 = ($356|0)==(0);
   if (!($357)) {
    $358 = (($325) + 132|0);
    $359 = HEAP16[$358>>1]|0;
    $360 = (($this) + 62|0);
    HEAP16[$360>>1] = $359;
   }
   $361 = $351 & 128;
   $362 = ($361|0)==(0);
   if (!($362)) {
    $363 = (($325) + 128|0);
    $364 = Math_fround(HEAPF32[$363>>2]);
    $365 = (($this) + 124|0);
    HEAPF32[$365>>2] = $364;
   }
   $366 = $351 & 512;
   $367 = ($366|0)==(0);
   if (!($367)) {
    $368 = (($325) + 144|0);
    $369 = Math_fround(HEAPF32[$368>>2]);
    $370 = (($this) + 64|0);
    HEAPF32[$370>>2] = $369;
    $371 = (($325) + 148|0);
    $372 = Math_fround(HEAPF32[$371>>2]);
    $373 = (($this) + 68|0);
    HEAPF32[$373>>2] = $372;
    $374 = (($325) + 152|0);
    $375 = Math_fround(HEAPF32[$374>>2]);
    $376 = (($this) + 72|0);
    HEAPF32[$376>>2] = $375;
    $377 = (($325) + 156|0);
    $378 = Math_fround(HEAPF32[$377>>2]);
    $379 = (($this) + 76|0);
    HEAPF32[$379>>2] = $378;
    $380 = (($325) + 160|0);
    $381 = Math_fround(HEAPF32[$380>>2]);
    $382 = (($this) + 80|0);
    HEAPF32[$382>>2] = $381;
    $383 = (($325) + 164|0);
    $384 = Math_fround(HEAPF32[$383>>2]);
    $385 = (($this) + 84|0);
    HEAPF32[$385>>2] = $384;
    $386 = (($325) + 168|0);
    $387 = Math_fround(HEAPF32[$386>>2]);
    $388 = (($this) + 88|0);
    HEAPF32[$388>>2] = $387;
   }
   $389 = $351 & 2048;
   $390 = ($389|0)==(0);
   if (!($390)) {
    $391 = (($325) + 176|0);
    $392 = Math_fround(HEAPF32[$391>>2]);
    $393 = (($this) + 164|0);
    HEAPF32[$393>>2] = $392;
   }
   $394 = $351 & 1024;
   $395 = ($394|0)==(0);
   if (!($395)) {
    $396 = (($325) + 172|0);
    $397 = Math_fround(HEAPF32[$396>>2]);
    $398 = (($this) + 108|0);
    HEAPF32[$398>>2] = $397;
   }
   $399 = $2 & 4096;
   $400 = ($399|0)==(0);
   if (!($400)) {
    $401 = (($this) + 16|0);
    $402 = HEAP32[$this>>2]|0;
    $403 = (($402) + 1256|0);
    $404 = HEAP32[$403>>2]|0;
    $405 = (($325) + 268|0);
    $406 = HEAP8[$405>>0]|0;
    HEAP8[$0>>0] = $406;
    __ZN5physx2Sc8BodyCore8setFlagsEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($401,$404,$0);
   }
   $407 = $2 & 8192;
   $408 = ($407|0)==(0);
   if (!($408)) {
    $409 = (($this) + 16|0);
    $410 = HEAP32[$this>>2]|0;
    $411 = (($410) + 1256|0);
    $412 = HEAP32[$411>>2]|0;
    $413 = (($325) + 192|0);
    $414 = (($this) + 228|0);
    $415 = Math_fround(HEAPF32[$414>>2]);
    __ZN5physx2Sc8BodyCore18setKinematicTargetEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEERKNS_11PxTransformEf($409,$412,$413,$415);
   }
   $416 = $2 & 16384;
   $417 = ($416|0)==(0);
   if (!($417)) {
    $418 = (($this) + 16|0);
    $419 = HEAP32[$this>>2]|0;
    $420 = (($419) + 1256|0);
    $421 = HEAP32[$420>>2]|0;
    $422 = (($325) + 220|0);
    $423 = (($325) + 232|0);
    __ZN5physx2Sc8BodyCore22addSpatialAccelerationEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEPKNS_6PxVec3ESB_($418,$421,$422,$423);
   }
   $424 = $2 & 32768;
   $425 = ($424|0)==(0);
   if ($425) {
    break;
   }
   $426 = (($this) + 16|0);
   $427 = HEAP32[$this>>2]|0;
   $428 = (($427) + 1256|0);
   $429 = HEAP32[$428>>2]|0;
   $430 = (($325) + 244|0);
   $431 = (($325) + 256|0);
   __ZN5physx2Sc8BodyCore18addSpatialVelocityEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEPKNS_6PxVec3ESB_($426,$429,$430,$431);
  }
 } while(0);
 $432 = $2 & 1048576;
 $433 = ($432|0)==(0);
 if ($433) {
  $434 = (($this) + 16|0);
  $435 = (Math_fround(__ZNK5physx2Sc8BodyCore14getWakeCounterEv($434)));
  $436 = (($this) + 228|0);
  HEAPF32[$436>>2] = $435;
  $$pre7 = $2 & 6291456;
  $$pre$phi9Z2D = $434;$$pre$phiZ2D = $$pre7;
  label = 60;
 } else {
  $437 = $2 & 6291456;
  $438 = ($437|0)==(0);
  $439 = (($this) + 16|0);
  if ($438) {
   $440 = (($this) + 228|0);
   $441 = Math_fround(HEAPF32[$440>>2]);
   __ZN5physx2Sc8BodyCore14setWakeCounterEfb($439,$441,0);
   $442 = (__ZNK5physx2Sc8BodyCore10isSleepingEv($439)|0);
   $448 = $442;
  } else {
   $$pre$phi9Z2D = $439;$$pre$phiZ2D = $437;
   label = 60;
  }
 }
 if ((label|0) == 60) {
  $443 = (__ZNK5physx2Sc8BodyCore10isSleepingEv($$pre$phi9Z2D)|0);
  $444 = ($$pre$phiZ2D|0)==(0);
  if ($444) {
   $448 = $443;
  } else {
   $450 = $2 & 2097152;
   $451 = ($450|0)==(0);
   if ($451) {
    $452 = (($this) + 228|0);
    $453 = Math_fround(HEAPF32[$452>>2]);
    __ZN5physx2Sc8BodyCore14setWakeCounterEfb($$pre$phi9Z2D,$453,1);
    __ZN5physx3Scb11RigidObject9syncStateEv($this);
    $454 = (($this) + 8|0);
    HEAP32[$454>>2] = 0;
    $455 = HEAP32[$3>>2]|0;
    $456 = $455 & -16777216;
    HEAP32[$3>>2] = $456;
    HEAP32[$1>>2] = 0;
    STACKTOP = sp;return;
   } else {
    __ZN5physx2Sc8BodyCore10putToSleepEv($$pre$phi9Z2D);
    __ZN5physx3Scb11RigidObject9syncStateEv($this);
    $454 = (($this) + 8|0);
    HEAP32[$454>>2] = 0;
    $455 = HEAP32[$3>>2]|0;
    $456 = $455 & -16777216;
    HEAP32[$3>>2] = $456;
    HEAP32[$1>>2] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 $445 = HEAP32[$3>>2]|0;
 $$mask = $445 & -1073741824;
 $446 = ($$mask|0)==(-1073741824);
 if ($446) {
  __ZN5physx3Scb11RigidObject9syncStateEv($this);
  $454 = (($this) + 8|0);
  HEAP32[$454>>2] = 0;
  $455 = HEAP32[$3>>2]|0;
  $456 = $455 & -16777216;
  HEAP32[$3>>2] = $456;
  HEAP32[$1>>2] = 0;
  STACKTOP = sp;return;
 }
 $447 = $448&1;
 $449 = (($this) + 232|0);
 HEAP32[$449>>2] = $447;
 __ZN5physx3Scb11RigidObject9syncStateEv($this);
 $454 = (($this) + 8|0);
 HEAP32[$454>>2] = 0;
 $455 = HEAP32[$3>>2]|0;
 $456 = $455 & -16777216;
 HEAP32[$3>>2] = $456;
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene20processPendingRemoveEv($this) {
 $this = $this|0;
 var $$mask = 0, $$mask$i = 0, $$mask$i12 = 0, $$mask$i17 = 0, $$mask$i22 = 0, $$mask$i27 = 0, $$mask$i3 = 0, $$mask$i32 = 0, $$mask$i37 = 0, $$mask$i8 = 0, $$pre = 0, $$pre$i = 0, $$pre$i14 = 0, $$pre$i19 = 0, $$pre$i34 = 0, $$pre$i39 = 0, $$pre$i5 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$01$i11 = 0, $i$01$i16 = 0, $i$01$i2 = 0, $i$01$i21 = 0, $i$01$i26 = 0, $i$01$i31 = 0, $i$01$i36 = 0, $i$01$i7 = 0, $i$040 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2560|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 2528|0);
  $159 = $1;$i$01$i = 0;
  while(1) {
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + ($i$01$i<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $$mask$i = $8 & -1073741824;
   $9 = ($$mask$i|0)==(-2147483648);
   if ($9) {
    __ZN5physx3Scb11RigidObject19processShapeRemovesEv($6);
    $$pre$i = HEAP32[$0>>2]|0;
    $12 = $$pre$i;
   } else {
    $12 = $159;
   }
   $10 = (($i$01$i) + 1)|0;
   $11 = ($10>>>0)<($12>>>0);
   if ($11) {
    $159 = $12;$i$01$i = $10;
   } else {
    break;
   }
  }
 }
 $13 = (($this) + 2600|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = (($this) + 2568|0);
  $160 = $14;$i$01$i2 = 0;
  while(1) {
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + ($i$01$i2<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $$mask$i3 = $21 & -1073741824;
   $22 = ($$mask$i3|0)==(-2147483648);
   if ($22) {
    __ZN5physx3Scb11RigidObject19processShapeRemovesEv($19);
    $$pre$i5 = HEAP32[$13>>2]|0;
    $25 = $$pre$i5;
   } else {
    $25 = $160;
   }
   $23 = (($i$01$i2) + 1)|0;
   $24 = ($23>>>0)<($25>>>0);
   if ($24) {
    $160 = $25;$i$01$i2 = $23;
   } else {
    break;
   }
  }
 }
 $26 = (($this) + 2680|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if (!($28)) {
  $29 = (($this) + 2648|0);
  $30 = (($this) + 16|0);
  $i$01$i7 = 0;
  while(1) {
   $31 = HEAP32[$29>>2]|0;
   $32 = (($31) + ($i$01$i7<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $$mask$i8 = $35 & -1073741824;
   $36 = ($$mask$i8|0)==(-1073741824);
   if ($36) {
    $37 = (($33) + 12|0);
    __ZN5physx2Sc5Scene16removeConstraintERNS0_14ConstraintCoreE($30,$37);
    $38 = HEAP32[$34>>2]|0;
    $39 = $38 & 268435456;
    $40 = ($39|0)==(0);
    if ($40) {
     __ZN5physx3Scb10Constraint9syncStateEv($33);
    }
   }
   $41 = (($i$01$i7) + 1)|0;
   $42 = HEAP32[$26>>2]|0;
   $43 = ($41>>>0)<($42>>>0);
   if ($43) {
    $i$01$i7 = $41;
   } else {
    break;
   }
  }
 }
 $44 = (($this) + 2760|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = (($this) + 2728|0);
  $48 = (($this) + 16|0);
  $161 = $45;$i$01$i11 = 0;
  while(1) {
   $49 = HEAP32[$47>>2]|0;
   $50 = (($49) + ($i$01$i11<<2)|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $$mask$i12 = $53 & -1073741824;
   $54 = ($$mask$i12|0)==(-1073741824);
   if ($54) {
    $55 = (($51) + 12|0);
    __ZN5physx2Sc5Scene23removeArticulationJointERNS0_21ArticulationJointCoreE($48,$55);
    $$pre$i14 = HEAP32[$44>>2]|0;
    $58 = $$pre$i14;
   } else {
    $58 = $161;
   }
   $56 = (($i$01$i11) + 1)|0;
   $57 = ($56>>>0)<($58>>>0);
   if ($57) {
    $161 = $58;$i$01$i11 = $56;
   } else {
    break;
   }
  }
 }
 $59 = HEAP32[$0>>2]|0;
 $60 = ($59|0)==(0);
 if (!($60)) {
  $61 = (($this) + 2528|0);
  $62 = (($this) + 16|0);
  $162 = $59;$i$01$i16 = 0;
  while(1) {
   $63 = HEAP32[$61>>2]|0;
   $64 = (($63) + ($i$01$i16<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 4|0);
   $67 = HEAP32[$66>>2]|0;
   $$mask$i17 = $67 & -1073741824;
   $68 = ($$mask$i17|0)==(-1073741824);
   if ($68) {
    $69 = $67 & 16;
    $70 = ($69|0)!=(0);
    __ZN10ScSceneFnsIN5physx3Scb11RigidStaticEE6removeERNS0_2Sc5SceneERS2_b($62,$65,$70);
    $$pre$i19 = HEAP32[$0>>2]|0;
    $73 = $$pre$i19;
   } else {
    $73 = $162;
   }
   $71 = (($i$01$i16) + 1)|0;
   $72 = ($71>>>0)<($73>>>0);
   if ($72) {
    $162 = $73;$i$01$i16 = $71;
   } else {
    break;
   }
  }
 }
 $74 = HEAP32[$13>>2]|0;
 $75 = ($74|0)==(0);
 if (!($75)) {
  $76 = (($this) + 2568|0);
  $77 = (($this) + 16|0);
  $i$01$i21 = 0;
  while(1) {
   $78 = HEAP32[$76>>2]|0;
   $79 = (($78) + ($i$01$i21<<2)|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($80) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   $$mask$i22 = $82 & -1073741824;
   $83 = ($$mask$i22|0)==(-1073741824);
   if ($83) {
    $84 = $82 & 16;
    $85 = ($84|0)!=(0);
    __ZN10ScSceneFnsIN5physx3Scb4BodyEE6removeERNS0_2Sc5SceneERS2_b($77,$80,$85);
    $86 = HEAP32[$81>>2]|0;
    $87 = $86 & 268435456;
    $88 = ($87|0)==(0);
    if ($88) {
     __ZN5physx3Scb4Body9syncStateEv($80);
    }
   }
   $89 = (($i$01$i21) + 1)|0;
   $90 = HEAP32[$13>>2]|0;
   $91 = ($89>>>0)<($90>>>0);
   if ($91) {
    $i$01$i21 = $89;
   } else {
    break;
   }
  }
 }
 $92 = (($this) + 2720|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==(0);
 if (!($94)) {
  $95 = (($this) + 2688|0);
  $96 = (($this) + 16|0);
  $i$01$i26 = 0;
  while(1) {
   $97 = HEAP32[$95>>2]|0;
   $98 = (($97) + ($i$01$i26<<2)|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (($99) + 4|0);
   $101 = HEAP32[$100>>2]|0;
   $$mask$i27 = $101 & -1073741824;
   $102 = ($$mask$i27|0)==(-1073741824);
   if ($102) {
    $103 = $101 & -769;
    HEAP32[$100>>2] = $103;
    $104 = (($99) + 12|0);
    __ZN5physx2Sc5Scene18removeArticulationERNS0_16ArticulationCoreE($96,$104);
    $105 = HEAP32[$100>>2]|0;
    $106 = $105 & 268435456;
    $107 = ($106|0)==(0);
    if ($107) {
     __ZN5physx3Scb12Articulation9syncStateEv($99);
    }
   }
   $108 = (($i$01$i26) + 1)|0;
   $109 = HEAP32[$92>>2]|0;
   $110 = ($108>>>0)<($109>>>0);
   if ($110) {
    $i$01$i26 = $108;
   } else {
    break;
   }
  }
 }
 $111 = (($this) + 2640|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ($112|0)==(0);
 if (!($113)) {
  $114 = (($this) + 2608|0);
  $115 = (($this) + 16|0);
  $163 = $112;$i$01$i31 = 0;
  while(1) {
   $116 = HEAP32[$114>>2]|0;
   $117 = (($116) + ($i$01$i31<<2)|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($118) + 4|0);
   $120 = HEAP32[$119>>2]|0;
   $$mask$i32 = $120 & -1073741824;
   $121 = ($$mask$i32|0)==(-1073741824);
   if ($121) {
    $122 = (($118) + 12|0);
    $123 = $120 & 536870912;
    $124 = ($123|0)!=(0);
    __ZN5physx2Sc5Scene20removeParticleSystemERNS0_18ParticleSystemCoreEb($115,$122,$124);
    $$pre$i34 = HEAP32[$111>>2]|0;
    $127 = $$pre$i34;
   } else {
    $127 = $163;
   }
   $125 = (($i$01$i31) + 1)|0;
   $126 = ($125>>>0)<($127>>>0);
   if ($126) {
    $163 = $127;$i$01$i31 = $125;
   } else {
    break;
   }
  }
 }
 $128 = (($this) + 2840|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ($129|0)==(0);
 if (!($130)) {
  $131 = (($this) + 2808|0);
  $132 = (($this) + 16|0);
  $164 = $129;$i$01$i36 = 0;
  while(1) {
   $133 = HEAP32[$131>>2]|0;
   $134 = (($133) + ($i$01$i36<<2)|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = (($135) + 4|0);
   $137 = HEAP32[$136>>2]|0;
   $$mask$i37 = $137 & -1073741824;
   $138 = ($$mask$i37|0)==(-1073741824);
   if ($138) {
    $139 = (($135) + 12|0);
    __ZN5physx2Sc5Scene11removeClothERNS0_9ClothCoreE($132,$139);
    $$pre$i39 = HEAP32[$128>>2]|0;
    $142 = $$pre$i39;
   } else {
    $142 = $164;
   }
   $140 = (($i$01$i36) + 1)|0;
   $141 = ($140>>>0)<($142>>>0);
   if ($141) {
    $164 = $142;$i$01$i36 = $140;
   } else {
    break;
   }
  }
 }
 $143 = (($this) + 2800|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = ($144|0)==(0);
 if ($145) {
  STACKTOP = sp;return;
 }
 $146 = (($this) + 2768|0);
 $147 = (($this) + 16|0);
 $165 = $144;$i$040 = 0;
 while(1) {
  $148 = HEAP32[$146>>2]|0;
  $149 = (($148) + ($i$040<<2)|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = (($150) + 4|0);
  $152 = HEAP32[$151>>2]|0;
  $$mask = $152 & -1073741824;
  $153 = ($$mask|0)==(-1073741824);
  if ($153) {
   __ZN5physx3Scb9Aggregate9syncStateERNS0_5SceneE($150,$this);
   $154 = (($150) + 16|0);
   $155 = HEAP32[$154>>2]|0;
   __ZN5physx2Sc5Scene15deleteAggregateEj($147,$155);
   $$pre = HEAP32[$143>>2]|0;
   $158 = $$pre;
  } else {
   $158 = $165;
  }
  $156 = (($i$040) + 1)|0;
  $157 = ($156>>>0)<($158>>>0);
  if ($157) {
   $165 = $158;$i$040 = $156;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($this,$object) {
 $this = $this|0;
 $object = $object|0;
 var $$mask$i = 0, $$mask$i10 = 0, $$mask$i14 = 0, $$mask$i18 = 0, $$mask$i2 = 0, $$mask$i22 = 0, $$mask$i26 = 0, $$mask$i30 = 0, $$mask$i34 = 0, $$mask$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exists$i$i$i = 0, $exists$i$i$i1 = 0, $exists$i$i$i13 = 0, $exists$i$i$i17 = 0, $exists$i$i$i21 = 0, $exists$i$i$i25 = 0, $exists$i$i$i29 = 0, $exists$i$i$i33 = 0, $exists$i$i$i5 = 0, $exists$i$i$i9 = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i11 = 0, $or$cond$i$i$i15 = 0, $or$cond$i$i$i19 = 0, $or$cond$i$i$i23 = 0, $or$cond$i$i$i27 = 0;
 var $or$cond$i$i$i3 = 0, $or$cond$i$i$i31 = 0, $or$cond$i$i$i35 = 0, $or$cond$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $exists$i$i$i33 = sp + 49|0;
 $0 = sp + 36|0;
 $exists$i$i$i29 = sp + 48|0;
 $1 = sp + 32|0;
 $exists$i$i$i25 = sp + 47|0;
 $2 = sp + 24|0;
 $exists$i$i$i21 = sp + 46|0;
 $3 = sp + 16|0;
 $exists$i$i$i17 = sp + 45|0;
 $4 = sp + 8|0;
 $exists$i$i$i13 = sp + 42|0;
 $5 = sp + 4|0;
 $exists$i$i$i9 = sp + 41|0;
 $6 = sp;
 $exists$i$i$i5 = sp + 43|0;
 $7 = sp + 12|0;
 $exists$i$i$i1 = sp + 44|0;
 $8 = sp + 28|0;
 $exists$i$i$i = sp + 40|0;
 $9 = sp + 20|0;
 $10 = (($object) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 >>> 24;
 $13 = $12 & 15;
 do {
  switch ($13|0) {
  case 8:  {
   $74 = $11 & 268435456;
   $75 = ($74|0)==(0);
   if (!($75)) {
    STACKTOP = sp;return;
   }
   $76 = $11 | 268435456;
   HEAP32[$10>>2] = $76;
   $$mask$i26 = $11 & -1073741824;
   $77 = ($$mask$i26|0)==(-2147483648);
   if (!($77)) {
    STACKTOP = sp;return;
   }
   HEAP32[$2>>2] = $object;
   $78 = (($this) + 2684|0);
   $79 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($78,$2,$exists$i$i$i25)|0);
   $80 = HEAP8[$exists$i$i$i25>>0]|0;
   $81 = ($80<<24>>24)!=(0);
   $82 = ($79|0)==(0|0);
   $or$cond$i$i$i27 = $81 | $82;
   if ($or$cond$i$i$i27) {
    STACKTOP = sp;return;
   }
   $83 = HEAP32[$2>>2]|0;
   HEAP32[$79>>2] = $83;
   STACKTOP = sp;return;
   break;
  }
  case 2: case 1:  {
   $14 = $11 & 268435456;
   $15 = ($14|0)==(0);
   if (!($15)) {
    STACKTOP = sp;return;
   }
   $16 = $11 | 268435456;
   HEAP32[$10>>2] = $16;
   $$mask$i2 = $11 & -1073741824;
   $17 = ($$mask$i2|0)==(-2147483648);
   if (!($17)) {
    STACKTOP = sp;return;
   }
   HEAP32[$8>>2] = $object;
   $18 = (($this) + 2448|0);
   $19 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($18,$8,$exists$i$i$i1)|0);
   $20 = HEAP8[$exists$i$i$i1>>0]|0;
   $21 = ($20<<24>>24)!=(0);
   $22 = ($19|0)==(0|0);
   $or$cond$i$i$i3 = $21 | $22;
   if ($or$cond$i$i$i3) {
    STACKTOP = sp;return;
   }
   $23 = HEAP32[$8>>2]|0;
   HEAP32[$19>>2] = $23;
   STACKTOP = sp;return;
   break;
  }
  case 4:  {
   $34 = $11 & 268435456;
   $35 = ($34|0)==(0);
   if (!($35)) {
    STACKTOP = sp;return;
   }
   $36 = $11 | 268435456;
   HEAP32[$10>>2] = $36;
   $$mask$i10 = $11 & -1073741824;
   $37 = ($$mask$i10|0)==(-2147483648);
   if (!($37)) {
    STACKTOP = sp;return;
   }
   HEAP32[$6>>2] = $object;
   $38 = (($this) + 2564|0);
   $39 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($38,$6,$exists$i$i$i9)|0);
   $40 = HEAP8[$exists$i$i$i9>>0]|0;
   $41 = ($40<<24>>24)!=(0);
   $42 = ($39|0)==(0|0);
   $or$cond$i$i$i11 = $41 | $42;
   if ($or$cond$i$i$i11) {
    STACKTOP = sp;return;
   }
   $43 = HEAP32[$6>>2]|0;
   HEAP32[$39>>2] = $43;
   STACKTOP = sp;return;
   break;
  }
  case 11:  {
   $104 = $11 & 268435456;
   $105 = ($104|0)==(0);
   if (!($105)) {
    STACKTOP = sp;return;
   }
   $106 = $11 | 268435456;
   HEAP32[$10>>2] = $106;
   $$mask$i = $11 & -1073741824;
   $107 = ($$mask$i|0)==(-2147483648);
   if (!($107)) {
    STACKTOP = sp;return;
   }
   HEAP32[$9>>2] = $object;
   $108 = (($this) + 2804|0);
   $109 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($108,$9,$exists$i$i$i)|0);
   $110 = HEAP8[$exists$i$i$i>>0]|0;
   $111 = ($110<<24>>24)!=(0);
   $112 = ($109|0)==(0|0);
   $or$cond$i$i$i = $111 | $112;
   if ($or$cond$i$i$i) {
    STACKTOP = sp;return;
   }
   $113 = HEAP32[$9>>2]|0;
   HEAP32[$109>>2] = $113;
   STACKTOP = sp;return;
   break;
  }
  case 10:  {
   $94 = $11 & 268435456;
   $95 = ($94|0)==(0);
   if (!($95)) {
    STACKTOP = sp;return;
   }
   $96 = $11 | 268435456;
   HEAP32[$10>>2] = $96;
   $$mask$i34 = $11 & -1073741824;
   $97 = ($$mask$i34|0)==(-2147483648);
   if (!($97)) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = $object;
   $98 = (($this) + 2764|0);
   $99 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($98,$0,$exists$i$i$i33)|0);
   $100 = HEAP8[$exists$i$i$i33>>0]|0;
   $101 = ($100<<24>>24)!=(0);
   $102 = ($99|0)==(0|0);
   $or$cond$i$i$i35 = $101 | $102;
   if ($or$cond$i$i$i35) {
    STACKTOP = sp;return;
   }
   $103 = HEAP32[$0>>2]|0;
   HEAP32[$99>>2] = $103;
   STACKTOP = sp;return;
   break;
  }
  case 6:  {
   $54 = $11 & 268435456;
   $55 = ($54|0)==(0);
   if (!($55)) {
    STACKTOP = sp;return;
   }
   $56 = $11 | 268435456;
   HEAP32[$10>>2] = $56;
   $$mask$i18 = $11 & -1073741824;
   $57 = ($$mask$i18|0)==(-2147483648);
   if (!($57)) {
    STACKTOP = sp;return;
   }
   HEAP32[$4>>2] = $object;
   $58 = (($this) + 2644|0);
   $59 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($58,$4,$exists$i$i$i17)|0);
   $60 = HEAP8[$exists$i$i$i17>>0]|0;
   $61 = ($60<<24>>24)!=(0);
   $62 = ($59|0)==(0|0);
   $or$cond$i$i$i19 = $61 | $62;
   if ($or$cond$i$i$i19) {
    STACKTOP = sp;return;
   }
   $63 = HEAP32[$4>>2]|0;
   HEAP32[$59>>2] = $63;
   STACKTOP = sp;return;
   break;
  }
  case 9:  {
   $84 = $11 & 268435456;
   $85 = ($84|0)==(0);
   if (!($85)) {
    STACKTOP = sp;return;
   }
   $86 = $11 | 268435456;
   HEAP32[$10>>2] = $86;
   $$mask$i30 = $11 & -1073741824;
   $87 = ($$mask$i30|0)==(-2147483648);
   if (!($87)) {
    STACKTOP = sp;return;
   }
   HEAP32[$1>>2] = $object;
   $88 = (($this) + 2724|0);
   $89 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($88,$1,$exists$i$i$i29)|0);
   $90 = HEAP8[$exists$i$i$i29>>0]|0;
   $91 = ($90<<24>>24)!=(0);
   $92 = ($89|0)==(0|0);
   $or$cond$i$i$i31 = $91 | $92;
   if ($or$cond$i$i$i31) {
    STACKTOP = sp;return;
   }
   $93 = HEAP32[$1>>2]|0;
   HEAP32[$89>>2] = $93;
   STACKTOP = sp;return;
   break;
  }
  case 7:  {
   $64 = $11 & 268435456;
   $65 = ($64|0)==(0);
   if (!($65)) {
    STACKTOP = sp;return;
   }
   $66 = $11 | 268435456;
   HEAP32[$10>>2] = $66;
   $$mask$i22 = $11 & -1073741824;
   $67 = ($$mask$i22|0)==(-2147483648);
   if (!($67)) {
    STACKTOP = sp;return;
   }
   HEAP32[$3>>2] = $object;
   $68 = (($this) + 2604|0);
   $69 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($68,$3,$exists$i$i$i21)|0);
   $70 = HEAP8[$exists$i$i$i21>>0]|0;
   $71 = ($70<<24>>24)!=(0);
   $72 = ($69|0)==(0|0);
   $or$cond$i$i$i23 = $71 | $72;
   if ($or$cond$i$i$i23) {
    STACKTOP = sp;return;
   }
   $73 = HEAP32[$3>>2]|0;
   HEAP32[$69>>2] = $73;
   STACKTOP = sp;return;
   break;
  }
  case 3:  {
   $24 = $11 & 268435456;
   $25 = ($24|0)==(0);
   if (!($25)) {
    STACKTOP = sp;return;
   }
   $26 = $11 | 268435456;
   HEAP32[$10>>2] = $26;
   $$mask$i6 = $11 & -1073741824;
   $27 = ($$mask$i6|0)==(-2147483648);
   if (!($27)) {
    STACKTOP = sp;return;
   }
   HEAP32[$7>>2] = $object;
   $28 = (($this) + 2564|0);
   $29 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($28,$7,$exists$i$i$i5)|0);
   $30 = HEAP8[$exists$i$i$i5>>0]|0;
   $31 = ($30<<24>>24)!=(0);
   $32 = ($29|0)==(0|0);
   $or$cond$i$i$i7 = $31 | $32;
   if ($or$cond$i$i$i7) {
    STACKTOP = sp;return;
   }
   $33 = HEAP32[$7>>2]|0;
   HEAP32[$29>>2] = $33;
   STACKTOP = sp;return;
   break;
  }
  case 5:  {
   $44 = $11 & 268435456;
   $45 = ($44|0)==(0);
   if (!($45)) {
    STACKTOP = sp;return;
   }
   $46 = $11 | 268435456;
   HEAP32[$10>>2] = $46;
   $$mask$i14 = $11 & -1073741824;
   $47 = ($$mask$i14|0)==(-2147483648);
   if (!($47)) {
    STACKTOP = sp;return;
   }
   HEAP32[$5>>2] = $object;
   $48 = (($this) + 2524|0);
   $49 = (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($48,$5,$exists$i$i$i13)|0);
   $50 = HEAP8[$exists$i$i$i13>>0]|0;
   $51 = ($50<<24>>24)!=(0);
   $52 = ($49|0)==(0|0);
   $or$cond$i$i$i15 = $51 | $52;
   if ($or$cond$i$i$i15) {
    STACKTOP = sp;return;
   }
   $53 = HEAP32[$5>>2]|0;
   HEAP32[$49>>2] = $53;
   STACKTOP = sp;return;
   break;
  }
  default: {
   STACKTOP = sp;return;
  }
  }
 } while(0);
}
function __ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 do {
  switch ($type|0) {
  case 8:  {
   $66 = (($this) + 2420|0);
   $67 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($66,28,16)|0);
   STACKTOP = sp;return ($67|0);
   break;
  }
  case 7:  {
   $61 = (($this) + 2420|0);
   $62 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($61,80,16)|0);
   $63 = ($62|0)==(0|0);
   if ($63) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP16[$62>>1] = 0;
   $64 = (($62) + 3|0);
   HEAP8[$64>>0] = 0;
   $65 = (($62) + 60|0);
   ;HEAP32[$65+0>>2]=0|0;HEAP32[$65+4>>2]=0|0;HEAP32[$65+8>>2]=0|0;HEAP32[$65+12>>2]=0|0;HEAP16[$65+16>>1]=0|0;
   $$0 = $62;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 3:  {
   $7 = (($this) + 2420|0);
   $8 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($7,272,16)|0);
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP16[$8>>1] = 0;
   $10 = (($8) + 3|0);
   HEAP8[$10>>0] = 0;
   $11 = (($8) + 4|0);
   $12 = (($8) + 20|0);
   $13 = (($8) + 24|0);
   $14 = (($8) + 28|0);
   HEAP32[$14>>2] = 0;
   $15 = (($8) + 32|0);
   HEAP8[$12>>0] = 1;
   HEAP32[$13>>2] = $11;
   HEAP32[$15>>2] = 4;
   $16 = (($8) + 36|0);
   $17 = (($8) + 68|0);
   $18 = (($8) + 72|0);
   $19 = (($8) + 76|0);
   HEAP32[$19>>2] = 0;
   $20 = (($8) + 80|0);
   HEAP8[$17>>0] = 1;
   HEAP32[$18>>2] = $16;
   HEAP32[$20>>2] = 4;
   $21 = (($8) + 84|0);
   HEAP32[$21>>2] = 0;
   $22 = (($8) + 88|0);
   HEAP32[$22>>2] = 0;
   $23 = (($8) + 220|0);
   dest=$23+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$23+48>>0]=0|0;
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 9:  {
   $68 = (($this) + 2420|0);
   $69 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($68,140,16)|0);
   $$0 = $69;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 10:  {
   $70 = (($this) + 2420|0);
   $71 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($70,16,16)|0);
   $72 = ($71|0)==(0|0);
   if ($72) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$71>>2] = -1;
   $73 = (($71) + 4|0);
   HEAP32[$73>>2] = 0;
   $74 = (($71) + 8|0);
   HEAP32[$74>>2] = -1;
   $75 = (($71) + 12|0);
   HEAP32[$75>>2] = 0;
   $$0 = $71;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 5:  {
   $41 = (($this) + 2420|0);
   $42 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($41,128,16)|0);
   $43 = ($42|0)==(0|0);
   if ($43) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP16[$42>>1] = 0;
   $44 = (($42) + 3|0);
   HEAP8[$44>>0] = 0;
   $45 = (($42) + 4|0);
   $46 = (($42) + 20|0);
   $47 = (($42) + 24|0);
   $48 = (($42) + 28|0);
   HEAP32[$48>>2] = 0;
   $49 = (($42) + 32|0);
   HEAP8[$46>>0] = 1;
   HEAP32[$47>>2] = $45;
   HEAP32[$49>>2] = 4;
   $50 = (($42) + 36|0);
   $51 = (($42) + 68|0);
   $52 = (($42) + 72|0);
   $53 = (($42) + 76|0);
   HEAP32[$53>>2] = 0;
   $54 = (($42) + 80|0);
   HEAP8[$51>>0] = 1;
   HEAP32[$52>>2] = $50;
   HEAP32[$54>>2] = 4;
   $55 = (($42) + 84|0);
   HEAP32[$55>>2] = 0;
   $56 = (($42) + 88|0);
   HEAP32[$56>>2] = 0;
   $$0 = $42;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 4:  {
   $24 = (($this) + 2420|0);
   $25 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($24,272,16)|0);
   $26 = ($25|0)==(0|0);
   if ($26) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP16[$25>>1] = 0;
   $27 = (($25) + 3|0);
   HEAP8[$27>>0] = 0;
   $28 = (($25) + 4|0);
   $29 = (($25) + 20|0);
   $30 = (($25) + 24|0);
   $31 = (($25) + 28|0);
   HEAP32[$31>>2] = 0;
   $32 = (($25) + 32|0);
   HEAP8[$29>>0] = 1;
   HEAP32[$30>>2] = $28;
   HEAP32[$32>>2] = 4;
   $33 = (($25) + 36|0);
   $34 = (($25) + 68|0);
   $35 = (($25) + 72|0);
   $36 = (($25) + 76|0);
   HEAP32[$36>>2] = 0;
   $37 = (($25) + 80|0);
   HEAP8[$34>>0] = 1;
   HEAP32[$35>>2] = $33;
   HEAP32[$37>>2] = 4;
   $38 = (($25) + 84|0);
   HEAP32[$38>>2] = 0;
   $39 = (($25) + 88|0);
   HEAP32[$39>>2] = 0;
   $40 = (($25) + 220|0);
   dest=$40+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$40+48>>0]=0|0;
   $$0 = $25;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 2: case 1:  {
   $0 = (($this) + 2420|0);
   $1 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($0,128,16)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$1>>2] = (-1);
   $3 = (($1) + 56|0);
   HEAP32[$3>>2] = 0;
   $4 = (($1) + 60|0);
   HEAP16[$4>>1] = 0;
   $5 = (($1) + 92|0);
   ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
   $6 = (($1) + 116|0);
   HEAP8[$6>>0] = 0;
   $$0 = $1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 6:  {
   $57 = (($this) + 2420|0);
   $58 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($57,20,16)|0);
   $59 = ($58|0)==(0|0);
   if ($59) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $60 = (($58) + 16|0);
   HEAP16[$60>>1] = 0;
   $$0 = $58;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  default: {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  }
 } while(0);
 return 0|0;
}
function __ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($this,$size,$alignment) {
 $this = $this|0;
 $size = $size|0;
 $alignment = $alignment|0;
 var $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pad$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($5) + ($4<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + ($9)|0);
 $11 = $10;
 $12 = (($alignment) + -1)|0;
 $13 = (($12) + ($11))|0;
 $14 = (0 - ($alignment))|0;
 $15 = $13 & $14;
 $16 = (($15) - ($11))|0;
 $17 = (($9) + ($size))|0;
 $18 = (($17) + ($16))|0;
 $19 = (($this) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if (!($21)) {
  $44 = $9;$46 = $7;$pad$0 = $16;
  $$sum = (($44) + ($pad$0))|0;
  $45 = (($46) + ($$sum)|0);
  $47 = (($pad$0) + ($size))|0;
  $48 = (($47) + ($44))|0;
  HEAP32[$8>>2] = $48;
  STACKTOP = sp;return ($45|0);
 }
 $22 = (($4) + 1)|0;
 HEAP32[$3>>2] = $22;
 HEAP32[$8>>2] = 0;
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22>>>0)<($24>>>0);
 do {
  if (!($25)) {
   $26 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$20,446656,87)|0);
   HEAP32[$1>>2] = $26;
   $27 = (($this) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $28 & 2147483647;
   $30 = HEAP32[$23>>2]|0;
   $31 = ($29>>>0)>($30>>>0);
   if (!($31)) {
    (__ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($2,$1)|0);
    break;
   }
   $32 = HEAP32[$2>>2]|0;
   $33 = (($32) + ($30<<2)|0);
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    HEAP32[$33>>2] = $26;
   }
   $35 = (($30) + 1)|0;
   HEAP32[$23>>2] = $35;
  }
 } while(0);
 $36 = HEAP32[$3>>2]|0;
 $37 = HEAP32[$2>>2]|0;
 $38 = (($37) + ($36<<2)|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39;
 $41 = (($12) + ($40))|0;
 $42 = $41 & $14;
 $43 = (($42) - ($40))|0;
 $$pre = HEAP32[$8>>2]|0;
 $44 = $$pre;$46 = $39;$pad$0 = $43;
 $$sum = (($44) + ($pad$0))|0;
 $45 = (($46) + ($$sum)|0);
 $47 = (($pad$0) + ($size))|0;
 $48 = (($47) + ($44))|0;
 HEAP32[$8>>2] = $48;
 STACKTOP = sp;return ($45|0);
}
function __ZNK5physx3Scb5Scene17getBroadPhaseTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc5Scene17getBroadPhaseTypeEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Scb5Scene17getBroadPhaseCapsERNS_16PxBroadPhaseCapsE($this,$caps) {
 $this = $this|0;
 $caps = $caps|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc5Scene17getBroadPhaseCapsERNS_16PxBroadPhaseCapsE($0,$caps)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Scb5Scene22getNbBroadPhaseRegionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc5Scene22getNbBroadPhaseRegionsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx3Scb5Scene20getBroadPhaseRegionsEPNS_22PxBroadPhaseRegionInfoEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc5Scene20getBroadPhaseRegionsEPNS_22PxBroadPhaseRegionInfoEjj($0,$userBuffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx3Scb5Scene19addBroadPhaseRegionERKNS_18PxBroadPhaseRegionEb($this,$region,$populateRegion) {
 $this = $this|0;
 $region = $region|0;
 $populateRegion = $populateRegion|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2417|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 16|0);
  $4 = (__ZN5physx2Sc5Scene19addBroadPhaseRegionERKNS_18PxBroadPhaseRegionEb($3,$region,$populateRegion)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 } else {
  $5 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($5,2,445424,1469,445544,$vararg_buffer);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx3Scb5Scene22removeBroadPhaseRegionEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 2417|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 16|0);
  $4 = (__ZN5physx2Sc5Scene22removeBroadPhaseRegionEj($3,$handle)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 } else {
  $5 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($5,2,445424,1478,445640,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx3Scb12Articulation9syncStateEv($this) {
 $this = $this|0;
 var $$mask = 0, $$pre = 0, $$pre$phi1011Z2D = 0, $$pre$phi1012Z2D = 0, $$pre$phi10Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0;
 var $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 128;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 12|0);
  $5 = (Math_fround(__ZNK5physx2Sc16ArticulationCore14getWakeCounterEv($4)));
  $6 = (($this) + 48|0);
  HEAPF32[$6>>2] = $5;
  $$pre6 = $1 & 768;
  $$pre$phi10Z2D = $4;$$pre$phiZ2D = $$pre6;
  label = 5;
 } else {
  $7 = $1 & 768;
  $8 = ($7|0)==(0);
  $9 = (($this) + 12|0);
  if ($8) {
   $10 = (($this) + 48|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   __ZN5physx2Sc16ArticulationCore14setWakeCounterEf($9,$11);
   $12 = (__ZNK5physx2Sc16ArticulationCore10isSleepingEv($9)|0);
   $$pre$phi1012Z2D = $9;$18 = $12;
   label = 6;
  } else {
   $$pre$phi10Z2D = $9;$$pre$phiZ2D = $7;
   label = 5;
  }
 }
 do {
  if ((label|0) == 5) {
   $13 = (__ZNK5physx2Sc16ArticulationCore10isSleepingEv($$pre$phi10Z2D)|0);
   $14 = ($$pre$phiZ2D|0)==(0);
   if ($14) {
    $$pre$phi1012Z2D = $$pre$phi10Z2D;$18 = $13;
    label = 6;
   } else {
    $20 = $1 & 256;
    $21 = ($20|0)==(0);
    if ($21) {
     $22 = (($this) + 48|0);
     $23 = Math_fround(HEAPF32[$22>>2]);
     __ZN5physx2Sc16ArticulationCore6wakeUpEf($$pre$phi10Z2D,$23);
     $$pre$phi1011Z2D = $$pre$phi10Z2D;
     break;
    } else {
     __ZN5physx2Sc16ArticulationCore10putToSleepEv($$pre$phi10Z2D);
     $$pre$phi1011Z2D = $$pre$phi10Z2D;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $15 = HEAP32[$0>>2]|0;
  $$mask = $15 & -1073741824;
  $16 = ($$mask|0)==(-1073741824);
  if ($16) {
   $$pre$phi1011Z2D = $$pre$phi1012Z2D;
  } else {
   $17 = $18&1;
   $19 = (($this) + 52|0);
   HEAP8[$19>>0] = $17;
   $$pre$phi1011Z2D = $$pre$phi1012Z2D;
  }
 }
 $24 = $1 & 16776319;
 $25 = ($24|0)==(0);
 $$pre7 = (($this) + 8|0);
 if ($25) {
  HEAP32[$$pre7>>2] = 0;
  $68 = HEAP32[$0>>2]|0;
  $69 = $68 & -16777216;
  HEAP32[$0>>2] = $69;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$$pre7>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $28 = HEAP32[$this>>2]|0;
  $29 = HEAP32[$0>>2]|0;
  $30 = $29 >>> 24;
  $31 = $30 & 15;
  $32 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($28,$31)|0);
  HEAP32[$$pre7>>2] = $32;
  $37 = $32;
 } else {
  $37 = $26;
 }
 $33 = HEAP32[$0>>2]|0;
 $34 = $33 & 2;
 $35 = ($34|0)==(0);
 if ($35) {
  $40 = $33;
 } else {
  $36 = (($37) + 4|0);
  $38 = HEAP32[$36>>2]|0;
  __ZN5physx2Sc16ArticulationCore26setExternalDriveIterationsEj($$pre$phi1011Z2D,$38);
  $$pre = HEAP32[$0>>2]|0;
  $40 = $$pre;
 }
 $39 = $40 & 1;
 $41 = ($39|0)==(0);
 if ($41) {
  $44 = $40;
 } else {
  $42 = HEAP32[$37>>2]|0;
  __ZN5physx2Sc16ArticulationCore26setInternalDriveIterationsEj($$pre$phi1011Z2D,$42);
  $$pre1 = HEAP32[$0>>2]|0;
  $44 = $$pre1;
 }
 $43 = $44 & 4;
 $45 = ($43|0)==(0);
 if ($45) {
  $49 = $44;
 } else {
  $46 = (($37) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  __ZN5physx2Sc16ArticulationCore26setMaxProjectionIterationsEj($$pre$phi1011Z2D,$47);
  $$pre2 = HEAP32[$0>>2]|0;
  $49 = $$pre2;
 }
 $48 = $49 & 8;
 $50 = ($48|0)==(0);
 if ($50) {
  $54 = $49;
 } else {
  $51 = (($37) + 12|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  __ZN5physx2Sc16ArticulationCore22setSeparationToleranceEf($$pre$phi1011Z2D,$52);
  $$pre3 = HEAP32[$0>>2]|0;
  $54 = $$pre3;
 }
 $53 = $54 & 16;
 $55 = ($53|0)==(0);
 if ($55) {
  $59 = $54;
 } else {
  $56 = (($37) + 16|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  __ZN5physx2Sc16ArticulationCore17setSleepThresholdEf($$pre$phi1011Z2D,$57);
  $$pre4 = HEAP32[$0>>2]|0;
  $59 = $$pre4;
 }
 $58 = $59 & 32;
 $60 = ($58|0)==(0);
 if ($60) {
  $64 = $59;
 } else {
  $61 = (($37) + 20|0);
  $62 = HEAP16[$61>>1]|0;
  __ZN5physx2Sc16ArticulationCore24setSolverIterationCountsEt($$pre$phi1011Z2D,$62);
  $$pre5 = HEAP32[$0>>2]|0;
  $64 = $$pre5;
 }
 $63 = $64 & 64;
 $65 = ($63|0)==(0);
 if ($65) {
  HEAP32[$$pre7>>2] = 0;
  $68 = HEAP32[$0>>2]|0;
  $69 = $68 & -16777216;
  HEAP32[$0>>2] = $69;
  STACKTOP = sp;return;
 }
 $66 = (($37) + 24|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 __ZN5physx2Sc16ArticulationCore18setFreezeThresholdEf($$pre$phi1011Z2D,$67);
 HEAP32[$$pre7>>2] = 0;
 $68 = HEAP32[$0>>2]|0;
 $69 = $68 & -16777216;
 HEAP32[$0>>2] = $69;
 STACKTOP = sp;return;
}
function __ZN10ScSceneFnsIN5physx3Scb4BodyEE6removeERNS0_2Sc5SceneERS2_b($s,$v,$wakeOnLostTouch) {
 $s = $s|0;
 $v = $v|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i3$i = 0, $s$idx = 0, $s$idx$val = 0, $scShapes$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 816|0;
 $0 = sp + 544|0;
 $scShapes$i = sp;
 $1 = sp + 272|0;
 $2 = (($v) + 236|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & -6291457;
 HEAP32[$2>>2] = $4;
 $5 = $v;
 $6 = (($v) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 24;
 $9 = $8 & 15;
 $10 = ((444424 + ($9<<2)|0) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($5))|0;
 $13 = $12;
 $14 = (($13) + 8|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15 & 8;
 $17 = ($16<<16>>16)==(0);
 if (!($17)) {
  $s$idx = (($s) + 1244|0);
  $s$idx$val = HEAP32[$s$idx>>2]|0;
  __ZL22addOrRemoveRigidObjectILb0ELb0ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_b($s$idx$val,$v);
  STACKTOP = sp;return;
 }
 $18 = (($s) + 1244|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = (($19) + 272|0);
  $22 = (($0) + 256|0);
  HEAP8[$22>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$21);
  __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb1ELb0EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($s,$v,$0,$wakeOnLostTouch);
  $23 = (($0) + 268|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 & 2147483647;
  $26 = ($25|0)!=(0);
  $27 = ($24|0)>(-1);
  $or$cond$i$i$i1$i = $26 & $27;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $28 = (($0) + 260|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($0|0)==($29|0);
  if ($30) {
   HEAP8[$22>>0] = 0;
   STACKTOP = sp;return;
  }
  $31 = ($29|0)==(0|0);
  if ($31) {
   STACKTOP = sp;return;
  }
  $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 12|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vii[$35 & 4095]($32,$29);
  STACKTOP = sp;return;
 }
 $36 = (($scShapes$i) + 256|0);
 $37 = (($scShapes$i) + 260|0);
 $38 = (($scShapes$i) + 264|0);
 HEAP32[$38>>2] = 0;
 $39 = (($scShapes$i) + 268|0);
 HEAP8[$36>>0] = 1;
 HEAP32[$37>>2] = $scShapes$i;
 HEAP32[$39>>2] = 64;
 $40 = (($1) + 256|0);
 HEAP8[$40>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes$i);
 __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb1ELb0EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($s,$v,$1,$wakeOnLostTouch);
 $41 = (($1) + 268|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 & 2147483647;
 $44 = ($43|0)!=(0);
 $45 = ($42|0)>(-1);
 $or$cond$i$i$i3$i = $44 & $45;
 do {
  if ($or$cond$i$i$i3$i) {
   $46 = (($1) + 260|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($1|0)==($47|0);
   if ($48) {
    HEAP8[$40>>0] = 0;
    break;
   }
   $49 = ($47|0)==(0|0);
   if (!($49)) {
    $50 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) + 12|0);
    $53 = HEAP32[$52>>2]|0;
    FUNCTION_TABLE_vii[$53 & 4095]($50,$47);
   }
  }
 } while(0);
 $54 = HEAP32[$39>>2]|0;
 $55 = $54 & 2147483647;
 $56 = ($55|0)!=(0);
 $57 = ($54|0)>(-1);
 $or$cond$i$i$i$i = $56 & $57;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $58 = HEAP32[$37>>2]|0;
 $59 = ($scShapes$i|0)==($58|0);
 if ($59) {
  HEAP8[$36>>0] = 0;
  STACKTOP = sp;return;
 }
 $60 = ($58|0)==(0|0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $61 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + 12|0);
 $64 = HEAP32[$63>>2]|0;
 FUNCTION_TABLE_vii[$64 & 4095]($61,$58);
 STACKTOP = sp;return;
}
function __ZL22addOrRemoveRigidObjectILb0ELb0ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_b($s$0$52$val,$rigidObject) {
 $s$0$52$val = $s$0$52$val|0;
 $rigidObject = $rigidObject|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $or$cond$i$i$i3 = 0, $scShapes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 816|0;
 $0 = sp + 544|0;
 $scShapes = sp;
 $1 = sp + 272|0;
 $2 = ($s$0$52$val|0)==(0|0);
 if (!($2)) {
  $3 = (($s$0$52$val) + 272|0);
  $4 = (($0) + 256|0);
  HEAP8[$4>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$3);
  __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($rigidObject);
  $5 = (($0) + 268|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 & 2147483647;
  $8 = ($7|0)!=(0);
  $9 = ($6|0)>(-1);
  $or$cond$i$i$i1 = $8 & $9;
  if (!($or$cond$i$i$i1)) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 260|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($0|0)==($11|0);
  if ($12) {
   HEAP8[$4>>0] = 0;
   STACKTOP = sp;return;
  }
  $13 = ($11|0)==(0|0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 4095]($14,$11);
  STACKTOP = sp;return;
 }
 $18 = (($scShapes) + 256|0);
 $19 = (($scShapes) + 260|0);
 $20 = (($scShapes) + 264|0);
 HEAP32[$20>>2] = 0;
 $21 = (($scShapes) + 268|0);
 HEAP8[$18>>0] = 1;
 HEAP32[$19>>2] = $scShapes;
 HEAP32[$21>>2] = 64;
 $22 = (($1) + 256|0);
 HEAP8[$22>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes);
 __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($rigidObject);
 $23 = (($1) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 & 2147483647;
 $26 = ($25|0)!=(0);
 $27 = ($24|0)>(-1);
 $or$cond$i$i$i3 = $26 & $27;
 do {
  if ($or$cond$i$i$i3) {
   $28 = (($1) + 260|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($1|0)==($29|0);
   if ($30) {
    HEAP8[$22>>0] = 0;
    break;
   }
   $31 = ($29|0)==(0|0);
   if (!($31)) {
    $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    FUNCTION_TABLE_vii[$35 & 4095]($32,$29);
   }
  }
 } while(0);
 $36 = HEAP32[$21>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37|0)!=(0);
 $39 = ($36|0)>(-1);
 $or$cond$i$i$i = $38 & $39;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$19>>2]|0;
 $41 = ($scShapes|0)==($40|0);
 if ($41) {
  HEAP8[$18>>0] = 0;
  STACKTOP = sp;return;
 }
 $42 = ($40|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_vii[$46 & 4095]($43,$40);
 STACKTOP = sp;return;
}
function __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($rigidObject) {
 $rigidObject = $rigidObject|0;
 var $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $shapes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $shapes = sp;
 $1 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $2 = (($rigidObject) + 16|0);
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($2)|0);
 $3 = (($1) + -16)|0;
 $4 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($rigidObject,$shapes)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$rigidObject>>2]|0;
 $$sum = (($1) + -12)|0;
 $7 = (($6) + 2448|0);
 $i$01 = 0;
 while(1) {
  $8 = HEAP32[$shapes>>2]|0;
  $9 = (($8) + ($i$01<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($3)|0);
  $12 = (($10) + ($$sum)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 & 268435456;
  $15 = ($14|0)==(0);
  if ($15) {
   $17 = $13;
  } else {
   __ZN5physx3Scb5Shape9syncStateEv($11);
   HEAP32[$0>>2] = $11;
   (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($7,$0)|0);
   $$pre = HEAP32[$12>>2]|0;
   $17 = $$pre;
  }
  $16 = $17 & 251658240;
  $18 = ($16|0)==(16777216);
  if ($18) {
   $19 = $17 & 1073741823;
   HEAP32[$12>>2] = $19;
   HEAP32[$11>>2] = 0;
  }
  $20 = (($i$01) + 1)|0;
  $exitcond = ($20|0)==($4|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $20;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $32 = (($this) + 260|0);
  HEAP32[$32>>2] = 0;
  $33 = (($this) + 264|0);
  HEAP32[$33>>2] = 0;
  $34 = (($this) + 268|0);
  HEAP32[$34>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 268|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 264|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = (($this) + 256|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = ($5>>>0)<(257);
 $or$cond$i$i = $8 & $9;
 if ($or$cond$i$i) {
  HEAP8[$6>>0] = 1;
  $$0$i$i = $this;$23 = $1;
 } else {
  $10 = ($5|0)==(0);
  if ($10) {
   $$0$i$i = 0;$23 = $1;
  } else {
   $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__Z15PxGetFoundationv()|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
   $$$i$i$i$i = $19 ? 445856 : 445824;
   $20 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,$5,$$$i$i$i$i,445744,558)|0);
   $$pre = HEAP32[$4>>2]|0;
   $$0$i$i = $20;$23 = $$pre;
  }
 }
 $21 = (($this) + 260|0);
 HEAP32[$21>>2] = $$0$i$i;
 $22 = (($$0$i$i) + ($23<<2)|0);
 $24 = ($$0$i$i>>>0)<($22>>>0);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 $25 = (($other) + 260|0);
 $26 = HEAP32[$25>>2]|0;
 $$012$i = $$0$i$i;$$03$i = $26;
 while(1) {
  $27 = ($$012$i|0)==(0|0);
  if (!($27)) {
   $28 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $28;
  }
  $29 = (($$012$i) + 4|0);
  $30 = (($$03$i) + 4|0);
  $31 = ($29>>>0)<($22>>>0);
  if ($31) {
   $$012$i = $29;$$03$i = $30;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb1ELb0EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($s,$rigidObject,$scShapes,$wakeOnLostTouch) {
 $s = $s|0;
 $rigidObject = $rigidObject|0;
 $scShapes = $scShapes|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($rigidObject) + 16|0);
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($1)|0);
 __ZN5physx2Sc5Scene10removeBodyERNS0_8BodyCoreERNS_6shdfnd11InlineArrayIPKNS0_9ShapeCoreELj64ENS4_19ReflectionAllocatorIS8_EEEEb($s,$1,$scShapes,$wakeOnLostTouch);
 $2 = (($scShapes) + 260|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($scShapes) + 264|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$rigidObject>>2]|0;
 $8 = (($7) + 2448|0);
 $i$01 = 0;
 while(1) {
  $9 = (($3) + ($i$01<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + -16|0);
  $12 = (($11) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 & 268435456;
  $15 = ($14|0)==(0);
  if ($15) {
   $17 = $13;
  } else {
   __ZN5physx3Scb5Shape9syncStateEv($11);
   HEAP32[$0>>2] = $11;
   (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($8,$0)|0);
   $$pre = HEAP32[$12>>2]|0;
   $17 = $$pre;
  }
  $16 = $17 & 251658240;
  $18 = ($16|0)==(16777216);
  if ($18) {
   $19 = $17 & 1073741823;
   HEAP32[$12>>2] = $19;
   HEAP32[$11>>2] = 0;
  }
  __ZN5physx18NpShapeDecRefCountERNS_3Scb5ShapeE($11);
  $20 = (($i$01) + 1)|0;
  $exitcond = ($20|0)==($5|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $20;
  }
 }
 STACKTOP = sp;return;
}
function __ZN10ScSceneFnsIN5physx3Scb11RigidStaticEE6removeERNS0_2Sc5SceneERS2_b($s,$v,$wakeOnLostTouch) {
 $s = $s|0;
 $v = $v|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i3$i = 0, $s$idx = 0, $s$idx$val = 0, $scShapes$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 816|0;
 $0 = sp + 544|0;
 $scShapes$i = sp;
 $1 = sp + 272|0;
 $2 = $v;
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 >>> 24;
 $6 = $5 & 15;
 $7 = ((444424 + ($6<<2)|0) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($2))|0;
 $10 = $9;
 $11 = (($10) + 8|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12 & 8;
 $14 = ($13<<16>>16)==(0);
 if (!($14)) {
  $s$idx = (($s) + 1244|0);
  $s$idx$val = HEAP32[$s$idx>>2]|0;
  __ZL22addOrRemoveRigidObjectILb0ELb0ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_b($s$idx$val,$v);
  STACKTOP = sp;return;
 }
 $15 = (($s) + 1244|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = (($16) + 272|0);
  $19 = (($0) + 256|0);
  HEAP8[$19>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$18);
  __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb0ELb0EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($s,$v,$0,$wakeOnLostTouch);
  $20 = (($0) + 268|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 2147483647;
  $23 = ($22|0)!=(0);
  $24 = ($21|0)>(-1);
  $or$cond$i$i$i1$i = $23 & $24;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $25 = (($0) + 260|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($0|0)==($26|0);
  if ($27) {
   HEAP8[$19>>0] = 0;
   STACKTOP = sp;return;
  }
  $28 = ($26|0)==(0|0);
  if ($28) {
   STACKTOP = sp;return;
  }
  $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 12|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vii[$32 & 4095]($29,$26);
  STACKTOP = sp;return;
 }
 $33 = (($scShapes$i) + 256|0);
 $34 = (($scShapes$i) + 260|0);
 $35 = (($scShapes$i) + 264|0);
 HEAP32[$35>>2] = 0;
 $36 = (($scShapes$i) + 268|0);
 HEAP8[$33>>0] = 1;
 HEAP32[$34>>2] = $scShapes$i;
 HEAP32[$36>>2] = 64;
 $37 = (($1) + 256|0);
 HEAP8[$37>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes$i);
 __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb0ELb0EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($s,$v,$1,$wakeOnLostTouch);
 $38 = (($1) + 268|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39 & 2147483647;
 $41 = ($40|0)!=(0);
 $42 = ($39|0)>(-1);
 $or$cond$i$i$i3$i = $41 & $42;
 do {
  if ($or$cond$i$i$i3$i) {
   $43 = (($1) + 260|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($1|0)==($44|0);
   if ($45) {
    HEAP8[$37>>0] = 0;
    break;
   }
   $46 = ($44|0)==(0|0);
   if (!($46)) {
    $47 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    FUNCTION_TABLE_vii[$50 & 4095]($47,$44);
   }
  }
 } while(0);
 $51 = HEAP32[$36>>2]|0;
 $52 = $51 & 2147483647;
 $53 = ($52|0)!=(0);
 $54 = ($51|0)>(-1);
 $or$cond$i$i$i$i = $53 & $54;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $55 = HEAP32[$34>>2]|0;
 $56 = ($scShapes$i|0)==($55|0);
 if ($56) {
  HEAP8[$33>>0] = 0;
  STACKTOP = sp;return;
 }
 $57 = ($55|0)==(0|0);
 if ($57) {
  STACKTOP = sp;return;
 }
 $58 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 FUNCTION_TABLE_vii[$61 & 4095]($58,$55);
 STACKTOP = sp;return;
}
function __ZL22addOrRemoveRigidObjectILb0ELb0ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_b($s$0$52$val,$rigidObject) {
 $s$0$52$val = $s$0$52$val|0;
 $rigidObject = $rigidObject|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $or$cond$i$i$i3 = 0, $scShapes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 816|0;
 $0 = sp + 544|0;
 $scShapes = sp;
 $1 = sp + 272|0;
 $2 = ($s$0$52$val|0)==(0|0);
 if (!($2)) {
  $3 = (($s$0$52$val) + 272|0);
  $4 = (($0) + 256|0);
  HEAP8[$4>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$3);
  __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($rigidObject);
  $5 = (($0) + 268|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 & 2147483647;
  $8 = ($7|0)!=(0);
  $9 = ($6|0)>(-1);
  $or$cond$i$i$i1 = $8 & $9;
  if (!($or$cond$i$i$i1)) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 260|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($0|0)==($11|0);
  if ($12) {
   HEAP8[$4>>0] = 0;
   STACKTOP = sp;return;
  }
  $13 = ($11|0)==(0|0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 4095]($14,$11);
  STACKTOP = sp;return;
 }
 $18 = (($scShapes) + 256|0);
 $19 = (($scShapes) + 260|0);
 $20 = (($scShapes) + 264|0);
 HEAP32[$20>>2] = 0;
 $21 = (($scShapes) + 268|0);
 HEAP8[$18>>0] = 1;
 HEAP32[$19>>2] = $scShapes;
 HEAP32[$21>>2] = 64;
 $22 = (($1) + 256|0);
 HEAP8[$22>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes);
 __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($rigidObject);
 $23 = (($1) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 & 2147483647;
 $26 = ($25|0)!=(0);
 $27 = ($24|0)>(-1);
 $or$cond$i$i$i3 = $26 & $27;
 do {
  if ($or$cond$i$i$i3) {
   $28 = (($1) + 260|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($1|0)==($29|0);
   if ($30) {
    HEAP8[$22>>0] = 0;
    break;
   }
   $31 = ($29|0)==(0|0);
   if (!($31)) {
    $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    FUNCTION_TABLE_vii[$35 & 4095]($32,$29);
   }
  }
 } while(0);
 $36 = HEAP32[$21>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37|0)!=(0);
 $39 = ($36|0)>(-1);
 $or$cond$i$i$i = $38 & $39;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$19>>2]|0;
 $41 = ($scShapes|0)==($40|0);
 if ($41) {
  HEAP8[$18>>0] = 0;
  STACKTOP = sp;return;
 }
 $42 = ($40|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_vii[$46 & 4095]($43,$40);
 STACKTOP = sp;return;
}
function __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($rigidObject) {
 $rigidObject = $rigidObject|0;
 var $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $shapes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $shapes = sp;
 $1 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $2 = (($rigidObject) + 16|0);
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($2)|0);
 $3 = (($1) + -16)|0;
 $4 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($rigidObject,$shapes)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$rigidObject>>2]|0;
 $$sum = (($1) + -12)|0;
 $7 = (($6) + 2448|0);
 $i$01 = 0;
 while(1) {
  $8 = HEAP32[$shapes>>2]|0;
  $9 = (($8) + ($i$01<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($3)|0);
  $12 = (($10) + ($$sum)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 & 268435456;
  $15 = ($14|0)==(0);
  if ($15) {
   $17 = $13;
  } else {
   __ZN5physx3Scb5Shape9syncStateEv($11);
   HEAP32[$0>>2] = $11;
   (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($7,$0)|0);
   $$pre = HEAP32[$12>>2]|0;
   $17 = $$pre;
  }
  $16 = $17 & 251658240;
  $18 = ($16|0)==(16777216);
  if ($18) {
   $19 = $17 & 1073741823;
   HEAP32[$12>>2] = $19;
   HEAP32[$11>>2] = 0;
  }
  $20 = (($i$01) + 1)|0;
  $exitcond = ($20|0)==($4|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $20;
  }
 }
 STACKTOP = sp;return;
}
function __ZL30addOrRemoveRigidObjectInternalILb0ELb0ELb0ELb0EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_NS0_6shdfnd11InlineArrayIPKNS3_9ShapeCoreELj64ENS8_19ReflectionAllocatorISC_EEEEb($s,$rigidObject,$scShapes,$wakeOnLostTouch) {
 $s = $s|0;
 $rigidObject = $rigidObject|0;
 $scShapes = $scShapes|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($rigidObject) + 16|0);
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($1)|0);
 __ZN5physx2Sc5Scene12removeStaticERNS0_10StaticCoreERNS_6shdfnd11InlineArrayIPKNS0_9ShapeCoreELj64ENS4_19ReflectionAllocatorIS8_EEEEb($s,$1,$scShapes,$wakeOnLostTouch);
 $2 = (($scShapes) + 260|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($scShapes) + 264|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$rigidObject>>2]|0;
 $8 = (($7) + 2448|0);
 $i$01 = 0;
 while(1) {
  $9 = (($3) + ($i$01<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + -16|0);
  $12 = (($11) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 & 268435456;
  $15 = ($14|0)==(0);
  if ($15) {
   $17 = $13;
  } else {
   __ZN5physx3Scb5Shape9syncStateEv($11);
   HEAP32[$0>>2] = $11;
   (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($8,$0)|0);
   $$pre = HEAP32[$12>>2]|0;
   $17 = $$pre;
  }
  $16 = $17 & 251658240;
  $18 = ($16|0)==(16777216);
  if ($18) {
   $19 = $17 & 1073741823;
   HEAP32[$12>>2] = $19;
   HEAP32[$11>>2] = 0;
  }
  __ZN5physx18NpShapeDecRefCountERNS_3Scb5ShapeE($11);
  $20 = (($i$01) + 1)|0;
  $exitcond = ($20|0)==($5|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $20;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx3Scb10Constraint9syncStateEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = (($this) + 80|0);
 $3 = (($this) + 92|0);
 __ZNK5physx2Sc14ConstraintCore8getForceERNS_6PxVec3ES3_($1,$2,$3);
 $4 = HEAP16[$1>>1]|0;
 $5 = $4&65535;
 $6 = $5 & 1;
 $7 = $6&65535;
 $8 = (($this) + 104|0);
 HEAP16[$8>>1] = $7;
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 16777215;
 $12 = ($11|0)==(0);
 $$pre = (($this) + 8|0);
 if ($12) {
  HEAP32[$$pre>>2] = 0;
  $37 = HEAP32[$9>>2]|0;
  $38 = $37 & -16777216;
  HEAP32[$9>>2] = $38;
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$$pre>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = HEAP32[$this>>2]|0;
  $16 = $10 >>> 24;
  $17 = $16 & 15;
  $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($15,$17)|0);
  HEAP32[$$pre>>2] = $18;
  $22 = $18;
 } else {
  $22 = $13;
 }
 $19 = $10 & 1;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = HEAP32[$22>>2]|0;
  $23 = (($22) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  __ZN5physx2Sc14ConstraintCore9setBodiesEPNS0_9RigidCoreES3_($1,$21,$24);
 }
 $25 = $10 & 2;
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = (($22) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($22) + 12|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  __ZN5physx2Sc14ConstraintCore13setBreakForceEff($1,$28,$30);
 }
 $31 = $10 & 4;
 $32 = ($31|0)==(0);
 if ($32) {
  HEAP32[$$pre>>2] = 0;
  $37 = HEAP32[$9>>2]|0;
  $38 = $37 & -16777216;
  HEAP32[$9>>2] = $38;
  STACKTOP = sp;return;
 }
 $33 = (($22) + 16|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = HEAP16[$8>>1]|0;
 $36 = $35 | $34;
 HEAP16[$0>>1] = $36;
 __ZN5physx2Sc14ConstraintCore8setFlagsENS_7PxFlagsINS_16PxConstraintFlag4EnumEtEE($1,$0);
 HEAP32[$$pre>>2] = 0;
 $37 = HEAP32[$9>>2]|0;
 $38 = $37 & -16777216;
 HEAP32[$9>>2] = $38;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb11RigidObject19processShapeRemovesEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 8;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $9 = $2 >>> 24;
  $10 = $9 & 15;
  $11 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($8,$10)|0);
  HEAP32[$5>>2] = $11;
  $$pre = HEAP32[$1>>2]|0;
  $14 = $$pre;$21 = $11;
 } else {
  $14 = $2;$21 = $6;
 }
 $12 = $this;
 $13 = $14 >>> 24;
 $15 = $13 & 15;
 $16 = ((444424 + ($15<<2)|0) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($12))|0;
 $19 = $18;
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($19)|0);
 $20 = (($21) + 36|0);
 $22 = (($21) + 76|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = (($21) + 72|0);
  $i$02 = 0;
  while(1) {
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + ($i$02<<3)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $30 & 251658240;
   $32 = ($31|0)==(16777216);
   if ($32) {
    $33 = $30 & 1073741823;
    HEAP32[$29>>2] = $33;
    HEAP32[$28>>2] = 0;
   }
   $34 = HEAP32[$1>>2]|0;
   $35 = $34 >>> 24;
   $36 = $35 & 15;
   $37 = ((444424 + ($36<<2)|0) + 24|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + ($12))|0;
   $40 = $39;
   $41 = HEAP32[$this>>2]|0;
   $42 = (($40) + 8|0);
   $43 = HEAP16[$42>>1]|0;
   $44 = $43 & 8;
   $45 = ($44<<16>>16)==(0);
   if ($45) {
    $46 = (($28) + 16|0);
    $47 = ((($26) + ($i$02<<3)|0) + 4|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = ($48<<24>>24)!=(0);
    __ZN5physx2Sc9RigidCore20removeShapeFromSceneERNS0_9ShapeCoreEb($40,$46,$49);
    $50 = HEAP32[$29>>2]|0;
    $51 = $50 & 268435456;
    $52 = ($51|0)==(0);
    if (!($52)) {
     __ZN5physx3Scb5Shape9syncStateEv($28);
     HEAP32[$0>>2] = $28;
     $53 = (($41) + 2448|0);
     (__ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($53,$0)|0);
    }
    __ZN5physx18NpShapeDecRefCountERNS_3Scb5ShapeE($28);
   }
   $54 = (($i$02) + 1)|0;
   $55 = HEAP32[$22>>2]|0;
   $56 = ($54>>>0)<($55>>>0);
   if ($56) {
    $i$02 = $54;
   } else {
    break;
   }
  }
 }
 HEAP32[$0>>2] = 0;
 $57 = (($0) + 4|0);
 HEAP8[$57>>0] = 0;
 __ZN5physx6shdfnd5ArrayINS_3Scb12RemovedShapeENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS3_EEEEE6resizeEjRKS3_($20,0,$0);
 $58 = HEAP32[$22>>2]|0;
 __ZN5physx6shdfnd5ArrayINS_3Scb12RemovedShapeENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS3_EEEEE8recreateEj($20,$58);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_3Scb12RemovedShapeENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS3_EEEEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_3Scb12RemovedShapeENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS3_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($size<<3)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + ($7<<3)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   $12 = $a;
   $13 = $12;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($12) + 4)|0;
   $16 = $15;
   $17 = HEAP32[$16>>2]|0;
   $18 = $$01$i;
   $19 = $18;
   HEAP32[$19>>2] = $14;
   $20 = (($18) + 4)|0;
   $21 = $20;
   HEAP32[$21>>2] = $17;
  }
  $22 = (($$01$i) + 8|0);
  $23 = ($22>>>0)<($8>>>0);
  if ($23) {
   $$01$i = $22;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_3Scb12RemovedShapeENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS3_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = (($this) + 32|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(33);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 445992 : 445824;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,445744,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<3)|0);
 $21 = (($this) + 36|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($19>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
 }
 $38 = (($this) + 44|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)>(-1);
 if (!($40)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$38>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $41 = HEAP32[$21>>2]|0;
 $42 = ($this|0)==($41|0);
 if ($42) {
  $43 = (($this) + 32|0);
  HEAP8[$43>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$38>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $44 = ($41|0)==(0|0);
 if ($44) {
  HEAP32[$21>>2] = $20;
  HEAP32[$38>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $45 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46) + 12|0);
 $48 = HEAP32[$47>>2]|0;
 FUNCTION_TABLE_vii[$48 & 4095]($45,$41);
 HEAP32[$21>>2] = $20;
 HEAP32[$38>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb17ArticulationJoint9syncStateEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre1 = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0);
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16777215;
 $3 = ($2|0)==(0);
 $$pre17 = (($this) + 8|0);
 if ($3) {
  $109 = $1;
  HEAP32[$$pre17>>2] = 0;
  $108 = $109 & -16777216;
  HEAP32[$0>>2] = $108;
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$$pre17>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  $7 = $1 >>> 24;
  $8 = $7 & 15;
  $9 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($6,$8)|0);
  HEAP32[$$pre17>>2] = $9;
  $$pre1 = HEAP32[$0>>2]|0;
  $11 = $$pre1;$14 = $9;
 } else {
  $11 = $1;$14 = $4;
 }
 $10 = $11 & 1;
 $12 = ($10|0)==(0);
 if ($12) {
  $16 = $11;
 } else {
  $13 = (($this) + 12|0);
  __ZN5physx2Sc21ArticulationJointCore13setParentPoseERKNS_11PxTransformE($13,$14);
  $$pre2 = HEAP32[$0>>2]|0;
  $16 = $$pre2;
 }
 $15 = $16 & 2;
 $17 = ($15|0)==(0);
 if ($17) {
  $21 = $16;
 } else {
  $18 = (($this) + 12|0);
  $19 = (($14) + 28|0);
  __ZN5physx2Sc21ArticulationJointCore12setChildPoseERKNS_11PxTransformE($18,$19);
  $$pre3 = HEAP32[$0>>2]|0;
  $21 = $$pre3;
 }
 $20 = $21 & 4;
 $22 = ($20|0)==(0);
 if ($22) {
  $26 = $21;
 } else {
  $23 = (($this) + 12|0);
  $24 = (($14) + 56|0);
  __ZN5physx2Sc21ArticulationJointCore20setTargetOrientationERKNS_6PxQuatE($23,$24);
  $$pre4 = HEAP32[$0>>2]|0;
  $26 = $$pre4;
 }
 $25 = $26 & 8;
 $27 = ($25|0)==(0);
 if ($27) {
  $31 = $26;
 } else {
  $28 = (($this) + 12|0);
  $29 = (($14) + 72|0);
  __ZN5physx2Sc21ArticulationJointCore17setTargetVelocityERKNS_6PxVec3E($28,$29);
  $$pre5 = HEAP32[$0>>2]|0;
  $31 = $$pre5;
 }
 $30 = $31 & 16;
 $32 = ($30|0)==(0);
 if ($32) {
  $37 = $31;
 } else {
  $33 = (($this) + 12|0);
  $34 = (($14) + 84|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  __ZN5physx2Sc21ArticulationJointCore12setStiffnessEf($33,$35);
  $$pre6 = HEAP32[$0>>2]|0;
  $37 = $$pre6;
 }
 $36 = $37 & 32;
 $38 = ($36|0)==(0);
 if ($38) {
  $43 = $37;
 } else {
  $39 = (($this) + 12|0);
  $40 = (($14) + 88|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  __ZN5physx2Sc21ArticulationJointCore10setDampingEf($39,$41);
  $$pre7 = HEAP32[$0>>2]|0;
  $43 = $$pre7;
 }
 $42 = $43 & 64;
 $44 = ($42|0)==(0);
 if ($44) {
  $49 = $43;
 } else {
  $45 = (($this) + 12|0);
  $46 = (($14) + 92|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  __ZN5physx2Sc21ArticulationJointCore21setInternalComplianceEf($45,$47);
  $$pre8 = HEAP32[$0>>2]|0;
  $49 = $$pre8;
 }
 $48 = $49 & 128;
 $50 = ($48|0)==(0);
 if ($50) {
  $55 = $49;
 } else {
  $51 = (($this) + 12|0);
  $52 = (($14) + 96|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  __ZN5physx2Sc21ArticulationJointCore21setExternalComplianceEf($51,$53);
  $$pre9 = HEAP32[$0>>2]|0;
  $55 = $$pre9;
 }
 $54 = $55 & 256;
 $56 = ($54|0)==(0);
 if ($56) {
  $61 = $55;
 } else {
  $57 = (($this) + 12|0);
  $58 = (($14) + 100|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  __ZN5physx2Sc21ArticulationJointCore28setSwingLimitContactDistanceEf($57,$59);
  $$pre10 = HEAP32[$0>>2]|0;
  $61 = $$pre10;
 }
 $60 = $61 & 512;
 $62 = ($60|0)==(0);
 if ($62) {
  $68 = $61;
 } else {
  $63 = (($this) + 12|0);
  $64 = (($14) + 104|0);
  $65 = HEAP8[$64>>0]|0;
  $66 = ($65<<24>>24)!=(0);
  __ZN5physx2Sc21ArticulationJointCore20setSwingLimitEnabledEb($63,$66);
  $$pre11 = HEAP32[$0>>2]|0;
  $68 = $$pre11;
 }
 $67 = $68 & 4096;
 $69 = ($67|0)==(0);
 if ($69) {
  $74 = $68;
 } else {
  $70 = (($this) + 12|0);
  $71 = (($14) + 116|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  __ZN5physx2Sc21ArticulationJointCore28setTwistLimitContactDistanceEf($70,$72);
  $$pre12 = HEAP32[$0>>2]|0;
  $74 = $$pre12;
 }
 $73 = $74 & 8192;
 $75 = ($73|0)==(0);
 if ($75) {
  $81 = $74;
 } else {
  $76 = (($this) + 12|0);
  $77 = (($14) + 120|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = ($78<<24>>24)!=(0);
  __ZN5physx2Sc21ArticulationJointCore20setTwistLimitEnabledEb($76,$79);
  $$pre13 = HEAP32[$0>>2]|0;
  $81 = $$pre13;
 }
 $80 = $81 & 1024;
 $82 = ($80|0)==(0);
 if ($82) {
  $87 = $81;
 } else {
  $83 = (($this) + 12|0);
  $84 = (($14) + 108|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  __ZN5physx2Sc21ArticulationJointCore22setTangentialStiffnessEf($83,$85);
  $$pre14 = HEAP32[$0>>2]|0;
  $87 = $$pre14;
 }
 $86 = $87 & 2048;
 $88 = ($86|0)==(0);
 if ($88) {
  $93 = $87;
 } else {
  $89 = (($this) + 12|0);
  $90 = (($14) + 112|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  __ZN5physx2Sc21ArticulationJointCore20setTangentialDampingEf($89,$91);
  $$pre15 = HEAP32[$0>>2]|0;
  $93 = $$pre15;
 }
 $92 = $93 & 16384;
 $94 = ($92|0)==(0);
 if ($94) {
  $101 = $93;
 } else {
  $95 = (($this) + 12|0);
  $96 = (($14) + 124|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = (($14) + 128|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  __ZN5physx2Sc21ArticulationJointCore13setSwingLimitEff($95,$97,$99);
  $$pre16 = HEAP32[$0>>2]|0;
  $101 = $$pre16;
 }
 $100 = $101 & 32768;
 $102 = ($100|0)==(0);
 if ($102) {
  $109 = $101;
  HEAP32[$$pre17>>2] = 0;
  $108 = $109 & -16777216;
  HEAP32[$0>>2] = $108;
  STACKTOP = sp;return;
 }
 $103 = (($this) + 12|0);
 $104 = (($14) + 132|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($14) + 136|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 __ZN5physx2Sc21ArticulationJointCore13setTwistLimitEff($103,$105,$107);
 $$pre = HEAP32[$0>>2]|0;
 $109 = $$pre;
 HEAP32[$$pre17>>2] = 0;
 $108 = $109 & -16777216;
 HEAP32[$0>>2] = $108;
 STACKTOP = sp;return;
}
function __ZN10ScSceneFnsIN5physx3Scb4BodyEE6insertERNS0_2Sc5SceneERS2_($s,$v) {
 $s = $s|0;
 $v = $v|0;
 var $$in = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i7$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i10$i = 0, $s$idx = 0, $s$idx$val = 0;
 var $scShapes$i = 0, $shapes$i3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $shapes$i3$i = sp + 816|0;
 $0 = sp;
 $scShapes$i = sp + 272|0;
 $1 = sp + 544|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = ((444424 + ($14<<2)|0) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $v;
  $18 = (($16) + ($17))|0;
  $19 = $18;
  $20 = (($19) + 8|0);
  $$in = $20;
 } else {
  $6 = (($v) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $9 = HEAP32[$v>>2]|0;
   $10 = $3 >>> 24;
   $11 = $10 & 15;
   $12 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($9,$11)|0);
   HEAP32[$6>>2] = $12;
   $107 = $12;
  } else {
   $107 = $7;
  }
  $$in = $107;
 }
 $21 = HEAP16[$$in>>1]|0;
 $22 = $21 & 8;
 $23 = ($22<<16>>16)==(0);
 if (!($23)) {
  $s$idx = (($s) + 1244|0);
  $s$idx$val = HEAP32[$s$idx>>2]|0;
  __ZL22addOrRemoveRigidObjectILb0ELb1ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_b($s$idx$val,$v);
  STACKTOP = sp;return;
 }
 $24 = (($s) + 1244|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (($25) + 272|0);
  $28 = (($0) + 256|0);
  HEAP8[$28>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$27);
  $29 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $30 = (($v) + 16|0);
  (__ZNK5physx2Sc9RigidCore10getPxActorEv($30)|0);
  $31 = (($29) + -16)|0;
  $32 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($v,$shapes$i3$i)|0);
  $33 = HEAP32[$shapes$i3$i>>2]|0;
  __ZN5physx2Sc5Scene7addBodyERNS0_8BodyCoreEPKPvjj($s,$30,$33,$32,$29);
  $34 = HEAP32[$v>>2]|0;
  $35 = ($32|0)==(0);
  if (!($35)) {
   $$sum$i$i = (($29) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $36 = HEAP32[$shapes$i3$i>>2]|0;
    $37 = (($36) + ($i$01$i$i<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + ($31)|0);
    $40 = (($38) + ($$sum$i$i)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $41 & 251658240;
    $43 = ($42|0)==(16777216);
    if ($43) {
     $44 = $41 & 1073741823;
     $45 = $44 | -2147483648;
     HEAP32[$40>>2] = $45;
     HEAP32[$39>>2] = $34;
    }
    __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($39);
    $46 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($46|0)==($32|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $46;
    }
   }
  }
  $47 = (($0) + 268|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = $48 & 2147483647;
  $50 = ($49|0)!=(0);
  $51 = ($48|0)>(-1);
  $or$cond$i$i$i1$i = $50 & $51;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $52 = (($0) + 260|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($0|0)==($53|0);
  if ($54) {
   HEAP8[$28>>0] = 0;
   STACKTOP = sp;return;
  }
  $55 = ($53|0)==(0|0);
  if ($55) {
   STACKTOP = sp;return;
  }
  $56 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($57) + 12|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vii[$59 & 4095]($56,$53);
  STACKTOP = sp;return;
 }
 $60 = (($scShapes$i) + 256|0);
 $61 = (($scShapes$i) + 260|0);
 $62 = (($scShapes$i) + 264|0);
 HEAP32[$62>>2] = 0;
 $63 = (($scShapes$i) + 268|0);
 HEAP8[$60>>0] = 1;
 HEAP32[$61>>2] = $scShapes$i;
 HEAP32[$63>>2] = 64;
 $64 = (($1) + 256|0);
 HEAP8[$64>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes$i);
 $65 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $66 = (($v) + 16|0);
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($66)|0);
 $67 = (($65) + -16)|0;
 $68 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($v,$shapes$i3$i)|0);
 $69 = HEAP32[$shapes$i3$i>>2]|0;
 __ZN5physx2Sc5Scene7addBodyERNS0_8BodyCoreEPKPvjj($s,$66,$69,$68,$65);
 $70 = HEAP32[$v>>2]|0;
 $71 = ($68|0)==(0);
 if (!($71)) {
  $$sum$i4$i = (($65) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $72 = HEAP32[$shapes$i3$i>>2]|0;
   $73 = (($72) + ($i$01$i6$i<<2)|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + ($67)|0);
   $76 = (($74) + ($$sum$i4$i)|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = $77 & 251658240;
   $79 = ($78|0)==(16777216);
   if ($79) {
    $80 = $77 & 1073741823;
    $81 = $80 | -2147483648;
    HEAP32[$76>>2] = $81;
    HEAP32[$75>>2] = $70;
   }
   __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($75);
   $82 = (($i$01$i6$i) + 1)|0;
   $exitcond$i7$i = ($82|0)==($68|0);
   if ($exitcond$i7$i) {
    break;
   } else {
    $i$01$i6$i = $82;
   }
  }
 }
 $83 = (($1) + 268|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = $84 & 2147483647;
 $86 = ($85|0)!=(0);
 $87 = ($84|0)>(-1);
 $or$cond$i$i$i10$i = $86 & $87;
 do {
  if ($or$cond$i$i$i10$i) {
   $88 = (($1) + 260|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($1|0)==($89|0);
   if ($90) {
    HEAP8[$64>>0] = 0;
    break;
   }
   $91 = ($89|0)==(0|0);
   if (!($91)) {
    $92 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($93) + 12|0);
    $95 = HEAP32[$94>>2]|0;
    FUNCTION_TABLE_vii[$95 & 4095]($92,$89);
   }
  }
 } while(0);
 $96 = HEAP32[$63>>2]|0;
 $97 = $96 & 2147483647;
 $98 = ($97|0)!=(0);
 $99 = ($96|0)>(-1);
 $or$cond$i$i$i$i = $98 & $99;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $100 = HEAP32[$61>>2]|0;
 $101 = ($scShapes$i|0)==($100|0);
 if ($101) {
  HEAP8[$60>>0] = 0;
  STACKTOP = sp;return;
 }
 $102 = ($100|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$100);
 STACKTOP = sp;return;
}
function __ZL22addOrRemoveRigidObjectILb0ELb1ELb1ELb1EN5physx3Scb4BodyEEvRNS0_2Sc5SceneERT3_b($s$0$52$val,$rigidObject) {
 $s$0$52$val = $s$0$52$val|0;
 $rigidObject = $rigidObject|0;
 var $$sum$i = 0, $$sum$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i8 = 0, $i$01$i = 0, $i$01$i6 = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $or$cond$i$i$i11 = 0, $scShapes = 0, $shapes$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $shapes$i3 = sp + 816|0;
 $0 = sp;
 $scShapes = sp + 272|0;
 $1 = sp + 544|0;
 $2 = ($s$0$52$val|0)==(0|0);
 if (!($2)) {
  $3 = (($s$0$52$val) + 272|0);
  $4 = (($0) + 256|0);
  HEAP8[$4>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$3);
  $5 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $6 = (($rigidObject) + 16|0);
  (__ZNK5physx2Sc9RigidCore10getPxActorEv($6)|0);
  $7 = (($5) + -16)|0;
  $8 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($rigidObject,$shapes$i3)|0);
  $9 = HEAP32[$rigidObject>>2]|0;
  $10 = ($8|0)==(0);
  if (!($10)) {
   $$sum$i = (($5) + -12)|0;
   $i$01$i = 0;
   while(1) {
    $11 = HEAP32[$shapes$i3>>2]|0;
    $12 = (($11) + ($i$01$i<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + ($$sum$i)|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $15 & 251658240;
    $17 = ($16|0)==(16777216);
    if ($17) {
     $18 = (($13) + ($7)|0);
     $19 = $15 & 1073741823;
     $20 = $19 | -2147483648;
     HEAP32[$14>>2] = $20;
     HEAP32[$18>>2] = $9;
    }
    $21 = (($i$01$i) + 1)|0;
    $exitcond$i = ($21|0)==($8|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $21;
    }
   }
  }
  $22 = (($0) + 268|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $25 = ($24|0)!=(0);
  $26 = ($23|0)>(-1);
  $or$cond$i$i$i1 = $25 & $26;
  if (!($or$cond$i$i$i1)) {
   STACKTOP = sp;return;
  }
  $27 = (($0) + 260|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($0|0)==($28|0);
  if ($29) {
   HEAP8[$4>>0] = 0;
   STACKTOP = sp;return;
  }
  $30 = ($28|0)==(0|0);
  if ($30) {
   STACKTOP = sp;return;
  }
  $31 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_vii[$34 & 4095]($31,$28);
  STACKTOP = sp;return;
 }
 $35 = (($scShapes) + 256|0);
 $36 = (($scShapes) + 260|0);
 $37 = (($scShapes) + 264|0);
 HEAP32[$37>>2] = 0;
 $38 = (($scShapes) + 268|0);
 HEAP8[$35>>0] = 1;
 HEAP32[$36>>2] = $scShapes;
 HEAP32[$38>>2] = 64;
 $39 = (($1) + 256|0);
 HEAP8[$39>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes);
 $40 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $41 = (($rigidObject) + 16|0);
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($41)|0);
 $42 = (($40) + -16)|0;
 $43 = (__ZN5physx23NpRigidDynamicGetShapesERNS_3Scb4BodyERPKPv($rigidObject,$shapes$i3)|0);
 $44 = HEAP32[$rigidObject>>2]|0;
 $45 = ($43|0)==(0);
 if (!($45)) {
  $$sum$i4 = (($40) + -12)|0;
  $i$01$i6 = 0;
  while(1) {
   $46 = HEAP32[$shapes$i3>>2]|0;
   $47 = (($46) + ($i$01$i6<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + ($$sum$i4)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $50 & 251658240;
   $52 = ($51|0)==(16777216);
   if ($52) {
    $53 = (($48) + ($42)|0);
    $54 = $50 & 1073741823;
    $55 = $54 | -2147483648;
    HEAP32[$49>>2] = $55;
    HEAP32[$53>>2] = $44;
   }
   $56 = (($i$01$i6) + 1)|0;
   $exitcond$i8 = ($56|0)==($43|0);
   if ($exitcond$i8) {
    break;
   } else {
    $i$01$i6 = $56;
   }
  }
 }
 $57 = (($1) + 268|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58 & 2147483647;
 $60 = ($59|0)!=(0);
 $61 = ($58|0)>(-1);
 $or$cond$i$i$i11 = $60 & $61;
 do {
  if ($or$cond$i$i$i11) {
   $62 = (($1) + 260|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($1|0)==($63|0);
   if ($64) {
    HEAP8[$39>>0] = 0;
    break;
   }
   $65 = ($63|0)==(0|0);
   if (!($65)) {
    $66 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($67) + 12|0);
    $69 = HEAP32[$68>>2]|0;
    FUNCTION_TABLE_vii[$69 & 4095]($66,$63);
   }
  }
 } while(0);
 $70 = HEAP32[$38>>2]|0;
 $71 = $70 & 2147483647;
 $72 = ($71|0)!=(0);
 $73 = ($70|0)>(-1);
 $or$cond$i$i$i = $72 & $73;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $74 = HEAP32[$36>>2]|0;
 $75 = ($scShapes|0)==($74|0);
 if ($75) {
  HEAP8[$35>>0] = 0;
  STACKTOP = sp;return;
 }
 $76 = ($74|0)==(0|0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 12|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($77,$74);
 STACKTOP = sp;return;
}
function __ZN10ScSceneFnsIN5physx3Scb11RigidStaticEE6insertERNS0_2Sc5SceneERS2_($s,$v) {
 $s = $s|0;
 $v = $v|0;
 var $$in = 0, $$sum$i$i = 0, $$sum$i4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i7$i = 0, $i$01$i$i = 0, $i$01$i6$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i1$i = 0, $or$cond$i$i$i10$i = 0, $s$idx = 0, $s$idx$val = 0;
 var $scShapes$i = 0, $shapes$i3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $shapes$i3$i = sp + 816|0;
 $0 = sp;
 $scShapes$i = sp + 272|0;
 $1 = sp + 544|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  $13 = $3 >>> 24;
  $14 = $13 & 15;
  $15 = ((444424 + ($14<<2)|0) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $v;
  $18 = (($16) + ($17))|0;
  $19 = $18;
  $20 = (($19) + 8|0);
  $$in = $20;
 } else {
  $6 = (($v) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $9 = HEAP32[$v>>2]|0;
   $10 = $3 >>> 24;
   $11 = $10 & 15;
   $12 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($9,$11)|0);
   HEAP32[$6>>2] = $12;
   $107 = $12;
  } else {
   $107 = $7;
  }
  $$in = $107;
 }
 $21 = HEAP16[$$in>>1]|0;
 $22 = $21 & 8;
 $23 = ($22<<16>>16)==(0);
 if (!($23)) {
  $s$idx = (($s) + 1244|0);
  $s$idx$val = HEAP32[$s$idx>>2]|0;
  __ZL22addOrRemoveRigidObjectILb0ELb1ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_b($s$idx$val,$v);
  STACKTOP = sp;return;
 }
 $24 = (($s) + 1244|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (($25) + 272|0);
  $28 = (($0) + 256|0);
  HEAP8[$28>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$27);
  $29 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $30 = (($v) + 16|0);
  (__ZNK5physx2Sc9RigidCore10getPxActorEv($30)|0);
  $31 = (($29) + -16)|0;
  $32 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($v,$shapes$i3$i)|0);
  $33 = HEAP32[$shapes$i3$i>>2]|0;
  __ZN5physx2Sc5Scene9addStaticERNS0_10StaticCoreEPKPvjj($s,$30,$33,$32,$29);
  $34 = HEAP32[$v>>2]|0;
  $35 = ($32|0)==(0);
  if (!($35)) {
   $$sum$i$i = (($29) + -12)|0;
   $i$01$i$i = 0;
   while(1) {
    $36 = HEAP32[$shapes$i3$i>>2]|0;
    $37 = (($36) + ($i$01$i$i<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + ($31)|0);
    $40 = (($38) + ($$sum$i$i)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $41 & 251658240;
    $43 = ($42|0)==(16777216);
    if ($43) {
     $44 = $41 & 1073741823;
     $45 = $44 | -2147483648;
     HEAP32[$40>>2] = $45;
     HEAP32[$39>>2] = $34;
    }
    __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($39);
    $46 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($46|0)==($32|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $46;
    }
   }
  }
  $47 = (($0) + 268|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = $48 & 2147483647;
  $50 = ($49|0)!=(0);
  $51 = ($48|0)>(-1);
  $or$cond$i$i$i1$i = $50 & $51;
  if (!($or$cond$i$i$i1$i)) {
   STACKTOP = sp;return;
  }
  $52 = (($0) + 260|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($0|0)==($53|0);
  if ($54) {
   HEAP8[$28>>0] = 0;
   STACKTOP = sp;return;
  }
  $55 = ($53|0)==(0|0);
  if ($55) {
   STACKTOP = sp;return;
  }
  $56 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($57) + 12|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vii[$59 & 4095]($56,$53);
  STACKTOP = sp;return;
 }
 $60 = (($scShapes$i) + 256|0);
 $61 = (($scShapes$i) + 260|0);
 $62 = (($scShapes$i) + 264|0);
 HEAP32[$62>>2] = 0;
 $63 = (($scShapes$i) + 268|0);
 HEAP8[$60>>0] = 1;
 HEAP32[$61>>2] = $scShapes$i;
 HEAP32[$63>>2] = 64;
 $64 = (($1) + 256|0);
 HEAP8[$64>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes$i);
 $65 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $66 = (($v) + 16|0);
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($66)|0);
 $67 = (($65) + -16)|0;
 $68 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($v,$shapes$i3$i)|0);
 $69 = HEAP32[$shapes$i3$i>>2]|0;
 __ZN5physx2Sc5Scene9addStaticERNS0_10StaticCoreEPKPvjj($s,$66,$69,$68,$65);
 $70 = HEAP32[$v>>2]|0;
 $71 = ($68|0)==(0);
 if (!($71)) {
  $$sum$i4$i = (($65) + -12)|0;
  $i$01$i6$i = 0;
  while(1) {
   $72 = HEAP32[$shapes$i3$i>>2]|0;
   $73 = (($72) + ($i$01$i6$i<<2)|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + ($67)|0);
   $76 = (($74) + ($$sum$i4$i)|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = $77 & 251658240;
   $79 = ($78|0)==(16777216);
   if ($79) {
    $80 = $77 & 1073741823;
    $81 = $80 | -2147483648;
    HEAP32[$76>>2] = $81;
    HEAP32[$75>>2] = $70;
   }
   __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($75);
   $82 = (($i$01$i6$i) + 1)|0;
   $exitcond$i7$i = ($82|0)==($68|0);
   if ($exitcond$i7$i) {
    break;
   } else {
    $i$01$i6$i = $82;
   }
  }
 }
 $83 = (($1) + 268|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = $84 & 2147483647;
 $86 = ($85|0)!=(0);
 $87 = ($84|0)>(-1);
 $or$cond$i$i$i10$i = $86 & $87;
 do {
  if ($or$cond$i$i$i10$i) {
   $88 = (($1) + 260|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($1|0)==($89|0);
   if ($90) {
    HEAP8[$64>>0] = 0;
    break;
   }
   $91 = ($89|0)==(0|0);
   if (!($91)) {
    $92 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($93) + 12|0);
    $95 = HEAP32[$94>>2]|0;
    FUNCTION_TABLE_vii[$95 & 4095]($92,$89);
   }
  }
 } while(0);
 $96 = HEAP32[$63>>2]|0;
 $97 = $96 & 2147483647;
 $98 = ($97|0)!=(0);
 $99 = ($96|0)>(-1);
 $or$cond$i$i$i$i = $98 & $99;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $100 = HEAP32[$61>>2]|0;
 $101 = ($scShapes$i|0)==($100|0);
 if ($101) {
  HEAP8[$60>>0] = 0;
  STACKTOP = sp;return;
 }
 $102 = ($100|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$100);
 STACKTOP = sp;return;
}
function __ZN5physx3Scb11RigidStatic9syncStateEv($this) {
 $this = $this|0;
 var $$mask$i = 0, $$not$i = 0, $$not1$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $brmerge$i = 0, $brmerge2$i = 0, $exitcond$i = 0, $i$01$i = 0, $shapes$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $shapes$i = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 do {
  if (!($3)) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    $7 = HEAP32[$this>>2]|0;
    $8 = $1 >>> 24;
    $9 = $8 & 15;
    $10 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($7,$9)|0);
    HEAP32[$4>>2] = $10;
    $16 = $10;
   } else {
    $16 = $5;
   }
   $11 = (($this) + 24|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = $12 & 8;
   $14 = ($13<<16>>16)!=(0);
   $15 = HEAP16[$16>>1]|0;
   $17 = $15 & 8;
   $18 = ($17<<16>>16)!=(0);
   $$not$i = $14 ^ 1;
   $brmerge$i = $18 | $$not$i;
   if ($brmerge$i) {
    $$not1$i = $18 ^ 1;
    $brmerge2$i = $14 | $$not1$i;
    if ($brmerge2$i) {
     break;
    }
    $41 = HEAP32[$this>>2]|0;
    __ZN5physx3Scb5Scene18switchRigidToNoSimERNS0_11RigidObjectEb($41,$this,0);
    break;
   }
   $19 = HEAP32[$this>>2]|0;
   $20 = HEAP32[$0>>2]|0;
   $$mask$i = $20 & -1073741824;
   $21 = ($$mask$i|0)==(-2147483648);
   if ($21) {
    $22 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
    $23 = (($22) + -16)|0;
    $24 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($this,$shapes$i)|0);
    $25 = (($19) + 16|0);
    $26 = $this;
    $27 = HEAP32[$0>>2]|0;
    $28 = $27 >>> 24;
    $29 = $28 & 15;
    $30 = ((444424 + ($29<<2)|0) + 24|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + ($26))|0;
    $33 = $32;
    $34 = HEAP32[$shapes$i>>2]|0;
    __ZN5physx2Sc5Scene9addStaticERNS0_10StaticCoreEPKPvjj($25,$33,$34,$24,$22);
    $35 = ($24|0)==(0);
    if (!($35)) {
     $i$01$i = 0;
     while(1) {
      $36 = HEAP32[$shapes$i>>2]|0;
      $37 = (($36) + ($i$01$i<<2)|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($38) + ($23)|0);
      __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($39);
      $40 = (($i$01$i) + 1)|0;
      $exitcond$i = ($40|0)==($24|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$01$i = $40;
      }
     }
    }
   }
  }
 } while(0);
 __ZN5physx3Scb11RigidObject9syncStateEv($this);
 $42 = $1 & 64;
 $43 = ($42|0)==(0);
 $$pre = (($this) + 8|0);
 if ($43) {
  HEAP32[$$pre>>2] = 0;
  $57 = HEAP32[$0>>2]|0;
  $58 = $57 & -16777216;
  HEAP32[$0>>2] = $58;
  STACKTOP = sp;return;
 }
 $44 = HEAP32[$$pre>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  $46 = HEAP32[$this>>2]|0;
  $47 = HEAP32[$0>>2]|0;
  $48 = $47 >>> 24;
  $49 = $48 & 15;
  $50 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($46,$49)|0);
  HEAP32[$$pre>>2] = $50;
  $56 = $50;
 } else {
  $56 = $44;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = $51 & 64;
 $53 = ($52|0)==(0);
 if ($53) {
  HEAP32[$$pre>>2] = 0;
  $57 = HEAP32[$0>>2]|0;
  $58 = $57 & -16777216;
  HEAP32[$0>>2] = $58;
  STACKTOP = sp;return;
 }
 $54 = (($this) + 16|0);
 $55 = (($56) + 96|0);
 __ZN5physx2Sc10StaticCore14setActor2WorldERKNS_11PxTransformE($54,$55);
 HEAP32[$$pre>>2] = 0;
 $57 = HEAP32[$0>>2]|0;
 $58 = $57 & -16777216;
 HEAP32[$0>>2] = $58;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb11RigidObject9syncStateEv($this) {
 $this = $this|0;
 var $$in = 0, $$in10 = 0, $$mask = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$014 = 0, $i2$012 = 0, $i2$012$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 32;
 $6 = ($5|0)==(0);
 do {
  if (!($6)) {
   $7 = HEAP32[$this>>2]|0;
   $8 = $this;
   $9 = $4 >>> 24;
   $10 = $9 & 15;
   $11 = ((444424 + ($10<<2)|0) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($8))|0;
   $14 = $13;
   $15 = (($this) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($7,$10)|0);
    HEAP32[$15>>2] = $18;
    $20 = $18;
   } else {
    $20 = $16;
   }
   $19 = (($20) + 88|0);
   $21 = HEAP32[$19>>2]|0;
   $22 = ($21|0)==(1);
   $23 = (($20) + 84|0);
   if ($22) {
    $30 = $23;
   } else {
    $24 = HEAP32[$23>>2]|0;
    $25 = (($7) + 2500|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($26) + ($24<<2)|0);
    $28 = ($21|0)==(0);
    if ($28) {
     break;
    } else {
     $30 = $27;
    }
   }
   $i$014 = 0;
   while(1) {
    $29 = (($30) + ($i$014<<2)|0);
    $31 = HEAP32[$29>>2]|0;
    $32 = (($31) + 16|0);
    $33 = (($31) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = $34 & 64;
    $36 = ($35|0)==(0);
    if ($36) {
     $46 = (($31) + 80|0);
     $$in10 = $46;
    } else {
     $37 = (($31) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $40 = HEAP32[$31>>2]|0;
      $41 = $34 >>> 24;
      $42 = $41 & 15;
      $43 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($40,$42)|0);
      HEAP32[$37>>2] = $43;
      $45 = $43;
     } else {
      $45 = $38;
     }
     $44 = (($45) + 116|0);
     $$in10 = $44;
    }
    $47 = HEAP8[$$in10>>0]|0;
    $48 = $47 & 5;
    $49 = ($48<<24>>24)==(0);
    if (!($49)) {
     HEAP32[$1>>2] = 128;
     HEAP8[$2>>0] = 0;
     __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($14,$32,$1,$2);
    }
    $50 = (($i$014) + 1)|0;
    $51 = HEAP32[$19>>2]|0;
    $52 = ($50>>>0)<($51>>>0);
    if ($52) {
     $i$014 = $50;
    } else {
     break;
    }
   }
  }
 } while(0);
 $53 = $4 & 8;
 $54 = ($53|0)==(0);
 if (!($54)) {
  $55 = (($this) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if ($57) {
   $58 = HEAP32[$this>>2]|0;
   $59 = HEAP32[$3>>2]|0;
   $60 = $59 >>> 24;
   $61 = $60 & 15;
   $62 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($58,$61)|0);
   HEAP32[$55>>2] = $62;
   $72 = $62;
  } else {
   $72 = $56;
  }
  $63 = HEAP32[$3>>2]|0;
  $64 = $this;
  $65 = $63 >>> 24;
  $66 = $65 & 15;
  $67 = ((444424 + ($66<<2)|0) + 24|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($68) + ($64))|0;
  $70 = $69;
  (__ZNK5physx2Sc9RigidCore10getPxActorEv($70)|0);
  $71 = (($72) + 4|0);
  $73 = (($72) + 28|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74|0)==(0);
  L28: do {
   if (!($75)) {
    $76 = (($72) + 24|0);
    $$mask = $63 & -1073741824;
    $77 = ($$mask|0)==(-1073741824);
    if ($77) {
     $162 = $74;$i2$012$us = 0;
     while(1) {
      $78 = HEAP32[$76>>2]|0;
      $79 = (($78) + ($i2$012$us<<2)|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 4|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = $82 & 251658240;
      $84 = ($83|0)==(16777216);
      if ($84) {
       $85 = HEAP32[$this>>2]|0;
       $86 = $82 & 1073741823;
       HEAP32[$81>>2] = $86;
       HEAP32[$80>>2] = $85;
       $$pre = HEAP32[$73>>2]|0;
       $89 = $$pre;
      } else {
       $89 = $162;
      }
      $87 = (($i2$012$us) + 1)|0;
      $88 = ($87>>>0)<($89>>>0);
      if ($88) {
       $162 = $89;$i2$012$us = $87;
      } else {
       break L28;
      }
     }
    } else {
     $i2$012 = 0;
    }
    while(1) {
     $90 = HEAP32[$76>>2]|0;
     $91 = (($90) + ($i2$012<<2)|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = (($92) + 4|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = $94 & 251658240;
     $96 = ($95|0)==(16777216);
     if ($96) {
      $97 = HEAP32[$this>>2]|0;
      $98 = $94 & 1073741823;
      $99 = $98 | -2147483648;
      HEAP32[$93>>2] = $99;
      HEAP32[$92>>2] = $97;
     }
     $100 = HEAP32[$3>>2]|0;
     $101 = $100 & 1;
     $102 = ($101|0)==(0);
     if ($102) {
      $109 = $100 >>> 24;
      $110 = $109 & 15;
      $111 = ((444424 + ($110<<2)|0) + 24|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = (($112) + ($64))|0;
      $114 = $113;
      $115 = (($114) + 8|0);
      $$in = $115;
     } else {
      $103 = HEAP32[$55>>2]|0;
      $104 = ($103|0)==(0|0);
      if ($104) {
       $105 = HEAP32[$this>>2]|0;
       $106 = $100 >>> 24;
       $107 = $106 & 15;
       $108 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($105,$107)|0);
       HEAP32[$55>>2] = $108;
       $163 = $108;
      } else {
       $163 = $103;
      }
      $$in = $163;
     }
     $116 = HEAP16[$$in>>1]|0;
     $117 = $116 & 8;
     $118 = ($117<<16>>16)==(0);
     if ($118) {
      $119 = HEAP32[$3>>2]|0;
      $120 = $119 >>> 24;
      $121 = $120 & 15;
      $122 = ((444424 + ($121<<2)|0) + 24|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = (($123) + ($64))|0;
      $125 = $124;
      $126 = (($92) + 16|0);
      __ZN5physx2Sc9RigidCore15addShapeToSceneERNS0_9ShapeCoreE($125,$126);
      __ZN5physx18NpShapeIncRefCountERNS_3Scb5ShapeE($92);
     }
     $127 = (($i2$012) + 1)|0;
     $128 = HEAP32[$73>>2]|0;
     $129 = ($127>>>0)<($128>>>0);
     if ($129) {
      $i2$012 = $127;
     } else {
      break;
     }
    }
   }
  } while(0);
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS4_EEEEE6resizeEjRKS4_($71,0,$0);
  $130 = HEAP32[$73>>2]|0;
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS4_EEEEE8recreateEj($71,$130);
 }
 $131 = HEAP32[$3>>2]|0;
 $132 = $131 & 7;
 $133 = ($132|0)==(0);
 if ($133) {
  STACKTOP = sp;return;
 }
 $134 = $this;
 $135 = $131 >>> 24;
 $136 = $135 & 15;
 $137 = ((444424 + ($136<<2)|0) + 24|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = (($138) + ($134))|0;
 $140 = $139;
 $141 = (($this) + 8|0);
 $142 = HEAP32[$141>>2]|0;
 $143 = ($142|0)==(0|0);
 if ($143) {
  $144 = HEAP32[$this>>2]|0;
  $145 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($144,$136)|0);
  HEAP32[$141>>2] = $145;
  $$pre$i = HEAP32[$3>>2]|0;
  $147 = $$pre$i;$150 = $145;
 } else {
  $147 = $131;$150 = $142;
 }
 $146 = $147 & 1;
 $148 = ($146|0)==(0);
 if ($148) {
  $152 = $147;
 } else {
  $149 = HEAP16[$150>>1]|0;
  HEAP16[$0>>1] = $149;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($140,$0);
  $$pre1$i = HEAP32[$3>>2]|0;
  $152 = $$pre1$i;
 }
 $151 = $152 & 2;
 $153 = ($151|0)==(0);
 if ($153) {
  $157 = $152;
 } else {
  $154 = (($150) + 2|0);
  $155 = HEAP8[$154>>0]|0;
  __ZN5physx2Sc9ActorCore17setDominanceGroupEh($140,$155);
  $$pre2$i = HEAP32[$3>>2]|0;
  $157 = $$pre2$i;
 }
 $156 = $157 & 4;
 $158 = ($156|0)==(0);
 if ($158) {
  STACKTOP = sp;return;
 }
 $159 = (($150) + 3|0);
 $160 = HEAP8[$159>>0]|0;
 $161 = (($140) + 11|0);
 HEAP8[$161>>0] = $160;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS4_EEEEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS4_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($size<<2)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + ($7<<2)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $12;
  }
  $13 = (($$01$i) + 4|0);
  $14 = ($13>>>0)<($8>>>0);
  if ($14) {
   $$01$i = $13;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_3Scb5ShapeENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS4_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = (($this) + 16|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(17);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 446120 : 445824;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,445744,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<2)|0);
 $21 = (($this) + 20|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($19>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = (($this) + 28|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(-1);
 if (!($31)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$21>>2]|0;
 $33 = ($this|0)==($32|0);
 if ($33) {
  $34 = (($this) + 16|0);
  HEAP8[$34>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = ($32|0)==(0|0);
 if ($35) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vii[$39 & 4095]($36,$32);
 HEAP32[$21>>2] = $20;
 HEAP32[$29>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZL22addOrRemoveRigidObjectILb0ELb1ELb0ELb1EN5physx3Scb11RigidStaticEEvRNS0_2Sc5SceneERT3_b($s$0$52$val,$rigidObject) {
 $s$0$52$val = $s$0$52$val|0;
 $rigidObject = $rigidObject|0;
 var $$sum$i = 0, $$sum$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i8 = 0, $i$01$i = 0, $i$01$i6 = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $or$cond$i$i$i11 = 0, $scShapes = 0, $shapes$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $shapes$i3 = sp + 816|0;
 $0 = sp;
 $scShapes = sp + 272|0;
 $1 = sp + 544|0;
 $2 = ($s$0$52$val|0)==(0|0);
 if (!($2)) {
  $3 = (($s$0$52$val) + 272|0);
  $4 = (($0) + 256|0);
  HEAP8[$4>>0] = 0;
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($0,$3);
  $5 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
  $6 = (($rigidObject) + 16|0);
  (__ZNK5physx2Sc9RigidCore10getPxActorEv($6)|0);
  $7 = (($5) + -16)|0;
  $8 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($rigidObject,$shapes$i3)|0);
  $9 = HEAP32[$rigidObject>>2]|0;
  $10 = ($8|0)==(0);
  if (!($10)) {
   $$sum$i = (($5) + -12)|0;
   $i$01$i = 0;
   while(1) {
    $11 = HEAP32[$shapes$i3>>2]|0;
    $12 = (($11) + ($i$01$i<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + ($$sum$i)|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $15 & 251658240;
    $17 = ($16|0)==(16777216);
    if ($17) {
     $18 = (($13) + ($7)|0);
     $19 = $15 & 1073741823;
     $20 = $19 | -2147483648;
     HEAP32[$14>>2] = $20;
     HEAP32[$18>>2] = $9;
    }
    $21 = (($i$01$i) + 1)|0;
    $exitcond$i = ($21|0)==($8|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $21;
    }
   }
  }
  $22 = (($0) + 268|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $25 = ($24|0)!=(0);
  $26 = ($23|0)>(-1);
  $or$cond$i$i$i1 = $25 & $26;
  if (!($or$cond$i$i$i1)) {
   STACKTOP = sp;return;
  }
  $27 = (($0) + 260|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($0|0)==($28|0);
  if ($29) {
   HEAP8[$4>>0] = 0;
   STACKTOP = sp;return;
  }
  $30 = ($28|0)==(0|0);
  if ($30) {
   STACKTOP = sp;return;
  }
  $31 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_vii[$34 & 4095]($31,$28);
  STACKTOP = sp;return;
 }
 $35 = (($scShapes) + 256|0);
 $36 = (($scShapes) + 260|0);
 $37 = (($scShapes) + 264|0);
 HEAP32[$37>>2] = 0;
 $38 = (($scShapes) + 268|0);
 HEAP8[$35>>0] = 1;
 HEAP32[$36>>2] = $scShapes;
 HEAP32[$38>>2] = 64;
 $39 = (($1) + 256|0);
 HEAP8[$39>>0] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE4copyIS9_EEvRKNS1_IS5_T_EE($1,$scShapes);
 $40 = (__ZN5physx21NpShapeGetScPtrOffsetEv()|0);
 $41 = (($rigidObject) + 16|0);
 (__ZNK5physx2Sc9RigidCore10getPxActorEv($41)|0);
 $42 = (($40) + -16)|0;
 $43 = (__ZN5physx22NpRigidStaticGetShapesERNS_3Scb11RigidStaticERPKPv($rigidObject,$shapes$i3)|0);
 $44 = HEAP32[$rigidObject>>2]|0;
 $45 = ($43|0)==(0);
 if (!($45)) {
  $$sum$i4 = (($40) + -12)|0;
  $i$01$i6 = 0;
  while(1) {
   $46 = HEAP32[$shapes$i3>>2]|0;
   $47 = (($46) + ($i$01$i6<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + ($$sum$i4)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $50 & 251658240;
   $52 = ($51|0)==(16777216);
   if ($52) {
    $53 = (($48) + ($42)|0);
    $54 = $50 & 1073741823;
    $55 = $54 | -2147483648;
    HEAP32[$49>>2] = $55;
    HEAP32[$53>>2] = $44;
   }
   $56 = (($i$01$i6) + 1)|0;
   $exitcond$i8 = ($56|0)==($43|0);
   if ($exitcond$i8) {
    break;
   } else {
    $i$01$i6 = $56;
   }
  }
 }
 $57 = (($1) + 268|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58 & 2147483647;
 $60 = ($59|0)!=(0);
 $61 = ($58|0)>(-1);
 $or$cond$i$i$i11 = $60 & $61;
 do {
  if ($or$cond$i$i$i11) {
   $62 = (($1) + 260|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($1|0)==($63|0);
   if ($64) {
    HEAP8[$39>>0] = 0;
    break;
   }
   $65 = ($63|0)==(0|0);
   if (!($65)) {
    $66 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($67) + 12|0);
    $69 = HEAP32[$68>>2]|0;
    FUNCTION_TABLE_vii[$69 & 4095]($66,$63);
   }
  }
 } while(0);
 $70 = HEAP32[$38>>2]|0;
 $71 = $70 & 2147483647;
 $72 = ($71|0)!=(0);
 $73 = ($70|0)>(-1);
 $or$cond$i$i$i = $72 & $73;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $74 = HEAP32[$36>>2]|0;
 $75 = ($scShapes|0)==($74|0);
 if ($75) {
  HEAP8[$35>>0] = 0;
  STACKTOP = sp;return;
 }
 $76 = ($74|0)==(0|0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 12|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($77,$74);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 446232 : 445824;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,445744,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = $$03$i;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = $$012$i;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
   }
   $30 = (($$012$i) + 8|0);
   $31 = (($$03$i) + 8|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_3Scb13MaterialEventENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 446232 : 445824;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,445744,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE5eraseERKS5_($this,$k) {
 $this = $this|0;
 $k = $k|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $ptr$0$lcssa$i = 0, $ptr$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$k>>2]|0;
 $4 = $3;
 $5 = $4 << 15;
 $6 = $5 ^ -1;
 $7 = (($4) + ($6))|0;
 $8 = $7 >>> 10;
 $9 = $8 ^ $7;
 $10 = ($9*9)|0;
 $11 = $10 >>> 6;
 $12 = $11 ^ $10;
 $13 = $12 << 11;
 $14 = $13 ^ -1;
 $15 = (($12) + ($14))|0;
 $16 = $15 >>> 16;
 $17 = $16 ^ $15;
 $18 = (($1) + -1)|0;
 $19 = $17 & $18;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19<<2)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(-1);
 if ($24) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $25 = (($this) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 8|0);
 $$pr = $23;$ptr$02 = $22;
 while(1) {
  $28 = (($26) + ($$pr<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==($3|0);
  if ($30) {
   break;
  }
  $31 = HEAP32[$27>>2]|0;
  $32 = (($31) + ($$pr<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(-1);
  if ($34) {
   $$0 = 0;
   label = 14;
   break;
  } else {
   $$pr = $33;$ptr$02 = $32;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return ($$0|0);
 }
 $35 = ($$pr|0)==(-1);
 if ($35) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = HEAP32[$27>>2]|0;
 $37 = (($36) + ($$pr<<2)|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$ptr$02>>2] = $38;
 $39 = (($this) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + -1)|0;
 HEAP32[$39>>2] = $41;
 $42 = (($this) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 1)|0;
 HEAP32[$42>>2] = $44;
 $45 = ($$pr|0)==($41|0);
 if (!($45)) {
  $46 = ($28|0)==(0|0);
  if ($46) {
   $50 = $36;$55 = $3;$72 = $21;
  } else {
   $47 = (($26) + ($41<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$28>>2] = $48;
   $$pre$i = HEAP32[$25>>2]|0;
   $$pre = HEAP32[$27>>2]|0;
   $$phi$trans$insert = (($$pre$i) + ($$pr<<2)|0);
   $$pre4 = HEAP32[$$phi$trans$insert>>2]|0;
   $$pre5 = HEAP32[$20>>2]|0;
   $50 = $$pre;$55 = $$pre4;$72 = $$pre5;
  }
  $49 = (($50) + ($41<<2)|0);
  $51 = HEAP32[$49>>2]|0;
  $52 = (($50) + ($$pr<<2)|0);
  HEAP32[$52>>2] = $51;
  $53 = HEAP32[$0>>2]|0;
  $54 = $55;
  $56 = $54 << 15;
  $57 = $56 ^ -1;
  $58 = (($54) + ($57))|0;
  $59 = $58 >>> 10;
  $60 = $59 ^ $58;
  $61 = ($60*9)|0;
  $62 = $61 >>> 6;
  $63 = $62 ^ $61;
  $64 = $63 << 11;
  $65 = $64 ^ -1;
  $66 = (($63) + ($65))|0;
  $67 = $66 >>> 16;
  $68 = $67 ^ $66;
  $69 = (($53) + -1)|0;
  $70 = $68 & $69;
  $71 = (($72) + ($70<<2)|0);
  $73 = HEAP32[$71>>2]|0;
  $74 = HEAP32[$39>>2]|0;
  $75 = ($73|0)==($74|0);
  if ($75) {
   $ptr$0$lcssa$i = $71;
  } else {
   $77 = $73;
   while(1) {
    $76 = (($50) + ($77<<2)|0);
    $78 = HEAP32[$76>>2]|0;
    $79 = ($78|0)==($74|0);
    if ($79) {
     $ptr$0$lcssa$i = $76;
     break;
    } else {
     $77 = $78;
    }
   }
  }
  HEAP32[$ptr$0$lcssa$i>>2] = $$pr;
 }
 $80 = (($this) + 28|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + -1)|0;
 HEAP32[$80>>2] = $82;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE6createERKS5_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $h$0 = 0;
 var $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($3|0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $27;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $33 = (($this) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 16|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 if ($37) {
  $38 = $1 << 1;
  $$$i = $2 ? 16 : $38;
  $39 = ($1>>>0)<($$$i>>>0);
  if ($39) {
   __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $56 = $$pre;
  } else {
   $56 = $1;
  }
  $40 = HEAP32[$k>>2]|0;
  $41 = $40;
  $42 = $41 << 15;
  $43 = $42 ^ -1;
  $44 = (($41) + ($43))|0;
  $45 = $44 >>> 10;
  $46 = $45 ^ $44;
  $47 = ($46*9)|0;
  $48 = $47 >>> 6;
  $49 = $48 ^ $47;
  $50 = $49 << 11;
  $51 = $50 ^ -1;
  $52 = (($49) + ($51))|0;
  $53 = $52 >>> 16;
  $54 = $53 ^ $52;
  $55 = (($56) + -1)|0;
  $57 = $54 & $55;
  $h$1 = $57;
 } else {
  $h$1 = $h$0;
 }
 $58 = (($this) + 28|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$58>>2] = $60;
 $61 = (($this) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($h$1<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($this) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($59<<2)|0);
 HEAP32[$67>>2] = $64;
 HEAP32[$63>>2] = $59;
 $68 = HEAP32[$33>>2]|0;
 $69 = (($68) + 1)|0;
 HEAP32[$33>>2] = $69;
 $70 = (($this) + 32|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + 1)|0;
 HEAP32[$70>>2] = $72;
 $73 = (($this) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($74) + ($59<<2)|0);
 $$0 = $75;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIPNS_3Scb4BaseES5_NS0_4HashIS5_EENS1_11HashSetBaseIS5_S7_NS0_9AllocatorELb1EE6GetKeyES9_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $index$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = (($27) + ($23))|0;
 $29 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$28,446360,354)|0);
 $30 = (($29) + ($22)|0);
 $31 = (($29) + ($27)|0);
 _memset(($29|0),-1,($22|0))|0;
 $32 = (($this) + 36|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 $$pre = (($this) + 4|0);
 if (!($34)) {
  $35 = (($$0) + -1)|0;
  $index$01 = 0;
  while(1) {
   $36 = HEAP32[$$pre>>2]|0;
   $37 = (($36) + ($index$01<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38;
   $40 = $39 << 15;
   $41 = $40 ^ -1;
   $42 = (($39) + ($41))|0;
   $43 = $42 >>> 10;
   $44 = $43 ^ $42;
   $45 = ($44*9)|0;
   $46 = $45 >>> 6;
   $47 = $46 ^ $45;
   $48 = $47 << 11;
   $49 = $48 ^ -1;
   $50 = (($47) + ($49))|0;
   $51 = $50 >>> 16;
   $52 = $51 ^ $50;
   $53 = $52 & $35;
   $54 = (($29) + ($53<<2)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($30) + ($index$01<<2)|0);
   HEAP32[$56>>2] = $55;
   HEAP32[$54>>2] = $index$01;
   $57 = (($31) + ($index$01<<2)|0);
   $58 = ($57|0)==(0|0);
   if (!($58)) {
    HEAP32[$57>>2] = $38;
   }
   $59 = (($index$01) + 1)|0;
   $60 = HEAP32[$32>>2]|0;
   $61 = ($59>>>0)<($60>>>0);
   if ($61) {
    $index$01 = $59;
   } else {
    break;
   }
  }
 }
 $62 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$62);
 HEAP32[$this>>2] = $29;
 $63 = (($this) + 12|0);
 HEAP32[$63>>2] = $29;
 $64 = (($this) + 20|0);
 HEAP32[$64>>2] = $$0;
 $65 = (($this) + 8|0);
 HEAP32[$65>>2] = $30;
 HEAP32[$$pre>>2] = $31;
 HEAP32[$15>>2] = $21;
 $66 = (($this) + 28|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(-1);
 if (!($68)) {
  STACKTOP = sp;return;
 }
 HEAP32[$66>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 446728 : 445824;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,445744,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx18PxsMaterialManager6resizeEj($this,$minValueForMax) {
 $this = $this|0;
 $minValueForMax = $minValueForMax|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $i1$01 = 0, $phitmp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)<($minValueForMax>>>0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($minValueForMax) + 31)|0;
 $6 = $5 & -32;
 HEAP32[$2>>2] = $6;
 $7 = $6 << 5;
 $8 = $7 | 19;
 $9 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$8,446832,115)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0$i = 0;
 } else {
  $11 = (($9) + 19|0);
  $12 = $11;
  $13 = $12 & -16;
  $14 = $9;
  $15 = (($13) - ($14))|0;
  $16 = $13;
  $17 = (($16) + -4|0);
  HEAP32[$17>>2] = $15;
  $phitmp = $13;
  $$0$i = $phitmp;
 }
 $18 = ($3|0)==(0);
 if (!($18)) {
  $i$02 = 0;
  while(1) {
   $21 = (($$0$i) + ($i$02<<5)|0);
   $22 = HEAP32[$this>>2]|0;
   $23 = (($22) + ($i$02<<5)|0);
   ;HEAP32[$21+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$21+16>>2]=HEAP32[$23+16>>2]|0;HEAP32[$21+20>>2]=HEAP32[$23+20>>2]|0;
   $24 = (($i$02) + 1)|0;
   $exitcond = ($24|0)==($3|0);
   if ($exitcond) {
    break;
   } else {
    $i$02 = $24;
   }
  }
 }
 $19 = HEAP32[$2>>2]|0;
 $20 = ($3>>>0)<($19>>>0);
 if ($20) {
  $i1$01 = $3;
  while(1) {
   $25 = ((($$0$i) + ($i1$01<<5)|0) + 20|0);
   HEAP32[$25>>2] = -1;
   $26 = (($i1$01) + 1)|0;
   $27 = HEAP32[$2>>2]|0;
   $28 = ($26>>>0)<($27>>>0);
   if ($28) {
    $i1$01 = $26;
   } else {
    break;
   }
  }
 }
 $29 = HEAP32[$this>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (($29) + -4|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (0 - ($32))|0;
  $34 = (($29) + ($33)|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$34);
 }
 HEAP32[$this>>2] = $$0$i;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm9FlushPoolC2Ej($this,$chunkSize) {
 $this = $this|0;
 $chunkSize = $chunkSize|0;
 var $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  HEAP32[$this>>2] = 0;
 } else {
  $5 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__Z15PxGetFoundationv()|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
  $$$i$i$i$i = $13 ? 446528 : 445824;
  $14 = (FUNCTION_TABLE_iiiiii[$8 & 255]($5,$3,$$$i$i$i$i,446448,111)|0);
  HEAP32[$this>>2] = $14;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($14);
  }
 }
 $16 = (($this) + 4|0);
 $17 = (($this) + 8|0);
 $18 = (($this) + 12|0);
 $19 = (($this) + 24|0);
 ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;
 HEAP32[$19>>2] = $chunkSize;
 $20 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$chunkSize,446656,56)|0);
 HEAP32[$1>>2] = $20;
 $21 = HEAP32[$18>>2]|0;
 $22 = $21 & 2147483647;
 $23 = HEAP32[$17>>2]|0;
 $24 = ($22>>>0)>($23>>>0);
 if (!($24)) {
  (__ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($16,$1)|0);
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$16>>2]|0;
 $26 = (($25) + ($23<<2)|0);
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  HEAP32[$26>>2] = $20;
 }
 $28 = (($23) + 1)|0;
 HEAP32[$17>>2] = $28;
 STACKTOP = sp;return;
}
function __ZN5physx3Scb5Shape18setMaterialsHelperEPKPNS_10PxMaterialEt($this,$materials,$materialCount) {
 $this = $this|0;
 $materials = $materials|0;
 $materialCount = $materialCount|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $materialIndex = 0, $materialIndices = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $materialIndex = sp + 16|0;
 $materialIndices = sp + 8|0;
 $0 = sp + 18|0;
 $1 = $materialCount&65535;
 $2 = ($materialCount<<16>>16)==(1);
 if ($2) {
  $3 = HEAP32[$materials>>2]|0;
  $4 = (($3) + 52|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5&65535;
  HEAP16[$materialIndex>>1] = $6;
  $7 = (($this) + 16|0);
  __ZN5physx2Sc9ShapeCore18setMaterialIndicesEPKtt($7,$materialIndex,1);
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $8 = $1 << 1;
 $9 = ($8>>>0)>(1024);
 $10 = (($materialIndices) + 4|0);
 $11 = $9&1;
 HEAP8[$10>>0] = $11;
 if ($9) {
  $13 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$8,446928,49)|0);
  HEAP32[$materialIndices>>2] = $13;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $29 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($29,16,446928,58,447008,$vararg_buffer);
   $30 = HEAP8[$10>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $32 = HEAP32[$materialIndices>>2]|0;
   __ZN5physx6shdfnd13TempAllocator10deallocateEPv($materialIndices,$32);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  } else {
   $22 = $13;$28 = $materialIndices;
  }
 } else {
  $12 = STACKTOP; STACKTOP = STACKTOP + ((((2*$1)|0)+15)&-16)|0;;
  HEAP32[$materialIndices>>2] = $12;
  $22 = $12;$28 = $materialIndices;
 }
 $15 = ($materialCount<<16>>16)==(0);
 if (!($15)) {
  $i$01$i = 0;
  while(1) {
   $16 = (($materials) + ($i$01$i<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 52|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = $19&65535;
   $21 = (($22) + ($i$01$i<<1)|0);
   HEAP16[$21>>1] = $20;
   $23 = (($i$01$i) + 1)|0;
   $exitcond$i = ($23|0)==($1|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $23;
   }
  }
 }
 $24 = (($this) + 16|0);
 __ZN5physx2Sc9ShapeCore18setMaterialIndicesEPKtt($24,$22,$materialCount);
 $25 = HEAP8[$10>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $27 = HEAP32[$28>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($materialIndices,$27);
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx3Scb5Shape9syncStateEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre2 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 16777215;
 $6 = ($5|0)==(0);
 if ($6) {
  $$pre4 = (($this) + 8|0);
  $$pre$phiZ2D = $$pre4;
  HEAP32[$$pre$phiZ2D>>2] = 0;
  $57 = HEAP32[$3>>2]|0;
  $58 = $57 & -16777216;
  HEAP32[$3>>2] = $58;
  STACKTOP = sp;return;
 }
 $7 = (($this) + 16|0);
 $8 = (($this) + 80|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $14 = $4 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $19 = $16;
 } else {
  $19 = $11;
 }
 $17 = $4 & 1;
 $18 = ($17|0)==(0);
 if (!($18)) {
  __ZN5physx2Sc9ShapeCore11setGeometryERKNS_10PxGeometryE($7,$19);
 }
 $20 = $4 & 2;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($19) + 60|0);
  $23 = HEAP16[$22>>1]|0;
  $24 = ($23<<16>>16)==(1);
  if ($24) {
   $25 = (($19) + 56|0);
   $$0$i = $25;
  } else {
   $26 = HEAP32[$this>>2]|0;
   $27 = (($19) + 56|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + 2488|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + ($28<<1)|0);
   $$0$i = $31;
  }
  __ZN5physx2Sc9ShapeCore18setMaterialIndicesEPKtt($7,$$0$i,$23);
 }
 $32 = HEAP32[$3>>2]|0;
 $33 = $32 & 4;
 $34 = ($33|0)==(0);
 if ($34) {
  $37 = $32;
 } else {
  $35 = (($19) + 64|0);
  __ZN5physx2Sc9ShapeCore14setShape2ActorERKNS_11PxTransformE($7,$35);
  $$pre = HEAP32[$3>>2]|0;
  $37 = $$pre;
 }
 $36 = $37 & 8;
 $38 = ($36|0)==(0);
 if ($38) {
  $41 = $37;
 } else {
  $39 = (($19) + 92|0);
  __ZN5physx2Sc9ShapeCore23setSimulationFilterDataERKNS_12PxFilterDataE($7,$39);
  $$pre1 = HEAP32[$3>>2]|0;
  $41 = $$pre1;
 }
 $40 = $41 & 16;
 $42 = ($40|0)==(0);
 if (!($42)) {
  $43 = (($19) + 108|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($this) + 76|0);
  HEAPF32[$45>>2] = $44;
 }
 $46 = $41 & 32;
 $47 = ($46|0)==(0);
 if ($47) {
  $51 = $41;
 } else {
  $48 = (($19) + 112|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  __ZN5physx2Sc9ShapeCore13setRestOffsetEf($7,$49);
  $$pre2 = HEAP32[$3>>2]|0;
  $51 = $$pre2;
 }
 $50 = $51 & 64;
 $52 = ($50|0)==(0);
 if (!($52)) {
  $53 = (($19) + 116|0);
  $54 = HEAP8[$53>>0]|0;
  HEAP8[$0>>0] = $54;
  __ZN5physx2Sc9ShapeCore8setFlagsENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($7,$0);
 }
 $55 = (__ZN5physx34NpShapeGetScRigidObjectFromScbSLOWERKNS_3Scb5ShapeE($this)|0);
 $56 = ($55|0)==(0|0);
 if ($56) {
  $$pre$phiZ2D = $10;
  HEAP32[$$pre$phiZ2D>>2] = 0;
  $57 = HEAP32[$3>>2]|0;
  $58 = $57 & -16777216;
  HEAP32[$3>>2] = $58;
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $5;
 HEAP8[$2>>0] = $9;
 __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($55,$7,$1,$2);
 $$pre$phiZ2D = $10;
 HEAP32[$$pre$phiZ2D>>2] = 0;
 $57 = HEAP32[$3>>2]|0;
 $58 = $57 & -16777216;
 HEAP32[$3>>2] = $58;
 STACKTOP = sp;return;
}
function __ZN5physx7NpClothC2ERKNS_11PxTransformERNS_13NpClothFabricEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($this,$globalPose,$fabric,$particles,$flags) {
 $this = $this|0;
 $globalPose = $globalPose|0;
 $fabric = $fabric|0;
 $particles = $particles|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP16[$1>>1] = 10;
 $2 = (($this) + 6|0);
 HEAP16[$2>>1] = 3;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((448816 + 8|0));
 $4 = (($this) + 12|0);
 __ZN5physx7NpActorC2EPKc($4,0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((447080 + 8|0));
 $5 = (($this) + 20|0);
 $6 = (($fabric) + 16|0);
 $7 = HEAP16[$flags>>1]|0;
 HEAP16[$0>>1] = $7;
 __ZN5physx3Scb5ClothC2ERKNS_11PxTransformERNS_2Sc15ClothFabricCoreEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($5,$globalPose,$6,$particles,$0);
 $8 = (($this) + 124|0);
 HEAP32[$8>>2] = $fabric;
 $9 = (($this) + 128|0);
 HEAP32[$9>>2] = ((457240 + 8|0));
 $10 = (($this) + 140|0);
 HEAP32[$10>>2] = $this;
 $11 = (($this) + 144|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 148|0);
 HEAP8[$12>>0] = 1;
 $13 = (($fabric) + 12|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($13)|0);
 STACKTOP = sp;return;
}
function __ZN5physx7NpClothD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((447080 + 8|0));
 $1 = (($this) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(1);
 if ($5) {
  $6 = (($this) + 64|0);
  HEAP32[$6>>2] = 0;
 }
 $7 = HEAP32[$1>>2]|0;
 $8 = (($7) + 8|0);
 $9 = (($7) + 12|0);
 $10 = (__ZN5physx6shdfnd15atomicDecrementEPVi($9)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 4095]($8);
 }
 $15 = (($this) + 20|0);
 __ZN5physx3Scb5ClothD2Ev($15);
 HEAP32[$this>>2] = ((448320 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx7NpClothD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((447080 + 8|0));
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1);
 if ($4) {
  $5 = (($this) + 64|0);
  HEAP32[$5>>2] = 0;
 }
 $6 = HEAP32[$0>>2]|0;
 $7 = (($6) + 8|0);
 $8 = (($6) + 12|0);
 $9 = (__ZN5physx6shdfnd15atomicDecrementEPVi($8)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = HEAP32[$7>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($7);
 }
 $14 = (($this) + 20|0);
 __ZN5physx3Scb5ClothD2Ev($14);
 HEAP32[$this>>2] = ((448320 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx19NpClothParticleDataD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx7NpCloth17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $8 = 0;
 } else {
  $3 = HEAP32[$context>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = $1;
  $6 = (FUNCTION_TABLE_iiii[$4 & 2047]($context,-2147483648,$5)|0);
  HEAP32[$0>>2] = $6;
  $8 = $6;
 }
 $7 = (($8) + 12|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($7)|0);
 $9 = HEAP32[$0>>2]|0;
 $10 = (($9) + 16|0);
 $11 = (($this) + 32|0);
 __ZN5physx2Sc9ClothCore17resolveReferencesERNS0_15ClothFabricCoreE($11,$10);
 STACKTOP = sp;return;
}
function __ZN5physx7NpCloth8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$c>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($c,$4);
 STACKTOP = sp;return;
}
function __Z12NpGetPxClothRN5physx2Sc9ClothCoreE($cloth) {
 $cloth = $cloth|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + -32|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx7NpCloth7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,$2,1);
 $3 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5physx7NpScene11removeClothERNS_7NpClothE($3,$this);
 }
 $5 = (($this) + 20|0);
 __ZN5physx3Scb4Base7destroyEv($5);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpCloth7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 5;
}
function __ZNK5physx7NpCloth9getFabricEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -16|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx7NpCloth12setParticlesEPKNS_15PxClothParticleES3_($this,$currentParticles,$previousParticles) {
 $this = $this|0;
 $currentParticles = $currentParticles|0;
 $previousParticles = $previousParticles|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore12setParticlesEPKNS_15PxClothParticleES4_($8,$currentParticles,$previousParticles);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,243,456776,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth14getNbParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc9ClothCore14getNbParticlesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpCloth20setMotionConstraintsEPKNS_31PxClothParticleMotionConstraintE($this,$motionConstraints) {
 $this = $this|0;
 $motionConstraints = $motionConstraints|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore20setMotionConstraintsEPKNS_31PxClothParticleMotionConstraintE($8,$motionConstraints);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,256,456688,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth20getMotionConstraintsEPNS_31PxClothParticleMotionConstraintE($this,$motionConstraintsBuffer) {
 $this = $this|0;
 $motionConstraintsBuffer = $motionConstraintsBuffer|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore20getMotionConstraintsEPNS_31PxClothParticleMotionConstraintE($8,$motionConstraintsBuffer)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,266,456600,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth22getNbMotionConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc9ClothCore22getNbMotionConstraintsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpCloth25setMotionConstraintConfigERKNS_29PxClothMotionConstraintConfigE($this,$config) {
 $this = $this|0;
 $config = $config|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore25setMotionConstraintConfigERKNS_29PxClothMotionConstraintConfigE($8,$config);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,292,456512,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth25getMotionConstraintConfigEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore25getMotionConstraintConfigEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,281,456416,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(1.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth24setSeparationConstraintsEPKNS_35PxClothParticleSeparationConstraintE($this,$separationConstraints) {
 $this = $this|0;
 $separationConstraints = $separationConstraints|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore24setSeparationConstraintsEPKNS_35PxClothParticleSeparationConstraintE($8,$separationConstraints);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,300,456328,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth24getSeparationConstraintsEPNS_35PxClothParticleSeparationConstraintE($this,$separationConstraintsBuffer) {
 $this = $this|0;
 $separationConstraintsBuffer = $separationConstraintsBuffer|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore24getSeparationConstraintsEPNS_35PxClothParticleSeparationConstraintE($8,$separationConstraintsBuffer)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,310,456240,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth26getNbSeparationConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc9ClothCore26getNbSeparationConstraintsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpCloth18clearInterpolationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN5physx2Sc9ClothCore18clearInterpolationEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx7NpCloth24setParticleAccelerationsEPKNS_6PxVec4E($this,$particleAccelerations) {
 $this = $this|0;
 $particleAccelerations = $particleAccelerations|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore24setParticleAccelerationsEPKNS_6PxVec4E($8,$particleAccelerations);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,330,456152,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth24getParticleAccelerationsEPNS_6PxVec4E($this,$particleAccelerationsBuffer) {
 $this = $this|0;
 $particleAccelerationsBuffer = $particleAccelerationsBuffer|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore24getParticleAccelerationsEPNS_6PxVec4E($8,$particleAccelerationsBuffer)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,340,456064,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth26getNbParticleAccelerationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc9ClothCore26getNbParticleAccelerationsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpCloth18addCollisionSphereERKNS_22PxClothCollisionSphereE($this,$sphere) {
 $this = $this|0;
 $sphere = $sphere|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore18addCollisionSphereERKNS_22PxClothCollisionSphereE($8,$sphere);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,355,455984,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth21removeCollisionSphereEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore21removeCollisionSphereEj($8,$index);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,362,455896,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth19setCollisionSpheresEPKNS_22PxClothCollisionSphereEj($this,$spheresBuffer,$count) {
 $this = $this|0;
 $spheresBuffer = $spheresBuffer|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore19setCollisionSpheresEPKNS_22PxClothCollisionSphereEj($8,$spheresBuffer,$count);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,369,455816,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth21getNbCollisionSpheresEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore21getNbCollisionSpheresEv($8)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,377,455728,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth16getCollisionDataEPNS_22PxClothCollisionSphereEPjPNS_21PxClothCollisionPlaneES3_PNS_24PxClothCollisionTriangleE($this,$spheresBuffer,$capsulesBuffer,$planesBuffer,$convexesBuffer,$trianglesBuffer) {
 $this = $this|0;
 $spheresBuffer = $spheresBuffer|0;
 $capsulesBuffer = $capsulesBuffer|0;
 $planesBuffer = $planesBuffer|0;
 $convexesBuffer = $convexesBuffer|0;
 $trianglesBuffer = $trianglesBuffer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore16getCollisionDataEPNS_22PxClothCollisionSphereEPjPNS_21PxClothCollisionPlaneES4_PNS_24PxClothCollisionTriangleE($8,$spheresBuffer,$capsulesBuffer,$planesBuffer,$convexesBuffer,$trianglesBuffer);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,388,455648,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth19addCollisionCapsuleEjj($this,$first,$second) {
 $this = $this|0;
 $first = $first|0;
 $second = $second|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore19addCollisionCapsuleEjj($8,$first,$second);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,397,455568,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth22removeCollisionCapsuleEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore22removeCollisionCapsuleEj($8,$index);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,404,455480,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth22getNbCollisionCapsulesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore22getNbCollisionCapsulesEv($8)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,412,455392,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN5physx7NpCloth20addCollisionTriangleERKNS_24PxClothCollisionTriangleE($this,$triangle) {
 $this = $this|0;
 $triangle = $triangle|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore20addCollisionTriangleERKNS_24PxClothCollisionTriangleE($8,$triangle);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,422,455304,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth23removeCollisionTriangleEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore23removeCollisionTriangleEj($8,$index);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,429,455216,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth21setCollisionTrianglesEPKNS_24PxClothCollisionTriangleEj($this,$trianglesBuffer,$count) {
 $this = $this|0;
 $trianglesBuffer = $trianglesBuffer|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore21setCollisionTrianglesEPKNS_24PxClothCollisionTriangleEj($8,$trianglesBuffer,$count);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,436,455128,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth23getNbCollisionTrianglesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore23getNbCollisionTrianglesEv($8)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,444,455040,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN5physx7NpCloth17addCollisionPlaneERKNS_21PxClothCollisionPlaneE($this,$plane) {
 $this = $this|0;
 $plane = $plane|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore17addCollisionPlaneERKNS_21PxClothCollisionPlaneE($8,$plane);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,454,454960,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth20removeCollisionPlaneEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore20removeCollisionPlaneEj($8,$index);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,461,454872,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth18setCollisionPlanesEPKNS_21PxClothCollisionPlaneEj($this,$planesBuffer,$count) {
 $this = $this|0;
 $planesBuffer = $planesBuffer|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore18setCollisionPlanesEPKNS_21PxClothCollisionPlaneEj($8,$planesBuffer,$count);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,468,454792,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth20getNbCollisionPlanesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore20getNbCollisionPlanesEv($8)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,476,454704,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN5physx7NpCloth18addCollisionConvexEj($this,$mask) {
 $this = $this|0;
 $mask = $mask|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore18addCollisionConvexEj($8,$mask);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,486,454624,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth21removeCollisionConvexEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore21removeCollisionConvexEj($8,$index);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,493,454536,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth22getNbCollisionConvexesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore22getNbCollisionConvexesEv($8)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,501,454448,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN5physx7NpCloth19setVirtualParticlesEjPKjjPKNS_6PxVec3E($this,$numParticles,$indices,$numWeights,$weights) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indices = $indices|0;
 $numWeights = $numWeights|0;
 $weights = $weights|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore19setVirtualParticlesEjPKjjPKNS_6PxVec3E($8,$numParticles,$indices,$numWeights,$weights);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,512,454368,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth21getNbVirtualParticlesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore21getNbVirtualParticlesEv($8)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,522,454280,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth19getVirtualParticlesEPj($this,$indicesBuffer) {
 $this = $this|0;
 $indicesBuffer = $indicesBuffer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore19getVirtualParticlesEPj($8,$indicesBuffer);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,533,454200,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth27getNbVirtualParticleWeightsEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore27getNbVirtualParticleWeightsEv($8)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,543,454112,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth25getVirtualParticleWeightsEPNS_6PxVec3E($this,$weightsBuffer) {
 $this = $this|0;
 $weightsBuffer = $weightsBuffer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore25getVirtualParticleWeightsEPNS_6PxVec3E($8,$weightsBuffer);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,554,454024,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth13setGlobalPoseERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $5 = Math_fround(0), $6 = Math_fround(0);
 var $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$pose>>2]);
 $2 = Math_fround($1 * $1);
 $3 = (($pose) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $4);
 $6 = Math_fround($2 + $5);
 $7 = (($pose) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($pose) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (Math_fround(Math_sqrt((Math_fround($14)))));
 $16 = Math_fround(Math_fround(1.0) / $15);
 $17 = Math_fround($1 * $16);
 $18 = Math_fround($4 * $16);
 $19 = Math_fround($8 * $16);
 $20 = Math_fround($12 * $16);
 HEAPF32[$0>>2] = $17;
 $21 = (($0) + 4|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($0) + 8|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($0) + 12|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($0) + 16|0);
 $25 = (($pose) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 HEAPF32[$24>>2] = $26;
 $27 = (($0) + 20|0);
 $28 = (($pose) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$27>>2] = $29;
 $30 = (($0) + 24|0);
 $31 = (($pose) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$30>>2] = $32;
 $33 = (($this) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 >>> 30;
 if ((($35|0) == 3)) {
  label = 4;
 } else if ((($35|0) == 2)) {
  $36 = (($this) + 20|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 2417|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = ($39<<24>>24)==(0);
  if ($40) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $41 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore13setGlobalPoseERKNS_11PxTransformE($41,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $42 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($42,8,449328,575,453944,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth13getGlobalPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,564,453864,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  $12 = (($agg$result) + 12|0);
  HEAPF32[$12>>2] = Math_fround(1.0);
  $13 = (($agg$result) + 16|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = (($agg$result) + 20|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
  $15 = (($agg$result) + 24|0);
  HEAPF32[$15>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth13setTargetPoseERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $5 = Math_fround(0), $6 = Math_fround(0);
 var $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$pose>>2]);
 $2 = Math_fround($1 * $1);
 $3 = (($pose) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $4);
 $6 = Math_fround($2 + $5);
 $7 = (($pose) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($pose) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (Math_fround(Math_sqrt((Math_fround($14)))));
 $16 = Math_fround(Math_fround(1.0) / $15);
 $17 = Math_fround($1 * $16);
 $18 = Math_fround($4 * $16);
 $19 = Math_fround($8 * $16);
 $20 = Math_fround($12 * $16);
 HEAPF32[$0>>2] = $17;
 $21 = (($0) + 4|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($0) + 8|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($0) + 12|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($0) + 16|0);
 $25 = (($pose) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 HEAPF32[$24>>2] = $26;
 $27 = (($0) + 20|0);
 $28 = (($pose) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$27>>2] = $29;
 $30 = (($0) + 24|0);
 $31 = (($pose) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$30>>2] = $32;
 $33 = (($this) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 >>> 30;
 if ((($35|0) == 2)) {
  $36 = (($this) + 20|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 2417|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = ($39<<24>>24)==(0);
  if ($40) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($35|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $41 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore13setTargetPoseERKNS_11PxTransformE($41,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $42 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($42,8,449328,584,453784,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth23setExternalAccelerationENS_6PxVec3E($this,$acceleration) {
 $this = $this|0;
 $acceleration = $acceleration|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$acceleration>>2]);
 $2 = (($acceleration) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($acceleration) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 30;
 if ((($8|0) == 2)) {
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 2417|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($8|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = (($this) + 32|0);
  HEAPF32[$0>>2] = $1;
  $15 = (($0) + 4|0);
  HEAPF32[$15>>2] = $3;
  $16 = (($0) + 8|0);
  HEAPF32[$16>>2] = $5;
  __ZN5physx2Sc9ClothCore23setExternalAccelerationENS_6PxVec3E($14,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,449328,605,453696,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth23getExternalAccelerationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore23getExternalAccelerationEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,594,453608,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth21setLinearInertiaScaleENS_6PxVec3E($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$scale>>2]);
 $2 = (($scale) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($scale) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 30;
 if ((($8|0) == 3)) {
  label = 4;
 } else if ((($8|0) == 2)) {
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 2417|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = (($this) + 32|0);
  HEAPF32[$0>>2] = $1;
  $15 = (($0) + 4|0);
  HEAPF32[$15>>2] = $3;
  $16 = (($0) + 8|0);
  HEAPF32[$16>>2] = $5;
  __ZN5physx2Sc9ClothCore21setLinearInertiaScaleENS_6PxVec3E($14,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,449328,625,453520,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth21getLinearInertiaScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore21getLinearInertiaScaleEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,614,453432,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth22setAngularInertiaScaleENS_6PxVec3E($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$scale>>2]);
 $2 = (($scale) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($scale) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 30;
 if ((($8|0) == 3)) {
  label = 4;
 } else if ((($8|0) == 2)) {
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 2417|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = (($this) + 32|0);
  HEAPF32[$0>>2] = $1;
  $15 = (($0) + 4|0);
  HEAPF32[$15>>2] = $3;
  $16 = (($0) + 8|0);
  HEAPF32[$16>>2] = $5;
  __ZN5physx2Sc9ClothCore22setAngularInertiaScaleENS_6PxVec3E($14,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,449328,645,453344,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth22getAngularInertiaScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore22getAngularInertiaScaleEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,634,453256,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth26setCentrifugalInertiaScaleENS_6PxVec3E($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$scale>>2]);
 $2 = (($scale) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($scale) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 30;
 if ((($8|0) == 2)) {
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 2417|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($8|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = (($this) + 32|0);
  HEAPF32[$0>>2] = $1;
  $15 = (($0) + 4|0);
  HEAPF32[$15>>2] = $3;
  $16 = (($0) + 8|0);
  HEAPF32[$16>>2] = $5;
  __ZN5physx2Sc9ClothCore26setCentrifugalInertiaScaleENS_6PxVec3E($14,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,449328,665,453168,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth26getCentrifugalInertiaScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore26getCentrifugalInertiaScaleEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,654,453080,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth15setInertiaScaleEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 20|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = HEAP32[$1>>2]|0;
  $6 = (($5) + 2417|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($4|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $9 = (($this) + 32|0);
  HEAPF32[$0>>2] = $scale;
  $10 = (($0) + 4|0);
  HEAPF32[$10>>2] = $scale;
  $11 = (($0) + 8|0);
  HEAPF32[$11>>2] = $scale;
  __ZN5physx2Sc9ClothCore21setLinearInertiaScaleENS_6PxVec3E($9,$0);
 }
 else if ((label|0) == 4) {
  $12 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($12,8,449328,625,453520,$vararg_buffer1);
 }
 $13 = HEAP32[$2>>2]|0;
 $14 = $13 >>> 30;
 if ((($14|0) == 2)) {
  $15 = HEAP32[$1>>2]|0;
  $16 = (($15) + 2417|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   label = 7;
  } else {
   label = 8;
  }
 } else if ((($14|0) == 3)) {
  label = 8;
 } else {
  label = 7;
 }
 if ((label|0) == 7) {
  $19 = (($this) + 32|0);
  HEAPF32[$0>>2] = $scale;
  $20 = (($0) + 4|0);
  HEAPF32[$20>>2] = $scale;
  $21 = (($0) + 8|0);
  HEAPF32[$21>>2] = $scale;
  __ZN5physx2Sc9ClothCore22setAngularInertiaScaleENS_6PxVec3E($19,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $22 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($22,8,449328,645,453344,$vararg_buffer1);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth21setDampingCoefficientENS_6PxVec3E($this,$dampingCoefficient) {
 $this = $this|0;
 $dampingCoefficient = $dampingCoefficient|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$dampingCoefficient>>2]);
 $2 = (($dampingCoefficient) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($dampingCoefficient) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 30;
 if ((($8|0) == 3)) {
  label = 4;
 } else if ((($8|0) == 2)) {
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 2417|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = (($this) + 32|0);
  HEAPF32[$0>>2] = $1;
  $15 = (($0) + 4|0);
  HEAPF32[$15>>2] = $3;
  $16 = (($0) + 8|0);
  HEAPF32[$16>>2] = $5;
  __ZN5physx2Sc9ClothCore21setDampingCoefficientENS_6PxVec3E($14,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,449328,685,452992,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth21getDampingCoefficientEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore21getDampingCoefficientEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,674,452904,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth22setFrictionCoefficientEf($this,$frictionCoefficient) {
 $this = $this|0;
 $frictionCoefficient = Math_fround($frictionCoefficient);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore22setFrictionCoefficientEf($8,$frictionCoefficient);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,705,452816,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth22getFrictionCoefficientEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore22getFrictionCoefficientEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,694,452728,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth24setLinearDragCoefficientENS_6PxVec3E($this,$dragCoefficient) {
 $this = $this|0;
 $dragCoefficient = $dragCoefficient|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$dragCoefficient>>2]);
 $2 = (($dragCoefficient) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($dragCoefficient) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 30;
 if ((($8|0) == 3)) {
  label = 4;
 } else if ((($8|0) == 2)) {
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 2417|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = (($this) + 32|0);
  HEAPF32[$0>>2] = $1;
  $15 = (($0) + 4|0);
  HEAPF32[$15>>2] = $3;
  $16 = (($0) + 8|0);
  HEAPF32[$16>>2] = $5;
  __ZN5physx2Sc9ClothCore24setLinearDragCoefficientENS_6PxVec3E($14,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,449328,725,452640,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth24getLinearDragCoefficientEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore24getLinearDragCoefficientEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,714,452552,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth25setAngularDragCoefficientENS_6PxVec3E($this,$dragCoefficient) {
 $this = $this|0;
 $dragCoefficient = $dragCoefficient|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = Math_fround(HEAPF32[$dragCoefficient>>2]);
 $2 = (($dragCoefficient) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($dragCoefficient) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 >>> 30;
 if ((($8|0) == 2)) {
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 2417|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($8|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = (($this) + 32|0);
  HEAPF32[$0>>2] = $1;
  $15 = (($0) + 4|0);
  HEAPF32[$15>>2] = $3;
  $16 = (($0) + 8|0);
  HEAPF32[$16>>2] = $5;
  __ZN5physx2Sc9ClothCore25setAngularDragCoefficientENS_6PxVec3E($14,$0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,8,449328,745,452464,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth25getAngularDragCoefficientEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore25getAngularDragCoefficientEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,734,452376,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth18setDragCoefficientEf($this,$coefficient) {
 $this = $this|0;
 $coefficient = Math_fround($coefficient);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 184|0);
 $4 = HEAP32[$3>>2]|0;
 HEAPF32[$0>>2] = $coefficient;
 $5 = (($0) + 4|0);
 HEAPF32[$5>>2] = $coefficient;
 $6 = (($0) + 8|0);
 HEAPF32[$6>>2] = $coefficient;
 FUNCTION_TABLE_vii[$4 & 4095]($this,$0);
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 192|0);
 $9 = HEAP32[$8>>2]|0;
 HEAPF32[$1>>2] = $coefficient;
 $10 = (($1) + 4|0);
 HEAPF32[$10>>2] = $coefficient;
 $11 = (($1) + 8|0);
 HEAPF32[$11>>2] = $coefficient;
 FUNCTION_TABLE_vii[$9 & 4095]($this,$1);
 STACKTOP = sp;return;
}
function __ZN5physx7NpCloth21setCollisionMassScaleEf($this,$scalingCoefficient) {
 $this = $this|0;
 $scalingCoefficient = Math_fround($scalingCoefficient);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore21setCollisionMassScaleEf($8,$scalingCoefficient);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,763,452288,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth21getCollisionMassScaleEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore21getCollisionMassScaleEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,754,452200,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth24setSelfCollisionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore24setSelfCollisionDistanceEf($8,$distance);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,781,452112,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth24getSelfCollisionDistanceEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore24getSelfCollisionDistanceEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,772,452024,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth25setSelfCollisionStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore25setSelfCollisionStiffnessEf($8,$stiffness);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,798,451936,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth25getSelfCollisionStiffnessEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore25getSelfCollisionStiffnessEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,789,451848,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth23setSelfCollisionIndicesEPKjj($this,$indices,$nbIndices) {
 $this = $this|0;
 $indices = $indices|0;
 $nbIndices = $nbIndices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore23setSelfCollisionIndicesEPKjj($8,$indices,$nbIndices);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,806,451760,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth23getSelfCollisionIndicesEPj($this,$indices) {
 $this = $this|0;
 $indices = $indices|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore23getSelfCollisionIndicesEPj($8,$indices)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,815,451672,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth25getNbSelfCollisionIndicesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc9ClothCore25getNbSelfCollisionIndicesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpCloth16setRestPositionsEPKNS_6PxVec4E($this,$restPositions) {
 $this = $this|0;
 $restPositions = $restPositions|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore16setRestPositionsEPKNS_6PxVec4E($8,$restPositions);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,831,451592,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth16getRestPositionsEPNS_6PxVec4E($this,$restPositions) {
 $this = $this|0;
 $restPositions = $restPositions|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore16getRestPositionsEPNS_6PxVec4E($8,$restPositions)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,840,451512,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth18getNbRestPositionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (__ZNK5physx2Sc9ClothCore18getNbRestPositionsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpCloth18setSolverFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore18setSolverFrequencyEf($8,$frequency);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,867,451432,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth18getSolverFrequencyEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore18getSolverFrequencyEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,856,451352,$vararg_buffer);
  $$0$i = Math_fround(60.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth21setStiffnessFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore21setStiffnessFrequencyEf($8,$frequency);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,887,451264,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth21getStiffnessFrequencyEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore21getStiffnessFrequencyEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,876,451176,$vararg_buffer);
  $$0$i = Math_fround(60.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth16setStretchConfigENS_22PxClothFabricPhaseType4EnumERKNS_20PxClothStretchConfigE($this,$type,$config) {
 $this = $this|0;
 $type = $type|0;
 $config = $config|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore16setStretchConfigENS_22PxClothFabricPhaseType4EnumERKNS_20PxClothStretchConfigE($8,$type,$config);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,896,451096,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth15setTetherConfigERKNS_19PxClothTetherConfigE($this,$config) {
 $this = $this|0;
 $config = $config|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore15setTetherConfigERKNS_19PxClothTetherConfigE($8,$config);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,904,451016,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth16getStretchConfigENS_22PxClothFabricPhaseType4EnumE($agg$result,$this,$type) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore16getStretchConfigENS_22PxClothFabricPhaseType4EnumE($agg$result,$8,$type);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,913,450936,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(1.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(1.0);
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = Math_fround(1.0);
  $12 = (($agg$result) + 12|0);
  HEAPF32[$12>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth15getTetherConfigEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore15getTetherConfigEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,924,450856,$vararg_buffer);
  HEAPF32[$agg$result>>2] = Math_fround(1.0);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth13setClothFlagsENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer3 = sp;
 $0 = (($this) + 24|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 20|0);
 $3 = HEAP16[$flags>>1]|0;
 $4 = $3 & 1;
 $5 = ($4<<16>>16)!=(0);
 $6 = HEAP32[$0>>2]|0;
 $7 = $6 >>> 30;
 if ((($7|0) == 2)) {
  $8 = HEAP32[$2>>2]|0;
  $9 = (($8) + 2417|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($7|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  __ZN5physx2Sc9ClothCore12setClothFlagENS_11PxClothFlag4EnumEb($1,1,$5);
 }
 else if ((label|0) == 4) {
  $12 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($12,8,449328,946,450776,$vararg_buffer3);
 }
 $13 = HEAP16[$flags>>1]|0;
 $14 = $13 & 2;
 $15 = ($14<<16>>16)!=(0);
 $16 = HEAP32[$0>>2]|0;
 $17 = $16 >>> 30;
 if ((($17|0) == 2)) {
  $18 = HEAP32[$2>>2]|0;
  $19 = (($18) + 2417|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 8;
  } else {
   label = 7;
  }
 } else if ((($17|0) == 3)) {
  label = 7;
 } else {
  label = 8;
 }
 if ((label|0) == 7) {
  $22 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($22,8,449328,946,450776,$vararg_buffer3);
 }
 else if ((label|0) == 8) {
  __ZN5physx2Sc9ClothCore12setClothFlagENS_11PxClothFlag4EnumEb($1,2,$15);
 }
 $23 = HEAP16[$flags>>1]|0;
 $24 = $23 & 4;
 $25 = ($24<<16>>16)!=(0);
 $26 = HEAP32[$0>>2]|0;
 $27 = $26 >>> 30;
 if ((($27|0) == 2)) {
  $28 = HEAP32[$2>>2]|0;
  $29 = (($28) + 2417|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   label = 12;
  } else {
   label = 11;
  }
 } else if ((($27|0) == 3)) {
  label = 11;
 } else {
  label = 12;
 }
 if ((label|0) == 11) {
  $32 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($32,8,449328,946,450776,$vararg_buffer3);
  (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  __ZN5physx2Sc9ClothCore12setClothFlagENS_11PxClothFlag4EnumEb($1,4,$25);
  (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth12setClothFlagENS_11PxClothFlag4EnumEb($this,$flag,$val) {
 $this = $this|0;
 $flag = $flag|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore12setClothFlagENS_11PxClothFlag4EnumEb($8,$flag,$val);
  (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,946,450776,$vararg_buffer);
  (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth13getClothFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore13getClothFlagsEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,935,450696,$vararg_buffer);
  HEAP16[$agg$result>>1] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth10isSleepingEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (__ZNK5physx2Sc9ClothCore10isSleepingEv($8)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,956,450624,$vararg_buffer);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth22getSleepLinearVelocityEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore22getSleepLinearVelocityEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,968,450536,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth22setSleepLinearVelocityEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore22setSleepLinearVelocityEf($8,$threshold);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,979,450448,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth14setWakeCounterEf($this,$wakeCounterValue) {
 $this = $this|0;
 $wakeCounterValue = Math_fround($wakeCounterValue);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore14setWakeCounterEf($8,$wakeCounterValue);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,988,450368,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth14getWakeCounterEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore14getWakeCounterEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,998,450288,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth6wakeUpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 30;
 if ((($4|0) == 2)) {
  $5 = (($1) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($4|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (($1) + 2844|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  __ZN5physx2Sc9ClothCore6wakeUpEf($8,$10);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $11 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($11,8,449328,1012,450216,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth10putToSleepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore10putToSleepEv($8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,1021,450144,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth16lockParticleDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 128|0);
 $2 = HEAP8[$flags>>0]|0;
 HEAP8[$0>>0] = $2;
 $3 = (__ZN5physx19NpClothParticleData7tryLockENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($1,$0)|0);
 if (!($3)) {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,8,447584,921,447664,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 >>> 30;
 if ((($7|0) == 2)) {
  $8 = (($this) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 2417|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   label = 5;
  } else {
   label = 6;
  }
 } else if ((($7|0) == 3)) {
  label = 6;
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $13 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore15getParticleDataERNS_19PxClothParticleDataE($13,$1);
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 6) {
  $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,8,449328,1030,450064,$vararg_buffer1);
  $15 = (($this) + 132|0);
  HEAP32[$15>>2] = 0;
  $16 = (($this) + 136|0);
  HEAP32[$16>>2] = 0;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx7NpCloth16lockParticleDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP8[$0>>0] = 1;
 $4 = (FUNCTION_TABLE_iii[$3 & 4095]($this,$0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx7NpCloth18unlockParticleDataEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN5physx2Sc9ClothCore18unlockParticleDataEv($0);
 STACKTOP = sp;return;
}
function __ZNK5physx7NpCloth19getPreviousTimeStepEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore19getPreviousTimeStepEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,1044,449984,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZNK5physx7NpCloth14getWorldBoundsEf($agg$result,$this,$inflation) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inflation = Math_fround($inflation);
 var $$phi$trans$insert1 = 0, $$phi$trans$insert3 = 0, $$phi$trans$insert5 = 0, $$phi$trans$insert7 = 0, $$phi$trans$insert9 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre2 = Math_fround(0), $$pre4 = Math_fround(0), $$pre6 = Math_fround(0), $$pre8 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0);
 var $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bounds = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $bounds = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore14getWorldBoundsEv($bounds,$8);
  $$pre = Math_fround(HEAPF32[$bounds>>2]);
  $$phi$trans$insert1 = (($bounds) + 12|0);
  $$pre2 = Math_fround(HEAPF32[$$phi$trans$insert1>>2]);
  $$phi$trans$insert3 = (($bounds) + 4|0);
  $$pre4 = Math_fround(HEAPF32[$$phi$trans$insert3>>2]);
  $$phi$trans$insert5 = (($bounds) + 16|0);
  $$pre6 = Math_fround(HEAPF32[$$phi$trans$insert5>>2]);
  $$phi$trans$insert7 = (($bounds) + 8|0);
  $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
  $$phi$trans$insert9 = (($bounds) + 20|0);
  $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert9>>2]);
  $16 = $$pre2;$17 = $$pre;$19 = $$pre6;$20 = $$pre4;$22 = $$pre10;$23 = $$pre8;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,1056,449904,$vararg_buffer);
  HEAPF32[$bounds>>2] = Math_fround(8.50705866596322149529E+37);
  $10 = (($bounds) + 4|0);
  HEAPF32[$10>>2] = Math_fround(8.50705866596322149529E+37);
  $11 = (($bounds) + 8|0);
  HEAPF32[$11>>2] = Math_fround(8.50705866596322149529E+37);
  $12 = (($bounds) + 12|0);
  HEAPF32[$12>>2] = Math_fround(-8.50705866596322149529E+37);
  $13 = (($bounds) + 16|0);
  HEAPF32[$13>>2] = Math_fround(-8.50705866596322149529E+37);
  $14 = (($bounds) + 20|0);
  HEAPF32[$14>>2] = Math_fround(-8.50705866596322149529E+37);
  $16 = Math_fround(-8.50705866596322149529E+37);$17 = Math_fround(8.50705866596322149529E+37);$19 = Math_fround(-8.50705866596322149529E+37);$20 = Math_fround(8.50705866596322149529E+37);$22 = Math_fround(-8.50705866596322149529E+37);$23 = Math_fround(8.50705866596322149529E+37);
 }
 $15 = Math_fround($17 + $16);
 $18 = Math_fround($20 + $19);
 $21 = Math_fround($23 + $22);
 $24 = Math_fround($15 * Math_fround(0.5));
 $25 = Math_fround($18 * Math_fround(0.5));
 $26 = Math_fround($21 * Math_fround(0.5));
 $27 = Math_fround($16 - $17);
 $28 = Math_fround($19 - $20);
 $29 = Math_fround($22 - $23);
 $30 = Math_fround($27 * Math_fround(0.5));
 $31 = Math_fround($28 * Math_fround(0.5));
 $32 = Math_fround($29 * Math_fround(0.5));
 $33 = Math_fround($30 * $inflation);
 $34 = Math_fround($31 * $inflation);
 $35 = Math_fround($32 * $inflation);
 $36 = Math_fround($24 - $33);
 $37 = Math_fround($25 - $34);
 $38 = Math_fround($26 - $35);
 $39 = Math_fround($24 + $33);
 $40 = Math_fround($25 + $34);
 $41 = Math_fround($26 + $35);
 HEAPF32[$agg$result>>2] = $36;
 $42 = (($agg$result) + 4|0);
 HEAPF32[$42>>2] = $37;
 $43 = (($agg$result) + 8|0);
 HEAPF32[$43>>2] = $38;
 $44 = (($agg$result) + 12|0);
 HEAPF32[$44>>2] = $39;
 $45 = (($agg$result) + 16|0);
 HEAPF32[$45>>2] = $40;
 $46 = (($agg$result) + 20|0);
 HEAPF32[$46>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN5physx7NpCloth23setSimulationFilterDataERKNS_12PxFilterDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore23setSimulationFilterDataERKNS_12PxFilterDataE($8,$data);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,1066,449816,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth23getSimulationFilterDataEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZNK5physx2Sc9ClothCore23getSimulationFilterDataEv($agg$result,$8);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,1075,449728,$vararg_buffer);
  ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx7NpCloth16setContactOffsetEf($this,$offset) {
 $this = $this|0;
 $offset = Math_fround($offset);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore16setContactOffsetEf($8,$offset);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,1085,449648,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth16getContactOffsetEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 3)) {
  label = 4;
 } else if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore16getContactOffsetEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,1094,449568,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth13setRestOffsetEf($this,$offset) {
 $this = $this|0;
 $offset = Math_fround($offset);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  __ZN5physx2Sc9ClothCore13setRestOffsetEf($8,$offset);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 4) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,8,449328,1104,449488,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx7NpCloth13getRestOffsetEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 30;
 if ((($2|0) == 2)) {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 2417|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   label = 3;
  } else {
   label = 4;
  }
 } else if ((($2|0) == 3)) {
  label = 4;
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $8 = (($this) + 32|0);
  $9 = (Math_fround(__ZNK5physx2Sc9ClothCore13getRestOffsetEv($8)));
  $$0$i = $9;
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 else if ((label|0) == 4) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,449328,1113,449408,$vararg_buffer);
  $$0$i = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0$i));
 }
 return Math_fround(0);
}
function __ZN5physx7NpCloth9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE($this,$out,$scene) {
 $this = $this|0;
 $out = $out|0;
 $scene = $scene|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0);
 var $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0;
 var $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $colorIndex$023 = 0, $colorIndex$1 = 0, $exitcond = 0, $exitcond27 = 0, $i$016 = 0, $iIt$017 = 0, $indices = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i4 = 0, $or$cond$i$i6 = 0, $p$021 = 0, $phases = 0, $scale$0 = Math_fround(0);
 var $sets = 0, $vpIndices = 0, $vpWeights = 0, $xform = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $sets = sp + 144|0;
 $0 = sp + 140|0;
 $phases = sp + 128|0;
 $1 = sp + 120|0;
 $indices = sp + 108|0;
 $2 = sp + 104|0;
 $xform = sp + 76|0;
 $3 = sp + 64|0;
 $4 = sp + 40|0;
 $vpIndices = sp + 28|0;
 $5 = sp + 24|0;
 $vpWeights = sp + 12|0;
 $6 = sp;
 $7 = sp + 52|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 96|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 84|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($this)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
 $21 = HEAP32[$16>>2]|0;
 $22 = (($21) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 4095]($16)|0);
 $25 = HEAP32[$16>>2]|0;
 $26 = (($25) + 40|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (FUNCTION_TABLE_ii[$27 & 4095]($16)|0);
 HEAP32[$0>>2] = 0;
 HEAP32[$sets>>2] = 0;
 $29 = (($sets) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($sets) + 8|0);
 HEAP32[$30>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($sets,$20,$0);
 HEAP32[$1>>2] = 0;
 $31 = (($1) + 4|0);
 HEAP32[$31>>2] = 0;
 HEAP32[$phases>>2] = 0;
 $32 = (($phases) + 4|0);
 HEAP32[$32>>2] = 0;
 $33 = (($phases) + 8|0);
 HEAP32[$33>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_18PxClothFabricPhaseENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($phases,$24,$1);
 HEAP32[$2>>2] = 0;
 HEAP32[$indices>>2] = 0;
 $34 = (($indices) + 4|0);
 HEAP32[$34>>2] = 0;
 $35 = (($indices) + 8|0);
 HEAP32[$35>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($indices,$28,$2);
 $36 = HEAP32[$16>>2]|0;
 $37 = (($36) + 52|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$sets>>2]|0;
 (FUNCTION_TABLE_iiii[$38 & 2047]($16,$39,$20)|0);
 $40 = HEAP32[$16>>2]|0;
 $41 = (($40) + 48|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$phases>>2]|0;
 (FUNCTION_TABLE_iiii[$42 & 2047]($16,$43,$24)|0);
 $44 = HEAP32[$16>>2]|0;
 $45 = (($44) + 56|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$indices>>2]|0;
 (FUNCTION_TABLE_iiii[$46 & 2047]($16,$47,$28)|0);
 $48 = (($11) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$this>>2]|0;
 $51 = (($50) + 124|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095]($xform,$this);
 (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,1)|0);
 $53 = ($24|0)==(0);
 if ($53) {
  $$pre$phiZ2D = $scene;
 } else {
  $54 = (($xform) + 12|0);
  $55 = (($xform) + 4|0);
  $56 = (($xform) + 8|0);
  $57 = (($xform) + 16|0);
  $58 = (($xform) + 20|0);
  $59 = (($xform) + 24|0);
  $60 = (($3) + 4|0);
  $61 = (($3) + 8|0);
  $62 = (($4) + 4|0);
  $63 = (($4) + 8|0);
  $colorIndex$023 = 0;$p$021 = 0;
  while(1) {
   $64 = HEAP32[$16>>2]|0;
   $65 = (($64) + 72|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (FUNCTION_TABLE_iii[$66 & 4095]($16,$p$021)|0);
   if ((($67|0) == 1)) {
    $68 = HEAP32[$scene>>2]|0;
    $69 = (($68) + 296|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (Math_fround(FUNCTION_TABLE_fii[$70 & 63]($scene,31)));
    $scale$0 = $71;
    label = 10;
   } else if ((($67|0) == 3)) {
    $76 = HEAP32[$scene>>2]|0;
    $77 = (($76) + 296|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (Math_fround(FUNCTION_TABLE_fii[$78 & 63]($scene,33)));
    $scale$0 = $79;
    label = 10;
   } else if ((($67|0) == 4)) {
    $80 = HEAP32[$scene>>2]|0;
    $81 = (($80) + 296|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (Math_fround(FUNCTION_TABLE_fii[$82 & 63]($scene,34)));
    $scale$0 = $83;
    label = 10;
   } else if ((($67|0) == 2)) {
    $72 = HEAP32[$scene>>2]|0;
    $73 = (($72) + 296|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (Math_fround(FUNCTION_TABLE_fii[$74 & 63]($scene,32)));
    $scale$0 = $75;
    label = 10;
   } else {
    $colorIndex$1 = $colorIndex$023;
   }
   if ((label|0) == 10) {
    label = 0;
    $84 = $scale$0 == Math_fround(0.0);
    if ($84) {
     $colorIndex$1 = $colorIndex$023;
    } else {
     $85 = (447768 + ($colorIndex$023<<2)|0);
     $86 = HEAP32[$85>>2]|0;
     (__ZN5physx2Cm12RenderOutputlsEj($out,$86)|0);
     $87 = ((($43) + ($p$021<<3)|0) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ($88|0)==(0);
     if ($89) {
      $98 = 0;
     } else {
      $90 = (($88) + -1)|0;
      $91 = (($39) + ($90<<2)|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = $92 << 1;
      $98 = $93;
     }
     $94 = (($39) + ($88<<2)|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = $95 << 1;
     $97 = ($98>>>0)<($96>>>0);
     if ($97) {
      $iIt$017 = $98;
      while(1) {
       $99 = $iIt$017 | 1;
       $100 = (($47) + ($iIt$017<<2)|0);
       $101 = HEAP32[$100>>2]|0;
       $102 = (($iIt$017) + 2)|0;
       $103 = (($47) + ($99<<2)|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = (($49) + ($101<<4)|0);
       $106 = Math_fround(HEAPF32[$105>>2]);
       $107 = Math_fround($106 * Math_fround(2.0));
       $108 = ((($49) + ($101<<4)|0) + 4|0);
       $109 = Math_fround(HEAPF32[$108>>2]);
       $110 = Math_fround($109 * Math_fround(2.0));
       $111 = ((($49) + ($101<<4)|0) + 8|0);
       $112 = Math_fround(HEAPF32[$111>>2]);
       $113 = Math_fround($112 * Math_fround(2.0));
       $114 = Math_fround(HEAPF32[$54>>2]);
       $115 = Math_fround($114 * $114);
       $116 = Math_fround($115 + Math_fround(-0.5));
       $117 = Math_fround(HEAPF32[$xform>>2]);
       $118 = Math_fround($107 * $117);
       $119 = Math_fround(HEAPF32[$55>>2]);
       $120 = Math_fround($110 * $119);
       $121 = Math_fround($118 + $120);
       $122 = Math_fround(HEAPF32[$56>>2]);
       $123 = Math_fround($113 * $122);
       $124 = Math_fround($121 + $123);
       $125 = Math_fround($107 * $116);
       $126 = Math_fround($113 * $119);
       $127 = Math_fround($110 * $122);
       $128 = Math_fround($126 - $127);
       $129 = Math_fround($114 * $128);
       $130 = Math_fround($125 + $129);
       $131 = Math_fround($117 * $124);
       $132 = Math_fround($131 + $130);
       $133 = Math_fround($110 * $116);
       $134 = Math_fround($107 * $122);
       $135 = Math_fround($113 * $117);
       $136 = Math_fround($134 - $135);
       $137 = Math_fround($114 * $136);
       $138 = Math_fround($133 + $137);
       $139 = Math_fround($119 * $124);
       $140 = Math_fround($139 + $138);
       $141 = Math_fround($113 * $116);
       $142 = Math_fround($110 * $117);
       $143 = Math_fround($107 * $119);
       $144 = Math_fround($142 - $143);
       $145 = Math_fround($114 * $144);
       $146 = Math_fround($141 + $145);
       $147 = Math_fround($122 * $124);
       $148 = Math_fround($146 + $147);
       $149 = Math_fround(HEAPF32[$57>>2]);
       $150 = Math_fround($149 + $132);
       $151 = Math_fround(HEAPF32[$58>>2]);
       $152 = Math_fround($151 + $140);
       $153 = Math_fround(HEAPF32[$59>>2]);
       $154 = Math_fround($153 + $148);
       HEAPF32[$3>>2] = $150;
       HEAPF32[$60>>2] = $152;
       HEAPF32[$61>>2] = $154;
       (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$3)|0);
       $155 = (($49) + ($104<<4)|0);
       $156 = Math_fround(HEAPF32[$155>>2]);
       $157 = Math_fround($156 * Math_fround(2.0));
       $158 = ((($49) + ($104<<4)|0) + 4|0);
       $159 = Math_fround(HEAPF32[$158>>2]);
       $160 = Math_fround($159 * Math_fround(2.0));
       $161 = ((($49) + ($104<<4)|0) + 8|0);
       $162 = Math_fround(HEAPF32[$161>>2]);
       $163 = Math_fround($162 * Math_fround(2.0));
       $164 = Math_fround(HEAPF32[$54>>2]);
       $165 = Math_fround($164 * $164);
       $166 = Math_fround($165 + Math_fround(-0.5));
       $167 = Math_fround(HEAPF32[$xform>>2]);
       $168 = Math_fround($157 * $167);
       $169 = Math_fround(HEAPF32[$55>>2]);
       $170 = Math_fround($160 * $169);
       $171 = Math_fround($168 + $170);
       $172 = Math_fround(HEAPF32[$56>>2]);
       $173 = Math_fround($163 * $172);
       $174 = Math_fround($171 + $173);
       $175 = Math_fround($157 * $166);
       $176 = Math_fround($163 * $169);
       $177 = Math_fround($160 * $172);
       $178 = Math_fround($176 - $177);
       $179 = Math_fround($164 * $178);
       $180 = Math_fround($175 + $179);
       $181 = Math_fround($167 * $174);
       $182 = Math_fround($181 + $180);
       $183 = Math_fround($160 * $166);
       $184 = Math_fround($157 * $172);
       $185 = Math_fround($163 * $167);
       $186 = Math_fround($184 - $185);
       $187 = Math_fround($164 * $186);
       $188 = Math_fround($183 + $187);
       $189 = Math_fround($169 * $174);
       $190 = Math_fround($189 + $188);
       $191 = Math_fround($163 * $166);
       $192 = Math_fround($160 * $167);
       $193 = Math_fround($157 * $169);
       $194 = Math_fround($192 - $193);
       $195 = Math_fround($164 * $194);
       $196 = Math_fround($191 + $195);
       $197 = Math_fround($172 * $174);
       $198 = Math_fround($196 + $197);
       $199 = Math_fround(HEAPF32[$57>>2]);
       $200 = Math_fround($199 + $182);
       $201 = Math_fround(HEAPF32[$58>>2]);
       $202 = Math_fround($201 + $190);
       $203 = Math_fround(HEAPF32[$59>>2]);
       $204 = Math_fround($203 + $198);
       HEAPF32[$4>>2] = $200;
       HEAPF32[$62>>2] = $202;
       HEAPF32[$63>>2] = $204;
       (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$4)|0);
       $205 = ($102>>>0)<($96>>>0);
       if ($205) {
        $iIt$017 = $102;
       } else {
        break;
       }
      }
     }
     $206 = (($colorIndex$023) + 1)|0;
     $207 = (($206>>>0) % 5)&-1;
     $colorIndex$1 = $207;
    }
   }
   $208 = (($p$021) + 1)|0;
   $exitcond27 = ($208|0)==($24|0);
   if ($exitcond27) {
    $$pre$phiZ2D = $scene;
    break;
   } else {
    $colorIndex$023 = $colorIndex$1;$p$021 = $208;
   }
  }
 }
 $209 = HEAP32[$$pre$phiZ2D>>2]|0;
 $210 = (($209) + 296|0);
 $211 = HEAP32[$210>>2]|0;
 $212 = (Math_fround(FUNCTION_TABLE_fii[$211 & 63]($scene,35)));
 $213 = $212 > Math_fround(0.0);
 if ($213) {
  $214 = HEAP32[$this>>2]|0;
  $215 = (($214) + 356|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = (FUNCTION_TABLE_ii[$216 & 4095]($this)|0);
  $218 = ($217|0)==(0);
  if (!($218)) {
   (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,0)|0);
   (__ZN5physx2Cm12RenderOutputlsEj($out,-1)|0);
   $219 = $217 << 2;
   HEAP32[$5>>2] = 0;
   HEAP32[$vpIndices>>2] = 0;
   $220 = (($vpIndices) + 4|0);
   HEAP32[$220>>2] = 0;
   $221 = (($vpIndices) + 8|0);
   HEAP32[$221>>2] = 0;
   __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($vpIndices,$219,$5);
   $222 = HEAP32[$this>>2]|0;
   $223 = (($222) + 360|0);
   $224 = HEAP32[$223>>2]|0;
   $225 = HEAP32[$vpIndices>>2]|0;
   FUNCTION_TABLE_vii[$224 & 4095]($this,$225);
   $226 = HEAP32[$this>>2]|0;
   $227 = (($226) + 364|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = (FUNCTION_TABLE_ii[$228 & 4095]($this)|0);
   HEAP32[$vpWeights>>2] = 0;
   $230 = (($vpWeights) + 4|0);
   HEAP32[$230>>2] = 0;
   $231 = (($vpWeights) + 8|0);
   HEAP32[$231>>2] = 0;
   __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($vpWeights,$229,$6);
   $232 = HEAP32[$this>>2]|0;
   $233 = (($232) + 368|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = HEAP32[$vpWeights>>2]|0;
   FUNCTION_TABLE_vii[$234 & 4095]($this,$235);
   $236 = (($xform) + 12|0);
   $237 = (($xform) + 4|0);
   $238 = (($xform) + 8|0);
   $239 = (($xform) + 16|0);
   $240 = (($xform) + 20|0);
   $241 = (($xform) + 24|0);
   $242 = (($7) + 4|0);
   $243 = (($7) + 8|0);
   $i$016 = 0;
   while(1) {
    $244 = $i$016 << 2;
    $245 = (($225) + ($244<<2)|0);
    $246 = HEAP32[$245>>2]|0;
    $247 = $244 | 1;
    $248 = (($225) + ($247<<2)|0);
    $249 = HEAP32[$248>>2]|0;
    $250 = $244 | 2;
    $251 = (($225) + ($250<<2)|0);
    $252 = HEAP32[$251>>2]|0;
    $253 = HEAP32[$48>>2]|0;
    $254 = (($253) + ($246<<4)|0);
    $255 = Math_fround(HEAPF32[$254>>2]);
    $256 = Math_fround($255 * Math_fround(2.0));
    $257 = ((($253) + ($246<<4)|0) + 4|0);
    $258 = Math_fround(HEAPF32[$257>>2]);
    $259 = Math_fround($258 * Math_fround(2.0));
    $260 = ((($253) + ($246<<4)|0) + 8|0);
    $261 = Math_fround(HEAPF32[$260>>2]);
    $262 = Math_fround($261 * Math_fround(2.0));
    $263 = Math_fround(HEAPF32[$236>>2]);
    $264 = Math_fround($263 * $263);
    $265 = Math_fround($264 + Math_fround(-0.5));
    $266 = Math_fround(HEAPF32[$xform>>2]);
    $267 = Math_fround($256 * $266);
    $268 = Math_fround(HEAPF32[$237>>2]);
    $269 = Math_fround($259 * $268);
    $270 = Math_fround($267 + $269);
    $271 = Math_fround(HEAPF32[$238>>2]);
    $272 = Math_fround($262 * $271);
    $273 = Math_fround($270 + $272);
    $274 = Math_fround($256 * $265);
    $275 = Math_fround($262 * $268);
    $276 = Math_fround($259 * $271);
    $277 = Math_fround($275 - $276);
    $278 = Math_fround($263 * $277);
    $279 = Math_fround($274 + $278);
    $280 = Math_fround($266 * $273);
    $281 = Math_fround($280 + $279);
    $282 = Math_fround($259 * $265);
    $283 = Math_fround($256 * $271);
    $284 = Math_fround($262 * $266);
    $285 = Math_fround($283 - $284);
    $286 = Math_fround($263 * $285);
    $287 = Math_fround($282 + $286);
    $288 = Math_fround($268 * $273);
    $289 = Math_fround($288 + $287);
    $290 = Math_fround($262 * $265);
    $291 = Math_fround($259 * $266);
    $292 = Math_fround($256 * $268);
    $293 = Math_fround($291 - $292);
    $294 = Math_fround($263 * $293);
    $295 = Math_fround($290 + $294);
    $296 = Math_fround($271 * $273);
    $297 = Math_fround($295 + $296);
    $298 = Math_fround(HEAPF32[$239>>2]);
    $299 = Math_fround($298 + $281);
    $300 = Math_fround(HEAPF32[$240>>2]);
    $301 = Math_fround($300 + $289);
    $302 = Math_fround(HEAPF32[$241>>2]);
    $303 = Math_fround($302 + $297);
    $304 = (($253) + ($249<<4)|0);
    $305 = Math_fround(HEAPF32[$304>>2]);
    $306 = Math_fround($305 * Math_fround(2.0));
    $307 = ((($253) + ($249<<4)|0) + 4|0);
    $308 = Math_fround(HEAPF32[$307>>2]);
    $309 = Math_fround($308 * Math_fround(2.0));
    $310 = ((($253) + ($249<<4)|0) + 8|0);
    $311 = Math_fround(HEAPF32[$310>>2]);
    $312 = Math_fround($311 * Math_fround(2.0));
    $313 = Math_fround($266 * $306);
    $314 = Math_fround($268 * $309);
    $315 = Math_fround($313 + $314);
    $316 = Math_fround($271 * $312);
    $317 = Math_fround($315 + $316);
    $318 = Math_fround($265 * $306);
    $319 = Math_fround($268 * $312);
    $320 = Math_fround($271 * $309);
    $321 = Math_fround($319 - $320);
    $322 = Math_fround($263 * $321);
    $323 = Math_fround($318 + $322);
    $324 = Math_fround($266 * $317);
    $325 = Math_fround($324 + $323);
    $326 = Math_fround($265 * $309);
    $327 = Math_fround($271 * $306);
    $328 = Math_fround($266 * $312);
    $329 = Math_fround($327 - $328);
    $330 = Math_fround($263 * $329);
    $331 = Math_fround($326 + $330);
    $332 = Math_fround($268 * $317);
    $333 = Math_fround($332 + $331);
    $334 = Math_fround($265 * $312);
    $335 = Math_fround($266 * $309);
    $336 = Math_fround($268 * $306);
    $337 = Math_fround($335 - $336);
    $338 = Math_fround($263 * $337);
    $339 = Math_fround($334 + $338);
    $340 = Math_fround($271 * $317);
    $341 = Math_fround($339 + $340);
    $342 = Math_fround($298 + $325);
    $343 = Math_fround($300 + $333);
    $344 = Math_fround($302 + $341);
    $345 = (($253) + ($252<<4)|0);
    $346 = Math_fround(HEAPF32[$345>>2]);
    $347 = Math_fround($346 * Math_fround(2.0));
    $348 = ((($253) + ($252<<4)|0) + 4|0);
    $349 = Math_fround(HEAPF32[$348>>2]);
    $350 = Math_fround($349 * Math_fround(2.0));
    $351 = ((($253) + ($252<<4)|0) + 8|0);
    $352 = Math_fround(HEAPF32[$351>>2]);
    $353 = Math_fround($352 * Math_fround(2.0));
    $354 = Math_fround($266 * $347);
    $355 = Math_fround($268 * $350);
    $356 = Math_fround($354 + $355);
    $357 = Math_fround($271 * $353);
    $358 = Math_fround($356 + $357);
    $359 = Math_fround($265 * $347);
    $360 = Math_fround($268 * $353);
    $361 = Math_fround($271 * $350);
    $362 = Math_fround($360 - $361);
    $363 = Math_fround($263 * $362);
    $364 = Math_fround($359 + $363);
    $365 = Math_fround($266 * $358);
    $366 = Math_fround($365 + $364);
    $367 = Math_fround($265 * $350);
    $368 = Math_fround($271 * $347);
    $369 = Math_fround($266 * $353);
    $370 = Math_fround($368 - $369);
    $371 = Math_fround($263 * $370);
    $372 = Math_fround($367 + $371);
    $373 = Math_fround($268 * $358);
    $374 = Math_fround($373 + $372);
    $375 = Math_fround($265 * $353);
    $376 = Math_fround($266 * $350);
    $377 = Math_fround($268 * $347);
    $378 = Math_fround($376 - $377);
    $379 = Math_fround($263 * $378);
    $380 = Math_fround($375 + $379);
    $381 = Math_fround($271 * $358);
    $382 = Math_fround($380 + $381);
    $383 = Math_fround($298 + $366);
    $384 = Math_fround($300 + $374);
    $385 = Math_fround($302 + $382);
    $386 = $244 | 3;
    $387 = (($225) + ($386<<2)|0);
    $388 = HEAP32[$387>>2]|0;
    $389 = (($235) + (($388*12)|0)|0);
    $390 = Math_fround(HEAPF32[$389>>2]);
    $391 = ((($235) + (($388*12)|0)|0) + 4|0);
    $392 = Math_fround(HEAPF32[$391>>2]);
    $393 = ((($235) + (($388*12)|0)|0) + 8|0);
    $394 = Math_fround(HEAPF32[$393>>2]);
    $395 = Math_fround($299 * $390);
    $396 = Math_fround($301 * $390);
    $397 = Math_fround($303 * $390);
    $398 = Math_fround($342 * $392);
    $399 = Math_fround($343 * $392);
    $400 = Math_fround($344 * $392);
    $401 = Math_fround($395 + $398);
    $402 = Math_fround($396 + $399);
    $403 = Math_fround($397 + $400);
    $404 = Math_fround($394 * $383);
    $405 = Math_fround($394 * $384);
    $406 = Math_fround($394 * $385);
    $407 = Math_fround($401 + $404);
    $408 = Math_fround($402 + $405);
    $409 = Math_fround($403 + $406);
    HEAPF32[$7>>2] = $407;
    HEAPF32[$242>>2] = $408;
    HEAPF32[$243>>2] = $409;
    (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$7)|0);
    $410 = (($i$016) + 1)|0;
    $exitcond = ($410|0)==($217|0);
    if ($exitcond) {
     break;
    } else {
     $i$016 = $410;
    }
   }
   $411 = HEAP32[$231>>2]|0;
   $412 = $411 & 2147483647;
   $413 = ($412|0)!=(0);
   $414 = ($411|0)>(-1);
   $or$cond$i$i6 = $413 & $414;
   if ($or$cond$i$i6) {
    $415 = HEAP32[$vpWeights>>2]|0;
    $416 = ($415|0)==(0|0);
    if (!($416)) {
     $417 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $418 = HEAP32[$417>>2]|0;
     $419 = (($418) + 12|0);
     $420 = HEAP32[$419>>2]|0;
     FUNCTION_TABLE_vii[$420 & 4095]($417,$415);
    }
   }
   $421 = HEAP32[$221>>2]|0;
   $422 = $421 & 2147483647;
   $423 = ($422|0)!=(0);
   $424 = ($421|0)>(-1);
   $or$cond$i$i4 = $423 & $424;
   if ($or$cond$i$i4) {
    $425 = HEAP32[$vpIndices>>2]|0;
    $426 = ($425|0)==(0|0);
    if (!($426)) {
     $427 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $428 = HEAP32[$427>>2]|0;
     $429 = (($428) + 12|0);
     $430 = HEAP32[$429>>2]|0;
     FUNCTION_TABLE_vii[$430 & 4095]($427,$425);
    }
   }
  }
 }
 $431 = HEAP32[$11>>2]|0;
 $432 = (($431) + 4|0);
 $433 = HEAP32[$432>>2]|0;
 FUNCTION_TABLE_vi[$433 & 4095]($11);
 $434 = HEAP32[$35>>2]|0;
 $435 = $434 & 2147483647;
 $436 = ($435|0)!=(0);
 $437 = ($434|0)>(-1);
 $or$cond$i$i2 = $436 & $437;
 if ($or$cond$i$i2) {
  $438 = HEAP32[$indices>>2]|0;
  $439 = ($438|0)==(0|0);
  if (!($439)) {
   $440 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $441 = HEAP32[$440>>2]|0;
   $442 = (($441) + 12|0);
   $443 = HEAP32[$442>>2]|0;
   FUNCTION_TABLE_vii[$443 & 4095]($440,$438);
  }
 }
 $444 = HEAP32[$33>>2]|0;
 $445 = $444 & 2147483647;
 $446 = ($445|0)!=(0);
 $447 = ($444|0)>(-1);
 $or$cond$i$i1 = $446 & $447;
 if ($or$cond$i$i1) {
  $448 = HEAP32[$phases>>2]|0;
  $449 = ($448|0)==(0|0);
  if (!($449)) {
   $450 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $451 = HEAP32[$450>>2]|0;
   $452 = (($451) + 12|0);
   $453 = HEAP32[$452>>2]|0;
   FUNCTION_TABLE_vii[$453 & 4095]($450,$448);
  }
 }
 $454 = HEAP32[$30>>2]|0;
 $455 = $454 & 2147483647;
 $456 = ($455|0)!=(0);
 $457 = ($454|0)>(-1);
 $or$cond$i$i = $456 & $457;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $458 = HEAP32[$sets>>2]|0;
 $459 = ($458|0)==(0|0);
 if ($459) {
  STACKTOP = sp;return;
 }
 $460 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $461 = HEAP32[$460>>2]|0;
 $462 = (($461) + 12|0);
 $463 = HEAP32[$462>>2]|0;
 FUNCTION_TABLE_vii[$463 & 4095]($460,$458);
 STACKTOP = sp;return;
}
function __ZNK5physx7PxCloth19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (449320|0);
}
function __ZNK5physx7PxCloth8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(449320,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $6 = 1;
 } else {
  $2 = (_strcmp(449304,$name)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $6 = 1;
  } else {
   $4 = (_strcmp($name,449312)|0);
   $5 = ($4|0)==(0);
   $6 = $5;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZNK5physx15NpActorTemplateINS_7PxClothEE8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx7NpActor11getAPISceneERKNS_7PxActorE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE7setNameEPKc($this,$debugName) {
 $this = $this|0;
 $debugName = $debugName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $debugName;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_7PxClothEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE12setActorFlagENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15NpActorTemplateINS_7PxClothEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$inFlags) {
 $this = $this|0;
 $inFlags = $inFlags|0;
 var $$pre$phi$i$i$iZ2D = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP16[$inFlags>>1]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + ($6)|0);
 $8 = $7;
 $$sum$i = (($6) + 4)|0;
 $9 = (($this) + ($$sum$i)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 24;
 $12 = $11 & 15;
 $13 = ((444424 + ($12<<2)|0) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($8))|0;
 $16 = $15;
 $17 = $10 >>> 30;
 if ((($17|0) == 3)) {
  $$pre$phi$i$i$iZ2D = $7;
 } else if ((($17|0) == 2)) {
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 2417|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 4;
  } else {
   $$pre$phi$i$i$iZ2D = $7;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  HEAP16[$0>>1] = $1;
  __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($16,$0);
  STACKTOP = sp;return;
 }
 $$sum1$i = (($6) + 8)|0;
 $22 = (($this) + ($$sum1$i)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$12)|0);
  HEAP32[$22>>2] = $26;
  $27 = $26;
 } else {
  $27 = $23;
 }
 HEAP16[$27>>1] = $1;
 $28 = HEAP32[$$pre$phi$i$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($28,$7);
 $29 = HEAP32[$9>>2]|0;
 $30 = $29 | 1;
 HEAP32[$9>>2] = $30;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_7PxClothEE13getActorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 8|0);
  $27 = HEAP16[$26>>1]|0;
  HEAP16[$agg$result>>1] = $27;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = HEAP16[$18>>1]|0;
 HEAP16[$agg$result>>1] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE17setDominanceGroupEh($this,$dominanceGroup) {
 $this = $this|0;
 $dominanceGroup = $dominanceGroup|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = $8 >>> 30;
 if ((($15|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else if ((($15|0) == 2)) {
  $16 = HEAP32[$5>>2]|0;
  $17 = (($16) + 2417|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN5physx2Sc9ActorCore17setDominanceGroupEh($14,$dominanceGroup);
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $20 = (($this) + ($$sum1)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $23 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $24 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($23,$10)|0);
  HEAP32[$20>>2] = $24;
  $26 = $24;
 } else {
  $26 = $21;
 }
 $25 = (($26) + 2|0);
 HEAP8[$25>>0] = $dominanceGroup;
 $27 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($27,$5);
 $28 = HEAP32[$7>>2]|0;
 $29 = $28 | 2;
 HEAP32[$7>>2] = $29;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_7PxClothEE17getDominanceGroupEv($this) {
 $this = $this|0;
 var $$in$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $19 = $7 >>> 24;
  $20 = $19 & 15;
  $21 = ((444424 + ($20<<2)|0) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $5;
  $24 = (($22) + ($23))|0;
  $25 = $24;
  $26 = (($25) + 12|0);
  $$in$i$i$i = $26;
  $27 = HEAP8[$$in$i$i$i>>0]|0;
  STACKTOP = sp;return ($27|0);
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 2|0);
 $$in$i$i$i = $17;
 $27 = HEAP8[$$in$i$i$i>>0]|0;
 STACKTOP = sp;return ($27|0);
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE14setOwnerClientEh($this,$inId) {
 $this = $this|0;
 $inId = $inId|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (__ZN5physx7NpActor13getOwnerSceneERKNS_7PxActorE($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,447792,198,447872,$vararg_buffer1);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = ((414264 + ($5<<2)|0) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + ($7)|0);
 $$sum = (($7) + 4)|0;
 $9 = (($this) + ($$sum)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 30;
 if ((($11|0) == 2)) {
  $12 = HEAP32[$8>>2]|0;
  $13 = (($12) + 2417|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   label = 5;
  } else {
   label = 6;
  }
 } else if ((($11|0) == 3)) {
  label = 6;
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $16 = $8;
  $17 = $10 >>> 24;
  $18 = $17 & 15;
  $19 = ((444424 + ($18<<2)|0) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($16))|0;
  $22 = $21;
  $23 = (($22) + 13|0);
  HEAP8[$23>>0] = $inId;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $24 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($24,8,447944,153,448024,$vararg_buffer1);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx15NpActorTemplateINS_7PxClothEE14getOwnerClientEv($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = $5;
 $$sum = (($4) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 >>> 24;
 $10 = $9 & 15;
 $11 = ((444424 + ($10<<2)|0) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($6))|0;
 $14 = $13;
 $15 = (($14) + 13|0);
 $16 = HEAP8[$15>>0]|0;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE($this,$bits) {
 $this = $this|0;
 $bits = $bits|0;
 var $$pre$phi$i$iZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $6 = HEAP8[$bits>>0]|0;
 $7 = $5;
 $$sum = (($4) + 4)|0;
 $8 = (($this) + ($$sum)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 24;
 $11 = $10 & 15;
 $12 = ((444424 + ($11<<2)|0) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($7))|0;
 $15 = $14;
 $16 = $9 >>> 30;
 if ((($16|0) == 2)) {
  $17 = HEAP32[$5>>2]|0;
  $18 = (($17) + 2417|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   label = 4;
  } else {
   $$pre$phi$i$iZ2D = $5;
  }
 } else if ((($16|0) == 3)) {
  $$pre$phi$i$iZ2D = $5;
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $21 = (($15) + 11|0);
  HEAP8[$21>>0] = $6;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $22 = (($this) + ($$sum1)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  $26 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($25,$11)|0);
  HEAP32[$22>>2] = $26;
  $28 = $26;
 } else {
  $28 = $23;
 }
 $27 = (($28) + 3|0);
 HEAP8[$27>>0] = $6;
 $29 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($29,$5);
 $30 = HEAP32[$8>>2]|0;
 $31 = $30 | 4;
 HEAP32[$8>>2] = $31;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_7PxClothEE22getClientBehaviorFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + ($4)|0);
 $$sum = (($4) + 4)|0;
 $6 = (($this) + ($$sum)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  $20 = $7 >>> 24;
  $21 = $20 & 15;
  $22 = ((444424 + ($21<<2)|0) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $5;
  $25 = (($23) + ($24))|0;
  $26 = $25;
  $27 = (($26) + 11|0);
  $28 = HEAP8[$27>>0]|0;
  HEAP8[$agg$result>>0] = $28;
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 8)|0;
 $10 = (($this) + ($$sum1)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$5>>2]|0;
  $14 = $7 >>> 24;
  $15 = $14 & 15;
  $16 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($13,$15)|0);
  HEAP32[$10>>2] = $16;
  $18 = $16;
 } else {
  $18 = $11;
 }
 $17 = (($18) + 3|0);
 $19 = HEAP8[$17>>0]|0;
 HEAP8[$agg$result>>0] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx15NpActorTemplateINS_7PxClothEE12getAggregateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (__ZNK5physx7NpActor12getAggregateEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7NpCloth15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN5physx2Sc9ClothCore15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE20setActorFlagInternalENS_11PxActorFlag4EnumEb($this,$flag,$value) {
 $this = $this|0;
 $flag = $flag|0;
 $value = $value|0;
 var $$in = 0, $$in19 = 0, $$pre = 0, $$pre$phi$i$i5Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre22 = 0, $$pre22$pre = 0, $$pre24 = 0, $$pre25 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum20 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = ((414264 + ($3<<2)|0) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + ($5)|0);
 $$sum = (($5) + 4)|0;
 $7 = (($this) + ($$sum)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($value) {
  if ($10) {
   $18 = $8 >>> 24;
   $19 = $18 & 15;
   $20 = ((444424 + ($19<<2)|0) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $6;
   $23 = (($21) + ($22))|0;
   $24 = $23;
   $25 = (($24) + 8|0);
   $$in19 = $25;$$pre$phiZ2D = $22;$31 = $8;
  } else {
   $$sum18 = (($5) + 8)|0;
   $11 = (($this) + ($$sum18)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[$6>>2]|0;
    $15 = $8 >>> 24;
    $16 = $15 & 15;
    $17 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($14,$16)|0);
    HEAP32[$11>>2] = $17;
    $$pre$pre = HEAP32[$7>>2]|0;
    $$pre = $$pre$pre;$91 = $17;
   } else {
    $$pre = $8;$91 = $12;
   }
   $$pre24 = $6;
   $$in19 = $91;$$pre$phiZ2D = $$pre24;$31 = $$pre;
  }
  $26 = HEAP16[$$in19>>1]|0;
  $27 = $26&65535;
  $28 = $27 | $flag;
  $29 = $28&65535;
  $30 = $31 >>> 24;
  $32 = $30 & 15;
  $33 = ((444424 + ($32<<2)|0) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($$pre$phiZ2D))|0;
  $36 = $35;
  $37 = $31 >>> 30;
  if ((($37|0) == 3)) {
   $$pre$phi$i$i5Z2D = $6;
  } else if ((($37|0) == 2)) {
   $38 = HEAP32[$6>>2]|0;
   $39 = (($38) + 2417|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    label = 10;
   } else {
    $$pre$phi$i$i5Z2D = $6;
   }
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   HEAP16[$0>>1] = $29;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($36,$0);
   STACKTOP = sp;return;
  }
  $$sum20 = (($5) + 8)|0;
  $42 = (($this) + ($$sum20)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   $45 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
   $46 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($45,$32)|0);
   HEAP32[$42>>2] = $46;
   $47 = $46;
  } else {
   $47 = $43;
  }
  HEAP16[$47>>1] = $29;
  $48 = HEAP32[$$pre$phi$i$i5Z2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($48,$6);
  $49 = HEAP32[$7>>2]|0;
  $50 = $49 | 1;
  HEAP32[$7>>2] = $50;
  STACKTOP = sp;return;
 } else {
  if ($10) {
   $58 = $8 >>> 24;
   $59 = $58 & 15;
   $60 = ((444424 + ($59<<2)|0) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $6;
   $63 = (($61) + ($62))|0;
   $64 = $63;
   $65 = (($64) + 8|0);
   $$in = $65;$$pre$phi26Z2D = $62;$71 = $8;
  } else {
   $$sum16 = (($5) + 8)|0;
   $51 = (($this) + ($$sum16)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    $54 = HEAP32[$6>>2]|0;
    $55 = $8 >>> 24;
    $56 = $55 & 15;
    $57 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($54,$56)|0);
    HEAP32[$51>>2] = $57;
    $$pre22$pre = HEAP32[$7>>2]|0;
    $$pre22 = $$pre22$pre;$92 = $57;
   } else {
    $$pre22 = $8;$92 = $52;
   }
   $$pre25 = $6;
   $$in = $92;$$pre$phi26Z2D = $$pre25;$71 = $$pre22;
  }
  $66 = HEAP16[$$in>>1]|0;
  $67 = $flag ^ 65535;
  $68 = $67&65535;
  $69 = $66 & $68;
  $70 = $71 >>> 24;
  $72 = $70 & 15;
  $73 = ((444424 + ($72<<2)|0) + 24|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + ($$pre$phi26Z2D))|0;
  $76 = $75;
  $77 = $71 >>> 30;
  if ((($77|0) == 3)) {
   $$pre$phi$i$iZ2D = $6;
  } else if ((($77|0) == 2)) {
   $78 = HEAP32[$6>>2]|0;
   $79 = (($78) + 2417|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    label = 22;
   } else {
    $$pre$phi$i$iZ2D = $6;
   }
  } else {
   label = 22;
  }
  if ((label|0) == 22) {
   HEAP16[$0>>1] = $69;
   __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($76,$0);
   STACKTOP = sp;return;
  }
  $$sum17 = (($5) + 8)|0;
  $82 = (($this) + ($$sum17)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $85 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
   $86 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($85,$72)|0);
   HEAP32[$82>>2] = $86;
   $87 = $86;
  } else {
   $87 = $83;
  }
  HEAP16[$87>>1] = $69;
  $88 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
  __ZN5physx3Scb5Scene17scheduleForUpdateERNS0_4BaseE($88,$6);
  $89 = HEAP32[$7>>2]|0;
  $90 = $89 | 1;
  HEAP32[$7>>2] = $90;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd5ArrayINS_18PxClothFabricPhaseENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_18PxClothFabricPhaseENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<3)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<3)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = $a;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = $$01$i;
   $18 = $17;
   HEAP32[$18>>2] = $13;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = $16;
  }
  $21 = (($$01$i) + 8|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_18PxClothFabricPhaseENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 448192 : 448160;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,448080,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = $$03$i;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = $$012$i;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
   }
   $30 = (($$012$i) + 8|0);
   $31 = (($$03$i) + 8|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor7releaseERNS_7PxActorE($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_7PxClothEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((448320 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_7PxClothEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((448320 + 8|0));
 __ZN5physx7NpActor14onActorReleaseEPNS_7PxActorE($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx15NpActorTemplateINS_7PxClothEE17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN5physx7NpActor17resolveReferencesERNS_24PxDeserializationContextE($0,$context);
 STACKTOP = sp;return;
}
function __ZN5physx7PxClothD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx7PxClothD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx19NpClothParticleData18getDataAccessFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 HEAP8[$agg$result>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx19NpClothParticleDataD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx13NpClothFabric15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Sc15ClothFabricCore15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx13NpClothFabricC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 4;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 HEAP32[$this>>2] = ((457144 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = ((424432 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 1;
 HEAP32[$this>>2] = ((456856 + 8|0));
 HEAP32[$2>>2] = ((456856 + 112|0));
 $4 = (($this) + 16|0);
 __ZN5physx2Sc15ClothFabricCoreC2Ev($4);
 STACKTOP = sp;return;
}
function __ZN5physx13NpClothFabricD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((456856 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((456856 + 112|0));
 $2 = (($this) + 16|0);
 __ZN5physx2Sc15ClothFabricCoreD2Ev($2);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx13NpClothFabricD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 HEAP32[$1>>2] = (((456856 + 8|0)));
 $2 = (($1) + 8|0);
 HEAP32[$2>>2] = (((456856 + 112|0)));
 $3 = (($1) + 16|0);
 __ZN5physx2Sc15ClothFabricCoreD2Ev($3);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx13NpClothFabricD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((456856 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = ((456856 + 112|0));
 $1 = (($this) + 16|0);
 __ZN5physx2Sc15ClothFabricCoreD2Ev($1);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx13NpClothFabricD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 HEAP32[$0>>2] = (((456856 + 8|0)));
 $1 = (($0) + 8|0);
 HEAP32[$1>>2] = (((456856 + 112|0)));
 $2 = (($0) + 16|0);
 __ZN5physx2Sc15ClothFabricCoreD2Ev($2);
 STACKTOP = sp;return;
}
function __ZN5physx13NpClothFabric7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($0,$this,0,1);
 $1 = (($this) + 6|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & -3;
 HEAP16[$1>>1] = $3;
 $4 = (($this) + 8|0);
 $5 = (($this) + 12|0);
 $6 = (__ZN5physx6shdfnd15atomicDecrementEPVi($5)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$4>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vi[$10 & 4095]($4);
 STACKTOP = sp;return;
}
function __ZN5physx13NpClothFabric14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[420520>>2]|0;
 $1 = (__ZN5physx9NpFactory17removeClothFabricERNS_13PxClothFabricE($0,$this)|0);
 if (!($1)) {
  $12 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($12,8,456984,98,457072,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $2 = (($this) + 6|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & 1;
 $5 = ($4<<16>>16)==(0);
 $6 = HEAP32[$this>>2]|0;
 if ($5) {
  $9 = (($6) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 4095]($this);
 } else {
  $7 = (($6) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vi[$8 & 4095]($this);
 }
 $11 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($11,$this,0,2);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx13NpClothFabric14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + -8|0);
 $1 = HEAP32[420520>>2]|0;
 $2 = (__ZN5physx9NpFactory17removeClothFabricERNS_13PxClothFabricE($1,$0)|0);
 if (!($2)) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($13,8,456984,98,457072,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $3 = (($0) + 6|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 1;
 $6 = ($5<<16>>16)==(0);
 $7 = HEAP32[$0>>2]|0;
 if ($6) {
  $10 = (($7) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($0);
 } else {
  $8 = (($7) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 4095]($0);
 }
 $12 = HEAP32[424544>>2]|0;
 __ZN5physx9NpPhysics23notifyDeletionListenersEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE($12,$0,0,2);
 STACKTOP = sp;return;
}
function __ZNK5physx13NpClothFabric17getReferenceCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx13NpClothFabric4loadERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZN5physx2Sc15ClothFabricCore4loadERNS_13PxInputStreamE($0,$stream)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx13NpClothFabric4loadERKNS_17PxClothFabricDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZN5physx2Sc15ClothFabricCore4loadERKNS_17PxClothFabricDescE($0,$desc)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric14getNbParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore14getNbParticlesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric11getNbPhasesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore11getNbPhasesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric9getNbSetsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore9getNbSetsEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric20getNbParticleIndicesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore20getNbParticleIndicesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric15getNbRestvaluesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore15getNbRestvaluesEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric12getNbTethersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore12getNbTethersEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric9getPhasesEPNS_18PxClothFabricPhaseEj($this,$userPhaseIndexBuffer,$bufferSize) {
 $this = $this|0;
 $userPhaseIndexBuffer = $userPhaseIndexBuffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore9getPhasesEPNS_18PxClothFabricPhaseEj($0,$userPhaseIndexBuffer,$bufferSize)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric7getSetsEPjj($this,$userSetBuffer,$bufferSize) {
 $this = $this|0;
 $userSetBuffer = $userSetBuffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore7getSetsEPjj($0,$userSetBuffer,$bufferSize)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric18getParticleIndicesEPjj($this,$userParticleIndexBuffer,$bufferSize) {
 $this = $this|0;
 $userParticleIndexBuffer = $userParticleIndexBuffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore18getParticleIndicesEPjj($0,$userParticleIndexBuffer,$bufferSize)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric13getRestvaluesEPfj($this,$userRestvalueBuffer,$bufferSize) {
 $this = $this|0;
 $userRestvalueBuffer = $userRestvalueBuffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore13getRestvaluesEPfj($0,$userRestvalueBuffer,$bufferSize)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric16getTetherAnchorsEPjj($this,$userAnchorBuffer,$bufferSize) {
 $this = $this|0;
 $userAnchorBuffer = $userAnchorBuffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore16getTetherAnchorsEPjj($0,$userAnchorBuffer,$bufferSize)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric16getTetherLengthsEPfj($this,$userLengthBuffer,$bufferSize) {
 $this = $this|0;
 $userLengthBuffer = $userLengthBuffer|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (__ZNK5physx2Sc15ClothFabricCore16getTetherLengthsEPfj($0,$userLengthBuffer,$bufferSize)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13NpClothFabric12getPhaseTypeEj($this,$phaseIndex) {
 $this = $this|0;
 $phaseIndex = $phaseIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($phaseIndex<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx13NpClothFabric16scaleRestlengthsEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Sc15ClothFabricCore16scaleRestlengthsEf($0,$scale);
 STACKTOP = sp;return;
}
function __ZNK5physx13PxClothFabric19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (457120|0);
}
function __ZNK5physx13PxClothFabric8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(457120,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,457136)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx13NpClothFabric8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx13PxClothFabricD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx13PxClothFabricD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx19NpClothParticleData6unlockEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 & 4;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = $2 & 2;
  $6 = ($5|0)==(0);
  $$pre1 = (($this) + 12|0);
  if (!($6)) {
   $7 = HEAP32[$$pre1>>2]|0;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 100|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_viii[$10 & 4095]($7,$12,$14);
  }
  $15 = HEAP32[$$pre1>>2]|0;
  __ZN5physx7NpCloth18unlockParticleDataEv($15);
  $$pre = HEAP8[$0>>0]|0;
  $17 = $$pre;
 } else {
  $17 = $1;
 }
 $16 = $17&255;
 $18 = $16 & 249;
 $19 = $18&255;
 HEAP8[$0>>0] = $19;
 $20 = (($this) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + -1)|0;
 HEAP32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN5physx19NpClothParticleData7tryLockENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = HEAP8[$flags>>0]|0;
 $3 = $2 | $1;
 HEAP8[$flags>>0] = $3;
 $4 = $3 & 6;
 $5 = ($4<<24>>24)==(0);
 $$phi$trans$insert = (($this) + 16|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if ($5) {
  $phitmp = (($$pre) + 1)|0;
  $8 = $phitmp;
 } else {
  $6 = ($$pre|0)==(0);
  if ($6) {
   $8 = 1;
  } else {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP8[$0>>0] = $3;
 $7 = (($this) + 16|0);
 HEAP32[$7>>2] = $8;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx22PxSimulationStatisticsC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i1$05 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 $i1$05 = 0;
 while(1) {
  $1 = ((($this) + (($i1$05*28)|0)|0) + 88|0);
  HEAP32[$1>>2] = 0;
  $2 = ((($this) + (($i1$05*28)|0)|0) + 480|0);
  HEAP32[$2>>2] = 0;
  $3 = ((($this) + (($i1$05*28)|0)|0) + 284|0);
  HEAP32[$3>>2] = 0;
  $4 = ((($this) + (($i1$05*28)|0)|0) + 676|0);
  HEAP32[$4>>2] = 0;
  $5 = ((($this) + (($i1$05*28)|0)|0) + 92|0);
  HEAP32[$5>>2] = 0;
  $6 = ((($this) + (($i1$05*28)|0)|0) + 484|0);
  HEAP32[$6>>2] = 0;
  $7 = ((($this) + (($i1$05*28)|0)|0) + 288|0);
  HEAP32[$7>>2] = 0;
  $8 = ((($this) + (($i1$05*28)|0)|0) + 680|0);
  HEAP32[$8>>2] = 0;
  $9 = ((($this) + (($i1$05*28)|0)|0) + 96|0);
  HEAP32[$9>>2] = 0;
  $10 = ((($this) + (($i1$05*28)|0)|0) + 488|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($this) + (($i1$05*28)|0)|0) + 292|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($this) + (($i1$05*28)|0)|0) + 684|0);
  HEAP32[$12>>2] = 0;
  $13 = ((($this) + (($i1$05*28)|0)|0) + 100|0);
  HEAP32[$13>>2] = 0;
  $14 = ((($this) + (($i1$05*28)|0)|0) + 492|0);
  HEAP32[$14>>2] = 0;
  $15 = ((($this) + (($i1$05*28)|0)|0) + 296|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($this) + (($i1$05*28)|0)|0) + 688|0);
  HEAP32[$16>>2] = 0;
  $17 = ((($this) + (($i1$05*28)|0)|0) + 104|0);
  HEAP32[$17>>2] = 0;
  $18 = ((($this) + (($i1$05*28)|0)|0) + 496|0);
  HEAP32[$18>>2] = 0;
  $19 = ((($this) + (($i1$05*28)|0)|0) + 300|0);
  HEAP32[$19>>2] = 0;
  $20 = ((($this) + (($i1$05*28)|0)|0) + 692|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($this) + (($i1$05*28)|0)|0) + 108|0);
  HEAP32[$21>>2] = 0;
  $22 = ((($this) + (($i1$05*28)|0)|0) + 500|0);
  HEAP32[$22>>2] = 0;
  $23 = ((($this) + (($i1$05*28)|0)|0) + 304|0);
  HEAP32[$23>>2] = 0;
  $24 = ((($this) + (($i1$05*28)|0)|0) + 696|0);
  HEAP32[$24>>2] = 0;
  $25 = ((($this) + (($i1$05*28)|0)|0) + 112|0);
  HEAP32[$25>>2] = 0;
  $26 = ((($this) + (($i1$05*28)|0)|0) + 504|0);
  HEAP32[$26>>2] = 0;
  $27 = ((($this) + (($i1$05*28)|0)|0) + 308|0);
  HEAP32[$27>>2] = 0;
  $28 = ((($this) + (($i1$05*28)|0)|0) + 700|0);
  HEAP32[$28>>2] = 0;
  $29 = (($i1$05) + 1)|0;
  $exitcond = ($29|0)==(7);
  if ($exitcond) {
   break;
  } else {
   $i1$05 = $29;
  }
 }
 $30 = (($this) + 872|0);
 dest=$this+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ActorCoreC2ENS_11PxActorType4EnumEthhh($this,$actorType,$actorFlags,$owner,$behavior,$dominanceGroup) {
 $this = $this|0;
 $actorType = $actorType|0;
 $actorFlags = $actorFlags|0;
 $owner = $owner|0;
 $behavior = $behavior|0;
 $dominanceGroup = $dominanceGroup|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = -1;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP16[$1>>1] = $actorFlags;
 $2 = (($this) + 10|0);
 $3 = $actorType&255;
 HEAP8[$2>>0] = $3;
 $4 = (($this) + 11|0);
 HEAP8[$4>>0] = $behavior;
 $5 = (($this) + 12|0);
 HEAP8[$5>>0] = $dominanceGroup;
 $6 = (($this) + 13|0);
 HEAP8[$6>>0] = $owner;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ActorCoreD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ActorCore13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE($this,$af) {
 $this = $this|0;
 $af = $af|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = HEAP16[$af>>1]|0;
 $3 = ($2<<16>>16)==($1<<16>>16);
 if ($3) {
  STACKTOP = sp;return;
 }
 HEAP16[$0>>1] = $2;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $1&65535;
 $11 = HEAP16[$af>>1]|0;
 $12 = $11&65535;
 FUNCTION_TABLE_viii[$9 & 4095]($5,$10,$12);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ActorCore17setDominanceGroupEh($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP8[$0>>0] = $g;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc8ActorSim24postDominanceGroupChangeEv($2);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ActorCore14reinsertShapesEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $shapeIterator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $shapeIterator = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 10|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 if ((($5|0) == 4) | (($5|0) == 1)) {
  $6 = (__ZNK5physx2Sc8BodyCore6getSimEv($this)|0);
  $7 = (($6) + 132|0);
  HEAP32[$7>>2] = 1073741823;
  $8 = (($6) + 136|0);
  HEAP32[$8>>2] = 1073741823;
  $$pre = HEAP32[$0>>2]|0;
  $9 = $$pre;
 } else {
  $9 = $1;
 }
 HEAP32[$shapeIterator>>2] = 0;
 __ZN5physx2Sc13ShapeIterator4initERKNS0_8ActorSimE($shapeIterator,$9);
 $10 = (__ZN5physx2Sc13ShapeIterator7getNextEv($shapeIterator)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 } else {
  $12 = $10;
 }
 while(1) {
  __ZN5physx2Sc8ShapeSim18reinsertBroadPhaseEv($12);
  $13 = (__ZN5physx2Sc13ShapeIterator7getNextEv($shapeIterator)|0);
  $14 = ($13|0)==(0|0);
  if ($14) {
   break;
  } else {
   $12 = $13;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16ActorInteractionD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ActorInteraction13getNPhaseCoreEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc8ActorSim8getSceneEv($1)|0);
 $3 = (($2) + 1088|0);
 $4 = HEAP32[$3>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZThn24_NK5physx2Sc16ActorInteraction13getNPhaseCoreEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5physx2Sc8ActorSim8getSceneEv($2)|0);
 $4 = (($3) + 1088|0);
 $5 = HEAP32[$4>>2]|0;
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc11Interaction10initializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 4095]($this,0)|0);
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($7,$this,$3);
 $8 = HEAP32[$4>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($8,$this);
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($10,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc11Interaction7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($1,$this);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($3,$this);
 $4 = HEAP32[$0>>2]|0;
 $5 = (($4) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($6,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc11Interaction10onActivateEj($this,$infoFlag) {
 $this = $this|0;
 $infoFlag = $infoFlag|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Sc11Interaction12onDeactivateEj($this,$infoFlag) {
 $this = $this|0;
 $infoFlag = $infoFlag|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Sc15CoreInteraction11updateStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)==(0);
 if (!($3)) {
  __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($this);
  $4 = HEAP16[$0>>1]|0;
  $5 = $4&65535;
  $6 = $5 & 65533;
  $7 = $6&65535;
  HEAP16[$0>>1] = $7;
 }
 $8 = (($this) + 4|0);
 HEAP16[$8>>1] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ActorPair24releaseContactReportDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1088|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx2Sc10NPhaseCore33releaseActorPairContactReportDataEPNS0_26ActorPairContactReportDataE($3,$5);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ActorPair23createContactReportDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1088|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN5physx2Sc10NPhaseCore32createActorPairContactReportDataEv($3)|0);
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = $4;
 $6 = ($4|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($4) + 16|0);
 HEAP32[$10>>2] = $9;
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($4) + 20|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$this>>2]|0;
 $17 = (__ZN5physx2Sc8RigidSim10getPxActorEv($16)|0);
 $18 = (($4) + 24|0);
 HEAP32[$18>>2] = $17;
 $19 = HEAP32[$11>>2]|0;
 $20 = (__ZN5physx2Sc8RigidSim10getPxActorEv($19)|0);
 $21 = (($4) + 28|0);
 HEAP32[$21>>2] = $20;
 $22 = HEAP32[$this>>2]|0;
 $23 = (($22) + 52|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$11>>2]|0;
 $26 = (($25) + 52|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($24) + 13|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = (($4) + 32|0);
 HEAP8[$30>>0] = $29;
 $31 = (($27) + 13|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = (($4) + 33|0);
 HEAP8[$33>>0] = $32;
 $34 = (($24) + 11|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = (($4) + 34|0);
 HEAP8[$36>>0] = $35;
 $37 = (($27) + 11|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = (($4) + 35|0);
 HEAP8[$39>>0] = $38;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ActorSimC2ERNS0_5SceneERNS0_9ActorCoreENS0_14IslandNodeInfo4TypeE($this,$scene,$core,$type) {
 $this = $this|0;
 $scene = $scene|0;
 $core = $core|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scene) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($core) + 10|0);
 $3 = HEAP8[$2>>0]|0;
 __ZN5physx2Sc5ActorC2ERNS0_16InteractionSceneEhNS0_14IslandNodeInfo4TypeE($this,$1,$3,$type);
 HEAP32[$this>>2] = ((457264 + 8|0));
 $4 = (($this) + 52|0);
 HEAP32[$4>>2] = $core;
 $5 = (($core) + 4|0);
 HEAP32[$5>>2] = $this;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ActorSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Sc5ActorD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ActorSimD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc5ActorD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8ActorSim8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1008|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx2Sc8ActorSim24postDominanceGroupChangeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)>(0);
 if ($5) {
  $7 = $1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $6 = HEAP32[$7>>2]|0;
  $8 = (($6) + 21|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9 & 3;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $12 = (__ZN5physx2Sc15CoreInteraction17isCoreInteractionEPNS0_11InteractionE($6)|0);
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = (($12) + 4|0);
    $15 = HEAP16[$14>>1]|0;
    $16 = $15&65535;
    $17 = $16 | 8;
    $18 = $17&65535;
    HEAP16[$14>>1] = $18;
    $19 = (($12) + 6|0);
    $20 = HEAP16[$19>>1]|0;
    $21 = $20 & 2;
    $22 = ($21<<16>>16)==(0);
    if ($22) {
     __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($12);
     $23 = HEAP16[$19>>1]|0;
     $24 = $23&65535;
     $25 = $24 | 2;
     $26 = $25&65535;
     HEAP16[$19>>1] = $26;
    }
   }
  }
  $27 = (($7) + 4|0);
  $28 = ($27>>>0)<($4>>>0);
  if ($28) {
   $7 = $27;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ActorSim26setActorsInteractionsDirtyENS0_15CoreInteraction9DirtyFlagEPKNS0_5ActorEh($this,$flag,$other,$interactionFlag) {
 $this = $this|0;
 $flag = $flag|0;
 $other = $other|0;
 $interactionFlag = $interactionFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)>(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = ($other|0)==(0|0);
 if ($6) {
  $8 = $1;
  while(1) {
   $7 = HEAP32[$8>>2]|0;
   $9 = (($7) + 21|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10 & $interactionFlag;
   $12 = ($11<<24>>24)==(0);
   if (!($12)) {
    $13 = (__ZN5physx2Sc15CoreInteraction17isCoreInteractionEPNS0_11InteractionE($7)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     $15 = (($13) + 4|0);
     $16 = HEAP16[$15>>1]|0;
     $17 = $16&65535;
     $18 = $17 | $flag;
     $19 = $18&65535;
     HEAP16[$15>>1] = $19;
     $20 = (($13) + 6|0);
     $21 = HEAP16[$20>>1]|0;
     $22 = $21 & 2;
     $23 = ($22<<16>>16)==(0);
     if ($23) {
      __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($13);
      $24 = HEAP16[$20>>1]|0;
      $25 = $24&65535;
      $26 = $25 | 2;
      $27 = $26&65535;
      HEAP16[$20>>1] = $27;
     }
    }
   }
   $28 = (($8) + 4|0);
   $29 = ($28>>>0)<($4>>>0);
   if ($29) {
    $8 = $28;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else {
  $31 = $1;
 }
 while(1) {
  $30 = HEAP32[$31>>2]|0;
  $32 = (($30) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==($other|0);
  if ($34) {
   label = 10;
  } else {
   $35 = (($30) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==($other|0);
   if ($37) {
    label = 10;
   }
  }
  if ((label|0) == 10) {
   label = 0;
   $38 = (($30) + 21|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = $39 & $interactionFlag;
   $41 = ($40<<24>>24)==(0);
   if (!($41)) {
    $42 = (__ZN5physx2Sc15CoreInteraction17isCoreInteractionEPNS0_11InteractionE($30)|0);
    $43 = ($42|0)==(0|0);
    if (!($43)) {
     $44 = (($42) + 4|0);
     $45 = HEAP16[$44>>1]|0;
     $46 = $45&65535;
     $47 = $46 | $flag;
     $48 = $47&65535;
     HEAP16[$44>>1] = $48;
     $49 = (($42) + 6|0);
     $50 = HEAP16[$49>>1]|0;
     $51 = $50 & 2;
     $52 = ($51<<16>>16)==(0);
     if ($52) {
      __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($42);
      $53 = HEAP16[$49>>1]|0;
      $54 = $53&65535;
      $55 = $54 | 2;
      $56 = $55&65535;
      HEAP16[$49>>1] = $56;
     }
    }
   }
  }
  $57 = (($31) + 4|0);
  $58 = ($57>>>0)<($4>>>0);
  if ($58) {
   $31 = $57;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor10onActivateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor12onDeactivateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ActorSim19postActorFlagChangeEjj($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16ArticulationCoreC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = HEAP32[463296>>2]|0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 4;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 4;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 4;
 $4 = Math_fround(HEAPF32[$0>>2]);
 $5 = Math_fround($4 * Math_fround(0.100000001490116119385));
 $6 = (($this) + 20|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 16|0);
 HEAP16[$7>>1] = 260;
 $8 = (($0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * Math_fround(4.99999987368937581778E-5));
 $11 = Math_fround($9 * $10);
 $12 = (($this) + 24|0);
 HEAPF32[$12>>2] = $11;
 $13 = Math_fround(HEAPF32[463304>>2]);
 $14 = (($this) + 32|0);
 HEAPF32[$14>>2] = $13;
 $15 = Math_fround(HEAPF32[$8>>2]);
 $16 = Math_fround($15 * Math_fround(4.99999987368937581778E-6));
 $17 = Math_fround($15 * $16);
 $18 = (($this) + 28|0);
 HEAPF32[$18>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16ArticulationCoreD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore26getInternalDriveIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc16ArticulationCore26setInternalDriveIterationsEj($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $v;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore26getExternalDriveIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc16ArticulationCore26setExternalDriveIterationsEj($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $v;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore26getMaxProjectionIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc16ArticulationCore26setMaxProjectionIterationsEj($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $v;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore22getSeparationToleranceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc16ArticulationCore22setSeparationToleranceEf($this,$v) {
 $this = $this|0;
 $v = Math_fround($v);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 HEAPF32[$0>>2] = $v;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore14getWakeCounterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc16ArticulationCore22setWakeCounterInternalEf($this,$v) {
 $this = $this|0;
 $v = Math_fround($v);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 HEAPF32[$0>>2] = $v;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16ArticulationCore14setWakeCounterEf($this,$v) {
 $this = $this|0;
 $v = Math_fround($v);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 HEAPF32[$0>>2] = $v;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore10isSleepingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $3 = (($this) + 32|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(0.0);
  $6 = $5;
  STACKTOP = sp;return ($6|0);
 } else {
  $2 = (__ZNK5physx2Sc15ArticulationSim10isSleepingEv($0)|0);
  $6 = $2;
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __ZN5physx2Sc16ArticulationCore6wakeUpEf($this,$wakeCounter) {
 $this = $this|0;
 $wakeCounter = Math_fround($wakeCounter);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 HEAPF32[$0>>2] = $wakeCounter;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16ArticulationCore10putToSleepEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore17getSleepThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc16ArticulationCore17setSleepThresholdEf($this,$v) {
 $this = $this|0;
 $v = Math_fround($v);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 HEAPF32[$0>>2] = $v;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16ArticulationCore18setFreezeThresholdEf($this,$v) {
 $this = $this|0;
 $v = Math_fround($v);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 HEAPF32[$0>>2] = $v;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore24getSolverIterationCountsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP16[$0>>1]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc16ArticulationCore24setSolverIterationCountsEt($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAP16[$0>>1] = $v;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore16createDriveCacheEfj($this,$compliance,$driveIterations) {
 $this = $this|0;
 $compliance = Math_fround($compliance);
 $driveIterations = $driveIterations|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $3 = 0;
  STACKTOP = sp;return ($3|0);
 }
 $2 = (__ZNK5physx2Sc15ArticulationSim16createDriveCacheEfj($0,$compliance,$driveIterations)|0);
 $3 = $2;
 STACKTOP = sp;return ($3|0);
}
function __ZNK5physx2Sc16ArticulationCore16updateDriveCacheERNS_9PxcFsDataEfj($this,$cache,$compliance,$driveIterations) {
 $this = $this|0;
 $cache = $cache|0;
 $compliance = Math_fround($compliance);
 $driveIterations = $driveIterations|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __ZNK5physx2Sc15ArticulationSim16updateDriveCacheERNS_9PxcFsDataEfj($0,$cache,$compliance,$driveIterations);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore17releaseDriveCacheERNS_9PxcFsDataE($this,$driveCache) {
 $this = $this|0;
 $driveCache = $driveCache|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __ZNK5physx2Sc15ArticulationSim17releaseDriveCacheERNS_9PxcFsDataE($0,$driveCache);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16ArticulationCore12applyImpulseERNS0_8BodyCoreERKNS_9PxcFsDataERKNS_6PxVec3ES9_($this,$link,$driveCache,$force,$torque) {
 $this = $this|0;
 $link = $link|0;
 $driveCache = $driveCache|0;
 $force = $force|0;
 $torque = $torque|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc15ArticulationSim12applyImpulseERNS0_8BodyCoreERKNS_9PxcFsDataERKNS_6PxVec3ES9_($0,$link,$driveCache,$force,$torque);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16ArticulationCore22computeImpulseResponseERNS0_8BodyCoreERNS_6PxVec3ES5_RKNS_9PxcFsDataERKS4_SA_($this,$link,$linearResponse,$angularResponse,$driveCache,$force,$torque) {
 $this = $this|0;
 $link = $link|0;
 $linearResponse = $linearResponse|0;
 $angularResponse = $angularResponse|0;
 $driveCache = $driveCache|0;
 $force = $force|0;
 $torque = $torque|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __ZNK5physx2Sc15ArticulationSim22computeImpulseResponseERNS0_8BodyCoreERNS_6PxVec3ES5_RKNS_9PxcFsDataERKS4_SA_($0,$link,$linearResponse,$angularResponse,$driveCache,$force,$torque);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCoreC2ERKNS_11PxTransformES4_($this,$parentFrame,$childFrame) {
 $this = $this|0;
 $parentFrame = $parentFrame|0;
 $childFrame = $childFrame|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 8|0);
 $2 = (($this) + 12|0);
 $3 = (($this) + 16|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 20|0);
 $5 = (($this) + 44|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 48|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 52|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 56|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 104|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 108|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 120|0);
 HEAPF32[$11>>2] = Math_fround(0.0500000007450580596924);
 $12 = (($this) + 144|0);
 HEAPF32[$12>>2] = Math_fround(0.0500000007450580596924);
 $13 = Math_fround(HEAPF32[$parentFrame>>2]);
 HEAPF32[$0>>2] = $13;
 $14 = (($parentFrame) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$1>>2] = $15;
 $16 = (($parentFrame) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$2>>2] = $17;
 $18 = (($parentFrame) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$3>>2] = $19;
 $20 = (($parentFrame) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$4>>2] = $21;
 $22 = (($parentFrame) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 24|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($parentFrame) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 28|0);
 HEAPF32[$27>>2] = $26;
 $28 = Math_fround(HEAPF32[$childFrame>>2]);
 $29 = (($this) + 32|0);
 HEAPF32[$29>>2] = $28;
 $30 = (($childFrame) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 36|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($childFrame) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($this) + 40|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($childFrame) + 12|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 HEAPF32[$5>>2] = $37;
 $38 = (($childFrame) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$6>>2] = $39;
 $40 = (($childFrame) + 20|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 HEAPF32[$7>>2] = $41;
 $42 = (($childFrame) + 24|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$8>>2] = $43;
 $44 = (($this) + 60|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($this) + 64|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($this) + 68|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($this) + 72|0);
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (($this) + 76|0);
 ;HEAP32[$48+0>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;
 HEAPF32[$9>>2] = Math_fround(1.0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $49 = (($this) + 112|0);
 HEAPF32[$49>>2] = Math_fround(0.785398185253143310546);
 $50 = (($this) + 116|0);
 HEAPF32[$50>>2] = Math_fround(0.785398185253143310546);
 HEAPF32[$11>>2] = Math_fround(0.0500000007450580596924);
 $51 = (($this) + 124|0);
 HEAP8[$51>>0] = 0;
 $52 = (($this) + 128|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($this) + 132|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($this) + 140|0);
 HEAPF32[$54>>2] = Math_fround(-0.785398185253143310546);
 $55 = (($this) + 136|0);
 HEAPF32[$55>>2] = Math_fround(0.785398185253143310546);
 HEAPF32[$12>>2] = Math_fround(0.0500000007450580596924);
 $56 = (($this) + 148|0);
 HEAP8[$56>>0] = 0;
 $57 = (($this) + 152|0);
 HEAPF32[$57>>2] = Math_fround(0.19891236722469329834);
 $58 = (($this) + 156|0);
 HEAPF32[$58>>2] = Math_fround(0.19891236722469329834);
 $59 = (($this) + 160|0);
 HEAPF32[$59>>2] = Math_fround(0.0125006511807441711426);
 $60 = (($this) + 164|0);
 HEAPF32[$60>>2] = Math_fround(0.19891236722469329834);
 $61 = (($this) + 168|0);
 HEAPF32[$61>>2] = Math_fround(-0.19891236722469329834);
 $62 = (($this) + 172|0);
 HEAPF32[$62>>2] = Math_fround(0.0125006511807441711426);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCoreD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore13setParentPoseERKNS_11PxTransformE($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$t>>2]);
 $1 = (($this) + 4|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($t) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($t) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 12|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($t) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 16|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($t) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 20|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($t) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 24|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($t) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 28|0);
 HEAPF32[$19>>2] = $18;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore12setChildPoseERKNS_11PxTransformE($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$t>>2]);
 $1 = (($this) + 32|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($t) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 36|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($t) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 40|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($t) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 44|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($t) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 48|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($t) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 52|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($t) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 56|0);
 HEAPF32[$19>>2] = $18;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore20setTargetOrientationERKNS_6PxQuatE($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$p>>2]);
 $1 = (($this) + 60|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($p) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 64|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($p) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 68|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($p) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 72|0);
 HEAPF32[$10>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore17setTargetVelocityERKNS_6PxVec3E($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$v>>2]);
 $1 = (($this) + 76|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($v) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 80|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($v) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 84|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore12setStiffnessEf($this,$s) {
 $this = $this|0;
 $s = Math_fround($s);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 HEAPF32[$0>>2] = $s;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore10setDampingEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 HEAPF32[$0>>2] = $d;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore21setInternalComplianceEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 HEAPF32[$0>>2] = $r;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore21setExternalComplianceEf($this,$r) {
 $this = $this|0;
 $r = Math_fround($r);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 HEAPF32[$0>>2] = $r;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore13setSwingLimitEff($this,$yLimit,$zLimit) {
 $this = $this|0;
 $yLimit = Math_fround($yLimit);
 $zLimit = Math_fround($zLimit);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $2 = Math_fround(0), $3 = 0.0, $4 = 0.0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 HEAPF32[$0>>2] = $yLimit;
 $1 = (($this) + 116|0);
 HEAPF32[$1>>2] = $zLimit;
 $2 = Math_fround($yLimit * Math_fround(0.25));
 $3 = +$2;
 $4 = (+Math_tan((+$3)));
 $5 = Math_fround($4);
 $6 = (($this) + 152|0);
 HEAPF32[$6>>2] = $5;
 $7 = Math_fround($zLimit * Math_fround(0.25));
 $8 = +$7;
 $9 = (+Math_tan((+$8)));
 $10 = Math_fround($9);
 $11 = (($this) + 156|0);
 HEAPF32[$11>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore22setTangentialStiffnessEf($this,$s) {
 $this = $this|0;
 $s = Math_fround($s);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 HEAPF32[$0>>2] = $s;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore20setTangentialDampingEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 HEAPF32[$0>>2] = $d;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore20setSwingLimitEnabledEb($this,$e) {
 $this = $this|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = $e&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore28setSwingLimitContactDistanceEf($this,$e) {
 $this = $this|0;
 $e = Math_fround($e);
 var $0 = 0, $1 = Math_fround(0), $2 = 0.0, $3 = 0.0, $4 = Math_fround(0), $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 HEAPF32[$0>>2] = $e;
 $1 = Math_fround($e * Math_fround(0.25));
 $2 = +$1;
 $3 = (+Math_tan((+$2)));
 $4 = Math_fround($3);
 $5 = (($this) + 160|0);
 HEAPF32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore13setTwistLimitEff($this,$lower,$upper) {
 $this = $this|0;
 $lower = Math_fround($lower);
 $upper = Math_fround($upper);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $2 = Math_fround(0), $3 = 0.0, $4 = 0.0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 HEAPF32[$0>>2] = $lower;
 $1 = (($this) + 136|0);
 HEAPF32[$1>>2] = $upper;
 $2 = Math_fround($upper * Math_fround(0.25));
 $3 = +$2;
 $4 = (+Math_tan((+$3)));
 $5 = Math_fround($4);
 $6 = (($this) + 164|0);
 HEAPF32[$6>>2] = $5;
 $7 = Math_fround($lower * Math_fround(0.25));
 $8 = +$7;
 $9 = (+Math_tan((+$8)));
 $10 = Math_fround($9);
 $11 = (($this) + 168|0);
 HEAPF32[$11>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore20setTwistLimitEnabledEb($this,$e) {
 $this = $this|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 148|0);
 $1 = $e&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ArticulationJointCore28setTwistLimitContactDistanceEf($this,$e) {
 $this = $this|0;
 $e = Math_fround($e);
 var $0 = 0, $1 = Math_fround(0), $2 = 0.0, $3 = 0.0, $4 = Math_fround(0), $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 HEAPF32[$0>>2] = $e;
 $1 = Math_fround($e * Math_fround(0.25));
 $2 = +$1;
 $3 = (+Math_tan((+$2)));
 $4 = Math_fround($3);
 $5 = (($this) + 172|0);
 HEAPF32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc20ArticulationJointSimC2ERNS0_21ArticulationJointCoreERNS0_8ActorSimES5_($this,$joint,$parent,$child) {
 $this = $this|0;
 $joint = $joint|0;
 $parent = $parent|0;
 $child = $child|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc11InteractionC2ERNS0_5ActorES3_NS0_15InteractionTypeEh($this,$parent,$child,5,0);
 $0 = (($this) + 24|0);
 $1 = (($this) + 28|0);
 HEAP16[$1>>1] = -1;
 $2 = (($this) + 30|0);
 HEAP16[$2>>1] = 0;
 HEAP32[$this>>2] = ((457296 + 8|0));
 HEAP32[$0>>2] = ((457296 + 44|0));
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = -1;
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = $joint;
 $5 = (__ZN5physx2Sc20ArticulationJointSim10onActivateEj($this,0)|0);
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($9,$this,$5);
 $10 = HEAP32[$6>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($10,$this);
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($12,$this);
 $13 = (($parent) + 152|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN5physx2Sc15ArticulationSim7addBodyERNS0_7BodySimEPS2_PNS0_20ArticulationJointSimE($14,$child,$parent,$this);
 $15 = HEAP32[$4>>2]|0;
 HEAP32[$15>>2] = $this;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc20ArticulationJointSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((457296 + 8|0));
 $1 = (($this) + 24|0);
 HEAP32[$1>>2] = ((457296 + 44|0));
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if (!($4)) {
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZNK5physx2Sc8ActorSim8getSceneEv($6)|0);
  $8 = (($7) + 1212|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($9)|0);
  __ZN5physx16PxsIslandManager10removeEdgeENS0_9eEdgeTypeERNS_20PxsIslandManagerHookIjLj4294967295EEE($10,2,$2);
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 152|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN5physx2Sc15ArticulationSim10removeBodyERNS0_7BodySimE($14,$12);
 $15 = (($this) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$16>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn24_N5physx2Sc20ArticulationJointSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 __ZN5physx2Sc20ArticulationJointSimD0Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc20ArticulationJointSimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((457296 + 8|0));
 $0 = (($this) + 24|0);
 HEAP32[$0>>2] = ((457296 + 44|0));
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 if (!($3)) {
  $4 = (($this) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (__ZNK5physx2Sc8ActorSim8getSceneEv($5)|0);
  $7 = (($6) + 1212|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($8)|0);
  __ZN5physx16PxsIslandManager10removeEdgeENS0_9eEdgeTypeERNS_20PxsIslandManagerHookIjLj4294967295EEE($9,2,$1);
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 152|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx2Sc15ArticulationSim10removeBodyERNS0_7BodySimE($13,$11);
 $14 = (($this) + 36|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn24_N5physx2Sc20ArticulationJointSimD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 HEAP32[$0>>2] = ((457296 + 8|0));
 $1 = (($0) + 24|0);
 HEAP32[$1>>2] = ((457296 + 44|0));
 $2 = (($0) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if (!($4)) {
  $5 = (($0) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZNK5physx2Sc8ActorSim8getSceneEv($6)|0);
  $8 = (($7) + 1212|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($9)|0);
  __ZN5physx16PxsIslandManager10removeEdgeENS0_9eEdgeTypeERNS_20PxsIslandManagerHookIjLj4294967295EEE($10,2,$2);
 }
 $11 = (($0) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 152|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN5physx2Sc15ArticulationSim10removeBodyERNS0_7BodySimE($14,$12);
 $15 = (($0) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$16>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc20ArticulationJointSim10onActivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $1 = sp + 4|0;
 $2 = sp;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 $6 = (($this) + 4|0);
 if ($5) {
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($9)|0);
  $11 = HEAP32[$6>>2]|0;
  $12 = (($11) + 188|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$1>>2] = $13;
  $14 = (($this) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 188|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$2>>2] = $17;
  __ZN5physx16PxsIslandManager7addEdgeENS0_9eEdgeTypeENS_20PxsIslandManagerHookIjLj4294967295EEES3_RS3_($10,2,$1,$2,$3);
  __ZN5physx16PxsIslandManager24setEdgeArticulationJointERKNS_20PxsIslandManagerHookIjLj4294967295EEE($10,$3);
  __ZN5physx16PxsIslandManager16setEdgeConnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($10,$3);
 }
 $18 = HEAP32[$6>>2]|0;
 $19 = (($18) + 51|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  STACKTOP = sp;return 0;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 51|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)!=(0);
  STACKTOP = sp;return ($28|0);
 }
 return 0|0;
}
function __ZN5physx2Sc20ArticulationJointSim12onDeactivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Sc20ArticulationJointSim7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 30|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)==(0);
 if (!($3)) {
  $4 = (($this) + 24|0);
  __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($4);
  $5 = HEAP16[$0>>1]|0;
  $6 = $5&65535;
  $7 = $6 & 65533;
  $8 = $7&65535;
  HEAP16[$0>>1] = $8;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($10,$this);
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($12,$this);
 $13 = HEAP32[$9>>2]|0;
 $14 = (($13) + 36|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($15,$this);
 $16 = HEAP32[$this>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ArticulationSimC2ERNS0_16ArticulationCoreERNS0_5SceneERNS0_8BodyCoreE($this,$core,$scene,$root) {
 $this = $this|0;
 $core = $core|0;
 $scene = $scene|0;
 $root = $root|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $phitmp1 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $scene;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $core;
 $2 = (($this) + 12|0);
 $3 = (($this) + 24|0);
 $4 = (($this) + 32|0);
 $5 = (($this) + 88|0);
 $6 = (($this) + 160|0);
 dest=$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$5+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP8[$6>>0] = 1;
 $7 = (($scene) + 1212|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 1000|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 44|0);
 __ZN5physx6shdfnd5ArrayINS_19PxsArticulationLinkENS0_19ReflectionAllocatorIS2_EEE8recreateEj($2,16);
 $$pre = HEAP32[$11>>2]|0;
 $phitmp = $$pre & 2147483632;
 $phitmp1 = ($phitmp>>>0)<(16);
 if ($phitmp1) {
  $12 = (($this) + 36|0);
  __ZN5physx6shdfnd5ArrayIPNS_2Sc20ArticulationJointSimENS0_19ReflectionAllocatorIS4_EEE8recreateEj($12,16);
 }
 $13 = HEAP32[$4>>2]|0;
 $14 = $13 & 2147483632;
 $15 = ($14>>>0)<(16);
 if ($15) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc7BodySimENS0_19ReflectionAllocatorIS4_EEE8recreateEj($3,16);
 }
 $16 = (__ZN5physx10PxsContext18createArticulationEv($10)|0);
 HEAP32[$this>>2] = $16;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $18 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($18,32,457360,70,457456,$vararg_buffer);
  STACKTOP = sp;return;
 } else {
  $19 = (__ZNK5physx2Sc8BodyCore6getSimEv($root)|0);
  __ZN5physx2Sc15ArticulationSim7addBodyERNS0_7BodySimEPS2_PNS0_20ArticulationJointSimE($this,$19,0,0);
  $20 = HEAP32[$1>>2]|0;
  HEAP32[$20>>2] = $this;
  $21 = (($core) + 4|0);
  $22 = (($this) + 72|0);
  HEAP32[$22>>2] = $21;
  $23 = (($this) + 48|0);
  HEAP32[$23>>2] = 0;
  $24 = (($this) + 56|0);
  $25 = (($this) + 76|0);
  ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;
  ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc15ArticulationSim7addBodyERNS0_7BodySimEPS2_PNS0_20ArticulationJointSimE($this,$body,$parent,$joint) {
 $this = $this|0;
 $body = $body|0;
 $parent = $parent|0;
 $joint = $joint|0;
 var $$ = 0, $$$i$i = 0, $$0$i7 = 0, $$off0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $currentlyAsleep$0$off0 = 0, $currentlyAsleep$0$off0$not = 0, $i$01$i = 0;
 var $i$08 = 0, $shouldSleep$0$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 HEAP32[$0>>2] = $joint;
 $2 = (($this) + 24|0);
 HEAP32[$1>>2] = $body;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  $9 = HEAP32[$2>>2]|0;
  $10 = (($9) + ($7<<2)|0);
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   HEAP32[$10>>2] = $body;
  }
  $12 = (($7) + 1)|0;
  HEAP32[$6>>2] = $12;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc7BodySimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($2,$1)|0);
 }
 $13 = (($this) + 36|0);
 $14 = (($this) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = (($this) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16>>>0)>($18>>>0);
 if ($19) {
  $20 = HEAP32[$13>>2]|0;
  $21 = (($20) + ($18<<2)|0);
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   HEAP32[$21>>2] = $joint;
  }
  $23 = (($18) + 1)|0;
  HEAP32[$17>>2] = $23;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc20ArticulationJointSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($13,$0)|0);
 }
 $24 = (($this) + 12|0);
 $25 = (($this) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 20|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 & 2147483647;
 $30 = ($29>>>0)>($26>>>0);
 if ($30) {
  $35 = $26;
 } else {
  $31 = ($29|0)==(0);
  $32 = $28 << 1;
  $$$i$i = $31 ? 1 : $32;
  __ZN5physx6shdfnd5ArrayINS_19PxsArticulationLinkENS0_19ReflectionAllocatorIS2_EEE8recreateEj($24,$$$i$i);
  $$pre$i6 = HEAP32[$25>>2]|0;
  $35 = $$pre$i6;
 }
 $33 = HEAP32[$24>>2]|0;
 $34 = (($35) + 1)|0;
 HEAP32[$25>>2] = $34;
 $36 = (($body) + 64|0);
 $37 = ((($33) + ($35<<5)|0) + 16|0);
 HEAP32[$37>>2] = $36;
 $38 = (($body) + 52|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 16|0);
 $41 = ((($33) + ($35<<5)|0) + 20|0);
 HEAP32[$41>>2] = $40;
 $42 = (($33) + ($35<<5)|0);
 $43 = $42;
 $44 = $43;
 HEAP32[$44>>2] = 0;
 $45 = (($43) + 4)|0;
 $46 = $45;
 HEAP32[$46>>2] = 0;
 $47 = (__ZN5physx2Sc7BodySim37checkSleepReadinessBesidesWakeCounterEv($body)|0);
 $48 = (($this) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (Math_fround(__ZNK5physx2Sc16ArticulationCore14getWakeCounterEv($49)));
 $51 = ($parent|0)==(0|0);
 if ($51) {
  $101 = $50 == Math_fround(0.0);
  $$off0 = $101 & $47;
  $102 = ((($33) + ($35<<5)|0) + 28|0);
  HEAP32[$102>>2] = -1;
  $103 = ((($33) + ($35<<5)|0) + 8|0);
  $104 = $103;
  $105 = $104;
  HEAP32[$105>>2] = 1;
  $106 = (($104) + 4)|0;
  $107 = $106;
  HEAP32[$107>>2] = 0;
  $108 = ((($33) + ($35<<5)|0) + 24|0);
  HEAP32[$108>>2] = 0;
  $currentlyAsleep$0$off0 = $101;$shouldSleep$0$off0 = $$off0;
 } else {
  $52 = HEAP32[$2>>2]|0;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 51|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55 & 1;
  $57 = ($56<<24>>24)==(0);
  $$ = $47 & $57;
  $58 = HEAP32[$6>>2]|0;
  $59 = ($58|0)==(0);
  L20: do {
   if ($59) {
    $$0$i7 = -2147483648;
   } else {
    $63 = $53;$i$01$i = 0;
    while(1) {
     $62 = ($63|0)==($parent|0);
     $61 = (($i$01$i) + 1)|0;
     if ($62) {
      $$0$i7 = $i$01$i;
      break L20;
     }
     $60 = ($61>>>0)<($58>>>0);
     if (!($60)) {
      $$0$i7 = -2147483648;
      break L20;
     }
     $$phi$trans$insert = (($52) + ($61<<2)|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $63 = $$pre;$i$01$i = $61;
    }
   }
  } while(0);
  $64 = ((($33) + ($35<<5)|0) + 28|0);
  HEAP32[$64>>2] = $$0$i7;
  $65 = HEAP32[$24>>2]|0;
  $66 = ((($65) + ($$0$i7<<5)|0) + 8|0);
  $67 = $66;
  $68 = $67;
  $69 = HEAP32[$68>>2]|0;
  $70 = (($67) + 4)|0;
  $71 = $70;
  $72 = HEAP32[$71>>2]|0;
  $73 = (_bitshift64Shl(1,0,($26|0))|0);
  $74 = tempRet0;
  $75 = $69 | $73;
  $76 = $72 | $74;
  $77 = ((($33) + ($35<<5)|0) + 8|0);
  $78 = $77;
  $79 = $78;
  HEAP32[$79>>2] = $75;
  $80 = (($78) + 4)|0;
  $81 = $80;
  HEAP32[$81>>2] = $76;
  $82 = HEAP32[$0>>2]|0;
  $83 = (($82) + 36|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + 4|0);
  $86 = ((($33) + ($35<<5)|0) + 24|0);
  HEAP32[$86>>2] = $85;
  $87 = HEAP32[$24>>2]|0;
  $88 = (($87) + ($$0$i7<<5)|0);
  $89 = $88;
  $90 = $89;
  $91 = HEAP32[$90>>2]|0;
  $92 = (($89) + 4)|0;
  $93 = $92;
  $94 = HEAP32[$93>>2]|0;
  $95 = $91 | $73;
  $96 = $94 | $74;
  $97 = $88;
  $98 = $97;
  HEAP32[$98>>2] = $95;
  $99 = (($97) + 4)|0;
  $100 = $99;
  HEAP32[$100>>2] = $96;
  $currentlyAsleep$0$off0 = $57;$shouldSleep$0$off0 = $$;
 }
 $currentlyAsleep$0$off0$not = $currentlyAsleep$0$off0 ^ 1;
 $brmerge = $shouldSleep$0$off0 | $currentlyAsleep$0$off0$not;
 if (!($brmerge)) {
  $109 = HEAP32[$6>>2]|0;
  $110 = ($109|0)==(1);
  if (!($110)) {
   $i$08 = 0;
   while(1) {
    $111 = HEAP32[$2>>2]|0;
    $112 = (($111) + ($i$08<<2)|0);
    $113 = HEAP32[$112>>2]|0;
    __ZN5physx2Sc7BodySim30internalWakeUpArticulationLinkEf($113,$50);
    $114 = (($i$08) + 1)|0;
    $115 = HEAP32[$6>>2]|0;
    $116 = (($115) + -1)|0;
    $117 = ($114>>>0)<($116>>>0);
    if ($117) {
     $i$08 = $114;
    } else {
     break;
    }
   }
  }
 }
 __ZN5physx2Sc7BodySim15setArticulationEPNS0_15ArticulationSimEfb($body,$this,$50,$shouldSleep$0$off0);
 $118 = HEAP32[$this>>2]|0;
 $119 = $118;
 $120 = $119 | $26;
 $121 = $120 & 63;
 $122 = ($121|0)==(0);
 $123 = (__ZNK5physx2Sc8ActorSim8getSceneEv($body)|0);
 $124 = (($123) + 1212|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($125)|0);
 $127 = (($body) + 188|0);
 if ($122) {
  __ZN5physx16PxsIslandManager29setArticulationRootLinkHandleEjPvRKNS_20PxsIslandManagerHookIjLj4294967295EEE($126,$120,$this,$127);
  $128 = (($this) + 160|0);
  HEAP8[$128>>0] = 1;
  STACKTOP = sp;return;
 } else {
  __ZN5physx16PxsIslandManager25setArticulationLinkHandleEjPvRKNS_20PxsIslandManagerHookIjLj4294967295EEE($126,$120,$this,$127);
  $128 = (($this) + 160|0);
  HEAP8[$128>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc15ArticulationSimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $notlhs$i$i = 0, $notlhs$i$i2 = 0, $notrhs$i$i = 0, $notrhs$i$i3 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0;
 var $or$cond$i$i10 = 0, $or$cond$i$i12 = 0, $or$cond$i$i7 = 0, $or$cond$i$i8 = 0, $or$cond$i$i9 = 0, $or$cond$not$i$i = 0, $or$cond$not$i$i4 = 0, $or$cond2$i$i = 0, $or$cond2$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 1212|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 1000|0);
  $7 = HEAP32[$6>>2]|0;
  __ZN5physx10PxsContext19destroyArticulationERNS_15PxsArticulationE($7,$0);
  $8 = (($this) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$9>>2] = 0;
 }
 $10 = (($this) + 148|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 156|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $notlhs$i$i = ($14|0)==(0);
 $notrhs$i$i = ($13|0)<(0);
 $or$cond$not$i$i = $notrhs$i$i | $notlhs$i$i;
 $15 = ($11|0)==(0|0);
 $or$cond2$i$i = $or$cond$not$i$i | $15;
 if (!($or$cond2$i$i)) {
  $16 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vii[$19 & 4095]($16,$11);
 }
 $20 = (($this) + 136|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 144|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $notlhs$i$i2 = ($24|0)==(0);
 $notrhs$i$i3 = ($23|0)<(0);
 $or$cond$not$i$i4 = $notrhs$i$i3 | $notlhs$i$i2;
 $25 = ($21|0)==(0|0);
 $or$cond2$i$i5 = $or$cond$not$i$i4 | $25;
 if (!($or$cond2$i$i5)) {
  $26 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vii[$29 & 4095]($26,$21);
 }
 $30 = (($this) + 132|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 & 2147483647;
 $33 = ($32|0)!=(0);
 $34 = ($31|0)>(-1);
 $or$cond$i$i7 = $33 & $34;
 if ($or$cond$i$i7) {
  $35 = (($this) + 124|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
  }
 }
 $42 = (($this) + 120|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 & 2147483647;
 $45 = ($44|0)!=(0);
 $46 = ($43|0)>(-1);
 $or$cond$i$i8 = $45 & $46;
 if ($or$cond$i$i8) {
  $47 = (($this) + 112|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + 12|0);
   $53 = HEAP32[$52>>2]|0;
   FUNCTION_TABLE_vii[$53 & 4095]($50,$48);
  }
 }
 $54 = (($this) + 108|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 & 2147483647;
 $57 = ($56|0)!=(0);
 $58 = ($55|0)>(-1);
 $or$cond$i$i9 = $57 & $58;
 if ($or$cond$i$i9) {
  $59 = (($this) + 100|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(0|0);
  if (!($61)) {
   $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($63) + 12|0);
   $65 = HEAP32[$64>>2]|0;
   FUNCTION_TABLE_vii[$65 & 4095]($62,$60);
  }
 }
 $66 = (($this) + 96|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = $67 & 2147483647;
 $69 = ($68|0)!=(0);
 $70 = ($67|0)>(-1);
 $or$cond$i$i10 = $69 & $70;
 if ($or$cond$i$i10) {
  $71 = (($this) + 88|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   $74 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($75) + 12|0);
   $77 = HEAP32[$76>>2]|0;
   FUNCTION_TABLE_vii[$77 & 4095]($74,$72);
  }
 }
 $78 = (($this) + 44|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = $79 & 2147483647;
 $81 = ($80|0)!=(0);
 $82 = ($79|0)>(-1);
 $or$cond$i$i12 = $81 & $82;
 if ($or$cond$i$i12) {
  $83 = (($this) + 36|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ($84|0)==(0|0);
  if (!($85)) {
   $86 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 12|0);
   $89 = HEAP32[$88>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$84);
  }
 }
 $90 = (($this) + 32|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = $91 & 2147483647;
 $93 = ($92|0)!=(0);
 $94 = ($91|0)>(-1);
 $or$cond$i$i1 = $93 & $94;
 if ($or$cond$i$i1) {
  $95 = (($this) + 24|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ($96|0)==(0|0);
  if (!($97)) {
   $98 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (($99) + 12|0);
   $101 = HEAP32[$100>>2]|0;
   FUNCTION_TABLE_vii[$101 & 4095]($98,$96);
  }
 }
 $102 = (($this) + 20|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = $103 & 2147483647;
 $105 = ($104|0)!=(0);
 $106 = ($103|0)>(-1);
 $or$cond$i$i = $105 & $106;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $107 = (($this) + 12|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108|0)==(0|0);
 if ($109) {
  STACKTOP = sp;return;
 }
 $110 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = (($111) + 12|0);
 $113 = HEAP32[$112>>2]|0;
 FUNCTION_TABLE_vii[$113 & 4095]($110,$108);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ArticulationSim22updateCachedTransformsERNS_17PxsTransformCacheE($this,$cache) {
 $this = $this|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN5physx2Sc7BodySim22updateCachedTransformsERNS_17PxsTransformCacheE($6,$cache);
  $7 = (($i$01) + 1)|0;
  $8 = HEAP32[$0>>2]|0;
  $9 = ($7>>>0)<($8>>>0);
  if ($9) {
   $i$01 = $7;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc15ArticulationSim13getLinkHandleERNS0_7BodySimE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = $0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0$i = -2147483648;
  } else {
   $5 = (($this) + 24|0);
   $6 = HEAP32[$5>>2]|0;
   $i$01$i = 0;
   while(1) {
    $9 = (($6) + ($i$01$i<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($body|0);
    $8 = (($i$01$i) + 1)|0;
    if ($11) {
     $$0$i = $i$01$i;
     break L1;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $i$01$i = $8;
    } else {
     $$0$i = -2147483648;
     break;
    }
   }
  }
 } while(0);
 $12 = $$0$i | $1;
 STACKTOP = sp;return ($12|0);
}
function __ZN5physx2Sc7BodySim37checkSleepReadinessBesidesWakeCounterEv($this) {
 $this = $this|0;
 var $$not = 0, $$not8 = 0, $$off0 = 0, $$off0$mux = 0, $$off0$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0);
 var $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0);
 var $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $brmerge = 0, $brmerge9 = 0, $cond = 0, $cond11 = 0, $readyForSleep$0$off0 = 0, $readyForSleep$0$off0$mux = 0, $readyForSleep$0$off0$not = 0, $readyForSleep$1$off0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 156|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $29 = 0;
 } else {
  $5 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($1,0)|0);
  if ($5) {
   $6 = HEAP32[$2>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $29 = 0;
   } else {
    $29 = $6;
   }
  } else {
   $29 = 0;
  }
 }
 $8 = (($1) + 80|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = $9 == Math_fround(0.0);
 if ($10) {
  $11 = (($1) + 84|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = $12 == Math_fround(0.0);
  if ($13) {
   $14 = (($1) + 88|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = $15 == Math_fround(0.0);
   if ($16) {
    $17 = (($1) + 96|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = $18 == Math_fround(0.0);
    if ($19) {
     $20 = (($1) + 100|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = $21 == Math_fround(0.0);
     if ($22) {
      $23 = (($1) + 104|0);
      $24 = Math_fround(HEAPF32[$23>>2]);
      $25 = $24 == Math_fround(0.0);
      $$off0 = $25;
     } else {
      $$off0 = 0;
     }
    } else {
     $$off0 = 0;
    }
   } else {
    $$off0 = 0;
   }
  } else {
   $$off0 = 0;
  }
 } else {
  $$off0 = 0;
 }
 $26 = (($this) + 146|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27 & 2;
 $$not = ($28<<24>>24)==(0);
 $$off0$not = $$off0 ^ 1;
 $brmerge = $$not | $$off0$not;
 $$off0$mux = $$not & $$off0;
 if ($brmerge) {
  $readyForSleep$0$off0 = $$off0$mux;
  label = 19;
 } else {
  $cond = ($29|0)==(0|0);
  if ($cond) {
   $readyForSleep$0$off0 = 1;
   label = 19;
  } else {
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = $30 == Math_fround(0.0);
   if ($31) {
    $32 = (($29) + 4|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = $33 == Math_fround(0.0);
    if ($34) {
     $35 = (($29) + 8|0);
     $36 = Math_fround(HEAPF32[$35>>2]);
     $37 = $36 == Math_fround(0.0);
     if ($37) {
      $38 = (($29) + 16|0);
      $39 = Math_fround(HEAPF32[$38>>2]);
      $40 = $39 == Math_fround(0.0);
      if ($40) {
       $41 = (($29) + 20|0);
       $42 = Math_fround(HEAPF32[$41>>2]);
       $43 = $42 == Math_fround(0.0);
       if ($43) {
        $44 = (($29) + 24|0);
        $45 = Math_fround(HEAPF32[$44>>2]);
        $46 = $45 == Math_fround(0.0);
        $readyForSleep$0$off0 = $46;
        label = 19;
       } else {
        $readyForSleep$1$off0 = 0;
       }
      } else {
       $readyForSleep$1$off0 = 0;
      }
     } else {
      $readyForSleep$1$off0 = 0;
     }
    } else {
     $readyForSleep$1$off0 = 0;
    }
   } else {
    $readyForSleep$1$off0 = 0;
   }
  }
 }
 if ((label|0) == 19) {
  $47 = $27 & 4;
  $$not8 = ($47<<24>>24)==(0);
  $readyForSleep$0$off0$not = $readyForSleep$0$off0 ^ 1;
  $brmerge9 = $$not8 | $readyForSleep$0$off0$not;
  $readyForSleep$0$off0$mux = $$not8 & $readyForSleep$0$off0;
  if ($brmerge9) {
   $readyForSleep$1$off0 = $readyForSleep$0$off0$mux;
  } else {
   $cond11 = ($29|0)==(0|0);
   if ($cond11) {
    $readyForSleep$1$off0 = 1;
   } else {
    $48 = (($29) + 32|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = $49 == Math_fround(0.0);
    if ($50) {
     $51 = (($29) + 36|0);
     $52 = Math_fround(HEAPF32[$51>>2]);
     $53 = $52 == Math_fround(0.0);
     if ($53) {
      $54 = (($29) + 40|0);
      $55 = Math_fround(HEAPF32[$54>>2]);
      $56 = $55 == Math_fround(0.0);
      if ($56) {
       $57 = (($29) + 48|0);
       $58 = Math_fround(HEAPF32[$57>>2]);
       $59 = $58 == Math_fround(0.0);
       if ($59) {
        $60 = (($29) + 52|0);
        $61 = Math_fround(HEAPF32[$60>>2]);
        $62 = $61 == Math_fround(0.0);
        if ($62) {
         $63 = (($29) + 56|0);
         $64 = Math_fround(HEAPF32[$63>>2]);
         $65 = $64 == Math_fround(0.0);
         $readyForSleep$1$off0 = $65;
        } else {
         $readyForSleep$1$off0 = 0;
        }
       } else {
        $readyForSleep$1$off0 = 0;
       }
      } else {
       $readyForSleep$1$off0 = 0;
      }
     } else {
      $readyForSleep$1$off0 = 0;
     }
    } else {
     $readyForSleep$1$off0 = 0;
    }
   }
  }
 }
 STACKTOP = sp;return ($readyForSleep$1$off0|0);
}
function __ZN5physx2Sc15ArticulationSim10removeBodyERNS0_7BodySimE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $$0$i = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $i$0 = 0, $i$0$in4 = 0, $i$0$in4$phi = 0, $i$01$i = 0, $i$03 = 0, $i$05 = 0, $i1$01 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $$0$i = -2147483648;
  } else {
   $3 = (($this) + 24|0);
   $4 = HEAP32[$3>>2]|0;
   $i$01$i = 0;
   while(1) {
    $7 = (($4) + ($i$01$i<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==($body|0);
    $6 = (($i$01$i) + 1)|0;
    if ($9) {
     $$0$i = $i$01$i;
     break L1;
    }
    $5 = ($6>>>0)<($1>>>0);
    if ($5) {
     $i$01$i = $6;
    } else {
     $$0$i = -2147483648;
     break;
    }
   }
  }
 } while(0);
 __ZN5physx2Sc7BodySim15setArticulationEPNS0_15ArticulationSimEfb($body,0,Math_fround(0.0),1);
 $10 = (($this) + 12|0);
 $i$03 = (($$0$i) + 1)|0;
 $11 = (($this) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($i$03>>>0)<($12>>>0);
 if ($13) {
  $14 = (($this) + 24|0);
  $15 = (($this) + 36|0);
  $i$0$in4 = $$0$i;$i$05 = $i$03;
  while(1) {
   $16 = HEAP32[$10>>2]|0;
   $17 = (($16) + ($i$0$in4<<5)|0);
   $18 = (($16) + ($i$05<<5)|0);
   ;HEAP32[$17+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$18+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$18+16>>2]|0;HEAP32[$17+20>>2]=HEAP32[$18+20>>2]|0;HEAP32[$17+24>>2]=HEAP32[$18+24>>2]|0;HEAP32[$17+28>>2]=HEAP32[$18+28>>2]|0;
   $19 = HEAP32[$14>>2]|0;
   $20 = (($19) + ($i$05<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + ($i$0$in4<<2)|0);
   HEAP32[$22>>2] = $21;
   $23 = HEAP32[$15>>2]|0;
   $24 = (($23) + ($i$05<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + ($i$0$in4<<2)|0);
   HEAP32[$26>>2] = $25;
   $27 = HEAP32[$14>>2]|0;
   $28 = (($27) + ($i$0$in4<<2)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$this>>2]|0;
   $31 = $30;
   $32 = $31 | $i$0$in4;
   $33 = $32 & 63;
   $34 = ($33|0)==(0);
   $35 = (__ZNK5physx2Sc8ActorSim8getSceneEv($29)|0);
   $36 = (($35) + 1212|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($37)|0);
   $39 = (($29) + 188|0);
   if ($34) {
    __ZN5physx16PxsIslandManager29setArticulationRootLinkHandleEjPvRKNS_20PxsIslandManagerHookIjLj4294967295EEE($38,$32,$this,$39);
   } else {
    __ZN5physx16PxsIslandManager25setArticulationLinkHandleEjPvRKNS_20PxsIslandManagerHookIjLj4294967295EEE($38,$32,$this,$39);
   }
   $i$0 = (($i$05) + 1)|0;
   $40 = HEAP32[$11>>2]|0;
   $41 = ($i$0>>>0)<($40>>>0);
   if ($41) {
    $i$0$in4$phi = $i$05;$i$05 = $i$0;$i$0$in4 = $i$0$in4$phi;
   } else {
    $51 = $40;
    break;
   }
  }
 } else {
  $51 = $12;
 }
 $42 = (_bitshift64Shl(1,0,($$0$i|0))|0);
 $43 = tempRet0;
 $44 = (_i64Add(($42|0),($43|0),-1,-1)|0);
 $45 = tempRet0;
 $46 = $44 | $42;
 $47 = $45 | $43;
 $48 = $46 ^ -1;
 $49 = $47 ^ -1;
 $50 = ($51|0)==(0);
 if ($50) {
  $$lcssa = 0;
  $97 = (($$lcssa) + -1)|0;
  HEAP32[$11>>2] = $97;
  $98 = (($this) + 160|0);
  HEAP8[$98>>0] = 1;
  STACKTOP = sp;return;
 }
 $52 = HEAP32[$10>>2]|0;
 $i1$01 = 0;
 while(1) {
  $53 = ((($52) + ($i1$01<<5)|0) + 28|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)!=(-1);
  $56 = ($54>>>0)>($$0$i>>>0);
  $or$cond = $55 & $56;
  if ($or$cond) {
   $57 = ((($52) + ($i1$01<<5)|0) + 8|0);
   $58 = $57;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = (($58) + 4)|0;
   $62 = $61;
   $63 = HEAP32[$62>>2]|0;
   $64 = $60 & $44;
   $65 = $63 & $45;
   $66 = $60 & $48;
   $67 = $63 & $49;
   $68 = (_bitshift64Lshr(($66|0),($67|0),1)|0);
   $69 = tempRet0;
   $70 = $68 | $64;
   $71 = $69 | $65;
   $72 = $57;
   $73 = $72;
   HEAP32[$73>>2] = $70;
   $74 = (($72) + 4)|0;
   $75 = $74;
   HEAP32[$75>>2] = $71;
  }
  $76 = (($52) + ($i1$01<<5)|0);
  $77 = $76;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($77) + 4)|0;
  $81 = $80;
  $82 = HEAP32[$81>>2]|0;
  $83 = $79 & $44;
  $84 = $82 & $45;
  $85 = $79 & $48;
  $86 = $82 & $49;
  $87 = (_bitshift64Lshr(($85|0),($86|0),1)|0);
  $88 = tempRet0;
  $89 = $87 | $83;
  $90 = $88 | $84;
  $91 = $76;
  $92 = $91;
  HEAP32[$92>>2] = $89;
  $93 = (($91) + 4)|0;
  $94 = $93;
  HEAP32[$94>>2] = $90;
  $95 = (($i1$01) + 1)|0;
  $96 = ($95>>>0)<($51>>>0);
  if ($96) {
   $i1$01 = $95;
  } else {
   $$lcssa = $51;
   break;
  }
 }
 $97 = (($$lcssa) + -1)|0;
 HEAP32[$11>>2] = $97;
 $98 = (($this) + 160|0);
 HEAP8[$98>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc15ArticulationSim11checkResizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, $scratchSize = 0, $solverDataSize = 0, $totalSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $0 = sp + 96|0;
 $1 = sp + 140|0;
 $2 = sp + 48|0;
 $3 = sp;
 $solverDataSize = sp + 128|0;
 $totalSize = sp + 132|0;
 $scratchSize = sp + 136|0;
 $4 = sp + 169|0;
 $5 = sp + 168|0;
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 188|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(-1);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 160|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (($this) + 48|0);
 $21 = (($this) + 84|0);
 $22 = HEAP16[$21>>1]|0;
 $23 = $22&65535;
 $24 = ($16|0)==($23|0);
 if (!($24)) {
  $25 = (($this) + 124|0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_14PxcSIMDSpatialENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($25,$16,$0);
  $26 = (($this) + 112|0);
  HEAPF32[$1>>2] = Math_fround(0.0);
  $27 = (($1) + 4|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  $28 = (($1) + 8|0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  $29 = (($1) + 12|0);
  HEAPF32[$29>>2] = Math_fround(1.0);
  $30 = (($1) + 16|0);
  HEAPF32[$30>>2] = Math_fround(0.0);
  $31 = (($1) + 20|0);
  HEAPF32[$31>>2] = Math_fround(0.0);
  $32 = (($1) + 24|0);
  HEAPF32[$32>>2] = Math_fround(0.0);
  __ZN5physx6shdfnd5ArrayINS_11PxTransformENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($26,$16,$1);
  $33 = (($this) + 100|0);
  HEAPF32[$2>>2] = Math_fround(1.0);
  $34 = (($2) + 4|0);
  $35 = (($2) + 20|0);
  ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
  HEAPF32[$35>>2] = Math_fround(1.0);
  $36 = (($2) + 24|0);
  $37 = (($2) + 40|0);
  ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;
  HEAPF32[$37>>2] = Math_fround(1.0);
  $38 = (($2) + 44|0);
  HEAPF32[$38>>2] = Math_fround(0.0);
  __ZN5physx6shdfnd5ArrayINS0_3aos6Mat33VENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($33,$16,$2);
  $39 = (($this) + 88|0);
  HEAPF32[$3>>2] = Math_fround(1.0);
  $40 = (($3) + 4|0);
  $41 = (($3) + 20|0);
  ;HEAP32[$40+0>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;
  HEAPF32[$41>>2] = Math_fround(1.0);
  $42 = (($3) + 24|0);
  $43 = (($3) + 40|0);
  ;HEAP32[$42+0>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;HEAP32[$42+12>>2]=0|0;
  HEAPF32[$43>>2] = Math_fround(1.0);
  $44 = (($3) + 44|0);
  HEAPF32[$44>>2] = Math_fround(0.0);
  __ZN5physx6shdfnd5ArrayINS0_3aos6Mat33VENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($39,$16,$3);
  __ZN5physx21PxcArticulationHelper12getDataSizesEjRjS1_S1_($16,$solverDataSize,$totalSize,$scratchSize);
  $45 = (($this) + 136|0);
  $46 = HEAP32[$totalSize>>2]|0;
  HEAP8[$4>>0] = 0;
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE6resizeEjRKc($45,$46,$4);
  $47 = HEAP32[$25>>2]|0;
  $48 = (($this) + 56|0);
  HEAP32[$48>>2] = $47;
  $49 = HEAP32[$33>>2]|0;
  $50 = (($this) + 64|0);
  HEAP32[$50>>2] = $49;
  $51 = HEAP32[$39>>2]|0;
  $52 = (($this) + 68|0);
  HEAP32[$52>>2] = $51;
  $53 = HEAP32[$26>>2]|0;
  $54 = (($this) + 60|0);
  HEAP32[$54>>2] = $53;
  $55 = HEAP32[$solverDataSize>>2]|0;
  $56 = $55&65535;
  $57 = (($this) + 82|0);
  HEAP16[$57>>1] = $56;
  $58 = HEAP32[$totalSize>>2]|0;
  $59 = $58&65535;
  $60 = (($this) + 80|0);
  HEAP16[$60>>1] = $59;
  $61 = HEAP32[$45>>2]|0;
  HEAP32[$20>>2] = $61;
  $62 = (($this) + 148|0);
  $63 = HEAP32[$scratchSize>>2]|0;
  HEAP8[$5>>0] = 0;
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE6resizeEjRKc($62,$63,$5);
  $64 = HEAP32[$62>>2]|0;
  $65 = (($this) + 76|0);
  HEAP32[$65>>2] = $64;
  $66 = HEAP32[$scratchSize>>2]|0;
  $67 = $66&65535;
  $68 = (($this) + 86|0);
  HEAP16[$68>>1] = $67;
 }
 $69 = (($this) + 100|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($this) + 104|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72*48)|0;
 _memset(($70|0),0,($73|0))|0;
 $74 = (($this) + 88|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = HEAP32[$71>>2]|0;
 $77 = ($76*48)|0;
 _memset(($75|0),0,($77|0))|0;
 $78 = (($this) + 12|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($this) + 52|0);
 HEAP32[$80>>2] = $79;
 $81 = HEAP32[$15>>2]|0;
 $82 = $81&65535;
 HEAP16[$21>>1] = $82;
 $83 = HEAP32[$this>>2]|0;
 HEAP32[$83>>2] = $20;
 HEAP8[$17>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_14PxcSIMDSpatialENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_14PxcSIMDSpatialENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<5)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<5)|0);
 $10 = (($a) + 16|0);
 $$01$i = $9;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;
   $12 = (($$01$i) + 16|0);
   ;HEAP32[$12+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$10+12>>2]|0;
  }
  $13 = (($$01$i) + 32|0);
  $14 = ($13>>>0)<($7>>>0);
  if ($14) {
   $$01$i = $13;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11PxTransformENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_11PxTransformENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*28)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*28)|0)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $13 = (($a) + 16|0);
 $14 = (($a) + 20|0);
 $15 = (($a) + 24|0);
 $$01$i = $9;
 while(1) {
  $16 = ($$01$i|0)==(0|0);
  if (!($16)) {
   $17 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $17;
   $18 = (($$01$i) + 4|0);
   $19 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$18>>2] = $19;
   $20 = (($$01$i) + 8|0);
   $21 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$20>>2] = $21;
   $22 = (($$01$i) + 12|0);
   $23 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$22>>2] = $23;
   $24 = (($$01$i) + 16|0);
   $25 = Math_fround(HEAPF32[$13>>2]);
   HEAPF32[$24>>2] = $25;
   $26 = (($$01$i) + 20|0);
   $27 = Math_fround(HEAPF32[$14>>2]);
   HEAPF32[$26>>2] = $27;
   $28 = (($$01$i) + 24|0);
   $29 = Math_fround(HEAPF32[$15>>2]);
   HEAPF32[$28>>2] = $29;
  }
  $30 = (($$01$i) + 28|0);
  $31 = ($30>>>0)<($7>>>0);
  if ($31) {
   $$01$i = $30;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS0_3aos6Mat33VENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS0_3aos6Mat33VENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*48)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*48)|0)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   dest=$$01$i+0|0; src=$a+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $11 = (($$01$i) + 48|0);
  $12 = ($11>>>0)<($7>>>0);
  if ($12) {
   $$01$i = $11;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE6resizeEjRKc($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIcNS0_19ReflectionAllocatorIcEEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP8[$a>>0]|0;
   HEAP8[$$01$i>>0] = $11;
  }
  $12 = (($$01$i) + 1|0);
  $exitcond$i = ($12|0)==($7|0);
  if ($exitcond$i) {
   break;
  } else {
   $$01$i = $12;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ArticulationSim10sleepCheckEffb($this,$dt,$invDt,$0) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $invDt = Math_fround($invDt);
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre14 = 0, $$pre15 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$07 = 0, $i1$01 = 0;
 var $i2$04 = 0, $maxTimer$08 = Math_fround(0), $minTimer$06 = Math_fround(0), $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 51|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($12) + 28|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 if ($19) {
  __ZN5physx2Sc16ArticulationCore22setWakeCounterInternalEf($12,Math_fround(0.0));
 } else {
  $20 = $6;$i$07 = 1;$maxTimer$08 = Math_fround(0.0);$minTimer$06 = Math_fround(3.40282346638528859812E+38);
  while(1) {
   $21 = (Math_fround(__ZN5physx2Sc7BodySim17updateWakeCounterEffffb($20,$dt,$14,$16,$invDt,0)));
   $22 = $maxTimer$08 > $21;
   $23 = $22 ? $maxTimer$08 : $21;
   $24 = $minTimer$06 < $21;
   $25 = $24 ? $minTimer$06 : $21;
   $26 = HEAP32[$17>>2]|0;
   $27 = ($i$07>>>0)<($26>>>0);
   if (!($27)) {
    break;
   }
   $$pre14 = HEAP32[$4>>2]|0;
   $$phi$trans$insert = (($$pre14) + ($i$07<<2)|0);
   $$pre15 = HEAP32[$$phi$trans$insert>>2]|0;
   $phitmp = (($i$07) + 1)|0;
   $20 = $$pre15;$i$07 = $phitmp;$maxTimer$08 = $23;$minTimer$06 = $25;
  }
  $$pre = HEAP32[$11>>2]|0;
  __ZN5physx2Sc16ArticulationCore22setWakeCounterInternalEf($$pre,$23);
  $28 = $23 != Math_fround(0.0);
  if ($28) {
   $31 = $25 == Math_fround(0.0);
   if (!($31)) {
    STACKTOP = sp;return;
   }
   $32 = HEAP32[$17>>2]|0;
   $33 = ($32|0)==(0);
   if ($33) {
    STACKTOP = sp;return;
   } else {
    $i1$01 = 0;
   }
   while(1) {
    $34 = HEAP32[$4>>2]|0;
    $35 = (($34) + ($i1$01<<2)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($36) + 52|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (Math_fround(__ZNK5physx2Sc8BodyCore14getWakeCounterEv($38)));
    $40 = $39 < Math_fround(9.99999997475242707878E-7);
    $41 = $40 ? Math_fround(9.99999997475242707878E-7) : $39;
    $42 = (($38) + 152|0);
    HEAPF32[$42>>2] = $41;
    $43 = (($i1$01) + 1)|0;
    $44 = HEAP32[$17>>2]|0;
    $45 = ($43>>>0)<($44>>>0);
    if ($45) {
     $i1$01 = $43;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $29 = HEAP32[$17>>2]|0;
 $30 = ($29|0)==(0);
 if ($30) {
  STACKTOP = sp;return;
 } else {
  $i2$04 = 0;
 }
 while(1) {
  $46 = HEAP32[$4>>2]|0;
  $47 = (($46) + ($i2$04<<2)|0);
  $48 = HEAP32[$47>>2]|0;
  __ZN5physx2Sc7BodySim22notifyReadyForSleepingEv($48);
  $49 = HEAP32[$4>>2]|0;
  $50 = (($49) + ($i2$04<<2)|0);
  $51 = HEAP32[$50>>2]|0;
  __ZN5physx2Sc7BodySim16resetSleepFilterEv($51);
  $52 = (($i2$04) + 1)|0;
  $53 = HEAP32[$17>>2]|0;
  $54 = ($52>>>0)<($53>>>0);
  if ($54) {
   $i2$04 = $52;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc15ArticulationSim10isSleepingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $10 = 1;
  STACKTOP = sp;return ($10|0);
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 51|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 $10 = $9;
 STACKTOP = sp;return ($10|0);
}
function __ZN5physx2Sc15ArticulationSim14internalWakeUpEf($this,$wakeCounter) {
 $this = $this|0;
 $wakeCounter = Math_fround($wakeCounter);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (Math_fround(__ZNK5physx2Sc16ArticulationCore14getWakeCounterEv($1)));
 $3 = $2 < $wakeCounter;
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc16ArticulationCore22setWakeCounterInternalEf($4,$wakeCounter);
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 24|0);
 $i$01 = 0;
 while(1) {
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($i$01<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  __ZN5physx2Sc7BodySim30internalWakeUpArticulationLinkEf($11,$wakeCounter);
  $12 = (($i$01) + 1)|0;
  $13 = HEAP32[$5>>2]|0;
  $14 = ($12>>>0)<($13>>>0);
  if ($14) {
   $i$01 = $12;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ArticulationSim9setActiveEbj($this,$b,$infoFlag) {
 $this = $this|0;
 $b = $b|0;
 $infoFlag = $infoFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $6 = $1;$i$01 = 0;
 while(1) {
  $4 = (($i$01) + 1)|0;
  $5 = ($4>>>0)<($6>>>0);
  if ($5) {
   $7 = HEAP32[$3>>2]|0;
   $8 = (($7) + ($4<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$3>>2]|0;
   $11 = (($10) + ($4<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 128|0);
  }
  $14 = HEAP32[$3>>2]|0;
  $15 = (($14) + ($i$01<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  __ZN5physx2Sc5Actor9setActiveEbj($16,$b,$infoFlag);
  $17 = HEAP32[$0>>2]|0;
  $18 = ($4>>>0)<($17>>>0);
  if ($18) {
   $6 = $17;$i$01 = $4;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ArticulationSim12updateForcesEffbRKNS_6PxVec3Ebb($this,$dt,$oneOverDt,$updateGravity,$gravity,$hasStaticTouch,$simUsesAdaptiveForce) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $oneOverDt = Math_fround($oneOverDt);
 $updateGravity = $updateGravity|0;
 $gravity = $gravity|0;
 $hasStaticTouch = $hasStaticTouch|0;
 $simUsesAdaptiveForce = $simUsesAdaptiveForce|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $6 = $1;$i$01 = 0;
 while(1) {
  $4 = (($i$01) + 1)|0;
  $5 = ($4>>>0)<($6>>>0);
  if ($5) {
   $7 = HEAP32[$3>>2]|0;
   $8 = (($7) + ($4<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 128|0);
   $11 = HEAP32[$3>>2]|0;
   $12 = (($11) + ($4<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 256|0);
  }
  $15 = HEAP32[$3>>2]|0;
  $16 = (($15) + ($i$01<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  __ZN5physx2Sc7BodySim12updateForcesEffbRKNS_6PxVec3Ebb($17,$dt,$oneOverDt,$updateGravity,$gravity,$hasStaticTouch,$simUsesAdaptiveForce);
  $18 = HEAP32[$0>>2]|0;
  $19 = ($4>>>0)<($18>>>0);
  if ($19) {
   $6 = $18;$i$01 = $4;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc15ArticulationSim16createDriveCacheEfj($this,$compliance,$driveIterations) {
 $this = $this|0;
 $compliance = Math_fround($compliance);
 $driveIterations = $driveIterations|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scratchSize = 0, $solverDataSize = 0, $totalSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $solverDataSize = sp + 8|0;
 $totalSize = sp;
 $scratchSize = sp + 4|0;
 $0 = sp + 12|0;
 __ZNK5physx2Sc15ArticulationSim11checkResizeEv($this);
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx21PxcArticulationHelper12getDataSizesEjRjS1_S1_($2,$solverDataSize,$totalSize,$scratchSize);
 $3 = HEAP32[$totalSize>>2]|0;
 $4 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$3,457360,408)|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = $5&65535;
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 148|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 152|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN5physx21PxcArticulationHelper20initializeDriveCacheERNS_9PxcFsDataEtPKNS_19PxsArticulationLinkEfjPcj($4,$6,$8,$compliance,$driveIterations,$10,$12);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc15ArticulationSim16updateDriveCacheERNS_9PxcFsDataEfj($this,$cache,$compliance,$driveIterations) {
 $this = $this|0;
 $cache = $cache|0;
 $compliance = Math_fround($compliance);
 $driveIterations = $driveIterations|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK5physx2Sc15ArticulationSim11checkResizeEv($this);
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1&65535;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 152|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx21PxcArticulationHelper20initializeDriveCacheERNS_9PxcFsDataEtPKNS_19PxsArticulationLinkEfjPcj($cache,$2,$4,$compliance,$driveIterations,$6,$8);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc15ArticulationSim17releaseDriveCacheERNS_9PxcFsDataE($this,$driveCache) {
 $this = $this|0;
 $driveCache = $driveCache|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$driveCache);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ArticulationSim12applyImpulseERNS0_8BodyCoreERKNS_9PxcFsDataERKNS_6PxVec3ES9_($this,$link,$driveCache,$force,$torque) {
 $this = $this|0;
 $link = $link|0;
 $driveCache = $driveCache|0;
 $force = $force|0;
 $torque = $torque|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0;
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $8 = 0, $9 = 0, $i$01$i = 0;
 var $i$036 = 0, $v = 0, $z = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4096|0;
 $v = sp + 2048|0;
 $z = sp;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 5;
 _memset(($z|0),0,($2|0))|0;
 _memset(($v|0),0,($2|0))|0;
 $3 = (__ZNK5physx2Sc8BodyCore6getSimEv($link)|0);
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 L1: do {
  if ($6) {
   $$0$i = -2147483648;
  } else {
   $7 = (($this) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $i$01$i = 0;
   while(1) {
    $11 = (($8) + ($i$01$i<<2)|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($3|0);
    $10 = (($i$01$i) + 1)|0;
    if ($13) {
     $$0$i = $i$01$i;
     break L1;
    }
    $9 = ($10>>>0)<($5>>>0);
    if ($9) {
     $i$01$i = $10;
    } else {
     $$0$i = -2147483648;
     break;
    }
   }
  }
 } while(0);
 $14 = Math_fround(HEAPF32[$force>>2]);
 $15 = Math_fround(-$14);
 $16 = (($force) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(-$17);
 $19 = (($force) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(-$20);
 $22 = (($z) + ($$0$i<<5)|0);
 HEAPF32[$22>>2] = $15;
 $23 = ((($z) + ($$0$i<<5)|0) + 4|0);
 HEAPF32[$23>>2] = $18;
 $24 = ((($z) + ($$0$i<<5)|0) + 8|0);
 HEAPF32[$24>>2] = $21;
 $25 = ((($z) + ($$0$i<<5)|0) + 12|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = Math_fround(HEAPF32[$torque>>2]);
 $27 = Math_fround(-$26);
 $28 = (($torque) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround(-$29);
 $31 = (($torque) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(-$32);
 $34 = ((($z) + ($$0$i<<5)|0) + 16|0);
 HEAPF32[$34>>2] = $27;
 $35 = ((($z) + ($$0$i<<5)|0) + 20|0);
 HEAPF32[$35>>2] = $30;
 $36 = ((($z) + ($$0$i<<5)|0) + 24|0);
 HEAPF32[$36>>2] = $33;
 $37 = ((($z) + ($$0$i<<5)|0) + 28|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 __ZN5physx21PxcArticulationHelper13applyImpulsesERKNS_9PxcFsDataEPNS_14PxcSIMDSpatialES5_($driveCache,$z,$v);
 $38 = HEAP32[$0>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 24|0);
 $$pre = HEAP32[$40>>2]|0;
 $i$036 = 0;
 while(1) {
  $41 = (($$pre) + ($i$036<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + 52|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($v) + ($i$036<<5)|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = ((($v) + ($i$036<<5)|0) + 4|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = ((($v) + ($i$036<<5)|0) + 8|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = ((($v) + ($i$036<<5)|0) + 16|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = ((($v) + ($i$036<<5)|0) + 20|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = ((($v) + ($i$036<<5)|0) + 24|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($44) + 80|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($46 + $58);
  $60 = (($44) + 84|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($48 + $61);
  $63 = (($44) + 88|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($50 + $64);
  HEAPF32[$57>>2] = $59;
  HEAPF32[$60>>2] = $62;
  HEAPF32[$63>>2] = $65;
  $66 = (($44) + 96|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($52 + $67);
  $69 = (($44) + 100|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($54 + $70);
  $72 = (($44) + 104|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($56 + $73);
  HEAPF32[$66>>2] = $68;
  HEAPF32[$69>>2] = $71;
  HEAPF32[$72>>2] = $74;
  $75 = (($i$036) + 1)|0;
  $76 = ($75>>>0)<($38>>>0);
  if ($76) {
   $i$036 = $75;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc15ArticulationSim22computeImpulseResponseERNS0_8BodyCoreERNS_6PxVec3ES5_RKNS_9PxcFsDataERKS4_SA_($this,$link,$linearResponse,$angularResponse,$driveCache,$force,$torque) {
 $this = $this|0;
 $link = $link|0;
 $linearResponse = $linearResponse|0;
 $angularResponse = $angularResponse|0;
 $driveCache = $driveCache|0;
 $force = $force|0;
 $torque = $torque|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $v = sp + 32|0;
 $0 = sp;
 $1 = (__ZNK5physx2Sc8BodyCore6getSimEv($link)|0);
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0$i = -2147483648;
  } else {
   $5 = (($this) + 24|0);
   $6 = HEAP32[$5>>2]|0;
   $i$01$i = 0;
   while(1) {
    $9 = (($6) + ($i$01$i<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($1|0);
    $8 = (($i$01$i) + 1)|0;
    if ($11) {
     $$0$i = $i$01$i;
     break L1;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $i$01$i = $8;
    } else {
     $$0$i = -2147483648;
     break;
    }
   }
  }
 } while(0);
 $12 = Math_fround(HEAPF32[$force>>2]);
 $13 = (($force) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($force) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$torque>>2]);
 $18 = (($torque) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($torque) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$0>>2] = $12;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $14;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $16;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($0) + 16|0);
 HEAPF32[$25>>2] = $17;
 $26 = (($0) + 20|0);
 HEAPF32[$26>>2] = $19;
 $27 = (($0) + 24|0);
 HEAPF32[$27>>2] = $21;
 $28 = (($0) + 28|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 __ZN5physx21PxcArticulationHelper18getImpulseResponseERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS4_($driveCache,$$0$i,$0,$v);
 $29 = Math_fround(HEAPF32[$v>>2]);
 $30 = (($v) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($v) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$linearResponse>>2] = $29;
 $34 = (($linearResponse) + 4|0);
 HEAPF32[$34>>2] = $31;
 $35 = (($linearResponse) + 8|0);
 HEAPF32[$35>>2] = $33;
 $36 = (($v) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($v) + 20|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($v) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 HEAPF32[$angularResponse>>2] = $37;
 $42 = (($angularResponse) + 4|0);
 HEAPF32[$42>>2] = $39;
 $43 = (($angularResponse) + 8|0);
 HEAPF32[$43>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS0_3aos6Mat33VENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*48)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 457624 : 457592;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,457512,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*48)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    dest=$$012$i+0|0; src=$$03$i+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $20 = (($$012$i) + 48|0);
   $21 = (($$03$i) + 48|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11PxTransformENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*28)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 457752 : 457592;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,457512,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*28)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
    $30 = (($$012$i) + 16|0);
    $31 = (($$03$i) + 16|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    HEAPF32[$30>>2] = $32;
    $33 = (($$012$i) + 20|0);
    $34 = (($$03$i) + 20|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    HEAPF32[$33>>2] = $35;
    $36 = (($$012$i) + 24|0);
    $37 = (($$03$i) + 24|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    HEAPF32[$36>>2] = $38;
   }
   $39 = (($$012$i) + 28|0);
   $40 = (($$03$i) + 28|0);
   $41 = ($39>>>0)<($15>>>0);
   if ($41) {
    $$012$i = $39;$$03$i = $40;
   } else {
    break;
   }
  }
 }
 $42 = (($this) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)>(-1);
 if (!($44)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$42>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$this>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  HEAP32[$this>>2] = $16;
  HEAP32[$42>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $47 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + 12|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_vii[$50 & 4095]($47,$45);
 HEAP32[$this>>2] = $16;
 HEAP32[$42>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_14PxcSIMDSpatialENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 457864 : 457592;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,457512,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<5)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
    $20 = (($$012$i) + 16|0);
    $21 = (($$03$i) + 16|0);
    ;HEAP32[$20+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$21+12>>2]|0;
   }
   $22 = (($$012$i) + 32|0);
   $23 = (($$03$i) + 32|0);
   $24 = ($22>>>0)<($15>>>0);
   if ($24) {
    $$012$i = $22;$$03$i = $23;
   } else {
    break;
   }
  }
 }
 $25 = (($this) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if (!($27)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$25>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = HEAP32[$this>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  HEAP32[$this>>2] = $16;
  HEAP32[$25>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $30 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vii[$33 & 4095]($30,$28);
 HEAP32[$this>>2] = $16;
 HEAP32[$25>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_19PxsArticulationLinkENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 457984 : 457592;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,457512,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<5)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;HEAP32[$$012$i+24>>2]=HEAP32[$$03$i+24>>2]|0;HEAP32[$$012$i+28>>2]=HEAP32[$$03$i+28>>2]|0;
   }
   $20 = (($$012$i) + 32|0);
   $21 = (($$03$i) + 32|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc20ArticulationJointSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 458112 : 457592;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,457512,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc7BodySimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 458256 : 457592;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,457512,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc7BodySimENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 458256 : 457592;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,457512,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc20ArticulationJointSimENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 458112 : 457592;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,457512,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCoreC2ENS_11PxActorType4EnumERKNS_11PxTransformE($this,$type,$bodyPose) {
 $this = $this|0;
 $type = $type|0;
 $bodyPose = $bodyPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc9RigidCoreC2ENS_11PxActorType4EnumE($this,$type);
 $0 = (($this) + 44|0);
 HEAP8[$0>>0] = 0;
 $1 = HEAP32[463296>>2]|0;
 $2 = Math_fround(HEAPF32[463304>>2]);
 $3 = (($this) + 152|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($this) + 128|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 132|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 136|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($this) + 140|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = Math_fround(HEAPF32[$bodyPose>>2]);
 $9 = (($this) + 16|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($bodyPose) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 20|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($bodyPose) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 24|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($bodyPose) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 28|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($bodyPose) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 32|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($bodyPose) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 36|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($bodyPose) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 40|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($1) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * Math_fround(4.99999987368937581778E-5));
 $31 = Math_fround($29 * $30);
 $32 = (($this) + 144|0);
 HEAPF32[$32>>2] = $31;
 $33 = Math_fround(HEAPF32[$28>>2]);
 $34 = Math_fround($33 * Math_fround(9.99999974737875163555E-6));
 $35 = Math_fround($33 * $34);
 $36 = (($this) + 148|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($this) + 156|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 92|0);
 HEAPF32[$38>>2] = Math_fround(-1.0000000331813535141E+32);
 HEAP8[$0>>0] = 0;
 $39 = (($this) + 80|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($this) + 84|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($this) + 88|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($this) + 96|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($this) + 100|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($this) + 104|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($this) + 120|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($this) + 116|0);
 HEAPF32[$46>>2] = Math_fround(3.40282346638528859812E+38);
 $47 = (($this) + 46|0);
 HEAP16[$47>>1] = 260;
 $48 = (($this) + 108|0);
 HEAPF32[$48>>2] = Math_fround(3.40282346638528859812E+38);
 $49 = (($this) + 48|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($this) + 52|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($this) + 56|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($this) + 60|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($this) + 64|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($this) + 68|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($this) + 72|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($this) + 76|0);
 HEAPF32[$56>>2] = Math_fround(0.150000005960464477539);
 $57 = (($this) + 45|0);
 HEAP8[$57>>0] = 0;
 $58 = ($type|0)==(1);
 $59 = (($this) + 124|0);
 if ($58) {
  HEAPF32[$59>>2] = Math_fround(0.0500000007450580596924);
  $60 = (($this) + 112|0);
  HEAPF32[$60>>2] = Math_fround(49.0);
  STACKTOP = sp;return;
 } else {
  HEAPF32[$59>>2] = Math_fround(0.0);
  $61 = (($this) + 112|0);
  HEAPF32[$61>>2] = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc8BodyCoreD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc9RigidCoreD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore6getSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc8BodyCore24setCCDAdvanceCoefficientEf($this,$ccdAdvanceCoefficient) {
 $this = $this|0;
 $ccdAdvanceCoefficient = Math_fround($ccdAdvanceCoefficient);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 HEAPF32[$0>>2] = $ccdAdvanceCoefficient;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore13setBody2WorldERKNS_11PxTransformE($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$p>>2]);
 $1 = (($this) + 16|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($p) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 20|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($p) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 24|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($p) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 28|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($p) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 32|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($p) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 36|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($p) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 40|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($this) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc7BodySim20postBody2WorldChangeEv($21);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore22addSpatialAccelerationEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEPKNS_6PxVec3ESB_($this,$simStateDataPool,$linAcc,$angAcc) {
 $this = $this|0;
 $simStateDataPool = $simStateDataPool|0;
 $linAcc = $linAcc|0;
 $angAcc = $angAcc|0;
 var $$pre$i$i1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vData$0$i = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5physx2Sc7BodySim28notifyAddSpatialAccelerationEv($1);
 }
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $9 = (($simStateDataPool) + 292|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($simStateDataPool);
   $$pre$i$i1$i = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i1$i;
  } else {
   $13 = $10;
  }
  $12 = HEAP32[$13>>2]|0;
  HEAP32[$9>>2] = $12;
  $14 = (($simStateDataPool) + 280|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 1)|0;
  HEAP32[$14>>2] = $16;
  $17 = (($simStateDataPool) + 284|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + -1)|0;
  HEAP32[$17>>2] = $19;
  $20 = ($13|0)==(0|0);
  if ($20) {
   $vData$0$i = 0;
   label = 9;
  } else {
   $vData$0$i = $13;
   label = 9;
  }
 } else {
  $6 = (($4) + 31|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $22 = $4;
  } else {
   $vData$0$i = $4;
   label = 9;
  }
 }
 if ((label|0) == 9) {
  dest=$vData$0$i+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  ;HEAP32[$vData$0$i+0>>2]=0|0;HEAP32[$vData$0$i+4>>2]=0|0;HEAP32[$vData$0$i+8>>2]=0|0;HEAP8[$vData$0$i+12>>0]=0|0;
  HEAP32[$3>>2] = $vData$0$i;
  $22 = $vData$0$i;
 }
 $21 = (($22) + 12|0);
 $23 = HEAP8[$21>>0]|0;
 $24 = $23&255;
 $25 = $24 | 2;
 $26 = $25&255;
 HEAP8[$21>>0] = $26;
 $27 = ($linAcc|0)==(0|0);
 if (!($27)) {
  $28 = Math_fround(HEAPF32[$linAcc>>2]);
  $29 = Math_fround(HEAPF32[$22>>2]);
  $30 = Math_fround($28 + $29);
  HEAPF32[$22>>2] = $30;
  $31 = (($linAcc) + 4|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($22) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($32 + $34);
  HEAPF32[$33>>2] = $35;
  $36 = (($linAcc) + 8|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($22) + 8|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($37 + $39);
  HEAPF32[$38>>2] = $40;
 }
 $41 = ($angAcc|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = Math_fround(HEAPF32[$angAcc>>2]);
 $43 = (($22) + 16|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($42 + $44);
 HEAPF32[$43>>2] = $45;
 $46 = (($angAcc) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($22) + 20|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($47 + $49);
 HEAPF32[$48>>2] = $50;
 $51 = (($angAcc) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($22) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($52 + $54);
 HEAPF32[$53>>2] = $55;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore17setupSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEbb($this,$simStateDataPool,$isKinematic,$targetValid) {
 $this = $this|0;
 $simStateDataPool = $simStateDataPool|0;
 $isKinematic = $isKinematic|0;
 $targetValid = $targetValid|0;
 var $$pre$i$i = 0, $$pre$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $kData$0 = 0, $storemerge = 0, $vData$0 = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($isKinematic) {
  if ($2) {
   $3 = (($simStateDataPool) + 292|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($simStateDataPool);
    $$pre$i$i = HEAP32[$3>>2]|0;
    $7 = $$pre$i$i;
   } else {
    $7 = $4;
   }
   $6 = HEAP32[$7>>2]|0;
   HEAP32[$3>>2] = $6;
   $8 = (($simStateDataPool) + 280|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 1)|0;
   HEAP32[$8>>2] = $10;
   $11 = (($simStateDataPool) + 284|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + -1)|0;
   HEAP32[$11>>2] = $13;
   $14 = ($7|0)==(0|0);
   if ($14) {
    $kData$0 = 0;
   } else {
    $kData$0 = $7;
   }
  } else {
   $kData$0 = $1;
  }
  dest=$kData$0+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  $15 = (($kData$0) + 31|0);
  HEAP8[$15>>0] = 1;
  $16 = $targetValid&1;
  $17 = (($kData$0) + 28|0);
  HEAP8[$17>>0] = $16;
  $18 = (($this) + 120|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($kData$0) + 48|0);
  HEAPF32[$20>>2] = $19;
  $21 = (($this) + 124|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($kData$0) + 52|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($kData$0) + 32|0);
  $25 = (($this) + 128|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$24>>2] = $26;
  $27 = (($this) + 132|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($kData$0) + 36|0);
  HEAPF32[$29>>2] = $28;
  $30 = (($this) + 136|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($kData$0) + 40|0);
  HEAPF32[$32>>2] = $31;
  $33 = (($this) + 140|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($kData$0) + 44|0);
  HEAPF32[$35>>2] = $34;
  $36 = (($this) + 112|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($kData$0) + 56|0);
  HEAPF32[$38>>2] = $37;
  $39 = (($this) + 116|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($kData$0) + 60|0);
  HEAPF32[$41>>2] = $40;
  ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;
  HEAPF32[$36>>2] = Math_fround(3.40282346638528859812E+38);
  HEAPF32[$39>>2] = Math_fround(3.40282346638528859812E+38);
  $storemerge = $kData$0;
  HEAP32[$0>>2] = $storemerge;
  STACKTOP = sp;return 1;
 } else {
  if ($2) {
   $42 = (($simStateDataPool) + 292|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($simStateDataPool);
    $$pre$i$i1 = HEAP32[$42>>2]|0;
    $46 = $$pre$i$i1;
   } else {
    $46 = $43;
   }
   $45 = HEAP32[$46>>2]|0;
   HEAP32[$42>>2] = $45;
   $47 = (($simStateDataPool) + 280|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + 1)|0;
   HEAP32[$47>>2] = $49;
   $50 = (($simStateDataPool) + 284|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + -1)|0;
   HEAP32[$50>>2] = $52;
   $53 = ($46|0)==(0|0);
   if ($53) {
    $vData$0 = 0;
   } else {
    $vData$0 = $46;
   }
  } else {
   $vData$0 = $1;
  }
  dest=$vData$0+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  ;HEAP32[$vData$0+0>>2]=0|0;HEAP32[$vData$0+4>>2]=0|0;HEAP32[$vData$0+8>>2]=0|0;HEAP8[$vData$0+12>>0]=0|0;
  $storemerge = $vData$0;
  HEAP32[$0>>2] = $storemerge;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5physx2Sc8BodyCore24clearSpatialAccelerationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5physx2Sc7BodySim30notifyClearSpatialAccelerationEv($1);
 }
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($4) + 12|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 | 2;
 $10 = $9&255;
 HEAP8[$6>>0] = $10;
 HEAPF32[$4>>2] = Math_fround(0.0);
 $11 = (($4) + 4|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($4) + 8|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($4) + 16|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($4) + 20|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($4) + 24|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore18addSpatialVelocityEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEPKNS_6PxVec3ESB_($this,$simStateDataPool,$linVelDelta,$angVelDelta) {
 $this = $this|0;
 $simStateDataPool = $simStateDataPool|0;
 $linVelDelta = $linVelDelta|0;
 $angVelDelta = $angVelDelta|0;
 var $$pre$i$i1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vData$0$i = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5physx2Sc7BodySim24notifyAddSpatialVelocityEv($1);
 }
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $9 = (($simStateDataPool) + 292|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($simStateDataPool);
   $$pre$i$i1$i = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i1$i;
  } else {
   $13 = $10;
  }
  $12 = HEAP32[$13>>2]|0;
  HEAP32[$9>>2] = $12;
  $14 = (($simStateDataPool) + 280|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 1)|0;
  HEAP32[$14>>2] = $16;
  $17 = (($simStateDataPool) + 284|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + -1)|0;
  HEAP32[$17>>2] = $19;
  $20 = ($13|0)==(0|0);
  if ($20) {
   $vData$0$i = 0;
   label = 9;
  } else {
   $vData$0$i = $13;
   label = 9;
  }
 } else {
  $6 = (($4) + 31|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $22 = $4;
  } else {
   $vData$0$i = $4;
   label = 9;
  }
 }
 if ((label|0) == 9) {
  dest=$vData$0$i+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  ;HEAP32[$vData$0$i+0>>2]=0|0;HEAP32[$vData$0$i+4>>2]=0|0;HEAP32[$vData$0$i+8>>2]=0|0;HEAP8[$vData$0$i+12>>0]=0|0;
  HEAP32[$3>>2] = $vData$0$i;
  $22 = $vData$0$i;
 }
 $21 = (($22) + 12|0);
 $23 = HEAP8[$21>>0]|0;
 $24 = $23&255;
 $25 = $24 | 4;
 $26 = $25&255;
 HEAP8[$21>>0] = $26;
 $27 = ($linVelDelta|0)==(0|0);
 if (!($27)) {
  $28 = Math_fround(HEAPF32[$linVelDelta>>2]);
  $29 = (($22) + 32|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($28 + $30);
  HEAPF32[$29>>2] = $31;
  $32 = (($linVelDelta) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($22) + 36|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($33 + $35);
  HEAPF32[$34>>2] = $36;
  $37 = (($linVelDelta) + 8|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($22) + 40|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($38 + $40);
  HEAPF32[$39>>2] = $41;
 }
 $42 = ($angVelDelta|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = Math_fround(HEAPF32[$angVelDelta>>2]);
 $44 = (($22) + 48|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 + $45);
 HEAPF32[$44>>2] = $46;
 $47 = (($angVelDelta) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($22) + 52|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($48 + $50);
 HEAPF32[$49>>2] = $51;
 $52 = (($angVelDelta) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($22) + 56|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($53 + $55);
 HEAPF32[$54>>2] = $56;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore20clearSpatialVelocityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5physx2Sc7BodySim26notifyClearSpatialVelocityEv($1);
 }
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($4) + 12|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 | 4;
 $10 = $9&255;
 HEAP8[$6>>0] = $10;
 $11 = (($4) + 32|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($4) + 36|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($4) + 40|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($4) + 48|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($4) + 52|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($4) + 56|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore14getInverseMassEv($this) {
 $this = $this|0;
 var $$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 44|0);
   $$in = $6;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($this) + 140|0);
  $$in = $7;
 }
 $8 = Math_fround(HEAPF32[$$in>>2]);
 STACKTOP = sp;return (Math_fround($8));
}
function __ZN5physx2Sc8BodyCore14setInverseMassEf($this,$m) {
 $this = $this|0;
 $m = Math_fround($m);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 44|0);
   HEAPF32[$6>>2] = $m;
   STACKTOP = sp;return;
  }
 }
 $7 = (($this) + 140|0);
 HEAPF32[$7>>2] = $m;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore17getInverseInertiaEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 32|0);
   $8 = $6;
   STACKTOP = sp;return ($8|0);
  }
 }
 $7 = (($this) + 128|0);
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx2Sc8BodyCore17setInverseInertiaERKNS_6PxVec3E($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0);
 var $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 32|0);
   $7 = Math_fround(HEAPF32[$i>>2]);
   HEAPF32[$6>>2] = $7;
   $8 = (($i) + 4|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = (($1) + 36|0);
   HEAPF32[$10>>2] = $9;
   $11 = (($i) + 8|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = (($1) + 40|0);
   HEAPF32[$13>>2] = $12;
   STACKTOP = sp;return;
  }
 }
 $14 = Math_fround(HEAPF32[$i>>2]);
 $15 = (($this) + 128|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($i) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 132|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($i) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 136|0);
 HEAPF32[$21>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore16getLinearDampingEv($this) {
 $this = $this|0;
 var $$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 48|0);
   $$in = $6;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($this) + 120|0);
  $$in = $7;
 }
 $8 = Math_fround(HEAPF32[$$in>>2]);
 STACKTOP = sp;return (Math_fround($8));
}
function __ZN5physx2Sc8BodyCore16setLinearDampingEf($this,$d) {
 $this = $this|0;
 $d = Math_fround($d);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 48|0);
   HEAPF32[$6>>2] = $d;
   STACKTOP = sp;return;
  }
 }
 $7 = (($this) + 120|0);
 HEAPF32[$7>>2] = $d;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore17getAngularDampingEv($this) {
 $this = $this|0;
 var $$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 52|0);
   $$in = $6;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($this) + 124|0);
  $$in = $7;
 }
 $8 = Math_fround(HEAPF32[$$in>>2]);
 STACKTOP = sp;return (Math_fround($8));
}
function __ZN5physx2Sc8BodyCore17setAngularDampingEf($this,$v) {
 $this = $this|0;
 $v = Math_fround($v);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 52|0);
   HEAPF32[$6>>2] = $v;
   STACKTOP = sp;return;
  }
 }
 $7 = (($this) + 124|0);
 HEAPF32[$7>>2] = $v;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore14getMaxAngVelSqEv($this) {
 $this = $this|0;
 var $$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 56|0);
   $$in = $6;
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($this) + 112|0);
  $$in = $7;
 }
 $8 = Math_fround(HEAPF32[$$in>>2]);
 STACKTOP = sp;return (Math_fround($8));
}
function __ZN5physx2Sc8BodyCore14setMaxAngVelSqEf($this,$v) {
 $this = $this|0;
 $v = Math_fround($v);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 31|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(1);
  if ($5) {
   $6 = (($1) + 56|0);
   HEAPF32[$6>>2] = $v;
   STACKTOP = sp;return;
  }
 }
 $7 = (($this) + 112|0);
 HEAPF32[$7>>2] = $v;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore8setFlagsEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE($this,$simStateDataPool,$f) {
 $this = $this|0;
 $simStateDataPool = $simStateDataPool|0;
 $f = $f|0;
 var $$ = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $kData$0$i = 0, $not$ = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = HEAP8[$f>>0]|0;
 $3 = ($2<<24>>24)==($1<<24>>24);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $2&255;
 $5 = $4 & 1;
 $6 = $1 & 1;
 $7 = ($6<<24>>24)!=(0);
 $8 = ($5|0)!=(0);
 $not$ = $7 ^ 1;
 $$ = $8 & $not$;
 $9 = ($5|0)==(0);
 $10 = $7 & $9;
 if ($$) {
  __ZN5physx2Sc8BodyCore10putToSleepEv($this);
  $$pre = HEAP8[$f>>0]|0;
  $11 = $$pre;
 } else {
  $11 = $2;
 }
 HEAP8[$0>>0] = $11;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 if ($$) {
  $15 = (($this) + 156|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $18 = (($simStateDataPool) + 292|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($simStateDataPool);
    $$pre$i$i$i = HEAP32[$18>>2]|0;
    $22 = $$pre$i$i$i;
   } else {
    $22 = $19;
   }
   $21 = HEAP32[$22>>2]|0;
   HEAP32[$18>>2] = $21;
   $23 = (($simStateDataPool) + 280|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + 1)|0;
   HEAP32[$23>>2] = $25;
   $26 = (($simStateDataPool) + 284|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + -1)|0;
   HEAP32[$26>>2] = $28;
   $29 = ($22|0)==(0|0);
   if ($29) {
    $kData$0$i = 0;
   } else {
    $kData$0$i = $22;
   }
  } else {
   $kData$0$i = $16;
  }
  dest=$kData$0$i+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  $30 = (($kData$0$i) + 31|0);
  HEAP8[$30>>0] = 1;
  $31 = (($kData$0$i) + 28|0);
  HEAP8[$31>>0] = 0;
  $32 = (($this) + 120|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($kData$0$i) + 48|0);
  HEAPF32[$34>>2] = $33;
  $35 = (($this) + 124|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($kData$0$i) + 52|0);
  HEAPF32[$37>>2] = $36;
  $38 = (($kData$0$i) + 32|0);
  $39 = (($this) + 128|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$38>>2] = $40;
  $41 = (($this) + 132|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($kData$0$i) + 36|0);
  HEAPF32[$43>>2] = $42;
  $44 = (($this) + 136|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($kData$0$i) + 40|0);
  HEAPF32[$46>>2] = $45;
  $47 = (($this) + 140|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($kData$0$i) + 44|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($this) + 112|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($kData$0$i) + 56|0);
  HEAPF32[$52>>2] = $51;
  $53 = (($this) + 116|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($kData$0$i) + 60|0);
  HEAPF32[$55>>2] = $54;
  ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;HEAP32[$32+20>>2]=0|0;
  HEAPF32[$50>>2] = Math_fround(3.40282346638528859812E+38);
  HEAPF32[$53>>2] = Math_fround(3.40282346638528859812E+38);
  HEAP32[$15>>2] = $kData$0$i;
  __ZN5physx2Sc7BodySim21postSwitchToKinematicEv($13);
  STACKTOP = sp;return;
 }
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $56 = (($this) + 156|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 if (!($58)) {
  $59 = (($57) + 44|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($this) + 140|0);
  HEAPF32[$61>>2] = $60;
  $62 = (($57) + 32|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($this) + 128|0);
  HEAPF32[$64>>2] = $63;
  $65 = (($57) + 36|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = (($this) + 132|0);
  HEAPF32[$67>>2] = $66;
  $68 = (($57) + 40|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($this) + 136|0);
  HEAPF32[$70>>2] = $69;
  $71 = (($57) + 48|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($this) + 120|0);
  HEAPF32[$73>>2] = $72;
  $74 = (($57) + 52|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = (($this) + 124|0);
  HEAPF32[$76>>2] = $75;
  $77 = (($57) + 56|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($this) + 112|0);
  HEAPF32[$79>>2] = $78;
  $80 = (($57) + 60|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($this) + 116|0);
  HEAPF32[$82>>2] = $81;
  $83 = (($simStateDataPool) + 280|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + -1)|0;
  HEAP32[$83>>2] = $85;
  $86 = (($simStateDataPool) + 292|0);
  $87 = HEAP32[$86>>2]|0;
  HEAP32[$57>>2] = $87;
  HEAP32[$86>>2] = $57;
  $88 = (($simStateDataPool) + 284|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (($89) + 1)|0;
  HEAP32[$88>>2] = $90;
  $91 = (($simStateDataPool) + 276|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92*50)|0;
  $94 = ($89|0)<($93|0);
  if (!($94)) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($simStateDataPool);
   HEAP32[$88>>2] = 0;
  }
  HEAP32[$56>>2] = 0;
 }
 __ZN5physx2Sc7BodySim19postSwitchToDynamicEv($13);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore10putToSleepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 84|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 88|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 96|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($this) + 100|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 104|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)!=(0|0);
 if ($8) {
  __ZN5physx2Sc7BodySim30notifyClearSpatialAccelerationEv($7);
  __ZN5physx2Sc7BodySim26notifyClearSpatialVelocityEv($7);
 }
 $9 = (($this) + 156|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = (($10) + 31|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($10) + 48|0);
   HEAPF32[$15>>2] = Math_fround(0.0);
   $16 = (($10) + 52|0);
   HEAPF32[$16>>2] = Math_fround(0.0);
   $17 = (($10) + 56|0);
   HEAPF32[$17>>2] = Math_fround(0.0);
   $18 = (($10) + 32|0);
   HEAPF32[$18>>2] = Math_fround(0.0);
   $19 = (($10) + 36|0);
   HEAPF32[$19>>2] = Math_fround(0.0);
   $20 = (($10) + 40|0);
   HEAPF32[$20>>2] = Math_fround(0.0);
   $21 = (($10) + 16|0);
   HEAPF32[$21>>2] = Math_fround(0.0);
   $22 = (($10) + 20|0);
   HEAPF32[$22>>2] = Math_fround(0.0);
   $23 = (($10) + 24|0);
   HEAPF32[$23>>2] = Math_fround(0.0);
   HEAPF32[$10>>2] = Math_fround(0.0);
   $24 = (($10) + 4|0);
   HEAPF32[$24>>2] = Math_fround(0.0);
   $25 = (($10) + 8|0);
   HEAPF32[$25>>2] = Math_fround(0.0);
  }
 }
 $26 = (($this) + 152|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = HEAP32[$6>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  __ZN5physx2Sc7BodySim18postSetWakeCounterEfb($27,Math_fround(0.0),0);
 }
 if (!($8)) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc7BodySim10putToSleepEv($7);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($this,$simStateDataPool,$isKinematic) {
 $this = $this|0;
 $simStateDataPool = $simStateDataPool|0;
 $isKinematic = $isKinematic|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 if ($isKinematic) {
  $3 = (($1) + 44|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($this) + 140|0);
  HEAPF32[$5>>2] = $4;
  $6 = (($1) + 32|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($this) + 128|0);
  HEAPF32[$8>>2] = $7;
  $9 = (($1) + 36|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($this) + 132|0);
  HEAPF32[$11>>2] = $10;
  $12 = (($1) + 40|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($this) + 136|0);
  HEAPF32[$14>>2] = $13;
  $15 = (($1) + 48|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($this) + 120|0);
  HEAPF32[$17>>2] = $16;
  $18 = (($1) + 52|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($this) + 124|0);
  HEAPF32[$20>>2] = $19;
  $21 = (($1) + 56|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($this) + 112|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($1) + 60|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($this) + 116|0);
  HEAPF32[$26>>2] = $25;
 }
 $27 = (($simStateDataPool) + 280|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + -1)|0;
 HEAP32[$27>>2] = $29;
 $30 = (($simStateDataPool) + 292|0);
 $31 = HEAP32[$30>>2]|0;
 HEAP32[$1>>2] = $31;
 HEAP32[$30>>2] = $1;
 $32 = (($simStateDataPool) + 284|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 1)|0;
 HEAP32[$32>>2] = $34;
 $35 = (($simStateDataPool) + 276|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36*50)|0;
 $38 = ($33|0)<($37|0);
 if (!($38)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($simStateDataPool);
  HEAP32[$32>>2] = 0;
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore14getWakeCounterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc8BodyCore14setWakeCounterEfb($this,$wakeCounter,$forceWakeUp) {
 $this = $this|0;
 $wakeCounter = Math_fround($wakeCounter);
 $forceWakeUp = $forceWakeUp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 HEAPF32[$0>>2] = $wakeCounter;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $wakeCounter > Math_fround(0.0);
 $brmerge = $4 | $forceWakeUp;
 if ($brmerge) {
  __ZN5physx2Sc7BodySim6wakeUpEv($2);
 }
 __ZN5physx2Sc7BodySim18postSetWakeCounterEfb($2,$wakeCounter,$forceWakeUp);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore10isSleepingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $7 = 1;
  STACKTOP = sp;return ($7|0);
 }
 $3 = (($1) + 51|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx2Sc8BodyCore18setKinematicTargetEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEERKNS_11PxTransformEf($this,$simStateDataPool,$p,$wakeCounter) {
 $this = $this|0;
 $simStateDataPool = $simStateDataPool|0;
 $p = $p|0;
 $wakeCounter = Math_fround($wakeCounter);
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $kData$0$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $26 = (($simStateDataPool) + 292|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($simStateDataPool);
   $$pre$i$i$i = HEAP32[$26>>2]|0;
   $30 = $$pre$i$i$i;
  } else {
   $30 = $27;
  }
  $29 = HEAP32[$30>>2]|0;
  HEAP32[$26>>2] = $29;
  $31 = (($simStateDataPool) + 280|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 1)|0;
  HEAP32[$31>>2] = $33;
  $34 = (($simStateDataPool) + 284|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + -1)|0;
  HEAP32[$34>>2] = $36;
  $37 = ($30|0)==(0|0);
  if ($37) {
   $kData$0$i = 0;
  } else {
   $kData$0$i = $30;
  }
  dest=$kData$0$i+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  $38 = (($kData$0$i) + 31|0);
  HEAP8[$38>>0] = 1;
  $39 = (($kData$0$i) + 28|0);
  HEAP8[$39>>0] = 1;
  $40 = (($this) + 120|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($kData$0$i) + 48|0);
  HEAPF32[$42>>2] = $41;
  $43 = (($this) + 124|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($kData$0$i) + 52|0);
  HEAPF32[$45>>2] = $44;
  $46 = (($kData$0$i) + 32|0);
  $47 = (($this) + 128|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  HEAPF32[$46>>2] = $48;
  $49 = (($this) + 132|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = (($kData$0$i) + 36|0);
  HEAPF32[$51>>2] = $50;
  $52 = (($this) + 136|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($kData$0$i) + 40|0);
  HEAPF32[$54>>2] = $53;
  $55 = (($this) + 140|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($kData$0$i) + 44|0);
  HEAPF32[$57>>2] = $56;
  $58 = (($this) + 112|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($kData$0$i) + 56|0);
  HEAPF32[$60>>2] = $59;
  $61 = (($this) + 116|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = (($kData$0$i) + 60|0);
  HEAPF32[$63>>2] = $62;
  ;HEAP32[$40+0>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;HEAP32[$40+16>>2]=0|0;HEAP32[$40+20>>2]=0|0;
  HEAPF32[$58>>2] = Math_fround(3.40282346638528859812E+38);
  HEAPF32[$61>>2] = Math_fround(3.40282346638528859812E+38);
  HEAP32[$0>>2] = $kData$0$i;
  $64 = Math_fround(HEAPF32[$p>>2]);
  HEAPF32[$kData$0$i>>2] = $64;
  $65 = (($p) + 4|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = (($kData$0$i) + 4|0);
  HEAPF32[$67>>2] = $66;
  $68 = (($p) + 8|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($kData$0$i) + 8|0);
  HEAPF32[$70>>2] = $69;
  $71 = (($p) + 12|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($kData$0$i) + 12|0);
  HEAPF32[$73>>2] = $72;
  $74 = (($p) + 16|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = (($kData$0$i) + 16|0);
  HEAPF32[$76>>2] = $75;
  $77 = (($p) + 20|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($kData$0$i) + 20|0);
  HEAPF32[$79>>2] = $78;
  $80 = (($p) + 24|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($kData$0$i) + 24|0);
  HEAPF32[$82>>2] = $81;
  HEAP8[$39>>0] = 1;
  $$pre = (($this) + 4|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $3 = Math_fround(HEAPF32[$p>>2]);
  HEAPF32[$1>>2] = $3;
  $4 = (($p) + 4|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($1) + 4|0);
  HEAPF32[$6>>2] = $5;
  $7 = (($p) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($1) + 8|0);
  HEAPF32[$9>>2] = $8;
  $10 = (($p) + 12|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($1) + 12|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($p) + 16|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($1) + 16|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($p) + 20|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($1) + 20|0);
  HEAPF32[$18>>2] = $17;
  $19 = (($p) + 24|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($1) + 24|0);
  HEAPF32[$21>>2] = $20;
  $22 = (($1) + 28|0);
  HEAP8[$22>>0] = 1;
  $23 = (($this) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $$pre$phiZ2D = $23;
  } else {
   __ZN5physx2Sc7BodySim22postSetKinematicTargetEv($24);
   $$pre$phiZ2D = $23;
  }
 }
 $83 = (($this) + 152|0);
 HEAPF32[$83>>2] = $wakeCounter;
 $84 = HEAP32[$$pre$phiZ2D>>2]|0;
 $85 = ($84|0)==(0|0);
 if ($85) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc7BodySim6wakeUpEv($84);
 __ZN5physx2Sc7BodySim18postSetWakeCounterEfb($84,$wakeCounter,1);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($this,$isKinematic) {
 $this = $this|0;
 $isKinematic = $isKinematic|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 31|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(1);
 $tmp = $4 ^ $isKinematic;
 $5 = $tmp ^ 1;
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc8BodyCore25invalidateKinematicTargetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 HEAP8[$2>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8BodyCore13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$shift>>2]);
 $3 = (($this) + 32|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 - $2);
 HEAPF32[$3>>2] = $5;
 $6 = (($shift) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 36|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 - $7);
 HEAPF32[$8>>2] = $10;
 $11 = (($shift) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 40|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 - $12);
 HEAPF32[$13>>2] = $15;
 $16 = (($this) + 156|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (($this) + 44|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20 & 1;
  $22 = ($21<<24>>24)==(0);
  if (!($22)) {
   $23 = (($17) + 28|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if (!($25)) {
    $26 = (($17) + 16|0);
    $27 = Math_fround(HEAPF32[$shift>>2]);
    $28 = Math_fround(HEAPF32[$26>>2]);
    $29 = Math_fround($28 - $27);
    HEAPF32[$26>>2] = $29;
    $30 = Math_fround(HEAPF32[$6>>2]);
    $31 = (($17) + 20|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = Math_fround($32 - $30);
    HEAPF32[$31>>2] = $33;
    $34 = Math_fround(HEAPF32[$11>>2]);
    $35 = (($17) + 24|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = Math_fround($36 - $34);
    HEAPF32[$35>>2] = $37;
   }
  }
 }
 $38 = Math_fround(HEAPF32[$shift>>2]);
 $39 = (($1) + 112|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($40 - $38);
 HEAPF32[$39>>2] = $41;
 $42 = Math_fround(HEAPF32[$6>>2]);
 $43 = (($1) + 116|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 - $42);
 HEAPF32[$43>>2] = $45;
 $46 = Math_fround(HEAPF32[$11>>2]);
 $47 = (($1) + 120|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($48 - $46);
 HEAPF32[$47>>2] = $49;
 STACKTOP = sp;return;
}
function __Z32ScGetPxRigidBodyFromPxsRigidCorePKN5physx12PxsRigidCoreE($core) {
 $core = $core|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($core) + -16|0);
 $1 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 64)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 458488 : 458456;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,458608,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 458488 : 458456;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,458608,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 458488 : 458456;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,458376,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 458488 : 458456;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,458376,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 458488 : 458456;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,458376,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 458488 : 458456;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,458696,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + ($$sum<<6)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -64|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($1) + 31|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(1);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($1) + 28|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$p>>2] = $9;
 $10 = (($1) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($p) + 4|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($p) + 8|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($1) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($p) + 12|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($1) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($p) + 16|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($1) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($p) + 20|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($1) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($p) + 24|0);
 HEAPF32[$27>>2] = $26;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc7BodySimC2ERNS0_5SceneERNS0_8BodyCoreE($this,$scene,$core) {
 $this = $this|0;
 $scene = $scene|0;
 $core = $core|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0;
 var $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0;
 var $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0;
 var $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $hasPendingForce$0$off0 = 0, $hasPendingForce$0$off0$ = 0, $phitmp = 0, $phitmp8 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN5physx2Sc8RigidSimC2ERNS0_5SceneERNS0_9RigidCoreENS0_14IslandNodeInfo4TypeE($this,$scene,$core,4);
 HEAP32[$this>>2] = ((458776 + 8|0));
 $0 = (($this) + 60|0);
 $1 = (($core) + 16|0);
 $2 = (($this) + 96|0);
 dest=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $3 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$2>>2] = $3;
 $4 = (($this) + 100|0);
 $5 = (($core) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($this) + 104|0);
 $8 = (($core) + 24|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($this) + 108|0);
 $11 = (($core) + 28|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$10>>2] = $12;
 $13 = (($this) + 112|0);
 $14 = (($core) + 32|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$13>>2] = $15;
 $16 = (($this) + 116|0);
 $17 = (($core) + 36|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $18;
 $19 = (($this) + 120|0);
 $20 = (($core) + 40|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 $22 = (($this) + 124|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 128|0);
 HEAP32[$23>>2] = $1;
 $24 = (($this) + 132|0);
 HEAP32[$24>>2] = 1073741823;
 $25 = (($this) + 136|0);
 HEAP32[$25>>2] = 1073741823;
 $26 = (($this) + 144|0);
 HEAP16[$26>>1] = 0;
 $27 = (($this) + 146|0);
 HEAP8[$27>>0] = 1;
 $28 = (($this) + 148|0);
 HEAP16[$28>>1] = 0;
 $29 = (($this) + 152|0);
 $30 = (($this) + 168|0);
 ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($this) + 172|0);
 $32 = (($this) + 188|0);
 ;HEAP32[$31+0>>2]=0|0;HEAP32[$31+4>>2]=0|0;HEAP32[$31+8>>2]=0|0;HEAP32[$31+12>>2]=0|0;
 HEAP32[$32>>2] = -1;
 $33 = (($scene) + 1212|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($core) + 8|0);
 $36 = HEAP16[$35>>1]|0;
 $37 = $36 & 2;
 $38 = ($37<<16>>16)==(0);
 if (!($38)) {
  HEAP16[$26>>1] = 1;
 }
 $39 = (($core) + 156|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  $hasPendingForce$0$off0 = 0;
 } else {
  $42 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($core,0)|0);
  if ($42) {
   $43 = HEAP32[$39>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    $hasPendingForce$0$off0 = 0;
   } else {
    $45 = (($43) + 12|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $170 = 0;
    } else {
     $48 = Math_fround(HEAPF32[$43>>2]);
     $49 = $48 == Math_fround(0.0);
     if ($49) {
      $50 = (($43) + 4|0);
      $51 = Math_fround(HEAPF32[$50>>2]);
      $52 = $51 == Math_fround(0.0);
      if ($52) {
       $53 = (($43) + 8|0);
       $54 = Math_fround(HEAPF32[$53>>2]);
       $55 = $54 == Math_fround(0.0);
       if ($55) {
        $56 = (($43) + 16|0);
        $57 = Math_fround(HEAPF32[$56>>2]);
        $58 = $57 == Math_fround(0.0);
        if ($58) {
         $59 = (($43) + 20|0);
         $60 = Math_fround(HEAPF32[$59>>2]);
         $61 = $60 == Math_fround(0.0);
         if ($61) {
          $62 = (($43) + 24|0);
          $63 = Math_fround(HEAPF32[$62>>2]);
          $64 = $63 == Math_fround(0.0);
          if ($64) {
           $65 = (($43) + 32|0);
           $66 = Math_fround(HEAPF32[$65>>2]);
           $67 = $66 == Math_fround(0.0);
           if ($67) {
            $68 = (($43) + 36|0);
            $69 = Math_fround(HEAPF32[$68>>2]);
            $70 = $69 == Math_fround(0.0);
            if ($70) {
             $71 = (($43) + 40|0);
             $72 = Math_fround(HEAPF32[$71>>2]);
             $73 = $72 == Math_fround(0.0);
             if ($73) {
              $74 = (($43) + 48|0);
              $75 = Math_fround(HEAPF32[$74>>2]);
              $76 = $75 == Math_fround(0.0);
              if ($76) {
               $77 = (($43) + 52|0);
               $78 = Math_fround(HEAPF32[$77>>2]);
               $79 = $78 == Math_fround(0.0);
               if ($79) {
                $80 = (($43) + 56|0);
                $81 = Math_fround(HEAPF32[$80>>2]);
                $phitmp8 = $81 != Math_fround(0.0);
                $170 = $phitmp8;
               } else {
                $170 = 1;
               }
              } else {
               $170 = 1;
              }
             } else {
              $170 = 1;
             }
            } else {
             $170 = 1;
            }
           } else {
            $170 = 1;
           }
          } else {
           $170 = 1;
          }
         } else {
          $170 = 1;
         }
        } else {
         $170 = 1;
        }
       } else {
        $170 = 1;
       }
      } else {
       $170 = 1;
      }
     } else {
      $170 = 1;
     }
    }
    HEAP8[$27>>0] = $46;
    HEAP8[$45>>0] = 0;
    $hasPendingForce$0$off0 = $170;
   }
  } else {
   $hasPendingForce$0$off0 = 0;
  }
 }
 $82 = (Math_fround(__ZNK5physx2Sc8BodyCore14getWakeCounterEv($core)));
 $83 = $82 > Math_fround(0.0);
 if ($83) {
  $123 = 1;
 } else {
  $84 = (($core) + 80|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = $85 == Math_fround(0.0);
  if ($86) {
   $87 = (($core) + 84|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = $88 == Math_fround(0.0);
   if ($89) {
    $90 = (($core) + 88|0);
    $91 = Math_fround(HEAPF32[$90>>2]);
    $92 = $91 == Math_fround(0.0);
    if ($92) {
     $93 = (($core) + 96|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = $94 == Math_fround(0.0);
     if ($95) {
      $96 = (($core) + 100|0);
      $97 = Math_fround(HEAPF32[$96>>2]);
      $98 = $97 == Math_fround(0.0);
      if ($98) {
       $99 = (($core) + 104|0);
       $100 = Math_fround(HEAPF32[$99>>2]);
       $phitmp = $100 != Math_fround(0.0);
       $101 = $phitmp;
      } else {
       $101 = 1;
      }
     } else {
      $101 = 1;
     }
     $hasPendingForce$0$off0$ = $hasPendingForce$0$off0 | $101;
     $123 = $hasPendingForce$0$off0$;
    } else {
     $123 = 1;
    }
   } else {
    $123 = 1;
   }
  } else {
   $123 = 1;
  }
 }
 $102 = (($this) + 52|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + 44|0);
 $105 = HEAP8[$104>>0]|0;
 $106 = $105 & 1;
 $107 = (($this) + 36|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($108)|0);
 $110 = (($this) + 50|0);
 $111 = HEAP8[$110>>0]|0;
 $112 = ($111<<24>>24)==(4);
 do {
  if ($112) {
   $114 = HEAP32[$107>>2]|0;
   $115 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($114)|0);
   __ZN5physx16PxsIslandManager19addArticulationLinkERNS_20PxsIslandManagerHookIjLj4294967295EEE($115,$32);
   $116 = HEAP32[$29>>2]|0;
   $117 = ($116|0)==(0|0);
   if (!($117)) {
    $118 = (__ZNK5physx2Sc15ArticulationSim13getLinkHandleERNS0_7BodySimE($116,$this)|0);
    $119 = $118 & 63;
    $120 = ($119|0)==(0);
    $121 = HEAP32[$107>>2]|0;
    $122 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($121)|0);
    if ($120) {
     __ZN5physx16PxsIslandManager29setArticulationRootLinkHandleEjPvRKNS_20PxsIslandManagerHookIjLj4294967295EEE($122,$118,$this,$32);
     break;
    } else {
     __ZN5physx16PxsIslandManager25setArticulationLinkHandleEjPvRKNS_20PxsIslandManagerHookIjLj4294967295EEE($122,$118,$this,$32);
     break;
    }
   }
  } else {
   $113 = ($106<<24>>24)!=(0);
   __ZN5physx16PxsIslandManager7addBodyEPvRNS_20PxsIslandManagerHookIjLj4294967295EEEb($109,$this,$32,$113);
  }
 } while(0);
 __ZN5physx2Sc16InteractionScene8addActorERNS0_5ActorEb($34,$this,$123);
 $124 = HEAP32[$32>>2]|0;
 $125 = (($109) + 16|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ((($126) + (($124*12)|0)|0) + 8|0);
 $128 = HEAP8[$127>>0]|0;
 $129 = $128&255;
 $130 = $129 & 231;
 if ($123) {
  $131 = $130 | 8;
  $132 = $131&255;
  HEAP8[$127>>0] = $132;
  $133 = (($109) + 273|0);
  HEAP8[$133>>0] = 1;
 } else {
  $134 = $130 | 16;
  $135 = $134&255;
  HEAP8[$127>>0] = $135;
  $136 = (($109) + 273|0);
  HEAP8[$136>>0] = 1;
 }
 $137 = ($106<<24>>24)==(0);
 if ($137) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc5Actor17setIslandNodeTypeENS0_14IslandNodeInfo4TypeE($this,2);
 $138 = (($this) + 64|0);
 ;HEAP32[$138+0>>2]=0|0;HEAP32[$138+4>>2]=0|0;HEAP32[$138+8>>2]=0|0;HEAP32[$138+12>>2]=0|0;HEAP32[$138+16>>2]=0|0;HEAP32[$138+20>>2]=0|0;HEAP32[$138+24>>2]=0|0;HEAP32[$138+28>>2]=0|0;
 $139 = HEAP32[$0>>2]|0;
 $140 = ($139|0)==(0|0);
 if (!($140)) {
  $141 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($139)|0);
  $142 = (($141) + 20|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ($143|0)==(0|0);
  if (!($144)) {
   __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($141);
  }
  __ZN5physx2Sc24ConstraintProjectionTree20buildProjectionTreesERNS0_19ConstraintGroupNodeE($141);
 }
 $145 = HEAP32[$39>>2]|0;
 $146 = ($145|0)==(0|0);
 if (!($146)) {
  $147 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($core,1)|0);
  if ($147) {
   $148 = HEAP32[$39>>2]|0;
   $149 = ($148|0)==(0|0);
   if (!($149)) {
    $166 = HEAP16[$26>>1]|0;
    $167 = $166&65535;
    $168 = $167 | 4;
    $169 = $168&65535;
    HEAP16[$26>>1] = $169;
    STACKTOP = sp;return;
   }
  }
 }
 $150 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $151 = (($150) + 1240|0);
 $152 = HEAP32[$151>>2]|0;
 (__ZN5physx2Sc8BodyCore17setupSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEbb($core,$152,1,0)|0);
 $153 = HEAP32[$107>>2]|0;
 $154 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($153)|0);
 $155 = (($this) + 188|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = (($154) + 16|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = ((($158) + (($156*12)|0)|0) + 8|0);
 $160 = HEAP8[$159>>0]|0;
 $161 = $160&255;
 $162 = $161 & 231;
 $163 = $162 | 16;
 $164 = $163&255;
 HEAP8[$159>>0] = $164;
 $165 = (($154) + 273|0);
 HEAP8[$165>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager7addBodyEPvRNS_20PxsIslandManagerHookIjLj4294967295EEEb($this,$owner,$hook,$kinematic) {
 $this = $this|0;
 $owner = $owner|0;
 $hook = $hook|0;
 $kinematic = $kinematic|0;
 var $$0$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 12|0);
 $3 = (($this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 do {
  if ($5) {
   $6 = (($this) + 24|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if ($8) {
    $$pre = (($this) + 16|0);
    $$0$i = -1;$$pre$phiZ2D = $$pre;
    break;
   } else {
    $9 = HEAP32[$2>>2]|0;
    $10 = (($9) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = $7 << 1;
    FUNCTION_TABLE_vii[$11 & 4095]($2,$12);
    $$pre$i = HEAP32[$3>>2]|0;
    $16 = $$pre$i;
    label = 5;
    break;
   }
  } else {
   $16 = $4;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  $13 = (($this) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($16<<2)|0);
  $17 = HEAP32[$15>>2]|0;
  HEAP32[$3>>2] = $17;
  HEAP32[$15>>2] = -1;
  $18 = (($this) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + (($16*12)|0)|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($19) + (($16*12)|0)|0) + 4|0);
  HEAP32[$21>>2] = -1;
  $22 = ((($19) + (($16*12)|0)|0) + 8|0);
  HEAP8[$22>>0] = 0;
  $$0$i = $16;$$pre$phiZ2D = $18;
 }
 HEAP32[$hook>>2] = $$0$i;
 $23 = HEAP32[$$pre$phiZ2D>>2]|0;
 $24 = (($23) + (($$0$i*12)|0)|0);
 $25 = ((($23) + (($$0$i*12)|0)|0) + 4|0);
 HEAP32[$25>>2] = -1;
 $26 = ((($23) + (($$0$i*12)|0)|0) + 8|0);
 HEAP32[$24>>2] = $owner;
 $storemerge$in$i = $kinematic&1;
 $27 = $storemerge$in$i | 64;
 $28 = $27&255;
 HEAP8[$26>>0] = $28;
 $29 = (($this) + 120|0);
 $30 = (($this) + 124|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 136|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($31|0)==($33|0);
 if ($34) {
  $35 = $31 << 1;
  $36 = $31 << 4;
  $37 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$36,458808,1373)|0);
  $38 = (($37) + ($35<<2)|0);
  $39 = HEAP32[$29>>2]|0;
  $40 = HEAP32[$30>>2]|0;
  $41 = $40 << 2;
  _memcpy(($37|0),($39|0),($41|0))|0;
  $42 = (($this) + 128|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($this) + 132|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $45 << 2;
  _memcpy(($38|0),($43|0),($46|0))|0;
  $47 = HEAP32[$29>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$47);
  HEAP32[$29>>2] = $37;
  HEAP32[$42>>2] = $38;
  HEAP32[$32>>2] = $35;
  $$pre$i1 = HEAP32[$30>>2]|0;
  $49 = $37;$50 = $$pre$i1;
 } else {
  $$pre1$i = HEAP32[$29>>2]|0;
  $49 = $$pre1$i;$50 = $31;
 }
 $48 = (($49) + ($50<<2)|0);
 HEAP32[$48>>2] = $$0$i;
 $51 = HEAP32[$30>>2]|0;
 $52 = (($51) + 1)|0;
 HEAP32[$30>>2] = $52;
 $53 = $kinematic&1;
 $54 = $53 ^ 1;
 $55 = (($this) + 244|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + ($54))|0;
 HEAP32[$55>>2] = $57;
 $58 = (($this) + 252|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + ($53))|0;
 HEAP32[$58>>2] = $60;
 if (!($kinematic)) {
  $70 = (($this) + 273|0);
  HEAP8[$70>>0] = 1;
  STACKTOP = sp;return;
 }
 $61 = (($this) + 92|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = $$0$i & 31;
 $64 = 1 << $63;
 $65 = $$0$i >>> 5;
 $66 = HEAP32[$62>>2]|0;
 $67 = (($66) + ($65<<2)|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68 | $64;
 HEAP32[$67>>2] = $69;
 $70 = (($this) + 273|0);
 HEAP8[$70>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim22postSetKinematicTargetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = $2 | 4;
 $4 = $3&65535;
 HEAP16[$0>>1] = $4;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Sc7BodySimD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((458776 + 8|0));
 $0 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $1 = (($0) + 1212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 51|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = (($2) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + -1)|0;
  $10 = HEAP32[$2>>2]|0;
  $11 = (($10) + ($9<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12;
  $14 = (_bitshift64Lshr(($13|0),0,6)|0);
  $15 = tempRet0;
  $16 = (_i64Add(($13|0),0,51,0)|0);
  $17 = tempRet0;
  $18 = (_bitshift64Lshr(($16|0),($17|0),6)|0);
  $19 = tempRet0;
  $20 = (_i64Subtract(1,0,($14|0),($15|0))|0);
  $21 = tempRet0;
  $22 = (_i64Add(($20|0),($21|0),($18|0),($19|0))|0);
  $23 = tempRet0;
  $25 = $22;$26 = $23;$cp$0$i = $12;
  while(1) {
   $24 = (($cp$0$i) + 64|0);
   $27 = (_i64Add(($25|0),($26|0),-1,-1)|0);
   $28 = tempRet0;
   $29 = ($27|0)==(0);
   $30 = ($28|0)==(0);
   $31 = $29 & $30;
   if ($31) {
    break;
   } else {
    $25 = $27;$26 = $28;$cp$0$i = $24;
   }
  }
 }
 $32 = (($this) + 52|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $35 = (($34) + 1240|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$32>>2]|0;
 $38 = (($37) + 44|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)!=(0);
 __ZN5physx2Sc8BodyCore20tearDownSimStateDataEPNS_6shdfnd4PoolINS0_12SimStateDataENS2_19ReflectionAllocatorIS4_EEEEb($33,$36,$41);
 $42 = (($this) + 144|0);
 $43 = HEAP16[$42>>1]|0;
 $44 = $43&65535;
 $45 = $44 | 8;
 $46 = $45&65535;
 HEAP16[$42>>1] = $46;
 $47 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 __ZN5physx2Sc5Scene10removeBodyERNS0_7BodySimE($47,$this);
 $48 = (($this) + 152|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  __ZN5physx2Sc15ArticulationSim10removeBodyERNS0_7BodySimE($49,$this);
 }
 $51 = (($this) + 188|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(-1);
 if ($53) {
  __ZN5physx2Sc16InteractionScene11removeActorERNS0_5ActorE($2,$this);
  $55 = HEAP32[$32>>2]|0;
  $56 = (($55) + 4|0);
  HEAP32[$56>>2] = 0;
  __ZN5physx2Sc8RigidSimD2Ev($this);
  STACKTOP = sp;return;
 }
 $54 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($2)|0);
 __ZN5physx16PxsIslandManager10removeNodeERNS_20PxsIslandManagerHookIjLj4294967295EEE($54,$51);
 __ZN5physx2Sc16InteractionScene11removeActorERNS0_5ActorE($2,$this);
 $55 = HEAP32[$32>>2]|0;
 $56 = (($55) + 4|0);
 HEAP32[$56>>2] = 0;
 __ZN5physx2Sc8RigidSimD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim10onActivateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 50|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(4);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 45|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 & 254;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 __ZN5physx2Sc5Scene12onBodyWakeUpEPNS0_7BodySimE($10,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim22updateCachedTransformsERNS_17PxsTransformCacheE($this,$cache) {
 $this = $this|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $iterator = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $iterator = sp + 28|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 45|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 HEAP32[$iterator>>2] = 0;
 __ZN5physx2Sc13ShapeIterator4initERKNS0_8ActorSimE($iterator,$this);
 $7 = (__ZN5physx2Sc13ShapeIterator7getNextEv($iterator)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($cache) + 16|0);
 $10 = (($0) + 4|0);
 $11 = (($0) + 8|0);
 $12 = (($0) + 12|0);
 $13 = (($0) + 16|0);
 $14 = (($0) + 20|0);
 $15 = (($0) + 24|0);
 $17 = $7;
 while(1) {
  $16 = (($17) + 24|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = ($18|0)==(-1);
  if (!($19)) {
   __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($0,$17);
   $20 = HEAP32[$16>>2]|0;
   $21 = HEAP32[$9>>2]|0;
   $22 = Math_fround(HEAPF32[$0>>2]);
   $23 = (($21) + (($20*28)|0)|0);
   HEAPF32[$23>>2] = $22;
   $24 = Math_fround(HEAPF32[$10>>2]);
   $25 = ((($21) + (($20*28)|0)|0) + 4|0);
   HEAPF32[$25>>2] = $24;
   $26 = Math_fround(HEAPF32[$11>>2]);
   $27 = ((($21) + (($20*28)|0)|0) + 8|0);
   HEAPF32[$27>>2] = $26;
   $28 = Math_fround(HEAPF32[$12>>2]);
   $29 = ((($21) + (($20*28)|0)|0) + 12|0);
   HEAPF32[$29>>2] = $28;
   $30 = Math_fround(HEAPF32[$13>>2]);
   $31 = ((($21) + (($20*28)|0)|0) + 16|0);
   HEAPF32[$31>>2] = $30;
   $32 = Math_fround(HEAPF32[$14>>2]);
   $33 = ((($21) + (($20*28)|0)|0) + 20|0);
   HEAPF32[$33>>2] = $32;
   $34 = Math_fround(HEAPF32[$15>>2]);
   $35 = ((($21) + (($20*28)|0)|0) + 24|0);
   HEAPF32[$35>>2] = $34;
  }
  $36 = (__ZN5physx2Sc13ShapeIterator7getNextEv($iterator)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   break;
  } else {
   $17 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim12onDeactivateEv($this) {
 $this = $this|0;
 var $$$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 8;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  $4 = (($this) + 52|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 80|0);
  HEAPF32[$6>>2] = Math_fround(0.0);
  $7 = (($5) + 84|0);
  HEAPF32[$7>>2] = Math_fround(0.0);
  $8 = (($5) + 88|0);
  HEAPF32[$8>>2] = Math_fround(0.0);
  $9 = (($5) + 96|0);
  HEAPF32[$9>>2] = Math_fround(0.0);
  $10 = (($5) + 100|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($5) + 104|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  $12 = $1 & 1;
  $13 = HEAP32[$4>>2]|0;
  $14 = (($13) + 156|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($13,0)|0);
   if ($17) {
    $18 = HEAP32[$14>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     $20 = (($18) + 48|0);
     HEAPF32[$20>>2] = Math_fround(0.0);
     $21 = (($18) + 52|0);
     HEAPF32[$21>>2] = Math_fround(0.0);
     $22 = (($18) + 56|0);
     HEAPF32[$22>>2] = Math_fround(0.0);
     $23 = (($18) + 32|0);
     HEAPF32[$23>>2] = Math_fround(0.0);
     $24 = (($18) + 36|0);
     HEAPF32[$24>>2] = Math_fround(0.0);
     $25 = (($18) + 40|0);
     HEAPF32[$25>>2] = Math_fround(0.0);
     $26 = (($18) + 16|0);
     HEAPF32[$26>>2] = Math_fround(0.0);
     $27 = (($18) + 20|0);
     HEAPF32[$27>>2] = Math_fround(0.0);
     $28 = (($18) + 24|0);
     HEAPF32[$28>>2] = Math_fround(0.0);
     HEAPF32[$18>>2] = Math_fround(0.0);
     $29 = (($18) + 4|0);
     HEAPF32[$29>>2] = Math_fround(0.0);
     $30 = (($18) + 8|0);
     HEAPF32[$30>>2] = Math_fround(0.0);
    }
   }
  }
  $31 = (($this) + 146|0);
  $32 = $12 ^ 1;
  $$$i = $32&255;
  HEAP8[$31>>0] = $$$i;
 }
 $33 = (($this) + 50|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)==(4);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 __ZN5physx2Sc5Scene11onBodySleepEPNS0_7BodySimE($36,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim28notifyAddSpatialAccelerationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 146|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 | 2;
 $4 = $3&255;
 HEAP8[$0>>0] = $4;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim30notifyClearSpatialAccelerationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 146|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 | 2;
 $4 = $3&255;
 HEAP8[$0>>0] = $4;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim24notifyAddSpatialVelocityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 146|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 | 4;
 $4 = $3&255;
 HEAP8[$0>>0] = $4;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim26notifyClearSpatialVelocityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 146|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 | 4;
 $4 = $3&255;
 HEAP8[$0>>0] = $4;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim19postActorFlagChangeEjj($this,$oldFlags,$newFlags) {
 $this = $this|0;
 $oldFlags = $oldFlags|0;
 $newFlags = $newFlags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $oldFlags & 2;
 $1 = $newFlags & 2;
 $2 = ($1|0)==($0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 146|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  HEAP8[$3>>0] = 1;
 }
 $6 = ($1|0)==(0);
 $7 = (($this) + 144|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 if ($6) {
  $12 = $9 & 65534;
  $13 = $12&65535;
  HEAP16[$7>>1] = $13;
  STACKTOP = sp;return;
 } else {
  $10 = $9 | 1;
  $11 = $10&65535;
  HEAP16[$7>>1] = $11;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc7BodySim20postBody2WorldChangeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = (($this) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 96|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($2) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 100|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($2) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 104|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($2) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 108|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($2) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 112|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($2) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 116|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($2) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 120|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($this) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 1000|0);
 $26 = HEAP32[$25>>2]|0;
 __ZN5physx12PxsRigidBody23updatePoseDependenciesVERNS_10PxsContextE($0,$26);
 __ZN5physx2Sc8RigidSim25notifyShapeTranformChangeEv($this);
 $27 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $28 = (($27) + 1212|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1000|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 7384|0);
 __ZN5physx2Sc7BodySim22updateCachedTransformsERNS_17PxsTransformCacheE($this,$32);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim18postSetWakeCounterEfb($this,$t,$forceWakeUp) {
 $this = $this|0;
 $t = Math_fround($t);
 $forceWakeUp = $forceWakeUp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $t > Math_fround(0.0);
 $brmerge = $0 | $forceWakeUp;
 if ($brmerge) {
  $1 = (($this) + 36|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($2)|0);
  $4 = (($this) + 188|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7) + (($5*12)|0)|0) + 8|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $10 | 8;
  $12 = $11&255;
  HEAP8[$8>>0] = $12;
  $13 = (($3) + 273|0);
  HEAP8[$13>>0] = 1;
  STACKTOP = sp;return;
 }
 $14 = (__ZN5physx2Sc7BodySim37checkSleepReadinessBesidesWakeCounterEv($this)|0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($16)|0);
 $18 = (($this) + 188|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + (($19*12)|0)|0) + 8|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 & 247;
 $26 = $25&255;
 HEAP8[$22>>0] = $26;
 $27 = (($17) + 273|0);
 HEAP8[$27>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim22notifyReadyForSleepingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($1)|0);
 $3 = (($this) + 188|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6) + (($4*12)|0)|0) + 8|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 & 247;
 $11 = $10&255;
 HEAP8[$7>>0] = $11;
 $12 = (($2) + 273|0);
 HEAP8[$12>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim21postSwitchToKinematicEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc5Actor17setIslandNodeTypeENS0_14IslandNodeInfo4TypeE($this,2);
 $0 = (($this) + 64|0);
 $1 = (($this) + 60|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($2)|0);
  $5 = (($4) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($4);
  }
  __ZN5physx2Sc24ConstraintProjectionTree20buildProjectionTreesERNS0_19ConstraintGroupNodeE($4);
 }
 $8 = (($this) + 188|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(-1);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($12)|0);
 __ZN5physx16PxsIslandManager12setKinematicERKNS_20PxsIslandManagerHookIjLj4294967295EEEb($13,$8,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim19postSwitchToDynamicEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 188|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if (!($2)) {
  $3 = (($this) + 36|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($4)|0);
  __ZN5physx16PxsIslandManager12setKinematicERKNS_20PxsIslandManagerHookIjLj4294967295EEEb($5,$0,0);
 }
 $6 = (($this) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 156|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($7,0)|0);
  if ($11) {
   $12 = HEAP32[$8>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = (($12) + 48|0);
    HEAPF32[$14>>2] = Math_fround(0.0);
    $15 = (($12) + 52|0);
    HEAPF32[$15>>2] = Math_fround(0.0);
    $16 = (($12) + 56|0);
    HEAPF32[$16>>2] = Math_fround(0.0);
    $17 = (($12) + 32|0);
    HEAPF32[$17>>2] = Math_fround(0.0);
    $18 = (($12) + 36|0);
    HEAPF32[$18>>2] = Math_fround(0.0);
    $19 = (($12) + 40|0);
    HEAPF32[$19>>2] = Math_fround(0.0);
    $20 = (($12) + 16|0);
    HEAPF32[$20>>2] = Math_fround(0.0);
    $21 = (($12) + 20|0);
    HEAPF32[$21>>2] = Math_fround(0.0);
    $22 = (($12) + 24|0);
    HEAPF32[$22>>2] = Math_fround(0.0);
    HEAPF32[$12>>2] = Math_fround(0.0);
    $23 = (($12) + 4|0);
    HEAPF32[$23>>2] = Math_fround(0.0);
    $24 = (($12) + 8|0);
    HEAPF32[$24>>2] = Math_fround(0.0);
   }
  }
 }
 $25 = (($this) + 146|0);
 HEAP8[$25>>0] = 1;
 $26 = (($this) + 60|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  __ZN5physx2Sc8ActorSim26setActorsInteractionsDirtyENS0_15CoreInteraction9DirtyFlagEPKNS0_5ActorEh($this,5,0,4);
  $33 = (($this) + 144|0);
  $34 = HEAP16[$33>>1]|0;
  $35 = $34&65535;
  $36 = $35 & 65019;
  $37 = $36&65535;
  HEAP16[$33>>1] = $37;
  __ZN5physx2Sc5Actor17setIslandNodeTypeENS0_14IslandNodeInfo4TypeE($this,4);
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($27)|0);
 $30 = (($29) + 20|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($29);
 }
 __ZN5physx2Sc24ConstraintProjectionTree20buildProjectionTreesERNS0_19ConstraintGroupNodeE($29);
 __ZN5physx2Sc8ActorSim26setActorsInteractionsDirtyENS0_15CoreInteraction9DirtyFlagEPKNS0_5ActorEh($this,5,0,4);
 $33 = (($this) + 144|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = $34&65535;
 $36 = $35 & 65019;
 $37 = $36&65535;
 HEAP16[$33>>1] = $37;
 __ZN5physx2Sc5Actor17setIslandNodeTypeENS0_14IslandNodeInfo4TypeE($this,4);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim6wakeUpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc5Actor9setActiveEbj($this,1,0);
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($1)|0);
 $3 = (($this) + 188|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6) + (($4*12)|0)|0) + 8|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 & 231;
 $11 = $10 | 8;
 $12 = $11&255;
 HEAP8[$7>>0] = $12;
 $13 = (($2) + 273|0);
 HEAP8[$13>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim10putToSleepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc5Actor9setActiveEbj($this,0,0);
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($1)|0);
 $3 = (($this) + 188|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6) + (($4*12)|0)|0) + 8|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 & 231;
 $11 = $10 | 16;
 $12 = $11&255;
 HEAP8[$7>>0] = $12;
 $13 = (($2) + 273|0);
 HEAP8[$13>>0] = 1;
 $14 = (($this) + 144|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = $16 & 65023;
 $18 = $17&65535;
 HEAP16[$14>>1] = $18;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim14internalWakeUpEf($this,$wakeCounterValue) {
 $this = $this|0;
 $wakeCounterValue = Math_fround($wakeCounterValue);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5physx2Sc15ArticulationSim14internalWakeUpEf($1,$wakeCounterValue);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 44|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (Math_fround(__ZNK5physx2Sc8BodyCore14getWakeCounterEv($4)));
 $10 = $9 < $wakeCounterValue;
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 152|0);
 HEAPF32[$12>>2] = $wakeCounterValue;
 __ZN5physx2Sc5Actor9setActiveEbj($this,1,0);
 $13 = (($this) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($14)|0);
 $16 = (($this) + 188|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($19) + (($17*12)|0)|0) + 8|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 $23 = $22 & 231;
 $24 = $23 | 8;
 $25 = $24&255;
 HEAP8[$20>>0] = $25;
 $26 = (($15) + 273|0);
 HEAP8[$26>>0] = 1;
 $27 = HEAP32[$3>>2]|0;
 $28 = (($27) + 45|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = $30 & 254;
 $32 = $31&255;
 HEAP8[$28>>0] = $32;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim30internalWakeUpArticulationLinkEf($this,$wakeCounterValue) {
 $this = $this|0;
 $wakeCounterValue = Math_fround($wakeCounterValue);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 44|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (Math_fround(__ZNK5physx2Sc8BodyCore14getWakeCounterEv($1)));
 $7 = $6 < $wakeCounterValue;
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$0>>2]|0;
 $9 = (($8) + 152|0);
 HEAPF32[$9>>2] = $wakeCounterValue;
 __ZN5physx2Sc5Actor9setActiveEbj($this,1,0);
 $10 = (($this) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($11)|0);
 $13 = (($this) + 188|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($16) + (($14*12)|0)|0) + 8|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = $19 & 231;
 $21 = $20 | 8;
 $22 = $21&255;
 HEAP8[$17>>0] = $22;
 $23 = (($12) + 273|0);
 HEAP8[$23>>0] = 1;
 $24 = HEAP32[$0>>2]|0;
 $25 = (($24) + 45|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = $27 & 254;
 $29 = $28&255;
 HEAP8[$25>>0] = $29;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim16resetSleepFilterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 160|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 164|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 172|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($this) + 176|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 180|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim17updateWakeCounterEffffb($this,$dt,$energyThreshold,$freezeThreshold,$invDt,$enableStabilization) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $energyThreshold = Math_fround($energyThreshold);
 $freezeThreshold = Math_fround($freezeThreshold);
 $invDt = Math_fround($invDt);
 $enableStabilization = $enableStabilization|0;
 var $$0 = Math_fround(0), $$not = 0, $$not5 = 0, $$op = Math_fround(0), $$op$op = Math_fround(0), $$op20 = Math_fround(0), $$op20$op = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0);
 var $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0);
 var $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0);
 var $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0);
 var $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0);
 var $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0;
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0;
 var $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0);
 var $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = 0, $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0;
 var $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $brmerge = 0, $invMass$0 = Math_fround(0), $invMass6$0 = Math_fround(0), $isFrozen$0$off0 = 0, $or$cond = 0, $or$cond4 = 0, $or$cond6 = 0, $or$cond7 = 0, $phitmp1 = Math_fround(0), $phitmp3 = Math_fround(0);
 var $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (Math_fround(__ZNK5physx2Sc8BodyCore14getWakeCounterEv($1)));
 do {
  if ($enableStabilization) {
   $3 = HEAP32[$0>>2]|0;
   $4 = (($3) + 16|0);
   $5 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($1)|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = (($5) + 4|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = (($5) + 8|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = $6 > Math_fround(0.0);
   if ($11) {
    $12 = Math_fround(Math_fround(1.0) / $6);
    $78 = $12;
   } else {
    $78 = Math_fround(1.0);
   }
   $13 = $8 > Math_fround(0.0);
   if ($13) {
    $14 = Math_fround(Math_fround(1.0) / $8);
    $80 = $14;
   } else {
    $80 = Math_fround(1.0);
   }
   $15 = $10 > Math_fround(0.0);
   if ($15) {
    $16 = Math_fround(Math_fround(1.0) / $10);
    $83 = $16;
   } else {
    $83 = Math_fround(1.0);
   }
   $17 = (($this) + 64|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = (($this) + 68|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = (($this) + 72|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = (($this) + 80|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($24 * Math_fround(2.0));
   $26 = (($this) + 84|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($27 * Math_fround(2.0));
   $29 = (($this) + 88|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = Math_fround($30 * Math_fround(2.0));
   $32 = (($3) + 28|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = Math_fround($33 * $33);
   $35 = Math_fround($34 + Math_fround(-0.5));
   $36 = Math_fround(HEAPF32[$4>>2]);
   $37 = Math_fround($25 * $36);
   $38 = (($3) + 20|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = Math_fround($28 * $39);
   $41 = Math_fround($37 + $40);
   $42 = (($3) + 24|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = Math_fround($31 * $43);
   $45 = Math_fround($41 + $44);
   $46 = Math_fround($25 * $35);
   $47 = Math_fround($31 * $39);
   $48 = Math_fround($28 * $43);
   $49 = Math_fround($47 - $48);
   $50 = Math_fround($33 * $49);
   $51 = Math_fround($46 - $50);
   $52 = Math_fround($36 * $45);
   $53 = Math_fround($52 + $51);
   $54 = Math_fround($28 * $35);
   $55 = Math_fround($25 * $43);
   $56 = Math_fround($31 * $36);
   $57 = Math_fround($55 - $56);
   $58 = Math_fround($33 * $57);
   $59 = Math_fround($54 - $58);
   $60 = Math_fround($39 * $45);
   $61 = Math_fround($60 + $59);
   $62 = Math_fround($31 * $35);
   $63 = Math_fround($28 * $36);
   $64 = Math_fround($25 * $39);
   $65 = Math_fround($63 - $64);
   $66 = Math_fround($33 * $65);
   $67 = Math_fround($62 - $66);
   $68 = Math_fround($43 * $45);
   $69 = Math_fround($67 + $68);
   $70 = (($this) + 46|0);
   $71 = HEAP16[$70>>1]|0;
   $72 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($1)));
   $73 = $72 == Math_fround(0.0);
   $invMass$0 = $73 ? Math_fround(1.0) : $72;
   $74 = Math_fround($53 * $53);
   $75 = Math_fround($61 * $61);
   $76 = Math_fround($69 * $69);
   $77 = Math_fround($78 * $74);
   $79 = Math_fround($80 * $75);
   $81 = Math_fround($77 + $79);
   $82 = Math_fround($83 * $76);
   $84 = Math_fround($82 + $81);
   $85 = Math_fround($invMass$0 * $84);
   $86 = Math_fround($18 * $18);
   $87 = Math_fround($20 * $20);
   $88 = Math_fround($86 + $87);
   $89 = Math_fround($22 * $22);
   $90 = Math_fround($88 + $89);
   $91 = Math_fround($90 + $85);
   $92 = Math_fround($91 * Math_fround(0.5));
   $93 = (($this) + 144|0);
   $94 = HEAP16[$93>>1]|0;
   $95 = $94 & 2;
   $$not = ($95<<16>>16)==(0);
   $96 = ($71<<16>>16)==(0);
   $or$cond = $$not | $96;
   if ($or$cond) {
    $101 = Math_fround(0.0);
   } else {
    $97 = $71&65535;
    $98 = (($97) + 1)|0;
    $99 = (Math_fround(($98>>>0)));
    $101 = $99;
   }
   $100 = Math_fround($101 * $101);
   $102 = Math_fround($100 * $freezeThreshold);
   $103 = (($this) + 168|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = Math_fround($104 - $dt);
   $106 = $105 > Math_fround(0.0);
   $107 = $106 ? $105 : Math_fround(0.0);
   HEAPF32[$103>>2] = $107;
   $108 = !($92 >= $102);
   if ($108) {
    $112 = Math_fround($dt * Math_fround(0.5));
    $113 = Math_fround(Math_fround(1.0) - $112);
    $114 = (($1) + 80|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = Math_fround($113 * $115);
    $117 = (($1) + 84|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = Math_fround($113 * $118);
    $120 = (($1) + 88|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    $122 = Math_fround($113 * $121);
    HEAPF32[$114>>2] = $116;
    HEAPF32[$117>>2] = $119;
    HEAPF32[$120>>2] = $122;
    $123 = (($1) + 96|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = Math_fround($113 * $124);
    $126 = (($1) + 100|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = Math_fround($113 * $127);
    $129 = (($1) + 104|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $131 = Math_fround($113 * $130);
    HEAPF32[$123>>2] = $125;
    HEAPF32[$126>>2] = $128;
    HEAPF32[$129>>2] = $131;
    $132 = Math_fround($invDt * Math_fround(0.899999976158142089843));
    $133 = (($this) + 184|0);
    HEAPF32[$133>>2] = $132;
    $134 = Math_fround(HEAPF32[$103>>2]);
    $135 = $134 == Math_fround(0.0);
    $136 = $92 < $freezeThreshold;
    $or$cond4 = $135 & $136;
    if ($or$cond4) {
     $137 = (($1) + 16|0);
     $138 = (($this) + 96|0);
     $139 = Math_fround(HEAPF32[$138>>2]);
     $140 = (($this) + 100|0);
     $141 = Math_fround(HEAPF32[$140>>2]);
     $142 = (($this) + 104|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = (($this) + 108|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = (($this) + 112|0);
     $147 = Math_fround(HEAPF32[$146>>2]);
     $148 = (($this) + 116|0);
     $149 = Math_fround(HEAPF32[$148>>2]);
     $150 = (($this) + 120|0);
     $151 = Math_fround(HEAPF32[$150>>2]);
     HEAPF32[$137>>2] = $139;
     $152 = (($1) + 20|0);
     HEAPF32[$152>>2] = $141;
     $153 = (($1) + 24|0);
     HEAPF32[$153>>2] = $143;
     $154 = (($1) + 28|0);
     HEAPF32[$154>>2] = $145;
     $155 = (($1) + 32|0);
     HEAPF32[$155>>2] = $147;
     $156 = (($1) + 36|0);
     HEAPF32[$156>>2] = $149;
     $157 = (($1) + 40|0);
     HEAPF32[$157>>2] = $151;
     $isFrozen$0$off0 = 1;
    } else {
     $isFrozen$0$off0 = 0;
    }
   } else {
    HEAPF32[$103>>2] = Math_fround(1.0);
    $109 = Math_fround($101 * $102);
    $110 = !($92 >= $109);
    if ($110) {
     $isFrozen$0$off0 = 0;
    } else {
     $111 = (($this) + 184|0);
     HEAPF32[$111>>2] = Math_fround(0.0);
     $isFrozen$0$off0 = 0;
    }
   }
   $158 = HEAP32[$0>>2]|0;
   $159 = (($158) + 45|0);
   $160 = HEAP8[$159>>0]|0;
   $161 = $160&255;
   $162 = $161 & 254;
   $163 = $161 | 1;
   $storemerge$in = $isFrozen$0$off0 ? $163 : $162;
   $storemerge = $storemerge$in&255;
   HEAP8[$159>>0] = $storemerge;
   $164 = !($92 >= $energyThreshold);
   if ($164) {
    $$not5 = !($102 > Math_fround(0.0));
    $brmerge = $$not5 | $isFrozen$0$off0;
    if ($brmerge) {
     break;
    }
   }
   $165 = $2 < Math_fround(0.199999988079071044922);
   $166 = $2 < $dt;
   $or$cond6 = $165 | $166;
   if ($or$cond6) {
    $167 = (($this) + 156|0);
    HEAPF32[$167>>2] = Math_fround(0.0);
    $168 = (($this) + 160|0);
    HEAPF32[$168>>2] = Math_fround(0.0);
    $169 = (($this) + 164|0);
    HEAPF32[$169>>2] = Math_fround(0.0);
    $170 = (($this) + 172|0);
    HEAPF32[$170>>2] = Math_fround(0.0);
    $171 = (($this) + 176|0);
    HEAPF32[$171>>2] = Math_fround(0.0);
    $172 = (($this) + 180|0);
    HEAPF32[$172>>2] = Math_fround(0.0);
    $173 = $energyThreshold == Math_fround(0.0);
    if ($173) {
     $180 = Math_fround(0.399999976158142089844);
    } else {
     $174 = Math_fround($92 / $energyThreshold);
     $175 = $174 < Math_fround(2.0);
     $$op20 = Math_fround($174 * Math_fround(0.5));
     $$op20$op = Math_fround($$op20 * Math_fround(0.399999976158142089844));
     $phitmp3 = $175 ? $$op20$op : Math_fround(0.399999976158142089844);
     $180 = $phitmp3;
    }
    $176 = (Math_fround(($71&65535)));
    $177 = Math_fround($176 + Math_fround(-1.0));
    $178 = Math_fround($177 * $dt);
    $179 = Math_fround($178 + $180);
    $181 = (($1) + 152|0);
    HEAPF32[$181>>2] = $179;
    $182 = $2 == Math_fround(0.0);
    if (!($182)) {
     $$0 = $179;
     STACKTOP = sp;return (Math_fround($$0));
    }
    $183 = (($this) + 36|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($184)|0);
    $186 = (($this) + 188|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = (($185) + 16|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = ((($189) + (($187*12)|0)|0) + 8|0);
    $191 = HEAP8[$190>>0]|0;
    $192 = $191&255;
    $193 = $192 | 8;
    $194 = $193&255;
    HEAP8[$190>>0] = $194;
    $195 = (($185) + 273|0);
    HEAP8[$195>>0] = 1;
    $$0 = $179;
    STACKTOP = sp;return (Math_fround($$0));
   }
  } else {
   $196 = $2 < Math_fround(0.199999988079071044922);
   $197 = $2 < $dt;
   $or$cond7 = $196 | $197;
   if ($or$cond7) {
    $198 = HEAP32[$0>>2]|0;
    $199 = (($198) + 16|0);
    $200 = (__ZNK5physx2Sc8BodyCore17getInverseInertiaEv($1)|0);
    $201 = Math_fround(HEAPF32[$200>>2]);
    $202 = (($200) + 4|0);
    $203 = Math_fround(HEAPF32[$202>>2]);
    $204 = (($200) + 8|0);
    $205 = Math_fround(HEAPF32[$204>>2]);
    $206 = $201 > Math_fround(0.0);
    if ($206) {
     $207 = Math_fround(Math_fround(1.0) / $201);
     $292 = $207;
    } else {
     $292 = Math_fround(1.0);
    }
    $208 = $203 > Math_fround(0.0);
    if ($208) {
     $209 = Math_fround(Math_fround(1.0) / $203);
     $294 = $209;
    } else {
     $294 = Math_fround(1.0);
    }
    $210 = $205 > Math_fround(0.0);
    if ($210) {
     $211 = Math_fround(Math_fround(1.0) / $205);
     $297 = $211;
    } else {
     $297 = Math_fround(1.0);
    }
    $212 = (($this) + 64|0);
    $213 = Math_fround(HEAPF32[$212>>2]);
    $214 = (($this) + 68|0);
    $215 = Math_fround(HEAPF32[$214>>2]);
    $216 = (($this) + 72|0);
    $217 = Math_fround(HEAPF32[$216>>2]);
    $218 = (($this) + 80|0);
    $219 = Math_fround(HEAPF32[$218>>2]);
    $220 = Math_fround($219 * Math_fround(2.0));
    $221 = (($this) + 84|0);
    $222 = Math_fround(HEAPF32[$221>>2]);
    $223 = Math_fround($222 * Math_fround(2.0));
    $224 = (($this) + 88|0);
    $225 = Math_fround(HEAPF32[$224>>2]);
    $226 = Math_fround($225 * Math_fround(2.0));
    $227 = (($198) + 28|0);
    $228 = Math_fround(HEAPF32[$227>>2]);
    $229 = Math_fround($228 * $228);
    $230 = Math_fround($229 + Math_fround(-0.5));
    $231 = Math_fround(HEAPF32[$199>>2]);
    $232 = Math_fround($220 * $231);
    $233 = (($198) + 20|0);
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = Math_fround($223 * $234);
    $236 = Math_fround($232 + $235);
    $237 = (($198) + 24|0);
    $238 = Math_fround(HEAPF32[$237>>2]);
    $239 = Math_fround($226 * $238);
    $240 = Math_fround($236 + $239);
    $241 = Math_fround($220 * $230);
    $242 = Math_fround($226 * $234);
    $243 = Math_fround($223 * $238);
    $244 = Math_fround($242 - $243);
    $245 = Math_fround($228 * $244);
    $246 = Math_fround($241 - $245);
    $247 = Math_fround($231 * $240);
    $248 = Math_fround($247 + $246);
    $249 = Math_fround($223 * $230);
    $250 = Math_fround($220 * $238);
    $251 = Math_fround($226 * $231);
    $252 = Math_fround($250 - $251);
    $253 = Math_fround($228 * $252);
    $254 = Math_fround($249 - $253);
    $255 = Math_fround($234 * $240);
    $256 = Math_fround($255 + $254);
    $257 = Math_fround($226 * $230);
    $258 = Math_fround($223 * $231);
    $259 = Math_fround($220 * $234);
    $260 = Math_fround($258 - $259);
    $261 = Math_fround($228 * $260);
    $262 = Math_fround($257 - $261);
    $263 = Math_fround($238 * $240);
    $264 = Math_fround($262 + $263);
    $265 = (($this) + 156|0);
    $266 = Math_fround(HEAPF32[$265>>2]);
    $267 = Math_fround($213 + $266);
    HEAPF32[$265>>2] = $267;
    $268 = (($this) + 160|0);
    $269 = Math_fround(HEAPF32[$268>>2]);
    $270 = Math_fround($215 + $269);
    HEAPF32[$268>>2] = $270;
    $271 = (($this) + 164|0);
    $272 = Math_fround(HEAPF32[$271>>2]);
    $273 = Math_fround($217 + $272);
    HEAPF32[$271>>2] = $273;
    $274 = (($this) + 172|0);
    $275 = Math_fround(HEAPF32[$274>>2]);
    $276 = Math_fround($275 + $248);
    HEAPF32[$274>>2] = $276;
    $277 = (($this) + 176|0);
    $278 = Math_fround(HEAPF32[$277>>2]);
    $279 = Math_fround($256 + $278);
    HEAPF32[$277>>2] = $279;
    $280 = (($this) + 180|0);
    $281 = Math_fround(HEAPF32[$280>>2]);
    $282 = Math_fround($264 + $281);
    HEAPF32[$280>>2] = $282;
    $283 = (Math_fround(__ZNK5physx2Sc8BodyCore14getInverseMassEv($1)));
    $284 = $283 == Math_fround(0.0);
    $invMass6$0 = $284 ? Math_fround(1.0) : $283;
    $285 = Math_fround(HEAPF32[$274>>2]);
    $286 = Math_fround($285 * $285);
    $287 = Math_fround(HEAPF32[$277>>2]);
    $288 = Math_fround($287 * $287);
    $289 = Math_fround(HEAPF32[$280>>2]);
    $290 = Math_fround($289 * $289);
    $291 = Math_fround($292 * $286);
    $293 = Math_fround($294 * $288);
    $295 = Math_fround($291 + $293);
    $296 = Math_fround($297 * $290);
    $298 = Math_fround($295 + $296);
    $299 = Math_fround($invMass6$0 * $298);
    $300 = Math_fround(HEAPF32[$265>>2]);
    $301 = Math_fround($300 * $300);
    $302 = Math_fround(HEAPF32[$268>>2]);
    $303 = Math_fround($302 * $302);
    $304 = Math_fround($301 + $303);
    $305 = Math_fround(HEAPF32[$271>>2]);
    $306 = Math_fround($305 * $305);
    $307 = Math_fround($304 + $306);
    $308 = Math_fround($299 + $307);
    $309 = Math_fround($308 * Math_fround(0.5));
    $310 = (($this) + 48|0);
    $311 = HEAP16[$310>>1]|0;
    $312 = $311&65535;
    $313 = (($312) + 1)|0;
    $314 = (Math_fround(($313>>>0)));
    $315 = Math_fround($314 * $energyThreshold);
    $316 = !($309 >= $315);
    if (!($316)) {
     HEAPF32[$265>>2] = Math_fround(0.0);
     HEAPF32[$268>>2] = Math_fround(0.0);
     HEAPF32[$271>>2] = Math_fround(0.0);
     HEAPF32[$274>>2] = Math_fround(0.0);
     HEAPF32[$277>>2] = Math_fround(0.0);
     HEAPF32[$280>>2] = Math_fround(0.0);
     $317 = $315 == Math_fround(0.0);
     if ($317) {
      $323 = Math_fround(0.399999976158142089844);
     } else {
      $318 = Math_fround($309 / $315);
      $319 = $318 < Math_fround(2.0);
      $$op = Math_fround($318 * Math_fround(0.5));
      $$op$op = Math_fround($$op * Math_fround(0.399999976158142089844));
      $phitmp1 = $319 ? $$op$op : Math_fround(0.399999976158142089844);
      $323 = $phitmp1;
     }
     $320 = Math_fround($314 + Math_fround(-1.0));
     $321 = Math_fround($320 * $dt);
     $322 = Math_fround($321 + $323);
     $324 = (($1) + 152|0);
     HEAPF32[$324>>2] = $322;
     $325 = $2 == Math_fround(0.0);
     if (!($325)) {
      $$0 = $322;
      STACKTOP = sp;return (Math_fround($$0));
     }
     $326 = (($this) + 36|0);
     $327 = HEAP32[$326>>2]|0;
     $328 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($327)|0);
     $329 = (($this) + 188|0);
     $330 = HEAP32[$329>>2]|0;
     $331 = (($328) + 16|0);
     $332 = HEAP32[$331>>2]|0;
     $333 = ((($332) + (($330*12)|0)|0) + 8|0);
     $334 = HEAP8[$333>>0]|0;
     $335 = $334&255;
     $336 = $335 | 8;
     $337 = $336&255;
     HEAP8[$333>>0] = $337;
     $338 = (($328) + 273|0);
     HEAP8[$338>>0] = 1;
     $$0 = $322;
     STACKTOP = sp;return (Math_fround($$0));
    }
   }
  }
 } while(0);
 $339 = Math_fround($2 - $dt);
 $340 = $339 > Math_fround(0.0);
 $341 = $340 ? $339 : Math_fround(0.0);
 $342 = (($1) + 152|0);
 HEAPF32[$342>>2] = $341;
 $$0 = $341;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx2Sc7BodySim10sleepCheckEffb($this,$dt,$invDt,$enableStabilization) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $invDt = Math_fround($invDt);
 $enableStabilization = $enableStabilization|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 144|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 148|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (Math_fround(__ZN5physx2Sc7BodySim17updateWakeCounterEffffb($this,$dt,$3,$5,$invDt,$enableStabilization)));
 $7 = $6 == Math_fround(0.0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($9)|0);
 $11 = (($this) + 188|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14) + (($12*12)|0)|0) + 8|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $17 & 247;
 $19 = $18&255;
 HEAP8[$15>>0] = $19;
 $20 = (($10) + 273|0);
 HEAP8[$20>>0] = 1;
 $21 = (($this) + 156|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($this) + 160|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 164|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($this) + 172|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($this) + 176|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($this) + 180|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim26calculateKinematicVelocityEf($this,$oneOverDt) {
 $this = $this|0;
 $oneOverDt = Math_fround($oneOverDt);
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0);
 var $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0.0, $99 = 0.0, $fabsf$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 144|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 & 4;
 $6 = ($5|0)==(0);
 if ($6) {
  $119 = (($1) + 80|0);
  HEAPF32[$119>>2] = Math_fround(0.0);
  $120 = (($1) + 84|0);
  HEAPF32[$120>>2] = Math_fround(0.0);
  $121 = (($1) + 88|0);
  HEAPF32[$121>>2] = Math_fround(0.0);
  $122 = (($1) + 96|0);
  HEAPF32[$122>>2] = Math_fround(0.0);
  $123 = (($1) + 100|0);
  HEAPF32[$123>>2] = Math_fround(0.0);
  $124 = (($1) + 104|0);
  HEAPF32[$124>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $7 = $4 & 65023;
 $8 = $7&65535;
 HEAP16[$2>>1] = $8;
 $9 = (($1) + 156|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($10) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($10) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($10) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($10) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($10) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($10) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = HEAP32[$0>>2]|0;
 $25 = (($24) + 16|0);
 $26 = (($24) + 32|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($19 - $27);
 $29 = (($24) + 36|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($21 - $30);
 $32 = (($24) + 40|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($23 - $33);
 $35 = Math_fround($28 * $oneOverDt);
 $36 = Math_fround($31 * $oneOverDt);
 $37 = Math_fround($34 * $oneOverDt);
 $38 = Math_fround(HEAPF32[$25>>2]);
 $39 = Math_fround(-$38);
 $40 = (($24) + 20|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround(-$41);
 $43 = (($24) + 24|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround(-$44);
 $46 = (($24) + 28|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($17 * $39);
 $49 = Math_fround($11 * $47);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($13 * $45);
 $52 = Math_fround($51 + $50);
 $53 = Math_fround($15 * $42);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($17 * $42);
 $56 = Math_fround($13 * $47);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($15 * $39);
 $59 = Math_fround($58 + $57);
 $60 = Math_fround($11 * $45);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($17 * $45);
 $63 = Math_fround($15 * $47);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($11 * $42);
 $66 = Math_fround($65 + $64);
 $67 = Math_fround($13 * $39);
 $68 = Math_fround($66 - $67);
 $69 = Math_fround($17 * $47);
 $70 = Math_fround($11 * $39);
 $71 = Math_fround($69 - $70);
 $72 = Math_fround($13 * $42);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($15 * $45);
 $75 = Math_fround($73 - $74);
 $76 = $75 < Math_fround(0.0);
 if ($76) {
  $77 = Math_fround(-$54);
  $78 = Math_fround(-$61);
  $79 = Math_fround(-$68);
  $80 = Math_fround(-$75);
  $82 = $77;$84 = $78;$87 = $79;$95 = $80;
 } else {
  $82 = $54;$84 = $61;$87 = $68;$95 = $75;
 }
 $81 = Math_fround($82 * $82);
 $83 = Math_fround($84 * $84);
 $85 = Math_fround($83 + $81);
 $86 = Math_fround($87 * $87);
 $88 = Math_fround($86 + $85);
 $89 = $88 < Math_fround(1.00000001686238352639E-16);
 if ($89) {
  $104 = Math_fround(1.0);$105 = Math_fround(0.0);$107 = Math_fround(0.0);$109 = Math_fround(0.0);
 } else {
  $90 = (Math_fround(Math_sqrt((Math_fround($88)))));
  $91 = Math_fround(Math_fround(1.0) / $90);
  $92 = Math_fround($82 * $91);
  $93 = Math_fround($84 * $91);
  $94 = Math_fround($87 * $91);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($95)))));
  $96 = $fabsf$i$i$i < Math_fround(9.99999993922529029077E-9);
  if ($96) {
   $104 = $92;$105 = Math_fround(3.14159274101257324219);$107 = $93;$109 = $94;
  } else {
   $97 = Math_fround($88 * $91);
   $98 = +$97;
   $99 = +$95;
   $100 = (+Math_atan2((+$98),(+$99)));
   $101 = Math_fround($100);
   $102 = Math_fround($101 * Math_fround(2.0));
   $104 = $92;$105 = $102;$107 = $93;$109 = $94;
  }
 }
 $103 = Math_fround($105 * $104);
 $106 = Math_fround($105 * $107);
 $108 = Math_fround($105 * $109);
 $110 = Math_fround($103 * $oneOverDt);
 $111 = Math_fround($106 * $oneOverDt);
 $112 = Math_fround($108 * $oneOverDt);
 $113 = (($1) + 80|0);
 HEAPF32[$113>>2] = $35;
 $114 = (($1) + 84|0);
 HEAPF32[$114>>2] = $36;
 $115 = (($1) + 88|0);
 HEAPF32[$115>>2] = $37;
 $116 = (($1) + 96|0);
 HEAPF32[$116>>2] = $110;
 $117 = (($1) + 100|0);
 HEAPF32[$117>>2] = $111;
 $118 = (($1) + 104|0);
 HEAPF32[$118>>2] = $112;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim19updateKinematicPoseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 144|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 & 4;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = $4 & 65023;
 $8 = $7&65535;
 HEAP16[$2>>1] = $8;
 $9 = (($1) + 156|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($10) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($10) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($10) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($10) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($10) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($10) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = HEAP32[$0>>2]|0;
 $25 = (($24) + 16|0);
 HEAPF32[$25>>2] = $11;
 $26 = (($24) + 20|0);
 HEAPF32[$26>>2] = $13;
 $27 = (($24) + 24|0);
 HEAPF32[$27>>2] = $15;
 $28 = (($24) + 28|0);
 HEAPF32[$28>>2] = $17;
 $29 = (($24) + 32|0);
 HEAPF32[$29>>2] = $19;
 $30 = (($24) + 36|0);
 HEAPF32[$30>>2] = $21;
 $31 = (($24) + 40|0);
 HEAPF32[$31>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim19deactivateKinematicEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = $2 & 512;
 $4 = ($3|0)==(0);
 if ($4) {
  $35 = $2 & 65019;
  $36 = $35 | 512;
  $37 = $36&65535;
  HEAP16[$0>>1] = $37;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $5 = (($this) + 52|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $2 & 65023;
  $8 = $7&65535;
  HEAP16[$0>>1] = $8;
  $9 = (($6) + 152|0);
  HEAPF32[$9>>2] = Math_fround(0.0);
  $10 = (($this) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($11)|0);
  $13 = (($this) + 188|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 16|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16) + (($14*12)|0)|0) + 8|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $19 & 247;
  $21 = $20&255;
  HEAP8[$17>>0] = $21;
  $22 = (($12) + 273|0);
  HEAP8[$22>>0] = 1;
  $23 = HEAP32[$10>>2]|0;
  $24 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($23)|0);
  $25 = HEAP32[$13>>2]|0;
  $26 = (($24) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($27) + (($25*12)|0)|0) + 8|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $30 & 231;
  $32 = $31 | 16;
  $33 = $32&255;
  HEAP8[$28>>0] = $33;
  $34 = (($24) + 273|0);
  HEAP8[$34>>0] = 1;
  __ZN5physx2Sc5Actor9setActiveEbj($this,0,0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sc7BodySim12updateForcesEffbRKNS_6PxVec3Ebb($this,$dt,$0,$1,$gravity,$hasStaticTouch,$simUsesAdaptiveForce) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $0 = Math_fround($0);
 $1 = $1|0;
 $gravity = $gravity|0;
 $hasStaticTouch = $hasStaticTouch|0;
 $simUsesAdaptiveForce = $simUsesAdaptiveForce|0;
 var $$lobit = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0;
 var $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $brmerge1$demorgan = 0, $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 146|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 4;
 $6 = ($5|0)==(0);
 $7 = (($this) + 144|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $10 = $9 & 65533;
 $11 = $9 | 2;
 $storemerge$in = $hasStaticTouch ? $11 : $10;
 $storemerge = $storemerge$in&65535;
 HEAP16[$7>>1] = $storemerge;
 $12 = (($this) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $4 & 6;
 $15 = ($14|0)==(0);
 if ($15) {
  $106 = Math_fround(0.0);$108 = Math_fround(0.0);$110 = Math_fround(0.0);$82 = Math_fround(0.0);$84 = Math_fround(0.0);$86 = Math_fround(0.0);
 } else {
  $16 = (($13) + 156|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $106 = Math_fround(0.0);$108 = Math_fround(0.0);$110 = Math_fround(0.0);$82 = Math_fround(0.0);$84 = Math_fround(0.0);$86 = Math_fround(0.0);
  } else {
   $19 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($13,0)|0);
   if ($19) {
    $20 = HEAP32[$16>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     $106 = Math_fround(0.0);$108 = Math_fround(0.0);$110 = Math_fround(0.0);$82 = Math_fround(0.0);$84 = Math_fround(0.0);$86 = Math_fround(0.0);
    } else {
     $22 = Math_fround(HEAPF32[$20>>2]);
     $23 = (($20) + 4|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $25 = (($20) + 8|0);
     $26 = Math_fround(HEAPF32[$25>>2]);
     $27 = (($20) + 16|0);
     $28 = Math_fround(HEAPF32[$27>>2]);
     $29 = (($20) + 20|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     $31 = (($20) + 24|0);
     $32 = Math_fround(HEAPF32[$31>>2]);
     if ($6) {
      $106 = $28;$108 = $30;$110 = $32;$82 = $22;$84 = $24;$86 = $26;
     } else {
      $33 = HEAP32[$12>>2]|0;
      $34 = (($20) + 32|0);
      $35 = (($20) + 48|0);
      $36 = Math_fround(HEAPF32[$34>>2]);
      $37 = (($33) + 80|0);
      $38 = Math_fround(HEAPF32[$37>>2]);
      $39 = Math_fround($36 + $38);
      HEAPF32[$37>>2] = $39;
      $40 = (($20) + 36|0);
      $41 = Math_fround(HEAPF32[$40>>2]);
      $42 = (($33) + 84|0);
      $43 = Math_fround(HEAPF32[$42>>2]);
      $44 = Math_fround($41 + $43);
      HEAPF32[$42>>2] = $44;
      $45 = (($20) + 40|0);
      $46 = Math_fround(HEAPF32[$45>>2]);
      $47 = (($33) + 88|0);
      $48 = Math_fround(HEAPF32[$47>>2]);
      $49 = Math_fround($46 + $48);
      HEAPF32[$47>>2] = $49;
      $50 = Math_fround(HEAPF32[$35>>2]);
      $51 = (($33) + 96|0);
      $52 = Math_fround(HEAPF32[$51>>2]);
      $53 = Math_fround($50 + $52);
      HEAPF32[$51>>2] = $53;
      $54 = (($20) + 52|0);
      $55 = Math_fround(HEAPF32[$54>>2]);
      $56 = (($33) + 100|0);
      $57 = Math_fround(HEAPF32[$56>>2]);
      $58 = Math_fround($55 + $57);
      HEAPF32[$56>>2] = $58;
      $59 = (($20) + 56|0);
      $60 = Math_fround(HEAPF32[$59>>2]);
      $61 = (($33) + 104|0);
      $62 = Math_fround(HEAPF32[$61>>2]);
      $63 = Math_fround($60 + $62);
      HEAPF32[$61>>2] = $63;
      $106 = $28;$108 = $30;$110 = $32;$82 = $22;$84 = $24;$86 = $26;
     }
    }
   } else {
    $106 = Math_fround(0.0);$108 = Math_fround(0.0);$110 = Math_fround(0.0);$82 = Math_fround(0.0);$84 = Math_fround(0.0);$86 = Math_fround(0.0);
   }
  }
 }
 $64 = HEAP16[$7>>1]|0;
 $65 = $64 & 1;
 $66 = ($65<<16>>16)==(0);
 if ($66) {
  $67 = (($this) + 184|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($68 * $dt);
  $70 = Math_fround(Math_fround(1.0) - $69);
  $71 = $70 > Math_fround(0.0);
  $72 = $71 ? $70 : Math_fround(0.0);
  $73 = Math_fround(HEAPF32[$gravity>>2]);
  $74 = Math_fround($73 * $72);
  $75 = (($gravity) + 4|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($76 * $72);
  $78 = (($gravity) + 8|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($79 * $72);
  $81 = Math_fround($82 + $74);
  $83 = Math_fround($84 + $77);
  $85 = Math_fround($86 + $80);
  $93 = $81;$95 = $83;$97 = $85;
 } else {
  $93 = $82;$95 = $84;$97 = $86;
 }
 $brmerge1$demorgan = $simUsesAdaptiveForce & $hasStaticTouch;
 if ($brmerge1$demorgan) {
  $87 = (($this) + 148|0);
  $88 = HEAP16[$87>>1]|0;
  $89 = ($88&65535)>(1);
  if ($89) {
   $90 = (Math_fround(($88&65535)));
   $91 = Math_fround(Math_fround(1.0) / $90);
   $92 = Math_fround($93 * $91);
   $94 = Math_fround($95 * $91);
   $96 = Math_fround($97 * $91);
   $101 = $94;$103 = $96;$99 = $92;
  } else {
   $101 = $95;$103 = $97;$99 = $93;
  }
 } else {
  $101 = $95;$103 = $97;$99 = $93;
 }
 $98 = (($this) + 64|0);
 HEAPF32[$98>>2] = $99;
 $100 = (($this) + 68|0);
 HEAPF32[$100>>2] = $101;
 $102 = (($this) + 72|0);
 HEAPF32[$102>>2] = $103;
 $104 = (($this) + 76|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($this) + 80|0);
 HEAPF32[$105>>2] = $106;
 $107 = (($this) + 84|0);
 HEAPF32[$107>>2] = $108;
 $109 = (($this) + 88|0);
 HEAPF32[$109>>2] = $110;
 $111 = (($this) + 92|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = HEAP8[$2>>0]|0;
 $113 = HEAP32[$12>>2]|0;
 $114 = (($113) + 156|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ($115|0)==(0|0);
 if ($116) {
  $131 = ($112&255) >>> 1;
  $$lobit = $131 & 1;
  HEAP8[$2>>0] = $$lobit;
  STACKTOP = sp;return;
 }
 $117 = (__ZNK5physx2Sc8BodyCore28checkSimStateKinematicStatusEb($113,0)|0);
 if (!($117)) {
  $131 = ($112&255) >>> 1;
  $$lobit = $131 & 1;
  HEAP8[$2>>0] = $$lobit;
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$114>>2]|0;
 $119 = ($118|0)==(0|0);
 if ($119) {
  $131 = ($112&255) >>> 1;
  $$lobit = $131 & 1;
  HEAP8[$2>>0] = $$lobit;
  STACKTOP = sp;return;
 }
 $120 = (($118) + 48|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($118) + 52|0);
 HEAPF32[$121>>2] = Math_fround(0.0);
 $122 = (($118) + 56|0);
 HEAPF32[$122>>2] = Math_fround(0.0);
 $123 = (($118) + 32|0);
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = (($118) + 36|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = (($118) + 40|0);
 HEAPF32[$125>>2] = Math_fround(0.0);
 $126 = (($118) + 16|0);
 HEAPF32[$126>>2] = Math_fround(0.0);
 $127 = (($118) + 20|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = (($118) + 24|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 $129 = (($118) + 4|0);
 HEAPF32[$129>>2] = Math_fround(0.0);
 $130 = (($118) + 8|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = ($112&255) >>> 1;
 $$lobit = $131 & 1;
 HEAP8[$2>>0] = $$lobit;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc7BodySim13isConnectedToERKNS0_8RigidSimERb($this,$other,$collisionDisabled) {
 $this = $this|0;
 $other = $other|0;
 $collisionDisabled = $collisionDisabled|0;
 var $$0 = 0, $$ph = 0, $$ph7 = 0, $$tr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $actorToMatch$0$ph = 0, $storemerge = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($other) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)>($3>>>0);
 if ($4) {
  $8 = (($other) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($3<<2)|0);
  $$ph = $10;$$ph7 = $9;$actorToMatch$0$ph = $this;
 } else {
  $5 = (($this) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($1<<2)|0);
  $$ph = $7;$$ph7 = $6;$actorToMatch$0$ph = $other;
 }
 $11 = ($$ph7>>>0)<($$ph>>>0);
 if ($11) {
  $13 = $$ph7;
 } else {
  $$0 = 0;$storemerge = 0;
  HEAP8[$collisionDisabled>>0] = $storemerge;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $12 = HEAP32[$13>>2]|0;
  $14 = (($12) + 20|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(1);
  if ($16) {
   $17 = (($12) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==($actorToMatch$0$ph|0);
   if ($19) {
    break;
   }
   $20 = (($12) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==($actorToMatch$0$ph|0);
   if ($22) {
    break;
   }
  }
  $31 = (($13) + 4|0);
  $32 = ($31>>>0)<($$ph>>>0);
  if ($32) {
   $13 = $31;
  } else {
   $$0 = 0;$storemerge = 0;
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  HEAP8[$collisionDisabled>>0] = $storemerge;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = (($12) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 100|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP16[$26>>1]|0;
 $28 = ($27&65535) >>> 3;
 $$tr = $28&255;
 $29 = $$tr & 1;
 $30 = $29 ^ 1;
 $$0 = 1;$storemerge = $30;
 HEAP8[$collisionDisabled>>0] = $storemerge;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc7BodySim18onConstraintDetachEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = (($this) + 46|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = (($6) + -1)<<16>>16;
 HEAP16[$5>>1] = $7;
 $8 = ($3|0)>(0);
 L1: do {
  if ($8) {
   $12 = $1;
   while(1) {
    $11 = HEAP32[$12>>2]|0;
    $13 = (($11) + 20|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = ($14<<24>>24)==(1);
    $10 = (($12) + 4|0);
    if ($15) {
     break;
    }
    $9 = ($10>>>0)<($4>>>0);
    if ($9) {
     $12 = $10;
    } else {
     break L1;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $16 = (($this) + 144|0);
 $17 = HEAP16[$16>>1]|0;
 $18 = $17&65535;
 $19 = $18 & 65279;
 $20 = $19&65535;
 HEAP16[$16>>1] = $20;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7BodySim15setArticulationEPNS0_15ArticulationSimEfb($this,$a,$wakeCounter,$asleep) {
 $this = $this|0;
 $a = $a|0;
 $wakeCounter = Math_fround($wakeCounter);
 $asleep = $asleep|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 HEAP32[$0>>2] = $a;
 $1 = ($a|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 152|0);
 HEAPF32[$4>>2] = $wakeCounter;
 if ($asleep) {
  $19 = (($this) + 36|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($20)|0);
  $22 = (($this) + 188|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($25) + (($23*12)|0)|0) + 8|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = $28 & 247;
  $30 = $29&255;
  HEAP8[$26>>0] = $30;
  $31 = (($21) + 273|0);
  HEAP8[$31>>0] = 1;
  $32 = HEAP32[$19>>2]|0;
  $33 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($32)|0);
  $34 = HEAP32[$22>>2]|0;
  $35 = (($33) + 16|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($36) + (($34*12)|0)|0) + 8|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = $38&255;
  $40 = $39 & 231;
  $41 = $40 | 16;
  $42 = $41&255;
  HEAP8[$37>>0] = $42;
  $43 = (($33) + 273|0);
  HEAP8[$43>>0] = 1;
  __ZN5physx2Sc5Actor9setActiveEbj($this,0,0);
  STACKTOP = sp;return;
 } else {
  __ZN5physx2Sc5Actor9setActiveEbj($this,1,0);
  $5 = (($this) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($6)|0);
  $8 = (($this) + 188|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + (($9*12)|0)|0) + 8|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 & 231;
  $16 = $15 | 8;
  $17 = $16&255;
  HEAP8[$12>>0] = $17;
  $18 = (($7) + 273|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc14ConstraintCoreC2ERNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableEj($this,$connector,$shaders,$dataSize) {
 $this = $this|0;
 $connector = $connector|0;
 $shaders = $shaders|0;
 $dataSize = $dataSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP16[$this>>1] = 64;
 $0 = (($this) + 4|0);
 $1 = (($this) + 28|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 HEAP32[$1>>2] = $connector;
 $2 = (($this) + 32|0);
 $3 = (($shaders) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 36|0);
 $6 = HEAP32[$shaders>>2]|0;
 HEAP32[$5>>2] = $6;
 $7 = (($this) + 40|0);
 $8 = (($shaders) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = (($this) + 44|0);
 $11 = (($shaders) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $12;
 $13 = (($this) + 48|0);
 $14 = (($shaders) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$13>>2] = $15;
 $16 = (($this) + 52|0);
 HEAP32[$16>>2] = $dataSize;
 $17 = (($this) + 56|0);
 HEAPF32[$17>>2] = Math_fround(3.40282346638528859812E+38);
 $18 = (($this) + 60|0);
 HEAPF32[$18>>2] = Math_fround(3.40282346638528859812E+38);
 $19 = (($this) + 64|0);
 HEAP32[$19>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc14ConstraintCoreD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc14ConstraintCore8setFlagsENS_7PxFlagsINS_16PxConstraintFlag4EnumEtEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = HEAP16[$flags>>1]|0;
 $3 = HEAP16[$this>>1]|0;
 $4 = ($2<<16>>16)==($3<<16>>16);
 if ($4) {
  STACKTOP = sp;return;
 }
 HEAP16[$this>>1] = $2;
 $5 = (($this) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 HEAP16[$0>>1] = $3;
 $8 = HEAP16[$flags>>1]|0;
 HEAP16[$1>>1] = $8;
 __ZN5physx2Sc13ConstraintSim14postFlagChangeENS_7PxFlagsINS_16PxConstraintFlag4EnumEtEES5_($6,$0,$1);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc14ConstraintCore8getForceERNS_6PxVec3ES3_($this,$force,$torque) {
 $this = $this|0;
 $force = $force|0;
 $torque = $torque|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAPF32[$force>>2] = Math_fround(0.0);
  $3 = (($force) + 4|0);
  HEAPF32[$3>>2] = Math_fround(0.0);
  $4 = (($force) + 8|0);
  HEAPF32[$4>>2] = Math_fround(0.0);
  HEAPF32[$torque>>2] = Math_fround(0.0);
  $5 = (($torque) + 4|0);
  HEAPF32[$5>>2] = Math_fround(0.0);
  $6 = (($torque) + 8|0);
  HEAPF32[$6>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 } else {
  __ZN5physx2Sc13ConstraintSim8getForceERNS_6PxVec3ES3_($1,$force,$torque);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc14ConstraintCore9setBodiesEPNS0_9RigidCoreES3_($this,$r0v,$r1v) {
 $this = $this|0;
 $r0v = $r0v|0;
 $r1v = $r1v|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc13ConstraintSim16postBodiesChangeEPNS0_9RigidCoreES3_($1,$r0v,$r1v);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc14ConstraintCore15updateConstantsEPv($this,$addr) {
 $this = $this|0;
 $addr = $addr|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($1) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 _memcpy(($4|0),($addr|0),($6|0))|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc14ConstraintCore13setBreakForceEff($this,$linear,$angular) {
 $this = $this|0;
 $linear = Math_fround($linear);
 $angular = Math_fround($angular);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 HEAPF32[$0>>2] = $linear;
 $1 = (($this) + 60|0);
 HEAPF32[$1>>2] = $angular;
 $2 = (($this) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc13ConstraintSim15setBreakForceLLEff($3,$linear,$angular);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc14ConstraintCore13getBreakForceERfS2_($this,$linear,$angular) {
 $this = $this|0;
 $linear = $linear|0;
 $angular = $angular|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$linear>>2] = $1;
 $2 = (($this) + 60|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$angular>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc14ConstraintCore15getPxConstraintEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z17NpGetPxConstraintRN5physx2Sc14ConstraintCoreE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Sc14ConstraintCore10breakApartEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$this>>1]|0;
 $1 = $0&65535;
 $2 = $1 | 1;
 $3 = $2&65535;
 HEAP16[$this>>1] = $3;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ConstraintGroupNodeC2ERNS0_7BodySimE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $b;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $this;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $this;
 $2 = (($this) + 12|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;HEAP8[$2+32>>0]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ConstraintGroupNode7getRootEv($this) {
 $this = $this|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curr$02 = 0, $curr$02$phi = 0, $nbHops$0 = 0;
 var $nbHops$11 = 0, $root$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $nbHops$0 = 1;$root$0 = $3;
 }
 while(1) {
  $5 = (($root$0) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($root$0|0)==($6|0);
  $8 = (($nbHops$0) + 1)|0;
  if ($7) {
   break;
  } else {
   $nbHops$0 = $8;$root$0 = $6;
  }
 }
 $9 = ($nbHops$0|0)==(0);
 if ($9) {
  $$0 = $root$0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $13 = $1;$curr$02 = $this;$nbHops$11 = $nbHops$0;
 }
 while(1) {
  $10 = (($curr$02) + 4|0);
  HEAP32[$10>>2] = $root$0;
  $11 = (($nbHops$11) + -1)|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $$0 = $root$0;
   break;
  }
  $$phi$trans$insert = (($13) + 4|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $curr$02$phi = $13;$13 = $$pre;$nbHops$11 = $11;$curr$02 = $curr$02$phi;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc19ConstraintGroupNode18initProjectionDataEPS1_PNS0_13ConstraintSimE($this,$parent_,$c) {
 $this = $this|0;
 $parent_ = $parent_|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = $c;
 $1 = ($parent_|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($parent_) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$2>>2] = $this;
 $5 = (($this) + 28|0);
 HEAP32[$5>>2] = $parent_;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ConstraintGroupNode19clearProjectionDataEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ConstraintGroupNode11projectPoseERS1_($node) {
 $node = $node|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc24ConstraintProjectionTree11projectPoseERNS0_19ConstraintGroupNodeE($node);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ConstraintInteractionC2EPNS0_13ConstraintSimERNS0_8RigidSimES5_($this,$constraint,$r0,$r1) {
 $this = $this|0;
 $constraint = $constraint|0;
 $r0 = $r0|0;
 $r1 = $r1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc11InteractionC2ERNS0_5ActorES3_NS0_15InteractionTypeEh($this,$r0,$r1,1,2);
 $0 = (($this) + 24|0);
 $1 = (($this) + 28|0);
 HEAP16[$1>>1] = -1;
 $2 = (($this) + 30|0);
 HEAP16[$2>>1] = 0;
 HEAP32[$this>>2] = ((458904 + 8|0));
 HEAP32[$0>>2] = ((458904 + 48|0));
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = $constraint;
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = -1;
 $5 = (($constraint) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($constraint) + 112|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==(0|0);
 if (!($9)) {
  $10 = (($6) + 144|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = $11&65535;
  $13 = $12 | 256;
  $14 = $13&65535;
  HEAP16[$10>>1] = $14;
  $15 = (($6) + 46|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = (($16) + 1)<<16>>16;
  HEAP16[$15>>1] = $17;
 }
 $18 = ($8|0)==(0|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($8) + 144|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = $20&65535;
 $22 = $21 | 256;
 $23 = $22&65535;
 HEAP16[$19>>1] = $23;
 $24 = (($8) + 46|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = (($25) + 1)<<16>>16;
 HEAP16[$24>>1] = $26;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ConstraintInteractionD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((458904 + 8|0));
 $1 = (($this) + 24|0);
 HEAP32[$1>>2] = ((458904 + 48|0));
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn24_N5physx2Sc21ConstraintInteractionD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -24|0);
 HEAP32[$1>>2] = ((458904 + 8|0));
 $2 = (($1) + 24|0);
 HEAP32[$2>>2] = ((458904 + 48|0));
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ConstraintInteractionD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((458904 + 8|0));
 $0 = (($this) + 24|0);
 HEAP32[$0>>2] = ((458904 + 48|0));
 STACKTOP = sp;return;
}
function __ZThn24_N5physx2Sc21ConstraintInteractionD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 HEAP32[$0>>2] = ((458904 + 8|0));
 $1 = (($0) + 24|0);
 HEAP32[$1>>2] = ((458904 + 48|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ConstraintInteraction7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc8ActorSim8getSceneEv($1)|0);
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 116|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 6;
 $8 = ($7<<24>>24)==(6);
 if ($8) {
  __ZN5physx2Sc5Scene31removeActiveBreakableConstraintEPNS0_13ConstraintSimE($2,$4);
 }
 $9 = (($this) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(-1);
 if (!($11)) {
  $12 = (($2) + 1212|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($13)|0);
  __ZN5physx16PxsIslandManager10removeEdgeENS0_9eEdgeTypeERNS_20PxsIslandManagerHookIjLj4294967295EEE($14,1,$9);
 }
 $15 = (($this) + 30|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16 & 2;
 $18 = ($17<<16>>16)==(0);
 if (!($18)) {
  $19 = (($this) + 24|0);
  __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($19);
  $20 = HEAP16[$15>>1]|0;
  $21 = $20&65535;
  $22 = $21 & 65533;
  $23 = $22&65535;
  HEAP16[$15>>1] = $23;
 }
 $24 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($24,$this);
 $25 = (($this) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($26,$this);
 $27 = HEAP32[$0>>2]|0;
 $28 = (($27) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($29,$this);
 $30 = HEAP32[$3>>2]|0;
 $31 = (($30) + 108|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 112|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32|0)==(0|0);
 if (!($35)) {
  __ZN5physx2Sc7BodySim18onConstraintDetachEv($32);
 }
 $36 = ($34|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc7BodySim18onConstraintDetachEv($34);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ConstraintInteraction11updateStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 30|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)==(0);
 if (!($3)) {
  $4 = (($this) + 24|0);
  __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($4);
  $5 = HEAP16[$0>>1]|0;
  $6 = $5&65535;
  $7 = $6 & 65533;
  $8 = $7&65535;
  HEAP16[$0>>1] = $8;
 }
 $9 = (($this) + 28|0);
 HEAP16[$9>>1] = 0;
 STACKTOP = sp;return;
}
function __ZThn24_N5physx2Sc21ConstraintInteraction11updateStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 $1 = (($0) + 30|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & 2;
 $4 = ($3<<16>>16)==(0);
 if ($4) {
  $10 = (($0) + 28|0);
  HEAP16[$10>>1] = 0;
  STACKTOP = sp;return;
 }
 $5 = (($0) + 24|0);
 __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($5);
 $6 = HEAP16[$1>>1]|0;
 $7 = $6&65535;
 $8 = $7 & 65533;
 $9 = $8&65535;
 HEAP16[$1>>1] = $9;
 $10 = (($0) + 28|0);
 HEAP16[$10>>1] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc21ConstraintInteraction10onActivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $storemerge = 0, $storemerge2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $1 = sp + 4|0;
 $2 = sp;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 112|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(-1);
 if ($11) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZNK5physx2Sc8ActorSim8getSceneEv($13)|0);
  $15 = (($14) + 1212|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($16)|0);
  $18 = ($6|0)==(0|0);
  if ($18) {
   $storemerge = -1;
  } else {
   $19 = (($6) + 188|0);
   $20 = HEAP32[$19>>2]|0;
   $storemerge = $20;
  }
  HEAP32[$1>>2] = $storemerge;
  $21 = ($8|0)==(0|0);
  if ($21) {
   $storemerge2 = -1;
  } else {
   $22 = (($8) + 188|0);
   $23 = HEAP32[$22>>2]|0;
   $storemerge2 = $23;
  }
  HEAP32[$2>>2] = $storemerge2;
  __ZN5physx16PxsIslandManager7addEdgeENS0_9eEdgeTypeENS_20PxsIslandManagerHookIjLj4294967295EEES3_RS3_($17,1,$1,$2,$9);
  $24 = HEAP32[$3>>2]|0;
  $25 = (($24) + 32|0);
  __ZN5physx16PxsIslandManager17setEdgeConstraintERKNS_20PxsIslandManagerHookIjLj4294967295EEEPNS_13PxsConstraintE($17,$9,$25);
  __ZN5physx16PxsIslandManager16setEdgeConnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($17,$9);
 }
 $26 = ($6|0)==(0|0);
 if ($26) {
  $36 = 1;
 } else {
  $27 = (($6) + 51|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)!=(0);
  $36 = $30;
 }
 $31 = ($8|0)==(0|0);
 if (!($31)) {
  $32 = (($8) + 51|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33 & 1;
  $35 = ($34<<24>>24)!=(0);
  $brmerge = $36 | $35;
  if (!($brmerge)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $37 = HEAP32[$3>>2]|0;
 $38 = (($37) + 116|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39 & 6;
 $41 = ($40<<24>>24)==(2);
 if (!($41)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = (($this) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (__ZNK5physx2Sc8ActorSim8getSceneEv($43)|0);
 $45 = HEAP32[$3>>2]|0;
 __ZN5physx2Sc5Scene28addActiveBreakableConstraintEPNS0_13ConstraintSimE($44,$45);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc21ConstraintInteraction12onDeactivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 116|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 6;
 $6 = ($5<<24>>24)==(6);
 if (!($6)) {
  STACKTOP = sp;return 1;
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK5physx2Sc8ActorSim8getSceneEv($8)|0);
 $10 = HEAP32[$1>>2]|0;
 __ZN5physx2Sc5Scene31removeActiveBreakableConstraintEPNS0_13ConstraintSimE($9,$10);
 STACKTOP = sp;return 1;
}
function __ZN5physx2Sc27ConstraintProjectionManagerC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 264|0);
 $2 = (($this) + 268|0);
 $3 = (($this) + 272|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 276|0);
 HEAP8[$1>>0] = 1;
 HEAP32[$2>>2] = $0;
 HEAP32[$4>>2] = 64;
 $5 = (($this) + 280|0);
 HEAP32[$5>>2] = 32;
 $6 = (($this) + 284|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 288|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 292|0);
 HEAP32[$8>>2] = 1536;
 $9 = (($this) + 296|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc27ConstraintProjectionManager24addToPendingGroupUpdatesERNS0_13ConstraintSimE($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 300|0);
 HEAP32[$0>>2] = $s;
 $2 = (($this) + 308|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = (($this) + 304|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if (!($7)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
  $12 = (($s) + 116|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13 | 1;
  HEAP8[$12>>0] = $14;
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  HEAP32[$9>>2] = $s;
 }
 $11 = (($6) + 1)|0;
 HEAP32[$5>>2] = $11;
 $12 = (($s) + 116|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 | 1;
 HEAP8[$12>>0] = $14;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc27ConstraintProjectionManager29removeFromPendingGroupUpdatesERNS0_13ConstraintSimE($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $index$0$lcssa$i = 0, $index$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 304|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 300|0);
  $4 = HEAP32[$3>>2]|0;
  $index$01$i = 0;
  while(1) {
   $7 = (($4) + ($index$01$i<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==($s|0);
   $6 = (($index$01$i) + 1)|0;
   if ($9) {
    $index$0$lcssa$i = $index$01$i;
    break;
   }
   $5 = ($6>>>0)<($1>>>0);
   if ($5) {
    $index$01$i = $6;
   } else {
    $index$0$lcssa$i = $6;
    break;
   }
  }
  $10 = ($index$0$lcssa$i|0)==($1|0);
  if (!($10)) {
   $11 = (($1) + -1)|0;
   HEAP32[$0>>2] = $11;
   $12 = (($4) + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($4) + ($index$0$lcssa$i<<2)|0);
   HEAP32[$14>>2] = $13;
  }
 }
 $15 = (($s) + 116|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $17 & 254;
 $19 = $18&255;
 HEAP8[$15>>0] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc27ConstraintProjectionManager10addToGroupERNS0_7BodySimEPS2_RNS0_13ConstraintSimE($this,$b,$other,$c) {
 $this = $this|0;
 $b = $b|0;
 $other = $other|0;
 $c = $c|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $myRoot$0 = 0, $newRoot$0$i = 0;
 var $otherRoot$0 = 0, $otherRoot$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 296|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $6 = (($this) + 4|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($6);
   $$pre$i$i$i1 = HEAP32[$3>>2]|0;
   $8 = $$pre$i$i$i1;
  } else {
   $8 = $4;
  }
  $7 = HEAP32[$8>>2]|0;
  HEAP32[$3>>2] = $7;
  $9 = (($this) + 284|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$9>>2] = $11;
  $12 = (($this) + 288|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + -1)|0;
  HEAP32[$12>>2] = $14;
  $15 = ($8|0)==(0|0);
  if ($15) {
   $16 = 0;
  } else {
   __ZN5physx2Sc19ConstraintGroupNodeC2ERNS0_7BodySimE($8,$b);
   $16 = $8;
  }
  HEAP32[$0>>2] = $16;
  $myRoot$0 = $16;
 } else {
  $17 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($1)|0);
  $18 = (($17) + 20|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $myRoot$0 = $17;
  } else {
   __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($17);
   $myRoot$0 = $17;
  }
 }
 $21 = ($other|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($other) + 60|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = (($this) + 296|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if ($27) {
   $28 = (($this) + 4|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($28);
   $$pre$i$i$i = HEAP32[$25>>2]|0;
   $30 = $$pre$i$i$i;
  } else {
   $30 = $26;
  }
  $29 = HEAP32[$30>>2]|0;
  HEAP32[$25>>2] = $29;
  $31 = (($this) + 284|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 1)|0;
  HEAP32[$31>>2] = $33;
  $34 = (($this) + 288|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + -1)|0;
  HEAP32[$34>>2] = $36;
  $37 = ($30|0)==(0|0);
  if ($37) {
   $38 = 0;
  } else {
   __ZN5physx2Sc19ConstraintGroupNodeC2ERNS0_7BodySimE($30,$other);
   $38 = $30;
  }
  HEAP32[$22>>2] = $38;
  $otherRoot$0 = $38;
 } else {
  $39 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($23)|0);
  $40 = (($39) + 20|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   $otherRoot$0 = $39;
  } else {
   __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($39);
   $otherRoot$0 = $39;
  }
 }
 $43 = ($myRoot$0|0)==($otherRoot$0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 $44 = (($myRoot$0) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($otherRoot$0) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($45>>>0)>($47>>>0);
 if ($48) {
  $newRoot$0$i = $myRoot$0;$otherRoot$0$i = $otherRoot$0;
 } else {
  $49 = (($47) + 1)|0;
  HEAP32[$46>>2] = $49;
  $newRoot$0$i = $otherRoot$0;$otherRoot$0$i = $myRoot$0;
 }
 $50 = (($otherRoot$0$i) + 4|0);
 HEAP32[$50>>2] = $newRoot$0$i;
 $51 = (($newRoot$0$i) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 16|0);
 HEAP32[$53>>2] = $otherRoot$0$i;
 $54 = (($otherRoot$0$i) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$51>>2] = $55;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc27ConstraintProjectionManager11buildGroupsEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$09 = 0, $i1$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 300|0);
 $2 = (($this) + 304|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 308|0);
 $i$09 = 0;
 while(1) {
  $6 = HEAP32[$1>>2]|0;
  $7 = (($6) + ($i$09<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 116|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = $11 & 254;
  $13 = $12&255;
  HEAP8[$9>>0] = $13;
  $14 = (($8) + 108|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = (($15) + 60|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    $20 = (($15) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($15) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + ($23<<2)|0);
    $25 = ($23|0)>(0);
    if ($25) {
     $27 = $21;
     while(1) {
      $26 = HEAP32[$27>>2]|0;
      $28 = (($26) + 20|0);
      $29 = HEAP8[$28>>0]|0;
      $30 = ($29<<24>>24)==(1);
      if ($30) {
       $31 = (($26) + 32|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = ($32|0)==($8|0);
       if (!($33)) {
        $34 = (($32) + 116|0);
        $35 = HEAP8[$34>>0]|0;
        $36 = $35 & 1;
        $37 = ($36<<24>>24)==(0);
        if ($37) {
         HEAP32[$0>>2] = $32;
         $38 = HEAP32[$5>>2]|0;
         $39 = $38 & 2147483647;
         $40 = HEAP32[$2>>2]|0;
         $41 = ($39>>>0)>($40>>>0);
         if ($41) {
          $42 = HEAP32[$1>>2]|0;
          $43 = (($42) + ($40<<2)|0);
          $44 = ($43|0)==(0|0);
          if (!($44)) {
           HEAP32[$43>>2] = $32;
          }
          $45 = (($40) + 1)|0;
          HEAP32[$2>>2] = $45;
         } else {
          (__ZN5physx6shdfnd5ArrayIPNS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
         }
         $46 = HEAP8[$34>>0]|0;
         $47 = $46 | 1;
         HEAP8[$34>>0] = $47;
        }
       }
      }
      $48 = (($27) + 4|0);
      $49 = ($48>>>0)<($24>>>0);
      if ($49) {
       $27 = $48;
      } else {
       break;
      }
     }
    }
   }
  }
  $50 = (($8) + 112|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0|0);
  if (!($52)) {
   $53 = (($51) + 60|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    $56 = (($51) + 20|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($51) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($57) + ($59<<2)|0);
    $61 = ($59|0)>(0);
    if ($61) {
     $63 = $57;
     while(1) {
      $62 = HEAP32[$63>>2]|0;
      $64 = (($62) + 20|0);
      $65 = HEAP8[$64>>0]|0;
      $66 = ($65<<24>>24)==(1);
      if ($66) {
       $67 = (($62) + 32|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = ($68|0)==($8|0);
       if (!($69)) {
        $70 = (($68) + 116|0);
        $71 = HEAP8[$70>>0]|0;
        $72 = $71 & 1;
        $73 = ($72<<24>>24)==(0);
        if ($73) {
         HEAP32[$0>>2] = $68;
         $74 = HEAP32[$5>>2]|0;
         $75 = $74 & 2147483647;
         $76 = HEAP32[$2>>2]|0;
         $77 = ($75>>>0)>($76>>>0);
         if ($77) {
          $78 = HEAP32[$1>>2]|0;
          $79 = (($78) + ($76<<2)|0);
          $80 = ($79|0)==(0|0);
          if (!($80)) {
           HEAP32[$79>>2] = $68;
          }
          $81 = (($76) + 1)|0;
          HEAP32[$2>>2] = $81;
         } else {
          (__ZN5physx6shdfnd5ArrayIPNS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
         }
         $82 = HEAP8[$70>>0]|0;
         $83 = $82 | 1;
         HEAP8[$70>>0] = $83;
        }
       }
      }
      $84 = (($63) + 4|0);
      $85 = ($84>>>0)<($60>>>0);
      if ($85) {
       $63 = $84;
      } else {
       break;
      }
     }
    }
   }
  }
  $86 = HEAP32[$14>>2]|0;
  $87 = ($86|0)==(0|0);
  if ($87) {
   $88 = HEAP32[$50>>2]|0;
   $$0$i1 = $88;
  } else {
   $$0$i1 = $86;
  }
  $89 = ($86|0)==($$0$i1|0);
  if ($89) {
   $90 = HEAP32[$50>>2]|0;
   $91 = $90;
  } else {
   $91 = $86;
  }
  __ZN5physx2Sc27ConstraintProjectionManager10addToGroupERNS0_7BodySimEPS2_RNS0_13ConstraintSimE($this,$$0$i1,$91,$8);
  $92 = (($i$09) + 1)|0;
  $93 = HEAP32[$2>>2]|0;
  $94 = ($92>>>0)<($93>>>0);
  if ($94) {
   $i$09 = $92;
  } else {
   break;
  }
 }
 $i1$07 = 0;
 while(1) {
  $95 = HEAP32[$1>>2]|0;
  $96 = (($95) + ($i1$07<<2)|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($97) + 108|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = ($99|0)==(0|0);
  if ($100) {
   $101 = (($97) + 112|0);
   $102 = HEAP32[$101>>2]|0;
   $$0$i = $102;
  } else {
   $$0$i = $99;
  }
  $103 = (($$0$i) + 60|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($104)|0);
  $106 = (($105) + 20|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ($107|0)==(0|0);
  if ($108) {
   __ZN5physx2Sc24ConstraintProjectionTree20buildProjectionTreesERNS0_19ConstraintGroupNodeE($105);
  }
  $109 = (($i1$07) + 1)|0;
  $exitcond = ($109|0)==($3|0);
  if ($exitcond) {
   break;
  } else {
   $i1$07 = $109;
  }
 }
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc27ConstraintProjectionManager15invalidateGroupERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimE($this,$node,$deletedConstraint) {
 $this = $this|0;
 $node = $node|0;
 $deletedConstraint = $deletedConstraint|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $n$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($node)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 300|0);
 $4 = (($this) + 308|0);
 $5 = (($this) + 304|0);
 $6 = (($this) + 4|0);
 $7 = (($this) + 284|0);
 $8 = (($this) + 296|0);
 $9 = (($this) + 288|0);
 $10 = (($this) + 280|0);
 $n$01 = $1;
 while(1) {
  $11 = HEAP32[$n$01>>2]|0;
  $12 = (($11) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + ($15<<2)|0);
  $17 = ($15|0)>(0);
  if ($17) {
   $19 = $13;
   while(1) {
    $18 = HEAP32[$19>>2]|0;
    $20 = (($18) + 20|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)==(1);
    if ($22) {
     $23 = (($18) + 32|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==($deletedConstraint|0);
     if (!($25)) {
      $26 = (__ZN5physx2Sc13ConstraintSim15needsProjectionEv($24)|0);
      if ($26) {
       $27 = (($24) + 116|0);
       $28 = HEAP8[$27>>0]|0;
       $29 = $28 & 1;
       $30 = ($29<<24>>24)==(0);
       if ($30) {
        HEAP32[$0>>2] = $24;
        $31 = HEAP32[$4>>2]|0;
        $32 = $31 & 2147483647;
        $33 = HEAP32[$5>>2]|0;
        $34 = ($32>>>0)>($33>>>0);
        if ($34) {
         $35 = HEAP32[$3>>2]|0;
         $36 = (($35) + ($33<<2)|0);
         $37 = ($36|0)==(0|0);
         if (!($37)) {
          HEAP32[$36>>2] = $24;
         }
         $38 = (($33) + 1)|0;
         HEAP32[$5>>2] = $38;
        } else {
         (__ZN5physx6shdfnd5ArrayIPNS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($3,$0)|0);
        }
        $39 = HEAP8[$27>>0]|0;
        $40 = $39 | 1;
        HEAP8[$27>>0] = $40;
       }
      }
     }
    }
    $41 = (($19) + 4|0);
    $42 = ($41>>>0)<($16>>>0);
    if ($42) {
     $19 = $41;
    } else {
     break;
    }
   }
   $$pre = HEAP32[$n$01>>2]|0;
   $46 = $$pre;
  } else {
   $46 = $11;
  }
  $43 = (($n$01) + 16|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($46) + 60|0);
  HEAP32[$45>>2] = 0;
  $47 = (($n$01) + 20|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($n$01);
  }
  $51 = HEAP32[$7>>2]|0;
  $52 = (($51) + -1)|0;
  HEAP32[$7>>2] = $52;
  $53 = HEAP32[$8>>2]|0;
  HEAP32[$n$01>>2] = $53;
  HEAP32[$8>>2] = $n$01;
  $54 = HEAP32[$9>>2]|0;
  $55 = (($54) + 1)|0;
  HEAP32[$9>>2] = $55;
  $56 = HEAP32[$10>>2]|0;
  $57 = ($56*50)|0;
  $58 = ($54|0)<($57|0);
  if (!($58)) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($6);
   HEAP32[$9>>2] = 0;
  }
  $50 = ($44|0)==(0|0);
  if ($50) {
   break;
  } else {
   $n$01 = $44;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 48)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 459080 : 459048;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,459216,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 459080 : 459048;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,459216,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 459080 : 459048;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,458968,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 459080 : 459048;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,458968,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 459080 : 459048;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,458968,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 459304 : 459048;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,458968,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 459080 : 459048;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,459432,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*48)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -48|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc24ConstraintProjectionTree14rankConstraintERNS0_13ConstraintSimERNS0_8BodyRankERj($c,$br,$dominanceTracking) {
 $c = $c|0;
 $br = $br|0;
 $dominanceTracking = $dominanceTracking|0;
 var $$phi$trans$insert$phi$trans$insert = 0, $$phi$trans$insert2 = 0, $$pre$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $rank$0 = 0, $rank$1 = 0, $rank$1$v = 0, $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$br>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc13ConstraintSim8isBrokenEv($c)|0);
 $3 = (($c) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = (($c) + 108|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($1|0);
 if ($9) {
  $10 = $6 & 2;
  $11 = $2 ? 0 : $10;
  $12 = $6 & 4;
  $13 = $2 ? 0 : $12;
  $14 = (($c) + 112|0);
  $27 = $13;$38 = $11;$storemerge$in$i = $14;
 } else {
  $15 = $6 & 4;
  $16 = $2 ? 0 : $15;
  $17 = $6 & 2;
  $18 = $2 ? 0 : $17;
  $27 = $18;$38 = $16;$storemerge$in$i = $7;
 }
 $storemerge$i = HEAP32[$storemerge$in$i>>2]|0;
 $19 = ($storemerge$i|0)==(0|0);
 if (!($19)) {
  $20 = (($storemerge$i) + 52|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 44|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23 & 1;
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   $37 = ($38|0)==(0);
   $39 = ($27|0)==(0);
   do {
    if ($37) {
     if ($39) {
      $$phi$trans$insert2 = (($br) + 8|0);
      $$pre3 = HEAP32[$$phi$trans$insert2>>2]|0;
      $57 = $$pre3;
      break;
     } else {
      $45 = HEAP32[$dominanceTracking>>2]|0;
      $46 = $45 & -402653185;
      HEAP32[$dominanceTracking>>2] = $46;
      $47 = (($br) + 8|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = $48 & -402653185;
      HEAP32[$47>>2] = $49;
      $57 = $49;
      break;
     }
    } else {
     $40 = HEAP32[$dominanceTracking>>2]|0;
     if ($39) {
      $50 = $40 & 402653184;
      $51 = (($br) + 8|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = $50 | $52;
      $54 = $53 | -2147483648;
      HEAP32[$51>>2] = $54;
      $57 = $54;
      break;
     } else {
      $41 = $40 & -268435457;
      HEAP32[$dominanceTracking>>2] = $41;
      $42 = (($br) + 8|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = $43 & -268435457;
      HEAP32[$42>>2] = $44;
      $57 = $44;
      break;
     }
    }
   } while(0);
   $55 = (($br) + 8|0);
   $56 = (($57) + 1)|0;
   HEAP32[$55>>2] = $56;
   STACKTOP = sp;return;
  }
 }
 $26 = ($27|0)==(0);
 if ($26) {
  $rank$0 = 0;
 } else {
  HEAP32[$dominanceTracking>>2] = 0;
  $28 = (($br) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $29 & -402653185;
  HEAP32[$28>>2] = $30;
  $rank$0 = -2147483648;
 }
 $rank$1$v = $19 ? 1073741824 : 536870912;
 $rank$1 = $rank$0 | $rank$1$v;
 $31 = (($br) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 $$phi$trans$insert$phi$trans$insert = (($br) + 8|0);
 $$pre$pre = HEAP32[$$phi$trans$insert$phi$trans$insert>>2]|0;
 $34 = ($rank$1>>>0)>($$pre$pre>>>0);
 $or$cond = $33 | $34;
 if ($or$cond) {
  HEAP32[$31>>2] = $c;
 }
 $35 = (($br) + 8|0);
 $36 = $$pre$pre | $rank$1;
 HEAP32[$35>>2] = $36;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc24ConstraintProjectionTree20buildProjectionTreesERNS0_19ConstraintGroupNodeE($root) {
 $root = $root|0;
 var $$pre = 0, $$pre$i = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $bodyRankArray = 0, $br = 0, $brIdx$030 = 0, $brIdx$1$lcssa = 0, $brIdx$110 = 0, $dominanceTracking = 0, $exitcond = 0, $firstProjectionTreeRoot$031 = 0, $firstProjectionTreeRoot$1$lcssa = 0, $firstProjectionTreeRoot$111 = 0, $firstProjectionTreeRoot$2$lcssa = 0, $firstProjectionTreeRoot$25 = 0, $firstProjectionTreeRoot$3 = 0, $i$026 = 0, $i4$04 = 0, $k$019 = 0, $node0$035 = 0, $nodeQueueCurrent$016 = 0;
 var $nodeQueueCurrent$12 = 0, $nodeQueueEnd$0$lcssa = 0, $nodeQueueEnd$09 = 0, $nodeQueueEnd$1 = 0, $nodeQueueEnd$217 = 0, $nodeQueueEnd$33 = 0, $or$cond$i$i$i = 0, $phitmp = 0, $ranksToProcess$027 = 0, $skipCount$028 = 0, $skipCount$1$lcssa = 0, $skipCount$120 = 0, $skipCount$2 = 0, $stopIdx$029 = 0, $stopIdx$1$lcssa = 0, $stopIdx$121 = 0, $stopIdx$2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 816|0;
 $vararg_buffer = sp;
 $bodyRankArray = sp + 24|0;
 $br = sp + 4|0;
 $dominanceTracking = sp + 16|0;
 $0 = sp + 810|0;
 $1 = sp + 808|0;
 $2 = sp + 809|0;
 $3 = (($bodyRankArray) + 768|0);
 $4 = (($bodyRankArray) + 772|0);
 $5 = (($bodyRankArray) + 776|0);
 HEAP32[$5>>2] = 0;
 $6 = (($bodyRankArray) + 780|0);
 HEAP8[$3>>0] = 1;
 HEAP32[$4>>2] = $bodyRankArray;
 HEAP32[$6>>2] = 64;
 $7 = ($root|0)==(0|0);
 do {
  if (!($7)) {
   $8 = (($br) + 8|0);
   $9 = (($br) + 4|0);
   $node0$035 = $root;
   while(1) {
    $10 = HEAP32[$node0$035>>2]|0;
    $11 = (($10) + 52|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 44|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = $14 & 1;
    $16 = ($15<<24>>24)==(0);
    $17 = (($node0$035) + 44|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18&255;
    do {
     if ($16) {
      $20 = $19 & 254;
      $21 = $20&255;
      HEAP8[$17>>0] = $21;
      HEAP32[$br>>2] = $node0$035;
      HEAP32[$8>>2] = 0;
      HEAP32[$9>>2] = 0;
      HEAP32[$dominanceTracking>>2] = 402653184;
      $22 = (($10) + 20|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = (($10) + 28|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($23) + ($25<<2)|0);
      $27 = ($25|0)>(0);
      if ($27) {
       $29 = $23;
       while(1) {
        $28 = HEAP32[$29>>2]|0;
        $30 = (($28) + 20|0);
        $31 = HEAP8[$30>>0]|0;
        $32 = ($31<<24>>24)==(1);
        if ($32) {
         $33 = (($28) + 32|0);
         $34 = HEAP32[$33>>2]|0;
         __ZN5physx2Sc24ConstraintProjectionTree14rankConstraintERNS0_13ConstraintSimERNS0_8BodyRankERj($34,$br,$dominanceTracking);
        }
        $35 = (($29) + 4|0);
        $36 = ($35>>>0)<($26>>>0);
        if ($36) {
         $29 = $35;
        } else {
         break;
        }
       }
       $$pre48 = HEAP32[$8>>2]|0;
       $phitmp = ($$pre48>>>0)>(2415919103);
       if ($phitmp) {
        $37 = HEAP8[$17>>0]|0;
        $38 = $37&255;
        $39 = $38 | 1;
        $40 = $39&255;
        HEAP8[$17>>0] = $40;
       }
      }
      $41 = HEAP32[$6>>2]|0;
      $42 = $41 & 2147483647;
      $43 = HEAP32[$5>>2]|0;
      $44 = ($42>>>0)>($43>>>0);
      if (!($44)) {
       (__ZN5physx6shdfnd5ArrayINS_2Sc8BodyRankENS0_15InlineAllocatorILj768ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($bodyRankArray,$br)|0);
       break;
      }
      $45 = HEAP32[$4>>2]|0;
      $46 = (($45) + (($43*12)|0)|0);
      $47 = ($46|0)==(0|0);
      if ($47) {
       $49 = $43;
      } else {
       ;HEAP32[$46+0>>2]=HEAP32[$br+0>>2]|0;HEAP32[$46+4>>2]=HEAP32[$br+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[$br+8>>2]|0;
       $$pre$i = HEAP32[$5>>2]|0;
       $49 = $$pre$i;
      }
      $48 = (($49) + 1)|0;
      HEAP32[$5>>2] = $48;
     } else {
      $50 = $19 | 1;
      $51 = $50&255;
      HEAP8[$17>>0] = $51;
     }
    } while(0);
    $52 = (($node0$035) + 16|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     break;
    } else {
     $node0$035 = $53;
    }
   }
   $$pre = HEAP32[$5>>2]|0;
   $55 = ($$pre|0)==(0);
   if (!($55)) {
    $56 = HEAP32[$4>>2]|0;
    __ZN5physx6shdfnd4sortINS_2Sc8BodyRankENS0_7GreaterIS3_EENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($56,$$pre,$0,$vararg_buffer);
    $57 = HEAP32[$5>>2]|0;
    $58 = $57 << 2;
    $59 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$58,459512,252)|0);
    $60 = ($59|0)==(0|0);
    if ($60) {
     $143 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
     __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($143,16,459512,395,459616,$vararg_buffer);
     break;
    }
    $61 = HEAP32[$5>>2]|0;
    $brIdx$030 = 0;$firstProjectionTreeRoot$031 = 0;$i$026 = 0;$ranksToProcess$027 = -1879048192;$skipCount$028 = 0;$stopIdx$029 = $61;
    while(1) {
     $62 = ($brIdx$030>>>0)<($stopIdx$029>>>0);
     L31: do {
      if ($62) {
       $brIdx$110 = $brIdx$030;$firstProjectionTreeRoot$111 = $firstProjectionTreeRoot$031;$nodeQueueEnd$09 = $59;
       while(1) {
        $66 = HEAP32[$4>>2]|0;
        $67 = ((($66) + (($brIdx$110*12)|0)|0) + 8|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = ($68>>>0)<($ranksToProcess$027>>>0);
        if ($69) {
         $brIdx$1$lcssa = $brIdx$110;$firstProjectionTreeRoot$1$lcssa = $firstProjectionTreeRoot$111;$nodeQueueEnd$0$lcssa = $nodeQueueEnd$09;
         break L31;
        }
        $70 = (($66) + (($brIdx$110*12)|0)|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = ((($66) + (($brIdx$110*12)|0)|0) + 4|0);
        $73 = HEAP32[$72>>2]|0;
        __ZN5physx2Sc19ConstraintGroupNode18initProjectionDataEPS1_PNS0_13ConstraintSimE($71,0,$73);
        $74 = HEAP32[$67>>2]|0;
        $75 = $74 & 1610612736;
        $76 = ($75|0)==(0);
        if ($76) {
         $78 = HEAP32[$72>>2]|0;
         $79 = (__ZN5physx2Sc24ConstraintProjectionTree23projectionTreeBuildStepERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimEPPS2_($71,$78,$nodeQueueEnd$09)|0);
         $80 = (($nodeQueueEnd$09) + ($79<<2)|0);
         $nodeQueueEnd$1 = $80;
        } else {
         HEAP32[$nodeQueueEnd$09>>2] = $71;
         $77 = (($nodeQueueEnd$09) + 4|0);
         $nodeQueueEnd$1 = $77;
        }
        $81 = (($71) + 24|0);
        HEAP32[$81>>2] = $firstProjectionTreeRoot$111;
        $82 = (($brIdx$110) + 1)|0;
        $83 = ($82>>>0)<($stopIdx$029>>>0);
        if ($83) {
         $brIdx$110 = $82;$firstProjectionTreeRoot$111 = $71;$nodeQueueEnd$09 = $nodeQueueEnd$1;
        } else {
         $brIdx$1$lcssa = $82;$firstProjectionTreeRoot$1$lcssa = $71;$nodeQueueEnd$0$lcssa = $nodeQueueEnd$1;
         break;
        }
       }
      } else {
       $brIdx$1$lcssa = $brIdx$030;$firstProjectionTreeRoot$1$lcssa = $firstProjectionTreeRoot$031;$nodeQueueEnd$0$lcssa = $59;
      }
     } while(0);
     $84 = ($59|0)==($nodeQueueEnd$0$lcssa|0);
     if (!($84)) {
      $nodeQueueCurrent$016 = $59;$nodeQueueEnd$217 = $nodeQueueEnd$0$lcssa;
      while(1) {
       $85 = HEAP32[$nodeQueueCurrent$016>>2]|0;
       $86 = (($nodeQueueCurrent$016) + 4|0);
       $87 = (($85) + 40|0);
       $88 = HEAP32[$87>>2]|0;
       $89 = (__ZN5physx2Sc24ConstraintProjectionTree23projectionTreeBuildStepERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimEPPS2_($85,$88,$nodeQueueEnd$217)|0);
       $90 = (($nodeQueueEnd$217) + ($89<<2)|0);
       $91 = ($86|0)==($90|0);
       if ($91) {
        break;
       } else {
        $nodeQueueCurrent$016 = $86;$nodeQueueEnd$217 = $90;
       }
      }
     }
     $64 = (($brIdx$1$lcssa) + ($skipCount$028))|0;
     $92 = HEAP32[$5>>2]|0;
     $93 = ($64>>>0)<($92>>>0);
     L44: do {
      if ($93) {
       $156 = $92;$k$019 = $64;$skipCount$120 = 0;$stopIdx$121 = $64;
       while(1) {
        $94 = HEAP32[$4>>2]|0;
        $95 = ((($94) + (($k$019*12)|0)|0) + 8|0);
        $96 = HEAP32[$95>>2]|0;
        $97 = ($96>>>0)>(2281701375);
        if (!($97)) {
         $65 = $156;$skipCount$1$lcssa = $skipCount$120;$stopIdx$1$lcssa = $stopIdx$121;
         break L44;
        }
        $98 = (($94) + (($k$019*12)|0)|0);
        $99 = HEAP32[$98>>2]|0;
        $100 = (($99) + 44|0);
        $101 = HEAP8[$100>>0]|0;
        $102 = $101&255;
        $103 = $102 & 1;
        $104 = ($103|0)==(0);
        if ($104) {
         $105 = $102 | 1;
         $106 = $105&255;
         HEAP8[$100>>0] = $106;
         $107 = HEAP32[$4>>2]|0;
         $108 = (($107) + (($stopIdx$121*12)|0)|0);
         $109 = (($107) + (($k$019*12)|0)|0);
         ;HEAP32[$108+0>>2]=HEAP32[$109+0>>2]|0;HEAP32[$108+4>>2]=HEAP32[$109+4>>2]|0;HEAP32[$108+8>>2]=HEAP32[$109+8>>2]|0;
         $110 = (($stopIdx$121) + 1)|0;
         $$pre47 = HEAP32[$5>>2]|0;
         $114 = $$pre47;$skipCount$2 = $skipCount$120;$stopIdx$2 = $110;
        } else {
         $111 = (($skipCount$120) + 1)|0;
         $114 = $156;$skipCount$2 = $111;$stopIdx$2 = $stopIdx$121;
        }
        $112 = (($k$019) + 1)|0;
        $113 = ($112>>>0)<($114>>>0);
        if ($113) {
         $156 = $114;$k$019 = $112;$skipCount$120 = $skipCount$2;$stopIdx$121 = $stopIdx$2;
        } else {
         $65 = $114;$skipCount$1$lcssa = $skipCount$2;$stopIdx$1$lcssa = $stopIdx$2;
         break;
        }
       }
      } else {
       $65 = $92;$skipCount$1$lcssa = 0;$stopIdx$1$lcssa = $64;
      }
     } while(0);
     $115 = (($i$026) + 1)|0;
     $exitcond = ($115|0)==(2);
     if ($exitcond) {
      break;
     } else {
      $brIdx$030 = $64;$firstProjectionTreeRoot$031 = $firstProjectionTreeRoot$1$lcssa;$i$026 = $115;$ranksToProcess$027 = -2013265920;$skipCount$028 = $skipCount$1$lcssa;$stopIdx$029 = $stopIdx$1$lcssa;
     }
    }
    $63 = ($64>>>0)<($65>>>0);
    if ($63) {
     $155 = $65;$firstProjectionTreeRoot$25 = $firstProjectionTreeRoot$1$lcssa;$i4$04 = $64;
     while(1) {
      $116 = HEAP32[$4>>2]|0;
      $117 = (($116) + (($i4$04*12)|0)|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = (($118) + 44|0);
      $120 = HEAP8[$119>>0]|0;
      $121 = $120&255;
      $122 = $121 & 1;
      $123 = ($122|0)==(0);
      if ($123) {
       $124 = $121 | 1;
       $125 = $124&255;
       HEAP8[$119>>0] = $125;
       $126 = ((($116) + (($i4$04*12)|0)|0) + 4|0);
       $127 = HEAP32[$126>>2]|0;
       $128 = (__ZN5physx2Sc24ConstraintProjectionTree23projectionTreeBuildStepERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimEPPS2_($118,$127,$59)|0);
       $129 = (($59) + ($128<<2)|0);
       $130 = ($59|0)==($129|0);
       if (!($130)) {
        $nodeQueueCurrent$12 = $59;$nodeQueueEnd$33 = $129;
        while(1) {
         $131 = HEAP32[$nodeQueueCurrent$12>>2]|0;
         $132 = (($nodeQueueCurrent$12) + 4|0);
         $133 = (($131) + 40|0);
         $134 = HEAP32[$133>>2]|0;
         $135 = (__ZN5physx2Sc24ConstraintProjectionTree23projectionTreeBuildStepERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimEPPS2_($131,$134,$nodeQueueEnd$33)|0);
         $136 = (($nodeQueueEnd$33) + ($135<<2)|0);
         $137 = ($132|0)==($136|0);
         if ($137) {
          break;
         } else {
          $nodeQueueCurrent$12 = $132;$nodeQueueEnd$33 = $136;
         }
        }
       }
       $138 = (($118) + 24|0);
       HEAP32[$138>>2] = $firstProjectionTreeRoot$25;
       $$pre46 = HEAP32[$5>>2]|0;
       $141 = $$pre46;$firstProjectionTreeRoot$3 = $118;
      } else {
       $141 = $155;$firstProjectionTreeRoot$3 = $firstProjectionTreeRoot$25;
      }
      $139 = (($i4$04) + 1)|0;
      $140 = ($139>>>0)<($141>>>0);
      if ($140) {
       $155 = $141;$firstProjectionTreeRoot$25 = $firstProjectionTreeRoot$3;$i4$04 = $139;
      } else {
       $firstProjectionTreeRoot$2$lcssa = $firstProjectionTreeRoot$3;
       break;
      }
     }
    } else {
     $firstProjectionTreeRoot$2$lcssa = $firstProjectionTreeRoot$1$lcssa;
    }
    $142 = (($root) + 20|0);
    HEAP32[$142>>2] = $firstProjectionTreeRoot$2$lcssa;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$59);
   }
  }
 } while(0);
 $144 = HEAP32[$6>>2]|0;
 $145 = $144 & 2147483647;
 $146 = ($145|0)!=(0);
 $147 = ($144|0)>(-1);
 $or$cond$i$i$i = $146 & $147;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $148 = HEAP32[$4>>2]|0;
 $149 = ($bodyRankArray|0)==($148|0);
 if ($149) {
  HEAP8[$3>>0] = 0;
  STACKTOP = sp;return;
 }
 $150 = ($148|0)==(0|0);
 if ($150) {
  STACKTOP = sp;return;
 }
 $151 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = (($152) + 12|0);
 $154 = HEAP32[$153>>2]|0;
 FUNCTION_TABLE_vii[$154 & 4095]($151,$148);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc24ConstraintProjectionTree23projectionTreeBuildStepERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimEPPS2_($node,$cToParent,$nodeQueue) {
 $node = $node|0;
 $cToParent = $cToParent|0;
 $nodeQueue = $nodeQueue|0;
 var $$02 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $nodeQueueFillCount$0$lcssa = 0;
 var $nodeQueueFillCount$01 = 0, $nodeQueueFillCount$1 = 0, $or$cond = 0, $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$node>>2]|0;
 $1 = (($0) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + ($4<<2)|0);
 $6 = ($4|0)>(0);
 if ($6) {
  $$02 = $nodeQueue;$8 = $2;$nodeQueueFillCount$01 = 0;
 } else {
  $nodeQueueFillCount$0$lcssa = 0;
  STACKTOP = sp;return ($nodeQueueFillCount$0$lcssa|0);
 }
 while(1) {
  $7 = HEAP32[$8>>2]|0;
  $9 = (($7) + 20|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(1);
  if ($11) {
   $12 = (($7) + 32|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==($cToParent|0);
   if ($14) {
    $$1 = $$02;$nodeQueueFillCount$1 = $nodeQueueFillCount$01;
   } else {
    $15 = (__ZNK5physx2Sc13ConstraintSim8isBrokenEv($13)|0);
    $16 = (($13) + 100|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP16[$17>>1]|0;
    $19 = $18&65535;
    $20 = (($13) + 108|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($0|0);
    if ($22) {
     $23 = $19 & 2;
     $24 = $15 ? 0 : $23;
     $25 = $19 & 4;
     $26 = $15 ? 0 : $25;
     $27 = (($13) + 112|0);
     $40 = $26;$42 = $24;$storemerge$in$i = $27;
    } else {
     $28 = $19 & 4;
     $29 = $15 ? 0 : $28;
     $30 = $19 & 2;
     $31 = $15 ? 0 : $30;
     $40 = $31;$42 = $29;$storemerge$in$i = $20;
    }
    $storemerge$i = HEAP32[$storemerge$in$i>>2]|0;
    $32 = ($storemerge$i|0)==(0|0);
    if ($32) {
     $$1 = $$02;$nodeQueueFillCount$1 = $nodeQueueFillCount$01;
    } else {
     $33 = (($storemerge$i) + 52|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 44|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = $36 & 1;
     $38 = ($37<<24>>24)==(0);
     if ($38) {
      $39 = ($40|0)!=(0);
      $41 = ($42|0)==(0);
      $or$cond = $39 & $41;
      if ($or$cond) {
       $$1 = $$02;$nodeQueueFillCount$1 = $nodeQueueFillCount$01;
      } else {
       $43 = (($storemerge$i) + 60|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = (($44) + 44|0);
       $46 = HEAP8[$45>>0]|0;
       $47 = $46 & 1;
       $48 = ($47<<24>>24)==(0);
       if ($48) {
        HEAP32[$$02>>2] = $44;
        __ZN5physx2Sc19ConstraintGroupNode18initProjectionDataEPS1_PNS0_13ConstraintSimE($44,$node,$13);
        $49 = HEAP8[$45>>0]|0;
        $50 = $49&255;
        $51 = $50 | 1;
        $52 = $51&255;
        HEAP8[$45>>0] = $52;
        $53 = (($nodeQueueFillCount$01) + 1)|0;
        $54 = (($$02) + 4|0);
        $$1 = $54;$nodeQueueFillCount$1 = $53;
       } else {
        $$1 = $$02;$nodeQueueFillCount$1 = $nodeQueueFillCount$01;
       }
      }
     } else {
      $$1 = $$02;$nodeQueueFillCount$1 = $nodeQueueFillCount$01;
     }
    }
   }
  } else {
   $$1 = $$02;$nodeQueueFillCount$1 = $nodeQueueFillCount$01;
  }
  $55 = (($8) + 4|0);
  $56 = ($55>>>0)<($5>>>0);
  if ($56) {
   $$02 = $$1;$8 = $55;$nodeQueueFillCount$01 = $nodeQueueFillCount$1;
  } else {
   $nodeQueueFillCount$0$lcssa = $nodeQueueFillCount$1;
   break;
  }
 }
 STACKTOP = sp;return ($nodeQueueFillCount$0$lcssa|0);
}
function __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($root) {
 $root = $root|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currentNode$0 = 0, $projRoot$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($root) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $projRoot$0 = $1;
 while(1) {
  $2 = (($projRoot$0) + 24|0);
  $3 = HEAP32[$2>>2]|0;
  $currentNode$0 = $projRoot$0;
  while(1) {
   $4 = (($currentNode$0) + 32|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $currentNode$0 = $5;
    continue;
   }
   $7 = (($currentNode$0) + 28|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($currentNode$0) + 36|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==(0|0);
   if (!($11)) {
    $12 = (($8) + 32|0);
    HEAP32[$12>>2] = 0;
   }
   __ZN5physx2Sc19ConstraintGroupNode19clearProjectionDataEv($currentNode$0);
   $13 = ($10|0)==(0|0);
   $$ = $13 ? $8 : $10;
   $14 = ($$|0)==(0|0);
   if ($14) {
    break;
   } else {
    $currentNode$0 = $$;
   }
  }
  $15 = ($3|0)==(0|0);
  if ($15) {
   break;
  } else {
   $projRoot$0 = $3;
  }
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc24ConstraintProjectionTree11projectPoseERNS0_19ConstraintGroupNodeE($root) {
 $root = $root|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $currentNode$0$pn$be$i = 0, $currentNode$0$pn$i = 0, $dummyNode$i = 0, $nextChildNode$0$i = 0, $nextSiblingNode$0$i = 0, $nextSiblingNode$0$in$phi$trans$insert$i = 0, $nextSiblingNode$0$pre$i = 0, $projRoot$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $dummyNode$i = sp;
 $0 = (($root) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($dummyNode$i) + 36|0);
 $projRoot$0 = $1;
 while(1) {
  $3 = HEAP32[$projRoot$0>>2]|0;
  __ZN5physx2Sc19ConstraintGroupNodeC2ERNS0_7BodySimE($dummyNode$i,$3);
  HEAP32[$2>>2] = $projRoot$0;
  $currentNode$0$pn$i = $dummyNode$i;$nextSiblingNode$0$i = $projRoot$0;
  while(1) {
   $4 = ($nextSiblingNode$0$i|0)==(0|0);
   if ($4) {
    $14 = (($currentNode$0$pn$i) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     break;
    } else {
     $currentNode$0$pn$be$i = $15;
    }
   } else {
    $nextChildNode$0$i = $nextSiblingNode$0$i;
    while(1) {
     $5 = (($nextChildNode$0$i) + 40|0);
     $6 = HEAP32[$5>>2]|0;
     $7 = ($6|0)==(0|0);
     if (!($7)) {
      $8 = (__ZN5physx2Sc13ConstraintSim14hasDynamicBodyEv($6)|0);
      if ($8) {
       $9 = (__ZN5physx2Sc13ConstraintSim15needsProjectionEv($6)|0);
       if ($9) {
        $10 = HEAP32[$nextChildNode$0$i>>2]|0;
        __ZN5physx2Sc13ConstraintSim11projectPoseEPNS0_7BodySimE($6,$10);
       }
      }
     }
     $11 = (($nextChildNode$0$i) + 32|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      $currentNode$0$pn$be$i = $nextChildNode$0$i;
      break;
     } else {
      $nextChildNode$0$i = $12;
     }
    }
   }
   $nextSiblingNode$0$in$phi$trans$insert$i = (($currentNode$0$pn$be$i) + 36|0);
   $nextSiblingNode$0$pre$i = HEAP32[$nextSiblingNode$0$in$phi$trans$insert$i>>2]|0;
   $currentNode$0$pn$i = $currentNode$0$pn$be$i;$nextSiblingNode$0$i = $nextSiblingNode$0$pre$i;
  }
  $17 = (($projRoot$0) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   break;
  } else {
   $projRoot$0 = $18;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortINS_2Sc8BodyRankENS0_7GreaterIS3_EENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i3 = 0, $$ph = 0, $$ph$be = 0, $$ph10 = 0, $$ph10$be = 0, $$ph11 = 0, $$ph11$be = 0, $$ph12 = 0, $$ph12$be = 0, $$ph8 = 0, $$ph8$be = 0, $$ph9 = 0, $$ph9$be = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$02$i = 0, $m$01$i = 0, $or$cond = 0, $or$cond6 = 0, $or$cond7 = 0, $stackMem = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $tmp$i$i = sp + 136|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph10 = 0;$$ph11 = 0;$$ph12 = $6;$$ph8 = $5;$$ph9 = 32;
  L3: while(1) {
   $10 = $$ph11;$30 = $$ph10;$9 = $$ph12;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = ((($elements) + (($j$02$i*12)|0)|0) + 8|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = ((($elements) + (($m$01$i*12)|0)|0) + 8|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = ($15>>>0)>($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + (($j$0$m$0$i*12)|0)|0);
      $22 = (($elements) + (($i$03$i*12)|0)|0);
      ;HEAP32[$tmp$i$i+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$tmp$i$i+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$tmp$i$i+8>>2]=HEAP32[$21+8>>2]|0;
      ;HEAP32[$21+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$22+8>>2]|0;
      ;HEAP32[$22+0>>2]=HEAP32[$tmp$i$i+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$tmp$i$i+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$tmp$i$i+8>>2]|0;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $86 = ($30|0)==(0);
    if ($86) {
     break L3;
    }
    $87 = (($30) + -1)|0;
    $88 = (($$ph8) + ($87<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($30) + -2)|0;
    $91 = (($$ph8) + ($90<<2)|0);
    $92 = HEAP32[$91>>2]|0;
    $10 = $92;$30 = $90;$9 = $89;
   }
   $23 = (__ZN5physx6shdfnd8internal9partitionINS_2Sc8BodyRankEKNS0_7GreaterIS4_EEEEiPT_iiRT0_($elements,$10,$9,$compare)|0);
   $24 = (($23) - ($10))|0;
   $25 = (($9) - ($23))|0;
   $26 = ($24|0)<($25|0);
   if ($26) {
    $27 = (($23) + -1)|0;
    $28 = (($$ph9) + -1)|0;
    $29 = ($30>>>0)<($28>>>0);
    if ($29) {
     $102 = $$ph;$103 = $$ph9;$54 = $$ph8;
    } else {
     $31 = $$ph9 << 1;
     $32 = $$ph9 << 3;
     $33 = ($32|0)==(0);
     if ($33) {
      $45 = 0;
     } else {
      $34 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = (($35) + 8|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (__Z15PxGetFoundationv()|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = (($39) + 24|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (FUNCTION_TABLE_ii[$41 & 4095]($38)|0);
      $$$i$i$i3 = $42 ? 459784 : 459752;
      $43 = (FUNCTION_TABLE_iiiiii[$37 & 255]($34,$32,$$$i$i$i3,459664,148)|0);
      $45 = $43;
     }
     $44 = $30 << 2;
     _memcpy(($45|0),($$ph8|0),($44|0))|0;
     $46 = ($$ph<<24>>24)==(0);
     $47 = ($$ph8|0)==(0|0);
     $or$cond = $46 | $47;
     if ($or$cond) {
      $102 = 1;$103 = $31;$54 = $45;
     } else {
      $48 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = (($49) + 12|0);
      $51 = HEAP32[$50>>2]|0;
      FUNCTION_TABLE_vii[$51 & 4095]($48,$$ph8);
      $102 = 1;$103 = $31;$54 = $45;
     }
    }
    $52 = (($30) + 1)|0;
    $53 = (($54) + ($30<<2)|0);
    HEAP32[$53>>2] = $10;
    $55 = (($54) + ($52<<2)|0);
    HEAP32[$55>>2] = $27;
    $56 = (($23) + 1)|0;
    $$ph$be = $102;$$ph11$be = $56;$$ph12$be = $9;$$ph8$be = $54;$$ph9$be = $103;
   } else {
    $57 = (($23) + 1)|0;
    $58 = (($$ph9) + -1)|0;
    $59 = ($30>>>0)<($58>>>0);
    if ($59) {
     $104 = $$ph;$105 = $$ph9;$83 = $$ph8;
    } else {
     $60 = $$ph9 << 1;
     $61 = $$ph9 << 3;
     $62 = ($61|0)==(0);
     if ($62) {
      $74 = 0;
     } else {
      $63 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = (__Z15PxGetFoundationv()|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (($68) + 24|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
      $$$i$i$i = $71 ? 459784 : 459752;
      $72 = (FUNCTION_TABLE_iiiiii[$66 & 255]($63,$61,$$$i$i$i,459664,148)|0);
      $74 = $72;
     }
     $73 = $30 << 2;
     _memcpy(($74|0),($$ph8|0),($73|0))|0;
     $75 = ($$ph<<24>>24)==(0);
     $76 = ($$ph8|0)==(0|0);
     $or$cond6 = $75 | $76;
     if ($or$cond6) {
      $104 = 1;$105 = $60;$83 = $74;
     } else {
      $77 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($78) + 12|0);
      $80 = HEAP32[$79>>2]|0;
      FUNCTION_TABLE_vii[$80 & 4095]($77,$$ph8);
      $104 = 1;$105 = $60;$83 = $74;
     }
    }
    $81 = (($30) + 1)|0;
    $82 = (($83) + ($30<<2)|0);
    HEAP32[$82>>2] = $57;
    $84 = (($83) + ($81<<2)|0);
    HEAP32[$84>>2] = $9;
    $85 = (($23) + -1)|0;
    $$ph$be = $104;$$ph11$be = $10;$$ph12$be = $85;$$ph8$be = $83;$$ph9$be = $105;
   }
   $$ph10$be = (($30) + 2)|0;
   $$ph = $$ph$be;$$ph10 = $$ph10$be;$$ph11 = $$ph11$be;$$ph12 = $$ph12$be;$$ph8 = $$ph8$be;$$ph9 = $$ph9$be;
  }
  $93 = ($$ph<<24>>24)==(0);
  $94 = ($$ph8|0)==(0|0);
  $or$cond7 = $93 | $94;
  if (!($or$cond7)) {
   $95 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = (($96) + 12|0);
   $98 = HEAP32[$97>>2]|0;
   FUNCTION_TABLE_vii[$98 & 4095]($95,$$ph8);
  }
 }
 $99 = HEAP8[$4>>0]|0;
 $100 = ($99<<24>>24)==(0);
 if ($100) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal9partitionINS_2Sc8BodyRankEKNS0_7GreaterIS4_EEEEiPT_iiRT0_($elements,$first,$last,$compare) {
 $elements = $elements|0;
 $first = $first|0;
 $last = $last|0;
 $compare = $compare|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$0$ph = 0, $j$0$ph = 0, $j$1 = 0, $tmp$i1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmp$i1 = sp;
 $0 = (($last) + ($first))|0;
 $1 = (($0|0) / 2)&-1;
 $2 = (($elements) + (($1*12)|0)|0);
 $3 = (($elements) + (($first*12)|0)|0);
 $4 = ((($elements) + (($1*12)|0)|0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($elements) + (($first*12)|0)|0) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  ;HEAP32[$tmp$i1+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$3+8>>2]|0;
  ;HEAP32[$3+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$2+8>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$tmp$i1+8>>2]|0;
  $$pre$i = HEAP32[$6>>2]|0;
  $13 = $$pre$i;
 } else {
  $13 = $7;
 }
 $9 = (($elements) + (($last*12)|0)|0);
 $10 = ((($elements) + (($last*12)|0)|0) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)>($13>>>0);
 if ($12) {
  ;HEAP32[$tmp$i1+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$3+8>>2]|0;
  ;HEAP32[$3+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$9+8>>2]|0;
  ;HEAP32[$9+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$tmp$i1+8>>2]|0;
  $$pre4$i = HEAP32[$10>>2]|0;
  $16 = $$pre4$i;
 } else {
  $16 = $11;
 }
 $14 = HEAP32[$4>>2]|0;
 $15 = ($16>>>0)>($14>>>0);
 if ($15) {
  ;HEAP32[$tmp$i1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$2+8>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$9+8>>2]|0;
  ;HEAP32[$9+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$tmp$i1+8>>2]|0;
  $$pre$phi$iZ2D = $2;
 } else {
  $$pre$phi$iZ2D = $2;
 }
 $17 = (($last) + -1)|0;
 $18 = (($elements) + (($17*12)|0)|0);
 ;HEAP32[$tmp$i1+0>>2]=HEAP32[$$pre$phi$iZ2D+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$$pre$phi$iZ2D+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$$pre$phi$iZ2D+8>>2]|0;
 ;HEAP32[$$pre$phi$iZ2D+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$$pre$phi$iZ2D+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$$pre$phi$iZ2D+8>>2]=HEAP32[$18+8>>2]|0;
 ;HEAP32[$18+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$tmp$i1+8>>2]|0;
 $19 = ((($elements) + (($17*12)|0)|0) + 8|0);
 $i$0$ph = $first;$j$0$ph = $17;
 while(1) {
  $20 = HEAP32[$19>>2]|0;
  $i$0 = $i$0$ph;
  while(1) {
   $21 = (($i$0) + 1)|0;
   $22 = (($elements) + (($21*12)|0)|0);
   $23 = ((($elements) + (($21*12)|0)|0) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24>>>0)>($20>>>0);
   if ($25) {
    $i$0 = $21;
   } else {
    $j$1 = $j$0$ph;
    break;
   }
  }
  while(1) {
   $26 = (($j$1) + -1)|0;
   $27 = (($elements) + (($26*12)|0)|0);
   $28 = ((($elements) + (($26*12)|0)|0) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($20>>>0)>($29>>>0);
   if ($30) {
    $j$1 = $26;
   } else {
    break;
   }
  }
  $31 = ($21|0)<($26|0);
  if (!($31)) {
   break;
  }
  ;HEAP32[$tmp$i1+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$22+8>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$27+8>>2]|0;
  ;HEAP32[$27+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$tmp$i1+8>>2]|0;
  $i$0$ph = $21;$j$0$ph = $26;
 }
 ;HEAP32[$tmp$i1+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$22+8>>2]|0;
 ;HEAP32[$22+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$18+8>>2]|0;
 ;HEAP32[$18+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$tmp$i1+8>>2]|0;
 STACKTOP = sp;return ($21|0);
}
function __ZN5physx6shdfnd5ArrayINS_2Sc8BodyRankENS0_15InlineAllocatorILj768ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 780|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = ($$$i*12)|0;
  $7 = (($this) + 768|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(769);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 459784 : 459752;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,459896,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 776|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + (($23*12)|0)|0);
 $26 = (($this) + 772|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;
   }
   $30 = (($$012$i) + 12|0);
   $31 = (($$03$i) + 12|0);
   $32 = ($30>>>0)<($24>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$22>>2]|0;
  $34 = $$pre;
 } else {
  $34 = $23;
 }
 $33 = (($25) + (($34*12)|0)|0);
 $35 = ($33|0)==(0|0);
 if (!($35)) {
  ;HEAP32[$33+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$a+8>>2]|0;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 768|0);
    HEAP8[$40>>0] = 0;
    break;
   }
   $41 = ($38|0)==(0|0);
   if (!($41)) {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
   }
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = HEAP32[$22>>2]|0;
 $47 = (($46) + 1)|0;
 HEAP32[$22>>2] = $47;
 $48 = (($25) + (($46*12)|0)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx2Sc13ConstraintSimC2ERNS0_14ConstraintCoreEPNS0_9RigidCoreES5_RNS0_5SceneE($this,$core,$r0,$r1,$scene) {
 $this = $this|0;
 $core = $core|0;
 $r0 = $r0|0;
 $r1 = $r1|0;
 $scene = $scene|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $angBreakForce = 0, $linBreakForce = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $linBreakForce = sp + 4|0;
 $angBreakForce = sp;
 $0 = (($this) + 96|0);
 HEAP32[$0>>2] = $scene;
 $1 = (($this) + 100|0);
 HEAP32[$1>>2] = $core;
 $2 = (($this) + 116|0);
 HEAP8[$2>>0] = 0;
 $3 = (($this) + 12|0);
 $4 = ($r0|0)!=(0|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;
 if ($4) {
  $5 = (($r0) + 10|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   $10 = 0;
  } else {
   $8 = (__ZNK5physx2Sc9RigidCore6getSimEv($r0)|0);
   $10 = $8;
  }
 } else {
  $10 = 0;
 }
 $9 = (($this) + 108|0);
 HEAP32[$9>>2] = $10;
 $11 = ($r1|0)!=(0|0);
 if ($11) {
  $12 = (($r1) + 10|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $17 = 0;
  } else {
   $15 = (__ZNK5physx2Sc9RigidCore6getSimEv($r1)|0);
   $17 = $15;
  }
 } else {
  $17 = 0;
 }
 $16 = (($this) + 112|0);
 HEAP32[$16>>2] = $17;
 $18 = (__ZN5physx2Sc13ConstraintSim18createLLConstraintEv($this)|0);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $19 = (($scene) + 2376|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 1)|0;
 HEAP32[$19>>2] = $21;
 $22 = (($this) + 88|0);
 HEAP32[$22>>2] = $20;
 __ZNK5physx2Sc14ConstraintCore13getBreakForceERfS2_($core,$linBreakForce,$angBreakForce);
 $23 = Math_fround(HEAPF32[$linBreakForce>>2]);
 $24 = $23 < Math_fround(3.40282346638528859812E+38);
 if ($24) {
  label = 10;
 } else {
  $25 = Math_fround(HEAPF32[$angBreakForce>>2]);
  $26 = $25 < Math_fround(3.40282346638528859812E+38);
  if ($26) {
   label = 10;
  }
 }
 if ((label|0) == 10) {
  $27 = HEAP8[$2>>0]|0;
  $28 = $27 | 2;
  HEAP8[$2>>0] = $28;
 }
 $29 = (($core) + 64|0);
 HEAP32[$29>>2] = $this;
 $30 = HEAP32[$1>>2]|0;
 $31 = HEAP16[$30>>1]|0;
 $32 = $31 & 6;
 $33 = ($32<<16>>16)==(0);
 if (!($33)) {
  $34 = HEAP32[$3>>2]|0;
  $35 = ($34|0)==(0);
  if ($35) {
   $36 = (($scene) + 80|0);
   $37 = HEAP32[$36>>2]|0;
   __ZN5physx2Sc27ConstraintProjectionManager24addToPendingGroupUpdatesERNS0_13ConstraintSimE($37,$this);
  }
 }
 $38 = HEAP32[$0>>2]|0;
 $39 = (($38) + 1236|0);
 $40 = HEAP32[$39>>2]|0;
 if ($4) {
  $41 = (__ZNK5physx2Sc9RigidCore6getSimEv($r0)|0);
  $59 = $41;
 } else {
  $42 = (($scene) + 1216|0);
  $43 = HEAP32[$42>>2]|0;
  $59 = $43;
 }
 if ($11) {
  $44 = (__ZNK5physx2Sc9RigidCore6getSimEv($r1)|0);
  $60 = $44;
 } else {
  $45 = (($scene) + 1216|0);
  $46 = HEAP32[$45>>2]|0;
  $60 = $46;
 }
 $47 = (($40) + 292|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($40);
  $$pre$i$i = HEAP32[$47>>2]|0;
  $51 = $$pre$i$i;
 } else {
  $51 = $48;
 }
 $50 = HEAP32[$51>>2]|0;
 HEAP32[$47>>2] = $50;
 $52 = (($40) + 280|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$52>>2] = $54;
 $55 = (($40) + 284|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + -1)|0;
 HEAP32[$55>>2] = $57;
 $58 = ($51|0)==(0|0);
 if ($58) {
  $62 = 0;
 } else {
  __ZN5physx2Sc21ConstraintInteractionC2EPNS0_13ConstraintSimERNS0_8RigidSimES5_($51,$this,$59,$60);
  $62 = $51;
 }
 $61 = (($this) + 104|0);
 HEAP32[$61>>2] = $62;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 FUNCTION_TABLE_vi[$64 & 4095]($62);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ConstraintSim18createLLConstraintEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 96|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN5physx2Sc5Scene23allocateConstraintBlockEj($5,$3)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($8,32,459976,113,460072,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 _memset(($6|0),0,($3|0))|0;
 $9 = (($this) + 32|0);
 $10 = (($this) + 36|0);
 __ZNK5physx2Sc14ConstraintCore13getBreakForceERfS2_($1,$9,$10);
 $11 = HEAP16[$1>>1]|0;
 $12 = $11&65535;
 $13 = (($this) + 84|0);
 HEAP32[$13>>2] = $12;
 $14 = (($1) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 40|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 44|0);
 HEAP32[$17>>2] = $3;
 $18 = (($1) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 48|0);
 HEAP32[$20>>2] = $19;
 $21 = (($1) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 52|0);
 HEAP32[$23>>2] = $22;
 $24 = (($1) + 40|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 56|0);
 HEAP32[$26>>2] = $25;
 $27 = (($this) + 60|0);
 HEAP32[$27>>2] = $6;
 $28 = (($this) + 64|0);
 HEAP32[$28>>2] = $this;
 $29 = (($this) + 108|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 $32 = (($30) + 64|0);
 $$ = $31 ? 0 : $32;
 $33 = (($this) + 68|0);
 HEAP32[$33>>2] = $$;
 $34 = (($this) + 112|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 $37 = (($35) + 64|0);
 $38 = $36 ? 0 : $37;
 $39 = (($this) + 72|0);
 HEAP32[$39>>2] = $38;
 if ($31) {
  $43 = 0;
 } else {
  $40 = (($$) + 64|0);
  $41 = HEAP32[$40>>2]|0;
  $43 = $41;
 }
 $42 = (($this) + 76|0);
 HEAP32[$42>>2] = $43;
 if ($36) {
  $47 = 0;
 } else {
  $44 = (($38) + 64|0);
  $45 = HEAP32[$44>>2]|0;
  $47 = $45;
 }
 $46 = (($this) + 80|0);
 HEAP32[$46>>2] = $47;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc13ConstraintSim15needsProjectionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & 6;
 $4 = ($3<<16>>16)==(0);
 if ($4) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx2Sc13ConstraintSimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 96|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  __ZN5physx2Sc27ConstraintProjectionManager29removeFromPendingGroupUpdatesERNS0_13ConstraintSimE($7,$this);
 }
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 $11 = (($this) + 104|0);
 if ($10) {
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$15 & 4095]($12);
 }
 $16 = (($this) + 96|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1236|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$11>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = HEAP32[$20>>2]|0;
  $23 = (($22) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vi[$24 & 4095]($20);
  $25 = (($19) + 280|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + -1)|0;
  HEAP32[$25>>2] = $27;
  $28 = (($19) + 292|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$20>>2] = $29;
  HEAP32[$28>>2] = $20;
  $30 = (($19) + 284|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 1)|0;
  HEAP32[$30>>2] = $32;
  $33 = (($19) + 276|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34*50)|0;
  $36 = ($31|0)<($35|0);
  if (!($36)) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($19);
   HEAP32[$30>>2] = 0;
  }
 }
 $37 = (($this) + 60|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $43 = (($this) + 100|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 64|0);
  HEAP32[$45>>2] = 0;
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$16>>2]|0;
 $41 = (($this) + 44|0);
 $42 = HEAP32[$41>>2]|0;
 __ZN5physx2Sc5Scene25deallocateConstraintBlockEPvj($40,$38,$42);
 $43 = (($this) + 100|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 64|0);
 HEAP32[$45>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc13ConstraintSim8isBrokenEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx2Sc13ConstraintSim16postBodiesChangeEPNS0_9RigidCoreES3_($this,$r0,$r1) {
 $this = $this|0;
 $r0 = $r0|0;
 $r1 = $r1|0;
 var $$ = 0, $$$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 3;
 } else {
  $3 = (($1) + 60|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   label = 3;
  } else {
   $17 = $4;
   label = 6;
  }
 }
 if ((label|0) == 3) {
  $6 = (($this) + 112|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (($7) + 60|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   $$$i = $11 ? 0 : $7;
   $12 = ($$$i|0)==(0|0);
   if (!($12)) {
    $$phi$trans$insert = (($$$i) + 60|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $17 = $$pre;
    label = 6;
   }
  }
 }
 if ((label|0) == 6) {
  $13 = (($this) + 96|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 80|0);
  $16 = HEAP32[$15>>2]|0;
  __ZN5physx2Sc27ConstraintProjectionManager15invalidateGroupERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimE($16,$17,$this);
  $18 = (($this) + 100|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP16[$19>>1]|0;
  $21 = $20 & 6;
  $22 = ($21<<16>>16)==(0);
  if (!($22)) {
   $23 = (($this) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0);
   if ($25) {
    $26 = (($this) + 116|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = $27 & 1;
    $29 = ($28<<24>>24)==(0);
    if ($29) {
     $30 = HEAP32[$13>>2]|0;
     $31 = (($30) + 80|0);
     $32 = HEAP32[$31>>2]|0;
     __ZN5physx2Sc27ConstraintProjectionManager24addToPendingGroupUpdatesERNS0_13ConstraintSimE($32,$this);
    }
   }
  }
 }
 $33 = ($r0|0)!=(0|0);
 if ($33) {
  $34 = (($r0) + 10|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ($35<<24>>24)==(0);
  if ($36) {
   $44 = 0;
  } else {
   $37 = (__ZNK5physx2Sc9RigidCore6getSimEv($r0)|0);
   $44 = $37;
  }
 } else {
  $44 = 0;
 }
 $38 = ($r1|0)!=(0|0);
 if ($38) {
  $39 = (($r1) + 10|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $48 = 0;
  } else {
   $42 = (__ZNK5physx2Sc9RigidCore6getSimEv($r1)|0);
   $48 = $42;
  }
 } else {
  $48 = 0;
 }
 $43 = ($44|0)==(0|0);
 $45 = (($44) + 64|0);
 $$ = $43 ? 0 : $45;
 $46 = (($this) + 68|0);
 HEAP32[$46>>2] = $$;
 $47 = ($48|0)==(0|0);
 $49 = (($48) + 64|0);
 $50 = $47 ? 0 : $49;
 $51 = (($this) + 72|0);
 HEAP32[$51>>2] = $50;
 if ($43) {
  $55 = 0;
 } else {
  $52 = (($$) + 64|0);
  $53 = HEAP32[$52>>2]|0;
  $55 = $53;
 }
 $54 = (($this) + 76|0);
 HEAP32[$54>>2] = $55;
 if ($47) {
  $59 = 0;
 } else {
  $56 = (($50) + 64|0);
  $57 = HEAP32[$56>>2]|0;
  $59 = $57;
 }
 $58 = (($this) + 80|0);
 HEAP32[$58>>2] = $59;
 $60 = (($this) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==(0);
 $63 = (($this) + 104|0);
 if ($62) {
  $64 = HEAP32[$63>>2]|0;
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_vi[$67 & 4095]($64);
 }
 HEAP32[$0>>2] = $44;
 $68 = (($this) + 112|0);
 HEAP32[$68>>2] = $48;
 $69 = (($this) + 96|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + 1236|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = HEAP32[$63>>2]|0;
 $74 = ($73|0)==(0|0);
 if (!($74)) {
  $75 = HEAP32[$73>>2]|0;
  $76 = (($75) + 8|0);
  $77 = HEAP32[$76>>2]|0;
  FUNCTION_TABLE_vi[$77 & 4095]($73);
  $78 = (($72) + 280|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($79) + -1)|0;
  HEAP32[$78>>2] = $80;
  $81 = (($72) + 292|0);
  $82 = HEAP32[$81>>2]|0;
  HEAP32[$73>>2] = $82;
  HEAP32[$81>>2] = $73;
  $83 = (($72) + 284|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + 1)|0;
  HEAP32[$83>>2] = $85;
  $86 = (($72) + 276|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87*50)|0;
  $89 = ($84|0)<($88|0);
  if (!($89)) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($72);
   HEAP32[$83>>2] = 0;
  }
 }
 $90 = HEAP32[$69>>2]|0;
 $91 = (($90) + 1236|0);
 $92 = HEAP32[$91>>2]|0;
 if ($33) {
  $93 = (__ZNK5physx2Sc9RigidCore6getSimEv($r0)|0);
  $112 = $93;
 } else {
  $94 = (($90) + 1216|0);
  $95 = HEAP32[$94>>2]|0;
  $112 = $95;
 }
 if ($38) {
  $96 = (__ZNK5physx2Sc9RigidCore6getSimEv($r1)|0);
  $113 = $96;
 } else {
  $97 = HEAP32[$69>>2]|0;
  $98 = (($97) + 1216|0);
  $99 = HEAP32[$98>>2]|0;
  $113 = $99;
 }
 $100 = (($92) + 292|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($92);
  $$pre$i$i = HEAP32[$100>>2]|0;
  $104 = $$pre$i$i;
 } else {
  $104 = $101;
 }
 $103 = HEAP32[$104>>2]|0;
 HEAP32[$100>>2] = $103;
 $105 = (($92) + 280|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = (($106) + 1)|0;
 HEAP32[$105>>2] = $107;
 $108 = (($92) + 284|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = (($109) + -1)|0;
 HEAP32[$108>>2] = $110;
 $111 = ($104|0)==(0|0);
 if ($111) {
  $114 = 0;
  HEAP32[$63>>2] = $114;
  $115 = HEAP32[$114>>2]|0;
  $116 = HEAP32[$115>>2]|0;
  FUNCTION_TABLE_vi[$116 & 4095]($114);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc21ConstraintInteractionC2EPNS0_13ConstraintSimERNS0_8RigidSimES5_($104,$this,$112,$113);
 $114 = $104;
 HEAP32[$63>>2] = $114;
 $115 = HEAP32[$114>>2]|0;
 $116 = HEAP32[$115>>2]|0;
 FUNCTION_TABLE_vi[$116 & 4095]($114);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ConstraintSim21checkMaxForceExceededEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 100|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc5Scene19addBrokenConstraintEPNS0_14ConstraintCoreE($4,$6);
 $7 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc14ConstraintCore10breakApartEv($7);
 $8 = (($this) + 104|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vi[$12 & 4095]($9);
 $13 = HEAP32[$8>>2]|0;
 $14 = (($13) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19>>>0)<($21>>>0);
 $23 = $22 ? $15 : $17;
 $24 = (($23) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + ($27<<2)|0);
 $29 = ($27|0)>(0);
 if ($29) {
  $31 = $25;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $30 = HEAP32[$31>>2]|0;
  $32 = (($30) + 21|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33 & 1;
  $35 = ($34<<24>>24)==(0);
  if (!($35)) {
   $36 = ($30|0)==(0|0);
   if ($36) {
    $39 = 0;
   } else {
    $37 = (($30) + -8|0);
    $39 = $37;
   }
   $38 = (($39) + 4|0);
   $40 = HEAP16[$38>>1]|0;
   $41 = $40&65535;
   $42 = $41 | 1;
   $43 = $42&65535;
   HEAP16[$38>>1] = $43;
   $44 = (($39) + 6|0);
   $45 = HEAP16[$44>>1]|0;
   $46 = $45 & 2;
   $47 = ($46<<16>>16)==(0);
   if ($47) {
    __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($39);
    $48 = HEAP16[$44>>1]|0;
    $49 = $48&65535;
    $50 = $49 | 2;
    $51 = $50&65535;
    HEAP16[$44>>1] = $51;
   }
  }
  $52 = (($31) + 4|0);
  $53 = ($52>>>0)<($28>>>0);
  if ($53) {
   $31 = $52;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ConstraintSim8getForceERNS_6PxVec3ES3_($this,$lin,$ang) {
 $this = $this|0;
 $lin = $lin|0;
 $ang = $ang|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $3 = Math_fround(0), $4 = Math_fround(0);
 var $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 52|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(HEAPF32[$this>>2]);
 $5 = Math_fround($3 * $4);
 $6 = (($this) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($3 * $7);
 $9 = (($this) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($3 * $10);
 HEAPF32[$lin>>2] = $5;
 $12 = (($lin) + 4|0);
 HEAPF32[$12>>2] = $8;
 $13 = (($lin) + 8|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($this) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 * $15);
 $17 = (($this) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($3 * $18);
 $20 = (($this) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($3 * $21);
 HEAPF32[$ang>>2] = $16;
 $23 = (($ang) + 4|0);
 HEAPF32[$23>>2] = $19;
 $24 = (($ang) + 8|0);
 HEAPF32[$24>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ConstraintSim15setBreakForceLLEff($this,$linear,$angular) {
 $this = $this|0;
 $linear = Math_fround($linear);
 $angular = Math_fround($angular);
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isBreakable$0 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 2;
 $3 = $linear < Math_fround(3.40282346638528859812E+38);
 $4 = $angular < Math_fround(3.40282346638528859812E+38);
 $or$cond = $3 | $4;
 $isBreakable$0 = $or$cond ? 2 : 0;
 $5 = ($isBreakable$0<<24>>24)==($2<<24>>24);
 do {
  if (!($5)) {
   if ($or$cond) {
    $6 = $1 | 2;
    HEAP8[$0>>0] = $6;
    $7 = (($this) + 96|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 1212|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($this) + 104|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($10,$12)|0);
    if (!($13)) {
     break;
    }
    $14 = HEAP32[$7>>2]|0;
    __ZN5physx2Sc5Scene28addActiveBreakableConstraintEPNS0_13ConstraintSimE($14,$this);
    break;
   }
   $15 = $1 & 4;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $20 = $1;
   } else {
    $17 = (($this) + 96|0);
    $18 = HEAP32[$17>>2]|0;
    __ZN5physx2Sc5Scene31removeActiveBreakableConstraintEPNS0_13ConstraintSimE($18,$this);
    $$pre = HEAP8[$0>>0]|0;
    $20 = $$pre;
   }
   $19 = $20&255;
   $21 = $19 & 253;
   $22 = $21&255;
   HEAP8[$0>>0] = $22;
  }
 } while(0);
 $23 = (($this) + 32|0);
 HEAPF32[$23>>2] = $linear;
 $24 = (($this) + 36|0);
 HEAPF32[$24>>2] = $angular;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ConstraintSim14postFlagChangeENS_7PxFlagsINS_16PxConstraintFlag4EnumEtEES5_($this,$oldFlags,$newFlags) {
 $this = $this|0;
 $oldFlags = $oldFlags|0;
 $newFlags = $newFlags|0;
 var $$$i = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$newFlags>>1]|0;
 $1 = $0&65535;
 $2 = (($this) + 84|0);
 HEAP32[$2>>2] = $1;
 $3 = HEAP16[$oldFlags>>1]|0;
 $4 = $0 & 6;
 $5 = ($4<<16>>16)!=(0);
 $6 = $3 & 6;
 $7 = ($6<<16>>16)==(0);
 $or$cond = $5 & $7;
 if (!($or$cond)) {
  $or$cond1 = $5 | $7;
  if ($or$cond1) {
   STACKTOP = sp;return;
  }
  $36 = (($this) + 116|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = $37 & 1;
  $39 = ($38<<24>>24)==(0);
  if (!($39)) {
   $58 = (($this) + 96|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 80|0);
   $61 = HEAP32[$60>>2]|0;
   __ZN5physx2Sc27ConstraintProjectionManager29removeFromPendingGroupUpdatesERNS0_13ConstraintSimE($61,$this);
   STACKTOP = sp;return;
  }
  $40 = (($this) + 108|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   label = 18;
  } else {
   $43 = (($41) + 60|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0|0);
   if ($45) {
    label = 18;
   } else {
    $57 = $44;
   }
  }
  do {
   if ((label|0) == 18) {
    $46 = (($this) + 112|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(0|0);
    if ($48) {
     STACKTOP = sp;return;
    }
    $49 = (($47) + 60|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==(0|0);
    $$$i = $51 ? 0 : $47;
    $52 = ($$$i|0)==(0|0);
    if ($52) {
     STACKTOP = sp;return;
    } else {
     $$phi$trans$insert = (($$$i) + 60|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $57 = $$pre;
     break;
    }
   }
  } while(0);
  $53 = (($this) + 96|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($54) + 80|0);
  $56 = HEAP32[$55>>2]|0;
  __ZN5physx2Sc27ConstraintProjectionManager15invalidateGroupERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimE($56,$57,0);
  STACKTOP = sp;return;
 }
 $8 = (($this) + 108|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 112|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)!=(0|0);
 if ($12) {
  $13 = (($9) + 60|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   label = 4;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $16 = ($11|0)==(0|0);
   if (!($16)) {
    $17 = (($11) + 60|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     break;
    }
   }
   if ($12) {
    $20 = (($9) + 60|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($21)|0);
    $23 = (($22) + 20|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0|0);
    if (!($25)) {
     __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($22);
    }
    __ZN5physx2Sc24ConstraintProjectionTree20buildProjectionTreesERNS0_19ConstraintGroupNodeE($22);
    STACKTOP = sp;return;
   } else {
    $26 = (($11) + 60|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($27)|0);
    $29 = (($28) + 20|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==(0|0);
    if (!($31)) {
     __ZN5physx2Sc24ConstraintProjectionTree20purgeProjectionTreesERNS0_19ConstraintGroupNodeE($28);
    }
    __ZN5physx2Sc24ConstraintProjectionTree20buildProjectionTreesERNS0_19ConstraintGroupNodeE($28);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $32 = (($this) + 96|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 80|0);
 $35 = HEAP32[$34>>2]|0;
 __ZN5physx2Sc27ConstraintProjectionManager24addToPendingGroupUpdatesERNS0_13ConstraintSimE($35,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ConstraintSim8getRigidEj($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $$0$in = 0, $$0$in$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($i|0)==(0);
 $1 = (($this) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($2) + 8|0);
 $$0$in$in = $0 ? $3 : $4;
 $$0$in = HEAP32[$$0$in$in>>2]|0;
 STACKTOP = sp;return ($$0$in|0);
}
function __ZN5physx2Sc13ConstraintSim14hasDynamicBodyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 52|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 44|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6 & 1;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $18 = 1;
   STACKTOP = sp;return ($18|0);
  }
 }
 $9 = (($this) + 112|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $18 = 0;
  STACKTOP = sp;return ($18|0);
 }
 $12 = (($10) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 44|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 $18 = $17;
 STACKTOP = sp;return ($18|0);
}
function __ZN5physx2Sc13ConstraintSim11projectPoseEPNS0_7BodySimE($this,$childBody) {
 $this = $this|0;
 $childBody = $childBody|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (($this) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($childBody|0);
 $4 = (($this) + 96|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 48|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 __ZN5physx20PxsConstraintProjectEPKNS_13PxsConstraintEbf($0,$3,$7);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ConstraintSim9visualizeERNS_14PxRenderBufferE($this,$output) {
 $this = $this|0;
 $output = $output|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $renderOut = 0, $viz = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $0 = sp + 152|0;
 $1 = sp;
 $renderOut = sp + 32|0;
 $viz = sp + 136|0;
 $2 = (($this) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 32;
 $6 = ($5<<16>>16)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 72|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==(0|0);
 if ($11) {
  HEAPF32[$0>>2] = Math_fround(0.0);
  $33 = (($0) + 4|0);
  HEAPF32[$33>>2] = Math_fround(0.0);
  $34 = (($0) + 8|0);
  HEAPF32[$34>>2] = Math_fround(0.0);
  $35 = (($0) + 12|0);
  HEAPF32[$35>>2] = Math_fround(1.0);
  $36 = (($0) + 16|0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $37 = (($0) + 20|0);
  HEAPF32[$37>>2] = Math_fround(0.0);
  $38 = (($0) + 24|0);
  HEAPF32[$38>>2] = Math_fround(0.0);
 } else {
  $12 = (($8) + 64|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$0>>2] = $14;
  $15 = (($0) + 4|0);
  $16 = (($13) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$15>>2] = $17;
  $18 = (($0) + 8|0);
  $19 = (($13) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$18>>2] = $20;
  $21 = (($0) + 12|0);
  $22 = (($13) + 12|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$21>>2] = $23;
  $24 = (($0) + 16|0);
  $25 = (($13) + 16|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$24>>2] = $26;
  $27 = (($0) + 20|0);
  $28 = (($13) + 20|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$27>>2] = $29;
  $30 = (($0) + 24|0);
  $31 = (($13) + 24|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$30>>2] = $32;
 }
 $39 = ($10|0)==(0|0);
 if ($39) {
  HEAPF32[$1>>2] = Math_fround(0.0);
  $61 = (($1) + 4|0);
  HEAPF32[$61>>2] = Math_fround(0.0);
  $62 = (($1) + 8|0);
  HEAPF32[$62>>2] = Math_fround(0.0);
  $63 = (($1) + 12|0);
  HEAPF32[$63>>2] = Math_fround(1.0);
  $64 = (($1) + 16|0);
  HEAPF32[$64>>2] = Math_fround(0.0);
  $65 = (($1) + 20|0);
  HEAPF32[$65>>2] = Math_fround(0.0);
  $66 = (($1) + 24|0);
  HEAPF32[$66>>2] = Math_fround(0.0);
 } else {
  $40 = (($10) + 64|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$1>>2] = $42;
  $43 = (($1) + 4|0);
  $44 = (($41) + 4|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$43>>2] = $45;
  $46 = (($1) + 8|0);
  $47 = (($41) + 8|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  HEAPF32[$46>>2] = $48;
  $49 = (($1) + 12|0);
  $50 = (($41) + 12|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  HEAPF32[$49>>2] = $51;
  $52 = (($1) + 16|0);
  $53 = (($41) + 16|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  HEAPF32[$52>>2] = $54;
  $55 = (($1) + 20|0);
  $56 = (($41) + 20|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  HEAPF32[$55>>2] = $57;
  $58 = (($1) + 24|0);
  $59 = (($41) + 24|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  HEAPF32[$58>>2] = $60;
 }
 $67 = (($this) + 96|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + 1416|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($68,21)));
 $72 = Math_fround($70 * $71);
 $73 = HEAP32[$67>>2]|0;
 $74 = (($73) + 1416|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($73,22)));
 $77 = Math_fround($75 * $76);
 $78 = (($renderOut) + 36|0);
 dest=$renderOut+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$78>>2] = Math_fround(1.0);
 $79 = (($renderOut) + 40|0);
 $80 = (($renderOut) + 56|0);
 ;HEAP32[$79+0>>2]=0|0;HEAP32[$79+4>>2]=0|0;HEAP32[$79+8>>2]=0|0;HEAP32[$79+12>>2]=0|0;
 HEAPF32[$80>>2] = Math_fround(1.0);
 $81 = (($renderOut) + 60|0);
 $82 = (($renderOut) + 76|0);
 ;HEAP32[$81+0>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;HEAP32[$81+12>>2]=0|0;
 HEAPF32[$82>>2] = Math_fround(1.0);
 $83 = (($renderOut) + 80|0);
 $84 = (($renderOut) + 96|0);
 ;HEAP32[$83+0>>2]=0|0;HEAP32[$83+4>>2]=0|0;HEAP32[$83+8>>2]=0|0;HEAP32[$83+12>>2]=0|0;
 HEAPF32[$84>>2] = Math_fround(1.0);
 $85 = (($renderOut) + 100|0);
 HEAP32[$85>>2] = $output;
 HEAP32[$viz>>2] = ((418496 + 8|0));
 $86 = (($viz) + 4|0);
 HEAPF32[$86>>2] = $72;
 $87 = (($viz) + 8|0);
 HEAPF32[$87>>2] = $77;
 $88 = (($viz) + 12|0);
 HEAP32[$88>>2] = $renderOut;
 $89 = HEAP32[$2>>2]|0;
 $90 = (($89) + 48|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (($this) + 60|0);
 $93 = HEAP32[$92>>2]|0;
 FUNCTION_TABLE_viiiii[$91 & 255]($viz,$93,$0,$1,3);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 40)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 460240 : 460208;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,460384,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 460240 : 460208;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,460384,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 460240 : 460208;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,460128,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 460240 : 460208;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460128,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 460240 : 460208;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,460128,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 460240 : 460208;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,460472,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*40)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -40|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 __ZN5physx2Sc10NPhaseCore25addToDirtyInteractionListEPNS0_15CoreInteractionE($3,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 (__ZN5physx2Sc10NPhaseCore30removeFromDirtyInteractionListEPNS0_15CoreInteractionE($3,$this)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15CoreInteraction17isCoreInteractionEPNS0_11InteractionE($interaction) {
 $interaction = $interaction|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($interaction) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 switch ($2|0) {
 case 4: case 3: case 2: case 0:  {
  $4 = (($interaction) + -8|0);
  $$0 = $4;
  break;
 }
 case 1:  {
  $3 = (($interaction) + 24|0);
  $$0 = $3;
  break;
 }
 default: {
  $$0 = 0;
 }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sc23ElementActorInteraction23isLastFilterInteractionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(1);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx2Sc24ElementInteractionMarker10initializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iii[$3 & 4095]($0,0)|0);
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($8,$0,$4);
 $9 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($9,$0);
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($11,$0);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc24ElementInteractionMarker10initializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$4 & 4095]($1,0)|0);
 $6 = (($0) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($9,$1,$5);
 $10 = HEAP32[$6>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($10,$1);
 $11 = (($0) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($12,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc24ElementInteractionMarker7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($2,$0);
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($4,$0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($7,$0);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc24ElementInteractionMarker7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 8|0);
 $2 = (($0) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($3,$1);
 $4 = (($0) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($5,$1);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($8,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc24ElementInteractionMarker11updateStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)==(0);
 if (!($3)) {
  __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($this);
  $4 = HEAP16[$0>>1]|0;
  $5 = $4&65535;
  $6 = $5 & 65533;
  $7 = $6&65535;
  HEAP16[$0>>1] = $7;
 }
 $8 = (($this) + 4|0);
 HEAP16[$8>>1] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc24ElementInteractionMarker10onActivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZThn8_N5physx2Sc24ElementInteractionMarker10onActivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx2Sc24ElementInteractionMarker12onDeactivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZThn8_N5physx2Sc24ElementInteractionMarker12onDeactivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Sc24ElementInteractionMarkerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc24ElementInteractionMarkerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc21ElementSimInteraction23isLastFilterInteractionEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZThn8_N5physx2Sc24ElementInteractionMarkerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc24ElementInteractionMarkerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10ElementSim27setElementInteractionsDirtyENS0_15CoreInteraction9DirtyFlagEh($this,$flag,$interactionFlag) {
 $this = $this|0;
 $flag = $flag|0;
 $interactionFlag = $interactionFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $interaction$01 = 0, $iter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5<<2)|0);
 $7 = $3;
 $8 = $6;
 $9 = $iter;
 $10 = $9;
 HEAP32[$10>>2] = $7;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($iter) + 8|0);
 HEAP32[$13>>2] = $this;
 $14 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 } else {
  $interaction$01 = $14;
 }
 while(1) {
  $16 = (($interaction$01) + 21|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17 & $interactionFlag;
  $19 = ($18<<24>>24)==(0);
  if (!($19)) {
   $20 = (($interaction$01) + -8|0);
   $21 = (($20) + 4|0);
   $22 = HEAP16[$21>>1]|0;
   $23 = $22&65535;
   $24 = $23 | $flag;
   $25 = $24&65535;
   HEAP16[$21>>1] = $25;
   $26 = (($20) + 6|0);
   $27 = HEAP16[$26>>1]|0;
   $28 = $27 & 2;
   $29 = ($28<<16>>16)==(0);
   if ($29) {
    __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($20);
    $30 = HEAP16[$26>>1]|0;
    $31 = $30&65535;
    $32 = $31 | 2;
    $33 = $32&65535;
    HEAP16[$26>>1] = $33;
   }
  }
  $34 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   break;
  } else {
   $interaction$01 = $34;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc21ElementSimInteraction13getNPhaseCoreEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5physx2Sc8ActorSim8getSceneEv($3)|0);
 $5 = (($4) + 1088|0);
 $6 = HEAP32[$5>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx2Sc12MaterialCoreC2ERKNS_15PxsMaterialDataE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=HEAP32[$desc+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$desc+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$desc+8>>2]|0;
 $0 = (($desc) + 12|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($this) + 12|0);
 HEAP16[$2>>1] = $1;
 $3 = (($this) + 14|0);
 $4 = (($desc) + 14|0);
 $5 = HEAPU8[$4>>0]|(HEAPU8[$4+1>>0]<<8);
 HEAP8[$3>>0]=$5&255;HEAP8[$3+1>>0]=$5>>8;
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 20|0);
 HEAP32[$7>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc12MaterialCoreD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCoreC2ERNS0_5SceneERKNS_11PxSceneDescE($this,$scene,$sceneDesc) {
 $this = $this|0;
 $scene = $scene|0;
 $sceneDesc = $sceneDesc|0;
 var $$tr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = $scene;
 $1 = (($this) + 4|0);
 $2 = (($sceneDesc) + 144|0);
 dest=$1+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $3 = HEAP32[$2>>2]|0;
 $4 = (($sceneDesc) + 100|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = (($this) + 44|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 48|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 52|0);
 HEAP32[$8>>2] = $3;
 $9 = (($this) + 56|0);
 HEAP32[$9>>2] = $3;
 $10 = (($this) + 60|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 64|0);
 $12 = ($5&65535) >>> 10;
 $$tr = $12&255;
 $13 = $$tr & 1;
 HEAP8[$11>>0] = $13;
 $14 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$3,463048,167)|0);
 HEAP32[$6>>2] = $14;
 $15 = (($this) + 68|0);
 $16 = (($this) + 120|0);
 $17 = (($this) + 376|0);
 $18 = (($this) + 380|0);
 $19 = (($this) + 384|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 388|0);
 dest=$15+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP8[$17>>0] = 1;
 HEAP32[$18>>2] = $16;
 HEAP32[$20>>2] = 64;
 $21 = (($this) + 392|0);
 HEAP32[$21>>2] = 32;
 $22 = (($this) + 396|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 400|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 404|0);
 HEAP32[$24>>2] = 768;
 $25 = (($this) + 408|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 416|0);
 $27 = (($this) + 672|0);
 $28 = (($this) + 676|0);
 $29 = (($this) + 680|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 684|0);
 HEAP8[$27>>0] = 1;
 HEAP32[$28>>2] = $26;
 HEAP32[$30>>2] = 64;
 $31 = (($this) + 688|0);
 HEAP32[$31>>2] = 32;
 $32 = (($this) + 692|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 696|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 700|0);
 HEAP32[$34>>2] = 768;
 $35 = (($this) + 704|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 712|0);
 $37 = (($this) + 968|0);
 $38 = (($this) + 972|0);
 $39 = (($this) + 976|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 980|0);
 HEAP8[$37>>0] = 1;
 HEAP32[$38>>2] = $36;
 HEAP32[$40>>2] = 64;
 $41 = (($this) + 984|0);
 HEAP32[$41>>2] = 32;
 $42 = (($this) + 988|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 992|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 996|0);
 HEAP32[$44>>2] = 2176;
 $45 = (($this) + 1000|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 1008|0);
 $47 = (($this) + 1264|0);
 $48 = (($this) + 1268|0);
 $49 = (($this) + 1272|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 1276|0);
 HEAP8[$47>>0] = 1;
 HEAP32[$48>>2] = $46;
 HEAP32[$50>>2] = 64;
 $51 = (($this) + 1280|0);
 HEAP32[$51>>2] = 32;
 $52 = (($this) + 1284|0);
 HEAP32[$52>>2] = 0;
 $53 = (($this) + 1288|0);
 HEAP32[$53>>2] = 0;
 $54 = (($this) + 1292|0);
 HEAP32[$54>>2] = 1920;
 $55 = (($this) + 1296|0);
 HEAP32[$55>>2] = 0;
 $56 = (($this) + 1304|0);
 $57 = (($this) + 1560|0);
 $58 = (($this) + 1564|0);
 $59 = (($this) + 1568|0);
 HEAP32[$59>>2] = 0;
 $60 = (($this) + 1572|0);
 HEAP8[$57>>0] = 1;
 HEAP32[$58>>2] = $56;
 HEAP32[$60>>2] = 64;
 $61 = (($this) + 1576|0);
 HEAP32[$61>>2] = 32;
 $62 = (($this) + 1580|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 1584|0);
 HEAP32[$63>>2] = 0;
 $64 = (($this) + 1588|0);
 HEAP32[$64>>2] = 1152;
 $65 = (($this) + 1592|0);
 HEAP32[$65>>2] = 0;
 $66 = (($this) + 1600|0);
 $67 = (($this) + 1856|0);
 $68 = (($this) + 1860|0);
 $69 = (($this) + 1864|0);
 HEAP32[$69>>2] = 0;
 $70 = (($this) + 1868|0);
 HEAP8[$67>>0] = 1;
 HEAP32[$68>>2] = $66;
 HEAP32[$70>>2] = 64;
 $71 = (($this) + 1872|0);
 HEAP32[$71>>2] = 32;
 $72 = (($this) + 1876|0);
 HEAP32[$72>>2] = 0;
 $73 = (($this) + 1880|0);
 HEAP32[$73>>2] = 0;
 $74 = (($this) + 1884|0);
 HEAP32[$74>>2] = 1280;
 $75 = (($this) + 1888|0);
 HEAP32[$75>>2] = 0;
 $76 = (($this) + 1896|0);
 $77 = (($this) + 2152|0);
 $78 = (($this) + 2156|0);
 $79 = (($this) + 2160|0);
 HEAP32[$79>>2] = 0;
 $80 = (($this) + 2164|0);
 HEAP8[$77>>0] = 1;
 HEAP32[$78>>2] = $76;
 HEAP32[$80>>2] = 64;
 $81 = (($this) + 2168|0);
 HEAP32[$81>>2] = 32;
 $82 = (($this) + 2172|0);
 HEAP32[$82>>2] = 0;
 $83 = (($this) + 2176|0);
 HEAP32[$83>>2] = 0;
 $84 = (($this) + 2180|0);
 HEAP32[$84>>2] = 1536;
 $85 = (($this) + 2184|0);
 HEAP32[$85>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCoreD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0;
 var $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Sc10NPhaseCore28clearContactReportActorPairsEb($this,0);
 $1 = (($this) + 1892|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc35ParticleElementRbElementInteractionENS0_19ReflectionAllocatorIS3_EEED2Ev($1);
 $2 = (($this) + 1596|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEED2Ev($2);
 $3 = (($this) + 1300|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc26ActorPairContactReportDataENS0_19ReflectionAllocatorIS3_EEED2Ev($3);
 $4 = (($this) + 1004|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc18TriggerInteractionENS0_19ReflectionAllocatorIS3_EEED2Ev($4);
 $5 = (($this) + 708|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS3_EEED2Ev($5);
 $6 = (($this) + 412|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc16ActorElementPairENS0_19ReflectionAllocatorIS3_EEED2Ev($6);
 $7 = (($this) + 116|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEED2Ev($7);
 $8 = (($this) + 80|0);
 __ZN5physx2Cm11IndexedPoolINS_2Sc10FilterPairELj32EED2Ev($8);
 $9 = (($this) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11|0)!=(0);
 $13 = ($10|0)>(-1);
 $or$cond$i$i = $12 & $13;
 if ($or$cond$i$i) {
  $14 = (($this) + 68|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$20 & 4095]($17,$15);
  }
 }
 $21 = (($this) + 44|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$22);
 $23 = (($this) + 40|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 & 2147483647;
 $26 = ($25|0)!=(0);
 $27 = ($24|0)>(-1);
 $or$cond$i$i1 = $26 & $27;
 if ($or$cond$i$i1) {
  $28 = (($this) + 32|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   $31 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 12|0);
   $34 = HEAP32[$33>>2]|0;
   FUNCTION_TABLE_vii[$34 & 4095]($31,$29);
  }
 }
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37|0)!=(0);
 $39 = ($36|0)>(-1);
 $or$cond$i$i2 = $38 & $39;
 if ($or$cond$i$i2) {
  $40 = (($this) + 16|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   FUNCTION_TABLE_vii[$46 & 4095]($43,$41);
  }
 }
 $47 = (($this) + 12|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 & 2147483647;
 $50 = ($49|0)!=(0);
 $51 = ($48|0)>(-1);
 $or$cond$i$i4 = $50 & $51;
 if (!($or$cond$i$i4)) {
  STACKTOP = sp;return;
 }
 $52 = (($this) + 4|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  STACKTOP = sp;return;
 }
 $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 12|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore28clearContactReportActorPairsEb($this,$shrinkToZero) {
 $this = $this|0;
 $shrinkToZero = $shrinkToZero|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($this) + 116|0);
  $6 = (($this) + 396|0);
  $7 = (($this) + 408|0);
  $8 = (($this) + 400|0);
  $9 = (($this) + 392|0);
  $i$02 = 0;
  while(1) {
   $10 = HEAP32[$1>>2]|0;
   $11 = (($10) + ($i$02<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 16|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = (($14) + -1)<<16>>16;
   HEAP16[$13>>1] = $15;
   $16 = ($14&65535)>(1);
   if ($16) {
    $17 = (($12) + 12|0);
    $18 = HEAP16[$17>>1]|0;
    $19 = $18&65535;
    $20 = $19 & 65534;
    $21 = $20&65535;
    HEAP16[$17>>1] = $21;
   } else {
    $22 = ($12|0)==(0|0);
    if (!($22)) {
     $23 = (($12) + 20|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if (!($25)) {
      __ZNK5physx2Sc9ActorPair24releaseContactReportDataEv($12);
     }
     $26 = HEAP32[$12>>2]|0;
     $27 = (($26) + 46|0);
     $28 = HEAP16[$27>>1]|0;
     $29 = (($28) + -1)<<16>>16;
     HEAP16[$27>>1] = $29;
     $30 = (($12) + 4|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($31) + 46|0);
     $33 = HEAP16[$32>>1]|0;
     $34 = (($33) + -1)<<16>>16;
     HEAP16[$32>>1] = $34;
     $35 = HEAP32[$6>>2]|0;
     $36 = (($35) + -1)|0;
     HEAP32[$6>>2] = $36;
     $37 = HEAP32[$7>>2]|0;
     HEAP32[$12>>2] = $37;
     HEAP32[$7>>2] = $12;
     $38 = HEAP32[$8>>2]|0;
     $39 = (($38) + 1)|0;
     HEAP32[$8>>2] = $39;
     $40 = HEAP32[$9>>2]|0;
     $41 = ($40*50)|0;
     $42 = ($38|0)<($41|0);
     if (!($42)) {
      __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($5);
      HEAP32[$8>>2] = 0;
     }
    }
   }
   $43 = (($i$02) + 1)|0;
   $44 = HEAP32[$2>>2]|0;
   $45 = ($43>>>0)<($44>>>0);
   if ($45) {
    $i$02 = $43;
   } else {
    break;
   }
  }
 }
 if ($shrinkToZero) {
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIPNS_2Sc9ActorPairENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($1,0,$0);
  $46 = HEAP32[$2>>2]|0;
  __ZN5physx6shdfnd5ArrayIPNS_2Sc9ActorPairENS0_19ReflectionAllocatorIS4_EEE8recreateEj($1,$46);
  STACKTOP = sp;return;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Sc10NPhaseCore39getDefaultContactReportStreamBufferSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc10NPhaseCore16onOverlapCreatedEPNS0_7ElementES3_j($this,$volume0,$volume1,$ccdPass) {
 $this = $this|0;
 $volume0 = $volume0|0;
 $volume1 = $volume1|0;
 $ccdPass = $ccdPass|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0;
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $finfo = 0, $particleShapeBounds = 0, $vararg_buffer = 0, $volume0$volume1 = 0, $volume1$volume0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $vararg_buffer = sp;
 $0 = sp + 154|0;
 $particleShapeBounds = sp + 64|0;
 $1 = sp + 88|0;
 $2 = sp + 116|0;
 $3 = sp + 152|0;
 $finfo = sp + 144|0;
 $4 = (($volume0) + 12|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (_bitshift64Lshr(($7|0),($10|0),30)|0);
 $12 = tempRet0;
 $13 = $11 & 3;
 $14 = (($volume1) + 12|0);
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (_bitshift64Lshr(($17|0),($20|0),30)|0);
 $22 = tempRet0;
 $23 = $21 & 3;
 $24 = ($13>>>0)>($23>>>0);
 $volume0$volume1 = $24 ? $volume0 : $volume1;
 $volume1$volume0 = $24 ? $volume1 : $volume0;
 $25 = (($volume0$volume1) + 12|0);
 $26 = $25;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (_bitshift64Lshr(($28|0),($31|0),30)|0);
 $33 = tempRet0;
 $34 = $32 & 3;
 if ((($34|0) == 2)) {
  $144 = (($volume1$volume0) + 12|0);
  $145 = $144;
  $146 = $145;
  $147 = HEAP32[$146>>2]|0;
  $148 = (($145) + 4)|0;
  $149 = $148;
  $150 = HEAP32[$149>>2]|0;
  $151 = $147 & -1073741824;
  $152 = ($151|0)==(0);
  $153 = (0)==(0);
  $154 = $152 & $153;
  if (!($154)) {
   STACKTOP = sp;return;
  }
  $155 = (($volume0$volume1) + 20|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = (__ZNK5physx2Sc9ClothCore6getSimEv($156)|0);
  $158 = (__ZNK5physx2Sc8ClothSim7getCoreEv($157)|0);
  __ZNK5physx2Sc9ClothCore13getClothFlagsEv($3,$158);
  $159 = HEAP16[$3>>1]|0;
  $160 = $159 & 4;
  $161 = ($160<<16>>16)==(0);
  if ($161) {
   STACKTOP = sp;return;
  }
  __ZN5physx2Sc10NPhaseCore9runFilterERKNS0_10ElementSimES4_PNS0_10FilterPairE($finfo,$this,$volume0$volume1,$volume1$volume0,0);
  $162 = HEAP16[$finfo>>1]|0;
  $163 = $162 & 3;
  $164 = ($163<<16>>16)==(0);
  if (!($164)) {
   STACKTOP = sp;return;
  }
  $165 = (($volume1$volume0) + 28|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = (($166) + 68|0);
  $168 = HEAP32[$167>>2]|0;
  switch ($168|0) {
  case 6:  {
   __ZN5physx2Sc8ClothSim23addCollisionHeightfieldEPKNS0_8ShapeSimE($157,$volume1$volume0);
   STACKTOP = sp;return;
   break;
  }
  case 4:  {
   __ZN5physx2Sc8ClothSim18addCollisionConvexEPKNS0_8ShapeSimE($157,$volume1$volume0);
   STACKTOP = sp;return;
   break;
  }
  case 3:  {
   __ZN5physx2Sc8ClothSim15addCollisionBoxEPKNS0_8ShapeSimE($157,$volume1$volume0);
   STACKTOP = sp;return;
   break;
  }
  case 0:  {
   __ZN5physx2Sc8ClothSim18addCollisionSphereEPKNS0_8ShapeSimE($157,$volume1$volume0);
   STACKTOP = sp;return;
   break;
  }
  case 5:  {
   __ZN5physx2Sc8ClothSim16addCollisionMeshEPKNS0_8ShapeSimE($157,$volume1$volume0);
   STACKTOP = sp;return;
   break;
  }
  case 1:  {
   __ZN5physx2Sc8ClothSim17addCollisionPlaneEPKNS0_8ShapeSimE($157,$volume1$volume0);
   STACKTOP = sp;return;
   break;
  }
  case 2:  {
   __ZN5physx2Sc8ClothSim19addCollisionCapsuleEPKNS0_8ShapeSimE($157,$volume1$volume0);
   STACKTOP = sp;return;
   break;
  }
  default: {
   STACKTOP = sp;return;
  }
  }
 } else if ((($34|0) == 0)) {
  (__ZN5physx2Sc10NPhaseCore26createRbElementInteractionERNS0_8ShapeSimES3_($this,$volume0$volume1,$volume1$volume0)|0);
  STACKTOP = sp;return;
 } else if ((($34|0) == 1)) {
  $35 = (($volume1$volume0) + 12|0);
  $36 = $35;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $38 & -1073741824;
  $43 = ($42|0)==(0);
  $44 = (0)==(0);
  $45 = $43 & $44;
  if (!($45)) {
   STACKTOP = sp;return;
  }
  $46 = (($volume1$volume0) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + 50|0);
  $49 = HEAP8[$48>>0]|0;
  if ((($49<<24>>24) == 1) | (($49<<24>>24) == 4)) {
   $50 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($volume0$volume1)|0);
   $51 = (__ZNK5physx2Sc17ParticleSystemSim7getCoreEv($50)|0);
   __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($0,$51);
   $52 = HEAP16[$0>>1]|0;
   $53 = $52 & 2;
   $54 = ($53<<16>>16)==(0);
   if ($54) {
    STACKTOP = sp;return;
   }
  }
  $55 = (($volume0$volume1) + 42|0);
  $56 = HEAP16[$55>>1]|0;
  $57 = ($56<<16>>16)==(-1);
  if ($57) {
   $143 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($143,2,460632,278,460728,$vararg_buffer);
   STACKTOP = sp;return;
  }
  $58 = (($volume1$volume0) + 28|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + 68|0);
  $61 = HEAP32[$60>>2]|0;
  $$off = (($61) + -5)|0;
  $62 = ($$off>>>0)<(2);
  do {
   if ($62) {
    __ZNK5physx2Sc19ParticlePacketShape18computeWorldBoundsERNS_9PxBounds3E($volume0$volume1,$particleShapeBounds);
    if ((($61|0) == 6)) {
     $63 = HEAP32[$58>>2]|0;
     $64 = (($63) + 68|0);
     $65 = Math_fround(HEAPF32[$particleShapeBounds>>2]);
     $66 = (($particleShapeBounds) + 12|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = Math_fround($65 + $67);
     $69 = (($particleShapeBounds) + 4|0);
     $70 = Math_fround(HEAPF32[$69>>2]);
     $71 = (($particleShapeBounds) + 16|0);
     $72 = Math_fround(HEAPF32[$71>>2]);
     $73 = Math_fround($70 + $72);
     $74 = (($particleShapeBounds) + 8|0);
     $75 = Math_fround(HEAPF32[$74>>2]);
     $76 = (($particleShapeBounds) + 20|0);
     $77 = Math_fround(HEAPF32[$76>>2]);
     $78 = Math_fround($75 + $77);
     $79 = Math_fround($68 * Math_fround(0.5));
     $80 = Math_fround($73 * Math_fround(0.5));
     $81 = Math_fround($78 * Math_fround(0.5));
     $82 = Math_fround($67 - $65);
     $83 = Math_fround($72 - $70);
     $84 = Math_fround($77 - $75);
     $85 = Math_fround($82 * Math_fround(0.5));
     $86 = Math_fround($83 * Math_fround(0.5));
     $87 = Math_fround($84 * Math_fround(0.5));
     HEAPF32[$vararg_buffer>>2] = Math_fround(1.0);
     $88 = (($vararg_buffer) + 4|0);
     HEAPF32[$88>>2] = Math_fround(0.0);
     $89 = (($vararg_buffer) + 8|0);
     HEAPF32[$89>>2] = Math_fround(0.0);
     $90 = (($vararg_buffer) + 12|0);
     HEAPF32[$90>>2] = Math_fround(0.0);
     $91 = (($vararg_buffer) + 16|0);
     HEAPF32[$91>>2] = Math_fround(1.0);
     $92 = (($vararg_buffer) + 20|0);
     HEAPF32[$92>>2] = Math_fround(0.0);
     $93 = (($vararg_buffer) + 24|0);
     HEAPF32[$93>>2] = Math_fround(0.0);
     $94 = (($vararg_buffer) + 28|0);
     HEAPF32[$94>>2] = Math_fround(0.0);
     $95 = (($vararg_buffer) + 32|0);
     HEAPF32[$95>>2] = Math_fround(1.0);
     $96 = (($vararg_buffer) + 36|0);
     HEAPF32[$96>>2] = $79;
     $97 = (($vararg_buffer) + 40|0);
     HEAPF32[$97>>2] = $80;
     $98 = (($vararg_buffer) + 44|0);
     HEAPF32[$98>>2] = $81;
     $99 = (($vararg_buffer) + 48|0);
     HEAPF32[$99>>2] = $85;
     $100 = (($vararg_buffer) + 52|0);
     HEAPF32[$100>>2] = $86;
     $101 = (($vararg_buffer) + 56|0);
     HEAPF32[$101>>2] = $87;
     __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($2,$volume1$volume0);
     $102 = (__ZN5physx2Gu31checkOverlapOBB_heightFieldGeomERKNS_10PxGeometryERKNS_11PxTransformERKNS0_3BoxE($64,$2,$vararg_buffer)|0);
     if ($102) {
      break;
     }
     STACKTOP = sp;return;
    } else if ((($61|0) == 5)) {
     $103 = HEAP32[$58>>2]|0;
     $104 = (($103) + 68|0);
     $105 = Math_fround(HEAPF32[$particleShapeBounds>>2]);
     $106 = (($particleShapeBounds) + 12|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = Math_fround($105 + $107);
     $109 = (($particleShapeBounds) + 4|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = (($particleShapeBounds) + 16|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = Math_fround($110 + $112);
     $114 = (($particleShapeBounds) + 8|0);
     $115 = Math_fround(HEAPF32[$114>>2]);
     $116 = (($particleShapeBounds) + 20|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = Math_fround($115 + $117);
     $119 = Math_fround($108 * Math_fround(0.5));
     $120 = Math_fround($113 * Math_fround(0.5));
     $121 = Math_fround($118 * Math_fround(0.5));
     $122 = Math_fround($107 - $105);
     $123 = Math_fround($112 - $110);
     $124 = Math_fround($117 - $115);
     $125 = Math_fround($122 * Math_fround(0.5));
     $126 = Math_fround($123 * Math_fround(0.5));
     $127 = Math_fround($124 * Math_fround(0.5));
     HEAPF32[$vararg_buffer>>2] = Math_fround(1.0);
     $128 = (($vararg_buffer) + 4|0);
     HEAPF32[$128>>2] = Math_fround(0.0);
     $129 = (($vararg_buffer) + 8|0);
     HEAPF32[$129>>2] = Math_fround(0.0);
     $130 = (($vararg_buffer) + 12|0);
     HEAPF32[$130>>2] = Math_fround(0.0);
     $131 = (($vararg_buffer) + 16|0);
     HEAPF32[$131>>2] = Math_fround(1.0);
     $132 = (($vararg_buffer) + 20|0);
     HEAPF32[$132>>2] = Math_fround(0.0);
     $133 = (($vararg_buffer) + 24|0);
     HEAPF32[$133>>2] = Math_fround(0.0);
     $134 = (($vararg_buffer) + 28|0);
     HEAPF32[$134>>2] = Math_fround(0.0);
     $135 = (($vararg_buffer) + 32|0);
     HEAPF32[$135>>2] = Math_fround(1.0);
     $136 = (($vararg_buffer) + 36|0);
     HEAPF32[$136>>2] = $119;
     $137 = (($vararg_buffer) + 40|0);
     HEAPF32[$137>>2] = $120;
     $138 = (($vararg_buffer) + 44|0);
     HEAPF32[$138>>2] = $121;
     $139 = (($vararg_buffer) + 48|0);
     HEAPF32[$139>>2] = $125;
     $140 = (($vararg_buffer) + 52|0);
     HEAPF32[$140>>2] = $126;
     $141 = (($vararg_buffer) + 56|0);
     HEAPF32[$141>>2] = $127;
     __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($1,$volume1$volume0);
     $142 = (__ZN5physx2Gu28checkOverlapOBB_triangleGeomERKNS_10PxGeometryERKNS_11PxTransformERKNS0_3BoxE($104,$1,$vararg_buffer)|0);
     if ($142) {
      break;
     }
     STACKTOP = sp;return;
    } else {
     STACKTOP = sp;return;
    }
   }
  } while(0);
  (__ZN5physx2Sc10NPhaseCore35createParticlePacketBodyInteractionERNS0_19ParticlePacketShapeERNS0_8ShapeSimEj($this,$volume0$volume1,$volume1$volume0,$ccdPass)|0);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc10NPhaseCore35createParticlePacketBodyInteractionERNS0_19ParticlePacketShapeERNS0_8ShapeSimEj($this,$ps,$s,$ccdPass) {
 $this = $this|0;
 $ps = $ps|0;
 $s = $s|0;
 $ccdPass = $ccdPass|0;
 var $$0 = 0, $$lobit = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $actorElementPair$0 = 0, $finfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $finfo = sp;
 $0 = (($s) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($ps) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($ps) + 42|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = (($3) + ($6<<2)|0);
 $8 = ($5<<16>>16)==(0);
 L1: do {
  if ($8) {
   label = 7;
  } else {
   $10 = $3;
   while(1) {
    $9 = HEAP32[$10>>2]|0;
    $11 = (($9) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($1|0);
    if ($13) {
     $14 = (($9) + 32|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==($ps|0);
     if ($16) {
      break;
     }
    }
    $17 = (($10) + 4|0);
    $18 = ($17>>>0)<($7>>>0);
    if ($18) {
     $10 = $17;
    } else {
     label = 7;
     break L1;
    }
   }
   $19 = ($9|0)==(0|0);
   if ($19) {
    label = 7;
   } else {
    $20 = (($9) + 40|0);
    $21 = HEAP32[$20>>2]|0;
    $actorElementPair$0 = $21;
   }
  }
 } while(0);
 if ((label|0) == 7) {
  __ZN5physx2Sc10NPhaseCore9runFilterERKNS0_10ElementSimES4_PNS0_10FilterPairE($finfo,$this,$ps,$s,0);
  $22 = HEAP16[$finfo>>1]|0;
  $23 = $22&65535;
  $24 = $23 & 1;
  $25 = ($24|0)==(0);
  if (!($25)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $26 = (($ps) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($this) + 704|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $31 = (($this) + 412|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Sc16ActorElementPairENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($31);
   $$pre$i$i = HEAP32[$28>>2]|0;
   $33 = $$pre$i$i;
  } else {
   $33 = $29;
  }
  $32 = HEAP32[$33>>2]|0;
  HEAP32[$28>>2] = $32;
  $34 = (($this) + 692|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + 1)|0;
  HEAP32[$34>>2] = $36;
  $37 = (($this) + 696|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + -1)|0;
  HEAP32[$37>>2] = $39;
  $40 = ($33|0)==(0|0);
  if ($40) {
   $47 = 0;
  } else {
   $41 = (($finfo) + 2|0);
   $42 = HEAP16[$41>>1]|0;
   HEAP32[$33>>2] = $27;
   $43 = (($33) + 4|0);
   HEAP32[$43>>2] = $s;
   $44 = (($33) + 8|0);
   HEAP16[$44>>1] = $42;
   $45 = (($33) + 12|0);
   ;HEAP32[$45+0>>2]=0|0;HEAP32[$45+4>>2]=0|0;HEAP8[$45+8>>0]=0|0;
   $47 = $33;
  }
  $46 = (($47) + 19|0);
  $48 = $23 >>> 1;
  $$lobit = $48 & 1;
  $49 = $$lobit&255;
  HEAP8[$46>>0] = $49;
  $50 = (($finfo) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)!=(0|0);
  $53 = (($47) + 18|0);
  $54 = $52&1;
  HEAP8[$53>>0] = $54;
  $55 = ($51|0)==(0|0);
  if ($55) {
   $actorElementPair$0 = $47;
  } else {
   $56 = (($51) + 8|0);
   HEAP8[$56>>0] = 1;
   $57 = (($51) + 4|0);
   HEAP32[$57>>2] = $47;
   $actorElementPair$0 = $47;
  }
 }
 $58 = (($this) + 2184|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0|0);
 if ($60) {
  $61 = (($this) + 1892|0);
  __ZN5physx6shdfnd8PoolBaseINS_2Sc35ParticleElementRbElementInteractionENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($61);
  $$pre$i$i$i = HEAP32[$58>>2]|0;
  $63 = $$pre$i$i$i;
 } else {
  $63 = $59;
 }
 $62 = HEAP32[$63>>2]|0;
 HEAP32[$58>>2] = $62;
 $64 = (($this) + 2172|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + 1)|0;
 HEAP32[$64>>2] = $66;
 $67 = (($this) + 2176|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 HEAP32[$67>>2] = $69;
 $70 = ($63|0)==(0|0);
 if ($70) {
  $78 = 0;
 } else {
  __ZN5physx2Sc35ParticleElementRbElementInteractionC2ERNS0_19ParticlePacketShapeERNS0_8ShapeSimERNS0_16ActorElementPairE($63,$ps,$s,$actorElementPair$0);
  $71 = (($actorElementPair$0) + 16|0);
  $72 = HEAP16[$71>>1]|0;
  $73 = (($72) + 1)<<16>>16;
  HEAP16[$71>>1] = $73;
  __ZN5physx2Sc35ParticleElementRbElementInteraction10initializeEj($63,$ccdPass);
  $78 = $63;
 }
 $74 = (($actorElementPair$0) + 18|0);
 $75 = HEAP8[$74>>0]|0;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  $$0 = $78;
  STACKTOP = sp;return ($$0|0);
 }
 $77 = (($78) + 6|0);
 $79 = HEAP16[$77>>1]|0;
 $80 = $79&65535;
 $81 = $80 | 4;
 $82 = $81&65535;
 HEAP16[$77>>1] = $82;
 $$0 = $78;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc10NPhaseCore9runFilterERKNS0_10ElementSimES4_PNS0_10FilterPairE($agg$result,$this,$e0,$e1,$filterPair) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $e0 = $e0|0;
 $e1 = $e1|0;
 $filterPair = $filterPair|0;
 var $$0 = 0, $$1 = 0, $$pre = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fa0 = 0, $fa1 = 0, $fd0 = 0, $fd0$byval_copy4 = 0, $fd1 = 0;
 var $fd1$byval_copy5 = 0, $storemerge$i = 0, $storemerge$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $fd1$byval_copy5 = sp;
 $fd0$byval_copy4 = sp + 96|0;
 $0 = sp + 114|0;
 $1 = sp + 80|0;
 $2 = sp + 64|0;
 $fd0 = sp + 48|0;
 $fd1 = sp + 24|0;
 $fa0 = sp + 16|0;
 $fa1 = sp + 40|0;
 $3 = sp + 112|0;
 $4 = $agg$result;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 ;HEAP32[$fd0+0>>2]=0|0;HEAP32[$fd0+4>>2]=0|0;HEAP32[$fd0+8>>2]=0|0;HEAP32[$fd0+12>>2]=0|0;
 ;HEAP32[$fd1+0>>2]=0|0;HEAP32[$fd1+4>>2]=0|0;HEAP32[$fd1+8>>2]=0|0;HEAP32[$fd1+12>>2]=0|0;
 $8 = HEAP32[$e0>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viii[$10 & 4095]($e0,$fa0,$fd0);
 $11 = HEAP32[$e1>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viii[$13 & 4095]($e1,$fa1,$fd1);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 1100|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$fa0>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$fd0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$fd0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$fd0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$fd0+12>>2]|0;
 $18 = HEAP32[$fa1>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$fd1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$fd1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$fd1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$fd1+12>>2]|0;
 $19 = (($agg$result) + 2|0);
 $20 = (($14) + 1092|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($14) + 1096|0);
 $23 = HEAP32[$22>>2]|0;
 ;HEAP32[$fd0$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$fd0$byval_copy4+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$fd0$byval_copy4+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$fd0$byval_copy4+12>>2]=HEAP32[$1+12>>2]|0;
 ;HEAP32[$fd1$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$fd1$byval_copy5+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$fd1$byval_copy5+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$fd1$byval_copy5+12>>2]=HEAP32[$2+12>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$16 & 63]($0,$17,$fd0$byval_copy4,$18,$fd1$byval_copy5,$19,$21,$23);
 $24 = HEAP16[$0>>1]|0;
 HEAP16[$agg$result>>1] = $24;
 $25 = $24&65535;
 $26 = $25 & 4;
 $27 = ($26|0)==(0);
 do {
  if ($27) {
   $$1 = $filterPair;$86 = $24;
  } else {
   $28 = HEAP32[$this>>2]|0;
   $29 = (($28) + 1104|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $82 = $25 & 65523;
    $83 = $82&65535;
    HEAP16[$agg$result>>1] = $83;
    $84 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($84,2,460632,1237,463232,$fd1$byval_copy5);
    $$pre = HEAP16[$agg$result>>1]|0;
    $$1 = $filterPair;$86 = $$pre;
    break;
   }
   $32 = ($filterPair|0)==(0|0);
   if ($32) {
    $33 = (__ZN5physx2Sc10NPhaseCore16createFilterPairEv($this)|0);
    $$0 = $33;
   } else {
    $$0 = $filterPair;
   }
   $34 = (($e0) + 12|0);
   $35 = $34;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $38 = (($35) + 4)|0;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = (_bitshift64Lshr(($37|0),($40|0),30)|0);
   $42 = tempRet0;
   $43 = $41 & 3;
   if ((($43|0) == 1)) {
    $49 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($e0)|0);
    $50 = (__ZNK5physx2Sc17ParticleSystemSim7getCoreEv($49)|0);
    $51 = (__ZN5physx2Sc18ParticleSystemCore17getPxParticleBaseEv($50)|0);
    $78 = $51;$storemerge$i = 0;
   } else if ((($43|0) == 0)) {
    $44 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($e0)|0);
    $45 = (__ZN5physx2Sc8RigidSim10getPxActorEv($44)|0);
    $46 = (($e0) + 28|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (__ZNK5physx2Sc9ShapeCore10getPxShapeEv($47)|0);
    $78 = $45;$storemerge$i = $48;
   } else {
    $78 = 0;$storemerge$i = 0;
   }
   $52 = (($e1) + 12|0);
   $53 = $52;
   $54 = $53;
   $55 = HEAP32[$54>>2]|0;
   $56 = (($53) + 4)|0;
   $57 = $56;
   $58 = HEAP32[$57>>2]|0;
   $59 = (_bitshift64Lshr(($55|0),($58|0),30)|0);
   $60 = tempRet0;
   $61 = $59 & 3;
   if ((($61|0) == 0)) {
    $62 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($e1)|0);
    $63 = (__ZN5physx2Sc8RigidSim10getPxActorEv($62)|0);
    $64 = (($e1) + 28|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (__ZNK5physx2Sc9ShapeCore10getPxShapeEv($65)|0);
    $79 = $63;$storemerge$i2 = $66;
   } else if ((($61|0) == 1)) {
    $67 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($e1)|0);
    $68 = (__ZNK5physx2Sc17ParticleSystemSim7getCoreEv($67)|0);
    $69 = (__ZN5physx2Sc18ParticleSystemCore17getPxParticleBaseEv($68)|0);
    $79 = $69;$storemerge$i2 = 0;
   } else {
    $79 = 0;$storemerge$i2 = 0;
   }
   $70 = HEAP32[$this>>2]|0;
   $71 = (($70) + 1104|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = HEAP32[$72>>2]|0;
   $74 = HEAP32[$73>>2]|0;
   $75 = HEAP32[$$0>>2]|0;
   $76 = HEAP32[$fa0>>2]|0;
   $77 = HEAP32[$fa1>>2]|0;
   ;HEAP32[$fd0$byval_copy4+0>>2]=HEAP32[$fd0+0>>2]|0;HEAP32[$fd0$byval_copy4+4>>2]=HEAP32[$fd0+4>>2]|0;HEAP32[$fd0$byval_copy4+8>>2]=HEAP32[$fd0+8>>2]|0;HEAP32[$fd0$byval_copy4+12>>2]=HEAP32[$fd0+12>>2]|0;
   ;HEAP32[$fd1$byval_copy5+0>>2]=HEAP32[$fd1+0>>2]|0;HEAP32[$fd1$byval_copy5+4>>2]=HEAP32[$fd1+4>>2]|0;HEAP32[$fd1$byval_copy5+8>>2]=HEAP32[$fd1+8>>2]|0;HEAP32[$fd1$byval_copy5+12>>2]=HEAP32[$fd1+12>>2]|0;
   FUNCTION_TABLE_viiiiiiiiiiii[$74 & 3]($3,$72,$75,$76,$fd0$byval_copy4,$78,$storemerge$i,$77,$fd1$byval_copy5,$79,$storemerge$i2,$19);
   $80 = HEAP16[$3>>1]|0;
   HEAP16[$agg$result>>1] = $80;
   $81 = (($agg$result) + 4|0);
   HEAP32[$81>>2] = $$0;
   $$1 = $$0;$86 = $80;
  }
 } while(0);
 $85 = $86 & 3;
 $87 = ($85<<16>>16)==(3);
 if ($87) {
  $88 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($88,2,460632,882,463144,$fd1$byval_copy5);
  $89 = $86&65535;
  $90 = $89 & 65534;
  $91 = $90&65535;
  $92 = $91;
 } else {
  $92 = $86;
 }
 HEAP16[$agg$result>>1] = $92;
 $93 = ($$1|0)==(0|0);
 if ($93) {
  STACKTOP = sp;return;
 }
 $94 = $92 & 13;
 if ((($94<<16>>16) == 12)) {
  STACKTOP = sp;return;
 } else if ((($94<<16>>16) == 13)) {
  $95 = HEAP32[$this>>2]|0;
  $96 = (($95) + 1104|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = HEAP32[$97>>2]|0;
  $99 = (($98) + 4|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = HEAP32[$$1>>2]|0;
  $102 = HEAP32[$fa0>>2]|0;
  $103 = HEAP32[$fa1>>2]|0;
  ;HEAP32[$fd0$byval_copy4+0>>2]=HEAP32[$fd0+0>>2]|0;HEAP32[$fd0$byval_copy4+4>>2]=HEAP32[$fd0+4>>2]|0;HEAP32[$fd0$byval_copy4+8>>2]=HEAP32[$fd0+8>>2]|0;HEAP32[$fd0$byval_copy4+12>>2]=HEAP32[$fd0+12>>2]|0;
  ;HEAP32[$fd1$byval_copy5+0>>2]=HEAP32[$fd1+0>>2]|0;HEAP32[$fd1$byval_copy5+4>>2]=HEAP32[$fd1+4>>2]|0;HEAP32[$fd1$byval_copy5+8>>2]=HEAP32[$fd1+8>>2]|0;HEAP32[$fd1$byval_copy5+12>>2]=HEAP32[$fd1+12>>2]|0;
  FUNCTION_TABLE_viiiiiii[$100 & 127]($97,$101,$102,$fd0$byval_copy4,$103,$fd1$byval_copy5,0);
  $$pre14 = HEAP16[$agg$result>>1]|0;
  $105 = $$pre14;
 } else {
  $105 = $92;
 }
 $104 = $105&65535;
 $106 = $104 & 12;
 $107 = ($106|0)==(12);
 if (!($107)) {
  $108 = $104 & 65523;
  $109 = $108&65535;
  HEAP16[$agg$result>>1] = $109;
 }
 __ZN5physx2Sc10NPhaseCore16deleteFilterPairEPNS0_10FilterPairE($this,$$1);
 $110 = (($agg$result) + 4|0);
 HEAP32[$110>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore26createRbElementInteractionERNS0_8ShapeSimES3_($this,$s0,$s1) {
 $this = $this|0;
 $s0 = $s0|0;
 $s1 = $s1|0;
 var $$0 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $finfo = 0;
 var $pair$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $finfo = sp;
 $0 = sp + 10|0;
 $1 = sp + 8|0;
 __ZN5physx2Sc10NPhaseCore21filterRbCollisionPairERKNS0_8ShapeSimES4_PNS0_10FilterPairE($finfo,$this,$s0,$s1,0);
 $2 = HEAP32[$finfo>>2]|0;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 $5 = $2 >>> 16;
 $6 = $5&65535;
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = $2 & 2;
 $8 = ($7|0)==(0);
 do {
  if ($8) {
   $9 = (($s0) + 28|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 64|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = $12 & 4;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $15 = (($s1) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + 64|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18 & 4;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     HEAP16[$0>>1] = $6;
     $21 = (__ZN5physx2Sc10NPhaseCore25createShapeInstancePairLLERNS0_8ShapeSimES3_NS_7PxFlagsINS_10PxPairFlag4EnumEtEE($this,$s0,$s1,$0)|0);
     $pair$0 = $21;
     break;
    }
   }
   HEAP16[$1>>1] = $6;
   $22 = (__ZN5physx2Sc10NPhaseCore24createTriggerInteractionERNS0_8ShapeSimES3_NS_7PxFlagsINS_10PxPairFlag4EnumEtEE($this,$s0,$s1,$1)|0);
   $pair$0 = $22;
  } else {
   $23 = (($this) + 1888|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    $26 = (($this) + 1596|0);
    __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($26);
    $$pre$i$i$i = HEAP32[$23>>2]|0;
    $28 = $$pre$i$i$i;
   } else {
    $28 = $24;
   }
   $27 = HEAP32[$28>>2]|0;
   HEAP32[$23>>2] = $27;
   $29 = (($this) + 1876|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 1)|0;
   HEAP32[$29>>2] = $31;
   $32 = (($this) + 1880|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   HEAP32[$32>>2] = $34;
   $35 = ($28|0)==(0|0);
   if ($35) {
    $46 = 0;
   } else {
    HEAP32[$28>>2] = ((463024 + 8|0));
    $36 = (($28) + 4|0);
    HEAP16[$36>>1] = -1;
    $37 = (($28) + 6|0);
    HEAP16[$37>>1] = 1;
    $38 = (($28) + 8|0);
    $39 = (($s0) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($s1) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    __ZN5physx2Sc11InteractionC2ERNS0_5ActorES3_NS0_15InteractionTypeEh($38,$40,$42,3,5);
    $43 = (($28) + 32|0);
    HEAP32[$43>>2] = $s0;
    $44 = (($28) + 36|0);
    HEAP32[$44>>2] = $s1;
    HEAP32[$28>>2] = ((460552 + 8|0));
    $45 = (($28) + 8|0);
    HEAP32[$45>>2] = ((460552 + 52|0));
    $46 = $28;
   }
   __ZN5physx2Sc24ElementInteractionMarker10initializeEv($46);
   $pair$0 = $46;
  }
 } while(0);
 $47 = (($finfo) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  $$0 = $pair$0;
  STACKTOP = sp;return ($$0|0);
 }
 $50 = (($pair$0) + 6|0);
 $51 = HEAP16[$50>>1]|0;
 $52 = $51&65535;
 $53 = $52 | 4;
 $54 = $53&65535;
 HEAP16[$50>>1] = $54;
 $55 = (($48) + 8|0);
 HEAP8[$55>>0] = 0;
 $56 = (($48) + 4|0);
 HEAP32[$56>>2] = $pair$0;
 $$0 = $pair$0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc10NPhaseCore16onOverlapCreatedEPKNS_20PxvBroadPhaseOverlapEjj($this,$pairs,$pairCount,$ccdPass) {
 $this = $this|0;
 $pairs = $pairs|0;
 $pairCount = $pairCount|0;
 $ccdPass = $ccdPass|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx10 = 0, $$idx10$val = 0, $$idx11 = 0, $$idx11$val = 0, $$idx12 = 0, $$idx12$val = 0, $$idx13 = 0, $$idx13$val = 0, $$idx14 = 0, $$idx14$val = 0, $$idx15 = 0, $$idx15$val = 0, $$idx16 = 0, $$idx16$val = 0, $$idx17 = 0, $$idx17$val = 0;
 var $$idx18 = 0, $$idx18$val = 0, $$idx19 = 0, $$idx19$val = 0, $$idx2 = 0, $$idx2$val = 0, $$idx20 = 0, $$idx20$val = 0, $$idx21 = 0, $$idx21$val = 0, $$idx22 = 0, $$idx22$val = 0, $$idx23 = 0, $$idx23$val = 0, $$idx24 = 0, $$idx24$val = 0, $$idx25 = 0, $$idx25$val = 0, $$idx26 = 0, $$idx26$val = 0;
 var $$idx27 = 0, $$idx27$val = 0, $$idx28 = 0, $$idx28$val = 0, $$idx29 = 0, $$idx29$val = 0, $$idx3 = 0, $$idx3$val = 0, $$idx30 = 0, $$idx30$val = 0, $$idx31 = 0, $$idx31$val = 0, $$idx32 = 0, $$idx32$val = 0, $$idx33 = 0, $$idx33$val = 0, $$idx34 = 0, $$idx34$val = 0, $$idx4 = 0, $$idx4$val = 0;
 var $$idx5 = 0, $$idx5$val = 0, $$idx6 = 0, $$idx6$val = 0, $$idx7 = 0, $$idx7$val = 0, $$idx8 = 0, $$idx8$val = 0, $$idx9 = 0, $$idx9$val = 0, $$sum40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $batchedActorIdx$057 = 0, $batchedActors = 0, $batchedElementIdx$043 = 0, $batchedElementIdx1$048 = 0, $batchedElementIdx3$052 = 0, $batchedElements = 0, $exitcond = 0, $exitcond64 = 0, $exitcond65 = 0, $exitcond66 = 0, $exitcond67 = 0, $i$061 = 0, $i6$041 = 0, $k$044 = 0;
 var $k2$049 = 0, $k4$053 = 0, $k5$058 = 0, $pairIdx$0$lcssa = 0, $pairIdx$060 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $batchedElements = sp + 32|0;
 $batchedActors = sp;
 $0 = $pairCount >>> 2;
 $1 = ($0|0)==(0);
 if ($1) {
  $pairIdx$0$lcssa = 0;
 } else {
  $2 = (($0) + -1)|0;
  $3 = (($batchedElements) + 4|0);
  $4 = (($batchedElements) + 8|0);
  $5 = (($batchedElements) + 12|0);
  $6 = (($batchedElements) + 16|0);
  $7 = (($batchedElements) + 20|0);
  $8 = (($batchedElements) + 24|0);
  $9 = (($batchedElements) + 28|0);
  $10 = (($batchedActors) + 4|0);
  $11 = (($batchedActors) + 8|0);
  $12 = (($batchedActors) + 12|0);
  $13 = (($batchedActors) + 16|0);
  $14 = (($batchedActors) + 20|0);
  $15 = (($batchedActors) + 24|0);
  $16 = (($batchedActors) + 28|0);
  $i$061 = 0;$pairIdx$060 = 0;
  while(1) {
   $19 = ($i$061>>>0)<($2>>>0);
   $20 = (($pairIdx$060) + 4)|0;
   if ($19) {
    $$idx8 = (($pairs) + ($20<<3)|0);
    $$idx8$val = HEAP32[$$idx8>>2]|0;
    $$idx9 = ((($pairs) + ($20<<3)|0) + 4|0);
    $$idx9$val = HEAP32[$$idx9>>2]|0;
    HEAP32[$batchedElements>>2] = $$idx8$val;
    HEAP32[$3>>2] = $$idx9$val;
    $22 = (($pairIdx$060) + 5)|0;
    $$idx6 = (($pairs) + ($22<<3)|0);
    $$idx6$val = HEAP32[$$idx6>>2]|0;
    $$idx7 = ((($pairs) + ($22<<3)|0) + 4|0);
    $$idx7$val = HEAP32[$$idx7>>2]|0;
    HEAP32[$4>>2] = $$idx6$val;
    HEAP32[$5>>2] = $$idx7$val;
    $23 = (($pairIdx$060) + 6)|0;
    $$idx4 = (($pairs) + ($23<<3)|0);
    $$idx4$val = HEAP32[$$idx4>>2]|0;
    $$idx5 = ((($pairs) + ($23<<3)|0) + 4|0);
    $$idx5$val = HEAP32[$$idx5>>2]|0;
    HEAP32[$6>>2] = $$idx4$val;
    HEAP32[$7>>2] = $$idx5$val;
    $24 = (($pairIdx$060) + 7)|0;
    $$idx2 = (($pairs) + ($24<<3)|0);
    $$idx2$val = HEAP32[$$idx2>>2]|0;
    $$idx3 = ((($pairs) + ($24<<3)|0) + 4|0);
    $$idx3$val = HEAP32[$$idx3>>2]|0;
    HEAP32[$8>>2] = $$idx2$val;
    HEAP32[$9>>2] = $$idx3$val;
   } else {
    $21 = ($20>>>0)<($pairCount>>>0);
    if ($21) {
     $batchedElementIdx$043 = 0;$k$044 = $20;
     while(1) {
      $25 = (($batchedElements) + ($batchedElementIdx$043<<2)|0);
      $$idx = (($pairs) + ($k$044<<3)|0);
      $$idx$val = HEAP32[$$idx>>2]|0;
      $$idx1 = ((($pairs) + ($k$044<<3)|0) + 4|0);
      $$idx1$val = HEAP32[$$idx1>>2]|0;
      HEAP32[$25>>2] = $$idx$val;
      $$sum40 = $batchedElementIdx$043 | 1;
      $26 = (($batchedElements) + ($$sum40<<2)|0);
      HEAP32[$26>>2] = $$idx1$val;
      $27 = (($batchedElementIdx$043) + 2)|0;
      $28 = (($k$044) + 1)|0;
      $exitcond64 = ($28|0)==($pairCount|0);
      if ($exitcond64) {
       break;
      } else {
       $batchedElementIdx$043 = $27;$k$044 = $28;
      }
     }
    }
   }
   $$idx18 = (($pairs) + ($pairIdx$060<<3)|0);
   $$idx18$val = HEAP32[$$idx18>>2]|0;
   $$idx19 = ((($pairs) + ($pairIdx$060<<3)|0) + 4|0);
   $$idx19$val = HEAP32[$$idx19>>2]|0;
   __ZN5physx2Sc10NPhaseCore16onOverlapCreatedEPNS0_7ElementES3_j($this,$$idx18$val,$$idx19$val,$ccdPass);
   L11: do {
    if ($19) {
     $30 = HEAP32[$batchedElements>>2]|0;
     $31 = HEAP32[$3>>2]|0;
     $$idx28 = (($30) + 8|0);
     $$idx28$val = HEAP32[$$idx28>>2]|0;
     $$idx29 = (($31) + 8|0);
     $$idx29$val = HEAP32[$$idx29>>2]|0;
     $32 = (($$idx28$val) + 128|0);
     $33 = (($$idx29$val) + 128|0);
     HEAP32[$batchedActors>>2] = $$idx28$val;
     HEAP32[$10>>2] = $$idx29$val;
     $34 = HEAP32[$4>>2]|0;
     $35 = HEAP32[$5>>2]|0;
     $$idx26 = (($34) + 8|0);
     $$idx26$val = HEAP32[$$idx26>>2]|0;
     $$idx27 = (($35) + 8|0);
     $$idx27$val = HEAP32[$$idx27>>2]|0;
     $36 = (($$idx26$val) + 128|0);
     $37 = (($$idx27$val) + 128|0);
     HEAP32[$11>>2] = $$idx26$val;
     HEAP32[$12>>2] = $$idx27$val;
     $38 = HEAP32[$6>>2]|0;
     $39 = HEAP32[$7>>2]|0;
     $$idx24 = (($38) + 8|0);
     $$idx24$val = HEAP32[$$idx24>>2]|0;
     $$idx25 = (($39) + 8|0);
     $$idx25$val = HEAP32[$$idx25>>2]|0;
     $40 = (($$idx24$val) + 128|0);
     $41 = (($$idx25$val) + 128|0);
     HEAP32[$13>>2] = $$idx24$val;
     HEAP32[$14>>2] = $$idx25$val;
     $42 = HEAP32[$8>>2]|0;
     $43 = HEAP32[$9>>2]|0;
     $$idx22 = (($42) + 8|0);
     $$idx22$val = HEAP32[$$idx22>>2]|0;
     $$idx23 = (($43) + 8|0);
     $$idx23$val = HEAP32[$$idx23>>2]|0;
     $44 = (($$idx22$val) + 128|0);
     $45 = (($$idx23$val) + 128|0);
     HEAP32[$15>>2] = $$idx22$val;
     HEAP32[$16>>2] = $$idx23$val;
    } else {
     $29 = ($20>>>0)<($pairCount>>>0);
     if ($29) {
      $batchedElementIdx1$048 = 0;$k2$049 = $20;
      while(1) {
       $46 = (($batchedElements) + ($batchedElementIdx1$048<<2)|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = $batchedElementIdx1$048 | 1;
       $49 = (($batchedElements) + ($48<<2)|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = (($batchedActors) + ($batchedElementIdx1$048<<2)|0);
       $$idx20 = (($47) + 8|0);
       $$idx20$val = HEAP32[$$idx20>>2]|0;
       $$idx21 = (($50) + 8|0);
       $$idx21$val = HEAP32[$$idx21>>2]|0;
       $52 = (($$idx20$val) + 128|0);
       $53 = (($$idx21$val) + 128|0);
       HEAP32[$51>>2] = $$idx20$val;
       $54 = (($batchedActors) + ($48<<2)|0);
       HEAP32[$54>>2] = $$idx21$val;
       $55 = (($k2$049) + 1)|0;
       $exitcond65 = ($55|0)==($pairCount|0);
       if ($exitcond65) {
        break L11;
       }
       $56 = (($batchedElementIdx1$048) + 2)|0;
       $batchedElementIdx1$048 = $56;$k2$049 = $55;
      }
     }
    }
   } while(0);
   $57 = $pairIdx$060 | 1;
   $$idx16 = (($pairs) + ($57<<3)|0);
   $$idx16$val = HEAP32[$$idx16>>2]|0;
   $$idx17 = ((($pairs) + ($57<<3)|0) + 4|0);
   $$idx17$val = HEAP32[$$idx17>>2]|0;
   __ZN5physx2Sc10NPhaseCore16onOverlapCreatedEPNS0_7ElementES3_j($this,$$idx16$val,$$idx17$val,$ccdPass);
   L18: do {
    if ($19) {
     $59 = HEAP32[$batchedElements>>2]|0;
     $60 = HEAP32[$3>>2]|0;
     $61 = (($59) + 12|0);
     $62 = $61;
     $63 = $62;
     $64 = HEAP32[$63>>2]|0;
     $65 = (($62) + 4)|0;
     $66 = $65;
     $67 = HEAP32[$66>>2]|0;
     $68 = $64 & -1073741824;
     $69 = ($68|0)==(0);
     $70 = (0)==(0);
     $71 = $69 & $70;
     if ($71) {
      $72 = (($59) + 28|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($73) + 128|0);
     }
     $75 = (($60) + 12|0);
     $76 = $75;
     $77 = $76;
     $78 = HEAP32[$77>>2]|0;
     $79 = (($76) + 4)|0;
     $80 = $79;
     $81 = HEAP32[$80>>2]|0;
     $82 = $78 & -1073741824;
     $83 = ($82|0)==(0);
     $84 = (0)==(0);
     $85 = $83 & $84;
     if ($85) {
      $86 = (($60) + 28|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = (($87) + 128|0);
     }
     $89 = HEAP32[$4>>2]|0;
     $90 = HEAP32[$5>>2]|0;
     $91 = (($89) + 12|0);
     $92 = $91;
     $93 = $92;
     $94 = HEAP32[$93>>2]|0;
     $95 = (($92) + 4)|0;
     $96 = $95;
     $97 = HEAP32[$96>>2]|0;
     $98 = $94 & -1073741824;
     $99 = ($98|0)==(0);
     $100 = (0)==(0);
     $101 = $99 & $100;
     if ($101) {
      $102 = (($89) + 28|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = (($103) + 128|0);
     }
     $105 = (($90) + 12|0);
     $106 = $105;
     $107 = $106;
     $108 = HEAP32[$107>>2]|0;
     $109 = (($106) + 4)|0;
     $110 = $109;
     $111 = HEAP32[$110>>2]|0;
     $112 = $108 & -1073741824;
     $113 = ($112|0)==(0);
     $114 = (0)==(0);
     $115 = $113 & $114;
     if ($115) {
      $116 = (($90) + 28|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = (($117) + 128|0);
     }
     $119 = HEAP32[$6>>2]|0;
     $120 = HEAP32[$7>>2]|0;
     $121 = (($119) + 12|0);
     $122 = $121;
     $123 = $122;
     $124 = HEAP32[$123>>2]|0;
     $125 = (($122) + 4)|0;
     $126 = $125;
     $127 = HEAP32[$126>>2]|0;
     $128 = $124 & -1073741824;
     $129 = ($128|0)==(0);
     $130 = (0)==(0);
     $131 = $129 & $130;
     if ($131) {
      $132 = (($119) + 28|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = (($133) + 128|0);
     }
     $135 = (($120) + 12|0);
     $136 = $135;
     $137 = $136;
     $138 = HEAP32[$137>>2]|0;
     $139 = (($136) + 4)|0;
     $140 = $139;
     $141 = HEAP32[$140>>2]|0;
     $142 = $138 & -1073741824;
     $143 = ($142|0)==(0);
     $144 = (0)==(0);
     $145 = $143 & $144;
     if ($145) {
      $146 = (($120) + 28|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = (($147) + 128|0);
     }
     $149 = HEAP32[$8>>2]|0;
     $150 = HEAP32[$9>>2]|0;
     $151 = (($149) + 12|0);
     $152 = $151;
     $153 = $152;
     $154 = HEAP32[$153>>2]|0;
     $155 = (($152) + 4)|0;
     $156 = $155;
     $157 = HEAP32[$156>>2]|0;
     $158 = $154 & -1073741824;
     $159 = ($158|0)==(0);
     $160 = (0)==(0);
     $161 = $159 & $160;
     if ($161) {
      $162 = (($149) + 28|0);
      $163 = HEAP32[$162>>2]|0;
      $164 = (($163) + 128|0);
     }
     $165 = (($150) + 12|0);
     $166 = $165;
     $167 = $166;
     $168 = HEAP32[$167>>2]|0;
     $169 = (($166) + 4)|0;
     $170 = $169;
     $171 = HEAP32[$170>>2]|0;
     $172 = $168 & -1073741824;
     $173 = ($172|0)==(0);
     $174 = (0)==(0);
     $175 = $173 & $174;
     if ($175) {
      $176 = (($150) + 28|0);
      $177 = HEAP32[$176>>2]|0;
      $178 = (($177) + 128|0);
     }
    } else {
     $58 = ($20>>>0)<($pairCount>>>0);
     if ($58) {
      $batchedElementIdx3$052 = 0;$k4$053 = $20;
      while(1) {
       $179 = (($batchedElements) + ($batchedElementIdx3$052<<2)|0);
       $180 = HEAP32[$179>>2]|0;
       $181 = $batchedElementIdx3$052 | 1;
       $182 = (($batchedElements) + ($181<<2)|0);
       $183 = HEAP32[$182>>2]|0;
       $184 = (($180) + 12|0);
       $185 = $184;
       $186 = $185;
       $187 = HEAP32[$186>>2]|0;
       $188 = (($185) + 4)|0;
       $189 = $188;
       $190 = HEAP32[$189>>2]|0;
       $191 = $187 & -1073741824;
       $192 = ($191|0)==(0);
       $193 = (0)==(0);
       $194 = $192 & $193;
       if ($194) {
        $195 = (($180) + 28|0);
        $196 = HEAP32[$195>>2]|0;
        $197 = (($196) + 128|0);
       }
       $198 = (($183) + 12|0);
       $199 = $198;
       $200 = $199;
       $201 = HEAP32[$200>>2]|0;
       $202 = (($199) + 4)|0;
       $203 = $202;
       $204 = HEAP32[$203>>2]|0;
       $205 = $201 & -1073741824;
       $206 = ($205|0)==(0);
       $207 = (0)==(0);
       $208 = $206 & $207;
       if ($208) {
        $209 = (($183) + 28|0);
        $210 = HEAP32[$209>>2]|0;
        $211 = (($210) + 128|0);
       }
       $212 = (($k4$053) + 1)|0;
       $exitcond66 = ($212|0)==($pairCount|0);
       if ($exitcond66) {
        break L18;
       }
       $213 = (($batchedElementIdx3$052) + 2)|0;
       $batchedElementIdx3$052 = $213;$k4$053 = $212;
      }
     }
    }
   } while(0);
   $214 = $pairIdx$060 | 2;
   $$idx14 = (($pairs) + ($214<<3)|0);
   $$idx14$val = HEAP32[$$idx14>>2]|0;
   $$idx15 = ((($pairs) + ($214<<3)|0) + 4|0);
   $$idx15$val = HEAP32[$$idx15>>2]|0;
   __ZN5physx2Sc10NPhaseCore16onOverlapCreatedEPNS0_7ElementES3_j($this,$$idx14$val,$$idx15$val,$ccdPass);
   L53: do {
    if ($19) {
     $216 = HEAP32[$batchedActors>>2]|0;
     $217 = HEAP32[$10>>2]|0;
     $$idx34 = (($216) + 52|0);
     $$idx34$val = HEAP32[$$idx34>>2]|0;
     $218 = (($$idx34$val) + 128|0);
     $219 = (($217) + 52|0);
     $220 = HEAP32[$219>>2]|0;
     $221 = (($220) + 128|0);
     $222 = HEAP32[$11>>2]|0;
     $223 = HEAP32[$12>>2]|0;
     $$idx33 = (($222) + 52|0);
     $$idx33$val = HEAP32[$$idx33>>2]|0;
     $224 = (($$idx33$val) + 128|0);
     $225 = (($223) + 52|0);
     $226 = HEAP32[$225>>2]|0;
     $227 = (($226) + 128|0);
     $228 = HEAP32[$13>>2]|0;
     $229 = HEAP32[$14>>2]|0;
     $$idx32 = (($228) + 52|0);
     $$idx32$val = HEAP32[$$idx32>>2]|0;
     $230 = (($$idx32$val) + 128|0);
     $231 = (($229) + 52|0);
     $232 = HEAP32[$231>>2]|0;
     $233 = (($232) + 128|0);
     $234 = HEAP32[$15>>2]|0;
     $235 = HEAP32[$16>>2]|0;
     $$idx31 = (($234) + 52|0);
     $$idx31$val = HEAP32[$$idx31>>2]|0;
     $236 = (($$idx31$val) + 128|0);
     $237 = (($235) + 52|0);
     $238 = HEAP32[$237>>2]|0;
     $239 = (($238) + 128|0);
    } else {
     $215 = ($20>>>0)<($pairCount>>>0);
     if ($215) {
      $batchedActorIdx$057 = 0;$k5$058 = $20;
      while(1) {
       $240 = (($batchedActors) + ($batchedActorIdx$057<<2)|0);
       $241 = HEAP32[$240>>2]|0;
       $242 = $batchedActorIdx$057 | 1;
       $243 = (($batchedActors) + ($242<<2)|0);
       $244 = HEAP32[$243>>2]|0;
       $$idx30 = (($241) + 52|0);
       $$idx30$val = HEAP32[$$idx30>>2]|0;
       $245 = (($$idx30$val) + 128|0);
       $246 = (($244) + 52|0);
       $247 = HEAP32[$246>>2]|0;
       $248 = (($247) + 128|0);
       $249 = (($k5$058) + 1)|0;
       $exitcond67 = ($249|0)==($pairCount|0);
       if ($exitcond67) {
        break L53;
       }
       $250 = (($batchedActorIdx$057) + 2)|0;
       $batchedActorIdx$057 = $250;$k5$058 = $249;
      }
     }
    }
   } while(0);
   $251 = $pairIdx$060 | 3;
   $$idx12 = (($pairs) + ($251<<3)|0);
   $$idx12$val = HEAP32[$$idx12>>2]|0;
   $$idx13 = ((($pairs) + ($251<<3)|0) + 4|0);
   $$idx13$val = HEAP32[$$idx13>>2]|0;
   __ZN5physx2Sc10NPhaseCore16onOverlapCreatedEPNS0_7ElementES3_j($this,$$idx12$val,$$idx13$val,$ccdPass);
   $252 = (($i$061) + 1)|0;
   $253 = ($252>>>0)<($0>>>0);
   if ($253) {
    $i$061 = $252;$pairIdx$060 = $20;
   } else {
    break;
   }
  }
  $17 = $0 << 2;
  $pairIdx$0$lcssa = $17;
 }
 $18 = ($pairIdx$0$lcssa>>>0)<($pairCount>>>0);
 if ($18) {
  $i6$041 = $pairIdx$0$lcssa;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $$idx10 = (($pairs) + ($i6$041<<3)|0);
  $$idx10$val = HEAP32[$$idx10>>2]|0;
  $$idx11 = ((($pairs) + ($i6$041<<3)|0) + 4|0);
  $$idx11$val = HEAP32[$$idx11>>2]|0;
  __ZN5physx2Sc10NPhaseCore16onOverlapCreatedEPNS0_7ElementES3_j($this,$$idx10$val,$$idx11$val,$ccdPass);
  $254 = (($i6$041) + 1)|0;
  $exitcond = ($254|0)==($pairCount|0);
  if ($exitcond) {
   break;
  } else {
   $i6$041 = $254;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore16onOverlapRemovedEPNS0_7ElementES3_j($this,$volume0,$volume1,$ccdPass) {
 $this = $this|0;
 $volume0 = $volume0|0;
 $volume1 = $volume1|0;
 $ccdPass = $ccdPass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $_element0$_element1$i = 0, $_element1$_element0$i = 0, $interaction$01$i = 0, $iter$i = 0, $volume0$volume1 = 0;
 var $volume1$volume0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter$i = sp;
 $0 = (($volume1) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($volume0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($3>>>0)<($7>>>0);
 $_element0$_element1$i = $8 ? $volume1 : $volume0;
 $_element1$_element0$i = $8 ? $volume0 : $volume1;
 $9 = (($_element0$_element1$i) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + ($14<<2)|0);
 $16 = $12;
 $17 = $15;
 $18 = $iter$i;
 $19 = $18;
 HEAP32[$19>>2] = $16;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 $22 = (($iter$i) + 8|0);
 HEAP32[$22>>2] = $_element0$_element1$i;
 $23 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter$i)|0);
 $24 = ($23|0)==(0|0);
 L1: do {
  if (!($24)) {
   $interaction$01$i = $23;
   while(1) {
    $25 = (($interaction$01$i) + 24|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==($_element1$_element0$i|0);
    if ($27) {
     break;
    }
    $28 = (($interaction$01$i) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==($_element1$_element0$i|0);
    if ($30) {
     label = 5;
     break;
    }
    $31 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter$i)|0);
    $32 = ($31|0)==(0|0);
    if ($32) {
     break L1;
    } else {
     $interaction$01$i = $31;
    }
   }
   if ((label|0) == 5) {
    $33 = ($interaction$01$i|0)==(0|0);
    if ($33) {
     break;
    }
   }
   $34 = (($interaction$01$i) + -8|0);
   __ZN5physx2Sc10NPhaseCore18releaseElementPairEPNS0_21ElementSimInteractionEjj($this,$34,4,$ccdPass);
  }
 } while(0);
 $35 = (($volume0) + 12|0);
 $36 = $35;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $38 & -1073741824;
 $43 = ($42|0)==(-2147483648);
 $44 = (0)==(0);
 $45 = $43 & $44;
 $volume0$volume1 = $45 ? $volume0 : $volume1;
 $volume1$volume0 = $45 ? $volume1 : $volume0;
 $46 = (($volume0$volume1) + 12|0);
 $47 = $46;
 $48 = $47;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($47) + 4)|0;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = $49 & -1073741824;
 $54 = ($53|0)==(-2147483648);
 $55 = (0)==(0);
 $56 = $54 & $55;
 if (!($56)) {
  STACKTOP = sp;return;
 }
 $57 = (($volume1$volume0) + 12|0);
 $58 = $57;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = (($58) + 4)|0;
 $62 = $61;
 $63 = HEAP32[$62>>2]|0;
 $64 = $60 & -1073741824;
 $65 = ($64|0)==(0);
 $66 = (0)==(0);
 $67 = $65 & $66;
 if (!($67)) {
  STACKTOP = sp;return;
 }
 $68 = (($volume0$volume1) + 20|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (__ZNK5physx2Sc9ClothCore6getSimEv($69)|0);
 $71 = (($volume1$volume0) + 28|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + 68|0);
 $74 = HEAP32[$73>>2]|0;
 switch ($74|0) {
 case 2:  {
  __ZN5physx2Sc8ClothSim22removeCollisionCapsuleEPKNS0_8ShapeSimE($70,$volume1$volume0);
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  __ZN5physx2Sc8ClothSim21removeCollisionSphereEPKNS0_8ShapeSimE($70,$volume1$volume0);
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  __ZN5physx2Sc8ClothSim19removeCollisionMeshEPKNS0_8ShapeSimE($70,$volume1$volume0);
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  __ZN5physx2Sc8ClothSim21removeCollisionConvexEPKNS0_8ShapeSimE($70,$volume1$volume0);
  STACKTOP = sp;return;
  break;
 }
 case 3:  {
  __ZN5physx2Sc8ClothSim18removeCollisionBoxEPKNS0_8ShapeSimE($70,$volume1$volume0);
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  __ZN5physx2Sc8ClothSim20removeCollisionPlaneEPKNS0_8ShapeSimE($70,$volume1$volume0);
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  __ZN5physx2Sc8ClothSim26removeCollisionHeightfieldEPKNS0_8ShapeSimE($70,$volume1$volume0);
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZN5physx2Sc10NPhaseCore18releaseElementPairEPNS0_21ElementSimInteractionEjj($this,$pair,$flags,$ccdPass) {
 $this = $this|0;
 $pair = $pair|0;
 $flags = $flags|0;
 $ccdPass = $ccdPass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $fa0$i = 0, $fa1$i = 0, $fd0$i = 0, $fd0$i$byval_copy = 0, $fd1$i = 0, $fd1$i$byval_copy = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $fd1$i$byval_copy = sp + 56|0;
 $fd0$i$byval_copy = sp;
 $fd0$i = sp + 16|0;
 $fd1$i = sp + 32|0;
 $fa0$i = sp + 48|0;
 $fa1$i = sp + 52|0;
 $0 = (($pair) + 6|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  $9 = $1;
 } else {
  __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($pair);
  $4 = HEAP16[$0>>1]|0;
  $5 = $4&65535;
  $6 = $5 & 65533;
  $7 = $6&65535;
  HEAP16[$0>>1] = $7;
  $9 = $7;
 }
 $8 = $9 & 4;
 $10 = ($8<<16>>16)==(0);
 if (!($10)) {
  $11 = HEAP32[$pair>>2]|0;
  $12 = (($11) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 4095]($pair)|0);
  if ($14) {
   $15 = (__ZN5physx2Sc10NPhaseCore15fetchFilterPairEPv($this,$pair)|0);
   $16 = $flags & 1;
   $17 = ($16|0)!=(0);
   $18 = (($pair) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($pair) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$15>>2]|0;
   ;HEAP32[$fd0$i+0>>2]=0|0;HEAP32[$fd0$i+4>>2]=0|0;HEAP32[$fd0$i+8>>2]=0|0;HEAP32[$fd0$i+12>>2]=0|0;
   ;HEAP32[$fd1$i+0>>2]=0|0;HEAP32[$fd1$i+4>>2]=0|0;HEAP32[$fd1$i+8>>2]=0|0;HEAP32[$fd1$i+12>>2]=0|0;
   $23 = HEAP32[$19>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_viii[$25 & 4095]($19,$fa0$i,$fd0$i);
   $26 = HEAP32[$21>>2]|0;
   $27 = (($26) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   FUNCTION_TABLE_viii[$28 & 4095]($21,$fa1$i,$fd1$i);
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 1104|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$fa0$i>>2]|0;
   $36 = HEAP32[$fa1$i>>2]|0;
   ;HEAP32[$fd0$i$byval_copy+0>>2]=HEAP32[$fd0$i+0>>2]|0;HEAP32[$fd0$i$byval_copy+4>>2]=HEAP32[$fd0$i+4>>2]|0;HEAP32[$fd0$i$byval_copy+8>>2]=HEAP32[$fd0$i+8>>2]|0;HEAP32[$fd0$i$byval_copy+12>>2]=HEAP32[$fd0$i+12>>2]|0;
   ;HEAP32[$fd1$i$byval_copy+0>>2]=HEAP32[$fd1$i+0>>2]|0;HEAP32[$fd1$i$byval_copy+4>>2]=HEAP32[$fd1$i+4>>2]|0;HEAP32[$fd1$i$byval_copy+8>>2]=HEAP32[$fd1$i+8>>2]|0;HEAP32[$fd1$i$byval_copy+12>>2]=HEAP32[$fd1$i+12>>2]|0;
   FUNCTION_TABLE_viiiiiii[$34 & 127]($31,$22,$35,$fd0$i$byval_copy,$36,$fd1$i$byval_copy,$17);
   __ZN5physx2Sc10NPhaseCore16deleteFilterPairEPNS0_10FilterPairE($this,$15);
  }
 }
 $37 = (($pair) + 28|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = $38&255;
 if ((($39|0) == 2)) {
  $40 = $flags & 1;
  $41 = ($40|0)!=(0);
  __ZN5physx2Sc10NPhaseCore19findTriggerContactsEPNS0_18TriggerInteractionEbb($this,$pair,1,$41);
  __ZN5physx2Sc18TriggerInteraction7destroyEv($pair);
  $42 = (($this) + 1004|0);
  $43 = ($pair|0)==(0|0);
  if ($43) {
   STACKTOP = sp;return;
  }
  $44 = HEAP32[$pair>>2]|0;
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vi[$45 & 4095]($pair);
  $46 = (($this) + 1284|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + -1)|0;
  HEAP32[$46>>2] = $48;
  $49 = (($this) + 1296|0);
  $50 = HEAP32[$49>>2]|0;
  HEAP32[$pair>>2] = $50;
  HEAP32[$49>>2] = $pair;
  $51 = (($this) + 1288|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + 1)|0;
  HEAP32[$51>>2] = $53;
  $54 = (($this) + 1280|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55*50)|0;
  $57 = ($52|0)<($56|0);
  if ($57) {
   STACKTOP = sp;return;
  }
  __ZN5physx6shdfnd8PoolBaseINS_2Sc18TriggerInteractionENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($42);
  HEAP32[$51>>2] = 0;
  STACKTOP = sp;return;
 } else if ((($39|0) == 0)) {
  __ZN5physx2Sc10NPhaseCore24releaseShapeInstancePairEPNS0_19ShapeInstancePairLLEjj($this,$pair,$flags,$ccdPass);
  STACKTOP = sp;return;
 } else if ((($39|0) == 3)) {
  __ZN5physx2Sc24ElementInteractionMarker7destroyEv($pair);
  $58 = (($this) + 1596|0);
  $59 = ($pair|0)==(0|0);
  if ($59) {
   STACKTOP = sp;return;
  }
  $60 = HEAP32[$pair>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_vi[$61 & 4095]($pair);
  $62 = (($this) + 1876|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($63) + -1)|0;
  HEAP32[$62>>2] = $64;
  $65 = (($this) + 1888|0);
  $66 = HEAP32[$65>>2]|0;
  HEAP32[$pair>>2] = $66;
  HEAP32[$65>>2] = $pair;
  $67 = (($this) + 1880|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($68) + 1)|0;
  HEAP32[$67>>2] = $69;
  $70 = (($this) + 1872|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71*50)|0;
  $73 = ($68|0)<($72|0);
  if ($73) {
   STACKTOP = sp;return;
  }
  __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($58);
  HEAP32[$67>>2] = 0;
  STACKTOP = sp;return;
 } else if ((($39|0) == 4)) {
  __ZN5physx2Sc10NPhaseCore39pool_deleteParticleElementRbElementPairEPNS0_35ParticleElementRbElementInteractionEjj($this,$pair,$flags,$ccdPass);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc10NPhaseCore15onVolumeRemovedEPNS0_7ElementEj($this,$volume,$flags) {
 $this = $this|0;
 $volume = $volume|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $interaction$01 = 0, $iter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 $0 = (($volume) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (_bitshift64Lshr(($3|0),($6|0),30)|0);
 $8 = tempRet0;
 $9 = $7 & 3;
 if ((($9|0) == 1)) {
  $30 = $flags | 1;
  $31 = (($volume) + 36|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($volume) + 42|0);
  $34 = HEAP16[$33>>1]|0;
  $35 = ($34<<16>>16)==(0);
  if ($35) {
   STACKTOP = sp;return;
  }
  $36 = $34&65535;
  $37 = (($32) + ($36<<2)|0);
  $39 = $37;
  while(1) {
   $38 = (($39) + -4|0);
   $40 = HEAP32[$38>>2]|0;
   __ZN5physx2Sc10NPhaseCore18releaseElementPairEPNS0_21ElementSimInteractionEjj($this,$40,$30,0);
   $41 = ($32>>>0)<($38>>>0);
   if ($41) {
    $39 = $38;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else if ((($9|0) == 0)) {
  $10 = $flags | 3;
  $11 = (($volume) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + ($16<<2)|0);
  $18 = $14;
  $19 = $17;
  $20 = $iter;
  $21 = $20;
  HEAP32[$21>>2] = $18;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  $24 = (($iter) + 8|0);
  HEAP32[$24>>2] = $volume;
  $25 = (__ZN5physx2Sc7Element33ElementInteractionReverseIterator7getNextEv($iter)|0);
  $26 = ($25|0)==(0|0);
  if ($26) {
   STACKTOP = sp;return;
  } else {
   $interaction$01 = $25;
  }
  while(1) {
   $27 = (($interaction$01) + -8|0);
   __ZN5physx2Sc10NPhaseCore18releaseElementPairEPNS0_21ElementSimInteractionEjj($this,$27,$10,0);
   $28 = (__ZN5physx2Sc7Element33ElementInteractionReverseIterator7getNextEv($iter)|0);
   $29 = ($28|0)==(0|0);
   if ($29) {
    break;
   } else {
    $interaction$01 = $28;
   }
  }
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc10NPhaseCore21filterRbCollisionPairERKNS0_8ShapeSimES4_PNS0_10FilterPairE($agg$result,$this,$s0,$s1,$filterPair) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $s0 = $s0|0;
 $s1 = $s1|0;
 $filterPair = $filterPair|0;
 var $$ = 0, $$mux = 0, $$not = 0, $$not12 = 0, $$not14$not = 0, $$off0 = 0, $$off02 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge13 = 0, $brmerge15$not = 0;
 var $brmerge16$not = 0, $brmerge26 = 0, $collisionDisabled = 0, $disableCollision$0$off0 = 0, $notlhs = 0, $notlhs27 = 0, $notrhs = 0, $notrhs28 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $collisionDisabled = sp + 8|0;
 $0 = sp;
 $1 = $agg$result;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s0)|0);
 $6 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s1)|0);
 $7 = (($5) + 50|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = (($6) + 50|0);
 $10 = HEAP8[$9>>0]|0;
 if ((($8<<24>>24) == 1) | (($8<<24>>24) == 4)) {
  $24 = $5;
 } else {
  $24 = 0;
 }
 if ((($10<<24>>24) == 1) | (($10<<24>>24) == 4)) {
  $31 = $6;
 } else {
  $31 = 0;
 }
 $11 = (($s0) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 64|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 >>> 2;
 $17 = (($s1) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 64|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = $21 >>> 2;
 if ((($8<<24>>24) == 1) | (($8<<24>>24) == 4)) {
  $23 = (($24) + 52|0);
  $25 = HEAP32[$23>>2]|0;
  $26 = (($25) + 44|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)!=(0);
  $$off0 = $29;
 } else {
  $$off0 = 0;
 }
 if ((($10<<24>>24) == 1) | (($10<<24>>24) == 4)) {
  $30 = (($31) + 52|0);
  $32 = HEAP32[$30>>2]|0;
  $33 = (($32) + 44|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = $34 & 1;
  $36 = ($35<<24>>24)!=(0);
  $$off02 = $36;
 } else {
  $$off02 = 0;
 }
 $37 = HEAP32[$this>>2]|0;
 $38 = (($37) + 1200|0);
 $39 = HEAP16[$38>>1]|0;
 $40 = $39&65535;
 $41 = $40 & 32;
 $42 = ($41|0)==(0);
 if ($42) {
  $43 = $16 & 1;
  $44 = ($43|0)==(0);
  if ($44) {
   $45 = $22 & 1;
   $46 = ($45|0)==(0);
   if ($46) {
    $notlhs = ($8<<24>>24)!=(1);
    $notrhs = ($8<<24>>24)!=(4);
    $$not = $notrhs & $notlhs;
    $notlhs27 = ($10<<24>>24)!=(1);
    $notrhs28 = ($10<<24>>24)!=(4);
    $$not12 = $notrhs28 & $notlhs27;
    $brmerge = $$not | $$not12;
    $brmerge13 = $$off0 | $$off02;
    $or$cond = $brmerge & $brmerge13;
    $$ = $or$cond ? 2 : 0;
    $52 = $$;$disableCollision$0$off0 = $or$cond;
   } else {
    $52 = 0;$disableCollision$0$off0 = 0;
   }
  } else {
   $52 = 0;$disableCollision$0$off0 = 0;
  }
 } else {
  $52 = 0;$disableCollision$0$off0 = 0;
 }
 $47 = $40 & 64;
 $48 = ($47|0)==(0);
 if ($48) {
  $49 = $16 & 1;
  $50 = ($49|0)==(0);
  if ($50) {
   $51 = $22 & 1;
   $$not14$not = ($51|0)==(0);
   $brmerge15$not = $$off0 & $$not14$not;
   $brmerge16$not = $$off02 & $brmerge15$not;
   $brmerge26 = $brmerge16$not | $disableCollision$0$off0;
   $$mux = $brmerge16$not ? 2 : $52;
   if ($brmerge26) {
    $128 = $$mux;
   } else {
    label = 17;
   }
  } else {
   label = 16;
  }
 } else {
  label = 16;
 }
 if ((label|0) == 16) {
  if ($disableCollision$0$off0) {
   $128 = $52;
  } else {
   label = 17;
  }
 }
 L23: do {
  if ((label|0) == 17) {
   HEAP8[$collisionDisabled>>0] = 0;
   $53 = ($24|0)==(0|0);
   if ($53) {
    label = 20;
   } else {
    $54 = (($24) + 144|0);
    $55 = HEAP16[$54>>1]|0;
    $56 = $55 & 256;
    $57 = ($56<<16>>16)==(0);
    if ($57) {
     label = 20;
    } else {
     $58 = (__ZNK5physx2Sc7BodySim13isConnectedToERKNS0_8RigidSimERb($24,$6,$collisionDisabled)|0);
     if ($58) {
      label = 23;
     } else {
      $129 = 0;
     }
    }
   }
   if ((label|0) == 20) {
    $59 = ($31|0)==(0|0);
    if ($59) {
     $129 = 0;
    } else {
     $60 = (($31) + 144|0);
     $61 = HEAP16[$60>>1]|0;
     $62 = $61 & 256;
     $63 = ($62<<16>>16)==(0);
     if ($63) {
      $129 = 0;
     } else {
      $64 = (__ZNK5physx2Sc7BodySim13isConnectedToERKNS0_8RigidSimERb($31,$5,$collisionDisabled)|0);
      if ($64) {
       label = 23;
      } else {
       $129 = 0;
      }
     }
    }
   }
   if ((label|0) == 23) {
    $65 = HEAP8[$collisionDisabled>>0]|0;
    $66 = ($65<<24>>24)!=(0);
    $129 = $66;
   }
   $67 = HEAP8[$7>>0]|0;
   $68 = ($67<<24>>24)==(4);
   if ($68) {
    $69 = HEAP8[$9>>0]|0;
    $70 = ($69<<24>>24)==(4);
    if ($70) {
     $71 = (($5) + 20|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = (($5) + 28|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($72) + ($74<<2)|0);
     $76 = ($74|0)>(0);
     if ($76) {
      $78 = $72;
      while(1) {
       $77 = HEAP32[$78>>2]|0;
       $79 = (($77) + 20|0);
       $80 = HEAP8[$79>>0]|0;
       $81 = ($80<<24>>24)==(5);
       if ($81) {
        $82 = (($77) + 4|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = ($83|0)==($6|0);
        if ($84) {
         $128 = 1;
         break L23;
        }
        $85 = (($77) + 8|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = ($86|0)==($6|0);
        if ($87) {
         $128 = 1;
         break L23;
        }
       }
       $88 = (($78) + 4|0);
       $89 = ($88>>>0)<($75>>>0);
       if ($89) {
        $78 = $88;
       } else {
        break;
       }
      }
     }
    }
   }
   if ($129) {
    $128 = 2;
   } else {
    __ZN5physx2Sc10NPhaseCore9runFilterERKNS0_10ElementSimES4_PNS0_10FilterPairE($0,$this,$s0,$s1,$filterPair);
    $90 = $0;
    $91 = $90;
    $92 = HEAP32[$91>>2]|0;
    $93 = (($90) + 4)|0;
    $94 = $93;
    $95 = HEAP32[$94>>2]|0;
    $96 = $agg$result;
    $97 = $96;
    HEAP32[$97>>2] = $92;
    $98 = (($96) + 4)|0;
    $99 = $98;
    HEAP32[$99>>2] = $95;
    $100 = (($agg$result) + 2|0);
    $101 = (_bitshift64Lshr(($92|0),($95|0),16)|0);
    $102 = tempRet0;
    $103 = $101&65535;
    $104 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($s0)|0);
    $105 = ($104|0)==(0|0);
    if ($105) {
     $126 = $103;
    } else {
     $106 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($s0)|0);
     $107 = (($106) + 52|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = (($108) + 44|0);
     $110 = HEAP8[$109>>0]|0;
     $111 = $110 & 1;
     $112 = ($111<<24>>24)==(0);
     if ($112) {
      $126 = $103;
     } else {
      $113 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($s1)|0);
      $114 = ($113|0)==(0|0);
      if ($114) {
       $126 = $103;
      } else {
       $115 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($s1)|0);
       $116 = (($115) + 52|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = (($117) + 44|0);
       $119 = HEAP8[$118>>0]|0;
       $120 = $119 & 1;
       $121 = ($120<<24>>24)==(0);
       if ($121) {
        $126 = $103;
       } else {
        $122 = $101 & 1;
        $123 = ($122|0)==(0);
        if ($123) {
         $126 = $103;
        } else {
         $124 = $101 & 65534;
         $125 = $124&65535;
         $126 = $125;
        }
       }
      }
     }
    }
    HEAP16[$100>>1] = $126;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $127 = ($filterPair|0)==(0|0);
 if (!($127)) {
  __ZN5physx2Sc10NPhaseCore16deleteFilterPairEPNS0_10FilterPairE($this,$filterPair);
 }
 HEAP16[$agg$result>>1] = $128;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore25createShapeInstancePairLLERNS0_8ShapeSimES3_NS_7PxFlagsINS_10PxPairFlag4EnumEtEE($this,$s0,$s1,$pairFlags) {
 $this = $this|0;
 $s0 = $s0|0;
 $s1 = $s1|0;
 $pairFlags = $pairFlags|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $s12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s0)|0);
 $2 = (($1) + 50|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $16 = 0;
 } else {
  $5 = (($1) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 2)|0;
  $16 = $7;
 }
 $8 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s1)|0);
 $9 = (($8) + 50|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $17 = 0;
 } else {
  $12 = (($8) + 56|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 2)|0;
  $17 = $14;
 }
 $15 = ($16>>>0)<($17>>>0);
 if ($15) {
  label = 7;
 } else {
  $18 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s0)|0);
  $19 = (($18) + 50|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 7;
  } else {
   $22 = $s1;$s12 = $s0;
  }
 }
 if ((label|0) == 7) {
  $22 = $s0;$s12 = $s1;
 }
 $23 = (__ZN5physx2Sc10NPhaseCore13findActorPairEPNS0_8ShapeSimES3_($this,$s12,$22)|0);
 $24 = (($this) + 1000|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $27 = (($this) + 708|0);
  __ZN5physx6shdfnd8PoolBaseINS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($27);
  $$pre$i$i = HEAP32[$24>>2]|0;
  $29 = $$pre$i$i;
 } else {
  $29 = $25;
 }
 $28 = HEAP32[$29>>2]|0;
 HEAP32[$24>>2] = $28;
 $30 = (($this) + 988|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 1)|0;
 HEAP32[$30>>2] = $32;
 $33 = (($this) + 992|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + -1)|0;
 HEAP32[$33>>2] = $35;
 $36 = ($29|0)==(0|0);
 if ($36) {
  $38 = 0;
 } else {
  $37 = HEAP16[$pairFlags>>1]|0;
  HEAP16[$0>>1] = $37;
  __ZN5physx2Sc19ShapeInstancePairLLC2ERNS0_8ShapeSimES3_RNS0_9ActorPairENS_7PxFlagsINS_10PxPairFlag4EnumEtEE($29,$s12,$22,$23,$0);
  $38 = $29;
 }
 __ZN5physx2Sc19ShapeInstancePairLL10initializeEv($38);
 $39 = (($38) + 52|0);
 HEAP32[$39>>2] = -1;
 $40 = (($38) + 44|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 134217728;
 $43 = ($42|0)==(0);
 if (!($43)) {
  STACKTOP = sp;return ($38|0);
 }
 __ZN5physx2Sc19ShapeInstancePairLL11updateStateEv($38);
 STACKTOP = sp;return ($38|0);
}
function __ZN5physx2Sc10NPhaseCore24createTriggerInteractionERNS0_8ShapeSimES3_NS_7PxFlagsINS_10PxPairFlag4EnumEtEE($this,$s0,$s1,$triggerFlags) {
 $this = $this|0;
 $s0 = $s0|0;
 $s1 = $s1|0;
 $triggerFlags = $triggerFlags|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $s0$s1 = 0, $s1$s0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s1) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 64|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 4;
 $5 = ($4<<24>>24)==(0);
 $s1$s0 = $5 ? $s1 : $s0;
 $s0$s1 = $5 ? $s0 : $s1;
 $6 = (($this) + 1296|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (($this) + 1004|0);
  __ZN5physx6shdfnd8PoolBaseINS_2Sc18TriggerInteractionENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($9);
  $$pre$i$i = HEAP32[$6>>2]|0;
  $11 = $$pre$i$i;
 } else {
  $11 = $7;
 }
 $10 = HEAP32[$11>>2]|0;
 HEAP32[$6>>2] = $10;
 $12 = (($this) + 1284|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[$12>>2] = $14;
 $15 = (($this) + 1288|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = ($11|0)==(0|0);
 if ($18) {
  $31 = 0;
  __ZN5physx2Sc18TriggerInteraction10initializeEv($31);
  $32 = HEAP16[$triggerFlags>>1]|0;
  $33 = (($31) + 56|0);
  $34 = HEAP16[$33>>1]|0;
  $35 = $34&65535;
  $36 = $32&65535;
  $37 = $36 & 20;
  $38 = $35 & 65504;
  $39 = $38 | $37;
  $40 = $39&65535;
  HEAP16[$33>>1] = $40;
  STACKTOP = sp;return ($31|0);
 }
 HEAP32[$11>>2] = ((463024 + 8|0));
 $19 = (($11) + 4|0);
 HEAP16[$19>>1] = -1;
 $20 = (($11) + 6|0);
 HEAP16[$20>>1] = 1;
 $21 = (($11) + 8|0);
 $22 = (($s0$s1) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($s1$s0) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 __ZN5physx2Sc11InteractionC2ERNS0_5ActorES3_NS0_15InteractionTypeEh($21,$23,$25,2,5);
 $26 = (($11) + 32|0);
 HEAP32[$26>>2] = $s0$s1;
 $27 = (($11) + 36|0);
 HEAP32[$27>>2] = $s1$s0;
 HEAP32[$11>>2] = ((472584 + 8|0));
 $28 = (($11) + 8|0);
 HEAP32[$28>>2] = ((472584 + 52|0));
 $29 = (($11) + 56|0);
 HEAP16[$29>>1] = 32;
 $30 = (($11) + 58|0);
 HEAP8[$30>>0] = 0;
 $31 = $11;
 __ZN5physx2Sc18TriggerInteraction10initializeEv($31);
 $32 = HEAP16[$triggerFlags>>1]|0;
 $33 = (($31) + 56|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = $34&65535;
 $36 = $32&65535;
 $37 = $36 & 20;
 $38 = $35 & 65504;
 $39 = $38 | $37;
 $40 = $39&65535;
 HEAP16[$33>>1] = $40;
 STACKTOP = sp;return ($31|0);
}
function __ZN5physx2Sc10NPhaseCore13findActorPairEPNS0_8ShapeSimES3_($this,$s0,$s1) {
 $this = $this|0;
 $s0 = $s0|0;
 $s1 = $s1|0;
 var $$0 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $aLess$0 = 0, $aMore$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s0) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($s1) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($3>>>0)<($7>>>0);
 if ($8) {
  $9 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s0)|0);
  $10 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s1)|0);
  $aLess$0 = $9;$aMore$0 = $10;
 } else {
  $11 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s1)|0);
  $12 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s0)|0);
  $aLess$0 = $11;$aMore$0 = $12;
 }
 $13 = (($aLess$0) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($aLess$0) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + ($16<<2)|0);
 $18 = ($16|0)>(0);
 L5: do {
  if ($18) {
   $20 = $14;
   while(1) {
    $19 = HEAP32[$20>>2]|0;
    $21 = (($19) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($aLess$0|0);
    if ($23) {
     $24 = (($19) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($aMore$0|0);
     if ($26) {
      label = 10;
     } else {
      label = 8;
     }
    } else {
     label = 8;
    }
    if ((label|0) == 8) {
     label = 0;
     $27 = ($22|0)==($aMore$0|0);
     if ($27) {
      $28 = (($19) + 8|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==($aLess$0|0);
      if ($30) {
       label = 10;
      }
     }
    }
    if ((label|0) == 10) {
     label = 0;
     $31 = (($19) + 21|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = $32 & 16;
     $34 = ($33<<24>>24)==(0);
     if (!($34)) {
      break;
     }
    }
    $39 = (($20) + 4|0);
    $40 = ($39>>>0)<($17>>>0);
    if ($40) {
     $20 = $39;
    } else {
     break L5;
    }
   }
   $35 = (($19) + -8|0);
   $36 = (($35) + 48|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $41 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s0)|0);
 $42 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($s1)|0);
 $43 = (($this) + 408|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  $46 = (($this) + 116|0);
  __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($46);
  $$pre$i$i = HEAP32[$43>>2]|0;
  $48 = $$pre$i$i;
 } else {
  $48 = $44;
 }
 $47 = HEAP32[$48>>2]|0;
 HEAP32[$43>>2] = $47;
 $49 = (($this) + 396|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 1)|0;
 HEAP32[$49>>2] = $51;
 $52 = (($this) + 400|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + -1)|0;
 HEAP32[$52>>2] = $54;
 $55 = ($48|0)==(0|0);
 if ($55) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$48>>2] = $41;
 $56 = (($48) + 4|0);
 HEAP32[$56>>2] = $42;
 $57 = (__ZNK5physx2Sc8ActorSim8getSceneEv($41)|0);
 $58 = (($48) + 8|0);
 HEAP32[$58>>2] = $57;
 $59 = (($48) + 12|0);
 HEAP16[$59>>1] = 0;
 $60 = (($48) + 14|0);
 HEAP16[$60>>1] = 0;
 $61 = (($48) + 16|0);
 HEAP16[$61>>1] = 0;
 $62 = (($48) + 20|0);
 HEAP32[$62>>2] = 0;
 $63 = (($41) + 46|0);
 $64 = HEAP16[$63>>1]|0;
 $65 = (($64) + 1)<<16>>16;
 HEAP16[$63>>1] = $65;
 $66 = (($42) + 46|0);
 $67 = HEAP16[$66>>1]|0;
 $68 = (($67) + 1)<<16>>16;
 HEAP16[$66>>1] = $68;
 $$0 = $48;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc10NPhaseCore16createFilterPairEv($this) {
 $this = $this|0;
 var $$0$i1$i = 0, $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   $3 = (($this) + 80|0);
   $4 = (__ZN5physx2Cm11IndexedPoolINS_2Sc10FilterPairELj32EE6extendEv($3)|0);
   if ($4) {
    $$pre$i$i = HEAP32[$0>>2]|0;
    $6 = $$pre$i$i;
    break;
   } else {
    $$0$i1$i = 0;
    STACKTOP = sp;return ($$0$i1$i|0);
   }
  } else {
   $6 = $1;
  }
 } while(0);
 $5 = (($6) + -1)|0;
 $7 = (($this) + 92|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($5<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = $5;
 $11 = (($this) + 104|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + 32)|0;
 $14 = $13 >>> 5;
 $15 = (($this) + 108|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = ($14>>>0)>($17>>>0);
 if ($18) {
  $19 = (($this) + 112|0);
  $20 = $14 << 2;
  $21 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($19,$20,462872,339)|0);
  $22 = HEAP32[$11>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$15>>2]|0;
   $25 = $24 << 2;
   _memcpy(($21|0),($22|0),($25|0))|0;
   $26 = HEAP32[$15>>2]|0;
   $27 = ($26|0)>(-1);
   if ($27) {
    $28 = HEAP32[$11>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($19,$28);
   }
  }
  $29 = HEAP32[$15>>2]|0;
  $30 = $29 & 2147483647;
  $31 = (($21) + ($30<<2)|0);
  $32 = (($14) - ($29))|0;
  $33 = $32 << 2;
  _memset(($31|0),0,($33|0))|0;
  HEAP32[$11>>2] = $21;
  HEAP32[$15>>2] = $14;
  $38 = $21;
 } else {
  $$pre$i = HEAP32[$11>>2]|0;
  $38 = $$pre$i;
 }
 $34 = $12 & 31;
 $35 = 1 << $34;
 $36 = $12 >>> 5;
 $37 = (($38) + ($36<<2)|0);
 $39 = HEAP32[$37>>2]|0;
 $40 = $39 | $35;
 HEAP32[$37>>2] = $40;
 $41 = ($10|0)==(0|0);
 if ($41) {
  $$0$i1$i = 0;
  STACKTOP = sp;return ($$0$i1$i|0);
 }
 $42 = (($10) + 4|0);
 HEAP32[$42>>2] = 0;
 $43 = (($10) + 8|0);
 HEAP8[$43>>0] = 2;
 $$0$i1$i = $10;
 STACKTOP = sp;return ($$0$i1$i|0);
}
function __ZN5physx2Sc10NPhaseCore16deleteFilterPairEPNS0_10FilterPairE($this,$pair) {
 $this = $this|0;
 $pair = $pair|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $pair;
 $1 = HEAP32[$pair>>2]|0;
 $2 = (($this) + 104|0);
 $3 = (($1) + 32)|0;
 $4 = $3 >>> 5;
 $5 = (($this) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if ($8) {
  $9 = (($this) + 112|0);
  $10 = $4 << 2;
  $11 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($9,$10,462872,339)|0);
  $12 = HEAP32[$2>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = HEAP32[$5>>2]|0;
   $15 = $14 << 2;
   _memcpy(($11|0),($12|0),($15|0))|0;
   $16 = HEAP32[$5>>2]|0;
   $17 = ($16|0)>(-1);
   if ($17) {
    $18 = HEAP32[$2>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($9,$18);
   }
  }
  $19 = HEAP32[$5>>2]|0;
  $20 = $19 & 2147483647;
  $21 = (($11) + ($20<<2)|0);
  $22 = (($4) - ($19))|0;
  $23 = $22 << 2;
  _memset(($21|0),0,($23|0))|0;
  HEAP32[$2>>2] = $11;
  HEAP32[$5>>2] = $4;
  $29 = $11;
 } else {
  $$pre$i = HEAP32[$2>>2]|0;
  $29 = $$pre$i;
 }
 $24 = $1 & 31;
 $25 = 1 << $24;
 $26 = $25 ^ -1;
 $27 = $1 >>> 5;
 $28 = (($29) + ($27<<2)|0);
 $30 = HEAP32[$28>>2]|0;
 $31 = $30 & $26;
 HEAP32[$28>>2] = $31;
 $32 = (($this) + 92|0);
 $33 = (($this) + 100|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 2147483647;
 $36 = (($this) + 96|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($35>>>0)>($37>>>0);
 if (!($38)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc10FilterPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($32,$0)|0);
  STACKTOP = sp;return;
 }
 $39 = HEAP32[$32>>2]|0;
 $40 = (($39) + ($37<<2)|0);
 $41 = ($40|0)==(0|0);
 if (!($41)) {
  HEAP32[$40>>2] = $pair;
 }
 $42 = (($37) + 1)|0;
 HEAP32[$36>>2] = $42;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore15fetchFilterPairEPv($this,$reference) {
 $this = $this|0;
 $reference = $reference|0;
 var $$0 = 0, $$ph = 0, $$ph2 = 0, $$ph3 = 0, $$ph418 = 0, $$ph519 = 0, $$ph620 = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = (($this) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$pre$i$i$i$i$i = HEAP32[$0>>2]|0;
 $6 = 0;
 while(1) {
  $5 = (($$pre$i$i$i$i$i) + ($6<<2)|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(0);
  if (!($8)) {
   break;
  }
  $9 = (($6) + 1)|0;
  $10 = ($9>>>0)<($3>>>0);
  if ($10) {
   $6 = $9;
  } else {
   $$0 = 0;
   label = 19;
   break;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return ($$0|0);
 }
 $11 = $6 << 5;
 $12 = (0 - ($7))|0;
 $13 = $7 & $12;
 $14 = Math_imul($13, 125613361)|0;
 $15 = $14 >>> 27;
 $16 = (412480 + ($15<<2)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 | $11;
 $19 = (($7) + -1)|0;
 $20 = $19 & $7;
 $21 = ($20|0)==(0);
 L10: do {
  if ($21) {
   $23 = $6;
   while(1) {
    $22 = (($23) + 1)|0;
    $24 = ($22>>>0)<($3>>>0);
    if (!($24)) {
     $$ph2 = $22;$$ph3 = 0;
     break L10;
    }
    $25 = (($$pre$i$i$i$i$i) + ($22<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0);
    if ($27) {
     $23 = $22;
    } else {
     $$ph2 = $22;$$ph3 = $26;
     break;
    }
   }
  } else {
   $$ph2 = $6;$$ph3 = $20;
  }
 } while(0);
 $28 = ($18|0)==(-1);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($this) + 80|0);
 $30 = HEAP32[$29>>2]|0;
 $$ph418 = $18;$$ph519 = $$ph2;$$ph620 = $$ph3;
 L18: while(1) {
  $33 = $$ph519 << 5;
  $35 = $$ph418;$43 = $$ph620;
  while(1) {
   $34 = $35 & 31;
   $36 = $35 >>> 5;
   $37 = (($30) + ($36<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($38) + (($34*12)|0)|0) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==($reference|0);
   if ($41) {
    label = 18;
    break L18;
   }
   $42 = ($43|0)==(0);
   if ($42) {
    $$0 = 0;
    label = 19;
    break L18;
   }
   $45 = (0 - ($43))|0;
   $46 = $43 & $45;
   $47 = Math_imul($46, 125613361)|0;
   $48 = $47 >>> 27;
   $49 = (412480 + ($48<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $32 = $50 | $33;
   $51 = (($43) + -1)|0;
   $52 = $51 & $43;
   $53 = ($52|0)==(0);
   if ($53) {
    $55 = $$ph519;
    break;
   }
   $44 = ($32|0)==(-1);
   if ($44) {
    $$0 = 0;
    label = 19;
    break L18;
   } else {
    $35 = $32;$43 = $52;
   }
  }
  while(1) {
   $54 = (($55) + 1)|0;
   $56 = ($54>>>0)<($3>>>0);
   if (!($56)) {
    $$ph = 0;
    break;
   }
   $57 = HEAP32[$0>>2]|0;
   $58 = (($57) + ($54<<2)|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0);
   if ($60) {
    $55 = $54;
   } else {
    $$ph = $59;
    break;
   }
  }
  $31 = ($32|0)==(-1);
  if ($31) {
   $$0 = 0;
   label = 19;
   break;
  } else {
   $$ph418 = $32;$$ph519 = $54;$$ph620 = $$ph;
  }
 }
 if ((label|0) == 18) {
  $61 = (($38) + (($34*12)|0)|0);
  $$0 = $61;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 19) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sc10NPhaseCore19refilterInteractionEPNS0_21ElementSimInteractionEPKNS0_10FilterInfoE($this,$pair,$filterInfo) {
 $this = $this|0;
 $pair = $pair|0;
 $filterInfo = $filterInfo|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre$phi40Z2D = 0, $$pre$phi42Z2D = 0, $$pre$phi48Z2D = 0, $$pre$phi50Z2D = 0, $$pre$phi52Z2D = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $$pre34 = 0, $$pre39 = 0, $$pre41 = 0, $$pre47 = 0, $$pre49 = 0, $$pre51 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fa0$i14 = 0, $fa1$i15 = 0, $fd0$i$byval_copy = 0, $fd0$i12 = 0, $fd1$i$byval_copy = 0, $fd1$i13 = 0, $filterPair$0 = 0, $filterPair6$0 = 0, $finfo = 0, $index$0$i = 0, $index$1$i = 0, $or$cond$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $fd1$i$byval_copy = sp + 80|0;
 $fd0$i$byval_copy = sp + 64|0;
 $fd0$i12 = sp + 48|0;
 $fd1$i13 = sp + 32|0;
 $fa0$i14 = sp + 28|0;
 $fa1$i15 = sp + 24|0;
 $finfo = sp + 8|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = (($pair) + 28|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 if ((($4|0) == 4)) {
  $239 = (($pair) + 40|0);
  $240 = HEAP32[$239>>2]|0;
  $241 = ($filterInfo|0)==(0|0);
  do {
   if ($241) {
    $276 = HEAP32[$this>>2]|0;
    $277 = (($276) + 60|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = (($240) + 12|0);
    $280 = HEAP32[$279>>2]|0;
    $281 = ($280|0)==($278|0);
    if (!($281)) {
     HEAP32[$279>>2] = $278;
     $282 = (($pair) + 6|0);
     $283 = HEAP16[$282>>1]|0;
     $284 = $283 & 4;
     $285 = ($284<<16>>16)==(0);
     if ($285) {
      $$pre49 = (($pair) + 32|0);
      $$pre51 = (($pair) + 36|0);
      $$pre$phi50Z2D = $$pre49;$$pre$phi52Z2D = $$pre51;$filterPair6$0 = 0;
     } else {
      $286 = (__ZN5physx2Sc10NPhaseCore15fetchFilterPairEPv($this,$240)|0);
      $287 = (($pair) + 32|0);
      $288 = HEAP32[$287>>2]|0;
      $289 = (($pair) + 36|0);
      $290 = HEAP32[$289>>2]|0;
      $291 = HEAP32[$286>>2]|0;
      ;HEAP32[$fd0$i12+0>>2]=0|0;HEAP32[$fd0$i12+4>>2]=0|0;HEAP32[$fd0$i12+8>>2]=0|0;HEAP32[$fd0$i12+12>>2]=0|0;
      ;HEAP32[$fd1$i13+0>>2]=0|0;HEAP32[$fd1$i13+4>>2]=0|0;HEAP32[$fd1$i13+8>>2]=0|0;HEAP32[$fd1$i13+12>>2]=0|0;
      $292 = HEAP32[$288>>2]|0;
      $293 = (($292) + 8|0);
      $294 = HEAP32[$293>>2]|0;
      FUNCTION_TABLE_viii[$294 & 4095]($288,$fa0$i14,$fd0$i12);
      $295 = HEAP32[$290>>2]|0;
      $296 = (($295) + 8|0);
      $297 = HEAP32[$296>>2]|0;
      FUNCTION_TABLE_viii[$297 & 4095]($290,$fa1$i15,$fd1$i13);
      $298 = HEAP32[$this>>2]|0;
      $299 = (($298) + 1104|0);
      $300 = HEAP32[$299>>2]|0;
      $301 = HEAP32[$300>>2]|0;
      $302 = (($301) + 4|0);
      $303 = HEAP32[$302>>2]|0;
      $304 = HEAP32[$fa0$i14>>2]|0;
      $305 = HEAP32[$fa1$i15>>2]|0;
      ;HEAP32[$fd0$i$byval_copy+0>>2]=HEAP32[$fd0$i12+0>>2]|0;HEAP32[$fd0$i$byval_copy+4>>2]=HEAP32[$fd0$i12+4>>2]|0;HEAP32[$fd0$i$byval_copy+8>>2]=HEAP32[$fd0$i12+8>>2]|0;HEAP32[$fd0$i$byval_copy+12>>2]=HEAP32[$fd0$i12+12>>2]|0;
      ;HEAP32[$fd1$i$byval_copy+0>>2]=HEAP32[$fd1$i13+0>>2]|0;HEAP32[$fd1$i$byval_copy+4>>2]=HEAP32[$fd1$i13+4>>2]|0;HEAP32[$fd1$i$byval_copy+8>>2]=HEAP32[$fd1$i13+8>>2]|0;HEAP32[$fd1$i$byval_copy+12>>2]=HEAP32[$fd1$i13+12>>2]|0;
      FUNCTION_TABLE_viiiiiii[$303 & 127]($300,$291,$304,$fd0$i$byval_copy,$305,$fd1$i$byval_copy,0);
      $$pre$phi50Z2D = $287;$$pre$phi52Z2D = $289;$filterPair6$0 = $286;
     }
     $306 = HEAP32[$$pre$phi50Z2D>>2]|0;
     $307 = HEAP32[$$pre$phi52Z2D>>2]|0;
     __ZN5physx2Sc10NPhaseCore9runFilterERKNS0_10ElementSimES4_PNS0_10FilterPairE($1,$this,$306,$307,$filterPair6$0);
     $308 = $1;
     $309 = $308;
     $310 = HEAP32[$309>>2]|0;
     $311 = (($308) + 4)|0;
     $312 = $311;
     $313 = HEAP32[$312>>2]|0;
     $314 = (_bitshift64Lshr(($310|0),($313|0),16)|0);
     $315 = tempRet0;
     $316 = $314&65535;
     $317 = ($313>>>0)>(0);
     $318 = ($313|0)==(0);
     $319 = ($310>>>0)>(4294967295);
     $320 = $318 & $319;
     $321 = $317 | $320;
     $322 = (($240) + 18|0);
     $323 = $321&1;
     HEAP8[$322>>0] = $323;
     $324 = (($240) + 8|0);
     HEAP16[$324>>1] = $316;
     $325 = $310 & 1;
     $326 = ($325|0)==(0);
     if (!($326)) {
      $327 = (($240) + 20|0);
      HEAP8[$327>>0] = 1;
      break;
     }
     $328 = $310 & 2;
     $329 = ($328|0)==(0);
     $330 = (($240) + 19|0);
     if ($329) {
      HEAP8[$330>>0] = 0;
      break;
     } else {
      HEAP8[$330>>0] = 1;
      break;
     }
    }
   } else {
    $242 = $filterInfo;
    $243 = $242;
    $244 = HEAP32[$243>>2]|0;
    $245 = (($242) + 4)|0;
    $246 = $245;
    $247 = HEAP32[$246>>2]|0;
    $248 = $247;
    $249 = ($247|0)==(0);
    if (!($249)) {
     $250 = (($240) + 20|0);
     $251 = HEAP8[$250>>0]|0;
     $252 = ($251<<24>>24)==(0);
     if (!($252)) {
      $253 = HEAP32[$pair>>2]|0;
      $254 = (($253) + 16|0);
      $255 = HEAP32[$254>>2]|0;
      $256 = (FUNCTION_TABLE_ii[$255 & 4095]($pair)|0);
      if ($256) {
       $257 = (($pair) + 32|0);
       $258 = HEAP32[$257>>2]|0;
       $259 = (($pair) + 36|0);
       $260 = HEAP32[$259>>2]|0;
       $261 = HEAP32[$248>>2]|0;
       ;HEAP32[$fd0$i12+0>>2]=0|0;HEAP32[$fd0$i12+4>>2]=0|0;HEAP32[$fd0$i12+8>>2]=0|0;HEAP32[$fd0$i12+12>>2]=0|0;
       ;HEAP32[$fd1$i13+0>>2]=0|0;HEAP32[$fd1$i13+4>>2]=0|0;HEAP32[$fd1$i13+8>>2]=0|0;HEAP32[$fd1$i13+12>>2]=0|0;
       $262 = HEAP32[$258>>2]|0;
       $263 = (($262) + 8|0);
       $264 = HEAP32[$263>>2]|0;
       FUNCTION_TABLE_viii[$264 & 4095]($258,$fa0$i14,$fd0$i12);
       $265 = HEAP32[$260>>2]|0;
       $266 = (($265) + 8|0);
       $267 = HEAP32[$266>>2]|0;
       FUNCTION_TABLE_viii[$267 & 4095]($260,$fa1$i15,$fd1$i13);
       $268 = HEAP32[$this>>2]|0;
       $269 = (($268) + 1104|0);
       $270 = HEAP32[$269>>2]|0;
       $271 = HEAP32[$270>>2]|0;
       $272 = (($271) + 4|0);
       $273 = HEAP32[$272>>2]|0;
       $274 = HEAP32[$fa0$i14>>2]|0;
       $275 = HEAP32[$fa1$i15>>2]|0;
       ;HEAP32[$fd0$i$byval_copy+0>>2]=HEAP32[$fd0$i12+0>>2]|0;HEAP32[$fd0$i$byval_copy+4>>2]=HEAP32[$fd0$i12+4>>2]|0;HEAP32[$fd0$i$byval_copy+8>>2]=HEAP32[$fd0$i12+8>>2]|0;HEAP32[$fd0$i$byval_copy+12>>2]=HEAP32[$fd0$i12+12>>2]|0;
       ;HEAP32[$fd1$i$byval_copy+0>>2]=HEAP32[$fd1$i13+0>>2]|0;HEAP32[$fd1$i$byval_copy+4>>2]=HEAP32[$fd1$i13+4>>2]|0;HEAP32[$fd1$i$byval_copy+8>>2]=HEAP32[$fd1$i13+8>>2]|0;HEAP32[$fd1$i$byval_copy+12>>2]=HEAP32[$fd1$i13+12>>2]|0;
       FUNCTION_TABLE_viiiiiii[$273 & 127]($270,$261,$274,$fd0$i$byval_copy,$275,$fd1$i$byval_copy,0);
       __ZN5physx2Sc10NPhaseCore16deleteFilterPairEPNS0_10FilterPairE($this,$248);
      }
     }
    }
   }
  } while(0);
  $331 = (($240) + 18|0);
  $332 = HEAP8[$331>>0]|0;
  $333 = ($332<<24>>24)==(0);
  $334 = (($pair) + 6|0);
  $335 = HEAP16[$334>>1]|0;
  $336 = $335&65535;
  if ($333) {
   $339 = $336 & 4;
   $340 = ($339|0)==(0);
   if (!($340)) {
    $341 = $336 & 65531;
    $342 = $341&65535;
    HEAP16[$334>>1] = $342;
   }
  } else {
   $337 = $336 | 4;
   $338 = $337&65535;
   HEAP16[$334>>1] = $338;
  }
  $343 = (($240) + 20|0);
  $344 = HEAP8[$343>>0]|0;
  $345 = ($344<<24>>24)==(0);
  if ($345) {
   $$0 = $pair;
   STACKTOP = sp;return ($$0|0);
  }
  __ZN5physx2Sc10NPhaseCore39pool_deleteParticleElementRbElementPairEPNS0_35ParticleElementRbElementInteractionEjj($this,$pair,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($4|0) == 0) | (($4|0) == 3) | (($4|0) == 2)) {
  $5 = $finfo;
  $6 = $5;
  HEAP32[$6>>2] = 0;
  $7 = (($5) + 4)|0;
  $8 = $7;
  HEAP32[$8>>2] = 0;
  $9 = ($filterInfo|0)==(0|0);
  if ($9) {
   $73 = (($pair) + 6|0);
   $74 = HEAP16[$73>>1]|0;
   $75 = $74 & 4;
   $76 = ($75<<16>>16)==(0);
   if ($76) {
    $$pre39 = (($pair) + 32|0);
    $$pre41 = (($pair) + 36|0);
    $$pre$phi40Z2D = $$pre39;$$pre$phi42Z2D = $$pre41;$filterPair$0 = 0;
   } else {
    $77 = (__ZN5physx2Sc10NPhaseCore15fetchFilterPairEPv($this,$pair)|0);
    $78 = (($pair) + 32|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($pair) + 36|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = HEAP32[$77>>2]|0;
    ;HEAP32[$fd0$i12+0>>2]=0|0;HEAP32[$fd0$i12+4>>2]=0|0;HEAP32[$fd0$i12+8>>2]=0|0;HEAP32[$fd0$i12+12>>2]=0|0;
    ;HEAP32[$fd1$i13+0>>2]=0|0;HEAP32[$fd1$i13+4>>2]=0|0;HEAP32[$fd1$i13+8>>2]=0|0;HEAP32[$fd1$i13+12>>2]=0|0;
    $83 = HEAP32[$79>>2]|0;
    $84 = (($83) + 8|0);
    $85 = HEAP32[$84>>2]|0;
    FUNCTION_TABLE_viii[$85 & 4095]($79,$fa0$i14,$fd0$i12);
    $86 = HEAP32[$81>>2]|0;
    $87 = (($86) + 8|0);
    $88 = HEAP32[$87>>2]|0;
    FUNCTION_TABLE_viii[$88 & 4095]($81,$fa1$i15,$fd1$i13);
    $89 = HEAP32[$this>>2]|0;
    $90 = (($89) + 1104|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = HEAP32[$91>>2]|0;
    $93 = (($92) + 4|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = HEAP32[$fa0$i14>>2]|0;
    $96 = HEAP32[$fa1$i15>>2]|0;
    ;HEAP32[$fd0$i$byval_copy+0>>2]=HEAP32[$fd0$i12+0>>2]|0;HEAP32[$fd0$i$byval_copy+4>>2]=HEAP32[$fd0$i12+4>>2]|0;HEAP32[$fd0$i$byval_copy+8>>2]=HEAP32[$fd0$i12+8>>2]|0;HEAP32[$fd0$i$byval_copy+12>>2]=HEAP32[$fd0$i12+12>>2]|0;
    ;HEAP32[$fd1$i$byval_copy+0>>2]=HEAP32[$fd1$i13+0>>2]|0;HEAP32[$fd1$i$byval_copy+4>>2]=HEAP32[$fd1$i13+4>>2]|0;HEAP32[$fd1$i$byval_copy+8>>2]=HEAP32[$fd1$i13+8>>2]|0;HEAP32[$fd1$i$byval_copy+12>>2]=HEAP32[$fd1$i13+12>>2]|0;
    FUNCTION_TABLE_viiiiiii[$94 & 127]($91,$82,$95,$fd0$i$byval_copy,$96,$fd1$i$byval_copy,0);
    $$pre$phi40Z2D = $78;$$pre$phi42Z2D = $80;$filterPair$0 = $77;
   }
   $97 = HEAP32[$$pre$phi40Z2D>>2]|0;
   $98 = HEAP32[$$pre$phi42Z2D>>2]|0;
   __ZN5physx2Sc10NPhaseCore21filterRbCollisionPairERKNS0_8ShapeSimES4_PNS0_10FilterPairE($0,$this,$97,$98,$filterPair$0);
   $99 = $0;
   $100 = $99;
   $101 = HEAP32[$100>>2]|0;
   $102 = (($99) + 4)|0;
   $103 = $102;
   $104 = HEAP32[$103>>2]|0;
   $105 = $finfo;
   $106 = $105;
   HEAP32[$106>>2] = $101;
   $107 = (($105) + 4)|0;
   $108 = $107;
   HEAP32[$108>>2] = $104;
   $109 = $101&65535;
   $110 = (_bitshift64Lshr(($101|0),($104|0),16)|0);
   $111 = tempRet0;
   $112 = $110&65535;
   $113 = $104;
   $$pre$phiZ2D = $73;$127 = $113;$347 = $112;$348 = $109;
  } else {
   $10 = $filterInfo;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   $13 = (($10) + 4)|0;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   $16 = $finfo;
   $17 = $16;
   HEAP32[$17>>2] = $12;
   $18 = (($16) + 4)|0;
   $19 = $18;
   HEAP32[$19>>2] = $15;
   $20 = $12&65535;
   $21 = $20 & 13;
   $22 = ($21<<16>>16)==(13);
   $23 = $15;
   $24 = (_bitshift64Lshr(($12|0),($15|0),16)|0);
   $25 = tempRet0;
   $26 = $24&65535;
   $27 = (($pair) + 32|0);
   if ($22) {
    $28 = HEAP32[$27>>2]|0;
    $29 = (($pair) + 36|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($finfo) + 4|0);
    $32 = HEAP32[$23>>2]|0;
    ;HEAP32[$fd0$i12+0>>2]=0|0;HEAP32[$fd0$i12+4>>2]=0|0;HEAP32[$fd0$i12+8>>2]=0|0;HEAP32[$fd0$i12+12>>2]=0|0;
    ;HEAP32[$fd1$i13+0>>2]=0|0;HEAP32[$fd1$i13+4>>2]=0|0;HEAP32[$fd1$i13+8>>2]=0|0;HEAP32[$fd1$i13+12>>2]=0|0;
    $33 = HEAP32[$28>>2]|0;
    $34 = (($33) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    FUNCTION_TABLE_viii[$35 & 4095]($28,$fa0$i14,$fd0$i12);
    $36 = HEAP32[$30>>2]|0;
    $37 = (($36) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    FUNCTION_TABLE_viii[$38 & 4095]($30,$fa1$i15,$fd1$i13);
    $39 = HEAP32[$this>>2]|0;
    $40 = (($39) + 1104|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = HEAP32[$fa0$i14>>2]|0;
    $46 = HEAP32[$fa1$i15>>2]|0;
    ;HEAP32[$fd0$i$byval_copy+0>>2]=HEAP32[$fd0$i12+0>>2]|0;HEAP32[$fd0$i$byval_copy+4>>2]=HEAP32[$fd0$i12+4>>2]|0;HEAP32[$fd0$i$byval_copy+8>>2]=HEAP32[$fd0$i12+8>>2]|0;HEAP32[$fd0$i$byval_copy+12>>2]=HEAP32[$fd0$i12+12>>2]|0;
    ;HEAP32[$fd1$i$byval_copy+0>>2]=HEAP32[$fd1$i13+0>>2]|0;HEAP32[$fd1$i$byval_copy+4>>2]=HEAP32[$fd1$i13+4>>2]|0;HEAP32[$fd1$i$byval_copy+8>>2]=HEAP32[$fd1$i13+8>>2]|0;HEAP32[$fd1$i$byval_copy+12>>2]=HEAP32[$fd1$i13+12>>2]|0;
    FUNCTION_TABLE_viiiiiii[$44 & 127]($41,$32,$45,$fd0$i$byval_copy,$46,$fd1$i$byval_copy,0);
    __ZN5physx2Sc10NPhaseCore16deleteFilterPairEPNS0_10FilterPairE($this,$23);
    HEAP32[$31>>2] = 0;
    $$pre$phi48Z2D = $29;$346 = 0;
   } else {
    $$pre47 = (($pair) + 36|0);
    $$pre$phi48Z2D = $$pre47;$346 = $23;
   }
   $47 = HEAP32[$27>>2]|0;
   $48 = HEAP32[$$pre$phi48Z2D>>2]|0;
   $49 = (($finfo) + 2|0);
   $50 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($47)|0);
   $51 = ($50|0)==(0|0);
   if ($51) {
    $72 = $26;
   } else {
    $52 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($47)|0);
    $53 = (($52) + 52|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + 44|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = $56 & 1;
    $58 = ($57<<24>>24)==(0);
    if ($58) {
     $72 = $26;
    } else {
     $59 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($48)|0);
     $60 = ($59|0)==(0|0);
     if ($60) {
      $72 = $26;
     } else {
      $61 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($48)|0);
      $62 = (($61) + 52|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 44|0);
      $65 = HEAP8[$64>>0]|0;
      $66 = $65 & 1;
      $67 = ($66<<24>>24)==(0);
      if ($67) {
       $72 = $26;
      } else {
       $68 = $24 & 1;
       $69 = ($68|0)==(0);
       if ($69) {
        $72 = $26;
       } else {
        $70 = $24 & 65534;
        $71 = $70&65535;
        $72 = $71;
       }
      }
     }
    }
   }
   HEAP16[$49>>1] = $72;
   $$pre34 = (($pair) + 6|0);
   $$pre$phiZ2D = $$pre34;$127 = $346;$347 = $72;$348 = $20;
  }
  $114 = HEAP16[$$pre$phiZ2D>>1]|0;
  $115 = $114&65535;
  $116 = $115 & 4;
  $117 = ($116|0)==(0);
  if ($117) {
   $134 = $348;$157 = $347;
  } else {
   $118 = HEAP32[$finfo>>2]|0;
   $119 = $118&65535;
   $120 = $119 & 12;
   $121 = ($120<<16>>16)==(12);
   $122 = $118 >>> 16;
   $123 = $122&65535;
   if ($121) {
    $134 = $119;$157 = $123;
   } else {
    $124 = $115 & 65531;
    $125 = $124&65535;
    HEAP16[$$pre$phiZ2D>>1] = $125;
    $126 = ($127|0)==(0|0);
    if ($126) {
     $134 = $119;$157 = $123;
    } else {
     $128 = (($finfo) + 4|0);
     __ZN5physx2Sc10NPhaseCore16deleteFilterPairEPNS0_10FilterPairE($this,$127);
     HEAP32[$128>>2] = 0;
     $134 = $119;$157 = $123;
    }
   }
  }
  $129 = (($pair) + 32|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($pair) + 36|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = $134&65535;
  $135 = $133 & 1;
  $136 = ($135|0)==(0);
  if ($136) {
   $137 = $133 & 2;
   $138 = ($137|0)==(0);
   if ($138) {
    $139 = (($130) + 28|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = (($140) + 64|0);
    $142 = HEAP8[$141>>0]|0;
    $143 = $142 & 4;
    $144 = ($143<<24>>24)==(0);
    if ($144) {
     $145 = (($132) + 28|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = (($146) + 64|0);
     $148 = HEAP8[$147>>0]|0;
     $149 = $148 & 4;
     $150 = ($149<<24>>24)==(0);
     $$$i = $150 ? 0 : 2;
     $154 = $$$i;
    } else {
     $154 = 2;
    }
   } else {
    $154 = 3;
   }
  } else {
   $154 = 6;
  }
  $151 = HEAP8[$2>>0]|0;
  $152 = $151&255;
  $153 = ($152|0)==($154|0);
  if (!($153)) {
   $155 = (__ZN5physx2Sc10NPhaseCore7convertEPNS0_21ElementSimInteractionENS0_15InteractionTypeERNS0_10FilterInfoE($this,$pair,$154,$finfo)|0);
   $$0 = $155;
   STACKTOP = sp;return ($$0|0);
  }
  if ((($4|0) == 2)) {
   $231 = (($pair) + 56|0);
   $232 = HEAP16[$231>>1]|0;
   $233 = $232&65535;
   $234 = $157&65535;
   $235 = $234 & 20;
   $236 = $233 & 65504;
   $237 = $236 | $235;
   $238 = $237&65535;
   HEAP16[$231>>1] = $238;
   $$0 = $pair;
   STACKTOP = sp;return ($$0|0);
  } else if ((($4|0) == 0)) {
   $156 = $157&65535;
   $158 = (($pair) + 44|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = $156 ^ $159;
   $161 = $160 & 32767;
   $162 = ($161|0)==(0);
   if (!($162)) {
    $163 = $159 & 6291456;
    $164 = ($163|0)==(0);
    do {
     if (!($164)) {
      $165 = $156 & 8;
      $166 = ($165|0)==(0);
      if ($166) {
       $167 = $159 & 2097152;
       $168 = ($167|0)==(0);
       if ($168) {
        $201 = $159 & -4194305;
        HEAP32[$158>>2] = $201;
        break;
       }
       $169 = (($pair) + 52|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = (($this) + 28|0);
       $172 = HEAP32[$171>>2]|0;
       $173 = ($170>>>0)<($172>>>0);
       if ($173) {
        $174 = (($172) + -1)|0;
        $175 = (($this) + 20|0);
        $176 = HEAP32[$175>>2]|0;
        $177 = ($172>>>0)>=($176>>>0);
        $178 = ($170|0)==($174|0);
        $or$cond$i = $177 | $178;
        if ($or$cond$i) {
         $186 = $172;$index$0$i = $170;
        } else {
         $179 = (($this) + 16|0);
         $180 = HEAP32[$179>>2]|0;
         $181 = (($180) + ($174<<2)|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = (($180) + ($170<<2)|0);
         HEAP32[$183>>2] = $182;
         $184 = (($182) + 52|0);
         HEAP32[$184>>2] = $170;
         $$pre$i = HEAP32[$171>>2]|0;
         $186 = $$pre$i;$index$0$i = $174;
        }
        $185 = (($186) + -1)|0;
        HEAP32[$171>>2] = $185;
        $$pre = HEAP32[$158>>2]|0;
        $$pre$phi$iZ2D = $175;$188 = $$pre;$index$1$i = $index$0$i;
       } else {
        $$pre1$i = (($this) + 20|0);
        $$pre$phi$iZ2D = $$pre1$i;$188 = $159;$index$1$i = $170;
       }
       $187 = $188 & -2097153;
       HEAP32[$158>>2] = $187;
       HEAP32[$169>>2] = (-1);
       $189 = HEAP32[$$pre$phi$iZ2D>>2]|0;
       $190 = (($189) + -1)|0;
       HEAP32[$$pre$phi$iZ2D>>2] = $190;
       $191 = (($this) + 16|0);
       $192 = HEAP32[$191>>2]|0;
       $193 = (($192) + ($190<<2)|0);
       $194 = HEAP32[$193>>2]|0;
       $195 = (($192) + ($index$1$i<<2)|0);
       HEAP32[$195>>2] = $194;
       $196 = ($index$1$i>>>0)<($190>>>0);
       if ($196) {
        $197 = HEAP32[$191>>2]|0;
        $198 = (($197) + ($index$1$i<<2)|0);
        $199 = HEAP32[$198>>2]|0;
        $200 = (($199) + 52|0);
        HEAP32[$200>>2] = $index$1$i;
       }
      }
     }
    } while(0);
    $202 = $159 & 448;
    $203 = ($202|0)==(0);
    if (!($203)) {
     $204 = $156 & 448;
     $205 = ($204|0)==(0);
     if ($205) {
      $206 = HEAP32[$158>>2]|0;
      $207 = $206 & -1572865;
      HEAP32[$158>>2] = $207;
      $208 = $206 & 8388608;
      $209 = ($208|0)==(0);
      if (!($209)) {
       $210 = (($pair) + 52|0);
       $211 = HEAP32[$210>>2]|0;
       $212 = $206 & -9961473;
       HEAP32[$158>>2] = $212;
       HEAP32[$210>>2] = (-1);
       $213 = (($this) + 36|0);
       $214 = HEAP32[$213>>2]|0;
       $215 = (($214) + -1)|0;
       HEAP32[$213>>2] = $215;
       $216 = (($this) + 32|0);
       $217 = HEAP32[$216>>2]|0;
       $218 = (($217) + ($215<<2)|0);
       $219 = HEAP32[$218>>2]|0;
       $220 = (($217) + ($211<<2)|0);
       HEAP32[$220>>2] = $219;
       $221 = ($211>>>0)<($215>>>0);
       if ($221) {
        $222 = HEAP32[$216>>2]|0;
        $223 = (($222) + ($211<<2)|0);
        $224 = HEAP32[$223>>2]|0;
        $225 = (($224) + 52|0);
        HEAP32[$225>>2] = $211;
       }
      }
     }
    }
   }
   $226 = HEAP32[$158>>2]|0;
   $227 = $157&65535;
   $228 = $227 & 32767;
   $229 = $226 & -32768;
   $230 = $228 | $229;
   HEAP32[$158>>2] = $230;
   $$0 = $pair;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0 = $pair;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sc10NPhaseCore7convertEPNS0_21ElementSimInteractionENS0_15InteractionTypeERNS0_10FilterInfoE($this,$pair,$newType,$filterInfo) {
 $this = $this|0;
 $pair = $pair|0;
 $newType = $newType|0;
 $filterInfo = $filterInfo|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = (($pair) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($pair) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($pair) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 51|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $12 = (($7) + 50|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(1);
  if ($14) {
   __ZN5physx2Sc7BodySim14internalWakeUpEf($7,Math_fround(0.399999976158142089844));
  }
 }
 $15 = (($pair) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 51|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  $21 = (($16) + 50|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)==(1);
  if ($23) {
   __ZN5physx2Sc7BodySim14internalWakeUpEf($16,Math_fround(0.399999976158142089844));
  }
 }
 if ((($newType|0) == 2)) {
  $51 = (($filterInfo) + 2|0);
  $52 = HEAP16[$51>>1]|0;
  HEAP16[$1>>1] = $52;
  $53 = (__ZN5physx2Sc10NPhaseCore24createTriggerInteractionERNS0_8ShapeSimES3_NS_7PxFlagsINS_10PxPairFlag4EnumEtEE($this,$3,$5,$1)|0);
  $result$0 = $53;
 } else if ((($newType|0) == 3)) {
  $24 = (($this) + 1888|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   $27 = (($this) + 1596|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($27);
   $$pre$i$i$i = HEAP32[$24>>2]|0;
   $29 = $$pre$i$i$i;
  } else {
   $29 = $25;
  }
  $28 = HEAP32[$29>>2]|0;
  HEAP32[$24>>2] = $28;
  $30 = (($this) + 1876|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 1)|0;
  HEAP32[$30>>2] = $32;
  $33 = (($this) + 1880|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + -1)|0;
  HEAP32[$33>>2] = $35;
  $36 = ($29|0)==(0|0);
  if ($36) {
   $47 = 0;
  } else {
   HEAP32[$29>>2] = ((463024 + 8|0));
   $37 = (($29) + 4|0);
   HEAP16[$37>>1] = -1;
   $38 = (($29) + 6|0);
   HEAP16[$38>>1] = 1;
   $39 = (($29) + 8|0);
   $40 = (($3) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($5) + 8|0);
   $43 = HEAP32[$42>>2]|0;
   __ZN5physx2Sc11InteractionC2ERNS0_5ActorES3_NS0_15InteractionTypeEh($39,$41,$43,3,5);
   $44 = (($29) + 32|0);
   HEAP32[$44>>2] = $3;
   $45 = (($29) + 36|0);
   HEAP32[$45>>2] = $5;
   HEAP32[$29>>2] = ((460552 + 8|0));
   $46 = (($29) + 8|0);
   HEAP32[$46>>2] = ((460552 + 52|0));
   $47 = $29;
  }
  __ZN5physx2Sc24ElementInteractionMarker10initializeEv($47);
  $result$0 = $47;
 } else if ((($newType|0) == 0)) {
  $48 = (($filterInfo) + 2|0);
  $49 = HEAP16[$48>>1]|0;
  HEAP16[$0>>1] = $49;
  $50 = (__ZN5physx2Sc10NPhaseCore25createShapeInstancePairLLERNS0_8ShapeSimES3_NS_7PxFlagsINS_10PxPairFlag4EnumEtEE($this,$3,$5,$0)|0);
  $result$0 = $50;
 } else {
  $result$0 = 0;
 }
 $54 = (($filterInfo) + 4|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = (($result$0) + 6|0);
  $58 = HEAP16[$57>>1]|0;
  $59 = $58&65535;
  $60 = $59 | 4;
  $61 = $60&65535;
  HEAP16[$57>>1] = $61;
  $62 = (($55) + 8|0);
  HEAP8[$62>>0] = 0;
  $63 = (($55) + 4|0);
  HEAP32[$63>>2] = $result$0;
 }
 $64 = (($pair) + 6|0);
 $65 = HEAP16[$64>>1]|0;
 $66 = $65&65535;
 $67 = $66 & 4;
 $68 = ($67|0)==(0);
 if ($68) {
  __ZN5physx2Sc10NPhaseCore18releaseElementPairEPNS0_21ElementSimInteractionEjj($this,$pair,4,0);
  STACKTOP = sp;return ($result$0|0);
 }
 $69 = $66 & 65531;
 $70 = $69&65535;
 HEAP16[$64>>1] = $70;
 __ZN5physx2Sc10NPhaseCore18releaseElementPairEPNS0_21ElementSimInteractionEjj($this,$pair,4,0);
 STACKTOP = sp;return ($result$0|0);
}
function __ZN5physx2Sc10NPhaseCore37removeFromPersistentContactEventPairsEPNS0_19ShapeInstancePairLLE($this,$sip) {
 $this = $this|0;
 $sip = $sip|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0 = 0, $index$1 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($sip) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  $5 = (($3) + -1)|0;
  $6 = (($this) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($3>>>0)>=($7>>>0);
  $9 = ($1|0)==($5|0);
  $or$cond = $8 | $9;
  if ($or$cond) {
   $17 = $3;$index$0 = $1;
  } else {
   $10 = (($this) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + ($5<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + ($1<<2)|0);
   HEAP32[$14>>2] = $13;
   $15 = (($13) + 52|0);
   HEAP32[$15>>2] = $1;
   $$pre = HEAP32[$2>>2]|0;
   $17 = $$pre;$index$0 = $5;
  }
  $16 = (($17) + -1)|0;
  HEAP32[$2>>2] = $16;
  $$pre$phiZ2D = $6;$index$1 = $index$0;
 } else {
  $$pre1 = (($this) + 20|0);
  $$pre$phiZ2D = $$pre1;$index$1 = $1;
 }
 $18 = (($sip) + 44|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & -2097153;
 HEAP32[$18>>2] = $20;
 HEAP32[$0>>2] = -1;
 $21 = HEAP32[$$pre$phiZ2D>>2]|0;
 $22 = (($21) + -1)|0;
 HEAP32[$$pre$phiZ2D>>2] = $22;
 $23 = (($this) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + ($22<<2)|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + ($index$1<<2)|0);
 HEAP32[$27>>2] = $26;
 $28 = ($index$1>>>0)<($22>>>0);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$23>>2]|0;
 $30 = (($29) + ($index$1<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 52|0);
 HEAP32[$32>>2] = $index$1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore41removeFromForceThresholdContactEventPairsEPNS0_19ShapeInstancePairLLE($this,$sip) {
 $this = $this|0;
 $sip = $sip|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($sip) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($sip) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & -8388609;
 HEAP32[$2>>2] = $4;
 HEAP32[$0>>2] = -1;
 $5 = (($this) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 HEAP32[$5>>2] = $7;
 $8 = (($this) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + ($1<<2)|0);
 HEAP32[$12>>2] = $11;
 $13 = ($1>>>0)<($7>>>0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$8>>2]|0;
 $15 = (($14) + ($1<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 52|0);
 HEAP32[$17>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore39pool_deleteParticleElementRbElementPairEPNS0_35ParticleElementRbElementInteractionEjj($this,$pair,$flags,$ccdPass) {
 $this = $this|0;
 $pair = $pair|0;
 $flags = $flags|0;
 $ccdPass = $ccdPass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($pair) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = (($3) + -1)<<16>>16;
 HEAP16[$2>>1] = $4;
 $5 = ($4<<16>>16)==(0);
 if ($5) {
  $6 = (($this) + 412|0);
  $7 = ($1|0)==(0|0);
  if (!($7)) {
   $8 = (($this) + 692|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + -1)|0;
   HEAP32[$8>>2] = $10;
   $11 = (($this) + 704|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$1>>2] = $12;
   HEAP32[$11>>2] = $1;
   $13 = (($this) + 696|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 1)|0;
   HEAP32[$13>>2] = $15;
   $16 = (($this) + 688|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17*50)|0;
   $19 = ($14|0)<($18|0);
   if (!($19)) {
    __ZN5physx6shdfnd8PoolBaseINS_2Sc16ActorElementPairENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($6);
    HEAP32[$13>>2] = 0;
   }
  }
 }
 $20 = $flags & 3;
 $21 = ($20|0)==(3);
 __ZN5physx2Sc35ParticleElementRbElementInteraction7destroyEbj($pair,$21,$ccdPass);
 $22 = (($this) + 1892|0);
 $23 = ($pair|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = HEAP32[$pair>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vi[$25 & 4095]($pair);
 $26 = (($this) + 2172|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + -1)|0;
 HEAP32[$26>>2] = $28;
 $29 = (($this) + 2184|0);
 $30 = HEAP32[$29>>2]|0;
 HEAP32[$pair>>2] = $30;
 HEAP32[$29>>2] = $pair;
 $31 = (($this) + 2176|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 1)|0;
 HEAP32[$31>>2] = $33;
 $34 = (($this) + 2168|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35*50)|0;
 $37 = ($32|0)<($36|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd8PoolBaseINS_2Sc35ParticleElementRbElementInteractionENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($22);
 HEAP32[$31>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore11narrowPhaseEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 1212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($2) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $sext = $4 << 2;
 $8 = $sext >> 2;
 $10 = $7;$i$01 = 0;
 while(1) {
  $9 = HEAP32[$10>>2]|0;
  $11 = ($9|0)==(0|0);
  if ($11) {
   $13 = 0;
  } else {
   $12 = (($9) + -8|0);
   $13 = $12;
  }
  __ZN5physx2Sc10NPhaseCore19findTriggerContactsEPNS0_18TriggerInteractionEbb($this,$13,0,0);
  $14 = (($13) + 56|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = $15&65535;
  $17 = $16 & 32;
  $18 = ($17|0)==(0);
  do {
   if ($18) {
    $19 = (($10) + 4|0);
    $31 = $19;
   } else {
    $20 = $16 & 65503;
    $21 = $20&65535;
    HEAP16[$14>>1] = $21;
    $22 = HEAP32[$13>>2]|0;
    $23 = (($22) + 20|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (FUNCTION_TABLE_iii[$24 & 4095]($13,0)|0);
    if ($25) {
     $29 = (($10) + 4|0);
     $31 = $29;
     break;
    } else {
     $26 = HEAP32[$1>>2]|0;
     $27 = ($13|0)==(0|0);
     $28 = (($13) + 8|0);
     $$ = $27 ? 0 : $28;
     __ZN5physx2Sc16InteractionScene28notifyInteractionDeactivatedEPNS0_11InteractionE($26,$$);
     $31 = $10;
     break;
    }
   }
  } while(0);
  $30 = (($i$01) + 1)|0;
  $exitcond = ($30|0)==($8|0);
  if ($exitcond) {
   break;
  } else {
   $10 = $31;$i$01 = $30;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore19findTriggerContactsEPNS0_18TriggerInteractionEbb($this,$tri,$toBeDeleted,$shapeDeleted) {
 $this = $this|0;
 $tri = $tri|0;
 $toBeDeleted = $toBeDeleted|0;
 $shapeDeleted = $shapeDeleted|0;
 var $$ = 0, $$5 = 0, $$pre$i = 0, $$pre$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $overlap$0$off0 = 0, $primitive0$primitive1$i = 0, $primitive1$primitive0$i = 0, $triggerPair = 0, $triggerPairExtra = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 68|0;
 $1 = sp;
 $triggerPair = sp + 32|0;
 $triggerPairExtra = sp + 56|0;
 $2 = (($tri) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($tri) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($tri) + 56|0);
 $7 = HEAP16[$6>>1]|0;
 if ($toBeDeleted) {
  if ($shapeDeleted) {
   $8 = HEAP32[$this>>2]|0;
   $9 = (($8) + 100|0);
   HEAP8[$9>>0] = 1;
   $overlap$0$off0 = 0;
  } else {
   $overlap$0$off0 = 0;
  }
 } else {
  $10 = HEAP32[$this>>2]|0;
  $11 = (($10) + 1192|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($3) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 68|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($5) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 68|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (((($12) + (($16*28)|0)|0) + ($20<<2)|0) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 1)|0;
  HEAP32[$21>>2] = $23;
  $24 = HEAP32[$13>>2]|0;
  $25 = (($24) + 68|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$17>>2]|0;
  $28 = (($27) + 68|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($26|0)>($29|0);
  $primitive1$primitive0$i = $30 ? $5 : $3;
  $primitive0$primitive1$i = $30 ? $3 : $5;
  $31 = (($primitive0$primitive1$i) + 28|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 68|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($primitive1$primitive0$i) + 28|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 68|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (__ZN5physx2Gu25GetGeomOverlapMethodTableEv()|0);
  $40 = ((($39) + (($38*28)|0)|0) + ($34<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = HEAP32[$35>>2]|0;
  $43 = (($42) + 68|0);
  __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($0,$primitive1$primitive0$i);
  $44 = HEAP32[$31>>2]|0;
  $45 = (($44) + 68|0);
  __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($1,$primitive0$primitive1$i);
  $46 = (($tri) + 40|0);
  $47 = (FUNCTION_TABLE_iiiiii[$41 & 255]($43,$0,$45,$1,$46)|0);
  $overlap$0$off0 = $47;
 }
 $48 = (($tri) + 58|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = ($49<<24>>24)==(0);
 if ($50) {
  $$5 = $overlap$0$off0 ? 4 : 0;
  $52 = $$5;
 } else {
  $$ = $overlap$0$off0 ? 0 : 16;
  $52 = $$;
 }
 $51 = $52 & $7;
 $53 = ($51<<16>>16)==(0);
 if ($53) {
  $119 = $overlap$0$off0&1;
  HEAP8[$48>>0] = $119;
  STACKTOP = sp;return;
 }
 $54 = (($triggerPair) + 20|0);
 HEAP8[$54>>0] = 0;
 $55 = (($3) + 28|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (__ZNK5physx2Sc9ShapeCore10getPxShapeEv($56)|0);
 HEAP32[$triggerPair>>2] = $57;
 $58 = (($5) + 28|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (__ZNK5physx2Sc9ShapeCore10getPxShapeEv($59)|0);
 $61 = (($triggerPair) + 8|0);
 HEAP32[$61>>2] = $60;
 $62 = $52&65535;
 $63 = (($triggerPair) + 16|0);
 HEAP32[$63>>2] = $62;
 $64 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($3)|0);
 $65 = (($64) + 52|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($5)|0);
 $68 = (($67) + 52|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($66)|0);
 $71 = (($triggerPair) + 4|0);
 HEAP32[$71>>2] = $70;
 $72 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($69)|0);
 $73 = (($triggerPair) + 12|0);
 HEAP32[$73>>2] = $72;
 $74 = (($3) + 20|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($5) + 20|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($66) + 13|0);
 $79 = HEAP8[$78>>0]|0;
 $80 = (($69) + 13|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = (($66) + 11|0);
 $83 = HEAP8[$82>>0]|0;
 $84 = (($69) + 11|0);
 $85 = HEAP8[$84>>0]|0;
 HEAP32[$triggerPairExtra>>2] = $75;
 $86 = (($triggerPairExtra) + 4|0);
 HEAP32[$86>>2] = $77;
 $87 = (($triggerPairExtra) + 8|0);
 HEAP8[$87>>0] = $79;
 $88 = (($triggerPairExtra) + 9|0);
 HEAP8[$88>>0] = $81;
 $89 = (($triggerPairExtra) + 10|0);
 HEAP8[$89>>0] = $83;
 $90 = (($triggerPairExtra) + 11|0);
 HEAP8[$90>>0] = $85;
 $91 = HEAP32[$this>>2]|0;
 $92 = (($91) + 84|0);
 $93 = (($91) + 92|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = $94 & 2147483647;
 $96 = (($91) + 88|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ($95>>>0)>($97>>>0);
 if ($98) {
  $99 = HEAP32[$92>>2]|0;
  $100 = (($99) + (($97*24)|0)|0);
  $101 = ($100|0)==(0|0);
  if ($101) {
   $104 = $97;
  } else {
   ;HEAP32[$100+0>>2]=HEAP32[$triggerPair+0>>2]|0;HEAP32[$100+4>>2]=HEAP32[$triggerPair+4>>2]|0;HEAP32[$100+8>>2]=HEAP32[$triggerPair+8>>2]|0;HEAP32[$100+12>>2]=HEAP32[$triggerPair+12>>2]|0;HEAP32[$100+16>>2]=HEAP32[$triggerPair+16>>2]|0;
   $102 = ((($99) + (($97*24)|0)|0) + 20|0);
   HEAP8[$102>>0] = 0;
   $$pre$i1 = HEAP32[$96>>2]|0;
   $104 = $$pre$i1;
  }
  $103 = (($104) + 1)|0;
  HEAP32[$96>>2] = $103;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($92,$triggerPair)|0);
 }
 $105 = HEAP32[$this>>2]|0;
 $106 = (($105) + 96|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($107) + 8|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = $109 & 2147483647;
 $111 = (($107) + 4|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ($110>>>0)>($112>>>0);
 if (!($113)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sc20TriggerPairExtraDataENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($107,$triggerPairExtra)|0);
  $119 = $overlap$0$off0&1;
  HEAP8[$48>>0] = $119;
  STACKTOP = sp;return;
 }
 $114 = HEAP32[$107>>2]|0;
 $115 = (($114) + (($112*12)|0)|0);
 $116 = ($115|0)==(0|0);
 if ($116) {
  $118 = $112;
 } else {
  ;HEAP32[$115+0>>2]=HEAP32[$triggerPairExtra+0>>2]|0;HEAP32[$115+4>>2]=HEAP32[$triggerPairExtra+4>>2]|0;HEAP32[$115+8>>2]=HEAP32[$triggerPairExtra+8>>2]|0;
  $$pre$i = HEAP32[$111>>2]|0;
  $118 = $$pre$i;
 }
 $117 = (($118) + 1)|0;
 HEAP32[$111>>2] = $117;
 $119 = $overlap$0$off0&1;
 HEAP8[$48>>0] = $119;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore9visualizeERNS_2Cm12RenderOutputE($this,$out) {
 $this = $this|0;
 $out = $out|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $prefetch$01 = 0, $prefetch$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 1416|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 == Math_fround(0.0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($0) + 1212|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + ($9<<2)|0);
 $11 = ($9|0)>(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($7) + 16|0);
 $$sum = (($9) + -1)|0;
 $13 = (($7) + ($$sum<<2)|0);
 $18 = $7;$prefetch$01 = $12;
 while(1) {
  $14 = ($prefetch$01>>>0)>($13>>>0);
  if ($14) {
   $prefetch$1 = $prefetch$01;
  } else {
   $15 = (($prefetch$01) + 4|0);
   $16 = HEAP32[$prefetch$01>>2]|0;
   $prefetch$1 = $15;
  }
  $17 = HEAP32[$18>>2]|0;
  $19 = ($17|0)==(0|0);
  if ($19) {
   $21 = 0;
  } else {
   $20 = (($17) + -8|0);
   $21 = $20;
  }
  __ZN5physx2Sc19ShapeInstancePairLL9visualizeERNS_2Cm12RenderOutputE($21,$out);
  $22 = (($18) + 4|0);
  $23 = ($22>>>0)<($10>>>0);
  if ($23) {
   $18 = $22;$prefetch$01 = $prefetch$1;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore30processPersistentContactEventsEv($this) {
 $this = $this|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $persistentEventPairs$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $$in = $1;$persistentEventPairs$01 = $4;
 while(1) {
  $5 = (($$in) + -1)|0;
  $6 = (($persistentEventPairs$01) + 4|0);
  $7 = HEAP32[$persistentEventPairs$01>>2]|0;
  $8 = ($5|0)==(0);
  if (!($8)) {
   $9 = HEAP32[$6>>2]|0;
  }
  $10 = (($7) + 48|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($7) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 & 8;
  $15 = ($14|0)==(0);
  if (!($15)) {
   __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($7,8,0,0,0,0);
  }
  if ($8) {
   break;
  } else {
   $$in = $5;$persistentEventPairs$01 = $6;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore28fireCustomFilteringCallbacksEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $filterFlags = 0, $finfo = 0, $finfo1 = 0, $interaction$07 = 0, $iter = 0, $pairFlags = 0, $pairID = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp + 32|0;
 $pairID = sp + 36|0;
 $filterFlags = sp + 42|0;
 $pairFlags = sp + 40|0;
 $finfo = sp;
 $finfo1 = sp + 24|0;
 $iter = sp + 8|0;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 1184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 1176|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,109,$6,$9);
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 1104|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $129 = HEAP32[$2>>2]|0;
  $130 = (($129) + 12|0);
  $131 = HEAP32[$130>>2]|0;
  FUNCTION_TABLE_viiii[$131 & 511]($2,109,$6,$9);
  STACKTOP = sp;return;
 }
 HEAP16[$filterFlags>>1] = 0;
 HEAP16[$pairFlags>>1] = 0;
 $17 = HEAP32[$15>>2]|0;
 $18 = (($17) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_iiiii[$19 & 511]($15,$pairID,$pairFlags,$filterFlags)|0);
 if (!($20)) {
  $129 = HEAP32[$2>>2]|0;
  $130 = (($129) + 12|0);
  $131 = HEAP32[$130>>2]|0;
  FUNCTION_TABLE_viiii[$131 & 511]($2,109,$6,$9);
  STACKTOP = sp;return;
 }
 $21 = (($this) + 80|0);
 $22 = (($finfo) + 2|0);
 $23 = (($finfo) + 4|0);
 $24 = (($finfo1) + 4|0);
 $25 = (($finfo1) + 2|0);
 $26 = (($iter) + 8|0);
 while(1) {
  $27 = HEAP32[$pairID>>2]|0;
  $28 = $27 & 31;
  $29 = $27 >>> 5;
  $30 = HEAP32[$21>>2]|0;
  $31 = (($30) + ($29<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + (($28*12)|0)|0);
  $34 = HEAP16[$filterFlags>>1]|0;
  $35 = $34 & 3;
  $36 = ($35<<16>>16)==(3);
  if ($36) {
   $37 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($37,2,460632,882,463144,$vararg_buffer);
   $38 = $34&65535;
   $39 = $38 & 65534;
   $40 = $39&65535;
   $41 = $40;
  } else {
   $41 = $34;
  }
  HEAP16[$filterFlags>>1] = $41;
  $42 = ((($32) + (($28*12)|0)|0) + 8|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = ($43<<24>>24)==(0);
  $45 = ((($32) + (($28*12)|0)|0) + 4|0);
  if ($44) {
   $46 = HEAP32[$45>>2]|0;
   $47 = $finfo;
   $48 = $47;
   HEAP32[$48>>2] = 0;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = 0;
   HEAP16[$finfo>>1] = $41;
   $51 = HEAP16[$pairFlags>>1]|0;
   HEAP16[$22>>1] = $51;
   HEAP32[$23>>2] = $33;
   $52 = (__ZN5physx2Sc10NPhaseCore19refilterInteractionEPNS0_21ElementSimInteractionEPKNS0_10FilterInfoE($this,$46,$finfo)|0);
   $53 = ($52|0)==($46|0);
   if ($53) {
    $58 = (($46) + 4|0);
    $59 = HEAP16[$58>>1]|0;
    $60 = $59&65535;
    $61 = $60 | 1;
    $62 = $61&65535;
    HEAP16[$58>>1] = $62;
    $63 = (($46) + 6|0);
    $64 = HEAP16[$63>>1]|0;
    $65 = $64 & 2;
    $66 = ($65<<16>>16)==(0);
    if ($66) {
     __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($46);
     $67 = HEAP16[$63>>1]|0;
     $68 = $67&65535;
     $69 = $68 | 2;
     $70 = $69&65535;
     HEAP16[$63>>1] = $70;
    }
    $71 = HEAP32[$46>>2]|0;
    $72 = (($71) + 8|0);
    $73 = HEAP32[$72>>2]|0;
    FUNCTION_TABLE_vi[$73 & 4095]($46);
   }
  } else {
   $74 = HEAP32[$45>>2]|0;
   $75 = $finfo1;
   $76 = $75;
   HEAP32[$76>>2] = 0;
   $77 = (($75) + 4)|0;
   $78 = $77;
   HEAP32[$78>>2] = 0;
   $79 = $41 & 12;
   $80 = ($79<<16>>16)==(12);
   if ($80) {
    HEAP32[$24>>2] = $33;
    $82 = $41;
   } else {
    __ZN5physx2Sc10NPhaseCore16deleteFilterPairEPNS0_10FilterPairE($this,$33);
    $81 = (($74) + 18|0);
    HEAP8[$81>>0] = 0;
    $$pre = HEAP16[$filterFlags>>1]|0;
    $82 = $$pre;
   }
   HEAP16[$finfo1>>1] = $82;
   $83 = HEAP16[$pairFlags>>1]|0;
   HEAP16[$25>>1] = $83;
   $84 = (($74) + 8|0);
   HEAP16[$84>>1] = $83;
   $85 = HEAP16[$filterFlags>>1]|0;
   $86 = $85&65535;
   $87 = $86 & 1;
   $88 = ($87|0)==(0);
   if ($88) {
    $90 = $86 & 2;
    $91 = ($90|0)==(0);
    if (!($91)) {
     $92 = (($74) + 19|0);
     HEAP8[$92>>0] = 1;
    }
   } else {
    $89 = (($74) + 20|0);
    HEAP8[$89>>0] = 1;
   }
   $93 = HEAP32[$74>>2]|0;
   $94 = (($74) + 4|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($97) + 20|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (($97) + 28|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (($99) + ($101<<2)|0);
   $103 = $99;
   $104 = $102;
   $105 = $iter;
   $106 = $105;
   HEAP32[$106>>2] = $103;
   $107 = (($105) + 4)|0;
   $108 = $107;
   HEAP32[$108>>2] = $104;
   HEAP32[$26>>2] = $95;
   $109 = (__ZN5physx2Sc7Element33ElementInteractionReverseIterator7getNextEv($iter)|0);
   $110 = ($109|0)==(0|0);
   if (!($110)) {
    $interaction$07 = $109;
    while(1) {
     $111 = (($interaction$07) + 21|0);
     $112 = HEAP8[$111>>0]|0;
     $113 = $112 & 8;
     $114 = ($113<<24>>24)==(0);
     if (!($114)) {
      $115 = (($interaction$07) + -8|0);
      $116 = (($115) + 36|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = ($117|0)==($95|0);
      if ($118) {
       $119 = (($115) + 12|0);
       $120 = HEAP32[$119>>2]|0;
       $121 = ($120|0)==($93|0);
       if ($121) {
        $122 = (__ZN5physx2Sc10NPhaseCore19refilterInteractionEPNS0_21ElementSimInteractionEPKNS0_10FilterInfoE($this,$115,$finfo1)|0);
        $123 = ($122|0)==($115|0);
        if ($123) {
         $124 = HEAP32[$115>>2]|0;
         $125 = (($124) + 8|0);
         $126 = HEAP32[$125>>2]|0;
         FUNCTION_TABLE_vi[$126 & 4095]($115);
        }
       }
      }
     }
     $127 = (__ZN5physx2Sc7Element33ElementInteractionReverseIterator7getNextEv($iter)|0);
     $128 = ($127|0)==(0|0);
     if ($128) {
      break;
     } else {
      $interaction$07 = $127;
     }
    }
   }
  }
  $54 = HEAP32[$15>>2]|0;
  $55 = (($54) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (FUNCTION_TABLE_iiiii[$56 & 511]($15,$pairID,$pairFlags,$filterFlags)|0);
  if (!($57)) {
   break;
  }
 }
 $129 = HEAP32[$2>>2]|0;
 $130 = (($129) + 12|0);
 $131 = HEAP32[$130>>2]|0;
 FUNCTION_TABLE_viiii[$131 & 511]($2,109,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore25addToDirtyInteractionListEPNS0_15CoreInteractionE($this,$pair) {
 $this = $this|0;
 $pair = $pair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $pair;
 $1 = (($this) + 68|0);
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = (($this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if (!($7)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc15CoreInteractionENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  HEAP32[$9>>2] = $pair;
 }
 $11 = (($6) + 1)|0;
 HEAP32[$5>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore30removeFromDirtyInteractionListEPNS0_15CoreInteractionE($this,$pair) {
 $this = $this|0;
 $pair = $pair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $i$04 = 0;
 while(1) {
  $7 = (($4) + ($i$04<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($pair|0);
  $6 = (($i$04) + 1)|0;
  if ($9) {
   break;
  }
  $5 = ($6>>>0)<($1>>>0);
  if ($5) {
   $i$04 = $6;
  } else {
   $$0 = 0;
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($1) + -1)|0;
 HEAP32[$0>>2] = $10;
 $11 = (($4) + ($10<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$7>>2] = $12;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc10NPhaseCore23updateDirtyInteractionsEv($this) {
 $this = $this|0;
 var $$in = 0, $$ph11 = 0, $$ph12 = 0, $$ph13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $or$cond8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 1196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 6;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = (($0) + 1212|0);
   $6 = HEAP32[$5>>2]|0;
   $8 = 460816;
   while(1) {
    $7 = HEAP32[$8>>2]|0;
    $9 = ((($6) + (($7*12)|0)|0) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ((($6) + (($7*12)|0)|0) + 20|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($8) + 4|0);
    $14 = ($12|0)<(1);
    $15 = ($13>>>0)<(((460816 + 12|0))>>>0);
    $or$cond8 = $14 & $15;
    if ($or$cond8) {
     $8 = $13;
    } else {
     break;
    }
   }
   $16 = (($10) + ($12<<2)|0);
   $$ph11 = $16;$$ph12 = $10;$$ph13 = $13;
   L6: while(1) {
    $18 = $$ph11;
    while(1) {
     $17 = ($$ph12>>>0)<($18>>>0);
     if (!($17)) {
      break L1;
     }
     $19 = (($18) + -4|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      $24 = 0;
     } else {
      $22 = (($20) + -8|0);
      $24 = $22;
     }
     $23 = (($24) + 4|0);
     $25 = HEAP16[$23>>1]|0;
     $26 = $25&65535;
     $27 = $26 | 65534;
     $28 = $27&65535;
     HEAP16[$23>>1] = $28;
     $29 = (($24) + 6|0);
     $30 = HEAP16[$29>>1]|0;
     $31 = $30 & 2;
     $32 = ($31<<16>>16)==(0);
     if ($32) {
      __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($24);
      $33 = HEAP16[$29>>1]|0;
      $34 = $33&65535;
      $35 = $34 | 2;
      $36 = $35&65535;
      HEAP16[$29>>1] = $36;
      $38 = $36;
     } else {
      $38 = $30;
     }
     $37 = $38 & 1;
     $39 = ($37<<16>>16)==(0);
     if ($39) {
      label = 14;
     } else {
      $40 = HEAP16[$23>>1]|0;
      $41 = $40 & 1;
      $42 = ($41<<16>>16)==(0);
      if ($42) {
       label = 14;
      } else {
       $43 = (__ZN5physx2Sc10NPhaseCore19refilterInteractionEPNS0_21ElementSimInteractionEPKNS0_10FilterInfoE($this,$24,0)|0);
       $44 = ($43|0)==($24|0);
       if ($44) {
        label = 14;
       }
      }
     }
     if ((label|0) == 14) {
      label = 0;
      $45 = HEAP32[$24>>2]|0;
      $46 = (($45) + 8|0);
      $47 = HEAP32[$46>>2]|0;
      FUNCTION_TABLE_vi[$47 & 4095]($24);
     }
     $48 = ($$ph12>>>0)<($19>>>0);
     if ($48) {
      $18 = $19;
     } else {
      $50 = $$ph13;$81 = $19;$82 = $$ph12;
      break;
     }
    }
    while(1) {
     $49 = ($50>>>0)<(((460816 + 12|0))>>>0);
     if (!($49)) {
      $$ph11 = $81;$$ph12 = $82;$$ph13 = $50;
      continue L6;
     }
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($6) + (($51*12)|0)|0) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($6) + (($51*12)|0)|0) + 20|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($53) + ($55<<2)|0);
     $57 = (($50) + 4|0);
     $58 = ($55|0)>(0);
     if ($58) {
      $$ph11 = $56;$$ph12 = $53;$$ph13 = $57;
      continue L6;
     } else {
      $50 = $57;$81 = $56;$82 = $53;
     }
    }
   }
  }
 } while(0);
 $59 = (($this) + 72|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0);
 if ($61) {
  HEAP32[$59>>2] = 0;
  STACKTOP = sp;return;
 }
 $62 = (($this) + 68|0);
 $$in = $60;
 while(1) {
  $63 = (($$in) + -1)|0;
  $64 = HEAP32[$62>>2]|0;
  $65 = (($64) + ($63<<2)|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + 6|0);
  $68 = HEAP16[$67>>1]|0;
  $69 = $68 & 1;
  $70 = ($69<<16>>16)==(0);
  if ($70) {
   label = 24;
  } else {
   $71 = (($66) + 4|0);
   $72 = HEAP16[$71>>1]|0;
   $73 = $72 & 1;
   $74 = ($73<<16>>16)==(0);
   if ($74) {
    label = 24;
   } else {
    $75 = (__ZN5physx2Sc10NPhaseCore19refilterInteractionEPNS0_21ElementSimInteractionEPKNS0_10FilterInfoE($this,$66,0)|0);
    $76 = ($75|0)==($66|0);
    if ($76) {
     label = 24;
    }
   }
  }
  if ((label|0) == 24) {
   label = 0;
   $78 = HEAP32[$66>>2]|0;
   $79 = (($78) + 8|0);
   $80 = HEAP32[$79>>2]|0;
   FUNCTION_TABLE_vi[$80 & 4095]($66);
  }
  $77 = ($63|0)==(0);
  if ($77) {
   break;
  } else {
   $$in = $63;
  }
 }
 HEAP32[$59>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore24releaseShapeInstancePairEPNS0_19ShapeInstancePairLLEjj($this,$npp,$flags,$ccdPass) {
 $this = $this|0;
 $npp = $npp|0;
 $flags = $flags|0;
 $ccdPass = $ccdPass|0;
 var $$$i = 0, $$0$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($npp) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($npp) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 476;
 $5 = ($4|0)==(0);
 $6 = $3 & 32768;
 $7 = ($6|0)==(0);
 $or$cond3 = $5 | $7;
 if (!($or$cond3)) {
  $8 = $flags & 1;
  $9 = ($8|0)!=(0);
  $10 = $3 >>> 11;
  $11 = $10 & 256;
  $12 = $11 | 16;
  $13 = $12 & $3;
  $14 = ($13|0)==(0);
  if (!($14)) {
   $15 = (($1) + 14|0);
   $16 = HEAP16[$15>>1]|0;
   $17 = ($16<<16>>16)==(1);
   $$$i = $17 ? 8 : 0;
   __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($npp,$13,$$$i,$9,1,$ccdPass);
  }
  if ($9) {
   $18 = HEAP32[$0>>2]|0;
   $19 = (($18) + 20|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    __ZNK5physx2Sc9ActorPair23createContactReportDataEv($18);
    $$pre$i$i$i = HEAP32[$19>>2]|0;
    $23 = $$pre$i$i$i;
   } else {
    $23 = $20;
   }
   $22 = (($23) + 10|0);
   $24 = HEAP16[$22>>1]|0;
   $25 = $24 & 8;
   $26 = ($25<<16>>16)==(0);
   if (!($26)) {
    __ZN5physx2Sc19ShapeInstancePairLL34setContactReportPostSolverVelocityERNS0_20ContactStreamManagerE($npp,$23);
   }
  }
 }
 $27 = HEAP32[$2>>2]|0;
 $28 = $27 & 32768;
 $29 = ($28|0)==(0);
 if ($29) {
  $30 = (($npp) + 56|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0|0);
  if ($32) {
   $37 = $27 & 98304;
   $$0$i = $37;
  } else {
   $33 = (($31) + 114|0);
   $34 = HEAP16[$33>>1]|0;
   $35 = $34&65535;
   $36 = $35 & 3;
   $$0$i = $36;
  }
  $38 = ($$0$i|0)==(0);
  if ($38) {
   label = 14;
  }
 } else {
  label = 14;
 }
 do {
  if ((label|0) == 14) {
   $39 = (($npp) + 32|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($40)|0);
   $42 = (($npp) + 36|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($43)|0);
   $45 = $flags & 4;
   $46 = ($45|0)==(0);
   if (!($46)) {
    $47 = ($41|0)==(0|0);
    $48 = ($44|0)==(0|0);
    $or$cond = $47 | $48;
    if (!($or$cond)) {
     $49 = HEAP32[$this>>2]|0;
     __ZN5physx2Sc5Scene18addToLostTouchListEPNS0_7BodySimES3_($49,$41,$44);
     break;
    }
    if (!($47)) {
     __ZN5physx2Sc7BodySim14internalWakeUpEf($41,Math_fround(0.399999976158142089844));
    }
    if (!($48)) {
     __ZN5physx2Sc7BodySim14internalWakeUpEf($44,Math_fround(0.399999976158142089844));
    }
   }
  }
 } while(0);
 $50 = HEAP32[$npp>>2]|0;
 $51 = (($50) + 24|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vi[$52 & 4095]($npp);
 $53 = (($this) + 708|0);
 $54 = ($npp|0)==(0|0);
 if (!($54)) {
  $55 = HEAP32[$npp>>2]|0;
  $56 = HEAP32[$55>>2]|0;
  FUNCTION_TABLE_vi[$56 & 4095]($npp);
  $57 = (($this) + 988|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + -1)|0;
  HEAP32[$57>>2] = $59;
  $60 = (($this) + 1000|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$npp>>2] = $61;
  HEAP32[$60>>2] = $npp;
  $62 = (($this) + 992|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($63) + 1)|0;
  HEAP32[$62>>2] = $64;
  $65 = (($this) + 984|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66*50)|0;
  $68 = ($63|0)<($67|0);
  if (!($68)) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($53);
   HEAP32[$62>>2] = 0;
  }
 }
 $69 = (($1) + 16|0);
 $70 = HEAP16[$69>>1]|0;
 $71 = ($70<<16>>16)==(0);
 if (!($71)) {
  STACKTOP = sp;return;
 }
 $72 = (($this) + 116|0);
 $73 = ($1|0)==(0|0);
 if ($73) {
  STACKTOP = sp;return;
 }
 $74 = (($1) + 20|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  __ZNK5physx2Sc9ActorPair24releaseContactReportDataEv($1);
 }
 $77 = HEAP32[$1>>2]|0;
 $78 = (($77) + 46|0);
 $79 = HEAP16[$78>>1]|0;
 $80 = (($79) + -1)<<16>>16;
 HEAP16[$78>>1] = $80;
 $81 = (($1) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($82) + 46|0);
 $84 = HEAP16[$83>>1]|0;
 $85 = (($84) + -1)<<16>>16;
 HEAP16[$83>>1] = $85;
 $86 = (($this) + 396|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($87) + -1)|0;
 HEAP32[$86>>2] = $88;
 $89 = (($this) + 408|0);
 $90 = HEAP32[$89>>2]|0;
 HEAP32[$1>>2] = $90;
 HEAP32[$89>>2] = $1;
 $91 = (($this) + 400|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + 1)|0;
 HEAP32[$91>>2] = $93;
 $94 = (($this) + 392|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95*50)|0;
 $97 = ($92|0)<($96|0);
 if ($97) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($72);
 HEAP32[$91>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore32addToPersistentContactEventPairsEPNS0_19ShapeInstancePairLLE($this,$sip) {
 $this = $this|0;
 $sip = $sip|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $firstDelayedSip = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $firstDelayedSip = sp;
 HEAP32[$0>>2] = $sip;
 $1 = (($sip) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 | 2097152;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 16|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  $10 = (($sip) + 52|0);
  HEAP32[$10>>2] = $6;
  $11 = (($this) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 & 2147483647;
  $14 = HEAP32[$5>>2]|0;
  $15 = ($13>>>0)>($14>>>0);
  if (!($15)) {
   (__ZN5physx6shdfnd5ArrayIPNS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($4,$0)|0);
   $37 = HEAP32[$7>>2]|0;
   $38 = (($37) + 1)|0;
   HEAP32[$7>>2] = $38;
   STACKTOP = sp;return;
  }
  $16 = HEAP32[$4>>2]|0;
  $17 = (($16) + ($14<<2)|0);
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   HEAP32[$17>>2] = $sip;
  }
  $19 = (($14) + 1)|0;
  HEAP32[$5>>2] = $19;
  $37 = HEAP32[$7>>2]|0;
  $38 = (($37) + 1)|0;
  HEAP32[$7>>2] = $38;
  STACKTOP = sp;return;
 } else {
  $20 = HEAP32[$4>>2]|0;
  $21 = (($20) + ($8<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$firstDelayedSip>>2] = $22;
  $23 = (($22) + 52|0);
  HEAP32[$23>>2] = $6;
  $24 = (($this) + 24|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 & 2147483647;
  $27 = HEAP32[$5>>2]|0;
  $28 = ($26>>>0)>($27>>>0);
  if ($28) {
   $29 = (($20) + ($27<<2)|0);
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    HEAP32[$29>>2] = $22;
   }
   $31 = (($27) + 1)|0;
   HEAP32[$5>>2] = $31;
  } else {
   (__ZN5physx6shdfnd5ArrayIPNS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($4,$firstDelayedSip)|0);
  }
  $32 = HEAP32[$7>>2]|0;
  $33 = (($sip) + 52|0);
  HEAP32[$33>>2] = $32;
  $34 = HEAP32[$7>>2]|0;
  $35 = HEAP32[$4>>2]|0;
  $36 = (($35) + ($34<<2)|0);
  HEAP32[$36>>2] = $sip;
  $37 = HEAP32[$7>>2]|0;
  $38 = (($37) + 1)|0;
  HEAP32[$7>>2] = $38;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc10NPhaseCore39addToPersistentContactEventPairsDelayedEPNS0_19ShapeInstancePairLLE($this,$sip) {
 $this = $this|0;
 $sip = $sip|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $sip;
 $1 = (($sip) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 | 2097152;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 16|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($sip) + 52|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = HEAP32[$5>>2]|0;
 $12 = ($10>>>0)>($11>>>0);
 if (!($12)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($4,$0)|0);
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$4>>2]|0;
 $14 = (($13) + ($11<<2)|0);
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  HEAP32[$14>>2] = $sip;
 }
 $16 = (($11) + 1)|0;
 HEAP32[$5>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore36addToForceThresholdContactEventPairsEPNS0_19ShapeInstancePairLLE($this,$sip) {
 $this = $this|0;
 $sip = $sip|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $sip;
 $1 = (($sip) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 | 8388608;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 32|0);
 $5 = (($this) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($sip) + 52|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = HEAP32[$5>>2]|0;
 $12 = ($10>>>0)>($11>>>0);
 if (!($12)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($4,$0)|0);
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$4>>2]|0;
 $14 = (($13) + ($11<<2)|0);
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  HEAP32[$14>>2] = $sip;
 }
 $16 = (($11) + 1)|0;
 HEAP32[$5>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10NPhaseCore28reserveContactReportPairDataEjjRj($this,$pairCount,$extraDataSize,$bufferIndex) {
 $this = $this|0;
 $pairCount = $pairCount|0;
 $extraDataSize = $extraDataSize|0;
 $bufferIndex = $bufferIndex|0;
 var $$0$i = 0, $$pre$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $nbBlocks$0$i1$i = 0;
 var $not$$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = $extraDataSize & 15;
 $not$$i$i = ($2|0)!=(0);
 $3 = $not$$i$i&1;
 $nbBlocks$0$i1$i = $3 << 4;
 $4 = (($nbBlocks$0$i1$i) + ($extraDataSize))|0;
 $5 = $4 & -16;
 $6 = (($this) + 44|0);
 $7 = $pairCount << 5;
 $8 = (($5) + ($7))|0;
 $9 = (($this) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 15)|0;
 $12 = $11 & -16;
 HEAP32[$bufferIndex>>2] = $12;
 $13 = (($12) + ($8))|0;
 $14 = (($this) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  $17 = (($this) + 64|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $21 = $15;
  } else {
   $$0$i = 0;
   STACKTOP = sp;return ($$0$i|0);
  }
  while(1) {
   $20 = $21 << 1;
   HEAP32[$14>>2] = $20;
   $22 = HEAP32[$bufferIndex>>2]|0;
   $23 = (($22) + ($8))|0;
   $24 = ($23>>>0)>($20>>>0);
   if ($24) {
    $21 = $20;
   } else {
    break;
   }
  }
  $25 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$20,463048,167)|0);
  $26 = HEAP32[$6>>2]|0;
  _memcpy(($25|0),($26|0),($15|0))|0;
  $27 = HEAP32[$6>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$27);
  HEAP32[$6>>2] = $25;
  $$pre$i = HEAP32[$bufferIndex>>2]|0;
  $29 = $25;$30 = $$pre$i;
 } else {
  $$pre3$i = HEAP32[$6>>2]|0;
  $29 = $$pre3$i;$30 = $12;
 }
 $28 = (($29) + ($30)|0);
 $31 = (($this) + 60|0);
 HEAP32[$31>>2] = $30;
 $32 = HEAP32[$9>>2]|0;
 $33 = (($8) - ($10))|0;
 $34 = (($33) + ($12))|0;
 $35 = (($34) + ($32))|0;
 HEAP32[$9>>2] = $35;
 $$0$i = $28;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx2Sc10NPhaseCore27resizeContactReportPairDataEjjRNS0_20ContactStreamManagerE($this,$pairCount,$extraDataSize,$csm) {
 $this = $this|0;
 $pairCount = $pairCount|0;
 $extraDataSize = $extraDataSize|0;
 $csm = $csm|0;
 var $$0$i = 0, $$0$i20 = 0, $$pre = 0, $$pre18 = 0, $$pre3$i = 0, $$pre3$i5 = 0, $$sum = 0, $$sum12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $nbBlocks$0$i1$i3 = 0, $not$$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$csm>>2]|0;
 $6 = (($4) + ($5)|0);
 $7 = $extraDataSize & 15;
 $not$$i$i2 = ($7|0)!=(0);
 $8 = $not$$i$i2&1;
 $nbBlocks$0$i1$i3 = $8 << 4;
 $9 = (($nbBlocks$0$i1$i3) + ($extraDataSize))|0;
 $10 = $9 & -16;
 $11 = $pairCount << 5;
 $12 = (($10) + ($11))|0;
 $13 = HEAP32[$csm>>2]|0;
 $14 = (($this) + 60|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($13|0);
 if ($16) {
  $40 = (($this) + 48|0);
  HEAP32[$40>>2] = $13;
  $41 = (($13) + 15)|0;
  $42 = $41 & -16;
  $43 = (($42) + ($12))|0;
  $44 = (($this) + 52|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($43>>>0)>($45>>>0);
  if ($46) {
   $47 = (($this) + 64|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    $51 = $45;
   } else {
    $$0$i20 = 0;
    STACKTOP = sp;return ($$0$i20|0);
   }
   while(1) {
    $50 = $51 << 1;
    $52 = ($43>>>0)>($50>>>0);
    if ($52) {
     $51 = $50;
    } else {
     break;
    }
   }
   HEAP32[$44>>2] = $50;
   $53 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$50,463048,167)|0);
   $54 = HEAP32[$3>>2]|0;
   _memcpy(($53|0),($54|0),($45|0))|0;
   $55 = HEAP32[$3>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$55);
   HEAP32[$3>>2] = $53;
   $$pre = HEAP32[$40>>2]|0;
   $57 = $53;$61 = $$pre;
  } else {
   $$pre3$i = HEAP32[$3>>2]|0;
   $57 = $$pre3$i;$61 = $13;
  }
  $56 = (($57) + ($42)|0);
  HEAP32[$14>>2] = $42;
  $58 = (($12) - ($13))|0;
  $59 = (($58) + ($42))|0;
  $60 = (($59) + ($61))|0;
  HEAP32[$40>>2] = $60;
  $$0$i = $56;$71 = $42;
 } else {
  $17 = (($this) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 15)|0;
  $20 = $19 & -16;
  $21 = (($20) + ($12))|0;
  $22 = (($this) + 52|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($21>>>0)>($23>>>0);
  if ($24) {
   $25 = (($this) + 64|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = ($26<<24>>24)==(0);
   if ($27) {
    $29 = $23;
   } else {
    $$0$i20 = 0;
    STACKTOP = sp;return ($$0$i20|0);
   }
   while(1) {
    $28 = $29 << 1;
    $30 = ($21>>>0)>($28>>>0);
    if ($30) {
     $29 = $28;
    } else {
     break;
    }
   }
   HEAP32[$22>>2] = $28;
   $31 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$28,463048,167)|0);
   $32 = HEAP32[$3>>2]|0;
   _memcpy(($31|0),($32|0),($23|0))|0;
   $33 = HEAP32[$3>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$33);
   HEAP32[$3>>2] = $31;
   $$pre18 = HEAP32[$17>>2]|0;
   $35 = $31;$39 = $$pre18;
  } else {
   $$pre3$i5 = HEAP32[$3>>2]|0;
   $35 = $$pre3$i5;$39 = $18;
  }
  $34 = (($35) + ($20)|0);
  HEAP32[$14>>2] = $20;
  $36 = (($12) - ($18))|0;
  $37 = (($36) + ($20))|0;
  $38 = (($37) + ($39))|0;
  HEAP32[$17>>2] = $38;
  $$0$i = $34;$71 = $20;
 }
 $62 = HEAP32[$3>>2]|0;
 $63 = HEAP32[$csm>>2]|0;
 $64 = (($62) + ($63)|0);
 $65 = ($$0$i|0)==(0|0);
 if ($65) {
  $$0$i20 = 0;
  STACKTOP = sp;return ($$0$i20|0);
 }
 $66 = (($csm) + 10|0);
 $67 = HEAP16[$66>>1]|0;
 $68 = $67&65535;
 $69 = $68 & 65520;
 $70 = ($63|0)==($71|0);
 $72 = ($10>>>0)>($69>>>0);
 if ($70) {
  if ($72) {
   $87 = (($$0$i) + ($10)|0);
   $$sum12 = (($69) + ($71))|0;
   $88 = (($62) + ($$sum12)|0);
   $89 = (($csm) + 6|0);
   $90 = HEAP16[$89>>1]|0;
   $91 = $90&65535;
   $92 = $91 << 5;
   _memmove(($87|0),($88|0),($92|0))|0;
  }
 } else {
  if ($72) {
   $78 = (($csm) + 8|0);
   $79 = HEAP16[$78>>1]|0;
   $80 = $79&65535;
   _memcpy(($$0$i|0),($64|0),($80|0))|0;
   $81 = (($$0$i) + ($10)|0);
   $$sum = (($69) + ($63))|0;
   $82 = (($62) + ($$sum)|0);
   $83 = (($csm) + 6|0);
   $84 = HEAP16[$83>>1]|0;
   $85 = $84&65535;
   $86 = $85 << 5;
   _memcpy(($81|0),($82|0),($86|0))|0;
  } else {
   $73 = (($csm) + 6|0);
   $74 = HEAP16[$73>>1]|0;
   $75 = $74&65535;
   $76 = $75 << 5;
   $77 = (($76) + ($69))|0;
   _memcpy(($$0$i|0),($64|0),($77|0))|0;
  }
  HEAP32[$csm>>2] = $71;
 }
 $93 = (($csm) + 4|0);
 $94 = HEAP16[$93>>1]|0;
 $95 = $94&65535;
 $96 = ($95>>>0)<($pairCount>>>0);
 if ($96) {
  $97 = $pairCount&65535;
  HEAP16[$93>>1] = $97;
 }
 if (!($72)) {
  $$0$i20 = $$0$i;
  STACKTOP = sp;return ($$0$i20|0);
 }
 $98 = HEAP16[$66>>1]|0;
 $99 = $98&65535;
 $100 = $99 & 15;
 $101 = $9 & 65520;
 $102 = $100 | $101;
 $103 = $102&65535;
 HEAP16[$66>>1] = $103;
 $$0$i20 = $$0$i;
 STACKTOP = sp;return ($$0$i20|0);
}
function __ZN5physx2Sc10NPhaseCore32createActorPairContactReportDataEv($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1592|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 1300|0);
  __ZN5physx6shdfnd8PoolBaseINS_2Sc26ActorPairContactReportDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($3);
  $$pre$i$i = HEAP32[$0>>2]|0;
  $5 = $$pre$i$i;
 } else {
  $5 = $1;
 }
 $4 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $4;
 $6 = (($this) + 1580|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 HEAP32[$6>>2] = $8;
 $9 = (($this) + 1584|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + -1)|0;
 HEAP32[$9>>2] = $11;
 $12 = ($5|0)==(0|0);
 if ($12) {
  $24 = 0;
  STACKTOP = sp;return ($24|0);
 }
 $13 = (($5) + 4|0);
 HEAP16[$13>>1] = 0;
 $14 = (($5) + 10|0);
 HEAP16[$14>>1] = 0;
 $15 = (($5) + 12|0);
 HEAP32[$15>>2] = (-1);
 $16 = (($5) + 16|0);
 HEAP32[$16>>2] = (-1);
 $17 = (($5) + 20|0);
 HEAP32[$17>>2] = (-1);
 $18 = (($5) + 24|0);
 HEAP32[$18>>2] = 0;
 $19 = (($5) + 28|0);
 HEAP32[$19>>2] = 0;
 $20 = (($5) + 32|0);
 HEAP8[$20>>0] = -1;
 $21 = (($5) + 33|0);
 HEAP8[$21>>0] = -1;
 $22 = (($5) + 34|0);
 HEAP8[$22>>0] = 0;
 $23 = (($5) + 35|0);
 HEAP8[$23>>0] = 0;
 $24 = $5;
 STACKTOP = sp;return ($24|0);
}
function __ZN5physx2Sc10NPhaseCore33releaseActorPairContactReportDataEPNS0_26ActorPairContactReportDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$c$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1300|0);
 $1 = ($data|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 1580|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 1592|0);
 $6 = HEAP32[$5>>2]|0;
 $$c$i$i = $6;
 HEAP32[$data>>2] = $$c$i$i;
 HEAP32[$5>>2] = $data;
 $7 = (($this) + 1584|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 1)|0;
 HEAP32[$7>>2] = $9;
 $10 = (($this) + 1576|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11*50)|0;
 $13 = ($8|0)<($12|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd8PoolBaseINS_2Sc26ActorPairContactReportDataENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc35ParticleElementRbElementInteractionENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 48)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 460944 : 460912;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,461112,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 460944 : 460912;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,461112,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 460944 : 460912;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,460832,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 460944 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 460944 : 460912;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,460832,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc16ActorElementPairENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 24)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 461200 : 460912;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,461112,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 461200 : 460912;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,461112,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 461200 : 460912;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,460832,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 461200 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 461200 : 460912;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,460832,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc26ActorPairContactReportDataENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 36)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 461328 : 460912;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,461112,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 461328 : 460912;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,461112,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 461328 : 460912;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,460832,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 461328 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 461328 : 460912;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,460832,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc26ActorPairContactReportDataENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$c = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 461328 : 460912;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,461480,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*36)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  $$c = $33;
  HEAP32[$34>>2] = $$c;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -36|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 461560 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc35ParticleElementRbElementInteractionENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 460944 : 460912;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,461480,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*48)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -48|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc9ActorPairENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc9ActorPairENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc9ActorPairENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 461704 : 460912;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,460832,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 24)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 461824 : 460912;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,461112,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 461824 : 460912;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,461112,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 461824 : 460912;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,460832,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 461824 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 461824 : 460912;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,460832,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 68)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 461944 : 460912;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,461112,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 461944 : 460912;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,461112,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 461944 : 460912;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,460832,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 461944 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 461944 : 460912;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,460832,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 40)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 462080 : 460912;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,461112,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 462080 : 460912;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,461112,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 462080 : 460912;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,460832,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 462080 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 462080 : 460912;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,460832,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc18TriggerInteractionENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 60)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 462224 : 460912;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,461112,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 462224 : 460912;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,461112,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 462224 : 460912;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,460832,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 462224 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 462224 : 460912;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,460832,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc15CoreInteractionENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 462360 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayINS_2Sc20TriggerPairExtraDataENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*12)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 462496 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*12)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;
   }
   $25 = (($$012$i) + 12|0);
   $26 = (($$03$i) + 12|0);
   $27 = ($25>>>0)<($20>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $19;
 }
 $28 = (($21) + (($29*12)|0)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  ;HEAP32[$28+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$a+8>>2]|0;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = HEAP32[$18>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$18>>2] = $40;
 $41 = (($21) + (($39*12)|0)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*24)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 462632 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*24)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
    $25 = (($$03$i) + 20|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = (($$012$i) + 20|0);
    HEAP8[$27>>0] = $26;
   }
   $28 = (($$012$i) + 24|0);
   $29 = (($$03$i) + 24|0);
   $30 = ($28>>>0)<($20>>>0);
   if ($30) {
    $$012$i = $28;$$03$i = $29;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $32 = $$pre;
 } else {
  $32 = $19;
 }
 $31 = (($21) + (($32*24)|0)|0);
 $33 = ($31|0)==(0|0);
 if (!($33)) {
  ;HEAP32[$31+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$31+16>>2]=HEAP32[$a+16>>2]|0;
  $34 = (($a) + 20|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ((($21) + (($32*24)|0)|0) + 20|0);
  HEAP8[$36>>0] = $35;
 }
 $37 = HEAP32[$0>>2]|0;
 $38 = ($37|0)>(-1);
 if (!($38)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $45 = HEAP32[$18>>2]|0;
  $46 = (($45) + 1)|0;
  HEAP32[$18>>2] = $46;
  $47 = (($21) + (($45*24)|0)|0);
  STACKTOP = sp;return ($47|0);
 }
 $39 = HEAP32[$this>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $45 = HEAP32[$18>>2]|0;
  $46 = (($45) + 1)|0;
  HEAP32[$18>>2] = $46;
  $47 = (($21) + (($45*24)|0)|0);
  STACKTOP = sp;return ($47|0);
 }
 $41 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($41,$39);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $45 = HEAP32[$18>>2]|0;
 $46 = (($45) + 1)|0;
 HEAP32[$18>>2] = $46;
 $47 = (($21) + (($45*24)|0)|0);
 STACKTOP = sp;return ($47|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 461824 : 460912;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,461480,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*24)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -24|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc10FilterPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 462752 : 460912;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,460832,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx2Cm11IndexedPoolINS_2Sc10FilterPairELj32EE6extendEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, $mAddr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mAddr = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,384,462944,186)|0);
 HEAP32[$mAddr>>2] = $2;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 12|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483616;
 $8 = ($7>>>0)<(32);
 if ($8) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc10FilterPairENS0_19ReflectionAllocatorIS4_EEE8recreateEj($4,32);
 }
 $9 = (($this) + 16|0);
 $10 = (($this) + 4|0);
 $i$05 = 31;
 while(1) {
  $11 = (($2) + (($i$05*12)|0)|0);
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = HEAP32[$10>>2]|0;
   $14 = $13 << 5;
   $15 = (($14) + ($i$05))|0;
   HEAP32[$11>>2] = $15;
  }
  $16 = (($2) + (($i$05*12)|0)|0);
  HEAP32[$1>>2] = $16;
  $17 = HEAP32[$5>>2]|0;
  $18 = $17 & 2147483647;
  $19 = HEAP32[$9>>2]|0;
  $20 = ($18>>>0)>($19>>>0);
  if ($20) {
   $21 = HEAP32[$4>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    HEAP32[$22>>2] = $16;
   }
   $24 = (($19) + 1)|0;
   HEAP32[$9>>2] = $24;
  } else {
   (__ZN5physx6shdfnd5ArrayIPNS_2Sc10FilterPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($4,$1)|0);
  }
  $25 = (($i$05) + -1)|0;
  $26 = ($i$05|0)>(0);
  if ($26) {
   $i$05 = $25;
  } else {
   break;
  }
 }
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 & 2147483647;
 $30 = HEAP32[$10>>2]|0;
 $31 = ($29>>>0)>($30>>>0);
 if ($31) {
  $32 = HEAP32[$this>>2]|0;
  $33 = (($32) + ($30<<2)|0);
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   HEAP32[$33>>2] = $2;
  }
  $35 = (($30) + 1)|0;
  HEAP32[$10>>2] = $35;
  $38 = $35;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc10FilterPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$mAddr)|0);
  $$pre = HEAP32[$10>>2]|0;
  $38 = $$pre;
 }
 $36 = (($this) + 24|0);
 $37 = $38 << 5;
 $39 = (($37) + -1)|0;
 $40 = $38 & 134217727;
 $41 = (($this) + 28|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 & 2147483647;
 $44 = ($40>>>0)>($43>>>0);
 if ($44) {
  $45 = (($this) + 32|0);
  $46 = $40 << 2;
  $47 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($45,$46,462872,339)|0);
  $48 = HEAP32[$36>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = HEAP32[$41>>2]|0;
   $51 = $50 << 2;
   _memcpy(($47|0),($48|0),($51|0))|0;
   $52 = HEAP32[$41>>2]|0;
   $53 = ($52|0)>(-1);
   if ($53) {
    $54 = HEAP32[$36>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($45,$54);
   }
  }
  $55 = HEAP32[$41>>2]|0;
  $56 = $55 & 2147483647;
  $57 = (($47) + ($56<<2)|0);
  $58 = (($40) - ($55))|0;
  $59 = $58 << 2;
  _memset(($57|0),0,($59|0))|0;
  HEAP32[$36>>2] = $47;
  HEAP32[$41>>2] = $40;
  $62 = $47;
 } else {
  $$pre$i = HEAP32[$36>>2]|0;
  $62 = $$pre$i;
 }
 $60 = $39 >>> 5;
 $61 = (($62) + ($60<<2)|0);
 $63 = HEAP32[$61>>2]|0;
 $64 = $63 & 2147483647;
 HEAP32[$61>>2] = $64;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc10FilterPairENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 462752 : 460912;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,460832,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15CoreInteractionD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15CoreInteractionD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 462080 : 460912;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,461480,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*40)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -40|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc18TriggerInteractionENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 462224 : 460912;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,461480,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*60)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -60|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 461944 : 460912;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,461480,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*68)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -68|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc16ActorElementPairENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 461200 : 460912;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,461480,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*24)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -24|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm11IndexedPoolINS_2Sc10FilterPairELj32EED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$03 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $i$03 = 0;
  while(1) {
   $4 = HEAP32[$this>>2]|0;
   $5 = (($4) + ($i$03<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
   $7 = HEAP32[$this>>2]|0;
   $8 = (($7) + ($i$03<<2)|0);
   HEAP32[$8>>2] = 0;
   $9 = (($i$03) + 1)|0;
   $10 = HEAP32[$1>>2]|0;
   $11 = ($9>>>0)<($10>>>0);
   if ($11) {
    $i$03 = $9;
   } else {
    break;
   }
  }
 }
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($this) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)>(-1);
  if ($17) {
   $18 = (($this) + 32|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($18,$13);
  }
 }
 $19 = (($this) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 2147483647;
 $22 = ($21|0)!=(0);
 $23 = ($20|0)>(-1);
 $or$cond$i$i1 = $22 & $23;
 if ($or$cond$i$i1) {
  $24 = (($this) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if (!($26)) {
   $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vii[$30 & 4095]($27,$25);
  }
 }
 $31 = (($this) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 & 2147483647;
 $34 = ($33|0)!=(0);
 $35 = ($32|0)>(-1);
 $or$cond$i$i = $34 & $35;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc9ActorPairENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc9ActorPairEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + (($31*24)|0)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $39 = (($tIt$02) + 20|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)==(0|0);
      if (!($41)) {
       __ZNK5physx2Sc9ActorPair24releaseContactReportDataEv($tIt$02);
      }
      $42 = HEAP32[$tIt$02>>2]|0;
      $43 = (($42) + 46|0);
      $44 = HEAP16[$43>>1]|0;
      $45 = (($44) + -1)<<16>>16;
      HEAP16[$43>>1] = $45;
      $46 = (($tIt$02) + 4|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + 46|0);
      $49 = HEAP16[$48>>1]|0;
      $50 = (($49) + -1)<<16>>16;
      HEAP16[$48>>1] = $50;
      $freeIt$2 = $freeIt$11;
     }
     $51 = (($tIt$02) + 24|0);
     $52 = ($51|0)==($32|0);
     if ($52) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $51;
     }
    }
   }
   $53 = (($slabIt$05) + 4|0);
   $54 = ($53|0)==($27|0);
   if ($54) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $53;
   }
  }
 }
 $55 = HEAP32[$4>>2]|0;
 $56 = $55 & 2147483647;
 $notlhs = ($56|0)==(0);
 $notrhs = ($55|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $57 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $57;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $58 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 FUNCTION_TABLE_vii[$61 & 4095]($58,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc16ActorElementPairENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc16ActorElementPairENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc16ActorElementPairENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc16ActorElementPairEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + (($30*24)|0)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 24|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ShapeInstancePairLLENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0;
 var $freeNodes = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ShapeInstancePairLLEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + (($31*68)|0)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $39 = HEAP32[$tIt$02>>2]|0;
      $40 = HEAP32[$39>>2]|0;
      FUNCTION_TABLE_vi[$40 & 4095]($tIt$02);
      $freeIt$2 = $freeIt$11;
     }
     $41 = (($tIt$02) + 68|0);
     $42 = ($41|0)==($32|0);
     if ($42) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $41;
     }
    }
   }
   $43 = (($slabIt$05) + 4|0);
   $44 = ($43|0)==($27|0);
   if ($44) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $43;
   }
  }
 }
 $45 = HEAP32[$4>>2]|0;
 $46 = $45 & 2147483647;
 $notlhs = ($46|0)==(0);
 $notrhs = ($45|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $47 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $47;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 FUNCTION_TABLE_vii[$51 & 4095]($48,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc18TriggerInteractionENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc18TriggerInteractionENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc18TriggerInteractionENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0;
 var $freeNodes = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc18TriggerInteractionEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + (($31*60)|0)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $39 = HEAP32[$tIt$02>>2]|0;
      $40 = HEAP32[$39>>2]|0;
      FUNCTION_TABLE_vi[$40 & 4095]($tIt$02);
      $freeIt$2 = $freeIt$11;
     }
     $41 = (($tIt$02) + 60|0);
     $42 = ($41|0)==($32|0);
     if ($42) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $41;
     }
    }
   }
   $43 = (($slabIt$05) + 4|0);
   $44 = ($43|0)==($27|0);
   if ($44) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $43;
   }
  }
 }
 $45 = HEAP32[$4>>2]|0;
 $46 = $45 & 2147483647;
 $notlhs = ($46|0)==(0);
 $notrhs = ($45|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $47 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $47;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 FUNCTION_TABLE_vii[$51 & 4095]($48,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc26ActorPairContactReportDataENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc26ActorPairContactReportDataENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc26ActorPairContactReportDataENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc26ActorPairContactReportDataEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + (($30*36)|0)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 36|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc24ElementInteractionMarkerENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0;
 var $freeNodes = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc24ElementInteractionMarkerEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + (($31*40)|0)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $39 = HEAP32[$tIt$02>>2]|0;
      $40 = HEAP32[$39>>2]|0;
      FUNCTION_TABLE_vi[$40 & 4095]($tIt$02);
      $freeIt$2 = $freeIt$11;
     }
     $41 = (($tIt$02) + 40|0);
     $42 = ($41|0)==($32|0);
     if ($42) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $41;
     }
    }
   }
   $43 = (($slabIt$05) + 4|0);
   $44 = ($43|0)==($27|0);
   if ($44) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $43;
   }
  }
 }
 $45 = HEAP32[$4>>2]|0;
 $46 = $45 & 2147483647;
 $notlhs = ($46|0)==(0);
 $notrhs = ($45|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $47 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $47;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 FUNCTION_TABLE_vii[$51 & 4095]($48,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc35ParticleElementRbElementInteractionENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc35ParticleElementRbElementInteractionENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc35ParticleElementRbElementInteractionENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0;
 var $freeNodes = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc35ParticleElementRbElementInteractionEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + (($31*48)|0)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $39 = HEAP32[$tIt$02>>2]|0;
      $40 = HEAP32[$39>>2]|0;
      FUNCTION_TABLE_vi[$40 & 4095]($tIt$02);
      $freeIt$2 = $freeIt$11;
     }
     $41 = (($tIt$02) + 48|0);
     $42 = ($41|0)==($32|0);
     if ($42) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $41;
     }
    }
   }
   $43 = (($slabIt$05) + 4|0);
   $44 = ($43|0)==($27|0);
   if ($44) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $43;
   }
  }
 }
 $45 = HEAP32[$4>>2]|0;
 $46 = $45 & 2147483647;
 $notlhs = ($46|0)==(0);
 $notrhs = ($45|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $47 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $47;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 FUNCTION_TABLE_vii[$51 & 4095]($48,$19);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7PhysicsC2ERKNS_17PxTolerancesScaleE($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=HEAP32[$scale+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$scale+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$scale+8>>2]|0;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = 0;
 HEAP32[463296>>2] = $this;
 __ZN5physx7PxvInitEv();
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7PhysicsD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
 }
 __ZN5physx7PxvTermEv();
 HEAP32[463296>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7Physics13registerClothEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN5physx5cloth7Factory13createFactoryENS1_8PlatformEPv(0,0)|0);
 HEAP32[$0>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9RigidCoreC2ENS_11PxActorType4EnumE($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc9ActorCoreC2ENS_11PxActorType4EnumEthhh($this,$type,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9RigidCoreD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9RigidCore15addShapeToSceneERNS0_9ShapeCoreE($this,$shapeCore) {
 $this = $this|0;
 $shapeCore = $shapeCore|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZNK5physx2Sc8ActorSim8getSceneEv($1)|0);
 __ZN5physx2Sc5Scene8addShapeERNS0_8RigidSimERNS0_9ShapeCoreE($3,$1,$shapeCore);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9RigidCore6getSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc9RigidCore20removeShapeFromSceneERNS0_9ShapeCoreEb($this,$shapeCore,$wakeOnLostTouch) {
 $this = $this|0;
 $shapeCore = $shapeCore|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZNK5physx2Sc8RigidSim14getSimForShapeERNS0_9ShapeCoreE($1,$shapeCore)|0);
 $4 = (__ZNK5physx2Sc8ActorSim8getSceneEv($1)|0);
 __ZN5physx2Sc5Scene11removeShapeERNS0_8ShapeSimEb($4,$3,$wakeOnLostTouch);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9RigidCore13onShapeChangeERNS0_9ShapeCoreENS_7PxFlagsINS0_21ShapeChangeNotifyFlag4EnumEjEENS4_INS_11PxShapeFlag4EnumEhEE($this,$shape,$notifyFlags,$oldShapeFlags) {
 $this = $this|0;
 $shape = $shape|0;
 $notifyFlags = $notifyFlags|0;
 $oldShapeFlags = $oldShapeFlags|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__ZNK5physx2Sc8RigidSim14getSimForShapeERNS0_9ShapeCoreE($2,$shape)|0);
 $5 = HEAP32[$notifyFlags>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $9 = $5;
 } else {
  __ZN5physx2Sc8ShapeSim16onGeometryChangeEv($4);
  $$pre = HEAP32[$notifyFlags>>2]|0;
  $9 = $$pre;
 }
 $8 = $9 & 2;
 $10 = ($8|0)==(0);
 if ($10) {
  $12 = $9;
 } else {
  __ZN5physx2Sc8ShapeSim16onMaterialChangeEv($4);
  $$pre7 = HEAP32[$notifyFlags>>2]|0;
  $12 = $$pre7;
 }
 $11 = $12 & 128;
 $13 = ($11|0)==(0);
 if ($13) {
  $15 = $12;
 } else {
  __ZN5physx2Sc8ShapeSim16onResetFilteringEv($4);
  $$pre8 = HEAP32[$notifyFlags>>2]|0;
  $15 = $$pre8;
 }
 $14 = $15 & 4;
 $16 = ($14|0)==(0);
 if ($16) {
  $18 = $15;
 } else {
  __ZN5physx2Sc8ShapeSim17onTransformChangeEv($4);
  $$pre9 = HEAP32[$notifyFlags>>2]|0;
  $18 = $$pre9;
 }
 $17 = $18 & 8;
 $19 = ($17|0)==(0);
 if ($19) {
  $21 = $18;
 } else {
  __ZN5physx2Sc8ShapeSim18onFilterDataChangeEv($4);
  $$pre10 = HEAP32[$notifyFlags>>2]|0;
  $21 = $$pre10;
 }
 $20 = $21 & 64;
 $22 = ($20|0)==(0);
 if ($22) {
  $25 = $21;
 } else {
  $23 = HEAP8[$oldShapeFlags>>0]|0;
  HEAP8[$0>>0] = $23;
  __ZN5physx2Sc8ShapeSim12onFlagChangeENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($4,$0);
  $$pre11 = HEAP32[$notifyFlags>>2]|0;
  $25 = $$pre11;
 }
 $24 = $25 & 32;
 $26 = ($24|0)==(0);
 if ($26) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc8ShapeSim18onRestOffsetChangeEv($4);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9RigidCore10getPxActorEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 10|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 if ((($2|0) == 0)) {
  $3 = (__Z14NpGetPxActorSCRN5physx2Sc10StaticCoreE($this)|0);
  $$0 = $3;
 } else if ((($2|0) == 1)) {
  $4 = (__Z14NpGetPxActorBCRN5physx2Sc8BodyCoreE($this)|0);
  $$0 = $4;
 } else if ((($2|0) == 4)) {
  $5 = (__Z31NpGetPxActorForArticulationLinkRN5physx2Sc8BodyCoreE($this)|0);
  $$0 = $5;
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc8RigidSimC2ERNS0_5SceneERNS0_9RigidCoreENS0_14IslandNodeInfo4TypeE($this,$scene,$core,$type) {
 $this = $this|0;
 $scene = $scene|0;
 $core = $core|0;
 $type = $type|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc8ActorSimC2ERNS0_5SceneERNS0_9ActorCoreENS0_14IslandNodeInfo4TypeE($this,$scene,$core,$type);
 HEAP32[$this>>2] = ((463312 + 8|0));
 $0 = (($scene) + 1208|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $10 = HEAP32[$1>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$1>>2] = $11;
  $$0$i$i = $10;
  $12 = (($this) + 56|0);
  HEAP32[$12>>2] = $$0$i$i;
  STACKTOP = sp;return;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$2>>2] = $5;
  $$0$i$i = $9;
  $12 = (($this) + 56|0);
  HEAP32[$12>>2] = $$0$i$i;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc8RigidSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((463312 + 8|0));
 $1 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $2 = (($1) + 1208|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx2Sc15ObjectIDTracker9releaseIDEj($3,$5);
 __ZN5physx2Sc8ActorSimD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8RigidSimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((463312 + 8|0));
 $0 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $1 = (($0) + 1208|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx2Sc15ObjectIDTracker9releaseIDEj($2,$4);
 __ZN5physx2Sc8ActorSimD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ObjectIDTracker9releaseIDEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $id;
 $1 = (($this) + 16|0);
 $2 = (($id) + 32)|0;
 $3 = $2 >>> 5;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = (($this) + 24|0);
  $9 = $3 << 2;
  $10 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($8,$9,463344,339)|0);
  $11 = HEAP32[$1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = HEAP32[$4>>2]|0;
   $14 = $13 << 2;
   _memcpy(($10|0),($11|0),($14|0))|0;
   $15 = HEAP32[$4>>2]|0;
   $16 = ($15|0)>(-1);
   if ($16) {
    $17 = HEAP32[$1>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($8,$17);
   }
  }
  $18 = HEAP32[$4>>2]|0;
  $19 = $18 & 2147483647;
  $20 = (($10) + ($19<<2)|0);
  $21 = (($3) - ($18))|0;
  $22 = $21 << 2;
  _memset(($20|0),0,($22|0))|0;
  HEAP32[$1>>2] = $10;
  HEAP32[$4>>2] = $3;
  $27 = $10;
 } else {
  $$pre$i$i = HEAP32[$1>>2]|0;
  $27 = $$pre$i$i;
 }
 $23 = $id & 31;
 $24 = 1 << $23;
 $25 = $id >>> 5;
 $26 = (($27) + ($25<<2)|0);
 $28 = HEAP32[$26>>2]|0;
 $29 = $28 | $24;
 HEAP32[$26>>2] = $29;
 $30 = (($this) + 28|0);
 $31 = (($this) + 36|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($this) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33>>>0)>($35>>>0);
 if (!($36)) {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($30,$0)|0);
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$30>>2]|0;
 $38 = (($37) + ($35<<2)|0);
 $39 = ($38|0)==(0|0);
 if ($39) {
  $41 = $35;
 } else {
  HEAP32[$38>>2] = $id;
  $$pre$i = HEAP32[$34>>2]|0;
  $41 = $$pre$i;
 }
 $40 = (($41) + 1)|0;
 HEAP32[$34>>2] = $40;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8RigidSim25notifyShapeTranformChangeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $e$0 = 0, $e$01 = 0, $e$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $e$01 = HEAP32[$0>>2]|0;
 $1 = ($e$01|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $e$02 = $e$01;
 }
 while(1) {
  $2 = (($e$02) + 12|0);
  $3 = $2;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $5 & -1073741824;
  $10 = ($9|0)==(0);
  $11 = (0)==(0);
  $12 = $10 & $11;
  if ($12) {
   __ZN5physx2Sc8ShapeSim17onTransformChangeEv($e$02);
  }
  $13 = (($e$02) + 4|0);
  $e$0 = HEAP32[$13>>2]|0;
  $14 = ($e$0|0)==(0|0);
  if ($14) {
   break;
  } else {
   $e$02 = $e$0;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8RigidSim14getSimForShapeERNS0_9ShapeCoreE($this,$core) {
 $this = $this|0;
 $core = $core|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $iterator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iterator = sp;
 HEAP32[$iterator>>2] = 0;
 __ZN5physx2Sc13ShapeIterator4initERKNS0_8ActorSimE($iterator,$this);
 while(1) {
  $0 = (__ZN5physx2Sc13ShapeIterator7getNextEv($iterator)|0);
  $1 = ($0|0)==(0|0);
  if ($1) {
   $$0 = (1);
   label = 4;
   break;
  }
  $2 = (($0) + 28|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==($core|0);
  if ($4) {
   $$0 = $0;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sc8RigidSim10getPxActorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx2Sc5SceneC2ERKNS_11PxSceneDescERNS_2Cm13EventProfilerE($this,$desc,$eventBuffer) {
 $this = $this|0;
 $desc = $desc|0;
 $eventBuffer = $eventBuffer|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$$i$i$i11 = 0, $$$i$i$i12 = 0, $$$i$i$i15 = 0, $$$i$i$i18 = 0, $$$i$i$i19 = 0, $$$i$i$i2 = 0, $$$i$i$i20 = 0, $$$i$i$i21 = 0, $$$i$i$i22 = 0, $$$i$i$i4 = 0, $$$i$i$i7 = 0, $$$i$i$i9 = 0, $$0$i$i$i = 0, $$lobit = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i14 = 0, $$pre$i$i$i$i$i17 = 0, $$tr = 0;
 var $$tr26 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = Math_fround(0), $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0), $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = Math_fround(0), $551 = 0, $552 = 0, $553 = Math_fround(0), $554 = 0, $555 = 0, $556 = Math_fround(0), $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0;
 var $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i$i = 0, $i$01$i = 0, $i$01$i$i = 0, $i$02$i = 0, $mask$01$i = 0, $or$cond$i = 0, $phitmp$i$i = 0, $scevgep = 0, $tmp$i$i$i$i16 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 18|0;
 $tmp$i$i$i$i16 = sp;
 $1 = sp + 16|0;
 $2 = sp + 12|0;
 $3 = sp + 17|0;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
 $4 = (($this) + 44|0);
 HEAP32[$4>>2] = 1;
 $5 = (($this) + 48|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 52|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 56|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 60|0);
 HEAP32[$8>>2] = 1;
 $9 = (($this) + 64|0);
 $10 = (($this) + 84|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 88|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 92|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 100|0);
 HEAP8[$13>>0] = 0;
 $14 = (($this) + 104|0);
 $15 = (($this) + 176|0);
 $16 = (($this) + 204|0);
 $17 = (($this) + 460|0);
 $18 = (($this) + 464|0);
 $19 = (($this) + 468|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 472|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
 dest=$14+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP32[$15+20>>2]=0|0;
 HEAP8[$17>>0] = 1;
 HEAP32[$18>>2] = $16;
 HEAP32[$20>>2] = 64;
 $21 = (($this) + 476|0);
 HEAP32[$21>>2] = 64;
 $22 = (($this) + 480|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 484|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 488|0);
 HEAP32[$24>>2] = 8192;
 $25 = (($this) + 492|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 500|0);
 $27 = (($this) + 756|0);
 $28 = (($this) + 760|0);
 $29 = (($this) + 764|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 768|0);
 HEAP8[$27>>0] = 1;
 HEAP32[$28>>2] = $26;
 HEAP32[$30>>2] = 64;
 $31 = (($this) + 772|0);
 HEAP32[$31>>2] = 32;
 $32 = (($this) + 776|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 780|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 784|0);
 HEAP32[$34>>2] = 8192;
 $35 = (($this) + 788|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 796|0);
 $37 = (($this) + 1052|0);
 $38 = (($this) + 1056|0);
 $39 = (($this) + 1060|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 1064|0);
 HEAP8[$37>>0] = 1;
 HEAP32[$38>>2] = $36;
 HEAP32[$40>>2] = 64;
 $41 = (($this) + 1068|0);
 HEAP32[$41>>2] = 21;
 $42 = (($this) + 1072|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 1076|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 1080|0);
 HEAP32[$44>>2] = 8192;
 $45 = (($this) + 1084|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 1088|0);
 HEAP32[$46>>2] = 0;
 $47 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,4115,471968,61)|0);
 $48 = ($47|0)==(0|0);
 if ($48) {
  $$0$i$i$i = 0;
 } else {
  $49 = (($47) + 19|0);
  $50 = $49;
  $51 = $50 & -16;
  $52 = $47;
  $53 = (($51) - ($52))|0;
  $54 = $51;
  $55 = (($54) + -4|0);
  HEAP32[$55>>2] = $53;
  $phitmp$i$i = $51;
  $$0$i$i$i = $phitmp$i$i;
 }
 $56 = (($this) + 1120|0);
 HEAP32[$56>>2] = $$0$i$i$i;
 $57 = (($this) + 1124|0);
 HEAP32[$57>>2] = 128;
 $i$01$i$i = 0;
 while(1) {
  $58 = ((($$0$i$i$i) + ($i$01$i$i<<5)|0) + 20|0);
  HEAP32[$58>>2] = -1;
  $59 = (($i$01$i$i) + 1)|0;
  $exitcond$i$i = ($59|0)==(128);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$01$i$i = $59;
  }
 }
 $60 = (($this) + 1136|0);
 $61 = (($this) + 1140|0);
 $62 = (($this) + 1162|0);
 $63 = (($desc) + 100|0);
 ;HEAP32[$60+0>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;HEAP32[$60+16>>2]=0|0;HEAP32[$60+20>>2]=0|0;
 $64 = HEAP16[$63>>1]|0;
 $65 = ($64&65535) >>> 14;
 $$tr = $65&255;
 $66 = $$tr & 1;
 HEAP8[$62>>0] = $66;
 $67 = (($this) + 1164|0);
 HEAP32[$67>>2] = 0;
 $68 = (($this) + 1168|0);
 HEAP32[$68>>2] = 0;
 $69 = (($this) + 1172|0);
 HEAP32[$69>>2] = 0;
 $70 = (($this) + 1176|0);
 $71 = $eventBuffer;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($71) + 4)|0;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = $70;
 $78 = $77;
 HEAP32[$78>>2] = $73;
 $79 = (($77) + 4)|0;
 $80 = $79;
 HEAP32[$80>>2] = $76;
 $81 = (($eventBuffer) + 8|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($this) + 1184|0);
 HEAP32[$83>>2] = $82;
 $84 = (($this) + 1196|0);
 HEAP32[$84>>2] = 0;
 $85 = (($this) + 1200|0);
 HEAP16[$85>>1] = $64;
 $86 = (($this) + 1216|0);
 HEAP32[$86>>2] = 0;
 $87 = (($this) + 1244|0);
 $88 = (($this) + 1272|0);
 $89 = (($this) + 1416|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 $90 = (($this) + 1420|0);
 HEAP8[$90>>0] = 0;
 $91 = (($this) + 1424|0);
 HEAP32[$91>>2] = 0;
 $92 = (($this) + 1428|0);
 HEAP32[$92>>2] = 0;
 $93 = (($this) + 1460|0);
 $94 = (($desc) + 152|0);
 ;HEAP32[$87+0>>2]=0|0;HEAP32[$87+4>>2]=0|0;HEAP32[$87+8>>2]=0|0;HEAP32[$87+12>>2]=0|0;HEAP32[$87+16>>2]=0|0;HEAP32[$87+20>>2]=0|0;
 ;HEAP32[$88+0>>2]=0|0;HEAP32[$88+4>>2]=0|0;HEAP32[$88+8>>2]=0|0;HEAP32[$88+12>>2]=0|0;
 $95 = HEAP32[$94>>2]|0;
 HEAP32[$93>>2] = $95;
 $96 = (($this) + 1464|0);
 __ZN5physx2Cm10FanoutTaskC2EPKc($96,463416);
 $97 = (($this) + 1556|0);
 $98 = (($this) + 1560|0);
 HEAP16[$98>>1] = -1;
 $99 = (($this) + 1562|0);
 HEAP16[$99>>1] = 0;
 $100 = (($this) + 1564|0);
 HEAP32[$100>>2] = 0;
 HEAP32[$97>>2] = ((434896 + 8|0));
 $101 = (($this) + 1568|0);
 HEAP32[$101>>2] = 0;
 $102 = (($this) + 1572|0);
 HEAP32[$102>>2] = 0;
 HEAP32[$97>>2] = ((471528 + 8|0));
 $103 = (($this) + 1576|0);
 HEAP32[$103>>2] = $this;
 $104 = (($this) + 1580|0);
 HEAP32[$104>>2] = 463448;
 $105 = (($this) + 1584|0);
 $106 = (($this) + 1588|0);
 HEAP16[$106>>1] = -1;
 $107 = (($this) + 1590|0);
 HEAP16[$107>>1] = 0;
 $108 = (($this) + 1592|0);
 HEAP32[$108>>2] = 0;
 HEAP32[$105>>2] = ((434896 + 8|0));
 $109 = (($this) + 1596|0);
 HEAP32[$109>>2] = 0;
 $110 = (($this) + 1600|0);
 HEAP32[$110>>2] = 0;
 HEAP32[$105>>2] = ((471480 + 8|0));
 $111 = (($this) + 1604|0);
 HEAP32[$111>>2] = $this;
 $112 = (($this) + 1608|0);
 HEAP32[$112>>2] = 463480;
 $113 = (($this) + 1612|0);
 __ZN5physx2Cm10FanoutTaskC2EPKc($113,463512);
 $114 = (($this) + 1704|0);
 __ZN5physx2Cm10FanoutTaskC2EPKc($114,463544);
 HEAP32[$114>>2] = ((471432 + 8|0));
 $115 = (($this) + 1796|0);
 HEAP32[$115>>2] = $this;
 $116 = (($this) + 1800|0);
 __ZN5physx2Cm10FanoutTaskC2EPKc($116,463576);
 HEAP32[$116>>2] = ((471384 + 8|0));
 $117 = (($this) + 1892|0);
 HEAP32[$117>>2] = $this;
 $118 = (($this) + 1896|0);
 $119 = (($this) + 1900|0);
 HEAP16[$119>>1] = -1;
 $120 = (($this) + 1902|0);
 HEAP16[$120>>1] = 0;
 $121 = (($this) + 1904|0);
 HEAP32[$121>>2] = 0;
 HEAP32[$118>>2] = ((434896 + 8|0));
 $122 = (($this) + 1908|0);
 HEAP32[$122>>2] = 0;
 $123 = (($this) + 1912|0);
 HEAP32[$123>>2] = 0;
 HEAP32[$118>>2] = ((471336 + 8|0));
 $124 = (($this) + 1916|0);
 HEAP32[$124>>2] = $this;
 $125 = (($this) + 1920|0);
 HEAP32[$125>>2] = 463608;
 $126 = (($this) + 1924|0);
 $127 = (($this) + 1964|0);
 $128 = (($this) + 1968|0);
 dest=$126+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP16[$128>>1] = -1;
 $129 = (($this) + 1970|0);
 HEAP16[$129>>1] = 0;
 $130 = (($this) + 1972|0);
 HEAP32[$130>>2] = 0;
 HEAP32[$127>>2] = ((434896 + 8|0));
 $131 = (($this) + 1976|0);
 HEAP32[$131>>2] = 0;
 $132 = (($this) + 1980|0);
 HEAP32[$132>>2] = 0;
 HEAP32[$127>>2] = ((471288 + 8|0));
 $133 = (($this) + 1984|0);
 HEAP32[$133>>2] = $this;
 $134 = (($this) + 1988|0);
 HEAP32[$134>>2] = 463640;
 $135 = (($this) + 1992|0);
 $136 = (($this) + 1996|0);
 HEAP16[$136>>1] = -1;
 $137 = (($this) + 1998|0);
 HEAP16[$137>>1] = 0;
 $138 = (($this) + 2000|0);
 HEAP32[$138>>2] = 0;
 HEAP32[$135>>2] = ((434896 + 8|0));
 $139 = (($this) + 2004|0);
 HEAP32[$139>>2] = 0;
 $140 = (($this) + 2008|0);
 HEAP32[$140>>2] = 0;
 HEAP32[$135>>2] = ((471240 + 8|0));
 $141 = (($this) + 2012|0);
 HEAP32[$141>>2] = $this;
 $142 = (($this) + 2016|0);
 HEAP32[$142>>2] = 463664;
 $143 = (($this) + 2020|0);
 $144 = (($this) + 2024|0);
 HEAP16[$144>>1] = -1;
 $145 = (($this) + 2026|0);
 HEAP16[$145>>1] = 0;
 $146 = (($this) + 2028|0);
 HEAP32[$146>>2] = 0;
 HEAP32[$143>>2] = ((434896 + 8|0));
 $147 = (($this) + 2032|0);
 HEAP32[$147>>2] = 0;
 $148 = (($this) + 2036|0);
 HEAP32[$148>>2] = 0;
 HEAP32[$143>>2] = ((471192 + 8|0));
 $149 = (($this) + 2040|0);
 HEAP32[$149>>2] = $this;
 $150 = (($this) + 2044|0);
 HEAP32[$150>>2] = 463696;
 $151 = (($this) + 2048|0);
 $152 = (($this) + 2052|0);
 HEAP16[$152>>1] = -1;
 $153 = (($this) + 2054|0);
 HEAP16[$153>>1] = 0;
 $154 = (($this) + 2056|0);
 HEAP32[$154>>2] = 0;
 HEAP32[$151>>2] = ((434896 + 8|0));
 $155 = (($this) + 2060|0);
 HEAP32[$155>>2] = 0;
 $156 = (($this) + 2064|0);
 HEAP32[$156>>2] = 0;
 HEAP32[$151>>2] = ((471144 + 8|0));
 $157 = (($this) + 2068|0);
 HEAP32[$157>>2] = $this;
 $158 = (($this) + 2072|0);
 HEAP32[$158>>2] = 463736;
 $159 = (($this) + 2076|0);
 $160 = (($this) + 2080|0);
 HEAP16[$160>>1] = -1;
 $161 = (($this) + 2082|0);
 HEAP16[$161>>1] = 0;
 $162 = (($this) + 2084|0);
 HEAP32[$162>>2] = 0;
 HEAP32[$159>>2] = ((434896 + 8|0));
 $163 = (($this) + 2088|0);
 HEAP32[$163>>2] = 0;
 $164 = (($this) + 2092|0);
 HEAP32[$164>>2] = 0;
 HEAP32[$159>>2] = ((471096 + 8|0));
 $165 = (($this) + 2096|0);
 HEAP32[$165>>2] = $this;
 $166 = (($this) + 2100|0);
 HEAP32[$166>>2] = 463768;
 $167 = (($this) + 2104|0);
 $168 = (($this) + 2108|0);
 HEAP16[$168>>1] = -1;
 $169 = (($this) + 2110|0);
 HEAP16[$169>>1] = 0;
 $170 = (($this) + 2112|0);
 HEAP32[$170>>2] = 0;
 HEAP32[$167>>2] = ((434896 + 8|0));
 $171 = (($this) + 2116|0);
 HEAP32[$171>>2] = 0;
 $172 = (($this) + 2120|0);
 HEAP32[$172>>2] = 0;
 HEAP32[$167>>2] = ((471048 + 8|0));
 $173 = (($this) + 2124|0);
 HEAP32[$173>>2] = $this;
 $174 = (($this) + 2128|0);
 HEAP32[$174>>2] = 463800;
 $175 = (($this) + 2132|0);
 $176 = (($this) + 2136|0);
 HEAP16[$176>>1] = -1;
 $177 = (($this) + 2138|0);
 HEAP16[$177>>1] = 0;
 $178 = (($this) + 2140|0);
 HEAP32[$178>>2] = 0;
 HEAP32[$175>>2] = ((434896 + 8|0));
 $179 = (($this) + 2144|0);
 HEAP32[$179>>2] = 0;
 $180 = (($this) + 2148|0);
 HEAP32[$180>>2] = 0;
 HEAP32[$175>>2] = ((471000 + 8|0));
 $181 = (($this) + 2152|0);
 HEAP32[$181>>2] = $this;
 $182 = (($this) + 2156|0);
 HEAP32[$182>>2] = 463824;
 $183 = (($this) + 2160|0);
 __ZN5physx2Cm10FanoutTaskC2EPKc($183,463856);
 HEAP32[$183>>2] = ((470744 + 8|0));
 $184 = (($this) + 2252|0);
 HEAP32[$184>>2] = $this;
 $185 = (($this) + 2256|0);
 $186 = (($this) + 2260|0);
 HEAP16[$186>>1] = -1;
 $187 = (($this) + 2262|0);
 HEAP16[$187>>1] = 0;
 $188 = (($this) + 2264|0);
 HEAP32[$188>>2] = 0;
 HEAP32[$185>>2] = ((434896 + 8|0));
 $189 = (($this) + 2268|0);
 HEAP32[$189>>2] = 0;
 $190 = (($this) + 2272|0);
 HEAP32[$190>>2] = 0;
 HEAP32[$185>>2] = ((470696 + 8|0));
 $191 = (($this) + 2276|0);
 HEAP32[$191>>2] = $this;
 $192 = (($this) + 2280|0);
 HEAP32[$192>>2] = 463888;
 $193 = (($this) + 2284|0);
 $194 = (($this) + 2288|0);
 HEAP16[$194>>1] = -1;
 $195 = (($this) + 2290|0);
 HEAP16[$195>>1] = 0;
 $196 = (($this) + 2292|0);
 HEAP32[$196>>2] = 0;
 HEAP32[$193>>2] = ((434896 + 8|0));
 $197 = (($this) + 2296|0);
 HEAP32[$197>>2] = 0;
 $198 = (($this) + 2300|0);
 HEAP32[$198>>2] = 0;
 HEAP32[$193>>2] = ((470648 + 8|0));
 $199 = (($this) + 2304|0);
 HEAP32[$199>>2] = $this;
 $200 = (($this) + 2308|0);
 HEAP32[$200>>2] = 463912;
 $201 = (($this) + 2312|0);
 $202 = (($this) + 2316|0);
 HEAP16[$202>>1] = -1;
 $203 = (($this) + 2318|0);
 HEAP16[$203>>1] = 0;
 $204 = (($this) + 2320|0);
 HEAP32[$204>>2] = 0;
 HEAP32[$201>>2] = ((434896 + 8|0));
 $205 = (($this) + 2324|0);
 HEAP32[$205>>2] = 0;
 $206 = (($this) + 2328|0);
 HEAP32[$206>>2] = 0;
 HEAP32[$201>>2] = ((470600 + 8|0));
 $207 = (($this) + 2332|0);
 HEAP32[$207>>2] = $this;
 $208 = (($this) + 2336|0);
 HEAP32[$208>>2] = 463936;
 $209 = (($this) + 2340|0);
 __ZN5physx2Cm9FlushPoolC2Ej($209,16384);
 $210 = (($this) + 2372|0);
 HEAP8[$210>>0] = 0;
 $211 = (($this) + 2376|0);
 HEAP32[$211>>2] = 0;
 $212 = (($this) + 152|0);
 dest=$212+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $213 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = (($214) + 8|0);
 $216 = HEAP32[$215>>2]|0;
 $217 = (__Z15PxGetFoundationv()|0);
 $218 = HEAP32[$217>>2]|0;
 $219 = (($218) + 24|0);
 $220 = HEAP32[$219>>2]|0;
 $221 = (FUNCTION_TABLE_ii[$220 & 4095]($217)|0);
 $$$i$i$i21 = $221 ? 470472 : 464392;
 $222 = (FUNCTION_TABLE_iiiiii[$216 & 255]($213,1012,$$$i$i$i21,463960,182)|0);
 __ZN5physx2Sc16InteractionSceneC2ERNS0_5SceneE($222,$this);
 $223 = (($this) + 1212|0);
 HEAP32[$223>>2] = $222;
 $224 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $225 = HEAP32[$224>>2]|0;
 $226 = (($225) + 8|0);
 $227 = HEAP32[$226>>2]|0;
 $228 = (__Z15PxGetFoundationv()|0);
 $229 = HEAP32[$228>>2]|0;
 $230 = (($229) + 24|0);
 $231 = HEAP32[$230>>2]|0;
 $232 = (FUNCTION_TABLE_ii[$231 & 4095]($228)|0);
 $$$i$i$i22 = $232 ? 470360 : 464392;
 $233 = (FUNCTION_TABLE_iiiiii[$227 & 255]($224,188,$$$i$i$i22,463960,183)|0);
 __ZN5physx2Sc8SimStatsC2Ev($233);
 $234 = (($this) + 1192|0);
 HEAP32[$234>>2] = $233;
 $235 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $236 = HEAP32[$235>>2]|0;
 $237 = (($236) + 8|0);
 $238 = HEAP32[$237>>2]|0;
 $239 = (__Z15PxGetFoundationv()|0);
 $240 = HEAP32[$239>>2]|0;
 $241 = (($240) + 24|0);
 $242 = HEAP32[$241>>2]|0;
 $243 = (FUNCTION_TABLE_ii[$242 & 4095]($239)|0);
 $$$i$i$i20 = $243 ? 470232 : 464392;
 $244 = (FUNCTION_TABLE_iiiiii[$238 & 255]($235,40,$$$i$i$i20,463960,184)|0);
 $245 = (($244) + 28|0);
 HEAP32[$245>>2] = 0;
 $246 = (($244) + 32|0);
 HEAP32[$246>>2] = 0;
 $247 = (($244) + 36|0);
 HEAP32[$247>>2] = 0;
 ;HEAP32[$244+0>>2]=0|0;HEAP32[$244+4>>2]=0|0;HEAP32[$244+8>>2]=0|0;HEAP32[$244+12>>2]=0|0;HEAP32[$244+16>>2]=0|0;HEAP32[$244+20>>2]=0|0;
 $248 = (($this) + 1204|0);
 HEAP32[$248>>2] = $244;
 $249 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $250 = HEAP32[$249>>2]|0;
 $251 = (($250) + 8|0);
 $252 = HEAP32[$251>>2]|0;
 $253 = (__Z15PxGetFoundationv()|0);
 $254 = HEAP32[$253>>2]|0;
 $255 = (($254) + 24|0);
 $256 = HEAP32[$255>>2]|0;
 $257 = (FUNCTION_TABLE_ii[$256 & 4095]($253)|0);
 $$$i$i$i19 = $257 ? 470232 : 464392;
 $258 = (FUNCTION_TABLE_iiiiii[$252 & 255]($249,40,$$$i$i$i19,463960,185)|0);
 $259 = (($258) + 28|0);
 HEAP32[$259>>2] = 0;
 $260 = (($258) + 32|0);
 HEAP32[$260>>2] = 0;
 $261 = (($258) + 36|0);
 HEAP32[$261>>2] = 0;
 ;HEAP32[$258+0>>2]=0|0;HEAP32[$258+4>>2]=0|0;HEAP32[$258+8>>2]=0|0;HEAP32[$258+12>>2]=0|0;HEAP32[$258+16>>2]=0|0;HEAP32[$258+20>>2]=0|0;
 $262 = (($this) + 1208|0);
 HEAP32[$262>>2] = $258;
 $263 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,12,463960,187)|0);
 $264 = (($this) + 96|0);
 HEAP32[$264>>2] = $263;
 $265 = ($263|0)==(0|0);
 if (!($265)) {
  HEAP32[$263>>2] = 0;
  $266 = (($263) + 4|0);
  HEAP32[$266>>2] = 0;
  $267 = (($263) + 8|0);
  HEAP32[$267>>2] = 0;
 }
 $268 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $269 = HEAP32[$268>>2]|0;
 $270 = (($269) + 8|0);
 $271 = HEAP32[$270>>2]|0;
 $272 = (__Z15PxGetFoundationv()|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = (($273) + 24|0);
 $275 = HEAP32[$274>>2]|0;
 $276 = (FUNCTION_TABLE_ii[$275 & 4095]($272)|0);
 $$$i$i$i18 = $276 ? 470056 : 464392;
 $277 = (FUNCTION_TABLE_iiiiii[$271 & 255]($268,32,$$$i$i$i18,463960,190)|0);
 HEAP32[$277>>2] = 64;
 $278 = (($277) + 4|0);
 HEAP32[$278>>2] = 60;
 $279 = (($277) + 8|0);
 $280 = (($277) + 12|0);
 $281 = (($277) + 16|0);
 $282 = (($277) + 20|0);
 $283 = (($277) + 24|0);
 ;HEAP32[$279+0>>2]=0|0;HEAP32[$279+4>>2]=0|0;HEAP32[$279+8>>2]=0|0;HEAP32[$279+12>>2]=0|0;
 HEAP8[$283>>0] = 1;
 $284 = (($277) + 28|0);
 HEAP32[$284>>2] = 464048;
 $285 = (($tmp$i$i$i$i16) + 4|0);
 $286 = (($tmp$i$i$i$i16) + 8|0);
 HEAP32[$285>>2] = 0;
 HEAP32[$286>>2] = 0;
 $287 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,3840,465496,60)|0);
 HEAP32[$tmp$i$i$i$i16>>2] = $287;
 $288 = HEAP32[$282>>2]|0;
 $289 = $288 & 2147483647;
 $290 = HEAP32[$281>>2]|0;
 $291 = ($289>>>0)>($290>>>0);
 if ($291) {
  $292 = HEAP32[$280>>2]|0;
  $293 = (($292) + (($290*12)|0)|0);
  $294 = ($293|0)==(0|0);
  if ($294) {
   $296 = $290;
  } else {
   ;HEAP32[$293+0>>2]=HEAP32[$tmp$i$i$i$i16+0>>2]|0;HEAP32[$293+4>>2]=HEAP32[$tmp$i$i$i$i16+4>>2]|0;HEAP32[$293+8>>2]=HEAP32[$tmp$i$i$i$i16+8>>2]|0;
   $$pre$i$i$i$i$i17 = HEAP32[$281>>2]|0;
   $296 = $$pre$i$i$i$i$i17;
  }
  $295 = (($296) + 1)|0;
  HEAP32[$281>>2] = $295;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Cm19PreallocatingRegionENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($280,$tmp$i$i$i$i16)|0);
 }
 $297 = (($this) + 1224|0);
 HEAP32[$297>>2] = $277;
 $298 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $299 = HEAP32[$298>>2]|0;
 $300 = (($299) + 8|0);
 $301 = HEAP32[$300>>2]|0;
 $302 = (__Z15PxGetFoundationv()|0);
 $303 = HEAP32[$302>>2]|0;
 $304 = (($303) + 24|0);
 $305 = HEAP32[$304>>2]|0;
 $306 = (FUNCTION_TABLE_ii[$305 & 4095]($302)|0);
 $$$i$i$i15 = $306 ? 469880 : 464392;
 $307 = (FUNCTION_TABLE_iiiiii[$301 & 255]($298,32,$$$i$i$i15,463960,191)|0);
 HEAP32[$307>>2] = 64;
 $308 = (($307) + 4|0);
 HEAP32[$308>>2] = 192;
 $309 = (($307) + 8|0);
 $310 = (($307) + 12|0);
 $311 = (($307) + 16|0);
 $312 = (($307) + 20|0);
 $313 = (($307) + 24|0);
 ;HEAP32[$309+0>>2]=0|0;HEAP32[$309+4>>2]=0|0;HEAP32[$309+8>>2]=0|0;HEAP32[$309+12>>2]=0|0;
 HEAP8[$313>>0] = 1;
 $314 = (($307) + 28|0);
 HEAP32[$314>>2] = 464064;
 $315 = (($tmp$i$i$i$i16) + 4|0);
 $316 = (($tmp$i$i$i$i16) + 8|0);
 HEAP32[$315>>2] = 0;
 HEAP32[$316>>2] = 0;
 $317 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,12288,465496,60)|0);
 HEAP32[$tmp$i$i$i$i16>>2] = $317;
 $318 = HEAP32[$312>>2]|0;
 $319 = $318 & 2147483647;
 $320 = HEAP32[$311>>2]|0;
 $321 = ($319>>>0)>($320>>>0);
 if ($321) {
  $322 = HEAP32[$310>>2]|0;
  $323 = (($322) + (($320*12)|0)|0);
  $324 = ($323|0)==(0|0);
  if ($324) {
   $326 = $320;
  } else {
   ;HEAP32[$323+0>>2]=HEAP32[$tmp$i$i$i$i16+0>>2]|0;HEAP32[$323+4>>2]=HEAP32[$tmp$i$i$i$i16+4>>2]|0;HEAP32[$323+8>>2]=HEAP32[$tmp$i$i$i$i16+8>>2]|0;
   $$pre$i$i$i$i$i14 = HEAP32[$311>>2]|0;
   $326 = $$pre$i$i$i$i$i14;
  }
  $325 = (($326) + 1)|0;
  HEAP32[$311>>2] = $325;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Cm19PreallocatingRegionENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($310,$tmp$i$i$i$i16)|0);
 }
 $327 = (($this) + 1228|0);
 HEAP32[$327>>2] = $307;
 $328 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $329 = HEAP32[$328>>2]|0;
 $330 = (($329) + 8|0);
 $331 = HEAP32[$330>>2]|0;
 $332 = (__Z15PxGetFoundationv()|0);
 $333 = HEAP32[$332>>2]|0;
 $334 = (($333) + 24|0);
 $335 = HEAP32[$334>>2]|0;
 $336 = (FUNCTION_TABLE_ii[$335 & 4095]($332)|0);
 $$$i$i$i12 = $336 ? 469704 : 464392;
 $337 = (FUNCTION_TABLE_iiiiii[$331 & 255]($328,32,$$$i$i$i12,463960,192)|0);
 HEAP32[$337>>2] = 64;
 $338 = (($337) + 4|0);
 HEAP32[$338>>2] = 32;
 $339 = (($337) + 8|0);
 $340 = (($337) + 12|0);
 $341 = (($337) + 16|0);
 $342 = (($337) + 20|0);
 $343 = (($337) + 24|0);
 ;HEAP32[$339+0>>2]=0|0;HEAP32[$339+4>>2]=0|0;HEAP32[$339+8>>2]=0|0;HEAP32[$339+12>>2]=0|0;
 HEAP8[$343>>0] = 1;
 $344 = (($337) + 28|0);
 HEAP32[$344>>2] = 464072;
 $345 = (($tmp$i$i$i$i16) + 4|0);
 $346 = (($tmp$i$i$i$i16) + 8|0);
 HEAP32[$345>>2] = 0;
 HEAP32[$346>>2] = 0;
 $347 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,2048,465496,60)|0);
 HEAP32[$tmp$i$i$i$i16>>2] = $347;
 $348 = HEAP32[$342>>2]|0;
 $349 = $348 & 2147483647;
 $350 = HEAP32[$341>>2]|0;
 $351 = ($349>>>0)>($350>>>0);
 if ($351) {
  $352 = HEAP32[$340>>2]|0;
  $353 = (($352) + (($350*12)|0)|0);
  $354 = ($353|0)==(0|0);
  if ($354) {
   $356 = $350;
  } else {
   ;HEAP32[$353+0>>2]=HEAP32[$tmp$i$i$i$i16+0>>2]|0;HEAP32[$353+4>>2]=HEAP32[$tmp$i$i$i$i16+4>>2]|0;HEAP32[$353+8>>2]=HEAP32[$tmp$i$i$i$i16+8>>2]|0;
   $$pre$i$i$i$i$i = HEAP32[$341>>2]|0;
   $356 = $$pre$i$i$i$i$i;
  }
  $355 = (($356) + 1)|0;
  HEAP32[$341>>2] = $355;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Cm19PreallocatingRegionENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($340,$tmp$i$i$i$i16)|0);
 }
 $357 = (($this) + 1220|0);
 HEAP32[$357>>2] = $337;
 $358 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $359 = HEAP32[$358>>2]|0;
 $360 = (($359) + 8|0);
 $361 = HEAP32[$360>>2]|0;
 $362 = (__Z15PxGetFoundationv()|0);
 $363 = HEAP32[$362>>2]|0;
 $364 = (($363) + 24|0);
 $365 = HEAP32[$364>>2]|0;
 $366 = (FUNCTION_TABLE_ii[$365 & 4095]($362)|0);
 $$$i$i$i11 = $366 ? 469408 : 464392;
 $367 = (FUNCTION_TABLE_iiiiii[$361 & 255]($358,296,$$$i$i$i11,463960,193)|0);
 $368 = (($367) + 4|0);
 $369 = (($367) + 260|0);
 $370 = (($367) + 264|0);
 $371 = (($367) + 268|0);
 HEAP32[$371>>2] = 0;
 $372 = (($367) + 272|0);
 HEAP8[$369>>0] = 1;
 HEAP32[$370>>2] = $368;
 HEAP32[$372>>2] = 64;
 $373 = (($367) + 276|0);
 HEAP32[$373>>2] = 32;
 $374 = (($367) + 280|0);
 HEAP32[$374>>2] = 0;
 $375 = (($367) + 284|0);
 HEAP32[$375>>2] = 0;
 $376 = (($367) + 288|0);
 HEAP32[$376>>2] = 4096;
 $377 = (($367) + 292|0);
 HEAP32[$377>>2] = 0;
 $378 = (($this) + 1232|0);
 HEAP32[$378>>2] = $367;
 $379 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $380 = HEAP32[$379>>2]|0;
 $381 = (($380) + 8|0);
 $382 = HEAP32[$381>>2]|0;
 $383 = (__Z15PxGetFoundationv()|0);
 $384 = HEAP32[$383>>2]|0;
 $385 = (($384) + 24|0);
 $386 = HEAP32[$385>>2]|0;
 $387 = (FUNCTION_TABLE_ii[$386 & 4095]($383)|0);
 $$$i$i$i9 = $387 ? 469080 : 464392;
 $388 = (FUNCTION_TABLE_iiiiii[$382 & 255]($379,296,$$$i$i$i9,463960,194)|0);
 $389 = (($388) + 4|0);
 $390 = (($388) + 260|0);
 $391 = (($388) + 264|0);
 $392 = (($388) + 268|0);
 HEAP32[$392>>2] = 0;
 $393 = (($388) + 272|0);
 HEAP8[$390>>0] = 1;
 HEAP32[$391>>2] = $389;
 HEAP32[$393>>2] = 64;
 $394 = (($388) + 276|0);
 HEAP32[$394>>2] = 32;
 $395 = (($388) + 280|0);
 HEAP32[$395>>2] = 0;
 $396 = (($388) + 284|0);
 HEAP32[$396>>2] = 0;
 $397 = (($388) + 288|0);
 HEAP32[$397>>2] = 1280;
 $398 = (($388) + 292|0);
 HEAP32[$398>>2] = 0;
 $399 = (($this) + 1236|0);
 HEAP32[$399>>2] = $388;
 $400 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $401 = HEAP32[$400>>2]|0;
 $402 = (($401) + 8|0);
 $403 = HEAP32[$402>>2]|0;
 $404 = (__Z15PxGetFoundationv()|0);
 $405 = HEAP32[$404>>2]|0;
 $406 = (($405) + 24|0);
 $407 = HEAP32[$406>>2]|0;
 $408 = (FUNCTION_TABLE_ii[$407 & 4095]($404)|0);
 $$$i$i$i7 = $408 ? 468792 : 464392;
 $409 = (FUNCTION_TABLE_iiiiii[$403 & 255]($400,296,$$$i$i$i7,463960,196)|0);
 $410 = (($409) + 4|0);
 $411 = (($409) + 260|0);
 $412 = (($409) + 264|0);
 $413 = (($409) + 268|0);
 HEAP32[$413>>2] = 0;
 $414 = (($409) + 272|0);
 HEAP8[$411>>0] = 1;
 HEAP32[$412>>2] = $410;
 HEAP32[$414>>2] = 64;
 $415 = (($409) + 276|0);
 HEAP32[$415>>2] = 32;
 $416 = (($409) + 280|0);
 HEAP32[$416>>2] = 0;
 $417 = (($409) + 284|0);
 HEAP32[$417>>2] = 0;
 $418 = (($409) + 288|0);
 HEAP32[$418>>2] = 2048;
 $419 = (($409) + 292|0);
 HEAP32[$419>>2] = 0;
 $420 = (($this) + 1240|0);
 HEAP32[$420>>2] = $409;
 $421 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $422 = HEAP32[$421>>2]|0;
 $423 = (($422) + 8|0);
 $424 = HEAP32[$423>>2]|0;
 $425 = (__Z15PxGetFoundationv()|0);
 $426 = HEAP32[$425>>2]|0;
 $427 = (($426) + 24|0);
 $428 = HEAP32[$427>>2]|0;
 $429 = (FUNCTION_TABLE_ii[$428 & 4095]($425)|0);
 $$$i$i$i4 = $429 ? 468680 : 464392;
 $430 = (FUNCTION_TABLE_iiiiii[$424 & 255]($421,24,$$$i$i$i4,463960,198)|0);
 $431 = (($430) + 16|0);
 HEAP32[$431>>2] = 0;
 $432 = (($430) + 20|0);
 HEAP32[$432>>2] = 0;
 ;HEAP32[$430+0>>2]=0|0;HEAP32[$430+4>>2]=0|0;HEAP32[$430+8>>2]=0|0;HEAP8[$430+12>>0]=0|0;
 HEAP32[$2>>2] = $430;
 $433 = HEAP32[$69>>2]|0;
 $434 = $433 & 2147483647;
 $435 = HEAP32[$68>>2]|0;
 $436 = ($434>>>0)>($435>>>0);
 if ($436) {
  $437 = HEAP32[$67>>2]|0;
  $438 = (($437) + ($435<<2)|0);
  $439 = ($438|0)==(0|0);
  if (!($439)) {
   HEAP32[$438>>2] = $430;
  }
  $440 = (($435) + 1)|0;
  HEAP32[$68>>2] = $440;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc6ClientENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($67,$2)|0);
 }
 $441 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $442 = HEAP32[$441>>2]|0;
 $443 = (($442) + 8|0);
 $444 = HEAP32[$443>>2]|0;
 $445 = (__Z15PxGetFoundationv()|0);
 $446 = HEAP32[$445>>2]|0;
 $447 = (($446) + 24|0);
 $448 = HEAP32[$447>>2]|0;
 $449 = (FUNCTION_TABLE_ii[$448 & 4095]($445)|0);
 $$$i$i$i2 = $449 ? 468528 : 464392;
 $450 = (FUNCTION_TABLE_iiiiii[$444 & 255]($441,312,$$$i$i$i2,463960,199)|0);
 __ZN5physx2Sc27ConstraintProjectionManagerC2Ev($450);
 $451 = (($this) + 80|0);
 HEAP32[$451>>2] = $450;
 $452 = (($desc) + 104|0);
 $453 = HEAP32[$452>>2]|0;
 $454 = (($desc) + 108|0);
 $455 = HEAP32[$454>>2]|0;
 $456 = (($desc) + 112|0);
 $457 = HEAP32[$456>>2]|0;
 $458 = (__ZN5physx13PxTaskManager17createTaskManagerEPNS_15PxCpuDispatcherEPNS_15PxGpuDispatcherEPNS_15PxSpuDispatcherE($453,$455,$457)|0);
 $459 = (($this) + 2368|0);
 HEAP32[$459>>2] = $458;
 $scevgep = (($this) + 1432|0);
 ;HEAP32[$scevgep+0>>2]=0|0;HEAP32[$scevgep+4>>2]=0|0;HEAP32[$scevgep+8>>2]=0|0;HEAP32[$scevgep+12>>2]=0|0;HEAP32[$scevgep+16>>2]=0|0;HEAP32[$scevgep+20>>2]=0|0;HEAP32[$scevgep+24>>2]=0|0;
 $460 = HEAP32[$223>>2]|0;
 $461 = (__ZN5physx2Sc16InteractionScene4initERKNS_11PxSceneDescEPNS_13PxTaskManagerEPNS_2Cm9FlushPoolERNS7_13EventProfilerE($460,$desc,$458,$209,$70)|0);
 if (!($461)) {
  STACKTOP = sp;return;
 }
 $462 = (($desc) + 132|0);
 $463 = HEAP32[$462>>2]|0;
 $464 = HEAP32[$223>>2]|0;
 $465 = (($464) + 1000|0);
 $466 = HEAP32[$465>>2]|0;
 __ZN5physx10PxsContext18setSolverBatchSizeEj($466,$463);
 $467 = (($desc) + 80|0);
 $468 = Math_fround(HEAPF32[$467>>2]);
 $469 = HEAP32[$223>>2]|0;
 $470 = (($469) + 1000|0);
 $471 = HEAP32[$470>>2]|0;
 $472 = (($471) + 6164|0);
 HEAPF32[$472>>2] = $468;
 $473 = (($desc) + 88|0);
 $474 = Math_fround(HEAPF32[$473>>2]);
 $475 = (($471) + 6168|0);
 HEAPF32[$475>>2] = $474;
 $476 = (($471) + 12|0);
 $477 = HEAP32[$476>>2]|0;
 $478 = (($desc) + 96|0);
 $479 = Math_fround(HEAPF32[$478>>2]);
 $480 = (($477) + 144|0);
 HEAPF32[$480>>2] = $479;
 $481 = HEAP32[463296>>2]|0;
 $482 = Math_fround(HEAPF32[$481>>2]);
 $483 = (($471) + 6172|0);
 HEAPF32[$483>>2] = $482;
 $484 = (($desc) + 92|0);
 $485 = Math_fround(HEAPF32[$484>>2]);
 $486 = Math_fround(-$485);
 __ZN5physx10PxsContext18setBounceThresholdEf($471,$486);
 $487 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $488 = HEAP32[$487>>2]|0;
 $489 = (($488) + 8|0);
 $490 = HEAP32[$489>>2]|0;
 $491 = (__Z15PxGetFoundationv()|0);
 $492 = HEAP32[$491>>2]|0;
 $493 = (($492) + 24|0);
 $494 = HEAP32[$493>>2]|0;
 $495 = (FUNCTION_TABLE_ii[$494 & 4095]($491)|0);
 $$$i$i$i1 = $495 ? 468408 : 464392;
 $496 = (FUNCTION_TABLE_iiiiii[$490 & 255]($487,48,$$$i$i$i1,463960,227)|0);
 __ZN5physx2Sc9RigidCoreC2ENS_11PxActorType4EnumE($496,0);
 $497 = (($496) + 16|0);
 HEAPF32[$497>>2] = Math_fround(0.0);
 $498 = (($496) + 20|0);
 HEAPF32[$498>>2] = Math_fround(0.0);
 $499 = (($496) + 24|0);
 HEAPF32[$499>>2] = Math_fround(0.0);
 $500 = (($496) + 28|0);
 HEAPF32[$500>>2] = Math_fround(1.0);
 $501 = (($496) + 32|0);
 ;HEAP32[$501+0>>2]=0|0;HEAP32[$501+4>>2]=0|0;HEAP32[$501+8>>2]=0|0;HEAP8[$501+12>>0]=0|0;
 $502 = HEAP32[$297>>2]|0;
 $503 = (($502) + 8|0);
 $504 = HEAP32[$503>>2]|0;
 $505 = (($502) + 12|0);
 $506 = HEAP32[$505>>2]|0;
 $507 = (($502) + 4|0);
 $508 = HEAP32[$507>>2]|0;
 $509 = ((($506) + (($504*12)|0)|0) + 4|0);
 $510 = HEAP32[$509>>2]|0;
 $511 = ($510|0)==(0|0);
 do {
  if ($511) {
   $513 = HEAP32[$502>>2]|0;
   $514 = ((($506) + (($504*12)|0)|0) + 8|0);
   $515 = HEAP32[$514>>2]|0;
   $516 = ($515|0)==($513|0);
   if (!($516)) {
    $517 = (($515) + 1)|0;
    HEAP32[$514>>2] = $517;
    $518 = (($506) + (($504*12)|0)|0);
    $519 = HEAP32[$518>>2]|0;
    $520 = Math_imul($515, $508)|0;
    $521 = (($519) + ($520)|0);
    $522 = ($521|0)==(0|0);
    if (!($522)) {
     $525 = $521;
     label = 33;
     break;
    }
   }
   $523 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($502)|0);
   $524 = ($523|0)==(0|0);
   if ($524) {
    $526 = 0;
   } else {
    $525 = $523;
    label = 33;
   }
  } else {
   $512 = HEAP32[$510>>2]|0;
   HEAP32[$509>>2] = $512;
   $525 = $510;
   label = 33;
  }
 } while(0);
 if ((label|0) == 33) {
  __ZN5physx2Sc9StaticSimC2ERNS0_5SceneERNS0_10StaticCoreE($525,$this,$496);
  $526 = $525;
 }
 HEAP32[$86>>2] = $526;
 $527 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $528 = HEAP32[$527>>2]|0;
 $529 = (($528) + 8|0);
 $530 = HEAP32[$529>>2]|0;
 $531 = (__Z15PxGetFoundationv()|0);
 $532 = HEAP32[$531>>2]|0;
 $533 = (($532) + 24|0);
 $534 = HEAP32[$533>>2]|0;
 $535 = (FUNCTION_TABLE_ii[$534 & 4095]($531)|0);
 $$$i$i$i = $535 ? 468288 : 464392;
 $536 = (FUNCTION_TABLE_iiiiii[$530 & 255]($527,2188,$$$i$i$i,463960,231)|0);
 __ZN5physx2Sc10NPhaseCoreC2ERNS0_5SceneERKNS_11PxSceneDescE($536,$this,$desc);
 HEAP32[$46>>2] = $536;
 $i$02$i = 0;$mask$01$i = -2;
 while(1) {
  $537 = $mask$01$i ^ -1;
  $538 = ((($this) + ($i$02$i<<2)|0) + 1288|0);
  HEAP32[$538>>2] = $537;
  $539 = (($i$02$i) + 1)|0;
  $540 = $mask$01$i << 1;
  $exitcond$i = ($539|0)==(32);
  if ($exitcond$i) {
   break;
  } else {
   $i$02$i = $539;$mask$01$i = $540;
  }
 }
 $541 = (($this) + 1160|0);
 HEAP8[$541>>0] = 1;
 $542 = (($this) + 1161|0);
 HEAP8[$542>>0] = 1;
 $543 = (($desc) + 48|0);
 ;HEAP32[$this+0>>2]=HEAP32[$543+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$543+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$543+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$543+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$543+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$543+20>>2]|0;HEAP32[$this+24>>2]=HEAP32[$543+24>>2]|0;HEAP32[$this+28>>2]=HEAP32[$543+28>>2]|0;
 $544 = (($desc) + 44|0);
 $545 = HEAP32[$544>>2]|0;
 $546 = (($this) + 1164|0);
 $547 = HEAP32[$546>>2]|0;
 $548 = HEAP32[$547>>2]|0;
 $549 = (($548) + 20|0);
 HEAP32[$549>>2] = $545;
 $550 = Math_fround(HEAPF32[$desc>>2]);
 $551 = (($this) + 32|0);
 HEAPF32[$551>>2] = $550;
 $552 = (($desc) + 4|0);
 $553 = Math_fround(HEAPF32[$552>>2]);
 $554 = (($this) + 36|0);
 HEAPF32[$554>>2] = $553;
 $555 = (($desc) + 8|0);
 $556 = Math_fround(HEAPF32[$555>>2]);
 $557 = (($this) + 40|0);
 HEAPF32[$557>>2] = $556;
 HEAP32[$4>>2] = 1;
 $558 = (($desc) + 84|0);
 $559 = HEAP32[$558>>2]|0;
 $560 = HEAP32[$223>>2]|0;
 $561 = (($560) + 1000|0);
 $562 = HEAP32[$561>>2]|0;
 $563 = (($562) + 7372|0);
 HEAP32[$563>>2] = $559;
 $564 = HEAP16[$63>>1]|0;
 $565 = (($562) + 7376|0);
 $566 = ($564&65535) >>> 9;
 $$tr26 = $566&255;
 $567 = $$tr26 & 1;
 HEAP8[$565>>0] = $567;
 $568 = (($562) + 7377|0);
 $569 = ($564&65535) >>> 11;
 $$lobit = $569 & 1;
 $570 = $$lobit ^ 1;
 $571 = $570&255;
 HEAP8[$568>>0] = $571;
 $572 = (($desc) + 12|0);
 $573 = HEAP32[$572>>2]|0;
 $574 = HEAP32[$546>>2]|0;
 $575 = HEAP32[$574>>2]|0;
 $576 = (($575) + 16|0);
 $577 = HEAP32[$576>>2]|0;
 $578 = ($577|0)!=(0|0);
 $579 = ($573|0)==(0|0);
 $or$cond$i = $578 | $579;
 if (!($or$cond$i)) {
  $580 = HEAP32[$61>>2]|0;
  $581 = ($580|0)==(0);
  if (!($581)) {
   $i$01$i = 0;
   while(1) {
    $582 = HEAP32[$60>>2]|0;
    $583 = (($582) + ($i$01$i<<2)|0);
    $584 = HEAP32[$583>>2]|0;
    $585 = (__ZNK5physx2Sc8BodyCore6getSimEv($584)|0);
    $586 = (($585) + 144|0);
    $587 = HEAP16[$586>>1]|0;
    $588 = $587&65535;
    $589 = $588 | 64;
    $590 = $589&65535;
    HEAP16[$586>>1] = $590;
    $591 = (($i$01$i) + 1)|0;
    $592 = HEAP32[$61>>2]|0;
    $593 = ($591>>>0)<($592>>>0);
    if ($593) {
     $i$01$i = $591;
    } else {
     break;
    }
   }
  }
 }
 HEAP32[$576>>2] = $573;
 $594 = (($desc) + 16|0);
 $595 = HEAP32[$594>>2]|0;
 $596 = HEAP32[$223>>2]|0;
 $597 = (($596) + 1000|0);
 $598 = HEAP32[$597>>2]|0;
 $599 = (($598) + 5912|0);
 HEAP32[$599>>2] = $595;
 $600 = (($desc) + 20|0);
 $601 = HEAP32[$600>>2]|0;
 $602 = HEAP32[$223>>2]|0;
 $603 = (($602) + 1000|0);
 $604 = HEAP32[$603>>2]|0;
 __ZN5physx10PxsContext27setCCDContactModifyCallbackEPNS_26PxCCDContactModifyCallbackE($604,$601);
 $605 = (($desc) + 148|0);
 $606 = HEAP32[$605>>2]|0;
 $607 = HEAP32[$223>>2]|0;
 $608 = (($607) + 1000|0);
 $609 = HEAP32[$608>>2]|0;
 __ZN5physx10PxsContext15setCCDMaxPassesEj($609,$606);
 $610 = (($desc) + 24|0);
 $611 = HEAP32[$610>>2]|0;
 $612 = ($611|0)==(0|0);
 if ($612) {
  $621 = (($this) + 1092|0);
  HEAP32[$621>>2] = 0;
  $622 = (($this) + 1096|0);
  HEAP32[$622>>2] = 0;
 } else {
  $613 = (($desc) + 28|0);
  $614 = HEAP32[$613>>2]|0;
  $615 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$614,463960,263)|0);
  $616 = (($this) + 1092|0);
  HEAP32[$616>>2] = $615;
  $617 = HEAP32[$610>>2]|0;
  $618 = HEAP32[$613>>2]|0;
  _memcpy(($615|0),($617|0),($618|0))|0;
  $619 = HEAP32[$613>>2]|0;
  $620 = (($this) + 1096|0);
  HEAP32[$620>>2] = $619;
 }
 $623 = (($desc) + 32|0);
 $624 = HEAP32[$623>>2]|0;
 $625 = (($this) + 1100|0);
 HEAP32[$625>>2] = $624;
 $626 = (($desc) + 36|0);
 $627 = HEAP32[$626>>2]|0;
 $628 = (($this) + 1104|0);
 HEAP32[$628>>2] = $627;
 __ZN5physx2Sc5Scene17createClothSolverEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene18setSolverBatchSizeEj($this,$solverBatchSize) {
 $this = $this|0;
 $solverBatchSize = $solverBatchSize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext18setSolverBatchSizeEj($3,$solverBatchSize);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene9setLimitsERKNS_13PxSceneLimitsE($this,$limits) {
 $this = $this|0;
 $limits = $limits|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=HEAP32[$limits+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$limits+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$limits+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$limits+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$limits+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$limits+20>>2]|0;HEAP32[$this+24>>2]=HEAP32[$limits+24>>2]|0;HEAP32[$this+28>>2]=HEAP32[$limits+28>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene21setBroadPhaseCallbackEPNS_20PxBroadPhaseCallbackEh($this,$callback,$client) {
 $this = $this|0;
 $callback = $callback|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $client&255;
 $1 = (($this) + 1164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 20|0);
 HEAP32[$5>>2] = $callback;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene15setFrictionTypeENS_14PxFrictionType4EnumE($this,$model) {
 $this = $this|0;
 $model = $model|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 7372|0);
 HEAP32[$4>>2] = $model;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene6setPCMEb($this,$enabled) {
 $this = $this|0;
 $enabled = $enabled|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 7376|0);
 $5 = $enabled&1;
 HEAP8[$4>>0] = $5;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene15setContactCacheEb($this,$enabled) {
 $this = $this|0;
 $enabled = $enabled|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 7377|0);
 $5 = $enabled&1;
 HEAP8[$4>>0] = $5;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene26setSimulationEventCallbackEPNS_25PxSimulationEventCallbackEh($this,$callback,$client) {
 $this = $this|0;
 $callback = $callback|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $client&255;
 $1 = (($this) + 1164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)!=(0|0);
 $8 = ($callback|0)==(0|0);
 $or$cond = $7 | $8;
 if ($or$cond) {
  HEAP32[$5>>2] = $callback;
  STACKTOP = sp;return;
 }
 $9 = (($this) + 1140|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  HEAP32[$5>>2] = $callback;
  STACKTOP = sp;return;
 }
 $12 = (($this) + 1136|0);
 $i$01 = 0;
 while(1) {
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($i$01<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (__ZNK5physx2Sc8BodyCore6getSimEv($15)|0);
  $17 = (($16) + 144|0);
  $18 = HEAP16[$17>>1]|0;
  $19 = $18&65535;
  $20 = $19 | 64;
  $21 = $20&65535;
  HEAP16[$17>>1] = $21;
  $22 = (($i$01) + 1)|0;
  $23 = HEAP32[$9>>2]|0;
  $24 = ($22>>>0)<($23>>>0);
  if ($24) {
   $i$01 = $22;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $callback;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene24setContactModifyCallbackEPNS_23PxContactModifyCallbackE($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 5912|0);
 HEAP32[$4>>2] = $callback;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene27setCCDContactModifyCallbackEPNS_26PxCCDContactModifyCallbackE($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext27setCCDContactModifyCallbackEPNS_26PxCCDContactModifyCallbackE($3,$callback);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene15setCCDMaxPassesEj($this,$ccdMaxPasses) {
 $this = $this|0;
 $ccdMaxPasses = $ccdMaxPasses|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext15setCCDMaxPassesEj($3,$ccdMaxPasses);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene17createClothSolverEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[463296>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($this) + 168|0);
  HEAP32[$7>>2] = $5;
 }
 $8 = (($this) + 2368|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  (FUNCTION_TABLE_ii[$13 & 4095]($9)|0);
 }
 $14 = (($this) + 1184|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $25 = 0;
 } else {
  $17 = (($15) + -8|0);
  $25 = $17;
 }
 $18 = (($this) + 168|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $$pre = HEAP32[$0>>2]|0;
  $28 = $$pre;
 } else {
  $21 = HEAP32[$19>>2]|0;
  $22 = (($21) + 16|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$8>>2]|0;
  $26 = (FUNCTION_TABLE_iiii[$23 & 2047]($19,$25,$24)|0);
  HEAP32[$0>>2] = $26;
  $28 = $26;
 }
 $27 = ($28|0)==(0|0);
 if (!($27)) {
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 44|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 4095]($28,2346);
 }
 $32 = (($this) + 172|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  $$phi$trans$insert = (($this) + 156|0);
  $$pre4 = HEAP32[$$phi$trans$insert>>2]|0;
  $42 = $$pre4;
 } else {
  $35 = HEAP32[$33>>2]|0;
  $36 = (($35) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$8>>2]|0;
  $39 = (FUNCTION_TABLE_iiii[$37 & 2047]($33,$25,$38)|0);
  $40 = (($this) + 156|0);
  HEAP32[$40>>2] = $39;
  $42 = $39;
 }
 $41 = ($42|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 44|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($42,2346);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene7releaseEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre21 = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i$i = 0, $exitcond$i$i$i$i4 = 0, $exitcond$i$i$i$i9 = 0, $i$01$i$i$i$i = 0, $i$01$i$i$i$i3 = 0, $i$01$i$i$i$i8 = 0, $i$020 = 0;
 var $or$cond$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i$i$i$i = 0, $or$cond$i$i$i$i$i$i10 = 0, $or$cond$i$i$i$i$i$i13 = 0, $or$cond$i$i$i$i$i$i16 = 0, $or$cond$i$i$i$i$i$i5 = 0, $or$cond$i$i$i$i1 = 0, $or$cond$i$i$i$i12 = 0, $or$cond$i$i$i$i14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 HEAP32[$3>>2] = $5;
 $6 = (($this) + 180|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 1088|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  __ZN5physx2Sc10NPhaseCoreD2Ev($8);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$8);
 }
 HEAP32[$7>>2] = 0;
 $10 = (($this) + 1092|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$11);
 HEAP32[$10>>2] = 0;
 $12 = (($this) + 1216|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($13) + 52|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($this) + 1224|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$13>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vi[$20 & 4095]($13);
  __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($18,$13);
  $21 = ($16|0)==(0|0);
  if (!($21)) {
   __ZN5physx2Sc9RigidCoreD2Ev($16);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$16);
  }
 }
 __ZN5physx2Sc5Scene18postReportsCleanupEv($this);
 $22 = (($this) + 2368|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = HEAP32[$23>>2]|0;
  $26 = (($25) + 60|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vi[$27 & 4095]($23);
 }
 $28 = (($this) + 80|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (($29) + 308|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $32 & 2147483647;
  $34 = ($33|0)!=(0);
  $35 = ($32|0)>(-1);
  $or$cond$i$i$i$i = $34 & $35;
  if ($or$cond$i$i$i$i) {
   $36 = (($29) + 300|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    $39 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($40) + 12|0);
    $42 = HEAP32[$41>>2]|0;
    FUNCTION_TABLE_vii[$42 & 4095]($39,$37);
   }
  }
  $43 = (($29) + 4|0);
  __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEED2Ev($43);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$29);
 }
 HEAP32[$28>>2] = 0;
 $44 = (($this) + 1168|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = (($this) + 1164|0);
  $249 = $45;$i$020 = 0;
  while(1) {
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + ($i$020<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $64 = $48;$67 = $249;
   } else {
    $52 = (($50) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = $53 & 2147483647;
    $55 = ($54|0)!=(0);
    $56 = ($53|0)>(-1);
    $or$cond$i$i$i$i1 = $55 & $56;
    if ($or$cond$i$i$i$i1) {
     $57 = HEAP32[$50>>2]|0;
     $58 = ($57|0)==(0|0);
     if (!($58)) {
      $59 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = (($60) + 12|0);
      $62 = HEAP32[$61>>2]|0;
      FUNCTION_TABLE_vii[$62 & 4095]($59,$57);
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$50);
    $$pre21 = HEAP32[$47>>2]|0;
    $$pre22 = HEAP32[$44>>2]|0;
    $64 = $$pre21;$67 = $$pre22;
   }
   $63 = (($64) + ($i$020<<2)|0);
   HEAP32[$63>>2] = 0;
   $65 = (($i$020) + 1)|0;
   $66 = ($65>>>0)<($67>>>0);
   if ($66) {
    $249 = $67;$i$020 = $65;
   } else {
    break;
   }
  }
 }
 $68 = (($this) + 1236|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0|0);
 if (!($70)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEED2Ev($69);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$69);
 }
 $71 = (($this) + 1232|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0|0);
 if (!($73)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS3_EEED2Ev($72);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$72);
 }
 $74 = (($this) + 1240|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEED2Ev($75);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$75);
 }
 $77 = (($this) + 1224|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0|0);
 if (!($79)) {
  $80 = (($78) + 12|0);
  $81 = (($78) + 16|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(0);
  if (!($83)) {
   $i$01$i$i$i$i = 0;
   while(1) {
    $84 = HEAP32[$80>>2]|0;
    $85 = (($84) + (($i$01$i$i$i$i*12)|0)|0);
    $86 = HEAP32[$85>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$86);
    HEAP32[$85>>2] = 0;
    $87 = (($i$01$i$i$i$i) + 1)|0;
    $exitcond$i$i$i$i = ($87|0)==($82|0);
    if ($exitcond$i$i$i$i) {
     break;
    } else {
     $i$01$i$i$i$i = $87;
    }
   }
  }
  $88 = (($78) + 20|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = $89 & 2147483647;
  $91 = ($90|0)!=(0);
  $92 = ($89|0)>(-1);
  $or$cond$i$i$i$i$i$i = $91 & $92;
  if ($or$cond$i$i$i$i$i$i) {
   $93 = HEAP32[$80>>2]|0;
   $94 = ($93|0)==(0|0);
   if (!($94)) {
    $95 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($96) + 12|0);
    $98 = HEAP32[$97>>2]|0;
    FUNCTION_TABLE_vii[$98 & 4095]($95,$93);
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$78);
 }
 $99 = (($this) + 1220|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = ($100|0)==(0|0);
 if (!($101)) {
  $102 = (($100) + 12|0);
  $103 = (($100) + 16|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ($104|0)==(0);
  if (!($105)) {
   $i$01$i$i$i$i3 = 0;
   while(1) {
    $106 = HEAP32[$102>>2]|0;
    $107 = (($106) + (($i$01$i$i$i$i3*12)|0)|0);
    $108 = HEAP32[$107>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$108);
    HEAP32[$107>>2] = 0;
    $109 = (($i$01$i$i$i$i3) + 1)|0;
    $exitcond$i$i$i$i4 = ($109|0)==($104|0);
    if ($exitcond$i$i$i$i4) {
     break;
    } else {
     $i$01$i$i$i$i3 = $109;
    }
   }
  }
  $110 = (($100) + 20|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = $111 & 2147483647;
  $113 = ($112|0)!=(0);
  $114 = ($111|0)>(-1);
  $or$cond$i$i$i$i$i$i5 = $113 & $114;
  if ($or$cond$i$i$i$i$i$i5) {
   $115 = HEAP32[$102>>2]|0;
   $116 = ($115|0)==(0|0);
   if (!($116)) {
    $117 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (($118) + 12|0);
    $120 = HEAP32[$119>>2]|0;
    FUNCTION_TABLE_vii[$120 & 4095]($117,$115);
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$100);
 }
 $121 = (($this) + 1228|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($122|0)==(0|0);
 if (!($123)) {
  $124 = (($122) + 12|0);
  $125 = (($122) + 16|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ($126|0)==(0);
  if (!($127)) {
   $i$01$i$i$i$i8 = 0;
   while(1) {
    $128 = HEAP32[$124>>2]|0;
    $129 = (($128) + (($i$01$i$i$i$i8*12)|0)|0);
    $130 = HEAP32[$129>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$130);
    HEAP32[$129>>2] = 0;
    $131 = (($i$01$i$i$i$i8) + 1)|0;
    $exitcond$i$i$i$i9 = ($131|0)==($126|0);
    if ($exitcond$i$i$i$i9) {
     break;
    } else {
     $i$01$i$i$i$i8 = $131;
    }
   }
  }
  $132 = (($122) + 20|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = $133 & 2147483647;
  $135 = ($134|0)!=(0);
  $136 = ($133|0)>(-1);
  $or$cond$i$i$i$i$i$i10 = $135 & $136;
  if ($or$cond$i$i$i$i$i$i10) {
   $137 = HEAP32[$124>>2]|0;
   $138 = ($137|0)==(0|0);
   if (!($138)) {
    $139 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = (($140) + 12|0);
    $142 = HEAP32[$141>>2]|0;
    FUNCTION_TABLE_vii[$142 & 4095]($139,$137);
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$122);
 }
 $143 = (($this) + 152|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = ($144|0)==(0|0);
 if (!($145)) {
  $146 = HEAP32[$144>>2]|0;
  $147 = (($146) + 4|0);
  $148 = HEAP32[$147>>2]|0;
  FUNCTION_TABLE_vi[$148 & 4095]($144);
 }
 $149 = (($this) + 156|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = ($150|0)==(0|0);
 if (!($151)) {
  $235 = HEAP32[$150>>2]|0;
  $236 = (($235) + 4|0);
  $237 = HEAP32[$236>>2]|0;
  FUNCTION_TABLE_vi[$237 & 4095]($150);
 }
 $238 = (($this) + 172|0);
 $239 = HEAP32[$238>>2]|0;
 $240 = ($239|0)==(0|0);
 if (!($240)) {
  $241 = HEAP32[$239>>2]|0;
  $242 = (($241) + 4|0);
  $243 = HEAP32[$242>>2]|0;
  FUNCTION_TABLE_vi[$243 & 4095]($239);
 }
 $159 = (($this) + 96|0);
 $153 = HEAP32[$159>>2]|0;
 $244 = (($153) + 8|0);
 $245 = HEAP32[$244>>2]|0;
 $246 = $245 & 2147483647;
 $247 = ($246|0)!=(0);
 $248 = ($245|0)>(-1);
 $or$cond$i$i = $247 & $248;
 if ($or$cond$i$i) {
  $152 = HEAP32[$153>>2]|0;
  $154 = ($152|0)==(0|0);
  if ($154) {
   $160 = $153;
  } else {
   $155 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = (($156) + 12|0);
   $158 = HEAP32[$157>>2]|0;
   FUNCTION_TABLE_vii[$158 & 4095]($155,$152);
   $$pre = HEAP32[$159>>2]|0;
   $160 = $$pre;
  }
 } else {
  $160 = $153;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$160);
 $161 = (($this) + 1208|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = ($162|0)==(0|0);
 if (!($163)) {
  $164 = (($162) + 36|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = $165 & 2147483647;
  $167 = ($166|0)!=(0);
  $168 = ($165|0)>(-1);
  $or$cond$i$i$i$i12 = $167 & $168;
  if ($or$cond$i$i$i$i12) {
   $169 = (($162) + 28|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = ($170|0)==(0|0);
   if (!($171)) {
    $172 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $173 = HEAP32[$172>>2]|0;
    $174 = (($173) + 12|0);
    $175 = HEAP32[$174>>2]|0;
    FUNCTION_TABLE_vii[$175 & 4095]($172,$170);
   }
  }
  $176 = (($162) + 16|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = ($177|0)==(0|0);
  do {
   if (!($178)) {
    $179 = (($162) + 20|0);
    $180 = HEAP32[$179>>2]|0;
    $181 = ($180|0)>(-1);
    if (!($181)) {
     break;
    }
    $182 = (($162) + 24|0);
    __ZN5physx6shdfnd9Allocator10deallocateEPv($182,$177);
   }
  } while(0);
  $183 = (($162) + 12|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = $184 & 2147483647;
  $186 = ($185|0)!=(0);
  $187 = ($184|0)>(-1);
  $or$cond$i$i$i$i$i$i13 = $186 & $187;
  do {
   if ($or$cond$i$i$i$i$i$i13) {
    $188 = (($162) + 4|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = ($189|0)==(0|0);
    if ($190) {
     break;
    }
    $191 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $192 = HEAP32[$191>>2]|0;
    $193 = (($192) + 12|0);
    $194 = HEAP32[$193>>2]|0;
    FUNCTION_TABLE_vii[$194 & 4095]($191,$189);
   }
  } while(0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$162);
 }
 $195 = (($this) + 1204|0);
 $196 = HEAP32[$195>>2]|0;
 $197 = ($196|0)==(0|0);
 if (!($197)) {
  $198 = (($196) + 36|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = $199 & 2147483647;
  $201 = ($200|0)!=(0);
  $202 = ($199|0)>(-1);
  $or$cond$i$i$i$i14 = $201 & $202;
  do {
   if ($or$cond$i$i$i$i14) {
    $203 = (($196) + 28|0);
    $204 = HEAP32[$203>>2]|0;
    $205 = ($204|0)==(0|0);
    if ($205) {
     break;
    }
    $206 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = (($207) + 12|0);
    $209 = HEAP32[$208>>2]|0;
    FUNCTION_TABLE_vii[$209 & 4095]($206,$204);
   }
  } while(0);
  $210 = (($196) + 16|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = ($211|0)==(0|0);
  do {
   if (!($212)) {
    $213 = (($196) + 20|0);
    $214 = HEAP32[$213>>2]|0;
    $215 = ($214|0)>(-1);
    if (!($215)) {
     break;
    }
    $216 = (($196) + 24|0);
    __ZN5physx6shdfnd9Allocator10deallocateEPv($216,$211);
   }
  } while(0);
  $217 = (($196) + 12|0);
  $218 = HEAP32[$217>>2]|0;
  $219 = $218 & 2147483647;
  $220 = ($219|0)!=(0);
  $221 = ($218|0)>(-1);
  $or$cond$i$i$i$i$i$i16 = $220 & $221;
  do {
   if ($or$cond$i$i$i$i$i$i16) {
    $222 = (($196) + 4|0);
    $223 = HEAP32[$222>>2]|0;
    $224 = ($223|0)==(0|0);
    if ($224) {
     break;
    }
    $225 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $226 = HEAP32[$225>>2]|0;
    $227 = (($226) + 12|0);
    $228 = HEAP32[$227>>2]|0;
    FUNCTION_TABLE_vii[$228 & 4095]($225,$223);
   }
  } while(0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$196);
 }
 $229 = (($this) + 1192|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = ($230|0)==(0|0);
 if (!($231)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$230);
 }
 $232 = (($this) + 1212|0);
 $233 = HEAP32[$232>>2]|0;
 $234 = ($233|0)==(0|0);
 if ($234) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc16InteractionSceneD2Ev($233);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$233);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene18postReportsCleanupEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $i$01$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1204|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $26 = $2;
 } else {
  $6 = (($2) + 28|0);
  $7 = (($2) + 4|0);
  $8 = (($2) + 12|0);
  $9 = (($2) + 8|0);
  $i$01$i = 0;
  while(1) {
   $10 = HEAP32[$6>>2]|0;
   $11 = (($10) + ($i$01$i<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$0>>2] = $12;
   $13 = HEAP32[$8>>2]|0;
   $14 = $13 & 2147483647;
   $15 = HEAP32[$9>>2]|0;
   $16 = ($14>>>0)>($15>>>0);
   if ($16) {
    $17 = HEAP32[$7>>2]|0;
    $18 = (($17) + ($15<<2)|0);
    $19 = ($18|0)==(0|0);
    if ($19) {
     $21 = $15;
    } else {
     HEAP32[$18>>2] = $12;
     $$pre$i$i$i = HEAP32[$9>>2]|0;
     $21 = $$pre$i$i$i;
    }
    $20 = (($21) + 1)|0;
    HEAP32[$9>>2] = $20;
   } else {
    (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($7,$0)|0);
   }
   $22 = (($i$01$i) + 1)|0;
   $23 = HEAP32[$3>>2]|0;
   $24 = ($22>>>0)<($23>>>0);
   if ($24) {
    $i$01$i = $22;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$1>>2]|0;
  $26 = $$pre;
 }
 HEAP32[$3>>2] = 0;
 $25 = (($26) + 20|0);
 $27 = HEAP32[$25>>2]|0;
 $28 = (($26) + 16|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = $27 << 2;
 _memset(($29|0),0,($30|0))|0;
 $31 = (($this) + 1208|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 32|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if ($35) {
  $56 = $32;
  HEAP32[$33>>2] = 0;
  $55 = (($56) + 20|0);
  $57 = HEAP32[$55>>2]|0;
  $58 = (($56) + 16|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $57 << 2;
  _memset(($59|0),0,($60|0))|0;
  STACKTOP = sp;return;
 }
 $36 = (($32) + 28|0);
 $37 = (($32) + 4|0);
 $38 = (($32) + 12|0);
 $39 = (($32) + 8|0);
 $i$01$i2 = 0;
 while(1) {
  $40 = HEAP32[$36>>2]|0;
  $41 = (($40) + ($i$01$i2<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  HEAP32[$0>>2] = $42;
  $43 = HEAP32[$38>>2]|0;
  $44 = $43 & 2147483647;
  $45 = HEAP32[$39>>2]|0;
  $46 = ($44>>>0)>($45>>>0);
  if ($46) {
   $47 = HEAP32[$37>>2]|0;
   $48 = (($47) + ($45<<2)|0);
   $49 = ($48|0)==(0|0);
   if ($49) {
    $51 = $45;
   } else {
    HEAP32[$48>>2] = $42;
    $$pre$i$i$i4 = HEAP32[$39>>2]|0;
    $51 = $$pre$i$i$i4;
   }
   $50 = (($51) + 1)|0;
   HEAP32[$39>>2] = $50;
  } else {
   (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($37,$0)|0);
  }
  $52 = (($i$01$i2) + 1)|0;
  $53 = HEAP32[$33>>2]|0;
  $54 = ($52>>>0)<($53>>>0);
  if ($54) {
   $i$01$i2 = $52;
  } else {
   break;
  }
 }
 $$pre7 = HEAP32[$31>>2]|0;
 $56 = $$pre7;
 HEAP32[$33>>2] = 0;
 $55 = (($56) + 20|0);
 $57 = HEAP32[$55>>2]|0;
 $58 = (($56) + 16|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = $57 << 2;
 _memset(($59|0),0,($60|0))|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene11preAllocateEjjjjj($this,$nbStatics,$nbBodies,$nbStaticShapes,$nbDynamicShapes,$nbAggregates) {
 $this = $this|0;
 $nbStatics = $nbStatics|0;
 $nbBodies = $nbBodies|0;
 $nbStaticShapes = $nbStaticShapes|0;
 $nbDynamicShapes = $nbDynamicShapes|0;
 $nbAggregates = $nbAggregates|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $availableSpace$01$i$i = 0, $availableSpace$01$i$i3 = 0, $availableSpace$01$i$i8 = 0, $tmp$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 12|0;
 $tmp$i$i6 = sp;
 $1 = (($this) + 1224|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($nbStatics|0)==(0);
 if (!($3)) {
  $4 = (($2) + 12|0);
  $5 = (($2) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$2>>2]|0;
  $8 = Math_imul($7, $6)|0;
  $9 = ($8>>>0)<($nbStatics>>>0);
  if ($9) {
   $10 = (($2) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($tmp$i$i6) + 4|0);
   $13 = (($tmp$i$i6) + 8|0);
   $14 = Math_imul($11, $7)|0;
   $15 = (($2) + 20|0);
   $availableSpace$01$i$i = $8;
   while(1) {
    HEAP32[$12>>2] = 0;
    HEAP32[$13>>2] = 0;
    $16 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$14,465496,60)|0);
    HEAP32[$tmp$i$i6>>2] = $16;
    $17 = HEAP32[$15>>2]|0;
    $18 = $17 & 2147483647;
    $19 = HEAP32[$5>>2]|0;
    $20 = ($18>>>0)>($19>>>0);
    if ($20) {
     $21 = HEAP32[$4>>2]|0;
     $22 = (($21) + (($19*12)|0)|0);
     $23 = ($22|0)==(0|0);
     if ($23) {
      $25 = $19;
     } else {
      ;HEAP32[$22+0>>2]=HEAP32[$tmp$i$i6+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$tmp$i$i6+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$tmp$i$i6+8>>2]|0;
      $$pre$i$i$i = HEAP32[$5>>2]|0;
      $25 = $$pre$i$i$i;
     }
     $24 = (($25) + 1)|0;
     HEAP32[$5>>2] = $24;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_2Cm19PreallocatingRegionENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($4,$tmp$i$i6)|0);
    }
    $26 = (($availableSpace$01$i$i) + ($7))|0;
    $27 = ($26>>>0)<($nbStatics>>>0);
    if ($27) {
     $availableSpace$01$i$i = $26;
    } else {
     break;
    }
   }
  }
 }
 $28 = (($this) + 1228|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($nbBodies|0)==(0);
 if (!($30)) {
  $31 = (($29) + 12|0);
  $32 = (($29) + 16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = HEAP32[$29>>2]|0;
  $35 = Math_imul($34, $33)|0;
  $36 = ($35>>>0)<($nbBodies>>>0);
  if ($36) {
   $37 = (($29) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($tmp$i$i6) + 4|0);
   $40 = (($tmp$i$i6) + 8|0);
   $41 = Math_imul($38, $34)|0;
   $42 = (($29) + 20|0);
   $availableSpace$01$i$i3 = $35;
   while(1) {
    HEAP32[$39>>2] = 0;
    HEAP32[$40>>2] = 0;
    $43 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$41,465496,60)|0);
    HEAP32[$tmp$i$i6>>2] = $43;
    $44 = HEAP32[$42>>2]|0;
    $45 = $44 & 2147483647;
    $46 = HEAP32[$32>>2]|0;
    $47 = ($45>>>0)>($46>>>0);
    if ($47) {
     $48 = HEAP32[$31>>2]|0;
     $49 = (($48) + (($46*12)|0)|0);
     $50 = ($49|0)==(0|0);
     if ($50) {
      $52 = $46;
     } else {
      ;HEAP32[$49+0>>2]=HEAP32[$tmp$i$i6+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$tmp$i$i6+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$tmp$i$i6+8>>2]|0;
      $$pre$i$i$i4 = HEAP32[$32>>2]|0;
      $52 = $$pre$i$i$i4;
     }
     $51 = (($52) + 1)|0;
     HEAP32[$32>>2] = $51;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_2Cm19PreallocatingRegionENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$tmp$i$i6)|0);
    }
    $53 = (($availableSpace$01$i$i3) + ($34))|0;
    $54 = ($53>>>0)<($nbBodies>>>0);
    if ($54) {
     $availableSpace$01$i$i3 = $53;
    } else {
     break;
    }
   }
  }
 }
 $55 = (($this) + 1212|0);
 $56 = HEAP32[$55>>2]|0;
 __ZN5physx2Sc16InteractionScene11preAllocateEjjjj($56,$nbBodies,$nbStaticShapes,$nbDynamicShapes,$nbAggregates);
 $57 = (($this) + 1220|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($nbDynamicShapes) + ($nbStaticShapes))|0;
 $60 = ($59|0)==(0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $61 = (($58) + 12|0);
 $62 = (($58) + 16|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$58>>2]|0;
 $65 = Math_imul($64, $63)|0;
 $66 = ($65>>>0)<($59>>>0);
 if (!($66)) {
  STACKTOP = sp;return;
 }
 $67 = (($58) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($tmp$i$i6) + 4|0);
 $70 = (($tmp$i$i6) + 8|0);
 $71 = Math_imul($68, $64)|0;
 $72 = (($58) + 20|0);
 $availableSpace$01$i$i8 = $65;
 while(1) {
  HEAP32[$69>>2] = 0;
  HEAP32[$70>>2] = 0;
  $73 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$71,465496,60)|0);
  HEAP32[$tmp$i$i6>>2] = $73;
  $74 = HEAP32[$72>>2]|0;
  $75 = $74 & 2147483647;
  $76 = HEAP32[$62>>2]|0;
  $77 = ($75>>>0)>($76>>>0);
  if ($77) {
   $78 = HEAP32[$61>>2]|0;
   $79 = (($78) + (($76*12)|0)|0);
   $80 = ($79|0)==(0|0);
   if ($80) {
    $82 = $76;
   } else {
    ;HEAP32[$79+0>>2]=HEAP32[$tmp$i$i6+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$tmp$i$i6+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$tmp$i$i6+8>>2]|0;
    $$pre$i$i$i9 = HEAP32[$62>>2]|0;
    $82 = $$pre$i$i$i9;
   }
   $81 = (($82) + 1)|0;
   HEAP32[$62>>2] = $81;
  } else {
   (__ZN5physx6shdfnd5ArrayINS_2Cm19PreallocatingRegionENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($61,$tmp$i$i6)|0);
  }
  $83 = (($availableSpace$01$i$i8) + ($64))|0;
  $84 = ($83>>>0)<($59>>>0);
  if ($84) {
   $availableSpace$01$i$i8 = $83;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene17getBroadPhaseTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 49828|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZNK5physx2Sc5Scene17getBroadPhaseCapsERNS_16PxBroadPhaseCapsE($this,$caps) {
 $this = $this|0;
 $caps = $caps|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 49828|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iii[$10 & 4095]($7,$caps)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZNK5physx2Sc5Scene22getNbBroadPhaseRegionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 49828|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZNK5physx2Sc5Scene20getBroadPhaseRegionsEPNS_22PxBroadPhaseRegionInfoEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 49828|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiii[$10 & 511]($7,$userBuffer,$bufferSize,$startIndex)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN5physx2Sc5Scene19addBroadPhaseRegionERKNS_18PxBroadPhaseRegionEb($this,$region,$populateRegion) {
 $this = $this|0;
 $region = $region|0;
 $populateRegion = $populateRegion|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 49828|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiii[$10 & 2047]($7,$region,$populateRegion)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN5physx2Sc5Scene22removeBroadPhaseRegionEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 49828|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iii[$10 & 4095]($7,$handle)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN5physx2Sc5Scene24getOutOfBoundsAggregatesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 51612|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx2Sc5Scene15getRenderBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 5928|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx2Sc5Scene15prepareSimulateEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 2372|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 1212|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1000|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 5928|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vi[$13 & 4095]($10);
 $14 = (($this) + 180|0);
 HEAP32[$14>>2] = 0;
 __ZN5physx2Sc5Scene33updateFromVisualizationParametersEv($this);
 $15 = (($this) + 128|0);
 $16 = (($this) + 132|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 120|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 136|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 2147483647;
 $22 = ($21>>>0)<($18>>>0);
 if ($22) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc17ParticleSystemSimENS0_19ReflectionAllocatorIS4_EEE8recreateEj($15,$18);
  $$pre = HEAP32[$17>>2]|0;
  $24 = $$pre;
 } else {
  $24 = $18;
 }
 $23 = ($24|0)==(0);
 if ($23) {
  __ZN5physx2Sc5Scene18visualizeStartStepEv($this);
  STACKTOP = sp;return;
 }
 $25 = (($this) + 116|0);
 $i$01 = 0;
 while(1) {
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($i$01<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($0,$28);
  $29 = HEAP16[$0>>1]|0;
  $30 = $29 & 4;
  $31 = ($30<<16>>16)==(0);
  do {
   if (!($31)) {
    $32 = (__ZNK5physx2Sc18ParticleSystemCore6getSimEv($28)|0);
    HEAP32[$1>>2] = $32;
    $33 = HEAP32[$19>>2]|0;
    $34 = $33 & 2147483647;
    $35 = HEAP32[$16>>2]|0;
    $36 = ($34>>>0)>($35>>>0);
    if (!($36)) {
     (__ZN5physx6shdfnd5ArrayIPNS_2Sc17ParticleSystemSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($15,$1)|0);
     break;
    }
    $37 = HEAP32[$15>>2]|0;
    $38 = (($37) + ($35<<2)|0);
    $39 = ($38|0)==(0|0);
    if (!($39)) {
     HEAP32[$38>>2] = $32;
    }
    $40 = (($35) + 1)|0;
    HEAP32[$16>>2] = $40;
   }
  } while(0);
  $41 = (($i$01) + 1)|0;
  $42 = HEAP32[$17>>2]|0;
  $43 = ($41>>>0)<($42>>>0);
  if ($43) {
   $i$01 = $41;
  } else {
   break;
  }
 }
 __ZN5physx2Sc5Scene18visualizeStartStepEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene33updateFromVisualizationParametersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1420|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 1212|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1000|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (Math_fround(__ZNK5physx10PxsContext25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($6,7)));
 $8 = $7 != Math_fround(0.0);
 if ($8) {
  label = 6;
 } else {
  $9 = HEAP32[$3>>2]|0;
  $10 = (($9) + 1000|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (Math_fround(__ZNK5physx10PxsContext25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($11,8)));
  $13 = $12 != Math_fround(0.0);
  if ($13) {
   label = 6;
  } else {
   $14 = HEAP32[$3>>2]|0;
   $15 = (($14) + 1000|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (Math_fround(__ZNK5physx10PxsContext25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($16,9)));
   $18 = $17 != Math_fround(0.0);
   if ($18) {
    label = 6;
   } else {
    $19 = HEAP32[$3>>2]|0;
    $20 = (($19) + 1000|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (Math_fround(__ZNK5physx10PxsContext25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($21,10)));
    $23 = $22 != Math_fround(0.0);
    if ($23) {
     label = 6;
    }
   }
  }
 }
 if ((label|0) == 6) {
  $24 = (($this) + 1196|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 | 4;
  HEAP32[$24>>2] = $26;
 }
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene18visualizeStartStepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $i1$01 = 0, $out = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $out = sp;
 $0 = (($this) + 1184|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1176|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 511]($1,64,$5,$8);
 $12 = (($this) + 1416|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = $13 != Math_fround(0.0);
 if (!($14)) {
  $65 = HEAP32[$1>>2]|0;
  $66 = (($65) + 12|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_viiii[$67 & 511]($1,64,$5,$8);
  STACKTOP = sp;return;
 }
 $15 = (($this) + 1212|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1000|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 5928|0);
 $20 = (($out) + 36|0);
 dest=$out+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($out) + 40|0);
 $22 = (($out) + 56|0);
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($out) + 60|0);
 $24 = (($out) + 76|0);
 ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($out) + 80|0);
 $26 = (($out) + 96|0);
 ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($out) + 100|0);
 HEAP32[$27>>2] = $19;
 $28 = HEAP32[$17>>2]|0;
 $29 = (Math_fround(__ZNK5physx10PxsContext25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($28,15)));
 $30 = $29 != Math_fround(0.0);
 if ($30) {
  $31 = HEAP32[$15>>2]|0;
  $32 = (($31) + 1000|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  __ZN5physx14PxsAABBManager9visualizeERNS_2Cm12RenderOutputE($35,$out);
 }
 $36 = (($this) + 72|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if (!($38)) {
  $39 = (($this) + 68|0);
  $i$02 = 0;
  while(1) {
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + ($i$02<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 64|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = HEAP32[$15>>2]|0;
   $46 = (($45) + 1000|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($47) + 5928|0);
   __ZN5physx2Sc13ConstraintSim9visualizeERNS_14PxRenderBufferE($44,$48);
   $49 = (($i$02) + 1)|0;
   $50 = HEAP32[$36>>2]|0;
   $51 = ($49>>>0)<($50>>>0);
   if ($51) {
    $i$02 = $49;
   } else {
    break;
   }
  }
 }
 $52 = (($this) + 1088|0);
 $53 = HEAP32[$52>>2]|0;
 __ZN5physx2Sc10NPhaseCore9visualizeERNS_2Cm12RenderOutputE($53,$out);
 $54 = (($this) + 120|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $65 = HEAP32[$1>>2]|0;
  $66 = (($65) + 12|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_viiii[$67 & 511]($1,64,$5,$8);
  STACKTOP = sp;return;
 }
 $57 = (($this) + 116|0);
 $i1$01 = 0;
 while(1) {
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + ($i1$01<<2)|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (__ZNK5physx2Sc18ParticleSystemCore6getSimEv($60)|0);
  __ZN5physx2Sc17ParticleSystemSim18visualizeStartStepERNS_2Cm12RenderOutputE($61,$out);
  $62 = (($i1$01) + 1)|0;
  $63 = HEAP32[$54>>2]|0;
  $64 = ($62>>>0)<($63>>>0);
  if ($64) {
   $i1$01 = $62;
  } else {
   break;
  }
 }
 $65 = HEAP32[$1>>2]|0;
 $66 = (($65) + 12|0);
 $67 = HEAP32[$66>>2]|0;
 FUNCTION_TABLE_viiii[$67 & 511]($1,64,$5,$8);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene8simulateEfPNS_10PxBaseTaskE($this,$timeStep,$continuation) {
 $this = $this|0;
 $timeStep = Math_fround($timeStep);
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $timeStep != Math_fround(0.0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 48|0);
 HEAPF32[$1>>2] = $timeStep;
 $2 = $timeStep > Math_fround(0.0);
 if ($2) {
  $3 = Math_fround(Math_fround(1.0) / $timeStep);
  $5 = $3;
 } else {
  $5 = Math_fround(0.0);
 }
 $4 = (($this) + 52|0);
 HEAPF32[$4>>2] = $5;
 __ZN5physx2Sc5Scene15prepareSimulateEv($this);
 __ZN5physx2Sc5Scene17stepSetupSimulateEv($this);
 $6 = (($this) + 2284|0);
 $7 = (($this) + 2300|0);
 HEAP32[$7>>2] = 1;
 $8 = (($this) + 2296|0);
 HEAP32[$8>>2] = $continuation;
 $9 = ($continuation|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$continuation>>2]|0;
  $11 = (($10) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($continuation);
  $13 = HEAP32[$8>>2]|0;
  $14 = (($13) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 2292|0);
  HEAP32[$16>>2] = $15;
 }
 $17 = (($this) + 2312|0);
 $18 = (($this) + 2328|0);
 HEAP32[$18>>2] = 1;
 $19 = (($this) + 2324|0);
 HEAP32[$19>>2] = $6;
 $20 = HEAP32[$6>>2]|0;
 $21 = (($20) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($6);
 $23 = HEAP32[$19>>2]|0;
 $24 = (($23) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 2320|0);
 HEAP32[$26>>2] = $25;
 $27 = HEAP32[$6>>2]|0;
 $28 = (($27) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vi[$29 & 4095]($6);
 $30 = HEAP32[$17>>2]|0;
 $31 = (($30) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vi[$32 & 4095]($17);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene17stepSetupSimulateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $cp$0$i$i = 0, $exitcond$i = 0, $i$01$i = 0, $kinePrefetch$02$i = 0, $kinePrefetch$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1184|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1176|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 511]($1,66,$5,$8);
 $12 = (($this) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 56|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 + $15);
 HEAPF32[$14>>2] = $16;
 $17 = (($this) + 80|0);
 $18 = HEAP32[$17>>2]|0;
 __ZN5physx2Sc27ConstraintProjectionManager11buildGroupsEv($18);
 $19 = (($this) + 1212|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$20>>2]|0;
 $24 = (($23) + ($22<<2)|0);
 $25 = ($22|0)==(0);
 if ($25) {
  $54 = (($this) + 1088|0);
  $55 = HEAP32[$54>>2]|0;
  __ZN5physx2Sc10NPhaseCore23updateDirtyInteractionsEv($55);
  $56 = (($this) + 1196|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = $57 & -7;
  HEAP32[$56>>2] = $58;
  $59 = HEAP32[$1>>2]|0;
  $60 = (($59) + 12|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_viiii[$61 & 511]($1,66,$5,$8);
  STACKTOP = sp;return;
 }
 $26 = (($23) + 64|0);
 $27 = (($this) + 52|0);
 $i$01$i = 0;$kinePrefetch$02$i = $26;
 while(1) {
  $28 = ($kinePrefetch$02$i>>>0)<($24>>>0);
  if ($28) {
   $29 = HEAP32[$kinePrefetch$02$i>>2]|0;
   $30 = $29;
   $31 = (_bitshift64Lshr(($30|0),0,6)|0);
   $32 = tempRet0;
   $33 = (_i64Add(($30|0),0,1023,0)|0);
   $34 = tempRet0;
   $35 = (_bitshift64Lshr(($33|0),($34|0),6)|0);
   $36 = tempRet0;
   $37 = (_i64Subtract(1,0,($31|0),($32|0))|0);
   $38 = tempRet0;
   $39 = (_i64Add(($37|0),($38|0),($35|0),($36|0))|0);
   $40 = tempRet0;
   $42 = $39;$43 = $40;$cp$0$i$i = $29;
   while(1) {
    $41 = (($cp$0$i$i) + 64|0);
    $44 = (_i64Add(($42|0),($43|0),-1,-1)|0);
    $45 = tempRet0;
    $46 = ($44|0)==(0);
    $47 = ($45|0)==(0);
    $48 = $46 & $47;
    if ($48) {
     break;
    } else {
     $42 = $44;$43 = $45;$cp$0$i$i = $41;
    }
   }
   $49 = (($kinePrefetch$02$i) + 4|0);
   $kinePrefetch$1$i = $49;
  } else {
   $kinePrefetch$1$i = $kinePrefetch$02$i;
  }
  $50 = (($23) + ($i$01$i<<2)|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = Math_fround(HEAPF32[$27>>2]);
  __ZN5physx2Sc7BodySim26calculateKinematicVelocityEf($51,$52);
  $53 = (($i$01$i) + 1)|0;
  $exitcond$i = ($53|0)==($22|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $53;$kinePrefetch$02$i = $kinePrefetch$1$i;
  }
 }
 $54 = (($this) + 1088|0);
 $55 = HEAP32[$54>>2]|0;
 __ZN5physx2Sc10NPhaseCore23updateDirtyInteractionsEv($55);
 $56 = (($this) + 1196|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $57 & -7;
 HEAP32[$56>>2] = $58;
 $59 = HEAP32[$1>>2]|0;
 $60 = (($59) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 FUNCTION_TABLE_viiii[$61 & 511]($1,66,$5,$8);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene5solveEfPNS_10PxBaseTaskE($this,$timeStep,$continuation) {
 $this = $this|0;
 $timeStep = Math_fround($timeStep);
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $cp$0$i$i$i = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $kinePrefetch$02$i$i = 0, $kinePrefetch$1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $timeStep != Math_fround(0.0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 48|0);
 HEAPF32[$1>>2] = $timeStep;
 $2 = $timeStep > Math_fround(0.0);
 if ($2) {
  $3 = Math_fround(Math_fround(1.0) / $timeStep);
  $5 = $3;
 } else {
  $5 = Math_fround(0.0);
 }
 $4 = (($this) + 52|0);
 HEAPF32[$4>>2] = $5;
 $6 = (($this) + 1184|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 1176|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$7>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_viiii[$17 & 511]($7,66,$11,$14);
 $18 = (($this) + 1212|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$19>>2]|0;
 $23 = (($22) + ($21<<2)|0);
 $24 = ($21|0)==(0);
 if (!($24)) {
  $25 = (($22) + 64|0);
  $i$01$i$i = 0;$kinePrefetch$02$i$i = $25;
  while(1) {
   $26 = ($kinePrefetch$02$i$i>>>0)<($23>>>0);
   if ($26) {
    $27 = HEAP32[$kinePrefetch$02$i$i>>2]|0;
    $28 = $27;
    $29 = (_bitshift64Lshr(($28|0),0,6)|0);
    $30 = tempRet0;
    $31 = (_i64Add(($28|0),0,1023,0)|0);
    $32 = tempRet0;
    $33 = (_bitshift64Lshr(($31|0),($32|0),6)|0);
    $34 = tempRet0;
    $35 = (_i64Subtract(1,0,($29|0),($30|0))|0);
    $36 = tempRet0;
    $37 = (_i64Add(($35|0),($36|0),($33|0),($34|0))|0);
    $38 = tempRet0;
    $40 = $37;$41 = $38;$cp$0$i$i$i = $27;
    while(1) {
     $39 = (($cp$0$i$i$i) + 64|0);
     $42 = (_i64Add(($40|0),($41|0),-1,-1)|0);
     $43 = tempRet0;
     $44 = ($42|0)==(0);
     $45 = ($43|0)==(0);
     $46 = $44 & $45;
     if ($46) {
      break;
     } else {
      $40 = $42;$41 = $43;$cp$0$i$i$i = $39;
     }
    }
    $47 = (($kinePrefetch$02$i$i) + 4|0);
    $kinePrefetch$1$i$i = $47;
   } else {
    $kinePrefetch$1$i$i = $kinePrefetch$02$i$i;
   }
   $48 = (($22) + ($i$01$i$i<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = Math_fround(HEAPF32[$4>>2]);
   __ZN5physx2Sc7BodySim26calculateKinematicVelocityEf($49,$50);
   $51 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($51|0)==($21|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $51;$kinePrefetch$02$i$i = $kinePrefetch$1$i$i;
   }
  }
 }
 $52 = HEAP32[$7>>2]|0;
 $53 = (($52) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 FUNCTION_TABLE_viiii[$54 & 511]($7,66,$11,$14);
 $55 = (($this) + 2284|0);
 $56 = (($this) + 2300|0);
 HEAP32[$56>>2] = 1;
 $57 = (($this) + 2296|0);
 HEAP32[$57>>2] = $continuation;
 $58 = ($continuation|0)==(0|0);
 if (!($58)) {
  $59 = HEAP32[$continuation>>2]|0;
  $60 = (($59) + 16|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_vi[$61 & 4095]($continuation);
  $62 = HEAP32[$57>>2]|0;
  $63 = (($62) + 8|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($this) + 2292|0);
  HEAP32[$65>>2] = $64;
 }
 $66 = HEAP32[$55>>2]|0;
 $67 = (($66) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vi[$68 & 4095]($55);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene26setBounceThresholdVelocityEf($this,$t) {
 $this = $this|0;
 $t = Math_fround($t);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(-$t);
 __ZN5physx10PxsContext18setBounceThresholdEf($3,$4);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene26getBounceThresholdVelocityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (Math_fround(__ZNK5physx10PxsContext18getBounceThresholdEv($3)));
 $5 = Math_fround(-$4);
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc5Scene7collideEfPNS_10PxBaseTaskE($this,$timeStep,$continuation) {
 $this = $this|0;
 $timeStep = Math_fround($timeStep);
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAPF32[$0>>2] = $timeStep;
 __ZN5physx2Sc5Scene15prepareSimulateEv($this);
 $1 = (($this) + 1192|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx2Sc8SimStats8simStartEv($2);
 $3 = (($this) + 1212|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1000|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx10PxsContext11beginUpdateEv($6);
 $7 = (($this) + 2312|0);
 $8 = (($this) + 2328|0);
 HEAP32[$8>>2] = 1;
 $9 = (($this) + 2324|0);
 HEAP32[$9>>2] = $continuation;
 $10 = ($continuation|0)==(0|0);
 if ($10) {
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 20|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vi[$20 & 4095]($7);
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$continuation>>2]|0;
 $12 = (($11) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vi[$13 & 4095]($continuation);
 $14 = HEAP32[$9>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 2320|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP32[$7>>2]|0;
 $19 = (($18) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vi[$20 & 4095]($7);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene15getFrictionTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 7372|0);
 $5 = HEAP32[$4>>2]|0;
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc5Scene13endSimulationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1088|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc10NPhaseCore28fireCustomFilteringCallbacksEv($1);
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 28|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 $9 = $8 & 2147483647;
 HEAP32[$6>>2] = $9;
 $10 = (($this) + 64|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 1)|0;
 HEAP32[$10>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene5flushEb($this,$sendPendingReports) {
 $this = $this|0;
 $sendPendingReports = $sendPendingReports|0;
 var $$pre = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i4 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i$i = 0, $i$01$i$i2 = 0, $i$03$i = 0, $i1$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = sp + 24|0;
 if ($sendPendingReports) {
  __ZN5physx2Sc5Scene26fireQueuedContactCallbacksEb($this,1);
  __ZN5physx2Sc5Scene20fireTriggerCallbacksEv($this);
  $$pre = (($this) + 1088|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $2 = (($this) + 1088|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN5physx2Sc10NPhaseCore28clearContactReportActorPairsEb($3,1);
  $$pre$phiZ2D = $2;
 }
 __ZN5physx2Sc5Scene18postReportsCleanupEv($this);
 $4 = HEAP32[$$pre$phiZ2D>>2]|0;
 $5 = (($4) + 48|0);
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 60|0);
 HEAP32[$6>>2] = -1;
 $7 = (($4) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($4) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if (!($11)) {
  $12 = (($4) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$13);
  $14 = HEAP32[$9>>2]|0;
  $15 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$14,471872,167)|0);
  HEAP32[$12>>2] = $15;
  $16 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $16;
 }
 $17 = (($this) + 68|0);
 $18 = (($this) + 72|0);
 $19 = HEAP32[$18>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($17,$19);
 $20 = (($this) + 84|0);
 $21 = (($0) + 20|0);
 HEAP8[$21>>0] = 0;
 __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($20,0,$0);
 $22 = (($this) + 88|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($20,$23);
 $24 = (($this) + 96|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($0) + 10|0);
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP16[$0+8>>1]=65535|0;
 HEAP8[$26>>0] = 0;
 $27 = (($0) + 11|0);
 HEAP8[$27>>0] = 0;
 __ZN5physx6shdfnd5ArrayINS_2Sc20TriggerPairExtraDataENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($25,0,$0);
 $28 = (($25) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 __ZN5physx6shdfnd5ArrayINS_2Sc20TriggerPairExtraDataENS0_19ReflectionAllocatorIS3_EEE8recreateEj($25,$29);
 $30 = (($this) + 180|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 176|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($31,0,$0);
 $32 = HEAP32[$30>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($31,$32);
 $33 = (($this) + 1140|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($this) + 1136|0);
  $i$03$i = 0;
  while(1) {
   $41 = HEAP32[$36>>2]|0;
   $42 = (($41) + ($i$03$i<<2)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__ZNK5physx2Sc8BodyCore6getSimEv($43)|0);
   $45 = (($44) + 144|0);
   $46 = HEAP16[$45>>1]|0;
   $47 = $46&65535;
   $48 = $47 & 65423;
   $49 = $48&65535;
   HEAP16[$45>>1] = $49;
   $50 = (($i$03$i) + 1)|0;
   $51 = HEAP32[$33>>2]|0;
   $52 = ($50>>>0)<($51>>>0);
   if ($52) {
    $i$03$i = $50;
   } else {
    break;
   }
  }
 }
 $37 = (($this) + 1152|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0);
 if (!($39)) {
  $40 = (($this) + 1148|0);
  $i1$01$i = 0;
  while(1) {
   $53 = HEAP32[$40>>2]|0;
   $54 = (($53) + ($i1$01$i<<2)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (__ZNK5physx2Sc8BodyCore6getSimEv($55)|0);
   $57 = (($56) + 144|0);
   $58 = HEAP16[$57>>1]|0;
   $59 = $58&65535;
   $60 = $59 & 65359;
   $61 = $60&65535;
   HEAP16[$57>>1] = $61;
   $62 = (($i1$01$i) + 1)|0;
   $63 = HEAP32[$37>>2]|0;
   $64 = ($62>>>0)<($63>>>0);
   if ($64) {
    $i1$01$i = $62;
   } else {
    break;
   }
  }
 }
 HEAP32[$33>>2] = 0;
 HEAP32[$37>>2] = 0;
 $65 = (($this) + 1160|0);
 HEAP8[$65>>0] = 1;
 $66 = (($this) + 1161|0);
 HEAP8[$66>>0] = 1;
 $67 = (($this) + 1136|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($67,0,$0);
 $68 = HEAP32[$33>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($67,$68);
 $69 = (($this) + 1148|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($69,0,$0);
 $70 = HEAP32[$37>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($69,$70);
 $71 = (($this) + 1164|0);
 $72 = (($this) + 1168|0);
 $73 = HEAP32[$72>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc6ClientENS0_19ReflectionAllocatorIS4_EEE8recreateEj($71,$73);
 $74 = (($this) + 1204|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($75) + 32|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0);
 if (!($78)) {
  $79 = (($75) + 28|0);
  $80 = (($75) + 4|0);
  $81 = (($75) + 12|0);
  $82 = (($75) + 8|0);
  $i$01$i$i = 0;
  while(1) {
   $83 = HEAP32[$79>>2]|0;
   $84 = (($83) + ($i$01$i$i<<2)|0);
   $85 = HEAP32[$84>>2]|0;
   HEAP32[$0>>2] = $85;
   $86 = HEAP32[$81>>2]|0;
   $87 = $86 & 2147483647;
   $88 = HEAP32[$82>>2]|0;
   $89 = ($87>>>0)>($88>>>0);
   if ($89) {
    $90 = HEAP32[$80>>2]|0;
    $91 = (($90) + ($88<<2)|0);
    $92 = ($91|0)==(0|0);
    if ($92) {
     $94 = $88;
    } else {
     HEAP32[$91>>2] = $85;
     $$pre$i$i$i$i = HEAP32[$82>>2]|0;
     $94 = $$pre$i$i$i$i;
    }
    $93 = (($94) + 1)|0;
    HEAP32[$82>>2] = $93;
   } else {
    (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($80,$0)|0);
   }
   $95 = (($i$01$i$i) + 1)|0;
   $96 = HEAP32[$76>>2]|0;
   $97 = ($95>>>0)<($96>>>0);
   if ($97) {
    $i$01$i$i = $95;
   } else {
    break;
   }
  }
 }
 HEAP32[$76>>2] = 0;
 $98 = (($75) + 28|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($98,0,$0);
 $99 = HEAP32[$76>>2]|0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($98,$99);
 $100 = (($this) + 1208|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = (($101) + 32|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ($103|0)==(0);
 if (!($104)) {
  $105 = (($101) + 28|0);
  $106 = (($101) + 4|0);
  $107 = (($101) + 12|0);
  $108 = (($101) + 8|0);
  $i$01$i$i2 = 0;
  while(1) {
   $109 = HEAP32[$105>>2]|0;
   $110 = (($109) + ($i$01$i$i2<<2)|0);
   $111 = HEAP32[$110>>2]|0;
   HEAP32[$0>>2] = $111;
   $112 = HEAP32[$107>>2]|0;
   $113 = $112 & 2147483647;
   $114 = HEAP32[$108>>2]|0;
   $115 = ($113>>>0)>($114>>>0);
   if ($115) {
    $116 = HEAP32[$106>>2]|0;
    $117 = (($116) + ($114<<2)|0);
    $118 = ($117|0)==(0|0);
    if ($118) {
     $120 = $114;
    } else {
     HEAP32[$117>>2] = $111;
     $$pre$i$i$i$i4 = HEAP32[$108>>2]|0;
     $120 = $$pre$i$i$i$i4;
    }
    $119 = (($120) + 1)|0;
    HEAP32[$108>>2] = $119;
   } else {
    (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($106,$0)|0);
   }
   $121 = (($i$01$i$i2) + 1)|0;
   $122 = HEAP32[$102>>2]|0;
   $123 = ($121>>>0)<($122>>>0);
   if ($123) {
    $i$01$i$i2 = $121;
   } else {
    break;
   }
  }
 }
 HEAP32[$102>>2] = 0;
 $124 = (($101) + 28|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($124,0,$0);
 $125 = HEAP32[$102>>2]|0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($124,$125);
 __ZN5physx2Sc5Scene20afterGenerateIslandsEv($this);
 $126 = (($this) + 1248|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($126,0,$0);
 $127 = (($this) + 1252|0);
 $128 = HEAP32[$127>>2]|0;
 __ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE8recreateEj($126,$128);
 $129 = (($this) + 1212|0);
 $130 = HEAP32[$129>>2]|0;
 __ZN5physx2Sc16InteractionScene14retrieveMemoryEv($130);
 $131 = (($this) + 116|0);
 $132 = (($this) + 120|0);
 $133 = HEAP32[$132>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc18ParticleSystemCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($131,$133);
 $134 = (($this) + 128|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc17ParticleSystemSimENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($134,0,$0);
 $135 = (($this) + 132|0);
 $136 = HEAP32[$135>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc17ParticleSystemSimENS0_19ReflectionAllocatorIS4_EEE8recreateEj($134,$136);
 $137 = HEAP32[$129>>2]|0;
 $138 = (($137) + 1000|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = (($139) + 44|0);
 __ZN5physx17PxcNpMemBlockPool19releaseUnusedBlocksEv($140);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene26fireQueuedContactCallbacksEb($this,$asPartOfFlush) {
 $this = $this|0;
 $asPartOfFlush = $asPartOfFlush|0;
 var $$ph = 0, $$ph51 = 0, $$ph52 = 0, $$pr = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i10 = 0, $$pre$i$i11 = 0, $$pre$i$i3 = 0, $$pre$i$i4 = 0, $$pre$i$i5 = 0, $$pre$i$i6 = 0, $$pre$i$i7 = 0, $$pre$i$i8 = 0, $$pre$phiZ2D = 0, $$pre46 = 0, $$pre47 = 0, $$pre49 = 0, $$sum = 0;
 var $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum30 = 0, $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0;
 var $$sum37 = 0, $$sum38 = 0, $$sum39 = 0, $$sum40 = 0, $$sum41 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = 0;
 var $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = Math_fround(0);
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $extraDataSize$0 = 0, $flags$0$i = 0, $flags$1$i = 0;
 var $i$02$i = 0, $i$044 = 0, $nbBlocks$0$i1$i = 0, $not$$i$i = 0, $pairHeader = 0, $pairHeaderFlags$1 = 0, $phitmp = 0, $phitmp43 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pairHeader = sp;
 $0 = (($this) + 1088|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $284 = $1;
  $283 = (($284) + 48|0);
  HEAP32[$283>>2] = 0;
  $285 = (($284) + 60|0);
  HEAP32[$285>>2] = -1;
  __ZN5physx2Sc10NPhaseCore28clearContactReportActorPairsEb($284,$asPartOfFlush);
  STACKTOP = sp;return;
 }
 $7 = (($5) + -1)|0;
 $8 = (($this) + 1208|0);
 $9 = (($pairHeader) + 14|0);
 $10 = (($pairHeader) + 4|0);
 $11 = (($pairHeader) + 8|0);
 $12 = (($pairHeader) + 12|0);
 $13 = (($this) + 1164|0);
 $14 = (($this) + 1204|0);
 $i$044 = 0;
 while(1) {
  $15 = ($i$044>>>0)<($7>>>0);
  if ($15) {
   $16 = (($i$044) + 1)|0;
   $17 = (($3) + ($16<<2)|0);
   $18 = HEAP32[$17>>2]|0;
  }
  $19 = (($3) + ($i$044<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
   $$pre$i$i1 = HEAP32[$21>>2]|0;
   $25 = $$pre$i$i1;
  } else {
   $25 = $22;
  }
  $24 = (($25) + 10|0);
  $26 = HEAP16[$24>>1]|0;
  $27 = $26&65535;
  $28 = $27 & 2;
  $29 = ($28|0)==(0);
  if ($29) {
   $30 = (($25) + 6|0);
   $31 = HEAP16[$30>>1]|0;
   $32 = HEAP32[$0>>2]|0;
   $33 = (($32) + 44|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$25>>2]|0;
   $36 = $27 & 1;
   $37 = ($36|0)==(0);
   $38 = $27 & 65520;
   $$sum = (($35) + ($38))|0;
   $39 = (($34) + ($$sum)|0);
   if (!($37)) {
    $40 = $31&65535;
    $41 = HEAP32[$14>>2]|0;
    $42 = ($31<<16>>16)==(0);
    if (!($42)) {
     $43 = (($41) + 20|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = $44 & 2147483647;
     $46 = (($41) + 16|0);
     $i$02$i = 0;
     while(1) {
      $47 = ((($39) + ($i$02$i<<5)|0) + 24|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ((($39) + ($i$02$i<<5)|0) + 28|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ((($39) + ($i$02$i<<5)|0) + 20|0);
      $52 = HEAP16[$51>>1]|0;
      $53 = $48 >>> 5;
      $54 = ($53>>>0)<($45>>>0);
      if ($54) {
       $55 = HEAP32[$46>>2]|0;
       $56 = (($55) + ($53<<2)|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = $48 & 31;
       $59 = 1 << $58;
       $60 = $57 & $59;
       $61 = ($60|0)==(0);
       if ($61) {
        $flags$0$i = $52;
       } else {
        $62 = $52&65535;
        $63 = $62 | 1;
        $64 = $63&65535;
        $flags$0$i = $64;
       }
      } else {
       $flags$0$i = $52;
      }
      $65 = $50 >>> 5;
      $66 = ($65>>>0)<($45>>>0);
      if ($66) {
       $67 = HEAP32[$46>>2]|0;
       $68 = (($67) + ($65<<2)|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = $50 & 31;
       $71 = 1 << $70;
       $72 = $69 & $71;
       $73 = ($72|0)==(0);
       if ($73) {
        $flags$1$i = $flags$0$i;
       } else {
        $74 = $flags$0$i&65535;
        $75 = $74 | 2;
        $76 = $75&65535;
        $flags$1$i = $76;
       }
      } else {
       $flags$1$i = $flags$0$i;
      }
      HEAP16[$51>>1] = $flags$1$i;
      $77 = (($i$02$i) + 1)|0;
      $exitcond$i = ($77|0)==($40|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$02$i = $77;
      }
     }
    }
   }
   $78 = (($i$044) + 1)|0;
   $79 = ($78>>>0)<($5>>>0);
   if ($79) {
    $80 = (($3) + ($78<<2)|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($81) + 20|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($83|0)==(0|0);
    if ($84) {
     __ZNK5physx2Sc9ActorPair23createContactReportDataEv($81);
     $$pre$i$i8 = HEAP32[$82>>2]|0;
     $286 = $$pre$i$i8;
    } else {
     $286 = $83;
    }
    $$pre46 = HEAP32[$21>>2]|0;
    $$pr = $$pre46;
   } else {
    $$pr = $25;
   }
   $85 = ($$pr|0)==(0|0);
   do {
    if ($85) {
     __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
     $$pre$i$i11 = HEAP32[$21>>2]|0;
     $90 = (($$pre$i$i11) + 32|0);
     $91 = HEAP8[$90>>0]|0;
     $92 = ($$pre$i$i11|0)==(0|0);
     if (!($92)) {
      $93 = (($$pre$i$i11) + 33|0);
      $94 = HEAP8[$93>>0]|0;
      $$ph = $$pre$i$i11;$$ph51 = $94;$$ph52 = $91;
      label = 28;
      break;
     }
     __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
     $$pre$i$i10 = HEAP32[$21>>2]|0;
     $95 = (($$pre$i$i10) + 33|0);
     $96 = HEAP8[$95>>0]|0;
     $97 = ($$pre$i$i10|0)==(0|0);
     if ($97) {
      __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
      $$pre$i$i7 = HEAP32[$21>>2]|0;
      $100 = (($$pre$i$i7) + 34|0);
      $101 = HEAP8[$100>>0]|0;
      $102 = ($$pre$i$i7|0)==(0|0);
      if ($102) {
       __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
       $$pre$i$i6 = HEAP32[$21>>2]|0;
       $107 = $$pre$i$i6;$287 = $101;$288 = $91;$289 = $96;
       label = 32;
       break;
      } else {
       $103 = (($$pre$i$i7) + 35|0);
       $104 = HEAP8[$103>>0]|0;
       $105 = HEAP32[$8>>2]|0;
       HEAP16[$9>>1] = 0;
       $112 = $$pre$i$i7;$126 = $105;$232 = $91;$240 = $96;$246 = $104;$265 = $101;
       break;
      }
     } else {
      $$ph = $$pre$i$i10;$$ph51 = $96;$$ph52 = $91;
      label = 28;
     }
    } else {
     $86 = (($$pr) + 32|0);
     $87 = HEAP8[$86>>0]|0;
     $88 = (($$pr) + 33|0);
     $89 = HEAP8[$88>>0]|0;
     $$ph = $$pr;$$ph51 = $89;$$ph52 = $87;
     label = 28;
    }
   } while(0);
   if ((label|0) == 28) {
    label = 0;
    $98 = (($$ph) + 34|0);
    $99 = HEAP8[$98>>0]|0;
    $107 = $$ph;$287 = $99;$288 = $$ph52;$289 = $$ph51;
    label = 32;
   }
   if ((label|0) == 32) {
    label = 0;
    $106 = (($107) + 35|0);
    $108 = HEAP8[$106>>0]|0;
    $109 = HEAP32[$8>>2]|0;
    HEAP16[$9>>1] = 0;
    $110 = ($107|0)==(0|0);
    if ($110) {
     __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
     $$pre$i$i5 = HEAP32[$21>>2]|0;
     $112 = $$pre$i$i5;$126 = $109;$232 = $288;$240 = $289;$246 = $108;$265 = $287;
    } else {
     $112 = $107;$126 = $109;$232 = $288;$240 = $289;$246 = $108;$265 = $287;
    }
   }
   $111 = (($112) + 24|0);
   $113 = HEAP32[$111>>2]|0;
   HEAP32[$pairHeader>>2] = $113;
   $114 = HEAP32[$21>>2]|0;
   $115 = ($114|0)==(0|0);
   if ($115) {
    __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
    $$pre$i$i4 = HEAP32[$21>>2]|0;
    $117 = $$pre$i$i4;
   } else {
    $117 = $114;
   }
   $116 = (($117) + 28|0);
   $118 = HEAP32[$116>>2]|0;
   HEAP32[$10>>2] = $118;
   $119 = HEAP32[$21>>2]|0;
   $120 = ($119|0)==(0|0);
   if ($120) {
    __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
    $$pre$i$i3 = HEAP32[$21>>2]|0;
    $122 = $$pre$i$i3;
   } else {
    $122 = $119;
   }
   $121 = (($122) + 16|0);
   $123 = HEAP32[$121>>2]|0;
   $124 = $123 >>> 5;
   $125 = (($126) + 20|0);
   $127 = HEAP32[$125>>2]|0;
   $128 = $127 & 2147483647;
   $129 = ($124>>>0)<($128>>>0);
   if ($129) {
    $130 = (($126) + 16|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($131) + ($124<<2)|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = $123 & 31;
    $135 = 1 << $134;
    $136 = $133 & $135;
    $phitmp = ($136|0)!=(0);
    $phitmp43 = $phitmp&1;
    $154 = $phitmp43;
   } else {
    $154 = 0;
   }
   $137 = ($122|0)==(0|0);
   if ($137) {
    __ZNK5physx2Sc9ActorPair23createContactReportDataEv($20);
    $$pre$i$i = HEAP32[$21>>2]|0;
    $$pre47 = HEAP32[$125>>2]|0;
    $139 = $$pre$i$i;$143 = $$pre47;
   } else {
    $139 = $122;$143 = $127;
   }
   $138 = (($139) + 20|0);
   $140 = HEAP32[$138>>2]|0;
   $141 = $140 >>> 5;
   $142 = $143 & 2147483647;
   $144 = ($141>>>0)<($142>>>0);
   if ($144) {
    $145 = (($126) + 16|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = (($146) + ($141<<2)|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = $140 & 31;
    $150 = 1 << $149;
    $151 = $148 & $150;
    $152 = ($151|0)==(0);
    if ($152) {
     $pairHeaderFlags$1 = $154;
    } else {
     $153 = $154&65535;
     $155 = $153 | 2;
     $156 = $155&65535;
     $pairHeaderFlags$1 = $156;
    }
   } else {
    $pairHeaderFlags$1 = $154;
   }
   HEAP16[$9>>1] = $pairHeaderFlags$1;
   $157 = (($25) + 8|0);
   $158 = HEAP16[$157>>1]|0;
   $159 = ($158<<16>>16)==(0);
   if ($159) {
    HEAP32[$11>>2] = 0;
    $extraDataSize$0 = 0;
   } else {
    $160 = $158&65535;
    $161 = (($160) + 65532)|0;
    $162 = $161&65535;
    $$sum17 = (($35) + 4)|0;
    $163 = (($34) + ($$sum17)|0);
    HEAP32[$11>>2] = $163;
    $164 = $27 & 8;
    $165 = ($164|0)==(0);
    if ($165) {
     $extraDataSize$0 = $162;
    } else {
     $166 = HEAP32[$20>>2]|0;
     $167 = (($20) + 4|0);
     $168 = HEAP32[$167>>2]|0;
     $169 = (($166) + 50|0);
     $170 = HEAP8[$169>>0]|0;
     $171 = ($170<<24>>24)==(0);
     if ($171) {
      $$sum36 = (($35) + 12)|0;
      $192 = (($34) + ($$sum36)|0);
      HEAPF32[$192>>2] = Math_fround(0.0);
      $$sum37 = (($35) + 16)|0;
      $193 = (($34) + ($$sum37)|0);
      HEAPF32[$193>>2] = Math_fround(0.0);
      $$sum38 = (($35) + 20)|0;
      $194 = (($34) + ($$sum38)|0);
      HEAPF32[$194>>2] = Math_fround(0.0);
      $$sum39 = (($35) + 36)|0;
      $195 = (($34) + ($$sum39)|0);
      HEAPF32[$195>>2] = Math_fround(0.0);
      $$sum40 = (($35) + 40)|0;
      $196 = (($34) + ($$sum40)|0);
      HEAPF32[$196>>2] = Math_fround(0.0);
      $$sum41 = (($35) + 44)|0;
      $197 = (($34) + ($$sum41)|0);
      HEAPF32[$197>>2] = Math_fround(0.0);
     } else {
      $172 = (($166) + 52|0);
      $173 = HEAP32[$172>>2]|0;
      $174 = (($173) + 80|0);
      $175 = Math_fround(HEAPF32[$174>>2]);
      $$sum18 = (($35) + 12)|0;
      $176 = (($34) + ($$sum18)|0);
      HEAPF32[$176>>2] = $175;
      $177 = (($173) + 84|0);
      $178 = Math_fround(HEAPF32[$177>>2]);
      $$sum19 = (($35) + 16)|0;
      $179 = (($34) + ($$sum19)|0);
      HEAPF32[$179>>2] = $178;
      $180 = (($173) + 88|0);
      $181 = Math_fround(HEAPF32[$180>>2]);
      $$sum20 = (($35) + 20)|0;
      $182 = (($34) + ($$sum20)|0);
      HEAPF32[$182>>2] = $181;
      $183 = (($173) + 96|0);
      $184 = Math_fround(HEAPF32[$183>>2]);
      $$sum21 = (($35) + 36)|0;
      $185 = (($34) + ($$sum21)|0);
      HEAPF32[$185>>2] = $184;
      $186 = (($173) + 100|0);
      $187 = Math_fround(HEAPF32[$186>>2]);
      $$sum22 = (($35) + 40)|0;
      $188 = (($34) + ($$sum22)|0);
      HEAPF32[$188>>2] = $187;
      $189 = (($173) + 104|0);
      $190 = Math_fround(HEAPF32[$189>>2]);
      $$sum23 = (($35) + 44)|0;
      $191 = (($34) + ($$sum23)|0);
      HEAPF32[$191>>2] = $190;
     }
     $198 = (($168) + 50|0);
     $199 = HEAP8[$198>>0]|0;
     $200 = ($199<<24>>24)==(0);
     if ($200) {
      $$sum30 = (($35) + 24)|0;
      $221 = (($34) + ($$sum30)|0);
      HEAPF32[$221>>2] = Math_fround(0.0);
      $$sum31 = (($35) + 28)|0;
      $222 = (($34) + ($$sum31)|0);
      HEAPF32[$222>>2] = Math_fround(0.0);
      $$sum32 = (($35) + 32)|0;
      $223 = (($34) + ($$sum32)|0);
      HEAPF32[$223>>2] = Math_fround(0.0);
      $$sum33 = (($35) + 48)|0;
      $224 = (($34) + ($$sum33)|0);
      HEAPF32[$224>>2] = Math_fround(0.0);
      $$sum34 = (($35) + 52)|0;
      $225 = (($34) + ($$sum34)|0);
      HEAPF32[$225>>2] = Math_fround(0.0);
      $$sum35 = (($35) + 56)|0;
      $226 = (($34) + ($$sum35)|0);
      HEAPF32[$226>>2] = Math_fround(0.0);
     } else {
      $201 = (($168) + 52|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = (($202) + 80|0);
      $204 = Math_fround(HEAPF32[$203>>2]);
      $$sum24 = (($35) + 24)|0;
      $205 = (($34) + ($$sum24)|0);
      HEAPF32[$205>>2] = $204;
      $206 = (($202) + 84|0);
      $207 = Math_fround(HEAPF32[$206>>2]);
      $$sum25 = (($35) + 28)|0;
      $208 = (($34) + ($$sum25)|0);
      HEAPF32[$208>>2] = $207;
      $209 = (($202) + 88|0);
      $210 = Math_fround(HEAPF32[$209>>2]);
      $$sum26 = (($35) + 32)|0;
      $211 = (($34) + ($$sum26)|0);
      HEAPF32[$211>>2] = $210;
      $212 = (($202) + 96|0);
      $213 = Math_fround(HEAPF32[$212>>2]);
      $$sum27 = (($35) + 48)|0;
      $214 = (($34) + ($$sum27)|0);
      HEAPF32[$214>>2] = $213;
      $215 = (($202) + 100|0);
      $216 = Math_fround(HEAPF32[$215>>2]);
      $$sum28 = (($35) + 52)|0;
      $217 = (($34) + ($$sum28)|0);
      HEAPF32[$217>>2] = $216;
      $218 = (($202) + 104|0);
      $219 = Math_fround(HEAPF32[$218>>2]);
      $$sum29 = (($35) + 56)|0;
      $220 = (($34) + ($$sum29)|0);
      HEAPF32[$220>>2] = $219;
     }
     $227 = HEAP16[$24>>1]|0;
     $228 = $227&65535;
     $229 = $228 & 65527;
     $230 = $229&65535;
     HEAP16[$24>>1] = $230;
     $extraDataSize$0 = $162;
    }
   }
   HEAP16[$12>>1] = $extraDataSize$0;
   $231 = $232&255;
   $233 = HEAP32[$13>>2]|0;
   $234 = (($233) + ($231<<2)|0);
   $235 = HEAP32[$234>>2]|0;
   $236 = (($235) + 16|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ($237|0)==(0|0);
   do {
    if (!($238)) {
     $239 = ($232<<24>>24)==($240<<24>>24);
     if (!($239)) {
      $241 = (($235) + 12|0);
      $242 = HEAP8[$241>>0]|0;
      $243 = $242 & 2;
      $244 = ($243<<24>>24)==(0);
      if ($244) {
       break;
      }
      $245 = $246 & 2;
      $247 = ($245<<24>>24)==(0);
      if ($247) {
       break;
      }
     }
     $248 = HEAP32[$237>>2]|0;
     $249 = (($248) + 12|0);
     $250 = HEAP32[$249>>2]|0;
     $251 = $31&65535;
     FUNCTION_TABLE_viiii[$250 & 511]($237,$pairHeader,$39,$251);
    }
   } while(0);
   $252 = ($232<<24>>24)==($240<<24>>24);
   do {
    if (!($252)) {
     $253 = $240&255;
     $254 = HEAP32[$13>>2]|0;
     $255 = (($254) + ($253<<2)|0);
     $256 = HEAP32[$255>>2]|0;
     $257 = (($256) + 16|0);
     $258 = HEAP32[$257>>2]|0;
     $259 = ($258|0)==(0|0);
     if (!($259)) {
      $260 = (($256) + 12|0);
      $261 = HEAP8[$260>>0]|0;
      $262 = $261 & 2;
      $263 = ($262<<24>>24)==(0);
      if (!($263)) {
       $264 = $265 & 2;
       $266 = ($264<<24>>24)==(0);
       if ($266) {
        break;
       }
       $267 = HEAP32[$258>>2]|0;
       $268 = (($267) + 12|0);
       $269 = HEAP32[$268>>2]|0;
       $270 = $31&65535;
       FUNCTION_TABLE_viiii[$269 & 511]($258,$pairHeader,$39,$270);
      }
     }
    }
   } while(0);
   $271 = (($25) + 4|0);
   HEAP16[$271>>1] = $31;
   $272 = HEAP16[$157>>1]|0;
   $273 = $272&65535;
   $274 = $273 & 15;
   $not$$i$i = ($274|0)!=(0);
   $275 = $not$$i$i&1;
   $276 = HEAP16[$24>>1]|0;
   $277 = $276&65535;
   $278 = $277 & 15;
   $nbBlocks$0$i1$i = $275 << 4;
   $279 = (($nbBlocks$0$i1$i) + ($273))|0;
   $280 = $279 & 65520;
   $281 = $280 | $278;
   $282 = $281&65535;
   HEAP16[$24>>1] = $282;
   $$pre$phiZ2D = $78;
  } else {
   $$pre49 = (($i$044) + 1)|0;
   $$pre$phiZ2D = $$pre49;
  }
  $exitcond = ($$pre$phiZ2D|0)==($5|0);
  if ($exitcond) {
   break;
  } else {
   $i$044 = $$pre$phiZ2D;
  }
 }
 $$pre = HEAP32[$0>>2]|0;
 $284 = $$pre;
 $283 = (($284) + 48|0);
 HEAP32[$283>>2] = 0;
 $285 = (($284) + 60|0);
 HEAP32[$285>>2] = -1;
 __ZN5physx2Sc10NPhaseCore28clearContactReportActorPairsEb($284,$asPartOfFlush);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene20fireTriggerCallbacksEv($this) {
 $this = $this|0;
 var $$$i = 0, $$$i2 = 0, $$off0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$us = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $activeClientLimit$020 = 0, $activeClientLimit$1 = 0, $activeClientLimit$2 = 0, $activeClientLimit$3 = 0, $activeClients = 0, $brmerge = 0, $exitcond = 0, $exitcond29 = 0;
 var $exitcond30 = 0, $exitcond31 = 0, $exitcond32 = 0, $flags$12$i = 0, $flags$12$i7 = 0, $i$025 = 0, $i1$017 = 0, $i2$014 = 0, $i2$014$us = 0, $j$012$us = 0, $nbValidPairs$018 = 0, $nbValidPairs$1 = 0, $or$cond = 0, $or$cond$i$i$i = 0, $perClientArray = 0, $phitmp = 0, $phitmp$i = 0, $phitmp$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 848|0;
 $activeClients = sp + 784|0;
 $perClientArray = sp;
 $0 = (($this) + 84|0);
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  $259 = (($this) + 96|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = (($260) + 4|0);
  HEAP32[$261>>2] = 0;
  $262 = (($this) + 100|0);
  HEAP8[$262>>0] = 0;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 1164|0);
 $5 = (($this) + 1168|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(1);
 if ($7) {
  $8 = HEAP32[$4>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = (($this) + 100|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $18 = HEAP32[$11>>2]|0;
    $19 = (($18) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$0>>2]|0;
    FUNCTION_TABLE_viii[$20 & 4095]($11,$21,$2);
    HEAP32[$1>>2] = 0;
    $259 = (($this) + 96|0);
    $260 = HEAP32[$259>>2]|0;
    $261 = (($260) + 4|0);
    HEAP32[$261>>2] = 0;
    $262 = (($this) + 100|0);
    HEAP8[$262>>0] = 0;
    STACKTOP = sp;return;
   }
   $16 = (($this) + 1204|0);
   $17 = (($this) + 96|0);
   $i$025 = 0;
   while(1) {
    $22 = HEAP32[$16>>2]|0;
    $23 = HEAP32[$17>>2]|0;
    $24 = HEAP32[$23>>2]|0;
    $25 = HEAP32[$0>>2]|0;
    $26 = (($24) + (($i$025*12)|0)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = $27 >>> 5;
    $29 = (($22) + 20|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = $30 & 2147483647;
    $32 = ($28>>>0)<($31>>>0);
    if ($32) {
     $33 = (($22) + 16|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + ($28<<2)|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = $27 & 31;
     $38 = 1 << $37;
     $39 = $36 & $38;
     $phitmp$i1 = ($39|0)==(0);
     $41 = $phitmp$i1;
    } else {
     $41 = 1;
    }
    $40 = $41&1;
    $$$i2 = $40 ^ 1;
    $42 = ((($24) + (($i$025*12)|0)|0) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = $43 >>> 5;
    $45 = ($44>>>0)<($31>>>0);
    if ($45) {
     $46 = (($22) + 16|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (($47) + ($44<<2)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = $43 & 31;
     $51 = 1 << $50;
     $52 = $49 & $51;
     $53 = ($52|0)==(0);
     if ($53) {
      label = 12;
     } else {
      $54 = $$$i2&255;
      $55 = $54 | 2;
      $56 = $55&255;
      $flags$12$i7 = $56;
      label = 13;
     }
    } else {
     label = 12;
    }
    if ((label|0) == 12) {
     label = 0;
     if (!($41)) {
      $flags$12$i7 = $$$i2;
      label = 13;
     }
    }
    if ((label|0) == 13) {
     label = 0;
     $57 = ((($25) + (($i$025*24)|0)|0) + 20|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = $58 | $flags$12$i7;
     HEAP8[$57>>0] = $59;
    }
    $60 = (($i$025) + 1)|0;
    $exitcond30 = ($60|0)==($2|0);
    if ($exitcond30) {
     break;
    } else {
     $i$025 = $60;
    }
   }
   $$pre = HEAP32[$4>>2]|0;
   $$pre33 = HEAP32[$$pre>>2]|0;
   $$phi$trans$insert = (($$pre33) + 16|0);
   $$pre34 = HEAP32[$$phi$trans$insert>>2]|0;
   $61 = HEAP32[$$pre34>>2]|0;
   $62 = (($61) + 16|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$0>>2]|0;
   FUNCTION_TABLE_viii[$63 & 4095]($$pre34,$64,$2);
   HEAP32[$1>>2] = 0;
   $259 = (($this) + 96|0);
   $260 = HEAP32[$259>>2]|0;
   $261 = (($260) + 4|0);
   HEAP32[$261>>2] = 0;
   $262 = (($this) + 100|0);
   HEAP8[$262>>0] = 0;
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$activeClients+0>>2]=0|0;HEAP32[$activeClients+4>>2]=0|0;HEAP32[$activeClients+8>>2]=0|0;HEAP32[$activeClients+12>>2]=0|0;
 $65 = (($this) + 96|0);
 $66 = (($this) + 1164|0);
 $67 = (($this) + 100|0);
 $68 = (($this) + 1204|0);
 $activeClientLimit$020 = 0;$i1$017 = 1;$nbValidPairs$018 = 0;
 while(1) {
  $69 = HEAP32[$65>>2]|0;
  $70 = HEAP32[$69>>2]|0;
  $71 = ((($70) + (($nbValidPairs$018*12)|0)|0) + 10|0);
  $72 = HEAP8[$71>>0]|0;
  $73 = ((($70) + (($nbValidPairs$018*12)|0)|0) + 11|0);
  $74 = HEAP8[$73>>0]|0;
  $75 = ((($70) + (($nbValidPairs$018*12)|0)|0) + 8|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $76&255;
  $78 = HEAP32[$66>>2]|0;
  $79 = (($78) + ($77<<2)|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($80) + 12|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = ((($70) + (($nbValidPairs$018*12)|0)|0) + 9|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = $84&255;
  $86 = (($78) + ($85<<2)|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (($87) + 12|0);
  $89 = HEAP8[$88>>0]|0;
  $90 = (($80) + 16|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($91|0)==(0|0);
  if ($92) {
   $105 = 0;
  } else {
   $93 = ($76<<24>>24)==($84<<24>>24);
   if ($93) {
    $105 = 1;
   } else {
    $94 = $82 & 1;
    $95 = ($94<<24>>24)==(0);
    if ($95) {
     $105 = 0;
    } else {
     $96 = $74 & 1;
     $97 = ($96<<24>>24)!=(0);
     $105 = $97;
    }
   }
  }
  $98 = (($87) + 16|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = ($99|0)==(0|0);
  $101 = ($76<<24>>24)==($84<<24>>24);
  $or$cond = $100 | $101;
  if ($or$cond) {
   $$off0 = 0;
  } else {
   $102 = $72 & 1;
   $103 = $102 & $89;
   $104 = ($103<<24>>24)!=(0);
   $$off0 = $104;
  }
  $brmerge = $105 | $$off0;
  if ($brmerge) {
   $106 = HEAP8[$67>>0]|0;
   $107 = ($106<<24>>24)==(0);
   do {
    if (!($107)) {
     $108 = HEAP32[$68>>2]|0;
     $109 = HEAP32[$0>>2]|0;
     $110 = (($70) + (($nbValidPairs$018*12)|0)|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = $111 >>> 5;
     $113 = (($108) + 20|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = $114 & 2147483647;
     $116 = ($112>>>0)<($115>>>0);
     if ($116) {
      $117 = (($108) + 16|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = (($118) + ($112<<2)|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = $111 & 31;
      $122 = 1 << $121;
      $123 = $120 & $122;
      $phitmp$i = ($123|0)==(0);
      $125 = $phitmp$i;
     } else {
      $125 = 1;
     }
     $124 = $125&1;
     $$$i = $124 ^ 1;
     $126 = ((($70) + (($nbValidPairs$018*12)|0)|0) + 4|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = $127 >>> 5;
     $129 = ($128>>>0)<($115>>>0);
     if ($129) {
      $130 = (($108) + 16|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = (($131) + ($128<<2)|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = $127 & 31;
      $135 = 1 << $134;
      $136 = $133 & $135;
      $137 = ($136|0)==(0);
      if ($137) {
       label = 30;
      } else {
       $138 = $$$i&255;
       $139 = $138 | 2;
       $140 = $139&255;
       $flags$12$i = $140;
      }
     } else {
      label = 30;
     }
     if ((label|0) == 30) {
      label = 0;
      if ($125) {
       break;
      } else {
       $flags$12$i = $$$i;
      }
     }
     $141 = ((($109) + (($nbValidPairs$018*24)|0)|0) + 20|0);
     $142 = HEAP8[$141>>0]|0;
     $143 = $142 | $flags$12$i;
     HEAP8[$141>>0] = $143;
    }
   } while(0);
   if ($105) {
    $144 = HEAP8[$75>>0]|0;
    $145 = $144&255;
    $146 = $145 & 7;
    $147 = 1 << $146;
    $148 = $145 >>> 3;
    $149 = (($activeClients) + ($148<<2)|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = $147 | $150;
    HEAP32[$149>>2] = $151;
    $152 = (($145) + 1)|0;
    $153 = $152&65535;
    $154 = ($153&65535)<($activeClientLimit$020&65535);
    $155 = $154 ? $activeClientLimit$020 : $153;
    $activeClientLimit$1 = $155;
   } else {
    HEAP8[$75>>0] = -128;
    $activeClientLimit$1 = $activeClientLimit$020;
   }
   if ($$off0) {
    $156 = HEAP8[$83>>0]|0;
    $157 = $156&255;
    $158 = $157 & 7;
    $159 = 1 << $158;
    $160 = $157 >>> 3;
    $161 = (($activeClients) + ($160<<2)|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = $159 | $162;
    HEAP32[$161>>2] = $163;
    $164 = (($157) + 1)|0;
    $165 = $164&65535;
    $166 = ($165&65535)<($activeClientLimit$1&65535);
    $167 = $166 ? $activeClientLimit$1 : $165;
    $activeClientLimit$2 = $167;
   } else {
    HEAP8[$83>>0] = -128;
    $activeClientLimit$2 = $activeClientLimit$1;
   }
   $168 = (($nbValidPairs$018) + 1)|0;
   $activeClientLimit$3 = $activeClientLimit$2;$nbValidPairs$1 = $168;
  } else {
   $169 = HEAP32[$0>>2]|0;
   $170 = (($169) + (($nbValidPairs$018*24)|0)|0);
   $171 = HEAP32[$1>>2]|0;
   $172 = (($171) + -1)|0;
   HEAP32[$1>>2] = $172;
   $173 = (($169) + (($172*24)|0)|0);
   ;HEAP32[$170+0>>2]=HEAP32[$173+0>>2]|0;HEAP32[$170+4>>2]=HEAP32[$173+4>>2]|0;HEAP32[$170+8>>2]=HEAP32[$173+8>>2]|0;HEAP32[$170+12>>2]=HEAP32[$173+12>>2]|0;HEAP32[$170+16>>2]=HEAP32[$173+16>>2]|0;HEAP8[$170+20>>0]=HEAP8[$173+20>>0]|0;
   $174 = HEAP32[$65>>2]|0;
   $175 = HEAP32[$174>>2]|0;
   $176 = (($175) + (($nbValidPairs$018*12)|0)|0);
   $177 = (($174) + 4|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = (($178) + -1)|0;
   HEAP32[$177>>2] = $179;
   $180 = (($175) + (($179*12)|0)|0);
   ;HEAP32[$176+0>>2]=HEAP32[$180+0>>2]|0;HEAP32[$176+4>>2]=HEAP32[$180+4>>2]|0;HEAP32[$176+8>>2]=HEAP32[$180+8>>2]|0;
   $activeClientLimit$3 = $activeClientLimit$020;$nbValidPairs$1 = $nbValidPairs$018;
  }
  $exitcond29 = ($i1$017|0)==($2|0);
  if ($exitcond29) {
   break;
  }
  $phitmp = (($i1$017) + 1)|0;
  $activeClientLimit$020 = $activeClientLimit$3;$i1$017 = $phitmp;$nbValidPairs$018 = $nbValidPairs$1;
 }
 $181 = (($perClientArray) + 768|0);
 $182 = (($perClientArray) + 772|0);
 $183 = (($perClientArray) + 776|0);
 HEAP32[$183>>2] = 0;
 $184 = (($perClientArray) + 780|0);
 HEAP8[$181>>0] = 1;
 HEAP32[$182>>2] = $perClientArray;
 HEAP32[$184>>2] = 32;
 $185 = ($activeClientLimit$3<<16>>16)==(0);
 if ($185) {
  $254 = 32;
 } else {
  $186 = ($nbValidPairs$1|0)==(0);
  $187 = (($this) + 96|0);
  $188 = $activeClientLimit$3&65535;
  if ($186) {
   $i2$014 = 0;
   while(1) {
    $235 = $i2$014 >>> 3;
    $236 = (($activeClients) + ($235<<2)|0);
    $237 = HEAP32[$236>>2]|0;
    $238 = $i2$014 & 7;
    $239 = 1 << $238;
    $240 = $237 & $239;
    $241 = ($240|0)==(0);
    if (!($241)) {
     HEAP32[$183>>2] = 0;
     $242 = HEAP32[$4>>2]|0;
     $243 = (($242) + ($i2$014<<2)|0);
     $244 = HEAP32[$243>>2]|0;
     $245 = (($244) + 16|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = HEAP32[$246>>2]|0;
     $248 = (($247) + 16|0);
     $249 = HEAP32[$248>>2]|0;
     $250 = HEAP32[$182>>2]|0;
     $251 = HEAP32[$183>>2]|0;
     FUNCTION_TABLE_viii[$249 & 4095]($246,$250,$251);
    }
    $252 = (($i2$014) + 1)|0;
    $exitcond = ($252|0)==($188|0);
    if ($exitcond) {
     break;
    } else {
     $i2$014 = $252;
    }
   }
  } else {
   $i2$014$us = 0;
   while(1) {
    $189 = $i2$014$us >>> 3;
    $190 = (($activeClients) + ($189<<2)|0);
    $191 = HEAP32[$190>>2]|0;
    $192 = $i2$014$us & 7;
    $193 = 1 << $192;
    $194 = $191 & $193;
    $195 = ($194|0)==(0);
    if (!($195)) {
     HEAP32[$183>>2] = 0;
     $196 = HEAP32[$184>>2]|0;
     $197 = $196 & 2147483647;
     $198 = ($197>>>0)<($nbValidPairs$1>>>0);
     if ($198) {
      __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_15InlineAllocatorILj768ENS0_13TempAllocatorEEEE8recreateEj($perClientArray,$nbValidPairs$1);
      $j$012$us = 0;
     } else {
      $j$012$us = 0;
     }
     while(1) {
      $209 = HEAP32[$187>>2]|0;
      $210 = HEAP32[$209>>2]|0;
      $211 = ((($210) + (($j$012$us*12)|0)|0) + 8|0);
      $212 = HEAP8[$211>>0]|0;
      $213 = $212&255;
      $214 = ($213|0)==($i2$014$us|0);
      if ($214) {
       label = 50;
      } else {
       $215 = ((($210) + (($j$012$us*12)|0)|0) + 9|0);
       $216 = HEAP8[$215>>0]|0;
       $217 = $216&255;
       $218 = ($217|0)==($i2$014$us|0);
       if ($218) {
        label = 50;
       }
      }
      do {
       if ((label|0) == 50) {
        label = 0;
        $219 = HEAP32[$0>>2]|0;
        $220 = (($219) + (($j$012$us*24)|0)|0);
        $221 = HEAP32[$184>>2]|0;
        $222 = $221 & 2147483647;
        $223 = HEAP32[$183>>2]|0;
        $224 = ($222>>>0)>($223>>>0);
        if (!($224)) {
         (__ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_15InlineAllocatorILj768ENS0_13TempAllocatorEEEE15growAndPushBackERKS2_($perClientArray,$220)|0);
         break;
        }
        $225 = HEAP32[$182>>2]|0;
        $226 = (($225) + (($223*24)|0)|0);
        $227 = ($226|0)==(0|0);
        if ($227) {
         $232 = $223;
        } else {
         ;HEAP32[$226+0>>2]=HEAP32[$220+0>>2]|0;HEAP32[$226+4>>2]=HEAP32[$220+4>>2]|0;HEAP32[$226+8>>2]=HEAP32[$220+8>>2]|0;HEAP32[$226+12>>2]=HEAP32[$220+12>>2]|0;HEAP32[$226+16>>2]=HEAP32[$220+16>>2]|0;
         $228 = ((($219) + (($j$012$us*24)|0)|0) + 20|0);
         $229 = HEAP8[$228>>0]|0;
         $230 = ((($225) + (($223*24)|0)|0) + 20|0);
         HEAP8[$230>>0] = $229;
         $$pre$i$us = HEAP32[$183>>2]|0;
         $232 = $$pre$i$us;
        }
        $231 = (($232) + 1)|0;
        HEAP32[$183>>2] = $231;
       }
      } while(0);
      $233 = (($j$012$us) + 1)|0;
      $exitcond31 = ($233|0)==($nbValidPairs$1|0);
      if ($exitcond31) {
       break;
      } else {
       $j$012$us = $233;
      }
     }
     $199 = HEAP32[$4>>2]|0;
     $200 = (($199) + ($i2$014$us<<2)|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = (($201) + 16|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = HEAP32[$203>>2]|0;
     $205 = (($204) + 16|0);
     $206 = HEAP32[$205>>2]|0;
     $207 = HEAP32[$182>>2]|0;
     $208 = HEAP32[$183>>2]|0;
     FUNCTION_TABLE_viii[$206 & 4095]($203,$207,$208);
    }
    $234 = (($i2$014$us) + 1)|0;
    $exitcond32 = ($234|0)==($188|0);
    if ($exitcond32) {
     break;
    } else {
     $i2$014$us = $234;
    }
   }
  }
  $$pre35 = HEAP32[$184>>2]|0;
  $254 = $$pre35;
 }
 $253 = $254 & 2147483647;
 $255 = ($253|0)!=(0);
 $256 = ($254|0)>(-1);
 $or$cond$i$i$i = $255 & $256;
 if (!($or$cond$i$i$i)) {
  HEAP32[$1>>2] = 0;
  $259 = (($this) + 96|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = (($260) + 4|0);
  HEAP32[$261>>2] = 0;
  $262 = (($this) + 100|0);
  HEAP8[$262>>0] = 0;
  STACKTOP = sp;return;
 }
 $257 = HEAP32[$182>>2]|0;
 $258 = ($perClientArray|0)==($257|0);
 if ($258) {
  HEAP8[$181>>0] = 0;
  HEAP32[$1>>2] = 0;
  $259 = (($this) + 96|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = (($260) + 4|0);
  HEAP32[$261>>2] = 0;
  $262 = (($this) + 100|0);
  HEAP8[$262>>0] = 0;
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($perClientArray,$257);
  HEAP32[$1>>2] = 0;
  $259 = (($this) + 96|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = (($260) + 4|0);
  HEAP32[$261>>2] = 0;
  $262 = (($this) + 100|0);
  HEAP8[$262>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc5Scene20afterGenerateIslandsEv($this) {
 $this = $this|0;
 var $$not = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i1$02 = 0, $or$cond = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1252|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$pre = (($this) + 1264|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $3 = (($this) + 1248|0);
  $4 = (($this) + 1264|0);
  $5 = (($this) + 1260|0);
  $i$03 = 0;
  while(1) {
   $6 = HEAP32[$3>>2]|0;
   $7 = ((($6) + ($i$03<<4)|0) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8 >>> 5;
   $10 = HEAP32[$4>>2]|0;
   $11 = $10 & 2147483647;
   $12 = ($9>>>0)<($11>>>0);
   if ($12) {
    $13 = HEAP32[$5>>2]|0;
    $14 = (($13) + ($9<<2)|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $8 & 31;
    $17 = 1 << $16;
    $18 = $15 & $17;
    $30 = $18;
   } else {
    $30 = 0;
   }
   $19 = ((($6) + ($i$03<<4)|0) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20 >>> 5;
   $22 = ($21>>>0)<($11>>>0);
   if ($22) {
    $23 = HEAP32[$5>>2]|0;
    $24 = (($23) + ($21<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = $20 & 31;
    $27 = 1 << $26;
    $28 = $25 & $27;
    $phitmp = ($28|0)==(0);
    $31 = $phitmp;
   } else {
    $31 = 1;
   }
   $29 = ($30|0)!=(0);
   $$not = $29 ^ 1;
   $or$cond = $31 & $$not;
   do {
    if ($or$cond) {
     $37 = (($6) + ($i$03<<4)|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($38) + 51|0);
     $40 = HEAP8[$39>>0]|0;
     $41 = $40 & 1;
     $42 = ($41<<24>>24)==(0);
     $43 = ((($6) + ($i$03<<4)|0) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + 51|0);
     $46 = HEAP8[$45>>0]|0;
     $47 = $46 & 1;
     $48 = ($47<<24>>24)==(0);
     if ($42) {
      if ($48) {
       break;
      }
     } else {
      if (!($48)) {
       break;
      }
     }
     __ZN5physx2Sc7BodySim14internalWakeUpEf($38,Math_fround(0.399999976158142089844));
     $49 = HEAP32[$3>>2]|0;
     $50 = ((($49) + ($i$03<<4)|0) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     __ZN5physx2Sc7BodySim14internalWakeUpEf($51,Math_fround(0.399999976158142089844));
    } else {
     if (!($29)) {
      $32 = (($6) + ($i$03<<4)|0);
      $33 = HEAP32[$32>>2]|0;
      __ZN5physx2Sc7BodySim14internalWakeUpEf($33,Math_fround(0.399999976158142089844));
     }
     if ($31) {
      $34 = HEAP32[$3>>2]|0;
      $35 = ((($34) + ($i$03<<4)|0) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      __ZN5physx2Sc7BodySim14internalWakeUpEf($36,Math_fround(0.399999976158142089844));
     }
    }
   } while(0);
   $52 = (($i$03) + 1)|0;
   $53 = HEAP32[$0>>2]|0;
   $54 = ($52>>>0)<($53>>>0);
   if ($54) {
    $i$03 = $52;
   } else {
    $$pre$phiZ2D = $4;
    break;
   }
  }
 }
 HEAP32[$0>>2] = 0;
 $55 = HEAP32[$$pre$phiZ2D>>2]|0;
 $56 = (($this) + 1260|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $55 << 2;
 _memset(($57|0),0,($58|0))|0;
 $59 = (($this) + 108|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $62 = (($this) + 104|0);
 $i1$02 = 0;
 while(1) {
  $63 = HEAP32[$62>>2]|0;
  $64 = (($63) + ($i1$02<<2)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  __ZNK5physx2Sc15ArticulationSim11checkResizeEv($66);
  $67 = (($i1$02) + 1)|0;
  $68 = HEAP32[$59>>2]|0;
  $69 = ($67>>>0)<($68>>>0);
  if ($69) {
   $i1$02 = $67;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene26getSimulationEventCallbackEh($this,$client) {
 $this = $this|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $client&255;
 $1 = (($this) + 1164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZNK5physx2Sc5Scene24getContactModifyCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 5912|0);
 $5 = HEAP32[$4>>2]|0;
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc5Scene27getCCDContactModifyCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5physx10PxsContext27getCCDContactModifyCallbackEv($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc5Scene15getCCDMaxPassesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5physx10PxsContext15getCCDMaxPassesEv($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc5Scene21getBroadPhaseCallbackEh($this,$client) {
 $this = $this|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $client&255;
 $1 = (($this) + 1164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx2Sc5Scene10removeBodyERNS0_7BodySimE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i = 0, $index$0$lcssa$i3 = 0, $index$01$i = 0, $index$01$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($body) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 80|0);
  $4 = HEAP32[$3>>2]|0;
  __ZN5physx2Sc27ConstraintProjectionManager15invalidateGroupERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimE($4,$1,0);
 }
 $5 = (($body) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 1140|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($this) + 1136|0);
  $11 = HEAP32[$10>>2]|0;
  $index$01$i2 = 0;
  while(1) {
   $14 = (($11) + ($index$01$i2<<2)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==($6|0);
   $13 = (($index$01$i2) + 1)|0;
   if ($16) {
    $index$0$lcssa$i3 = $index$01$i2;
    break;
   }
   $12 = ($13>>>0)<($8>>>0);
   if ($12) {
    $index$01$i2 = $13;
   } else {
    $index$0$lcssa$i3 = $13;
    break;
   }
  }
  $17 = ($index$0$lcssa$i3|0)==($8|0);
  if (!($17)) {
   $18 = (($8) + -1)|0;
   HEAP32[$7>>2] = $18;
   $19 = (($11) + ($18<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($11) + ($index$0$lcssa$i3<<2)|0);
   HEAP32[$21>>2] = $20;
  }
 }
 $22 = (($this) + 1152|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = (($this) + 1148|0);
  $26 = HEAP32[$25>>2]|0;
  $index$01$i = 0;
  while(1) {
   $29 = (($26) + ($index$01$i<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==($6|0);
   $28 = (($index$01$i) + 1)|0;
   if ($31) {
    $index$0$lcssa$i = $index$01$i;
    break;
   }
   $27 = ($28>>>0)<($23>>>0);
   if ($27) {
    $index$01$i = $28;
   } else {
    $index$0$lcssa$i = $28;
    break;
   }
  }
  $32 = ($index$0$lcssa$i|0)==($23|0);
  if (!($32)) {
   $33 = (($23) + -1)|0;
   HEAP32[$22>>2] = $33;
   $34 = (($26) + ($33<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($26) + ($index$0$lcssa$i<<2)|0);
   HEAP32[$36>>2] = $35;
  }
 }
 $37 = (($body) + 56|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($this) + 1260|0);
 $40 = (($38) + 32)|0;
 $41 = $40 >>> 5;
 $42 = (($this) + 1264|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 & 2147483647;
 $45 = ($41>>>0)>($44>>>0);
 if (!($45)) {
  $$pre$i$i = HEAP32[$39>>2]|0;
  $65 = $$pre$i$i;
  $61 = $38 & 31;
  $62 = 1 << $61;
  $63 = $38 >>> 5;
  $64 = (($65) + ($63<<2)|0);
  $66 = HEAP32[$64>>2]|0;
  $67 = $66 | $62;
  HEAP32[$64>>2] = $67;
  STACKTOP = sp;return;
 }
 $46 = (($this) + 1268|0);
 $47 = $41 << 2;
 $48 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($46,$47,471576,339)|0);
 $49 = HEAP32[$39>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = HEAP32[$42>>2]|0;
  $52 = $51 << 2;
  _memcpy(($48|0),($49|0),($52|0))|0;
  $53 = HEAP32[$42>>2]|0;
  $54 = ($53|0)>(-1);
  if ($54) {
   $55 = HEAP32[$39>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($46,$55);
  }
 }
 $56 = HEAP32[$42>>2]|0;
 $57 = $56 & 2147483647;
 $58 = (($48) + ($57<<2)|0);
 $59 = (($41) - ($56))|0;
 $60 = $59 << 2;
 _memset(($58|0),0,($60|0))|0;
 HEAP32[$39>>2] = $48;
 HEAP32[$42>>2] = $41;
 $65 = $48;
 $61 = $38 & 31;
 $62 = 1 << $61;
 $63 = $38 >>> 5;
 $64 = (($65) + ($63<<2)|0);
 $66 = HEAP32[$64>>2]|0;
 $67 = $66 | $62;
 HEAP32[$64>>2] = $67;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene13addConstraintERNS0_14ConstraintCoreEPNS0_9RigidCoreES5_($this,$constraint,$body0,$body1) {
 $this = $this|0;
 $constraint = $constraint|0;
 $body0 = $body0|0;
 $body1 = $body1|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1232|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 292|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($2);
  $$pre$i$i = HEAP32[$3>>2]|0;
  $7 = $$pre$i$i;
 } else {
  $7 = $4;
 }
 $6 = HEAP32[$7>>2]|0;
 HEAP32[$3>>2] = $6;
 $8 = (($2) + 280|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = (($2) + 284|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + -1)|0;
 HEAP32[$11>>2] = $13;
 $14 = ($7|0)==(0|0);
 if (!($14)) {
  __ZN5physx2Sc13ConstraintSimC2ERNS0_14ConstraintCoreEPNS0_9RigidCoreES5_RNS0_5SceneE($7,$constraint,$body0,$body1,$this);
 }
 $15 = (($this) + 68|0);
 HEAP32[$0>>2] = $constraint;
 $16 = (($this) + 76|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2147483647;
 $19 = (($this) + 72|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if (!($21)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($15,$0)|0);
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$15>>2]|0;
 $23 = (($22) + ($20<<2)|0);
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  HEAP32[$23>>2] = $constraint;
 }
 $25 = (($20) + 1)|0;
 HEAP32[$19>>2] = $25;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene16removeConstraintERNS0_14ConstraintCoreE($this,$constraint) {
 $this = $this|0;
 $constraint = $constraint|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i = 0, $index$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($constraint) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 108|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $6 = (($1) + 112|0);
   $7 = HEAP32[$6>>2]|0;
   $$0$i1 = $7;
  } else {
   $$0$i1 = $4;
  }
  $8 = (($$0$i1) + 60|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = (($this) + 80|0);
   $12 = HEAP32[$11>>2]|0;
   __ZN5physx2Sc27ConstraintProjectionManager15invalidateGroupERNS0_19ConstraintGroupNodeEPNS0_13ConstraintSimE($12,$9,$1);
  }
  $13 = (($this) + 1232|0);
  $14 = HEAP32[$13>>2]|0;
  __ZN5physx2Sc13ConstraintSimD2Ev($1);
  $15 = (($14) + 280|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + -1)|0;
  HEAP32[$15>>2] = $17;
  $18 = (($14) + 292|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$1>>2] = $19;
  HEAP32[$18>>2] = $1;
  $20 = (($14) + 284|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 1)|0;
  HEAP32[$20>>2] = $22;
  $23 = (($14) + 276|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24*50)|0;
  $26 = ($21|0)<($25|0);
  if (!($26)) {
   __ZN5physx6shdfnd8PoolBaseINS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($14);
   HEAP32[$20>>2] = 0;
  }
 }
 $27 = (($this) + 72|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($this) + 68|0);
 $31 = HEAP32[$30>>2]|0;
 $index$01$i = 0;
 while(1) {
  $34 = (($31) + ($index$01$i<<2)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==($constraint|0);
  $33 = (($index$01$i) + 1)|0;
  if ($36) {
   $index$0$lcssa$i = $index$01$i;
   break;
  }
  $32 = ($33>>>0)<($28>>>0);
  if ($32) {
   $index$01$i = $33;
  } else {
   $index$0$lcssa$i = $33;
   break;
  }
 }
 $37 = ($index$0$lcssa$i|0)==($28|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($28) + -1)|0;
 HEAP32[$27>>2] = $38;
 $39 = (($31) + ($38<<2)|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($31) + ($index$0$lcssa$i<<2)|0);
 HEAP32[$41>>2] = $40;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene15addArticulationERNS0_16ArticulationCoreERNS0_8BodyCoreE($this,$articulation,$root) {
 $this = $this|0;
 $articulation = $articulation|0;
 $root = $root|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__Z15PxGetFoundationv()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $$$i$i$i = $10 ? 467400 : 464392;
 $11 = (FUNCTION_TABLE_iiiiii[$5 & 255]($2,164,$$$i$i$i,463960,774)|0);
 __ZN5physx2Sc15ArticulationSimC2ERNS0_16ArticulationCoreERNS0_5SceneERNS0_8BodyCoreE($11,$articulation,$this,$root);
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   __ZN5physx2Sc15ArticulationSimD2Ev($11);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
   STACKTOP = sp;return;
  }
 }
 $15 = (($this) + 104|0);
 HEAP32[$1>>2] = $articulation;
 $16 = (($this) + 112|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2147483647;
 $19 = (($this) + 108|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if (!($21)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc16ArticulationCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($15,$1)|0);
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$15>>2]|0;
 $23 = (($22) + ($20<<2)|0);
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  HEAP32[$23>>2] = $articulation;
 }
 $25 = (($20) + 1)|0;
 HEAP32[$19>>2] = $25;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene18removeArticulationERNS0_16ArticulationCoreE($this,$articulation) {
 $this = $this|0;
 $articulation = $articulation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i = 0, $index$01$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$articulation>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5physx2Sc15ArticulationSimD2Ev($1);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 }
 $3 = (($this) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 104|0);
 $7 = HEAP32[$6>>2]|0;
 $index$01$i = 0;
 while(1) {
  $10 = (($7) + ($index$01$i<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==($articulation|0);
  $9 = (($index$01$i) + 1)|0;
  if ($12) {
   $index$0$lcssa$i = $index$01$i;
   break;
  }
  $8 = ($9>>>0)<($4>>>0);
  if ($8) {
   $index$01$i = $9;
  } else {
   $index$0$lcssa$i = $9;
   break;
  }
 }
 $13 = ($index$0$lcssa$i|0)==($4|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($4) + -1)|0;
 HEAP32[$3>>2] = $14;
 $15 = (($7) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($7) + ($index$0$lcssa$i<<2)|0);
 HEAP32[$17>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene20addArticulationJointERNS0_21ArticulationJointCoreERNS0_8BodyCoreES5_($this,$joint,$parent,$child) {
 $this = $this|0;
 $joint = $joint|0;
 $parent = $parent|0;
 $child = $child|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 467128 : 464392;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,40,$$$i$i$i,463960,796)|0);
 $10 = (__ZNK5physx2Sc8BodyCore6getSimEv($parent)|0);
 $11 = (__ZNK5physx2Sc8BodyCore6getSimEv($child)|0);
 __ZN5physx2Sc20ArticulationJointSimC2ERNS0_21ArticulationJointCoreERNS0_8ActorSimES5_($9,$joint,$10,$11);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene23removeArticulationJointERNS0_21ArticulationJointCoreE($this,$joint) {
 $this = $this|0;
 $joint = $joint|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$joint>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19addBrokenConstraintEPNS0_14ConstraintCoreE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $c;
 $1 = (($this) + 176|0);
 $2 = (($this) + 184|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = (($this) + 180|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if (!($7)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  HEAP32[$9>>2] = $c;
 }
 $11 = (($6) + 1)|0;
 HEAP32[$5>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene28addActiveBreakableConstraintEPNS0_13ConstraintSimE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $c;
 $1 = (($this) + 188|0);
 $2 = (($this) + 196|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = (($this) + 192|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if (!($7)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
  $$pre = HEAP32[$0>>2]|0;
  $13 = $$pre;
  $12 = (($13) + 116|0);
  $14 = HEAP8[$12>>0]|0;
  $15 = $14 | 4;
  HEAP8[$12>>0] = $15;
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  HEAP32[$9>>2] = $c;
 }
 $11 = (($6) + 1)|0;
 HEAP32[$5>>2] = $11;
 $13 = $c;
 $12 = (($13) + 116|0);
 $14 = HEAP8[$12>>0]|0;
 $15 = $14 | 4;
 HEAP8[$12>>0] = $15;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene31removeActiveBreakableConstraintEPNS0_13ConstraintSimE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $index$0$lcssa$i = 0, $index$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 192|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 188|0);
  $4 = HEAP32[$3>>2]|0;
  $index$01$i = 0;
  while(1) {
   $7 = (($4) + ($index$01$i<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==($c|0);
   $6 = (($index$01$i) + 1)|0;
   if ($9) {
    $index$0$lcssa$i = $index$01$i;
    break;
   }
   $5 = ($6>>>0)<($1>>>0);
   if ($5) {
    $index$01$i = $6;
   } else {
    $index$0$lcssa$i = $6;
    break;
   }
  }
  $10 = ($index$0$lcssa$i|0)==($1|0);
  if (!($10)) {
   $11 = (($1) + -1)|0;
   HEAP32[$0>>2] = $11;
   $12 = (($4) + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($4) + ($index$0$lcssa$i<<2)|0);
   HEAP32[$14>>2] = $13;
  }
 }
 $15 = (($c) + 116|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $17 & 251;
 $19 = $18&255;
 HEAP8[$15>>0] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene23allocateConstraintBlockEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($size>>>0)<(129);
 if ($1) {
  $2 = (($this) + 492|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $5 = (($this) + 200|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj128EEENS0_19ReflectionAllocatorIS4_EEE12allocateSlabEv($5);
   $$pre$i$i = HEAP32[$2>>2]|0;
   $7 = $$pre$i$i;
  } else {
   $7 = $3;
  }
  $6 = HEAP32[$7>>2]|0;
  HEAP32[$2>>2] = $6;
  $8 = (($this) + 480|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$8>>2] = $10;
  $11 = (($this) + 484|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + -1)|0;
  HEAP32[$11>>2] = $13;
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = ($size>>>0)<(257);
 if ($14) {
  $15 = (($this) + 788|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $18 = (($this) + 496|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj256EEENS0_19ReflectionAllocatorIS4_EEE12allocateSlabEv($18);
   $$pre$i$i1 = HEAP32[$15>>2]|0;
   $20 = $$pre$i$i1;
  } else {
   $20 = $16;
  }
  $19 = HEAP32[$20>>2]|0;
  HEAP32[$15>>2] = $19;
  $21 = (($this) + 776|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 1)|0;
  HEAP32[$21>>2] = $23;
  $24 = (($this) + 780|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + -1)|0;
  HEAP32[$24>>2] = $26;
  $$0 = $20;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = ($size>>>0)<(385);
 if (!($27)) {
  $40 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$size,463960,843)|0);
  $$0 = $40;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = (($this) + 1084|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  $31 = (($this) + 792|0);
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj384EEENS0_19ReflectionAllocatorIS4_EEE12allocateSlabEv($31);
  $$pre$i$i2 = HEAP32[$28>>2]|0;
  $33 = $$pre$i$i2;
 } else {
  $33 = $29;
 }
 $32 = HEAP32[$33>>2]|0;
 HEAP32[$28>>2] = $32;
 $34 = (($this) + 1072|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 1)|0;
 HEAP32[$34>>2] = $36;
 $37 = (($this) + 1076|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$37>>2] = $39;
 $$0 = $33;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc5Scene25deallocateConstraintBlockEPvj($this,$ptr,$size) {
 $this = $this|0;
 $ptr = $ptr|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($size>>>0)<(129);
 if ($1) {
  $2 = (($this) + 200|0);
  $3 = ($ptr|0)==(0|0);
  if ($3) {
   STACKTOP = sp;return;
  }
  $4 = (($this) + 480|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + -1)|0;
  HEAP32[$4>>2] = $6;
  $7 = (($this) + 492|0);
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$ptr>>2] = $8;
  HEAP32[$7>>2] = $ptr;
  $9 = (($this) + 484|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$9>>2] = $11;
  $12 = (($this) + 476|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13*50)|0;
  $15 = ($10|0)<($14|0);
  if ($15) {
   STACKTOP = sp;return;
  }
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj128EEENS0_19ReflectionAllocatorIS4_EEE17releaseEmptySlabsEv($2);
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return;
 }
 $16 = ($size>>>0)<(257);
 if ($16) {
  $17 = (($this) + 496|0);
  $18 = ($ptr|0)==(0|0);
  if ($18) {
   STACKTOP = sp;return;
  }
  $19 = (($this) + 776|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + -1)|0;
  HEAP32[$19>>2] = $21;
  $22 = (($this) + 788|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$ptr>>2] = $23;
  HEAP32[$22>>2] = $ptr;
  $24 = (($this) + 780|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 1)|0;
  HEAP32[$24>>2] = $26;
  $27 = (($this) + 772|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28*50)|0;
  $30 = ($25|0)<($29|0);
  if ($30) {
   STACKTOP = sp;return;
  }
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj256EEENS0_19ReflectionAllocatorIS4_EEE17releaseEmptySlabsEv($17);
  HEAP32[$24>>2] = 0;
  STACKTOP = sp;return;
 }
 $31 = ($size>>>0)<(385);
 if (!($31)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$ptr);
  STACKTOP = sp;return;
 }
 $32 = (($this) + 792|0);
 $33 = ($ptr|0)==(0|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = (($this) + 1072|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + -1)|0;
 HEAP32[$34>>2] = $36;
 $37 = (($this) + 1084|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$ptr>>2] = $38;
 HEAP32[$37>>2] = $ptr;
 $39 = (($this) + 1076|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 1)|0;
 HEAP32[$39>>2] = $41;
 $42 = (($this) + 1068|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43*50)|0;
 $45 = ($40|0)<($44|0);
 if ($45) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj384EEENS0_19ReflectionAllocatorIS4_EEE17releaseEmptySlabsEv($32);
 HEAP32[$39>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene16scheduleClothGpuERNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $j$01 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 144|0);
 $1 = (($this) + 140|0);
 $2 = (($this) + 48|0);
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 if (!($9)) {
  $25 = HEAP32[$3>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 16|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = Math_fround(HEAPF32[$2>>2]);
  $30 = (FUNCTION_TABLE_iifi[$28 & 7]($25,$29,$continuation)|0);
  $31 = (($this) + 164|0);
  HEAP32[$31>>2] = $30;
  STACKTOP = sp;return;
 }
 $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,2,463960,901,464088,$vararg_buffer);
 $11 = HEAP32[$0>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $j$01 = 0;
  while(1) {
   $13 = HEAP32[$1>>2]|0;
   $14 = (($13) + ($j$01<<2)|0);
   $15 = HEAP32[$14>>2]|0;
   __ZN5physx2Sc9ClothCore12setClothFlagENS_11PxClothFlag4EnumEb($15,1,0);
   $16 = (($j$01) + 1)|0;
   $17 = HEAP32[$0>>2]|0;
   $18 = ($16>>>0)<($17>>>0);
   if ($18) {
    $j$01 = $16;
   } else {
    break;
   }
  }
 }
 $19 = HEAP32[$3>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = HEAP32[$19>>2]|0;
  $22 = (($21) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  FUNCTION_TABLE_vi[$23 & 4095]($19);
 }
 HEAP32[$3>>2] = 0;
 $24 = (($this) + 164|0);
 HEAP32[$24>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene31scheduleParticleShapeGenerationERNS_10PxBaseTaskES3_($this,$broadPhaseDependent,$dynamicsCpuDependent) {
 $this = $this|0;
 $broadPhaseDependent = $broadPhaseDependent|0;
 $dynamicsCpuDependent = $dynamicsCpuDependent|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1704|0);
 $2 = (($this) + 1792|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($3);
 $4 = (($this) + 1716|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($4)|0);
 $5 = (($broadPhaseDependent) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 1712|0);
 HEAP32[$7>>2] = $6;
 HEAP32[$0>>2] = $broadPhaseDependent;
 $8 = (($this) + 1752|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = (($this) + 1748|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($13) {
  $15 = (($this) + 1744|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($12<<2)|0);
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   HEAP32[$17>>2] = $broadPhaseDependent;
  }
  $19 = (($12) + 1)|0;
  HEAP32[$11>>2] = $19;
 } else {
  $14 = (($this) + 1724|0);
  (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($14,$0)|0);
 }
 $20 = HEAP32[$broadPhaseDependent>>2]|0;
 $21 = (($20) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($broadPhaseDependent);
 $23 = (($this) + 1788|0);
 HEAP8[$23>>0] = 1;
 $24 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($24);
 $25 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($25);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($4)|0);
 $26 = (($dynamicsCpuDependent) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$7>>2] = $27;
 HEAP32[$0>>2] = $dynamicsCpuDependent;
 $28 = HEAP32[$8>>2]|0;
 $29 = $28 & 2147483647;
 $30 = HEAP32[$11>>2]|0;
 $31 = ($29>>>0)>($30>>>0);
 if ($31) {
  $33 = (($this) + 1744|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($30<<2)|0);
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   HEAP32[$35>>2] = $dynamicsCpuDependent;
  }
  $37 = (($30) + 1)|0;
  HEAP32[$11>>2] = $37;
 } else {
  $32 = (($this) + 1724|0);
  (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($32,$0)|0);
 }
 $38 = HEAP32[$dynamicsCpuDependent>>2]|0;
 $39 = (($38) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_vi[$40 & 4095]($dynamicsCpuDependent);
 HEAP8[$23>>0] = 1;
 $41 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($41);
 $42 = HEAP32[$1>>2]|0;
 $43 = (($42) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vi[$44 & 4095]($1);
 $45 = (($this) + 132|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0);
 if ($47) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $48 = (($this) + 128|0);
  $49 = (($this) + 1212|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (__ZN5physx2Sc17ParticleSystemSim23scheduleShapeGenerationERNS0_16InteractionSceneERKNS_6shdfnd5ArrayIPS1_NS4_19ReflectionAllocatorIS6_EEEERNS_10PxBaseTaskE($50,$48,$1)|0);
  $52 = HEAP32[$1>>2]|0;
  $53 = (($52) + 20|0);
  $54 = HEAP32[$53>>2]|0;
  FUNCTION_TABLE_vi[$54 & 4095]($1);
  $$0 = $51;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sc5Scene29scheduleParticleCollisionPrepERNS_10PxBaseTaskES3_($this,$collisionCpuDependent,$gpuDependent) {
 $this = $this|0;
 $collisionCpuDependent = $collisionCpuDependent|0;
 $gpuDependent = $gpuDependent|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1612|0);
 $2 = (($this) + 1700|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($3);
 $4 = (($this) + 1624|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($4)|0);
 $5 = (($collisionCpuDependent) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 1620|0);
 HEAP32[$7>>2] = $6;
 HEAP32[$0>>2] = $collisionCpuDependent;
 $8 = (($this) + 1660|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = (($this) + 1656|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($13) {
  $15 = (($this) + 1652|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($12<<2)|0);
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   HEAP32[$17>>2] = $collisionCpuDependent;
  }
  $19 = (($12) + 1)|0;
  HEAP32[$11>>2] = $19;
 } else {
  $14 = (($this) + 1632|0);
  (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($14,$0)|0);
 }
 $20 = HEAP32[$collisionCpuDependent>>2]|0;
 $21 = (($20) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($collisionCpuDependent);
 $23 = (($this) + 1696|0);
 HEAP8[$23>>0] = 1;
 $24 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($24);
 $25 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($25);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($4)|0);
 $26 = (($gpuDependent) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$7>>2] = $27;
 HEAP32[$0>>2] = $gpuDependent;
 $28 = HEAP32[$8>>2]|0;
 $29 = $28 & 2147483647;
 $30 = HEAP32[$11>>2]|0;
 $31 = ($29>>>0)>($30>>>0);
 if ($31) {
  $33 = (($this) + 1652|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($30<<2)|0);
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   HEAP32[$35>>2] = $gpuDependent;
  }
  $37 = (($30) + 1)|0;
  HEAP32[$11>>2] = $37;
 } else {
  $32 = (($this) + 1632|0);
  (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($32,$0)|0);
 }
 $38 = HEAP32[$gpuDependent>>2]|0;
 $39 = (($38) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_vi[$40 & 4095]($gpuDependent);
 HEAP8[$23>>0] = 1;
 $41 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($41);
 __ZN5physx2Cm10FanoutTask15removeReferenceEv($1);
 $42 = (($this) + 132|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0);
 if ($44) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $45 = (($this) + 128|0);
  $46 = (($this) + 1212|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (__ZN5physx2Sc17ParticleSystemSim21scheduleCollisionPrepERNS0_16InteractionSceneERKNS_6shdfnd5ArrayIPS1_NS4_19ReflectionAllocatorIS6_EEEERNS_10PxBaseTaskE($47,$45,$1)|0);
  __ZN5physx2Cm10FanoutTask15removeReferenceEv($1);
  $$0 = $48;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sc5Scene9solveStepEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1176|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,65,$6,$9);
 $13 = (($this) + 48|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $14 != Math_fround(0.0);
 if (!($15)) {
  $164 = HEAP32[$2>>2]|0;
  $165 = (($164) + 12|0);
  $166 = HEAP32[$165>>2]|0;
  FUNCTION_TABLE_viiii[$166 & 511]($2,65,$6,$9);
  STACKTOP = sp;return;
 }
 $16 = (($this) + 1800|0);
 $17 = (($this) + 1888|0);
 $18 = HEAP32[$17>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($18);
 $19 = (($this) + 1812|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($19)|0);
 $20 = (($continuation) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 1808|0);
 HEAP32[$22>>2] = $21;
 HEAP32[$0>>2] = $continuation;
 $23 = (($this) + 1848|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 & 2147483647;
 $26 = (($this) + 1844|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($25>>>0)>($27>>>0);
 if ($28) {
  $30 = (($this) + 1840|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + ($27<<2)|0);
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   HEAP32[$32>>2] = $continuation;
  }
  $34 = (($27) + 1)|0;
  HEAP32[$26>>2] = $34;
 } else {
  $29 = (($this) + 1820|0);
  (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($29,$0)|0);
 }
 $35 = HEAP32[$continuation>>2]|0;
 $36 = (($35) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vi[$37 & 4095]($continuation);
 $38 = (($this) + 1884|0);
 HEAP8[$38>>0] = 1;
 $39 = HEAP32[$17>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($39);
 $40 = HEAP32[$16>>2]|0;
 $41 = (($40) + 20|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vi[$42 & 4095]($16);
 $43 = (($this) + 1200|0);
 $44 = HEAP16[$43>>1]|0;
 $45 = $44 & 4;
 $46 = ($45<<16>>16)==(0);
 if ($46) {
  $69 = (($this) + 1980|0);
  HEAP32[$69>>2] = 1;
  $70 = (($this) + 1976|0);
  HEAP32[$70>>2] = $16;
  $71 = HEAP32[$16>>2]|0;
  $72 = (($71) + 16|0);
  $73 = HEAP32[$72>>2]|0;
  FUNCTION_TABLE_vi[$73 & 4095]($16);
  $74 = HEAP32[$70>>2]|0;
  $75 = (($74) + 8|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($this) + 1972|0);
  HEAP32[$77>>2] = $76;
 } else {
  $47 = (($this) + 1896|0);
  $48 = (($this) + 1912|0);
  HEAP32[$48>>2] = 1;
  $49 = (($this) + 1908|0);
  HEAP32[$49>>2] = $16;
  $50 = HEAP32[$16>>2]|0;
  $51 = (($50) + 16|0);
  $52 = HEAP32[$51>>2]|0;
  FUNCTION_TABLE_vi[$52 & 4095]($16);
  $53 = HEAP32[$49>>2]|0;
  $54 = (($53) + 8|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($this) + 1904|0);
  HEAP32[$56>>2] = $55;
  $57 = (($this) + 1980|0);
  HEAP32[$57>>2] = 1;
  $58 = (($this) + 1976|0);
  HEAP32[$58>>2] = $47;
  $59 = HEAP32[$47>>2]|0;
  $60 = (($59) + 16|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_vi[$61 & 4095]($47);
  $62 = HEAP32[$58>>2]|0;
  $63 = (($62) + 8|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($this) + 1972|0);
  HEAP32[$65>>2] = $64;
  $66 = HEAP32[$47>>2]|0;
  $67 = (($66) + 20|0);
  $68 = HEAP32[$67>>2]|0;
  FUNCTION_TABLE_vi[$68 & 4095]($47);
 }
 $78 = (($this) + 1964|0);
 $79 = (($this) + 152|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0|0);
 L15: do {
  if ($81) {
   label = 17;
  } else {
   $82 = (($this) + 144|0);
   $83 = (($this) + 140|0);
   $i$02$i = 0;
   while(1) {
    $84 = HEAP32[$82>>2]|0;
    $85 = ($i$02$i>>>0)<($84>>>0);
    if (!($85)) {
     label = 17;
     break L15;
    }
    $86 = HEAP32[$83>>2]|0;
    $87 = (($86) + ($i$02$i<<2)|0);
    $88 = HEAP32[$87>>2]|0;
    __ZNK5physx2Sc9ClothCore13getClothFlagsEv($0,$88);
    $89 = HEAP16[$0>>1]|0;
    $90 = $89 & 4;
    $91 = ($90<<16>>16)==(0);
    $92 = (($i$02$i) + 1)|0;
    if ($91) {
     $i$02$i = $92;
    } else {
     break;
    }
   }
   $93 = HEAP32[$79>>2]|0;
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 16|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = Math_fround(HEAPF32[$13>>2]);
   $98 = (FUNCTION_TABLE_iifi[$96 & 7]($93,$97,$78)|0);
   $99 = (($this) + 1572|0);
   HEAP32[$99>>2] = 1;
   $100 = (($this) + 1568|0);
   HEAP32[$100>>2] = $98;
   $101 = ($98|0)==(0|0);
   if (!($101)) {
    $102 = HEAP32[$98>>2]|0;
    $103 = (($102) + 16|0);
    $104 = HEAP32[$103>>2]|0;
    FUNCTION_TABLE_vi[$104 & 4095]($98);
    $105 = HEAP32[$100>>2]|0;
    $106 = (($105) + 8|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($this) + 1564|0);
    HEAP32[$108>>2] = $107;
   }
   $109 = HEAP32[$98>>2]|0;
   $110 = (($109) + 20|0);
   $111 = HEAP32[$110>>2]|0;
   FUNCTION_TABLE_vi[$111 & 4095]($98);
   $112 = (($this) + 1556|0);
   $$0$i = $112;
  }
 } while(0);
 if ((label|0) == 17) {
  $113 = HEAP32[$78>>2]|0;
  $114 = (($113) + 16|0);
  $115 = HEAP32[$114>>2]|0;
  FUNCTION_TABLE_vi[$115 & 4095]($78);
  $$0$i = $78;
 }
 $116 = (($this) + 1992|0);
 $117 = (($this) + 2008|0);
 HEAP32[$117>>2] = 1;
 $118 = (($this) + 2004|0);
 HEAP32[$118>>2] = $$0$i;
 $119 = HEAP32[$$0$i>>2]|0;
 $120 = (($119) + 16|0);
 $121 = HEAP32[$120>>2]|0;
 FUNCTION_TABLE_vi[$121 & 4095]($$0$i);
 $122 = HEAP32[$118>>2]|0;
 $123 = (($122) + 8|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($this) + 2000|0);
 HEAP32[$125>>2] = $124;
 $126 = (($this) + 2076|0);
 $127 = (($this) + 2092|0);
 HEAP32[$127>>2] = 1;
 $128 = (($this) + 2088|0);
 HEAP32[$128>>2] = $116;
 $129 = HEAP32[$116>>2]|0;
 $130 = (($129) + 16|0);
 $131 = HEAP32[$130>>2]|0;
 FUNCTION_TABLE_vi[$131 & 4095]($116);
 $132 = HEAP32[$128>>2]|0;
 $133 = (($132) + 8|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = (($this) + 2084|0);
 HEAP32[$135>>2] = $134;
 $136 = (($this) + 2104|0);
 $137 = (($this) + 2120|0);
 HEAP32[$137>>2] = 1;
 $138 = (($this) + 2116|0);
 HEAP32[$138>>2] = $126;
 $139 = HEAP32[$126>>2]|0;
 $140 = (($139) + 16|0);
 $141 = HEAP32[$140>>2]|0;
 FUNCTION_TABLE_vi[$141 & 4095]($126);
 $142 = HEAP32[$138>>2]|0;
 $143 = (($142) + 8|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = (($this) + 2112|0);
 HEAP32[$145>>2] = $144;
 $146 = HEAP32[$16>>2]|0;
 $147 = (($146) + 20|0);
 $148 = HEAP32[$147>>2]|0;
 FUNCTION_TABLE_vi[$148 & 4095]($16);
 $149 = HEAP32[$78>>2]|0;
 $150 = (($149) + 20|0);
 $151 = HEAP32[$150>>2]|0;
 FUNCTION_TABLE_vi[$151 & 4095]($78);
 $152 = HEAP32[$$0$i>>2]|0;
 $153 = (($152) + 20|0);
 $154 = HEAP32[$153>>2]|0;
 FUNCTION_TABLE_vi[$154 & 4095]($$0$i);
 $155 = HEAP32[$116>>2]|0;
 $156 = (($155) + 20|0);
 $157 = HEAP32[$156>>2]|0;
 FUNCTION_TABLE_vi[$157 & 4095]($116);
 $158 = HEAP32[$126>>2]|0;
 $159 = (($158) + 20|0);
 $160 = HEAP32[$159>>2]|0;
 FUNCTION_TABLE_vi[$160 & 4095]($126);
 $161 = HEAP32[$136>>2]|0;
 $162 = (($161) + 20|0);
 $163 = HEAP32[$162>>2]|0;
 FUNCTION_TABLE_vi[$163 & 4095]($136);
 $164 = HEAP32[$2>>2]|0;
 $165 = (($164) + 12|0);
 $166 = HEAP32[$165>>2]|0;
 FUNCTION_TABLE_viiii[$166 & 511]($2,65,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene11collideStepEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $$0$i = 0, $$0$i3 = 0, $$0$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$02$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1176|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,65,$6,$9);
 $13 = HEAP8[((545752 + 2|0))>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  $15 = HEAP32[$1>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = HEAP32[$15>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP16[545752>>1]|0;
   $21 = $3;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_viiiii[$19 & 255]($15,$20,$23,$26,99999789);
  }
 }
 $27 = (($this) + 1192|0);
 $28 = HEAP32[$27>>2]|0;
 __ZN5physx2Sc8SimStats8simStartEv($28);
 $29 = (($this) + 1212|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1000|0);
 $32 = HEAP32[$31>>2]|0;
 __ZN5physx10PxsContext11beginUpdateEv($32);
 $33 = (($this) + 132|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($this) + 128|0);
  $i$01$i = 0;
  while(1) {
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + ($i$01$i<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   __ZN5physx2Sc17ParticleSystemSim9startStepEv($39);
   $40 = (($i$01$i) + 1)|0;
   $41 = HEAP32[$33>>2]|0;
   $42 = ($40>>>0)<($41>>>0);
   if ($42) {
    $i$01$i = $40;
   } else {
    break;
   }
  }
 }
 $43 = (($this) + 1800|0);
 $44 = (($continuation) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($this) + 1808|0);
 HEAP32[$46>>2] = $45;
 $47 = HEAP32[$43>>2]|0;
 $48 = (($47) + 16|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vi[$49 & 4095]($43);
 $50 = (($this) + 1584|0);
 $51 = (($this) + 1600|0);
 HEAP32[$51>>2] = 1;
 $52 = (($this) + 1596|0);
 HEAP32[$52>>2] = $continuation;
 $53 = ($continuation|0)==(0|0);
 if (!($53)) {
  $54 = HEAP32[$continuation>>2]|0;
  $55 = (($54) + 16|0);
  $56 = HEAP32[$55>>2]|0;
  FUNCTION_TABLE_vi[$56 & 4095]($continuation);
  $57 = HEAP32[$52>>2]|0;
  $58 = (($57) + 8|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($this) + 1592|0);
  HEAP32[$60>>2] = $59;
 }
 $61 = (($this) + 2132|0);
 $62 = (($this) + 2148|0);
 HEAP32[$62>>2] = 1;
 $63 = (($this) + 2144|0);
 HEAP32[$63>>2] = $50;
 $64 = HEAP32[$50>>2]|0;
 $65 = (($64) + 16|0);
 $66 = HEAP32[$65>>2]|0;
 FUNCTION_TABLE_vi[$66 & 4095]($50);
 $67 = HEAP32[$63>>2]|0;
 $68 = (($67) + 8|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($this) + 2140|0);
 HEAP32[$70>>2] = $69;
 $71 = (($this) + 2160|0);
 $72 = (($this) + 2248|0);
 $73 = HEAP32[$72>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($73);
 $74 = (($this) + 2172|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($74)|0);
 $75 = HEAP32[$70>>2]|0;
 $76 = (($this) + 2168|0);
 HEAP32[$76>>2] = $75;
 HEAP32[$0>>2] = $61;
 $77 = (($this) + 2208|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = $78 & 2147483647;
 $80 = (($this) + 2204|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ($79>>>0)>($81>>>0);
 if ($82) {
  $84 = (($this) + 2200|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($85) + ($81<<2)|0);
  $87 = ($86|0)==(0|0);
  if (!($87)) {
   HEAP32[$86>>2] = $61;
  }
  $88 = (($81) + 1)|0;
  HEAP32[$80>>2] = $88;
 } else {
  $83 = (($this) + 2180|0);
  (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($83,$0)|0);
 }
 $89 = HEAP32[$61>>2]|0;
 $90 = (($89) + 16|0);
 $91 = HEAP32[$90>>2]|0;
 FUNCTION_TABLE_vi[$91 & 4095]($61);
 $92 = (($this) + 2244|0);
 HEAP8[$92>>0] = 1;
 $93 = HEAP32[$72>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($93);
 $94 = (($this) + 2256|0);
 $95 = (($this) + 2272|0);
 HEAP32[$95>>2] = 1;
 $96 = (($this) + 2268|0);
 HEAP32[$96>>2] = $71;
 $97 = HEAP32[$71>>2]|0;
 $98 = (($97) + 16|0);
 $99 = HEAP32[$98>>2]|0;
 FUNCTION_TABLE_vi[$99 & 4095]($71);
 $100 = HEAP32[$96>>2]|0;
 $101 = (($100) + 8|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = (($this) + 2264|0);
 HEAP32[$103>>2] = $102;
 $104 = (($this) + 1464|0);
 $105 = (($this) + 1552|0);
 $106 = HEAP32[$105>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($106);
 $107 = (($this) + 1476|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($107)|0);
 $108 = HEAP32[$103>>2]|0;
 $109 = (($this) + 1472|0);
 HEAP32[$109>>2] = $108;
 HEAP32[$0>>2] = $94;
 $110 = (($this) + 1512|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = $111 & 2147483647;
 $113 = (($this) + 1508|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = ($112>>>0)>($114>>>0);
 if ($115) {
  $117 = (($this) + 1504|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($118) + ($114<<2)|0);
  $120 = ($119|0)==(0|0);
  if (!($120)) {
   HEAP32[$119>>2] = $94;
  }
  $121 = (($114) + 1)|0;
  HEAP32[$113>>2] = $121;
 } else {
  $116 = (($this) + 1484|0);
  (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($116,$0)|0);
 }
 $122 = HEAP32[$94>>2]|0;
 $123 = (($122) + 16|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_vi[$124 & 4095]($94);
 $125 = (($this) + 1548|0);
 HEAP8[$125>>0] = 1;
 $126 = HEAP32[$105>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($126);
 $127 = HEAP32[$33>>2]|0;
 $128 = ($127|0)==(0);
 if (!($128)) {
  $129 = HEAP32[$43>>2]|0;
  $130 = (($129) + 16|0);
  $131 = HEAP32[$130>>2]|0;
  FUNCTION_TABLE_vi[$131 & 4095]($43);
  $132 = HEAP32[$33>>2]|0;
  $133 = ($132|0)==(0);
  if ($133) {
   $137 = HEAP32[$50>>2]|0;
   $138 = (($137) + 16|0);
   $139 = HEAP32[$138>>2]|0;
   FUNCTION_TABLE_vi[$139 & 4095]($50);
   $$0$i = $50;
  } else {
   $134 = (($this) + 128|0);
   $135 = HEAP32[$29>>2]|0;
   $136 = (__ZN5physx2Sc17ParticleSystemSim20scheduleCollisionCpuERNS0_16InteractionSceneERKNS_6shdfnd5ArrayIPS1_NS4_19ReflectionAllocatorIS6_EEEERNS_10PxBaseTaskE($135,$134,$50)|0);
   $$0$i = $136;
  }
  $140 = (__ZN5physx2Sc5Scene29scheduleParticleCollisionPrepERNS_10PxBaseTaskES3_($this,$$0$i,$43)|0);
  $141 = HEAP32[$33>>2]|0;
  $142 = ($141|0)==(0);
  if ($142) {
   $146 = HEAP32[$$0$i>>2]|0;
   $147 = (($146) + 16|0);
   $148 = HEAP32[$147>>2]|0;
   FUNCTION_TABLE_vi[$148 & 4095]($$0$i);
   $$0$i3 = $$0$i;
  } else {
   $143 = (($this) + 128|0);
   $144 = HEAP32[$29>>2]|0;
   $145 = (__ZN5physx2Sc17ParticleSystemSim19scheduleDynamicsCpuERNS0_16InteractionSceneERKNS_6shdfnd5ArrayIPS1_NS4_19ReflectionAllocatorIS6_EEEERNS_10PxBaseTaskE($144,$143,$$0$i)|0);
   $$0$i3 = $145;
  }
  $149 = (__ZN5physx2Sc5Scene31scheduleParticleShapeGenerationERNS_10PxBaseTaskES3_($this,$94,$$0$i3)|0);
  $150 = HEAP32[$72>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($150);
  (__ZN5physx6shdfnd15atomicIncrementEPVi($74)|0);
  $151 = (($140) + 8|0);
  $152 = HEAP32[$151>>2]|0;
  HEAP32[$76>>2] = $152;
  HEAP32[$0>>2] = $140;
  $153 = HEAP32[$77>>2]|0;
  $154 = $153 & 2147483647;
  $155 = HEAP32[$80>>2]|0;
  $156 = ($154>>>0)>($155>>>0);
  if ($156) {
   $158 = (($this) + 2200|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($159) + ($155<<2)|0);
   $161 = ($160|0)==(0|0);
   if (!($161)) {
    HEAP32[$160>>2] = $140;
   }
   $162 = (($155) + 1)|0;
   HEAP32[$80>>2] = $162;
  } else {
   $157 = (($this) + 2180|0);
   (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($157,$0)|0);
  }
  $163 = HEAP32[$140>>2]|0;
  $164 = (($163) + 16|0);
  $165 = HEAP32[$164>>2]|0;
  FUNCTION_TABLE_vi[$165 & 4095]($140);
  HEAP8[$92>>0] = 1;
  $166 = HEAP32[$72>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($166);
  $167 = HEAP32[$71>>2]|0;
  $168 = (($167) + 20|0);
  $169 = HEAP32[$168>>2]|0;
  FUNCTION_TABLE_vi[$169 & 4095]($71);
  $170 = HEAP32[$105>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($170);
  (__ZN5physx6shdfnd15atomicIncrementEPVi($107)|0);
  $171 = (($149) + 8|0);
  $172 = HEAP32[$171>>2]|0;
  HEAP32[$109>>2] = $172;
  HEAP32[$0>>2] = $149;
  $173 = HEAP32[$110>>2]|0;
  $174 = $173 & 2147483647;
  $175 = HEAP32[$113>>2]|0;
  $176 = ($174>>>0)>($175>>>0);
  if ($176) {
   $178 = (($this) + 1504|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = (($179) + ($175<<2)|0);
   $181 = ($180|0)==(0|0);
   if (!($181)) {
    HEAP32[$180>>2] = $149;
   }
   $182 = (($175) + 1)|0;
   HEAP32[$113>>2] = $182;
  } else {
   $177 = (($this) + 1484|0);
   (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($177,$0)|0);
  }
  $183 = HEAP32[$149>>2]|0;
  $184 = (($183) + 16|0);
  $185 = HEAP32[$184>>2]|0;
  FUNCTION_TABLE_vi[$185 & 4095]($149);
  HEAP8[$125>>0] = 1;
  $186 = HEAP32[$105>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($186);
  __ZN5physx2Cm10FanoutTask15removeReferenceEv($104);
  $187 = HEAP32[$43>>2]|0;
  $188 = (($187) + 20|0);
  $189 = HEAP32[$188>>2]|0;
  FUNCTION_TABLE_vi[$189 & 4095]($43);
  $190 = HEAP32[$$0$i>>2]|0;
  $191 = (($190) + 20|0);
  $192 = HEAP32[$191>>2]|0;
  FUNCTION_TABLE_vi[$192 & 4095]($$0$i);
  $193 = HEAP32[$140>>2]|0;
  $194 = (($193) + 20|0);
  $195 = HEAP32[$194>>2]|0;
  FUNCTION_TABLE_vi[$195 & 4095]($140);
  $196 = HEAP32[$$0$i3>>2]|0;
  $197 = (($196) + 20|0);
  $198 = HEAP32[$197>>2]|0;
  FUNCTION_TABLE_vi[$198 & 4095]($$0$i3);
  $199 = HEAP32[$149>>2]|0;
  $200 = (($199) + 20|0);
  $201 = HEAP32[$200>>2]|0;
  FUNCTION_TABLE_vi[$201 & 4095]($149);
 }
 __ZN5physx2Sc5Scene16scheduleClothGpuERNS_10PxBaseTaskE($this,$43);
 $202 = (($this) + 152|0);
 $203 = HEAP32[$202>>2]|0;
 $204 = ($203|0)==(0|0);
 L52: do {
  if ($204) {
   label = 44;
  } else {
   $205 = (($this) + 144|0);
   $206 = (($this) + 140|0);
   $i$02$i = 0;
   while(1) {
    $207 = HEAP32[$205>>2]|0;
    $208 = ($i$02$i>>>0)<($207>>>0);
    if (!($208)) {
     break;
    }
    $219 = HEAP32[$206>>2]|0;
    $220 = (($219) + ($i$02$i<<2)|0);
    $221 = HEAP32[$220>>2]|0;
    __ZNK5physx2Sc9ClothCore13getClothFlagsEv($0,$221);
    $222 = HEAP16[$0>>1]|0;
    $223 = $222 & 4;
    $224 = ($223<<16>>16)==(0);
    $225 = (($i$02$i) + 1)|0;
    if ($224) {
     $i$02$i = $225;
    } else {
     label = 44;
     break L52;
    }
   }
   $209 = HEAP32[$202>>2]|0;
   $210 = HEAP32[$209>>2]|0;
   $211 = (($210) + 16|0);
   $212 = HEAP32[$211>>2]|0;
   $213 = (($this) + 48|0);
   $214 = Math_fround(HEAPF32[$213>>2]);
   $215 = (FUNCTION_TABLE_iifi[$212 & 7]($209,$214,$43)|0);
   $216 = (($this) + 1572|0);
   HEAP32[$216>>2] = 1;
   $217 = (($this) + 1568|0);
   HEAP32[$217>>2] = $215;
   $218 = ($215|0)==(0|0);
   if (!($218)) {
    $226 = HEAP32[$215>>2]|0;
    $227 = (($226) + 16|0);
    $228 = HEAP32[$227>>2]|0;
    FUNCTION_TABLE_vi[$228 & 4095]($215);
    $229 = HEAP32[$217>>2]|0;
    $230 = (($229) + 8|0);
    $231 = HEAP32[$230>>2]|0;
    $232 = (($this) + 1564|0);
    HEAP32[$232>>2] = $231;
   }
   $233 = HEAP32[$215>>2]|0;
   $234 = (($233) + 20|0);
   $235 = HEAP32[$234>>2]|0;
   FUNCTION_TABLE_vi[$235 & 4095]($215);
   $236 = (($this) + 1556|0);
   $$0$i6 = $236;
  }
 } while(0);
 if ((label|0) == 44) {
  $237 = HEAP32[$43>>2]|0;
  $238 = (($237) + 16|0);
  $239 = HEAP32[$238>>2]|0;
  FUNCTION_TABLE_vi[$239 & 4095]($43);
  $$0$i6 = $43;
 }
 $240 = HEAP32[$105>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($240);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($107)|0);
 $241 = (($$0$i6) + 8|0);
 $242 = HEAP32[$241>>2]|0;
 HEAP32[$109>>2] = $242;
 HEAP32[$0>>2] = $$0$i6;
 $243 = HEAP32[$110>>2]|0;
 $244 = $243 & 2147483647;
 $245 = HEAP32[$113>>2]|0;
 $246 = ($244>>>0)>($245>>>0);
 if (!($246)) {
  $247 = (($this) + 1484|0);
  (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($247,$0)|0);
  $253 = HEAP32[$$0$i6>>2]|0;
  $254 = (($253) + 16|0);
  $255 = HEAP32[$254>>2]|0;
  FUNCTION_TABLE_vi[$255 & 4095]($$0$i6);
  HEAP8[$125>>0] = 1;
  $256 = HEAP32[$105>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($256);
  __ZN5physx2Cm10FanoutTask15removeReferenceEv($104);
  $257 = HEAP32[$$0$i6>>2]|0;
  $258 = (($257) + 20|0);
  $259 = HEAP32[$258>>2]|0;
  FUNCTION_TABLE_vi[$259 & 4095]($$0$i6);
  $260 = HEAP32[$50>>2]|0;
  $261 = (($260) + 20|0);
  $262 = HEAP32[$261>>2]|0;
  FUNCTION_TABLE_vi[$262 & 4095]($50);
  $263 = HEAP32[$61>>2]|0;
  $264 = (($263) + 20|0);
  $265 = HEAP32[$264>>2]|0;
  FUNCTION_TABLE_vi[$265 & 4095]($61);
  $266 = HEAP32[$71>>2]|0;
  $267 = (($266) + 20|0);
  $268 = HEAP32[$267>>2]|0;
  FUNCTION_TABLE_vi[$268 & 4095]($71);
  $269 = HEAP32[$94>>2]|0;
  $270 = (($269) + 20|0);
  $271 = HEAP32[$270>>2]|0;
  FUNCTION_TABLE_vi[$271 & 4095]($94);
  __ZN5physx2Cm10FanoutTask15removeReferenceEv($104);
  $272 = HEAP32[$2>>2]|0;
  $273 = (($272) + 12|0);
  $274 = HEAP32[$273>>2]|0;
  FUNCTION_TABLE_viiii[$274 & 511]($2,65,$6,$9);
  STACKTOP = sp;return;
 }
 $248 = (($this) + 1504|0);
 $249 = HEAP32[$248>>2]|0;
 $250 = (($249) + ($245<<2)|0);
 $251 = ($250|0)==(0|0);
 if (!($251)) {
  HEAP32[$250>>2] = $$0$i6;
 }
 $252 = (($245) + 1)|0;
 HEAP32[$113>>2] = $252;
 $253 = HEAP32[$$0$i6>>2]|0;
 $254 = (($253) + 16|0);
 $255 = HEAP32[$254>>2]|0;
 FUNCTION_TABLE_vi[$255 & 4095]($$0$i6);
 HEAP8[$125>>0] = 1;
 $256 = HEAP32[$105>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($256);
 __ZN5physx2Cm10FanoutTask15removeReferenceEv($104);
 $257 = HEAP32[$$0$i6>>2]|0;
 $258 = (($257) + 20|0);
 $259 = HEAP32[$258>>2]|0;
 FUNCTION_TABLE_vi[$259 & 4095]($$0$i6);
 $260 = HEAP32[$50>>2]|0;
 $261 = (($260) + 20|0);
 $262 = HEAP32[$261>>2]|0;
 FUNCTION_TABLE_vi[$262 & 4095]($50);
 $263 = HEAP32[$61>>2]|0;
 $264 = (($263) + 20|0);
 $265 = HEAP32[$264>>2]|0;
 FUNCTION_TABLE_vi[$265 & 4095]($61);
 $266 = HEAP32[$71>>2]|0;
 $267 = (($266) + 20|0);
 $268 = HEAP32[$267>>2]|0;
 FUNCTION_TABLE_vi[$268 & 4095]($71);
 $269 = HEAP32[$94>>2]|0;
 $270 = (($269) + 20|0);
 $271 = HEAP32[$270>>2]|0;
 FUNCTION_TABLE_vi[$271 & 4095]($94);
 __ZN5physx2Cm10FanoutTask15removeReferenceEv($104);
 $272 = HEAP32[$2>>2]|0;
 $273 = (($272) + 12|0);
 $274 = HEAP32[$273>>2]|0;
 FUNCTION_TABLE_viiii[$274 & 511]($2,65,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene16finishBroadPhaseEj($this,$ccdPass) {
 $this = $this|0;
 $ccdPass = $ccdPass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $destroyedOverlapCount$02 = 0, $p1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 49848|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 49836|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 1184|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 1176|0);
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$11>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_viiii[$21 & 511]($11,67,$15,$18);
 $22 = (($5) + 49832|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 1088|0);
 $25 = HEAP32[$24>>2]|0;
 __ZN5physx2Sc10NPhaseCore16onOverlapCreatedEPKNS_20PxvBroadPhaseOverlapEjj($25,$23,$9,$ccdPass);
 __ZN5physx14PxsAABBManager19freeCreatedOverlapsEv($5);
 $26 = HEAP32[$11>>2]|0;
 $27 = (($26) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_viiii[$28 & 511]($11,67,$15,$18);
 $29 = HEAP32[$10>>2]|0;
 $30 = $12;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$29>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_viiii[$38 & 511]($29,68,$32,$35);
 $39 = ($7|0)==(0);
 if ($39) {
  __ZN5physx14PxsAABBManager21freeDestroyedOverlapsEv($5);
  $49 = HEAP32[$29>>2]|0;
  $50 = (($49) + 12|0);
  $51 = HEAP32[$50>>2]|0;
  FUNCTION_TABLE_viiii[$51 & 511]($29,68,$32,$35);
  STACKTOP = sp;return;
 }
 $40 = (($5) + 49844|0);
 $41 = HEAP32[$40>>2]|0;
 $destroyedOverlapCount$02 = $7;$p1$01 = $41;
 while(1) {
  $42 = (($destroyedOverlapCount$02) + -1)|0;
  $43 = HEAP32[$p1$01>>2]|0;
  $44 = (($p1$01) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = HEAP32[$24>>2]|0;
  __ZN5physx2Sc10NPhaseCore16onOverlapRemovedEPNS0_7ElementES3_j($46,$43,$45,$ccdPass);
  $47 = (($p1$01) + 8|0);
  $48 = ($42|0)==(0);
  if ($48) {
   break;
  } else {
   $destroyedOverlapCount$02 = $42;$p1$01 = $47;
  }
 }
 __ZN5physx14PxsAABBManager21freeDestroyedOverlapsEv($5);
 $49 = HEAP32[$29>>2]|0;
 $50 = (($49) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 FUNCTION_TABLE_viiii[$51 & 511]($29,68,$32,$35);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene29processNarrowPhaseTouchEventsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $ccdTouchCount = 0, $i$03 = 0, $i2$02 = 0, $lostTouchCount = 0, $lostTouches = 0, $newTouchCount = 0, $newTouches = 0, $p$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $p$i = sp + 32|0;
 $newTouchCount = sp;
 $lostTouchCount = sp + 4|0;
 $ccdTouchCount = sp + 8|0;
 $newTouches = sp + 16|0;
 $0 = sp + 49|0;
 $lostTouches = sp + 24|0;
 $1 = sp + 48|0;
 $2 = (($this) + 1212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1000|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 1184|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 1176|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$7>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_viiii[$17 & 511]($7,75,$11,$14);
 HEAP32[$ccdTouchCount>>2] = 0;
 (__ZNK5physx10PxsContext25getManagerTouchEventCountEPiS1_S1_($5,$newTouchCount,$lostTouchCount,0)|0);
 $18 = HEAP32[$newTouchCount>>2]|0;
 $19 = $18 << 3;
 $20 = ($19>>>0)>(1024);
 $21 = (($newTouches) + 4|0);
 $22 = $20&1;
 HEAP8[$21>>0] = $22;
 if ($20) {
  $23 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$19,463960,1238)|0);
  HEAP32[$newTouches>>2] = $23;
  $87 = $23;
 } else {
  $24 = STACKTOP; STACKTOP = STACKTOP + ((((1*$19)|0)+15)&-16)|0;;
  HEAP32[$newTouches>>2] = $24;
  $87 = $24;
 }
 $25 = HEAP32[$lostTouchCount>>2]|0;
 $26 = $25 << 3;
 $27 = ($26>>>0)>(1024);
 $28 = (($lostTouches) + 4|0);
 $29 = $27&1;
 HEAP8[$28>>0] = $29;
 if ($27) {
  $30 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,$26,463960,1239)|0);
  HEAP32[$lostTouches>>2] = $30;
  $$pre = HEAP32[$newTouches>>2]|0;
  $$pre$phiZ2D = $newTouches;$32 = $$pre;$33 = $30;
 } else {
  $31 = STACKTOP; STACKTOP = STACKTOP + ((((1*$26)|0)+15)&-16)|0;;
  HEAP32[$lostTouches>>2] = $31;
  $$pre$phiZ2D = $newTouches;$32 = $87;$33 = $31;
 }
 (__ZN5physx10PxsContext22fillManagerTouchEventsEPNS_27PxvContactManagerTouchEventERiS2_S3_S2_S3_($5,$32,$newTouchCount,$33,$lostTouchCount,0,$ccdTouchCount)|0);
 $34 = HEAP32[$newTouchCount>>2]|0;
 $35 = ($34|0)>(0);
 if ($35) {
  $i$03 = 0;
  while(1) {
   $44 = HEAP32[$$pre$phiZ2D>>2]|0;
   $45 = ((($44) + ($i$03<<3)|0) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   __ZN5physx2Sc19ShapeInstancePairLL15managerNewTouchEjb($46,0,1);
   $47 = (($i$03) + 1)|0;
   $48 = HEAP32[$newTouchCount>>2]|0;
   $49 = ($47|0)<($48|0);
   if ($49) {
    $i$03 = $47;
   } else {
    break;
   }
  }
 }
 $36 = HEAP32[$lostTouchCount>>2]|0;
 $37 = ($36|0)>(0);
 if ($37) {
  $38 = (($p$i) + 4|0);
  $39 = (($p$i) + 8|0);
  $40 = (($p$i) + 12|0);
  $41 = (($this) + 1248|0);
  $42 = (($this) + 1256|0);
  $43 = (($this) + 1252|0);
  $i2$02 = 0;
  while(1) {
   $50 = HEAP32[$lostTouches>>2]|0;
   $51 = ((($50) + ($i2$02<<3)|0) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (__ZN5physx2Sc19ShapeInstancePairLL16managerLostTouchEjb($52,0,1)|0);
   do {
    if ($53) {
     $54 = (($52) + 32|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($55)|0);
     $57 = (($52) + 36|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($58)|0);
     HEAP32[$p$i>>2] = $56;
     HEAP32[$38>>2] = $59;
     $60 = (($56) + 56|0);
     $61 = HEAP32[$60>>2]|0;
     HEAP32[$39>>2] = $61;
     $62 = (($59) + 56|0);
     $63 = HEAP32[$62>>2]|0;
     HEAP32[$40>>2] = $63;
     $64 = HEAP32[$42>>2]|0;
     $65 = $64 & 2147483647;
     $66 = HEAP32[$43>>2]|0;
     $67 = ($65>>>0)>($66>>>0);
     if (!($67)) {
      (__ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($41,$p$i)|0);
      break;
     }
     $68 = HEAP32[$41>>2]|0;
     $69 = (($68) + ($66<<4)|0);
     $70 = ($69|0)==(0|0);
     if ($70) {
      $72 = $66;
     } else {
      ;HEAP32[$69+0>>2]=HEAP32[$p$i+0>>2]|0;HEAP32[$69+4>>2]=HEAP32[$p$i+4>>2]|0;HEAP32[$69+8>>2]=HEAP32[$p$i+8>>2]|0;HEAP32[$69+12>>2]=HEAP32[$p$i+12>>2]|0;
      $$pre$i$i = HEAP32[$43>>2]|0;
      $72 = $$pre$i$i;
     }
     $71 = (($72) + 1)|0;
     HEAP32[$43>>2] = $71;
    }
   } while(0);
   $73 = (($i2$02) + 1)|0;
   $74 = HEAP32[$lostTouchCount>>2]|0;
   $75 = ($73|0)<($74|0);
   if ($75) {
    $i2$02 = $73;
   } else {
    break;
   }
  }
 }
 $76 = (($this) + 1088|0);
 $77 = HEAP32[$76>>2]|0;
 __ZN5physx2Sc10NPhaseCore30processPersistentContactEventsEv($77);
 $78 = HEAP8[$28>>0]|0;
 $79 = ($78<<24>>24)==(0);
 if (!($79)) {
  $80 = HEAP32[$lostTouches>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($lostTouches,$80);
 }
 $81 = HEAP8[$21>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  $84 = HEAP32[$7>>2]|0;
  $85 = (($84) + 12|0);
  $86 = HEAP32[$85>>2]|0;
  FUNCTION_TABLE_viiii[$86 & 511]($7,75,$11,$14);
  STACKTOP = sp;return;
 }
 $83 = HEAP32[$$pre$phiZ2D>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($newTouches,$83);
 $84 = HEAP32[$7>>2]|0;
 $85 = (($84) + 12|0);
 $86 = HEAP32[$85>>2]|0;
 FUNCTION_TABLE_viiii[$86 & 511]($7,75,$11,$14);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene18addToLostTouchListEPNS0_7BodySimES3_($this,$body1,$body2) {
 $this = $this|0;
 $body1 = $body1|0;
 $body2 = $body2|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $p = sp;
 HEAP32[$p>>2] = $body1;
 $0 = (($p) + 4|0);
 HEAP32[$0>>2] = $body2;
 $1 = (($p) + 8|0);
 $2 = (($body1) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$1>>2] = $3;
 $4 = (($p) + 12|0);
 $5 = (($body2) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$4>>2] = $6;
 $7 = (($this) + 1248|0);
 $8 = (($this) + 1256|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = (($this) + 1252|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if (!($13)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($7,$p)|0);
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$7>>2]|0;
 $15 = (($14) + ($12<<4)|0);
 $16 = ($15|0)==(0|0);
 if ($16) {
  $18 = $12;
 } else {
  ;HEAP32[$15+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$p+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$p+12>>2]|0;
  $$pre$i = HEAP32[$11>>2]|0;
  $18 = $$pre$i;
 }
 $17 = (($18) + 1)|0;
 HEAP32[$11>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene13postIslandGenEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$pre = 0, $$sum$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i6 = 0, $i$01$i = 0, $i$01$i1 = 0, $phitmp$i = 0, $phitmp$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 1212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($2)|0);
 $4 = (($3) + 296|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) - ($7))|0;
 $9 = (($3) + 284|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($7|0)==(0);
 if ($11) {
  $25 = $10;
 } else {
  $i$01$i = 0;
  while(1) {
   $$sum$i = (($8) + ($i$01$i))|0;
   $12 = (($10) + ($$sum$i<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13;
   $15 = $14 & 15;
   $16 = ($15|0)==(0);
   if ($16) {
    $18 = ($13|0)==(0|0);
    if ($18) {
     $19 = 0;
     label = 6;
    } else {
     __ZN5physx2Sc5Actor9setActiveEbj($13,0,2);
    }
   } else {
    $17 = $14 & -2;
    $phitmp$i = $17;
    $19 = $phitmp$i;
    label = 6;
   }
   if ((label|0) == 6) {
    label = 0;
    __ZN5physx2Sc15ArticulationSim9setActiveEbj($19,0,2);
   }
   $20 = (($i$01$i) + 1)|0;
   $exitcond$i = ($20|0)==($7|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $20;
   }
  }
  $$pre = HEAP32[$9>>2]|0;
  $25 = $$pre;
 }
 $21 = (($3) + 288|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if (!($23)) {
  $i$01$i1 = 0;
  while(1) {
   $24 = (($25) + ($i$01$i1<<2)|0);
   $26 = HEAP32[$24>>2]|0;
   $27 = $26;
   $28 = $27 & 15;
   $29 = ($28|0)==(0);
   if ($29) {
    $31 = ($26|0)==(0|0);
    if ($31) {
     $32 = 0;
     label = 14;
    } else {
     __ZN5physx2Sc5Actor9setActiveEbj($26,1,2);
    }
   } else {
    $30 = $27 & -2;
    $phitmp$i3 = $30;
    $32 = $phitmp$i3;
    label = 14;
   }
   if ((label|0) == 14) {
    label = 0;
    __ZN5physx2Sc15ArticulationSim9setActiveEbj($32,1,2);
   }
   $33 = (($i$01$i1) + 1)|0;
   $exitcond$i6 = ($33|0)==($22|0);
   if ($exitcond$i6) {
    break;
   } else {
    $i$01$i1 = $33;
   }
  }
 }
 $34 = (($this) + 1184|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 1176|0);
 $37 = $36;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) + 4)|0;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$35>>2]|0;
 $44 = (($43) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_viiii[$45 & 511]($35,70,$39,$42);
 $46 = (($this) + 1088|0);
 $47 = HEAP32[$46>>2]|0;
 __ZN5physx2Sc10NPhaseCore11narrowPhaseEv($47);
 $48 = HEAP32[$35>>2]|0;
 $49 = (($48) + 12|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_viiii[$50 & 511]($35,70,$39,$42);
 __ZN5physx16PxsIslandManager27setWokenPairContactManagersEv($3);
 $51 = (($3) + 304|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0);
 if ($53) {
  STACKTOP = sp;return;
 }
 $54 = (($3) + 300|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($this) + 2020|0);
 $57 = (($this) + 1992|0);
 $58 = (($this) + 2036|0);
 HEAP32[$58>>2] = 1;
 $59 = (($this) + 2032|0);
 HEAP32[$59>>2] = $57;
 $60 = HEAP32[$57>>2]|0;
 $61 = (($60) + 16|0);
 $62 = HEAP32[$61>>2]|0;
 FUNCTION_TABLE_vi[$62 & 4095]($57);
 $63 = HEAP32[$59>>2]|0;
 $64 = (($63) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($this) + 2028|0);
 HEAP32[$66>>2] = $65;
 $67 = (($this) + 2048|0);
 $68 = (($this) + 2064|0);
 HEAP32[$68>>2] = 1;
 $69 = (($this) + 2060|0);
 HEAP32[$69>>2] = $56;
 $70 = HEAP32[$56>>2]|0;
 $71 = (($70) + 16|0);
 $72 = HEAP32[$71>>2]|0;
 FUNCTION_TABLE_vi[$72 & 4095]($56);
 $73 = HEAP32[$69>>2]|0;
 $74 = (($73) + 8|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($this) + 2056|0);
 HEAP32[$76>>2] = $75;
 $77 = HEAP32[$1>>2]|0;
 $78 = (($77) + 1000|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($this) + 48|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 __ZN5physx10PxsContext30secondPassUpdateContactManagerEfPNS_25NarrowPhaseContactManagerEjPNS_10PxBaseTaskE($79,$81,$55,$52,$67);
 $82 = HEAP32[$56>>2]|0;
 $83 = (($82) + 20|0);
 $84 = HEAP32[$83>>2]|0;
 FUNCTION_TABLE_vi[$84 & 4095]($56);
 $85 = HEAP32[$67>>2]|0;
 $86 = (($85) + 20|0);
 $87 = HEAP32[$86>>2]|0;
 FUNCTION_TABLE_vi[$87 & 4095]($67);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19islandGenSecondPassEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $ccdTouchCount = 0, $i$03 = 0, $i2$02 = 0;
 var $lostTouchCount = 0, $lostTouches = 0, $newTouchCount = 0, $newTouches = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $newTouchCount = sp + 24|0;
 $lostTouchCount = sp;
 $ccdTouchCount = sp + 4|0;
 $newTouches = sp + 8|0;
 $0 = sp + 29|0;
 $lostTouches = sp + 16|0;
 $1 = sp + 28|0;
 $2 = (($this) + 1212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($3)|0);
 $5 = (($this) + 1184|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 1176|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$6>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_viiii[$16 & 511]($6,77,$10,$13);
 HEAP32[$ccdTouchCount>>2] = 0;
 $17 = HEAP32[$2>>2]|0;
 $18 = (($17) + 1000|0);
 $19 = HEAP32[$18>>2]|0;
 (__ZNK5physx10PxsContext25getManagerTouchEventCountEPiS1_S1_($19,$newTouchCount,$lostTouchCount,0)|0);
 $20 = HEAP32[$newTouchCount>>2]|0;
 $21 = $20 << 3;
 $22 = ($21>>>0)>(1024);
 $23 = (($newTouches) + 4|0);
 $24 = $22&1;
 HEAP8[$23>>0] = $24;
 if ($22) {
  $25 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$21,463960,1393)|0);
  HEAP32[$newTouches>>2] = $25;
  $74 = $25;
 } else {
  $26 = STACKTOP; STACKTOP = STACKTOP + ((((1*$21)|0)+15)&-16)|0;;
  HEAP32[$newTouches>>2] = $26;
  $74 = $26;
 }
 $27 = HEAP32[$lostTouchCount>>2]|0;
 $28 = $27 << 3;
 $29 = ($28>>>0)>(1024);
 $30 = (($lostTouches) + 4|0);
 $31 = $29&1;
 HEAP8[$30>>0] = $31;
 if ($29) {
  $32 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,$28,463960,1394)|0);
  HEAP32[$lostTouches>>2] = $32;
  $$pre = HEAP32[$newTouches>>2]|0;
  $$pre$phiZ2D = $newTouches;$34 = $$pre;$35 = $32;
 } else {
  $33 = STACKTOP; STACKTOP = STACKTOP + ((((1*$28)|0)+15)&-16)|0;;
  HEAP32[$lostTouches>>2] = $33;
  $$pre$phiZ2D = $newTouches;$34 = $74;$35 = $33;
 }
 (__ZN5physx10PxsContext22fillManagerTouchEventsEPNS_27PxvContactManagerTouchEventERiS2_S3_S2_S3_($19,$34,$newTouchCount,$35,$lostTouchCount,0,$ccdTouchCount)|0);
 $36 = HEAP32[$newTouchCount>>2]|0;
 $37 = ($36|0)>(0);
 if ($37) {
  $i$03 = 0;
  while(1) {
   $40 = HEAP32[$$pre$phiZ2D>>2]|0;
   $41 = ((($40) + ($i$03<<3)|0) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   __ZN5physx2Sc19ShapeInstancePairLL25postNarrowPhaseSecondPassERNS_16PxsIslandManagerEb($42,$4,1);
   $43 = (($i$03) + 1)|0;
   $44 = HEAP32[$newTouchCount>>2]|0;
   $45 = ($43|0)<($44|0);
   if ($45) {
    $i$03 = $43;
   } else {
    break;
   }
  }
 }
 $38 = HEAP32[$lostTouchCount>>2]|0;
 $39 = ($38|0)>(0);
 if ($39) {
  $i2$02 = 0;
  while(1) {
   $46 = HEAP32[$lostTouches>>2]|0;
   $47 = ((($46) + ($i2$02<<3)|0) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   __ZN5physx2Sc19ShapeInstancePairLL25postNarrowPhaseSecondPassERNS_16PxsIslandManagerEb($48,$4,0);
   $49 = (($i2$02) + 1)|0;
   $50 = HEAP32[$lostTouchCount>>2]|0;
   $51 = ($49|0)<($50|0);
   if ($51) {
    $i2$02 = $49;
   } else {
    break;
   }
  }
 }
 $52 = HEAP8[$30>>0]|0;
 $53 = ($52<<24>>24)==(0);
 if (!($53)) {
  $54 = HEAP32[$lostTouches>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($lostTouches,$54);
 }
 $55 = HEAP8[$23>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  $58 = HEAP32[$6>>2]|0;
  $59 = (($58) + 12|0);
  $60 = HEAP32[$59>>2]|0;
  FUNCTION_TABLE_viiii[$60 & 511]($6,77,$10,$13);
  $61 = HEAP32[$5>>2]|0;
  $62 = $7;
  $63 = $62;
  $64 = HEAP32[$63>>2]|0;
  $65 = (($62) + 4)|0;
  $66 = $65;
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$61>>2]|0;
  $69 = (($68) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  FUNCTION_TABLE_viiii[$70 & 511]($61,78,$64,$67);
  __ZN5physx16PxsIslandManager23updateIslandsSecondPassEPNS_10PxBaseTaskEj($4,$continuation,0);
  $71 = HEAP32[$61>>2]|0;
  $72 = (($71) + 12|0);
  $73 = HEAP32[$72>>2]|0;
  FUNCTION_TABLE_viiii[$73 & 511]($61,78,$64,$67);
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$$pre$phiZ2D>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($newTouches,$57);
 $58 = HEAP32[$6>>2]|0;
 $59 = (($58) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 FUNCTION_TABLE_viiii[$60 & 511]($6,77,$10,$13);
 $61 = HEAP32[$5>>2]|0;
 $62 = $7;
 $63 = $62;
 $64 = HEAP32[$63>>2]|0;
 $65 = (($62) + 4)|0;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$61>>2]|0;
 $69 = (($68) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_viiii[$70 & 511]($61,78,$64,$67);
 __ZN5physx16PxsIslandManager23updateIslandsSecondPassEPNS_10PxBaseTaskEj($4,$continuation,0);
 $71 = HEAP32[$61>>2]|0;
 $72 = (($71) + 12|0);
 $73 = HEAP32[$72>>2]|0;
 FUNCTION_TABLE_viiii[$73 & 511]($61,78,$64,$67);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene23postIslandGenSecondPassEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$sum$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond$i = 0, $i$01 = 0, $i$01$i = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 1212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($2)|0);
 $4 = (($this) + 1184|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 1176|0);
 $7 = $6;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$5>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_viiii[$15 & 511]($5,79,$9,$12);
 $16 = (($3) + 296|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($3) + 292|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) - ($19))|0;
 $21 = (($3) + 284|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($19|0)==(0);
 if (!($23)) {
  $i$01$i = 0;
  while(1) {
   $$sum$i = (($20) + ($i$01$i))|0;
   $24 = (($22) + ($$sum$i<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25;
   $27 = $26 & 15;
   $28 = ($27|0)==(0);
   if ($28) {
    $30 = ($25|0)==(0|0);
    if ($30) {
     $31 = 0;
     label = 6;
    } else {
     __ZN5physx2Sc5Actor9setActiveEbj($25,0,4);
    }
   } else {
    $29 = $26 & -2;
    $phitmp$i = $29;
    $31 = $phitmp$i;
    label = 6;
   }
   if ((label|0) == 6) {
    label = 0;
    __ZN5physx2Sc15ArticulationSim9setActiveEbj($31,0,4);
   }
   $32 = (($i$01$i) + 1)|0;
   $exitcond$i = ($32|0)==($19|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $32;
   }
  }
 }
 __ZN5physx16PxsIslandManager33removeSleepingPairContactManagersEv($3);
 $33 = (($3) + 300|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($3) + 304|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  $43 = HEAP32[$5>>2]|0;
  $44 = (($43) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_viiii[$45 & 511]($5,79,$9,$12);
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $38 = (($34) + ($i$01<<3)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  __ZN5physx2Sc19ShapeInstancePairLL23postIslandGenSecondPassEv($41);
  $42 = (($i$01) + 1)|0;
  $exitcond = ($42|0)==($36|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $42;
  }
 }
 $43 = HEAP32[$5>>2]|0;
 $44 = (($43) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_viiii[$45 & 511]($5,79,$9,$12);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene6solverEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $7 = 0, $8 = 0, $9 = 0, $actorPrefetch$01$i = 0, $actorPrefetch$1$i = 0, $cp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext28runModifiableContactManagersEv($3);
 $4 = HEAP32[$0>>2]|0;
 $5 = (($4) + 1000|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx10PxsContext11swapStreamsEv($6);
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($7) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + ($10<<2)|0);
 $12 = ($10|0)>(0);
 if (!($12)) {
  __ZN5physx2Sc5Scene12beforeSolverEv($this);
  $63 = HEAP32[$0>>2]|0;
  $64 = (($63) + 1000|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($this) + 48|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = (($this) + 1120|0);
  __ZN5physx10PxsContext14updateDynamicsEfPNS_10PxBaseTaskERNS_18PxsMaterialManagerE($65,$67,$continuation,$68);
  STACKTOP = sp;return;
 }
 $13 = (($8) + 32|0);
 $$sum$i = (($10) + -1)|0;
 $14 = (($8) + ($$sum$i<<2)|0);
 $38 = $8;$actorPrefetch$01$i = $13;
 while(1) {
  $15 = ($actorPrefetch$01$i>>>0)>($14>>>0);
  if ($15) {
   $actorPrefetch$1$i = $actorPrefetch$01$i;
  } else {
   $16 = HEAP32[$actorPrefetch$01$i>>2]|0;
   $17 = $16;
   $18 = (_bitshift64Lshr(($17|0),0,6)|0);
   $19 = tempRet0;
   $20 = (_i64Add(($17|0),0,511,0)|0);
   $21 = tempRet0;
   $22 = (_bitshift64Lshr(($20|0),($21|0),6)|0);
   $23 = tempRet0;
   $24 = (_i64Subtract(1,0,($18|0),($19|0))|0);
   $25 = tempRet0;
   $26 = (_i64Add(($24|0),($25|0),($22|0),($23|0))|0);
   $27 = tempRet0;
   $29 = $26;$30 = $27;$cp$0$i$i = $16;
   while(1) {
    $28 = (($cp$0$i$i) + 64|0);
    $31 = (_i64Add(($29|0),($30|0),-1,-1)|0);
    $32 = tempRet0;
    $33 = ($31|0)==(0);
    $34 = ($32|0)==(0);
    $35 = $33 & $34;
    if ($35) {
     break;
    } else {
     $29 = $31;$30 = $32;$cp$0$i$i = $28;
    }
   }
   $36 = (($actorPrefetch$01$i) + 4|0);
   $actorPrefetch$1$i = $36;
  }
  $37 = HEAP32[$38>>2]|0;
  $39 = (($37) + 128|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($37) + 96|0);
  HEAPF32[$42>>2] = $41;
  $43 = (($40) + 4|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($37) + 100|0);
  HEAPF32[$45>>2] = $44;
  $46 = (($40) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = (($37) + 104|0);
  HEAPF32[$48>>2] = $47;
  $49 = (($40) + 12|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = (($37) + 108|0);
  HEAPF32[$51>>2] = $50;
  $52 = (($40) + 16|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($37) + 112|0);
  HEAPF32[$54>>2] = $53;
  $55 = (($40) + 20|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($37) + 116|0);
  HEAPF32[$57>>2] = $56;
  $58 = (($40) + 24|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($37) + 120|0);
  HEAPF32[$60>>2] = $59;
  $61 = (($38) + 4|0);
  $62 = ($61>>>0)<($11>>>0);
  if ($62) {
   $38 = $61;$actorPrefetch$01$i = $actorPrefetch$1$i;
  } else {
   break;
  }
 }
 __ZN5physx2Sc5Scene12beforeSolverEv($this);
 $63 = HEAP32[$0>>2]|0;
 $64 = (($63) + 1000|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($this) + 48|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($this) + 1120|0);
 __ZN5physx10PxsContext14updateDynamicsEfPNS_10PxBaseTaskERNS_18PxsMaterialManagerE($65,$67,$continuation,$68);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene12beforeSolverEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $exitcond = 0, $exitcond10 = 0, $exitcond9 = 0, $i$05 = 0, $j$01 = 0, $j3$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1184|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1176|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiii[$11 & 511]($1,80,$5,$8);
 $12 = (($this) + 1212|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 1000|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 6576|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 6584|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($15) + 6560|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($15) + 6564|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 44|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)!=(0);
 $27 = ($17|0)==(0|0);
 if (!($27)) {
  $28 = HEAP32[$17>>2]|0;
  $29 = HEAP32[$17>>2]|0;
  $30 = (($29) + 128|0);
 }
 $31 = (($this) + 1200|0);
 $32 = HEAP16[$31>>1]|0;
 $33 = $32 & 16;
 $34 = ($33<<16>>16)!=(0);
 $35 = (($this) + 32|0);
 $36 = ($23|0)==(0);
 if ($36) {
  HEAP32[$24>>2] = 0;
  $78 = HEAP32[$1>>2]|0;
  $79 = (($78) + 12|0);
  $80 = HEAP32[$79>>2]|0;
  FUNCTION_TABLE_viiii[$80 & 511]($1,80,$5,$8);
  STACKTOP = sp;return;
 }
 $37 = (($this) + 48|0);
 $38 = (($this) + 52|0);
 $i$05 = 0;
 while(1) {
  $40 = ((($21) + ($i$05<<4)|0) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)<(0);
  $43 = (($21) + ($i$05<<4)|0);
  $44 = HEAP32[$43>>2]|0;
  $39 = (($i$05) + 1)|0;
  $45 = (($21) + ($39<<4)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($44>>>0)<($46>>>0);
  if ($47) {
   $48 = (($46) + -1)|0;
   $j$01 = $44;
   while(1) {
    $49 = ($j$01>>>0)<($48>>>0);
    $50 = (($j$01) + 1)|0;
    if ($49) {
     $51 = (($17) + ($50<<2)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = HEAP32[$51>>2]|0;
     $54 = (($53) + 128|0);
    }
    $55 = (($17) + ($j$01<<2)|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($56) + -64|0);
    $58 = Math_fround(HEAPF32[$37>>2]);
    $59 = Math_fround(HEAPF32[$38>>2]);
    __ZN5physx2Sc7BodySim12updateForcesEffbRKNS_6PxVec3Ebb($57,$58,$59,$26,$35,$42,$34);
    $exitcond = ($50|0)==($46|0);
    if ($exitcond) {
     break;
    } else {
     $j$01 = $50;
    }
   }
   $$pre = HEAP32[$40>>2]|0;
   $61 = $$pre;
  } else {
   $61 = $41;
  }
  $60 = $61 & 2147483647;
  $62 = ((($21) + ($39<<4)|0) + 4|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = $63 & 2147483647;
  $65 = ($60>>>0)<($64>>>0);
  if ($65) {
   $66 = (($64) + -1)|0;
   $67 = $63 & 2147483647;
   $j3$02 = $60;
   while(1) {
    $68 = ($j3$02>>>0)<($66>>>0);
    $69 = (($j3$02) + 1)|0;
    if ($68) {
     $70 = (($19) + ($69<<2)|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = HEAP32[$70>>2]|0;
     $73 = (($72) + 128|0);
    }
    $74 = (($19) + ($j3$02<<2)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = Math_fround(HEAPF32[$37>>2]);
    $77 = Math_fround(HEAPF32[$38>>2]);
    __ZN5physx2Sc15ArticulationSim12updateForcesEffbRKNS_6PxVec3Ebb($75,$76,$77,$26,$35,$42,$34);
    $exitcond9 = ($69|0)==($67|0);
    if ($exitcond9) {
     break;
    } else {
     $j3$02 = $69;
    }
   }
  }
  $exitcond10 = ($39|0)==($23|0);
  if ($exitcond10) {
   break;
  } else {
   $i$05 = $39;
  }
 }
 HEAP32[$24>>2] = 0;
 $78 = HEAP32[$1>>2]|0;
 $79 = (($78) + 12|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_viiii[$80 & 511]($1,80,$5,$8);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene18updateCCDMultiPassEPNS_10PxBaseTaskE($this,$parentContinuation) {
 $this = $this|0;
 $parentContinuation = $parentContinuation|0;
 var $$01$i$i = 0, $$01$i$i1 = 0, $$01$i$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $j$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 56|0;
 $1 = sp;
 $2 = sp + 28|0;
 $3 = (($this) + 1200|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 4;
 $6 = ($5<<16>>16)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 2372|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  __ZN5physx2Sc5Scene36collectPostSolverVelocitiesBeforeCCDEv($this);
 }
 $10 = (($this) + 1948|0);
 $11 = (($this) + 1952|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(2);
 if (!($13)) {
  $14 = HEAP32[$10>>2]|0;
  $15 = (($14) + (($12*28)|0)|0);
  $16 = ($12|0)>(0);
  if ($16) {
   $$01$i$i = $14;
   while(1) {
    $17 = HEAP32[$$01$i$i>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    FUNCTION_TABLE_vi[$18 & 4095]($$01$i$i);
    $19 = (($$01$i$i) + 28|0);
    $20 = ($19>>>0)<($15>>>0);
    if ($20) {
     $$01$i$i = $19;
    } else {
     break;
    }
   }
  }
  HEAP32[$11>>2] = 0;
  $21 = (($this) + 1924|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($this) + 1928|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($22) + (($24*28)|0)|0);
  $26 = ($24|0)>(0);
  if ($26) {
   $$01$i$i1 = $22;
   while(1) {
    $27 = HEAP32[$$01$i$i1>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    FUNCTION_TABLE_vi[$28 & 4095]($$01$i$i1);
    $29 = (($$01$i$i1) + 28|0);
    $30 = ($29>>>0)<($25>>>0);
    if ($30) {
     $$01$i$i1 = $29;
    } else {
     break;
    }
   }
  }
  HEAP32[$23>>2] = 0;
  $31 = (($this) + 1936|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($this) + 1940|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + (($34*28)|0)|0);
  $36 = ($34|0)>(0);
  if ($36) {
   $$01$i$i3 = $32;
   while(1) {
    $37 = HEAP32[$$01$i$i3>>2]|0;
    $38 = HEAP32[$37>>2]|0;
    FUNCTION_TABLE_vi[$38 & 4095]($$01$i$i3);
    $39 = (($$01$i$i3) + 28|0);
    $40 = ($39>>>0)<($35>>>0);
    if ($40) {
     $$01$i$i3 = $39;
    } else {
     break;
    }
   }
  }
  HEAP32[$33>>2] = 0;
  $41 = (($this) + 1956|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 & 2147483646;
  $44 = ($43>>>0)<(2);
  if ($44) {
   __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_11postCCDPassEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE8recreateEj($10,2);
  }
  $45 = (($this) + 1932|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46 & 2147483646;
  $48 = ($47>>>0)<(2);
  if ($48) {
   __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_19updateCCDSinglePassEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE8recreateEj($21,2);
  }
  $49 = (($this) + 1944|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 2147483646;
  $52 = ($51>>>0)<(2);
  if ($52) {
   __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_13ccdBroadPhaseEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE8recreateEj($31,2);
  }
  $53 = (($0) + 4|0);
  $54 = (($0) + 6|0);
  $55 = (($0) + 8|0);
  $56 = (($0) + 12|0);
  $57 = (($0) + 16|0);
  $58 = (($0) + 20|0);
  $59 = (($0) + 24|0);
  $60 = (($1) + 4|0);
  $61 = (($1) + 6|0);
  $62 = (($1) + 8|0);
  $63 = (($1) + 12|0);
  $64 = (($1) + 16|0);
  $65 = (($1) + 20|0);
  $66 = (($1) + 24|0);
  $67 = (($2) + 4|0);
  $68 = (($2) + 6|0);
  $69 = (($2) + 8|0);
  $70 = (($2) + 12|0);
  $71 = (($2) + 16|0);
  $72 = (($2) + 20|0);
  $73 = (($2) + 24|0);
  $j$07 = 0;
  while(1) {
   HEAP16[$53>>1] = -1;
   HEAP16[$54>>1] = 0;
   HEAP32[$55>>2] = 0;
   HEAP32[$0>>2] = ((434896 + 8|0));
   HEAP32[$56>>2] = 0;
   HEAP32[$57>>2] = 0;
   HEAP32[$0>>2] = ((466360 + 8|0));
   HEAP32[$58>>2] = $this;
   HEAP32[$59>>2] = 464144;
   $74 = HEAP32[$41>>2]|0;
   $75 = $74 & 2147483647;
   $76 = HEAP32[$11>>2]|0;
   $77 = ($75>>>0)>($76>>>0);
   if ($77) {
    $78 = HEAP32[$10>>2]|0;
    $79 = (($78) + (($76*28)|0)|0);
    $80 = ((($78) + (($76*28)|0)|0) + 4|0);
    $81 = $53;
    $82 = $81;
    $83 = HEAP32[$82>>2]|0;
    $84 = (($81) + 4)|0;
    $85 = $84;
    $86 = HEAP32[$85>>2]|0;
    $87 = $80;
    $88 = $87;
    HEAP16[$88>>1]=$83&65535;HEAP16[$88+2>>1]=$83>>>16;
    $89 = (($87) + 4)|0;
    $90 = $89;
    HEAP16[$90>>1]=$86&65535;HEAP16[$90+2>>1]=$86>>>16;
    HEAP32[$79>>2] = ((434896 + 8|0));
    $91 = ((($78) + (($76*28)|0)|0) + 12|0);
    $92 = HEAP32[$56>>2]|0;
    HEAP32[$91>>2] = $92;
    $93 = ((($78) + (($76*28)|0)|0) + 16|0);
    $94 = HEAP32[$57>>2]|0;
    HEAP32[$93>>2] = $94;
    $95 = HEAP32[$56>>2]|0;
    HEAP32[$91>>2] = $95;
    HEAP32[$79>>2] = ((466360 + 8|0));
    $96 = ((($78) + (($76*28)|0)|0) + 20|0);
    $97 = $58;
    $98 = $97;
    $99 = HEAP32[$98>>2]|0;
    $100 = (($97) + 4)|0;
    $101 = $100;
    $102 = HEAP32[$101>>2]|0;
    $103 = $96;
    $104 = $103;
    HEAP32[$104>>2] = $99;
    $105 = (($103) + 4)|0;
    $106 = $105;
    HEAP32[$106>>2] = $102;
    $107 = HEAP32[$11>>2]|0;
    $108 = (($107) + 1)|0;
    HEAP32[$11>>2] = $108;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_11postCCDPassEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE15growAndPushBackERKS8_($10,$0)|0);
   }
   HEAP32[$0>>2] = ((434896 + 8|0));
   HEAP32[$55>>2] = 0;
   HEAP16[$60>>1] = -1;
   HEAP16[$61>>1] = 0;
   HEAP32[$62>>2] = 0;
   HEAP32[$1>>2] = ((434896 + 8|0));
   HEAP32[$63>>2] = 0;
   HEAP32[$64>>2] = 0;
   HEAP32[$1>>2] = ((466112 + 8|0));
   HEAP32[$65>>2] = $this;
   HEAP32[$66>>2] = 464168;
   $109 = HEAP32[$45>>2]|0;
   $110 = $109 & 2147483647;
   $111 = HEAP32[$23>>2]|0;
   $112 = ($110>>>0)>($111>>>0);
   if ($112) {
    $113 = HEAP32[$21>>2]|0;
    $114 = (($113) + (($111*28)|0)|0);
    $115 = ((($113) + (($111*28)|0)|0) + 4|0);
    $116 = $60;
    $117 = $116;
    $118 = HEAP32[$117>>2]|0;
    $119 = (($116) + 4)|0;
    $120 = $119;
    $121 = HEAP32[$120>>2]|0;
    $122 = $115;
    $123 = $122;
    HEAP16[$123>>1]=$118&65535;HEAP16[$123+2>>1]=$118>>>16;
    $124 = (($122) + 4)|0;
    $125 = $124;
    HEAP16[$125>>1]=$121&65535;HEAP16[$125+2>>1]=$121>>>16;
    HEAP32[$114>>2] = ((434896 + 8|0));
    $126 = ((($113) + (($111*28)|0)|0) + 12|0);
    $127 = HEAP32[$63>>2]|0;
    HEAP32[$126>>2] = $127;
    $128 = ((($113) + (($111*28)|0)|0) + 16|0);
    $129 = HEAP32[$64>>2]|0;
    HEAP32[$128>>2] = $129;
    $130 = HEAP32[$63>>2]|0;
    HEAP32[$126>>2] = $130;
    HEAP32[$114>>2] = ((466112 + 8|0));
    $131 = ((($113) + (($111*28)|0)|0) + 20|0);
    $132 = $65;
    $133 = $132;
    $134 = HEAP32[$133>>2]|0;
    $135 = (($132) + 4)|0;
    $136 = $135;
    $137 = HEAP32[$136>>2]|0;
    $138 = $131;
    $139 = $138;
    HEAP32[$139>>2] = $134;
    $140 = (($138) + 4)|0;
    $141 = $140;
    HEAP32[$141>>2] = $137;
    $142 = HEAP32[$23>>2]|0;
    $143 = (($142) + 1)|0;
    HEAP32[$23>>2] = $143;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_19updateCCDSinglePassEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE15growAndPushBackERKS8_($21,$1)|0);
   }
   HEAP32[$1>>2] = ((434896 + 8|0));
   HEAP32[$62>>2] = 0;
   HEAP16[$67>>1] = -1;
   HEAP16[$68>>1] = 0;
   HEAP32[$69>>2] = 0;
   HEAP32[$2>>2] = ((434896 + 8|0));
   HEAP32[$70>>2] = 0;
   HEAP32[$71>>2] = 0;
   HEAP32[$2>>2] = ((465832 + 8|0));
   HEAP32[$72>>2] = $this;
   HEAP32[$73>>2] = 464200;
   $144 = HEAP32[$49>>2]|0;
   $145 = $144 & 2147483647;
   $146 = HEAP32[$33>>2]|0;
   $147 = ($145>>>0)>($146>>>0);
   if ($147) {
    $148 = HEAP32[$31>>2]|0;
    $149 = (($148) + (($146*28)|0)|0);
    $150 = ((($148) + (($146*28)|0)|0) + 4|0);
    $151 = $67;
    $152 = $151;
    $153 = HEAP32[$152>>2]|0;
    $154 = (($151) + 4)|0;
    $155 = $154;
    $156 = HEAP32[$155>>2]|0;
    $157 = $150;
    $158 = $157;
    HEAP16[$158>>1]=$153&65535;HEAP16[$158+2>>1]=$153>>>16;
    $159 = (($157) + 4)|0;
    $160 = $159;
    HEAP16[$160>>1]=$156&65535;HEAP16[$160+2>>1]=$156>>>16;
    HEAP32[$149>>2] = ((434896 + 8|0));
    $161 = ((($148) + (($146*28)|0)|0) + 12|0);
    $162 = HEAP32[$70>>2]|0;
    HEAP32[$161>>2] = $162;
    $163 = ((($148) + (($146*28)|0)|0) + 16|0);
    $164 = HEAP32[$71>>2]|0;
    HEAP32[$163>>2] = $164;
    $165 = HEAP32[$70>>2]|0;
    HEAP32[$161>>2] = $165;
    HEAP32[$149>>2] = ((465832 + 8|0));
    $166 = ((($148) + (($146*28)|0)|0) + 20|0);
    $167 = $72;
    $168 = $167;
    $169 = HEAP32[$168>>2]|0;
    $170 = (($167) + 4)|0;
    $171 = $170;
    $172 = HEAP32[$171>>2]|0;
    $173 = $166;
    $174 = $173;
    HEAP32[$174>>2] = $169;
    $175 = (($173) + 4)|0;
    $176 = $175;
    HEAP32[$176>>2] = $172;
    $177 = HEAP32[$33>>2]|0;
    $178 = (($177) + 1)|0;
    HEAP32[$33>>2] = $178;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_13ccdBroadPhaseEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE15growAndPushBackERKS8_($31,$2)|0);
   }
   HEAP32[$2>>2] = ((434896 + 8|0));
   HEAP32[$69>>2] = 0;
   $179 = (($j$07) + 1)|0;
   $exitcond = ($179|0)==(2);
   if ($exitcond) {
    break;
   } else {
    $j$07 = $179;
   }
  }
 }
 $180 = (($this) + 1212|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = (($181) + 1000|0);
 $183 = HEAP32[$182>>2]|0;
 __ZN5physx10PxsContext19resetThreadContextsEv($183);
 $184 = HEAP32[$180>>2]|0;
 $185 = (($184) + 1000|0);
 $186 = HEAP32[$185>>2]|0;
 __ZN5physx10PxsContext14updateCCDBeginEv($186);
 $187 = (($this) + 1936|0);
 $188 = HEAP32[$187>>2]|0;
 $189 = (($188) + 16|0);
 HEAP32[$189>>2] = 1;
 $190 = (($188) + 12|0);
 HEAP32[$190>>2] = $parentContinuation;
 $191 = ($parentContinuation|0)==(0|0);
 if (!($191)) {
  $192 = HEAP32[$parentContinuation>>2]|0;
  $193 = (($192) + 16|0);
  $194 = HEAP32[$193>>2]|0;
  FUNCTION_TABLE_vi[$194 & 4095]($parentContinuation);
  $195 = HEAP32[$190>>2]|0;
  $196 = (($195) + 8|0);
  $197 = HEAP32[$196>>2]|0;
  $198 = (($188) + 8|0);
  HEAP32[$198>>2] = $197;
 }
 $199 = HEAP32[$187>>2]|0;
 $200 = HEAP32[$199>>2]|0;
 $201 = (($200) + 20|0);
 $202 = HEAP32[$201>>2]|0;
 FUNCTION_TABLE_vi[$202 & 4095]($199);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene36collectPostSolverVelocitiesBeforeCCDEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0;
 var $$sum25 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0);
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0;
 var $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$026 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2372|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 1088|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($8) + -1)|0;
 $i$026 = 0;
 while(1) {
  $11 = ($i$026>>>0)<($10>>>0);
  if ($11) {
   $12 = (($i$026) + 1)|0;
   $13 = (($6) + ($12<<2)|0);
   $14 = HEAP32[$13>>2]|0;
  }
  $15 = (($6) + ($i$026<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   __ZNK5physx2Sc9ActorPair23createContactReportDataEv($16);
   $$pre$i$i1 = HEAP32[$17>>2]|0;
   $21 = $$pre$i$i1;
  } else {
   $21 = $18;
  }
  $20 = (($21) + 10|0);
  $22 = HEAP16[$20>>1]|0;
  $23 = $22&65535;
  $24 = $23 & 2;
  $25 = ($24|0)==(0);
  if ($25) {
   $26 = HEAP32[$3>>2]|0;
   $27 = (($26) + 44|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$21>>2]|0;
   $30 = (($i$026) + 1)|0;
   $31 = ($30>>>0)<($8>>>0);
   if ($31) {
    $32 = (($6) + ($30<<2)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==(0|0);
    if ($36) {
     __ZNK5physx2Sc9ActorPair23createContactReportDataEv($33);
     $$pre$i$i = HEAP32[$34>>2]|0;
     $107 = $$pre$i$i;
    } else {
     $107 = $35;
    }
   }
   $37 = (($21) + 8|0);
   $38 = HEAP16[$37>>1]|0;
   $39 = ($38<<16>>16)==(0);
   if ($39) {
    $$pre$phiZ2D = $30;
   } else {
    $40 = $23 & 8;
    $41 = ($40|0)==(0);
    if ($41) {
     $$pre$phiZ2D = $30;
    } else {
     $42 = HEAP32[$16>>2]|0;
     $43 = (($16) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + 50|0);
     $46 = HEAP8[$45>>0]|0;
     $47 = ($46<<24>>24)==(0);
     if ($47) {
      $$sum20 = (($29) + 12)|0;
      $68 = (($28) + ($$sum20)|0);
      HEAPF32[$68>>2] = Math_fround(0.0);
      $$sum21 = (($29) + 16)|0;
      $69 = (($28) + ($$sum21)|0);
      HEAPF32[$69>>2] = Math_fround(0.0);
      $$sum22 = (($29) + 20)|0;
      $70 = (($28) + ($$sum22)|0);
      HEAPF32[$70>>2] = Math_fround(0.0);
      $$sum23 = (($29) + 36)|0;
      $71 = (($28) + ($$sum23)|0);
      HEAPF32[$71>>2] = Math_fround(0.0);
      $$sum24 = (($29) + 40)|0;
      $72 = (($28) + ($$sum24)|0);
      HEAPF32[$72>>2] = Math_fround(0.0);
      $$sum25 = (($29) + 44)|0;
      $73 = (($28) + ($$sum25)|0);
      HEAPF32[$73>>2] = Math_fround(0.0);
     } else {
      $48 = (($42) + 52|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = (($49) + 80|0);
      $51 = Math_fround(HEAPF32[$50>>2]);
      $$sum = (($29) + 12)|0;
      $52 = (($28) + ($$sum)|0);
      HEAPF32[$52>>2] = $51;
      $53 = (($49) + 84|0);
      $54 = Math_fround(HEAPF32[$53>>2]);
      $$sum3 = (($29) + 16)|0;
      $55 = (($28) + ($$sum3)|0);
      HEAPF32[$55>>2] = $54;
      $56 = (($49) + 88|0);
      $57 = Math_fround(HEAPF32[$56>>2]);
      $$sum4 = (($29) + 20)|0;
      $58 = (($28) + ($$sum4)|0);
      HEAPF32[$58>>2] = $57;
      $59 = (($49) + 96|0);
      $60 = Math_fround(HEAPF32[$59>>2]);
      $$sum5 = (($29) + 36)|0;
      $61 = (($28) + ($$sum5)|0);
      HEAPF32[$61>>2] = $60;
      $62 = (($49) + 100|0);
      $63 = Math_fround(HEAPF32[$62>>2]);
      $$sum6 = (($29) + 40)|0;
      $64 = (($28) + ($$sum6)|0);
      HEAPF32[$64>>2] = $63;
      $65 = (($49) + 104|0);
      $66 = Math_fround(HEAPF32[$65>>2]);
      $$sum7 = (($29) + 44)|0;
      $67 = (($28) + ($$sum7)|0);
      HEAPF32[$67>>2] = $66;
     }
     $74 = (($44) + 50|0);
     $75 = HEAP8[$74>>0]|0;
     $76 = ($75<<24>>24)==(0);
     if ($76) {
      $$sum14 = (($29) + 24)|0;
      $97 = (($28) + ($$sum14)|0);
      HEAPF32[$97>>2] = Math_fround(0.0);
      $$sum15 = (($29) + 28)|0;
      $98 = (($28) + ($$sum15)|0);
      HEAPF32[$98>>2] = Math_fround(0.0);
      $$sum16 = (($29) + 32)|0;
      $99 = (($28) + ($$sum16)|0);
      HEAPF32[$99>>2] = Math_fround(0.0);
      $$sum17 = (($29) + 48)|0;
      $100 = (($28) + ($$sum17)|0);
      HEAPF32[$100>>2] = Math_fround(0.0);
      $$sum18 = (($29) + 52)|0;
      $101 = (($28) + ($$sum18)|0);
      HEAPF32[$101>>2] = Math_fround(0.0);
      $$sum19 = (($29) + 56)|0;
      $102 = (($28) + ($$sum19)|0);
      HEAPF32[$102>>2] = Math_fround(0.0);
     } else {
      $77 = (($44) + 52|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($78) + 80|0);
      $80 = Math_fround(HEAPF32[$79>>2]);
      $$sum8 = (($29) + 24)|0;
      $81 = (($28) + ($$sum8)|0);
      HEAPF32[$81>>2] = $80;
      $82 = (($78) + 84|0);
      $83 = Math_fround(HEAPF32[$82>>2]);
      $$sum9 = (($29) + 28)|0;
      $84 = (($28) + ($$sum9)|0);
      HEAPF32[$84>>2] = $83;
      $85 = (($78) + 88|0);
      $86 = Math_fround(HEAPF32[$85>>2]);
      $$sum10 = (($29) + 32)|0;
      $87 = (($28) + ($$sum10)|0);
      HEAPF32[$87>>2] = $86;
      $88 = (($78) + 96|0);
      $89 = Math_fround(HEAPF32[$88>>2]);
      $$sum11 = (($29) + 48)|0;
      $90 = (($28) + ($$sum11)|0);
      HEAPF32[$90>>2] = $89;
      $91 = (($78) + 100|0);
      $92 = Math_fround(HEAPF32[$91>>2]);
      $$sum12 = (($29) + 52)|0;
      $93 = (($28) + ($$sum12)|0);
      HEAPF32[$93>>2] = $92;
      $94 = (($78) + 104|0);
      $95 = Math_fround(HEAPF32[$94>>2]);
      $$sum13 = (($29) + 56)|0;
      $96 = (($28) + ($$sum13)|0);
      HEAPF32[$96>>2] = $95;
     }
     $103 = HEAP16[$20>>1]|0;
     $104 = $103&65535;
     $105 = $104 & 65527;
     $106 = $105&65535;
     HEAP16[$20>>1] = $106;
     $$pre$phiZ2D = $30;
    }
   }
  } else {
   $$pre = (($i$026) + 1)|0;
   $$pre$phiZ2D = $$pre;
  }
  $exitcond = ($$pre$phiZ2D|0)==($8|0);
  if ($exitcond) {
   break;
  } else {
   $i$026 = $$pre$phiZ2D;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11postCCDPassEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19updateCCDSinglePassEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13ccdBroadPhaseEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene13ccdBroadPhaseEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[((545648 + 2|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $2 = (($this) + 1184|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = HEAP32[$3>>2]|0;
   $6 = (($5) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP16[545648>>1]|0;
   $9 = (($this) + 1176|0);
   $10 = $9;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   $13 = (($10) + 4)|0;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   FUNCTION_TABLE_viiiii[$7 & 255]($3,$8,$12,$15,99999789);
  }
 }
 $16 = (($this) + 1212|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1000|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__ZNK5physx10PxsContext17getCurrentCCDPassEv($19)|0);
 $21 = (__ZNK5physx10PxsContext15getCCDMaxPassesEv($19)|0);
 $22 = ($20|0)==(0);
 if (!($22)) {
  $23 = (__ZNK5physx10PxsContext15getNumSweepHitsEv($19)|0);
  $24 = ($23|0)==(0);
  if ($24) {
   STACKTOP = sp;return;
  }
 }
 $25 = $20 & 1;
 $26 = $25 ^ 1;
 $27 = (($21) + -1)|0;
 $28 = ($20|0)!=($27|0);
 if ($28) {
  $29 = (($this) + 1936|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ((($30) + (($26*28)|0)|0) + 16|0);
  HEAP32[$31>>2] = 1;
  $32 = ((($30) + (($26*28)|0)|0) + 12|0);
  HEAP32[$32>>2] = $continuation;
  $33 = ($continuation|0)==(0|0);
  if (!($33)) {
   $34 = HEAP32[$continuation>>2]|0;
   $35 = (($34) + 16|0);
   $36 = HEAP32[$35>>2]|0;
   FUNCTION_TABLE_vi[$36 & 4095]($continuation);
   $37 = HEAP32[$32>>2]|0;
   $38 = (($37) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($30) + (($26*28)|0)|0) + 8|0);
   HEAP32[$40>>2] = $39;
  }
 }
 $41 = (($this) + 1948|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($20|0)==($27|0);
 if ($43) {
  $49 = $continuation;
 } else {
  $44 = (($this) + 1936|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + (($26*28)|0)|0);
  $49 = $46;
 }
 $47 = ((($42) + (($25*28)|0)|0) + 16|0);
 HEAP32[$47>>2] = 1;
 $48 = ((($42) + (($25*28)|0)|0) + 12|0);
 HEAP32[$48>>2] = $49;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = HEAP32[$49>>2]|0;
  $52 = (($51) + 16|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vi[$53 & 4095]($49);
  $54 = HEAP32[$48>>2]|0;
  $55 = (($54) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ((($42) + (($25*28)|0)|0) + 8|0);
  HEAP32[$57>>2] = $56;
 }
 $58 = (($this) + 1924|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$41>>2]|0;
 $61 = (($60) + (($25*28)|0)|0);
 $62 = ((($59) + (($25*28)|0)|0) + 16|0);
 HEAP32[$62>>2] = 1;
 $63 = ((($59) + (($25*28)|0)|0) + 12|0);
 HEAP32[$63>>2] = $61;
 $64 = ($61|0)==(0|0);
 if (!($64)) {
  $65 = HEAP32[$61>>2]|0;
  $66 = (($65) + 16|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_vi[$67 & 4095]($61);
  $68 = HEAP32[$63>>2]|0;
  $69 = (($68) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ((($59) + (($25*28)|0)|0) + 8|0);
  HEAP32[$71>>2] = $70;
 }
 $72 = HEAP32[$58>>2]|0;
 $73 = (($72) + (($25*28)|0)|0);
 __ZN5physx10PxsContext16updateBroadPhaseEPNS_10PxBaseTaskEb($19,$73,1);
 $74 = HEAP32[$41>>2]|0;
 $75 = (($74) + (($25*28)|0)|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + 20|0);
 $78 = HEAP32[$77>>2]|0;
 FUNCTION_TABLE_vi[$78 & 4095]($75);
 $79 = HEAP32[$58>>2]|0;
 $80 = (($79) + (($25*28)|0)|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + 20|0);
 $83 = HEAP32[$82>>2]|0;
 FUNCTION_TABLE_vi[$83 & 4095]($80);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $84 = (($this) + 1936|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($85) + (($26*28)|0)|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($87) + 20|0);
 $89 = HEAP32[$88>>2]|0;
 FUNCTION_TABLE_vi[$89 & 4095]($86);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19updateCCDSinglePassEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 $3 = (($this) + 1212|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1000|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK5physx10PxsContext17getCurrentCCDPassEv($6)|0);
 $8 = (($7) + 1)|0;
 __ZN5physx2Sc5Scene16finishBroadPhaseEj($this,$8);
 $9 = HEAP8[((545648 + 2|0))>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = (($this) + 1184|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = HEAP32[$12>>2]|0;
   $15 = (($14) + 20|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP16[545648>>1]|0;
   $18 = (($this) + 1176|0);
   $19 = $18;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_viiiii[$16 & 255]($12,$17,$21,$24,99999789);
  }
 }
 __ZN5physx10PxsContext19resetThreadContextsEv($6);
 $25 = (($this) + 48|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 1200|0);
 $28 = HEAP16[$27>>1]|0;
 $29 = $28 & 8;
 $30 = ($29<<16>>16)!=(0);
 __ZN5physx10PxsContext9updateCCDEfPNS_10PxBaseTaskEb($6,$26,$continuation,$30);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene10postSolverEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$pre$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $cp$0$i = 0, $exitcond = 0, $i$01 = 0, $kinePrefetch$02 = 0, $kinePrefetch$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 1212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1000|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 44|0);
 $6 = (($4) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx18PxsDynamicsContext12mergeResultsEv($7);
 __ZN5physx17PxcNpMemBlockPool19swapFrictionStreamsEv($5);
 $8 = (__ZNK5physx17PxcNpMemBlockPool27getPeakConstraintBlockCountEv($5)|0);
 $9 = (($4) + 7368|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$10>>2]|0;
 $14 = (($13) + ($12<<2)|0);
 $15 = (($10) + 1000|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($12|0)==(0);
 if (!($17)) {
  $18 = (($13) + 64|0);
  $19 = (($16) + 5920|0);
  $20 = (($16) + 5924|0);
  $21 = (($16) + 5916|0);
  $i$01 = 0;$kinePrefetch$02 = $18;
  while(1) {
   $22 = ($kinePrefetch$02>>>0)<($14>>>0);
   if ($22) {
    $23 = HEAP32[$kinePrefetch$02>>2]|0;
    $24 = $23;
    $25 = (_bitshift64Lshr(($24|0),0,6)|0);
    $26 = tempRet0;
    $27 = (_i64Add(($24|0),0,1023,0)|0);
    $28 = tempRet0;
    $29 = (_bitshift64Lshr(($27|0),($28|0),6)|0);
    $30 = tempRet0;
    $31 = (_i64Subtract(1,0,($25|0),($26|0))|0);
    $32 = tempRet0;
    $33 = (_i64Add(($31|0),($32|0),($29|0),($30|0))|0);
    $34 = tempRet0;
    $36 = $33;$37 = $34;$cp$0$i = $23;
    while(1) {
     $35 = (($cp$0$i) + 64|0);
     $38 = (_i64Add(($36|0),($37|0),-1,-1)|0);
     $39 = tempRet0;
     $40 = ($38|0)==(0);
     $41 = ($39|0)==(0);
     $42 = $40 & $41;
     if ($42) {
      break;
     } else {
      $36 = $38;$37 = $39;$cp$0$i = $35;
     }
    }
    $43 = (($kinePrefetch$02) + 4|0);
    $kinePrefetch$1 = $43;
   } else {
    $kinePrefetch$1 = $kinePrefetch$02;
   }
   $44 = (($13) + ($i$01<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   __ZN5physx2Sc7BodySim19updateKinematicPoseEv($45);
   $46 = (($45) + 136|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(1073741823);
   if (!($48)) {
    $49 = (($47) + 32)|0;
    $50 = $49 >>> 5;
    $51 = HEAP32[$19>>2]|0;
    $52 = $51 & 2147483647;
    $53 = ($50>>>0)>($52>>>0);
    if ($53) {
     $54 = $50 << 2;
     $55 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($20,$54,471576,339)|0);
     $56 = HEAP32[$21>>2]|0;
     $57 = ($56|0)==(0|0);
     if (!($57)) {
      $58 = HEAP32[$19>>2]|0;
      $59 = $58 << 2;
      _memcpy(($55|0),($56|0),($59|0))|0;
      $60 = HEAP32[$19>>2]|0;
      $61 = ($60|0)>(-1);
      if ($61) {
       $62 = HEAP32[$21>>2]|0;
       __ZN5physx6shdfnd9Allocator10deallocateEPv($20,$62);
      }
     }
     $63 = HEAP32[$19>>2]|0;
     $64 = $63 & 2147483647;
     $65 = (($55) + ($64<<2)|0);
     $66 = (($50) - ($63))|0;
     $67 = $66 << 2;
     _memset(($65|0),0,($67|0))|0;
     HEAP32[$21>>2] = $55;
     HEAP32[$19>>2] = $50;
     $72 = $55;
    } else {
     $$pre$i = HEAP32[$21>>2]|0;
     $72 = $$pre$i;
    }
    $68 = $47 & 31;
    $69 = 1 << $68;
    $70 = $47 >>> 5;
    $71 = (($72) + ($70<<2)|0);
    $73 = HEAP32[$71>>2]|0;
    $74 = $73 | $69;
    HEAP32[$71>>2] = $74;
   }
   $75 = (($i$01) + 1)|0;
   $exitcond = ($75|0)==($12|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $75;$kinePrefetch$02 = $kinePrefetch$1;
   }
  }
 }
 __ZN5physx2Sc5Scene16afterIntegrationEv($this);
 __ZN5physx2Sc5Scene11afterSolverEj($this,0);
 $76 = HEAP8[((545776 + 2|0))>>0]|0;
 $77 = ($76<<24>>24)==(0);
 if ($77) {
  STACKTOP = sp;return;
 }
 $78 = (($this) + 1184|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($79|0)==(0|0);
 if ($80) {
  STACKTOP = sp;return;
 }
 $81 = HEAP32[$79>>2]|0;
 $82 = (($81) + 20|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = HEAP16[545776>>1]|0;
 $85 = (($this) + 1176|0);
 $86 = $85;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = (($86) + 4)|0;
 $90 = $89;
 $91 = HEAP32[$90>>2]|0;
 FUNCTION_TABLE_viiiii[$83 & 255]($79,$84,$88,$91,99999789);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene16afterIntegrationEv($this) {
 $this = $this|0;
 var $$idx = 0, $$in = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0);
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $actorPrefetch$05 = 0, $actorPrefetch$1 = 0;
 var $cp$0$i = 0, $i$01 = 0, $secondPassBodies = 0, $secondPassBodyCount$0$lcssa = 0, $secondPassBodyCount$06 = 0, $secondPassBodyCount$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $secondPassBodies = sp;
 $0 = sp + 8|0;
 $1 = (($this) + 1212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($2) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5<<2)|0);
 $$idx = $5 << 2;
 $7 = ($$idx>>>0)>(1024);
 $8 = (($secondPassBodies) + 4|0);
 $9 = $7&1;
 HEAP8[$8>>0] = $9;
 if ($7) {
  $10 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$$idx,463960,1968)|0);
  HEAP32[$secondPassBodies>>2] = $10;
 } else {
  $11 = STACKTOP; STACKTOP = STACKTOP + ((((4*$5)|0)+15)&-16)|0;;
  HEAP32[$secondPassBodies>>2] = $11;
 }
 $12 = (($this) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(Math_fround(1.0) / $13);
 $15 = (($this) + 1184|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 1176|0);
 $18 = $17;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$16>>2]|0;
 $25 = (($24) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_viiii[$26 & 511]($16,105,$20,$23);
 $27 = ($5|0)>(0);
 if ($27) {
  $28 = (($3) + 32|0);
  $$sum = (($5) + -1)|0;
  $29 = (($3) + ($$sum<<2)|0);
  $30 = (($this) + 1162|0);
  $54 = $3;$actorPrefetch$05 = $28;$secondPassBodyCount$06 = 0;
  while(1) {
   $31 = ($actorPrefetch$05>>>0)>($29>>>0);
   if ($31) {
    $actorPrefetch$1 = $actorPrefetch$05;
   } else {
    $32 = HEAP32[$actorPrefetch$05>>2]|0;
    $33 = $32;
    $34 = (_bitshift64Lshr(($33|0),0,6)|0);
    $35 = tempRet0;
    $36 = (_i64Add(($33|0),0,511,0)|0);
    $37 = tempRet0;
    $38 = (_bitshift64Lshr(($36|0),($37|0),6)|0);
    $39 = tempRet0;
    $40 = (_i64Subtract(1,0,($34|0),($35|0))|0);
    $41 = tempRet0;
    $42 = (_i64Add(($40|0),($41|0),($38|0),($39|0))|0);
    $43 = tempRet0;
    $45 = $42;$46 = $43;$cp$0$i = $32;
    while(1) {
     $44 = (($cp$0$i) + 64|0);
     $47 = (_i64Add(($45|0),($46|0),-1,-1)|0);
     $48 = tempRet0;
     $49 = ($47|0)==(0);
     $50 = ($48|0)==(0);
     $51 = $49 & $50;
     if ($51) {
      break;
     } else {
      $45 = $47;$46 = $48;$cp$0$i = $44;
     }
    }
    $52 = (($actorPrefetch$05) + 4|0);
    $actorPrefetch$1 = $52;
   }
   $53 = HEAP32[$54>>2]|0;
   $55 = (($53) + 60|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==(0|0);
   if ($57) {
    $secondPassBodyCount$1 = $secondPassBodyCount$06;
   } else {
    $58 = (__ZN5physx2Sc19ConstraintGroupNode7getRootEv($56)|0);
    $59 = (($58) + 44|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = $60 & 2;
    $62 = ($61<<24>>24)==(0);
    if ($62) {
     $63 = (($58) + 20|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)==(0|0);
     if ($65) {
      $secondPassBodyCount$1 = $secondPassBodyCount$06;
     } else {
      $66 = (($secondPassBodyCount$06) + 1)|0;
      $67 = HEAP32[$secondPassBodies>>2]|0;
      $68 = (($67) + ($secondPassBodyCount$06<<2)|0);
      HEAP32[$68>>2] = $58;
      $69 = HEAP8[$59>>0]|0;
      $70 = $69&255;
      $71 = $70 | 2;
      $72 = $71&255;
      HEAP8[$59>>0] = $72;
      $secondPassBodyCount$1 = $66;
     }
    } else {
     $secondPassBodyCount$1 = $secondPassBodyCount$06;
    }
   }
   $73 = (($53) + 52|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + 44|0);
   $76 = HEAP8[$75>>0]|0;
   $77 = $76 & 1;
   $78 = ($77<<24>>24)==(0);
   if ($78) {
    $79 = (($53) + 50|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = ($80<<24>>24)==(4);
    if (!($81)) {
     $82 = Math_fround(HEAPF32[$12>>2]);
     $83 = HEAP8[$30>>0]|0;
     $84 = ($83<<24>>24)!=(0);
     __ZN5physx2Sc7BodySim10sleepCheckEffb($53,$82,$14,$84);
    }
   }
   $85 = (($54) + 4|0);
   $86 = ($85>>>0)<($6>>>0);
   if ($86) {
    $54 = $85;$actorPrefetch$05 = $actorPrefetch$1;$secondPassBodyCount$06 = $secondPassBodyCount$1;
   } else {
    $secondPassBodyCount$0$lcssa = $secondPassBodyCount$1;
    break;
   }
  }
 } else {
  $secondPassBodyCount$0$lcssa = 0;
 }
 $87 = HEAP32[$16>>2]|0;
 $88 = (($87) + 12|0);
 $89 = HEAP32[$88>>2]|0;
 FUNCTION_TABLE_viiii[$89 & 511]($16,105,$20,$23);
 $90 = (($this) + 108|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)==(0);
 if (!($92)) {
  $93 = (($this) + 104|0);
  $94 = (($this) + 1162|0);
  $i$01 = 0;
  while(1) {
   $95 = HEAP32[$93>>2]|0;
   $96 = (($95) + ($i$01<<2)|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = HEAP32[$97>>2]|0;
   $99 = Math_fround(HEAPF32[$12>>2]);
   $100 = HEAP8[$94>>0]|0;
   $101 = ($100<<24>>24)!=(0);
   __ZN5physx2Sc15ArticulationSim10sleepCheckEffb($98,$99,$14,$101);
   $102 = (($i$01) + 1)|0;
   $103 = HEAP32[$90>>2]|0;
   $104 = ($102>>>0)<($103>>>0);
   if ($104) {
    $i$01 = $102;
   } else {
    break;
   }
  }
 }
 $105 = HEAP32[$15>>2]|0;
 $106 = $17;
 $107 = $106;
 $108 = HEAP32[$107>>2]|0;
 $109 = (($106) + 4)|0;
 $110 = $109;
 $111 = HEAP32[$110>>2]|0;
 $112 = HEAP32[$105>>2]|0;
 $113 = (($112) + 8|0);
 $114 = HEAP32[$113>>2]|0;
 FUNCTION_TABLE_viiii[$114 & 511]($105,106,$108,$111);
 $115 = ($secondPassBodyCount$0$lcssa|0)==(0);
 if (!($115)) {
  $$in = $secondPassBodyCount$0$lcssa;
  while(1) {
   $116 = (($$in) + -1)|0;
   $117 = HEAP32[$secondPassBodies>>2]|0;
   $118 = (($117) + ($116<<2)|0);
   $119 = HEAP32[$118>>2]|0;
   __ZN5physx2Sc19ConstraintGroupNode11projectPoseERS1_($119);
   $120 = HEAP32[$secondPassBodies>>2]|0;
   $121 = (($120) + ($116<<2)|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = (($122) + 44|0);
   $124 = HEAP8[$123>>0]|0;
   $125 = $124&255;
   $126 = $125 & 253;
   $127 = $126&255;
   HEAP8[$123>>0] = $127;
   $128 = ($116|0)==(0);
   if ($128) {
    break;
   } else {
    $$in = $116;
   }
  }
 }
 $129 = HEAP32[$105>>2]|0;
 $130 = (($129) + 12|0);
 $131 = HEAP32[$130>>2]|0;
 FUNCTION_TABLE_viiii[$131 & 511]($105,106,$108,$111);
 $132 = HEAP8[$8>>0]|0;
 $133 = ($132<<24>>24)==(0);
 if ($133) {
  STACKTOP = sp;return;
 }
 $134 = HEAP32[$secondPassBodies>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($secondPassBodies,$134);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene11afterSolverEj($this,$ccdPass) {
 $this = $this|0;
 $ccdPass = $ccdPass|0;
 var $$idx = 0, $$in = 0, $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $actorPrefetch$03 = 0;
 var $actorPrefetch$1 = 0, $contactEventPairs$09 = 0, $cp$0$i = 0, $exitcond = 0, $i$02 = 0, $j$013 = 0, $or$cond = 0, $pairArrays = 0, $pairIndex$0$i = 0, $pairIndex$03$i = 0, $pairIndex$04$i = 0, $pairSizes = 0, $secondPassBodies = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pairArrays = sp + 16|0;
 $pairSizes = sp;
 $secondPassBodies = sp + 8|0;
 $0 = sp + 24|0;
 $1 = (($this) + 1184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1176|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,103,$6,$9);
 $13 = (($this) + 1212|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1000|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 5868|0);
 $18 = (($16) + 5872|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 $21 = (($16) + 5880|0);
 __ZN5physx17PxsThresholdTable5buildERKNS_18PxsThresholdStreamE($21,$17);
 $22 = (($this) + 1088|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 32|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$pairArrays>>2] = $25;
 $26 = (($23) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$pairSizes>>2] = $27;
 $28 = (($23) + 16|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($pairArrays) + 4|0);
 HEAP32[$30>>2] = $29;
 $31 = (($23) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($pairSizes) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = (($this) + 48|0);
 $35 = (($16) + 5884|0);
 $36 = (($16) + 5900|0);
 $37 = (($16) + 5896|0);
 $38 = (($16) + 5888|0);
 $40 = $27;$j$013 = 0;
 while(1) {
  $39 = ($40|0)==(0);
  if (!($39)) {
   $41 = (($pairArrays) + ($j$013<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $$in = $40;$contactEventPairs$09 = $42;
   while(1) {
    $43 = (($$in) + -1)|0;
    $44 = (($contactEventPairs$09) + 4|0);
    $45 = HEAP32[$contactEventPairs$09>>2]|0;
    $46 = ($43|0)==(0);
    if (!($46)) {
     $47 = HEAP32[$44>>2]|0;
    }
    $48 = (($45) + 44|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = $49 & 448;
    $51 = ($50|0)==(0);
    L10: do {
     if (!($51)) {
      $52 = $49 << 1;
      $53 = $52 & 1048576;
      $54 = $49 & -1572865;
      $55 = $53 | $54;
      HEAP32[$48>>2] = $55;
      L12: do {
       if (!($20)) {
        $56 = (($45) + 12|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = (($57) + 50|0);
        $59 = HEAP8[$58>>0]|0;
        if ((($59<<24>>24) == 1) | (($59<<24>>24) == 4)) {
         $60 = (($57) + 64|0);
         $71 = $60;
        } else {
         $71 = 0;
        }
        $61 = (($45) + 16|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = (($62) + 50|0);
        $64 = HEAP8[$63>>0]|0;
        if ((($64<<24>>24) == 1) | (($64<<24>>24) == 4)) {
         $65 = (($62) + 64|0);
         $72 = $65;
        } else {
         $72 = 0;
        }
        $66 = Math_fround(HEAPF32[$34>>2]);
        $67 = HEAP32[$35>>2]|0;
        $68 = HEAP32[$36>>2]|0;
        $69 = HEAP32[$37>>2]|0;
        $70 = ($71>>>0)<($72>>>0);
        $73 = $70 ? $71 : $72;
        $74 = $70 ? $72 : $71;
        $75 = HEAP32[$38>>2]|0;
        $76 = $73;
        $77 = $74;
        $78 = $77 ^ -1;
        $79 = (_i64Add(($77|0),($76|0),-1,($78|0))|0);
        $80 = tempRet0;
        $81 = (_bitshift64Lshr(($79|0),($80|0),22)|0);
        $82 = tempRet0;
        $83 = $81 ^ $79;
        $84 = $82 ^ $80;
        $85 = (_bitshift64Shl(($83|0),($84|0),13)|0);
        $86 = tempRet0;
        $87 = $85 ^ -1;
        $88 = $86 ^ -1;
        $89 = (_i64Add(($83|0),($84|0),($87|0),($88|0))|0);
        $90 = tempRet0;
        $91 = (_bitshift64Lshr(($89|0),($90|0),8)|0);
        $92 = tempRet0;
        $93 = $91 ^ $89;
        $94 = $92 ^ $90;
        $95 = (___muldi3(($93|0),($94|0),9,0)|0);
        $96 = tempRet0;
        $97 = (_bitshift64Lshr(($95|0),($96|0),15)|0);
        $98 = tempRet0;
        $99 = $97 ^ $95;
        $100 = $98 ^ $96;
        $101 = (_bitshift64Shl(($99|0),($100|0),27)|0);
        $102 = tempRet0;
        $103 = $101 ^ -1;
        $104 = $102 ^ -1;
        $105 = (_i64Add(($99|0),($100|0),($103|0),($104|0))|0);
        $106 = tempRet0;
        $107 = (_bitshift64Lshr(($105|0),($106|0),31)|0);
        $108 = tempRet0;
        $109 = $107 ^ $105;
        $108 ^ $106;
        $110 = (($109>>>0) % ($75>>>0))&-1;
        $111 = (($67) + ($110<<2)|0);
        $pairIndex$03$i = HEAP32[$111>>2]|0;
        $112 = ($pairIndex$03$i|0)==(-1);
        if (!($112)) {
         $113 = HEAP32[$17>>2]|0;
         $pairIndex$04$i = $pairIndex$03$i;
         while(1) {
          $114 = (($69) + ($pairIndex$04$i<<3)|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = (($113) + ($115<<4)|0);
          $117 = HEAP32[$116>>2]|0;
          $118 = ($117|0)==($73|0);
          if ($118) {
           $119 = ((($113) + ($115<<4)|0) + 4|0);
           $120 = HEAP32[$119>>2]|0;
           $121 = ($120|0)==($74|0);
           if ($121) {
            break;
           }
          }
          $122 = (($68) + ($pairIndex$04$i<<2)|0);
          $pairIndex$0$i = HEAP32[$122>>2]|0;
          $123 = ($pairIndex$0$i|0)==(-1);
          if ($123) {
           break L12;
          } else {
           $pairIndex$04$i = $pairIndex$0$i;
          }
         }
         $124 = ((($69) + ($pairIndex$04$i<<3)|0) + 4|0);
         $125 = Math_fround(HEAPF32[$124>>2]);
         $126 = ((($113) + ($115<<4)|0) + 12|0);
         $127 = Math_fround(HEAPF32[$126>>2]);
         $128 = Math_fround($66 * $127);
         $129 = $125 > $128;
         if ($129) {
          $130 = $55 | 524288;
          HEAP32[$48>>2] = $130;
          $131 = ($53|0)==(0);
          if ($131) {
           $132 = $49 & 64;
           $133 = ($132|0)==(0);
           if ($133) {
            break L10;
           }
           __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($45,64,0,0,0,$ccdPass);
           break L10;
          } else {
           $134 = $49 & 128;
           $135 = ($134|0)==(0);
           if ($135) {
            break L10;
           }
           __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($45,128,0,0,0,$ccdPass);
           break L10;
          }
         }
        }
       }
      } while(0);
      $136 = ($53|0)==(0);
      $137 = $49 & 256;
      $138 = ($137|0)==(0);
      $or$cond = $136 | $138;
      if (!($or$cond)) {
       __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($45,256,0,0,0,$ccdPass);
      }
     }
    } while(0);
    if ($46) {
     break;
    } else {
     $$in = $43;$contactEventPairs$09 = $44;
    }
   }
  }
  $139 = (($j$013) + 1)|0;
  $exitcond = ($139|0)==(2);
  if ($exitcond) {
   break;
  }
  $$phi$trans$insert = (($pairSizes) + ($139<<2)|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $40 = $$pre;$j$013 = $139;
 }
 $140 = HEAP32[$13>>2]|0;
 $141 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($140)|0);
 __ZN5physx16PxsIslandManager11freeBuffersEv($141);
 $142 = HEAP32[$13>>2]|0;
 $143 = (($142) + 1000|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = (($144) + 7384|0);
 $146 = HEAP32[$142>>2]|0;
 $147 = (($142) + 4|0);
 $148 = HEAP32[$147>>2]|0;
 $149 = (($146) + ($148<<2)|0);
 $$idx = $148 << 2;
 $150 = ($$idx>>>0)>(1024);
 $151 = (($secondPassBodies) + 4|0);
 $152 = $150&1;
 HEAP8[$151>>0] = $152;
 if ($150) {
  $153 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$$idx,463960,2106)|0);
  HEAP32[$secondPassBodies>>2] = $153;
 } else {
  $154 = STACKTOP; STACKTOP = STACKTOP + ((((4*$148)|0)+15)&-16)|0;;
  HEAP32[$secondPassBodies>>2] = $154;
 }
 $155 = HEAP32[$1>>2]|0;
 $156 = $3;
 $157 = $156;
 $158 = HEAP32[$157>>2]|0;
 $159 = (($156) + 4)|0;
 $160 = $159;
 $161 = HEAP32[$160>>2]|0;
 $162 = HEAP32[$155>>2]|0;
 $163 = (($162) + 8|0);
 $164 = HEAP32[$163>>2]|0;
 FUNCTION_TABLE_viiii[$164 & 511]($155,104,$158,$161);
 $165 = ($148|0)>(0);
 if ($165) {
  $166 = (($146) + 32|0);
  $$sum = (($148) + -1)|0;
  $167 = (($146) + ($$sum<<2)|0);
  $169 = $146;$actorPrefetch$03 = $166;
  while(1) {
   $168 = HEAP32[$169>>2]|0;
   $170 = ($actorPrefetch$03>>>0)>($167>>>0);
   if ($170) {
    $actorPrefetch$1 = $actorPrefetch$03;
   } else {
    $171 = HEAP32[$actorPrefetch$03>>2]|0;
    $172 = $171;
    $173 = (_bitshift64Lshr(($172|0),0,6)|0);
    $174 = tempRet0;
    $175 = (_i64Add(($172|0),0,511,0)|0);
    $176 = tempRet0;
    $177 = (_bitshift64Lshr(($175|0),($176|0),6)|0);
    $178 = tempRet0;
    $179 = (_i64Subtract(1,0,($173|0),($174|0))|0);
    $180 = tempRet0;
    $181 = (_i64Add(($179|0),($180|0),($177|0),($178|0))|0);
    $182 = tempRet0;
    $184 = $181;$185 = $182;$cp$0$i = $171;
    while(1) {
     $183 = (($cp$0$i) + 64|0);
     $186 = (_i64Add(($184|0),($185|0),-1,-1)|0);
     $187 = tempRet0;
     $188 = ($186|0)==(0);
     $189 = ($187|0)==(0);
     $190 = $188 & $189;
     if ($190) {
      break;
     } else {
      $184 = $186;$185 = $187;$cp$0$i = $183;
     }
    }
    $191 = (($actorPrefetch$03) + 4|0);
    $actorPrefetch$1 = $191;
   }
   __ZN5physx2Sc7BodySim22updateCachedTransformsERNS_17PxsTransformCacheE($168,$145);
   $192 = (($169) + 4|0);
   $193 = ($192>>>0)<($149>>>0);
   if ($193) {
    $169 = $192;$actorPrefetch$03 = $actorPrefetch$1;
   } else {
    break;
   }
  }
 }
 $194 = HEAP32[$155>>2]|0;
 $195 = (($194) + 12|0);
 $196 = HEAP32[$195>>2]|0;
 FUNCTION_TABLE_viiii[$196 & 511]($155,104,$158,$161);
 $197 = (($this) + 108|0);
 $198 = HEAP32[$197>>2]|0;
 $199 = ($198|0)==(0);
 if (!($199)) {
  $200 = (($this) + 104|0);
  $i$02 = 0;
  while(1) {
   $201 = HEAP32[$200>>2]|0;
   $202 = (($201) + ($i$02<<2)|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = HEAP32[$203>>2]|0;
   __ZN5physx2Sc15ArticulationSim22updateCachedTransformsERNS_17PxsTransformCacheE($204,$145);
   $205 = (($i$02) + 1)|0;
   $206 = HEAP32[$197>>2]|0;
   $207 = ($205>>>0)<($206>>>0);
   if ($207) {
    $i$02 = $205;
   } else {
    break;
   }
  }
 }
 $208 = HEAP8[$151>>0]|0;
 $209 = ($208<<24>>24)==(0);
 if ($209) {
  $211 = HEAP32[$2>>2]|0;
  $212 = (($211) + 12|0);
  $213 = HEAP32[$212>>2]|0;
  FUNCTION_TABLE_viiii[$213 & 511]($2,103,$6,$9);
  STACKTOP = sp;return;
 }
 $210 = HEAP32[$secondPassBodies>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($secondPassBodies,$210);
 $211 = HEAP32[$2>>2]|0;
 $212 = (($211) + 12|0);
 $213 = HEAP32[$212>>2]|0;
 FUNCTION_TABLE_viiii[$213 & 511]($2,103,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene11postCCDPassEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $$pre12 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $ccdTouchCount = 0, $ccdTouches = 0, $i$07 = 0, $i3$05 = 0, $i5$03 = 0, $lostTouchCount = 0, $lostTouches = 0, $newTouchCount = 0, $newTouches = 0, $p$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $p$i = sp + 40|0;
 $newTouchCount = sp + 36|0;
 $lostTouchCount = sp + 32|0;
 $ccdTouchCount = sp + 16|0;
 $newTouches = sp + 8|0;
 $1 = sp + 58|0;
 $lostTouches = sp;
 $2 = sp + 56|0;
 $ccdTouches = sp + 24|0;
 $3 = sp + 57|0;
 $4 = (($this) + 1212|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 1000|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZNK5physx10PxsContext17getCurrentCCDPassEv($7)|0);
 (__ZNK5physx10PxsContext25getManagerTouchEventCountEPiS1_S1_($7,$newTouchCount,$lostTouchCount,$ccdTouchCount)|0);
 $9 = HEAP32[$newTouchCount>>2]|0;
 $10 = $9 << 3;
 $11 = ($10>>>0)>(1024);
 $12 = (($newTouches) + 4|0);
 $13 = $11&1;
 HEAP8[$12>>0] = $13;
 if ($11) {
  $14 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,$10,463960,1675)|0);
  HEAP32[$newTouches>>2] = $14;
 } else {
  $15 = STACKTOP; STACKTOP = STACKTOP + ((((1*$10)|0)+15)&-16)|0;;
  HEAP32[$newTouches>>2] = $15;
 }
 $16 = HEAP32[$lostTouchCount>>2]|0;
 $17 = $16 << 3;
 $18 = ($17>>>0)>(1024);
 $19 = (($lostTouches) + 4|0);
 $20 = $18&1;
 HEAP8[$19>>0] = $20;
 if ($18) {
  $21 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($2,$17,463960,1676)|0);
  HEAP32[$lostTouches>>2] = $21;
  $96 = $21;
 } else {
  $22 = STACKTOP; STACKTOP = STACKTOP + ((((1*$17)|0)+15)&-16)|0;;
  HEAP32[$lostTouches>>2] = $22;
  $96 = $22;
 }
 $23 = HEAP32[$ccdTouchCount>>2]|0;
 $24 = $23 << 3;
 $25 = ($24>>>0)>(1024);
 $26 = (($ccdTouches) + 4|0);
 $27 = $25&1;
 HEAP8[$26>>0] = $27;
 if ($25) {
  $28 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($3,$24,463960,1677)|0);
  HEAP32[$ccdTouches>>2] = $28;
  $$pre = HEAP32[$lostTouches>>2]|0;
  $$pre$phiZ2D = $lostTouches;$31 = $$pre;$32 = $28;
 } else {
  $29 = STACKTOP; STACKTOP = STACKTOP + ((((1*$24)|0)+15)&-16)|0;;
  HEAP32[$ccdTouches>>2] = $29;
  $$pre$phiZ2D = $lostTouches;$31 = $96;$32 = $29;
 }
 $30 = HEAP32[$newTouches>>2]|0;
 (__ZN5physx10PxsContext22fillManagerTouchEventsEPNS_27PxvContactManagerTouchEventERiS2_S3_S2_S3_($7,$30,$newTouchCount,$31,$lostTouchCount,$32,$ccdTouchCount)|0);
 $33 = HEAP32[$newTouchCount>>2]|0;
 $34 = ($33|0)>(0);
 L13: do {
  if ($34) {
   $44 = $30;$i$07 = 0;
   while(1) {
    $43 = ((($44) + ($i$07<<3)|0) + 4|0);
    $45 = HEAP32[$43>>2]|0;
    __ZN5physx2Sc19ShapeInstancePairLL15managerNewTouchEjb($45,$8,1);
    $46 = (($i$07) + 1)|0;
    $47 = HEAP32[$newTouchCount>>2]|0;
    $48 = ($46|0)<($47|0);
    if (!($48)) {
     break L13;
    }
    $$pre12 = HEAP32[$newTouches>>2]|0;
    $44 = $$pre12;$i$07 = $46;
   }
  }
 } while(0);
 $35 = HEAP32[$lostTouchCount>>2]|0;
 $36 = ($35|0)>(0);
 if ($36) {
  $37 = (($p$i) + 4|0);
  $38 = (($p$i) + 8|0);
  $39 = (($p$i) + 12|0);
  $40 = (($this) + 1248|0);
  $41 = (($this) + 1256|0);
  $42 = (($this) + 1252|0);
  $i3$05 = 0;
  while(1) {
   $51 = HEAP32[$$pre$phiZ2D>>2]|0;
   $52 = ((($51) + ($i3$05<<3)|0) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (__ZN5physx2Sc19ShapeInstancePairLL16managerLostTouchEjb($53,$8,1)|0);
   do {
    if ($54) {
     $55 = (($53) + 32|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($56)|0);
     $58 = (($53) + 36|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($59)|0);
     HEAP32[$p$i>>2] = $57;
     HEAP32[$37>>2] = $60;
     $61 = (($57) + 56|0);
     $62 = HEAP32[$61>>2]|0;
     HEAP32[$38>>2] = $62;
     $63 = (($60) + 56|0);
     $64 = HEAP32[$63>>2]|0;
     HEAP32[$39>>2] = $64;
     $65 = HEAP32[$41>>2]|0;
     $66 = $65 & 2147483647;
     $67 = HEAP32[$42>>2]|0;
     $68 = ($66>>>0)>($67>>>0);
     if (!($68)) {
      (__ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($40,$p$i)|0);
      break;
     }
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + ($67<<4)|0);
     $71 = ($70|0)==(0|0);
     if ($71) {
      $73 = $67;
     } else {
      ;HEAP32[$70+0>>2]=HEAP32[$p$i+0>>2]|0;HEAP32[$70+4>>2]=HEAP32[$p$i+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$p$i+8>>2]|0;HEAP32[$70+12>>2]=HEAP32[$p$i+12>>2]|0;
      $$pre$i$i = HEAP32[$42>>2]|0;
      $73 = $$pre$i$i;
     }
     $72 = (($73) + 1)|0;
     HEAP32[$42>>2] = $72;
    }
   } while(0);
   $74 = (($i3$05) + 1)|0;
   $75 = HEAP32[$lostTouchCount>>2]|0;
   $76 = ($74|0)<($75|0);
   if ($76) {
    $i3$05 = $74;
   } else {
    break;
   }
  }
 }
 $49 = HEAP32[$ccdTouchCount>>2]|0;
 $50 = ($49|0)>(0);
 if ($50) {
  $97 = $49;$i5$03 = 0;
  while(1) {
   $77 = HEAP32[$ccdTouches>>2]|0;
   $78 = ((($77) + ($i5$03<<3)|0) + 4|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($79) + 44|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = $81 & 32;
   $83 = ($82|0)==(0);
   if ($83) {
    $86 = $97;
   } else {
    __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($79,32,0,0,0,$8);
    $$pre10 = HEAP32[$ccdTouchCount>>2]|0;
    $86 = $$pre10;
   }
   $84 = (($i5$03) + 1)|0;
   $85 = ($84|0)<($86|0);
   if ($85) {
    $97 = $86;$i5$03 = $84;
   } else {
    break;
   }
  }
 }
 __ZN5physx2Sc5Scene11afterSolverEj($this,$8);
 $87 = HEAP8[$26>>0]|0;
 $88 = ($87<<24>>24)==(0);
 if (!($88)) {
  $89 = HEAP32[$ccdTouches>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($ccdTouches,$89);
 }
 $90 = HEAP8[$19>>0]|0;
 $91 = ($90<<24>>24)==(0);
 if (!($91)) {
  $92 = HEAP32[$$pre$phiZ2D>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($lostTouches,$92);
 }
 $93 = HEAP8[$12>>0]|0;
 $94 = ($93<<24>>24)==(0);
 if ($94) {
  STACKTOP = sp;return;
 }
 $95 = HEAP32[$newTouches>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($newTouches,$95);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene17finalizationPhaseEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$01$i = 0, $i$01$i = 0, $i$01$i3 = 0, $out$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $1 = sp + 104|0;
 $out$i = sp;
 $2 = (($this) + 1184|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 1176|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiii[$13 & 511]($3,115,$7,$10);
 $14 = HEAP32[$2>>2]|0;
 $15 = $4;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$14>>2]|0;
 $22 = (($21) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_viiii[$23 & 511]($14,107,$17,$20);
 $24 = (($this) + 192|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = (($this) + 188|0);
  $count$01$i = $25;
  while(1) {
   $28 = (($count$01$i) + -1)|0;
   $29 = HEAP32[$27>>2]|0;
   $30 = (($29) + ($28<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   __ZN5physx2Sc13ConstraintSim21checkMaxForceExceededEv($31);
   $32 = ($28|0)==(0);
   if ($32) {
    break;
   } else {
    $count$01$i = $28;
   }
  }
 }
 $33 = HEAP32[$14>>2]|0;
 $34 = (($33) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_viiii[$35 & 511]($14,107,$17,$20);
 $36 = (($this) + 132|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if (!($38)) {
  $39 = (($this) + 128|0);
  $i$01$i = 0;
  while(1) {
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + ($i$01$i<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   __ZN5physx2Sc17ParticleSystemSim7endStepEv($42);
   $43 = (($i$01$i) + 1)|0;
   $44 = HEAP32[$36>>2]|0;
   $45 = ($43>>>0)<($44>>>0);
   if ($45) {
    $i$01$i = $43;
   } else {
    break;
   }
  }
 }
 $46 = HEAP32[$2>>2]|0;
 $47 = $4;
 $48 = $47;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($47) + 4)|0;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$46>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 FUNCTION_TABLE_viiii[$55 & 511]($46,108,$49,$52);
 $56 = (($this) + 1416|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = $57 != Math_fround(0.0);
 if ($58) {
  $59 = (($this) + 1212|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 1000|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + 5928|0);
  $64 = (($out$i) + 36|0);
  dest=$out$i+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAPF32[$64>>2] = Math_fround(1.0);
  $65 = (($out$i) + 40|0);
  $66 = (($out$i) + 56|0);
  ;HEAP32[$65+0>>2]=0|0;HEAP32[$65+4>>2]=0|0;HEAP32[$65+8>>2]=0|0;HEAP32[$65+12>>2]=0|0;
  HEAPF32[$66>>2] = Math_fround(1.0);
  $67 = (($out$i) + 60|0);
  $68 = (($out$i) + 76|0);
  ;HEAP32[$67+0>>2]=0|0;HEAP32[$67+4>>2]=0|0;HEAP32[$67+8>>2]=0|0;HEAP32[$67+12>>2]=0|0;
  HEAPF32[$68>>2] = Math_fround(1.0);
  $69 = (($out$i) + 80|0);
  $70 = (($out$i) + 96|0);
  ;HEAP32[$69+0>>2]=0|0;HEAP32[$69+4>>2]=0|0;HEAP32[$69+8>>2]=0|0;HEAP32[$69+12>>2]=0|0;
  HEAPF32[$70>>2] = Math_fround(1.0);
  $71 = (($out$i) + 100|0);
  HEAP32[$71>>2] = $63;
  $72 = (($this) + 120|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==(0);
  if (!($74)) {
   $75 = (($this) + 116|0);
   $i$01$i3 = 0;
   while(1) {
    $76 = HEAP32[$75>>2]|0;
    $77 = (($76) + ($i$01$i3<<2)|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (__ZNK5physx2Sc18ParticleSystemCore6getSimEv($78)|0);
    __ZN5physx2Sc17ParticleSystemSim16visualizeEndStepERNS_2Cm12RenderOutputE($79,$out$i);
    $80 = (($i$01$i3) + 1)|0;
    $81 = HEAP32[$72>>2]|0;
    $82 = ($80>>>0)<($81>>>0);
    if ($82) {
     $i$01$i3 = $80;
    } else {
     break;
    }
   }
  }
 }
 $83 = HEAP32[$46>>2]|0;
 $84 = (($83) + 12|0);
 $85 = HEAP32[$84>>2]|0;
 FUNCTION_TABLE_viiii[$85 & 511]($46,108,$49,$52);
 $86 = (($this) + 2340|0);
 $87 = HEAP32[$86>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($87);
 $88 = (($this) + 2356|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + 2)|0;
 $91 = (($this) + 2348|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92>>>0)>($90>>>0);
 if (!($93)) {
  HEAP32[$88>>2] = 0;
  $102 = (($this) + 2360|0);
  HEAP32[$102>>2] = 0;
  $103 = HEAP32[$86>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($103);
  $104 = (($this) + 64|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($105) + 1)|0;
  HEAP32[$104>>2] = $106;
  $107 = HEAP32[$3>>2]|0;
  $108 = (($107) + 12|0);
  $109 = HEAP32[$108>>2]|0;
  FUNCTION_TABLE_viiii[$109 & 511]($3,115,$7,$10);
  STACKTOP = sp;return;
 }
 $94 = (($this) + 2344|0);
 $96 = $92;
 while(1) {
  $95 = (($96) + -1)|0;
  $97 = HEAP32[$94>>2]|0;
  $98 = (($97) + ($95<<2)|0);
  $99 = HEAP32[$98>>2]|0;
  HEAP32[$91>>2] = $95;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$99);
  $100 = HEAP32[$91>>2]|0;
  $101 = ($100>>>0)>($90>>>0);
  if ($101) {
   $96 = $100;
  } else {
   break;
  }
 }
 HEAP32[$88>>2] = 0;
 $102 = (($this) + 2360|0);
 HEAP32[$102>>2] = 0;
 $103 = HEAP32[$86>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($103);
 $104 = (($this) + 64|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($105) + 1)|0;
 HEAP32[$104>>2] = $106;
 $107 = HEAP32[$3>>2]|0;
 $108 = (($107) + 12|0);
 $109 = HEAP32[$108>>2]|0;
 FUNCTION_TABLE_viiii[$109 & 511]($3,115,$7,$10);
 STACKTOP = sp;return;
}
function __ZN5physx17PxsThresholdTable5buildERKNS_18PxsThresholdStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$phi24Z2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$011 = 0, $or$cond = 0, $pairIndex$0 = 0, $pairIndex$010 = 0, $pairIndex$09 = 0, $pairsSize$013 = 0, $pairsSize$1 = 0, $prevPairIndex$0$lcssa = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($stream) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = (($this) + 24|0);
  HEAP32[$6>>2] = 0;
  $7 = (($this) + 28|0);
  HEAP32[$7>>2] = 0;
  $8 = (($this) + 8|0);
  HEAP32[$8>>2] = 0;
  $9 = (($this) + 12|0);
  HEAP32[$9>>2] = 0;
  $10 = HEAP32[$this>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$10);
  }
  HEAP32[$this>>2] = 0;
  STACKTOP = sp;return;
 }
 $12 = $4 << 1;
 $13 = $12 | 1;
 $14 = (($this) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($4>>>0)>($15>>>0);
 $17 = $15 >>> 2;
 $18 = ($4>>>0)<($17>>>0);
 $or$cond = $16 | $18;
 if ($or$cond) {
  $19 = HEAP32[$this>>2]|0;
  $20 = ($19|0)==(0|0);
  if (!($20)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$19);
  }
  $21 = $4 << 3;
  $22 = $4 << 2;
  $23 = $13 << 2;
  $24 = (($21) + ($22))|0;
  $25 = (($23) + ($24))|0;
  $26 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$25,471776,101)|0);
  HEAP32[$this>>2] = $26;
  $27 = (($this) + 16|0);
  HEAP32[$27>>2] = $26;
  $28 = (($26) + ($21)|0);
  $29 = (($this) + 20|0);
  HEAP32[$29>>2] = $28;
  $30 = (($26) + ($24)|0);
  $31 = (($this) + 4|0);
  HEAP32[$31>>2] = $30;
  HEAP32[$14>>2] = $4;
  $32 = (($this) + 12|0);
  HEAP32[$32>>2] = $13;
  $$pre$phi24Z2D = $29;$$pre$phi26Z2D = $27;$$pre$phiZ2D = $23;$34 = $30;
 } else {
  $$phi$trans$insert = (($this) + 4|0);
  $$pre21 = HEAP32[$$phi$trans$insert>>2]|0;
  $$pre22 = $13 << 2;
  $$pre23 = (($this) + 20|0);
  $$pre25 = (($this) + 16|0);
  $$pre$phi24Z2D = $$pre23;$$pre$phi26Z2D = $$pre25;$$pre$phiZ2D = $$pre22;$34 = $$pre21;
 }
 $33 = (($this) + 4|0);
 _memset(($34|0),-1,($$pre$phiZ2D|0))|0;
 $35 = (($this) + 24|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 8|0);
 HEAP32[$36>>2] = $13;
 $37 = HEAP32[$33>>2]|0;
 $38 = HEAP32[$$pre$phi24Z2D>>2]|0;
 $39 = HEAP32[$$pre$phi26Z2D>>2]|0;
 $$pre = HEAP32[$stream>>2]|0;
 $i$011 = 0;$pairsSize$013 = 0;
 while(1) {
  $40 = (($$pre) + ($i$011<<4)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($$pre) + ($i$011<<4)|0) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($$pre) + ($i$011<<4)|0) + 8|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = $41;
  $47 = $43;
  $48 = $47 ^ -1;
  $49 = (_i64Add(($47|0),($46|0),-1,($48|0))|0);
  $50 = tempRet0;
  $51 = (_bitshift64Lshr(($49|0),($50|0),22)|0);
  $52 = tempRet0;
  $53 = $51 ^ $49;
  $54 = $52 ^ $50;
  $55 = (_bitshift64Shl(($53|0),($54|0),13)|0);
  $56 = tempRet0;
  $57 = $55 ^ -1;
  $58 = $56 ^ -1;
  $59 = (_i64Add(($53|0),($54|0),($57|0),($58|0))|0);
  $60 = tempRet0;
  $61 = (_bitshift64Lshr(($59|0),($60|0),8)|0);
  $62 = tempRet0;
  $63 = $61 ^ $59;
  $64 = $62 ^ $60;
  $65 = (___muldi3(($63|0),($64|0),9,0)|0);
  $66 = tempRet0;
  $67 = (_bitshift64Lshr(($65|0),($66|0),15)|0);
  $68 = tempRet0;
  $69 = $67 ^ $65;
  $70 = $68 ^ $66;
  $71 = (_bitshift64Shl(($69|0),($70|0),27)|0);
  $72 = tempRet0;
  $73 = $71 ^ -1;
  $74 = $72 ^ -1;
  $75 = (_i64Add(($69|0),($70|0),($73|0),($74|0))|0);
  $76 = tempRet0;
  $77 = (_bitshift64Lshr(($75|0),($76|0),31)|0);
  $78 = tempRet0;
  $79 = $77 ^ $75;
  $78 ^ $76;
  $80 = (($79>>>0) % ($13>>>0))&-1;
  $81 = (($37) + ($80<<2)|0);
  $pairIndex$09 = HEAP32[$81>>2]|0;
  $82 = ($pairIndex$09|0)==(-1);
  L17: do {
   if ($82) {
    $prevPairIndex$0$lcssa = $80;
    label = 16;
   } else {
    $pairIndex$010 = $pairIndex$09;
    while(1) {
     $83 = (($39) + ($pairIndex$010<<3)|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = (($$pre) + ($84<<4)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($41|0)==($86|0);
     if ($87) {
      $88 = ((($$pre) + ($84<<4)|0) + 4|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($43|0)==($89|0);
      if ($90) {
       break;
      }
     }
     $94 = (($38) + ($pairIndex$010<<2)|0);
     $pairIndex$0 = HEAP32[$94>>2]|0;
     $95 = ($pairIndex$0|0)==(-1);
     if ($95) {
      $prevPairIndex$0$lcssa = $pairIndex$010;
      label = 16;
      break L17;
     } else {
      $pairIndex$010 = $pairIndex$0;
     }
    }
    $91 = ((($39) + ($pairIndex$010<<3)|0) + 4|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = Math_fround($45 + $92);
    HEAPF32[$91>>2] = $93;
    $pairsSize$1 = $pairsSize$013;
   }
  } while(0);
  if ((label|0) == 16) {
   label = 0;
   $96 = ($prevPairIndex$0$lcssa|0)==(-1);
   if ($96) {
    $pairsSize$1 = $pairsSize$013;
   } else {
    HEAP32[$81>>2] = $pairsSize$013;
    $97 = (($38) + ($pairsSize$013<<2)|0);
    HEAP32[$97>>2] = -1;
    $98 = (($39) + ($pairsSize$013<<3)|0);
    HEAP32[$98>>2] = $i$011;
    $99 = ((($39) + ($pairsSize$013<<3)|0) + 4|0);
    HEAPF32[$99>>2] = $45;
    $100 = (($pairsSize$013) + 1)|0;
    $pairsSize$1 = $100;
   }
  }
  $101 = (($i$011) + 1)|0;
  $exitcond = ($101|0)==($4|0);
  if ($exitcond) {
   break;
  } else {
   $i$011 = $101;$pairsSize$013 = $pairsSize$1;
  }
 }
 HEAP32[$35>>2] = $pairsSize$1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene24resizeReleasedBodyIDMapsEjj($this,$maxActors,$numActors) {
 $this = $this|0;
 $maxActors = $maxActors|0;
 $numActors = $numActors|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($maxActors) + 31)|0;
 $1 = $0 >>> 5;
 $2 = (($this) + 1264|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($1>>>0)>($4>>>0);
 if ($5) {
  $6 = (($this) + 1268|0);
  $7 = $1 << 2;
  $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($6,$7,471576,339)|0);
  $9 = (($this) + 1260|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$2>>2]|0;
   $13 = $12 << 2;
   _memcpy(($8|0),($10|0),($13|0))|0;
   $14 = HEAP32[$2>>2]|0;
   $15 = ($14|0)>(-1);
   if ($15) {
    $16 = HEAP32[$9>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$16);
   }
  }
  $17 = HEAP32[$2>>2]|0;
  $18 = $17 & 2147483647;
  $19 = (($8) + ($18<<2)|0);
  $20 = (($1) - ($17))|0;
  $21 = $20 << 2;
  _memset(($19|0),0,($21|0))|0;
  HEAP32[$9>>2] = $8;
  HEAP32[$2>>2] = $1;
 }
 $22 = (($this) + 1208|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($1>>>0)>($26>>>0);
 if ($27) {
  $28 = (($23) + 24|0);
  $29 = $1 << 2;
  $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($28,$29,471576,339)|0);
  $31 = (($23) + 16|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $34 = HEAP32[$24>>2]|0;
   $35 = $34 << 2;
   _memcpy(($30|0),($32|0),($35|0))|0;
   $36 = HEAP32[$24>>2]|0;
   $37 = ($36|0)>(-1);
   if ($37) {
    $38 = HEAP32[$31>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($28,$38);
   }
  }
  $39 = HEAP32[$24>>2]|0;
  $40 = $39 & 2147483647;
  $41 = (($30) + ($40<<2)|0);
  $42 = (($1) - ($39))|0;
  $43 = $42 << 2;
  _memset(($41|0),0,($43|0))|0;
  HEAP32[$31>>2] = $30;
  HEAP32[$24>>2] = $1;
 }
 $44 = (($23) + 36|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45 & 2147483647;
 $47 = ($46>>>0)<($numActors>>>0);
 if ($47) {
  $48 = (($23) + 28|0);
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($48,$numActors);
 }
 $49 = (($this) + 1204|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 20|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 & 2147483647;
 $54 = ($1>>>0)>($53>>>0);
 if ($54) {
  $55 = (($50) + 24|0);
  $56 = $1 << 2;
  $57 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($55,$56,471576,339)|0);
  $58 = (($50) + 16|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59|0)==(0|0);
  if (!($60)) {
   $61 = HEAP32[$51>>2]|0;
   $62 = $61 << 2;
   _memcpy(($57|0),($59|0),($62|0))|0;
   $63 = HEAP32[$51>>2]|0;
   $64 = ($63|0)>(-1);
   if ($64) {
    $65 = HEAP32[$58>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($55,$65);
   }
  }
  $66 = HEAP32[$51>>2]|0;
  $67 = $66 & 2147483647;
  $68 = (($57) + ($67<<2)|0);
  $69 = (($1) - ($66))|0;
  $70 = $69 << 2;
  _memset(($68|0),0,($70|0))|0;
  HEAP32[$58>>2] = $57;
  HEAP32[$51>>2] = $1;
 }
 $71 = (($50) + 36|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $72 & 2147483647;
 $74 = ($73>>>0)<($numActors>>>0);
 if (!($74)) {
  STACKTOP = sp;return;
 }
 $75 = (($50) + 28|0);
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($75,$numActors);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($this,$param) {
 $this = $this|0;
 $param = $param|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (Math_fround(__ZNK5physx10PxsContext25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($3,$param)));
 STACKTOP = sp;return (Math_fround($4));
}
function __ZNK5physx2Sc5Scene22getClientBehaviorFlagsEh($agg$result,$this,$client) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $client = $client|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $client&255;
 $1 = (($this) + 1164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 12|0);
 $6 = HEAP8[$5>>0]|0;
 HEAP8[$agg$result>>0] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene29fireBrokenConstraintCallbacksEv($this) {
 $this = $this|0;
 var $$ = 0, $$13 = 0, $$15 = 0, $$idx$val = 0, $$idx$val16 = 0, $$idx$val16$pre = 0, $$idx1$val = 0, $$idx4$val = 0, $$pre = 0, $$pre$i = 0, $$pre$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $activeClientLimit$0$lcssa = 0, $activeClientLimit$023 = 0, $activeClientLimit$1 = 0, $activeClientLimit$2 = 0, $activeClients = 0, $brmerge = 0, $d = 0, $exitcond = 0, $exitcond26 = 0, $i$022 = 0;
 var $i1$019 = 0, $j$017 = 0, $notifyArray = 0, $notlhs = 0, $notrhs = 0, $or$cond$i = 0, $or$cond$i$i$i = 0, $or$cond$not = 0, $or$cond14 = 0, $perClientArray = 0, $this$idx$val$i = 0, $this$idx$val$i8 = 0, $typeID = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1024|0;
 $notifyArray = sp + 488|0;
 $activeClients = sp;
 $typeID = sp + 64|0;
 $d = sp + 72|0;
 $perClientArray = sp + 88|0;
 $0 = (($this) + 180|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($notifyArray) + 512|0);
 $3 = (($notifyArray) + 516|0);
 $4 = (($notifyArray) + 520|0);
 HEAP32[$4>>2] = 0;
 $5 = (($notifyArray) + 524|0);
 HEAP8[$2>>0] = 1;
 HEAP32[$3>>2] = $notifyArray;
 HEAP32[$5>>2] = 32;
 $6 = ($1>>>0)>(32);
 if ($6) {
  __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_126BrokenConstraintReportDataENS0_15InlineAllocatorILj512ENS0_13TempAllocatorEEEE8recreateEj($notifyArray,$1);
  ;HEAP32[$activeClients+0>>2]=0|0;HEAP32[$activeClients+4>>2]=0|0;HEAP32[$activeClients+8>>2]=0|0;HEAP32[$activeClients+12>>2]=0|0;
  $177 = $activeClients;
  label = 4;
 } else {
  ;HEAP32[$activeClients+0>>2]=0|0;HEAP32[$activeClients+4>>2]=0|0;HEAP32[$activeClients+8>>2]=0|0;HEAP32[$activeClients+12>>2]=0|0;
  $7 = ($1|0)==(0);
  if ($7) {
   $178 = $activeClients;$activeClientLimit$0$lcssa = 0;
  } else {
   $177 = $activeClients;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $8 = (($this) + 176|0);
  $9 = (($this) + 1216|0);
  $10 = (($this) + 1164|0);
  $11 = (($d) + 4|0);
  $12 = (($d) + 8|0);
  $13 = (($d) + 12|0);
  $14 = (($d) + 14|0);
  $activeClientLimit$023 = 0;$i$022 = 0;
  while(1) {
   $15 = HEAP32[$8>>2]|0;
   $16 = (($15) + ($i$022<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 64|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $activeClientLimit$2 = $activeClientLimit$023;
   } else {
    $21 = (__ZN5physx2Sc13ConstraintSim8getRigidEj($19,0)|0);
    $22 = HEAP32[$9>>2]|0;
    $23 = ($21|0)==($22|0);
    if ($23) {
     $37 = 0;
    } else {
     $24 = HEAP32[$18>>2]|0;
     $25 = (__ZN5physx2Sc13ConstraintSim8getRigidEj($24,0)|0);
     $26 = (($25) + 52|0);
     $27 = HEAP32[$26>>2]|0;
     $37 = $27;
    }
    $28 = HEAP32[$18>>2]|0;
    $29 = (__ZN5physx2Sc13ConstraintSim8getRigidEj($28,1)|0);
    $30 = HEAP32[$9>>2]|0;
    $31 = ($29|0)==($30|0);
    if ($31) {
     $41 = 0;
    } else {
     $32 = HEAP32[$18>>2]|0;
     $33 = (__ZN5physx2Sc13ConstraintSim8getRigidEj($32,1)|0);
     $34 = (($33) + 52|0);
     $35 = HEAP32[$34>>2]|0;
     $41 = $35;
    }
    $36 = ($37|0)!=(0|0);
    if ($36) {
     $38 = (($37) + 13|0);
     $39 = HEAP8[$38>>0]|0;
     $51 = $39;
    } else {
     $51 = 0;
    }
    $40 = ($41|0)!=(0|0);
    if ($40) {
     $42 = (($41) + 13|0);
     $43 = HEAP8[$42>>0]|0;
     $59 = $43;
    } else {
     $59 = 0;
    }
    if ($36) {
     $44 = (($37) + 11|0);
     $45 = HEAP8[$44>>0]|0;
     $46 = $45 & 4;
     $75 = $46;
    } else {
     $75 = 0;
    }
    if ($40) {
     $47 = (($41) + 11|0);
     $48 = HEAP8[$47>>0]|0;
     $49 = $48 & 4;
     $71 = $49;
    } else {
     $71 = 0;
    }
    $50 = $51&255;
    $52 = HEAP32[$10>>2]|0;
    $53 = (($52) + ($50<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP8[$55>>0]|0;
    $57 = $56 & 4;
    $58 = $59&255;
    $60 = (($52) + ($58<<2)|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61) + 12|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = $63 & 4;
    $65 = (($54) + 16|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    if ($67) {
     $77 = 0;
    } else {
     $68 = ($51<<24>>24)==($59<<24>>24);
     if ($68) {
      $77 = 1;
     } else {
      $69 = ($57<<24>>24)!=(0);
      $70 = ($71<<24>>24)!=(0);
      $$13 = $69 & $70;
      $77 = $$13;
     }
    }
    $72 = (($61) + 16|0);
    $73 = HEAP32[$72>>2]|0;
    $notlhs = ($73|0)!=(0|0);
    $notrhs = ($51<<24>>24)!=($59<<24>>24);
    $or$cond$not = $notrhs & $notlhs;
    $74 = ($75<<24>>24)!=(0);
    $or$cond14 = $or$cond$not & $74;
    $76 = ($64<<24>>24)!=(0);
    $$15 = $or$cond14 & $76;
    $brmerge = $77 | $$15;
    if ($brmerge) {
     HEAP32[$typeID>>2] = -1;
     $78 = (($17) + 28|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = HEAP32[$79>>2]|0;
     $81 = (($80) + 20|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = (FUNCTION_TABLE_iii[$82 & 4095]($79,$typeID)|0);
     $84 = (__ZN5physx2Sc14ConstraintCore15getPxConstraintEv($17)|0);
     $85 = HEAP32[$typeID>>2]|0;
     $86 = $51&255;
     $$ = $77 ? $86 : -1;
     $87 = $59&255;
     $88 = $$15 ? $87 : -1;
     HEAP32[$d>>2] = $84;
     HEAP32[$11>>2] = $83;
     HEAP32[$12>>2] = $85;
     HEAP16[$13>>1] = $$;
     HEAP16[$14>>1] = $88;
     $this$idx$val$i8 = HEAP32[$5>>2]|0;
     $89 = $this$idx$val$i8 & 2147483647;
     $90 = HEAP32[$4>>2]|0;
     $91 = ($89>>>0)>($90>>>0);
     if ($91) {
      $92 = HEAP32[$3>>2]|0;
      $93 = (($92) + ($90<<4)|0);
      $94 = ($93|0)==(0|0);
      if ($94) {
       $96 = $90;
      } else {
       ;HEAP32[$93+0>>2]=HEAP32[$d+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$d+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$d+8>>2]|0;HEAP32[$93+12>>2]=HEAP32[$d+12>>2]|0;
       $$pre$i9 = HEAP32[$4>>2]|0;
       $96 = $$pre$i9;
      }
      $95 = (($96) + 1)|0;
      HEAP32[$4>>2] = $95;
     } else {
      (__ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_126BrokenConstraintReportDataENS0_15InlineAllocatorILj512ENS0_13TempAllocatorEEEE15growAndPushBackERKS3_($notifyArray,$d)|0);
     }
     if ($77) {
      $97 = $50 & 7;
      $98 = 1 << $97;
      $99 = $50 >>> 3;
      $100 = (($activeClients) + ($99<<2)|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = $101 | $98;
      HEAP32[$100>>2] = $102;
      $103 = (($50) + 1)|0;
      $104 = $103&65535;
      $105 = ($104&65535)<($activeClientLimit$023&65535);
      $106 = $105 ? $activeClientLimit$023 : $104;
      $activeClientLimit$1 = $106;
     } else {
      $activeClientLimit$1 = $activeClientLimit$023;
     }
     if ($$15) {
      $107 = $58 & 7;
      $108 = 1 << $107;
      $109 = $58 >>> 3;
      $110 = (($activeClients) + ($109<<2)|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = $111 | $108;
      HEAP32[$110>>2] = $112;
      $113 = (($58) + 1)|0;
      $114 = $113&65535;
      $115 = ($114&65535)<($activeClientLimit$1&65535);
      $116 = $115 ? $activeClientLimit$1 : $114;
      $activeClientLimit$2 = $116;
     } else {
      $activeClientLimit$2 = $activeClientLimit$1;
     }
    } else {
     $activeClientLimit$2 = $activeClientLimit$023;
    }
   }
   $117 = (($i$022) + 1)|0;
   $exitcond26 = ($117|0)==($1|0);
   if ($exitcond26) {
    $178 = $177;$activeClientLimit$0$lcssa = $activeClientLimit$2;
    break;
   } else {
    $activeClientLimit$023 = $activeClientLimit$2;$i$022 = $117;
   }
  }
 }
 $118 = (($perClientArray) + 384|0);
 $119 = (($perClientArray) + 388|0);
 $120 = (($perClientArray) + 392|0);
 HEAP32[$120>>2] = 0;
 $121 = (($perClientArray) + 396|0);
 HEAP8[$118>>0] = 1;
 HEAP32[$119>>2] = $perClientArray;
 HEAP32[$121>>2] = 32;
 $122 = ($activeClientLimit$0$lcssa<<16>>16)==(0);
 if ($122) {
  $167 = 32;
 } else {
  $123 = (($this) + 1164|0);
  $124 = $activeClientLimit$0$lcssa&65535;
  $i1$019 = 0;
  while(1) {
   $125 = $i1$019 >>> 3;
   $126 = (($activeClients) + ($125<<2)|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = $i1$019 & 7;
   $129 = 1 << $128;
   $130 = $127 & $129;
   $131 = ($130|0)==(0);
   if (!($131)) {
    HEAP32[$120>>2] = 0;
    $$idx1$val = HEAP32[$4>>2]|0;
    $132 = HEAP32[$121>>2]|0;
    $133 = $132 & 2147483647;
    $134 = ($133>>>0)<($$idx1$val>>>0);
    if ($134) {
     __ZN5physx6shdfnd5ArrayINS_16PxConstraintInfoENS0_15InlineAllocatorILj384ENS0_13TempAllocatorEEEE8recreateEj($perClientArray,$$idx1$val);
     $$idx$val16$pre = HEAP32[$4>>2]|0;
     $$idx$val16 = $$idx$val16$pre;
    } else {
     $$idx$val16 = $$idx1$val;
    }
    $135 = ($$idx$val16|0)==(0);
    if (!($135)) {
     $j$017 = 0;
     while(1) {
      $$idx4$val = HEAP32[$3>>2]|0;
      $136 = ((($$idx4$val) + ($j$017<<4)|0) + 12|0);
      $137 = HEAP16[$136>>1]|0;
      $138 = $137&65535;
      $139 = ($138|0)==($i1$019|0);
      if ($139) {
       label = 40;
      } else {
       $140 = ((($$idx4$val) + ($j$017<<4)|0) + 14|0);
       $141 = HEAP16[$140>>1]|0;
       $142 = $141&65535;
       $143 = ($142|0)==($i1$019|0);
       if ($143) {
        label = 40;
       }
      }
      do {
       if ((label|0) == 40) {
        label = 0;
        $144 = (($$idx4$val) + ($j$017<<4)|0);
        $145 = HEAP32[$121>>2]|0;
        $146 = $145 & 2147483647;
        $147 = HEAP32[$120>>2]|0;
        $148 = ($146>>>0)>($147>>>0);
        if (!($148)) {
         (__ZN5physx6shdfnd5ArrayINS_16PxConstraintInfoENS0_15InlineAllocatorILj384ENS0_13TempAllocatorEEEE15growAndPushBackERKS2_($perClientArray,$144)|0);
         break;
        }
        $149 = HEAP32[$119>>2]|0;
        $150 = (($149) + (($147*12)|0)|0);
        $151 = ($150|0)==(0|0);
        if ($151) {
         $153 = $147;
        } else {
         ;HEAP32[$150+0>>2]=HEAP32[$144+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$144+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$144+8>>2]|0;
         $$pre$i = HEAP32[$120>>2]|0;
         $153 = $$pre$i;
        }
        $152 = (($153) + 1)|0;
        HEAP32[$120>>2] = $152;
       }
      } while(0);
      $154 = (($j$017) + 1)|0;
      $$idx$val = HEAP32[$4>>2]|0;
      $155 = ($154>>>0)<($$idx$val>>>0);
      if ($155) {
       $j$017 = $154;
      } else {
       break;
      }
     }
    }
    $156 = HEAP32[$123>>2]|0;
    $157 = (($156) + ($i1$019<<2)|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($158) + 16|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = HEAP32[$160>>2]|0;
    $162 = HEAP32[$161>>2]|0;
    $163 = HEAP32[$119>>2]|0;
    $164 = HEAP32[$120>>2]|0;
    FUNCTION_TABLE_viii[$162 & 4095]($160,$163,$164);
   }
   $165 = (($i1$019) + 1)|0;
   $exitcond = ($165|0)==($124|0);
   if ($exitcond) {
    break;
   } else {
    $i1$019 = $165;
   }
  }
  $$pre = HEAP32[$121>>2]|0;
  $167 = $$pre;
 }
 $166 = $167 & 2147483647;
 $168 = ($166|0)!=(0);
 $169 = ($167|0)>(-1);
 $or$cond$i$i$i = $168 & $169;
 do {
  if ($or$cond$i$i$i) {
   $170 = HEAP32[$119>>2]|0;
   $171 = ($perClientArray|0)==($170|0);
   if ($171) {
    HEAP8[$118>>0] = 0;
    break;
   } else {
    __ZN5physx6shdfnd13TempAllocator10deallocateEPv($perClientArray,$170);
    break;
   }
  }
 } while(0);
 $this$idx$val$i = HEAP32[$5>>2]|0;
 $172 = $this$idx$val$i & 2147483647;
 $173 = ($172|0)!=(0);
 $174 = ($this$idx$val$i|0)>(-1);
 $or$cond$i = $173 & $174;
 if (!($or$cond$i)) {
  STACKTOP = sp;return;
 }
 $175 = HEAP32[$3>>2]|0;
 $176 = ($notifyArray|0)==($175|0);
 if ($176) {
  HEAP8[$2>>0] = 0;
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($notifyArray,$175);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc5Scene20fireCallBacksPreSyncEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc5Scene29fireBrokenConstraintCallbacksEv($this);
 __ZN5physx2Sc5Scene20fireTriggerCallbacksEv($this);
 __ZN5physx2Sc5Scene26fireQueuedContactCallbacksEb($this,0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene21fireCallBacksPostSyncEv($this) {
 $this = $this|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $destSlot$023 = 0, $destSlot$1 = 0, $destSlot$2 = 0, $destSlot1$016 = 0, $destSlot1$1 = 0, $destSlot1$2 = 0, $exitcond = 0;
 var $exitcond30 = 0, $i$0$ph1$i$i = 0, $i$0$ph1$i$i7 = 0, $i$022 = 0, $i$03$i = 0, $i1$01$i = 0, $i3$018 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0, $prevClient$021 = 0, $prevClient$1 = 0, $prevClient2$017 = 0, $prevClient2$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 1161|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 1140|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  L3: do {
   if (!($7)) {
    $8 = (($this) + 1136|0);
    $i$0$ph1$i$i = 0;
    while(1) {
     while(1) {
      $9 = HEAP32[$8>>2]|0;
      $10 = (($9) + ($i$0$ph1$i$i<<2)|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (__ZNK5physx2Sc8BodyCore6getSimEv($11)|0);
      $13 = (($12) + 144|0);
      $14 = HEAP16[$13>>1]|0;
      $15 = $14 & 128;
      $16 = ($15<<16>>16)==(0);
      if ($16) {
       break;
      }
      $17 = HEAP32[$5>>2]|0;
      $18 = (($17) + -1)|0;
      HEAP32[$5>>2] = $18;
      $19 = HEAP32[$8>>2]|0;
      $20 = (($19) + ($18<<2)|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($i$0$ph1$i$i<<2)|0);
      HEAP32[$22>>2] = $21;
      $23 = ($i$0$ph1$i$i>>>0)<($18>>>0);
      if (!($23)) {
       break L3;
      }
     }
     $24 = (($i$0$ph1$i$i) + 1)|0;
     $25 = HEAP32[$5>>2]|0;
     $26 = ($24>>>0)<($25>>>0);
     if ($26) {
      $i$0$ph1$i$i = $24;
     } else {
      break;
     }
    }
   }
  } while(0);
  HEAP8[$2>>0] = 1;
 }
 $27 = (($this) + 1160|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 $30 = (($this) + 1152|0);
 $31 = HEAP32[$30>>2]|0;
 if ($29) {
  $32 = ($31|0)==(0);
  L15: do {
   if ($32) {
    $171 = 0;
   } else {
    $33 = (($this) + 1148|0);
    $i$0$ph1$i$i7 = 0;
    while(1) {
     while(1) {
      $34 = HEAP32[$33>>2]|0;
      $35 = (($34) + ($i$0$ph1$i$i7<<2)|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (__ZNK5physx2Sc8BodyCore6getSimEv($36)|0);
      $38 = (($37) + 144|0);
      $39 = HEAP16[$38>>1]|0;
      $40 = $39 & 64;
      $41 = ($40<<16>>16)==(0);
      if ($41) {
       break;
      }
      $42 = HEAP32[$30>>2]|0;
      $43 = (($42) + -1)|0;
      HEAP32[$30>>2] = $43;
      $44 = HEAP32[$33>>2]|0;
      $45 = (($44) + ($43<<2)|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = (($44) + ($i$0$ph1$i$i7<<2)|0);
      HEAP32[$47>>2] = $46;
      $48 = ($i$0$ph1$i$i7>>>0)<($43>>>0);
      if (!($48)) {
       $171 = $43;
       break L15;
      }
     }
     $49 = (($i$0$ph1$i$i7) + 1)|0;
     $50 = HEAP32[$30>>2]|0;
     $51 = ($49>>>0)<($50>>>0);
     if ($51) {
      $i$0$ph1$i$i7 = $49;
     } else {
      $171 = $50;
      break;
     }
    }
   }
  } while(0);
  HEAP8[$27>>0] = 1;
  $56 = $171;
 } else {
  $56 = $31;
 }
 $52 = (($this) + 1140|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 1152|0);
 $55 = ($53>>>0)<($56>>>0);
 $57 = $55 ? $56 : $53;
 $58 = ($57|0)==(0);
 if ($58) {
  $141 = $53;$170 = 0;
 } else {
  $59 = $57 << 2;
  $60 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$59,463960,2599)|0);
  $61 = ($53|0)==(0);
  $62 = ($60|0)==(0|0);
  $or$cond = $61 | $62;
  if (!($or$cond)) {
   $63 = (($this) + 1136|0);
   $64 = (($this) + 1164|0);
   $destSlot$023 = 0;$i$022 = 0;$prevClient$021 = -1;
   while(1) {
    $65 = HEAP32[$63>>2]|0;
    $66 = (($65) + ($i$022<<2)|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($67) + 13|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = ($prevClient$021<<24>>24)==($69<<24>>24);
    if ($70) {
     $destSlot$1 = $destSlot$023;$prevClient$1 = $prevClient$021;
    } else {
     $71 = $69&255;
     $72 = HEAP32[$64>>2]|0;
     $73 = (($72) + ($71<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($74) + 16|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==(0|0);
     $78 = ($destSlot$023|0)==(0);
     $or$cond1 = $77 | $78;
     if ($or$cond1) {
      $destSlot$1 = 0;$prevClient$1 = $69;
     } else {
      $79 = HEAP32[$76>>2]|0;
      $80 = (($79) + 8|0);
      $81 = HEAP32[$80>>2]|0;
      FUNCTION_TABLE_viii[$81 & 4095]($76,$60,$destSlot$023);
      $destSlot$1 = 0;$prevClient$1 = $69;
     }
    }
    $82 = (($67) + 8|0);
    $83 = HEAP16[$82>>1]|0;
    $84 = $83 & 4;
    $85 = ($84<<16>>16)==(0);
    if ($85) {
     $destSlot$2 = $destSlot$1;
    } else {
     $86 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($67)|0);
     $87 = (($destSlot$1) + 1)|0;
     $88 = (($60) + ($destSlot$1<<2)|0);
     HEAP32[$88>>2] = $86;
     $destSlot$2 = $87;
    }
    $89 = (($i$022) + 1)|0;
    $exitcond30 = ($89|0)==($53|0);
    if ($exitcond30) {
     break;
    } else {
     $destSlot$023 = $destSlot$2;$i$022 = $89;$prevClient$021 = $prevClient$1;
    }
   }
   $90 = $prevClient$1&255;
   $91 = HEAP32[$64>>2]|0;
   $92 = (($91) + ($90<<2)|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + 16|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)==(0|0);
   $97 = ($destSlot$2|0)==(0);
   $or$cond2 = $96 | $97;
   if (!($or$cond2)) {
    $98 = HEAP32[$95>>2]|0;
    $99 = (($98) + 8|0);
    $100 = HEAP32[$99>>2]|0;
    FUNCTION_TABLE_viii[$100 & 4095]($95,$60,$destSlot$2);
   }
  }
  $101 = ($56|0)==(0);
  $or$cond3 = $101 | $62;
  if (!($or$cond3)) {
   $102 = (($this) + 1148|0);
   $103 = (($this) + 1164|0);
   $destSlot1$016 = 0;$i3$018 = 0;$prevClient2$017 = -1;
   while(1) {
    $104 = HEAP32[$102>>2]|0;
    $105 = (($104) + ($i3$018<<2)|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = (($106) + 13|0);
    $108 = HEAP8[$107>>0]|0;
    $109 = ($prevClient2$017<<24>>24)==($108<<24>>24);
    if ($109) {
     $destSlot1$1 = $destSlot1$016;$prevClient2$1 = $prevClient2$017;
    } else {
     $110 = $108&255;
     $111 = HEAP32[$103>>2]|0;
     $112 = (($111) + ($110<<2)|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = (($113) + 16|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = ($115|0)==(0|0);
     $117 = ($destSlot1$016|0)==(0);
     $or$cond4 = $116 | $117;
     if ($or$cond4) {
      $destSlot1$1 = 0;$prevClient2$1 = $108;
     } else {
      $118 = HEAP32[$115>>2]|0;
      $119 = (($118) + 4|0);
      $120 = HEAP32[$119>>2]|0;
      FUNCTION_TABLE_viii[$120 & 4095]($115,$60,$destSlot1$016);
      $destSlot1$1 = 0;$prevClient2$1 = $108;
     }
    }
    $121 = (($106) + 8|0);
    $122 = HEAP16[$121>>1]|0;
    $123 = $122 & 4;
    $124 = ($123<<16>>16)==(0);
    if ($124) {
     $destSlot1$2 = $destSlot1$1;
    } else {
     $125 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($106)|0);
     $126 = (($destSlot1$1) + 1)|0;
     $127 = (($60) + ($destSlot1$1<<2)|0);
     HEAP32[$127>>2] = $125;
     $destSlot1$2 = $126;
    }
    $128 = (($i3$018) + 1)|0;
    $exitcond = ($128|0)==($56|0);
    if ($exitcond) {
     break;
    } else {
     $destSlot1$016 = $destSlot1$2;$i3$018 = $128;$prevClient2$017 = $prevClient2$1;
    }
   }
   $129 = $prevClient2$1&255;
   $130 = HEAP32[$103>>2]|0;
   $131 = (($130) + ($129<<2)|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = (($132) + 16|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ($134|0)==(0|0);
   $136 = ($destSlot1$2|0)==(0);
   $or$cond5 = $135 | $136;
   if (!($or$cond5)) {
    $137 = HEAP32[$134>>2]|0;
    $138 = (($137) + 4|0);
    $139 = HEAP32[$138>>2]|0;
    FUNCTION_TABLE_viii[$139 & 4095]($134,$60,$destSlot1$2);
   }
  }
  $$pr = HEAP32[$52>>2]|0;
  $141 = $$pr;$170 = $60;
 }
 $140 = ($141|0)==(0);
 if (!($140)) {
  $142 = (($this) + 1136|0);
  $i$03$i = 0;
  while(1) {
   $146 = HEAP32[$142>>2]|0;
   $147 = (($146) + ($i$03$i<<2)|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = (__ZNK5physx2Sc8BodyCore6getSimEv($148)|0);
   $150 = (($149) + 144|0);
   $151 = HEAP16[$150>>1]|0;
   $152 = $151&65535;
   $153 = $152 & 65423;
   $154 = $153&65535;
   HEAP16[$150>>1] = $154;
   $155 = (($i$03$i) + 1)|0;
   $156 = HEAP32[$52>>2]|0;
   $157 = ($155>>>0)<($156>>>0);
   if ($157) {
    $i$03$i = $155;
   } else {
    break;
   }
  }
 }
 $143 = HEAP32[$54>>2]|0;
 $144 = ($143|0)==(0);
 if ($144) {
  HEAP32[$52>>2] = 0;
  HEAP32[$54>>2] = 0;
  HEAP8[$27>>0] = 1;
  HEAP8[$2>>0] = 1;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$170);
  STACKTOP = sp;return;
 }
 $145 = (($this) + 1148|0);
 $i1$01$i = 0;
 while(1) {
  $158 = HEAP32[$145>>2]|0;
  $159 = (($158) + ($i1$01$i<<2)|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = (__ZNK5physx2Sc8BodyCore6getSimEv($160)|0);
  $162 = (($161) + 144|0);
  $163 = HEAP16[$162>>1]|0;
  $164 = $163&65535;
  $165 = $164 & 65359;
  $166 = $165&65535;
  HEAP16[$162>>1] = $166;
  $167 = (($i1$01$i) + 1)|0;
  $168 = HEAP32[$54>>2]|0;
  $169 = ($167>>>0)<($168>>>0);
  if ($169) {
   $i1$01$i = $167;
  } else {
   break;
  }
 }
 HEAP32[$52>>2] = 0;
 HEAP32[$54>>2] = 0;
 HEAP8[$27>>0] = 1;
 HEAP8[$2>>0] = 1;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$170);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene27prepareOutOfBoundsCallbacksEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $id = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $id = sp;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 51604|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 1272|0);
 $9 = (($this) + 1276|0);
 HEAP32[$9>>2] = 0;
 $10 = ($7|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($5) + 51600|0);
 $12 = (($this) + 1280|0);
 $21 = 0;$i$01 = 0;
 while(1) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + ($i$01<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 20|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$id>>2] = $17;
  $18 = HEAP32[$12>>2]|0;
  $19 = $18 & 2147483647;
  $20 = ($19>>>0)>($21>>>0);
  if ($20) {
   $22 = HEAP32[$8>>2]|0;
   $23 = (($22) + ($21<<2)|0);
   $24 = ($23|0)==(0|0);
   if ($24) {
    $26 = $21;
   } else {
    HEAP32[$23>>2] = $17;
    $$pre$i = HEAP32[$9>>2]|0;
    $26 = $$pre$i;
   }
   $25 = (($26) + 1)|0;
   HEAP32[$9>>2] = $25;
  } else {
   (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($8,$id)|0);
  }
  $27 = (($i$01) + 1)|0;
  $exitcond = ($27|0)==($7|0);
  if ($exitcond) {
   break;
  }
  $$pre = HEAP32[$9>>2]|0;
  $21 = $$pre;$i$01 = $27;
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene24fireOutOfBoundsCallbacksEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, $outputWarning$0$off0$lcssa = 0, $outputWarning$0$off04 = 0;
 var $outputWarning$1$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1000|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 51600|0);
 $8 = (($6) + 51604|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 1204|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==(0);
 if ($12) {
  $outputWarning$0$off0$lcssa = 0;
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($7,0,$0);
  $55 = HEAP32[$8>>2]|0;
  __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE8recreateEj($7,$55);
  STACKTOP = sp;return ($outputWarning$0$off0$lcssa|0);
 }
 $13 = (($this) + 1272|0);
 $14 = (($11) + 20|0);
 $15 = (($11) + 16|0);
 $16 = (($this) + 1164|0);
 $i$03 = 0;$outputWarning$0$off04 = 0;
 while(1) {
  $17 = HEAP32[$7>>2]|0;
  $18 = (($17) + ($i$03<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$13>>2]|0;
  $21 = (($20) + ($i$03<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $22 >>> 5;
  $24 = HEAP32[$14>>2]|0;
  $25 = $24 & 2147483647;
  $26 = ($23>>>0)<($25>>>0);
  if ($26) {
   $27 = HEAP32[$15>>2]|0;
   $28 = (($27) + ($23<<2)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = $22 & 31;
   $31 = 1 << $30;
   $32 = $29 & $31;
   $33 = ($32|0)==(0);
   if ($33) {
    label = 5;
   } else {
    $outputWarning$1$off0 = $outputWarning$0$off04;
   }
  } else {
   label = 5;
  }
  if ((label|0) == 5) {
   label = 0;
   $34 = (($19) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (__ZN5physx2Sc8RigidSim10getPxActorEv($35)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + 68|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (FUNCTION_TABLE_ii[$39 & 4095]($36)|0);
   $41 = $40&255;
   $42 = HEAP32[$16>>2]|0;
   $43 = (($42) + ($41<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 20|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    $outputWarning$1$off0 = 1;
   } else {
    $48 = (($19) + 28|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (__ZNK5physx2Sc9ShapeCore10getPxShapeEv($49)|0);
    $51 = HEAP32[$46>>2]|0;
    $52 = (($51) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    FUNCTION_TABLE_viii[$53 & 4095]($46,$50,$36);
    $outputWarning$1$off0 = $outputWarning$0$off04;
   }
  }
  $54 = (($i$03) + 1)|0;
  $exitcond = ($54|0)==($9|0);
  if ($exitcond) {
   $outputWarning$0$off0$lcssa = $outputWarning$1$off0;
   break;
  } else {
   $i$03 = $54;$outputWarning$0$off04 = $outputWarning$1$off0;
  }
 }
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($7,0,$0);
 $55 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE8recreateEj($7,$55);
 STACKTOP = sp;return ($outputWarning$0$off0$lcssa|0);
}
function __ZN5physx2Sc5Scene20postCallbacksPreSyncEv($this) {
 $this = $this|0;
 var $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $kinePrefetch$01 = 0, $kinePrefetch$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($4) + ($3<<2)|0);
 $6 = ($3|0)==(0);
 if ($6) {
  $17 = $1;
  __ZN5physx2Sc16InteractionScene18releaseConstraintsEb($17,1);
  STACKTOP = sp;return;
 }
 $7 = (($4) + 64|0);
 $$in = $3;$kinePrefetch$01 = $7;
 while(1) {
  $8 = (($$in) + -1)|0;
  $9 = ($kinePrefetch$01>>>0)<($5>>>0);
  if ($9) {
   $10 = HEAP32[$kinePrefetch$01>>2]|0;
   $11 = (($kinePrefetch$01) + 4|0);
   $kinePrefetch$1 = $11;
  } else {
   $kinePrefetch$1 = $kinePrefetch$01;
  }
  $12 = (($4) + ($8<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  (__ZN5physx2Sc7BodySim19deactivateKinematicEv($13)|0);
  $14 = (($13) + 52|0);
  $15 = HEAP32[$14>>2]|0;
  __ZN5physx2Sc8BodyCore25invalidateKinematicTargetEv($15);
  $16 = ($8|0)==(0);
  if ($16) {
   break;
  } else {
   $$in = $8;$kinePrefetch$01 = $kinePrefetch$1;
  }
 }
 $$pre = HEAP32[$0>>2]|0;
 $17 = $$pre;
 __ZN5physx2Sc16InteractionScene18releaseConstraintsEb($17,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene13getErrorStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1284|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Sc5Scene9getLimitsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Sc5Scene22setNbContactDataBlocksEj($this,$numBlocks) {
 $this = $this|0;
 $numBlocks = $numBlocks|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 44|0);
 __ZN5physx17PxcNpMemBlockPool13setBlockCountEj($4,$numBlocks);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene26getNbContactDataBlocksUsedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 44|0);
 $5 = (__ZNK5physx17PxcNpMemBlockPool17getUsedBlockCountEv($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc5Scene29getMaxNbContactDataBlocksUsedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 44|0);
 $5 = (__ZNK5physx17PxcNpMemBlockPool20getMaxUsedBlockCountEv($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc5Scene15setScratchBlockEPvj($this,$addr,$size) {
 $this = $this|0;
 $addr = $addr|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext15setScratchBlockEPvj($3,$addr,$size);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene8getStatsERNS_22PxSimulationStatisticsE($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1192|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1000|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 6752|0);
 __ZNK5physx2Sc8SimStats7readOutERNS_22PxSimulationStatisticsERKNS_11PxvSimStatsE($1,$s,$6);
 $7 = (($this) + 1424|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($s) + 12|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 1428|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($s) + 16|0);
 HEAP32[$12>>2] = $11;
 $13 = (($this) + 1432|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($s) + 20|0);
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 1436|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($s) + 24|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 1440|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($s) + 28|0);
 HEAP32[$21>>2] = $20;
 $22 = (($this) + 1444|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($s) + 32|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 1448|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($s) + 36|0);
 HEAP32[$27>>2] = $26;
 $28 = (($this) + 1452|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($s) + 40|0);
 HEAP32[$30>>2] = $29;
 $31 = (($this) + 1456|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($s) + 44|0);
 HEAP32[$33>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene12removeShapesERNS0_8RigidSimERNS_6shdfnd11InlineArrayIPNS0_8ShapeSimELj64ENS4_19ReflectionAllocatorIS7_EEEERNS5_IPKNS0_9ShapeCoreELj64ENS8_ISE_EEEEb($this,$sim,$shapesBuffer,$removedShapes,$wakeOnLostTouch) {
 $this = $this|0;
 $sim = $sim|0;
 $shapesBuffer = $shapesBuffer|0;
 $removedShapes = $removedShapes|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $iterator = 0, $s = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iterator = sp + 8|0;
 $s = sp;
 $0 = sp + 4|0;
 HEAP32[$iterator>>2] = 0;
 __ZN5physx2Sc13ShapeIterator4initERKNS0_8ActorSimE($iterator,$sim);
 $1 = (__ZN5physx2Sc13ShapeIterator7getNextEv($iterator)|0);
 HEAP32[$s>>2] = $1;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$pre6 = (($shapesBuffer) + 264|0);
  $$pre$phiZ2D = $$pre6;
 } else {
  $3 = (($shapesBuffer) + 268|0);
  $4 = (($shapesBuffer) + 264|0);
  $5 = (($shapesBuffer) + 260|0);
  $6 = (($removedShapes) + 268|0);
  $7 = (($removedShapes) + 264|0);
  $8 = (($removedShapes) + 260|0);
  $20 = $1;
  while(1) {
   $13 = HEAP32[$3>>2]|0;
   $14 = $13 & 2147483647;
   $15 = HEAP32[$4>>2]|0;
   $16 = ($14>>>0)>($15>>>0);
   if ($16) {
    $17 = HEAP32[$5>>2]|0;
    $18 = (($17) + ($15<<2)|0);
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     HEAP32[$18>>2] = $20;
    }
    $21 = (($15) + 1)|0;
    HEAP32[$4>>2] = $21;
    $23 = $20;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_2Sc8ShapeSimENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS4_EEEEE15growAndPushBackERKS4_($shapesBuffer,$s)|0);
    $$pre = HEAP32[$s>>2]|0;
    $23 = $$pre;
   }
   $22 = (($23) + 28|0);
   $24 = HEAP32[$22>>2]|0;
   HEAP32[$0>>2] = $24;
   $25 = HEAP32[$6>>2]|0;
   $26 = $25 & 2147483647;
   $27 = HEAP32[$7>>2]|0;
   $28 = ($26>>>0)>($27>>>0);
   if ($28) {
    $31 = HEAP32[$8>>2]|0;
    $32 = (($31) + ($27<<2)|0);
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     HEAP32[$32>>2] = $24;
    }
    $34 = (($27) + 1)|0;
    HEAP32[$7>>2] = $34;
   } else {
    (__ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE15growAndPushBackERKS5_($removedShapes,$0)|0);
   }
   $29 = (__ZN5physx2Sc13ShapeIterator7getNextEv($iterator)|0);
   HEAP32[$s>>2] = $29;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $$pre$phiZ2D = $4;
    break;
   } else {
    $20 = $29;
   }
  }
 }
 $9 = HEAP32[$$pre$phiZ2D>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($shapesBuffer) + 260|0);
 $12 = (($this) + 1220|0);
 $i$03 = 0;
 while(1) {
  $35 = HEAP32[$11>>2]|0;
  $36 = (($35) + ($i$03<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 28|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 68|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($this) + ($41<<2)|0) + 1432|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + -1)|0;
  HEAP32[$42>>2] = $44;
  __ZN5physx2Sc8ShapeSim20removeFromBroadPhaseEb($37,$wakeOnLostTouch);
  $45 = ($37|0)==(0|0);
  if (!($45)) {
   $46 = HEAP32[$12>>2]|0;
   $47 = HEAP32[$37>>2]|0;
   $48 = HEAP32[$47>>2]|0;
   FUNCTION_TABLE_vi[$48 & 4095]($37);
   __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($46,$37);
  }
  $49 = (($i$03) + 1)|0;
  $50 = HEAP32[$$pre$phiZ2D>>2]|0;
  $51 = ($49>>>0)<($50>>>0);
  if ($51) {
   $i$03 = $49;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene11removeShapeERNS0_8ShapeSimEb($this,$shape,$wakeOnLostTouch) {
 $this = $this|0;
 $shape = $shape|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($this) + ($3<<2)|0) + 1432|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -1)|0;
 HEAP32[$4>>2] = $6;
 __ZN5physx2Sc8ShapeSim20removeFromBroadPhaseEb($shape,$wakeOnLostTouch);
 $7 = ($shape|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 1220|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$shape>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$11 & 4095]($shape);
 __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($9,$shape);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene9addStaticERNS0_10StaticCoreEPKPvjj($this,$ro,$shapes,$nbShapes,$shapePtrOffset) {
 $this = $this|0;
 $ro = $ro|0;
 $shapes = $shapes|0;
 $nbShapes = $nbShapes|0;
 $shapePtrOffset = $shapePtrOffset|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1224|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($3*12)|0)|0) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if ($10) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($5) + (($3*12)|0)|0) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($12|0);
   if (!($15)) {
    $16 = (($14) + 1)|0;
    HEAP32[$13>>2] = $16;
    $17 = (($5) + (($3*12)|0)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = Math_imul($14, $7)|0;
    $20 = (($18) + ($19)|0);
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     $24 = $20;
     label = 6;
     break;
    }
   }
   $22 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($1)|0);
   $23 = ($22|0)==(0|0);
   if ($23) {
    $59 = 0;
   } else {
    $24 = $22;
    label = 6;
   }
  } else {
   $11 = HEAP32[$9>>2]|0;
   HEAP32[$8>>2] = $11;
   $24 = $9;
   label = 6;
  }
 } while(0);
 if ((label|0) == 6) {
  __ZN5physx2Sc9StaticSimC2ERNS0_5SceneERNS0_10StaticCoreE($24,$this,$ro);
  $59 = $24;
 }
 $25 = (($this) + 1424|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$25>>2] = $27;
 $28 = ($nbShapes|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($this) + 1220|0);
 $i$01$i = 0;
 while(1) {
  $30 = (($shapes) + ($i$01$i<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $31;
  $33 = (($32) + ($shapePtrOffset))|0;
  $34 = $33;
  $35 = HEAP32[$29>>2]|0;
  $36 = (($35) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + 12|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($35) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($39) + (($37*12)|0)|0) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  do {
   if ($44) {
    $46 = HEAP32[$35>>2]|0;
    $47 = ((($39) + (($37*12)|0)|0) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==($46|0);
    if (!($49)) {
     $50 = (($48) + 1)|0;
     HEAP32[$47>>2] = $50;
     $51 = (($39) + (($37*12)|0)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = Math_imul($48, $41)|0;
     $54 = (($52) + ($53)|0);
     $55 = ($54|0)==(0|0);
     if (!($55)) {
      $58 = $54;
      label = 14;
      break;
     }
    }
    $56 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($35)|0);
    $57 = ($56|0)==(0|0);
    if (!($57)) {
     $58 = $56;
     label = 14;
    }
   } else {
    $45 = HEAP32[$43>>2]|0;
    HEAP32[$42>>2] = $45;
    $58 = $43;
    label = 14;
   }
  } while(0);
  if ((label|0) == 14) {
   label = 0;
   __ZN5physx2Sc8ShapeSimC2ERNS0_8RigidSimERKNS0_9ShapeCoreEPNS_12PxsRigidBodyEPNS_9PxBounds3E($58,$59,$34,0,0);
  }
  $60 = (($34) + 68|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($this) + ($61<<2)|0) + 1432|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($63) + 1)|0;
  HEAP32[$62>>2] = $64;
  $65 = (($i$01$i) + 1)|0;
  $exitcond$i = ($65|0)==($nbShapes|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene17prefetchForRemoveERKNS0_10StaticCoreE($this,$core) {
 $this = $this|0;
 $core = $core|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $cp$0$i = 0, $cp$0$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Sc10StaticCore6getSimEv($core)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = $0;
 $3 = (_bitshift64Lshr(($2|0),0,6)|0);
 $4 = tempRet0;
 $5 = (_i64Add(($2|0),0,59,0)|0);
 $6 = tempRet0;
 $7 = (_bitshift64Lshr(($5|0),($6|0),6)|0);
 $8 = tempRet0;
 $9 = (_i64Subtract(1,0,($3|0),($4|0))|0);
 $10 = tempRet0;
 $11 = (_i64Add(($9|0),($10|0),($7|0),($8|0))|0);
 $12 = tempRet0;
 $14 = $11;$15 = $12;$cp$0$i = $0;
 while(1) {
  $13 = (($cp$0$i) + 64|0);
  $16 = (_i64Add(($14|0),($15|0),-1,-1)|0);
  $17 = tempRet0;
  $18 = ($16|0)==(0);
  $19 = ($17|0)==(0);
  $20 = $18 & $19;
  if ($20) {
   break;
  } else {
   $14 = $16;$15 = $17;$cp$0$i = $13;
  }
 }
 $21 = (($0) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22;
 $24 = (_bitshift64Lshr(($23|0),0,6)|0);
 $25 = tempRet0;
 $26 = (_i64Add(($23|0),0,19,0)|0);
 $27 = tempRet0;
 $28 = (_bitshift64Lshr(($26|0),($27|0),6)|0);
 $29 = tempRet0;
 $30 = (_i64Subtract(1,0,($24|0),($25|0))|0);
 $31 = tempRet0;
 $32 = (_i64Add(($30|0),($31|0),($28|0),($29|0))|0);
 $33 = tempRet0;
 $35 = $32;$36 = $33;$cp$0$i1 = $22;
 while(1) {
  $34 = (($cp$0$i1) + 64|0);
  $37 = (_i64Add(($35|0),($36|0),-1,-1)|0);
  $38 = tempRet0;
  $39 = ($37|0)==(0);
  $40 = ($38|0)==(0);
  $41 = $39 & $40;
  if ($41) {
   break;
  } else {
   $35 = $37;$36 = $38;$cp$0$i1 = $34;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene17prefetchForRemoveERKNS0_8BodyCoreE($this,$core) {
 $this = $this|0;
 $core = $core|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $cp$0$i = 0, $cp$0$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Sc8BodyCore6getSimEv($core)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = $0;
 $3 = (_bitshift64Lshr(($2|0),0,6)|0);
 $4 = tempRet0;
 $5 = (_i64Add(($2|0),0,191,0)|0);
 $6 = tempRet0;
 $7 = (_bitshift64Lshr(($5|0),($6|0),6)|0);
 $8 = tempRet0;
 $9 = (_i64Subtract(1,0,($3|0),($4|0))|0);
 $10 = tempRet0;
 $11 = (_i64Add(($9|0),($10|0),($7|0),($8|0))|0);
 $12 = tempRet0;
 $14 = $11;$15 = $12;$cp$0$i = $0;
 while(1) {
  $13 = (($cp$0$i) + 64|0);
  $16 = (_i64Add(($14|0),($15|0),-1,-1)|0);
  $17 = tempRet0;
  $18 = ($16|0)==(0);
  $19 = ($17|0)==(0);
  $20 = $18 & $19;
  if ($20) {
   break;
  } else {
   $14 = $16;$15 = $17;$cp$0$i = $13;
  }
 }
 $21 = (($0) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22;
 $24 = (_bitshift64Lshr(($23|0),0,6)|0);
 $25 = tempRet0;
 $26 = (_i64Add(($23|0),0,19,0)|0);
 $27 = tempRet0;
 $28 = (_bitshift64Lshr(($26|0),($27|0),6)|0);
 $29 = tempRet0;
 $30 = (_i64Subtract(1,0,($24|0),($25|0))|0);
 $31 = tempRet0;
 $32 = (_i64Add(($30|0),($31|0),($28|0),($29|0))|0);
 $33 = tempRet0;
 $35 = $32;$36 = $33;$cp$0$i1 = $22;
 while(1) {
  $34 = (($cp$0$i1) + 64|0);
  $37 = (_i64Add(($35|0),($36|0),-1,-1)|0);
  $38 = tempRet0;
  $39 = ($37|0)==(0);
  $40 = ($38|0)==(0);
  $41 = $39 & $40;
  if ($41) {
   break;
  } else {
   $35 = $37;$36 = $38;$cp$0$i1 = $34;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene12removeStaticERNS0_10StaticCoreERNS_6shdfnd11InlineArrayIPKNS0_9ShapeCoreELj64ENS4_19ReflectionAllocatorIS8_EEEEb($this,$ro,$removedShapes,$wakeOnLostTouch) {
 $this = $this|0;
 $ro = $ro|0;
 $removedShapes = $removedShapes|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $shapesBuffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $shapesBuffer = sp;
 $0 = (__ZNK5physx2Sc10StaticCore6getSimEv($ro)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 1244|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $5 = (($shapesBuffer) + 256|0);
   $6 = (($shapesBuffer) + 260|0);
   $7 = (($shapesBuffer) + 264|0);
   HEAP32[$7>>2] = 0;
   $8 = (($shapesBuffer) + 268|0);
   HEAP8[$5>>0] = 1;
   HEAP32[$6>>2] = $shapesBuffer;
   HEAP32[$8>>2] = 64;
   __ZN5physx2Sc5Scene12removeShapesERNS0_8RigidSimERNS_6shdfnd11InlineArrayIPNS0_8ShapeSimELj64ENS4_19ReflectionAllocatorIS7_EEEERNS5_IPKNS0_9ShapeCoreELj64ENS8_ISE_EEEEb($this,$0,$shapesBuffer,$removedShapes,$wakeOnLostTouch);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 & 2147483647;
   $11 = ($10|0)!=(0);
   $12 = ($9|0)>(-1);
   $or$cond$i$i$i = $11 & $12;
   if ($or$cond$i$i$i) {
    $13 = HEAP32[$6>>2]|0;
    $14 = ($shapesBuffer|0)==($13|0);
    if ($14) {
     HEAP8[$5>>0] = 0;
     break;
    }
    $15 = ($13|0)==(0|0);
    if (!($15)) {
     $16 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($17) + 12|0);
     $19 = HEAP32[$18>>2]|0;
     FUNCTION_TABLE_vii[$19 & 4095]($16,$13);
    }
   }
  } else {
   __ZN5physx2Sc5Scene12removeShapesERNS0_8RigidSimERNS_6shdfnd11InlineArrayIPNS0_8ShapeSimELj64ENS4_19ReflectionAllocatorIS7_EEEERNS5_IPKNS0_9ShapeCoreELj64ENS8_ISE_EEEEb($this,$0,$3,$removedShapes,$wakeOnLostTouch);
  }
 } while(0);
 $20 = (($this) + 1224|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__ZNK5physx2Sc10StaticCore6getSimEv($ro)|0);
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = HEAP32[$22>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_vi[$25 & 4095]($22);
  __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($21,$22);
 }
 $26 = (($this) + 1424|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + -1)|0;
 HEAP32[$26>>2] = $28;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene7addBodyERNS0_8BodyCoreEPKPvjj($this,$body,$shapes,$nbShapes,$shapePtrOffset) {
 $this = $this|0;
 $body = $body|0;
 $shapes = $shapes|0;
 $nbShapes = $nbShapes|0;
 $shapePtrOffset = $shapePtrOffset|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1228|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($3*12)|0)|0) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if ($10) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($5) + (($3*12)|0)|0) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($12|0);
   if (!($15)) {
    $16 = (($14) + 1)|0;
    HEAP32[$13>>2] = $16;
    $17 = (($5) + (($3*12)|0)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = Math_imul($14, $7)|0;
    $20 = (($18) + ($19)|0);
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     $24 = $20;
     label = 6;
     break;
    }
   }
   $22 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($1)|0);
   $23 = ($22|0)==(0|0);
   if ($23) {
    $29 = 0;
   } else {
    $24 = $22;
    label = 6;
   }
  } else {
   $11 = HEAP32[$9>>2]|0;
   HEAP32[$8>>2] = $11;
   $24 = $9;
   label = 6;
  }
 } while(0);
 if ((label|0) == 6) {
  __ZN5physx2Sc7BodySimC2ERNS0_5SceneERNS0_8BodyCoreE($24,$this,$body);
  $29 = $24;
 }
 $25 = (($this) + 1428|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$25>>2] = $27;
 $28 = (($29) + 64|0);
 $30 = ($nbShapes|0)==(0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 1220|0);
 $i$01$i = 0;
 while(1) {
  $32 = (($shapes) + ($i$01$i<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33;
  $35 = (($34) + ($shapePtrOffset))|0;
  $36 = $35;
  $37 = HEAP32[$31>>2]|0;
  $38 = (($37) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($37) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($41) + (($39*12)|0)|0) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  do {
   if ($46) {
    $48 = HEAP32[$37>>2]|0;
    $49 = ((($41) + (($39*12)|0)|0) + 8|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==($48|0);
    if (!($51)) {
     $52 = (($50) + 1)|0;
     HEAP32[$49>>2] = $52;
     $53 = (($41) + (($39*12)|0)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = Math_imul($50, $43)|0;
     $56 = (($54) + ($55)|0);
     $57 = ($56|0)==(0|0);
     if (!($57)) {
      $60 = $56;
      label = 14;
      break;
     }
    }
    $58 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($37)|0);
    $59 = ($58|0)==(0|0);
    if (!($59)) {
     $60 = $58;
     label = 14;
    }
   } else {
    $47 = HEAP32[$45>>2]|0;
    HEAP32[$44>>2] = $47;
    $60 = $45;
    label = 14;
   }
  } while(0);
  if ((label|0) == 14) {
   label = 0;
   __ZN5physx2Sc8ShapeSimC2ERNS0_8RigidSimERKNS0_9ShapeCoreEPNS_12PxsRigidBodyEPNS_9PxBounds3E($60,$29,$36,$28,0);
  }
  $61 = (($36) + 68|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($this) + ($62<<2)|0) + 1432|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($64) + 1)|0;
  HEAP32[$63>>2] = $65;
  $66 = (($i$01$i) + 1)|0;
  $exitcond$i = ($66|0)==($nbShapes|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $66;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene10removeBodyERNS0_8BodyCoreERNS_6shdfnd11InlineArrayIPKNS0_9ShapeCoreELj64ENS4_19ReflectionAllocatorIS8_EEEEb($this,$body,$removedShapes,$wakeOnLostTouch) {
 $this = $this|0;
 $body = $body|0;
 $removedShapes = $removedShapes|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $shapesBuffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $shapesBuffer = sp;
 $0 = (__ZNK5physx2Sc8BodyCore6getSimEv($body)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 1244|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $5 = (($shapesBuffer) + 256|0);
   $6 = (($shapesBuffer) + 260|0);
   $7 = (($shapesBuffer) + 264|0);
   HEAP32[$7>>2] = 0;
   $8 = (($shapesBuffer) + 268|0);
   HEAP8[$5>>0] = 1;
   HEAP32[$6>>2] = $shapesBuffer;
   HEAP32[$8>>2] = 64;
   __ZN5physx2Sc5Scene12removeShapesERNS0_8RigidSimERNS_6shdfnd11InlineArrayIPNS0_8ShapeSimELj64ENS4_19ReflectionAllocatorIS7_EEEERNS5_IPKNS0_9ShapeCoreELj64ENS8_ISE_EEEEb($this,$0,$shapesBuffer,$removedShapes,$wakeOnLostTouch);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 & 2147483647;
   $11 = ($10|0)!=(0);
   $12 = ($9|0)>(-1);
   $or$cond$i$i$i = $11 & $12;
   if ($or$cond$i$i$i) {
    $13 = HEAP32[$6>>2]|0;
    $14 = ($shapesBuffer|0)==($13|0);
    if ($14) {
     HEAP8[$5>>0] = 0;
     break;
    }
    $15 = ($13|0)==(0|0);
    if (!($15)) {
     $16 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($17) + 12|0);
     $19 = HEAP32[$18>>2]|0;
     FUNCTION_TABLE_vii[$19 & 4095]($16,$13);
    }
   }
  } else {
   __ZN5physx2Sc5Scene12removeShapesERNS0_8RigidSimERNS_6shdfnd11InlineArrayIPNS0_8ShapeSimELj64ENS4_19ReflectionAllocatorIS7_EEEERNS5_IPKNS0_9ShapeCoreELj64ENS8_ISE_EEEEb($this,$0,$3,$removedShapes,$wakeOnLostTouch);
  }
 } while(0);
 $$in = (($this) + 1228|0);
 $20 = HEAP32[$$in>>2]|0;
 $21 = HEAP32[$0>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($0);
 __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($20,$0);
 $23 = (($this) + 1428|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + -1)|0;
 HEAP32[$23>>2] = $25;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene8addShapeERNS0_8RigidSimERNS0_9ShapeCoreE($this,$owner,$shapeCore) {
 $this = $this|0;
 $owner = $owner|0;
 $shapeCore = $shapeCore|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($owner) + 50|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 if ((($2|0) == 4) | (($2|0) == 1)) {
  $3 = (($owner) + 64|0);
  $29 = $3;
 } else {
  $29 = 0;
 }
 $4 = (($this) + 1220|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($7*12)|0)|0) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 do {
  if ($14) {
   $16 = HEAP32[$5>>2]|0;
   $17 = ((($9) + (($7*12)|0)|0) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==($16|0);
   if (!($19)) {
    $20 = (($18) + 1)|0;
    HEAP32[$17>>2] = $20;
    $21 = (($9) + (($7*12)|0)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = Math_imul($18, $11)|0;
    $24 = (($22) + ($23)|0);
    $25 = ($24|0)==(0|0);
    if (!($25)) {
     $28 = $24;
     break;
    }
   }
   $26 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($5)|0);
   $27 = ($26|0)==(0|0);
   if ($27) {
    $30 = (($shapeCore) + 68|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($this) + ($31<<2)|0) + 1432|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 1)|0;
    HEAP32[$32>>2] = $34;
    STACKTOP = sp;return;
   } else {
    $28 = $26;
   }
  } else {
   $15 = HEAP32[$13>>2]|0;
   HEAP32[$12>>2] = $15;
   $28 = $13;
  }
 } while(0);
 __ZN5physx2Sc8ShapeSimC2ERNS0_8RigidSimERKNS0_9ShapeCoreEPNS_12PxsRigidBodyEPNS_9PxBounds3E($28,$owner,$shapeCore,$29,0);
 $30 = (($shapeCore) + 68|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($this) + ($31<<2)|0) + 1432|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 1)|0;
 HEAP32[$32>>2] = $34;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19startBatchInsertionERNS0_19BatchInsertionStateE($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cp$0$i$i = 0, $cp$0$i$i11 = 0, $cp$0$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1220|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($3*12)|0)|0) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if ($10) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ((($5) + (($3*12)|0)|0) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($12|0);
   if (!($15)) {
    $16 = (($14) + 1)|0;
    HEAP32[$13>>2] = $16;
    $17 = (($5) + (($3*12)|0)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = Math_imul($14, $7)|0;
    $20 = (($18) + ($19)|0);
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     $24 = $20;
     break;
    }
   }
   $22 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($1)|0);
   $24 = $22;
  } else {
   $11 = HEAP32[$9>>2]|0;
   HEAP32[$8>>2] = $11;
   $24 = $9;
  }
 } while(0);
 $23 = $24;
 $25 = (_bitshift64Lshr(($23|0),0,6)|0);
 $26 = tempRet0;
 $27 = (_i64Add(($23|0),0,31,0)|0);
 $28 = tempRet0;
 $29 = (_bitshift64Lshr(($27|0),($28|0),6)|0);
 $30 = tempRet0;
 $31 = (_i64Subtract(1,0,($25|0),($26|0))|0);
 $32 = tempRet0;
 $33 = (_i64Add(($31|0),($32|0),($29|0),($30|0))|0);
 $34 = tempRet0;
 $36 = $33;$37 = $34;$cp$0$i$i = $24;
 while(1) {
  $35 = (($cp$0$i$i) + 64|0);
  $38 = (_i64Add(($36|0),($37|0),-1,-1)|0);
  $39 = tempRet0;
  $40 = ($38|0)==(0);
  $41 = ($39|0)==(0);
  $42 = $40 & $41;
  if ($42) {
   break;
  } else {
   $36 = $38;$37 = $39;$cp$0$i$i = $35;
  }
 }
 $43 = (($state) + 8|0);
 HEAP32[$43>>2] = $24;
 $44 = (($this) + 1224|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($45) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($45) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($49) + (($47*12)|0)|0) + 4|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 do {
  if ($54) {
   $56 = HEAP32[$45>>2]|0;
   $57 = ((($49) + (($47*12)|0)|0) + 8|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==($56|0);
   if (!($59)) {
    $60 = (($58) + 1)|0;
    HEAP32[$57>>2] = $60;
    $61 = (($49) + (($47*12)|0)|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = Math_imul($58, $51)|0;
    $64 = (($62) + ($63)|0);
    $65 = ($64|0)==(0|0);
    if (!($65)) {
     $68 = $64;
     break;
    }
   }
   $66 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($45)|0);
   $68 = $66;
  } else {
   $55 = HEAP32[$53>>2]|0;
   HEAP32[$52>>2] = $55;
   $68 = $53;
  }
 } while(0);
 $67 = $68;
 $69 = (_bitshift64Lshr(($67|0),0,6)|0);
 $70 = tempRet0;
 $71 = (_i64Add(($67|0),0,59,0)|0);
 $72 = tempRet0;
 $73 = (_bitshift64Lshr(($71|0),($72|0),6)|0);
 $74 = tempRet0;
 $75 = (_i64Subtract(1,0,($69|0),($70|0))|0);
 $76 = tempRet0;
 $77 = (_i64Add(($75|0),($76|0),($73|0),($74|0))|0);
 $78 = tempRet0;
 $80 = $77;$81 = $78;$cp$0$i$i5 = $68;
 while(1) {
  $79 = (($cp$0$i$i5) + 64|0);
  $82 = (_i64Add(($80|0),($81|0),-1,-1)|0);
  $83 = tempRet0;
  $84 = ($82|0)==(0);
  $85 = ($83|0)==(0);
  $86 = $84 & $85;
  if ($86) {
   break;
  } else {
   $80 = $82;$81 = $83;$cp$0$i$i5 = $79;
  }
 }
 $87 = (($state) + 4|0);
 HEAP32[$87>>2] = $68;
 $88 = (($this) + 1228|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + 8|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (($89) + 12|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($89) + 4|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ((($93) + (($91*12)|0)|0) + 4|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ($97|0)==(0|0);
 do {
  if ($98) {
   $100 = HEAP32[$89>>2]|0;
   $101 = ((($93) + (($91*12)|0)|0) + 8|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ($102|0)==($100|0);
   if (!($103)) {
    $104 = (($102) + 1)|0;
    HEAP32[$101>>2] = $104;
    $105 = (($93) + (($91*12)|0)|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = Math_imul($102, $95)|0;
    $108 = (($106) + ($107)|0);
    $109 = ($108|0)==(0|0);
    if (!($109)) {
     $112 = $108;
     break;
    }
   }
   $110 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($89)|0);
   $112 = $110;
  } else {
   $99 = HEAP32[$97>>2]|0;
   HEAP32[$96>>2] = $99;
   $112 = $97;
  }
 } while(0);
 $111 = $112;
 $113 = (_bitshift64Lshr(($111|0),0,6)|0);
 $114 = tempRet0;
 $115 = (_i64Add(($111|0),0,191,0)|0);
 $116 = tempRet0;
 $117 = (_bitshift64Lshr(($115|0),($116|0),6)|0);
 $118 = tempRet0;
 $119 = (_i64Subtract(1,0,($113|0),($114|0))|0);
 $120 = tempRet0;
 $121 = (_i64Add(($119|0),($120|0),($117|0),($118|0))|0);
 $122 = tempRet0;
 $124 = $121;$125 = $122;$cp$0$i$i11 = $112;
 while(1) {
  $123 = (($cp$0$i$i11) + 64|0);
  $126 = (_i64Add(($124|0),($125|0),-1,-1)|0);
  $127 = tempRet0;
  $128 = ($126|0)==(0);
  $129 = ($127|0)==(0);
  $130 = $128 & $129;
  if ($130) {
   break;
  } else {
   $124 = $126;$125 = $127;$cp$0$i$i11 = $123;
  }
 }
 HEAP32[$state>>2] = $112;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene9addShapesEPKPvjjRNS0_8RigidSimEPNS_12PxsRigidBodyERPNS0_8ShapeSimEPNS_9PxBounds3E($this,$shapes,$nbShapes,$ptrOffset,$rigidSim,$llBody,$prefetchedShapeSim,$outBounds) {
 $this = $this|0;
 $shapes = $shapes|0;
 $nbShapes = $nbShapes|0;
 $ptrOffset = $ptrOffset|0;
 $rigidSim = $rigidSim|0;
 $llBody = $llBody|0;
 $prefetchedShapeSim = $prefetchedShapeSim|0;
 $outBounds = $outBounds|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $cp$0$i = 0, $cp$0$i$i = 0, $exitcond = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nbShapes|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($ptrOffset) + 144)|0;
 $2 = (_i64Add(($1|0),0,-1,-1)|0);
 $3 = tempRet0;
 $4 = (($this) + 1220|0);
 $$sum = (($ptrOffset) + 68)|0;
 $i$02 = 0;
 while(1) {
  $5 = (($i$02) + 1)|0;
  $6 = ($5>>>0)<($nbShapes>>>0);
  if ($6) {
   $7 = (($shapes) + ($5<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8;
   $10 = (_bitshift64Lshr(($9|0),0,6)|0);
   $11 = tempRet0;
   $12 = (_i64Add(($2|0),($3|0),($9|0),0)|0);
   $13 = tempRet0;
   $14 = (_bitshift64Lshr(($12|0),($13|0),6)|0);
   $15 = tempRet0;
   $16 = (_i64Subtract(1,0,($10|0),($11|0))|0);
   $17 = tempRet0;
   $18 = (_i64Add(($16|0),($17|0),($14|0),($15|0))|0);
   $19 = tempRet0;
   $21 = $18;$22 = $19;$cp$0$i = $8;
   while(1) {
    $20 = (($cp$0$i) + 64|0);
    $23 = (_i64Add(($21|0),($22|0),-1,-1)|0);
    $24 = tempRet0;
    $25 = ($23|0)==(0);
    $26 = ($24|0)==(0);
    $27 = $25 & $26;
    if ($27) {
     break;
    } else {
     $21 = $23;$22 = $24;$cp$0$i = $20;
    }
   }
  }
  $28 = HEAP32[$4>>2]|0;
  $29 = (($28) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($28) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ((($32) + (($30*12)|0)|0) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  do {
   if ($37) {
    $39 = HEAP32[$28>>2]|0;
    $40 = ((($32) + (($30*12)|0)|0) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==($39|0);
    if (!($42)) {
     $43 = (($41) + 1)|0;
     HEAP32[$40>>2] = $43;
     $44 = (($32) + (($30*12)|0)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = Math_imul($41, $34)|0;
     $47 = (($45) + ($46)|0);
     $48 = ($47|0)==(0|0);
     if (!($48)) {
      $51 = $47;
      break;
     }
    }
    $49 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($28)|0);
    $51 = $49;
   } else {
    $38 = HEAP32[$36>>2]|0;
    HEAP32[$35>>2] = $38;
    $51 = $36;
   }
  } while(0);
  $50 = $51;
  $52 = (_bitshift64Lshr(($50|0),0,6)|0);
  $53 = tempRet0;
  $54 = (_i64Add(($50|0),0,31,0)|0);
  $55 = tempRet0;
  $56 = (_bitshift64Lshr(($54|0),($55|0),6)|0);
  $57 = tempRet0;
  $58 = (_i64Subtract(1,0,($52|0),($53|0))|0);
  $59 = tempRet0;
  $60 = (_i64Add(($58|0),($59|0),($56|0),($57|0))|0);
  $61 = tempRet0;
  $63 = $60;$64 = $61;$cp$0$i$i = $51;
  while(1) {
   $62 = (($cp$0$i$i) + 64|0);
   $65 = (_i64Add(($63|0),($64|0),-1,-1)|0);
   $66 = tempRet0;
   $67 = ($65|0)==(0);
   $68 = ($66|0)==(0);
   $69 = $67 & $68;
   if ($69) {
    break;
   } else {
    $63 = $65;$64 = $66;$cp$0$i$i = $62;
   }
  }
  $70 = (($shapes) + ($i$02<<2)|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($71) + ($ptrOffset)|0);
  $73 = HEAP32[$prefetchedShapeSim>>2]|0;
  $74 = (($outBounds) + (($i$02*24)|0)|0);
  __ZN5physx2Sc8ShapeSimC2ERNS0_8RigidSimERKNS0_9ShapeCoreEPNS_12PxsRigidBodyEPNS_9PxBounds3E($73,$rigidSim,$72,$llBody,$74);
  HEAP32[$prefetchedShapeSim>>2] = $51;
  $75 = (($71) + ($$sum)|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ((($this) + ($76<<2)|0) + 1432|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($78) + 1)|0;
  HEAP32[$77>>2] = $79;
  $exitcond = ($5|0)==($nbShapes|0);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene9addStaticEPNS_7PxActorERNS0_19BatchInsertionStateEPNS_9PxBounds3E($this,$actor,$s,$outBounds) {
 $this = $this|0;
 $actor = $actor|0;
 $s = $s|0;
 $outBounds = $outBounds|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $cp$0$i = 0, $cp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($s) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($actor) + ($3)|0);
 $$sum = (($3) + 4)|0;
 $5 = (($actor) + ($$sum)|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = ($6<<16>>16)==(1);
 if ($7) {
  $11 = $4;
  label = 4;
 } else {
  $8 = HEAP32[$4>>2]|0;
  $9 = ($6<<16>>16)==(0);
  if ($9) {
   $87 = $8;
  } else {
   $11 = $8;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $10 = HEAP32[$11>>2]|0;
  $12 = (($s) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 144)|0;
  $15 = $10;
  $16 = (_bitshift64Lshr(($15|0),0,6)|0);
  $17 = tempRet0;
  $18 = (_i64Add(($15|0),0,-1,-1)|0);
  $19 = tempRet0;
  $20 = (_i64Add(($18|0),($19|0),($14|0),0)|0);
  $21 = tempRet0;
  $22 = (_bitshift64Lshr(($20|0),($21|0),6)|0);
  $23 = tempRet0;
  $24 = (_i64Subtract(1,0,($16|0),($17|0))|0);
  $25 = tempRet0;
  $26 = (_i64Add(($24|0),($25|0),($22|0),($23|0))|0);
  $27 = tempRet0;
  $29 = $26;$30 = $27;$cp$0$i = $10;
  while(1) {
   $28 = (($cp$0$i) + 64|0);
   $31 = (_i64Add(($29|0),($30|0),-1,-1)|0);
   $32 = tempRet0;
   $33 = ($31|0)==(0);
   $34 = ($32|0)==(0);
   $35 = $33 & $34;
   if ($35) {
    $87 = $11;
    break;
   } else {
    $29 = $31;$30 = $32;$cp$0$i = $28;
   }
  }
 }
 $36 = (($this) + 1224|0);
 $37 = (($s) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($actor) + ($38)|0);
 __ZN5physx2Sc9StaticSimC2ERNS0_5SceneERNS0_10StaticCoreE($1,$this,$39);
 $40 = HEAP32[$36>>2]|0;
 $41 = (($40) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($40) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($44) + (($42*12)|0)|0) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 do {
  if ($49) {
   $51 = HEAP32[$40>>2]|0;
   $52 = ((($44) + (($42*12)|0)|0) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==($51|0);
   if (!($54)) {
    $55 = (($53) + 1)|0;
    HEAP32[$52>>2] = $55;
    $56 = (($44) + (($42*12)|0)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = Math_imul($53, $46)|0;
    $59 = (($57) + ($58)|0);
    $60 = ($59|0)==(0|0);
    if (!($60)) {
     $63 = $59;
     break;
    }
   }
   $61 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($40)|0);
   $63 = $61;
  } else {
   $50 = HEAP32[$48>>2]|0;
   HEAP32[$47>>2] = $50;
   $63 = $48;
  }
 } while(0);
 $62 = $63;
 $64 = (_bitshift64Lshr(($62|0),0,6)|0);
 $65 = tempRet0;
 $66 = (_i64Add(($62|0),0,59,0)|0);
 $67 = tempRet0;
 $68 = (_bitshift64Lshr(($66|0),($67|0),6)|0);
 $69 = tempRet0;
 $70 = (_i64Subtract(1,0,($64|0),($65|0))|0);
 $71 = tempRet0;
 $72 = (_i64Add(($70|0),($71|0),($68|0),($69|0))|0);
 $73 = tempRet0;
 $75 = $72;$76 = $73;$cp$0$i$i = $63;
 while(1) {
  $74 = (($cp$0$i$i) + 64|0);
  $77 = (_i64Add(($75|0),($76|0),-1,-1)|0);
  $78 = tempRet0;
  $79 = ($77|0)==(0);
  $80 = ($78|0)==(0);
  $81 = $79 & $80;
  if ($81) {
   break;
  } else {
   $75 = $77;$76 = $78;$cp$0$i$i = $74;
  }
 }
 HEAP32[$0>>2] = $63;
 $82 = HEAP16[$5>>1]|0;
 $83 = $82&65535;
 $84 = (($s) + 28|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($s) + 8|0);
 __ZN5physx2Sc5Scene9addShapesEPKPvjjRNS0_8RigidSimEPNS_12PxsRigidBodyERPNS0_8ShapeSimEPNS_9PxBounds3E($this,$87,$83,$85,$1,0,$86,$outBounds);
 $88 = (($this) + 1424|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + 1)|0;
 HEAP32[$88>>2] = $90;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene7addBodyEPNS_7PxActorERNS0_19BatchInsertionStateEPNS_9PxBounds3E($this,$actor,$s,$outBounds) {
 $this = $this|0;
 $actor = $actor|0;
 $s = $s|0;
 $outBounds = $outBounds|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $cp$0$i = 0, $cp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$s>>2]|0;
 $1 = (($s) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($actor) + ($2)|0);
 $$sum = (($2) + 4)|0;
 $4 = (($actor) + ($$sum)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = ($5<<16>>16)==(1);
 if ($6) {
  $10 = $3;
  label = 4;
 } else {
  $7 = HEAP32[$3>>2]|0;
  $8 = ($5<<16>>16)==(0);
  if ($8) {
   $87 = $7;
  } else {
   $10 = $7;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $9 = HEAP32[$10>>2]|0;
  $11 = (($s) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 144)|0;
  $14 = $9;
  $15 = (_bitshift64Lshr(($14|0),0,6)|0);
  $16 = tempRet0;
  $17 = (_i64Add(($14|0),0,-1,-1)|0);
  $18 = tempRet0;
  $19 = (_i64Add(($17|0),($18|0),($13|0),0)|0);
  $20 = tempRet0;
  $21 = (_bitshift64Lshr(($19|0),($20|0),6)|0);
  $22 = tempRet0;
  $23 = (_i64Subtract(1,0,($15|0),($16|0))|0);
  $24 = tempRet0;
  $25 = (_i64Add(($23|0),($24|0),($21|0),($22|0))|0);
  $26 = tempRet0;
  $28 = $25;$29 = $26;$cp$0$i = $9;
  while(1) {
   $27 = (($cp$0$i) + 64|0);
   $30 = (_i64Add(($28|0),($29|0),-1,-1)|0);
   $31 = tempRet0;
   $32 = ($30|0)==(0);
   $33 = ($31|0)==(0);
   $34 = $32 & $33;
   if ($34) {
    $87 = $10;
    break;
   } else {
    $28 = $30;$29 = $31;$cp$0$i = $27;
   }
  }
 }
 $35 = (($this) + 1228|0);
 $36 = (($s) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($actor) + ($37)|0);
 __ZN5physx2Sc7BodySimC2ERNS0_5SceneERNS0_8BodyCoreE($0,$this,$38);
 $39 = HEAP32[$35>>2]|0;
 $40 = (($39) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + 12|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($39) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($43) + (($41*12)|0)|0) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 do {
  if ($48) {
   $50 = HEAP32[$39>>2]|0;
   $51 = ((($43) + (($41*12)|0)|0) + 8|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==($50|0);
   if (!($53)) {
    $54 = (($52) + 1)|0;
    HEAP32[$51>>2] = $54;
    $55 = (($43) + (($41*12)|0)|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = Math_imul($52, $45)|0;
    $58 = (($56) + ($57)|0);
    $59 = ($58|0)==(0|0);
    if (!($59)) {
     $62 = $58;
     break;
    }
   }
   $60 = (__ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($39)|0);
   $62 = $60;
  } else {
   $49 = HEAP32[$47>>2]|0;
   HEAP32[$46>>2] = $49;
   $62 = $47;
  }
 } while(0);
 $61 = $62;
 $63 = (_bitshift64Lshr(($61|0),0,6)|0);
 $64 = tempRet0;
 $65 = (_i64Add(($61|0),0,191,0)|0);
 $66 = tempRet0;
 $67 = (_bitshift64Lshr(($65|0),($66|0),6)|0);
 $68 = tempRet0;
 $69 = (_i64Subtract(1,0,($63|0),($64|0))|0);
 $70 = tempRet0;
 $71 = (_i64Add(($69|0),($70|0),($67|0),($68|0))|0);
 $72 = tempRet0;
 $74 = $71;$75 = $72;$cp$0$i$i = $62;
 while(1) {
  $73 = (($cp$0$i$i) + 64|0);
  $76 = (_i64Add(($74|0),($75|0),-1,-1)|0);
  $77 = tempRet0;
  $78 = ($76|0)==(0);
  $79 = ($77|0)==(0);
  $80 = $78 & $79;
  if ($80) {
   break;
  } else {
   $74 = $76;$75 = $77;$cp$0$i$i = $73;
  }
 }
 HEAP32[$s>>2] = $62;
 $81 = HEAP16[$4>>1]|0;
 $82 = $81&65535;
 $83 = (($s) + 28|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($0) + 64|0);
 $86 = (($s) + 8|0);
 __ZN5physx2Sc5Scene9addShapesEPKPvjjRNS0_8RigidSimEPNS_12PxsRigidBodyERPNS0_8ShapeSimEPNS_9PxBounds3E($this,$87,$82,$84,$0,$85,$86,$outBounds);
 $88 = (($this) + 1428|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + 1)|0;
 HEAP32[$88>>2] = $90;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene20finishBatchInsertionERNS0_19BatchInsertionStateE($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 1224|0);
  $4 = HEAP32[$3>>2]|0;
  __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($4,$1);
 }
 $5 = HEAP32[$state>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($this) + 1228|0);
  $8 = HEAP32[$7>>2]|0;
  __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($8,$5);
 }
 $9 = (($state) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 1220|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($13,$10);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene24initActiveBodiesIteratorERNS0_12BodyIteratorE($this,$activeBodiesIterator) {
 $this = $this|0;
 $activeBodiesIterator = $activeBodiesIterator|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($1) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + ($4<<2)|0);
 $6 = $2;
 $7 = $5;
 $8 = $activeBodiesIterator;
 $9 = $8;
 HEAP32[$9>>2] = $6;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene21setDominanceGroupPairEhhRKNS_20PxDominanceGroupPairE($this,$group1,$group2,$dominance) {
 $this = $this|0;
 $group1 = $group1|0;
 $group2 = $group2|0;
 $dominance = $dominance|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i = 0, $storemerge$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $group1&255;
 $1 = ((($this) + ($0<<2)|0) + 1288|0);
 $2 = Math_fround(HEAPF32[$dominance>>2]);
 $3 = $2 != Math_fround(0.0);
 $4 = $group2&255;
 $5 = 1 << $4;
 if ($3) {
  $6 = HEAP32[$1>>2]|0;
  $7 = $6 | $5;
  $storemerge$i = $7;
 } else {
  $8 = $5 ^ -1;
  $9 = HEAP32[$1>>2]|0;
  $10 = $9 & $8;
  $storemerge$i = $10;
 }
 HEAP32[$1>>2] = $storemerge$i;
 $11 = ((($this) + ($4<<2)|0) + 1288|0);
 $12 = (($dominance) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = $13 != Math_fround(0.0);
 $15 = 1 << $0;
 if ($14) {
  $16 = HEAP32[$11>>2]|0;
  $17 = $16 | $15;
  $storemerge$i1 = $17;
 } else {
  $18 = $15 ^ -1;
  $19 = HEAP32[$11>>2]|0;
  $20 = $19 & $18;
  $storemerge$i1 = $20;
 }
 HEAP32[$11>>2] = $storemerge$i1;
 $21 = (($this) + 1196|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 | 2;
 HEAP32[$21>>2] = $23;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene21getDominanceGroupPairEhh($agg$result,$this,$group1,$group2) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $group1 = $group1|0;
 $group2 = $group2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $group1&255;
 $1 = ((($this) + ($0<<2)|0) + 1288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $group2&255;
 $4 = 1 << $3;
 $5 = $2 & $4;
 $6 = ($5|0)!=(0);
 $7 = $6 ? Math_fround(1.0) : Math_fround(0.0);
 $8 = ((($this) + ($3<<2)|0) + 1288|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = 1 << $0;
 $11 = $9 & $10;
 $12 = ($11|0)!=(0);
 $13 = $12 ? Math_fround(1.0) : Math_fround(0.0);
 HEAPF32[$agg$result>>2] = $7;
 $14 = (($agg$result) + 4|0);
 HEAPF32[$14>>2] = $13;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene18getSolverBatchSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5physx10PxsContext18getSolverBatchSizeEv($3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx2Sc5Scene25setVisualizationParameterENS_24PxVisualizationParameter4EnumEf($this,$param,$value) {
 $this = $this|0;
 $param = $param|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1420|0);
 HEAP8[$0>>0] = 1;
 $1 = (($this) + 1212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1000|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx10PxsContext25setVisualizationParameterENS_24PxVisualizationParameter4EnumEf($4,$param,$value);
 $5 = ($param|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 1416|0);
 HEAPF32[$6>>2] = $value;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene26setVisualizationCullingBoxERKNS_9PxBounds3E($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$box>>2]);
 $5 = (($3) + 6140|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($box) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($3) + 6144|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($box) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($3) + 6148|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($box) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($3) + 6152|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($box) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($3) + 6156|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($box) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($3) + 6160|0);
 HEAPF32[$20>>2] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene26getVisualizationCullingBoxEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 6140|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc5Scene20getMeshContactMarginEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 6164|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 STACKTOP = sp;return (Math_fround($5));
}
function __ZNK5physx2Sc5Scene29getContactCorrelationDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 6168|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 STACKTOP = sp;return (Math_fround($5));
}
function __ZNK5physx2Sc5Scene26getFrictionOffsetThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 144|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 STACKTOP = sp;return (Math_fround($7));
}
function __ZNK5physx2Sc5Scene39getDefaultContactReportStreamBufferSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1088|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc10NPhaseCore39getDefaultContactReportStreamBufferSizeEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx2Sc5Scene21buildActiveTransformsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond10 = 0, $exitcond11 = 0, $i$06 = 0, $i1$03 = 0, $i2$01 = 0, $j$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1164|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1168|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 1212|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$5>>2]|0;
 $9 = ($3|0)==(0);
 if (!($9)) {
  $i$06 = 0;
  while(1) {
   $10 = (($1) + ($i$06<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 4|0);
   HEAP32[$12>>2] = 0;
   $13 = HEAP32[$0>>2]|0;
   $14 = (($13) + ($i$06<<2)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = $16;
   $18 = $17 & -128;
   $19 = $18;
   $20 = HEAP32[$0>>2]|0;
   $21 = (($20) + ($i$06<<2)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = HEAP32[$22>>2]|0;
   $24 = $23;
   $25 = (($24) + 128)|0;
   $26 = $25 & -128;
   $27 = $26;
   $28 = (($i$06) + 1)|0;
   $exitcond11 = ($28|0)==($3|0);
   if ($exitcond11) {
    break;
   } else {
    $i$06 = $28;
   }
  }
 }
 $29 = $7 & -32;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = (($8) + 128|0);
  $32 = (($7) + -1)|0;
  $i1$03 = 0;
  while(1) {
   $j$02 = 0;
   while(1) {
    $35 = (($j$02) + ($i1$03))|0;
    $36 = ($35>>>0)<($32>>>0);
    if ($36) {
     $37 = (($35) + 1)|0;
     $38 = (($8) + ($37<<2)|0);
     $39 = HEAP32[$38>>2]|0;
    }
    $40 = (($8) + ($35<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    __Z20buildActiveTransformPN5physx2Sc5ActorEPPNS0_6ClientEj($41,$1,$3);
    $42 = (($j$02) + 1)|0;
    $exitcond10 = ($42|0)==(32);
    if ($exitcond10) {
     break;
    } else {
     $j$02 = $42;
    }
   }
   $43 = (($i1$03) + 32)|0;
   $44 = ($43>>>0)<($29>>>0);
   if ($44) {
    $i1$03 = $43;
   } else {
    break;
   }
  }
 }
 $33 = ($29>>>0)<($7>>>0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $34 = (($7) + -1)|0;
 $i2$01 = $29;
 while(1) {
  $45 = ($i2$01>>>0)<($34>>>0);
  $46 = (($i2$01) + 1)|0;
  if ($45) {
   $47 = (($8) + ($46<<2)|0);
   $48 = HEAP32[$47>>2]|0;
  }
  $49 = (($8) + ($i2$01<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  __Z20buildActiveTransformPN5physx2Sc5ActorEPPNS0_6ClientEj($50,$1,$3);
  $exitcond = ($46|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $i2$01 = $46;
  }
 }
 STACKTOP = sp;return;
}
function __Z20buildActiveTransformPN5physx2Sc5ActorEPPNS0_6ClientEj($activeActor,$clients,$numClients) {
 $activeActor = $activeActor|0;
 $clients = $clients|0;
 $numClients = $numClients|0;
 var $$pre$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $activeTransform = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $activeTransform = sp;
 $0 = sp + 36|0;
 $1 = (__ZN5physx2Sc8RigidSim10getPxActorEv($activeActor)|0);
 HEAP32[$activeTransform>>2] = $1;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($activeTransform) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 84|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($0,$1);
 $8 = Math_fround(HEAPF32[$0>>2]);
 $9 = (($activeTransform) + 8|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($0) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($activeTransform) + 12|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($0) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($activeTransform) + 16|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($0) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($activeTransform) + 20|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($0) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($activeTransform) + 24|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($0) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($activeTransform) + 28|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($0) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($activeTransform) + 32|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($activeActor) + 52|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 13|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31&255;
 $33 = (($clients) + ($32<<2)|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 2147483647;
 $40 = ($39>>>0)>($36>>>0);
 if (!($40)) {
  (__ZN5physx6shdfnd5ArrayINS_17PxActiveTransformENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($34,$activeTransform)|0);
  $63 = HEAP32[$33>>2]|0;
  $64 = HEAP32[$63>>2]|0;
  $$sum = (($36) + 1)|0;
  $65 = (($64) + (($$sum*36)|0)|0);
  $66 = $65;
  $67 = (($66) + 128)|0;
  $68 = $67 & -128;
  $69 = $68;
  STACKTOP = sp;return;
 }
 $41 = HEAP32[$34>>2]|0;
 $42 = (($41) + (($36*36)|0)|0);
 $43 = ($42|0)==(0|0);
 if ($43) {
  $62 = $36;
 } else {
  $44 = $activeTransform;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = (($44) + 4)|0;
  $48 = $47;
  $49 = HEAP32[$48>>2]|0;
  $50 = $42;
  $51 = $50;
  HEAP32[$51>>2] = $46;
  $52 = (($50) + 4)|0;
  $53 = $52;
  HEAP32[$53>>2] = $49;
  $54 = ((($41) + (($36*36)|0)|0) + 8|0);
  HEAPF32[$54>>2] = $8;
  $55 = ((($41) + (($36*36)|0)|0) + 12|0);
  HEAPF32[$55>>2] = $11;
  $56 = ((($41) + (($36*36)|0)|0) + 16|0);
  HEAPF32[$56>>2] = $14;
  $57 = ((($41) + (($36*36)|0)|0) + 20|0);
  HEAPF32[$57>>2] = $17;
  $58 = ((($41) + (($36*36)|0)|0) + 24|0);
  HEAPF32[$58>>2] = $20;
  $59 = ((($41) + (($36*36)|0)|0) + 28|0);
  HEAPF32[$59>>2] = $23;
  $60 = ((($41) + (($36*36)|0)|0) + 32|0);
  HEAPF32[$60>>2] = $26;
  $$pre$i = HEAP32[$35>>2]|0;
  $62 = $$pre$i;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$35>>2] = $61;
 $63 = HEAP32[$33>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $$sum = (($36) + 1)|0;
 $65 = (($64) + (($$sum*36)|0)|0);
 $66 = $65;
 $67 = (($66) + 128)|0;
 $68 = $67 & -128;
 $69 = $68;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19getActiveTransformsERjh($this,$nbTransformsOut,$client) {
 $this = $this|0;
 $nbTransformsOut = $nbTransformsOut|0;
 $client = $client|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $client&255;
 $1 = (($this) + 1164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$nbTransformsOut>>2] = $6;
 $7 = ($6|0)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP32[$4>>2]|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc5Scene12createClientEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1164|0);
 $2 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__Z15PxGetFoundationv()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $$$i$i$i = $10 ? 468680 : 464392;
 $11 = (FUNCTION_TABLE_iiiiii[$5 & 255]($2,24,$$$i$i$i,463960,3233)|0);
 $12 = (($11) + 16|0);
 HEAP32[$12>>2] = 0;
 $13 = (($11) + 20|0);
 HEAP32[$13>>2] = 0;
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP8[$11+12>>0]=0|0;
 HEAP32[$0>>2] = $11;
 $14 = (($this) + 1172|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = (($this) + 1168|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16>>>0)>($18>>>0);
 if (!($19)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc6ClientENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
  $$pre = HEAP32[$17>>2]|0;
  $25 = $$pre;
  $24 = (($25) + 255)|0;
  $26 = $24&255;
  STACKTOP = sp;return ($26|0);
 }
 $20 = HEAP32[$1>>2]|0;
 $21 = (($20) + ($18<<2)|0);
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  HEAP32[$21>>2] = $11;
 }
 $23 = (($18) + 1)|0;
 HEAP32[$17>>2] = $23;
 $25 = $23;
 $24 = (($25) + 255)|0;
 $26 = $24&255;
 STACKTOP = sp;return ($26|0);
}
function __ZN5physx2Sc5Scene22setClientBehaviorFlagsEhNS_7PxFlagsINS_20PxClientBehaviorFlag4EnumEhEE($this,$client,$clientBehaviorFlags) {
 $this = $this|0;
 $client = $client|0;
 $clientBehaviorFlags = $clientBehaviorFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $client&255;
 $1 = (($this) + 1164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 12|0);
 $6 = HEAP8[$clientBehaviorFlags>>0]|0;
 HEAP8[$5>>0] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene30setClothInterCollisionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vif[$5 & 255]($1,$distance);
 }
 $6 = (($this) + 156|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vif[$11 & 255]($7,$distance);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene30getClothInterCollisionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc5Scene31setClothInterCollisionStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vif[$5 & 255]($1,$stiffness);
 }
 $6 = (($this) + 156|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vif[$11 & 255]($7,$stiffness);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene31getClothInterCollisionStiffnessEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc5Scene34setClothInterCollisionNbIterationsEj($this,$nbIterations) {
 $this = $this|0;
 $nbIterations = $nbIterations|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($1,$nbIterations);
 }
 $6 = (($this) + 156|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095]($7,$nbIterations);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene34getClothInterCollisionNbIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc5Scene11onBodySleepEPNS0_7BodySimE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 1164|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 $8 = (($body) + 144|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9&65535;
 if ($7) {
  $39 = $10 & 16;
  $40 = ($39|0)==(0);
  do {
   if ($40) {
    $41 = (($this) + 1136|0);
    $42 = (($body) + 52|0);
    $43 = HEAP32[$42>>2]|0;
    HEAP32[$1>>2] = $43;
    $44 = (($this) + 1144|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = $45 & 2147483647;
    $47 = (($this) + 1140|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($46>>>0)>($48>>>0);
    if (!($49)) {
     (__ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($41,$1)|0);
     $$pre = HEAP16[$8>>1]|0;
     $55 = $$pre;
     break;
    }
    $50 = HEAP32[$41>>2]|0;
    $51 = (($50) + ($48<<2)|0);
    $52 = ($51|0)==(0|0);
    if (!($52)) {
     HEAP32[$51>>2] = $43;
    }
    $53 = (($48) + 1)|0;
    HEAP32[$47>>2] = $53;
    $55 = $9;
   } else {
    $55 = $9;
   }
  } while(0);
  $54 = $55&65535;
  $56 = $54 | 16;
  $57 = $56&65535;
  HEAP16[$8>>1] = $57;
  STACKTOP = sp;return;
 }
 $11 = $10 & 128;
 $12 = ($11|0)==(0);
 if ($12) {
  $17 = $9;
 } else {
  $13 = $10 & 65407;
  $14 = $13&65535;
  HEAP16[$8>>1] = $14;
  $15 = (($this) + 1160|0);
  HEAP8[$15>>0] = 0;
  $17 = $14;
 }
 $16 = $17&65535;
 $18 = $16 | 64;
 $19 = $18&65535;
 HEAP16[$8>>1] = $19;
 $20 = $16 & 16;
 $21 = ($20|0)==(0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 1136|0);
 $23 = (($body) + 52|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$0>>2] = $24;
 $25 = (($this) + 1144|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26 & 2147483647;
 $28 = (($this) + 1140|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27>>>0)>($29>>>0);
 if ($30) {
  $31 = HEAP32[$22>>2]|0;
  $32 = (($31) + ($29<<2)|0);
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   HEAP32[$32>>2] = $24;
  }
  $34 = (($29) + 1)|0;
  HEAP32[$28>>2] = $34;
  $36 = $19;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($22,$0)|0);
  $$pre4 = HEAP16[$8>>1]|0;
  $36 = $$pre4;
 }
 $35 = $36&65535;
 $37 = $35 | 16;
 $38 = $37&65535;
 HEAP16[$8>>1] = $38;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene12onBodyWakeUpEPNS0_7BodySimE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($body) + 144|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $10 = $9 & 64;
 $11 = ($10|0)==(0);
 if ($11) {
  $16 = $8;
 } else {
  $12 = $9 & 65471;
  $13 = $12&65535;
  HEAP16[$7>>1] = $13;
  $14 = (($this) + 1161|0);
  HEAP8[$14>>0] = 0;
  $16 = $13;
 }
 $15 = $16&65535;
 $17 = $15 | 128;
 $18 = $17&65535;
 HEAP16[$7>>1] = $18;
 $19 = $15 & 32;
 $20 = ($19|0)==(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 1148|0);
 $22 = (($body) + 52|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$0>>2] = $23;
 $24 = (($this) + 1156|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = (($this) + 1152|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($26>>>0)>($28>>>0);
 if ($29) {
  $30 = HEAP32[$21>>2]|0;
  $31 = (($30) + ($28<<2)|0);
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   HEAP32[$31>>2] = $23;
  }
  $33 = (($28) + 1)|0;
  HEAP32[$27>>2] = $33;
  $35 = $18;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($21,$0)|0);
  $$pre = HEAP16[$7>>1]|0;
  $35 = $$pre;
 }
 $34 = $35&65535;
 $36 = $34 | 32;
 $37 = $36&65535;
 HEAP16[$7>>1] = $37;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene7isValidEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)!=(0|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx2Sc5Scene17addParticleSystemERNS0_18ParticleSystemCoreE($this,$ps) {
 $this = $this|0;
 $ps = $ps|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 464872 : 464392;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,400,$$$i$i$i,463960,3520)|0);
 __ZN5physx2Sc17ParticleSystemSimC2ERNS0_5SceneERNS0_18ParticleSystemCoreE($10,$this,$ps);
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($12,32,463960,3524,464232,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $13 = (($this) + 116|0);
 HEAP32[$0>>2] = $ps;
 $14 = (($this) + 124|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = (($this) + 120|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16>>>0)>($18>>>0);
 if (!($19)) {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc18ParticleSystemCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($13,$0)|0);
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$13>>2]|0;
 $21 = (($20) + ($18<<2)|0);
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  HEAP32[$21>>2] = $ps;
 }
 $23 = (($18) + 1)|0;
 HEAP32[$17>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene20removeParticleSystemERNS0_18ParticleSystemCoreEb($this,$ps,$isRelease) {
 $this = $this|0;
 $ps = $ps|0;
 $isRelease = $isRelease|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$lcssa = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $$phi$trans$insert = (($this) + 116|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 L1: do {
  if ($2) {
   $9 = 0;$i$0$lcssa = 0;
  } else {
   $i$01 = 0;
   while(1) {
    $5 = (($$pre) + ($i$01<<2)|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)==($ps|0);
    $4 = (($i$01) + 1)|0;
    if ($7) {
     $9 = $1;$i$0$lcssa = $i$01;
     break L1;
    }
    $3 = ($4>>>0)<($1>>>0);
    if ($3) {
     $i$01 = $4;
    } else {
     $9 = $1;$i$0$lcssa = $4;
     break;
    }
   }
  }
 } while(0);
 $8 = (($9) + -1)|0;
 HEAP32[$0>>2] = $8;
 $10 = (($$pre) + ($8<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($$pre) + ($i$0$lcssa<<2)|0);
 HEAP32[$12>>2] = $11;
 $13 = (__ZNK5physx2Sc18ParticleSystemCore6getSimEv($ps)|0);
 __ZN5physx2Sc17ParticleSystemSim7releaseEb($13,$isRelease);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene20getNbParticleSystemsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc5Scene18getParticleSystemsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc5Scene8addClothERNS0_9ClothCoreE($this,$clothCore) {
 $this = $this|0;
 $clothCore = $clothCore|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cloth$0 = 0, $type$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 8|0;
 $1 = sp + 4|0;
 $2 = (($clothCore) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNK5physx2Sc9ClothCore13getClothFlagsEv($0,$clothCore);
 $4 = HEAP16[$0>>1]|0;
 $5 = $4&65535;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   $cloth$0 = $3;$type$0 = 0;
  } else {
   $8 = ((($this) + ($6<<2)|0) + 152|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = ((($this) + ($6<<2)|0) + 168|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 20|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (FUNCTION_TABLE_iii[$15 & 4095]($12,$3)|0);
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     __ZN5physx2Sc9ClothCore11switchClothEPNS_5cloth5ClothE($clothCore,$16);
     $cloth$0 = $16;$type$0 = $6;
     break;
    }
   }
   $18 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($18,2,463960,3595,464272,$vararg_buffer);
   __ZN5physx2Sc9ClothCore12setClothFlagENS_11PxClothFlag4EnumEb($clothCore,1,0);
   $cloth$0 = $3;$type$0 = 0;
  }
 } while(0);
 $19 = ((($this) + ($type$0<<2)|0) + 152|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vii[$23 & 4095]($20,$cloth$0);
 $24 = (($this) + 140|0);
 HEAP32[$1>>2] = $clothCore;
 $25 = (($this) + 148|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26 & 2147483647;
 $28 = (($this) + 144|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27>>>0)>($29>>>0);
 if ($30) {
  $31 = HEAP32[$24>>2]|0;
  $32 = (($31) + ($29<<2)|0);
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   HEAP32[$32>>2] = $clothCore;
  }
  $34 = (($29) + 1)|0;
  HEAP32[$28>>2] = $34;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc9ClothCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($24,$1)|0);
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (__Z15PxGetFoundationv()|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (FUNCTION_TABLE_ii[$42 & 4095]($39)|0);
 $$$i$i$i = $43 ? 464424 : 464392;
 $44 = (FUNCTION_TABLE_iiiiii[$38 & 255]($35,140,$$$i$i$i,463960,3605)|0);
 __ZN5physx2Sc8ClothSimC2ERNS0_5SceneERNS0_9ClothCoreE($44,$this,$clothCore);
 STACKTOP = sp;return 1;
}
function __ZN5physx2Sc5Scene11removeClothERNS0_9ClothCoreE($this,$clothCore) {
 $this = $this|0;
 $clothCore = $clothCore|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $index$0$lcssa$i = 0, $index$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 140|0);
  $4 = HEAP32[$3>>2]|0;
  $index$01$i = 0;
  while(1) {
   $7 = (($4) + ($index$01$i<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==($clothCore|0);
   $6 = (($index$01$i) + 1)|0;
   if ($9) {
    $index$0$lcssa$i = $index$01$i;
    break;
   }
   $5 = ($6>>>0)<($1>>>0);
   if ($5) {
    $index$01$i = $6;
   } else {
    $index$0$lcssa$i = $6;
    break;
   }
  }
  $10 = ($index$0$lcssa$i|0)==($1|0);
  if (!($10)) {
   $11 = (($1) + -1)|0;
   HEAP32[$0>>2] = $11;
   $12 = (($4) + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($4) + ($index$0$lcssa$i<<2)|0);
   HEAP32[$14>>2] = $13;
  }
 }
 $15 = (($clothCore) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
 $21 = (($20) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($this) + ($22<<2)|0) + 152|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vii[$27 & 4095]($24,$16);
 $28 = ($22|0)==(0);
 if (!($28)) {
  $29 = (($this) + 168|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 20|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (FUNCTION_TABLE_iii[$33 & 4095]($30,$16)|0);
  __ZN5physx2Sc9ClothCore11switchClothEPNS_5cloth5ClothE($clothCore,$34);
 }
 $35 = (__ZNK5physx2Sc9ClothCore6getSimEv($clothCore)|0);
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$35>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vi[$39 & 4095]($35);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc5Scene18getNbArticulationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc5Scene16getArticulationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Sc5Scene16getNbConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc5Scene14getConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc5Scene15createAggregateEPvb($this,$userData,$selfCollisions) {
 $this = $this|0;
 $userData = $userData|0;
 $selfCollisions = $selfCollisions|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN5physx14PxsAABBManager15createAggregateEPvb($5,$userData,$selfCollisions)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx2Sc5Scene15deleteAggregateEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx14PxsAABBManager15deleteAggregateEj($5,$id);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$$i$i$i = 0, $$op = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$021 = 0, $exitcond = 0, $exitcond24 = 0, $exitcond25 = 0, $i$012 = 0, $i1$018 = 0, $i2$06 = 0, $i3$02 = 0, $i4$01 = 0, $idx$0$lcssa = 0, $idx$014 = 0, $j$08 = 0, $prefetchPtr$013 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1000|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext11shiftOriginERKNS_6PxVec3E($3,$shift);
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx14PxsAABBManager11shiftOriginERKNS_6PxVec3E($5,$shift);
 $6 = (($this) + 1164|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 1168|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (($shift) + 4|0);
  $12 = (($shift) + 8|0);
  $c$021 = 0;
  while(1) {
   $17 = (($7) + ($c$021<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($18) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21>>>0) / 6)&-1;
   $23 = ($21>>>0)>(5);
   if ($23) {
    $24 = (($19) + 256|0);
    $25 = ($21>>>0)>(11);
    $i$012 = 0;$idx$014 = 0;$prefetchPtr$013 = $24;
    while(1) {
     $26 = (($prefetchPtr$013) + 128|0);
     $27 = (($idx$014) + 6)|0;
     $j$08 = $idx$014;
     while(1) {
      $28 = Math_fround(HEAPF32[$shift>>2]);
      $29 = ((($19) + (($j$08*36)|0)|0) + 24|0);
      $30 = Math_fround(HEAPF32[$29>>2]);
      $31 = Math_fround($30 - $28);
      HEAPF32[$29>>2] = $31;
      $32 = Math_fround(HEAPF32[$11>>2]);
      $33 = ((($19) + (($j$08*36)|0)|0) + 28|0);
      $34 = Math_fround(HEAPF32[$33>>2]);
      $35 = Math_fround($34 - $32);
      HEAPF32[$33>>2] = $35;
      $36 = Math_fround(HEAPF32[$12>>2]);
      $37 = ((($19) + (($j$08*36)|0)|0) + 32|0);
      $38 = Math_fround(HEAPF32[$37>>2]);
      $39 = Math_fround($38 - $36);
      HEAPF32[$37>>2] = $39;
      $40 = (($j$08) + 1)|0;
      $41 = ($40>>>0)<($27>>>0);
      if ($41) {
       $j$08 = $40;
      } else {
       break;
      }
     }
     $42 = (($prefetchPtr$013) + 256|0);
     $43 = (($i$012) + 1)|0;
     $44 = ($43>>>0)<($22>>>0);
     if ($44) {
      $i$012 = $43;$idx$014 = $27;$prefetchPtr$013 = $42;
     } else {
      break;
     }
    }
    $$op = ($22*6)|0;
    $45 = $25 ? $$op : 6;
    $idx$0$lcssa = $45;
   } else {
    $idx$0$lcssa = 0;
   }
   $46 = ($idx$0$lcssa>>>0)<($21>>>0);
   if ($46) {
    $i1$018 = $idx$0$lcssa;
    while(1) {
     $47 = Math_fround(HEAPF32[$shift>>2]);
     $48 = ((($19) + (($i1$018*36)|0)|0) + 24|0);
     $49 = Math_fround(HEAPF32[$48>>2]);
     $50 = Math_fround($49 - $47);
     HEAPF32[$48>>2] = $50;
     $51 = Math_fround(HEAPF32[$11>>2]);
     $52 = ((($19) + (($i1$018*36)|0)|0) + 28|0);
     $53 = Math_fround(HEAPF32[$52>>2]);
     $54 = Math_fround($53 - $51);
     HEAPF32[$52>>2] = $54;
     $55 = Math_fround(HEAPF32[$12>>2]);
     $56 = ((($19) + (($i1$018*36)|0)|0) + 32|0);
     $57 = Math_fround(HEAPF32[$56>>2]);
     $58 = Math_fround($57 - $55);
     HEAPF32[$56>>2] = $58;
     $59 = (($i1$018) + 1)|0;
     $exitcond24 = ($59|0)==($21|0);
     if ($exitcond24) {
      break;
     } else {
      $i1$018 = $59;
     }
    }
   }
   $60 = (($c$021) + 1)|0;
   $exitcond25 = ($60|0)==($9|0);
   if ($exitcond25) {
    break;
   } else {
    $c$021 = $60;
   }
  }
 }
 $13 = (($this) + 72|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = (($this) + 68|0);
  $i2$06 = 0;
  while(1) {
   $65 = HEAP32[$16>>2]|0;
   $66 = (($65) + ($i2$06<<2)|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($67) + 28|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + 16|0);
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_vii[$72 & 4095]($69,$shift);
   $73 = (($i2$06) + 1)|0;
   $74 = HEAP32[$13>>2]|0;
   $75 = ($73>>>0)<($74>>>0);
   if ($75) {
    $i2$06 = $73;
   } else {
    break;
   }
  }
 }
 $61 = (($this) + 144|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if (!($63)) {
  $64 = (($this) + 140|0);
  $i3$02 = 0;
  while(1) {
   $76 = HEAP32[$64>>2]|0;
   $77 = (($76) + ($i3$02<<2)|0);
   $78 = HEAP32[$77>>2]|0;
   __ZN5physx2Sc9ClothCore13onOriginShiftERKNS_6PxVec3E($78,$shift);
   $79 = (($i3$02) + 1)|0;
   $80 = HEAP32[$61>>2]|0;
   $81 = ($79>>>0)<($80>>>0);
   if ($81) {
    $i3$02 = $79;
   } else {
    break;
   }
  }
 }
 $82 = (($this) + 120|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($83|0)==(0);
 if ($84) {
  STACKTOP = sp;return;
 }
 $85 = (($this) + 116|0);
 $i4$01 = 0;
 while(1) {
  $86 = HEAP32[$85>>2]|0;
  $87 = (($86) + ($i4$01<<2)|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (__ZNK5physx2Sc18ParticleSystemCore6getSimEv($88)|0);
  __ZN5physx2Sc17ParticleSystemSim7releaseEb($89,0);
  __ZN5physx2Sc18ParticleSystemCore13onOriginShiftERKNS_6PxVec3E($88,$shift);
  $90 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($91) + 8|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (__Z15PxGetFoundationv()|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($95) + 24|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (FUNCTION_TABLE_ii[$97 & 4095]($94)|0);
  $$$i$i$i = $98 ? 464872 : 464392;
  $99 = (FUNCTION_TABLE_iiiiii[$93 & 255]($90,400,$$$i$i$i,463960,3784)|0);
  __ZN5physx2Sc17ParticleSystemSimC2ERNS0_5SceneERNS0_18ParticleSystemCoreE($99,$this,$88);
  $100 = ($99|0)==(0|0);
  if ($100) {
   $101 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($101,32,463960,3787,464336,$vararg_buffer);
  }
  $102 = (($i4$01) + 1)|0;
  $exitcond = ($102|0)==($83|0);
  if ($exitcond) {
   break;
  } else {
   $i4$01 = $102;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19addBroadPhaseVolumeERKNS_9PxBounds3EjRKNS_9AABBMgrIdERNS0_8ShapeSimE($this,$bounds,$actorGroup,$aabbMgrId,$shapeSim) {
 $this = $this|0;
 $bounds = $bounds|0;
 $actorGroup = $actorGroup|0;
 $aabbMgrId = $aabbMgrId|0;
 $shapeSim = $shapeSim|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($shapeSim)|0);
 $2 = (($1) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = $aabbMgrId;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 __ZN5physx2Sc8ShapeSim20createLowLevelVolumeEjRKNS_9PxBounds3EjNS_9AABBMgrIdE($shapeSim,$actorGroup,$bounds,$4,$0);
 $15 = (($this) + 1088|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1192|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 1)|0;
 HEAP32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19addBroadPhaseVolumeERKNS_9PxBounds3ERNS0_8ShapeSimE($this,$bounds,$shapeSim) {
 $this = $this|0;
 $bounds = $bounds|0;
 $shapeSim = $shapeSim|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($shapeSim)|0);
 $2 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($shapeSim)|0);
 $3 = (($2) + 50|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $31 = 0;
 } else {
  $6 = (($2) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 2)|0;
  $31 = $8;
 }
 $9 = ($1|0)==(0|0);
 if ($9) {
  $22 = 1073741823;$23 = 0;$25 = 0;$26 = 1073741823;
 } else {
  $10 = (($1) + 132|0);
  $11 = $10;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $22 = $13;$23 = 0;$25 = 0;$26 = $16;
 }
 $17 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($shapeSim)|0);
 $18 = (($17) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = $22 | $23;
 $24 = $25 | $26;
 $27 = $0;
 $28 = $27;
 HEAP32[$28>>2] = $21;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $24;
 __ZN5physx2Sc8ShapeSim20createLowLevelVolumeEjRKNS_9PxBounds3EjNS_9AABBMgrIdE($shapeSim,$31,$bounds,$20,$0);
 $32 = (($this) + 1088|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 1192|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$37>>2] = $39;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19addBroadPhaseVolumeERNS0_19ParticlePacketShapeE($this,$particleShape) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bounds = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bounds = sp + 8|0;
 $0 = sp;
 $1 = (($particleShape) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($bounds,$2);
 $6 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($particleShape)|0);
 $7 = (__ZNK5physx2Sc17ParticleSystemSim7getCoreEv($6)|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$0>>2] = 1073741823;
 $9 = (($0) + 4|0);
 HEAP32[$9>>2] = 1073741823;
 (__ZN5physx2Sc7Element20createLowLevelVolumeEjRKNS_9PxBounds3EjRKNS_9AABBMgrIdE($particleShape,1,$bounds,$8,$0)|0);
 $10 = (($this) + 1088|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1192|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$15>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene19addBroadPhaseVolumeERNS0_10ClothShapeE($this,$clothShape) {
 $this = $this|0;
 $clothShape = $clothShape|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bounds = sp + 8|0;
 $0 = sp;
 $1 = (($clothShape) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNK5physx2Sc9ClothCore14getWorldBoundsEv($bounds,$2);
 $3 = HEAP32[$1>>2]|0;
 $4 = (__ZNK5physx2Sc9ClothCore6getSimEv($3)|0);
 $5 = (($4) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = 1073741823;
 $8 = (($0) + 4|0);
 HEAP32[$8>>2] = 1073741823;
 (__ZN5physx2Sc7Element20createLowLevelVolumeEjRKNS_9PxBounds3EjRKNS_9AABBMgrIdE($clothShape,1,$bounds,$7,$0)|0);
 $9 = (($this) + 1088|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 1192|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 32|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 1)|0;
 HEAP32[$14>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene22removeBroadPhaseVolumeEbRNS0_8ShapeSimE($this,$wakeOnLostTouch,$shape) {
 $this = $this|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 $shape = $shape|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wakeOnLostTouch ? 4 : 0;
 $1 = (($this) + 1088|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx2Sc10NPhaseCore15onVolumeRemovedEPNS0_7ElementEj($2,$shape,$0);
 (__ZN5physx2Sc8ShapeSim21destroyLowLevelVolumeEv($shape)|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1192|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 1)|0;
 HEAP32[$7>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene22removeBroadPhaseVolumeERNS0_19ParticlePacketShapeE($this,$particleShape) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1088|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc10NPhaseCore15onVolumeRemovedEPNS0_7ElementEj($1,$particleShape,0);
 (__ZN5physx2Sc7Element21destroyLowLevelVolumeEv($particleShape)|0);
 $2 = HEAP32[$0>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1192|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 HEAP32[$6>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Scene22removeBroadPhaseVolumeERNS0_10ClothShapeE($this,$clothShape) {
 $this = $this|0;
 $clothShape = $clothShape|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1088|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc10NPhaseCore15onVolumeRemovedEPNS0_7ElementEj($1,$clothShape,0);
 (__ZN5physx2Sc7Element21destroyLowLevelVolumeEv($clothShape)|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc9ClothCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 464616 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc18ParticleSystemCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 464736 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 4;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 465008 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<4)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
   }
   $25 = (($$012$i) + 16|0);
   $26 = (($$03$i) + 16|0);
   $27 = ($25>>>0)<($20>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $19;
 }
 $28 = (($21) + ($29<<4)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  ;HEAP32[$28+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$a+12>>2]|0;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = HEAP32[$18>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$18>>2] = $40;
 $41 = (($21) + ($39<<4)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 465152 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx2Cm26PreallocatingRegionManager16deallocateMemoryEPh($this,$element) {
 $this = $this|0;
 $element = $element|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $first$0$ph8 = 0, $first$06 = 0;
 var $last$0$ph7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = ($element|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $$pre = (($this) + 16|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $6 = (($this) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($this) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  __ZN5physx6shdfnd4sortINS_2Cm19PreallocatingRegionENS0_4LessIS3_EENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($7,$9,$0,$1);
  $$pre$phiZ2D = $8;
 }
 $10 = HEAP32[$this>>2]|0;
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = Math_imul($12, $10)|0;
 $14 = HEAP32[$$pre$phiZ2D>>2]|0;
 $15 = (($14) + -1)|0;
 $16 = ($15|0)<(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $first$0$ph8 = 0;$last$0$ph7 = $15;
 L11: while(1) {
  $first$06 = $first$0$ph8;
  while(1) {
   $22 = (($first$06) + ($last$0$ph7))|0;
   $20 = $22 >> 1;
   $23 = (($18) + (($20*12)|0)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24>>>0)>($element>>>0);
   if (!($25)) {
    $26 = (($24) + ($13)|0);
    $27 = ($26>>>0)>($element>>>0);
    if ($27) {
     label = 11;
     break L11;
    }
   }
   $33 = ($24>>>0)<($element>>>0);
   if (!($33)) {
    break;
   }
   $19 = (($20) + 1)|0;
   $21 = ($20|0)<($last$0$ph7|0);
   if ($21) {
    $first$06 = $19;
   } else {
    label = 16;
    break L11;
   }
  }
  $34 = (($20) + -1)|0;
  $35 = ($first$06|0)>($34|0);
  if ($35) {
   label = 16;
   break;
  } else {
   $first$0$ph8 = $first$06;$last$0$ph7 = $34;
  }
 }
 if ((label|0) == 11) {
  $28 = ((($18) + (($20*12)|0)|0) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$element>>2] = $29;
  HEAP32[$28>>2] = $element;
  $30 = HEAP8[$3>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if (!($31)) {
   $32 = (($this) + 8|0);
   HEAP32[$32>>2] = $20;
  }
  HEAP8[$3>>0] = 0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd4sortINS_2Cm19PreallocatingRegionENS0_4LessIS3_EENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph12 = 0, $$ph12$be = 0, $$ph13 = 0, $$ph13$be = 0, $$ph14 = 0, $$ph14$be = 0, $$ph15 = 0, $$ph15$be = 0, $$ph16 = 0, $$ph16$be = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre4$i$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0, $m$01$i = 0, $or$cond = 0, $or$cond7 = 0, $or$cond8 = 0, $stackMem = 0, $tmp$i1$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $tmp$i1$i = sp + 136|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph12 = $5;$$ph13 = 32;$$ph14 = 0;$$ph15 = 0;$$ph16 = $6;
  L3: while(1) {
   $10 = $$ph15;$54 = $$ph14;$9 = $$ph16;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + (($j$02$i*12)|0)|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($elements) + (($m$01$i*12)|0)|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = ($15>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + (($j$0$m$0$i*12)|0)|0);
      $22 = (($elements) + (($i$03$i*12)|0)|0);
      ;HEAP32[$tmp$i1$i+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$tmp$i1$i+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$tmp$i1$i+8>>2]=HEAP32[$21+8>>2]|0;
      ;HEAP32[$21+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$22+8>>2]|0;
      ;HEAP32[$22+0>>2]=HEAP32[$tmp$i1$i+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$tmp$i1$i+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$tmp$i1$i+8>>2]|0;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $109 = ($54|0)==(0);
    if ($109) {
     break L3;
    }
    $110 = (($54) + -1)|0;
    $111 = (($$ph12) + ($110<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($54) + -2)|0;
    $114 = (($$ph12) + ($113<<2)|0);
    $115 = HEAP32[$114>>2]|0;
    $10 = $115;$54 = $113;$9 = $112;
   }
   $23 = (($9) + ($10))|0;
   $24 = (($23|0) / 2)&-1;
   $25 = (($elements) + (($24*12)|0)|0);
   $26 = (($elements) + (($10*12)|0)|0);
   $27 = HEAP32[$25>>2]|0;
   $28 = HEAP32[$26>>2]|0;
   $29 = ($27>>>0)<($28>>>0);
   if ($29) {
    ;HEAP32[$tmp$i1$i+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$tmp$i1$i+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$tmp$i1$i+8>>2]=HEAP32[$26+8>>2]|0;
    ;HEAP32[$26+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$25+8>>2]|0;
    ;HEAP32[$25+0>>2]=HEAP32[$tmp$i1$i+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$tmp$i1$i+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$tmp$i1$i+8>>2]|0;
    $$pre$i$i = HEAP32[$26>>2]|0;
    $33 = $$pre$i$i;
   } else {
    $33 = $28;
   }
   $30 = (($elements) + (($9*12)|0)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31>>>0)<($33>>>0);
   if ($32) {
    ;HEAP32[$tmp$i1$i+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$tmp$i1$i+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$tmp$i1$i+8>>2]=HEAP32[$26+8>>2]|0;
    ;HEAP32[$26+0>>2]=HEAP32[$30+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$30+8>>2]|0;
    ;HEAP32[$30+0>>2]=HEAP32[$tmp$i1$i+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$tmp$i1$i+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$tmp$i1$i+8>>2]|0;
    $$pre4$i$i = HEAP32[$30>>2]|0;
    $36 = $$pre4$i$i;
   } else {
    $36 = $31;
   }
   $34 = HEAP32[$25>>2]|0;
   $35 = ($36>>>0)<($34>>>0);
   if ($35) {
    ;HEAP32[$tmp$i1$i+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$tmp$i1$i+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$tmp$i1$i+8>>2]=HEAP32[$25+8>>2]|0;
    ;HEAP32[$25+0>>2]=HEAP32[$30+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$30+8>>2]|0;
    ;HEAP32[$30+0>>2]=HEAP32[$tmp$i1$i+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$tmp$i1$i+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$tmp$i1$i+8>>2]|0;
    $$pre$phi$i$iZ2D = $25;
   } else {
    $$pre$phi$i$iZ2D = $25;
   }
   $37 = (($9) + -1)|0;
   $38 = (($elements) + (($37*12)|0)|0);
   ;HEAP32[$tmp$i1$i+0>>2]=HEAP32[$$pre$phi$i$iZ2D+0>>2]|0;HEAP32[$tmp$i1$i+4>>2]=HEAP32[$$pre$phi$i$iZ2D+4>>2]|0;HEAP32[$tmp$i1$i+8>>2]=HEAP32[$$pre$phi$i$iZ2D+8>>2]|0;
   ;HEAP32[$$pre$phi$i$iZ2D+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$$pre$phi$i$iZ2D+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$$pre$phi$i$iZ2D+8>>2]=HEAP32[$38+8>>2]|0;
   ;HEAP32[$38+0>>2]=HEAP32[$tmp$i1$i+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$tmp$i1$i+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$tmp$i1$i+8>>2]|0;
   $i$0$ph$i = $10;$j$0$ph$i = $37;
   while(1) {
    $39 = HEAP32[$38>>2]|0;
    $i$0$i = $i$0$ph$i;
    while(1) {
     $40 = (($i$0$i) + 1)|0;
     $41 = (($elements) + (($40*12)|0)|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42>>>0)<($39>>>0);
     if ($43) {
      $i$0$i = $40;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $44 = (($j$1$i) + -1)|0;
     $45 = (($elements) + (($44*12)|0)|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($39>>>0)<($46>>>0);
     if ($47) {
      $j$1$i = $44;
     } else {
      break;
     }
    }
    $48 = ($40|0)<($44|0);
    if (!($48)) {
     break;
    }
    ;HEAP32[$tmp$i1$i+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$tmp$i1$i+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$tmp$i1$i+8>>2]=HEAP32[$41+8>>2]|0;
    ;HEAP32[$41+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$45+8>>2]|0;
    ;HEAP32[$45+0>>2]=HEAP32[$tmp$i1$i+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$tmp$i1$i+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$tmp$i1$i+8>>2]|0;
    $i$0$ph$i = $40;$j$0$ph$i = $44;
   }
   ;HEAP32[$tmp$i1$i+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$tmp$i1$i+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$tmp$i1$i+8>>2]=HEAP32[$41+8>>2]|0;
   ;HEAP32[$41+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$38+8>>2]|0;
   ;HEAP32[$38+0>>2]=HEAP32[$tmp$i1$i+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$tmp$i1$i+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$tmp$i1$i+8>>2]|0;
   $49 = (($40) - ($10))|0;
   $50 = (($9) - ($40))|0;
   $51 = ($49|0)<($50|0);
   if ($51) {
    $52 = (($$ph13) + -1)|0;
    $53 = ($54>>>0)<($52>>>0);
    if ($53) {
     $125 = $$ph;$126 = $$ph13;$78 = $$ph12;
    } else {
     $55 = $$ph13 << 1;
     $56 = $$ph13 << 3;
     $57 = ($56|0)==(0);
     if ($57) {
      $69 = 0;
     } else {
      $58 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = (($59) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = (__Z15PxGetFoundationv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 24|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (FUNCTION_TABLE_ii[$65 & 4095]($62)|0);
      $$$i$i$i4 = $66 ? 465360 : 464392;
      $67 = (FUNCTION_TABLE_iiiiii[$61 & 255]($58,$56,$$$i$i$i4,465272,148)|0);
      $69 = $67;
     }
     $68 = $54 << 2;
     _memcpy(($69|0),($$ph12|0),($68|0))|0;
     $70 = ($$ph<<24>>24)==(0);
     $71 = ($$ph12|0)==(0|0);
     $or$cond = $70 | $71;
     if ($or$cond) {
      $125 = 1;$126 = $55;$78 = $69;
     } else {
      $72 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($73) + 12|0);
      $75 = HEAP32[$74>>2]|0;
      FUNCTION_TABLE_vii[$75 & 4095]($72,$$ph12);
      $125 = 1;$126 = $55;$78 = $69;
     }
    }
    $76 = (($54) + 1)|0;
    $77 = (($78) + ($54<<2)|0);
    HEAP32[$77>>2] = $10;
    $79 = (($78) + ($76<<2)|0);
    HEAP32[$79>>2] = $i$0$i;
    $80 = (($i$0$i) + 2)|0;
    $$ph$be = $125;$$ph12$be = $78;$$ph13$be = $126;$$ph15$be = $80;$$ph16$be = $9;
   } else {
    $81 = (($i$0$i) + 2)|0;
    $82 = (($$ph13) + -1)|0;
    $83 = ($54>>>0)<($82>>>0);
    if ($83) {
     $107 = $$ph12;$127 = $$ph;$128 = $$ph13;
    } else {
     $84 = $$ph13 << 1;
     $85 = $$ph13 << 3;
     $86 = ($85|0)==(0);
     if ($86) {
      $98 = 0;
     } else {
      $87 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (($88) + 8|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = (__Z15PxGetFoundationv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 24|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (FUNCTION_TABLE_ii[$94 & 4095]($91)|0);
      $$$i$i$i = $95 ? 465360 : 464392;
      $96 = (FUNCTION_TABLE_iiiiii[$90 & 255]($87,$85,$$$i$i$i,465272,148)|0);
      $98 = $96;
     }
     $97 = $54 << 2;
     _memcpy(($98|0),($$ph12|0),($97|0))|0;
     $99 = ($$ph<<24>>24)==(0);
     $100 = ($$ph12|0)==(0|0);
     $or$cond7 = $99 | $100;
     if ($or$cond7) {
      $107 = $98;$127 = 1;$128 = $84;
     } else {
      $101 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = (($102) + 12|0);
      $104 = HEAP32[$103>>2]|0;
      FUNCTION_TABLE_vii[$104 & 4095]($101,$$ph12);
      $107 = $98;$127 = 1;$128 = $84;
     }
    }
    $105 = (($54) + 1)|0;
    $106 = (($107) + ($54<<2)|0);
    HEAP32[$106>>2] = $81;
    $108 = (($107) + ($105<<2)|0);
    HEAP32[$108>>2] = $9;
    $$ph$be = $127;$$ph12$be = $107;$$ph13$be = $128;$$ph15$be = $10;$$ph16$be = $i$0$i;
   }
   $$ph14$be = (($54) + 2)|0;
   $$ph = $$ph$be;$$ph12 = $$ph12$be;$$ph13 = $$ph13$be;$$ph14 = $$ph14$be;$$ph15 = $$ph15$be;$$ph16 = $$ph16$be;
  }
  $116 = ($$ph<<24>>24)==(0);
  $117 = ($$ph12|0)==(0|0);
  $or$cond8 = $116 | $117;
  if (!($or$cond8)) {
   $118 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = (($119) + 12|0);
   $121 = HEAP32[$120>>2]|0;
   FUNCTION_TABLE_vii[$121 & 4095]($118,$$ph12);
  }
 }
 $122 = HEAP8[$4>>0]|0;
 $123 = ($122<<24>>24)==(0);
 if ($123) {
  STACKTOP = sp;return;
 }
 $124 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$124);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm26PreallocatingRegionManager15searchForMemoryEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i1 = 0, $$0$i25 = 0, $$pre$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$013 = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 12|0;
 $tmp = sp;
 $1 = (($this) + 12|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($3|0)==(0);
 L1: do {
  if (!($9)) {
   $i$013 = 0;
   while(1) {
    $10 = ($i$013|0)==($5|0);
    if (!($10)) {
     $11 = HEAP32[$1>>2]|0;
     $12 = ((($11) + (($i$013*12)|0)|0) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if (!($14)) {
      label = 5;
      break;
     }
     $16 = ((($11) + (($i$013*12)|0)|0) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==($6|0);
     if (!($18)) {
      $19 = (($17) + 1)|0;
      HEAP32[$16>>2] = $19;
      $20 = (($11) + (($i$013*12)|0)|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = Math_imul($17, $8)|0;
      $23 = (($21) + ($22)|0);
      $24 = ($23|0)==(0|0);
      if (!($24)) {
       $$0$i25 = $23;
       break;
      }
     }
    }
    $25 = (($i$013) + 1)|0;
    $26 = ($25>>>0)<($3>>>0);
    if ($26) {
     $i$013 = $25;
    } else {
     break L1;
    }
   }
   if ((label|0) == 5) {
    $15 = HEAP32[$13>>2]|0;
    HEAP32[$12>>2] = $15;
    $$0$i25 = $13;
   }
   HEAP32[$4>>2] = $i$013;
   $$0 = $$0$i25;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$4>>2] = $3;
 $27 = (($this) + 24|0);
 HEAP8[$27>>0] = 1;
 $28 = (($tmp) + 4|0);
 $29 = (($tmp) + 8|0);
 HEAP32[$28>>2] = 0;
 HEAP32[$29>>2] = 0;
 $30 = Math_imul($8, $6)|0;
 $31 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$30,465496,60)|0);
 HEAP32[$tmp>>2] = $31;
 $32 = (($this) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 & 2147483647;
 $35 = HEAP32[$2>>2]|0;
 $36 = ($34>>>0)>($35>>>0);
 if ($36) {
  $38 = HEAP32[$1>>2]|0;
  $39 = (($38) + (($35*12)|0)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $42 = $35;$44 = $38;
  } else {
   ;HEAP32[$39+0>>2]=HEAP32[$tmp+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$tmp+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$tmp+8>>2]|0;
   $$pre$i = HEAP32[$2>>2]|0;
   $$pre1$i = HEAP32[$1>>2]|0;
   $42 = $$pre$i;$44 = $$pre1$i;
  }
  $41 = (($42) + 1)|0;
  HEAP32[$2>>2] = $41;
  $43 = (($44) + (($42*12)|0)|0);
  $$0$i1 = $43;
 } else {
  $37 = (__ZN5physx6shdfnd5ArrayINS_2Cm19PreallocatingRegionENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($1,$tmp)|0);
  $$0$i1 = $37;
 }
 $45 = (($$0$i1) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 if (!($47)) {
  $48 = HEAP32[$46>>2]|0;
  HEAP32[$45>>2] = $48;
  $$0 = $46;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = (($$0$i1) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==($6|0);
 if ($51) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $52 = (($50) + 1)|0;
 HEAP32[$49>>2] = $52;
 $53 = HEAP32[$$0$i1>>2]|0;
 $54 = Math_imul($50, $8)|0;
 $55 = (($53) + ($54)|0);
 $$0 = $55;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayINS_2Cm19PreallocatingRegionENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*12)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 465360 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*12)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;
   }
   $25 = (($$012$i) + 12|0);
   $26 = (($$03$i) + 12|0);
   $27 = ($25>>>0)<($20>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $19;
 }
 $28 = (($21) + (($29*12)|0)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  ;HEAP32[$28+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$a+8>>2]|0;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = HEAP32[$18>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$18>>2] = $40;
 $41 = (($21) + (($39*12)|0)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPKNS_2Sc9ShapeCoreENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS5_EEEEE15growAndPushBackERKS5_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 465696 : 464392;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,464536,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc8ShapeSimENS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorIS4_EEEEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 465576 : 464392;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,464536,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayINS_16PxConstraintInfoENS0_15InlineAllocatorILj384ENS0_13TempAllocatorEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 396|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $15 = 0;
 } else {
  $6 = ($$$i*12)|0;
  $7 = (($this) + 384|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(385);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$6,464536,558)|0);
   $$0$i$i = $11;
  }
  $15 = $$0$i$i;
 }
 $12 = (($this) + 392|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($15) + (($13*12)|0)|0);
 $16 = (($this) + 388|0);
 $17 = ($13|0)>(0);
 if ($17) {
  $18 = HEAP32[$16>>2]|0;
  $$012$i = $15;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;
   }
   $20 = (($$012$i) + 12|0);
   $21 = (($$03$i) + 12|0);
   $22 = ($20>>>0)<($14>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$12>>2]|0;
  $24 = $$pre;
 } else {
  $24 = $13;
 }
 $23 = (($15) + (($24*12)|0)|0);
 $25 = ($23|0)==(0|0);
 if (!($25)) {
  ;HEAP32[$23+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$a+8>>2]|0;
 }
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)>(-1);
 do {
  if ($27) {
   $28 = HEAP32[$16>>2]|0;
   $29 = ($this|0)==($28|0);
   if ($29) {
    $30 = (($this) + 384|0);
    HEAP8[$30>>0] = 0;
    break;
   } else {
    __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$28);
    break;
   }
  }
 } while(0);
 HEAP32[$16>>2] = $15;
 HEAP32[$0>>2] = $$$i;
 $31 = HEAP32[$12>>2]|0;
 $32 = (($31) + 1)|0;
 HEAP32[$12>>2] = $32;
 $33 = (($15) + (($31*12)|0)|0);
 STACKTOP = sp;return ($33|0);
}
function __ZN5physx6shdfnd5ArrayINS_16PxConstraintInfoENS0_15InlineAllocatorILj384ENS0_13TempAllocatorEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $10 = 0;
 } else {
  $1 = ($capacity*12)|0;
  $2 = (($this) + 384|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(385);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$1,464536,558)|0);
   $$0$i$i = $6;
  }
  $10 = $$0$i$i;
 }
 $7 = (($this) + 392|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($10) + (($8*12)|0)|0);
 $11 = (($this) + 388|0);
 $12 = ($8|0)>(0);
 if ($12) {
  $13 = HEAP32[$11>>2]|0;
  $$012$i = $10;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;
   }
   $15 = (($$012$i) + 12|0);
   $16 = (($$03$i) + 12|0);
   $17 = ($15>>>0)<($9>>>0);
   if ($17) {
    $$012$i = $15;$$03$i = $16;
   } else {
    break;
   }
  }
 }
 $18 = (($this) + 396|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(-1);
 if (!($20)) {
  HEAP32[$11>>2] = $10;
  HEAP32[$18>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $21 = HEAP32[$11>>2]|0;
 $22 = ($this|0)==($21|0);
 if ($22) {
  $23 = (($this) + 384|0);
  HEAP8[$23>>0] = 0;
  HEAP32[$11>>2] = $10;
  HEAP32[$18>>2] = $capacity;
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$21);
  HEAP32[$11>>2] = $10;
  HEAP32[$18>>2] = $capacity;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_126BrokenConstraintReportDataENS0_15InlineAllocatorILj512ENS0_13TempAllocatorEEEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $this$idx$val = 0, $this$idx1 = 0, $this$idx1$val = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $this$idx1 = (($this) + 524|0);
 $this$idx1$val = HEAP32[$this$idx1>>2]|0;
 $0 = $this$idx1$val & 2147483647;
 $1 = ($0|0)==(0);
 $2 = $this$idx1$val << 1;
 $$$i = $1 ? 1 : $2;
 $3 = ($$$i|0)==(0);
 if ($3) {
  $13 = 0;
 } else {
  $4 = $$$i << 4;
  $5 = (($this) + 512|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  $8 = ($4>>>0)<(513);
  $or$cond$i$i = $7 & $8;
  if ($or$cond$i$i) {
   HEAP8[$5>>0] = 1;
   $$0$i$i = $this;
  } else {
   $9 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$4,464536,558)|0);
   $$0$i$i = $9;
  }
  $13 = $$0$i$i;
 }
 $10 = (($this) + 520|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($13) + ($11<<4)|0);
 $14 = (($this) + 516|0);
 $15 = ($11|0)>(0);
 if ($15) {
  $16 = HEAP32[$14>>2]|0;
  $$012$i = $13;$$03$i = $16;
  while(1) {
   $17 = ($$012$i|0)==(0|0);
   if (!($17)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
   }
   $18 = (($$012$i) + 16|0);
   $19 = (($$03$i) + 16|0);
   $20 = ($18>>>0)<($12>>>0);
   if ($20) {
    $$012$i = $18;$$03$i = $19;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$10>>2]|0;
  $22 = $$pre;
 } else {
  $22 = $11;
 }
 $21 = (($13) + ($22<<4)|0);
 $23 = ($21|0)==(0|0);
 if (!($23)) {
  ;HEAP32[$21+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$a+12>>2]|0;
 }
 $this$idx$val = HEAP32[$this$idx1>>2]|0;
 $24 = ($this$idx$val|0)>(-1);
 do {
  if ($24) {
   $25 = HEAP32[$14>>2]|0;
   $26 = ($this|0)==($25|0);
   if ($26) {
    $27 = (($this) + 512|0);
    HEAP8[$27>>0] = 0;
    break;
   } else {
    __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$25);
    break;
   }
  }
 } while(0);
 HEAP32[$14>>2] = $13;
 HEAP32[$this$idx1>>2] = $$$i;
 $28 = HEAP32[$10>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$10>>2] = $29;
 $30 = (($13) + ($28<<4)|0);
 STACKTOP = sp;return ($30|0);
}
function __ZN5physx6shdfnd5ArrayIN12_GLOBAL__N_126BrokenConstraintReportDataENS0_15InlineAllocatorILj512ENS0_13TempAllocatorEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $this$idx = 0, $this$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $10 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = (($this) + 512|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(513);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$1,464536,558)|0);
   $$0$i$i = $6;
  }
  $10 = $$0$i$i;
 }
 $7 = (($this) + 520|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($10) + ($8<<4)|0);
 $11 = (($this) + 516|0);
 $12 = ($8|0)>(0);
 if ($12) {
  $13 = HEAP32[$11>>2]|0;
  $$012$i = $10;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
   }
   $15 = (($$012$i) + 16|0);
   $16 = (($$03$i) + 16|0);
   $17 = ($15>>>0)<($9>>>0);
   if ($17) {
    $$012$i = $15;$$03$i = $16;
   } else {
    break;
   }
  }
 }
 $this$idx = (($this) + 524|0);
 $this$idx$val = HEAP32[$this$idx>>2]|0;
 $18 = ($this$idx$val|0)>(-1);
 if (!($18)) {
  HEAP32[$11>>2] = $10;
  HEAP32[$this$idx>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$11>>2]|0;
 $20 = ($this|0)==($19|0);
 if ($20) {
  $21 = (($this) + 512|0);
  HEAP8[$21>>0] = 0;
  HEAP32[$11>>2] = $10;
  HEAP32[$this$idx>>2] = $capacity;
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$19);
  HEAP32[$11>>2] = $10;
  HEAP32[$this$idx>>2] = $capacity;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_15InlineAllocatorILj768ENS0_13TempAllocatorEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 780|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $15 = 0;
 } else {
  $6 = ($$$i*24)|0;
  $7 = (($this) + 768|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(769);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$6,464536,558)|0);
   $$0$i$i = $11;
  }
  $15 = $$0$i$i;
 }
 $12 = (($this) + 776|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($15) + (($13*24)|0)|0);
 $16 = (($this) + 772|0);
 $17 = ($13|0)>(0);
 if ($17) {
  $18 = HEAP32[$16>>2]|0;
  $$012$i = $15;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
    $20 = (($$03$i) + 20|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = (($$012$i) + 20|0);
    HEAP8[$22>>0] = $21;
   }
   $23 = (($$012$i) + 24|0);
   $24 = (($$03$i) + 24|0);
   $25 = ($23>>>0)<($14>>>0);
   if ($25) {
    $$012$i = $23;$$03$i = $24;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$12>>2]|0;
  $27 = $$pre;
 } else {
  $27 = $13;
 }
 $26 = (($15) + (($27*24)|0)|0);
 $28 = ($26|0)==(0|0);
 if (!($28)) {
  ;HEAP32[$26+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$a+16>>2]|0;
  $29 = (($a) + 20|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ((($15) + (($27*24)|0)|0) + 20|0);
  HEAP8[$31>>0] = $30;
 }
 $32 = HEAP32[$0>>2]|0;
 $33 = ($32|0)>(-1);
 do {
  if ($33) {
   $34 = HEAP32[$16>>2]|0;
   $35 = ($this|0)==($34|0);
   if ($35) {
    $36 = (($this) + 768|0);
    HEAP8[$36>>0] = 0;
    break;
   } else {
    __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$34);
    break;
   }
  }
 } while(0);
 HEAP32[$16>>2] = $15;
 HEAP32[$0>>2] = $$$i;
 $37 = HEAP32[$12>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$12>>2] = $38;
 $39 = (($15) + (($37*24)|0)|0);
 STACKTOP = sp;return ($39|0);
}
function __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_15InlineAllocatorILj768ENS0_13TempAllocatorEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $10 = 0;
 } else {
  $1 = ($capacity*24)|0;
  $2 = (($this) + 768|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(769);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$1,464536,558)|0);
   $$0$i$i = $6;
  }
  $10 = $$0$i$i;
 }
 $7 = (($this) + 776|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($10) + (($8*24)|0)|0);
 $11 = (($this) + 772|0);
 $12 = ($8|0)>(0);
 if ($12) {
  $13 = HEAP32[$11>>2]|0;
  $$012$i = $10;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
    $15 = (($$03$i) + 20|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = (($$012$i) + 20|0);
    HEAP8[$17>>0] = $16;
   }
   $18 = (($$012$i) + 24|0);
   $19 = (($$03$i) + 24|0);
   $20 = ($18>>>0)<($9>>>0);
   if ($20) {
    $$012$i = $18;$$03$i = $19;
   } else {
    break;
   }
  }
 }
 $21 = (($this) + 780|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(-1);
 if (!($23)) {
  HEAP32[$11>>2] = $10;
  HEAP32[$21>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $24 = HEAP32[$11>>2]|0;
 $25 = ($this|0)==($24|0);
 if ($25) {
  $26 = (($this) + 768|0);
  HEAP8[$26>>0] = 0;
  HEAP32[$11>>2] = $10;
  HEAP32[$21>>2] = $capacity;
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$24);
  HEAP32[$11>>2] = $10;
  HEAP32[$21>>2] = $capacity;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13ccdBroadPhaseEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13ccdBroadPhaseEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13ccdBroadPhaseEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene13ccdBroadPhaseEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx10PxBaseTaskD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx10PxBaseTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_13ccdBroadPhaseEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE15growAndPushBackERKS8_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*28)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 465920 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*28)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    HEAP32[$$012$i>>2] = ((465880 + 8|0));
    $25 = (($$012$i) + 4|0);
    $26 = (($$03$i) + 4|0);
    $27 = $26;
    $28 = $27;
    $29 = HEAPU16[$28>>1]|(HEAPU16[$28+2>>1]<<16);
    $30 = (($27) + 4)|0;
    $31 = $30;
    $32 = HEAPU16[$31>>1]|(HEAPU16[$31+2>>1]<<16);
    $33 = $25;
    $34 = $33;
    HEAP16[$34>>1]=$29&65535;HEAP16[$34+2>>1]=$29>>>16;
    $35 = (($33) + 4)|0;
    $36 = $35;
    HEAP16[$36>>1]=$32&65535;HEAP16[$36+2>>1]=$32>>>16;
    HEAP32[$$012$i>>2] = ((434896 + 8|0));
    $37 = (($$012$i) + 12|0);
    $38 = (($$03$i) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$37>>2] = $39;
    $40 = (($$012$i) + 16|0);
    $41 = (($$03$i) + 16|0);
    $42 = HEAP32[$41>>2]|0;
    HEAP32[$40>>2] = $42;
    $43 = HEAP32[$38>>2]|0;
    HEAP32[$37>>2] = $43;
    HEAP32[$$012$i>>2] = ((465832 + 8|0));
    $44 = (($$012$i) + 20|0);
    $45 = (($$03$i) + 20|0);
    $46 = $45;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4)|0;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = $44;
    $53 = $52;
    HEAP32[$53>>2] = $48;
    $54 = (($52) + 4)|0;
    $55 = $54;
    HEAP32[$55>>2] = $51;
   }
   $56 = (($$012$i) + 28|0);
   $57 = (($$03$i) + 28|0);
   $58 = ($56>>>0)<($20>>>0);
   if ($58) {
    $$012$i = $56;$$03$i = $57;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $60 = $$pre;
 } else {
  $60 = $19;
 }
 $59 = (($21) + (($60*28)|0)|0);
 HEAP32[$59>>2] = ((465880 + 8|0));
 $61 = ((($21) + (($60*28)|0)|0) + 4|0);
 $62 = (($a) + 4|0);
 $63 = $62;
 $64 = $63;
 $65 = HEAPU16[$64>>1]|(HEAPU16[$64+2>>1]<<16);
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAPU16[$67>>1]|(HEAPU16[$67+2>>1]<<16);
 $69 = $61;
 $70 = $69;
 HEAP16[$70>>1]=$65&65535;HEAP16[$70+2>>1]=$65>>>16;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP16[$72>>1]=$68&65535;HEAP16[$72+2>>1]=$68>>>16;
 HEAP32[$59>>2] = ((434896 + 8|0));
 $73 = ((($21) + (($60*28)|0)|0) + 12|0);
 $74 = (($a) + 12|0);
 $75 = HEAP32[$74>>2]|0;
 HEAP32[$73>>2] = $75;
 $76 = ((($21) + (($60*28)|0)|0) + 16|0);
 $77 = (($a) + 16|0);
 $78 = HEAP32[$77>>2]|0;
 HEAP32[$76>>2] = $78;
 $79 = HEAP32[$74>>2]|0;
 HEAP32[$73>>2] = $79;
 HEAP32[$59>>2] = ((465832 + 8|0));
 $80 = ((($21) + (($60*28)|0)|0) + 20|0);
 $81 = (($a) + 20|0);
 $82 = $81;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $80;
 $89 = $88;
 HEAP32[$89>>2] = $84;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $87;
 $92 = HEAP32[$this>>2]|0;
 $93 = HEAP32[$18>>2]|0;
 $94 = (($92) + (($93*28)|0)|0);
 $95 = ($93|0)>(0);
 if ($95) {
  $$01$i = $92;
  while(1) {
   $96 = HEAP32[$$01$i>>2]|0;
   $97 = HEAP32[$96>>2]|0;
   FUNCTION_TABLE_vi[$97 & 4095]($$01$i);
   $98 = (($$01$i) + 28|0);
   $99 = ($98>>>0)<($94>>>0);
   if ($99) {
    $$01$i = $98;
   } else {
    break;
   }
  }
 }
 $100 = HEAP32[$0>>2]|0;
 $101 = ($100|0)>(-1);
 if (!($101)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $108 = HEAP32[$18>>2]|0;
  $109 = (($108) + 1)|0;
  HEAP32[$18>>2] = $109;
  $110 = (($21) + (($108*28)|0)|0);
  STACKTOP = sp;return ($110|0);
 }
 $102 = HEAP32[$this>>2]|0;
 $103 = ($102|0)==(0|0);
 if ($103) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $108 = HEAP32[$18>>2]|0;
  $109 = (($108) + 1)|0;
  HEAP32[$18>>2] = $109;
  $110 = (($21) + (($108*28)|0)|0);
  STACKTOP = sp;return ($110|0);
 }
 $104 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($105) + 12|0);
 $107 = HEAP32[$106>>2]|0;
 FUNCTION_TABLE_vii[$107 & 4095]($104,$102);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $108 = HEAP32[$18>>2]|0;
 $109 = (($108) + 1)|0;
 HEAP32[$18>>2] = $109;
 $110 = (($21) + (($108*28)|0)|0);
 STACKTOP = sp;return ($110|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19updateCCDSinglePassEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19updateCCDSinglePassEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19updateCCDSinglePassEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene19updateCCDSinglePassEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_19updateCCDSinglePassEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE15growAndPushBackERKS8_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*28)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 466160 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*28)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    HEAP32[$$012$i>>2] = ((465880 + 8|0));
    $25 = (($$012$i) + 4|0);
    $26 = (($$03$i) + 4|0);
    $27 = $26;
    $28 = $27;
    $29 = HEAPU16[$28>>1]|(HEAPU16[$28+2>>1]<<16);
    $30 = (($27) + 4)|0;
    $31 = $30;
    $32 = HEAPU16[$31>>1]|(HEAPU16[$31+2>>1]<<16);
    $33 = $25;
    $34 = $33;
    HEAP16[$34>>1]=$29&65535;HEAP16[$34+2>>1]=$29>>>16;
    $35 = (($33) + 4)|0;
    $36 = $35;
    HEAP16[$36>>1]=$32&65535;HEAP16[$36+2>>1]=$32>>>16;
    HEAP32[$$012$i>>2] = ((434896 + 8|0));
    $37 = (($$012$i) + 12|0);
    $38 = (($$03$i) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$37>>2] = $39;
    $40 = (($$012$i) + 16|0);
    $41 = (($$03$i) + 16|0);
    $42 = HEAP32[$41>>2]|0;
    HEAP32[$40>>2] = $42;
    $43 = HEAP32[$38>>2]|0;
    HEAP32[$37>>2] = $43;
    HEAP32[$$012$i>>2] = ((466112 + 8|0));
    $44 = (($$012$i) + 20|0);
    $45 = (($$03$i) + 20|0);
    $46 = $45;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4)|0;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = $44;
    $53 = $52;
    HEAP32[$53>>2] = $48;
    $54 = (($52) + 4)|0;
    $55 = $54;
    HEAP32[$55>>2] = $51;
   }
   $56 = (($$012$i) + 28|0);
   $57 = (($$03$i) + 28|0);
   $58 = ($56>>>0)<($20>>>0);
   if ($58) {
    $$012$i = $56;$$03$i = $57;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $60 = $$pre;
 } else {
  $60 = $19;
 }
 $59 = (($21) + (($60*28)|0)|0);
 HEAP32[$59>>2] = ((465880 + 8|0));
 $61 = ((($21) + (($60*28)|0)|0) + 4|0);
 $62 = (($a) + 4|0);
 $63 = $62;
 $64 = $63;
 $65 = HEAPU16[$64>>1]|(HEAPU16[$64+2>>1]<<16);
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAPU16[$67>>1]|(HEAPU16[$67+2>>1]<<16);
 $69 = $61;
 $70 = $69;
 HEAP16[$70>>1]=$65&65535;HEAP16[$70+2>>1]=$65>>>16;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP16[$72>>1]=$68&65535;HEAP16[$72+2>>1]=$68>>>16;
 HEAP32[$59>>2] = ((434896 + 8|0));
 $73 = ((($21) + (($60*28)|0)|0) + 12|0);
 $74 = (($a) + 12|0);
 $75 = HEAP32[$74>>2]|0;
 HEAP32[$73>>2] = $75;
 $76 = ((($21) + (($60*28)|0)|0) + 16|0);
 $77 = (($a) + 16|0);
 $78 = HEAP32[$77>>2]|0;
 HEAP32[$76>>2] = $78;
 $79 = HEAP32[$74>>2]|0;
 HEAP32[$73>>2] = $79;
 HEAP32[$59>>2] = ((466112 + 8|0));
 $80 = ((($21) + (($60*28)|0)|0) + 20|0);
 $81 = (($a) + 20|0);
 $82 = $81;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $80;
 $89 = $88;
 HEAP32[$89>>2] = $84;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $87;
 $92 = HEAP32[$this>>2]|0;
 $93 = HEAP32[$18>>2]|0;
 $94 = (($92) + (($93*28)|0)|0);
 $95 = ($93|0)>(0);
 if ($95) {
  $$01$i = $92;
  while(1) {
   $96 = HEAP32[$$01$i>>2]|0;
   $97 = HEAP32[$96>>2]|0;
   FUNCTION_TABLE_vi[$97 & 4095]($$01$i);
   $98 = (($$01$i) + 28|0);
   $99 = ($98>>>0)<($94>>>0);
   if ($99) {
    $$01$i = $98;
   } else {
    break;
   }
  }
 }
 $100 = HEAP32[$0>>2]|0;
 $101 = ($100|0)>(-1);
 if (!($101)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $108 = HEAP32[$18>>2]|0;
  $109 = (($108) + 1)|0;
  HEAP32[$18>>2] = $109;
  $110 = (($21) + (($108*28)|0)|0);
  STACKTOP = sp;return ($110|0);
 }
 $102 = HEAP32[$this>>2]|0;
 $103 = ($102|0)==(0|0);
 if ($103) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $108 = HEAP32[$18>>2]|0;
  $109 = (($108) + 1)|0;
  HEAP32[$18>>2] = $109;
  $110 = (($21) + (($108*28)|0)|0);
  STACKTOP = sp;return ($110|0);
 }
 $104 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($105) + 12|0);
 $107 = HEAP32[$106>>2]|0;
 FUNCTION_TABLE_vii[$107 & 4095]($104,$102);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $108 = HEAP32[$18>>2]|0;
 $109 = (($108) + 1)|0;
 HEAP32[$18>>2] = $109;
 $110 = (($21) + (($108*28)|0)|0);
 STACKTOP = sp;return ($110|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11postCCDPassEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11postCCDPassEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11postCCDPassEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene11postCCDPassEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_11postCCDPassEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE15growAndPushBackERKS8_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*28)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 466408 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*28)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    HEAP32[$$012$i>>2] = ((465880 + 8|0));
    $25 = (($$012$i) + 4|0);
    $26 = (($$03$i) + 4|0);
    $27 = $26;
    $28 = $27;
    $29 = HEAPU16[$28>>1]|(HEAPU16[$28+2>>1]<<16);
    $30 = (($27) + 4)|0;
    $31 = $30;
    $32 = HEAPU16[$31>>1]|(HEAPU16[$31+2>>1]<<16);
    $33 = $25;
    $34 = $33;
    HEAP16[$34>>1]=$29&65535;HEAP16[$34+2>>1]=$29>>>16;
    $35 = (($33) + 4)|0;
    $36 = $35;
    HEAP16[$36>>1]=$32&65535;HEAP16[$36+2>>1]=$32>>>16;
    HEAP32[$$012$i>>2] = ((434896 + 8|0));
    $37 = (($$012$i) + 12|0);
    $38 = (($$03$i) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$37>>2] = $39;
    $40 = (($$012$i) + 16|0);
    $41 = (($$03$i) + 16|0);
    $42 = HEAP32[$41>>2]|0;
    HEAP32[$40>>2] = $42;
    $43 = HEAP32[$38>>2]|0;
    HEAP32[$37>>2] = $43;
    HEAP32[$$012$i>>2] = ((466360 + 8|0));
    $44 = (($$012$i) + 20|0);
    $45 = (($$03$i) + 20|0);
    $46 = $45;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4)|0;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = $44;
    $53 = $52;
    HEAP32[$53>>2] = $48;
    $54 = (($52) + 4)|0;
    $55 = $54;
    HEAP32[$55>>2] = $51;
   }
   $56 = (($$012$i) + 28|0);
   $57 = (($$03$i) + 28|0);
   $58 = ($56>>>0)<($20>>>0);
   if ($58) {
    $$012$i = $56;$$03$i = $57;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $60 = $$pre;
 } else {
  $60 = $19;
 }
 $59 = (($21) + (($60*28)|0)|0);
 HEAP32[$59>>2] = ((465880 + 8|0));
 $61 = ((($21) + (($60*28)|0)|0) + 4|0);
 $62 = (($a) + 4|0);
 $63 = $62;
 $64 = $63;
 $65 = HEAPU16[$64>>1]|(HEAPU16[$64+2>>1]<<16);
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAPU16[$67>>1]|(HEAPU16[$67+2>>1]<<16);
 $69 = $61;
 $70 = $69;
 HEAP16[$70>>1]=$65&65535;HEAP16[$70+2>>1]=$65>>>16;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP16[$72>>1]=$68&65535;HEAP16[$72+2>>1]=$68>>>16;
 HEAP32[$59>>2] = ((434896 + 8|0));
 $73 = ((($21) + (($60*28)|0)|0) + 12|0);
 $74 = (($a) + 12|0);
 $75 = HEAP32[$74>>2]|0;
 HEAP32[$73>>2] = $75;
 $76 = ((($21) + (($60*28)|0)|0) + 16|0);
 $77 = (($a) + 16|0);
 $78 = HEAP32[$77>>2]|0;
 HEAP32[$76>>2] = $78;
 $79 = HEAP32[$74>>2]|0;
 HEAP32[$73>>2] = $79;
 HEAP32[$59>>2] = ((466360 + 8|0));
 $80 = ((($21) + (($60*28)|0)|0) + 20|0);
 $81 = (($a) + 20|0);
 $82 = $81;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $80;
 $89 = $88;
 HEAP32[$89>>2] = $84;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $87;
 $92 = HEAP32[$this>>2]|0;
 $93 = HEAP32[$18>>2]|0;
 $94 = (($92) + (($93*28)|0)|0);
 $95 = ($93|0)>(0);
 if ($95) {
  $$01$i = $92;
  while(1) {
   $96 = HEAP32[$$01$i>>2]|0;
   $97 = HEAP32[$96>>2]|0;
   FUNCTION_TABLE_vi[$97 & 4095]($$01$i);
   $98 = (($$01$i) + 28|0);
   $99 = ($98>>>0)<($94>>>0);
   if ($99) {
    $$01$i = $98;
   } else {
    break;
   }
  }
 }
 $100 = HEAP32[$0>>2]|0;
 $101 = ($100|0)>(-1);
 if (!($101)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $108 = HEAP32[$18>>2]|0;
  $109 = (($108) + 1)|0;
  HEAP32[$18>>2] = $109;
  $110 = (($21) + (($108*28)|0)|0);
  STACKTOP = sp;return ($110|0);
 }
 $102 = HEAP32[$this>>2]|0;
 $103 = ($102|0)==(0|0);
 if ($103) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $108 = HEAP32[$18>>2]|0;
  $109 = (($108) + 1)|0;
  HEAP32[$18>>2] = $109;
  $110 = (($21) + (($108*28)|0)|0);
  STACKTOP = sp;return ($110|0);
 }
 $104 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($105) + 12|0);
 $107 = HEAP32[$106>>2]|0;
 FUNCTION_TABLE_vii[$107 & 4095]($104,$102);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $108 = HEAP32[$18>>2]|0;
 $109 = (($108) + 1)|0;
 HEAP32[$18>>2] = $109;
 $110 = (($21) + (($108*28)|0)|0);
 STACKTOP = sp;return ($110|0);
}
function __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_13ccdBroadPhaseEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*28)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 465920 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*28)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    HEAP32[$$012$i>>2] = ((465880 + 8|0));
    $20 = (($$012$i) + 4|0);
    $21 = (($$03$i) + 4|0);
    $22 = $21;
    $23 = $22;
    $24 = HEAPU16[$23>>1]|(HEAPU16[$23+2>>1]<<16);
    $25 = (($22) + 4)|0;
    $26 = $25;
    $27 = HEAPU16[$26>>1]|(HEAPU16[$26+2>>1]<<16);
    $28 = $20;
    $29 = $28;
    HEAP16[$29>>1]=$24&65535;HEAP16[$29+2>>1]=$24>>>16;
    $30 = (($28) + 4)|0;
    $31 = $30;
    HEAP16[$31>>1]=$27&65535;HEAP16[$31+2>>1]=$27>>>16;
    HEAP32[$$012$i>>2] = ((434896 + 8|0));
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $34;
    $35 = (($$012$i) + 16|0);
    $36 = (($$03$i) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    HEAP32[$35>>2] = $37;
    $38 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $38;
    HEAP32[$$012$i>>2] = ((465832 + 8|0));
    $39 = (($$012$i) + 20|0);
    $40 = (($$03$i) + 20|0);
    $41 = $40;
    $42 = $41;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($41) + 4)|0;
    $45 = $44;
    $46 = HEAP32[$45>>2]|0;
    $47 = $39;
    $48 = $47;
    HEAP32[$48>>2] = $43;
    $49 = (($47) + 4)|0;
    $50 = $49;
    HEAP32[$50>>2] = $46;
   }
   $51 = (($$012$i) + 28|0);
   $52 = (($$03$i) + 28|0);
   $53 = ($51>>>0)<($15>>>0);
   if ($53) {
    $$012$i = $51;$$03$i = $52;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$13>>2]|0;
  $54 = HEAP32[$this>>2]|0;
  $55 = (($54) + (($$pre*28)|0)|0);
  $56 = ($$pre|0)>(0);
  if ($56) {
   $$01$i = $54;
   while(1) {
    $57 = HEAP32[$$01$i>>2]|0;
    $58 = HEAP32[$57>>2]|0;
    FUNCTION_TABLE_vi[$58 & 4095]($$01$i);
    $59 = (($$01$i) + 28|0);
    $60 = ($59>>>0)<($55>>>0);
    if ($60) {
     $$01$i = $59;
    } else {
     break;
    }
   }
  }
 }
 $61 = (($this) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)>(-1);
 if (!($63)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$61>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $64 = HEAP32[$this>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  HEAP32[$this>>2] = $16;
  HEAP32[$61>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $66 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 12|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vii[$69 & 4095]($66,$64);
 HEAP32[$this>>2] = $16;
 HEAP32[$61>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_19updateCCDSinglePassEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*28)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 466160 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*28)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    HEAP32[$$012$i>>2] = ((465880 + 8|0));
    $20 = (($$012$i) + 4|0);
    $21 = (($$03$i) + 4|0);
    $22 = $21;
    $23 = $22;
    $24 = HEAPU16[$23>>1]|(HEAPU16[$23+2>>1]<<16);
    $25 = (($22) + 4)|0;
    $26 = $25;
    $27 = HEAPU16[$26>>1]|(HEAPU16[$26+2>>1]<<16);
    $28 = $20;
    $29 = $28;
    HEAP16[$29>>1]=$24&65535;HEAP16[$29+2>>1]=$24>>>16;
    $30 = (($28) + 4)|0;
    $31 = $30;
    HEAP16[$31>>1]=$27&65535;HEAP16[$31+2>>1]=$27>>>16;
    HEAP32[$$012$i>>2] = ((434896 + 8|0));
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $34;
    $35 = (($$012$i) + 16|0);
    $36 = (($$03$i) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    HEAP32[$35>>2] = $37;
    $38 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $38;
    HEAP32[$$012$i>>2] = ((466112 + 8|0));
    $39 = (($$012$i) + 20|0);
    $40 = (($$03$i) + 20|0);
    $41 = $40;
    $42 = $41;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($41) + 4)|0;
    $45 = $44;
    $46 = HEAP32[$45>>2]|0;
    $47 = $39;
    $48 = $47;
    HEAP32[$48>>2] = $43;
    $49 = (($47) + 4)|0;
    $50 = $49;
    HEAP32[$50>>2] = $46;
   }
   $51 = (($$012$i) + 28|0);
   $52 = (($$03$i) + 28|0);
   $53 = ($51>>>0)<($15>>>0);
   if ($53) {
    $$012$i = $51;$$03$i = $52;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$13>>2]|0;
  $54 = HEAP32[$this>>2]|0;
  $55 = (($54) + (($$pre*28)|0)|0);
  $56 = ($$pre|0)>(0);
  if ($56) {
   $$01$i = $54;
   while(1) {
    $57 = HEAP32[$$01$i>>2]|0;
    $58 = HEAP32[$57>>2]|0;
    FUNCTION_TABLE_vi[$58 & 4095]($$01$i);
    $59 = (($$01$i) + 28|0);
    $60 = ($59>>>0)<($55>>>0);
    if ($60) {
     $$01$i = $59;
    } else {
     break;
    }
   }
  }
 }
 $61 = (($this) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)>(-1);
 if (!($63)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$61>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $64 = HEAP32[$this>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  HEAP32[$this>>2] = $16;
  HEAP32[$61>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $66 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 12|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vii[$69 & 4095]($66,$64);
 HEAP32[$this>>2] = $16;
 HEAP32[$61>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS5_11postCCDPassEPNS_10PxBaseTaskEEEEENS0_19ReflectionAllocatorIS8_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*28)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 466408 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*28)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    HEAP32[$$012$i>>2] = ((465880 + 8|0));
    $20 = (($$012$i) + 4|0);
    $21 = (($$03$i) + 4|0);
    $22 = $21;
    $23 = $22;
    $24 = HEAPU16[$23>>1]|(HEAPU16[$23+2>>1]<<16);
    $25 = (($22) + 4)|0;
    $26 = $25;
    $27 = HEAPU16[$26>>1]|(HEAPU16[$26+2>>1]<<16);
    $28 = $20;
    $29 = $28;
    HEAP16[$29>>1]=$24&65535;HEAP16[$29+2>>1]=$24>>>16;
    $30 = (($28) + 4)|0;
    $31 = $30;
    HEAP16[$31>>1]=$27&65535;HEAP16[$31+2>>1]=$27>>>16;
    HEAP32[$$012$i>>2] = ((434896 + 8|0));
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $34;
    $35 = (($$012$i) + 16|0);
    $36 = (($$03$i) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    HEAP32[$35>>2] = $37;
    $38 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $38;
    HEAP32[$$012$i>>2] = ((466360 + 8|0));
    $39 = (($$012$i) + 20|0);
    $40 = (($$03$i) + 20|0);
    $41 = $40;
    $42 = $41;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($41) + 4)|0;
    $45 = $44;
    $46 = HEAP32[$45>>2]|0;
    $47 = $39;
    $48 = $47;
    HEAP32[$48>>2] = $43;
    $49 = (($47) + 4)|0;
    $50 = $49;
    HEAP32[$50>>2] = $46;
   }
   $51 = (($$012$i) + 28|0);
   $52 = (($$03$i) + 28|0);
   $53 = ($51>>>0)<($15>>>0);
   if ($53) {
    $$012$i = $51;$$03$i = $52;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$13>>2]|0;
  $54 = HEAP32[$this>>2]|0;
  $55 = (($54) + (($$pre*28)|0)|0);
  $56 = ($$pre|0)>(0);
  if ($56) {
   $$01$i = $54;
   while(1) {
    $57 = HEAP32[$$01$i>>2]|0;
    $58 = HEAP32[$57>>2]|0;
    FUNCTION_TABLE_vi[$58 & 4095]($$01$i);
    $59 = (($$01$i) + 28|0);
    $60 = ($59>>>0)<($55>>>0);
    if ($60) {
     $$01$i = $59;
    } else {
     break;
    }
   }
  }
 }
 $61 = (($this) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)>(-1);
 if (!($63)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$61>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $64 = HEAP32[$this>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  HEAP32[$this>>2] = $16;
  HEAP32[$61>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $66 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 12|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vii[$69 & 4095]($66,$64);
 HEAP32[$this>>2] = $16;
 HEAP32[$61>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj384EEENS0_19ReflectionAllocatorIS4_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 384)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 466592 : 464392;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,464536,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 466592 : 464392;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,464536,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj256EEENS0_19ReflectionAllocatorIS4_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 256)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 466744 : 464392;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,464536,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 466744 : 464392;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,464536,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj128EEENS0_19ReflectionAllocatorIS4_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 128)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 466896 : 464392;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,464536,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 466896 : 464392;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,464536,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj384EEENS0_19ReflectionAllocatorIS4_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 466592 : 464392;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,467048,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj384EEEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*384)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -384|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj256EEENS0_19ReflectionAllocatorIS4_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 466744 : 464392;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,467048,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj256EEEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + ($$sum<<8)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -256|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIhLj128EEENS0_19ReflectionAllocatorIS4_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 466896 : 464392;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,467048,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIhLj128EEEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + ($$sum<<7)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -128|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc16ArticulationCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 467264 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 467528 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 128)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 467656 : 464392;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,465272,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 467656 : 464392;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,465272,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 467656 : 464392;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,464536,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 467656 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 467656 : 464392;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,464536,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 467656 : 464392;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,467048,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + ($$sum<<7)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -128|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc17ParticleSystemSimENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc17ParticleSystemSimENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc17ParticleSystemSimENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 467784 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc18ParticleSystemCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 464736 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;
  }
  $11 = (($$01$i) + 16|0);
  $12 = ($11>>>0)<($7>>>0);
  if ($12) {
   $$01$i = $11;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Sc5Scene14SimpleBodyPairENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 465008 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
   }
   $20 = (($$012$i) + 16|0);
   $21 = (($$03$i) + 16|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc6ClientENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 467920 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc8BodyCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 465152 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc14ConstraintCoreENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 467528 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Sc20TriggerPairExtraDataENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_2Sc20TriggerPairExtraDataENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*12)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*12)|0)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;
  }
  $11 = (($$01$i) + 12|0);
  $12 = ($11>>>0)<($7>>>0);
  if ($12) {
   $$01$i = $11;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Sc20TriggerPairExtraDataENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*12)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 468032 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*12)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;
   }
   $20 = (($$012$i) + 12|0);
   $21 = (($$03$i) + 12|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*24)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*24)|0)|0);
 $10 = (($a) + 20|0);
 $$01$i = $9;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$$01$i+16>>2]=HEAP32[$a+16>>2]|0;
   $12 = HEAP8[$10>>0]|0;
   $13 = (($$01$i) + 20|0);
   HEAP8[$13>>0] = $12;
  }
  $14 = (($$01$i) + 24|0);
  $15 = ($14>>>0)<($7>>>0);
  if ($15) {
   $$01$i = $14;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_13PxTriggerPairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*24)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 468168 : 464392;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,464536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*24)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
    $20 = (($$03$i) + 20|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = (($$012$i) + 20|0);
    HEAP8[$22>>0] = $21;
   }
   $23 = (($$012$i) + 24|0);
   $24 = (($$03$i) + 24|0);
   $25 = ($23>>>0)<($15>>>0);
   if ($25) {
    $$012$i = $23;$$03$i = $24;
   } else {
    break;
   }
  }
 }
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$26>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$this>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  HEAP32[$this>>2] = $16;
  HEAP32[$26>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $31 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 FUNCTION_TABLE_vii[$34 & 4095]($31,$29);
 HEAP32[$this>>2] = $16;
 HEAP32[$26>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc17ParticleSystemSimENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 467784 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc6ClientENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 467920 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11collideStepEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11collideStepEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11collideStepEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11collideStepEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene11collideStepEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9solveStepEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9solveStepEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9solveStepEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9solveStepEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene9solveStepEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10broadPhaseEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10broadPhaseEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10broadPhaseEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10broadPhaseEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[((545760 + 2|0))>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($1) + 1184|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = HEAP32[$7>>2]|0;
   $10 = (($9) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP16[545760>>1]|0;
   $13 = (($1) + 1176|0);
   $14 = $13;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_viiiii[$11 & 255]($7,$12,$16,$19,99999789);
  }
 }
 $20 = (($1) + 144|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $31 = (($1) + 1212|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 1000|0);
  $34 = HEAP32[$33>>2]|0;
  __ZN5physx10PxsContext16updateBroadPhaseEPNS_10PxBaseTaskEb($34,$3,0);
  STACKTOP = sp;return;
 }
 $23 = (($1) + 140|0);
 $i$01$i = 0;
 while(1) {
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($i$01$i<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__ZNK5physx2Sc9ClothCore6getSimEv($26)|0);
  __ZN5physx2Sc8ClothSim12updateBoundsEv($27);
  $28 = (($i$01$i) + 1)|0;
  $29 = HEAP32[$20>>2]|0;
  $30 = ($28>>>0)<($29>>>0);
  if ($30) {
   $i$01$i = $28;
  } else {
   break;
  }
 }
 $31 = (($1) + 1212|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 1000|0);
 $34 = HEAP32[$33>>2]|0;
 __ZN5physx10PxsContext16updateBroadPhaseEPNS_10PxBaseTaskEb($34,$3,0);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm10FanoutTaskC2EPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $this;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 4|0);
 HEAP16[$4>>1] = -1;
 $5 = (($this) + 6|0);
 HEAP16[$5>>1] = 0;
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$this>>2] = ((436992 + 8|0));
 $7 = (($this) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 16|0);
 HEAP32[$8>>2] = $name;
 $9 = (($this) + 20|0);
 $10 = (($this) + 36|0);
 $11 = (($this) + 40|0);
 $12 = (($this) + 44|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 48|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $9;
 HEAP32[$13>>2] = 4;
 $14 = (($this) + 52|0);
 $15 = (($this) + 68|0);
 $16 = (($this) + 72|0);
 $17 = (($this) + 76|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 80|0);
 HEAP8[$15>>0] = 1;
 HEAP32[$16>>2] = $14;
 HEAP32[$18>>2] = 4;
 $19 = (($this) + 84|0);
 HEAP8[$19>>0] = 0;
 $20 = (($this) + 88|0);
 $21 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  HEAP32[$20>>2] = 0;
  STACKTOP = sp;return;
 }
 $24 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (__Z15PxGetFoundationv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
 $$$i$i$i$i = $32 ? 470872 : 464392;
 $33 = (FUNCTION_TABLE_iiiiii[$27 & 255]($24,$22,$$$i$i$i$i,470792,111)|0);
 HEAP32[$20>>2] = $33;
 $34 = ($33|0)==(0|0);
 if ($34) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9MutexImplC2Ev($33);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_14postBroadPhaseEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Cm10FanoutTaskD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_14postBroadPhaseEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Cm10FanoutTaskD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_14postBroadPhaseEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1000|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 5920|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 5916|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7 << 2;
 _memset(($9|0),0,($10|0))|0;
 __ZN5physx2Sc5Scene16finishBroadPhaseEj($1,0);
 __ZN5physx2Sc5Scene20afterGenerateIslandsEv($1);
 $11 = HEAP32[$2>>2]|0;
 $12 = (($11) + 1000|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx10PxsContext19resetThreadContextsEv($13);
 $14 = HEAP8[((545760 + 2|0))>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($1) + 1184|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$17>>2]|0;
 $20 = (($19) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP16[545760>>1]|0;
 $23 = (($1) + 1176|0);
 $24 = $23;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_viiiii[$21 & 255]($17,$22,$26,$29,99999789);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_20rigidBodyNarrowPhaseEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_20rigidBodyNarrowPhaseEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_20rigidBodyNarrowPhaseEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_20rigidBodyNarrowPhaseEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[((545768 + 2|0))>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($1) + 1184|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = HEAP32[$7>>2]|0;
   $10 = (($9) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP16[545768>>1]|0;
   $13 = (($1) + 1176|0);
   $14 = $13;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_viiiii[$11 & 255]($7,$12,$16,$19,99999789);
  }
 }
 $20 = (($1) + 1212|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 1000|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($1) + 48|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 __ZN5physx10PxsContext20updateContactManagerEfPNS_10PxBaseTaskE($23,$25,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9islandGenEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9islandGenEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9islandGenEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9islandGenEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[((545776 + 2|0))>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $$pre$i = (($1) + 1184|0);
 if (!($5)) {
  $6 = HEAP32[$$pre$i>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = HEAP32[$6>>2]|0;
   $9 = (($8) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP16[545776>>1]|0;
   $12 = (($1) + 1176|0);
   $13 = $12;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($13) + 4)|0;
   $17 = $16;
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_viiiii[$10 & 255]($6,$11,$15,$18,99999789);
  }
 }
 $19 = (($1) + 1212|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 1000|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx2Sc5Scene29processNarrowPhaseTouchEventsEv($1);
 $23 = HEAP32[$$pre$i>>2]|0;
 $24 = (($1) + 1176|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$23>>2]|0;
 $32 = (($31) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_viiii[$33 & 511]($23,76,$27,$30);
 $34 = (($1) + 48|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 __ZN5physx10PxsContext13updateIslandsEfPNS_10PxBaseTaskE($22,$35,$3);
 $36 = HEAP32[$23>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_viiii[$38 & 511]($23,76,$27,$30);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13postIslandGenEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13postIslandGenEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13postIslandGenEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13postIslandGenEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene13postIslandGenEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19islandGenSecondPassEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19islandGenSecondPassEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19islandGenSecondPassEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19islandGenSecondPassEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene19islandGenSecondPassEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_23postIslandGenSecondPassEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_23postIslandGenSecondPassEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_23postIslandGenSecondPassEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_23postIslandGenSecondPassEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene23postIslandGenSecondPassEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_6solverEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_6solverEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_6solverEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_6solverEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene6solverEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10postSolverEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10postSolverEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10postSolverEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10postSolverEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene10postSolverEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18updateCCDMultiPassEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18updateCCDMultiPassEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18updateCCDMultiPassEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18updateCCDMultiPassEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Scene18updateCCDMultiPassEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_17finalizationPhaseEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Cm10FanoutTaskD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_17finalizationPhaseEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Cm10FanoutTaskD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_17finalizationPhaseEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $8 = 0;
 } else {
  $3 = (($this) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $8 = $5;
 }
 $6 = (($this) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx2Sc5Scene17finalizationPhaseEPNS_10PxBaseTaskE($7,$8);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_20particlePostShapeGenEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Cm10FanoutTaskD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_20particlePostShapeGenEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Cm10FanoutTaskD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_20particlePostShapeGenEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($1) + 128|0);
 $i$01$i = 0;
 while(1) {
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($i$01$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  __ZN5physx2Sc17ParticleSystemSim19processShapesUpdateEv($8);
  $9 = (($i$01$i) + 1)|0;
  $10 = HEAP32[$2>>2]|0;
  $11 = ($9>>>0)<($10>>>0);
  if ($11) {
   $i$01$i = $9;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_15postNarrowPhaseEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_15postNarrowPhaseEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_15postNarrowPhaseEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_15postNarrowPhaseEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $$pre$i = (($1) + 1212|0);
 if (!($4)) {
  $5 = HEAP32[$$pre$i>>2]|0;
  $6 = (($5) + 1000|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 1448|0);
  __ZN5physx21PxsBodyTransformVault6updateEv($8);
 }
 $9 = HEAP32[$$pre$i>>2]|0;
 __ZN5physx2Sc16InteractionScene18releaseConstraintsEb($9,0);
 $10 = HEAP8[((545768 + 2|0))>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = (($1) + 1184|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = HEAP32[$13>>2]|0;
   $16 = (($15) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP16[545768>>1]|0;
   $19 = (($1) + 1176|0);
   $20 = $19;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_viiiii[$17 & 255]($13,$18,$22,$25,99999789);
  }
 }
 $26 = HEAP8[((545752 + 2|0))>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (($1) + 1184|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$29>>2]|0;
 $32 = (($31) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP16[545752>>1]|0;
 $35 = (($1) + 1176|0);
 $36 = $35;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viiiii[$33 & 255]($29,$34,$38,$41,99999789);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18clothPreprocessingEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18clothPreprocessingEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18clothPreprocessingEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18clothPreprocessingEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($1) + 140|0);
  $i$02$i = 0;
  while(1) {
   $9 = HEAP32[$5>>2]|0;
   $10 = (($9) + ($i$02$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__ZNK5physx2Sc9ClothCore6getSimEv($11)|0);
   __ZN5physx2Sc8ClothSim9startStepEv($12);
   $13 = (($i$02$i) + 1)|0;
   $14 = HEAP32[$2>>2]|0;
   $15 = ($13>>>0)<($14>>>0);
   if ($15) {
    $i$02$i = $13;
   } else {
    break;
   }
  }
 }
 $6 = (($1) + 160|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $16 = HEAP32[$7>>2]|0;
  $17 = (($16) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vi[$18 & 4095]($7);
 }
 $19 = (($1) + 164|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$20>>2]|0;
 $23 = (($22) + 20|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_vi[$24 & 4095]($20);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_17PxActiveTransformENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0;
 var $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0;
 var $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*36)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 471648 : 464392;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,464536,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*36)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
    $35 = (($$012$i) + 8|0);
    $36 = (($$03$i) + 8|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 12|0);
    $39 = (($$03$i) + 12|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 16|0);
    $42 = (($$03$i) + 16|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$41>>2] = $43;
    $44 = (($$012$i) + 20|0);
    $45 = (($$03$i) + 20|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    HEAPF32[$44>>2] = $46;
    $47 = (($$012$i) + 24|0);
    $48 = (($$03$i) + 24|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$47>>2] = $49;
    $50 = (($$012$i) + 28|0);
    $51 = (($$03$i) + 28|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    HEAPF32[$50>>2] = $52;
    $53 = (($$012$i) + 32|0);
    $54 = (($$03$i) + 32|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    HEAPF32[$53>>2] = $55;
   }
   $56 = (($$012$i) + 36|0);
   $57 = (($$03$i) + 36|0);
   $58 = ($56>>>0)<($20>>>0);
   if ($58) {
    $$012$i = $56;$$03$i = $57;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $60 = $$pre;
 } else {
  $60 = $19;
 }
 $59 = (($21) + (($60*36)|0)|0);
 $61 = ($59|0)==(0|0);
 if (!($61)) {
  $62 = $a;
  $63 = $62;
  $64 = HEAP32[$63>>2]|0;
  $65 = (($62) + 4)|0;
  $66 = $65;
  $67 = HEAP32[$66>>2]|0;
  $68 = $59;
  $69 = $68;
  HEAP32[$69>>2] = $64;
  $70 = (($68) + 4)|0;
  $71 = $70;
  HEAP32[$71>>2] = $67;
  $72 = ((($21) + (($60*36)|0)|0) + 8|0);
  $73 = (($a) + 8|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  HEAPF32[$72>>2] = $74;
  $75 = ((($21) + (($60*36)|0)|0) + 12|0);
  $76 = (($a) + 12|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  HEAPF32[$75>>2] = $77;
  $78 = ((($21) + (($60*36)|0)|0) + 16|0);
  $79 = (($a) + 16|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  HEAPF32[$78>>2] = $80;
  $81 = ((($21) + (($60*36)|0)|0) + 20|0);
  $82 = (($a) + 20|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  HEAPF32[$81>>2] = $83;
  $84 = ((($21) + (($60*36)|0)|0) + 24|0);
  $85 = (($a) + 24|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  HEAPF32[$84>>2] = $86;
  $87 = ((($21) + (($60*36)|0)|0) + 28|0);
  $88 = (($a) + 28|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  HEAPF32[$87>>2] = $89;
  $90 = ((($21) + (($60*36)|0)|0) + 32|0);
  $91 = (($a) + 32|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  HEAPF32[$90>>2] = $92;
 }
 $93 = HEAP32[$0>>2]|0;
 $94 = ($93|0)>(-1);
 if (!($94)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $101 = HEAP32[$18>>2]|0;
  $102 = (($101) + 1)|0;
  HEAP32[$18>>2] = $102;
  $103 = (($21) + (($101*36)|0)|0);
  STACKTOP = sp;return ($103|0);
 }
 $95 = HEAP32[$this>>2]|0;
 $96 = ($95|0)==(0|0);
 if ($96) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $101 = HEAP32[$18>>2]|0;
  $102 = (($101) + 1)|0;
  HEAP32[$18>>2] = $102;
  $103 = (($21) + (($101*36)|0)|0);
  STACKTOP = sp;return ($103|0);
 }
 $97 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (($98) + 12|0);
 $100 = HEAP32[$99>>2]|0;
 FUNCTION_TABLE_vii[$100 & 4095]($97,$95);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $101 = HEAP32[$18>>2]|0;
 $102 = (($101) + 1)|0;
 HEAP32[$18>>2] = $102;
 $103 = (($21) + (($101*36)|0)|0);
 STACKTOP = sp;return ($103|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc12SimStateDataENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc12SimStateDataEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<6)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 64|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc13ConstraintSimENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0, $notlhs = 0;
 var $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc13ConstraintSimEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + ($31<<7)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      __ZN5physx2Sc13ConstraintSimD2Ev($tIt$02);
      $freeIt$2 = $freeIt$11;
     }
     $39 = (($tIt$02) + 128|0);
     $40 = ($39|0)==($32|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$05) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc21ConstraintInteractionENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0;
 var $freeIt$2 = 0, $freeNodes = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc21ConstraintInteractionEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + (($31*40)|0)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $39 = HEAP32[$tIt$02>>2]|0;
      $40 = (($39) + 8|0);
      $41 = HEAP32[$40>>2]|0;
      FUNCTION_TABLE_vi[$41 & 4095]($tIt$02);
      $freeIt$2 = $freeIt$11;
     }
     $42 = (($tIt$02) + 40|0);
     $43 = ($42|0)==($32|0);
     if ($43) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $42;
     }
    }
   }
   $44 = (($slabIt$05) + 4|0);
   $45 = ($44|0)==($27|0);
   if ($45) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $44;
   }
  }
 }
 $46 = HEAP32[$4>>2]|0;
 $47 = $46 & 2147483647;
 $notlhs = ($47|0)==(0);
 $notrhs = ($46|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $48 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $48;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $49 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095]($49,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ConstraintGroupNodeENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ConstraintGroupNodeEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + (($30*48)|0)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 48|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ShapeCoreC2ERKNS_10PxGeometryENS_7PxFlagsINS_11PxShapeFlag4EnumEhEEPKtt($this,$geometry,$shapeFlags,$materialIndices,$materialCount) {
 $this = $this|0;
 $geometry = $geometry|0;
 $shapeFlags = $shapeFlags|0;
 $materialIndices = $materialIndices|0;
 $materialCount = $materialCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
 HEAP32[$0>>2] = (-1);
 $1 = (($this) + 128|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 132|0);
 HEAP8[$2>>0] = 1;
 $3 = HEAP32[463296>>2]|0;
 $4 = (($this) + 68|0);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($4,$geometry);
 $5 = (($this) + 32|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 36|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 40|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 44|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 48|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 52|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 56|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = Math_fround(HEAPF32[$3>>2]);
 $13 = Math_fround($12 * Math_fround(0.0199999995529651641846));
 $14 = (($this) + 60|0);
 HEAPF32[$14>>2] = $13;
 $15 = HEAP8[$shapeFlags>>0]|0;
 $16 = (($this) + 64|0);
 HEAP8[$16>>0] = $15;
 __ZN5physx2Sc9ShapeCore18setMaterialIndicesEPKtt($this,$materialIndices,$materialCount);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ShapeCore18setMaterialIndicesEPKtt($this,$materialIndices,$materialIndexCount) {
 $this = $this|0;
 $materialIndices = $materialIndices|0;
 $materialIndexCount = $materialIndexCount|0;
 var $$pre$phi$i3Z2D = 0, $$pre$phi$iZ2D = 0, $$pre1$i = 0, $$pre1$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP16[$materialIndices>>1]|0;
 $4 = (($this) + 66|0);
 HEAP16[$4>>1] = $3;
 if ((($2|0) == 5)) {
  $5 = (($this) + 116|0);
  $6 = (($this) + 132|0);
  $7 = (($this) + 120|0);
  $8 = HEAP16[$7>>1]|0;
  $9 = $materialIndexCount&65535;
  $10 = ($8&65535)<($materialIndexCount&65535);
  $11 = HEAP32[$5>>2]|0;
  if ($10) {
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = HEAP8[$6>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if (!($14)) {
     __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
     HEAP16[$7>>1] = 0;
    }
   }
   $15 = $9 << 1;
   $16 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$15,472064,101)|0);
   HEAP32[$5>>2] = $16;
   HEAP16[$7>>1] = $materialIndexCount;
   HEAP8[$6>>0] = 1;
   $$pre$phi$i3Z2D = $15;$17 = $16;
  } else {
   $$pre1$i1 = $9 << 1;
   $$pre$phi$i3Z2D = $$pre1$i1;$17 = $11;
  }
  _memcpy(($17|0),($materialIndices|0),($$pre$phi$i3Z2D|0))|0;
  STACKTOP = sp;return;
 } else if ((($2|0) == 6)) {
  $18 = (($this) + 96|0);
  $19 = (($this) + 132|0);
  $20 = (($this) + 100|0);
  $21 = HEAP16[$20>>1]|0;
  $22 = $materialIndexCount&65535;
  $23 = ($21&65535)<($materialIndexCount&65535);
  $24 = HEAP32[$18>>2]|0;
  if ($23) {
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = HEAP8[$19>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if (!($27)) {
     __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$24);
     HEAP16[$20>>1] = 0;
    }
   }
   $28 = $22 << 1;
   $29 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$28,472064,101)|0);
   HEAP32[$18>>2] = $29;
   HEAP16[$20>>1] = $materialIndexCount;
   HEAP8[$19>>0] = 1;
   $$pre$phi$iZ2D = $28;$30 = $29;
  } else {
   $$pre1$i = $22 << 1;
   $$pre$phi$iZ2D = $$pre1$i;$30 = $24;
  }
  _memcpy(($30|0),($materialIndices|0),($$pre$phi$iZ2D|0))|0;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc9ShapeCoreD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 if ((($2|0) == 6)) {
  $9 = (($this) + 132|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = (($this) + 96|0);
  $13 = HEAP32[$12>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$13);
  $14 = (($this) + 100|0);
  HEAP16[$14>>1] = 0;
  STACKTOP = sp;return;
 } else if ((($2|0) == 5)) {
  $3 = (($this) + 132|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   STACKTOP = sp;return;
  }
  $6 = (($this) + 116|0);
  $7 = HEAP32[$6>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
  $8 = (($this) + 120|0);
  HEAP16[$8>>1] = 0;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc9ShapeCore14setShape2ActorERKNS_11PxTransformE($this,$s2b) {
 $this = $this|0;
 $s2b = $s2b|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$s2b>>2]);
 $1 = (($this) + 32|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($s2b) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 36|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($s2b) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 40|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($s2b) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 44|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($s2b) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 48|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($s2b) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 52|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($s2b) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 56|0);
 HEAPF32[$19>>2] = $18;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ShapeCore23setSimulationFilterDataERKNS_12PxFilterDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 ;HEAP32[$0+0>>2]=HEAP32[$data+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$data+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$data+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$data+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ShapeCore20getNbMaterialIndicesEv($this) {
 $this = $this|0;
 var $$0 = 0, $$off = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $$off = (($1) + -5)|0;
 $2 = ($$off>>>0)>(1);
 do {
  if ($2) {
   $$0 = 1;
  } else {
   $3 = ($1|0)==(5);
   if ($3) {
    $4 = (($this) + 120|0);
    $5 = HEAP16[$4>>1]|0;
    $$0 = $5;
    break;
   } else {
    $6 = (($this) + 100|0);
    $7 = HEAP16[$6>>1]|0;
    $$0 = $7;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sc9ShapeCore18getMaterialIndicesEv($this) {
 $this = $this|0;
 var $$0 = 0, $$off = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $$off = (($1) + -5)|0;
 $2 = ($$off>>>0)>(1);
 do {
  if ($2) {
   $3 = (($this) + 66|0);
   $$0 = $3;
  } else {
   $4 = ($1|0)==(5);
   if ($4) {
    $5 = (($this) + 116|0);
    $6 = HEAP32[$5>>2]|0;
    $$0 = $6;
    break;
   } else {
    $7 = (($this) + 96|0);
    $8 = HEAP32[$7>>2]|0;
    $$0 = $8;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc9ShapeCore13setRestOffsetEf($this,$s) {
 $this = $this|0;
 $s = Math_fround($s);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 HEAPF32[$0>>2] = $s;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ShapeCore11setGeometryERKNS_10PxGeometryE($this,$geom) {
 $this = $this|0;
 $geom = $geom|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newMaterials$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$geom>>2]|0;
 if ((($2|0) == 6)) {
  $16 = (($this) + 96|0);
  $17 = $16;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = $19;
  $24 = $22&65535;
  $25 = (_bitshift64Lshr(($19|0),($22|0),48)|0);
  $26 = tempRet0;
  $27 = $25&65535;
  $33 = $24;$35 = $23;$37 = $27;
 } else if ((($2|0) == 5)) {
  $4 = (($this) + 116|0);
  $5 = $4;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) + 4)|0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = $7;
  $12 = $10&65535;
  $13 = (_bitshift64Lshr(($7|0),($10|0),48)|0);
  $14 = tempRet0;
  $15 = $13&65535;
  $33 = $12;$35 = $11;$37 = $15;
 } else {
  $33 = 0;$35 = 0;$37 = 0;
 }
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($1,$geom);
 $$off = (($3) + -5)|0;
 $28 = ($$off>>>0)<(2);
 if ($28) {
  $29 = ($3|0)==(5);
  $30 = (($this) + 116|0);
  $31 = (($this) + 96|0);
  $newMaterials$0$in = $29 ? $30 : $31;
  $32 = ($33<<16>>16)==(0);
  if ($32) {
   $47 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,2,472064,101)|0);
   HEAP32[$newMaterials$0$in>>2] = $47;
   $48 = (($newMaterials$0$in) + 4|0);
   HEAP16[$48>>1] = 1;
   $49 = (($this) + 66|0);
   $50 = HEAP16[$49>>1]|0;
   HEAP16[$47>>1] = $50;
   $51 = (($this) + 132|0);
   HEAP8[$51>>0] = 1;
   STACKTOP = sp;return;
  } else {
   $34 = $35;
   $36 = $37&65535;
   $38 = (_bitshift64Shl(($36|0),0,48)|0);
   $39 = tempRet0;
   $40 = $33&65535;
   $41 = $40 | $39;
   $42 = $38 | $34;
   $43 = $newMaterials$0$in;
   $44 = $43;
   HEAP32[$44>>2] = $42;
   $45 = (($43) + 4)|0;
   $46 = $45;
   HEAP32[$46>>2] = $41;
   STACKTOP = sp;return;
  }
 }
 $52 = ($33<<16>>16)==(0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = (($this) + 132|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$35);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ShapeCore8setFlagsENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$f>>0]|0;
 $1 = (($this) + 64|0);
 HEAP8[$1>>0] = $0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ShapeCore10getPxShapeEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx12NpGetPxShapeERNS_2Sc9ShapeCoreE($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z28ScGetPxShapeFromPxsShapeCorePKN5physx12PxsShapeCoreE($shape) {
 $shape = $shape|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + -32|0);
 $1 = (__ZN5physx12NpGetPxShapeERNS_2Sc9ShapeCoreE($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc9ShapeCore15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 6)) {
  $14 = (($this) + 96|0);
  $15 = HEAP32[$stream>>2]|0;
  $16 = (($15) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 4095]($stream,16);
  $18 = HEAP32[$stream>>2]|0;
  $19 = (($18) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$14>>2]|0;
  $22 = (($this) + 100|0);
  $23 = HEAP16[$22>>1]|0;
  $24 = $23&65535;
  $25 = $24 << 1;
  FUNCTION_TABLE_viii[$20 & 4095]($stream,$21,$25);
  STACKTOP = sp;return;
 } else if ((($1|0) == 5)) {
  $2 = (($this) + 116|0);
  $3 = HEAP32[$stream>>2]|0;
  $4 = (($3) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($stream,16);
  $6 = HEAP32[$stream>>2]|0;
  $7 = (($6) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$2>>2]|0;
  $10 = (($this) + 120|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = $11&65535;
  $13 = $12 << 1;
  FUNCTION_TABLE_viii[$8 & 4095]($stream,$9,$13);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc19ShapeInstancePairLLC2ERNS0_8ShapeSimES3_RNS0_9ActorPairENS_7PxFlagsINS_10PxPairFlag4EnumEtEE($this,$s1,$s2,$aPair,$pairFlags) {
 $this = $this|0;
 $s1 = $s1|0;
 $s2 = $s2|0;
 $aPair = $aPair|0;
 $pairFlags = $pairFlags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((463024 + 8|0));
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 1;
 $2 = (($this) + 8|0);
 $3 = (($s1) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($s2) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc11InteractionC2ERNS0_5ActorES3_NS0_15InteractionTypeEh($2,$4,$6,0,21);
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $s1;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = $s2;
 $9 = (($this) + 8|0);
 HEAP32[$this>>2] = ((472144 + 8|0));
 HEAP32[$9>>2] = ((472144 + 52|0));
 $10 = (($this) + 40|0);
 HEAP32[$10>>2] = -1;
 $11 = (($this) + 44|0);
 $12 = (($this) + 48|0);
 HEAP32[$12>>2] = $aPair;
 $13 = (($this) + 52|0);
 HEAP32[$13>>2] = -1;
 $14 = (($this) + 56|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 60|0);
 HEAP32[$15>>2] = -1;
 $16 = (($this) + 64|0);
 HEAP16[$16>>1] = 0;
 $17 = HEAP16[$pairFlags>>1]|0;
 $18 = $17&65535;
 $19 = $18 & 32767;
 HEAP32[$11>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL9visualizeERNS_2Cm12RenderOutputE($this,$out) {
 $this = $this|0;
 $out = $out|0;
 var $$0$i$i$i = 0, $$0$i$i$i27 = 0, $$in = 0, $$in$us = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0;
 var $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0;
 var $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $color$0$us = 0, $exitcond = 0, $exitcond35 = 0, $fabsf$i$i$us = Math_fround(0), $idx$0$ph$i = 0, $idx$04$i = 0, $length$0$us = Math_fround(0), $modify$0$off0$i$i = 0, $nextOffset$0 = 0, $not$$i = 0, $not$2$i = 0, $or$cond = 0, $patchHeaderSize$0$i$i = 0, $pointSize$0$i$i = 0, $start$0$i$i = 0;
 var $start$0$i$i2330 = 0, $start$0$i$i2330$us = 0, $start$0$i$i2532 = 0, $startOffset$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 84|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 $6 = sp + 60|0;
 $7 = sp + 72|0;
 $8 = (($this) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($12)|0);
 $14 = (($13) + 1416|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$11>>2]|0;
 $20 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($19)|0);
 $21 = ($18|0)==($20|0);
 $22 = $21 ? Math_fround(1.0) : Math_fround(-1.0);
 $23 = (($0) + 4|0);
 $24 = (($0) + 8|0);
 $25 = (($1) + 4|0);
 $26 = (($1) + 8|0);
 $27 = Math_fround($15 * Math_fround(0.100000001490116119385));
 $28 = (($2) + 4|0);
 $29 = (($2) + 8|0);
 $30 = (($3) + 4|0);
 $31 = (($3) + 8|0);
 $32 = (($4) + 4|0);
 $33 = (($4) + 8|0);
 $34 = (($5) + 4|0);
 $35 = (($5) + 8|0);
 $36 = (($6) + 4|0);
 $37 = (($6) + 8|0);
 $38 = (($7) + 4|0);
 $39 = (($7) + 8|0);
 $nextOffset$0 = 0;
 while(1) {
  $40 = HEAP32[$8>>2]|0;
  $41 = ($40|0)==(0|0);
  L6: do {
   if ($41) {
    $$0$i$i$i27 = 0;$219 = $nextOffset$0;$81 = 0;$83 = 0;
   } else {
    $42 = (($40) + 40|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($40) + 44|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($40) + 48|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($40) + 114|0);
    $49 = HEAP16[$48>>1]|0;
    $50 = $49 & 16;
    $51 = ($50<<16>>16)==(0);
    if ($51) {
     $$0$i$i$i = 0;
    } else {
     $52 = (($47) + 15)|0;
     $53 = $52 & -16;
     $54 = (($45) + ($53)|0);
     $$0$i$i$i = $54;
    }
    $55 = (($40) + 36|0);
    $56 = HEAP16[$55>>1]|0;
    $57 = ($56<<16>>16)==(0);
    if ($57) {
     $idx$0$ph$i = 0;
    } else {
     $58 = ($nextOffset$0|0)==(0);
     if ($58) {
      $not$2$i = ($43|0)!=(0|0);
      $60 = $not$2$i&1;
      $$0$i$i$i27 = $$0$i$i$i;$219 = $60;$81 = $47;$83 = $45;
      break;
     } else {
      $idx$0$ph$i = 1;
     }
    }
    $59 = ($43|0)==(0|0);
    if ($59) {
     $$0$i$i$i27 = 0;$219 = $nextOffset$0;$81 = 0;$83 = 0;
    } else {
     $63 = $43;$idx$04$i = $idx$0$ph$i;
     while(1) {
      $61 = ($idx$04$i|0)==($nextOffset$0|0);
      if ($61) {
       break;
      }
      $73 = (($idx$04$i) + 1)|0;
      $74 = HEAP32[$63>>2]|0;
      $75 = ($74|0)==(0|0);
      if ($75) {
       $$0$i$i$i27 = 0;$219 = $nextOffset$0;$81 = 0;$83 = 0;
       break L6;
      } else {
       $63 = $74;$idx$04$i = $73;
      }
     }
     $62 = (($63) + 4|0);
     $64 = HEAP16[$62>>1]|0;
     $65 = (($63) + 8|0);
     $66 = $64&65535;
     $67 = (($66) + -8)|0;
     $68 = (($66) + 15)|0;
     $69 = $68 & 131056;
     $70 = (($63) + ($69)|0);
     $71 = HEAP32[$63>>2]|0;
     $not$$i = ($71|0)!=(0|0);
     $72 = $not$$i&1;
     $startOffset$1$i = (($72) + ($nextOffset$0))|0;
     $$0$i$i$i27 = $70;$219 = $startOffset$1$i;$81 = $67;$83 = $65;
    }
   }
  } while(0);
  $76 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($13,10)));
  $77 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($13,8)));
  $78 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($13,9)));
  $79 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($13,7)));
  $80 = ($81|0)==(0);
  if ($80) {
   $modify$0$off0$i$i = 0;$patchHeaderSize$0$i$i = 0;$pointSize$0$i$i = 0;$start$0$i$i = 0;
  } else {
   $82 = (($83) + 2|0);
   $84 = HEAP16[$82>>1]|0;
   $85 = $84&65535;
   $86 = $85 & 2;
   $87 = ($86|0)!=(0);
   $88 = $86 << 3;
   $89 = $88 | 4;
   $90 = (($83) + ($89)|0);
   $91 = $87 ? 4 : 32;
   if ($87) {
    $modify$0$off0$i$i = 1;$patchHeaderSize$0$i$i = $91;$pointSize$0$i$i = 72;$start$0$i$i = $90;
   } else {
    $92 = $85 << 3;
    $93 = $92 & 8;
    $94 = $93 | 16;
    $modify$0$off0$i$i = 0;$patchHeaderSize$0$i$i = $91;$pointSize$0$i$i = $94;$start$0$i$i = $90;
   }
  }
  $95 = $start$0$i$i;
  $96 = $83;
  $97 = (($95) - ($96))|0;
  $98 = ($97>>>0)<($81>>>0);
  if ($98) {
   $99 = $76 == Math_fround(0.0);
   $100 = ($$0$i$i$i27|0)==(0|0);
   $or$cond = $99 | $100;
   $101 = $77 != Math_fround(0.0);
   $102 = Math_fround($15 * $77);
   $103 = $78 != Math_fround(0.0);
   $104 = Math_fround($15 * $78);
   $105 = $79 != Math_fround(0.0);
   $106 = Math_fround($15 * $76);
   $start$0$i$i2532 = $start$0$i$i;
   while(1) {
    $111 = HEAP16[$start$0$i$i2532>>1]|0;
    $112 = $111&65535;
    $113 = Math_imul($112, $pointSize$0$i$i)|0;
    $$sum$i = (($113) + ($patchHeaderSize$0$i$i))|0;
    $108 = (($start$0$i$i2532) + ($$sum$i)|0);
    $114 = (($start$0$i$i2532) + ($patchHeaderSize$0$i$i)|0);
    $115 = ($111<<16>>16)==(0);
    L28: do {
     if (!($115)) {
      $116 = (($start$0$i$i2532) + 4|0);
      if ($or$cond) {
       $118 = 0;$start$0$i$i2330$us = $114;
      } else {
       $169 = 0;$start$0$i$i2330 = $114;
       while(1) {
        $168 = (($169) + 1)|0;
        $170 = (($start$0$i$i2330) + ($pointSize$0$i$i)|0);
        $171 = Math_fround(HEAPF32[$$0$i$i$i27>>2]);
        $172 = Math_fround($106 * $171);
        $173 = $172 != Math_fround(0.0);
        if ($173) {
         $174 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,1)|0);
         $175 = (__ZN5physx2Cm12RenderOutputlsEj($174,16711680)|0);
         $176 = Math_fround(HEAPF32[$start$0$i$i2330>>2]);
         HEAPF32[$0>>2] = $176;
         $177 = (($start$0$i$i2330) + 4|0);
         $178 = Math_fround(HEAPF32[$177>>2]);
         HEAPF32[$23>>2] = $178;
         $179 = (($start$0$i$i2330) + 8|0);
         $180 = Math_fround(HEAPF32[$179>>2]);
         HEAPF32[$24>>2] = $180;
         $181 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($175,$0)|0);
         $182 = (($start$0$i$i2330) + 24|0);
         $$in = $modify$0$off0$i$i ? $182 : $116;
         $183 = Math_fround(HEAPF32[$$in>>2]);
         $184 = Math_fround($172 * $183);
         $185 = (($$in) + 4|0);
         $186 = Math_fround(HEAPF32[$185>>2]);
         $187 = Math_fround($172 * $186);
         $188 = (($$in) + 8|0);
         $189 = Math_fround(HEAPF32[$188>>2]);
         $190 = Math_fround($172 * $189);
         $191 = Math_fround($22 * $184);
         $192 = Math_fround($22 * $187);
         $193 = Math_fround($22 * $190);
         $194 = Math_fround(HEAPF32[$start$0$i$i2330>>2]);
         $195 = Math_fround($191 + $194);
         $196 = Math_fround(HEAPF32[$177>>2]);
         $197 = Math_fround($192 + $196);
         $198 = Math_fround(HEAPF32[$179>>2]);
         $199 = Math_fround($193 + $198);
         HEAPF32[$1>>2] = $195;
         HEAPF32[$25>>2] = $197;
         HEAPF32[$26>>2] = $199;
         (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($181,$1)|0);
        }
        if ($105) {
         $200 = Math_fround(HEAPF32[$start$0$i$i2330>>2]);
         $201 = (($start$0$i$i2330) + 4|0);
         $202 = Math_fround(HEAPF32[$201>>2]);
         $203 = (($start$0$i$i2330) + 8|0);
         $204 = Math_fround(HEAPF32[$203>>2]);
         $205 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,1)|0);
         (__ZN5physx2Cm12RenderOutputlsEj($205,-65536)|0);
         $206 = Math_fround($200 - $27);
         $207 = Math_fround($202 + Math_fround(0.0));
         $208 = Math_fround($204 + Math_fround(0.0));
         HEAPF32[$2>>2] = $206;
         HEAPF32[$28>>2] = $207;
         HEAPF32[$29>>2] = $208;
         $209 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$2)|0);
         $210 = Math_fround($27 + $200);
         HEAPF32[$3>>2] = $210;
         HEAPF32[$30>>2] = $207;
         HEAPF32[$31>>2] = $208;
         (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($209,$3)|0);
         $211 = Math_fround($200 + Math_fround(0.0));
         $212 = Math_fround($202 - $27);
         HEAPF32[$4>>2] = $211;
         HEAPF32[$32>>2] = $212;
         HEAPF32[$33>>2] = $208;
         $213 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$4)|0);
         $214 = Math_fround($27 + $202);
         HEAPF32[$5>>2] = $211;
         HEAPF32[$34>>2] = $214;
         HEAPF32[$35>>2] = $208;
         (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($213,$5)|0);
         $215 = Math_fround($204 - $27);
         HEAPF32[$6>>2] = $211;
         HEAPF32[$36>>2] = $207;
         HEAPF32[$37>>2] = $215;
         $216 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$6)|0);
         $217 = Math_fround($27 + $204);
         HEAPF32[$7>>2] = $211;
         HEAPF32[$38>>2] = $207;
         HEAPF32[$39>>2] = $217;
         (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($216,$7)|0);
        }
        $exitcond = ($168|0)==($112|0);
        if ($exitcond) {
         break L28;
        } else {
         $169 = $168;$start$0$i$i2330 = $170;
        }
       }
      }
      while(1) {
       $117 = (($118) + 1)|0;
       $119 = (($start$0$i$i2330$us) + ($pointSize$0$i$i)|0);
       if ($101) {
        $color$0$us = 255;$length$0$us = $102;
        label = 24;
       } else {
        if ($103) {
         $120 = (($start$0$i$i2330$us) + 12|0);
         $121 = Math_fround(HEAPF32[$120>>2]);
         $122 = Math_fround($104 * $121);
         $fabsf$i$i$us = (Math_fround(Math_abs((Math_fround($122)))));
         $color$0$us = 16776960;$length$0$us = $fabsf$i$i$us;
         label = 24;
        }
       }
       if ((label|0) == 24) {
        label = 0;
        $123 = $length$0$us != Math_fround(0.0);
        if ($123) {
         $124 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,1)|0);
         $125 = (__ZN5physx2Cm12RenderOutputlsEj($124,$color$0$us)|0);
         $126 = Math_fround(HEAPF32[$start$0$i$i2330$us>>2]);
         HEAPF32[$0>>2] = $126;
         $127 = (($start$0$i$i2330$us) + 4|0);
         $128 = Math_fround(HEAPF32[$127>>2]);
         HEAPF32[$23>>2] = $128;
         $129 = (($start$0$i$i2330$us) + 8|0);
         $130 = Math_fround(HEAPF32[$129>>2]);
         HEAPF32[$24>>2] = $130;
         $131 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($125,$0)|0);
         $132 = (($start$0$i$i2330$us) + 24|0);
         $$in$us = $modify$0$off0$i$i ? $132 : $116;
         $133 = Math_fround(HEAPF32[$$in$us>>2]);
         $134 = Math_fround($length$0$us * $133);
         $135 = (($$in$us) + 4|0);
         $136 = Math_fround(HEAPF32[$135>>2]);
         $137 = Math_fround($length$0$us * $136);
         $138 = (($$in$us) + 8|0);
         $139 = Math_fround(HEAPF32[$138>>2]);
         $140 = Math_fround($length$0$us * $139);
         $141 = Math_fround($22 * $134);
         $142 = Math_fround($22 * $137);
         $143 = Math_fround($22 * $140);
         $144 = Math_fround(HEAPF32[$start$0$i$i2330$us>>2]);
         $145 = Math_fround($141 + $144);
         $146 = Math_fround(HEAPF32[$127>>2]);
         $147 = Math_fround($142 + $146);
         $148 = Math_fround(HEAPF32[$129>>2]);
         $149 = Math_fround($143 + $148);
         HEAPF32[$1>>2] = $145;
         HEAPF32[$25>>2] = $147;
         HEAPF32[$26>>2] = $149;
         (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($131,$1)|0);
        }
       }
       if ($105) {
        $150 = Math_fround(HEAPF32[$start$0$i$i2330$us>>2]);
        $151 = (($start$0$i$i2330$us) + 4|0);
        $152 = Math_fround(HEAPF32[$151>>2]);
        $153 = (($start$0$i$i2330$us) + 8|0);
        $154 = Math_fround(HEAPF32[$153>>2]);
        $155 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,1)|0);
        (__ZN5physx2Cm12RenderOutputlsEj($155,-65536)|0);
        $156 = Math_fround($150 - $27);
        $157 = Math_fround($152 + Math_fround(0.0));
        $158 = Math_fround($154 + Math_fround(0.0));
        HEAPF32[$2>>2] = $156;
        HEAPF32[$28>>2] = $157;
        HEAPF32[$29>>2] = $158;
        $159 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$2)|0);
        $160 = Math_fround($27 + $150);
        HEAPF32[$3>>2] = $160;
        HEAPF32[$30>>2] = $157;
        HEAPF32[$31>>2] = $158;
        (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($159,$3)|0);
        $161 = Math_fround($150 + Math_fround(0.0));
        $162 = Math_fround($152 - $27);
        HEAPF32[$4>>2] = $161;
        HEAPF32[$32>>2] = $162;
        HEAPF32[$33>>2] = $158;
        $163 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$4)|0);
        $164 = Math_fround($27 + $152);
        HEAPF32[$5>>2] = $161;
        HEAPF32[$34>>2] = $164;
        HEAPF32[$35>>2] = $158;
        (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($163,$5)|0);
        $165 = Math_fround($154 - $27);
        HEAPF32[$6>>2] = $161;
        HEAPF32[$36>>2] = $157;
        HEAPF32[$37>>2] = $165;
        $166 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$6)|0);
        $167 = Math_fround($27 + $154);
        HEAPF32[$7>>2] = $161;
        HEAPF32[$38>>2] = $157;
        HEAPF32[$39>>2] = $167;
        (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($166,$7)|0);
       }
       $exitcond35 = ($117|0)==($112|0);
       if ($exitcond35) {
        break;
       } else {
        $118 = $117;$start$0$i$i2330$us = $119;
       }
      }
     }
    } while(0);
    $107 = $108;
    $109 = (($107) - ($96))|0;
    $110 = ($109>>>0)<($81>>>0);
    if ($110) {
     $start$0$i$i2532 = $108;
    } else {
     break;
    }
   }
  }
  $218 = ($219|0)==($nextOffset$0|0);
  if ($218) {
   break;
  } else {
   $nextOffset$0 = $219;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL34setContactReportPostSolverVelocityERNS0_20ContactStreamManagerE($this,$cs) {
 $this = $this|0;
 $cs = $cs|0;
 var $$sum = 0, $$sum1 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0;
 var $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0);
 var $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0;
 var $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($1)|0);
 $3 = (($2) + 1088|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$cs>>2]|0;
 $8 = (($this) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($9) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 50|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $$sum18 = (($7) + 12)|0;
  $36 = (($6) + ($$sum18)|0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $$sum19 = (($7) + 16)|0;
  $37 = (($6) + ($$sum19)|0);
  HEAPF32[$37>>2] = Math_fround(0.0);
  $$sum20 = (($7) + 20)|0;
  $38 = (($6) + ($$sum20)|0);
  HEAPF32[$38>>2] = Math_fround(0.0);
  $$sum21 = (($7) + 36)|0;
  $39 = (($6) + ($$sum21)|0);
  HEAPF32[$39>>2] = Math_fround(0.0);
  $$sum22 = (($7) + 40)|0;
  $40 = (($6) + ($$sum22)|0);
  HEAPF32[$40>>2] = Math_fround(0.0);
  $$sum23 = (($7) + 44)|0;
  $41 = (($6) + ($$sum23)|0);
  HEAPF32[$41>>2] = Math_fround(0.0);
 } else {
  $16 = (($10) + 52|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 80|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $$sum = (($7) + 12)|0;
  $20 = (($6) + ($$sum)|0);
  HEAPF32[$20>>2] = $19;
  $21 = (($17) + 84|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $$sum1 = (($7) + 16)|0;
  $23 = (($6) + ($$sum1)|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($17) + 88|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $$sum2 = (($7) + 20)|0;
  $26 = (($6) + ($$sum2)|0);
  HEAPF32[$26>>2] = $25;
  $27 = (($17) + 96|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $$sum3 = (($7) + 36)|0;
  $29 = (($6) + ($$sum3)|0);
  HEAPF32[$29>>2] = $28;
  $30 = (($17) + 100|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $$sum4 = (($7) + 40)|0;
  $32 = (($6) + ($$sum4)|0);
  HEAPF32[$32>>2] = $31;
  $33 = (($17) + 104|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $$sum5 = (($7) + 44)|0;
  $35 = (($6) + ($$sum5)|0);
  HEAPF32[$35>>2] = $34;
 }
 $42 = (($12) + 50|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if ($44) {
  $$sum12 = (($7) + 24)|0;
  $65 = (($6) + ($$sum12)|0);
  HEAPF32[$65>>2] = Math_fround(0.0);
  $$sum13 = (($7) + 28)|0;
  $66 = (($6) + ($$sum13)|0);
  HEAPF32[$66>>2] = Math_fround(0.0);
  $$sum14 = (($7) + 32)|0;
  $67 = (($6) + ($$sum14)|0);
  HEAPF32[$67>>2] = Math_fround(0.0);
  $$sum15 = (($7) + 48)|0;
  $68 = (($6) + ($$sum15)|0);
  HEAPF32[$68>>2] = Math_fround(0.0);
  $$sum16 = (($7) + 52)|0;
  $69 = (($6) + ($$sum16)|0);
  HEAPF32[$69>>2] = Math_fround(0.0);
  $$sum17 = (($7) + 56)|0;
  $70 = (($6) + ($$sum17)|0);
  HEAPF32[$70>>2] = Math_fround(0.0);
  $71 = (($cs) + 10|0);
  $72 = HEAP16[$71>>1]|0;
  $73 = $72&65535;
  $74 = $73 & 65527;
  $75 = $74&65535;
  HEAP16[$71>>1] = $75;
  STACKTOP = sp;return;
 } else {
  $45 = (($12) + 52|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + 80|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $$sum6 = (($7) + 24)|0;
  $49 = (($6) + ($$sum6)|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($46) + 84|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $$sum7 = (($7) + 28)|0;
  $52 = (($6) + ($$sum7)|0);
  HEAPF32[$52>>2] = $51;
  $53 = (($46) + 88|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $$sum8 = (($7) + 32)|0;
  $55 = (($6) + ($$sum8)|0);
  HEAPF32[$55>>2] = $54;
  $56 = (($46) + 96|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $$sum9 = (($7) + 48)|0;
  $58 = (($6) + ($$sum9)|0);
  HEAPF32[$58>>2] = $57;
  $59 = (($46) + 100|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $$sum10 = (($7) + 52)|0;
  $61 = (($6) + ($$sum10)|0);
  HEAPF32[$61>>2] = $60;
  $62 = (($46) + 104|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $$sum11 = (($7) + 56)|0;
  $64 = (($6) + ($$sum11)|0);
  HEAPF32[$64>>2] = $63;
  $71 = (($cs) + 10|0);
  $72 = HEAP16[$71>>1]|0;
  $73 = $72&65535;
  $74 = $73 & 65527;
  $75 = $74&65535;
  HEAP16[$71>>1] = $75;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($this,$contactEvent,$infoFlags,$shapeDeleted,$touchLost,$ccdPass) {
 $this = $this|0;
 $contactEvent = $contactEvent|0;
 $infoFlags = $infoFlags|0;
 $shapeDeleted = $shapeDeleted|0;
 $touchLost = $touchLost|0;
 $ccdPass = $ccdPass|0;
 var $$ = 0, $$$i = 0, $$$i9 = 0, $$0 = 0, $$0$i$i = 0, $$0$in = 0, $$19 = 0, $$20 = 0, $$7 = 0, $$in = 0, $$not = 0, $$not5 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i14 = 0, $$pre$phiZ2D = 0, $$pre21 = 0, $$pre22 = 0;
 var $$pre27 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alignedContactDataSize$0 = 0, $brmerge = 0, $brmerge4 = 0, $brmerge6 = 0, $brmerge8 = 0;
 var $cData$0 = 0, $cDataSize$0 = 0, $cp$0 = 0, $cp$1 = 0, $extraDataSize_$1$i = 0, $extraDataSize_$1$i10 = 0, $extraDataSize_$2$i = 0, $extraDataSize_$2$i11 = 0, $extraDataSize_$3$i = 0, $impulses$0 = 0, $lastContactPass$0 = 0, $maxCount$0 = 0, $maxExtraDataSize$0 = 0, $nbBlocks$0$i1$i = 0, $nbPoints$0 = 0, $not$ = 0, $not$$i$i = 0, $strPtr$0 = 0, $stream$0 = 0, $stream$018 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($ccdPass|0)!=(0);
 $2 = $contactEvent | 32;
 $3 = $1 ? $2 : $contactEvent;
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
 }
 $7 = (($this) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($8)|0);
 $10 = (($9) + 1088|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 28672;
 $15 = (($this) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$7>>2]|0;
 $19 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($18)|0);
 $20 = ($17|0)==($19|0);
 $21 = (($this) + 36|0);
 $$19 = $20 ? $21 : $7;
 $$20 = $20 ? $7 : $21;
 $$in = HEAP32[$$20>>2]|0;
 $$sink = HEAP32[$$19>>2]|0;
 $22 = HEAP32[$15>>2]|0;
 $23 = (($22) + 12|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = $24&65535;
 $26 = $25 & 1;
 $27 = ($26|0)==(0);
 if ($27) {
  $28 = $25 | 1;
  $29 = $28&65535;
  HEAP16[$23>>1] = $29;
  $30 = HEAP32[$15>>2]|0;
  HEAP32[$0>>2] = $30;
  $31 = (($11) + 4|0);
  $32 = (($11) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 & 2147483647;
  $35 = (($11) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($34>>>0)>($36>>>0);
  if ($37) {
   $38 = HEAP32[$31>>2]|0;
   $39 = (($38) + ($36<<2)|0);
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    HEAP32[$39>>2] = $30;
   }
   $41 = (($36) + 1)|0;
   HEAP32[$35>>2] = $41;
  } else {
   (__ZN5physx6shdfnd5ArrayIPNS_2Sc9ActorPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($31,$0)|0);
  }
  $42 = HEAP32[$15>>2]|0;
  $43 = (($42) + 16|0);
  $44 = HEAP16[$43>>1]|0;
  $45 = (($44) + 1)<<16>>16;
  HEAP16[$43>>1] = $45;
  $$pre = HEAP32[$15>>2]|0;
  $51 = $$pre;
 } else {
  $51 = $22;
 }
 $46 = (($9) + 60|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($9) + 64|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($51) + 20|0);
 $52 = HEAP32[$50>>2]|0;
 $53 = ($52|0)==(0|0);
 do {
  if ($53) {
   __ZNK5physx2Sc9ActorPair23createContactReportDataEv($51);
   $$pre$i$i14 = HEAP32[$50>>2]|0;
   $$pre21 = HEAP32[$15>>2]|0;
   $$phi$trans$insert = (($$pre21) + 20|0);
   $$pre22 = HEAP32[$$phi$trans$insert>>2]|0;
   $54 = (($$pre21) + 20|0);
   $55 = ($$pre22|0)==(0|0);
   if ($55) {
    __ZNK5physx2Sc9ActorPair23createContactReportDataEv($$pre21);
    $$pre$i$i$i = HEAP32[$54>>2]|0;
    $60 = (($$pre$i$i$i) + 12|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)!=($47|0);
    $63 = ($$pre$i$i$i|0)==(0|0);
    if ($63) {
     __ZNK5physx2Sc9ActorPair23createContactReportDataEv($$pre21);
     $$pre$i$i = HEAP32[$54>>2]|0;
     $64 = (($$pre$i$i) + 12|0);
     HEAP32[$64>>2] = $47;
     if ($62) {
      $119 = $$pre$i$i14;$66 = $$pre$i$i14;
      label = 17;
      break;
     } else {
      $124 = $$pre$i$i14;$169 = $$pre$i$i14;
      label = 32;
      break;
     }
    } else {
     HEAP32[$60>>2] = $47;
     if ($62) {
      $119 = $$pre$i$i14;$66 = $$pre$i$i14;
      label = 17;
      break;
     } else {
      $124 = $$pre$i$i14;$169 = $$pre$i$i14;
      label = 32;
      break;
     }
    }
   } else {
    $310 = $$pre$i$i14;$311 = $$pre$i$i14;$57 = $$pre22;
    label = 13;
   }
  } else {
   $310 = $52;$311 = $52;$57 = $52;
   label = 13;
  }
 } while(0);
 if ((label|0) == 13) {
  $56 = (($57) + 12|0);
  $58 = HEAP32[$56>>2]|0;
  $59 = ($58|0)==($47|0);
  HEAP32[$56>>2] = $47;
  if ($59) {
   $124 = $311;$169 = $310;
   label = 32;
  } else {
   $119 = $310;$66 = $311;
   label = 17;
  }
 }
 do {
  if ((label|0) == 17) {
   $65 = (($66) + 4|0);
   $67 = HEAP16[$65>>1]|0;
   $68 = ($67<<16>>16)==(0);
   if ($68) {
    HEAP16[$65>>1] = 2;
    $maxCount$0 = 2;
   } else {
    $maxCount$0 = $67;
   }
   $69 = ($14|0)==(0);
   $brmerge = $69 | $touchLost;
   $70 = (($66) + 10|0);
   $71 = HEAP16[$70>>1]|0;
   $72 = $71&65535;
   if ($brmerge) {
    $73 = $72 & 15;
    $74 = $73&65535;
    HEAP16[$70>>1] = $74;
    $maxExtraDataSize$0 = 0;
   } else {
    $75 = $72 & 65520;
    $76 = $13 & 4096;
    $77 = ($76|0)==(0);
    $$$i9 = $77 ? 4 : 56;
    $78 = $13 & 8192;
    $79 = ($78|0)==(0);
    if ($79) {
     $extraDataSize_$1$i10 = $$$i9;
    } else {
     $80 = $$$i9&65535;
     $81 = (($80) + 52)|0;
     $82 = $81&65535;
     $extraDataSize_$1$i10 = $82;
    }
    $83 = $13 & 16384;
    $84 = ($83|0)==(0);
    if ($84) {
     $extraDataSize_$2$i11 = $extraDataSize_$1$i10;
    } else {
     $85 = $extraDataSize_$1$i10&65535;
     $86 = (($85) + 60)|0;
     $87 = $86&65535;
     $extraDataSize_$2$i11 = $87;
    }
    $88 = $extraDataSize_$2$i11&65535;
    $89 = (($88) + 4)|0;
    $90 = $89 & 65535;
    $91 = ($90>>>0)>($75>>>0);
    if ($91) {
     $92 = $89 & 15;
     $not$$i$i = ($92|0)!=(0);
     $93 = $not$$i$i&1;
     $94 = $72 & 15;
     $nbBlocks$0$i1$i = $93 << 4;
     $95 = (($nbBlocks$0$i1$i) + ($89))|0;
     $96 = $95 & 65520;
     $97 = $94 | $96;
     $98 = $97&65535;
     HEAP16[$70>>1] = $98;
     $maxExtraDataSize$0 = $90;
    } else {
     $maxExtraDataSize$0 = $75;
    }
   }
   $99 = $maxCount$0&65535;
   $100 = (__ZN5physx2Sc10NPhaseCore28reserveContactReportPairDataEjjRj($11,$99,$maxExtraDataSize$0,$66)|0);
   $101 = ($maxExtraDataSize$0|0)==(0);
   if ($101) {
    $102 = (($66) + 6|0);
    HEAP16[$102>>1] = 0;
    $103 = (($66) + 8|0);
    HEAP16[$103>>1] = 0;
    $104 = HEAP16[$70>>1]|0;
    $105 = $104&65535;
    $106 = $105 & 65520;
    $107 = $106&65535;
    HEAP16[$70>>1] = $107;
    $182 = $66;$312 = $119;$stream$0 = $100;
    label = 49;
    break;
   }
   $108 = ($100|0)==(0|0);
   if ($108) {
    $191 = $66;
    label = 52;
   } else {
    $109 = (($66) + 6|0);
    HEAP16[$109>>1] = 0;
    $110 = (($66) + 8|0);
    HEAP16[$110>>1] = 0;
    $111 = HEAP16[$70>>1]|0;
    $112 = $111&65535;
    $113 = $112 & 65520;
    $114 = $113&65535;
    HEAP16[$70>>1] = $114;
    $115 = HEAP32[$15>>2]|0;
    $116 = HEAP32[$115>>2]|0;
    $117 = (($115) + 4|0);
    $118 = HEAP32[$117>>2]|0;
    __ZN5physx2Sc20ContactStreamManager28fillInContactReportExtraDataEPhjRKNS0_8RigidSimES5_jjj($119,$100,$14,$116,$118,$ccdPass,0,4);
    $120 = $13 & 10240;
    $121 = ($120|0)==(10240);
    if ($121) {
     $122 = (($9) + 2372|0);
     HEAP8[$122>>0] = 1;
     $182 = $66;$312 = $119;$stream$0 = $100;
     label = 49;
    } else {
     $$pre$phiZ2D = $70;$195 = $66;$205 = $119;$stream$018 = $100;
    }
   }
  }
  else if ((label|0) == 32) {
   $123 = (($124) + 6|0);
   $125 = HEAP16[$123>>1]|0;
   $126 = $125&65535;
   $127 = ($125<<16>>16)==(0);
   if ($127) {
    $191 = $124;
    label = 52;
   } else {
    $128 = (($11) + 44|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = HEAP32[$124>>2]|0;
    $131 = (($129) + ($130)|0);
    $132 = ($14|0)==(0);
    $brmerge8 = $132 | $touchLost;
    if ($brmerge8) {
     $182 = $124;$312 = $169;$stream$0 = $131;
     label = 49;
    } else {
     $133 = (($124) + 8|0);
     $134 = HEAP16[$133>>1]|0;
     $135 = ($134<<16>>16)!=(0);
     if ($135) {
      $136 = HEAP16[$131>>1]|0;
      $137 = $136&65535;
      $lastContactPass$0 = $137;
     } else {
      $lastContactPass$0 = -1;
     }
     $138 = ($lastContactPass$0|0)<($ccdPass|0);
     if ($138) {
      $139 = $134&65535;
      $140 = ($134<<16>>16)==(0);
      $141 = $13 & 4096;
      $142 = ($141|0)==(0);
      $$$i = $142 ? 4 : 56;
      $143 = $13 & 8192;
      $144 = ($143|0)==(0);
      if ($144) {
       $extraDataSize_$1$i = $$$i;
      } else {
       $145 = $$$i&65535;
       $146 = (($145) + 52)|0;
       $147 = $146&65535;
       $extraDataSize_$1$i = $147;
      }
      $148 = $13 & 16384;
      $149 = ($148|0)==(0);
      if ($149) {
       $extraDataSize_$2$i = $extraDataSize_$1$i;
      } else {
       $150 = $extraDataSize_$1$i&65535;
       $151 = (($150) + 60)|0;
       $152 = $151&65535;
       $extraDataSize_$2$i = $152;
      }
      if ($140) {
       $153 = $extraDataSize_$2$i&65535;
       $154 = (($153) + 4)|0;
       $155 = $154&65535;
       $extraDataSize_$3$i = $155;
      } else {
       $extraDataSize_$3$i = $extraDataSize_$2$i;
      }
      $156 = $extraDataSize_$3$i&65535;
      $157 = (($156) + ($139))|0;
      $158 = $157 & 65535;
      $159 = (($124) + 10|0);
      $160 = HEAP16[$159>>1]|0;
      $161 = $160&65535;
      $162 = $161 & 65520;
      $163 = ($158>>>0)>($162>>>0);
      if ($163) {
       $164 = (($124) + 4|0);
       $165 = HEAP16[$164>>1]|0;
       $166 = $165&65535;
       $not$ = ($125&65535)>=($165&65535);
       $167 = $not$&1;
       $168 = (($167) + ($166))|0;
       $170 = (__ZN5physx2Sc10NPhaseCore27resizeContactReportPairDataEjjRNS0_20ContactStreamManagerE($11,$168,$158,$169)|0);
       $strPtr$0 = $170;
      } else {
       $strPtr$0 = $131;
      }
      $171 = ($strPtr$0|0)==(0|0);
      if ($171) {
       $179 = HEAP16[$159>>1]|0;
       $180 = $179 | 4;
       HEAP16[$159>>1] = $180;
       $182 = $124;$312 = $169;$stream$0 = $131;
       label = 49;
       break;
      }
      $$ = $135 ? $139 : 4;
      $172 = HEAP32[$15>>2]|0;
      $173 = HEAP32[$172>>2]|0;
      $174 = (($172) + 4|0);
      $175 = HEAP32[$174>>2]|0;
      __ZN5physx2Sc20ContactStreamManager28fillInContactReportExtraDataEPhjRKNS0_8RigidSimES5_jjj($169,$strPtr$0,$14,$173,$175,$ccdPass,$126,$$);
      $176 = $13 & 10240;
      $177 = ($176|0)==(10240);
      if ($177) {
       $178 = (($9) + 2372|0);
       HEAP8[$178>>0] = 1;
       $182 = $124;$312 = $169;$stream$0 = $strPtr$0;
       label = 49;
      } else {
       $$pre$phiZ2D = $159;$195 = $124;$205 = $169;$stream$018 = $strPtr$0;
      }
     } else {
      $182 = $124;$312 = $169;$stream$0 = $131;
      label = 49;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 49) {
  $181 = ($stream$0|0)==(0|0);
  if ($181) {
   $191 = $182;
   label = 52;
  } else {
   $$pre27 = (($182) + 10|0);
   $$pre$phiZ2D = $$pre27;$195 = $182;$205 = $312;$stream$018 = $stream$0;
  }
 }
 if ((label|0) == 52) {
  $190 = (($191) + 10|0);
  $192 = HEAP16[$190>>1]|0;
  $193 = $192 | 2;
  HEAP16[$190>>1] = $193;
  STACKTOP = sp;return;
 }
 $183 = HEAP16[$$pre$phiZ2D>>1]|0;
 $184 = $183&65535;
 $185 = $184 & 65520;
 $186 = (($stream$018) + ($185)|0);
 $187 = (($this) + 40|0);
 $188 = HEAP32[$187>>2]|0;
 $189 = ($188|0)==($49|0);
 if ($189) {
  $237 = (($this) + 64|0);
  $238 = HEAP16[$237>>1]|0;
  $239 = $238&65535;
  $240 = (($186) + ($239<<5)|0);
  $241 = ((($186) + ($239<<5)|0) + 22|0);
  $242 = HEAP16[$241>>1]|0;
  $243 = $242&65535;
  $244 = $243 | $3;
  $245 = $244&65535;
  HEAP16[$241>>1] = $245;
  $246 = ((($186) + ($239<<5)|0) + 20|0);
  $247 = HEAP16[$246>>1]|0;
  $248 = $247 | $infoFlags;
  HEAP16[$246>>1] = $248;
  $cp$1 = $240;
 } else {
  $194 = (($195) + 6|0);
  $196 = HEAP16[$194>>1]|0;
  $197 = $196&65535;
  $198 = (($195) + 4|0);
  $199 = HEAP16[$198>>1]|0;
  $200 = ($196&65535)<($199&65535);
  do {
   if ($200) {
    $201 = (($186) + ($197<<5)|0);
    $217 = $196;$cp$0 = $201;
   } else {
    $202 = $197 >>> 1;
    $203 = (($197) + 1)|0;
    $204 = (($203) + ($202))|0;
    $206 = (__ZN5physx2Sc10NPhaseCore27resizeContactReportPairDataEjjRNS0_20ContactStreamManagerE($11,$204,$185,$205)|0);
    $207 = ($206|0)==(0|0);
    $208 = HEAP16[$$pre$phiZ2D>>1]|0;
    if (!($207)) {
     $209 = $208&65535;
     $210 = $209 & 65520;
     $211 = (($206) + ($210)|0);
     $212 = HEAP16[$194>>1]|0;
     $213 = $212&65535;
     $214 = (($211) + ($213<<5)|0);
     $217 = $212;$cp$0 = $214;
     break;
    }
    $215 = $208 | 4;
    HEAP16[$$pre$phiZ2D>>1] = $215;
    STACKTOP = sp;return;
   }
  } while(0);
  $216 = (($this) + 64|0);
  HEAP16[$216>>1] = $217;
  $218 = (($$in) + 28|0);
  $219 = HEAP32[$218>>2]|0;
  $220 = (__ZNK5physx2Sc9ShapeCore10getPxShapeEv($219)|0);
  HEAP32[$cp$0>>2] = $220;
  $221 = (($$sink) + 28|0);
  $222 = HEAP32[$221>>2]|0;
  $223 = (__ZNK5physx2Sc9ShapeCore10getPxShapeEv($222)|0);
  $224 = (($cp$0) + 4|0);
  HEAP32[$224>>2] = $223;
  $225 = (($cp$0) + 8|0);
  $226 = (($cp$0) + 20|0);
  ;HEAP32[$225+0>>2]=0|0;HEAP32[$225+4>>2]=0|0;HEAP32[$225+8>>2]=0|0;
  HEAP16[$226>>1] = $infoFlags;
  $227 = $3&65535;
  $228 = (($cp$0) + 22|0);
  HEAP16[$228>>1] = $227;
  $229 = (($$in) + 20|0);
  $230 = HEAP32[$229>>2]|0;
  $231 = (($cp$0) + 24|0);
  HEAP32[$231>>2] = $230;
  $232 = (($$sink) + 20|0);
  $233 = HEAP32[$232>>2]|0;
  $234 = (($cp$0) + 28|0);
  HEAP32[$234>>2] = $233;
  $235 = HEAP16[$194>>1]|0;
  $236 = (($235) + 1)<<16>>16;
  HEAP16[$194>>1] = $236;
  HEAP32[$187>>2] = $49;
  $cp$1 = $cp$0;
 }
 $249 = HEAP32[$12>>2]|0;
 if ($shapeDeleted) {
  $250 = HEAP16[$$pre$phiZ2D>>1]|0;
  $251 = $250 | 1;
  HEAP16[$$pre$phiZ2D>>1] = $251;
 }
 $252 = $249 & 131072;
 $253 = ($252|0)==(0);
 if ($253) {
  STACKTOP = sp;return;
 }
 $254 = HEAP32[$4>>2]|0;
 $255 = ($254|0)==(0|0);
 if ($255) {
  STACKTOP = sp;return;
 }
 $256 = (($cp$1) + 8|0);
 $257 = HEAP32[$256>>2]|0;
 $258 = ($257|0)==(0|0);
 if (!($258)) {
  STACKTOP = sp;return;
 }
 $259 = $3 & 272;
 $260 = ($259|0)==(0);
 if (!($260)) {
  STACKTOP = sp;return;
 }
 $261 = (($254) + 40|0);
 $262 = HEAP32[$261>>2]|0;
 $263 = (($254) + 44|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = (($254) + 48|0);
 $266 = HEAP32[$265>>2]|0;
 $267 = (($254) + 114|0);
 $268 = HEAP16[$267>>1]|0;
 $269 = $268 & 16;
 $270 = ($269<<16>>16)==(0);
 if ($270) {
  $$0$i$i = 0;
 } else {
  $271 = (($266) + 15)|0;
  $272 = $271 & -16;
  $273 = (($264) + ($272)|0);
  $$0$i$i = $273;
 }
 $274 = (($254) + 36|0);
 $275 = HEAP16[$274>>1]|0;
 $276 = $275&65535;
 $277 = ($266|0)==(0);
 $brmerge4 = $277 | $1;
 if ($brmerge4) {
  $278 = ($262|0)==(0|0);
  if ($278) {
   STACKTOP = sp;return;
  }
  $279 = (($262) + 6|0);
  $280 = HEAP16[$279>>1]|0;
  $$not = ($280<<16>>16)!=(0);
  $$not5 = $1 ^ 1;
  $brmerge6 = $$not | $$not5;
  if ($brmerge6) {
   STACKTOP = sp;return;
  }
 }
 if ($1) {
  $283 = (($262) + 8|0);
  $284 = (($262) + 4|0);
  $285 = HEAP16[$284>>1]|0;
  $286 = $285&65535;
  $287 = (($286) + -8)|0;
  $288 = (($286) + 15)|0;
  $289 = $288 & 131056;
  $290 = (($289) + -8)|0;
  $291 = (($262) + ($289)|0);
  $alignedContactDataSize$0 = $290;$cData$0 = $283;$cDataSize$0 = $287;$impulses$0 = $291;$nbPoints$0 = 1;
 } else {
  $281 = (($266) + 15)|0;
  $282 = $281 & -16;
  $alignedContactDataSize$0 = $282;$cData$0 = $264;$cDataSize$0 = $266;$impulses$0 = $$0$i$i;$nbPoints$0 = $276;
 }
 $292 = (($cp$1) + 20|0);
 $293 = HEAP16[$292>>1]|0;
 $294 = $20 ? 0 : 64;
 $295 = $293&65535;
 $296 = $295 | $294;
 $297 = $249 >>> 22;
 $298 = $297 & 16;
 $299 = $296 | $298;
 $300 = ($impulses$0|0)==(0|0);
 $301 = $nbPoints$0 << 2;
 $$7 = $300 ? 0 : $301;
 $302 = ($$7|0)==(0);
 $303 = $299 | 32;
 $$0$in = $302 ? $299 : $303;
 $$0 = $$0$in&65535;
 HEAP32[$256>>2] = $cData$0;
 $304 = $nbPoints$0&65535;
 $305 = (($cp$1) + 16|0);
 HEAP16[$305>>1] = $304;
 $306 = $cDataSize$0&65535;
 $307 = (($cp$1) + 18|0);
 HEAP16[$307>>1] = $306;
 $308 = (($$7) + ($alignedContactDataSize$0))|0;
 $309 = (($cp$1) + 12|0);
 HEAP32[$309>>2] = $308;
 HEAP16[$292>>1] = $$0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc20ContactStreamManager28fillInContactReportExtraDataEPhjRKNS0_8RigidSimES5_jjj($this,$stream,$extraDataFlags,$rs0,$rs1,$ccdPass,$pairIndex,$sizeOffset) {
 $this = $this|0;
 $stream = $stream|0;
 $extraDataFlags = $extraDataFlags|0;
 $rs0 = $rs0|0;
 $rs1 = $rs1|0;
 $ccdPass = $ccdPass|0;
 $pairIndex = $pairIndex|0;
 $sizeOffset = $sizeOffset|0;
 var $$sum = 0, $$sum1 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum30 = 0, $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0;
 var $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum38 = 0, $$sum39 = 0, $$sum40 = 0, $$sum41 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0;
 var $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0;
 var $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0;
 var $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0);
 var $97 = 0, $98 = 0, $99 = Math_fround(0), $edStream$0 = 0, $edStream$1 = 0, $edStream$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $ccdPass&65535;
 HEAP16[$stream>>1] = $0;
 $1 = (($stream) + ($sizeOffset)|0);
 $2 = ($ccdPass|0)!=(0);
 HEAP8[$1>>0] = 3;
 $3 = $pairIndex&65535;
 $$sum = (($sizeOffset) + 2)|0;
 $4 = (($stream) + ($$sum)|0);
 HEAP16[$4>>1] = $3;
 $$sum1 = (($sizeOffset) + 4)|0;
 $5 = (($stream) + ($$sum1)|0);
 $6 = $extraDataFlags & 8192;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   $edStream$0 = $5;
  } else {
   HEAP8[$5>>0] = 1;
   $$sum2 = (($sizeOffset) + 56)|0;
   $8 = (($stream) + ($$sum2)|0);
   if (!($2)) {
    $9 = (($this) + 10|0);
    $10 = HEAP16[$9>>1]|0;
    $11 = $10 | 8;
    HEAP16[$9>>1] = $11;
    $edStream$0 = $8;
    break;
   }
   $12 = (($rs0) + 50|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $$sum36 = (($sizeOffset) + 8)|0;
    $35 = (($stream) + ($$sum36)|0);
    HEAPF32[$35>>2] = Math_fround(0.0);
    $$sum37 = (($sizeOffset) + 12)|0;
    $36 = (($stream) + ($$sum37)|0);
    HEAPF32[$36>>2] = Math_fround(0.0);
    $$sum38 = (($sizeOffset) + 16)|0;
    $37 = (($stream) + ($$sum38)|0);
    HEAPF32[$37>>2] = Math_fround(0.0);
    $$sum39 = (($sizeOffset) + 32)|0;
    $38 = (($stream) + ($$sum39)|0);
    HEAPF32[$38>>2] = Math_fround(0.0);
    $$sum40 = (($sizeOffset) + 36)|0;
    $39 = (($stream) + ($$sum40)|0);
    HEAPF32[$39>>2] = Math_fround(0.0);
    $$sum41 = (($sizeOffset) + 40)|0;
    $40 = (($stream) + ($$sum41)|0);
    HEAPF32[$40>>2] = Math_fround(0.0);
   } else {
    $15 = (($rs0) + 52|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + 80|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $$sum30 = (($sizeOffset) + 8)|0;
    $19 = (($stream) + ($$sum30)|0);
    HEAPF32[$19>>2] = $18;
    $20 = (($16) + 84|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $$sum31 = (($sizeOffset) + 12)|0;
    $22 = (($stream) + ($$sum31)|0);
    HEAPF32[$22>>2] = $21;
    $23 = (($16) + 88|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $$sum32 = (($sizeOffset) + 16)|0;
    $25 = (($stream) + ($$sum32)|0);
    HEAPF32[$25>>2] = $24;
    $26 = (($16) + 96|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $$sum33 = (($sizeOffset) + 32)|0;
    $28 = (($stream) + ($$sum33)|0);
    HEAPF32[$28>>2] = $27;
    $29 = (($16) + 100|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $$sum34 = (($sizeOffset) + 36)|0;
    $31 = (($stream) + ($$sum34)|0);
    HEAPF32[$31>>2] = $30;
    $32 = (($16) + 104|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $$sum35 = (($sizeOffset) + 40)|0;
    $34 = (($stream) + ($$sum35)|0);
    HEAPF32[$34>>2] = $33;
   }
   $41 = (($rs1) + 50|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $$sum24 = (($sizeOffset) + 20)|0;
    $64 = (($stream) + ($$sum24)|0);
    HEAPF32[$64>>2] = Math_fround(0.0);
    $$sum25 = (($sizeOffset) + 24)|0;
    $65 = (($stream) + ($$sum25)|0);
    HEAPF32[$65>>2] = Math_fround(0.0);
    $$sum26 = (($sizeOffset) + 28)|0;
    $66 = (($stream) + ($$sum26)|0);
    HEAPF32[$66>>2] = Math_fround(0.0);
    $$sum27 = (($sizeOffset) + 44)|0;
    $67 = (($stream) + ($$sum27)|0);
    HEAPF32[$67>>2] = Math_fround(0.0);
    $$sum28 = (($sizeOffset) + 48)|0;
    $68 = (($stream) + ($$sum28)|0);
    HEAPF32[$68>>2] = Math_fround(0.0);
    $$sum29 = (($sizeOffset) + 52)|0;
    $69 = (($stream) + ($$sum29)|0);
    HEAPF32[$69>>2] = Math_fround(0.0);
    $edStream$0 = $8;
    break;
   } else {
    $44 = (($rs1) + 52|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($45) + 80|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $$sum18 = (($sizeOffset) + 20)|0;
    $48 = (($stream) + ($$sum18)|0);
    HEAPF32[$48>>2] = $47;
    $49 = (($45) + 84|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $$sum19 = (($sizeOffset) + 24)|0;
    $51 = (($stream) + ($$sum19)|0);
    HEAPF32[$51>>2] = $50;
    $52 = (($45) + 88|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $$sum20 = (($sizeOffset) + 28)|0;
    $54 = (($stream) + ($$sum20)|0);
    HEAPF32[$54>>2] = $53;
    $55 = (($45) + 96|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $$sum21 = (($sizeOffset) + 44)|0;
    $57 = (($stream) + ($$sum21)|0);
    HEAPF32[$57>>2] = $56;
    $58 = (($45) + 100|0);
    $59 = Math_fround(HEAPF32[$58>>2]);
    $$sum22 = (($sizeOffset) + 48)|0;
    $60 = (($stream) + ($$sum22)|0);
    HEAPF32[$60>>2] = $59;
    $61 = (($45) + 104|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $$sum23 = (($sizeOffset) + 52)|0;
    $63 = (($stream) + ($$sum23)|0);
    HEAPF32[$63>>2] = $62;
    $edStream$0 = $8;
    break;
   }
  }
 } while(0);
 $70 = $extraDataFlags & 4096;
 $71 = ($70|0)==(0);
 if ($71) {
  $edStream$1 = $edStream$0;
 } else {
  HEAP8[$edStream$0>>0] = 0;
  $72 = (($rs0) + 50|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = ($73<<24>>24)==(0);
  do {
   if ($74) {
    $113 = (($edStream$0) + 4|0);
    HEAPF32[$113>>2] = Math_fround(0.0);
    $114 = (($edStream$0) + 8|0);
    HEAPF32[$114>>2] = Math_fround(0.0);
    $115 = (($edStream$0) + 12|0);
    HEAPF32[$115>>2] = Math_fround(0.0);
    $116 = (($edStream$0) + 28|0);
    HEAPF32[$116>>2] = Math_fround(0.0);
    $117 = (($edStream$0) + 32|0);
    HEAPF32[$117>>2] = Math_fround(0.0);
    $118 = (($edStream$0) + 36|0);
    HEAPF32[$118>>2] = Math_fround(0.0);
   } else {
    if ($2) {
     $95 = (($rs0) + 64|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $97 = (($edStream$0) + 4|0);
     HEAPF32[$97>>2] = $96;
     $98 = (($rs0) + 68|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     $100 = (($edStream$0) + 8|0);
     HEAPF32[$100>>2] = $99;
     $101 = (($rs0) + 72|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = (($edStream$0) + 12|0);
     HEAPF32[$103>>2] = $102;
     $104 = (($95) + 16|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = (($edStream$0) + 28|0);
     HEAPF32[$106>>2] = $105;
     $107 = (($95) + 20|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     $109 = (($edStream$0) + 32|0);
     HEAPF32[$109>>2] = $108;
     $110 = (($95) + 24|0);
     $111 = Math_fround(HEAPF32[$110>>2]);
     $112 = (($edStream$0) + 36|0);
     HEAPF32[$112>>2] = $111;
     break;
    } else {
     $75 = (($rs0) + 52|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = (($76) + 80|0);
     $78 = Math_fround(HEAPF32[$77>>2]);
     $79 = (($edStream$0) + 4|0);
     HEAPF32[$79>>2] = $78;
     $80 = (($76) + 84|0);
     $81 = Math_fround(HEAPF32[$80>>2]);
     $82 = (($edStream$0) + 8|0);
     HEAPF32[$82>>2] = $81;
     $83 = (($76) + 88|0);
     $84 = Math_fround(HEAPF32[$83>>2]);
     $85 = (($edStream$0) + 12|0);
     HEAPF32[$85>>2] = $84;
     $86 = (($76) + 96|0);
     $87 = Math_fround(HEAPF32[$86>>2]);
     $88 = (($edStream$0) + 28|0);
     HEAPF32[$88>>2] = $87;
     $89 = (($76) + 100|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     $91 = (($edStream$0) + 32|0);
     HEAPF32[$91>>2] = $90;
     $92 = (($76) + 104|0);
     $93 = Math_fround(HEAPF32[$92>>2]);
     $94 = (($edStream$0) + 36|0);
     HEAPF32[$94>>2] = $93;
     break;
    }
   }
  } while(0);
  $119 = (($rs1) + 50|0);
  $120 = HEAP8[$119>>0]|0;
  $121 = ($120<<24>>24)==(0);
  do {
   if ($121) {
    $160 = (($edStream$0) + 16|0);
    HEAPF32[$160>>2] = Math_fround(0.0);
    $161 = (($edStream$0) + 20|0);
    HEAPF32[$161>>2] = Math_fround(0.0);
    $162 = (($edStream$0) + 24|0);
    HEAPF32[$162>>2] = Math_fround(0.0);
    $163 = (($edStream$0) + 40|0);
    HEAPF32[$163>>2] = Math_fround(0.0);
    $164 = (($edStream$0) + 44|0);
    HEAPF32[$164>>2] = Math_fround(0.0);
    $165 = (($edStream$0) + 48|0);
    HEAPF32[$165>>2] = Math_fround(0.0);
   } else {
    if ($2) {
     $142 = (($rs1) + 64|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = (($edStream$0) + 16|0);
     HEAPF32[$144>>2] = $143;
     $145 = (($rs1) + 68|0);
     $146 = Math_fround(HEAPF32[$145>>2]);
     $147 = (($edStream$0) + 20|0);
     HEAPF32[$147>>2] = $146;
     $148 = (($rs1) + 72|0);
     $149 = Math_fround(HEAPF32[$148>>2]);
     $150 = (($edStream$0) + 24|0);
     HEAPF32[$150>>2] = $149;
     $151 = (($142) + 16|0);
     $152 = Math_fround(HEAPF32[$151>>2]);
     $153 = (($edStream$0) + 40|0);
     HEAPF32[$153>>2] = $152;
     $154 = (($142) + 20|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = (($edStream$0) + 44|0);
     HEAPF32[$156>>2] = $155;
     $157 = (($142) + 24|0);
     $158 = Math_fround(HEAPF32[$157>>2]);
     $159 = (($edStream$0) + 48|0);
     HEAPF32[$159>>2] = $158;
     break;
    } else {
     $122 = (($rs1) + 52|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = (($123) + 80|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     $126 = (($edStream$0) + 16|0);
     HEAPF32[$126>>2] = $125;
     $127 = (($123) + 84|0);
     $128 = Math_fround(HEAPF32[$127>>2]);
     $129 = (($edStream$0) + 20|0);
     HEAPF32[$129>>2] = $128;
     $130 = (($123) + 88|0);
     $131 = Math_fround(HEAPF32[$130>>2]);
     $132 = (($edStream$0) + 24|0);
     HEAPF32[$132>>2] = $131;
     $133 = (($123) + 96|0);
     $134 = Math_fround(HEAPF32[$133>>2]);
     $135 = (($edStream$0) + 40|0);
     HEAPF32[$135>>2] = $134;
     $136 = (($123) + 100|0);
     $137 = Math_fround(HEAPF32[$136>>2]);
     $138 = (($edStream$0) + 44|0);
     HEAPF32[$138>>2] = $137;
     $139 = (($123) + 104|0);
     $140 = Math_fround(HEAPF32[$139>>2]);
     $141 = (($edStream$0) + 48|0);
     HEAPF32[$141>>2] = $140;
     break;
    }
   }
  } while(0);
  $166 = (($edStream$0) + 52|0);
  $edStream$1 = $166;
 }
 $167 = $extraDataFlags & 16384;
 $168 = ($167|0)==(0);
 if ($168) {
  $edStream$2 = $edStream$1;
  $170 = $edStream$2;
  $171 = $1;
  $172 = (($sizeOffset) - ($171))|0;
  $173 = (($172) + ($170))|0;
  $174 = $173&65535;
  $175 = (($this) + 8|0);
  HEAP16[$175>>1] = $174;
  STACKTOP = sp;return;
 }
 HEAP8[$edStream$1>>0] = 2;
 __ZN5physx2Sc20ContactStreamManager28fillInContactReportExtraDataEPNS_17PxContactPairPoseEjRKNS0_8RigidSimEb($edStream$1,0,$rs0,$2);
 __ZN5physx2Sc20ContactStreamManager28fillInContactReportExtraDataEPNS_17PxContactPairPoseEjRKNS0_8RigidSimEb($edStream$1,1,$rs1,$2);
 $169 = (($edStream$1) + 60|0);
 $edStream$2 = $169;
 $170 = $edStream$2;
 $171 = $1;
 $172 = (($sizeOffset) - ($171))|0;
 $173 = (($172) + ($170))|0;
 $174 = $173&65535;
 $175 = (($this) + 8|0);
 HEAP16[$175>>1] = $174;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL15managerNewTouchEjb($this,$ccdPass,$adjustCounters) {
 $this = $this|0;
 $ccdPass = $ccdPass|0;
 $adjustCounters = $adjustCounters|0;
 var $$ = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32768;
 $3 = ($2|0)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = $1 & -98305;
 $5 = $4 | 32768;
 HEAP32[$0>>2] = $5;
 if ($adjustCounters) {
  $6 = (($this) + 48|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 14|0);
  $9 = HEAP16[$8>>1]|0;
  $10 = (($9) + 1)<<16>>16;
  HEAP16[$8>>1] = $10;
  $11 = (($this) + 32|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($12)|0);
  $14 = (($this) + 36|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($15)|0);
  $17 = ($13|0)==(0|0);
  if (!($17)) {
   $18 = (($13) + 148|0);
   $19 = HEAP16[$18>>1]|0;
   $20 = (($19) + 1)<<16>>16;
   HEAP16[$18>>1] = $20;
  }
  $21 = ($16|0)==(0|0);
  if ($21) {
   $$pre$phiZ2D = $11;
  } else {
   $22 = (($16) + 148|0);
   $23 = HEAP16[$22>>1]|0;
   $24 = (($23) + 1)<<16>>16;
   HEAP16[$22>>1] = $24;
   $$pre$phiZ2D = $11;
  }
 } else {
  $$pre = (($this) + 32|0);
  $$pre$phiZ2D = $$pre;
 }
 $25 = HEAP32[$$pre$phiZ2D>>2]|0;
 $26 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($25)|0);
 $27 = (($26) + 1212|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($28)|0);
 $30 = (($this) + 60|0);
 __ZN5physx16PxsIslandManager16setEdgeConnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($29,$30);
 $31 = HEAP32[$0>>2]|0;
 $32 = $31 & 476;
 $33 = ($32|0)==(0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = $31 & 4;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($this) + 48|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 14|0);
  $39 = HEAP16[$38>>1]|0;
  $40 = ($39<<16>>16)==(1);
  $$ = $40 ? 4 : 0;
  __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($this,4,$$,0,0,$ccdPass);
 }
 $41 = $31 & 8;
 $42 = ($41|0)==(0);
 if (!($42)) {
  $43 = HEAP32[$$pre$phiZ2D>>2]|0;
  $44 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($43)|0);
  $45 = (($44) + 1088|0);
  $46 = HEAP32[$45>>2]|0;
  __ZN5physx2Sc10NPhaseCore39addToPersistentContactEventPairsDelayedEPNS0_19ShapeInstancePairLLE($46,$this);
  STACKTOP = sp;return;
 }
 $47 = $31 & 448;
 $48 = ($47|0)==(0);
 if ($48) {
  STACKTOP = sp;return;
 }
 $49 = HEAP32[$$pre$phiZ2D>>2]|0;
 $50 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($49)|0);
 $51 = (($50) + 1088|0);
 $52 = HEAP32[$51>>2]|0;
 __ZN5physx2Sc10NPhaseCore36addToForceThresholdContactEventPairsEPNS0_19ShapeInstancePairLLE($52,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL16managerLostTouchEjb($this,$ccdPass,$adjustCounters) {
 $this = $this|0;
 $ccdPass = $ccdPass|0;
 $adjustCounters = $adjustCounters|0;
 var $$$i = 0, $$0 = 0, $$not = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $storemerge = 0, $storemerge$in = 0, $storemerge$in$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32768;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($5)|0);
 $7 = (($6) + 1212|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($8)|0);
 $10 = (($this) + 60|0);
 __ZN5physx16PxsIslandManager18setEdgeUnconnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($9,$10);
 $11 = HEAP32[$0>>2]|0;
 $12 = $11 & 476;
 $13 = ($12|0)==(0);
 if ($13) {
  $storemerge$in$in = $11;
 } else {
  $14 = $11 >>> 11;
  $15 = $14 & 256;
  $16 = $15 | 16;
  $17 = $16 & $11;
  $18 = ($17|0)==(0);
  if ($18) {
   $25 = $11;
  } else {
   $19 = (($this) + 48|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 14|0);
   $22 = HEAP16[$21>>1]|0;
   $23 = ($22<<16>>16)==(1);
   $$$i = $23 ? 8 : 0;
   __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($this,$17,$$$i,0,1,$ccdPass);
   $$pre = HEAP32[$0>>2]|0;
   $25 = $$pre;
  }
  $24 = $25 & 10485760;
  $26 = ($24|0)==(0);
  if ($26) {
   $storemerge$in$in = $25;
  } else {
   $27 = $25 & 8388608;
   $28 = ($27|0)==(0);
   $29 = HEAP32[$4>>2]|0;
   $30 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($29)|0);
   $31 = (($30) + 1088|0);
   $32 = HEAP32[$31>>2]|0;
   if ($28) {
    __ZN5physx2Sc10NPhaseCore37removeFromPersistentContactEventPairsEPNS0_19ShapeInstancePairLLE($32,$this);
   } else {
    __ZN5physx2Sc10NPhaseCore41removeFromForceThresholdContactEventPairsEPNS0_19ShapeInstancePairLLE($32,$this);
   }
   $33 = HEAP32[$0>>2]|0;
   $34 = $33 & -1572865;
   HEAP32[$0>>2] = $34;
   $storemerge$in$in = $34;
  }
 }
 $storemerge$in = $storemerge$in$in & -98305;
 $storemerge = $storemerge$in | 65536;
 HEAP32[$0>>2] = $storemerge;
 if ($adjustCounters) {
  $35 = (($this) + 48|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 14|0);
  $38 = HEAP16[$37>>1]|0;
  $39 = (($38) + -1)<<16>>16;
  HEAP16[$37>>1] = $39;
  $40 = HEAP32[$4>>2]|0;
  $41 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($40)|0);
  $42 = (($this) + 36|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($43)|0);
  $45 = ($41|0)==(0|0);
  if (!($45)) {
   $46 = (($41) + 148|0);
   $47 = HEAP16[$46>>1]|0;
   $48 = (($47) + -1)<<16>>16;
   HEAP16[$46>>1] = $48;
  }
  $49 = ($44|0)==(0|0);
  if ($49) {
   $$pre$phiZ2D = $42;
  } else {
   $50 = (($44) + 148|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = (($51) + -1)<<16>>16;
   HEAP16[$50>>1] = $52;
   $$pre$phiZ2D = $42;
  }
 } else {
  $$pre1 = (($this) + 36|0);
  $$pre$phiZ2D = $$pre1;
 }
 $53 = HEAP32[$4>>2]|0;
 $54 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($53)|0);
 $55 = HEAP32[$$pre$phiZ2D>>2]|0;
 $56 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($55)|0);
 $57 = ($54|0)!=(0|0);
 $$not = $57 ^ 1;
 $58 = ($56|0)==(0|0);
 $or$cond = $58 | $$not;
 if (!($or$cond)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($57) {
  __ZN5physx2Sc7BodySim14internalWakeUpEf($54,Math_fround(0.399999976158142089844));
 }
 if ($58) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx2Sc7BodySim14internalWakeUpEf($56,Math_fround(0.399999976158142089844));
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc19ShapeInstancePairLL11updateStateEv($this) {
 $this = $this|0;
 var $$off = 0, $$off9 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0;
 var $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cdom = 0, $or$cond = 0, $phitmp = 0, $storemerge = 0, $switch = 0;
 var $switch10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $cdom = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = (($this) + 6|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 & 2;
 $7 = ($6<<16>>16)==(0);
 if (!($7)) {
  __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($this);
  $8 = HEAP16[$4>>1]|0;
  $9 = $8&65535;
  $10 = $9 & 65533;
  $11 = $10&65535;
  HEAP16[$4>>1] = $11;
 }
 HEAP16[$2>>1] = 0;
 $12 = (($this) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($13)|0);
 $15 = (($14) + 1212|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $3 & 33;
 $18 = ($17<<16>>16)==(0);
 do {
  if (!($18)) {
   $19 = HEAP32[$0>>2]|0;
   $20 = HEAP32[$12>>2]|0;
   $21 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($20)|0);
   $22 = (($this) + 36|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($23)|0);
   $25 = ($21|0)==(0|0);
   if ($25) {
    label = 6;
   } else {
    $26 = (($21) + 52|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 44|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if ($31) {
     label = 8;
    } else {
     label = 6;
    }
   }
   if ((label|0) == 6) {
    $32 = ($24|0)==(0|0);
    if ($32) {
     label = 9;
    } else {
     $33 = (($24) + 52|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 44|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = $36 & 1;
     $38 = ($37<<24>>24)==(0);
     if ($38) {
      label = 8;
     } else {
      label = 9;
     }
    }
   }
   if ((label|0) == 8) {
    $39 = $19 & 1;
    $phitmp = ($39|0)==(0);
    if ($phitmp) {
     label = 9;
    } else {
     $42 = HEAP32[$0>>2]|0;
     $43 = $42 & -262145;
     $storemerge = $43;
    }
   }
   if ((label|0) == 9) {
    $40 = HEAP32[$0>>2]|0;
    $41 = $40 | 262144;
    $storemerge = $41;
   }
   HEAP32[$0>>2] = $storemerge;
   $44 = $19 & 514;
   $45 = ($44|0)==(0);
   if ($45) {
    $46 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($14,7)));
    $47 = $46 != Math_fround(0.0);
    if (!($47)) {
     $48 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($14,8)));
     $49 = $48 != Math_fround(0.0);
     if (!($49)) {
      $50 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($14,9)));
      $51 = $50 != Math_fround(0.0);
      if (!($51)) {
       $52 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($14,10)));
       $53 = $52 != Math_fround(0.0);
       if (!($53)) {
        $56 = HEAP32[$0>>2]|0;
        $57 = $56 & -131073;
        HEAP32[$0>>2] = $57;
        break;
       }
      }
     }
    }
   }
   $54 = HEAP32[$0>>2]|0;
   $55 = $54 | 131072;
   HEAP32[$0>>2] = $55;
  }
 } while(0);
 $58 = $3&65535;
 $59 = $58 & 5;
 $60 = ($59|0)==(5);
 do {
  if ($60) {
   $61 = HEAP32[$12>>2]|0;
   $62 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($61)|0);
   $63 = (($this) + 36|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($64)|0);
   $66 = ($62|0)==(0|0);
   if ($66) {
    label = 23;
   } else {
    $67 = (($62) + 52|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($68) + 44|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = $70 & 1;
    $72 = ($71<<24>>24)==(0);
    if ($72) {
     label = 23;
    } else {
     $73 = HEAP32[$0>>2]|0;
     $74 = $73 | 16777216;
     $77 = $74;
    }
   }
   if ((label|0) == 23) {
    $75 = HEAP32[$0>>2]|0;
    $76 = $75 & -16777217;
    $77 = $76;
   }
   HEAP32[$0>>2] = $77;
   $78 = ($65|0)==(0|0);
   if (!($78)) {
    $79 = (($65) + 52|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($80) + 44|0);
    $82 = HEAP8[$81>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if (!($84)) {
     $85 = $77 | 33554432;
     HEAP32[$0>>2] = $85;
     $88 = $85;
     break;
    }
   }
   $86 = $77 & -33554433;
   HEAP32[$0>>2] = $86;
   $88 = $86;
  } else {
   $$pre = HEAP32[$0>>2]|0;
   $88 = $$pre;
  }
 } while(0);
 $87 = $88 & 476;
 $89 = ($87|0)==(0);
 L39: do {
  if ($89) {
   $120 = $88;
  } else {
   $90 = (($this) + 52|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(-1);
   if ($92) {
    $93 = HEAP32[$15>>2]|0;
    $94 = (($this) + 8|0);
    $95 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($93,$94)|0);
    if ($95) {
     $96 = HEAP32[$0>>2]|0;
     $97 = $96 & 32768;
     $98 = ($97|0)==(0);
     $99 = $96 & 448;
     $100 = ($99|0)==(0);
     $or$cond = $98 | $100;
     if (!($or$cond)) {
      $101 = (($14) + 1088|0);
      $102 = HEAP32[$101>>2]|0;
      __ZN5physx2Sc10NPhaseCore36addToForceThresholdContactEventPairsEPNS0_19ShapeInstancePairLLE($102,$this);
     }
    }
   }
   $103 = HEAP32[$0>>2]|0;
   $104 = $103 & 512;
   $105 = ($104|0)==(0);
   do {
    if (!($105)) {
     $106 = HEAP32[$12>>2]|0;
     $107 = (($106) + 28|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = (($108) + 68|0);
     $110 = HEAP32[$109>>2]|0;
     $$off = (($110) + -5)|0;
     $switch = ($$off>>>0)<(2);
     if (!($switch)) {
      $111 = (($this) + 36|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = (($112) + 28|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = (($114) + 68|0);
      $116 = HEAP32[$115>>2]|0;
      $$off9 = (($116) + -5)|0;
      $switch10 = ($$off9>>>0)<(2);
      if (!($switch10)) {
       break;
      }
     }
     $117 = $103 | 67108864;
     HEAP32[$0>>2] = $117;
     $120 = $117;
     break L39;
    }
   } while(0);
   $118 = $103 & -67108865;
   HEAP32[$0>>2] = $118;
   $120 = $118;
  }
 } while(0);
 $119 = $120 ^ $1;
 $121 = $119 & 393694;
 $122 = ($121|0)==(0);
 do {
  if ($122) {
   $123 = (($this) + 56|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)==(0|0);
   if ($125) {
    label = 53;
   } else {
    $126 = HEAP32[$12>>2]|0;
    $127 = (($this) + 36|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = $58 & 8;
    $130 = ($129|0)==(0);
    if ($130) {
     $165 = $124;
    } else {
     $131 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($126)|0);
     $132 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($128)|0);
     $133 = ($131|0)==(0|0);
     if ($133) {
      $145 = 0;
     } else {
      $134 = (($131) + 52|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = (($135) + 12|0);
      $137 = HEAP8[$136>>0]|0;
      $145 = $137;
     }
     $138 = ($132|0)==(0|0);
     if ($138) {
      $146 = 0;
     } else {
      $139 = (($132) + 52|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = (($140) + 12|0);
      $142 = HEAP8[$141>>0]|0;
      $146 = $142;
     }
     $143 = HEAP32[$12>>2]|0;
     $144 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($143)|0);
     __ZNK5physx2Sc5Scene21getDominanceGroupPairEhh($cdom,$144,$145,$146);
     $147 = HEAP32[$123>>2]|0;
     $148 = Math_fround(HEAPF32[$cdom>>2]);
     $149 = (($147) + 100|0);
     HEAPF32[$149>>2] = $148;
     $150 = (($cdom) + 4|0);
     $151 = Math_fround(HEAPF32[$150>>2]);
     $152 = (($147) + 104|0);
     HEAPF32[$152>>2] = $151;
     $165 = $147;
    }
    $153 = $58 & 16;
    $154 = ($153|0)==(0);
    if (!($154)) {
     $155 = (($126) + 28|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = (($156) + 128|0);
     $158 = Math_fround(HEAPF32[$157>>2]);
     $159 = (($128) + 28|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = (($160) + 128|0);
     $162 = Math_fround(HEAPF32[$161>>2]);
     $163 = Math_fround($158 + $162);
     $164 = (($165) + 108|0);
     HEAPF32[$164>>2] = $163;
    }
    $166 = HEAP32[$12>>2]|0;
    $167 = (($166) + 8|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = (($168) + 51|0);
    $170 = HEAP8[$169>>0]|0;
    $171 = $170 & 1;
    $172 = ($171<<24>>24)==(0);
    if ($172) {
     $173 = HEAP32[$127>>2]|0;
     $174 = (($173) + 8|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = (($175) + 51|0);
     $177 = HEAP8[$176>>0]|0;
     $178 = $177 & 1;
     $179 = ($178<<24>>24)==(0);
     if ($179) {
      $180 = HEAP32[$0>>2]|0;
      $181 = $180 | 134217728;
      HEAP32[$0>>2] = $181;
      break;
     }
    }
    $182 = HEAP32[$0>>2]|0;
    $183 = $182 & -134217729;
    HEAP32[$0>>2] = $183;
    $184 = ($165|0)==(0|0);
    if ($184) {
     __ZN5physx2Sc19ShapeInstancePairLL13createManagerEv($this);
    }
   }
  } else {
   label = 53;
  }
 } while(0);
 do {
  if ((label|0) == 53) {
   $185 = (($this) + 8|0);
   $186 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($16,$185)|0);
   if ($186) {
    __ZN5physx2Sc19ShapeInstancePairLL14destroyManagerEv($this);
    $187 = HEAP32[$12>>2]|0;
    $188 = (($187) + 8|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = (($189) + 51|0);
    $191 = HEAP8[$190>>0]|0;
    $192 = $191 & 1;
    $193 = ($192<<24>>24)==(0);
    if ($193) {
     $194 = (($this) + 36|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = (($195) + 8|0);
     $197 = HEAP32[$196>>2]|0;
     $198 = (($197) + 51|0);
     $199 = HEAP8[$198>>0]|0;
     $200 = $199 & 1;
     $201 = ($200<<24>>24)==(0);
     if ($201) {
      $202 = HEAP32[$0>>2]|0;
      $203 = $202 | 134217728;
      HEAP32[$0>>2] = $203;
      break;
     }
    }
    $204 = HEAP32[$0>>2]|0;
    $205 = $204 & -134217729;
    HEAP32[$0>>2] = $205;
    __ZN5physx2Sc19ShapeInstancePairLL13createManagerEv($this);
   }
  }
 } while(0);
 $206 = (($this) + 56|0);
 $207 = HEAP32[$206>>2]|0;
 $208 = ($207|0)==(0|0);
 if ($208) {
  STACKTOP = sp;return;
 }
 $209 = HEAP32[$0>>2]|0;
 $210 = $209 & 2048;
 $211 = ($210|0)!=(0);
 __ZN5physx17PxsContactManager6setCCDEb($207,$211);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL10initializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($3)|0);
 $5 = (($4) + 1212|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($6)|0);
 $8 = HEAP32[$2>>2]|0;
 $9 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($8)|0);
 $10 = (($this) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($11)|0);
 $13 = ($9|0)==(0|0);
 if ($13) {
  $65 = 0;
 } else {
  $14 = (($9) + 50|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15&255;
  $65 = $16;
 }
 $17 = ($12|0)==(0|0);
 if ($17) {
  $66 = 0;
 } else {
  $18 = (($12) + 50|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19&255;
  $66 = $20;
 }
 if ((($65|0) == 1) | (($65|0) == 4)) {
  $21 = (($9) + 188|0);
  $22 = HEAP32[$21>>2]|0;
  $25 = $22;
 } else {
  $25 = -1;
 }
 if ((($66|0) == 1) | (($66|0) == 4)) {
  $23 = (($12) + 188|0);
  $24 = HEAP32[$23>>2]|0;
  $26 = $24;
 } else {
  $26 = -1;
 }
 HEAP32[$0>>2] = $25;
 HEAP32[$1>>2] = $26;
 $27 = (($this) + 60|0);
 __ZN5physx16PxsIslandManager7addEdgeENS0_9eEdgeTypeENS_20PxsIslandManagerHookIjLj4294967295EEES3_RS3_($7,0,$0,$1,$27);
 $28 = HEAP32[$2>>2]|0;
 $29 = (($28) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 51|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32 & 1;
 $34 = ($33<<24>>24)==(0);
 if ($34) {
  $35 = HEAP32[$10>>2]|0;
  $36 = (($35) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 51|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $45 = (($this) + 44|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = $46 | 134217728;
   HEAP32[$45>>2] = $47;
   __ZN5physx16PxsIslandManager16setEdgeConnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($7,$27);
  } else {
   label = 11;
  }
 } else {
  label = 11;
 }
 if ((label|0) == 11) {
  $42 = (($this) + 44|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = $43 & -134217729;
  HEAP32[$42>>2] = $44;
 }
 $48 = (($this) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 16|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (FUNCTION_TABLE_iii[$51 & 4095]($48,0)|0);
 $53 = (($this) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 36|0);
 $56 = HEAP32[$55>>2]|0;
 __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($56,$48,$52);
 $57 = HEAP32[$53>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($57,$48);
 $58 = (($this) + 16|0);
 $59 = HEAP32[$58>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($59,$48);
 $60 = (($this) + 48|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($61) + 16|0);
 $63 = HEAP16[$62>>1]|0;
 $64 = (($63) + 1)<<16>>16;
 HEAP16[$62>>1] = $64;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc19ShapeInstancePairLL10initializeEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 __ZN5physx2Sc19ShapeInstancePairLL10initializeEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL7destroyEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc19ShapeInstancePairLL14destroyManagerEv($this);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($1)|0);
 $3 = (($2) + 1212|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($4)|0);
 $6 = (($this) + 60|0);
 __ZN5physx16PxsIslandManager10removeEdgeENS0_9eEdgeTypeERNS_20PxsIslandManagerHookIjLj4294967295EEE($5,0,$6);
 $7 = (($this) + 8|0);
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($9,$7);
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($11,$7);
 $12 = HEAP32[$8>>2]|0;
 $13 = (($12) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($14,$7);
 $15 = (($this) + 52|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 do {
  if ($17) {
   $$pre = (($this) + 44|0);
   $$pre$phiZ2D = $$pre;
  } else {
   $18 = HEAP32[$0>>2]|0;
   $19 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($18)|0);
   $20 = (($this) + 44|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $21 & 8388608;
   $23 = ($22|0)==(0);
   $24 = (($19) + 1088|0);
   $25 = HEAP32[$24>>2]|0;
   if ($23) {
    __ZN5physx2Sc10NPhaseCore37removeFromPersistentContactEventPairsEPNS0_19ShapeInstancePairLLE($25,$this);
    $$pre$phiZ2D = $20;
    break;
   } else {
    __ZN5physx2Sc10NPhaseCore41removeFromForceThresholdContactEventPairsEPNS0_19ShapeInstancePairLLE($25,$this);
    $$pre$phiZ2D = $20;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$$pre$phiZ2D>>2]|0;
 $27 = $26 & 32768;
 $28 = ($27|0)==(0);
 if ($28) {
  $$pre1 = (($this) + 48|0);
  $$pre$phi2Z2D = $$pre1;
  $47 = HEAP32[$$pre$phi2Z2D>>2]|0;
  $48 = (($47) + 16|0);
  $49 = HEAP16[$48>>1]|0;
  $50 = (($49) + -1)<<16>>16;
  HEAP16[$48>>1] = $50;
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$0>>2]|0;
 $30 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($29)|0);
 $31 = (($this) + 36|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($32)|0);
 $34 = ($30|0)==(0|0);
 if (!($34)) {
  $35 = (($30) + 148|0);
  $36 = HEAP16[$35>>1]|0;
  $37 = (($36) + -1)<<16>>16;
  HEAP16[$35>>1] = $37;
 }
 $38 = ($33|0)==(0|0);
 if (!($38)) {
  $39 = (($33) + 148|0);
  $40 = HEAP16[$39>>1]|0;
  $41 = (($40) + -1)<<16>>16;
  HEAP16[$39>>1] = $41;
 }
 $42 = (($this) + 48|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 14|0);
 $45 = HEAP16[$44>>1]|0;
 $46 = (($45) + -1)<<16>>16;
 HEAP16[$44>>1] = $46;
 $$pre$phi2Z2D = $42;
 $47 = HEAP32[$$pre$phi2Z2D>>2]|0;
 $48 = (($47) + 16|0);
 $49 = HEAP16[$48>>1]|0;
 $50 = (($49) + -1)<<16>>16;
 HEAP16[$48>>1] = $50;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL14destroyManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($4)|0);
 $6 = (($5) + 1212|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($7)|0);
 $9 = (($this) + 60|0);
 __ZN5physx16PxsIslandManager16clearEdgeRigidCMERKNS_20PxsIslandManagerHookIjLj4294967295EEE($8,$9);
 $10 = (($7) + 1000|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 __ZN5physx10PxsContext21destroyContactManagerEPNS_17PxsContactManagerE($11,$12);
 HEAP32[$0>>2] = 0;
 $13 = HEAP32[$3>>2]|0;
 $14 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($13)|0);
 $15 = (($14) + 1212|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1000|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 7384|0);
 $20 = HEAP32[$3>>2]|0;
 __ZN5physx2Sc8ShapeSim21destroyTransformCacheERNS_17PxsTransformCacheE($20,$19);
 $21 = (($this) + 36|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx2Sc8ShapeSim21destroyTransformCacheERNS_17PxsTransformCacheE($22,$19);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc19ShapeInstancePairLL7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 __ZN5physx2Sc19ShapeInstancePairLL7destroyEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL10onActivateEj($this,$infoFlag) {
 $this = $this|0;
 $infoFlag = $infoFlag|0;
 var $$0 = 0, $$pre = 0, $$pre$i = 0, $$pre2 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 476;
 $3 = ($2|0)==(0);
 if ($3) {
  $32 = $1;
 } else {
  $4 = $infoFlag & 2;
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = $1 & 4194304;
   $7 = ($6|0)==(0);
   if ($7) {
    $32 = $1;
   } else {
    $8 = (($this) + 32|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($9)|0);
    $11 = (($10) + 1088|0);
    $12 = HEAP32[$11>>2]|0;
    __ZN5physx2Sc10NPhaseCore32addToPersistentContactEventPairsEPNS0_19ShapeInstancePairLLE($12,$this);
    $13 = HEAP32[$0>>2]|0;
    $14 = $13 & -4194305;
    HEAP32[$0>>2] = $14;
    $32 = $14;
   }
  } else {
   $32 = $1;
  }
 }
 $15 = (($this) + 32|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 51|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $23 = (($this) + 36|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 51|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $31 = $32 | 134217728;
   HEAP32[$0>>2] = $31;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $33 = $32 & -134217729;
 HEAP32[$0>>2] = $33;
 $34 = (($this) + 56|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 do {
  if ($36) {
   __ZN5physx2Sc19ShapeInstancePairLL13createManagerEv($this);
   $$pre$i = HEAP32[$34>>2]|0;
   $37 = ($$pre$i|0)==(0|0);
   if ($37) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$pre3 = HEAP32[$0>>2]|0;
    $39 = $$pre3;$51 = $$pre$i;
    break;
   }
  } else {
   $39 = $33;$51 = $35;
  }
 } while(0);
 $38 = $39 & 32768;
 $40 = ($38|0)==(0);
 if ($40) {
  $41 = HEAP32[$15>>2]|0;
  $42 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($41)|0);
  $43 = (($42) + 1212|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($44)|0);
  $46 = (($this) + 60|0);
  __ZN5physx16PxsIslandManager18setEdgeUnconnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($45,$46);
  $$pre = HEAP32[$34>>2]|0;
  $$pre2 = HEAP32[$0>>2]|0;
  $48 = $$pre2;$50 = $$pre;
 } else {
  $48 = $39;$50 = $51;
 }
 $47 = $48 & 2048;
 $49 = ($47|0)!=(0);
 __ZN5physx17PxsContactManager6setCCDEb($50,$49);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZThn8_N5physx2Sc19ShapeInstancePairLL10onActivateEj($this,$infoFlag) {
 $this = $this|0;
 $infoFlag = $infoFlag|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (__ZN5physx2Sc19ShapeInstancePairLL10onActivateEj($0,$infoFlag)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc19ShapeInstancePairLL12onDeactivateEj($this,$infoFlag) {
 $this = $this|0;
 $infoFlag = $infoFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = $infoFlag & 4;
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   $38 = (($this) + 52|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(-1);
   if (!($40)) {
    $41 = (($this) + 44|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42 << 1;
    $44 = $43 & 4194304;
    $45 = $44 | $42;
    HEAP32[$41>>2] = $45;
    $46 = (($this) + 32|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($47)|0);
    $49 = HEAP32[$41>>2]|0;
    $50 = $49 & 8388608;
    $51 = ($50|0)==(0);
    $52 = (($48) + 1088|0);
    $53 = HEAP32[$52>>2]|0;
    if ($51) {
     __ZN5physx2Sc10NPhaseCore37removeFromPersistentContactEventPairsEPNS0_19ShapeInstancePairLLE($53,$this);
     break;
    } else {
     __ZN5physx2Sc10NPhaseCore41removeFromForceThresholdContactEventPairsEPNS0_19ShapeInstancePairLLE($53,$this);
     break;
    }
   }
  } else {
   $2 = (($this) + 56|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($3) + 114|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = $5 & 2;
   $7 = ($6<<16>>16)!=(0);
   $8 = (($this) + 44|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 & 32768;
   $11 = ($10|0)!=(0);
   $12 = $7 ^ $11;
   if (!($12)) {
    $24 = (($this) + 52|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(-1);
    if ($26) {
     break;
    }
    $27 = $9 << 1;
    $28 = $27 & 4194304;
    $29 = $28 | $9;
    HEAP32[$8>>2] = $29;
    $30 = (($this) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($31)|0);
    $33 = HEAP32[$8>>2]|0;
    $34 = $33 & 8388608;
    $35 = ($34|0)==(0);
    $36 = (($32) + 1088|0);
    $37 = HEAP32[$36>>2]|0;
    if ($35) {
     __ZN5physx2Sc10NPhaseCore37removeFromPersistentContactEventPairsEPNS0_19ShapeInstancePairLLE($37,$this);
     break;
    } else {
     __ZN5physx2Sc10NPhaseCore41removeFromForceThresholdContactEventPairsEPNS0_19ShapeInstancePairLLE($37,$this);
     break;
    }
   }
   if ($7) {
    $13 = $9 & -98305;
    $14 = $13 | 32768;
    HEAP32[$8>>2] = $14;
    $15 = $9 & 456;
    $16 = ($15|0)==(0);
    if ($16) {
     break;
    }
    $17 = $13 | 4227072;
    HEAP32[$8>>2] = $17;
    break;
   }
   $18 = $9 & 456;
   $19 = ($18|0)==(0);
   if ($19) {
    $22 = $9;
   } else {
    $20 = $9 & -4194305;
    HEAP32[$8>>2] = $20;
    $22 = $20;
   }
   $21 = $22 & -98305;
   $23 = $21 | 65536;
   HEAP32[$8>>2] = $23;
  }
 } while(0);
 $54 = (($this) + 56|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = (($this) + 44|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = $58 & 98304;
  $60 = ($59|0)==(0);
  if ($60) {
   $61 = (($55) + 114|0);
   $62 = HEAP16[$61>>1]|0;
   $63 = $62&65535;
   $64 = $63 & 3;
   $65 = ($64|0)!=(0);
   $66 = $63 & 2;
   $67 = ($66|0)==(0);
   $or$cond = $65 & $67;
   if ($or$cond) {
    $68 = $58 | 65536;
    HEAP32[$57>>2] = $68;
   }
  }
  __ZN5physx2Sc19ShapeInstancePairLL14destroyManagerEv($this);
 }
 $69 = $infoFlag & 6;
 $70 = ($69|0)==(0);
 if (!($70)) {
  STACKTOP = sp;return 1;
 }
 $71 = (($this) + 32|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($72)|0);
 $74 = (($73) + 1212|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($75)|0);
 $77 = (($this) + 60|0);
 __ZN5physx16PxsIslandManager16setEdgeConnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($76,$77);
 STACKTOP = sp;return 1;
}
function __ZThn8_N5physx2Sc19ShapeInstancePairLL12onDeactivateEj($this,$infoFlag) {
 $this = $this|0;
 $infoFlag = $infoFlag|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 (__ZN5physx2Sc19ShapeInstancePairLL12onDeactivateEj($0,$infoFlag)|0);
 STACKTOP = sp;return 1;
}
function __ZN5physx2Sc19ShapeInstancePairLL13createManagerEv($this) {
 $this = $this|0;
 var $$2 = 0, $$lobit = 0, $$lobit1 = 0, $$lobit3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cdom = 0, $managerDesc = 0, $touching$0 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $cdom = sp + 80|0;
 $managerDesc = sp;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($1)|0);
 $3 = (($2) + 1120|0);
 $4 = HEAP32[$0>>2]|0;
 $5 = (($this) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 50|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = (($6) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 50|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = (($this) + 44|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 262144;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = $16 >>> 10;
  $$lobit = $19 & 1;
  $20 = $$lobit ^ 1;
  $21 = $16 >>> 11;
  $$lobit1 = $21 & 1;
  $22 = $$lobit1 ^ 1;
  $30 = $20;$82 = $22;
 } else {
  $30 = 1;$82 = 1;
 }
 $23 = $16 & 512;
 $24 = ($23|0)==(0);
 if ($24) {
  $25 = $16 & 131072;
  $26 = ($25|0)!=(0);
  $28 = $26;
 } else {
  $28 = 1;
 }
 $27 = $28&1;
 $29 = ($30|0)==(0);
 if ($29) {
  $31 = $16 & 448;
  $32 = ($31|0)!=(0);
  $34 = $32;
 } else {
  $34 = 0;
 }
 $33 = $34&1;
 $35 = $16 & 98304;
 $36 = ($35|0)==(0);
 if ($36) {
  $touching$0 = 0;
 } else {
  $37 = $16 >>> 14;
  $38 = $37 & 2;
  $39 = (($38) + -1)|0;
  $touching$0 = $39;
 }
 $40 = $16 >>> 1;
 $$lobit3 = $40 & 1;
 $41 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($4)|0);
 $42 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($6)|0);
 $43 = ($41|0)!=(0|0);
 if ($43) {
  $44 = (($41) + 52|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 12|0);
  $47 = HEAP8[$46>>0]|0;
  $53 = $47;
 } else {
  $53 = 0;
 }
 $48 = ($42|0)!=(0|0);
 if ($48) {
  $49 = (($42) + 52|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + 12|0);
  $52 = HEAP8[$51>>0]|0;
  $54 = $52;
 } else {
  $54 = 0;
 }
 __ZNK5physx2Sc5Scene21getDominanceGroupPairEhh($cdom,$2,$53,$54);
 $55 = (($2) + 1212|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 1000|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + 7384|0);
 __ZN5physx2Sc8ShapeSim20createTransformCacheERNS_17PxsTransformCacheE($4,$59);
 __ZN5physx2Sc8ShapeSim20createTransformCacheERNS_17PxsTransformCacheE($6,$59);
 dest=$managerDesc+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $60 = (($managerDesc) + 4|0);
 HEAPF32[$60>>2] = Math_fround(1.0);
 $61 = (($managerDesc) + 8|0);
 HEAPF32[$61>>2] = Math_fround(1.0);
 $62 = (($4) + 28|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 128|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($6) + 28|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 128|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($65 + $69);
 $71 = (($managerDesc) + 48|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($41) + 64|0);
 $$2 = $43 ? $72 : 0;
 $73 = (($managerDesc) + 12|0);
 HEAP32[$73>>2] = $$2;
 $74 = (($42) + 64|0);
 $75 = $48 ? $74 : 0;
 $76 = (($managerDesc) + 16|0);
 HEAP32[$76>>2] = $75;
 $77 = (($managerDesc) + 36|0);
 HEAP32[$77>>2] = $27;
 $78 = (($managerDesc) + 40|0);
 HEAP32[$78>>2] = $33;
 $79 = (($managerDesc) + 44|0);
 HEAP32[$79>>2] = $$lobit3;
 $80 = (($managerDesc) + 52|0);
 HEAP32[$80>>2] = $30;
 $81 = (($managerDesc) + 56|0);
 HEAP32[$81>>2] = $82;
 $83 = Math_fround(HEAPF32[$cdom>>2]);
 HEAPF32[$60>>2] = $83;
 $84 = (($cdom) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 HEAPF32[$61>>2] = $85;
 $86 = HEAP32[$62>>2]|0;
 $87 = (($86) + 32|0);
 $88 = (($managerDesc) + 20|0);
 HEAP32[$88>>2] = $87;
 $89 = HEAP32[$66>>2]|0;
 $90 = (($89) + 32|0);
 $91 = (($managerDesc) + 24|0);
 HEAP32[$91>>2] = $90;
 $92 = ($10<<24>>24)==(4);
 $93 = $92&1;
 $94 = ($14<<24>>24)==(4);
 $95 = $94&1;
 $96 = $95 << 1;
 $97 = $96 | $93;
 $98 = (($managerDesc) + 60|0);
 HEAP32[$98>>2] = $97;
 $99 = ($10<<24>>24)!=(0);
 $100 = $99&1;
 $101 = ($14<<24>>24)!=(0);
 $102 = $101&1;
 $103 = $102 << 1;
 $104 = $103 | $100;
 $105 = (($managerDesc) + 64|0);
 HEAP32[$105>>2] = $104;
 $106 = (($managerDesc) + 68|0);
 HEAP32[$106>>2] = $touching$0;
 $107 = (__ZNK5physx2Sc8ShapeSim15getPxsRigidCoreEv($4)|0);
 $108 = (($managerDesc) + 28|0);
 HEAP32[$108>>2] = $107;
 $109 = (__ZNK5physx2Sc8ShapeSim15getPxsRigidCoreEv($6)|0);
 $110 = (($managerDesc) + 32|0);
 HEAP32[$110>>2] = $109;
 $111 = (($4) + 24|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = (($managerDesc) + 72|0);
 HEAP32[$113>>2] = $112;
 $114 = (($6) + 24|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (($managerDesc) + 76|0);
 HEAP32[$116>>2] = $115;
 HEAP32[$managerDesc>>2] = $this;
 $117 = HEAP32[$55>>2]|0;
 $118 = (($117) + 1000|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (__ZN5physx10PxsContext20createContactManagerERKNS_24PxvManagerDescRigidRigidEPNS_18PxsMaterialManagerE($119,$managerDesc,$3)|0);
 $121 = (($this) + 56|0);
 HEAP32[$121>>2] = $120;
 $122 = ($120|0)==(0|0);
 if ($122) {
  STACKTOP = sp;return;
 }
 $123 = HEAP32[$55>>2]|0;
 $124 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($123)|0);
 $125 = (($this) + 60|0);
 $126 = HEAP32[$121>>2]|0;
 __ZN5physx16PxsIslandManager14setEdgeRigidCMERKNS_20PxsIslandManagerHookIjLj4294967295EEEPNS_17PxsContactManagerE($124,$125,$126);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL26onPoseChangedWhileSleepingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($4)|0);
 $6 = (($5) + 1212|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($7)|0);
 $9 = (($this) + 60|0);
 __ZN5physx16PxsIslandManager16setEdgeConnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($8,$9);
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 98304;
 $13 = ($12|0)==(0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$3>>2]|0;
 $15 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($14)|0);
 $16 = (($this) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($17)|0);
 $19 = ($15|0)==(0|0);
 $20 = ($18|0)==(0|0);
 $or$cond = $19 | $20;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc5Scene18addToLostTouchListEPNS0_7BodySimES3_($5,$15,$18);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLL25postNarrowPhaseSecondPassERNS_16PxsIslandManagerEb($this,$islandManager,$connect) {
 $this = $this|0;
 $islandManager = $islandManager|0;
 $connect = $connect|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 14|0);
 $3 = HEAP16[$2>>1]|0;
 if ($connect) {
  $4 = (($3) + 1)<<16>>16;
  HEAP16[$2>>1] = $4;
  $5 = (($this) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($6)|0);
  $8 = (($this) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($9)|0);
  $11 = ($7|0)==(0|0);
  if (!($11)) {
   $12 = (($7) + 148|0);
   $13 = HEAP16[$12>>1]|0;
   $14 = (($13) + 1)<<16>>16;
   HEAP16[$12>>1] = $14;
  }
  $15 = ($10|0)==(0|0);
  if (!($15)) {
   $16 = (($10) + 148|0);
   $17 = HEAP16[$16>>1]|0;
   $18 = (($17) + 1)<<16>>16;
   HEAP16[$16>>1] = $18;
  }
  $19 = (($this) + 60|0);
  __ZN5physx16PxsIslandManager16setEdgeConnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($islandManager,$19);
  STACKTOP = sp;return;
 } else {
  $20 = (($3) + -1)<<16>>16;
  HEAP16[$2>>1] = $20;
  $21 = (($this) + 32|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($22)|0);
  $24 = (($this) + 36|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($25)|0);
  $27 = ($23|0)==(0|0);
  if (!($27)) {
   $28 = (($23) + 148|0);
   $29 = HEAP16[$28>>1]|0;
   $30 = (($29) + -1)<<16>>16;
   HEAP16[$28>>1] = $30;
  }
  $31 = ($26|0)==(0|0);
  if (!($31)) {
   $32 = (($26) + 148|0);
   $33 = HEAP16[$32>>1]|0;
   $34 = (($33) + -1)<<16>>16;
   HEAP16[$32>>1] = $34;
  }
  $35 = (($this) + 60|0);
  __ZN5physx16PxsIslandManager18setEdgeUnconnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($islandManager,$35);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc19ShapeInstancePairLL23postIslandGenSecondPassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 476;
 $3 = ($2|0)==(0);
 $4 = $1 & 4194304;
 $5 = ($4|0)==(0);
 $or$cond = $3 | $5;
 if ($or$cond) {
  $20 = $1;
 } else {
  $6 = (($this) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($7)|0);
  $9 = (($8) + 1088|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN5physx2Sc10NPhaseCore32addToPersistentContactEventPairsEPNS0_19ShapeInstancePairLLE($10,$this);
  $11 = HEAP32[$0>>2]|0;
  $12 = $11 & -4194305;
  HEAP32[$0>>2] = $12;
  $20 = $12;
 }
 $13 = (($this) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 114|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16 & 2;
 $18 = ($17<<16>>16)==(0);
 $19 = $20 & 32768;
 $21 = ($19|0)!=(0);
 if ($18) {
  if (!($21)) {
   STACKTOP = sp;return;
  }
  $24 = (__ZN5physx2Sc19ShapeInstancePairLL16managerLostTouchEjb($this,0,0)|0);
  if (!($24)) {
   STACKTOP = sp;return;
  }
  $25 = (($this) + 32|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__ZNK5physx2Sc8ShapeSim8getSceneEv($26)|0);
  $28 = HEAP32[$25>>2]|0;
  $29 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($28)|0);
  $30 = (($this) + 36|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($31)|0);
  __ZN5physx2Sc5Scene18addToLostTouchListEPNS0_7BodySimES3_($27,$29,$32);
  STACKTOP = sp;return;
 }
 if (!($21)) {
  __ZN5physx2Sc19ShapeInstancePairLL15managerNewTouchEjb($this,0,0);
  STACKTOP = sp;return;
 }
 $22 = $20 & 8;
 $23 = ($22|0)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc19ShapeInstancePairLL23processUserNotificationEjtbbj($this,8,0,0,0,0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLLD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((472144 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = ((472144 + 52|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ShapeInstancePairLLD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((472144 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((472144 + 52|0));
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc19ShapeInstancePairLLD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 HEAP32[$0>>2] = (((472144 + 8|0)));
 $1 = (($0) + 8|0);
 HEAP32[$1>>2] = (((472144 + 52|0)));
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc19ShapeInstancePairLLD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 HEAP32[$1>>2] = (((472144 + 8|0)));
 $2 = (($1) + 8|0);
 HEAP32[$2>>2] = (((472144 + 52|0)));
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc20ContactStreamManager28fillInContactReportExtraDataEPNS_17PxContactPairPoseEjRKNS0_8RigidSimEb($cpPose,$index,$rs,$isCCDPass) {
 $cpPose = $cpPose|0;
 $index = $index|0;
 $rs = $rs|0;
 $isCCDPass = $isCCDPass|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = 0;
 var $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($rs) + 50|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($rs) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 if ($2) {
  $279 = (($4) + 16|0);
  $280 = Math_fround(HEAPF32[$279>>2]);
  $281 = ((($cpPose) + (($index*28)|0)|0) + 4|0);
  HEAPF32[$281>>2] = $280;
  $282 = (($4) + 20|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = ((($cpPose) + (($index*28)|0)|0) + 8|0);
  HEAPF32[$284>>2] = $283;
  $285 = (($4) + 24|0);
  $286 = Math_fround(HEAPF32[$285>>2]);
  $287 = ((($cpPose) + (($index*28)|0)|0) + 12|0);
  HEAPF32[$287>>2] = $286;
  $288 = (($4) + 28|0);
  $289 = Math_fround(HEAPF32[$288>>2]);
  $290 = ((($cpPose) + (($index*28)|0)|0) + 16|0);
  HEAPF32[$290>>2] = $289;
  $291 = (($4) + 32|0);
  $292 = Math_fround(HEAPF32[$291>>2]);
  $293 = ((($cpPose) + (($index*28)|0)|0) + 20|0);
  HEAPF32[$293>>2] = $292;
  $294 = (($4) + 36|0);
  $295 = Math_fround(HEAPF32[$294>>2]);
  $296 = ((($cpPose) + (($index*28)|0)|0) + 24|0);
  HEAPF32[$296>>2] = $295;
  $297 = (($4) + 40|0);
  $298 = Math_fround(HEAPF32[$297>>2]);
  $299 = ((($cpPose) + (($index*28)|0)|0) + 28|0);
  HEAPF32[$299>>2] = $298;
  STACKTOP = sp;return;
 }
 $5 = ((($cpPose) + (($index*28)|0)|0) + 4|0);
 if ($isCCDPass) {
  $142 = (($rs) + 64|0);
  $143 = (($142) + 32|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = (($142) + 36|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($142) + 40|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = (($142) + 44|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $151 = (($142) + 48|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = (($142) + 52|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = (($142) + 56|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = (($4) + 48|0);
  $158 = (($4) + 64|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = (($4) + 68|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = (($4) + 72|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = Math_fround($159 * Math_fround(-2.0));
  $165 = Math_fround($161 * Math_fround(-2.0));
  $166 = Math_fround($163 * Math_fround(-2.0));
  $167 = (($4) + 60|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = Math_fround($168 * $168);
  $170 = Math_fround($169 + Math_fround(-0.5));
  $171 = Math_fround(HEAPF32[$157>>2]);
  $172 = Math_fround($164 * $171);
  $173 = (($4) + 52|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = Math_fround($165 * $174);
  $176 = Math_fround($172 + $175);
  $177 = (($4) + 56|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = Math_fround($166 * $178);
  $180 = Math_fround($176 + $179);
  $181 = Math_fround($164 * $170);
  $182 = Math_fround($166 * $174);
  $183 = Math_fround($165 * $178);
  $184 = Math_fround($182 - $183);
  $185 = Math_fround($168 * $184);
  $186 = Math_fround($181 - $185);
  $187 = Math_fround($171 * $180);
  $188 = Math_fround($187 + $186);
  $189 = Math_fround($165 * $170);
  $190 = Math_fround($164 * $178);
  $191 = Math_fround($166 * $171);
  $192 = Math_fround($190 - $191);
  $193 = Math_fround($168 * $192);
  $194 = Math_fround($189 - $193);
  $195 = Math_fround($174 * $180);
  $196 = Math_fround($195 + $194);
  $197 = Math_fround($166 * $170);
  $198 = Math_fround($165 * $171);
  $199 = Math_fround($164 * $174);
  $200 = Math_fround($198 - $199);
  $201 = Math_fround($168 * $200);
  $202 = Math_fround($197 - $201);
  $203 = Math_fround($178 * $180);
  $204 = Math_fround($202 + $203);
  $205 = Math_fround(-$171);
  $206 = Math_fround(-$174);
  $207 = Math_fround(-$178);
  $208 = Math_fround($188 * Math_fround(2.0));
  $209 = Math_fround($196 * Math_fround(2.0));
  $210 = Math_fround($204 * Math_fround(2.0));
  $211 = Math_fround($150 * $150);
  $212 = Math_fround($211 + Math_fround(-0.5));
  $213 = Math_fround($144 * $208);
  $214 = Math_fround($146 * $209);
  $215 = Math_fround($213 + $214);
  $216 = Math_fround($148 * $210);
  $217 = Math_fround($216 + $215);
  $218 = Math_fround($212 * $208);
  $219 = Math_fround($146 * $210);
  $220 = Math_fround($148 * $209);
  $221 = Math_fround($219 - $220);
  $222 = Math_fround($150 * $221);
  $223 = Math_fround($218 + $222);
  $224 = Math_fround($144 * $217);
  $225 = Math_fround($224 + $223);
  $226 = Math_fround($212 * $209);
  $227 = Math_fround($148 * $208);
  $228 = Math_fround($144 * $210);
  $229 = Math_fround($227 - $228);
  $230 = Math_fround($150 * $229);
  $231 = Math_fround($226 + $230);
  $232 = Math_fround($146 * $217);
  $233 = Math_fround($232 + $231);
  $234 = Math_fround($212 * $210);
  $235 = Math_fround($144 * $209);
  $236 = Math_fround($146 * $208);
  $237 = Math_fround($235 - $236);
  $238 = Math_fround($150 * $237);
  $239 = Math_fround($234 + $238);
  $240 = Math_fround($148 * $217);
  $241 = Math_fround($239 + $240);
  $242 = Math_fround($152 + $225);
  $243 = Math_fround($154 + $233);
  $244 = Math_fround($156 + $241);
  $245 = Math_fround($150 * $205);
  $246 = Math_fround($144 * $168);
  $247 = Math_fround($246 + $245);
  $248 = Math_fround($146 * $207);
  $249 = Math_fround($247 + $248);
  $250 = Math_fround($148 * $206);
  $251 = Math_fround($249 - $250);
  $252 = Math_fround($150 * $206);
  $253 = Math_fround($146 * $168);
  $254 = Math_fround($253 + $252);
  $255 = Math_fround($148 * $205);
  $256 = Math_fround($255 + $254);
  $257 = Math_fround($144 * $207);
  $258 = Math_fround($256 - $257);
  $259 = Math_fround($150 * $207);
  $260 = Math_fround($148 * $168);
  $261 = Math_fround($260 + $259);
  $262 = Math_fround($144 * $206);
  $263 = Math_fround($262 + $261);
  $264 = Math_fround($146 * $205);
  $265 = Math_fround($263 - $264);
  $266 = Math_fround($150 * $168);
  $267 = Math_fround($144 * $205);
  $268 = Math_fround($266 - $267);
  $269 = Math_fround($146 * $206);
  $270 = Math_fround($268 - $269);
  $271 = Math_fround($148 * $207);
  $272 = Math_fround($270 - $271);
  HEAPF32[$5>>2] = $251;
  $273 = ((($cpPose) + (($index*28)|0)|0) + 8|0);
  HEAPF32[$273>>2] = $258;
  $274 = ((($cpPose) + (($index*28)|0)|0) + 12|0);
  HEAPF32[$274>>2] = $265;
  $275 = ((($cpPose) + (($index*28)|0)|0) + 16|0);
  HEAPF32[$275>>2] = $272;
  $276 = ((($cpPose) + (($index*28)|0)|0) + 20|0);
  HEAPF32[$276>>2] = $242;
  $277 = ((($cpPose) + (($index*28)|0)|0) + 24|0);
  HEAPF32[$277>>2] = $243;
  $278 = ((($cpPose) + (($index*28)|0)|0) + 28|0);
  HEAPF32[$278>>2] = $244;
  STACKTOP = sp;return;
 } else {
  $6 = (($4) + 16|0);
  $7 = (($4) + 48|0);
  $8 = (($4) + 64|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($4) + 68|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($4) + 72|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($9 * Math_fround(-2.0));
  $15 = Math_fround($11 * Math_fround(-2.0));
  $16 = Math_fround($13 * Math_fround(-2.0));
  $17 = (($4) + 60|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($18 * $18);
  $20 = Math_fround($19 + Math_fround(-0.5));
  $21 = Math_fround(HEAPF32[$7>>2]);
  $22 = Math_fround($14 * $21);
  $23 = (($4) + 52|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($15 * $24);
  $26 = Math_fround($22 + $25);
  $27 = (($4) + 56|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround($16 * $28);
  $30 = Math_fround($26 + $29);
  $31 = Math_fround($14 * $20);
  $32 = Math_fround($16 * $24);
  $33 = Math_fround($15 * $28);
  $34 = Math_fround($32 - $33);
  $35 = Math_fround($18 * $34);
  $36 = Math_fround($31 - $35);
  $37 = Math_fround($21 * $30);
  $38 = Math_fround($37 + $36);
  $39 = Math_fround($15 * $20);
  $40 = Math_fround($14 * $28);
  $41 = Math_fround($16 * $21);
  $42 = Math_fround($40 - $41);
  $43 = Math_fround($18 * $42);
  $44 = Math_fround($39 - $43);
  $45 = Math_fround($24 * $30);
  $46 = Math_fround($45 + $44);
  $47 = Math_fround($16 * $20);
  $48 = Math_fround($15 * $21);
  $49 = Math_fround($14 * $24);
  $50 = Math_fround($48 - $49);
  $51 = Math_fround($18 * $50);
  $52 = Math_fround($47 - $51);
  $53 = Math_fround($28 * $30);
  $54 = Math_fround($52 + $53);
  $55 = Math_fround(-$21);
  $56 = Math_fround(-$24);
  $57 = Math_fround(-$28);
  $58 = Math_fround($38 * Math_fround(2.0));
  $59 = Math_fround($46 * Math_fround(2.0));
  $60 = Math_fround($54 * Math_fround(2.0));
  $61 = (($4) + 28|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = Math_fround($62 * $62);
  $64 = Math_fround($63 + Math_fround(-0.5));
  $65 = Math_fround(HEAPF32[$6>>2]);
  $66 = Math_fround($65 * $58);
  $67 = (($4) + 20|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($68 * $59);
  $70 = Math_fround($66 + $69);
  $71 = (($4) + 24|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($72 * $60);
  $74 = Math_fround($73 + $70);
  $75 = Math_fround($64 * $58);
  $76 = Math_fround($68 * $60);
  $77 = Math_fround($72 * $59);
  $78 = Math_fround($76 - $77);
  $79 = Math_fround($62 * $78);
  $80 = Math_fround($75 + $79);
  $81 = Math_fround($65 * $74);
  $82 = Math_fround($81 + $80);
  $83 = Math_fround($64 * $59);
  $84 = Math_fround($72 * $58);
  $85 = Math_fround($65 * $60);
  $86 = Math_fround($84 - $85);
  $87 = Math_fround($62 * $86);
  $88 = Math_fround($83 + $87);
  $89 = Math_fround($68 * $74);
  $90 = Math_fround($89 + $88);
  $91 = Math_fround($64 * $60);
  $92 = Math_fround($65 * $59);
  $93 = Math_fround($68 * $58);
  $94 = Math_fround($92 - $93);
  $95 = Math_fround($62 * $94);
  $96 = Math_fround($91 + $95);
  $97 = Math_fround($72 * $74);
  $98 = Math_fround($96 + $97);
  $99 = (($4) + 32|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($100 + $82);
  $102 = (($4) + 36|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = Math_fround($103 + $90);
  $105 = (($4) + 40|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = Math_fround($106 + $98);
  $108 = Math_fround($62 * $55);
  $109 = Math_fround($18 * $65);
  $110 = Math_fround($108 + $109);
  $111 = Math_fround($68 * $57);
  $112 = Math_fround($110 + $111);
  $113 = Math_fround($72 * $56);
  $114 = Math_fround($112 - $113);
  $115 = Math_fround($62 * $56);
  $116 = Math_fround($18 * $68);
  $117 = Math_fround($115 + $116);
  $118 = Math_fround($72 * $55);
  $119 = Math_fround($118 + $117);
  $120 = Math_fround($65 * $57);
  $121 = Math_fround($119 - $120);
  $122 = Math_fround($62 * $57);
  $123 = Math_fround($18 * $72);
  $124 = Math_fround($122 + $123);
  $125 = Math_fround($65 * $56);
  $126 = Math_fround($125 + $124);
  $127 = Math_fround($68 * $55);
  $128 = Math_fround($126 - $127);
  $129 = Math_fround($18 * $62);
  $130 = Math_fround($65 * $55);
  $131 = Math_fround($129 - $130);
  $132 = Math_fround($68 * $56);
  $133 = Math_fround($131 - $132);
  $134 = Math_fround($72 * $57);
  $135 = Math_fround($133 - $134);
  HEAPF32[$5>>2] = $114;
  $136 = ((($cpPose) + (($index*28)|0)|0) + 8|0);
  HEAPF32[$136>>2] = $121;
  $137 = ((($cpPose) + (($index*28)|0)|0) + 12|0);
  HEAPF32[$137>>2] = $128;
  $138 = ((($cpPose) + (($index*28)|0)|0) + 16|0);
  HEAPF32[$138>>2] = $135;
  $139 = ((($cpPose) + (($index*28)|0)|0) + 20|0);
  HEAPF32[$139>>2] = $101;
  $140 = ((($cpPose) + (($index*28)|0)|0) + 24|0);
  HEAPF32[$140>>2] = $104;
  $141 = ((($cpPose) + (($index*28)|0)|0) + 28|0);
  HEAPF32[$141>>2] = $107;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc9ActorPairENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 472336 : 472304;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,472224,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx2Sc13ShapeIterator7getNextEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$pre = HEAP32[$this>>2]|0;
 $1 = $$pre;
 while(1) {
  $0 = ($1|0)==(0|0);
  if ($0) {
   $$0 = 0;
   label = 5;
   break;
  }
  $2 = (($1) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$this>>2] = $3;
  $4 = (($1) + 12|0);
  $5 = $4;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) + 4)|0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = $7 & -1073741824;
  $12 = ($11|0)==(0);
  $13 = (0)==(0);
  $14 = $12 & $13;
  if ($14) {
   break;
  } else {
   $1 = $3;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc13ShapeIterator4initERKNS0_8ActorSimE($this,$r) {
 $this = $this|0;
 $r = $r|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($r) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$this>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc12BodyIterator7getNextEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $$pre = HEAP32[$this>>2]|0;
 $$pre1 = HEAP32[$0>>2]|0;
 $2 = $$pre;
 while(1) {
  $1 = ($2>>>0)<($$pre1>>>0);
  if (!($1)) {
   $$0 = 0;
   label = 5;
   break;
  }
  $3 = HEAP32[$2>>2]|0;
  $4 = (($2) + 4|0);
  HEAP32[$this>>2] = $4;
  $5 = (($3) + 50|0);
  $6 = HEAP8[$5>>0]|0;
  if ((($6<<24>>24) == 1) | (($6<<24>>24) == 4)) {
   break;
  } else {
   $2 = $4;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($3) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc8ShapeSimC2ERNS0_8RigidSimERKNS0_9ShapeCoreEPNS_12PxsRigidBodyEPNS_9PxBounds3E($this,$owner,$core,$atom,$outBounds) {
 $this = $this|0;
 $owner = $owner|0;
 $core = $core|0;
 $atom = $atom|0;
 $outBounds = $outBounds|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $bounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bounds = sp + 8|0;
 $0 = sp;
 HEAP32[$this>>2] = ((473672 + 8|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $owner;
 $3 = (($this) + 12|0);
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = 1073741823;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 1073741823;
 __ZN5physx2Sc5Actor15onElementAttachERNS0_7ElementE($owner,$this);
 HEAP32[$this>>2] = ((472456 + 8|0));
 $8 = (($this) + 24|0);
 HEAP32[$8>>2] = -1;
 $9 = (($this) + 28|0);
 HEAP32[$9>>2] = $core;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1008|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($core) + 64|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16 & 5;
 $18 = ($17<<24>>24)==(0);
 if (!($18)) {
  __ZNK5physx2Sc8ShapeSim18computeWorldBoundsERKNS0_9ShapeCoreERKNS0_8RigidSimE($bounds,0,$core,$owner);
  $19 = (($owner) + 50|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   $27 = 0;
  } else {
   $22 = (($owner) + 56|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 2)|0;
   $27 = $24;
  }
  $25 = ($atom|0)==(0|0);
  if ($25) {
   HEAP32[$0>>2] = 1073741823;
   $26 = (($0) + 4|0);
   HEAP32[$26>>2] = 1073741823;
   __ZN5physx2Sc5Scene19addBroadPhaseVolumeERKNS_9PxBounds3EjRKNS_9AABBMgrIdERNS0_8ShapeSimE($14,$bounds,$27,$0,$this);
  } else {
   $28 = (($atom) + 68|0);
   $29 = $28;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = $0;
   $36 = $35;
   HEAP32[$36>>2] = $31;
   $37 = (($35) + 4)|0;
   $38 = $37;
   HEAP32[$38>>2] = $34;
   __ZN5physx2Sc5Scene19addBroadPhaseVolumeERKNS_9PxBounds3EjRKNS_9AABBMgrIdERNS0_8ShapeSimE($14,$bounds,$27,$0,$this);
   $39 = $3;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 4)|0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = $41 & 1073741823;
   $46 = $44 & 1073741823;
   $47 = $28;
   $48 = $47;
   HEAP32[$48>>2] = $45;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
  }
  $51 = ($outBounds|0)==(0|0);
  if (!($51)) {
   $52 = (($core) + 60|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = Math_fround(HEAPF32[$bounds>>2]);
   $55 = Math_fround($53 + $54);
   $56 = (($bounds) + 4|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround($53 + $57);
   $59 = (($bounds) + 8|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround($53 + $60);
   HEAPF32[$outBounds>>2] = $55;
   $62 = (($outBounds) + 4|0);
   HEAPF32[$62>>2] = $58;
   $63 = (($outBounds) + 8|0);
   HEAPF32[$63>>2] = $61;
   $64 = Math_fround(HEAPF32[$52>>2]);
   $65 = (($bounds) + 12|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = Math_fround($66 - $64);
   $68 = (($bounds) + 16|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($69 - $64);
   $71 = (($bounds) + 20|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = Math_fround($72 - $64);
   $74 = (($outBounds) + 12|0);
   HEAPF32[$74>>2] = $67;
   $75 = (($outBounds) + 16|0);
   HEAPF32[$75>>2] = $70;
   $76 = (($outBounds) + 20|0);
   HEAPF32[$76>>2] = $73;
  }
 }
 $77 = (($14) + 1204|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 8|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0);
 if ($81) {
  $87 = HEAP32[$78>>2]|0;
  $88 = (($87) + 1)|0;
  HEAP32[$78>>2] = $88;
  $$0$i$i = $87;
  $89 = (($this) + 20|0);
  HEAP32[$89>>2] = $$0$i$i;
  STACKTOP = sp;return;
 } else {
  $82 = (($80) + -1)|0;
  $83 = (($78) + 4|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + ($82<<2)|0);
  $86 = HEAP32[$85>>2]|0;
  HEAP32[$79>>2] = $82;
  $$0$i$i = $86;
  $89 = (($this) + 20|0);
  HEAP32[$89>>2] = $$0$i$i;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Sc8ShapeSim8getSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1008|0);
 $5 = HEAP32[$4>>2]|0;
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc8ShapeSim18computeWorldBoundsERKNS0_9ShapeCoreERKNS0_8RigidSimE($agg$result,$this,$core,$actor) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $core = $core|0;
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $globalPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $globalPose = sp;
 $0 = (($core) + 32|0);
 $1 = (($actor) + 50|0);
 $2 = HEAP8[$1>>0]|0;
 if ((($2<<24>>24) == 1) | (($2<<24>>24) == 4)) {
  $3 = (($actor) + 52|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 16|0);
  $6 = (($4) + 48|0);
  __ZN5physx2Cm27getDynamicGlobalPoseAlignedERKNS_11PxTransformES3_S3_RS1_($5,$0,$6,$globalPose);
  $107 = (($core) + 68|0);
  $108 = (($core) + 60|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($107,$agg$result,$globalPose,$109,0);
  STACKTOP = sp;return;
 } else {
  $7 = (($actor) + 52|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 16|0);
  $10 = (($8) + 32|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($8) + 36|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($8) + 40|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround(HEAPF32[$9>>2]);
  $17 = (($8) + 20|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($8) + 24|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($8) + 28|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($core) + 48|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($core) + 52|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($core) + 56|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround(HEAPF32[$0>>2]);
  $30 = (($0) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($0) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($0) + 12|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($22 * $35);
  $37 = Math_fround($16 * $29);
  $38 = Math_fround($18 * $31);
  $39 = Math_fround($37 + $38);
  $40 = Math_fround($20 * $33);
  $41 = Math_fround($39 + $40);
  $42 = Math_fround($36 - $41);
  $43 = Math_fround($18 * $33);
  $44 = Math_fround($20 * $31);
  $45 = Math_fround($43 - $44);
  $46 = Math_fround($20 * $29);
  $47 = Math_fround($16 * $33);
  $48 = Math_fround($46 - $47);
  $49 = Math_fround($16 * $31);
  $50 = Math_fround($18 * $29);
  $51 = Math_fround($49 - $50);
  $52 = Math_fround($22 * $29);
  $53 = Math_fround($22 * $31);
  $54 = Math_fround($22 * $33);
  $55 = Math_fround($52 + $45);
  $56 = Math_fround($53 + $48);
  $57 = Math_fround($54 + $51);
  $58 = Math_fround($16 * $35);
  $59 = Math_fround($18 * $35);
  $60 = Math_fround($20 * $35);
  $61 = Math_fround($58 + $55);
  $62 = Math_fround($59 + $56);
  $63 = Math_fround($60 + $57);
  $64 = Math_fround($22 * $22);
  $65 = Math_fround($64 + Math_fround(-0.5));
  $66 = Math_fround($24 * $65);
  $67 = Math_fround($26 * $65);
  $68 = Math_fround($65 * $28);
  $69 = Math_fround($18 * $28);
  $70 = Math_fround($20 * $26);
  $71 = Math_fround($69 - $70);
  $72 = Math_fround($20 * $24);
  $73 = Math_fround($16 * $28);
  $74 = Math_fround($72 - $73);
  $75 = Math_fround($16 * $26);
  $76 = Math_fround($18 * $24);
  $77 = Math_fround($75 - $76);
  $78 = Math_fround($22 * $71);
  $79 = Math_fround($22 * $74);
  $80 = Math_fround($22 * $77);
  $81 = Math_fround($66 + $78);
  $82 = Math_fround($67 + $79);
  $83 = Math_fround($68 + $80);
  $84 = Math_fround($16 * $24);
  $85 = Math_fround($18 * $26);
  $86 = Math_fround($84 + $85);
  $87 = Math_fround($20 * $28);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround($16 * $88);
  $90 = Math_fround($18 * $88);
  $91 = Math_fround($20 * $88);
  $92 = Math_fround($89 + $81);
  $93 = Math_fround($90 + $82);
  $94 = Math_fround($83 + $91);
  $95 = Math_fround($92 * Math_fround(2.0));
  $96 = Math_fround($93 * Math_fround(2.0));
  $97 = Math_fround($94 * Math_fround(2.0));
  $98 = Math_fround($11 + $95);
  $99 = Math_fround($13 + $96);
  $100 = Math_fround($15 + $97);
  $101 = (($globalPose) + 16|0);
  HEAPF32[$101>>2] = $98;
  $102 = (($globalPose) + 20|0);
  HEAPF32[$102>>2] = $99;
  $103 = (($globalPose) + 24|0);
  HEAPF32[$103>>2] = $100;
  HEAPF32[$globalPose>>2] = $61;
  $104 = (($globalPose) + 4|0);
  HEAPF32[$104>>2] = $62;
  $105 = (($globalPose) + 8|0);
  HEAPF32[$105>>2] = $63;
  $106 = (($globalPose) + 12|0);
  HEAPF32[$106>>2] = $42;
  $107 = (($core) + 68|0);
  $108 = (($core) + 60|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($107,$agg$result,$globalPose,$109,0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc8ShapeSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((472456 + 8|0));
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1008|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1204|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5physx2Sc15ObjectIDTracker9releaseIDEj($8,$10);
 __ZN5physx2Sc7ElementD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((472456 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1008|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 1204|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx2Sc15ObjectIDTracker9releaseIDEj($7,$9);
 __ZN5physx2Sc7ElementD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim20createTransformCacheERNS_17PxsTransformCacheE($this,$cache) {
 $this = $this|0;
 $cache = $cache|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 if (!($3)) {
  $$pre = (($cache) + 28|0);
  $$pre$phiZ2D = $$pre;$58 = $2;
  $56 = HEAP32[$$pre$phiZ2D>>2]|0;
  $57 = (($56) + ($58<<2)|0);
  $59 = HEAP32[$57>>2]|0;
  $60 = (($59) + 1)|0;
  HEAP32[$57>>2] = $60;
  STACKTOP = sp;return;
 }
 $4 = (($cache) + 16|0);
 $5 = (($cache) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = (($cache) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $16 = HEAP32[$cache>>2]|0;
  $17 = (($16) + 1)|0;
  HEAP32[$cache>>2] = $17;
  $$0$i$i = $16;
 } else {
  $11 = (($9) + -1)|0;
  $12 = (($cache) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($11<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$8>>2] = $11;
  $$0$i$i = $15;
 }
 $18 = ($$0$i$i|0)==($7|0);
 if ($18) {
  $19 = $6 << 1;
  $20 = ($7>>>0)<($19>>>0);
  if ($20) {
   __ZN5physx6shdfnd5ArrayINS_11PxTransformENS0_19ReflectionAllocatorIS2_EEE8recreateEj($4,$19);
  }
  $21 = (($cache) + 28|0);
  $22 = (($cache) + 36|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 2147483647;
  $25 = ($24>>>0)<($19>>>0);
  if ($25) {
   __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($21,$19);
  }
  $26 = (($cache) + 20|0);
  HEAP32[$26>>2] = $19;
  $27 = (($cache) + 32|0);
  HEAP32[$27>>2] = $19;
  $28 = HEAP32[$21>>2]|0;
  $29 = (($28) + ($7<<2)|0);
  $30 = $6 << 2;
  _memset(($29|0),0,($30|0))|0;
 }
 $31 = (($cache) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($$0$i$i<<2)|0);
 HEAP32[$33>>2] = 0;
 __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($0,$this);
 $34 = (($cache) + 16|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = Math_fround(HEAPF32[$0>>2]);
 $37 = (($35) + (($$0$i$i*28)|0)|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($0) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = ((($35) + (($$0$i$i*28)|0)|0) + 4|0);
 HEAPF32[$40>>2] = $39;
 $41 = (($0) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = ((($35) + (($$0$i$i*28)|0)|0) + 8|0);
 HEAPF32[$43>>2] = $42;
 $44 = (($0) + 12|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = ((($35) + (($$0$i$i*28)|0)|0) + 12|0);
 HEAPF32[$46>>2] = $45;
 $47 = (($0) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = ((($35) + (($$0$i$i*28)|0)|0) + 16|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($0) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = ((($35) + (($$0$i$i*28)|0)|0) + 20|0);
 HEAPF32[$52>>2] = $51;
 $53 = (($0) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = ((($35) + (($$0$i$i*28)|0)|0) + 24|0);
 HEAPF32[$55>>2] = $54;
 HEAP32[$1>>2] = $$0$i$i;
 $$pre$phiZ2D = $31;$58 = $$0$i$i;
 $56 = HEAP32[$$pre$phiZ2D>>2]|0;
 $57 = (($56) + ($58<<2)|0);
 $59 = HEAP32[$57>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$57>>2] = $60;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 50|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 $8 = (($4) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 16|0);
 if ($7) {
  $11 = (($1) + 48|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($12 * Math_fround(2.0));
  $14 = (($1) + 52|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($15 * Math_fround(2.0));
  $17 = (($1) + 56|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($18 * Math_fround(2.0));
  $20 = (($9) + 28|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($21 * $21);
  $23 = Math_fround($22 + Math_fround(-0.5));
  $24 = Math_fround(HEAPF32[$10>>2]);
  $25 = Math_fround($13 * $24);
  $26 = (($9) + 20|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($16 * $27);
  $29 = Math_fround($25 + $28);
  $30 = (($9) + 24|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($19 * $31);
  $33 = Math_fround($29 + $32);
  $34 = Math_fround($13 * $23);
  $35 = Math_fround($19 * $27);
  $36 = Math_fround($16 * $31);
  $37 = Math_fround($35 - $36);
  $38 = Math_fround($21 * $37);
  $39 = Math_fround($34 + $38);
  $40 = Math_fround($24 * $33);
  $41 = Math_fround($40 + $39);
  $42 = Math_fround($16 * $23);
  $43 = Math_fround($13 * $31);
  $44 = Math_fround($19 * $24);
  $45 = Math_fround($43 - $44);
  $46 = Math_fround($21 * $45);
  $47 = Math_fround($42 + $46);
  $48 = Math_fround($27 * $33);
  $49 = Math_fround($48 + $47);
  $50 = Math_fround($19 * $23);
  $51 = Math_fround($16 * $24);
  $52 = Math_fround($13 * $27);
  $53 = Math_fround($51 - $52);
  $54 = Math_fround($21 * $53);
  $55 = Math_fround($50 + $54);
  $56 = Math_fround($31 * $33);
  $57 = Math_fround($55 + $56);
  $58 = (($9) + 32|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($59 + $41);
  $61 = (($9) + 36|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = Math_fround($62 + $49);
  $64 = (($9) + 40|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($65 + $57);
  $67 = Math_fround(HEAPF32[$2>>2]);
  $68 = Math_fround($21 * $67);
  $69 = (($1) + 44|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($24 * $70);
  $72 = Math_fround($68 + $71);
  $73 = (($1) + 40|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($27 * $74);
  $76 = Math_fround($72 + $75);
  $77 = (($1) + 36|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($31 * $78);
  $80 = Math_fround($76 - $79);
  $81 = Math_fround($21 * $78);
  $82 = Math_fround($27 * $70);
  $83 = Math_fround($82 + $81);
  $84 = Math_fround($31 * $67);
  $85 = Math_fround($84 + $83);
  $86 = Math_fround($24 * $74);
  $87 = Math_fround($85 - $86);
  $88 = Math_fround($21 * $74);
  $89 = Math_fround($31 * $70);
  $90 = Math_fround($89 + $88);
  $91 = Math_fround($24 * $78);
  $92 = Math_fround($91 + $90);
  $93 = Math_fround($27 * $67);
  $94 = Math_fround($92 - $93);
  $95 = Math_fround($21 * $70);
  $96 = Math_fround($24 * $67);
  $97 = Math_fround($95 - $96);
  $98 = Math_fround($27 * $78);
  $99 = Math_fround($97 - $98);
  $100 = Math_fround($31 * $74);
  $101 = Math_fround($99 - $100);
  HEAPF32[$agg$result>>2] = $80;
  $102 = (($agg$result) + 4|0);
  HEAPF32[$102>>2] = $87;
  $103 = (($agg$result) + 8|0);
  HEAPF32[$103>>2] = $94;
  $104 = (($agg$result) + 12|0);
  HEAPF32[$104>>2] = $101;
  $105 = (($agg$result) + 16|0);
  HEAPF32[$105>>2] = $60;
  $106 = (($agg$result) + 20|0);
  HEAPF32[$106>>2] = $63;
  $107 = (($agg$result) + 24|0);
  HEAPF32[$107>>2] = $66;
  STACKTOP = sp;return;
 } else {
  $108 = (($9) + 48|0);
  $109 = (($9) + 64|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = (($9) + 68|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($9) + 72|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = Math_fround($110 * Math_fround(-2.0));
  $116 = Math_fround($112 * Math_fround(-2.0));
  $117 = Math_fround($114 * Math_fround(-2.0));
  $118 = (($9) + 60|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround($119 * $119);
  $121 = Math_fround($120 + Math_fround(-0.5));
  $122 = Math_fround(HEAPF32[$108>>2]);
  $123 = Math_fround($115 * $122);
  $124 = (($9) + 52|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = Math_fround($116 * $125);
  $127 = Math_fround($123 + $126);
  $128 = (($9) + 56|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = Math_fround($117 * $129);
  $131 = Math_fround($127 + $130);
  $132 = Math_fround($115 * $121);
  $133 = Math_fround($117 * $125);
  $134 = Math_fround($116 * $129);
  $135 = Math_fround($133 - $134);
  $136 = Math_fround($119 * $135);
  $137 = Math_fround($132 - $136);
  $138 = Math_fround($122 * $131);
  $139 = Math_fround($138 + $137);
  $140 = Math_fround($116 * $121);
  $141 = Math_fround($115 * $129);
  $142 = Math_fround($117 * $122);
  $143 = Math_fround($141 - $142);
  $144 = Math_fround($119 * $143);
  $145 = Math_fround($140 - $144);
  $146 = Math_fround($125 * $131);
  $147 = Math_fround($146 + $145);
  $148 = Math_fround($117 * $121);
  $149 = Math_fround($116 * $122);
  $150 = Math_fround($115 * $125);
  $151 = Math_fround($149 - $150);
  $152 = Math_fround($119 * $151);
  $153 = Math_fround($148 - $152);
  $154 = Math_fround($129 * $131);
  $155 = Math_fround($153 + $154);
  $156 = Math_fround(-$122);
  $157 = Math_fround(-$125);
  $158 = Math_fround(-$129);
  $159 = Math_fround($139 * Math_fround(2.0));
  $160 = Math_fround($147 * Math_fround(2.0));
  $161 = Math_fround($155 * Math_fround(2.0));
  $162 = (($9) + 28|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = Math_fround($163 * $163);
  $165 = Math_fround($164 + Math_fround(-0.5));
  $166 = Math_fround(HEAPF32[$10>>2]);
  $167 = Math_fround($166 * $159);
  $168 = (($9) + 20|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = Math_fround($169 * $160);
  $171 = Math_fround($167 + $170);
  $172 = (($9) + 24|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($173 * $161);
  $175 = Math_fround($174 + $171);
  $176 = Math_fround($165 * $159);
  $177 = Math_fround($169 * $161);
  $178 = Math_fround($173 * $160);
  $179 = Math_fround($177 - $178);
  $180 = Math_fround($163 * $179);
  $181 = Math_fround($176 + $180);
  $182 = Math_fround($166 * $175);
  $183 = Math_fround($182 + $181);
  $184 = Math_fround($165 * $160);
  $185 = Math_fround($173 * $159);
  $186 = Math_fround($166 * $161);
  $187 = Math_fround($185 - $186);
  $188 = Math_fround($163 * $187);
  $189 = Math_fround($184 + $188);
  $190 = Math_fround($169 * $175);
  $191 = Math_fround($190 + $189);
  $192 = Math_fround($165 * $161);
  $193 = Math_fround($166 * $160);
  $194 = Math_fround($169 * $159);
  $195 = Math_fround($193 - $194);
  $196 = Math_fround($163 * $195);
  $197 = Math_fround($192 + $196);
  $198 = Math_fround($173 * $175);
  $199 = Math_fround($197 + $198);
  $200 = (($9) + 32|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = Math_fround($201 + $183);
  $203 = (($9) + 36|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = Math_fround($204 + $191);
  $206 = (($9) + 40|0);
  $207 = Math_fround(HEAPF32[$206>>2]);
  $208 = Math_fround($207 + $199);
  $209 = Math_fround($163 * $156);
  $210 = Math_fround($119 * $166);
  $211 = Math_fround($209 + $210);
  $212 = Math_fround($169 * $158);
  $213 = Math_fround($211 + $212);
  $214 = Math_fround($173 * $157);
  $215 = Math_fround($213 - $214);
  $216 = Math_fround($163 * $157);
  $217 = Math_fround($119 * $169);
  $218 = Math_fround($216 + $217);
  $219 = Math_fround($173 * $156);
  $220 = Math_fround($219 + $218);
  $221 = Math_fround($166 * $158);
  $222 = Math_fround($220 - $221);
  $223 = Math_fround($163 * $158);
  $224 = Math_fround($119 * $173);
  $225 = Math_fround($223 + $224);
  $226 = Math_fround($166 * $157);
  $227 = Math_fround($226 + $225);
  $228 = Math_fround($169 * $156);
  $229 = Math_fround($227 - $228);
  $230 = Math_fround($119 * $163);
  $231 = Math_fround($166 * $156);
  $232 = Math_fround($230 - $231);
  $233 = Math_fround($169 * $157);
  $234 = Math_fround($232 - $233);
  $235 = Math_fround($173 * $158);
  $236 = Math_fround($234 - $235);
  $237 = (($1) + 48|0);
  $238 = Math_fround(HEAPF32[$237>>2]);
  $239 = Math_fround($238 * Math_fround(2.0));
  $240 = (($1) + 52|0);
  $241 = Math_fround(HEAPF32[$240>>2]);
  $242 = Math_fround($241 * Math_fround(2.0));
  $243 = (($1) + 56|0);
  $244 = Math_fround(HEAPF32[$243>>2]);
  $245 = Math_fround($244 * Math_fround(2.0));
  $246 = Math_fround($236 * $236);
  $247 = Math_fround($246 + Math_fround(-0.5));
  $248 = Math_fround($215 * $239);
  $249 = Math_fround($222 * $242);
  $250 = Math_fround($248 + $249);
  $251 = Math_fround($229 * $245);
  $252 = Math_fround($250 + $251);
  $253 = Math_fround($247 * $239);
  $254 = Math_fround($222 * $245);
  $255 = Math_fround($229 * $242);
  $256 = Math_fround($254 - $255);
  $257 = Math_fround($236 * $256);
  $258 = Math_fround($253 + $257);
  $259 = Math_fround($215 * $252);
  $260 = Math_fround($259 + $258);
  $261 = Math_fround($247 * $242);
  $262 = Math_fround($229 * $239);
  $263 = Math_fround($215 * $245);
  $264 = Math_fround($262 - $263);
  $265 = Math_fround($236 * $264);
  $266 = Math_fround($261 + $265);
  $267 = Math_fround($222 * $252);
  $268 = Math_fround($267 + $266);
  $269 = Math_fround($247 * $245);
  $270 = Math_fround($215 * $242);
  $271 = Math_fround($222 * $239);
  $272 = Math_fround($270 - $271);
  $273 = Math_fround($236 * $272);
  $274 = Math_fround($269 + $273);
  $275 = Math_fround($229 * $252);
  $276 = Math_fround($274 + $275);
  $277 = Math_fround($202 + $260);
  $278 = Math_fround($205 + $268);
  $279 = Math_fround($208 + $276);
  $280 = Math_fround(HEAPF32[$2>>2]);
  $281 = Math_fround($236 * $280);
  $282 = (($1) + 44|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = Math_fround($215 * $283);
  $285 = Math_fround($281 + $284);
  $286 = (($1) + 40|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $288 = Math_fround($222 * $287);
  $289 = Math_fround($285 + $288);
  $290 = (($1) + 36|0);
  $291 = Math_fround(HEAPF32[$290>>2]);
  $292 = Math_fround($229 * $291);
  $293 = Math_fround($289 - $292);
  $294 = Math_fround($236 * $291);
  $295 = Math_fround($222 * $283);
  $296 = Math_fround($295 + $294);
  $297 = Math_fround($229 * $280);
  $298 = Math_fround($297 + $296);
  $299 = Math_fround($215 * $287);
  $300 = Math_fround($298 - $299);
  $301 = Math_fround($236 * $287);
  $302 = Math_fround($229 * $283);
  $303 = Math_fround($302 + $301);
  $304 = Math_fround($215 * $291);
  $305 = Math_fround($304 + $303);
  $306 = Math_fround($222 * $280);
  $307 = Math_fround($305 - $306);
  $308 = Math_fround($236 * $283);
  $309 = Math_fround($215 * $280);
  $310 = Math_fround($308 - $309);
  $311 = Math_fround($222 * $291);
  $312 = Math_fround($310 - $311);
  $313 = Math_fround($229 * $287);
  $314 = Math_fround($312 - $313);
  HEAPF32[$agg$result>>2] = $293;
  $315 = (($agg$result) + 4|0);
  HEAPF32[$315>>2] = $300;
  $316 = (($agg$result) + 8|0);
  HEAPF32[$316>>2] = $307;
  $317 = (($agg$result) + 12|0);
  HEAPF32[$317>>2] = $314;
  $318 = (($agg$result) + 16|0);
  HEAPF32[$318>>2] = $277;
  $319 = (($agg$result) + 20|0);
  HEAPF32[$319>>2] = $278;
  $320 = (($agg$result) + 24|0);
  HEAPF32[$320>>2] = $279;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc8ShapeSim21destroyTransformCacheERNS_17PxsTransformCacheE($this,$cache) {
 $this = $this|0;
 $cache = $cache|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($cache) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($2<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 HEAP32[$5>>2] = $7;
 $8 = ($7|0)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $9;
 $10 = (($cache) + 4|0);
 $11 = (($cache) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2147483647;
 $14 = (($cache) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  $17 = HEAP32[$10>>2]|0;
  $18 = (($17) + ($15<<2)|0);
  $19 = ($18|0)==(0|0);
  if ($19) {
   $21 = $15;
  } else {
   HEAP32[$18>>2] = $9;
   $$pre$i$i$i = HEAP32[$14>>2]|0;
   $21 = $$pre$i$i$i;
  }
  $20 = (($21) + 1)|0;
  HEAP32[$14>>2] = $20;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($10,$0)|0);
 }
 HEAP32[$1>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim20createLowLevelVolumeEjRKNS_9PxBounds3EjNS_9AABBMgrIdE($this,$group,$bounds,$aggregateID,$aabbMgrId) {
 $this = $this|0;
 $group = $group|0;
 $bounds = $bounds|0;
 $aggregateID = $aggregateID|0;
 $aabbMgrId = $aabbMgrId|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $aabbData = 0, $aabbData1 = 0, $localSpaceAABB$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $aabbData = sp + 8|0;
 $aabbData1 = sp;
 $0 = (__ZN5physx2Sc7Element20createLowLevelVolumeEjRKNS_9PxBounds3EjRKNS_9AABBMgrIdE($this,$group,$bounds,$aggregateID,$aabbMgrId)|0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 32|0);
 $4 = (($2) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 if ((($5|0) == 5)) {
  $8 = (($2) + 108|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 128|0);
  $localSpaceAABB$0 = $10;
 } else if ((($5|0) == 4)) {
  $6 = (($2) + 104|0);
  $7 = HEAP32[$6>>2]|0;
  $localSpaceAABB$0 = $7;
 } else if ((($5|0) == 6)) {
  $11 = (($2) + 92|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 40|0);
  $localSpaceAABB$0 = $13;
 } else {
  $localSpaceAABB$0 = 0;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1000|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($15) + 50|0);
 $21 = HEAP8[$20>>0]|0;
 if ((($21<<24>>24) == 1) | (($21<<24>>24) == 4)) {
  HEAP32[$aabbData>>2] = $3;
  $22 = (($aabbData) + 12|0);
  HEAP32[$22>>2] = $localSpaceAABB$0;
  $23 = (($15) + 52|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 16|0);
  $26 = (($aabbData) + 8|0);
  HEAP32[$26>>2] = $25;
  $27 = (($15) + 64|0);
  $28 = (($aabbData) + 4|0);
  HEAP32[$28>>2] = $27;
  $29 = (($19) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($this) + 12|0);
  $32 = $31;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $34 & 1073741823;
  __ZN5physx14PxsAABBManager18setDynamicAABBDataEjRKNS_18PxcAABBDataDynamicE($30,$38,$aabbData);
 } else {
  HEAP32[$aabbData1>>2] = $3;
  $39 = (($15) + 52|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 16|0);
  $42 = (($aabbData1) + 4|0);
  HEAP32[$42>>2] = $41;
  $43 = (($19) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($this) + 12|0);
  $46 = $45;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) + 4)|0;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = $48 & 1073741823;
  __ZN5physx14PxsAABBManager17setStaticAABBDataEjRKNS_17PxcAABBDataStaticE($44,$52,$aabbData1);
 }
 $53 = (($this) + 12|0);
 $54 = $53;
 $55 = $54;
 $56 = HEAP32[$55>>2]|0;
 $57 = (($54) + 4)|0;
 $58 = $57;
 $59 = HEAP32[$58>>2]|0;
 $60 = $59 & 1073741823;
 $61 = (($19) + 5916|0);
 $62 = (($60) + 32)|0;
 $63 = $62 >>> 5;
 $64 = (($19) + 5920|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = $65 & 2147483647;
 $67 = ($63>>>0)>($66>>>0);
 if ($67) {
  $68 = (($19) + 5924|0);
  $69 = $63 << 2;
  $70 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($68,$69,472480,339)|0);
  $71 = HEAP32[$61>>2]|0;
  $72 = ($71|0)==(0|0);
  if (!($72)) {
   $73 = HEAP32[$64>>2]|0;
   $74 = $73 << 2;
   _memcpy(($70|0),($71|0),($74|0))|0;
   $75 = HEAP32[$64>>2]|0;
   $76 = ($75|0)>(-1);
   if ($76) {
    $77 = HEAP32[$61>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($68,$77);
   }
  }
  $78 = HEAP32[$64>>2]|0;
  $79 = $78 & 2147483647;
  $80 = (($70) + ($79<<2)|0);
  $81 = (($63) - ($78))|0;
  $82 = $81 << 2;
  _memset(($80|0),0,($82|0))|0;
  HEAP32[$61>>2] = $70;
  HEAP32[$64>>2] = $63;
  $87 = $70;
 } else {
  $$pre$i$i = HEAP32[$61>>2]|0;
  $87 = $$pre$i$i;
 }
 $83 = $59 & 31;
 $84 = 1 << $83;
 $85 = $60 >>> 5;
 $86 = (($87) + ($85<<2)|0);
 $88 = HEAP32[$86>>2]|0;
 $89 = $88 | $84;
 HEAP32[$86>>2] = $89;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim21destroyLowLevelVolumeEv($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 1073741823;
 $8 = ($7|0)==(1073741823);
 if (!($8)) {
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 1000|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 5916|0);
  $16 = (($7) + 32)|0;
  $17 = $16 >>> 5;
  $18 = (($14) + 5920|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & 2147483647;
  $21 = ($17>>>0)>($20>>>0);
  if ($21) {
   $22 = (($14) + 5924|0);
   $23 = $17 << 2;
   $24 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($22,$23,472480,339)|0);
   $25 = HEAP32[$15>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = HEAP32[$18>>2]|0;
    $28 = $27 << 2;
    _memcpy(($24|0),($25|0),($28|0))|0;
    $29 = HEAP32[$18>>2]|0;
    $30 = ($29|0)>(-1);
    if ($30) {
     $31 = HEAP32[$15>>2]|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($22,$31);
    }
   }
   $32 = HEAP32[$18>>2]|0;
   $33 = $32 & 2147483647;
   $34 = (($24) + ($33<<2)|0);
   $35 = (($17) - ($32))|0;
   $36 = $35 << 2;
   _memset(($34|0),0,($36|0))|0;
   HEAP32[$15>>2] = $24;
   HEAP32[$18>>2] = $17;
   $42 = $24;
  } else {
   $$pre$i$i = HEAP32[$15>>2]|0;
   $42 = $$pre$i$i;
  }
  $37 = $6 & 31;
  $38 = 1 << $37;
  $39 = $38 ^ -1;
  $40 = $7 >>> 5;
  $41 = (($42) + ($40<<2)|0);
  $43 = HEAP32[$41>>2]|0;
  $44 = $43 & $39;
  HEAP32[$41>>2] = $44;
 }
 $45 = (__ZN5physx2Sc7Element21destroyLowLevelVolumeEv($this)|0);
 if (!($45)) {
  STACKTOP = sp;return ($45|0);
 }
 $46 = (($this) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 50|0);
 $49 = HEAP8[$48>>0]|0;
 if (!((($49<<24>>24) == 1) | (($49<<24>>24) == 4))) {
  STACKTOP = sp;return ($45|0);
 }
 $50 = ($47|0)==(0|0);
 if ($50) {
  STACKTOP = sp;return ($45|0);
 }
 $51 = (($47) + 132|0);
 HEAP32[$51>>2] = (1073741823);
 $52 = (($47) + 136|0);
 HEAP32[$52>>2] = (1073741823);
 STACKTOP = sp;return ($45|0);
}
function __ZNK5physx2Sc8ShapeSim10getBodySimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 50|0);
 $3 = HEAP8[$2>>0]|0;
 if ((($3<<24>>24) == 1) | (($3<<24>>24) == 4)) {
  $4 = $1;
 } else {
  $4 = 0;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx2Sc8ShapeSim20removeFromBroadPhaseEb($this,$wakeOnLostTouch) {
 $this = $this|0;
 $wakeOnLostTouch = $wakeOnLostTouch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $3 & 1073741823;
 $8 = ($7|0)==(1073741823);
 $9 = (0)==(0);
 $10 = $8 & $9;
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1008|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN5physx2Sc5Scene22removeBroadPhaseVolumeEbRNS0_8ShapeSimE($16,$wakeOnLostTouch,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim18reinsertBroadPhaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1008|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc5Scene22removeBroadPhaseVolumeEbRNS0_8ShapeSimE($6,1,$this);
 $7 = HEAP32[$1>>2]|0;
 $8 = (($7) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1008|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNK5physx2Sc8ShapeSim18computeWorldBoundsERKNS0_9ShapeCoreERKNS0_8RigidSimE($0,0,$13,$7);
 __ZN5physx2Sc5Scene19addBroadPhaseVolumeERKNS_9PxBounds3ERNS0_8ShapeSimE($11,$0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim18onFilterDataChangeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc10ElementSim27setElementInteractionsDirtyENS0_15CoreInteraction9DirtyFlagEh($this,1,4);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim16onResetFilteringEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $4 & 1073741823;
 $9 = ($8|0)==(1073741823);
 $10 = (0)==(0);
 $11 = $9 & $10;
 if (!($11)) {
  $12 = (($this) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 36|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 1008|0);
  $17 = HEAP32[$16>>2]|0;
  __ZN5physx2Sc5Scene22removeBroadPhaseVolumeEbRNS0_8ShapeSimE($17,1,$this);
 }
 $18 = (($this) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 64|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21 & 5;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1008|0);
 $29 = HEAP32[$28>>2]|0;
 __ZNK5physx2Sc8ShapeSim18computeWorldBoundsERKNS0_9ShapeCoreERKNS0_8RigidSimE($0,0,$19,$25);
 __ZN5physx2Sc5Scene19addBroadPhaseVolumeERKNS_9PxBounds3ERNS0_8ShapeSimE($29,$0,$this);
 $30 = HEAP32[$24>>2]|0;
 $31 = (($30) + 50|0);
 $32 = HEAP8[$31>>0]|0;
 if (!((($32<<24>>24) == 1) | (($32<<24>>24) == 4))) {
  STACKTOP = sp;return;
 }
 $33 = ($30|0)==(0|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 if ((($32<<24>>24) == 1) | (($32<<24>>24) == 4)) {
  $41 = $30;
 } else {
  $41 = 0;
 }
 $34 = $1;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($41) + 132|0);
 $42 = $36 & 1073741823;
 $43 = $39 & 1073741823;
 $44 = $40;
 $45 = $44;
 HEAP32[$45>>2] = $42;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim16onMaterialChangeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc10ElementSim27setElementInteractionsDirtyENS0_15CoreInteraction9DirtyFlagEh($this,2,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim18onRestOffsetChangeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc10ElementSim27setElementInteractionsDirtyENS0_15CoreInteraction9DirtyFlagEh($this,16,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim12onFlagChangeENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE($this,$oldFlags) {
 $this = $this|0;
 $oldFlags = $oldFlags|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 64|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = HEAP8[$oldFlags>>0]|0;
 $6 = $5 ^ $4;
 $7 = $6 & 4;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $10 = $5;
 } else {
  __ZN5physx2Sc10ElementSim27setElementInteractionsDirtyENS0_15CoreInteraction9DirtyFlagEh($this,1,4);
  $$pre = HEAP8[$oldFlags>>0]|0;
  $10 = $$pre;
 }
 $9 = $10 & 5;
 $11 = ($9<<24>>24)!=(0);
 $12 = $4 & 5;
 $13 = ($12<<24>>24)==(0);
 $or$cond = $11 | $13;
 if ($or$cond) {
  $or$cond1 = $11 & $13;
  if (!($or$cond1)) {
   STACKTOP = sp;return;
  }
  $40 = (($this) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 36|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 1008|0);
  $45 = HEAP32[$44>>2]|0;
  __ZN5physx2Sc5Scene22removeBroadPhaseVolumeEbRNS0_8ShapeSimE($45,1,$this);
  STACKTOP = sp;return;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1008|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$1>>2]|0;
 __ZNK5physx2Sc8ShapeSim18computeWorldBoundsERKNS0_9ShapeCoreERKNS0_8RigidSimE($0,0,$20,$15);
 __ZN5physx2Sc5Scene19addBroadPhaseVolumeERKNS_9PxBounds3ERNS0_8ShapeSimE($19,$0,$this);
 $21 = HEAP32[$14>>2]|0;
 $22 = (($21) + 50|0);
 $23 = HEAP8[$22>>0]|0;
 if (!((($23<<24>>24) == 1) | (($23<<24>>24) == 4))) {
  STACKTOP = sp;return;
 }
 $24 = ($21|0)==(0|0);
 if ($24) {
  STACKTOP = sp;return;
 }
 if ((($23<<24>>24) == 1) | (($23<<24>>24) == 4)) {
  $33 = $21;
 } else {
  $33 = 0;
 }
 $25 = (($this) + 12|0);
 $26 = $25;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($33) + 132|0);
 $34 = $28 & 1073741823;
 $35 = $31 & 1073741823;
 $36 = $32;
 $37 = $36;
 HEAP32[$37>>2] = $34;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = $35;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8ShapeSim13getFilterInfoERjRNS_12PxFilterDataE($this,$filterAttr,$filterData) {
 $this = $this|0;
 $filterAttr = $filterAttr|0;
 $filterData = $filterData|0;
 var $$ = 0, $$lobit$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$filterAttr>>2] = 0;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 64|0);
 $3 = HEAP8[$2>>0]|0;
 $$lobit$i = $3 & 4;
 $4 = ($$lobit$i<<24>>24)==(0);
 $$ = $4 ? 0 : 32;
 HEAP32[$filterAttr>>2] = $$;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 50|0);
 $8 = HEAP8[$7>>0]|0;
 do {
  if ((($8<<24>>24) == 1) | (($8<<24>>24) == 4)) {
   $9 = ($6|0)==(0|0);
   if (!($9)) {
    $10 = ($8<<24>>24)==(4);
    if ($10) {
     $20 = $$ | 4;
     HEAP32[$filterAttr>>2] = $20;
     break;
    }
    $11 = (($6) + 52|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 44|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = $14 & 1;
    $16 = ($15<<24>>24)==(0);
    if ($16) {
     $19 = $$;
    } else {
     $17 = $$ | 16;
     HEAP32[$filterAttr>>2] = $17;
     $19 = $17;
    }
    $18 = $19 | 1;
    HEAP32[$filterAttr>>2] = $18;
   }
  }
 } while(0);
 $21 = HEAP32[$0>>2]|0;
 $22 = (($21) + 16|0);
 ;HEAP32[$filterData+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$filterData+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$filterData+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$filterData+12>>2]=HEAP32[$22+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8ShapeSim8getRbSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Sc8ShapeSim15getPxsRigidCoreEv($this) {
 $this = $this|0;
 var $$in = 0, $$pn = 0, $$pn$in$in = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $$pn$in$in = (($1) + 52|0);
 $$pn = HEAP32[$$pn$in$in>>2]|0;
 $$in = (($$pn) + 16|0);
 STACKTOP = sp;return ($$in|0);
}
function __ZNK5physx2Sc8ShapeSim14actorIsDynamicEv($this) {
 $this = $this|0;
 var $$$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 50|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(1);
 $5 = ($3<<24>>24)==(4);
 $$$i = $4 | $5;
 STACKTOP = sp;return ($$$i|0);
}
function __ZN5physx2Cm27getDynamicGlobalPoseAlignedERKNS_11PxTransformES3_S3_RS1_($body2World,$shape2Actor,$body2Actor,$outTransform) {
 $body2World = $body2World|0;
 $shape2Actor = $shape2Actor|0;
 $body2Actor = $body2Actor|0;
 $outTransform = $outTransform|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0;
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape2Actor) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($shape2Actor) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($shape2Actor) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$shape2Actor>>2]);
 $7 = (($shape2Actor) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($shape2Actor) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($shape2Actor) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($body2Actor) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($body2Actor) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($body2Actor) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(HEAPF32[$body2Actor>>2]);
 $20 = (($body2Actor) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($body2Actor) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($body2Actor) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($body2World) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($body2World) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($body2World) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(HEAPF32[$body2World>>2]);
 $33 = (($body2World) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($body2World) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($body2World) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($6 * $19);
 $40 = Math_fround($8 * $21);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($10 * $23);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($12 * $25);
 $45 = Math_fround($44 + $43);
 $46 = Math_fround($8 * $23);
 $47 = Math_fround($10 * $21);
 $48 = Math_fround($46 - $47);
 $49 = Math_fround($10 * $19);
 $50 = Math_fround($6 * $23);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($6 * $21);
 $53 = Math_fround($8 * $19);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($6 * $25);
 $56 = Math_fround($8 * $25);
 $57 = Math_fround($10 * $25);
 $58 = Math_fround($55 + $48);
 $59 = Math_fround($56 + $51);
 $60 = Math_fround($54 + $57);
 $61 = Math_fround($12 * $19);
 $62 = Math_fround($12 * $21);
 $63 = Math_fround($12 * $23);
 $64 = Math_fround($58 - $61);
 $65 = Math_fround($59 - $62);
 $66 = Math_fround($60 - $63);
 $67 = Math_fround($1 - $14);
 $68 = Math_fround($3 - $16);
 $69 = Math_fround($5 - $18);
 $70 = Math_fround($25 * $25);
 $71 = Math_fround($70 + Math_fround(-0.5));
 $72 = Math_fround($67 * $71);
 $73 = Math_fround($68 * $71);
 $74 = Math_fround($69 * $71);
 $75 = Math_fround($68 * $23);
 $76 = Math_fround($69 * $21);
 $77 = Math_fround($75 - $76);
 $78 = Math_fround($69 * $19);
 $79 = Math_fround($67 * $23);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($67 * $21);
 $82 = Math_fround($68 * $19);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($25 * $77);
 $85 = Math_fround($25 * $80);
 $86 = Math_fround($83 * $25);
 $87 = Math_fround($84 + $72);
 $88 = Math_fround($85 + $73);
 $89 = Math_fround($86 + $74);
 $90 = Math_fround($67 * $19);
 $91 = Math_fround($68 * $21);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($69 * $23);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($19 * $94);
 $96 = Math_fround($21 * $94);
 $97 = Math_fround($23 * $94);
 $98 = Math_fround($95 + $87);
 $99 = Math_fround($96 + $88);
 $100 = Math_fround($97 + $89);
 $101 = Math_fround($98 + $98);
 $102 = Math_fround($99 + $99);
 $103 = Math_fround($100 + $100);
 $104 = Math_fround($45 * $38);
 $105 = Math_fround($64 * $32);
 $106 = Math_fround($65 * $34);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($66 * $36);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($104 - $109);
 $111 = Math_fround($66 * $34);
 $112 = Math_fround($65 * $36);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($64 * $36);
 $115 = Math_fround($66 * $32);
 $116 = Math_fround($114 - $115);
 $117 = Math_fround($65 * $32);
 $118 = Math_fround($64 * $34);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($64 * $38);
 $121 = Math_fround($65 * $38);
 $122 = Math_fround($66 * $38);
 $123 = Math_fround($120 + $113);
 $124 = Math_fround($121 + $116);
 $125 = Math_fround($119 + $122);
 $126 = Math_fround($45 * $32);
 $127 = Math_fround($45 * $34);
 $128 = Math_fround($45 * $36);
 $129 = Math_fround($126 + $123);
 $130 = Math_fround($127 + $124);
 $131 = Math_fround($128 + $125);
 $132 = Math_fround($38 * $38);
 $133 = Math_fround($132 + Math_fround(-0.5));
 $134 = Math_fround($101 * $133);
 $135 = Math_fround($102 * $133);
 $136 = Math_fround($103 * $133);
 $137 = Math_fround($34 * $103);
 $138 = Math_fround($36 * $102);
 $139 = Math_fround($137 - $138);
 $140 = Math_fround($36 * $101);
 $141 = Math_fround($32 * $103);
 $142 = Math_fround($140 - $141);
 $143 = Math_fround($32 * $102);
 $144 = Math_fround($34 * $101);
 $145 = Math_fround($143 - $144);
 $146 = Math_fround($38 * $139);
 $147 = Math_fround($38 * $142);
 $148 = Math_fround($38 * $145);
 $149 = Math_fround($146 + $134);
 $150 = Math_fround($147 + $135);
 $151 = Math_fround($148 + $136);
 $152 = Math_fround($32 * $101);
 $153 = Math_fround($34 * $102);
 $154 = Math_fround($152 + $153);
 $155 = Math_fround($36 * $103);
 $156 = Math_fround($155 + $154);
 $157 = Math_fround($32 * $156);
 $158 = Math_fround($34 * $156);
 $159 = Math_fround($36 * $156);
 $160 = Math_fround($157 + $149);
 $161 = Math_fround($158 + $150);
 $162 = Math_fround($159 + $151);
 $163 = Math_fround($160 * Math_fround(2.0));
 $164 = Math_fround($161 * Math_fround(2.0));
 $165 = Math_fround($162 * Math_fround(2.0));
 $166 = Math_fround($27 + $163);
 $167 = Math_fround($29 + $164);
 $168 = Math_fround($31 + $165);
 $169 = (($outTransform) + 16|0);
 HEAPF32[$169>>2] = $166;
 $170 = (($outTransform) + 20|0);
 HEAPF32[$170>>2] = $167;
 $171 = (($outTransform) + 24|0);
 HEAPF32[$171>>2] = $168;
 HEAPF32[$outTransform>>2] = $129;
 $172 = (($outTransform) + 4|0);
 HEAPF32[$172>>2] = $130;
 $173 = (($outTransform) + 8|0);
 HEAPF32[$173>>2] = $131;
 $174 = (($outTransform) + 12|0);
 HEAPF32[$174>>2] = $110;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim17onTransformChangeEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$in$i = 0, $$pn$i = 0, $$pn$in$in$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01 = 0, $i$01$us = 0, $iter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 12|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 1073741823;
 $12 = ($11|0)==(1073741823);
 if ($12) {
  $48 = $1;
 } else {
  $13 = (($3) + 1000|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 5916|0);
  $16 = (($11) + 32)|0;
  $17 = $16 >>> 5;
  $18 = (($14) + 5920|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & 2147483647;
  $21 = ($17>>>0)>($20>>>0);
  if ($21) {
   $22 = (($14) + 5924|0);
   $23 = $17 << 2;
   $24 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($22,$23,472480,339)|0);
   $25 = HEAP32[$15>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = HEAP32[$18>>2]|0;
    $28 = $27 << 2;
    _memcpy(($24|0),($25|0),($28|0))|0;
    $29 = HEAP32[$18>>2]|0;
    $30 = ($29|0)>(-1);
    if ($30) {
     $31 = HEAP32[$15>>2]|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($22,$31);
    }
   }
   $32 = HEAP32[$18>>2]|0;
   $33 = $32 & 2147483647;
   $34 = (($24) + ($33<<2)|0);
   $35 = (($17) - ($32))|0;
   $36 = $35 << 2;
   _memset(($34|0),0,($36|0))|0;
   HEAP32[$15>>2] = $24;
   HEAP32[$18>>2] = $17;
   $$pre2 = HEAP32[$13>>2]|0;
   $41 = $24;$45 = $$pre2;
  } else {
   $$pre$i$i = HEAP32[$15>>2]|0;
   $41 = $$pre$i$i;$45 = $14;
  }
  $37 = $10 & 31;
  $38 = 1 << $37;
  $39 = $11 >>> 5;
  $40 = (($41) + ($39<<2)|0);
  $42 = HEAP32[$40>>2]|0;
  $43 = $42 | $38;
  HEAP32[$40>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = HEAP32[$44>>2]|0;
  __ZN5physx14PxsAABBManager13setActorDirtyEj($46,$11);
  $$pre = HEAP32[$0>>2]|0;
  $48 = $$pre;
 }
 $47 = (($48) + 51|0);
 $49 = HEAP8[$47>>0]|0;
 $50 = (($48) + 20|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($48) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($51) + ($53<<2)|0);
 $55 = $51;
 $56 = $54;
 $57 = $iter;
 $58 = $57;
 HEAP32[$58>>2] = $55;
 $59 = (($57) + 4)|0;
 $60 = $59;
 HEAP32[$60>>2] = $56;
 $61 = (($iter) + 8|0);
 HEAP32[$61>>2] = $this;
 $62 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter)|0);
 $63 = ($62|0)==(0|0);
 L12: do {
  if (!($63)) {
   $64 = $49 & 1;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    $i$01$us = $62;
   } else {
    $i$01 = $62;
    while(1) {
     $90 = (($i$01) + 20|0);
     $91 = HEAP8[$90>>0]|0;
     $92 = $91&255;
     if ((($92|0) == 0)) {
      $93 = (($i$01) + -8|0);
      $94 = (($93) + 56|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = ($95|0)==(0|0);
      if (!($96)) {
       __ZN5physx17PxsContactManager16resetCachedStateEv($95);
      }
     } else if ((($92|0) == 4)) {
      $105 = (($i$01) + -8|0);
      $106 = (($105) + 32|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($107)|0);
      $109 = HEAP32[$106>>2]|0;
      $110 = (($105) + 36|0);
      $111 = HEAP32[$110>>2]|0;
      __ZN5physx2Sc17ParticleSystemSim15onRbShapeChangeERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimE($108,$109,$111);
     } else if ((($92|0) == 2)) {
      $97 = (($i$01) + -8|0);
      $98 = (($97) + 56|0);
      $99 = HEAP16[$98>>1]|0;
      $100 = $99&65535;
      $101 = $100 | 32;
      $102 = $101&65535;
      HEAP16[$98>>1] = $102;
      $103 = (($97) + 8|0);
      $104 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($3,$103)|0);
      if (!($104)) {
       __ZN5physx2Sc16InteractionScene26notifyInteractionActivatedEPNS0_11InteractionE($3,$103);
      }
     }
     $112 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter)|0);
     $113 = ($112|0)==(0|0);
     if ($113) {
      break L12;
     } else {
      $i$01 = $112;
     }
    }
   }
   while(1) {
    $66 = (($i$01$us) + 20|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67&255;
    if ((($68|0) == 4)) {
     $69 = (($i$01$us) + -8|0);
     $70 = (($69) + 32|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($71)|0);
     $73 = HEAP32[$70>>2]|0;
     $74 = (($69) + 36|0);
     $75 = HEAP32[$74>>2]|0;
     __ZN5physx2Sc17ParticleSystemSim15onRbShapeChangeERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimE($72,$73,$75);
    } else if ((($68|0) == 2)) {
     $76 = (($i$01$us) + -8|0);
     $77 = (($76) + 56|0);
     $78 = HEAP16[$77>>1]|0;
     $79 = $78&65535;
     $80 = $79 | 32;
     $81 = $80&65535;
     HEAP16[$77>>1] = $81;
     $82 = (($76) + 8|0);
     $83 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($3,$82)|0);
     if (!($83)) {
      __ZN5physx2Sc16InteractionScene26notifyInteractionActivatedEPNS0_11InteractionE($3,$82);
     }
    } else if ((($68|0) == 0)) {
     $84 = (($i$01$us) + -8|0);
     $85 = (($84) + 56|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86|0)==(0|0);
     if (!($87)) {
      __ZN5physx17PxsContactManager16resetCachedStateEv($86);
     }
     __ZN5physx2Sc19ShapeInstancePairLL26onPoseChangedWhileSleepingEv($84);
    }
    $88 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter)|0);
    $89 = ($88|0)==(0|0);
    if ($89) {
     break;
    } else {
     $i$01$us = $88;
    }
   }
  }
 } while(0);
 $114 = HEAP32[$0>>2]|0;
 $115 = (($114) + 36|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($116) + 1000|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = (($this) + 28|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = (($120) + 32|0);
 $$pn$in$in$i = (($114) + 52|0);
 $$pn$i = HEAP32[$$pn$in$in$i>>2]|0;
 $$in$i = (($$pn$i) + 16|0);
 $122 = (($114) + 50|0);
 $123 = HEAP8[$122>>0]|0;
 $124 = ($123<<24>>24)==(1);
 $125 = ($123<<24>>24)==(4);
 $$$i$i = $124 | $125;
 __ZN5physx10PxsContext13onShapeChangeERKNS_12PxsShapeCoreERKNS_12PxsRigidCoreEb($118,$121,$$in$i,$$$i$i);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ShapeSim16onGeometryChangeEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$in$i = 0, $$pn$i = 0, $$pn$in$in$i = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $i$01 = 0;
 var $iter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iter = sp;
 $0 = (($this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 1073741823;
 $8 = ($7|0)==(1073741823);
 $$pre = (($this) + 8|0);
 if (!($8)) {
  $9 = HEAP32[$$pre>>2]|0;
  $10 = (($9) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 1000|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 5916|0);
  $15 = (($7) + 32)|0;
  $16 = $15 >>> 5;
  $17 = (($13) + 5920|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 2147483647;
  $20 = ($16>>>0)>($19>>>0);
  if ($20) {
   $21 = (($13) + 5924|0);
   $22 = $16 << 2;
   $23 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($21,$22,472480,339)|0);
   $24 = HEAP32[$14>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = HEAP32[$17>>2]|0;
    $27 = $26 << 2;
    _memcpy(($23|0),($24|0),($27|0))|0;
    $28 = HEAP32[$17>>2]|0;
    $29 = ($28|0)>(-1);
    if ($29) {
     $30 = HEAP32[$14>>2]|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($21,$30);
    }
   }
   $31 = HEAP32[$17>>2]|0;
   $32 = $31 & 2147483647;
   $33 = (($23) + ($32<<2)|0);
   $34 = (($16) - ($31))|0;
   $35 = $34 << 2;
   _memset(($33|0),0,($35|0))|0;
   HEAP32[$14>>2] = $23;
   HEAP32[$17>>2] = $16;
   $40 = $23;
  } else {
   $$pre$i$i = HEAP32[$14>>2]|0;
   $40 = $$pre$i$i;
  }
  $36 = $6 & 31;
  $37 = 1 << $36;
  $38 = $7 >>> 5;
  $39 = (($40) + ($38<<2)|0);
  $41 = HEAP32[$39>>2]|0;
  $42 = $41 | $37;
  HEAP32[$39>>2] = $42;
  $43 = HEAP32[$$pre>>2]|0;
  $44 = (($43) + 36|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 1000|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + 8|0);
  $49 = HEAP32[$48>>2]|0;
  __ZN5physx14PxsAABBManager13setActorDirtyEj($49,$7);
 }
 $50 = HEAP32[$$pre>>2]|0;
 $51 = (($50) + 20|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 28|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($52) + ($54<<2)|0);
 $56 = $52;
 $57 = $55;
 $58 = $iter;
 $59 = $58;
 HEAP32[$59>>2] = $56;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $57;
 $62 = (($iter) + 8|0);
 HEAP32[$62>>2] = $this;
 $63 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter)|0);
 $64 = ($63|0)==(0|0);
 if ($64) {
  $81 = HEAP32[$$pre>>2]|0;
  $82 = (($81) + 36|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + 1000|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($this) + 28|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (($87) + 32|0);
  $$pn$in$in$i = (($81) + 52|0);
  $$pn$i = HEAP32[$$pn$in$in$i>>2]|0;
  $$in$i = (($$pn$i) + 16|0);
  $89 = (($81) + 50|0);
  $90 = HEAP8[$89>>0]|0;
  $91 = ($90<<24>>24)==(1);
  $92 = ($90<<24>>24)==(4);
  $$$i$i = $91 | $92;
  __ZN5physx10PxsContext13onShapeChangeERKNS_12PxsShapeCoreERKNS_12PxsRigidCoreEb($85,$88,$$in$i,$$$i$i);
  STACKTOP = sp;return;
 } else {
  $i$01 = $63;
 }
 while(1) {
  $65 = (($i$01) + 20|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  if ((($67|0) == 0)) {
   $75 = (($i$01) + -8|0);
   $76 = (($75) + 56|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    __ZN5physx17PxsContactManager16resetCachedStateEv($77);
   }
  } else if ((($67|0) == 4)) {
   $68 = (($i$01) + -8|0);
   $69 = (($68) + 32|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($70)|0);
   $72 = HEAP32[$69>>2]|0;
   $73 = (($68) + 36|0);
   $74 = HEAP32[$73>>2]|0;
   __ZN5physx2Sc17ParticleSystemSim15onRbShapeChangeERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimE($71,$72,$74);
  }
  $79 = (__ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($iter)|0);
  $80 = ($79|0)==(0|0);
  if ($80) {
   break;
  } else {
   $i$01 = $79;
  }
 }
 $81 = HEAP32[$$pre>>2]|0;
 $82 = (($81) + 36|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($83) + 1000|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($this) + 28|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($87) + 32|0);
 $$pn$in$in$i = (($81) + 52|0);
 $$pn$i = HEAP32[$$pn$in$in$i>>2]|0;
 $$in$i = (($$pn$i) + 16|0);
 $89 = (($81) + 50|0);
 $90 = HEAP8[$89>>0]|0;
 $91 = ($90<<24>>24)==(1);
 $92 = ($90<<24>>24)==(4);
 $$$i$i = $91 | $92;
 __ZN5physx10PxsContext13onShapeChangeERKNS_12PxsShapeCoreERKNS_12PxsRigidCoreEb($85,$88,$$in$i,$$$i$i);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8SimStatsC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _memset(($this|0),0,188)|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8SimStats8simStartEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 dest=$this+0|0; src=$0+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $1 = (($this) + 12|0);
 $2 = (($this) + 36|0);
 dest=$1+0|0; src=$2+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $3 = (($this) + 24|0);
 _memset(($3|0),0,164)|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8SimStats7readOutERNS_22PxSimulationStatisticsERKNS_11PxvSimStatsE($this,$s,$simStats) {
 $this = $this|0;
 $s = $s|0;
 $simStats = $simStats|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond11 = 0, $exitcond16 = 0, $i$07 = 0, $i2$02 = 0;
 var $j3$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 896|0;
 $0 = sp;
 __ZN5physx22PxSimulationStatisticsC2Ev($0);
 _memcpy(($s|0),($0|0),888)|0;
 $i$07 = 0;
 while(1) {
  $1 = ((($this) + (($i$07*28)|0)|0) + 48|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ((($s) + (($i$07*28)|0)|0) + 676|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($2))|0;
  HEAP32[$3>>2] = $5;
  $6 = ($i$07|0)==(0);
  if (!($6)) {
   $24 = HEAP32[$1>>2]|0;
   $25 = ((($s) + ($i$07<<2)|0) + 676|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + ($24))|0;
   HEAP32[$25>>2] = $27;
  }
  $28 = ((($this) + (($i$07*28)|0)|0) + 52|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($s) + (($i$07*28)|0)|0) + 680|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + ($29))|0;
  HEAP32[$30>>2] = $32;
  $33 = ($i$07|0)==(1);
  if (!($33)) {
   $82 = HEAP32[$28>>2]|0;
   $83 = ((($s) + ($i$07<<2)|0) + 704|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($84) + ($82))|0;
   HEAP32[$83>>2] = $85;
  }
  $86 = ((($this) + (($i$07*28)|0)|0) + 56|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ((($s) + (($i$07*28)|0)|0) + 684|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (($89) + ($87))|0;
  HEAP32[$88>>2] = $90;
  $91 = ($i$07|0)==(2);
  if (!($91)) {
   $92 = HEAP32[$86>>2]|0;
   $93 = ((($s) + ($i$07<<2)|0) + 732|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + ($92))|0;
   HEAP32[$93>>2] = $95;
  }
  $96 = ((($this) + (($i$07*28)|0)|0) + 60|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = ((($s) + (($i$07*28)|0)|0) + 688|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = (($99) + ($97))|0;
  HEAP32[$98>>2] = $100;
  $101 = ($i$07|0)==(3);
  if (!($101)) {
   $102 = HEAP32[$96>>2]|0;
   $103 = ((($s) + ($i$07<<2)|0) + 760|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = (($104) + ($102))|0;
   HEAP32[$103>>2] = $105;
  }
  $106 = ((($this) + (($i$07*28)|0)|0) + 64|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ((($s) + (($i$07*28)|0)|0) + 692|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($109) + ($107))|0;
  HEAP32[$108>>2] = $110;
  $111 = ($i$07|0)==(4);
  if (!($111)) {
   $112 = HEAP32[$106>>2]|0;
   $113 = ((($s) + ($i$07<<2)|0) + 788|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = (($114) + ($112))|0;
   HEAP32[$113>>2] = $115;
  }
  $116 = ((($this) + (($i$07*28)|0)|0) + 68|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = ((($s) + (($i$07*28)|0)|0) + 696|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = (($119) + ($117))|0;
  HEAP32[$118>>2] = $120;
  $121 = HEAP32[$116>>2]|0;
  $122 = ((($s) + ($i$07<<2)|0) + 816|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = (($123) + ($121))|0;
  HEAP32[$122>>2] = $124;
  $125 = ((($this) + (($i$07*28)|0)|0) + 72|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ((($s) + (($i$07*28)|0)|0) + 700|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (($128) + ($126))|0;
  HEAP32[$127>>2] = $129;
  $130 = HEAP32[$125>>2]|0;
  $131 = ((($s) + ($i$07<<2)|0) + 844|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = (($132) + ($130))|0;
  HEAP32[$131>>2] = $133;
  $134 = (($i$07) + 1)|0;
  $exitcond16 = ($134|0)==(5);
  if ($exitcond16) {
   break;
  } else {
   $i$07 = $134;
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($s) + 64|0);
 HEAP32[$8>>2] = $7;
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($s) + 76|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($s) + 68|0);
 HEAP32[$14>>2] = $13;
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($s) + 80|0);
 HEAP32[$17>>2] = $16;
 $18 = (($this) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($s) + 72|0);
 HEAP32[$20>>2] = $19;
 $21 = (($this) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($s) + 84|0);
 HEAP32[$23>>2] = $22;
 $i2$02 = 0;
 while(1) {
  $35 = ((($simStats) + (($i2$02*28)|0)|0) + ($i2$02<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (((($s) + (($i2$02*28)|0)|0) + ($i2$02<<2)|0) + 88|0);
  HEAP32[$37>>2] = $36;
  $38 = (((($simStats) + (($i2$02*28)|0)|0) + ($i2$02<<2)|0) + 392|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (((($s) + (($i2$02*28)|0)|0) + ($i2$02<<2)|0) + 480|0);
  HEAP32[$40>>2] = $39;
  $41 = (((($simStats) + (($i2$02*28)|0)|0) + ($i2$02<<2)|0) + 196|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (((($s) + (($i2$02*28)|0)|0) + ($i2$02<<2)|0) + 284|0);
  HEAP32[$43>>2] = $42;
  $34 = (($i2$02) + 1)|0;
  $44 = ($34>>>0)<(7);
  if ($44) {
   $j3$01 = $34;
   while(1) {
    $45 = ((($simStats) + (($i2$02*28)|0)|0) + ($j3$01<<2)|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (((($s) + (($i2$02*28)|0)|0) + ($j3$01<<2)|0) + 88|0);
    HEAP32[$47>>2] = $46;
    $48 = (((($s) + (($j3$01*28)|0)|0) + ($i2$02<<2)|0) + 88|0);
    HEAP32[$48>>2] = $46;
    $49 = (((($simStats) + (($i2$02*28)|0)|0) + ($j3$01<<2)|0) + 392|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (((($s) + (($i2$02*28)|0)|0) + ($j3$01<<2)|0) + 480|0);
    HEAP32[$51>>2] = $50;
    $52 = (((($s) + (($j3$01*28)|0)|0) + ($i2$02<<2)|0) + 480|0);
    HEAP32[$52>>2] = $50;
    $53 = (((($simStats) + (($i2$02*28)|0)|0) + ($j3$01<<2)|0) + 196|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (((($s) + (($i2$02*28)|0)|0) + ($j3$01<<2)|0) + 284|0);
    HEAP32[$55>>2] = $54;
    $56 = (((($s) + (($j3$01*28)|0)|0) + ($i2$02<<2)|0) + 284|0);
    HEAP32[$56>>2] = $54;
    $57 = (($j3$01) + 1)|0;
    $exitcond = ($57|0)==(7);
    if ($exitcond) {
     break;
    } else {
     $j3$01 = $57;
    }
   }
  }
  $exitcond11 = ($34|0)==(7);
  if ($exitcond11) {
   break;
  } else {
   $i2$02 = $34;
  }
 }
 $58 = (($simStats) + 588|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($s) + 872|0);
 HEAP32[$60>>2] = $59;
 $61 = (($simStats) + 592|0);
 $62 = HEAP32[$61>>2]|0;
 HEAP32[$s>>2] = $62;
 $63 = (($simStats) + 596|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($s) + 4|0);
 HEAP32[$65>>2] = $64;
 $66 = (($simStats) + 600|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($s) + 8|0);
 HEAP32[$68>>2] = $67;
 $69 = (($simStats) + 604|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($s) + 48|0);
 HEAP32[$71>>2] = $70;
 $72 = (($simStats) + 616|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73 << 14;
 $75 = (($s) + 60|0);
 HEAP32[$75>>2] = $74;
 $76 = (($simStats) + 608|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($s) + 52|0);
 HEAP32[$78>>2] = $77;
 $79 = (($simStats) + 612|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($s) + 56|0);
 HEAP32[$81>>2] = $80;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc10StaticCore6getSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc10StaticCore14setActor2WorldERKNS_11PxTransformE($this,$actor2World) {
 $this = $this|0;
 $actor2World = $actor2World|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$actor2World>>2]);
 $1 = (($this) + 16|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($actor2World) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 20|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($actor2World) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 24|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($actor2World) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 28|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($actor2World) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 32|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($actor2World) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 36|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($actor2World) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 40|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($this) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc9StaticSim21postActor2WorldChangeEv($21);
 STACKTOP = sp;return;
}
function __Z34ScGetPxRigidStaticFromPxsRigidCorePKN5physx12PxsRigidCoreE($core) {
 $core = $core|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($core) + -16|0);
 $1 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc9StaticSimC2ERNS0_5SceneERNS0_10StaticCoreE($this,$scene,$core) {
 $this = $this|0;
 $scene = $scene|0;
 $core = $core|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc8RigidSimC2ERNS0_5SceneERNS0_9RigidCoreENS0_14IslandNodeInfo4TypeE($this,$scene,$core,8);
 HEAP32[$this>>2] = ((472552 + 8|0));
 $0 = (($scene) + 1212|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc16InteractionScene8addActorERNS0_5ActorEb($1,$this,0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9StaticSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((472552 + 8|0));
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx2Sc16InteractionScene11removeActorERNS0_5ActorE($2,$this);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 HEAP32[$5>>2] = 0;
 __ZN5physx2Sc8RigidSimD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9StaticSimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((472552 + 8|0));
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc16InteractionScene11removeActorERNS0_5ActorE($1,$this);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 HEAP32[$4>>2] = 0;
 __ZN5physx2Sc8RigidSimD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9StaticSim21postActor2WorldChangeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $iterator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $iterator = sp + 28|0;
 $0 = sp;
 __ZN5physx2Sc8RigidSim25notifyShapeTranformChangeEv($this);
 $1 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $2 = (($1) + 1212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1000|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$iterator>>2] = 0;
 __ZN5physx2Sc13ShapeIterator4initERKNS0_8ActorSimE($iterator,$this);
 $6 = (__ZN5physx2Sc13ShapeIterator7getNextEv($iterator)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($5) + 7400|0);
 $9 = (($0) + 4|0);
 $10 = (($0) + 8|0);
 $11 = (($0) + 12|0);
 $12 = (($0) + 16|0);
 $13 = (($0) + 20|0);
 $14 = (($0) + 24|0);
 $16 = $6;
 while(1) {
  $15 = (($16) + 24|0);
  $17 = HEAP32[$15>>2]|0;
  $18 = ($17|0)==(-1);
  if (!($18)) {
   __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($0,$16);
   $19 = HEAP32[$15>>2]|0;
   $20 = HEAP32[$8>>2]|0;
   $21 = Math_fround(HEAPF32[$0>>2]);
   $22 = (($20) + (($19*28)|0)|0);
   HEAPF32[$22>>2] = $21;
   $23 = Math_fround(HEAPF32[$9>>2]);
   $24 = ((($20) + (($19*28)|0)|0) + 4|0);
   HEAPF32[$24>>2] = $23;
   $25 = Math_fround(HEAPF32[$10>>2]);
   $26 = ((($20) + (($19*28)|0)|0) + 8|0);
   HEAPF32[$26>>2] = $25;
   $27 = Math_fround(HEAPF32[$11>>2]);
   $28 = ((($20) + (($19*28)|0)|0) + 12|0);
   HEAPF32[$28>>2] = $27;
   $29 = Math_fround(HEAPF32[$12>>2]);
   $30 = ((($20) + (($19*28)|0)|0) + 16|0);
   HEAPF32[$30>>2] = $29;
   $31 = Math_fround(HEAPF32[$13>>2]);
   $32 = ((($20) + (($19*28)|0)|0) + 20|0);
   HEAPF32[$32>>2] = $31;
   $33 = Math_fround(HEAPF32[$14>>2]);
   $34 = ((($20) + (($19*28)|0)|0) + 24|0);
   HEAPF32[$34>>2] = $33;
  }
  $35 = (__ZN5physx2Sc13ShapeIterator7getNextEv($iterator)|0);
  $36 = ($35|0)==(0|0);
  if ($36) {
   break;
  } else {
   $16 = $35;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18TriggerInteractionD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc18TriggerInteractionD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18TriggerInteractionD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc18TriggerInteractionD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18TriggerInteraction10onActivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 56|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & 32;
 $4 = ($3<<16>>16)==(0);
 if (!($4)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 51|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 51|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)!=(0);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZThn8_N5physx2Sc18TriggerInteraction10onActivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + -8|0);
 $2 = (($1) + 56|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & 32;
 $5 = ($4<<16>>16)==(0);
 if (!($5)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $6 = (($1) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 51|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $12 = (($1) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 51|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)!=(0);
 $$0$i = $17;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx2Sc18TriggerInteraction12onDeactivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 56|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & 32;
 $4 = ($3<<16>>16)==(0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 51|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 51|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14 & 1;
 $phitmp = ($15<<24>>24)==(0);
 $$0 = $phitmp;
 STACKTOP = sp;return ($$0|0);
}
function __ZThn8_N5physx2Sc18TriggerInteraction12onDeactivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + -8|0);
 $2 = (($1) + 56|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & 32;
 $5 = ($4<<16>>16)==(0);
 if (!($5)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $6 = (($1) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 51|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $12 = (($1) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 51|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15 & 1;
 $phitmp$i = ($16<<24>>24)==(0);
 $$0$i = $phitmp$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx2Sc18TriggerInteraction10initializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iii[$3 & 4095]($0,0)|0);
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($8,$0,$4);
 $9 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($9,$0);
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($11,$0);
 $12 = (($this) + 52|0);
 HEAP16[$12>>1] = 0;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc18TriggerInteraction10initializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$4 & 4095]($1,0)|0);
 $6 = (($0) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($9,$1,$5);
 $10 = HEAP32[$6>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($10,$1);
 $11 = (($0) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($12,$1);
 $13 = (($0) + 52|0);
 HEAP16[$13>>1] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18TriggerInteraction7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($2,$0);
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($4,$0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($7,$0);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc18TriggerInteraction7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 $1 = (($0) + 8|0);
 $2 = (($0) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($3,$1);
 $4 = (($0) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($5,$1);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($8,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc35ParticleElementRbElementInteractionC2ERNS0_19ParticlePacketShapeERNS0_8ShapeSimERNS0_16ActorElementPairE($this,$particleShape,$rbShape,$actorElementPair) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 $rbShape = $rbShape|0;
 $actorElementPair = $actorElementPair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((463024 + 8|0));
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 1;
 $2 = (($this) + 8|0);
 $3 = (($particleShape) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($rbShape) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc11InteractionC2ERNS0_5ActorES3_NS0_15InteractionTypeEh($2,$4,$6,4,12);
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $particleShape;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = $rbShape;
 $9 = (($this) + 8|0);
 $10 = (($this) + 40|0);
 HEAP32[$10>>2] = $actorElementPair;
 HEAP32[$this>>2] = ((472664 + 8|0));
 HEAP32[$9>>2] = ((472664 + 52|0));
 $11 = (($this) + 44|0);
 HEAP16[$11>>1] = -1;
 $12 = (($this) + 46|0);
 HEAP8[$12>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc35ParticleElementRbElementInteractionD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc35ParticleElementRbElementInteractionD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc35ParticleElementRbElementInteractionD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc35ParticleElementRbElementInteractionD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc35ParticleElementRbElementInteraction10initializeEj($this,$ccdPass) {
 $this = $this|0;
 $ccdPass = $ccdPass|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iii[$3 & 4095]($0,0)|0);
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($8,$0,$4);
 $9 = HEAP32[$5>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($9,$0);
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($11,$0);
 $12 = (($this) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 36|0);
 $15 = (($13) + 42|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($13) + 40|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = ($16<<16>>16)==($18<<16>>16);
 if ($19) {
  $20 = $16&65535;
  $21 = (($20) + 1)|0;
  $22 = $21&65535;
  __ZN5physx2Sc19ParticlePacketShape19reallocInteractionsERPPNS0_35ParticleElementRbElementInteractionERttt($13,$14,$17,$16,$22);
  $$pre$i$i = HEAP16[$15>>1]|0;
  $$pre$phi$i$iZ2D = $14;$24 = $$pre$i$i;
 } else {
  $$pre$phi$i$iZ2D = $14;$24 = $16;
 }
 $23 = (($24) + 1)<<16>>16;
 HEAP16[$15>>1] = $23;
 $25 = $24&65535;
 $26 = HEAP32[$$pre$phi$i$iZ2D>>2]|0;
 $27 = (($26) + ($25<<2)|0);
 HEAP32[$27>>2] = $this;
 $28 = $23&65535;
 $29 = (($28) + 65535)|0;
 $30 = $29&65535;
 $31 = (($this) + 44|0);
 HEAP16[$31>>1] = $30;
 $32 = (($this) + 46|0);
 HEAP8[$32>>0] = 0;
 $33 = (($this) + 40|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 19|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)==(0);
 if (!($37)) {
  STACKTOP = sp;return;
 }
 $38 = (($this) + 36|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 28|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 64|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43 & 4;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 $46 = HEAP32[$12>>2]|0;
 $47 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($46)|0);
 $48 = HEAP32[$12>>2]|0;
 $49 = HEAP32[$38>>2]|0;
 __ZN5physx2Sc17ParticleSystemSim14addInteractionERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimEj($47,$48,$49,$ccdPass);
 HEAP8[$32>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc35ParticleElementRbElementInteraction7destroyEbj($this,$isDyingRb,$ccdPass) {
 $this = $this|0;
 $isDyingRb = $isDyingRb|0;
 $ccdPass = $ccdPass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 19|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = (($this) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 64|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = $12 & 4;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($1)|0);
   $16 = HEAP32[$0>>2]|0;
   $17 = HEAP32[$7>>2]|0;
   __ZN5physx2Sc17ParticleSystemSim17removeInteractionERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimEbj($15,$16,$17,$isDyingRb,$ccdPass);
   $18 = (($this) + 46|0);
   HEAP8[$18>>0] = 0;
  }
 }
 $19 = (($this) + 44|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = (($1) + 42|0);
 $22 = HEAP16[$21>>1]|0;
 $23 = (($22) + -1)<<16>>16;
 HEAP16[$21>>1] = $23;
 $24 = $23&65535;
 $25 = (($1) + 36|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + ($24<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $20&65535;
 $30 = (($26) + ($29<<2)|0);
 HEAP32[$30>>2] = $28;
 $31 = ($20&65535)<($23&65535);
 if ($31) {
  $32 = HEAP32[$25>>2]|0;
  $33 = (($32) + ($29<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 44|0);
  HEAP16[$35>>1] = $20;
 }
 HEAP16[$19>>1] = -1;
 $36 = (($this) + 8|0);
 $37 = (($this) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($38,$36);
 $39 = (($this) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($40,$36);
 $41 = HEAP32[$37>>2]|0;
 $42 = (($41) + 36|0);
 $43 = HEAP32[$42>>2]|0;
 __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($43,$36);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc35ParticleElementRbElementInteraction10onActivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($2)|0);
 $4 = (($3) + 51|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)!=(0);
 STACKTOP = sp;return ($7|0);
}
function __ZThn8_N5physx2Sc35ParticleElementRbElementInteraction10onActivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + -8|0);
 $2 = (($1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($3)|0);
 $5 = (($4) + 51|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)!=(0);
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx2Sc35ParticleElementRbElementInteraction12onDeactivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($2)|0);
 $4 = (($3) + 51|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 STACKTOP = sp;return ($7|0);
}
function __ZThn8_N5physx2Sc35ParticleElementRbElementInteraction12onDeactivateEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + -8|0);
 $2 = (($1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($3)|0);
 $5 = (($4) + 51|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx2Sc35ParticleElementRbElementInteraction11updateStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)==(0);
 if (!($3)) {
  __ZN5physx2Sc15CoreInteraction19removeFromDirtyListEv($this);
  $4 = HEAP16[$0>>1]|0;
  $5 = $4&65535;
  $6 = $5 & 65533;
  $7 = $6&65535;
  HEAP16[$0>>1] = $7;
 }
 $8 = (($this) + 4|0);
 HEAP16[$8>>1] = 0;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 19|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $14 = (($this) + 36|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 64|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19 & 4;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   $22 = (($this) + 46|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    $25 = (($this) + 32|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($26)|0);
    $28 = HEAP32[$25>>2]|0;
    $29 = HEAP32[$14>>2]|0;
    __ZN5physx2Sc17ParticleSystemSim14addInteractionERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimEj($27,$28,$29,0);
    HEAP8[$22>>0] = 1;
    STACKTOP = sp;return;
   }
  }
  $30 = (($this) + 36|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 28|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 64|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35 & 4;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   STACKTOP = sp;return;
  }
 }
 $38 = (($this) + 46|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 32|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (__ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($42)|0);
 $44 = HEAP32[$41>>2]|0;
 $45 = (($this) + 36|0);
 $46 = HEAP32[$45>>2]|0;
 __ZN5physx2Sc17ParticleSystemSim17removeInteractionERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimEbj($43,$44,$46,0,0);
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc35ParticleElementRbElementInteraction10initializeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc35ParticleElementRbElementInteraction7destroyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc35ParticleElementRbElementInteraction10initializeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Sc35ParticleElementRbElementInteraction7destroyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ParticlePacketShapeC2ERNS0_17ParticleSystemSimEjPNS_16PxvParticleShapeE($this,$particleSystem,$index,$llParticleShape) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $index = $index|0;
 $llParticleShape = $llParticleShape|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((473672 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $particleSystem;
 $2 = (($this) + 12|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 2147483647;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 1073741823;
 __ZN5physx2Sc5Actor15onElementAttachERNS0_7ElementE($particleSystem,$this);
 HEAP32[$this>>2] = ((472744 + 8|0));
 $7 = (($this) + 36|0);
 $8 = $7;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 44|0);
 HEAP32[$12>>2] = $llParticleShape;
 $13 = HEAP32[$llParticleShape>>2]|0;
 $14 = (($13) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($llParticleShape,$this);
 $16 = $index&65535;
 $17 = (($this) + 48|0);
 HEAP16[$17>>1] = $16;
 $18 = HEAP32[$1>>2]|0;
 $19 = (__ZNK5physx2Sc8ActorSim8getSceneEv($18)|0);
 __ZN5physx2Sc5Scene19addBroadPhaseVolumeERNS0_19ParticlePacketShapeE($19,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ParticlePacketShapeD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Sc19ParticlePacketShapeD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ParticlePacketShapeD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((472744 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc17ParticleSystemSim19unlinkParticleShapeEPNS0_19ParticlePacketShapeE($1,$this);
 $2 = HEAP32[$0>>2]|0;
 $3 = (__ZNK5physx2Sc8ActorSim8getSceneEv($2)|0);
 __ZN5physx2Sc5Scene22removeBroadPhaseVolumeERNS0_19ParticlePacketShapeE($3,$this);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 4095]($5);
  HEAP32[$4>>2] = 0;
 }
 $10 = (($this) + 42|0);
 HEAP16[$10>>1] = 0;
 $11 = (($this) + 36|0);
 $12 = (($this) + 40|0);
 $13 = HEAP32[$11>>2]|0;
 $14 = ($13|0)==(0|0);
 $15 = (($this) + 20|0);
 $16 = ($13|0)==($15|0);
 $or$cond = $14 | $16;
 if ($or$cond) {
  HEAP16[$12>>1] = 0;
  HEAP32[$11>>2] = 0;
  __ZN5physx2Sc7ElementD2Ev($this);
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$0>>2]|0;
 $18 = (($17) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP16[$12>>1]|0;
 $21 = $20&65535;
 __ZN5physx2Sc16InteractionScene22deallocatePointerBlockEPPvj($19,$13,$21);
 HEAP16[$12>>1] = 0;
 HEAP32[$11>>2] = 0;
 __ZN5physx2Sc7ElementD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc19ParticlePacketShape17getParticleSystemEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Sc19ParticlePacketShape18computeWorldBoundsERNS_9PxBounds3E($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0;
 var $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$b>>2] = $6;
 $7 = (($0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($b) + 4|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($b) + 8|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($0) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($b) + 12|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($0) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($b) + 16|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($0) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($b) + 20|0);
 HEAPF32[$21>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc19ParticlePacketShape13getFilterInfoERjRNS_12PxFilterDataE($this,$filterAttr,$filterData) {
 $this = $this|0;
 $filterAttr = $filterAttr|0;
 $filterData = $filterData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$filterAttr>>2] = 0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5physx2Sc17ParticleSystemSim16getInternalFlagsEv($2)|0);
 $4 = HEAP32[$filterAttr>>2]|0;
 $5 = $3 >>> 16;
 $6 = $5 & 1;
 $7 = $6 | 2;
 $storemerge = $4 | $7;
 HEAP32[$filterAttr>>2] = $storemerge;
 $8 = HEAP32[$1>>2]|0;
 __ZNK5physx2Sc17ParticleSystemSim23getSimulationFilterDataEv($0,$8);
 ;HEAP32[$filterData+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$filterData+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$filterData+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$filterData+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ParticlePacketShape20setInteractionsDirtyENS0_15CoreInteraction9DirtyFlagE($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 42|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($1) + ($4<<2)|0);
 $6 = ($3<<16>>16)==(0);
 if ($6) {
  STACKTOP = sp;return;
 } else {
  $8 = $1;
 }
 while(1) {
  $7 = HEAP32[$8>>2]|0;
  $9 = (($7) + 4|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = $10&65535;
  $12 = $11 | $flag;
  $13 = $12&65535;
  HEAP16[$9>>1] = $13;
  $14 = (($7) + 6|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = $15 & 2;
  $17 = ($16<<16>>16)==(0);
  if ($17) {
   __ZN5physx2Sc15CoreInteraction14addToDirtyListEv($7);
   $18 = HEAP16[$14>>1]|0;
   $19 = $18&65535;
   $20 = $19 | 2;
   $21 = $20&65535;
   HEAP16[$14>>1] = $21;
  }
  $22 = (($8) + 4|0);
  $23 = ($22>>>0)<($5>>>0);
  if ($23) {
   $8 = $22;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ParticlePacketShape19reallocInteractionsERPPNS0_35ParticleElementRbElementInteractionERttt($this,$mem,$capacity,$size,$requiredMinCapacity) {
 $this = $this|0;
 $mem = $mem|0;
 $capacity = $capacity|0;
 $size = $size|0;
 $requiredMinCapacity = $requiredMinCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newCapacity$0 = 0, $newMem$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $requiredMinCapacity&65535;
 $1 = ($requiredMinCapacity<<16>>16)==(0);
 do {
  if ($1) {
   $newCapacity$0 = 0;$newMem$0 = 0;
  } else {
   $2 = ($requiredMinCapacity&65535)<(5);
   if ($2) {
    $3 = (($this) + 20|0);
    $newCapacity$0 = 4;$newMem$0 = $3;
    break;
   } else {
    $4 = (($0) + -1)|0;
    $5 = $4 >>> 1;
    $6 = $5 | $4;
    $7 = $6 >>> 2;
    $8 = $7 | $6;
    $9 = $8 >>> 4;
    $10 = $9 | $8;
    $11 = $10 >>> 8;
    $12 = $11 | $10;
    $13 = $12 >>> 16;
    $14 = $13 | $12;
    $15 = (($14) + 1)|0;
    $16 = $15&65535;
    $17 = (($this) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 36|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $15 & 65535;
    $22 = (__ZN5physx2Sc16InteractionScene20allocatePointerBlockEj($20,$21)|0);
    $newCapacity$0 = $16;$newMem$0 = $22;
    break;
   }
  }
 } while(0);
 $23 = HEAP32[$mem>>2]|0;
 $24 = $size&65535;
 $25 = $24 << 2;
 _memcpy(($newMem$0|0),($23|0),($25|0))|0;
 $26 = HEAP32[$mem>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP16[$capacity>>1] = $newCapacity$0;
  HEAP32[$mem>>2] = $newMem$0;
  STACKTOP = sp;return;
 }
 $28 = (($this) + 20|0);
 $29 = ($26|0)==($28|0);
 if ($29) {
  HEAP16[$capacity>>1] = $newCapacity$0;
  HEAP32[$mem>>2] = $newMem$0;
  STACKTOP = sp;return;
 }
 $30 = (($this) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 36|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP16[$capacity>>1]|0;
 $35 = $34&65535;
 __ZN5physx2Sc16InteractionScene22deallocatePointerBlockEPPvj($33,$26,$35);
 HEAP16[$capacity>>1] = $newCapacity$0;
 HEAP32[$mem>>2] = $newMem$0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc19ParticlePacketShape8isActiveEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx2Sc18ParticleSystemCoreC2ERKNS_11PxActorType4EnumEjb($this,$actorType,$maxParticles,$perParticleRestOffset) {
 $this = $this|0;
 $actorType = $actorType|0;
 $maxParticles = $maxParticles|0;
 $perParticleRestOffset = $perParticleRestOffset|0;
 var $$ = 0, $$01$i$i = 0, $$01$i$i4 = 0, $$02$i$i = 0, $$02$i$i3 = 0, $$op = 0, $$op$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $i$03$i$i = 0, $i$03$i$i2 = 0, $or$cond = 0, $perParticleRestOffset$not = 0, $scopedFpGuard$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $scopedFpGuard$i1 = sp;
 $0 = HEAP32[$actorType>>2]|0;
 __ZN5physx2Sc9ActorCoreC2ENS_11PxActorType4EnumEthhh($this,$0,1,0,0,0);
 $1 = (($this) + 16|0);
 $2 = (($this) + 20|0);
 $3 = (($this) + 48|0);
 HEAP32[$1>>2] = 0;
 HEAPF32[$3>>2] = Math_fround(0.00100000004749745130539);
 $4 = (($this) + 52|0);
 $5 = (($this) + 132|0);
 ;HEAP32[$scopedFpGuard$i1+0>>2]=0|0;HEAP32[$scopedFpGuard$i1+4>>2]=0|0;HEAP32[$scopedFpGuard$i1+8>>2]=0|0;HEAP32[$scopedFpGuard$i1+12>>2]=0|0;
 ;HEAP32[$2+0>>2]=HEAP32[$scopedFpGuard$i1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$scopedFpGuard$i1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$scopedFpGuard$i1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$scopedFpGuard$i1+12>>2]|0;
 $6 = (($this) + 36|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 40|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 44|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 HEAP16[$5>>1] = 9;
 $9 = (($this) + 72|0);
 $$ = $perParticleRestOffset ? 54 : 38;
 HEAP32[$9>>2] = $$;
 $10 = HEAP32[$actorType>>2]|0;
 $11 = ($10|0)==(2);
 if ($11) {
  HEAPF32[$4>>2] = Math_fround(0.0599999986588954925537);
  $38 = (($this) + 56|0);
  HEAPF32[$38>>2] = Math_fround(1.0);
  $39 = (Math_fround(Math_ceil(Math_fround(10.0000009536743164063))));
  $40 = (~~(($39))>>>0);
  $41 = (($40) + -1)|0;
  $42 = $41 >>> 1;
  $43 = $42 | $41;
  $44 = $43 >>> 2;
  $45 = $44 | $43;
  $46 = $45 >>> 4;
  $47 = $46 | $45;
  $48 = $47 >>> 8;
  $49 = $48 | $47;
  $50 = $49 >>> 16;
  $51 = $50 | $49;
  $52 = (($51) + 1)|0;
  $53 = ($52>>>0)>(4);
  $54 = $53 ? $52 : 4;
  $$02$i$i = $54;$i$03$i$i = 0;
  while(1) {
   $57 = $$02$i$i >>> 1;
   $58 = ($57|0)==(0);
   $56 = (($i$03$i$i) + 1)|0;
   if ($58) {
    $$01$i$i = $i$03$i$i;
    break;
   }
   $55 = ($56>>>0)<(32);
   if ($55) {
    $$02$i$i = $57;$i$03$i$i = $56;
   } else {
    $$01$i$i = -1;
    break;
   }
  }
  $59 = (($this) + 76|0);
  HEAP32[$59>>2] = $$01$i$i;
  $60 = (($this) + 100|0);
  HEAPF32[$60>>2] = Math_fround(0.0);
  $61 = (($this) + 60|0);
  HEAPF32[$61>>2] = Math_fround(0.0);
  $62 = (($this) + 92|0);
  HEAPF32[$62>>2] = Math_fround(0.0);
 } else {
  $12 = $$ | 65536;
  HEAP32[$9>>2] = $12;
  HEAPF32[$4>>2] = Math_fround(0.0199999995529651641846);
  $13 = (($this) + 56|0);
  HEAPF32[$13>>2] = Math_fround(2.0);
  $14 = (Math_fround(Math_ceil(Math_fround(15.0000009536743164063))));
  $15 = (~~(($14))>>>0);
  $16 = (($15) + -1)|0;
  $17 = $16 >>> 1;
  $18 = $17 | $16;
  $19 = $18 >>> 2;
  $20 = $19 | $18;
  $21 = $20 >>> 4;
  $22 = $21 | $20;
  $23 = $22 >>> 8;
  $24 = $23 | $22;
  $25 = $24 >>> 16;
  $26 = $25 | $24;
  $27 = (($26) + 1)|0;
  $28 = ($27>>>0)>(4);
  $29 = $28 ? $27 : 4;
  $$02$i$i3 = $29;$i$03$i$i2 = 0;
  while(1) {
   $32 = $$02$i$i3 >>> 1;
   $33 = ($32|0)==(0);
   $31 = (($i$03$i$i2) + 1)|0;
   if ($33) {
    $$01$i$i4 = $i$03$i$i2;
    break;
   }
   $30 = ($31>>>0)<(32);
   if ($30) {
    $$02$i$i3 = $32;$i$03$i$i2 = $31;
   } else {
    $$01$i$i4 = -1;
    break;
   }
  }
  $34 = (($this) + 76|0);
  HEAP32[$34>>2] = $$01$i$i4;
  $35 = (($this) + 100|0);
  HEAPF32[$35>>2] = Math_fround(20.0);
  $36 = (($this) + 60|0);
  HEAPF32[$36>>2] = Math_fround(6.0);
  $37 = (($this) + 92|0);
  HEAPF32[$37>>2] = Math_fround(1000.0);
 }
 $63 = (($this) + 104|0);
 HEAPF32[$63>>2] = Math_fround(0.0599999986588954925537);
 $64 = (($this) + 108|0);
 HEAPF32[$64>>2] = Math_fround(0.00400000018998980522156);
 $65 = (($this) + 112|0);
 HEAPF32[$65>>2] = Math_fround(0.00800000037997961044312);
 $66 = (($this) + 96|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($this) + 136|0);
 HEAP32[$67>>2] = 0;
 $68 = (($this) + 80|0);
 HEAPF32[$68>>2] = Math_fround(0.5);
 $69 = (($this) + 84|0);
 HEAPF32[$69>>2] = Math_fround(0.0500000007450580596924);
 $70 = (($this) + 88|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($this) + 116|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($this) + 120|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($this) + 124|0);
 HEAPF32[$73>>2] = Math_fround(1.0);
 $74 = (($this) + 128|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = ($maxParticles>>>0)<(4294967294);
 $76 = $75 ? $maxParticles : -2;
 $77 = (__ZN5physx15PxsParticleData6createEjb($76,$perParticleRestOffset)|0);
 HEAP32[$1>>2] = $77;
 $perParticleRestOffset$not = $perParticleRestOffset ^ 1;
 $78 = ($76|0)==(0);
 $or$cond = $78 | $perParticleRestOffset$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $79 = (($77) + 52|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($maxParticles>>>0)<(4294967294);
 $82 = $maxParticles << 2;
 $$op = $82 ^ -4;
 $$op$op = (-4 - ($$op))|0;
 $83 = $81 ? $$op$op : -8;
 _memset(($80|0),0,($83|0))|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore23setExternalAccelerationERKNS_6PxVec3E($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$v>>2]);
 $1 = (($this) + 36|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($v) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 40|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($v) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 44|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCoreD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5physx15PxsParticleData7releaseEv($1);
 }
 __ZN5physx2Sc9ActorCoreD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $particles = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $particles = sp + 24|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN5physx15PxsParticleData10exportDataERNS_22PxSerializationContextE($2,$stream);
  STACKTOP = sp;return;
 }
 $4 = (($particles) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($particles) + 20|0);
 HEAP32[$5>>2] = 12;
 $6 = (($particles) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($particles) + 28|0);
 HEAP32[$7>>2] = 12;
 $8 = (($particles) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = (($particles) + 36|0);
 HEAP32[$9>>2] = 4;
 $10 = (($particles) + 40|0);
 HEAP32[$10>>2] = 0;
 $11 = (($particles) + 44|0);
 HEAP32[$11>>2] = 4;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($13)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_viiii[$17 & 511]($14,$particles,1,0);
 $18 = HEAP32[$12>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $21 = HEAP32[$1>>2]|0;
  $23 = $21;
 } else {
  $20 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($18)|0);
  $23 = $20;
 }
 $22 = HEAP32[$23>>2]|0;
 $24 = (($22) + 40|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095]($0,$23);
 $26 = (__ZN5physx15PxsParticleData6createERNS_30PxvParticleSystemStateDataDescERKNS_9PxBounds3E($particles,$0)|0);
 __ZN5physx15PxsParticleData10exportDataERNS_22PxSerializationContextE($26,$stream);
 __ZN5physx15PxsParticleData7releaseEv($26);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore6getSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc18ParticleSystemCore20obtainStandaloneDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc18ParticleSystemCore20returnStandaloneDataEPNS_15PxsParticleDataE($this,$particleData) {
 $this = $this|0;
 $particleData = $particleData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = $particleData;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0);
 var $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$shift>>2]);
 $3 = Math_fround($1 * $2);
 $4 = (($this) + 120|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($shift) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = Math_fround($3 + $8);
 $10 = (($this) + 124|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($shift) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 * $13);
 $15 = Math_fround($9 + $14);
 $16 = (($this) + 128|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 + $15);
 HEAPF32[$16>>2] = $18;
 $19 = (($this) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 __ZN5physx15PxsParticleData13onOriginShiftERKNS_6PxVec3E($20,$shift);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore17getPxParticleBaseEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 10|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(2);
 if ($2) {
  $3 = (__Z21NpGetNxParticleSystemRN5physx2Sc18ParticleSystemCoreE($this)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 } else {
  $4 = (__Z20NpGetNxParticleFluidRN5physx2Sc18ParticleSystemCoreE($this)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Sc18ParticleSystemCore12getStiffnessEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore12setStiffnessEf($this,$t) {
 $this = $this|0;
 $t = Math_fround($t);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 HEAPF32[$0>>2] = $t;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore12getViscosityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore12setViscosityEf($this,$t) {
 $this = $this|0;
 $t = Math_fround($t);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 HEAPF32[$0>>2] = $t;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore10getDampingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore10setDampingEf($this,$t) {
 $this = $this|0;
 $t = Math_fround($t);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 HEAPF32[$0>>2] = $t;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore15getParticleMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore15setParticleMassEf($this,$mass) {
 $this = $this|0;
 $mass = Math_fround($mass);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAPF32[$0>>2] = $mass;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore14getRestitutionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore14setRestitutionEf($this,$t) {
 $this = $this|0;
 $t = Math_fround($t);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 HEAPF32[$0>>2] = $t;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore18getDynamicFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore18setDynamicFrictionEf($this,$t) {
 $this = $this|0;
 $t = Math_fround($t);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 HEAPF32[$0>>2] = $t;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore17getStaticFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore17setStaticFrictionEf($this,$t) {
 $this = $this|0;
 $t = Math_fround($t);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 HEAPF32[$0>>2] = $t;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore23getSimulationFilterDataEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Sc18ParticleSystemCore23setSimulationFilterDataERKNS_12PxFilterDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 ;HEAP32[$0+0>>2]=HEAP32[$data+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$data+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$data+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$data+12>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc17ParticleSystemSim19scheduleRefilteringEv($2);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore14resetFilteringEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc17ParticleSystemSim14resetFilteringEv($1);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1&65535;
 HEAP16[$agg$result>>1] = $2;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore8setFlagsENS_7PxFlagsINS_18PxParticleBaseFlag4EnumEtEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = HEAP16[$flags>>1]|0;
 if ($2) {
  $21 = (($this) + 72|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $22 & -65536;
  $24 = $3&65535;
  $25 = $23 | $24;
  HEAP32[$21>>2] = $25;
  STACKTOP = sp;return;
 }
 $4 = $3 & 99;
 $5 = ($4<<16>>16)==(0);
 if ($5) {
  $13 = (($this) + 72|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & -65536;
  $16 = $3&65535;
  $17 = $15 | $16;
  HEAP32[$13>>2] = $17;
  $19 = $3;$20 = $1;
 } else {
  $6 = (__ZNK5physx2Sc8ActorSim8getSceneEv($1)|0);
  __ZN5physx2Sc5Scene20removeParticleSystemERNS0_18ParticleSystemCoreEb($6,$this,0);
  $7 = HEAP16[$flags>>1]|0;
  $8 = (($this) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & -65536;
  $11 = $7&65535;
  $12 = $10 | $11;
  HEAP32[$8>>2] = $12;
  __ZN5physx2Sc5Scene17addParticleSystemERNS0_18ParticleSystemCoreE($6,$this);
  $$pre = HEAP32[$0>>2]|0;
  $$pre6 = HEAP16[$flags>>1]|0;
  $19 = $$pre6;$20 = $$pre;
 }
 $18 = $19&65535;
 __ZN5physx2Sc17ParticleSystemSim8setFlagsEj($20,$18);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore16getInternalFlagsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc18ParticleSystemCore17notifyCpuFallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -65;
 HEAP32[$0>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = HEAP16[$0>>1]|0;
 HEAP16[$agg$result>>1] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore24setParticleReadDataFlagsENS_7PxFlagsINS_22PxParticleReadDataFlag4EnumEtEE($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$flags>>1]|0;
 $1 = (($this) + 132|0);
 HEAP16[$1>>1] = $0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore15getMaxParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($7)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNK5physx2Sc18ParticleSystemCore20getMaxMotionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore20setMaxMotionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 HEAPF32[$0>>2] = $distance;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore13getRestOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore13setRestOffsetEf($this,$restOffset) {
 $this = $this|0;
 $restOffset = Math_fround($restOffset);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 HEAPF32[$0>>2] = $restOffset;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore16getContactOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore16setContactOffsetEf($this,$contactOffset) {
 $this = $this|0;
 $contactOffset = Math_fround($contactOffset);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 HEAPF32[$0>>2] = $contactOffset;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore23getRestParticleDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc18ParticleSystemCore23setRestParticleDistanceEf($this,$restParticleDistance) {
 $this = $this|0;
 $restParticleDistance = Math_fround($restParticleDistance);
 var $$01$i$i$i = 0, $$02$i$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $i$03$i$i$i = 0, $scopedFpGuard$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $scopedFpGuard$i$i = sp;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 52|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 * $3);
 $5 = (($this) + 76|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = 1 << $6;
 $8 = (Math_fround(($7>>>0)));
 $9 = Math_fround($4 * $8);
 HEAPF32[$2>>2] = $restParticleDistance;
 $10 = Math_fround($1 * $restParticleDistance);
 $11 = Math_fround($9 / $10);
 $12 = (Math_fround(Math_ceil((Math_fround($11)))));
 $13 = (~~(($12))>>>0);
 $14 = (($13) + -1)|0;
 $15 = $14 >>> 1;
 $16 = $15 | $14;
 $17 = $16 >>> 2;
 $18 = $17 | $16;
 $19 = $18 >>> 4;
 $20 = $19 | $18;
 $21 = $20 >>> 8;
 $22 = $21 | $20;
 $23 = $22 >>> 16;
 $24 = $23 | $22;
 $25 = (($24) + 1)|0;
 $26 = ($25>>>0)>(4);
 $27 = $26 ? $25 : 4;
 $$02$i$i$i = $27;$i$03$i$i$i = 0;
 while(1) {
  $30 = $$02$i$i$i >>> 1;
  $31 = ($30|0)==(0);
  $29 = (($i$03$i$i$i) + 1)|0;
  if ($31) {
   $$01$i$i$i = $i$03$i$i$i;
   label = 4;
   break;
  }
  $28 = ($29>>>0)<(32);
  if ($28) {
   $$02$i$i$i = $30;$i$03$i$i$i = $29;
  } else {
   $$01$i$i$i = -1;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$5>>2] = $$01$i$i$i;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Sc18ParticleSystemCore11getGridSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 52|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 * $3);
 $5 = (($this) + 76|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = 1 << $6;
 $8 = (Math_fround(($7>>>0)));
 $9 = Math_fround($4 * $8);
 STACKTOP = sp;return (Math_fround($9));
}
function __ZN5physx2Sc18ParticleSystemCore11setGridSizeEf($this,$gridSize) {
 $this = $this|0;
 $gridSize = Math_fround($gridSize);
 var $$01$i$i = 0, $$02$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $i$03$i$i = 0, $scopedFpGuard$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $scopedFpGuard$i = sp;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 52|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 * $3);
 $5 = Math_fround($gridSize / $4);
 $6 = (Math_fround(Math_ceil((Math_fround($5)))));
 $7 = (~~(($6))>>>0);
 $8 = (($7) + -1)|0;
 $9 = $8 >>> 1;
 $10 = $9 | $8;
 $11 = $10 >>> 2;
 $12 = $11 | $10;
 $13 = $12 >>> 4;
 $14 = $13 | $12;
 $15 = $14 >>> 8;
 $16 = $15 | $14;
 $17 = $16 >>> 16;
 $18 = $17 | $16;
 $19 = (($18) + 1)|0;
 $20 = ($19>>>0)>(4);
 $21 = $20 ? $19 : 4;
 $$02$i$i = $21;$i$03$i$i = 0;
 while(1) {
  $24 = $$02$i$i >>> 1;
  $25 = ($24|0)==(0);
  $23 = (($i$03$i$i) + 1)|0;
  if ($25) {
   $$01$i$i = $i$03$i$i;
   label = 4;
   break;
  }
  $22 = ($23>>>0)<(32);
  if ($22) {
   $$02$i$i = $24;$i$03$i$i = $23;
  } else {
   $$01$i$i = -1;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $26 = (($this) + 76|0);
  HEAP32[$26>>2] = $$01$i$i;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc18ParticleSystemCore15createParticlesERKNS_22PxParticleCreationDataE($this,$creationData) {
 $this = $this|0;
 $creationData = $creationData|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$9 & 4095]($7,$creationData)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN5physx2Sc18ParticleSystemCore16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE($this,$nbIndices,$indices) {
 $this = $this|0;
 $nbIndices = $nbIndices|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viii[$9 & 4095]($7,$nbIndices,$indices);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore16releaseParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$9 & 4095]($7);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($this,$numParticles,$indexBuffer,$positionBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $positionBuffer = $positionBuffer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiii[$9 & 511]($7,$numParticles,$indexBuffer,$positionBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS2_IKNS_6PxVec3EEE($this,$numParticles,$indexBuffer,$velocityBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $velocityBuffer = $velocityBuffer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiii[$9 & 511]($7,$numParticles,$indexBuffer,$velocityBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS2_IKfEE($this,$numParticles,$indexBuffer,$restOffsetBuffer) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indexBuffer = $indexBuffer|0;
 $restOffsetBuffer = $restOffsetBuffer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiii[$9 & 511]($7,$numParticles,$indexBuffer,$restOffsetBuffer);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc18ParticleSystemCore18addDeltaVelocitiesERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKNS_6PxVec3Ef($this,$bufferMap,$buffer,$multiplier) {
 $this = $this|0;
 $bufferMap = $bufferMap|0;
 $buffer = $buffer|0;
 $multiplier = Math_fround($multiplier);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiif[$9 & 15]($7,$bufferMap,$buffer,$multiplier);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore19getParticleReadDataERNS_23PxParticleFluidReadDataE($this,$readData) {
 $this = $this|0;
 $readData = $readData|0;
 var $$pre = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $particles = 0, $simParticleData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 88|0;
 $particles = sp + 40|0;
 $simParticleData = sp;
 $1 = HEAP32[$readData>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($0,$readData);
 $3 = HEAP8[$0>>0]|0;
 $4 = $3 & 4;
 $5 = ($4<<24>>24)!=(0);
 $6 = (($particles) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = (($particles) + 20|0);
 HEAP32[$7>>2] = 12;
 $8 = (($particles) + 24|0);
 HEAP32[$8>>2] = 0;
 $9 = (($particles) + 28|0);
 HEAP32[$9>>2] = 12;
 $10 = (($particles) + 32|0);
 HEAP32[$10>>2] = 0;
 $11 = (($particles) + 36|0);
 HEAP32[$11>>2] = 4;
 $12 = (($particles) + 40|0);
 HEAP32[$12>>2] = 0;
 $13 = (($particles) + 44|0);
 HEAP32[$13>>2] = 4;
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $18 = (($this) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $21 = $19;
 } else {
  $17 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($15)|0);
  $21 = $17;
 }
 $20 = HEAP32[$21>>2]|0;
 $22 = (($20) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_viiii[$23 & 511]($21,$particles,0,$5);
 $24 = (($particles) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($readData) + 4|0);
 HEAP32[$26>>2] = $25;
 $27 = (($particles) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($readData) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = (($particles) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $35 = 0;
 } else {
  $33 = HEAP32[$31>>2]|0;
  $35 = $33;
 }
 $34 = (($readData) + 12|0);
 HEAP32[$34>>2] = $35;
 $36 = (($readData) + 16|0);
 $37 = $36;
 $38 = $37;
 HEAP32[$38>>2] = 0;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = 12;
 $41 = (($readData) + 24|0);
 $42 = $41;
 $43 = $42;
 HEAP32[$43>>2] = 0;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = 12;
 $46 = (($readData) + 32|0);
 $47 = $46;
 $48 = $47;
 HEAP32[$48>>2] = 0;
 $49 = (($47) + 4)|0;
 $50 = $49;
 HEAP32[$50>>2] = 4;
 $51 = (($readData) + 40|0);
 $52 = $51;
 $53 = $52;
 HEAP32[$53>>2] = 0;
 $54 = (($52) + 4)|0;
 $55 = $54;
 HEAP32[$55>>2] = 2;
 $56 = (($readData) + 48|0);
 $57 = $56;
 $58 = $57;
 HEAP32[$58>>2] = 0;
 $59 = (($57) + 4)|0;
 $60 = $59;
 HEAP32[$60>>2] = 12;
 $61 = (($readData) + 56|0);
 $62 = $61;
 $63 = $62;
 HEAP32[$63>>2] = 0;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = 12;
 $66 = (($readData) + 64|0);
 $67 = $66;
 $68 = $67;
 HEAP32[$68>>2] = 0;
 $69 = (($67) + 4)|0;
 $70 = $69;
 HEAP32[$70>>2] = 4;
 $71 = ($28|0)==(0);
 if ($71) {
  STACKTOP = sp;return;
 }
 $72 = (($this) + 132|0);
 $73 = HEAP16[$72>>1]|0;
 $74 = $73 & 1;
 $75 = ($74<<16>>16)==(0);
 if ($75) {
  $88 = $73;
 } else {
  $76 = (($particles) + 16|0);
  $77 = $76;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($77) + 4)|0;
  $81 = $80;
  $82 = HEAP32[$81>>2]|0;
  $83 = $36;
  $84 = $83;
  HEAP32[$84>>2] = $79;
  $85 = (($83) + 4)|0;
  $86 = $85;
  HEAP32[$86>>2] = $82;
  $$pre = HEAP16[$72>>1]|0;
  $88 = $$pre;
 }
 $87 = $88 & 2;
 $89 = ($87<<16>>16)==(0);
 if ($89) {
  $102 = $88;
 } else {
  $90 = (($particles) + 24|0);
  $91 = $90;
  $92 = $91;
  $93 = HEAP32[$92>>2]|0;
  $94 = (($91) + 4)|0;
  $95 = $94;
  $96 = HEAP32[$95>>2]|0;
  $97 = $41;
  $98 = $97;
  HEAP32[$98>>2] = $93;
  $99 = (($97) + 4)|0;
  $100 = $99;
  HEAP32[$100>>2] = $96;
  $$pre30 = HEAP16[$72>>1]|0;
  $102 = $$pre30;
 }
 $101 = $102 & 4;
 $103 = ($101<<16>>16)==(0);
 if ($103) {
  $116 = $102;
 } else {
  $104 = (($particles) + 40|0);
  $105 = $104;
  $106 = $105;
  $107 = HEAP32[$106>>2]|0;
  $108 = (($105) + 4)|0;
  $109 = $108;
  $110 = HEAP32[$109>>2]|0;
  $111 = $46;
  $112 = $111;
  HEAP32[$112>>2] = $107;
  $113 = (($111) + 4)|0;
  $114 = $113;
  HEAP32[$114>>2] = $110;
  $$pre31 = HEAP16[$72>>1]|0;
  $116 = $$pre31;
 }
 $115 = $116 & 8;
 $117 = ($115<<16>>16)==(0);
 if (!($117)) {
  $118 = HEAP32[$10>>2]|0;
  $119 = HEAP32[$11>>2]|0;
  $120 = $118;
  $121 = $51;
  $122 = $121;
  HEAP32[$122>>2] = $120;
  $123 = (($121) + 4)|0;
  $124 = $123;
  HEAP32[$124>>2] = $119;
 }
 $125 = HEAP32[$14>>2]|0;
 $126 = ($125|0)==(0|0);
 if ($126) {
  STACKTOP = sp;return;
 }
 HEAP32[$simParticleData>>2] = 0;
 $127 = (($simParticleData) + 4|0);
 HEAP32[$127>>2] = 4;
 $128 = (($simParticleData) + 8|0);
 HEAP32[$128>>2] = 0;
 $129 = (($simParticleData) + 12|0);
 HEAP32[$129>>2] = 12;
 $130 = (($simParticleData) + 16|0);
 HEAP32[$130>>2] = 0;
 $131 = (($simParticleData) + 20|0);
 HEAP32[$131>>2] = 12;
 $132 = (($simParticleData) + 24|0);
 HEAP32[$132>>2] = 0;
 $133 = (($simParticleData) + 28|0);
 HEAP32[$133>>2] = 12;
 $134 = (($simParticleData) + 32|0);
 HEAP32[$134>>2] = 0;
 $135 = (($simParticleData) + 36|0);
 HEAP32[$135>>2] = 4;
 __ZNK5physx2Sc17ParticleSystemSim18getSimParticleDataERNS_28PxvParticleSystemSimDataDescEb($125,$simParticleData,$5);
 $136 = HEAP16[$72>>1]|0;
 $137 = $136 & 16;
 $138 = ($137<<16>>16)==(0);
 if ($138) {
  $151 = $136;
 } else {
  $139 = (($simParticleData) + 8|0);
  $140 = $139;
  $141 = $140;
  $142 = HEAP32[$141>>2]|0;
  $143 = (($140) + 4)|0;
  $144 = $143;
  $145 = HEAP32[$144>>2]|0;
  $146 = $56;
  $147 = $146;
  HEAP32[$147>>2] = $142;
  $148 = (($146) + 4)|0;
  $149 = $148;
  HEAP32[$149>>2] = $145;
  $$pre32 = HEAP16[$72>>1]|0;
  $151 = $$pre32;
 }
 $150 = $151 & 32;
 $152 = ($150<<16>>16)==(0);
 if ($152) {
  $165 = $151;
 } else {
  $153 = (($simParticleData) + 16|0);
  $154 = $153;
  $155 = $154;
  $156 = HEAP32[$155>>2]|0;
  $157 = (($154) + 4)|0;
  $158 = $157;
  $159 = HEAP32[$158>>2]|0;
  $160 = $61;
  $161 = $160;
  HEAP32[$161>>2] = $156;
  $162 = (($160) + 4)|0;
  $163 = $162;
  HEAP32[$163>>2] = $159;
  $$pre33 = HEAP16[$72>>1]|0;
  $165 = $$pre33;
 }
 $164 = $165 & 64;
 $166 = ($164<<16>>16)==(0);
 if ($166) {
  STACKTOP = sp;return;
 }
 $167 = $simParticleData;
 $168 = $167;
 $169 = HEAP32[$168>>2]|0;
 $170 = (($167) + 4)|0;
 $171 = $170;
 $172 = HEAP32[$171>>2]|0;
 $173 = $66;
 $174 = $173;
 HEAP32[$174>>2] = $169;
 $175 = (($173) + 4)|0;
 $176 = $175;
 HEAP32[$176>>2] = $172;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore14getWorldBoundsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = (($this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 } else {
  $3 = (__ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($1)|0);
  $7 = $3;
 }
 $6 = HEAP32[$7>>2]|0;
 $8 = (($6) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($agg$result,$7);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc18ParticleSystemCore23getExternalAccelerationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx2Sc18ParticleSystemCore18getProjectionPlaneEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Sc18ParticleSystemCore18setProjectionPlaneERKNS_7PxPlaneE($this,$plane) {
 $this = $this|0;
 $plane = $plane|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$plane>>2]);
 $1 = (($this) + 116|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($plane) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 120|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($plane) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 124|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($plane) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 128|0);
 HEAPF32[$10>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSimC2ERNS0_5SceneERNS0_18ParticleSystemCoreE($this,$scene,$core) {
 $this = $this|0;
 $scene = $scene|0;
 $core = $core|0;
 var $$not = 0, $$not1 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 6|0;
 $1 = sp + 4|0;
 __ZN5physx2Sc8ActorSimC2ERNS0_5SceneERNS0_9ActorCoreENS0_14IslandNodeInfo4TypeE($this,$scene,$core,8);
 HEAP32[$this>>2] = ((472768 + 8|0));
 $2 = (($this) + 64|0);
 $3 = (($this) + 320|0);
 $4 = (($this) + 324|0);
 $5 = (($this) + 328|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 332|0);
 HEAP8[$3>>0] = 1;
 HEAP32[$4>>2] = $2;
 HEAP32[$6>>2] = 64;
 $7 = (($this) + 336|0);
 HEAP32[$7>>2] = 32;
 $8 = (($this) + 340|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 344|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 348|0);
 HEAP32[$10>>2] = 1664;
 $11 = (($this) + 352|0);
 $12 = (($this) + 372|0);
 $13 = (($this) + 376|0);
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;
 HEAP16[$13>>1] = -1;
 $14 = (($this) + 378|0);
 HEAP16[$14>>1] = 0;
 $15 = (($this) + 380|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$12>>2] = ((434896 + 8|0));
 $16 = (($this) + 384|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 388|0);
 HEAP32[$17>>2] = 0;
 HEAP32[$12>>2] = ((473376 + 8|0));
 $18 = (($this) + 392|0);
 HEAP32[$18>>2] = $this;
 $19 = (($this) + 396|0);
 HEAP32[$19>>2] = 472800;
 $20 = (($this) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21>>>0)>(32);
 if (!($22)) {
  $23 = (($this) + 20|0);
  $24 = (($this) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  __ZN5physx2Sc5Actor19reallocInteractionsERPPNS0_11InteractionERjjj($this,$23,$20,$25,32);
 }
 $26 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $27 = (($26) + 1212|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1000|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (__ZN5physx2Sc18ParticleSystemCore20obtainStandaloneDataEv($core)|0);
 $32 = (($this) + 52|0);
 $33 = HEAP32[$32>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($0,$33);
 $34 = HEAP16[$0>>1]|0;
 $35 = $34 & 64;
 $36 = ($35<<16>>16)!=(0);
 $37 = (($core) + 52|0);
 $38 = (__ZN5physx10PxsContext17addParticleSystemEPNS_15PxsParticleDataERKNS_26PxvParticleSystemParameterEb($30,$31,$37,$36)|0);
 $39 = (($this) + 56|0);
 HEAP32[$39>>2] = $38;
 $$not = ($38|0)!=(0|0);
 $$not1 = $36 ^ 1;
 $brmerge = $$not | $$not1;
 if ($brmerge) {
  $44 = $38;
 } else {
  $40 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($40,2,472848,74,472960,$vararg_buffer);
  $41 = (__ZN5physx10PxsContext17addParticleSystemEPNS_15PxsParticleDataERKNS_26PxvParticleSystemParameterEb($30,$31,$37,0)|0);
  HEAP32[$39>>2] = $41;
  $42 = HEAP32[$32>>2]|0;
  __ZN5physx2Sc18ParticleSystemCore17notifyCpuFallbackEv($42);
  $$pr = HEAP32[$39>>2]|0;
  $44 = $$pr;
 }
 $43 = ($44|0)==(0|0);
 if ($43) {
  $53 = (($core) + 4|0);
  HEAP32[$53>>2] = 0;
  __ZN5physx2Sc18ParticleSystemCore20returnStandaloneDataEPNS_15PxsParticleDataE($core,$31);
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$32>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($1,$45);
 $46 = HEAP16[$1>>1]|0;
 $47 = $46 & 4;
 $48 = ($47<<16>>16)==(0);
 if ($48) {
  STACKTOP = sp;return;
 }
 $49 = HEAP32[$39>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095]($49,1);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc17ParticleSystemSim7getCoreEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc17ParticleSystemSim7releaseEb($this,$releaseParticleData) {
 $this = $this|0;
 $releaseParticleData = $releaseParticleData|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 360|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = (($this) + 356|0);
   $4 = (($this) + 60|0);
   $5 = (($this) + 340|0);
   $6 = (($this) + 352|0);
   $7 = (($this) + 344|0);
   $8 = (($this) + 336|0);
   $10 = $1;$i$01$i = 1;
   while(1) {
    $9 = (($10) + -1)|0;
    $11 = HEAP32[$3>>2]|0;
    $12 = (($11) + ($9<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     $15 = HEAP32[$13>>2]|0;
     $16 = HEAP32[$15>>2]|0;
     FUNCTION_TABLE_vi[$16 & 4095]($13);
     $17 = HEAP32[$5>>2]|0;
     $18 = (($17) + -1)|0;
     HEAP32[$5>>2] = $18;
     $19 = HEAP32[$6>>2]|0;
     HEAP32[$13>>2] = $19;
     HEAP32[$6>>2] = $13;
     $20 = HEAP32[$7>>2]|0;
     $21 = (($20) + 1)|0;
     HEAP32[$7>>2] = $21;
     $22 = HEAP32[$8>>2]|0;
     $23 = ($22*50)|0;
     $24 = ($20|0)<($23|0);
     if (!($24)) {
      __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($4);
      HEAP32[$7>>2] = 0;
     }
    }
    $exitcond$i = ($i$01$i|0)==($1|0);
    if ($exitcond$i) {
     break L1;
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $phitmp$i = (($i$01$i) + 1)|0;
    $10 = $$pre$i;$i$01$i = $phitmp$i;
   }
  }
 } while(0);
 $25 = (($this) + 56|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
  $29 = (($28) + 1212|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1000|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$25>>2]|0;
  $34 = $releaseParticleData ^ 1;
  $35 = (__ZN5physx10PxsContext20removeParticleSystemEPNS_20PxvParticleSystemSimEb($32,$33,$34)|0);
  $$pre = (($this) + 52|0);
  if (!($releaseParticleData)) {
   $36 = HEAP32[$$pre>>2]|0;
   __ZN5physx2Sc18ParticleSystemCore20returnStandaloneDataEPNS_15PxsParticleDataE($36,$35);
  }
  $37 = HEAP32[$$pre>>2]|0;
  $38 = (($37) + 4|0);
  HEAP32[$38>>2] = 0;
 }
 $39 = ($this|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$this>>2]|0;
 $41 = (($40) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vi[$42 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim19unlinkParticleShapeEPNS0_19ParticlePacketShapeE($this,$particleShape) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($particleShape) + 48|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = (($this) + 360|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 $6 = (($this) + 356|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 48|0);
 HEAP16[$10>>1] = $1;
 HEAP32[$3>>2] = $5;
 $11 = (($7) + ($2<<2)|0);
 HEAP32[$11>>2] = $9;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc17ParticleSystemSim16getInternalFlagsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc18ParticleSystemCore16getInternalFlagsEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx2Sc17ParticleSystemSim23getSimulationFilterDataEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc18ParticleSystemCore23getSimulationFilterDataEv($1)|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim19scheduleRefilteringEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 360|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 356|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN5physx2Sc19ParticlePacketShape20setInteractionsDirtyENS0_15CoreInteraction9DirtyFlagE($6,1);
  $7 = (($i$01) + 1)|0;
  $8 = HEAP32[$0>>2]|0;
  $9 = ($7>>>0)<($8>>>0);
  if ($9) {
   $i$01 = $7;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim14resetFilteringEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $1 = (($this) + 360|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 356|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($i$01<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  __ZN5physx2Sc5Scene22removeBroadPhaseVolumeERNS0_19ParticlePacketShapeE($0,$7);
  $8 = HEAP32[$4>>2]|0;
  $9 = (($8) + ($i$01<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN5physx2Sc5Scene19addBroadPhaseVolumeERNS0_19ParticlePacketShapeE($0,$10);
  $11 = (($i$01) + 1)|0;
  $exitcond = ($11|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $11;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim8setFlagsEj($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($0,$3);
 $4 = HEAP16[$0>>1]|0;
 $5 = $4 & 4;
 $6 = ($5<<16>>16)==(0);
 if (!($6)) {
  $7 = $flags & 4;
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = (($this) + 56|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vii[$13 & 4095]($10,1);
   STACKTOP = sp;return;
  }
 }
 $14 = HEAP32[$2>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($1,$14);
 $15 = HEAP16[$1>>1]|0;
 $16 = $15 & 4;
 $17 = ($16<<16>>16)==(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = $flags & 4;
 $19 = ($18|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (($this) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_vii[$24 & 4095]($21,0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc17ParticleSystemSim18getSimParticleDataERNS_28PxvParticleSystemSimDataDescEb($this,$simParticleData,$devicePtr) {
 $this = $this|0;
 $simParticleData = $simParticleData|0;
 $devicePtr = $devicePtr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viii[$4 & 4095]($1,$simParticleData,$devicePtr);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim16getParticleStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($1)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx2Sc17ParticleSystemSim14addInteractionERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimEj($this,$particleShape,$shape,$ccdPass) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 $shape = $shape|0;
 $ccdPass = $ccdPass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = (__ZNK5physx2Sc8ShapeSim14actorIsDynamicEv($shape)|0);
 $4 = (__ZNK5physx2Sc8ShapeSim15getPxsRigidCoreEv($shape)|0);
 if ($3) {
  $5 = (($this) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 1000|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 1448|0);
  __ZN5physx21PxsBodyTransformVault7addBodyERKNS_11PxsBodyCoreE($9,$4);
 }
 $10 = (($this) + 56|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($particleShape) + 44|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $2;
 $18 = $4;
 $19 = ($ccdPass|0)!=(0);
 FUNCTION_TABLE_viiiiii[$14 & 255]($11,$16,$17,$18,$3,$19);
 $20 = (($this) + 368|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 1)|0;
 HEAP32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim17removeInteractionERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimEbj($this,$particleShape,$shape,$isDyingRb,$ccdPass) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 $shape = $shape|0;
 $isDyingRb = $isDyingRb|0;
 $ccdPass = $ccdPass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = (__ZNK5physx2Sc8ShapeSim14actorIsDynamicEv($shape)|0);
 $4 = (__ZNK5physx2Sc8ShapeSim15getPxsRigidCoreEv($shape)|0);
 if ($3) {
  $5 = (($this) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 1000|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 1448|0);
  __ZN5physx21PxsBodyTransformVault10removeBodyERKNS_11PxsBodyCoreE($9,$4);
 }
 $10 = (($this) + 56|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($particleShape) + 44|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $2;
 $18 = $4;
 $19 = ($ccdPass|0)!=(0);
 FUNCTION_TABLE_viiiiiii[$14 & 127]($11,$16,$17,$18,$3,$isDyingRb,$19);
 $20 = (($this) + 368|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + -1)|0;
 HEAP32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim15onRbShapeChangeERKNS0_19ParticlePacketShapeERKNS0_8ShapeSimE($this,$particleShape,$shape) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 $shape = $shape|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($shape)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $17 = 0;
 } else {
  $2 = (__ZNK5physx2Sc8ShapeSim10getBodySimEv($shape)|0);
  $3 = (($2) + 52|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 16|0);
  $phitmp = $5;
  $17 = $phitmp;
 }
 $6 = (($this) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($particleShape) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($shape) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 32|0);
 $16 = $15;
 FUNCTION_TABLE_viiii[$10 & 511]($7,$12,$16,$17);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim17updateRigidBodiesEv($this) {
 $this = $this|0;
 var $$ph = 0, $$ph10 = 0, $$ph11 = 0, $$ph1225 = 0, $$ph1326 = 0, $$pre$i$i$i = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0);
 var $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cdom = 0, $p$0$ph1427 = 0, $p$017 = 0, $particlesCore = 0, $particlesSim = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 110|0;
 $1 = sp + 108|0;
 $particlesCore = sp + 8|0;
 $particlesSim = sp + 56|0;
 $cdom = sp;
 $2 = sp + 96|0;
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($0,$4);
 $5 = HEAP16[$0>>1]|0;
 $6 = $5 & 1;
 $7 = ($6<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$3>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore8getFlagsEv($1,$8);
 $9 = HEAP16[$1>>1]|0;
 $10 = $9 & 2;
 $11 = ($10<<16>>16)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$3>>2]|0;
 $13 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore15getParticleMassEv($12)));
 $14 = (($this) + 56|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($15)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 48|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 4095]($18)|0);
 $23 = ($22|0)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($particlesCore) + 16|0);
 HEAP32[$24>>2] = 0;
 $25 = (($particlesCore) + 20|0);
 HEAP32[$25>>2] = 12;
 $26 = (($particlesCore) + 24|0);
 HEAP32[$26>>2] = 0;
 $27 = (($particlesCore) + 28|0);
 HEAP32[$27>>2] = 12;
 $28 = (($particlesCore) + 32|0);
 HEAP32[$28>>2] = 0;
 $29 = (($particlesCore) + 36|0);
 HEAP32[$29>>2] = 4;
 $30 = (($particlesCore) + 40|0);
 HEAP32[$30>>2] = 0;
 $31 = (($particlesCore) + 44|0);
 HEAP32[$31>>2] = 4;
 $32 = HEAP32[$14>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (FUNCTION_TABLE_ii[$34 & 4095]($32)|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_viiii[$38 & 511]($35,$particlesCore,0,0);
 $39 = (($particlesCore) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 HEAP32[$particlesSim>>2] = 0;
 $42 = (($particlesSim) + 4|0);
 HEAP32[$42>>2] = 4;
 $43 = (($particlesSim) + 8|0);
 HEAP32[$43>>2] = 0;
 $44 = (($particlesSim) + 12|0);
 HEAP32[$44>>2] = 12;
 $45 = (($particlesSim) + 16|0);
 HEAP32[$45>>2] = 0;
 $46 = (($particlesSim) + 20|0);
 HEAP32[$46>>2] = 12;
 $47 = (($particlesSim) + 24|0);
 HEAP32[$47>>2] = 0;
 $48 = (($particlesSim) + 28|0);
 HEAP32[$48>>2] = 12;
 $49 = (($particlesSim) + 32|0);
 HEAP32[$49>>2] = 0;
 $50 = (($particlesSim) + 36|0);
 HEAP32[$50>>2] = 4;
 $51 = HEAP32[$14>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 4|0);
 $54 = HEAP32[$53>>2]|0;
 FUNCTION_TABLE_viii[$54 & 4095]($51,$particlesSim,0);
 $55 = (($particlesCore) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 4|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58 & 2147483647;
 $60 = ($59|0)==(0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $$pre$i$i$i = HEAP32[$56>>2]|0;
 $62 = 0;
 while(1) {
  $61 = (($$pre$i$i$i) + ($62<<2)|0);
  $63 = HEAP32[$61>>2]|0;
  $64 = ($63|0)==(0);
  if (!($64)) {
   break;
  }
  $65 = (($62) + 1)|0;
  $66 = ($65>>>0)<($59>>>0);
  if ($66) {
   $62 = $65;
  } else {
   label = 29;
   break;
  }
 }
 if ((label|0) == 29) {
  STACKTOP = sp;return;
 }
 $67 = $62 << 5;
 $68 = (0 - ($63))|0;
 $69 = $63 & $68;
 $70 = Math_imul($69, 125613361)|0;
 $71 = $70 >>> 27;
 $72 = (412480 + ($71<<2)|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73 | $67;
 $75 = (($63) + -1)|0;
 $76 = $75 & $63;
 $77 = ($76|0)==(0);
 L22: do {
  if ($77) {
   $79 = $62;
   while(1) {
    $78 = (($79) + 1)|0;
    $80 = ($78>>>0)<($59>>>0);
    if (!($80)) {
     $$ph10 = $78;$$ph11 = 0;
     break L22;
    }
    $81 = (($$pre$i$i$i) + ($78<<2)|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ($82|0)==(0);
    if ($83) {
     $79 = $78;
    } else {
     $$ph10 = $78;$$ph11 = $82;
     break;
    }
   }
  } else {
   $$ph10 = $62;$$ph11 = $76;
  }
 } while(0);
 $84 = ($74|0)==(-1);
 if ($84) {
  STACKTOP = sp;return;
 }
 $85 = (($2) + 4|0);
 $86 = (($2) + 8|0);
 $$ph1225 = $$ph10;$$ph1326 = $$ph11;$p$0$ph1427 = $74;
 L30: while(1) {
  $89 = $$ph1225 << 5;
  $142 = $$ph1326;$p$017 = $p$0$ph1427;
  while(1) {
   $90 = HEAP32[$49>>2]|0;
   $91 = HEAP32[$50>>2]|0;
   $92 = Math_imul($91, $p$017)|0;
   $93 = (($90) + ($92)|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($94|0)==(0);
   do {
    if (!($95)) {
     $96 = HEAP32[$28>>2]|0;
     $97 = HEAP32[$29>>2]|0;
     $98 = Math_imul($97, $p$017)|0;
     $99 = (($96) + ($98)|0);
     $100 = HEAP16[$99>>1]|0;
     $101 = $94;
     $102 = (($101) + -16|0);
     $103 = (($102) + 16|0);
     $104 = (($103) + 124|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = $105 == Math_fround(0.0);
     if (!($106)) {
      $107 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
      $108 = HEAP32[$3>>2]|0;
      $109 = (($108) + 12|0);
      $110 = HEAP8[$109>>0]|0;
      $111 = (($102) + 12|0);
      $112 = HEAP8[$111>>0]|0;
      __ZNK5physx2Sc5Scene21getDominanceGroupPairEhh($cdom,$107,$110,$112);
      $113 = Math_fround(HEAPF32[$cdom>>2]);
      $114 = $113 == Math_fround(0.0);
      if (!($114)) {
       $115 = $100 & 8;
       $116 = ($115<<16>>16)==(0);
       if ($116) {
        $117 = HEAP32[$24>>2]|0;
        $118 = HEAP32[$25>>2]|0;
        $119 = Math_imul($118, $p$017)|0;
        $120 = (($117) + ($119)|0);
        $121 = HEAP32[$47>>2]|0;
        $122 = HEAP32[$48>>2]|0;
        $123 = Math_imul($122, $p$017)|0;
        $124 = (($121) + ($123)|0);
        $125 = Math_fround(HEAPF32[$124>>2]);
        $126 = $125 == Math_fround(0.0);
        $$sum8 = (($123) + 4)|0;
        $127 = (($121) + ($$sum8)|0);
        if ($126) {
         $128 = Math_fround(HEAPF32[$127>>2]);
         $129 = $128 == Math_fround(0.0);
         if ($129) {
          $$sum9 = (($123) + 8)|0;
          $130 = (($121) + ($$sum9)|0);
          $131 = Math_fround(HEAPF32[$130>>2]);
          $132 = $131 == Math_fround(0.0);
          if ($132) {
           break;
          }
         }
        }
        $133 = (__ZNK5physx2Sc8BodyCore6getSimEv($102)|0);
        __ZN5physx2Sc7BodySim14internalWakeUpEf($133,Math_fround(0.399999976158142089844));
        $134 = Math_fround(HEAPF32[$124>>2]);
        $135 = Math_fround($13 * $134);
        $136 = Math_fround(HEAPF32[$127>>2]);
        $137 = Math_fround($13 * $136);
        $$sum7 = (($123) + 8)|0;
        $138 = (($121) + ($$sum7)|0);
        $139 = Math_fround(HEAPF32[$138>>2]);
        $140 = Math_fround($13 * $139);
        HEAPF32[$2>>2] = $135;
        HEAPF32[$85>>2] = $137;
        HEAPF32[$86>>2] = $140;
        __Z15addImpulseAtPosRN5physx11PxsBodyCoreERKNS_6PxVec3ES4_($103,$2,$120);
       }
      }
     }
    }
   } while(0);
   $141 = ($142|0)==(0);
   if ($141) {
    label = 29;
    break L30;
   }
   $144 = (0 - ($142))|0;
   $145 = $142 & $144;
   $146 = Math_imul($145, 125613361)|0;
   $147 = $146 >>> 27;
   $148 = (412480 + ($147<<2)|0);
   $149 = HEAP32[$148>>2]|0;
   $88 = $149 | $89;
   $150 = (($142) + -1)|0;
   $151 = $150 & $142;
   $152 = HEAP32[$57>>2]|0;
   $153 = $152 & 2147483647;
   $154 = ($151|0)==(0);
   if ($154) {
    $156 = $$ph1225;
    break;
   }
   $143 = ($88|0)==(-1);
   if ($143) {
    label = 29;
    break L30;
   } else {
    $142 = $151;$p$017 = $88;
   }
  }
  while(1) {
   $155 = (($156) + 1)|0;
   $157 = ($155>>>0)<($153>>>0);
   if (!($157)) {
    $$ph = 0;
    break;
   }
   $158 = HEAP32[$56>>2]|0;
   $159 = (($158) + ($155<<2)|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($160|0)==(0);
   if ($161) {
    $156 = $155;
   } else {
    $$ph = $160;
    break;
   }
  }
  $87 = ($88|0)==(-1);
  if ($87) {
   label = 29;
   break;
  } else {
   $$ph1225 = $155;$$ph1326 = $$ph;$p$0$ph1427 = $88;
  }
 }
 if ((label|0) == 29) {
  STACKTOP = sp;return;
 }
}
function __Z15addImpulseAtPosRN5physx11PxsBodyCoreERKNS_6PxVec3ES4_($bodyCore,$impulse,$worldPos) {
 $bodyCore = $bodyCore|0;
 $impulse = $impulse|0;
 $worldPos = $worldPos|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $14 = 0;
 var $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$worldPos>>2]);
 $1 = (($bodyCore) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 - $2);
 $4 = (($worldPos) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($bodyCore) + 20|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($worldPos) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($bodyCore) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = (($impulse) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($8 * $15);
 $17 = (($impulse) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($13 * $18);
 $20 = Math_fround($16 - $19);
 $21 = Math_fround(HEAPF32[$impulse>>2]);
 $22 = Math_fround($13 * $21);
 $23 = Math_fround($3 * $15);
 $24 = Math_fround($22 - $23);
 $25 = Math_fround($3 * $18);
 $26 = Math_fround($8 * $21);
 $27 = Math_fround($25 - $26);
 $28 = (($bodyCore) + 124|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($21 * $29);
 $31 = Math_fround($18 * $29);
 $32 = Math_fround($15 * $29);
 $33 = (($bodyCore) + 64|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($30 + $34);
 HEAPF32[$33>>2] = $35;
 $36 = (($bodyCore) + 68|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($31 + $37);
 HEAPF32[$36>>2] = $38;
 $39 = (($bodyCore) + 72|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($32 + $40);
 HEAPF32[$39>>2] = $41;
 $42 = Math_fround($20 * Math_fround(2.0));
 $43 = Math_fround($24 * Math_fround(2.0));
 $44 = Math_fround($27 * Math_fround(2.0));
 $45 = (($bodyCore) + 12|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 * $46);
 $48 = Math_fround($47 + Math_fround(-0.5));
 $49 = Math_fround(HEAPF32[$bodyCore>>2]);
 $50 = Math_fround($42 * $49);
 $51 = (($bodyCore) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($43 * $52);
 $54 = Math_fround($50 + $53);
 $55 = (($bodyCore) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($44 * $56);
 $58 = Math_fround($54 + $57);
 $59 = Math_fround($42 * $48);
 $60 = Math_fround($44 * $52);
 $61 = Math_fround($43 * $56);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($46 * $62);
 $64 = Math_fround($59 - $63);
 $65 = Math_fround($49 * $58);
 $66 = Math_fround($65 + $64);
 $67 = Math_fround($43 * $48);
 $68 = Math_fround($42 * $56);
 $69 = Math_fround($44 * $49);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($46 * $70);
 $72 = Math_fround($67 - $71);
 $73 = Math_fround($52 * $58);
 $74 = Math_fround($73 + $72);
 $75 = Math_fround($44 * $48);
 $76 = Math_fround($43 * $49);
 $77 = Math_fround($42 * $52);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($46 * $78);
 $80 = Math_fround($75 - $79);
 $81 = Math_fround($56 * $58);
 $82 = Math_fround($80 + $81);
 $83 = (($bodyCore) + 112|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 * $66);
 $86 = (($bodyCore) + 116|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($87 * $74);
 $89 = (($bodyCore) + 120|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($90 * $82);
 $92 = Math_fround($85 * Math_fround(2.0));
 $93 = Math_fround($88 * Math_fround(2.0));
 $94 = Math_fround($91 * Math_fround(2.0));
 $95 = Math_fround($49 * $92);
 $96 = Math_fround($52 * $93);
 $97 = Math_fround($95 + $96);
 $98 = Math_fround($56 * $94);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($48 * $92);
 $101 = Math_fround($52 * $94);
 $102 = Math_fround($56 * $93);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($46 * $103);
 $105 = Math_fround($100 + $104);
 $106 = Math_fround($49 * $99);
 $107 = Math_fround($106 + $105);
 $108 = Math_fround($48 * $93);
 $109 = Math_fround($56 * $92);
 $110 = Math_fround($49 * $94);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($46 * $111);
 $113 = Math_fround($108 + $112);
 $114 = Math_fround($52 * $99);
 $115 = Math_fround($114 + $113);
 $116 = Math_fround($48 * $94);
 $117 = Math_fround($49 * $93);
 $118 = Math_fround($52 * $92);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($46 * $119);
 $121 = Math_fround($116 + $120);
 $122 = Math_fround($56 * $99);
 $123 = Math_fround($121 + $122);
 $124 = (($bodyCore) + 80|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = Math_fround($125 + $107);
 HEAPF32[$124>>2] = $126;
 $127 = (($bodyCore) + 84|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($128 + $115);
 HEAPF32[$127>>2] = $129;
 $130 = (($bodyCore) + 88|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($131 + $123);
 HEAPF32[$130>>2] = $132;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim9startStepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $externalAcceleration = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $externalAcceleration = sp;
 $0 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $1 = (($0) + 1184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 1176|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,116,$6,$9);
 $13 = (($this) + 52|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (__ZNK5physx2Sc18ParticleSystemCore23getExternalAccelerationEv($14)|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$externalAcceleration>>2] = $16;
 $17 = (($externalAcceleration) + 4|0);
 $18 = (($15) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$17>>2] = $19;
 $20 = (($externalAcceleration) + 8|0);
 $21 = (($15) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = HEAP32[$13>>2]|0;
 $24 = (($23) + 8|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = $25 & 2;
 $27 = ($26<<16>>16)==(0);
 if ($27) {
  $28 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
  $29 = (($28) + 32|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($28) + 36|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($28) + 40|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround(HEAPF32[$externalAcceleration>>2]);
  $36 = Math_fround($30 + $35);
  HEAPF32[$externalAcceleration>>2] = $36;
  $37 = Math_fround(HEAPF32[$17>>2]);
  $38 = Math_fround($32 + $37);
  HEAPF32[$17>>2] = $38;
  $39 = Math_fround(HEAPF32[$20>>2]);
  $40 = Math_fround($34 + $39);
  HEAPF32[$20>>2] = $40;
 }
 $41 = (($this) + 56|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($42,$externalAcceleration);
 $46 = HEAP32[$41>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $51 = (($50) + 48|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 FUNCTION_TABLE_vif[$49 & 255]($46,$52);
 $53 = HEAP32[$2>>2]|0;
 $54 = (($53) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 FUNCTION_TABLE_viiii[$55 & 511]($2,116,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim19processShapesUpdateEv($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $i$04 = 0, $i1$03 = 0, $inEnabled$not$i$i$i1 = 0, $or$cond$i$i$i2 = 0, $particleShape$i = 0;
 var $updateResults = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $particleShape$i = sp + 16|0;
 $updateResults = sp;
 $0 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $1 = (($0) + 1184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $4 = (($3) + 1176|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAPU16[545744>>1]|(HEAPU16[545744+2>>1]<<16);
 $12 = $11 & 16711680;
 $inEnabled$not$i$i$i1 = ($12|0)==(0);
 $13 = ($2|0)==(0|0);
 $or$cond$i$i$i2 = $13 | $inEnabled$not$i$i$i1;
 if (!($or$cond$i$i$i2)) {
  $14 = $11&65535;
  $15 = HEAP32[$2>>2]|0;
  $16 = (($15) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_viiii[$17 & 511]($2,$14,$7,$10);
 }
 $18 = (($this) + 56|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vii[$22 & 4095]($19,$updateResults);
 $23 = (($updateResults) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = (($updateResults) + 8|0);
  $27 = (($this) + 60|0);
  $28 = (($this) + 340|0);
  $29 = (($this) + 352|0);
  $30 = (($this) + 344|0);
  $31 = (($this) + 336|0);
  $i$04 = 0;
  while(1) {
   $42 = HEAP32[$26>>2]|0;
   $43 = (($42) + ($i$04<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 16|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (FUNCTION_TABLE_ii[$47 & 4095]($44)|0);
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = HEAP32[$48>>2]|0;
    $51 = HEAP32[$50>>2]|0;
    FUNCTION_TABLE_vi[$51 & 4095]($48);
    $52 = HEAP32[$28>>2]|0;
    $53 = (($52) + -1)|0;
    HEAP32[$28>>2] = $53;
    $54 = HEAP32[$29>>2]|0;
    HEAP32[$48>>2] = $54;
    HEAP32[$29>>2] = $48;
    $55 = HEAP32[$30>>2]|0;
    $56 = (($55) + 1)|0;
    HEAP32[$30>>2] = $56;
    $57 = HEAP32[$31>>2]|0;
    $58 = ($57*50)|0;
    $59 = ($55|0)<($58|0);
    if (!($59)) {
     __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($27);
     HEAP32[$30>>2] = 0;
    }
   }
   $60 = (($i$04) + 1)|0;
   $61 = HEAP32[$23>>2]|0;
   $62 = ($60>>>0)<($61>>>0);
   if ($62) {
    $i$04 = $60;
   } else {
    break;
   }
  }
 }
 $32 = (($updateResults) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 if (!($34)) {
  $35 = (($this) + 356|0);
  $36 = (($this) + 360|0);
  $37 = (($this) + 352|0);
  $38 = (($this) + 60|0);
  $39 = (($this) + 340|0);
  $40 = (($this) + 344|0);
  $41 = (($this) + 364|0);
  $i1$03 = 0;
  while(1) {
   $63 = HEAP32[$updateResults>>2]|0;
   $64 = (($63) + ($i1$03<<2)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[$36>>2]|0;
   $67 = HEAP32[$37>>2]|0;
   $68 = ($67|0)==(0|0);
   if ($68) {
    __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($38);
    $$pre$i$i$i = HEAP32[$37>>2]|0;
    $70 = $$pre$i$i$i;
   } else {
    $70 = $67;
   }
   $69 = HEAP32[$70>>2]|0;
   HEAP32[$37>>2] = $69;
   $71 = HEAP32[$39>>2]|0;
   $72 = (($71) + 1)|0;
   HEAP32[$39>>2] = $72;
   $73 = HEAP32[$40>>2]|0;
   $74 = (($73) + -1)|0;
   HEAP32[$40>>2] = $74;
   $75 = ($70|0)==(0|0);
   do {
    if ($75) {
     HEAP32[$particleShape$i>>2] = 0;
     $76 = HEAP32[$65>>2]|0;
     $77 = (($76) + 20|0);
     $78 = HEAP32[$77>>2]|0;
     FUNCTION_TABLE_vi[$78 & 4095]($65);
    } else {
     __ZN5physx2Sc19ParticlePacketShapeC2ERNS0_17ParticleSystemSimEjPNS_16PxvParticleShapeE($70,$this,$66,$65);
     HEAP32[$particleShape$i>>2] = $70;
     $79 = HEAP32[$41>>2]|0;
     $80 = $79 & 2147483647;
     $81 = HEAP32[$36>>2]|0;
     $82 = ($80>>>0)>($81>>>0);
     if (!($82)) {
      (__ZN5physx6shdfnd5ArrayIPNS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($35,$particleShape$i)|0);
      break;
     }
     $83 = HEAP32[$35>>2]|0;
     $84 = (($83) + ($81<<2)|0);
     $85 = ($84|0)==(0|0);
     if (!($85)) {
      HEAP32[$84>>2] = $70;
     }
     $86 = (($81) + 1)|0;
     HEAP32[$36>>2] = $86;
    }
   } while(0);
   $87 = (($i1$03) + 1)|0;
   $88 = HEAP32[$32>>2]|0;
   $89 = ($87>>>0)<($88>>>0);
   if ($89) {
    $i1$03 = $87;
   } else {
    break;
   }
  }
 }
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return;
 }
 $90 = HEAP32[$2>>2]|0;
 $91 = (($90) + 12|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = $11&65535;
 FUNCTION_TABLE_viiii[$92 & 511]($2,$93,$7,$10);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim7endStepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $1 = (($0) + 1184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 1176|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiii[$12 & 511]($2,117,$6,$9);
 $13 = (($this) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vi[$17 & 4095]($14);
 __ZN5physx2Sc17ParticleSystemSim19processShapesUpdateEv($this);
 __ZN5physx2Sc17ParticleSystemSim17updateRigidBodiesEv($this);
 $18 = HEAP32[$2>>2]|0;
 $19 = (($18) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_viiii[$20 & 511]($2,117,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim18visualizeStartStepERNS_2Cm12RenderOutputE($this,$out) {
 $this = $this|0;
 $out = $out|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, $bounds$i1 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $bounds$i1 = sp + 56|0;
 $0 = sp;
 $1 = sp + 28|0;
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 & 1;
 $7 = ($6<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 HEAPF32[$1>>2] = Math_fround(0.0);
 $8 = (($1) + 4|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($1) + 8|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($1) + 12|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($1) + 16|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($1) + 20|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($1) + 24|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$1)|0);
 $14 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $15 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($14,26)));
 $16 = $15 > Math_fround(0.0);
 if ($16) {
  $17 = (($this) + 56|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_ii[$20 & 4095]($18)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 40|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vii[$24 & 4095]($bounds$i1,$21);
  $25 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65536)|0);
  $26 = Math_fround(HEAPF32[$bounds$i1>>2]);
  HEAPF32[$0>>2] = $26;
  $27 = (($0) + 4|0);
  $28 = (($bounds$i1) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$27>>2] = $29;
  $30 = (($0) + 8|0);
  $31 = (($bounds$i1) + 8|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$30>>2] = $32;
  $33 = (($0) + 12|0);
  $34 = (($bounds$i1) + 12|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  HEAPF32[$33>>2] = $35;
  $36 = (($0) + 16|0);
  $37 = (($bounds$i1) + 16|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$36>>2] = $38;
  $39 = (($0) + 20|0);
  $40 = (($bounds$i1) + 20|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  HEAPF32[$39>>2] = $41;
  $42 = (($0) + 24|0);
  HEAP8[$42>>0] = 1;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($25,$0)|0);
 }
 __ZN5physx2Sc17ParticleSystemSim18visualizeParticlesERNS_2Cm12RenderOutputE($this,$out);
 $43 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $44 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($43,27)));
 $45 = $44 > Math_fround(0.0);
 if ($45) {
  __ZN5physx2Sc17ParticleSystemSim20visualizeSpatialGridERNS_2Cm12RenderOutputE($this,$out);
 }
 $46 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $47 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($46,28)));
 $48 = $47 > Math_fround(0.0);
 if (!($48)) {
  STACKTOP = sp;return;
 }
 $49 = (($this) + 360|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $52 = (($this) + 356|0);
 $53 = (($0) + 4|0);
 $54 = (($bounds$i1) + 4|0);
 $55 = (($0) + 8|0);
 $56 = (($bounds$i1) + 8|0);
 $57 = (($0) + 12|0);
 $58 = (($bounds$i1) + 12|0);
 $59 = (($0) + 16|0);
 $60 = (($bounds$i1) + 16|0);
 $61 = (($0) + 20|0);
 $62 = (($bounds$i1) + 20|0);
 $63 = (($0) + 24|0);
 $i$01$i = 0;
 while(1) {
  $64 = HEAP32[$52>>2]|0;
  $65 = (($64) + ($i$01$i<<2)|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + 44|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = HEAP32[$68>>2]|0;
  $70 = (($69) + 8|0);
  $71 = HEAP32[$70>>2]|0;
  FUNCTION_TABLE_vii[$71 & 4095]($bounds$i1,$68);
  $72 = (__ZN5physx2Cm12RenderOutputlsEj($out,-16776961)|0);
  $73 = Math_fround(HEAPF32[$bounds$i1>>2]);
  HEAPF32[$0>>2] = $73;
  $74 = Math_fround(HEAPF32[$54>>2]);
  HEAPF32[$53>>2] = $74;
  $75 = Math_fround(HEAPF32[$56>>2]);
  HEAPF32[$55>>2] = $75;
  $76 = Math_fround(HEAPF32[$58>>2]);
  HEAPF32[$57>>2] = $76;
  $77 = Math_fround(HEAPF32[$60>>2]);
  HEAPF32[$59>>2] = $77;
  $78 = Math_fround(HEAPF32[$62>>2]);
  HEAPF32[$61>>2] = $78;
  HEAP8[$63>>0] = 1;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($72,$0)|0);
  $79 = (($i$01$i) + 1)|0;
  $80 = HEAP32[$49>>2]|0;
  $81 = ($79>>>0)<($80>>>0);
  if ($81) {
   $i$01$i = $79;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim18visualizeParticlesERNS_2Cm12RenderOutputE($this,$out) {
 $this = $this|0;
 $out = $out|0;
 var $$lcssa96 = 0, $$lcssa97 = 0, $$lcssa97$in = 0, $$not = 0, $$not1 = 0, $$not2 = 0, $$not5 = 0, $$not8 = 0, $$ph = 0, $$ph52 = 0, $$ph53 = 0, $$ph54107 = 0, $$ph55108 = 0, $$ph67 = 0, $$ph69 = 0, $$ph70 = 0, $$ph72110 = 0, $$ph73111 = 0, $$ph87 = 0, $$ph89 = 0;
 var $$ph90 = 0, $$ph92113 = 0, $$ph93114 = 0, $$pre$i$i$i = 0, $$pre$i$i$i20 = 0, $$pre$i$i$i30 = 0, $$sum = 0, $$sum$us = 0, $$sum43 = 0, $$sum43$us = 0, $$sum44$us = 0, $$sum45$us = 0, $$sum46 = 0, $$sum47 = 0, $$sum48 = 0, $$sum49 = 0, $$sum50 = 0, $$sum51 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0);
 var $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0;
 var $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0);
 var $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0;
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = 0;
 var $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = Math_fround(0);
 var $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0);
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge4 = 0, $brmerge7 = 0, $brmerge9 = 0, $p$0$ph94115 = 0, $p$098 = 0, $p$098$us = 0;
 var $p2$0$ph74112 = 0, $p2$078 = 0, $p5$0$ph56109 = 0, $p5$059 = 0, $particlesCore = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $particlesCore = sp + 352|0;
 $0 = sp + 400|0;
 $1 = sp + 402|0;
 $2 = sp + 320|0;
 $3 = sp + 312|0;
 $4 = sp + 280|0;
 $5 = sp + 272|0;
 $6 = sp + 240|0;
 $7 = sp + 232|0;
 $8 = sp + 168|0;
 $9 = sp + 124|0;
 $10 = sp + 112|0;
 $11 = sp + 100|0;
 $12 = sp + 88|0;
 $13 = sp + 76|0;
 $14 = sp + 64|0;
 $15 = sp;
 $16 = sp + 136|0;
 $17 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $18 = (($17) + 48|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($particlesCore) + 16|0);
 HEAP32[$20>>2] = 0;
 $21 = (($particlesCore) + 20|0);
 HEAP32[$21>>2] = 12;
 $22 = (($particlesCore) + 24|0);
 HEAP32[$22>>2] = 0;
 $23 = (($particlesCore) + 28|0);
 HEAP32[$23>>2] = 12;
 $24 = (($particlesCore) + 32|0);
 HEAP32[$24>>2] = 0;
 $25 = (($particlesCore) + 36|0);
 HEAP32[$25>>2] = 4;
 $26 = (($particlesCore) + 40|0);
 HEAP32[$26>>2] = 0;
 $27 = (($particlesCore) + 44|0);
 HEAP32[$27>>2] = 4;
 $28 = (($this) + 56|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_ii[$31 & 4095]($29)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 20|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_viiii[$35 & 511]($32,$particlesCore,0,0);
 $36 = (($particlesCore) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($this) + 52|0);
 $40 = HEAP32[$39>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($0,$40);
 $41 = HEAP16[$0>>1]|0;
 $42 = $41 & 1;
 $43 = HEAP32[$39>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($1,$43);
 $44 = HEAP16[$1>>1]|0;
 $45 = $44 & 2;
 $46 = ($45<<16>>16)!=(0);
 $47 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $48 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($47,29)));
 $$not = !($48 > Math_fround(0.0));
 $$not1 = ($42<<16>>16)==(0);
 $brmerge = $$not | $$not1;
 L4: do {
  if (!($brmerge)) {
   $49 = HEAP32[$39>>2]|0;
   $50 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore20getMaxMotionDistanceEv($49)));
   $51 = (($particlesCore) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = $54 & 2147483647;
   $56 = ($55|0)==(0);
   if (!($56)) {
    $$pre$i$i$i30 = HEAP32[$52>>2]|0;
    $58 = 0;
    while(1) {
     $57 = (($$pre$i$i$i30) + ($58<<2)|0);
     $59 = HEAP32[$57>>2]|0;
     $60 = ($59|0)==(0);
     if (!($60)) {
      break;
     }
     $61 = (($58) + 1)|0;
     $62 = ($61>>>0)<($55>>>0);
     if ($62) {
      $58 = $61;
     } else {
      break L4;
     }
    }
    $63 = $58 << 5;
    $64 = (0 - ($59))|0;
    $65 = $59 & $64;
    $66 = Math_imul($65, 125613361)|0;
    $67 = $66 >>> 27;
    $68 = (412480 + ($67<<2)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = $69 | $63;
    $71 = (($59) + -1)|0;
    $72 = $71 & $59;
    $73 = ($72|0)==(0);
    L11: do {
     if ($73) {
      $75 = $58;
      while(1) {
       $74 = (($75) + 1)|0;
       $76 = ($74>>>0)<($55>>>0);
       if (!($76)) {
        $$ph89 = $74;$$ph90 = 0;
        break L11;
       }
       $77 = (($$pre$i$i$i30) + ($74<<2)|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($78|0)==(0);
       if ($79) {
        $75 = $74;
       } else {
        $$ph89 = $74;$$ph90 = $78;
        break;
       }
      }
     } else {
      $$ph89 = $58;$$ph90 = $72;
     }
    } while(0);
    $80 = ($70|0)==(-1);
    if (!($80)) {
     $81 = Math_fround($50 * Math_fround(0.990000009536743164062));
     $82 = (($2) + 4|0);
     $83 = (($2) + 8|0);
     $84 = (($2) + 12|0);
     $85 = (($2) + 16|0);
     $86 = (($2) + 20|0);
     $87 = (($2) + 24|0);
     $88 = (($3) + 4|0);
     $89 = (($4) + 4|0);
     $90 = (($4) + 8|0);
     $91 = (($4) + 12|0);
     $92 = (($4) + 16|0);
     $93 = (($4) + 20|0);
     $94 = (($4) + 24|0);
     $95 = (($5) + 4|0);
     $96 = (($6) + 4|0);
     $97 = (($6) + 8|0);
     $98 = (($6) + 12|0);
     $99 = (($6) + 16|0);
     $100 = (($6) + 20|0);
     $101 = (($6) + 24|0);
     $102 = (($7) + 4|0);
     $$ph92113 = $$ph89;$$ph93114 = $$ph90;$p$0$ph94115 = $70;
     while(1) {
      $104 = $$ph92113 << 5;
      L19: do {
       if ($46) {
        $141 = $$ph93114;$p$098$us = $p$0$ph94115;
        while(1) {
         $105 = HEAP32[$20>>2]|0;
         $106 = HEAP32[$21>>2]|0;
         $107 = Math_imul($106, $p$098$us)|0;
         $108 = (($105) + ($107)|0);
         $109 = HEAP32[$22>>2]|0;
         $110 = HEAP32[$23>>2]|0;
         $111 = Math_imul($110, $p$098$us)|0;
         $112 = (($109) + ($111)|0);
         $113 = Math_fround(HEAPF32[$112>>2]);
         $114 = Math_fround($113 * $113);
         $$sum44$us = (($111) + 4)|0;
         $115 = (($109) + ($$sum44$us)|0);
         $116 = Math_fround(HEAPF32[$115>>2]);
         $117 = Math_fround($116 * $116);
         $118 = Math_fround($114 + $117);
         $$sum45$us = (($111) + 8)|0;
         $119 = (($109) + ($$sum45$us)|0);
         $120 = Math_fround(HEAPF32[$119>>2]);
         $121 = Math_fround($120 * $120);
         $122 = Math_fround($118 + $121);
         $123 = (Math_fround(Math_sqrt((Math_fround($122)))));
         $124 = Math_fround($19 * $123);
         $125 = !($124 >= $81);
         if ($125) {
          (__ZN5physx2Cm12RenderOutputlsEj($out,-16711936)|0);
         } else {
          (__ZN5physx2Cm12RenderOutputlsEj($out,-65536)|0);
         }
         HEAPF32[$2>>2] = Math_fround(0.0);
         HEAPF32[$82>>2] = Math_fround(0.0);
         HEAPF32[$83>>2] = Math_fround(0.0);
         HEAPF32[$84>>2] = Math_fround(1.0);
         $126 = Math_fround(HEAPF32[$108>>2]);
         HEAPF32[$85>>2] = $126;
         $$sum$us = (($107) + 4)|0;
         $127 = (($105) + ($$sum$us)|0);
         $128 = Math_fround(HEAPF32[$127>>2]);
         HEAPF32[$86>>2] = $128;
         $$sum43$us = (($107) + 8)|0;
         $129 = (($105) + ($$sum43$us)|0);
         $130 = Math_fround(HEAPF32[$129>>2]);
         HEAPF32[$87>>2] = $130;
         $131 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$2)|0);
         HEAP32[$3>>2] = 12;
         HEAPF32[$88>>2] = $50;
         (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($131,$3)|0);
         HEAPF32[$4>>2] = Math_fround(0.0);
         HEAPF32[$89>>2] = Math_fround(0.707106769084930419921);
         HEAPF32[$90>>2] = Math_fround(0.0);
         HEAPF32[$91>>2] = Math_fround(0.707106769084930419921);
         $132 = Math_fround(HEAPF32[$108>>2]);
         HEAPF32[$92>>2] = $132;
         $133 = Math_fround(HEAPF32[$127>>2]);
         HEAPF32[$93>>2] = $133;
         $134 = Math_fround(HEAPF32[$129>>2]);
         HEAPF32[$94>>2] = $134;
         $135 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$4)|0);
         HEAP32[$5>>2] = 12;
         HEAPF32[$95>>2] = $50;
         (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($135,$5)|0);
         HEAPF32[$6>>2] = Math_fround(0.5);
         HEAPF32[$96>>2] = Math_fround(0.5);
         HEAPF32[$97>>2] = Math_fround(0.5);
         HEAPF32[$98>>2] = Math_fround(0.5);
         $136 = Math_fround(HEAPF32[$108>>2]);
         HEAPF32[$99>>2] = $136;
         $137 = Math_fround(HEAPF32[$127>>2]);
         HEAPF32[$100>>2] = $137;
         $138 = Math_fround(HEAPF32[$129>>2]);
         HEAPF32[$101>>2] = $138;
         $139 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$6)|0);
         HEAP32[$7>>2] = 12;
         HEAPF32[$102>>2] = $50;
         (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($139,$7)|0);
         $140 = ($141|0)==(0);
         if ($140) {
          break L4;
         }
         $142 = (0 - ($141))|0;
         $143 = $141 & $142;
         $144 = Math_imul($143, 125613361)|0;
         $145 = $144 >>> 27;
         $146 = (412480 + ($145<<2)|0);
         $147 = HEAP32[$146>>2]|0;
         $148 = $147 | $104;
         $149 = (($141) + -1)|0;
         $150 = $149 & $141;
         $151 = ($150|0)==(0);
         if ($151) {
          $$lcssa96 = $148;
          break L19;
         }
         $152 = ($148|0)==(-1);
         if ($152) {
          break L4;
         } else {
          $141 = $150;$p$098$us = $148;
         }
        }
       } else {
        $172 = $$ph93114;$p$098 = $p$0$ph94115;
        while(1) {
         $153 = HEAP32[$20>>2]|0;
         $154 = HEAP32[$21>>2]|0;
         $155 = Math_imul($154, $p$098)|0;
         $156 = (($153) + ($155)|0);
         (__ZN5physx2Cm12RenderOutputlsEj($out,-16711936)|0);
         HEAPF32[$2>>2] = Math_fround(0.0);
         HEAPF32[$82>>2] = Math_fround(0.0);
         HEAPF32[$83>>2] = Math_fround(0.0);
         HEAPF32[$84>>2] = Math_fround(1.0);
         $157 = Math_fround(HEAPF32[$156>>2]);
         HEAPF32[$85>>2] = $157;
         $$sum = (($155) + 4)|0;
         $158 = (($153) + ($$sum)|0);
         $159 = Math_fround(HEAPF32[$158>>2]);
         HEAPF32[$86>>2] = $159;
         $$sum43 = (($155) + 8)|0;
         $160 = (($153) + ($$sum43)|0);
         $161 = Math_fround(HEAPF32[$160>>2]);
         HEAPF32[$87>>2] = $161;
         $162 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$2)|0);
         HEAP32[$3>>2] = 12;
         HEAPF32[$88>>2] = $50;
         (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($162,$3)|0);
         HEAPF32[$4>>2] = Math_fround(0.0);
         HEAPF32[$89>>2] = Math_fround(0.707106769084930419921);
         HEAPF32[$90>>2] = Math_fround(0.0);
         HEAPF32[$91>>2] = Math_fround(0.707106769084930419921);
         $163 = Math_fround(HEAPF32[$156>>2]);
         HEAPF32[$92>>2] = $163;
         $164 = Math_fround(HEAPF32[$158>>2]);
         HEAPF32[$93>>2] = $164;
         $165 = Math_fround(HEAPF32[$160>>2]);
         HEAPF32[$94>>2] = $165;
         $166 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$4)|0);
         HEAP32[$5>>2] = 12;
         HEAPF32[$95>>2] = $50;
         (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($166,$5)|0);
         HEAPF32[$6>>2] = Math_fround(0.5);
         HEAPF32[$96>>2] = Math_fround(0.5);
         HEAPF32[$97>>2] = Math_fround(0.5);
         HEAPF32[$98>>2] = Math_fround(0.5);
         $167 = Math_fround(HEAPF32[$156>>2]);
         HEAPF32[$99>>2] = $167;
         $168 = Math_fround(HEAPF32[$158>>2]);
         HEAPF32[$100>>2] = $168;
         $169 = Math_fround(HEAPF32[$160>>2]);
         HEAPF32[$101>>2] = $169;
         $170 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$6)|0);
         HEAP32[$7>>2] = 12;
         HEAPF32[$102>>2] = $50;
         (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($170,$7)|0);
         $171 = ($172|0)==(0);
         if ($171) {
          break L4;
         }
         $175 = (0 - ($172))|0;
         $176 = $172 & $175;
         $177 = Math_imul($176, 125613361)|0;
         $178 = $177 >>> 27;
         $179 = (412480 + ($178<<2)|0);
         $180 = HEAP32[$179>>2]|0;
         $174 = $180 | $104;
         $181 = (($172) + -1)|0;
         $182 = $181 & $172;
         $183 = ($182|0)==(0);
         if ($183) {
          $$lcssa96 = $174;
          break L19;
         }
         $173 = ($174|0)==(-1);
         if ($173) {
          break L4;
         } else {
          $172 = $182;$p$098 = $174;
         }
        }
       }
      } while(0);
      $$lcssa97$in = HEAP32[$53>>2]|0;
      $$lcssa97 = $$lcssa97$in & 2147483647;
      $185 = $$ph92113;
      while(1) {
       $184 = (($185) + 1)|0;
       $186 = ($184>>>0)<($$lcssa97>>>0);
       if (!($186)) {
        $$ph87 = 0;
        break;
       }
       $187 = HEAP32[$52>>2]|0;
       $188 = (($187) + ($184<<2)|0);
       $189 = HEAP32[$188>>2]|0;
       $190 = ($189|0)==(0);
       if ($190) {
        $185 = $184;
       } else {
        $$ph87 = $189;
        break;
       }
      }
      $103 = ($$lcssa96|0)==(-1);
      if ($103) {
       break;
      } else {
       $$ph92113 = $184;$$ph93114 = $$ph87;$p$0$ph94115 = $$lcssa96;
      }
     }
    }
   }
  }
 } while(0);
 $191 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $192 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($191,23)));
 $$not2 = !($192 > Math_fround(0.0));
 $brmerge4 = $$not2 | $$not1;
 L38: do {
  if (!($brmerge4)) {
   $193 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
   $194 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($193,23)));
   $195 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
   $196 = (($195) + 1416|0);
   $197 = Math_fround(HEAPF32[$196>>2]);
   $198 = Math_fround($194 * $197);
   $199 = Math_fround($198 * Math_fround(0.5));
   $200 = (__ZN5physx2Cm12RenderOutputlsEj($out,-16776961)|0);
   $201 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($200,1)|0);
   HEAPF32[$8>>2] = Math_fround(1.0);
   $202 = (($8) + 4|0);
   $203 = (($8) + 20|0);
   ;HEAP32[$202+0>>2]=0|0;HEAP32[$202+4>>2]=0|0;HEAP32[$202+8>>2]=0|0;HEAP32[$202+12>>2]=0|0;
   HEAPF32[$203>>2] = Math_fround(1.0);
   $204 = (($8) + 24|0);
   $205 = (($8) + 40|0);
   ;HEAP32[$204+0>>2]=0|0;HEAP32[$204+4>>2]=0|0;HEAP32[$204+8>>2]=0|0;HEAP32[$204+12>>2]=0|0;
   HEAPF32[$205>>2] = Math_fround(1.0);
   $206 = (($8) + 44|0);
   $207 = (($8) + 60|0);
   ;HEAP32[$206+0>>2]=0|0;HEAP32[$206+4>>2]=0|0;HEAP32[$206+8>>2]=0|0;HEAP32[$206+12>>2]=0|0;
   HEAPF32[$207>>2] = Math_fround(1.0);
   (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($201,$8)|0);
   $208 = (($particlesCore) + 12|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = (($209) + 4|0);
   $211 = HEAP32[$210>>2]|0;
   $212 = $211 & 2147483647;
   $213 = ($212|0)==(0);
   if (!($213)) {
    $$pre$i$i$i20 = HEAP32[$209>>2]|0;
    $215 = 0;
    while(1) {
     $214 = (($$pre$i$i$i20) + ($215<<2)|0);
     $216 = HEAP32[$214>>2]|0;
     $217 = ($216|0)==(0);
     if (!($217)) {
      break;
     }
     $218 = (($215) + 1)|0;
     $219 = ($218>>>0)<($212>>>0);
     if ($219) {
      $215 = $218;
     } else {
      break L38;
     }
    }
    $220 = $215 << 5;
    $221 = (0 - ($216))|0;
    $222 = $216 & $221;
    $223 = Math_imul($222, 125613361)|0;
    $224 = $223 >>> 27;
    $225 = (412480 + ($224<<2)|0);
    $226 = HEAP32[$225>>2]|0;
    $227 = $226 | $220;
    $228 = (($216) + -1)|0;
    $229 = $228 & $216;
    $230 = ($229|0)==(0);
    L45: do {
     if ($230) {
      $232 = $215;
      while(1) {
       $231 = (($232) + 1)|0;
       $233 = ($231>>>0)<($212>>>0);
       if (!($233)) {
        $$ph69 = $231;$$ph70 = 0;
        break L45;
       }
       $234 = (($$pre$i$i$i20) + ($231<<2)|0);
       $235 = HEAP32[$234>>2]|0;
       $236 = ($235|0)==(0);
       if ($236) {
        $232 = $231;
       } else {
        $$ph69 = $231;$$ph70 = $235;
        break;
       }
      }
     } else {
      $$ph69 = $215;$$ph70 = $229;
     }
    } while(0);
    $237 = ($227|0)==(-1);
    if (!($237)) {
     $238 = (($9) + 4|0);
     $239 = (($9) + 8|0);
     $240 = (($10) + 4|0);
     $241 = (($10) + 8|0);
     $242 = (($11) + 4|0);
     $243 = (($11) + 8|0);
     $244 = (($12) + 4|0);
     $245 = (($12) + 8|0);
     $246 = (($13) + 4|0);
     $247 = (($13) + 8|0);
     $248 = (($14) + 4|0);
     $249 = (($14) + 8|0);
     $$ph72110 = $$ph69;$$ph73111 = $$ph70;$p2$0$ph74112 = $227;
     while(1) {
      $252 = $$ph72110 << 5;
      $293 = $$ph73111;$p2$078 = $p2$0$ph74112;
      while(1) {
       $253 = HEAP32[$20>>2]|0;
       $254 = HEAP32[$21>>2]|0;
       $255 = Math_imul($254, $p2$078)|0;
       $256 = (($253) + ($255)|0);
       $257 = Math_fround(HEAPF32[$256>>2]);
       $258 = Math_fround($257 + Math_fround(0.0));
       $$sum46 = (($255) + 4)|0;
       $259 = (($253) + ($$sum46)|0);
       $260 = Math_fround(HEAPF32[$259>>2]);
       $261 = Math_fround($260 + Math_fround(0.0));
       $$sum47 = (($255) + 8)|0;
       $262 = (($253) + ($$sum47)|0);
       $263 = Math_fround(HEAPF32[$262>>2]);
       $264 = Math_fround($199 + $263);
       HEAPF32[$9>>2] = $258;
       HEAPF32[$238>>2] = $261;
       HEAPF32[$239>>2] = $264;
       $265 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$9)|0);
       $266 = Math_fround(HEAPF32[$256>>2]);
       $267 = Math_fround(HEAPF32[$259>>2]);
       $268 = Math_fround(HEAPF32[$262>>2]);
       $269 = Math_fround($268 - $199);
       HEAPF32[$10>>2] = $266;
       HEAPF32[$240>>2] = $267;
       HEAPF32[$241>>2] = $269;
       (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($265,$10)|0);
       $270 = Math_fround(HEAPF32[$256>>2]);
       $271 = Math_fround($270 + Math_fround(0.0));
       $272 = Math_fround(HEAPF32[$259>>2]);
       $273 = Math_fround($199 + $272);
       $274 = Math_fround(HEAPF32[$262>>2]);
       $275 = Math_fround($274 + Math_fround(0.0));
       HEAPF32[$11>>2] = $271;
       HEAPF32[$242>>2] = $273;
       HEAPF32[$243>>2] = $275;
       $276 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$11)|0);
       $277 = Math_fround(HEAPF32[$256>>2]);
       $278 = Math_fround(HEAPF32[$259>>2]);
       $279 = Math_fround($278 - $199);
       $280 = Math_fround(HEAPF32[$262>>2]);
       HEAPF32[$12>>2] = $277;
       HEAPF32[$244>>2] = $279;
       HEAPF32[$245>>2] = $280;
       (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($276,$12)|0);
       $281 = Math_fround(HEAPF32[$256>>2]);
       $282 = Math_fround($199 + $281);
       $283 = Math_fround(HEAPF32[$259>>2]);
       $284 = Math_fround($283 + Math_fround(0.0));
       $285 = Math_fround(HEAPF32[$262>>2]);
       $286 = Math_fround($285 + Math_fround(0.0));
       HEAPF32[$13>>2] = $282;
       HEAPF32[$246>>2] = $284;
       HEAPF32[$247>>2] = $286;
       $287 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$13)|0);
       $288 = Math_fround(HEAPF32[$256>>2]);
       $289 = Math_fround($288 - $199);
       $290 = Math_fround(HEAPF32[$259>>2]);
       $291 = Math_fround(HEAPF32[$262>>2]);
       HEAPF32[$14>>2] = $289;
       HEAPF32[$248>>2] = $290;
       HEAPF32[$249>>2] = $291;
       (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($287,$14)|0);
       $292 = ($293|0)==(0);
       if ($292) {
        break L38;
       }
       $295 = (0 - ($293))|0;
       $296 = $293 & $295;
       $297 = Math_imul($296, 125613361)|0;
       $298 = $297 >>> 27;
       $299 = (412480 + ($298<<2)|0);
       $300 = HEAP32[$299>>2]|0;
       $251 = $300 | $252;
       $301 = (($293) + -1)|0;
       $302 = $301 & $293;
       $303 = HEAP32[$210>>2]|0;
       $304 = $303 & 2147483647;
       $305 = ($302|0)==(0);
       if ($305) {
        $307 = $$ph72110;
        break;
       }
       $294 = ($251|0)==(-1);
       if ($294) {
        break L38;
       } else {
        $293 = $302;$p2$078 = $251;
       }
      }
      while(1) {
       $306 = (($307) + 1)|0;
       $308 = ($306>>>0)<($304>>>0);
       if (!($308)) {
        $$ph67 = 0;
        break;
       }
       $309 = HEAP32[$209>>2]|0;
       $310 = (($309) + ($306<<2)|0);
       $311 = HEAP32[$310>>2]|0;
       $312 = ($311|0)==(0);
       if ($312) {
        $307 = $306;
       } else {
        $$ph67 = $311;
        break;
       }
      }
      $250 = ($251|0)==(-1);
      if ($250) {
       break;
      } else {
       $$ph72110 = $306;$$ph73111 = $$ph67;$p2$0$ph74112 = $251;
      }
     }
    }
   }
  }
 } while(0);
 $313 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $314 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($313,24)));
 $$not5 = !($314 > Math_fround(0.0));
 $brmerge7 = $$not5 | $$not1;
 $$not8 = $46 ^ 1;
 $brmerge9 = $brmerge7 | $$not8;
 if ($brmerge9) {
  STACKTOP = sp;return;
 }
 $315 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $316 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($315,24)));
 $317 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $318 = (($317) + 1416|0);
 $319 = Math_fround(HEAPF32[$318>>2]);
 $320 = Math_fround($316 * $319);
 $321 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65536)|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $322 = (($15) + 4|0);
 $323 = (($15) + 20|0);
 ;HEAP32[$322+0>>2]=0|0;HEAP32[$322+4>>2]=0|0;HEAP32[$322+8>>2]=0|0;HEAP32[$322+12>>2]=0|0;
 HEAPF32[$323>>2] = Math_fround(1.0);
 $324 = (($15) + 24|0);
 $325 = (($15) + 40|0);
 ;HEAP32[$324+0>>2]=0|0;HEAP32[$324+4>>2]=0|0;HEAP32[$324+8>>2]=0|0;HEAP32[$324+12>>2]=0|0;
 HEAPF32[$325>>2] = Math_fround(1.0);
 $326 = (($15) + 44|0);
 $327 = (($15) + 60|0);
 ;HEAP32[$326+0>>2]=0|0;HEAP32[$326+4>>2]=0|0;HEAP32[$326+8>>2]=0|0;HEAP32[$326+12>>2]=0|0;
 HEAPF32[$327>>2] = Math_fround(1.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($321,$15)|0);
 $328 = (($particlesCore) + 12|0);
 $329 = HEAP32[$328>>2]|0;
 $330 = (($329) + 4|0);
 $331 = HEAP32[$330>>2]|0;
 $332 = $331 & 2147483647;
 $333 = ($332|0)==(0);
 if ($333) {
  STACKTOP = sp;return;
 }
 $$pre$i$i$i = HEAP32[$329>>2]|0;
 $335 = 0;
 while(1) {
  $334 = (($$pre$i$i$i) + ($335<<2)|0);
  $336 = HEAP32[$334>>2]|0;
  $337 = ($336|0)==(0);
  if (!($337)) {
   break;
  }
  $338 = (($335) + 1)|0;
  $339 = ($338>>>0)<($332>>>0);
  if ($339) {
   $335 = $338;
  } else {
   label = 60;
   break;
  }
 }
 if ((label|0) == 60) {
  STACKTOP = sp;return;
 }
 $340 = $335 << 5;
 $341 = (0 - ($336))|0;
 $342 = $336 & $341;
 $343 = Math_imul($342, 125613361)|0;
 $344 = $343 >>> 27;
 $345 = (412480 + ($344<<2)|0);
 $346 = HEAP32[$345>>2]|0;
 $347 = $346 | $340;
 $348 = (($336) + -1)|0;
 $349 = $348 & $336;
 $350 = ($349|0)==(0);
 L74: do {
  if ($350) {
   $352 = $335;
   while(1) {
    $351 = (($352) + 1)|0;
    $353 = ($351>>>0)<($332>>>0);
    if (!($353)) {
     $$ph52 = $351;$$ph53 = 0;
     break L74;
    }
    $354 = (($$pre$i$i$i) + ($351<<2)|0);
    $355 = HEAP32[$354>>2]|0;
    $356 = ($355|0)==(0);
    if ($356) {
     $352 = $351;
    } else {
     $$ph52 = $351;$$ph53 = $355;
     break;
    }
   }
  } else {
   $$ph52 = $335;$$ph53 = $349;
  }
 } while(0);
 $357 = ($347|0)==(-1);
 if ($357) {
  STACKTOP = sp;return;
 }
 $358 = (($16) + 4|0);
 $359 = (($16) + 8|0);
 $360 = (($16) + 12|0);
 $361 = (($16) + 16|0);
 $362 = (($16) + 20|0);
 $363 = (($16) + 24|0);
 $$ph54107 = $$ph52;$$ph55108 = $$ph53;$p5$0$ph56109 = $347;
 L82: while(1) {
  $366 = $$ph54107 << 5;
  $395 = $$ph55108;$p5$059 = $p5$0$ph56109;
  while(1) {
   $367 = HEAP32[$20>>2]|0;
   $368 = HEAP32[$21>>2]|0;
   $369 = Math_imul($368, $p5$059)|0;
   $370 = (($367) + ($369)|0);
   $371 = HEAP32[$22>>2]|0;
   $372 = HEAP32[$23>>2]|0;
   $373 = Math_imul($372, $p5$059)|0;
   $374 = (($371) + ($373)|0);
   $375 = Math_fround(HEAPF32[$374>>2]);
   $376 = Math_fround($19 * $375);
   $$sum48 = (($373) + 4)|0;
   $377 = (($371) + ($$sum48)|0);
   $378 = Math_fround(HEAPF32[$377>>2]);
   $379 = Math_fround($19 * $378);
   $$sum49 = (($373) + 8)|0;
   $380 = (($371) + ($$sum49)|0);
   $381 = Math_fround(HEAPF32[$380>>2]);
   $382 = Math_fround($19 * $381);
   $383 = Math_fround(HEAPF32[$370>>2]);
   HEAPF32[$16>>2] = $383;
   $$sum50 = (($369) + 4)|0;
   $384 = (($367) + ($$sum50)|0);
   $385 = Math_fround(HEAPF32[$384>>2]);
   HEAPF32[$358>>2] = $385;
   $$sum51 = (($369) + 8)|0;
   $386 = (($367) + ($$sum51)|0);
   $387 = Math_fround(HEAPF32[$386>>2]);
   HEAPF32[$359>>2] = $387;
   $388 = Math_fround(HEAPF32[$370>>2]);
   $389 = Math_fround($376 + $388);
   $390 = Math_fround(HEAPF32[$384>>2]);
   $391 = Math_fround($379 + $390);
   $392 = Math_fround(HEAPF32[$386>>2]);
   $393 = Math_fround($382 + $392);
   HEAPF32[$360>>2] = $389;
   HEAPF32[$361>>2] = $391;
   HEAPF32[$362>>2] = $393;
   HEAPF32[$363>>2] = $320;
   (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($out,$16)|0);
   $394 = ($395|0)==(0);
   if ($394) {
    label = 60;
    break L82;
   }
   $397 = (0 - ($395))|0;
   $398 = $395 & $397;
   $399 = Math_imul($398, 125613361)|0;
   $400 = $399 >>> 27;
   $401 = (412480 + ($400<<2)|0);
   $402 = HEAP32[$401>>2]|0;
   $365 = $402 | $366;
   $403 = (($395) + -1)|0;
   $404 = $403 & $395;
   $405 = HEAP32[$330>>2]|0;
   $406 = $405 & 2147483647;
   $407 = ($404|0)==(0);
   if ($407) {
    $409 = $$ph54107;
    break;
   }
   $396 = ($365|0)==(-1);
   if ($396) {
    label = 60;
    break L82;
   } else {
    $395 = $404;$p5$059 = $365;
   }
  }
  while(1) {
   $408 = (($409) + 1)|0;
   $410 = ($408>>>0)<($406>>>0);
   if (!($410)) {
    $$ph = 0;
    break;
   }
   $411 = HEAP32[$329>>2]|0;
   $412 = (($411) + ($408<<2)|0);
   $413 = HEAP32[$412>>2]|0;
   $414 = ($413|0)==(0);
   if ($414) {
    $409 = $408;
   } else {
    $$ph = $413;
    break;
   }
  }
  $364 = ($365|0)==(-1);
  if ($364) {
   label = 60;
   break;
  } else {
   $$ph54107 = $408;$$ph55108 = $$ph;$p5$0$ph56109 = $365;
  }
 }
 if ((label|0) == 60) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc17ParticleSystemSim20visualizeSpatialGridERNS_2Cm12RenderOutputE($this,$out) {
 $this = $this|0;
 $out = $out|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $bounds = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $bounds = sp + 32|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (Math_fround(__ZNK5physx2Sc18ParticleSystemCore11getGridSizeEv($2)));
 $4 = (($this) + 360|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 356|0);
 $8 = (($bounds) + 12|0);
 $9 = (($bounds) + 4|0);
 $10 = (($bounds) + 16|0);
 $11 = (($bounds) + 8|0);
 $12 = (($bounds) + 20|0);
 $13 = Math_fround(Math_fround(1.0) / $3);
 $14 = (($0) + 4|0);
 $15 = (($0) + 8|0);
 $16 = (($0) + 12|0);
 $17 = (($0) + 16|0);
 $18 = (($0) + 20|0);
 $19 = (($0) + 24|0);
 $i$03 = 0;
 while(1) {
  $20 = HEAP32[$7>>2]|0;
  $21 = (($20) + ($i$03<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 44|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vii[$27 & 4095]($bounds,$24);
  $28 = Math_fround(HEAPF32[$bounds>>2]);
  $29 = Math_fround(HEAPF32[$8>>2]);
  $30 = Math_fround($28 + $29);
  $31 = Math_fround(HEAPF32[$9>>2]);
  $32 = Math_fround(HEAPF32[$10>>2]);
  $33 = Math_fround($31 + $32);
  $34 = Math_fround(HEAPF32[$11>>2]);
  $35 = Math_fround(HEAPF32[$12>>2]);
  $36 = Math_fround($34 + $35);
  $37 = Math_fround($30 * Math_fround(0.5));
  $38 = Math_fround($33 * Math_fround(0.5));
  $39 = Math_fround($36 * Math_fround(0.5));
  $40 = Math_fround($37 * $13);
  $41 = Math_fround($38 * $13);
  $42 = Math_fround($13 * $39);
  $43 = (Math_fround(Math_floor((Math_fround($40)))));
  $44 = Math_fround($3 * $43);
  HEAPF32[$bounds>>2] = $44;
  $45 = (Math_fround(Math_floor((Math_fround($41)))));
  $46 = Math_fround($3 * $45);
  $47 = (($bounds) + 4|0);
  HEAPF32[$47>>2] = $46;
  $48 = (Math_fround(Math_floor((Math_fround($42)))));
  $49 = Math_fround($3 * $48);
  $50 = (($bounds) + 8|0);
  HEAPF32[$50>>2] = $49;
  $51 = (Math_fround(Math_ceil((Math_fround($40)))));
  $52 = Math_fround($3 * $51);
  HEAPF32[$8>>2] = $52;
  $53 = (Math_fround(Math_ceil((Math_fround($41)))));
  $54 = Math_fround($3 * $53);
  $55 = (($8) + 4|0);
  HEAPF32[$55>>2] = $54;
  $56 = (Math_fround(Math_ceil((Math_fround($42)))));
  $57 = Math_fround($3 * $56);
  $58 = (($8) + 8|0);
  HEAPF32[$58>>2] = $57;
  $59 = (__ZN5physx2Cm12RenderOutputlsEj($out,-16776961)|0);
  $60 = Math_fround(HEAPF32[$bounds>>2]);
  HEAPF32[$0>>2] = $60;
  $61 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$14>>2] = $61;
  $62 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$15>>2] = $62;
  $63 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$16>>2] = $63;
  $64 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$17>>2] = $64;
  $65 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$18>>2] = $65;
  HEAP8[$19>>0] = 1;
  (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($59,$0)|0);
  $66 = (($i$03) + 1)|0;
  $67 = HEAP32[$4>>2]|0;
  $68 = ($66>>>0)<($67>>>0);
  if ($68) {
   $i$03 = $66;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim16visualizeEndStepERNS_2Cm12RenderOutputE($this,$out) {
 $this = $this|0;
 $out = $out|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 1;
 $6 = ($5<<16>>16)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = Math_fround(0.0);
 $7 = (($0) + 4|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($0) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($0) + 12|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($0) + 16|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($0) + 20|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($0) + 24|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$0)|0);
 __ZN5physx2Sc17ParticleSystemSim25visualizeCollisionNormalsERNS_2Cm12RenderOutputE($this,$out);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSim25visualizeCollisionNormalsERNS_2Cm12RenderOutputE($this,$out) {
 $this = $this|0;
 $out = $out|0;
 var $$not = 0, $$not1 = 0, $$not2 = 0, $$ph = 0, $$ph16 = 0, $$ph17 = 0, $$ph1831 = 0, $$ph1932 = 0, $$pre$i$i$i = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge3 = 0, $p$0$ph2033 = 0, $p$023 = 0, $particlesCore = 0, $particlesSim = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $particlesCore = sp + 136|0;
 $0 = sp + 186|0;
 $1 = sp + 184|0;
 $particlesSim = sp + 96|0;
 $2 = sp + 32|0;
 $3 = sp;
 $4 = (($particlesCore) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($particlesCore) + 20|0);
 HEAP32[$5>>2] = 12;
 $6 = (($particlesCore) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($particlesCore) + 28|0);
 HEAP32[$7>>2] = 12;
 $8 = (($particlesCore) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = (($particlesCore) + 36|0);
 HEAP32[$9>>2] = 4;
 $10 = (($particlesCore) + 40|0);
 HEAP32[$10>>2] = 0;
 $11 = (($particlesCore) + 44|0);
 HEAP32[$11>>2] = 4;
 $12 = (($this) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($13)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_viiii[$19 & 511]($16,$particlesCore,0,0);
 $20 = (($particlesCore) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (($this) + 52|0);
 $24 = HEAP32[$23>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($0,$24);
 $25 = HEAP16[$0>>1]|0;
 $26 = $25 & 1;
 $27 = HEAP32[$23>>2]|0;
 __ZNK5physx2Sc18ParticleSystemCore24getParticleReadDataFlagsEv($1,$27);
 $28 = HEAP16[$1>>1]|0;
 $29 = $28 & 16;
 $30 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $31 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($30,25)));
 $$not = !($31 > Math_fround(0.0));
 $$not1 = ($26<<16>>16)==(0);
 $brmerge = $$not | $$not1;
 $$not2 = ($29<<16>>16)==(0);
 $brmerge3 = $brmerge | $$not2;
 if ($brmerge3) {
  STACKTOP = sp;return;
 }
 HEAP32[$particlesSim>>2] = 0;
 $32 = (($particlesSim) + 4|0);
 HEAP32[$32>>2] = 4;
 $33 = (($particlesSim) + 8|0);
 HEAP32[$33>>2] = 0;
 $34 = (($particlesSim) + 12|0);
 HEAP32[$34>>2] = 12;
 $35 = (($particlesSim) + 16|0);
 HEAP32[$35>>2] = 0;
 $36 = (($particlesSim) + 20|0);
 HEAP32[$36>>2] = 12;
 $37 = (($particlesSim) + 24|0);
 HEAP32[$37>>2] = 0;
 $38 = (($particlesSim) + 28|0);
 HEAP32[$38>>2] = 12;
 $39 = (($particlesSim) + 32|0);
 HEAP32[$39>>2] = 0;
 $40 = (($particlesSim) + 36|0);
 HEAP32[$40>>2] = 4;
 $41 = HEAP32[$12>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 4|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_viii[$44 & 4095]($41,$particlesSim,0);
 $45 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $46 = (Math_fround(__ZNK5physx2Sc5Scene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($45,25)));
 $47 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $48 = (($47) + 1416|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($46 * $49);
 $51 = (__ZN5physx2Cm12RenderOutputlsEj($out,-16711936)|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $52 = (($2) + 4|0);
 $53 = (($2) + 20|0);
 ;HEAP32[$52+0>>2]=0|0;HEAP32[$52+4>>2]=0|0;HEAP32[$52+8>>2]=0|0;HEAP32[$52+12>>2]=0|0;
 HEAPF32[$53>>2] = Math_fround(1.0);
 $54 = (($2) + 24|0);
 $55 = (($2) + 40|0);
 ;HEAP32[$54+0>>2]=0|0;HEAP32[$54+4>>2]=0|0;HEAP32[$54+8>>2]=0|0;HEAP32[$54+12>>2]=0|0;
 HEAPF32[$55>>2] = Math_fround(1.0);
 $56 = (($2) + 44|0);
 $57 = (($2) + 60|0);
 ;HEAP32[$56+0>>2]=0|0;HEAP32[$56+4>>2]=0|0;HEAP32[$56+8>>2]=0|0;HEAP32[$56+12>>2]=0|0;
 HEAPF32[$57>>2] = Math_fround(1.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($51,$2)|0);
 $58 = HEAP32[$33>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  STACKTOP = sp;return;
 }
 $60 = (($particlesCore) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($61) + 4|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = $63 & 2147483647;
 $65 = ($64|0)==(0);
 if ($65) {
  STACKTOP = sp;return;
 }
 $$pre$i$i$i = HEAP32[$61>>2]|0;
 $67 = 0;
 while(1) {
  $66 = (($$pre$i$i$i) + ($67<<2)|0);
  $68 = HEAP32[$66>>2]|0;
  $69 = ($68|0)==(0);
  if (!($69)) {
   break;
  }
  $70 = (($67) + 1)|0;
  $71 = ($70>>>0)<($64>>>0);
  if ($71) {
   $67 = $70;
  } else {
   label = 24;
   break;
  }
 }
 if ((label|0) == 24) {
  STACKTOP = sp;return;
 }
 $72 = $67 << 5;
 $73 = (0 - ($68))|0;
 $74 = $68 & $73;
 $75 = Math_imul($74, 125613361)|0;
 $76 = $75 >>> 27;
 $77 = (412480 + ($76<<2)|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = $78 | $72;
 $80 = (($68) + -1)|0;
 $81 = $80 & $68;
 $82 = ($81|0)==(0);
 L19: do {
  if ($82) {
   $84 = $67;
   while(1) {
    $83 = (($84) + 1)|0;
    $85 = ($83>>>0)<($64>>>0);
    if (!($85)) {
     $$ph16 = $83;$$ph17 = 0;
     break L19;
    }
    $86 = (($$pre$i$i$i) + ($83<<2)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(0);
    if ($88) {
     $84 = $83;
    } else {
     $$ph16 = $83;$$ph17 = $87;
     break;
    }
   }
  } else {
   $$ph16 = $67;$$ph17 = $81;
  }
 } while(0);
 $89 = ($79|0)==(-1);
 if ($89) {
  STACKTOP = sp;return;
 }
 $90 = Math_fround($50 * Math_fround(0.100000001490116119385));
 $91 = (($3) + 4|0);
 $92 = (($3) + 8|0);
 $93 = (($3) + 12|0);
 $94 = (($3) + 16|0);
 $95 = (($3) + 20|0);
 $96 = (($3) + 24|0);
 $$ph1831 = $$ph16;$$ph1932 = $$ph17;$p$0$ph2033 = $79;
 L27: while(1) {
  $99 = $$ph1831 << 5;
  $134 = $$ph1932;$p$023 = $p$0$ph2033;
  while(1) {
   $100 = HEAP32[$33>>2]|0;
   $101 = HEAP32[$34>>2]|0;
   $102 = Math_imul($101, $p$023)|0;
   $103 = (($100) + ($102)|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = $104 == Math_fround(0.0);
   $$sum14 = (($102) + 4)|0;
   $106 = (($100) + ($$sum14)|0);
   if ($105) {
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = $107 == Math_fround(0.0);
    if ($108) {
     $$sum15 = (($102) + 8)|0;
     $109 = (($100) + ($$sum15)|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = $110 == Math_fround(0.0);
     if (!($111)) {
      label = 18;
     }
    } else {
     label = 18;
    }
   } else {
    label = 18;
   }
   if ((label|0) == 18) {
    label = 0;
    $112 = HEAP32[$4>>2]|0;
    $113 = HEAP32[$5>>2]|0;
    $114 = Math_imul($113, $p$023)|0;
    $115 = (($112) + ($114)|0);
    $116 = Math_fround($50 * $104);
    $117 = Math_fround(HEAPF32[$106>>2]);
    $118 = Math_fround($50 * $117);
    $$sum11 = (($102) + 8)|0;
    $119 = (($100) + ($$sum11)|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = Math_fround($50 * $120);
    $122 = Math_fround(HEAPF32[$115>>2]);
    HEAPF32[$3>>2] = $122;
    $$sum12 = (($114) + 4)|0;
    $123 = (($112) + ($$sum12)|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    HEAPF32[$91>>2] = $124;
    $$sum13 = (($114) + 8)|0;
    $125 = (($112) + ($$sum13)|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    HEAPF32[$92>>2] = $126;
    $127 = Math_fround(HEAPF32[$115>>2]);
    $128 = Math_fround($116 + $127);
    $129 = Math_fround(HEAPF32[$123>>2]);
    $130 = Math_fround($118 + $129);
    $131 = Math_fround(HEAPF32[$125>>2]);
    $132 = Math_fround($121 + $131);
    HEAPF32[$93>>2] = $128;
    HEAPF32[$94>>2] = $130;
    HEAPF32[$95>>2] = $132;
    HEAPF32[$96>>2] = $90;
    (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($out,$3)|0);
   }
   $133 = ($134|0)==(0);
   if ($133) {
    label = 24;
    break L27;
   }
   $136 = (0 - ($134))|0;
   $137 = $134 & $136;
   $138 = Math_imul($137, 125613361)|0;
   $139 = $138 >>> 27;
   $140 = (412480 + ($139<<2)|0);
   $141 = HEAP32[$140>>2]|0;
   $98 = $141 | $99;
   $142 = (($134) + -1)|0;
   $143 = $142 & $134;
   $144 = HEAP32[$62>>2]|0;
   $145 = $144 & 2147483647;
   $146 = ($143|0)==(0);
   if ($146) {
    $148 = $$ph1831;
    break;
   }
   $135 = ($98|0)==(-1);
   if ($135) {
    label = 24;
    break L27;
   } else {
    $134 = $143;$p$023 = $98;
   }
  }
  while(1) {
   $147 = (($148) + 1)|0;
   $149 = ($147>>>0)<($145>>>0);
   if (!($149)) {
    $$ph = 0;
    break;
   }
   $150 = HEAP32[$61>>2]|0;
   $151 = (($150) + ($147<<2)|0);
   $152 = HEAP32[$151>>2]|0;
   $153 = ($152|0)==(0);
   if ($153) {
    $148 = $147;
   } else {
    $$ph = $152;
    break;
   }
  }
  $97 = ($98|0)==(-1);
  if ($97) {
   label = 24;
   break;
  } else {
   $$ph1831 = $147;$$ph1932 = $$ph;$p$0$ph2033 = $98;
  }
 }
 if ((label|0) == 24) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc17ParticleSystemSim23scheduleShapeGenerationERNS0_16InteractionSceneERKNS_6shdfnd5ArrayIPS1_NS4_19ReflectionAllocatorIS6_EEEERNS_10PxBaseTaskE($scene,$particleSystems,$continuation) {
 $scene = $scene|0;
 $particleSystems = $particleSystems|0;
 $continuation = $continuation|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01$i = 0, $i$02 = 0, $llInputs = 0, $llParticleSystems = 0, $llShapes$0$i = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 36|0;
 $llParticleSystems = sp + 24|0;
 $1 = sp + 8|0;
 $llInputs = sp + 12|0;
 $2 = sp;
 $3 = (($particleSystems) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$1>>2] = 0;
 HEAP32[$llParticleSystems>>2] = 0;
 $5 = (($llParticleSystems) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($llParticleSystems) + 8|0);
 HEAP32[$6>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_20PxvParticleSystemSimENS0_13TempAllocatorEE6resizeEjRKS3_($llParticleSystems,$4,$1);
 $7 = HEAP32[$3>>2]|0;
 $8 = $2;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 HEAP32[$llInputs>>2] = 0;
 $12 = (($llInputs) + 4|0);
 HEAP32[$12>>2] = 0;
 $13 = (($llInputs) + 8|0);
 HEAP32[$13>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_28PxvParticleShapesUpdateInputENS0_13TempAllocatorEE6resizeEjRKS2_($llInputs,$7,$2);
 $14 = HEAP32[$3>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $$lcssa = 0;
 } else {
  $i$02 = 0;
  while(1) {
   $16 = HEAP32[$particleSystems>>2]|0;
   $17 = (($16) + ($i$02<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$llInputs>>2]|0;
   $20 = (($18) + 360|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    $37 = 0;$llShapes$0$i = 0;
   } else {
    $23 = $21 << 2;
    $24 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$23,472848,850)|0);
    $25 = HEAP32[$20>>2]|0;
    $26 = ($25|0)==(0);
    if ($26) {
     $37 = 0;$llShapes$0$i = $24;
    } else {
     $27 = (($18) + 356|0);
     $i$01$i = 0;
     while(1) {
      $28 = HEAP32[$27>>2]|0;
      $29 = (($28) + ($i$01$i<<2)|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($30) + 44|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($24) + ($i$01$i<<2)|0);
      HEAP32[$33>>2] = $32;
      $34 = (($i$01$i) + 1)|0;
      $exitcond = ($34|0)==($25|0);
      if ($exitcond) {
       $37 = $25;$llShapes$0$i = $24;
       break;
      } else {
       $i$01$i = $34;
      }
     }
    }
   }
   $35 = (($19) + ($i$02<<3)|0);
   HEAP32[$35>>2] = $llShapes$0$i;
   $36 = ((($19) + ($i$02<<3)|0) + 4|0);
   HEAP32[$36>>2] = $37;
   $38 = HEAP32[$particleSystems>>2]|0;
   $39 = (($38) + ($i$02<<2)|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + 56|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$llParticleSystems>>2]|0;
   $44 = (($43) + ($i$02<<2)|0);
   HEAP32[$44>>2] = $42;
   $45 = (($i$02) + 1)|0;
   $46 = HEAP32[$3>>2]|0;
   $47 = ($45>>>0)<($46>>>0);
   if ($47) {
    $i$02 = $45;
   } else {
    $$lcssa = $46;
    break;
   }
  }
 }
 $48 = (($scene) + 1000|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 324|0);
 $51 = HEAP32[$llParticleSystems>>2]|0;
 $52 = HEAP32[$llInputs>>2]|0;
 $53 = (__ZN5physx24PxsParticleSystemBatcher23scheduleShapeGenerationEPPNS_20PxvParticleSystemSimEPNS_28PxvParticleShapesUpdateInputEjRNS_10PxBaseTaskE($50,$51,$52,$$lcssa,$continuation)|0);
 $54 = HEAP32[$13>>2]|0;
 $55 = $54 & 2147483647;
 $56 = ($55|0)!=(0);
 $57 = ($54|0)>(-1);
 $or$cond$i$i1 = $56 & $57;
 if ($or$cond$i$i1) {
  $58 = HEAP32[$llInputs>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($llInputs,$58);
 }
 $59 = HEAP32[$6>>2]|0;
 $60 = $59 & 2147483647;
 $61 = ($60|0)!=(0);
 $62 = ($59|0)>(-1);
 $or$cond$i$i = $61 & $62;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return ($53|0);
 }
 $63 = HEAP32[$llParticleSystems>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($llParticleSystems,$63);
 STACKTOP = sp;return ($53|0);
}
function __ZN5physx2Sc17ParticleSystemSim19scheduleDynamicsCpuERNS0_16InteractionSceneERKNS_6shdfnd5ArrayIPS1_NS4_19ReflectionAllocatorIS6_EEEERNS_10PxBaseTaskE($scene,$particleSystems,$continuation) {
 $scene = $scene|0;
 $particleSystems = $particleSystems|0;
 $continuation = $continuation|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $llParticleSystems = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $llParticleSystems = sp + 4|0;
 $0 = sp;
 $1 = (($particleSystems) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$llParticleSystems>>2] = 0;
 $3 = (($llParticleSystems) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($llParticleSystems) + 8|0);
 HEAP32[$4>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_20PxvParticleSystemSimENS0_13TempAllocatorEE6resizeEjRKS3_($llParticleSystems,$2,$0);
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$lcssa = 0;
 } else {
  $i$01 = 0;
  while(1) {
   $7 = HEAP32[$particleSystems>>2]|0;
   $8 = (($7) + ($i$01<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 56|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$llParticleSystems>>2]|0;
   $13 = (($12) + ($i$01<<2)|0);
   HEAP32[$13>>2] = $11;
   $14 = (($i$01) + 1)|0;
   $15 = ($14>>>0)<($5>>>0);
   if ($15) {
    $i$01 = $14;
   } else {
    $$lcssa = $5;
    break;
   }
  }
 }
 $16 = (($scene) + 1000|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 324|0);
 $19 = HEAP32[$llParticleSystems>>2]|0;
 $20 = (__ZN5physx24PxsParticleSystemBatcher19scheduleDynamicsCpuEPPNS_20PxvParticleSystemSimEjRNS_10PxBaseTaskE($18,$19,$$lcssa,$continuation)|0);
 $21 = HEAP32[$4>>2]|0;
 $22 = $21 & 2147483647;
 $23 = ($22|0)!=(0);
 $24 = ($21|0)>(-1);
 $or$cond$i$i = $23 & $24;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return ($20|0);
 }
 $25 = HEAP32[$llParticleSystems>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($llParticleSystems,$25);
 STACKTOP = sp;return ($20|0);
}
function __ZN5physx2Sc17ParticleSystemSim21scheduleCollisionPrepERNS0_16InteractionSceneERKNS_6shdfnd5ArrayIPS1_NS4_19ReflectionAllocatorIS6_EEEERNS_10PxBaseTaskE($scene,$particleSystems,$continuation) {
 $scene = $scene|0;
 $particleSystems = $particleSystems|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $inputPrepTasks = 0, $llParticleSystems = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $llParticleSystems = sp + 20|0;
 $0 = sp;
 $inputPrepTasks = sp + 4|0;
 $1 = sp + 16|0;
 $2 = (($particleSystems) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$llParticleSystems>>2] = 0;
 $4 = (($llParticleSystems) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($llParticleSystems) + 8|0);
 HEAP32[$5>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_20PxvParticleSystemSimENS0_13TempAllocatorEE6resizeEjRKS3_($llParticleSystems,$3,$0);
 $6 = HEAP32[$2>>2]|0;
 HEAP32[$1>>2] = 0;
 HEAP32[$inputPrepTasks>>2] = 0;
 $7 = (($inputPrepTasks) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($inputPrepTasks) + 8|0);
 HEAP32[$8>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_14PxLightCpuTaskENS0_13TempAllocatorEE6resizeEjRKS3_($inputPrepTasks,$6,$1);
 $9 = HEAP32[$2>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $i$02 = 0;
  while(1) {
   $11 = HEAP32[$particleSystems>>2]|0;
   $12 = (($11) + ($i$02<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 372|0);
   $15 = HEAP32[$inputPrepTasks>>2]|0;
   $16 = (($15) + ($i$02<<2)|0);
   HEAP32[$16>>2] = $14;
   $17 = HEAP32[$particleSystems>>2]|0;
   $18 = (($17) + ($i$02<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 56|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$llParticleSystems>>2]|0;
   $23 = (($22) + ($i$02<<2)|0);
   HEAP32[$23>>2] = $21;
   $24 = (($i$02) + 1)|0;
   $25 = ($24>>>0)<($9>>>0);
   if ($25) {
    $i$02 = $24;
   } else {
    break;
   }
  }
 }
 $26 = (($scene) + 1000|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 324|0);
 $29 = HEAP32[$llParticleSystems>>2]|0;
 $30 = HEAP32[$inputPrepTasks>>2]|0;
 $31 = HEAP32[$7>>2]|0;
 $32 = (__ZN5physx24PxsParticleSystemBatcher21scheduleCollisionPrepEPPNS_20PxvParticleSystemSimEPPNS_14PxLightCpuTaskEjRNS_10PxBaseTaskE($28,$29,$30,$31,$continuation)|0);
 $33 = HEAP32[$8>>2]|0;
 $34 = $33 & 2147483647;
 $35 = ($34|0)!=(0);
 $36 = ($33|0)>(-1);
 $or$cond$i$i1 = $35 & $36;
 if ($or$cond$i$i1) {
  $37 = HEAP32[$inputPrepTasks>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($inputPrepTasks,$37);
 }
 $38 = HEAP32[$5>>2]|0;
 $39 = $38 & 2147483647;
 $40 = ($39|0)!=(0);
 $41 = ($38|0)>(-1);
 $or$cond$i$i = $40 & $41;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return ($32|0);
 }
 $42 = HEAP32[$llParticleSystems>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($llParticleSystems,$42);
 STACKTOP = sp;return ($32|0);
}
function __ZN5physx2Sc17ParticleSystemSim20scheduleCollisionCpuERNS0_16InteractionSceneERKNS_6shdfnd5ArrayIPS1_NS4_19ReflectionAllocatorIS6_EEEERNS_10PxBaseTaskE($scene,$particleSystems,$continuation) {
 $scene = $scene|0;
 $particleSystems = $particleSystems|0;
 $continuation = $continuation|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $llParticleSystems = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $llParticleSystems = sp + 4|0;
 $0 = sp;
 $1 = (($particleSystems) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$llParticleSystems>>2] = 0;
 $3 = (($llParticleSystems) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($llParticleSystems) + 8|0);
 HEAP32[$4>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_20PxvParticleSystemSimENS0_13TempAllocatorEE6resizeEjRKS3_($llParticleSystems,$2,$0);
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$lcssa = 0;
 } else {
  $i$01 = 0;
  while(1) {
   $7 = HEAP32[$particleSystems>>2]|0;
   $8 = (($7) + ($i$01<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 56|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$llParticleSystems>>2]|0;
   $13 = (($12) + ($i$01<<2)|0);
   HEAP32[$13>>2] = $11;
   $14 = (($i$01) + 1)|0;
   $15 = ($14>>>0)<($5>>>0);
   if ($15) {
    $i$01 = $14;
   } else {
    $$lcssa = $5;
    break;
   }
  }
 }
 $16 = (($scene) + 1000|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 324|0);
 $19 = HEAP32[$llParticleSystems>>2]|0;
 $20 = (__ZN5physx24PxsParticleSystemBatcher20scheduleCollisionCpuEPPNS_20PxvParticleSystemSimEjRNS_10PxBaseTaskE($18,$19,$$lcssa,$continuation)|0);
 $21 = HEAP32[$4>>2]|0;
 $22 = $21 & 2147483647;
 $23 = ($22|0)!=(0);
 $24 = ($21|0)>(-1);
 $or$cond$i$i = $23 & $24;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return ($20|0);
 }
 $25 = HEAP32[$llParticleSystems>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($llParticleSystems,$25);
 STACKTOP = sp;return ($20|0);
}
function __ZN5physx2Sc17ParticleSystemSim21prepareCollisionInputEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$lcssa = 0, $$lobit = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $s$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($this) + 360|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 368|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4 << 3;
 $8 = (($7) + 8)|0;
 $9 = $6 << 4;
 $10 = (($8) + ($9))|0;
 $11 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$10,472848,868)|0);
 $12 = HEAP32[$5>>2]|0;
 HEAP32[$11>>2] = $4;
 $13 = (($11) + 4|0);
 $14 = $12 << 4;
 $15 = (($14) + ($8))|0;
 HEAP32[$13>>2] = $15;
 $16 = HEAP32[$3>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $81 = (($this) + 56|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + 52|0);
  $85 = HEAP32[$84>>2]|0;
  HEAP32[$2>>2] = $11;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
  FUNCTION_TABLE_vii[$85 & 4095]($82,$$byval_copy);
  STACKTOP = sp;return;
 }
 $18 = (($11) + 8|0);
 $19 = (($this) + 356|0);
 $20 = (($this) + 36|0);
 $26 = $18;$s$03 = 0;
 while(1) {
  $21 = HEAP32[$19>>2]|0;
  $22 = (($21) + ($s$03<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 44|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$26>>2] = $25;
  $27 = (($26) + 4|0);
  $28 = (($26) + 8|0);
  HEAP32[$27>>2] = 0;
  $29 = (($23) + 36|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($23) + 42|0);
  $32 = HEAP16[$31>>1]|0;
  $33 = $32&65535;
  $34 = (($30) + ($33<<2)|0);
  $35 = ($32<<16>>16)==(0);
  if ($35) {
   $$lcssa = $28;
  } else {
   $37 = $30;$66 = $28;
   while(1) {
    $36 = HEAP32[$37>>2]|0;
    $38 = (($36) + 40|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 19|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $43 = (($36) + 36|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + 28|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($46) + 64|0);
     $48 = HEAP8[$47>>0]|0;
     $49 = $48 & 4;
     $50 = ($49<<24>>24)==(0);
     if ($50) {
      $51 = (__ZNK5physx2Sc8ShapeSim14actorIsDynamicEv($44)|0);
      $52 = (__ZNK5physx2Sc8ShapeSim8getRbSimEv($44)|0);
      $53 = (($52) + 52|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = (($54) + 16|0);
      if ($51) {
       $56 = HEAP32[$20>>2]|0;
       $57 = (($56) + 1000|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($58) + 1448|0);
       $60 = (__ZNK5physx21PxsBodyTransformVault12getTransformERKNS_11PxsBodyCoreE($59,$55)|0);
       $69 = $60;
      } else {
       $69 = 0;
      }
      $61 = HEAP32[$45>>2]|0;
      $62 = (($61) + 32|0);
      $63 = (($61) + 64|0);
      $64 = HEAP8[$63>>0]|0;
      $65 = (($66) + 16|0);
      HEAP32[$66>>2] = $55;
      $67 = (($66) + 4|0);
      HEAP32[$67>>2] = $62;
      $68 = (($66) + 8|0);
      HEAP32[$68>>2] = $69;
      $70 = (($66) + 12|0);
      $71 = ($64&255) >>> 4;
      $$lobit = $71 & 1;
      HEAP8[$70>>0] = $$lobit;
      $72 = (($66) + 13|0);
      $73 = $51&1;
      HEAP8[$72>>0] = $73;
      $74 = HEAP32[$27>>2]|0;
      $75 = (($74) + 1)|0;
      HEAP32[$27>>2] = $75;
      $86 = $65;
     } else {
      $86 = $66;
     }
    } else {
     $86 = $66;
    }
    $76 = (($37) + 4|0);
    $77 = ($76>>>0)<($34>>>0);
    if ($77) {
     $37 = $76;$66 = $86;
    } else {
     $$lcssa = $86;
     break;
    }
   }
  }
  $78 = (($s$03) + 1)|0;
  $79 = HEAP32[$3>>2]|0;
  $80 = ($78>>>0)<($79>>>0);
  if ($80) {
   $26 = $$lcssa;$s$03 = $78;
  } else {
   break;
  }
 }
 $81 = (($this) + 56|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$82>>2]|0;
 $84 = (($83) + 52|0);
 $85 = HEAP32[$84>>2]|0;
 HEAP32[$2>>2] = $11;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
 FUNCTION_TABLE_vii[$85 & 4095]($82,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSimD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((472768 + 8|0));
 $0 = (($this) + 372|0);
 HEAP32[$0>>2] = ((434896 + 8|0));
 $1 = (($this) + 380|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 364|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4|0)!=(0);
 $6 = ($3|0)>(-1);
 $or$cond$i$i$i = $5 & $6;
 if ($or$cond$i$i$i) {
  $7 = (($this) + 356|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vii[$13 & 4095]($10,$8);
  }
 }
 $14 = (($this) + 60|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEED2Ev($14);
 __ZN5physx2Sc8ActorSimD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc17ParticleSystemSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((472768 + 8|0));
 $1 = (($this) + 372|0);
 HEAP32[$1>>2] = ((434896 + 8|0));
 $2 = (($this) + 380|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 364|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = ($5|0)!=(0);
 $7 = ($4|0)>(-1);
 $or$cond$i$i$i$i = $6 & $7;
 if ($or$cond$i$i$i$i) {
  $8 = (($this) + 356|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
  }
 }
 $15 = (($this) + 60|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEED2Ev($15);
 __ZN5physx2Sc8ActorSimD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc17ParticleSystemSimEXadL_ZNS3_21prepareCollisionInputEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0;
 var $freeNodes = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $freeIt$04 = $19;$slabIt$05 = $25;
  while(1) {
   $30 = HEAP32[$slabIt$05>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = (($30) + (($31*52)|0)|0);
   $33 = ($30|0)==($32|0);
   if ($33) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $30;
    while(1) {
     $34 = (($19) + ($20<<2)|0);
     $35 = ($freeIt$11|0)==($34|0);
     if ($35) {
      label = 16;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      if ($37) {
       $38 = (($freeIt$11) + 4|0);
       $freeIt$2 = $38;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $39 = HEAP32[$tIt$02>>2]|0;
      $40 = HEAP32[$39>>2]|0;
      FUNCTION_TABLE_vi[$40 & 4095]($tIt$02);
      $freeIt$2 = $freeIt$11;
     }
     $41 = (($tIt$02) + 52|0);
     $42 = ($41|0)==($32|0);
     if ($42) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $41;
     }
    }
   }
   $43 = (($slabIt$05) + 4|0);
   $44 = ($43|0)==($27|0);
   if ($44) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $43;
   }
  }
 }
 $45 = HEAP32[$4>>2]|0;
 $46 = $45 & 2147483647;
 $notlhs = ($46|0)==(0);
 $notrhs = ($45|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $47 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $47;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 FUNCTION_TABLE_vii[$51 & 4095]($48,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 473160 : 473128;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,473040,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 473160 : 473128;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,473040,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 473160 : 473128;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,473296,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_14PxLightCpuTaskENS0_13TempAllocatorEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_14PxLightCpuTaskENS0_13TempAllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_14PxLightCpuTaskENS0_13TempAllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$1,473296,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<2)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $10;
   }
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11>>>0)<($5>>>0);
   if ($13) {
    $$012$i = $11;$$03$i = $12;
   } else {
    break;
   }
  }
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(-1);
 if (!($16)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$14>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$17);
 HEAP32[$this>>2] = $6;
 HEAP32[$14>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_28PxvParticleShapesUpdateInputENS0_13TempAllocatorEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_28PxvParticleShapesUpdateInputENS0_13TempAllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<3)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<3)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = $a;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = $$01$i;
   $18 = $17;
   HEAP32[$18>>2] = $13;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = $16;
  }
  $21 = (($$01$i) + 8|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_28PxvParticleShapesUpdateInputENS0_13TempAllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$1,473296,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<3)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = $$03$i;
    $11 = $10;
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + 4)|0;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = $$012$i;
    $17 = $16;
    HEAP32[$17>>2] = $12;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP32[$19>>2] = $15;
   }
   $20 = (($$012$i) + 8|0);
   $21 = (($$03$i) + 8|0);
   $22 = ($20>>>0)<($5>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$26);
 HEAP32[$this>>2] = $6;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_20PxvParticleSystemSimENS0_13TempAllocatorEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_20PxvParticleSystemSimENS0_13TempAllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_20PxvParticleSystemSimENS0_13TempAllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$1,473296,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<2)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $10;
   }
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11>>>0)<($5>>>0);
   if ($13) {
    $$012$i = $11;$$03$i = $12;
   } else {
    break;
   }
  }
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(-1);
 if (!($16)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$14>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$17);
 HEAP32[$this>>2] = $6;
 HEAP32[$14>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 52)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 473160 : 473128;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,473296,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 473160 : 473128;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,473296,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc17ParticleSystemSimEXadL_ZNS3_21prepareCollisionInputEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_2Sc17ParticleSystemSimEXadL_ZNS3_21prepareCollisionInputEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_2Sc17ParticleSystemSimEXadL_ZNS3_21prepareCollisionInputEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc17ParticleSystemSim21prepareCollisionInputEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 473424 : 473128;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,473296,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Sc19ParticlePacketShapeENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 473160 : 473128;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,473568,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Sc19ParticlePacketShapeEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*52)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -52|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5ActorC2ERNS0_16InteractionSceneEhNS0_14IslandNodeInfo4TypeE($this,$scene,$actorType,$nodeType) {
 $this = $this|0;
 $scene = $scene|0;
 $actorType = $actorType|0;
 $nodeType = $nodeType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((473648 + 8|0));
 $0 = (($this) + 20|0);
 $1 = (($this) + 36|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 HEAP32[$1>>2] = $scene;
 $2 = (($this) + 40|0);
 HEAP32[$2>>2] = -1;
 $3 = (($this) + 44|0);
 HEAP16[$3>>1] = 0;
 $4 = (($this) + 46|0);
 HEAP16[$4>>1] = 0;
 $5 = (($this) + 48|0);
 HEAP16[$5>>1] = 0;
 $6 = (($this) + 50|0);
 HEAP8[$6>>0] = $actorType;
 $7 = (($this) + 51|0);
 $8 = $nodeType&255;
 HEAP8[$7>>0] = $8;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5ActorD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((473648 + 8|0));
 $1 = (($this) + 28|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 20|0);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = (($this) + 4|0);
 $7 = ($4|0)==($6|0);
 $or$cond$i = $5 | $7;
 if (!($or$cond$i)) {
  $8 = (($this) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$3>>2]|0;
  __ZN5physx2Sc16InteractionScene22deallocatePointerBlockEPPvj($9,$4,$10);
 }
 HEAP32[$3>>2] = 0;
 HEAP32[$2>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5ActorD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((473648 + 8|0));
 $0 = (($this) + 28|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 20|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = (($this) + 4|0);
 $6 = ($3|0)==($5|0);
 $or$cond = $4 | $6;
 if ($or$cond) {
  HEAP32[$2>>2] = 0;
  HEAP32[$1>>2] = 0;
  STACKTOP = sp;return;
 }
 $7 = (($this) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$2>>2]|0;
 __ZN5physx2Sc16InteractionScene22deallocatePointerBlockEPPvj($8,$3,$9);
 HEAP32[$2>>2] = 0;
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor17setIslandNodeTypeENS0_14IslandNodeInfo4TypeE($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 51|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $7 = $1;
 } else {
  $4 = (($this) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN5physx2Sc16InteractionScene25removeFromActiveActorListERNS0_5ActorE($5,$this);
  $$pre = HEAP8[$0>>0]|0;
  $7 = $$pre;
 }
 $6 = $7&255;
 $8 = $6 & 241;
 $9 = $8 | $type;
 $10 = $9&255;
 HEAP8[$0>>0] = $10;
 $11 = $10 & 1;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN5physx2Sc16InteractionScene20addToActiveActorListERNS0_5ActorE($14,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor20activateInteractionsEj($this,$infoFlag) {
 $this = $this|0;
 $infoFlag = $infoFlag|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $i1$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 44|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ($3<<16>>16)==(0);
 if ($5) {
  $$lcssa = $4;
 } else {
  $6 = (($this) + 20|0);
  $7 = (($this) + 36|0);
  $13 = 0;$16 = $4;$i$02 = 0;
  while(1) {
   $12 = (($13) + 1)|0;
   $14 = $12&65535;
   $15 = (($16) + 65535)|0;
   $17 = $15&65535;
   $18 = ($14&65535)<($17&65535);
   $19 = $18 ? $12 : $15;
   $20 = $19 & 65535;
   $21 = HEAP32[$6>>2]|0;
   $22 = (($21) + ($20<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$6>>2]|0;
   $25 = (($24) + ($13<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$7>>2]|0;
   $28 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($27,$26)|0);
   if (!($28)) {
    $29 = HEAP32[$26>>2]|0;
    $30 = (($29) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (FUNCTION_TABLE_iii[$31 & 4095]($26,$infoFlag)|0);
    if ($32) {
     $33 = HEAP32[$7>>2]|0;
     __ZN5physx2Sc16InteractionScene26notifyInteractionActivatedEPNS0_11InteractionE($33,$26);
    }
   }
   $34 = (($i$02) + 1)<<16>>16;
   $35 = $34&65535;
   $36 = HEAP16[$2>>1]|0;
   $37 = $36&65535;
   $38 = ($34&65535)<($36&65535);
   if ($38) {
    $13 = $35;$16 = $37;$i$02 = $34;
   } else {
    $$lcssa = $37;
    break;
   }
  }
 }
 $8 = ($$lcssa>>>0)<($1>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($1) + -1)|0;
 $10 = (($this) + 20|0);
 $11 = (($this) + 36|0);
 $i1$01 = $$lcssa;
 while(1) {
  $39 = (($i1$01) + 1)|0;
  $40 = ($39>>>0)<($9>>>0);
  $41 = $40 ? $39 : $9;
  $42 = HEAP32[$10>>2]|0;
  $43 = (($42) + ($41<<2)|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = HEAP32[$10>>2]|0;
  $46 = (($45) + ($i1$01<<2)|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = HEAP32[$11>>2]|0;
  $49 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($48,$47)|0);
  if (!($49)) {
   $50 = HEAP32[$47>>2]|0;
   $51 = (($50) + 16|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (FUNCTION_TABLE_iii[$52 & 4095]($47,$infoFlag)|0);
   if ($53) {
    $54 = HEAP32[$11>>2]|0;
    __ZN5physx2Sc16InteractionScene26notifyInteractionActivatedEPNS0_11InteractionE($54,$47);
   }
  }
  $exitcond = ($39|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i1$01 = $39;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor22deactivateInteractionsEj($this,$infoFlag) {
 $this = $this|0;
 $infoFlag = $infoFlag|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $i1$01 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 44|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ($3<<16>>16)==(0);
 L1: do {
  if ($5) {
   $$lcssa = $4;
  } else {
   $6 = (($this) + 20|0);
   $7 = (($this) + 36|0);
   $13 = 0;$16 = $4;$i$02 = 1;
   while(1) {
    $12 = (($13) + 1)|0;
    $14 = $12&65535;
    $15 = (($16) + 65535)|0;
    $17 = $15&65535;
    $18 = ($14&65535)<($17&65535);
    $19 = $18 ? $12 : $15;
    $20 = $19 & 65535;
    $21 = HEAP32[$6>>2]|0;
    $22 = (($21) + ($20<<2)|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = HEAP32[$6>>2]|0;
    $25 = (($24) + ($13<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($26) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==($this|0);
    if ($29) {
     $30 = (($26) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     $33 = $31;
    } else {
     $33 = $28;
    }
    $32 = (($33) + 51|0);
    $34 = HEAP8[$32>>0]|0;
    $35 = $34 & 1;
    $36 = ($35<<24>>24)==(0);
    if ($36) {
     $37 = HEAP32[$7>>2]|0;
     $38 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($37,$26)|0);
     if ($38) {
      $39 = HEAP32[$26>>2]|0;
      $40 = (($39) + 20|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (FUNCTION_TABLE_iii[$41 & 4095]($26,$infoFlag)|0);
      if ($42) {
       $43 = HEAP32[$7>>2]|0;
       __ZN5physx2Sc16InteractionScene28notifyInteractionDeactivatedEPNS0_11InteractionE($43,$26);
      }
     }
    }
    $44 = HEAP16[$2>>1]|0;
    $45 = $44&65535;
    $46 = ($i$02&65535)<($44&65535);
    if (!($46)) {
     $$lcssa = $45;
     break L1;
    }
    $47 = $i$02&65535;
    $phitmp = (($i$02) + 1)<<16>>16;
    $13 = $47;$16 = $45;$i$02 = $phitmp;
   }
  }
 } while(0);
 $8 = ($$lcssa>>>0)<($1>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($1) + -1)|0;
 $10 = (($this) + 20|0);
 $11 = (($this) + 36|0);
 $i1$01 = $$lcssa;
 while(1) {
  $48 = (($i1$01) + 1)|0;
  $49 = ($48>>>0)<($9>>>0);
  $50 = $49 ? $48 : $9;
  $51 = HEAP32[$10>>2]|0;
  $52 = (($51) + ($50<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = HEAP32[$10>>2]|0;
  $55 = (($54) + ($i1$01<<2)|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = HEAP32[$11>>2]|0;
  $58 = (__ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($57,$56)|0);
  if ($58) {
   $59 = HEAP32[$56>>2]|0;
   $60 = (($59) + 20|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (FUNCTION_TABLE_iii[$61 & 4095]($56,$infoFlag)|0);
   if ($62) {
    $63 = HEAP32[$11>>2]|0;
    __ZN5physx2Sc16InteractionScene28notifyInteractionDeactivatedEPNS0_11InteractionE($63,$56);
   }
  }
  $exitcond = ($48|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i1$01 = $48;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor9setActiveEbj($this,$active,$infoFlag) {
 $this = $this|0;
 $active = $active|0;
 $infoFlag = $infoFlag|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $infoFlag & 1;
 $1 = ($0|0)!=(0);
 $$phi$trans$insert = (($this) + 51|0);
 $$pre = HEAP8[$$phi$trans$insert>>0]|0;
 if (!($1)) {
  $2 = $$pre & 1;
  $3 = ($2<<24>>24)!=(0);
  $4 = $3 ^ $active;
  if (!($4)) {
   STACKTOP = sp;return;
  }
 }
 $5 = (($this) + 51|0);
 $6 = $$pre&255;
 if ($active) {
  $7 = $6 | 1;
  $8 = $7&255;
  HEAP8[$5>>0] = $8;
  $9 = HEAP32[$this>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($this);
  __ZN5physx2Sc5Actor20activateInteractionsEj($this,$infoFlag);
  if ($1) {
   STACKTOP = sp;return;
  }
  $12 = (($this) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  __ZN5physx2Sc16InteractionScene20addToActiveActorListERNS0_5ActorE($13,$this);
  STACKTOP = sp;return;
 } else {
  $14 = $6 & 254;
  $15 = $14&255;
  HEAP8[$5>>0] = $15;
  __ZN5physx2Sc5Actor22deactivateInteractionsEj($this,$infoFlag);
  $16 = HEAP32[$this>>2]|0;
  $17 = (($16) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vi[$18 & 4095]($this);
  if ($1) {
   STACKTOP = sp;return;
  }
  $19 = (($this) + 36|0);
  $20 = HEAP32[$19>>2]|0;
  __ZN5physx2Sc16InteractionScene25removeFromActiveActorListERNS0_5ActorE($20,$this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc5Actor19registerInteractionEPNS0_11InteractionE($this,$interaction) {
 $this = $this|0;
 $interaction = $interaction|0;
 var $$ = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $swapInteraction = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $swapInteraction = sp;
 HEAP32[$0>>2] = $interaction;
 $1 = (($interaction) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = (($interaction) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 50|0);
 $6 = HEAP8[$5>>0]|0;
 if ((($6<<24>>24) == 1) | (($6<<24>>24) == 4)) {
  $7 = (($interaction) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 50|0);
  $10 = HEAP8[$9>>0]|0;
  $notlhs = ($10<<24>>24)!=(1);
  $notrhs = ($10<<24>>24)!=(4);
  $$not = $notrhs & $notlhs;
  $11 = ($2<<24>>24)==(2);
  $or$cond = $$not | $11;
  $12 = ($2<<24>>24)==(3);
  $$ = $or$cond | $12;
  $59 = $$;
 } else {
  $59 = 1;
 }
 $13 = (($this) + 20|0);
 $14 = (($this) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15>>>0)>(65534);
 if ($16) {
  STACKTOP = sp;return;
 }
 do {
  if ($59) {
   __ZN5physx2Cm10OwnedArrayIPNS_2Sc11InteractionENS2_5ActorEjXadL_ZNS5_19reallocInteractionsERPS4_RjjjEEE8pushBackERS4_RS5_($13,$0,$this);
   $17 = HEAP32[$0>>2]|0;
   $18 = (($17) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==($this|0);
   $21 = $15&65535;
   if ($20) {
    $22 = (($17) + 16|0);
    HEAP16[$22>>1] = $21;
    break;
   } else {
    $23 = (($17) + 18|0);
    HEAP16[$23>>1] = $21;
    break;
   }
  } else {
   $24 = (($this) + 44|0);
   $25 = HEAP16[$24>>1]|0;
   $26 = $25&65535;
   $27 = ($15|0)==($26|0);
   do {
    if ($27) {
     __ZN5physx2Cm10OwnedArrayIPNS_2Sc11InteractionENS2_5ActorEjXadL_ZNS5_19reallocInteractionsERPS4_RjjjEEE8pushBackERS4_RS5_($13,$0,$this);
     $28 = HEAP32[$0>>2]|0;
     $29 = (($28) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($this|0);
     $32 = $15&65535;
     if ($31) {
      $33 = (($28) + 16|0);
      HEAP16[$33>>1] = $32;
      break;
     } else {
      $34 = (($28) + 18|0);
      HEAP16[$34>>1] = $32;
      break;
     }
    } else {
     $35 = HEAP32[$13>>2]|0;
     $36 = (($35) + ($26<<2)|0);
     $37 = HEAP32[$36>>2]|0;
     HEAP32[$swapInteraction>>2] = $37;
     __ZN5physx2Cm10OwnedArrayIPNS_2Sc11InteractionENS2_5ActorEjXadL_ZNS5_19reallocInteractionsERPS4_RjjjEEE8pushBackERS4_RS5_($13,$swapInteraction,$this);
     $38 = HEAP32[$swapInteraction>>2]|0;
     $39 = (($38) + 4|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($this|0);
     $42 = $15&65535;
     if ($41) {
      $43 = (($38) + 16|0);
      HEAP16[$43>>1] = $42;
     } else {
      $44 = (($38) + 18|0);
      HEAP16[$44>>1] = $42;
     }
     $45 = HEAP16[$24>>1]|0;
     $46 = $45&65535;
     $47 = HEAP32[$13>>2]|0;
     $48 = (($47) + ($46<<2)|0);
     HEAP32[$48>>2] = $interaction;
     $49 = HEAP32[$3>>2]|0;
     $50 = ($49|0)==($this|0);
     if ($50) {
      $51 = (($interaction) + 16|0);
      HEAP16[$51>>1] = $45;
      break;
     } else {
      $52 = (($interaction) + 18|0);
      HEAP16[$52>>1] = $45;
      break;
     }
    }
   } while(0);
   $53 = HEAP16[$24>>1]|0;
   $54 = (($53) + 1)<<16>>16;
   HEAP16[$24>>1] = $54;
  }
 } while(0);
 $55 = ($2&255)<(2);
 if (!($55)) {
  STACKTOP = sp;return;
 }
 $56 = (($this) + 48|0);
 $57 = HEAP16[$56>>1]|0;
 $58 = (($57) + 1)<<16>>16;
 HEAP16[$56>>1] = $58;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm10OwnedArrayIPNS_2Sc11InteractionENS2_5ActorEjXadL_ZNS5_19reallocInteractionsERPS4_RjjjEEE8pushBackERS4_RS5_($this,$element,$owner) {
 $this = $this|0;
 $element = $element|0;
 $owner = $owner|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $newCapacity$0$i = 0, $newMem$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  $$pre1 = HEAP32[$this>>2]|0;
  $36 = $1;$38 = $$pre1;
  $34 = HEAP32[$element>>2]|0;
  $35 = (($36) + 1)|0;
  HEAP32[$0>>2] = $35;
  $37 = (($38) + ($36<<2)|0);
  HEAP32[$37>>2] = $34;
  STACKTOP = sp;return;
 }
 $5 = (($1) + 1)|0;
 $6 = $5 & 65535;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   $newCapacity$0$i = 0;$newMem$0$i = 0;
  } else {
   $8 = ($6>>>0)<(5);
   if ($8) {
    $9 = (($owner) + 4|0);
    $newCapacity$0$i = 4;$newMem$0$i = $9;
    break;
   } else {
    $10 = (($6) + -1)|0;
    $11 = $10 >>> 1;
    $12 = $11 | $10;
    $13 = $12 >>> 2;
    $14 = $13 | $12;
    $15 = $14 >>> 4;
    $16 = $15 | $14;
    $17 = $16 >>> 8;
    $18 = $17 | $16;
    $19 = $18 >>> 16;
    $20 = $19 | $18;
    $21 = (($20) + 1)|0;
    $22 = (($owner) + 36|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (__ZN5physx2Sc16InteractionScene20allocatePointerBlockEj($23,$21)|0);
    $newCapacity$0$i = $21;$newMem$0$i = $24;
    break;
   }
  }
 } while(0);
 $25 = HEAP32[$this>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = $1 << 2;
  _memcpy(($newMem$0$i|0),($25|0),($27|0))|0;
  $28 = HEAP32[$this>>2]|0;
  $29 = (($owner) + 4|0);
  $30 = ($28|0)==($29|0);
  if (!($30)) {
   $31 = (($owner) + 36|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$2>>2]|0;
   __ZN5physx2Sc16InteractionScene22deallocatePointerBlockEPPvj($32,$28,$33);
  }
 }
 HEAP32[$2>>2] = $newCapacity$0$i;
 HEAP32[$this>>2] = $newMem$0$i;
 $$pre = HEAP32[$0>>2]|0;
 $36 = $$pre;$38 = $newMem$0$i;
 $34 = HEAP32[$element>>2]|0;
 $35 = (($36) + 1)|0;
 HEAP32[$0>>2] = $35;
 $37 = (($38) + ($36<<2)|0);
 HEAP32[$37>>2] = $34;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor21unregisterInteractionEPNS0_11InteractionE($this,$interaction) {
 $this = $this|0;
 $interaction = $interaction|0;
 var $$sink$i = 0, $$sink$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($interaction) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($this|0);
 $3 = (($interaction) + 16|0);
 $4 = (($interaction) + 18|0);
 $$sink$in$i = $2 ? $3 : $4;
 $$sink$i = HEAP16[$$sink$in$i>>1]|0;
 $5 = $$sink$i&65535;
 $6 = ($$sink$i<<16>>16)==(-1);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 44|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = ($$sink$i&65535)<($8&65535);
 do {
  if ($9) {
   $27 = (($8) + -1)<<16>>16;
   HEAP16[$7>>1] = $27;
   $28 = $27&65535;
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + ($28<<2)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + ($5<<2)|0);
   HEAP32[$33>>2] = $32;
   $34 = HEAP32[$29>>2]|0;
   $35 = (($34) + ($5<<2)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==($this|0);
   if ($39) {
    $40 = (($36) + 16|0);
    HEAP16[$40>>1] = $$sink$i;
   } else {
    $41 = (($36) + 18|0);
    HEAP16[$41>>1] = $$sink$i;
   }
   $42 = HEAP16[$7>>1]|0;
   $43 = $42&65535;
   $44 = (($this) + 28|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + -1)|0;
   HEAP32[$44>>2] = $46;
   $47 = (($34) + ($46<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($34) + ($43<<2)|0);
   HEAP32[$49>>2] = $48;
   $50 = ($43>>>0)<($46>>>0);
   if ($50) {
    $51 = HEAP32[$29>>2]|0;
    $52 = (($51) + ($43<<2)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==($this|0);
    if ($56) {
     $57 = (($53) + 16|0);
     HEAP16[$57>>1] = $42;
     break;
    } else {
     $58 = (($53) + 18|0);
     HEAP16[$58>>1] = $42;
     break;
    }
   }
  } else {
   $10 = (($this) + 28|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + -1)|0;
   HEAP32[$10>>2] = $12;
   $13 = (($this) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + ($12<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + ($5<<2)|0);
   HEAP32[$17>>2] = $16;
   $18 = ($5>>>0)<($12>>>0);
   if ($18) {
    $19 = HEAP32[$13>>2]|0;
    $20 = (($19) + ($5<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==($this|0);
    if ($24) {
     $25 = (($21) + 16|0);
     HEAP16[$25>>1] = $$sink$i;
     break;
    } else {
     $26 = (($21) + 18|0);
     HEAP16[$26>>1] = $$sink$i;
     break;
    }
   }
  }
 } while(0);
 $59 = (($interaction) + 20|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = ($60&255)<(2);
 if (!($61)) {
  STACKTOP = sp;return;
 }
 $62 = (($this) + 48|0);
 $63 = HEAP16[$62>>1]|0;
 $64 = (($63) + -1)<<16>>16;
 HEAP16[$62>>1] = $64;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor15onElementAttachERNS0_7ElementE($this,$element) {
 $this = $this|0;
 $element = $element|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($element) + 4|0);
 HEAP32[$2>>2] = $1;
 HEAP32[$0>>2] = $element;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc5Actor15onElementDetachERNS0_7ElementE($this,$element) {
 $this = $this|0;
 $element = $element|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $currentElem$0 = 0, $currentElem$03 = 0, $currentElem$05 = 0, $previousElem$04 = 0, $previousElem$04$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $currentElem$03 = HEAP32[$0>>2]|0;
 $1 = ($currentElem$03|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $currentElem$05 = $currentElem$03;$previousElem$04 = 0;
 }
 while(1) {
  $4 = ($currentElem$05|0)==($element|0);
  if ($4) {
   break;
  }
  $2 = (($currentElem$05) + 4|0);
  $currentElem$0 = HEAP32[$2>>2]|0;
  $3 = ($currentElem$0|0)==(0|0);
  if ($3) {
   label = 7;
   break;
  } else {
   $previousElem$04$phi = $currentElem$05;$currentElem$05 = $currentElem$0;$previousElem$04 = $previousElem$04$phi;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return;
 }
 $5 = ($previousElem$04|0)==(0|0);
 $6 = (($element) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 if ($5) {
  HEAP32[$0>>2] = $7;
  STACKTOP = sp;return;
 } else {
  $8 = (($previousElem$04) + 4|0);
  HEAP32[$8>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc5Actor19reallocInteractionsERPPNS0_11InteractionERjjj($this,$mem,$capacity,$size,$requiredMinCapacity) {
 $this = $this|0;
 $mem = $mem|0;
 $capacity = $capacity|0;
 $size = $size|0;
 $requiredMinCapacity = $requiredMinCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newCapacity$0 = 0, $newMem$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($requiredMinCapacity|0)==(0);
 do {
  if ($0) {
   $newCapacity$0 = 0;$newMem$0 = 0;
  } else {
   $1 = ($requiredMinCapacity>>>0)<(5);
   if ($1) {
    $2 = (($this) + 4|0);
    $newCapacity$0 = 4;$newMem$0 = $2;
    break;
   } else {
    $3 = (($requiredMinCapacity) + -1)|0;
    $4 = $3 >>> 1;
    $5 = $4 | $3;
    $6 = $5 >>> 2;
    $7 = $6 | $5;
    $8 = $7 >>> 4;
    $9 = $8 | $7;
    $10 = $9 >>> 8;
    $11 = $10 | $9;
    $12 = $11 >>> 16;
    $13 = $12 | $11;
    $14 = (($13) + 1)|0;
    $15 = (($this) + 36|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (__ZN5physx2Sc16InteractionScene20allocatePointerBlockEj($16,$14)|0);
    $newCapacity$0 = $14;$newMem$0 = $17;
    break;
   }
  }
 } while(0);
 $18 = HEAP32[$mem>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = $size << 2;
  _memcpy(($newMem$0|0),($18|0),($20|0))|0;
  $21 = HEAP32[$mem>>2]|0;
  $22 = (($this) + 4|0);
  $23 = ($21|0)==($22|0);
  if (!($23)) {
   $24 = (($this) + 36|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[$capacity>>2]|0;
   __ZN5physx2Sc16InteractionScene22deallocatePointerBlockEPPvj($25,$21,$26);
  }
 }
 HEAP32[$capacity>>2] = $newCapacity$0;
 HEAP32[$mem>>2] = $newMem$0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7Element26ElementInteractionIterator7getNextEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)<($2>>>0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 8|0);
 $6 = $0;
 while(1) {
  $5 = HEAP32[$6>>2]|0;
  $7 = (($5) + 21|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = $8 & 9;
  $10 = ($9<<24>>24)==(0);
  if (!($10)) {
   $11 = (($5) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$4>>2]|0;
   $14 = ($12|0)==($13|0);
   if ($14) {
    break;
   }
   $15 = (($5) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($13|0);
   if ($17) {
    break;
   }
  }
  $19 = (($6) + 4|0);
  HEAP32[$this>>2] = $19;
  $20 = ($19>>>0)<($2>>>0);
  if ($20) {
   $6 = $19;
  } else {
   $$0 = 0;
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($6) + 4|0);
 HEAP32[$this>>2] = $18;
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc7Element33ElementInteractionReverseIterator7getNextEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)<($2>>>0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 8|0);
 $6 = $2;
 while(1) {
  $5 = (($6) + -4|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 21|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9 & 9;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $12 = (($7) + 24|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$4>>2]|0;
   $15 = ($13|0)==($14|0);
   if ($15) {
    break;
   }
   $16 = (($7) + 28|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==($14|0);
   if ($18) {
    break;
   }
  }
  HEAP32[$1>>2] = $5;
  $19 = ($0>>>0)<($5>>>0);
  if ($19) {
   $6 = $5;
  } else {
   $$0 = 0;
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $5;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc7ElementD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((473672 + 8|0));
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx2Sc5Actor15onElementDetachERNS0_7ElementE($2,$this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7ElementD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((473672 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx2Sc5Actor15onElementDetachERNS0_7ElementE($1,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc7Element20createLowLevelVolumeEjRKNS_9PxBounds3EjRKNS_9AABBMgrIdE($this,$group,$bounds,$aggregateID,$aabbMgrId) {
 $this = $this|0;
 $group = $group|0;
 $bounds = $bounds|0;
 $aggregateID = $aggregateID|0;
 $aabbMgrId = $aabbMgrId|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newAABBMgrId = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $newAABBMgrId = sp + 8|0;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1000|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($aabbMgrId) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx14PxsAABBManager12createVolumeEjjjPvRKNS_9PxBounds3E($newAABBMgrId,$7,$aggregateID,$9,$group,$this,$bounds);
 $10 = HEAP32[$newAABBMgrId>>2]|0;
 $11 = (($this) + 12|0);
 $12 = $11;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = $10 & 1073741823;
 $19 = $14 & -1073741824;
 $20 = $17 & -1073741824;
 $21 = $19 | $18;
 $22 = (($newAABBMgrId) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 1073741823;
 $25 = $24 | $20;
 $26 = $11;
 $27 = $26;
 HEAP32[$27>>2] = $21;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 $30 = ($10|0)==(1073741823);
 if (!($30)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($31,32,473688,112,473784,$vararg_buffer);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc7Element21destroyLowLevelVolumeEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $3 & 1073741823;
 $8 = ($7|0)==(1073741823);
 $9 = (0)==(0);
 $10 = $8 & $9;
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1000|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $3 & 1073741823;
 $20 = (__ZN5physx14PxsAABBManager13releaseVolumeEj($18,$19)|0);
 $21 = $0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 4)|0;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = $23 | 1073741823;
 $28 = $26 | 1073741823;
 $29 = $0;
 $30 = $29;
 HEAP32[$30>>2] = $27;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $28;
 $$0 = $20;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc11InteractionC2ERNS0_5ActorES3_NS0_15InteractionTypeEh($this,$actor0,$actor1,$type,$flags) {
 $this = $this|0;
 $actor0 = $actor0|0;
 $actor1 = $actor1|0;
 $type = $type|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((473864 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $actor0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $actor1;
 $2 = (($this) + 12|0);
 $3 = (($this) + 20|0);
 $4 = $type&255;
 $5 = $2;
 $6 = $5;
 HEAP32[$6>>2] = -1;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = -1;
 HEAP8[$3>>0] = $4;
 $9 = (($this) + 21|0);
 HEAP8[$9>>0] = $flags;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc11InteractionD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc11InteractionD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionSceneC2ERNS0_5SceneE($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 24|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 44|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 48|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 52|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 56|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 60|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 64|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 68|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 72|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 76|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 80|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 84|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 116|0);
 $18 = (($this) + 372|0);
 $19 = (($this) + 376|0);
 $20 = (($this) + 380|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 384|0);
 HEAP8[$18>>0] = 1;
 HEAP32[$19>>2] = $17;
 HEAP32[$21>>2] = 64;
 $22 = (($this) + 388|0);
 HEAP32[$22>>2] = 32;
 $23 = (($this) + 392|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 396|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 400|0);
 HEAP32[$25>>2] = 1024;
 $26 = (($this) + 404|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 412|0);
 $28 = (($this) + 668|0);
 $29 = (($this) + 672|0);
 $30 = (($this) + 676|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 680|0);
 HEAP8[$28>>0] = 1;
 HEAP32[$29>>2] = $27;
 HEAP32[$31>>2] = 64;
 $32 = (($this) + 684|0);
 HEAP32[$32>>2] = 32;
 $33 = (($this) + 688|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 692|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 696|0);
 HEAP32[$35>>2] = 2048;
 $36 = (($this) + 700|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 708|0);
 $38 = (($this) + 964|0);
 $39 = (($this) + 968|0);
 $40 = (($this) + 972|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 976|0);
 HEAP8[$38>>0] = 1;
 HEAP32[$39>>2] = $37;
 HEAP32[$41>>2] = 64;
 $42 = (($this) + 980|0);
 HEAP32[$42>>2] = 32;
 $43 = (($this) + 984|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 988|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 992|0);
 HEAP32[$45>>2] = 4096;
 $46 = (($this) + 996|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 1000|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 1004|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 1008|0);
 HEAP32[$49>>2] = $s;
 $scevgep = (($this) + 88|0);
 ;HEAP32[$scevgep+0>>2]=0|0;HEAP32[$scevgep+4>>2]=0|0;HEAP32[$scevgep+8>>2]=0|0;HEAP32[$scevgep+12>>2]=0|0;HEAP32[$scevgep+16>>2]=0|0;HEAP32[$scevgep+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionSceneD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i$1 = 0, $or$cond$i$i$2 = 0, $or$cond$i$i$3 = 0, $or$cond$i$i$4 = 0, $or$cond$i$i$5 = 0, $or$cond$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 1000|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN5physx10PxsContextD2Ev($2);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 }
 $4 = (($this) + 704|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj32EEENS0_19ReflectionAllocatorIS5_EEED2Ev($4);
 $5 = (($this) + 408|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj16EEENS0_19ReflectionAllocatorIS5_EEED2Ev($5);
 $6 = (($this) + 112|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj8EEENS0_19ReflectionAllocatorIS5_EEED2Ev($6);
 $7 = (($this) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9|0)!=(0);
 $11 = ($8|0)>(-1);
 $or$cond$i$i = $10 & $11;
 if ($or$cond$i$i) {
  $12 = (($this) + 76|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$13);
  }
 }
 $19 = (($this) + 72|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 2147483647;
 $22 = ($21|0)!=(0);
 $23 = ($20|0)>(-1);
 $or$cond$i$i$1 = $22 & $23;
 if ($or$cond$i$i$1) {
  $30 = (($this) + 64|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   $33 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   FUNCTION_TABLE_vii[$36 & 4095]($33,$31);
  }
 }
 $37 = (($this) + 60|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 2147483647;
 $40 = ($39|0)!=(0);
 $41 = ($38|0)>(-1);
 $or$cond$i$i$2 = $40 & $41;
 if ($or$cond$i$i$2) {
  $42 = (($this) + 52|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   $45 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($46) + 12|0);
   $48 = HEAP32[$47>>2]|0;
   FUNCTION_TABLE_vii[$48 & 4095]($45,$43);
  }
 }
 $49 = (($this) + 48|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 2147483647;
 $52 = ($51|0)!=(0);
 $53 = ($50|0)>(-1);
 $or$cond$i$i$3 = $52 & $53;
 if ($or$cond$i$i$3) {
  $54 = (($this) + 40|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($58) + 12|0);
   $60 = HEAP32[$59>>2]|0;
   FUNCTION_TABLE_vii[$60 & 4095]($57,$55);
  }
 }
 $61 = (($this) + 36|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = $62 & 2147483647;
 $64 = ($63|0)!=(0);
 $65 = ($62|0)>(-1);
 $or$cond$i$i$4 = $64 & $65;
 if ($or$cond$i$i$4) {
  $66 = (($this) + 28|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  if (!($68)) {
   $69 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + 12|0);
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_vii[$72 & 4095]($69,$67);
  }
 }
 $73 = (($this) + 24|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $74 & 2147483647;
 $76 = ($75|0)!=(0);
 $77 = ($74|0)>(-1);
 $or$cond$i$i$5 = $76 & $77;
 if ($or$cond$i$i$5) {
  $78 = (($this) + 16|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)==(0|0);
  if (!($80)) {
   $81 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($82) + 12|0);
   $84 = HEAP32[$83>>2]|0;
   FUNCTION_TABLE_vii[$84 & 4095]($81,$79);
  }
 }
 $85 = (($this) + 8|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = $86 & 2147483647;
 $88 = ($87|0)!=(0);
 $89 = ($86|0)>(-1);
 $or$cond$i$i1 = $88 & $89;
 if (!($or$cond$i$i1)) {
  STACKTOP = sp;return;
 }
 $24 = HEAP32[$this>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$29 & 4095]($26,$24);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionScene4initERKNS_11PxSceneDescEPNS_13PxTaskManagerEPNS_2Cm9FlushPoolERNS7_13EventProfilerE($this,$desc,$taskManager,$taskPool,$profiler) {
 $this = $this|0;
 $desc = $desc|0;
 $taskManager = $taskManager|0;
 $taskPool = $taskPool|0;
 $profiler = $profiler|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $scevgep = (($this) + 88|0);
 ;HEAP32[$scevgep+0>>2]=0|0;HEAP32[$scevgep+4>>2]=0|0;HEAP32[$scevgep+8>>2]=0|0;HEAP32[$scevgep+12>>2]=0|0;HEAP32[$scevgep+16>>2]=0|0;HEAP32[$scevgep+20>>2]=0|0;
 $0 = (($this) + 1000|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5physx10PxsContextD2Ev($1);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$1);
  HEAP32[$0>>2] = 0;
 }
 $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__Z15PxGetFoundationv()|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $$$i$i$i = $11 ? 475000 : 474152;
 $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,7424,$$$i$i$i,473896,77)|0);
 __ZN5physx10PxsContextC2ERKNS_11PxSceneDescEPNS_13PxTaskManagerEPNS_2Cm9FlushPoolERNS6_13EventProfilerEj($12,$desc,$taskManager,$taskPool,$profiler,64);
 HEAP32[$0>>2] = $12;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,4,473896,81,474008,$vararg_buffer);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc16InteractionScene20addToActiveActorListERNS0_5ActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $swapActor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $swapActor = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 12|0);
 $3 = (($actor) + 51|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 14;
 $6 = ($5<<24>>24)==(4);
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $9 = (($actor) + 40|0);
  HEAP32[$9>>2] = $8;
  HEAP32[$0>>2] = $actor;
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 & 2147483647;
  $13 = HEAP32[$7>>2]|0;
  $14 = ($12>>>0)>($13>>>0);
  if (!($14)) {
   (__ZN5physx6shdfnd5ArrayIPNS_2Sc5ActorENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$0)|0);
   STACKTOP = sp;return;
  }
  $15 = HEAP32[$this>>2]|0;
  $16 = (($15) + ($13<<2)|0);
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   HEAP32[$16>>2] = $actor;
  }
  $18 = (($13) + 1)|0;
  HEAP32[$7>>2] = $18;
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$2>>2]|0;
 $20 = ($8|0)==($19|0);
 do {
  if ($20) {
   $38 = (($actor) + 40|0);
   HEAP32[$38>>2] = $8;
   HEAP32[$1>>2] = $actor;
   $39 = (($this) + 8|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $40 & 2147483647;
   $42 = HEAP32[$7>>2]|0;
   $43 = ($41>>>0)>($42>>>0);
   if (!($43)) {
    (__ZN5physx6shdfnd5ArrayIPNS_2Sc5ActorENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$1)|0);
    break;
   }
   $44 = HEAP32[$this>>2]|0;
   $45 = (($44) + ($42<<2)|0);
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    HEAP32[$45>>2] = $actor;
   }
   $47 = (($42) + 1)|0;
   HEAP32[$7>>2] = $47;
  } else {
   $21 = HEAP32[$this>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$swapActor>>2] = $23;
   $24 = (($actor) + 40|0);
   HEAP32[$24>>2] = $19;
   $25 = HEAP32[$2>>2]|0;
   $26 = (($21) + ($25<<2)|0);
   HEAP32[$26>>2] = $actor;
   $27 = HEAP32[$7>>2]|0;
   $28 = (($23) + 40|0);
   HEAP32[$28>>2] = $27;
   $29 = (($this) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $30 & 2147483647;
   $32 = HEAP32[$7>>2]|0;
   $33 = ($31>>>0)>($32>>>0);
   if (!($33)) {
    (__ZN5physx6shdfnd5ArrayIPNS_2Sc5ActorENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$swapActor)|0);
    break;
   }
   $34 = HEAP32[$this>>2]|0;
   $35 = (($34) + ($32<<2)|0);
   $36 = ($35|0)==(0|0);
   if (!($36)) {
    HEAP32[$35>>2] = $23;
   }
   $37 = (($32) + 1)|0;
   HEAP32[$7>>2] = $37;
  }
 } while(0);
 $48 = HEAP32[$2>>2]|0;
 $49 = (($48) + 1)|0;
 HEAP32[$2>>2] = $49;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionScene25removeFromActiveActorListERNS0_5ActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($actor) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = -2;
 $2 = (($this) + 12|0);
 $3 = (($actor) + 51|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 14;
 $6 = ($5<<24>>24)==(4);
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $9 = (($8) + -1)|0;
  HEAP32[$7>>2] = $9;
  $10 = HEAP32[$this>>2]|0;
  $11 = (($10) + ($9<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + ($1<<2)|0);
  HEAP32[$13>>2] = $12;
  $14 = ($1>>>0)<($9>>>0);
  if (!($14)) {
   STACKTOP = sp;return;
  }
  $15 = HEAP32[$this>>2]|0;
  $16 = (($15) + ($1<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 40|0);
  HEAP32[$18>>2] = $1;
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$2>>2]|0;
 $20 = ($8|0)==($19|0);
 if ($20) {
  $38 = (($8) + -1)|0;
  HEAP32[$7>>2] = $38;
  $39 = HEAP32[$this>>2]|0;
  $40 = (($39) + ($38<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($1<<2)|0);
  HEAP32[$42>>2] = $41;
  $43 = ($1>>>0)<($38>>>0);
  if ($43) {
   $44 = HEAP32[$this>>2]|0;
   $45 = (($44) + ($1<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($46) + 40|0);
   HEAP32[$47>>2] = $1;
  }
 } else {
  $21 = (($19) + -1)|0;
  $22 = ($1>>>0)<($21>>>0);
  if ($22) {
   $23 = HEAP32[$this>>2]|0;
   $24 = (($23) + ($21<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 40|0);
   HEAP32[$26>>2] = $1;
   $27 = (($23) + ($1<<2)|0);
   HEAP32[$27>>2] = $25;
   $$pre = HEAP32[$7>>2]|0;
   $29 = $$pre;
  } else {
   $29 = $8;
  }
  $28 = (($29) + -1)|0;
  HEAP32[$7>>2] = $28;
  $30 = HEAP32[$this>>2]|0;
  $31 = (($30) + ($28<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + ($21<<2)|0);
  HEAP32[$33>>2] = $32;
  $34 = HEAP32[$this>>2]|0;
  $35 = (($34) + ($21<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 40|0);
  HEAP32[$37>>2] = $21;
 }
 $48 = HEAP32[$2>>2]|0;
 $49 = (($48) + -1)|0;
 HEAP32[$2>>2] = $49;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionScene8addActorERNS0_5ActorEb($this,$actor,$active) {
 $this = $this|0;
 $actor = $actor|0;
 $active = $active|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc5Actor9setActiveEbj($actor,$active,1);
 if ($active) {
  __ZN5physx2Sc16InteractionScene20addToActiveActorListERNS0_5ActorE($this,$actor);
  STACKTOP = sp;return;
 } else {
  $0 = (($actor) + 40|0);
  HEAP32[$0>>2] = -2;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc16InteractionScene11removeActorERNS0_5ActorE($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($actor) + 51|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  __ZN5physx2Sc16InteractionScene25removeFromActiveActorListERNS0_5ActorE($this,$actor);
 }
 $4 = (($actor) + 40|0);
 HEAP32[$4>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionScene19registerInteractionEPNS0_11InteractionEb($this,$interaction,$active) {
 $this = $this|0;
 $interaction = $interaction|0;
 $active = $active|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $interaction;
 $1 = (($interaction) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = ((($this) + (($3*12)|0)|0) + 16|0);
 $5 = ((($this) + (($3*12)|0)|0) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($interaction) + 12|0);
 HEAP32[$7>>2] = $6;
 $8 = ((($this) + (($3*12)|0)|0) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($10|0)==(0);
 if ($11) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE8recreateEj($4,64);
  $$pre = HEAP32[$8>>2]|0;
  $13 = $$pre;
 } else {
  $13 = $9;
 }
 $12 = $13 & 2147483647;
 $14 = HEAP32[$5>>2]|0;
 $15 = ($12>>>0)>($14>>>0);
 if ($15) {
  $16 = HEAP32[$4>>2]|0;
  $17 = (($16) + ($14<<2)|0);
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   HEAP32[$17>>2] = $interaction;
  }
  $19 = (($14) + 1)|0;
  HEAP32[$5>>2] = $19;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($4,$0)|0);
 }
 if (!($active)) {
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$0>>2]|0;
 $21 = (($20) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($this) + ($3<<2)|0) + 88|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22>>>0)>($24>>>0);
 if ($25) {
  $26 = ((($this) + (($3*12)|0)|0) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + ($22<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + ($24<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$28>>2] = $31;
  $32 = HEAP32[$26>>2]|0;
  $33 = (($32) + ($24<<2)|0);
  HEAP32[$33>>2] = $29;
  $34 = (($29) + 12|0);
  HEAP32[$34>>2] = $24;
  $35 = (($31) + 12|0);
  HEAP32[$35>>2] = $22;
  $$pre1 = HEAP32[$23>>2]|0;
  $37 = $$pre1;
 } else {
  $37 = $24;
 }
 $36 = (($37) + 1)|0;
 HEAP32[$23>>2] = $36;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionScene21unregisterInteractionEPNS0_11InteractionE($this,$interaction) {
 $this = $this|0;
 $interaction = $interaction|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($interaction) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = (($interaction) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($this) + (($2*12)|0)|0) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 HEAP32[$5>>2] = $7;
 $8 = ((($this) + (($2*12)|0)|0) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + ($4<<2)|0);
 HEAP32[$12>>2] = $11;
 HEAP32[$3>>2] = -1;
 $13 = HEAP32[$5>>2]|0;
 $14 = ($4>>>0)<($13>>>0);
 if ($14) {
  $15 = HEAP32[$8>>2]|0;
  $16 = (($15) + ($4<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 12|0);
  HEAP32[$18>>2] = $4;
 }
 $19 = ((($this) + ($2<<2)|0) + 88|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($4>>>0)<($20>>>0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($20) + -1)|0;
 HEAP32[$19>>2] = $22;
 $23 = HEAP32[$5>>2]|0;
 $24 = ($22>>>0)<($23>>>0);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$8>>2]|0;
 $26 = (($25) + ($4<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + ($22<<2)|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$26>>2] = $29;
 $30 = HEAP32[$8>>2]|0;
 $31 = (($30) + ($22<<2)|0);
 HEAP32[$31>>2] = $27;
 $32 = (($27) + 12|0);
 HEAP32[$32>>2] = $22;
 $33 = (($29) + 12|0);
 HEAP32[$33>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16InteractionScene19isActiveInteractionEPKNS0_11InteractionE($this,$interaction) {
 $this = $this|0;
 $interaction = $interaction|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($interaction) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($interaction) + 20|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = ((($this) + ($4<<2)|0) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($1>>>0)<($6>>>0);
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx2Sc16InteractionScene26notifyInteractionActivatedEPNS0_11InteractionE($this,$interaction) {
 $this = $this|0;
 $interaction = $interaction|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($interaction) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = ((($this) + ($2<<2)|0) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($this) + (($2*12)|0)|0) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if (!($7)) {
  $21 = $4;
  $20 = (($21) + 1)|0;
  HEAP32[$3>>2] = $20;
  STACKTOP = sp;return;
 }
 $8 = (($interaction) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($this) + (($2*12)|0)|0) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($4<<2)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + ($9<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$12>>2] = $15;
 $16 = HEAP32[$10>>2]|0;
 $17 = (($16) + ($9<<2)|0);
 HEAP32[$17>>2] = $13;
 $18 = (($13) + 12|0);
 HEAP32[$18>>2] = $9;
 $19 = (($15) + 12|0);
 HEAP32[$19>>2] = $4;
 $$pre = HEAP32[$3>>2]|0;
 $21 = $$pre;
 $20 = (($21) + 1)|0;
 HEAP32[$3>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionScene28notifyInteractionDeactivatedEPNS0_11InteractionE($this,$interaction) {
 $this = $this|0;
 $interaction = $interaction|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($interaction) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = ((($this) + ($2<<2)|0) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>(1);
 if (!($5)) {
  $20 = $4;
  $19 = (($20) + -1)|0;
  HEAP32[$3>>2] = $19;
  STACKTOP = sp;return;
 }
 $6 = (($4) + -1)|0;
 $7 = (($interaction) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($this) + (($2*12)|0)|0) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($6<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($8<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 HEAP32[$11>>2] = $14;
 $15 = HEAP32[$9>>2]|0;
 $16 = (($15) + ($8<<2)|0);
 HEAP32[$16>>2] = $12;
 $17 = (($12) + 12|0);
 HEAP32[$17>>2] = $8;
 $18 = (($14) + 12|0);
 HEAP32[$18>>2] = $6;
 $$pre = HEAP32[$3>>2]|0;
 $20 = $$pre;
 $19 = (($20) + -1)|0;
 HEAP32[$3>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionScene11preAllocateEjjjj($this,$nbBodies,$nbStaticShapes,$nbDynamicShapes,$nbAggregates) {
 $this = $this|0;
 $nbBodies = $nbBodies|0;
 $nbStaticShapes = $nbStaticShapes|0;
 $nbDynamicShapes = $nbDynamicShapes|0;
 $nbAggregates = $nbAggregates|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nbBodies>>>0)>(64);
 $1 = $0 ? $nbBodies : 64;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)<($1>>>0);
 if ($5) {
  __ZN5physx6shdfnd5ArrayIPNS_2Sc5ActorENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$1);
 }
 $6 = (($this) + 1000|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 __ZN5physx10PxsContext11preAllocateEjjjj($7,$nbBodies,$nbStaticShapes,$nbDynamicShapes,$nbAggregates);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc16InteractionScene14retrieveMemoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc5ActorENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$1);
 $2 = (($this) + 16|0);
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE8recreateEj($2,$4);
 $5 = (($this) + 28|0);
 $6 = (($this) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE8recreateEj($5,$7);
 $8 = (($this) + 40|0);
 $9 = (($this) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE8recreateEj($8,$10);
 $11 = (($this) + 52|0);
 $12 = (($this) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE8recreateEj($11,$13);
 $14 = (($this) + 64|0);
 $15 = (($this) + 68|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE8recreateEj($14,$16);
 $17 = (($this) + 76|0);
 $18 = (($this) + 80|0);
 $19 = HEAP32[$18>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE8recreateEj($17,$19);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc16InteractionScene18getLLIslandManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1000|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6176|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx2Sc16InteractionScene20allocatePointerBlockEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ptr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 if ((($size|0) == 8)) {
  $1 = (($this) + 404|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if ($3) {
   $4 = (($this) + 112|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj8EEENS0_19ReflectionAllocatorIS5_EEE12allocateSlabEv($4);
   $$pre$i$i = HEAP32[$1>>2]|0;
   $6 = $$pre$i$i;
  } else {
   $6 = $2;
  }
  $5 = HEAP32[$6>>2]|0;
  HEAP32[$1>>2] = $5;
  $7 = (($this) + 392|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$7>>2] = $9;
  $10 = (($this) + 396|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + -1)|0;
  HEAP32[$10>>2] = $12;
  $ptr$0 = $6;
  STACKTOP = sp;return ($ptr$0|0);
 } else if ((($size|0) == 16)) {
  $13 = (($this) + 700|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $16 = (($this) + 408|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj16EEENS0_19ReflectionAllocatorIS5_EEE12allocateSlabEv($16);
   $$pre$i$i1 = HEAP32[$13>>2]|0;
   $18 = $$pre$i$i1;
  } else {
   $18 = $14;
  }
  $17 = HEAP32[$18>>2]|0;
  HEAP32[$13>>2] = $17;
  $19 = (($this) + 688|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 1)|0;
  HEAP32[$19>>2] = $21;
  $22 = (($this) + 692|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + -1)|0;
  HEAP32[$22>>2] = $24;
  $ptr$0 = $18;
  STACKTOP = sp;return ($ptr$0|0);
 } else if ((($size|0) == 32)) {
  $25 = (($this) + 996|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if ($27) {
   $28 = (($this) + 704|0);
   __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj32EEENS0_19ReflectionAllocatorIS5_EEE12allocateSlabEv($28);
   $$pre$i$i2 = HEAP32[$25>>2]|0;
   $30 = $$pre$i$i2;
  } else {
   $30 = $26;
  }
  $29 = HEAP32[$30>>2]|0;
  HEAP32[$25>>2] = $29;
  $31 = (($this) + 984|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 1)|0;
  HEAP32[$31>>2] = $33;
  $34 = (($this) + 988|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + -1)|0;
  HEAP32[$34>>2] = $36;
  $ptr$0 = $30;
  STACKTOP = sp;return ($ptr$0|0);
 } else {
  $37 = $size << 2;
  $38 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$37,473896,333)|0);
  $ptr$0 = $38;
  STACKTOP = sp;return ($ptr$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sc16InteractionScene22deallocatePointerBlockEPPvj($this,$block,$size) {
 $this = $this|0;
 $block = $block|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 if ((($size|0) == 16)) {
  $15 = (($this) + 408|0);
  $16 = ($block|0)==(0|0);
  if ($16) {
   STACKTOP = sp;return;
  }
  $17 = (($this) + 688|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + -1)|0;
  HEAP32[$17>>2] = $19;
  $20 = (($this) + 700|0);
  $21 = HEAP32[$20>>2]|0;
  HEAP32[$block>>2] = $21;
  HEAP32[$20>>2] = $block;
  $22 = (($this) + 692|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 1)|0;
  HEAP32[$22>>2] = $24;
  $25 = (($this) + 684|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26*50)|0;
  $28 = ($23|0)<($27|0);
  if ($28) {
   STACKTOP = sp;return;
  }
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj16EEENS0_19ReflectionAllocatorIS5_EEE17releaseEmptySlabsEv($15);
  HEAP32[$22>>2] = 0;
  STACKTOP = sp;return;
 } else if ((($size|0) == 8)) {
  $1 = (($this) + 112|0);
  $2 = ($block|0)==(0|0);
  if ($2) {
   STACKTOP = sp;return;
  }
  $3 = (($this) + 392|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + -1)|0;
  HEAP32[$3>>2] = $5;
  $6 = (($this) + 404|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$block>>2] = $7;
  HEAP32[$6>>2] = $block;
  $8 = (($this) + 396|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$8>>2] = $10;
  $11 = (($this) + 388|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12*50)|0;
  $14 = ($9|0)<($13|0);
  if ($14) {
   STACKTOP = sp;return;
  }
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj8EEENS0_19ReflectionAllocatorIS5_EEE17releaseEmptySlabsEv($1);
  HEAP32[$8>>2] = 0;
  STACKTOP = sp;return;
 } else if ((($size|0) == 32)) {
  $29 = (($this) + 704|0);
  $30 = ($block|0)==(0|0);
  if ($30) {
   STACKTOP = sp;return;
  }
  $31 = (($this) + 984|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + -1)|0;
  HEAP32[$31>>2] = $33;
  $34 = (($this) + 996|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$block>>2] = $35;
  HEAP32[$34>>2] = $block;
  $36 = (($this) + 988|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 1)|0;
  HEAP32[$36>>2] = $38;
  $39 = (($this) + 980|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40*50)|0;
  $42 = ($37|0)<($41|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj32EEENS0_19ReflectionAllocatorIS5_EEE17releaseEmptySlabsEv($29);
  HEAP32[$36>>2] = 0;
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$block);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc16InteractionScene18releaseConstraintsEb($this,$endOfScene) {
 $this = $this|0;
 $endOfScene = $endOfScene|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1008|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1162|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  if (!($endOfScene)) {
   STACKTOP = sp;return;
  }
  $8 = (($this) + 1000|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 44|0);
  __ZN5physx17PxcNpMemBlockPool15releaseContactsEv($10);
  $11 = HEAP32[$8>>2]|0;
  $12 = (($11) + 44|0);
  __ZN5physx17PxcNpMemBlockPool15releaseContactsEv($12);
  STACKTOP = sp;return;
 } else {
  if ($endOfScene) {
   STACKTOP = sp;return;
  }
  $5 = (($this) + 1000|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 44|0);
  __ZN5physx17PxcNpMemBlockPool15releaseContactsEv($7);
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj32EEENS0_19ReflectionAllocatorIS5_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 128)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 474184 : 474152;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,474320,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 474184 : 474152;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,474320,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 474184 : 474152;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,474072,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 474184 : 474152;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,474072,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 474184 : 474152;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,474072,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj16EEENS0_19ReflectionAllocatorIS5_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 64)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 474408 : 474152;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,474320,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 474408 : 474152;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,474320,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 474408 : 474152;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,474072,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 474408 : 474152;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,474072,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 474408 : 474152;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,474072,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj8EEENS0_19ReflectionAllocatorIS5_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 32)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 474544 : 474152;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,474320,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 474544 : 474152;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,474320,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 474544 : 474152;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,474072,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 474544 : 474152;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,474072,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEE4copyINS0_15InlineAllocatorILj256ES7_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 474544 : 474152;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,474072,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj32EEENS0_19ReflectionAllocatorIS5_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 474184 : 474152;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,474680,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + ($$sum<<7)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -128|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj16EEENS0_19ReflectionAllocatorIS5_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 474408 : 474152;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,474680,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + ($$sum<<6)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -64|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj8EEENS0_19ReflectionAllocatorIS5_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 474544 : 474152;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,474680,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + ($$sum<<5)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -32|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 474760 : 474152;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,474072,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc5ActorENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 474888 : 474152;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,474072,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc11InteractionENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 474760 : 474152;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,474072,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sc5ActorENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 474888 : 474152;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,474072,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj8EEENS0_19ReflectionAllocatorIS5_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj8EEENS0_19ReflectionAllocatorIS5_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj8EEENS0_19ReflectionAllocatorIS5_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj8EEEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<5)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 32|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj16EEENS0_19ReflectionAllocatorIS5_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj16EEENS0_19ReflectionAllocatorIS5_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj16EEENS0_19ReflectionAllocatorIS5_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj16EEEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<6)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 64|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj32EEENS0_19ReflectionAllocatorIS5_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj32EEENS0_19ReflectionAllocatorIS5_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Cm5BlockIPvLj32EEENS0_19ReflectionAllocatorIS5_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Cm5BlockIS2_Lj32EEEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<7)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 128|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc32DefaultClothInterCollisionFilterEPvS1_($cloth0,$cloth1) {
 $cloth0 = $cloth0|0;
 $cloth1 = $cloth1|0;
 var $$byval_copy2 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $filterFlags = 0, $not$ = 0, $pairFlags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy3 = sp + 80|0;
 $$byval_copy2 = sp + 64|0;
 $pairFlags = sp + 98|0;
 $filterFlags = sp + 100|0;
 $0 = sp + 48|0;
 $1 = sp + 16|0;
 $2 = sp + 96|0;
 $3 = sp;
 $4 = sp + 32|0;
 $5 = (($cloth0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK5physx2Sc8ActorSim8getSceneEv($6)|0);
 $8 = (($7) + 1100|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP16[$pairFlags>>1] = 0;
 $10 = (($cloth0) + 44|0);
 ;HEAP32[$0+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$10+12>>2]|0;
 $11 = (($cloth1) + 44|0);
 ;HEAP32[$1+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$11+12>>2]|0;
 $12 = (($7) + 1092|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($7) + 1096|0);
 $15 = HEAP32[$14>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$1+12>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$9 & 63]($filterFlags,5,$$byval_copy2,5,$$byval_copy3,$pairFlags,$13,$15);
 $16 = HEAP16[$filterFlags>>1]|0;
 $17 = $16 & 4;
 $18 = ($17<<16>>16)==(0);
 if ($18) {
  $58 = $16;
 } else {
  $19 = $cloth1;
  $20 = $19 << 15;
  $21 = $20 ^ -1;
  $22 = (($19) + ($21))|0;
  $23 = $22 >>> 10;
  $24 = $23 ^ $22;
  $25 = ($24*9)|0;
  $26 = $25 >>> 6;
  $27 = $26 ^ $25;
  $28 = $27 << 11;
  $29 = $28 ^ -1;
  $30 = (($27) + ($29))|0;
  $31 = $30 >>> 16;
  $32 = $31 ^ $30;
  $33 = $cloth0;
  $34 = $33 << 15;
  $35 = $34 ^ -1;
  $36 = (($33) + ($35))|0;
  $37 = $36 >>> 10;
  $38 = $37 ^ $36;
  $39 = ($38*9)|0;
  $40 = $39 >>> 6;
  $41 = $40 ^ $39;
  $42 = $41 << 11;
  $43 = $42 ^ -1;
  $44 = (($41) + ($43))|0;
  $45 = $44 >>> 16;
  $46 = $44 ^ -57320555;
  $47 = $46 ^ $45;
  $48 = ($47*1000007)|0;
  $49 = $32 ^ $48;
  $50 = (($7) + 1104|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = HEAP32[$51>>2]|0;
  $53 = HEAP32[$52>>2]|0;
  ;HEAP32[$3+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$10+12>>2]|0;
  $54 = (__Z12NpGetPxClothRN5physx2Sc9ClothCoreE($cloth0)|0);
  ;HEAP32[$4+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$11+12>>2]|0;
  $55 = (__Z12NpGetPxClothRN5physx2Sc9ClothCoreE($cloth1)|0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$3+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$4+12>>2]|0;
  FUNCTION_TABLE_viiiiiiiiiiii[$53 & 3]($2,$51,$49,5,$$byval_copy2,$54,0,5,$$byval_copy3,$55,0,$pairFlags);
  $56 = HEAP16[$2>>1]|0;
  HEAP16[$filterFlags>>1] = $56;
  $58 = $56;
 }
 $57 = $58&65535;
 $59 = $57 & 1;
 $60 = ($59|0)==(0);
 if ($60) {
  $61 = $57 & 2;
  $not$ = ($61|0)==(0);
  STACKTOP = sp;return ($not$|0);
 } else {
  STACKTOP = sp;return 0;
 }
 return 0|0;
}
function __ZNK5physx2Sc9ClothCore6getSimEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Sc9ClothCore23getSimulationFilterDataEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCoreC2ERKNS_11PxTransformERNS0_15ClothFabricCoreEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE($this,$globalPose,$fabric,$particles,$flags) {
 $this = $this|0;
 $globalPose = $globalPose|0;
 $fabric = $fabric|0;
 $particles = $particles|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sc9ActorCoreC2ENS_11PxActorType4EnumEthhh($this,5,1,0,0,0);
 $0 = (($this) + 16|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 20|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 24|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = $fabric;
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 44|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 $6 = HEAP16[$flags>>1]|0;
 $7 = (($this) + 60|0);
 HEAP16[$7>>1] = $6;
 $8 = (($this) + 64|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;
 __ZN5physx2Sc9ClothCore12initLowLevelERKNS_11PxTransformEPKNS_15PxClothParticleE($this,$globalPose,$particles);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore12initLowLevelERKNS_11PxTransformEPKNS_15PxClothParticleE($this,$globalPose,$particles) {
 $this = $this|0;
 $globalPose = $globalPose|0;
 $particles = $particles|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $config = 0, $i$04 = 0, $or$cond$i$i = 0, $tmpcast2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast2$byval_copy = sp + 40|0;
 $0 = sp + 48|0;
 $config = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5physx2Sc15ClothFabricCore11getNbPhasesEv($4)|0);
 $6 = ($5*20)|0;
 $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$6,475112,142)|0);
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = $7;
 $9 = ($7|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($5|0)==(0);
 if (!($10)) {
  $13 = 0;$i$04 = 0;
  while(1) {
   __ZN5physx5cloth11PhaseConfigC2Et($config,$i$04);
   $11 = HEAP32[$8>>2]|0;
   $12 = (($11) + (($13*20)|0)|0);
   $14 = ($12|0)==(0|0);
   if (!($14)) {
    ;HEAP32[$12+0>>2]=HEAP32[$config+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$config+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$config+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$config+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$config+16>>2]|0;
   }
   $15 = (($i$04) + 1)<<16>>16;
   $16 = $15&65535;
   $17 = ($16>>>0)<($5>>>0);
   if ($17) {
    $13 = $16;$i$04 = $15;
   } else {
    break;
   }
  }
 }
 $18 = HEAP32[$3>>2]|0;
 $19 = (__ZNK5physx2Sc15ClothFabricCore14getNbParticlesEv($18)|0);
 $20 = (($particles) + ($19<<4)|0);
 $21 = HEAP32[463296>>2]|0;
 $22 = (($21) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $particles;
 $28 = $20;
 $29 = $1;
 $30 = $29;
 HEAP32[$30>>2] = $27;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $28;
 $33 = HEAP32[$3>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $35 = (FUNCTION_TABLE_iiii[$26 & 2047]($23,$tmpcast2$byval_copy,$34)|0);
 $36 = (($this) + 28|0);
 HEAP32[$36>>2] = $35;
 $37 = ($35|0)==(0|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$35>>2]|0;
 $39 = (($38) + 52|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($globalPose) + 16|0);
 FUNCTION_TABLE_vii[$40 & 4095]($35,$41);
 $42 = HEAP32[$36>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 56|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($42,$globalPose);
 $46 = HEAP32[$36>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 68|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vi[$49 & 4095]($46);
 $50 = HEAP32[$8>>2]|0;
 $51 = (($50) + (($5*20)|0)|0);
 $52 = HEAP32[$36>>2]|0;
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 160|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $50;
 $57 = $51;
 $58 = $2;
 $59 = $58;
 HEAP32[$59>>2] = $56;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $57;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 FUNCTION_TABLE_vii[$55 & 4095]($52,$tmpcast2$byval_copy);
 $62 = HEAP32[$36>>2]|0;
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 212|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($this) + 60|0);
 $67 = HEAP16[$66>>1]|0;
 $68 = $67 & 2;
 $69 = ($68<<16>>16)!=(0);
 FUNCTION_TABLE_vii[$65 & 4095]($62,$69);
 $70 = HEAP32[$36>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + 400|0);
 $73 = HEAP32[$72>>2]|0;
 FUNCTION_TABLE_vii[$73 & 4095]($70,$this);
 $74 = Math_fround(HEAPF32[463304>>2]);
 $75 = $74 > Math_fround(4294967.0);
 if ($75) {
  $76 = HEAP32[$36>>2]|0;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($77) + 368|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_vii[$79 & 4095]($76,-1);
  STACKTOP = sp;return;
 }
 $80 = Math_fround($74 * Math_fround(1000.0));
 $81 = (~~(($80))>>>0);
 $82 = (($81>>>0) / 5)&-1;
 $83 = ($82>>>0)<(200);
 $84 = $83 ? $82 : 200;
 $85 = ($84>>>0)>(1);
 $86 = $85 ? $84 : 1;
 $87 = (($81>>>0) / ($86>>>0))&-1;
 $88 = HEAP32[$36>>2]|0;
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + 388|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (FUNCTION_TABLE_ii[$91 & 4095]($88)|0);
 $93 = HEAP32[$36>>2]|0;
 $94 = HEAP32[$93>>2]|0;
 $95 = (($94) + 368|0);
 $96 = HEAP32[$95>>2]|0;
 FUNCTION_TABLE_vii[$96 & 4095]($93,$86);
 $97 = HEAP32[$36>>2]|0;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($98) + 376|0);
 $100 = HEAP32[$99>>2]|0;
 FUNCTION_TABLE_vii[$100 & 4095]($97,$87);
 $101 = $74 == Math_fround(0.0);
 $or$cond$i$i = $92 & $101;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $102 = HEAP32[$36>>2]|0;
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + 392|0);
 $105 = HEAP32[$104>>2]|0;
 FUNCTION_TABLE_vi[$105 & 4095]($102);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCoreD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $10 = HEAP32[$4>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 4095]($10);
 }
 $15 = (($9) + 4|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = ($16<<16>>16)!=(0);
 $18 = ($9|0)==(0|0);
 $or$cond = $17 | $18;
 if ($or$cond) {
  __ZN5physx2Sc9ActorCoreD2Ev($this);
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$9>>2]|0;
 $20 = (($19) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vi[$21 & 4095]($9);
 __ZN5physx2Sc9ActorCoreD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore13setGlobalPoseERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($pose) + 16|0);
 FUNCTION_TABLE_vii[$4 & 4095]($1,$5);
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($6,$pose);
 $10 = HEAP32[$0>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 68|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vi[$13 & 4095]($10);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore6wakeUpEf($this,$wakeCounter) {
 $this = $this|0;
 $wakeCounter = Math_fround($wakeCounter);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wakeCounter > Math_fround(4294967.0);
 if ($0) {
  $1 = (($this) + 28|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 368|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($2,-1);
  STACKTOP = sp;return;
 }
 $6 = Math_fround($wakeCounter * Math_fround(1000.0));
 $7 = (~~(($6))>>>0);
 $8 = (($7>>>0) / 5)&-1;
 $9 = ($8>>>0)<(200);
 $10 = $9 ? $8 : 200;
 $11 = ($10>>>0)>(1);
 $12 = $11 ? $10 : 1;
 $13 = (($7>>>0) / ($12>>>0))&-1;
 $14 = (($this) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 388|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
 $20 = HEAP32[$14>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 368|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vii[$23 & 4095]($20,$12);
 $24 = HEAP32[$14>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 376|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vii[$27 & 4095]($24,$13);
 $28 = $wakeCounter == Math_fround(0.0);
 $or$cond$i = $19 & $28;
 if (!($or$cond$i)) {
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$14>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 392|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vi[$32 & 4095]($29);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore14updateBulkDataERNS0_13ClothBulkDataE($this,$bulkData) {
 $this = $this|0;
 $bulkData = $bulkData|0;
 var $$0$i = Math_fround(0), $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = Math_fround(0);
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = Math_fround(0), $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = Math_fround(0), $421 = 0, $422 = 0, $423 = Math_fround(0), $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = Math_fround(0);
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = 0, $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = Math_fround(0);
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = Math_fround(0);
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = 0, $492 = Math_fround(0);
 var $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = 0, $497 = Math_fround(0), $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $particles = 0, $tmpcast$i1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $$byval_copy1 = sp + 328|0;
 $tmpcast$i1$byval_copy = sp + 320|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 16|0;
 $particles = sp + 288|0;
 $3 = sp + 272|0;
 $4 = sp + 268|0;
 $5 = sp + 256|0;
 $6 = sp + 240|0;
 $7 = sp + 232|0;
 $8 = sp + 216|0;
 $9 = sp + 72|0;
 $10 = sp + 36|0;
 $11 = sp + 120|0;
 $12 = sp + 136|0;
 $13 = sp + 80|0;
 $14 = sp + 112|0;
 $15 = sp + 96|0;
 $16 = sp + 24|0;
 $17 = sp + 152|0;
 $18 = sp + 164|0;
 $19 = sp + 176|0;
 $20 = sp + 188|0;
 $21 = sp + 200|0;
 $22 = (($this) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 36|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vii[$26 & 4095]($particles,$23);
 $27 = HEAP32[$22>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (FUNCTION_TABLE_ii[$30 & 4095]($27)|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_15PxClothParticleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($bulkData,$31,$3);
 $32 = HEAP32[$bulkData>>2]|0;
 $33 = HEAP32[$particles>>2]|0;
 $34 = (($particles) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35;
 $37 = $33;
 $38 = (($36) - ($37))|0;
 _memcpy(($32|0),($33|0),($38|0))|0;
 $39 = HEAP32[$22>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 236|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (FUNCTION_TABLE_ii[$42 & 4095]($39)|0);
 $44 = ($43|0)==(0);
 if (!($44)) {
  $45 = (($bulkData) + 12|0);
  $46 = HEAP32[$22>>2]|0;
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + 236|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (FUNCTION_TABLE_ii[$49 & 4095]($46)|0);
  $51 = $50 << 2;
  HEAP32[$4>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($45,$51,$4);
  $52 = (($bulkData) + 24|0);
  $53 = HEAP32[$22>>2]|0;
  $54 = HEAP32[$53>>2]|0;
  $55 = (($54) + 240|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (FUNCTION_TABLE_ii[$56 & 4095]($53)|0);
  HEAPF32[$5>>2] = Math_fround(0.0);
  $58 = (($5) + 4|0);
  HEAPF32[$58>>2] = Math_fround(0.0);
  $59 = (($5) + 8|0);
  HEAPF32[$59>>2] = Math_fround(0.0);
  __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($52,$57,$5);
  $60 = HEAP32[$45>>2]|0;
  $61 = HEAP32[$22>>2]|0;
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + 236|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (FUNCTION_TABLE_ii[$64 & 4095]($61)|0);
  $66 = (($60) + ($65<<4)|0);
  $67 = HEAP32[$22>>2]|0;
  $68 = HEAP32[$67>>2]|0;
  $69 = (($68) + 16|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + 44|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = HEAP32[$22>>2]|0;
  $76 = $60;
  $77 = $66;
  $78 = $0;
  $79 = $78;
  HEAP32[$79>>2] = $76;
  $80 = (($78) + 4)|0;
  $81 = $80;
  HEAP32[$81>>2] = $77;
  $82 = $1;
  $83 = $82;
  HEAP32[$83>>2] = 0;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = 0;
  ;HEAP32[$tmpcast$i1$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i1$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
  FUNCTION_TABLE_viiii[$74 & 511]($71,$75,$tmpcast$i1$byval_copy,$$byval_copy1);
  $86 = HEAP32[$52>>2]|0;
  $87 = HEAP32[$22>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 240|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 4095]($87)|0);
  $92 = (($86) + (($91*12)|0)|0);
  $93 = HEAP32[$22>>2]|0;
  $94 = HEAP32[$93>>2]|0;
  $95 = (($94) + 16|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (FUNCTION_TABLE_ii[$96 & 4095]($93)|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = (($98) + 44|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = HEAP32[$22>>2]|0;
  $102 = $0;
  $103 = $102;
  HEAP32[$103>>2] = 0;
  $104 = (($102) + 4)|0;
  $105 = $104;
  HEAP32[$105>>2] = 0;
  $106 = $86;
  $107 = $92;
  $108 = $1;
  $109 = $108;
  HEAP32[$109>>2] = $106;
  $110 = (($108) + 4)|0;
  $111 = $110;
  HEAP32[$111>>2] = $107;
  ;HEAP32[$tmpcast$i1$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i1$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
  FUNCTION_TABLE_viiii[$100 & 511]($97,$101,$tmpcast$i1$byval_copy,$$byval_copy1);
 }
 $112 = HEAP32[$22>>2]|0;
 $113 = HEAP32[$112>>2]|0;
 $114 = (($113) + 168|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (FUNCTION_TABLE_ii[$115 & 4095]($112)|0);
 $117 = ($116|0)==(0);
 if ($117) {
  $118 = HEAP32[$22>>2]|0;
  $119 = HEAP32[$118>>2]|0;
  $120 = (($119) + 192|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = (FUNCTION_TABLE_ii[$121 & 4095]($118)|0);
  $123 = ($122|0)==(0);
  if ($123) {
   $124 = HEAP32[$22>>2]|0;
   $125 = HEAP32[$124>>2]|0;
   $126 = (($125) + 204|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (FUNCTION_TABLE_ii[$127 & 4095]($124)|0);
   $129 = ($128|0)==(0);
   if (!($129)) {
    label = 6;
   }
  } else {
   label = 6;
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  $130 = (($bulkData) + 36|0);
  $131 = HEAP32[$22>>2]|0;
  $132 = HEAP32[$131>>2]|0;
  $133 = (($132) + 168|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = (FUNCTION_TABLE_ii[$134 & 4095]($131)|0);
  __ZN5physx6shdfnd5ArrayINS_22PxClothCollisionSphereENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($130,$135,$6);
  $136 = (($bulkData) + 48|0);
  $137 = HEAP32[$22>>2]|0;
  $138 = HEAP32[$137>>2]|0;
  $139 = (($138) + 176|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = (FUNCTION_TABLE_ii[$140 & 4095]($137)|0);
  $142 = $141 << 1;
  HEAP32[$7>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($136,$142,$7);
  $143 = (($bulkData) + 60|0);
  $144 = HEAP32[$22>>2]|0;
  $145 = HEAP32[$144>>2]|0;
  $146 = (($145) + 184|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = (FUNCTION_TABLE_ii[$147 & 4095]($144)|0);
  __ZN5physx6shdfnd5ArrayINS_21PxClothCollisionPlaneENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($143,$148,$8);
  $149 = (($bulkData) + 72|0);
  $150 = HEAP32[$22>>2]|0;
  $151 = HEAP32[$150>>2]|0;
  $152 = (($151) + 192|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = (FUNCTION_TABLE_ii[$153 & 4095]($150)|0);
  HEAP32[$9>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($149,$154,$9);
  $155 = (($bulkData) + 84|0);
  $156 = HEAP32[$22>>2]|0;
  $157 = HEAP32[$156>>2]|0;
  $158 = (($157) + 204|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = (FUNCTION_TABLE_ii[$159 & 4095]($156)|0);
  __ZN5physx6shdfnd5ArrayINS_24PxClothCollisionTriangleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($155,$160,$10);
  $161 = HEAP32[$130>>2]|0;
  $162 = HEAP32[$136>>2]|0;
  $163 = HEAP32[$143>>2]|0;
  $164 = HEAP32[$149>>2]|0;
  $165 = HEAP32[$155>>2]|0;
  __ZNK5physx2Sc9ClothCore16getCollisionDataEPNS_22PxClothCollisionSphereEPjPNS_21PxClothCollisionPlaneES4_PNS_24PxClothCollisionTriangleE($this,$161,$162,$163,$164,$165);
 }
 $166 = HEAP32[$22>>2]|0;
 $167 = HEAP32[$166>>2]|0;
 $168 = (($167) + 268|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = (FUNCTION_TABLE_ii[$169 & 4095]($166)|0);
 $171 = ($170|0)==(0);
 if (!($171)) {
  $172 = (($bulkData) + 96|0);
  $173 = HEAP32[$22>>2]|0;
  $174 = HEAP32[$173>>2]|0;
  $175 = (($174) + 268|0);
  $176 = HEAP32[$175>>2]|0;
  $177 = (FUNCTION_TABLE_ii[$176 & 4095]($173)|0);
  ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_31PxClothParticleMotionConstraintENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($172,$177,$11);
  $178 = HEAP32[$172>>2]|0;
  $179 = HEAP32[$22>>2]|0;
  $180 = HEAP32[$179>>2]|0;
  $181 = (($180) + 268|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = (FUNCTION_TABLE_ii[$182 & 4095]($179)|0);
  $184 = ($183|0)==(0);
  if (!($184)) {
   $185 = (($178) + ($183<<4)|0);
   $186 = HEAP32[$22>>2]|0;
   $187 = HEAP32[$186>>2]|0;
   $188 = (($187) + 16|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = (FUNCTION_TABLE_ii[$189 & 4095]($186)|0);
   $191 = HEAP32[$190>>2]|0;
   $192 = (($191) + 32|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = HEAP32[$22>>2]|0;
   $195 = $178;
   $196 = $185;
   $197 = $2;
   $198 = $197;
   HEAP32[$198>>2] = $195;
   $199 = (($197) + 4)|0;
   $200 = $199;
   HEAP32[$200>>2] = $196;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$2+4>>2]|0;
   FUNCTION_TABLE_viii[$193 & 4095]($190,$194,$$byval_copy1);
  }
 }
 $201 = HEAP32[$22>>2]|0;
 $202 = HEAP32[$201>>2]|0;
 $203 = (($202) + 300|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = (FUNCTION_TABLE_ii[$204 & 4095]($201)|0);
 $206 = ($205|0)==(0);
 if (!($206)) {
  $207 = (($bulkData) + 108|0);
  $208 = HEAP32[$22>>2]|0;
  $209 = HEAP32[$208>>2]|0;
  $210 = (($209) + 300|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = (FUNCTION_TABLE_ii[$211 & 4095]($208)|0);
  ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_35PxClothParticleSeparationConstraintENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($207,$212,$12);
  $213 = HEAP32[$207>>2]|0;
  $214 = HEAP32[$22>>2]|0;
  $215 = HEAP32[$214>>2]|0;
  $216 = (($215) + 300|0);
  $217 = HEAP32[$216>>2]|0;
  $218 = (FUNCTION_TABLE_ii[$217 & 4095]($214)|0);
  $219 = ($218|0)==(0);
  if (!($219)) {
   $220 = (($213) + ($218<<4)|0);
   $221 = HEAP32[$22>>2]|0;
   $222 = HEAP32[$221>>2]|0;
   $223 = (($222) + 16|0);
   $224 = HEAP32[$223>>2]|0;
   $225 = (FUNCTION_TABLE_ii[$224 & 4095]($221)|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = (($226) + 36|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = HEAP32[$22>>2]|0;
   $230 = $213;
   $231 = $220;
   $232 = $1;
   $233 = $232;
   HEAP32[$233>>2] = $230;
   $234 = (($232) + 4)|0;
   $235 = $234;
   HEAP32[$235>>2] = $231;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
   FUNCTION_TABLE_viii[$228 & 4095]($225,$229,$$byval_copy1);
  }
 }
 $236 = HEAP32[$22>>2]|0;
 $237 = HEAP32[$236>>2]|0;
 $238 = (($237) + 316|0);
 $239 = HEAP32[$238>>2]|0;
 $240 = (FUNCTION_TABLE_ii[$239 & 4095]($236)|0);
 $241 = ($240|0)==(0);
 if (!($241)) {
  $242 = (($bulkData) + 120|0);
  $243 = HEAP32[$22>>2]|0;
  $244 = HEAP32[$243>>2]|0;
  $245 = (($244) + 316|0);
  $246 = HEAP32[$245>>2]|0;
  $247 = (FUNCTION_TABLE_ii[$246 & 4095]($243)|0);
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($242,$247,$13);
  $248 = HEAP32[$242>>2]|0;
  $249 = HEAP32[$22>>2]|0;
  $250 = HEAP32[$249>>2]|0;
  $251 = (($250) + 316|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = (FUNCTION_TABLE_ii[$252 & 4095]($249)|0);
  $254 = ($253|0)==(0);
  if (!($254)) {
   $255 = (($248) + ($253<<4)|0);
   $256 = HEAP32[$22>>2]|0;
   $257 = HEAP32[$256>>2]|0;
   $258 = (($257) + 16|0);
   $259 = HEAP32[$258>>2]|0;
   $260 = (FUNCTION_TABLE_ii[$259 & 4095]($256)|0);
   $261 = HEAP32[$260>>2]|0;
   $262 = (($261) + 40|0);
   $263 = HEAP32[$262>>2]|0;
   $264 = HEAP32[$22>>2]|0;
   $265 = $248;
   $266 = $255;
   $267 = $0;
   $268 = $267;
   HEAP32[$268>>2] = $265;
   $269 = (($267) + 4)|0;
   $270 = $269;
   HEAP32[$270>>2] = $266;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;
   FUNCTION_TABLE_viii[$263 & 4095]($260,$264,$$byval_copy1);
  }
 }
 $271 = HEAP32[$22>>2]|0;
 $272 = HEAP32[$271>>2]|0;
 $273 = (($272) + 340|0);
 $274 = HEAP32[$273>>2]|0;
 $275 = (FUNCTION_TABLE_ii[$274 & 4095]($271)|0);
 $276 = ($275|0)==(0);
 if (!($276)) {
  $277 = (($bulkData) + 132|0);
  $278 = HEAP32[$22>>2]|0;
  $279 = HEAP32[$278>>2]|0;
  $280 = (($279) + 340|0);
  $281 = HEAP32[$280>>2]|0;
  $282 = (FUNCTION_TABLE_ii[$281 & 4095]($278)|0);
  HEAP32[$14>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($277,$282,$14);
  $283 = HEAP32[$277>>2]|0;
  $284 = HEAP32[$22>>2]|0;
  $285 = HEAP32[$284>>2]|0;
  $286 = (($285) + 340|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = (FUNCTION_TABLE_ii[$287 & 4095]($284)|0);
  $289 = HEAP32[$22>>2]|0;
  $290 = HEAP32[$289>>2]|0;
  $291 = (($290) + 16|0);
  $292 = HEAP32[$291>>2]|0;
  $293 = (FUNCTION_TABLE_ii[$292 & 4095]($289)|0);
  $294 = HEAP32[$293>>2]|0;
  $295 = (($294) + 48|0);
  $296 = HEAP32[$295>>2]|0;
  $297 = HEAP32[$22>>2]|0;
  $298 = (($283) + ($288<<2)|0);
  HEAP32[$tmpcast$i1$byval_copy>>2] = $283;
  $299 = (($tmpcast$i1$byval_copy) + 4|0);
  HEAP32[$299>>2] = $298;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$tmpcast$i1$byval_copy+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$tmpcast$i1$byval_copy+4>>2]|0;
  FUNCTION_TABLE_viii[$296 & 4095]($293,$297,$$byval_copy1);
 }
 $300 = HEAP32[$22>>2]|0;
 $301 = HEAP32[$300>>2]|0;
 $302 = (($301) + 348|0);
 $303 = HEAP32[$302>>2]|0;
 $304 = (FUNCTION_TABLE_ii[$303 & 4095]($300)|0);
 $305 = ($304|0)==(0);
 if (!($305)) {
  $306 = (($bulkData) + 144|0);
  $307 = HEAP32[$22>>2]|0;
  $308 = HEAP32[$307>>2]|0;
  $309 = (($308) + 348|0);
  $310 = HEAP32[$309>>2]|0;
  $311 = (FUNCTION_TABLE_ii[$310 & 4095]($307)|0);
  ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($306,$311,$15);
  $312 = HEAP32[$306>>2]|0;
  $313 = HEAP32[$22>>2]|0;
  $314 = HEAP32[$313>>2]|0;
  $315 = (($314) + 348|0);
  $316 = HEAP32[$315>>2]|0;
  $317 = (FUNCTION_TABLE_ii[$316 & 4095]($313)|0);
  $318 = HEAP32[$22>>2]|0;
  $319 = HEAP32[$318>>2]|0;
  $320 = (($319) + 16|0);
  $321 = HEAP32[$320>>2]|0;
  $322 = (FUNCTION_TABLE_ii[$321 & 4095]($318)|0);
  $323 = HEAP32[$322>>2]|0;
  $324 = (($323) + 52|0);
  $325 = HEAP32[$324>>2]|0;
  $326 = HEAP32[$22>>2]|0;
  $327 = (($312) + ($317<<4)|0);
  HEAP32[$tmpcast$i1$byval_copy>>2] = $312;
  $328 = (($tmpcast$i1$byval_copy) + 4|0);
  HEAP32[$328>>2] = $327;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$tmpcast$i1$byval_copy+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$tmpcast$i1$byval_copy+4>>2]|0;
  FUNCTION_TABLE_viii[$325 & 4095]($322,$326,$$byval_copy1);
 }
 $329 = HEAP32[$22>>2]|0;
 $330 = HEAP32[$329>>2]|0;
 $331 = (($330) + 248|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = (Math_fround(FUNCTION_TABLE_fi[$332 & 255]($329)));
 $334 = (($bulkData) + 156|0);
 HEAPF32[$334>>2] = $333;
 $335 = HEAP32[$22>>2]|0;
 $336 = HEAP32[$335>>2]|0;
 $337 = (($336) + 256|0);
 $338 = HEAP32[$337>>2]|0;
 $339 = (Math_fround(FUNCTION_TABLE_fi[$338 & 255]($335)));
 $340 = (($bulkData) + 160|0);
 HEAPF32[$340>>2] = $339;
 $341 = HEAP32[$22>>2]|0;
 $342 = HEAP32[$341>>2]|0;
 $343 = (($342) + 276|0);
 $344 = HEAP32[$343>>2]|0;
 $345 = (Math_fround(FUNCTION_TABLE_fi[$344 & 255]($341)));
 $346 = (($bulkData) + 164|0);
 HEAPF32[$346>>2] = $345;
 $347 = HEAP32[$22>>2]|0;
 $348 = HEAP32[$347>>2]|0;
 $349 = (($348) + 280|0);
 $350 = HEAP32[$349>>2]|0;
 $351 = (Math_fround(FUNCTION_TABLE_fi[$350 & 255]($347)));
 $352 = (($bulkData) + 168|0);
 HEAPF32[$352>>2] = $351;
 $353 = HEAP32[$22>>2]|0;
 $354 = HEAP32[$353>>2]|0;
 $355 = (($354) + 288|0);
 $356 = HEAP32[$355>>2]|0;
 $357 = (Math_fround(FUNCTION_TABLE_fi[$356 & 255]($353)));
 $358 = (($bulkData) + 172|0);
 HEAPF32[$358>>2] = $357;
 $359 = (($this) + 16|0);
 $360 = Math_fround(HEAPF32[$359>>2]);
 $361 = (($this) + 20|0);
 $362 = Math_fround(HEAPF32[$361>>2]);
 $363 = (($this) + 24|0);
 $364 = Math_fround(HEAPF32[$363>>2]);
 $365 = (($bulkData) + 176|0);
 HEAPF32[$365>>2] = $360;
 $366 = (($bulkData) + 180|0);
 HEAPF32[$366>>2] = $362;
 $367 = (($bulkData) + 184|0);
 HEAPF32[$367>>2] = $364;
 $368 = HEAP32[$22>>2]|0;
 $369 = HEAP32[$368>>2]|0;
 $370 = (($369) + 92|0);
 $371 = HEAP32[$370>>2]|0;
 FUNCTION_TABLE_vii[$371 & 4095]($16,$368);
 $372 = Math_fround(HEAPF32[$16>>2]);
 $373 = (($bulkData) + 188|0);
 HEAPF32[$373>>2] = $372;
 $374 = (($16) + 4|0);
 $375 = Math_fround(HEAPF32[$374>>2]);
 $376 = (($bulkData) + 192|0);
 HEAPF32[$376>>2] = $375;
 $377 = (($16) + 8|0);
 $378 = Math_fround(HEAPF32[$377>>2]);
 $379 = (($bulkData) + 196|0);
 HEAPF32[$379>>2] = $378;
 $380 = HEAP32[$22>>2]|0;
 $381 = HEAP32[$380>>2]|0;
 $382 = (($381) + 228|0);
 $383 = HEAP32[$382>>2]|0;
 $384 = (Math_fround(FUNCTION_TABLE_fi[$383 & 255]($380)));
 $385 = (($bulkData) + 200|0);
 HEAPF32[$385>>2] = $384;
 $386 = HEAP32[$22>>2]|0;
 $387 = HEAP32[$386>>2]|0;
 $388 = (($387) + 216|0);
 $389 = HEAP32[$388>>2]|0;
 $390 = (Math_fround(FUNCTION_TABLE_fi[$389 & 255]($386)));
 $391 = (($bulkData) + 204|0);
 HEAPF32[$391>>2] = $390;
 $392 = HEAP32[$22>>2]|0;
 $393 = HEAP32[$392>>2]|0;
 $394 = (($393) + 100|0);
 $395 = HEAP32[$394>>2]|0;
 FUNCTION_TABLE_vii[$395 & 4095]($17,$392);
 $396 = Math_fround(HEAPF32[$17>>2]);
 $397 = (($bulkData) + 208|0);
 HEAPF32[$397>>2] = $396;
 $398 = (($17) + 4|0);
 $399 = Math_fround(HEAPF32[$398>>2]);
 $400 = (($bulkData) + 212|0);
 HEAPF32[$400>>2] = $399;
 $401 = (($17) + 8|0);
 $402 = Math_fround(HEAPF32[$401>>2]);
 $403 = (($bulkData) + 216|0);
 HEAPF32[$403>>2] = $402;
 $404 = HEAP32[$22>>2]|0;
 $405 = HEAP32[$404>>2]|0;
 $406 = (($405) + 108|0);
 $407 = HEAP32[$406>>2]|0;
 FUNCTION_TABLE_vii[$407 & 4095]($18,$404);
 $408 = Math_fround(HEAPF32[$18>>2]);
 $409 = (($bulkData) + 220|0);
 HEAPF32[$409>>2] = $408;
 $410 = (($18) + 4|0);
 $411 = Math_fround(HEAPF32[$410>>2]);
 $412 = (($bulkData) + 224|0);
 HEAPF32[$412>>2] = $411;
 $413 = (($18) + 8|0);
 $414 = Math_fround(HEAPF32[$413>>2]);
 $415 = (($bulkData) + 228|0);
 HEAPF32[$415>>2] = $414;
 $416 = HEAP32[$22>>2]|0;
 $417 = HEAP32[$416>>2]|0;
 $418 = (($417) + 116|0);
 $419 = HEAP32[$418>>2]|0;
 FUNCTION_TABLE_vii[$419 & 4095]($19,$416);
 $420 = Math_fround(HEAPF32[$19>>2]);
 $421 = (($bulkData) + 232|0);
 HEAPF32[$421>>2] = $420;
 $422 = (($19) + 4|0);
 $423 = Math_fround(HEAPF32[$422>>2]);
 $424 = (($bulkData) + 236|0);
 HEAPF32[$424>>2] = $423;
 $425 = (($19) + 8|0);
 $426 = Math_fround(HEAPF32[$425>>2]);
 $427 = (($bulkData) + 240|0);
 HEAPF32[$427>>2] = $426;
 $428 = HEAP32[$22>>2]|0;
 $429 = HEAP32[$428>>2]|0;
 $430 = (($429) + 124|0);
 $431 = HEAP32[$430>>2]|0;
 FUNCTION_TABLE_vii[$431 & 4095]($20,$428);
 $432 = Math_fround(HEAPF32[$20>>2]);
 $433 = (($bulkData) + 244|0);
 HEAPF32[$433>>2] = $432;
 $434 = (($20) + 4|0);
 $435 = Math_fround(HEAPF32[$434>>2]);
 $436 = (($bulkData) + 248|0);
 HEAPF32[$436>>2] = $435;
 $437 = (($20) + 8|0);
 $438 = Math_fround(HEAPF32[$437>>2]);
 $439 = (($bulkData) + 252|0);
 HEAPF32[$439>>2] = $438;
 $440 = HEAP32[$22>>2]|0;
 $441 = HEAP32[$440>>2]|0;
 $442 = (($441) + 132|0);
 $443 = HEAP32[$442>>2]|0;
 FUNCTION_TABLE_vii[$443 & 4095]($21,$440);
 $444 = Math_fround(HEAPF32[$21>>2]);
 $445 = (($bulkData) + 256|0);
 HEAPF32[$445>>2] = $444;
 $446 = (($21) + 4|0);
 $447 = Math_fround(HEAPF32[$446>>2]);
 $448 = (($bulkData) + 260|0);
 HEAPF32[$448>>2] = $447;
 $449 = (($21) + 8|0);
 $450 = Math_fround(HEAPF32[$449>>2]);
 $451 = (($bulkData) + 264|0);
 HEAPF32[$451>>2] = $450;
 $452 = HEAP32[$22>>2]|0;
 $453 = HEAP32[$452>>2]|0;
 $454 = (($453) + 140|0);
 $455 = HEAP32[$454>>2]|0;
 $456 = (Math_fround(FUNCTION_TABLE_fi[$455 & 255]($452)));
 $457 = (($bulkData) + 268|0);
 HEAPF32[$457>>2] = $456;
 $458 = HEAP32[$22>>2]|0;
 $459 = HEAP32[$458>>2]|0;
 $460 = (($459) + 148|0);
 $461 = HEAP32[$460>>2]|0;
 $462 = (Math_fround(FUNCTION_TABLE_fi[$461 & 255]($458)));
 $463 = (($bulkData) + 272|0);
 HEAPF32[$463>>2] = $462;
 $464 = HEAP32[$22>>2]|0;
 $465 = HEAP32[$464>>2]|0;
 $466 = (($465) + 324|0);
 $467 = HEAP32[$466>>2]|0;
 $468 = (Math_fround(FUNCTION_TABLE_fi[$467 & 255]($464)));
 $469 = (($bulkData) + 276|0);
 HEAPF32[$469>>2] = $468;
 $470 = HEAP32[$22>>2]|0;
 $471 = HEAP32[$470>>2]|0;
 $472 = (($471) + 332|0);
 $473 = HEAP32[$472>>2]|0;
 $474 = (Math_fround(FUNCTION_TABLE_fi[$473 & 255]($470)));
 $475 = (($bulkData) + 280|0);
 HEAPF32[$475>>2] = $474;
 $476 = HEAP32[$22>>2]|0;
 $477 = HEAP32[$476>>2]|0;
 $478 = (($477) + 60|0);
 $479 = HEAP32[$478>>2]|0;
 $480 = (FUNCTION_TABLE_ii[$479 & 4095]($476)|0);
 $481 = HEAP32[$22>>2]|0;
 $482 = HEAP32[$481>>2]|0;
 $483 = (($482) + 64|0);
 $484 = HEAP32[$483>>2]|0;
 $485 = (FUNCTION_TABLE_ii[$484 & 4095]($481)|0);
 $486 = Math_fround(HEAPF32[$485>>2]);
 $487 = (($485) + 4|0);
 $488 = Math_fround(HEAPF32[$487>>2]);
 $489 = (($485) + 8|0);
 $490 = Math_fround(HEAPF32[$489>>2]);
 $491 = (($485) + 12|0);
 $492 = Math_fround(HEAPF32[$491>>2]);
 $493 = Math_fround(HEAPF32[$480>>2]);
 $494 = (($480) + 4|0);
 $495 = Math_fround(HEAPF32[$494>>2]);
 $496 = (($480) + 8|0);
 $497 = Math_fround(HEAPF32[$496>>2]);
 $498 = (($bulkData) + 284|0);
 HEAPF32[$498>>2] = $486;
 $499 = (($bulkData) + 288|0);
 HEAPF32[$499>>2] = $488;
 $500 = (($bulkData) + 292|0);
 HEAPF32[$500>>2] = $490;
 $501 = (($bulkData) + 296|0);
 HEAPF32[$501>>2] = $492;
 $502 = (($bulkData) + 300|0);
 HEAPF32[$502>>2] = $493;
 $503 = (($bulkData) + 304|0);
 HEAPF32[$503>>2] = $495;
 $504 = (($bulkData) + 308|0);
 HEAPF32[$504>>2] = $497;
 $505 = HEAP32[$22>>2]|0;
 $506 = HEAP32[$505>>2]|0;
 $507 = (($506) + 364|0);
 $508 = HEAP32[$507>>2]|0;
 $509 = (Math_fround(FUNCTION_TABLE_fi[$508 & 255]($505)));
 $510 = (($bulkData) + 312|0);
 HEAPF32[$510>>2] = $509;
 $511 = HEAP32[$22>>2]|0;
 $512 = HEAP32[$511>>2]|0;
 $513 = (($512) + 372|0);
 $514 = HEAP32[$513>>2]|0;
 $515 = (FUNCTION_TABLE_ii[$514 & 4095]($511)|0);
 $516 = ($515|0)==(-1);
 if ($516) {
  $$0$i = Math_fround(3.40282346638528859812E+38);
 } else {
  $517 = HEAP32[$22>>2]|0;
  $518 = HEAP32[$517>>2]|0;
  $519 = (($518) + 380|0);
  $520 = HEAP32[$519>>2]|0;
  $521 = (FUNCTION_TABLE_ii[$520 & 4095]($517)|0);
  $522 = HEAP32[$22>>2]|0;
  $523 = HEAP32[$522>>2]|0;
  $524 = (($523) + 384|0);
  $525 = HEAP32[$524>>2]|0;
  $526 = (FUNCTION_TABLE_ii[$525 & 4095]($522)|0);
  $527 = ($526>>>0)<($521>>>0);
  if ($527) {
   $528 = (($521) - ($526))|0;
   $529 = Math_imul($528, $515)|0;
   $530 = (Math_fround(($529>>>0)));
   $531 = Math_fround($530 / Math_fround(1000.0));
   $$0$i = $531;
  } else {
   $$0$i = Math_fround(0.0);
  }
 }
 $532 = (($bulkData) + 316|0);
 HEAPF32[$532>>2] = $$0$i;
 $533 = (($particles) + 20|0);
 $534 = HEAP32[$533>>2]|0;
 $535 = (($particles) + 24|0);
 $536 = HEAP32[$535>>2]|0;
 $537 = (($particles) + 8|0);
 $538 = HEAP32[$537>>2]|0;
 $539 = $536 >> 1;
 $540 = (($538) + ($539)|0);
 $541 = $536 & 1;
 $542 = ($541|0)==(0);
 if ($542) {
  $546 = $534;
  $547 = $546;
  FUNCTION_TABLE_vi[$547 & 4095]($540);
  STACKTOP = sp;return;
 } else {
  $543 = HEAP32[$540>>2]|0;
  $544 = (($543) + ($534)|0);
  $545 = HEAP32[$544>>2]|0;
  $547 = $545;
  FUNCTION_TABLE_vi[$547 & 4095]($540);
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd5ArrayINS_15PxClothParticleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_15PxClothParticleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $$01$i = $9;
 while(1) {
  $13 = ($$01$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $14;
   $15 = (($$01$i) + 4|0);
   $16 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$15>>2] = $16;
   $17 = (($$01$i) + 8|0);
   $18 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$17>>2] = $18;
   $19 = (($$01$i) + 12|0);
   $20 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$19>>2] = $20;
  }
  $21 = (($$01$i) + 16|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore14getNbParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc9ClothCore21getNbVirtualParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 236|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc9ClothCore27getNbVirtualParticleWeightsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 240|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc9ClothCore19getVirtualParticlesEPj($this,$indicesBuffer) {
 $this = $this|0;
 $indicesBuffer = $indicesBuffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, $tmpcast2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast2$byval_copy = sp + 24|0;
 $tmpcast$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 236|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 $8 = (($indicesBuffer) + ($7<<4)|0);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 44|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$2>>2]|0;
 $18 = $indicesBuffer;
 $19 = $8;
 $20 = $0;
 $21 = $20;
 HEAP32[$21>>2] = $18;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = $1;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 FUNCTION_TABLE_viiii[$16 & 511]($13,$17,$tmpcast$byval_copy,$tmpcast2$byval_copy);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore25getVirtualParticleWeightsEPNS_6PxVec3E($this,$weightsBuffer) {
 $this = $this|0;
 $weightsBuffer = $weightsBuffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, $tmpcast2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast2$byval_copy = sp + 24|0;
 $tmpcast$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 240|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 $8 = (($weightsBuffer) + (($7*12)|0)|0);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 44|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$2>>2]|0;
 $18 = $0;
 $19 = $18;
 HEAP32[$19>>2] = 0;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = 0;
 $22 = $weightsBuffer;
 $23 = $8;
 $24 = $1;
 $25 = $24;
 HEAP32[$25>>2] = $22;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 FUNCTION_TABLE_viiii[$16 & 511]($13,$17,$tmpcast$byval_copy,$tmpcast2$byval_copy);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore21getNbCollisionSpheresEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 168|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc9ClothCore22getNbCollisionConvexesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 192|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc9ClothCore23getNbCollisionTrianglesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 204|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx6shdfnd5ArrayINS_22PxClothCollisionSphereENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_22PxClothCollisionSphereENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $$01$i = $9;
 while(1) {
  $13 = ($$01$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $14;
   $15 = (($$01$i) + 4|0);
   $16 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$15>>2] = $16;
   $17 = (($$01$i) + 8|0);
   $18 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$17>>2] = $18;
   $19 = (($$01$i) + 12|0);
   $20 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$19>>2] = $20;
  }
  $21 = (($$01$i) + 16|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore22getNbCollisionCapsulesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 176|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx6shdfnd5ArrayINS_21PxClothCollisionPlaneENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_21PxClothCollisionPlaneENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $$01$i = $9;
 while(1) {
  $13 = ($$01$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $14;
   $15 = (($$01$i) + 4|0);
   $16 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$15>>2] = $16;
   $17 = (($$01$i) + 8|0);
   $18 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$17>>2] = $18;
   $19 = (($$01$i) + 12|0);
   $20 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$19>>2] = $20;
  }
  $21 = (($$01$i) + 16|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore20getNbCollisionPlanesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 184|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx6shdfnd5ArrayINS_24PxClothCollisionTriangleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_24PxClothCollisionTriangleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*36)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*36)|0)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $13 = (($a) + 16|0);
 $14 = (($a) + 20|0);
 $15 = (($a) + 24|0);
 $16 = (($a) + 28|0);
 $17 = (($a) + 32|0);
 $$01$i = $9;
 while(1) {
  $18 = ($$01$i|0)==(0|0);
  if (!($18)) {
   $19 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $19;
   $20 = (($$01$i) + 4|0);
   $21 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$20>>2] = $21;
   $22 = (($$01$i) + 8|0);
   $23 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$22>>2] = $23;
   $24 = (($$01$i) + 12|0);
   $25 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$24>>2] = $25;
   $26 = (($$01$i) + 16|0);
   $27 = Math_fround(HEAPF32[$13>>2]);
   HEAPF32[$26>>2] = $27;
   $28 = (($$01$i) + 20|0);
   $29 = Math_fround(HEAPF32[$14>>2]);
   HEAPF32[$28>>2] = $29;
   $30 = (($$01$i) + 24|0);
   $31 = Math_fround(HEAPF32[$15>>2]);
   HEAPF32[$30>>2] = $31;
   $32 = (($$01$i) + 28|0);
   $33 = Math_fround(HEAPF32[$16>>2]);
   HEAPF32[$32>>2] = $33;
   $34 = (($$01$i) + 32|0);
   $35 = Math_fround(HEAPF32[$17>>2]);
   HEAPF32[$34>>2] = $35;
  }
  $36 = (($$01$i) + 36|0);
  $37 = ($36>>>0)<($7>>>0);
  if ($37) {
   $$01$i = $36;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore16getCollisionDataEPNS_22PxClothCollisionSphereEPjPNS_21PxClothCollisionPlaneES4_PNS_24PxClothCollisionTriangleE($this,$spheresBuffer,$capsulesBuffer,$planesBuffer,$convexesBuffer,$trianglesBuffer) {
 $this = $this|0;
 $spheresBuffer = $spheresBuffer|0;
 $capsulesBuffer = $capsulesBuffer|0;
 $planesBuffer = $planesBuffer|0;
 $convexesBuffer = $convexesBuffer|0;
 $trianglesBuffer = $trianglesBuffer|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $tmpcast$byval_copy = 0, $tmpcast2$byval_copy = 0, $tmpcast4$byval_copy = 0, $tmpcast6$byval_copy = 0, $tmpcast8$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast8$byval_copy = sp + 64|0;
 $tmpcast6$byval_copy = sp + 56|0;
 $tmpcast4$byval_copy = sp + 48|0;
 $tmpcast2$byval_copy = sp + 40|0;
 $tmpcast$byval_copy = sp + 72|0;
 $0 = sp + 32|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = sp + 24|0;
 $5 = ($spheresBuffer|0)==(0|0);
 if ($5) {
  $13 = 0;
 } else {
  $6 = (($this) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 168|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
  $13 = $11;
 }
 $12 = (($spheresBuffer) + ($13<<4)|0);
 $14 = ($capsulesBuffer|0)==(0|0);
 if ($14) {
  $23 = 0;
 } else {
  $15 = (($this) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 176|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
  $21 = $20 << 1;
  $23 = $21;
 }
 $22 = (($capsulesBuffer) + ($23<<2)|0);
 $24 = ($planesBuffer|0)==(0|0);
 if ($24) {
  $32 = 0;
 } else {
  $25 = (($this) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 184|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (FUNCTION_TABLE_ii[$29 & 4095]($26)|0);
  $32 = $30;
 }
 $31 = (($planesBuffer) + ($32<<4)|0);
 $33 = ($convexesBuffer|0)==(0|0);
 if ($33) {
  $41 = 0;
 } else {
  $34 = (($this) + 28|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 192|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (FUNCTION_TABLE_ii[$38 & 4095]($35)|0);
  $41 = $39;
 }
 $40 = (($convexesBuffer) + ($41<<2)|0);
 $42 = ($trianglesBuffer|0)==(0|0);
 $$pre = (($this) + 28|0);
 if ($42) {
  $50 = 0;
 } else {
  $43 = HEAP32[$$pre>>2]|0;
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 204|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (FUNCTION_TABLE_ii[$46 & 4095]($43)|0);
  $48 = ($47*3)|0;
  $50 = $48;
 }
 $49 = (($trianglesBuffer) + (($50*12)|0)|0);
 $51 = HEAP32[$$pre>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (FUNCTION_TABLE_ii[$54 & 4095]($51)|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 28|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = HEAP32[$$pre>>2]|0;
 $60 = $spheresBuffer;
 $61 = $12;
 $62 = $0;
 $63 = $62;
 HEAP32[$63>>2] = $60;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = $61;
 $66 = $capsulesBuffer;
 $67 = $22;
 $68 = $1;
 $69 = $68;
 HEAP32[$69>>2] = $66;
 $70 = (($68) + 4)|0;
 $71 = $70;
 HEAP32[$71>>2] = $67;
 $72 = $planesBuffer;
 $73 = $31;
 $74 = $2;
 $75 = $74;
 HEAP32[$75>>2] = $72;
 $76 = (($74) + 4)|0;
 $77 = $76;
 HEAP32[$77>>2] = $73;
 $78 = $convexesBuffer;
 $79 = $40;
 $80 = $3;
 $81 = $80;
 HEAP32[$81>>2] = $78;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $79;
 $84 = $trianglesBuffer;
 $85 = $49;
 $86 = $4;
 $87 = $86;
 HEAP32[$87>>2] = $84;
 $88 = (($86) + 4)|0;
 $89 = $88;
 HEAP32[$89>>2] = $85;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
 FUNCTION_TABLE_viiiiiii[$58 & 127]($55,$59,$tmpcast$byval_copy,$tmpcast2$byval_copy,$tmpcast4$byval_copy,$tmpcast6$byval_copy,$tmpcast8$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_31PxClothParticleMotionConstraintENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_31PxClothParticleMotionConstraintENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $$01$i = $9;
 while(1) {
  $13 = ($$01$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $14;
   $15 = (($$01$i) + 4|0);
   $16 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$15>>2] = $16;
   $17 = (($$01$i) + 8|0);
   $18 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$17>>2] = $18;
   $19 = (($$01$i) + 12|0);
   $20 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$19>>2] = $20;
  }
  $21 = (($$01$i) + 16|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore20getMotionConstraintsEPNS_31PxClothParticleMotionConstraintE($this,$motionConstraintsBuffer) {
 $this = $this|0;
 $motionConstraintsBuffer = $motionConstraintsBuffer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 268|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = ($6|0)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($motionConstraintsBuffer) + ($6<<4)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 32|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$1>>2]|0;
 $18 = $motionConstraintsBuffer;
 $19 = $8;
 $20 = $0;
 $21 = $20;
 HEAP32[$21>>2] = $18;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$16 & 4095]($13,$17,$tmpcast$byval_copy);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayINS_35PxClothParticleSeparationConstraintENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_35PxClothParticleSeparationConstraintENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $$01$i = $9;
 while(1) {
  $13 = ($$01$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $14;
   $15 = (($$01$i) + 4|0);
   $16 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$15>>2] = $16;
   $17 = (($$01$i) + 8|0);
   $18 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$17>>2] = $18;
   $19 = (($$01$i) + 12|0);
   $20 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$19>>2] = $20;
  }
  $21 = (($$01$i) + 16|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore24getSeparationConstraintsEPNS_35PxClothParticleSeparationConstraintE($this,$separationConstraintsBuffer) {
 $this = $this|0;
 $separationConstraintsBuffer = $separationConstraintsBuffer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 300|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = ($6|0)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($separationConstraintsBuffer) + ($6<<4)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$1>>2]|0;
 $18 = $separationConstraintsBuffer;
 $19 = $8;
 $20 = $0;
 $21 = $20;
 HEAP32[$21>>2] = $18;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$16 & 4095]($13,$17,$tmpcast$byval_copy);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $$01$i = $9;
 while(1) {
  $13 = ($$01$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $14;
   $15 = (($$01$i) + 4|0);
   $16 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$15>>2] = $16;
   $17 = (($$01$i) + 8|0);
   $18 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$17>>2] = $18;
   $19 = (($$01$i) + 12|0);
   $20 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$19>>2] = $20;
  }
  $21 = (($$01$i) + 16|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore24getParticleAccelerationsEPNS_6PxVec4E($this,$particleAccelerationBuffer) {
 $this = $this|0;
 $particleAccelerationBuffer = $particleAccelerationBuffer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 316|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = ($6|0)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($particleAccelerationBuffer) + ($6<<4)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$1>>2]|0;
 $18 = $particleAccelerationBuffer;
 $19 = $8;
 $20 = $0;
 $21 = $20;
 HEAP32[$21>>2] = $18;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$16 & 4095]($13,$17,$tmpcast$byval_copy);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sc9ClothCore23getSelfCollisionIndicesEPj($this,$indices) {
 $this = $this|0;
 $indices = $indices|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 340|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 48|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$1>>2]|0;
 $16 = (($indices) + ($6<<2)|0);
 HEAP32[$0>>2] = $indices;
 $17 = (($0) + 4|0);
 HEAP32[$17>>2] = $16;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$14 & 4095]($11,$15,$$byval_copy);
 $18 = ($6|0)!=(0);
 STACKTOP = sp;return ($18|0);
}
function __ZNK5physx2Sc9ClothCore16getRestPositionsEPNS_6PxVec4E($this,$restPositions) {
 $this = $this|0;
 $restPositions = $restPositions|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 348|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 52|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$1>>2]|0;
 $16 = (($restPositions) + ($6<<4)|0);
 HEAP32[$0>>2] = $restPositions;
 $17 = (($0) + 4|0);
 HEAP32[$17>>2] = $16;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$14 & 4095]($11,$15,$$byval_copy);
 STACKTOP = sp;return 1;
}
function __ZNK5physx2Sc9ClothCore23getExternalAccelerationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$agg$result>>2] = $11;
 $12 = (($agg$result) + 4|0);
 $13 = (($10) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$12>>2] = $14;
 $15 = (($agg$result) + 8|0);
 $16 = (($10) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$15>>2] = $17;
 $18 = (($agg$result) + 12|0);
 $19 = (($10) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$18>>2] = $20;
 $21 = (($agg$result) + 16|0);
 $22 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$21>>2] = $22;
 $23 = (($agg$result) + 20|0);
 $24 = (($5) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$23>>2] = $25;
 $26 = (($agg$result) + 24|0);
 $27 = (($5) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$26>>2] = $28;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore14getWakeCounterEv($this) {
 $this = $this|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 372|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = ($5|0)==(-1);
 if ($6) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 380|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $12 = HEAP32[$0>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 384|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
 $17 = ($16>>>0)<($11>>>0);
 if (!($17)) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $18 = (($11) - ($16))|0;
 $19 = Math_imul($18, $5)|0;
 $20 = (Math_fround(($19>>>0)));
 $21 = Math_fround($20 / Math_fround(1000.0));
 $$0 = $21;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx2Sc9ClothCore17resolveReferencesERNS0_15ClothFabricCoreE($this,$fabric) {
 $this = $this|0;
 $fabric = $fabric|0;
 var $$byval_copy6 = 0, $$pre = 0, $$pre11 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0;
 var $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i = 0, $separationConstraintsRange$i = 0, $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy6 = sp + 72|0;
 $tmpcast$i$byval_copy = sp + 64|0;
 $separationConstraintsRange$i = sp;
 $0 = sp + 8|0;
 $1 = sp + 56|0;
 $2 = sp + 32|0;
 $3 = sp + 40|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = sp + 48|0;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $fabric;
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 284|0);
 $11 = HEAP32[$9>>2]|0;
 __ZN5physx2Sc9ClothCore12initLowLevelERKNS_11PxTransformEPKNS_15PxClothParticleE($this,$10,$11);
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 164|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$8>>2]|0;
 $18 = (($17) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 40|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + ($21<<4)|0);
 HEAP32[$2>>2] = $19;
 $23 = (($2) + 4|0);
 HEAP32[$23>>2] = $22;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;
 FUNCTION_TABLE_viiii[$16 & 511]($13,$$byval_copy6,0,0);
 $24 = HEAP32[$12>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 172|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$8>>2]|0;
 $29 = (($28) + 48|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 52|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 >>> 1;
 $34 = (($30) + ($33<<2)|0);
 HEAP32[$3>>2] = $30;
 $35 = (($3) + 4|0);
 HEAP32[$35>>2] = $34;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$3+4>>2]|0;
 FUNCTION_TABLE_viiii[$27 & 511]($24,$$byval_copy6,0,0);
 $36 = HEAP32[$12>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 180|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$8>>2]|0;
 $41 = (($40) + 60|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 64|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + ($44<<4)|0);
 HEAP32[$4>>2] = $42;
 $46 = (($4) + 4|0);
 HEAP32[$46>>2] = $45;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$4+4>>2]|0;
 FUNCTION_TABLE_viiii[$39 & 511]($36,$$byval_copy6,0,0);
 $47 = HEAP32[$12>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + 188|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$8>>2]|0;
 $52 = (($51) + 72|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($51) + 76|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($53) + ($55<<2)|0);
 HEAP32[$5>>2] = $53;
 $57 = (($5) + 4|0);
 HEAP32[$57>>2] = $56;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$5+4>>2]|0;
 FUNCTION_TABLE_viiii[$50 & 511]($47,$$byval_copy6,0,0);
 $58 = HEAP32[$12>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 196|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$8>>2]|0;
 $63 = (($62) + 84|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($62) + 88|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($64) + (($66*36)|0)|0);
 HEAP32[$6>>2] = $64;
 $68 = (($6) + 4|0);
 HEAP32[$68>>2] = $67;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$6+4>>2]|0;
 FUNCTION_TABLE_viiii[$61 & 511]($58,$$byval_copy6,0,0);
 $69 = HEAP32[$8>>2]|0;
 $70 = (($69) + 16|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0);
 if ($72) {
  $99 = $69;
 } else {
  $73 = $71 >>> 2;
  $74 = (($69) + 12|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($69) + 28|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($69) + 24|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($75) + ($73<<4)|0);
  $81 = (($79) + (($77*12)|0)|0);
  $82 = HEAP32[$12>>2]|0;
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + 232|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = $75;
  $87 = $80;
  $88 = $separationConstraintsRange$i;
  $89 = $88;
  HEAP32[$89>>2] = $86;
  $90 = (($88) + 4)|0;
  $91 = $90;
  HEAP32[$91>>2] = $87;
  $92 = $79;
  $93 = $81;
  $94 = $0;
  $95 = $94;
  HEAP32[$95>>2] = $92;
  $96 = (($94) + 4)|0;
  $97 = $96;
  HEAP32[$97>>2] = $93;
  ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$separationConstraintsRange$i+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$separationConstraintsRange$i+4>>2]|0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$0+4>>2]|0;
  FUNCTION_TABLE_viii[$85 & 4095]($82,$tmpcast$i$byval_copy,$$byval_copy6);
  $$pre = HEAP32[$8>>2]|0;
  $99 = $$pre;
 }
 $98 = (($99) + 100|0);
 $100 = HEAP32[$98>>2]|0;
 $101 = ($100|0)==(0);
 do {
  if (!($101)) {
   $102 = (($99) + 96|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==(0|0);
   $105 = HEAP32[$12>>2]|0;
   if ($104) {
    $115 = HEAP32[$105>>2]|0;
    $116 = (($115) + 264|0);
    $117 = HEAP32[$116>>2]|0;
    FUNCTION_TABLE_vi[$117 & 4095]($105);
    break;
   } else {
    $106 = HEAP32[$105>>2]|0;
    $107 = (($106) + 260|0);
    $108 = HEAP32[$107>>2]|0;
    FUNCTION_TABLE_vii[$108 & 4095]($tmpcast$i$byval_copy,$105);
    $109 = HEAP32[$tmpcast$i$byval_copy>>2]|0;
    $110 = (($tmpcast$i$byval_copy) + 4|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = $111;
    $113 = $109;
    $114 = (($112) - ($113))|0;
    _memcpy(($109|0),($103|0),($114|0))|0;
    break;
   }
  }
 } while(0);
 $118 = HEAP32[$8>>2]|0;
 $119 = (($118) + 112|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($120|0)==(0);
 do {
  if (!($121)) {
   $122 = (($118) + 108|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = ($123|0)==(0|0);
   $125 = HEAP32[$12>>2]|0;
   if ($124) {
    $135 = HEAP32[$125>>2]|0;
    $136 = (($135) + 296|0);
    $137 = HEAP32[$136>>2]|0;
    FUNCTION_TABLE_vi[$137 & 4095]($125);
    break;
   } else {
    $126 = HEAP32[$125>>2]|0;
    $127 = (($126) + 292|0);
    $128 = HEAP32[$127>>2]|0;
    FUNCTION_TABLE_vii[$128 & 4095]($separationConstraintsRange$i,$125);
    $129 = HEAP32[$separationConstraintsRange$i>>2]|0;
    $130 = (($separationConstraintsRange$i) + 4|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = $131;
    $133 = $129;
    $134 = (($132) - ($133))|0;
    _memcpy(($129|0),($123|0),($134|0))|0;
    break;
   }
  }
 } while(0);
 $138 = HEAP32[$8>>2]|0;
 $139 = (($138) + 124|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = ($140|0)==(0);
 do {
  if (!($141)) {
   $142 = (($138) + 120|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = ($143|0)==(0|0);
   $145 = HEAP32[$12>>2]|0;
   if ($144) {
    $155 = HEAP32[$145>>2]|0;
    $156 = (($155) + 312|0);
    $157 = HEAP32[$156>>2]|0;
    FUNCTION_TABLE_vi[$157 & 4095]($145);
    break;
   } else {
    $146 = HEAP32[$145>>2]|0;
    $147 = (($146) + 308|0);
    $148 = HEAP32[$147>>2]|0;
    FUNCTION_TABLE_vii[$148 & 4095]($0,$145);
    $149 = HEAP32[$0>>2]|0;
    $150 = (($0) + 4|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = $151;
    $153 = $149;
    $154 = (($152) - ($153))|0;
    _memcpy(($149|0),($143|0),($154|0))|0;
    break;
   }
  }
 } while(0);
 $158 = HEAP32[$8>>2]|0;
 $159 = (($158) + 136|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = ($160|0)==(0);
 if ($161) {
  $171 = $158;
 } else {
  $162 = (($158) + 132|0);
  $163 = HEAP32[$162>>2]|0;
  $164 = HEAP32[$12>>2]|0;
  $165 = HEAP32[$164>>2]|0;
  $166 = (($165) + 336|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = (($163) + ($160<<2)|0);
  HEAP32[$1>>2] = $163;
  $169 = (($1) + 4|0);
  HEAP32[$169>>2] = $168;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$1+4>>2]|0;
  FUNCTION_TABLE_vii[$167 & 4095]($164,$$byval_copy6);
  $$pre11 = HEAP32[$8>>2]|0;
  $171 = $$pre11;
 }
 $170 = (($171) + 148|0);
 $172 = HEAP32[$170>>2]|0;
 $173 = ($172|0)==(0);
 if ($173) {
  $194 = $171;
 } else {
  $174 = (($171) + 144|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = ($175|0)==(0|0);
  if ($176) {
   $187 = 0;
  } else {
   $177 = HEAP32[$12>>2]|0;
   $178 = HEAP32[$177>>2]|0;
   $179 = (($178) + 20|0);
   $180 = HEAP32[$179>>2]|0;
   $181 = (FUNCTION_TABLE_ii[$180 & 4095]($177)|0);
   $187 = $181;
  }
  $182 = HEAP32[$12>>2]|0;
  $183 = HEAP32[$182>>2]|0;
  $184 = (($183) + 344|0);
  $185 = HEAP32[$184>>2]|0;
  $186 = (($175) + ($187<<4)|0);
  HEAP32[$1>>2] = $175;
  $188 = (($1) + 4|0);
  HEAP32[$188>>2] = $186;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$1+4>>2]|0;
  FUNCTION_TABLE_vii[$185 & 4095]($182,$$byval_copy6);
  $$pre12 = HEAP32[$8>>2]|0;
  $194 = $$pre12;
 }
 $189 = HEAP32[$12>>2]|0;
 $190 = HEAP32[$189>>2]|0;
 $191 = (($190) + 244|0);
 $192 = HEAP32[$191>>2]|0;
 $193 = (($194) + 156|0);
 $195 = Math_fround(HEAPF32[$193>>2]);
 FUNCTION_TABLE_vif[$192 & 255]($189,$195);
 $196 = HEAP32[$12>>2]|0;
 $197 = HEAP32[$196>>2]|0;
 $198 = (($197) + 252|0);
 $199 = HEAP32[$198>>2]|0;
 $200 = HEAP32[$8>>2]|0;
 $201 = (($200) + 160|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 FUNCTION_TABLE_vif[$199 & 255]($196,$202);
 $203 = HEAP32[$12>>2]|0;
 $204 = HEAP32[$203>>2]|0;
 $205 = (($204) + 272|0);
 $206 = HEAP32[$205>>2]|0;
 $207 = HEAP32[$8>>2]|0;
 $208 = (($207) + 164|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = (($207) + 168|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 FUNCTION_TABLE_viff[$206 & 31]($203,$209,$211);
 $212 = HEAP32[$12>>2]|0;
 $213 = HEAP32[$212>>2]|0;
 $214 = (($213) + 284|0);
 $215 = HEAP32[$214>>2]|0;
 $216 = HEAP32[$8>>2]|0;
 $217 = (($216) + 172|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 FUNCTION_TABLE_vif[$215 & 255]($212,$218);
 $219 = HEAP32[$8>>2]|0;
 $220 = (($219) + 176|0);
 $221 = Math_fround(HEAPF32[$220>>2]);
 $222 = (($219) + 180|0);
 $223 = Math_fround(HEAPF32[$222>>2]);
 $224 = (($219) + 184|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = (($this) + 16|0);
 HEAPF32[$226>>2] = $221;
 $227 = (($this) + 20|0);
 HEAPF32[$227>>2] = $223;
 $228 = (($this) + 24|0);
 HEAPF32[$228>>2] = $225;
 $229 = HEAP32[$12>>2]|0;
 $230 = HEAP32[$229>>2]|0;
 $231 = (($230) + 88|0);
 $232 = HEAP32[$231>>2]|0;
 $233 = (($219) + 188|0);
 FUNCTION_TABLE_vii[$232 & 4095]($229,$233);
 $234 = HEAP32[$12>>2]|0;
 $235 = HEAP32[$234>>2]|0;
 $236 = (($235) + 224|0);
 $237 = HEAP32[$236>>2]|0;
 $238 = HEAP32[$8>>2]|0;
 $239 = (($238) + 200|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 FUNCTION_TABLE_vif[$237 & 255]($234,$240);
 $241 = HEAP32[$12>>2]|0;
 $242 = HEAP32[$241>>2]|0;
 $243 = (($242) + 220|0);
 $244 = HEAP32[$243>>2]|0;
 $245 = HEAP32[$8>>2]|0;
 $246 = (($245) + 204|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 FUNCTION_TABLE_vif[$244 & 255]($241,$247);
 $248 = HEAP32[$12>>2]|0;
 $249 = HEAP32[$248>>2]|0;
 $250 = (($249) + 96|0);
 $251 = HEAP32[$250>>2]|0;
 $252 = HEAP32[$8>>2]|0;
 $253 = (($252) + 208|0);
 FUNCTION_TABLE_vii[$251 & 4095]($248,$253);
 $254 = HEAP32[$12>>2]|0;
 $255 = HEAP32[$254>>2]|0;
 $256 = (($255) + 104|0);
 $257 = HEAP32[$256>>2]|0;
 $258 = HEAP32[$8>>2]|0;
 $259 = (($258) + 220|0);
 FUNCTION_TABLE_vii[$257 & 4095]($254,$259);
 $260 = HEAP32[$12>>2]|0;
 $261 = HEAP32[$260>>2]|0;
 $262 = (($261) + 112|0);
 $263 = HEAP32[$262>>2]|0;
 $264 = HEAP32[$8>>2]|0;
 $265 = (($264) + 232|0);
 FUNCTION_TABLE_vii[$263 & 4095]($260,$265);
 $266 = HEAP32[$12>>2]|0;
 $267 = HEAP32[$266>>2]|0;
 $268 = (($267) + 120|0);
 $269 = HEAP32[$268>>2]|0;
 $270 = HEAP32[$8>>2]|0;
 $271 = (($270) + 244|0);
 FUNCTION_TABLE_vii[$269 & 4095]($266,$271);
 $272 = HEAP32[$12>>2]|0;
 $273 = HEAP32[$272>>2]|0;
 $274 = (($273) + 128|0);
 $275 = HEAP32[$274>>2]|0;
 $276 = HEAP32[$8>>2]|0;
 $277 = (($276) + 256|0);
 FUNCTION_TABLE_vii[$275 & 4095]($272,$277);
 $278 = HEAP32[$12>>2]|0;
 $279 = HEAP32[$278>>2]|0;
 $280 = (($279) + 136|0);
 $281 = HEAP32[$280>>2]|0;
 $282 = HEAP32[$8>>2]|0;
 $283 = (($282) + 268|0);
 $284 = Math_fround(HEAPF32[$283>>2]);
 FUNCTION_TABLE_vif[$281 & 255]($278,$284);
 $285 = HEAP32[$12>>2]|0;
 $286 = HEAP32[$285>>2]|0;
 $287 = (($286) + 144|0);
 $288 = HEAP32[$287>>2]|0;
 $289 = HEAP32[$8>>2]|0;
 $290 = (($289) + 272|0);
 $291 = Math_fround(HEAPF32[$290>>2]);
 FUNCTION_TABLE_vif[$288 & 255]($285,$291);
 $292 = HEAP32[$12>>2]|0;
 $293 = HEAP32[$292>>2]|0;
 $294 = (($293) + 320|0);
 $295 = HEAP32[$294>>2]|0;
 $296 = HEAP32[$8>>2]|0;
 $297 = (($296) + 276|0);
 $298 = Math_fround(HEAPF32[$297>>2]);
 FUNCTION_TABLE_vif[$295 & 255]($292,$298);
 $299 = HEAP32[$12>>2]|0;
 $300 = HEAP32[$299>>2]|0;
 $301 = (($300) + 328|0);
 $302 = HEAP32[$301>>2]|0;
 $303 = HEAP32[$8>>2]|0;
 $304 = (($303) + 280|0);
 $305 = Math_fround(HEAPF32[$304>>2]);
 FUNCTION_TABLE_vif[$302 & 255]($299,$305);
 $306 = HEAP32[$12>>2]|0;
 $307 = HEAP32[$306>>2]|0;
 $308 = (($307) + 360|0);
 $309 = HEAP32[$308>>2]|0;
 $310 = HEAP32[$8>>2]|0;
 $311 = (($310) + 312|0);
 $312 = Math_fround(HEAPF32[$311>>2]);
 FUNCTION_TABLE_vif[$309 & 255]($306,$312);
 $313 = HEAP32[$8>>2]|0;
 $314 = (($313) + 316|0);
 $315 = Math_fround(HEAPF32[$314>>2]);
 $316 = $315 > Math_fround(4294967.0);
 if ($316) {
  $317 = HEAP32[$12>>2]|0;
  $318 = HEAP32[$317>>2]|0;
  $319 = (($318) + 368|0);
  $320 = HEAP32[$319>>2]|0;
  FUNCTION_TABLE_vii[$320 & 4095]($317,-1);
  HEAP32[$8>>2] = 0;
  STACKTOP = sp;return;
 }
 $321 = Math_fround($315 * Math_fround(1000.0));
 $322 = (~~(($321))>>>0);
 $323 = (($322>>>0) / 5)&-1;
 $324 = ($323>>>0)<(200);
 $325 = $324 ? $323 : 200;
 $326 = ($325>>>0)>(1);
 $327 = $326 ? $325 : 1;
 $328 = (($322>>>0) / ($327>>>0))&-1;
 $329 = HEAP32[$12>>2]|0;
 $330 = HEAP32[$329>>2]|0;
 $331 = (($330) + 388|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = (FUNCTION_TABLE_ii[$332 & 4095]($329)|0);
 $334 = HEAP32[$12>>2]|0;
 $335 = HEAP32[$334>>2]|0;
 $336 = (($335) + 368|0);
 $337 = HEAP32[$336>>2]|0;
 FUNCTION_TABLE_vii[$337 & 4095]($334,$327);
 $338 = HEAP32[$12>>2]|0;
 $339 = HEAP32[$338>>2]|0;
 $340 = (($339) + 376|0);
 $341 = HEAP32[$340>>2]|0;
 FUNCTION_TABLE_vii[$341 & 4095]($338,$328);
 $342 = $315 == Math_fround(0.0);
 $or$cond$i = $333 & $342;
 if (!($or$cond$i)) {
  HEAP32[$8>>2] = 0;
  STACKTOP = sp;return;
 }
 $343 = HEAP32[$12>>2]|0;
 $344 = HEAP32[$343>>2]|0;
 $345 = (($344) + 392|0);
 $346 = HEAP32[$345>>2]|0;
 FUNCTION_TABLE_vi[$346 & 4095]($343);
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore19setVirtualParticlesEjPKjjPKNS_6PxVec3E($this,$numParticles,$indices,$numWeights,$weights) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indices = $indices|0;
 $numWeights = $numWeights|0;
 $weights = $weights|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $tmpcast$byval_copy = 0, $tmpcast2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast2$byval_copy = sp + 24|0;
 $tmpcast$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($indices) + ($numParticles<<4)|0);
 $3 = (($weights) + (($numWeights*12)|0)|0);
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 232|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $indices;
 $10 = $2;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $9;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = $weights;
 $16 = $3;
 $17 = $1;
 $18 = $17;
 HEAP32[$18>>2] = $15;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 FUNCTION_TABLE_viii[$8 & 4095]($5,$tmpcast$byval_copy,$tmpcast2$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore20setMotionConstraintsEPKNS_31PxClothParticleMotionConstraintE($this,$motionConstraints) {
 $this = $this|0;
 $motionConstraints = $motionConstraints|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $motionConstraintsRange = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $motionConstraintsRange = sp;
 $0 = ($motionConstraints|0)==(0|0);
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 if ($0) {
  $12 = HEAP32[$2>>2]|0;
  $13 = (($12) + 264|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 4095]($2);
  STACKTOP = sp;return;
 } else {
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 260|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($motionConstraintsRange,$2);
  $6 = HEAP32[$motionConstraintsRange>>2]|0;
  $7 = (($motionConstraintsRange) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8;
  $10 = $6;
  $11 = (($9) - ($10))|0;
  _memcpy(($6|0),($motionConstraints|0),($11|0))|0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc9ClothCore24setSeparationConstraintsEPKNS_35PxClothParticleSeparationConstraintE($this,$separationConstraints) {
 $this = $this|0;
 $separationConstraints = $separationConstraints|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $separationConstraintsRange = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $separationConstraintsRange = sp;
 $0 = ($separationConstraints|0)==(0|0);
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 if ($0) {
  $12 = HEAP32[$2>>2]|0;
  $13 = (($12) + 296|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 4095]($2);
  STACKTOP = sp;return;
 } else {
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 292|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($separationConstraintsRange,$2);
  $6 = HEAP32[$separationConstraintsRange>>2]|0;
  $7 = (($separationConstraintsRange) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8;
  $10 = $6;
  $11 = (($9) - ($10))|0;
  _memcpy(($6|0),($separationConstraints|0),($11|0))|0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc9ClothCore24setParticleAccelerationsEPKNS_6PxVec4E($this,$particleAccelerations) {
 $this = $this|0;
 $particleAccelerations = $particleAccelerations|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $accelerationsRange = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $accelerationsRange = sp;
 $0 = ($particleAccelerations|0)==(0|0);
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 if ($0) {
  $12 = HEAP32[$2>>2]|0;
  $13 = (($12) + 312|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 4095]($2);
  STACKTOP = sp;return;
 } else {
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 308|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($accelerationsRange,$2);
  $6 = HEAP32[$accelerationsRange>>2]|0;
  $7 = (($accelerationsRange) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8;
  $10 = $6;
  $11 = (($9) - ($10))|0;
  _memcpy(($6|0),($particleAccelerations|0),($11|0))|0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sc9ClothCore23setSelfCollisionIndicesEPKjj($this,$indices,$nbIndices) {
 $this = $this|0;
 $indices = $indices|0;
 $nbIndices = $nbIndices|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 336|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($indices) + ($nbIndices<<2)|0);
 HEAP32[$0>>2] = $indices;
 $7 = (($0) + 4|0);
 HEAP32[$7>>2] = $6;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($2,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore16setRestPositionsEPKNS_6PxVec4E($this,$restPositions) {
 $this = $this|0;
 $restPositions = $restPositions|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = ($restPositions|0)==(0|0);
 $$pre = (($this) + 28|0);
 if ($1) {
  $12 = 0;
 } else {
  $2 = HEAP32[$$pre>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
  $12 = $6;
 }
 $7 = HEAP32[$$pre>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 344|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($restPositions) + ($12<<4)|0);
 HEAP32[$0>>2] = $restPositions;
 $13 = (($0) + 4|0);
 HEAP32[$13>>2] = $11;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$10 & 4095]($7,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore23setExternalAccelerationENS_6PxVec3E($this,$acceleration) {
 $this = $this|0;
 $acceleration = $acceleration|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$acceleration>>2]);
 $1 = (($this) + 16|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($acceleration) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 20|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($acceleration) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 24|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore14setWakeCounterEf($this,$wakeCounterValue) {
 $this = $this|0;
 $wakeCounterValue = Math_fround($wakeCounterValue);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wakeCounterValue > Math_fround(4294967.0);
 if ($0) {
  $1 = (($this) + 28|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 368|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($2,-1);
  STACKTOP = sp;return;
 }
 $6 = Math_fround($wakeCounterValue * Math_fround(1000.0));
 $7 = (~~(($6))>>>0);
 $8 = (($7>>>0) / 5)&-1;
 $9 = ($8>>>0)<(200);
 $10 = $9 ? $8 : 200;
 $11 = ($10>>>0)>(1);
 $12 = $11 ? $10 : 1;
 $13 = (($7>>>0) / ($12>>>0))&-1;
 $14 = (($this) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 388|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
 $20 = HEAP32[$14>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 368|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vii[$23 & 4095]($20,$12);
 $24 = HEAP32[$14>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 376|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vii[$27 & 4095]($24,$13);
 $28 = $wakeCounterValue == Math_fround(0.0);
 $or$cond = $19 & $28;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$14>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 392|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vi[$32 & 4095]($29);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ClothBulkData15exportExtraDataERNS_22PxSerializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if (!($1)) {
   $2 = (($this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0);
   $5 = (($this) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   if ($4) {
    $7 = $6 & 2147483647;
    $8 = ($7|0)==(0);
    if ($8) {
     break;
    }
   }
   $9 = HEAP32[$context>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $6 << 4;
   FUNCTION_TABLE_viii[$11 & 4095]($context,$0,$12);
  }
 } while(0);
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if (!($15)) {
   $16 = (($this) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0);
   $19 = (($this) + 20|0);
   $20 = HEAP32[$19>>2]|0;
   if ($18) {
    $21 = $20 & 2147483647;
    $22 = ($21|0)==(0);
    if ($22) {
     break;
    }
   }
   $23 = HEAP32[$context>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $20 << 2;
   FUNCTION_TABLE_viii[$25 & 4095]($context,$14,$26);
  }
 } while(0);
 $27 = (($this) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = (($this) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($this) + 32|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 & 2147483647;
  $35 = $34 | $31;
  $36 = ($35|0)==(0);
  if (!($36)) {
   $37 = HEAP32[$context>>2]|0;
   $38 = (($37) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($34*12)|0;
   FUNCTION_TABLE_viii[$39 & 4095]($context,$28,$40);
  }
 }
 $41 = (($this) + 36|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 do {
  if (!($43)) {
   $44 = (($this) + 40|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0);
   $47 = (($this) + 44|0);
   $48 = HEAP32[$47>>2]|0;
   if ($46) {
    $49 = $48 & 2147483647;
    $50 = ($49|0)==(0);
    if ($50) {
     break;
    }
   }
   $51 = HEAP32[$context>>2]|0;
   $52 = (($51) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $48 << 4;
   FUNCTION_TABLE_viii[$53 & 4095]($context,$42,$54);
  }
 } while(0);
 $55 = (($this) + 48|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0|0);
 do {
  if (!($57)) {
   $58 = (($this) + 52|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0);
   $61 = (($this) + 56|0);
   $62 = HEAP32[$61>>2]|0;
   if ($60) {
    $63 = $62 & 2147483647;
    $64 = ($63|0)==(0);
    if ($64) {
     break;
    }
   }
   $65 = HEAP32[$context>>2]|0;
   $66 = (($65) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = $62 << 2;
   FUNCTION_TABLE_viii[$67 & 4095]($context,$56,$68);
  }
 } while(0);
 $69 = (($this) + 60|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(0|0);
 do {
  if (!($71)) {
   $72 = (($this) + 64|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   $75 = (($this) + 68|0);
   $76 = HEAP32[$75>>2]|0;
   if ($74) {
    $77 = $76 & 2147483647;
    $78 = ($77|0)==(0);
    if ($78) {
     break;
    }
   }
   $79 = HEAP32[$context>>2]|0;
   $80 = (($79) + 8|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = $76 << 4;
   FUNCTION_TABLE_viii[$81 & 4095]($context,$70,$82);
  }
 } while(0);
 $83 = (($this) + 72|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(0|0);
 do {
  if (!($85)) {
   $86 = (($this) + 76|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)==(0);
   $89 = (($this) + 80|0);
   $90 = HEAP32[$89>>2]|0;
   if ($88) {
    $91 = $90 & 2147483647;
    $92 = ($91|0)==(0);
    if ($92) {
     break;
    }
   }
   $93 = HEAP32[$context>>2]|0;
   $94 = (($93) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = $90 << 2;
   FUNCTION_TABLE_viii[$95 & 4095]($context,$84,$96);
  }
 } while(0);
 $97 = (($this) + 84|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = ($98|0)==(0|0);
 if (!($99)) {
  $100 = (($this) + 88|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (($this) + 92|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = $103 & 2147483647;
  $105 = $104 | $101;
  $106 = ($105|0)==(0);
  if (!($106)) {
   $107 = HEAP32[$context>>2]|0;
   $108 = (($107) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ($104*36)|0;
   FUNCTION_TABLE_viii[$109 & 4095]($context,$98,$110);
  }
 }
 $111 = (($this) + 96|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ($112|0)==(0|0);
 do {
  if (!($113)) {
   $114 = (($this) + 100|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ($115|0)==(0);
   $117 = (($this) + 104|0);
   $118 = HEAP32[$117>>2]|0;
   if ($116) {
    $119 = $118 & 2147483647;
    $120 = ($119|0)==(0);
    if ($120) {
     break;
    }
   }
   $121 = HEAP32[$context>>2]|0;
   $122 = (($121) + 8|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = $118 << 4;
   FUNCTION_TABLE_viii[$123 & 4095]($context,$112,$124);
  }
 } while(0);
 $125 = (($this) + 108|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($126|0)==(0|0);
 do {
  if (!($127)) {
   $128 = (($this) + 112|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0);
   $131 = (($this) + 116|0);
   $132 = HEAP32[$131>>2]|0;
   if ($130) {
    $133 = $132 & 2147483647;
    $134 = ($133|0)==(0);
    if ($134) {
     break;
    }
   }
   $135 = HEAP32[$context>>2]|0;
   $136 = (($135) + 8|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = $132 << 4;
   FUNCTION_TABLE_viii[$137 & 4095]($context,$126,$138);
  }
 } while(0);
 $139 = (($this) + 120|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = ($140|0)==(0|0);
 do {
  if (!($141)) {
   $142 = (($this) + 124|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = ($143|0)==(0);
   $145 = (($this) + 128|0);
   $146 = HEAP32[$145>>2]|0;
   if ($144) {
    $147 = $146 & 2147483647;
    $148 = ($147|0)==(0);
    if ($148) {
     break;
    }
   }
   $149 = HEAP32[$context>>2]|0;
   $150 = (($149) + 8|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = $146 << 4;
   FUNCTION_TABLE_viii[$151 & 4095]($context,$140,$152);
  }
 } while(0);
 $153 = (($this) + 144|0);
 $154 = HEAP32[$153>>2]|0;
 $155 = ($154|0)==(0|0);
 if ($155) {
  STACKTOP = sp;return;
 }
 $156 = (($this) + 148|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = ($157|0)==(0);
 $159 = (($this) + 152|0);
 $160 = HEAP32[$159>>2]|0;
 if ($158) {
  $161 = $160 & 2147483647;
  $162 = ($161|0)==(0);
  if ($162) {
   STACKTOP = sp;return;
  }
 }
 $163 = HEAP32[$context>>2]|0;
 $164 = (($163) + 8|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = $160 << 4;
 FUNCTION_TABLE_viii[$165 & 4095]($context,$154,$166);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 475240 : 475208;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,320,$$$i$i$i,475112,362)|0);
 _memset(($10|0),0,156)|0;
 __ZN5physx2Sc9ClothCore14updateBulkDataERNS0_13ClothBulkDataE($this,$10);
 $11 = HEAP32[$stream>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viii[$13 & 4095]($stream,$10,320);
 __ZN5physx2Sc13ClothBulkData15exportExtraDataERNS_22PxSerializationContextE($10,$stream);
 $14 = ($10|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc13ClothBulkDataD2Ev($10);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$10);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore12setParticlesEPKNS_15PxClothParticleES4_($this,$currentParticles,$previousParticles) {
 $this = $this|0;
 $currentParticles = $currentParticles|0;
 $previousParticles = $previousParticles|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $particlesRange = 0, $particlesRange1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $particlesRange = sp + 28|0;
 $particlesRange1 = sp;
 $0 = ($currentParticles|0)==(0|0);
 if (!($0)) {
  $1 = (($this) + 28|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($particlesRange,$2);
  $6 = HEAP32[$particlesRange>>2]|0;
  $7 = ($6|0)==($currentParticles|0);
  if (!($7)) {
   $8 = (($particlesRange) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9;
   $11 = $6;
   $12 = (($10) - ($11))|0;
   _memcpy(($6|0),($currentParticles|0),($12|0))|0;
  }
  $13 = (($particlesRange) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($particlesRange) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($particlesRange) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $16 >> 1;
  $20 = (($18) + ($19)|0);
  $21 = $16 & 1;
  $22 = ($21|0)==(0);
  if ($22) {
   $26 = $14;
   $27 = $26;
  } else {
   $23 = HEAP32[$20>>2]|0;
   $24 = (($23) + ($14)|0);
   $25 = HEAP32[$24>>2]|0;
   $27 = $25;
  }
  FUNCTION_TABLE_vi[$27 & 4095]($20);
 }
 $28 = ($previousParticles|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($this) + 28|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 40|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vii[$33 & 4095]($particlesRange1,$30);
 $34 = HEAP32[$particlesRange1>>2]|0;
 $35 = ($34|0)==($previousParticles|0);
 if (!($35)) {
  $36 = (($particlesRange1) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = $37;
  $39 = $34;
  $40 = (($38) - ($39))|0;
  _memcpy(($34|0),($previousParticles|0),($40|0))|0;
 }
 $41 = (($particlesRange1) + 20|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($particlesRange1) + 24|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($particlesRange1) + 8|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $44 >> 1;
 $48 = (($46) + ($47)|0);
 $49 = $44 & 1;
 $50 = ($49|0)==(0);
 if ($50) {
  $54 = $42;
  $55 = $54;
 } else {
  $51 = HEAP32[$48>>2]|0;
  $52 = (($51) + ($42)|0);
  $53 = HEAP32[$52>>2]|0;
  $55 = $53;
 }
 FUNCTION_TABLE_vi[$55 & 4095]($48);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore22getNbMotionConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 268|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc9ClothCore25setMotionConstraintConfigERKNS_29PxClothMotionConstraintConfigE($this,$config) {
 $this = $this|0;
 $config = $config|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 272|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$config>>2]);
 $6 = (($config) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 FUNCTION_TABLE_viff[$4 & 31]($1,$5,$7);
 $8 = HEAP32[$0>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 284|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($config) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 FUNCTION_TABLE_vif[$11 & 255]($8,$13);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore25getMotionConstraintConfigEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 4|0);
 $1 = (($agg$result) + 8|0);
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 276|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (Math_fround(FUNCTION_TABLE_fi[$6 & 255]($3)));
 HEAPF32[$agg$result>>2] = $7;
 $8 = HEAP32[$2>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 280|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (Math_fround(FUNCTION_TABLE_fi[$11 & 255]($8)));
 HEAPF32[$0>>2] = $12;
 $13 = HEAP32[$2>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 288|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(FUNCTION_TABLE_fi[$16 & 255]($13)));
 HEAPF32[$1>>2] = $17;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore26getNbSeparationConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 300|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc9ClothCore18clearInterpolationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 304|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore26getNbParticleAccelerationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 316|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc9ClothCore18addCollisionSphereERKNS_22PxClothCollisionSphereE($this,$sphere) {
 $this = $this|0;
 $sphere = $sphere|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 164|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($sphere) + 16|0);
 HEAP32[$0>>2] = $sphere;
 $7 = (($0) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 72|0);
 $9 = HEAP32[$8>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511]($2,$$byval_copy,$9,$9);
 $10 = HEAP32[$8>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$8>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore21removeCollisionSphereEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 176|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 164|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = 0;
 $11 = (($0) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($index) + 1)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$10 & 511]($7,$$byval_copy,$index,$12);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 176|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
 $18 = (($this) + 76|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) - ($6))|0;
 $21 = (($20) + ($19))|0;
 HEAP32[$18>>2] = $21;
 $22 = (($this) + 72|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + -1)|0;
 HEAP32[$22>>2] = $24;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore19setCollisionSpheresEPKNS_22PxClothCollisionSphereEj($this,$spheresBuffer,$count) {
 $this = $this|0;
 $spheresBuffer = $spheresBuffer|0;
 $count = $count|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 176|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 164|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($spheresBuffer) + ($count<<4)|0);
 HEAP32[$0>>2] = $spheresBuffer;
 $12 = (($0) + 4|0);
 HEAP32[$12>>2] = $11;
 $13 = (($this) + 72|0);
 $14 = HEAP32[$13>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$10 & 511]($7,$$byval_copy,0,$14);
 $15 = HEAP32[$1>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 176|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
 $20 = (($this) + 76|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) - ($6))|0;
 $23 = (($22) + ($21))|0;
 HEAP32[$20>>2] = $23;
 HEAP32[$13>>2] = $count;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore19addCollisionCapsuleEjj($this,$first,$second) {
 $this = $this|0;
 $first = $first|0;
 $second = $second|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $indices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $indices = sp;
 $0 = sp + 8|0;
 HEAP32[$indices>>2] = $first;
 $1 = (($indices) + 4|0);
 HEAP32[$1>>2] = $second;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 172|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($indices) + 8|0);
 HEAP32[$0>>2] = $indices;
 $8 = (($0) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = (($this) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$6 & 511]($3,$$byval_copy,$10,$10);
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11) + 1)|0;
 HEAP32[$9>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore22removeCollisionCapsuleEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 172|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = 0;
 $6 = (($0) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($index) + 1)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511]($2,$$byval_copy,$index,$7);
 $8 = (($this) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + -1)|0;
 HEAP32[$8>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore20addCollisionTriangleERKNS_24PxClothCollisionTriangleE($this,$triangle) {
 $this = $this|0;
 $triangle = $triangle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($triangle) + 36|0);
 HEAP32[$0>>2] = $triangle;
 $7 = (($0) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511]($2,$$byval_copy,$9,$9);
 $10 = HEAP32[$8>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$8>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore23removeCollisionTriangleEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = 0;
 $6 = (($0) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($index) + 1)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511]($2,$$byval_copy,$index,$7);
 $8 = (($this) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + -1)|0;
 HEAP32[$8>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore21setCollisionTrianglesEPKNS_24PxClothCollisionTriangleEj($this,$trianglesBuffer,$count) {
 $this = $this|0;
 $trianglesBuffer = $trianglesBuffer|0;
 $count = $count|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($trianglesBuffer) + (($count*36)|0)|0);
 HEAP32[$0>>2] = $trianglesBuffer;
 $7 = (($0) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511]($2,$$byval_copy,0,$9);
 HEAP32[$8>>2] = $count;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore17addCollisionPlaneERKNS_21PxClothCollisionPlaneE($this,$plane) {
 $this = $this|0;
 $plane = $plane|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 180|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($plane) + 16|0);
 HEAP32[$0>>2] = $plane;
 $7 = (($0) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511]($2,$$byval_copy,$9,$9);
 $10 = HEAP32[$8>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$8>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore20removeCollisionPlaneEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 192|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 180|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = 0;
 $11 = (($0) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($index) + 1)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$10 & 511]($7,$$byval_copy,$index,$12);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 192|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
 $18 = (($this) + 84|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) - ($6))|0;
 $21 = (($20) + ($19))|0;
 HEAP32[$18>>2] = $21;
 $22 = (($this) + 80|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + -1)|0;
 HEAP32[$22>>2] = $24;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore18setCollisionPlanesEPKNS_21PxClothCollisionPlaneEj($this,$planesBuffer,$count) {
 $this = $this|0;
 $planesBuffer = $planesBuffer|0;
 $count = $count|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 192|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 180|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($planesBuffer) + ($count<<4)|0);
 HEAP32[$0>>2] = $planesBuffer;
 $12 = (($0) + 4|0);
 HEAP32[$12>>2] = $11;
 $13 = (($this) + 80|0);
 $14 = HEAP32[$13>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$10 & 511]($7,$$byval_copy,0,$14);
 $15 = HEAP32[$1>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 192|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
 $20 = (($this) + 84|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) - ($6))|0;
 $23 = (($22) + ($21))|0;
 HEAP32[$20>>2] = $23;
 HEAP32[$13>>2] = $count;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore18addCollisionConvexEj($this,$mask) {
 $this = $this|0;
 $mask = $mask|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 HEAP32[$0>>2] = $mask;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 188|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + 4|0);
 HEAP32[$1>>2] = $0;
 $8 = (($1) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = (($this) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 FUNCTION_TABLE_viiii[$6 & 511]($3,$$byval_copy,$10,$10);
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11) + 1)|0;
 HEAP32[$9>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore21removeCollisionConvexEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 188|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = 0;
 $6 = (($0) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($index) + 1)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511]($2,$$byval_copy,$index,$7);
 $8 = (($this) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + -1)|0;
 HEAP32[$8>>2] = $10;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore21getLinearInertiaScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($agg$result,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore21setLinearInertiaScaleENS_6PxVec3E($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$scale);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore22getAngularInertiaScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($agg$result,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore22setAngularInertiaScaleENS_6PxVec3E($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$scale);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore26getCentrifugalInertiaScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 132|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($agg$result,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore26setCentrifugalInertiaScaleENS_6PxVec3E($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$scale);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore13setTargetPoseERKNS_11PxTransformE($this,$pose) {
 $this = $this|0;
 $pose = $pose|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($pose) + 16|0);
 FUNCTION_TABLE_vii[$4 & 4095]($1,$5);
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($6,$pose);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore21setDampingCoefficientENS_6PxVec3E($this,$dampingCoefficient) {
 $this = $this|0;
 $dampingCoefficient = $dampingCoefficient|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$dampingCoefficient);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore21getDampingCoefficientEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($agg$result,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore22setFrictionCoefficientEf($this,$frictionCoefficient) {
 $this = $this|0;
 $frictionCoefficient = Math_fround($frictionCoefficient);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 224|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vif[$4 & 255]($1,$frictionCoefficient);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore22getFrictionCoefficientEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 228|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc9ClothCore24setLinearDragCoefficientENS_6PxVec3E($this,$dragCoefficient) {
 $this = $this|0;
 $dragCoefficient = $dragCoefficient|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$dragCoefficient);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore24getLinearDragCoefficientEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($agg$result,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore25setAngularDragCoefficientENS_6PxVec3E($this,$dragCoefficient) {
 $this = $this|0;
 $dragCoefficient = $dragCoefficient|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$dragCoefficient);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore25getAngularDragCoefficientEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($agg$result,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore21setCollisionMassScaleEf($this,$scalingCoefficient) {
 $this = $this|0;
 $scalingCoefficient = Math_fround($scalingCoefficient);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 220|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vif[$4 & 255]($1,$scalingCoefficient);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore21getCollisionMassScaleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 216|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc9ClothCore24setSelfCollisionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vif[$4 & 255]($1,$distance);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore24getSelfCollisionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 324|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc9ClothCore25setSelfCollisionStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 328|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vif[$4 & 255]($1,$stiffness);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore25getSelfCollisionStiffnessEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 332|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZNK5physx2Sc9ClothCore25getNbSelfCollisionIndicesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 340|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc9ClothCore18getNbRestPositionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 348|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Sc9ClothCore18setSolverFrequencyEf($this,$solverFreq) {
 $this = $this|0;
 $solverFreq = Math_fround($solverFreq);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vif[$4 & 255]($1,$solverFreq);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore18getSolverFrequencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc9ClothCore21setStiffnessFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 144|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vif[$4 & 255]($1,$frequency);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore21getStiffnessFrequencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc9ClothCore16setStretchConfigENS_22PxClothFabricPhaseType4EnumERKNS_20PxClothStretchConfigE($this,$type,$config) {
 $this = $this|0;
 $type = $type|0;
 $config = $config|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $pc = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 32|0;
 $pc = sp + 8|0;
 $0 = sp;
 __ZN5physx5cloth11PhaseConfigC2Et($pc,-1);
 $1 = Math_fround(HEAPF32[$config>>2]);
 $2 = (($pc) + 4|0);
 HEAPF32[$2>>2] = $1;
 $3 = (($config) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pc) + 8|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($config) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($pc) + 16|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($config) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($pc) + 12|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($this) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZNK5physx2Sc15ClothFabricCore11getNbPhasesEv($13)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  $$pre = (($this) + 40|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $16 = HEAP32[$12>>2]|0;
  $17 = (($16) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($this) + 40|0);
  $i$02 = 0;
  while(1) {
   $20 = (($18) + ($i$02<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==($type|0);
   if ($22) {
    $23 = Math_fround(HEAPF32[$config>>2]);
    $24 = HEAP32[$19>>2]|0;
    $25 = ((($24) + (($i$02*20)|0)|0) + 4|0);
    HEAPF32[$25>>2] = $23;
    $26 = Math_fround(HEAPF32[$3>>2]);
    $27 = ((($24) + (($i$02*20)|0)|0) + 8|0);
    HEAPF32[$27>>2] = $26;
    $28 = Math_fround(HEAPF32[$9>>2]);
    $29 = ((($24) + (($i$02*20)|0)|0) + 12|0);
    HEAPF32[$29>>2] = $28;
    $30 = Math_fround(HEAPF32[$6>>2]);
    $31 = ((($24) + (($i$02*20)|0)|0) + 16|0);
    HEAPF32[$31>>2] = $30;
   }
   $32 = (($i$02) + 1)|0;
   $exitcond = ($32|0)==($14|0);
   if ($exitcond) {
    $$pre$phiZ2D = $19;
    break;
   } else {
    $i$02 = $32;
   }
  }
 }
 $33 = HEAP32[$$pre$phiZ2D>>2]|0;
 $34 = (($33) + (($14*20)|0)|0);
 $35 = (($this) + 28|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 160|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $33;
 $41 = $34;
 $42 = $0;
 $43 = $42;
 HEAP32[$43>>2] = $40;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$39 & 4095]($36,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore15setTetherConfigERKNS_19PxClothTetherConfigE($this,$config) {
 $this = $this|0;
 $config = $config|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 244|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($config) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 FUNCTION_TABLE_vif[$4 & 255]($1,$6);
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 252|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_fround(HEAPF32[$config>>2]);
 FUNCTION_TABLE_vif[$10 & 255]($7,$11);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore16getStretchConfigENS_22PxClothFabricPhaseType4EnumE($agg$result,$this,$type) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $pc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pc = sp;
 __ZN5physx5cloth11PhaseConfigC2Et($pc,-1);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Sc15ClothFabricCore11getNbPhasesEv($1)|0);
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = HEAP32[$0>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $i$02 = 0;
   while(1) {
    $9 = (($6) + ($i$02<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($type|0);
    $8 = (($i$02) + 1)|0;
    if ($11) {
     break;
    }
    $7 = ($8>>>0)<($2>>>0);
    if ($7) {
     $i$02 = $8;
    } else {
     break L1;
    }
   }
   $12 = (($this) + 40|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + (($i$02*20)|0)|0);
   ;HEAP32[$pc+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$pc+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$pc+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$pc+12>>2]=HEAP32[$14+12>>2]|0;HEAP32[$pc+16>>2]=HEAP32[$14+16>>2]|0;
  }
 } while(0);
 $15 = (($pc) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($pc) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($pc) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($pc) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$agg$result>>2] = $16;
 $23 = (($agg$result) + 4|0);
 HEAPF32[$23>>2] = $18;
 $24 = (($agg$result) + 8|0);
 HEAPF32[$24>>2] = $20;
 $25 = (($agg$result) + 12|0);
 HEAPF32[$25>>2] = $22;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore15getTetherConfigEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 256|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 248|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (Math_fround(FUNCTION_TABLE_fi[$9 & 255]($6)));
 HEAPF32[$agg$result>>2] = $5;
 $11 = (($agg$result) + 4|0);
 HEAPF32[$11>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore12setClothFlagENS_11PxClothFlag4EnumEb($this,$flag,$val) {
 $this = $this|0;
 $flag = $flag|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 if ($val) {
  $1 = HEAP16[$0>>1]|0;
  $2 = $1&65535;
  $3 = $2 | $flag;
  $4 = $3&65535;
  HEAP16[$0>>1] = $4;
 } else {
  $5 = $flag ^ 65535;
  $6 = $5&65535;
  $7 = HEAP16[$0>>1]|0;
  $8 = $7 & $6;
  HEAP16[$0>>1] = $8;
 }
 if ((($flag|0) == 1)) {
  $14 = (($this) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   STACKTOP = sp;return;
  }
  $17 = (($this) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 16|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 4095]($18)|0);
  $23 = (($22) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)!=(0);
  $26 = $25 ^ $val;
  if (!($26)) {
   STACKTOP = sp;return;
  }
  $27 = HEAP32[$14>>2]|0;
  __ZN5physx2Sc8ClothSim8reinsertEv($27);
  STACKTOP = sp;return;
 } else if ((($flag|0) == 2)) {
  $9 = (($this) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 212|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($10,$val);
  STACKTOP = sp;return;
 } else if ((($flag|0) == 4)) {
  if ($val) {
   STACKTOP = sp;return;
  }
  $28 = (($this) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   STACKTOP = sp;return;
  }
  __ZN5physx2Sc8ClothSim20clearCollisionShapesEv($29);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Sc9ClothCore13getClothFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP16[$0>>1]|0;
 HEAP16[$agg$result>>1] = $1;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore10isSleepingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 388|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Sc9ClothCore22getSleepLinearVelocityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 364|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx2Sc9ClothCore22setSleepLinearVelocityEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 360|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vif[$4 & 255]($1,$threshold);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore10putToSleepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 392|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore15getParticleDataERNS_19PxClothParticleDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $particles = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 68|0;
 $particles = sp;
 $1 = sp + 12|0;
 $2 = sp + 40|0;
 $3 = HEAP32[$data>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($0,$data);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 4;
 $7 = ($6<<24>>24)==(0);
 $8 = (($this) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 if (!($7)) {
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 48|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 4095]($particles,$9);
  $13 = HEAP32[$particles>>2]|0;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $13;
  $15 = (($particles) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($data) + 8|0);
  HEAP32[$17>>2] = $16;
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$9>>2]|0;
 $19 = (($18) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vi[$20 & 4095]($9);
 $21 = HEAP32[$8>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_vii[$24 & 4095]($1,$21);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($data) + 4|0);
 HEAP32[$26>>2] = $25;
 $27 = (($1) + 20|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($1) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($1) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $30 >> 1;
 $34 = (($32) + ($33)|0);
 $35 = $30 & 1;
 $36 = ($35|0)==(0);
 if ($36) {
  $40 = $28;
  $41 = $40;
 } else {
  $37 = HEAP32[$34>>2]|0;
  $38 = (($37) + ($28)|0);
  $39 = HEAP32[$38>>2]|0;
  $41 = $39;
 }
 FUNCTION_TABLE_vi[$41 & 4095]($34);
 $42 = HEAP32[$8>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 44|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($2,$42);
 $46 = HEAP32[$2>>2]|0;
 $47 = (($data) + 8|0);
 HEAP32[$47>>2] = $46;
 $48 = (($2) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($2) + 24|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($2) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = $51 >> 1;
 $55 = (($53) + ($54)|0);
 $56 = $51 & 1;
 $57 = ($56|0)==(0);
 if ($57) {
  $61 = $49;
  $62 = $61;
 } else {
  $58 = HEAP32[$55>>2]|0;
  $59 = (($58) + ($49)|0);
  $60 = HEAP32[$59>>2]|0;
  $62 = $60;
 }
 FUNCTION_TABLE_vi[$62 & 4095]($55);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore18unlockParticleDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore19getPreviousTimeStepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZNK5physx2Sc9ClothCore14getWorldBoundsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $7 = 0, $8 = 0;
 var $9 = 0, $localBounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $localBounds = sp + 32|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 352|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 356|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $12 = Math_fround(HEAPF32[$6>>2]);
 $13 = Math_fround(HEAPF32[$11>>2]);
 $14 = Math_fround($12 - $13);
 $15 = (($6) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($11) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = (($6) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($11) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 $25 = Math_fround($12 + $13);
 $26 = Math_fround($16 + $18);
 $27 = Math_fround($21 + $23);
 HEAPF32[$localBounds>>2] = $14;
 $28 = (($localBounds) + 4|0);
 HEAPF32[$28>>2] = $19;
 $29 = (($localBounds) + 8|0);
 HEAPF32[$29>>2] = $24;
 $30 = (($localBounds) + 12|0);
 HEAPF32[$30>>2] = $25;
 $31 = (($localBounds) + 16|0);
 HEAPF32[$31>>2] = $26;
 $32 = (($localBounds) + 20|0);
 HEAPF32[$32>>2] = $27;
 $33 = HEAP32[$1>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 60|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (FUNCTION_TABLE_ii[$36 & 4095]($33)|0);
 $38 = HEAP32[$1>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 64|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (FUNCTION_TABLE_ii[$41 & 4095]($38)|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$0>>2] = $43;
 $44 = (($0) + 4|0);
 $45 = (($42) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 HEAPF32[$44>>2] = $46;
 $47 = (($0) + 8|0);
 $48 = (($42) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$47>>2] = $49;
 $50 = (($0) + 12|0);
 $51 = (($42) + 12|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 HEAPF32[$50>>2] = $52;
 $53 = (($0) + 16|0);
 $54 = Math_fround(HEAPF32[$37>>2]);
 HEAPF32[$53>>2] = $54;
 $55 = (($0) + 20|0);
 $56 = (($37) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 HEAPF32[$55>>2] = $57;
 $58 = (($0) + 24|0);
 $59 = (($37) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 HEAPF32[$58>>2] = $60;
 __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($agg$result,$0,$localBounds);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore23setSimulationFilterDataERKNS_12PxFilterDataE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 ;HEAP32[$0+0>>2]=HEAP32[$data+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$data+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$data+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$data+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore16setContactOffsetEf($this,$offset) {
 $this = $this|0;
 $offset = Math_fround($offset);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 HEAPF32[$0>>2] = $offset;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore16getContactOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc9ClothCore13setRestOffsetEf($this,$offset) {
 $this = $this|0;
 $offset = Math_fround($offset);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 HEAPF32[$0>>2] = $offset;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc9ClothCore13getRestOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx2Sc9ClothCore13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_fround(HEAPF32[$shift>>2]);
 $7 = Math_fround(-$6);
 $8 = (($shift) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(-$9);
 $11 = (($shift) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(-$12);
 HEAPF32[$0>>2] = $7;
 $14 = (($0) + 4|0);
 HEAPF32[$14>>2] = $10;
 $15 = (($0) + 8|0);
 HEAPF32[$15>>2] = $13;
 FUNCTION_TABLE_vii[$5 & 4095]($2,$0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc9ClothCore11switchClothEPNS_5cloth5ClothE($this,$cl) {
 $this = $this|0;
 $cl = $cl|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$0>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = HEAP32[$13>>2]|0;
  $16 = (($15) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vi[$17 & 4095]($13);
 }
 HEAP32[$0>>2] = $cl;
 $18 = (($5) + 4|0);
 $19 = HEAP16[$18>>1]|0;
 $20 = ($19<<16>>16)==(0);
 if ($20) {
  $21 = ($12|0)==(0);
  if (!($21)) {
   $22 = (($this) + 32|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 4|0);
   HEAP32[$24>>2] = 0;
  }
  $25 = ($5|0)==(0|0);
  if (!($25)) {
   $26 = HEAP32[$5>>2]|0;
   $27 = (($26) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   FUNCTION_TABLE_vi[$28 & 4095]($5);
  }
 }
 $29 = HEAP32[$cl>>2]|0;
 $30 = (($29) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_ii[$31 & 4095]($cl)|0);
 $33 = (($32) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$cl>>2]|0;
 $39 = (($38) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (FUNCTION_TABLE_ii[$40 & 4095]($cl)|0);
 $42 = (($37) + 4|0);
 HEAP32[$42>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_35PxClothParticleSeparationConstraintENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 475448 : 475208;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,475368,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
   }
   $30 = (($$012$i) + 16|0);
   $31 = (($$03$i) + 16|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_31PxClothParticleMotionConstraintENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 475608 : 475208;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,475368,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
   }
   $30 = (($$012$i) + 16|0);
   $31 = (($$03$i) + 16|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_24PxClothCollisionTriangleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*36)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 475760 : 475208;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,475368,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*36)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
    $30 = (($$012$i) + 16|0);
    $31 = (($$03$i) + 16|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    HEAPF32[$30>>2] = $32;
    $33 = (($$012$i) + 20|0);
    $34 = (($$03$i) + 20|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    HEAPF32[$33>>2] = $35;
    $36 = (($$012$i) + 24|0);
    $37 = (($$03$i) + 24|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    HEAPF32[$36>>2] = $38;
    $39 = (($$012$i) + 28|0);
    $40 = (($$03$i) + 28|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    HEAPF32[$39>>2] = $41;
    $42 = (($$012$i) + 32|0);
    $43 = (($$03$i) + 32|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    HEAPF32[$42>>2] = $44;
   }
   $45 = (($$012$i) + 36|0);
   $46 = (($$03$i) + 36|0);
   $47 = ($45>>>0)<($15>>>0);
   if ($47) {
    $$012$i = $45;$$03$i = $46;
   } else {
    break;
   }
  }
 }
 $48 = (($this) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)>(-1);
 if (!($50)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$48>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $51 = HEAP32[$this>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  HEAP32[$this>>2] = $16;
  HEAP32[$48>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $53 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vii[$56 & 4095]($53,$51);
 HEAP32[$this>>2] = $16;
 HEAP32[$48>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_21PxClothCollisionPlaneENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 475896 : 475208;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,475368,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
   }
   $30 = (($$012$i) + 16|0);
   $31 = (($$03$i) + 16|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_22PxClothCollisionSphereENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 476032 : 475208;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,475368,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
   }
   $30 = (($$012$i) + 16|0);
   $31 = (($$03$i) + 16|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_15PxClothParticleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 476168 : 475208;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,475368,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
   }
   $30 = (($$012$i) + 16|0);
   $31 = (($$03$i) + 16|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc13ClothBulkDataD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i10 = 0, $or$cond$i$i12 = 0, $or$cond$i$i13 = 0;
 var $or$cond$i$i14 = 0, $or$cond$i$i16 = 0, $or$cond$i$i2 = 0, $or$cond$i$i4 = 0, $or$cond$i$i5 = 0, $or$cond$i$i6 = 0, $or$cond$i$i7 = 0, $or$cond$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 144|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 140|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i1 = $15 & $16;
 if ($or$cond$i$i1) {
  $17 = (($this) + 132|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 128|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i2 = $27 & $28;
 if ($or$cond$i$i2) {
  $29 = (($this) + 120|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
  }
 }
 $36 = (($this) + 116|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38|0)!=(0);
 $40 = ($37|0)>(-1);
 $or$cond$i$i4 = $39 & $40;
 if ($or$cond$i$i4) {
  $41 = (($this) + 108|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($44,$42);
  }
 }
 $48 = (($this) + 104|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49 & 2147483647;
 $51 = ($50|0)!=(0);
 $52 = ($49|0)>(-1);
 $or$cond$i$i5 = $51 & $52;
 if ($or$cond$i$i5) {
  $53 = (($this) + 96|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   FUNCTION_TABLE_vii[$59 & 4095]($56,$54);
  }
 }
 $60 = (($this) + 92|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = $61 & 2147483647;
 $63 = ($62|0)!=(0);
 $64 = ($61|0)>(-1);
 $or$cond$i$i6 = $63 & $64;
 if ($or$cond$i$i6) {
  $65 = (($this) + 84|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==(0|0);
  if (!($67)) {
   $68 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($69) + 12|0);
   $71 = HEAP32[$70>>2]|0;
   FUNCTION_TABLE_vii[$71 & 4095]($68,$66);
  }
 }
 $72 = (($this) + 80|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73 & 2147483647;
 $75 = ($74|0)!=(0);
 $76 = ($73|0)>(-1);
 $or$cond$i$i7 = $75 & $76;
 if ($or$cond$i$i7) {
  $77 = (($this) + 72|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0|0);
  if (!($79)) {
   $80 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($81) + 12|0);
   $83 = HEAP32[$82>>2]|0;
   FUNCTION_TABLE_vii[$83 & 4095]($80,$78);
  }
 }
 $84 = (($this) + 68|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = $85 & 2147483647;
 $87 = ($86|0)!=(0);
 $88 = ($85|0)>(-1);
 $or$cond$i$i9 = $87 & $88;
 if ($or$cond$i$i9) {
  $89 = (($this) + 60|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($90|0)==(0|0);
  if (!($91)) {
   $92 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + 12|0);
   $95 = HEAP32[$94>>2]|0;
   FUNCTION_TABLE_vii[$95 & 4095]($92,$90);
  }
 }
 $96 = (($this) + 56|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i10 = $99 & $100;
 if ($or$cond$i$i10) {
  $101 = (($this) + 48|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)==(0|0);
  if (!($103)) {
   $104 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + 12|0);
   $107 = HEAP32[$106>>2]|0;
   FUNCTION_TABLE_vii[$107 & 4095]($104,$102);
  }
 }
 $108 = (($this) + 44|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = $109 & 2147483647;
 $111 = ($110|0)!=(0);
 $112 = ($109|0)>(-1);
 $or$cond$i$i12 = $111 & $112;
 if ($or$cond$i$i12) {
  $113 = (($this) + 36|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = ($114|0)==(0|0);
  if (!($115)) {
   $116 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = (($117) + 12|0);
   $119 = HEAP32[$118>>2]|0;
   FUNCTION_TABLE_vii[$119 & 4095]($116,$114);
  }
 }
 $120 = (($this) + 32|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = $121 & 2147483647;
 $123 = ($122|0)!=(0);
 $124 = ($121|0)>(-1);
 $or$cond$i$i13 = $123 & $124;
 if ($or$cond$i$i13) {
  $125 = (($this) + 24|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ($126|0)==(0|0);
  if (!($127)) {
   $128 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = (($129) + 12|0);
   $131 = HEAP32[$130>>2]|0;
   FUNCTION_TABLE_vii[$131 & 4095]($128,$126);
  }
 }
 $132 = (($this) + 20|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = $133 & 2147483647;
 $135 = ($134|0)!=(0);
 $136 = ($133|0)>(-1);
 $or$cond$i$i14 = $135 & $136;
 if ($or$cond$i$i14) {
  $137 = (($this) + 12|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = ($138|0)==(0|0);
  if (!($139)) {
   $140 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = (($141) + 12|0);
   $143 = HEAP32[$142>>2]|0;
   FUNCTION_TABLE_vii[$143 & 4095]($140,$138);
  }
 }
 $144 = (($this) + 8|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = $145 & 2147483647;
 $147 = ($146|0)!=(0);
 $148 = ($145|0)>(-1);
 $or$cond$i$i16 = $147 & $148;
 if (!($or$cond$i$i16)) {
  STACKTOP = sp;return;
 }
 $149 = HEAP32[$this>>2]|0;
 $150 = ($149|0)==(0|0);
 if ($150) {
  STACKTOP = sp;return;
 }
 $151 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = (($152) + 12|0);
 $154 = HEAP32[$153>>2]|0;
 FUNCTION_TABLE_vii[$154 & 4095]($151,$149);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ClothFabricCoreC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ClothFabricCoreD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 4|0);
  $3 = HEAP16[$2>>1]|0;
  $4 = (($3) + -1)<<16>>16;
  HEAP16[$2>>1] = $4;
  $5 = ($4<<16>>16)==(0);
  if ($5) {
   $6 = HEAP32[$0>>2]|0;
   $7 = (($6) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vi[$8 & 4095]($0);
  }
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11|0)!=(0);
 $13 = ($10|0)>(-1);
 $or$cond$i$i = $12 & $13;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vii[$20 & 4095]($17,$15);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ClothFabricBulkData15exportExtraDataERNS_22PxSerializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if (!($2)) {
   $3 = (($this) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0);
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   if ($5) {
    $8 = $7 & 2147483647;
    $9 = ($8|0)==(0);
    if ($9) {
     break;
    }
   }
   $10 = HEAP32[$context>>2]|0;
   $11 = (($10) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = $7 << 2;
   FUNCTION_TABLE_viii[$12 & 4095]($context,$1,$13);
  }
 } while(0);
 $14 = (($this) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 do {
  if (!($16)) {
   $17 = (($this) + 20|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0);
   $20 = (($this) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   if ($19) {
    $22 = $21 & 2147483647;
    $23 = ($22|0)==(0);
    if ($23) {
     break;
    }
   }
   $24 = HEAP32[$context>>2]|0;
   $25 = (($24) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = $21 << 2;
   FUNCTION_TABLE_viii[$26 & 4095]($context,$15,$27);
  }
 } while(0);
 $28 = (($this) + 28|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 do {
  if (!($30)) {
   $31 = (($this) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0);
   $34 = (($this) + 36|0);
   $35 = HEAP32[$34>>2]|0;
   if ($33) {
    $36 = $35 & 2147483647;
    $37 = ($36|0)==(0);
    if ($37) {
     break;
    }
   }
   $38 = HEAP32[$context>>2]|0;
   $39 = (($38) + 8|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $35 << 2;
   FUNCTION_TABLE_viii[$40 & 4095]($context,$29,$41);
  }
 } while(0);
 $42 = (($this) + 40|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 do {
  if (!($44)) {
   $45 = (($this) + 44|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0);
   $48 = (($this) + 48|0);
   $49 = HEAP32[$48>>2]|0;
   if ($47) {
    $50 = $49 & 2147483647;
    $51 = ($50|0)==(0);
    if ($51) {
     break;
    }
   }
   $52 = HEAP32[$context>>2]|0;
   $53 = (($52) + 8|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = $49 << 2;
   FUNCTION_TABLE_viii[$54 & 4095]($context,$43,$55);
  }
 } while(0);
 $56 = (($this) + 52|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 do {
  if (!($58)) {
   $59 = (($this) + 56|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0);
   $62 = (($this) + 60|0);
   $63 = HEAP32[$62>>2]|0;
   if ($61) {
    $64 = $63 & 2147483647;
    $65 = ($64|0)==(0);
    if ($65) {
     break;
    }
   }
   $66 = HEAP32[$context>>2]|0;
   $67 = (($66) + 8|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = $63 << 2;
   FUNCTION_TABLE_viii[$68 & 4095]($context,$57,$69);
  }
 } while(0);
 $70 = (($this) + 64|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  STACKTOP = sp;return;
 }
 $73 = (($this) + 68|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 $76 = (($this) + 72|0);
 $77 = HEAP32[$76>>2]|0;
 if ($75) {
  $78 = $77 & 2147483647;
  $79 = ($78|0)==(0);
  if ($79) {
   STACKTOP = sp;return;
  }
 }
 $80 = HEAP32[$context>>2]|0;
 $81 = (($80) + 8|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = $77 << 2;
 FUNCTION_TABLE_viii[$82 & 4095]($context,$71,$83);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ClothFabricCore15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$$i$i$i = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy5 = sp + 112|0;
 $$byval_copy4 = sp + 104|0;
 $$byval_copy3 = sp + 96|0;
 $$byval_copy2 = sp + 88|0;
 $$byval_copy1 = sp + 80|0;
 $$byval_copy = sp + 72|0;
 $0 = sp + 64|0;
 $1 = sp + 60|0;
 $2 = sp + 56|0;
 $3 = sp + 40|0;
 $4 = sp + 32|0;
 $5 = sp + 24|0;
 $6 = sp + 16|0;
 $7 = sp + 8|0;
 $8 = sp;
 $9 = sp + 48|0;
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 do {
  if (!($12)) {
   $13 = (($this) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0);
   $16 = (($this) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   if ($15) {
    $18 = $17 & 2147483647;
    $19 = ($18|0)==(0);
    if ($19) {
     break;
    }
   }
   $20 = HEAP32[$stream>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = $17 << 2;
   FUNCTION_TABLE_viii[$22 & 4095]($stream,$11,$23);
  }
 } while(0);
 $24 = HEAP32[$this>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (__Z15PxGetFoundationv()|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
 $$$i$i$i = $34 ? 476792 : 476616;
 $35 = (FUNCTION_TABLE_iiiiii[$29 & 255]($26,76,$$$i$i$i,476288,97)|0);
 $36 = (($35) + 4|0);
 dest=$36+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $37 = HEAP32[463296>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 28|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (FUNCTION_TABLE_ii[$43 & 4095]($40)|0);
 HEAP32[$35>>2] = $44;
 $45 = HEAP32[$this>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46) + 12|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (FUNCTION_TABLE_ii[$48 & 4095]($45)|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($36,$49,$0);
 $50 = (($35) + 16|0);
 $51 = HEAP32[$this>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (FUNCTION_TABLE_ii[$54 & 4095]($51)|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($50,$55,$1);
 $56 = (($35) + 28|0);
 $57 = HEAP32[$this>>2]|0;
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + 16|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (FUNCTION_TABLE_ii[$60 & 4095]($57)|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($56,$61,$2);
 $62 = (($35) + 40|0);
 $63 = HEAP32[$this>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 24|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (FUNCTION_TABLE_ii[$66 & 4095]($63)|0);
 HEAP32[$3>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($62,$67,$3);
 $68 = (($35) + 52|0);
 $69 = HEAP32[$this>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + 32|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (FUNCTION_TABLE_ii[$72 & 4095]($69)|0);
 $74 = (($35) + 60|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = $75 & 2147483647;
 $77 = ($76>>>0)<($73>>>0);
 if ($77) {
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($68,$73);
 }
 $78 = (($35) + 64|0);
 $79 = HEAP32[$this>>2]|0;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + 32|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (FUNCTION_TABLE_ii[$82 & 4095]($79)|0);
 $84 = (($35) + 72|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = $85 & 2147483647;
 $87 = ($86>>>0)<($83>>>0);
 if ($87) {
  __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE8recreateEj($78,$83);
 }
 $88 = HEAP32[$39>>2]|0;
 $89 = (($88) + 24|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = HEAP32[$this>>2]|0;
 $92 = HEAP32[$36>>2]|0;
 $93 = (($35) + 8|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($92) + ($94<<2)|0);
 HEAP32[$4>>2] = $92;
 $96 = (($4) + 4|0);
 HEAP32[$96>>2] = $95;
 $97 = HEAP32[$50>>2]|0;
 $98 = (($35) + 20|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = (($97) + ($99<<2)|0);
 HEAP32[$5>>2] = $97;
 $101 = (($5) + 4|0);
 HEAP32[$101>>2] = $100;
 $102 = HEAP32[$56>>2]|0;
 $103 = (($35) + 32|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($102) + ($104<<2)|0);
 HEAP32[$6>>2] = $102;
 $106 = (($6) + 4|0);
 HEAP32[$106>>2] = $105;
 $107 = HEAP32[$62>>2]|0;
 $108 = (($35) + 44|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = (($107) + ($109<<2)|0);
 HEAP32[$7>>2] = $107;
 $111 = (($7) + 4|0);
 HEAP32[$111>>2] = $110;
 $112 = HEAP32[$68>>2]|0;
 $113 = (($35) + 56|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (($112) + ($114<<2)|0);
 HEAP32[$8>>2] = $112;
 $116 = (($8) + 4|0);
 HEAP32[$116>>2] = $115;
 $117 = HEAP32[$78>>2]|0;
 $118 = (($35) + 68|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (($117) + ($119<<2)|0);
 HEAP32[$9>>2] = $117;
 $121 = (($9) + 4|0);
 HEAP32[$121>>2] = $120;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$5+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$6+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$7+4>>2]|0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$8+4>>2]|0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$9+4>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$90 & 63]($39,$91,$$byval_copy,$$byval_copy1,$$byval_copy2,$$byval_copy3,$$byval_copy4,$$byval_copy5);
 $122 = HEAP32[$stream>>2]|0;
 $123 = (($122) + 8|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_viii[$124 & 4095]($stream,$35,76);
 __ZN5physx2Sc19ClothFabricBulkData15exportExtraDataERNS_22PxSerializationContextE($35,$stream);
 $125 = ($35|0)==(0|0);
 if ($125) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sc19ClothFabricBulkDataD2Ev($35);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($$byval_copy5,$35);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc15ClothFabricCore4loadERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $indices = 0, $notlhs = 0, $notlhs13 = 0, $notlhs15 = 0, $notlhs17 = 0, $notlhs19 = 0, $notrhs = 0, $notrhs14 = 0, $notrhs16 = 0, $notrhs18 = 0, $notrhs20 = 0, $or$cond = 0, $or$cond$i$i = 0, $or$cond$i$i1$not = 0, $or$cond$i$i2$not = 0;
 var $or$cond$i$i3$not = 0, $or$cond$i$i5$not = 0, $or$cond$i$i7$not = 0, $or$cond10 = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond9 = 0, $phases = 0, $restvalues = 0, $sets = 0, $tetherAnchors = 0, $tetherLengths = 0, $vararg_buffer = 0, $version = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $vararg_buffer = sp;
 $version = sp + 140|0;
 $phases = sp + 128|0;
 $0 = sp + 120|0;
 $sets = sp + 104|0;
 $1 = sp + 100|0;
 $restvalues = sp + 88|0;
 $2 = sp + 144|0;
 $indices = sp + 60|0;
 $3 = sp + 56|0;
 $tetherAnchors = sp + 44|0;
 $4 = sp + 40|0;
 $tetherLengths = sp + 72|0;
 $5 = sp + 84|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$version,4)|0);
 $8 = HEAP32[$version>>2]|0;
 $9 = ($8|0)==(50528512);
 if (!($9)) {
  $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,32,476288,165,476392,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 dest=$vararg_buffer+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $11 = HEAP32[$stream>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$vararg_buffer,4)|0);
 $13 = HEAP32[$stream>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($vararg_buffer) + 4|0);
 (FUNCTION_TABLE_iiii[$14 & 2047]($stream,$15,4)|0);
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($vararg_buffer) + 12|0);
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$18,4)|0);
 $19 = HEAP32[$stream>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($vararg_buffer) + 28|0);
 (FUNCTION_TABLE_iiii[$20 & 2047]($stream,$21,4)|0);
 $22 = HEAP32[$15>>2]|0;
 HEAP32[$0>>2] = 0;
 $23 = (($0) + 4|0);
 HEAP32[$23>>2] = 0;
 HEAP32[$phases>>2] = 0;
 $24 = (($phases) + 4|0);
 HEAP32[$24>>2] = 0;
 $25 = (($phases) + 8|0);
 HEAP32[$25>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_18PxClothFabricPhaseENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($phases,$22,$0);
 $26 = HEAP32[$stream>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$phases>>2]|0;
 $29 = HEAP32[$15>>2]|0;
 $30 = $29 << 3;
 (FUNCTION_TABLE_iiii[$27 & 2047]($stream,$28,$30)|0);
 $31 = (($vararg_buffer) + 8|0);
 HEAP32[$31>>2] = $28;
 $32 = HEAP32[$18>>2]|0;
 HEAP32[$1>>2] = 0;
 HEAP32[$sets>>2] = 0;
 $33 = (($sets) + 4|0);
 HEAP32[$33>>2] = 0;
 $34 = (($sets) + 8|0);
 HEAP32[$34>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($sets,$32,$1);
 $35 = HEAP32[$stream>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$sets>>2]|0;
 $38 = HEAP32[$18>>2]|0;
 $39 = $38 << 2;
 (FUNCTION_TABLE_iiii[$36 & 2047]($stream,$37,$39)|0);
 $40 = (($vararg_buffer) + 16|0);
 HEAP32[$40>>2] = $37;
 $41 = HEAP32[$33>>2]|0;
 $42 = (($41) + -1)|0;
 $43 = (($37) + ($42<<2)|0);
 $44 = HEAP32[$43>>2]|0;
 HEAPF32[$2>>2] = Math_fround(0.0);
 HEAP32[$restvalues>>2] = 0;
 $45 = (($restvalues) + 4|0);
 HEAP32[$45>>2] = 0;
 $46 = (($restvalues) + 8|0);
 HEAP32[$46>>2] = 0;
 __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($restvalues,$44,$2);
 $47 = HEAP32[$stream>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$restvalues>>2]|0;
 $50 = $44 << 2;
 (FUNCTION_TABLE_iiii[$48 & 2047]($stream,$49,$50)|0);
 $51 = (($vararg_buffer) + 24|0);
 HEAP32[$51>>2] = $49;
 $52 = $44 << 1;
 HEAP32[$3>>2] = 0;
 HEAP32[$indices>>2] = 0;
 $53 = (($indices) + 4|0);
 HEAP32[$53>>2] = 0;
 $54 = (($indices) + 8|0);
 HEAP32[$54>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($indices,$52,$3);
 $55 = HEAP32[$stream>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$indices>>2]|0;
 $58 = $44 << 3;
 (FUNCTION_TABLE_iiii[$56 & 2047]($stream,$57,$58)|0);
 $59 = (($vararg_buffer) + 20|0);
 HEAP32[$59>>2] = $57;
 $60 = HEAP32[$21>>2]|0;
 HEAP32[$4>>2] = 0;
 HEAP32[$tetherAnchors>>2] = 0;
 $61 = (($tetherAnchors) + 4|0);
 HEAP32[$61>>2] = 0;
 $62 = (($tetherAnchors) + 8|0);
 HEAP32[$62>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($tetherAnchors,$60,$4);
 $63 = HEAP32[$stream>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = HEAP32[$tetherAnchors>>2]|0;
 $66 = HEAP32[$21>>2]|0;
 $67 = $66 << 2;
 (FUNCTION_TABLE_iiii[$64 & 2047]($stream,$65,$67)|0);
 $68 = (($vararg_buffer) + 32|0);
 HEAP32[$68>>2] = $65;
 $69 = HEAP32[$21>>2]|0;
 HEAPF32[$5>>2] = Math_fround(0.0);
 HEAP32[$tetherLengths>>2] = 0;
 $70 = (($tetherLengths) + 4|0);
 HEAP32[$70>>2] = 0;
 $71 = (($tetherLengths) + 8|0);
 HEAP32[$71>>2] = 0;
 __ZN5physx6shdfnd5ArrayIfNS0_19ReflectionAllocatorIfEEE6resizeEjRKf($tetherLengths,$69,$5);
 $72 = HEAP32[$stream>>2]|0;
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$tetherLengths>>2]|0;
 $75 = HEAP32[$21>>2]|0;
 $76 = $75 << 2;
 (FUNCTION_TABLE_iiii[$73 & 2047]($stream,$74,$76)|0);
 $77 = (($vararg_buffer) + 36|0);
 HEAP32[$77>>2] = $74;
 $78 = (__ZN5physx2Sc15ClothFabricCore4loadERKNS_17PxClothFabricDescE($this,$vararg_buffer)|0);
 $79 = HEAP32[$71>>2]|0;
 $80 = $79 & 2147483647;
 $notlhs = ($80|0)==(0);
 $notrhs = ($79|0)<(0);
 $or$cond$i$i7$not = $notrhs | $notlhs;
 $81 = ($74|0)==(0|0);
 $or$cond = $or$cond$i$i7$not | $81;
 if (!($or$cond)) {
  $82 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + 12|0);
  $85 = HEAP32[$84>>2]|0;
  FUNCTION_TABLE_vii[$85 & 4095]($82,$74);
 }
 $86 = HEAP32[$62>>2]|0;
 $87 = $86 & 2147483647;
 $notlhs13 = ($87|0)==(0);
 $notrhs14 = ($86|0)<(0);
 $or$cond$i$i5$not = $notrhs14 | $notlhs13;
 $88 = ($65|0)==(0|0);
 $or$cond9 = $or$cond$i$i5$not | $88;
 if (!($or$cond9)) {
  $89 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($90) + 12|0);
  $92 = HEAP32[$91>>2]|0;
  FUNCTION_TABLE_vii[$92 & 4095]($89,$65);
 }
 $93 = HEAP32[$54>>2]|0;
 $94 = $93 & 2147483647;
 $notlhs15 = ($94|0)==(0);
 $notrhs16 = ($93|0)<(0);
 $or$cond$i$i3$not = $notrhs16 | $notlhs15;
 $95 = ($57|0)==(0|0);
 $or$cond10 = $or$cond$i$i3$not | $95;
 if (!($or$cond10)) {
  $96 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($97) + 12|0);
  $99 = HEAP32[$98>>2]|0;
  FUNCTION_TABLE_vii[$99 & 4095]($96,$57);
 }
 $100 = HEAP32[$46>>2]|0;
 $101 = $100 & 2147483647;
 $notlhs17 = ($101|0)==(0);
 $notrhs18 = ($100|0)<(0);
 $or$cond$i$i2$not = $notrhs18 | $notlhs17;
 $102 = ($49|0)==(0|0);
 $or$cond11 = $or$cond$i$i2$not | $102;
 if (!($or$cond11)) {
  $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($104) + 12|0);
  $106 = HEAP32[$105>>2]|0;
  FUNCTION_TABLE_vii[$106 & 4095]($103,$49);
 }
 $107 = HEAP32[$34>>2]|0;
 $108 = $107 & 2147483647;
 $notlhs19 = ($108|0)==(0);
 $notrhs20 = ($107|0)<(0);
 $or$cond$i$i1$not = $notrhs20 | $notlhs19;
 $109 = ($37|0)==(0|0);
 $or$cond12 = $or$cond$i$i1$not | $109;
 if (!($or$cond12)) {
  $110 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = (($111) + 12|0);
  $113 = HEAP32[$112>>2]|0;
  FUNCTION_TABLE_vii[$113 & 4095]($110,$37);
 }
 $114 = HEAP32[$25>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i = $116 & $117;
 if (!($or$cond$i$i)) {
  $$0 = $78;
  STACKTOP = sp;return ($$0|0);
 }
 $118 = HEAP32[$phases>>2]|0;
 $119 = ($118|0)==(0|0);
 if ($119) {
  $$0 = $78;
  STACKTOP = sp;return ($$0|0);
 }
 $120 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = (($121) + 12|0);
 $123 = HEAP32[$122>>2]|0;
 FUNCTION_TABLE_vii[$123 & 4095]($120,$118);
 $$0 = $78;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc15ClothFabricCore4loadERKNS_17PxClothFabricDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $i$03 = 0, $llphases = 0, $notlhs = 0, $notrhs = 0, $offsets = 0, $or$cond = 0, $or$cond$i$i$not = 0, $or$cond$i$i1 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy5 = sp;
 $$byval_copy4 = sp + 120|0;
 $$byval_copy3 = sp + 112|0;
 $$byval_copy2 = sp + 104|0;
 $$byval_copy1 = sp + 96|0;
 $$byval_copy = sp + 88|0;
 $0 = sp + 84|0;
 $llphases = sp + 72|0;
 $1 = sp + 128|0;
 $offsets = sp + 44|0;
 $2 = sp + 40|0;
 $3 = sp + 32|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = sp + 8|0;
 $7 = sp + 56|0;
 $8 = sp + 64|0;
 $9 = (($this) + 8|0);
 $10 = (($desc) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_22PxClothFabricPhaseType4EnumENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($9,$11,$0);
 $12 = HEAP32[$10>>2]|0;
 HEAP32[$1>>2] = 0;
 HEAP32[$llphases>>2] = 0;
 $13 = (($llphases) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($llphases) + 8|0);
 HEAP32[$14>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($llphases,$12,$1);
 $15 = HEAP32[$10>>2]|0;
 HEAP32[$2>>2] = 0;
 HEAP32[$offsets>>2] = 0;
 $16 = (($offsets) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($offsets) + 8|0);
 HEAP32[$17>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($offsets,$15,$2);
 $18 = HEAP32[$10>>2]|0;
 $19 = ($18|0)==(0);
 L1: do {
  if ($19) {
   $$pre = HEAP32[$llphases>>2]|0;
   $52 = $$pre;
   label = 7;
  } else {
   $20 = (($desc) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$llphases>>2]|0;
   $i$03 = 0;
   while(1) {
    $23 = (($21) + ($i$03<<3)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0);
    $26 = ($24|0)>(4);
    $or$cond = $25 | $26;
    if ($or$cond) {
     break;
    }
    $28 = HEAP32[$9>>2]|0;
    $29 = (($28) + ($i$03<<2)|0);
    HEAP32[$29>>2] = $24;
    $30 = ((($21) + ($i$03<<3)|0) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($22) + ($i$03<<2)|0);
    HEAP32[$32>>2] = $31;
    $33 = (($i$03) + 1)|0;
    $34 = HEAP32[$10>>2]|0;
    $35 = ($33>>>0)<($34>>>0);
    if ($35) {
     $i$03 = $33;
    } else {
     $52 = $22;
     label = 7;
     break L1;
    }
   }
   $27 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($27,4,476288,224,476472,$$byval_copy5);
   $$0 = 0;$92 = $22;
  }
 } while(0);
 if ((label|0) == 7) {
  $36 = HEAP32[463296>>2]|0;
  $37 = (($36) + 12|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($desc) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + -1)|0;
  $42 = (($desc) + 16|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + ($41<<2)|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = HEAP32[$38>>2]|0;
  $47 = (($46) + 8|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = HEAP32[$desc>>2]|0;
  $50 = HEAP32[$13>>2]|0;
  $51 = (($52) + ($50<<2)|0);
  HEAP32[$3>>2] = $52;
  $53 = (($3) + 4|0);
  HEAP32[$53>>2] = $51;
  $54 = (($43) + ($40<<2)|0);
  HEAP32[$4>>2] = $43;
  $55 = (($4) + 4|0);
  HEAP32[$55>>2] = $54;
  $56 = (($desc) + 24|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($57) + ($45<<2)|0);
  HEAP32[$5>>2] = $57;
  $59 = (($5) + 4|0);
  HEAP32[$59>>2] = $58;
  $60 = (($desc) + 20|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = $45 << 1;
  $63 = (($61) + ($62<<2)|0);
  HEAP32[$6>>2] = $61;
  $64 = (($6) + 4|0);
  HEAP32[$64>>2] = $63;
  $65 = (($desc) + 32|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($desc) + 28|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($66) + ($68<<2)|0);
  HEAP32[$7>>2] = $66;
  $70 = (($7) + 4|0);
  HEAP32[$70>>2] = $69;
  $71 = (($desc) + 36|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + ($68<<2)|0);
  HEAP32[$8>>2] = $72;
  $74 = (($8) + 4|0);
  HEAP32[$74>>2] = $73;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$4+4>>2]|0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$5+4>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$6+4>>2]|0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$7+4>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$8+4>>2]|0;
  $75 = (FUNCTION_TABLE_iiiiiiiii[$48 & 63]($38,$49,$$byval_copy,$$byval_copy1,$$byval_copy2,$$byval_copy3,$$byval_copy4,$$byval_copy5)|0);
  HEAP32[$this>>2] = $75;
  $76 = (($75) + 4|0);
  $77 = HEAP16[$76>>1]|0;
  $78 = (($77) + 1)<<16>>16;
  HEAP16[$76>>1] = $78;
  $$0 = 1;$92 = $52;
 }
 $79 = HEAP32[$17>>2]|0;
 $80 = $79 & 2147483647;
 $81 = ($80|0)!=(0);
 $82 = ($79|0)>(-1);
 $or$cond$i$i1 = $81 & $82;
 if ($or$cond$i$i1) {
  $83 = HEAP32[$offsets>>2]|0;
  $84 = ($83|0)==(0|0);
  if (!($84)) {
   $85 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 12|0);
   $88 = HEAP32[$87>>2]|0;
   FUNCTION_TABLE_vii[$88 & 4095]($85,$83);
  }
 }
 $89 = HEAP32[$14>>2]|0;
 $90 = $89 & 2147483647;
 $notlhs = ($90|0)==(0);
 $notrhs = ($89|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $91 = ($92|0)==(0|0);
 $or$cond5 = $or$cond$i$i$not | $91;
 if ($or$cond5) {
  STACKTOP = sp;return ($$0|0);
 }
 $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($94) + 12|0);
 $96 = HEAP32[$95>>2]|0;
 FUNCTION_TABLE_vii[$96 & 4095]($93,$92);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayINS_22PxClothFabricPhaseType4EnumENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_22PxClothFabricPhaseType4EnumENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc15ClothFabricCore14getNbParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc15ClothFabricCore11getNbPhasesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc15ClothFabricCore9getNbSetsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc15ClothFabricCore20getNbParticleIndicesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc15ClothFabricCore15getNbRestvaluesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc15ClothFabricCore12getNbTethersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Sc15ClothFabricCore9getPhasesEPNS_18PxClothFabricPhaseEj($this,$userPhaseBuffer,$bufferSize) {
 $this = $this|0;
 $userPhaseBuffer = $userPhaseBuffer|0;
 $bufferSize = $bufferSize|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0;
 var $or$cond$i$i$not = 0, $phases = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy5 = sp + 104|0;
 $$byval_copy4 = sp + 96|0;
 $$byval_copy3 = sp + 88|0;
 $$byval_copy2 = sp + 80|0;
 $$byval_copy1 = sp + 72|0;
 $$byval_copy = sp + 64|0;
 $phases = sp + 52|0;
 $0 = sp + 48|0;
 $1 = sp + 32|0;
 $2 = sp + 24|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 $6 = sp + 40|0;
 $7 = HEAP32[$this>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $12 = ($11>>>0)>($bufferSize>>>0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = 0;
 HEAP32[$phases>>2] = 0;
 $13 = (($phases) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($phases) + 8|0);
 HEAP32[$14>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($phases,$11,$0);
 $15 = HEAP32[463296>>2]|0;
 $16 = (($15) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$phases>>2]|0;
 $23 = HEAP32[$13>>2]|0;
 $24 = (($22) + ($23<<2)|0);
 HEAP32[$1>>2] = $22;
 $25 = (($1) + 4|0);
 HEAP32[$25>>2] = $24;
 HEAP32[$2>>2] = 0;
 $26 = (($2) + 4|0);
 HEAP32[$26>>2] = 0;
 HEAP32[$3>>2] = 0;
 $27 = (($3) + 4|0);
 HEAP32[$27>>2] = 0;
 HEAP32[$4>>2] = 0;
 $28 = (($4) + 4|0);
 HEAP32[$28>>2] = 0;
 HEAP32[$5>>2] = 0;
 $29 = (($5) + 4|0);
 HEAP32[$29>>2] = 0;
 HEAP32[$6>>2] = 0;
 $30 = (($6) + 4|0);
 HEAP32[$30>>2] = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$5+4>>2]|0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$6+4>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$20 & 63]($17,$21,$$byval_copy,$$byval_copy1,$$byval_copy2,$$byval_copy3,$$byval_copy4,$$byval_copy5);
 $31 = ($11|0)==(0);
 if (!($31)) {
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $i$01 = 0;
  while(1) {
   $34 = (($22) + ($i$01<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($userPhaseBuffer) + ($i$01<<3)|0) + 4|0);
   HEAP32[$36>>2] = $35;
   $37 = (($33) + ($i$01<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($userPhaseBuffer) + ($i$01<<3)|0);
   HEAP32[$39>>2] = $38;
   $40 = (($i$01) + 1)|0;
   $exitcond = ($40|0)==($11|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $40;
   }
  }
 }
 $41 = HEAP32[$14>>2]|0;
 $42 = $41 & 2147483647;
 $notlhs = ($42|0)==(0);
 $notrhs = ($41|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $43 = ($22|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $43;
 if ($or$cond) {
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 FUNCTION_TABLE_vii[$47 & 4095]($44,$22);
 $$0 = $11;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sc15ClothFabricCore13getRestvaluesEPfj($this,$userRestvalueBuffer,$bufferSize) {
 $this = $this|0;
 $userRestvalueBuffer = $userRestvalueBuffer|0;
 $bufferSize = $bufferSize|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy5 = sp + 88|0;
 $$byval_copy4 = sp + 80|0;
 $$byval_copy3 = sp + 72|0;
 $$byval_copy2 = sp + 64|0;
 $$byval_copy1 = sp + 56|0;
 $$byval_copy = sp + 48|0;
 $0 = sp + 40|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 $5 = sp + 32|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = ($10>>>0)>($bufferSize>>>0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[463296>>2]|0;
 $13 = (($12) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = 0;
 $19 = (($0) + 4|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$1>>2] = 0;
 $20 = (($1) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($userRestvalueBuffer) + ($10<<2)|0);
 HEAP32[$2>>2] = $userRestvalueBuffer;
 $22 = (($2) + 4|0);
 HEAP32[$22>>2] = $21;
 HEAP32[$3>>2] = 0;
 $23 = (($3) + 4|0);
 HEAP32[$23>>2] = 0;
 HEAP32[$4>>2] = 0;
 $24 = (($4) + 4|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$5>>2] = 0;
 $25 = (($5) + 4|0);
 HEAP32[$25>>2] = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$5+4>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$17 & 63]($14,$18,$$byval_copy,$$byval_copy1,$$byval_copy2,$$byval_copy3,$$byval_copy4,$$byval_copy5);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sc15ClothFabricCore7getSetsEPjj($this,$userSetBuffer,$bufferSize) {
 $this = $this|0;
 $userSetBuffer = $userSetBuffer|0;
 $bufferSize = $bufferSize|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy5 = sp + 88|0;
 $$byval_copy4 = sp + 80|0;
 $$byval_copy3 = sp + 72|0;
 $$byval_copy2 = sp + 64|0;
 $$byval_copy1 = sp + 56|0;
 $$byval_copy = sp + 48|0;
 $0 = sp + 40|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 $5 = sp + 32|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = ($10>>>0)>($bufferSize>>>0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[463296>>2]|0;
 $13 = (($12) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = 0;
 $19 = (($0) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($userSetBuffer) + ($10<<2)|0);
 HEAP32[$1>>2] = $userSetBuffer;
 $21 = (($1) + 4|0);
 HEAP32[$21>>2] = $20;
 HEAP32[$2>>2] = 0;
 $22 = (($2) + 4|0);
 HEAP32[$22>>2] = 0;
 HEAP32[$3>>2] = 0;
 $23 = (($3) + 4|0);
 HEAP32[$23>>2] = 0;
 HEAP32[$4>>2] = 0;
 $24 = (($4) + 4|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$5>>2] = 0;
 $25 = (($5) + 4|0);
 HEAP32[$25>>2] = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$5+4>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$17 & 63]($14,$18,$$byval_copy,$$byval_copy1,$$byval_copy2,$$byval_copy3,$$byval_copy4,$$byval_copy5);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sc15ClothFabricCore18getParticleIndicesEPjj($this,$userParticleIndexBuffer,$bufferSize) {
 $this = $this|0;
 $userParticleIndexBuffer = $userParticleIndexBuffer|0;
 $bufferSize = $bufferSize|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy5 = sp + 88|0;
 $$byval_copy4 = sp + 80|0;
 $$byval_copy3 = sp + 72|0;
 $$byval_copy2 = sp + 64|0;
 $$byval_copy1 = sp + 56|0;
 $$byval_copy = sp + 48|0;
 $0 = sp + 40|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 $5 = sp + 32|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = ($10>>>0)>($bufferSize>>>0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[463296>>2]|0;
 $13 = (($12) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = 0;
 $19 = (($0) + 4|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$1>>2] = 0;
 $20 = (($1) + 4|0);
 HEAP32[$20>>2] = 0;
 HEAP32[$2>>2] = 0;
 $21 = (($2) + 4|0);
 HEAP32[$21>>2] = 0;
 $22 = (($userParticleIndexBuffer) + ($10<<2)|0);
 HEAP32[$3>>2] = $userParticleIndexBuffer;
 $23 = (($3) + 4|0);
 HEAP32[$23>>2] = $22;
 HEAP32[$4>>2] = 0;
 $24 = (($4) + 4|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$5>>2] = 0;
 $25 = (($5) + 4|0);
 HEAP32[$25>>2] = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$5+4>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$17 & 63]($14,$18,$$byval_copy,$$byval_copy1,$$byval_copy2,$$byval_copy3,$$byval_copy4,$$byval_copy5);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sc15ClothFabricCore16getTetherAnchorsEPjj($this,$userAnchorBuffer,$bufferSize) {
 $this = $this|0;
 $userAnchorBuffer = $userAnchorBuffer|0;
 $bufferSize = $bufferSize|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy5 = sp + 88|0;
 $$byval_copy4 = sp + 80|0;
 $$byval_copy3 = sp + 72|0;
 $$byval_copy2 = sp + 64|0;
 $$byval_copy1 = sp + 56|0;
 $$byval_copy = sp + 48|0;
 $0 = sp + 40|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 $5 = sp + 32|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = ($10>>>0)>($bufferSize>>>0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[463296>>2]|0;
 $13 = (($12) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = 0;
 $19 = (($0) + 4|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$1>>2] = 0;
 $20 = (($1) + 4|0);
 HEAP32[$20>>2] = 0;
 HEAP32[$2>>2] = 0;
 $21 = (($2) + 4|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$3>>2] = 0;
 $22 = (($3) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = (($userAnchorBuffer) + ($10<<2)|0);
 HEAP32[$4>>2] = $userAnchorBuffer;
 $24 = (($4) + 4|0);
 HEAP32[$24>>2] = $23;
 HEAP32[$5>>2] = 0;
 $25 = (($5) + 4|0);
 HEAP32[$25>>2] = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$5+4>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$17 & 63]($14,$18,$$byval_copy,$$byval_copy1,$$byval_copy2,$$byval_copy3,$$byval_copy4,$$byval_copy5);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sc15ClothFabricCore16getTetherLengthsEPfj($this,$userLengthBuffer,$bufferSize) {
 $this = $this|0;
 $userLengthBuffer = $userLengthBuffer|0;
 $bufferSize = $bufferSize|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy5 = sp + 88|0;
 $$byval_copy4 = sp + 80|0;
 $$byval_copy3 = sp + 72|0;
 $$byval_copy2 = sp + 64|0;
 $$byval_copy1 = sp + 56|0;
 $$byval_copy = sp + 48|0;
 $0 = sp + 40|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 $5 = sp + 32|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = ($10>>>0)>($bufferSize>>>0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[463296>>2]|0;
 $13 = (($12) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = 0;
 $19 = (($0) + 4|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$1>>2] = 0;
 $20 = (($1) + 4|0);
 HEAP32[$20>>2] = 0;
 HEAP32[$2>>2] = 0;
 $21 = (($2) + 4|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$3>>2] = 0;
 $22 = (($3) + 4|0);
 HEAP32[$22>>2] = 0;
 HEAP32[$4>>2] = 0;
 $23 = (($4) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = (($userLengthBuffer) + ($10<<2)|0);
 HEAP32[$5>>2] = $userLengthBuffer;
 $25 = (($5) + 4|0);
 HEAP32[$25>>2] = $24;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$5+4>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$17 & 63]($14,$18,$$byval_copy,$$byval_copy1,$$byval_copy2,$$byval_copy3,$$byval_copy4,$$byval_copy5);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sc15ClothFabricCore16scaleRestlengthsEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vif[$3 & 255]($0,$scale);
 $4 = HEAP32[$this>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vif[$7 & 255]($4,$scale);
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vif[$13 & 255]($9,$scale);
 $14 = HEAP32[$8>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 40|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vif[$17 & 255]($14,$scale);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_22PxClothFabricPhaseType4EnumENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 476648 : 476616;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,476536,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc19ClothFabricBulkDataD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i4 = 0, $or$cond$i$i6 = 0, $or$cond$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 64|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i1 = $15 & $16;
 if ($or$cond$i$i1) {
  $17 = (($this) + 52|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 48|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i2 = $27 & $28;
 if ($or$cond$i$i2) {
  $29 = (($this) + 40|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38|0)!=(0);
 $40 = ($37|0)>(-1);
 $or$cond$i$i4 = $39 & $40;
 if ($or$cond$i$i4) {
  $41 = (($this) + 28|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($44,$42);
  }
 }
 $48 = (($this) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49 & 2147483647;
 $51 = ($50|0)!=(0);
 $52 = ($49|0)>(-1);
 $or$cond$i$i6 = $51 & $52;
 if ($or$cond$i$i6) {
  $53 = (($this) + 16|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   FUNCTION_TABLE_vii[$59 & 4095]($56,$54);
  }
 }
 $60 = (($this) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = $61 & 2147483647;
 $63 = ($62|0)!=(0);
 $64 = ($61|0)>(-1);
 $or$cond$i$i8 = $63 & $64;
 if (!($or$cond$i$i8)) {
  STACKTOP = sp;return;
 }
 $65 = (($this) + 4|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $68 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 12|0);
 $71 = HEAP32[$70>>2]|0;
 FUNCTION_TABLE_vii[$71 & 4095]($68,$66);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10ClothShapeC2ERNS0_8ClothSimE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((473672 + 8|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $cloth;
 $3 = (($this) + 12|0);
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = -1073741825;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 1073741823;
 __ZN5physx2Sc5Actor15onElementAttachERNS0_7ElementE($cloth,$this);
 HEAP32[$this>>2] = ((476928 + 8|0));
 $8 = (($this) + 20|0);
 $9 = (__ZNK5physx2Sc8ClothSim7getCoreEv($cloth)|0);
 HEAP32[$8>>2] = $9;
 $10 = (($this) + 24|0);
 __ZNK5physx2Sc9ClothCore13getClothFlagsEv($0,$9);
 $11 = HEAP16[$0>>1]|0;
 $12 = $11 & 4;
 $13 = ($12<<16>>16)==(0);
 $$lobit = ($12&65535) >>> 2;
 $14 = $$lobit&255;
 HEAP8[$10>>0] = $14;
 if ($13) {
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$2>>2]|0;
 $16 = (__ZNK5physx2Sc8ActorSim8getSceneEv($15)|0);
 __ZN5physx2Sc5Scene19addBroadPhaseVolumeERNS0_10ClothShapeE($16,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10ClothShapeD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((476928 + 8|0));
 $1 = (($this) + 24|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (__ZNK5physx2Sc8ActorSim8getSceneEv($5)|0);
  __ZN5physx2Sc5Scene22removeBroadPhaseVolumeERNS0_10ClothShapeE($6,$this);
 }
 __ZN5physx2Sc7ElementD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10ClothShapeD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((476928 + 8|0));
 $0 = (($this) + 24|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  __ZN5physx2Sc7ElementD2Ev($this);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5physx2Sc8ActorSim8getSceneEv($4)|0);
 __ZN5physx2Sc5Scene22removeBroadPhaseVolumeERNS0_10ClothShapeE($5,$this);
 __ZN5physx2Sc7ElementD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc10ClothShape13getFilterInfoERjRNS_12PxFilterDataE($this,$filterAttr,$filterData) {
 $this = $this|0;
 $filterAttr = $filterAttr|0;
 $filterData = $filterData|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$filterAttr>>2] = 5;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNK5physx2Sc9ClothCore23getSimulationFilterDataEv($0,$2);
 ;HEAP32[$filterData+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$filterData+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$filterData+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$filterData+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc10ClothShape21updateBoundsInAABBMgrEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $worldBounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 24|0;
 $worldBounds = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNK5physx2Sc9ClothCore13getClothFlagsEv($0,$2);
 $3 = HEAP16[$0>>1]|0;
 $4 = $3 & 4;
 $5 = ($4<<16>>16)==(0);
 $6 = (($this) + 24|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 if ($5) {
  if (!($8)) {
   STACKTOP = sp;return;
  }
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__ZNK5physx2Sc8ActorSim8getSceneEv($10)|0);
  __ZN5physx2Sc5Scene22removeBroadPhaseVolumeERNS0_10ClothShapeE($11,$this);
  HEAP8[$6>>0] = 0;
  STACKTOP = sp;return;
 }
 $$pre = (($this) + 8|0);
 if (!($8)) {
  $12 = HEAP32[$$pre>>2]|0;
  $13 = (__ZNK5physx2Sc8ActorSim8getSceneEv($12)|0);
  __ZN5physx2Sc5Scene19addBroadPhaseVolumeERNS0_10ClothShapeE($13,$this);
  HEAP8[$6>>0] = 1;
 }
 $14 = HEAP32[$$pre>>2]|0;
 $15 = (($14) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1000|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$1>>2]|0;
 __ZNK5physx2Sc9ClothCore14getWorldBoundsEv($worldBounds,$21);
 $22 = HEAP32[$1>>2]|0;
 $23 = (Math_fround(__ZNK5physx2Sc9ClothCore16getContactOffsetEv($22)));
 $24 = Math_fround(HEAPF32[$worldBounds>>2]);
 $25 = (($worldBounds) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = $24 > $26;
 if (!($27)) {
  $28 = Math_fround($24 - $23);
  HEAPF32[$worldBounds>>2] = $28;
  $29 = (($worldBounds) + 4|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($30 - $23);
  HEAPF32[$29>>2] = $31;
  $32 = (($worldBounds) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($33 - $23);
  HEAPF32[$32>>2] = $34;
  $35 = Math_fround($23 + $26);
  HEAPF32[$25>>2] = $35;
  $36 = (($worldBounds) + 16|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($23 + $37);
  HEAPF32[$36>>2] = $38;
  $39 = (($worldBounds) + 20|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($23 + $40);
  HEAPF32[$39>>2] = $41;
 }
 $42 = (($this) + 12|0);
 $43 = $42;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = $45 & 1073741823;
 __ZN5physx14PxsAABBManager15setVolumeBoundsEjRKNS_9PxBounds3E($20,$49,$worldBounds);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc10ClothShape8isActiveEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx2Sc8ClothSimC2ERNS0_5SceneERNS0_9ClothCoreE($this,$scene,$core) {
 $this = $this|0;
 $scene = $scene|0;
 $core = $core|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $externalAcceleration$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $externalAcceleration$i = sp;
 __ZN5physx2Sc8ActorSimC2ERNS0_5SceneERNS0_9ActorCoreENS0_14IslandNodeInfo4TypeE($this,$scene,$core,8);
 HEAP32[$this>>2] = ((476952 + 8|0));
 $0 = (($this) + 56|0);
 __ZN5physx2Sc10ClothShapeC2ERNS0_8ClothSimE($0,$this);
 $1 = (($this) + 84|0);
 dest=$1+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx2Sc8ClothSim24updateRigidBodyPositionsEv($this);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNK5physx2Sc9ClothCore23getExternalAccelerationEv($externalAcceleration$i,$3);
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6 & 2;
 $8 = ($7<<16>>16)==(0);
 if (!($8)) {
  $25 = $4;
  $24 = (($25) + 28|0);
  $26 = HEAP32[$24>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 80|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vii[$29 & 4095]($26,$externalAcceleration$i);
  STACKTOP = sp;return;
 }
 $9 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $10 = (($9) + 32|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($9) + 36|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($9) + 40|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$externalAcceleration$i>>2]);
 $17 = Math_fround($11 + $16);
 HEAPF32[$externalAcceleration$i>>2] = $17;
 $18 = (($externalAcceleration$i) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($13 + $19);
 HEAPF32[$18>>2] = $20;
 $21 = (($externalAcceleration$i) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($15 + $22);
 HEAPF32[$21>>2] = $23;
 $$pre$i = HEAP32[$2>>2]|0;
 $25 = $$pre$i;
 $24 = (($25) + 28|0);
 $26 = HEAP32[$24>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 80|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$29 & 4095]($26,$externalAcceleration$i);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim9startStepEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $externalAcceleration = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $externalAcceleration = sp;
 __ZN5physx2Sc8ClothSim24updateRigidBodyPositionsEv($this);
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __ZNK5physx2Sc9ClothCore23getExternalAccelerationEv($externalAcceleration,$1);
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 2;
 $6 = ($5<<16>>16)==(0);
 if (!($6)) {
  $23 = $2;
  $22 = (($23) + 28|0);
  $24 = HEAP32[$22>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 80|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vii[$27 & 4095]($24,$externalAcceleration);
  STACKTOP = sp;return;
 }
 $7 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $8 = (($7) + 32|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($7) + 36|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($7) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$externalAcceleration>>2]);
 $15 = Math_fround($9 + $14);
 HEAPF32[$externalAcceleration>>2] = $15;
 $16 = (($externalAcceleration) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($11 + $17);
 HEAPF32[$16>>2] = $18;
 $19 = (($externalAcceleration) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($13 + $20);
 HEAPF32[$19>>2] = $21;
 $$pre = HEAP32[$0>>2]|0;
 $23 = $$pre;
 $22 = (($23) + 28|0);
 $24 = HEAP32[$22>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 80|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vii[$27 & 4095]($24,$externalAcceleration);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Sc8ClothSimD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((476952 + 8|0));
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = ($5|0)!=(0);
 $7 = ($4|0)>(-1);
 $or$cond$i$i1 = $6 & $7;
 if ($or$cond$i$i1) {
  $8 = (($this) + 128|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
  }
 }
 $15 = (($this) + 124|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = ($17|0)!=(0);
 $19 = ($16|0)>(-1);
 $or$cond$i$i = $18 & $19;
 if ($or$cond$i$i) {
  $20 = (($this) + 116|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   $23 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vii[$26 & 4095]($23,$21);
  }
 }
 $27 = (($this) + 56|0);
 __ZN5physx2Sc10ClothShapeD2Ev($27);
 __ZN5physx2Sc8ActorSimD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sc8ClothSim7getCoreEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Sc8ClothSim12updateBoundsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 __ZN5physx2Sc10ClothShape21updateBoundsInAABBMgrEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim24updateRigidBodyPositionsEv($this) {
 $this = $this|0;
 var $$01$i = 0, $$01$i21 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$lobit$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i26 = 0, $$pre$i38 = 0, $$pre$phi$iZ2D = 0, $$pre15$i = 0, $$pre16$i = 0, $$pre17$i = 0, $$pre177 = 0, $$pre178 = 0, $$pre179 = 0, $$pre18$i = 0, $$pre180 = 0, $$pre181 = 0, $$pre182 = 0;
 var $$pre183 = 0, $$pre184 = 0, $$pre185 = 0, $$pre186 = 0, $$pre187 = 0, $$pre19$i = 0, $$pre191 = 0, $$pre192 = Math_fround(0), $$pre193 = Math_fround(0), $$pre194 = Math_fround(0), $$pre195 = Math_fround(0), $$pre196 = Math_fround(0), $$pre197 = Math_fround(0), $$pre198 = Math_fround(0), $$pre199 = Math_fround(0), $$pre20$i = 0, $$pre200 = Math_fround(0), $$pre201 = Math_fround(0), $$pre202 = Math_fround(0), $$pre203 = Math_fround(0);
 var $$pre204 = 0, $$pre205 = 0, $$pre206 = 0, $$pre21$i = 0, $$pre22$i = 0, $$pre6$i = 0, $$pre6$i39 = 0, $$pre7$i = 0, $$pre7$i41 = 0, $$pre8$i = 0, $$pre8$i42 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0;
 var $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = Math_fround(0), $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = Math_fround(0), $1020 = 0, $1021 = 0, $1022 = 0;
 var $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = Math_fround(0), $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = Math_fround(0), $1040 = 0;
 var $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0);
 var $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0);
 var $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = Math_fround(0), $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0);
 var $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0);
 var $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = 0, $1128 = 0, $1129 = 0, $113 = Math_fround(0), $1130 = 0;
 var $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = Math_fround(0), $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0;
 var $115 = Math_fround(0), $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = Math_fround(0), $1160 = 0, $1161 = 0, $1162 = 0, $1163 = Math_fround(0), $1164 = 0, $1165 = 0, $1166 = Math_fround(0), $1167 = 0;
 var $1168 = 0, $1169 = Math_fround(0), $117 = Math_fround(0), $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = Math_fround(0), $1180 = 0, $1181 = 0, $1182 = 0, $1183 = Math_fround(0), $1184 = 0, $1185 = 0;
 var $1186 = Math_fround(0), $1187 = 0, $1188 = 0, $1189 = Math_fround(0), $119 = Math_fround(0), $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = Math_fround(0), $1200 = 0, $1201 = 0, $1202 = 0;
 var $1203 = Math_fround(0), $1204 = 0, $1205 = 0, $1206 = Math_fround(0), $1207 = 0, $1208 = 0, $1209 = Math_fround(0), $121 = Math_fround(0), $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = Math_fround(0), $1220 = 0;
 var $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = Math_fround(0), $1229 = 0, $123 = Math_fround(0), $1230 = 0, $1231 = Math_fround(0), $1232 = 0, $1233 = 0, $1234 = Math_fround(0), $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0;
 var $124 = Math_fround(0), $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = Math_fround(0), $1248 = 0, $1249 = 0, $125 = Math_fround(0), $1250 = Math_fround(0), $1251 = 0, $1252 = 0, $1253 = Math_fround(0), $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0;
 var $1258 = 0, $1259 = 0, $126 = Math_fround(0), $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = Math_fround(0), $1267 = 0, $1268 = 0, $1269 = Math_fround(0), $127 = Math_fround(0), $1270 = 0, $1271 = 0, $1272 = Math_fround(0), $1273 = 0, $1274 = 0, $1275 = 0;
 var $1276 = 0, $1277 = Math_fround(0), $1278 = 0, $1279 = Math_fround(0), $128 = 0, $1280 = 0, $1281 = Math_fround(0), $1282 = 0, $1283 = Math_fround(0), $1284 = 0, $1285 = Math_fround(0), $1286 = 0, $1287 = Math_fround(0), $1288 = 0, $1289 = Math_fround(0), $129 = Math_fround(0), $1290 = 0, $1291 = Math_fround(0), $1292 = 0, $1293 = Math_fround(0);
 var $1294 = 0, $1295 = Math_fround(0), $1296 = 0, $1297 = Math_fround(0), $1298 = 0, $1299 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = Math_fround(0), $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0), $131 = 0, $1310 = Math_fround(0);
 var $1311 = Math_fround(0), $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = Math_fround(0), $1317 = Math_fround(0), $1318 = Math_fround(0), $1319 = Math_fround(0), $132 = 0, $1320 = 0, $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = Math_fround(0), $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = 0, $1329 = Math_fround(0);
 var $133 = 0, $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0;
 var $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = Math_fround(0), $136 = 0, $1360 = 0, $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = Math_fround(0);
 var $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = 0, $1370 = Math_fround(0), $1371 = 0, $1372 = Math_fround(0), $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = Math_fround(0), $1379 = Math_fround(0), $138 = 0, $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0);
 var $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0;
 var $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0;
 var $142 = 0, $1420 = 0, $1421 = Math_fround(0), $1422 = Math_fround(0), $1423 = Math_fround(0), $1424 = Math_fround(0), $1425 = Math_fround(0), $1426 = Math_fround(0), $1427 = Math_fround(0), $1428 = Math_fround(0), $1429 = Math_fround(0), $143 = 0, $1430 = Math_fround(0), $1431 = Math_fround(0), $1432 = Math_fround(0), $1433 = Math_fround(0), $1434 = Math_fround(0), $1435 = Math_fround(0), $1436 = Math_fround(0), $1437 = Math_fround(0);
 var $1438 = Math_fround(0), $1439 = Math_fround(0), $144 = 0, $1440 = Math_fround(0), $1441 = Math_fround(0), $1442 = Math_fround(0), $1443 = Math_fround(0), $1444 = Math_fround(0), $1445 = Math_fround(0), $1446 = Math_fround(0), $1447 = Math_fround(0), $1448 = Math_fround(0), $1449 = Math_fround(0), $145 = 0, $1450 = Math_fround(0), $1451 = Math_fround(0), $1452 = Math_fround(0), $1453 = Math_fround(0), $1454 = Math_fround(0), $1455 = Math_fround(0);
 var $1456 = Math_fround(0), $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = 0, $1460 = Math_fround(0), $1461 = Math_fround(0), $1462 = Math_fround(0), $1463 = Math_fround(0), $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = Math_fround(0), $1467 = Math_fround(0), $1468 = Math_fround(0), $1469 = Math_fround(0), $147 = Math_fround(0), $1470 = Math_fround(0), $1471 = Math_fround(0), $1472 = Math_fround(0), $1473 = Math_fround(0);
 var $1474 = Math_fround(0), $1475 = Math_fround(0), $1476 = Math_fround(0), $1477 = Math_fround(0), $1478 = Math_fround(0), $1479 = Math_fround(0), $148 = Math_fround(0), $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0), $1486 = Math_fround(0), $1487 = Math_fround(0), $1488 = Math_fround(0), $1489 = Math_fround(0), $149 = Math_fround(0), $1490 = Math_fround(0), $1491 = Math_fround(0);
 var $1492 = Math_fround(0), $1493 = Math_fround(0), $1494 = Math_fround(0), $1495 = Math_fround(0), $1496 = Math_fround(0), $1497 = Math_fround(0), $1498 = Math_fround(0), $1499 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $1500 = Math_fround(0), $1501 = Math_fround(0), $1502 = Math_fround(0), $1503 = Math_fround(0), $1504 = Math_fround(0), $1505 = Math_fround(0), $1506 = Math_fround(0), $1507 = Math_fround(0), $1508 = Math_fround(0), $1509 = Math_fround(0);
 var $151 = Math_fround(0), $1510 = Math_fround(0), $1511 = Math_fround(0), $1512 = Math_fround(0), $1513 = Math_fround(0), $1514 = Math_fround(0), $1515 = Math_fround(0), $1516 = Math_fround(0), $1517 = Math_fround(0), $1518 = Math_fround(0), $1519 = Math_fround(0), $152 = Math_fround(0), $1520 = Math_fround(0), $1521 = Math_fround(0), $1522 = Math_fround(0), $1523 = Math_fround(0), $1524 = Math_fround(0), $1525 = Math_fround(0), $1526 = 0, $1527 = Math_fround(0);
 var $1528 = Math_fround(0), $1529 = Math_fround(0), $153 = Math_fround(0), $1530 = Math_fround(0), $1531 = 0, $1532 = Math_fround(0), $1533 = Math_fround(0), $1534 = Math_fround(0), $1535 = Math_fround(0), $1536 = 0, $1537 = Math_fround(0), $1538 = Math_fround(0), $1539 = Math_fround(0), $154 = Math_fround(0), $1540 = Math_fround(0), $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0;
 var $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = Math_fround(0), $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = Math_fround(0), $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0;
 var $1564 = 0, $1565 = 0, $1566 = 0, $1567 = Math_fround(0), $1568 = Math_fround(0), $1569 = Math_fround(0), $157 = Math_fround(0), $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = Math_fround(0), $1580 = 0, $1581 = 0;
 var $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = Math_fround(0), $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0;
 var $160 = Math_fround(0), $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = Math_fround(0), $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0;
 var $1618 = 0, $1619 = 0, $162 = Math_fround(0), $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = Math_fround(0), $1628 = 0, $1629 = 0, $163 = Math_fround(0), $1630 = Math_fround(0), $1631 = 0, $1632 = 0, $1633 = Math_fround(0), $1634 = 0, $1635 = 0;
 var $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = Math_fround(0), $1640 = 0, $1641 = 0, $1642 = 0, $1643 = Math_fround(0), $1644 = 0, $1645 = 0, $1646 = Math_fround(0), $1647 = 0, $1648 = 0, $1649 = Math_fround(0), $165 = Math_fround(0), $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0;
 var $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = Math_fround(0), $1660 = 0, $1661 = Math_fround(0), $1662 = 0, $1663 = 0, $1664 = Math_fround(0), $1665 = 0, $1666 = 0, $1667 = Math_fround(0), $1668 = 0, $1669 = 0, $167 = Math_fround(0), $1670 = 0, $1671 = 0;
 var $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = Math_fround(0), $1680 = 0, $1681 = 0, $1682 = 0, $1683 = Math_fround(0), $1684 = 0, $1685 = 0, $1686 = Math_fround(0), $1687 = 0, $1688 = 0, $1689 = Math_fround(0), $169 = Math_fround(0);
 var $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $1700 = 0, $1701 = 0, $1702 = Math_fround(0), $1703 = 0, $1704 = 0, $1705 = Math_fround(0), $1706 = 0, $1707 = 0;
 var $1708 = 0, $1709 = 0, $171 = Math_fround(0), $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = Math_fround(0), $1718 = 0, $1719 = 0, $172 = Math_fround(0), $1720 = Math_fround(0), $1721 = 0, $1722 = 0, $1723 = Math_fround(0), $1724 = 0, $1725 = 0;
 var $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = Math_fround(0), $1730 = Math_fround(0), $1731 = 0, $1732 = Math_fround(0), $1733 = 0, $1734 = Math_fround(0), $1735 = 0, $1736 = Math_fround(0), $1737 = 0, $1738 = Math_fround(0), $1739 = 0, $174 = Math_fround(0), $1740 = Math_fround(0), $1741 = 0, $1742 = Math_fround(0), $1743 = 0;
 var $1744 = Math_fround(0), $1745 = 0, $1746 = Math_fround(0), $1747 = 0, $1748 = Math_fround(0), $1749 = 0, $175 = Math_fround(0), $1750 = Math_fround(0), $1751 = 0, $1752 = Math_fround(0), $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = Math_fround(0), $1758 = Math_fround(0), $1759 = Math_fround(0), $176 = Math_fround(0), $1760 = Math_fround(0), $1761 = 0;
 var $1762 = Math_fround(0), $1763 = Math_fround(0), $1764 = Math_fround(0), $1765 = Math_fround(0), $1766 = Math_fround(0), $1767 = Math_fround(0), $1768 = Math_fround(0), $1769 = 0, $177 = Math_fround(0), $1770 = Math_fround(0), $1771 = Math_fround(0), $1772 = Math_fround(0), $1773 = Math_fround(0), $1774 = Math_fround(0), $1775 = Math_fround(0), $1776 = Math_fround(0), $1777 = Math_fround(0), $1778 = Math_fround(0), $1779 = Math_fround(0), $178 = Math_fround(0);
 var $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = Math_fround(0), $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = Math_fround(0), $1795 = Math_fround(0), $1796 = Math_fround(0), $1797 = Math_fround(0), $1798 = 0;
 var $1799 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $1800 = Math_fround(0), $1801 = Math_fround(0), $1802 = Math_fround(0), $1803 = Math_fround(0), $1804 = Math_fround(0), $1805 = Math_fround(0), $1806 = 0, $1807 = Math_fround(0), $1808 = Math_fround(0), $1809 = Math_fround(0), $181 = Math_fround(0), $1810 = Math_fround(0), $1811 = Math_fround(0), $1812 = Math_fround(0), $1813 = Math_fround(0), $1814 = Math_fround(0), $1815 = Math_fround(0);
 var $1816 = Math_fround(0), $1817 = 0, $1818 = 0, $1819 = 0, $182 = Math_fround(0), $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = Math_fround(0), $1829 = 0, $183 = Math_fround(0), $1830 = 0, $1831 = Math_fround(0), $1832 = 0, $1833 = 0;
 var $1834 = Math_fround(0), $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = Math_fround(0), $1840 = Math_fround(0), $1841 = Math_fround(0), $1842 = Math_fround(0), $1843 = 0, $1844 = Math_fround(0), $1845 = Math_fround(0), $1846 = 0, $1847 = Math_fround(0), $1848 = Math_fround(0), $1849 = 0, $185 = Math_fround(0), $1850 = 0, $1851 = 0;
 var $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = Math_fround(0), $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = Math_fround(0), $1869 = 0, $187 = Math_fround(0);
 var $1870 = 0, $1871 = Math_fround(0), $1872 = 0, $1873 = 0, $1874 = Math_fround(0), $1875 = 0, $1876 = 0, $1877 = 0, $1878 = Math_fround(0), $1879 = 0, $188 = Math_fround(0), $1880 = 0, $1881 = Math_fround(0), $1882 = 0, $1883 = 0, $1884 = Math_fround(0), $1885 = 0, $1886 = 0, $1887 = 0, $1888 = Math_fround(0);
 var $1889 = 0, $189 = Math_fround(0), $1890 = 0, $1891 = Math_fround(0), $1892 = 0, $1893 = 0, $1894 = Math_fround(0), $1895 = 0, $1896 = 0, $1897 = Math_fround(0), $1898 = 0, $1899 = 0, $19 = 0, $190 = Math_fround(0), $1900 = Math_fround(0), $1901 = 0, $1902 = 0, $1903 = Math_fround(0), $1904 = 0, $1905 = 0;
 var $1906 = Math_fround(0), $1907 = 0, $1908 = 0, $1909 = Math_fround(0), $191 = Math_fround(0), $1910 = 0, $1911 = 0, $1912 = Math_fround(0), $1913 = 0, $1914 = 0, $1915 = Math_fround(0), $1916 = 0, $1917 = 0, $1918 = Math_fround(0), $1919 = 0, $192 = Math_fround(0), $1920 = 0, $1921 = Math_fround(0), $1922 = 0, $1923 = 0;
 var $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = Math_fround(0), $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = Math_fround(0), $1940 = 0, $1941 = 0;
 var $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = Math_fround(0), $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = Math_fround(0);
 var $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = Math_fround(0), $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0;
 var $1979 = 0, $198 = Math_fround(0), $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = Math_fround(0), $1990 = 0, $1991 = 0, $1992 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0;
 var $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0);
 var $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0);
 var $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0);
 var $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0);
 var $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0);
 var $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0);
 var $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0);
 var $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = 0, $615 = Math_fround(0), $616 = Math_fround(0);
 var $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = 0, $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0);
 var $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0);
 var $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0);
 var $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0);
 var $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0);
 var $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0);
 var $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0);
 var $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = 0;
 var $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0);
 var $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = 0, $796 = 0, $797 = 0;
 var $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0);
 var $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = Math_fround(0), $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = Math_fround(0), $830 = 0, $831 = 0, $832 = 0;
 var $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = Math_fround(0), $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0);
 var $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0);
 var $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0);
 var $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0);
 var $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = Math_fround(0), $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0);
 var $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = Math_fround(0), $940 = Math_fround(0);
 var $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = Math_fround(0), $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0);
 var $96 = Math_fround(0), $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = 0, $977 = 0;
 var $978 = 0, $979 = 0, $98 = Math_fround(0), $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = Math_fround(0), $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0;
 var $996 = 0, $997 = 0, $998 = 0, $999 = 0, $bboxCenter = 0, $bboxScale = 0, $clothPose = 0, $clothPose24 = 0, $curTriangles = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i17 = 0, $exitcond$i29 = 0, $exitcond$i44 = 0, $exitcond14$i = 0, $exitcond169 = 0, $exitcond171 = 0, $exitcond3$i = 0, $heightfieldPose = 0, $i$012$i = 0;
 var $i$0164 = 0, $i$02$us$i = 0, $i$05$i = 0, $i$05$i36 = 0, $i1$0159 = 0, $i14$0139 = 0, $i16$0132 = 0, $i21$0120 = 0, $i30$0114 = 0, $i4$0153 = 0, $i7$0149 = 0, $j$01$us$i = 0, $j$011$i = 0, $j$0143 = 0, $j20$0127 = 0, $j28$0116 = 0, $meshPose = 0, $notlhs = 0, $notlhs210 = 0, $notrhs = 0;
 var $notrhs211 = 0, $numVertices$0$lcssa = 0, $numVertices$0113 = 0, $numVertices$1 = 0, $or$cond = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2$not = 0, $or$cond$i$i3$not = 0, $or$cond$i$i5 = 0, $or$cond$i$i7 = 0, $or$cond208 = 0, $or$cond209 = 0, $phitmp = 0, $phitmp207 = 0, $plane = 0, $planes = 0, $polygon = 0, $prevTriangles = 0, $samples = 0;
 var $shapeIt$0$lcssa = 0, $shapeIt$0165 = 0, $shapeIt$1$lcssa = 0, $shapeIt$1160 = 0, $shapeIt$2$lcssa = 0, $shapeIt$2154 = 0, $shapeIt$3$lcssa = 0, $shapeIt$3150 = 0, $shapeIt$4$lcssa = 0, $shapeIt$4144 = 0, $shapeIt$5$lcssa = 0, $shapeIt$5133 = 0, $shapeIt$6121 = 0, $spheres = 0, $vertices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 896|0;
 $$byval_copy3 = sp + 728|0;
 $$byval_copy2 = sp + 644|0;
 $0 = sp + 888|0;
 $spheres = sp + 656|0;
 $1 = sp + 668|0;
 $2 = sp + 696|0;
 $3 = sp + 776|0;
 $4 = sp + 792|0;
 $5 = sp + 820|0;
 $6 = sp + 848|0;
 $7 = sp + 864|0;
 $8 = sp + 880|0;
 $planes = sp + 632|0;
 $9 = sp + 604|0;
 $10 = sp + 576|0;
 $plane = sp + 560|0;
 $11 = sp + 532|0;
 $12 = sp + 504|0;
 $13 = sp + 488|0;
 $14 = sp + 472|0;
 $15 = sp + 456|0;
 $16 = sp + 440|0;
 $17 = sp + 424|0;
 $18 = sp + 216|0;
 $19 = sp + 188|0;
 $20 = sp + 160|0;
 $21 = sp + 132|0;
 $polygon = sp + 112|0;
 $22 = sp + 96|0;
 $23 = sp + 56|0;
 $curTriangles = sp + 40|0;
 $prevTriangles = sp + 28|0;
 $clothPose = sp;
 $meshPose = sp + 64|0;
 $24 = sp + 232|0;
 $25 = sp + 890|0;
 $26 = sp + 260|0;
 $vertices = sp + 272|0;
 $samples = sp + 284|0;
 $clothPose24 = sp + 296|0;
 $heightfieldPose = sp + 324|0;
 $27 = sp + 352|0;
 $28 = sp + 364|0;
 $29 = sp + 376|0;
 $bboxCenter = sp + 380|0;
 $bboxScale = sp + 392|0;
 $30 = sp + 408|0;
 $31 = sp + 416|0;
 $32 = (($this) + 52|0);
 $33 = HEAP32[$32>>2]|0;
 __ZNK5physx2Sc9ClothCore13getClothFlagsEv($0,$33);
 $34 = HEAP16[$0>>1]|0;
 $35 = $34 & 4;
 $36 = ($35<<16>>16)==(0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = (Math_fround(__ZNK5physx2Sc9ClothCore13getRestOffsetEv($33)));
 $38 = (($this) + 116|0);
 $39 = HEAP32[$38>>2]|0;
 HEAP32[$spheres>>2] = 0;
 $40 = (($spheres) + 4|0);
 HEAP32[$40>>2] = 0;
 $41 = (($spheres) + 8|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 84|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0);
 L4: do {
  if ($44) {
   $shapeIt$0$lcssa = $39;
  } else {
   $45 = (($2) + 16|0);
   $46 = (($1) + 16|0);
   $47 = (($2) + 20|0);
   $48 = (($1) + 20|0);
   $49 = (($2) + 24|0);
   $50 = (($1) + 24|0);
   $51 = (($1) + 12|0);
   $52 = (($1) + 4|0);
   $53 = (($1) + 8|0);
   $54 = (($3) + 4|0);
   $55 = (($3) + 8|0);
   $56 = (($3) + 12|0);
   $132 = 0;$133 = 0;$i$0164 = 1;$shapeIt$0165 = $39;
   while(1) {
    $78 = HEAP32[$shapeIt$0165>>2]|0;
    $79 = (($78) + 28|0);
    $80 = HEAP32[$79>>2]|0;
    __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($1,$33);
    __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($2,$78);
    $81 = Math_fround(HEAPF32[$45>>2]);
    $82 = Math_fround(HEAPF32[$46>>2]);
    $83 = Math_fround($81 - $82);
    $84 = Math_fround(HEAPF32[$47>>2]);
    $85 = Math_fround(HEAPF32[$48>>2]);
    $86 = Math_fround($84 - $85);
    $87 = Math_fround(HEAPF32[$49>>2]);
    $88 = Math_fround(HEAPF32[$50>>2]);
    $89 = Math_fround($87 - $88);
    $90 = Math_fround($83 * Math_fround(2.0));
    $91 = Math_fround($86 * Math_fround(2.0));
    $92 = Math_fround($89 * Math_fround(2.0));
    $93 = Math_fround(HEAPF32[$51>>2]);
    $94 = Math_fround($93 * $93);
    $95 = Math_fround($94 + Math_fround(-0.5));
    $96 = Math_fround(HEAPF32[$1>>2]);
    $97 = Math_fround($90 * $96);
    $98 = Math_fround(HEAPF32[$52>>2]);
    $99 = Math_fround($91 * $98);
    $100 = Math_fround($97 + $99);
    $101 = Math_fround(HEAPF32[$53>>2]);
    $102 = Math_fround($92 * $101);
    $103 = Math_fround($100 + $102);
    $104 = Math_fround($90 * $95);
    $105 = Math_fround($92 * $98);
    $106 = Math_fround($91 * $101);
    $107 = Math_fround($105 - $106);
    $108 = Math_fround($93 * $107);
    $109 = Math_fround($104 - $108);
    $110 = Math_fround($96 * $103);
    $111 = Math_fround($110 + $109);
    $112 = Math_fround($91 * $95);
    $113 = Math_fround($90 * $101);
    $114 = Math_fround($92 * $96);
    $115 = Math_fround($113 - $114);
    $116 = Math_fround($93 * $115);
    $117 = Math_fround($112 - $116);
    $118 = Math_fround($98 * $103);
    $119 = Math_fround($118 + $117);
    $120 = Math_fround($92 * $95);
    $121 = Math_fround($91 * $96);
    $122 = Math_fround($90 * $98);
    $123 = Math_fround($121 - $122);
    $124 = Math_fround($93 * $123);
    $125 = Math_fround($120 - $124);
    $126 = Math_fround($101 * $103);
    $127 = Math_fround($125 + $126);
    $128 = (($80) + 72|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = Math_fround($37 + $129);
    HEAPF32[$3>>2] = $111;
    HEAPF32[$54>>2] = $119;
    HEAPF32[$55>>2] = $127;
    HEAPF32[$56>>2] = $130;
    $131 = ($132>>>0)>($133>>>0);
    if ($131) {
     $134 = HEAP32[$spheres>>2]|0;
     $135 = (($134) + ($133<<4)|0);
     $136 = ($135|0)==(0|0);
     if (!($136)) {
      HEAPF32[$135>>2] = $111;
      $137 = ((($134) + ($133<<4)|0) + 4|0);
      HEAPF32[$137>>2] = $119;
      $138 = ((($134) + ($133<<4)|0) + 8|0);
      HEAPF32[$138>>2] = $127;
      $139 = ((($134) + ($133<<4)|0) + 12|0);
      HEAPF32[$139>>2] = $130;
     }
     $140 = (($133) + 1)|0;
     HEAP32[$40>>2] = $140;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($spheres,$3)|0);
    }
    $141 = (($shapeIt$0165) + 4|0);
    $142 = HEAP32[$42>>2]|0;
    $143 = ($i$0164>>>0)<($142>>>0);
    if (!($143)) {
     $shapeIt$0$lcssa = $141;
     break L4;
    }
    $$pre205 = HEAP32[$41>>2]|0;
    $$pre206 = HEAP32[$40>>2]|0;
    $phitmp = $$pre205 & 2147483647;
    $phitmp207 = (($i$0164) + 1)|0;
    $132 = $phitmp;$133 = $$pre206;$i$0164 = $phitmp207;$shapeIt$0165 = $141;
   }
  }
 } while(0);
 $57 = (($this) + 88|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0);
 if ($59) {
  $shapeIt$1$lcssa = $shapeIt$0$lcssa;
 } else {
  $60 = (($4) + 4|0);
  $61 = (($4) + 8|0);
  $62 = (($4) + 12|0);
  $63 = (($5) + 16|0);
  $64 = (($4) + 16|0);
  $65 = (($5) + 20|0);
  $66 = (($4) + 20|0);
  $67 = (($5) + 24|0);
  $68 = (($4) + 24|0);
  $69 = (($5) + 12|0);
  $70 = (($5) + 8|0);
  $71 = (($5) + 4|0);
  $72 = (($6) + 4|0);
  $73 = (($6) + 8|0);
  $74 = (($6) + 12|0);
  $75 = (($7) + 4|0);
  $76 = (($7) + 8|0);
  $77 = (($7) + 12|0);
  $i1$0159 = 0;$shapeIt$1160 = $shapeIt$0$lcssa;
  while(1) {
   $144 = HEAP32[$shapeIt$1160>>2]|0;
   $145 = (($144) + 28|0);
   $146 = HEAP32[$145>>2]|0;
   __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($4,$33);
   __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($5,$144);
   $147 = Math_fround(HEAPF32[$4>>2]);
   $148 = Math_fround(-$147);
   $149 = Math_fround(HEAPF32[$60>>2]);
   $150 = Math_fround(-$149);
   $151 = Math_fround(HEAPF32[$61>>2]);
   $152 = Math_fround(-$151);
   $153 = Math_fround(HEAPF32[$62>>2]);
   $154 = Math_fround(HEAPF32[$63>>2]);
   $155 = Math_fround(HEAPF32[$64>>2]);
   $156 = Math_fround($154 - $155);
   $157 = Math_fround(HEAPF32[$65>>2]);
   $158 = Math_fround(HEAPF32[$66>>2]);
   $159 = Math_fround($157 - $158);
   $160 = Math_fround(HEAPF32[$67>>2]);
   $161 = Math_fround(HEAPF32[$68>>2]);
   $162 = Math_fround($160 - $161);
   $163 = Math_fround($156 * Math_fround(2.0));
   $164 = Math_fround($159 * Math_fround(2.0));
   $165 = Math_fround($162 * Math_fround(2.0));
   $166 = Math_fround($153 * $153);
   $167 = Math_fround($166 + Math_fround(-0.5));
   $168 = Math_fround($163 * $148);
   $169 = Math_fround($164 * $150);
   $170 = Math_fround($168 + $169);
   $171 = Math_fround($165 * $152);
   $172 = Math_fround($170 + $171);
   $173 = Math_fround($167 * $163);
   $174 = Math_fround($165 * $150);
   $175 = Math_fround($164 * $152);
   $176 = Math_fround($174 - $175);
   $177 = Math_fround($153 * $176);
   $178 = Math_fround($173 + $177);
   $179 = Math_fround($172 * $148);
   $180 = Math_fround($179 + $178);
   $181 = Math_fround($167 * $164);
   $182 = Math_fround($163 * $152);
   $183 = Math_fround($165 * $148);
   $184 = Math_fround($182 - $183);
   $185 = Math_fround($153 * $184);
   $186 = Math_fround($181 + $185);
   $187 = Math_fround($172 * $150);
   $188 = Math_fround($187 + $186);
   $189 = Math_fround($167 * $165);
   $190 = Math_fround($164 * $148);
   $191 = Math_fround($163 * $150);
   $192 = Math_fround($190 - $191);
   $193 = Math_fround($153 * $192);
   $194 = Math_fround($189 + $193);
   $195 = Math_fround($172 * $152);
   $196 = Math_fround($194 + $195);
   $197 = Math_fround(HEAPF32[$5>>2]);
   $198 = Math_fround($153 * $197);
   $199 = Math_fround(HEAPF32[$69>>2]);
   $200 = Math_fround($199 * $148);
   $201 = Math_fround($198 + $200);
   $202 = Math_fround(HEAPF32[$70>>2]);
   $203 = Math_fround($202 * $150);
   $204 = Math_fround($201 + $203);
   $205 = Math_fround(HEAPF32[$71>>2]);
   $206 = Math_fround($205 * $152);
   $207 = Math_fround($204 - $206);
   $208 = Math_fround($153 * $205);
   $209 = Math_fround($199 * $150);
   $210 = Math_fround($209 + $208);
   $211 = Math_fround($197 * $152);
   $212 = Math_fround($211 + $210);
   $213 = Math_fround($202 * $148);
   $214 = Math_fround($212 - $213);
   $215 = Math_fround($153 * $202);
   $216 = Math_fround($199 * $152);
   $217 = Math_fround($216 + $215);
   $218 = Math_fround($205 * $148);
   $219 = Math_fround($218 + $217);
   $220 = Math_fround($197 * $150);
   $221 = Math_fround($219 - $220);
   $222 = Math_fround($153 * $199);
   $223 = Math_fround($197 * $148);
   $224 = Math_fround($222 - $223);
   $225 = Math_fround($205 * $150);
   $226 = Math_fround($224 - $225);
   $227 = Math_fround($202 * $152);
   $228 = Math_fround($226 - $227);
   $229 = (($146) + 76|0);
   $230 = Math_fround(HEAPF32[$229>>2]);
   $231 = Math_fround($230 * Math_fround(2.0));
   $232 = Math_fround($228 * $228);
   $233 = Math_fround($232 + Math_fround(-0.5));
   $234 = Math_fround($231 * $207);
   $235 = Math_fround($214 * Math_fround(0.0));
   $236 = Math_fround($234 + $235);
   $237 = Math_fround($221 * Math_fround(0.0));
   $238 = Math_fround($237 + $236);
   $239 = Math_fround($231 * $233);
   $240 = Math_fround($235 - $237);
   $241 = Math_fround($228 * $240);
   $242 = Math_fround($239 + $241);
   $243 = Math_fround($207 * $238);
   $244 = Math_fround($243 + $242);
   $245 = Math_fround($233 * Math_fround(0.0));
   $246 = Math_fround($231 * $221);
   $247 = Math_fround($207 * Math_fround(0.0));
   $248 = Math_fround($246 - $247);
   $249 = Math_fround($228 * $248);
   $250 = Math_fround($245 + $249);
   $251 = Math_fround($214 * $238);
   $252 = Math_fround($250 + $251);
   $253 = Math_fround($231 * $214);
   $254 = Math_fround($247 - $253);
   $255 = Math_fround($228 * $254);
   $256 = Math_fround($245 + $255);
   $257 = Math_fround($221 * $238);
   $258 = Math_fround($256 + $257);
   $259 = (($146) + 72|0);
   $260 = Math_fround(HEAPF32[$259>>2]);
   $261 = Math_fround($37 + $260);
   $262 = Math_fround($180 - $244);
   $263 = Math_fround($188 - $252);
   $264 = Math_fround($196 - $258);
   HEAPF32[$6>>2] = $262;
   HEAPF32[$72>>2] = $263;
   HEAPF32[$73>>2] = $264;
   HEAPF32[$74>>2] = $261;
   $265 = HEAP32[$41>>2]|0;
   $266 = $265 & 2147483647;
   $267 = HEAP32[$40>>2]|0;
   $268 = ($266>>>0)>($267>>>0);
   if ($268) {
    $269 = HEAP32[$spheres>>2]|0;
    $270 = (($269) + ($267<<4)|0);
    $271 = ($270|0)==(0|0);
    if (!($271)) {
     HEAPF32[$270>>2] = $262;
     $272 = ((($269) + ($267<<4)|0) + 4|0);
     HEAPF32[$272>>2] = $263;
     $273 = ((($269) + ($267<<4)|0) + 8|0);
     HEAPF32[$273>>2] = $264;
     $274 = ((($269) + ($267<<4)|0) + 12|0);
     HEAPF32[$274>>2] = $261;
    }
    $275 = (($267) + 1)|0;
    HEAP32[$40>>2] = $275;
    $280 = $265;$282 = $275;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($spheres,$6)|0);
    $$pre186 = HEAP32[$41>>2]|0;
    $$pre187 = HEAP32[$40>>2]|0;
    $280 = $$pre186;$282 = $$pre187;
   }
   $276 = Math_fround($180 + $244);
   $277 = Math_fround($188 + $252);
   $278 = Math_fround($196 + $258);
   HEAPF32[$7>>2] = $276;
   HEAPF32[$75>>2] = $277;
   HEAPF32[$76>>2] = $278;
   HEAPF32[$77>>2] = $261;
   $279 = $280 & 2147483647;
   $281 = ($279>>>0)>($282>>>0);
   if ($281) {
    $283 = HEAP32[$spheres>>2]|0;
    $284 = (($283) + ($282<<4)|0);
    $285 = ($284|0)==(0|0);
    if (!($285)) {
     HEAPF32[$284>>2] = $276;
     $286 = ((($283) + ($282<<4)|0) + 4|0);
     HEAPF32[$286>>2] = $277;
     $287 = ((($283) + ($282<<4)|0) + 8|0);
     HEAPF32[$287>>2] = $278;
     $288 = ((($283) + ($282<<4)|0) + 12|0);
     HEAPF32[$288>>2] = $261;
    }
    $289 = (($282) + 1)|0;
    HEAP32[$40>>2] = $289;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($spheres,$7)|0);
   }
   $290 = (($i1$0159) + 1)|0;
   $291 = (($shapeIt$1160) + 4|0);
   $292 = HEAP32[$57>>2]|0;
   $293 = ($290>>>0)<($292>>>0);
   if ($293) {
    $i1$0159 = $290;$shapeIt$1160 = $291;
   } else {
    $shapeIt$1$lcssa = $291;
    break;
   }
  }
 }
 $294 = (($33) + 72|0);
 $295 = HEAP32[$294>>2]|0;
 $296 = HEAP32[$40>>2]|0;
 $297 = (($33) + 28|0);
 $298 = HEAP32[$297>>2]|0;
 $299 = HEAP32[$298>>2]|0;
 $300 = (($299) + 164|0);
 $301 = HEAP32[$300>>2]|0;
 $302 = HEAP32[$spheres>>2]|0;
 $303 = (($302) + ($296<<4)|0);
 HEAP32[$8>>2] = $302;
 $304 = (($8) + 4|0);
 HEAP32[$304>>2] = $303;
 $305 = (($296) + ($295))|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$8+4>>2]|0;
 FUNCTION_TABLE_viiii[$301 & 511]($298,$$byval_copy3,$295,$305);
 HEAP32[$planes>>2] = 0;
 $306 = (($planes) + 4|0);
 HEAP32[$306>>2] = 0;
 $307 = (($planes) + 8|0);
 HEAP32[$307>>2] = 0;
 $308 = (($this) + 92|0);
 $309 = HEAP32[$308>>2]|0;
 $310 = ($309|0)==(0);
 if ($310) {
  $shapeIt$2$lcssa = $shapeIt$1$lcssa;
 } else {
  $311 = (($9) + 4|0);
  $312 = (($9) + 8|0);
  $313 = (($9) + 12|0);
  $314 = (($10) + 16|0);
  $315 = (($9) + 16|0);
  $316 = (($10) + 20|0);
  $317 = (($9) + 20|0);
  $318 = (($10) + 24|0);
  $319 = (($9) + 24|0);
  $320 = (($10) + 12|0);
  $321 = (($10) + 8|0);
  $322 = (($10) + 4|0);
  $323 = (($plane) + 4|0);
  $324 = (($plane) + 8|0);
  $325 = (($plane) + 12|0);
  $i4$0153 = 0;$shapeIt$2154 = $shapeIt$1$lcssa;
  while(1) {
   $359 = HEAP32[$shapeIt$2154>>2]|0;
   __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($9,$33);
   __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($10,$359);
   $360 = Math_fround(HEAPF32[$9>>2]);
   $361 = Math_fround(-$360);
   $362 = Math_fround(HEAPF32[$311>>2]);
   $363 = Math_fround(-$362);
   $364 = Math_fround(HEAPF32[$312>>2]);
   $365 = Math_fround(-$364);
   $366 = Math_fround(HEAPF32[$313>>2]);
   $367 = Math_fround(HEAPF32[$314>>2]);
   $368 = Math_fround(HEAPF32[$315>>2]);
   $369 = Math_fround($367 - $368);
   $370 = Math_fround(HEAPF32[$316>>2]);
   $371 = Math_fround(HEAPF32[$317>>2]);
   $372 = Math_fround($370 - $371);
   $373 = Math_fround(HEAPF32[$318>>2]);
   $374 = Math_fround(HEAPF32[$319>>2]);
   $375 = Math_fround($373 - $374);
   $376 = Math_fround($369 * Math_fround(2.0));
   $377 = Math_fround($372 * Math_fround(2.0));
   $378 = Math_fround($375 * Math_fround(2.0));
   $379 = Math_fround($366 * $366);
   $380 = Math_fround($379 + Math_fround(-0.5));
   $381 = Math_fround($376 * $361);
   $382 = Math_fround($377 * $363);
   $383 = Math_fround($381 + $382);
   $384 = Math_fround($378 * $365);
   $385 = Math_fround($383 + $384);
   $386 = Math_fround($380 * $376);
   $387 = Math_fround($378 * $363);
   $388 = Math_fround($377 * $365);
   $389 = Math_fround($387 - $388);
   $390 = Math_fround($366 * $389);
   $391 = Math_fround($386 + $390);
   $392 = Math_fround($385 * $361);
   $393 = Math_fround($392 + $391);
   $394 = Math_fround($380 * $377);
   $395 = Math_fround($376 * $365);
   $396 = Math_fround($378 * $361);
   $397 = Math_fround($395 - $396);
   $398 = Math_fround($366 * $397);
   $399 = Math_fround($394 + $398);
   $400 = Math_fround($385 * $363);
   $401 = Math_fround($400 + $399);
   $402 = Math_fround($380 * $378);
   $403 = Math_fround($377 * $361);
   $404 = Math_fround($376 * $363);
   $405 = Math_fround($403 - $404);
   $406 = Math_fround($366 * $405);
   $407 = Math_fround($402 + $406);
   $408 = Math_fround($385 * $365);
   $409 = Math_fround($407 + $408);
   $410 = Math_fround(HEAPF32[$10>>2]);
   $411 = Math_fround($366 * $410);
   $412 = Math_fround(HEAPF32[$320>>2]);
   $413 = Math_fround($412 * $361);
   $414 = Math_fround($411 + $413);
   $415 = Math_fround(HEAPF32[$321>>2]);
   $416 = Math_fround($415 * $363);
   $417 = Math_fround($414 + $416);
   $418 = Math_fround(HEAPF32[$322>>2]);
   $419 = Math_fround($418 * $365);
   $420 = Math_fround($417 - $419);
   $421 = Math_fround($366 * $418);
   $422 = Math_fround($412 * $363);
   $423 = Math_fround($422 + $421);
   $424 = Math_fround($410 * $365);
   $425 = Math_fround($424 + $423);
   $426 = Math_fround($415 * $361);
   $427 = Math_fround($425 - $426);
   $428 = Math_fround($366 * $415);
   $429 = Math_fround($412 * $365);
   $430 = Math_fround($429 + $428);
   $431 = Math_fround($418 * $361);
   $432 = Math_fround($431 + $430);
   $433 = Math_fround($410 * $363);
   $434 = Math_fround($432 - $433);
   $435 = Math_fround($366 * $412);
   $436 = Math_fround($410 * $361);
   $437 = Math_fround($435 - $436);
   $438 = Math_fround($418 * $363);
   $439 = Math_fround($437 - $438);
   $440 = Math_fround($415 * $365);
   $441 = Math_fround($439 - $440);
   $442 = Math_fround($441 * $441);
   $443 = Math_fround($442 + Math_fround(-0.5));
   $444 = Math_fround($420 * Math_fround(2.0));
   $445 = Math_fround($427 * Math_fround(0.0));
   $446 = Math_fround($444 + $445);
   $447 = Math_fround($434 * Math_fround(0.0));
   $448 = Math_fround($447 + $446);
   $449 = Math_fround($443 * Math_fround(2.0));
   $450 = Math_fround($445 - $447);
   $451 = Math_fround($441 * $450);
   $452 = Math_fround($449 + $451);
   $453 = Math_fround($420 * $448);
   $454 = Math_fround($453 + $452);
   $455 = Math_fround($443 * Math_fround(0.0));
   $456 = Math_fround($434 * Math_fround(2.0));
   $457 = Math_fround($420 * Math_fround(0.0));
   $458 = Math_fround($456 - $457);
   $459 = Math_fround($441 * $458);
   $460 = Math_fround($455 + $459);
   $461 = Math_fround($427 * $448);
   $462 = Math_fround($460 + $461);
   $463 = Math_fround($427 * Math_fround(2.0));
   $464 = Math_fround($457 - $463);
   $465 = Math_fround($441 * $464);
   $466 = Math_fround($455 + $465);
   $467 = Math_fround($434 * $448);
   $468 = Math_fround($466 + $467);
   $469 = Math_fround($393 * $454);
   $470 = Math_fround($401 * $462);
   $471 = Math_fround($469 + $470);
   $472 = Math_fround($409 * $468);
   $473 = Math_fround($472 + $471);
   $474 = Math_fround(Math_fround(0.0) - $473);
   HEAPF32[$plane>>2] = $454;
   HEAPF32[$323>>2] = $462;
   HEAPF32[$324>>2] = $468;
   $475 = Math_fround($474 - $37);
   HEAPF32[$325>>2] = $475;
   $476 = HEAP32[$307>>2]|0;
   $477 = $476 & 2147483647;
   $478 = HEAP32[$306>>2]|0;
   $479 = ($477>>>0)>($478>>>0);
   if ($479) {
    $480 = HEAP32[$planes>>2]|0;
    $481 = (($480) + ($478<<4)|0);
    $482 = ($481|0)==(0|0);
    if (!($482)) {
     HEAPF32[$481>>2] = $454;
     $483 = ((($480) + ($478<<4)|0) + 4|0);
     HEAPF32[$483>>2] = $462;
     $484 = ((($480) + ($478<<4)|0) + 8|0);
     HEAPF32[$484>>2] = $468;
     $485 = ((($480) + ($478<<4)|0) + 12|0);
     HEAPF32[$485>>2] = $475;
    }
    $486 = (($478) + 1)|0;
    HEAP32[$306>>2] = $486;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$plane)|0);
   }
   $487 = (($i4$0153) + 1)|0;
   $488 = (($shapeIt$2154) + 4|0);
   $489 = HEAP32[$308>>2]|0;
   $490 = ($487>>>0)<($489>>>0);
   if ($490) {
    $i4$0153 = $487;$shapeIt$2154 = $488;
   } else {
    $shapeIt$2$lcssa = $488;
    break;
   }
  }
 }
 $326 = (($this) + 96|0);
 $327 = HEAP32[$326>>2]|0;
 $328 = ($327|0)==(0);
 if ($328) {
  $shapeIt$3$lcssa = $shapeIt$2$lcssa;
 } else {
  $329 = (($11) + 4|0);
  $330 = (($11) + 8|0);
  $331 = (($11) + 12|0);
  $332 = (($12) + 16|0);
  $333 = (($11) + 16|0);
  $334 = (($12) + 20|0);
  $335 = (($11) + 20|0);
  $336 = (($12) + 24|0);
  $337 = (($11) + 24|0);
  $338 = (($12) + 12|0);
  $339 = (($12) + 8|0);
  $340 = (($12) + 4|0);
  $341 = (($13) + 4|0);
  $342 = (($13) + 8|0);
  $343 = (($13) + 12|0);
  $344 = (($14) + 4|0);
  $345 = (($14) + 8|0);
  $346 = (($14) + 12|0);
  $347 = (($15) + 4|0);
  $348 = (($15) + 8|0);
  $349 = (($15) + 12|0);
  $350 = (($16) + 4|0);
  $351 = (($16) + 8|0);
  $352 = (($16) + 12|0);
  $353 = (($17) + 4|0);
  $354 = (($17) + 8|0);
  $355 = (($17) + 12|0);
  $356 = (($18) + 4|0);
  $357 = (($18) + 8|0);
  $358 = (($18) + 12|0);
  $i7$0149 = 0;$shapeIt$3150 = $shapeIt$2$lcssa;
  while(1) {
   $529 = HEAP32[$shapeIt$3150>>2]|0;
   $530 = (($529) + 28|0);
   $531 = HEAP32[$530>>2]|0;
   __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($11,$33);
   __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($12,$529);
   $532 = Math_fround(HEAPF32[$11>>2]);
   $533 = Math_fround(-$532);
   $534 = Math_fround(HEAPF32[$329>>2]);
   $535 = Math_fround(-$534);
   $536 = Math_fround(HEAPF32[$330>>2]);
   $537 = Math_fround(-$536);
   $538 = Math_fround(HEAPF32[$331>>2]);
   $539 = Math_fround(HEAPF32[$332>>2]);
   $540 = Math_fround(HEAPF32[$333>>2]);
   $541 = Math_fround($539 - $540);
   $542 = Math_fround(HEAPF32[$334>>2]);
   $543 = Math_fround(HEAPF32[$335>>2]);
   $544 = Math_fround($542 - $543);
   $545 = Math_fround(HEAPF32[$336>>2]);
   $546 = Math_fround(HEAPF32[$337>>2]);
   $547 = Math_fround($545 - $546);
   $548 = Math_fround($541 * Math_fround(2.0));
   $549 = Math_fround($544 * Math_fround(2.0));
   $550 = Math_fround($547 * Math_fround(2.0));
   $551 = Math_fround($538 * $538);
   $552 = Math_fround($551 + Math_fround(-0.5));
   $553 = Math_fround($548 * $533);
   $554 = Math_fround($549 * $535);
   $555 = Math_fround($553 + $554);
   $556 = Math_fround($550 * $537);
   $557 = Math_fround($555 + $556);
   $558 = Math_fround($552 * $548);
   $559 = Math_fround($550 * $535);
   $560 = Math_fround($549 * $537);
   $561 = Math_fround($559 - $560);
   $562 = Math_fround($538 * $561);
   $563 = Math_fround($558 + $562);
   $564 = Math_fround($557 * $533);
   $565 = Math_fround($564 + $563);
   $566 = Math_fround($552 * $549);
   $567 = Math_fround($548 * $537);
   $568 = Math_fround($550 * $533);
   $569 = Math_fround($567 - $568);
   $570 = Math_fround($538 * $569);
   $571 = Math_fround($566 + $570);
   $572 = Math_fround($557 * $535);
   $573 = Math_fround($572 + $571);
   $574 = Math_fround($552 * $550);
   $575 = Math_fround($549 * $533);
   $576 = Math_fround($548 * $535);
   $577 = Math_fround($575 - $576);
   $578 = Math_fround($538 * $577);
   $579 = Math_fround($574 + $578);
   $580 = Math_fround($557 * $537);
   $581 = Math_fround($579 + $580);
   $582 = Math_fround(HEAPF32[$12>>2]);
   $583 = Math_fround($538 * $582);
   $584 = Math_fround(HEAPF32[$338>>2]);
   $585 = Math_fround($584 * $533);
   $586 = Math_fround($583 + $585);
   $587 = Math_fround(HEAPF32[$339>>2]);
   $588 = Math_fround($587 * $535);
   $589 = Math_fround($586 + $588);
   $590 = Math_fround(HEAPF32[$340>>2]);
   $591 = Math_fround($590 * $537);
   $592 = Math_fround($589 - $591);
   $593 = Math_fround($538 * $590);
   $594 = Math_fround($584 * $535);
   $595 = Math_fround($594 + $593);
   $596 = Math_fround($582 * $537);
   $597 = Math_fround($596 + $595);
   $598 = Math_fround($587 * $533);
   $599 = Math_fround($597 - $598);
   $600 = Math_fround($538 * $587);
   $601 = Math_fround($584 * $537);
   $602 = Math_fround($601 + $600);
   $603 = Math_fround($590 * $533);
   $604 = Math_fround($603 + $602);
   $605 = Math_fround($582 * $535);
   $606 = Math_fround($604 - $605);
   $607 = Math_fround($538 * $584);
   $608 = Math_fround($582 * $533);
   $609 = Math_fround($607 - $608);
   $610 = Math_fround($590 * $535);
   $611 = Math_fround($609 - $610);
   $612 = Math_fround($587 * $537);
   $613 = Math_fround($611 - $612);
   $614 = (($531) + 72|0);
   $615 = Math_fround(HEAPF32[$614>>2]);
   $616 = Math_fround($37 + $615);
   $617 = (($531) + 76|0);
   $618 = Math_fround(HEAPF32[$617>>2]);
   $619 = Math_fround($37 + $618);
   $620 = (($531) + 80|0);
   $621 = Math_fround(HEAPF32[$620>>2]);
   $622 = Math_fround($37 + $621);
   $623 = Math_fround(-$616);
   $624 = Math_fround($613 * $613);
   $625 = Math_fround($624 + Math_fround(-0.5));
   $626 = Math_fround($592 * Math_fround(2.0));
   $627 = Math_fround($599 * Math_fround(0.0));
   $628 = Math_fround($626 + $627);
   $629 = Math_fround($606 * Math_fround(0.0));
   $630 = Math_fround($629 + $628);
   $631 = Math_fround($625 * Math_fround(2.0));
   $632 = Math_fround($627 - $629);
   $633 = Math_fround($613 * $632);
   $634 = Math_fround($631 + $633);
   $635 = Math_fround($592 * $630);
   $636 = Math_fround($635 + $634);
   $637 = Math_fround($625 * Math_fround(0.0));
   $638 = Math_fround($606 * Math_fround(2.0));
   $639 = Math_fround($592 * Math_fround(0.0));
   $640 = Math_fround($638 - $639);
   $641 = Math_fround($613 * $640);
   $642 = Math_fround($637 + $641);
   $643 = Math_fround($599 * $630);
   $644 = Math_fround($642 + $643);
   $645 = Math_fround($599 * Math_fround(2.0));
   $646 = Math_fround($639 - $645);
   $647 = Math_fround($613 * $646);
   $648 = Math_fround($637 + $647);
   $649 = Math_fround($606 * $630);
   $650 = Math_fround($648 + $649);
   $651 = Math_fround($565 * $636);
   $652 = Math_fround($573 * $644);
   $653 = Math_fround($651 + $652);
   $654 = Math_fround($581 * $650);
   $655 = Math_fround($654 + $653);
   $656 = Math_fround($623 - $655);
   HEAPF32[$13>>2] = $636;
   HEAPF32[$341>>2] = $644;
   HEAPF32[$342>>2] = $650;
   HEAPF32[$343>>2] = $656;
   $657 = HEAP32[$307>>2]|0;
   $658 = $657 & 2147483647;
   $659 = HEAP32[$306>>2]|0;
   $660 = ($658>>>0)>($659>>>0);
   if ($660) {
    $661 = HEAP32[$planes>>2]|0;
    $662 = (($661) + ($659<<4)|0);
    $663 = ($662|0)==(0|0);
    if (!($663)) {
     HEAPF32[$662>>2] = $636;
     $664 = ((($661) + ($659<<4)|0) + 4|0);
     HEAPF32[$664>>2] = $644;
     $665 = ((($661) + ($659<<4)|0) + 8|0);
     HEAPF32[$665>>2] = $650;
     $666 = ((($661) + ($659<<4)|0) + 12|0);
     HEAPF32[$666>>2] = $656;
    }
    $667 = (($659) + 1)|0;
    HEAP32[$306>>2] = $667;
    $694 = $657;$696 = $667;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$13)|0);
    $$pre = HEAP32[$307>>2]|0;
    $$pre177 = HEAP32[$306>>2]|0;
    $694 = $$pre;$696 = $$pre177;
   }
   $668 = Math_fround($592 * Math_fround(-2.0));
   $669 = Math_fround($668 + $627);
   $670 = Math_fround($629 + $669);
   $671 = Math_fround($625 * Math_fround(-2.0));
   $672 = Math_fround($671 + $633);
   $673 = Math_fround($592 * $670);
   $674 = Math_fround($673 + $672);
   $675 = Math_fround($606 * Math_fround(-2.0));
   $676 = Math_fround($675 - $639);
   $677 = Math_fround($613 * $676);
   $678 = Math_fround($637 + $677);
   $679 = Math_fround($599 * $670);
   $680 = Math_fround($678 + $679);
   $681 = Math_fround($599 * Math_fround(-2.0));
   $682 = Math_fround($639 - $681);
   $683 = Math_fround($613 * $682);
   $684 = Math_fround($637 + $683);
   $685 = Math_fround($606 * $670);
   $686 = Math_fround($684 + $685);
   $687 = Math_fround($565 * $674);
   $688 = Math_fround($573 * $680);
   $689 = Math_fround($687 + $688);
   $690 = Math_fround($581 * $686);
   $691 = Math_fround($690 + $689);
   $692 = Math_fround($623 - $691);
   HEAPF32[$14>>2] = $674;
   HEAPF32[$344>>2] = $680;
   HEAPF32[$345>>2] = $686;
   HEAPF32[$346>>2] = $692;
   $693 = $694 & 2147483647;
   $695 = ($693>>>0)>($696>>>0);
   if ($695) {
    $697 = HEAP32[$planes>>2]|0;
    $698 = (($697) + ($696<<4)|0);
    $699 = ($698|0)==(0|0);
    if (!($699)) {
     HEAPF32[$698>>2] = $674;
     $700 = ((($697) + ($696<<4)|0) + 4|0);
     HEAPF32[$700>>2] = $680;
     $701 = ((($697) + ($696<<4)|0) + 8|0);
     HEAPF32[$701>>2] = $686;
     $702 = ((($697) + ($696<<4)|0) + 12|0);
     HEAPF32[$702>>2] = $692;
    }
    $703 = (($696) + 1)|0;
    HEAP32[$306>>2] = $703;
    $729 = $694;$731 = $703;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$14)|0);
    $$pre178 = HEAP32[$307>>2]|0;
    $$pre179 = HEAP32[$306>>2]|0;
    $729 = $$pre178;$731 = $$pre179;
   }
   $704 = Math_fround(-$619);
   $705 = Math_fround($639 + $645);
   $706 = Math_fround($629 + $705);
   $707 = Math_fround($627 - $638);
   $708 = Math_fround($613 * $707);
   $709 = Math_fround($637 + $708);
   $710 = Math_fround($592 * $706);
   $711 = Math_fround($710 + $709);
   $712 = Math_fround($629 - $639);
   $713 = Math_fround($613 * $712);
   $714 = Math_fround($631 + $713);
   $715 = Math_fround($599 * $706);
   $716 = Math_fround($714 + $715);
   $717 = Math_fround($626 - $627);
   $718 = Math_fround($613 * $717);
   $719 = Math_fround($637 + $718);
   $720 = Math_fround($606 * $706);
   $721 = Math_fround($719 + $720);
   $722 = Math_fround($565 * $711);
   $723 = Math_fround($573 * $716);
   $724 = Math_fround($722 + $723);
   $725 = Math_fround($581 * $721);
   $726 = Math_fround($725 + $724);
   $727 = Math_fround($704 - $726);
   HEAPF32[$15>>2] = $711;
   HEAPF32[$347>>2] = $716;
   HEAPF32[$348>>2] = $721;
   HEAPF32[$349>>2] = $727;
   $728 = $729 & 2147483647;
   $730 = ($728>>>0)>($731>>>0);
   if ($730) {
    $732 = HEAP32[$planes>>2]|0;
    $733 = (($732) + ($731<<4)|0);
    $734 = ($733|0)==(0|0);
    if (!($734)) {
     HEAPF32[$733>>2] = $711;
     $735 = ((($732) + ($731<<4)|0) + 4|0);
     HEAPF32[$735>>2] = $716;
     $736 = ((($732) + ($731<<4)|0) + 8|0);
     HEAPF32[$736>>2] = $721;
     $737 = ((($732) + ($731<<4)|0) + 12|0);
     HEAPF32[$737>>2] = $727;
    }
    $738 = (($731) + 1)|0;
    HEAP32[$306>>2] = $738;
    $761 = $729;$763 = $738;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$15)|0);
    $$pre180 = HEAP32[$307>>2]|0;
    $$pre181 = HEAP32[$306>>2]|0;
    $761 = $$pre180;$763 = $$pre181;
   }
   $739 = Math_fround($639 + $681);
   $740 = Math_fround($629 + $739);
   $741 = Math_fround($627 - $675);
   $742 = Math_fround($613 * $741);
   $743 = Math_fround($637 + $742);
   $744 = Math_fround($592 * $740);
   $745 = Math_fround($744 + $743);
   $746 = Math_fround($671 + $713);
   $747 = Math_fround($599 * $740);
   $748 = Math_fround($746 + $747);
   $749 = Math_fround($668 - $627);
   $750 = Math_fround($613 * $749);
   $751 = Math_fround($637 + $750);
   $752 = Math_fround($606 * $740);
   $753 = Math_fround($751 + $752);
   $754 = Math_fround($565 * $745);
   $755 = Math_fround($573 * $748);
   $756 = Math_fround($754 + $755);
   $757 = Math_fround($581 * $753);
   $758 = Math_fround($757 + $756);
   $759 = Math_fround($704 - $758);
   HEAPF32[$16>>2] = $745;
   HEAPF32[$350>>2] = $748;
   HEAPF32[$351>>2] = $753;
   HEAPF32[$352>>2] = $759;
   $760 = $761 & 2147483647;
   $762 = ($760>>>0)>($763>>>0);
   if ($762) {
    $764 = HEAP32[$planes>>2]|0;
    $765 = (($764) + ($763<<4)|0);
    $766 = ($765|0)==(0|0);
    if (!($766)) {
     HEAPF32[$765>>2] = $745;
     $767 = ((($764) + ($763<<4)|0) + 4|0);
     HEAPF32[$767>>2] = $748;
     $768 = ((($764) + ($763<<4)|0) + 8|0);
     HEAPF32[$768>>2] = $753;
     $769 = ((($764) + ($763<<4)|0) + 12|0);
     HEAPF32[$769>>2] = $759;
    }
    $770 = (($763) + 1)|0;
    HEAP32[$306>>2] = $770;
    $796 = $761;$798 = $770;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$16)|0);
    $$pre182 = HEAP32[$307>>2]|0;
    $$pre183 = HEAP32[$306>>2]|0;
    $796 = $$pre182;$798 = $$pre183;
   }
   $771 = Math_fround(-$622);
   $772 = Math_fround($639 + $627);
   $773 = Math_fround($638 + $772);
   $774 = Math_fround($645 - $629);
   $775 = Math_fround($613 * $774);
   $776 = Math_fround($637 + $775);
   $777 = Math_fround($592 * $773);
   $778 = Math_fround($777 + $776);
   $779 = Math_fround($629 - $626);
   $780 = Math_fround($613 * $779);
   $781 = Math_fround($637 + $780);
   $782 = Math_fround($599 * $773);
   $783 = Math_fround($781 + $782);
   $784 = Math_fround($639 - $627);
   $785 = Math_fround($613 * $784);
   $786 = Math_fround($631 + $785);
   $787 = Math_fround($606 * $773);
   $788 = Math_fround($786 + $787);
   $789 = Math_fround($565 * $778);
   $790 = Math_fround($573 * $783);
   $791 = Math_fround($789 + $790);
   $792 = Math_fround($581 * $788);
   $793 = Math_fround($792 + $791);
   $794 = Math_fround($771 - $793);
   HEAPF32[$17>>2] = $778;
   HEAPF32[$353>>2] = $783;
   HEAPF32[$354>>2] = $788;
   HEAPF32[$355>>2] = $794;
   $795 = $796 & 2147483647;
   $797 = ($795>>>0)>($798>>>0);
   if ($797) {
    $799 = HEAP32[$planes>>2]|0;
    $800 = (($799) + ($798<<4)|0);
    $801 = ($800|0)==(0|0);
    if (!($801)) {
     HEAPF32[$800>>2] = $778;
     $802 = ((($799) + ($798<<4)|0) + 4|0);
     HEAPF32[$802>>2] = $783;
     $803 = ((($799) + ($798<<4)|0) + 8|0);
     HEAPF32[$803>>2] = $788;
     $804 = ((($799) + ($798<<4)|0) + 12|0);
     HEAPF32[$804>>2] = $794;
    }
    $805 = (($798) + 1)|0;
    HEAP32[$306>>2] = $805;
    $827 = $796;$829 = $805;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$17)|0);
    $$pre184 = HEAP32[$307>>2]|0;
    $$pre185 = HEAP32[$306>>2]|0;
    $827 = $$pre184;$829 = $$pre185;
   }
   $806 = Math_fround($675 + $772);
   $807 = Math_fround($681 - $629);
   $808 = Math_fround($613 * $807);
   $809 = Math_fround($637 + $808);
   $810 = Math_fround($592 * $806);
   $811 = Math_fround($810 + $809);
   $812 = Math_fround($629 - $668);
   $813 = Math_fround($613 * $812);
   $814 = Math_fround($637 + $813);
   $815 = Math_fround($599 * $806);
   $816 = Math_fround($814 + $815);
   $817 = Math_fround($671 + $785);
   $818 = Math_fround($606 * $806);
   $819 = Math_fround($817 + $818);
   $820 = Math_fround($565 * $811);
   $821 = Math_fround($573 * $816);
   $822 = Math_fround($820 + $821);
   $823 = Math_fround($581 * $819);
   $824 = Math_fround($823 + $822);
   $825 = Math_fround($771 - $824);
   HEAPF32[$18>>2] = $811;
   HEAPF32[$356>>2] = $816;
   HEAPF32[$357>>2] = $819;
   HEAPF32[$358>>2] = $825;
   $826 = $827 & 2147483647;
   $828 = ($826>>>0)>($829>>>0);
   if ($828) {
    $830 = HEAP32[$planes>>2]|0;
    $831 = (($830) + ($829<<4)|0);
    $832 = ($831|0)==(0|0);
    if (!($832)) {
     HEAPF32[$831>>2] = $811;
     $833 = ((($830) + ($829<<4)|0) + 4|0);
     HEAPF32[$833>>2] = $816;
     $834 = ((($830) + ($829<<4)|0) + 8|0);
     HEAPF32[$834>>2] = $819;
     $835 = ((($830) + ($829<<4)|0) + 12|0);
     HEAPF32[$835>>2] = $825;
    }
    $836 = (($829) + 1)|0;
    HEAP32[$306>>2] = $836;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$18)|0);
   }
   $837 = (($i7$0149) + 1)|0;
   $838 = (($shapeIt$3150) + 4|0);
   $839 = HEAP32[$326>>2]|0;
   $840 = ($837>>>0)<($839>>>0);
   if ($840) {
    $i7$0149 = $837;$shapeIt$3150 = $838;
   } else {
    $shapeIt$3$lcssa = $838;
    break;
   }
  }
 }
 $491 = (($this) + 100|0);
 $492 = HEAP32[$491>>2]|0;
 $493 = ($492|0)==(0);
 if ($493) {
  $shapeIt$4$lcssa = $shapeIt$3$lcssa;
 } else {
  $494 = (($20) + 4|0);
  $495 = (($20) + 8|0);
  $496 = (($20) + 12|0);
  $497 = (($21) + 16|0);
  $498 = (($20) + 16|0);
  $499 = (($21) + 20|0);
  $500 = (($20) + 20|0);
  $501 = (($21) + 24|0);
  $502 = (($20) + 24|0);
  $503 = (($21) + 12|0);
  $504 = (($21) + 8|0);
  $505 = (($21) + 4|0);
  $506 = (($19) + 4|0);
  $507 = (($19) + 8|0);
  $508 = (($19) + 12|0);
  $509 = (($19) + 16|0);
  $510 = (($19) + 20|0);
  $511 = (($19) + 24|0);
  $512 = (($$byval_copy3) + 4|0);
  $513 = (($$byval_copy3) + 8|0);
  $514 = (($polygon) + 4|0);
  $515 = (($$byval_copy3) + 12|0);
  $516 = (($$byval_copy3) + 16|0);
  $517 = (($$byval_copy3) + 20|0);
  $518 = (($polygon) + 8|0);
  $519 = (($$byval_copy3) + 24|0);
  $520 = (($$byval_copy3) + 28|0);
  $521 = (($$byval_copy3) + 32|0);
  $522 = (($polygon) + 12|0);
  $523 = (($$byval_copy3) + 36|0);
  $524 = (($$byval_copy3) + 40|0);
  $525 = (($$byval_copy3) + 44|0);
  $526 = (($22) + 4|0);
  $527 = (($22) + 8|0);
  $528 = (($22) + 12|0);
  $j$0143 = 0;$shapeIt$4144 = $shapeIt$3$lcssa;
  while(1) {
   $841 = HEAP32[$shapeIt$4144>>2]|0;
   $842 = (($841) + 28|0);
   $843 = HEAP32[$842>>2]|0;
   __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($20,$33);
   __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($21,$841);
   $844 = Math_fround(HEAPF32[$20>>2]);
   $845 = Math_fround(-$844);
   $846 = Math_fround(HEAPF32[$494>>2]);
   $847 = Math_fround(-$846);
   $848 = Math_fround(HEAPF32[$495>>2]);
   $849 = Math_fround(-$848);
   $850 = Math_fround(HEAPF32[$496>>2]);
   $851 = Math_fround(HEAPF32[$497>>2]);
   $852 = Math_fround(HEAPF32[$498>>2]);
   $853 = Math_fround($851 - $852);
   $854 = Math_fround(HEAPF32[$499>>2]);
   $855 = Math_fround(HEAPF32[$500>>2]);
   $856 = Math_fround($854 - $855);
   $857 = Math_fround(HEAPF32[$501>>2]);
   $858 = Math_fround(HEAPF32[$502>>2]);
   $859 = Math_fround($857 - $858);
   $860 = Math_fround($853 * Math_fround(2.0));
   $861 = Math_fround($856 * Math_fround(2.0));
   $862 = Math_fround($859 * Math_fround(2.0));
   $863 = Math_fround($850 * $850);
   $864 = Math_fround($863 + Math_fround(-0.5));
   $865 = Math_fround($860 * $845);
   $866 = Math_fround($861 * $847);
   $867 = Math_fround($865 + $866);
   $868 = Math_fround($862 * $849);
   $869 = Math_fround($867 + $868);
   $870 = Math_fround($864 * $860);
   $871 = Math_fround($862 * $847);
   $872 = Math_fround($861 * $849);
   $873 = Math_fround($871 - $872);
   $874 = Math_fround($850 * $873);
   $875 = Math_fround($870 + $874);
   $876 = Math_fround($869 * $845);
   $877 = Math_fround($876 + $875);
   $878 = Math_fround($864 * $861);
   $879 = Math_fround($860 * $849);
   $880 = Math_fround($862 * $845);
   $881 = Math_fround($879 - $880);
   $882 = Math_fround($850 * $881);
   $883 = Math_fround($878 + $882);
   $884 = Math_fround($869 * $847);
   $885 = Math_fround($884 + $883);
   $886 = Math_fround($864 * $862);
   $887 = Math_fround($861 * $845);
   $888 = Math_fround($860 * $847);
   $889 = Math_fround($887 - $888);
   $890 = Math_fround($850 * $889);
   $891 = Math_fround($886 + $890);
   $892 = Math_fround($869 * $849);
   $893 = Math_fround($891 + $892);
   $894 = Math_fround(HEAPF32[$21>>2]);
   $895 = Math_fround($850 * $894);
   $896 = Math_fround(HEAPF32[$503>>2]);
   $897 = Math_fround($896 * $845);
   $898 = Math_fround($895 + $897);
   $899 = Math_fround(HEAPF32[$504>>2]);
   $900 = Math_fround($899 * $847);
   $901 = Math_fround($898 + $900);
   $902 = Math_fround(HEAPF32[$505>>2]);
   $903 = Math_fround($902 * $849);
   $904 = Math_fround($901 - $903);
   $905 = Math_fround($850 * $902);
   $906 = Math_fround($896 * $847);
   $907 = Math_fround($906 + $905);
   $908 = Math_fround($894 * $849);
   $909 = Math_fround($908 + $907);
   $910 = Math_fround($899 * $845);
   $911 = Math_fround($909 - $910);
   $912 = Math_fround($850 * $899);
   $913 = Math_fround($896 * $849);
   $914 = Math_fround($913 + $912);
   $915 = Math_fround($902 * $845);
   $916 = Math_fround($915 + $914);
   $917 = Math_fround($894 * $847);
   $918 = Math_fround($916 - $917);
   $919 = Math_fround($850 * $896);
   $920 = Math_fround($894 * $845);
   $921 = Math_fround($919 - $920);
   $922 = Math_fround($902 * $847);
   $923 = Math_fround($921 - $922);
   $924 = Math_fround($899 * $849);
   $925 = Math_fround($923 - $924);
   HEAPF32[$19>>2] = $904;
   HEAPF32[$506>>2] = $911;
   HEAPF32[$507>>2] = $918;
   HEAPF32[$508>>2] = $925;
   HEAPF32[$509>>2] = $877;
   HEAPF32[$510>>2] = $885;
   HEAPF32[$511>>2] = $893;
   $926 = (($843) + 72|0);
   __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($$byval_copy3,$19,$926);
   $927 = (($843) + 100|0);
   $928 = HEAP32[$927>>2]|0;
   $929 = HEAP32[$928>>2]|0;
   $930 = (($929) + 36|0);
   $931 = HEAP32[$930>>2]|0;
   $932 = (FUNCTION_TABLE_ii[$931 & 4095]($928)|0);
   $933 = ($932|0)==(0);
   if (!($933)) {
    $934 = Math_fround(HEAPF32[$$byval_copy3>>2]);
    $935 = Math_fround(HEAPF32[$512>>2]);
    $936 = Math_fround(HEAPF32[$513>>2]);
    $937 = Math_fround(HEAPF32[$515>>2]);
    $938 = Math_fround(HEAPF32[$516>>2]);
    $939 = Math_fround(HEAPF32[$517>>2]);
    $940 = Math_fround(HEAPF32[$519>>2]);
    $941 = Math_fround(HEAPF32[$520>>2]);
    $942 = Math_fround(HEAPF32[$521>>2]);
    $943 = Math_fround(HEAPF32[$523>>2]);
    $944 = Math_fround(HEAPF32[$524>>2]);
    $945 = Math_fround(HEAPF32[$525>>2]);
    $i14$0139 = 0;
    while(1) {
     $946 = HEAP32[$927>>2]|0;
     $947 = HEAP32[$946>>2]|0;
     $948 = (($947) + 40|0);
     $949 = HEAP32[$948>>2]|0;
     (FUNCTION_TABLE_iiii[$949 & 2047]($946,$i14$0139,$polygon)|0);
     $950 = Math_fround(HEAPF32[$polygon>>2]);
     $951 = Math_fround($950 * $934);
     $952 = Math_fround($950 * $935);
     $953 = Math_fround($950 * $936);
     $954 = Math_fround(HEAPF32[$514>>2]);
     $955 = Math_fround($954 * $937);
     $956 = Math_fround($954 * $938);
     $957 = Math_fround($954 * $939);
     $958 = Math_fround($951 + $955);
     $959 = Math_fround($952 + $956);
     $960 = Math_fround($953 + $957);
     $961 = Math_fround(HEAPF32[$518>>2]);
     $962 = Math_fround($961 * $940);
     $963 = Math_fround($961 * $941);
     $964 = Math_fround($961 * $942);
     $965 = Math_fround($958 + $962);
     $966 = Math_fround($959 + $963);
     $967 = Math_fround($960 + $964);
     $968 = Math_fround(HEAPF32[$522>>2]);
     $969 = Math_fround($965 * $943);
     $970 = Math_fround($966 * $944);
     $971 = Math_fround($969 + $970);
     $972 = Math_fround($967 * $945);
     $973 = Math_fround($971 + $972);
     $974 = Math_fround($968 - $973);
     $975 = Math_fround($974 - $37);
     HEAPF32[$22>>2] = $965;
     HEAPF32[$526>>2] = $966;
     HEAPF32[$527>>2] = $967;
     HEAPF32[$528>>2] = $975;
     $976 = HEAP32[$307>>2]|0;
     $977 = $976 & 2147483647;
     $978 = HEAP32[$306>>2]|0;
     $979 = ($977>>>0)>($978>>>0);
     if ($979) {
      $980 = HEAP32[$planes>>2]|0;
      $981 = (($980) + ($978<<4)|0);
      $982 = ($981|0)==(0|0);
      if (!($982)) {
       HEAPF32[$981>>2] = $965;
       $983 = ((($980) + ($978<<4)|0) + 4|0);
       HEAPF32[$983>>2] = $966;
       $984 = ((($980) + ($978<<4)|0) + 8|0);
       HEAPF32[$984>>2] = $967;
       $985 = ((($980) + ($978<<4)|0) + 12|0);
       HEAPF32[$985>>2] = $975;
      }
      $986 = (($978) + 1)|0;
      HEAP32[$306>>2] = $986;
     } else {
      (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$22)|0);
     }
     $987 = (($i14$0139) + 1)|0;
     $exitcond171 = ($987|0)==($932|0);
     if ($exitcond171) {
      break;
     } else {
      $i14$0139 = $987;
     }
    }
   }
   $988 = (($j$0143) + 1)|0;
   $989 = (($shapeIt$4144) + 4|0);
   $990 = HEAP32[$491>>2]|0;
   $991 = ($988>>>0)<($990>>>0);
   if ($991) {
    $j$0143 = $988;$shapeIt$4144 = $989;
   } else {
    $shapeIt$4$lcssa = $989;
    break;
   }
  }
 }
 $992 = (($33) + 80|0);
 $993 = HEAP32[$992>>2]|0;
 $994 = HEAP32[$306>>2]|0;
 $995 = HEAP32[$297>>2]|0;
 $996 = HEAP32[$995>>2]|0;
 $997 = (($996) + 180|0);
 $998 = HEAP32[$997>>2]|0;
 $999 = HEAP32[$planes>>2]|0;
 $1000 = (($999) + ($994<<4)|0);
 HEAP32[$23>>2] = $999;
 $1001 = (($23) + 4|0);
 HEAP32[$1001>>2] = $1000;
 $1002 = (($994) + ($993))|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$23+4>>2]|0;
 FUNCTION_TABLE_viiii[$998 & 511]($995,$$byval_copy3,$993,$1002);
 HEAP32[$curTriangles>>2] = 0;
 $1003 = (($curTriangles) + 4|0);
 HEAP32[$1003>>2] = 0;
 $1004 = (($curTriangles) + 8|0);
 HEAP32[$1004>>2] = 0;
 HEAP32[$prevTriangles>>2] = 0;
 $1005 = (($prevTriangles) + 4|0);
 HEAP32[$1005>>2] = 0;
 $1006 = (($prevTriangles) + 8|0);
 HEAP32[$1006>>2] = 0;
 $1007 = (($this) + 104|0);
 $1008 = HEAP32[$1007>>2]|0;
 $1009 = ($1008|0)==(0);
 if ($1009) {
  $1991 = 0;$1992 = 0;$shapeIt$5$lcssa = $shapeIt$4$lcssa;
 } else {
  $1010 = (($clothPose) + 4|0);
  $1011 = (($clothPose) + 8|0);
  $1012 = (($clothPose) + 12|0);
  $1013 = (($meshPose) + 16|0);
  $1014 = (($clothPose) + 16|0);
  $1015 = (($meshPose) + 20|0);
  $1016 = (($clothPose) + 20|0);
  $1017 = (($meshPose) + 24|0);
  $1018 = (($clothPose) + 24|0);
  $1019 = (($meshPose) + 12|0);
  $1020 = (($meshPose) + 8|0);
  $1021 = (($meshPose) + 4|0);
  $1022 = (($24) + 4|0);
  $1023 = (($24) + 8|0);
  $1024 = (($24) + 12|0);
  $1025 = (($24) + 16|0);
  $1026 = (($24) + 20|0);
  $1027 = (($24) + 24|0);
  $1028 = (($this) + 128|0);
  $1029 = (($$byval_copy3) + 4|0);
  $1030 = (($$byval_copy3) + 8|0);
  $1031 = (($$byval_copy3) + 12|0);
  $1032 = (($$byval_copy3) + 16|0);
  $1033 = (($$byval_copy3) + 20|0);
  $1034 = (($$byval_copy3) + 24|0);
  $1035 = (($$byval_copy3) + 28|0);
  $1036 = (($$byval_copy3) + 32|0);
  $1037 = (($$byval_copy3) + 36|0);
  $1038 = (($$byval_copy3) + 40|0);
  $1039 = (($$byval_copy3) + 44|0);
  $1040 = (($26) + 4|0);
  $1041 = (($26) + 8|0);
  $i16$0132 = 0;$shapeIt$5133 = $shapeIt$4$lcssa;
  while(1) {
   $1042 = HEAP32[$shapeIt$5133>>2]|0;
   $1043 = (($1042) + 28|0);
   $1044 = HEAP32[$1043>>2]|0;
   __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($clothPose,$33);
   __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($meshPose,$1042);
   $1045 = Math_fround(HEAPF32[$clothPose>>2]);
   $1046 = Math_fround(-$1045);
   $1047 = Math_fround(HEAPF32[$1010>>2]);
   $1048 = Math_fround(-$1047);
   $1049 = Math_fround(HEAPF32[$1011>>2]);
   $1050 = Math_fround(-$1049);
   $1051 = Math_fround(HEAPF32[$1012>>2]);
   $1052 = Math_fround(HEAPF32[$1013>>2]);
   $1053 = Math_fround(HEAPF32[$1014>>2]);
   $1054 = Math_fround($1052 - $1053);
   $1055 = Math_fround(HEAPF32[$1015>>2]);
   $1056 = Math_fround(HEAPF32[$1016>>2]);
   $1057 = Math_fround($1055 - $1056);
   $1058 = Math_fround(HEAPF32[$1017>>2]);
   $1059 = Math_fround(HEAPF32[$1018>>2]);
   $1060 = Math_fround($1058 - $1059);
   $1061 = Math_fround($1054 * Math_fround(2.0));
   $1062 = Math_fround($1057 * Math_fround(2.0));
   $1063 = Math_fround($1060 * Math_fround(2.0));
   $1064 = Math_fround($1051 * $1051);
   $1065 = Math_fround($1064 + Math_fround(-0.5));
   $1066 = Math_fround($1061 * $1046);
   $1067 = Math_fround($1062 * $1048);
   $1068 = Math_fround($1066 + $1067);
   $1069 = Math_fround($1063 * $1050);
   $1070 = Math_fround($1068 + $1069);
   $1071 = Math_fround($1065 * $1061);
   $1072 = Math_fround($1063 * $1048);
   $1073 = Math_fround($1062 * $1050);
   $1074 = Math_fround($1072 - $1073);
   $1075 = Math_fround($1051 * $1074);
   $1076 = Math_fround($1071 + $1075);
   $1077 = Math_fround($1070 * $1046);
   $1078 = Math_fround($1077 + $1076);
   $1079 = Math_fround($1065 * $1062);
   $1080 = Math_fround($1061 * $1050);
   $1081 = Math_fround($1063 * $1046);
   $1082 = Math_fround($1080 - $1081);
   $1083 = Math_fround($1051 * $1082);
   $1084 = Math_fround($1079 + $1083);
   $1085 = Math_fround($1070 * $1048);
   $1086 = Math_fround($1085 + $1084);
   $1087 = Math_fround($1065 * $1063);
   $1088 = Math_fround($1062 * $1046);
   $1089 = Math_fround($1061 * $1048);
   $1090 = Math_fround($1088 - $1089);
   $1091 = Math_fround($1051 * $1090);
   $1092 = Math_fround($1087 + $1091);
   $1093 = Math_fround($1070 * $1050);
   $1094 = Math_fround($1092 + $1093);
   $1095 = Math_fround(HEAPF32[$meshPose>>2]);
   $1096 = Math_fround($1051 * $1095);
   $1097 = Math_fround(HEAPF32[$1019>>2]);
   $1098 = Math_fround($1097 * $1046);
   $1099 = Math_fround($1096 + $1098);
   $1100 = Math_fround(HEAPF32[$1020>>2]);
   $1101 = Math_fround($1100 * $1048);
   $1102 = Math_fround($1099 + $1101);
   $1103 = Math_fround(HEAPF32[$1021>>2]);
   $1104 = Math_fround($1103 * $1050);
   $1105 = Math_fround($1102 - $1104);
   $1106 = Math_fround($1051 * $1103);
   $1107 = Math_fround($1097 * $1048);
   $1108 = Math_fround($1107 + $1106);
   $1109 = Math_fround($1095 * $1050);
   $1110 = Math_fround($1109 + $1108);
   $1111 = Math_fround($1100 * $1046);
   $1112 = Math_fround($1110 - $1111);
   $1113 = Math_fround($1051 * $1100);
   $1114 = Math_fround($1097 * $1050);
   $1115 = Math_fround($1114 + $1113);
   $1116 = Math_fround($1103 * $1046);
   $1117 = Math_fround($1116 + $1115);
   $1118 = Math_fround($1095 * $1048);
   $1119 = Math_fround($1117 - $1118);
   $1120 = Math_fround($1051 * $1097);
   $1121 = Math_fround($1095 * $1046);
   $1122 = Math_fround($1120 - $1121);
   $1123 = Math_fround($1103 * $1048);
   $1124 = Math_fround($1122 - $1123);
   $1125 = Math_fround($1100 * $1050);
   $1126 = Math_fround($1124 - $1125);
   HEAPF32[$24>>2] = $1105;
   HEAPF32[$1022>>2] = $1112;
   HEAPF32[$1023>>2] = $1119;
   HEAPF32[$1024>>2] = $1126;
   HEAPF32[$1025>>2] = $1078;
   HEAPF32[$1026>>2] = $1086;
   HEAPF32[$1027>>2] = $1094;
   $1127 = (($1044) + 72|0);
   __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($$byval_copy3,$24,$1127);
   $1128 = HEAP32[$1003>>2]|0;
   $1129 = (($1044) + 104|0);
   $1130 = HEAP32[$1129>>2]|0;
   $1131 = HEAP32[$1130>>2]|0;
   $1132 = (($1131) + 40|0);
   $1133 = HEAP32[$1132>>2]|0;
   FUNCTION_TABLE_vii[$1133 & 4095]($25,$1130);
   $1134 = HEAP8[$25>>0]|0;
   $1135 = $1134 & 2;
   $1136 = ($1135<<24>>24)==(0);
   $1137 = HEAP32[$1129>>2]|0;
   $1138 = HEAP32[$1137>>2]|0;
   $1139 = (($1138) + 32|0);
   $1140 = HEAP32[$1139>>2]|0;
   $1141 = (FUNCTION_TABLE_ii[$1140 & 4095]($1137)|0);
   $1142 = HEAP32[$1137>>2]|0;
   $1143 = (($1142) + 36|0);
   $1144 = HEAP32[$1143>>2]|0;
   $1145 = (FUNCTION_TABLE_ii[$1144 & 4095]($1137)|0);
   L116: do {
    if ($1136) {
     $1212 = HEAP32[$1137>>2]|0;
     $1213 = (($1212) + 28|0);
     $1214 = HEAP32[$1213>>2]|0;
     $1215 = (FUNCTION_TABLE_ii[$1214 & 4095]($1137)|0);
     $1216 = ($1141|0)==(0);
     if (!($1216)) {
      $1224 = $1128;$i$05$i = 0;
      while(1) {
       $1217 = ($i$05$i*3)|0;
       $1218 = (($1145) + ($1217<<2)|0);
       $1219 = HEAP32[$1218>>2]|0;
       $1220 = (($1215) + (($1219*12)|0)|0);
       $1221 = HEAP32[$1004>>2]|0;
       $1222 = $1221 & 2147483647;
       $1223 = ($1222>>>0)>($1224>>>0);
       if ($1223) {
        $1225 = HEAP32[$curTriangles>>2]|0;
        $1226 = (($1225) + (($1224*12)|0)|0);
        $1227 = ($1226|0)==(0|0);
        if (!($1227)) {
         $1228 = Math_fround(HEAPF32[$1220>>2]);
         HEAPF32[$1226>>2] = $1228;
         $1229 = ((($1225) + (($1224*12)|0)|0) + 4|0);
         $1230 = ((($1215) + (($1219*12)|0)|0) + 4|0);
         $1231 = Math_fround(HEAPF32[$1230>>2]);
         HEAPF32[$1229>>2] = $1231;
         $1232 = ((($1225) + (($1224*12)|0)|0) + 8|0);
         $1233 = ((($1215) + (($1219*12)|0)|0) + 8|0);
         $1234 = Math_fround(HEAPF32[$1233>>2]);
         HEAPF32[$1232>>2] = $1234;
        }
        $1235 = (($1224) + 1)|0;
        HEAP32[$1003>>2] = $1235;
        $1241 = $1221;$1243 = $1235;
       } else {
        (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1220)|0);
        $$pre$i26 = HEAP32[$1004>>2]|0;
        $$pre6$i = HEAP32[$1003>>2]|0;
        $1241 = $$pre$i26;$1243 = $$pre6$i;
       }
       $1236 = (($1217) + 1)|0;
       $1237 = (($1145) + ($1236<<2)|0);
       $1238 = HEAP32[$1237>>2]|0;
       $1239 = (($1215) + (($1238*12)|0)|0);
       $1240 = $1241 & 2147483647;
       $1242 = ($1240>>>0)>($1243>>>0);
       if ($1242) {
        $1244 = HEAP32[$curTriangles>>2]|0;
        $1245 = (($1244) + (($1243*12)|0)|0);
        $1246 = ($1245|0)==(0|0);
        if (!($1246)) {
         $1247 = Math_fround(HEAPF32[$1239>>2]);
         HEAPF32[$1245>>2] = $1247;
         $1248 = ((($1244) + (($1243*12)|0)|0) + 4|0);
         $1249 = ((($1215) + (($1238*12)|0)|0) + 4|0);
         $1250 = Math_fround(HEAPF32[$1249>>2]);
         HEAPF32[$1248>>2] = $1250;
         $1251 = ((($1244) + (($1243*12)|0)|0) + 8|0);
         $1252 = ((($1215) + (($1238*12)|0)|0) + 8|0);
         $1253 = Math_fround(HEAPF32[$1252>>2]);
         HEAPF32[$1251>>2] = $1253;
        }
        $1254 = (($1243) + 1)|0;
        HEAP32[$1003>>2] = $1254;
        $1260 = $1241;$1262 = $1254;
       } else {
        (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1239)|0);
        $$pre7$i = HEAP32[$1004>>2]|0;
        $$pre8$i = HEAP32[$1003>>2]|0;
        $1260 = $$pre7$i;$1262 = $$pre8$i;
       }
       $1255 = (($1217) + 2)|0;
       $1256 = (($1145) + ($1255<<2)|0);
       $1257 = HEAP32[$1256>>2]|0;
       $1258 = (($1215) + (($1257*12)|0)|0);
       $1259 = $1260 & 2147483647;
       $1261 = ($1259>>>0)>($1262>>>0);
       if ($1261) {
        $1263 = HEAP32[$curTriangles>>2]|0;
        $1264 = (($1263) + (($1262*12)|0)|0);
        $1265 = ($1264|0)==(0|0);
        if (!($1265)) {
         $1266 = Math_fround(HEAPF32[$1258>>2]);
         HEAPF32[$1264>>2] = $1266;
         $1267 = ((($1263) + (($1262*12)|0)|0) + 4|0);
         $1268 = ((($1215) + (($1257*12)|0)|0) + 4|0);
         $1269 = Math_fround(HEAPF32[$1268>>2]);
         HEAPF32[$1267>>2] = $1269;
         $1270 = ((($1263) + (($1262*12)|0)|0) + 8|0);
         $1271 = ((($1215) + (($1257*12)|0)|0) + 8|0);
         $1272 = Math_fround(HEAPF32[$1271>>2]);
         HEAPF32[$1270>>2] = $1272;
        }
        $1273 = (($1262) + 1)|0;
        HEAP32[$1003>>2] = $1273;
       } else {
        (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1258)|0);
       }
       $1274 = (($i$05$i) + 1)|0;
       $exitcond$i29 = ($1274|0)==($1141|0);
       if ($exitcond$i29) {
        break L116;
       }
       $$pre191 = HEAP32[$1003>>2]|0;
       $1224 = $$pre191;$i$05$i = $1274;
      }
     }
    } else {
     $1146 = HEAP32[$1137>>2]|0;
     $1147 = (($1146) + 28|0);
     $1148 = HEAP32[$1147>>2]|0;
     $1149 = (FUNCTION_TABLE_ii[$1148 & 4095]($1137)|0);
     $1150 = ($1141|0)==(0);
     if (!($1150)) {
      $1159 = $1128;$i$05$i36 = 0;
      while(1) {
       $1151 = ($i$05$i36*3)|0;
       $1152 = (($1145) + ($1151<<1)|0);
       $1153 = HEAP16[$1152>>1]|0;
       $1154 = $1153&65535;
       $1155 = (($1149) + (($1154*12)|0)|0);
       $1156 = HEAP32[$1004>>2]|0;
       $1157 = $1156 & 2147483647;
       $1158 = ($1157>>>0)>($1159>>>0);
       if ($1158) {
        $1160 = HEAP32[$curTriangles>>2]|0;
        $1161 = (($1160) + (($1159*12)|0)|0);
        $1162 = ($1161|0)==(0|0);
        if (!($1162)) {
         $1163 = Math_fround(HEAPF32[$1155>>2]);
         HEAPF32[$1161>>2] = $1163;
         $1164 = ((($1160) + (($1159*12)|0)|0) + 4|0);
         $1165 = ((($1149) + (($1154*12)|0)|0) + 4|0);
         $1166 = Math_fround(HEAPF32[$1165>>2]);
         HEAPF32[$1164>>2] = $1166;
         $1167 = ((($1160) + (($1159*12)|0)|0) + 8|0);
         $1168 = ((($1149) + (($1154*12)|0)|0) + 8|0);
         $1169 = Math_fround(HEAPF32[$1168>>2]);
         HEAPF32[$1167>>2] = $1169;
        }
        $1170 = (($1159) + 1)|0;
        HEAP32[$1003>>2] = $1170;
        $1177 = $1156;$1179 = $1170;
       } else {
        (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1155)|0);
        $$pre$i38 = HEAP32[$1004>>2]|0;
        $$pre6$i39 = HEAP32[$1003>>2]|0;
        $1177 = $$pre$i38;$1179 = $$pre6$i39;
       }
       $1171 = (($1151) + 1)|0;
       $1172 = (($1145) + ($1171<<1)|0);
       $1173 = HEAP16[$1172>>1]|0;
       $1174 = $1173&65535;
       $1175 = (($1149) + (($1174*12)|0)|0);
       $1176 = $1177 & 2147483647;
       $1178 = ($1176>>>0)>($1179>>>0);
       if ($1178) {
        $1180 = HEAP32[$curTriangles>>2]|0;
        $1181 = (($1180) + (($1179*12)|0)|0);
        $1182 = ($1181|0)==(0|0);
        if (!($1182)) {
         $1183 = Math_fround(HEAPF32[$1175>>2]);
         HEAPF32[$1181>>2] = $1183;
         $1184 = ((($1180) + (($1179*12)|0)|0) + 4|0);
         $1185 = ((($1149) + (($1174*12)|0)|0) + 4|0);
         $1186 = Math_fround(HEAPF32[$1185>>2]);
         HEAPF32[$1184>>2] = $1186;
         $1187 = ((($1180) + (($1179*12)|0)|0) + 8|0);
         $1188 = ((($1149) + (($1174*12)|0)|0) + 8|0);
         $1189 = Math_fround(HEAPF32[$1188>>2]);
         HEAPF32[$1187>>2] = $1189;
        }
        $1190 = (($1179) + 1)|0;
        HEAP32[$1003>>2] = $1190;
        $1197 = $1177;$1199 = $1190;
       } else {
        (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1175)|0);
        $$pre7$i41 = HEAP32[$1004>>2]|0;
        $$pre8$i42 = HEAP32[$1003>>2]|0;
        $1197 = $$pre7$i41;$1199 = $$pre8$i42;
       }
       $1191 = (($1151) + 2)|0;
       $1192 = (($1145) + ($1191<<1)|0);
       $1193 = HEAP16[$1192>>1]|0;
       $1194 = $1193&65535;
       $1195 = (($1149) + (($1194*12)|0)|0);
       $1196 = $1197 & 2147483647;
       $1198 = ($1196>>>0)>($1199>>>0);
       if ($1198) {
        $1200 = HEAP32[$curTriangles>>2]|0;
        $1201 = (($1200) + (($1199*12)|0)|0);
        $1202 = ($1201|0)==(0|0);
        if (!($1202)) {
         $1203 = Math_fround(HEAPF32[$1195>>2]);
         HEAPF32[$1201>>2] = $1203;
         $1204 = ((($1200) + (($1199*12)|0)|0) + 4|0);
         $1205 = ((($1149) + (($1194*12)|0)|0) + 4|0);
         $1206 = Math_fround(HEAPF32[$1205>>2]);
         HEAPF32[$1204>>2] = $1206;
         $1207 = ((($1200) + (($1199*12)|0)|0) + 8|0);
         $1208 = ((($1149) + (($1194*12)|0)|0) + 8|0);
         $1209 = Math_fround(HEAPF32[$1208>>2]);
         HEAPF32[$1207>>2] = $1209;
        }
        $1210 = (($1199) + 1)|0;
        HEAP32[$1003>>2] = $1210;
       } else {
        (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1195)|0);
       }
       $1211 = (($i$05$i36) + 1)|0;
       $exitcond$i44 = ($1211|0)==($1141|0);
       if ($exitcond$i44) {
        break L116;
       }
       $$pre204 = HEAP32[$1003>>2]|0;
       $1159 = $$pre204;$i$05$i36 = $1211;
      }
     }
    }
   } while(0);
   $1275 = HEAP32[$1028>>2]|0;
   $1276 = (($1275) + (($i16$0132*48)|0)|0);
   $1277 = Math_fround(HEAPF32[$1276>>2]);
   $1278 = ((($1275) + (($i16$0132*48)|0)|0) + 4|0);
   $1279 = Math_fround(HEAPF32[$1278>>2]);
   $1280 = ((($1275) + (($i16$0132*48)|0)|0) + 8|0);
   $1281 = Math_fround(HEAPF32[$1280>>2]);
   $1282 = ((($1275) + (($i16$0132*48)|0)|0) + 12|0);
   $1283 = Math_fround(HEAPF32[$1282>>2]);
   $1284 = ((($1275) + (($i16$0132*48)|0)|0) + 16|0);
   $1285 = Math_fround(HEAPF32[$1284>>2]);
   $1286 = ((($1275) + (($i16$0132*48)|0)|0) + 20|0);
   $1287 = Math_fround(HEAPF32[$1286>>2]);
   $1288 = ((($1275) + (($i16$0132*48)|0)|0) + 24|0);
   $1289 = Math_fround(HEAPF32[$1288>>2]);
   $1290 = ((($1275) + (($i16$0132*48)|0)|0) + 28|0);
   $1291 = Math_fround(HEAPF32[$1290>>2]);
   $1292 = ((($1275) + (($i16$0132*48)|0)|0) + 32|0);
   $1293 = Math_fround(HEAPF32[$1292>>2]);
   $1294 = ((($1275) + (($i16$0132*48)|0)|0) + 36|0);
   $1295 = Math_fround(HEAPF32[$1294>>2]);
   $1296 = ((($1275) + (($i16$0132*48)|0)|0) + 40|0);
   $1297 = Math_fround(HEAPF32[$1296>>2]);
   $1298 = ((($1275) + (($i16$0132*48)|0)|0) + 44|0);
   $1299 = Math_fround(HEAPF32[$1298>>2]);
   $1300 = Math_fround(HEAPF32[$$byval_copy3>>2]);
   HEAPF32[$1276>>2] = $1300;
   $1301 = Math_fround(HEAPF32[$1029>>2]);
   HEAPF32[$1278>>2] = $1301;
   $1302 = Math_fround(HEAPF32[$1030>>2]);
   HEAPF32[$1280>>2] = $1302;
   $1303 = Math_fround(HEAPF32[$1031>>2]);
   HEAPF32[$1282>>2] = $1303;
   $1304 = Math_fround(HEAPF32[$1032>>2]);
   HEAPF32[$1284>>2] = $1304;
   $1305 = Math_fround(HEAPF32[$1033>>2]);
   HEAPF32[$1286>>2] = $1305;
   $1306 = Math_fround(HEAPF32[$1034>>2]);
   HEAPF32[$1288>>2] = $1306;
   $1307 = Math_fround(HEAPF32[$1035>>2]);
   HEAPF32[$1290>>2] = $1307;
   $1308 = Math_fround(HEAPF32[$1036>>2]);
   HEAPF32[$1292>>2] = $1308;
   $1309 = Math_fround(HEAPF32[$1037>>2]);
   HEAPF32[$1294>>2] = $1309;
   $1310 = Math_fround(HEAPF32[$1038>>2]);
   HEAPF32[$1296>>2] = $1310;
   $1311 = Math_fround(HEAPF32[$1039>>2]);
   HEAPF32[$1298>>2] = $1311;
   $1312 = HEAP32[$1003>>2]|0;
   $1313 = ($1128>>>0)<($1312>>>0);
   $1314 = HEAP32[$curTriangles>>2]|0;
   if ($1313) {
    $j20$0127 = $1128;
    while(1) {
     $1315 = (($1314) + (($j20$0127*12)|0)|0);
     $1316 = Math_fround(HEAPF32[$1315>>2]);
     $1317 = Math_fround($1277 * $1316);
     $1318 = Math_fround($1279 * $1316);
     $1319 = Math_fround($1281 * $1316);
     $1320 = ((($1314) + (($j20$0127*12)|0)|0) + 4|0);
     $1321 = Math_fround(HEAPF32[$1320>>2]);
     $1322 = Math_fround($1283 * $1321);
     $1323 = Math_fround($1285 * $1321);
     $1324 = Math_fround($1287 * $1321);
     $1325 = Math_fround($1317 + $1322);
     $1326 = Math_fround($1318 + $1323);
     $1327 = Math_fround($1319 + $1324);
     $1328 = ((($1314) + (($j20$0127*12)|0)|0) + 8|0);
     $1329 = Math_fround(HEAPF32[$1328>>2]);
     $1330 = Math_fround($1289 * $1329);
     $1331 = Math_fround($1291 * $1329);
     $1332 = Math_fround($1293 * $1329);
     $1333 = Math_fround($1325 + $1330);
     $1334 = Math_fround($1326 + $1331);
     $1335 = Math_fround($1327 + $1332);
     $1336 = Math_fround($1295 + $1333);
     $1337 = Math_fround($1297 + $1334);
     $1338 = Math_fround($1299 + $1335);
     HEAPF32[$26>>2] = $1336;
     HEAPF32[$1040>>2] = $1337;
     HEAPF32[$1041>>2] = $1338;
     $1339 = HEAP32[$1006>>2]|0;
     $1340 = $1339 & 2147483647;
     $1341 = HEAP32[$1005>>2]|0;
     $1342 = ($1340>>>0)>($1341>>>0);
     if ($1342) {
      $1343 = HEAP32[$prevTriangles>>2]|0;
      $1344 = (($1343) + (($1341*12)|0)|0);
      $1345 = ($1344|0)==(0|0);
      if (!($1345)) {
       HEAPF32[$1344>>2] = $1336;
       $1346 = ((($1343) + (($1341*12)|0)|0) + 4|0);
       HEAPF32[$1346>>2] = $1337;
       $1347 = ((($1343) + (($1341*12)|0)|0) + 8|0);
       HEAPF32[$1347>>2] = $1338;
      }
      $1348 = (($1341) + 1)|0;
      HEAP32[$1005>>2] = $1348;
     } else {
      (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($prevTriangles,$26)|0);
     }
     $1349 = (($j20$0127) + 1)|0;
     $exitcond169 = ($1349|0)==($1312|0);
     if ($exitcond169) {
      break;
     } else {
      $j20$0127 = $1349;
     }
    }
   }
   $1350 = (($1314) + (($1312*12)|0)|0);
   $1351 = ($1128|0)<($1312|0);
   L179: do {
    if ($1351) {
     $1352 = (($1314) + (($1128*12)|0)|0);
     $$01$i21 = $1352;$1355 = $1300;$1357 = $1301;$1359 = $1302;$1363 = $1303;$1365 = $1304;$1367 = $1305;$1374 = $1306;$1376 = $1307;$1378 = $1308;$1383 = $1309;$1385 = $1310;$1387 = $1311;
     while(1) {
      $1353 = Math_fround(HEAPF32[$$01$i21>>2]);
      $1354 = Math_fround($1353 * $1355);
      $1356 = Math_fround($1353 * $1357);
      $1358 = Math_fround($1353 * $1359);
      $1360 = (($$01$i21) + 4|0);
      $1361 = Math_fround(HEAPF32[$1360>>2]);
      $1362 = Math_fround($1361 * $1363);
      $1364 = Math_fround($1361 * $1365);
      $1366 = Math_fround($1361 * $1367);
      $1368 = Math_fround($1354 + $1362);
      $1369 = Math_fround($1356 + $1364);
      $1370 = Math_fround($1358 + $1366);
      $1371 = (($$01$i21) + 8|0);
      $1372 = Math_fround(HEAPF32[$1371>>2]);
      $1373 = Math_fround($1372 * $1374);
      $1375 = Math_fround($1372 * $1376);
      $1377 = Math_fround($1372 * $1378);
      $1379 = Math_fround($1368 + $1373);
      $1380 = Math_fround($1369 + $1375);
      $1381 = Math_fround($1370 + $1377);
      $1382 = Math_fround($1379 + $1383);
      $1384 = Math_fround($1380 + $1385);
      $1386 = Math_fround($1381 + $1387);
      HEAPF32[$$01$i21>>2] = $1382;
      HEAPF32[$1360>>2] = $1384;
      HEAPF32[$1371>>2] = $1386;
      $1388 = (($$01$i21) + 12|0);
      $1389 = ($1388>>>0)<($1350>>>0);
      if (!($1389)) {
       break L179;
      }
      $$pre192 = Math_fround(HEAPF32[$$byval_copy3>>2]);
      $$pre193 = Math_fround(HEAPF32[$1029>>2]);
      $$pre194 = Math_fround(HEAPF32[$1030>>2]);
      $$pre195 = Math_fround(HEAPF32[$1031>>2]);
      $$pre196 = Math_fround(HEAPF32[$1032>>2]);
      $$pre197 = Math_fround(HEAPF32[$1033>>2]);
      $$pre198 = Math_fround(HEAPF32[$1034>>2]);
      $$pre199 = Math_fround(HEAPF32[$1035>>2]);
      $$pre200 = Math_fround(HEAPF32[$1036>>2]);
      $$pre201 = Math_fround(HEAPF32[$1037>>2]);
      $$pre202 = Math_fround(HEAPF32[$1038>>2]);
      $$pre203 = Math_fround(HEAPF32[$1039>>2]);
      $$01$i21 = $1388;$1355 = $$pre192;$1357 = $$pre193;$1359 = $$pre194;$1363 = $$pre195;$1365 = $$pre196;$1367 = $$pre197;$1374 = $$pre198;$1376 = $$pre199;$1378 = $$pre200;$1383 = $$pre201;$1385 = $$pre202;$1387 = $$pre203;
     }
    }
   } while(0);
   $1390 = (($i16$0132) + 1)|0;
   $1391 = (($shapeIt$5133) + 4|0);
   $1392 = HEAP32[$1007>>2]|0;
   $1393 = ($1390>>>0)<($1392>>>0);
   if ($1393) {
    $i16$0132 = $1390;$shapeIt$5133 = $1391;
   } else {
    $1991 = $1314;$1992 = $1312;$shapeIt$5$lcssa = $1391;
    break;
   }
  }
 }
 HEAP32[$vertices>>2] = 0;
 $1394 = (($vertices) + 4|0);
 HEAP32[$1394>>2] = 0;
 $1395 = (($vertices) + 8|0);
 HEAP32[$1395>>2] = 0;
 HEAP32[$samples>>2] = 0;
 $1396 = (($samples) + 4|0);
 HEAP32[$1396>>2] = 0;
 $1397 = (($samples) + 8|0);
 HEAP32[$1397>>2] = 0;
 $1398 = (($this) + 108|0);
 $1399 = HEAP32[$1398>>2]|0;
 $1400 = ($1399|0)==(0);
 if ($1400) {
  $1852 = $1992;$1855 = $1991;
 } else {
  $1401 = (($clothPose24) + 4|0);
  $1402 = (($clothPose24) + 8|0);
  $1403 = (($clothPose24) + 12|0);
  $1404 = (($heightfieldPose) + 16|0);
  $1405 = (($clothPose24) + 16|0);
  $1406 = (($heightfieldPose) + 20|0);
  $1407 = (($clothPose24) + 20|0);
  $1408 = (($heightfieldPose) + 24|0);
  $1409 = (($clothPose24) + 24|0);
  $1410 = (($heightfieldPose) + 12|0);
  $1411 = (($heightfieldPose) + 8|0);
  $1412 = (($heightfieldPose) + 4|0);
  $1413 = (($this) + 128|0);
  $1414 = (($27) + 4|0);
  $1415 = (($27) + 8|0);
  $1416 = (($$byval_copy2) + 4|0);
  $1417 = (($$byval_copy2) + 8|0);
  $i21$0120 = 0;$shapeIt$6121 = $shapeIt$5$lcssa;
  while(1) {
   $1418 = HEAP32[$shapeIt$6121>>2]|0;
   $1419 = (($1418) + 28|0);
   $1420 = HEAP32[$1419>>2]|0;
   __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($clothPose24,$33);
   __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($heightfieldPose,$1418);
   $1421 = Math_fround(HEAPF32[$clothPose24>>2]);
   $1422 = Math_fround(-$1421);
   $1423 = Math_fround(HEAPF32[$1401>>2]);
   $1424 = Math_fround(-$1423);
   $1425 = Math_fround(HEAPF32[$1402>>2]);
   $1426 = Math_fround(-$1425);
   $1427 = Math_fround(HEAPF32[$1403>>2]);
   $1428 = Math_fround(HEAPF32[$1404>>2]);
   $1429 = Math_fround(HEAPF32[$1405>>2]);
   $1430 = Math_fround($1428 - $1429);
   $1431 = Math_fround(HEAPF32[$1406>>2]);
   $1432 = Math_fround(HEAPF32[$1407>>2]);
   $1433 = Math_fround($1431 - $1432);
   $1434 = Math_fround(HEAPF32[$1408>>2]);
   $1435 = Math_fround(HEAPF32[$1409>>2]);
   $1436 = Math_fround($1434 - $1435);
   $1437 = Math_fround($1430 * Math_fround(2.0));
   $1438 = Math_fround($1433 * Math_fround(2.0));
   $1439 = Math_fround($1436 * Math_fround(2.0));
   $1440 = Math_fround($1427 * $1427);
   $1441 = Math_fround($1440 + Math_fround(-0.5));
   $1442 = Math_fround($1437 * $1422);
   $1443 = Math_fround($1438 * $1424);
   $1444 = Math_fround($1442 + $1443);
   $1445 = Math_fround($1439 * $1426);
   $1446 = Math_fround($1444 + $1445);
   $1447 = Math_fround($1441 * $1437);
   $1448 = Math_fround($1439 * $1424);
   $1449 = Math_fround($1438 * $1426);
   $1450 = Math_fround($1448 - $1449);
   $1451 = Math_fround($1427 * $1450);
   $1452 = Math_fround($1447 + $1451);
   $1453 = Math_fround($1446 * $1422);
   $1454 = Math_fround($1453 + $1452);
   $1455 = Math_fround($1441 * $1438);
   $1456 = Math_fround($1437 * $1426);
   $1457 = Math_fround($1439 * $1422);
   $1458 = Math_fround($1456 - $1457);
   $1459 = Math_fround($1427 * $1458);
   $1460 = Math_fround($1455 + $1459);
   $1461 = Math_fround($1446 * $1424);
   $1462 = Math_fround($1461 + $1460);
   $1463 = Math_fround($1441 * $1439);
   $1464 = Math_fround($1438 * $1422);
   $1465 = Math_fround($1437 * $1424);
   $1466 = Math_fround($1464 - $1465);
   $1467 = Math_fround($1427 * $1466);
   $1468 = Math_fround($1463 + $1467);
   $1469 = Math_fround($1446 * $1426);
   $1470 = Math_fround($1468 + $1469);
   $1471 = Math_fround(HEAPF32[$heightfieldPose>>2]);
   $1472 = Math_fround($1427 * $1471);
   $1473 = Math_fround(HEAPF32[$1410>>2]);
   $1474 = Math_fround($1473 * $1422);
   $1475 = Math_fround($1472 + $1474);
   $1476 = Math_fround(HEAPF32[$1411>>2]);
   $1477 = Math_fround($1476 * $1424);
   $1478 = Math_fround($1475 + $1477);
   $1479 = Math_fround(HEAPF32[$1412>>2]);
   $1480 = Math_fround($1479 * $1426);
   $1481 = Math_fround($1478 - $1480);
   $1482 = Math_fround($1427 * $1479);
   $1483 = Math_fround($1473 * $1424);
   $1484 = Math_fround($1483 + $1482);
   $1485 = Math_fround($1471 * $1426);
   $1486 = Math_fround($1485 + $1484);
   $1487 = Math_fround($1476 * $1422);
   $1488 = Math_fround($1486 - $1487);
   $1489 = Math_fround($1427 * $1476);
   $1490 = Math_fround($1473 * $1426);
   $1491 = Math_fround($1490 + $1489);
   $1492 = Math_fround($1479 * $1422);
   $1493 = Math_fround($1492 + $1491);
   $1494 = Math_fround($1471 * $1424);
   $1495 = Math_fround($1493 - $1494);
   $1496 = Math_fround($1427 * $1473);
   $1497 = Math_fround($1471 * $1422);
   $1498 = Math_fround($1496 - $1497);
   $1499 = Math_fround($1479 * $1424);
   $1500 = Math_fround($1498 - $1499);
   $1501 = Math_fround($1476 * $1426);
   $1502 = Math_fround($1500 - $1501);
   $1503 = Math_fround($1481 + $1481);
   $1504 = Math_fround($1488 + $1488);
   $1505 = Math_fround($1495 + $1495);
   $1506 = Math_fround($1503 * $1502);
   $1507 = Math_fround($1502 * $1504);
   $1508 = Math_fround($1502 * $1505);
   $1509 = Math_fround($1481 * $1503);
   $1510 = Math_fround($1481 * $1504);
   $1511 = Math_fround($1481 * $1505);
   $1512 = Math_fround($1488 * $1504);
   $1513 = Math_fround($1488 * $1505);
   $1514 = Math_fround($1495 * $1505);
   $1515 = Math_fround(Math_fround(1.0) - $1512);
   $1516 = Math_fround($1515 - $1514);
   $1517 = Math_fround($1508 + $1510);
   $1518 = Math_fround($1511 - $1507);
   $1519 = Math_fround($1510 - $1508);
   $1520 = Math_fround(Math_fround(1.0) - $1509);
   $1521 = Math_fround($1520 - $1514);
   $1522 = Math_fround($1506 + $1513);
   $1523 = Math_fround($1511 + $1507);
   $1524 = Math_fround($1513 - $1506);
   $1525 = Math_fround($1520 - $1512);
   $1526 = (($1420) + 80|0);
   $1527 = Math_fround(HEAPF32[$1526>>2]);
   $1528 = Math_fround($1527 * $1516);
   $1529 = Math_fround($1527 * $1517);
   $1530 = Math_fround($1527 * $1518);
   $1531 = (($1420) + 76|0);
   $1532 = Math_fround(HEAPF32[$1531>>2]);
   $1533 = Math_fround($1532 * $1519);
   $1534 = Math_fround($1532 * $1521);
   $1535 = Math_fround($1532 * $1522);
   $1536 = (($1420) + 84|0);
   $1537 = Math_fround(HEAPF32[$1536>>2]);
   $1538 = Math_fround($1537 * $1523);
   $1539 = Math_fround($1537 * $1524);
   $1540 = Math_fround($1537 * $1525);
   $1541 = (($1420) + 72|0);
   $1542 = HEAP32[$1541>>2]|0;
   $1543 = HEAP32[$1542>>2]|0;
   $1544 = (($1543) + 36|0);
   $1545 = HEAP32[$1544>>2]|0;
   $1546 = (FUNCTION_TABLE_ii[$1545 & 4095]($1542)|0);
   $1547 = HEAP32[$1542>>2]|0;
   $1548 = (($1547) + 32|0);
   $1549 = HEAP32[$1548>>2]|0;
   $1550 = (FUNCTION_TABLE_ii[$1549 & 4095]($1542)|0);
   $1551 = Math_imul($1550, $1546)|0;
   HEAP32[$$byval_copy3>>2] = 0;
   __ZN5physx6shdfnd5ArrayINS_19PxHeightFieldSampleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($samples,$1551,$$byval_copy3);
   $1552 = HEAP32[$1542>>2]|0;
   $1553 = (($1552) + 24|0);
   $1554 = HEAP32[$1553>>2]|0;
   $1555 = HEAP32[$samples>>2]|0;
   $1556 = $1551 << 2;
   (FUNCTION_TABLE_iiii[$1554 & 2047]($1542,$1555,$1556)|0);
   $1557 = HEAP32[$1395>>2]|0;
   $1558 = $1557 & 2147483647;
   $1559 = ($1558>>>0)<($1551>>>0);
   if ($1559) {
    __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($vertices,$1551);
   }
   $1560 = ($1550|0)==(0);
   $1561 = ($1546|0)==(0);
   $or$cond = $1560 | $1561;
   if (!($or$cond)) {
    $i$02$us$i = 0;
    while(1) {
     $1569 = (Math_fround(($i$02$us$i>>>0)));
     $1564 = Math_imul($i$02$us$i, $1546)|0;
     $j$01$us$i = 0;
     while(1) {
      $1563 = (($j$01$us$i) + ($1564))|0;
      $1565 = (($1555) + ($1563<<2)|0);
      $1566 = HEAP16[$1565>>1]|0;
      $1567 = (Math_fround(($1566<<16>>16)));
      $1568 = (Math_fround(($j$01$us$i>>>0)));
      HEAPF32[$$byval_copy2>>2] = $1569;
      HEAPF32[$1416>>2] = $1567;
      HEAPF32[$1417>>2] = $1568;
      $1570 = HEAP32[$1395>>2]|0;
      $1571 = $1570 & 2147483647;
      $1572 = HEAP32[$1394>>2]|0;
      $1573 = ($1571>>>0)>($1572>>>0);
      if ($1573) {
       $1574 = HEAP32[$vertices>>2]|0;
       $1575 = (($1574) + (($1572*12)|0)|0);
       $1576 = ($1575|0)==(0|0);
       if (!($1576)) {
        HEAPF32[$1575>>2] = $1569;
        $1577 = ((($1574) + (($1572*12)|0)|0) + 4|0);
        HEAPF32[$1577>>2] = $1567;
        $1578 = ((($1574) + (($1572*12)|0)|0) + 8|0);
        HEAPF32[$1578>>2] = $1568;
       }
       $1579 = (($1572) + 1)|0;
       HEAP32[$1394>>2] = $1579;
      } else {
       (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($vertices,$$byval_copy2)|0);
      }
      $1580 = (($j$01$us$i) + 1)|0;
      $exitcond$i17 = ($1580|0)==($1546|0);
      if ($exitcond$i17) {
       break;
      } else {
       $j$01$us$i = $1580;
      }
     }
     $1562 = (($i$02$us$i) + 1)|0;
     $exitcond3$i = ($1562|0)==($1550|0);
     if ($exitcond3$i) {
      break;
     } else {
      $i$02$us$i = $1562;
     }
    }
   }
   $1581 = HEAP32[$1003>>2]|0;
   $1582 = HEAP32[$1541>>2]|0;
   $1583 = HEAP32[$vertices>>2]|0;
   $1584 = HEAP32[$1582>>2]|0;
   $1585 = (($1584) + 36|0);
   $1586 = HEAP32[$1585>>2]|0;
   $1587 = (FUNCTION_TABLE_ii[$1586 & 4095]($1582)|0);
   $1588 = HEAP32[$1582>>2]|0;
   $1589 = (($1588) + 32|0);
   $1590 = HEAP32[$1589>>2]|0;
   $1591 = (FUNCTION_TABLE_ii[$1590 & 4095]($1582)|0);
   $1592 = (($1591) + -1)|0;
   $1593 = (($1587) + -1)|0;
   $1594 = ($1593*6)|0;
   $1595 = Math_imul($1594, $1592)|0;
   $1596 = (($1595) + ($1581))|0;
   $1597 = HEAP32[$1004>>2]|0;
   $1598 = $1597 & 2147483647;
   $1599 = ($1598>>>0)<($1596>>>0);
   if ($1599) {
    __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($curTriangles,$1596);
   }
   $1600 = ($1593|0)==(0);
   if (!($1600)) {
    $1601 = ($1592|0)==(0);
    $i$012$i = 0;
    while(1) {
     if ($1601) {
      $$pre22$i = (($i$012$i) + 1)|0;
      $$pre$phi$iZ2D = $$pre22$i;
     } else {
      $1602 = Math_imul($i$012$i, $1591)|0;
      $1603 = (($i$012$i) + 1)|0;
      $1604 = Math_imul($1603, $1591)|0;
      $j$011$i = 0;
      while(1) {
       $1605 = Math_imul($j$011$i, $1587)|0;
       $1606 = (($1605) + ($i$012$i))|0;
       $1607 = ((($1555) + ($1606<<2)|0) + 2|0);
       $1608 = HEAP8[$1607>>0]|0;
       $$lobit$i$i = ($1608&255) >>> 7;
       $1609 = (($j$011$i) + ($1602))|0;
       $1610 = (($1609) + 1)|0;
       $1611 = (($j$011$i) + ($1604))|0;
       $1612 = (($1611) + 1)|0;
       $1613 = HEAP32[$1582>>2]|0;
       $1614 = (($1613) + 68|0);
       $1615 = HEAP32[$1614>>2]|0;
       $1616 = $1606 << 1;
       $1617 = (FUNCTION_TABLE_iii[$1615 & 4095]($1582,$1616)|0);
       $1618 = ($1617<<16>>16)==(127);
       do {
        if (!($1618)) {
         $1619 = (($1583) + (($1611*12)|0)|0);
         $1620 = HEAP32[$1004>>2]|0;
         $1621 = $1620 & 2147483647;
         $1622 = HEAP32[$1003>>2]|0;
         $1623 = ($1621>>>0)>($1622>>>0);
         if ($1623) {
          $1624 = HEAP32[$curTriangles>>2]|0;
          $1625 = (($1624) + (($1622*12)|0)|0);
          $1626 = ($1625|0)==(0|0);
          if (!($1626)) {
           $1627 = Math_fround(HEAPF32[$1619>>2]);
           HEAPF32[$1625>>2] = $1627;
           $1628 = ((($1624) + (($1622*12)|0)|0) + 4|0);
           $1629 = ((($1583) + (($1611*12)|0)|0) + 4|0);
           $1630 = Math_fround(HEAPF32[$1629>>2]);
           HEAPF32[$1628>>2] = $1630;
           $1631 = ((($1624) + (($1622*12)|0)|0) + 8|0);
           $1632 = ((($1583) + (($1611*12)|0)|0) + 8|0);
           $1633 = Math_fround(HEAPF32[$1632>>2]);
           HEAPF32[$1631>>2] = $1633;
          }
          $1634 = (($1622) + 1)|0;
          HEAP32[$1003>>2] = $1634;
          $1637 = $1620;$1639 = $1634;
         } else {
          (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1619)|0);
          $$pre18$i = HEAP32[$1004>>2]|0;
          $$pre19$i = HEAP32[$1003>>2]|0;
          $1637 = $$pre18$i;$1639 = $$pre19$i;
         }
         $1635 = (($1583) + (($1609*12)|0)|0);
         $1636 = $1637 & 2147483647;
         $1638 = ($1636>>>0)>($1639>>>0);
         if ($1638) {
          $1640 = HEAP32[$curTriangles>>2]|0;
          $1641 = (($1640) + (($1639*12)|0)|0);
          $1642 = ($1641|0)==(0|0);
          if (!($1642)) {
           $1643 = Math_fround(HEAPF32[$1635>>2]);
           HEAPF32[$1641>>2] = $1643;
           $1644 = ((($1640) + (($1639*12)|0)|0) + 4|0);
           $1645 = ((($1583) + (($1609*12)|0)|0) + 4|0);
           $1646 = Math_fround(HEAPF32[$1645>>2]);
           HEAPF32[$1644>>2] = $1646;
           $1647 = ((($1640) + (($1639*12)|0)|0) + 8|0);
           $1648 = ((($1583) + (($1609*12)|0)|0) + 8|0);
           $1649 = Math_fround(HEAPF32[$1648>>2]);
           HEAPF32[$1647>>2] = $1649;
          }
          $1650 = (($1639) + 1)|0;
          HEAP32[$1003>>2] = $1650;
          $1655 = $1637;$1657 = $1650;
         } else {
          (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1635)|0);
          $$pre20$i = HEAP32[$1004>>2]|0;
          $$pre21$i = HEAP32[$1003>>2]|0;
          $1655 = $$pre20$i;$1657 = $$pre21$i;
         }
         $1651 = ($$lobit$i$i<<24>>24)!=(0);
         $1652 = $1651 ? $1612 : $1610;
         $1653 = (($1583) + (($1652*12)|0)|0);
         $1654 = $1655 & 2147483647;
         $1656 = ($1654>>>0)>($1657>>>0);
         if (!($1656)) {
          (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1653)|0);
          break;
         }
         $1658 = HEAP32[$curTriangles>>2]|0;
         $1659 = (($1658) + (($1657*12)|0)|0);
         $1660 = ($1659|0)==(0|0);
         if (!($1660)) {
          $1661 = Math_fround(HEAPF32[$1653>>2]);
          HEAPF32[$1659>>2] = $1661;
          $1662 = ((($1658) + (($1657*12)|0)|0) + 4|0);
          $1663 = ((($1583) + (($1652*12)|0)|0) + 4|0);
          $1664 = Math_fround(HEAPF32[$1663>>2]);
          HEAPF32[$1662>>2] = $1664;
          $1665 = ((($1658) + (($1657*12)|0)|0) + 8|0);
          $1666 = ((($1583) + (($1652*12)|0)|0) + 8|0);
          $1667 = Math_fround(HEAPF32[$1666>>2]);
          HEAPF32[$1665>>2] = $1667;
         }
         $1668 = (($1657) + 1)|0;
         HEAP32[$1003>>2] = $1668;
        }
       } while(0);
       $1669 = HEAP32[$1582>>2]|0;
       $1670 = (($1669) + 68|0);
       $1671 = HEAP32[$1670>>2]|0;
       $1672 = $1616 | 1;
       $1673 = (FUNCTION_TABLE_iii[$1671 & 4095]($1582,$1672)|0);
       $1674 = ($1673<<16>>16)==(127);
       do {
        if (!($1674)) {
         $1675 = (($1583) + (($1610*12)|0)|0);
         $1676 = HEAP32[$1004>>2]|0;
         $1677 = $1676 & 2147483647;
         $1678 = HEAP32[$1003>>2]|0;
         $1679 = ($1677>>>0)>($1678>>>0);
         if ($1679) {
          $1680 = HEAP32[$curTriangles>>2]|0;
          $1681 = (($1680) + (($1678*12)|0)|0);
          $1682 = ($1681|0)==(0|0);
          if (!($1682)) {
           $1683 = Math_fround(HEAPF32[$1675>>2]);
           HEAPF32[$1681>>2] = $1683;
           $1684 = ((($1680) + (($1678*12)|0)|0) + 4|0);
           $1685 = ((($1583) + (($1610*12)|0)|0) + 4|0);
           $1686 = Math_fround(HEAPF32[$1685>>2]);
           HEAPF32[$1684>>2] = $1686;
           $1687 = ((($1680) + (($1678*12)|0)|0) + 8|0);
           $1688 = ((($1583) + (($1610*12)|0)|0) + 8|0);
           $1689 = Math_fround(HEAPF32[$1688>>2]);
           HEAPF32[$1687>>2] = $1689;
          }
          $1690 = (($1678) + 1)|0;
          HEAP32[$1003>>2] = $1690;
          $1693 = $1676;$1695 = $1690;
         } else {
          (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1675)|0);
          $$pre$i = HEAP32[$1004>>2]|0;
          $$pre15$i = HEAP32[$1003>>2]|0;
          $1693 = $$pre$i;$1695 = $$pre15$i;
         }
         $1691 = (($1583) + (($1612*12)|0)|0);
         $1692 = $1693 & 2147483647;
         $1694 = ($1692>>>0)>($1695>>>0);
         if ($1694) {
          $1696 = HEAP32[$curTriangles>>2]|0;
          $1697 = (($1696) + (($1695*12)|0)|0);
          $1698 = ($1697|0)==(0|0);
          if (!($1698)) {
           $1699 = Math_fround(HEAPF32[$1691>>2]);
           HEAPF32[$1697>>2] = $1699;
           $1700 = ((($1696) + (($1695*12)|0)|0) + 4|0);
           $1701 = ((($1583) + (($1612*12)|0)|0) + 4|0);
           $1702 = Math_fround(HEAPF32[$1701>>2]);
           HEAPF32[$1700>>2] = $1702;
           $1703 = ((($1696) + (($1695*12)|0)|0) + 8|0);
           $1704 = ((($1583) + (($1612*12)|0)|0) + 8|0);
           $1705 = Math_fround(HEAPF32[$1704>>2]);
           HEAPF32[$1703>>2] = $1705;
          }
          $1706 = (($1695) + 1)|0;
          HEAP32[$1003>>2] = $1706;
          $1711 = $1693;$1713 = $1706;
         } else {
          (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1691)|0);
          $$pre16$i = HEAP32[$1004>>2]|0;
          $$pre17$i = HEAP32[$1003>>2]|0;
          $1711 = $$pre16$i;$1713 = $$pre17$i;
         }
         $1707 = ($$lobit$i$i<<24>>24)!=(0);
         $1708 = $1707 ? $1609 : $1611;
         $1709 = (($1583) + (($1708*12)|0)|0);
         $1710 = $1711 & 2147483647;
         $1712 = ($1710>>>0)>($1713>>>0);
         if (!($1712)) {
          (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($curTriangles,$1709)|0);
          break;
         }
         $1714 = HEAP32[$curTriangles>>2]|0;
         $1715 = (($1714) + (($1713*12)|0)|0);
         $1716 = ($1715|0)==(0|0);
         if (!($1716)) {
          $1717 = Math_fround(HEAPF32[$1709>>2]);
          HEAPF32[$1715>>2] = $1717;
          $1718 = ((($1714) + (($1713*12)|0)|0) + 4|0);
          $1719 = ((($1583) + (($1708*12)|0)|0) + 4|0);
          $1720 = Math_fround(HEAPF32[$1719>>2]);
          HEAPF32[$1718>>2] = $1720;
          $1721 = ((($1714) + (($1713*12)|0)|0) + 8|0);
          $1722 = ((($1583) + (($1708*12)|0)|0) + 8|0);
          $1723 = Math_fround(HEAPF32[$1722>>2]);
          HEAPF32[$1721>>2] = $1723;
         }
         $1724 = (($1713) + 1)|0;
         HEAP32[$1003>>2] = $1724;
        }
       } while(0);
       $1725 = (($j$011$i) + 1)|0;
       $exitcond$i = ($1725|0)==($1592|0);
       if ($exitcond$i) {
        $$pre$phi$iZ2D = $1603;
        break;
       } else {
        $j$011$i = $1725;
       }
      }
     }
     $exitcond14$i = ($$pre$phi$iZ2D|0)==($1593|0);
     if ($exitcond14$i) {
      break;
     } else {
      $i$012$i = $$pre$phi$iZ2D;
     }
    }
   }
   $1726 = HEAP32[$1007>>2]|0;
   $1727 = (($1726) + ($i21$0120))|0;
   $1728 = HEAP32[$1413>>2]|0;
   $1729 = (($1728) + (($1727*48)|0)|0);
   $1730 = Math_fround(HEAPF32[$1729>>2]);
   $1731 = ((($1728) + (($1727*48)|0)|0) + 4|0);
   $1732 = Math_fround(HEAPF32[$1731>>2]);
   $1733 = ((($1728) + (($1727*48)|0)|0) + 8|0);
   $1734 = Math_fround(HEAPF32[$1733>>2]);
   $1735 = ((($1728) + (($1727*48)|0)|0) + 12|0);
   $1736 = Math_fround(HEAPF32[$1735>>2]);
   $1737 = ((($1728) + (($1727*48)|0)|0) + 16|0);
   $1738 = Math_fround(HEAPF32[$1737>>2]);
   $1739 = ((($1728) + (($1727*48)|0)|0) + 20|0);
   $1740 = Math_fround(HEAPF32[$1739>>2]);
   $1741 = ((($1728) + (($1727*48)|0)|0) + 24|0);
   $1742 = Math_fround(HEAPF32[$1741>>2]);
   $1743 = ((($1728) + (($1727*48)|0)|0) + 28|0);
   $1744 = Math_fround(HEAPF32[$1743>>2]);
   $1745 = ((($1728) + (($1727*48)|0)|0) + 32|0);
   $1746 = Math_fround(HEAPF32[$1745>>2]);
   $1747 = ((($1728) + (($1727*48)|0)|0) + 36|0);
   $1748 = Math_fround(HEAPF32[$1747>>2]);
   $1749 = ((($1728) + (($1727*48)|0)|0) + 40|0);
   $1750 = Math_fround(HEAPF32[$1749>>2]);
   $1751 = ((($1728) + (($1727*48)|0)|0) + 44|0);
   $1752 = Math_fround(HEAPF32[$1751>>2]);
   HEAPF32[$1729>>2] = $1528;
   HEAPF32[$1731>>2] = $1529;
   HEAPF32[$1733>>2] = $1530;
   HEAPF32[$1735>>2] = $1533;
   HEAPF32[$1737>>2] = $1534;
   HEAPF32[$1739>>2] = $1535;
   HEAPF32[$1741>>2] = $1538;
   HEAPF32[$1743>>2] = $1539;
   HEAPF32[$1745>>2] = $1540;
   HEAPF32[$1747>>2] = $1454;
   HEAPF32[$1749>>2] = $1462;
   HEAPF32[$1751>>2] = $1470;
   $1753 = HEAP32[$1003>>2]|0;
   $1754 = ($1581>>>0)<($1753>>>0);
   $1755 = HEAP32[$curTriangles>>2]|0;
   if ($1754) {
    $j28$0116 = $1581;
    while(1) {
     $1756 = (($1755) + (($j28$0116*12)|0)|0);
     $1757 = Math_fround(HEAPF32[$1756>>2]);
     $1758 = Math_fround($1730 * $1757);
     $1759 = Math_fround($1732 * $1757);
     $1760 = Math_fround($1734 * $1757);
     $1761 = ((($1755) + (($j28$0116*12)|0)|0) + 4|0);
     $1762 = Math_fround(HEAPF32[$1761>>2]);
     $1763 = Math_fround($1736 * $1762);
     $1764 = Math_fround($1738 * $1762);
     $1765 = Math_fround($1740 * $1762);
     $1766 = Math_fround($1758 + $1763);
     $1767 = Math_fround($1759 + $1764);
     $1768 = Math_fround($1760 + $1765);
     $1769 = ((($1755) + (($j28$0116*12)|0)|0) + 8|0);
     $1770 = Math_fround(HEAPF32[$1769>>2]);
     $1771 = Math_fround($1742 * $1770);
     $1772 = Math_fround($1744 * $1770);
     $1773 = Math_fround($1746 * $1770);
     $1774 = Math_fround($1766 + $1771);
     $1775 = Math_fround($1767 + $1772);
     $1776 = Math_fround($1768 + $1773);
     $1777 = Math_fround($1748 + $1774);
     $1778 = Math_fround($1750 + $1775);
     $1779 = Math_fround($1752 + $1776);
     HEAPF32[$27>>2] = $1777;
     HEAPF32[$1414>>2] = $1778;
     HEAPF32[$1415>>2] = $1779;
     $1780 = HEAP32[$1006>>2]|0;
     $1781 = $1780 & 2147483647;
     $1782 = HEAP32[$1005>>2]|0;
     $1783 = ($1781>>>0)>($1782>>>0);
     if ($1783) {
      $1784 = HEAP32[$prevTriangles>>2]|0;
      $1785 = (($1784) + (($1782*12)|0)|0);
      $1786 = ($1785|0)==(0|0);
      if (!($1786)) {
       HEAPF32[$1785>>2] = $1777;
       $1787 = ((($1784) + (($1782*12)|0)|0) + 4|0);
       HEAPF32[$1787>>2] = $1778;
       $1788 = ((($1784) + (($1782*12)|0)|0) + 8|0);
       HEAPF32[$1788>>2] = $1779;
      }
      $1789 = (($1782) + 1)|0;
      HEAP32[$1005>>2] = $1789;
     } else {
      (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($prevTriangles,$27)|0);
     }
     $1790 = (($j28$0116) + 1)|0;
     $exitcond = ($1790|0)==($1753|0);
     if ($exitcond) {
      break;
     } else {
      $j28$0116 = $1790;
     }
    }
   }
   $1791 = (($1755) + (($1753*12)|0)|0);
   $1792 = ($1581|0)<($1753|0);
   if ($1792) {
    $1793 = (($1755) + (($1581*12)|0)|0);
    $$01$i = $1793;
    while(1) {
     $1794 = Math_fround(HEAPF32[$$01$i>>2]);
     $1795 = Math_fround($1528 * $1794);
     $1796 = Math_fround($1529 * $1794);
     $1797 = Math_fround($1530 * $1794);
     $1798 = (($$01$i) + 4|0);
     $1799 = Math_fround(HEAPF32[$1798>>2]);
     $1800 = Math_fround($1533 * $1799);
     $1801 = Math_fround($1534 * $1799);
     $1802 = Math_fround($1535 * $1799);
     $1803 = Math_fround($1795 + $1800);
     $1804 = Math_fround($1796 + $1801);
     $1805 = Math_fround($1797 + $1802);
     $1806 = (($$01$i) + 8|0);
     $1807 = Math_fround(HEAPF32[$1806>>2]);
     $1808 = Math_fround($1538 * $1807);
     $1809 = Math_fround($1539 * $1807);
     $1810 = Math_fround($1540 * $1807);
     $1811 = Math_fround($1803 + $1808);
     $1812 = Math_fround($1804 + $1809);
     $1813 = Math_fround($1805 + $1810);
     $1814 = Math_fround($1454 + $1811);
     $1815 = Math_fround($1462 + $1812);
     $1816 = Math_fround($1470 + $1813);
     HEAPF32[$$01$i>>2] = $1814;
     HEAPF32[$1798>>2] = $1815;
     HEAPF32[$1806>>2] = $1816;
     $1817 = (($$01$i) + 12|0);
     $1818 = ($1817>>>0)<($1791>>>0);
     if ($1818) {
      $$01$i = $1817;
     } else {
      break;
     }
    }
   }
   __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($vertices,0,$28);
   HEAP32[$29>>2] = 0;
   __ZN5physx6shdfnd5ArrayINS_19PxHeightFieldSampleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($samples,0,$29);
   $1819 = (($i21$0120) + 1)|0;
   $1820 = (($shapeIt$6121) + 4|0);
   $1821 = HEAP32[$1398>>2]|0;
   $1822 = ($1819>>>0)<($1821>>>0);
   if ($1822) {
    $i21$0120 = $1819;$shapeIt$6121 = $1820;
   } else {
    $1852 = $1753;$1855 = $1755;
    break;
   }
  }
 }
 $1823 = HEAP32[$297>>2]|0;
 $1824 = HEAP32[$1823>>2]|0;
 $1825 = (($1824) + 352|0);
 $1826 = HEAP32[$1825>>2]|0;
 $1827 = (FUNCTION_TABLE_ii[$1826 & 4095]($1823)|0);
 $1828 = Math_fround(HEAPF32[$1827>>2]);
 HEAPF32[$bboxCenter>>2] = $1828;
 $1829 = (($bboxCenter) + 4|0);
 $1830 = (($1827) + 4|0);
 $1831 = Math_fround(HEAPF32[$1830>>2]);
 HEAPF32[$1829>>2] = $1831;
 $1832 = (($bboxCenter) + 8|0);
 $1833 = (($1827) + 8|0);
 $1834 = Math_fround(HEAPF32[$1833>>2]);
 HEAPF32[$1832>>2] = $1834;
 $1835 = HEAP32[$297>>2]|0;
 $1836 = HEAP32[$1835>>2]|0;
 $1837 = (($1836) + 356|0);
 $1838 = HEAP32[$1837>>2]|0;
 $1839 = (FUNCTION_TABLE_ii[$1838 & 4095]($1835)|0);
 $1840 = (Math_fround(__ZNK5physx2Sc9ClothCore16getContactOffsetEv($33)));
 $1841 = Math_fround(HEAPF32[$1839>>2]);
 $1842 = Math_fround($1840 + $1841);
 $1843 = (($1839) + 4|0);
 $1844 = Math_fround(HEAPF32[$1843>>2]);
 $1845 = Math_fround($1840 + $1844);
 $1846 = (($1839) + 8|0);
 $1847 = Math_fround(HEAPF32[$1846>>2]);
 $1848 = Math_fround($1840 + $1847);
 HEAPF32[$bboxScale>>2] = $1842;
 $1849 = (($bboxScale) + 4|0);
 HEAPF32[$1849>>2] = $1845;
 $1850 = (($bboxScale) + 8|0);
 HEAPF32[$1850>>2] = $1848;
 $1851 = ($1852|0)==(0);
 if ($1851) {
  $numVertices$0$lcssa = 0;
 } else {
  $1853 = HEAP32[$prevTriangles>>2]|0;
  $i30$0114 = 0;$numVertices$0113 = 0;
  while(1) {
   $1854 = (($1855) + (($i30$0114*12)|0)|0);
   $1856 = (($i30$0114) + 1)|0;
   $1857 = (($1855) + (($1856*12)|0)|0);
   $1858 = (($i30$0114) + 2)|0;
   $1859 = (($1855) + (($1858*12)|0)|0);
   $1860 = (__ZN5physx2Gu20intersectTriangleBoxERKNS_6PxVec3ES3_S3_S3_S3_($bboxCenter,$bboxScale,$1854,$1857,$1859)|0);
   $1861 = ($1860|0)==(0);
   if ($1861) {
    $1862 = (($1853) + (($i30$0114*12)|0)|0);
    $1863 = (($1853) + (($1856*12)|0)|0);
    $1864 = (($1853) + (($1858*12)|0)|0);
    $1865 = (__ZN5physx2Gu20intersectTriangleBoxERKNS_6PxVec3ES3_S3_S3_S3_($bboxCenter,$bboxScale,$1862,$1863,$1864)|0);
    $1866 = ($1865|0)==(0);
    if ($1866) {
     $numVertices$1 = $numVertices$0113;
    } else {
     label = 196;
    }
   } else {
    label = 196;
   }
   if ((label|0) == 196) {
    label = 0;
    $1867 = (($1855) + (($i30$0114*12)|0)|0);
    $1868 = Math_fround(HEAPF32[$1867>>2]);
    $1869 = (($1855) + (($numVertices$0113*12)|0)|0);
    HEAPF32[$1869>>2] = $1868;
    $1870 = ((($1855) + (($i30$0114*12)|0)|0) + 4|0);
    $1871 = Math_fround(HEAPF32[$1870>>2]);
    $1872 = ((($1855) + (($numVertices$0113*12)|0)|0) + 4|0);
    HEAPF32[$1872>>2] = $1871;
    $1873 = ((($1855) + (($i30$0114*12)|0)|0) + 8|0);
    $1874 = Math_fround(HEAPF32[$1873>>2]);
    $1875 = ((($1855) + (($numVertices$0113*12)|0)|0) + 8|0);
    HEAPF32[$1875>>2] = $1874;
    $1876 = (($numVertices$0113) + 1)|0;
    $1877 = (($1855) + (($1856*12)|0)|0);
    $1878 = Math_fround(HEAPF32[$1877>>2]);
    $1879 = (($1855) + (($1876*12)|0)|0);
    HEAPF32[$1879>>2] = $1878;
    $1880 = ((($1855) + (($1856*12)|0)|0) + 4|0);
    $1881 = Math_fround(HEAPF32[$1880>>2]);
    $1882 = ((($1855) + (($1876*12)|0)|0) + 4|0);
    HEAPF32[$1882>>2] = $1881;
    $1883 = ((($1855) + (($1856*12)|0)|0) + 8|0);
    $1884 = Math_fround(HEAPF32[$1883>>2]);
    $1885 = ((($1855) + (($1876*12)|0)|0) + 8|0);
    HEAPF32[$1885>>2] = $1884;
    $1886 = (($numVertices$0113) + 2)|0;
    $1887 = (($1855) + (($1858*12)|0)|0);
    $1888 = Math_fround(HEAPF32[$1887>>2]);
    $1889 = (($1855) + (($1886*12)|0)|0);
    HEAPF32[$1889>>2] = $1888;
    $1890 = ((($1855) + (($1858*12)|0)|0) + 4|0);
    $1891 = Math_fround(HEAPF32[$1890>>2]);
    $1892 = ((($1855) + (($1886*12)|0)|0) + 4|0);
    HEAPF32[$1892>>2] = $1891;
    $1893 = ((($1855) + (($1858*12)|0)|0) + 8|0);
    $1894 = Math_fround(HEAPF32[$1893>>2]);
    $1895 = ((($1855) + (($1886*12)|0)|0) + 8|0);
    HEAPF32[$1895>>2] = $1894;
    $1896 = (($1853) + (($i30$0114*12)|0)|0);
    $1897 = Math_fround(HEAPF32[$1896>>2]);
    $1898 = (($1853) + (($numVertices$0113*12)|0)|0);
    HEAPF32[$1898>>2] = $1897;
    $1899 = ((($1853) + (($i30$0114*12)|0)|0) + 4|0);
    $1900 = Math_fround(HEAPF32[$1899>>2]);
    $1901 = ((($1853) + (($numVertices$0113*12)|0)|0) + 4|0);
    HEAPF32[$1901>>2] = $1900;
    $1902 = ((($1853) + (($i30$0114*12)|0)|0) + 8|0);
    $1903 = Math_fround(HEAPF32[$1902>>2]);
    $1904 = ((($1853) + (($numVertices$0113*12)|0)|0) + 8|0);
    HEAPF32[$1904>>2] = $1903;
    $1905 = (($1853) + (($1856*12)|0)|0);
    $1906 = Math_fround(HEAPF32[$1905>>2]);
    $1907 = (($1853) + (($1876*12)|0)|0);
    HEAPF32[$1907>>2] = $1906;
    $1908 = ((($1853) + (($1856*12)|0)|0) + 4|0);
    $1909 = Math_fround(HEAPF32[$1908>>2]);
    $1910 = ((($1853) + (($1876*12)|0)|0) + 4|0);
    HEAPF32[$1910>>2] = $1909;
    $1911 = ((($1853) + (($1856*12)|0)|0) + 8|0);
    $1912 = Math_fround(HEAPF32[$1911>>2]);
    $1913 = ((($1853) + (($1876*12)|0)|0) + 8|0);
    HEAPF32[$1913>>2] = $1912;
    $1914 = (($1853) + (($1858*12)|0)|0);
    $1915 = Math_fround(HEAPF32[$1914>>2]);
    $1916 = (($1853) + (($1886*12)|0)|0);
    HEAPF32[$1916>>2] = $1915;
    $1917 = ((($1853) + (($1858*12)|0)|0) + 4|0);
    $1918 = Math_fround(HEAPF32[$1917>>2]);
    $1919 = ((($1853) + (($1886*12)|0)|0) + 4|0);
    HEAPF32[$1919>>2] = $1918;
    $1920 = ((($1853) + (($1858*12)|0)|0) + 8|0);
    $1921 = Math_fround(HEAPF32[$1920>>2]);
    $1922 = ((($1853) + (($1886*12)|0)|0) + 8|0);
    HEAPF32[$1922>>2] = $1921;
    $1923 = (($numVertices$0113) + 3)|0;
    $numVertices$1 = $1923;
   }
   $1924 = (($i30$0114) + 3)|0;
   $1925 = ($1924>>>0)<($1852>>>0);
   if ($1925) {
    $i30$0114 = $1924;$numVertices$0113 = $numVertices$1;
   } else {
    $numVertices$0$lcssa = $numVertices$1;
    break;
   }
  }
 }
 $1926 = HEAP32[$prevTriangles>>2]|0;
 $1927 = (($1926) + (($numVertices$0$lcssa*12)|0)|0);
 $1928 = (($1855) + (($numVertices$0$lcssa*12)|0)|0);
 __ZN12_GLOBAL__N_115offsetTrianglesEPN5physx6PxVec3ES2_f($1926,$1927,$37);
 __ZN12_GLOBAL__N_115offsetTrianglesEPN5physx6PxVec3ES2_f($1855,$1928,$37);
 $1929 = HEAP32[$297>>2]|0;
 $1930 = HEAP32[$1929>>2]|0;
 $1931 = (($1930) + 200|0);
 $1932 = HEAP32[$1931>>2]|0;
 HEAP32[$30>>2] = $1926;
 $1933 = (($30) + 4|0);
 HEAP32[$1933>>2] = $1927;
 HEAP32[$31>>2] = $1855;
 $1934 = (($31) + 4|0);
 HEAP32[$1934>>2] = $1928;
 $1935 = (($33) + 88|0);
 $1936 = HEAP32[$1935>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$30+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$30+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$31+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$31+4>>2]|0;
 FUNCTION_TABLE_viiii[$1932 & 511]($1929,$$byval_copy2,$$byval_copy3,$1936);
 $1937 = HEAP32[$1397>>2]|0;
 $1938 = $1937 & 2147483647;
 $1939 = ($1938|0)!=(0);
 $1940 = ($1937|0)>(-1);
 $or$cond$i$i7 = $1939 & $1940;
 if ($or$cond$i$i7) {
  $1941 = HEAP32[$samples>>2]|0;
  $1942 = ($1941|0)==(0|0);
  if (!($1942)) {
   $1943 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $1944 = HEAP32[$1943>>2]|0;
   $1945 = (($1944) + 12|0);
   $1946 = HEAP32[$1945>>2]|0;
   FUNCTION_TABLE_vii[$1946 & 4095]($1943,$1941);
  }
 }
 $1947 = HEAP32[$1395>>2]|0;
 $1948 = $1947 & 2147483647;
 $1949 = ($1948|0)!=(0);
 $1950 = ($1947|0)>(-1);
 $or$cond$i$i5 = $1949 & $1950;
 if ($or$cond$i$i5) {
  $1951 = HEAP32[$vertices>>2]|0;
  $1952 = ($1951|0)==(0|0);
  if (!($1952)) {
   $1953 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $1954 = HEAP32[$1953>>2]|0;
   $1955 = (($1954) + 12|0);
   $1956 = HEAP32[$1955>>2]|0;
   FUNCTION_TABLE_vii[$1956 & 4095]($1953,$1951);
  }
 }
 $1957 = HEAP32[$1006>>2]|0;
 $1958 = $1957 & 2147483647;
 $notlhs = ($1958|0)==(0);
 $notrhs = ($1957|0)<(0);
 $or$cond$i$i3$not = $notrhs | $notlhs;
 $1959 = ($1926|0)==(0|0);
 $or$cond208 = $or$cond$i$i3$not | $1959;
 if (!($or$cond208)) {
  $1960 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $1961 = HEAP32[$1960>>2]|0;
  $1962 = (($1961) + 12|0);
  $1963 = HEAP32[$1962>>2]|0;
  FUNCTION_TABLE_vii[$1963 & 4095]($1960,$1926);
 }
 $1964 = HEAP32[$1004>>2]|0;
 $1965 = $1964 & 2147483647;
 $notlhs210 = ($1965|0)==(0);
 $notrhs211 = ($1964|0)<(0);
 $or$cond$i$i2$not = $notrhs211 | $notlhs210;
 $1966 = ($1855|0)==(0|0);
 $or$cond209 = $or$cond$i$i2$not | $1966;
 if (!($or$cond209)) {
  $1967 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $1968 = HEAP32[$1967>>2]|0;
  $1969 = (($1968) + 12|0);
  $1970 = HEAP32[$1969>>2]|0;
  FUNCTION_TABLE_vii[$1970 & 4095]($1967,$1855);
 }
 $1971 = HEAP32[$307>>2]|0;
 $1972 = $1971 & 2147483647;
 $1973 = ($1972|0)!=(0);
 $1974 = ($1971|0)>(-1);
 $or$cond$i$i1 = $1973 & $1974;
 if ($or$cond$i$i1) {
  $1975 = HEAP32[$planes>>2]|0;
  $1976 = ($1975|0)==(0|0);
  if (!($1976)) {
   $1977 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $1978 = HEAP32[$1977>>2]|0;
   $1979 = (($1978) + 12|0);
   $1980 = HEAP32[$1979>>2]|0;
   FUNCTION_TABLE_vii[$1980 & 4095]($1977,$1975);
  }
 }
 $1981 = HEAP32[$41>>2]|0;
 $1982 = $1981 & 2147483647;
 $1983 = ($1982|0)!=(0);
 $1984 = ($1981|0)>(-1);
 $or$cond$i$i = $1983 & $1984;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $1985 = HEAP32[$spheres>>2]|0;
 $1986 = ($1985|0)==(0|0);
 if ($1986) {
  STACKTOP = sp;return;
 }
 $1987 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1988 = HEAP32[$1987>>2]|0;
 $1989 = (($1988) + 12|0);
 $1990 = HEAP32[$1989>>2]|0;
 FUNCTION_TABLE_vii[$1990 & 4095]($1987,$1985);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim8reinsertEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx2Sc8ActorSim8getSceneEv($this)|0);
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx2Sc5Scene11removeClothERNS0_9ClothCoreE($0,$2);
 (__ZN5physx2Sc5Scene8addClothERNS0_9ClothCoreE($0,$2)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim18addCollisionSphereEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0;
 var $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$01$i$phi = 0, $sphere = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp;
 $0 = sp + 64|0;
 $1 = sp + 8|0;
 $sphere = sp + 40|0;
 $2 = sp + 56|0;
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6))|0;
 $10 = ($9>>>0)>(31);
 if ($10) {
  $11 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($11,2,476984,136,477080,$$byval_copy);
  STACKTOP = sp;return;
 }
 $12 = (($shape) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($0,$4);
 __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($1,$shape);
 $14 = Math_fround(HEAPF32[$0>>2]);
 $15 = Math_fround(-$14);
 $16 = (($0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(-$17);
 $19 = (($0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(-$20);
 $22 = (($0) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($1) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($0) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 - $27);
 $29 = (($1) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($0) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($30 - $32);
 $34 = (($1) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($0) + 24|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 - $37);
 $39 = Math_fround($28 * Math_fround(2.0));
 $40 = Math_fround($33 * Math_fround(2.0));
 $41 = Math_fround($38 * Math_fround(2.0));
 $42 = Math_fround($23 * $23);
 $43 = Math_fround($42 + Math_fround(-0.5));
 $44 = Math_fround($39 * $15);
 $45 = Math_fround($40 * $18);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($41 * $21);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($43 * $39);
 $50 = Math_fround($41 * $18);
 $51 = Math_fround($40 * $21);
 $52 = Math_fround($50 - $51);
 $53 = Math_fround($23 * $52);
 $54 = Math_fround($49 + $53);
 $55 = Math_fround($48 * $15);
 $56 = Math_fround($55 + $54);
 $57 = Math_fround($43 * $40);
 $58 = Math_fround($39 * $21);
 $59 = Math_fround($41 * $15);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($23 * $60);
 $62 = Math_fround($57 + $61);
 $63 = Math_fround($48 * $18);
 $64 = Math_fround($63 + $62);
 $65 = Math_fround($43 * $41);
 $66 = Math_fround($40 * $15);
 $67 = Math_fround($39 * $18);
 $68 = Math_fround($66 - $67);
 $69 = Math_fround($23 * $68);
 $70 = Math_fround($65 + $69);
 $71 = Math_fround($48 * $21);
 $72 = Math_fround($70 + $71);
 $73 = (($13) + 72|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 HEAPF32[$sphere>>2] = $56;
 $75 = (($sphere) + 4|0);
 HEAPF32[$75>>2] = $64;
 $76 = (($sphere) + 8|0);
 HEAPF32[$76>>2] = $72;
 $77 = (($sphere) + 12|0);
 HEAPF32[$77>>2] = $74;
 $78 = (($4) + 28|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + 164|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($sphere) + 16|0);
 HEAP32[$2>>2] = $sphere;
 $84 = (($2) + 4|0);
 HEAP32[$84>>2] = $83;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 FUNCTION_TABLE_viiii[$82 & 511]($79,$$byval_copy,$9,$9);
 $85 = HEAP32[$7>>2]|0;
 $86 = (($85) + 1)|0;
 HEAP32[$7>>2] = $86;
 $87 = (($this) + 116|0);
 HEAP32[$$byval_copy>>2] = 0;
 $88 = (($this) + 124|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = $89 & 2147483647;
 $91 = (($this) + 120|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($90>>>0)>($92>>>0);
 if ($93) {
  $94 = HEAP32[$87>>2]|0;
  $95 = (($94) + ($92<<2)|0);
  $96 = ($95|0)==(0|0);
  if (!($96)) {
   HEAP32[$95>>2] = 0;
  }
  $97 = (($92) + 1)|0;
  HEAP32[$91>>2] = $97;
  $$pre$phiZ2D = $87;$99 = $97;
 } else {
  (__ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($87,$$byval_copy)|0);
  $$pre$i = HEAP32[$91>>2]|0;
  $$pre$phiZ2D = $87;$99 = $$pre$i;
 }
 $98 = (($99) + -1)|0;
 $100 = ($98>>>0)>($85>>>0);
 if ($100) {
  $106 = $98;$i$01$i = $99;
  while(1) {
   $101 = (($i$01$i) + -2)|0;
   $102 = HEAP32[$$pre$phiZ2D>>2]|0;
   $103 = (($102) + ($101<<2)|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = (($102) + ($106<<2)|0);
   HEAP32[$105>>2] = $104;
   $107 = (($106) + -1)|0;
   $108 = ($107>>>0)>($85>>>0);
   if ($108) {
    $i$01$i$phi = $106;$106 = $107;$i$01$i = $i$01$i$phi;
   } else {
    break;
   }
  }
 }
 $109 = HEAP32[$$pre$phiZ2D>>2]|0;
 $110 = (($109) + ($85<<2)|0);
 HEAP32[$110>>2] = $shape;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim21removeCollisionSphereEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $index$0 = 0, $it$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 $index$0 = 0;
 while(1) {
  $7 = ($index$0>>>0)<($6>>>0);
  if (!($7)) {
   label = 9;
   break;
  }
  $8 = (($4) + ($index$0<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($shape|0);
  $11 = (($index$0) + 1)|0;
  if ($10) {
   break;
  } else {
   $index$0 = $11;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 120|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $18 = $11;$it$02$i = $8;
  while(1) {
   $15 = ($it$02$i|0)==(0|0);
   if (!($15)) {
    $16 = HEAP32[$3>>2]|0;
    $17 = (($16) + ($18<<2)|0);
    $19 = HEAP32[$17>>2]|0;
    HEAP32[$it$02$i>>2] = $19;
   }
   $20 = (($it$02$i) + 4|0);
   $21 = (($18) + 1)|0;
   $exitcond = ($21|0)==($13|0);
   if ($exitcond) {
    break;
   } else {
    $18 = $21;$it$02$i = $20;
   }
  }
 }
 $22 = (($13) + -1)|0;
 HEAP32[$12>>2] = $22;
 $23 = (($6) + -1)|0;
 HEAP32[$5>>2] = $23;
 $24 = (($2) + 72|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($index$0))|0;
 $27 = (($2) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 164|0);
 $31 = HEAP32[$30>>2]|0;
 HEAP32[$0>>2] = 0;
 $32 = (($0) + 4|0);
 HEAP32[$32>>2] = 0;
 $33 = (($26) + 1)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$31 & 511]($28,$$byval_copy,$26,$33);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim19addCollisionCapsuleEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy3 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$01$i = 0, $i$01$i$phi = 0, $indices = 0, $spheres = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy3 = sp;
 $0 = sp + 96|0;
 $1 = sp + 8|0;
 $spheres = sp + 40|0;
 $2 = sp + 72|0;
 $indices = sp + 80|0;
 $3 = sp + 88|0;
 $4 = (($this) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 88|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9))|0;
 $13 = ($12>>>0)>(31);
 if ($13) {
  $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,2,476984,185,477136,$$byval_copy3);
  STACKTOP = sp;return;
 }
 $15 = (($7) + 72|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $11 << 1;
 $18 = (($17) + ($5))|0;
 $19 = (($18) + ($16))|0;
 $20 = ($19>>>0)>(31);
 if ($20) {
  $21 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($21,2,476984,192,477192,$$byval_copy3);
  STACKTOP = sp;return;
 }
 $22 = (($shape) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($0,$7);
 __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($1,$shape);
 $24 = Math_fround(HEAPF32[$0>>2]);
 $25 = Math_fround(-$24);
 $26 = (($0) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround(-$27);
 $29 = (($0) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround(-$30);
 $32 = (($0) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($1) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($0) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 - $37);
 $39 = (($1) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($0) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 - $42);
 $44 = (($1) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($0) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 - $47);
 $49 = Math_fround($38 * Math_fround(2.0));
 $50 = Math_fround($43 * Math_fround(2.0));
 $51 = Math_fround($48 * Math_fround(2.0));
 $52 = Math_fround($33 * $33);
 $53 = Math_fround($52 + Math_fround(-0.5));
 $54 = Math_fround($49 * $25);
 $55 = Math_fround($50 * $28);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($51 * $31);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($53 * $49);
 $60 = Math_fround($51 * $28);
 $61 = Math_fround($50 * $31);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($33 * $62);
 $64 = Math_fround($59 + $63);
 $65 = Math_fround($58 * $25);
 $66 = Math_fround($65 + $64);
 $67 = Math_fround($53 * $50);
 $68 = Math_fround($49 * $31);
 $69 = Math_fround($51 * $25);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($33 * $70);
 $72 = Math_fround($67 + $71);
 $73 = Math_fround($58 * $28);
 $74 = Math_fround($73 + $72);
 $75 = Math_fround($53 * $51);
 $76 = Math_fround($50 * $25);
 $77 = Math_fround($49 * $28);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($33 * $78);
 $80 = Math_fround($75 + $79);
 $81 = Math_fround($58 * $31);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround(HEAPF32[$1>>2]);
 $84 = Math_fround($33 * $83);
 $85 = (($1) + 12|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 * $25);
 $88 = Math_fround($84 + $87);
 $89 = (($1) + 8|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($90 * $28);
 $92 = Math_fround($88 + $91);
 $93 = (($1) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 * $31);
 $96 = Math_fround($92 - $95);
 $97 = Math_fround($33 * $94);
 $98 = Math_fround($86 * $28);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($83 * $31);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($90 * $25);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($33 * $90);
 $105 = Math_fround($86 * $31);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($94 * $25);
 $108 = Math_fround($107 + $106);
 $109 = Math_fround($83 * $28);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($33 * $86);
 $112 = Math_fround($83 * $25);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($94 * $28);
 $115 = Math_fround($113 - $114);
 $116 = Math_fround($90 * $31);
 $117 = Math_fround($115 - $116);
 $118 = (($23) + 76|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($119 * Math_fround(2.0));
 $121 = Math_fround($117 * $117);
 $122 = Math_fround($121 + Math_fround(-0.5));
 $123 = Math_fround($120 * $96);
 $124 = Math_fround($103 * Math_fround(0.0));
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($110 * Math_fround(0.0));
 $127 = Math_fround($126 + $125);
 $128 = Math_fround($120 * $122);
 $129 = Math_fround($124 - $126);
 $130 = Math_fround($117 * $129);
 $131 = Math_fround($128 + $130);
 $132 = Math_fround($96 * $127);
 $133 = Math_fround($132 + $131);
 $134 = Math_fround($122 * Math_fround(0.0));
 $135 = Math_fround($120 * $110);
 $136 = Math_fround($96 * Math_fround(0.0));
 $137 = Math_fround($135 - $136);
 $138 = Math_fround($117 * $137);
 $139 = Math_fround($134 + $138);
 $140 = Math_fround($103 * $127);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($120 * $103);
 $143 = Math_fround($136 - $142);
 $144 = Math_fround($117 * $143);
 $145 = Math_fround($134 + $144);
 $146 = Math_fround($110 * $127);
 $147 = Math_fround($145 + $146);
 $148 = (($23) + 72|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = Math_fround($66 - $133);
 $151 = Math_fround($74 - $141);
 $152 = Math_fround($82 - $147);
 HEAPF32[$spheres>>2] = $150;
 $153 = (($spheres) + 4|0);
 HEAPF32[$153>>2] = $151;
 $154 = (($spheres) + 8|0);
 HEAPF32[$154>>2] = $152;
 $155 = (($spheres) + 12|0);
 HEAPF32[$155>>2] = $149;
 $156 = Math_fround($66 + $133);
 $157 = Math_fround($74 + $141);
 $158 = Math_fround($82 + $147);
 $159 = (($spheres) + 16|0);
 HEAPF32[$159>>2] = $156;
 $160 = (($spheres) + 20|0);
 HEAPF32[$160>>2] = $157;
 $161 = (($spheres) + 24|0);
 HEAPF32[$161>>2] = $158;
 $162 = (($spheres) + 28|0);
 HEAPF32[$162>>2] = $149;
 $163 = (($7) + 28|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = HEAP32[$164>>2]|0;
 $166 = (($165) + 164|0);
 $167 = HEAP32[$166>>2]|0;
 $168 = (($spheres) + 32|0);
 HEAP32[$2>>2] = $spheres;
 $169 = (($2) + 4|0);
 HEAP32[$169>>2] = $168;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$2+4>>2]|0;
 FUNCTION_TABLE_viiii[$167 & 511]($164,$$byval_copy3,$19,$19);
 HEAP32[$indices>>2] = $19;
 $170 = (($indices) + 4|0);
 $171 = (($19) + 1)|0;
 HEAP32[$170>>2] = $171;
 $172 = HEAP32[$163>>2]|0;
 $173 = HEAP32[$172>>2]|0;
 $174 = (($173) + 172|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = (($indices) + 8|0);
 HEAP32[$3>>2] = $indices;
 $177 = (($3) + 4|0);
 HEAP32[$177>>2] = $176;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$3+4>>2]|0;
 FUNCTION_TABLE_viiii[$175 & 511]($172,$$byval_copy3,$12,$12);
 $178 = HEAP32[$10>>2]|0;
 $179 = (($178) + 1)|0;
 HEAP32[$10>>2] = $179;
 $180 = (($178) + ($5))|0;
 $181 = (($this) + 116|0);
 HEAP32[$$byval_copy3>>2] = 0;
 $182 = (($this) + 124|0);
 $183 = HEAP32[$182>>2]|0;
 $184 = $183 & 2147483647;
 $185 = (($this) + 120|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = ($184>>>0)>($186>>>0);
 if ($187) {
  $188 = HEAP32[$181>>2]|0;
  $189 = (($188) + ($186<<2)|0);
  $190 = ($189|0)==(0|0);
  if (!($190)) {
   HEAP32[$189>>2] = 0;
  }
  $191 = (($186) + 1)|0;
  HEAP32[$185>>2] = $191;
  $$pre$phiZ2D = $181;$193 = $191;
 } else {
  (__ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($181,$$byval_copy3)|0);
  $$pre$i = HEAP32[$185>>2]|0;
  $$pre$phiZ2D = $181;$193 = $$pre$i;
 }
 $192 = (($193) + -1)|0;
 $194 = ($192>>>0)>($180>>>0);
 if ($194) {
  $200 = $192;$i$01$i = $193;
  while(1) {
   $195 = (($i$01$i) + -2)|0;
   $196 = HEAP32[$$pre$phiZ2D>>2]|0;
   $197 = (($196) + ($195<<2)|0);
   $198 = HEAP32[$197>>2]|0;
   $199 = (($196) + ($200<<2)|0);
   HEAP32[$199>>2] = $198;
   $201 = (($200) + -1)|0;
   $202 = ($201>>>0)>($180>>>0);
   if ($202) {
    $i$01$i$phi = $200;$200 = $201;$i$01$i = $i$01$i$phi;
   } else {
    break;
   }
  }
 }
 $203 = HEAP32[$$pre$phiZ2D>>2]|0;
 $204 = (($203) + ($180<<2)|0);
 HEAP32[$204>>2] = $shape;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim22removeCollisionCapsuleEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $index$03 = 0, $it$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 116|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 88|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 } else {
  $index$03 = 0;
 }
 while(1) {
  $$sum = (($index$03) + ($4))|0;
  $12 = (($6) + ($$sum<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($shape|0);
  $11 = (($index$03) + 1)|0;
  if ($14) {
   break;
  }
  $10 = ($11>>>0)<($8>>>0);
  if ($10) {
   $index$03 = $11;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return;
 }
 $15 = (($$sum) + 1)|0;
 $16 = (($this) + 120|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15>>>0)<($17>>>0);
 if ($18) {
  $22 = $15;$it$02$i = $12;
  while(1) {
   $19 = ($it$02$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$5>>2]|0;
    $21 = (($20) + ($22<<2)|0);
    $23 = HEAP32[$21>>2]|0;
    HEAP32[$it$02$i>>2] = $23;
   }
   $24 = (($it$02$i) + 4|0);
   $25 = (($22) + 1)|0;
   $exitcond = ($25|0)==($17|0);
   if ($exitcond) {
    break;
   } else {
    $22 = $25;$it$02$i = $24;
   }
  }
 }
 $26 = (($17) + -1)|0;
 HEAP32[$16>>2] = $26;
 $27 = (($8) + -1)|0;
 HEAP32[$7>>2] = $27;
 $28 = (($2) + 72|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = $index$03 << 1;
 $31 = (($29) + ($30))|0;
 $32 = (($31) + ($4))|0;
 $33 = (($2) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 164|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$0>>2] = 0;
 $38 = (($0) + 4|0);
 HEAP32[$38>>2] = 0;
 $39 = (($32) + 2)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$37 & 511]($34,$$byval_copy,$32,$39);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim17addCollisionPlaneEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $convexMask = 0, $i$01$i = 0, $i$01$i$phi = 0, $plane = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp;
 $0 = sp + 80|0;
 $1 = sp + 8|0;
 $plane = sp + 40|0;
 $2 = sp + 56|0;
 $convexMask = sp + 64|0;
 $3 = sp + 72|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7))|0;
 $11 = ($10>>>0)>(31);
 if ($11) {
  $12 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($12,2,476984,246,477248,$$byval_copy1);
  STACKTOP = sp;return;
 }
 $13 = (($this) + 88|0);
 $14 = (($this) + 84|0);
 $15 = HEAP32[$13>>2]|0;
 $16 = HEAP32[$14>>2]|0;
 $17 = (($16) + ($15))|0;
 __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($0,$5);
 __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($1,$shape);
 $18 = Math_fround(HEAPF32[$0>>2]);
 $19 = Math_fround(-$18);
 $20 = (($0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(-$21);
 $23 = (($0) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(-$24);
 $26 = (($0) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($1) + 16|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($0) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($29 - $31);
 $33 = (($1) + 20|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($0) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 - $36);
 $38 = (($1) + 24|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($0) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($39 - $41);
 $43 = Math_fround($32 * Math_fround(2.0));
 $44 = Math_fround($37 * Math_fround(2.0));
 $45 = Math_fround($42 * Math_fround(2.0));
 $46 = Math_fround($27 * $27);
 $47 = Math_fround($46 + Math_fround(-0.5));
 $48 = Math_fround($43 * $19);
 $49 = Math_fround($44 * $22);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($45 * $25);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($47 * $43);
 $54 = Math_fround($45 * $22);
 $55 = Math_fround($44 * $25);
 $56 = Math_fround($54 - $55);
 $57 = Math_fround($27 * $56);
 $58 = Math_fround($53 + $57);
 $59 = Math_fround($52 * $19);
 $60 = Math_fround($59 + $58);
 $61 = Math_fround($47 * $44);
 $62 = Math_fround($43 * $25);
 $63 = Math_fround($45 * $19);
 $64 = Math_fround($62 - $63);
 $65 = Math_fround($27 * $64);
 $66 = Math_fround($61 + $65);
 $67 = Math_fround($52 * $22);
 $68 = Math_fround($67 + $66);
 $69 = Math_fround($47 * $45);
 $70 = Math_fround($44 * $19);
 $71 = Math_fround($43 * $22);
 $72 = Math_fround($70 - $71);
 $73 = Math_fround($27 * $72);
 $74 = Math_fround($69 + $73);
 $75 = Math_fround($52 * $25);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround(HEAPF32[$1>>2]);
 $78 = Math_fround($27 * $77);
 $79 = (($1) + 12|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($80 * $19);
 $82 = Math_fround($78 + $81);
 $83 = (($1) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 * $22);
 $86 = Math_fround($82 + $85);
 $87 = (($1) + 4|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($88 * $25);
 $90 = Math_fround($86 - $89);
 $91 = Math_fround($27 * $88);
 $92 = Math_fround($80 * $22);
 $93 = Math_fround($92 + $91);
 $94 = Math_fround($77 * $25);
 $95 = Math_fround($94 + $93);
 $96 = Math_fround($84 * $19);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($27 * $84);
 $99 = Math_fround($80 * $25);
 $100 = Math_fround($99 + $98);
 $101 = Math_fround($88 * $19);
 $102 = Math_fround($101 + $100);
 $103 = Math_fround($77 * $22);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($27 * $80);
 $106 = Math_fround($77 * $19);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($88 * $22);
 $109 = Math_fround($107 - $108);
 $110 = Math_fround($84 * $25);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($111 * $111);
 $113 = Math_fround($112 + Math_fround(-0.5));
 $114 = Math_fround($90 * Math_fround(2.0));
 $115 = Math_fround($97 * Math_fround(0.0));
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($104 * Math_fround(0.0));
 $118 = Math_fround($117 + $116);
 $119 = Math_fround($113 * Math_fround(2.0));
 $120 = Math_fround($115 - $117);
 $121 = Math_fround($111 * $120);
 $122 = Math_fround($119 + $121);
 $123 = Math_fround($90 * $118);
 $124 = Math_fround($123 + $122);
 $125 = Math_fround($113 * Math_fround(0.0));
 $126 = Math_fround($104 * Math_fround(2.0));
 $127 = Math_fround($90 * Math_fround(0.0));
 $128 = Math_fround($126 - $127);
 $129 = Math_fround($111 * $128);
 $130 = Math_fround($125 + $129);
 $131 = Math_fround($97 * $118);
 $132 = Math_fround($130 + $131);
 $133 = Math_fround($97 * Math_fround(2.0));
 $134 = Math_fround($127 - $133);
 $135 = Math_fround($111 * $134);
 $136 = Math_fround($125 + $135);
 $137 = Math_fround($104 * $118);
 $138 = Math_fround($136 + $137);
 $139 = Math_fround($60 * $124);
 $140 = Math_fround($68 * $132);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($76 * $138);
 $143 = Math_fround($142 + $141);
 $144 = Math_fround(Math_fround(0.0) - $143);
 HEAPF32[$plane>>2] = $124;
 $145 = (($plane) + 4|0);
 HEAPF32[$145>>2] = $132;
 $146 = (($plane) + 8|0);
 HEAPF32[$146>>2] = $138;
 $147 = (($plane) + 12|0);
 HEAPF32[$147>>2] = $144;
 $148 = (($5) + 28|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = HEAP32[$149>>2]|0;
 $151 = (($150) + 180|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = (($plane) + 16|0);
 HEAP32[$2>>2] = $plane;
 $154 = (($2) + 4|0);
 HEAP32[$154>>2] = $153;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$2+4>>2]|0;
 FUNCTION_TABLE_viiii[$152 & 511]($149,$$byval_copy1,$10,$10);
 $155 = (($5) + 84|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = HEAP32[$8>>2]|0;
 $158 = (($157) + ($156))|0;
 $159 = 1 << $10;
 HEAP32[$convexMask>>2] = $159;
 $160 = HEAP32[$148>>2]|0;
 $161 = HEAP32[$160>>2]|0;
 $162 = (($161) + 188|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = (($convexMask) + 4|0);
 HEAP32[$3>>2] = $convexMask;
 $165 = (($3) + 4|0);
 HEAP32[$165>>2] = $164;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$3+4>>2]|0;
 FUNCTION_TABLE_viiii[$163 & 511]($160,$$byval_copy1,$158,$158);
 $166 = HEAP32[$8>>2]|0;
 $167 = (($166) + 1)|0;
 HEAP32[$8>>2] = $167;
 $168 = (($17) + ($166))|0;
 $169 = (($this) + 116|0);
 HEAP32[$$byval_copy1>>2] = 0;
 $170 = (($this) + 124|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = $171 & 2147483647;
 $173 = (($this) + 120|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ($172>>>0)>($174>>>0);
 if ($175) {
  $176 = HEAP32[$169>>2]|0;
  $177 = (($176) + ($174<<2)|0);
  $178 = ($177|0)==(0|0);
  if (!($178)) {
   HEAP32[$177>>2] = 0;
  }
  $179 = (($174) + 1)|0;
  HEAP32[$173>>2] = $179;
  $$pre$phiZ2D = $169;$181 = $179;
 } else {
  (__ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($169,$$byval_copy1)|0);
  $$pre$i = HEAP32[$173>>2]|0;
  $$pre$phiZ2D = $169;$181 = $$pre$i;
 }
 $180 = (($181) + -1)|0;
 $182 = ($180>>>0)>($168>>>0);
 if ($182) {
  $188 = $180;$i$01$i = $181;
  while(1) {
   $183 = (($i$01$i) + -2)|0;
   $184 = HEAP32[$$pre$phiZ2D>>2]|0;
   $185 = (($184) + ($183<<2)|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = (($184) + ($188<<2)|0);
   HEAP32[$187>>2] = $186;
   $189 = (($188) + -1)|0;
   $190 = ($189>>>0)>($168>>>0);
   if ($190) {
    $i$01$i$phi = $188;$188 = $189;$i$01$i = $i$01$i$phi;
   } else {
    break;
   }
  }
 }
 $191 = HEAP32[$$pre$phiZ2D>>2]|0;
 $192 = (($191) + ($168<<2)|0);
 HEAP32[$192>>2] = $shape;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim20removeCollisionPlaneEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $index$03 = 0, $it$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4))|0;
 $8 = (($this) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 92|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 } else {
  $index$03 = 0;
 }
 while(1) {
  $$sum = (($7) + ($index$03))|0;
  $15 = (($9) + ($$sum<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($shape|0);
  $14 = (($index$03) + 1)|0;
  if ($17) {
   break;
  }
  $13 = ($14>>>0)<($11>>>0);
  if ($13) {
   $index$03 = $14;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return;
 }
 $18 = (($$sum) + 1)|0;
 $19 = (($this) + 120|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)<($20>>>0);
 if ($21) {
  $25 = $18;$it$02$i = $15;
  while(1) {
   $22 = ($it$02$i|0)==(0|0);
   if (!($22)) {
    $23 = HEAP32[$8>>2]|0;
    $24 = (($23) + ($25<<2)|0);
    $26 = HEAP32[$24>>2]|0;
    HEAP32[$it$02$i>>2] = $26;
   }
   $27 = (($it$02$i) + 4|0);
   $28 = (($25) + 1)|0;
   $exitcond = ($28|0)==($20|0);
   if ($exitcond) {
    break;
   } else {
    $25 = $28;$it$02$i = $27;
   }
  }
 }
 $29 = (($20) + -1)|0;
 HEAP32[$19>>2] = $29;
 $30 = (($11) + -1)|0;
 HEAP32[$10>>2] = $30;
 $31 = (($2) + 80|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($index$03))|0;
 $34 = (($2) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 180|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$0>>2] = 0;
 $39 = (($0) + 4|0);
 HEAP32[$39>>2] = 0;
 $40 = (($33) + 1)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$38 & 511]($35,$$byval_copy,$33,$40);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim15addCollisionBoxEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0;
 var $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $convexMask = 0, $i$01$i = 0, $i$01$i$phi = 0, $planes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy1 = sp;
 $0 = sp + 160|0;
 $1 = sp + 8|0;
 $planes = sp + 40|0;
 $2 = sp + 136|0;
 $convexMask = sp + 144|0;
 $3 = sp + 152|0;
 $4 = (($this) + 92|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($5))|0;
 $11 = (($this) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12*6)|0;
 $14 = (($10) + ($13))|0;
 $15 = (($14) + 6)|0;
 $16 = ($15>>>0)>(32);
 if ($16) {
  $17 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($17,2,476984,298,477296,$$byval_copy1);
  STACKTOP = sp;return;
 }
 $18 = (($this) + 88|0);
 $19 = (($this) + 84|0);
 $20 = HEAP32[$18>>2]|0;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($shape) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($0,$7);
 __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($1,$shape);
 $24 = Math_fround(HEAPF32[$0>>2]);
 $25 = Math_fround(-$24);
 $26 = (($0) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround(-$27);
 $29 = (($0) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround(-$30);
 $32 = (($0) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($1) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($0) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 - $37);
 $39 = (($1) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($0) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 - $42);
 $44 = (($1) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($0) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 - $47);
 $49 = Math_fround($38 * Math_fround(2.0));
 $50 = Math_fround($43 * Math_fround(2.0));
 $51 = Math_fround($48 * Math_fround(2.0));
 $52 = Math_fround($33 * $33);
 $53 = Math_fround($52 + Math_fround(-0.5));
 $54 = Math_fround($49 * $25);
 $55 = Math_fround($50 * $28);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($51 * $31);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($53 * $49);
 $60 = Math_fround($51 * $28);
 $61 = Math_fround($50 * $31);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($33 * $62);
 $64 = Math_fround($59 + $63);
 $65 = Math_fround($58 * $25);
 $66 = Math_fround($65 + $64);
 $67 = Math_fround($53 * $50);
 $68 = Math_fround($49 * $31);
 $69 = Math_fround($51 * $25);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($33 * $70);
 $72 = Math_fround($67 + $71);
 $73 = Math_fround($58 * $28);
 $74 = Math_fround($73 + $72);
 $75 = Math_fround($53 * $51);
 $76 = Math_fround($50 * $25);
 $77 = Math_fround($49 * $28);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($33 * $78);
 $80 = Math_fround($75 + $79);
 $81 = Math_fround($58 * $31);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround(HEAPF32[$1>>2]);
 $84 = Math_fround($33 * $83);
 $85 = (($1) + 12|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 * $25);
 $88 = Math_fround($84 + $87);
 $89 = (($1) + 8|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($90 * $28);
 $92 = Math_fround($88 + $91);
 $93 = (($1) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 * $31);
 $96 = Math_fround($92 - $95);
 $97 = Math_fround($33 * $94);
 $98 = Math_fround($86 * $28);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($83 * $31);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($90 * $25);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($33 * $90);
 $105 = Math_fround($86 * $31);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($94 * $25);
 $108 = Math_fround($107 + $106);
 $109 = Math_fround($83 * $28);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($33 * $86);
 $112 = Math_fround($83 * $25);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($94 * $28);
 $115 = Math_fround($113 - $114);
 $116 = Math_fround($90 * $31);
 $117 = Math_fround($115 - $116);
 $118 = (($23) + 72|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($23) + 76|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($23) + 80|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround(-$119);
 $125 = Math_fround($117 * $117);
 $126 = Math_fround($125 + Math_fround(-0.5));
 $127 = Math_fround($96 * Math_fround(2.0));
 $128 = Math_fround($103 * Math_fround(0.0));
 $129 = Math_fround($127 + $128);
 $130 = Math_fround($110 * Math_fround(0.0));
 $131 = Math_fround($130 + $129);
 $132 = Math_fround($126 * Math_fround(2.0));
 $133 = Math_fround($128 - $130);
 $134 = Math_fround($117 * $133);
 $135 = Math_fround($132 + $134);
 $136 = Math_fround($96 * $131);
 $137 = Math_fround($136 + $135);
 $138 = Math_fround($126 * Math_fround(0.0));
 $139 = Math_fround($110 * Math_fround(2.0));
 $140 = Math_fround($96 * Math_fround(0.0));
 $141 = Math_fround($139 - $140);
 $142 = Math_fround($117 * $141);
 $143 = Math_fround($138 + $142);
 $144 = Math_fround($103 * $131);
 $145 = Math_fround($143 + $144);
 $146 = Math_fround($103 * Math_fround(2.0));
 $147 = Math_fround($140 - $146);
 $148 = Math_fround($117 * $147);
 $149 = Math_fround($138 + $148);
 $150 = Math_fround($110 * $131);
 $151 = Math_fround($149 + $150);
 $152 = Math_fround($66 * $137);
 $153 = Math_fround($74 * $145);
 $154 = Math_fround($152 + $153);
 $155 = Math_fround($82 * $151);
 $156 = Math_fround($155 + $154);
 $157 = Math_fround($124 - $156);
 HEAPF32[$planes>>2] = $137;
 $158 = (($planes) + 4|0);
 HEAPF32[$158>>2] = $145;
 $159 = (($planes) + 8|0);
 HEAPF32[$159>>2] = $151;
 $160 = (($planes) + 12|0);
 HEAPF32[$160>>2] = $157;
 $161 = Math_fround($96 * Math_fround(-2.0));
 $162 = Math_fround($161 + $128);
 $163 = Math_fround($130 + $162);
 $164 = Math_fround($126 * Math_fround(-2.0));
 $165 = Math_fround($164 + $134);
 $166 = Math_fround($96 * $163);
 $167 = Math_fround($166 + $165);
 $168 = Math_fround($110 * Math_fround(-2.0));
 $169 = Math_fround($168 - $140);
 $170 = Math_fround($117 * $169);
 $171 = Math_fround($138 + $170);
 $172 = Math_fround($103 * $163);
 $173 = Math_fround($171 + $172);
 $174 = Math_fround($103 * Math_fround(-2.0));
 $175 = Math_fround($140 - $174);
 $176 = Math_fround($117 * $175);
 $177 = Math_fround($138 + $176);
 $178 = Math_fround($110 * $163);
 $179 = Math_fround($177 + $178);
 $180 = Math_fround($66 * $167);
 $181 = Math_fround($74 * $173);
 $182 = Math_fround($180 + $181);
 $183 = Math_fround($82 * $179);
 $184 = Math_fround($183 + $182);
 $185 = Math_fround($124 - $184);
 $186 = (($planes) + 16|0);
 HEAPF32[$186>>2] = $167;
 $187 = (($planes) + 20|0);
 HEAPF32[$187>>2] = $173;
 $188 = (($planes) + 24|0);
 HEAPF32[$188>>2] = $179;
 $189 = (($planes) + 28|0);
 HEAPF32[$189>>2] = $185;
 $190 = Math_fround(-$121);
 $191 = Math_fround($140 + $146);
 $192 = Math_fround($130 + $191);
 $193 = Math_fround($128 - $139);
 $194 = Math_fround($117 * $193);
 $195 = Math_fround($138 + $194);
 $196 = Math_fround($96 * $192);
 $197 = Math_fround($196 + $195);
 $198 = Math_fround($130 - $140);
 $199 = Math_fround($117 * $198);
 $200 = Math_fround($132 + $199);
 $201 = Math_fround($103 * $192);
 $202 = Math_fround($200 + $201);
 $203 = Math_fround($127 - $128);
 $204 = Math_fround($117 * $203);
 $205 = Math_fround($138 + $204);
 $206 = Math_fround($110 * $192);
 $207 = Math_fround($205 + $206);
 $208 = Math_fround($66 * $197);
 $209 = Math_fround($74 * $202);
 $210 = Math_fround($208 + $209);
 $211 = Math_fround($82 * $207);
 $212 = Math_fround($211 + $210);
 $213 = Math_fround($190 - $212);
 $214 = (($planes) + 32|0);
 HEAPF32[$214>>2] = $197;
 $215 = (($planes) + 36|0);
 HEAPF32[$215>>2] = $202;
 $216 = (($planes) + 40|0);
 HEAPF32[$216>>2] = $207;
 $217 = (($planes) + 44|0);
 HEAPF32[$217>>2] = $213;
 $218 = Math_fround($140 + $174);
 $219 = Math_fround($130 + $218);
 $220 = Math_fround($128 - $168);
 $221 = Math_fround($117 * $220);
 $222 = Math_fround($138 + $221);
 $223 = Math_fround($96 * $219);
 $224 = Math_fround($223 + $222);
 $225 = Math_fround($164 + $199);
 $226 = Math_fround($103 * $219);
 $227 = Math_fround($225 + $226);
 $228 = Math_fround($161 - $128);
 $229 = Math_fround($117 * $228);
 $230 = Math_fround($138 + $229);
 $231 = Math_fround($110 * $219);
 $232 = Math_fround($230 + $231);
 $233 = Math_fround($66 * $224);
 $234 = Math_fround($74 * $227);
 $235 = Math_fround($233 + $234);
 $236 = Math_fround($82 * $232);
 $237 = Math_fround($236 + $235);
 $238 = Math_fround($190 - $237);
 $239 = (($planes) + 48|0);
 HEAPF32[$239>>2] = $224;
 $240 = (($planes) + 52|0);
 HEAPF32[$240>>2] = $227;
 $241 = (($planes) + 56|0);
 HEAPF32[$241>>2] = $232;
 $242 = (($planes) + 60|0);
 HEAPF32[$242>>2] = $238;
 $243 = Math_fround(-$123);
 $244 = Math_fround($140 + $128);
 $245 = Math_fround($139 + $244);
 $246 = Math_fround($146 - $130);
 $247 = Math_fround($117 * $246);
 $248 = Math_fround($138 + $247);
 $249 = Math_fround($96 * $245);
 $250 = Math_fround($249 + $248);
 $251 = Math_fround($130 - $127);
 $252 = Math_fround($117 * $251);
 $253 = Math_fround($138 + $252);
 $254 = Math_fround($103 * $245);
 $255 = Math_fround($253 + $254);
 $256 = Math_fround($140 - $128);
 $257 = Math_fround($117 * $256);
 $258 = Math_fround($132 + $257);
 $259 = Math_fround($110 * $245);
 $260 = Math_fround($258 + $259);
 $261 = Math_fround($66 * $250);
 $262 = Math_fround($74 * $255);
 $263 = Math_fround($261 + $262);
 $264 = Math_fround($82 * $260);
 $265 = Math_fround($264 + $263);
 $266 = Math_fround($243 - $265);
 $267 = (($planes) + 64|0);
 HEAPF32[$267>>2] = $250;
 $268 = (($planes) + 68|0);
 HEAPF32[$268>>2] = $255;
 $269 = (($planes) + 72|0);
 HEAPF32[$269>>2] = $260;
 $270 = (($planes) + 76|0);
 HEAPF32[$270>>2] = $266;
 $271 = Math_fround($168 + $244);
 $272 = Math_fround($174 - $130);
 $273 = Math_fround($117 * $272);
 $274 = Math_fround($138 + $273);
 $275 = Math_fround($96 * $271);
 $276 = Math_fround($275 + $274);
 $277 = Math_fround($130 - $161);
 $278 = Math_fround($117 * $277);
 $279 = Math_fround($138 + $278);
 $280 = Math_fround($103 * $271);
 $281 = Math_fround($279 + $280);
 $282 = Math_fround($164 + $257);
 $283 = Math_fround($110 * $271);
 $284 = Math_fround($282 + $283);
 $285 = Math_fround($66 * $276);
 $286 = Math_fround($74 * $281);
 $287 = Math_fround($285 + $286);
 $288 = Math_fround($82 * $284);
 $289 = Math_fround($288 + $287);
 $290 = Math_fround($243 - $289);
 $291 = (($planes) + 80|0);
 HEAPF32[$291>>2] = $276;
 $292 = (($planes) + 84|0);
 HEAPF32[$292>>2] = $281;
 $293 = (($planes) + 88|0);
 HEAPF32[$293>>2] = $284;
 $294 = (($planes) + 92|0);
 HEAPF32[$294>>2] = $290;
 $295 = (($7) + 28|0);
 $296 = HEAP32[$295>>2]|0;
 $297 = HEAP32[$296>>2]|0;
 $298 = (($297) + 180|0);
 $299 = HEAP32[$298>>2]|0;
 $300 = (($planes) + 96|0);
 HEAP32[$2>>2] = $planes;
 $301 = (($2) + 4|0);
 HEAP32[$301>>2] = $300;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$2+4>>2]|0;
 FUNCTION_TABLE_viiii[$299 & 511]($296,$$byval_copy1,$14,$14);
 $302 = (($7) + 84|0);
 $303 = HEAP32[$302>>2]|0;
 $304 = HEAP32[$4>>2]|0;
 $305 = (($304) + ($303))|0;
 $306 = HEAP32[$11>>2]|0;
 $307 = (($305) + ($306))|0;
 $308 = 63 << $14;
 HEAP32[$convexMask>>2] = $308;
 $309 = HEAP32[$295>>2]|0;
 $310 = HEAP32[$309>>2]|0;
 $311 = (($310) + 188|0);
 $312 = HEAP32[$311>>2]|0;
 $313 = (($convexMask) + 4|0);
 HEAP32[$3>>2] = $convexMask;
 $314 = (($3) + 4|0);
 HEAP32[$314>>2] = $313;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$3+4>>2]|0;
 FUNCTION_TABLE_viiii[$312 & 511]($309,$$byval_copy1,$307,$307);
 $315 = HEAP32[$11>>2]|0;
 $316 = (($315) + 1)|0;
 HEAP32[$11>>2] = $316;
 $317 = (($20) + ($5))|0;
 $318 = (($317) + ($21))|0;
 $319 = (($318) + ($315))|0;
 $320 = (($this) + 116|0);
 HEAP32[$$byval_copy1>>2] = 0;
 $321 = (($this) + 124|0);
 $322 = HEAP32[$321>>2]|0;
 $323 = $322 & 2147483647;
 $324 = (($this) + 120|0);
 $325 = HEAP32[$324>>2]|0;
 $326 = ($323>>>0)>($325>>>0);
 if ($326) {
  $327 = HEAP32[$320>>2]|0;
  $328 = (($327) + ($325<<2)|0);
  $329 = ($328|0)==(0|0);
  if (!($329)) {
   HEAP32[$328>>2] = 0;
  }
  $330 = (($325) + 1)|0;
  HEAP32[$324>>2] = $330;
  $$pre$phiZ2D = $320;$332 = $330;
 } else {
  (__ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($320,$$byval_copy1)|0);
  $$pre$i = HEAP32[$324>>2]|0;
  $$pre$phiZ2D = $320;$332 = $$pre$i;
 }
 $331 = (($332) + -1)|0;
 $333 = ($331>>>0)>($319>>>0);
 if ($333) {
  $339 = $331;$i$01$i = $332;
  while(1) {
   $334 = (($i$01$i) + -2)|0;
   $335 = HEAP32[$$pre$phiZ2D>>2]|0;
   $336 = (($335) + ($334<<2)|0);
   $337 = HEAP32[$336>>2]|0;
   $338 = (($335) + ($339<<2)|0);
   HEAP32[$338>>2] = $337;
   $340 = (($339) + -1)|0;
   $341 = ($340>>>0)>($319>>>0);
   if ($341) {
    $i$01$i$phi = $339;$339 = $340;$i$01$i = $i$01$i$phi;
   } else {
    break;
   }
  }
 }
 $342 = HEAP32[$$pre$phiZ2D>>2]|0;
 $343 = (($342) + ($319<<2)|0);
 HEAP32[$343>>2] = $shape;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim18removeCollisionBoxEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $index$03 = 0, $it$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4))|0;
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + ($9))|0;
 $11 = (($this) + 116|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 96|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 } else {
  $index$03 = 0;
 }
 while(1) {
  $$sum = (($10) + ($index$03))|0;
  $18 = (($12) + ($$sum<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($shape|0);
  $17 = (($index$03) + 1)|0;
  if ($20) {
   break;
  }
  $16 = ($17>>>0)<($14>>>0);
  if ($16) {
   $index$03 = $17;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return;
 }
 $21 = (($$sum) + 1)|0;
 $22 = (($this) + 120|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($21>>>0)<($23>>>0);
 if ($24) {
  $28 = $21;$it$02$i = $18;
  while(1) {
   $25 = ($it$02$i|0)==(0|0);
   if (!($25)) {
    $26 = HEAP32[$11>>2]|0;
    $27 = (($26) + ($28<<2)|0);
    $29 = HEAP32[$27>>2]|0;
    HEAP32[$it$02$i>>2] = $29;
   }
   $30 = (($it$02$i) + 4|0);
   $31 = (($28) + 1)|0;
   $exitcond = ($31|0)==($23|0);
   if ($exitcond) {
    break;
   } else {
    $28 = $31;$it$02$i = $30;
   }
  }
 }
 $32 = (($23) + -1)|0;
 HEAP32[$22>>2] = $32;
 $33 = (($14) + -1)|0;
 HEAP32[$13>>2] = $33;
 $34 = (($2) + 80|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($index$03*6)|0;
 $37 = (($35) + ($36))|0;
 $38 = (($37) + ($9))|0;
 $39 = (($2) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 180|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$0>>2] = 0;
 $44 = (($0) + 4|0);
 HEAP32[$44>>2] = 0;
 $45 = (($38) + 6)|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$43 & 511]($40,$$byval_copy,$38,$45);
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim18addCollisionConvexEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0;
 var $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0);
 var $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0;
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $convexMask = 0;
 var $exitcond = 0, $i$01 = 0, $i$01$i = 0, $i$01$i$phi = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $planes = 0, $polygon = 0, $trafo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $$byval_copy1 = sp;
 $trafo = sp + 152|0;
 $0 = sp + 120|0;
 $1 = sp + 92|0;
 $2 = sp + 64|0;
 $planes = sp + 200|0;
 $polygon = sp + 32|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $convexMask = sp + 52|0;
 $5 = sp + 56|0;
 $6 = (($this) + 84|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7))|0;
 $11 = (($this) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12))|0;
 $14 = (($this) + 96|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + ($15))|0;
 $17 = (($this) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($shape) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 100|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 36|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 4095]($22)|0);
 $27 = (($18) + 80|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$11>>2]|0;
 $30 = (($29) + ($28))|0;
 $31 = HEAP32[$14>>2]|0;
 $32 = ($31*6)|0;
 $33 = (($30) + ($32))|0;
 $34 = (($this) + 112|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($33) + ($35))|0;
 $37 = (($36) + ($26))|0;
 $38 = ($37>>>0)>(32);
 if ($38) {
  $39 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($39,2,476984,361,477344,$$byval_copy1);
  STACKTOP = sp;return;
 }
 __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($1,$18);
 __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($2,$shape);
 $40 = Math_fround(HEAPF32[$1>>2]);
 $41 = Math_fround(-$40);
 $42 = (($1) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(-$43);
 $45 = (($1) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround(-$46);
 $48 = (($1) + 12|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($2) + 16|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($1) + 16|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($51 - $53);
 $55 = (($2) + 20|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($1) + 20|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($56 - $58);
 $60 = (($2) + 24|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($1) + 24|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($61 - $63);
 $65 = Math_fround($54 * Math_fround(2.0));
 $66 = Math_fround($59 * Math_fround(2.0));
 $67 = Math_fround($64 * Math_fround(2.0));
 $68 = Math_fround($49 * $49);
 $69 = Math_fround($68 + Math_fround(-0.5));
 $70 = Math_fround($65 * $41);
 $71 = Math_fround($66 * $44);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($67 * $47);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($69 * $65);
 $76 = Math_fround($67 * $44);
 $77 = Math_fround($66 * $47);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($49 * $78);
 $80 = Math_fround($75 + $79);
 $81 = Math_fround($74 * $41);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($69 * $66);
 $84 = Math_fround($65 * $47);
 $85 = Math_fround($67 * $41);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($49 * $86);
 $88 = Math_fround($83 + $87);
 $89 = Math_fround($74 * $44);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($69 * $67);
 $92 = Math_fround($66 * $41);
 $93 = Math_fround($65 * $44);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($49 * $94);
 $96 = Math_fround($91 + $95);
 $97 = Math_fround($74 * $47);
 $98 = Math_fround($96 + $97);
 $99 = Math_fround(HEAPF32[$2>>2]);
 $100 = Math_fround($49 * $99);
 $101 = (($2) + 12|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($102 * $41);
 $104 = Math_fround($100 + $103);
 $105 = (($2) + 8|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($106 * $44);
 $108 = Math_fround($104 + $107);
 $109 = (($2) + 4|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($110 * $47);
 $112 = Math_fround($108 - $111);
 $113 = Math_fround($49 * $110);
 $114 = Math_fround($102 * $44);
 $115 = Math_fround($114 + $113);
 $116 = Math_fround($99 * $47);
 $117 = Math_fround($116 + $115);
 $118 = Math_fround($106 * $41);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($49 * $106);
 $121 = Math_fround($102 * $47);
 $122 = Math_fround($121 + $120);
 $123 = Math_fround($110 * $41);
 $124 = Math_fround($123 + $122);
 $125 = Math_fround($99 * $44);
 $126 = Math_fround($124 - $125);
 $127 = Math_fround($49 * $102);
 $128 = Math_fround($99 * $41);
 $129 = Math_fround($127 - $128);
 $130 = Math_fround($110 * $44);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($106 * $47);
 $133 = Math_fround($131 - $132);
 HEAPF32[$0>>2] = $112;
 $134 = (($0) + 4|0);
 HEAPF32[$134>>2] = $119;
 $135 = (($0) + 8|0);
 HEAPF32[$135>>2] = $126;
 $136 = (($0) + 12|0);
 HEAPF32[$136>>2] = $133;
 $137 = (($0) + 16|0);
 HEAPF32[$137>>2] = $82;
 $138 = (($0) + 20|0);
 HEAPF32[$138>>2] = $90;
 $139 = (($0) + 24|0);
 HEAPF32[$139>>2] = $98;
 $140 = (($20) + 72|0);
 __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($trafo,$0,$140);
 HEAP32[$planes>>2] = 0;
 $141 = (($planes) + 4|0);
 HEAP32[$141>>2] = 0;
 $142 = (($planes) + 8|0);
 HEAP32[$142>>2] = 0;
 $143 = ($26|0)==(0);
 if (!($143)) {
  __ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE8recreateEj($planes,$26);
  $144 = Math_fround(HEAPF32[$trafo>>2]);
  $145 = (($trafo) + 4|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($trafo) + 8|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = (($polygon) + 4|0);
  $150 = (($trafo) + 12|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = (($trafo) + 16|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  $154 = (($trafo) + 20|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = (($polygon) + 8|0);
  $157 = (($trafo) + 24|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = (($trafo) + 28|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = (($trafo) + 32|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = (($polygon) + 12|0);
  $164 = (($trafo) + 36|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  $166 = (($trafo) + 40|0);
  $167 = Math_fround(HEAPF32[$166>>2]);
  $168 = (($trafo) + 44|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = (($3) + 4|0);
  $171 = (($3) + 8|0);
  $172 = (($3) + 12|0);
  $i$01 = 0;
  while(1) {
   $173 = HEAP32[$21>>2]|0;
   $174 = HEAP32[$173>>2]|0;
   $175 = (($174) + 40|0);
   $176 = HEAP32[$175>>2]|0;
   (FUNCTION_TABLE_iiii[$176 & 2047]($173,$i$01,$polygon)|0);
   $177 = Math_fround(HEAPF32[$polygon>>2]);
   $178 = Math_fround($177 * $144);
   $179 = Math_fround($177 * $146);
   $180 = Math_fround($177 * $148);
   $181 = Math_fround(HEAPF32[$149>>2]);
   $182 = Math_fround($181 * $151);
   $183 = Math_fround($181 * $153);
   $184 = Math_fround($181 * $155);
   $185 = Math_fround($178 + $182);
   $186 = Math_fround($179 + $183);
   $187 = Math_fround($180 + $184);
   $188 = Math_fround(HEAPF32[$156>>2]);
   $189 = Math_fround($188 * $158);
   $190 = Math_fround($188 * $160);
   $191 = Math_fround($188 * $162);
   $192 = Math_fround($185 + $189);
   $193 = Math_fround($186 + $190);
   $194 = Math_fround($187 + $191);
   $195 = Math_fround(HEAPF32[$163>>2]);
   $196 = Math_fround($192 * $165);
   $197 = Math_fround($193 * $167);
   $198 = Math_fround($196 + $197);
   $199 = Math_fround($194 * $169);
   $200 = Math_fround($198 + $199);
   $201 = Math_fround($195 - $200);
   HEAPF32[$3>>2] = $192;
   HEAPF32[$170>>2] = $193;
   HEAPF32[$171>>2] = $194;
   HEAPF32[$172>>2] = $201;
   $202 = HEAP32[$142>>2]|0;
   $203 = $202 & 2147483647;
   $204 = HEAP32[$141>>2]|0;
   $205 = ($203>>>0)>($204>>>0);
   if ($205) {
    $206 = HEAP32[$planes>>2]|0;
    $207 = (($206) + ($204<<4)|0);
    $208 = ($207|0)==(0|0);
    if (!($208)) {
     HEAPF32[$207>>2] = $192;
     $209 = ((($206) + ($204<<4)|0) + 4|0);
     HEAPF32[$209>>2] = $193;
     $210 = ((($206) + ($204<<4)|0) + 8|0);
     HEAPF32[$210>>2] = $194;
     $211 = ((($206) + ($204<<4)|0) + 12|0);
     HEAPF32[$211>>2] = $201;
    }
    $212 = (($204) + 1)|0;
    HEAP32[$141>>2] = $212;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($planes,$3)|0);
   }
   $213 = (($i$01) + 1)|0;
   $exitcond = ($213|0)==($26|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $213;
   }
  }
 }
 $214 = (($18) + 28|0);
 $215 = HEAP32[$214>>2]|0;
 $216 = HEAP32[$215>>2]|0;
 $217 = (($216) + 180|0);
 $218 = HEAP32[$217>>2]|0;
 $219 = HEAP32[$planes>>2]|0;
 $220 = (($219) + ($26<<4)|0);
 HEAP32[$4>>2] = $219;
 $221 = (($4) + 4|0);
 HEAP32[$221>>2] = $220;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$4+4>>2]|0;
 FUNCTION_TABLE_viiii[$218 & 511]($215,$$byval_copy1,$36,$36);
 $222 = (($18) + 84|0);
 $223 = HEAP32[$222>>2]|0;
 $224 = HEAP32[$11>>2]|0;
 $225 = (($224) + ($223))|0;
 $226 = HEAP32[$14>>2]|0;
 $227 = (($225) + ($226))|0;
 $228 = (($this) + 100|0);
 $229 = HEAP32[$228>>2]|0;
 $230 = (($227) + ($229))|0;
 $231 = 1 << $26;
 $232 = (($231) + -1)|0;
 $233 = $232 << $36;
 HEAP32[$convexMask>>2] = $233;
 $234 = HEAP32[$214>>2]|0;
 $235 = HEAP32[$234>>2]|0;
 $236 = (($235) + 188|0);
 $237 = HEAP32[$236>>2]|0;
 $238 = (($convexMask) + 4|0);
 HEAP32[$5>>2] = $convexMask;
 $239 = (($5) + 4|0);
 HEAP32[$239>>2] = $238;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$5+4>>2]|0;
 FUNCTION_TABLE_viiii[$237 & 511]($234,$$byval_copy1,$230,$230);
 $240 = HEAP32[$34>>2]|0;
 $241 = (($240) + ($26))|0;
 HEAP32[$34>>2] = $241;
 $242 = HEAP32[$228>>2]|0;
 $243 = (($242) + 1)|0;
 HEAP32[$228>>2] = $243;
 $244 = (($16) + ($242))|0;
 $245 = (($this) + 116|0);
 HEAP32[$$byval_copy1>>2] = 0;
 $246 = (($this) + 124|0);
 $247 = HEAP32[$246>>2]|0;
 $248 = $247 & 2147483647;
 $249 = (($this) + 120|0);
 $250 = HEAP32[$249>>2]|0;
 $251 = ($248>>>0)>($250>>>0);
 if ($251) {
  $252 = HEAP32[$245>>2]|0;
  $253 = (($252) + ($250<<2)|0);
  $254 = ($253|0)==(0|0);
  if (!($254)) {
   HEAP32[$253>>2] = 0;
  }
  $255 = (($250) + 1)|0;
  HEAP32[$249>>2] = $255;
  $$pre$phiZ2D = $245;$257 = $255;
 } else {
  (__ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($245,$$byval_copy1)|0);
  $$pre$i = HEAP32[$249>>2]|0;
  $$pre$phiZ2D = $245;$257 = $$pre$i;
 }
 $256 = (($257) + -1)|0;
 $258 = ($256>>>0)>($244>>>0);
 if ($258) {
  $264 = $256;$i$01$i = $257;
  while(1) {
   $259 = (($i$01$i) + -2)|0;
   $260 = HEAP32[$$pre$phiZ2D>>2]|0;
   $261 = (($260) + ($259<<2)|0);
   $262 = HEAP32[$261>>2]|0;
   $263 = (($260) + ($264<<2)|0);
   HEAP32[$263>>2] = $262;
   $265 = (($264) + -1)|0;
   $266 = ($265>>>0)>($244>>>0);
   if ($266) {
    $i$01$i$phi = $264;$264 = $265;$i$01$i = $i$01$i$phi;
   } else {
    break;
   }
  }
 }
 $267 = HEAP32[$$pre$phiZ2D>>2]|0;
 $268 = (($267) + ($244<<2)|0);
 HEAP32[$268>>2] = $shape;
 $269 = HEAP32[$142>>2]|0;
 $270 = $269 & 2147483647;
 $notlhs = ($270|0)==(0);
 $notrhs = ($269|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $271 = ($219|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $271;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $272 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = (($273) + 12|0);
 $275 = HEAP32[$274>>2]|0;
 FUNCTION_TABLE_vii[$275 & 4095]($272,$219);
 STACKTOP = sp;return;
}
function __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($agg$result,$transform,$scale) {
 $agg$result = $agg$result|0;
 $transform = $transform|0;
 $scale = $scale|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$transform>>2]);
 $1 = (($transform) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($transform) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($transform) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 + $0);
 $8 = Math_fround($2 + $2);
 $9 = Math_fround($4 + $4);
 $10 = Math_fround($0 * $7);
 $11 = Math_fround($2 * $8);
 $12 = Math_fround($4 * $9);
 $13 = Math_fround($7 * $2);
 $14 = Math_fround($7 * $4);
 $15 = Math_fround($7 * $6);
 $16 = Math_fround($8 * $4);
 $17 = Math_fround($8 * $6);
 $18 = Math_fround($9 * $6);
 $19 = Math_fround(Math_fround(1.0) - $11);
 $20 = Math_fround($19 - $12);
 $21 = Math_fround($13 + $18);
 $22 = Math_fround($14 - $17);
 $23 = Math_fround($13 - $18);
 $24 = Math_fround(Math_fround(1.0) - $10);
 $25 = Math_fround($24 - $12);
 $26 = Math_fround($16 + $15);
 $27 = Math_fround($14 + $17);
 $28 = Math_fround($16 - $15);
 $29 = Math_fround($24 - $11);
 $30 = (($scale) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($scale) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($scale) + 20|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($scale) + 24|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($31 + $31);
 $39 = Math_fround($33 + $33);
 $40 = Math_fround($35 + $35);
 $41 = Math_fround($31 * $38);
 $42 = Math_fround($33 * $39);
 $43 = Math_fround($35 * $40);
 $44 = Math_fround($38 * $33);
 $45 = Math_fround($38 * $35);
 $46 = Math_fround($38 * $37);
 $47 = Math_fround($39 * $35);
 $48 = Math_fround($39 * $37);
 $49 = Math_fround($40 * $37);
 $50 = Math_fround(Math_fround(1.0) - $42);
 $51 = Math_fround($50 - $43);
 $52 = Math_fround($44 + $49);
 $53 = Math_fround($45 - $48);
 $54 = Math_fround($44 - $49);
 $55 = Math_fround(Math_fround(1.0) - $41);
 $56 = Math_fround($55 - $43);
 $57 = Math_fround($47 + $46);
 $58 = Math_fround($45 + $48);
 $59 = Math_fround($47 - $46);
 $60 = Math_fround($55 - $42);
 $61 = Math_fround(HEAPF32[$scale>>2]);
 $62 = Math_fround($61 * $51);
 $63 = Math_fround($61 * $54);
 $64 = Math_fround($61 * $58);
 $65 = (($scale) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($52 * $66);
 $68 = Math_fround($56 * $66);
 $69 = Math_fround($59 * $66);
 $70 = (($scale) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($53 * $71);
 $73 = Math_fround($57 * $71);
 $74 = Math_fround($60 * $71);
 $75 = Math_fround($51 * $62);
 $76 = Math_fround($51 * $63);
 $77 = Math_fround($51 * $64);
 $78 = Math_fround($52 * $67);
 $79 = Math_fround($52 * $68);
 $80 = Math_fround($52 * $69);
 $81 = Math_fround($75 + $78);
 $82 = Math_fround($76 + $79);
 $83 = Math_fround($77 + $80);
 $84 = Math_fround($53 * $72);
 $85 = Math_fround($53 * $73);
 $86 = Math_fround($53 * $74);
 $87 = Math_fround($81 + $84);
 $88 = Math_fround($82 + $85);
 $89 = Math_fround($83 + $86);
 $90 = Math_fround($54 * $62);
 $91 = Math_fround($54 * $63);
 $92 = Math_fround($54 * $64);
 $93 = Math_fround($56 * $67);
 $94 = Math_fround($56 * $68);
 $95 = Math_fround($56 * $69);
 $96 = Math_fround($90 + $93);
 $97 = Math_fround($91 + $94);
 $98 = Math_fround($92 + $95);
 $99 = Math_fround($57 * $72);
 $100 = Math_fround($57 * $73);
 $101 = Math_fround($57 * $74);
 $102 = Math_fround($96 + $99);
 $103 = Math_fround($97 + $100);
 $104 = Math_fround($98 + $101);
 $105 = Math_fround($58 * $62);
 $106 = Math_fround($58 * $63);
 $107 = Math_fround($58 * $64);
 $108 = Math_fround($59 * $67);
 $109 = Math_fround($59 * $68);
 $110 = Math_fround($59 * $69);
 $111 = Math_fround($105 + $108);
 $112 = Math_fround($106 + $109);
 $113 = Math_fround($107 + $110);
 $114 = Math_fround($60 * $72);
 $115 = Math_fround($60 * $73);
 $116 = Math_fround($60 * $74);
 $117 = Math_fround($111 + $114);
 $118 = Math_fround($112 + $115);
 $119 = Math_fround($113 + $116);
 $120 = Math_fround($20 * $87);
 $121 = Math_fround($21 * $87);
 $122 = Math_fround($22 * $87);
 $123 = Math_fround($23 * $88);
 $124 = Math_fround($25 * $88);
 $125 = Math_fround($26 * $88);
 $126 = Math_fround($120 + $123);
 $127 = Math_fround($121 + $124);
 $128 = Math_fround($122 + $125);
 $129 = Math_fround($27 * $89);
 $130 = Math_fround($28 * $89);
 $131 = Math_fround($29 * $89);
 $132 = Math_fround($129 + $126);
 $133 = Math_fround($130 + $127);
 $134 = Math_fround($131 + $128);
 $135 = Math_fround($20 * $102);
 $136 = Math_fround($21 * $102);
 $137 = Math_fround($22 * $102);
 $138 = Math_fround($23 * $103);
 $139 = Math_fround($25 * $103);
 $140 = Math_fround($26 * $103);
 $141 = Math_fround($135 + $138);
 $142 = Math_fround($136 + $139);
 $143 = Math_fround($137 + $140);
 $144 = Math_fround($27 * $104);
 $145 = Math_fround($28 * $104);
 $146 = Math_fround($29 * $104);
 $147 = Math_fround($144 + $141);
 $148 = Math_fround($145 + $142);
 $149 = Math_fround($146 + $143);
 $150 = Math_fround($20 * $117);
 $151 = Math_fround($21 * $117);
 $152 = Math_fround($22 * $117);
 $153 = Math_fround($23 * $118);
 $154 = Math_fround($25 * $118);
 $155 = Math_fround($26 * $118);
 $156 = Math_fround($150 + $153);
 $157 = Math_fround($151 + $154);
 $158 = Math_fround($152 + $155);
 $159 = Math_fround($27 * $119);
 $160 = Math_fround($28 * $119);
 $161 = Math_fround($29 * $119);
 $162 = Math_fround($159 + $156);
 $163 = Math_fround($160 + $157);
 $164 = Math_fround($161 + $158);
 HEAPF32[$agg$result>>2] = $132;
 $165 = (($agg$result) + 4|0);
 HEAPF32[$165>>2] = $133;
 $166 = (($agg$result) + 8|0);
 HEAPF32[$166>>2] = $134;
 $167 = (($agg$result) + 12|0);
 HEAPF32[$167>>2] = $147;
 $168 = (($agg$result) + 16|0);
 HEAPF32[$168>>2] = $148;
 $169 = (($agg$result) + 20|0);
 HEAPF32[$169>>2] = $149;
 $170 = (($agg$result) + 24|0);
 HEAPF32[$170>>2] = $162;
 $171 = (($agg$result) + 28|0);
 HEAPF32[$171>>2] = $163;
 $172 = (($agg$result) + 32|0);
 HEAPF32[$172>>2] = $164;
 $173 = (($agg$result) + 36|0);
 $174 = (($transform) + 16|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 HEAPF32[$173>>2] = $175;
 $176 = (($agg$result) + 40|0);
 $177 = (($transform) + 20|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 HEAPF32[$176>>2] = $178;
 $179 = (($agg$result) + 44|0);
 $180 = (($transform) + 24|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 HEAPF32[$179>>2] = $181;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim21removeCollisionConvexEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$byval_copy = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $index$03 = 0, $it$02$i = 0, $planeIndex$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4))|0;
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + ($9))|0;
 $11 = (($this) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12))|0;
 $14 = (($this) + 116|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 100|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = ($12*6)|0;
 $20 = (($2) + 80|0);
 $21 = (($19) + ($9))|0;
 $22 = HEAP32[$20>>2]|0;
 $23 = (($21) + ($22))|0;
 $index$03 = 0;$planeIndex$04 = $23;
 while(1) {
  $$sum = (($13) + ($index$03))|0;
  $24 = (($15) + ($$sum<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 100|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 36|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
  $34 = HEAP32[$24>>2]|0;
  $35 = ($34|0)==($shape|0);
  if ($35) {
   break;
  }
  $62 = (($33) + ($planeIndex$04))|0;
  $63 = (($index$03) + 1)|0;
  $64 = HEAP32[$16>>2]|0;
  $65 = ($63>>>0)<($64>>>0);
  if ($65) {
   $index$03 = $63;$planeIndex$04 = $62;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return;
 }
 $36 = (($$sum) + 1)|0;
 $37 = (($this) + 120|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($36>>>0)<($38>>>0);
 if ($39) {
  $40 = HEAP32[$14>>2]|0;
  $41 = (($40) + ($$sum<<2)|0);
  $45 = $36;$it$02$i = $41;
  while(1) {
   $42 = ($it$02$i|0)==(0|0);
   if (!($42)) {
    $43 = HEAP32[$14>>2]|0;
    $44 = (($43) + ($45<<2)|0);
    $46 = HEAP32[$44>>2]|0;
    HEAP32[$it$02$i>>2] = $46;
   }
   $47 = (($it$02$i) + 4|0);
   $48 = (($45) + 1)|0;
   $exitcond = ($48|0)==($38|0);
   if ($exitcond) {
    break;
   } else {
    $45 = $48;$it$02$i = $47;
   }
  }
 }
 $49 = (($38) + -1)|0;
 HEAP32[$37>>2] = $49;
 $50 = HEAP32[$16>>2]|0;
 $51 = (($50) + -1)|0;
 HEAP32[$16>>2] = $51;
 $52 = (($2) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 180|0);
 $56 = HEAP32[$55>>2]|0;
 HEAP32[$0>>2] = 0;
 $57 = (($0) + 4|0);
 HEAP32[$57>>2] = 0;
 $58 = (($33) + ($planeIndex$04))|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$56 & 511]($53,$$byval_copy,$planeIndex$04,$58);
 $59 = (($this) + 112|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) - ($33))|0;
 HEAP32[$59>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim16addCollisionMeshEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0;
 var $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0;
 var $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0);
 var $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$01$i = 0, $i$01$i$phi = 0;
 var $trafo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 132|0;
 $trafo = sp;
 $1 = sp + 48|0;
 $2 = sp + 76|0;
 $3 = sp + 104|0;
 $4 = (($this) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5))|0;
 $9 = (($this) + 92|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + ($10))|0;
 $12 = (($this) + 96|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + ($13))|0;
 $15 = (($this) + 100|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + ($16))|0;
 $18 = (($this) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($shape) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($2,$19);
 __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($3,$shape);
 $22 = Math_fround(HEAPF32[$2>>2]);
 $23 = Math_fround(-$22);
 $24 = (($2) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround(-$25);
 $27 = (($2) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(-$28);
 $30 = (($2) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($3) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($2) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 - $35);
 $37 = (($3) + 20|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($2) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 - $40);
 $42 = (($3) + 24|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($2) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 - $45);
 $47 = Math_fround($36 * Math_fround(2.0));
 $48 = Math_fround($41 * Math_fround(2.0));
 $49 = Math_fround($46 * Math_fround(2.0));
 $50 = Math_fround($31 * $31);
 $51 = Math_fround($50 + Math_fround(-0.5));
 $52 = Math_fround($47 * $23);
 $53 = Math_fround($48 * $26);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($49 * $29);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($51 * $47);
 $58 = Math_fround($49 * $26);
 $59 = Math_fround($48 * $29);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($31 * $60);
 $62 = Math_fround($57 + $61);
 $63 = Math_fround($56 * $23);
 $64 = Math_fround($63 + $62);
 $65 = Math_fround($51 * $48);
 $66 = Math_fround($47 * $29);
 $67 = Math_fround($49 * $23);
 $68 = Math_fround($66 - $67);
 $69 = Math_fround($31 * $68);
 $70 = Math_fround($65 + $69);
 $71 = Math_fround($56 * $26);
 $72 = Math_fround($71 + $70);
 $73 = Math_fround($51 * $49);
 $74 = Math_fround($48 * $23);
 $75 = Math_fround($47 * $26);
 $76 = Math_fround($74 - $75);
 $77 = Math_fround($31 * $76);
 $78 = Math_fround($73 + $77);
 $79 = Math_fround($56 * $29);
 $80 = Math_fround($78 + $79);
 $81 = Math_fround(HEAPF32[$3>>2]);
 $82 = Math_fround($31 * $81);
 $83 = (($3) + 12|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 * $23);
 $86 = Math_fround($82 + $85);
 $87 = (($3) + 8|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($88 * $26);
 $90 = Math_fround($86 + $89);
 $91 = (($3) + 4|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($92 * $29);
 $94 = Math_fround($90 - $93);
 $95 = Math_fround($31 * $92);
 $96 = Math_fround($84 * $26);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($81 * $29);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($88 * $23);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($31 * $88);
 $103 = Math_fround($84 * $29);
 $104 = Math_fround($103 + $102);
 $105 = Math_fround($92 * $23);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($81 * $26);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($31 * $84);
 $110 = Math_fround($81 * $23);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($92 * $26);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($88 * $29);
 $115 = Math_fround($113 - $114);
 HEAPF32[$1>>2] = $94;
 $116 = (($1) + 4|0);
 HEAPF32[$116>>2] = $101;
 $117 = (($1) + 8|0);
 HEAPF32[$117>>2] = $108;
 $118 = (($1) + 12|0);
 HEAPF32[$118>>2] = $115;
 $119 = (($1) + 16|0);
 HEAPF32[$119>>2] = $64;
 $120 = (($1) + 20|0);
 HEAPF32[$120>>2] = $72;
 $121 = (($1) + 24|0);
 HEAPF32[$121>>2] = $80;
 $122 = (($21) + 72|0);
 __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($trafo,$1,$122);
 $123 = (($this) + 104|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($124) + 1)|0;
 HEAP32[$123>>2] = $125;
 $126 = (($17) + ($124))|0;
 $127 = (($this) + 116|0);
 HEAP32[$0>>2] = 0;
 $128 = (($this) + 124|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = $129 & 2147483647;
 $131 = (($this) + 120|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($130>>>0)>($132>>>0);
 if ($133) {
  $134 = HEAP32[$127>>2]|0;
  $135 = (($134) + ($132<<2)|0);
  $136 = ($135|0)==(0|0);
  if (!($136)) {
   HEAP32[$135>>2] = 0;
  }
  $137 = (($132) + 1)|0;
  HEAP32[$131>>2] = $137;
  $$pre$phiZ2D = $127;$139 = $137;
 } else {
  (__ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($127,$0)|0);
  $$pre$i = HEAP32[$131>>2]|0;
  $$pre$phiZ2D = $127;$139 = $$pre$i;
 }
 $138 = (($139) + -1)|0;
 $140 = ($138>>>0)>($126>>>0);
 if ($140) {
  $146 = $138;$i$01$i = $139;
  while(1) {
   $141 = (($i$01$i) + -2)|0;
   $142 = HEAP32[$$pre$phiZ2D>>2]|0;
   $143 = (($142) + ($141<<2)|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = (($142) + ($146<<2)|0);
   HEAP32[$145>>2] = $144;
   $147 = (($146) + -1)|0;
   $148 = ($147>>>0)>($126>>>0);
   if ($148) {
    $i$01$i$phi = $146;$146 = $147;$i$01$i = $i$01$i$phi;
   } else {
    break;
   }
  }
 }
 $149 = HEAP32[$$pre$phiZ2D>>2]|0;
 $150 = (($149) + ($126<<2)|0);
 HEAP32[$150>>2] = $shape;
 $151 = (($this) + 128|0);
 $152 = (($this) + 136|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = $153 & 2147483647;
 $155 = (($this) + 132|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = ($154>>>0)>($156>>>0);
 if (!($157)) {
  (__ZN5physx6shdfnd5ArrayINS_2Cm8Matrix34ENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($151,$trafo)|0);
  STACKTOP = sp;return;
 }
 $158 = HEAP32[$151>>2]|0;
 $159 = (($158) + (($156*48)|0)|0);
 $160 = ($159|0)==(0|0);
 if (!($160)) {
  $161 = Math_fround(HEAPF32[$trafo>>2]);
  HEAPF32[$159>>2] = $161;
  $162 = (($trafo) + 4|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = ((($158) + (($156*48)|0)|0) + 4|0);
  HEAPF32[$164>>2] = $163;
  $165 = (($trafo) + 8|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = ((($158) + (($156*48)|0)|0) + 8|0);
  HEAPF32[$167>>2] = $166;
  $168 = (($trafo) + 12|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = ((($158) + (($156*48)|0)|0) + 12|0);
  HEAPF32[$170>>2] = $169;
  $171 = (($trafo) + 16|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = ((($158) + (($156*48)|0)|0) + 16|0);
  HEAPF32[$173>>2] = $172;
  $174 = (($trafo) + 20|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = ((($158) + (($156*48)|0)|0) + 20|0);
  HEAPF32[$176>>2] = $175;
  $177 = (($trafo) + 24|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = ((($158) + (($156*48)|0)|0) + 24|0);
  HEAPF32[$179>>2] = $178;
  $180 = (($trafo) + 28|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = ((($158) + (($156*48)|0)|0) + 28|0);
  HEAPF32[$182>>2] = $181;
  $183 = (($trafo) + 32|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = ((($158) + (($156*48)|0)|0) + 32|0);
  HEAPF32[$185>>2] = $184;
  $186 = (($trafo) + 36|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = ((($158) + (($156*48)|0)|0) + 36|0);
  HEAPF32[$188>>2] = $187;
  $189 = (($trafo) + 40|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = ((($158) + (($156*48)|0)|0) + 40|0);
  HEAPF32[$191>>2] = $190;
  $192 = (($trafo) + 44|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = ((($158) + (($156*48)|0)|0) + 44|0);
  HEAPF32[$194>>2] = $193;
 }
 $195 = (($156) + 1)|0;
 HEAP32[$155>>2] = $195;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim19removeCollisionMeshEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $9 = 0, $exitcond = 0, $exitcond6 = 0, $index$05 = 0, $it$02$i = 0, $it$02$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 $5 = (($this) + 92|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6))|0;
 $8 = (($this) + 96|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + ($9))|0;
 $11 = (($this) + 100|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12))|0;
 $14 = (($this) + 116|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 104|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  STACKTOP = sp;return;
 } else {
  $index$05 = 0;
 }
 while(1) {
  $$sum = (($13) + ($index$05))|0;
  $21 = (($15) + ($$sum<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==($shape|0);
  $20 = (($index$05) + 1)|0;
  if ($23) {
   break;
  }
  $19 = ($20>>>0)<($17>>>0);
  if ($19) {
   $index$05 = $20;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
 $24 = (($$sum) + 1)|0;
 $25 = (($this) + 120|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24>>>0)<($26>>>0);
 if ($27) {
  $31 = $24;$it$02$i2 = $21;
  while(1) {
   $28 = ($it$02$i2|0)==(0|0);
   if (!($28)) {
    $29 = HEAP32[$14>>2]|0;
    $30 = (($29) + ($31<<2)|0);
    $32 = HEAP32[$30>>2]|0;
    HEAP32[$it$02$i2>>2] = $32;
   }
   $33 = (($it$02$i2) + 4|0);
   $34 = (($31) + 1)|0;
   $exitcond6 = ($34|0)==($26|0);
   if ($exitcond6) {
    break;
   } else {
    $31 = $34;$it$02$i2 = $33;
   }
  }
 }
 $35 = (($26) + -1)|0;
 HEAP32[$25>>2] = $35;
 $36 = (($this) + 132|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($20>>>0)<($37>>>0);
 if ($38) {
  $39 = (($this) + 128|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + (($index$05*48)|0)|0);
  $44 = $20;$it$02$i = $41;
  while(1) {
   $42 = ($it$02$i|0)==(0|0);
   if (!($42)) {
    $43 = (($40) + (($44*48)|0)|0);
    $45 = Math_fround(HEAPF32[$43>>2]);
    HEAPF32[$it$02$i>>2] = $45;
    $46 = ((($40) + (($44*48)|0)|0) + 4|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = (($it$02$i) + 4|0);
    HEAPF32[$48>>2] = $47;
    $49 = ((($40) + (($44*48)|0)|0) + 8|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = (($it$02$i) + 8|0);
    HEAPF32[$51>>2] = $50;
    $52 = ((($40) + (($44*48)|0)|0) + 12|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = (($it$02$i) + 12|0);
    HEAPF32[$54>>2] = $53;
    $55 = ((($40) + (($44*48)|0)|0) + 16|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = (($it$02$i) + 16|0);
    HEAPF32[$57>>2] = $56;
    $58 = ((($40) + (($44*48)|0)|0) + 20|0);
    $59 = Math_fround(HEAPF32[$58>>2]);
    $60 = (($it$02$i) + 20|0);
    HEAPF32[$60>>2] = $59;
    $61 = ((($40) + (($44*48)|0)|0) + 24|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = (($it$02$i) + 24|0);
    HEAPF32[$63>>2] = $62;
    $64 = ((($40) + (($44*48)|0)|0) + 28|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    $66 = (($it$02$i) + 28|0);
    HEAPF32[$66>>2] = $65;
    $67 = ((($40) + (($44*48)|0)|0) + 32|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = (($it$02$i) + 32|0);
    HEAPF32[$69>>2] = $68;
    $70 = ((($40) + (($44*48)|0)|0) + 36|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = (($it$02$i) + 36|0);
    HEAPF32[$72>>2] = $71;
    $73 = ((($40) + (($44*48)|0)|0) + 40|0);
    $74 = Math_fround(HEAPF32[$73>>2]);
    $75 = (($it$02$i) + 40|0);
    HEAPF32[$75>>2] = $74;
    $76 = ((($40) + (($44*48)|0)|0) + 44|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = (($it$02$i) + 44|0);
    HEAPF32[$78>>2] = $77;
   }
   $79 = (($it$02$i) + 48|0);
   $80 = (($44) + 1)|0;
   $exitcond = ($80|0)==($37|0);
   if ($exitcond) {
    break;
   } else {
    $44 = $80;$it$02$i = $79;
   }
  }
 }
 $81 = (($37) + -1)|0;
 HEAP32[$36>>2] = $81;
 $82 = (($17) + -1)|0;
 HEAP32[$16>>2] = $82;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim23addCollisionHeightfieldEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0);
 var $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$01$i = 0;
 var $i$01$i$phi = 0, $trafo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 104|0;
 $trafo = sp;
 $1 = sp + 48|0;
 $2 = sp + 76|0;
 $3 = (($this) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4))|0;
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + ($9))|0;
 $11 = (($this) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12))|0;
 $14 = (($this) + 100|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + ($15))|0;
 $17 = (($this) + 104|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + ($18))|0;
 $20 = (($this) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($shape) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNK5physx2Sc9ClothCore13getGlobalPoseEv($1,$21);
 __ZNK5physx2Sc8ShapeSim10getAbsPoseEv($2,$shape);
 $24 = Math_fround(HEAPF32[$1>>2]);
 $25 = Math_fround(-$24);
 $26 = (($1) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround(-$27);
 $29 = (($1) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround(-$30);
 $32 = (($1) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($2) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($1) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 - $37);
 $39 = (($2) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($1) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 - $42);
 $44 = (($2) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($1) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 - $47);
 $49 = Math_fround($38 * Math_fround(2.0));
 $50 = Math_fround($43 * Math_fround(2.0));
 $51 = Math_fround($48 * Math_fround(2.0));
 $52 = Math_fround($33 * $33);
 $53 = Math_fround($52 + Math_fround(-0.5));
 $54 = Math_fround($49 * $25);
 $55 = Math_fround($50 * $28);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($51 * $31);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($53 * $49);
 $60 = Math_fround($51 * $28);
 $61 = Math_fround($50 * $31);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($33 * $62);
 $64 = Math_fround($59 + $63);
 $65 = Math_fround($58 * $25);
 $66 = Math_fround($65 + $64);
 $67 = Math_fround($53 * $50);
 $68 = Math_fround($49 * $31);
 $69 = Math_fround($51 * $25);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($33 * $70);
 $72 = Math_fround($67 + $71);
 $73 = Math_fround($58 * $28);
 $74 = Math_fround($73 + $72);
 $75 = Math_fround($53 * $51);
 $76 = Math_fround($50 * $25);
 $77 = Math_fround($49 * $28);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($33 * $78);
 $80 = Math_fround($75 + $79);
 $81 = Math_fround($58 * $31);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround(HEAPF32[$2>>2]);
 $84 = Math_fround($33 * $83);
 $85 = (($2) + 12|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 * $25);
 $88 = Math_fround($84 + $87);
 $89 = (($2) + 8|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($90 * $28);
 $92 = Math_fround($88 + $91);
 $93 = (($2) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 * $31);
 $96 = Math_fround($92 - $95);
 $97 = Math_fround($33 * $94);
 $98 = Math_fround($86 * $28);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($83 * $31);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($90 * $25);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($33 * $90);
 $105 = Math_fround($86 * $31);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($94 * $25);
 $108 = Math_fround($107 + $106);
 $109 = Math_fround($83 * $28);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($33 * $86);
 $112 = Math_fround($83 * $25);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($94 * $28);
 $115 = Math_fround($113 - $114);
 $116 = Math_fround($90 * $31);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($96 + $96);
 $119 = Math_fround($103 + $103);
 $120 = Math_fround($110 + $110);
 $121 = Math_fround($118 * $117);
 $122 = Math_fround($117 * $119);
 $123 = Math_fround($117 * $120);
 $124 = Math_fround($96 * $118);
 $125 = Math_fround($96 * $119);
 $126 = Math_fround($96 * $120);
 $127 = Math_fround($103 * $119);
 $128 = Math_fround($103 * $120);
 $129 = Math_fround($110 * $120);
 $130 = Math_fround(Math_fround(1.0) - $127);
 $131 = Math_fround($130 - $129);
 $132 = Math_fround($123 + $125);
 $133 = (($trafo) + 4|0);
 $134 = Math_fround($126 - $122);
 $135 = (($trafo) + 8|0);
 $136 = Math_fround($125 - $123);
 $137 = (($trafo) + 12|0);
 $138 = Math_fround(Math_fround(1.0) - $124);
 $139 = Math_fround($138 - $129);
 $140 = (($trafo) + 16|0);
 $141 = Math_fround($121 + $128);
 $142 = (($trafo) + 20|0);
 $143 = Math_fround($126 + $122);
 $144 = (($trafo) + 24|0);
 $145 = Math_fround($128 - $121);
 $146 = (($trafo) + 28|0);
 $147 = Math_fround($138 - $127);
 $148 = (($trafo) + 32|0);
 $149 = (($trafo) + 36|0);
 $150 = (($trafo) + 40|0);
 $151 = (($trafo) + 44|0);
 HEAPF32[$149>>2] = $66;
 HEAPF32[$150>>2] = $74;
 HEAPF32[$151>>2] = $82;
 $152 = (($23) + 80|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = Math_fround($153 * $131);
 HEAPF32[$trafo>>2] = $154;
 $155 = Math_fround($153 * $132);
 HEAPF32[$133>>2] = $155;
 $156 = Math_fround($153 * $134);
 HEAPF32[$135>>2] = $156;
 $157 = (($23) + 76|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround($158 * $136);
 HEAPF32[$137>>2] = $159;
 $160 = Math_fround($158 * $139);
 HEAPF32[$140>>2] = $160;
 $161 = Math_fround($158 * $141);
 HEAPF32[$142>>2] = $161;
 $162 = (($23) + 84|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = Math_fround($163 * $143);
 HEAPF32[$144>>2] = $164;
 $165 = Math_fround($163 * $145);
 HEAPF32[$146>>2] = $165;
 $166 = Math_fround($163 * $147);
 HEAPF32[$148>>2] = $166;
 $167 = (($this) + 108|0);
 $168 = HEAP32[$167>>2]|0;
 $169 = (($168) + 1)|0;
 HEAP32[$167>>2] = $169;
 $170 = (($19) + ($168))|0;
 $171 = (($this) + 116|0);
 HEAP32[$0>>2] = 0;
 $172 = (($this) + 124|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = $173 & 2147483647;
 $175 = (($this) + 120|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = ($174>>>0)>($176>>>0);
 if ($177) {
  $178 = HEAP32[$171>>2]|0;
  $179 = (($178) + ($176<<2)|0);
  $180 = ($179|0)==(0|0);
  if (!($180)) {
   HEAP32[$179>>2] = 0;
  }
  $181 = (($176) + 1)|0;
  HEAP32[$175>>2] = $181;
  $$pre$phiZ2D = $171;$183 = $181;
 } else {
  (__ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($171,$0)|0);
  $$pre$i = HEAP32[$175>>2]|0;
  $$pre$phiZ2D = $171;$183 = $$pre$i;
 }
 $182 = (($183) + -1)|0;
 $184 = ($182>>>0)>($170>>>0);
 if ($184) {
  $190 = $182;$i$01$i = $183;
  while(1) {
   $185 = (($i$01$i) + -2)|0;
   $186 = HEAP32[$$pre$phiZ2D>>2]|0;
   $187 = (($186) + ($185<<2)|0);
   $188 = HEAP32[$187>>2]|0;
   $189 = (($186) + ($190<<2)|0);
   HEAP32[$189>>2] = $188;
   $191 = (($190) + -1)|0;
   $192 = ($191>>>0)>($170>>>0);
   if ($192) {
    $i$01$i$phi = $190;$190 = $191;$i$01$i = $i$01$i$phi;
   } else {
    break;
   }
  }
 }
 $193 = HEAP32[$$pre$phiZ2D>>2]|0;
 $194 = (($193) + ($170<<2)|0);
 HEAP32[$194>>2] = $shape;
 $195 = (($this) + 128|0);
 $196 = (($this) + 136|0);
 $197 = HEAP32[$196>>2]|0;
 $198 = $197 & 2147483647;
 $199 = (($this) + 132|0);
 $200 = HEAP32[$199>>2]|0;
 $201 = ($198>>>0)>($200>>>0);
 if (!($201)) {
  (__ZN5physx6shdfnd5ArrayINS_2Cm8Matrix34ENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($195,$trafo)|0);
  STACKTOP = sp;return;
 }
 $202 = HEAP32[$195>>2]|0;
 $203 = (($202) + (($200*48)|0)|0);
 $204 = ($203|0)==(0|0);
 if (!($204)) {
  HEAPF32[$203>>2] = $154;
  $205 = ((($202) + (($200*48)|0)|0) + 4|0);
  HEAPF32[$205>>2] = $155;
  $206 = ((($202) + (($200*48)|0)|0) + 8|0);
  HEAPF32[$206>>2] = $156;
  $207 = ((($202) + (($200*48)|0)|0) + 12|0);
  HEAPF32[$207>>2] = $159;
  $208 = ((($202) + (($200*48)|0)|0) + 16|0);
  HEAPF32[$208>>2] = $160;
  $209 = ((($202) + (($200*48)|0)|0) + 20|0);
  HEAPF32[$209>>2] = $161;
  $210 = ((($202) + (($200*48)|0)|0) + 24|0);
  HEAPF32[$210>>2] = $164;
  $211 = ((($202) + (($200*48)|0)|0) + 28|0);
  HEAPF32[$211>>2] = $165;
  $212 = ((($202) + (($200*48)|0)|0) + 32|0);
  HEAPF32[$212>>2] = $166;
  $213 = ((($202) + (($200*48)|0)|0) + 36|0);
  HEAPF32[$213>>2] = $66;
  $214 = ((($202) + (($200*48)|0)|0) + 40|0);
  HEAPF32[$214>>2] = $74;
  $215 = ((($202) + (($200*48)|0)|0) + 44|0);
  HEAPF32[$215>>2] = $82;
 }
 $216 = (($200) + 1)|0;
 HEAP32[$199>>2] = $216;
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim26removeCollisionHeightfieldEPKNS0_8ShapeSimE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0;
 var $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $exitcond = 0, $exitcond6 = 0, $index$05 = 0, $it$02$i = 0, $it$02$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 $5 = (($this) + 92|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6))|0;
 $8 = (($this) + 96|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + ($9))|0;
 $11 = (($this) + 100|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12))|0;
 $14 = (($this) + 104|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + ($15))|0;
 $17 = (($this) + 116|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 108|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 } else {
  $index$05 = 0;
 }
 while(1) {
  $$sum = (($16) + ($index$05))|0;
  $24 = (($18) + ($$sum<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==($shape|0);
  $23 = (($index$05) + 1)|0;
  if ($26) {
   break;
  }
  $22 = ($23>>>0)<($20>>>0);
  if ($22) {
   $index$05 = $23;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
 $27 = (($$sum) + 1)|0;
 $28 = (($this) + 120|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27>>>0)<($29>>>0);
 if ($30) {
  $34 = $27;$it$02$i2 = $24;
  while(1) {
   $31 = ($it$02$i2|0)==(0|0);
   if (!($31)) {
    $32 = HEAP32[$17>>2]|0;
    $33 = (($32) + ($34<<2)|0);
    $35 = HEAP32[$33>>2]|0;
    HEAP32[$it$02$i2>>2] = $35;
   }
   $36 = (($it$02$i2) + 4|0);
   $37 = (($34) + 1)|0;
   $exitcond6 = ($37|0)==($29|0);
   if ($exitcond6) {
    break;
   } else {
    $34 = $37;$it$02$i2 = $36;
   }
  }
 }
 $38 = (($29) + -1)|0;
 HEAP32[$28>>2] = $38;
 $39 = (($15) + ($index$05))|0;
 $40 = (($39) + 1)|0;
 $41 = (($this) + 132|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($40>>>0)<($42>>>0);
 if ($43) {
  $44 = (($this) + 128|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + (($39*48)|0)|0);
  $49 = $40;$it$02$i = $46;
  while(1) {
   $47 = ($it$02$i|0)==(0|0);
   if (!($47)) {
    $48 = (($45) + (($49*48)|0)|0);
    $50 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$it$02$i>>2] = $50;
    $51 = ((($45) + (($49*48)|0)|0) + 4|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = (($it$02$i) + 4|0);
    HEAPF32[$53>>2] = $52;
    $54 = ((($45) + (($49*48)|0)|0) + 8|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = (($it$02$i) + 8|0);
    HEAPF32[$56>>2] = $55;
    $57 = ((($45) + (($49*48)|0)|0) + 12|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = (($it$02$i) + 12|0);
    HEAPF32[$59>>2] = $58;
    $60 = ((($45) + (($49*48)|0)|0) + 16|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = (($it$02$i) + 16|0);
    HEAPF32[$62>>2] = $61;
    $63 = ((($45) + (($49*48)|0)|0) + 20|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = (($it$02$i) + 20|0);
    HEAPF32[$65>>2] = $64;
    $66 = ((($45) + (($49*48)|0)|0) + 24|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = (($it$02$i) + 24|0);
    HEAPF32[$68>>2] = $67;
    $69 = ((($45) + (($49*48)|0)|0) + 28|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = (($it$02$i) + 28|0);
    HEAPF32[$71>>2] = $70;
    $72 = ((($45) + (($49*48)|0)|0) + 32|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = (($it$02$i) + 32|0);
    HEAPF32[$74>>2] = $73;
    $75 = ((($45) + (($49*48)|0)|0) + 36|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = (($it$02$i) + 36|0);
    HEAPF32[$77>>2] = $76;
    $78 = ((($45) + (($49*48)|0)|0) + 40|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = (($it$02$i) + 40|0);
    HEAPF32[$80>>2] = $79;
    $81 = ((($45) + (($49*48)|0)|0) + 44|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = (($it$02$i) + 44|0);
    HEAPF32[$83>>2] = $82;
   }
   $84 = (($it$02$i) + 48|0);
   $85 = (($49) + 1)|0;
   $exitcond = ($85|0)==($42|0);
   if ($exitcond) {
    break;
   } else {
    $49 = $85;$it$02$i = $84;
   }
  }
 }
 $86 = (($42) + -1)|0;
 HEAP32[$41>>2] = $86;
 $87 = (($20) + -1)|0;
 HEAP32[$19>>2] = $87;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_19PxHeightFieldSampleENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_19PxHeightFieldSampleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAPU16[$a>>1]|(HEAPU16[$a+2>>1]<<16);
   HEAP16[$$01$i>>1]=$11&65535;HEAP16[$$01$i+2>>1]=$11>>>16;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_115offsetTrianglesEPN5physx6PxVec3ES2_f($it,$end,$offset) {
 $it = $it|0;
 $end = $end|0;
 $offset = Math_fround($offset);
 var $$019 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $7 = Math_fround(0);
 var $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($it>>>0)<($end>>>0);
 if ($0) {
  $$019 = $it;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $1 = Math_fround(HEAPF32[$$019>>2]);
  $2 = (($$019) + 4|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = (($$019) + 8|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($$019) + 12|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($$019) + 16|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($$019) + 20|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($$019) + 24|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($$019) + 28|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($$019) + 32|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($7 - $1);
  $19 = Math_fround($9 - $3);
  $20 = Math_fround($11 - $5);
  $21 = Math_fround($13 - $1);
  $22 = Math_fround($15 - $3);
  $23 = Math_fround($17 - $5);
  $24 = Math_fround($19 * $23);
  $25 = Math_fround($20 * $22);
  $26 = Math_fround($24 - $25);
  $27 = Math_fround($20 * $21);
  $28 = Math_fround($18 * $23);
  $29 = Math_fround($27 - $28);
  $30 = Math_fround($18 * $22);
  $31 = Math_fround($19 * $21);
  $32 = Math_fround($30 - $31);
  $33 = Math_fround($26 * $26);
  $34 = Math_fround($29 * $29);
  $35 = Math_fround($33 + $34);
  $36 = Math_fround($32 * $32);
  $37 = Math_fround($36 + $35);
  $38 = $37 > Math_fround(0.0);
  if ($38) {
   $39 = (Math_fround(Math_sqrt((Math_fround($37)))));
   $40 = Math_fround(Math_fround(1.0) / $39);
   $41 = Math_fround($26 * $40);
   $42 = Math_fround($29 * $40);
   $43 = Math_fround($32 * $40);
   $45 = $41;$47 = $42;$49 = $43;
  } else {
   $45 = Math_fround(0.0);$47 = Math_fround(0.0);$49 = Math_fround(0.0);
  }
  $44 = Math_fround($45 * $offset);
  $46 = Math_fround($47 * $offset);
  $48 = Math_fround($49 * $offset);
  $50 = Math_fround($1 + $44);
  $51 = Math_fround($3 + $46);
  $52 = Math_fround($5 + $48);
  HEAPF32[$$019>>2] = $50;
  HEAPF32[$2>>2] = $51;
  HEAPF32[$4>>2] = $52;
  $53 = Math_fround($7 + $44);
  $54 = Math_fround($9 + $46);
  $55 = Math_fround($11 + $48);
  HEAPF32[$6>>2] = $53;
  HEAPF32[$8>>2] = $54;
  HEAPF32[$10>>2] = $55;
  $56 = Math_fround($13 + $44);
  $57 = Math_fround($15 + $46);
  $58 = Math_fround($17 + $48);
  HEAPF32[$12>>2] = $56;
  HEAPF32[$14>>2] = $57;
  HEAPF32[$16>>2] = $58;
  $59 = (($$019) + 36|0);
  $60 = ($59>>>0)<($end>>>0);
  if ($60) {
   $$019 = $59;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sc8ClothSim20clearCollisionShapesEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy2 = sp + 32|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 16|0;
 $3 = sp + 24|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 164|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = 0;
 $11 = (($0) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($5) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($8) + 168|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($7)|0);
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$10 & 511]($7,$$byval_copy2,$13,$16);
 $17 = HEAP32[$7>>2]|0;
 $18 = (($17) + 180|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$1>>2] = 0;
 $20 = (($1) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($5) + 80|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($17) + 184|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_ii[$24 & 4095]($7)|0);
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$1+4>>2]|0;
 FUNCTION_TABLE_viiii[$19 & 511]($7,$$byval_copy2,$22,$25);
 $26 = HEAP32[$7>>2]|0;
 $27 = (($26) + 196|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$2>>2] = 0;
 $29 = (($2) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($5) + 88|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($26) + 204|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 4095]($7)|0);
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 FUNCTION_TABLE_viiii[$28 & 511]($7,$$byval_copy2,$31,$34);
 $35 = (($this) + 84|0);
 $36 = (($this) + 116|0);
 ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;HEAP32[$35+20>>2]=0|0;HEAP32[$35+24>>2]=0|0;HEAP32[$35+28>>2]=0|0;
 HEAP32[$3>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE6resizeEjRKS5_($36,0,$3);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE6resizeEjRKS5_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 477504 : 477472;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,477392,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPKNS_2Sc8ShapeSimENS0_19ReflectionAllocatorIS5_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 477504 : 477472;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,477392,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_19PxHeightFieldSampleENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 477632 : 477472;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,477392,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAPU16[$$03$i>>1]|(HEAPU16[$$03$i+2>>1]<<16);
    HEAP16[$$012$i>>1]=$20&65535;HEAP16[$$012$i+2>>1]=$20>>>16;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Cm8Matrix34ENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0;
 var $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0;
 var $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0;
 var $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0;
 var $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*48)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 477760 : 477472;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,477392,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*48)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$03$i) + 4|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = (($$012$i) + 4|0);
    HEAPF32[$28>>2] = $27;
    $29 = (($$03$i) + 8|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = (($$012$i) + 8|0);
    HEAPF32[$31>>2] = $30;
    $32 = (($$03$i) + 12|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = (($$012$i) + 12|0);
    HEAPF32[$34>>2] = $33;
    $35 = (($$03$i) + 16|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = (($$012$i) + 16|0);
    HEAPF32[$37>>2] = $36;
    $38 = (($$03$i) + 20|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = (($$012$i) + 20|0);
    HEAPF32[$40>>2] = $39;
    $41 = (($$03$i) + 24|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = (($$012$i) + 24|0);
    HEAPF32[$43>>2] = $42;
    $44 = (($$03$i) + 28|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = (($$012$i) + 28|0);
    HEAPF32[$46>>2] = $45;
    $47 = (($$03$i) + 32|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = (($$012$i) + 32|0);
    HEAPF32[$49>>2] = $48;
    $50 = (($$03$i) + 36|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = (($$012$i) + 36|0);
    HEAPF32[$52>>2] = $51;
    $53 = (($$03$i) + 40|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = (($$012$i) + 40|0);
    HEAPF32[$55>>2] = $54;
    $56 = (($$03$i) + 44|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = (($$012$i) + 44|0);
    HEAPF32[$58>>2] = $57;
   }
   $59 = (($$012$i) + 48|0);
   $60 = (($$03$i) + 48|0);
   $61 = ($59>>>0)<($20>>>0);
   if ($61) {
    $$012$i = $59;$$03$i = $60;
   } else {
    break;
   }
  }
 }
 $62 = ($20|0)==(0|0);
 if (!($62)) {
  $63 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$20>>2] = $63;
  $64 = (($a) + 4|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($21) + (($19*48)|0)|0) + 4|0);
  HEAPF32[$66>>2] = $65;
  $67 = (($a) + 8|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = ((($21) + (($19*48)|0)|0) + 8|0);
  HEAPF32[$69>>2] = $68;
  $70 = (($a) + 12|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = ((($21) + (($19*48)|0)|0) + 12|0);
  HEAPF32[$72>>2] = $71;
  $73 = (($a) + 16|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = ((($21) + (($19*48)|0)|0) + 16|0);
  HEAPF32[$75>>2] = $74;
  $76 = (($a) + 20|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = ((($21) + (($19*48)|0)|0) + 20|0);
  HEAPF32[$78>>2] = $77;
  $79 = (($a) + 24|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = ((($21) + (($19*48)|0)|0) + 24|0);
  HEAPF32[$81>>2] = $80;
  $82 = (($a) + 28|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = ((($21) + (($19*48)|0)|0) + 28|0);
  HEAPF32[$84>>2] = $83;
  $85 = (($a) + 32|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = ((($21) + (($19*48)|0)|0) + 32|0);
  HEAPF32[$87>>2] = $86;
  $88 = (($a) + 36|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = ((($21) + (($19*48)|0)|0) + 36|0);
  HEAPF32[$90>>2] = $89;
  $91 = (($a) + 40|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = ((($21) + (($19*48)|0)|0) + 40|0);
  HEAPF32[$93>>2] = $92;
  $94 = (($a) + 44|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = ((($21) + (($19*48)|0)|0) + 44|0);
  HEAPF32[$96>>2] = $95;
 }
 $97 = HEAP32[$0>>2]|0;
 $98 = ($97|0)>(-1);
 if (!($98)) {
  $106 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $105 = (($106) + 1)|0;
  HEAP32[$18>>2] = $105;
  $107 = (($21) + (($106*48)|0)|0);
  STACKTOP = sp;return ($107|0);
 }
 $99 = HEAP32[$this>>2]|0;
 $100 = ($99|0)==(0|0);
 if ($100) {
  $106 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $105 = (($106) + 1)|0;
  HEAP32[$18>>2] = $105;
  $107 = (($21) + (($106*48)|0)|0);
  STACKTOP = sp;return ($107|0);
 }
 $101 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = (($102) + 12|0);
 $104 = HEAP32[$103>>2]|0;
 FUNCTION_TABLE_vii[$104 & 4095]($101,$99);
 $$pre = HEAP32[$18>>2]|0;
 $106 = $$pre;
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $105 = (($106) + 1)|0;
 HEAP32[$18>>2] = $105;
 $107 = (($21) + (($106*48)|0)|0);
 STACKTOP = sp;return ($107|0);
}
function __ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 4;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 477872 : 477472;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,477392,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<4)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
   }
   $35 = (($$012$i) + 16|0);
   $36 = (($$03$i) + 16|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
 }
 $38 = ($20|0)==(0|0);
 if (!($38)) {
  $39 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$20>>2] = $39;
  $40 = ((($21) + ($19<<4)|0) + 4|0);
  $41 = (($a) + 4|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$40>>2] = $42;
  $43 = ((($21) + ($19<<4)|0) + 8|0);
  $44 = (($a) + 8|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$43>>2] = $45;
  $46 = ((($21) + ($19<<4)|0) + 12|0);
  $47 = (($a) + 12|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  HEAPF32[$46>>2] = $48;
 }
 $49 = HEAP32[$0>>2]|0;
 $50 = ($49|0)>(-1);
 if (!($50)) {
  $58 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $57 = (($58) + 1)|0;
  HEAP32[$18>>2] = $57;
  $59 = (($21) + ($58<<4)|0);
  STACKTOP = sp;return ($59|0);
 }
 $51 = HEAP32[$this>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  $58 = $19;
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $57 = (($58) + 1)|0;
  HEAP32[$18>>2] = $57;
  $59 = (($21) + ($58<<4)|0);
  STACKTOP = sp;return ($59|0);
 }
 $53 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vii[$56 & 4095]($53,$51);
 $$pre = HEAP32[$18>>2]|0;
 $58 = $$pre;
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $57 = (($58) + 1)|0;
 HEAP32[$18>>2] = $57;
 $59 = (($21) + ($58<<4)|0);
 STACKTOP = sp;return ($59|0);
}
function __ZN5physx6shdfnd5ArrayINS_7PxPlaneENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 477872 : 477472;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,477392,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
   }
   $30 = (($$012$i) + 16|0);
   $31 = (($$03$i) + 16|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8allocateEj($n) {
 $n = $n|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $6 = 0;
  STACKTOP = sp;return ($6|0);
 }
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,$n,477976,477984,38)|0);
 $6 = $5;
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx5cloth10deallocateEPv($ptr) {
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$ptr);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth15getNextFabricIdEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[478064>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[478064>>2] = $1;
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx5cloth7Factory13createFactoryENS1_8PlatformEPv($platform,$contextManager) {
 $platform = $platform|0;
 $contextManager = $contextManager|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($platform|0)==(0);
 if ($0) {
  $1 = (__ZN5physx5cloth8allocateEj(24)|0);
  __ZN5physx5cloth9SwFactoryC2Ev($1);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (($1) + 4|0);
   $$0 = $3;
  }
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx5cloth11PhaseConfigC2Et($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP16[$this>>1] = $index;
 $0 = (($this) + 2|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 4|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 8|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 12|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 16|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9transformERKNS0_11PhaseConfigE($agg$result,$config) {
 $agg$result = $agg$result|0;
 $config = $config|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$config>>1]|0;
 HEAP16[$agg$result>>1] = $0;
 $1 = (($agg$result) + 2|0);
 HEAP16[$1>>1] = -1;
 $2 = (($agg$result) + 4|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 8|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($agg$result) + 12|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($agg$result) + 16|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($config) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(Math_fround(1.0) - $7);
 $9 = $8 < Math_fround(1.0);
 $10 = $9 ? $8 : Math_fround(1.0);
 $11 = $10 < Math_fround(0.0);
 $12 = $11 ? Math_fround(0.0) : $10;
 $13 = $12 != Math_fround(0.0);
 if ($13) {
  $14 = +$12;
  $15 = (+Math_log((+$14)));
  $16 = $15 / 0.693147182464599609375;
  $17 = Math_fround($16);
  $18 = $17;
 } else {
  $18 = Math_fround(-128.0);
 }
 HEAPF32[$2>>2] = $18;
 $19 = (($config) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = $20 < Math_fround(1.0);
 $22 = $21 ? $20 : Math_fround(1.0);
 $23 = $22 < Math_fround(0.0);
 $24 = $23 ? Math_fround(0.0) : $22;
 $25 = $24 != Math_fround(0.0);
 if ($25) {
  $26 = +$24;
  $27 = (+Math_log((+$26)));
  $28 = $27 / 0.693147182464599609375;
  $29 = Math_fround($28);
  $30 = $29;
 } else {
  $30 = Math_fround(-128.0);
 }
 HEAPF32[$3>>2] = $30;
 $31 = (($config) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(Math_fround(1.0) / $32);
 $34 = Math_fround(Math_fround(1.0) - $33);
 HEAPF32[$4>>2] = $34;
 $35 = (($config) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(Math_fround(1.0) / $36);
 $38 = Math_fround(Math_fround(1.0) - $37);
 HEAPF32[$5>>2] = $38;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth7SwClothC2ERNS0_9SwFactoryERNS0_8SwFabricENS0_5RangeIKNS_6PxVec4EEE($this,$factory,$fabric,$particles) {
 $this = $this|0;
 $factory = $factory|0;
 $fabric = $fabric|0;
 $particles = $particles|0;
 var $$012$i$i = 0, $$012$i$i$i = 0, $$03$i$i = 0, $$03$i$i$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = sp + 16|0;
 HEAP32[$this>>2] = $factory;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = $fabric;
 $4 = (($this) + 8|0);
 $5 = (($this) + 12|0);
 $6 = (($this) + 16|0);
 $7 = (($this) + 20|0);
 $8 = (($this) + 24|0);
 $9 = (($this) + 28|0);
 $10 = (($this) + 232|0);
 $11 = (($this) + 248|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 HEAP32[$11>>2] = 1;
 $12 = (($this) + 252|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 256|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 260|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 272|0);
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP32[$15+20>>2]=0|0;
 $16 = (($this) + 308|0);
 $17 = (($this) + 452|0);
 $18 = (($this) + 488|0);
 $19 = (($this) + 532|0);
 HEAP32[$19>>2] = 0;
 _memset(($16|0),0,132)|0;
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;HEAP32[$17+16>>2]=0|0;HEAP32[$17+20>>2]=0|0;HEAP32[$17+24>>2]=0|0;
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;
 $20 = HEAP32[$particles>>2]|0;
 $21 = (($particles) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx5cloth10initializeINS0_7SwClothEEEvRT_PKNS_6PxVec4ES7_($this,$20,$22);
 $23 = $22;
 $24 = $20;
 $25 = (($23) - ($24))|0;
 $26 = $25 >> 4;
 $27 = (($26) + 3)|0;
 $28 = HEAP32[$6>>2]|0;
 $29 = $28 & 2147483647;
 $30 = ($29>>>0)<($27>>>0);
 if ($30) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($4,$27);
 }
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE19resizeUninitializedEj($4,$26);
 $31 = HEAP32[$4>>2]|0;
 $32 = HEAP32[$5>>2]|0;
 $33 = (($31) + ($32<<4)|0);
 $34 = ($32|0)>(0);
 if ($34) {
  $$012$i$i = $31;$$03$i$i = $20;
  while(1) {
   $35 = ($$012$i$i|0)==(0|0);
   if (!($35)) {
    $36 = Math_fround(HEAPF32[$$03$i$i>>2]);
    HEAPF32[$$012$i$i>>2] = $36;
    $37 = (($$012$i$i) + 4|0);
    $38 = (($$03$i$i) + 4|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    HEAPF32[$37>>2] = $39;
    $40 = (($$012$i$i) + 8|0);
    $41 = (($$03$i$i) + 8|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    HEAPF32[$40>>2] = $42;
    $43 = (($$012$i$i) + 12|0);
    $44 = (($$03$i$i) + 12|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$43>>2] = $45;
   }
   $46 = (($$012$i$i) + 16|0);
   $47 = (($$03$i$i) + 16|0);
   $48 = ($46>>>0)<($33>>>0);
   if ($48) {
    $$012$i$i = $46;$$03$i$i = $47;
   } else {
    break;
   }
  }
 }
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($4,$27,$0);
 HEAP32[$8>>2] = 0;
 $49 = HEAP32[$5>>2]|0;
 $50 = HEAP32[$9>>2]|0;
 $51 = $50 & 2147483647;
 $52 = ($51>>>0)<($49>>>0);
 if ($52) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($7,$49);
  $$pre$i$i = HEAP32[$5>>2]|0;
  $55 = $$pre$i$i;
 } else {
  $55 = $49;
 }
 $53 = HEAP32[$7>>2]|0;
 $54 = (($53) + ($55<<4)|0);
 $56 = ($55|0)>(0);
 if (!($56)) {
  HEAP32[$8>>2] = $55;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($4,$26,$1);
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($7,$26,$2);
  $72 = HEAP32[$3>>2]|0;
  $73 = (($72) + 8|0);
  $74 = HEAP16[$73>>1]|0;
  $75 = (($74) + 1)<<16>>16;
  HEAP16[$73>>1] = $75;
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$4>>2]|0;
 $$012$i$i$i = $53;$$03$i$i$i = $57;
 while(1) {
  $58 = ($$012$i$i$i|0)==(0|0);
  if (!($58)) {
   $59 = Math_fround(HEAPF32[$$03$i$i$i>>2]);
   HEAPF32[$$012$i$i$i>>2] = $59;
   $60 = (($$012$i$i$i) + 4|0);
   $61 = (($$03$i$i$i) + 4|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   HEAPF32[$60>>2] = $62;
   $63 = (($$012$i$i$i) + 8|0);
   $64 = (($$03$i$i$i) + 8|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   HEAPF32[$63>>2] = $65;
   $66 = (($$012$i$i$i) + 12|0);
   $67 = (($$03$i$i$i) + 12|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   HEAPF32[$66>>2] = $68;
  }
  $69 = (($$012$i$i$i) + 16|0);
  $70 = (($$03$i$i$i) + 16|0);
  $71 = ($69>>>0)<($54>>>0);
  if ($71) {
   $$012$i$i$i = $69;$$03$i$i$i = $70;
  } else {
   break;
  }
 }
 HEAP32[$8>>2] = $55;
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($4,$26,$1);
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($7,$26,$2);
 $72 = HEAP32[$3>>2]|0;
 $73 = (($72) + 8|0);
 $74 = HEAP16[$73>>1]|0;
 $75 = (($74) + 1)<<16>>16;
 HEAP16[$73>>1] = $75;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth10initializeINS0_7SwClothEEEvRT_PKNS_6PxVec4ES7_($cloth,$pIt,$pEnd) {
 $cloth = $cloth|0;
 $pIt = $pIt|0;
 $pEnd = $pEnd|0;
 var $$056 = 0, $$lcssa = Math_fround(0), $$lcssa51 = Math_fround(0), $$lcssa52 = Math_fround(0), $$lcssa53 = Math_fround(0), $$lcssa54 = Math_fround(0), $$lcssa55 = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0);
 var $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = ($pIt|0)==($pEnd|0);
 if ($1) {
  $$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa51 = Math_fround(3.40282346638528859812E+38);$$lcssa52 = Math_fround(3.40282346638528859812E+38);$$lcssa53 = Math_fround(-3.40282346638528859812E+38);$$lcssa54 = Math_fround(-3.40282346638528859812E+38);$$lcssa55 = Math_fround(-3.40282346638528859812E+38);
 } else {
  $$056 = $pIt;$14 = Math_fround(3.40282346638528859812E+38);$17 = Math_fround(-3.40282346638528859812E+38);$20 = Math_fround(-3.40282346638528859812E+38);$23 = Math_fround(-3.40282346638528859812E+38);$4 = Math_fround(3.40282346638528859812E+38);$9 = Math_fround(3.40282346638528859812E+38);
  while(1) {
   $2 = Math_fround(HEAPF32[$$056>>2]);
   $3 = $4 < $2;
   $5 = $3 ? $4 : $2;
   $6 = (($$056) + 4|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $9 < $7;
   $10 = $8 ? $9 : $7;
   $11 = (($$056) + 8|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $14 < $12;
   $15 = $13 ? $14 : $12;
   $16 = $17 > $2;
   $18 = $16 ? $17 : $2;
   $19 = $20 > $7;
   $21 = $19 ? $20 : $7;
   $22 = $23 > $12;
   $24 = $22 ? $23 : $12;
   $25 = (($$056) + 16|0);
   $26 = ($25|0)==($pEnd|0);
   if ($26) {
    $$lcssa = $15;$$lcssa51 = $10;$$lcssa52 = $5;$$lcssa53 = $24;$$lcssa54 = $21;$$lcssa55 = $18;
    break;
   } else {
    $$056 = $25;$14 = $15;$17 = $18;$20 = $21;$23 = $24;$4 = $5;$9 = $10;
   }
  }
 }
 $27 = Math_fround($$lcssa52 + $$lcssa55);
 $28 = Math_fround($$lcssa51 + $$lcssa54);
 $29 = Math_fround($$lcssa + $$lcssa53);
 $30 = Math_fround($27 * Math_fround(0.5));
 $31 = Math_fround($28 * Math_fround(0.5));
 $32 = Math_fround($29 * Math_fround(0.5));
 $33 = Math_fround($$lcssa55 - $$lcssa52);
 $34 = Math_fround($$lcssa54 - $$lcssa51);
 $35 = Math_fround($$lcssa53 - $$lcssa);
 $36 = Math_fround($33 * Math_fround(0.5));
 $37 = Math_fround($34 * Math_fround(0.5));
 $38 = Math_fround($35 * Math_fround(0.5));
 $39 = (($cloth) + 32|0);
 HEAPF32[$39>>2] = $30;
 $40 = (($cloth) + 36|0);
 HEAPF32[$40>>2] = $31;
 $41 = (($cloth) + 40|0);
 HEAPF32[$41>>2] = $32;
 $42 = (($cloth) + 44|0);
 HEAPF32[$42>>2] = $36;
 $43 = (($cloth) + 48|0);
 HEAPF32[$43>>2] = $37;
 $44 = (($cloth) + 52|0);
 HEAPF32[$44>>2] = $38;
 $45 = (($cloth) + 56|0);
 $46 = (($cloth) + 104|0);
 dest=$45+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$46>>2] = Math_fround(1.0);
 $47 = (($cloth) + 108|0);
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (($cloth) + 112|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($cloth) + 116|0);
 HEAPF32[$49>>2] = Math_fround(1.0);
 $50 = (($cloth) + 120|0);
 HEAPF32[$50>>2] = Math_fround(1.0);
 $51 = (($cloth) + 124|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 $52 = (($cloth) + 128|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($cloth) + 132|0);
 HEAPF32[$53>>2] = Math_fround(1.0);
 $54 = (($cloth) + 136|0);
 HEAPF32[$54>>2] = Math_fround(1.0);
 $55 = (($cloth) + 140|0);
 HEAPF32[$55>>2] = Math_fround(60.0);
 $56 = (($cloth) + 144|0);
 HEAPF32[$56>>2] = Math_fround(10.0);
 $57 = (($cloth) + 148|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($cloth) + 152|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($cloth) + 156|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($cloth) + 160|0);
 HEAPF32[$60>>2] = Math_fround(1.0);
 $61 = (($cloth) + 164|0);
 $62 = (($cloth) + 188|0);
 ;HEAP32[$61+0>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;HEAP32[$61+12>>2]=0|0;HEAP32[$61+16>>2]=0|0;HEAP32[$61+20>>2]=0|0;
 HEAPF32[$62>>2] = Math_fround(1.0);
 $63 = (($cloth) + 192|0);
 $64 = (($cloth) + 232|0);
 $65 = (($0) + 16|0);
 dest=$63+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 HEAP32[$65>>2] = 30;
 $66 = ($0|0)==($64|0);
 if ($66) {
  $81 = 0;
 } else {
  $67 = (($cloth) + 236|0);
  HEAP32[$67>>2] = 0;
  $$phi$trans$insert = (($0) + 8|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $81 = $$pre;
 }
 $68 = (($cloth) + 244|0);
 $69 = (($0) + 12|0);
 $70 = $69;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = (($70) + 4)|0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = $68;
 $77 = $76;
 HEAP32[$77>>2] = $72;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $75;
 $80 = $81 & 2147483647;
 $82 = ($80|0)!=(0);
 $83 = ($81|0)>(-1);
 $or$cond$i$i$i$i = $82 & $83;
 if ($or$cond$i$i$i$i) {
  $84 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$84);
 }
 $85 = (($cloth) + 264|0);
 HEAPF32[$85>>2] = Math_fround(-128.0);
 $86 = (($cloth) + 268|0);
 HEAPF32[$86>>2] = Math_fround(1.0);
 $87 = (($cloth) + 296|0);
 HEAPF32[$87>>2] = Math_fround(1.0);
 $88 = (($cloth) + 300|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($cloth) + 304|0);
 HEAPF32[$89>>2] = Math_fround(-128.0);
 $90 = (($cloth) + 440|0);
 HEAP8[$90>>0] = 0;
 $91 = (($cloth) + 444|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($cloth) + 448|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $93 = (($cloth) + 480|0);
 HEAPF32[$93>>2] = Math_fround(0.0);
 $94 = (($cloth) + 484|0);
 HEAPF32[$94>>2] = Math_fround(-128.0);
 $95 = (($cloth) + 512|0);
 HEAP32[$95>>2] = -1;
 $96 = (($cloth) + 516|0);
 HEAP32[$96>>2] = -1;
 $97 = (($cloth) + 520|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 $98 = (($cloth) + 524|0);
 HEAP32[$98>>2] = 0;
 $99 = (($cloth) + 528|0);
 HEAP32[$99>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $$01$i = $9;
 while(1) {
  $13 = ($$01$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $14;
   $15 = (($$01$i) + 4|0);
   $16 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$15>>2] = $16;
   $17 = (($$01$i) + 8|0);
   $18 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$17>>2] = $18;
   $19 = (($$01$i) + 12|0);
   $20 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$19>>2] = $20;
  }
  $21 = (($$01$i) + 16|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth7SwClothC2ERNS0_9SwFactoryERKS1_($this,$factory,$cloth) {
 $this = $this|0;
 $factory = $factory|0;
 $cloth = $cloth|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $factory;
 $0 = (($this) + 4|0);
 $1 = (($cloth) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($this) + 8|0);
 $4 = (($this) + 20|0);
 $5 = (($this) + 232|0);
 $6 = (($this) + 248|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 HEAP32[$6>>2] = 1;
 $7 = (($this) + 252|0);
 $8 = (($cloth) + 252|0);
 __ZN5physx6shdfnd5ArrayINS_5cloth11PhaseConfigENS0_9AllocatorEE4copyIS4_EEvRKNS1_IS3_T_EE($7,$8);
 $9 = (($this) + 272|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;
 $10 = (($this) + 308|0);
 $11 = (($this) + 332|0);
 $12 = (($this) + 344|0);
 $13 = (($cloth) + 344|0);
 dest=$10+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx6shdfnd5ArrayINS_5cloth9IndexPairENS0_9AllocatorEE4copyIS4_EEvRKNS1_IS3_T_EE($12,$13);
 $14 = (($this) + 356|0);
 $15 = (($cloth) + 356|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE4copyIS5_EEvRKNS1_IS2_T_EE($14,$15);
 $16 = (($this) + 368|0);
 $17 = (($cloth) + 368|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE4copyIS5_EEvRKNS1_IS2_T_EE($16,$17);
 $18 = (($this) + 380|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 384|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 388|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 392|0);
 $22 = (($cloth) + 392|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE4copyIS5_EEvRKNS1_IS2_T_EE($21,$22);
 $23 = (($this) + 404|0);
 $24 = (($cloth) + 404|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE4copyIS5_EEvRKNS1_IS2_T_EE($23,$24);
 $25 = (($this) + 416|0);
 $26 = (($cloth) + 416|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE4copyIS3_EEvRKNS1_IS2_T_EE($25,$26);
 $27 = (($this) + 428|0);
 $28 = (($cloth) + 428|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE4copyIS3_EEvRKNS1_IS2_T_EE($27,$28);
 $29 = (($this) + 452|0);
 $30 = (($cloth) + 452|0);
 __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE4copyIS5_EEvRKNS1_IS4_T_EE($29,$30);
 $31 = (($this) + 464|0);
 $32 = (($cloth) + 464|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE4copyIS5_EEvRKNS1_IS2_T_EE($31,$32);
 $33 = (($this) + 476|0);
 $34 = (($cloth) + 476|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$33>>2] = $35;
 $36 = (($this) + 488|0);
 $37 = (($cloth) + 488|0);
 __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE4copyIS2_EEvRKNS1_IjT_EE($36,$37);
 $38 = (($this) + 500|0);
 $39 = (($cloth) + 500|0);
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE4copyIS5_EEvRKNS1_IS2_T_EE($38,$39);
 __ZN5physx5cloth4copyINS0_7SwClothES2_EEvRT_RKT0_($this,$cloth);
 $40 = (($cloth) + 8|0);
 __ZN12_GLOBAL__N_110copyVectorERN5physx6shdfnd5ArrayINS0_6PxVec4ENS1_16AlignedAllocatorILj16ENS1_9AllocatorEEEEERKS7_($3,$40);
 $41 = (($cloth) + 20|0);
 __ZN12_GLOBAL__N_110copyVectorERN5physx6shdfnd5ArrayINS0_6PxVec4ENS1_16AlignedAllocatorILj16ENS1_9AllocatorEEEEERKS7_($4,$41);
 $42 = (($cloth) + 272|0);
 __ZN12_GLOBAL__N_110copyVectorERN5physx6shdfnd5ArrayINS0_6PxVec4ENS1_16AlignedAllocatorILj16ENS1_9AllocatorEEEEERKS7_($9,$42);
 $43 = (($this) + 284|0);
 $44 = (($cloth) + 284|0);
 __ZN12_GLOBAL__N_110copyVectorERN5physx6shdfnd5ArrayINS0_6PxVec4ENS1_16AlignedAllocatorILj16ENS1_9AllocatorEEEEERKS7_($43,$44);
 $45 = (($cloth) + 308|0);
 __ZN12_GLOBAL__N_110copyVectorERN5physx6shdfnd5ArrayINS0_6PxVec4ENS1_16AlignedAllocatorILj16ENS1_9AllocatorEEEEERKS7_($10,$45);
 $46 = (($this) + 320|0);
 $47 = (($cloth) + 320|0);
 __ZN12_GLOBAL__N_110copyVectorERN5physx6shdfnd5ArrayINS0_6PxVec4ENS1_16AlignedAllocatorILj16ENS1_9AllocatorEEEEERKS7_($46,$47);
 $48 = (($cloth) + 332|0);
 __ZN12_GLOBAL__N_110copyVectorERN5physx6shdfnd5ArrayINS0_6PxVec4ENS1_16AlignedAllocatorILj16ENS1_9AllocatorEEEEERKS7_($11,$48);
 $49 = HEAP32[$0>>2]|0;
 $50 = (($49) + 8|0);
 $51 = HEAP16[$50>>1]|0;
 $52 = (($51) + 1)<<16>>16;
 HEAP16[$50>>1] = $52;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth4copyINS0_7SwClothES2_EEvRT_RKT0_($dstCloth,$srcCloth) {
 $dstCloth = $dstCloth|0;
 $srcCloth = $srcCloth|0;
 var $$012$i$i$i$i = 0, $$03$i$i$i$i = 0, $$pre$i$i$i = 0, $$pre1$i$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0;
 var $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0);
 var $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0);
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0);
 var $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0;
 var $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0;
 var $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0;
 var $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($srcCloth) + 32|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($dstCloth) + 32|0);
 HEAPF32[$2>>2] = $1;
 $3 = (($srcCloth) + 36|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($dstCloth) + 36|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($srcCloth) + 40|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($dstCloth) + 40|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($srcCloth) + 44|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($dstCloth) + 44|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($srcCloth) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($dstCloth) + 48|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($srcCloth) + 52|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($dstCloth) + 52|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($srcCloth) + 56|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($dstCloth) + 56|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($srcCloth) + 60|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($dstCloth) + 60|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($srcCloth) + 64|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($dstCloth) + 64|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($srcCloth) + 68|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($dstCloth) + 68|0);
 HEAPF32[$29>>2] = $28;
 $30 = (($srcCloth) + 72|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($dstCloth) + 72|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($srcCloth) + 76|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($dstCloth) + 76|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($srcCloth) + 80|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($dstCloth) + 80|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($srcCloth) + 84|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($dstCloth) + 84|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($srcCloth) + 88|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($dstCloth) + 88|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($srcCloth) + 92|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($dstCloth) + 92|0);
 HEAPF32[$47>>2] = $46;
 $48 = (($srcCloth) + 96|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($dstCloth) + 96|0);
 HEAPF32[$50>>2] = $49;
 $51 = (($srcCloth) + 100|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($dstCloth) + 100|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($srcCloth) + 104|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($dstCloth) + 104|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($srcCloth) + 108|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($dstCloth) + 108|0);
 HEAPF32[$59>>2] = $58;
 $60 = (($srcCloth) + 112|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($dstCloth) + 112|0);
 HEAPF32[$62>>2] = $61;
 $63 = (($srcCloth) + 116|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($dstCloth) + 116|0);
 HEAPF32[$65>>2] = $64;
 $66 = (($srcCloth) + 120|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($dstCloth) + 120|0);
 HEAPF32[$68>>2] = $67;
 $69 = (($srcCloth) + 124|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($dstCloth) + 124|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($srcCloth) + 128|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($dstCloth) + 128|0);
 HEAPF32[$74>>2] = $73;
 $75 = (($srcCloth) + 132|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($dstCloth) + 132|0);
 HEAPF32[$77>>2] = $76;
 $78 = (($srcCloth) + 136|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($dstCloth) + 136|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($srcCloth) + 140|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($dstCloth) + 140|0);
 HEAPF32[$83>>2] = $82;
 $84 = (($srcCloth) + 144|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($dstCloth) + 144|0);
 HEAPF32[$86>>2] = $85;
 $87 = (($srcCloth) + 148|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($dstCloth) + 148|0);
 HEAPF32[$89>>2] = $88;
 $90 = (($srcCloth) + 152|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($dstCloth) + 152|0);
 HEAPF32[$92>>2] = $91;
 $93 = (($srcCloth) + 156|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($dstCloth) + 156|0);
 HEAPF32[$95>>2] = $94;
 $96 = (($srcCloth) + 160|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($dstCloth) + 160|0);
 HEAPF32[$98>>2] = $97;
 $99 = (($srcCloth) + 164|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($dstCloth) + 164|0);
 HEAPF32[$101>>2] = $100;
 $102 = (($srcCloth) + 168|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($dstCloth) + 168|0);
 HEAPF32[$104>>2] = $103;
 $105 = (($srcCloth) + 172|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($dstCloth) + 172|0);
 HEAPF32[$107>>2] = $106;
 $108 = (($srcCloth) + 176|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($dstCloth) + 176|0);
 HEAPF32[$110>>2] = $109;
 $111 = (($srcCloth) + 180|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($dstCloth) + 180|0);
 HEAPF32[$113>>2] = $112;
 $114 = (($srcCloth) + 184|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($dstCloth) + 184|0);
 HEAPF32[$116>>2] = $115;
 $117 = (($srcCloth) + 188|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($dstCloth) + 188|0);
 HEAPF32[$119>>2] = $118;
 $120 = (($srcCloth) + 192|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($dstCloth) + 192|0);
 HEAPF32[$122>>2] = $121;
 $123 = (($srcCloth) + 196|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($dstCloth) + 196|0);
 HEAPF32[$125>>2] = $124;
 $126 = (($srcCloth) + 200|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($dstCloth) + 200|0);
 HEAPF32[$128>>2] = $127;
 $129 = (($srcCloth) + 204|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($dstCloth) + 204|0);
 HEAPF32[$131>>2] = $130;
 $132 = (($srcCloth) + 208|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($dstCloth) + 208|0);
 HEAPF32[$134>>2] = $133;
 $135 = (($srcCloth) + 212|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($dstCloth) + 212|0);
 HEAPF32[$137>>2] = $136;
 $138 = (($srcCloth) + 216|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = (($dstCloth) + 216|0);
 HEAPF32[$140>>2] = $139;
 $141 = (($srcCloth) + 220|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($dstCloth) + 220|0);
 HEAPF32[$143>>2] = $142;
 $144 = (($srcCloth) + 224|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($dstCloth) + 224|0);
 HEAPF32[$146>>2] = $145;
 $147 = (($srcCloth) + 228|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = (($dstCloth) + 228|0);
 HEAPF32[$149>>2] = $148;
 $150 = (($dstCloth) + 232|0);
 $151 = ($srcCloth|0)==($dstCloth|0);
 if (!($151)) {
  $152 = (($dstCloth) + 236|0);
  HEAP32[$152>>2] = 0;
  $153 = (($srcCloth) + 236|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = (($dstCloth) + 240|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = $156 & 2147483647;
  $158 = ($157>>>0)<($154>>>0);
  if ($158) {
   __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE8recreateEj($150,$154);
   $$pre$i$i$i = HEAP32[$153>>2]|0;
   $161 = $$pre$i$i$i;
  } else {
   $161 = $154;
  }
  $159 = HEAP32[$150>>2]|0;
  $160 = (($159) + ($161<<3)|0);
  $162 = ($161|0)>(0);
  if ($162) {
   $163 = (($srcCloth) + 232|0);
   $164 = HEAP32[$163>>2]|0;
   $$012$i$i$i$i = $159;$$03$i$i$i$i = $164;
   while(1) {
    $165 = ($$012$i$i$i$i|0)==(0|0);
    if (!($165)) {
     $166 = $$03$i$i$i$i;
     $167 = $166;
     $168 = HEAP32[$167>>2]|0;
     $169 = (($166) + 4)|0;
     $170 = $169;
     $171 = HEAP32[$170>>2]|0;
     $172 = $$012$i$i$i$i;
     $173 = $172;
     HEAP32[$173>>2] = $168;
     $174 = (($172) + 4)|0;
     $175 = $174;
     HEAP32[$175>>2] = $171;
    }
    $176 = (($$012$i$i$i$i) + 8|0);
    $177 = (($$03$i$i$i$i) + 8|0);
    $178 = ($176>>>0)<($160>>>0);
    if ($178) {
     $$012$i$i$i$i = $176;$$03$i$i$i$i = $177;
    } else {
     break;
    }
   }
   $$pre1$i$i$i = HEAP32[$153>>2]|0;
   $179 = $$pre1$i$i$i;
  } else {
   $179 = $161;
  }
  HEAP32[$152>>2] = $179;
 }
 $180 = (($dstCloth) + 244|0);
 $181 = (($srcCloth) + 244|0);
 $182 = $181;
 $183 = $182;
 $184 = HEAP32[$183>>2]|0;
 $185 = (($182) + 4)|0;
 $186 = $185;
 $187 = HEAP32[$186>>2]|0;
 $188 = $180;
 $189 = $188;
 HEAP32[$189>>2] = $184;
 $190 = (($188) + 4)|0;
 $191 = $190;
 HEAP32[$191>>2] = $187;
 $192 = (($srcCloth) + 264|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($dstCloth) + 264|0);
 HEAPF32[$194>>2] = $193;
 $195 = (($srcCloth) + 268|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($dstCloth) + 268|0);
 HEAPF32[$197>>2] = $196;
 $198 = (($srcCloth) + 296|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($dstCloth) + 296|0);
 HEAPF32[$200>>2] = $199;
 $201 = (($srcCloth) + 300|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($dstCloth) + 300|0);
 HEAPF32[$203>>2] = $202;
 $204 = (($srcCloth) + 304|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($dstCloth) + 304|0);
 HEAPF32[$206>>2] = $205;
 $207 = (($srcCloth) + 440|0);
 $208 = HEAP8[$207>>0]|0;
 $209 = (($dstCloth) + 440|0);
 HEAP8[$209>>0] = $208;
 $210 = (($srcCloth) + 444|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = (($dstCloth) + 444|0);
 HEAPF32[$212>>2] = $211;
 $213 = (($srcCloth) + 448|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = (($dstCloth) + 448|0);
 HEAPF32[$215>>2] = $214;
 $216 = (($srcCloth) + 480|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = (($dstCloth) + 480|0);
 HEAPF32[$218>>2] = $217;
 $219 = (($srcCloth) + 484|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = (($dstCloth) + 484|0);
 HEAPF32[$221>>2] = $220;
 $222 = (($srcCloth) + 512|0);
 $223 = HEAP32[$222>>2]|0;
 $224 = (($dstCloth) + 512|0);
 HEAP32[$224>>2] = $223;
 $225 = (($srcCloth) + 516|0);
 $226 = HEAP32[$225>>2]|0;
 $227 = (($dstCloth) + 516|0);
 HEAP32[$227>>2] = $226;
 $228 = (($srcCloth) + 520|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = (($dstCloth) + 520|0);
 HEAPF32[$230>>2] = $229;
 $231 = (($srcCloth) + 524|0);
 $232 = HEAP32[$231>>2]|0;
 $233 = (($dstCloth) + 524|0);
 HEAP32[$233>>2] = $232;
 $234 = (($srcCloth) + 528|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = (($dstCloth) + 528|0);
 HEAP32[$236>>2] = $235;
 $237 = (($srcCloth) + 532|0);
 $238 = HEAP32[$237>>2]|0;
 $239 = (($dstCloth) + 532|0);
 HEAP32[$239>>2] = $238;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_110copyVectorERN5physx6shdfnd5ArrayINS0_6PxVec4ENS1_16AlignedAllocatorILj16ENS1_9AllocatorEEEEERKS7_($dst,$src) {
 $dst = $dst|0;
 $src = $src|0;
 var $$012$i$i = 0, $$03$i$i = 0, $$idx = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($src) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = (($dst) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($4>>>0);
 if ($8) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($dst,$4);
 }
 $9 = HEAP32[$src>>2]|0;
 $10 = (($src) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $$idx = $11 << 4;
 $12 = $$idx >> 4;
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE19resizeUninitializedEj($dst,$12);
 $13 = HEAP32[$dst>>2]|0;
 $14 = (($dst) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + ($15<<4)|0);
 $17 = ($15|0)>(0);
 if ($17) {
  $$012$i$i = $13;$$03$i$i = $9;
  while(1) {
   $18 = ($$012$i$i|0)==(0|0);
   if (!($18)) {
    $19 = Math_fround(HEAPF32[$$03$i$i>>2]);
    HEAPF32[$$012$i$i>>2] = $19;
    $20 = (($$012$i$i) + 4|0);
    $21 = (($$03$i$i) + 4|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    HEAPF32[$20>>2] = $22;
    $23 = (($$012$i$i) + 8|0);
    $24 = (($$03$i$i) + 8|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    HEAPF32[$23>>2] = $25;
    $26 = (($$012$i$i) + 12|0);
    $27 = (($$03$i$i) + 12|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
   }
   $29 = (($$012$i$i) + 16|0);
   $30 = (($$03$i$i) + 16|0);
   $31 = ($29>>>0)<($16>>>0);
   if ($31) {
    $$012$i$i = $29;$$03$i$i = $30;
   } else {
    break;
   }
  }
 }
 $32 = HEAP32[$2>>2]|0;
 $33 = $32 & 2147483647;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($dst,$33,$0);
 $34 = HEAP32[$10>>2]|0;
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($dst,$34,$1);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth7SwClothD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i$i23 = 0;
 var $or$cond$i$i$i$i28 = 0, $or$cond$i$i1 = 0, $or$cond$i$i1$i$i = 0, $or$cond$i$i1$i$i24 = 0, $or$cond$i$i10 = 0, $or$cond$i$i12 = 0, $or$cond$i$i14 = 0, $or$cond$i$i16 = 0, $or$cond$i$i18 = 0, $or$cond$i$i20 = 0, $or$cond$i$i21 = 0, $or$cond$i$i27 = 0, $or$cond$i$i29 = 0, $or$cond$i$i3 = 0, $or$cond$i$i4 = 0, $or$cond$i$i6 = 0, $or$cond$i$i7 = 0, $or$cond$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = (($3) + -1)<<16>>16;
 HEAP16[$2>>1] = $4;
 $5 = (($this) + 500|0);
 $6 = (($this) + 508|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8|0)!=(0);
 $10 = ($7|0)>(-1);
 $or$cond$i$i1 = $9 & $10;
 if ($or$cond$i$i1) {
  $11 = HEAP32[$5>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = (($11) + -4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (0 - ($14))|0;
   $16 = (($11) + ($15)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$16);
  }
 }
 $17 = (($this) + 488|0);
 $18 = (($this) + 496|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & 2147483647;
 $21 = ($20|0)!=(0);
 $22 = ($19|0)>(-1);
 $or$cond$i$i3 = $21 & $22;
 if ($or$cond$i$i3) {
  $23 = HEAP32[$17>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($17,$23);
 }
 $24 = (($this) + 464|0);
 $25 = (($this) + 472|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26 & 2147483647;
 $28 = ($27|0)!=(0);
 $29 = ($26|0)>(-1);
 $or$cond$i$i4 = $28 & $29;
 if ($or$cond$i$i4) {
  $30 = HEAP32[$24>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (($30) + -4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (0 - ($33))|0;
   $35 = (($30) + ($34)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($24,$35);
  }
 }
 $36 = (($this) + 452|0);
 $37 = (($this) + 460|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 2147483647;
 $40 = ($39|0)!=(0);
 $41 = ($38|0)>(-1);
 $or$cond$i$i6 = $40 & $41;
 if ($or$cond$i$i6) {
  $42 = HEAP32[$36>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($36,$42);
 }
 $43 = (($this) + 428|0);
 $44 = (($this) + 436|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45 & 2147483647;
 $47 = ($46|0)!=(0);
 $48 = ($45|0)>(-1);
 $or$cond$i$i7 = $47 & $48;
 if ($or$cond$i$i7) {
  $49 = HEAP32[$43>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($43,$49);
 }
 $50 = (($this) + 416|0);
 $51 = (($this) + 424|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 & 2147483647;
 $54 = ($53|0)!=(0);
 $55 = ($52|0)>(-1);
 $or$cond$i$i8 = $54 & $55;
 if ($or$cond$i$i8) {
  $56 = HEAP32[$50>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($50,$56);
 }
 $57 = (($this) + 404|0);
 $58 = (($this) + 412|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = $59 & 2147483647;
 $61 = ($60|0)!=(0);
 $62 = ($59|0)>(-1);
 $or$cond$i$i10 = $61 & $62;
 if ($or$cond$i$i10) {
  $63 = HEAP32[$57>>2]|0;
  $64 = ($63|0)==(0|0);
  if (!($64)) {
   $65 = (($63) + -4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (0 - ($66))|0;
   $68 = (($63) + ($67)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($57,$68);
  }
 }
 $69 = (($this) + 392|0);
 $70 = (($this) + 400|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = $71 & 2147483647;
 $73 = ($72|0)!=(0);
 $74 = ($71|0)>(-1);
 $or$cond$i$i12 = $73 & $74;
 if ($or$cond$i$i12) {
  $75 = HEAP32[$69>>2]|0;
  $76 = ($75|0)==(0|0);
  if (!($76)) {
   $77 = (($75) + -4|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (0 - ($78))|0;
   $80 = (($75) + ($79)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($69,$80);
  }
 }
 $81 = (($this) + 380|0);
 $82 = (($this) + 388|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = $83 & 2147483647;
 $85 = ($84|0)!=(0);
 $86 = ($83|0)>(-1);
 $or$cond$i$i14 = $85 & $86;
 if ($or$cond$i$i14) {
  $87 = HEAP32[$81>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($81,$87);
 }
 $88 = (($this) + 368|0);
 $89 = (($this) + 376|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = $90 & 2147483647;
 $92 = ($91|0)!=(0);
 $93 = ($90|0)>(-1);
 $or$cond$i$i16 = $92 & $93;
 if ($or$cond$i$i16) {
  $94 = HEAP32[$88>>2]|0;
  $95 = ($94|0)==(0|0);
  if (!($95)) {
   $96 = (($94) + -4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (0 - ($97))|0;
   $99 = (($94) + ($98)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($88,$99);
  }
 }
 $100 = (($this) + 356|0);
 $101 = (($this) + 364|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = $102 & 2147483647;
 $104 = ($103|0)!=(0);
 $105 = ($102|0)>(-1);
 $or$cond$i$i18 = $104 & $105;
 if ($or$cond$i$i18) {
  $106 = HEAP32[$100>>2]|0;
  $107 = ($106|0)==(0|0);
  if (!($107)) {
   $108 = (($106) + -4|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = (0 - ($109))|0;
   $111 = (($106) + ($110)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($100,$111);
  }
 }
 $112 = (($this) + 344|0);
 $113 = (($this) + 352|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i20 = $116 & $117;
 if ($or$cond$i$i20) {
  $118 = HEAP32[$112>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($112,$118);
 }
 $119 = (($this) + 332|0);
 $120 = (($this) + 340|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = $121 & 2147483647;
 $123 = ($122|0)!=(0);
 $124 = ($121|0)>(-1);
 $or$cond$i$i21 = $123 & $124;
 if ($or$cond$i$i21) {
  $125 = HEAP32[$119>>2]|0;
  $126 = ($125|0)==(0|0);
  if (!($126)) {
   $127 = (($125) + -4|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = (0 - ($128))|0;
   $130 = (($125) + ($129)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($119,$130);
  }
 }
 $131 = (($this) + 308|0);
 $132 = (($this) + 320|0);
 $133 = (($this) + 328|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = $134 & 2147483647;
 $136 = ($135|0)!=(0);
 $137 = ($134|0)>(-1);
 $or$cond$i$i$i$i = $136 & $137;
 if ($or$cond$i$i$i$i) {
  $138 = HEAP32[$132>>2]|0;
  $139 = ($138|0)==(0|0);
  if (!($139)) {
   $140 = (($138) + -4|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = (0 - ($141))|0;
   $143 = (($138) + ($142)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($132,$143);
  }
 }
 $144 = (($this) + 316|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = $145 & 2147483647;
 $147 = ($146|0)!=(0);
 $148 = ($145|0)>(-1);
 $or$cond$i$i1$i$i = $147 & $148;
 if ($or$cond$i$i1$i$i) {
  $149 = HEAP32[$131>>2]|0;
  $150 = ($149|0)==(0|0);
  if (!($150)) {
   $151 = (($149) + -4|0);
   $152 = HEAP32[$151>>2]|0;
   $153 = (0 - ($152))|0;
   $154 = (($149) + ($153)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($131,$154);
  }
 }
 $155 = (($this) + 272|0);
 $156 = (($this) + 284|0);
 $157 = (($this) + 292|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = $158 & 2147483647;
 $160 = ($159|0)!=(0);
 $161 = ($158|0)>(-1);
 $or$cond$i$i$i$i23 = $160 & $161;
 if ($or$cond$i$i$i$i23) {
  $162 = HEAP32[$156>>2]|0;
  $163 = ($162|0)==(0|0);
  if (!($163)) {
   $164 = (($162) + -4|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = (0 - ($165))|0;
   $167 = (($162) + ($166)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($156,$167);
  }
 }
 $168 = (($this) + 280|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = $169 & 2147483647;
 $171 = ($170|0)!=(0);
 $172 = ($169|0)>(-1);
 $or$cond$i$i1$i$i24 = $171 & $172;
 if ($or$cond$i$i1$i$i24) {
  $173 = HEAP32[$155>>2]|0;
  $174 = ($173|0)==(0|0);
  if (!($174)) {
   $175 = (($173) + -4|0);
   $176 = HEAP32[$175>>2]|0;
   $177 = (0 - ($176))|0;
   $178 = (($173) + ($177)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($155,$178);
  }
 }
 $179 = (($this) + 252|0);
 $180 = (($this) + 260|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = $181 & 2147483647;
 $183 = ($182|0)!=(0);
 $184 = ($181|0)>(-1);
 $or$cond$i$i27 = $183 & $184;
 if ($or$cond$i$i27) {
  $185 = HEAP32[$179>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($179,$185);
 }
 $186 = (($this) + 232|0);
 $187 = (($this) + 240|0);
 $188 = HEAP32[$187>>2]|0;
 $189 = $188 & 2147483647;
 $190 = ($189|0)!=(0);
 $191 = ($188|0)>(-1);
 $or$cond$i$i$i$i28 = $190 & $191;
 if ($or$cond$i$i$i$i28) {
  $192 = HEAP32[$186>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($186,$192);
 }
 $193 = (($this) + 20|0);
 $194 = (($this) + 28|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = $195 & 2147483647;
 $197 = ($196|0)!=(0);
 $198 = ($195|0)>(-1);
 $or$cond$i$i29 = $197 & $198;
 do {
  if ($or$cond$i$i29) {
   $199 = HEAP32[$193>>2]|0;
   $200 = ($199|0)==(0|0);
   if ($200) {
    break;
   }
   $201 = (($199) + -4|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = (0 - ($202))|0;
   $204 = (($199) + ($203)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($193,$204);
  }
 } while(0);
 $205 = (($this) + 8|0);
 $206 = (($this) + 16|0);
 $207 = HEAP32[$206>>2]|0;
 $208 = $207 & 2147483647;
 $209 = ($208|0)!=(0);
 $210 = ($207|0)>(-1);
 $or$cond$i$i = $209 & $210;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $211 = HEAP32[$205>>2]|0;
 $212 = ($211|0)==(0|0);
 if ($212) {
  STACKTOP = sp;return;
 }
 $213 = (($211) + -4|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = (0 - ($214))|0;
 $216 = (($211) + ($215)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($205,$216);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth7SwCloth4pushERNS0_13SwConstraintsE($agg$result,$this,$constraints) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $constraints = $constraints|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($constraints) + 12|0);
 $4 = (($constraints) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($2) + 3)|0;
  $9 = $8 & -4;
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($3,$9,$0);
 }
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE19resizeUninitializedEj($3,$2);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($constraints) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12<<4)|0);
 HEAP32[$agg$result>>2] = $10;
 $14 = (($agg$result) + 4|0);
 HEAP32[$14>>2] = $13;
 $15 = (($constraints) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$constraints>>2]|0;
 HEAP32[$constraints>>2] = $10;
 HEAP32[$3>>2] = $18;
 HEAP32[$15>>2] = $12;
 HEAP32[$11>>2] = 0;
 $19 = (($constraints) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$4>>2]|0;
 HEAP32[$19>>2] = $21;
 HEAP32[$4>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth7SwCloth5clearERNS0_13SwConstraintsE($constraints) {
 $constraints = $constraints|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs = 0, $notlhs4 = 0, $notrhs = 0, $notrhs5 = 0, $or$cond = 0, $or$cond$i$i$not = 0, $or$cond$i$i1$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (($0) + 4|0);
 $3 = (($0) + 8|0);
 $4 = HEAP32[$constraints>>2]|0;
 HEAP32[$0>>2] = $4;
 HEAP32[$constraints>>2] = 0;
 $5 = (($constraints) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$2>>2] = $6;
 HEAP32[$5>>2] = 0;
 $7 = (($constraints) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$3>>2] = $8;
 HEAP32[$7>>2] = 0;
 $9 = $8 & 2147483647;
 $notlhs = ($9|0)==(0);
 $notrhs = ($8|0)<(0);
 $or$cond$i$i1$not = $notrhs | $notlhs;
 $10 = ($4|0)==(0|0);
 $or$cond = $or$cond$i$i1$not | $10;
 if (!($or$cond)) {
  $11 = (($4) + -4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (0 - ($12))|0;
  $14 = (($4) + ($13)|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$14);
 }
 $15 = (($1) + 4|0);
 $16 = (($1) + 8|0);
 $17 = (($constraints) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 HEAP32[$1>>2] = $18;
 HEAP32[$17>>2] = 0;
 $19 = (($constraints) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$15>>2] = $20;
 HEAP32[$19>>2] = 0;
 $21 = (($constraints) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$16>>2] = $22;
 HEAP32[$21>>2] = 0;
 $23 = $22 & 2147483647;
 $notlhs4 = ($23|0)==(0);
 $notrhs5 = ($22|0)<(0);
 $or$cond$i$i$not = $notrhs5 | $notlhs4;
 $24 = ($18|0)==(0|0);
 $or$cond3 = $or$cond$i$i$not | $24;
 if ($or$cond3) {
  STACKTOP = sp;return;
 }
 $25 = (($18) + -4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (0 - ($26))|0;
 $28 = (($18) + ($27)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$28);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth7SwCloth18clampTriangleCountENS0_5RangeIKNS_6PxVec3EEEj($agg$result,$range,$0) {
 $agg$result = $agg$result|0;
 $range = $range|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $range;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE5cloneERNS0_7FactoryE($this,$factory) {
 $this = $this|0;
 $factory = $factory|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$factory>>2]|0;
 $1 = (($0) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = (FUNCTION_TABLE_iii[$2 & 4095]($factory,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE5cloneERNS0_7FactoryE($this,$factory) {
 $this = $this|0;
 $factory = $factory|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$factory>>2]|0;
 $1 = (($0) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($this);
 $4 = (FUNCTION_TABLE_iii[$2 & 4095]($factory,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE15getNumParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE15getNumParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE13lockParticlesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE13lockParticlesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE15unlockParticlesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE15unlockParticlesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE19getCurrentParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$index1 = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 $6 = (($1) + ($5<<4)|0);
 $7 = (($this) + 4|0);
 HEAP32[$agg$result>>2] = $1;
 $8 = (($agg$result) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($agg$result) + 8|0);
 HEAP32[$9>>2] = $7;
 $10 = (($agg$result) + 12|0);
 HEAP8[$10>>0]=24&255;HEAP8[$10+1>>0]=(24>>8)&255;HEAP8[$10+2>>0]=(24>>16)&255;HEAP8[$10+3>>0]=24>>24;
 $$index1 = (($10) + 4|0);
 HEAP8[$$index1>>0]=1&255;HEAP8[$$index1+1>>0]=(1>>8)&255;HEAP8[$$index1+2>>0]=(1>>16)&255;HEAP8[$$index1+3>>0]=1>>24;
 $11 = (($agg$result) + 20|0);
 HEAP8[$11>>0]=28&255;HEAP8[$11+1>>0]=(28>>8)&255;HEAP8[$11+2>>0]=(28>>16)&255;HEAP8[$11+3>>0]=28>>24;
 $$index3 = (($11) + 4|0);
 HEAP8[$$index3>>0]=1&255;HEAP8[$$index3+1>>0]=(1>>8)&255;HEAP8[$$index3+2>>0]=(1>>16)&255;HEAP8[$$index3+3>>0]=1>>24;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE19getCurrentParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$index1 = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($0)|0);
 $7 = (($2) + ($6<<4)|0);
 $8 = ($this);
 HEAP32[$agg$result>>2] = $2;
 $9 = (($agg$result) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (($agg$result) + 8|0);
 HEAP32[$10>>2] = $8;
 $11 = (($agg$result) + 12|0);
 HEAP8[$11>>0]=24&255;HEAP8[$11+1>>0]=(24>>8)&255;HEAP8[$11+2>>0]=(24>>16)&255;HEAP8[$11+3>>0]=24>>24;
 $$index1 = (($11) + 4|0);
 HEAP8[$$index1>>0]=1&255;HEAP8[$$index1+1>>0]=(1>>8)&255;HEAP8[$$index1+2>>0]=(1>>16)&255;HEAP8[$$index1+3>>0]=1>>24;
 $12 = (($agg$result) + 20|0);
 HEAP8[$12>>0]=28&255;HEAP8[$12+1>>0]=(28>>8)&255;HEAP8[$12+2>>0]=(28>>16)&255;HEAP8[$12+3>>0]=28>>24;
 $$index3 = (($12) + 4|0);
 HEAP8[$$index3>>0]=1&255;HEAP8[$$index3+1>>0]=(1>>8)&255;HEAP8[$$index3+2>>0]=(1>>16)&255;HEAP8[$$index3+3>>0]=1>>24;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE19getCurrentParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$index1 = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 $6 = (($1) + ($5<<4)|0);
 $7 = (($this) + 4|0);
 HEAP32[$agg$result>>2] = $1;
 $8 = (($agg$result) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($agg$result) + 8|0);
 HEAP32[$9>>2] = $7;
 $10 = (($agg$result) + 12|0);
 HEAP8[$10>>0]=24&255;HEAP8[$10+1>>0]=(24>>8)&255;HEAP8[$10+2>>0]=(24>>16)&255;HEAP8[$10+3>>0]=24>>24;
 $$index1 = (($10) + 4|0);
 HEAP8[$$index1>>0]=1&255;HEAP8[$$index1+1>>0]=(1>>8)&255;HEAP8[$$index1+2>>0]=(1>>16)&255;HEAP8[$$index1+3>>0]=1>>24;
 $11 = (($agg$result) + 20|0);
 HEAP8[$11>>0]=28&255;HEAP8[$11+1>>0]=(28>>8)&255;HEAP8[$11+2>>0]=(28>>16)&255;HEAP8[$11+3>>0]=28>>24;
 $$index3 = (($11) + 4|0);
 HEAP8[$$index3>>0]=1&255;HEAP8[$$index3+1>>0]=(1>>8)&255;HEAP8[$$index3+2>>0]=(1>>16)&255;HEAP8[$$index3+3>>0]=1>>24;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE19getCurrentParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$index1 = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($0)|0);
 $7 = (($2) + ($6<<4)|0);
 $8 = ($this);
 HEAP32[$agg$result>>2] = $2;
 $9 = (($agg$result) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (($agg$result) + 8|0);
 HEAP32[$10>>2] = $8;
 $11 = (($agg$result) + 12|0);
 HEAP8[$11>>0]=24&255;HEAP8[$11+1>>0]=(24>>8)&255;HEAP8[$11+2>>0]=(24>>16)&255;HEAP8[$11+3>>0]=24>>24;
 $$index1 = (($11) + 4|0);
 HEAP8[$$index1>>0]=1&255;HEAP8[$$index1+1>>0]=(1>>8)&255;HEAP8[$$index1+2>>0]=(1>>16)&255;HEAP8[$$index1+3>>0]=1>>24;
 $12 = (($agg$result) + 20|0);
 HEAP8[$12>>0]=28&255;HEAP8[$12+1>>0]=(28>>8)&255;HEAP8[$12+2>>0]=(28>>16)&255;HEAP8[$12+3>>0]=28>>24;
 $$index3 = (($12) + 4|0);
 HEAP8[$$index3>>0]=1&255;HEAP8[$$index3+1>>0]=(1>>8)&255;HEAP8[$$index3+2>>0]=(1>>16)&255;HEAP8[$$index3+3>>0]=1>>24;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE20getPreviousParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$index1 = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 $6 = (($1) + ($5<<4)|0);
 $7 = (($this) + 4|0);
 HEAP32[$agg$result>>2] = $1;
 $8 = (($agg$result) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($agg$result) + 8|0);
 HEAP32[$9>>2] = $7;
 $10 = (($agg$result) + 12|0);
 HEAP8[$10>>0]=24&255;HEAP8[$10+1>>0]=(24>>8)&255;HEAP8[$10+2>>0]=(24>>16)&255;HEAP8[$10+3>>0]=24>>24;
 $$index1 = (($10) + 4|0);
 HEAP8[$$index1>>0]=1&255;HEAP8[$$index1+1>>0]=(1>>8)&255;HEAP8[$$index1+2>>0]=(1>>16)&255;HEAP8[$$index1+3>>0]=1>>24;
 $11 = (($agg$result) + 20|0);
 HEAP8[$11>>0]=28&255;HEAP8[$11+1>>0]=(28>>8)&255;HEAP8[$11+2>>0]=(28>>16)&255;HEAP8[$11+3>>0]=28>>24;
 $$index3 = (($11) + 4|0);
 HEAP8[$$index3>>0]=1&255;HEAP8[$$index3+1>>0]=(1>>8)&255;HEAP8[$$index3+2>>0]=(1>>16)&255;HEAP8[$$index3+3>>0]=1>>24;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE20getPreviousParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$index1 = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($0)|0);
 $7 = (($2) + ($6<<4)|0);
 $8 = ($this);
 HEAP32[$agg$result>>2] = $2;
 $9 = (($agg$result) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (($agg$result) + 8|0);
 HEAP32[$10>>2] = $8;
 $11 = (($agg$result) + 12|0);
 HEAP8[$11>>0]=24&255;HEAP8[$11+1>>0]=(24>>8)&255;HEAP8[$11+2>>0]=(24>>16)&255;HEAP8[$11+3>>0]=24>>24;
 $$index1 = (($11) + 4|0);
 HEAP8[$$index1>>0]=1&255;HEAP8[$$index1+1>>0]=(1>>8)&255;HEAP8[$$index1+2>>0]=(1>>16)&255;HEAP8[$$index1+3>>0]=1>>24;
 $12 = (($agg$result) + 20|0);
 HEAP8[$12>>0]=28&255;HEAP8[$12+1>>0]=(28>>8)&255;HEAP8[$12+2>>0]=(28>>16)&255;HEAP8[$12+3>>0]=28>>24;
 $$index3 = (($12) + 4|0);
 HEAP8[$$index3>>0]=1&255;HEAP8[$$index3+1>>0]=(1>>8)&255;HEAP8[$$index3+2>>0]=(1>>16)&255;HEAP8[$$index3+3>>0]=1>>24;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE20getPreviousParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$index1 = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 $6 = (($1) + ($5<<4)|0);
 $7 = (($this) + 4|0);
 HEAP32[$agg$result>>2] = $1;
 $8 = (($agg$result) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($agg$result) + 8|0);
 HEAP32[$9>>2] = $7;
 $10 = (($agg$result) + 12|0);
 HEAP8[$10>>0]=24&255;HEAP8[$10+1>>0]=(24>>8)&255;HEAP8[$10+2>>0]=(24>>16)&255;HEAP8[$10+3>>0]=24>>24;
 $$index1 = (($10) + 4|0);
 HEAP8[$$index1>>0]=1&255;HEAP8[$$index1+1>>0]=(1>>8)&255;HEAP8[$$index1+2>>0]=(1>>16)&255;HEAP8[$$index1+3>>0]=1>>24;
 $11 = (($agg$result) + 20|0);
 HEAP8[$11>>0]=28&255;HEAP8[$11+1>>0]=(28>>8)&255;HEAP8[$11+2>>0]=(28>>16)&255;HEAP8[$11+3>>0]=28>>24;
 $$index3 = (($11) + 4|0);
 HEAP8[$$index3>>0]=1&255;HEAP8[$$index3+1>>0]=(1>>8)&255;HEAP8[$$index3+2>>0]=(1>>16)&255;HEAP8[$$index3+3>>0]=1>>24;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE20getPreviousParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$index1 = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($0)|0);
 $7 = (($2) + ($6<<4)|0);
 $8 = ($this);
 HEAP32[$agg$result>>2] = $2;
 $9 = (($agg$result) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (($agg$result) + 8|0);
 HEAP32[$10>>2] = $8;
 $11 = (($agg$result) + 12|0);
 HEAP8[$11>>0]=24&255;HEAP8[$11+1>>0]=(24>>8)&255;HEAP8[$11+2>>0]=(24>>16)&255;HEAP8[$11+3>>0]=24>>24;
 $$index1 = (($11) + 4|0);
 HEAP8[$$index1>>0]=1&255;HEAP8[$$index1+1>>0]=(1>>8)&255;HEAP8[$$index1+2>>0]=(1>>16)&255;HEAP8[$$index1+3>>0]=1>>24;
 $12 = (($agg$result) + 20|0);
 HEAP8[$12>>0]=28&255;HEAP8[$12+1>>0]=(28>>8)&255;HEAP8[$12+2>>0]=(28>>16)&255;HEAP8[$12+3>>0]=28>>24;
 $$index3 = (($12) + 4|0);
 HEAP8[$$index3>>0]=1&255;HEAP8[$$index3+1>>0]=(1>>8)&255;HEAP8[$$index3+2>>0]=(1>>16)&255;HEAP8[$$index3+3>>0]=1>>24;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE15getGpuParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE15getGpuParticlesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE14setPhaseConfigENS0_5RangeIKNS0_11PhaseConfigEEE($this,$configs) {
 $this = $this|0;
 $configs = $configs|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 20|0;
 $1 = sp;
 $2 = (($this) + 268|0);
 __ZN5physx5cloth11PhaseConfigC2Et($0,-1);
 __ZN5physx6shdfnd5ArrayINS_5cloth11PhaseConfigENS0_9AllocatorEE6resizeEjRKS3_($2,0,$0);
 $3 = HEAP32[$configs>>2]|0;
 $4 = (($configs) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if (!($6)) {
  $24 = (($this) + 540|0);
  HEAP32[$24>>2] = 0;
  STACKTOP = sp;return;
 }
 $7 = (($this) + 276|0);
 $8 = (($this) + 272|0);
 $10 = $3;
 while(1) {
  $9 = (($10) + 4|0);
  $11 = Math_fround(HEAPF32[$9>>2]);
  $12 = $11 > Math_fround(0.0);
  do {
   if ($12) {
    __ZN5physx5cloth9transformERKNS0_11PhaseConfigE($1,$10);
    $13 = HEAP32[$7>>2]|0;
    $14 = $13 & 2147483647;
    $15 = HEAP32[$8>>2]|0;
    $16 = ($14>>>0)>($15>>>0);
    if (!($16)) {
     (__ZN5physx6shdfnd5ArrayINS_5cloth11PhaseConfigENS0_9AllocatorEE15growAndPushBackERKS3_($2,$1)|0);
     break;
    }
    $17 = HEAP32[$2>>2]|0;
    $18 = (($17) + (($15*20)|0)|0);
    $19 = ($18|0)==(0|0);
    if ($19) {
     $21 = $15;
    } else {
     ;HEAP32[$18+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$18+16>>2]=HEAP32[$1+16>>2]|0;
     $$pre$i = HEAP32[$8>>2]|0;
     $21 = $$pre$i;
    }
    $20 = (($21) + 1)|0;
    HEAP32[$8>>2] = $20;
   }
  } while(0);
  $22 = (($10) + 20|0);
  $23 = ($22>>>0)<($5>>>0);
  if ($23) {
   $10 = $22;
  } else {
   break;
  }
 }
 HEAP32[$configs>>2] = $22;
 $24 = (($this) + 540|0);
 HEAP32[$24>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth11PhaseConfigENS0_9AllocatorEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_5cloth11PhaseConfigENS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*20)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*20)|0)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$$01$i+16>>2]=HEAP32[$a+16>>2]|0;
  }
  $11 = (($$01$i) + 20|0);
  $12 = ($11>>>0)<($7>>>0);
  if ($12) {
   $$01$i = $11;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE14setPhaseConfigENS0_5RangeIKNS0_11PhaseConfigEEE($this,$configs) {
 $this = $this|0;
 $configs = $configs|0;
 var $0 = 0, $configs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $configs$byval_copy = sp;
 $0 = (($this) + -4|0);
 ;HEAP32[$configs$byval_copy+0>>2]=HEAP32[$configs+0>>2]|0;HEAP32[$configs$byval_copy+4>>2]=HEAP32[$configs+4>>2]|0;
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE14setPhaseConfigENS0_5RangeIKNS0_11PhaseConfigEEE($0,$configs$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE23setSelfCollisionIndicesENS0_5RangeIKjEE($this,$indices) {
 $this = $this|0;
 $indices = $indices|0;
 var $$012$i$i = 0, $$03$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 504|0);
 $1 = HEAP32[$indices>>2]|0;
 $2 = (($indices) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3;
 $5 = $1;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE19resizeUninitializedEj($0,$7);
 $8 = HEAP32[$0>>2]|0;
 $9 = (($this) + 508|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + ($10<<2)|0);
 $12 = ($10|0)>(0);
 if ($12) {
  $$012$i$i = $8;$$03$i$i = $1;
 } else {
  $18 = (($this) + 540|0);
  HEAP32[$18>>2] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $13 = ($$012$i$i|0)==(0|0);
  if (!($13)) {
   $14 = HEAP32[$$03$i$i>>2]|0;
   HEAP32[$$012$i$i>>2] = $14;
  }
  $15 = (($$012$i$i) + 4|0);
  $16 = (($$03$i$i) + 4|0);
  $17 = ($15>>>0)<($11>>>0);
  if ($17) {
   $$012$i$i = $15;$$03$i$i = $16;
  } else {
   break;
  }
 }
 $18 = (($this) + 540|0);
 HEAP32[$18>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE23setSelfCollisionIndicesENS0_5RangeIKjEE($this,$indices) {
 $this = $this|0;
 $indices = $indices|0;
 var $$012$i$i$i = 0, $$03$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$indices>>2]|0;
 $1 = (($indices) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 500|0);
 $4 = $2;
 $5 = $0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE19resizeUninitializedEj($3,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($this) + 504|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + ($10<<2)|0);
 $12 = ($10|0)>(0);
 if ($12) {
  $$012$i$i$i = $8;$$03$i$i$i = $0;
 } else {
  $18 = (($this) + 536|0);
  HEAP32[$18>>2] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $13 = ($$012$i$i$i|0)==(0|0);
  if (!($13)) {
   $14 = HEAP32[$$03$i$i$i>>2]|0;
   HEAP32[$$012$i$i$i>>2] = $14;
  }
  $15 = (($$012$i$i$i) + 4|0);
  $16 = (($$03$i$i$i) + 4|0);
  $17 = ($15>>>0)<($11>>>0);
  if ($17) {
   $$012$i$i$i = $15;$$03$i$i$i = $16;
  } else {
   break;
  }
 }
 $18 = (($this) + 536|0);
 HEAP32[$18>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE22getNumVirtualParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 492|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE22getNumVirtualParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 488|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE24getParticleAccelerationsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 348|0);
 $2 = (($this) + 352|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($this) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($1,$6,$0);
  $$pre = HEAP32[$2>>2]|0;
  $10 = $$pre;
 } else {
  $10 = $3;
 }
 $7 = (($this) + 540|0);
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + ($10<<4)|0);
 HEAP32[$agg$result>>2] = $8;
 $11 = (($agg$result) + 4|0);
 HEAP32[$11>>2] = $9;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE24getParticleAccelerationsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 344|0);
 $2 = (($this) + 348|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($this) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($1,$6,$0);
  $$pre$i = HEAP32[$2>>2]|0;
  $10 = $$pre$i;
 } else {
  $10 = $3;
 }
 $7 = (($this) + 536|0);
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + ($10<<4)|0);
 HEAP32[$agg$result>>2] = $8;
 $11 = (($agg$result) + 4|0);
 HEAP32[$11>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE26clearParticleAccelerationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($0) + 4|0);
 $2 = (($0) + 8|0);
 $3 = (($this) + 348|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 HEAP32[$3>>2] = 0;
 $5 = (($this) + 352|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 HEAP32[$5>>2] = 0;
 $7 = (($this) + 356|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$2>>2] = $8;
 HEAP32[$7>>2] = 0;
 $9 = $8 & 2147483647;
 $notlhs = ($9|0)==(0);
 $notrhs = ($8|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $10 = ($4|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $10;
 if ($or$cond) {
  $15 = (($this) + 540|0);
  HEAP32[$15>>2] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($4) + -4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (0 - ($12))|0;
 $14 = (($4) + ($13)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$14);
 $15 = (($this) + 540|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE26clearParticleAccelerationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$i = 0, $or$cond$i$i$not$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($0) + 4|0);
 $2 = (($0) + 8|0);
 $3 = (($this) + 344|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 HEAP32[$3>>2] = 0;
 $5 = (($this) + 348|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 HEAP32[$5>>2] = 0;
 $7 = (($this) + 352|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$2>>2] = $8;
 HEAP32[$7>>2] = 0;
 $9 = $8 & 2147483647;
 $notlhs$i = ($9|0)==(0);
 $notrhs$i = ($8|0)<(0);
 $or$cond$i$i$not$i = $notrhs$i | $notlhs$i;
 $10 = ($4|0)==(0|0);
 $or$cond$i = $or$cond$i$i$not$i | $10;
 if ($or$cond$i) {
  $15 = (($this) + 536|0);
  HEAP32[$15>>2] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($4) + -4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (0 - ($12))|0;
 $14 = (($4) + ($13)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$14);
 $15 = (($this) + 536|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE19setVirtualParticlesENS0_5RangeIA4_KjEENS4_IKNS_6PxVec3EEE($this,$indices,$weights) {
 $this = $this|0;
 $indices = $indices|0;
 $weights = $weights|0;
 var $$012$i$i$i = 0, $$03$i$i$i = 0, $$idx = 0, $$idx4 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$phi16Z2D = 0, $$pre$phi18Z2D = 0, $$pre$phiZ2D = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dummy = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$not = 0, $or$cond$i$i1 = 0, $or$cond$i$i1$i$i = 0, $phitmp = 0, $sIt$08 = 0, $scevgep$sum = 0;
 var $scevgep11 = 0, $scheduler = 0, $tIt$07 = 0, $tIt$1$lcssa = 0, $tIt$15 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $tmpcast$byval_copy = sp + 32|0;
 $scheduler = sp + 72|0;
 $0 = sp;
 $dummy = sp + 104|0;
 $1 = sp + 96|0;
 $2 = sp + 8|0;
 $3 = sp + 16|0;
 $4 = sp + 40|0;
 $5 = sp + 56|0;
 $6 = (($this) + 492|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8&65535;
 $10 = $indices;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $0;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN5physx5cloth16TripletSchedulerC2ENS0_5RangeIA4_KjEE($scheduler,$tmpcast$byval_copy);
 $20 = $8 & 65535;
 __ZN5physx5cloth16TripletScheduler4simdEjj($scheduler,$20,4);
 $21 = (($8) + 1)|0;
 $22 = $21&65535;
 $23 = (($8) + 2)|0;
 $24 = $23&65535;
 HEAP16[$dummy>>1] = $9;
 $25 = (($dummy) + 2|0);
 HEAP16[$25>>1] = $22;
 $26 = (($dummy) + 4|0);
 HEAP16[$26>>1] = $24;
 $27 = (($dummy) + 6|0);
 HEAP16[$27>>1] = 0;
 $28 = (($scheduler) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($scheduler) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + ($31<<2)|0);
 $33 = HEAP32[$scheduler>>2]|0;
 $34 = (($this) + 468|0);
 __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE6resizeEjRKS4_($34,0,$1);
 $35 = (($indices) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36;
 $38 = (($37) - ($12))|0;
 $39 = $38 >> 4;
 $$idx = $31 << 2;
 $40 = $$idx >> 2;
 $41 = ($40*3)|0;
 $42 = (($39) + ($41))|0;
 $43 = (($this) + 476|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 & 2147483647;
 $46 = ($45>>>0)<($42>>>0);
 if ($46) {
  __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE8recreateEj($34,$42);
 }
 $47 = ($31|0)==(0);
 if ($47) {
  $$pre17 = (($this) + 472|0);
  $$pre$phi16Z2D = $34;$$pre$phi18Z2D = $$pre17;
 } else {
  $48 = (($this) + 472|0);
  $49 = (($2) + 2|0);
  $50 = (($2) + 4|0);
  $51 = (($2) + 6|0);
  $sIt$08 = $29;$tIt$07 = $33;
  while(1) {
   $52 = HEAP32[$sIt$08>>2]|0;
   $53 = (($tIt$07) + ($52<<4)|0);
   $54 = ($52|0)==(0);
   if ($54) {
    $tIt$1$lcssa = $tIt$07;
   } else {
    $55 = $52 << 4;
    $56 = (($55) + -16)|0;
    $57 = $56 >>> 4;
    $tIt$15 = $tIt$07;
    while(1) {
     $58 = HEAP32[$tIt$15>>2]|0;
     $59 = $58&65535;
     HEAP16[$2>>1] = $59;
     $60 = (($tIt$15) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = $61&65535;
     HEAP16[$49>>1] = $62;
     $63 = (($tIt$15) + 8|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = $64&65535;
     HEAP16[$50>>1] = $65;
     $66 = (($tIt$15) + 12|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = $67&65535;
     HEAP16[$51>>1] = $68;
     $69 = HEAP32[$43>>2]|0;
     $70 = $69 & 2147483647;
     $71 = HEAP32[$48>>2]|0;
     $72 = ($70>>>0)>($71>>>0);
     if ($72) {
      $73 = HEAP32[$34>>2]|0;
      $74 = (($73) + ($71<<3)|0);
      $75 = ($74|0)==(0|0);
      if ($75) {
       $87 = $71;
      } else {
       $76 = $2;
       $77 = $76;
       $78 = HEAP32[$77>>2]|0;
       $79 = (($76) + 4)|0;
       $80 = $79;
       $81 = HEAP32[$80>>2]|0;
       $82 = $74;
       $83 = $82;
       HEAP16[$83>>1]=$78&65535;HEAP16[$83+2>>1]=$78>>>16;
       $84 = (($82) + 4)|0;
       $85 = $84;
       HEAP16[$85>>1]=$81&65535;HEAP16[$85+2>>1]=$81>>>16;
       $$pre$i = HEAP32[$48>>2]|0;
       $87 = $$pre$i;
      }
      $86 = (($87) + 1)|0;
      HEAP32[$48>>2] = $86;
     } else {
      (__ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE15growAndPushBackERKS4_($34,$2)|0);
     }
     $88 = (($tIt$15) + 16|0);
     $89 = HEAP32[$6>>2]|0;
     $90 = (($89) + 1)|0;
     HEAP32[$6>>2] = $90;
     $91 = ($88|0)==($53|0);
     if ($91) {
      break;
     } else {
      $tIt$15 = $88;
     }
    }
    $scevgep$sum = (($57) + 1)|0;
    $scevgep11 = (($tIt$07) + ($scevgep$sum<<4)|0);
    $tIt$1$lcssa = $scevgep11;
   }
   $92 = HEAP32[$48>>2]|0;
   $93 = (($92) + 3)|0;
   $94 = $93 & -4;
   __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE6resizeEjRKS4_($34,$94,$dummy);
   $95 = (($sIt$08) + 4|0);
   $96 = ($95|0)==($32|0);
   if ($96) {
    $$pre$phi16Z2D = $34;$$pre$phi18Z2D = $48;
    break;
   } else {
    $sIt$08 = $95;$tIt$07 = $tIt$1$lcssa;
   }
  }
 }
 $97 = HEAP32[$$pre$phi16Z2D>>2]|0;
 $98 = HEAP32[$$pre$phi18Z2D>>2]|0;
 $99 = (($3) + 4|0);
 $100 = ($98|0)<(0);
 if ($100) {
  HEAP32[$99>>2] = 0;
  $101 = (($3) + 8|0);
  HEAP32[$101>>2] = 0;
  label = 19;
 } else {
  $$idx4 = $98 << 3;
  $102 = $$idx4 >> 3;
  HEAP32[$99>>2] = $102;
  $103 = (($3) + 8|0);
  HEAP32[$103>>2] = $102;
  $104 = ($102|0)==(0);
  if ($104) {
   label = 19;
  } else {
   $105 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$$idx4,478072,558)|0);
   $$pre$i$i = HEAP32[$99>>2]|0;
   HEAP32[$3>>2] = $105;
   $106 = (($105) + ($$pre$i$i<<3)|0);
   $107 = ($$pre$i$i|0)>(0);
   if ($107) {
    $$012$i$i$i = $105;$$03$i$i$i = $97;
    while(1) {
     $108 = ($$012$i$i$i|0)==(0|0);
     if (!($108)) {
      $109 = $$03$i$i$i;
      $110 = $109;
      $111 = HEAPU16[$110>>1]|(HEAPU16[$110+2>>1]<<16);
      $112 = (($109) + 4)|0;
      $113 = $112;
      $114 = HEAPU16[$113>>1]|(HEAPU16[$113+2>>1]<<16);
      $115 = $$012$i$i$i;
      $116 = $115;
      HEAP16[$116>>1]=$111&65535;HEAP16[$116+2>>1]=$111>>>16;
      $117 = (($115) + 4)|0;
      $118 = $117;
      HEAP16[$118>>1]=$114&65535;HEAP16[$118+2>>1]=$114>>>16;
     }
     $119 = (($$012$i$i$i) + 8|0);
     $120 = (($$03$i$i$i) + 8|0);
     $121 = ($119>>>0)<($106>>>0);
     if ($121) {
      $$012$i$i$i = $119;$$03$i$i$i = $120;
     } else {
      break;
     }
    }
    $$pre = HEAP32[$3>>2]|0;
    $$pre12 = HEAP32[$99>>2]|0;
    $$pre$phiZ2D = $103;$123 = $$pre;$125 = $$pre12;
   } else {
    $$pre$phiZ2D = $103;$123 = $105;$125 = $$pre$i$i;
   }
  }
 }
 if ((label|0) == 19) {
  HEAP32[$3>>2] = 0;
  $$pre14 = (($3) + 8|0);
  $$pre$phiZ2D = $$pre14;$123 = 0;$125 = 0;
 }
 $122 = HEAP32[$$pre$phi16Z2D>>2]|0;
 HEAP32[$3>>2] = $122;
 HEAP32[$$pre$phi16Z2D>>2] = $123;
 $124 = HEAP32[$$pre$phi18Z2D>>2]|0;
 HEAP32[$99>>2] = $124;
 HEAP32[$$pre$phi18Z2D>>2] = $125;
 $126 = HEAP32[$$pre$phiZ2D>>2]|0;
 $127 = HEAP32[$43>>2]|0;
 HEAP32[$$pre$phiZ2D>>2] = $127;
 HEAP32[$43>>2] = $126;
 $128 = $127 & 2147483647;
 $129 = ($128|0)!=(0);
 $130 = ($127|0)>(-1);
 $or$cond$i$i1 = $129 & $130;
 if ($or$cond$i$i1) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$122);
 }
 $131 = (($4) + 4|0);
 $132 = (($4) + 8|0);
 $133 = (($this) + 480|0);
 $134 = HEAP32[$133>>2]|0;
 HEAP32[$4>>2] = $134;
 HEAP32[$133>>2] = 0;
 $135 = (($this) + 484|0);
 $136 = HEAP32[$135>>2]|0;
 HEAP32[$131>>2] = $136;
 HEAP32[$135>>2] = 0;
 $137 = (($this) + 488|0);
 $138 = HEAP32[$137>>2]|0;
 HEAP32[$132>>2] = $138;
 HEAP32[$137>>2] = 0;
 $139 = $138 & 2147483647;
 $notlhs = ($139|0)==(0);
 $notrhs = ($138|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $140 = ($134|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $140;
 if ($or$cond) {
  $153 = 0;
 } else {
  $141 = (($134) + -4|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = (0 - ($142))|0;
  $144 = (($134) + ($143)|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$144);
  $$pre13 = HEAP32[$137>>2]|0;
  $phitmp = $$pre13 & 2147483647;
  $153 = $phitmp;
 }
 $145 = (($weights) + 4|0);
 $146 = HEAP32[$145>>2]|0;
 $147 = HEAP32[$weights>>2]|0;
 $148 = $146;
 $149 = $147;
 $150 = (($148) - ($149))|0;
 $151 = (($150|0) / 12)&-1;
 $152 = ($153>>>0)<($151>>>0);
 if ($152) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($133,$151);
 }
 $154 = ($147>>>0)<($146>>>0);
 if ($154) {
  $155 = (($5) + 4|0);
  $156 = (($5) + 8|0);
  $157 = (($5) + 12|0);
  $159 = $147;
  while(1) {
   $158 = Math_fround(HEAPF32[$159>>2]);
   $160 = (($159) + 4|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = (($159) + 8|0);
   $163 = Math_fround(HEAPF32[$162>>2]);
   $164 = Math_fround($158 * $158);
   $165 = Math_fround($161 * $161);
   $166 = Math_fround($164 + $165);
   $167 = Math_fround($163 * $163);
   $168 = Math_fround($166 + $167);
   $169 = Math_fround(Math_fround(1.0) / $168);
   HEAPF32[$5>>2] = $158;
   HEAPF32[$155>>2] = $161;
   HEAPF32[$156>>2] = $163;
   HEAPF32[$157>>2] = $169;
   $170 = HEAP32[$137>>2]|0;
   $171 = $170 & 2147483647;
   $172 = HEAP32[$135>>2]|0;
   $173 = ($171>>>0)>($172>>>0);
   if ($173) {
    $174 = HEAP32[$133>>2]|0;
    $175 = (($174) + ($172<<4)|0);
    $176 = ($175|0)==(0|0);
    if (!($176)) {
     HEAPF32[$175>>2] = $158;
     $177 = ((($174) + ($172<<4)|0) + 4|0);
     HEAPF32[$177>>2] = $161;
     $178 = ((($174) + ($172<<4)|0) + 8|0);
     HEAPF32[$178>>2] = $163;
     $179 = ((($174) + ($172<<4)|0) + 12|0);
     HEAPF32[$179>>2] = $169;
    }
    $180 = (($172) + 1)|0;
    HEAP32[$135>>2] = $180;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE15growAndPushBackERKS2_($133,$5)|0);
   }
   $181 = (($159) + 12|0);
   $182 = ($181>>>0)<($146>>>0);
   if ($182) {
    $159 = $181;
   } else {
    break;
   }
  }
  HEAP32[$weights>>2] = $181;
 }
 $183 = (($scheduler) + 20|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = $184 & 2147483647;
 $186 = ($185|0)!=(0);
 $187 = ($184|0)>(-1);
 $or$cond$i$i$i$i = $186 & $187;
 if ($or$cond$i$i$i$i) {
  $188 = HEAP32[$28>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($28,$188);
 }
 $189 = (($scheduler) + 8|0);
 $190 = HEAP32[$189>>2]|0;
 $191 = $190 & 2147483647;
 $192 = ($191|0)!=(0);
 $193 = ($190|0)>(-1);
 $or$cond$i$i1$i$i = $192 & $193;
 if (!($or$cond$i$i1$i$i)) {
  STACKTOP = sp;return;
 }
 $194 = HEAP32[$scheduler>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($scheduler,$194);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<3)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<3)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = $a;
   $12 = $11;
   $13 = HEAPU16[$12>>1]|(HEAPU16[$12+2>>1]<<16);
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAPU16[$15>>1]|(HEAPU16[$15+2>>1]<<16);
   $17 = $$01$i;
   $18 = $17;
   HEAP16[$18>>1]=$13&65535;HEAP16[$18+2>>1]=$13>>>16;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP16[$20>>1]=$16&65535;HEAP16[$20+2>>1]=$16>>>16;
  }
  $21 = (($$01$i) + 8|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE19setVirtualParticlesENS0_5RangeIA4_KjEENS4_IKNS_6PxVec3EEE($this,$indices,$weights) {
 $this = $this|0;
 $indices = $indices|0;
 $weights = $weights|0;
 var $0 = 0, $indices$byval_copy = 0, $weights$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $weights$byval_copy = sp + 8|0;
 $indices$byval_copy = sp;
 $0 = (($this) + -4|0);
 ;HEAP32[$indices$byval_copy+0>>2]=HEAP32[$indices+0>>2]|0;HEAP32[$indices$byval_copy+4>>2]=HEAP32[$indices+4>>2]|0;
 ;HEAP32[$weights$byval_copy+0>>2]=HEAP32[$weights+0>>2]|0;HEAP32[$weights$byval_copy+4>>2]=HEAP32[$weights+4>>2]|0;
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE19setVirtualParticlesENS0_5RangeIA4_KjEENS4_IKNS_6PxVec3EEE($0,$indices$byval_copy,$weights$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0;
 var $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $20 = 0;
 } else {
  $6 = $$$i << 4;
  $7 = (($6) + 19)|0;
  $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$7,478072,558)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $20 = 0;
  } else {
   $10 = (($8) + 19|0);
   $11 = $10;
   $12 = $11 & -16;
   $13 = $8;
   $14 = (($12) - ($13))|0;
   $15 = $12;
   $16 = (($15) + -4|0);
   HEAP32[$16>>2] = $14;
   $phitmp$i = $12;
   $20 = $phitmp$i;
  }
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<4)|0);
 $21 = ($18|0)>(0);
 if ($21) {
  $22 = HEAP32[$this>>2]|0;
  $$012$i = $20;$$03$i = $22;
  while(1) {
   $23 = ($$012$i|0)==(0|0);
   if (!($23)) {
    $24 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $24;
    $25 = (($$012$i) + 4|0);
    $26 = (($$03$i) + 4|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    HEAPF32[$25>>2] = $27;
    $28 = (($$012$i) + 8|0);
    $29 = (($$03$i) + 8|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$28>>2] = $30;
    $31 = (($$012$i) + 12|0);
    $32 = (($$03$i) + 12|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    HEAPF32[$31>>2] = $33;
   }
   $34 = (($$012$i) + 16|0);
   $35 = (($$03$i) + 16|0);
   $36 = ($34>>>0)<($19>>>0);
   if ($36) {
    $$012$i = $34;$$03$i = $35;
   } else {
    break;
   }
  }
 }
 $37 = ($19|0)==(0|0);
 if (!($37)) {
  $38 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$19>>2] = $38;
  $39 = ((($20) + ($18<<4)|0) + 4|0);
  $40 = (($a) + 4|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  HEAPF32[$39>>2] = $41;
  $42 = ((($20) + ($18<<4)|0) + 8|0);
  $43 = (($a) + 8|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$42>>2] = $44;
  $45 = ((($20) + ($18<<4)|0) + 12|0);
  $46 = (($a) + 12|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  HEAPF32[$45>>2] = $47;
 }
 $48 = HEAP32[$0>>2]|0;
 $49 = ($48|0)>(-1);
 if (!($49)) {
  $57 = $18;
  HEAP32[$this>>2] = $20;
  HEAP32[$0>>2] = $$$i;
  $56 = (($57) + 1)|0;
  HEAP32[$17>>2] = $56;
  $58 = (($20) + ($57<<4)|0);
  STACKTOP = sp;return ($58|0);
 }
 $50 = HEAP32[$this>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  $57 = $18;
  HEAP32[$this>>2] = $20;
  HEAP32[$0>>2] = $$$i;
  $56 = (($57) + 1)|0;
  HEAP32[$17>>2] = $56;
  $58 = (($20) + ($57<<4)|0);
  STACKTOP = sp;return ($58|0);
 }
 $52 = (($50) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (0 - ($53))|0;
 $55 = (($50) + ($54)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$55);
 $$pre = HEAP32[$17>>2]|0;
 $57 = $$pre;
 HEAP32[$this>>2] = $20;
 HEAP32[$0>>2] = $$$i;
 $56 = (($57) + 1)|0;
 HEAP32[$17>>2] = $56;
 $58 = (($20) + ($57<<4)|0);
 STACKTOP = sp;return ($58|0);
}
function __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,478072,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + ($9<<3)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    $15 = $$03$i;
    $16 = $15;
    $17 = HEAPU16[$16>>1]|(HEAPU16[$16+2>>1]<<16);
    $18 = (($15) + 4)|0;
    $19 = $18;
    $20 = HEAPU16[$19>>1]|(HEAPU16[$19+2>>1]<<16);
    $21 = $$012$i;
    $22 = $21;
    HEAP16[$22>>1]=$17&65535;HEAP16[$22+2>>1]=$17>>>16;
    $23 = (($21) + 4)|0;
    $24 = $23;
    HEAP16[$24>>1]=$20&65535;HEAP16[$24+2>>1]=$20>>>16;
   }
   $25 = (($$012$i) + 8|0);
   $26 = (($$03$i) + 8|0);
   $27 = ($25>>>0)<($10>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$8>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $9;
 }
 $28 = (($11) + ($29<<3)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  $31 = $a;
  $32 = $31;
  $33 = HEAPU16[$32>>1]|(HEAPU16[$32+2>>1]<<16);
  $34 = (($31) + 4)|0;
  $35 = $34;
  $36 = HEAPU16[$35>>1]|(HEAPU16[$35+2>>1]<<16);
  $37 = $28;
  $38 = $37;
  HEAP16[$38>>1]=$33&65535;HEAP16[$38+2>>1]=$33>>>16;
  $39 = (($37) + 4)|0;
  $40 = $39;
  HEAP16[$40>>1]=$36&65535;HEAP16[$40+2>>1]=$36>>>16;
 }
 $41 = HEAP32[$0>>2]|0;
 $42 = ($41|0)>(-1);
 if (!($42)) {
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $44 = HEAP32[$8>>2]|0;
  $45 = (($44) + 1)|0;
  HEAP32[$8>>2] = $45;
  $46 = (($11) + ($44<<3)|0);
  STACKTOP = sp;return ($46|0);
 }
 $43 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$43);
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $44 = HEAP32[$8>>2]|0;
 $45 = (($44) + 1)|0;
 HEAP32[$8>>2] = $45;
 $46 = (($11) + ($44<<3)|0);
 STACKTOP = sp;return ($46|0);
}
function __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$1,478072,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<3)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = $$03$i;
    $11 = $10;
    $12 = HEAPU16[$11>>1]|(HEAPU16[$11+2>>1]<<16);
    $13 = (($10) + 4)|0;
    $14 = $13;
    $15 = HEAPU16[$14>>1]|(HEAPU16[$14+2>>1]<<16);
    $16 = $$012$i;
    $17 = $16;
    HEAP16[$17>>1]=$12&65535;HEAP16[$17+2>>1]=$12>>>16;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP16[$19>>1]=$15&65535;HEAP16[$19+2>>1]=$15>>>16;
   }
   $20 = (($$012$i) + 8|0);
   $21 = (($$03$i) + 8|0);
   $22 = ($20>>>0)<($5>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$26);
 HEAP32[$this>>2] = $6;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$1,478072,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<2)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $10;
   }
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11>>>0)<($5>>>0);
   if ($13) {
    $$012$i = $11;$$03$i = $12;
   } else {
    break;
   }
  }
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(-1);
 if (!($16)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$14>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$17);
 HEAP32[$this>>2] = $6;
 HEAP32[$14>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth11PhaseConfigENS0_9AllocatorEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = ($$$i*20)|0;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,478072,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + (($9*20)|0)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
   }
   $15 = (($$012$i) + 20|0);
   $16 = (($$03$i) + 20|0);
   $17 = ($15>>>0)<($10>>>0);
   if ($17) {
    $$012$i = $15;$$03$i = $16;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$8>>2]|0;
  $19 = $$pre;
 } else {
  $19 = $9;
 }
 $18 = (($11) + (($19*20)|0)|0);
 $20 = ($18|0)==(0|0);
 if (!($20)) {
  ;HEAP32[$18+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$18+16>>2]=HEAP32[$a+16>>2]|0;
 }
 $21 = HEAP32[$0>>2]|0;
 $22 = ($21|0)>(-1);
 if (!($22)) {
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $24 = HEAP32[$8>>2]|0;
  $25 = (($24) + 1)|0;
  HEAP32[$8>>2] = $25;
  $26 = (($11) + (($24*20)|0)|0);
  STACKTOP = sp;return ($26|0);
 }
 $23 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$23);
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $24 = HEAP32[$8>>2]|0;
 $25 = (($24) + 1)|0;
 HEAP32[$8>>2] = $25;
 $26 = (($11) + (($24*20)|0)|0);
 STACKTOP = sp;return ($26|0);
}
function __ZN5physx6shdfnd5ArrayINS_5cloth11PhaseConfigENS0_9AllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = ($capacity*20)|0;
  $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$1,478072,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + (($4*20)|0)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
   }
   $10 = (($$012$i) + 20|0);
   $11 = (($$03$i) + 20|0);
   $12 = ($10>>>0)<($5>>>0);
   if ($12) {
    $$012$i = $10;$$03$i = $11;
   } else {
    break;
   }
  }
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(-1);
 if (!($15)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$13>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$16);
 HEAP32[$this>>2] = $6;
 HEAP32[$13>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$1,478072,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<3)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = $$03$i;
    $11 = $10;
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + 4)|0;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = $$012$i;
    $17 = $16;
    HEAP32[$17>>2] = $12;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP32[$19>>2] = $15;
   }
   $20 = (($$012$i) + 8|0);
   $21 = (($$03$i) + 8|0);
   $22 = ($20>>>0)<($5>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$26);
 HEAP32[$this>>2] = $6;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE4copyIS2_EEvRKNS1_IjT_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $16 = (($this) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($this) + 8|0);
  HEAP32[$17>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$5,478072,558)|0);
 HEAP32[$this>>2] = $6;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) + ($7<<2)|0);
 $9 = ($6>>>0)<($8>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$other>>2]|0;
 $$012$i = $6;$$03$i = $10;
 while(1) {
  $11 = ($$012$i|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $12;
  }
  $13 = (($$012$i) + 4|0);
  $14 = (($$03$i) + 4|0);
  $15 = ($13>>>0)<($8>>>0);
  if ($15) {
   $$012$i = $13;$$03$i = $14;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth5Vec4TItEENS0_9AllocatorEE4copyIS5_EEvRKNS1_IS4_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $25 = (($this) + 4|0);
  HEAP32[$25>>2] = 0;
  $26 = (($this) + 8|0);
  HEAP32[$26>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 3;
 $6 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$5,478072,558)|0);
 HEAP32[$this>>2] = $6;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) + ($7<<3)|0);
 $9 = ($6>>>0)<($8>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$other>>2]|0;
 $$012$i = $6;$$03$i = $10;
 while(1) {
  $11 = ($$012$i|0)==(0|0);
  if (!($11)) {
   $12 = $$03$i;
   $13 = $12;
   $14 = HEAPU16[$13>>1]|(HEAPU16[$13+2>>1]<<16);
   $15 = (($12) + 4)|0;
   $16 = $15;
   $17 = HEAPU16[$16>>1]|(HEAPU16[$16+2>>1]<<16);
   $18 = $$012$i;
   $19 = $18;
   HEAP16[$19>>1]=$14&65535;HEAP16[$19+2>>1]=$14>>>16;
   $20 = (($18) + 4)|0;
   $21 = $20;
   HEAP16[$21>>1]=$17&65535;HEAP16[$21+2>>1]=$17>>>16;
  }
  $22 = (($$012$i) + 8|0);
  $23 = (($$03$i) + 8|0);
  $24 = ($22>>>0)<($8>>>0);
  if ($24) {
   $$012$i = $22;$$03$i = $23;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE4copyIS3_EEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $22 = (($this) + 4|0);
  HEAP32[$22>>2] = 0;
  $23 = (($this) + 8|0);
  HEAP32[$23>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = ($1*12)|0;
 $6 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$5,478072,558)|0);
 HEAP32[$this>>2] = $6;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) + (($7*12)|0)|0);
 $9 = ($6>>>0)<($8>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$other>>2]|0;
 $$012$i = $6;$$03$i = $10;
 while(1) {
  $11 = ($$012$i|0)==(0|0);
  if (!($11)) {
   $12 = Math_fround(HEAPF32[$$03$i>>2]);
   HEAPF32[$$012$i>>2] = $12;
   $13 = (($$012$i) + 4|0);
   $14 = (($$03$i) + 4|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   HEAPF32[$13>>2] = $15;
   $16 = (($$012$i) + 8|0);
   $17 = (($$03$i) + 8|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   HEAPF32[$16>>2] = $18;
  }
  $19 = (($$012$i) + 12|0);
  $20 = (($$03$i) + 12|0);
  $21 = ($19>>>0)<($8>>>0);
  if ($21) {
   $$012$i = $19;$$03$i = $20;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE4copyIS5_EEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $35 = (($this) + 4|0);
  HEAP32[$35>>2] = 0;
  $36 = (($this) + 8|0);
  HEAP32[$36>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 4;
 $6 = (($5) + 19)|0;
 $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,478072,558)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  $16 = 0;
 } else {
  $9 = (($7) + 19|0);
  $10 = $9;
  $11 = $10 & -16;
  $12 = $7;
  $13 = (($11) - ($12))|0;
  $14 = $11;
  $15 = (($14) + -4|0);
  HEAP32[$15>>2] = $13;
  $phitmp$i = $11;
  $16 = $phitmp$i;
 }
 HEAP32[$this>>2] = $16;
 $17 = HEAP32[$4>>2]|0;
 $18 = (($16) + ($17<<4)|0);
 $19 = ($17|0)>(0);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$other>>2]|0;
 $$012$i = $16;$$03$i = $20;
 while(1) {
  $21 = ($$012$i|0)==(0|0);
  if (!($21)) {
   $22 = Math_fround(HEAPF32[$$03$i>>2]);
   HEAPF32[$$012$i>>2] = $22;
   $23 = (($$012$i) + 4|0);
   $24 = (($$03$i) + 4|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   HEAPF32[$23>>2] = $25;
   $26 = (($$012$i) + 8|0);
   $27 = (($$03$i) + 8|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   HEAPF32[$26>>2] = $28;
   $29 = (($$012$i) + 12|0);
   $30 = (($$03$i) + 12|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   HEAPF32[$29>>2] = $31;
  }
  $32 = (($$012$i) + 16|0);
  $33 = (($$03$i) + 16|0);
  $34 = ($32>>>0)<($18>>>0);
  if ($34) {
   $$012$i = $32;$$03$i = $33;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth9IndexPairENS0_9AllocatorEE4copyIS4_EEvRKNS1_IS3_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $25 = (($this) + 4|0);
  HEAP32[$25>>2] = 0;
  $26 = (($this) + 8|0);
  HEAP32[$26>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 3;
 $6 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$5,478072,558)|0);
 HEAP32[$this>>2] = $6;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) + ($7<<3)|0);
 $9 = ($6>>>0)<($8>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$other>>2]|0;
 $$012$i = $6;$$03$i = $10;
 while(1) {
  $11 = ($$012$i|0)==(0|0);
  if (!($11)) {
   $12 = $$03$i;
   $13 = $12;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($12) + 4)|0;
   $16 = $15;
   $17 = HEAP32[$16>>2]|0;
   $18 = $$012$i;
   $19 = $18;
   HEAP32[$19>>2] = $14;
   $20 = (($18) + 4)|0;
   $21 = $20;
   HEAP32[$21>>2] = $17;
  }
  $22 = (($$012$i) + 8|0);
  $23 = (($$03$i) + 8|0);
  $24 = ($22>>>0)<($8>>>0);
  if ($24) {
   $$012$i = $22;$$03$i = $23;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth11PhaseConfigENS0_9AllocatorEE4copyIS4_EEvRKNS1_IS3_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $15 = (($this) + 4|0);
  HEAP32[$15>>2] = 0;
  $16 = (($this) + 8|0);
  HEAP32[$16>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = ($1*20)|0;
 $6 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$5,478072,558)|0);
 HEAP32[$this>>2] = $6;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($6) + (($7*20)|0)|0);
 $9 = ($6>>>0)<($8>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$other>>2]|0;
 $$012$i = $6;$$03$i = $10;
 while(1) {
  $11 = ($$012$i|0)==(0|0);
  if (!($11)) {
   ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
  }
  $12 = (($$012$i) + 20|0);
  $13 = (($$03$i) + 20|0);
  $14 = ($12>>>0)<($8>>>0);
  if ($14) {
   $$012$i = $12;$$03$i = $13;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $15 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = (($1) + 19)|0;
  $3 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$2,478072,558)|0);
  $4 = ($3|0)==(0|0);
  if ($4) {
   $15 = 0;
  } else {
   $5 = (($3) + 19|0);
   $6 = $5;
   $7 = $6 & -16;
   $8 = $3;
   $9 = (($7) - ($8))|0;
   $10 = $7;
   $11 = (($10) + -4|0);
   HEAP32[$11>>2] = $9;
   $phitmp$i = $7;
   $15 = $phitmp$i;
  }
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($15) + ($13<<4)|0);
 $16 = ($13|0)>(0);
 if ($16) {
  $17 = HEAP32[$this>>2]|0;
  $$012$i = $15;$$03$i = $17;
  while(1) {
   $18 = ($$012$i|0)==(0|0);
   if (!($18)) {
    $19 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $19;
    $20 = (($$012$i) + 4|0);
    $21 = (($$03$i) + 4|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    HEAPF32[$20>>2] = $22;
    $23 = (($$012$i) + 8|0);
    $24 = (($$03$i) + 8|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    HEAPF32[$23>>2] = $25;
    $26 = (($$012$i) + 12|0);
    $27 = (($$03$i) + 12|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
   }
   $29 = (($$012$i) + 16|0);
   $30 = (($$03$i) + 16|0);
   $31 = ($29>>>0)<($14>>>0);
   if ($31) {
    $$012$i = $29;$$03$i = $30;
   } else {
    break;
   }
  }
 }
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)>(-1);
 if (!($34)) {
  HEAP32[$this>>2] = $15;
  HEAP32[$32>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = HEAP32[$this>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  HEAP32[$this>>2] = $15;
  HEAP32[$32>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $37 = (($35) + -4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (0 - ($38))|0;
 $40 = (($35) + ($39)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$40);
 HEAP32[$this>>2] = $15;
 HEAP32[$32>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwClothDataC2ERNS0_7SwClothERKNS0_8SwFabricE($this,$cloth,$fabric) {
 $this = $this|0;
 $cloth = $cloth|0;
 $fabric = $fabric|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0;
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$this>>2] = $1;
 $2 = (($cloth) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($cloth) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 8|0);
 HEAP32[$7>>2] = $6;
 $8 = (($cloth) + 32|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($cloth) + 44|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($this) + 12|0);
 HEAPF32[$13>>2] = $12;
 $14 = Math_fround(HEAPF32[$8>>2]);
 $15 = Math_fround(HEAPF32[$10>>2]);
 $16 = Math_fround($14 + $15);
 $17 = (($this) + 24|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($cloth) + 36|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($cloth) + 48|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($19 - $21);
 $23 = (($this) + 16|0);
 HEAPF32[$23>>2] = $22;
 $24 = Math_fround(HEAPF32[$18>>2]);
 $25 = Math_fround(HEAPF32[$20>>2]);
 $26 = Math_fround($24 + $25);
 $27 = (($this) + 28|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($cloth) + 40|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($cloth) + 52|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($29 - $31);
 $33 = (($this) + 20|0);
 HEAPF32[$33>>2] = $32;
 $34 = Math_fround(HEAPF32[$28>>2]);
 $35 = Math_fround(HEAPF32[$30>>2]);
 $36 = Math_fround($34 + $35);
 $37 = (($this) + 32|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($this) + 36|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($cloth) + 256|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0);
 if ($41) {
  $45 = 0;
 } else {
  $42 = (($cloth) + 252|0);
  $43 = HEAP32[$42>>2]|0;
  $45 = $43;
 }
 $44 = (($this) + 64|0);
 HEAP32[$44>>2] = $45;
 $46 = (($45) + (($40*20)|0)|0);
 $47 = (($this) + 68|0);
 HEAP32[$47>>2] = $46;
 $48 = (($fabric) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 72|0);
 HEAP32[$50>>2] = $49;
 $51 = (($fabric) + 24|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 76|0);
 HEAP32[$53>>2] = $52;
 $54 = (($fabric) + 32|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($this) + 80|0);
 HEAP32[$56>>2] = $55;
 $57 = (($fabric) + 36|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 84|0);
 HEAP32[$59>>2] = $58;
 $60 = (($fabric) + 44|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($this) + 88|0);
 HEAP32[$62>>2] = $61;
 $63 = (($fabric) + 48|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($this) + 92|0);
 HEAP32[$65>>2] = $64;
 $66 = (($fabric) + 56|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($this) + 96|0);
 HEAP32[$68>>2] = $67;
 $69 = (($fabric) + 60|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($this) + 100|0);
 HEAP32[$71>>2] = $70;
 $72 = (($cloth) + 144|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($cloth) + 228|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($73 * $75);
 $77 = Math_fround($76 * Math_fround(0.693147182464599609375));
 $78 = (($fabric) + 68|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($this) + 104|0);
 HEAP32[$80>>2] = $79;
 $81 = (($fabric) + 72|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($this) + 108|0);
 HEAP32[$83>>2] = $82;
 $84 = (($cloth) + 264|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($77 * $85);
 $87 = +$86;
 $88 = (+Math_exp((+$87)));
 $89 = 1.0 - $88;
 $90 = Math_fround($89);
 $91 = (($this) + 112|0);
 HEAPF32[$91>>2] = $90;
 $92 = (($cloth) + 268|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($fabric) + 80|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($93 * $95);
 $97 = (($this) + 116|0);
 HEAPF32[$97>>2] = $96;
 $98 = (($cloth) + 276|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($99|0)==(0);
 if ($100) {
  $104 = 0;
 } else {
  $101 = (($cloth) + 272|0);
  $102 = HEAP32[$101>>2]|0;
  $104 = $102;
 }
 $103 = (($this) + 120|0);
 HEAP32[$103>>2] = $104;
 $105 = (($cloth) + 288|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($106|0)==(0);
 if ($107) {
  $111 = 0;
 } else {
  $108 = (($cloth) + 284|0);
  $109 = HEAP32[$108>>2]|0;
  $111 = $109;
 }
 $110 = (($this) + 124|0);
 HEAP32[$110>>2] = $111;
 $112 = (($cloth) + 304|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($77 * $113);
 $115 = +$114;
 $116 = (+Math_exp((+$115)));
 $117 = 1.0 - $116;
 $118 = Math_fround($117);
 $119 = (($this) + 128|0);
 HEAPF32[$119>>2] = $118;
 $120 = (($cloth) + 312|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($121|0)==(0);
 if ($122) {
  $126 = 0;
 } else {
  $123 = (($cloth) + 308|0);
  $124 = HEAP32[$123>>2]|0;
  $126 = $124;
 }
 $125 = (($this) + 132|0);
 HEAP32[$125>>2] = $126;
 $127 = (($cloth) + 324|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = ($128|0)==(0);
 if ($129) {
  $133 = 0;
 } else {
  $130 = (($cloth) + 320|0);
  $131 = HEAP32[$130>>2]|0;
  $133 = $131;
 }
 $132 = (($this) + 136|0);
 HEAP32[$132>>2] = $133;
 $134 = (($cloth) + 336|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = ($135|0)==(0);
 if ($136) {
  $140 = 0;
 } else {
  $137 = (($cloth) + 332|0);
  $138 = HEAP32[$137>>2]|0;
  $140 = $138;
 }
 $139 = (($this) + 140|0);
 HEAP32[$139>>2] = $140;
 $141 = (($cloth) + 360|0);
 $142 = HEAP32[$141>>2]|0;
 $143 = ($142|0)==(0);
 if ($143) {
  $147 = 0;
 } else {
  $144 = (($cloth) + 356|0);
  $145 = HEAP32[$144>>2]|0;
  $147 = $145;
 }
 $146 = (($this) + 144|0);
 HEAP32[$146>>2] = $147;
 $148 = (($cloth) + 372|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = ($149|0)==(0);
 if ($150) {
  $154 = $147;
 } else {
  $151 = (($cloth) + 368|0);
  $152 = HEAP32[$151>>2]|0;
  $154 = $152;
 }
 $153 = (($this) + 148|0);
 HEAP32[$153>>2] = $154;
 $155 = (($this) + 152|0);
 HEAP32[$155>>2] = $142;
 $156 = (($cloth) + 348|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = ($157|0)==(0);
 if ($158) {
  $162 = 0;
 } else {
  $159 = (($cloth) + 344|0);
  $160 = HEAP32[$159>>2]|0;
  $162 = $160;
 }
 $161 = (($this) + 156|0);
 HEAP32[$161>>2] = $162;
 $163 = (($this) + 160|0);
 HEAP32[$163>>2] = $157;
 $164 = (($cloth) + 396|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = ($165|0)==(0);
 if ($166) {
  $170 = 0;
 } else {
  $167 = (($cloth) + 392|0);
  $168 = HEAP32[$167>>2]|0;
  $170 = $168;
 }
 $169 = (($this) + 164|0);
 HEAP32[$169>>2] = $170;
 $171 = (($cloth) + 408|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = ($172|0)==(0);
 if ($173) {
  $177 = $170;
 } else {
  $174 = (($cloth) + 404|0);
  $175 = HEAP32[$174>>2]|0;
  $177 = $175;
 }
 $176 = (($this) + 168|0);
 HEAP32[$176>>2] = $177;
 $178 = (($this) + 172|0);
 HEAP32[$178>>2] = $165;
 $179 = (($cloth) + 384|0);
 $180 = HEAP32[$179>>2]|0;
 $181 = ($180|0)==(0);
 if ($181) {
  $185 = 0;
 } else {
  $182 = (($cloth) + 380|0);
  $183 = HEAP32[$182>>2]|0;
  $185 = $183;
 }
 $184 = (($this) + 176|0);
 HEAP32[$184>>2] = $185;
 $186 = (($this) + 180|0);
 HEAP32[$186>>2] = $180;
 $187 = (($cloth) + 420|0);
 $188 = HEAP32[$187>>2]|0;
 $189 = ($188|0)==(0);
 if ($189) {
  $193 = 0;
 } else {
  $190 = (($cloth) + 416|0);
  $191 = HEAP32[$190>>2]|0;
  $193 = $191;
 }
 $192 = (($this) + 184|0);
 HEAP32[$192>>2] = $193;
 $194 = (($cloth) + 432|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)==(0);
 if ($196) {
  $200 = $193;
 } else {
  $197 = (($cloth) + 428|0);
  $198 = HEAP32[$197>>2]|0;
  $200 = $198;
 }
 $199 = (($this) + 188|0);
 HEAP32[$199>>2] = $200;
 $201 = (($188>>>0) / 3)&-1;
 $202 = (($this) + 192|0);
 HEAP32[$202>>2] = $201;
 $203 = (($cloth) + 456|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = ($204|0)==(0);
 if ($205) {
  $209 = 0;
 } else {
  $206 = (($cloth) + 452|0);
  $207 = HEAP32[$206>>2]|0;
  $209 = $207;
 }
 $208 = (($this) + 196|0);
 HEAP32[$208>>2] = $209;
 $210 = $204 << 2;
 $211 = (($209) + ($210<<1)|0);
 $212 = (($this) + 200|0);
 HEAP32[$212>>2] = $211;
 $213 = (($cloth) + 468|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = ($214|0)==(0);
 if ($215) {
  $219 = 0;
 } else {
  $216 = (($cloth) + 464|0);
  $217 = HEAP32[$216>>2]|0;
  $219 = $217;
 }
 $218 = (($this) + 204|0);
 HEAP32[$218>>2] = $219;
 $220 = (($this) + 208|0);
 HEAP32[$220>>2] = $214;
 $221 = (($cloth) + 440|0);
 $222 = HEAP8[$221>>0]|0;
 $223 = (($this) + 212|0);
 HEAP8[$223>>0] = $222;
 $224 = (($cloth) + 444|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = (($this) + 220|0);
 HEAPF32[$226>>2] = $225;
 $227 = (($cloth) + 448|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 $229 = (($this) + 216|0);
 HEAPF32[$229>>2] = $228;
 $230 = (($cloth) + 480|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($this) + 224|0);
 HEAPF32[$232>>2] = $231;
 $233 = (($cloth) + 484|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = Math_fround($77 * $234);
 $236 = +$235;
 $237 = (+Math_exp((+$236)));
 $238 = 1.0 - $237;
 $239 = Math_fround($238);
 $240 = (($this) + 228|0);
 HEAPF32[$240>>2] = $239;
 $241 = (($cloth) + 492|0);
 $242 = HEAP32[$241>>2]|0;
 $243 = ($242|0)==(0);
 if ($243) {
  $244 = (($this) + 236|0);
  HEAP32[$244>>2] = 0;
  label = 36;
 } else {
  $245 = (($cloth) + 488|0);
  $246 = HEAP32[$245>>2]|0;
  $247 = (($this) + 236|0);
  HEAP32[$247>>2] = $246;
  $248 = ($246|0)==(0|0);
  if ($248) {
   label = 36;
  } else {
   $$in = $241;
  }
 }
 if ((label|0) == 36) {
  $$in = $this;
 }
 $249 = HEAP32[$$in>>2]|0;
 $250 = (($this) + 232|0);
 HEAP32[$250>>2] = $249;
 $251 = (($cloth) + 504|0);
 $252 = HEAP32[$251>>2]|0;
 $253 = ($252|0)==(0);
 if ($253) {
  $257 = 0;
  $256 = (($this) + 240|0);
  HEAP32[$256>>2] = $257;
  $258 = (($cloth) + 524|0);
  $259 = HEAP32[$258>>2]|0;
  $260 = (($this) + 244|0);
  HEAP32[$260>>2] = $259;
  $261 = (($cloth) + 528|0);
  $262 = HEAP32[$261>>2]|0;
  $263 = (($this) + 248|0);
  HEAP32[$263>>2] = $262;
  STACKTOP = sp;return;
 }
 $254 = (($cloth) + 500|0);
 $255 = HEAP32[$254>>2]|0;
 $257 = $255;
 $256 = (($this) + 240|0);
 HEAP32[$256>>2] = $257;
 $258 = (($cloth) + 524|0);
 $259 = HEAP32[$258>>2]|0;
 $260 = (($this) + 244|0);
 HEAP32[$260>>2] = $259;
 $261 = (($cloth) + 528|0);
 $262 = HEAP32[$261>>2]|0;
 $263 = (($this) + 248|0);
 HEAP32[$263>>2] = $262;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth11SwClothData9reconcileERNS0_7SwClothE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0);
 var $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($cloth) + 32|0);
 $2 = (($cloth) + 44|0);
 $3 = (($this) + 24|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$0>>2]);
 $6 = Math_fround($4 + $5);
 $7 = Math_fround($6 * Math_fround(0.5));
 HEAPF32[$1>>2] = $7;
 $8 = Math_fround(HEAPF32[$3>>2]);
 $9 = Math_fround(HEAPF32[$0>>2]);
 $10 = Math_fround($8 - $9);
 $11 = Math_fround($10 * Math_fround(0.5));
 HEAPF32[$2>>2] = $11;
 $12 = (($this) + 28|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 + $15);
 $17 = Math_fround($16 * Math_fround(0.5));
 $18 = (($1) + 4|0);
 HEAPF32[$18>>2] = $17;
 $19 = Math_fround(HEAPF32[$12>>2]);
 $20 = Math_fround(HEAPF32[$14>>2]);
 $21 = Math_fround($19 - $20);
 $22 = Math_fround($21 * Math_fround(0.5));
 $23 = (($2) + 4|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($this) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 20|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 + $27);
 $29 = Math_fround($28 * Math_fround(0.5));
 $30 = (($1) + 8|0);
 HEAPF32[$30>>2] = $29;
 $31 = Math_fround(HEAPF32[$24>>2]);
 $32 = Math_fround(HEAPF32[$26>>2]);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($33 * Math_fround(0.5));
 $35 = (($2) + 8|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($this) + 248|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($cloth) + 528|0);
 HEAP32[$38>>2] = $37;
 $39 = (($this) + 244|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($cloth) + 524|0);
 HEAP32[$41>>2] = $40;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth11SwClothData6verifyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fEC1ERNS0_11SwClothDataER14StackAllocatorILj16EEPNS_13PxProfileZoneE($this,$clothData,$alloc,$profiler) {
 $this = $this|0;
 $clothData = $clothData|0;
 $alloc = $alloc|0;
 $profiler = $profiler|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx5cloth11SwCollisionI8Scalar4fEC2ERNS0_11SwClothDataER14StackAllocatorILj16EEPNS_13PxProfileZoneE($this,$clothData,$alloc,$profiler);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fEC2ERNS0_11SwClothDataER14StackAllocatorILj16EEPNS_13PxProfileZoneE($this,$clothData,$alloc,$profiler) {
 $this = $this|0;
 $clothData = $clothData|0;
 $alloc = $alloc|0;
 $profiler = $profiler|0;
 var $$0$i$i = 0, $$0$i$i2 = 0, $$0$i1$i5 = 0, $$011$i = 0, $$02$i = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0;
 var $phitmp$i1 = 0, $phitmp3$i = 0, $phitmp3$i4 = 0, $sIt$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 $1 = (($this) + 420|0);
 $2 = (($this) + 424|0);
 $3 = (($this) + 428|0);
 $4 = (($this) + 432|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 HEAP32[$4>>2] = $clothData;
 $5 = (($this) + 436|0);
 HEAP32[$5>>2] = $alloc;
 $6 = (($this) + 444|0);
 HEAP32[$6>>2] = $profiler;
 $7 = (($clothData) + 152|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 4;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0$i$i2 = 0;$24 = $clothData;$29 = $alloc;
 } else {
  $11 = (($alloc) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12;
  $14 = (($13) + 23)|0;
  $15 = $14 & -16;
  $16 = $15;
  $17 = (($16) + ($9)|0);
  $18 = (($16) + -8|0);
  $19 = (($alloc) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$18>>2] = $20;
  $21 = (($16) + -4|0);
  $22 = $9 & 2147483632;
  HEAP32[$21>>2] = $22;
  HEAP32[$19>>2] = $18;
  HEAP32[$11>>2] = $17;
  $phitmp$i1 = $15;
  $$pre = HEAP32[$5>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $$0$i$i2 = $phitmp$i1;$24 = $$pre7;$29 = $$pre;
 }
 HEAP32[$2>>2] = $$0$i$i2;
 $23 = (($24) + 160|0);
 $25 = HEAP32[$23>>2]|0;
 $26 = ($25*48)|0;
 $27 = ($26|0)==(0);
 if ($27) {
  $$0$i1$i5 = 0;$42 = $24;
 } else {
  $28 = (($29) + 8|0);
  $30 = HEAP32[$28>>2]|0;
  $31 = $30;
  $32 = (($31) + 23)|0;
  $33 = $32 & -16;
  $34 = $33;
  $35 = (($34) + ($26)|0);
  $36 = (($34) + -8|0);
  $37 = (($29) + 12|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$36>>2] = $38;
  $39 = (($34) + -4|0);
  $40 = $26 & 2147483632;
  HEAP32[$39>>2] = $40;
  HEAP32[$37>>2] = $36;
  HEAP32[$28>>2] = $35;
  $phitmp3$i4 = $33;
  $$pre8 = HEAP32[$4>>2]|0;
  $$0$i1$i5 = $phitmp3$i4;$42 = $$pre8;
 }
 HEAP32[$3>>2] = $$0$i1$i5;
 $41 = (($42) + 212|0);
 $43 = HEAP8[$41>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if ($44) {
  $45 = (($42) + 216|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = $46 > Math_fround(0.0);
  if (!($47)) {
   STACKTOP = sp;return;
  }
 }
 $48 = HEAP32[$5>>2]|0;
 $49 = (($42) + 152|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 << 4;
 $52 = ($51|0)==(0);
 if ($52) {
  $$0$i$i = 0;$66 = $42;$71 = $48;
 } else {
  $53 = (($48) + 8|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = $54;
  $56 = (($55) + 23)|0;
  $57 = $56 & -16;
  $58 = $57;
  $59 = (($58) + ($51)|0);
  $60 = (($58) + -8|0);
  $61 = (($48) + 12|0);
  $62 = HEAP32[$61>>2]|0;
  HEAP32[$60>>2] = $62;
  $63 = (($58) + -4|0);
  $64 = $51 & 2147483632;
  HEAP32[$63>>2] = $64;
  HEAP32[$61>>2] = $60;
  HEAP32[$53>>2] = $59;
  $phitmp$i = $57;
  $$pre9 = HEAP32[$5>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $$0$i$i = $phitmp$i;$66 = $$pre10;$71 = $$pre9;
 }
 HEAP32[$0>>2] = $$0$i$i;
 $65 = (($66) + 160|0);
 $67 = HEAP32[$65>>2]|0;
 $68 = ($67*48)|0;
 $69 = ($68|0)==(0);
 if ($69) {
  $83 = 0;
 } else {
  $70 = (($71) + 8|0);
  $72 = HEAP32[$70>>2]|0;
  $73 = $72;
  $74 = (($73) + 23)|0;
  $75 = $74 & -16;
  $76 = $75;
  $77 = (($76) + ($68)|0);
  $78 = (($76) + -8|0);
  $79 = (($71) + 12|0);
  $80 = HEAP32[$79>>2]|0;
  HEAP32[$78>>2] = $80;
  $81 = (($76) + -4|0);
  $82 = $68 & 2147483632;
  HEAP32[$81>>2] = $82;
  HEAP32[$79>>2] = $78;
  HEAP32[$70>>2] = $77;
  $phitmp3$i = $75;
  $83 = $phitmp3$i;
 }
 HEAP32[$1>>2] = $83;
 $84 = HEAP32[$7>>2]|0;
 $85 = ($84|0)==(0);
 if ($85) {
  $$pre11 = HEAP32[$0>>2]|0;
  $107 = $$pre11;
 } else {
  $86 = (($clothData) + 144|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = HEAP32[$0>>2]|0;
  $$011$i = $88;$$02$i = $84;$sIt$03$i = $87;
  while(1) {
   $89 = (($$02$i) + -1)|0;
   $90 = HEAP32[$sIt$03$i>>2]|0;
   HEAP32[$$011$i>>2] = $90;
   $91 = (($sIt$03$i) + 4|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($$011$i) + 4|0);
   HEAP32[$93>>2] = $92;
   $94 = (($sIt$03$i) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($$011$i) + 8|0);
   HEAP32[$96>>2] = $95;
   $97 = (($sIt$03$i) + 12|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($$011$i) + 12|0);
   HEAP32[$99>>2] = $98;
   $100 = (($sIt$03$i) + 16|0);
   $101 = (($$011$i) + 16|0);
   $102 = ($89|0)==(0);
   if ($102) {
    $107 = $88;
    break;
   } else {
    $$011$i = $101;$$02$i = $89;$sIt$03$i = $100;
   }
  }
 }
 $103 = (($clothData) + 156|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($clothData) + 160|0);
 $106 = HEAP32[$105>>2]|0;
 __ZN12_GLOBAL__N_113generateConesEPN5physx5cloth8ConeDataEPKNS1_10SphereDataEPKNS1_9IndexPairEj($83,$107,$104,$106);
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_113generateConesEPN5physx5cloth8ConeDataEPKNS1_10SphereDataEPKNS1_9IndexPairEj($dst,$sourceSpheres,$capsuleIndices,$numCones) {
 $dst = $dst|0;
 $sourceSpheres = $sourceSpheres|0;
 $capsuleIndices = $capsuleIndices|0;
 $numCones = $numCones|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = Math_fround(0), $9 = 0, $cIt$015 = 0, $iIt$014 = 0, $invAxisLength$0 = Math_fround(0), $invConeLength$0 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($capsuleIndices) + ($numCones<<3)|0);
 $1 = ($numCones|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $cIt$015 = $dst;$iIt$014 = $capsuleIndices;
 }
 while(1) {
  $2 = HEAP32[$iIt$014>>2]|0;
  $3 = (($sourceSpheres) + ($2<<4)|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = ((($sourceSpheres) + ($2<<4)|0) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = ((($sourceSpheres) + ($2<<4)|0) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = ((($sourceSpheres) + ($2<<4)|0) + 12|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($iIt$014) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($sourceSpheres) + ($12<<4)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = ((($sourceSpheres) + ($12<<4)|0) + 4|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = ((($sourceSpheres) + ($12<<4)|0) + 8|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = ((($sourceSpheres) + ($12<<4)|0) + 12|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($4 + $14);
  $22 = Math_fround($6 + $16);
  $23 = Math_fround($8 + $18);
  $24 = Math_fround($21 * Math_fround(0.5));
  $25 = Math_fround($22 * Math_fround(0.5));
  $26 = Math_fround($23 * Math_fround(0.5));
  $27 = Math_fround($14 - $4);
  $28 = Math_fround($16 - $6);
  $29 = Math_fround($18 - $8);
  $30 = Math_fround($20 - $10);
  $31 = Math_fround($27 * Math_fround(0.5));
  $32 = Math_fround($28 * Math_fround(0.5));
  $33 = Math_fround($29 * Math_fround(0.5));
  $34 = Math_fround($30 * Math_fround(0.5));
  $35 = Math_fround($31 * $31);
  $36 = Math_fround($32 * $32);
  $37 = Math_fround($35 + $36);
  $38 = Math_fround($33 * $33);
  $39 = Math_fround($37 + $38);
  $40 = Math_fround($34 * $34);
  $41 = Math_fround($39 - $40);
  $42 = (Math_fround(Math_sqrt((Math_fround($39)))));
  $43 = Math_fround(Math_fround(1.0) / $42);
  $44 = (Math_fround(Math_sqrt((Math_fround($41)))));
  $45 = Math_fround(Math_fround(1.0) / $44);
  $46 = !($41 <= Math_fround(0.0));
  $invConeLength$0 = $46 ? $45 : Math_fround(0.0);
  $invAxisLength$0 = $46 ? $43 : Math_fround(0.0);
  $47 = Math_fround($39 * $invAxisLength$0);
  $48 = Math_fround($34 * $invConeLength$0);
  HEAPF32[$cIt$015>>2] = $24;
  $49 = (($cIt$015) + 4|0);
  HEAPF32[$49>>2] = $25;
  $50 = (($cIt$015) + 8|0);
  HEAPF32[$50>>2] = $26;
  $51 = Math_fround($10 + $34);
  $52 = Math_fround($51 * $invConeLength$0);
  $53 = Math_fround($52 * $47);
  $54 = (($cIt$015) + 12|0);
  HEAPF32[$54>>2] = $53;
  $55 = Math_fround($31 * $invAxisLength$0);
  $56 = Math_fround($32 * $invAxisLength$0);
  $57 = Math_fround($33 * $invAxisLength$0);
  $58 = (($cIt$015) + 16|0);
  HEAPF32[$58>>2] = $55;
  $59 = (($cIt$015) + 20|0);
  HEAPF32[$59>>2] = $56;
  $60 = (($cIt$015) + 24|0);
  HEAPF32[$60>>2] = $57;
  $61 = (($cIt$015) + 28|0);
  HEAPF32[$61>>2] = $48;
  $62 = Math_fround($34 * $invAxisLength$0);
  $63 = Math_fround($62 * $62);
  $64 = Math_fround(Math_fround(1.0) - $63);
  $65 = (($cIt$015) + 32|0);
  HEAPF32[$65>>2] = $64;
  $66 = (($cIt$015) + 36|0);
  HEAPF32[$66>>2] = $47;
  $67 = 1 << $2;
  $68 = (($cIt$015) + 40|0);
  HEAP32[$68>>2] = $67;
  $69 = HEAP32[$11>>2]|0;
  $70 = 1 << $69;
  $71 = $70 | $67;
  $72 = (($cIt$015) + 44|0);
  HEAP32[$72>>2] = $71;
  $73 = (($iIt$014) + 8|0);
  $74 = (($cIt$015) + 48|0);
  $75 = ($73|0)==($0|0);
  if ($75) {
   break;
  } else {
   $cIt$015 = $74;$iIt$014 = $73;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx5cloth11SwCollisionI8Scalar4fED2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 436|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 424|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 L1: do {
  if (!($4)) {
   $5 = (($3) + -4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = $6 | -2147483648;
   HEAP32[$5>>2] = $7;
   $8 = (($1) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($1) + 8|0);
    $13 = $9;
    while(1) {
     $12 = (($13) + 4|0);
     $14 = HEAP32[$12>>2]|0;
     $15 = ($14|0)<(0);
     if (!($15)) {
      break L1;
     }
     HEAP32[$11>>2] = $13;
     $16 = HEAP32[$13>>2]|0;
     HEAP32[$8>>2] = $16;
     $17 = ($16|0)==(0|0);
     if ($17) {
      break;
     } else {
      $13 = $16;
     }
    }
   }
  }
 } while(0);
 $18 = HEAP32[$0>>2]|0;
 $19 = (($this) + 428|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 L8: do {
  if (!($21)) {
   $22 = (($20) + -4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23 | -2147483648;
   HEAP32[$22>>2] = $24;
   $25 = (($18) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = (($18) + 8|0);
    $30 = $26;
    while(1) {
     $29 = (($30) + 4|0);
     $31 = HEAP32[$29>>2]|0;
     $32 = ($31|0)<(0);
     if (!($32)) {
      break L8;
     }
     HEAP32[$28>>2] = $30;
     $33 = HEAP32[$30>>2]|0;
     HEAP32[$25>>2] = $33;
     $34 = ($33|0)==(0|0);
     if ($34) {
      break;
     } else {
      $30 = $33;
     }
    }
   }
  }
 } while(0);
 $35 = HEAP32[$0>>2]|0;
 $36 = (($this) + 416|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 L15: do {
  if (!($38)) {
   $39 = (($37) + -4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $40 | -2147483648;
   HEAP32[$39>>2] = $41;
   $42 = (($35) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if (!($44)) {
    $45 = (($35) + 8|0);
    $47 = $43;
    while(1) {
     $46 = (($47) + 4|0);
     $48 = HEAP32[$46>>2]|0;
     $49 = ($48|0)<(0);
     if (!($49)) {
      break L15;
     }
     HEAP32[$45>>2] = $47;
     $50 = HEAP32[$47>>2]|0;
     HEAP32[$42>>2] = $50;
     $51 = ($50|0)==(0|0);
     if ($51) {
      break;
     } else {
      $47 = $50;
     }
    }
   }
  }
 } while(0);
 $52 = HEAP32[$0>>2]|0;
 $53 = (($this) + 420|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0|0);
 if ($55) {
  STACKTOP = sp;return;
 }
 $56 = (($54) + -4|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $57 | -2147483648;
 HEAP32[$56>>2] = $58;
 $59 = (($52) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0|0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $62 = (($52) + 8|0);
 $64 = $60;
 while(1) {
  $63 = (($64) + 4|0);
  $65 = HEAP32[$63>>2]|0;
  $66 = ($65|0)<(0);
  if (!($66)) {
   label = 21;
   break;
  }
  HEAP32[$62>>2] = $64;
  $67 = HEAP32[$64>>2]|0;
  HEAP32[$59>>2] = $67;
  $68 = ($67|0)==(0|0);
  if ($68) {
   label = 21;
   break;
  } else {
   $64 = $67;
  }
 }
 if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fEclERKNS0_14IterationStateIS2_EE($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $$011$i = 0, $$012$i = 0, $$02$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $sIt$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 440|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx5cloth11SwCollisionI8Scalar4fE15collideConvexesERKNS0_14IterationStateIS2_EE($this,$state);
 __ZN5physx5cloth11SwCollisionI8Scalar4fE16collideTrianglesERKNS0_14IterationStateIS2_EE($this,$state);
 __ZN5physx5cloth11SwCollisionI8Scalar4fE13computeBoundsEv($this);
 $1 = (($this) + 432|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$state>>2]|0;
 $7 = ($6|0)==(1);
 $8 = (($2) + 148|0);
 $9 = HEAP32[$8>>2]|0;
 if ($7) {
  $60 = (($this) + 424|0);
  $61 = HEAP32[$60>>2]|0;
  $$011$i = $61;$$02$i = $4;$sIt$03$i = $9;
  while(1) {
   $62 = (($$02$i) + -1)|0;
   $63 = HEAP32[$sIt$03$i>>2]|0;
   HEAP32[$$011$i>>2] = $63;
   $64 = (($sIt$03$i) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($$011$i) + 4|0);
   HEAP32[$66>>2] = $65;
   $67 = (($sIt$03$i) + 8|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (($$011$i) + 8|0);
   HEAP32[$69>>2] = $68;
   $70 = (($sIt$03$i) + 12|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($$011$i) + 12|0);
   HEAP32[$72>>2] = $71;
   $73 = (($sIt$03$i) + 16|0);
   $74 = (($$011$i) + 16|0);
   $75 = ($62|0)==(0);
   if ($75) {
    $84 = $61;
    break;
   } else {
    $$011$i = $74;$$02$i = $62;$sIt$03$i = $73;
   }
  }
 } else {
  $10 = (($2) + 144|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (Math_fround(($6>>>0)));
  $13 = (($state) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($12 * $14);
  $16 = Math_fround(Math_fround(1.0) - $15);
  $17 = Math_fround($14 + $16);
  $18 = (($this) + 424|0);
  $19 = HEAP32[$18>>2]|0;
  $$012$i = $19;$$03$i = $4;$22 = $9;$24 = $11;
  while(1) {
   $20 = (($$03$i) + -1)|0;
   $21 = Math_fround(HEAPF32[$22>>2]);
   $23 = Math_fround(HEAPF32[$24>>2]);
   $25 = Math_fround($21 - $23);
   $26 = (($22) + 4|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = (($24) + 4|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($27 - $29);
   $31 = (($22) + 8|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = (($24) + 8|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = Math_fround($32 - $34);
   $36 = (($22) + 12|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = (($24) + 12|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = Math_fround($37 - $39);
   $41 = Math_fround($17 * $25);
   $42 = Math_fround($17 * $30);
   $43 = Math_fround($17 * $35);
   $44 = Math_fround($17 * $40);
   $45 = Math_fround($23 + $41);
   $46 = Math_fround($29 + $42);
   $47 = Math_fround($34 + $43);
   $48 = Math_fround($39 + $44);
   $49 = (HEAPF32[tempDoublePtr>>2]=$45,HEAP32[tempDoublePtr>>2]|0);
   $50 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
   $51 = (HEAPF32[tempDoublePtr>>2]=$47,HEAP32[tempDoublePtr>>2]|0);
   $52 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$012$i>>2] = $49;
   $53 = (($$012$i) + 4|0);
   HEAP32[$53>>2] = $50;
   $54 = (($$012$i) + 8|0);
   HEAP32[$54>>2] = $51;
   $55 = (($$012$i) + 12|0);
   HEAP32[$55>>2] = $52;
   $56 = (($24) + 16|0);
   $57 = (($22) + 16|0);
   $58 = (($$012$i) + 16|0);
   $59 = ($20|0)==(0);
   if ($59) {
    $84 = $19;
    break;
   } else {
    $$012$i = $58;$$03$i = $20;$22 = $57;$24 = $56;
   }
  }
 }
 $76 = (($this) + 424|0);
 $77 = (($this) + 428|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = HEAP32[$1>>2]|0;
 $80 = (($79) + 156|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($79) + 160|0);
 $83 = HEAP32[$82>>2]|0;
 __ZN12_GLOBAL__N_113generateConesEPN5physx5cloth8ConeDataEPKNS1_10SphereDataEPKNS1_9IndexPairEj($78,$84,$81,$83);
 $85 = (__ZN5physx5cloth11SwCollisionI8Scalar4fE17buildAccelerationEv($this)|0);
 if ($85) {
  $86 = HEAP32[$1>>2]|0;
  $87 = (($86) + 212|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = ($88<<24>>24)==(0);
  if (!($89)) {
   __ZN5physx5cloth11SwCollisionI8Scalar4fE26collideContinuousParticlesEv($this);
  }
  __ZN5physx5cloth11SwCollisionI8Scalar4fE17mergeAccelerationEPj($this);
  $90 = (($this) + 192|0);
  __ZN5physx5cloth11SwCollisionI8Scalar4fE17mergeAccelerationEPj($90);
  $91 = HEAP32[$1>>2]|0;
  $92 = (($91) + 212|0);
  $93 = HEAP8[$92>>0]|0;
  $94 = ($93<<24>>24)==(0);
  if ($94) {
   __ZN5physx5cloth11SwCollisionI8Scalar4fE16collideParticlesEv($this);
  }
  __ZN5physx5cloth11SwCollisionI8Scalar4fE23collideVirtualParticlesEv($this);
 }
 $95 = (($this) + 416|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96|0)==(0|0);
 if ($97) {
  STACKTOP = sp;return;
 }
 $98 = $76;
 $99 = $98;
 $100 = HEAP32[$99>>2]|0;
 $101 = (($98) + 4)|0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = $95;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = (($104) + 4)|0;
 $108 = $107;
 $109 = HEAP32[$108>>2]|0;
 $110 = $76;
 $111 = $110;
 HEAP32[$111>>2] = $106;
 $112 = (($110) + 4)|0;
 $113 = $112;
 HEAP32[$113>>2] = $109;
 $114 = $95;
 $115 = $114;
 HEAP32[$115>>2] = $100;
 $116 = (($114) + 4)|0;
 $117 = $116;
 HEAP32[$117>>2] = $103;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE15collideConvexesERKNS0_14IterationStateIS2_EE($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $$$i = 0, $$$i$us = 0, $$0$i = 0, $$011$i = 0, $$012$i = 0, $$02$i = 0, $$03$i = 0, $$pre = 0, $$pre115 = Math_fround(0), $$pre116 = Math_fround(0), $$pre117 = Math_fround(0), $$pre118 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0;
 var $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0);
 var $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0;
 var $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0);
 var $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0);
 var $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0);
 var $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0);
 var $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = 0, $425 = 0, $426 = 0, $427 = Math_fround(0), $428 = 0, $429 = Math_fround(0);
 var $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0), $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0);
 var $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = 0, $482 = Math_fround(0), $483 = Math_fround(0);
 var $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0);
 var $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0;
 var $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0);
 var $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = 0, $554 = Math_fround(0), $555 = Math_fround(0);
 var $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0);
 var $99 = 0, $accum = 0, $brmerge$i = 0, $brmerge$i$us = 0, $brmerge1$i = 0, $brmerge1$i$us = 0, $curIt$0109 = 0, $curIt$0109$us = 0, $curPos = 0, $frictionImpulse = 0, $frictionScale = 0, $invNumCollisions = 0, $mask = 0, $not$w$i$i$i = 0, $not$w$i$i$i$us = 0, $not$x$i$i$i = 0, $not$x$i$i$i$us = 0, $not$y$i$i$i = 0, $not$y$i$i$i$us = 0, $not$z$i$i$i = 0;
 var $not$z$i$i$i$us = 0, $prevIt$0111$us = 0, $prevPos = 0, $sIt$03$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $curPos = sp + 272|0;
 $prevPos = sp;
 $frictionScale = sp + 64|0;
 $accum = sp + 80|0;
 $mask = sp + 192|0;
 $invNumCollisions = sp + 208|0;
 $frictionImpulse = sp + 224|0;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 180|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 436|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + 172|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 5;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0$i = 0;$24 = $1;
 } else {
  $11 = (($6) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12;
  $14 = (($13) + 23)|0;
  $15 = $14 & -16;
  $16 = $15;
  $17 = (($16) + ($9)|0);
  $18 = (($16) + -8|0);
  $19 = (($6) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$18>>2] = $20;
  $21 = (($16) + -4|0);
  $22 = $9 & 2147483616;
  HEAP32[$21>>2] = $22;
  HEAP32[$19>>2] = $18;
  HEAP32[$11>>2] = $17;
  $$pre = HEAP32[$0>>2]|0;
  $$0$i = $16;$24 = $$pre;
 }
 $23 = (($24) + 168|0);
 $25 = HEAP32[$23>>2]|0;
 $26 = HEAP32[$state>>2]|0;
 $27 = ($26|0)==(1);
 if ($27) {
  $79 = (($24) + 172|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==(0);
  if (!($81)) {
   $$011$i = $$0$i;$$02$i = $80;$sIt$03$i = $25;
   while(1) {
    $82 = (($$02$i) + -1)|0;
    $83 = HEAP32[$sIt$03$i>>2]|0;
    HEAP32[$$011$i>>2] = $83;
    $84 = (($sIt$03$i) + 4|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($$011$i) + 4|0);
    HEAP32[$86>>2] = $85;
    $87 = (($sIt$03$i) + 8|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = (($$011$i) + 8|0);
    HEAP32[$89>>2] = $88;
    $90 = (($sIt$03$i) + 12|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($$011$i) + 12|0);
    HEAP32[$92>>2] = $91;
    $93 = (($sIt$03$i) + 16|0);
    $94 = (($$011$i) + 16|0);
    $95 = ($82|0)==(0);
    if ($95) {
     break;
    } else {
     $$011$i = $94;$$02$i = $82;$sIt$03$i = $93;
    }
   }
  }
 } else {
  $28 = (($state) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($24) + 172|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0);
  if (!($32)) {
   $33 = (Math_fround(($26>>>0)));
   $34 = Math_fround($33 * $29);
   $35 = (($24) + 164|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = Math_fround(Math_fround(1.0) - $34);
   $38 = Math_fround($29 + $37);
   $$012$i = $$0$i;$$03$i = $31;$41 = $25;$43 = $36;
   while(1) {
    $39 = (($$03$i) + -1)|0;
    $40 = Math_fround(HEAPF32[$41>>2]);
    $42 = Math_fround(HEAPF32[$43>>2]);
    $44 = Math_fround($40 - $42);
    $45 = (($41) + 4|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = (($43) + 4|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = Math_fround($46 - $48);
    $50 = (($41) + 8|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = (($43) + 8|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = Math_fround($51 - $53);
    $55 = (($41) + 12|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = (($43) + 12|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($56 - $58);
    $60 = Math_fround($38 * $44);
    $61 = Math_fround($38 * $49);
    $62 = Math_fround($38 * $54);
    $63 = Math_fround($38 * $59);
    $64 = Math_fround($42 + $60);
    $65 = Math_fround($48 + $61);
    $66 = Math_fround($53 + $62);
    $67 = Math_fround($58 + $63);
    $68 = (HEAPF32[tempDoublePtr>>2]=$64,HEAP32[tempDoublePtr>>2]|0);
    $69 = (HEAPF32[tempDoublePtr>>2]=$65,HEAP32[tempDoublePtr>>2]|0);
    $70 = (HEAPF32[tempDoublePtr>>2]=$66,HEAP32[tempDoublePtr>>2]|0);
    $71 = (HEAPF32[tempDoublePtr>>2]=$67,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$$012$i>>2] = $68;
    $72 = (($$012$i) + 4|0);
    HEAP32[$72>>2] = $69;
    $73 = (($$012$i) + 8|0);
    HEAP32[$73>>2] = $70;
    $74 = (($$012$i) + 12|0);
    HEAP32[$74>>2] = $71;
    $75 = (($43) + 16|0);
    $76 = (($41) + 16|0);
    $77 = (($$012$i) + 16|0);
    $78 = ($39|0)==(0);
    if ($78) {
     break;
    } else {
     $$012$i = $77;$$03$i = $39;$41 = $76;$43 = $75;
    }
   }
  }
 }
 $96 = HEAP32[$0>>2]|0;
 $97 = (($96) + 216|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 HEAPF32[$frictionScale>>2] = $98;
 $99 = (($frictionScale) + 4|0);
 HEAPF32[$99>>2] = $98;
 $100 = (($frictionScale) + 8|0);
 HEAPF32[$100>>2] = $98;
 $101 = (($frictionScale) + 12|0);
 HEAPF32[$101>>2] = $98;
 $102 = (($96) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = HEAP32[$96>>2]|0;
 $105 = $104 << 2;
 $106 = (($103) + ($105<<2)|0);
 $107 = ($105|0)>(0);
 L17: do {
  if ($107) {
   $108 = (($96) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = $98 > Math_fround(0.0);
   $111 = (($curPos) + 4|0);
   $112 = (($curPos) + 8|0);
   $113 = (($curPos) + 12|0);
   $114 = (($curPos) + 16|0);
   $115 = (($curPos) + 20|0);
   $116 = (($curPos) + 24|0);
   $117 = (($curPos) + 28|0);
   $118 = (($curPos) + 32|0);
   $119 = (($curPos) + 36|0);
   $120 = (($curPos) + 40|0);
   $121 = (($curPos) + 44|0);
   $122 = (($curPos) + 52|0);
   $123 = (($curPos) + 56|0);
   $124 = (($curPos) + 60|0);
   $125 = (($curPos) + 48|0);
   $126 = (($accum) + 96|0);
   $127 = (($accum) + 100|0);
   $128 = (($accum) + 104|0);
   $129 = (($accum) + 108|0);
   $130 = (($mask) + 4|0);
   $131 = (($mask) + 8|0);
   $132 = (($mask) + 12|0);
   $133 = (($invNumCollisions) + 4|0);
   $134 = (($invNumCollisions) + 8|0);
   $135 = (($invNumCollisions) + 12|0);
   $136 = (($prevPos) + 4|0);
   $137 = (($prevPos) + 8|0);
   $138 = (($prevPos) + 12|0);
   $139 = (($prevPos) + 16|0);
   $140 = (($prevPos) + 20|0);
   $141 = (($prevPos) + 24|0);
   $142 = (($prevPos) + 28|0);
   $143 = (($prevPos) + 32|0);
   $144 = (($prevPos) + 36|0);
   $145 = (($prevPos) + 40|0);
   $146 = (($prevPos) + 44|0);
   $147 = (($prevPos) + 52|0);
   $148 = (($prevPos) + 56|0);
   $149 = (($prevPos) + 60|0);
   $150 = (($prevPos) + 48|0);
   $151 = (($accum) + 16|0);
   $152 = (($accum) + 32|0);
   $153 = (($accum) + 48|0);
   $154 = (($accum) + 64|0);
   $155 = (($accum) + 80|0);
   $156 = (($frictionImpulse) + 4|0);
   $157 = (($frictionImpulse) + 8|0);
   $158 = (($frictionImpulse) + 12|0);
   $159 = (($frictionImpulse) + 16|0);
   $160 = (($frictionImpulse) + 20|0);
   $161 = (($frictionImpulse) + 24|0);
   $162 = (($frictionImpulse) + 28|0);
   $163 = (($frictionImpulse) + 32|0);
   $164 = (($frictionImpulse) + 36|0);
   $165 = (($frictionImpulse) + 40|0);
   $166 = (($frictionImpulse) + 44|0);
   $167 = (($accum) + 4|0);
   $168 = (($accum) + 8|0);
   $169 = (($accum) + 12|0);
   $170 = (($accum) + 16|0);
   $171 = (($accum) + 20|0);
   $172 = (($accum) + 24|0);
   $173 = (($accum) + 28|0);
   $174 = (($accum) + 32|0);
   $175 = (($accum) + 36|0);
   $176 = (($accum) + 40|0);
   $177 = (($accum) + 44|0);
   if ($110) {
    $curIt$0109$us = $103;$prevIt$0111$us = $109;
   } else {
    $curIt$0109 = $103;
    while(1) {
     $427 = Math_fround(HEAPF32[$curIt$0109>>2]);
     $428 = (($curIt$0109) + 4|0);
     $429 = Math_fround(HEAPF32[$428>>2]);
     $430 = (($curIt$0109) + 8|0);
     $431 = Math_fround(HEAPF32[$430>>2]);
     $432 = (($curIt$0109) + 12|0);
     $433 = Math_fround(HEAPF32[$432>>2]);
     $434 = (HEAPF32[tempDoublePtr>>2]=$427,HEAP32[tempDoublePtr>>2]|0);
     $435 = (HEAPF32[tempDoublePtr>>2]=$429,HEAP32[tempDoublePtr>>2]|0);
     $436 = (HEAPF32[tempDoublePtr>>2]=$431,HEAP32[tempDoublePtr>>2]|0);
     $437 = (HEAPF32[tempDoublePtr>>2]=$433,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$curPos>>2] = $434;
     HEAP32[$111>>2] = $435;
     HEAP32[$112>>2] = $436;
     HEAP32[$113>>2] = $437;
     $438 = (($curIt$0109) + 16|0);
     $439 = Math_fround(HEAPF32[$438>>2]);
     $440 = (($curIt$0109) + 20|0);
     $441 = Math_fround(HEAPF32[$440>>2]);
     $442 = (($curIt$0109) + 24|0);
     $443 = Math_fround(HEAPF32[$442>>2]);
     $444 = (($curIt$0109) + 28|0);
     $445 = Math_fround(HEAPF32[$444>>2]);
     $446 = (HEAPF32[tempDoublePtr>>2]=$439,HEAP32[tempDoublePtr>>2]|0);
     $447 = (HEAPF32[tempDoublePtr>>2]=$441,HEAP32[tempDoublePtr>>2]|0);
     $448 = (HEAPF32[tempDoublePtr>>2]=$443,HEAP32[tempDoublePtr>>2]|0);
     $449 = (HEAPF32[tempDoublePtr>>2]=$445,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$114>>2] = $446;
     HEAP32[$115>>2] = $447;
     HEAP32[$116>>2] = $448;
     HEAP32[$117>>2] = $449;
     $450 = (($curIt$0109) + 32|0);
     $451 = Math_fround(HEAPF32[$450>>2]);
     $452 = (($curIt$0109) + 36|0);
     $453 = Math_fround(HEAPF32[$452>>2]);
     $454 = (($curIt$0109) + 40|0);
     $455 = Math_fround(HEAPF32[$454>>2]);
     $456 = (($curIt$0109) + 44|0);
     $457 = Math_fround(HEAPF32[$456>>2]);
     $458 = (HEAPF32[tempDoublePtr>>2]=$451,HEAP32[tempDoublePtr>>2]|0);
     $459 = (HEAPF32[tempDoublePtr>>2]=$453,HEAP32[tempDoublePtr>>2]|0);
     $460 = (HEAPF32[tempDoublePtr>>2]=$455,HEAP32[tempDoublePtr>>2]|0);
     $461 = (HEAPF32[tempDoublePtr>>2]=$457,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$118>>2] = $458;
     HEAP32[$119>>2] = $459;
     HEAP32[$120>>2] = $460;
     HEAP32[$121>>2] = $461;
     $462 = (($curIt$0109) + 48|0);
     $463 = Math_fround(HEAPF32[$462>>2]);
     $464 = (($curIt$0109) + 52|0);
     $465 = Math_fround(HEAPF32[$464>>2]);
     $466 = (($curIt$0109) + 56|0);
     $467 = Math_fround(HEAPF32[$466>>2]);
     $468 = (($curIt$0109) + 60|0);
     $469 = Math_fround(HEAPF32[$468>>2]);
     $470 = (HEAPF32[tempDoublePtr>>2]=$469,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$124>>2] = $470;
     HEAPF32[$111>>2] = $439;
     HEAPF32[$112>>2] = $451;
     HEAPF32[$113>>2] = $463;
     HEAPF32[$114>>2] = $429;
     HEAPF32[$116>>2] = $453;
     HEAPF32[$117>>2] = $465;
     HEAPF32[$118>>2] = $431;
     HEAPF32[$119>>2] = $443;
     HEAPF32[$121>>2] = $467;
     HEAPF32[$125>>2] = $433;
     HEAPF32[$122>>2] = $445;
     HEAPF32[$123>>2] = $457;
     dest=$accum+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     $471 = HEAP32[478152>>2]|0;
     HEAP32[$126>>2] = $471;
     $472 = HEAP32[((478152 + 4|0))>>2]|0;
     HEAP32[$127>>2] = $472;
     $473 = HEAP32[((478152 + 8|0))>>2]|0;
     HEAP32[$128>>2] = $473;
     $474 = HEAP32[((478152 + 12|0))>>2]|0;
     HEAP32[$129>>2] = $474;
     __ZN5physx5cloth11SwCollisionI8Scalar4fE15collideConvexesEPKS2_PS2_RNS3_18ImpulseAccumulatorE($this,$$0$i,$curPos,$accum);
     $475 = HEAP32[478152>>2]|0;
     $476 = HEAP32[((478152 + 4|0))>>2]|0;
     $477 = HEAP32[((478152 + 8|0))>>2]|0;
     $478 = HEAP32[((478152 + 12|0))>>2]|0;
     $479 = Math_fround(HEAPF32[$126>>2]);
     $480 = (HEAP32[tempDoublePtr>>2]=$475,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $481 = $479 > $480;
     $482 = Math_fround(HEAPF32[$127>>2]);
     $483 = (HEAP32[tempDoublePtr>>2]=$476,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $484 = $482 > $483;
     $485 = Math_fround(HEAPF32[$128>>2]);
     $486 = (HEAP32[tempDoublePtr>>2]=$477,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $487 = $485 > $486;
     $488 = Math_fround(HEAPF32[$129>>2]);
     $489 = (HEAP32[tempDoublePtr>>2]=$478,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $490 = $488 > $489;
     $not$x$i$i$i = $481 ^ 1;
     $491 = $not$x$i$i$i << 31 >> 31;
     $492 = $491 ^ -1;
     $not$y$i$i$i = $484 ^ 1;
     $493 = $not$y$i$i$i << 31 >> 31;
     $494 = $493 ^ -1;
     $not$z$i$i$i = $487 ^ 1;
     $495 = $not$z$i$i$i << 31 >> 31;
     $496 = $495 ^ -1;
     $not$w$i$i$i = $490 ^ 1;
     $497 = $not$w$i$i$i << 31 >> 31;
     $498 = $497 ^ -1;
     HEAP32[$mask>>2] = $492;
     HEAP32[$130>>2] = $494;
     HEAP32[$131>>2] = $496;
     HEAP32[$132>>2] = $498;
     $brmerge$i = $481 | $484;
     $brmerge1$i = $brmerge$i | $487;
     $$$i = $brmerge1$i | $490;
     if ($$$i) {
      $499 = Math_fround(Math_fround(1.0) / $479);
      $500 = Math_fround(Math_fround(1.0) / $482);
      $501 = Math_fround(Math_fround(1.0) / $485);
      $502 = Math_fround(Math_fround(1.0) / $488);
      HEAPF32[$invNumCollisions>>2] = $499;
      HEAPF32[$133>>2] = $500;
      HEAPF32[$134>>2] = $501;
      HEAPF32[$135>>2] = $502;
      $503 = Math_fround(HEAPF32[$accum>>2]);
      $504 = Math_fround($503 * $499);
      $505 = Math_fround(HEAPF32[$167>>2]);
      $506 = Math_fround($505 * $500);
      $507 = Math_fround(HEAPF32[$168>>2]);
      $508 = Math_fround($507 * $501);
      $509 = Math_fround(HEAPF32[$169>>2]);
      $510 = Math_fround($509 * $502);
      $511 = Math_fround(HEAPF32[$curPos>>2]);
      $512 = Math_fround($504 + $511);
      $513 = Math_fround(HEAPF32[$111>>2]);
      $514 = Math_fround($506 + $513);
      $515 = Math_fround(HEAPF32[$112>>2]);
      $516 = Math_fround($508 + $515);
      $517 = Math_fround(HEAPF32[$113>>2]);
      $518 = Math_fround($510 + $517);
      $519 = (HEAPF32[tempDoublePtr>>2]=$512,HEAP32[tempDoublePtr>>2]|0);
      HEAP32[$curPos>>2] = $519;
      $520 = Math_fround(HEAPF32[$170>>2]);
      $521 = Math_fround($520 * $499);
      $522 = Math_fround(HEAPF32[$171>>2]);
      $523 = Math_fround($522 * $500);
      $524 = Math_fround(HEAPF32[$172>>2]);
      $525 = Math_fround($524 * $501);
      $526 = Math_fround(HEAPF32[$173>>2]);
      $527 = Math_fround($526 * $502);
      $528 = Math_fround(HEAPF32[$114>>2]);
      $529 = Math_fround($521 + $528);
      $530 = Math_fround(HEAPF32[$115>>2]);
      $531 = Math_fround($523 + $530);
      $532 = Math_fround(HEAPF32[$116>>2]);
      $533 = Math_fround($525 + $532);
      $534 = Math_fround(HEAPF32[$117>>2]);
      $535 = Math_fround($527 + $534);
      $536 = (HEAPF32[tempDoublePtr>>2]=$531,HEAP32[tempDoublePtr>>2]|0);
      HEAP32[$115>>2] = $536;
      $537 = Math_fround(HEAPF32[$174>>2]);
      $538 = Math_fround($537 * $499);
      $539 = Math_fround(HEAPF32[$175>>2]);
      $540 = Math_fround($539 * $500);
      $541 = Math_fround(HEAPF32[$176>>2]);
      $542 = Math_fround($541 * $501);
      $543 = Math_fround(HEAPF32[$177>>2]);
      $544 = Math_fround($543 * $502);
      $545 = Math_fround(HEAPF32[$118>>2]);
      $546 = Math_fround($538 + $545);
      $547 = Math_fround(HEAPF32[$119>>2]);
      $548 = Math_fround($540 + $547);
      $549 = Math_fround(HEAPF32[$120>>2]);
      $550 = Math_fround($542 + $549);
      $551 = Math_fround(HEAPF32[$121>>2]);
      $552 = Math_fround($544 + $551);
      $553 = (HEAPF32[tempDoublePtr>>2]=$550,HEAP32[tempDoublePtr>>2]|0);
      HEAP32[$120>>2] = $553;
      HEAPF32[$111>>2] = $529;
      HEAPF32[$112>>2] = $546;
      $554 = Math_fround(HEAPF32[$125>>2]);
      HEAPF32[$113>>2] = $554;
      HEAPF32[$114>>2] = $514;
      HEAPF32[$116>>2] = $548;
      $555 = Math_fround(HEAPF32[$122>>2]);
      HEAPF32[$117>>2] = $555;
      HEAPF32[$118>>2] = $516;
      HEAPF32[$119>>2] = $533;
      $556 = Math_fround(HEAPF32[$123>>2]);
      HEAPF32[$121>>2] = $556;
      HEAPF32[$125>>2] = $518;
      HEAPF32[$122>>2] = $535;
      HEAPF32[$123>>2] = $552;
      HEAPF32[$curIt$0109>>2] = $512;
      $557 = Math_fround(HEAPF32[$111>>2]);
      HEAPF32[$428>>2] = $557;
      $558 = Math_fround(HEAPF32[$112>>2]);
      HEAPF32[$430>>2] = $558;
      $559 = Math_fround(HEAPF32[$113>>2]);
      HEAPF32[$432>>2] = $559;
      $560 = Math_fround(HEAPF32[$114>>2]);
      HEAPF32[$438>>2] = $560;
      $561 = Math_fround(HEAPF32[$115>>2]);
      HEAPF32[$440>>2] = $561;
      $562 = Math_fround(HEAPF32[$116>>2]);
      HEAPF32[$442>>2] = $562;
      $563 = Math_fround(HEAPF32[$117>>2]);
      HEAPF32[$444>>2] = $563;
      $564 = Math_fround(HEAPF32[$118>>2]);
      HEAPF32[$450>>2] = $564;
      $565 = Math_fround(HEAPF32[$119>>2]);
      HEAPF32[$452>>2] = $565;
      $566 = Math_fround(HEAPF32[$120>>2]);
      HEAPF32[$454>>2] = $566;
      $567 = Math_fround(HEAPF32[$121>>2]);
      HEAPF32[$456>>2] = $567;
      $568 = Math_fround(HEAPF32[$125>>2]);
      HEAPF32[$462>>2] = $568;
      $569 = Math_fround(HEAPF32[$122>>2]);
      HEAPF32[$464>>2] = $569;
      $570 = Math_fround(HEAPF32[$123>>2]);
      HEAPF32[$466>>2] = $570;
      $571 = Math_fround(HEAPF32[$124>>2]);
      HEAPF32[$468>>2] = $571;
     }
     $572 = (($curIt$0109) + 64|0);
     $573 = ($572>>>0)<($106>>>0);
     if ($573) {
      $curIt$0109 = $572;
     } else {
      break L17;
     }
    }
   }
   while(1) {
    $178 = Math_fround(HEAPF32[$curIt$0109$us>>2]);
    $179 = (($curIt$0109$us) + 4|0);
    $180 = Math_fround(HEAPF32[$179>>2]);
    $181 = (($curIt$0109$us) + 8|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = (($curIt$0109$us) + 12|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    $185 = (HEAPF32[tempDoublePtr>>2]=$178,HEAP32[tempDoublePtr>>2]|0);
    $186 = (HEAPF32[tempDoublePtr>>2]=$180,HEAP32[tempDoublePtr>>2]|0);
    $187 = (HEAPF32[tempDoublePtr>>2]=$182,HEAP32[tempDoublePtr>>2]|0);
    $188 = (HEAPF32[tempDoublePtr>>2]=$184,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$curPos>>2] = $185;
    HEAP32[$111>>2] = $186;
    HEAP32[$112>>2] = $187;
    HEAP32[$113>>2] = $188;
    $189 = (($curIt$0109$us) + 16|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = (($curIt$0109$us) + 20|0);
    $192 = Math_fround(HEAPF32[$191>>2]);
    $193 = (($curIt$0109$us) + 24|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = (($curIt$0109$us) + 28|0);
    $196 = Math_fround(HEAPF32[$195>>2]);
    $197 = (HEAPF32[tempDoublePtr>>2]=$190,HEAP32[tempDoublePtr>>2]|0);
    $198 = (HEAPF32[tempDoublePtr>>2]=$192,HEAP32[tempDoublePtr>>2]|0);
    $199 = (HEAPF32[tempDoublePtr>>2]=$194,HEAP32[tempDoublePtr>>2]|0);
    $200 = (HEAPF32[tempDoublePtr>>2]=$196,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$114>>2] = $197;
    HEAP32[$115>>2] = $198;
    HEAP32[$116>>2] = $199;
    HEAP32[$117>>2] = $200;
    $201 = (($curIt$0109$us) + 32|0);
    $202 = Math_fround(HEAPF32[$201>>2]);
    $203 = (($curIt$0109$us) + 36|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = (($curIt$0109$us) + 40|0);
    $206 = Math_fround(HEAPF32[$205>>2]);
    $207 = (($curIt$0109$us) + 44|0);
    $208 = Math_fround(HEAPF32[$207>>2]);
    $209 = (HEAPF32[tempDoublePtr>>2]=$202,HEAP32[tempDoublePtr>>2]|0);
    $210 = (HEAPF32[tempDoublePtr>>2]=$204,HEAP32[tempDoublePtr>>2]|0);
    $211 = (HEAPF32[tempDoublePtr>>2]=$206,HEAP32[tempDoublePtr>>2]|0);
    $212 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$118>>2] = $209;
    HEAP32[$119>>2] = $210;
    HEAP32[$120>>2] = $211;
    HEAP32[$121>>2] = $212;
    $213 = (($curIt$0109$us) + 48|0);
    $214 = Math_fround(HEAPF32[$213>>2]);
    $215 = (($curIt$0109$us) + 52|0);
    $216 = Math_fround(HEAPF32[$215>>2]);
    $217 = (($curIt$0109$us) + 56|0);
    $218 = Math_fround(HEAPF32[$217>>2]);
    $219 = (($curIt$0109$us) + 60|0);
    $220 = Math_fround(HEAPF32[$219>>2]);
    $221 = (HEAPF32[tempDoublePtr>>2]=$220,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$124>>2] = $221;
    HEAPF32[$111>>2] = $190;
    HEAPF32[$112>>2] = $202;
    HEAPF32[$113>>2] = $214;
    HEAPF32[$114>>2] = $180;
    HEAPF32[$116>>2] = $204;
    HEAPF32[$117>>2] = $216;
    HEAPF32[$118>>2] = $182;
    HEAPF32[$119>>2] = $194;
    HEAPF32[$121>>2] = $218;
    HEAPF32[$125>>2] = $184;
    HEAPF32[$122>>2] = $196;
    HEAPF32[$123>>2] = $208;
    dest=$accum+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $222 = HEAP32[478152>>2]|0;
    HEAP32[$126>>2] = $222;
    $223 = HEAP32[((478152 + 4|0))>>2]|0;
    HEAP32[$127>>2] = $223;
    $224 = HEAP32[((478152 + 8|0))>>2]|0;
    HEAP32[$128>>2] = $224;
    $225 = HEAP32[((478152 + 12|0))>>2]|0;
    HEAP32[$129>>2] = $225;
    __ZN5physx5cloth11SwCollisionI8Scalar4fE15collideConvexesEPKS2_PS2_RNS3_18ImpulseAccumulatorE($this,$$0$i,$curPos,$accum);
    $226 = HEAP32[478152>>2]|0;
    $227 = HEAP32[((478152 + 4|0))>>2]|0;
    $228 = HEAP32[((478152 + 8|0))>>2]|0;
    $229 = HEAP32[((478152 + 12|0))>>2]|0;
    $230 = Math_fround(HEAPF32[$126>>2]);
    $231 = (HEAP32[tempDoublePtr>>2]=$226,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $232 = $230 > $231;
    $233 = Math_fround(HEAPF32[$127>>2]);
    $234 = (HEAP32[tempDoublePtr>>2]=$227,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $235 = $233 > $234;
    $236 = Math_fround(HEAPF32[$128>>2]);
    $237 = (HEAP32[tempDoublePtr>>2]=$228,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $238 = $236 > $237;
    $239 = Math_fround(HEAPF32[$129>>2]);
    $240 = (HEAP32[tempDoublePtr>>2]=$229,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $241 = $239 > $240;
    $not$x$i$i$i$us = $232 ^ 1;
    $242 = $not$x$i$i$i$us << 31 >> 31;
    $243 = $242 ^ -1;
    $not$y$i$i$i$us = $235 ^ 1;
    $244 = $not$y$i$i$i$us << 31 >> 31;
    $245 = $244 ^ -1;
    $not$z$i$i$i$us = $238 ^ 1;
    $246 = $not$z$i$i$i$us << 31 >> 31;
    $247 = $246 ^ -1;
    $not$w$i$i$i$us = $241 ^ 1;
    $248 = $not$w$i$i$i$us << 31 >> 31;
    $249 = $248 ^ -1;
    HEAP32[$mask>>2] = $243;
    HEAP32[$130>>2] = $245;
    HEAP32[$131>>2] = $247;
    HEAP32[$132>>2] = $249;
    $brmerge$i$us = $232 | $235;
    $brmerge1$i$us = $brmerge$i$us | $238;
    $$$i$us = $brmerge1$i$us | $241;
    if ($$$i$us) {
     $250 = Math_fround(Math_fround(1.0) / $230);
     $251 = Math_fround(Math_fround(1.0) / $233);
     $252 = Math_fround(Math_fround(1.0) / $236);
     $253 = Math_fround(Math_fround(1.0) / $239);
     HEAPF32[$invNumCollisions>>2] = $250;
     HEAPF32[$133>>2] = $251;
     HEAPF32[$134>>2] = $252;
     HEAPF32[$135>>2] = $253;
     $254 = Math_fround(HEAPF32[$prevIt$0111$us>>2]);
     $255 = (($prevIt$0111$us) + 4|0);
     $256 = Math_fround(HEAPF32[$255>>2]);
     $257 = (($prevIt$0111$us) + 8|0);
     $258 = Math_fround(HEAPF32[$257>>2]);
     $259 = (($prevIt$0111$us) + 12|0);
     $260 = Math_fround(HEAPF32[$259>>2]);
     $261 = (HEAPF32[tempDoublePtr>>2]=$254,HEAP32[tempDoublePtr>>2]|0);
     $262 = (HEAPF32[tempDoublePtr>>2]=$256,HEAP32[tempDoublePtr>>2]|0);
     $263 = (HEAPF32[tempDoublePtr>>2]=$258,HEAP32[tempDoublePtr>>2]|0);
     $264 = (HEAPF32[tempDoublePtr>>2]=$260,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$prevPos>>2] = $261;
     HEAP32[$136>>2] = $262;
     HEAP32[$137>>2] = $263;
     HEAP32[$138>>2] = $264;
     $265 = (($prevIt$0111$us) + 16|0);
     $266 = Math_fround(HEAPF32[$265>>2]);
     $267 = (($prevIt$0111$us) + 20|0);
     $268 = Math_fround(HEAPF32[$267>>2]);
     $269 = (($prevIt$0111$us) + 24|0);
     $270 = Math_fround(HEAPF32[$269>>2]);
     $271 = (($prevIt$0111$us) + 28|0);
     $272 = Math_fround(HEAPF32[$271>>2]);
     $273 = (HEAPF32[tempDoublePtr>>2]=$266,HEAP32[tempDoublePtr>>2]|0);
     $274 = (HEAPF32[tempDoublePtr>>2]=$268,HEAP32[tempDoublePtr>>2]|0);
     $275 = (HEAPF32[tempDoublePtr>>2]=$270,HEAP32[tempDoublePtr>>2]|0);
     $276 = (HEAPF32[tempDoublePtr>>2]=$272,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$139>>2] = $273;
     HEAP32[$140>>2] = $274;
     HEAP32[$141>>2] = $275;
     HEAP32[$142>>2] = $276;
     $277 = (($prevIt$0111$us) + 32|0);
     $278 = Math_fround(HEAPF32[$277>>2]);
     $279 = (($prevIt$0111$us) + 36|0);
     $280 = Math_fround(HEAPF32[$279>>2]);
     $281 = (($prevIt$0111$us) + 40|0);
     $282 = Math_fround(HEAPF32[$281>>2]);
     $283 = (($prevIt$0111$us) + 44|0);
     $284 = Math_fround(HEAPF32[$283>>2]);
     $285 = (HEAPF32[tempDoublePtr>>2]=$278,HEAP32[tempDoublePtr>>2]|0);
     $286 = (HEAPF32[tempDoublePtr>>2]=$280,HEAP32[tempDoublePtr>>2]|0);
     $287 = (HEAPF32[tempDoublePtr>>2]=$282,HEAP32[tempDoublePtr>>2]|0);
     $288 = (HEAPF32[tempDoublePtr>>2]=$284,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$143>>2] = $285;
     HEAP32[$144>>2] = $286;
     HEAP32[$145>>2] = $287;
     HEAP32[$146>>2] = $288;
     $289 = (($prevIt$0111$us) + 48|0);
     $290 = Math_fround(HEAPF32[$289>>2]);
     $291 = (($prevIt$0111$us) + 52|0);
     $292 = Math_fround(HEAPF32[$291>>2]);
     $293 = (($prevIt$0111$us) + 56|0);
     $294 = Math_fround(HEAPF32[$293>>2]);
     $295 = (($prevIt$0111$us) + 60|0);
     $296 = Math_fround(HEAPF32[$295>>2]);
     $297 = (HEAPF32[tempDoublePtr>>2]=$296,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$149>>2] = $297;
     HEAPF32[$136>>2] = $266;
     HEAPF32[$137>>2] = $278;
     HEAPF32[$138>>2] = $290;
     HEAPF32[$139>>2] = $256;
     HEAPF32[$141>>2] = $280;
     HEAPF32[$142>>2] = $292;
     HEAPF32[$143>>2] = $258;
     HEAPF32[$144>>2] = $270;
     HEAPF32[$146>>2] = $294;
     HEAPF32[$150>>2] = $260;
     HEAPF32[$147>>2] = $272;
     HEAPF32[$148>>2] = $284;
     __ZN12_GLOBAL__N_124calculateFrictionImpulseI8Scalar4fEEvRKT_S4_S4_S4_S4_S4_PS3_S5_S4_S4_S4_PS2_($accum,$151,$152,$153,$154,$155,$curPos,$prevPos,$invNumCollisions,$frictionScale,$mask,$frictionImpulse);
     $298 = Math_fround(HEAPF32[$prevPos>>2]);
     $299 = Math_fround(HEAPF32[$frictionImpulse>>2]);
     $300 = Math_fround($298 - $299);
     $301 = Math_fround(HEAPF32[$136>>2]);
     $302 = Math_fround(HEAPF32[$156>>2]);
     $303 = Math_fround($301 - $302);
     $304 = Math_fround(HEAPF32[$137>>2]);
     $305 = Math_fround(HEAPF32[$157>>2]);
     $306 = Math_fround($304 - $305);
     $307 = Math_fround(HEAPF32[$138>>2]);
     $308 = Math_fround(HEAPF32[$158>>2]);
     $309 = Math_fround($307 - $308);
     $310 = (HEAPF32[tempDoublePtr>>2]=$300,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$prevPos>>2] = $310;
     $311 = Math_fround(HEAPF32[$139>>2]);
     $312 = Math_fround(HEAPF32[$159>>2]);
     $313 = Math_fround($311 - $312);
     $314 = Math_fround(HEAPF32[$140>>2]);
     $315 = Math_fround(HEAPF32[$160>>2]);
     $316 = Math_fround($314 - $315);
     $317 = Math_fround(HEAPF32[$141>>2]);
     $318 = Math_fround(HEAPF32[$161>>2]);
     $319 = Math_fround($317 - $318);
     $320 = Math_fround(HEAPF32[$142>>2]);
     $321 = Math_fround(HEAPF32[$162>>2]);
     $322 = Math_fround($320 - $321);
     $323 = (HEAPF32[tempDoublePtr>>2]=$316,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$140>>2] = $323;
     $324 = Math_fround(HEAPF32[$143>>2]);
     $325 = Math_fround(HEAPF32[$163>>2]);
     $326 = Math_fround($324 - $325);
     $327 = Math_fround(HEAPF32[$144>>2]);
     $328 = Math_fround(HEAPF32[$164>>2]);
     $329 = Math_fround($327 - $328);
     $330 = Math_fround(HEAPF32[$145>>2]);
     $331 = Math_fround(HEAPF32[$165>>2]);
     $332 = Math_fround($330 - $331);
     $333 = Math_fround(HEAPF32[$146>>2]);
     $334 = Math_fround(HEAPF32[$166>>2]);
     $335 = Math_fround($333 - $334);
     $336 = (HEAPF32[tempDoublePtr>>2]=$332,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$145>>2] = $336;
     HEAPF32[$136>>2] = $313;
     HEAPF32[$137>>2] = $326;
     $337 = Math_fround(HEAPF32[$150>>2]);
     HEAPF32[$138>>2] = $337;
     HEAPF32[$139>>2] = $303;
     HEAPF32[$141>>2] = $329;
     $338 = Math_fround(HEAPF32[$147>>2]);
     HEAPF32[$142>>2] = $338;
     HEAPF32[$143>>2] = $306;
     HEAPF32[$144>>2] = $319;
     $339 = Math_fround(HEAPF32[$148>>2]);
     HEAPF32[$146>>2] = $339;
     HEAPF32[$150>>2] = $309;
     HEAPF32[$147>>2] = $322;
     HEAPF32[$148>>2] = $335;
     HEAPF32[$prevIt$0111$us>>2] = $300;
     $340 = Math_fround(HEAPF32[$136>>2]);
     HEAPF32[$255>>2] = $340;
     $341 = Math_fround(HEAPF32[$137>>2]);
     HEAPF32[$257>>2] = $341;
     $342 = Math_fround(HEAPF32[$138>>2]);
     HEAPF32[$259>>2] = $342;
     $343 = Math_fround(HEAPF32[$139>>2]);
     HEAPF32[$265>>2] = $343;
     $344 = Math_fround(HEAPF32[$140>>2]);
     HEAPF32[$267>>2] = $344;
     $345 = Math_fround(HEAPF32[$141>>2]);
     HEAPF32[$269>>2] = $345;
     $346 = Math_fround(HEAPF32[$142>>2]);
     HEAPF32[$271>>2] = $346;
     $347 = Math_fround(HEAPF32[$143>>2]);
     HEAPF32[$277>>2] = $347;
     $348 = Math_fround(HEAPF32[$144>>2]);
     HEAPF32[$279>>2] = $348;
     $349 = Math_fround(HEAPF32[$145>>2]);
     HEAPF32[$281>>2] = $349;
     $350 = Math_fround(HEAPF32[$146>>2]);
     HEAPF32[$283>>2] = $350;
     $351 = Math_fround(HEAPF32[$150>>2]);
     HEAPF32[$289>>2] = $351;
     $352 = Math_fround(HEAPF32[$147>>2]);
     HEAPF32[$291>>2] = $352;
     $353 = Math_fround(HEAPF32[$148>>2]);
     HEAPF32[$293>>2] = $353;
     $354 = Math_fround(HEAPF32[$149>>2]);
     HEAPF32[$295>>2] = $354;
     $$pre115 = Math_fround(HEAPF32[$invNumCollisions>>2]);
     $$pre116 = Math_fround(HEAPF32[$133>>2]);
     $$pre117 = Math_fround(HEAPF32[$134>>2]);
     $$pre118 = Math_fround(HEAPF32[$135>>2]);
     $355 = Math_fround(HEAPF32[$accum>>2]);
     $356 = Math_fround($355 * $$pre115);
     $357 = Math_fround(HEAPF32[$167>>2]);
     $358 = Math_fround($357 * $$pre116);
     $359 = Math_fround(HEAPF32[$168>>2]);
     $360 = Math_fround($359 * $$pre117);
     $361 = Math_fround(HEAPF32[$169>>2]);
     $362 = Math_fround($361 * $$pre118);
     $363 = Math_fround(HEAPF32[$curPos>>2]);
     $364 = Math_fround($356 + $363);
     $365 = Math_fround(HEAPF32[$111>>2]);
     $366 = Math_fround($358 + $365);
     $367 = Math_fround(HEAPF32[$112>>2]);
     $368 = Math_fround($360 + $367);
     $369 = Math_fround(HEAPF32[$113>>2]);
     $370 = Math_fround($362 + $369);
     $371 = (HEAPF32[tempDoublePtr>>2]=$364,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$curPos>>2] = $371;
     $372 = Math_fround(HEAPF32[$170>>2]);
     $373 = Math_fround($372 * $$pre115);
     $374 = Math_fround(HEAPF32[$171>>2]);
     $375 = Math_fround($374 * $$pre116);
     $376 = Math_fround(HEAPF32[$172>>2]);
     $377 = Math_fround($376 * $$pre117);
     $378 = Math_fround(HEAPF32[$173>>2]);
     $379 = Math_fround($378 * $$pre118);
     $380 = Math_fround(HEAPF32[$114>>2]);
     $381 = Math_fround($373 + $380);
     $382 = Math_fround(HEAPF32[$115>>2]);
     $383 = Math_fround($375 + $382);
     $384 = Math_fround(HEAPF32[$116>>2]);
     $385 = Math_fround($377 + $384);
     $386 = Math_fround(HEAPF32[$117>>2]);
     $387 = Math_fround($379 + $386);
     $388 = (HEAPF32[tempDoublePtr>>2]=$383,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$115>>2] = $388;
     $389 = Math_fround(HEAPF32[$174>>2]);
     $390 = Math_fround($389 * $$pre115);
     $391 = Math_fround(HEAPF32[$175>>2]);
     $392 = Math_fround($391 * $$pre116);
     $393 = Math_fround(HEAPF32[$176>>2]);
     $394 = Math_fround($393 * $$pre117);
     $395 = Math_fround(HEAPF32[$177>>2]);
     $396 = Math_fround($395 * $$pre118);
     $397 = Math_fround(HEAPF32[$118>>2]);
     $398 = Math_fround($390 + $397);
     $399 = Math_fround(HEAPF32[$119>>2]);
     $400 = Math_fround($392 + $399);
     $401 = Math_fround(HEAPF32[$120>>2]);
     $402 = Math_fround($394 + $401);
     $403 = Math_fround(HEAPF32[$121>>2]);
     $404 = Math_fround($396 + $403);
     $405 = (HEAPF32[tempDoublePtr>>2]=$402,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$120>>2] = $405;
     HEAPF32[$111>>2] = $381;
     HEAPF32[$112>>2] = $398;
     $406 = Math_fround(HEAPF32[$125>>2]);
     HEAPF32[$113>>2] = $406;
     HEAPF32[$114>>2] = $366;
     HEAPF32[$116>>2] = $400;
     $407 = Math_fround(HEAPF32[$122>>2]);
     HEAPF32[$117>>2] = $407;
     HEAPF32[$118>>2] = $368;
     HEAPF32[$119>>2] = $385;
     $408 = Math_fround(HEAPF32[$123>>2]);
     HEAPF32[$121>>2] = $408;
     HEAPF32[$125>>2] = $370;
     HEAPF32[$122>>2] = $387;
     HEAPF32[$123>>2] = $404;
     HEAPF32[$curIt$0109$us>>2] = $364;
     $409 = Math_fround(HEAPF32[$111>>2]);
     HEAPF32[$179>>2] = $409;
     $410 = Math_fround(HEAPF32[$112>>2]);
     HEAPF32[$181>>2] = $410;
     $411 = Math_fround(HEAPF32[$113>>2]);
     HEAPF32[$183>>2] = $411;
     $412 = Math_fround(HEAPF32[$114>>2]);
     HEAPF32[$189>>2] = $412;
     $413 = Math_fround(HEAPF32[$115>>2]);
     HEAPF32[$191>>2] = $413;
     $414 = Math_fround(HEAPF32[$116>>2]);
     HEAPF32[$193>>2] = $414;
     $415 = Math_fround(HEAPF32[$117>>2]);
     HEAPF32[$195>>2] = $415;
     $416 = Math_fround(HEAPF32[$118>>2]);
     HEAPF32[$201>>2] = $416;
     $417 = Math_fround(HEAPF32[$119>>2]);
     HEAPF32[$203>>2] = $417;
     $418 = Math_fround(HEAPF32[$120>>2]);
     HEAPF32[$205>>2] = $418;
     $419 = Math_fround(HEAPF32[$121>>2]);
     HEAPF32[$207>>2] = $419;
     $420 = Math_fround(HEAPF32[$125>>2]);
     HEAPF32[$213>>2] = $420;
     $421 = Math_fround(HEAPF32[$122>>2]);
     HEAPF32[$215>>2] = $421;
     $422 = Math_fround(HEAPF32[$123>>2]);
     HEAPF32[$217>>2] = $422;
     $423 = Math_fround(HEAPF32[$124>>2]);
     HEAPF32[$219>>2] = $423;
    }
    $424 = (($curIt$0109$us) + 64|0);
    $425 = ($424>>>0)<($106>>>0);
    if (!($425)) {
     break L17;
    }
    $426 = (($prevIt$0111$us) + 64|0);
    $curIt$0109$us = $424;$prevIt$0111$us = $426;
   }
  }
 } while(0);
 $574 = HEAP32[$5>>2]|0;
 $575 = ($$0$i|0)==(0|0);
 if ($575) {
  STACKTOP = sp;return;
 }
 $576 = (($$0$i) + -4|0);
 $577 = HEAP32[$576>>2]|0;
 $578 = $577 | -2147483648;
 HEAP32[$576>>2] = $578;
 $579 = (($574) + 12|0);
 $580 = HEAP32[$579>>2]|0;
 $581 = ($580|0)==(0|0);
 if ($581) {
  STACKTOP = sp;return;
 }
 $582 = (($574) + 8|0);
 $584 = $580;
 while(1) {
  $583 = (($584) + 4|0);
  $585 = HEAP32[$583>>2]|0;
  $586 = ($585|0)<(0);
  if (!($586)) {
   label = 25;
   break;
  }
  HEAP32[$582>>2] = $584;
  $587 = HEAP32[$584>>2]|0;
  HEAP32[$579>>2] = $587;
  $588 = ($587|0)==(0|0);
  if ($588) {
   label = 25;
   break;
  } else {
   $584 = $587;
  }
 }
 if ((label|0) == 25) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE16collideTrianglesERKNS0_14IterationStateIS2_EE($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $$$i = 0, $$0$i = 0, $$0169$i = 0, $$0170$i = 0, $$070$i = 0, $$071$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0;
 var $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0;
 var $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0;
 var $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = Math_fround(0);
 var $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0);
 var $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0;
 var $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = 0, $444 = Math_fround(0), $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = Math_fround(0);
 var $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = Math_fround(0), $546 = 0, $547 = Math_fround(0), $548 = 0, $549 = Math_fround(0), $55 = Math_fround(0), $550 = 0, $551 = Math_fround(0), $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = 0;
 var $560 = 0, $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = Math_fround(0), $57 = Math_fround(0), $570 = 0, $571 = Math_fround(0), $572 = 0, $573 = Math_fround(0), $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = Math_fround(0), $582 = 0, $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = Math_fround(0), $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = Math_fround(0), $605 = 0, $606 = Math_fround(0), $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0);
 var $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = 0, $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0);
 var $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = 0, $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0);
 var $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = 0, $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0);
 var $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = Math_fround(0), $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $accum = 0, $brmerge$i = 0, $brmerge1$i = 0, $pIt$067 = 0, $positions = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $positions = sp + 112|0;
 $accum = sp;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 192|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 436|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($3*80)|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0$i = 0;$22 = $1;
 } else {
  $9 = (($6) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10;
  $12 = (($11) + 23)|0;
  $13 = $12 & -16;
  $14 = $13;
  $15 = (($14) + ($7)|0);
  $16 = (($14) + -8|0);
  $17 = (($6) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$16>>2] = $18;
  $19 = (($14) + -4|0);
  $20 = $7 & 2147483632;
  HEAP32[$19>>2] = $20;
  HEAP32[$17>>2] = $16;
  HEAP32[$9>>2] = $15;
  $$pre = HEAP32[$0>>2]|0;
  $$0$i = $14;$22 = $$pre;
 }
 $21 = (($22) + 188|0);
 $23 = HEAP32[$21>>2]|0;
 $24 = HEAP32[$state>>2]|0;
 $25 = ($24|0)==(1);
 if ($25) {
  $296 = (($22) + 192|0);
  $297 = HEAP32[$296>>2]|0;
  $298 = ($297|0)==(0);
  if (!($298)) {
   $299 = HEAP32[478184>>2]|0;
   $300 = HEAP32[((478184 + 4|0))>>2]|0;
   $301 = HEAP32[((478184 + 8|0))>>2]|0;
   $302 = HEAP32[((478184 + 12|0))>>2]|0;
   $303 = HEAP32[478200>>2]|0;
   $304 = HEAP32[((478200 + 4|0))>>2]|0;
   $305 = HEAP32[((478200 + 8|0))>>2]|0;
   $306 = HEAP32[((478200 + 12|0))>>2]|0;
   $307 = HEAP32[478216>>2]|0;
   $308 = HEAP32[((478216 + 4|0))>>2]|0;
   $309 = HEAP32[((478216 + 8|0))>>2]|0;
   $310 = HEAP32[((478216 + 12|0))>>2]|0;
   $$0169$i = $$0$i;$$070$i = $297;$313 = $23;
   while(1) {
    $311 = (($$070$i) + -1)|0;
    $312 = Math_fround(HEAPF32[$313>>2]);
    $314 = (($313) + 4|0);
    $315 = Math_fround(HEAPF32[$314>>2]);
    $316 = (($313) + 8|0);
    $317 = Math_fround(HEAPF32[$316>>2]);
    $318 = (($313) + 12|0);
    $319 = Math_fround(HEAPF32[$318>>2]);
    $320 = (HEAPF32[tempDoublePtr>>2]=$312,HEAP32[tempDoublePtr>>2]|0);
    $321 = (HEAPF32[tempDoublePtr>>2]=$315,HEAP32[tempDoublePtr>>2]|0);
    $322 = (HEAPF32[tempDoublePtr>>2]=$317,HEAP32[tempDoublePtr>>2]|0);
    $323 = (HEAPF32[tempDoublePtr>>2]=$319,HEAP32[tempDoublePtr>>2]|0);
    $324 = (($313) + 16|0);
    $325 = Math_fround(HEAPF32[$324>>2]);
    $326 = (($313) + 20|0);
    $327 = Math_fround(HEAPF32[$326>>2]);
    $328 = (($313) + 24|0);
    $329 = Math_fround(HEAPF32[$328>>2]);
    $330 = (($313) + 28|0);
    $331 = Math_fround(HEAPF32[$330>>2]);
    $332 = (($313) + 32|0);
    $333 = Math_fround(HEAPF32[$332>>2]);
    $334 = (($313) + 36|0);
    $335 = Math_fround(HEAPF32[$334>>2]);
    $336 = Math_fround($319 - $312);
    $337 = Math_fround($325 - $315);
    $338 = Math_fround($327 - $317);
    $339 = Math_fround($329 - $319);
    $340 = (HEAPF32[tempDoublePtr>>2]=$336,HEAP32[tempDoublePtr>>2]|0);
    $341 = (HEAPF32[tempDoublePtr>>2]=$337,HEAP32[tempDoublePtr>>2]|0);
    $342 = (HEAPF32[tempDoublePtr>>2]=$338,HEAP32[tempDoublePtr>>2]|0);
    $343 = (HEAPF32[tempDoublePtr>>2]=$339,HEAP32[tempDoublePtr>>2]|0);
    $344 = Math_fround($329 - $312);
    $345 = Math_fround($331 - $315);
    $346 = Math_fround($333 - $317);
    $347 = Math_fround($335 - $319);
    $348 = (HEAPF32[tempDoublePtr>>2]=$344,HEAP32[tempDoublePtr>>2]|0);
    $349 = (HEAPF32[tempDoublePtr>>2]=$345,HEAP32[tempDoublePtr>>2]|0);
    $350 = (HEAPF32[tempDoublePtr>>2]=$346,HEAP32[tempDoublePtr>>2]|0);
    $351 = (HEAPF32[tempDoublePtr>>2]=$347,HEAP32[tempDoublePtr>>2]|0);
    $352 = Math_fround($337 * $346);
    $353 = Math_fround($338 * $345);
    $354 = Math_fround($352 - $353);
    $355 = Math_fround($338 * $344);
    $356 = Math_fround($336 * $346);
    $357 = Math_fround($355 - $356);
    $358 = Math_fround($336 * $345);
    $359 = Math_fround($337 * $344);
    $360 = Math_fround($358 - $359);
    $361 = Math_fround($336 * $336);
    $362 = Math_fround($337 * $337);
    $363 = Math_fround($361 + $362);
    $364 = Math_fround($338 * $338);
    $365 = Math_fround($363 + $364);
    $366 = (HEAPF32[tempDoublePtr>>2]=$365,HEAP32[tempDoublePtr>>2]|0);
    $367 = Math_fround($344 * $344);
    $368 = Math_fround($345 * $345);
    $369 = Math_fround($367 + $368);
    $370 = Math_fround($346 * $346);
    $371 = Math_fround($369 + $370);
    $372 = (HEAPF32[tempDoublePtr>>2]=$371,HEAP32[tempDoublePtr>>2]|0);
    $373 = Math_fround($336 * $344);
    $374 = Math_fround($337 * $345);
    $375 = Math_fround($373 + $374);
    $376 = Math_fround($338 * $346);
    $377 = Math_fround($375 + $376);
    $378 = (HEAPF32[tempDoublePtr>>2]=$377,HEAP32[tempDoublePtr>>2]|0);
    $379 = Math_fround($354 * $354);
    $380 = Math_fround($357 * $357);
    $381 = Math_fround($379 + $380);
    $382 = Math_fround($360 * $360);
    $383 = Math_fround($382 + $381);
    $384 = (Math_fround(Math_sqrt((Math_fround($383)))));
    $385 = Math_fround(Math_fround(1.0) / $384);
    $386 = Math_fround($365 * $371);
    $387 = Math_fround($377 * $377);
    $388 = Math_fround($386 - $387);
    $389 = (HEAPF32[tempDoublePtr>>2]=$388,HEAP32[tempDoublePtr>>2]|0);
    $390 = Math_fround($365 + $371);
    $391 = Math_fround($390 - $377);
    $392 = Math_fround($391 - $377);
    $393 = (HEAPF32[tempDoublePtr>>2]=$392,HEAP32[tempDoublePtr>>2]|0);
    $394 = $393 ^ $389;
    $395 = $394 & $299;
    $396 = $394 & $300;
    $397 = $394 & $301;
    $398 = $394 & $302;
    $399 = $395 ^ $393;
    $400 = $396 ^ $393;
    $401 = $397 ^ $393;
    $402 = $398 ^ $393;
    $403 = $399 ^ $366;
    $404 = $400 ^ $366;
    $405 = $401 ^ $366;
    $406 = $402 ^ $366;
    $407 = $403 & $303;
    $408 = $404 & $304;
    $409 = $405 & $305;
    $410 = $406 & $306;
    $411 = $407 ^ $399;
    $412 = $408 ^ $400;
    $413 = $409 ^ $401;
    $414 = $410 ^ $402;
    $415 = $411 ^ $372;
    $416 = $412 ^ $372;
    $417 = $413 ^ $372;
    $418 = $414 ^ $372;
    $419 = $415 & $307;
    $420 = $416 & $308;
    $421 = $417 & $309;
    $422 = $418 & $310;
    $423 = $419 ^ $411;
    $424 = $420 ^ $412;
    $425 = $421 ^ $413;
    $426 = $422 ^ $414;
    $427 = $378 ^ $320;
    $428 = $378 ^ $321;
    $429 = $378 ^ $322;
    $430 = $378 ^ $323;
    $431 = $427 & $307;
    $432 = $428 & $308;
    $433 = $429 & $309;
    $434 = $430 & $310;
    $435 = $431 ^ $320;
    $436 = $432 ^ $321;
    $437 = $433 ^ $322;
    $438 = $434 ^ $323;
    $439 = (HEAP32[tempDoublePtr>>2]=$435,Math_fround(HEAPF32[tempDoublePtr>>2]));
    HEAPF32[$$0169$i>>2] = $439;
    $440 = (HEAP32[tempDoublePtr>>2]=$436,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $441 = (($$0169$i) + 4|0);
    HEAPF32[$441>>2] = $440;
    $442 = (HEAP32[tempDoublePtr>>2]=$437,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $443 = (($$0169$i) + 8|0);
    HEAPF32[$443>>2] = $442;
    $444 = (HEAP32[tempDoublePtr>>2]=$438,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $445 = (($$0169$i) + 12|0);
    HEAPF32[$445>>2] = $444;
    $446 = (($$0169$i) + 16|0);
    $447 = $366 ^ $340;
    $448 = $366 ^ $341;
    $449 = $366 ^ $342;
    $450 = $366 ^ $343;
    $451 = $447 & $307;
    $452 = $448 & $308;
    $453 = $449 & $309;
    $454 = $450 & $310;
    $455 = $451 ^ $340;
    $456 = $452 ^ $341;
    $457 = $453 ^ $342;
    $458 = $454 ^ $343;
    $459 = (HEAP32[tempDoublePtr>>2]=$455,Math_fround(HEAPF32[tempDoublePtr>>2]));
    HEAPF32[$446>>2] = $459;
    $460 = (HEAP32[tempDoublePtr>>2]=$456,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $461 = (($446) + 4|0);
    HEAPF32[$461>>2] = $460;
    $462 = (HEAP32[tempDoublePtr>>2]=$457,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $463 = (($446) + 8|0);
    HEAPF32[$463>>2] = $462;
    $464 = (HEAP32[tempDoublePtr>>2]=$458,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $465 = (($446) + 12|0);
    HEAPF32[$465>>2] = $464;
    $466 = (($$0169$i) + 32|0);
    $467 = $372 ^ $348;
    $468 = $372 ^ $349;
    $469 = $372 ^ $350;
    $470 = $372 ^ $351;
    $471 = $467 & $307;
    $472 = $468 & $308;
    $473 = $469 & $309;
    $474 = $470 & $310;
    $475 = $471 ^ $348;
    $476 = $472 ^ $349;
    $477 = $473 ^ $350;
    $478 = $474 ^ $351;
    $479 = (HEAP32[tempDoublePtr>>2]=$475,Math_fround(HEAPF32[tempDoublePtr>>2]));
    HEAPF32[$466>>2] = $479;
    $480 = (HEAP32[tempDoublePtr>>2]=$476,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $481 = (($466) + 4|0);
    HEAPF32[$481>>2] = $480;
    $482 = (HEAP32[tempDoublePtr>>2]=$477,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $483 = (($466) + 8|0);
    HEAPF32[$483>>2] = $482;
    $484 = (HEAP32[tempDoublePtr>>2]=$478,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $485 = (($466) + 12|0);
    HEAPF32[$485>>2] = $484;
    $486 = (($$0169$i) + 48|0);
    $487 = Math_fround($354 * $385);
    $488 = Math_fround($357 * $385);
    $489 = Math_fround($360 * $385);
    $490 = Math_fround($385 * Math_fround(0.0));
    HEAPF32[$486>>2] = $487;
    $491 = (($486) + 4|0);
    HEAPF32[$491>>2] = $488;
    $492 = (($486) + 8|0);
    HEAPF32[$492>>2] = $489;
    $493 = (($486) + 12|0);
    HEAPF32[$493>>2] = $490;
    $494 = (($$0169$i) + 64|0);
    $495 = (HEAP32[tempDoublePtr>>2]=$423,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $496 = Math_fround(Math_fround(1.0) / $495);
    $497 = (HEAP32[tempDoublePtr>>2]=$424,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $498 = Math_fround(Math_fround(1.0) / $497);
    $499 = (HEAP32[tempDoublePtr>>2]=$425,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $500 = Math_fround(Math_fround(1.0) / $499);
    $501 = (HEAP32[tempDoublePtr>>2]=$426,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $502 = Math_fround(Math_fround(1.0) / $501);
    HEAPF32[$494>>2] = $496;
    $503 = (($494) + 4|0);
    HEAPF32[$503>>2] = $498;
    $504 = (($494) + 8|0);
    HEAPF32[$504>>2] = $500;
    $505 = (($494) + 12|0);
    HEAPF32[$505>>2] = $502;
    $506 = (($$0169$i) + 80|0);
    $507 = ($311|0)==(0);
    if ($507) {
     break;
    } else {
     $$0169$i = $506;$$070$i = $311;$313 = $334;
    }
   }
  }
 } else {
  $26 = (($state) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($22) + 192|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0);
  if (!($30)) {
   $31 = (Math_fround(($24>>>0)));
   $32 = Math_fround($31 * $27);
   $33 = (($22) + 184|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = Math_fround(Math_fround(1.0) - $32);
   $36 = Math_fround($27 + $35);
   $37 = HEAP32[478184>>2]|0;
   $38 = HEAP32[((478184 + 4|0))>>2]|0;
   $39 = HEAP32[((478184 + 8|0))>>2]|0;
   $40 = HEAP32[((478184 + 12|0))>>2]|0;
   $41 = HEAP32[478200>>2]|0;
   $42 = HEAP32[((478200 + 4|0))>>2]|0;
   $43 = HEAP32[((478200 + 8|0))>>2]|0;
   $44 = HEAP32[((478200 + 12|0))>>2]|0;
   $45 = HEAP32[478216>>2]|0;
   $46 = HEAP32[((478216 + 4|0))>>2]|0;
   $47 = HEAP32[((478216 + 8|0))>>2]|0;
   $48 = HEAP32[((478216 + 12|0))>>2]|0;
   $$0170$i = $$0$i;$$071$i = $29;$51 = $34;$59 = $23;
   while(1) {
    $49 = (($$071$i) + -1)|0;
    $50 = Math_fround(HEAPF32[$51>>2]);
    $52 = (($51) + 4|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = (($51) + 8|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = (($51) + 12|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = Math_fround(HEAPF32[$59>>2]);
    $60 = (($59) + 4|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = (($59) + 8|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    $64 = (($59) + 12|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    $66 = Math_fround($58 - $50);
    $67 = Math_fround($61 - $53);
    $68 = Math_fround($63 - $55);
    $69 = Math_fround($65 - $57);
    $70 = Math_fround($36 * $66);
    $71 = Math_fround($36 * $67);
    $72 = Math_fround($36 * $68);
    $73 = Math_fround($36 * $69);
    $74 = Math_fround($50 + $70);
    $75 = Math_fround($53 + $71);
    $76 = Math_fround($55 + $72);
    $77 = Math_fround($57 + $73);
    $78 = (HEAPF32[tempDoublePtr>>2]=$74,HEAP32[tempDoublePtr>>2]|0);
    $79 = (HEAPF32[tempDoublePtr>>2]=$75,HEAP32[tempDoublePtr>>2]|0);
    $80 = (HEAPF32[tempDoublePtr>>2]=$76,HEAP32[tempDoublePtr>>2]|0);
    $81 = (HEAPF32[tempDoublePtr>>2]=$77,HEAP32[tempDoublePtr>>2]|0);
    $82 = (($51) + 16|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = (($51) + 20|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = (($51) + 24|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = (($59) + 16|0);
    $89 = Math_fround(HEAPF32[$88>>2]);
    $90 = (($59) + 20|0);
    $91 = Math_fround(HEAPF32[$90>>2]);
    $92 = (($59) + 24|0);
    $93 = Math_fround(HEAPF32[$92>>2]);
    $94 = Math_fround($89 - $83);
    $95 = Math_fround($91 - $85);
    $96 = Math_fround($93 - $87);
    $97 = Math_fround($36 * $94);
    $98 = Math_fround($36 * $95);
    $99 = Math_fround($36 * $96);
    $100 = Math_fround($83 + $97);
    $101 = Math_fround($85 + $98);
    $102 = Math_fround($87 + $99);
    $103 = (($51) + 28|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = (($51) + 32|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $107 = (($51) + 36|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $109 = (($59) + 28|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $111 = (($59) + 32|0);
    $112 = Math_fround(HEAPF32[$111>>2]);
    $113 = (($59) + 36|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = Math_fround($110 - $104);
    $116 = Math_fround($112 - $106);
    $117 = Math_fround($114 - $108);
    $118 = Math_fround($36 * $115);
    $119 = Math_fround($36 * $116);
    $120 = Math_fround($36 * $117);
    $121 = Math_fround($104 + $118);
    $122 = Math_fround($106 + $119);
    $123 = Math_fround($108 + $120);
    $124 = Math_fround($77 - $74);
    $125 = Math_fround($100 - $75);
    $126 = Math_fround($101 - $76);
    $127 = Math_fround($102 - $77);
    $128 = (HEAPF32[tempDoublePtr>>2]=$124,HEAP32[tempDoublePtr>>2]|0);
    $129 = (HEAPF32[tempDoublePtr>>2]=$125,HEAP32[tempDoublePtr>>2]|0);
    $130 = (HEAPF32[tempDoublePtr>>2]=$126,HEAP32[tempDoublePtr>>2]|0);
    $131 = (HEAPF32[tempDoublePtr>>2]=$127,HEAP32[tempDoublePtr>>2]|0);
    $132 = Math_fround($102 - $74);
    $133 = Math_fround($121 - $75);
    $134 = Math_fround($122 - $76);
    $135 = Math_fround($123 - $77);
    $136 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
    $137 = (HEAPF32[tempDoublePtr>>2]=$133,HEAP32[tempDoublePtr>>2]|0);
    $138 = (HEAPF32[tempDoublePtr>>2]=$134,HEAP32[tempDoublePtr>>2]|0);
    $139 = (HEAPF32[tempDoublePtr>>2]=$135,HEAP32[tempDoublePtr>>2]|0);
    $140 = Math_fround($125 * $134);
    $141 = Math_fround($126 * $133);
    $142 = Math_fround($140 - $141);
    $143 = Math_fround($126 * $132);
    $144 = Math_fround($124 * $134);
    $145 = Math_fround($143 - $144);
    $146 = Math_fround($124 * $133);
    $147 = Math_fround($125 * $132);
    $148 = Math_fround($146 - $147);
    $149 = Math_fround($124 * $124);
    $150 = Math_fround($125 * $125);
    $151 = Math_fround($149 + $150);
    $152 = Math_fround($126 * $126);
    $153 = Math_fround($151 + $152);
    $154 = (HEAPF32[tempDoublePtr>>2]=$153,HEAP32[tempDoublePtr>>2]|0);
    $155 = Math_fround($132 * $132);
    $156 = Math_fround($133 * $133);
    $157 = Math_fround($155 + $156);
    $158 = Math_fround($134 * $134);
    $159 = Math_fround($157 + $158);
    $160 = (HEAPF32[tempDoublePtr>>2]=$159,HEAP32[tempDoublePtr>>2]|0);
    $161 = Math_fround($124 * $132);
    $162 = Math_fround($125 * $133);
    $163 = Math_fround($161 + $162);
    $164 = Math_fround($126 * $134);
    $165 = Math_fround($163 + $164);
    $166 = (HEAPF32[tempDoublePtr>>2]=$165,HEAP32[tempDoublePtr>>2]|0);
    $167 = Math_fround($142 * $142);
    $168 = Math_fround($145 * $145);
    $169 = Math_fround($167 + $168);
    $170 = Math_fround($148 * $148);
    $171 = Math_fround($170 + $169);
    $172 = (Math_fround(Math_sqrt((Math_fround($171)))));
    $173 = Math_fround(Math_fround(1.0) / $172);
    $174 = Math_fround($153 * $159);
    $175 = Math_fround($165 * $165);
    $176 = Math_fround($174 - $175);
    $177 = (HEAPF32[tempDoublePtr>>2]=$176,HEAP32[tempDoublePtr>>2]|0);
    $178 = Math_fround($153 + $159);
    $179 = Math_fround($178 - $165);
    $180 = Math_fround($179 - $165);
    $181 = (HEAPF32[tempDoublePtr>>2]=$180,HEAP32[tempDoublePtr>>2]|0);
    $182 = $181 ^ $177;
    $183 = $182 & $37;
    $184 = $182 & $38;
    $185 = $182 & $39;
    $186 = $182 & $40;
    $187 = $183 ^ $181;
    $188 = $184 ^ $181;
    $189 = $185 ^ $181;
    $190 = $186 ^ $181;
    $191 = $187 ^ $154;
    $192 = $188 ^ $154;
    $193 = $189 ^ $154;
    $194 = $190 ^ $154;
    $195 = $191 & $41;
    $196 = $192 & $42;
    $197 = $193 & $43;
    $198 = $194 & $44;
    $199 = $195 ^ $187;
    $200 = $196 ^ $188;
    $201 = $197 ^ $189;
    $202 = $198 ^ $190;
    $203 = $199 ^ $160;
    $204 = $200 ^ $160;
    $205 = $201 ^ $160;
    $206 = $202 ^ $160;
    $207 = $203 & $45;
    $208 = $204 & $46;
    $209 = $205 & $47;
    $210 = $206 & $48;
    $211 = $207 ^ $199;
    $212 = $208 ^ $200;
    $213 = $209 ^ $201;
    $214 = $210 ^ $202;
    $215 = $166 ^ $78;
    $216 = $166 ^ $79;
    $217 = $166 ^ $80;
    $218 = $166 ^ $81;
    $219 = $215 & $45;
    $220 = $216 & $46;
    $221 = $217 & $47;
    $222 = $218 & $48;
    $223 = $219 ^ $78;
    $224 = $220 ^ $79;
    $225 = $221 ^ $80;
    $226 = $222 ^ $81;
    $227 = (HEAP32[tempDoublePtr>>2]=$223,Math_fround(HEAPF32[tempDoublePtr>>2]));
    HEAPF32[$$0170$i>>2] = $227;
    $228 = (HEAP32[tempDoublePtr>>2]=$224,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $229 = (($$0170$i) + 4|0);
    HEAPF32[$229>>2] = $228;
    $230 = (HEAP32[tempDoublePtr>>2]=$225,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $231 = (($$0170$i) + 8|0);
    HEAPF32[$231>>2] = $230;
    $232 = (HEAP32[tempDoublePtr>>2]=$226,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $233 = (($$0170$i) + 12|0);
    HEAPF32[$233>>2] = $232;
    $234 = (($$0170$i) + 16|0);
    $235 = $154 ^ $128;
    $236 = $154 ^ $129;
    $237 = $154 ^ $130;
    $238 = $154 ^ $131;
    $239 = $235 & $45;
    $240 = $236 & $46;
    $241 = $237 & $47;
    $242 = $238 & $48;
    $243 = $239 ^ $128;
    $244 = $240 ^ $129;
    $245 = $241 ^ $130;
    $246 = $242 ^ $131;
    $247 = (HEAP32[tempDoublePtr>>2]=$243,Math_fround(HEAPF32[tempDoublePtr>>2]));
    HEAPF32[$234>>2] = $247;
    $248 = (HEAP32[tempDoublePtr>>2]=$244,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $249 = (($234) + 4|0);
    HEAPF32[$249>>2] = $248;
    $250 = (HEAP32[tempDoublePtr>>2]=$245,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $251 = (($234) + 8|0);
    HEAPF32[$251>>2] = $250;
    $252 = (HEAP32[tempDoublePtr>>2]=$246,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $253 = (($234) + 12|0);
    HEAPF32[$253>>2] = $252;
    $254 = (($$0170$i) + 32|0);
    $255 = $160 ^ $136;
    $256 = $160 ^ $137;
    $257 = $160 ^ $138;
    $258 = $160 ^ $139;
    $259 = $255 & $45;
    $260 = $256 & $46;
    $261 = $257 & $47;
    $262 = $258 & $48;
    $263 = $259 ^ $136;
    $264 = $260 ^ $137;
    $265 = $261 ^ $138;
    $266 = $262 ^ $139;
    $267 = (HEAP32[tempDoublePtr>>2]=$263,Math_fround(HEAPF32[tempDoublePtr>>2]));
    HEAPF32[$254>>2] = $267;
    $268 = (HEAP32[tempDoublePtr>>2]=$264,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $269 = (($254) + 4|0);
    HEAPF32[$269>>2] = $268;
    $270 = (HEAP32[tempDoublePtr>>2]=$265,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $271 = (($254) + 8|0);
    HEAPF32[$271>>2] = $270;
    $272 = (HEAP32[tempDoublePtr>>2]=$266,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $273 = (($254) + 12|0);
    HEAPF32[$273>>2] = $272;
    $274 = (($$0170$i) + 48|0);
    $275 = Math_fround($173 * $142);
    $276 = Math_fround($173 * $145);
    $277 = Math_fround($173 * $148);
    $278 = Math_fround($173 * Math_fround(0.0));
    HEAPF32[$274>>2] = $275;
    $279 = (($274) + 4|0);
    HEAPF32[$279>>2] = $276;
    $280 = (($274) + 8|0);
    HEAPF32[$280>>2] = $277;
    $281 = (($274) + 12|0);
    HEAPF32[$281>>2] = $278;
    $282 = (($$0170$i) + 64|0);
    $283 = (HEAP32[tempDoublePtr>>2]=$211,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $284 = Math_fround(Math_fround(1.0) / $283);
    $285 = (HEAP32[tempDoublePtr>>2]=$212,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $286 = Math_fround(Math_fround(1.0) / $285);
    $287 = (HEAP32[tempDoublePtr>>2]=$213,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $288 = Math_fround(Math_fround(1.0) / $287);
    $289 = (HEAP32[tempDoublePtr>>2]=$214,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $290 = Math_fround(Math_fround(1.0) / $289);
    HEAPF32[$282>>2] = $284;
    $291 = (($282) + 4|0);
    HEAPF32[$291>>2] = $286;
    $292 = (($282) + 8|0);
    HEAPF32[$292>>2] = $288;
    $293 = (($282) + 12|0);
    HEAPF32[$293>>2] = $290;
    $294 = (($$0170$i) + 80|0);
    $295 = ($49|0)==(0);
    if ($295) {
     break;
    } else {
     $$0170$i = $294;$$071$i = $49;$51 = $107;$59 = $113;
    }
   }
  }
 }
 $508 = HEAP32[$0>>2]|0;
 $509 = (($508) + 4|0);
 $510 = HEAP32[$509>>2]|0;
 $511 = HEAP32[$508>>2]|0;
 $512 = $511 << 2;
 $513 = (($510) + ($512<<2)|0);
 $514 = ($512|0)>(0);
 if ($514) {
  $515 = (($positions) + 4|0);
  $516 = (($positions) + 8|0);
  $517 = (($positions) + 12|0);
  $518 = (($positions) + 16|0);
  $519 = (($positions) + 20|0);
  $520 = (($positions) + 24|0);
  $521 = (($positions) + 28|0);
  $522 = (($positions) + 32|0);
  $523 = (($positions) + 36|0);
  $524 = (($positions) + 40|0);
  $525 = (($positions) + 44|0);
  $526 = (($positions) + 52|0);
  $527 = (($positions) + 56|0);
  $528 = (($positions) + 60|0);
  $529 = (($positions) + 48|0);
  $530 = (($accum) + 96|0);
  $531 = (($accum) + 100|0);
  $532 = (($accum) + 104|0);
  $533 = (($accum) + 108|0);
  $534 = (($accum) + 4|0);
  $535 = (($accum) + 8|0);
  $536 = (($accum) + 12|0);
  $537 = (($accum) + 16|0);
  $538 = (($accum) + 20|0);
  $539 = (($accum) + 24|0);
  $540 = (($accum) + 28|0);
  $541 = (($accum) + 32|0);
  $542 = (($accum) + 36|0);
  $543 = (($accum) + 40|0);
  $544 = (($accum) + 44|0);
  $pIt$067 = $510;
  while(1) {
   $545 = Math_fround(HEAPF32[$pIt$067>>2]);
   $546 = (($pIt$067) + 4|0);
   $547 = Math_fround(HEAPF32[$546>>2]);
   $548 = (($pIt$067) + 8|0);
   $549 = Math_fround(HEAPF32[$548>>2]);
   $550 = (($pIt$067) + 12|0);
   $551 = Math_fround(HEAPF32[$550>>2]);
   $552 = (HEAPF32[tempDoublePtr>>2]=$545,HEAP32[tempDoublePtr>>2]|0);
   $553 = (HEAPF32[tempDoublePtr>>2]=$547,HEAP32[tempDoublePtr>>2]|0);
   $554 = (HEAPF32[tempDoublePtr>>2]=$549,HEAP32[tempDoublePtr>>2]|0);
   $555 = (HEAPF32[tempDoublePtr>>2]=$551,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$positions>>2] = $552;
   HEAP32[$515>>2] = $553;
   HEAP32[$516>>2] = $554;
   HEAP32[$517>>2] = $555;
   $556 = (($pIt$067) + 16|0);
   $557 = Math_fround(HEAPF32[$556>>2]);
   $558 = (($pIt$067) + 20|0);
   $559 = Math_fround(HEAPF32[$558>>2]);
   $560 = (($pIt$067) + 24|0);
   $561 = Math_fround(HEAPF32[$560>>2]);
   $562 = (($pIt$067) + 28|0);
   $563 = Math_fround(HEAPF32[$562>>2]);
   $564 = (HEAPF32[tempDoublePtr>>2]=$557,HEAP32[tempDoublePtr>>2]|0);
   $565 = (HEAPF32[tempDoublePtr>>2]=$559,HEAP32[tempDoublePtr>>2]|0);
   $566 = (HEAPF32[tempDoublePtr>>2]=$561,HEAP32[tempDoublePtr>>2]|0);
   $567 = (HEAPF32[tempDoublePtr>>2]=$563,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$518>>2] = $564;
   HEAP32[$519>>2] = $565;
   HEAP32[$520>>2] = $566;
   HEAP32[$521>>2] = $567;
   $568 = (($pIt$067) + 32|0);
   $569 = Math_fround(HEAPF32[$568>>2]);
   $570 = (($pIt$067) + 36|0);
   $571 = Math_fround(HEAPF32[$570>>2]);
   $572 = (($pIt$067) + 40|0);
   $573 = Math_fround(HEAPF32[$572>>2]);
   $574 = (($pIt$067) + 44|0);
   $575 = Math_fround(HEAPF32[$574>>2]);
   $576 = (HEAPF32[tempDoublePtr>>2]=$569,HEAP32[tempDoublePtr>>2]|0);
   $577 = (HEAPF32[tempDoublePtr>>2]=$571,HEAP32[tempDoublePtr>>2]|0);
   $578 = (HEAPF32[tempDoublePtr>>2]=$573,HEAP32[tempDoublePtr>>2]|0);
   $579 = (HEAPF32[tempDoublePtr>>2]=$575,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$522>>2] = $576;
   HEAP32[$523>>2] = $577;
   HEAP32[$524>>2] = $578;
   HEAP32[$525>>2] = $579;
   $580 = (($pIt$067) + 48|0);
   $581 = Math_fround(HEAPF32[$580>>2]);
   $582 = (($pIt$067) + 52|0);
   $583 = Math_fround(HEAPF32[$582>>2]);
   $584 = (($pIt$067) + 56|0);
   $585 = Math_fround(HEAPF32[$584>>2]);
   $586 = (($pIt$067) + 60|0);
   $587 = Math_fround(HEAPF32[$586>>2]);
   $588 = (HEAPF32[tempDoublePtr>>2]=$587,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$528>>2] = $588;
   HEAPF32[$515>>2] = $557;
   HEAPF32[$516>>2] = $569;
   HEAPF32[$517>>2] = $581;
   HEAPF32[$518>>2] = $547;
   HEAPF32[$520>>2] = $571;
   HEAPF32[$521>>2] = $583;
   HEAPF32[$522>>2] = $549;
   HEAPF32[$523>>2] = $561;
   HEAPF32[$525>>2] = $585;
   HEAPF32[$529>>2] = $551;
   HEAPF32[$526>>2] = $563;
   HEAPF32[$527>>2] = $575;
   dest=$accum+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $589 = HEAP32[478152>>2]|0;
   HEAP32[$530>>2] = $589;
   $590 = HEAP32[((478152 + 4|0))>>2]|0;
   HEAP32[$531>>2] = $590;
   $591 = HEAP32[((478152 + 8|0))>>2]|0;
   HEAP32[$532>>2] = $591;
   $592 = HEAP32[((478152 + 12|0))>>2]|0;
   HEAP32[$533>>2] = $592;
   __ZN5physx5cloth11SwCollisionI8Scalar4fE16collideTrianglesEPKNS0_12TriangleDataEPS2_RNS3_18ImpulseAccumulatorE($this,$$0$i,$positions,$accum);
   $593 = HEAP32[478152>>2]|0;
   $594 = HEAP32[((478152 + 4|0))>>2]|0;
   $595 = HEAP32[((478152 + 8|0))>>2]|0;
   $596 = HEAP32[((478152 + 12|0))>>2]|0;
   $597 = Math_fround(HEAPF32[$530>>2]);
   $598 = (HEAP32[tempDoublePtr>>2]=$593,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $599 = $597 > $598;
   $600 = Math_fround(HEAPF32[$531>>2]);
   $601 = (HEAP32[tempDoublePtr>>2]=$594,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $602 = $600 > $601;
   $603 = Math_fround(HEAPF32[$532>>2]);
   $604 = (HEAP32[tempDoublePtr>>2]=$595,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $605 = $603 > $604;
   $606 = Math_fround(HEAPF32[$533>>2]);
   $607 = (HEAP32[tempDoublePtr>>2]=$596,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $608 = $606 > $607;
   $brmerge$i = $599 | $602;
   $brmerge1$i = $brmerge$i | $605;
   $$$i = $brmerge1$i | $608;
   if ($$$i) {
    $609 = Math_fround(Math_fround(1.0) / $597);
    $610 = Math_fround(Math_fround(1.0) / $600);
    $611 = Math_fround(Math_fround(1.0) / $603);
    $612 = Math_fround(Math_fround(1.0) / $606);
    $613 = Math_fround(HEAPF32[$accum>>2]);
    $614 = Math_fround($609 * $613);
    $615 = Math_fround(HEAPF32[$534>>2]);
    $616 = Math_fround($610 * $615);
    $617 = Math_fround(HEAPF32[$535>>2]);
    $618 = Math_fround($611 * $617);
    $619 = Math_fround(HEAPF32[$536>>2]);
    $620 = Math_fround($612 * $619);
    $621 = Math_fround(HEAPF32[$positions>>2]);
    $622 = Math_fround($614 + $621);
    $623 = Math_fround(HEAPF32[$515>>2]);
    $624 = Math_fround($616 + $623);
    $625 = Math_fround(HEAPF32[$516>>2]);
    $626 = Math_fround($618 + $625);
    $627 = Math_fround(HEAPF32[$517>>2]);
    $628 = Math_fround($620 + $627);
    $629 = (HEAPF32[tempDoublePtr>>2]=$622,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$positions>>2] = $629;
    $630 = Math_fround(HEAPF32[$537>>2]);
    $631 = Math_fround($609 * $630);
    $632 = Math_fround(HEAPF32[$538>>2]);
    $633 = Math_fround($610 * $632);
    $634 = Math_fround(HEAPF32[$539>>2]);
    $635 = Math_fround($611 * $634);
    $636 = Math_fround(HEAPF32[$540>>2]);
    $637 = Math_fround($612 * $636);
    $638 = Math_fround(HEAPF32[$518>>2]);
    $639 = Math_fround($631 + $638);
    $640 = Math_fround(HEAPF32[$519>>2]);
    $641 = Math_fround($633 + $640);
    $642 = Math_fround(HEAPF32[$520>>2]);
    $643 = Math_fround($635 + $642);
    $644 = Math_fround(HEAPF32[$521>>2]);
    $645 = Math_fround($637 + $644);
    $646 = (HEAPF32[tempDoublePtr>>2]=$641,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$519>>2] = $646;
    $647 = Math_fround(HEAPF32[$541>>2]);
    $648 = Math_fround($609 * $647);
    $649 = Math_fround(HEAPF32[$542>>2]);
    $650 = Math_fround($610 * $649);
    $651 = Math_fround(HEAPF32[$543>>2]);
    $652 = Math_fround($611 * $651);
    $653 = Math_fround(HEAPF32[$544>>2]);
    $654 = Math_fround($612 * $653);
    $655 = Math_fround(HEAPF32[$522>>2]);
    $656 = Math_fround($648 + $655);
    $657 = Math_fround(HEAPF32[$523>>2]);
    $658 = Math_fround($650 + $657);
    $659 = Math_fround(HEAPF32[$524>>2]);
    $660 = Math_fround($652 + $659);
    $661 = Math_fround(HEAPF32[$525>>2]);
    $662 = Math_fround($654 + $661);
    $663 = (HEAPF32[tempDoublePtr>>2]=$660,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$524>>2] = $663;
    HEAPF32[$515>>2] = $639;
    HEAPF32[$516>>2] = $656;
    $664 = Math_fround(HEAPF32[$529>>2]);
    HEAPF32[$517>>2] = $664;
    HEAPF32[$518>>2] = $624;
    HEAPF32[$520>>2] = $658;
    $665 = Math_fround(HEAPF32[$526>>2]);
    HEAPF32[$521>>2] = $665;
    HEAPF32[$522>>2] = $626;
    HEAPF32[$523>>2] = $643;
    $666 = Math_fround(HEAPF32[$527>>2]);
    HEAPF32[$525>>2] = $666;
    HEAPF32[$529>>2] = $628;
    HEAPF32[$526>>2] = $645;
    HEAPF32[$527>>2] = $662;
    HEAPF32[$pIt$067>>2] = $622;
    $667 = Math_fround(HEAPF32[$515>>2]);
    HEAPF32[$546>>2] = $667;
    $668 = Math_fround(HEAPF32[$516>>2]);
    HEAPF32[$548>>2] = $668;
    $669 = Math_fround(HEAPF32[$517>>2]);
    HEAPF32[$550>>2] = $669;
    $670 = Math_fround(HEAPF32[$518>>2]);
    HEAPF32[$556>>2] = $670;
    $671 = Math_fround(HEAPF32[$519>>2]);
    HEAPF32[$558>>2] = $671;
    $672 = Math_fround(HEAPF32[$520>>2]);
    HEAPF32[$560>>2] = $672;
    $673 = Math_fround(HEAPF32[$521>>2]);
    HEAPF32[$562>>2] = $673;
    $674 = Math_fround(HEAPF32[$522>>2]);
    HEAPF32[$568>>2] = $674;
    $675 = Math_fround(HEAPF32[$523>>2]);
    HEAPF32[$570>>2] = $675;
    $676 = Math_fround(HEAPF32[$524>>2]);
    HEAPF32[$572>>2] = $676;
    $677 = Math_fround(HEAPF32[$525>>2]);
    HEAPF32[$574>>2] = $677;
    $678 = Math_fround(HEAPF32[$529>>2]);
    HEAPF32[$580>>2] = $678;
    $679 = Math_fround(HEAPF32[$526>>2]);
    HEAPF32[$582>>2] = $679;
    $680 = Math_fround(HEAPF32[$527>>2]);
    HEAPF32[$584>>2] = $680;
    $681 = Math_fround(HEAPF32[$528>>2]);
    HEAPF32[$586>>2] = $681;
   }
   $682 = (($pIt$067) + 64|0);
   $683 = ($682>>>0)<($513>>>0);
   if ($683) {
    $pIt$067 = $682;
   } else {
    break;
   }
  }
 }
 $684 = HEAP32[$5>>2]|0;
 $685 = ($$0$i|0)==(0|0);
 if ($685) {
  STACKTOP = sp;return;
 }
 $686 = (($$0$i) + -4|0);
 $687 = HEAP32[$686>>2]|0;
 $688 = $687 | -2147483648;
 HEAP32[$686>>2] = $688;
 $689 = (($684) + 12|0);
 $690 = HEAP32[$689>>2]|0;
 $691 = ($690|0)==(0|0);
 if ($691) {
  STACKTOP = sp;return;
 }
 $692 = (($684) + 8|0);
 $694 = $690;
 while(1) {
  $693 = (($694) + 4|0);
  $695 = HEAP32[$693>>2]|0;
  $696 = ($695|0)<(0);
  if (!($696)) {
   label = 21;
   break;
  }
  HEAP32[$692>>2] = $694;
  $697 = HEAP32[$694>>2]|0;
  HEAP32[$689>>2] = $697;
  $698 = ($697|0)==(0|0);
  if ($698) {
   label = 21;
   break;
  } else {
   $694 = $697;
  }
 }
 if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE13computeBoundsEv($this) {
 $this = $this|0;
 var $$lcssa = Math_fround(0), $$lcssa18 = Math_fround(0), $$lcssa19 = Math_fround(0), $$lcssa20 = Math_fround(0), $$lcssa21 = Math_fround(0), $$lcssa22 = Math_fround(0), $$lcssa23 = Math_fround(0), $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0;
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $curIt$024 = 0, $not$w$i$i$i = 0, $not$x$i$i$i = 0, $not$y$i$i$i = 0, $not$z$i$i$i = 0, $prevIt$025 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) + ($4<<4)|0);
 $6 = HEAP32[478344>>2]|0;
 $7 = HEAP32[((478344 + 4|0))>>2]|0;
 $8 = HEAP32[((478344 + 8|0))>>2]|0;
 $9 = HEAP32[((478344 + 12|0))>>2]|0;
 $10 = (HEAP32[tempDoublePtr>>2]=$6,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $11 = Math_fround(-$10);
 $12 = (HEAP32[tempDoublePtr>>2]=$7,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $13 = Math_fround(-$12);
 $14 = (HEAP32[tempDoublePtr>>2]=$8,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $15 = Math_fround(-$14);
 $16 = (HEAP32[tempDoublePtr>>2]=$9,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $17 = Math_fround(-$16);
 $18 = ($3>>>0)<($5>>>0);
 if ($18) {
  $19 = (($1) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $30 = Math_fround(3.40282346638528859812E+38);$34 = Math_fround(3.40282346638528859812E+38);$38 = Math_fround(3.40282346638528859812E+38);$42 = Math_fround(-3.40282346638528859812E+38);$45 = Math_fround(-3.40282346638528859812E+38);$48 = Math_fround(-3.40282346638528859812E+38);$51 = Math_fround(-3.40282346638528859812E+38);$curIt$024 = $3;$prevIt$025 = $20;
  while(1) {
   $21 = HEAP32[$curIt$024>>2]|0;
   $22 = (($curIt$024) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($curIt$024) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($curIt$024) + 12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (HEAP32[tempDoublePtr>>2]=$21,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $29 = $28 < $30;
   $31 = $29 ? $28 : $30;
   $32 = (HEAP32[tempDoublePtr>>2]=$23,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $33 = $32 < $34;
   $35 = $33 ? $32 : $34;
   $36 = (HEAP32[tempDoublePtr>>2]=$25,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $37 = $36 < $38;
   $39 = $37 ? $36 : $38;
   $40 = (HEAP32[tempDoublePtr>>2]=$27,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $41 = $42 < $28;
   $43 = $41 ? $28 : $42;
   $44 = $45 < $32;
   $46 = $44 ? $32 : $45;
   $47 = $48 < $36;
   $49 = $47 ? $36 : $48;
   $50 = $51 < $40;
   $52 = $50 ? $40 : $51;
   $not$x$i$i$i = $28 > $11;
   $not$y$i$i$i = $32 > $13;
   $not$z$i$i$i = $36 > $15;
   $not$w$i$i$i = $40 > $17;
   $53 = HEAP32[$prevIt$025>>2]|0;
   $54 = $53 ^ $21;
   $55 = (($prevIt$025) + 4|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = $56 ^ $23;
   $58 = (($prevIt$025) + 8|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 ^ $25;
   $61 = (($prevIt$025) + 12|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = $62 ^ $27;
   $64 = $not$x$i$i$i ? $54 : 0;
   $65 = $not$y$i$i$i ? $57 : 0;
   $66 = $not$z$i$i$i ? $60 : 0;
   $67 = $not$w$i$i$i ? $63 : 0;
   $68 = $64 ^ $21;
   $69 = $65 ^ $23;
   $70 = $66 ^ $25;
   $71 = $67 ^ $27;
   HEAP32[$curIt$024>>2] = $68;
   HEAP32[$22>>2] = $69;
   HEAP32[$24>>2] = $70;
   HEAP32[$26>>2] = $71;
   $72 = (($curIt$024) + 16|0);
   $73 = (($prevIt$025) + 16|0);
   $74 = ($72>>>0)<($5>>>0);
   if ($74) {
    $30 = $31;$34 = $35;$38 = $39;$42 = $43;$45 = $46;$48 = $49;$51 = $52;$curIt$024 = $72;$prevIt$025 = $73;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$0>>2]|0;
  $$lcssa = $39;$$lcssa18 = $35;$$lcssa19 = $31;$$lcssa20 = $52;$$lcssa21 = $49;$$lcssa22 = $46;$$lcssa23 = $43;$76 = $$pre;
 } else {
  $$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa18 = Math_fround(3.40282346638528859812E+38);$$lcssa19 = Math_fround(3.40282346638528859812E+38);$$lcssa20 = Math_fround(-3.40282346638528859812E+38);$$lcssa21 = Math_fround(-3.40282346638528859812E+38);$$lcssa22 = Math_fround(-3.40282346638528859812E+38);$$lcssa23 = Math_fround(-3.40282346638528859812E+38);$76 = $1;
 }
 $75 = (($76) + 12|0);
 $77 = Math_fround(HEAPF32[$75>>2]);
 $78 = (($76) + 16|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($76) + 20|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($76) + 24|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($76) + 28|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($76) + 32|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($76) + 36|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 HEAPF32[$75>>2] = $$lcssa19;
 HEAPF32[$78>>2] = $$lcssa18;
 HEAPF32[$80>>2] = $$lcssa;
 HEAPF32[$82>>2] = $$lcssa23;
 HEAPF32[$84>>2] = $$lcssa22;
 HEAPF32[$86>>2] = $$lcssa21;
 HEAPF32[$88>>2] = $$lcssa20;
 $90 = HEAP32[$0>>2]|0;
 $91 = (($90) + 36|0);
 HEAPF32[$91>>2] = $77;
 $92 = (($90) + 40|0);
 HEAPF32[$92>>2] = $79;
 $93 = (($90) + 44|0);
 HEAPF32[$93>>2] = $81;
 $94 = (($90) + 48|0);
 HEAPF32[$94>>2] = $83;
 $95 = (($90) + 52|0);
 HEAPF32[$95>>2] = $85;
 $96 = (($90) + 56|0);
 HEAPF32[$96>>2] = $87;
 $97 = (($90) + 60|0);
 HEAPF32[$97>>2] = $89;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE17buildAccelerationEv($this) {
 $this = $this|0;
 var $$0 = 0, $$014$i = 0, $$014$i10 = 0, $$in = Math_fround(0), $$in$i = 0, $$in$i2 = 0, $$in105 = Math_fround(0), $$in106 = Math_fround(0), $$in107 = Math_fround(0), $$in108 = Math_fround(0), $$in109 = Math_fround(0), $$in15$i = 0, $$in15$i3 = 0, $$in16$i = 0, $$in16$i4 = 0, $$in17$i = 0, $$in17$i5 = 0, $$in18$i = 0, $$in18$i6 = 0, $$in19$i = 0;
 var $$in19$i7 = 0, $$in20$i = 0, $$in20$i8 = 0, $$in21$i = 0, $$in21$i9 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0;
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0;
 var $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0;
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = Math_fround(0);
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = 0, $98 = Math_fround(0), $99 = 0, $coneIt$06$i = 0, $coneMask$03$i = 0, $gridIt$02$i = 0, $sphereIt$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 424|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 432|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 152|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + ($5<<4)|0);
 $7 = ($5|0)==(0);
 if ($7) {
  $342 = -8388609;$343 = -8388609;$344 = -8388609;$345 = -8388609;$346 = 2139095039;$347 = 2139095039;$348 = 2139095039;$349 = 2139095039;
 } else {
  $$014$i = $1;$$in$i = -8388609;$$in15$i = -8388609;$$in16$i = -8388609;$$in17$i = -8388609;$$in18$i = 2139095039;$$in19$i = 2139095039;$$in20$i = 2139095039;$$in21$i = 2139095039;
  while(1) {
   $8 = (HEAP32[tempDoublePtr>>2]=$$in21$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $9 = (HEAP32[tempDoublePtr>>2]=$$in20$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $10 = (HEAP32[tempDoublePtr>>2]=$$in19$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $11 = (HEAP32[tempDoublePtr>>2]=$$in18$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $12 = (HEAP32[tempDoublePtr>>2]=$$in17$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $13 = (HEAP32[tempDoublePtr>>2]=$$in16$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $14 = (HEAP32[tempDoublePtr>>2]=$$in15$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $15 = (HEAP32[tempDoublePtr>>2]=$$in$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $16 = Math_fround(HEAPF32[$$014$i>>2]);
   $17 = (($$014$i) + 4|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = (($$014$i) + 8|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = (($$014$i) + 12|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = Math_fround($16 - $22);
   $24 = Math_fround($18 - $22);
   $25 = Math_fround($20 - $22);
   $26 = Math_fround($22 - $22);
   $27 = $23 < $8;
   $28 = $27 ? $23 : $8;
   $29 = $24 < $9;
   $30 = $29 ? $24 : $9;
   $31 = $25 < $10;
   $32 = $31 ? $25 : $10;
   $33 = $26 < $11;
   $34 = $33 ? $26 : $11;
   $35 = (HEAPF32[tempDoublePtr>>2]=$28,HEAP32[tempDoublePtr>>2]|0);
   $36 = (HEAPF32[tempDoublePtr>>2]=$30,HEAP32[tempDoublePtr>>2]|0);
   $37 = (HEAPF32[tempDoublePtr>>2]=$32,HEAP32[tempDoublePtr>>2]|0);
   $38 = (HEAPF32[tempDoublePtr>>2]=$34,HEAP32[tempDoublePtr>>2]|0);
   $39 = Math_fround($16 + $22);
   $40 = Math_fround($18 + $22);
   $41 = Math_fround($20 + $22);
   $42 = Math_fround($22 + $22);
   $43 = $12 < $39;
   $44 = $43 ? $39 : $12;
   $45 = $13 < $40;
   $46 = $45 ? $40 : $13;
   $47 = $14 < $41;
   $48 = $47 ? $41 : $14;
   $49 = $15 < $42;
   $50 = $49 ? $42 : $15;
   $51 = (HEAPF32[tempDoublePtr>>2]=$44,HEAP32[tempDoublePtr>>2]|0);
   $52 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
   $53 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
   $54 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
   $55 = (($$014$i) + 16|0);
   $56 = ($55|0)==($6|0);
   if ($56) {
    $342 = $54;$343 = $53;$344 = $52;$345 = $51;$346 = $38;$347 = $37;$348 = $36;$349 = $35;
    break;
   } else {
    $$014$i = $55;$$in$i = $54;$$in15$i = $53;$$in16$i = $52;$$in17$i = $51;$$in18$i = $38;$$in19$i = $37;$$in20$i = $36;$$in21$i = $35;
   }
  }
 }
 $57 = (($3) + 12|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($3) + 16|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($3) + 20|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($3) + 24|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (HEAPF32[tempDoublePtr>>2]=$64,HEAP32[tempDoublePtr>>2]|0);
 $66 = (($3) + 28|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($3) + 32|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($3) + 36|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($3) + 212|0);
 $73 = HEAP8[$72>>0]|0;
 $74 = ($73<<24>>24)==(0);
 if ($74) {
  $$in = $71;$$in105 = $69;$$in106 = $67;$$in107 = $62;$$in108 = $60;$$in109 = $58;$158 = $349;$162 = $348;$166 = $347;$170 = $346;$172 = $65;$176 = $65;$178 = $345;$182 = $344;$186 = $343;$190 = $342;
 } else {
  $75 = (($this) + 416|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($76) + ($5<<4)|0);
  if ($7) {
   $350 = $342;$351 = $343;$352 = $344;$353 = $345;$354 = $346;$355 = $347;$356 = $348;$357 = $349;
  } else {
   $$014$i10 = $76;$$in$i2 = $342;$$in15$i3 = $343;$$in16$i4 = $344;$$in17$i5 = $345;$$in18$i6 = $346;$$in19$i7 = $347;$$in20$i8 = $348;$$in21$i9 = $349;
   while(1) {
    $78 = (HEAP32[tempDoublePtr>>2]=$$in21$i9,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $79 = (HEAP32[tempDoublePtr>>2]=$$in20$i8,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $80 = (HEAP32[tempDoublePtr>>2]=$$in19$i7,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $81 = (HEAP32[tempDoublePtr>>2]=$$in18$i6,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $82 = (HEAP32[tempDoublePtr>>2]=$$in17$i5,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $83 = (HEAP32[tempDoublePtr>>2]=$$in16$i4,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $84 = (HEAP32[tempDoublePtr>>2]=$$in15$i3,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $85 = (HEAP32[tempDoublePtr>>2]=$$in$i2,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $86 = Math_fround(HEAPF32[$$014$i10>>2]);
    $87 = (($$014$i10) + 4|0);
    $88 = Math_fround(HEAPF32[$87>>2]);
    $89 = (($$014$i10) + 8|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = (($$014$i10) + 12|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = Math_fround($86 - $92);
    $94 = Math_fround($88 - $92);
    $95 = Math_fround($90 - $92);
    $96 = Math_fround($92 - $92);
    $97 = $93 < $78;
    $98 = $97 ? $93 : $78;
    $99 = $94 < $79;
    $100 = $99 ? $94 : $79;
    $101 = $95 < $80;
    $102 = $101 ? $95 : $80;
    $103 = $96 < $81;
    $104 = $103 ? $96 : $81;
    $105 = (HEAPF32[tempDoublePtr>>2]=$98,HEAP32[tempDoublePtr>>2]|0);
    $106 = (HEAPF32[tempDoublePtr>>2]=$100,HEAP32[tempDoublePtr>>2]|0);
    $107 = (HEAPF32[tempDoublePtr>>2]=$102,HEAP32[tempDoublePtr>>2]|0);
    $108 = (HEAPF32[tempDoublePtr>>2]=$104,HEAP32[tempDoublePtr>>2]|0);
    $109 = Math_fround($86 + $92);
    $110 = Math_fround($88 + $92);
    $111 = Math_fround($90 + $92);
    $112 = Math_fround($92 + $92);
    $113 = $82 < $109;
    $114 = $113 ? $109 : $82;
    $115 = $83 < $110;
    $116 = $115 ? $110 : $83;
    $117 = $84 < $111;
    $118 = $117 ? $111 : $84;
    $119 = $85 < $112;
    $120 = $119 ? $112 : $85;
    $121 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
    $122 = (HEAPF32[tempDoublePtr>>2]=$116,HEAP32[tempDoublePtr>>2]|0);
    $123 = (HEAPF32[tempDoublePtr>>2]=$118,HEAP32[tempDoublePtr>>2]|0);
    $124 = (HEAPF32[tempDoublePtr>>2]=$120,HEAP32[tempDoublePtr>>2]|0);
    $125 = (($$014$i10) + 16|0);
    $126 = ($125|0)==($77|0);
    if ($126) {
     $350 = $124;$351 = $123;$352 = $122;$353 = $121;$354 = $108;$355 = $107;$356 = $106;$357 = $105;
     break;
    } else {
     $$014$i10 = $125;$$in$i2 = $124;$$in15$i3 = $123;$$in16$i4 = $122;$$in17$i5 = $121;$$in18$i6 = $108;$$in19$i7 = $107;$$in20$i8 = $106;$$in21$i9 = $105;
    }
   }
  }
  $127 = (($3) + 40|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = (($3) + 44|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = (($3) + 48|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($3) + 52|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($3) + 56|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = (($3) + 60|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = $71 < $58;
  $140 = $139 ? $71 : $58;
  $141 = $128 < $60;
  $142 = $141 ? $128 : $60;
  $143 = $130 < $62;
  $144 = $143 ? $130 : $62;
  $145 = $132 < $64;
  $146 = $145 ? $132 : $64;
  $147 = (HEAPF32[tempDoublePtr>>2]=$146,HEAP32[tempDoublePtr>>2]|0);
  $148 = $64 < $132;
  $149 = $148 ? $132 : $64;
  $150 = $67 < $134;
  $151 = $150 ? $134 : $67;
  $152 = $69 < $136;
  $153 = $152 ? $136 : $69;
  $154 = $71 < $138;
  $155 = $154 ? $138 : $71;
  $156 = (HEAPF32[tempDoublePtr>>2]=$149,HEAP32[tempDoublePtr>>2]|0);
  $$in = $155;$$in105 = $153;$$in106 = $151;$$in107 = $144;$$in108 = $142;$$in109 = $140;$158 = $357;$162 = $356;$166 = $355;$170 = $354;$172 = $147;$176 = $156;$178 = $353;$182 = $352;$186 = $351;$190 = $350;
 }
 $157 = (HEAP32[tempDoublePtr>>2]=$158,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $159 = $157 < $$in109;
 $160 = $159 ? $$in109 : $157;
 $161 = (HEAP32[tempDoublePtr>>2]=$162,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $163 = $161 < $$in108;
 $164 = $163 ? $$in108 : $161;
 $165 = (HEAP32[tempDoublePtr>>2]=$166,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $167 = $165 < $$in107;
 $168 = $167 ? $$in107 : $165;
 $169 = (HEAP32[tempDoublePtr>>2]=$170,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $171 = (HEAP32[tempDoublePtr>>2]=$172,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $173 = $169 < $171;
 $174 = $173 ? $171 : $169;
 $175 = (HEAP32[tempDoublePtr>>2]=$176,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $177 = (HEAP32[tempDoublePtr>>2]=$178,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $179 = $175 < $177;
 $180 = $179 ? $175 : $177;
 $181 = (HEAP32[tempDoublePtr>>2]=$182,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $183 = $$in106 < $181;
 $184 = $183 ? $$in106 : $181;
 $185 = (HEAP32[tempDoublePtr>>2]=$186,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $187 = $$in105 < $185;
 $188 = $187 ? $$in105 : $185;
 $189 = (HEAP32[tempDoublePtr>>2]=$190,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $191 = $$in < $189;
 $192 = $191 ? $$in : $189;
 $193 = Math_fround($180 - $160);
 $194 = Math_fround($188 - $168);
 $195 = Math_fround($192 - $174);
 $196 = (HEAPF32[tempDoublePtr>>2]=$193,HEAP32[tempDoublePtr>>2]|0);
 $197 = (HEAPF32[tempDoublePtr>>2]=$194,HEAP32[tempDoublePtr>>2]|0);
 $198 = (HEAPF32[tempDoublePtr>>2]=$195,HEAP32[tempDoublePtr>>2]|0);
 $199 = HEAP32[478216>>2]|0;
 $200 = HEAP32[((478216 + 8|0))>>2]|0;
 $201 = HEAP32[((478216 + 12|0))>>2]|0;
 $202 = $199 ^ -1;
 $203 = $196 & $202;
 $204 = $200 ^ -1;
 $205 = $197 & $204;
 $206 = $201 ^ -1;
 $207 = $198 & $206;
 $208 = (HEAP32[tempDoublePtr>>2]=$203,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $209 = !($208 >= Math_fround(0.0));
 if ($209) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $210 = HEAP32[((478216 + 4|0))>>2]|0;
 $211 = Math_fround($184 - $164);
 $212 = $210 ^ -1;
 $213 = (HEAPF32[tempDoublePtr>>2]=$211,HEAP32[tempDoublePtr>>2]|0);
 $214 = $213 & $212;
 $215 = (HEAP32[tempDoublePtr>>2]=$214,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $216 = !($215 >= Math_fround(0.0));
 if ($216) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $217 = (HEAP32[tempDoublePtr>>2]=$205,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $218 = !($217 >= Math_fround(0.0));
 if ($218) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $219 = (HEAP32[tempDoublePtr>>2]=$207,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $220 = !($219 >= Math_fround(0.0));
 if ($220) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $221 = (Math_fround(Math_abs((Math_fround($160)))));
 $222 = (Math_fround(Math_abs((Math_fround($164)))));
 $223 = (Math_fround(Math_abs((Math_fround($168)))));
 $224 = (Math_fround(Math_abs((Math_fround($174)))));
 $225 = HEAP32[478328>>2]|0;
 $226 = HEAP32[((478328 + 4|0))>>2]|0;
 $227 = HEAP32[((478328 + 8|0))>>2]|0;
 $228 = HEAP32[((478328 + 12|0))>>2]|0;
 $229 = (HEAP32[tempDoublePtr>>2]=$225,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $230 = Math_fround($221 * $229);
 $231 = (HEAP32[tempDoublePtr>>2]=$226,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $232 = Math_fround($222 * $231);
 $233 = (HEAP32[tempDoublePtr>>2]=$227,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $234 = Math_fround($223 * $233);
 $235 = (HEAP32[tempDoublePtr>>2]=$228,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $236 = Math_fround($224 * $235);
 $237 = Math_fround($160 - $230);
 $238 = Math_fround($164 - $232);
 $239 = Math_fround($168 - $234);
 $240 = Math_fround($174 - $236);
 $241 = (Math_fround(Math_abs((Math_fround($180)))));
 $242 = (Math_fround(Math_abs((Math_fround($184)))));
 $243 = (Math_fround(Math_abs((Math_fround($188)))));
 $244 = (Math_fround(Math_abs((Math_fround($192)))));
 $245 = Math_fround($229 * $241);
 $246 = Math_fround($231 * $242);
 $247 = Math_fround($233 * $243);
 $248 = Math_fround($235 * $244);
 $249 = Math_fround($180 + $245);
 $250 = Math_fround($184 + $246);
 $251 = Math_fround($188 + $247);
 $252 = Math_fround($192 + $248);
 $253 = Math_fround($249 - $237);
 $254 = Math_fround($250 - $238);
 $255 = Math_fround($251 - $239);
 $256 = Math_fround($252 - $240);
 $257 = HEAP32[478152>>2]|0;
 $258 = HEAP32[((478152 + 4|0))>>2]|0;
 $259 = HEAP32[((478152 + 8|0))>>2]|0;
 $260 = HEAP32[((478152 + 12|0))>>2]|0;
 $261 = (HEAP32[tempDoublePtr>>2]=$257,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $262 = $253 < $261;
 $263 = $262 ? $261 : $253;
 $264 = (HEAP32[tempDoublePtr>>2]=$258,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $265 = $254 < $264;
 $266 = $265 ? $264 : $254;
 $267 = (HEAP32[tempDoublePtr>>2]=$259,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $268 = $255 < $267;
 $269 = $268 ? $267 : $255;
 $270 = (HEAP32[tempDoublePtr>>2]=$260,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $271 = $256 < $270;
 $272 = $271 ? $270 : $256;
 $273 = (($this) + 384|0);
 $274 = HEAP32[478312>>2]|0;
 $275 = HEAP32[((478312 + 4|0))>>2]|0;
 $276 = HEAP32[((478312 + 8|0))>>2]|0;
 $277 = HEAP32[((478312 + 12|0))>>2]|0;
 $278 = Math_fround(Math_fround(1.0) / $263);
 $279 = Math_fround(Math_fround(1.0) / $266);
 $280 = Math_fround(Math_fround(1.0) / $269);
 $281 = Math_fround(Math_fround(1.0) / $272);
 $282 = (HEAP32[tempDoublePtr>>2]=$274,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $283 = Math_fround($282 * $278);
 $284 = (HEAP32[tempDoublePtr>>2]=$275,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $285 = Math_fround($284 * $279);
 $286 = (HEAP32[tempDoublePtr>>2]=$276,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $287 = Math_fround($286 * $280);
 $288 = (HEAP32[tempDoublePtr>>2]=$277,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $289 = Math_fround($288 * $281);
 $290 = (HEAPF32[tempDoublePtr>>2]=$283,HEAP32[tempDoublePtr>>2]|0);
 $291 = (HEAPF32[tempDoublePtr>>2]=$285,HEAP32[tempDoublePtr>>2]|0);
 $292 = (HEAPF32[tempDoublePtr>>2]=$287,HEAP32[tempDoublePtr>>2]|0);
 $293 = (HEAPF32[tempDoublePtr>>2]=$289,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$273>>2] = $290;
 $294 = (($this) + 388|0);
 HEAP32[$294>>2] = $291;
 $295 = (($this) + 392|0);
 HEAP32[$295>>2] = $292;
 $296 = (($this) + 396|0);
 HEAP32[$296>>2] = $293;
 $297 = (($this) + 400|0);
 $298 = Math_fround($237 * $283);
 $299 = Math_fround(-$298);
 $300 = Math_fround($238 * $285);
 $301 = Math_fround(-$300);
 $302 = Math_fround($239 * $287);
 $303 = Math_fround(-$302);
 $304 = (HEAPF32[tempDoublePtr>>2]=$299,HEAP32[tempDoublePtr>>2]|0);
 $305 = (HEAPF32[tempDoublePtr>>2]=$301,HEAP32[tempDoublePtr>>2]|0);
 $306 = (HEAPF32[tempDoublePtr>>2]=$303,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$297>>2] = $304;
 $307 = (($this) + 404|0);
 HEAP32[$307>>2] = $305;
 $308 = (($this) + 408|0);
 HEAP32[$308>>2] = $306;
 $309 = (($this) + 412|0);
 HEAPF32[$309>>2] = Math_fround(1.0);
 _memset(($this|0),0,192)|0;
 $310 = HEAP32[$2>>2]|0;
 $311 = (($310) + 212|0);
 $312 = HEAP8[$311>>0]|0;
 $313 = ($312<<24>>24)==(0);
 if (!($313)) {
  $314 = (($this) + 416|0);
  $315 = HEAP32[$314>>2]|0;
  __ZN5physx5cloth11SwCollisionI8Scalar4fE23buildSphereAccelerationEPKNS0_10SphereDataE($this,$315);
 }
 $316 = HEAP32[$0>>2]|0;
 __ZN5physx5cloth11SwCollisionI8Scalar4fE23buildSphereAccelerationEPKNS0_10SphereDataE($this,$316);
 $317 = (($this) + 192|0);
 _memset(($317|0),0,192)|0;
 $318 = (($this) + 428|0);
 $319 = HEAP32[$318>>2]|0;
 $320 = HEAP32[$2>>2]|0;
 $321 = (($320) + 160|0);
 $322 = HEAP32[$321>>2]|0;
 $323 = (($319) + (($322*48)|0)|0);
 $324 = ($322|0)==(0);
 if ($324) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $325 = (($this) + 192|0);
 $coneIt$06$i = $319;$coneMask$03$i = 1;
 while(1) {
  $326 = (($coneIt$06$i) + 12|0);
  $327 = Math_fround(HEAPF32[$326>>2]);
  $328 = $327 == Math_fround(0.0);
  if (!($328)) {
   $329 = (($coneIt$06$i) + 44|0);
   $330 = HEAP32[$329>>2]|0;
   $gridIt$02$i = $325;$sphereIt$01$i = $this;
   while(1) {
    $331 = HEAP32[$sphereIt$01$i>>2]|0;
    $332 = $331 & $330;
    $333 = ($332|0)==(0);
    if (!($333)) {
     $334 = HEAP32[$gridIt$02$i>>2]|0;
     $335 = $334 | $coneMask$03$i;
     HEAP32[$gridIt$02$i>>2] = $335;
    }
    $336 = (($sphereIt$01$i) + 4|0);
    $337 = (($gridIt$02$i) + 4|0);
    $338 = ($336|0)==($317|0);
    if ($338) {
     break;
    } else {
     $gridIt$02$i = $337;$sphereIt$01$i = $336;
    }
   }
  }
  $339 = (($coneIt$06$i) + 48|0);
  $340 = $coneMask$03$i << 1;
  $341 = ($339|0)==($323|0);
  if ($341) {
   $$0 = 1;
   break;
  } else {
   $coneIt$06$i = $339;$coneMask$03$i = $340;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE26collideContinuousParticlesEv($this) {
 $this = $this|0;
 var $$$i = 0, $$pre = Math_fround(0), $$pre158 = Math_fround(0), $$pre159 = Math_fround(0), $$pre160 = Math_fround(0), $$pre161 = Math_fround(0), $$pre162 = Math_fround(0), $$pre163 = Math_fround(0), $$pre164 = Math_fround(0), $$pre165 = Math_fround(0), $$pre166 = Math_fround(0), $$pre167 = Math_fround(0), $$pre168 = Math_fround(0), $$pre169 = Math_fround(0), $$pre170 = Math_fround(0), $$pre171 = Math_fround(0), $$pre172 = Math_fround(0), $$pre173 = Math_fround(0), $$pre174 = Math_fround(0), $0 = 0;
 var $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0);
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0);
 var $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0);
 var $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0);
 var $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0);
 var $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0);
 var $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0);
 var $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0);
 var $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0);
 var $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0);
 var $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0);
 var $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0);
 var $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0);
 var $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0);
 var $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0);
 var $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0);
 var $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $accum = 0, $brmerge$i = 0, $brmerge1$i = 0;
 var $curIt$0152 = 0, $curPos = 0, $frictionImpulse = 0, $frictionScale = 0, $invNumCollisions = 0, $mask = 0, $not$w$i$i$i = 0, $not$x$i$i$i = 0, $not$y$i$i$i = 0, $not$z$i$i$i = 0, $prevIt$0154 = 0, $prevPos = 0, $sphereMask = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $curPos = sp + 288|0;
 $prevPos = sp;
 $frictionScale = sp + 64|0;
 $accum = sp + 80|0;
 $sphereMask = sp + 192|0;
 $mask = sp + 208|0;
 $invNumCollisions = sp + 224|0;
 $frictionImpulse = sp + 240|0;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 220|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $3 > Math_fround(0.0);
 $5 = (($1) + 216|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $6 > Math_fround(0.0);
 HEAPF32[$frictionScale>>2] = $6;
 $8 = (($frictionScale) + 4|0);
 HEAPF32[$8>>2] = $6;
 $9 = (($frictionScale) + 8|0);
 HEAPF32[$9>>2] = $6;
 $10 = (($frictionScale) + 12|0);
 HEAPF32[$10>>2] = $6;
 $11 = (($1) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$1>>2]|0;
 $14 = $13 << 2;
 $15 = (($12) + ($14<<2)|0);
 $16 = ($14|0)>(0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = (($1) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($prevPos) + 4|0);
 $20 = (($prevPos) + 8|0);
 $21 = (($prevPos) + 12|0);
 $22 = (($prevPos) + 16|0);
 $23 = (($prevPos) + 20|0);
 $24 = (($prevPos) + 24|0);
 $25 = (($prevPos) + 28|0);
 $26 = (($prevPos) + 32|0);
 $27 = (($prevPos) + 36|0);
 $28 = (($prevPos) + 40|0);
 $29 = (($prevPos) + 44|0);
 $30 = (($prevPos) + 52|0);
 $31 = (($prevPos) + 56|0);
 $32 = (($prevPos) + 60|0);
 $33 = (($prevPos) + 48|0);
 $34 = (($curPos) + 4|0);
 $35 = (($curPos) + 8|0);
 $36 = (($curPos) + 12|0);
 $37 = (($curPos) + 16|0);
 $38 = (($curPos) + 20|0);
 $39 = (($curPos) + 24|0);
 $40 = (($curPos) + 28|0);
 $41 = (($curPos) + 32|0);
 $42 = (($curPos) + 36|0);
 $43 = (($curPos) + 40|0);
 $44 = (($curPos) + 44|0);
 $45 = (($curPos) + 48|0);
 $46 = (($curPos) + 52|0);
 $47 = (($curPos) + 56|0);
 $48 = (($curPos) + 60|0);
 $49 = (($accum) + 96|0);
 $50 = (($accum) + 100|0);
 $51 = (($accum) + 104|0);
 $52 = (($accum) + 108|0);
 $53 = (($mask) + 4|0);
 $54 = (($mask) + 8|0);
 $55 = (($mask) + 12|0);
 $56 = (($invNumCollisions) + 4|0);
 $57 = (($invNumCollisions) + 8|0);
 $58 = (($invNumCollisions) + 12|0);
 $59 = (($accum) + 16|0);
 $60 = (($accum) + 32|0);
 $61 = (($accum) + 48|0);
 $62 = (($accum) + 64|0);
 $63 = (($accum) + 80|0);
 $64 = (($frictionImpulse) + 4|0);
 $65 = (($frictionImpulse) + 8|0);
 $66 = (($frictionImpulse) + 12|0);
 $67 = (($frictionImpulse) + 16|0);
 $68 = (($frictionImpulse) + 20|0);
 $69 = (($frictionImpulse) + 24|0);
 $70 = (($frictionImpulse) + 28|0);
 $71 = (($frictionImpulse) + 32|0);
 $72 = (($frictionImpulse) + 36|0);
 $73 = (($frictionImpulse) + 40|0);
 $74 = (($frictionImpulse) + 44|0);
 $75 = (($accum) + 4|0);
 $76 = (($accum) + 8|0);
 $77 = (($accum) + 12|0);
 $78 = (($accum) + 16|0);
 $79 = (($accum) + 20|0);
 $80 = (($accum) + 24|0);
 $81 = (($accum) + 28|0);
 $82 = (($accum) + 32|0);
 $83 = (($accum) + 36|0);
 $84 = (($accum) + 40|0);
 $85 = (($accum) + 44|0);
 $curIt$0152 = $12;$prevIt$0154 = $18;
 while(1) {
  $86 = Math_fround(HEAPF32[$prevIt$0154>>2]);
  $87 = (($prevIt$0154) + 4|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (($prevIt$0154) + 8|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = (($prevIt$0154) + 12|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = (HEAPF32[tempDoublePtr>>2]=$86,HEAP32[tempDoublePtr>>2]|0);
  $94 = (HEAPF32[tempDoublePtr>>2]=$88,HEAP32[tempDoublePtr>>2]|0);
  $95 = (HEAPF32[tempDoublePtr>>2]=$90,HEAP32[tempDoublePtr>>2]|0);
  $96 = (HEAPF32[tempDoublePtr>>2]=$92,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$prevPos>>2] = $93;
  HEAP32[$19>>2] = $94;
  HEAP32[$20>>2] = $95;
  HEAP32[$21>>2] = $96;
  $97 = (($prevIt$0154) + 16|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($prevIt$0154) + 20|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($prevIt$0154) + 24|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = (($prevIt$0154) + 28|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = (HEAPF32[tempDoublePtr>>2]=$98,HEAP32[tempDoublePtr>>2]|0);
  $106 = (HEAPF32[tempDoublePtr>>2]=$100,HEAP32[tempDoublePtr>>2]|0);
  $107 = (HEAPF32[tempDoublePtr>>2]=$102,HEAP32[tempDoublePtr>>2]|0);
  $108 = (HEAPF32[tempDoublePtr>>2]=$104,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$22>>2] = $105;
  HEAP32[$23>>2] = $106;
  HEAP32[$24>>2] = $107;
  HEAP32[$25>>2] = $108;
  $109 = (($prevIt$0154) + 32|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = (($prevIt$0154) + 36|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($prevIt$0154) + 40|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = (($prevIt$0154) + 44|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = (HEAPF32[tempDoublePtr>>2]=$110,HEAP32[tempDoublePtr>>2]|0);
  $118 = (HEAPF32[tempDoublePtr>>2]=$112,HEAP32[tempDoublePtr>>2]|0);
  $119 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
  $120 = (HEAPF32[tempDoublePtr>>2]=$116,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$26>>2] = $117;
  HEAP32[$27>>2] = $118;
  HEAP32[$28>>2] = $119;
  HEAP32[$29>>2] = $120;
  $121 = (($prevIt$0154) + 48|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = (($prevIt$0154) + 52|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = (($prevIt$0154) + 56|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = (($prevIt$0154) + 60|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = (HEAPF32[tempDoublePtr>>2]=$128,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$32>>2] = $129;
  HEAPF32[$19>>2] = $98;
  HEAPF32[$20>>2] = $110;
  HEAPF32[$21>>2] = $122;
  HEAPF32[$22>>2] = $88;
  HEAPF32[$24>>2] = $112;
  HEAPF32[$25>>2] = $124;
  HEAPF32[$26>>2] = $90;
  HEAPF32[$27>>2] = $102;
  HEAPF32[$29>>2] = $126;
  HEAPF32[$33>>2] = $92;
  HEAPF32[$30>>2] = $104;
  HEAPF32[$31>>2] = $116;
  $130 = Math_fround(HEAPF32[$curIt$0152>>2]);
  $131 = (($curIt$0152) + 4|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($curIt$0152) + 8|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($curIt$0152) + 12|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = (HEAPF32[tempDoublePtr>>2]=$130,HEAP32[tempDoublePtr>>2]|0);
  $138 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
  $139 = (HEAPF32[tempDoublePtr>>2]=$134,HEAP32[tempDoublePtr>>2]|0);
  $140 = (HEAPF32[tempDoublePtr>>2]=$136,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$curPos>>2] = $137;
  HEAP32[$34>>2] = $138;
  HEAP32[$35>>2] = $139;
  HEAP32[$36>>2] = $140;
  $141 = (($curIt$0152) + 16|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($curIt$0152) + 20|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = (($curIt$0152) + 24|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($curIt$0152) + 28|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = (HEAPF32[tempDoublePtr>>2]=$142,HEAP32[tempDoublePtr>>2]|0);
  $150 = (HEAPF32[tempDoublePtr>>2]=$144,HEAP32[tempDoublePtr>>2]|0);
  $151 = (HEAPF32[tempDoublePtr>>2]=$146,HEAP32[tempDoublePtr>>2]|0);
  $152 = (HEAPF32[tempDoublePtr>>2]=$148,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$37>>2] = $149;
  HEAP32[$38>>2] = $150;
  HEAP32[$39>>2] = $151;
  HEAP32[$40>>2] = $152;
  $153 = (($curIt$0152) + 32|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = (($curIt$0152) + 36|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = (($curIt$0152) + 40|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = (($curIt$0152) + 44|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = (HEAPF32[tempDoublePtr>>2]=$154,HEAP32[tempDoublePtr>>2]|0);
  $162 = (HEAPF32[tempDoublePtr>>2]=$156,HEAP32[tempDoublePtr>>2]|0);
  $163 = (HEAPF32[tempDoublePtr>>2]=$158,HEAP32[tempDoublePtr>>2]|0);
  $164 = (HEAPF32[tempDoublePtr>>2]=$160,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$41>>2] = $161;
  HEAP32[$42>>2] = $162;
  HEAP32[$43>>2] = $163;
  HEAP32[$44>>2] = $164;
  $165 = (($curIt$0152) + 48|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($curIt$0152) + 52|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($curIt$0152) + 56|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = (($curIt$0152) + 60|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = (HEAPF32[tempDoublePtr>>2]=$172,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$48>>2] = $173;
  HEAPF32[$34>>2] = $142;
  HEAPF32[$35>>2] = $154;
  HEAPF32[$36>>2] = $166;
  HEAPF32[$37>>2] = $132;
  HEAPF32[$39>>2] = $156;
  HEAPF32[$40>>2] = $168;
  HEAPF32[$41>>2] = $134;
  HEAPF32[$42>>2] = $146;
  HEAPF32[$44>>2] = $170;
  HEAPF32[$45>>2] = $136;
  HEAPF32[$46>>2] = $148;
  HEAPF32[$47>>2] = $160;
  dest=$accum+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $174 = HEAP32[478152>>2]|0;
  HEAP32[$49>>2] = $174;
  $175 = HEAP32[((478152 + 4|0))>>2]|0;
  HEAP32[$50>>2] = $175;
  $176 = HEAP32[((478152 + 8|0))>>2]|0;
  HEAP32[$51>>2] = $176;
  $177 = HEAP32[((478152 + 12|0))>>2]|0;
  HEAP32[$52>>2] = $177;
  __ZNK5physx5cloth11SwCollisionI8Scalar4fE12collideConesEPKS2_PS2_RNS3_18ImpulseAccumulatorE($sphereMask,$this,$prevPos,$curPos,$accum);
  __ZNK5physx5cloth11SwCollisionI8Scalar4fE14collideSpheresERKS2_PS4_PS2_RNS3_18ImpulseAccumulatorE($this,$sphereMask,$prevPos,$curPos,$accum);
  $178 = HEAP32[478152>>2]|0;
  $179 = HEAP32[((478152 + 4|0))>>2]|0;
  $180 = HEAP32[((478152 + 8|0))>>2]|0;
  $181 = HEAP32[((478152 + 12|0))>>2]|0;
  $182 = Math_fround(HEAPF32[$49>>2]);
  $183 = (HEAP32[tempDoublePtr>>2]=$178,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $184 = $182 > $183;
  $185 = Math_fround(HEAPF32[$50>>2]);
  $186 = (HEAP32[tempDoublePtr>>2]=$179,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $187 = $185 > $186;
  $188 = Math_fround(HEAPF32[$51>>2]);
  $189 = (HEAP32[tempDoublePtr>>2]=$180,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $190 = $188 > $189;
  $191 = Math_fround(HEAPF32[$52>>2]);
  $192 = (HEAP32[tempDoublePtr>>2]=$181,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $193 = $191 > $192;
  $not$x$i$i$i = $184 ^ 1;
  $194 = $not$x$i$i$i << 31 >> 31;
  $195 = $194 ^ -1;
  $not$y$i$i$i = $187 ^ 1;
  $196 = $not$y$i$i$i << 31 >> 31;
  $197 = $196 ^ -1;
  $not$z$i$i$i = $190 ^ 1;
  $198 = $not$z$i$i$i << 31 >> 31;
  $199 = $198 ^ -1;
  $not$w$i$i$i = $193 ^ 1;
  $200 = $not$w$i$i$i << 31 >> 31;
  $201 = $200 ^ -1;
  HEAP32[$mask>>2] = $195;
  HEAP32[$53>>2] = $197;
  HEAP32[$54>>2] = $199;
  HEAP32[$55>>2] = $201;
  $brmerge$i = $184 | $187;
  $brmerge1$i = $brmerge$i | $190;
  $$$i = $brmerge1$i | $193;
  if ($$$i) {
   $202 = Math_fround(Math_fround(1.0) / $182);
   $203 = Math_fround(Math_fround(1.0) / $185);
   $204 = Math_fround(Math_fround(1.0) / $188);
   $205 = Math_fround(Math_fround(1.0) / $191);
   HEAPF32[$invNumCollisions>>2] = $202;
   HEAPF32[$56>>2] = $203;
   HEAPF32[$57>>2] = $204;
   HEAPF32[$58>>2] = $205;
   if ($7) {
    __ZN12_GLOBAL__N_124calculateFrictionImpulseI8Scalar4fEEvRKT_S4_S4_S4_S4_S4_PS3_S5_S4_S4_S4_PS2_($accum,$59,$60,$61,$62,$63,$curPos,$prevPos,$invNumCollisions,$frictionScale,$mask,$frictionImpulse);
    $206 = Math_fround(HEAPF32[$prevPos>>2]);
    $207 = Math_fround(HEAPF32[$frictionImpulse>>2]);
    $208 = Math_fround($206 - $207);
    $209 = Math_fround(HEAPF32[$19>>2]);
    $210 = Math_fround(HEAPF32[$64>>2]);
    $211 = Math_fround($209 - $210);
    $212 = Math_fround(HEAPF32[$20>>2]);
    $213 = Math_fround(HEAPF32[$65>>2]);
    $214 = Math_fround($212 - $213);
    $215 = Math_fround(HEAPF32[$21>>2]);
    $216 = Math_fround(HEAPF32[$66>>2]);
    $217 = Math_fround($215 - $216);
    $218 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$prevPos>>2] = $218;
    $219 = Math_fround(HEAPF32[$22>>2]);
    $220 = Math_fround(HEAPF32[$67>>2]);
    $221 = Math_fround($219 - $220);
    $222 = Math_fround(HEAPF32[$23>>2]);
    $223 = Math_fround(HEAPF32[$68>>2]);
    $224 = Math_fround($222 - $223);
    $225 = Math_fround(HEAPF32[$24>>2]);
    $226 = Math_fround(HEAPF32[$69>>2]);
    $227 = Math_fround($225 - $226);
    $228 = Math_fround(HEAPF32[$25>>2]);
    $229 = Math_fround(HEAPF32[$70>>2]);
    $230 = Math_fround($228 - $229);
    $231 = (HEAPF32[tempDoublePtr>>2]=$224,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$23>>2] = $231;
    $232 = Math_fround(HEAPF32[$26>>2]);
    $233 = Math_fround(HEAPF32[$71>>2]);
    $234 = Math_fround($232 - $233);
    $235 = Math_fround(HEAPF32[$27>>2]);
    $236 = Math_fround(HEAPF32[$72>>2]);
    $237 = Math_fround($235 - $236);
    $238 = Math_fround(HEAPF32[$28>>2]);
    $239 = Math_fround(HEAPF32[$73>>2]);
    $240 = Math_fround($238 - $239);
    $241 = Math_fround(HEAPF32[$29>>2]);
    $242 = Math_fround(HEAPF32[$74>>2]);
    $243 = Math_fround($241 - $242);
    $244 = (HEAPF32[tempDoublePtr>>2]=$240,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$28>>2] = $244;
    HEAPF32[$19>>2] = $221;
    HEAPF32[$20>>2] = $234;
    $245 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$21>>2] = $245;
    HEAPF32[$22>>2] = $211;
    HEAPF32[$24>>2] = $237;
    $246 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$25>>2] = $246;
    HEAPF32[$26>>2] = $214;
    HEAPF32[$27>>2] = $227;
    $247 = Math_fround(HEAPF32[$31>>2]);
    HEAPF32[$29>>2] = $247;
    HEAPF32[$33>>2] = $217;
    HEAPF32[$30>>2] = $230;
    HEAPF32[$31>>2] = $243;
    HEAPF32[$prevIt$0154>>2] = $208;
    $248 = Math_fround(HEAPF32[$19>>2]);
    HEAPF32[$87>>2] = $248;
    $249 = Math_fround(HEAPF32[$20>>2]);
    HEAPF32[$89>>2] = $249;
    $250 = Math_fround(HEAPF32[$21>>2]);
    HEAPF32[$91>>2] = $250;
    $251 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$97>>2] = $251;
    $252 = Math_fround(HEAPF32[$23>>2]);
    HEAPF32[$99>>2] = $252;
    $253 = Math_fround(HEAPF32[$24>>2]);
    HEAPF32[$101>>2] = $253;
    $254 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$103>>2] = $254;
    $255 = Math_fround(HEAPF32[$26>>2]);
    HEAPF32[$109>>2] = $255;
    $256 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$111>>2] = $256;
    $257 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$113>>2] = $257;
    $258 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$115>>2] = $258;
    $259 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$121>>2] = $259;
    $260 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$123>>2] = $260;
    $261 = Math_fround(HEAPF32[$31>>2]);
    HEAPF32[$125>>2] = $261;
    $262 = Math_fround(HEAPF32[$32>>2]);
    HEAPF32[$127>>2] = $262;
   }
   if ($4) {
    $263 = Math_fround(HEAPF32[$invNumCollisions>>2]);
    $264 = Math_fround($263 * $263);
    $265 = Math_fround(HEAPF32[$56>>2]);
    $266 = Math_fround($265 * $265);
    $267 = Math_fround(HEAPF32[$57>>2]);
    $268 = Math_fround($267 * $267);
    $269 = Math_fround(HEAPF32[$58>>2]);
    $270 = Math_fround($269 * $269);
    $271 = Math_fround(HEAPF32[$accum>>2]);
    $272 = Math_fround($271 * $271);
    $273 = Math_fround(HEAPF32[$75>>2]);
    $274 = Math_fround($273 * $273);
    $275 = Math_fround(HEAPF32[$76>>2]);
    $276 = Math_fround($275 * $275);
    $277 = Math_fround(HEAPF32[$77>>2]);
    $278 = Math_fround($277 * $277);
    $279 = Math_fround(HEAPF32[$78>>2]);
    $280 = Math_fround($279 * $279);
    $281 = Math_fround(HEAPF32[$79>>2]);
    $282 = Math_fround($281 * $281);
    $283 = Math_fround(HEAPF32[$80>>2]);
    $284 = Math_fround($283 * $283);
    $285 = Math_fround(HEAPF32[$81>>2]);
    $286 = Math_fround($285 * $285);
    $287 = Math_fround($272 + $280);
    $288 = Math_fround($274 + $282);
    $289 = Math_fround($276 + $284);
    $290 = Math_fround($278 + $286);
    $291 = Math_fround(HEAPF32[$82>>2]);
    $292 = Math_fround($291 * $291);
    $293 = Math_fround(HEAPF32[$83>>2]);
    $294 = Math_fround($293 * $293);
    $295 = Math_fround(HEAPF32[$84>>2]);
    $296 = Math_fround($295 * $295);
    $297 = Math_fround(HEAPF32[$85>>2]);
    $298 = Math_fround($297 * $297);
    $299 = Math_fround($287 + $292);
    $300 = Math_fround($288 + $294);
    $301 = Math_fround($289 + $296);
    $302 = Math_fround($290 + $298);
    $303 = Math_fround($264 * $299);
    $304 = Math_fround($266 * $300);
    $305 = Math_fround($268 * $301);
    $306 = Math_fround($270 * $302);
    $307 = HEAP32[478248>>2]|0;
    $308 = HEAP32[((478248 + 4|0))>>2]|0;
    $309 = HEAP32[((478248 + 8|0))>>2]|0;
    $310 = HEAP32[((478248 + 12|0))>>2]|0;
    $311 = Math_fround($3 * $303);
    $312 = Math_fround($3 * $304);
    $313 = Math_fround($3 * $305);
    $314 = Math_fround($3 * $306);
    $315 = (HEAP32[tempDoublePtr>>2]=$307,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $316 = Math_fround($311 + $315);
    $317 = (HEAP32[tempDoublePtr>>2]=$308,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $318 = Math_fround($312 + $317);
    $319 = (HEAP32[tempDoublePtr>>2]=$309,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $320 = Math_fround($313 + $319);
    $321 = (HEAP32[tempDoublePtr>>2]=$310,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $322 = Math_fround($314 + $321);
    $323 = Math_fround(Math_fround(1.0) / $316);
    $324 = Math_fround(Math_fround(1.0) / $318);
    $325 = Math_fround(Math_fround(1.0) / $320);
    $326 = Math_fround(Math_fround(1.0) / $322);
    $327 = Math_fround(HEAPF32[$45>>2]);
    $328 = Math_fround($323 * $327);
    $329 = Math_fround(HEAPF32[$46>>2]);
    $330 = Math_fround($324 * $329);
    $331 = Math_fround(HEAPF32[$47>>2]);
    $332 = Math_fround($325 * $331);
    $333 = Math_fround(HEAPF32[$48>>2]);
    $334 = Math_fround($326 * $333);
    $335 = (HEAPF32[tempDoublePtr>>2]=$328,HEAP32[tempDoublePtr>>2]|0);
    $336 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
    $337 = (HEAPF32[tempDoublePtr>>2]=$332,HEAP32[tempDoublePtr>>2]|0);
    $338 = (HEAPF32[tempDoublePtr>>2]=$334,HEAP32[tempDoublePtr>>2]|0);
    $339 = (HEAPF32[tempDoublePtr>>2]=$327,HEAP32[tempDoublePtr>>2]|0);
    $340 = $339 ^ $335;
    $341 = (HEAPF32[tempDoublePtr>>2]=$329,HEAP32[tempDoublePtr>>2]|0);
    $342 = $341 ^ $336;
    $343 = (HEAPF32[tempDoublePtr>>2]=$331,HEAP32[tempDoublePtr>>2]|0);
    $344 = $343 ^ $337;
    $345 = (HEAPF32[tempDoublePtr>>2]=$333,HEAP32[tempDoublePtr>>2]|0);
    $346 = $345 ^ $338;
    $347 = HEAP32[$mask>>2]|0;
    $348 = $347 & $340;
    $349 = HEAP32[$53>>2]|0;
    $350 = $349 & $342;
    $351 = HEAP32[$54>>2]|0;
    $352 = $351 & $344;
    $353 = HEAP32[$55>>2]|0;
    $354 = $353 & $346;
    $355 = $348 ^ $339;
    $356 = $350 ^ $341;
    $357 = $352 ^ $343;
    $358 = $354 ^ $345;
    HEAP32[$45>>2] = $355;
    HEAP32[$46>>2] = $356;
    HEAP32[$47>>2] = $357;
    HEAP32[$48>>2] = $358;
    $359 = (HEAP32[tempDoublePtr>>2]=$355,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $360 = (HEAP32[tempDoublePtr>>2]=$356,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $361 = (HEAP32[tempDoublePtr>>2]=$357,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $364 = $271;$366 = $265;$367 = $273;$369 = $267;$370 = $275;$372 = $269;$373 = $277;$384 = $279;$386 = $281;$388 = $283;$390 = $285;$401 = $291;$403 = $293;$405 = $295;$407 = $297;$417 = $359;$418 = $360;$419 = $361;
   } else {
    $$pre = Math_fround(HEAPF32[$accum>>2]);
    $$pre158 = Math_fround(HEAPF32[$75>>2]);
    $$pre159 = Math_fround(HEAPF32[$56>>2]);
    $$pre160 = Math_fround(HEAPF32[$76>>2]);
    $$pre161 = Math_fround(HEAPF32[$57>>2]);
    $$pre162 = Math_fround(HEAPF32[$77>>2]);
    $$pre163 = Math_fround(HEAPF32[$58>>2]);
    $$pre164 = Math_fround(HEAPF32[$78>>2]);
    $$pre165 = Math_fround(HEAPF32[$79>>2]);
    $$pre166 = Math_fround(HEAPF32[$80>>2]);
    $$pre167 = Math_fround(HEAPF32[$81>>2]);
    $$pre168 = Math_fround(HEAPF32[$82>>2]);
    $$pre169 = Math_fround(HEAPF32[$83>>2]);
    $$pre170 = Math_fround(HEAPF32[$84>>2]);
    $$pre171 = Math_fround(HEAPF32[$85>>2]);
    $$pre172 = Math_fround(HEAPF32[$45>>2]);
    $$pre173 = Math_fround(HEAPF32[$46>>2]);
    $$pre174 = Math_fround(HEAPF32[$47>>2]);
    $364 = $$pre;$366 = $$pre159;$367 = $$pre158;$369 = $$pre161;$370 = $$pre160;$372 = $$pre163;$373 = $$pre162;$384 = $$pre164;$386 = $$pre165;$388 = $$pre166;$390 = $$pre167;$401 = $$pre168;$403 = $$pre169;$405 = $$pre170;$407 = $$pre171;$417 = $$pre172;$418 = $$pre173;$419 = $$pre174;
   }
   $362 = Math_fround(HEAPF32[$invNumCollisions>>2]);
   $363 = Math_fround($364 * $362);
   $365 = Math_fround($367 * $366);
   $368 = Math_fround($370 * $369);
   $371 = Math_fround($373 * $372);
   $374 = Math_fround(HEAPF32[$curPos>>2]);
   $375 = Math_fround($363 + $374);
   $376 = Math_fround(HEAPF32[$34>>2]);
   $377 = Math_fround($365 + $376);
   $378 = Math_fround(HEAPF32[$35>>2]);
   $379 = Math_fround($368 + $378);
   $380 = Math_fround(HEAPF32[$36>>2]);
   $381 = Math_fround($371 + $380);
   $382 = (HEAPF32[tempDoublePtr>>2]=$375,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$curPos>>2] = $382;
   $383 = Math_fround($384 * $362);
   $385 = Math_fround($386 * $366);
   $387 = Math_fround($388 * $369);
   $389 = Math_fround($390 * $372);
   $391 = Math_fround(HEAPF32[$37>>2]);
   $392 = Math_fround($383 + $391);
   $393 = Math_fround(HEAPF32[$38>>2]);
   $394 = Math_fround($385 + $393);
   $395 = Math_fround(HEAPF32[$39>>2]);
   $396 = Math_fround($387 + $395);
   $397 = Math_fround(HEAPF32[$40>>2]);
   $398 = Math_fround($389 + $397);
   $399 = (HEAPF32[tempDoublePtr>>2]=$394,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$38>>2] = $399;
   $400 = Math_fround($401 * $362);
   $402 = Math_fround($403 * $366);
   $404 = Math_fround($405 * $369);
   $406 = Math_fround($407 * $372);
   $408 = Math_fround(HEAPF32[$41>>2]);
   $409 = Math_fround($400 + $408);
   $410 = Math_fround(HEAPF32[$42>>2]);
   $411 = Math_fround($402 + $410);
   $412 = Math_fround(HEAPF32[$43>>2]);
   $413 = Math_fround($404 + $412);
   $414 = Math_fround(HEAPF32[$44>>2]);
   $415 = Math_fround($406 + $414);
   $416 = (HEAPF32[tempDoublePtr>>2]=$413,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$43>>2] = $416;
   HEAPF32[$34>>2] = $392;
   HEAPF32[$35>>2] = $409;
   HEAPF32[$36>>2] = $417;
   HEAPF32[$37>>2] = $377;
   HEAPF32[$39>>2] = $411;
   HEAPF32[$40>>2] = $418;
   HEAPF32[$41>>2] = $379;
   HEAPF32[$42>>2] = $396;
   HEAPF32[$44>>2] = $419;
   HEAPF32[$45>>2] = $381;
   HEAPF32[$46>>2] = $398;
   HEAPF32[$47>>2] = $415;
   HEAPF32[$curIt$0152>>2] = $375;
   $420 = Math_fround(HEAPF32[$34>>2]);
   HEAPF32[$131>>2] = $420;
   $421 = Math_fround(HEAPF32[$35>>2]);
   HEAPF32[$133>>2] = $421;
   $422 = Math_fround(HEAPF32[$36>>2]);
   HEAPF32[$135>>2] = $422;
   $423 = Math_fround(HEAPF32[$37>>2]);
   HEAPF32[$141>>2] = $423;
   $424 = Math_fround(HEAPF32[$38>>2]);
   HEAPF32[$143>>2] = $424;
   $425 = Math_fround(HEAPF32[$39>>2]);
   HEAPF32[$145>>2] = $425;
   $426 = Math_fround(HEAPF32[$40>>2]);
   HEAPF32[$147>>2] = $426;
   $427 = Math_fround(HEAPF32[$41>>2]);
   HEAPF32[$153>>2] = $427;
   $428 = Math_fround(HEAPF32[$42>>2]);
   HEAPF32[$155>>2] = $428;
   $429 = Math_fround(HEAPF32[$43>>2]);
   HEAPF32[$157>>2] = $429;
   $430 = Math_fround(HEAPF32[$44>>2]);
   HEAPF32[$159>>2] = $430;
   $431 = Math_fround(HEAPF32[$45>>2]);
   HEAPF32[$165>>2] = $431;
   $432 = Math_fround(HEAPF32[$46>>2]);
   HEAPF32[$167>>2] = $432;
   $433 = Math_fround(HEAPF32[$47>>2]);
   HEAPF32[$169>>2] = $433;
   $434 = Math_fround(HEAPF32[$48>>2]);
   HEAPF32[$171>>2] = $434;
  }
  $435 = (($curIt$0152) + 64|0);
  $436 = (($prevIt$0154) + 64|0);
  $437 = ($435>>>0)<($15>>>0);
  if ($437) {
   $curIt$0152 = $435;$prevIt$0154 = $436;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE17mergeAccelerationEPj($firstIt) {
 $firstIt = $firstIt|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($firstIt) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$firstIt>>2]|0;
 $3 = $2 & $1;
 HEAP32[$firstIt>>2] = $3;
 $4 = (($firstIt) + 4|0);
 $5 = (($firstIt) + 100|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$4>>2]|0;
 $8 = $7 & $6;
 HEAP32[$4>>2] = $8;
 $9 = (($firstIt) + 8|0);
 $10 = (($firstIt) + 104|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = $12 & $11;
 HEAP32[$9>>2] = $13;
 $14 = (($firstIt) + 12|0);
 $15 = (($firstIt) + 108|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = $17 & $16;
 HEAP32[$14>>2] = $18;
 $19 = (($firstIt) + 16|0);
 $20 = (($firstIt) + 112|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$19>>2]|0;
 $23 = $22 & $21;
 HEAP32[$19>>2] = $23;
 $24 = (($firstIt) + 20|0);
 $25 = (($firstIt) + 116|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$24>>2]|0;
 $28 = $27 & $26;
 HEAP32[$24>>2] = $28;
 $29 = (($firstIt) + 24|0);
 $30 = (($firstIt) + 120|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$29>>2]|0;
 $33 = $32 & $31;
 HEAP32[$29>>2] = $33;
 $34 = (($firstIt) + 28|0);
 $35 = (($firstIt) + 124|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$34>>2]|0;
 $38 = $37 & $36;
 HEAP32[$34>>2] = $38;
 $39 = (($firstIt) + 32|0);
 $40 = (($firstIt) + 128|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$39>>2]|0;
 $43 = $42 & $41;
 HEAP32[$39>>2] = $43;
 $44 = (($firstIt) + 36|0);
 $45 = (($firstIt) + 132|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$44>>2]|0;
 $48 = $47 & $46;
 HEAP32[$44>>2] = $48;
 $49 = (($firstIt) + 40|0);
 $50 = (($firstIt) + 136|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = HEAP32[$49>>2]|0;
 $53 = $52 & $51;
 HEAP32[$49>>2] = $53;
 $54 = (($firstIt) + 44|0);
 $55 = (($firstIt) + 140|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$54>>2]|0;
 $58 = $57 & $56;
 HEAP32[$54>>2] = $58;
 $59 = (($firstIt) + 48|0);
 $60 = (($firstIt) + 144|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$59>>2]|0;
 $63 = $62 & $61;
 HEAP32[$59>>2] = $63;
 $64 = (($firstIt) + 52|0);
 $65 = (($firstIt) + 148|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$64>>2]|0;
 $68 = $67 & $66;
 HEAP32[$64>>2] = $68;
 $69 = (($firstIt) + 56|0);
 $70 = (($firstIt) + 152|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$69>>2]|0;
 $73 = $72 & $71;
 HEAP32[$69>>2] = $73;
 $74 = (($firstIt) + 60|0);
 $75 = (($firstIt) + 156|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = HEAP32[$74>>2]|0;
 $78 = $77 & $76;
 HEAP32[$74>>2] = $78;
 $79 = (($firstIt) + 64|0);
 $80 = (($firstIt) + 160|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = HEAP32[$79>>2]|0;
 $83 = $82 & $81;
 HEAP32[$79>>2] = $83;
 $84 = (($firstIt) + 68|0);
 $85 = (($firstIt) + 164|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = HEAP32[$84>>2]|0;
 $88 = $87 & $86;
 HEAP32[$84>>2] = $88;
 $89 = (($firstIt) + 72|0);
 $90 = (($firstIt) + 168|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = HEAP32[$89>>2]|0;
 $93 = $92 & $91;
 HEAP32[$89>>2] = $93;
 $94 = (($firstIt) + 76|0);
 $95 = (($firstIt) + 172|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = HEAP32[$94>>2]|0;
 $98 = $97 & $96;
 HEAP32[$94>>2] = $98;
 $99 = (($firstIt) + 80|0);
 $100 = (($firstIt) + 176|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = HEAP32[$99>>2]|0;
 $103 = $102 & $101;
 HEAP32[$99>>2] = $103;
 $104 = (($firstIt) + 84|0);
 $105 = (($firstIt) + 180|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = HEAP32[$104>>2]|0;
 $108 = $107 & $106;
 HEAP32[$104>>2] = $108;
 $109 = (($firstIt) + 88|0);
 $110 = (($firstIt) + 184|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = HEAP32[$109>>2]|0;
 $113 = $112 & $111;
 HEAP32[$109>>2] = $113;
 $114 = (($firstIt) + 92|0);
 $115 = (($firstIt) + 188|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = HEAP32[$114>>2]|0;
 $118 = $117 & $116;
 HEAP32[$114>>2] = $118;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE16collideParticlesEv($this) {
 $this = $this|0;
 var $$$i = 0, $$pre = Math_fround(0), $$pre159 = Math_fround(0), $$pre160 = Math_fround(0), $$pre161 = Math_fround(0), $$pre162 = Math_fround(0), $$pre163 = Math_fround(0), $$pre164 = Math_fround(0), $$pre165 = Math_fround(0), $$pre166 = Math_fround(0), $$pre167 = Math_fround(0), $$pre168 = Math_fround(0), $$pre169 = Math_fround(0), $$pre170 = Math_fround(0), $$pre171 = Math_fround(0), $$pre172 = Math_fround(0), $$pre173 = Math_fround(0), $$pre174 = Math_fround(0), $$pre175 = Math_fround(0), $0 = 0;
 var $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0);
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0;
 var $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0);
 var $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0);
 var $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0);
 var $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0);
 var $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0);
 var $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0);
 var $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0);
 var $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0);
 var $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0);
 var $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0);
 var $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0);
 var $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0);
 var $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $accum = 0, $brmerge$i = 0, $brmerge1$i = 0;
 var $curPos = 0, $frictionImpulse = 0, $frictionScale = 0, $invNumCollisions = 0, $mask = 0, $not$w$i$i$i = 0, $not$x$i$i$i = 0, $not$y$i$i$i = 0, $not$z$i$i$i = 0, $pIt$0152 = 0, $prevIt$0154 = 0, $prevPos = 0, $sphereMask = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $frictionScale = sp + 336|0;
 $curPos = sp;
 $prevPos = sp + 64|0;
 $accum = sp + 128|0;
 $sphereMask = sp + 240|0;
 $mask = sp + 256|0;
 $invNumCollisions = sp + 272|0;
 $frictionImpulse = sp + 288|0;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 220|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 216|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$frictionScale>>2] = $5;
 $6 = (($frictionScale) + 4|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($frictionScale) + 8|0);
 HEAPF32[$7>>2] = $5;
 $8 = (($frictionScale) + 12|0);
 HEAPF32[$8>>2] = $5;
 $9 = $3 > Math_fround(0.0);
 $10 = $5 > Math_fround(0.0);
 $11 = (($1) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$1>>2]|0;
 $14 = $13 << 2;
 $15 = (($12) + ($14<<2)|0);
 $16 = ($14|0)>(0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = (($1) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($curPos) + 4|0);
 $20 = (($curPos) + 8|0);
 $21 = (($curPos) + 12|0);
 $22 = (($curPos) + 16|0);
 $23 = (($curPos) + 20|0);
 $24 = (($curPos) + 24|0);
 $25 = (($curPos) + 28|0);
 $26 = (($curPos) + 32|0);
 $27 = (($curPos) + 36|0);
 $28 = (($curPos) + 40|0);
 $29 = (($curPos) + 44|0);
 $30 = (($curPos) + 48|0);
 $31 = (($curPos) + 52|0);
 $32 = (($curPos) + 56|0);
 $33 = (($curPos) + 60|0);
 $34 = (($accum) + 96|0);
 $35 = (($accum) + 100|0);
 $36 = (($accum) + 104|0);
 $37 = (($accum) + 108|0);
 $38 = (($mask) + 4|0);
 $39 = (($mask) + 8|0);
 $40 = (($mask) + 12|0);
 $41 = (($invNumCollisions) + 4|0);
 $42 = (($invNumCollisions) + 8|0);
 $43 = (($invNumCollisions) + 12|0);
 $44 = (($prevPos) + 4|0);
 $45 = (($prevPos) + 8|0);
 $46 = (($prevPos) + 12|0);
 $47 = (($prevPos) + 16|0);
 $48 = (($prevPos) + 20|0);
 $49 = (($prevPos) + 24|0);
 $50 = (($prevPos) + 28|0);
 $51 = (($prevPos) + 32|0);
 $52 = (($prevPos) + 36|0);
 $53 = (($prevPos) + 40|0);
 $54 = (($prevPos) + 44|0);
 $55 = (($prevPos) + 52|0);
 $56 = (($prevPos) + 56|0);
 $57 = (($prevPos) + 60|0);
 $58 = (($prevPos) + 48|0);
 $59 = (($accum) + 16|0);
 $60 = (($accum) + 32|0);
 $61 = (($accum) + 48|0);
 $62 = (($accum) + 64|0);
 $63 = (($accum) + 80|0);
 $64 = (($frictionImpulse) + 4|0);
 $65 = (($frictionImpulse) + 8|0);
 $66 = (($frictionImpulse) + 12|0);
 $67 = (($frictionImpulse) + 16|0);
 $68 = (($frictionImpulse) + 20|0);
 $69 = (($frictionImpulse) + 24|0);
 $70 = (($frictionImpulse) + 28|0);
 $71 = (($frictionImpulse) + 32|0);
 $72 = (($frictionImpulse) + 36|0);
 $73 = (($frictionImpulse) + 40|0);
 $74 = (($frictionImpulse) + 44|0);
 $75 = (($accum) + 4|0);
 $76 = (($accum) + 8|0);
 $77 = (($accum) + 12|0);
 $78 = (($accum) + 16|0);
 $79 = (($accum) + 20|0);
 $80 = (($accum) + 24|0);
 $81 = (($accum) + 28|0);
 $82 = (($accum) + 32|0);
 $83 = (($accum) + 36|0);
 $84 = (($accum) + 40|0);
 $85 = (($accum) + 44|0);
 $pIt$0152 = $12;$prevIt$0154 = $18;
 while(1) {
  $86 = Math_fround(HEAPF32[$pIt$0152>>2]);
  $87 = (($pIt$0152) + 4|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (($pIt$0152) + 8|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = (($pIt$0152) + 12|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = (HEAPF32[tempDoublePtr>>2]=$86,HEAP32[tempDoublePtr>>2]|0);
  $94 = (HEAPF32[tempDoublePtr>>2]=$88,HEAP32[tempDoublePtr>>2]|0);
  $95 = (HEAPF32[tempDoublePtr>>2]=$90,HEAP32[tempDoublePtr>>2]|0);
  $96 = (HEAPF32[tempDoublePtr>>2]=$92,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$curPos>>2] = $93;
  HEAP32[$19>>2] = $94;
  HEAP32[$20>>2] = $95;
  HEAP32[$21>>2] = $96;
  $97 = (($pIt$0152) + 16|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($pIt$0152) + 20|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($pIt$0152) + 24|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = (($pIt$0152) + 28|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = (HEAPF32[tempDoublePtr>>2]=$98,HEAP32[tempDoublePtr>>2]|0);
  $106 = (HEAPF32[tempDoublePtr>>2]=$100,HEAP32[tempDoublePtr>>2]|0);
  $107 = (HEAPF32[tempDoublePtr>>2]=$102,HEAP32[tempDoublePtr>>2]|0);
  $108 = (HEAPF32[tempDoublePtr>>2]=$104,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$22>>2] = $105;
  HEAP32[$23>>2] = $106;
  HEAP32[$24>>2] = $107;
  HEAP32[$25>>2] = $108;
  $109 = (($pIt$0152) + 32|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = (($pIt$0152) + 36|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($pIt$0152) + 40|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = (($pIt$0152) + 44|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = (HEAPF32[tempDoublePtr>>2]=$110,HEAP32[tempDoublePtr>>2]|0);
  $118 = (HEAPF32[tempDoublePtr>>2]=$112,HEAP32[tempDoublePtr>>2]|0);
  $119 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
  $120 = (HEAPF32[tempDoublePtr>>2]=$116,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$26>>2] = $117;
  HEAP32[$27>>2] = $118;
  HEAP32[$28>>2] = $119;
  HEAP32[$29>>2] = $120;
  $121 = (($pIt$0152) + 48|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = (($pIt$0152) + 52|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = (($pIt$0152) + 56|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = (($pIt$0152) + 60|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = (HEAPF32[tempDoublePtr>>2]=$128,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$33>>2] = $129;
  HEAPF32[$19>>2] = $98;
  HEAPF32[$20>>2] = $110;
  HEAPF32[$21>>2] = $122;
  HEAPF32[$22>>2] = $88;
  HEAPF32[$24>>2] = $112;
  HEAPF32[$25>>2] = $124;
  HEAPF32[$26>>2] = $90;
  HEAPF32[$27>>2] = $102;
  HEAPF32[$29>>2] = $126;
  HEAPF32[$30>>2] = $92;
  HEAPF32[$31>>2] = $104;
  HEAPF32[$32>>2] = $116;
  dest=$accum+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $130 = HEAP32[478152>>2]|0;
  HEAP32[$34>>2] = $130;
  $131 = HEAP32[((478152 + 4|0))>>2]|0;
  HEAP32[$35>>2] = $131;
  $132 = HEAP32[((478152 + 8|0))>>2]|0;
  HEAP32[$36>>2] = $132;
  $133 = HEAP32[((478152 + 12|0))>>2]|0;
  HEAP32[$37>>2] = $133;
  __ZNK5physx5cloth11SwCollisionI8Scalar4fE12collideConesEPKS2_RNS3_18ImpulseAccumulatorE($sphereMask,$this,$curPos,$accum);
  __ZNK5physx5cloth11SwCollisionI8Scalar4fE14collideSpheresERKS2_PS4_RNS3_18ImpulseAccumulatorE($this,$sphereMask,$curPos,$accum);
  $134 = HEAP32[478152>>2]|0;
  $135 = HEAP32[((478152 + 4|0))>>2]|0;
  $136 = HEAP32[((478152 + 8|0))>>2]|0;
  $137 = HEAP32[((478152 + 12|0))>>2]|0;
  $138 = Math_fround(HEAPF32[$34>>2]);
  $139 = (HEAP32[tempDoublePtr>>2]=$134,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $140 = $138 > $139;
  $141 = Math_fround(HEAPF32[$35>>2]);
  $142 = (HEAP32[tempDoublePtr>>2]=$135,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $143 = $141 > $142;
  $144 = Math_fround(HEAPF32[$36>>2]);
  $145 = (HEAP32[tempDoublePtr>>2]=$136,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $146 = $144 > $145;
  $147 = Math_fround(HEAPF32[$37>>2]);
  $148 = (HEAP32[tempDoublePtr>>2]=$137,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $149 = $147 > $148;
  $not$x$i$i$i = $140 ^ 1;
  $150 = $not$x$i$i$i << 31 >> 31;
  $151 = $150 ^ -1;
  $not$y$i$i$i = $143 ^ 1;
  $152 = $not$y$i$i$i << 31 >> 31;
  $153 = $152 ^ -1;
  $not$z$i$i$i = $146 ^ 1;
  $154 = $not$z$i$i$i << 31 >> 31;
  $155 = $154 ^ -1;
  $not$w$i$i$i = $149 ^ 1;
  $156 = $not$w$i$i$i << 31 >> 31;
  $157 = $156 ^ -1;
  HEAP32[$mask>>2] = $151;
  HEAP32[$38>>2] = $153;
  HEAP32[$39>>2] = $155;
  HEAP32[$40>>2] = $157;
  $brmerge$i = $140 | $143;
  $brmerge1$i = $brmerge$i | $146;
  $$$i = $brmerge1$i | $149;
  if ($$$i) {
   $158 = Math_fround(Math_fround(1.0) / $138);
   $159 = Math_fround(Math_fround(1.0) / $141);
   $160 = Math_fround(Math_fround(1.0) / $144);
   $161 = Math_fround(Math_fround(1.0) / $147);
   HEAPF32[$invNumCollisions>>2] = $158;
   HEAPF32[$41>>2] = $159;
   HEAPF32[$42>>2] = $160;
   HEAPF32[$43>>2] = $161;
   if ($10) {
    $162 = Math_fround(HEAPF32[$prevIt$0154>>2]);
    $163 = (($prevIt$0154) + 4|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = (($prevIt$0154) + 8|0);
    $166 = Math_fround(HEAPF32[$165>>2]);
    $167 = (($prevIt$0154) + 12|0);
    $168 = Math_fround(HEAPF32[$167>>2]);
    $169 = (HEAPF32[tempDoublePtr>>2]=$162,HEAP32[tempDoublePtr>>2]|0);
    $170 = (HEAPF32[tempDoublePtr>>2]=$164,HEAP32[tempDoublePtr>>2]|0);
    $171 = (HEAPF32[tempDoublePtr>>2]=$166,HEAP32[tempDoublePtr>>2]|0);
    $172 = (HEAPF32[tempDoublePtr>>2]=$168,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$prevPos>>2] = $169;
    HEAP32[$44>>2] = $170;
    HEAP32[$45>>2] = $171;
    HEAP32[$46>>2] = $172;
    $173 = (($prevIt$0154) + 16|0);
    $174 = Math_fround(HEAPF32[$173>>2]);
    $175 = (($prevIt$0154) + 20|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = (($prevIt$0154) + 24|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = (($prevIt$0154) + 28|0);
    $180 = Math_fround(HEAPF32[$179>>2]);
    $181 = (HEAPF32[tempDoublePtr>>2]=$174,HEAP32[tempDoublePtr>>2]|0);
    $182 = (HEAPF32[tempDoublePtr>>2]=$176,HEAP32[tempDoublePtr>>2]|0);
    $183 = (HEAPF32[tempDoublePtr>>2]=$178,HEAP32[tempDoublePtr>>2]|0);
    $184 = (HEAPF32[tempDoublePtr>>2]=$180,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$47>>2] = $181;
    HEAP32[$48>>2] = $182;
    HEAP32[$49>>2] = $183;
    HEAP32[$50>>2] = $184;
    $185 = (($prevIt$0154) + 32|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = (($prevIt$0154) + 36|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = (($prevIt$0154) + 40|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = (($prevIt$0154) + 44|0);
    $192 = Math_fround(HEAPF32[$191>>2]);
    $193 = (HEAPF32[tempDoublePtr>>2]=$186,HEAP32[tempDoublePtr>>2]|0);
    $194 = (HEAPF32[tempDoublePtr>>2]=$188,HEAP32[tempDoublePtr>>2]|0);
    $195 = (HEAPF32[tempDoublePtr>>2]=$190,HEAP32[tempDoublePtr>>2]|0);
    $196 = (HEAPF32[tempDoublePtr>>2]=$192,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$51>>2] = $193;
    HEAP32[$52>>2] = $194;
    HEAP32[$53>>2] = $195;
    HEAP32[$54>>2] = $196;
    $197 = (($prevIt$0154) + 48|0);
    $198 = Math_fround(HEAPF32[$197>>2]);
    $199 = (($prevIt$0154) + 52|0);
    $200 = Math_fround(HEAPF32[$199>>2]);
    $201 = (($prevIt$0154) + 56|0);
    $202 = Math_fround(HEAPF32[$201>>2]);
    $203 = (($prevIt$0154) + 60|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = (HEAPF32[tempDoublePtr>>2]=$204,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$57>>2] = $205;
    HEAPF32[$44>>2] = $174;
    HEAPF32[$45>>2] = $186;
    HEAPF32[$46>>2] = $198;
    HEAPF32[$47>>2] = $164;
    HEAPF32[$49>>2] = $188;
    HEAPF32[$50>>2] = $200;
    HEAPF32[$51>>2] = $166;
    HEAPF32[$52>>2] = $178;
    HEAPF32[$54>>2] = $202;
    HEAPF32[$58>>2] = $168;
    HEAPF32[$55>>2] = $180;
    HEAPF32[$56>>2] = $192;
    __ZN12_GLOBAL__N_124calculateFrictionImpulseI8Scalar4fEEvRKT_S4_S4_S4_S4_S4_PS3_S5_S4_S4_S4_PS2_($accum,$59,$60,$61,$62,$63,$curPos,$prevPos,$invNumCollisions,$frictionScale,$mask,$frictionImpulse);
    $206 = Math_fround(HEAPF32[$prevPos>>2]);
    $207 = Math_fround(HEAPF32[$frictionImpulse>>2]);
    $208 = Math_fround($206 - $207);
    $209 = Math_fround(HEAPF32[$44>>2]);
    $210 = Math_fround(HEAPF32[$64>>2]);
    $211 = Math_fround($209 - $210);
    $212 = Math_fround(HEAPF32[$45>>2]);
    $213 = Math_fround(HEAPF32[$65>>2]);
    $214 = Math_fround($212 - $213);
    $215 = Math_fround(HEAPF32[$46>>2]);
    $216 = Math_fround(HEAPF32[$66>>2]);
    $217 = Math_fround($215 - $216);
    $218 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$prevPos>>2] = $218;
    $219 = Math_fround(HEAPF32[$47>>2]);
    $220 = Math_fround(HEAPF32[$67>>2]);
    $221 = Math_fround($219 - $220);
    $222 = Math_fround(HEAPF32[$48>>2]);
    $223 = Math_fround(HEAPF32[$68>>2]);
    $224 = Math_fround($222 - $223);
    $225 = Math_fround(HEAPF32[$49>>2]);
    $226 = Math_fround(HEAPF32[$69>>2]);
    $227 = Math_fround($225 - $226);
    $228 = Math_fround(HEAPF32[$50>>2]);
    $229 = Math_fround(HEAPF32[$70>>2]);
    $230 = Math_fround($228 - $229);
    $231 = (HEAPF32[tempDoublePtr>>2]=$224,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$48>>2] = $231;
    $232 = Math_fround(HEAPF32[$51>>2]);
    $233 = Math_fround(HEAPF32[$71>>2]);
    $234 = Math_fround($232 - $233);
    $235 = Math_fround(HEAPF32[$52>>2]);
    $236 = Math_fround(HEAPF32[$72>>2]);
    $237 = Math_fround($235 - $236);
    $238 = Math_fround(HEAPF32[$53>>2]);
    $239 = Math_fround(HEAPF32[$73>>2]);
    $240 = Math_fround($238 - $239);
    $241 = Math_fround(HEAPF32[$54>>2]);
    $242 = Math_fround(HEAPF32[$74>>2]);
    $243 = Math_fround($241 - $242);
    $244 = (HEAPF32[tempDoublePtr>>2]=$240,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$53>>2] = $244;
    HEAPF32[$44>>2] = $221;
    HEAPF32[$45>>2] = $234;
    $245 = Math_fround(HEAPF32[$58>>2]);
    HEAPF32[$46>>2] = $245;
    HEAPF32[$47>>2] = $211;
    HEAPF32[$49>>2] = $237;
    $246 = Math_fround(HEAPF32[$55>>2]);
    HEAPF32[$50>>2] = $246;
    HEAPF32[$51>>2] = $214;
    HEAPF32[$52>>2] = $227;
    $247 = Math_fround(HEAPF32[$56>>2]);
    HEAPF32[$54>>2] = $247;
    HEAPF32[$58>>2] = $217;
    HEAPF32[$55>>2] = $230;
    HEAPF32[$56>>2] = $243;
    HEAPF32[$prevIt$0154>>2] = $208;
    $248 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$163>>2] = $248;
    $249 = Math_fround(HEAPF32[$45>>2]);
    HEAPF32[$165>>2] = $249;
    $250 = Math_fround(HEAPF32[$46>>2]);
    HEAPF32[$167>>2] = $250;
    $251 = Math_fround(HEAPF32[$47>>2]);
    HEAPF32[$173>>2] = $251;
    $252 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$175>>2] = $252;
    $253 = Math_fround(HEAPF32[$49>>2]);
    HEAPF32[$177>>2] = $253;
    $254 = Math_fround(HEAPF32[$50>>2]);
    HEAPF32[$179>>2] = $254;
    $255 = Math_fround(HEAPF32[$51>>2]);
    HEAPF32[$185>>2] = $255;
    $256 = Math_fround(HEAPF32[$52>>2]);
    HEAPF32[$187>>2] = $256;
    $257 = Math_fround(HEAPF32[$53>>2]);
    HEAPF32[$189>>2] = $257;
    $258 = Math_fround(HEAPF32[$54>>2]);
    HEAPF32[$191>>2] = $258;
    $259 = Math_fround(HEAPF32[$58>>2]);
    HEAPF32[$197>>2] = $259;
    $260 = Math_fround(HEAPF32[$55>>2]);
    HEAPF32[$199>>2] = $260;
    $261 = Math_fround(HEAPF32[$56>>2]);
    HEAPF32[$201>>2] = $261;
    $262 = Math_fround(HEAPF32[$57>>2]);
    HEAPF32[$203>>2] = $262;
   }
   if ($9) {
    $263 = Math_fround(HEAPF32[$invNumCollisions>>2]);
    $264 = Math_fround($263 * $263);
    $265 = Math_fround(HEAPF32[$41>>2]);
    $266 = Math_fround($265 * $265);
    $267 = Math_fround(HEAPF32[$42>>2]);
    $268 = Math_fround($267 * $267);
    $269 = Math_fround(HEAPF32[$43>>2]);
    $270 = Math_fround($269 * $269);
    $271 = Math_fround(HEAPF32[$accum>>2]);
    $272 = Math_fround($271 * $271);
    $273 = Math_fround(HEAPF32[$75>>2]);
    $274 = Math_fround($273 * $273);
    $275 = Math_fround(HEAPF32[$76>>2]);
    $276 = Math_fround($275 * $275);
    $277 = Math_fround(HEAPF32[$77>>2]);
    $278 = Math_fround($277 * $277);
    $279 = Math_fround(HEAPF32[$78>>2]);
    $280 = Math_fround($279 * $279);
    $281 = Math_fround(HEAPF32[$79>>2]);
    $282 = Math_fround($281 * $281);
    $283 = Math_fround(HEAPF32[$80>>2]);
    $284 = Math_fround($283 * $283);
    $285 = Math_fround(HEAPF32[$81>>2]);
    $286 = Math_fround($285 * $285);
    $287 = Math_fround($272 + $280);
    $288 = Math_fround($274 + $282);
    $289 = Math_fround($276 + $284);
    $290 = Math_fround($278 + $286);
    $291 = Math_fround(HEAPF32[$82>>2]);
    $292 = Math_fround($291 * $291);
    $293 = Math_fround(HEAPF32[$83>>2]);
    $294 = Math_fround($293 * $293);
    $295 = Math_fround(HEAPF32[$84>>2]);
    $296 = Math_fround($295 * $295);
    $297 = Math_fround(HEAPF32[$85>>2]);
    $298 = Math_fround($297 * $297);
    $299 = Math_fround($287 + $292);
    $300 = Math_fround($288 + $294);
    $301 = Math_fround($289 + $296);
    $302 = Math_fround($290 + $298);
    $303 = Math_fround($264 * $299);
    $304 = Math_fround($266 * $300);
    $305 = Math_fround($268 * $301);
    $306 = Math_fround($270 * $302);
    $307 = HEAP32[478248>>2]|0;
    $308 = HEAP32[((478248 + 4|0))>>2]|0;
    $309 = HEAP32[((478248 + 8|0))>>2]|0;
    $310 = HEAP32[((478248 + 12|0))>>2]|0;
    $311 = Math_fround($3 * $303);
    $312 = Math_fround($3 * $304);
    $313 = Math_fround($3 * $305);
    $314 = Math_fround($3 * $306);
    $315 = (HEAP32[tempDoublePtr>>2]=$307,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $316 = Math_fround($311 + $315);
    $317 = (HEAP32[tempDoublePtr>>2]=$308,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $318 = Math_fround($312 + $317);
    $319 = (HEAP32[tempDoublePtr>>2]=$309,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $320 = Math_fround($313 + $319);
    $321 = (HEAP32[tempDoublePtr>>2]=$310,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $322 = Math_fround($314 + $321);
    $323 = Math_fround(Math_fround(1.0) / $316);
    $324 = Math_fround(Math_fround(1.0) / $318);
    $325 = Math_fround(Math_fround(1.0) / $320);
    $326 = Math_fround(Math_fround(1.0) / $322);
    $327 = Math_fround(HEAPF32[$30>>2]);
    $328 = Math_fround($323 * $327);
    $329 = Math_fround(HEAPF32[$31>>2]);
    $330 = Math_fround($324 * $329);
    $331 = Math_fround(HEAPF32[$32>>2]);
    $332 = Math_fround($325 * $331);
    $333 = Math_fround(HEAPF32[$33>>2]);
    $334 = Math_fround($326 * $333);
    $335 = (HEAPF32[tempDoublePtr>>2]=$328,HEAP32[tempDoublePtr>>2]|0);
    $336 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
    $337 = (HEAPF32[tempDoublePtr>>2]=$332,HEAP32[tempDoublePtr>>2]|0);
    $338 = (HEAPF32[tempDoublePtr>>2]=$334,HEAP32[tempDoublePtr>>2]|0);
    $339 = (HEAPF32[tempDoublePtr>>2]=$327,HEAP32[tempDoublePtr>>2]|0);
    $340 = $339 ^ $335;
    $341 = (HEAPF32[tempDoublePtr>>2]=$329,HEAP32[tempDoublePtr>>2]|0);
    $342 = $341 ^ $336;
    $343 = (HEAPF32[tempDoublePtr>>2]=$331,HEAP32[tempDoublePtr>>2]|0);
    $344 = $343 ^ $337;
    $345 = (HEAPF32[tempDoublePtr>>2]=$333,HEAP32[tempDoublePtr>>2]|0);
    $346 = $345 ^ $338;
    $347 = HEAP32[$mask>>2]|0;
    $348 = $347 & $340;
    $349 = HEAP32[$38>>2]|0;
    $350 = $349 & $342;
    $351 = HEAP32[$39>>2]|0;
    $352 = $351 & $344;
    $353 = HEAP32[$40>>2]|0;
    $354 = $353 & $346;
    $355 = $348 ^ $339;
    $356 = $350 ^ $341;
    $357 = $352 ^ $343;
    $358 = $354 ^ $345;
    HEAP32[$30>>2] = $355;
    HEAP32[$31>>2] = $356;
    HEAP32[$32>>2] = $357;
    HEAP32[$33>>2] = $358;
    $359 = (HEAP32[tempDoublePtr>>2]=$355,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $360 = (HEAP32[tempDoublePtr>>2]=$356,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $361 = (HEAP32[tempDoublePtr>>2]=$357,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $364 = $271;$366 = $265;$367 = $273;$369 = $267;$370 = $275;$372 = $269;$373 = $277;$384 = $279;$386 = $281;$388 = $283;$390 = $285;$401 = $291;$403 = $293;$405 = $295;$407 = $297;$417 = $359;$418 = $360;$419 = $361;
   } else {
    $$pre = Math_fround(HEAPF32[$accum>>2]);
    $$pre159 = Math_fround(HEAPF32[$75>>2]);
    $$pre160 = Math_fround(HEAPF32[$41>>2]);
    $$pre161 = Math_fround(HEAPF32[$76>>2]);
    $$pre162 = Math_fround(HEAPF32[$42>>2]);
    $$pre163 = Math_fround(HEAPF32[$77>>2]);
    $$pre164 = Math_fround(HEAPF32[$43>>2]);
    $$pre165 = Math_fround(HEAPF32[$78>>2]);
    $$pre166 = Math_fround(HEAPF32[$79>>2]);
    $$pre167 = Math_fround(HEAPF32[$80>>2]);
    $$pre168 = Math_fround(HEAPF32[$81>>2]);
    $$pre169 = Math_fround(HEAPF32[$82>>2]);
    $$pre170 = Math_fround(HEAPF32[$83>>2]);
    $$pre171 = Math_fround(HEAPF32[$84>>2]);
    $$pre172 = Math_fround(HEAPF32[$85>>2]);
    $$pre173 = Math_fround(HEAPF32[$30>>2]);
    $$pre174 = Math_fround(HEAPF32[$31>>2]);
    $$pre175 = Math_fround(HEAPF32[$32>>2]);
    $364 = $$pre;$366 = $$pre160;$367 = $$pre159;$369 = $$pre162;$370 = $$pre161;$372 = $$pre164;$373 = $$pre163;$384 = $$pre165;$386 = $$pre166;$388 = $$pre167;$390 = $$pre168;$401 = $$pre169;$403 = $$pre170;$405 = $$pre171;$407 = $$pre172;$417 = $$pre173;$418 = $$pre174;$419 = $$pre175;
   }
   $362 = Math_fround(HEAPF32[$invNumCollisions>>2]);
   $363 = Math_fround($364 * $362);
   $365 = Math_fround($367 * $366);
   $368 = Math_fround($370 * $369);
   $371 = Math_fround($373 * $372);
   $374 = Math_fround(HEAPF32[$curPos>>2]);
   $375 = Math_fround($363 + $374);
   $376 = Math_fround(HEAPF32[$19>>2]);
   $377 = Math_fround($365 + $376);
   $378 = Math_fround(HEAPF32[$20>>2]);
   $379 = Math_fround($368 + $378);
   $380 = Math_fround(HEAPF32[$21>>2]);
   $381 = Math_fround($371 + $380);
   $382 = (HEAPF32[tempDoublePtr>>2]=$375,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$curPos>>2] = $382;
   $383 = Math_fround($384 * $362);
   $385 = Math_fround($386 * $366);
   $387 = Math_fround($388 * $369);
   $389 = Math_fround($390 * $372);
   $391 = Math_fround(HEAPF32[$22>>2]);
   $392 = Math_fround($383 + $391);
   $393 = Math_fround(HEAPF32[$23>>2]);
   $394 = Math_fround($385 + $393);
   $395 = Math_fround(HEAPF32[$24>>2]);
   $396 = Math_fround($387 + $395);
   $397 = Math_fround(HEAPF32[$25>>2]);
   $398 = Math_fround($389 + $397);
   $399 = (HEAPF32[tempDoublePtr>>2]=$394,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$23>>2] = $399;
   $400 = Math_fround($401 * $362);
   $402 = Math_fround($403 * $366);
   $404 = Math_fround($405 * $369);
   $406 = Math_fround($407 * $372);
   $408 = Math_fround(HEAPF32[$26>>2]);
   $409 = Math_fround($400 + $408);
   $410 = Math_fround(HEAPF32[$27>>2]);
   $411 = Math_fround($402 + $410);
   $412 = Math_fround(HEAPF32[$28>>2]);
   $413 = Math_fround($404 + $412);
   $414 = Math_fround(HEAPF32[$29>>2]);
   $415 = Math_fround($406 + $414);
   $416 = (HEAPF32[tempDoublePtr>>2]=$413,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$28>>2] = $416;
   HEAPF32[$19>>2] = $392;
   HEAPF32[$20>>2] = $409;
   HEAPF32[$21>>2] = $417;
   HEAPF32[$22>>2] = $377;
   HEAPF32[$24>>2] = $411;
   HEAPF32[$25>>2] = $418;
   HEAPF32[$26>>2] = $379;
   HEAPF32[$27>>2] = $396;
   HEAPF32[$29>>2] = $419;
   HEAPF32[$30>>2] = $381;
   HEAPF32[$31>>2] = $398;
   HEAPF32[$32>>2] = $415;
   HEAPF32[$pIt$0152>>2] = $375;
   $420 = Math_fround(HEAPF32[$19>>2]);
   HEAPF32[$87>>2] = $420;
   $421 = Math_fround(HEAPF32[$20>>2]);
   HEAPF32[$89>>2] = $421;
   $422 = Math_fround(HEAPF32[$21>>2]);
   HEAPF32[$91>>2] = $422;
   $423 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$97>>2] = $423;
   $424 = Math_fround(HEAPF32[$23>>2]);
   HEAPF32[$99>>2] = $424;
   $425 = Math_fround(HEAPF32[$24>>2]);
   HEAPF32[$101>>2] = $425;
   $426 = Math_fround(HEAPF32[$25>>2]);
   HEAPF32[$103>>2] = $426;
   $427 = Math_fround(HEAPF32[$26>>2]);
   HEAPF32[$109>>2] = $427;
   $428 = Math_fround(HEAPF32[$27>>2]);
   HEAPF32[$111>>2] = $428;
   $429 = Math_fround(HEAPF32[$28>>2]);
   HEAPF32[$113>>2] = $429;
   $430 = Math_fround(HEAPF32[$29>>2]);
   HEAPF32[$115>>2] = $430;
   $431 = Math_fround(HEAPF32[$30>>2]);
   HEAPF32[$121>>2] = $431;
   $432 = Math_fround(HEAPF32[$31>>2]);
   HEAPF32[$123>>2] = $432;
   $433 = Math_fround(HEAPF32[$32>>2]);
   HEAPF32[$125>>2] = $433;
   $434 = Math_fround(HEAPF32[$33>>2]);
   HEAPF32[$127>>2] = $434;
  }
  $435 = (($pIt$0152) + 64|0);
  $436 = ($435>>>0)<($15>>>0);
  if (!($436)) {
   break;
  }
  $437 = (($prevIt$0154) + 64|0);
  $pIt$0152 = $435;$prevIt$0154 = $437;
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE23collideVirtualParticlesEv($this) {
 $this = $this|0;
 var $$$i = 0, $$in = Math_fround(0), $$in1229 = Math_fround(0), $$in1230 = Math_fround(0), $$in1231 = Math_fround(0), $$in1232 = Math_fround(0), $$in1233 = Math_fround(0), $$in1234 = Math_fround(0), $$in1235 = Math_fround(0), $$in1236 = Math_fround(0), $$in1237 = Math_fround(0), $$in1238 = Math_fround(0), $$in1239 = Math_fround(0), $$in1240 = Math_fround(0), $$in1241 = Math_fround(0), $$in1242 = Math_fround(0), $$in1243 = Math_fround(0), $$in1244 = Math_fround(0), $$in1245 = Math_fround(0), $$in1246 = Math_fround(0);
 var $$in1247 = Math_fround(0), $$in1248 = Math_fround(0), $$in1249 = Math_fround(0), $$in1250 = Math_fround(0), $$in1251 = Math_fround(0), $$in1252 = Math_fround(0), $$in1253 = Math_fround(0), $$in1254 = Math_fround(0), $$in1255 = Math_fround(0), $$in1256 = Math_fround(0), $$in1257 = Math_fround(0), $$in1258 = Math_fround(0), $$in1259 = Math_fround(0), $$in1260 = Math_fround(0), $$in1261 = Math_fround(0), $$in1262 = Math_fround(0), $$in1263 = Math_fround(0), $$in1264 = Math_fround(0), $$in1265 = Math_fround(0), $$in1266 = Math_fround(0);
 var $$in1267 = Math_fround(0), $$in1268 = Math_fround(0), $$in1269 = Math_fround(0), $$in1270 = Math_fround(0), $$in1271 = Math_fround(0), $$in1272 = Math_fround(0), $$in1273 = Math_fround(0), $$in1274 = Math_fround(0), $$in1275 = Math_fround(0), $$sum = 0, $$sum$i1011315 = 0, $$sum$i1041312 = 0, $$sum$i1071226 = 0, $$sum$i1101223 = 0, $$sum$i111297 = 0, $$sum$i1131220 = 0, $$sum$i1161217 = 0, $$sum$i1191214 = 0, $$sum$i1221211 = 0, $$sum$i1251208 = 0;
 var $$sum$i1281205 = 0, $$sum$i1309 = 0, $$sum$i1311202 = 0, $$sum$i1341199 = 0, $$sum$i1371196 = 0, $$sum$i1401193 = 0, $$sum$i141294 = 0, $$sum$i1431190 = 0, $$sum$i1461187 = 0, $$sum$i1491184 = 0, $$sum$i1521181 = 0, $$sum$i171291 = 0, $$sum$i201288 = 0, $$sum$i21306 = 0, $$sum$i231285 = 0, $$sum$i261282 = 0, $$sum$i291279 = 0, $$sum$i321276 = 0, $$sum$i351381 = 0, $$sum$i381378 = 0;
 var $$sum$i411375 = 0, $$sum$i441372 = 0, $$sum$i471369 = 0, $$sum$i501366 = 0, $$sum$i51303 = 0, $$sum$i531363 = 0, $$sum$i561360 = 0, $$sum$i591357 = 0, $$sum$i621354 = 0, $$sum$i651351 = 0, $$sum$i681348 = 0, $$sum$i711345 = 0, $$sum$i741342 = 0, $$sum$i771339 = 0, $$sum$i801336 = 0, $$sum$i81300 = 0, $$sum$i831333 = 0, $$sum$i861330 = 0, $$sum$i891327 = 0, $$sum$i921324 = 0;
 var $$sum$i951321 = 0, $$sum$i981318 = 0, $$sum1 = 0, $$sum1$i1021316 = 0, $$sum1$i1051313 = 0, $$sum1$i1081227 = 0, $$sum1$i1111224 = 0, $$sum1$i1141221 = 0, $$sum1$i1171218 = 0, $$sum1$i1201215 = 0, $$sum1$i121298 = 0, $$sum1$i1231212 = 0, $$sum1$i1261209 = 0, $$sum1$i1291206 = 0, $$sum1$i1310 = 0, $$sum1$i1321203 = 0, $$sum1$i1351200 = 0, $$sum1$i1381197 = 0, $$sum1$i1411194 = 0, $$sum1$i1441191 = 0;
 var $$sum1$i1471188 = 0, $$sum1$i1501185 = 0, $$sum1$i151295 = 0, $$sum1$i1531182 = 0, $$sum1$i181292 = 0, $$sum1$i211289 = 0, $$sum1$i241286 = 0, $$sum1$i271283 = 0, $$sum1$i301280 = 0, $$sum1$i31307 = 0, $$sum1$i331277 = 0, $$sum1$i361382 = 0, $$sum1$i391379 = 0, $$sum1$i421376 = 0, $$sum1$i451373 = 0, $$sum1$i481370 = 0, $$sum1$i511367 = 0, $$sum1$i541364 = 0, $$sum1$i571361 = 0, $$sum1$i601358 = 0;
 var $$sum1$i61304 = 0, $$sum1$i631355 = 0, $$sum1$i661352 = 0, $$sum1$i691349 = 0, $$sum1$i721346 = 0, $$sum1$i751343 = 0, $$sum1$i781340 = 0, $$sum1$i811337 = 0, $$sum1$i841334 = 0, $$sum1$i871331 = 0, $$sum1$i901328 = 0, $$sum1$i91301 = 0, $$sum1$i931325 = 0, $$sum1$i961322 = 0, $$sum1$i991319 = 0, $$sum2$i1001320 = 0, $$sum2$i101302 = 0, $$sum2$i1031317 = 0, $$sum2$i1061314 = 0, $$sum2$i1091228 = 0;
 var $$sum2$i1121225 = 0, $$sum2$i1151222 = 0, $$sum2$i1181219 = 0, $$sum2$i1211216 = 0, $$sum2$i1241213 = 0, $$sum2$i1271210 = 0, $$sum2$i1301207 = 0, $$sum2$i1311 = 0, $$sum2$i131299 = 0, $$sum2$i1331204 = 0, $$sum2$i1361201 = 0, $$sum2$i1391198 = 0, $$sum2$i1421195 = 0, $$sum2$i1451192 = 0, $$sum2$i1481189 = 0, $$sum2$i1511186 = 0, $$sum2$i1541183 = 0, $$sum2$i161296 = 0, $$sum2$i191293 = 0, $$sum2$i221290 = 0;
 var $$sum2$i251287 = 0, $$sum2$i281284 = 0, $$sum2$i311281 = 0, $$sum2$i341278 = 0, $$sum2$i371383 = 0, $$sum2$i401380 = 0, $$sum2$i41308 = 0, $$sum2$i431377 = 0, $$sum2$i461374 = 0, $$sum2$i491371 = 0, $$sum2$i521368 = 0, $$sum2$i551365 = 0, $$sum2$i581362 = 0, $$sum2$i611359 = 0, $$sum2$i641356 = 0, $$sum2$i671353 = 0, $$sum2$i701350 = 0, $$sum2$i71305 = 0, $$sum2$i731347 = 0, $$sum2$i761344 = 0;
 var $$sum2$i791341 = 0, $$sum2$i821338 = 0, $$sum2$i851335 = 0, $$sum2$i881332 = 0, $$sum2$i911329 = 0, $$sum2$i941326 = 0, $$sum2$i971323 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = 0, $1007 = 0, $1008 = 0;
 var $1009 = 0, $101 = 0, $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0;
 var $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = 0, $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = 0;
 var $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = 0, $1060 = Math_fround(0), $1061 = 0, $1062 = 0;
 var $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0), $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0;
 var $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = 0, $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0;
 var $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0;
 var $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0;
 var $1135 = 0, $1136 = 0, $1137 = 0, $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = 0, $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0;
 var $1153 = 0, $1154 = 0, $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = Math_fround(0), $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0;
 var $1171 = 0, $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = Math_fround(0), $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = Math_fround(0);
 var $119 = 0, $1190 = Math_fround(0), $1191 = Math_fround(0), $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = Math_fround(0), $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = Math_fround(0);
 var $1207 = Math_fround(0), $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = 0, $1210 = Math_fround(0), $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = Math_fround(0), $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = Math_fround(0), $1224 = Math_fround(0);
 var $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = Math_fround(0), $1229 = Math_fround(0), $123 = 0, $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = Math_fround(0), $1233 = Math_fround(0), $1234 = Math_fround(0), $1235 = Math_fround(0), $1236 = Math_fround(0), $1237 = Math_fround(0), $1238 = Math_fround(0), $1239 = Math_fround(0), $124 = 0, $1240 = Math_fround(0), $1241 = Math_fround(0), $1242 = Math_fround(0);
 var $1243 = Math_fround(0), $1244 = Math_fround(0), $1245 = Math_fround(0), $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = 0, $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0), $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = 0, $1260 = Math_fround(0);
 var $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0), $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = Math_fround(0), $1276 = Math_fround(0), $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = Math_fround(0);
 var $128 = 0, $1280 = Math_fround(0), $1281 = Math_fround(0), $1282 = Math_fround(0), $1283 = Math_fround(0), $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = Math_fround(0), $1287 = Math_fround(0), $1288 = Math_fround(0), $1289 = Math_fround(0), $129 = 0, $1290 = Math_fround(0), $1291 = Math_fround(0), $1292 = Math_fround(0), $1293 = Math_fround(0), $1294 = Math_fround(0), $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = Math_fround(0);
 var $1298 = Math_fround(0), $1299 = Math_fround(0), $13 = 0, $130 = 0, $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = Math_fround(0), $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0), $131 = 0, $1310 = Math_fround(0), $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = Math_fround(0), $1314 = Math_fround(0);
 var $1315 = Math_fround(0), $1316 = Math_fround(0), $1317 = Math_fround(0), $1318 = Math_fround(0), $1319 = Math_fround(0), $132 = 0, $1320 = Math_fround(0), $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = Math_fround(0), $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0;
 var $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0;
 var $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0;
 var $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0;
 var $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0;
 var $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0;
 var $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0);
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0);
 var $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0);
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0);
 var $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0);
 var $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = Math_fround(0), $496 = 0, $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $500 = 0, $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0), $509 = 0, $51 = Math_fround(0), $510 = Math_fround(0);
 var $511 = 0, $512 = Math_fround(0), $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = Math_fround(0), $518 = 0, $519 = Math_fround(0), $52 = Math_fround(0), $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = Math_fround(0), $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = Math_fround(0), $529 = 0;
 var $53 = Math_fround(0), $530 = Math_fround(0), $531 = 0, $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = Math_fround(0), $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = Math_fround(0), $551 = 0, $552 = Math_fround(0), $553 = 0, $554 = Math_fround(0), $555 = 0, $556 = Math_fround(0), $557 = 0, $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = Math_fround(0);
 var $566 = 0, $567 = Math_fround(0), $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = Math_fround(0), $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = 0, $578 = Math_fround(0), $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0, $582 = 0, $583 = Math_fround(0);
 var $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = 0, $589 = Math_fround(0), $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = Math_fround(0), $595 = 0, $596 = Math_fround(0), $597 = 0, $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0);
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = Math_fround(0), $606 = 0, $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = Math_fround(0), $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = Math_fround(0), $617 = 0, $618 = Math_fround(0), $619 = 0;
 var $62 = 0, $620 = Math_fround(0), $621 = 0, $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0);
 var $638 = 0, $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = 0, $655 = Math_fround(0);
 var $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = 0, $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0);
 var $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0;
 var $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0);
 var $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0);
 var $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0);
 var $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0);
 var $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0);
 var $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0;
 var $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0;
 var $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0;
 var $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0;
 var $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0;
 var $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0;
 var $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0);
 var $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0);
 var $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = Math_fround(0);
 var $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = 0, $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = 0, $960 = Math_fround(0), $961 = Math_fround(0);
 var $962 = Math_fround(0), $963 = Math_fround(0), $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = Math_fround(0), $969 = Math_fround(0), $97 = 0, $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = 0, $979 = 0, $98 = 0;
 var $980 = 0, $981 = 0, $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0, $990 = Math_fround(0), $991 = Math_fround(0), $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0);
 var $999 = Math_fround(0), $accum = 0, $brmerge$i = 0, $brmerge1$i = 0, $curPos = 0, $frictionImpulse = 0, $frictionScale = 0, $invNumCollisions = 0, $mask = 0, $not$w$i$i$i = 0, $not$w$i$i$i158 = 0, $not$x$i$i$i = 0, $not$x$i$i$i155 = 0, $not$y$i$i$i = 0, $not$y$i$i$i156 = 0, $not$z$i$i$i = 0, $not$z$i$i$i157 = 0, $prevPos = 0, $sphereMask = 0, $vpIt$01384 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $frictionScale = sp + 320|0;
 $curPos = sp;
 $accum = sp + 48|0;
 $sphereMask = sp + 160|0;
 $mask = sp + 176|0;
 $invNumCollisions = sp + 192|0;
 $prevPos = sp + 208|0;
 $frictionImpulse = sp + 256|0;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 220|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 216|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$frictionScale>>2] = $5;
 $6 = (($frictionScale) + 4|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($frictionScale) + 8|0);
 HEAPF32[$7>>2] = $5;
 $8 = (($frictionScale) + 12|0);
 HEAPF32[$8>>2] = $5;
 $9 = $3 > Math_fround(0.0);
 $10 = $5 > Math_fround(0.0);
 $11 = (($1) + 204|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($1) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($1) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$1>>2]|0;
 $18 = (($14) + ($17<<4)|0);
 $19 = (($this) + 384|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(Math_fround(1.0) / $20);
 $22 = (($this) + 388|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(Math_fround(1.0) / $23);
 $25 = (($this) + 392|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(Math_fround(1.0) / $26);
 $28 = (($this) + 396|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround(Math_fround(1.0) / $29);
 $31 = HEAP32[478152>>2]|0;
 $32 = HEAP32[((478152 + 4|0))>>2]|0;
 $33 = HEAP32[((478152 + 8|0))>>2]|0;
 $34 = HEAP32[((478152 + 12|0))>>2]|0;
 $35 = (HEAP32[tempDoublePtr>>2]=$31,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $36 = (HEAP32[tempDoublePtr>>2]=$32,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $37 = (HEAP32[tempDoublePtr>>2]=$33,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $38 = (HEAP32[tempDoublePtr>>2]=$34,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $not$x$i$i$i155 = $20 > $35;
 $not$y$i$i$i156 = $23 > $36;
 $not$z$i$i$i157 = $26 > $37;
 $not$w$i$i$i158 = $29 > $38;
 $$sum = (($17) + 1)|0;
 $39 = (($14) + ($$sum<<4)|0);
 $$sum1 = (($17) + 2)|0;
 $40 = (($14) + ($$sum1<<4)|0);
 $41 = $not$x$i$i$i155 ? $21 : Math_fround(0.0);
 $42 = (($this) + 400|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($41 * $43);
 $45 = $not$y$i$i$i156 ? $24 : Math_fround(0.0);
 $46 = (($this) + 404|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 * $47);
 $49 = $not$z$i$i$i157 ? $27 : Math_fround(0.0);
 $50 = (($this) + 408|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($49 * $51);
 $53 = $not$w$i$i$i158 ? $30 : Math_fround(0.0);
 $54 = (($this) + 412|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($53 * $55);
 $57 = Math_fround($44 - $41);
 $58 = Math_fround($48 - $45);
 $59 = Math_fround($52 - $49);
 $60 = Math_fround($56 - $53);
 $61 = (HEAPF32[tempDoublePtr>>2]=$57,HEAP32[tempDoublePtr>>2]|0);
 $62 = (HEAPF32[tempDoublePtr>>2]=$58,HEAP32[tempDoublePtr>>2]|0);
 $63 = (HEAPF32[tempDoublePtr>>2]=$59,HEAP32[tempDoublePtr>>2]|0);
 $64 = (HEAPF32[tempDoublePtr>>2]=$60,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$40>>2] = $61;
 $65 = ((($14) + ($$sum1<<4)|0) + 4|0);
 HEAP32[$65>>2] = $62;
 $66 = ((($14) + ($$sum1<<4)|0) + 8|0);
 HEAP32[$66>>2] = $63;
 $67 = ((($14) + ($$sum1<<4)|0) + 12|0);
 HEAP32[$67>>2] = $64;
 HEAP32[$39>>2] = $61;
 $68 = ((($14) + ($$sum<<4)|0) + 4|0);
 HEAP32[$68>>2] = $62;
 $69 = ((($14) + ($$sum<<4)|0) + 8|0);
 HEAP32[$69>>2] = $63;
 $70 = ((($14) + ($$sum<<4)|0) + 12|0);
 HEAP32[$70>>2] = $64;
 HEAP32[$18>>2] = $61;
 $71 = ((($14) + ($17<<4)|0) + 4|0);
 HEAP32[$71>>2] = $62;
 $72 = ((($14) + ($17<<4)|0) + 8|0);
 HEAP32[$72>>2] = $63;
 $73 = ((($14) + ($17<<4)|0) + 12|0);
 HEAP32[$73>>2] = $64;
 $74 = HEAP32[$0>>2]|0;
 $75 = (($74) + 196|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($74) + 200|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($76|0)==($78|0);
 if ($79) {
  STACKTOP = sp;return;
 }
 $80 = (($curPos) + 4|0);
 $81 = (($curPos) + 8|0);
 $82 = (($curPos) + 12|0);
 $83 = (($curPos) + 16|0);
 $84 = (($curPos) + 20|0);
 $85 = (($curPos) + 24|0);
 $86 = (($curPos) + 28|0);
 $87 = (($curPos) + 32|0);
 $88 = (($curPos) + 36|0);
 $89 = (($curPos) + 40|0);
 $90 = (($curPos) + 44|0);
 $91 = (($accum) + 96|0);
 $92 = (($accum) + 100|0);
 $93 = (($accum) + 104|0);
 $94 = (($accum) + 108|0);
 $95 = (($mask) + 4|0);
 $96 = (($mask) + 8|0);
 $97 = (($mask) + 12|0);
 $98 = (($invNumCollisions) + 4|0);
 $99 = (($invNumCollisions) + 8|0);
 $100 = (($invNumCollisions) + 12|0);
 $101 = (($accum) + 4|0);
 $102 = (($accum) + 8|0);
 $103 = (($accum) + 12|0);
 $104 = (($accum) + 16|0);
 $105 = (($accum) + 20|0);
 $106 = (($accum) + 24|0);
 $107 = (($accum) + 28|0);
 $108 = (($accum) + 32|0);
 $109 = (($accum) + 36|0);
 $110 = (($accum) + 40|0);
 $111 = (($accum) + 44|0);
 $112 = (($prevPos) + 4|0);
 $113 = (($prevPos) + 8|0);
 $114 = (($prevPos) + 12|0);
 $115 = (($prevPos) + 16|0);
 $116 = (($prevPos) + 20|0);
 $117 = (($prevPos) + 24|0);
 $118 = (($prevPos) + 28|0);
 $119 = (($prevPos) + 32|0);
 $120 = (($prevPos) + 36|0);
 $121 = (($prevPos) + 40|0);
 $122 = (($prevPos) + 44|0);
 $123 = (($frictionImpulse) + 48|0);
 $124 = (($frictionImpulse) + 52|0);
 $125 = (($frictionImpulse) + 56|0);
 $126 = (($frictionImpulse) + 60|0);
 $127 = (($accum) + 48|0);
 $128 = (($accum) + 64|0);
 $129 = (($accum) + 80|0);
 $130 = (($frictionImpulse) + 4|0);
 $131 = (($frictionImpulse) + 8|0);
 $132 = (($frictionImpulse) + 12|0);
 $133 = (($frictionImpulse) + 24|0);
 $134 = (($frictionImpulse) + 28|0);
 $135 = (($frictionImpulse) + 44|0);
 $136 = (($frictionImpulse) + 16|0);
 $137 = (($frictionImpulse) + 32|0);
 $138 = (($frictionImpulse) + 36|0);
 $139 = (($frictionImpulse) + 20|0);
 $140 = (($frictionImpulse) + 40|0);
 $vpIt$01384 = $76;
 while(1) {
  $141 = HEAP16[$vpIt$01384>>1]|0;
  $142 = $141&65535;
  $143 = $142 << 4;
  $144 = (($14) + ($143)|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $$sum$i1521181 = $143 | 4;
  $146 = (($14) + ($$sum$i1521181)|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  $$sum1$i1531182 = $143 | 8;
  $148 = (($14) + ($$sum1$i1531182)|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $$sum2$i1541183 = $143 | 12;
  $150 = (($14) + ($$sum2$i1541183)|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = (($vpIt$01384) + 2|0);
  $153 = HEAP16[$152>>1]|0;
  $154 = $153&65535;
  $155 = $154 << 4;
  $156 = (($14) + ($155)|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $$sum$i1491184 = $155 | 4;
  $158 = (($14) + ($$sum$i1491184)|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $$sum1$i1501185 = $155 | 8;
  $160 = (($14) + ($$sum1$i1501185)|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $$sum2$i1511186 = $155 | 12;
  $162 = (($14) + ($$sum2$i1511186)|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = (($vpIt$01384) + 4|0);
  $165 = HEAP16[$164>>1]|0;
  $166 = $165&65535;
  $167 = $166 << 4;
  $168 = (($14) + ($167)|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $$sum$i1461187 = $167 | 4;
  $170 = (($14) + ($$sum$i1461187)|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $$sum1$i1471188 = $167 | 8;
  $172 = (($14) + ($$sum1$i1471188)|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $$sum2$i1481189 = $167 | 12;
  $174 = (($14) + ($$sum2$i1481189)|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (($vpIt$01384) + 6|0);
  $177 = HEAP16[$176>>1]|0;
  $178 = $177&65535;
  $179 = $178 << 4;
  $180 = (($12) + ($179)|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $$sum$i1431190 = $179 | 4;
  $182 = (($12) + ($$sum$i1431190)|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $$sum1$i1441191 = $179 | 8;
  $184 = (($12) + ($$sum1$i1441191)|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $$sum2$i1451192 = $179 | 12;
  $186 = (($12) + ($$sum2$i1451192)|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = (HEAPF32[tempDoublePtr>>2]=$181,HEAP32[tempDoublePtr>>2]|0);
  $189 = (HEAPF32[tempDoublePtr>>2]=$183,HEAP32[tempDoublePtr>>2]|0);
  $190 = (HEAPF32[tempDoublePtr>>2]=$185,HEAP32[tempDoublePtr>>2]|0);
  $191 = (($vpIt$01384) + 8|0);
  $192 = HEAP16[$191>>1]|0;
  $193 = $192&65535;
  $194 = $193 << 4;
  $195 = (($14) + ($194)|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $$sum$i1401193 = $194 | 4;
  $197 = (($14) + ($$sum$i1401193)|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $$sum1$i1411194 = $194 | 8;
  $199 = (($14) + ($$sum1$i1411194)|0);
  $200 = Math_fround(HEAPF32[$199>>2]);
  $$sum2$i1421195 = $194 | 12;
  $201 = (($14) + ($$sum2$i1421195)|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($vpIt$01384) + 10|0);
  $204 = HEAP16[$203>>1]|0;
  $205 = $204&65535;
  $206 = $205 << 4;
  $207 = (($14) + ($206)|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $$sum$i1371196 = $206 | 4;
  $209 = (($14) + ($$sum$i1371196)|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $$sum1$i1381197 = $206 | 8;
  $211 = (($14) + ($$sum1$i1381197)|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $$sum2$i1391198 = $206 | 12;
  $213 = (($14) + ($$sum2$i1391198)|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = (($vpIt$01384) + 12|0);
  $216 = HEAP16[$215>>1]|0;
  $217 = $216&65535;
  $218 = $217 << 4;
  $219 = (($14) + ($218)|0);
  $220 = Math_fround(HEAPF32[$219>>2]);
  $$sum$i1341199 = $218 | 4;
  $221 = (($14) + ($$sum$i1341199)|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  $$sum1$i1351200 = $218 | 8;
  $223 = (($14) + ($$sum1$i1351200)|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $$sum2$i1361201 = $218 | 12;
  $225 = (($14) + ($$sum2$i1361201)|0);
  $226 = Math_fround(HEAPF32[$225>>2]);
  $227 = (($vpIt$01384) + 14|0);
  $228 = HEAP16[$227>>1]|0;
  $229 = $228&65535;
  $230 = $229 << 4;
  $231 = (($12) + ($230)|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $$sum$i1311202 = $230 | 4;
  $233 = (($12) + ($$sum$i1311202)|0);
  $234 = Math_fround(HEAPF32[$233>>2]);
  $$sum1$i1321203 = $230 | 8;
  $235 = (($12) + ($$sum1$i1321203)|0);
  $236 = Math_fround(HEAPF32[$235>>2]);
  $$sum2$i1331204 = $230 | 12;
  $237 = (($12) + ($$sum2$i1331204)|0);
  $238 = Math_fround(HEAPF32[$237>>2]);
  $239 = (HEAPF32[tempDoublePtr>>2]=$232,HEAP32[tempDoublePtr>>2]|0);
  $240 = (HEAPF32[tempDoublePtr>>2]=$234,HEAP32[tempDoublePtr>>2]|0);
  $241 = (HEAPF32[tempDoublePtr>>2]=$236,HEAP32[tempDoublePtr>>2]|0);
  $242 = (($vpIt$01384) + 16|0);
  $243 = HEAP16[$242>>1]|0;
  $244 = $243&65535;
  $245 = $244 << 4;
  $246 = (($14) + ($245)|0);
  $247 = Math_fround(HEAPF32[$246>>2]);
  $$sum$i1281205 = $245 | 4;
  $248 = (($14) + ($$sum$i1281205)|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $$sum1$i1291206 = $245 | 8;
  $250 = (($14) + ($$sum1$i1291206)|0);
  $251 = Math_fround(HEAPF32[$250>>2]);
  $$sum2$i1301207 = $245 | 12;
  $252 = (($14) + ($$sum2$i1301207)|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = (($vpIt$01384) + 18|0);
  $255 = HEAP16[$254>>1]|0;
  $256 = $255&65535;
  $257 = $256 << 4;
  $258 = (($14) + ($257)|0);
  $259 = Math_fround(HEAPF32[$258>>2]);
  $$sum$i1251208 = $257 | 4;
  $260 = (($14) + ($$sum$i1251208)|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $$sum1$i1261209 = $257 | 8;
  $262 = (($14) + ($$sum1$i1261209)|0);
  $263 = Math_fround(HEAPF32[$262>>2]);
  $$sum2$i1271210 = $257 | 12;
  $264 = (($14) + ($$sum2$i1271210)|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = (($vpIt$01384) + 20|0);
  $267 = HEAP16[$266>>1]|0;
  $268 = $267&65535;
  $269 = $268 << 4;
  $270 = (($14) + ($269)|0);
  $271 = Math_fround(HEAPF32[$270>>2]);
  $$sum$i1221211 = $269 | 4;
  $272 = (($14) + ($$sum$i1221211)|0);
  $273 = Math_fround(HEAPF32[$272>>2]);
  $$sum1$i1231212 = $269 | 8;
  $274 = (($14) + ($$sum1$i1231212)|0);
  $275 = Math_fround(HEAPF32[$274>>2]);
  $$sum2$i1241213 = $269 | 12;
  $276 = (($14) + ($$sum2$i1241213)|0);
  $277 = Math_fround(HEAPF32[$276>>2]);
  $278 = (($vpIt$01384) + 22|0);
  $279 = HEAP16[$278>>1]|0;
  $280 = $279&65535;
  $281 = $280 << 4;
  $282 = (($12) + ($281)|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $$sum$i1191214 = $281 | 4;
  $284 = (($12) + ($$sum$i1191214)|0);
  $285 = Math_fround(HEAPF32[$284>>2]);
  $$sum1$i1201215 = $281 | 8;
  $286 = (($12) + ($$sum1$i1201215)|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $$sum2$i1211216 = $281 | 12;
  $288 = (($12) + ($$sum2$i1211216)|0);
  $289 = Math_fround(HEAPF32[$288>>2]);
  $290 = (HEAPF32[tempDoublePtr>>2]=$283,HEAP32[tempDoublePtr>>2]|0);
  $291 = (HEAPF32[tempDoublePtr>>2]=$285,HEAP32[tempDoublePtr>>2]|0);
  $292 = (HEAPF32[tempDoublePtr>>2]=$287,HEAP32[tempDoublePtr>>2]|0);
  $293 = (($vpIt$01384) + 26|0);
  $294 = HEAP16[$293>>1]|0;
  $295 = $294&65535;
  $296 = $295 << 4;
  $297 = (($14) + ($296)|0);
  $298 = Math_fround(HEAPF32[$297>>2]);
  $$sum$i1161217 = $296 | 4;
  $299 = (($14) + ($$sum$i1161217)|0);
  $300 = Math_fround(HEAPF32[$299>>2]);
  $$sum1$i1171218 = $296 | 8;
  $301 = (($14) + ($$sum1$i1171218)|0);
  $302 = Math_fround(HEAPF32[$301>>2]);
  $$sum2$i1181219 = $296 | 12;
  $303 = (($14) + ($$sum2$i1181219)|0);
  $304 = Math_fround(HEAPF32[$303>>2]);
  $305 = (($vpIt$01384) + 24|0);
  $306 = HEAP16[$305>>1]|0;
  $307 = $306&65535;
  $308 = $307 << 4;
  $309 = (($14) + ($308)|0);
  $310 = Math_fround(HEAPF32[$309>>2]);
  $$sum$i1131220 = $308 | 4;
  $311 = (($14) + ($$sum$i1131220)|0);
  $312 = Math_fround(HEAPF32[$311>>2]);
  $$sum1$i1141221 = $308 | 8;
  $313 = (($14) + ($$sum1$i1141221)|0);
  $314 = Math_fround(HEAPF32[$313>>2]);
  $$sum2$i1151222 = $308 | 12;
  $315 = (($14) + ($$sum2$i1151222)|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = (($vpIt$01384) + 28|0);
  $318 = HEAP16[$317>>1]|0;
  $319 = $318&65535;
  $320 = $319 << 4;
  $321 = (($14) + ($320)|0);
  $322 = Math_fround(HEAPF32[$321>>2]);
  $$sum$i1101223 = $320 | 4;
  $323 = (($14) + ($$sum$i1101223)|0);
  $324 = Math_fround(HEAPF32[$323>>2]);
  $$sum1$i1111224 = $320 | 8;
  $325 = (($14) + ($$sum1$i1111224)|0);
  $326 = Math_fround(HEAPF32[$325>>2]);
  $$sum2$i1121225 = $320 | 12;
  $327 = (($14) + ($$sum2$i1121225)|0);
  $328 = Math_fround(HEAPF32[$327>>2]);
  $329 = (($vpIt$01384) + 30|0);
  $330 = HEAP16[$329>>1]|0;
  $331 = $330&65535;
  $332 = $331 << 4;
  $333 = (($12) + ($332)|0);
  $334 = Math_fround(HEAPF32[$333>>2]);
  $$sum$i1071226 = $332 | 4;
  $335 = (($12) + ($$sum$i1071226)|0);
  $336 = Math_fround(HEAPF32[$335>>2]);
  $$sum1$i1081227 = $332 | 8;
  $337 = (($12) + ($$sum1$i1081227)|0);
  $338 = Math_fround(HEAPF32[$337>>2]);
  $$sum2$i1091228 = $332 | 12;
  $339 = (($12) + ($$sum2$i1091228)|0);
  $340 = Math_fround(HEAPF32[$339>>2]);
  $341 = (HEAPF32[tempDoublePtr>>2]=$334,HEAP32[tempDoublePtr>>2]|0);
  $342 = (HEAPF32[tempDoublePtr>>2]=$336,HEAP32[tempDoublePtr>>2]|0);
  $343 = (HEAPF32[tempDoublePtr>>2]=$338,HEAP32[tempDoublePtr>>2]|0);
  $344 = Math_fround($145 * $181);
  $345 = Math_fround($147 * $181);
  $346 = Math_fround($149 * $181);
  $347 = Math_fround($157 * $183);
  $348 = Math_fround($159 * $183);
  $349 = Math_fround($161 * $183);
  $350 = Math_fround($344 + $347);
  $351 = Math_fround($345 + $348);
  $352 = Math_fround($346 + $349);
  $353 = Math_fround($169 * $185);
  $354 = Math_fround($171 * $185);
  $355 = Math_fround($173 * $185);
  $356 = Math_fround($350 + $353);
  $357 = Math_fround($351 + $354);
  $358 = Math_fround($352 + $355);
  $359 = (HEAPF32[tempDoublePtr>>2]=$356,HEAP32[tempDoublePtr>>2]|0);
  $360 = Math_fround($196 * $232);
  $361 = Math_fround($198 * $232);
  $362 = Math_fround($200 * $232);
  $363 = Math_fround($208 * $234);
  $364 = Math_fround($210 * $234);
  $365 = Math_fround($212 * $234);
  $366 = Math_fround($360 + $363);
  $367 = Math_fround($361 + $364);
  $368 = Math_fround($362 + $365);
  $369 = Math_fround($220 * $236);
  $370 = Math_fround($222 * $236);
  $371 = Math_fround($224 * $236);
  $372 = Math_fround($366 + $369);
  $373 = Math_fround($367 + $370);
  $374 = Math_fround($368 + $371);
  $375 = (HEAPF32[tempDoublePtr>>2]=$373,HEAP32[tempDoublePtr>>2]|0);
  $376 = Math_fround($247 * $283);
  $377 = Math_fround($249 * $283);
  $378 = Math_fround($251 * $283);
  $379 = Math_fround($259 * $285);
  $380 = Math_fround($261 * $285);
  $381 = Math_fround($263 * $285);
  $382 = Math_fround($376 + $379);
  $383 = Math_fround($377 + $380);
  $384 = Math_fround($378 + $381);
  $385 = Math_fround($271 * $287);
  $386 = Math_fround($273 * $287);
  $387 = Math_fround($275 * $287);
  $388 = Math_fround($382 + $385);
  $389 = Math_fround($383 + $386);
  $390 = Math_fround($384 + $387);
  $391 = (HEAPF32[tempDoublePtr>>2]=$390,HEAP32[tempDoublePtr>>2]|0);
  $392 = Math_fround($310 * $334);
  $393 = Math_fround($312 * $334);
  $394 = Math_fround($314 * $334);
  $395 = Math_fround($298 * $336);
  $396 = Math_fround($300 * $336);
  $397 = Math_fround($302 * $336);
  $398 = Math_fround($392 + $395);
  $399 = Math_fround($393 + $396);
  $400 = Math_fround($394 + $397);
  $401 = Math_fround($322 * $338);
  $402 = Math_fround($324 * $338);
  $403 = Math_fround($326 * $338);
  $404 = Math_fround($398 + $401);
  $405 = Math_fround($399 + $402);
  $406 = Math_fround($400 + $403);
  $407 = (HEAPF32[tempDoublePtr>>2]=$372,HEAP32[tempDoublePtr>>2]|0);
  $408 = (HEAPF32[tempDoublePtr>>2]=$388,HEAP32[tempDoublePtr>>2]|0);
  $409 = (HEAPF32[tempDoublePtr>>2]=$404,HEAP32[tempDoublePtr>>2]|0);
  $410 = (HEAPF32[tempDoublePtr>>2]=$357,HEAP32[tempDoublePtr>>2]|0);
  $411 = (HEAPF32[tempDoublePtr>>2]=$389,HEAP32[tempDoublePtr>>2]|0);
  $412 = (HEAPF32[tempDoublePtr>>2]=$405,HEAP32[tempDoublePtr>>2]|0);
  $413 = (HEAPF32[tempDoublePtr>>2]=$358,HEAP32[tempDoublePtr>>2]|0);
  $414 = (HEAPF32[tempDoublePtr>>2]=$374,HEAP32[tempDoublePtr>>2]|0);
  $415 = (HEAPF32[tempDoublePtr>>2]=$406,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$curPos>>2] = $359;
  HEAP32[$80>>2] = $407;
  HEAP32[$81>>2] = $408;
  HEAP32[$82>>2] = $409;
  HEAP32[$83>>2] = $410;
  HEAP32[$84>>2] = $375;
  HEAP32[$85>>2] = $411;
  HEAP32[$86>>2] = $412;
  HEAP32[$87>>2] = $413;
  HEAP32[$88>>2] = $414;
  HEAP32[$89>>2] = $391;
  HEAP32[$90>>2] = $415;
  dest=$accum+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $416 = HEAP32[478152>>2]|0;
  HEAP32[$91>>2] = $416;
  $417 = HEAP32[((478152 + 4|0))>>2]|0;
  HEAP32[$92>>2] = $417;
  $418 = HEAP32[((478152 + 8|0))>>2]|0;
  HEAP32[$93>>2] = $418;
  $419 = HEAP32[((478152 + 12|0))>>2]|0;
  HEAP32[$94>>2] = $419;
  __ZNK5physx5cloth11SwCollisionI8Scalar4fE12collideConesEPKS2_RNS3_18ImpulseAccumulatorE($sphereMask,$this,$curPos,$accum);
  __ZNK5physx5cloth11SwCollisionI8Scalar4fE14collideSpheresERKS2_PS4_RNS3_18ImpulseAccumulatorE($this,$sphereMask,$curPos,$accum);
  $420 = HEAP32[478152>>2]|0;
  $421 = HEAP32[((478152 + 4|0))>>2]|0;
  $422 = HEAP32[((478152 + 8|0))>>2]|0;
  $423 = HEAP32[((478152 + 12|0))>>2]|0;
  $424 = Math_fround(HEAPF32[$91>>2]);
  $425 = (HEAP32[tempDoublePtr>>2]=$420,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $426 = $424 > $425;
  $427 = Math_fround(HEAPF32[$92>>2]);
  $428 = (HEAP32[tempDoublePtr>>2]=$421,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $429 = $427 > $428;
  $430 = Math_fround(HEAPF32[$93>>2]);
  $431 = (HEAP32[tempDoublePtr>>2]=$422,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $432 = $430 > $431;
  $433 = Math_fround(HEAPF32[$94>>2]);
  $434 = (HEAP32[tempDoublePtr>>2]=$423,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $435 = $433 > $434;
  $not$x$i$i$i = $426 ^ 1;
  $436 = $not$x$i$i$i << 31 >> 31;
  $437 = $436 ^ -1;
  $not$y$i$i$i = $429 ^ 1;
  $438 = $not$y$i$i$i << 31 >> 31;
  $439 = $438 ^ -1;
  $not$z$i$i$i = $432 ^ 1;
  $440 = $not$z$i$i$i << 31 >> 31;
  $441 = $440 ^ -1;
  $not$w$i$i$i = $435 ^ 1;
  $442 = $not$w$i$i$i << 31 >> 31;
  $443 = $442 ^ -1;
  HEAP32[$mask>>2] = $437;
  HEAP32[$95>>2] = $439;
  HEAP32[$96>>2] = $441;
  HEAP32[$97>>2] = $443;
  $brmerge$i = $426 | $429;
  $brmerge1$i = $brmerge$i | $432;
  $$$i = $brmerge1$i | $435;
  if ($$$i) {
   $444 = Math_fround(Math_fround(1.0) / $424);
   $445 = Math_fround(Math_fround(1.0) / $427);
   $446 = Math_fround(Math_fround(1.0) / $430);
   $447 = Math_fround(Math_fround(1.0) / $433);
   HEAPF32[$invNumCollisions>>2] = $444;
   HEAPF32[$98>>2] = $445;
   HEAPF32[$99>>2] = $446;
   HEAPF32[$100>>2] = $447;
   $448 = Math_fround(HEAPF32[$accum>>2]);
   $449 = Math_fround($448 * $444);
   $450 = Math_fround(HEAPF32[$101>>2]);
   $451 = Math_fround($450 * $445);
   $452 = Math_fround(HEAPF32[$102>>2]);
   $453 = Math_fround($452 * $446);
   $454 = Math_fround(HEAPF32[$103>>2]);
   $455 = Math_fround($447 * $454);
   $456 = Math_fround(HEAPF32[$104>>2]);
   $457 = Math_fround($444 * $456);
   $458 = Math_fround(HEAPF32[$105>>2]);
   $459 = Math_fround($445 * $458);
   $460 = Math_fround(HEAPF32[$106>>2]);
   $461 = Math_fround($446 * $460);
   $462 = Math_fround(HEAPF32[$107>>2]);
   $463 = Math_fround($447 * $462);
   $464 = Math_fround(HEAPF32[$108>>2]);
   $465 = Math_fround($444 * $464);
   $466 = Math_fround(HEAPF32[$109>>2]);
   $467 = Math_fround($445 * $466);
   $468 = Math_fround(HEAPF32[$110>>2]);
   $469 = Math_fround($446 * $468);
   $470 = Math_fround(HEAPF32[$111>>2]);
   $471 = Math_fround($447 * $470);
   $472 = HEAP32[478232>>2]|0;
   $473 = HEAP32[((478232 + 4|0))>>2]|0;
   $474 = HEAP32[((478232 + 8|0))>>2]|0;
   $475 = HEAP32[((478232 + 12|0))>>2]|0;
   $476 = (HEAP32[tempDoublePtr>>2]=$472,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $477 = (HEAP32[tempDoublePtr>>2]=$473,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $478 = (HEAP32[tempDoublePtr>>2]=$474,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $479 = Math_fround($181 * $187);
   $480 = Math_fround($183 * $187);
   $481 = Math_fround($185 * $187);
   $482 = Math_fround($232 * $238);
   $483 = Math_fround($234 * $238);
   $484 = Math_fround($236 * $238);
   $485 = Math_fround($283 * $289);
   $486 = Math_fround($285 * $289);
   $487 = Math_fround($287 * $289);
   $488 = Math_fround($334 * $340);
   $489 = Math_fround($336 * $340);
   $490 = Math_fround($338 * $340);
   if ($10) {
    $491 = HEAP16[$vpIt$01384>>1]|0;
    $492 = $491&65535;
    $493 = $492 << 4;
    $494 = (($16) + ($493)|0);
    $495 = Math_fround(HEAPF32[$494>>2]);
    $$sum$i1041312 = $493 | 4;
    $496 = (($16) + ($$sum$i1041312)|0);
    $497 = Math_fround(HEAPF32[$496>>2]);
    $$sum1$i1051313 = $493 | 8;
    $498 = (($16) + ($$sum1$i1051313)|0);
    $499 = Math_fround(HEAPF32[$498>>2]);
    $$sum2$i1061314 = $493 | 12;
    $500 = (($16) + ($$sum2$i1061314)|0);
    $501 = Math_fround(HEAPF32[$500>>2]);
    $502 = HEAP16[$152>>1]|0;
    $503 = $502&65535;
    $504 = $503 << 4;
    $505 = (($16) + ($504)|0);
    $506 = Math_fround(HEAPF32[$505>>2]);
    $$sum$i1011315 = $504 | 4;
    $507 = (($16) + ($$sum$i1011315)|0);
    $508 = Math_fround(HEAPF32[$507>>2]);
    $$sum1$i1021316 = $504 | 8;
    $509 = (($16) + ($$sum1$i1021316)|0);
    $510 = Math_fround(HEAPF32[$509>>2]);
    $$sum2$i1031317 = $504 | 12;
    $511 = (($16) + ($$sum2$i1031317)|0);
    $512 = Math_fround(HEAPF32[$511>>2]);
    $513 = HEAP16[$164>>1]|0;
    $514 = $513&65535;
    $515 = $514 << 4;
    $516 = (($16) + ($515)|0);
    $517 = Math_fround(HEAPF32[$516>>2]);
    $$sum$i981318 = $515 | 4;
    $518 = (($16) + ($$sum$i981318)|0);
    $519 = Math_fround(HEAPF32[$518>>2]);
    $$sum1$i991319 = $515 | 8;
    $520 = (($16) + ($$sum1$i991319)|0);
    $521 = Math_fround(HEAPF32[$520>>2]);
    $$sum2$i1001320 = $515 | 12;
    $522 = (($16) + ($$sum2$i1001320)|0);
    $523 = Math_fround(HEAPF32[$522>>2]);
    $524 = HEAP16[$191>>1]|0;
    $525 = $524&65535;
    $526 = $525 << 4;
    $527 = (($16) + ($526)|0);
    $528 = Math_fround(HEAPF32[$527>>2]);
    $$sum$i951321 = $526 | 4;
    $529 = (($16) + ($$sum$i951321)|0);
    $530 = Math_fround(HEAPF32[$529>>2]);
    $$sum1$i961322 = $526 | 8;
    $531 = (($16) + ($$sum1$i961322)|0);
    $532 = Math_fround(HEAPF32[$531>>2]);
    $$sum2$i971323 = $526 | 12;
    $533 = (($16) + ($$sum2$i971323)|0);
    $534 = Math_fround(HEAPF32[$533>>2]);
    $535 = HEAP16[$203>>1]|0;
    $536 = $535&65535;
    $537 = $536 << 4;
    $538 = (($16) + ($537)|0);
    $539 = Math_fround(HEAPF32[$538>>2]);
    $$sum$i921324 = $537 | 4;
    $540 = (($16) + ($$sum$i921324)|0);
    $541 = Math_fround(HEAPF32[$540>>2]);
    $$sum1$i931325 = $537 | 8;
    $542 = (($16) + ($$sum1$i931325)|0);
    $543 = Math_fround(HEAPF32[$542>>2]);
    $$sum2$i941326 = $537 | 12;
    $544 = (($16) + ($$sum2$i941326)|0);
    $545 = Math_fround(HEAPF32[$544>>2]);
    $546 = HEAP16[$215>>1]|0;
    $547 = $546&65535;
    $548 = $547 << 4;
    $549 = (($16) + ($548)|0);
    $550 = Math_fround(HEAPF32[$549>>2]);
    $$sum$i891327 = $548 | 4;
    $551 = (($16) + ($$sum$i891327)|0);
    $552 = Math_fround(HEAPF32[$551>>2]);
    $$sum1$i901328 = $548 | 8;
    $553 = (($16) + ($$sum1$i901328)|0);
    $554 = Math_fround(HEAPF32[$553>>2]);
    $$sum2$i911329 = $548 | 12;
    $555 = (($16) + ($$sum2$i911329)|0);
    $556 = Math_fround(HEAPF32[$555>>2]);
    $557 = HEAP16[$242>>1]|0;
    $558 = $557&65535;
    $559 = $558 << 4;
    $560 = (($16) + ($559)|0);
    $561 = Math_fround(HEAPF32[$560>>2]);
    $$sum$i861330 = $559 | 4;
    $562 = (($16) + ($$sum$i861330)|0);
    $563 = Math_fround(HEAPF32[$562>>2]);
    $$sum1$i871331 = $559 | 8;
    $564 = (($16) + ($$sum1$i871331)|0);
    $565 = Math_fround(HEAPF32[$564>>2]);
    $$sum2$i881332 = $559 | 12;
    $566 = (($16) + ($$sum2$i881332)|0);
    $567 = Math_fround(HEAPF32[$566>>2]);
    $568 = HEAP16[$254>>1]|0;
    $569 = $568&65535;
    $570 = $569 << 4;
    $571 = (($16) + ($570)|0);
    $572 = Math_fround(HEAPF32[$571>>2]);
    $$sum$i831333 = $570 | 4;
    $573 = (($16) + ($$sum$i831333)|0);
    $574 = Math_fround(HEAPF32[$573>>2]);
    $$sum1$i841334 = $570 | 8;
    $575 = (($16) + ($$sum1$i841334)|0);
    $576 = Math_fround(HEAPF32[$575>>2]);
    $$sum2$i851335 = $570 | 12;
    $577 = (($16) + ($$sum2$i851335)|0);
    $578 = Math_fround(HEAPF32[$577>>2]);
    $579 = HEAP16[$266>>1]|0;
    $580 = $579&65535;
    $581 = $580 << 4;
    $582 = (($16) + ($581)|0);
    $583 = Math_fround(HEAPF32[$582>>2]);
    $$sum$i801336 = $581 | 4;
    $584 = (($16) + ($$sum$i801336)|0);
    $585 = Math_fround(HEAPF32[$584>>2]);
    $$sum1$i811337 = $581 | 8;
    $586 = (($16) + ($$sum1$i811337)|0);
    $587 = Math_fround(HEAPF32[$586>>2]);
    $$sum2$i821338 = $581 | 12;
    $588 = (($16) + ($$sum2$i821338)|0);
    $589 = Math_fround(HEAPF32[$588>>2]);
    $590 = HEAP16[$305>>1]|0;
    $591 = $590&65535;
    $592 = $591 << 4;
    $593 = (($16) + ($592)|0);
    $594 = Math_fround(HEAPF32[$593>>2]);
    $$sum$i771339 = $592 | 4;
    $595 = (($16) + ($$sum$i771339)|0);
    $596 = Math_fround(HEAPF32[$595>>2]);
    $$sum1$i781340 = $592 | 8;
    $597 = (($16) + ($$sum1$i781340)|0);
    $598 = Math_fround(HEAPF32[$597>>2]);
    $$sum2$i791341 = $592 | 12;
    $599 = (($16) + ($$sum2$i791341)|0);
    $600 = Math_fround(HEAPF32[$599>>2]);
    $601 = HEAP16[$293>>1]|0;
    $602 = $601&65535;
    $603 = $602 << 4;
    $604 = (($16) + ($603)|0);
    $605 = Math_fround(HEAPF32[$604>>2]);
    $$sum$i741342 = $603 | 4;
    $606 = (($16) + ($$sum$i741342)|0);
    $607 = Math_fround(HEAPF32[$606>>2]);
    $$sum1$i751343 = $603 | 8;
    $608 = (($16) + ($$sum1$i751343)|0);
    $609 = Math_fround(HEAPF32[$608>>2]);
    $$sum2$i761344 = $603 | 12;
    $610 = (($16) + ($$sum2$i761344)|0);
    $611 = Math_fround(HEAPF32[$610>>2]);
    $612 = HEAP16[$317>>1]|0;
    $613 = $612&65535;
    $614 = $613 << 4;
    $615 = (($16) + ($614)|0);
    $616 = Math_fround(HEAPF32[$615>>2]);
    $$sum$i711345 = $614 | 4;
    $617 = (($16) + ($$sum$i711345)|0);
    $618 = Math_fround(HEAPF32[$617>>2]);
    $$sum1$i721346 = $614 | 8;
    $619 = (($16) + ($$sum1$i721346)|0);
    $620 = Math_fround(HEAPF32[$619>>2]);
    $$sum2$i731347 = $614 | 12;
    $621 = (($16) + ($$sum2$i731347)|0);
    $622 = Math_fround(HEAPF32[$621>>2]);
    $623 = Math_fround($181 * $495);
    $624 = Math_fround($181 * $497);
    $625 = Math_fround($181 * $499);
    $626 = Math_fround($183 * $506);
    $627 = Math_fround($183 * $508);
    $628 = Math_fround($183 * $510);
    $629 = Math_fround($623 + $626);
    $630 = Math_fround($624 + $627);
    $631 = Math_fround($625 + $628);
    $632 = Math_fround($185 * $517);
    $633 = Math_fround($185 * $519);
    $634 = Math_fround($185 * $521);
    $635 = Math_fround($629 + $632);
    $636 = Math_fround($630 + $633);
    $637 = Math_fround($631 + $634);
    $638 = (HEAPF32[tempDoublePtr>>2]=$635,HEAP32[tempDoublePtr>>2]|0);
    $639 = Math_fround($232 * $528);
    $640 = Math_fround($232 * $530);
    $641 = Math_fround($232 * $532);
    $642 = Math_fround($234 * $539);
    $643 = Math_fround($234 * $541);
    $644 = Math_fround($234 * $543);
    $645 = Math_fround($639 + $642);
    $646 = Math_fround($640 + $643);
    $647 = Math_fround($641 + $644);
    $648 = Math_fround($236 * $550);
    $649 = Math_fround($236 * $552);
    $650 = Math_fround($236 * $554);
    $651 = Math_fround($645 + $648);
    $652 = Math_fround($646 + $649);
    $653 = Math_fround($647 + $650);
    $654 = (HEAPF32[tempDoublePtr>>2]=$652,HEAP32[tempDoublePtr>>2]|0);
    $655 = Math_fround($283 * $561);
    $656 = Math_fround($283 * $563);
    $657 = Math_fround($283 * $565);
    $658 = Math_fround($285 * $572);
    $659 = Math_fround($285 * $574);
    $660 = Math_fround($285 * $576);
    $661 = Math_fround($655 + $658);
    $662 = Math_fround($656 + $659);
    $663 = Math_fround($657 + $660);
    $664 = Math_fround($287 * $583);
    $665 = Math_fround($287 * $585);
    $666 = Math_fround($287 * $587);
    $667 = Math_fround($661 + $664);
    $668 = Math_fround($662 + $665);
    $669 = Math_fround($663 + $666);
    $670 = (HEAPF32[tempDoublePtr>>2]=$669,HEAP32[tempDoublePtr>>2]|0);
    $671 = Math_fround($334 * $594);
    $672 = Math_fround($334 * $596);
    $673 = Math_fround($334 * $598);
    $674 = Math_fround($336 * $605);
    $675 = Math_fround($336 * $607);
    $676 = Math_fround($336 * $609);
    $677 = Math_fround($671 + $674);
    $678 = Math_fround($672 + $675);
    $679 = Math_fround($673 + $676);
    $680 = Math_fround($338 * $616);
    $681 = Math_fround($338 * $618);
    $682 = Math_fround($338 * $620);
    $683 = Math_fround($677 + $680);
    $684 = Math_fround($678 + $681);
    $685 = Math_fround($679 + $682);
    $686 = (HEAPF32[tempDoublePtr>>2]=$651,HEAP32[tempDoublePtr>>2]|0);
    $687 = (HEAPF32[tempDoublePtr>>2]=$667,HEAP32[tempDoublePtr>>2]|0);
    $688 = (HEAPF32[tempDoublePtr>>2]=$683,HEAP32[tempDoublePtr>>2]|0);
    $689 = (HEAPF32[tempDoublePtr>>2]=$636,HEAP32[tempDoublePtr>>2]|0);
    $690 = (HEAPF32[tempDoublePtr>>2]=$668,HEAP32[tempDoublePtr>>2]|0);
    $691 = (HEAPF32[tempDoublePtr>>2]=$684,HEAP32[tempDoublePtr>>2]|0);
    $692 = (HEAPF32[tempDoublePtr>>2]=$637,HEAP32[tempDoublePtr>>2]|0);
    $693 = (HEAPF32[tempDoublePtr>>2]=$653,HEAP32[tempDoublePtr>>2]|0);
    $694 = (HEAPF32[tempDoublePtr>>2]=$685,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$prevPos>>2] = $638;
    HEAP32[$112>>2] = $686;
    HEAP32[$113>>2] = $687;
    HEAP32[$114>>2] = $688;
    HEAP32[$115>>2] = $689;
    HEAP32[$116>>2] = $654;
    HEAP32[$117>>2] = $690;
    HEAP32[$118>>2] = $691;
    HEAP32[$119>>2] = $692;
    HEAP32[$120>>2] = $693;
    HEAP32[$121>>2] = $670;
    HEAP32[$122>>2] = $694;
    $695 = HEAP32[478232>>2]|0;
    $696 = HEAP32[((478232 + 4|0))>>2]|0;
    $697 = HEAP32[((478232 + 8|0))>>2]|0;
    $698 = HEAP32[((478232 + 12|0))>>2]|0;
    HEAP32[$123>>2] = $695;
    HEAP32[$124>>2] = $696;
    HEAP32[$125>>2] = $697;
    HEAP32[$126>>2] = $698;
    __ZN12_GLOBAL__N_124calculateFrictionImpulseI8Scalar4fEEvRKT_S4_S4_S4_S4_S4_PS3_S5_S4_S4_S4_PS2_($accum,$104,$108,$127,$128,$129,$curPos,$prevPos,$invNumCollisions,$frictionScale,$mask,$frictionImpulse);
    $699 = Math_fround(HEAPF32[$130>>2]);
    $700 = Math_fround(HEAPF32[$131>>2]);
    $701 = Math_fround(HEAPF32[$132>>2]);
    $702 = Math_fround(HEAPF32[$133>>2]);
    $703 = Math_fround(HEAPF32[$134>>2]);
    $704 = Math_fround(HEAPF32[$135>>2]);
    $705 = Math_fround(HEAPF32[$136>>2]);
    HEAPF32[$130>>2] = $705;
    $706 = Math_fround(HEAPF32[$137>>2]);
    HEAPF32[$131>>2] = $706;
    $707 = Math_fround(HEAPF32[$123>>2]);
    HEAPF32[$132>>2] = $707;
    HEAPF32[$136>>2] = $699;
    $708 = Math_fround(HEAPF32[$138>>2]);
    HEAPF32[$133>>2] = $708;
    $709 = Math_fround(HEAPF32[$124>>2]);
    HEAPF32[$134>>2] = $709;
    HEAPF32[$137>>2] = $700;
    HEAPF32[$138>>2] = $702;
    $710 = Math_fround(HEAPF32[$125>>2]);
    HEAPF32[$135>>2] = $710;
    HEAPF32[$123>>2] = $701;
    HEAPF32[$124>>2] = $703;
    HEAPF32[$125>>2] = $704;
    $711 = Math_fround(HEAPF32[$frictionImpulse>>2]);
    $712 = Math_fround($479 * $711);
    $713 = Math_fround($479 * $705);
    $714 = Math_fround($479 * $706);
    $715 = Math_fround($479 * $707);
    $716 = Math_fround($495 - $712);
    $717 = Math_fround($497 - $713);
    $718 = Math_fround($499 - $714);
    $719 = Math_fround($501 - $715);
    $720 = Math_fround($480 * $711);
    $721 = Math_fround($480 * $705);
    $722 = Math_fround($480 * $706);
    $723 = Math_fround($480 * $707);
    $724 = Math_fround($506 - $720);
    $725 = Math_fround($508 - $721);
    $726 = Math_fround($510 - $722);
    $727 = Math_fround($512 - $723);
    $728 = Math_fround($481 * $711);
    $729 = Math_fround($481 * $705);
    $730 = Math_fround($481 * $706);
    $731 = Math_fround($481 * $707);
    $732 = Math_fround($517 - $728);
    $733 = Math_fround($519 - $729);
    $734 = Math_fround($521 - $730);
    $735 = Math_fround($523 - $731);
    $736 = Math_fround($482 * $699);
    $737 = Math_fround(HEAPF32[$139>>2]);
    $738 = Math_fround($482 * $737);
    $739 = Math_fround($482 * $708);
    $740 = Math_fround($482 * $709);
    $741 = Math_fround($528 - $736);
    $742 = Math_fround($530 - $738);
    $743 = Math_fround($532 - $739);
    $744 = Math_fround($534 - $740);
    $745 = Math_fround($483 * $699);
    $746 = Math_fround($483 * $737);
    $747 = Math_fround($483 * $708);
    $748 = Math_fround($483 * $709);
    $749 = Math_fround($539 - $745);
    $750 = Math_fround($541 - $746);
    $751 = Math_fround($543 - $747);
    $752 = Math_fround($545 - $748);
    $753 = Math_fround($484 * $699);
    $754 = Math_fround($484 * $737);
    $755 = Math_fround($484 * $708);
    $756 = Math_fround($484 * $709);
    $757 = Math_fround($550 - $753);
    $758 = Math_fround($552 - $754);
    $759 = Math_fround($554 - $755);
    $760 = Math_fround($556 - $756);
    $761 = Math_fround($485 * $700);
    $762 = Math_fround($485 * $702);
    $763 = Math_fround(HEAPF32[$140>>2]);
    $764 = Math_fround($485 * $763);
    $765 = Math_fround($485 * $710);
    $766 = Math_fround($561 - $761);
    $767 = Math_fround($563 - $762);
    $768 = Math_fround($565 - $764);
    $769 = Math_fround($567 - $765);
    $770 = Math_fround($486 * $700);
    $771 = Math_fround($486 * $702);
    $772 = Math_fround($486 * $763);
    $773 = Math_fround($486 * $710);
    $774 = Math_fround($572 - $770);
    $775 = Math_fround($574 - $771);
    $776 = Math_fround($576 - $772);
    $777 = Math_fround($578 - $773);
    $778 = Math_fround($487 * $700);
    $779 = Math_fround($487 * $702);
    $780 = Math_fround($487 * $763);
    $781 = Math_fround($487 * $710);
    $782 = Math_fround($583 - $778);
    $783 = Math_fround($585 - $779);
    $784 = Math_fround($587 - $780);
    $785 = Math_fround($589 - $781);
    $786 = Math_fround($488 * $701);
    $787 = Math_fround($488 * $703);
    $788 = Math_fround($488 * $704);
    $789 = Math_fround(HEAPF32[$126>>2]);
    $790 = Math_fround($488 * $789);
    $791 = Math_fround($594 - $786);
    $792 = Math_fround($596 - $787);
    $793 = Math_fround($598 - $788);
    $794 = Math_fround($600 - $790);
    $795 = Math_fround($489 * $701);
    $796 = Math_fround($489 * $703);
    $797 = Math_fround($489 * $704);
    $798 = Math_fround($489 * $789);
    $799 = Math_fround($605 - $795);
    $800 = Math_fround($607 - $796);
    $801 = Math_fround($609 - $797);
    $802 = Math_fround($611 - $798);
    $803 = Math_fround($490 * $701);
    $804 = Math_fround($490 * $703);
    $805 = Math_fround($490 * $704);
    $806 = Math_fround($490 * $789);
    $807 = Math_fround($616 - $803);
    $808 = Math_fround($618 - $804);
    $809 = Math_fround($620 - $805);
    $810 = Math_fround($622 - $806);
    $811 = HEAP16[$vpIt$01384>>1]|0;
    $812 = $811&65535;
    $813 = $812 << 4;
    $814 = (($16) + ($813)|0);
    HEAPF32[$814>>2] = $716;
    $$sum$i681348 = $813 | 4;
    $815 = (($16) + ($$sum$i681348)|0);
    HEAPF32[$815>>2] = $717;
    $$sum1$i691349 = $813 | 8;
    $816 = (($16) + ($$sum1$i691349)|0);
    HEAPF32[$816>>2] = $718;
    $$sum2$i701350 = $813 | 12;
    $817 = (($16) + ($$sum2$i701350)|0);
    HEAPF32[$817>>2] = $719;
    $818 = HEAP16[$152>>1]|0;
    $819 = $818&65535;
    $820 = $819 << 4;
    $821 = (($16) + ($820)|0);
    HEAPF32[$821>>2] = $724;
    $$sum$i651351 = $820 | 4;
    $822 = (($16) + ($$sum$i651351)|0);
    HEAPF32[$822>>2] = $725;
    $$sum1$i661352 = $820 | 8;
    $823 = (($16) + ($$sum1$i661352)|0);
    HEAPF32[$823>>2] = $726;
    $$sum2$i671353 = $820 | 12;
    $824 = (($16) + ($$sum2$i671353)|0);
    HEAPF32[$824>>2] = $727;
    $825 = HEAP16[$164>>1]|0;
    $826 = $825&65535;
    $827 = $826 << 4;
    $828 = (($16) + ($827)|0);
    HEAPF32[$828>>2] = $732;
    $$sum$i621354 = $827 | 4;
    $829 = (($16) + ($$sum$i621354)|0);
    HEAPF32[$829>>2] = $733;
    $$sum1$i631355 = $827 | 8;
    $830 = (($16) + ($$sum1$i631355)|0);
    HEAPF32[$830>>2] = $734;
    $$sum2$i641356 = $827 | 12;
    $831 = (($16) + ($$sum2$i641356)|0);
    HEAPF32[$831>>2] = $735;
    $832 = HEAP16[$191>>1]|0;
    $833 = $832&65535;
    $834 = $833 << 4;
    $835 = (($16) + ($834)|0);
    HEAPF32[$835>>2] = $741;
    $$sum$i591357 = $834 | 4;
    $836 = (($16) + ($$sum$i591357)|0);
    HEAPF32[$836>>2] = $742;
    $$sum1$i601358 = $834 | 8;
    $837 = (($16) + ($$sum1$i601358)|0);
    HEAPF32[$837>>2] = $743;
    $$sum2$i611359 = $834 | 12;
    $838 = (($16) + ($$sum2$i611359)|0);
    HEAPF32[$838>>2] = $744;
    $839 = HEAP16[$203>>1]|0;
    $840 = $839&65535;
    $841 = $840 << 4;
    $842 = (($16) + ($841)|0);
    HEAPF32[$842>>2] = $749;
    $$sum$i561360 = $841 | 4;
    $843 = (($16) + ($$sum$i561360)|0);
    HEAPF32[$843>>2] = $750;
    $$sum1$i571361 = $841 | 8;
    $844 = (($16) + ($$sum1$i571361)|0);
    HEAPF32[$844>>2] = $751;
    $$sum2$i581362 = $841 | 12;
    $845 = (($16) + ($$sum2$i581362)|0);
    HEAPF32[$845>>2] = $752;
    $846 = HEAP16[$215>>1]|0;
    $847 = $846&65535;
    $848 = $847 << 4;
    $849 = (($16) + ($848)|0);
    HEAPF32[$849>>2] = $757;
    $$sum$i531363 = $848 | 4;
    $850 = (($16) + ($$sum$i531363)|0);
    HEAPF32[$850>>2] = $758;
    $$sum1$i541364 = $848 | 8;
    $851 = (($16) + ($$sum1$i541364)|0);
    HEAPF32[$851>>2] = $759;
    $$sum2$i551365 = $848 | 12;
    $852 = (($16) + ($$sum2$i551365)|0);
    HEAPF32[$852>>2] = $760;
    $853 = HEAP16[$242>>1]|0;
    $854 = $853&65535;
    $855 = $854 << 4;
    $856 = (($16) + ($855)|0);
    HEAPF32[$856>>2] = $766;
    $$sum$i501366 = $855 | 4;
    $857 = (($16) + ($$sum$i501366)|0);
    HEAPF32[$857>>2] = $767;
    $$sum1$i511367 = $855 | 8;
    $858 = (($16) + ($$sum1$i511367)|0);
    HEAPF32[$858>>2] = $768;
    $$sum2$i521368 = $855 | 12;
    $859 = (($16) + ($$sum2$i521368)|0);
    HEAPF32[$859>>2] = $769;
    $860 = HEAP16[$254>>1]|0;
    $861 = $860&65535;
    $862 = $861 << 4;
    $863 = (($16) + ($862)|0);
    HEAPF32[$863>>2] = $774;
    $$sum$i471369 = $862 | 4;
    $864 = (($16) + ($$sum$i471369)|0);
    HEAPF32[$864>>2] = $775;
    $$sum1$i481370 = $862 | 8;
    $865 = (($16) + ($$sum1$i481370)|0);
    HEAPF32[$865>>2] = $776;
    $$sum2$i491371 = $862 | 12;
    $866 = (($16) + ($$sum2$i491371)|0);
    HEAPF32[$866>>2] = $777;
    $867 = HEAP16[$266>>1]|0;
    $868 = $867&65535;
    $869 = $868 << 4;
    $870 = (($16) + ($869)|0);
    HEAPF32[$870>>2] = $782;
    $$sum$i441372 = $869 | 4;
    $871 = (($16) + ($$sum$i441372)|0);
    HEAPF32[$871>>2] = $783;
    $$sum1$i451373 = $869 | 8;
    $872 = (($16) + ($$sum1$i451373)|0);
    HEAPF32[$872>>2] = $784;
    $$sum2$i461374 = $869 | 12;
    $873 = (($16) + ($$sum2$i461374)|0);
    HEAPF32[$873>>2] = $785;
    $874 = HEAP16[$305>>1]|0;
    $875 = $874&65535;
    $876 = $875 << 4;
    $877 = (($16) + ($876)|0);
    HEAPF32[$877>>2] = $791;
    $$sum$i411375 = $876 | 4;
    $878 = (($16) + ($$sum$i411375)|0);
    HEAPF32[$878>>2] = $792;
    $$sum1$i421376 = $876 | 8;
    $879 = (($16) + ($$sum1$i421376)|0);
    HEAPF32[$879>>2] = $793;
    $$sum2$i431377 = $876 | 12;
    $880 = (($16) + ($$sum2$i431377)|0);
    HEAPF32[$880>>2] = $794;
    $881 = HEAP16[$293>>1]|0;
    $882 = $881&65535;
    $883 = $882 << 4;
    $884 = (($16) + ($883)|0);
    HEAPF32[$884>>2] = $799;
    $$sum$i381378 = $883 | 4;
    $885 = (($16) + ($$sum$i381378)|0);
    HEAPF32[$885>>2] = $800;
    $$sum1$i391379 = $883 | 8;
    $886 = (($16) + ($$sum1$i391379)|0);
    HEAPF32[$886>>2] = $801;
    $$sum2$i401380 = $883 | 12;
    $887 = (($16) + ($$sum2$i401380)|0);
    HEAPF32[$887>>2] = $802;
    $888 = HEAP16[$317>>1]|0;
    $889 = $888&65535;
    $890 = $889 << 4;
    $891 = (($16) + ($890)|0);
    HEAPF32[$891>>2] = $807;
    $$sum$i351381 = $890 | 4;
    $892 = (($16) + ($$sum$i351381)|0);
    HEAPF32[$892>>2] = $808;
    $$sum1$i361382 = $890 | 8;
    $893 = (($16) + ($$sum1$i361382)|0);
    HEAPF32[$893>>2] = $809;
    $$sum2$i371383 = $890 | 12;
    $894 = (($16) + ($$sum2$i371383)|0);
    HEAPF32[$894>>2] = $810;
   }
   if ($9) {
    $895 = Math_fround(HEAPF32[$invNumCollisions>>2]);
    $896 = Math_fround($895 * $895);
    $897 = Math_fround(HEAPF32[$98>>2]);
    $898 = Math_fround($897 * $897);
    $899 = Math_fround(HEAPF32[$99>>2]);
    $900 = Math_fround($899 * $899);
    $901 = Math_fround(HEAPF32[$100>>2]);
    $902 = Math_fround($901 * $901);
    $903 = Math_fround(HEAPF32[$accum>>2]);
    $904 = Math_fround($903 * $903);
    $905 = Math_fround(HEAPF32[$101>>2]);
    $906 = Math_fround($905 * $905);
    $907 = Math_fround(HEAPF32[$102>>2]);
    $908 = Math_fround($907 * $907);
    $909 = Math_fround(HEAPF32[$103>>2]);
    $910 = Math_fround($909 * $909);
    $911 = Math_fround(HEAPF32[$104>>2]);
    $912 = Math_fround($911 * $911);
    $913 = Math_fround(HEAPF32[$105>>2]);
    $914 = Math_fround($913 * $913);
    $915 = Math_fround(HEAPF32[$106>>2]);
    $916 = Math_fround($915 * $915);
    $917 = Math_fround(HEAPF32[$107>>2]);
    $918 = Math_fround($917 * $917);
    $919 = Math_fround($904 + $912);
    $920 = Math_fround($906 + $914);
    $921 = Math_fround($908 + $916);
    $922 = Math_fround($910 + $918);
    $923 = Math_fround(HEAPF32[$108>>2]);
    $924 = Math_fround($923 * $923);
    $925 = Math_fround(HEAPF32[$109>>2]);
    $926 = Math_fround($925 * $925);
    $927 = Math_fround(HEAPF32[$110>>2]);
    $928 = Math_fround($927 * $927);
    $929 = Math_fround(HEAPF32[$111>>2]);
    $930 = Math_fround($929 * $929);
    $931 = Math_fround($919 + $924);
    $932 = Math_fround($920 + $926);
    $933 = Math_fround($921 + $928);
    $934 = Math_fround($922 + $930);
    $935 = Math_fround($896 * $931);
    $936 = Math_fround($898 * $932);
    $937 = Math_fround($900 * $933);
    $938 = Math_fround($902 * $934);
    $939 = HEAP32[478248>>2]|0;
    $940 = HEAP32[((478248 + 4|0))>>2]|0;
    $941 = HEAP32[((478248 + 8|0))>>2]|0;
    $942 = HEAP32[((478248 + 12|0))>>2]|0;
    $943 = Math_fround($3 * $935);
    $944 = Math_fround($3 * $936);
    $945 = Math_fround($3 * $937);
    $946 = Math_fround($3 * $938);
    $947 = (HEAP32[tempDoublePtr>>2]=$939,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $948 = Math_fround($943 + $947);
    $949 = (HEAP32[tempDoublePtr>>2]=$940,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $950 = Math_fround($944 + $949);
    $951 = (HEAP32[tempDoublePtr>>2]=$941,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $952 = Math_fround($945 + $951);
    $953 = (HEAP32[tempDoublePtr>>2]=$942,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $954 = Math_fround($946 + $953);
    $955 = Math_fround(Math_fround(1.0) / $948);
    $956 = Math_fround(Math_fround(1.0) / $950);
    $957 = Math_fround(Math_fround(1.0) / $952);
    $958 = Math_fround(Math_fround(1.0) / $954);
    $959 = Math_fround($955 - $947);
    $960 = Math_fround($956 - $949);
    $961 = Math_fround($957 - $951);
    $962 = Math_fround($958 - $953);
    $963 = Math_fround(HEAPF32[$mask>>2]);
    $964 = (HEAPF32[tempDoublePtr>>2]=$963,HEAP32[tempDoublePtr>>2]|0);
    $965 = $964 & $188;
    $966 = $964 & $189;
    $967 = $964 & $190;
    $968 = (HEAP32[tempDoublePtr>>2]=$965,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $969 = Math_fround($959 * $968);
    $970 = (HEAP32[tempDoublePtr>>2]=$966,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $971 = Math_fround($959 * $970);
    $972 = (HEAP32[tempDoublePtr>>2]=$967,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $973 = Math_fround($959 * $972);
    $974 = Math_fround($947 + $969);
    $975 = Math_fround($949 + $971);
    $976 = Math_fround($951 + $973);
    $977 = Math_fround(HEAPF32[$95>>2]);
    $978 = (HEAPF32[tempDoublePtr>>2]=$977,HEAP32[tempDoublePtr>>2]|0);
    $979 = $978 & $239;
    $980 = $978 & $240;
    $981 = $978 & $241;
    $982 = (HEAP32[tempDoublePtr>>2]=$979,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $983 = Math_fround($960 * $982);
    $984 = (HEAP32[tempDoublePtr>>2]=$980,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $985 = Math_fround($960 * $984);
    $986 = (HEAP32[tempDoublePtr>>2]=$981,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $987 = Math_fround($960 * $986);
    $988 = Math_fround($947 + $983);
    $989 = Math_fround($949 + $985);
    $990 = Math_fround($951 + $987);
    $991 = Math_fround(HEAPF32[$96>>2]);
    $992 = (HEAPF32[tempDoublePtr>>2]=$991,HEAP32[tempDoublePtr>>2]|0);
    $993 = $992 & $290;
    $994 = $992 & $291;
    $995 = $992 & $292;
    $996 = (HEAP32[tempDoublePtr>>2]=$993,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $997 = Math_fround($961 * $996);
    $998 = (HEAP32[tempDoublePtr>>2]=$994,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $999 = Math_fround($961 * $998);
    $1000 = (HEAP32[tempDoublePtr>>2]=$995,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1001 = Math_fround($961 * $1000);
    $1002 = Math_fround($947 + $997);
    $1003 = Math_fround($949 + $999);
    $1004 = Math_fround($951 + $1001);
    $1005 = Math_fround(HEAPF32[$97>>2]);
    $1006 = (HEAPF32[tempDoublePtr>>2]=$1005,HEAP32[tempDoublePtr>>2]|0);
    $1007 = $1006 & $341;
    $1008 = $1006 & $342;
    $1009 = $1006 & $343;
    $1010 = (HEAP32[tempDoublePtr>>2]=$1007,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1011 = Math_fround($962 * $1010);
    $1012 = (HEAP32[tempDoublePtr>>2]=$1008,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1013 = Math_fround($962 * $1012);
    $1014 = (HEAP32[tempDoublePtr>>2]=$1009,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1015 = Math_fround($962 * $1014);
    $1016 = Math_fround($947 + $1011);
    $1017 = Math_fround($949 + $1013);
    $1018 = Math_fround($951 + $1015);
    $1019 = HEAP32[478296>>2]|0;
    $1020 = HEAP32[((478296 + 4|0))>>2]|0;
    $1021 = HEAP32[((478296 + 8|0))>>2]|0;
    $1022 = HEAP32[((478296 + 12|0))>>2]|0;
    $1023 = (HEAPF32[tempDoublePtr>>2]=$974,HEAP32[tempDoublePtr>>2]|0);
    $1024 = HEAP32[478216>>2]|0;
    $1025 = HEAP32[((478216 + 4|0))>>2]|0;
    $1026 = HEAP32[((478216 + 8|0))>>2]|0;
    $1027 = HEAP32[((478216 + 12|0))>>2]|0;
    $1028 = $1024 & $1023;
    $1029 = $1025 & $1023;
    $1030 = $1026 & $1023;
    $1031 = $1027 & $1023;
    $1032 = $1028 | $1019;
    $1033 = $1029 | $1020;
    $1034 = $1030 | $1021;
    $1035 = $1031 | $1022;
    $1036 = (HEAP32[tempDoublePtr>>2]=$1032,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1037 = Math_fround($145 * $1036);
    $1038 = (HEAP32[tempDoublePtr>>2]=$1033,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1039 = Math_fround($147 * $1038);
    $1040 = (HEAP32[tempDoublePtr>>2]=$1034,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1041 = Math_fround($149 * $1040);
    $1042 = (HEAP32[tempDoublePtr>>2]=$1035,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1043 = Math_fround($151 * $1042);
    $1044 = (HEAPF32[tempDoublePtr>>2]=$975,HEAP32[tempDoublePtr>>2]|0);
    $1045 = $1024 & $1044;
    $1046 = $1025 & $1044;
    $1047 = $1026 & $1044;
    $1048 = $1027 & $1044;
    $1049 = $1045 | $1019;
    $1050 = $1046 | $1020;
    $1051 = $1047 | $1021;
    $1052 = $1048 | $1022;
    $1053 = (HEAP32[tempDoublePtr>>2]=$1049,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1054 = Math_fround($157 * $1053);
    $1055 = (HEAP32[tempDoublePtr>>2]=$1050,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1056 = Math_fround($159 * $1055);
    $1057 = (HEAP32[tempDoublePtr>>2]=$1051,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1058 = Math_fround($161 * $1057);
    $1059 = (HEAP32[tempDoublePtr>>2]=$1052,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1060 = Math_fround($163 * $1059);
    $1061 = (HEAPF32[tempDoublePtr>>2]=$976,HEAP32[tempDoublePtr>>2]|0);
    $1062 = $1024 & $1061;
    $1063 = $1025 & $1061;
    $1064 = $1026 & $1061;
    $1065 = $1027 & $1061;
    $1066 = $1062 | $1019;
    $1067 = $1063 | $1020;
    $1068 = $1064 | $1021;
    $1069 = $1065 | $1022;
    $1070 = (HEAP32[tempDoublePtr>>2]=$1066,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1071 = Math_fround($169 * $1070);
    $1072 = (HEAP32[tempDoublePtr>>2]=$1067,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1073 = Math_fround($171 * $1072);
    $1074 = (HEAP32[tempDoublePtr>>2]=$1068,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1075 = Math_fround($173 * $1074);
    $1076 = (HEAP32[tempDoublePtr>>2]=$1069,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1077 = Math_fround($175 * $1076);
    $1078 = (HEAPF32[tempDoublePtr>>2]=$988,HEAP32[tempDoublePtr>>2]|0);
    $1079 = $1024 & $1078;
    $1080 = $1025 & $1078;
    $1081 = $1026 & $1078;
    $1082 = $1027 & $1078;
    $1083 = $1079 | $1019;
    $1084 = $1080 | $1020;
    $1085 = $1081 | $1021;
    $1086 = $1082 | $1022;
    $1087 = (HEAP32[tempDoublePtr>>2]=$1083,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1088 = Math_fround($196 * $1087);
    $1089 = (HEAP32[tempDoublePtr>>2]=$1084,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1090 = Math_fround($198 * $1089);
    $1091 = (HEAP32[tempDoublePtr>>2]=$1085,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1092 = Math_fround($200 * $1091);
    $1093 = (HEAP32[tempDoublePtr>>2]=$1086,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1094 = Math_fround($202 * $1093);
    $1095 = (HEAPF32[tempDoublePtr>>2]=$989,HEAP32[tempDoublePtr>>2]|0);
    $1096 = $1024 & $1095;
    $1097 = $1025 & $1095;
    $1098 = $1026 & $1095;
    $1099 = $1027 & $1095;
    $1100 = $1096 | $1019;
    $1101 = $1097 | $1020;
    $1102 = $1098 | $1021;
    $1103 = $1099 | $1022;
    $1104 = (HEAP32[tempDoublePtr>>2]=$1100,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1105 = Math_fround($208 * $1104);
    $1106 = (HEAP32[tempDoublePtr>>2]=$1101,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1107 = Math_fround($210 * $1106);
    $1108 = (HEAP32[tempDoublePtr>>2]=$1102,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1109 = Math_fround($212 * $1108);
    $1110 = (HEAP32[tempDoublePtr>>2]=$1103,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1111 = Math_fround($214 * $1110);
    $1112 = (HEAPF32[tempDoublePtr>>2]=$990,HEAP32[tempDoublePtr>>2]|0);
    $1113 = $1024 & $1112;
    $1114 = $1025 & $1112;
    $1115 = $1026 & $1112;
    $1116 = $1027 & $1112;
    $1117 = $1113 | $1019;
    $1118 = $1114 | $1020;
    $1119 = $1115 | $1021;
    $1120 = $1116 | $1022;
    $1121 = (HEAP32[tempDoublePtr>>2]=$1117,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1122 = Math_fround($220 * $1121);
    $1123 = (HEAP32[tempDoublePtr>>2]=$1118,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1124 = Math_fround($222 * $1123);
    $1125 = (HEAP32[tempDoublePtr>>2]=$1119,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1126 = Math_fround($224 * $1125);
    $1127 = (HEAP32[tempDoublePtr>>2]=$1120,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1128 = Math_fround($226 * $1127);
    $1129 = (HEAPF32[tempDoublePtr>>2]=$1002,HEAP32[tempDoublePtr>>2]|0);
    $1130 = $1024 & $1129;
    $1131 = $1025 & $1129;
    $1132 = $1026 & $1129;
    $1133 = $1027 & $1129;
    $1134 = $1130 | $1019;
    $1135 = $1131 | $1020;
    $1136 = $1132 | $1021;
    $1137 = $1133 | $1022;
    $1138 = (HEAP32[tempDoublePtr>>2]=$1134,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1139 = Math_fround($247 * $1138);
    $1140 = (HEAP32[tempDoublePtr>>2]=$1135,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1141 = Math_fround($249 * $1140);
    $1142 = (HEAP32[tempDoublePtr>>2]=$1136,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1143 = Math_fround($251 * $1142);
    $1144 = (HEAP32[tempDoublePtr>>2]=$1137,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1145 = Math_fround($253 * $1144);
    $1146 = (HEAPF32[tempDoublePtr>>2]=$1003,HEAP32[tempDoublePtr>>2]|0);
    $1147 = $1024 & $1146;
    $1148 = $1025 & $1146;
    $1149 = $1026 & $1146;
    $1150 = $1027 & $1146;
    $1151 = $1147 | $1019;
    $1152 = $1148 | $1020;
    $1153 = $1149 | $1021;
    $1154 = $1150 | $1022;
    $1155 = (HEAP32[tempDoublePtr>>2]=$1151,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1156 = Math_fround($259 * $1155);
    $1157 = (HEAP32[tempDoublePtr>>2]=$1152,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1158 = Math_fround($261 * $1157);
    $1159 = (HEAP32[tempDoublePtr>>2]=$1153,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1160 = Math_fround($263 * $1159);
    $1161 = (HEAP32[tempDoublePtr>>2]=$1154,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1162 = Math_fround($265 * $1161);
    $1163 = (HEAPF32[tempDoublePtr>>2]=$1004,HEAP32[tempDoublePtr>>2]|0);
    $1164 = $1024 & $1163;
    $1165 = $1025 & $1163;
    $1166 = $1026 & $1163;
    $1167 = $1027 & $1163;
    $1168 = $1164 | $1019;
    $1169 = $1165 | $1020;
    $1170 = $1166 | $1021;
    $1171 = $1167 | $1022;
    $1172 = (HEAP32[tempDoublePtr>>2]=$1168,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1173 = Math_fround($271 * $1172);
    $1174 = (HEAP32[tempDoublePtr>>2]=$1169,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1175 = Math_fround($273 * $1174);
    $1176 = (HEAP32[tempDoublePtr>>2]=$1170,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1177 = Math_fround($275 * $1176);
    $1178 = (HEAP32[tempDoublePtr>>2]=$1171,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1179 = Math_fround($277 * $1178);
    $1180 = (HEAPF32[tempDoublePtr>>2]=$1016,HEAP32[tempDoublePtr>>2]|0);
    $1181 = $1180 & $1024;
    $1182 = $1025 & $1180;
    $1183 = $1026 & $1180;
    $1184 = $1027 & $1180;
    $1185 = $1181 | $1019;
    $1186 = $1182 | $1020;
    $1187 = $1183 | $1021;
    $1188 = $1184 | $1022;
    $1189 = (HEAP32[tempDoublePtr>>2]=$1185,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1190 = Math_fround($310 * $1189);
    $1191 = (HEAP32[tempDoublePtr>>2]=$1186,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1192 = Math_fround($312 * $1191);
    $1193 = (HEAP32[tempDoublePtr>>2]=$1187,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1194 = Math_fround($314 * $1193);
    $1195 = (HEAP32[tempDoublePtr>>2]=$1188,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1196 = Math_fround($316 * $1195);
    $1197 = (HEAPF32[tempDoublePtr>>2]=$1017,HEAP32[tempDoublePtr>>2]|0);
    $1198 = $1197 & $1024;
    $1199 = $1025 & $1197;
    $1200 = $1026 & $1197;
    $1201 = $1027 & $1197;
    $1202 = $1198 | $1019;
    $1203 = $1199 | $1020;
    $1204 = $1200 | $1021;
    $1205 = $1201 | $1022;
    $1206 = (HEAP32[tempDoublePtr>>2]=$1202,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1207 = Math_fround($298 * $1206);
    $1208 = (HEAP32[tempDoublePtr>>2]=$1203,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1209 = Math_fround($300 * $1208);
    $1210 = (HEAP32[tempDoublePtr>>2]=$1204,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1211 = Math_fround($302 * $1210);
    $1212 = (HEAP32[tempDoublePtr>>2]=$1205,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1213 = Math_fround($304 * $1212);
    $1214 = (HEAPF32[tempDoublePtr>>2]=$1018,HEAP32[tempDoublePtr>>2]|0);
    $1215 = $1214 & $1024;
    $1216 = $1025 & $1214;
    $1217 = $1026 & $1214;
    $1218 = $1027 & $1214;
    $1219 = $1215 | $1019;
    $1220 = $1216 | $1020;
    $1221 = $1217 | $1021;
    $1222 = $1218 | $1022;
    $1223 = (HEAP32[tempDoublePtr>>2]=$1219,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1224 = Math_fround($322 * $1223);
    $1225 = (HEAP32[tempDoublePtr>>2]=$1220,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1226 = Math_fround($324 * $1225);
    $1227 = (HEAP32[tempDoublePtr>>2]=$1221,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1228 = Math_fround($326 * $1227);
    $1229 = (HEAP32[tempDoublePtr>>2]=$1222,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1230 = Math_fround($328 * $1229);
    $$in = $1043;$$in1229 = $1041;$$in1230 = $1039;$$in1231 = $1037;$$in1232 = $1060;$$in1233 = $1058;$$in1234 = $1056;$$in1235 = $1054;$$in1236 = $1077;$$in1237 = $1075;$$in1238 = $1073;$$in1239 = $1071;$$in1240 = $1094;$$in1241 = $1092;$$in1242 = $1090;$$in1243 = $1088;$$in1244 = $1111;$$in1245 = $1109;$$in1246 = $1107;$$in1247 = $1105;$$in1248 = $1128;$$in1249 = $1126;$$in1250 = $1124;$$in1251 = $1122;$$in1252 = $1145;$$in1253 = $1143;$$in1254 = $1141;$$in1255 = $1139;$$in1256 = $1162;$$in1257 = $1160;$$in1258 = $1158;$$in1259 = $1156;$$in1260 = $1179;$$in1261 = $1177;$$in1262 = $1175;$$in1263 = $1173;$$in1264 = $1213;$$in1265 = $1211;$$in1266 = $1209;$$in1267 = $1207;$$in1268 = $1196;$$in1269 = $1194;$$in1270 = $1192;$$in1271 = $1190;$$in1272 = $1230;$$in1273 = $1228;$$in1274 = $1226;$$in1275 = $1224;
   } else {
    $$in = $151;$$in1229 = $149;$$in1230 = $147;$$in1231 = $145;$$in1232 = $163;$$in1233 = $161;$$in1234 = $159;$$in1235 = $157;$$in1236 = $175;$$in1237 = $173;$$in1238 = $171;$$in1239 = $169;$$in1240 = $202;$$in1241 = $200;$$in1242 = $198;$$in1243 = $196;$$in1244 = $214;$$in1245 = $212;$$in1246 = $210;$$in1247 = $208;$$in1248 = $226;$$in1249 = $224;$$in1250 = $222;$$in1251 = $220;$$in1252 = $253;$$in1253 = $251;$$in1254 = $249;$$in1255 = $247;$$in1256 = $265;$$in1257 = $263;$$in1258 = $261;$$in1259 = $259;$$in1260 = $277;$$in1261 = $275;$$in1262 = $273;$$in1263 = $271;$$in1264 = $304;$$in1265 = $302;$$in1266 = $300;$$in1267 = $298;$$in1268 = $316;$$in1269 = $314;$$in1270 = $312;$$in1271 = $310;$$in1272 = $328;$$in1273 = $326;$$in1274 = $324;$$in1275 = $322;
   }
   $1231 = Math_fround($479 * $449);
   $1232 = Math_fround($479 * $457);
   $1233 = Math_fround($479 * $465);
   $1234 = Math_fround($479 * $476);
   $1235 = Math_fround($1231 + $$in1231);
   $1236 = Math_fround($1232 + $$in1230);
   $1237 = Math_fround($1233 + $$in1229);
   $1238 = Math_fround($1234 + $$in);
   $1239 = Math_fround($480 * $449);
   $1240 = Math_fround($480 * $457);
   $1241 = Math_fround($480 * $465);
   $1242 = Math_fround($480 * $476);
   $1243 = Math_fround($1239 + $$in1235);
   $1244 = Math_fround($1240 + $$in1234);
   $1245 = Math_fround($1241 + $$in1233);
   $1246 = Math_fround($1242 + $$in1232);
   $1247 = Math_fround($481 * $449);
   $1248 = Math_fround($481 * $457);
   $1249 = Math_fround($481 * $465);
   $1250 = Math_fround($481 * $476);
   $1251 = Math_fround($1247 + $$in1239);
   $1252 = Math_fround($1248 + $$in1238);
   $1253 = Math_fround($1249 + $$in1237);
   $1254 = Math_fround($1250 + $$in1236);
   $1255 = Math_fround($482 * $451);
   $1256 = Math_fround($482 * $459);
   $1257 = Math_fround($482 * $467);
   $1258 = Math_fround($482 * $477);
   $1259 = Math_fround($1255 + $$in1243);
   $1260 = Math_fround($1256 + $$in1242);
   $1261 = Math_fround($1257 + $$in1241);
   $1262 = Math_fround($1258 + $$in1240);
   $1263 = Math_fround($483 * $451);
   $1264 = Math_fround($483 * $459);
   $1265 = Math_fround($483 * $467);
   $1266 = Math_fround($483 * $477);
   $1267 = Math_fround($1263 + $$in1247);
   $1268 = Math_fround($1264 + $$in1246);
   $1269 = Math_fround($1265 + $$in1245);
   $1270 = Math_fround($1266 + $$in1244);
   $1271 = Math_fround($484 * $451);
   $1272 = Math_fround($484 * $459);
   $1273 = Math_fround($484 * $467);
   $1274 = Math_fround($484 * $477);
   $1275 = Math_fround($1271 + $$in1251);
   $1276 = Math_fround($1272 + $$in1250);
   $1277 = Math_fround($1273 + $$in1249);
   $1278 = Math_fround($1274 + $$in1248);
   $1279 = Math_fround($485 * $453);
   $1280 = Math_fround($485 * $461);
   $1281 = Math_fround($485 * $469);
   $1282 = Math_fround($485 * $478);
   $1283 = Math_fround($1279 + $$in1255);
   $1284 = Math_fround($1280 + $$in1254);
   $1285 = Math_fround($1281 + $$in1253);
   $1286 = Math_fround($1282 + $$in1252);
   $1287 = Math_fround($486 * $453);
   $1288 = Math_fround($486 * $461);
   $1289 = Math_fround($486 * $469);
   $1290 = Math_fround($486 * $478);
   $1291 = Math_fround($1287 + $$in1259);
   $1292 = Math_fround($1288 + $$in1258);
   $1293 = Math_fround($1289 + $$in1257);
   $1294 = Math_fround($1290 + $$in1256);
   $1295 = Math_fround($487 * $453);
   $1296 = Math_fround($487 * $461);
   $1297 = Math_fround($487 * $469);
   $1298 = Math_fround($487 * $478);
   $1299 = Math_fround($1295 + $$in1263);
   $1300 = Math_fround($1296 + $$in1262);
   $1301 = Math_fround($1297 + $$in1261);
   $1302 = Math_fround($1298 + $$in1260);
   $1303 = Math_fround($488 * $455);
   $1304 = Math_fround($488 * $463);
   $1305 = Math_fround($488 * $471);
   $1306 = (HEAP32[tempDoublePtr>>2]=$475,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1307 = Math_fround($488 * $1306);
   $1308 = Math_fround($1303 + $$in1271);
   $1309 = Math_fround($1304 + $$in1270);
   $1310 = Math_fround($1305 + $$in1269);
   $1311 = Math_fround($1307 + $$in1268);
   $1312 = Math_fround($489 * $455);
   $1313 = Math_fround($489 * $463);
   $1314 = Math_fround($489 * $471);
   $1315 = Math_fround($489 * $1306);
   $1316 = Math_fround($1312 + $$in1267);
   $1317 = Math_fround($1313 + $$in1266);
   $1318 = Math_fround($1314 + $$in1265);
   $1319 = Math_fround($1315 + $$in1264);
   $1320 = Math_fround($490 * $455);
   $1321 = Math_fround($490 * $463);
   $1322 = Math_fround($490 * $471);
   $1323 = Math_fround($490 * $1306);
   $1324 = Math_fround($1320 + $$in1275);
   $1325 = Math_fround($1321 + $$in1274);
   $1326 = Math_fround($1322 + $$in1273);
   $1327 = Math_fround($1323 + $$in1272);
   $1328 = HEAP16[$vpIt$01384>>1]|0;
   $1329 = $1328&65535;
   $1330 = $1329 << 4;
   $1331 = (($14) + ($1330)|0);
   HEAPF32[$1331>>2] = $1235;
   $$sum$i321276 = $1330 | 4;
   $1332 = (($14) + ($$sum$i321276)|0);
   HEAPF32[$1332>>2] = $1236;
   $$sum1$i331277 = $1330 | 8;
   $1333 = (($14) + ($$sum1$i331277)|0);
   HEAPF32[$1333>>2] = $1237;
   $$sum2$i341278 = $1330 | 12;
   $1334 = (($14) + ($$sum2$i341278)|0);
   HEAPF32[$1334>>2] = $1238;
   $1335 = HEAP16[$152>>1]|0;
   $1336 = $1335&65535;
   $1337 = $1336 << 4;
   $1338 = (($14) + ($1337)|0);
   HEAPF32[$1338>>2] = $1243;
   $$sum$i291279 = $1337 | 4;
   $1339 = (($14) + ($$sum$i291279)|0);
   HEAPF32[$1339>>2] = $1244;
   $$sum1$i301280 = $1337 | 8;
   $1340 = (($14) + ($$sum1$i301280)|0);
   HEAPF32[$1340>>2] = $1245;
   $$sum2$i311281 = $1337 | 12;
   $1341 = (($14) + ($$sum2$i311281)|0);
   HEAPF32[$1341>>2] = $1246;
   $1342 = HEAP16[$164>>1]|0;
   $1343 = $1342&65535;
   $1344 = $1343 << 4;
   $1345 = (($14) + ($1344)|0);
   HEAPF32[$1345>>2] = $1251;
   $$sum$i261282 = $1344 | 4;
   $1346 = (($14) + ($$sum$i261282)|0);
   HEAPF32[$1346>>2] = $1252;
   $$sum1$i271283 = $1344 | 8;
   $1347 = (($14) + ($$sum1$i271283)|0);
   HEAPF32[$1347>>2] = $1253;
   $$sum2$i281284 = $1344 | 12;
   $1348 = (($14) + ($$sum2$i281284)|0);
   HEAPF32[$1348>>2] = $1254;
   $1349 = HEAP16[$191>>1]|0;
   $1350 = $1349&65535;
   $1351 = $1350 << 4;
   $1352 = (($14) + ($1351)|0);
   HEAPF32[$1352>>2] = $1259;
   $$sum$i231285 = $1351 | 4;
   $1353 = (($14) + ($$sum$i231285)|0);
   HEAPF32[$1353>>2] = $1260;
   $$sum1$i241286 = $1351 | 8;
   $1354 = (($14) + ($$sum1$i241286)|0);
   HEAPF32[$1354>>2] = $1261;
   $$sum2$i251287 = $1351 | 12;
   $1355 = (($14) + ($$sum2$i251287)|0);
   HEAPF32[$1355>>2] = $1262;
   $1356 = HEAP16[$203>>1]|0;
   $1357 = $1356&65535;
   $1358 = $1357 << 4;
   $1359 = (($14) + ($1358)|0);
   HEAPF32[$1359>>2] = $1267;
   $$sum$i201288 = $1358 | 4;
   $1360 = (($14) + ($$sum$i201288)|0);
   HEAPF32[$1360>>2] = $1268;
   $$sum1$i211289 = $1358 | 8;
   $1361 = (($14) + ($$sum1$i211289)|0);
   HEAPF32[$1361>>2] = $1269;
   $$sum2$i221290 = $1358 | 12;
   $1362 = (($14) + ($$sum2$i221290)|0);
   HEAPF32[$1362>>2] = $1270;
   $1363 = HEAP16[$215>>1]|0;
   $1364 = $1363&65535;
   $1365 = $1364 << 4;
   $1366 = (($14) + ($1365)|0);
   HEAPF32[$1366>>2] = $1275;
   $$sum$i171291 = $1365 | 4;
   $1367 = (($14) + ($$sum$i171291)|0);
   HEAPF32[$1367>>2] = $1276;
   $$sum1$i181292 = $1365 | 8;
   $1368 = (($14) + ($$sum1$i181292)|0);
   HEAPF32[$1368>>2] = $1277;
   $$sum2$i191293 = $1365 | 12;
   $1369 = (($14) + ($$sum2$i191293)|0);
   HEAPF32[$1369>>2] = $1278;
   $1370 = HEAP16[$242>>1]|0;
   $1371 = $1370&65535;
   $1372 = $1371 << 4;
   $1373 = (($14) + ($1372)|0);
   HEAPF32[$1373>>2] = $1283;
   $$sum$i141294 = $1372 | 4;
   $1374 = (($14) + ($$sum$i141294)|0);
   HEAPF32[$1374>>2] = $1284;
   $$sum1$i151295 = $1372 | 8;
   $1375 = (($14) + ($$sum1$i151295)|0);
   HEAPF32[$1375>>2] = $1285;
   $$sum2$i161296 = $1372 | 12;
   $1376 = (($14) + ($$sum2$i161296)|0);
   HEAPF32[$1376>>2] = $1286;
   $1377 = HEAP16[$254>>1]|0;
   $1378 = $1377&65535;
   $1379 = $1378 << 4;
   $1380 = (($14) + ($1379)|0);
   HEAPF32[$1380>>2] = $1291;
   $$sum$i111297 = $1379 | 4;
   $1381 = (($14) + ($$sum$i111297)|0);
   HEAPF32[$1381>>2] = $1292;
   $$sum1$i121298 = $1379 | 8;
   $1382 = (($14) + ($$sum1$i121298)|0);
   HEAPF32[$1382>>2] = $1293;
   $$sum2$i131299 = $1379 | 12;
   $1383 = (($14) + ($$sum2$i131299)|0);
   HEAPF32[$1383>>2] = $1294;
   $1384 = HEAP16[$266>>1]|0;
   $1385 = $1384&65535;
   $1386 = $1385 << 4;
   $1387 = (($14) + ($1386)|0);
   HEAPF32[$1387>>2] = $1299;
   $$sum$i81300 = $1386 | 4;
   $1388 = (($14) + ($$sum$i81300)|0);
   HEAPF32[$1388>>2] = $1300;
   $$sum1$i91301 = $1386 | 8;
   $1389 = (($14) + ($$sum1$i91301)|0);
   HEAPF32[$1389>>2] = $1301;
   $$sum2$i101302 = $1386 | 12;
   $1390 = (($14) + ($$sum2$i101302)|0);
   HEAPF32[$1390>>2] = $1302;
   $1391 = HEAP16[$305>>1]|0;
   $1392 = $1391&65535;
   $1393 = $1392 << 4;
   $1394 = (($14) + ($1393)|0);
   HEAPF32[$1394>>2] = $1308;
   $$sum$i51303 = $1393 | 4;
   $1395 = (($14) + ($$sum$i51303)|0);
   HEAPF32[$1395>>2] = $1309;
   $$sum1$i61304 = $1393 | 8;
   $1396 = (($14) + ($$sum1$i61304)|0);
   HEAPF32[$1396>>2] = $1310;
   $$sum2$i71305 = $1393 | 12;
   $1397 = (($14) + ($$sum2$i71305)|0);
   HEAPF32[$1397>>2] = $1311;
   $1398 = HEAP16[$293>>1]|0;
   $1399 = $1398&65535;
   $1400 = $1399 << 4;
   $1401 = (($14) + ($1400)|0);
   HEAPF32[$1401>>2] = $1316;
   $$sum$i21306 = $1400 | 4;
   $1402 = (($14) + ($$sum$i21306)|0);
   HEAPF32[$1402>>2] = $1317;
   $$sum1$i31307 = $1400 | 8;
   $1403 = (($14) + ($$sum1$i31307)|0);
   HEAPF32[$1403>>2] = $1318;
   $$sum2$i41308 = $1400 | 12;
   $1404 = (($14) + ($$sum2$i41308)|0);
   HEAPF32[$1404>>2] = $1319;
   $1405 = HEAP16[$317>>1]|0;
   $1406 = $1405&65535;
   $1407 = $1406 << 4;
   $1408 = (($14) + ($1407)|0);
   HEAPF32[$1408>>2] = $1324;
   $$sum$i1309 = $1407 | 4;
   $1409 = (($14) + ($$sum$i1309)|0);
   HEAPF32[$1409>>2] = $1325;
   $$sum1$i1310 = $1407 | 8;
   $1410 = (($14) + ($$sum1$i1310)|0);
   HEAPF32[$1410>>2] = $1326;
   $$sum2$i1311 = $1407 | 12;
   $1411 = (($14) + ($$sum2$i1311)|0);
   HEAPF32[$1411>>2] = $1327;
  }
  $1412 = (($vpIt$01384) + 32|0);
  $1413 = ($1412|0)==($78|0);
  if ($1413) {
   break;
  } else {
   $vpIt$01384 = $1412;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE23estimateTemporaryMemoryERKNS0_7SwClothE($cloth) {
 $cloth = $cloth|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 420|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cloth) + 396|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1*80)|0;
 $5 = $3 << 5;
 $6 = ($4>>>0)<($5>>>0);
 $7 = $6 ? $5 : $4;
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE24estimatePersistentMemoryERKNS0_7SwClothE($cloth) {
 $cloth = $cloth|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cloth) + 360|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 5;
 $5 = ($1*96)|0;
 $6 = (($4) + ($5))|0;
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE23buildSphereAccelerationEPKNS0_10SphereDataE($this,$sIt) {
 $this = $this|0;
 $sIt = $sIt|0;
 var $$051 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0;
 var $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$1 = 0, $exitcond$2 = 0, $floorf$i = Math_fround(0), $floorf$i1 = Math_fround(0);
 var $floorf1$i = Math_fround(0), $floorf1$i2 = Math_fround(0), $floorf2$i = Math_fround(0), $floorf2$i3 = Math_fround(0), $j$042 = 0, $j$042$1 = 0, $j$042$2 = 0, $j1$043 = 0, $j1$043$1 = 0, $j1$043$2 = 0, $mask$050 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($sIt) + ($3<<4)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 384|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 388|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 392|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 400|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 404|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 408|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 96|0);
 $$051 = $sIt;$mask$050 = 1;
 while(1) {
  $19 = Math_fround(HEAPF32[$$051>>2]);
  $20 = (($$051) + 4|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($$051) + 8|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($$051) + 12|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($19 - $25);
  $27 = Math_fround($21 - $25);
  $28 = Math_fround($23 - $25);
  $29 = Math_fround($26 * $7);
  $30 = Math_fround($27 * $9);
  $31 = Math_fround($28 * $11);
  $32 = Math_fround($29 + $13);
  $33 = Math_fround($30 + $15);
  $34 = Math_fround($31 + $17);
  $35 = HEAP32[478232>>2]|0;
  $36 = HEAP32[((478232 + 4|0))>>2]|0;
  $37 = HEAP32[((478232 + 8|0))>>2]|0;
  $38 = (HEAP32[tempDoublePtr>>2]=$35,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $39 = $32 < $38;
  $40 = $39 ? $38 : $32;
  $41 = (HEAP32[tempDoublePtr>>2]=$36,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $42 = $33 < $41;
  $43 = $42 ? $41 : $33;
  $44 = (HEAP32[tempDoublePtr>>2]=$37,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $45 = $34 < $44;
  $46 = $45 ? $44 : $34;
  $floorf$i1 = (Math_fround(Math_floor((Math_fround($40)))));
  $47 = (~~(($floorf$i1)));
  $floorf1$i2 = (Math_fround(Math_floor((Math_fround($43)))));
  $48 = (~~(($floorf1$i2)));
  $floorf2$i3 = (Math_fround(Math_floor((Math_fround($46)))));
  $49 = (~~(($floorf2$i3)));
  $50 = Math_fround($19 + $25);
  $51 = Math_fround($21 + $25);
  $52 = Math_fround($23 + $25);
  $53 = Math_fround($50 * $7);
  $54 = Math_fround($51 * $9);
  $55 = Math_fround($52 * $11);
  $56 = Math_fround($53 + $13);
  $57 = Math_fround($54 + $15);
  $58 = Math_fround($55 + $17);
  $59 = HEAP32[478312>>2]|0;
  $60 = HEAP32[((478312 + 4|0))>>2]|0;
  $61 = HEAP32[((478312 + 8|0))>>2]|0;
  $62 = (HEAP32[tempDoublePtr>>2]=$59,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $63 = $62 < $56;
  $64 = $63 ? $62 : $56;
  $65 = (HEAP32[tempDoublePtr>>2]=$60,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $66 = $65 < $57;
  $67 = $66 ? $65 : $57;
  $68 = (HEAP32[tempDoublePtr>>2]=$61,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $69 = $68 < $58;
  $70 = $69 ? $68 : $58;
  $floorf$i = (Math_fround(Math_floor((Math_fround($64)))));
  $71 = (~~(($floorf$i)));
  $floorf1$i = (Math_fround(Math_floor((Math_fround($67)))));
  $72 = (~~(($floorf1$i)));
  $floorf2$i = (Math_fround(Math_floor((Math_fround($70)))));
  $73 = (~~(($floorf2$i)));
  $74 = ($47|0)<(8);
  if ($74) {
   $j$042 = $47;
   while(1) {
    $75 = (($this) + ($j$042<<2)|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = $76 | $mask$050;
    HEAP32[$75>>2] = $77;
    $78 = (($j$042) + 1)|0;
    $exitcond = ($78|0)==(8);
    if ($exitcond) {
     break;
    } else {
     $j$042 = $78;
    }
   }
  }
  $79 = ($71|0)>(-1);
  if ($79) {
   $j1$043 = $71;
   while(1) {
    $80 = (($18) + ($j1$043<<2)|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = $81 | $mask$050;
    HEAP32[$80>>2] = $82;
    $83 = (($j1$043) + -1)|0;
    $84 = ($j1$043|0)>(0);
    if ($84) {
     $j1$043 = $83;
    } else {
     break;
    }
   }
  }
  $85 = (($this) + 32|0);
  $86 = (($this) + 128|0);
  $87 = ($48|0)<(8);
  if ($87) {
   $j$042$1 = $48;
   while(1) {
    $88 = (($85) + ($j$042$1<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = $89 | $mask$050;
    HEAP32[$88>>2] = $90;
    $91 = (($j$042$1) + 1)|0;
    $exitcond$1 = ($91|0)==(8);
    if ($exitcond$1) {
     break;
    } else {
     $j$042$1 = $91;
    }
   }
  }
  $92 = ($72|0)>(-1);
  if ($92) {
   $j1$043$1 = $72;
   while(1) {
    $93 = (($86) + ($j1$043$1<<2)|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = $94 | $mask$050;
    HEAP32[$93>>2] = $95;
    $96 = (($j1$043$1) + -1)|0;
    $97 = ($j1$043$1|0)>(0);
    if ($97) {
     $j1$043$1 = $96;
    } else {
     break;
    }
   }
  }
  $98 = (($this) + 64|0);
  $99 = (($this) + 160|0);
  $100 = ($49|0)<(8);
  if ($100) {
   $j$042$2 = $49;
   while(1) {
    $101 = (($98) + ($j$042$2<<2)|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = $102 | $mask$050;
    HEAP32[$101>>2] = $103;
    $104 = (($j$042$2) + 1)|0;
    $exitcond$2 = ($104|0)==(8);
    if ($exitcond$2) {
     break;
    } else {
     $j$042$2 = $104;
    }
   }
  }
  $105 = ($73|0)>(-1);
  if ($105) {
   $j1$043$2 = $73;
   while(1) {
    $106 = (($99) + ($j1$043$2<<2)|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = $107 | $mask$050;
    HEAP32[$106>>2] = $108;
    $109 = (($j1$043$2) + -1)|0;
    $110 = ($j1$043$2|0)>(0);
    if ($110) {
     $j1$043$2 = $109;
    } else {
     break;
    }
   }
  }
  $111 = (($$051) + 16|0);
  $112 = ($111|0)==($4|0);
  if ($112) {
   break;
  }
  $113 = $mask$050 << 1;
  $$051 = $111;$mask$050 = $113;
 }
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth11SwCollisionI8Scalar4fE12getShapeMaskEPKS2_($agg$result,$this,$positions) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $positions = $positions|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0);
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $floorf$i$i = Math_fround(0), $floorf$i$i1 = Math_fround(0), $floorf$i$i9 = Math_fround(0), $floorf1$i$i = Math_fround(0), $floorf1$i$i10 = Math_fround(0), $floorf1$i$i2 = Math_fround(0), $floorf2$i$i = Math_fround(0), $floorf2$i$i11 = Math_fround(0), $floorf2$i$i3 = Math_fround(0), $floorf3$i$i = Math_fround(0), $floorf3$i$i12 = Math_fround(0), $floorf3$i$i4 = Math_fround(0), $not$$i$i$i = 0, $not$$i$i$i13 = 0, $not$$i$i$i5 = 0, $not$1$i$i$i = 0, $not$1$i$i$i14 = 0;
 var $not$1$i$i$i6 = 0, $not$2$i$i$i = 0, $not$2$i$i$i15 = 0, $not$2$i$i$i7 = 0, $not$3$i$i$i = 0, $not$3$i$i$i16 = 0, $not$3$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 384|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$positions>>2]);
 $3 = Math_fround($1 * $2);
 $4 = (($positions) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($1 * $5);
 $7 = (($positions) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($1 * $8);
 $10 = (($positions) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($1 * $11);
 $13 = (($this) + 400|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($3 + $14);
 $16 = Math_fround($6 + $14);
 $17 = Math_fround($9 + $14);
 $18 = Math_fround($12 + $14);
 $19 = (($this) + 388|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($positions) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (($positions) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($20 * $25);
 $27 = (($positions) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($20 * $28);
 $30 = (($positions) + 28|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($20 * $31);
 $33 = (($this) + 404|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($23 + $34);
 $36 = Math_fround($26 + $34);
 $37 = Math_fround($29 + $34);
 $38 = Math_fround($32 + $34);
 $39 = (($this) + 392|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($positions) + 32|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 * $42);
 $44 = (($positions) + 36|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($40 * $45);
 $47 = (($positions) + 40|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($40 * $48);
 $50 = (($positions) + 44|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($40 * $51);
 $53 = (($this) + 408|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($43 + $54);
 $56 = Math_fround($46 + $54);
 $57 = Math_fround($49 + $54);
 $58 = Math_fround($52 + $54);
 $59 = (($this) + 192|0);
 $floorf$i$i9 = (Math_fround(Math_floor((Math_fround($15)))));
 $60 = (~~(($floorf$i$i9)));
 $floorf1$i$i10 = (Math_fround(Math_floor((Math_fround($16)))));
 $61 = (~~(($floorf1$i$i10)));
 $floorf2$i$i11 = (Math_fround(Math_floor((Math_fround($17)))));
 $62 = (~~(($floorf2$i$i11)));
 $floorf3$i$i12 = (Math_fround(Math_floor((Math_fround($18)))));
 $63 = (~~(($floorf3$i$i12)));
 $64 = $60 & 7;
 $65 = $61 & 7;
 $66 = $62 & 7;
 $67 = $63 & 7;
 $not$$i$i$i13 = ($60>>>0)<(8);
 $not$1$i$i$i14 = ($61>>>0)<(8);
 $not$2$i$i$i15 = ($62>>>0)<(8);
 $not$3$i$i$i16 = ($63>>>0)<(8);
 $68 = (($59) + ($64<<2)|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = $not$$i$i$i13 ? $69 : 0;
 $71 = (($59) + ($65<<2)|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $not$1$i$i$i14 ? $72 : 0;
 $74 = (($59) + ($66<<2)|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = $not$2$i$i$i15 ? $75 : 0;
 $77 = (($59) + ($67<<2)|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = $not$3$i$i$i16 ? $78 : 0;
 $80 = (($agg$result) + 4|0);
 $81 = (($agg$result) + 8|0);
 $82 = (($agg$result) + 12|0);
 $83 = (($agg$result) + 16|0);
 $84 = (($this) + ($64<<2)|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = $not$$i$i$i13 ? $85 : 0;
 $87 = (($this) + ($65<<2)|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = $not$1$i$i$i14 ? $88 : 0;
 $90 = (($this) + ($66<<2)|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = $not$2$i$i$i15 ? $91 : 0;
 $93 = (($this) + ($67<<2)|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = $not$3$i$i$i16 ? $94 : 0;
 $96 = (($agg$result) + 20|0);
 $97 = (($agg$result) + 24|0);
 $98 = (($agg$result) + 28|0);
 $99 = (($this) + 32|0);
 $100 = (($this) + 224|0);
 $floorf$i$i1 = (Math_fround(Math_floor((Math_fround($35)))));
 $101 = (~~(($floorf$i$i1)));
 $floorf1$i$i2 = (Math_fround(Math_floor((Math_fround($36)))));
 $102 = (~~(($floorf1$i$i2)));
 $floorf2$i$i3 = (Math_fround(Math_floor((Math_fround($37)))));
 $103 = (~~(($floorf2$i$i3)));
 $floorf3$i$i4 = (Math_fround(Math_floor((Math_fround($38)))));
 $104 = (~~(($floorf3$i$i4)));
 $105 = $101 & 7;
 $106 = $102 & 7;
 $107 = $103 & 7;
 $108 = $104 & 7;
 $not$$i$i$i5 = ($101>>>0)<(8);
 $not$1$i$i$i6 = ($102>>>0)<(8);
 $not$2$i$i$i7 = ($103>>>0)<(8);
 $not$3$i$i$i8 = ($104>>>0)<(8);
 $109 = (($100) + ($105<<2)|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = $not$$i$i$i5 ? $110 : 0;
 $112 = (($100) + ($106<<2)|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = $not$1$i$i$i6 ? $113 : 0;
 $115 = (($100) + ($107<<2)|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = $not$2$i$i$i7 ? $116 : 0;
 $118 = (($100) + ($108<<2)|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = $not$3$i$i$i8 ? $119 : 0;
 $121 = (($99) + ($105<<2)|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = $not$$i$i$i5 ? $122 : 0;
 $124 = (($99) + ($106<<2)|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = $not$1$i$i$i6 ? $125 : 0;
 $127 = (($99) + ($107<<2)|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = $not$2$i$i$i7 ? $128 : 0;
 $130 = (($99) + ($108<<2)|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = $not$3$i$i$i8 ? $131 : 0;
 $133 = $70 & $111;
 $134 = $73 & $114;
 $135 = $76 & $117;
 $136 = $79 & $120;
 $137 = $86 & $123;
 $138 = $89 & $126;
 $139 = $92 & $129;
 $140 = $95 & $132;
 $141 = (($this) + 64|0);
 $142 = (($this) + 256|0);
 $floorf$i$i = (Math_fround(Math_floor((Math_fround($55)))));
 $143 = (~~(($floorf$i$i)));
 $floorf1$i$i = (Math_fround(Math_floor((Math_fround($56)))));
 $144 = (~~(($floorf1$i$i)));
 $floorf2$i$i = (Math_fround(Math_floor((Math_fround($57)))));
 $145 = (~~(($floorf2$i$i)));
 $floorf3$i$i = (Math_fround(Math_floor((Math_fround($58)))));
 $146 = (~~(($floorf3$i$i)));
 $147 = $143 & 7;
 $148 = $144 & 7;
 $149 = $145 & 7;
 $150 = $146 & 7;
 $not$$i$i$i = ($143>>>0)<(8);
 $not$1$i$i$i = ($144>>>0)<(8);
 $not$2$i$i$i = ($145>>>0)<(8);
 $not$3$i$i$i = ($146>>>0)<(8);
 $151 = (($142) + ($147<<2)|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = $not$$i$i$i ? $152 : 0;
 $154 = (($142) + ($148<<2)|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = $not$1$i$i$i ? $155 : 0;
 $157 = (($142) + ($149<<2)|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = $not$2$i$i$i ? $158 : 0;
 $160 = (($142) + ($150<<2)|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = $not$3$i$i$i ? $161 : 0;
 $163 = (($141) + ($147<<2)|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = $not$$i$i$i ? $164 : 0;
 $166 = (($141) + ($148<<2)|0);
 $167 = HEAP32[$166>>2]|0;
 $168 = $not$1$i$i$i ? $167 : 0;
 $169 = (($141) + ($149<<2)|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = $not$2$i$i$i ? $170 : 0;
 $172 = (($141) + ($150<<2)|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = $not$3$i$i$i ? $173 : 0;
 $175 = $133 & $153;
 $176 = $134 & $156;
 $177 = $135 & $159;
 $178 = $136 & $162;
 HEAP32[$agg$result>>2] = $175;
 HEAP32[$80>>2] = $176;
 HEAP32[$81>>2] = $177;
 HEAP32[$82>>2] = $178;
 $179 = $137 & $165;
 $180 = $138 & $168;
 $181 = $139 & $171;
 $182 = $140 & $174;
 HEAP32[$83>>2] = $179;
 HEAP32[$96>>2] = $180;
 HEAP32[$97>>2] = $181;
 HEAP32[$98>>2] = $182;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth11SwCollisionI8Scalar4fE12getShapeMaskEPKS2_S5_($agg$result,$this,$prevPos,$curPos) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $prevPos = $prevPos|0;
 $curPos = $curPos|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0);
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0;
 var $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0);
 var $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0);
 var $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0);
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0);
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $floorf$i$i = Math_fround(0), $floorf$i$i1 = Math_fround(0), $floorf$i$i17 = Math_fround(0), $floorf$i$i25 = Math_fround(0), $floorf$i$i33 = Math_fround(0), $floorf$i$i9 = Math_fround(0), $floorf1$i$i = Math_fround(0), $floorf1$i$i10 = Math_fround(0), $floorf1$i$i18 = Math_fround(0), $floorf1$i$i2 = Math_fround(0), $floorf1$i$i26 = Math_fround(0), $floorf1$i$i34 = Math_fround(0);
 var $floorf2$i$i = Math_fround(0), $floorf2$i$i11 = Math_fround(0), $floorf2$i$i19 = Math_fround(0), $floorf2$i$i27 = Math_fround(0), $floorf2$i$i3 = Math_fround(0), $floorf2$i$i35 = Math_fround(0), $floorf3$i$i = Math_fround(0), $floorf3$i$i12 = Math_fround(0), $floorf3$i$i20 = Math_fround(0), $floorf3$i$i28 = Math_fround(0), $floorf3$i$i36 = Math_fround(0), $floorf3$i$i4 = Math_fround(0), $not$$i$i$i = 0, $not$$i$i$i13 = 0, $not$$i$i$i21 = 0, $not$$i$i$i29 = 0, $not$$i$i$i37 = 0, $not$$i$i$i5 = 0, $not$1$i$i$i = 0, $not$1$i$i$i14 = 0;
 var $not$1$i$i$i22 = 0, $not$1$i$i$i30 = 0, $not$1$i$i$i38 = 0, $not$1$i$i$i6 = 0, $not$2$i$i$i = 0, $not$2$i$i$i15 = 0, $not$2$i$i$i23 = 0, $not$2$i$i$i31 = 0, $not$2$i$i$i39 = 0, $not$2$i$i$i7 = 0, $not$3$i$i$i = 0, $not$3$i$i$i16 = 0, $not$3$i$i$i24 = 0, $not$3$i$i$i32 = 0, $not$3$i$i$i40 = 0, $not$3$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 384|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 388|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 392|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 400|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 404|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 408|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(HEAPF32[$prevPos>>2]);
 $13 = Math_fround($1 * $12);
 $14 = (($prevPos) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($1 * $15);
 $17 = (($prevPos) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($1 * $18);
 $20 = (($prevPos) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($1 * $21);
 $23 = Math_fround($7 + $13);
 $24 = Math_fround($7 + $16);
 $25 = Math_fround($7 + $19);
 $26 = Math_fround($7 + $22);
 $27 = (($prevPos) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($3 * $28);
 $30 = (($prevPos) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($3 * $31);
 $33 = (($prevPos) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($3 * $34);
 $36 = (($prevPos) + 28|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($3 * $37);
 $39 = Math_fround($9 + $29);
 $40 = Math_fround($9 + $32);
 $41 = Math_fround($9 + $35);
 $42 = Math_fround($9 + $38);
 $43 = (($prevPos) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($5 * $44);
 $46 = (($prevPos) + 36|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($5 * $47);
 $49 = (($prevPos) + 40|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($5 * $50);
 $52 = (($prevPos) + 44|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($5 * $53);
 $55 = Math_fround($11 + $45);
 $56 = Math_fround($11 + $48);
 $57 = Math_fround($11 + $51);
 $58 = Math_fround($11 + $54);
 $59 = Math_fround(HEAPF32[$curPos>>2]);
 $60 = Math_fround($1 * $59);
 $61 = (($curPos) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($1 * $62);
 $64 = (($curPos) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($1 * $65);
 $67 = (($curPos) + 12|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($1 * $68);
 $70 = Math_fround($7 + $60);
 $71 = Math_fround($7 + $63);
 $72 = Math_fround($7 + $66);
 $73 = Math_fround($7 + $69);
 $74 = (($curPos) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($3 * $75);
 $77 = (($curPos) + 20|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($3 * $78);
 $80 = (($curPos) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($3 * $81);
 $83 = (($curPos) + 28|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($3 * $84);
 $86 = Math_fround($9 + $76);
 $87 = Math_fround($9 + $79);
 $88 = Math_fround($9 + $82);
 $89 = Math_fround($9 + $85);
 $90 = (($curPos) + 32|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($5 * $91);
 $93 = (($curPos) + 36|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($5 * $94);
 $96 = (($curPos) + 40|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($5 * $97);
 $99 = (($curPos) + 44|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($5 * $100);
 $102 = Math_fround($11 + $92);
 $103 = Math_fround($11 + $95);
 $104 = Math_fround($11 + $98);
 $105 = Math_fround($11 + $101);
 $106 = $23 < $70;
 $107 = $106 ? $70 : $23;
 $108 = $24 < $71;
 $109 = $108 ? $71 : $24;
 $110 = $25 < $72;
 $111 = $110 ? $72 : $25;
 $112 = $26 < $73;
 $113 = $112 ? $73 : $26;
 $114 = HEAP32[478312>>2]|0;
 $115 = HEAP32[((478312 + 4|0))>>2]|0;
 $116 = HEAP32[((478312 + 8|0))>>2]|0;
 $117 = HEAP32[((478312 + 12|0))>>2]|0;
 $118 = (HEAP32[tempDoublePtr>>2]=$114,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $119 = $118 < $107;
 $120 = $119 ? $118 : $107;
 $121 = (HEAP32[tempDoublePtr>>2]=$115,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $122 = $121 < $109;
 $123 = $122 ? $121 : $109;
 $124 = (HEAP32[tempDoublePtr>>2]=$116,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $125 = $124 < $111;
 $126 = $125 ? $124 : $111;
 $127 = (HEAP32[tempDoublePtr>>2]=$117,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $128 = $127 < $113;
 $129 = $128 ? $127 : $113;
 $130 = $39 < $86;
 $131 = $130 ? $86 : $39;
 $132 = $40 < $87;
 $133 = $132 ? $87 : $40;
 $134 = $41 < $88;
 $135 = $134 ? $88 : $41;
 $136 = $42 < $89;
 $137 = $136 ? $89 : $42;
 $138 = $118 < $131;
 $139 = $138 ? $118 : $131;
 $140 = $121 < $133;
 $141 = $140 ? $121 : $133;
 $142 = $124 < $135;
 $143 = $142 ? $124 : $135;
 $144 = $127 < $137;
 $145 = $144 ? $127 : $137;
 $146 = $55 < $102;
 $147 = $146 ? $102 : $55;
 $148 = $56 < $103;
 $149 = $148 ? $103 : $56;
 $150 = $57 < $104;
 $151 = $150 ? $104 : $57;
 $152 = $58 < $105;
 $153 = $152 ? $105 : $58;
 $154 = $118 < $147;
 $155 = $154 ? $118 : $147;
 $156 = $121 < $149;
 $157 = $156 ? $121 : $149;
 $158 = $124 < $151;
 $159 = $158 ? $124 : $151;
 $160 = $127 < $153;
 $161 = $160 ? $127 : $153;
 $162 = (($this) + 192|0);
 $floorf$i$i33 = (Math_fround(Math_floor((Math_fround($120)))));
 $163 = (~~(($floorf$i$i33)));
 $floorf1$i$i34 = (Math_fround(Math_floor((Math_fround($123)))));
 $164 = (~~(($floorf1$i$i34)));
 $floorf2$i$i35 = (Math_fround(Math_floor((Math_fround($126)))));
 $165 = (~~(($floorf2$i$i35)));
 $floorf3$i$i36 = (Math_fround(Math_floor((Math_fround($129)))));
 $166 = (~~(($floorf3$i$i36)));
 $167 = $163 & 7;
 $168 = $164 & 7;
 $169 = $165 & 7;
 $170 = $166 & 7;
 $not$$i$i$i37 = ($163>>>0)<(8);
 $not$1$i$i$i38 = ($164>>>0)<(8);
 $not$2$i$i$i39 = ($165>>>0)<(8);
 $not$3$i$i$i40 = ($166>>>0)<(8);
 $171 = (($162) + ($167<<2)|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = $not$$i$i$i37 ? $172 : 0;
 $174 = (($162) + ($168<<2)|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = $not$1$i$i$i38 ? $175 : 0;
 $177 = (($162) + ($169<<2)|0);
 $178 = HEAP32[$177>>2]|0;
 $179 = $not$2$i$i$i39 ? $178 : 0;
 $180 = (($162) + ($170<<2)|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = $not$3$i$i$i40 ? $181 : 0;
 $183 = (($agg$result) + 4|0);
 $184 = (($agg$result) + 8|0);
 $185 = (($agg$result) + 12|0);
 $186 = (($agg$result) + 16|0);
 $187 = (($this) + ($167<<2)|0);
 $188 = HEAP32[$187>>2]|0;
 $189 = $not$$i$i$i37 ? $188 : 0;
 $190 = (($this) + ($168<<2)|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = $not$1$i$i$i38 ? $191 : 0;
 $193 = (($this) + ($169<<2)|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = $not$2$i$i$i39 ? $194 : 0;
 $196 = (($this) + ($170<<2)|0);
 $197 = HEAP32[$196>>2]|0;
 $198 = $not$3$i$i$i40 ? $197 : 0;
 $199 = (($agg$result) + 20|0);
 $200 = (($agg$result) + 24|0);
 $201 = (($agg$result) + 28|0);
 $202 = (($this) + 32|0);
 $203 = (($this) + 224|0);
 $floorf$i$i25 = (Math_fround(Math_floor((Math_fround($139)))));
 $204 = (~~(($floorf$i$i25)));
 $floorf1$i$i26 = (Math_fround(Math_floor((Math_fround($141)))));
 $205 = (~~(($floorf1$i$i26)));
 $floorf2$i$i27 = (Math_fround(Math_floor((Math_fround($143)))));
 $206 = (~~(($floorf2$i$i27)));
 $floorf3$i$i28 = (Math_fround(Math_floor((Math_fround($145)))));
 $207 = (~~(($floorf3$i$i28)));
 $208 = $204 & 7;
 $209 = $205 & 7;
 $210 = $206 & 7;
 $211 = $207 & 7;
 $not$$i$i$i29 = ($204>>>0)<(8);
 $not$1$i$i$i30 = ($205>>>0)<(8);
 $not$2$i$i$i31 = ($206>>>0)<(8);
 $not$3$i$i$i32 = ($207>>>0)<(8);
 $212 = (($203) + ($208<<2)|0);
 $213 = HEAP32[$212>>2]|0;
 $214 = $not$$i$i$i29 ? $213 : 0;
 $215 = (($203) + ($209<<2)|0);
 $216 = HEAP32[$215>>2]|0;
 $217 = $not$1$i$i$i30 ? $216 : 0;
 $218 = (($203) + ($210<<2)|0);
 $219 = HEAP32[$218>>2]|0;
 $220 = $not$2$i$i$i31 ? $219 : 0;
 $221 = (($203) + ($211<<2)|0);
 $222 = HEAP32[$221>>2]|0;
 $223 = $not$3$i$i$i32 ? $222 : 0;
 $224 = (($202) + ($208<<2)|0);
 $225 = HEAP32[$224>>2]|0;
 $226 = $not$$i$i$i29 ? $225 : 0;
 $227 = (($202) + ($209<<2)|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = $not$1$i$i$i30 ? $228 : 0;
 $230 = (($202) + ($210<<2)|0);
 $231 = HEAP32[$230>>2]|0;
 $232 = $not$2$i$i$i31 ? $231 : 0;
 $233 = (($202) + ($211<<2)|0);
 $234 = HEAP32[$233>>2]|0;
 $235 = $not$3$i$i$i32 ? $234 : 0;
 $236 = $173 & $214;
 $237 = $176 & $217;
 $238 = $179 & $220;
 $239 = $182 & $223;
 $240 = $189 & $226;
 $241 = $192 & $229;
 $242 = $195 & $232;
 $243 = $198 & $235;
 $244 = (($this) + 64|0);
 $245 = (($this) + 256|0);
 $floorf$i$i17 = (Math_fround(Math_floor((Math_fround($155)))));
 $246 = (~~(($floorf$i$i17)));
 $floorf1$i$i18 = (Math_fround(Math_floor((Math_fround($157)))));
 $247 = (~~(($floorf1$i$i18)));
 $floorf2$i$i19 = (Math_fround(Math_floor((Math_fround($159)))));
 $248 = (~~(($floorf2$i$i19)));
 $floorf3$i$i20 = (Math_fround(Math_floor((Math_fround($161)))));
 $249 = (~~(($floorf3$i$i20)));
 $250 = $246 & 7;
 $251 = $247 & 7;
 $252 = $248 & 7;
 $253 = $249 & 7;
 $not$$i$i$i21 = ($246>>>0)<(8);
 $not$1$i$i$i22 = ($247>>>0)<(8);
 $not$2$i$i$i23 = ($248>>>0)<(8);
 $not$3$i$i$i24 = ($249>>>0)<(8);
 $254 = (($245) + ($250<<2)|0);
 $255 = HEAP32[$254>>2]|0;
 $256 = $not$$i$i$i21 ? $255 : 0;
 $257 = (($245) + ($251<<2)|0);
 $258 = HEAP32[$257>>2]|0;
 $259 = $not$1$i$i$i22 ? $258 : 0;
 $260 = (($245) + ($252<<2)|0);
 $261 = HEAP32[$260>>2]|0;
 $262 = $not$2$i$i$i23 ? $261 : 0;
 $263 = (($245) + ($253<<2)|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = $not$3$i$i$i24 ? $264 : 0;
 $266 = (($244) + ($250<<2)|0);
 $267 = HEAP32[$266>>2]|0;
 $268 = $not$$i$i$i21 ? $267 : 0;
 $269 = (($244) + ($251<<2)|0);
 $270 = HEAP32[$269>>2]|0;
 $271 = $not$1$i$i$i22 ? $270 : 0;
 $272 = (($244) + ($252<<2)|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = $not$2$i$i$i23 ? $273 : 0;
 $275 = (($244) + ($253<<2)|0);
 $276 = HEAP32[$275>>2]|0;
 $277 = $not$3$i$i$i24 ? $276 : 0;
 $278 = $236 & $256;
 $279 = $237 & $259;
 $280 = $238 & $262;
 $281 = $239 & $265;
 HEAP32[$agg$result>>2] = $278;
 HEAP32[$183>>2] = $279;
 HEAP32[$184>>2] = $280;
 HEAP32[$185>>2] = $281;
 $282 = $240 & $268;
 $283 = $241 & $271;
 $284 = $242 & $274;
 $285 = $243 & $277;
 HEAP32[$186>>2] = $282;
 HEAP32[$199>>2] = $283;
 HEAP32[$200>>2] = $284;
 HEAP32[$201>>2] = $285;
 $286 = $70 < $23;
 $287 = $286 ? $70 : $23;
 $288 = $71 < $24;
 $289 = $288 ? $71 : $24;
 $290 = $72 < $25;
 $291 = $290 ? $72 : $25;
 $292 = $73 < $26;
 $293 = $292 ? $73 : $26;
 $294 = $287 < Math_fround(0.0);
 $295 = $294 ? Math_fround(0.0) : $287;
 $296 = $289 < Math_fround(0.0);
 $297 = $296 ? Math_fround(0.0) : $289;
 $298 = $291 < Math_fround(0.0);
 $299 = $298 ? Math_fround(0.0) : $291;
 $300 = $293 < Math_fround(0.0);
 $301 = $300 ? Math_fround(0.0) : $293;
 $302 = $86 < $39;
 $303 = $302 ? $86 : $39;
 $304 = $87 < $40;
 $305 = $304 ? $87 : $40;
 $306 = $88 < $41;
 $307 = $306 ? $88 : $41;
 $308 = $89 < $42;
 $309 = $308 ? $89 : $42;
 $310 = $303 < Math_fround(0.0);
 $311 = $310 ? Math_fround(0.0) : $303;
 $312 = $305 < Math_fround(0.0);
 $313 = $312 ? Math_fround(0.0) : $305;
 $314 = $307 < Math_fround(0.0);
 $315 = $314 ? Math_fround(0.0) : $307;
 $316 = $309 < Math_fround(0.0);
 $317 = $316 ? Math_fround(0.0) : $309;
 $318 = $102 < $55;
 $319 = $318 ? $102 : $55;
 $320 = $103 < $56;
 $321 = $320 ? $103 : $56;
 $322 = $104 < $57;
 $323 = $322 ? $104 : $57;
 $324 = $105 < $58;
 $325 = $324 ? $105 : $58;
 $326 = $319 < Math_fround(0.0);
 $327 = $326 ? Math_fround(0.0) : $319;
 $328 = $321 < Math_fround(0.0);
 $329 = $328 ? Math_fround(0.0) : $321;
 $330 = $323 < Math_fround(0.0);
 $331 = $330 ? Math_fround(0.0) : $323;
 $332 = $325 < Math_fround(0.0);
 $333 = $332 ? Math_fround(0.0) : $325;
 $334 = (($this) + 96|0);
 $335 = (($this) + 288|0);
 $floorf$i$i9 = (Math_fround(Math_floor((Math_fround($295)))));
 $336 = (~~(($floorf$i$i9)));
 $floorf1$i$i10 = (Math_fround(Math_floor((Math_fround($297)))));
 $337 = (~~(($floorf1$i$i10)));
 $floorf2$i$i11 = (Math_fround(Math_floor((Math_fround($299)))));
 $338 = (~~(($floorf2$i$i11)));
 $floorf3$i$i12 = (Math_fround(Math_floor((Math_fround($301)))));
 $339 = (~~(($floorf3$i$i12)));
 $340 = $336 & 7;
 $341 = $337 & 7;
 $342 = $338 & 7;
 $343 = $339 & 7;
 $not$$i$i$i13 = ($336>>>0)<(8);
 $not$1$i$i$i14 = ($337>>>0)<(8);
 $not$2$i$i$i15 = ($338>>>0)<(8);
 $not$3$i$i$i16 = ($339>>>0)<(8);
 $344 = (($335) + ($340<<2)|0);
 $345 = HEAP32[$344>>2]|0;
 $346 = $not$$i$i$i13 ? $345 : 0;
 $347 = (($335) + ($341<<2)|0);
 $348 = HEAP32[$347>>2]|0;
 $349 = $not$1$i$i$i14 ? $348 : 0;
 $350 = (($335) + ($342<<2)|0);
 $351 = HEAP32[$350>>2]|0;
 $352 = $not$2$i$i$i15 ? $351 : 0;
 $353 = (($335) + ($343<<2)|0);
 $354 = HEAP32[$353>>2]|0;
 $355 = $not$3$i$i$i16 ? $354 : 0;
 $356 = (($334) + ($340<<2)|0);
 $357 = HEAP32[$356>>2]|0;
 $358 = $not$$i$i$i13 ? $357 : 0;
 $359 = (($334) + ($341<<2)|0);
 $360 = HEAP32[$359>>2]|0;
 $361 = $not$1$i$i$i14 ? $360 : 0;
 $362 = (($334) + ($342<<2)|0);
 $363 = HEAP32[$362>>2]|0;
 $364 = $not$2$i$i$i15 ? $363 : 0;
 $365 = (($334) + ($343<<2)|0);
 $366 = HEAP32[$365>>2]|0;
 $367 = $not$3$i$i$i16 ? $366 : 0;
 $368 = HEAP32[$agg$result>>2]|0;
 $369 = $368 & $346;
 $370 = HEAP32[$183>>2]|0;
 $371 = $370 & $349;
 $372 = HEAP32[$184>>2]|0;
 $373 = $372 & $352;
 $374 = HEAP32[$185>>2]|0;
 $375 = $374 & $355;
 $376 = HEAP32[$186>>2]|0;
 $377 = $376 & $358;
 $378 = HEAP32[$199>>2]|0;
 $379 = $378 & $361;
 $380 = HEAP32[$200>>2]|0;
 $381 = $380 & $364;
 $382 = HEAP32[$201>>2]|0;
 $383 = $382 & $367;
 $384 = (($this) + 128|0);
 $385 = (($this) + 320|0);
 $floorf$i$i1 = (Math_fround(Math_floor((Math_fround($311)))));
 $386 = (~~(($floorf$i$i1)));
 $floorf1$i$i2 = (Math_fround(Math_floor((Math_fround($313)))));
 $387 = (~~(($floorf1$i$i2)));
 $floorf2$i$i3 = (Math_fround(Math_floor((Math_fround($315)))));
 $388 = (~~(($floorf2$i$i3)));
 $floorf3$i$i4 = (Math_fround(Math_floor((Math_fround($317)))));
 $389 = (~~(($floorf3$i$i4)));
 $390 = $386 & 7;
 $391 = $387 & 7;
 $392 = $388 & 7;
 $393 = $389 & 7;
 $not$$i$i$i5 = ($386>>>0)<(8);
 $not$1$i$i$i6 = ($387>>>0)<(8);
 $not$2$i$i$i7 = ($388>>>0)<(8);
 $not$3$i$i$i8 = ($389>>>0)<(8);
 $394 = (($385) + ($390<<2)|0);
 $395 = HEAP32[$394>>2]|0;
 $396 = $not$$i$i$i5 ? $395 : 0;
 $397 = (($385) + ($391<<2)|0);
 $398 = HEAP32[$397>>2]|0;
 $399 = $not$1$i$i$i6 ? $398 : 0;
 $400 = (($385) + ($392<<2)|0);
 $401 = HEAP32[$400>>2]|0;
 $402 = $not$2$i$i$i7 ? $401 : 0;
 $403 = (($385) + ($393<<2)|0);
 $404 = HEAP32[$403>>2]|0;
 $405 = $not$3$i$i$i8 ? $404 : 0;
 $406 = (($384) + ($390<<2)|0);
 $407 = HEAP32[$406>>2]|0;
 $408 = $not$$i$i$i5 ? $407 : 0;
 $409 = (($384) + ($391<<2)|0);
 $410 = HEAP32[$409>>2]|0;
 $411 = $not$1$i$i$i6 ? $410 : 0;
 $412 = (($384) + ($392<<2)|0);
 $413 = HEAP32[$412>>2]|0;
 $414 = $not$2$i$i$i7 ? $413 : 0;
 $415 = (($384) + ($393<<2)|0);
 $416 = HEAP32[$415>>2]|0;
 $417 = $not$3$i$i$i8 ? $416 : 0;
 $418 = $369 & $396;
 $419 = $371 & $399;
 $420 = $373 & $402;
 $421 = $375 & $405;
 $422 = $377 & $408;
 $423 = $379 & $411;
 $424 = $381 & $414;
 $425 = $383 & $417;
 $426 = (($this) + 160|0);
 $427 = (($this) + 352|0);
 $floorf$i$i = (Math_fround(Math_floor((Math_fround($327)))));
 $428 = (~~(($floorf$i$i)));
 $floorf1$i$i = (Math_fround(Math_floor((Math_fround($329)))));
 $429 = (~~(($floorf1$i$i)));
 $floorf2$i$i = (Math_fround(Math_floor((Math_fround($331)))));
 $430 = (~~(($floorf2$i$i)));
 $floorf3$i$i = (Math_fround(Math_floor((Math_fround($333)))));
 $431 = (~~(($floorf3$i$i)));
 $432 = $428 & 7;
 $433 = $429 & 7;
 $434 = $430 & 7;
 $435 = $431 & 7;
 $not$$i$i$i = ($428>>>0)<(8);
 $not$1$i$i$i = ($429>>>0)<(8);
 $not$2$i$i$i = ($430>>>0)<(8);
 $not$3$i$i$i = ($431>>>0)<(8);
 $436 = (($427) + ($432<<2)|0);
 $437 = HEAP32[$436>>2]|0;
 $438 = $not$$i$i$i ? $437 : 0;
 $439 = (($427) + ($433<<2)|0);
 $440 = HEAP32[$439>>2]|0;
 $441 = $not$1$i$i$i ? $440 : 0;
 $442 = (($427) + ($434<<2)|0);
 $443 = HEAP32[$442>>2]|0;
 $444 = $not$2$i$i$i ? $443 : 0;
 $445 = (($427) + ($435<<2)|0);
 $446 = HEAP32[$445>>2]|0;
 $447 = $not$3$i$i$i ? $446 : 0;
 $448 = (($426) + ($432<<2)|0);
 $449 = HEAP32[$448>>2]|0;
 $450 = $not$$i$i$i ? $449 : 0;
 $451 = (($426) + ($433<<2)|0);
 $452 = HEAP32[$451>>2]|0;
 $453 = $not$1$i$i$i ? $452 : 0;
 $454 = (($426) + ($434<<2)|0);
 $455 = HEAP32[$454>>2]|0;
 $456 = $not$2$i$i$i ? $455 : 0;
 $457 = (($426) + ($435<<2)|0);
 $458 = HEAP32[$457>>2]|0;
 $459 = $not$3$i$i$i ? $458 : 0;
 $460 = $418 & $438;
 $461 = $419 & $441;
 $462 = $420 & $444;
 $463 = $421 & $447;
 HEAP32[$agg$result>>2] = $460;
 HEAP32[$183>>2] = $461;
 HEAP32[$184>>2] = $462;
 HEAP32[$185>>2] = $463;
 $464 = $422 & $450;
 $465 = $423 & $453;
 $466 = $424 & $456;
 $467 = $425 & $459;
 HEAP32[$186>>2] = $464;
 HEAP32[$199>>2] = $465;
 HEAP32[$200>>2] = $466;
 HEAP32[$201>>2] = $467;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth11SwCollisionI8Scalar4fE14collideSpheresERKS2_PS4_RNS3_18ImpulseAccumulatorE($this,$sphereMask,$positions,$accum) {
 $this = $this|0;
 $sphereMask = $sphereMask|0;
 $positions = $positions|0;
 $accum = $accum|0;
 var $$$i = 0, $$0$i = 0, $$sum$i176 = 0, $$sum1$i277 = 0, $$sum2$i378 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0);
 var $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0;
 var $99 = 0, $brmerge$i = 0, $brmerge1$i = 0, $mask$082 = 0, $result$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 424|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 432|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 216|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 > Math_fround(0.0);
 $7 = HEAP32[$sphereMask>>2]|0;
 $8 = (($sphereMask) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($sphereMask) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($sphereMask) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $9 | $7;
 $15 = $14 | $11;
 $16 = $15 | $13;
 $17 = ($16|0)==(0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = (($positions) + 4|0);
 $19 = (($positions) + 8|0);
 $20 = (($positions) + 12|0);
 $21 = (($positions) + 16|0);
 $22 = (($positions) + 20|0);
 $23 = (($positions) + 24|0);
 $24 = (($positions) + 28|0);
 $25 = (($positions) + 32|0);
 $26 = (($positions) + 36|0);
 $27 = (($positions) + 40|0);
 $28 = (($positions) + 44|0);
 $29 = (($accum) + 4|0);
 $30 = (($accum) + 8|0);
 $31 = (($accum) + 12|0);
 $32 = (($accum) + 16|0);
 $33 = (($accum) + 20|0);
 $34 = (($accum) + 24|0);
 $35 = (($accum) + 28|0);
 $36 = (($accum) + 32|0);
 $37 = (($accum) + 36|0);
 $38 = (($accum) + 40|0);
 $39 = (($accum) + 44|0);
 $40 = (($accum) + 96|0);
 $41 = (($accum) + 100|0);
 $42 = (($accum) + 104|0);
 $43 = (($accum) + 108|0);
 $44 = (($this) + 416|0);
 $45 = (($accum) + 48|0);
 $46 = (($accum) + 52|0);
 $47 = (($accum) + 56|0);
 $48 = (($accum) + 60|0);
 $49 = (($accum) + 64|0);
 $50 = (($accum) + 68|0);
 $51 = (($accum) + 72|0);
 $52 = (($accum) + 76|0);
 $53 = (($accum) + 80|0);
 $54 = (($accum) + 84|0);
 $55 = (($accum) + 88|0);
 $56 = (($accum) + 92|0);
 $mask$082 = $16;
 while(1) {
  $57 = (0 - ($mask$082))|0;
  $58 = $mask$082 & $57;
  $$0$i = $58;$result$0$i = 0;
  while(1) {
   $59 = $$0$i >>> 1;
   $60 = ($59|0)==(0);
   $61 = (($result$0$i) + 1)|0;
   if ($60) {
    break;
   } else {
    $$0$i = $59;$result$0$i = $61;
   }
  }
  $62 = (($mask$082) + -1)|0;
  $63 = $result$0$i << 4;
  $64 = $62 & $mask$082;
  $65 = (($1) + ($result$0$i<<4)|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $$sum$i176 = $63 | 4;
  $67 = (($1) + ($$sum$i176)|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $$sum1$i277 = $63 | 8;
  $69 = (($1) + ($$sum1$i277)|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $$sum2$i378 = $63 | 12;
  $71 = (($1) + ($$sum2$i378)|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround(HEAPF32[$positions>>2]);
  $74 = Math_fround($73 - $66);
  $75 = Math_fround(HEAPF32[$18>>2]);
  $76 = Math_fround($75 - $66);
  $77 = Math_fround(HEAPF32[$19>>2]);
  $78 = Math_fround($77 - $66);
  $79 = Math_fround(HEAPF32[$20>>2]);
  $80 = Math_fround($79 - $66);
  $81 = Math_fround(HEAPF32[$21>>2]);
  $82 = Math_fround($81 - $68);
  $83 = Math_fround(HEAPF32[$22>>2]);
  $84 = Math_fround($83 - $68);
  $85 = Math_fround(HEAPF32[$23>>2]);
  $86 = Math_fround($85 - $68);
  $87 = Math_fround(HEAPF32[$24>>2]);
  $88 = Math_fround($87 - $68);
  $89 = Math_fround(HEAPF32[$25>>2]);
  $90 = Math_fround($89 - $70);
  $91 = Math_fround(HEAPF32[$26>>2]);
  $92 = Math_fround($91 - $70);
  $93 = Math_fround(HEAPF32[$27>>2]);
  $94 = Math_fround($93 - $70);
  $95 = Math_fround(HEAPF32[$28>>2]);
  $96 = Math_fround($95 - $70);
  $97 = HEAP32[478152>>2]|0;
  $98 = HEAP32[((478152 + 4|0))>>2]|0;
  $99 = HEAP32[((478152 + 8|0))>>2]|0;
  $100 = HEAP32[((478152 + 12|0))>>2]|0;
  $101 = Math_fround($74 * $74);
  $102 = Math_fround($76 * $76);
  $103 = Math_fround($78 * $78);
  $104 = Math_fround($80 * $80);
  $105 = (HEAP32[tempDoublePtr>>2]=$97,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $106 = Math_fround($101 + $105);
  $107 = (HEAP32[tempDoublePtr>>2]=$98,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $108 = Math_fround($102 + $107);
  $109 = (HEAP32[tempDoublePtr>>2]=$99,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $110 = Math_fround($103 + $109);
  $111 = (HEAP32[tempDoublePtr>>2]=$100,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $112 = Math_fround($104 + $111);
  $113 = Math_fround($82 * $82);
  $114 = Math_fround($84 * $84);
  $115 = Math_fround($86 * $86);
  $116 = Math_fround($88 * $88);
  $117 = Math_fround($113 + $106);
  $118 = Math_fround($114 + $108);
  $119 = Math_fround($115 + $110);
  $120 = Math_fround($116 + $112);
  $121 = Math_fround($90 * $90);
  $122 = Math_fround($92 * $92);
  $123 = Math_fround($94 * $94);
  $124 = Math_fround($96 * $96);
  $125 = Math_fround($121 + $117);
  $126 = Math_fround($122 + $118);
  $127 = Math_fround($123 + $119);
  $128 = Math_fround($124 + $120);
  $129 = (Math_fround(Math_sqrt((Math_fround($125)))));
  $130 = (Math_fround(Math_sqrt((Math_fround($126)))));
  $131 = (Math_fround(Math_sqrt((Math_fround($127)))));
  $132 = (Math_fround(Math_sqrt((Math_fround($128)))));
  $133 = Math_fround(Math_fround(1.0) / $129);
  $134 = Math_fround(Math_fround(1.0) / $130);
  $135 = Math_fround(Math_fround(1.0) / $131);
  $136 = Math_fround(Math_fround(1.0) / $132);
  $137 = Math_fround($72 * $133);
  $138 = Math_fround($72 * $134);
  $139 = Math_fround($72 * $135);
  $140 = Math_fround($72 * $136);
  $141 = Math_fround(Math_fround(1.0) - $137);
  $142 = Math_fround(Math_fround(1.0) - $138);
  $143 = Math_fround(Math_fround(1.0) - $139);
  $144 = Math_fround(Math_fround(1.0) - $140);
  $145 = $141 < Math_fround(0.0);
  $146 = $142 < Math_fround(0.0);
  $147 = $143 < Math_fround(0.0);
  $148 = $144 < Math_fround(0.0);
  $brmerge$i = $145 | $146;
  $brmerge1$i = $brmerge$i | $147;
  $$$i = $brmerge1$i | $148;
  if ($$$i) {
   $149 = $145 ? $141 : Math_fround(0.0);
   $150 = Math_fround($74 * $149);
   $151 = $146 ? $142 : Math_fround(0.0);
   $152 = Math_fround($76 * $151);
   $153 = $147 ? $143 : Math_fround(0.0);
   $154 = Math_fround($78 * $153);
   $155 = $148 ? $144 : Math_fround(0.0);
   $156 = Math_fround($80 * $155);
   $157 = Math_fround(HEAPF32[$accum>>2]);
   $158 = Math_fround($157 - $150);
   $159 = Math_fround(HEAPF32[$29>>2]);
   $160 = Math_fround($159 - $152);
   $161 = Math_fround(HEAPF32[$30>>2]);
   $162 = Math_fround($161 - $154);
   $163 = Math_fround(HEAPF32[$31>>2]);
   $164 = Math_fround($163 - $156);
   $165 = (HEAPF32[tempDoublePtr>>2]=$158,HEAP32[tempDoublePtr>>2]|0);
   $166 = (HEAPF32[tempDoublePtr>>2]=$160,HEAP32[tempDoublePtr>>2]|0);
   $167 = (HEAPF32[tempDoublePtr>>2]=$162,HEAP32[tempDoublePtr>>2]|0);
   $168 = (HEAPF32[tempDoublePtr>>2]=$164,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$accum>>2] = $165;
   HEAP32[$29>>2] = $166;
   HEAP32[$30>>2] = $167;
   HEAP32[$31>>2] = $168;
   $169 = Math_fround($82 * $149);
   $170 = Math_fround($84 * $151);
   $171 = Math_fround($86 * $153);
   $172 = Math_fround($88 * $155);
   $173 = Math_fround(HEAPF32[$32>>2]);
   $174 = Math_fround($173 - $169);
   $175 = Math_fround(HEAPF32[$33>>2]);
   $176 = Math_fround($175 - $170);
   $177 = Math_fround(HEAPF32[$34>>2]);
   $178 = Math_fround($177 - $171);
   $179 = Math_fround(HEAPF32[$35>>2]);
   $180 = Math_fround($179 - $172);
   $181 = (HEAPF32[tempDoublePtr>>2]=$174,HEAP32[tempDoublePtr>>2]|0);
   $182 = (HEAPF32[tempDoublePtr>>2]=$176,HEAP32[tempDoublePtr>>2]|0);
   $183 = (HEAPF32[tempDoublePtr>>2]=$178,HEAP32[tempDoublePtr>>2]|0);
   $184 = (HEAPF32[tempDoublePtr>>2]=$180,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$32>>2] = $181;
   HEAP32[$33>>2] = $182;
   HEAP32[$34>>2] = $183;
   HEAP32[$35>>2] = $184;
   $185 = Math_fround($90 * $149);
   $186 = Math_fround($92 * $151);
   $187 = Math_fround($94 * $153);
   $188 = Math_fround($96 * $155);
   $189 = Math_fround(HEAPF32[$36>>2]);
   $190 = Math_fround($189 - $185);
   $191 = Math_fround(HEAPF32[$37>>2]);
   $192 = Math_fround($191 - $186);
   $193 = Math_fround(HEAPF32[$38>>2]);
   $194 = Math_fround($193 - $187);
   $195 = Math_fround(HEAPF32[$39>>2]);
   $196 = Math_fround($195 - $188);
   $197 = (HEAPF32[tempDoublePtr>>2]=$190,HEAP32[tempDoublePtr>>2]|0);
   $198 = (HEAPF32[tempDoublePtr>>2]=$192,HEAP32[tempDoublePtr>>2]|0);
   $199 = (HEAPF32[tempDoublePtr>>2]=$194,HEAP32[tempDoublePtr>>2]|0);
   $200 = (HEAPF32[tempDoublePtr>>2]=$196,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$36>>2] = $197;
   HEAP32[$37>>2] = $198;
   HEAP32[$38>>2] = $199;
   HEAP32[$39>>2] = $200;
   $201 = Math_fround(HEAPF32[$40>>2]);
   $202 = $145 ? Math_fround(1.0) : Math_fround(0.0);
   $203 = Math_fround($202 + $201);
   $204 = Math_fround(HEAPF32[$41>>2]);
   $205 = $146 ? Math_fround(1.0) : Math_fround(0.0);
   $206 = Math_fround($205 + $204);
   $207 = Math_fround(HEAPF32[$42>>2]);
   $208 = $147 ? Math_fround(1.0) : Math_fround(0.0);
   $209 = Math_fround($208 + $207);
   $210 = Math_fround(HEAPF32[$43>>2]);
   $211 = $148 ? Math_fround(1.0) : Math_fround(0.0);
   $212 = Math_fround($211 + $210);
   $213 = (HEAPF32[tempDoublePtr>>2]=$203,HEAP32[tempDoublePtr>>2]|0);
   $214 = (HEAPF32[tempDoublePtr>>2]=$206,HEAP32[tempDoublePtr>>2]|0);
   $215 = (HEAPF32[tempDoublePtr>>2]=$209,HEAP32[tempDoublePtr>>2]|0);
   $216 = (HEAPF32[tempDoublePtr>>2]=$212,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$40>>2] = $213;
   HEAP32[$41>>2] = $214;
   HEAP32[$42>>2] = $215;
   HEAP32[$43>>2] = $216;
   if ($6) {
    $217 = HEAP32[$44>>2]|0;
    $218 = (($217) + ($result$0$i<<4)|0);
    $219 = Math_fround(HEAPF32[$218>>2]);
    $220 = (($217) + ($$sum$i176)|0);
    $221 = Math_fround(HEAPF32[$220>>2]);
    $222 = (($217) + ($$sum1$i277)|0);
    $223 = Math_fround(HEAPF32[$222>>2]);
    $224 = Math_fround($66 - $219);
    $225 = Math_fround($68 - $221);
    $226 = Math_fround($70 - $223);
    $227 = Math_fround(HEAPF32[$45>>2]);
    $228 = $145 ? $224 : Math_fround(0.0);
    $229 = Math_fround($228 + $227);
    $230 = Math_fround(HEAPF32[$46>>2]);
    $231 = $146 ? $224 : Math_fround(0.0);
    $232 = Math_fround($231 + $230);
    $233 = Math_fround(HEAPF32[$47>>2]);
    $234 = $147 ? $224 : Math_fround(0.0);
    $235 = Math_fround($234 + $233);
    $236 = Math_fround(HEAPF32[$48>>2]);
    $237 = $148 ? $224 : Math_fround(0.0);
    $238 = Math_fround($237 + $236);
    $239 = (HEAPF32[tempDoublePtr>>2]=$229,HEAP32[tempDoublePtr>>2]|0);
    $240 = (HEAPF32[tempDoublePtr>>2]=$232,HEAP32[tempDoublePtr>>2]|0);
    $241 = (HEAPF32[tempDoublePtr>>2]=$235,HEAP32[tempDoublePtr>>2]|0);
    $242 = (HEAPF32[tempDoublePtr>>2]=$238,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$45>>2] = $239;
    HEAP32[$46>>2] = $240;
    HEAP32[$47>>2] = $241;
    HEAP32[$48>>2] = $242;
    $243 = Math_fround(HEAPF32[$49>>2]);
    $244 = $145 ? $225 : Math_fround(0.0);
    $245 = Math_fround($244 + $243);
    $246 = Math_fround(HEAPF32[$50>>2]);
    $247 = $146 ? $225 : Math_fround(0.0);
    $248 = Math_fround($247 + $246);
    $249 = Math_fround(HEAPF32[$51>>2]);
    $250 = $147 ? $225 : Math_fround(0.0);
    $251 = Math_fround($250 + $249);
    $252 = Math_fround(HEAPF32[$52>>2]);
    $253 = $148 ? $225 : Math_fround(0.0);
    $254 = Math_fround($253 + $252);
    $255 = (HEAPF32[tempDoublePtr>>2]=$245,HEAP32[tempDoublePtr>>2]|0);
    $256 = (HEAPF32[tempDoublePtr>>2]=$248,HEAP32[tempDoublePtr>>2]|0);
    $257 = (HEAPF32[tempDoublePtr>>2]=$251,HEAP32[tempDoublePtr>>2]|0);
    $258 = (HEAPF32[tempDoublePtr>>2]=$254,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$49>>2] = $255;
    HEAP32[$50>>2] = $256;
    HEAP32[$51>>2] = $257;
    HEAP32[$52>>2] = $258;
    $259 = Math_fround(HEAPF32[$53>>2]);
    $260 = $145 ? $226 : Math_fround(0.0);
    $261 = Math_fround($260 + $259);
    $262 = Math_fround(HEAPF32[$54>>2]);
    $263 = $146 ? $226 : Math_fround(0.0);
    $264 = Math_fround($263 + $262);
    $265 = Math_fround(HEAPF32[$55>>2]);
    $266 = $147 ? $226 : Math_fround(0.0);
    $267 = Math_fround($266 + $265);
    $268 = Math_fround(HEAPF32[$56>>2]);
    $269 = $148 ? $226 : Math_fround(0.0);
    $270 = Math_fround($269 + $268);
    $271 = (HEAPF32[tempDoublePtr>>2]=$261,HEAP32[tempDoublePtr>>2]|0);
    $272 = (HEAPF32[tempDoublePtr>>2]=$264,HEAP32[tempDoublePtr>>2]|0);
    $273 = (HEAPF32[tempDoublePtr>>2]=$267,HEAP32[tempDoublePtr>>2]|0);
    $274 = (HEAPF32[tempDoublePtr>>2]=$270,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$53>>2] = $271;
    HEAP32[$54>>2] = $272;
    HEAP32[$55>>2] = $273;
    HEAP32[$56>>2] = $274;
   }
  }
  $275 = ($64|0)==(0);
  if ($275) {
   break;
  } else {
   $mask$082 = $64;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth11SwCollisionI8Scalar4fE12collideConesEPKS2_RNS3_18ImpulseAccumulatorE($agg$result,$this,$positions,$accum) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $positions = $positions|0;
 $accum = $accum|0;
 var $$$i = 0, $$$i$us = 0, $$0$i = 0, $$0$i$us = 0, $$demorgan333 = 0, $$demorgan333$us = 0, $$demorgan334335 = 0, $$demorgan334335$us = 0, $$demorgan336337 = 0, $$demorgan336337$us = 0, $$demorgan338339 = 0, $$demorgan338339$us = 0, $$demorgan352353 = 0, $$demorgan352353$us = 0, $$demorgan354 = 0, $$demorgan354$us = 0, $$demorgan355356 = 0, $$demorgan355356$us = 0, $$op = 0, $$op$us = 0;
 var $$op329 = 0, $$op329$us = 0, $$pre = 0, $$pre$phi360Z2D = 0, $$pre$phi364Z2D = 0, $$pre$phi368Z2D = 0, $$pre$phi372Z2D = 0, $$pre361 = 0, $$pre365 = 0, $$pre369 = 0, $$sum$i1346$us = 0, $$sum$i24317 = 0, $$sum$i24317$us = 0, $$sum$i7340$us = 0, $$sum1$i2347$us = 0, $$sum1$i25318 = 0, $$sum1$i25318$us = 0, $$sum1$i8341$us = 0, $$sum2$i26319 = 0, $$sum2$i26319$us = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0;
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = 0;
 var $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = 0;
 var $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = Math_fround(0), $458 = Math_fround(0);
 var $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0);
 var $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0);
 var $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0;
 var $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = 0, $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0);
 var $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0);
 var $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = 0, $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = Math_fround(0), $612 = 0, $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0;
 var $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0);
 var $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = Math_fround(0), $647 = 0, $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = 0, $651 = Math_fround(0), $652 = Math_fround(0), $653 = 0, $654 = Math_fround(0), $655 = Math_fround(0), $656 = 0;
 var $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0);
 var $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = 0, $687 = Math_fround(0), $688 = 0, $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0);
 var $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = Math_fround(0), $722 = 0, $723 = Math_fround(0), $724 = Math_fround(0), $725 = 0, $726 = Math_fround(0), $727 = Math_fround(0), $728 = 0;
 var $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = 0, $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0);
 var $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0;
 var $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0);
 var $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = 0;
 var $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0, $850 = Math_fround(0), $851 = Math_fround(0), $852 = 0, $853 = 0, $854 = 0;
 var $855 = 0, $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = Math_fround(0);
 var $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0;
 var $891 = 0, $892 = 0, $893 = 0, $894 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $brmerge$i = 0, $brmerge$i$us = 0, $brmerge1$i = 0, $brmerge1$i$us = 0, $mask$0357 = 0;
 var $mask$0357$us = 0, $not$w$i$i$i = 0, $not$w$i$i$i$i = 0, $not$w$i$i$i$i$us = 0, $not$w$i$i$i$us = 0, $not$w$i$i$i13 = 0, $not$w$i$i$i13$us = 0, $not$w$i$i$i17 = 0, $not$w$i$i$i17$us = 0, $not$x$i$i$i = 0, $not$x$i$i$i$i = 0, $not$x$i$i$i$i$us = 0, $not$x$i$i$i$us = 0, $not$x$i$i$i10 = 0, $not$x$i$i$i10$us = 0, $not$x$i$i$i14 = 0, $not$x$i$i$i14$us = 0, $not$y$i$i$i = 0, $not$y$i$i$i$i = 0, $not$y$i$i$i$i$us = 0;
 var $not$y$i$i$i$us = 0, $not$y$i$i$i11 = 0, $not$y$i$i$i11$us = 0, $not$y$i$i$i15 = 0, $not$y$i$i$i15$us = 0, $not$z$i$i$i = 0, $not$z$i$i$i$i = 0, $not$z$i$i$i$i$us = 0, $not$z$i$i$i$us = 0, $not$z$i$i$i12 = 0, $not$z$i$i$i12$us = 0, $not$z$i$i$i16 = 0, $not$z$i$i$i16$us = 0, $result$0$i = 0, $result$0$i$us = 0, $shapeMask = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $shapeMask = sp;
 $0 = (($this) + 428|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 432|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 216|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 __ZNK5physx5cloth11SwCollisionI8Scalar4fE12getShapeMaskEPKS2_($shapeMask,$this,$positions);
 $6 = HEAP32[$shapeMask>>2]|0;
 $7 = (($shapeMask) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($shapeMask) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($shapeMask) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $8 | $6;
 $14 = $13 | $10;
 $15 = $14 | $12;
 $16 = ($15|0)==(0);
 if ($16) {
  $$pre = (($shapeMask) + 16|0);
  $$pre361 = (($shapeMask) + 20|0);
  $$pre365 = (($shapeMask) + 24|0);
  $$pre369 = (($shapeMask) + 28|0);
  $$pre$phi360Z2D = $$pre;$$pre$phi364Z2D = $$pre361;$$pre$phi368Z2D = $$pre365;$$pre$phi372Z2D = $$pre369;
  $888 = HEAP32[$$pre$phi360Z2D>>2]|0;
  HEAP32[$agg$result>>2] = $888;
  $889 = HEAP32[$$pre$phi364Z2D>>2]|0;
  $890 = (($agg$result) + 4|0);
  HEAP32[$890>>2] = $889;
  $891 = HEAP32[$$pre$phi368Z2D>>2]|0;
  $892 = (($agg$result) + 8|0);
  HEAP32[$892>>2] = $891;
  $893 = HEAP32[$$pre$phi372Z2D>>2]|0;
  $894 = (($agg$result) + 12|0);
  HEAP32[$894>>2] = $893;
  STACKTOP = sp;return;
 }
 $17 = $5 > Math_fround(0.0);
 $18 = (($1) + 32|0);
 $19 = (($1) + 16|0);
 $20 = (($positions) + 4|0);
 $21 = (($positions) + 8|0);
 $22 = (($positions) + 12|0);
 $23 = (($positions) + 16|0);
 $24 = (($positions) + 20|0);
 $25 = (($positions) + 24|0);
 $26 = (($positions) + 28|0);
 $27 = (($positions) + 32|0);
 $28 = (($positions) + 36|0);
 $29 = (($positions) + 40|0);
 $30 = (($positions) + 44|0);
 $31 = (($shapeMask) + 16|0);
 $32 = (($shapeMask) + 20|0);
 $33 = (($shapeMask) + 24|0);
 $34 = (($shapeMask) + 28|0);
 $35 = (($accum) + 4|0);
 $36 = (($accum) + 8|0);
 $37 = (($accum) + 12|0);
 $38 = (($accum) + 16|0);
 $39 = (($accum) + 20|0);
 $40 = (($accum) + 24|0);
 $41 = (($accum) + 28|0);
 $42 = (($accum) + 32|0);
 $43 = (($accum) + 36|0);
 $44 = (($accum) + 40|0);
 $45 = (($accum) + 44|0);
 $46 = (($accum) + 96|0);
 $47 = (($accum) + 100|0);
 $48 = (($accum) + 104|0);
 $49 = (($accum) + 108|0);
 $50 = (($this) + 416|0);
 $51 = (($this) + 424|0);
 $52 = (($accum) + 48|0);
 $53 = (($accum) + 52|0);
 $54 = (($accum) + 56|0);
 $55 = (($accum) + 60|0);
 $56 = (($accum) + 64|0);
 $57 = (($accum) + 68|0);
 $58 = (($accum) + 72|0);
 $59 = (($accum) + 76|0);
 $60 = (($accum) + 80|0);
 $61 = (($accum) + 84|0);
 $62 = (($accum) + 88|0);
 $63 = (($accum) + 92|0);
 if ($17) {
  $73 = $15;$75 = $15;$77 = $15;$79 = $15;$mask$0357$us = $15;
  while(1) {
   $64 = (0 - ($mask$0357$us))|0;
   $65 = $mask$0357$us & $64;
   $$0$i$us = $65;$result$0$i$us = 0;
   while(1) {
    $66 = $$0$i$us >>> 1;
    $67 = ($66|0)==(0);
    $68 = (($result$0$i$us) + 1)|0;
    if ($67) {
     break;
    } else {
     $$0$i$us = $66;$result$0$i$us = $68;
    }
   }
   $69 = (($mask$0357$us) + -1)|0;
   $70 = ($result$0$i$us*48)|0;
   $71 = $69 & $mask$0357$us;
   $72 = (($73) + -1)|0;
   $74 = (($75) + -1)|0;
   $76 = (($77) + -1)|0;
   $78 = (($79) + -1)|0;
   $80 = HEAP32[$shapeMask>>2]|0;
   $81 = (0 - ($73))|0;
   $82 = $80 & $81;
   $83 = HEAP32[$7>>2]|0;
   $84 = (0 - ($75))|0;
   $85 = $83 & $84;
   $86 = HEAP32[$9>>2]|0;
   $87 = (0 - ($77))|0;
   $88 = $86 & $87;
   $89 = HEAP32[$11>>2]|0;
   $90 = (0 - ($79))|0;
   $91 = $89 & $90;
   $not$x$i$i$i$i$us = ($82|0)!=(0);
   $not$y$i$i$i$i$us = ($85|0)!=(0);
   $not$z$i$i$i$i$us = ($88|0)!=(0);
   $not$w$i$i$i$i$us = ($91|0)!=(0);
   $92 = $72 & $73;
   $93 = $74 & $75;
   $94 = $76 & $77;
   $95 = $78 & $79;
   $96 = (($1) + (($result$0$i$us*48)|0)|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $$sum$i24317$us = $70 | 4;
   $98 = (($1) + ($$sum$i24317$us)|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $$sum1$i25318$us = $70 | 8;
   $100 = (($1) + ($$sum1$i25318$us)|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $$sum2$i26319$us = $70 | 12;
   $102 = (($1) + ($$sum2$i26319$us)|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = Math_fround(HEAPF32[$positions>>2]);
   $105 = Math_fround($104 - $97);
   $106 = Math_fround(HEAPF32[$20>>2]);
   $107 = Math_fround($106 - $97);
   $108 = Math_fround(HEAPF32[$21>>2]);
   $109 = Math_fround($108 - $97);
   $110 = Math_fround(HEAPF32[$22>>2]);
   $111 = Math_fround($110 - $97);
   $112 = Math_fround(HEAPF32[$23>>2]);
   $113 = Math_fround($112 - $99);
   $114 = Math_fround(HEAPF32[$24>>2]);
   $115 = Math_fround($114 - $99);
   $116 = Math_fround(HEAPF32[$25>>2]);
   $117 = Math_fround($116 - $99);
   $118 = Math_fround(HEAPF32[$26>>2]);
   $119 = Math_fround($118 - $99);
   $120 = Math_fround(HEAPF32[$27>>2]);
   $121 = Math_fround($120 - $101);
   $122 = Math_fround(HEAPF32[$28>>2]);
   $123 = Math_fround($122 - $101);
   $124 = Math_fround(HEAPF32[$29>>2]);
   $125 = Math_fround($124 - $101);
   $126 = Math_fround(HEAPF32[$30>>2]);
   $127 = Math_fround($126 - $101);
   $128 = (($19) + ($70)|0);
   $129 = Math_fround(HEAPF32[$128>>2]);
   $130 = (($19) + ($$sum$i24317$us)|0);
   $131 = Math_fround(HEAPF32[$130>>2]);
   $132 = (($19) + ($$sum1$i25318$us)|0);
   $133 = Math_fround(HEAPF32[$132>>2]);
   $134 = (($19) + ($$sum2$i26319$us)|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = Math_fround($105 * $129);
   $137 = Math_fround($107 * $129);
   $138 = Math_fround($109 * $129);
   $139 = Math_fround($111 * $129);
   $140 = Math_fround($113 * $131);
   $141 = Math_fround($115 * $131);
   $142 = Math_fround($117 * $131);
   $143 = Math_fround($119 * $131);
   $144 = Math_fround($136 + $140);
   $145 = Math_fround($137 + $141);
   $146 = Math_fround($138 + $142);
   $147 = Math_fround($139 + $143);
   $148 = Math_fround($121 * $133);
   $149 = Math_fround($123 * $133);
   $150 = Math_fround($125 * $133);
   $151 = Math_fround($127 * $133);
   $152 = Math_fround($144 + $148);
   $153 = Math_fround($145 + $149);
   $154 = Math_fround($146 + $150);
   $155 = Math_fround($147 + $151);
   $156 = Math_fround($135 * $152);
   $157 = Math_fround($135 * $153);
   $158 = Math_fround($135 * $154);
   $159 = Math_fround($135 * $155);
   $160 = Math_fround($103 + $156);
   $161 = Math_fround($103 + $157);
   $162 = Math_fround($103 + $158);
   $163 = Math_fround($103 + $159);
   $164 = HEAP32[478232>>2]|0;
   $165 = HEAP32[((478232 + 4|0))>>2]|0;
   $166 = HEAP32[((478232 + 8|0))>>2]|0;
   $167 = HEAP32[((478232 + 12|0))>>2]|0;
   $168 = (HEAP32[tempDoublePtr>>2]=$164,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $169 = $160 < $168;
   $170 = $169 ? $168 : $160;
   $171 = (HEAP32[tempDoublePtr>>2]=$165,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $172 = $161 < $171;
   $173 = $172 ? $171 : $161;
   $174 = (HEAP32[tempDoublePtr>>2]=$166,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $175 = $162 < $174;
   $176 = $175 ? $174 : $162;
   $177 = (HEAP32[tempDoublePtr>>2]=$167,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $178 = $163 < $177;
   $179 = $178 ? $177 : $163;
   $180 = Math_fround($105 * $105);
   $181 = Math_fround($107 * $107);
   $182 = Math_fround($109 * $109);
   $183 = Math_fround($111 * $111);
   $184 = Math_fround($113 * $113);
   $185 = Math_fround($115 * $115);
   $186 = Math_fround($117 * $117);
   $187 = Math_fround($119 * $119);
   $188 = Math_fround($180 + $184);
   $189 = Math_fround($181 + $185);
   $190 = Math_fround($182 + $186);
   $191 = Math_fround($183 + $187);
   $192 = Math_fround($121 * $121);
   $193 = Math_fround($123 * $123);
   $194 = Math_fround($125 * $125);
   $195 = Math_fround($127 * $127);
   $196 = Math_fround($188 + $192);
   $197 = Math_fround($189 + $193);
   $198 = Math_fround($190 + $194);
   $199 = Math_fround($191 + $195);
   $200 = Math_fround($152 * $152);
   $201 = Math_fround($153 * $153);
   $202 = Math_fround($154 * $154);
   $203 = Math_fround($155 * $155);
   $204 = Math_fround($196 - $200);
   $205 = Math_fround($197 - $201);
   $206 = Math_fround($198 - $202);
   $207 = Math_fround($199 - $203);
   $208 = (($18) + ($$sum2$i26319$us)|0);
   $209 = Math_fround(HEAPF32[$208>>2]);
   $210 = (HEAPF32[tempDoublePtr>>2]=$209,HEAP32[tempDoublePtr>>2]|0);
   $211 = $not$x$i$i$i$i$us ? $170 : Math_fround(0.0);
   $212 = Math_fround($211 * $211);
   $213 = $not$y$i$i$i$i$us ? $173 : Math_fround(0.0);
   $214 = Math_fround($213 * $213);
   $215 = $not$z$i$i$i$i$us ? $176 : Math_fround(0.0);
   $216 = Math_fround($215 * $215);
   $217 = $not$w$i$i$i$i$us ? $179 : Math_fround(0.0);
   $218 = Math_fround($217 * $217);
   $219 = $212 > $204;
   $220 = $214 > $205;
   $221 = $216 > $206;
   $222 = $218 > $207;
   $brmerge$i$us = $219 | $220;
   $brmerge1$i$us = $brmerge$i$us | $221;
   $$$i$us = $brmerge1$i$us | $222;
   if ($$$i$us) {
    $232 = (($18) + ($$sum1$i25318$us)|0);
    $233 = (($18) + ($$sum$i24317$us)|0);
    $234 = (($18) + ($70)|0);
    $not$w$i$i$i17$us = $222 ^ 1;
    $not$z$i$i$i16$us = $221 ^ 1;
    $not$y$i$i$i15$us = $220 ^ 1;
    $not$x$i$i$i14$us = $219 ^ 1;
    $235 = Math_fround(HEAPF32[$234>>2]);
    $236 = Math_fround(HEAPF32[$232>>2]);
    $237 = Math_fround(HEAPF32[$233>>2]);
    $238 = HEAP32[478152>>2]|0;
    $239 = HEAP32[((478152 + 4|0))>>2]|0;
    $240 = HEAP32[((478152 + 8|0))>>2]|0;
    $241 = HEAP32[((478152 + 12|0))>>2]|0;
    $242 = (HEAP32[tempDoublePtr>>2]=$238,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $243 = $204 < $242;
    $244 = $243 ? $242 : $204;
    $245 = (HEAP32[tempDoublePtr>>2]=$239,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $246 = $205 < $245;
    $247 = $246 ? $245 : $205;
    $248 = (HEAP32[tempDoublePtr>>2]=$240,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $249 = $206 < $248;
    $250 = $249 ? $248 : $206;
    $251 = (HEAP32[tempDoublePtr>>2]=$241,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $252 = $207 < $251;
    $253 = $252 ? $251 : $207;
    $254 = (Math_fround(Math_sqrt((Math_fround($244)))));
    $255 = (Math_fround(Math_sqrt((Math_fround($247)))));
    $256 = (Math_fround(Math_sqrt((Math_fround($250)))));
    $257 = (Math_fround(Math_sqrt((Math_fround($253)))));
    $258 = Math_fround(Math_fround(1.0) / $254);
    $259 = Math_fround(Math_fround(1.0) / $255);
    $260 = Math_fround(Math_fround(1.0) / $256);
    $261 = Math_fround(Math_fround(1.0) / $257);
    $262 = Math_fround($135 * $244);
    $263 = Math_fround($135 * $247);
    $264 = Math_fround($135 * $250);
    $265 = Math_fround($135 * $253);
    $266 = Math_fround($262 * $258);
    $267 = Math_fround($263 * $259);
    $268 = Math_fround($264 * $260);
    $269 = Math_fround($265 * $261);
    $270 = Math_fround($152 + $266);
    $271 = Math_fround($153 + $267);
    $272 = Math_fround($154 + $268);
    $273 = Math_fround($155 + $269);
    $274 = Math_fround(-$237);
    $275 = $219 ? $270 : Math_fround(0.0);
    $276 = $220 ? $271 : Math_fround(0.0);
    $277 = $221 ? $272 : Math_fround(0.0);
    $278 = $222 ? $273 : Math_fround(0.0);
    $not$x$i$i$i10$us = $275 < $274;
    $not$y$i$i$i11$us = $276 < $274;
    $not$z$i$i$i12$us = $277 < $274;
    $not$w$i$i$i13$us = $278 < $274;
    $not$x$i$i$i$us = $275 > $237;
    $not$y$i$i$i$us = $276 > $237;
    $not$z$i$i$i$us = $277 > $237;
    $not$w$i$i$i$us = $278 > $237;
    $279 = (HEAPF32[tempDoublePtr>>2]=$236,HEAP32[tempDoublePtr>>2]|0);
    $280 = $279 ^ $210;
    $281 = HEAP32[$31>>2]|0;
    $$op$us = $279 ^ -1;
    $282 = $not$x$i$i$i10$us ? -1 : $$op$us;
    $283 = $282 & $281;
    $284 = HEAP32[$32>>2]|0;
    $285 = $not$y$i$i$i11$us ? -1 : $$op$us;
    $286 = $285 & $284;
    $287 = HEAP32[$33>>2]|0;
    $288 = $not$z$i$i$i12$us ? -1 : $$op$us;
    $289 = $288 & $287;
    $290 = HEAP32[$34>>2]|0;
    $291 = $not$w$i$i$i13$us ? -1 : $$op$us;
    $292 = $291 & $290;
    $$op329$us = $280 ^ -1;
    $293 = $not$x$i$i$i$us ? -1 : $$op329$us;
    $294 = $283 & $293;
    $295 = $not$y$i$i$i$us ? -1 : $$op329$us;
    $296 = $286 & $295;
    $297 = $not$z$i$i$i$us ? -1 : $$op329$us;
    $298 = $289 & $297;
    $299 = $not$w$i$i$i$us ? -1 : $$op329$us;
    $300 = $292 & $299;
    HEAP32[$31>>2] = $294;
    HEAP32[$32>>2] = $296;
    HEAP32[$33>>2] = $298;
    HEAP32[$34>>2] = $300;
    $301 = $not$x$i$i$i$us | $not$x$i$i$i10$us;
    $302 = $not$y$i$i$i$us | $not$y$i$i$i11$us;
    $303 = $not$z$i$i$i$us | $not$z$i$i$i12$us;
    $304 = $not$w$i$i$i$us | $not$w$i$i$i13$us;
    $$demorgan333$us = $301 | $not$x$i$i$i14$us;
    $$demorgan334335$us = $302 | $not$y$i$i$i15$us;
    $$demorgan336337$us = $303 | $not$z$i$i$i16$us;
    $$demorgan338339$us = $304 | $not$w$i$i$i17$us;
    $$demorgan352353$us = $$demorgan334335$us & $$demorgan333$us;
    $$demorgan354$us = $$demorgan352353$us & $$demorgan336337$us;
    $$demorgan355356$us = $$demorgan354$us & $$demorgan338339$us;
    if (!($$demorgan355356$us)) {
     $305 = Math_fround($217 * $261);
     $306 = Math_fround($215 * $260);
     $307 = Math_fround($213 * $259);
     $308 = Math_fround($211 * $258);
     $309 = Math_fround($235 * $305);
     $310 = Math_fround($235 * $306);
     $311 = Math_fround($235 * $307);
     $312 = Math_fround($235 * $308);
     $313 = Math_fround($133 * $278);
     $314 = Math_fround($133 * $277);
     $315 = Math_fround($133 * $276);
     $316 = Math_fround($133 * $275);
     $317 = Math_fround($131 * $278);
     $318 = Math_fround($131 * $277);
     $319 = Math_fround($131 * $276);
     $320 = Math_fround($131 * $275);
     $321 = Math_fround($129 * $278);
     $322 = Math_fround($129 * $277);
     $323 = Math_fround($129 * $276);
     $324 = Math_fround($129 * $275);
     $325 = Math_fround($127 - $313);
     $326 = Math_fround($125 - $314);
     $327 = Math_fround($123 - $315);
     $328 = Math_fround($121 - $316);
     $329 = Math_fround($119 - $317);
     $330 = Math_fround($117 - $318);
     $331 = Math_fround($115 - $319);
     $332 = Math_fround($113 - $320);
     $333 = Math_fround($309 - $235);
     $334 = Math_fround($111 - $321);
     $335 = Math_fround($310 - $235);
     $336 = Math_fround($109 - $322);
     $337 = Math_fround($311 - $235);
     $338 = Math_fround($107 - $323);
     $339 = Math_fround($312 - $235);
     $340 = Math_fround($105 - $324);
     $341 = $$demorgan333$us ? Math_fround(0.0) : $339;
     $342 = Math_fround($340 * $341);
     $343 = $$demorgan334335$us ? Math_fround(0.0) : $337;
     $344 = Math_fround($338 * $343);
     $345 = $$demorgan336337$us ? Math_fround(0.0) : $335;
     $346 = Math_fround($336 * $345);
     $347 = $$demorgan338339$us ? Math_fround(0.0) : $333;
     $348 = Math_fround($334 * $347);
     $349 = Math_fround(HEAPF32[$accum>>2]);
     $350 = Math_fround($342 + $349);
     $351 = Math_fround(HEAPF32[$35>>2]);
     $352 = Math_fround($344 + $351);
     $353 = Math_fround(HEAPF32[$36>>2]);
     $354 = Math_fround($346 + $353);
     $355 = Math_fround(HEAPF32[$37>>2]);
     $356 = Math_fround($348 + $355);
     $357 = (HEAPF32[tempDoublePtr>>2]=$350,HEAP32[tempDoublePtr>>2]|0);
     $358 = (HEAPF32[tempDoublePtr>>2]=$352,HEAP32[tempDoublePtr>>2]|0);
     $359 = (HEAPF32[tempDoublePtr>>2]=$354,HEAP32[tempDoublePtr>>2]|0);
     $360 = (HEAPF32[tempDoublePtr>>2]=$356,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$accum>>2] = $357;
     HEAP32[$35>>2] = $358;
     HEAP32[$36>>2] = $359;
     HEAP32[$37>>2] = $360;
     $361 = Math_fround($332 * $341);
     $362 = Math_fround($331 * $343);
     $363 = Math_fround($330 * $345);
     $364 = Math_fround($329 * $347);
     $365 = Math_fround(HEAPF32[$38>>2]);
     $366 = Math_fround($361 + $365);
     $367 = Math_fround(HEAPF32[$39>>2]);
     $368 = Math_fround($362 + $367);
     $369 = Math_fround(HEAPF32[$40>>2]);
     $370 = Math_fround($363 + $369);
     $371 = Math_fround(HEAPF32[$41>>2]);
     $372 = Math_fround($364 + $371);
     $373 = (HEAPF32[tempDoublePtr>>2]=$366,HEAP32[tempDoublePtr>>2]|0);
     $374 = (HEAPF32[tempDoublePtr>>2]=$368,HEAP32[tempDoublePtr>>2]|0);
     $375 = (HEAPF32[tempDoublePtr>>2]=$370,HEAP32[tempDoublePtr>>2]|0);
     $376 = (HEAPF32[tempDoublePtr>>2]=$372,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$38>>2] = $373;
     HEAP32[$39>>2] = $374;
     HEAP32[$40>>2] = $375;
     HEAP32[$41>>2] = $376;
     $377 = Math_fround($328 * $341);
     $378 = Math_fround($327 * $343);
     $379 = Math_fround($326 * $345);
     $380 = Math_fround($325 * $347);
     $381 = Math_fround(HEAPF32[$42>>2]);
     $382 = Math_fround($377 + $381);
     $383 = Math_fround(HEAPF32[$43>>2]);
     $384 = Math_fround($378 + $383);
     $385 = Math_fround(HEAPF32[$44>>2]);
     $386 = Math_fround($379 + $385);
     $387 = Math_fround(HEAPF32[$45>>2]);
     $388 = Math_fround($380 + $387);
     $389 = (HEAPF32[tempDoublePtr>>2]=$382,HEAP32[tempDoublePtr>>2]|0);
     $390 = (HEAPF32[tempDoublePtr>>2]=$384,HEAP32[tempDoublePtr>>2]|0);
     $391 = (HEAPF32[tempDoublePtr>>2]=$386,HEAP32[tempDoublePtr>>2]|0);
     $392 = (HEAPF32[tempDoublePtr>>2]=$388,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$42>>2] = $389;
     HEAP32[$43>>2] = $390;
     HEAP32[$44>>2] = $391;
     HEAP32[$45>>2] = $392;
     $393 = Math_fround(HEAPF32[$46>>2]);
     $394 = $$demorgan333$us ? Math_fround(0.0) : Math_fround(1.0);
     $395 = Math_fround($394 + $393);
     $396 = Math_fround(HEAPF32[$47>>2]);
     $397 = $$demorgan334335$us ? Math_fround(0.0) : Math_fround(1.0);
     $398 = Math_fround($397 + $396);
     $399 = Math_fround(HEAPF32[$48>>2]);
     $400 = $$demorgan336337$us ? Math_fround(0.0) : Math_fround(1.0);
     $401 = Math_fround($400 + $399);
     $402 = Math_fround(HEAPF32[$49>>2]);
     $403 = $$demorgan338339$us ? Math_fround(0.0) : Math_fround(1.0);
     $404 = Math_fround($403 + $402);
     $405 = (HEAPF32[tempDoublePtr>>2]=$395,HEAP32[tempDoublePtr>>2]|0);
     $406 = (HEAPF32[tempDoublePtr>>2]=$398,HEAP32[tempDoublePtr>>2]|0);
     $407 = (HEAPF32[tempDoublePtr>>2]=$401,HEAP32[tempDoublePtr>>2]|0);
     $408 = (HEAPF32[tempDoublePtr>>2]=$404,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$46>>2] = $405;
     HEAP32[$47>>2] = $406;
     HEAP32[$48>>2] = $407;
     HEAP32[$49>>2] = $408;
     $409 = HEAP32[$2>>2]|0;
     $410 = (($409) + 156|0);
     $411 = HEAP32[$410>>2]|0;
     $412 = (($411) + ($result$0$i$us<<3)|0);
     $413 = HEAP32[$412>>2]|0;
     $414 = ((($411) + ($result$0$i$us<<3)|0) + 4|0);
     $415 = HEAP32[$414>>2]|0;
     $416 = HEAP32[$50>>2]|0;
     $417 = HEAP32[$51>>2]|0;
     $418 = $413 << 4;
     $419 = (($416) + ($413<<4)|0);
     $420 = Math_fround(HEAPF32[$419>>2]);
     $$sum$i7340$us = $418 | 4;
     $421 = (($416) + ($$sum$i7340$us)|0);
     $422 = Math_fround(HEAPF32[$421>>2]);
     $$sum1$i8341$us = $418 | 8;
     $423 = (($416) + ($$sum1$i8341$us)|0);
     $424 = Math_fround(HEAPF32[$423>>2]);
     $425 = (($417) + ($413<<4)|0);
     $426 = Math_fround(HEAPF32[$425>>2]);
     $427 = (($417) + ($$sum$i7340$us)|0);
     $428 = Math_fround(HEAPF32[$427>>2]);
     $429 = (($417) + ($$sum1$i8341$us)|0);
     $430 = Math_fround(HEAPF32[$429>>2]);
     $431 = $415 << 4;
     $432 = (($416) + ($415<<4)|0);
     $433 = Math_fround(HEAPF32[$432>>2]);
     $$sum$i1346$us = $431 | 4;
     $434 = (($416) + ($$sum$i1346$us)|0);
     $435 = Math_fround(HEAPF32[$434>>2]);
     $$sum1$i2347$us = $431 | 8;
     $436 = (($416) + ($$sum1$i2347$us)|0);
     $437 = Math_fround(HEAPF32[$436>>2]);
     $438 = (($417) + ($415<<4)|0);
     $439 = Math_fround(HEAPF32[$438>>2]);
     $440 = (($417) + ($$sum$i1346$us)|0);
     $441 = Math_fround(HEAPF32[$440>>2]);
     $442 = (($417) + ($$sum1$i2347$us)|0);
     $443 = Math_fround(HEAPF32[$442>>2]);
     $444 = Math_fround($426 - $420);
     $445 = Math_fround($428 - $422);
     $446 = Math_fround($430 - $424);
     $447 = Math_fround($439 - $433);
     $448 = Math_fround($441 - $435);
     $449 = Math_fround($443 - $437);
     $450 = Math_fround($447 - $444);
     $451 = Math_fround($448 - $445);
     $452 = Math_fround($449 - $446);
     $453 = HEAP32[478280>>2]|0;
     $454 = HEAP32[((478280 + 4|0))>>2]|0;
     $455 = HEAP32[((478280 + 8|0))>>2]|0;
     $456 = HEAP32[((478280 + 12|0))>>2]|0;
     $457 = (HEAP32[tempDoublePtr>>2]=$453,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $458 = Math_fround($152 * $457);
     $459 = (HEAP32[tempDoublePtr>>2]=$454,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $460 = Math_fround($153 * $459);
     $461 = (HEAP32[tempDoublePtr>>2]=$455,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $462 = Math_fround($154 * $461);
     $463 = (HEAP32[tempDoublePtr>>2]=$456,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $464 = Math_fround($155 * $463);
     $465 = Math_fround($457 + $458);
     $466 = Math_fround($459 + $460);
     $467 = Math_fround($461 + $462);
     $468 = Math_fround($463 + $464);
     $469 = Math_fround($450 * $465);
     $470 = Math_fround($450 * $466);
     $471 = Math_fround($450 * $467);
     $472 = Math_fround($450 * $468);
     $473 = Math_fround($444 + $469);
     $474 = Math_fround($444 + $470);
     $475 = Math_fround($444 + $471);
     $476 = Math_fround($444 + $472);
     $477 = Math_fround($451 * $465);
     $478 = Math_fround($451 * $466);
     $479 = Math_fround($451 * $467);
     $480 = Math_fround($451 * $468);
     $481 = Math_fround($445 + $477);
     $482 = Math_fround($445 + $478);
     $483 = Math_fround($445 + $479);
     $484 = Math_fround($445 + $480);
     $485 = Math_fround($452 * $465);
     $486 = Math_fround($452 * $466);
     $487 = Math_fround($452 * $467);
     $488 = Math_fround($452 * $468);
     $489 = Math_fround($446 + $485);
     $490 = Math_fround($446 + $486);
     $491 = Math_fround($446 + $487);
     $492 = Math_fround($446 + $488);
     $493 = Math_fround(HEAPF32[$52>>2]);
     $494 = $$demorgan333$us ? Math_fround(0.0) : $473;
     $495 = Math_fround($493 + $494);
     $496 = Math_fround(HEAPF32[$53>>2]);
     $497 = $$demorgan334335$us ? Math_fround(0.0) : $474;
     $498 = Math_fround($496 + $497);
     $499 = Math_fround(HEAPF32[$54>>2]);
     $500 = $$demorgan336337$us ? Math_fround(0.0) : $475;
     $501 = Math_fround($499 + $500);
     $502 = Math_fround(HEAPF32[$55>>2]);
     $503 = $$demorgan338339$us ? Math_fround(0.0) : $476;
     $504 = Math_fround($502 + $503);
     $505 = (HEAPF32[tempDoublePtr>>2]=$495,HEAP32[tempDoublePtr>>2]|0);
     $506 = (HEAPF32[tempDoublePtr>>2]=$498,HEAP32[tempDoublePtr>>2]|0);
     $507 = (HEAPF32[tempDoublePtr>>2]=$501,HEAP32[tempDoublePtr>>2]|0);
     $508 = (HEAPF32[tempDoublePtr>>2]=$504,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$52>>2] = $505;
     HEAP32[$53>>2] = $506;
     HEAP32[$54>>2] = $507;
     HEAP32[$55>>2] = $508;
     $509 = Math_fround(HEAPF32[$56>>2]);
     $510 = $$demorgan333$us ? Math_fround(0.0) : $481;
     $511 = Math_fround($510 + $509);
     $512 = Math_fround(HEAPF32[$57>>2]);
     $513 = $$demorgan334335$us ? Math_fround(0.0) : $482;
     $514 = Math_fround($513 + $512);
     $515 = Math_fround(HEAPF32[$58>>2]);
     $516 = $$demorgan336337$us ? Math_fround(0.0) : $483;
     $517 = Math_fround($516 + $515);
     $518 = Math_fround(HEAPF32[$59>>2]);
     $519 = $$demorgan338339$us ? Math_fround(0.0) : $484;
     $520 = Math_fround($519 + $518);
     $521 = (HEAPF32[tempDoublePtr>>2]=$511,HEAP32[tempDoublePtr>>2]|0);
     $522 = (HEAPF32[tempDoublePtr>>2]=$514,HEAP32[tempDoublePtr>>2]|0);
     $523 = (HEAPF32[tempDoublePtr>>2]=$517,HEAP32[tempDoublePtr>>2]|0);
     $524 = (HEAPF32[tempDoublePtr>>2]=$520,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$56>>2] = $521;
     HEAP32[$57>>2] = $522;
     HEAP32[$58>>2] = $523;
     HEAP32[$59>>2] = $524;
     $525 = Math_fround(HEAPF32[$60>>2]);
     $526 = $$demorgan333$us ? Math_fround(0.0) : $489;
     $527 = Math_fround($526 + $525);
     $528 = Math_fround(HEAPF32[$61>>2]);
     $529 = $$demorgan334335$us ? Math_fround(0.0) : $490;
     $530 = Math_fround($529 + $528);
     $531 = Math_fround(HEAPF32[$62>>2]);
     $532 = $$demorgan336337$us ? Math_fround(0.0) : $491;
     $533 = Math_fround($532 + $531);
     $534 = Math_fround(HEAPF32[$63>>2]);
     $535 = $$demorgan338339$us ? Math_fround(0.0) : $492;
     $536 = Math_fround($535 + $534);
     $537 = (HEAPF32[tempDoublePtr>>2]=$527,HEAP32[tempDoublePtr>>2]|0);
     $538 = (HEAPF32[tempDoublePtr>>2]=$530,HEAP32[tempDoublePtr>>2]|0);
     $539 = (HEAPF32[tempDoublePtr>>2]=$533,HEAP32[tempDoublePtr>>2]|0);
     $540 = (HEAPF32[tempDoublePtr>>2]=$536,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$60>>2] = $537;
     HEAP32[$61>>2] = $538;
     HEAP32[$62>>2] = $539;
     HEAP32[$63>>2] = $540;
    }
   } else {
    $223 = HEAP32[$31>>2]|0;
    $224 = $210 ^ -1;
    $225 = $223 & $224;
    $226 = HEAP32[$32>>2]|0;
    $227 = $226 & $224;
    $228 = HEAP32[$33>>2]|0;
    $229 = $228 & $224;
    $230 = HEAP32[$34>>2]|0;
    $231 = $230 & $224;
    HEAP32[$31>>2] = $225;
    HEAP32[$32>>2] = $227;
    HEAP32[$33>>2] = $229;
    HEAP32[$34>>2] = $231;
   }
   $541 = ($71|0)==(0);
   if ($541) {
    $$pre$phi360Z2D = $31;$$pre$phi364Z2D = $32;$$pre$phi368Z2D = $33;$$pre$phi372Z2D = $34;
    break;
   } else {
    $73 = $92;$75 = $93;$77 = $94;$79 = $95;$mask$0357$us = $71;
   }
  }
  $888 = HEAP32[$$pre$phi360Z2D>>2]|0;
  HEAP32[$agg$result>>2] = $888;
  $889 = HEAP32[$$pre$phi364Z2D>>2]|0;
  $890 = (($agg$result) + 4|0);
  HEAP32[$890>>2] = $889;
  $891 = HEAP32[$$pre$phi368Z2D>>2]|0;
  $892 = (($agg$result) + 8|0);
  HEAP32[$892>>2] = $891;
  $893 = HEAP32[$$pre$phi372Z2D>>2]|0;
  $894 = (($agg$result) + 12|0);
  HEAP32[$894>>2] = $893;
  STACKTOP = sp;return;
 } else {
  $551 = $15;$553 = $15;$555 = $15;$557 = $15;$mask$0357 = $15;
  while(1) {
   $542 = (0 - ($mask$0357))|0;
   $543 = $mask$0357 & $542;
   $$0$i = $543;$result$0$i = 0;
   while(1) {
    $544 = $$0$i >>> 1;
    $545 = ($544|0)==(0);
    $546 = (($result$0$i) + 1)|0;
    if ($545) {
     break;
    } else {
     $$0$i = $544;$result$0$i = $546;
    }
   }
   $547 = (($mask$0357) + -1)|0;
   $548 = ($result$0$i*48)|0;
   $549 = $547 & $mask$0357;
   $550 = (($551) + -1)|0;
   $552 = (($553) + -1)|0;
   $554 = (($555) + -1)|0;
   $556 = (($557) + -1)|0;
   $558 = HEAP32[$shapeMask>>2]|0;
   $559 = (0 - ($551))|0;
   $560 = $558 & $559;
   $561 = HEAP32[$7>>2]|0;
   $562 = (0 - ($553))|0;
   $563 = $561 & $562;
   $564 = HEAP32[$9>>2]|0;
   $565 = (0 - ($555))|0;
   $566 = $564 & $565;
   $567 = HEAP32[$11>>2]|0;
   $568 = (0 - ($557))|0;
   $569 = $567 & $568;
   $not$x$i$i$i$i = ($560|0)!=(0);
   $not$y$i$i$i$i = ($563|0)!=(0);
   $not$z$i$i$i$i = ($566|0)!=(0);
   $not$w$i$i$i$i = ($569|0)!=(0);
   $570 = $550 & $551;
   $571 = $552 & $553;
   $572 = $554 & $555;
   $573 = $556 & $557;
   $574 = (($1) + (($result$0$i*48)|0)|0);
   $575 = Math_fround(HEAPF32[$574>>2]);
   $$sum$i24317 = $548 | 4;
   $576 = (($1) + ($$sum$i24317)|0);
   $577 = Math_fround(HEAPF32[$576>>2]);
   $$sum1$i25318 = $548 | 8;
   $578 = (($1) + ($$sum1$i25318)|0);
   $579 = Math_fround(HEAPF32[$578>>2]);
   $$sum2$i26319 = $548 | 12;
   $580 = (($1) + ($$sum2$i26319)|0);
   $581 = Math_fround(HEAPF32[$580>>2]);
   $582 = Math_fround(HEAPF32[$positions>>2]);
   $583 = Math_fround($582 - $575);
   $584 = Math_fround(HEAPF32[$20>>2]);
   $585 = Math_fround($584 - $575);
   $586 = Math_fround(HEAPF32[$21>>2]);
   $587 = Math_fround($586 - $575);
   $588 = Math_fround(HEAPF32[$22>>2]);
   $589 = Math_fround($588 - $575);
   $590 = Math_fround(HEAPF32[$23>>2]);
   $591 = Math_fround($590 - $577);
   $592 = Math_fround(HEAPF32[$24>>2]);
   $593 = Math_fround($592 - $577);
   $594 = Math_fround(HEAPF32[$25>>2]);
   $595 = Math_fround($594 - $577);
   $596 = Math_fround(HEAPF32[$26>>2]);
   $597 = Math_fround($596 - $577);
   $598 = Math_fround(HEAPF32[$27>>2]);
   $599 = Math_fround($598 - $579);
   $600 = Math_fround(HEAPF32[$28>>2]);
   $601 = Math_fround($600 - $579);
   $602 = Math_fround(HEAPF32[$29>>2]);
   $603 = Math_fround($602 - $579);
   $604 = Math_fround(HEAPF32[$30>>2]);
   $605 = Math_fround($604 - $579);
   $606 = (($19) + ($548)|0);
   $607 = Math_fround(HEAPF32[$606>>2]);
   $608 = (($19) + ($$sum$i24317)|0);
   $609 = Math_fround(HEAPF32[$608>>2]);
   $610 = (($19) + ($$sum1$i25318)|0);
   $611 = Math_fround(HEAPF32[$610>>2]);
   $612 = (($19) + ($$sum2$i26319)|0);
   $613 = Math_fround(HEAPF32[$612>>2]);
   $614 = Math_fround($583 * $607);
   $615 = Math_fround($585 * $607);
   $616 = Math_fround($587 * $607);
   $617 = Math_fround($589 * $607);
   $618 = Math_fround($591 * $609);
   $619 = Math_fround($593 * $609);
   $620 = Math_fround($595 * $609);
   $621 = Math_fround($597 * $609);
   $622 = Math_fround($614 + $618);
   $623 = Math_fround($615 + $619);
   $624 = Math_fround($616 + $620);
   $625 = Math_fround($617 + $621);
   $626 = Math_fround($599 * $611);
   $627 = Math_fround($601 * $611);
   $628 = Math_fround($603 * $611);
   $629 = Math_fround($605 * $611);
   $630 = Math_fround($622 + $626);
   $631 = Math_fround($623 + $627);
   $632 = Math_fround($624 + $628);
   $633 = Math_fround($625 + $629);
   $634 = Math_fround($613 * $630);
   $635 = Math_fround($613 * $631);
   $636 = Math_fround($613 * $632);
   $637 = Math_fround($613 * $633);
   $638 = Math_fround($581 + $634);
   $639 = Math_fround($581 + $635);
   $640 = Math_fround($581 + $636);
   $641 = Math_fround($581 + $637);
   $642 = HEAP32[478232>>2]|0;
   $643 = HEAP32[((478232 + 4|0))>>2]|0;
   $644 = HEAP32[((478232 + 8|0))>>2]|0;
   $645 = HEAP32[((478232 + 12|0))>>2]|0;
   $646 = (HEAP32[tempDoublePtr>>2]=$642,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $647 = $638 < $646;
   $648 = $647 ? $646 : $638;
   $649 = (HEAP32[tempDoublePtr>>2]=$643,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $650 = $639 < $649;
   $651 = $650 ? $649 : $639;
   $652 = (HEAP32[tempDoublePtr>>2]=$644,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $653 = $640 < $652;
   $654 = $653 ? $652 : $640;
   $655 = (HEAP32[tempDoublePtr>>2]=$645,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $656 = $641 < $655;
   $657 = $656 ? $655 : $641;
   $658 = Math_fround($583 * $583);
   $659 = Math_fround($585 * $585);
   $660 = Math_fround($587 * $587);
   $661 = Math_fround($589 * $589);
   $662 = Math_fround($591 * $591);
   $663 = Math_fround($593 * $593);
   $664 = Math_fround($595 * $595);
   $665 = Math_fround($597 * $597);
   $666 = Math_fround($658 + $662);
   $667 = Math_fround($659 + $663);
   $668 = Math_fround($660 + $664);
   $669 = Math_fround($661 + $665);
   $670 = Math_fround($599 * $599);
   $671 = Math_fround($601 * $601);
   $672 = Math_fround($603 * $603);
   $673 = Math_fround($605 * $605);
   $674 = Math_fround($666 + $670);
   $675 = Math_fround($667 + $671);
   $676 = Math_fround($668 + $672);
   $677 = Math_fround($669 + $673);
   $678 = Math_fround($630 * $630);
   $679 = Math_fround($631 * $631);
   $680 = Math_fround($632 * $632);
   $681 = Math_fround($633 * $633);
   $682 = Math_fround($674 - $678);
   $683 = Math_fround($675 - $679);
   $684 = Math_fround($676 - $680);
   $685 = Math_fround($677 - $681);
   $686 = (($18) + ($$sum2$i26319)|0);
   $687 = Math_fround(HEAPF32[$686>>2]);
   $688 = (HEAPF32[tempDoublePtr>>2]=$687,HEAP32[tempDoublePtr>>2]|0);
   $689 = $not$x$i$i$i$i ? $648 : Math_fround(0.0);
   $690 = Math_fround($689 * $689);
   $691 = $not$y$i$i$i$i ? $651 : Math_fround(0.0);
   $692 = Math_fround($691 * $691);
   $693 = $not$z$i$i$i$i ? $654 : Math_fround(0.0);
   $694 = Math_fround($693 * $693);
   $695 = $not$w$i$i$i$i ? $657 : Math_fround(0.0);
   $696 = Math_fround($695 * $695);
   $697 = $690 > $682;
   $698 = $692 > $683;
   $699 = $694 > $684;
   $700 = $696 > $685;
   $brmerge$i = $697 | $698;
   $brmerge1$i = $brmerge$i | $699;
   $$$i = $brmerge1$i | $700;
   if ($$$i) {
    $711 = (($18) + ($$sum1$i25318)|0);
    $712 = (($18) + ($$sum$i24317)|0);
    $713 = (($18) + ($548)|0);
    $not$w$i$i$i17 = $700 ^ 1;
    $not$z$i$i$i16 = $699 ^ 1;
    $not$y$i$i$i15 = $698 ^ 1;
    $not$x$i$i$i14 = $697 ^ 1;
    $714 = Math_fround(HEAPF32[$713>>2]);
    $715 = Math_fround(HEAPF32[$711>>2]);
    $716 = Math_fround(HEAPF32[$712>>2]);
    $717 = HEAP32[478152>>2]|0;
    $718 = HEAP32[((478152 + 4|0))>>2]|0;
    $719 = HEAP32[((478152 + 8|0))>>2]|0;
    $720 = HEAP32[((478152 + 12|0))>>2]|0;
    $721 = (HEAP32[tempDoublePtr>>2]=$717,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $722 = $682 < $721;
    $723 = $722 ? $721 : $682;
    $724 = (HEAP32[tempDoublePtr>>2]=$718,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $725 = $683 < $724;
    $726 = $725 ? $724 : $683;
    $727 = (HEAP32[tempDoublePtr>>2]=$719,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $728 = $684 < $727;
    $729 = $728 ? $727 : $684;
    $730 = (HEAP32[tempDoublePtr>>2]=$720,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $731 = $685 < $730;
    $732 = $731 ? $730 : $685;
    $733 = (Math_fround(Math_sqrt((Math_fround($723)))));
    $734 = (Math_fround(Math_sqrt((Math_fround($726)))));
    $735 = (Math_fround(Math_sqrt((Math_fround($729)))));
    $736 = (Math_fround(Math_sqrt((Math_fround($732)))));
    $737 = Math_fround(Math_fround(1.0) / $733);
    $738 = Math_fround(Math_fround(1.0) / $734);
    $739 = Math_fround(Math_fround(1.0) / $735);
    $740 = Math_fround(Math_fround(1.0) / $736);
    $741 = Math_fround($613 * $723);
    $742 = Math_fround($613 * $726);
    $743 = Math_fround($613 * $729);
    $744 = Math_fround($613 * $732);
    $745 = Math_fround($741 * $737);
    $746 = Math_fround($742 * $738);
    $747 = Math_fround($743 * $739);
    $748 = Math_fround($744 * $740);
    $749 = Math_fround($630 + $745);
    $750 = Math_fround($631 + $746);
    $751 = Math_fround($632 + $747);
    $752 = Math_fround($633 + $748);
    $753 = Math_fround(-$716);
    $754 = $697 ? $749 : Math_fround(0.0);
    $755 = $698 ? $750 : Math_fround(0.0);
    $756 = $699 ? $751 : Math_fround(0.0);
    $757 = $700 ? $752 : Math_fround(0.0);
    $not$x$i$i$i10 = $754 < $753;
    $not$y$i$i$i11 = $755 < $753;
    $not$z$i$i$i12 = $756 < $753;
    $not$w$i$i$i13 = $757 < $753;
    $not$x$i$i$i = $754 > $716;
    $not$y$i$i$i = $755 > $716;
    $not$z$i$i$i = $756 > $716;
    $not$w$i$i$i = $757 > $716;
    $758 = (HEAPF32[tempDoublePtr>>2]=$715,HEAP32[tempDoublePtr>>2]|0);
    $759 = $758 ^ $688;
    $760 = HEAP32[$31>>2]|0;
    $$op = $758 ^ -1;
    $761 = $not$x$i$i$i10 ? -1 : $$op;
    $762 = $761 & $760;
    $763 = HEAP32[$32>>2]|0;
    $764 = $not$y$i$i$i11 ? -1 : $$op;
    $765 = $764 & $763;
    $766 = HEAP32[$33>>2]|0;
    $767 = $not$z$i$i$i12 ? -1 : $$op;
    $768 = $767 & $766;
    $769 = HEAP32[$34>>2]|0;
    $770 = $not$w$i$i$i13 ? -1 : $$op;
    $771 = $770 & $769;
    $$op329 = $759 ^ -1;
    $772 = $not$x$i$i$i ? -1 : $$op329;
    $773 = $762 & $772;
    $774 = $not$y$i$i$i ? -1 : $$op329;
    $775 = $765 & $774;
    $776 = $not$z$i$i$i ? -1 : $$op329;
    $777 = $768 & $776;
    $778 = $not$w$i$i$i ? -1 : $$op329;
    $779 = $771 & $778;
    HEAP32[$31>>2] = $773;
    HEAP32[$32>>2] = $775;
    HEAP32[$33>>2] = $777;
    HEAP32[$34>>2] = $779;
    $780 = $not$x$i$i$i | $not$x$i$i$i10;
    $781 = $not$y$i$i$i | $not$y$i$i$i11;
    $782 = $not$z$i$i$i | $not$z$i$i$i12;
    $783 = $not$w$i$i$i | $not$w$i$i$i13;
    $$demorgan333 = $780 | $not$x$i$i$i14;
    $$demorgan334335 = $781 | $not$y$i$i$i15;
    $$demorgan336337 = $782 | $not$z$i$i$i16;
    $$demorgan338339 = $783 | $not$w$i$i$i17;
    $$demorgan352353 = $$demorgan334335 & $$demorgan333;
    $$demorgan354 = $$demorgan352353 & $$demorgan336337;
    $$demorgan355356 = $$demorgan354 & $$demorgan338339;
    if (!($$demorgan355356)) {
     $784 = Math_fround($695 * $740);
     $785 = Math_fround($693 * $739);
     $786 = Math_fround($691 * $738);
     $787 = Math_fround($689 * $737);
     $788 = Math_fround($714 * $784);
     $789 = Math_fround($714 * $785);
     $790 = Math_fround($714 * $786);
     $791 = Math_fround($714 * $787);
     $792 = Math_fround($611 * $757);
     $793 = Math_fround($611 * $756);
     $794 = Math_fround($611 * $755);
     $795 = Math_fround($611 * $754);
     $796 = Math_fround($609 * $757);
     $797 = Math_fround($609 * $756);
     $798 = Math_fround($609 * $755);
     $799 = Math_fround($609 * $754);
     $800 = Math_fround($607 * $757);
     $801 = Math_fround($607 * $756);
     $802 = Math_fround($607 * $755);
     $803 = Math_fround($607 * $754);
     $804 = Math_fround($605 - $792);
     $805 = Math_fround($603 - $793);
     $806 = Math_fround($601 - $794);
     $807 = Math_fround($599 - $795);
     $808 = Math_fround($597 - $796);
     $809 = Math_fround($595 - $797);
     $810 = Math_fround($593 - $798);
     $811 = Math_fround($591 - $799);
     $812 = Math_fround($788 - $714);
     $813 = Math_fround($589 - $800);
     $814 = Math_fround($789 - $714);
     $815 = Math_fround($587 - $801);
     $816 = Math_fround($790 - $714);
     $817 = Math_fround($585 - $802);
     $818 = Math_fround($791 - $714);
     $819 = Math_fround($583 - $803);
     $820 = $$demorgan333 ? Math_fround(0.0) : $818;
     $821 = Math_fround($819 * $820);
     $822 = $$demorgan334335 ? Math_fround(0.0) : $816;
     $823 = Math_fround($817 * $822);
     $824 = $$demorgan336337 ? Math_fround(0.0) : $814;
     $825 = Math_fround($815 * $824);
     $826 = $$demorgan338339 ? Math_fround(0.0) : $812;
     $827 = Math_fround($813 * $826);
     $828 = Math_fround(HEAPF32[$accum>>2]);
     $829 = Math_fround($821 + $828);
     $830 = Math_fround(HEAPF32[$35>>2]);
     $831 = Math_fround($823 + $830);
     $832 = Math_fround(HEAPF32[$36>>2]);
     $833 = Math_fround($825 + $832);
     $834 = Math_fround(HEAPF32[$37>>2]);
     $835 = Math_fround($827 + $834);
     $836 = (HEAPF32[tempDoublePtr>>2]=$829,HEAP32[tempDoublePtr>>2]|0);
     $837 = (HEAPF32[tempDoublePtr>>2]=$831,HEAP32[tempDoublePtr>>2]|0);
     $838 = (HEAPF32[tempDoublePtr>>2]=$833,HEAP32[tempDoublePtr>>2]|0);
     $839 = (HEAPF32[tempDoublePtr>>2]=$835,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$accum>>2] = $836;
     HEAP32[$35>>2] = $837;
     HEAP32[$36>>2] = $838;
     HEAP32[$37>>2] = $839;
     $840 = Math_fround($811 * $820);
     $841 = Math_fround($810 * $822);
     $842 = Math_fround($809 * $824);
     $843 = Math_fround($808 * $826);
     $844 = Math_fround(HEAPF32[$38>>2]);
     $845 = Math_fround($840 + $844);
     $846 = Math_fround(HEAPF32[$39>>2]);
     $847 = Math_fround($841 + $846);
     $848 = Math_fround(HEAPF32[$40>>2]);
     $849 = Math_fround($842 + $848);
     $850 = Math_fround(HEAPF32[$41>>2]);
     $851 = Math_fround($843 + $850);
     $852 = (HEAPF32[tempDoublePtr>>2]=$845,HEAP32[tempDoublePtr>>2]|0);
     $853 = (HEAPF32[tempDoublePtr>>2]=$847,HEAP32[tempDoublePtr>>2]|0);
     $854 = (HEAPF32[tempDoublePtr>>2]=$849,HEAP32[tempDoublePtr>>2]|0);
     $855 = (HEAPF32[tempDoublePtr>>2]=$851,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$38>>2] = $852;
     HEAP32[$39>>2] = $853;
     HEAP32[$40>>2] = $854;
     HEAP32[$41>>2] = $855;
     $856 = Math_fround($807 * $820);
     $857 = Math_fround($806 * $822);
     $858 = Math_fround($805 * $824);
     $859 = Math_fround($804 * $826);
     $860 = Math_fround(HEAPF32[$42>>2]);
     $861 = Math_fround($856 + $860);
     $862 = Math_fround(HEAPF32[$43>>2]);
     $863 = Math_fround($857 + $862);
     $864 = Math_fround(HEAPF32[$44>>2]);
     $865 = Math_fround($858 + $864);
     $866 = Math_fround(HEAPF32[$45>>2]);
     $867 = Math_fround($859 + $866);
     $868 = (HEAPF32[tempDoublePtr>>2]=$861,HEAP32[tempDoublePtr>>2]|0);
     $869 = (HEAPF32[tempDoublePtr>>2]=$863,HEAP32[tempDoublePtr>>2]|0);
     $870 = (HEAPF32[tempDoublePtr>>2]=$865,HEAP32[tempDoublePtr>>2]|0);
     $871 = (HEAPF32[tempDoublePtr>>2]=$867,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$42>>2] = $868;
     HEAP32[$43>>2] = $869;
     HEAP32[$44>>2] = $870;
     HEAP32[$45>>2] = $871;
     $872 = Math_fround(HEAPF32[$46>>2]);
     $873 = $$demorgan333 ? Math_fround(0.0) : Math_fround(1.0);
     $874 = Math_fround($873 + $872);
     $875 = Math_fround(HEAPF32[$47>>2]);
     $876 = $$demorgan334335 ? Math_fround(0.0) : Math_fround(1.0);
     $877 = Math_fround($876 + $875);
     $878 = Math_fround(HEAPF32[$48>>2]);
     $879 = $$demorgan336337 ? Math_fround(0.0) : Math_fround(1.0);
     $880 = Math_fround($879 + $878);
     $881 = Math_fround(HEAPF32[$49>>2]);
     $882 = $$demorgan338339 ? Math_fround(0.0) : Math_fround(1.0);
     $883 = Math_fround($882 + $881);
     $884 = (HEAPF32[tempDoublePtr>>2]=$874,HEAP32[tempDoublePtr>>2]|0);
     $885 = (HEAPF32[tempDoublePtr>>2]=$877,HEAP32[tempDoublePtr>>2]|0);
     $886 = (HEAPF32[tempDoublePtr>>2]=$880,HEAP32[tempDoublePtr>>2]|0);
     $887 = (HEAPF32[tempDoublePtr>>2]=$883,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$46>>2] = $884;
     HEAP32[$47>>2] = $885;
     HEAP32[$48>>2] = $886;
     HEAP32[$49>>2] = $887;
    }
   } else {
    $701 = HEAP32[$31>>2]|0;
    $702 = $688 ^ -1;
    $703 = $701 & $702;
    $704 = HEAP32[$32>>2]|0;
    $705 = $704 & $702;
    $706 = HEAP32[$33>>2]|0;
    $707 = $706 & $702;
    $708 = HEAP32[$34>>2]|0;
    $709 = $708 & $702;
    HEAP32[$31>>2] = $703;
    HEAP32[$32>>2] = $705;
    HEAP32[$33>>2] = $707;
    HEAP32[$34>>2] = $709;
   }
   $710 = ($549|0)==(0);
   if ($710) {
    $$pre$phi360Z2D = $31;$$pre$phi364Z2D = $32;$$pre$phi368Z2D = $33;$$pre$phi372Z2D = $34;
    break;
   } else {
    $551 = $570;$553 = $571;$555 = $572;$557 = $573;$mask$0357 = $549;
   }
  }
  $888 = HEAP32[$$pre$phi360Z2D>>2]|0;
  HEAP32[$agg$result>>2] = $888;
  $889 = HEAP32[$$pre$phi364Z2D>>2]|0;
  $890 = (($agg$result) + 4|0);
  HEAP32[$890>>2] = $889;
  $891 = HEAP32[$$pre$phi368Z2D>>2]|0;
  $892 = (($agg$result) + 8|0);
  HEAP32[$892>>2] = $891;
  $893 = HEAP32[$$pre$phi372Z2D>>2]|0;
  $894 = (($agg$result) + 12|0);
  HEAP32[$894>>2] = $893;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx5cloth11SwCollisionI8Scalar4fE14collideSpheresERKS2_PS4_PS2_RNS3_18ImpulseAccumulatorE($this,$sphereMask,$prevPos,$curPos,$accum) {
 $this = $this|0;
 $sphereMask = $sphereMask|0;
 $prevPos = $prevPos|0;
 $curPos = $curPos|0;
 $accum = $accum|0;
 var $$$i = 0, $$0$i = 0, $$in = Math_fround(0), $$in326 = Math_fround(0), $$in327 = Math_fround(0), $$in328 = Math_fround(0), $$in329 = Math_fround(0), $$in330 = Math_fround(0), $$in331 = Math_fround(0), $$in332 = Math_fround(0), $$in333 = Math_fround(0), $$in334 = Math_fround(0), $$in335 = Math_fround(0), $$in336 = Math_fround(0), $$in337 = Math_fround(0), $$in338 = Math_fround(0), $$in339 = Math_fround(0), $$in340 = Math_fround(0), $$sum$i320 = 0, $$sum1$i321 = 0;
 var $$sum2$i322 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0);
 var $44 = 0, $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0);
 var $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge$i = 0, $brmerge1$i = 0, $mask$0343 = 0, $not$w$i$i$i12 = 0, $not$w$i$i$i16 = 0, $not$w$i$i$i4 = 0, $not$w$i$i$i8 = 0, $not$x$i$i$i1 = 0, $not$x$i$i$i13 = 0, $not$x$i$i$i5 = 0, $not$x$i$i$i9 = 0, $not$y$i$i$i10 = 0, $not$y$i$i$i14 = 0, $not$y$i$i$i2 = 0;
 var $not$y$i$i$i6 = 0, $not$z$i$i$i11 = 0, $not$z$i$i$i15 = 0, $not$z$i$i$i3 = 0, $not$z$i$i$i7 = 0, $result$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 424|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 432|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 216|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $7 > Math_fround(0.0);
 $9 = HEAP32[$sphereMask>>2]|0;
 $10 = (($sphereMask) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($sphereMask) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($sphereMask) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $11 | $9;
 $17 = $16 | $13;
 $18 = $17 | $15;
 $19 = ($18|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (($prevPos) + 4|0);
 $21 = (($prevPos) + 8|0);
 $22 = (($prevPos) + 12|0);
 $23 = (($prevPos) + 16|0);
 $24 = (($prevPos) + 20|0);
 $25 = (($prevPos) + 24|0);
 $26 = (($prevPos) + 28|0);
 $27 = (($prevPos) + 32|0);
 $28 = (($prevPos) + 36|0);
 $29 = (($prevPos) + 40|0);
 $30 = (($prevPos) + 44|0);
 $31 = (($curPos) + 4|0);
 $32 = (($curPos) + 8|0);
 $33 = (($curPos) + 12|0);
 $34 = (($curPos) + 16|0);
 $35 = (($curPos) + 20|0);
 $36 = (($curPos) + 24|0);
 $37 = (($curPos) + 28|0);
 $38 = (($curPos) + 32|0);
 $39 = (($curPos) + 36|0);
 $40 = (($curPos) + 40|0);
 $41 = (($curPos) + 44|0);
 $42 = (($accum) + 4|0);
 $43 = (($accum) + 8|0);
 $44 = (($accum) + 12|0);
 $45 = (($accum) + 16|0);
 $46 = (($accum) + 20|0);
 $47 = (($accum) + 24|0);
 $48 = (($accum) + 28|0);
 $49 = (($accum) + 32|0);
 $50 = (($accum) + 36|0);
 $51 = (($accum) + 40|0);
 $52 = (($accum) + 44|0);
 $53 = (($accum) + 96|0);
 $54 = (($accum) + 100|0);
 $55 = (($accum) + 104|0);
 $56 = (($accum) + 108|0);
 $57 = (($accum) + 48|0);
 $58 = (($accum) + 52|0);
 $59 = (($accum) + 56|0);
 $60 = (($accum) + 60|0);
 $61 = (($accum) + 64|0);
 $62 = (($accum) + 68|0);
 $63 = (($accum) + 72|0);
 $64 = (($accum) + 76|0);
 $65 = (($accum) + 80|0);
 $66 = (($accum) + 84|0);
 $67 = (($accum) + 88|0);
 $68 = (($accum) + 92|0);
 $mask$0343 = $18;
 while(1) {
  $69 = (0 - ($mask$0343))|0;
  $70 = $mask$0343 & $69;
  $$0$i = $70;$result$0$i = 0;
  while(1) {
   $71 = $$0$i >>> 1;
   $72 = ($71|0)==(0);
   $73 = (($result$0$i) + 1)|0;
   if ($72) {
    break;
   } else {
    $$0$i = $71;$result$0$i = $73;
   }
  }
  $74 = (($mask$0343) + -1)|0;
  $75 = $result$0$i << 4;
  $76 = $74 & $mask$0343;
  $77 = (($1) + ($result$0$i<<4)|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $$sum$i320 = $75 | 4;
  $79 = (($1) + ($$sum$i320)|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $$sum1$i321 = $75 | 8;
  $81 = (($1) + ($$sum1$i321)|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $$sum2$i322 = $75 | 12;
  $83 = (($1) + ($$sum2$i322)|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = Math_fround(HEAPF32[$prevPos>>2]);
  $86 = Math_fround($85 - $78);
  $87 = Math_fround(HEAPF32[$20>>2]);
  $88 = Math_fround($87 - $78);
  $89 = Math_fround(HEAPF32[$21>>2]);
  $90 = Math_fround($89 - $78);
  $91 = Math_fround(HEAPF32[$22>>2]);
  $92 = Math_fround($91 - $78);
  $93 = Math_fround(HEAPF32[$23>>2]);
  $94 = Math_fround($93 - $80);
  $95 = Math_fround(HEAPF32[$24>>2]);
  $96 = Math_fround($95 - $80);
  $97 = Math_fround(HEAPF32[$25>>2]);
  $98 = Math_fround($97 - $80);
  $99 = Math_fround(HEAPF32[$26>>2]);
  $100 = Math_fround($99 - $80);
  $101 = Math_fround(HEAPF32[$27>>2]);
  $102 = Math_fround($101 - $82);
  $103 = Math_fround(HEAPF32[$28>>2]);
  $104 = Math_fround($103 - $82);
  $105 = Math_fround(HEAPF32[$29>>2]);
  $106 = Math_fround($105 - $82);
  $107 = Math_fround(HEAPF32[$30>>2]);
  $108 = Math_fround($107 - $82);
  $109 = Math_fround(HEAPF32[478360>>2]);
  $110 = Math_fround($84 * $109);
  $111 = Math_fround(HEAPF32[((478360 + 4|0))>>2]);
  $112 = Math_fround($84 * $111);
  $113 = Math_fround(HEAPF32[((478360 + 8|0))>>2]);
  $114 = Math_fround($84 * $113);
  $115 = Math_fround(HEAPF32[((478360 + 12|0))>>2]);
  $116 = Math_fround($84 * $115);
  $117 = (($3) + ($result$0$i<<4)|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = (($3) + ($$sum$i320)|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $121 = (($3) + ($$sum1$i321)|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = (($3) + ($$sum2$i322)|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = Math_fround(HEAPF32[$curPos>>2]);
  $126 = Math_fround($125 - $118);
  $127 = Math_fround(HEAPF32[$31>>2]);
  $128 = Math_fround($127 - $118);
  $129 = Math_fround(HEAPF32[$32>>2]);
  $130 = Math_fround($129 - $118);
  $131 = Math_fround(HEAPF32[$33>>2]);
  $132 = Math_fround($131 - $118);
  $133 = Math_fround(HEAPF32[$34>>2]);
  $134 = Math_fround($133 - $120);
  $135 = Math_fround(HEAPF32[$35>>2]);
  $136 = Math_fround($135 - $120);
  $137 = Math_fround(HEAPF32[$36>>2]);
  $138 = Math_fround($137 - $120);
  $139 = Math_fround(HEAPF32[$37>>2]);
  $140 = Math_fround($139 - $120);
  $141 = Math_fround(HEAPF32[$38>>2]);
  $142 = Math_fround($141 - $122);
  $143 = Math_fround(HEAPF32[$39>>2]);
  $144 = Math_fround($143 - $122);
  $145 = Math_fround(HEAPF32[$40>>2]);
  $146 = Math_fround($145 - $122);
  $147 = Math_fround(HEAPF32[$41>>2]);
  $148 = Math_fround($147 - $122);
  $149 = Math_fround($109 * $124);
  $150 = Math_fround($111 * $124);
  $151 = Math_fround($113 * $124);
  $152 = Math_fround($115 * $124);
  $153 = HEAP32[478152>>2]|0;
  $154 = HEAP32[((478152 + 4|0))>>2]|0;
  $155 = HEAP32[((478152 + 8|0))>>2]|0;
  $156 = HEAP32[((478152 + 12|0))>>2]|0;
  $157 = Math_fround($126 * $126);
  $158 = Math_fround($128 * $128);
  $159 = Math_fround($130 * $130);
  $160 = Math_fround($132 * $132);
  $161 = (HEAP32[tempDoublePtr>>2]=$153,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $162 = Math_fround($157 + $161);
  $163 = (HEAP32[tempDoublePtr>>2]=$154,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $164 = Math_fround($158 + $163);
  $165 = (HEAP32[tempDoublePtr>>2]=$155,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $166 = Math_fround($159 + $165);
  $167 = (HEAP32[tempDoublePtr>>2]=$156,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $168 = Math_fround($160 + $167);
  $169 = Math_fround($134 * $134);
  $170 = Math_fround($136 * $136);
  $171 = Math_fround($138 * $138);
  $172 = Math_fround($140 * $140);
  $173 = Math_fround($169 + $162);
  $174 = Math_fround($170 + $164);
  $175 = Math_fround($171 + $166);
  $176 = Math_fround($172 + $168);
  $177 = Math_fround($142 * $142);
  $178 = Math_fround($144 * $144);
  $179 = Math_fround($146 * $146);
  $180 = Math_fround($148 * $148);
  $181 = Math_fround($177 + $173);
  $182 = Math_fround($178 + $174);
  $183 = Math_fround($179 + $175);
  $184 = Math_fround($180 + $176);
  $185 = Math_fround($86 * $86);
  $186 = Math_fround($88 * $88);
  $187 = Math_fround($90 * $90);
  $188 = Math_fround($92 * $92);
  $189 = Math_fround($94 * $94);
  $190 = Math_fround($96 * $96);
  $191 = Math_fround($98 * $98);
  $192 = Math_fround($100 * $100);
  $193 = Math_fround($185 + $189);
  $194 = Math_fround($186 + $190);
  $195 = Math_fround($187 + $191);
  $196 = Math_fround($188 + $192);
  $197 = Math_fround($102 * $102);
  $198 = Math_fround($104 * $104);
  $199 = Math_fround($106 * $106);
  $200 = Math_fround($108 * $108);
  $201 = Math_fround($193 + $197);
  $202 = Math_fround($194 + $198);
  $203 = Math_fround($195 + $199);
  $204 = Math_fround($196 + $200);
  $205 = Math_fround($110 * $110);
  $206 = Math_fround($112 * $112);
  $207 = Math_fround($114 * $114);
  $208 = Math_fround($116 * $116);
  $209 = Math_fround($201 - $205);
  $210 = Math_fround($202 - $206);
  $211 = Math_fround($203 - $207);
  $212 = Math_fround($204 - $208);
  $213 = Math_fround($86 * $126);
  $214 = Math_fround($88 * $128);
  $215 = Math_fround($90 * $130);
  $216 = Math_fround($92 * $132);
  $217 = Math_fround($94 * $134);
  $218 = Math_fround($96 * $136);
  $219 = Math_fround($98 * $138);
  $220 = Math_fround($100 * $140);
  $221 = Math_fround($213 + $217);
  $222 = Math_fround($214 + $218);
  $223 = Math_fround($215 + $219);
  $224 = Math_fround($216 + $220);
  $225 = Math_fround($102 * $142);
  $226 = Math_fround($104 * $144);
  $227 = Math_fround($106 * $146);
  $228 = Math_fround($108 * $148);
  $229 = Math_fround($221 + $225);
  $230 = Math_fround($222 + $226);
  $231 = Math_fround($223 + $227);
  $232 = Math_fround($224 + $228);
  $233 = Math_fround($110 * $149);
  $234 = Math_fround($112 * $150);
  $235 = Math_fround($114 * $151);
  $236 = Math_fround($116 * $152);
  $237 = Math_fround($229 - $233);
  $238 = Math_fround($230 - $234);
  $239 = Math_fround($231 - $235);
  $240 = Math_fround($232 - $236);
  $241 = Math_fround($149 * $149);
  $242 = Math_fround($150 * $150);
  $243 = Math_fround($151 * $151);
  $244 = Math_fround($152 * $152);
  $245 = Math_fround($181 - $241);
  $246 = Math_fround($182 - $242);
  $247 = Math_fround($183 - $243);
  $248 = Math_fround($184 - $244);
  $249 = Math_fround($237 * $237);
  $250 = Math_fround($238 * $238);
  $251 = Math_fround($239 * $239);
  $252 = Math_fround($240 * $240);
  $253 = Math_fround($209 * $245);
  $254 = Math_fround($210 * $246);
  $255 = Math_fround($211 * $247);
  $256 = Math_fround($212 * $248);
  $257 = Math_fround($249 - $253);
  $258 = Math_fround($250 - $254);
  $259 = Math_fround($251 - $255);
  $260 = Math_fround($252 - $256);
  $261 = (Math_fround(Math_sqrt((Math_fround($257)))));
  $262 = (Math_fround(Math_sqrt((Math_fround($258)))));
  $263 = (Math_fround(Math_sqrt((Math_fround($259)))));
  $264 = (Math_fround(Math_sqrt((Math_fround($260)))));
  $265 = Math_fround($237 - $209);
  $266 = Math_fround($238 - $210);
  $267 = Math_fround($239 - $211);
  $268 = Math_fround($240 - $212);
  $269 = Math_fround($237 - $245);
  $270 = Math_fround($238 - $246);
  $271 = Math_fround($239 - $247);
  $272 = Math_fround($240 - $248);
  $273 = Math_fround($265 + $269);
  $274 = Math_fround($266 + $270);
  $275 = Math_fround($267 + $271);
  $276 = Math_fround($268 + $272);
  $277 = Math_fround(Math_fround(1.0) / $273);
  $278 = Math_fround(Math_fround(1.0) / $274);
  $279 = Math_fround(Math_fround(1.0) / $275);
  $280 = Math_fround(Math_fround(1.0) / $276);
  $281 = Math_fround($265 + $261);
  $282 = Math_fround($266 + $262);
  $283 = Math_fround($267 + $263);
  $284 = Math_fround($268 + $264);
  $285 = $281 < Math_fround(0.0);
  $286 = $285 ? $281 : Math_fround(0.0);
  $287 = $282 < Math_fround(0.0);
  $288 = $287 ? $282 : Math_fround(0.0);
  $289 = $283 < Math_fround(0.0);
  $290 = $289 ? $283 : Math_fround(0.0);
  $291 = $284 < Math_fround(0.0);
  $292 = $291 ? $284 : Math_fround(0.0);
  $293 = Math_fround($286 * $277);
  $294 = Math_fround($288 * $278);
  $295 = Math_fround($290 * $279);
  $296 = Math_fround($292 * $280);
  $not$x$i$i$i13 = $293 < Math_fround(1.0);
  $not$y$i$i$i14 = $294 < Math_fround(1.0);
  $not$z$i$i$i15 = $295 < Math_fround(1.0);
  $not$w$i$i$i16 = $296 < Math_fround(1.0);
  $not$x$i$i$i9 = $265 < $261;
  $not$y$i$i$i10 = $266 < $262;
  $not$z$i$i$i11 = $267 < $263;
  $not$w$i$i$i12 = $268 < $264;
  $297 = $not$x$i$i$i9 & $not$x$i$i$i13;
  $298 = $not$y$i$i$i10 & $not$y$i$i$i14;
  $299 = $not$z$i$i$i11 & $not$z$i$i$i15;
  $300 = $not$w$i$i$i12 & $not$w$i$i$i16;
  $not$x$i$i$i5 = $257 >= Math_fround(0.0);
  $not$y$i$i$i6 = $258 >= Math_fround(0.0);
  $not$z$i$i$i7 = $259 >= Math_fround(0.0);
  $not$w$i$i$i8 = $260 >= Math_fround(0.0);
  $301 = $not$x$i$i$i5 & $297;
  $302 = $not$y$i$i$i6 & $298;
  $303 = $not$z$i$i$i7 & $299;
  $304 = $not$w$i$i$i8 & $300;
  $305 = Math_fround(-$161);
  $306 = Math_fround(-$163);
  $307 = Math_fround(-$165);
  $308 = Math_fround(-$167);
  $not$x$i$i$i1 = $273 < $305;
  $not$y$i$i$i2 = $274 < $306;
  $not$z$i$i$i3 = $275 < $307;
  $not$w$i$i$i4 = $276 < $308;
  $309 = $not$x$i$i$i1 & $301;
  $310 = $309 << 31 >> 31;
  $311 = $not$y$i$i$i2 & $302;
  $312 = $not$z$i$i$i3 & $303;
  $313 = $312 << 31 >> 31;
  $314 = $not$w$i$i$i4 & $304;
  $315 = $314 << 31 >> 31;
  $316 = (HEAP32[tempDoublePtr>>2]=$310,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $317 = $316 == Math_fround(0.0);
  if ($317) {
   $318 = $311 << 31 >> 31;
   $319 = (HEAP32[tempDoublePtr>>2]=$318,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $320 = $319 == Math_fround(0.0);
   if ($320) {
    $321 = (HEAP32[tempDoublePtr>>2]=$313,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $322 = $321 == Math_fround(0.0);
    if ($322) {
     $323 = (HEAP32[tempDoublePtr>>2]=$315,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $324 = $323 == Math_fround(0.0);
     if ($324) {
      $$in = $184;$$in326 = $183;$$in327 = $182;$$in328 = $181;$$in329 = $132;$$in330 = $130;$$in331 = $128;$$in332 = $126;$$in333 = $140;$$in334 = $138;$$in335 = $136;$$in336 = $134;$$in337 = $148;$$in338 = $146;$$in339 = $144;$$in340 = $142;
     } else {
      label = 9;
     }
    } else {
     label = 9;
    }
   } else {
    label = 9;
   }
  } else {
   label = 9;
  }
  if ((label|0) == 9) {
   label = 0;
   $325 = Math_fround($86 - $126);
   $326 = Math_fround($88 - $128);
   $327 = Math_fround($90 - $130);
   $328 = Math_fround($92 - $132);
   $329 = Math_fround($94 - $134);
   $330 = Math_fround($96 - $136);
   $331 = Math_fround($98 - $138);
   $332 = Math_fround($100 - $140);
   $333 = Math_fround($102 - $142);
   $334 = Math_fround($104 - $144);
   $335 = Math_fround($106 - $146);
   $336 = Math_fround($108 - $148);
   $337 = Math_fround(Math_fround(1.0) - $293);
   $338 = Math_fround(Math_fround(1.0) - $294);
   $339 = Math_fround(Math_fround(1.0) - $295);
   $340 = Math_fround(Math_fround(1.0) - $296);
   $341 = $309 ? $337 : Math_fround(0.0);
   $342 = Math_fround($325 * $341);
   $343 = $311 ? $338 : Math_fround(0.0);
   $344 = Math_fround($326 * $343);
   $345 = $312 ? $339 : Math_fround(0.0);
   $346 = Math_fround($327 * $345);
   $347 = $314 ? $340 : Math_fround(0.0);
   $348 = Math_fround($328 * $347);
   $349 = Math_fround($126 + $342);
   $350 = Math_fround($128 + $344);
   $351 = Math_fround($130 + $346);
   $352 = Math_fround($132 + $348);
   $353 = Math_fround($329 * $341);
   $354 = Math_fround($330 * $343);
   $355 = Math_fround($331 * $345);
   $356 = Math_fround($332 * $347);
   $357 = Math_fround($134 + $353);
   $358 = Math_fround($136 + $354);
   $359 = Math_fround($138 + $355);
   $360 = Math_fround($140 + $356);
   $361 = Math_fround($333 * $341);
   $362 = Math_fround($334 * $343);
   $363 = Math_fround($335 * $345);
   $364 = Math_fround($336 * $347);
   $365 = Math_fround($142 + $361);
   $366 = Math_fround($144 + $362);
   $367 = Math_fround($146 + $363);
   $368 = Math_fround($148 + $364);
   $369 = Math_fround($118 + $349);
   $370 = Math_fround($118 + $350);
   $371 = Math_fround($118 + $351);
   $372 = Math_fround($118 + $352);
   $373 = (HEAPF32[tempDoublePtr>>2]=$369,HEAP32[tempDoublePtr>>2]|0);
   $374 = (HEAPF32[tempDoublePtr>>2]=$370,HEAP32[tempDoublePtr>>2]|0);
   $375 = (HEAPF32[tempDoublePtr>>2]=$371,HEAP32[tempDoublePtr>>2]|0);
   $376 = (HEAPF32[tempDoublePtr>>2]=$372,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$curPos>>2] = $373;
   HEAP32[$31>>2] = $374;
   HEAP32[$32>>2] = $375;
   HEAP32[$33>>2] = $376;
   $377 = Math_fround($120 + $357);
   $378 = Math_fround($120 + $358);
   $379 = Math_fround($120 + $359);
   $380 = Math_fround($120 + $360);
   $381 = (HEAPF32[tempDoublePtr>>2]=$377,HEAP32[tempDoublePtr>>2]|0);
   $382 = (HEAPF32[tempDoublePtr>>2]=$378,HEAP32[tempDoublePtr>>2]|0);
   $383 = (HEAPF32[tempDoublePtr>>2]=$379,HEAP32[tempDoublePtr>>2]|0);
   $384 = (HEAPF32[tempDoublePtr>>2]=$380,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$34>>2] = $381;
   HEAP32[$35>>2] = $382;
   HEAP32[$36>>2] = $383;
   HEAP32[$37>>2] = $384;
   $385 = Math_fround($122 + $365);
   $386 = Math_fround($122 + $366);
   $387 = Math_fround($122 + $367);
   $388 = Math_fround($122 + $368);
   $389 = (HEAPF32[tempDoublePtr>>2]=$385,HEAP32[tempDoublePtr>>2]|0);
   $390 = (HEAPF32[tempDoublePtr>>2]=$386,HEAP32[tempDoublePtr>>2]|0);
   $391 = (HEAPF32[tempDoublePtr>>2]=$387,HEAP32[tempDoublePtr>>2]|0);
   $392 = (HEAPF32[tempDoublePtr>>2]=$388,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$38>>2] = $389;
   HEAP32[$39>>2] = $390;
   HEAP32[$40>>2] = $391;
   HEAP32[$41>>2] = $392;
   $393 = HEAP32[478152>>2]|0;
   $394 = HEAP32[((478152 + 4|0))>>2]|0;
   $395 = HEAP32[((478152 + 8|0))>>2]|0;
   $396 = HEAP32[((478152 + 12|0))>>2]|0;
   $397 = Math_fround($349 * $349);
   $398 = Math_fround($350 * $350);
   $399 = Math_fround($351 * $351);
   $400 = Math_fround($352 * $352);
   $401 = (HEAP32[tempDoublePtr>>2]=$393,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $402 = Math_fround($397 + $401);
   $403 = (HEAP32[tempDoublePtr>>2]=$394,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $404 = Math_fround($398 + $403);
   $405 = (HEAP32[tempDoublePtr>>2]=$395,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $406 = Math_fround($399 + $405);
   $407 = (HEAP32[tempDoublePtr>>2]=$396,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $408 = Math_fround($400 + $407);
   $409 = Math_fround($357 * $357);
   $410 = Math_fround($358 * $358);
   $411 = Math_fround($359 * $359);
   $412 = Math_fround($360 * $360);
   $413 = Math_fround($409 + $402);
   $414 = Math_fround($410 + $404);
   $415 = Math_fround($411 + $406);
   $416 = Math_fround($412 + $408);
   $417 = Math_fround($365 * $365);
   $418 = Math_fround($366 * $366);
   $419 = Math_fround($367 * $367);
   $420 = Math_fround($368 * $368);
   $421 = Math_fround($417 + $413);
   $422 = Math_fround($418 + $414);
   $423 = Math_fround($419 + $415);
   $424 = Math_fround($420 + $416);
   $$in = $424;$$in326 = $423;$$in327 = $422;$$in328 = $421;$$in329 = $352;$$in330 = $351;$$in331 = $350;$$in332 = $349;$$in333 = $360;$$in334 = $359;$$in335 = $358;$$in336 = $357;$$in337 = $368;$$in338 = $367;$$in339 = $366;$$in340 = $365;
  }
  $425 = (Math_fround(Math_sqrt((Math_fround($$in328)))));
  $426 = (Math_fround(Math_sqrt((Math_fround($$in327)))));
  $427 = (Math_fround(Math_sqrt((Math_fround($$in326)))));
  $428 = (Math_fround(Math_sqrt((Math_fround($$in)))));
  $429 = Math_fround(Math_fround(1.0) / $425);
  $430 = Math_fround(Math_fround(1.0) / $426);
  $431 = Math_fround(Math_fround(1.0) / $427);
  $432 = Math_fround(Math_fround(1.0) / $428);
  $433 = Math_fround($124 * $429);
  $434 = Math_fround($124 * $430);
  $435 = Math_fround($124 * $431);
  $436 = Math_fround($124 * $432);
  $437 = Math_fround(Math_fround(1.0) - $433);
  $438 = Math_fround(Math_fround(1.0) - $434);
  $439 = Math_fround(Math_fround(1.0) - $435);
  $440 = Math_fround(Math_fround(1.0) - $436);
  $441 = $437 < Math_fround(0.0);
  $442 = $438 < Math_fround(0.0);
  $443 = $439 < Math_fround(0.0);
  $444 = $440 < Math_fround(0.0);
  $brmerge$i = $441 | $442;
  $brmerge1$i = $brmerge$i | $443;
  $$$i = $brmerge1$i | $444;
  if ($$$i) {
   $445 = $441 ? $437 : Math_fround(0.0);
   $446 = Math_fround($$in332 * $445);
   $447 = $442 ? $438 : Math_fround(0.0);
   $448 = Math_fround($$in331 * $447);
   $449 = $443 ? $439 : Math_fround(0.0);
   $450 = Math_fround($$in330 * $449);
   $451 = $444 ? $440 : Math_fround(0.0);
   $452 = Math_fround($$in329 * $451);
   $453 = Math_fround(HEAPF32[$accum>>2]);
   $454 = Math_fround($453 - $446);
   $455 = Math_fround(HEAPF32[$42>>2]);
   $456 = Math_fround($455 - $448);
   $457 = Math_fround(HEAPF32[$43>>2]);
   $458 = Math_fround($457 - $450);
   $459 = Math_fround(HEAPF32[$44>>2]);
   $460 = Math_fround($459 - $452);
   $461 = (HEAPF32[tempDoublePtr>>2]=$454,HEAP32[tempDoublePtr>>2]|0);
   $462 = (HEAPF32[tempDoublePtr>>2]=$456,HEAP32[tempDoublePtr>>2]|0);
   $463 = (HEAPF32[tempDoublePtr>>2]=$458,HEAP32[tempDoublePtr>>2]|0);
   $464 = (HEAPF32[tempDoublePtr>>2]=$460,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$accum>>2] = $461;
   HEAP32[$42>>2] = $462;
   HEAP32[$43>>2] = $463;
   HEAP32[$44>>2] = $464;
   $465 = Math_fround($$in336 * $445);
   $466 = Math_fround($$in335 * $447);
   $467 = Math_fround($$in334 * $449);
   $468 = Math_fround($$in333 * $451);
   $469 = Math_fround(HEAPF32[$45>>2]);
   $470 = Math_fround($469 - $465);
   $471 = Math_fround(HEAPF32[$46>>2]);
   $472 = Math_fround($471 - $466);
   $473 = Math_fround(HEAPF32[$47>>2]);
   $474 = Math_fround($473 - $467);
   $475 = Math_fround(HEAPF32[$48>>2]);
   $476 = Math_fround($475 - $468);
   $477 = (HEAPF32[tempDoublePtr>>2]=$470,HEAP32[tempDoublePtr>>2]|0);
   $478 = (HEAPF32[tempDoublePtr>>2]=$472,HEAP32[tempDoublePtr>>2]|0);
   $479 = (HEAPF32[tempDoublePtr>>2]=$474,HEAP32[tempDoublePtr>>2]|0);
   $480 = (HEAPF32[tempDoublePtr>>2]=$476,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$45>>2] = $477;
   HEAP32[$46>>2] = $478;
   HEAP32[$47>>2] = $479;
   HEAP32[$48>>2] = $480;
   $481 = Math_fround($$in340 * $445);
   $482 = Math_fround($$in339 * $447);
   $483 = Math_fround($$in338 * $449);
   $484 = Math_fround($$in337 * $451);
   $485 = Math_fround(HEAPF32[$49>>2]);
   $486 = Math_fround($485 - $481);
   $487 = Math_fround(HEAPF32[$50>>2]);
   $488 = Math_fround($487 - $482);
   $489 = Math_fround(HEAPF32[$51>>2]);
   $490 = Math_fround($489 - $483);
   $491 = Math_fround(HEAPF32[$52>>2]);
   $492 = Math_fround($491 - $484);
   $493 = (HEAPF32[tempDoublePtr>>2]=$486,HEAP32[tempDoublePtr>>2]|0);
   $494 = (HEAPF32[tempDoublePtr>>2]=$488,HEAP32[tempDoublePtr>>2]|0);
   $495 = (HEAPF32[tempDoublePtr>>2]=$490,HEAP32[tempDoublePtr>>2]|0);
   $496 = (HEAPF32[tempDoublePtr>>2]=$492,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$49>>2] = $493;
   HEAP32[$50>>2] = $494;
   HEAP32[$51>>2] = $495;
   HEAP32[$52>>2] = $496;
   $497 = Math_fround(HEAPF32[$53>>2]);
   $498 = $441 ? Math_fround(1.0) : Math_fround(0.0);
   $499 = Math_fround($498 + $497);
   $500 = Math_fround(HEAPF32[$54>>2]);
   $501 = $442 ? Math_fround(1.0) : Math_fround(0.0);
   $502 = Math_fround($501 + $500);
   $503 = Math_fround(HEAPF32[$55>>2]);
   $504 = $443 ? Math_fround(1.0) : Math_fround(0.0);
   $505 = Math_fround($504 + $503);
   $506 = Math_fround(HEAPF32[$56>>2]);
   $507 = $444 ? Math_fround(1.0) : Math_fround(0.0);
   $508 = Math_fround($507 + $506);
   $509 = (HEAPF32[tempDoublePtr>>2]=$499,HEAP32[tempDoublePtr>>2]|0);
   $510 = (HEAPF32[tempDoublePtr>>2]=$502,HEAP32[tempDoublePtr>>2]|0);
   $511 = (HEAPF32[tempDoublePtr>>2]=$505,HEAP32[tempDoublePtr>>2]|0);
   $512 = (HEAPF32[tempDoublePtr>>2]=$508,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$53>>2] = $509;
   HEAP32[$54>>2] = $510;
   HEAP32[$55>>2] = $511;
   HEAP32[$56>>2] = $512;
   if ($8) {
    $513 = Math_fround($118 - $78);
    $514 = Math_fround($120 - $80);
    $515 = Math_fround($122 - $82);
    $516 = Math_fround(HEAPF32[$57>>2]);
    $517 = $441 ? $513 : Math_fround(0.0);
    $518 = Math_fround($517 + $516);
    $519 = Math_fround(HEAPF32[$58>>2]);
    $520 = $442 ? $513 : Math_fround(0.0);
    $521 = Math_fround($520 + $519);
    $522 = Math_fround(HEAPF32[$59>>2]);
    $523 = $443 ? $513 : Math_fround(0.0);
    $524 = Math_fround($523 + $522);
    $525 = Math_fround(HEAPF32[$60>>2]);
    $526 = $444 ? $513 : Math_fround(0.0);
    $527 = Math_fround($526 + $525);
    $528 = (HEAPF32[tempDoublePtr>>2]=$518,HEAP32[tempDoublePtr>>2]|0);
    $529 = (HEAPF32[tempDoublePtr>>2]=$521,HEAP32[tempDoublePtr>>2]|0);
    $530 = (HEAPF32[tempDoublePtr>>2]=$524,HEAP32[tempDoublePtr>>2]|0);
    $531 = (HEAPF32[tempDoublePtr>>2]=$527,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$57>>2] = $528;
    HEAP32[$58>>2] = $529;
    HEAP32[$59>>2] = $530;
    HEAP32[$60>>2] = $531;
    $532 = Math_fround(HEAPF32[$61>>2]);
    $533 = $441 ? $514 : Math_fround(0.0);
    $534 = Math_fround($533 + $532);
    $535 = Math_fround(HEAPF32[$62>>2]);
    $536 = $442 ? $514 : Math_fround(0.0);
    $537 = Math_fround($536 + $535);
    $538 = Math_fround(HEAPF32[$63>>2]);
    $539 = $443 ? $514 : Math_fround(0.0);
    $540 = Math_fround($539 + $538);
    $541 = Math_fround(HEAPF32[$64>>2]);
    $542 = $444 ? $514 : Math_fround(0.0);
    $543 = Math_fround($542 + $541);
    $544 = (HEAPF32[tempDoublePtr>>2]=$534,HEAP32[tempDoublePtr>>2]|0);
    $545 = (HEAPF32[tempDoublePtr>>2]=$537,HEAP32[tempDoublePtr>>2]|0);
    $546 = (HEAPF32[tempDoublePtr>>2]=$540,HEAP32[tempDoublePtr>>2]|0);
    $547 = (HEAPF32[tempDoublePtr>>2]=$543,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$61>>2] = $544;
    HEAP32[$62>>2] = $545;
    HEAP32[$63>>2] = $546;
    HEAP32[$64>>2] = $547;
    $548 = Math_fround(HEAPF32[$65>>2]);
    $549 = $441 ? $515 : Math_fround(0.0);
    $550 = Math_fround($549 + $548);
    $551 = Math_fround(HEAPF32[$66>>2]);
    $552 = $442 ? $515 : Math_fround(0.0);
    $553 = Math_fround($552 + $551);
    $554 = Math_fround(HEAPF32[$67>>2]);
    $555 = $443 ? $515 : Math_fround(0.0);
    $556 = Math_fround($555 + $554);
    $557 = Math_fround(HEAPF32[$68>>2]);
    $558 = $444 ? $515 : Math_fround(0.0);
    $559 = Math_fround($558 + $557);
    $560 = (HEAPF32[tempDoublePtr>>2]=$550,HEAP32[tempDoublePtr>>2]|0);
    $561 = (HEAPF32[tempDoublePtr>>2]=$553,HEAP32[tempDoublePtr>>2]|0);
    $562 = (HEAPF32[tempDoublePtr>>2]=$556,HEAP32[tempDoublePtr>>2]|0);
    $563 = (HEAPF32[tempDoublePtr>>2]=$559,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$65>>2] = $560;
    HEAP32[$66>>2] = $561;
    HEAP32[$67>>2] = $562;
    HEAP32[$68>>2] = $563;
   }
  }
  $564 = ($76|0)==(0);
  if ($564) {
   break;
  } else {
   $mask$0343 = $76;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth11SwCollisionI8Scalar4fE12collideConesEPKS2_PS2_RNS3_18ImpulseAccumulatorE($agg$result,$this,$prevPos,$curPos,$accum) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $prevPos = $prevPos|0;
 $curPos = $curPos|0;
 $accum = $accum|0;
 var $$$i = 0, $$0$i = 0, $$demorgan920 = 0, $$demorgan921922 = 0, $$demorgan923924 = 0, $$demorgan925926 = 0, $$demorgan942943 = 0, $$demorgan944 = 0, $$demorgan945946 = 0, $$pre = 0, $$pre$phi955Z2D = 0, $$pre$phi959Z2D = 0, $$pre$phi963Z2D = 0, $$pre$phi967Z2D = 0, $$pre956 = 0, $$pre960 = 0, $$pre964 = 0, $$sum$i1933 = 0, $$sum$i30905 = 0, $$sum$i7927 = 0;
 var $$sum1$i2934 = 0, $$sum1$i31906 = 0, $$sum1$i8928 = 0, $$sum2$i32907 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = Math_fround(0);
 var $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = 0, $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0);
 var $103 = 0, $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = 0, $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = 0, $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = 0, $1040 = 0, $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = 0, $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = 0, $1047 = 0;
 var $1048 = 0, $1049 = 0, $105 = 0, $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = 0, $106 = 0, $1060 = Math_fround(0), $1061 = 0, $1062 = Math_fround(0), $1063 = 0, $1064 = Math_fround(0), $1065 = 0;
 var $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = 0, $1070 = Math_fround(0), $1071 = 0, $1072 = Math_fround(0), $1073 = 0, $1074 = Math_fround(0), $1075 = 0, $1076 = Math_fround(0), $1077 = 0, $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = 0, $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = 0;
 var $1084 = Math_fround(0), $1085 = 0, $1086 = Math_fround(0), $1087 = 0, $1088 = Math_fround(0), $1089 = 0, $109 = 0, $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = 0, $1100 = Math_fround(0);
 var $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0);
 var $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0);
 var $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = Math_fround(0), $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = 0, $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0);
 var $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = 0, $1159 = 0, $116 = Math_fround(0), $1160 = 0, $1161 = 0, $1162 = Math_fround(0), $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0), $1169 = Math_fround(0), $117 = 0, $1170 = Math_fround(0), $1171 = Math_fround(0), $1172 = Math_fround(0), $1173 = Math_fround(0);
 var $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = Math_fround(0), $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = Math_fround(0), $119 = 0, $1190 = 0, $1191 = Math_fround(0);
 var $1192 = 0, $1193 = Math_fround(0), $1194 = 0, $1195 = Math_fround(0), $1196 = 0, $1197 = Math_fround(0), $1198 = 0, $1199 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $1200 = 0, $1201 = 0, $1202 = Math_fround(0), $1203 = 0, $1204 = Math_fround(0), $1205 = 0, $1206 = Math_fround(0), $1207 = 0, $1208 = Math_fround(0), $1209 = 0;
 var $121 = 0, $1210 = Math_fround(0), $1211 = 0, $1212 = Math_fround(0), $1213 = Math_fround(0), $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = Math_fround(0), $1217 = Math_fround(0), $1218 = Math_fround(0), $1219 = Math_fround(0), $122 = Math_fround(0), $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = Math_fround(0), $1227 = Math_fround(0);
 var $1228 = Math_fround(0), $1229 = Math_fround(0), $123 = 0, $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = Math_fround(0), $1233 = Math_fround(0), $1234 = Math_fround(0), $1235 = Math_fround(0), $1236 = Math_fround(0), $1237 = Math_fround(0), $1238 = Math_fround(0), $1239 = Math_fround(0), $124 = Math_fround(0), $1240 = Math_fround(0), $1241 = Math_fround(0), $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = Math_fround(0), $1245 = Math_fround(0);
 var $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = 0, $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0), $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = Math_fround(0), $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0);
 var $1264 = Math_fround(0), $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = Math_fround(0), $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = Math_fround(0), $1280 = Math_fround(0), $1281 = Math_fround(0);
 var $1282 = Math_fround(0), $1283 = Math_fround(0), $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = Math_fround(0), $1287 = Math_fround(0), $1288 = Math_fround(0), $1289 = Math_fround(0), $129 = Math_fround(0), $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = Math_fround(0), $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = Math_fround(0), $1298 = Math_fround(0), $1299 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = Math_fround(0), $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0;
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0;
 var $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0;
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0;
 var $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0);
 var $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0);
 var $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0);
 var $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0);
 var $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0;
 var $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0);
 var $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = Math_fround(0), $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0);
 var $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0);
 var $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0;
 var $600 = 0, $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0);
 var $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0);
 var $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0);
 var $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0);
 var $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0);
 var $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0);
 var $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0);
 var $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0);
 var $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0);
 var $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = Math_fround(0), $78 = 0, $780 = 0;
 var $781 = 0, $782 = Math_fround(0), $783 = 0, $784 = Math_fround(0), $785 = 0, $786 = Math_fround(0), $787 = 0, $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0);
 var $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0);
 var $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = Math_fround(0), $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0);
 var $835 = Math_fround(0), $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = Math_fround(0);
 var $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = 0, $870 = Math_fround(0);
 var $871 = Math_fround(0), $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0;
 var $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0);
 var $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0);
 var $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0);
 var $943 = Math_fround(0), $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = Math_fround(0), $949 = Math_fround(0), $95 = 0, $950 = Math_fround(0), $951 = Math_fround(0), $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = Math_fround(0), $957 = 0, $958 = Math_fround(0), $959 = Math_fround(0), $96 = 0, $960 = 0;
 var $961 = Math_fround(0), $962 = Math_fround(0), $963 = 0, $964 = Math_fround(0), $965 = Math_fround(0), $966 = 0, $967 = Math_fround(0), $968 = Math_fround(0), $969 = 0, $97 = 0, $970 = 0, $971 = Math_fround(0), $972 = 0, $973 = 0, $974 = Math_fround(0), $975 = 0, $976 = 0, $977 = Math_fround(0), $978 = 0, $979 = 0;
 var $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0;
 var $998 = 0, $999 = 0, $brmerge$i = 0, $brmerge1$i = 0, $mask$0952 = 0, $not$w$i$i$i = 0, $not$w$i$i$i$i = 0, $not$w$i$i$i13 = 0, $not$w$i$i$i17 = 0, $not$w$i$i$i21 = 0, $not$w$i$i$i25 = 0, $not$w$i$i$i29 = 0, $not$w$i$i$i40 = 0, $not$w$i$i$i44 = 0, $not$w$i$i$i48 = 0, $not$w$i$i$i52 = 0, $not$x$i$i$i = 0, $not$x$i$i$i$i = 0, $not$x$i$i$i10 = 0, $not$x$i$i$i14 = 0;
 var $not$x$i$i$i18 = 0, $not$x$i$i$i22 = 0, $not$x$i$i$i26 = 0, $not$x$i$i$i37 = 0, $not$x$i$i$i41 = 0, $not$x$i$i$i45 = 0, $not$x$i$i$i49 = 0, $not$y$i$i$i = 0, $not$y$i$i$i$i = 0, $not$y$i$i$i11 = 0, $not$y$i$i$i15 = 0, $not$y$i$i$i19 = 0, $not$y$i$i$i23 = 0, $not$y$i$i$i27 = 0, $not$y$i$i$i38 = 0, $not$y$i$i$i42 = 0, $not$y$i$i$i46 = 0, $not$y$i$i$i50 = 0, $not$z$i$i$i = 0, $not$z$i$i$i$i = 0;
 var $not$z$i$i$i12 = 0, $not$z$i$i$i16 = 0, $not$z$i$i$i20 = 0, $not$z$i$i$i24 = 0, $not$z$i$i$i28 = 0, $not$z$i$i$i39 = 0, $not$z$i$i$i43 = 0, $not$z$i$i$i47 = 0, $not$z$i$i$i51 = 0, $result$0$i = 0, $shapeMask = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $shapeMask = sp;
 $0 = (($this) + 420|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 428|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 432|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 216|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $7 > Math_fround(0.0);
 __ZNK5physx5cloth11SwCollisionI8Scalar4fE12getShapeMaskEPKS2_S5_($shapeMask,$this,$prevPos,$curPos);
 $9 = HEAP32[$shapeMask>>2]|0;
 $10 = (($shapeMask) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($shapeMask) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($shapeMask) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $11 | $9;
 $17 = $16 | $13;
 $18 = $17 | $15;
 $19 = ($18|0)==(0);
 if ($19) {
  $$pre = (($shapeMask) + 16|0);
  $$pre956 = (($shapeMask) + 20|0);
  $$pre960 = (($shapeMask) + 24|0);
  $$pre964 = (($shapeMask) + 28|0);
  $$pre$phi955Z2D = $$pre;$$pre$phi959Z2D = $$pre956;$$pre$phi963Z2D = $$pre960;$$pre$phi967Z2D = $$pre964;
  $1311 = HEAP32[$$pre$phi955Z2D>>2]|0;
  HEAP32[$agg$result>>2] = $1311;
  $1312 = HEAP32[$$pre$phi959Z2D>>2]|0;
  $1313 = (($agg$result) + 4|0);
  HEAP32[$1313>>2] = $1312;
  $1314 = HEAP32[$$pre$phi963Z2D>>2]|0;
  $1315 = (($agg$result) + 8|0);
  HEAP32[$1315>>2] = $1314;
  $1316 = HEAP32[$$pre$phi967Z2D>>2]|0;
  $1317 = (($agg$result) + 12|0);
  HEAP32[$1317>>2] = $1316;
  STACKTOP = sp;return;
 }
 $20 = (($3) + 32|0);
 $21 = (($3) + 16|0);
 $22 = (($1) + 32|0);
 $23 = (($1) + 16|0);
 $24 = (($prevPos) + 4|0);
 $25 = (($prevPos) + 8|0);
 $26 = (($prevPos) + 12|0);
 $27 = (($prevPos) + 16|0);
 $28 = (($prevPos) + 20|0);
 $29 = (($prevPos) + 24|0);
 $30 = (($prevPos) + 28|0);
 $31 = (($prevPos) + 32|0);
 $32 = (($prevPos) + 36|0);
 $33 = (($prevPos) + 40|0);
 $34 = (($prevPos) + 44|0);
 $35 = (($curPos) + 4|0);
 $36 = (($curPos) + 8|0);
 $37 = (($curPos) + 12|0);
 $38 = (($curPos) + 16|0);
 $39 = (($curPos) + 20|0);
 $40 = (($curPos) + 24|0);
 $41 = (($curPos) + 28|0);
 $42 = (($curPos) + 32|0);
 $43 = (($curPos) + 36|0);
 $44 = (($curPos) + 40|0);
 $45 = (($curPos) + 44|0);
 $46 = (($shapeMask) + 16|0);
 $47 = (($shapeMask) + 20|0);
 $48 = (($shapeMask) + 24|0);
 $49 = (($shapeMask) + 28|0);
 $50 = (($accum) + 4|0);
 $51 = (($accum) + 8|0);
 $52 = (($accum) + 12|0);
 $53 = (($accum) + 16|0);
 $54 = (($accum) + 20|0);
 $55 = (($accum) + 24|0);
 $56 = (($accum) + 28|0);
 $57 = (($accum) + 32|0);
 $58 = (($accum) + 36|0);
 $59 = (($accum) + 40|0);
 $60 = (($accum) + 44|0);
 $61 = (($accum) + 96|0);
 $62 = (($accum) + 100|0);
 $63 = (($accum) + 104|0);
 $64 = (($accum) + 108|0);
 $65 = (($this) + 416|0);
 $66 = (($this) + 424|0);
 $67 = (($accum) + 48|0);
 $68 = (($accum) + 52|0);
 $69 = (($accum) + 56|0);
 $70 = (($accum) + 60|0);
 $71 = (($accum) + 64|0);
 $72 = (($accum) + 68|0);
 $73 = (($accum) + 72|0);
 $74 = (($accum) + 76|0);
 $75 = (($accum) + 80|0);
 $76 = (($accum) + 84|0);
 $77 = (($accum) + 88|0);
 $78 = (($accum) + 92|0);
 $88 = $18;$90 = $18;$92 = $18;$94 = $18;$mask$0952 = $18;
 while(1) {
  $79 = (0 - ($mask$0952))|0;
  $80 = $mask$0952 & $79;
  $$0$i = $80;$result$0$i = 0;
  while(1) {
   $81 = $$0$i >>> 1;
   $82 = ($81|0)==(0);
   $83 = (($result$0$i) + 1)|0;
   if ($82) {
    break;
   } else {
    $$0$i = $81;$result$0$i = $83;
   }
  }
  $84 = (($mask$0952) + -1)|0;
  $85 = ($result$0$i*48)|0;
  $86 = $84 & $mask$0952;
  $87 = (($88) + -1)|0;
  $89 = (($90) + -1)|0;
  $91 = (($92) + -1)|0;
  $93 = (($94) + -1)|0;
  $95 = HEAP32[$shapeMask>>2]|0;
  $96 = (0 - ($88))|0;
  $97 = $95 & $96;
  $98 = HEAP32[$10>>2]|0;
  $99 = (0 - ($90))|0;
  $100 = $98 & $99;
  $101 = HEAP32[$12>>2]|0;
  $102 = (0 - ($92))|0;
  $103 = $101 & $102;
  $104 = HEAP32[$14>>2]|0;
  $105 = (0 - ($94))|0;
  $106 = $104 & $105;
  $not$x$i$i$i$i = ($97|0)!=(0);
  $not$y$i$i$i$i = ($100|0)!=(0);
  $not$z$i$i$i$i = ($103|0)!=(0);
  $not$w$i$i$i$i = ($106|0)!=(0);
  $107 = $87 & $88;
  $108 = $89 & $90;
  $109 = $91 & $92;
  $110 = $93 & $94;
  $111 = (($1) + (($result$0$i*48)|0)|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $$sum$i30905 = $85 | 4;
  $113 = (($1) + ($$sum$i30905)|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $$sum1$i31906 = $85 | 8;
  $115 = (($1) + ($$sum1$i31906)|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $$sum2$i32907 = $85 | 12;
  $117 = (($1) + ($$sum2$i32907)|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = (($23) + ($85)|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $121 = (($23) + ($$sum$i30905)|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = (($23) + ($$sum1$i31906)|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = (($23) + ($$sum2$i32907)|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = Math_fround(HEAPF32[$prevPos>>2]);
  $128 = Math_fround($127 - $112);
  $129 = Math_fround(HEAPF32[$24>>2]);
  $130 = Math_fround($129 - $112);
  $131 = Math_fround(HEAPF32[$25>>2]);
  $132 = Math_fround($131 - $112);
  $133 = Math_fround(HEAPF32[$26>>2]);
  $134 = Math_fround($133 - $112);
  $135 = Math_fround(HEAPF32[$27>>2]);
  $136 = Math_fround($135 - $114);
  $137 = Math_fround(HEAPF32[$28>>2]);
  $138 = Math_fround($137 - $114);
  $139 = Math_fround(HEAPF32[$29>>2]);
  $140 = Math_fround($139 - $114);
  $141 = Math_fround(HEAPF32[$30>>2]);
  $142 = Math_fround($141 - $114);
  $143 = Math_fround(HEAPF32[$31>>2]);
  $144 = Math_fround($143 - $116);
  $145 = Math_fround(HEAPF32[$32>>2]);
  $146 = Math_fround($145 - $116);
  $147 = Math_fround(HEAPF32[$33>>2]);
  $148 = Math_fround($147 - $116);
  $149 = Math_fround(HEAPF32[$34>>2]);
  $150 = Math_fround($149 - $116);
  $151 = Math_fround($124 * $136);
  $152 = Math_fround($124 * $138);
  $153 = Math_fround($124 * $140);
  $154 = Math_fround($124 * $142);
  $155 = Math_fround($122 * $144);
  $156 = Math_fround($122 * $146);
  $157 = Math_fround($122 * $148);
  $158 = Math_fround($122 * $150);
  $159 = Math_fround($151 - $155);
  $160 = Math_fround($152 - $156);
  $161 = Math_fround($153 - $157);
  $162 = Math_fround($154 - $158);
  $163 = Math_fround($120 * $144);
  $164 = Math_fround($120 * $146);
  $165 = Math_fround($120 * $148);
  $166 = Math_fround($120 * $150);
  $167 = Math_fround($124 * $128);
  $168 = Math_fround($124 * $130);
  $169 = Math_fround($124 * $132);
  $170 = Math_fround($124 * $134);
  $171 = Math_fround($163 - $167);
  $172 = Math_fround($164 - $168);
  $173 = Math_fround($165 - $169);
  $174 = Math_fround($166 - $170);
  $175 = Math_fround($122 * $128);
  $176 = Math_fround($122 * $130);
  $177 = Math_fround($122 * $132);
  $178 = Math_fround($122 * $134);
  $179 = Math_fround($120 * $136);
  $180 = Math_fround($120 * $138);
  $181 = Math_fround($120 * $140);
  $182 = Math_fround($120 * $142);
  $183 = Math_fround($175 - $179);
  $184 = Math_fround($176 - $180);
  $185 = Math_fround($177 - $181);
  $186 = Math_fround($178 - $182);
  $187 = Math_fround($120 * $128);
  $188 = Math_fround($120 * $130);
  $189 = Math_fround($120 * $132);
  $190 = Math_fround($120 * $134);
  $191 = Math_fround($122 * $136);
  $192 = Math_fround($122 * $138);
  $193 = Math_fround($122 * $140);
  $194 = Math_fround($122 * $142);
  $195 = Math_fround($187 + $191);
  $196 = Math_fround($188 + $192);
  $197 = Math_fround($189 + $193);
  $198 = Math_fround($190 + $194);
  $199 = Math_fround($124 * $144);
  $200 = Math_fround($124 * $146);
  $201 = Math_fround($124 * $148);
  $202 = Math_fround($124 * $150);
  $203 = Math_fround($195 + $199);
  $204 = Math_fround($196 + $200);
  $205 = Math_fround($197 + $201);
  $206 = Math_fround($198 + $202);
  $207 = Math_fround($126 * $203);
  $208 = Math_fround($126 * $204);
  $209 = Math_fround($126 * $205);
  $210 = Math_fround($126 * $206);
  $211 = Math_fround($118 + $207);
  $212 = Math_fround($118 + $208);
  $213 = Math_fround($118 + $209);
  $214 = Math_fround($118 + $210);
  $215 = (($3) + (($result$0$i*48)|0)|0);
  $216 = Math_fround(HEAPF32[$215>>2]);
  $217 = (($3) + ($$sum$i30905)|0);
  $218 = Math_fround(HEAPF32[$217>>2]);
  $219 = (($3) + ($$sum1$i31906)|0);
  $220 = Math_fround(HEAPF32[$219>>2]);
  $221 = (($3) + ($$sum2$i32907)|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  $223 = (($21) + ($85)|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = (($21) + ($$sum$i30905)|0);
  $226 = Math_fround(HEAPF32[$225>>2]);
  $227 = (($21) + ($$sum1$i31906)|0);
  $228 = Math_fround(HEAPF32[$227>>2]);
  $229 = (($21) + ($$sum2$i32907)|0);
  $230 = Math_fround(HEAPF32[$229>>2]);
  $231 = (($20) + ($85)|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = (($20) + ($$sum$i30905)|0);
  $234 = Math_fround(HEAPF32[$233>>2]);
  $235 = (($20) + ($$sum2$i32907)|0);
  $236 = Math_fround(HEAPF32[$235>>2]);
  $237 = Math_fround(HEAPF32[$curPos>>2]);
  $238 = Math_fround($237 - $216);
  $239 = Math_fround(HEAPF32[$35>>2]);
  $240 = Math_fround($239 - $216);
  $241 = Math_fround(HEAPF32[$36>>2]);
  $242 = Math_fround($241 - $216);
  $243 = Math_fround(HEAPF32[$37>>2]);
  $244 = Math_fround($243 - $216);
  $245 = (HEAPF32[tempDoublePtr>>2]=$238,HEAP32[tempDoublePtr>>2]|0);
  $246 = (HEAPF32[tempDoublePtr>>2]=$240,HEAP32[tempDoublePtr>>2]|0);
  $247 = (HEAPF32[tempDoublePtr>>2]=$242,HEAP32[tempDoublePtr>>2]|0);
  $248 = (HEAPF32[tempDoublePtr>>2]=$244,HEAP32[tempDoublePtr>>2]|0);
  $249 = Math_fround(HEAPF32[$38>>2]);
  $250 = Math_fround($249 - $218);
  $251 = Math_fround(HEAPF32[$39>>2]);
  $252 = Math_fround($251 - $218);
  $253 = Math_fround(HEAPF32[$40>>2]);
  $254 = Math_fround($253 - $218);
  $255 = Math_fround(HEAPF32[$41>>2]);
  $256 = Math_fround($255 - $218);
  $257 = (HEAPF32[tempDoublePtr>>2]=$250,HEAP32[tempDoublePtr>>2]|0);
  $258 = (HEAPF32[tempDoublePtr>>2]=$252,HEAP32[tempDoublePtr>>2]|0);
  $259 = (HEAPF32[tempDoublePtr>>2]=$254,HEAP32[tempDoublePtr>>2]|0);
  $260 = (HEAPF32[tempDoublePtr>>2]=$256,HEAP32[tempDoublePtr>>2]|0);
  $261 = Math_fround(HEAPF32[$42>>2]);
  $262 = Math_fround($261 - $220);
  $263 = Math_fround(HEAPF32[$43>>2]);
  $264 = Math_fround($263 - $220);
  $265 = Math_fround(HEAPF32[$44>>2]);
  $266 = Math_fround($265 - $220);
  $267 = Math_fround(HEAPF32[$45>>2]);
  $268 = Math_fround($267 - $220);
  $269 = (HEAPF32[tempDoublePtr>>2]=$262,HEAP32[tempDoublePtr>>2]|0);
  $270 = (HEAPF32[tempDoublePtr>>2]=$264,HEAP32[tempDoublePtr>>2]|0);
  $271 = (HEAPF32[tempDoublePtr>>2]=$266,HEAP32[tempDoublePtr>>2]|0);
  $272 = (HEAPF32[tempDoublePtr>>2]=$268,HEAP32[tempDoublePtr>>2]|0);
  $273 = Math_fround($228 * $250);
  $274 = Math_fround($228 * $252);
  $275 = Math_fround($228 * $254);
  $276 = Math_fround($228 * $256);
  $277 = Math_fround($226 * $262);
  $278 = Math_fround($226 * $264);
  $279 = Math_fround($226 * $266);
  $280 = Math_fround($226 * $268);
  $281 = Math_fround($273 - $277);
  $282 = Math_fround($274 - $278);
  $283 = Math_fround($275 - $279);
  $284 = Math_fround($276 - $280);
  $285 = Math_fround($224 * $262);
  $286 = Math_fround($224 * $264);
  $287 = Math_fround($224 * $266);
  $288 = Math_fround($224 * $268);
  $289 = Math_fround($228 * $238);
  $290 = Math_fround($228 * $240);
  $291 = Math_fround($228 * $242);
  $292 = Math_fround($228 * $244);
  $293 = Math_fround($285 - $289);
  $294 = Math_fround($286 - $290);
  $295 = Math_fround($287 - $291);
  $296 = Math_fround($288 - $292);
  $297 = Math_fround($226 * $238);
  $298 = Math_fround($226 * $240);
  $299 = Math_fround($226 * $242);
  $300 = Math_fround($226 * $244);
  $301 = Math_fround($224 * $250);
  $302 = Math_fround($224 * $252);
  $303 = Math_fround($224 * $254);
  $304 = Math_fround($224 * $256);
  $305 = Math_fround($297 - $301);
  $306 = Math_fround($298 - $302);
  $307 = Math_fround($299 - $303);
  $308 = Math_fround($300 - $304);
  $309 = Math_fround($224 * $238);
  $310 = Math_fround($224 * $240);
  $311 = Math_fround($224 * $242);
  $312 = Math_fround($224 * $244);
  $313 = Math_fround($226 * $250);
  $314 = Math_fround($226 * $252);
  $315 = Math_fround($226 * $254);
  $316 = Math_fround($226 * $256);
  $317 = Math_fround($309 + $313);
  $318 = Math_fround($310 + $314);
  $319 = Math_fround($311 + $315);
  $320 = Math_fround($312 + $316);
  $321 = Math_fround($228 * $262);
  $322 = Math_fround($228 * $264);
  $323 = Math_fround($228 * $266);
  $324 = Math_fround($228 * $268);
  $325 = Math_fround($317 + $321);
  $326 = Math_fround($318 + $322);
  $327 = Math_fround($319 + $323);
  $328 = Math_fround($320 + $324);
  $329 = (HEAPF32[tempDoublePtr>>2]=$325,HEAP32[tempDoublePtr>>2]|0);
  $330 = (HEAPF32[tempDoublePtr>>2]=$326,HEAP32[tempDoublePtr>>2]|0);
  $331 = (HEAPF32[tempDoublePtr>>2]=$327,HEAP32[tempDoublePtr>>2]|0);
  $332 = (HEAPF32[tempDoublePtr>>2]=$328,HEAP32[tempDoublePtr>>2]|0);
  $333 = Math_fround($230 * $325);
  $334 = Math_fround($230 * $326);
  $335 = Math_fround($230 * $327);
  $336 = Math_fround($230 * $328);
  $337 = Math_fround($222 + $333);
  $338 = Math_fround($222 + $334);
  $339 = Math_fround($222 + $335);
  $340 = Math_fround($222 + $336);
  $341 = HEAP32[478152>>2]|0;
  $342 = HEAP32[((478152 + 4|0))>>2]|0;
  $343 = HEAP32[((478152 + 8|0))>>2]|0;
  $344 = HEAP32[((478152 + 12|0))>>2]|0;
  $345 = Math_fround($281 * $281);
  $346 = Math_fround($282 * $282);
  $347 = Math_fround($283 * $283);
  $348 = Math_fround($284 * $284);
  $349 = (HEAP32[tempDoublePtr>>2]=$341,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $350 = Math_fround($345 + $349);
  $351 = (HEAP32[tempDoublePtr>>2]=$342,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $352 = Math_fround($346 + $351);
  $353 = (HEAP32[tempDoublePtr>>2]=$343,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $354 = Math_fround($347 + $353);
  $355 = (HEAP32[tempDoublePtr>>2]=$344,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $356 = Math_fround($348 + $355);
  $357 = Math_fround($293 * $293);
  $358 = Math_fround($294 * $294);
  $359 = Math_fround($295 * $295);
  $360 = Math_fround($296 * $296);
  $361 = Math_fround($357 + $350);
  $362 = Math_fround($358 + $352);
  $363 = Math_fround($359 + $354);
  $364 = Math_fround($360 + $356);
  $365 = Math_fround($305 * $305);
  $366 = Math_fround($306 * $306);
  $367 = Math_fround($307 * $307);
  $368 = Math_fround($308 * $308);
  $369 = Math_fround($365 + $361);
  $370 = Math_fround($366 + $362);
  $371 = Math_fround($367 + $363);
  $372 = Math_fround($368 + $364);
  $373 = (HEAPF32[tempDoublePtr>>2]=$369,HEAP32[tempDoublePtr>>2]|0);
  $374 = (HEAPF32[tempDoublePtr>>2]=$370,HEAP32[tempDoublePtr>>2]|0);
  $375 = (HEAPF32[tempDoublePtr>>2]=$371,HEAP32[tempDoublePtr>>2]|0);
  $376 = (HEAPF32[tempDoublePtr>>2]=$372,HEAP32[tempDoublePtr>>2]|0);
  $377 = $211 < Math_fround(0.0);
  $378 = $212 < Math_fround(0.0);
  $379 = $213 < Math_fround(0.0);
  $380 = $214 < Math_fround(0.0);
  $381 = $337 < Math_fround(0.0);
  $382 = $338 < Math_fround(0.0);
  $383 = $339 < Math_fround(0.0);
  $384 = $340 < Math_fround(0.0);
  $385 = (HEAPF32[tempDoublePtr>>2]=$337,HEAP32[tempDoublePtr>>2]|0);
  $386 = $381 ? 0 : $385;
  $387 = (HEAPF32[tempDoublePtr>>2]=$338,HEAP32[tempDoublePtr>>2]|0);
  $388 = $382 ? 0 : $387;
  $389 = (HEAPF32[tempDoublePtr>>2]=$339,HEAP32[tempDoublePtr>>2]|0);
  $390 = $383 ? 0 : $389;
  $391 = (HEAPF32[tempDoublePtr>>2]=$340,HEAP32[tempDoublePtr>>2]|0);
  $392 = $384 ? 0 : $391;
  $393 = $not$x$i$i$i$i ? $386 : 0;
  $394 = $not$y$i$i$i$i ? $388 : 0;
  $395 = $not$z$i$i$i$i ? $390 : 0;
  $396 = $not$w$i$i$i$i ? $392 : 0;
  $397 = $377 ? Math_fround(0.0) : $211;
  $398 = $not$x$i$i$i$i ? $397 : Math_fround(0.0);
  $399 = Math_fround(HEAPF32[478360>>2]);
  $400 = Math_fround($398 * $399);
  $401 = $378 ? Math_fround(0.0) : $212;
  $402 = $not$y$i$i$i$i ? $401 : Math_fround(0.0);
  $403 = Math_fround(HEAPF32[((478360 + 4|0))>>2]);
  $404 = Math_fround($402 * $403);
  $405 = $379 ? Math_fround(0.0) : $213;
  $406 = $not$z$i$i$i$i ? $405 : Math_fround(0.0);
  $407 = Math_fround(HEAPF32[((478360 + 8|0))>>2]);
  $408 = Math_fround($406 * $407);
  $409 = $380 ? Math_fround(0.0) : $214;
  $410 = $not$w$i$i$i$i ? $409 : Math_fround(0.0);
  $411 = Math_fround(HEAPF32[((478360 + 12|0))>>2]);
  $412 = Math_fround($410 * $411);
  $413 = (HEAP32[tempDoublePtr>>2]=$393,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $414 = Math_fround($399 * $413);
  $415 = (HEAP32[tempDoublePtr>>2]=$394,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $416 = Math_fround($403 * $415);
  $417 = (HEAP32[tempDoublePtr>>2]=$395,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $418 = Math_fround($407 * $417);
  $419 = (HEAP32[tempDoublePtr>>2]=$396,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $420 = Math_fround($411 * $419);
  $421 = Math_fround($159 * $159);
  $422 = Math_fround($160 * $160);
  $423 = Math_fround($161 * $161);
  $424 = Math_fround($162 * $162);
  $425 = Math_fround($171 * $171);
  $426 = Math_fround($172 * $172);
  $427 = Math_fround($173 * $173);
  $428 = Math_fround($174 * $174);
  $429 = Math_fround($421 + $425);
  $430 = Math_fround($422 + $426);
  $431 = Math_fround($423 + $427);
  $432 = Math_fround($424 + $428);
  $433 = Math_fround($183 * $183);
  $434 = Math_fround($184 * $184);
  $435 = Math_fround($185 * $185);
  $436 = Math_fround($186 * $186);
  $437 = Math_fround($433 + $429);
  $438 = Math_fround($434 + $430);
  $439 = Math_fround($435 + $431);
  $440 = Math_fround($436 + $432);
  $441 = Math_fround($400 * $400);
  $442 = Math_fround($404 * $404);
  $443 = Math_fround($408 * $408);
  $444 = Math_fround($412 * $412);
  $445 = Math_fround($437 - $441);
  $446 = Math_fround($438 - $442);
  $447 = Math_fround($439 - $443);
  $448 = Math_fround($440 - $444);
  $449 = Math_fround($159 * $281);
  $450 = Math_fround($160 * $282);
  $451 = Math_fround($161 * $283);
  $452 = Math_fround($162 * $284);
  $453 = Math_fround($171 * $293);
  $454 = Math_fround($172 * $294);
  $455 = Math_fround($173 * $295);
  $456 = Math_fround($174 * $296);
  $457 = Math_fround($449 + $453);
  $458 = Math_fround($450 + $454);
  $459 = Math_fround($451 + $455);
  $460 = Math_fround($452 + $456);
  $461 = Math_fround($183 * $305);
  $462 = Math_fround($184 * $306);
  $463 = Math_fround($185 * $307);
  $464 = Math_fround($186 * $308);
  $465 = Math_fround($461 + $457);
  $466 = Math_fround($462 + $458);
  $467 = Math_fround($463 + $459);
  $468 = Math_fround($464 + $460);
  $469 = Math_fround($400 * $414);
  $470 = Math_fround($404 * $416);
  $471 = Math_fround($408 * $418);
  $472 = Math_fround($412 * $420);
  $473 = Math_fround($465 - $469);
  $474 = Math_fround($466 - $470);
  $475 = Math_fround($467 - $471);
  $476 = Math_fround($468 - $472);
  $477 = Math_fround($414 * $414);
  $478 = Math_fround($416 * $416);
  $479 = Math_fround($418 * $418);
  $480 = Math_fround($420 * $420);
  $481 = Math_fround($369 - $477);
  $482 = Math_fround($370 - $478);
  $483 = Math_fround($371 - $479);
  $484 = Math_fround($372 - $480);
  $485 = Math_fround($473 * $473);
  $486 = Math_fround($474 * $474);
  $487 = Math_fround($475 * $475);
  $488 = Math_fround($476 * $476);
  $489 = Math_fround($445 * $481);
  $490 = Math_fround($446 * $482);
  $491 = Math_fround($447 * $483);
  $492 = Math_fround($448 * $484);
  $493 = Math_fround($485 - $489);
  $494 = Math_fround($486 - $490);
  $495 = Math_fround($487 - $491);
  $496 = Math_fround($488 - $492);
  $497 = (Math_fround(Math_sqrt((Math_fround($493)))));
  $498 = (Math_fround(Math_sqrt((Math_fround($494)))));
  $499 = (Math_fround(Math_sqrt((Math_fround($495)))));
  $500 = (Math_fround(Math_sqrt((Math_fround($496)))));
  $501 = Math_fround($473 - $445);
  $502 = Math_fround($474 - $446);
  $503 = Math_fround($475 - $447);
  $504 = Math_fround($476 - $448);
  $505 = Math_fround($473 - $481);
  $506 = Math_fround($474 - $482);
  $507 = Math_fround($475 - $483);
  $508 = Math_fround($476 - $484);
  $509 = Math_fround($505 + $501);
  $510 = Math_fround($506 + $502);
  $511 = Math_fround($507 + $503);
  $512 = Math_fround($508 + $504);
  $513 = Math_fround(Math_fround(1.0) / $509);
  $514 = Math_fround(Math_fround(1.0) / $510);
  $515 = Math_fround(Math_fround(1.0) / $511);
  $516 = Math_fround(Math_fround(1.0) / $512);
  $517 = Math_fround($497 + $501);
  $518 = Math_fround($498 + $502);
  $519 = Math_fround($499 + $503);
  $520 = Math_fround($500 + $504);
  $521 = $517 < Math_fround(0.0);
  $522 = $521 ? $517 : Math_fround(0.0);
  $523 = $518 < Math_fround(0.0);
  $524 = $523 ? $518 : Math_fround(0.0);
  $525 = $519 < Math_fround(0.0);
  $526 = $525 ? $519 : Math_fround(0.0);
  $527 = $520 < Math_fround(0.0);
  $528 = $527 ? $520 : Math_fround(0.0);
  $529 = Math_fround($513 * $522);
  $530 = Math_fround($514 * $524);
  $531 = Math_fround($515 * $526);
  $532 = Math_fround($516 * $528);
  $not$x$i$i$i49 = $529 < Math_fround(1.0);
  $not$y$i$i$i50 = $530 < Math_fround(1.0);
  $not$z$i$i$i51 = $531 < Math_fround(1.0);
  $not$w$i$i$i52 = $532 < Math_fround(1.0);
  $not$x$i$i$i45 = $501 < $497;
  $not$y$i$i$i46 = $502 < $498;
  $not$z$i$i$i47 = $503 < $499;
  $not$w$i$i$i48 = $504 < $500;
  $533 = $not$x$i$i$i45 & $not$x$i$i$i49;
  $534 = $not$y$i$i$i46 & $not$y$i$i$i50;
  $535 = $not$z$i$i$i47 & $not$z$i$i$i51;
  $536 = $not$w$i$i$i48 & $not$w$i$i$i52;
  $not$x$i$i$i41 = $493 >= Math_fround(0.0);
  $not$y$i$i$i42 = $494 >= Math_fround(0.0);
  $not$z$i$i$i43 = $495 >= Math_fround(0.0);
  $not$w$i$i$i44 = $496 >= Math_fround(0.0);
  $537 = $not$x$i$i$i41 & $533;
  $538 = $not$y$i$i$i42 & $534;
  $539 = $not$z$i$i$i43 & $535;
  $540 = $not$w$i$i$i44 & $536;
  $541 = Math_fround(-$349);
  $542 = Math_fround(-$351);
  $543 = Math_fround(-$353);
  $544 = Math_fround(-$355);
  $not$x$i$i$i37 = $509 < $541;
  $not$y$i$i$i38 = $510 < $542;
  $not$z$i$i$i39 = $511 < $543;
  $not$w$i$i$i40 = $512 < $544;
  $545 = $not$x$i$i$i37 & $537;
  $546 = $545 << 31 >> 31;
  $547 = $not$y$i$i$i38 & $538;
  $548 = $not$z$i$i$i39 & $539;
  $549 = $548 << 31 >> 31;
  $550 = $not$w$i$i$i40 & $540;
  $551 = $550 << 31 >> 31;
  $552 = (HEAP32[tempDoublePtr>>2]=$546,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $553 = $552 == Math_fround(0.0);
  if ($553) {
   $554 = $547 << 31 >> 31;
   $555 = (HEAP32[tempDoublePtr>>2]=$554,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $556 = $555 == Math_fround(0.0);
   if ($556) {
    $557 = (HEAP32[tempDoublePtr>>2]=$549,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $558 = $557 == Math_fround(0.0);
    if ($558) {
     $559 = (HEAP32[tempDoublePtr>>2]=$551,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $560 = $559 == Math_fround(0.0);
     if ($560) {
      $1034 = $329;$1037 = $330;$1040 = $331;$1043 = $332;$1059 = $272;$1061 = $271;$1063 = $270;$1065 = $269;$1071 = $260;$1073 = $259;$1075 = $258;$1077 = $257;$1083 = $248;$1085 = $247;$1087 = $246;$1089 = $245;$957 = $393;$960 = $394;$963 = $395;$966 = $396;$969 = $373;$972 = $374;$975 = $375;$978 = $376;
     } else {
      label = 10;
     }
    } else {
     label = 10;
    }
   } else {
    label = 10;
   }
  } else {
   label = 10;
  }
  do {
   if ((label|0) == 10) {
    label = 0;
    $561 = Math_fround($128 - $238);
    $562 = Math_fround($130 - $240);
    $563 = Math_fround($132 - $242);
    $564 = Math_fround($134 - $244);
    $565 = Math_fround($136 - $250);
    $566 = Math_fround($138 - $252);
    $567 = Math_fround($140 - $254);
    $568 = Math_fround($142 - $256);
    $569 = Math_fround($144 - $262);
    $570 = Math_fround($146 - $264);
    $571 = Math_fround($148 - $266);
    $572 = Math_fround($150 - $268);
    $573 = Math_fround($561 * $529);
    $574 = Math_fround($562 * $530);
    $575 = Math_fround($563 * $531);
    $576 = Math_fround($564 * $532);
    $577 = Math_fround($128 - $573);
    $578 = Math_fround($130 - $574);
    $579 = Math_fround($132 - $575);
    $580 = Math_fround($134 - $576);
    $581 = Math_fround($565 * $529);
    $582 = Math_fround($566 * $530);
    $583 = Math_fround($567 * $531);
    $584 = Math_fround($568 * $532);
    $585 = Math_fround($136 - $581);
    $586 = Math_fround($138 - $582);
    $587 = Math_fround($140 - $583);
    $588 = Math_fround($142 - $584);
    $589 = Math_fround($569 * $529);
    $590 = Math_fround($570 * $530);
    $591 = Math_fround($571 * $531);
    $592 = Math_fround($572 * $532);
    $593 = Math_fround($144 - $589);
    $594 = Math_fround($146 - $590);
    $595 = Math_fround($148 - $591);
    $596 = Math_fround($150 - $592);
    $597 = Math_fround($224 * $234);
    $598 = Math_fround($226 * $234);
    $599 = Math_fround($228 * $234);
    $600 = (($22) + ($$sum$i30905)|0);
    $601 = Math_fround(HEAPF32[$600>>2]);
    $602 = Math_fround($120 * $601);
    $603 = Math_fround($122 * $601);
    $604 = Math_fround($124 * $601);
    $605 = Math_fround($597 - $602);
    $606 = Math_fround($598 - $603);
    $607 = Math_fround($599 - $604);
    $608 = Math_fround(Math_fround(1.0) - $529);
    $609 = Math_fround(Math_fround(1.0) - $530);
    $610 = Math_fround(Math_fround(1.0) - $531);
    $611 = Math_fround(Math_fround(1.0) - $532);
    $612 = Math_fround($608 * $605);
    $613 = Math_fround($609 * $605);
    $614 = Math_fround($610 * $605);
    $615 = Math_fround($611 * $605);
    $616 = Math_fround($597 - $612);
    $617 = Math_fround($597 - $613);
    $618 = Math_fround($597 - $614);
    $619 = Math_fround($597 - $615);
    $620 = Math_fround($608 * $606);
    $621 = Math_fround($609 * $606);
    $622 = Math_fround($610 * $606);
    $623 = Math_fround($611 * $606);
    $624 = Math_fround($598 - $620);
    $625 = Math_fround($598 - $621);
    $626 = Math_fround($598 - $622);
    $627 = Math_fround($598 - $623);
    $628 = Math_fround($608 * $607);
    $629 = Math_fround($609 * $607);
    $630 = Math_fround($610 * $607);
    $631 = Math_fround($611 * $607);
    $632 = Math_fround($599 - $628);
    $633 = Math_fround($599 - $629);
    $634 = Math_fround($599 - $630);
    $635 = Math_fround($599 - $631);
    $636 = Math_fround($126 * $608);
    $637 = Math_fround($126 * $609);
    $638 = Math_fround($126 * $610);
    $639 = Math_fround($126 * $611);
    $640 = Math_fround($230 * $529);
    $641 = Math_fround($230 * $530);
    $642 = Math_fround($230 * $531);
    $643 = Math_fround($230 * $532);
    $644 = Math_fround($640 + $636);
    $645 = Math_fround($641 + $637);
    $646 = Math_fround($642 + $638);
    $647 = Math_fround($643 + $639);
    $648 = Math_fround(HEAPF32[478360>>2]);
    $649 = Math_fround($644 * $648);
    $650 = Math_fround(HEAPF32[((478360 + 4|0))>>2]);
    $651 = Math_fround($645 * $650);
    $652 = Math_fround(HEAPF32[((478360 + 8|0))>>2]);
    $653 = Math_fround($646 * $652);
    $654 = Math_fround(HEAPF32[((478360 + 12|0))>>2]);
    $655 = Math_fround($647 * $654);
    $656 = Math_fround($616 * $616);
    $657 = Math_fround($617 * $617);
    $658 = Math_fround($618 * $618);
    $659 = Math_fround($619 * $619);
    $660 = Math_fround($624 * $624);
    $661 = Math_fround($625 * $625);
    $662 = Math_fround($626 * $626);
    $663 = Math_fround($627 * $627);
    $664 = Math_fround($656 + $660);
    $665 = Math_fround($657 + $661);
    $666 = Math_fround($658 + $662);
    $667 = Math_fround($659 + $663);
    $668 = Math_fround($632 * $632);
    $669 = Math_fround($633 * $633);
    $670 = Math_fround($634 * $634);
    $671 = Math_fround($635 * $635);
    $672 = Math_fround($668 + $664);
    $673 = Math_fround($669 + $665);
    $674 = Math_fround($670 + $666);
    $675 = Math_fround($671 + $667);
    $676 = (Math_fround(Math_sqrt((Math_fround($672)))));
    $677 = (Math_fround(Math_sqrt((Math_fround($673)))));
    $678 = (Math_fround(Math_sqrt((Math_fround($674)))));
    $679 = (Math_fround(Math_sqrt((Math_fround($675)))));
    $680 = Math_fround(Math_fround(1.0) / $676);
    $681 = Math_fround(Math_fround(1.0) / $677);
    $682 = Math_fround(Math_fround(1.0) / $678);
    $683 = Math_fround(Math_fround(1.0) / $679);
    $684 = Math_fround($577 * $616);
    $685 = Math_fround($578 * $617);
    $686 = Math_fround($579 * $618);
    $687 = Math_fround($580 * $619);
    $688 = Math_fround($585 * $624);
    $689 = Math_fround($586 * $625);
    $690 = Math_fround($587 * $626);
    $691 = Math_fround($588 * $627);
    $692 = Math_fround($684 + $688);
    $693 = Math_fround($685 + $689);
    $694 = Math_fround($686 + $690);
    $695 = Math_fround($687 + $691);
    $696 = Math_fround($593 * $632);
    $697 = Math_fround($594 * $633);
    $698 = Math_fround($595 * $634);
    $699 = Math_fround($596 * $635);
    $700 = Math_fround($696 + $692);
    $701 = Math_fround($697 + $693);
    $702 = Math_fround($698 + $694);
    $703 = Math_fround($699 + $695);
    $704 = Math_fround($700 * $680);
    $705 = Math_fround($701 * $681);
    $706 = Math_fround($702 * $682);
    $707 = Math_fround($703 * $683);
    $708 = Math_fround($577 * $577);
    $709 = Math_fround($578 * $578);
    $710 = Math_fround($579 * $579);
    $711 = Math_fround($580 * $580);
    $712 = Math_fround($585 * $585);
    $713 = Math_fround($586 * $586);
    $714 = Math_fround($587 * $587);
    $715 = Math_fround($588 * $588);
    $716 = Math_fround($708 + $712);
    $717 = Math_fround($709 + $713);
    $718 = Math_fround($710 + $714);
    $719 = Math_fround($711 + $715);
    $720 = Math_fround($593 * $593);
    $721 = Math_fround($594 * $594);
    $722 = Math_fround($595 * $595);
    $723 = Math_fround($596 * $596);
    $724 = Math_fround($720 + $716);
    $725 = Math_fround($721 + $717);
    $726 = Math_fround($722 + $718);
    $727 = Math_fround($723 + $719);
    $728 = Math_fround($704 * $704);
    $729 = Math_fround($705 * $705);
    $730 = Math_fround($706 * $706);
    $731 = Math_fround($707 * $707);
    $732 = Math_fround($724 - $728);
    $733 = Math_fround($725 - $729);
    $734 = Math_fround($726 - $730);
    $735 = Math_fround($727 - $731);
    $736 = (Math_fround(Math_sqrt((Math_fround($732)))));
    $737 = (Math_fround(Math_sqrt((Math_fround($733)))));
    $738 = (Math_fround(Math_sqrt((Math_fround($734)))));
    $739 = (Math_fround(Math_sqrt((Math_fround($735)))));
    $740 = Math_fround(Math_fround(1.0) / $736);
    $741 = Math_fround(Math_fround(1.0) / $737);
    $742 = Math_fround(Math_fround(1.0) / $738);
    $743 = Math_fround(Math_fround(1.0) / $739);
    $not$x$i$i$i26 = $732 > Math_fround(0.0);
    $not$y$i$i$i27 = $733 > Math_fround(0.0);
    $not$z$i$i$i28 = $734 > Math_fround(0.0);
    $not$w$i$i$i29 = $735 > Math_fround(0.0);
    $744 = Math_fround($649 * $732);
    $745 = Math_fround($651 * $733);
    $746 = Math_fround($653 * $734);
    $747 = Math_fround($655 * $735);
    $748 = $not$x$i$i$i26 ? $740 : Math_fround(0.0);
    $749 = Math_fround($744 * $748);
    $750 = $not$y$i$i$i27 ? $741 : Math_fround(0.0);
    $751 = Math_fround($745 * $750);
    $752 = $not$z$i$i$i28 ? $742 : Math_fround(0.0);
    $753 = Math_fround($746 * $752);
    $754 = $not$w$i$i$i29 ? $743 : Math_fround(0.0);
    $755 = Math_fround($747 * $754);
    $756 = Math_fround($704 + $749);
    $757 = Math_fround($705 + $751);
    $758 = Math_fround($706 + $753);
    $759 = Math_fround($707 + $755);
    $760 = Math_fround($680 * $756);
    $761 = Math_fround($681 * $757);
    $762 = Math_fround($682 * $758);
    $763 = Math_fround($683 * $759);
    $764 = $545 ? $760 : Math_fround(0.0);
    $765 = (Math_fround(Math_abs((Math_fround($764)))));
    $766 = $547 ? $761 : Math_fround(0.0);
    $767 = (Math_fround(Math_abs((Math_fround($766)))));
    $768 = $548 ? $762 : Math_fround(0.0);
    $769 = (Math_fround(Math_abs((Math_fround($768)))));
    $770 = $550 ? $763 : Math_fround(0.0);
    $771 = (Math_fround(Math_abs((Math_fround($770)))));
    $not$x$i$i$i22 = $765 < Math_fround(1.0);
    $not$y$i$i$i23 = $767 < Math_fround(1.0);
    $not$z$i$i$i24 = $769 < Math_fround(1.0);
    $not$w$i$i$i25 = $771 < Math_fround(1.0);
    $772 = $545 & $not$x$i$i$i22;
    $773 = $772 << 31 >> 31;
    $774 = $547 & $not$y$i$i$i23;
    $775 = $548 & $not$z$i$i$i24;
    $776 = $775 << 31 >> 31;
    $777 = $550 & $not$w$i$i$i25;
    $778 = $777 << 31 >> 31;
    $779 = (HEAP32[tempDoublePtr>>2]=$773,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $780 = $779 == Math_fround(0.0);
    if ($780) {
     $781 = $774 << 31 >> 31;
     $782 = (HEAP32[tempDoublePtr>>2]=$781,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $783 = $782 == Math_fround(0.0);
     if ($783) {
      $784 = (HEAP32[tempDoublePtr>>2]=$776,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $785 = $784 == Math_fround(0.0);
      if ($785) {
       $786 = (HEAP32[tempDoublePtr>>2]=$778,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $787 = $786 == Math_fround(0.0);
       if ($787) {
        $1034 = $329;$1037 = $330;$1040 = $331;$1043 = $332;$1059 = $272;$1061 = $271;$1063 = $270;$1065 = $269;$1071 = $260;$1073 = $259;$1075 = $258;$1077 = $257;$1083 = $248;$1085 = $247;$1087 = $246;$1089 = $245;$957 = $393;$960 = $394;$963 = $395;$966 = $396;$969 = $373;$972 = $374;$975 = $375;$978 = $376;
        break;
       }
      }
     }
    }
    $788 = Math_fround($605 * $764);
    $789 = Math_fround($605 * $766);
    $790 = Math_fround($605 * $768);
    $791 = Math_fround($605 * $770);
    $792 = Math_fround($561 + $788);
    $793 = Math_fround($562 + $789);
    $794 = Math_fround($563 + $790);
    $795 = Math_fround($564 + $791);
    $796 = Math_fround($606 * $764);
    $797 = Math_fround($606 * $766);
    $798 = Math_fround($606 * $768);
    $799 = Math_fround($606 * $770);
    $800 = Math_fround($565 + $796);
    $801 = Math_fround($566 + $797);
    $802 = Math_fround($567 + $798);
    $803 = Math_fround($568 + $799);
    $804 = Math_fround($607 * $764);
    $805 = Math_fround($607 * $766);
    $806 = Math_fround($607 * $768);
    $807 = Math_fround($607 * $770);
    $808 = Math_fround($569 + $804);
    $809 = Math_fround($570 + $805);
    $810 = Math_fround($571 + $806);
    $811 = Math_fround($572 + $807);
    $812 = $772 ? $608 : Math_fround(0.0);
    $813 = Math_fround($792 * $812);
    $814 = $774 ? $609 : Math_fround(0.0);
    $815 = Math_fround($793 * $814);
    $816 = $775 ? $610 : Math_fround(0.0);
    $817 = Math_fround($794 * $816);
    $818 = $777 ? $611 : Math_fround(0.0);
    $819 = Math_fround($795 * $818);
    $820 = Math_fround($238 + $813);
    $821 = Math_fround($240 + $815);
    $822 = Math_fround($242 + $817);
    $823 = Math_fround($244 + $819);
    $824 = (HEAPF32[tempDoublePtr>>2]=$820,HEAP32[tempDoublePtr>>2]|0);
    $825 = (HEAPF32[tempDoublePtr>>2]=$821,HEAP32[tempDoublePtr>>2]|0);
    $826 = (HEAPF32[tempDoublePtr>>2]=$822,HEAP32[tempDoublePtr>>2]|0);
    $827 = (HEAPF32[tempDoublePtr>>2]=$823,HEAP32[tempDoublePtr>>2]|0);
    $828 = Math_fround($800 * $812);
    $829 = Math_fround($801 * $814);
    $830 = Math_fround($802 * $816);
    $831 = Math_fround($803 * $818);
    $832 = Math_fround($250 + $828);
    $833 = Math_fround($252 + $829);
    $834 = Math_fround($254 + $830);
    $835 = Math_fround($256 + $831);
    $836 = (HEAPF32[tempDoublePtr>>2]=$832,HEAP32[tempDoublePtr>>2]|0);
    $837 = (HEAPF32[tempDoublePtr>>2]=$833,HEAP32[tempDoublePtr>>2]|0);
    $838 = (HEAPF32[tempDoublePtr>>2]=$834,HEAP32[tempDoublePtr>>2]|0);
    $839 = (HEAPF32[tempDoublePtr>>2]=$835,HEAP32[tempDoublePtr>>2]|0);
    $840 = Math_fround($808 * $812);
    $841 = Math_fround($809 * $814);
    $842 = Math_fround($810 * $816);
    $843 = Math_fround($811 * $818);
    $844 = Math_fround($262 + $840);
    $845 = Math_fround($264 + $841);
    $846 = Math_fround($266 + $842);
    $847 = Math_fround($268 + $843);
    $848 = (HEAPF32[tempDoublePtr>>2]=$844,HEAP32[tempDoublePtr>>2]|0);
    $849 = (HEAPF32[tempDoublePtr>>2]=$845,HEAP32[tempDoublePtr>>2]|0);
    $850 = (HEAPF32[tempDoublePtr>>2]=$846,HEAP32[tempDoublePtr>>2]|0);
    $851 = (HEAPF32[tempDoublePtr>>2]=$847,HEAP32[tempDoublePtr>>2]|0);
    $852 = Math_fround($224 * $820);
    $853 = Math_fround($224 * $821);
    $854 = Math_fround($224 * $822);
    $855 = Math_fround($224 * $823);
    $856 = Math_fround($226 * $832);
    $857 = Math_fround($226 * $833);
    $858 = Math_fround($226 * $834);
    $859 = Math_fround($226 * $835);
    $860 = Math_fround($852 + $856);
    $861 = Math_fround($853 + $857);
    $862 = Math_fround($854 + $858);
    $863 = Math_fround($855 + $859);
    $864 = Math_fround($228 * $844);
    $865 = Math_fround($228 * $845);
    $866 = Math_fround($228 * $846);
    $867 = Math_fround($228 * $847);
    $868 = Math_fround($864 + $860);
    $869 = Math_fround($865 + $861);
    $870 = Math_fround($866 + $862);
    $871 = Math_fround($867 + $863);
    $872 = (HEAPF32[tempDoublePtr>>2]=$868,HEAP32[tempDoublePtr>>2]|0);
    $873 = (HEAPF32[tempDoublePtr>>2]=$869,HEAP32[tempDoublePtr>>2]|0);
    $874 = (HEAPF32[tempDoublePtr>>2]=$870,HEAP32[tempDoublePtr>>2]|0);
    $875 = (HEAPF32[tempDoublePtr>>2]=$871,HEAP32[tempDoublePtr>>2]|0);
    $876 = Math_fround($230 * $868);
    $877 = Math_fround($230 * $869);
    $878 = Math_fround($230 * $870);
    $879 = Math_fround($230 * $871);
    $880 = Math_fround($222 + $876);
    $881 = Math_fround($222 + $877);
    $882 = Math_fround($222 + $878);
    $883 = Math_fround($222 + $879);
    $884 = $880 < Math_fround(0.0);
    $885 = $881 < Math_fround(0.0);
    $886 = $882 < Math_fround(0.0);
    $887 = $883 < Math_fround(0.0);
    $888 = (HEAPF32[tempDoublePtr>>2]=$880,HEAP32[tempDoublePtr>>2]|0);
    $889 = $884 ? 0 : $888;
    $890 = (HEAPF32[tempDoublePtr>>2]=$881,HEAP32[tempDoublePtr>>2]|0);
    $891 = $885 ? 0 : $890;
    $892 = (HEAPF32[tempDoublePtr>>2]=$882,HEAP32[tempDoublePtr>>2]|0);
    $893 = $886 ? 0 : $892;
    $894 = (HEAPF32[tempDoublePtr>>2]=$883,HEAP32[tempDoublePtr>>2]|0);
    $895 = $887 ? 0 : $894;
    $896 = $not$x$i$i$i$i ? $889 : 0;
    $897 = $not$y$i$i$i$i ? $891 : 0;
    $898 = $not$z$i$i$i$i ? $893 : 0;
    $899 = $not$w$i$i$i$i ? $895 : 0;
    $900 = Math_fround($820 * $820);
    $901 = Math_fround($821 * $821);
    $902 = Math_fround($822 * $822);
    $903 = Math_fround($823 * $823);
    $904 = Math_fround($832 * $832);
    $905 = Math_fround($833 * $833);
    $906 = Math_fround($834 * $834);
    $907 = Math_fround($835 * $835);
    $908 = Math_fround($900 + $904);
    $909 = Math_fround($901 + $905);
    $910 = Math_fround($902 + $906);
    $911 = Math_fround($903 + $907);
    $912 = Math_fround($844 * $844);
    $913 = Math_fround($845 * $845);
    $914 = Math_fround($846 * $846);
    $915 = Math_fround($847 * $847);
    $916 = Math_fround($912 + $908);
    $917 = Math_fround($913 + $909);
    $918 = Math_fround($914 + $910);
    $919 = Math_fround($915 + $911);
    $920 = Math_fround($868 * $868);
    $921 = Math_fround($869 * $869);
    $922 = Math_fround($870 * $870);
    $923 = Math_fround($871 * $871);
    $924 = Math_fround($916 - $920);
    $925 = Math_fround($917 - $921);
    $926 = Math_fround($918 - $922);
    $927 = Math_fround($919 - $923);
    $928 = (HEAPF32[tempDoublePtr>>2]=$924,HEAP32[tempDoublePtr>>2]|0);
    $929 = (HEAPF32[tempDoublePtr>>2]=$925,HEAP32[tempDoublePtr>>2]|0);
    $930 = (HEAPF32[tempDoublePtr>>2]=$926,HEAP32[tempDoublePtr>>2]|0);
    $931 = (HEAPF32[tempDoublePtr>>2]=$927,HEAP32[tempDoublePtr>>2]|0);
    $932 = Math_fround($216 + $820);
    $933 = Math_fround($216 + $821);
    $934 = Math_fround($216 + $822);
    $935 = Math_fround($216 + $823);
    $936 = (HEAPF32[tempDoublePtr>>2]=$932,HEAP32[tempDoublePtr>>2]|0);
    $937 = (HEAPF32[tempDoublePtr>>2]=$933,HEAP32[tempDoublePtr>>2]|0);
    $938 = (HEAPF32[tempDoublePtr>>2]=$934,HEAP32[tempDoublePtr>>2]|0);
    $939 = (HEAPF32[tempDoublePtr>>2]=$935,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$curPos>>2] = $936;
    HEAP32[$35>>2] = $937;
    HEAP32[$36>>2] = $938;
    HEAP32[$37>>2] = $939;
    $940 = Math_fround($218 + $832);
    $941 = Math_fround($218 + $833);
    $942 = Math_fround($218 + $834);
    $943 = Math_fround($218 + $835);
    $944 = (HEAPF32[tempDoublePtr>>2]=$940,HEAP32[tempDoublePtr>>2]|0);
    $945 = (HEAPF32[tempDoublePtr>>2]=$941,HEAP32[tempDoublePtr>>2]|0);
    $946 = (HEAPF32[tempDoublePtr>>2]=$942,HEAP32[tempDoublePtr>>2]|0);
    $947 = (HEAPF32[tempDoublePtr>>2]=$943,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$38>>2] = $944;
    HEAP32[$39>>2] = $945;
    HEAP32[$40>>2] = $946;
    HEAP32[$41>>2] = $947;
    $948 = Math_fround($220 + $844);
    $949 = Math_fround($220 + $845);
    $950 = Math_fround($220 + $846);
    $951 = Math_fround($220 + $847);
    $952 = (HEAPF32[tempDoublePtr>>2]=$948,HEAP32[tempDoublePtr>>2]|0);
    $953 = (HEAPF32[tempDoublePtr>>2]=$949,HEAP32[tempDoublePtr>>2]|0);
    $954 = (HEAPF32[tempDoublePtr>>2]=$950,HEAP32[tempDoublePtr>>2]|0);
    $955 = (HEAPF32[tempDoublePtr>>2]=$951,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$42>>2] = $952;
    HEAP32[$43>>2] = $953;
    HEAP32[$44>>2] = $954;
    HEAP32[$45>>2] = $955;
    $1034 = $872;$1037 = $873;$1040 = $874;$1043 = $875;$1059 = $851;$1061 = $850;$1063 = $849;$1065 = $848;$1071 = $839;$1073 = $838;$1075 = $837;$1077 = $836;$1083 = $827;$1085 = $826;$1087 = $825;$1089 = $824;$957 = $896;$960 = $897;$963 = $898;$966 = $899;$969 = $928;$972 = $929;$975 = $930;$978 = $931;
   }
  } while(0);
  $956 = (HEAP32[tempDoublePtr>>2]=$957,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $958 = Math_fround($956 * $956);
  $959 = (HEAP32[tempDoublePtr>>2]=$960,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $961 = Math_fround($959 * $959);
  $962 = (HEAP32[tempDoublePtr>>2]=$963,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $964 = Math_fround($962 * $962);
  $965 = (HEAP32[tempDoublePtr>>2]=$966,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $967 = Math_fround($965 * $965);
  $968 = (HEAP32[tempDoublePtr>>2]=$969,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $970 = $958 > $968;
  $971 = (HEAP32[tempDoublePtr>>2]=$972,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $973 = $961 > $971;
  $974 = (HEAP32[tempDoublePtr>>2]=$975,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $976 = $964 > $974;
  $977 = (HEAP32[tempDoublePtr>>2]=$978,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $979 = $967 > $977;
  $not$x$i$i$i18 = $970 ^ 1;
  $980 = $not$x$i$i$i18 << 31 >> 31;
  $not$y$i$i$i19 = $973 ^ 1;
  $981 = $not$y$i$i$i19 << 31 >> 31;
  $not$z$i$i$i20 = $976 ^ 1;
  $982 = $not$z$i$i$i20 << 31 >> 31;
  $not$w$i$i$i21 = $979 ^ 1;
  $983 = $not$w$i$i$i21 << 31 >> 31;
  $brmerge$i = $970 | $973;
  $brmerge1$i = $brmerge$i | $976;
  $$$i = $brmerge1$i | $979;
  $984 = (HEAPF32[tempDoublePtr>>2]=$236,HEAP32[tempDoublePtr>>2]|0);
  $985 = $545 ? 0 : $980;
  $986 = $985 & $984;
  $987 = $547 ? 0 : $981;
  $988 = $987 & $984;
  $989 = $548 ? 0 : $982;
  $990 = $989 & $984;
  $991 = $550 ? 0 : $983;
  $992 = $991 & $984;
  $993 = HEAP32[$46>>2]|0;
  $994 = $986 ^ -1;
  $995 = $993 & $994;
  $996 = HEAP32[$47>>2]|0;
  $997 = $988 ^ -1;
  $998 = $996 & $997;
  $999 = HEAP32[$48>>2]|0;
  $1000 = $990 ^ -1;
  $1001 = $999 & $1000;
  $1002 = HEAP32[$49>>2]|0;
  $1003 = $992 ^ -1;
  $1004 = $1002 & $1003;
  HEAP32[$46>>2] = $995;
  HEAP32[$47>>2] = $998;
  HEAP32[$48>>2] = $1001;
  HEAP32[$49>>2] = $1004;
  if ($$$i) {
   $1005 = (Math_fround(Math_sqrt((Math_fround($968)))));
   $1006 = (Math_fround(Math_sqrt((Math_fround($971)))));
   $1007 = (Math_fround(Math_sqrt((Math_fround($974)))));
   $1008 = (Math_fround(Math_sqrt((Math_fround($977)))));
   $1009 = Math_fround(Math_fround(1.0) / $1005);
   $1010 = Math_fround(Math_fround(1.0) / $1006);
   $1011 = Math_fround(Math_fround(1.0) / $1007);
   $1012 = Math_fround(Math_fround(1.0) / $1008);
   $1013 = HEAP32[478232>>2]|0;
   $1014 = HEAP32[((478232 + 4|0))>>2]|0;
   $1015 = HEAP32[((478232 + 8|0))>>2]|0;
   $1016 = HEAP32[((478232 + 12|0))>>2]|0;
   $1017 = (HEAP32[tempDoublePtr>>2]=$1013,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1018 = (HEAP32[tempDoublePtr>>2]=$1014,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1019 = (HEAP32[tempDoublePtr>>2]=$1015,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1020 = (HEAP32[tempDoublePtr>>2]=$1016,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i14 = $968 > $1017;
   $not$y$i$i$i15 = $971 > $1018;
   $not$z$i$i$i16 = $974 > $1019;
   $not$w$i$i$i17 = $977 > $1020;
   $1021 = Math_fround($230 * $968);
   $1022 = Math_fround($230 * $971);
   $1023 = Math_fround($230 * $974);
   $1024 = Math_fround($230 * $977);
   $1025 = $not$x$i$i$i14 ? $1009 : Math_fround(0.0);
   $1026 = Math_fround($1021 * $1025);
   $1027 = $not$y$i$i$i15 ? $1010 : Math_fround(0.0);
   $1028 = Math_fround($1022 * $1027);
   $1029 = $not$z$i$i$i16 ? $1011 : Math_fround(0.0);
   $1030 = Math_fround($1023 * $1029);
   $1031 = $not$w$i$i$i17 ? $1012 : Math_fround(0.0);
   $1032 = Math_fround($1024 * $1031);
   $1033 = (HEAP32[tempDoublePtr>>2]=$1034,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1035 = Math_fround($1033 + $1026);
   $1036 = (HEAP32[tempDoublePtr>>2]=$1037,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1038 = Math_fround($1036 + $1028);
   $1039 = (HEAP32[tempDoublePtr>>2]=$1040,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1041 = Math_fround($1039 + $1030);
   $1042 = (HEAP32[tempDoublePtr>>2]=$1043,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1044 = Math_fround($1042 + $1032);
   $1045 = Math_fround(-$234);
   $not$x$i$i$i10 = $1035 < $1045;
   $not$y$i$i$i11 = $1038 < $1045;
   $not$z$i$i$i12 = $1041 < $1045;
   $not$w$i$i$i13 = $1044 < $1045;
   $not$x$i$i$i = $1035 > $234;
   $not$y$i$i$i = $1038 > $234;
   $not$z$i$i$i = $1041 > $234;
   $not$w$i$i$i = $1044 > $234;
   $1046 = $not$x$i$i$i | $not$x$i$i$i10;
   $1047 = $not$y$i$i$i | $not$y$i$i$i11;
   $1048 = $not$z$i$i$i | $not$z$i$i$i12;
   $1049 = $not$w$i$i$i | $not$w$i$i$i13;
   $$demorgan920 = $1046 | $not$x$i$i$i18;
   $$demorgan921922 = $1047 | $not$y$i$i$i19;
   $$demorgan923924 = $1048 | $not$z$i$i$i20;
   $$demorgan925926 = $1049 | $not$w$i$i$i21;
   $$demorgan942943 = $$demorgan921922 & $$demorgan920;
   $$demorgan944 = $$demorgan942943 & $$demorgan923924;
   $$demorgan945946 = $$demorgan944 & $$demorgan925926;
   if (!($$demorgan945946)) {
    $1050 = Math_fround($965 * $1031);
    $1051 = Math_fround($962 * $1029);
    $1052 = Math_fround($959 * $1027);
    $1053 = Math_fround($956 * $1025);
    $1054 = Math_fround($232 * $1050);
    $1055 = Math_fround($232 * $1051);
    $1056 = Math_fround($232 * $1052);
    $1057 = Math_fround($232 * $1053);
    $1058 = (HEAP32[tempDoublePtr>>2]=$1059,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1060 = (HEAP32[tempDoublePtr>>2]=$1061,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1062 = (HEAP32[tempDoublePtr>>2]=$1063,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1064 = (HEAP32[tempDoublePtr>>2]=$1065,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1066 = Math_fround($228 * $1044);
    $1067 = Math_fround($228 * $1041);
    $1068 = Math_fround($228 * $1038);
    $1069 = Math_fround($228 * $1035);
    $1070 = (HEAP32[tempDoublePtr>>2]=$1071,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1072 = (HEAP32[tempDoublePtr>>2]=$1073,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1074 = (HEAP32[tempDoublePtr>>2]=$1075,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1076 = (HEAP32[tempDoublePtr>>2]=$1077,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1078 = Math_fround($226 * $1044);
    $1079 = Math_fround($226 * $1041);
    $1080 = Math_fround($226 * $1038);
    $1081 = Math_fround($226 * $1035);
    $1082 = (HEAP32[tempDoublePtr>>2]=$1083,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1084 = (HEAP32[tempDoublePtr>>2]=$1085,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1086 = (HEAP32[tempDoublePtr>>2]=$1087,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1088 = (HEAP32[tempDoublePtr>>2]=$1089,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1090 = Math_fround($224 * $1044);
    $1091 = Math_fround($224 * $1041);
    $1092 = Math_fround($224 * $1038);
    $1093 = Math_fround($224 * $1035);
    $1094 = Math_fround($1054 - $232);
    $1095 = Math_fround($1055 - $232);
    $1096 = Math_fround($1056 - $232);
    $1097 = Math_fround($1057 - $232);
    $1098 = Math_fround($1058 - $1066);
    $1099 = Math_fround($1060 - $1067);
    $1100 = Math_fround($1062 - $1068);
    $1101 = Math_fround($1064 - $1069);
    $1102 = Math_fround($1070 - $1078);
    $1103 = Math_fround($1072 - $1079);
    $1104 = Math_fround($1074 - $1080);
    $1105 = Math_fround($1076 - $1081);
    $1106 = Math_fround($1082 - $1090);
    $1107 = Math_fround($1084 - $1091);
    $1108 = Math_fround($1086 - $1092);
    $1109 = Math_fround($1088 - $1093);
    $1110 = $$demorgan920 ? Math_fround(0.0) : $1097;
    $1111 = Math_fround($1109 * $1110);
    $1112 = $$demorgan921922 ? Math_fround(0.0) : $1096;
    $1113 = Math_fround($1108 * $1112);
    $1114 = $$demorgan923924 ? Math_fround(0.0) : $1095;
    $1115 = Math_fround($1107 * $1114);
    $1116 = $$demorgan925926 ? Math_fround(0.0) : $1094;
    $1117 = Math_fround($1106 * $1116);
    $1118 = Math_fround(HEAPF32[$accum>>2]);
    $1119 = Math_fround($1111 + $1118);
    $1120 = Math_fround(HEAPF32[$50>>2]);
    $1121 = Math_fround($1113 + $1120);
    $1122 = Math_fround(HEAPF32[$51>>2]);
    $1123 = Math_fround($1115 + $1122);
    $1124 = Math_fround(HEAPF32[$52>>2]);
    $1125 = Math_fround($1117 + $1124);
    $1126 = (HEAPF32[tempDoublePtr>>2]=$1119,HEAP32[tempDoublePtr>>2]|0);
    $1127 = (HEAPF32[tempDoublePtr>>2]=$1121,HEAP32[tempDoublePtr>>2]|0);
    $1128 = (HEAPF32[tempDoublePtr>>2]=$1123,HEAP32[tempDoublePtr>>2]|0);
    $1129 = (HEAPF32[tempDoublePtr>>2]=$1125,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$accum>>2] = $1126;
    HEAP32[$50>>2] = $1127;
    HEAP32[$51>>2] = $1128;
    HEAP32[$52>>2] = $1129;
    $1130 = Math_fround($1105 * $1110);
    $1131 = Math_fround($1104 * $1112);
    $1132 = Math_fround($1103 * $1114);
    $1133 = Math_fround($1102 * $1116);
    $1134 = Math_fround(HEAPF32[$53>>2]);
    $1135 = Math_fround($1130 + $1134);
    $1136 = Math_fround(HEAPF32[$54>>2]);
    $1137 = Math_fround($1131 + $1136);
    $1138 = Math_fround(HEAPF32[$55>>2]);
    $1139 = Math_fround($1132 + $1138);
    $1140 = Math_fround(HEAPF32[$56>>2]);
    $1141 = Math_fround($1133 + $1140);
    $1142 = (HEAPF32[tempDoublePtr>>2]=$1135,HEAP32[tempDoublePtr>>2]|0);
    $1143 = (HEAPF32[tempDoublePtr>>2]=$1137,HEAP32[tempDoublePtr>>2]|0);
    $1144 = (HEAPF32[tempDoublePtr>>2]=$1139,HEAP32[tempDoublePtr>>2]|0);
    $1145 = (HEAPF32[tempDoublePtr>>2]=$1141,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$53>>2] = $1142;
    HEAP32[$54>>2] = $1143;
    HEAP32[$55>>2] = $1144;
    HEAP32[$56>>2] = $1145;
    $1146 = Math_fround($1101 * $1110);
    $1147 = Math_fround($1100 * $1112);
    $1148 = Math_fround($1099 * $1114);
    $1149 = Math_fround($1098 * $1116);
    $1150 = Math_fround(HEAPF32[$57>>2]);
    $1151 = Math_fround($1146 + $1150);
    $1152 = Math_fround(HEAPF32[$58>>2]);
    $1153 = Math_fround($1147 + $1152);
    $1154 = Math_fround(HEAPF32[$59>>2]);
    $1155 = Math_fround($1148 + $1154);
    $1156 = Math_fround(HEAPF32[$60>>2]);
    $1157 = Math_fround($1149 + $1156);
    $1158 = (HEAPF32[tempDoublePtr>>2]=$1151,HEAP32[tempDoublePtr>>2]|0);
    $1159 = (HEAPF32[tempDoublePtr>>2]=$1153,HEAP32[tempDoublePtr>>2]|0);
    $1160 = (HEAPF32[tempDoublePtr>>2]=$1155,HEAP32[tempDoublePtr>>2]|0);
    $1161 = (HEAPF32[tempDoublePtr>>2]=$1157,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$57>>2] = $1158;
    HEAP32[$58>>2] = $1159;
    HEAP32[$59>>2] = $1160;
    HEAP32[$60>>2] = $1161;
    $1162 = Math_fround(HEAPF32[$61>>2]);
    $1163 = $$demorgan920 ? Math_fround(0.0) : Math_fround(1.0);
    $1164 = Math_fround($1163 + $1162);
    $1165 = Math_fround(HEAPF32[$62>>2]);
    $1166 = $$demorgan921922 ? Math_fround(0.0) : Math_fround(1.0);
    $1167 = Math_fround($1166 + $1165);
    $1168 = Math_fround(HEAPF32[$63>>2]);
    $1169 = $$demorgan923924 ? Math_fround(0.0) : Math_fround(1.0);
    $1170 = Math_fround($1169 + $1168);
    $1171 = Math_fround(HEAPF32[$64>>2]);
    $1172 = $$demorgan925926 ? Math_fround(0.0) : Math_fround(1.0);
    $1173 = Math_fround($1172 + $1171);
    $1174 = (HEAPF32[tempDoublePtr>>2]=$1164,HEAP32[tempDoublePtr>>2]|0);
    $1175 = (HEAPF32[tempDoublePtr>>2]=$1167,HEAP32[tempDoublePtr>>2]|0);
    $1176 = (HEAPF32[tempDoublePtr>>2]=$1170,HEAP32[tempDoublePtr>>2]|0);
    $1177 = (HEAPF32[tempDoublePtr>>2]=$1173,HEAP32[tempDoublePtr>>2]|0);
    HEAP32[$61>>2] = $1174;
    HEAP32[$62>>2] = $1175;
    HEAP32[$63>>2] = $1176;
    HEAP32[$64>>2] = $1177;
    if ($8) {
     $1178 = HEAP32[$4>>2]|0;
     $1179 = (($1178) + 156|0);
     $1180 = HEAP32[$1179>>2]|0;
     $1181 = (($1180) + ($result$0$i<<3)|0);
     $1182 = HEAP32[$1181>>2]|0;
     $1183 = ((($1180) + ($result$0$i<<3)|0) + 4|0);
     $1184 = HEAP32[$1183>>2]|0;
     $1185 = HEAP32[$65>>2]|0;
     $1186 = HEAP32[$66>>2]|0;
     $1187 = $1182 << 4;
     $1188 = (($1185) + ($1182<<4)|0);
     $1189 = Math_fround(HEAPF32[$1188>>2]);
     $$sum$i7927 = $1187 | 4;
     $1190 = (($1185) + ($$sum$i7927)|0);
     $1191 = Math_fround(HEAPF32[$1190>>2]);
     $$sum1$i8928 = $1187 | 8;
     $1192 = (($1185) + ($$sum1$i8928)|0);
     $1193 = Math_fround(HEAPF32[$1192>>2]);
     $1194 = (($1186) + ($1182<<4)|0);
     $1195 = Math_fround(HEAPF32[$1194>>2]);
     $1196 = (($1186) + ($$sum$i7927)|0);
     $1197 = Math_fround(HEAPF32[$1196>>2]);
     $1198 = (($1186) + ($$sum1$i8928)|0);
     $1199 = Math_fround(HEAPF32[$1198>>2]);
     $1200 = $1184 << 4;
     $1201 = (($1185) + ($1184<<4)|0);
     $1202 = Math_fround(HEAPF32[$1201>>2]);
     $$sum$i1933 = $1200 | 4;
     $1203 = (($1185) + ($$sum$i1933)|0);
     $1204 = Math_fround(HEAPF32[$1203>>2]);
     $$sum1$i2934 = $1200 | 8;
     $1205 = (($1185) + ($$sum1$i2934)|0);
     $1206 = Math_fround(HEAPF32[$1205>>2]);
     $1207 = (($1186) + ($1184<<4)|0);
     $1208 = Math_fround(HEAPF32[$1207>>2]);
     $1209 = (($1186) + ($$sum$i1933)|0);
     $1210 = Math_fround(HEAPF32[$1209>>2]);
     $1211 = (($1186) + ($$sum1$i2934)|0);
     $1212 = Math_fround(HEAPF32[$1211>>2]);
     $1213 = Math_fround($1195 - $1189);
     $1214 = Math_fround($1197 - $1191);
     $1215 = Math_fround($1199 - $1193);
     $1216 = Math_fround($1208 - $1202);
     $1217 = Math_fround($1210 - $1204);
     $1218 = Math_fround($1212 - $1206);
     $1219 = Math_fround($1216 - $1213);
     $1220 = Math_fround($1217 - $1214);
     $1221 = Math_fround($1218 - $1215);
     $1222 = HEAP32[478280>>2]|0;
     $1223 = HEAP32[((478280 + 4|0))>>2]|0;
     $1224 = HEAP32[((478280 + 8|0))>>2]|0;
     $1225 = HEAP32[((478280 + 12|0))>>2]|0;
     $1226 = (HEAP32[tempDoublePtr>>2]=$1222,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1227 = Math_fround($1033 * $1226);
     $1228 = (HEAP32[tempDoublePtr>>2]=$1223,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1229 = Math_fround($1036 * $1228);
     $1230 = (HEAP32[tempDoublePtr>>2]=$1224,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1231 = Math_fround($1039 * $1230);
     $1232 = (HEAP32[tempDoublePtr>>2]=$1225,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1233 = Math_fround($1042 * $1232);
     $1234 = Math_fround($1226 + $1227);
     $1235 = Math_fround($1228 + $1229);
     $1236 = Math_fround($1230 + $1231);
     $1237 = Math_fround($1232 + $1233);
     $1238 = Math_fround($1219 * $1234);
     $1239 = Math_fround($1219 * $1235);
     $1240 = Math_fround($1219 * $1236);
     $1241 = Math_fround($1219 * $1237);
     $1242 = Math_fround($1213 + $1238);
     $1243 = Math_fround($1213 + $1239);
     $1244 = Math_fround($1213 + $1240);
     $1245 = Math_fround($1213 + $1241);
     $1246 = Math_fround($1220 * $1234);
     $1247 = Math_fround($1220 * $1235);
     $1248 = Math_fround($1220 * $1236);
     $1249 = Math_fround($1220 * $1237);
     $1250 = Math_fround($1214 + $1246);
     $1251 = Math_fround($1214 + $1247);
     $1252 = Math_fround($1214 + $1248);
     $1253 = Math_fround($1214 + $1249);
     $1254 = Math_fround($1221 * $1234);
     $1255 = Math_fround($1221 * $1235);
     $1256 = Math_fround($1221 * $1236);
     $1257 = Math_fround($1221 * $1237);
     $1258 = Math_fround($1215 + $1254);
     $1259 = Math_fround($1215 + $1255);
     $1260 = Math_fround($1215 + $1256);
     $1261 = Math_fround($1215 + $1257);
     $1262 = Math_fround(HEAPF32[$67>>2]);
     $1263 = $$demorgan920 ? Math_fround(0.0) : $1242;
     $1264 = Math_fround($1262 + $1263);
     $1265 = Math_fround(HEAPF32[$68>>2]);
     $1266 = $$demorgan921922 ? Math_fround(0.0) : $1243;
     $1267 = Math_fround($1265 + $1266);
     $1268 = Math_fround(HEAPF32[$69>>2]);
     $1269 = $$demorgan923924 ? Math_fround(0.0) : $1244;
     $1270 = Math_fround($1268 + $1269);
     $1271 = Math_fround(HEAPF32[$70>>2]);
     $1272 = $$demorgan925926 ? Math_fround(0.0) : $1245;
     $1273 = Math_fround($1271 + $1272);
     $1274 = (HEAPF32[tempDoublePtr>>2]=$1264,HEAP32[tempDoublePtr>>2]|0);
     $1275 = (HEAPF32[tempDoublePtr>>2]=$1267,HEAP32[tempDoublePtr>>2]|0);
     $1276 = (HEAPF32[tempDoublePtr>>2]=$1270,HEAP32[tempDoublePtr>>2]|0);
     $1277 = (HEAPF32[tempDoublePtr>>2]=$1273,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$67>>2] = $1274;
     HEAP32[$68>>2] = $1275;
     HEAP32[$69>>2] = $1276;
     HEAP32[$70>>2] = $1277;
     $1278 = Math_fround(HEAPF32[$71>>2]);
     $1279 = $$demorgan920 ? Math_fround(0.0) : $1250;
     $1280 = Math_fround($1279 + $1278);
     $1281 = Math_fround(HEAPF32[$72>>2]);
     $1282 = $$demorgan921922 ? Math_fround(0.0) : $1251;
     $1283 = Math_fround($1282 + $1281);
     $1284 = Math_fround(HEAPF32[$73>>2]);
     $1285 = $$demorgan923924 ? Math_fround(0.0) : $1252;
     $1286 = Math_fround($1285 + $1284);
     $1287 = Math_fround(HEAPF32[$74>>2]);
     $1288 = $$demorgan925926 ? Math_fround(0.0) : $1253;
     $1289 = Math_fround($1288 + $1287);
     $1290 = (HEAPF32[tempDoublePtr>>2]=$1280,HEAP32[tempDoublePtr>>2]|0);
     $1291 = (HEAPF32[tempDoublePtr>>2]=$1283,HEAP32[tempDoublePtr>>2]|0);
     $1292 = (HEAPF32[tempDoublePtr>>2]=$1286,HEAP32[tempDoublePtr>>2]|0);
     $1293 = (HEAPF32[tempDoublePtr>>2]=$1289,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$71>>2] = $1290;
     HEAP32[$72>>2] = $1291;
     HEAP32[$73>>2] = $1292;
     HEAP32[$74>>2] = $1293;
     $1294 = Math_fround(HEAPF32[$75>>2]);
     $1295 = $$demorgan920 ? Math_fround(0.0) : $1258;
     $1296 = Math_fround($1295 + $1294);
     $1297 = Math_fround(HEAPF32[$76>>2]);
     $1298 = $$demorgan921922 ? Math_fround(0.0) : $1259;
     $1299 = Math_fround($1298 + $1297);
     $1300 = Math_fround(HEAPF32[$77>>2]);
     $1301 = $$demorgan923924 ? Math_fround(0.0) : $1260;
     $1302 = Math_fround($1301 + $1300);
     $1303 = Math_fround(HEAPF32[$78>>2]);
     $1304 = $$demorgan925926 ? Math_fround(0.0) : $1261;
     $1305 = Math_fround($1304 + $1303);
     $1306 = (HEAPF32[tempDoublePtr>>2]=$1296,HEAP32[tempDoublePtr>>2]|0);
     $1307 = (HEAPF32[tempDoublePtr>>2]=$1299,HEAP32[tempDoublePtr>>2]|0);
     $1308 = (HEAPF32[tempDoublePtr>>2]=$1302,HEAP32[tempDoublePtr>>2]|0);
     $1309 = (HEAPF32[tempDoublePtr>>2]=$1305,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$75>>2] = $1306;
     HEAP32[$76>>2] = $1307;
     HEAP32[$77>>2] = $1308;
     HEAP32[$78>>2] = $1309;
    }
   }
  }
  $1310 = ($86|0)==(0);
  if ($1310) {
   $$pre$phi955Z2D = $46;$$pre$phi959Z2D = $47;$$pre$phi963Z2D = $48;$$pre$phi967Z2D = $49;
   break;
  } else {
   $88 = $107;$90 = $108;$92 = $109;$94 = $110;$mask$0952 = $86;
  }
 }
 $1311 = HEAP32[$$pre$phi955Z2D>>2]|0;
 HEAP32[$agg$result>>2] = $1311;
 $1312 = HEAP32[$$pre$phi959Z2D>>2]|0;
 $1313 = (($agg$result) + 4|0);
 HEAP32[$1313>>2] = $1312;
 $1314 = HEAP32[$$pre$phi963Z2D>>2]|0;
 $1315 = (($agg$result) + 8|0);
 HEAP32[$1315>>2] = $1314;
 $1316 = HEAP32[$$pre$phi967Z2D>>2]|0;
 $1317 = (($agg$result) + 12|0);
 HEAP32[$1317>>2] = $1316;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_124calculateFrictionImpulseI8Scalar4fEEvRKT_S4_S4_S4_S4_S4_PS3_S5_S4_S4_S4_PS2_($deltaX,$deltaY,$deltaZ,$velX,$velY,$velZ,$curPos,$prevPos,$scale,$coefficient,$mask,$impulse) {
 $deltaX = $deltaX|0;
 $deltaY = $deltaY|0;
 $deltaZ = $deltaZ|0;
 $velX = $velX|0;
 $velY = $velY|0;
 $velZ = $velZ|0;
 $curPos = $curPos|0;
 $prevPos = $prevPos|0;
 $scale = $scale|0;
 $coefficient = $coefficient|0;
 $mask = $mask|0;
 $impulse = $impulse|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0;
 var $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0);
 var $350 = 0, $351 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0;
 var $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$deltaX>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($deltaX) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = (($deltaX) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $6);
 $8 = (($deltaX) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = Math_fround(HEAPF32[$deltaY>>2]);
 $12 = Math_fround($11 * $11);
 $13 = (($deltaY) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $14);
 $16 = (($deltaY) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $17);
 $19 = (($deltaY) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $20);
 $22 = Math_fround($1 + $12);
 $23 = Math_fround($4 + $15);
 $24 = Math_fround($7 + $18);
 $25 = Math_fround($10 + $21);
 $26 = Math_fround(HEAPF32[$deltaZ>>2]);
 $27 = Math_fround($26 * $26);
 $28 = (($deltaZ) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $29);
 $31 = (($deltaZ) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $32);
 $34 = (($deltaZ) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * $35);
 $37 = Math_fround($22 + $27);
 $38 = Math_fround($23 + $30);
 $39 = Math_fround($24 + $33);
 $40 = Math_fround($25 + $36);
 $41 = HEAP32[478152>>2]|0;
 $42 = HEAP32[((478152 + 4|0))>>2]|0;
 $43 = HEAP32[((478152 + 8|0))>>2]|0;
 $44 = HEAP32[((478152 + 12|0))>>2]|0;
 $45 = (HEAP32[tempDoublePtr>>2]=$41,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $46 = Math_fround($37 + $45);
 $47 = (HEAP32[tempDoublePtr>>2]=$42,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $48 = Math_fround($38 + $47);
 $49 = (HEAP32[tempDoublePtr>>2]=$43,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $50 = Math_fround($39 + $49);
 $51 = (HEAP32[tempDoublePtr>>2]=$44,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $52 = Math_fround($40 + $51);
 $53 = (Math_fround(Math_sqrt((Math_fround($46)))));
 $54 = (Math_fround(Math_sqrt((Math_fround($48)))));
 $55 = (Math_fround(Math_sqrt((Math_fround($50)))));
 $56 = (Math_fround(Math_sqrt((Math_fround($52)))));
 $57 = Math_fround(Math_fround(1.0) / $53);
 $58 = Math_fround(Math_fround(1.0) / $54);
 $59 = Math_fround(Math_fround(1.0) / $55);
 $60 = Math_fround(Math_fround(1.0) / $56);
 $61 = Math_fround($0 * $57);
 $62 = Math_fround($3 * $58);
 $63 = Math_fround($6 * $59);
 $64 = Math_fround($9 * $60);
 $65 = Math_fround($11 * $57);
 $66 = Math_fround($14 * $58);
 $67 = Math_fround($17 * $59);
 $68 = Math_fround($20 * $60);
 $69 = Math_fround($26 * $57);
 $70 = Math_fround($29 * $58);
 $71 = Math_fround($32 * $59);
 $72 = Math_fround($35 * $60);
 $73 = Math_fround(HEAPF32[$curPos>>2]);
 $74 = Math_fround(HEAPF32[$prevPos>>2]);
 $75 = Math_fround($73 - $74);
 $76 = (($curPos) + 4|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($prevPos) + 4|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($77 - $79);
 $81 = (($curPos) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($prevPos) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($82 - $84);
 $86 = (($curPos) + 12|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($prevPos) + 12|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($87 - $89);
 $91 = Math_fround(HEAPF32[$velX>>2]);
 $92 = Math_fround(HEAPF32[$scale>>2]);
 $93 = Math_fround($91 * $92);
 $94 = (($velX) + 4|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($scale) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($95 * $97);
 $99 = (($velX) + 8|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($scale) + 8|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($100 * $102);
 $104 = (($velX) + 12|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($scale) + 12|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($105 * $107);
 $109 = Math_fround($75 - $93);
 $110 = Math_fround($80 - $98);
 $111 = Math_fround($85 - $103);
 $112 = Math_fround($90 - $108);
 $113 = (($curPos) + 16|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($prevPos) + 16|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($114 - $116);
 $118 = (($curPos) + 20|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($prevPos) + 20|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround($119 - $121);
 $123 = (($curPos) + 24|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($prevPos) + 24|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($124 - $126);
 $128 = (($curPos) + 28|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = (($prevPos) + 28|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($129 - $131);
 $133 = Math_fround(HEAPF32[$velY>>2]);
 $134 = Math_fround($92 * $133);
 $135 = (($velY) + 4|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($97 * $136);
 $138 = (($velY) + 8|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($102 * $139);
 $141 = (($velY) + 12|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround($107 * $142);
 $144 = Math_fround($117 - $134);
 $145 = Math_fround($122 - $137);
 $146 = Math_fround($127 - $140);
 $147 = Math_fround($132 - $143);
 $148 = (($curPos) + 32|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($prevPos) + 32|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = Math_fround($149 - $151);
 $153 = (($curPos) + 36|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($prevPos) + 36|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = Math_fround($154 - $156);
 $158 = (($curPos) + 40|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($prevPos) + 40|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = Math_fround($159 - $161);
 $163 = (($curPos) + 44|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = (($prevPos) + 44|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = Math_fround($164 - $166);
 $168 = Math_fround(HEAPF32[$velZ>>2]);
 $169 = Math_fround($92 * $168);
 $170 = (($velZ) + 4|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = Math_fround($97 * $171);
 $173 = (($velZ) + 8|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = Math_fround($102 * $174);
 $176 = (($velZ) + 12|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = Math_fround($107 * $177);
 $179 = Math_fround($152 - $169);
 $180 = Math_fround($157 - $172);
 $181 = Math_fround($162 - $175);
 $182 = Math_fround($167 - $178);
 $183 = Math_fround($61 * $109);
 $184 = Math_fround($62 * $110);
 $185 = Math_fround($63 * $111);
 $186 = Math_fround($64 * $112);
 $187 = Math_fround($65 * $144);
 $188 = Math_fround($66 * $145);
 $189 = Math_fround($67 * $146);
 $190 = Math_fround($68 * $147);
 $191 = Math_fround($183 + $187);
 $192 = Math_fround($184 + $188);
 $193 = Math_fround($185 + $189);
 $194 = Math_fround($186 + $190);
 $195 = Math_fround($69 * $179);
 $196 = Math_fround($70 * $180);
 $197 = Math_fround($71 * $181);
 $198 = Math_fround($72 * $182);
 $199 = Math_fround($191 + $195);
 $200 = Math_fround($192 + $196);
 $201 = Math_fround($193 + $197);
 $202 = Math_fround($194 + $198);
 $203 = Math_fround($61 * $199);
 $204 = Math_fround($62 * $200);
 $205 = Math_fround($63 * $201);
 $206 = Math_fround($64 * $202);
 $207 = Math_fround($109 - $203);
 $208 = Math_fround($110 - $204);
 $209 = Math_fround($111 - $205);
 $210 = Math_fround($112 - $206);
 $211 = Math_fround($65 * $199);
 $212 = Math_fround($66 * $200);
 $213 = Math_fround($67 * $201);
 $214 = Math_fround($68 * $202);
 $215 = Math_fround($144 - $211);
 $216 = Math_fround($145 - $212);
 $217 = Math_fround($146 - $213);
 $218 = Math_fround($147 - $214);
 $219 = Math_fround($69 * $199);
 $220 = Math_fround($70 * $200);
 $221 = Math_fround($71 * $201);
 $222 = Math_fround($72 * $202);
 $223 = Math_fround($179 - $219);
 $224 = Math_fround($180 - $220);
 $225 = Math_fround($181 - $221);
 $226 = Math_fround($182 - $222);
 $227 = Math_fround($207 * $207);
 $228 = Math_fround($208 * $208);
 $229 = Math_fround($209 * $209);
 $230 = Math_fround($210 * $210);
 $231 = Math_fround($215 * $215);
 $232 = Math_fround($216 * $216);
 $233 = Math_fround($217 * $217);
 $234 = Math_fround($218 * $218);
 $235 = Math_fround($227 + $231);
 $236 = Math_fround($228 + $232);
 $237 = Math_fround($229 + $233);
 $238 = Math_fround($230 + $234);
 $239 = Math_fround($223 * $223);
 $240 = Math_fround($224 * $224);
 $241 = Math_fround($225 * $225);
 $242 = Math_fround($226 * $226);
 $243 = Math_fround($239 + $235);
 $244 = Math_fround($240 + $236);
 $245 = Math_fround($241 + $237);
 $246 = Math_fround($242 + $238);
 $247 = Math_fround($45 + $243);
 $248 = Math_fround($47 + $244);
 $249 = Math_fround($49 + $245);
 $250 = Math_fround($51 + $246);
 $251 = (Math_fround(Math_sqrt((Math_fround($247)))));
 $252 = (Math_fround(Math_sqrt((Math_fround($248)))));
 $253 = (Math_fround(Math_sqrt((Math_fround($249)))));
 $254 = (Math_fround(Math_sqrt((Math_fround($250)))));
 $255 = Math_fround(Math_fround(1.0) / $251);
 $256 = Math_fround(Math_fround(1.0) / $252);
 $257 = Math_fround(Math_fround(1.0) / $253);
 $258 = Math_fround(Math_fround(1.0) / $254);
 $259 = Math_fround(HEAPF32[$coefficient>>2]);
 $260 = (($coefficient) + 4|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = (($coefficient) + 8|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 $264 = (($coefficient) + 12|0);
 $265 = Math_fround(HEAPF32[$264>>2]);
 $266 = Math_fround($37 * $259);
 $267 = Math_fround($38 * $261);
 $268 = Math_fround($39 * $263);
 $269 = Math_fround($40 * $265);
 $270 = Math_fround($57 * $266);
 $271 = Math_fround($58 * $267);
 $272 = Math_fround($59 * $268);
 $273 = Math_fround($60 * $269);
 $274 = Math_fround($255 * $270);
 $275 = Math_fround(-$274);
 $276 = Math_fround($256 * $271);
 $277 = Math_fround(-$276);
 $278 = Math_fround($257 * $272);
 $279 = Math_fround(-$278);
 $280 = Math_fround($258 * $273);
 $281 = Math_fround(-$280);
 $282 = HEAP32[478264>>2]|0;
 $283 = HEAP32[((478264 + 4|0))>>2]|0;
 $284 = HEAP32[((478264 + 8|0))>>2]|0;
 $285 = HEAP32[((478264 + 12|0))>>2]|0;
 $286 = (HEAP32[tempDoublePtr>>2]=$282,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $287 = $286 > $275;
 $288 = $287 ? $286 : $275;
 $289 = (HEAP32[tempDoublePtr>>2]=$283,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $290 = $289 > $277;
 $291 = $290 ? $289 : $277;
 $292 = (HEAP32[tempDoublePtr>>2]=$284,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $293 = $292 > $279;
 $294 = $293 ? $292 : $279;
 $295 = (HEAP32[tempDoublePtr>>2]=$285,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $296 = $295 > $281;
 $297 = $296 ? $295 : $281;
 $298 = (HEAPF32[tempDoublePtr>>2]=$288,HEAP32[tempDoublePtr>>2]|0);
 $299 = (HEAPF32[tempDoublePtr>>2]=$291,HEAP32[tempDoublePtr>>2]|0);
 $300 = (HEAPF32[tempDoublePtr>>2]=$294,HEAP32[tempDoublePtr>>2]|0);
 $301 = (HEAPF32[tempDoublePtr>>2]=$297,HEAP32[tempDoublePtr>>2]|0);
 $302 = HEAP32[$mask>>2]|0;
 $303 = $302 & $298;
 $304 = (($mask) + 4|0);
 $305 = HEAP32[$304>>2]|0;
 $306 = $305 & $299;
 $307 = (($mask) + 8|0);
 $308 = HEAP32[$307>>2]|0;
 $309 = $308 & $300;
 $310 = (($mask) + 12|0);
 $311 = HEAP32[$310>>2]|0;
 $312 = $311 & $301;
 $313 = (HEAP32[tempDoublePtr>>2]=$303,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $314 = Math_fround($207 * $313);
 $315 = (HEAP32[tempDoublePtr>>2]=$306,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $316 = Math_fround($208 * $315);
 $317 = (HEAP32[tempDoublePtr>>2]=$309,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $318 = Math_fround($209 * $317);
 $319 = (HEAP32[tempDoublePtr>>2]=$312,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $320 = Math_fround($210 * $319);
 $321 = (HEAPF32[tempDoublePtr>>2]=$314,HEAP32[tempDoublePtr>>2]|0);
 $322 = (HEAPF32[tempDoublePtr>>2]=$316,HEAP32[tempDoublePtr>>2]|0);
 $323 = (HEAPF32[tempDoublePtr>>2]=$318,HEAP32[tempDoublePtr>>2]|0);
 $324 = (HEAPF32[tempDoublePtr>>2]=$320,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$impulse>>2] = $321;
 $325 = (($impulse) + 4|0);
 HEAP32[$325>>2] = $322;
 $326 = (($impulse) + 8|0);
 HEAP32[$326>>2] = $323;
 $327 = (($impulse) + 12|0);
 HEAP32[$327>>2] = $324;
 $328 = (($impulse) + 16|0);
 $329 = Math_fround($215 * $313);
 $330 = Math_fround($216 * $315);
 $331 = Math_fround($217 * $317);
 $332 = Math_fround($218 * $319);
 $333 = (HEAPF32[tempDoublePtr>>2]=$329,HEAP32[tempDoublePtr>>2]|0);
 $334 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
 $335 = (HEAPF32[tempDoublePtr>>2]=$331,HEAP32[tempDoublePtr>>2]|0);
 $336 = (HEAPF32[tempDoublePtr>>2]=$332,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$328>>2] = $333;
 $337 = (($impulse) + 20|0);
 HEAP32[$337>>2] = $334;
 $338 = (($impulse) + 24|0);
 HEAP32[$338>>2] = $335;
 $339 = (($impulse) + 28|0);
 HEAP32[$339>>2] = $336;
 $340 = (($impulse) + 32|0);
 $341 = Math_fround($223 * $313);
 $342 = Math_fround($224 * $315);
 $343 = Math_fround($225 * $317);
 $344 = Math_fround($226 * $319);
 $345 = (HEAPF32[tempDoublePtr>>2]=$341,HEAP32[tempDoublePtr>>2]|0);
 $346 = (HEAPF32[tempDoublePtr>>2]=$342,HEAP32[tempDoublePtr>>2]|0);
 $347 = (HEAPF32[tempDoublePtr>>2]=$343,HEAP32[tempDoublePtr>>2]|0);
 $348 = (HEAPF32[tempDoublePtr>>2]=$344,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$340>>2] = $345;
 $349 = (($impulse) + 36|0);
 HEAP32[$349>>2] = $346;
 $350 = (($impulse) + 40|0);
 HEAP32[$350>>2] = $347;
 $351 = (($impulse) + 44|0);
 HEAP32[$351>>2] = $348;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE15collideConvexesEPKS2_PS2_RNS3_18ImpulseAccumulatorE($this,$planes,$curPos,$accum) {
 $this = $this|0;
 $planes = $planes|0;
 $curPos = $curPos|0;
 $accum = $accum|0;
 var $$$$i = 0, $$$i = 0, $$0$i = 0, $$0$i2 = 0, $$lcssa = 0, $$lcssa119 = 0, $$lcssa120 = 0, $$lcssa121 = 0, $$lcssa122 = 0, $$lcssa123 = 0, $$lcssa124 = 0, $$lcssa125 = 0, $$lcssa126 = 0, $$lcssa127 = 0, $$lcssa128 = 0, $$lcssa129 = 0, $$lcssa130 = 0, $$lcssa131 = 0, $$lcssa132 = 0, $$lcssa133 = 0;
 var $$lcssa153 = 0, $$lcssa154 = 0, $$lcssa155 = 0, $$lcssa156 = 0, $$pre = Math_fround(0), $$pre185 = Math_fround(0), $$pre186 = Math_fround(0), $$pre187 = Math_fround(0), $$pre188 = Math_fround(0), $$pre189 = Math_fround(0), $$pre190 = Math_fround(0), $$pre191 = Math_fround(0), $$pre192 = Math_fround(0), $$pre193 = Math_fround(0), $$pre194 = Math_fround(0), $$pre195 = Math_fround(0), $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0);
 var $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0);
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0);
 var $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$i = 0, $cIt$0150 = 0, $dIt$0157 = 0, $not$w$i$i$i = 0, $not$w$i$i$i12 = 0, $not$x$i$i$i = 0, $not$x$i$i$i9 = 0, $not$y$i$i$i = 0;
 var $not$y$i$i$i10 = 0, $not$z$i$i$i = 0, $not$z$i$i$i11 = 0, $pIt$0158 = 0, $result$0$i = 0, $result$0$i3 = 0, $test$0 = 0, $test$0134 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 172|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($planes) + ($3<<4)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  $$lcssa153 = 0;$$lcssa154 = 0;$$lcssa155 = 0;$$lcssa156 = 0;
 } else {
  $6 = (($curPos) + 32|0);
  $7 = (($curPos) + 36|0);
  $8 = (($curPos) + 40|0);
  $9 = (($curPos) + 44|0);
  $10 = (($curPos) + 16|0);
  $11 = (($curPos) + 20|0);
  $12 = (($curPos) + 24|0);
  $13 = (($curPos) + 28|0);
  $14 = (($curPos) + 4|0);
  $15 = (($curPos) + 8|0);
  $16 = (($curPos) + 12|0);
  $$pre = Math_fround(HEAPF32[$6>>2]);
  $$pre185 = Math_fround(HEAPF32[$7>>2]);
  $$pre186 = Math_fround(HEAPF32[$8>>2]);
  $$pre187 = Math_fround(HEAPF32[$9>>2]);
  $$pre188 = Math_fround(HEAPF32[$10>>2]);
  $$pre189 = Math_fround(HEAPF32[$11>>2]);
  $$pre190 = Math_fround(HEAPF32[$12>>2]);
  $$pre191 = Math_fround(HEAPF32[$13>>2]);
  $$pre192 = Math_fround(HEAPF32[$curPos>>2]);
  $$pre193 = Math_fround(HEAPF32[$14>>2]);
  $$pre194 = Math_fround(HEAPF32[$15>>2]);
  $$pre195 = Math_fround(HEAPF32[$16>>2]);
  $56 = 1;$58 = 1;$60 = 1;$62 = 1;$64 = 0;$66 = 0;$68 = 0;$70 = 0;$dIt$0157 = $4;$pIt$0158 = $planes;
  while(1) {
   $17 = (($pIt$0158) + 12|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = (($pIt$0158) + 8|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround($20 * $$pre);
   $22 = Math_fround($20 * $$pre185);
   $23 = Math_fround($20 * $$pre186);
   $24 = Math_fround($20 * $$pre187);
   $25 = Math_fround($18 + $21);
   $26 = Math_fround($18 + $22);
   $27 = Math_fround($18 + $23);
   $28 = Math_fround($18 + $24);
   $29 = (($pIt$0158) + 4|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = Math_fround($30 * $$pre188);
   $32 = Math_fround($30 * $$pre189);
   $33 = Math_fround($30 * $$pre190);
   $34 = Math_fround($30 * $$pre191);
   $35 = Math_fround($25 + $31);
   $36 = Math_fround($26 + $32);
   $37 = Math_fround($27 + $33);
   $38 = Math_fround($28 + $34);
   $39 = Math_fround(HEAPF32[$pIt$0158>>2]);
   $40 = Math_fround($39 * $$pre192);
   $41 = Math_fround($39 * $$pre193);
   $42 = Math_fround($39 * $$pre194);
   $43 = Math_fround($39 * $$pre195);
   $44 = Math_fround($35 + $40);
   $45 = Math_fround($36 + $41);
   $46 = Math_fround($37 + $42);
   $47 = Math_fround($38 + $43);
   $48 = (HEAPF32[tempDoublePtr>>2]=$44,HEAP32[tempDoublePtr>>2]|0);
   $49 = (HEAPF32[tempDoublePtr>>2]=$45,HEAP32[tempDoublePtr>>2]|0);
   $50 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
   $51 = (HEAPF32[tempDoublePtr>>2]=$47,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$dIt$0157>>2] = $48;
   $52 = (($dIt$0157) + 4|0);
   HEAP32[$52>>2] = $49;
   $53 = (($dIt$0157) + 8|0);
   HEAP32[$53>>2] = $50;
   $54 = (($dIt$0157) + 12|0);
   HEAP32[$54>>2] = $51;
   $not$x$i$i$i9 = $44 < Math_fround(0.0);
   $not$y$i$i$i10 = $45 < Math_fround(0.0);
   $not$z$i$i$i11 = $46 < Math_fround(0.0);
   $not$w$i$i$i12 = $47 < Math_fround(0.0);
   $55 = $not$x$i$i$i9 ? $56 : 0;
   $57 = $not$y$i$i$i10 ? $58 : 0;
   $59 = $not$z$i$i$i11 ? $60 : 0;
   $61 = $not$w$i$i$i12 ? $62 : 0;
   $63 = $55 | $64;
   $65 = $57 | $66;
   $67 = $59 | $68;
   $69 = $61 | $70;
   $71 = $56 << 1;
   $72 = $58 << 1;
   $73 = $60 << 1;
   $74 = $62 << 1;
   $75 = (($pIt$0158) + 16|0);
   $76 = (($dIt$0157) + 16|0);
   $77 = ($75|0)==($4|0);
   if ($77) {
    $$lcssa153 = $69;$$lcssa154 = $67;$$lcssa155 = $65;$$lcssa156 = $63;
    break;
   } else {
    $56 = $71;$58 = $72;$60 = $73;$62 = $74;$64 = $63;$66 = $65;$68 = $67;$70 = $69;$dIt$0157 = $76;$pIt$0158 = $75;
   }
  }
 }
 $78 = $$lcssa154 | $$lcssa153;
 $79 = $78 | $$lcssa155;
 $80 = $79 | $$lcssa156;
 $81 = ($80|0)==(0);
 if ($81) {
  STACKTOP = sp;return;
 }
 $82 = HEAP32[$0>>2]|0;
 $83 = (($82) + 176|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 180|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($84) + ($86<<2)|0);
 $88 = ($86|0)==(0);
 if ($88) {
  STACKTOP = sp;return;
 }
 $89 = (($accum) + 4|0);
 $90 = (($accum) + 8|0);
 $91 = (($accum) + 12|0);
 $92 = (($accum) + 16|0);
 $93 = (($accum) + 20|0);
 $94 = (($accum) + 24|0);
 $95 = (($accum) + 28|0);
 $96 = (($accum) + 32|0);
 $97 = (($accum) + 36|0);
 $98 = (($accum) + 40|0);
 $99 = (($accum) + 44|0);
 $100 = (($accum) + 96|0);
 $101 = (($accum) + 100|0);
 $102 = (($accum) + 104|0);
 $103 = (($accum) + 108|0);
 $cIt$0150 = $84;
 while(1) {
  $104 = HEAP32[$cIt$0150>>2]|0;
  $105 = $104 & $$lcssa156;
  $106 = $104 & $$lcssa155;
  $107 = $104 & $$lcssa154;
  $108 = $104 & $$lcssa153;
  $109 = ($105|0)==($104|0);
  $110 = ($106|0)==($104|0);
  $111 = ($107|0)==($104|0);
  $112 = ($108|0)==($104|0);
  $brmerge$i = $109 | $110;
  $$$i = $111 | $112;
  $$$$i = $brmerge$i | $$$i;
  if ($$$$i) {
   $113 = (0 - ($104))|0;
   $114 = $104 & $113;
   $$0$i2 = $114;$result$0$i3 = 0;
   while(1) {
    $115 = $$0$i2 >>> 1;
    $116 = ($115|0)==(0);
    $117 = (($result$0$i3) + 1)|0;
    if ($116) {
     break;
    } else {
     $$0$i2 = $115;$result$0$i3 = $117;
    }
   }
   $118 = (($planes) + ($result$0$i3<<4)|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = ((($planes) + ($result$0$i3<<4)|0) + 4|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ((($planes) + ($result$0$i3<<4)|0) + 8|0);
   $123 = HEAP32[$122>>2]|0;
   $$sum = (($result$0$i3) + ($3))|0;
   $124 = (($planes) + ($$sum<<4)|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = ((($planes) + ($$sum<<4)|0) + 4|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ((($planes) + ($$sum<<4)|0) + 8|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ((($planes) + ($$sum<<4)|0) + 12|0);
   $131 = HEAP32[$130>>2]|0;
   $test$0134 = (($104) + -1)|0;
   $132 = $test$0134 & $104;
   $133 = ($132|0)==(0);
   if ($133) {
    $$lcssa = $119;$$lcssa119 = $119;$$lcssa120 = $119;$$lcssa121 = $119;$$lcssa122 = $121;$$lcssa123 = $121;$$lcssa124 = $121;$$lcssa125 = $121;$$lcssa126 = $123;$$lcssa127 = $123;$$lcssa128 = $123;$$lcssa129 = $123;$$lcssa130 = $131;$$lcssa131 = $129;$$lcssa132 = $127;$$lcssa133 = $125;
   } else {
    $135 = $132;$156 = $125;$159 = $127;$162 = $129;$165 = $131;$167 = $119;$169 = $119;$171 = $119;$173 = $119;$183 = $121;$185 = $121;$187 = $121;$189 = $121;$199 = $123;$201 = $123;$203 = $123;$205 = $123;
    while(1) {
     $134 = (0 - ($135))|0;
     $136 = $135 & $134;
     $$0$i = $136;$result$0$i = 0;
     while(1) {
      $137 = $$0$i >>> 1;
      $138 = ($137|0)==(0);
      $139 = (($result$0$i) + 1)|0;
      if ($138) {
       break;
      } else {
       $$0$i = $137;$result$0$i = $139;
      }
     }
     $140 = (($planes) + ($result$0$i<<4)|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ((($planes) + ($result$0$i<<4)|0) + 4|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = ((($planes) + ($result$0$i<<4)|0) + 8|0);
     $145 = HEAP32[$144>>2]|0;
     $$sum1 = (($result$0$i) + ($3))|0;
     $146 = (($planes) + ($$sum1<<4)|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = ((($planes) + ($$sum1<<4)|0) + 4|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ((($planes) + ($$sum1<<4)|0) + 8|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = ((($planes) + ($$sum1<<4)|0) + 12|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = (HEAP32[tempDoublePtr>>2]=$147,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $155 = (HEAP32[tempDoublePtr>>2]=$156,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $157 = (HEAP32[tempDoublePtr>>2]=$149,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $158 = (HEAP32[tempDoublePtr>>2]=$159,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $160 = (HEAP32[tempDoublePtr>>2]=$151,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $161 = (HEAP32[tempDoublePtr>>2]=$162,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $163 = (HEAP32[tempDoublePtr>>2]=$153,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $164 = (HEAP32[tempDoublePtr>>2]=$165,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $not$x$i$i$i = $154 > $155;
     $not$y$i$i$i = $157 > $158;
     $not$z$i$i$i = $160 > $161;
     $not$w$i$i$i = $163 > $164;
     $166 = $141 ^ $167;
     $168 = $141 ^ $169;
     $170 = $141 ^ $171;
     $172 = $141 ^ $173;
     $174 = $not$x$i$i$i ? $166 : 0;
     $175 = $not$y$i$i$i ? $168 : 0;
     $176 = $not$z$i$i$i ? $170 : 0;
     $177 = $not$w$i$i$i ? $172 : 0;
     $178 = $174 ^ $167;
     $179 = $175 ^ $169;
     $180 = $176 ^ $171;
     $181 = $177 ^ $173;
     $182 = $143 ^ $183;
     $184 = $143 ^ $185;
     $186 = $143 ^ $187;
     $188 = $143 ^ $189;
     $190 = $not$x$i$i$i ? $182 : 0;
     $191 = $not$y$i$i$i ? $184 : 0;
     $192 = $not$z$i$i$i ? $186 : 0;
     $193 = $not$w$i$i$i ? $188 : 0;
     $194 = $190 ^ $183;
     $195 = $191 ^ $185;
     $196 = $192 ^ $187;
     $197 = $193 ^ $189;
     $198 = $145 ^ $199;
     $200 = $145 ^ $201;
     $202 = $145 ^ $203;
     $204 = $145 ^ $205;
     $206 = $not$x$i$i$i ? $198 : 0;
     $207 = $not$y$i$i$i ? $200 : 0;
     $208 = $not$z$i$i$i ? $202 : 0;
     $209 = $not$w$i$i$i ? $204 : 0;
     $210 = $206 ^ $199;
     $211 = $207 ^ $201;
     $212 = $208 ^ $203;
     $213 = $209 ^ $205;
     $214 = $154 < $155;
     $215 = $214 ? $155 : $154;
     $216 = $157 < $158;
     $217 = $216 ? $158 : $157;
     $218 = $160 < $161;
     $219 = $218 ? $161 : $160;
     $220 = $163 < $164;
     $221 = $220 ? $164 : $163;
     $222 = (HEAPF32[tempDoublePtr>>2]=$215,HEAP32[tempDoublePtr>>2]|0);
     $223 = (HEAPF32[tempDoublePtr>>2]=$217,HEAP32[tempDoublePtr>>2]|0);
     $224 = (HEAPF32[tempDoublePtr>>2]=$219,HEAP32[tempDoublePtr>>2]|0);
     $225 = (HEAPF32[tempDoublePtr>>2]=$221,HEAP32[tempDoublePtr>>2]|0);
     $test$0 = (($135) + -1)|0;
     $226 = $test$0 & $135;
     $227 = ($226|0)==(0);
     if ($227) {
      $$lcssa = $181;$$lcssa119 = $180;$$lcssa120 = $179;$$lcssa121 = $178;$$lcssa122 = $197;$$lcssa123 = $196;$$lcssa124 = $195;$$lcssa125 = $194;$$lcssa126 = $213;$$lcssa127 = $212;$$lcssa128 = $211;$$lcssa129 = $210;$$lcssa130 = $225;$$lcssa131 = $224;$$lcssa132 = $223;$$lcssa133 = $222;
      break;
     } else {
      $135 = $226;$156 = $222;$159 = $223;$162 = $224;$165 = $225;$167 = $178;$169 = $179;$171 = $180;$173 = $181;$183 = $194;$185 = $195;$187 = $196;$189 = $197;$199 = $210;$201 = $211;$203 = $212;$205 = $213;
     }
    }
   }
   $228 = (HEAP32[tempDoublePtr>>2]=$$lcssa121,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $229 = (HEAP32[tempDoublePtr>>2]=$$lcssa133,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $230 = $109 ? $229 : Math_fround(0.0);
   $231 = Math_fround($228 * $230);
   $232 = (HEAP32[tempDoublePtr>>2]=$$lcssa120,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $233 = (HEAP32[tempDoublePtr>>2]=$$lcssa132,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $234 = $110 ? $233 : Math_fround(0.0);
   $235 = Math_fround($232 * $234);
   $236 = (HEAP32[tempDoublePtr>>2]=$$lcssa119,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $237 = (HEAP32[tempDoublePtr>>2]=$$lcssa131,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $238 = $111 ? $237 : Math_fround(0.0);
   $239 = Math_fround($236 * $238);
   $240 = (HEAP32[tempDoublePtr>>2]=$$lcssa,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $241 = (HEAP32[tempDoublePtr>>2]=$$lcssa130,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $242 = $112 ? $241 : Math_fround(0.0);
   $243 = Math_fround($240 * $242);
   $244 = Math_fround(HEAPF32[$accum>>2]);
   $245 = Math_fround($244 - $231);
   $246 = Math_fround(HEAPF32[$89>>2]);
   $247 = Math_fround($246 - $235);
   $248 = Math_fround(HEAPF32[$90>>2]);
   $249 = Math_fround($248 - $239);
   $250 = Math_fround(HEAPF32[$91>>2]);
   $251 = Math_fround($250 - $243);
   $252 = (HEAPF32[tempDoublePtr>>2]=$245,HEAP32[tempDoublePtr>>2]|0);
   $253 = (HEAPF32[tempDoublePtr>>2]=$247,HEAP32[tempDoublePtr>>2]|0);
   $254 = (HEAPF32[tempDoublePtr>>2]=$249,HEAP32[tempDoublePtr>>2]|0);
   $255 = (HEAPF32[tempDoublePtr>>2]=$251,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$accum>>2] = $252;
   HEAP32[$89>>2] = $253;
   HEAP32[$90>>2] = $254;
   HEAP32[$91>>2] = $255;
   $256 = (HEAP32[tempDoublePtr>>2]=$$lcssa125,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $257 = Math_fround($256 * $230);
   $258 = (HEAP32[tempDoublePtr>>2]=$$lcssa124,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $259 = Math_fround($258 * $234);
   $260 = (HEAP32[tempDoublePtr>>2]=$$lcssa123,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $261 = Math_fround($260 * $238);
   $262 = (HEAP32[tempDoublePtr>>2]=$$lcssa122,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $263 = Math_fround($262 * $242);
   $264 = Math_fround(HEAPF32[$92>>2]);
   $265 = Math_fround($264 - $257);
   $266 = Math_fround(HEAPF32[$93>>2]);
   $267 = Math_fround($266 - $259);
   $268 = Math_fround(HEAPF32[$94>>2]);
   $269 = Math_fround($268 - $261);
   $270 = Math_fround(HEAPF32[$95>>2]);
   $271 = Math_fround($270 - $263);
   $272 = (HEAPF32[tempDoublePtr>>2]=$265,HEAP32[tempDoublePtr>>2]|0);
   $273 = (HEAPF32[tempDoublePtr>>2]=$267,HEAP32[tempDoublePtr>>2]|0);
   $274 = (HEAPF32[tempDoublePtr>>2]=$269,HEAP32[tempDoublePtr>>2]|0);
   $275 = (HEAPF32[tempDoublePtr>>2]=$271,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$92>>2] = $272;
   HEAP32[$93>>2] = $273;
   HEAP32[$94>>2] = $274;
   HEAP32[$95>>2] = $275;
   $276 = (HEAP32[tempDoublePtr>>2]=$$lcssa129,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $277 = Math_fround($276 * $230);
   $278 = (HEAP32[tempDoublePtr>>2]=$$lcssa128,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $279 = Math_fround($278 * $234);
   $280 = (HEAP32[tempDoublePtr>>2]=$$lcssa127,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $281 = Math_fround($280 * $238);
   $282 = (HEAP32[tempDoublePtr>>2]=$$lcssa126,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $283 = Math_fround($282 * $242);
   $284 = Math_fround(HEAPF32[$96>>2]);
   $285 = Math_fround($284 - $277);
   $286 = Math_fround(HEAPF32[$97>>2]);
   $287 = Math_fround($286 - $279);
   $288 = Math_fround(HEAPF32[$98>>2]);
   $289 = Math_fround($288 - $281);
   $290 = Math_fround(HEAPF32[$99>>2]);
   $291 = Math_fround($290 - $283);
   $292 = (HEAPF32[tempDoublePtr>>2]=$285,HEAP32[tempDoublePtr>>2]|0);
   $293 = (HEAPF32[tempDoublePtr>>2]=$287,HEAP32[tempDoublePtr>>2]|0);
   $294 = (HEAPF32[tempDoublePtr>>2]=$289,HEAP32[tempDoublePtr>>2]|0);
   $295 = (HEAPF32[tempDoublePtr>>2]=$291,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$96>>2] = $292;
   HEAP32[$97>>2] = $293;
   HEAP32[$98>>2] = $294;
   HEAP32[$99>>2] = $295;
   $296 = Math_fround(HEAPF32[$100>>2]);
   $297 = $109 ? Math_fround(1.0) : Math_fround(0.0);
   $298 = Math_fround($297 + $296);
   $299 = Math_fround(HEAPF32[$101>>2]);
   $300 = $110 ? Math_fround(1.0) : Math_fround(0.0);
   $301 = Math_fround($300 + $299);
   $302 = Math_fround(HEAPF32[$102>>2]);
   $303 = $111 ? Math_fround(1.0) : Math_fround(0.0);
   $304 = Math_fround($303 + $302);
   $305 = Math_fround(HEAPF32[$103>>2]);
   $306 = $112 ? Math_fround(1.0) : Math_fround(0.0);
   $307 = Math_fround($306 + $305);
   $308 = (HEAPF32[tempDoublePtr>>2]=$298,HEAP32[tempDoublePtr>>2]|0);
   $309 = (HEAPF32[tempDoublePtr>>2]=$301,HEAP32[tempDoublePtr>>2]|0);
   $310 = (HEAPF32[tempDoublePtr>>2]=$304,HEAP32[tempDoublePtr>>2]|0);
   $311 = (HEAPF32[tempDoublePtr>>2]=$307,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$100>>2] = $308;
   HEAP32[$101>>2] = $309;
   HEAP32[$102>>2] = $310;
   HEAP32[$103>>2] = $311;
  }
  $312 = (($cIt$0150) + 4|0);
  $313 = ($312|0)==($87|0);
  if ($313) {
   break;
  } else {
   $cIt$0150 = $312;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth11SwCollisionI8Scalar4fE16collideTrianglesEPKNS0_12TriangleDataEPS2_RNS3_18ImpulseAccumulatorE($this,$triangles,$curPos,$accum) {
 $this = $this|0;
 $triangles = $triangles|0;
 $curPos = $curPos|0;
 $accum = $accum|0;
 var $$$i = 0, $$lcssa = Math_fround(0), $$lcssa315 = Math_fround(0), $$lcssa316 = Math_fround(0), $$lcssa317 = Math_fround(0), $$lcssa318 = Math_fround(0), $$lcssa319 = Math_fround(0), $$lcssa320 = Math_fround(0), $$lcssa321 = Math_fround(0), $$lcssa322 = Math_fround(0), $$lcssa323 = Math_fround(0), $$lcssa324 = Math_fround(0), $$lcssa325 = Math_fround(0), $$lcssa326 = Math_fround(0), $$lcssa327 = Math_fround(0), $$lcssa328 = Math_fround(0), $$lcssa329 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0);
 var $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0);
 var $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0);
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0);
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0);
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0);
 var $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0;
 var $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0);
 var $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0);
 var $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0);
 var $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0);
 var $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0);
 var $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = Math_fround(0), $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = Math_fround(0);
 var $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = 0, $511 = Math_fround(0), $512 = Math_fround(0), $513 = 0, $514 = Math_fround(0);
 var $515 = Math_fround(0), $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = 0, $531 = Math_fround(0), $532 = Math_fround(0);
 var $533 = 0, $534 = Math_fround(0), $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = 0, $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0);
 var $551 = 0, $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = 0, $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $brmerge$i = 0, $brmerge1$i = 0, $not$w$i$i$i12 = 0, $not$w$i$i$i16 = 0, $not$w$i$i$i20 = 0, $not$w$i$i$i4 = 0, $not$w$i$i$i8 = 0, $not$x$i$i$i1 = 0, $not$x$i$i$i13 = 0, $not$x$i$i$i17 = 0, $not$x$i$i$i5 = 0, $not$x$i$i$i9 = 0, $not$y$i$i$i10 = 0, $not$y$i$i$i14 = 0, $not$y$i$i$i18 = 0, $not$y$i$i$i2 = 0, $not$y$i$i$i6 = 0, $not$z$i$i$i11 = 0, $not$z$i$i$i15 = 0, $not$z$i$i$i19 = 0;
 var $not$z$i$i$i3 = 0, $not$z$i$i$i7 = 0, $phitmp = Math_fround(0), $phitmp346 = Math_fround(0), $phitmp347 = Math_fround(0), $phitmp348 = Math_fround(0), $phitmp349 = Math_fround(0), $phitmp350 = Math_fround(0), $phitmp351 = Math_fround(0), $phitmp352 = Math_fround(0), $phitmp353 = Math_fround(0), $phitmp354 = Math_fround(0), $phitmp355 = Math_fround(0), $phitmp356 = Math_fround(0), $phitmp357 = Math_fround(0), $phitmp358 = Math_fround(0), $phitmp359 = Math_fround(0), $phitmp360 = Math_fround(0), $tIt$0330 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 192|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($triangles) + (($3*80)|0)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  $$lcssa = Math_fround(0.0);$$lcssa315 = Math_fround(0.0);$$lcssa316 = Math_fround(0.0);$$lcssa317 = Math_fround(0.0);$$lcssa318 = Math_fround(0.0);$$lcssa319 = Math_fround(0.0);$$lcssa320 = Math_fround(0.0);$$lcssa321 = Math_fround(0.0);$$lcssa322 = Math_fround(0.0);$$lcssa323 = Math_fround(0.0);$$lcssa324 = Math_fround(0.0);$$lcssa325 = Math_fround(0.0);$$lcssa326 = Math_fround(0.0);$$lcssa327 = Math_fround(0.0);$$lcssa328 = Math_fround(0.0);$$lcssa329 = Math_fround(0.0);
 } else {
  $6 = HEAP32[((478168 + 12|0))>>2]|0;
  $7 = HEAP32[((478168 + 8|0))>>2]|0;
  $8 = HEAP32[((478168 + 4|0))>>2]|0;
  $9 = HEAP32[478168>>2]|0;
  $10 = Math_fround(HEAPF32[$curPos>>2]);
  $11 = (($curPos) + 4|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($curPos) + 8|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($curPos) + 12|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($curPos) + 16|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($curPos) + 20|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($curPos) + 24|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($curPos) + 28|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($curPos) + 32|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($curPos) + 36|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($curPos) + 40|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($curPos) + 44|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $391 = $9;$393 = $8;$395 = $7;$397 = $6;$399 = 0;$401 = 0;$403 = 0;$405 = 0;$415 = 0;$417 = 0;$419 = 0;$421 = 0;$431 = 0;$433 = 0;$435 = 0;$437 = 0;$447 = 0;$449 = 0;$451 = 0;$453 = 0;$tIt$0330 = $triangles;
  while(1) {
   $33 = Math_fround(HEAPF32[$tIt$0330>>2]);
   $34 = (($tIt$0330) + 4|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = (($tIt$0330) + 8|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = (($tIt$0330) + 12|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = (($tIt$0330) + 16|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = (($40) + 4|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = (($40) + 8|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = (($40) + 12|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = (($tIt$0330) + 32|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = (($48) + 4|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = (($48) + 8|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = (($48) + 12|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = (($tIt$0330) + 48|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = (($56) + 4|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = (($56) + 8|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = (($tIt$0330) + 64|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = (($62) + 4|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = (($62) + 8|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = (($62) + 12|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($10 - $33);
   $71 = Math_fround($12 - $33);
   $72 = Math_fround($14 - $33);
   $73 = Math_fround($16 - $33);
   $74 = Math_fround($18 - $35);
   $75 = Math_fround($20 - $35);
   $76 = Math_fround($22 - $35);
   $77 = Math_fround($24 - $35);
   $78 = Math_fround($26 - $37);
   $79 = Math_fround($28 - $37);
   $80 = Math_fround($30 - $37);
   $81 = Math_fround($32 - $37);
   $82 = (HEAPF32[tempDoublePtr>>2]=$57,HEAP32[tempDoublePtr>>2]|0);
   $83 = (HEAPF32[tempDoublePtr>>2]=$59,HEAP32[tempDoublePtr>>2]|0);
   $84 = (HEAPF32[tempDoublePtr>>2]=$61,HEAP32[tempDoublePtr>>2]|0);
   $85 = Math_fround($41 * $70);
   $86 = Math_fround($41 * $71);
   $87 = Math_fround($41 * $72);
   $88 = Math_fround($41 * $73);
   $89 = Math_fround($43 * $74);
   $90 = Math_fround($43 * $75);
   $91 = Math_fround($43 * $76);
   $92 = Math_fround($43 * $77);
   $93 = Math_fround($85 + $89);
   $94 = Math_fround($86 + $90);
   $95 = Math_fround($87 + $91);
   $96 = Math_fround($88 + $92);
   $97 = Math_fround($45 * $78);
   $98 = Math_fround($45 * $79);
   $99 = Math_fround($45 * $80);
   $100 = Math_fround($45 * $81);
   $101 = Math_fround($93 + $97);
   $102 = Math_fround($94 + $98);
   $103 = Math_fround($95 + $99);
   $104 = Math_fround($96 + $100);
   $105 = Math_fround($49 * $70);
   $106 = Math_fround($49 * $71);
   $107 = Math_fround($49 * $72);
   $108 = Math_fround($49 * $73);
   $109 = Math_fround($51 * $74);
   $110 = Math_fround($51 * $75);
   $111 = Math_fround($51 * $76);
   $112 = Math_fround($51 * $77);
   $113 = Math_fround($105 + $109);
   $114 = Math_fround($106 + $110);
   $115 = Math_fround($107 + $111);
   $116 = Math_fround($108 + $112);
   $117 = Math_fround($53 * $78);
   $118 = Math_fround($53 * $79);
   $119 = Math_fround($53 * $80);
   $120 = Math_fround($53 * $81);
   $121 = Math_fround($113 + $117);
   $122 = Math_fround($114 + $118);
   $123 = Math_fround($115 + $119);
   $124 = Math_fround($116 + $120);
   $125 = Math_fround($57 * $70);
   $126 = Math_fround($57 * $71);
   $127 = Math_fround($57 * $72);
   $128 = Math_fround($57 * $73);
   $129 = Math_fround($59 * $74);
   $130 = Math_fround($59 * $75);
   $131 = Math_fround($59 * $76);
   $132 = Math_fround($59 * $77);
   $133 = Math_fround($125 + $129);
   $134 = Math_fround($126 + $130);
   $135 = Math_fround($127 + $131);
   $136 = Math_fround($128 + $132);
   $137 = Math_fround($61 * $78);
   $138 = Math_fround($61 * $79);
   $139 = Math_fround($61 * $80);
   $140 = Math_fround($61 * $81);
   $141 = Math_fround($133 + $137);
   $142 = Math_fround($134 + $138);
   $143 = Math_fround($135 + $139);
   $144 = Math_fround($136 + $140);
   $145 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
   $146 = (HEAPF32[tempDoublePtr>>2]=$142,HEAP32[tempDoublePtr>>2]|0);
   $147 = (HEAPF32[tempDoublePtr>>2]=$143,HEAP32[tempDoublePtr>>2]|0);
   $148 = (HEAPF32[tempDoublePtr>>2]=$144,HEAP32[tempDoublePtr>>2]|0);
   $149 = Math_fround($55 * $101);
   $150 = Math_fround($55 * $102);
   $151 = Math_fround($55 * $103);
   $152 = Math_fround($55 * $104);
   $153 = Math_fround($39 * $121);
   $154 = Math_fround($39 * $122);
   $155 = Math_fround($39 * $123);
   $156 = Math_fround($39 * $124);
   $157 = Math_fround($149 - $153);
   $158 = Math_fround($150 - $154);
   $159 = Math_fround($151 - $155);
   $160 = Math_fround($152 - $156);
   $161 = Math_fround($47 * $121);
   $162 = Math_fround($47 * $122);
   $163 = Math_fround($47 * $123);
   $164 = Math_fround($47 * $124);
   $165 = Math_fround($39 * $101);
   $166 = Math_fround($39 * $102);
   $167 = Math_fround($39 * $103);
   $168 = Math_fround($39 * $104);
   $169 = Math_fround($161 - $165);
   $170 = Math_fround($162 - $166);
   $171 = Math_fround($163 - $167);
   $172 = Math_fround($164 - $168);
   $not$x$i$i$i17 = $157 > Math_fround(0.0);
   $not$y$i$i$i18 = $158 > Math_fround(0.0);
   $not$z$i$i$i19 = $159 > Math_fround(0.0);
   $not$w$i$i$i20 = $160 > Math_fround(0.0);
   $not$x$i$i$i13 = $169 > Math_fround(0.0);
   $not$y$i$i$i14 = $170 > Math_fround(0.0);
   $not$z$i$i$i15 = $171 > Math_fround(0.0);
   $not$w$i$i$i16 = $172 > Math_fround(0.0);
   $173 = Math_fround($63 * $157);
   $174 = Math_fround($63 * $158);
   $175 = Math_fround($63 * $159);
   $176 = Math_fround($63 * $160);
   $177 = (HEAPF32[tempDoublePtr>>2]=$173,HEAP32[tempDoublePtr>>2]|0);
   $178 = (HEAPF32[tempDoublePtr>>2]=$174,HEAP32[tempDoublePtr>>2]|0);
   $179 = (HEAPF32[tempDoublePtr>>2]=$175,HEAP32[tempDoublePtr>>2]|0);
   $180 = (HEAPF32[tempDoublePtr>>2]=$176,HEAP32[tempDoublePtr>>2]|0);
   $181 = Math_fround($67 * $101);
   $182 = Math_fround($67 * $102);
   $183 = Math_fround($67 * $103);
   $184 = Math_fround($67 * $104);
   $185 = (HEAPF32[tempDoublePtr>>2]=$181,HEAP32[tempDoublePtr>>2]|0);
   $186 = (HEAPF32[tempDoublePtr>>2]=$182,HEAP32[tempDoublePtr>>2]|0);
   $187 = (HEAPF32[tempDoublePtr>>2]=$183,HEAP32[tempDoublePtr>>2]|0);
   $188 = (HEAPF32[tempDoublePtr>>2]=$184,HEAP32[tempDoublePtr>>2]|0);
   $189 = $177 ^ $185;
   $190 = $178 ^ $186;
   $191 = $179 ^ $187;
   $192 = $180 ^ $188;
   $193 = $not$x$i$i$i13 ? $189 : 0;
   $194 = $not$y$i$i$i14 ? $190 : 0;
   $195 = $not$z$i$i$i15 ? $191 : 0;
   $196 = $not$w$i$i$i16 ? $192 : 0;
   $197 = $193 ^ $185;
   $198 = $194 ^ $186;
   $199 = $195 ^ $187;
   $200 = $196 ^ $188;
   $201 = Math_fround($63 * $169);
   $202 = Math_fround($63 * $170);
   $203 = Math_fround($63 * $171);
   $204 = Math_fround($63 * $172);
   $205 = (HEAPF32[tempDoublePtr>>2]=$201,HEAP32[tempDoublePtr>>2]|0);
   $206 = (HEAPF32[tempDoublePtr>>2]=$202,HEAP32[tempDoublePtr>>2]|0);
   $207 = (HEAPF32[tempDoublePtr>>2]=$203,HEAP32[tempDoublePtr>>2]|0);
   $208 = (HEAPF32[tempDoublePtr>>2]=$204,HEAP32[tempDoublePtr>>2]|0);
   $209 = Math_fround($69 * $121);
   $210 = Math_fround($69 * $122);
   $211 = Math_fround($69 * $123);
   $212 = Math_fround($69 * $124);
   $213 = (HEAPF32[tempDoublePtr>>2]=$209,HEAP32[tempDoublePtr>>2]|0);
   $214 = (HEAPF32[tempDoublePtr>>2]=$210,HEAP32[tempDoublePtr>>2]|0);
   $215 = (HEAPF32[tempDoublePtr>>2]=$211,HEAP32[tempDoublePtr>>2]|0);
   $216 = (HEAPF32[tempDoublePtr>>2]=$212,HEAP32[tempDoublePtr>>2]|0);
   $217 = $205 ^ $213;
   $218 = $206 ^ $214;
   $219 = $207 ^ $215;
   $220 = $208 ^ $216;
   $221 = $not$x$i$i$i17 ? $217 : 0;
   $222 = $not$y$i$i$i18 ? $218 : 0;
   $223 = $not$z$i$i$i19 ? $219 : 0;
   $224 = $not$w$i$i$i20 ? $220 : 0;
   $225 = $221 ^ $213;
   $226 = $222 ^ $214;
   $227 = $223 ^ $215;
   $228 = $224 ^ $216;
   $229 = (HEAP32[tempDoublePtr>>2]=$197,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $230 = (HEAP32[tempDoublePtr>>2]=$225,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $231 = Math_fround($229 + $230);
   $232 = (HEAP32[tempDoublePtr>>2]=$198,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $233 = (HEAP32[tempDoublePtr>>2]=$226,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $234 = Math_fround($232 + $233);
   $235 = (HEAP32[tempDoublePtr>>2]=$199,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $236 = (HEAP32[tempDoublePtr>>2]=$227,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $237 = Math_fround($235 + $236);
   $238 = (HEAP32[tempDoublePtr>>2]=$200,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $239 = (HEAP32[tempDoublePtr>>2]=$228,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $240 = Math_fround($238 + $239);
   $not$x$i$i$i9 = $231 > Math_fround(1.0);
   $not$y$i$i$i10 = $234 > Math_fround(1.0);
   $not$z$i$i$i11 = $237 > Math_fround(1.0);
   $not$w$i$i$i12 = $240 > Math_fround(1.0);
   $241 = Math_fround($55 - $39);
   $242 = Math_fround($241 + $101);
   $243 = Math_fround($241 + $102);
   $244 = Math_fround($241 + $103);
   $245 = Math_fround($241 + $104);
   $246 = Math_fround($242 - $121);
   $247 = Math_fround($243 - $122);
   $248 = Math_fround($244 - $123);
   $249 = Math_fround($245 - $124);
   $250 = Math_fround($65 * $246);
   $251 = Math_fround($65 * $247);
   $252 = Math_fround($65 * $248);
   $253 = Math_fround($65 * $249);
   $254 = (HEAPF32[tempDoublePtr>>2]=$250,HEAP32[tempDoublePtr>>2]|0);
   $255 = (HEAPF32[tempDoublePtr>>2]=$251,HEAP32[tempDoublePtr>>2]|0);
   $256 = (HEAPF32[tempDoublePtr>>2]=$252,HEAP32[tempDoublePtr>>2]|0);
   $257 = (HEAPF32[tempDoublePtr>>2]=$253,HEAP32[tempDoublePtr>>2]|0);
   $258 = $197 ^ $254;
   $259 = $198 ^ $255;
   $260 = $199 ^ $256;
   $261 = $200 ^ $257;
   $262 = $not$x$i$i$i9 ? $258 : 0;
   $263 = $not$y$i$i$i10 ? $259 : 0;
   $264 = $not$z$i$i$i11 ? $260 : 0;
   $265 = $not$w$i$i$i12 ? $261 : 0;
   $266 = $262 ^ $197;
   $267 = $263 ^ $198;
   $268 = $264 ^ $199;
   $269 = $265 ^ $200;
   $270 = (HEAP32[tempDoublePtr>>2]=$266,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $271 = $270 < Math_fround(1.0);
   $272 = $271 ? $270 : Math_fround(1.0);
   $273 = (HEAP32[tempDoublePtr>>2]=$267,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $274 = $273 < Math_fround(1.0);
   $275 = $274 ? $273 : Math_fround(1.0);
   $276 = (HEAP32[tempDoublePtr>>2]=$268,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $277 = $276 < Math_fround(1.0);
   $278 = $277 ? $276 : Math_fround(1.0);
   $279 = (HEAP32[tempDoublePtr>>2]=$269,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $280 = $279 < Math_fround(1.0);
   $281 = $280 ? $279 : Math_fround(1.0);
   $282 = $272 > Math_fround(0.0);
   $283 = $275 > Math_fround(0.0);
   $284 = $278 > Math_fround(0.0);
   $285 = $281 > Math_fround(0.0);
   $286 = $282 ? $272 : Math_fround(0.0);
   $287 = Math_fround(Math_fround(1.0) - $286);
   $288 = $283 ? $275 : Math_fround(0.0);
   $289 = Math_fround(Math_fround(1.0) - $288);
   $290 = $284 ? $278 : Math_fround(0.0);
   $291 = Math_fround(Math_fround(1.0) - $290);
   $292 = $285 ? $281 : Math_fround(0.0);
   $293 = Math_fround(Math_fround(1.0) - $292);
   $294 = $230 < $287;
   $295 = $294 ? $230 : $287;
   $296 = $233 < $289;
   $297 = $296 ? $233 : $289;
   $298 = $236 < $291;
   $299 = $298 ? $236 : $291;
   $300 = $239 < $293;
   $301 = $300 ? $239 : $293;
   $302 = $295 > Math_fround(0.0);
   $303 = $297 > Math_fround(0.0);
   $304 = $299 > Math_fround(0.0);
   $305 = $301 > Math_fround(0.0);
   $306 = Math_fround($41 * $286);
   $307 = Math_fround($41 * $288);
   $308 = Math_fround($41 * $290);
   $309 = Math_fround($41 * $292);
   $310 = Math_fround($70 - $306);
   $311 = Math_fround($71 - $307);
   $312 = Math_fround($72 - $308);
   $313 = Math_fround($73 - $309);
   $314 = $302 ? $295 : Math_fround(0.0);
   $315 = Math_fround($49 * $314);
   $316 = $303 ? $297 : Math_fround(0.0);
   $317 = Math_fround($49 * $316);
   $318 = $304 ? $299 : Math_fround(0.0);
   $319 = Math_fround($49 * $318);
   $320 = $305 ? $301 : Math_fround(0.0);
   $321 = Math_fround($49 * $320);
   $322 = Math_fround($310 - $315);
   $323 = Math_fround($311 - $317);
   $324 = Math_fround($312 - $319);
   $325 = Math_fround($313 - $321);
   $326 = Math_fround($43 * $286);
   $327 = Math_fround($43 * $288);
   $328 = Math_fround($43 * $290);
   $329 = Math_fround($43 * $292);
   $330 = Math_fround($74 - $326);
   $331 = Math_fround($75 - $327);
   $332 = Math_fround($76 - $328);
   $333 = Math_fround($77 - $329);
   $334 = Math_fround($51 * $314);
   $335 = Math_fround($51 * $316);
   $336 = Math_fround($51 * $318);
   $337 = Math_fround($51 * $320);
   $338 = Math_fround($330 - $334);
   $339 = Math_fround($331 - $335);
   $340 = Math_fround($332 - $336);
   $341 = Math_fround($333 - $337);
   $342 = Math_fround($45 * $286);
   $343 = Math_fround($45 * $288);
   $344 = Math_fround($45 * $290);
   $345 = Math_fround($45 * $292);
   $346 = Math_fround($78 - $342);
   $347 = Math_fround($79 - $343);
   $348 = Math_fround($80 - $344);
   $349 = Math_fround($81 - $345);
   $350 = Math_fround($53 * $314);
   $351 = Math_fround($53 * $316);
   $352 = Math_fround($53 * $318);
   $353 = Math_fround($53 * $320);
   $354 = Math_fround($346 - $350);
   $355 = Math_fround($347 - $351);
   $356 = Math_fround($348 - $352);
   $357 = Math_fround($349 - $353);
   $358 = Math_fround($322 * $322);
   $359 = Math_fround($323 * $323);
   $360 = Math_fround($324 * $324);
   $361 = Math_fround($325 * $325);
   $362 = Math_fround($338 * $338);
   $363 = Math_fround($339 * $339);
   $364 = Math_fround($340 * $340);
   $365 = Math_fround($341 * $341);
   $366 = Math_fround($358 + $362);
   $367 = Math_fround($359 + $363);
   $368 = Math_fround($360 + $364);
   $369 = Math_fround($361 + $365);
   $370 = Math_fround($354 * $354);
   $371 = Math_fround($355 * $355);
   $372 = Math_fround($356 * $356);
   $373 = Math_fround($357 * $357);
   $374 = Math_fround($370 + $366);
   $375 = Math_fround($371 + $367);
   $376 = Math_fround($372 + $368);
   $377 = Math_fround($373 + $369);
   $not$x$i$i$i5 = $141 < Math_fround(0.0);
   $not$y$i$i$i6 = $142 < Math_fround(0.0);
   $not$z$i$i$i7 = $143 < Math_fround(0.0);
   $not$w$i$i$i8 = $144 < Math_fround(0.0);
   $378 = $not$x$i$i$i5 ? Math_fround(9.99999974737875163555E-5) : Math_fround(0.0);
   $379 = Math_fround($378 * $374);
   $380 = $not$y$i$i$i6 ? Math_fround(9.99999974737875163555E-5) : Math_fround(0.0);
   $381 = Math_fround($380 * $375);
   $382 = $not$z$i$i$i7 ? Math_fround(9.99999974737875163555E-5) : Math_fround(0.0);
   $383 = Math_fround($382 * $376);
   $384 = $not$w$i$i$i8 ? Math_fround(9.99999974737875163555E-5) : Math_fround(0.0);
   $385 = Math_fround($384 * $377);
   $386 = Math_fround($374 + $379);
   $387 = Math_fround($375 + $381);
   $388 = Math_fround($376 + $383);
   $389 = Math_fround($377 + $385);
   $390 = (HEAP32[tempDoublePtr>>2]=$391,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $392 = (HEAP32[tempDoublePtr>>2]=$393,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $394 = (HEAP32[tempDoublePtr>>2]=$395,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $396 = (HEAP32[tempDoublePtr>>2]=$397,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i1 = $386 < $390;
   $not$y$i$i$i2 = $387 < $392;
   $not$z$i$i$i3 = $388 < $394;
   $not$w$i$i$i4 = $389 < $396;
   $398 = $82 ^ $399;
   $400 = $82 ^ $401;
   $402 = $82 ^ $403;
   $404 = $82 ^ $405;
   $406 = $not$x$i$i$i1 ? $398 : 0;
   $407 = $not$y$i$i$i2 ? $400 : 0;
   $408 = $not$z$i$i$i3 ? $402 : 0;
   $409 = $not$w$i$i$i4 ? $404 : 0;
   $410 = $406 ^ $399;
   $411 = $407 ^ $401;
   $412 = $408 ^ $403;
   $413 = $409 ^ $405;
   $414 = $83 ^ $415;
   $416 = $83 ^ $417;
   $418 = $83 ^ $419;
   $420 = $83 ^ $421;
   $422 = $not$x$i$i$i1 ? $414 : 0;
   $423 = $not$y$i$i$i2 ? $416 : 0;
   $424 = $not$z$i$i$i3 ? $418 : 0;
   $425 = $not$w$i$i$i4 ? $420 : 0;
   $426 = $422 ^ $415;
   $427 = $423 ^ $417;
   $428 = $424 ^ $419;
   $429 = $425 ^ $421;
   $430 = $84 ^ $431;
   $432 = $84 ^ $433;
   $434 = $84 ^ $435;
   $436 = $84 ^ $437;
   $438 = $not$x$i$i$i1 ? $430 : 0;
   $439 = $not$y$i$i$i2 ? $432 : 0;
   $440 = $not$z$i$i$i3 ? $434 : 0;
   $441 = $not$w$i$i$i4 ? $436 : 0;
   $442 = $438 ^ $431;
   $443 = $439 ^ $433;
   $444 = $440 ^ $435;
   $445 = $441 ^ $437;
   $446 = $145 ^ $447;
   $448 = $146 ^ $449;
   $450 = $147 ^ $451;
   $452 = $148 ^ $453;
   $454 = $not$x$i$i$i1 ? $446 : 0;
   $455 = $not$y$i$i$i2 ? $448 : 0;
   $456 = $not$z$i$i$i3 ? $450 : 0;
   $457 = $not$w$i$i$i4 ? $452 : 0;
   $458 = $454 ^ $447;
   $459 = $455 ^ $449;
   $460 = $456 ^ $451;
   $461 = $457 ^ $453;
   $462 = $390 < $386;
   $463 = $462 ? $390 : $386;
   $464 = $392 < $387;
   $465 = $464 ? $392 : $387;
   $466 = $394 < $388;
   $467 = $466 ? $394 : $388;
   $468 = $396 < $389;
   $469 = $468 ? $396 : $389;
   $470 = (HEAPF32[tempDoublePtr>>2]=$463,HEAP32[tempDoublePtr>>2]|0);
   $471 = (HEAPF32[tempDoublePtr>>2]=$465,HEAP32[tempDoublePtr>>2]|0);
   $472 = (HEAPF32[tempDoublePtr>>2]=$467,HEAP32[tempDoublePtr>>2]|0);
   $473 = (HEAPF32[tempDoublePtr>>2]=$469,HEAP32[tempDoublePtr>>2]|0);
   $474 = (($tIt$0330) + 80|0);
   $475 = ($474|0)==($4|0);
   if ($475) {
    break;
   } else {
    $391 = $470;$393 = $471;$395 = $472;$397 = $473;$399 = $410;$401 = $411;$403 = $412;$405 = $413;$415 = $426;$417 = $427;$419 = $428;$421 = $429;$431 = $442;$433 = $443;$435 = $444;$437 = $445;$447 = $458;$449 = $459;$451 = $460;$453 = $461;$tIt$0330 = $474;
   }
  }
  $phitmp = (HEAP32[tempDoublePtr>>2]=$458,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp346 = (HEAP32[tempDoublePtr>>2]=$459,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp347 = (HEAP32[tempDoublePtr>>2]=$460,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp348 = (HEAP32[tempDoublePtr>>2]=$461,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp349 = (HEAP32[tempDoublePtr>>2]=$410,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp350 = (HEAP32[tempDoublePtr>>2]=$411,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp351 = (HEAP32[tempDoublePtr>>2]=$412,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp352 = (HEAP32[tempDoublePtr>>2]=$413,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp353 = (HEAP32[tempDoublePtr>>2]=$426,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp354 = (HEAP32[tempDoublePtr>>2]=$427,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp355 = (HEAP32[tempDoublePtr>>2]=$428,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp356 = (HEAP32[tempDoublePtr>>2]=$429,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp357 = (HEAP32[tempDoublePtr>>2]=$442,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp358 = (HEAP32[tempDoublePtr>>2]=$443,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp359 = (HEAP32[tempDoublePtr>>2]=$444,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $phitmp360 = (HEAP32[tempDoublePtr>>2]=$445,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $$lcssa = $phitmp352;$$lcssa315 = $phitmp351;$$lcssa316 = $phitmp350;$$lcssa317 = $phitmp349;$$lcssa318 = $phitmp356;$$lcssa319 = $phitmp355;$$lcssa320 = $phitmp354;$$lcssa321 = $phitmp353;$$lcssa322 = $phitmp360;$$lcssa323 = $phitmp359;$$lcssa324 = $phitmp358;$$lcssa325 = $phitmp357;$$lcssa326 = $phitmp348;$$lcssa327 = $phitmp347;$$lcssa328 = $phitmp346;$$lcssa329 = $phitmp;
 }
 $476 = $$lcssa329 < Math_fround(0.0);
 $477 = $$lcssa328 < Math_fround(0.0);
 $478 = $$lcssa327 < Math_fround(0.0);
 $479 = $$lcssa326 < Math_fround(0.0);
 $brmerge$i = $476 | $477;
 $brmerge1$i = $brmerge$i | $478;
 $$$i = $brmerge1$i | $479;
 if (!($$$i)) {
  STACKTOP = sp;return;
 }
 $480 = $476 ? $$lcssa329 : Math_fround(0.0);
 $481 = Math_fround($$lcssa317 * $480);
 $482 = $477 ? $$lcssa328 : Math_fround(0.0);
 $483 = Math_fround($$lcssa316 * $482);
 $484 = $478 ? $$lcssa327 : Math_fround(0.0);
 $485 = Math_fround($$lcssa315 * $484);
 $486 = $479 ? $$lcssa326 : Math_fround(0.0);
 $487 = Math_fround($$lcssa * $486);
 $488 = Math_fround(HEAPF32[$accum>>2]);
 $489 = Math_fround($488 - $481);
 $490 = (($accum) + 4|0);
 $491 = Math_fround(HEAPF32[$490>>2]);
 $492 = Math_fround($491 - $483);
 $493 = (($accum) + 8|0);
 $494 = Math_fround(HEAPF32[$493>>2]);
 $495 = Math_fround($494 - $485);
 $496 = (($accum) + 12|0);
 $497 = Math_fround(HEAPF32[$496>>2]);
 $498 = Math_fround($497 - $487);
 $499 = (HEAPF32[tempDoublePtr>>2]=$489,HEAP32[tempDoublePtr>>2]|0);
 $500 = (HEAPF32[tempDoublePtr>>2]=$492,HEAP32[tempDoublePtr>>2]|0);
 $501 = (HEAPF32[tempDoublePtr>>2]=$495,HEAP32[tempDoublePtr>>2]|0);
 $502 = (HEAPF32[tempDoublePtr>>2]=$498,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$accum>>2] = $499;
 HEAP32[$490>>2] = $500;
 HEAP32[$493>>2] = $501;
 HEAP32[$496>>2] = $502;
 $503 = (($accum) + 16|0);
 $504 = Math_fround($$lcssa321 * $480);
 $505 = Math_fround($$lcssa320 * $482);
 $506 = Math_fround($$lcssa319 * $484);
 $507 = Math_fround($$lcssa318 * $486);
 $508 = Math_fround(HEAPF32[$503>>2]);
 $509 = Math_fround($508 - $504);
 $510 = (($accum) + 20|0);
 $511 = Math_fround(HEAPF32[$510>>2]);
 $512 = Math_fround($511 - $505);
 $513 = (($accum) + 24|0);
 $514 = Math_fround(HEAPF32[$513>>2]);
 $515 = Math_fround($514 - $506);
 $516 = (($accum) + 28|0);
 $517 = Math_fround(HEAPF32[$516>>2]);
 $518 = Math_fround($517 - $507);
 $519 = (HEAPF32[tempDoublePtr>>2]=$509,HEAP32[tempDoublePtr>>2]|0);
 $520 = (HEAPF32[tempDoublePtr>>2]=$512,HEAP32[tempDoublePtr>>2]|0);
 $521 = (HEAPF32[tempDoublePtr>>2]=$515,HEAP32[tempDoublePtr>>2]|0);
 $522 = (HEAPF32[tempDoublePtr>>2]=$518,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$503>>2] = $519;
 HEAP32[$510>>2] = $520;
 HEAP32[$513>>2] = $521;
 HEAP32[$516>>2] = $522;
 $523 = (($accum) + 32|0);
 $524 = Math_fround($$lcssa325 * $480);
 $525 = Math_fround($$lcssa324 * $482);
 $526 = Math_fround($$lcssa323 * $484);
 $527 = Math_fround($$lcssa322 * $486);
 $528 = Math_fround(HEAPF32[$523>>2]);
 $529 = Math_fround($528 - $524);
 $530 = (($accum) + 36|0);
 $531 = Math_fround(HEAPF32[$530>>2]);
 $532 = Math_fround($531 - $525);
 $533 = (($accum) + 40|0);
 $534 = Math_fround(HEAPF32[$533>>2]);
 $535 = Math_fround($534 - $526);
 $536 = (($accum) + 44|0);
 $537 = Math_fround(HEAPF32[$536>>2]);
 $538 = Math_fround($537 - $527);
 $539 = (HEAPF32[tempDoublePtr>>2]=$529,HEAP32[tempDoublePtr>>2]|0);
 $540 = (HEAPF32[tempDoublePtr>>2]=$532,HEAP32[tempDoublePtr>>2]|0);
 $541 = (HEAPF32[tempDoublePtr>>2]=$535,HEAP32[tempDoublePtr>>2]|0);
 $542 = (HEAPF32[tempDoublePtr>>2]=$538,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$523>>2] = $539;
 HEAP32[$530>>2] = $540;
 HEAP32[$533>>2] = $541;
 HEAP32[$536>>2] = $542;
 $543 = (($accum) + 96|0);
 $544 = Math_fround(HEAPF32[$543>>2]);
 $545 = $476 ? Math_fround(1.0) : Math_fround(0.0);
 $546 = Math_fround($545 + $544);
 $547 = (($accum) + 100|0);
 $548 = Math_fround(HEAPF32[$547>>2]);
 $549 = $477 ? Math_fround(1.0) : Math_fround(0.0);
 $550 = Math_fround($549 + $548);
 $551 = (($accum) + 104|0);
 $552 = Math_fround(HEAPF32[$551>>2]);
 $553 = $478 ? Math_fround(1.0) : Math_fround(0.0);
 $554 = Math_fround($553 + $552);
 $555 = (($accum) + 108|0);
 $556 = Math_fround(HEAPF32[$555>>2]);
 $557 = $479 ? Math_fround(1.0) : Math_fround(0.0);
 $558 = Math_fround($557 + $556);
 $559 = (HEAPF32[tempDoublePtr>>2]=$546,HEAP32[tempDoublePtr>>2]|0);
 $560 = (HEAPF32[tempDoublePtr>>2]=$550,HEAP32[tempDoublePtr>>2]|0);
 $561 = (HEAPF32[tempDoublePtr>>2]=$554,HEAP32[tempDoublePtr>>2]|0);
 $562 = (HEAPF32[tempDoublePtr>>2]=$558,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$543>>2] = $559;
 HEAP32[$547>>2] = $560;
 HEAP32[$551>>2] = $561;
 HEAP32[$555>>2] = $562;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a4171() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[478152>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((478152 + 4|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((478152 + 8|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((478152 + 12|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[478168>>2] = Math_fround(3.40282346638528859812E+38);
 HEAPF32[((478168 + 4|0))>>2] = Math_fround(3.40282346638528859812E+38);
 HEAPF32[((478168 + 8|0))>>2] = Math_fround(3.40282346638528859812E+38);
 HEAPF32[((478168 + 12|0))>>2] = Math_fround(3.40282346638528859812E+38);
 HEAP32[478184>>2] = -1;
 HEAP32[((478184 + 4|0))>>2] = 0;
 HEAP32[((478184 + 8|0))>>2] = 0;
 HEAP32[((478184 + 12|0))>>2] = 0;
 HEAP32[478200>>2] = 0;
 HEAP32[((478200 + 4|0))>>2] = 0;
 HEAP32[((478200 + 8|0))>>2] = -1;
 HEAP32[((478200 + 12|0))>>2] = 0;
 HEAP32[478216>>2] = 0;
 HEAP32[((478216 + 4|0))>>2] = 0;
 HEAP32[((478216 + 8|0))>>2] = 0;
 HEAP32[((478216 + 12|0))>>2] = -1;
 ;HEAP32[478232+0>>2]=0|0;HEAP32[478232+4>>2]=0|0;HEAP32[478232+8>>2]=0|0;HEAP32[478232+12>>2]=0|0;
 HEAPF32[478248>>2] = Math_fround(1.0);
 HEAPF32[((478248 + 4|0))>>2] = Math_fround(1.0);
 HEAPF32[((478248 + 8|0))>>2] = Math_fround(1.0);
 HEAPF32[((478248 + 12|0))>>2] = Math_fround(1.0);
 HEAPF32[478264>>2] = Math_fround(-1.0);
 HEAPF32[((478264 + 4|0))>>2] = Math_fround(-1.0);
 HEAPF32[((478264 + 8|0))>>2] = Math_fround(-1.0);
 HEAPF32[((478264 + 12|0))>>2] = Math_fround(-1.0);
 HEAPF32[478280>>2] = Math_fround(0.5);
 HEAPF32[((478280 + 4|0))>>2] = Math_fround(0.5);
 HEAPF32[((478280 + 8|0))>>2] = Math_fround(0.5);
 HEAPF32[((478280 + 12|0))>>2] = Math_fround(0.5);
 HEAPF32[478296>>2] = Math_fround(1.0);
 HEAPF32[((478296 + 4|0))>>2] = Math_fround(1.0);
 HEAPF32[((478296 + 8|0))>>2] = Math_fround(1.0);
 HEAPF32[((478296 + 12|0))>>2] = Math_fround(0.0);
 HEAPF32[478312>>2] = Math_fround(7.99900007247924804688);
 HEAPF32[((478312 + 4|0))>>2] = Math_fround(7.99900007247924804688);
 HEAPF32[((478312 + 8|0))>>2] = Math_fround(7.99900007247924804688);
 HEAPF32[((478312 + 12|0))>>2] = Math_fround(7.99900007247924804688);
 HEAPF32[478328>>2] = Math_fround(9.99999974737875163555E-5);
 HEAPF32[((478328 + 4|0))>>2] = Math_fround(9.99999974737875163555E-5);
 HEAPF32[((478328 + 8|0))>>2] = Math_fround(9.99999974737875163555E-5);
 HEAPF32[((478328 + 12|0))>>2] = Math_fround(9.99999974737875163555E-5);
 HEAPF32[478344>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((478344 + 4|0))>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((478344 + 8|0))>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((478344 + 12|0))>>2] = Math_fround(0.0);
 $0 = HEAP8[478376>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 HEAPF32[478360>>2] = Math_fround(0.949999988079071044921);
 HEAPF32[((478360 + 4|0))>>2] = Math_fround(0.949999988079071044921);
 HEAPF32[((478360 + 8|0))>>2] = Math_fround(0.949999988079071044921);
 HEAPF32[((478360 + 12|0))>>2] = Math_fround(0.949999988079071044921);
 $2 = 478376;
 $3 = $2;
 HEAP32[$3>>2] = 1;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwFabricC2ERNS0_9SwFactoryEjNS0_5RangeIKjEES6_NS4_IKfEES6_S6_S8_j($this,$factory,$numParticles,$phases,$sets,$restvalues,$indices,$anchors,$tetherLengths,$id) {
 $this = $this|0;
 $factory = $factory|0;
 $numParticles = $numParticles|0;
 $phases = $phases|0;
 $sets = $sets|0;
 $restvalues = $restvalues|0;
 $indices = $indices|0;
 $anchors = $anchors|0;
 $tetherLengths = $tetherLengths|0;
 $id = $id|0;
 var $$012$i$i = 0, $$012$i$i$i = 0, $$012$i$i$i6 = 0, $$03$i$i = 0, $$03$i$i$i = 0, $$03$i$i$i5 = 0, $$idx = 0, $$idx21 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre$i18 = 0, $$pre$i8 = 0, $$pre$phiZ2D = 0, $$pre52 = 0, $$pre53 = 0, $$pre54 = 0, $$promoted = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $iIt$033 = 0, $iIt$03348 = 0, $iIt$1$lcssa = 0, $iIt$127 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0;
 var $or$cond$i$i = 0, $or$cond$i$i3$not = 0, $phitmp$i$i$i = 0, $rIt$032 = 0, $rIt$1$lcssa = 0, $rIt$124 = 0, $sIt$031 = 0, $scevgep$sum = 0, $scevgep38$sum = 0, $scevgep39 = 0, $scevgep42 = 0, $scevgep44$sum = 0, $scevgep45$sum = 0, $scevgep46 = 0, $scevgep51 = 0, $uglygep = 0, $uglygep41 = 0, $uglygep49 = 0, $uglygep4950 = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 44|0;
 $1 = sp + 48|0;
 $2 = sp + 40|0;
 $3 = sp + 50|0;
 $4 = sp + 52|0;
 $5 = sp + 36|0;
 $6 = sp + 20|0;
 $7 = sp + 8|0;
 $8 = sp;
 $9 = sp + 32|0;
 $10 = (($this) + 4|0);
 $11 = (($this) + 8|0);
 HEAP16[$11>>1] = 0;
 HEAP32[$this>>2] = ((478384 + 8|0));
 HEAP32[$10>>2] = ((478384 + 60|0));
 $12 = (($this) + 12|0);
 HEAP32[$12>>2] = $factory;
 $13 = (($this) + 16|0);
 HEAP32[$13>>2] = $numParticles;
 $14 = (($this) + 20|0);
 $15 = (($this) + 24|0);
 $16 = (($this) + 32|0);
 $17 = (($this) + 36|0);
 $18 = (($this) + 40|0);
 $19 = (($this) + 44|0);
 $20 = (($this) + 48|0);
 $21 = (($this) + 52|0);
 $22 = (($this) + 56|0);
 $23 = (($this) + 60|0);
 $24 = (($this) + 64|0);
 $25 = (($this) + 68|0);
 $26 = (($this) + 72|0);
 $27 = (($this) + 76|0);
 $28 = (($this) + 80|0);
 dest=$14+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($this) + 84|0);
 HEAP32[$29>>2] = $id;
 $30 = HEAP32[$phases>>2]|0;
 $31 = (($phases) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32;
 $34 = $30;
 $35 = (($33) - ($34))|0;
 $36 = $35 >> 2;
 __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE19resizeUninitializedEj($14,$36);
 $37 = HEAP32[$14>>2]|0;
 $38 = HEAP32[$15>>2]|0;
 $39 = (($37) + ($38<<2)|0);
 $40 = ($38|0)>(0);
 if ($40) {
  $$012$i$i = $37;$$03$i$i = $30;
  while(1) {
   $41 = ($$012$i$i|0)==(0|0);
   if (!($41)) {
    $42 = HEAP32[$$03$i$i>>2]|0;
    HEAP32[$$012$i$i>>2] = $42;
   }
   $43 = (($$012$i$i) + 4|0);
   $44 = (($$03$i$i) + 4|0);
   $45 = ($43>>>0)<($39>>>0);
   if ($45) {
    $$012$i$i = $43;$$03$i$i = $44;
   } else {
    break;
   }
  }
 }
 $46 = (($sets) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$sets>>2]|0;
 $49 = $47;
 $50 = $48;
 $51 = (($49) - ($50))|0;
 $52 = $51 >> 2;
 $53 = (($52) + 1)|0;
 $54 = HEAP32[$18>>2]|0;
 $55 = $54 & 2147483647;
 $56 = ($55>>>0)<($53>>>0);
 if ($56) {
  __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE8recreateEj($16,$53);
  $$pre = HEAP32[$18>>2]|0;
  $58 = $$pre;
 } else {
  $58 = $54;
 }
 HEAP32[$0>>2] = 0;
 $57 = $58 & 2147483647;
 $59 = HEAP32[$17>>2]|0;
 $60 = ($57>>>0)>($59>>>0);
 if ($60) {
  $61 = HEAP32[$16>>2]|0;
  $62 = (($61) + ($59<<2)|0);
  $63 = ($62|0)==(0|0);
  if ($63) {
   $65 = $59;
  } else {
   HEAP32[$62>>2] = 0;
   $$pre$i18 = HEAP32[$17>>2]|0;
   $65 = $$pre$i18;
  }
  $64 = (($65) + 1)|0;
  HEAP32[$17>>2] = $64;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE15growAndPushBackERKj($16,$0)|0);
 }
 $66 = (($restvalues) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$restvalues>>2]|0;
 $69 = $67;
 $70 = $68;
 $71 = (($69) - ($70))|0;
 $72 = $71 >> 2;
 $73 = (($this) + 88|0);
 HEAP32[$73>>2] = $72;
 $74 = HEAP32[$indices>>2]|0;
 $75 = ($48|0)==($47|0);
 if (!($75)) {
  $iIt$033 = $74;$rIt$032 = $68;$sIt$031 = $48;
  while(1) {
   $iIt$03348 = $iIt$033;
   $76 = $rIt$032;
   $77 = HEAP32[$sIt$031>>2]|0;
   $78 = (($68) + ($77<<2)|0);
   $79 = $77 << 1;
   $80 = (($74) + ($79<<2)|0);
   $81 = $78;
   $82 = (($81) - ($76))|0;
   $83 = $82 >>> 2;
   $84 = ($rIt$032|0)==($78|0);
   if ($84) {
    $rIt$1$lcssa = $rIt$032;
   } else {
    $scevgep38$sum = (($77) + -1)|0;
    $scevgep39 = (($68) + ($scevgep38$sum<<2)|0);
    $85 = (0 - ($76))|0;
    $uglygep = (($scevgep39) + ($85)|0);
    $uglygep41 = $uglygep;
    $86 = $uglygep41 >>> 2;
    $rIt$124 = $rIt$032;
    while(1) {
     $87 = HEAP32[$21>>2]|0;
     $88 = $87 & 2147483647;
     $89 = HEAP32[$20>>2]|0;
     $90 = ($88>>>0)>($89>>>0);
     if ($90) {
      $91 = HEAP32[$19>>2]|0;
      $92 = (($91) + ($89<<2)|0);
      $93 = ($92|0)==(0|0);
      if (!($93)) {
       $94 = Math_fround(HEAPF32[$rIt$124>>2]);
       HEAPF32[$92>>2] = $94;
      }
      $95 = (($89) + 1)|0;
      HEAP32[$20>>2] = $95;
     } else {
      (__ZN5physx6shdfnd5ArrayIfNS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE15growAndPushBackERKf($19,$rIt$124)|0);
     }
     $96 = (($rIt$124) + 4|0);
     $97 = ($96|0)==($78|0);
     if ($97) {
      break;
     } else {
      $rIt$124 = $96;
     }
    }
    $scevgep$sum = (($86) + 1)|0;
    $scevgep42 = (($rIt$032) + ($scevgep$sum<<2)|0);
    $rIt$1$lcssa = $scevgep42;
   }
   $98 = ($iIt$033|0)==($80|0);
   if ($98) {
    $iIt$1$lcssa = $iIt$033;
   } else {
    $99 = $77 << 1;
    $scevgep45$sum = (($99) + -1)|0;
    $scevgep46 = (($74) + ($scevgep45$sum<<2)|0);
    $100 = (0 - ($iIt$03348))|0;
    $uglygep49 = (($scevgep46) + ($100)|0);
    $uglygep4950 = $uglygep49;
    $101 = $uglygep4950 >>> 2;
    $iIt$127 = $iIt$033;
    while(1) {
     $102 = HEAP32[$iIt$127>>2]|0;
     $103 = $102&65535;
     HEAP16[$1>>1] = $103;
     $104 = HEAP32[$24>>2]|0;
     $105 = $104 & 2147483647;
     $106 = HEAP32[$23>>2]|0;
     $107 = ($105>>>0)>($106>>>0);
     if ($107) {
      $108 = HEAP32[$22>>2]|0;
      $109 = (($108) + ($106<<1)|0);
      $110 = ($109|0)==(0|0);
      if (!($110)) {
       HEAP16[$109>>1] = $103;
      }
      $111 = (($106) + 1)|0;
      HEAP32[$23>>2] = $111;
     } else {
      (__ZN5physx6shdfnd5ArrayItNS0_9AllocatorEE15growAndPushBackERKt($22,$1)|0);
     }
     $112 = (($iIt$127) + 4|0);
     $113 = ($112|0)==($80|0);
     if ($113) {
      break;
     } else {
      $iIt$127 = $112;
     }
    }
    $scevgep44$sum = (($101) + 1)|0;
    $scevgep51 = (($iIt$033) + ($scevgep44$sum<<2)|0);
    $iIt$1$lcssa = $scevgep51;
   }
   $114 = $83 & 3;
   $115 = ($114|0)==(0);
   if (!($115)) {
    $126 = $114;
    while(1) {
     HEAPF32[$2>>2] = Math_fround(-3.40282346638528859812E+38);
     $116 = HEAP32[$21>>2]|0;
     $117 = $116 & 2147483647;
     $118 = HEAP32[$20>>2]|0;
     $119 = ($117>>>0)>($118>>>0);
     if ($119) {
      $120 = HEAP32[$19>>2]|0;
      $121 = (($120) + ($118<<2)|0);
      $122 = ($121|0)==(0|0);
      if (!($122)) {
       HEAPF32[$121>>2] = Math_fround(-3.40282346638528859812E+38);
      }
      $123 = (($118) + 1)|0;
      HEAP32[$20>>2] = $123;
     } else {
      (__ZN5physx6shdfnd5ArrayIfNS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE15growAndPushBackERKf($19,$2)|0);
     }
     $124 = HEAP32[$13>>2]|0;
     $125 = (($126) + 65535)|0;
     $127 = (($125) + ($124))|0;
     $128 = $127&65535;
     HEAP16[$3>>1] = $128;
     $129 = HEAP32[$24>>2]|0;
     $130 = $129 & 2147483647;
     $131 = HEAP32[$23>>2]|0;
     $132 = ($130>>>0)>($131>>>0);
     if ($132) {
      $133 = HEAP32[$22>>2]|0;
      $134 = (($133) + ($131<<1)|0);
      $135 = ($134|0)==(0|0);
      if (!($135)) {
       HEAP16[$134>>1] = $128;
      }
      $136 = (($131) + 1)|0;
      HEAP32[$23>>2] = $136;
      $138 = $129;$140 = $136;
     } else {
      (__ZN5physx6shdfnd5ArrayItNS0_9AllocatorEE15growAndPushBackERKt($22,$3)|0);
      $$pre52 = HEAP32[$24>>2]|0;
      $$pre53 = HEAP32[$23>>2]|0;
      $138 = $$pre52;$140 = $$pre53;
     }
     HEAP16[$4>>1] = $128;
     $137 = $138 & 2147483647;
     $139 = ($137>>>0)>($140>>>0);
     if ($139) {
      $141 = HEAP32[$22>>2]|0;
      $142 = (($141) + ($140<<1)|0);
      $143 = ($142|0)==(0|0);
      if (!($143)) {
       HEAP16[$142>>1] = $128;
      }
      $144 = (($140) + 1)|0;
      HEAP32[$23>>2] = $144;
     } else {
      (__ZN5physx6shdfnd5ArrayItNS0_9AllocatorEE15growAndPushBackERKt($22,$4)|0);
     }
     $145 = (($126) + 1)|0;
     $146 = $145 & 3;
     $147 = ($146|0)==(0);
     if ($147) {
      break;
     } else {
      $126 = $146;
     }
    }
   }
   $148 = HEAP32[$20>>2]|0;
   HEAP32[$5>>2] = $148;
   $149 = HEAP32[$18>>2]|0;
   $150 = $149 & 2147483647;
   $151 = HEAP32[$17>>2]|0;
   $152 = ($150>>>0)>($151>>>0);
   if ($152) {
    $153 = HEAP32[$16>>2]|0;
    $154 = (($153) + ($151<<2)|0);
    $155 = ($154|0)==(0|0);
    if ($155) {
     $157 = $151;
    } else {
     HEAP32[$154>>2] = $148;
     $$pre$i8 = HEAP32[$17>>2]|0;
     $157 = $$pre$i8;
    }
    $156 = (($157) + 1)|0;
    HEAP32[$17>>2] = $156;
   } else {
    (__ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE15growAndPushBackERKj($16,$5)|0);
   }
   $158 = (($sIt$031) + 4|0);
   $159 = ($158|0)==($47|0);
   if ($159) {
    break;
   } else {
    $iIt$033 = $iIt$1$lcssa;$rIt$032 = $rIt$1$lcssa;$sIt$031 = $158;
   }
  }
 }
 $160 = HEAP32[$19>>2]|0;
 $161 = HEAP32[$20>>2]|0;
 $162 = (($6) + 4|0);
 $163 = ($161|0)<(0);
 if ($163) {
  HEAP32[$162>>2] = 0;
  $164 = (($6) + 8|0);
  HEAP32[$164>>2] = 0;
  $178 = 0;
 } else {
  $$idx = $161 << 2;
  $165 = $$idx >> 2;
  HEAP32[$162>>2] = $165;
  $166 = (($6) + 8|0);
  HEAP32[$166>>2] = $165;
  $167 = ($165|0)==(0);
  if ($167) {
   $178 = 0;
  } else {
   $168 = (($$idx) + 19)|0;
   $169 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($6,$168,478488,558)|0);
   $170 = ($169|0)==(0|0);
   if ($170) {
    $178 = 0;
   } else {
    $171 = (($169) + 19|0);
    $172 = $171;
    $173 = $172 & -16;
    $174 = $169;
    $175 = (($173) - ($174))|0;
    $176 = $173;
    $177 = (($176) + -4|0);
    HEAP32[$177>>2] = $175;
    $phitmp$i$i$i = $173;
    $178 = $phitmp$i$i$i;
   }
  }
 }
 HEAP32[$6>>2] = $178;
 $179 = HEAP32[$162>>2]|0;
 $180 = (($178) + ($179<<2)|0);
 $181 = ($179|0)>(0);
 if ($181) {
  $$012$i$i$i6 = $178;$$03$i$i$i5 = $160;
  while(1) {
   $182 = ($$012$i$i$i6|0)==(0|0);
   if (!($182)) {
    $183 = Math_fround(HEAPF32[$$03$i$i$i5>>2]);
    HEAPF32[$$012$i$i$i6>>2] = $183;
   }
   $184 = (($$012$i$i$i6) + 4|0);
   $185 = (($$03$i$i$i5) + 4|0);
   $186 = ($184>>>0)<($180>>>0);
   if ($186) {
    $$012$i$i$i6 = $184;$$03$i$i$i5 = $185;
   } else {
    break;
   }
  }
 }
 $187 = HEAP32[$19>>2]|0;
 HEAP32[$6>>2] = $187;
 HEAP32[$19>>2] = $178;
 $188 = HEAP32[$20>>2]|0;
 HEAP32[$162>>2] = $188;
 HEAP32[$20>>2] = $179;
 $189 = (($6) + 8|0);
 $190 = HEAP32[$189>>2]|0;
 $191 = HEAP32[$21>>2]|0;
 HEAP32[$189>>2] = $191;
 HEAP32[$21>>2] = $190;
 $192 = $191 & 2147483647;
 $notlhs = ($192|0)==(0);
 $notrhs = ($191|0)<(0);
 $or$cond$i$i3$not = $notrhs | $notlhs;
 $193 = ($187|0)==(0|0);
 $or$cond = $or$cond$i$i3$not | $193;
 if (!($or$cond)) {
  $194 = (($187) + -4|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = (0 - ($195))|0;
  $197 = (($187) + ($196)|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$197);
 }
 $198 = HEAP32[$22>>2]|0;
 $199 = HEAP32[$23>>2]|0;
 $200 = (($7) + 4|0);
 $201 = ($199|0)<(0);
 if ($201) {
  HEAP32[$200>>2] = 0;
  $202 = (($7) + 8|0);
  HEAP32[$202>>2] = 0;
  label = 68;
 } else {
  $$idx21 = $199 << 1;
  $203 = $$idx21 >> 1;
  HEAP32[$200>>2] = $203;
  $204 = (($7) + 8|0);
  HEAP32[$204>>2] = $203;
  $205 = ($203|0)==(0);
  if ($205) {
   label = 68;
  } else {
   $206 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($7,$$idx21,478488,558)|0);
   $$pre$i$i = HEAP32[$200>>2]|0;
   HEAP32[$7>>2] = $206;
   $207 = (($206) + ($$pre$i$i<<1)|0);
   $208 = ($$pre$i$i|0)>(0);
   if ($208) {
    $$012$i$i$i = $206;$$03$i$i$i = $198;
    while(1) {
     $209 = ($$012$i$i$i|0)==(0|0);
     if (!($209)) {
      $210 = HEAP16[$$03$i$i$i>>1]|0;
      HEAP16[$$012$i$i$i>>1] = $210;
     }
     $211 = (($$012$i$i$i) + 2|0);
     $212 = (($$03$i$i$i) + 2|0);
     $213 = ($211>>>0)<($207>>>0);
     if ($213) {
      $$012$i$i$i = $211;$$03$i$i$i = $212;
     } else {
      $$pre$phiZ2D = $204;$215 = $206;$217 = $$pre$i$i;
      break;
     }
    }
   } else {
    $$pre$phiZ2D = $204;$215 = $206;$217 = $$pre$i$i;
   }
  }
 }
 if ((label|0) == 68) {
  HEAP32[$7>>2] = 0;
  $$pre54 = (($7) + 8|0);
  $$pre$phiZ2D = $$pre54;$215 = 0;$217 = 0;
 }
 $214 = HEAP32[$22>>2]|0;
 HEAP32[$7>>2] = $214;
 HEAP32[$22>>2] = $215;
 $216 = HEAP32[$23>>2]|0;
 HEAP32[$200>>2] = $216;
 HEAP32[$23>>2] = $217;
 $218 = HEAP32[$$pre$phiZ2D>>2]|0;
 $219 = HEAP32[$24>>2]|0;
 HEAP32[$$pre$phiZ2D>>2] = $219;
 HEAP32[$24>>2] = $218;
 $220 = $219 & 2147483647;
 $221 = ($220|0)!=(0);
 $222 = ($219|0)>(-1);
 $or$cond$i$i = $221 & $222;
 if ($or$cond$i$i) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$214);
 }
 $223 = (($anchors) + 4|0);
 $224 = HEAP32[$223>>2]|0;
 $225 = HEAP32[$anchors>>2]|0;
 $226 = $224;
 $227 = $225;
 $228 = (($226) - ($227))|0;
 $229 = $228 >> 2;
 $230 = (($229) + 2)|0;
 $231 = HEAP32[$27>>2]|0;
 $232 = $231 & 2147483647;
 $233 = ($232>>>0)<($230>>>0);
 if ($233) {
  __ZN5physx6shdfnd5ArrayINS_5cloth8SwTetherENS0_9AllocatorEE8recreateEj($25,$230);
 }
 $234 = ($225>>>0)<($224>>>0);
 if ($234) {
  $235 = (($8) + 4|0);
  $$promoted = HEAP32[$tetherLengths>>2]|0;
  $237 = $225;$240 = $$promoted;
  while(1) {
   $236 = HEAP32[$237>>2]|0;
   $238 = $236&65535;
   $239 = Math_fround(HEAPF32[$240>>2]);
   HEAP16[$8>>1] = $238;
   HEAPF32[$235>>2] = $239;
   $241 = HEAP32[$27>>2]|0;
   $242 = $241 & 2147483647;
   $243 = HEAP32[$26>>2]|0;
   $244 = ($242>>>0)>($243>>>0);
   if ($244) {
    $245 = HEAP32[$25>>2]|0;
    $246 = (($245) + ($243<<3)|0);
    $247 = ($246|0)==(0|0);
    if ($247) {
     $259 = $243;
    } else {
     $248 = $8;
     $249 = $248;
     $250 = HEAP32[$249>>2]|0;
     $251 = (($248) + 4)|0;
     $252 = $251;
     $253 = HEAP32[$252>>2]|0;
     $254 = $246;
     $255 = $254;
     HEAP32[$255>>2] = $250;
     $256 = (($254) + 4)|0;
     $257 = $256;
     HEAP32[$257>>2] = $253;
     $$pre$i1 = HEAP32[$26>>2]|0;
     $259 = $$pre$i1;
    }
    $258 = (($259) + 1)|0;
    HEAP32[$26>>2] = $258;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_5cloth8SwTetherENS0_9AllocatorEE15growAndPushBackERKS3_($25,$8)|0);
   }
   $260 = (($237) + 4|0);
   $261 = (($240) + 4|0);
   $262 = ($260>>>0)<($224>>>0);
   if ($262) {
    $237 = $260;$240 = $261;
   } else {
    break;
   }
  }
  HEAP32[$tetherLengths>>2] = $261;
  HEAP32[$anchors>>2] = $260;
 }
 $263 = HEAP32[$12>>2]|0;
 $264 = (($263) + 12|0);
 HEAP32[$9>>2] = $this;
 $265 = (($263) + 20|0);
 $266 = HEAP32[$265>>2]|0;
 $267 = $266 & 2147483647;
 $268 = (($263) + 16|0);
 $269 = HEAP32[$268>>2]|0;
 $270 = ($267>>>0)>($269>>>0);
 if (!($270)) {
  (__ZN5physx6shdfnd5ArrayIPNS_5cloth8SwFabricENS0_9AllocatorEE15growAndPushBackERKS4_($264,$9)|0);
  STACKTOP = sp;return;
 }
 $271 = HEAP32[$264>>2]|0;
 $272 = (($271) + ($269<<2)|0);
 $273 = ($272|0)==(0|0);
 if (!($273)) {
  HEAP32[$272>>2] = $this;
 }
 $274 = (($269) + 1)|0;
 HEAP32[$268>>2] = $274;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwFabricD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx5cloth8SwFabricD2Ev($this);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth8SwFabricD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth8SwFabricD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwFabricD2Ev($this) {
 $this = $this|0;
 var $$idx = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0$lcssa$i = 0;
 var $index$01$i = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i3 = 0, $or$cond$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478384 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((478384 + 60|0));
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 $$phi$trans$insert$i = (($2) + 12|0);
 $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 L1: do {
  if ($5) {
   $index$0$lcssa$i = 0;
  } else {
   $index$01$i = 0;
   while(1) {
    $8 = (($$pre$i) + ($index$01$i<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==($this|0);
    $7 = (($index$01$i) + 1)|0;
    if ($10) {
     $index$0$lcssa$i = $index$01$i;
     break L1;
    }
    $6 = ($7>>>0)<($4>>>0);
    if ($6) {
     $index$01$i = $7;
    } else {
     $index$0$lcssa$i = $7;
     break;
    }
   }
  }
 } while(0);
 $$idx = $index$0$lcssa$i << 2;
 $11 = $$idx >> 2;
 $12 = (($4) + -1)|0;
 HEAP32[$3>>2] = $12;
 $13 = (($$pre$i) + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($$pre$i) + ($11<<2)|0);
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 68|0);
 $17 = (($this) + 76|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i1 = $20 & $21;
 if ($or$cond$i$i1) {
  $22 = HEAP32[$16>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($16,$22);
 }
 $23 = (($this) + 56|0);
 $24 = (($this) + 64|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i2 = $27 & $28;
 if ($or$cond$i$i2) {
  $29 = HEAP32[$23>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($23,$29);
 }
 $30 = (($this) + 44|0);
 $31 = (($this) + 52|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 & 2147483647;
 $34 = ($33|0)!=(0);
 $35 = ($32|0)>(-1);
 $or$cond$i$i3 = $34 & $35;
 if ($or$cond$i$i3) {
  $36 = HEAP32[$30>>2]|0;
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $38 = (($36) + -4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (0 - ($39))|0;
   $41 = (($36) + ($40)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($30,$41);
  }
 }
 $42 = (($this) + 32|0);
 $43 = (($this) + 40|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 & 2147483647;
 $46 = ($45|0)!=(0);
 $47 = ($44|0)>(-1);
 $or$cond$i$i4 = $46 & $47;
 if ($or$cond$i$i4) {
  $48 = HEAP32[$42>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($42,$48);
 }
 $49 = (($this) + 20|0);
 $50 = (($this) + 28|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = $51 & 2147483647;
 $53 = ($52|0)!=(0);
 $54 = ($51|0)>(-1);
 $or$cond$i$i = $53 & $54;
 if (!($or$cond$i$i)) {
  HEAP32[$0>>2] = ((478584 + 8|0));
  HEAP32[$this>>2] = ((478568 + 8|0));
  __ZN5physx5cloth10deallocateEPv($this);
  STACKTOP = sp;return;
 }
 $55 = HEAP32[$49>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($49,$55);
 HEAP32[$0>>2] = ((478584 + 8|0));
 HEAP32[$this>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($this);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth8SwFabricD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth8SwFabricD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth8SwFabric10getFactoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 STACKTOP = sp;return ($2|0);
}
function __ZThn4_NK5physx5cloth8SwFabric10getFactoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx5cloth8SwFabric12getNumPhasesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth8SwFabric12getNumPhasesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx5cloth8SwFabric16getNumRestvaluesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth8SwFabric16getNumRestvaluesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx5cloth8SwFabric10getNumSetsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 STACKTOP = sp;return ($2|0);
}
function __ZThn4_NK5physx5cloth8SwFabric10getNumSetsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx5cloth8SwFabric13getNumIndicesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 1;
 STACKTOP = sp;return ($2|0);
}
function __ZThn4_NK5physx5cloth8SwFabric13getNumIndicesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 1;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx5cloth8SwFabric15getNumParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth8SwFabric15getNumParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx5cloth8SwFabric13getNumTethersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth8SwFabric13getNumTethersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth8SwFabric15scaleRestvaluesEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $rIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $rIt$01 = $1;
 }
 while(1) {
  $6 = Math_fround(HEAPF32[$rIt$01>>2]);
  $7 = Math_fround($6 * $scale);
  HEAPF32[$rIt$01>>2] = $7;
  $8 = (($rIt$01) + 4|0);
  $9 = ($8|0)==($4|0);
  if ($9) {
   break;
  } else {
   $rIt$01 = $8;
  }
 }
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth8SwFabric15scaleRestvaluesEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $rIt$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $rIt$01$i = $1;
 }
 while(1) {
  $6 = Math_fround(HEAPF32[$rIt$01$i>>2]);
  $7 = Math_fround($6 * $scale);
  HEAPF32[$rIt$01$i>>2] = $7;
  $8 = (($rIt$01$i) + 4|0);
  $9 = ($8|0)==($4|0);
  if ($9) {
   break;
  } else {
   $rIt$01$i = $8;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwFabric18scaleTetherLengthsEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = Math_fround(0), $2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * $scale);
 HEAPF32[$0>>2] = $2;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth8SwFabric18scaleTetherLengthsEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = Math_fround(0), $2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * $scale);
 HEAPF32[$0>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_5cloth8SwFabricENS0_9AllocatorEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,478488,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + ($9<<2)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    $15 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $15;
   }
   $16 = (($$012$i) + 4|0);
   $17 = (($$03$i) + 4|0);
   $18 = ($16>>>0)<($10>>>0);
   if ($18) {
    $$012$i = $16;$$03$i = $17;
   } else {
    break;
   }
  }
 }
 $19 = ($10|0)==(0|0);
 if (!($19)) {
  $20 = HEAP32[$a>>2]|0;
  HEAP32[$10>>2] = $20;
 }
 $21 = HEAP32[$0>>2]|0;
 $22 = ($21|0)>(-1);
 if (!($22)) {
  $25 = $9;
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $24 = (($25) + 1)|0;
  HEAP32[$8>>2] = $24;
  $26 = (($11) + ($25<<2)|0);
  STACKTOP = sp;return ($26|0);
 }
 $23 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$23);
 $$pre = HEAP32[$8>>2]|0;
 $25 = $$pre;
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $24 = (($25) + 1)|0;
 HEAP32[$8>>2] = $24;
 $26 = (($11) + ($25<<2)|0);
 STACKTOP = sp;return ($26|0);
}
function __ZN5physx6shdfnd5ArrayINS_5cloth8SwTetherENS0_9AllocatorEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,478488,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + ($9<<3)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    $15 = $$03$i;
    $16 = $15;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + 4)|0;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = $$012$i;
    $22 = $21;
    HEAP32[$22>>2] = $17;
    $23 = (($21) + 4)|0;
    $24 = $23;
    HEAP32[$24>>2] = $20;
   }
   $25 = (($$012$i) + 8|0);
   $26 = (($$03$i) + 8|0);
   $27 = ($25>>>0)<($10>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$8>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $9;
 }
 $28 = (($11) + ($29<<3)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  $31 = $a;
  $32 = $31;
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + 4)|0;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = $28;
  $38 = $37;
  HEAP32[$38>>2] = $33;
  $39 = (($37) + 4)|0;
  $40 = $39;
  HEAP32[$40>>2] = $36;
 }
 $41 = HEAP32[$0>>2]|0;
 $42 = ($41|0)>(-1);
 if (!($42)) {
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $44 = HEAP32[$8>>2]|0;
  $45 = (($44) + 1)|0;
  HEAP32[$8>>2] = $45;
  $46 = (($11) + ($44<<3)|0);
  STACKTOP = sp;return ($46|0);
 }
 $43 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$43);
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $44 = HEAP32[$8>>2]|0;
 $45 = (($44) + 1)|0;
 HEAP32[$8>>2] = $45;
 $46 = (($11) + ($44<<3)|0);
 STACKTOP = sp;return ($46|0);
}
function __ZN5physx6shdfnd5ArrayINS_5cloth8SwTetherENS0_9AllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$1,478488,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<3)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = $$03$i;
    $11 = $10;
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + 4)|0;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = $$012$i;
    $17 = $16;
    HEAP32[$17>>2] = $12;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP32[$19>>2] = $15;
   }
   $20 = (($$012$i) + 8|0);
   $21 = (($$03$i) + 8|0);
   $22 = ($20>>>0)<($5>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$26);
 HEAP32[$this>>2] = $6;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayItNS0_9AllocatorEE15growAndPushBackERKt($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = $$$i << 1;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,478488,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + ($9<<1)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    $15 = HEAP16[$$03$i>>1]|0;
    HEAP16[$$012$i>>1] = $15;
   }
   $16 = (($$012$i) + 2|0);
   $17 = (($$03$i) + 2|0);
   $18 = ($16>>>0)<($10>>>0);
   if ($18) {
    $$012$i = $16;$$03$i = $17;
   } else {
    break;
   }
  }
 }
 $19 = ($10|0)==(0|0);
 if (!($19)) {
  $20 = HEAP16[$a>>1]|0;
  HEAP16[$10>>1] = $20;
 }
 $21 = HEAP32[$0>>2]|0;
 $22 = ($21|0)>(-1);
 if (!($22)) {
  $25 = $9;
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $24 = (($25) + 1)|0;
  HEAP32[$8>>2] = $24;
  $26 = (($11) + ($25<<1)|0);
  STACKTOP = sp;return ($26|0);
 }
 $23 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$23);
 $$pre = HEAP32[$8>>2]|0;
 $25 = $$pre;
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $24 = (($25) + 1)|0;
 HEAP32[$8>>2] = $24;
 $26 = (($11) + ($25<<1)|0);
 STACKTOP = sp;return ($26|0);
}
function __ZN5physx6shdfnd5ArrayIfNS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE15growAndPushBackERKf($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $20 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($6) + 19)|0;
  $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$7,478488,558)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $20 = 0;
  } else {
   $10 = (($8) + 19|0);
   $11 = $10;
   $12 = $11 & -16;
   $13 = $8;
   $14 = (($12) - ($13))|0;
   $15 = $12;
   $16 = (($15) + -4|0);
   HEAP32[$16>>2] = $14;
   $phitmp$i = $12;
   $20 = $phitmp$i;
  }
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<2)|0);
 $21 = ($18|0)>(0);
 if ($21) {
  $22 = HEAP32[$this>>2]|0;
  $$012$i = $20;$$03$i = $22;
  while(1) {
   $23 = ($$012$i|0)==(0|0);
   if (!($23)) {
    $24 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $24;
   }
   $25 = (($$012$i) + 4|0);
   $26 = (($$03$i) + 4|0);
   $27 = ($25>>>0)<($19>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
 }
 $28 = ($19|0)==(0|0);
 if (!($28)) {
  $29 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$19>>2] = $29;
 }
 $30 = HEAP32[$0>>2]|0;
 $31 = ($30|0)>(-1);
 if ($31) {
  $32 = HEAP32[$this>>2]|0;
  $33 = ($32|0)==(0|0);
  if ($33) {
   $39 = $18;
  } else {
   $34 = (($32) + -4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (0 - ($35))|0;
   $37 = (($32) + ($36)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$37);
   $$pre = HEAP32[$17>>2]|0;
   $39 = $$pre;
  }
 } else {
  $39 = $18;
 }
 HEAP32[$this>>2] = $20;
 HEAP32[$0>>2] = $$$i;
 $38 = (($39) + 1)|0;
 HEAP32[$17>>2] = $38;
 $40 = (($20) + ($39<<2)|0);
 STACKTOP = sp;return ($40|0);
}
function __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE15growAndPushBackERKj($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,478488,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + ($9<<2)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    $15 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $15;
   }
   $16 = (($$012$i) + 4|0);
   $17 = (($$03$i) + 4|0);
   $18 = ($16>>>0)<($10>>>0);
   if ($18) {
    $$012$i = $16;$$03$i = $17;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$8>>2]|0;
  $20 = $$pre;
 } else {
  $20 = $9;
 }
 $19 = (($11) + ($20<<2)|0);
 $21 = ($19|0)==(0|0);
 if (!($21)) {
  $22 = HEAP32[$a>>2]|0;
  HEAP32[$19>>2] = $22;
 }
 $23 = HEAP32[$0>>2]|0;
 $24 = ($23|0)>(-1);
 if (!($24)) {
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $26 = HEAP32[$8>>2]|0;
  $27 = (($26) + 1)|0;
  HEAP32[$8>>2] = $27;
  $28 = (($11) + ($26<<2)|0);
  STACKTOP = sp;return ($28|0);
 }
 $25 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$25);
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $26 = HEAP32[$8>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$8>>2] = $27;
 $28 = (($11) + ($26<<2)|0);
 STACKTOP = sp;return ($28|0);
}
function __ZN5physx5cloth13UserAllocatedD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth13UserAllocatedD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth6FabricD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478584 + 8|0));
 STACKTOP = sp;return;
}
function __ZN5physx5cloth6FabricD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478584 + 8|0));
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9SwFactoryC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 HEAP32[$this>>2] = ((478640 + 8|0));
 HEAP32[$0>>2] = ((478640 + 88|0));
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9SwFactoryD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478640 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((478640 + 88|0));
 $1 = (($this) + 12|0);
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4|0)!=(0);
 $6 = ($3|0)>(-1);
 $or$cond$i$i$i = $5 & $6;
 if ($or$cond$i$i$i) {
  $7 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
 }
 HEAP32[$this>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($this);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9SwFactoryD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = (((478640 + 8|0)));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = (((478640 + 88|0)));
 $2 = (($0) + 12|0);
 $3 = (($0) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = ($5|0)!=(0);
 $7 = ($4|0)>(-1);
 $or$cond$i$i$i$i = $6 & $7;
 if ($or$cond$i$i$i$i) {
  $8 = HEAP32[$2>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$8);
 }
 HEAP32[$0>>2] = (((478568 + 8|0)));
 __ZN5physx5cloth10deallocateEPv($0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9SwFactoryD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478640 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((478640 + 88|0));
 $1 = (($this) + 12|0);
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4|0)!=(0);
 $6 = ($3|0)>(-1);
 $or$cond$i$i = $5 & $6;
 if ($or$cond$i$i) {
  $7 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
 }
 HEAP32[$this>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($this);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9SwFactoryD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = (((478640 + 8|0)));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = (((478640 + 88|0)));
 $2 = (($0) + 12|0);
 $3 = (($0) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = ($5|0)!=(0);
 $7 = ($4|0)>(-1);
 $or$cond$i$i$i = $6 & $7;
 if ($or$cond$i$i$i) {
  $8 = HEAP32[$2>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$8);
 }
 HEAP32[$0>>2] = (((478568 + 8|0)));
 __ZN5physx5cloth10deallocateEPv($0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9SwFactory12createFabricEjNS0_5RangeIKjEES4_NS2_IKfEES4_S4_S6_($this,$numParticles,$phases,$sets,$restvalues,$indices,$anchors,$tetherLengths) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $phases = $phases|0;
 $sets = $sets|0;
 $restvalues = $restvalues|0;
 $indices = $indices|0;
 $anchors = $anchors|0;
 $tetherLengths = $tetherLengths|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, $tmpcast2$byval_copy = 0, $tmpcast3$byval_copy = 0, $tmpcast4$byval_copy = 0, $tmpcast5$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmpcast5$byval_copy = sp + 80|0;
 $tmpcast4$byval_copy = sp + 72|0;
 $tmpcast3$byval_copy = sp + 64|0;
 $tmpcast2$byval_copy = sp + 56|0;
 $tmpcast1$byval_copy = sp + 48|0;
 $tmpcast$byval_copy = sp + 88|0;
 $0 = sp + 40|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 $5 = sp + 32|0;
 $6 = (__ZN5physx5cloth8allocateEj(96)|0);
 $7 = $phases;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $0;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = $sets;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $1;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 $27 = $restvalues;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + 4)|0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = $2;
 $34 = $33;
 HEAP32[$34>>2] = $29;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $32;
 $37 = $indices;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) + 4)|0;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = $3;
 $44 = $43;
 HEAP32[$44>>2] = $39;
 $45 = (($43) + 4)|0;
 $46 = $45;
 HEAP32[$46>>2] = $42;
 $47 = $anchors;
 $48 = $47;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($47) + 4)|0;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = $4;
 $54 = $53;
 HEAP32[$54>>2] = $49;
 $55 = (($53) + 4)|0;
 $56 = $55;
 HEAP32[$56>>2] = $52;
 $57 = $tetherLengths;
 $58 = $57;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 4)|0;
 $61 = $60;
 $62 = HEAP32[$61>>2]|0;
 $63 = $5;
 $64 = $63;
 HEAP32[$64>>2] = $59;
 $65 = (($63) + 4)|0;
 $66 = $65;
 HEAP32[$66>>2] = $62;
 $67 = (__ZN5physx5cloth15getNextFabricIdEv()|0);
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$tmpcast3$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast3$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
 __ZN5physx5cloth8SwFabricC2ERNS0_9SwFactoryEjNS0_5RangeIKjEES6_NS4_IKfEES6_S6_S8_j($6,$this,$numParticles,$tmpcast$byval_copy,$tmpcast1$byval_copy,$tmpcast2$byval_copy,$tmpcast3$byval_copy,$tmpcast4$byval_copy,$tmpcast5$byval_copy,$67);
 $68 = ($6|0)==(0|0);
 if ($68) {
  $70 = 0;
  STACKTOP = sp;return ($70|0);
 }
 $69 = (($6) + 4|0);
 $70 = $69;
 STACKTOP = sp;return ($70|0);
}
function __ZThn4_N5physx5cloth9SwFactory12createFabricEjNS0_5RangeIKjEES4_NS2_IKfEES4_S4_S6_($this,$numParticles,$phases,$sets,$restvalues,$indices,$anchors,$tetherLengths) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $phases = $phases|0;
 $sets = $sets|0;
 $restvalues = $restvalues|0;
 $indices = $indices|0;
 $anchors = $anchors|0;
 $tetherLengths = $tetherLengths|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $tmpcast$i$byval_copy = 0, $tmpcast1$i$byval_copy = 0, $tmpcast2$i$byval_copy = 0, $tmpcast3$i$byval_copy = 0, $tmpcast4$i$byval_copy = 0, $tmpcast5$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmpcast5$i$byval_copy = sp + 80|0;
 $tmpcast4$i$byval_copy = sp + 72|0;
 $tmpcast3$i$byval_copy = sp + 64|0;
 $tmpcast2$i$byval_copy = sp + 56|0;
 $tmpcast1$i$byval_copy = sp + 48|0;
 $tmpcast$i$byval_copy = sp + 88|0;
 $0 = sp + 40|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 $5 = sp + 32|0;
 $6 = (($this) + -4|0);
 $7 = $phases;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $sets;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $restvalues;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $indices;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $anchors;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $tetherLengths;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) + 4)|0;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = (__ZN5physx5cloth8allocateEj(96)|0);
 $44 = $0;
 $45 = $44;
 HEAP32[$45>>2] = $9;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $12;
 $48 = $1;
 $49 = $48;
 HEAP32[$49>>2] = $15;
 $50 = (($48) + 4)|0;
 $51 = $50;
 HEAP32[$51>>2] = $18;
 $52 = $2;
 $53 = $52;
 HEAP32[$53>>2] = $21;
 $54 = (($52) + 4)|0;
 $55 = $54;
 HEAP32[$55>>2] = $24;
 $56 = $3;
 $57 = $56;
 HEAP32[$57>>2] = $27;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = $30;
 $60 = $4;
 $61 = $60;
 HEAP32[$61>>2] = $33;
 $62 = (($60) + 4)|0;
 $63 = $62;
 HEAP32[$63>>2] = $36;
 $64 = $5;
 $65 = $64;
 HEAP32[$65>>2] = $39;
 $66 = (($64) + 4)|0;
 $67 = $66;
 HEAP32[$67>>2] = $42;
 $68 = (__ZN5physx5cloth15getNextFabricIdEv()|0);
 ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$tmpcast2$i$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast2$i$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$tmpcast3$i$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast3$i$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 ;HEAP32[$tmpcast4$i$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast4$i$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
 ;HEAP32[$tmpcast5$i$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast5$i$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
 __ZN5physx5cloth8SwFabricC2ERNS0_9SwFactoryEjNS0_5RangeIKjEES6_NS4_IKfEES6_S6_S8_j($43,$6,$numParticles,$tmpcast$i$byval_copy,$tmpcast1$i$byval_copy,$tmpcast2$i$byval_copy,$tmpcast3$i$byval_copy,$tmpcast4$i$byval_copy,$tmpcast5$i$byval_copy,$68);
 $69 = ($43|0)==(0|0);
 if ($69) {
  $71 = 0;
  STACKTOP = sp;return ($71|0);
 }
 $70 = (($43) + 4|0);
 $71 = $70;
 STACKTOP = sp;return ($71|0);
}
function __ZN5physx5cloth9SwFactory11createClothENS0_5RangeIKNS_6PxVec4EEERNS0_6FabricE($this,$particles,$fabric) {
 $this = $this|0;
 $particles = $particles|0;
 $fabric = $fabric|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$i$i$byval_copy = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$i$i$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (__ZN5physx5cloth8allocateEj(560)|0);
 $2 = (($this) + 4|0);
 $3 = $particles;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($1) + 4|0);
 HEAP32[$1>>2] = ((478800 + 8|0));
 HEAP32[$9>>2] = ((478800 + 424|0));
 $10 = (($1) + 16|0);
 $11 = (($2) + -4|0);
 $12 = (($fabric) + -4|0);
 $13 = $0;
 $14 = $13;
 HEAP32[$14>>2] = $5;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $8;
 ;HEAP32[$tmpcast$i$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN5physx5cloth7SwClothC2ERNS0_9SwFactoryERNS0_8SwFabricENS0_5RangeIKNS_6PxVec4EEE($10,$11,$12,$tmpcast$i$i$byval_copy);
 $17 = ($1|0)==(0|0);
 if ($17) {
  $18 = 0;
  STACKTOP = sp;return ($18|0);
 }
 $18 = $9;
 STACKTOP = sp;return ($18|0);
}
function __ZThn4_N5physx5cloth9SwFactory11createClothENS0_5RangeIKNS_6PxVec4EEERNS0_6FabricE($this,$particles,$fabric) {
 $this = $this|0;
 $particles = $particles|0;
 $fabric = $fabric|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$i$i$i$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$i$i$i$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + -4|0);
 $2 = $particles;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN5physx5cloth8allocateEj(560)|0);
 $9 = (($8) + 4|0);
 HEAP32[$8>>2] = ((478800 + 8|0));
 HEAP32[$9>>2] = ((478800 + 424|0));
 $10 = (($8) + 16|0);
 $11 = (($fabric) + -4|0);
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $4;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $7;
 ;HEAP32[$tmpcast$i$i$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$i$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN5physx5cloth7SwClothC2ERNS0_9SwFactoryERNS0_8SwFabricENS0_5RangeIKNS_6PxVec4EEE($10,$1,$11,$tmpcast$i$i$i$byval_copy);
 $16 = ($8|0)==(0|0);
 if ($16) {
  $17 = 0;
  STACKTOP = sp;return ($17|0);
 }
 $17 = $9;
 STACKTOP = sp;return ($17|0);
}
function __ZN5physx5cloth9SwFactory12createSolverEPNS_13PxProfileZoneEPNS_13PxTaskManagerE($this,$profiler,$taskMgr) {
 $this = $this|0;
 $profiler = $profiler|0;
 $taskMgr = $taskMgr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx5cloth8allocateEj(116)|0);
 __ZN5physx5cloth8SwSolverC2EPNS_13PxProfileZoneEPNS_13PxTaskManagerE($0,$profiler,$taskMgr);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $3 = 0;
  STACKTOP = sp;return ($3|0);
 }
 $2 = (($0) + 4|0);
 $3 = $2;
 STACKTOP = sp;return ($3|0);
}
function __ZThn4_N5physx5cloth9SwFactory12createSolverEPNS_13PxProfileZoneEPNS_13PxTaskManagerE($this,$profiler,$taskMgr) {
 $this = $this|0;
 $profiler = $profiler|0;
 $taskMgr = $taskMgr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx5cloth8allocateEj(116)|0);
 __ZN5physx5cloth8SwSolverC2EPNS_13PxProfileZoneEPNS_13PxTaskManagerE($0,$profiler,$taskMgr);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $3 = 0;
  STACKTOP = sp;return ($3|0);
 }
 $2 = (($0) + 4|0);
 $3 = $2;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx5cloth9SwFactory5cloneERKNS0_5ClothE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cloth>>2]|0;
 $1 = (($0) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($cloth)|0);
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = HEAP32[$cloth>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 4|0);
  $11 = (FUNCTION_TABLE_iii[$9 & 4095]($cloth,$10)|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (__ZN5physx5cloth8allocateEj(560)|0);
 $13 = (($this) + 4|0);
 $14 = (($12) + 4|0);
 HEAP32[$12>>2] = ((478800 + 8|0));
 HEAP32[$14>>2] = ((478800 + 424|0));
 $15 = (($12) + 16|0);
 $16 = (($13) + -4|0);
 $17 = (($cloth) + 12|0);
 __ZN5physx5cloth7SwClothC2ERNS0_9SwFactoryERKS1_($15,$16,$17);
 $18 = ($12|0)==(0|0);
 if ($18) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZThn4_N5physx5cloth9SwFactory5cloneERKNS0_5ClothE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = HEAP32[$cloth>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($cloth)|0);
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = HEAP32[$cloth>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($0) + 4|0);
  $12 = (FUNCTION_TABLE_iii[$10 & 4095]($cloth,$11)|0);
  $$0$i = $12;
  STACKTOP = sp;return ($$0$i|0);
 }
 $13 = (__ZN5physx5cloth8allocateEj(560)|0);
 $14 = (($13) + 4|0);
 HEAP32[$13>>2] = ((478800 + 8|0));
 HEAP32[$14>>2] = ((478800 + 424|0));
 $15 = (($13) + 16|0);
 $16 = (($cloth) + 12|0);
 __ZN5physx5cloth7SwClothC2ERNS0_9SwFactoryERKS1_($15,$0,$16);
 $17 = ($13|0)==(0|0);
 if ($17) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $$0$i = $14;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK5physx5cloth9SwFactory10copyToHostEPKvS3_Pv($this,$srcIt,$srcEnd,$dstIt) {
 $this = $this|0;
 $srcIt = $srcIt|0;
 $srcEnd = $srcEnd|0;
 $dstIt = $dstIt|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $srcEnd;
 $1 = $srcIt;
 $2 = (($0) - ($1))|0;
 _memcpy(($dstIt|0),($srcIt|0),($2|0))|0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory10copyToHostEPKvS3_Pv($this,$srcIt,$srcEnd,$dstIt) {
 $this = $this|0;
 $srcIt = $srcIt|0;
 $srcEnd = $srcEnd|0;
 $dstIt = $dstIt|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $srcEnd;
 $1 = $srcIt;
 $2 = (($0) - ($1))|0;
 _memcpy(($dstIt|0),($srcIt|0),($2|0))|0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory12copyFromHostEPKvS3_Pv($this,$srcIt,$srcEnd,$dstIt) {
 $this = $this|0;
 $srcIt = $srcIt|0;
 $srcEnd = $srcEnd|0;
 $dstIt = $dstIt|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$2 & 511]($this,$srcIt,$srcEnd,$dstIt);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory12copyFromHostEPKvS3_Pv($this,$srcIt,$srcEnd,$dstIt) {
 $this = $this|0;
 $srcIt = $srcIt|0;
 $srcEnd = $srcEnd|0;
 $dstIt = $dstIt|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($0,$srcIt,$srcEnd,$dstIt);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory10copyToHostEPKvS3_PvP11CUstream_st($this,$srcIt,$srcEnd,$dstIt,$0) {
 $this = $this|0;
 $srcIt = $srcIt|0;
 $srcEnd = $srcEnd|0;
 $dstIt = $dstIt|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($this,$srcIt,$srcEnd,$dstIt);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory10copyToHostEPKvS3_PvP11CUstream_st($this,$srcIt,$srcEnd,$dstIt,$0) {
 $this = $this|0;
 $srcIt = $srcIt|0;
 $srcEnd = $srcEnd|0;
 $dstIt = $dstIt|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + -4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiii[$4 & 511]($1,$srcIt,$srcEnd,$dstIt);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory12copyFromHostEPKvS3_PvP11CUstream_st($this,$srcIt,$srcEnd,$dstIt,$0) {
 $this = $this|0;
 $srcIt = $srcIt|0;
 $srcEnd = $srcEnd|0;
 $dstIt = $dstIt|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($this,$srcIt,$srcEnd,$dstIt);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory12copyFromHostEPKvS3_PvP11CUstream_st($this,$srcIt,$srcEnd,$dstIt,$0) {
 $this = $this|0;
 $srcIt = $srcIt|0;
 $srcEnd = $srcEnd|0;
 $dstIt = $dstIt|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + -4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiii[$4 & 511]($1,$srcIt,$srcEnd,$dstIt);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory17extractFabricDataERKNS0_6FabricENS0_5RangeIjEES6_NS5_IfEES6_S6_S7_($this,$fabric,$phases,$sets,$restvalues,$indices,$anchors,$tetherLengths) {
 $this = $this|0;
 $fabric = $fabric|0;
 $phases = $phases|0;
 $sets = $sets|0;
 $restvalues = $restvalues|0;
 $indices = $indices|0;
 $anchors = $anchors|0;
 $tetherLengths = $tetherLengths|0;
 var $$numConstraints$110 = 0, $$pre = 0, $$pre84 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$031 = 0, $i2$03 = 0, $i3$01 = 0, $iDst$0 = 0, $iDst$0$ph = 0, $iDst$1$lcssa = 0, $iDst$19$us$us = 0, $iDst$19$us21 = 0;
 var $iDst$3$us$us = 0, $iDst$3$us27 = 0, $iIt$0 = 0, $iIt$0$ph = 0, $iIt$1$lcssa = 0, $iIt$17 = 0, $iIt$17$us = 0, $iIt$17$us$us = 0, $iIt$17$us23 = 0, $numConstraints$0 = 0, $numConstraints$0$ph = 0, $numConstraints$1$lcssa = 0, $numConstraints$110 = 0, $numConstraints$110$us = 0, $numConstraints$110$us$us = 0, $numConstraints$110$us20 = 0, $numConstraints$2$us = 0, $numConstraints$2$us$us = 0, $numConstraints$2$us28 = 0, $rDst$0 = 0;
 var $rDst$0$ph = 0, $rDst$1$lcssa = 0, $rDst$18$us = 0, $rDst$18$us$us = 0, $rDst$3$us = 0, $rDst$3$us$us = 0, $rIt$0 = 0, $rIt$0$ph = 0, $rIt$043 = 0, $rIt$1$lcssa = 0, $rIt$111 = 0, $rIt$111$us = 0, $rIt$111$us$us = 0, $rIt$111$us19 = 0, $sDst$0$ph = 0, $sIt$0 = 0, $sIt$0$ph = 0, $scevgep$sum$pn$pn = 0, $scevgep40$sum89 = 0, $scevgep46$sum$pn$pn = 0;
 var $scevgep46$sum$pn$pn$in = 0, $scevgep74 = 0, $split = 0, $split15 = 0, $split16 = 0, $split17 = 0, $split18 = 0, $uglygep76 = 0, $uglygep7677 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($fabric) + -4|0);
 $1 = HEAP32[$phases>>2]|0;
 $2 = (($phases) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  $5 = (($0) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $9 = $1;$i$031 = 0;
  while(1) {
   $7 = (($6) + ($i$031<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$9>>2] = $8;
   $10 = (($i$031) + 1)|0;
   $11 = (($9) + 4|0);
   $12 = ($11>>>0)<($3>>>0);
   if ($12) {
    $9 = $11;$i$031 = $10;
   } else {
    break;
   }
  }
  HEAP32[$phases>>2] = $11;
 }
 $13 = (($0) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($0) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + ($16<<2)|0);
 $18 = (($0) + 44|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($0) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$sets>>2]|0;
 $23 = HEAP32[$restvalues>>2]|0;
 $24 = HEAP32[$indices>>2]|0;
 $25 = (($sets) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($22>>>0)<($26>>>0);
 $28 = (($0) + 16|0);
 $29 = (($restvalues) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($23>>>0)<($30>>>0);
 $32 = (($indices) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($24>>>0)<($33>>>0);
 $iDst$0$ph = $24;$iIt$0$ph = $21;$numConstraints$0$ph = 0;$rDst$0$ph = $23;$rIt$0$ph = $19;$sDst$0$ph = $22;$sIt$0$ph = $14;
 L7: while(1) {
  $iDst$0 = $iDst$0$ph;$iIt$0 = $iIt$0$ph;$numConstraints$0 = $numConstraints$0$ph;$rDst$0 = $rDst$0$ph;$rIt$0 = $rIt$0$ph;$sIt$0 = $sIt$0$ph;
  while(1) {
   $rIt$043 = $rIt$0;
   $35 = (($sIt$0) + 4|0);
   $36 = ($35|0)==($17|0);
   if ($36) {
    break L7;
   }
   $43 = HEAP32[$35>>2]|0;
   $44 = (($19) + ($43<<2)|0);
   $45 = ($rIt$0|0)==($44|0);
   if ($45) {
    $iDst$1$lcssa = $iDst$0;$iIt$1$lcssa = $iIt$0;$numConstraints$1$lcssa = $numConstraints$0;$rDst$1$lcssa = $rDst$0;$rIt$1$lcssa = $rIt$0;
   } else {
    $scevgep40$sum89 = (($43) + -1)|0;
    $scevgep74 = (($19) + ($scevgep40$sum89<<2)|0);
    $46 = (0 - ($rIt$043))|0;
    $uglygep76 = (($scevgep74) + ($46)|0);
    $uglygep7677 = $uglygep76;
    $47 = $uglygep7677 >>> 2;
    L14: do {
     if ($31) {
      if ($34) {
       $iDst$19$us$us = $iDst$0;$iIt$17$us$us = $iIt$0;$numConstraints$110$us$us = $numConstraints$0;$rDst$18$us$us = $rDst$0;$rIt$111$us$us = $rIt$0;
       while(1) {
        $48 = (($iIt$17$us$us) + 2|0);
        $49 = HEAP16[$iIt$17$us$us>>1]|0;
        $50 = (($iIt$17$us$us) + 4|0);
        $51 = HEAP16[$48>>1]|0;
        $52 = ($49&65535)<($51&65535);
        $53 = $52 ? $51 : $49;
        $54 = $53&65535;
        $55 = HEAP32[$28>>2]|0;
        $56 = ($54>>>0)<($55>>>0);
        if ($56) {
         $57 = Math_fround(HEAPF32[$rIt$111$us$us>>2]);
         $58 = (($rDst$18$us$us) + 4|0);
         HEAPF32[$rDst$18$us$us>>2] = $57;
         $59 = $49&65535;
         $60 = (($iDst$19$us$us) + 4|0);
         HEAP32[$iDst$19$us$us>>2] = $59;
         $61 = $51&65535;
         $62 = (($iDst$19$us$us) + 8|0);
         HEAP32[$60>>2] = $61;
         $63 = (($numConstraints$110$us$us) + 1)|0;
         $iDst$3$us$us = $62;$numConstraints$2$us$us = $63;$rDst$3$us$us = $58;
        } else {
         $iDst$3$us$us = $iDst$19$us$us;$numConstraints$2$us$us = $numConstraints$110$us$us;$rDst$3$us$us = $rDst$18$us$us;
        }
        $64 = (($rIt$111$us$us) + 4|0);
        $65 = ($64|0)==($44|0);
        if ($65) {
         $split15 = $numConstraints$2$us$us;$split16 = $iDst$3$us$us;$split17 = $rDst$3$us$us;
         break L14;
        } else {
         $iDst$19$us$us = $iDst$3$us$us;$iIt$17$us$us = $50;$numConstraints$110$us$us = $numConstraints$2$us$us;$rDst$18$us$us = $rDst$3$us$us;$rIt$111$us$us = $64;
        }
       }
      }
      $$pre = HEAP32[$28>>2]|0;
      $iIt$17$us = $iIt$0;$numConstraints$110$us = $numConstraints$0;$rDst$18$us = $rDst$0;$rIt$111$us = $rIt$0;
      while(1) {
       $66 = (($iIt$17$us) + 2|0);
       $67 = HEAP16[$iIt$17$us>>1]|0;
       $68 = (($iIt$17$us) + 4|0);
       $69 = HEAP16[$66>>1]|0;
       $70 = ($67&65535)<($69&65535);
       $71 = $70 ? $69 : $67;
       $72 = $71&65535;
       $73 = ($72>>>0)<($$pre>>>0);
       if ($73) {
        $74 = Math_fround(HEAPF32[$rIt$111$us>>2]);
        $75 = (($rDst$18$us) + 4|0);
        HEAPF32[$rDst$18$us>>2] = $74;
        $76 = (($numConstraints$110$us) + 1)|0;
        $numConstraints$2$us = $76;$rDst$3$us = $75;
       } else {
        $numConstraints$2$us = $numConstraints$110$us;$rDst$3$us = $rDst$18$us;
       }
       $77 = (($rIt$111$us) + 4|0);
       $78 = ($77|0)==($44|0);
       if ($78) {
        $split15 = $numConstraints$2$us;$split16 = $iDst$0;$split17 = $rDst$3$us;
        break;
       } else {
        $iIt$17$us = $68;$numConstraints$110$us = $numConstraints$2$us;$rDst$18$us = $rDst$3$us;$rIt$111$us = $77;
       }
      }
     } else {
      if ($34) {
       $iDst$19$us21 = $iDst$0;$iIt$17$us23 = $iIt$0;$numConstraints$110$us20 = $numConstraints$0;$rIt$111$us19 = $rIt$0;
      } else {
       $$pre84 = HEAP32[$28>>2]|0;
       $iIt$17 = $iIt$0;$numConstraints$110 = $numConstraints$0;$rIt$111 = $rIt$0;
       while(1) {
        $95 = (($iIt$17) + 2|0);
        $96 = HEAP16[$iIt$17>>1]|0;
        $97 = (($iIt$17) + 4|0);
        $98 = HEAP16[$95>>1]|0;
        $99 = ($96&65535)<($98&65535);
        $100 = $99 ? $98 : $96;
        $101 = $100&65535;
        $102 = ($101>>>0)<($$pre84>>>0);
        $103 = $102&1;
        $$numConstraints$110 = (($numConstraints$110) + ($103))|0;
        $104 = (($rIt$111) + 4|0);
        $105 = ($104|0)==($44|0);
        if ($105) {
         $split15 = $$numConstraints$110;$split16 = $iDst$0;$split17 = $rDst$0;
         break L14;
        } else {
         $iIt$17 = $97;$numConstraints$110 = $$numConstraints$110;$rIt$111 = $104;
        }
       }
      }
      while(1) {
       $79 = (($iIt$17$us23) + 2|0);
       $80 = HEAP16[$iIt$17$us23>>1]|0;
       $81 = (($iIt$17$us23) + 4|0);
       $82 = HEAP16[$79>>1]|0;
       $83 = ($80&65535)<($82&65535);
       $84 = $83 ? $82 : $80;
       $85 = $84&65535;
       $86 = HEAP32[$28>>2]|0;
       $87 = ($85>>>0)<($86>>>0);
       if ($87) {
        $88 = $80&65535;
        $89 = (($iDst$19$us21) + 4|0);
        HEAP32[$iDst$19$us21>>2] = $88;
        $90 = $82&65535;
        $91 = (($iDst$19$us21) + 8|0);
        HEAP32[$89>>2] = $90;
        $92 = (($numConstraints$110$us20) + 1)|0;
        $iDst$3$us27 = $91;$numConstraints$2$us28 = $92;
       } else {
        $iDst$3$us27 = $iDst$19$us21;$numConstraints$2$us28 = $numConstraints$110$us20;
       }
       $93 = (($rIt$111$us19) + 4|0);
       $94 = ($93|0)==($44|0);
       if ($94) {
        $split15 = $numConstraints$2$us28;$split16 = $iDst$3$us27;$split17 = $rDst$0;
        break;
       } else {
        $iDst$19$us21 = $iDst$3$us27;$iIt$17$us23 = $81;$numConstraints$110$us20 = $numConstraints$2$us28;$rIt$111$us19 = $93;
       }
      }
     }
    } while(0);
    $scevgep46$sum$pn$pn$in = $47 << 1;
    $scevgep46$sum$pn$pn = (($scevgep46$sum$pn$pn$in) + 2)|0;
    $split18 = (($iIt$0) + ($scevgep46$sum$pn$pn<<1)|0);
    $scevgep$sum$pn$pn = (($47) + 1)|0;
    $split = (($rIt$0) + ($scevgep$sum$pn$pn<<2)|0);
    $iDst$1$lcssa = $split16;$iIt$1$lcssa = $split18;$numConstraints$1$lcssa = $split15;$rDst$1$lcssa = $split17;$rIt$1$lcssa = $split;
   }
   if ($27) {
    break;
   } else {
    $iDst$0 = $iDst$1$lcssa;$iIt$0 = $iIt$1$lcssa;$numConstraints$0 = $numConstraints$1$lcssa;$rDst$0 = $rDst$1$lcssa;$rIt$0 = $rIt$1$lcssa;$sIt$0 = $35;
   }
  }
  $106 = (($sDst$0$ph) + 4|0);
  HEAP32[$sDst$0$ph>>2] = $numConstraints$1$lcssa;
  $iDst$0$ph = $iDst$1$lcssa;$iIt$0$ph = $iIt$1$lcssa;$numConstraints$0$ph = $numConstraints$1$lcssa;$rDst$0$ph = $rDst$1$lcssa;$rIt$0$ph = $rIt$1$lcssa;$sDst$0$ph = $106;$sIt$0$ph = $35;
 }
 $37 = HEAP32[$anchors>>2]|0;
 $38 = (($anchors) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($37>>>0)<($39>>>0);
 if ($40) {
  $41 = (($0) + 68|0);
  $42 = HEAP32[$41>>2]|0;
  $118 = $37;$i2$03 = 0;
  while(1) {
   $115 = (($42) + ($i2$03<<3)|0);
   $116 = HEAP16[$115>>1]|0;
   $117 = $116&65535;
   HEAP32[$118>>2] = $117;
   $119 = (($i2$03) + 1)|0;
   $107 = (($118) + 4|0);
   $120 = ($107>>>0)<($39>>>0);
   if ($120) {
    $118 = $107;$i2$03 = $119;
   } else {
    break;
   }
  }
  HEAP32[$anchors>>2] = $107;
 }
 $108 = HEAP32[$tetherLengths>>2]|0;
 $109 = (($tetherLengths) + 4|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = ($108>>>0)<($110>>>0);
 if (!($111)) {
  STACKTOP = sp;return;
 }
 $112 = (($0) + 68|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($0) + 80|0);
 $125 = $108;$i3$01 = 0;
 while(1) {
  $121 = ((($113) + ($i3$01<<3)|0) + 4|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround(HEAPF32[$114>>2]);
  $124 = Math_fround($122 * $123);
  HEAPF32[$125>>2] = $124;
  $126 = (($i3$01) + 1)|0;
  $127 = (($125) + 4|0);
  $128 = ($127>>>0)<($110>>>0);
  if ($128) {
   $125 = $127;$i3$01 = $126;
  } else {
   break;
  }
 }
 HEAP32[$tetherLengths>>2] = $127;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory17extractFabricDataERKNS0_6FabricENS0_5RangeIjEES6_NS5_IfEES6_S6_S7_($this,$fabric,$phases,$sets,$restvalues,$indices,$anchors,$tetherLengths) {
 $this = $this|0;
 $fabric = $fabric|0;
 $phases = $phases|0;
 $sets = $sets|0;
 $restvalues = $restvalues|0;
 $indices = $indices|0;
 $anchors = $anchors|0;
 $tetherLengths = $tetherLengths|0;
 var $anchors$byval_copy = 0, $indices$byval_copy = 0, $phases$byval_copy = 0, $restvalues$byval_copy = 0, $sets$byval_copy = 0, $tetherLengths$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tetherLengths$byval_copy = sp + 40|0;
 $anchors$byval_copy = sp;
 $indices$byval_copy = sp + 8|0;
 $restvalues$byval_copy = sp + 16|0;
 $sets$byval_copy = sp + 24|0;
 $phases$byval_copy = sp + 32|0;
 ;HEAP32[$phases$byval_copy+0>>2]=HEAP32[$phases+0>>2]|0;HEAP32[$phases$byval_copy+4>>2]=HEAP32[$phases+4>>2]|0;
 ;HEAP32[$sets$byval_copy+0>>2]=HEAP32[$sets+0>>2]|0;HEAP32[$sets$byval_copy+4>>2]=HEAP32[$sets+4>>2]|0;
 ;HEAP32[$restvalues$byval_copy+0>>2]=HEAP32[$restvalues+0>>2]|0;HEAP32[$restvalues$byval_copy+4>>2]=HEAP32[$restvalues+4>>2]|0;
 ;HEAP32[$indices$byval_copy+0>>2]=HEAP32[$indices+0>>2]|0;HEAP32[$indices$byval_copy+4>>2]=HEAP32[$indices+4>>2]|0;
 ;HEAP32[$anchors$byval_copy+0>>2]=HEAP32[$anchors+0>>2]|0;HEAP32[$anchors$byval_copy+4>>2]=HEAP32[$anchors+4>>2]|0;
 ;HEAP32[$tetherLengths$byval_copy+0>>2]=HEAP32[$tetherLengths+0>>2]|0;HEAP32[$tetherLengths$byval_copy+4>>2]=HEAP32[$tetherLengths+4>>2]|0;
 __ZNK5physx5cloth9SwFactory17extractFabricDataERKNS0_6FabricENS0_5RangeIjEES6_NS5_IfEES6_S6_S7_(0,$fabric,$phases$byval_copy,$sets$byval_copy,$restvalues$byval_copy,$indices$byval_copy,$anchors$byval_copy,$tetherLengths$byval_copy);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory20extractCollisionDataERKNS0_5ClothENS0_5RangeINS_6PxVec4EEENS5_IjEES7_S8_NS5_INS_6PxVec3EEE($this,$cloth,$spheres,$capsules,$planes,$convexes,$triangles) {
 $this = $this|0;
 $cloth = $cloth|0;
 $spheres = $spheres|0;
 $capsules = $capsules|0;
 $planes = $planes|0;
 $convexes = $convexes|0;
 $triangles = $triangles|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 368|0);
 $1 = (($cloth) + 372|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = HEAP32[$spheres>>2]|0;
  $5 = (($spheres) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4>>>0)<($6>>>0);
  if ($7) {
   $8 = HEAP32[$0>>2]|0;
   $9 = $2 << 4;
   _memcpy(($4|0),($8|0),($9|0))|0;
  }
 }
 $10 = (($cloth) + 356|0);
 $11 = (($cloth) + 360|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = HEAP32[$capsules>>2]|0;
  $15 = (($capsules) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)<($16>>>0);
  if ($17) {
   $18 = HEAP32[$10>>2]|0;
   $19 = $12 << 3;
   _memcpy(($14|0),($18|0),($19|0))|0;
  }
 }
 $20 = (($cloth) + 404|0);
 $21 = (($cloth) + 408|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if (!($23)) {
  $24 = HEAP32[$planes>>2]|0;
  $25 = (($planes) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($24>>>0)<($26>>>0);
  if ($27) {
   $28 = HEAP32[$20>>2]|0;
   $29 = $22 << 4;
   _memcpy(($24|0),($28|0),($29|0))|0;
  }
 }
 $30 = (($cloth) + 392|0);
 $31 = (($cloth) + 396|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = HEAP32[$convexes>>2]|0;
  $35 = (($convexes) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($34>>>0)<($36>>>0);
  if ($37) {
   $38 = HEAP32[$30>>2]|0;
   $39 = $32 << 2;
   _memcpy(($34|0),($38|0),($39|0))|0;
  }
 }
 $40 = (($cloth) + 428|0);
 $41 = (($cloth) + 432|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if ($43) {
  STACKTOP = sp;return;
 }
 $44 = HEAP32[$triangles>>2]|0;
 $45 = (($triangles) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($44>>>0)<($46>>>0);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$40>>2]|0;
 $49 = ($42*12)|0;
 _memcpy(($44|0),($48|0),($49|0))|0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory20extractCollisionDataERKNS0_5ClothENS0_5RangeINS_6PxVec4EEENS5_IjEES7_S8_NS5_INS_6PxVec3EEE($this,$cloth,$spheres,$capsules,$planes,$convexes,$triangles) {
 $this = $this|0;
 $cloth = $cloth|0;
 $spheres = $spheres|0;
 $capsules = $capsules|0;
 $planes = $planes|0;
 $convexes = $convexes|0;
 $triangles = $triangles|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond15 = 0, $or$cond16 = 0, $or$cond17 = 0, $or$cond18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$spheres>>2]|0;
 $1 = (($spheres) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$capsules>>2]|0;
 $4 = (($capsules) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$planes>>2]|0;
 $7 = (($planes) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$convexes>>2]|0;
 $10 = (($convexes) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$triangles>>2]|0;
 $13 = (($triangles) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($cloth) + 372|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)!=(0);
 $18 = ($0>>>0)<($2>>>0);
 $or$cond = $17 & $18;
 if ($or$cond) {
  $19 = (($cloth) + 368|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $16 << 4;
  _memcpy(($0|0),($20|0),($21|0))|0;
 }
 $22 = (($cloth) + 360|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)!=(0);
 $25 = ($3>>>0)<($5>>>0);
 $or$cond15 = $24 & $25;
 if ($or$cond15) {
  $26 = (($cloth) + 356|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $23 << 3;
  _memcpy(($3|0),($27|0),($28|0))|0;
 }
 $29 = (($cloth) + 408|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)!=(0);
 $32 = ($6>>>0)<($8>>>0);
 $or$cond16 = $31 & $32;
 if ($or$cond16) {
  $33 = (($cloth) + 404|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $30 << 4;
  _memcpy(($6|0),($34|0),($35|0))|0;
 }
 $36 = (($cloth) + 396|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)!=(0);
 $39 = ($9>>>0)<($11>>>0);
 $or$cond17 = $38 & $39;
 if ($or$cond17) {
  $40 = (($cloth) + 392|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = $37 << 2;
  _memcpy(($9|0),($41|0),($42|0))|0;
 }
 $43 = (($cloth) + 432|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)!=(0);
 $46 = ($12>>>0)<($14>>>0);
 $or$cond18 = $45 & $46;
 if (!($or$cond18)) {
  STACKTOP = sp;return;
 }
 $47 = (($cloth) + 428|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($44*12)|0;
 _memcpy(($12|0),($48|0),($49|0))|0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory24extractMotionConstraintsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE($this,$cloth,$destConstraints) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destConstraints = $destConstraints|0;
 var $$v = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 284|0);
 $1 = (($cloth) + 296|0);
 $2 = (($cloth) + 300|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $$v = $4 ? $0 : $1;
 $5 = (($$v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$destConstraints>>2]|0;
 $9 = HEAP32[$$v>>2]|0;
 $10 = $6 << 4;
 _memcpy(($8|0),($9|0),($10|0))|0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory24extractMotionConstraintsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE($this,$cloth,$destConstraints) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destConstraints = $destConstraints|0;
 var $$v$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 284|0);
 $1 = (($cloth) + 296|0);
 $2 = (($cloth) + 300|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $$v$i = $4 ? $0 : $1;
 $5 = (($$v$i) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$destConstraints>>2]|0;
 $9 = HEAP32[$$v$i>>2]|0;
 $10 = $6 << 4;
 _memcpy(($8|0),($9|0),($10|0))|0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory28extractSeparationConstraintsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE($this,$cloth,$destConstraints) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destConstraints = $destConstraints|0;
 var $$v = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 320|0);
 $1 = (($cloth) + 332|0);
 $2 = (($cloth) + 336|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $$v = $4 ? $0 : $1;
 $5 = (($$v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$destConstraints>>2]|0;
 $9 = HEAP32[$$v>>2]|0;
 $10 = $6 << 4;
 _memcpy(($8|0),($9|0),($10|0))|0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory28extractSeparationConstraintsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE($this,$cloth,$destConstraints) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destConstraints = $destConstraints|0;
 var $$v$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 320|0);
 $1 = (($cloth) + 332|0);
 $2 = (($cloth) + 336|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $$v$i = $4 ? $0 : $1;
 $5 = (($$v$i) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$destConstraints>>2]|0;
 $9 = HEAP32[$$v$i>>2]|0;
 $10 = $6 << 4;
 _memcpy(($8|0),($9|0),($10|0))|0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory28extractParticleAccelerationsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE($this,$cloth,$destAccelerations) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destAccelerations = $destAccelerations|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($cloth) + 344|0);
 $4 = HEAP32[$destAccelerations>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = $1 << 4;
 _memcpy(($4|0),($5|0),($6|0))|0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory28extractParticleAccelerationsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE($this,$cloth,$destAccelerations) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destAccelerations = $destAccelerations|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$destAccelerations>>2]|0;
 $4 = (($cloth) + 344|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $1 << 4;
 _memcpy(($3|0),($5|0),($6|0))|0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory23extractVirtualParticlesERKNS0_5ClothENS0_5RangeIA4_jEENS5_INS_6PxVec3EEE($this,$cloth,$indices,$weights) {
 $this = $this|0;
 $cloth = $cloth|0;
 $indices = $indices|0;
 $weights = $weights|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $iDestIt$04 = 0, $iDestIt$1 = 0, $iIt$05 = 0, $wDestIt$08 = 0, $wIt$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cloth>>2]|0;
 $1 = (($0) + 236|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($cloth)|0);
 $4 = HEAP32[$cloth>>2]|0;
 $5 = (($4) + 240|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($cloth)|0);
 $8 = (($weights) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$weights>>2]|0;
 $11 = $9;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = (($13|0) / 12)&-1;
 $15 = ($14|0)==($7|0);
 if ($15) {
  $16 = (($cloth) + 476|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($7<<4)|0);
  $19 = ($7|0)==(0);
  if (!($19)) {
   $wDestIt$08 = $10;$wIt$07 = $17;
   while(1) {
    $20 = Math_fround(HEAPF32[$wIt$07>>2]);
    $21 = (($wIt$07) + 4|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = (($wIt$07) + 8|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    HEAPF32[$wDestIt$08>>2] = $20;
    $25 = (($wDestIt$08) + 4|0);
    HEAPF32[$25>>2] = $22;
    $26 = (($wDestIt$08) + 8|0);
    HEAPF32[$26>>2] = $24;
    $27 = (($wIt$07) + 16|0);
    $28 = (($wDestIt$08) + 12|0);
    $29 = ($27|0)==($18|0);
    if ($29) {
     break;
    } else {
     $wDestIt$08 = $28;$wIt$07 = $27;
    }
   }
  }
 }
 $30 = (($indices) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$indices>>2]|0;
 $33 = $31;
 $34 = $32;
 $35 = (($33) - ($34))|0;
 $36 = $35 >> 4;
 $37 = ($36|0)==($3|0);
 if (!($37)) {
  STACKTOP = sp;return;
 }
 $38 = (($cloth) + 464|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($cloth) + 468|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + ($41<<3)|0);
 $43 = (($cloth) + 24|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($41|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $iDestIt$04 = $32;$iIt$05 = $39;
 while(1) {
  $46 = HEAP16[$iIt$05>>1]|0;
  $47 = $46&65535;
  $48 = ($47>>>0)<($44>>>0);
  if ($48) {
   $49 = (($iDestIt$04) + 16|0);
   $50 = (($iIt$05) + 2|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = $51&65535;
   $53 = (($iIt$05) + 4|0);
   $54 = HEAP16[$53>>1]|0;
   $55 = $54&65535;
   $56 = (($iIt$05) + 6|0);
   $57 = HEAP16[$56>>1]|0;
   $58 = $57&65535;
   HEAP32[$iDestIt$04>>2] = $47;
   $59 = (($iDestIt$04) + 4|0);
   HEAP32[$59>>2] = $52;
   $60 = (($iDestIt$04) + 8|0);
   HEAP32[$60>>2] = $55;
   $61 = (($iDestIt$04) + 12|0);
   HEAP32[$61>>2] = $58;
   $iDestIt$1 = $49;
  } else {
   $iDestIt$1 = $iDestIt$04;
  }
  $62 = (($iIt$05) + 8|0);
  $63 = ($62|0)==($42|0);
  if ($63) {
   break;
  } else {
   $iDestIt$04 = $iDestIt$1;$iIt$05 = $62;
  }
 }
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory23extractVirtualParticlesERKNS0_5ClothENS0_5RangeIA4_jEENS5_INS_6PxVec3EEE($this,$cloth,$indices,$weights) {
 $this = $this|0;
 $cloth = $cloth|0;
 $indices = $indices|0;
 $weights = $weights|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $iDestIt$04$i = 0, $iDestIt$1$i = 0, $iIt$05$i = 0, $wDestIt$08$i = 0, $wIt$07$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$indices>>2]|0;
 $1 = (($indices) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$weights>>2]|0;
 $4 = (($weights) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$cloth>>2]|0;
 $7 = (($6) + 236|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($cloth)|0);
 $10 = HEAP32[$cloth>>2]|0;
 $11 = (($10) + 240|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($cloth)|0);
 $14 = $5;
 $15 = $3;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = ($17|0)==($13|0);
 if ($18) {
  $19 = (($cloth) + 476|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + ($13<<4)|0);
  $22 = ($13|0)==(0);
  if (!($22)) {
   $wDestIt$08$i = $3;$wIt$07$i = $20;
   while(1) {
    $23 = Math_fround(HEAPF32[$wIt$07$i>>2]);
    $24 = (($wIt$07$i) + 4|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = (($wIt$07$i) + 8|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    HEAPF32[$wDestIt$08$i>>2] = $23;
    $28 = (($wDestIt$08$i) + 4|0);
    HEAPF32[$28>>2] = $25;
    $29 = (($wDestIt$08$i) + 8|0);
    HEAPF32[$29>>2] = $27;
    $30 = (($wIt$07$i) + 16|0);
    $31 = (($wDestIt$08$i) + 12|0);
    $32 = ($30|0)==($21|0);
    if ($32) {
     break;
    } else {
     $wDestIt$08$i = $31;$wIt$07$i = $30;
    }
   }
  }
 }
 $33 = $2;
 $34 = $0;
 $35 = (($33) - ($34))|0;
 $36 = $35 >> 4;
 $37 = ($36|0)==($9|0);
 if (!($37)) {
  STACKTOP = sp;return;
 }
 $38 = (($cloth) + 464|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($cloth) + 468|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + ($41<<3)|0);
 $43 = (($cloth) + 24|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($41|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $iDestIt$04$i = $0;$iIt$05$i = $39;
 while(1) {
  $46 = HEAP16[$iIt$05$i>>1]|0;
  $47 = $46&65535;
  $48 = ($47>>>0)<($44>>>0);
  if ($48) {
   $49 = (($iDestIt$04$i) + 16|0);
   $50 = (($iIt$05$i) + 2|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = $51&65535;
   $53 = (($iIt$05$i) + 4|0);
   $54 = HEAP16[$53>>1]|0;
   $55 = $54&65535;
   $56 = (($iIt$05$i) + 6|0);
   $57 = HEAP16[$56>>1]|0;
   $58 = $57&65535;
   HEAP32[$iDestIt$04$i>>2] = $47;
   $59 = (($iDestIt$04$i) + 4|0);
   HEAP32[$59>>2] = $52;
   $60 = (($iDestIt$04$i) + 8|0);
   HEAP32[$60>>2] = $55;
   $61 = (($iDestIt$04$i) + 12|0);
   HEAP32[$61>>2] = $58;
   $iDestIt$1$i = $49;
  } else {
   $iDestIt$1$i = $iDestIt$04$i;
  }
  $62 = (($iIt$05$i) + 8|0);
  $63 = ($62|0)==($42|0);
  if ($63) {
   break;
  } else {
   $iDestIt$04$i = $iDestIt$1$i;$iIt$05$i = $62;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory27extractSelfCollisionIndicesERKNS0_5ClothENS0_5RangeIjEE($this,$cloth,$destIndices) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destIndices = $destIndices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($cloth) + 500|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($cloth) + 504|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = HEAP32[$destIndices>>2]|0;
 FUNCTION_TABLE_viiii[$2 & 511]($this,$4,$7,$8);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory27extractSelfCollisionIndicesERKNS0_5ClothENS0_5RangeIjEE($this,$cloth,$destIndices) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destIndices = $destIndices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = HEAP32[$destIndices>>2]|0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($cloth) + 500|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($cloth) + 504|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + ($8<<2)|0);
 FUNCTION_TABLE_viiii[$4 & 511]($0,$6,$9,$1);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9SwFactory20extractRestPositionsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE($this,$cloth,$destRestPositions) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destRestPositions = $destRestPositions|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($cloth) + 512|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($cloth) + 516|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<4)|0);
 $8 = HEAP32[$destRestPositions>>2]|0;
 FUNCTION_TABLE_viiii[$2 & 511]($this,$4,$7,$8);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9SwFactory20extractRestPositionsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE($this,$cloth,$destRestPositions) {
 $this = $this|0;
 $cloth = $cloth|0;
 $destRestPositions = $destRestPositions|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = HEAP32[$destRestPositions>>2]|0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($cloth) + 512|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($cloth) + 516|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + ($8<<4)|0);
 FUNCTION_TABLE_viiii[$4 & 511]($0,$6,$9,$1);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478800 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((478800 + 424|0));
 $1 = (($this) + 16|0);
 __ZN5physx5cloth7SwClothD2Ev($1);
 HEAP32[$this>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((478800 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((478800 + 424|0));
 $1 = (($this) + 16|0);
 __ZN5physx5cloth7SwClothD2Ev($1);
 HEAP32[$this>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE9getFabricEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE10getFactoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE14setTranslationERKNS_6PxVec3E($this,$trans) {
 $this = $this|0;
 $trans = $trans|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$trans>>2]);
 $1 = (($trans) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($trans) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 180|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 184|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 188|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 188|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 540|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE11setRotationERKNS_6PxQuatE($this,$q) {
 $this = $this|0;
 $q = $q|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$q>>2]);
 $1 = (($this) + 164|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 - $2);
 $4 = (($q) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 168|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($q) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 172|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = (($q) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 176|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = Math_fround($3 * $3);
 $20 = Math_fround($8 * $8);
 $21 = Math_fround($19 + $20);
 $22 = Math_fround($13 * $13);
 $23 = Math_fround($21 + $22);
 $24 = Math_fround($18 * $18);
 $25 = Math_fround($23 + $24);
 $26 = $25 == Math_fround(0.0);
 if ($26) {
  STACKTOP = sp;return;
 }
 HEAPF32[$1>>2] = $0;
 $27 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$6>>2] = $27;
 $28 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$11>>2] = $28;
 $29 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$16>>2] = $29;
 $30 = (($this) + 540|0);
 HEAP32[$30>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE14getTranslationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 180|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE11getRotationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 164|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE12clearInertiaEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0;
 var $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 164|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 192|0);
 HEAPF32[$2>>2] = $1;
 $3 = (($this) + 168|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 196|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($this) + 172|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 200|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($this) + 176|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 204|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($this) + 180|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 208|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($this) + 184|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 212|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($this) + 188|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 216|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($this) + 220|0);
 $22 = (($this) + 540|0);
 HEAP32[$22>>2] = 0;
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;HEAP32[$21+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE8teleportERKNS_6PxVec3E($this,$delta) {
 $this = $this|0;
 $delta = $delta|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $3 = Math_fround(0);
 var $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$delta>>2]);
 $1 = (($this) + 208|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 HEAPF32[$1>>2] = $3;
 $4 = (($delta) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 212|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 HEAPF32[$6>>2] = $8;
 $9 = (($delta) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 216|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 HEAPF32[$11>>2] = $13;
 $14 = Math_fround(HEAPF32[$delta>>2]);
 $15 = (($this) + 180|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 + $16);
 HEAPF32[$15>>2] = $17;
 $18 = Math_fround(HEAPF32[$4>>2]);
 $19 = (($this) + 184|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 + $20);
 HEAPF32[$19>>2] = $21;
 $22 = Math_fround(HEAPF32[$9>>2]);
 $23 = (($this) + 188|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 + $24);
 HEAPF32[$23>>2] = $25;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE22getPreviousIterationDtEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE10setGravityERKNS_6PxVec3E($this,$gravity) {
 $this = $this|0;
 $gravity = $gravity|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$gravity>>2]);
 $1 = (($gravity) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($gravity) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 72|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 76|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 80|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 80|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 540|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE10getGravityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 76|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 80|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE10setDampingERKNS_6PxVec3E($this,$damping) {
 $this = $this|0;
 $damping = $damping|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0.0, $11 = 0.0, $12 = Math_fround(0), $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = Math_fround(0), $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$damping>>2]);
 $1 = Math_fround(Math_fround(1.0) - $0);
 $2 = (($damping) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(Math_fround(1.0) - $3);
 $5 = (($damping) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(Math_fround(1.0) - $6);
 $8 = $1 != Math_fround(0.0);
 if ($8) {
  $9 = +$1;
  $10 = (+Math_log((+$9)));
  $11 = $10 / 0.693147182464599609375;
  $12 = Math_fround($11);
  $26 = $12;
 } else {
  $26 = Math_fround(-128.0);
 }
 $13 = $4 != Math_fround(0.0);
 if ($13) {
  $14 = +$4;
  $15 = (+Math_log((+$14)));
  $16 = $15 / 0.693147182464599609375;
  $17 = Math_fround($16);
  $30 = $17;
 } else {
  $30 = Math_fround(-128.0);
 }
 $18 = $7 != Math_fround(0.0);
 if ($18) {
  $19 = +$7;
  $20 = (+Math_log((+$19)));
  $21 = $20 / 0.693147182464599609375;
  $22 = Math_fround($21);
  $34 = $22;
 } else {
  $34 = Math_fround(-128.0);
 }
 $23 = (($this) + 84|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $26 == $24;
 $27 = (($this) + 88|0);
 if ($25) {
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = $30 == $28;
  if ($29) {
   $31 = (($this) + 92|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = $34 == $32;
   if ($33) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$23>>2] = $26;
 HEAPF32[$27>>2] = $30;
 $35 = (($this) + 92|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($this) + 540|0);
 HEAP32[$36>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE10getDampingEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $$0$i1$i = Math_fround(0), $$0$i3$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0.0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0.0, $19 = 0.0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i = $6;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $7 = (($this) + 88|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 <= Math_fround(-128.0));
 if ($9) {
  $10 = Math_fround($8 * Math_fround(0.693147182464599609375));
  $11 = +$10;
  $12 = (+Math_exp((+$11)));
  $13 = Math_fround($12);
  $$0$i1$i = $13;
 } else {
  $$0$i1$i = Math_fround(0.0);
 }
 $14 = (($this) + 92|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = !($15 <= Math_fround(-128.0));
 if ($16) {
  $17 = Math_fround($15 * Math_fround(0.693147182464599609375));
  $18 = +$17;
  $19 = (+Math_exp((+$18)));
  $20 = Math_fround($19);
  $$0$i3$i = $20;
 } else {
  $$0$i3$i = Math_fround(0.0);
 }
 $21 = Math_fround(Math_fround(1.0) - $$0$i$i);
 $22 = Math_fround(Math_fround(1.0) - $$0$i1$i);
 $23 = Math_fround(Math_fround(1.0) - $$0$i3$i);
 HEAPF32[$agg$result>>2] = $21;
 $24 = (($agg$result) + 4|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($agg$result) + 8|0);
 HEAPF32[$25>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE13setLinearDragERKNS_6PxVec3E($this,$drag) {
 $this = $this|0;
 $drag = $drag|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0.0, $11 = 0.0, $12 = Math_fround(0), $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = Math_fround(0), $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$drag>>2]);
 $1 = Math_fround(Math_fround(1.0) - $0);
 $2 = (($drag) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(Math_fround(1.0) - $3);
 $5 = (($drag) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(Math_fround(1.0) - $6);
 $8 = $1 != Math_fround(0.0);
 if ($8) {
  $9 = +$1;
  $10 = (+Math_log((+$9)));
  $11 = $10 / 0.693147182464599609375;
  $12 = Math_fround($11);
  $26 = $12;
 } else {
  $26 = Math_fround(-128.0);
 }
 $13 = $4 != Math_fround(0.0);
 if ($13) {
  $14 = +$4;
  $15 = (+Math_log((+$14)));
  $16 = $15 / 0.693147182464599609375;
  $17 = Math_fround($16);
  $30 = $17;
 } else {
  $30 = Math_fround(-128.0);
 }
 $18 = $7 != Math_fround(0.0);
 if ($18) {
  $19 = +$7;
  $20 = (+Math_log((+$19)));
  $21 = $20 / 0.693147182464599609375;
  $22 = Math_fround($21);
  $34 = $22;
 } else {
  $34 = Math_fround(-128.0);
 }
 $23 = (($this) + 96|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $26 == $24;
 $27 = (($this) + 100|0);
 if ($25) {
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = $30 == $28;
  if ($29) {
   $31 = (($this) + 104|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = $34 == $32;
   if ($33) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$23>>2] = $26;
 HEAPF32[$27>>2] = $30;
 $35 = (($this) + 104|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($this) + 540|0);
 HEAP32[$36>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE13getLinearDragEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $$0$i1$i = Math_fround(0), $$0$i3$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0.0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0.0, $19 = 0.0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i = $6;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $7 = (($this) + 100|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 <= Math_fround(-128.0));
 if ($9) {
  $10 = Math_fround($8 * Math_fround(0.693147182464599609375));
  $11 = +$10;
  $12 = (+Math_exp((+$11)));
  $13 = Math_fround($12);
  $$0$i1$i = $13;
 } else {
  $$0$i1$i = Math_fround(0.0);
 }
 $14 = (($this) + 104|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = !($15 <= Math_fround(-128.0));
 if ($16) {
  $17 = Math_fround($15 * Math_fround(0.693147182464599609375));
  $18 = +$17;
  $19 = (+Math_exp((+$18)));
  $20 = Math_fround($19);
  $$0$i3$i = $20;
 } else {
  $$0$i3$i = Math_fround(0.0);
 }
 $21 = Math_fround(Math_fround(1.0) - $$0$i$i);
 $22 = Math_fround(Math_fround(1.0) - $$0$i1$i);
 $23 = Math_fround(Math_fround(1.0) - $$0$i3$i);
 HEAPF32[$agg$result>>2] = $21;
 $24 = (($agg$result) + 4|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($agg$result) + 8|0);
 HEAPF32[$25>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE14setAngularDragERKNS_6PxVec3E($this,$drag) {
 $this = $this|0;
 $drag = $drag|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0.0, $11 = 0.0, $12 = Math_fround(0), $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = Math_fround(0), $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$drag>>2]);
 $1 = Math_fround(Math_fround(1.0) - $0);
 $2 = (($drag) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(Math_fround(1.0) - $3);
 $5 = (($drag) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(Math_fround(1.0) - $6);
 $8 = $1 != Math_fround(0.0);
 if ($8) {
  $9 = +$1;
  $10 = (+Math_log((+$9)));
  $11 = $10 / 0.693147182464599609375;
  $12 = Math_fround($11);
  $26 = $12;
 } else {
  $26 = Math_fround(-128.0);
 }
 $13 = $4 != Math_fround(0.0);
 if ($13) {
  $14 = +$4;
  $15 = (+Math_log((+$14)));
  $16 = $15 / 0.693147182464599609375;
  $17 = Math_fround($16);
  $30 = $17;
 } else {
  $30 = Math_fround(-128.0);
 }
 $18 = $7 != Math_fround(0.0);
 if ($18) {
  $19 = +$7;
  $20 = (+Math_log((+$19)));
  $21 = $20 / 0.693147182464599609375;
  $22 = Math_fround($21);
  $34 = $22;
 } else {
  $34 = Math_fround(-128.0);
 }
 $23 = (($this) + 108|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $26 == $24;
 $27 = (($this) + 112|0);
 if ($25) {
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = $30 == $28;
  if ($29) {
   $31 = (($this) + 116|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = $34 == $32;
   if ($33) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$23>>2] = $26;
 HEAPF32[$27>>2] = $30;
 $35 = (($this) + 116|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($this) + 540|0);
 HEAP32[$36>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE14getAngularDragEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $$0$i1$i = Math_fround(0), $$0$i3$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0.0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0.0, $19 = 0.0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i = $6;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $7 = (($this) + 112|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 <= Math_fround(-128.0));
 if ($9) {
  $10 = Math_fround($8 * Math_fround(0.693147182464599609375));
  $11 = +$10;
  $12 = (+Math_exp((+$11)));
  $13 = Math_fround($12);
  $$0$i1$i = $13;
 } else {
  $$0$i1$i = Math_fround(0.0);
 }
 $14 = (($this) + 116|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = !($15 <= Math_fround(-128.0));
 if ($16) {
  $17 = Math_fround($15 * Math_fround(0.693147182464599609375));
  $18 = +$17;
  $19 = (+Math_exp((+$18)));
  $20 = Math_fround($19);
  $$0$i3$i = $20;
 } else {
  $$0$i3$i = Math_fround(0.0);
 }
 $21 = Math_fround(Math_fround(1.0) - $$0$i$i);
 $22 = Math_fround(Math_fround(1.0) - $$0$i1$i);
 $23 = Math_fround(Math_fround(1.0) - $$0$i3$i);
 HEAPF32[$agg$result>>2] = $21;
 $24 = (($agg$result) + 4|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($agg$result) + 8|0);
 HEAPF32[$25>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE16setLinearInertiaERKNS_6PxVec3E($this,$inertia) {
 $this = $this|0;
 $inertia = $inertia|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inertia>>2]);
 $1 = (($inertia) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($inertia) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 120|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 124|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 128|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 128|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 540|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE16getLinearInertiaEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 124|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 128|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE17setAngularInertiaERKNS_6PxVec3E($this,$inertia) {
 $this = $this|0;
 $inertia = $inertia|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inertia>>2]);
 $1 = (($inertia) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($inertia) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 132|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 136|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 140|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 140|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 540|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE17getAngularInertiaEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 136|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 140|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE21setCentrifugalInertiaERKNS_6PxVec3E($this,$inertia) {
 $this = $this|0;
 $inertia = $inertia|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inertia>>2]);
 $1 = (($inertia) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($inertia) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 144|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 148|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 152|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 152|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 540|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE21getCentrifugalInertiaEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 148|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 152|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE18setSolverFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $0 = 0, $1 = 0, $10 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 156|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 == $frequency;
 if ($3) {
  STACKTOP = sp;return;
 }
 HEAPF32[$1>>2] = $frequency;
 $4 = (($this) + 248|0);
 $5 = $0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE6resizeEjRKS4_($4,0,$0);
 $9 = (($this) + 260|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 540|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE18getSolverFrequencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE21setStiffnessFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $frequency;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $frequency;
 $3 = (($this) + 540|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE21getStiffnessFrequencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE25setAcceleationFilterWidthEj($this,$n) {
 $this = $this|0;
 $n = $n|0;
 var $$012$i$i$i$i = 0, $$03$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $it$01$i$i = 0, $k$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 248|0);
 $1 = (($this) + 264|0);
 HEAP32[$1>>2] = $n;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($this) + 260|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>($n>>>0);
 if ($5) {
  $9 = $4;$it$01$i$i = $2;$k$02$i$i = $n;
  while(1) {
   $6 = HEAP32[$it$01$i$i>>2]|0;
   $7 = (($6) + ($k$02$i$i))|0;
   $8 = (($7) - ($9))|0;
   HEAP32[$it$01$i$i>>2] = $8;
   $10 = HEAP32[$3>>2]|0;
   $11 = ($7>>>0)<=($10>>>0);
   $12 = $11&1;
   $13 = (($it$01$i$i) + ($12<<3)|0);
   $14 = ($7>>>0)<($10>>>0);
   if ($14) {
    $9 = $10;$it$01$i$i = $13;$k$02$i$i = $7;
   } else {
    break;
   }
  }
  $15 = ($13|0)==($2|0);
  if (!($15)) {
   $16 = (($this) + 252|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($2) + ($17<<3)|0);
   $19 = $18;
   $20 = $13;
   $21 = (($19) - ($20))|0;
   $22 = $21 >> 3;
   __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE19resizeUninitializedEj($0,$22);
   $23 = HEAP32[$0>>2]|0;
   $24 = HEAP32[$16>>2]|0;
   $25 = (($23) + ($24<<3)|0);
   $26 = ($24|0)>(0);
   if ($26) {
    $$012$i$i$i$i = $23;$$03$i$i$i$i = $13;
    while(1) {
     $27 = ($$012$i$i$i$i|0)==(0|0);
     if (!($27)) {
      $28 = $$03$i$i$i$i;
      $29 = $28;
      $30 = HEAP32[$29>>2]|0;
      $31 = (($28) + 4)|0;
      $32 = $31;
      $33 = HEAP32[$32>>2]|0;
      $34 = $$012$i$i$i$i;
      $35 = $34;
      HEAP32[$35>>2] = $30;
      $36 = (($34) + 4)|0;
      $37 = $36;
      HEAP32[$37>>2] = $33;
     }
     $38 = (($$012$i$i$i$i) + 8|0);
     $39 = (($$03$i$i$i$i) + 8|0);
     $40 = ($38>>>0)<($25>>>0);
     if ($40) {
      $$012$i$i$i$i = $38;$$03$i$i$i$i = $39;
     } else {
      break;
     }
    }
   }
  }
 }
 $41 = HEAP32[$3>>2]|0;
 $42 = HEAP32[$1>>2]|0;
 $43 = ($41>>>0)<($42>>>0);
 $44 = $43 ? $41 : $42;
 HEAP32[$3>>2] = $44;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE26getAccelerationFilterWidthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE10setSpheresENS0_5RangeIKNS_6PxVec4EEEjj($this,$spheres,$first,$last) {
 $this = $this|0;
 $spheres = $spheres|0;
 $first = $first|0;
 $last = $last|0;
 var $$012$i$i = 0, $$013$i = 0, $$013$i5 = 0, $$026$i = 0, $$026$i7 = 0, $$03$i$i = 0, $$04$i = 0, $$04$i4 = 0, $$17$i = 0, $$17$i6 = 0, $$not = 0, $$pre = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0);
 var $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0;
 var $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0;
 var $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $cEnd$0$ph26 = 0, $cEnd$015 = 0, $cIt$0$ph25 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i8 = 0, $exitcond28 = 0, $i$021 = 0, $i2$017 = 0, $i3$013 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = (($this) + 372|0);
 $5 = (($this) + 376|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($spheres) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$spheres>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 4;
 $14 = (($first) - ($last))|0;
 $15 = (($14) + ($6))|0;
 $16 = (($15) + ($13))|0;
 $17 = ($6|0)!=(0);
 $$not = $17 ^ 1;
 $18 = ($16|0)==(0);
 $or$cond = $18 & $$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 if ($17) {
  $37 = ($6>>>0)<($16>>>0);
  $38 = $37 ? $16 : $6;
  $39 = (($this) + 380|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & 2147483647;
  $42 = (($this) + 384|0);
  $43 = (($this) + 392|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & 2147483647;
  $46 = ($41>>>0)<($45>>>0);
  $47 = $46 ? $41 : $45;
  $48 = ($38>>>0)>($47>>>0);
  if ($48) {
   $49 = ($41>>>0)<($16>>>0);
   if ($49) {
    __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($4,$16);
    $$pre = HEAP32[$43>>2]|0;
    $51 = $$pre;
   } else {
    $51 = $44;
   }
   $50 = $51 & 2147483647;
   $52 = ($50>>>0)<($38>>>0);
   if ($52) {
    __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($42,$38);
   }
  }
  $53 = (($this) + 388|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54>>>0)<($6>>>0);
  L19: do {
   if ($55) {
    $61 = $54;$i$021 = $54;
    while(1) {
     $56 = HEAP32[$4>>2]|0;
     $57 = (($56) + ($i$021<<4)|0);
     $58 = HEAP32[$43>>2]|0;
     $59 = $58 & 2147483647;
     $60 = ($59>>>0)>($61>>>0);
     if ($60) {
      $62 = HEAP32[$42>>2]|0;
      $63 = (($62) + ($61<<4)|0);
      $64 = ($63|0)==(0|0);
      if (!($64)) {
       $65 = Math_fround(HEAPF32[$57>>2]);
       HEAPF32[$63>>2] = $65;
       $66 = ((($62) + ($61<<4)|0) + 4|0);
       $67 = ((($56) + ($i$021<<4)|0) + 4|0);
       $68 = Math_fround(HEAPF32[$67>>2]);
       HEAPF32[$66>>2] = $68;
       $69 = ((($62) + ($61<<4)|0) + 8|0);
       $70 = ((($56) + ($i$021<<4)|0) + 8|0);
       $71 = Math_fround(HEAPF32[$70>>2]);
       HEAPF32[$69>>2] = $71;
       $72 = ((($62) + ($61<<4)|0) + 12|0);
       $73 = ((($56) + ($i$021<<4)|0) + 12|0);
       $74 = Math_fround(HEAPF32[$73>>2]);
       HEAPF32[$72>>2] = $74;
      }
      $75 = (($61) + 1)|0;
      HEAP32[$53>>2] = $75;
     } else {
      (__ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE15growAndPushBackERKS2_($42,$57)|0);
     }
     $76 = (($i$021) + 1)|0;
     $exitcond28 = ($76|0)==($6|0);
     if ($exitcond28) {
      break L19;
     }
     $$pre31 = HEAP32[$53>>2]|0;
     $61 = $$pre31;$i$021 = $76;
    }
   }
  } while(0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($4,$38,$0);
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($42,$38,$1);
  $77 = (($16) - ($6))|0;
  $78 = ($16|0)==($6|0);
  if ($78) {
   $204 = $8;$205 = $9;
  } else {
   $79 = HEAP32[$4>>2]|0;
   $80 = (($77) + ($last))|0;
   $81 = ($80>>>0)>($last>>>0);
   $82 = ($6>>>0)>($last>>>0);
   if ($81) {
    if ($82) {
     $$013$i5 = $6;$$04$i4 = $16;
     while(1) {
      $83 = (($$04$i4) + -1)|0;
      $84 = (($$013$i5) + -1)|0;
      $85 = (($79) + ($84<<4)|0);
      $86 = Math_fround(HEAPF32[$85>>2]);
      $87 = (($79) + ($83<<4)|0);
      HEAPF32[$87>>2] = $86;
      $88 = ((($79) + ($84<<4)|0) + 4|0);
      $89 = Math_fround(HEAPF32[$88>>2]);
      $90 = ((($79) + ($83<<4)|0) + 4|0);
      HEAPF32[$90>>2] = $89;
      $91 = ((($79) + ($84<<4)|0) + 8|0);
      $92 = Math_fround(HEAPF32[$91>>2]);
      $93 = ((($79) + ($83<<4)|0) + 8|0);
      HEAPF32[$93>>2] = $92;
      $94 = ((($79) + ($84<<4)|0) + 12|0);
      $95 = Math_fround(HEAPF32[$94>>2]);
      $96 = ((($79) + ($83<<4)|0) + 12|0);
      HEAPF32[$96>>2] = $95;
      $97 = ($84>>>0)>($last>>>0);
      if ($97) {
       $$013$i5 = $84;$$04$i4 = $83;
      } else {
       label = 27;
       break;
      }
     }
    } else {
     label = 32;
    }
   } else {
    if ($82) {
     $$026$i7 = $last;$$17$i6 = $80;
     while(1) {
      $98 = (($$17$i6) + 1)|0;
      $99 = (($$026$i7) + 1)|0;
      $100 = (($79) + ($$026$i7<<4)|0);
      $101 = Math_fround(HEAPF32[$100>>2]);
      $102 = (($79) + ($$17$i6<<4)|0);
      HEAPF32[$102>>2] = $101;
      $103 = ((($79) + ($$026$i7<<4)|0) + 4|0);
      $104 = Math_fround(HEAPF32[$103>>2]);
      $105 = ((($79) + ($$17$i6<<4)|0) + 4|0);
      HEAPF32[$105>>2] = $104;
      $106 = ((($79) + ($$026$i7<<4)|0) + 8|0);
      $107 = Math_fround(HEAPF32[$106>>2]);
      $108 = ((($79) + ($$17$i6<<4)|0) + 8|0);
      HEAPF32[$108>>2] = $107;
      $109 = ((($79) + ($$026$i7<<4)|0) + 12|0);
      $110 = Math_fround(HEAPF32[$109>>2]);
      $111 = ((($79) + ($$17$i6<<4)|0) + 12|0);
      HEAPF32[$111>>2] = $110;
      $exitcond$i8 = ($99|0)==($6|0);
      if ($exitcond$i8) {
       label = 27;
       break;
      } else {
       $$026$i7 = $99;$$17$i6 = $98;
      }
     }
    } else {
     label = 32;
    }
   }
   do {
    if ((label|0) == 27) {
     $112 = HEAP32[$42>>2]|0;
     if ($81) {
      if ($82) {
       $$013$i = $6;$$04$i = $16;
      } else {
       label = 33;
       break;
      }
      while(1) {
       $113 = (($$04$i) + -1)|0;
       $114 = (($$013$i) + -1)|0;
       $115 = (($112) + ($114<<4)|0);
       $116 = Math_fround(HEAPF32[$115>>2]);
       $117 = (($112) + ($113<<4)|0);
       HEAPF32[$117>>2] = $116;
       $118 = ((($112) + ($114<<4)|0) + 4|0);
       $119 = Math_fround(HEAPF32[$118>>2]);
       $120 = ((($112) + ($113<<4)|0) + 4|0);
       HEAPF32[$120>>2] = $119;
       $121 = ((($112) + ($114<<4)|0) + 8|0);
       $122 = Math_fround(HEAPF32[$121>>2]);
       $123 = ((($112) + ($113<<4)|0) + 8|0);
       HEAPF32[$123>>2] = $122;
       $124 = ((($112) + ($114<<4)|0) + 12|0);
       $125 = Math_fround(HEAPF32[$124>>2]);
       $126 = ((($112) + ($113<<4)|0) + 12|0);
       HEAPF32[$126>>2] = $125;
       $127 = ($114>>>0)>($last>>>0);
       if ($127) {
        $$013$i = $114;$$04$i = $113;
       } else {
        label = 32;
        break;
       }
      }
     } else {
      if ($82) {
       $$026$i = $last;$$17$i = $80;
      } else {
       break;
      }
      while(1) {
       $128 = (($$17$i) + 1)|0;
       $129 = (($$026$i) + 1)|0;
       $130 = (($112) + ($$026$i<<4)|0);
       $131 = Math_fround(HEAPF32[$130>>2]);
       $132 = (($112) + ($$17$i<<4)|0);
       HEAPF32[$132>>2] = $131;
       $133 = ((($112) + ($$026$i<<4)|0) + 4|0);
       $134 = Math_fround(HEAPF32[$133>>2]);
       $135 = ((($112) + ($$17$i<<4)|0) + 4|0);
       HEAPF32[$135>>2] = $134;
       $136 = ((($112) + ($$026$i<<4)|0) + 8|0);
       $137 = Math_fround(HEAPF32[$136>>2]);
       $138 = ((($112) + ($$17$i<<4)|0) + 8|0);
       HEAPF32[$138>>2] = $137;
       $139 = ((($112) + ($$026$i<<4)|0) + 12|0);
       $140 = Math_fround(HEAPF32[$139>>2]);
       $141 = ((($112) + ($$17$i<<4)|0) + 12|0);
       HEAPF32[$141>>2] = $140;
       $exitcond$i = ($129|0)==($6|0);
       if ($exitcond$i) {
        label = 32;
        break;
       } else {
        $$026$i = $129;$$17$i = $128;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 32) {
    if ($81) {
     label = 33;
    }
   }
   if ((label|0) == 33) {
    $142 = (($13) + ($first))|0;
    $i2$017 = $last;
    while(1) {
     $143 = (($i2$017) - ($first))|0;
     $144 = (($9) + ($143<<4)|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = (($79) + ($i2$017<<4)|0);
     HEAPF32[$146>>2] = $145;
     $147 = ((($9) + ($143<<4)|0) + 4|0);
     $148 = Math_fround(HEAPF32[$147>>2]);
     $149 = ((($79) + ($i2$017<<4)|0) + 4|0);
     HEAPF32[$149>>2] = $148;
     $150 = ((($9) + ($143<<4)|0) + 8|0);
     $151 = Math_fround(HEAPF32[$150>>2]);
     $152 = ((($79) + ($i2$017<<4)|0) + 8|0);
     HEAPF32[$152>>2] = $151;
     $153 = ((($9) + ($143<<4)|0) + 12|0);
     $154 = Math_fround(HEAPF32[$153>>2]);
     $155 = ((($79) + ($i2$017<<4)|0) + 12|0);
     HEAPF32[$155>>2] = $154;
     $156 = (($i2$017) + 1)|0;
     $exitcond = ($156|0)==($142|0);
     if ($exitcond) {
      break;
     } else {
      $i2$017 = $156;
     }
    }
   }
   $157 = (($this) + 360|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($this) + 364|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($160|0)==(0);
   L57: do {
    if (!($161)) {
     $162 = (($158) + ($160<<3)|0);
     $163 = ($77|0)>(0);
     $164 = $163 ? 0 : $77;
     $165 = (($164) + ($last))|0;
     $227 = $158;$cEnd$0$ph26 = $162;$cIt$0$ph25 = $158;
     while(1) {
      $166 = (($cIt$0$ph25) + 4|0);
      $167 = $cIt$0$ph25;
      $182 = $227;$cEnd$015 = $cEnd$0$ph26;
      while(1) {
       $168 = HEAP32[$cIt$0$ph25>>2]|0;
       $169 = ($168>>>0)<($165>>>0);
       if ($169) {
        $177 = 0;
       } else {
        $170 = (($168) + ($77))|0;
        HEAP32[$cIt$0$ph25>>2] = $170;
        $171 = ($170|0)<($165|0);
        $177 = $171;
       }
       $172 = HEAP32[$166>>2]|0;
       $173 = ($172>>>0)<($165>>>0);
       if ($173) {
        $178 = 0;
       } else {
        $174 = (($172) + ($77))|0;
        HEAP32[$166>>2] = $174;
        $175 = ($174|0)<($165|0);
        $178 = $175;
       }
       $176 = $177 | $178;
       if (!($176)) {
        break;
       }
       $181 = $182;
       $183 = (($167) - ($181))|0;
       $184 = $183 >> 3;
       $185 = (($182) + ($184<<3)|0);
       $186 = HEAP32[$159>>2]|0;
       $187 = (($186) + -1)|0;
       HEAP32[$159>>2] = $187;
       $188 = (($182) + ($187<<3)|0);
       $189 = $188;
       $190 = $189;
       $191 = HEAP32[$190>>2]|0;
       $192 = (($189) + 4)|0;
       $193 = $192;
       $194 = HEAP32[$193>>2]|0;
       $195 = $185;
       $196 = $195;
       HEAP32[$196>>2] = $191;
       $197 = (($195) + 4)|0;
       $198 = $197;
       HEAP32[$198>>2] = $194;
       $199 = HEAP32[$157>>2]|0;
       $200 = HEAP32[$159>>2]|0;
       $201 = (($199) + ($200<<3)|0);
       $202 = ($cIt$0$ph25|0)==($201|0);
       if ($202) {
        break L57;
       } else {
        $182 = $199;$cEnd$015 = $201;
       }
      }
      $179 = (($cIt$0$ph25) + 8|0);
      $180 = ($179|0)==($cEnd$015|0);
      if ($180) {
       break;
      } else {
       $227 = $182;$cEnd$0$ph26 = $cEnd$015;$cIt$0$ph25 = $179;
      }
     }
    }
   } while(0);
   __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($4,$16,$2);
   __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($42,$16,$3);
   $$pre29 = HEAP32[$7>>2]|0;
   $$pre30 = HEAP32[$spheres>>2]|0;
   $204 = $$pre29;$205 = $$pre30;
  }
  $203 = ($204|0)==($205|0);
  if (!($203)) {
   $206 = HEAP32[$42>>2]|0;
   $207 = $204;
   $208 = $205;
   $209 = (($207) - ($208))|0;
   $210 = $209 >> 4;
   $i3$013 = 0;
   while(1) {
    $211 = (($i3$013) + ($first))|0;
    $212 = (($205) + ($i3$013<<4)|0);
    $213 = Math_fround(HEAPF32[$212>>2]);
    $214 = (($206) + ($211<<4)|0);
    HEAPF32[$214>>2] = $213;
    $215 = ((($205) + ($i3$013<<4)|0) + 4|0);
    $216 = Math_fround(HEAPF32[$215>>2]);
    $217 = ((($206) + ($211<<4)|0) + 4|0);
    HEAPF32[$217>>2] = $216;
    $218 = ((($205) + ($i3$013<<4)|0) + 8|0);
    $219 = Math_fround(HEAPF32[$218>>2]);
    $220 = ((($206) + ($211<<4)|0) + 8|0);
    HEAPF32[$220>>2] = $219;
    $221 = ((($205) + ($i3$013<<4)|0) + 12|0);
    $222 = Math_fround(HEAPF32[$221>>2]);
    $223 = ((($206) + ($211<<4)|0) + 12|0);
    HEAPF32[$223>>2] = $222;
    $224 = (($i3$013) + 1)|0;
    $225 = ($224>>>0)<($210>>>0);
    if ($225) {
     $i3$013 = $224;
    } else {
     break;
    }
   }
  }
 } else {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE19resizeUninitializedEj($4,$13);
  $19 = HEAP32[$4>>2]|0;
  $20 = HEAP32[$5>>2]|0;
  $21 = (($19) + ($20<<4)|0);
  $22 = ($20|0)>(0);
  if ($22) {
   $$012$i$i = $19;$$03$i$i = $9;
   while(1) {
    $23 = ($$012$i$i|0)==(0|0);
    if (!($23)) {
     $24 = Math_fround(HEAPF32[$$03$i$i>>2]);
     HEAPF32[$$012$i$i>>2] = $24;
     $25 = (($$012$i$i) + 4|0);
     $26 = (($$03$i$i) + 4|0);
     $27 = Math_fround(HEAPF32[$26>>2]);
     HEAPF32[$25>>2] = $27;
     $28 = (($$012$i$i) + 8|0);
     $29 = (($$03$i$i) + 8|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     HEAPF32[$28>>2] = $30;
     $31 = (($$012$i$i) + 12|0);
     $32 = (($$03$i$i) + 12|0);
     $33 = Math_fround(HEAPF32[$32>>2]);
     HEAPF32[$31>>2] = $33;
    }
    $34 = (($$012$i$i) + 16|0);
    $35 = (($$03$i$i) + 16|0);
    $36 = ($34>>>0)<($21>>>0);
    if ($36) {
     $$012$i$i = $34;$$03$i$i = $35;
    } else {
     break;
    }
   }
  }
 }
 $226 = (($this) + 540|0);
 HEAP32[$226>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE13getNumSpheresEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 376|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE11setCapsulesENS0_5RangeIKjEEjj($this,$capsules,$first,$last) {
 $this = $this|0;
 $capsules = $capsules|0;
 $first = $first|0;
 $last = $last|0;
 var $$013$i = 0, $$026$i = 0, $$04$i = 0, $$17$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $exitcond = 0, $exitcond$i = 0, $i$03 = 0, $i1$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 360|0);
 $3 = (($this) + 364|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($capsules) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$capsules>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = $11 >>> 1;
 $13 = (($first) - ($last))|0;
 $14 = (($13) + ($4))|0;
 $15 = (($14) + ($12))|0;
 $16 = (($this) + 368|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2147483647;
 $19 = ($18>>>0)<($15>>>0);
 if ($19) {
  __ZN5physx6shdfnd5ArrayINS_5cloth9IndexPairENS0_9AllocatorEE8recreateEj($2,$15);
 }
 $20 = ($4>>>0)<($15>>>0);
 $21 = $20 ? $15 : $4;
 $22 = $0;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_5cloth9IndexPairENS0_9AllocatorEE6resizeEjRKS3_($2,$21,$0);
 $26 = ($15|0)==($4|0);
 if (!($26)) {
  $27 = (($15) - ($4))|0;
  $28 = HEAP32[$2>>2]|0;
  $29 = (($27) + ($last))|0;
  $30 = ($29>>>0)>($last>>>0);
  $31 = ($4>>>0)>($last>>>0);
  if ($30) {
   if ($31) {
    $$013$i = $4;$$04$i = $15;
    while(1) {
     $32 = (($$04$i) + -1)|0;
     $33 = (($28) + ($32<<3)|0);
     $34 = (($$013$i) + -1)|0;
     $35 = (($28) + ($34<<3)|0);
     $36 = $35;
     $37 = $36;
     $38 = HEAP32[$37>>2]|0;
     $39 = (($36) + 4)|0;
     $40 = $39;
     $41 = HEAP32[$40>>2]|0;
     $42 = $33;
     $43 = $42;
     HEAP32[$43>>2] = $38;
     $44 = (($42) + 4)|0;
     $45 = $44;
     HEAP32[$45>>2] = $41;
     $46 = ($34>>>0)>($last>>>0);
     if ($46) {
      $$013$i = $34;$$04$i = $32;
     } else {
      label = 9;
      break;
     }
    }
   } else {
    $i$03 = $last;
    label = 10;
   }
  } else {
   if ($31) {
    $$026$i = $last;$$17$i = $29;
    while(1) {
     $47 = (($$17$i) + 1)|0;
     $48 = (($28) + ($$17$i<<3)|0);
     $49 = (($$026$i) + 1)|0;
     $50 = (($28) + ($$026$i<<3)|0);
     $51 = $50;
     $52 = $51;
     $53 = HEAP32[$52>>2]|0;
     $54 = (($51) + 4)|0;
     $55 = $54;
     $56 = HEAP32[$55>>2]|0;
     $57 = $48;
     $58 = $57;
     HEAP32[$58>>2] = $53;
     $59 = (($57) + 4)|0;
     $60 = $59;
     HEAP32[$60>>2] = $56;
     $exitcond$i = ($49|0)==($4|0);
     if ($exitcond$i) {
      label = 9;
      break;
     } else {
      $$026$i = $49;$$17$i = $47;
     }
    }
   }
  }
  if ((label|0) == 9) {
   if ($30) {
    $i$03 = $last;
    label = 10;
   }
  }
  if ((label|0) == 10) {
   while(1) {
    label = 0;
    $61 = HEAP32[$2>>2]|0;
    $62 = (($61) + ($i$03<<3)|0);
    $63 = (($i$03) - ($first))|0;
    $64 = (($7) + ($63<<3)|0);
    $65 = $64;
    $66 = $65;
    $67 = HEAP32[$66>>2]|0;
    $68 = (($65) + 4)|0;
    $69 = $68;
    $70 = HEAP32[$69>>2]|0;
    $71 = $62;
    $72 = $71;
    HEAP32[$72>>2] = $67;
    $73 = (($71) + 4)|0;
    $74 = $73;
    HEAP32[$74>>2] = $70;
    $75 = (($i$03) + 1)|0;
    $76 = ($75>>>0)<($29>>>0);
    if ($76) {
     $i$03 = $75;
     label = 10;
    } else {
     break;
    }
   }
  }
  $77 = $1;
  $78 = $77;
  HEAP32[$78>>2] = 0;
  $79 = (($77) + 4)|0;
  $80 = $79;
  HEAP32[$80>>2] = 0;
  __ZN5physx6shdfnd5ArrayINS_5cloth9IndexPairENS0_9AllocatorEE6resizeEjRKS3_($2,$15,$1);
 }
 $81 = ($first>>>0)<($last>>>0);
 if (!($81)) {
  $97 = (($this) + 540|0);
  HEAP32[$97>>2] = 0;
  STACKTOP = sp;return;
 }
 $i1$02 = $first;
 while(1) {
  $82 = HEAP32[$2>>2]|0;
  $83 = (($82) + ($i1$02<<3)|0);
  $84 = (($i1$02) - ($first))|0;
  $85 = (($7) + ($84<<3)|0);
  $86 = $85;
  $87 = $86;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($86) + 4)|0;
  $90 = $89;
  $91 = HEAP32[$90>>2]|0;
  $92 = $83;
  $93 = $92;
  HEAP32[$93>>2] = $88;
  $94 = (($92) + 4)|0;
  $95 = $94;
  HEAP32[$95>>2] = $91;
  $96 = (($i1$02) + 1)|0;
  $exitcond = ($96|0)==($last|0);
  if ($exitcond) {
   break;
  } else {
   $i1$02 = $96;
  }
 }
 $97 = (($this) + 540|0);
 HEAP32[$97>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE14getNumCapsulesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 364|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE9setPlanesENS0_5RangeIKNS_6PxVec4EEEjj($this,$planes,$first,$last) {
 $this = $this|0;
 $planes = $planes|0;
 $first = $first|0;
 $last = $last|0;
 var $$012$i$i = 0, $$013$i = 0, $$013$i4 = 0, $$026$i = 0, $$026$i6 = 0, $$03$i$i = 0, $$04$i = 0, $$04$i3 = 0, $$17$i = 0, $$17$i5 = 0, $$not = 0, $$pre = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0;
 var $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0;
 var $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0;
 var $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0;
 var $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0;
 var $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cEnd$0$lcssa13 = 0, $cEnd$0$ph26 = 0, $cEnd$014 = 0, $cEnd$014$us = 0;
 var $cIt$0$ph24 = 0, $convex$0 = 0, $convex$0$lcssa = 0, $convex$0$us = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i7 = 0, $exitcond32 = 0, $i$020 = 0, $i2$016 = 0, $i3$012 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = (($this) + 408|0);
 $5 = (($this) + 412|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($planes) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$planes>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 4;
 $14 = (($first) - ($last))|0;
 $15 = (($14) + ($6))|0;
 $16 = (($15) + ($13))|0;
 $17 = ($6|0)!=(0);
 $$not = $17 ^ 1;
 $18 = ($16|0)==(0);
 $or$cond = $18 & $$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 if ($17) {
  $37 = ($6>>>0)<($16>>>0);
  $38 = $37 ? $16 : $6;
  $39 = (($this) + 416|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & 2147483647;
  $42 = (($this) + 420|0);
  $43 = (($this) + 428|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & 2147483647;
  $46 = ($41>>>0)<($45>>>0);
  $47 = $46 ? $41 : $45;
  $48 = ($38>>>0)>($47>>>0);
  if ($48) {
   $49 = ($41>>>0)<($16>>>0);
   if ($49) {
    __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($4,$16);
    $$pre = HEAP32[$43>>2]|0;
    $51 = $$pre;
   } else {
    $51 = $44;
   }
   $50 = $51 & 2147483647;
   $52 = ($50>>>0)<($38>>>0);
   if ($52) {
    __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE8recreateEj($42,$38);
   }
  }
  $53 = (($this) + 424|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54>>>0)<($6>>>0);
  L13: do {
   if ($55) {
    $61 = $54;$i$020 = $54;
    while(1) {
     $56 = HEAP32[$4>>2]|0;
     $57 = (($56) + ($i$020<<4)|0);
     $58 = HEAP32[$43>>2]|0;
     $59 = $58 & 2147483647;
     $60 = ($59>>>0)>($61>>>0);
     if ($60) {
      $62 = HEAP32[$42>>2]|0;
      $63 = (($62) + ($61<<4)|0);
      $64 = ($63|0)==(0|0);
      if (!($64)) {
       $65 = Math_fround(HEAPF32[$57>>2]);
       HEAPF32[$63>>2] = $65;
       $66 = ((($62) + ($61<<4)|0) + 4|0);
       $67 = ((($56) + ($i$020<<4)|0) + 4|0);
       $68 = Math_fround(HEAPF32[$67>>2]);
       HEAPF32[$66>>2] = $68;
       $69 = ((($62) + ($61<<4)|0) + 8|0);
       $70 = ((($56) + ($i$020<<4)|0) + 8|0);
       $71 = Math_fround(HEAPF32[$70>>2]);
       HEAPF32[$69>>2] = $71;
       $72 = ((($62) + ($61<<4)|0) + 12|0);
       $73 = ((($56) + ($i$020<<4)|0) + 12|0);
       $74 = Math_fround(HEAPF32[$73>>2]);
       HEAPF32[$72>>2] = $74;
      }
      $75 = (($61) + 1)|0;
      HEAP32[$53>>2] = $75;
     } else {
      (__ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE15growAndPushBackERKS2_($42,$57)|0);
     }
     $76 = (($i$020) + 1)|0;
     $exitcond32 = ($76|0)==($6|0);
     if ($exitcond32) {
      break L13;
     }
     $$pre33 = HEAP32[$53>>2]|0;
     $61 = $$pre33;$i$020 = $76;
    }
   }
  } while(0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($4,$38,$0);
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($42,$38,$1);
  $77 = (($16) - ($6))|0;
  $78 = ($16|0)==($6|0);
  if (!($78)) {
   $79 = HEAP32[$4>>2]|0;
   $80 = (($77) + ($last))|0;
   $81 = ($80>>>0)>($last>>>0);
   $82 = ($6>>>0)>($last>>>0);
   if ($81) {
    if ($82) {
     $$013$i4 = $6;$$04$i3 = $16;
     while(1) {
      $83 = (($$04$i3) + -1)|0;
      $84 = (($$013$i4) + -1)|0;
      $85 = (($79) + ($84<<4)|0);
      $86 = Math_fround(HEAPF32[$85>>2]);
      $87 = (($79) + ($83<<4)|0);
      HEAPF32[$87>>2] = $86;
      $88 = ((($79) + ($84<<4)|0) + 4|0);
      $89 = Math_fround(HEAPF32[$88>>2]);
      $90 = ((($79) + ($83<<4)|0) + 4|0);
      HEAPF32[$90>>2] = $89;
      $91 = ((($79) + ($84<<4)|0) + 8|0);
      $92 = Math_fround(HEAPF32[$91>>2]);
      $93 = ((($79) + ($83<<4)|0) + 8|0);
      HEAPF32[$93>>2] = $92;
      $94 = ((($79) + ($84<<4)|0) + 12|0);
      $95 = Math_fround(HEAPF32[$94>>2]);
      $96 = ((($79) + ($83<<4)|0) + 12|0);
      HEAPF32[$96>>2] = $95;
      $97 = ($84>>>0)>($last>>>0);
      if ($97) {
       $$013$i4 = $84;$$04$i3 = $83;
      } else {
       label = 27;
       break;
      }
     }
    } else {
     label = 32;
    }
   } else {
    if ($82) {
     $$026$i6 = $last;$$17$i5 = $80;
     while(1) {
      $98 = (($$17$i5) + 1)|0;
      $99 = (($$026$i6) + 1)|0;
      $100 = (($79) + ($$026$i6<<4)|0);
      $101 = Math_fround(HEAPF32[$100>>2]);
      $102 = (($79) + ($$17$i5<<4)|0);
      HEAPF32[$102>>2] = $101;
      $103 = ((($79) + ($$026$i6<<4)|0) + 4|0);
      $104 = Math_fround(HEAPF32[$103>>2]);
      $105 = ((($79) + ($$17$i5<<4)|0) + 4|0);
      HEAPF32[$105>>2] = $104;
      $106 = ((($79) + ($$026$i6<<4)|0) + 8|0);
      $107 = Math_fround(HEAPF32[$106>>2]);
      $108 = ((($79) + ($$17$i5<<4)|0) + 8|0);
      HEAPF32[$108>>2] = $107;
      $109 = ((($79) + ($$026$i6<<4)|0) + 12|0);
      $110 = Math_fround(HEAPF32[$109>>2]);
      $111 = ((($79) + ($$17$i5<<4)|0) + 12|0);
      HEAPF32[$111>>2] = $110;
      $exitcond$i7 = ($99|0)==($6|0);
      if ($exitcond$i7) {
       label = 27;
       break;
      } else {
       $$026$i6 = $99;$$17$i5 = $98;
      }
     }
    } else {
     label = 32;
    }
   }
   do {
    if ((label|0) == 27) {
     $112 = HEAP32[$42>>2]|0;
     if ($81) {
      if ($82) {
       $$013$i = $6;$$04$i = $16;
      } else {
       label = 33;
       break;
      }
      while(1) {
       $113 = (($$04$i) + -1)|0;
       $114 = (($$013$i) + -1)|0;
       $115 = (($112) + ($114<<4)|0);
       $116 = Math_fround(HEAPF32[$115>>2]);
       $117 = (($112) + ($113<<4)|0);
       HEAPF32[$117>>2] = $116;
       $118 = ((($112) + ($114<<4)|0) + 4|0);
       $119 = Math_fround(HEAPF32[$118>>2]);
       $120 = ((($112) + ($113<<4)|0) + 4|0);
       HEAPF32[$120>>2] = $119;
       $121 = ((($112) + ($114<<4)|0) + 8|0);
       $122 = Math_fround(HEAPF32[$121>>2]);
       $123 = ((($112) + ($113<<4)|0) + 8|0);
       HEAPF32[$123>>2] = $122;
       $124 = ((($112) + ($114<<4)|0) + 12|0);
       $125 = Math_fround(HEAPF32[$124>>2]);
       $126 = ((($112) + ($113<<4)|0) + 12|0);
       HEAPF32[$126>>2] = $125;
       $127 = ($114>>>0)>($last>>>0);
       if ($127) {
        $$013$i = $114;$$04$i = $113;
       } else {
        label = 32;
        break;
       }
      }
     } else {
      if ($82) {
       $$026$i = $last;$$17$i = $80;
      } else {
       break;
      }
      while(1) {
       $128 = (($$17$i) + 1)|0;
       $129 = (($$026$i) + 1)|0;
       $130 = (($112) + ($$026$i<<4)|0);
       $131 = Math_fround(HEAPF32[$130>>2]);
       $132 = (($112) + ($$17$i<<4)|0);
       HEAPF32[$132>>2] = $131;
       $133 = ((($112) + ($$026$i<<4)|0) + 4|0);
       $134 = Math_fround(HEAPF32[$133>>2]);
       $135 = ((($112) + ($$17$i<<4)|0) + 4|0);
       HEAPF32[$135>>2] = $134;
       $136 = ((($112) + ($$026$i<<4)|0) + 8|0);
       $137 = Math_fround(HEAPF32[$136>>2]);
       $138 = ((($112) + ($$17$i<<4)|0) + 8|0);
       HEAPF32[$138>>2] = $137;
       $139 = ((($112) + ($$026$i<<4)|0) + 12|0);
       $140 = Math_fround(HEAPF32[$139>>2]);
       $141 = ((($112) + ($$17$i<<4)|0) + 12|0);
       HEAPF32[$141>>2] = $140;
       $exitcond$i = ($129|0)==($6|0);
       if ($exitcond$i) {
        label = 32;
        break;
       } else {
        $$026$i = $129;$$17$i = $128;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 32) {
    if ($81) {
     label = 33;
    }
   }
   if ((label|0) == 33) {
    $142 = (($13) + ($first))|0;
    $i2$016 = $last;
    while(1) {
     $143 = (($i2$016) - ($first))|0;
     $144 = (($9) + ($143<<4)|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = (($79) + ($i2$016<<4)|0);
     HEAPF32[$146>>2] = $145;
     $147 = ((($9) + ($143<<4)|0) + 4|0);
     $148 = Math_fround(HEAPF32[$147>>2]);
     $149 = ((($79) + ($i2$016<<4)|0) + 4|0);
     HEAPF32[$149>>2] = $148;
     $150 = ((($9) + ($143<<4)|0) + 8|0);
     $151 = Math_fround(HEAPF32[$150>>2]);
     $152 = ((($79) + ($i2$016<<4)|0) + 8|0);
     HEAPF32[$152>>2] = $151;
     $153 = ((($9) + ($143<<4)|0) + 12|0);
     $154 = Math_fround(HEAPF32[$153>>2]);
     $155 = ((($79) + ($i2$016<<4)|0) + 12|0);
     HEAPF32[$155>>2] = $154;
     $156 = (($i2$016) + 1)|0;
     $exitcond = ($156|0)==($142|0);
     if ($exitcond) {
      break;
     } else {
      $i2$016 = $156;
     }
    }
   }
   $157 = ($77|0)<(0);
   $158 = $157 ? $77 : 0;
   $159 = (($158) + ($last))|0;
   $160 = 1 << $159;
   $161 = (($160) + -1)|0;
   $162 = (($this) + 396|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = (($this) + 400|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($165|0)==(0);
   L51: do {
    if (!($166)) {
     $167 = (($163) + ($165<<2)|0);
     $168 = (0 - ($77))|0;
     $169 = (0 - ($160))|0;
     $cEnd$0$ph26 = $167;$cIt$0$ph24 = $163;
     while(1) {
      $170 = $cIt$0$ph24;
      L55: do {
       if ($157) {
        $cEnd$014$us = $cEnd$0$ph26;
        while(1) {
         $171 = HEAP32[$cIt$0$ph24>>2]|0;
         $172 = $171 & $161;
         $173 = $171 >>> $168;
         $174 = $173 & $169;
         $convex$0$us = $174 | $172;
         $175 = ($convex$0$us|0)==(0);
         if (!($175)) {
          $cEnd$0$lcssa13 = $cEnd$014$us;$convex$0$lcssa = $convex$0$us;
          break L55;
         }
         $176 = $163;
         $177 = (($170) - ($176))|0;
         $178 = $177 >> 2;
         $179 = HEAP32[$164>>2]|0;
         $180 = (($179) + -1)|0;
         HEAP32[$164>>2] = $180;
         $181 = (($163) + ($180<<2)|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = (($163) + ($178<<2)|0);
         HEAP32[$183>>2] = $182;
         $184 = HEAP32[$164>>2]|0;
         $185 = (($163) + ($184<<2)|0);
         $186 = ($cIt$0$ph24|0)==($185|0);
         if ($186) {
          break L51;
         } else {
          $cEnd$014$us = $185;
         }
        }
       } else {
        $cEnd$014 = $cEnd$0$ph26;
        while(1) {
         $187 = HEAP32[$cIt$0$ph24>>2]|0;
         $188 = $187 & $161;
         $189 = $187 & $169;
         $190 = $189 << $77;
         $convex$0 = $190 | $188;
         $191 = ($convex$0|0)==(0);
         if (!($191)) {
          $cEnd$0$lcssa13 = $cEnd$014;$convex$0$lcssa = $convex$0;
          break L55;
         }
         $194 = $163;
         $195 = (($170) - ($194))|0;
         $196 = $195 >> 2;
         $197 = HEAP32[$164>>2]|0;
         $198 = (($197) + -1)|0;
         HEAP32[$164>>2] = $198;
         $199 = (($163) + ($198<<2)|0);
         $200 = HEAP32[$199>>2]|0;
         $201 = (($163) + ($196<<2)|0);
         HEAP32[$201>>2] = $200;
         $202 = HEAP32[$164>>2]|0;
         $203 = (($163) + ($202<<2)|0);
         $204 = ($cIt$0$ph24|0)==($203|0);
         if ($204) {
          break L51;
         } else {
          $cEnd$014 = $203;
         }
        }
       }
      } while(0);
      $192 = (($cIt$0$ph24) + 4|0);
      HEAP32[$cIt$0$ph24>>2] = $convex$0$lcssa;
      $193 = ($192|0)==($cEnd$0$lcssa13|0);
      if ($193) {
       break;
      } else {
       $cEnd$0$ph26 = $cEnd$0$lcssa13;$cIt$0$ph24 = $192;
      }
     }
    }
   } while(0);
   __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($4,$16,$2);
   __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($42,$16,$3);
  }
  $205 = ($8|0)==($9|0);
  if (!($205)) {
   $206 = HEAP32[$42>>2]|0;
   $i3$012 = 0;
   while(1) {
    $207 = (($i3$012) + ($first))|0;
    $208 = (($9) + ($i3$012<<4)|0);
    $209 = Math_fround(HEAPF32[$208>>2]);
    $210 = (($206) + ($207<<4)|0);
    HEAPF32[$210>>2] = $209;
    $211 = ((($9) + ($i3$012<<4)|0) + 4|0);
    $212 = Math_fround(HEAPF32[$211>>2]);
    $213 = ((($206) + ($207<<4)|0) + 4|0);
    HEAPF32[$213>>2] = $212;
    $214 = ((($9) + ($i3$012<<4)|0) + 8|0);
    $215 = Math_fround(HEAPF32[$214>>2]);
    $216 = ((($206) + ($207<<4)|0) + 8|0);
    HEAPF32[$216>>2] = $215;
    $217 = ((($9) + ($i3$012<<4)|0) + 12|0);
    $218 = Math_fround(HEAPF32[$217>>2]);
    $219 = ((($206) + ($207<<4)|0) + 12|0);
    HEAPF32[$219>>2] = $218;
    $220 = (($i3$012) + 1)|0;
    $221 = ($220>>>0)<($13>>>0);
    if ($221) {
     $i3$012 = $220;
    } else {
     break;
    }
   }
  }
 } else {
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE19resizeUninitializedEj($4,$13);
  $19 = HEAP32[$4>>2]|0;
  $20 = HEAP32[$5>>2]|0;
  $21 = (($19) + ($20<<4)|0);
  $22 = ($20|0)>(0);
  if ($22) {
   $$012$i$i = $19;$$03$i$i = $9;
   while(1) {
    $23 = ($$012$i$i|0)==(0|0);
    if (!($23)) {
     $24 = Math_fround(HEAPF32[$$03$i$i>>2]);
     HEAPF32[$$012$i$i>>2] = $24;
     $25 = (($$012$i$i) + 4|0);
     $26 = (($$03$i$i) + 4|0);
     $27 = Math_fround(HEAPF32[$26>>2]);
     HEAPF32[$25>>2] = $27;
     $28 = (($$012$i$i) + 8|0);
     $29 = (($$03$i$i) + 8|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     HEAPF32[$28>>2] = $30;
     $31 = (($$012$i$i) + 12|0);
     $32 = (($$03$i$i) + 12|0);
     $33 = Math_fround(HEAPF32[$32>>2]);
     HEAPF32[$31>>2] = $33;
    }
    $34 = (($$012$i$i) + 16|0);
    $35 = (($$03$i$i) + 16|0);
    $36 = ($34>>>0)<($21>>>0);
    if ($36) {
     $$012$i$i = $34;$$03$i$i = $35;
    } else {
     break;
    }
   }
  }
 }
 $222 = (($this) + 540|0);
 HEAP32[$222>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE12getNumPlanesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 412|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE11setConvexesENS0_5RangeIKjEEjj($this,$convexes,$first,$last) {
 $this = $this|0;
 $convexes = $convexes|0;
 $first = $first|0;
 $last = $last|0;
 var $$013$i = 0, $$026$i = 0, $$04$i = 0, $$17$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond$i = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 396|0);
 $3 = (($this) + 400|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($convexes) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$convexes>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = (($first) - ($last))|0;
 $13 = (($12) + ($4))|0;
 $14 = (($13) + ($11))|0;
 $15 = (($this) + 404|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = ($17>>>0)<($14>>>0);
 if ($18) {
  __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE8recreateEj($2,$14);
 }
 $19 = ($4>>>0)<($14>>>0);
 $20 = $19 ? $14 : $4;
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE6resizeEjRKj($2,$20,$0);
 $21 = ($14|0)==($4|0);
 if ($21) {
  $44 = (($this) + 540|0);
  HEAP32[$44>>2] = 0;
  STACKTOP = sp;return;
 }
 $22 = (($14) - ($4))|0;
 $23 = HEAP32[$2>>2]|0;
 $24 = (($22) + ($last))|0;
 $25 = ($24>>>0)>($last>>>0);
 $26 = ($4>>>0)>($last>>>0);
 if ($25) {
  if ($26) {
   $$013$i = $4;$$04$i = $14;
   while(1) {
    $27 = (($$013$i) + -1)|0;
    $28 = (($23) + ($27<<2)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($$04$i) + -1)|0;
    $31 = (($23) + ($30<<2)|0);
    HEAP32[$31>>2] = $29;
    $32 = ($27>>>0)>($last>>>0);
    if ($32) {
     $$013$i = $27;$$04$i = $30;
    } else {
     label = 9;
     break;
    }
   }
  } else {
   label = 10;
  }
 } else {
  if ($26) {
   $$026$i = $last;$$17$i = $24;
   while(1) {
    $33 = (($$026$i) + 1)|0;
    $34 = (($23) + ($$026$i<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($$17$i) + 1)|0;
    $37 = (($23) + ($$17$i<<2)|0);
    HEAP32[$37>>2] = $35;
    $exitcond$i = ($33|0)==($4|0);
    if ($exitcond$i) {
     label = 9;
     break;
    } else {
     $$026$i = $33;$$17$i = $36;
    }
   }
  }
 }
 if ((label|0) == 9) {
  if ($25) {
   label = 10;
  }
 }
 if ((label|0) == 10) {
  $38 = (($11) + ($first))|0;
  $i$01 = $last;
  while(1) {
   $39 = (($i$01) - ($first))|0;
   $40 = (($7) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($23) + ($i$01<<2)|0);
   HEAP32[$42>>2] = $41;
   $43 = (($i$01) + 1)|0;
   $exitcond = ($43|0)==($38|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $43;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE6resizeEjRKj($2,$14,$1);
 $44 = (($this) + 540|0);
 HEAP32[$44>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE14getNumConvexesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEEjj($this,$triangles,$first,$last) {
 $this = $this|0;
 $triangles = $triangles|0;
 $first = $first|0;
 $last = $last|0;
 var $$012$i$i = 0, $$013$i = 0, $$013$i5 = 0, $$026$i = 0, $$026$i7 = 0, $$03$i$i = 0, $$04$i = 0, $$04$i4 = 0, $$17$i = 0, $$17$i6 = 0, $$not = 0, $$pre = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0;
 var $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = Math_fround(0);
 var $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0);
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0;
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i8 = 0, $exitcond21 = 0, $i$018 = 0, $i2$014 = 0, $i3$013 = 0, $inttoptr = 0;
 var $or$cond = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast$byval_copy = sp + 64|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 40|0;
 $5 = sp + 52|0;
 $6 = ($first*3)|0;
 $7 = ($last*3)|0;
 $8 = $triangles;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $1;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 $18 = (($7) - ($6))|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 __ZN5physx5cloth7SwCloth18clampTriangleCountENS0_5RangeIKNS_6PxVec3EEEj($0,$tmpcast$byval_copy,$18);
 $19 = $0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $triangles;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = (($this) + 432|0);
 $30 = (($this) + 436|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $24;
 $inttoptr = $21;
 $33 = (($24) - ($21))|0;
 $34 = (($33|0) / 12)&-1;
 $35 = (($6) - ($7))|0;
 $36 = (($35) + ($31))|0;
 $37 = (($36) + ($34))|0;
 $38 = ($31|0)!=(0);
 $$not = $38 ^ 1;
 $39 = ($37|0)==(0);
 $or$cond = $39 & $$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 if ($38) {
  $55 = ($31>>>0)<($37>>>0);
  $56 = $55 ? $37 : $31;
  $57 = (($this) + 440|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = $58 & 2147483647;
  $60 = (($this) + 444|0);
  $61 = (($this) + 452|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = $62 & 2147483647;
  $64 = ($59>>>0)<($63>>>0);
  $65 = $64 ? $59 : $63;
  $66 = ($56>>>0)>($65>>>0);
  if ($66) {
   $67 = ($59>>>0)<($37>>>0);
   if ($67) {
    __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE8recreateEj($29,$37);
    $$pre = HEAP32[$61>>2]|0;
    $69 = $$pre;
   } else {
    $69 = $62;
   }
   $68 = $69 & 2147483647;
   $70 = ($68>>>0)<($56>>>0);
   if ($70) {
    __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE8recreateEj($60,$56);
   }
  }
  $71 = (($this) + 448|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72>>>0)<($31>>>0);
  L13: do {
   if ($73) {
    $79 = $72;$i$018 = $72;
    while(1) {
     $74 = HEAP32[$29>>2]|0;
     $75 = (($74) + (($i$018*12)|0)|0);
     $76 = HEAP32[$61>>2]|0;
     $77 = $76 & 2147483647;
     $78 = ($77>>>0)>($79>>>0);
     if ($78) {
      $80 = HEAP32[$60>>2]|0;
      $81 = (($80) + (($79*12)|0)|0);
      $82 = ($81|0)==(0|0);
      if (!($82)) {
       $83 = Math_fround(HEAPF32[$75>>2]);
       HEAPF32[$81>>2] = $83;
       $84 = ((($80) + (($79*12)|0)|0) + 4|0);
       $85 = ((($74) + (($i$018*12)|0)|0) + 4|0);
       $86 = Math_fround(HEAPF32[$85>>2]);
       HEAPF32[$84>>2] = $86;
       $87 = ((($80) + (($79*12)|0)|0) + 8|0);
       $88 = ((($74) + (($i$018*12)|0)|0) + 8|0);
       $89 = Math_fround(HEAPF32[$88>>2]);
       HEAPF32[$87>>2] = $89;
      }
      $90 = (($79) + 1)|0;
      HEAP32[$71>>2] = $90;
     } else {
      (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE15growAndPushBackERKS2_($60,$75)|0);
     }
     $91 = (($i$018) + 1)|0;
     $exitcond21 = ($91|0)==($31|0);
     if ($exitcond21) {
      break L13;
     }
     $$pre22 = HEAP32[$71>>2]|0;
     $79 = $$pre22;$i$018 = $91;
    }
   }
  } while(0);
  __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE6resizeEjRKS2_($29,$56,$2);
  __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE6resizeEjRKS2_($60,$56,$3);
  $92 = ($37|0)==($31|0);
  if (!($92)) {
   $93 = (($37) - ($31))|0;
   $94 = HEAP32[$29>>2]|0;
   $95 = (($93) + ($7))|0;
   $96 = ($95>>>0)>($7>>>0);
   do {
    if ($96) {
     $99 = ($31>>>0)>($7>>>0);
     if ($99) {
      $$013$i5 = $31;$$04$i4 = $37;
      while(1) {
       $101 = (($$04$i4) + -1)|0;
       $102 = (($$013$i5) + -1)|0;
       $103 = (($94) + (($102*12)|0)|0);
       $104 = Math_fround(HEAPF32[$103>>2]);
       $105 = (($94) + (($101*12)|0)|0);
       HEAPF32[$105>>2] = $104;
       $106 = ((($94) + (($102*12)|0)|0) + 4|0);
       $107 = Math_fround(HEAPF32[$106>>2]);
       $108 = ((($94) + (($101*12)|0)|0) + 4|0);
       HEAPF32[$108>>2] = $107;
       $109 = ((($94) + (($102*12)|0)|0) + 8|0);
       $110 = Math_fround(HEAPF32[$109>>2]);
       $111 = ((($94) + (($101*12)|0)|0) + 8|0);
       HEAPF32[$111>>2] = $110;
       $112 = ($102>>>0)>($7>>>0);
       if ($112) {
        $$013$i5 = $102;$$04$i4 = $101;
       } else {
        label = 29;
        break;
       }
      }
     } else {
      $100 = HEAP32[$60>>2]|0;
      $130 = $100;
      label = 31;
      break;
     }
    } else {
     $97 = ($7>>>0)<($31>>>0);
     if ($97) {
      $$026$i7 = $7;$$17$i6 = $95;
      while(1) {
       $113 = (($$17$i6) + 1)|0;
       $114 = (($$026$i7) + 1)|0;
       $115 = (($94) + (($$026$i7*12)|0)|0);
       $116 = Math_fround(HEAPF32[$115>>2]);
       $117 = (($94) + (($$17$i6*12)|0)|0);
       HEAPF32[$117>>2] = $116;
       $118 = ((($94) + (($$026$i7*12)|0)|0) + 4|0);
       $119 = Math_fround(HEAPF32[$118>>2]);
       $120 = ((($94) + (($$17$i6*12)|0)|0) + 4|0);
       HEAPF32[$120>>2] = $119;
       $121 = ((($94) + (($$026$i7*12)|0)|0) + 8|0);
       $122 = Math_fround(HEAPF32[$121>>2]);
       $123 = ((($94) + (($$17$i6*12)|0)|0) + 8|0);
       HEAPF32[$123>>2] = $122;
       $exitcond$i8 = ($114|0)==($31|0);
       if ($exitcond$i8) {
        label = 29;
        break;
       } else {
        $$026$i7 = $114;$$17$i6 = $113;
       }
      }
     } else {
      $98 = HEAP32[$60>>2]|0;
      $143 = $98;
      label = 30;
      break;
     }
    }
   } while(0);
   if ((label|0) == 29) {
    $124 = HEAP32[$60>>2]|0;
    if ($96) {
     $130 = $124;
     label = 31;
    } else {
     $143 = $124;
     label = 30;
    }
   }
   if ((label|0) == 30) {
    $125 = ($7>>>0)<($31>>>0);
    if ($125) {
     $$026$i = $7;$$17$i = $95;
     while(1) {
      $140 = (($$17$i) + 1)|0;
      $141 = (($$026$i) + 1)|0;
      $142 = (($143) + (($$026$i*12)|0)|0);
      $144 = Math_fround(HEAPF32[$142>>2]);
      $145 = (($143) + (($$17$i*12)|0)|0);
      HEAPF32[$145>>2] = $144;
      $146 = ((($143) + (($$026$i*12)|0)|0) + 4|0);
      $147 = Math_fround(HEAPF32[$146>>2]);
      $148 = ((($143) + (($$17$i*12)|0)|0) + 4|0);
      HEAPF32[$148>>2] = $147;
      $149 = ((($143) + (($$026$i*12)|0)|0) + 8|0);
      $150 = Math_fround(HEAPF32[$149>>2]);
      $151 = ((($143) + (($$17$i*12)|0)|0) + 8|0);
      HEAPF32[$151>>2] = $150;
      $exitcond$i = ($141|0)==($31|0);
      if ($exitcond$i) {
       break;
      } else {
       $$026$i = $141;$$17$i = $140;
      }
     }
    }
   }
   else if ((label|0) == 31) {
    $126 = ($31>>>0)>($7>>>0);
    if ($126) {
     $$013$i = $31;$$04$i = $37;
     while(1) {
      $127 = (($$04$i) + -1)|0;
      $128 = (($$013$i) + -1)|0;
      $129 = (($130) + (($128*12)|0)|0);
      $131 = Math_fround(HEAPF32[$129>>2]);
      $132 = (($130) + (($127*12)|0)|0);
      HEAPF32[$132>>2] = $131;
      $133 = ((($130) + (($128*12)|0)|0) + 4|0);
      $134 = Math_fround(HEAPF32[$133>>2]);
      $135 = ((($130) + (($127*12)|0)|0) + 4|0);
      HEAPF32[$135>>2] = $134;
      $136 = ((($130) + (($128*12)|0)|0) + 8|0);
      $137 = Math_fround(HEAPF32[$136>>2]);
      $138 = ((($130) + (($127*12)|0)|0) + 8|0);
      HEAPF32[$138>>2] = $137;
      $139 = ($128>>>0)>($7>>>0);
      if ($139) {
       $$013$i = $128;$$04$i = $127;
      } else {
       break;
      }
     }
    }
   }
   if ($96) {
    $152 = (($34) + ($6))|0;
    $i2$014 = $7;
    while(1) {
     $153 = (($i2$014) - ($6))|0;
     $154 = (($inttoptr) + (($153*12)|0)|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = (($94) + (($i2$014*12)|0)|0);
     HEAPF32[$156>>2] = $155;
     $157 = ((($inttoptr) + (($153*12)|0)|0) + 4|0);
     $158 = Math_fround(HEAPF32[$157>>2]);
     $159 = ((($94) + (($i2$014*12)|0)|0) + 4|0);
     HEAPF32[$159>>2] = $158;
     $160 = ((($inttoptr) + (($153*12)|0)|0) + 8|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = ((($94) + (($i2$014*12)|0)|0) + 8|0);
     HEAPF32[$162>>2] = $161;
     $163 = (($i2$014) + 1)|0;
     $exitcond = ($163|0)==($152|0);
     if ($exitcond) {
      break;
     } else {
      $i2$014 = $163;
     }
    }
   }
   __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE6resizeEjRKS2_($29,$37,$4);
   __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE6resizeEjRKS2_($60,$37,$5);
  }
  $164 = ($32|0)==($inttoptr|0);
  if (!($164)) {
   $165 = HEAP32[$60>>2]|0;
   $i3$013 = 0;
   while(1) {
    $166 = (($i3$013) + ($6))|0;
    $167 = (($inttoptr) + (($i3$013*12)|0)|0);
    $168 = Math_fround(HEAPF32[$167>>2]);
    $169 = (($165) + (($166*12)|0)|0);
    HEAPF32[$169>>2] = $168;
    $170 = ((($inttoptr) + (($i3$013*12)|0)|0) + 4|0);
    $171 = Math_fround(HEAPF32[$170>>2]);
    $172 = ((($165) + (($166*12)|0)|0) + 4|0);
    HEAPF32[$172>>2] = $171;
    $173 = ((($inttoptr) + (($i3$013*12)|0)|0) + 8|0);
    $174 = Math_fround(HEAPF32[$173>>2]);
    $175 = ((($165) + (($166*12)|0)|0) + 8|0);
    HEAPF32[$175>>2] = $174;
    $176 = (($i3$013) + 1)|0;
    $177 = ($176>>>0)<($34>>>0);
    if ($177) {
     $i3$013 = $176;
    } else {
     break;
    }
   }
  }
 } else {
  __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE19resizeUninitializedEj($29,$34);
  $40 = HEAP32[$29>>2]|0;
  $41 = HEAP32[$30>>2]|0;
  $42 = (($40) + (($41*12)|0)|0);
  $43 = ($41|0)>(0);
  if ($43) {
   $$012$i$i = $40;$$03$i$i = $inttoptr;
   while(1) {
    $44 = ($$012$i$i|0)==(0|0);
    if (!($44)) {
     $45 = Math_fround(HEAPF32[$$03$i$i>>2]);
     HEAPF32[$$012$i$i>>2] = $45;
     $46 = (($$012$i$i) + 4|0);
     $47 = (($$03$i$i) + 4|0);
     $48 = Math_fround(HEAPF32[$47>>2]);
     HEAPF32[$46>>2] = $48;
     $49 = (($$012$i$i) + 8|0);
     $50 = (($$03$i$i) + 8|0);
     $51 = Math_fround(HEAPF32[$50>>2]);
     HEAPF32[$49>>2] = $51;
    }
    $52 = (($$012$i$i) + 12|0);
    $53 = (($$03$i$i) + 12|0);
    $54 = ($52>>>0)<($42>>>0);
    if ($54) {
     $$012$i$i = $52;$$03$i$i = $53;
    } else {
     break;
    }
   }
  }
 }
 $178 = (($this) + 540|0);
 HEAP32[$178>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEES7_j($this,$startTriangles,$targetTriangles,$first) {
 $this = $this|0;
 $startTriangles = $startTriangles|0;
 $targetTriangles = $targetTriangles|0;
 $first = $first|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$07 = 0, $inttoptr = 0, $tmpcast2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast2$byval_copy = sp + 56|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 16|0;
 $3 = sp + 24|0;
 $4 = sp + 32|0;
 $5 = sp + 44|0;
 $6 = ($first*3)|0;
 $7 = (($this) + 432|0);
 $8 = (($this) + 436|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $startTriangles;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $1;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = (($9) - ($6))|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 __ZN5physx5cloth7SwCloth18clampTriangleCountENS0_5RangeIKNS_6PxVec3EEEj($0,$tmpcast2$byval_copy,$20);
 $21 = $0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 4)|0;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = $startTriangles;
 $28 = $27;
 HEAP32[$28>>2] = $23;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $26;
 $31 = $targetTriangles;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $3;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 __ZN5physx5cloth7SwCloth18clampTriangleCountENS0_5RangeIKNS_6PxVec3EEEj($2,$tmpcast2$byval_copy,$20);
 $41 = $2;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($41) + 4)|0;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = $targetTriangles;
 $48 = $47;
 HEAP32[$48>>2] = $43;
 $49 = (($47) + 4)|0;
 $50 = $49;
 HEAP32[$50>>2] = $46;
 $51 = HEAP32[$8>>2]|0;
 $52 = $26;
 $inttoptr = $23;
 $53 = (($26) - ($23))|0;
 $54 = (($53|0) / 12)&-1;
 $55 = (($6) - ($9))|0;
 $56 = (($55) + ($51))|0;
 $57 = (($56) + ($54))|0;
 $58 = $57 | $51;
 $59 = ($58|0)==(0);
 $60 = $43;
 if ($59) {
  STACKTOP = sp;return;
 }
 $61 = (($this) + 440|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = $62 & 2147483647;
 $64 = (($this) + 444|0);
 $65 = (($this) + 452|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 & 2147483647;
 $68 = ($63>>>0)<($67>>>0);
 $69 = $68 ? $63 : $67;
 $70 = ($57>>>0)>($69>>>0);
 if ($70) {
  $71 = ($63>>>0)<($57>>>0);
  if ($71) {
   __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE8recreateEj($7,$57);
   $$pre = HEAP32[$65>>2]|0;
   $73 = $$pre;
  } else {
   $73 = $66;
  }
  $72 = $73 & 2147483647;
  $74 = ($72>>>0)<($57>>>0);
  if ($74) {
   __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE8recreateEj($64,$57);
  }
 }
 $75 = (($51) - ($9))|0;
 $76 = (($75) + ($6))|0;
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE6resizeEjRKS2_($7,$76,$4);
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE6resizeEjRKS2_($64,$76,$5);
 $77 = ($52|0)==($inttoptr|0);
 if (!($77)) {
  $78 = (($this) + 448|0);
  $i$07 = 0;
  while(1) {
   $79 = (($inttoptr) + (($i$07*12)|0)|0);
   $80 = HEAP32[$61>>2]|0;
   $81 = $80 & 2147483647;
   $82 = HEAP32[$8>>2]|0;
   $83 = ($81>>>0)>($82>>>0);
   if ($83) {
    $84 = HEAP32[$7>>2]|0;
    $85 = (($84) + (($82*12)|0)|0);
    $86 = ($85|0)==(0|0);
    if (!($86)) {
     $87 = Math_fround(HEAPF32[$79>>2]);
     HEAPF32[$85>>2] = $87;
     $88 = ((($84) + (($82*12)|0)|0) + 4|0);
     $89 = ((($inttoptr) + (($i$07*12)|0)|0) + 4|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     HEAPF32[$88>>2] = $90;
     $91 = ((($84) + (($82*12)|0)|0) + 8|0);
     $92 = ((($inttoptr) + (($i$07*12)|0)|0) + 8|0);
     $93 = Math_fround(HEAPF32[$92>>2]);
     HEAPF32[$91>>2] = $93;
    }
    $94 = (($82) + 1)|0;
    HEAP32[$8>>2] = $94;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE15growAndPushBackERKS2_($7,$79)|0);
   }
   $95 = (($60) + (($i$07*12)|0)|0);
   $96 = HEAP32[$65>>2]|0;
   $97 = $96 & 2147483647;
   $98 = HEAP32[$78>>2]|0;
   $99 = ($97>>>0)>($98>>>0);
   if ($99) {
    $100 = HEAP32[$64>>2]|0;
    $101 = (($100) + (($98*12)|0)|0);
    $102 = ($101|0)==(0|0);
    if (!($102)) {
     $103 = Math_fround(HEAPF32[$95>>2]);
     HEAPF32[$101>>2] = $103;
     $104 = ((($100) + (($98*12)|0)|0) + 4|0);
     $105 = ((($60) + (($i$07*12)|0)|0) + 4|0);
     $106 = Math_fround(HEAPF32[$105>>2]);
     HEAPF32[$104>>2] = $106;
     $107 = ((($100) + (($98*12)|0)|0) + 8|0);
     $108 = ((($60) + (($i$07*12)|0)|0) + 8|0);
     $109 = Math_fround(HEAPF32[$108>>2]);
     HEAPF32[$107>>2] = $109;
    }
    $110 = (($98) + 1)|0;
    HEAP32[$78>>2] = $110;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE15growAndPushBackERKS2_($64,$95)|0);
   }
   $111 = (($i$07) + 1)|0;
   $112 = ($111>>>0)<($54>>>0);
   if ($112) {
    $i$07 = $111;
   } else {
    break;
   }
  }
 }
 $113 = (($this) + 540|0);
 HEAP32[$113>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE15getNumTrianglesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 436|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1>>>0) / 3)&-1;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE28isContinuousCollisionEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 456|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE25enableContinuousCollisionEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $enable&1;
 $1 = (($this) + 456|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = ($0|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $enable&1;
 HEAP8[$1>>0] = $5;
 $6 = (($this) + 540|0);
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE21getCollisionMassScaleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 460|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE21setCollisionMassScaleEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 460|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $scale;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $scale;
 $3 = (($this) + 540|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE11setFrictionEf($this,$friction) {
 $this = $this|0;
 $friction = Math_fround($friction);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 464|0);
 HEAPF32[$0>>2] = $friction;
 $1 = (($this) + 540|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE11getFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 464|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE28getNumVirtualParticleWeightsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 484|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE24setTetherConstraintScaleEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $scale;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $scale;
 $3 = (($this) + 540|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE24getTetherConstraintScaleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE28setTetherConstraintStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(Math_fround(1.0) - $stiffness);
 $1 = $0 != Math_fround(0.0);
 if ($1) {
  $2 = +$0;
  $3 = (+Math_log((+$2)));
  $4 = $3 / 0.693147182464599609375;
  $5 = Math_fround($4);
  $9 = $5;
 } else {
  $9 = Math_fround(-128.0);
 }
 $6 = (($this) + 280|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $9 == $7;
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAPF32[$6>>2] = $9;
 $10 = (($this) + 540|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE28getTetherConstraintStiffnessEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i = $6;
 } else {
  $$0$i = Math_fround(0.0);
 }
 $7 = Math_fround(Math_fround(1.0) - $$0$i);
 STACKTOP = sp;return (Math_fround($7));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE20getMotionConstraintsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 540|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 288|0);
 __ZN5physx5cloth7SwCloth4pushERNS0_13SwConstraintsE($agg$result,$0,$2);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE22clearMotionConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 288|0);
 __ZN5physx5cloth7SwCloth5clearERNS0_13SwConstraintsE($0);
 $1 = (($this) + 540|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE23getNumMotionConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 292|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE28setMotionConstraintScaleBiasEff($this,$scale,$bias) {
 $this = $this|0;
 $scale = Math_fround($scale);
 $bias = Math_fround($bias);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 312|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $scale;
 $3 = (($this) + 316|0);
 if ($2) {
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == $bias;
  if ($5) {
   STACKTOP = sp;return;
  }
 }
 HEAPF32[$0>>2] = $scale;
 HEAPF32[$3>>2] = $bias;
 $6 = (($this) + 540|0);
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE24getMotionConstraintScaleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 312|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE23getMotionConstraintBiasEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 316|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE28setMotionConstraintStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(Math_fround(1.0) - $stiffness);
 $1 = $0 != Math_fround(0.0);
 if ($1) {
  $2 = +$0;
  $3 = (+Math_log((+$2)));
  $4 = $3 / 0.693147182464599609375;
  $5 = Math_fround($4);
  $9 = $5;
 } else {
  $9 = Math_fround(-128.0);
 }
 $6 = (($this) + 320|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $9 == $7;
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAPF32[$6>>2] = $9;
 $10 = (($this) + 540|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE28getMotionConstraintStiffnessEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i = $6;
 } else {
  $$0$i = Math_fround(0.0);
 }
 $7 = Math_fround(Math_fround(1.0) - $$0$i);
 STACKTOP = sp;return (Math_fround($7));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE24getSeparationConstraintsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 540|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 324|0);
 __ZN5physx5cloth7SwCloth4pushERNS0_13SwConstraintsE($agg$result,$0,$2);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE26clearSeparationConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 324|0);
 __ZN5physx5cloth7SwCloth5clearERNS0_13SwConstraintsE($0);
 $1 = (($this) + 540|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE27getNumSeparationConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 328|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE18clearInterpolationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 384|0);
 $3 = (($this) + 388|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($this) + 372|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$2>>2]|0;
  HEAP32[$6>>2] = $8;
  HEAP32[$2>>2] = $7;
  $9 = (($this) + 376|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$9>>2] = $4;
  HEAP32[$3>>2] = $10;
  $11 = (($this) + 380|0);
  $12 = (($this) + 392|0);
  $13 = HEAP32[$11>>2]|0;
  $14 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $14;
  HEAP32[$12>>2] = $13;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($2,0,$1);
 }
 $15 = (($this) + 300|0);
 $16 = (($this) + 304|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = (($this) + 288|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$15>>2]|0;
  HEAP32[$19>>2] = $21;
  HEAP32[$15>>2] = $20;
  $22 = (($this) + 292|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$22>>2] = $17;
  HEAP32[$16>>2] = $23;
  $24 = (($this) + 296|0);
  $25 = (($this) + 308|0);
  $26 = HEAP32[$24>>2]|0;
  $27 = HEAP32[$25>>2]|0;
  HEAP32[$24>>2] = $27;
  HEAP32[$25>>2] = $26;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($15,0,$0);
 }
 $28 = (($this) + 336|0);
 $29 = (($this) + 340|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if ($31) {
  $41 = (($this) + 540|0);
  HEAP32[$41>>2] = 0;
  STACKTOP = sp;return;
 }
 $32 = (($this) + 324|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$28>>2]|0;
 HEAP32[$32>>2] = $34;
 HEAP32[$28>>2] = $33;
 $35 = (($this) + 328|0);
 $36 = HEAP32[$35>>2]|0;
 HEAP32[$35>>2] = $30;
 HEAP32[$29>>2] = $36;
 $37 = (($this) + 332|0);
 $38 = (($this) + 344|0);
 $39 = HEAP32[$37>>2]|0;
 $40 = HEAP32[$38>>2]|0;
 HEAP32[$37>>2] = $40;
 HEAP32[$38>>2] = $39;
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($28,0,$0);
 $41 = (($this) + 540|0);
 HEAP32[$41>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE27getNumParticleAccelerationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 352|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE24setSelfCollisionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 496|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $distance;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $distance;
 $3 = (($this) + 540|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE24getSelfCollisionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 496|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE25setSelfCollisionStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(Math_fround(1.0) - $stiffness);
 $1 = $0 != Math_fround(0.0);
 if ($1) {
  $2 = +$0;
  $3 = (+Math_log((+$2)));
  $4 = $3 / 0.693147182464599609375;
  $5 = Math_fround($4);
  $9 = $5;
 } else {
  $9 = Math_fround(-128.0);
 }
 $6 = (($this) + 500|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $9 == $7;
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAPF32[$6>>2] = $9;
 $10 = (($this) + 540|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE25getSelfCollisionStiffnessEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 500|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i = $6;
 } else {
  $$0$i = Math_fround(0.0);
 }
 $7 = Math_fround(Math_fround(1.0) - $$0$i);
 STACKTOP = sp;return (Math_fround($7));
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE26getNumSelfCollisionIndicesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE16setRestPositionsENS0_5RangeIKNS_6PxVec4EEE($this,$restPositions) {
 $this = $this|0;
 $restPositions = $restPositions|0;
 var $$012$i$i = 0, $$03$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 516|0);
 $1 = HEAP32[$restPositions>>2]|0;
 $2 = (($restPositions) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3;
 $5 = $1;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE19resizeUninitializedEj($0,$7);
 $8 = HEAP32[$0>>2]|0;
 $9 = (($this) + 520|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + ($10<<4)|0);
 $12 = ($10|0)>(0);
 if ($12) {
  $$012$i$i = $8;$$03$i$i = $1;
 } else {
  $27 = (($this) + 540|0);
  HEAP32[$27>>2] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $13 = ($$012$i$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$$03$i$i>>2]);
   HEAPF32[$$012$i$i>>2] = $14;
   $15 = (($$012$i$i) + 4|0);
   $16 = (($$03$i$i) + 4|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   HEAPF32[$15>>2] = $17;
   $18 = (($$012$i$i) + 8|0);
   $19 = (($$03$i$i) + 8|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   HEAPF32[$18>>2] = $20;
   $21 = (($$012$i$i) + 12|0);
   $22 = (($$03$i$i) + 12|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$21>>2] = $23;
  }
  $24 = (($$012$i$i) + 16|0);
  $25 = (($$03$i$i) + 16|0);
  $26 = ($24>>>0)<($11>>>0);
  if ($26) {
   $$012$i$i = $24;$$03$i$i = $25;
  } else {
   break;
  }
 }
 $27 = (($this) + 540|0);
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE19getNumRestPositionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 520|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE20getBoundingBoxCenterEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE19getBoundingBoxScaleEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE17setSleepThresholdEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 536|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $threshold;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $threshold;
 $3 = (($this) + 540|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE17getSleepThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 536|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE20setSleepTestIntervalEj($this,$interval) {
 $this = $this|0;
 $interval = $interval|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 528|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($interval|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $interval;
 $3 = (($this) + 540|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE20getSleepTestIntervalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 528|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE18setSleepAfterCountEj($this,$afterCount) {
 $this = $this|0;
 $afterCount = $afterCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 532|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($afterCount|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $afterCount;
 $3 = (($this) + 540|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE18getSleepAfterCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 532|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE17getSleepPassCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 540|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE8isAsleepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 540|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 532|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)>=($3>>>0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE10putToSleepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 532|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 540|0);
 HEAP32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE6wakeUpEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 540|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth9ClothImplINS0_7SwClothEE11setUserDataEPv($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 548|0);
 HEAP32[$0>>2] = $data;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth9ClothImplINS0_7SwClothEE11getUserDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 548|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((478800 + 8|0));
 $1 = ($this);
 HEAP32[$1>>2] = ((478800 + 424|0));
 $2 = (($this) + 12|0);
 __ZN5physx5cloth7SwClothD2Ev($2);
 HEAP32[$0>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($0);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((478800 + 8|0));
 $1 = ($this);
 HEAP32[$1>>2] = ((478800 + 424|0));
 $2 = (($this) + 12|0);
 __ZN5physx5cloth7SwClothD2Ev($2);
 HEAP32[$0>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($0);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE9getFabricEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 STACKTOP = sp;return ($2|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE10getFactoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 STACKTOP = sp;return ($2|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE14setTranslationERKNS_6PxVec3E($this,$trans) {
 $this = $this|0;
 $trans = $trans|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$trans>>2]);
 $1 = (($trans) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($trans) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 176|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 180|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 184|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 184|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 536|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setRotationERKNS_6PxQuatE($this,$q) {
 $this = $this|0;
 $q = $q|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$q>>2]);
 $1 = (($this) + 160|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 - $2);
 $4 = (($q) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 164|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($q) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 168|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = (($q) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 172|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = Math_fround($3 * $3);
 $20 = Math_fround($8 * $8);
 $21 = Math_fround($19 + $20);
 $22 = Math_fround($13 * $13);
 $23 = Math_fround($21 + $22);
 $24 = Math_fround($18 * $18);
 $25 = Math_fround($23 + $24);
 $26 = $25 == Math_fround(0.0);
 if ($26) {
  STACKTOP = sp;return;
 }
 HEAPF32[$1>>2] = $0;
 $27 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$6>>2] = $27;
 $28 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$11>>2] = $28;
 $29 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$16>>2] = $29;
 $30 = (($this) + 536|0);
 HEAP32[$30>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE14getTranslationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 176|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE11getRotationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE12clearInertiaEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0;
 var $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 188|0);
 HEAPF32[$2>>2] = $1;
 $3 = (($this) + 164|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 192|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($this) + 168|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 196|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($this) + 172|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 200|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($this) + 176|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 204|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($this) + 180|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 208|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($this) + 184|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 212|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($this) + 216|0);
 $22 = (($this) + 536|0);
 HEAP32[$22>>2] = 0;
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;HEAP32[$21+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE8teleportERKNS_6PxVec3E($this,$delta) {
 $this = $this|0;
 $delta = $delta|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $3 = Math_fround(0);
 var $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$delta>>2]);
 $1 = (($this) + 204|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 HEAPF32[$1>>2] = $3;
 $4 = (($delta) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 208|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 HEAPF32[$6>>2] = $8;
 $9 = (($delta) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 212|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 HEAPF32[$11>>2] = $13;
 $14 = Math_fround(HEAPF32[$delta>>2]);
 $15 = (($this) + 176|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 + $16);
 HEAPF32[$15>>2] = $17;
 $18 = Math_fround(HEAPF32[$4>>2]);
 $19 = (($this) + 180|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 + $20);
 HEAPF32[$19>>2] = $21;
 $22 = Math_fround(HEAPF32[$9>>2]);
 $23 = (($this) + 184|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 + $24);
 HEAPF32[$23>>2] = $25;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE22getPreviousIterationDtEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 240|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE10setGravityERKNS_6PxVec3E($this,$gravity) {
 $this = $this|0;
 $gravity = $gravity|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$gravity>>2]);
 $1 = (($gravity) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($gravity) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 68|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 72|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 76|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 76|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 536|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE10getGravityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 72|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 76|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE10setDampingERKNS_6PxVec3E($this,$damping) {
 $this = $this|0;
 $damping = $damping|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE10setDampingERKNS_6PxVec3E($0,$damping);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE10getDampingEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i$i$i = Math_fround(0), $$0$i1$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0.0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0.0, $19 = 0.0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i$i = $6;
 } else {
  $$0$i$i$i = Math_fround(0.0);
 }
 $7 = (($this) + 84|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 <= Math_fround(-128.0));
 if ($9) {
  $10 = Math_fround($8 * Math_fround(0.693147182464599609375));
  $11 = +$10;
  $12 = (+Math_exp((+$11)));
  $13 = Math_fround($12);
  $$0$i1$i$i = $13;
 } else {
  $$0$i1$i$i = Math_fround(0.0);
 }
 $14 = (($this) + 88|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = !($15 <= Math_fround(-128.0));
 if ($16) {
  $17 = Math_fround($15 * Math_fround(0.693147182464599609375));
  $18 = +$17;
  $19 = (+Math_exp((+$18)));
  $20 = Math_fround($19);
  $$0$i3$i$i = $20;
 } else {
  $$0$i3$i$i = Math_fround(0.0);
 }
 $21 = Math_fround(Math_fround(1.0) - $$0$i$i$i);
 $22 = Math_fround(Math_fround(1.0) - $$0$i1$i$i);
 $23 = Math_fround(Math_fround(1.0) - $$0$i3$i$i);
 HEAPF32[$agg$result>>2] = $21;
 $24 = (($agg$result) + 4|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($agg$result) + 8|0);
 HEAPF32[$25>>2] = $23;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE13setLinearDragERKNS_6PxVec3E($this,$drag) {
 $this = $this|0;
 $drag = $drag|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE13setLinearDragERKNS_6PxVec3E($0,$drag);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE13getLinearDragEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i$i$i = Math_fround(0), $$0$i1$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0.0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0.0, $19 = 0.0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i$i = $6;
 } else {
  $$0$i$i$i = Math_fround(0.0);
 }
 $7 = (($this) + 96|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 <= Math_fround(-128.0));
 if ($9) {
  $10 = Math_fround($8 * Math_fround(0.693147182464599609375));
  $11 = +$10;
  $12 = (+Math_exp((+$11)));
  $13 = Math_fround($12);
  $$0$i1$i$i = $13;
 } else {
  $$0$i1$i$i = Math_fround(0.0);
 }
 $14 = (($this) + 100|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = !($15 <= Math_fround(-128.0));
 if ($16) {
  $17 = Math_fround($15 * Math_fround(0.693147182464599609375));
  $18 = +$17;
  $19 = (+Math_exp((+$18)));
  $20 = Math_fround($19);
  $$0$i3$i$i = $20;
 } else {
  $$0$i3$i$i = Math_fround(0.0);
 }
 $21 = Math_fround(Math_fround(1.0) - $$0$i$i$i);
 $22 = Math_fround(Math_fround(1.0) - $$0$i1$i$i);
 $23 = Math_fround(Math_fround(1.0) - $$0$i3$i$i);
 HEAPF32[$agg$result>>2] = $21;
 $24 = (($agg$result) + 4|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($agg$result) + 8|0);
 HEAPF32[$25>>2] = $23;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE14setAngularDragERKNS_6PxVec3E($this,$drag) {
 $this = $this|0;
 $drag = $drag|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE14setAngularDragERKNS_6PxVec3E($0,$drag);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE14getAngularDragEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i$i$i = Math_fround(0), $$0$i1$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0.0, $12 = 0.0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0.0, $19 = 0.0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i$i = $6;
 } else {
  $$0$i$i$i = Math_fround(0.0);
 }
 $7 = (($this) + 108|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 <= Math_fround(-128.0));
 if ($9) {
  $10 = Math_fround($8 * Math_fround(0.693147182464599609375));
  $11 = +$10;
  $12 = (+Math_exp((+$11)));
  $13 = Math_fround($12);
  $$0$i1$i$i = $13;
 } else {
  $$0$i1$i$i = Math_fround(0.0);
 }
 $14 = (($this) + 112|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = !($15 <= Math_fround(-128.0));
 if ($16) {
  $17 = Math_fround($15 * Math_fround(0.693147182464599609375));
  $18 = +$17;
  $19 = (+Math_exp((+$18)));
  $20 = Math_fround($19);
  $$0$i3$i$i = $20;
 } else {
  $$0$i3$i$i = Math_fround(0.0);
 }
 $21 = Math_fround(Math_fround(1.0) - $$0$i$i$i);
 $22 = Math_fround(Math_fround(1.0) - $$0$i1$i$i);
 $23 = Math_fround(Math_fround(1.0) - $$0$i3$i$i);
 HEAPF32[$agg$result>>2] = $21;
 $24 = (($agg$result) + 4|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($agg$result) + 8|0);
 HEAPF32[$25>>2] = $23;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE16setLinearInertiaERKNS_6PxVec3E($this,$inertia) {
 $this = $this|0;
 $inertia = $inertia|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inertia>>2]);
 $1 = (($inertia) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($inertia) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 116|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 120|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 124|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 124|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 536|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE16getLinearInertiaEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 120|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 124|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE17setAngularInertiaERKNS_6PxVec3E($this,$inertia) {
 $this = $this|0;
 $inertia = $inertia|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inertia>>2]);
 $1 = (($inertia) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($inertia) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 128|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 132|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 136|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 136|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 536|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE17getAngularInertiaEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 132|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 136|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE21setCentrifugalInertiaERKNS_6PxVec3E($this,$inertia) {
 $this = $this|0;
 $inertia = $inertia|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inertia>>2]);
 $1 = (($inertia) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($inertia) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 140|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $0 == $6;
 $8 = (($this) + 144|0);
 if ($7) {
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $2 == $9;
  if ($10) {
   $11 = (($this) + 148|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $4 == $12;
   if ($13) {
    STACKTOP = sp;return;
   }
  }
 }
 HEAPF32[$5>>2] = $0;
 HEAPF32[$8>>2] = $2;
 $14 = (($this) + 148|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($this) + 536|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE21getCentrifugalInertiaEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 144|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 148|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE18setSolverFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $0 = 0, $1 = 0, $10 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 152|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 == $frequency;
 if ($3) {
  STACKTOP = sp;return;
 }
 HEAPF32[$1>>2] = $frequency;
 $4 = (($this) + 244|0);
 $5 = $0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE6resizeEjRKS4_($4,0,$0);
 $9 = (($this) + 256|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 536|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE18getSolverFrequencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE21setStiffnessFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $frequency;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $frequency;
 $3 = (($this) + 536|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE21getStiffnessFrequencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE25setAcceleationFilterWidthEj($this,$n) {
 $this = $this|0;
 $n = $n|0;
 var $$012$i$i$i$i$i = 0, $$03$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $it$01$i$i$i = 0, $k$02$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 $1 = (($this) + 260|0);
 HEAP32[$1>>2] = $n;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($this) + 256|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>($n>>>0);
 if ($5) {
  $9 = $4;$it$01$i$i$i = $2;$k$02$i$i$i = $n;
  while(1) {
   $6 = HEAP32[$it$01$i$i$i>>2]|0;
   $7 = (($6) + ($k$02$i$i$i))|0;
   $8 = (($7) - ($9))|0;
   HEAP32[$it$01$i$i$i>>2] = $8;
   $10 = HEAP32[$3>>2]|0;
   $11 = ($7>>>0)<=($10>>>0);
   $12 = $11&1;
   $13 = (($it$01$i$i$i) + ($12<<3)|0);
   $14 = ($7>>>0)<($10>>>0);
   if ($14) {
    $9 = $10;$it$01$i$i$i = $13;$k$02$i$i$i = $7;
   } else {
    break;
   }
  }
  $15 = ($13|0)==($2|0);
  if (!($15)) {
   $16 = (($this) + 248|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($2) + ($17<<3)|0);
   $19 = $18;
   $20 = $13;
   $21 = (($19) - ($20))|0;
   $22 = $21 >> 3;
   __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE19resizeUninitializedEj($0,$22);
   $23 = HEAP32[$0>>2]|0;
   $24 = HEAP32[$16>>2]|0;
   $25 = (($23) + ($24<<3)|0);
   $26 = ($24|0)>(0);
   if ($26) {
    $$012$i$i$i$i$i = $23;$$03$i$i$i$i$i = $13;
    while(1) {
     $27 = ($$012$i$i$i$i$i|0)==(0|0);
     if (!($27)) {
      $28 = $$03$i$i$i$i$i;
      $29 = $28;
      $30 = HEAP32[$29>>2]|0;
      $31 = (($28) + 4)|0;
      $32 = $31;
      $33 = HEAP32[$32>>2]|0;
      $34 = $$012$i$i$i$i$i;
      $35 = $34;
      HEAP32[$35>>2] = $30;
      $36 = (($34) + 4)|0;
      $37 = $36;
      HEAP32[$37>>2] = $33;
     }
     $38 = (($$012$i$i$i$i$i) + 8|0);
     $39 = (($$03$i$i$i$i$i) + 8|0);
     $40 = ($38>>>0)<($25>>>0);
     if ($40) {
      $$012$i$i$i$i$i = $38;$$03$i$i$i$i$i = $39;
     } else {
      break;
     }
    }
   }
  }
 }
 $41 = HEAP32[$3>>2]|0;
 $42 = HEAP32[$1>>2]|0;
 $43 = ($41>>>0)<($42>>>0);
 $44 = $43 ? $41 : $42;
 HEAP32[$3>>2] = $44;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE26getAccelerationFilterWidthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE10setSpheresENS0_5RangeIKNS_6PxVec4EEEjj($this,$spheres,$first,$last) {
 $this = $this|0;
 $spheres = $spheres|0;
 $first = $first|0;
 $last = $last|0;
 var $0 = 0, $spheres$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $spheres$byval_copy = sp;
 $0 = (($this) + -4|0);
 ;HEAP32[$spheres$byval_copy+0>>2]=HEAP32[$spheres+0>>2]|0;HEAP32[$spheres$byval_copy+4>>2]=HEAP32[$spheres+4>>2]|0;
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE10setSpheresENS0_5RangeIKNS_6PxVec4EEEjj($0,$spheres$byval_copy,$first,$last);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE13getNumSpheresEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 372|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setCapsulesENS0_5RangeIKjEEjj($this,$capsules,$first,$last) {
 $this = $this|0;
 $capsules = $capsules|0;
 $first = $first|0;
 $last = $last|0;
 var $0 = 0, $capsules$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $capsules$byval_copy = sp;
 $0 = (($this) + -4|0);
 ;HEAP32[$capsules$byval_copy+0>>2]=HEAP32[$capsules+0>>2]|0;HEAP32[$capsules$byval_copy+4>>2]=HEAP32[$capsules+4>>2]|0;
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE11setCapsulesENS0_5RangeIKjEEjj($0,$capsules$byval_copy,$first,$last);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE14getNumCapsulesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 360|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE9setPlanesENS0_5RangeIKNS_6PxVec4EEEjj($this,$planes,$first,$last) {
 $this = $this|0;
 $planes = $planes|0;
 $first = $first|0;
 $last = $last|0;
 var $0 = 0, $planes$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $planes$byval_copy = sp;
 $0 = (($this) + -4|0);
 ;HEAP32[$planes$byval_copy+0>>2]=HEAP32[$planes+0>>2]|0;HEAP32[$planes$byval_copy+4>>2]=HEAP32[$planes+4>>2]|0;
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE9setPlanesENS0_5RangeIKNS_6PxVec4EEEjj($0,$planes$byval_copy,$first,$last);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE12getNumPlanesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 408|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setConvexesENS0_5RangeIKjEEjj($this,$convexes,$first,$last) {
 $this = $this|0;
 $convexes = $convexes|0;
 $first = $first|0;
 $last = $last|0;
 var $0 = 0, $convexes$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $convexes$byval_copy = sp;
 $0 = (($this) + -4|0);
 ;HEAP32[$convexes$byval_copy+0>>2]=HEAP32[$convexes+0>>2]|0;HEAP32[$convexes$byval_copy+4>>2]=HEAP32[$convexes+4>>2]|0;
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE11setConvexesENS0_5RangeIKjEEjj($0,$convexes$byval_copy,$first,$last);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE14getNumConvexesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 396|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEEjj($this,$triangles,$first,$last) {
 $this = $this|0;
 $triangles = $triangles|0;
 $first = $first|0;
 $last = $last|0;
 var $0 = 0, $triangles$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $triangles$byval_copy = sp;
 $0 = (($this) + -4|0);
 ;HEAP32[$triangles$byval_copy+0>>2]=HEAP32[$triangles+0>>2]|0;HEAP32[$triangles$byval_copy+4>>2]=HEAP32[$triangles+4>>2]|0;
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEEjj($0,$triangles$byval_copy,$first,$last);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEES7_j($this,$startTriangles,$targetTriangles,$first) {
 $this = $this|0;
 $startTriangles = $startTriangles|0;
 $targetTriangles = $targetTriangles|0;
 $first = $first|0;
 var $0 = 0, $startTriangles$byval_copy = 0, $targetTriangles$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $targetTriangles$byval_copy = sp + 8|0;
 $startTriangles$byval_copy = sp;
 $0 = (($this) + -4|0);
 ;HEAP32[$startTriangles$byval_copy+0>>2]=HEAP32[$startTriangles+0>>2]|0;HEAP32[$startTriangles$byval_copy+4>>2]=HEAP32[$startTriangles+4>>2]|0;
 ;HEAP32[$targetTriangles$byval_copy+0>>2]=HEAP32[$targetTriangles+0>>2]|0;HEAP32[$targetTriangles$byval_copy+4>>2]=HEAP32[$targetTriangles+4>>2]|0;
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEES7_j($0,$startTriangles$byval_copy,$targetTriangles$byval_copy,$first);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE15getNumTrianglesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 432|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1>>>0) / 3)&-1;
 STACKTOP = sp;return ($2|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE28isContinuousCollisionEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 452|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE25enableContinuousCollisionEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $enable&1;
 $1 = (($this) + 452|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = ($0|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $enable&1;
 HEAP8[$1>>0] = $5;
 $6 = (($this) + 536|0);
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE21getCollisionMassScaleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 456|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE21setCollisionMassScaleEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 456|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $scale;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $scale;
 $3 = (($this) + 536|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setFrictionEf($this,$friction) {
 $this = $this|0;
 $friction = Math_fround($friction);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 460|0);
 HEAPF32[$0>>2] = $friction;
 $1 = (($this) + 536|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE11getFrictionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 460|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE28getNumVirtualParticleWeightsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 480|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE24setTetherConstraintScaleEf($this,$scale) {
 $this = $this|0;
 $scale = Math_fround($scale);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $scale;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $scale;
 $3 = (($this) + 536|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE24getTetherConstraintScaleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE28setTetherConstraintStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(Math_fround(1.0) - $stiffness);
 $1 = $0 != Math_fround(0.0);
 if ($1) {
  $2 = +$0;
  $3 = (+Math_log((+$2)));
  $4 = $3 / 0.693147182464599609375;
  $5 = Math_fround($4);
  $9 = $5;
 } else {
  $9 = Math_fround(-128.0);
 }
 $6 = (($this) + 276|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $9 == $7;
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAPF32[$6>>2] = $9;
 $10 = (($this) + 536|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE28getTetherConstraintStiffnessEv($this) {
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 276|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i = $6;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $7 = Math_fround(Math_fround(1.0) - $$0$i$i);
 STACKTOP = sp;return (Math_fround($7));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE20getMotionConstraintsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 536|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 284|0);
 __ZN5physx5cloth7SwCloth4pushERNS0_13SwConstraintsE($agg$result,$0,$2);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE22clearMotionConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 __ZN5physx5cloth7SwCloth5clearERNS0_13SwConstraintsE($0);
 $1 = (($this) + 536|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE23getNumMotionConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 288|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE28setMotionConstraintScaleBiasEff($this,$scale,$bias) {
 $this = $this|0;
 $scale = Math_fround($scale);
 $bias = Math_fround($bias);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 308|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $scale;
 $3 = (($this) + 312|0);
 if ($2) {
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == $bias;
  if ($5) {
   STACKTOP = sp;return;
  }
 }
 HEAPF32[$0>>2] = $scale;
 HEAPF32[$3>>2] = $bias;
 $6 = (($this) + 536|0);
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE24getMotionConstraintScaleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 308|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE23getMotionConstraintBiasEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 312|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE28setMotionConstraintStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(Math_fround(1.0) - $stiffness);
 $1 = $0 != Math_fround(0.0);
 if ($1) {
  $2 = +$0;
  $3 = (+Math_log((+$2)));
  $4 = $3 / 0.693147182464599609375;
  $5 = Math_fround($4);
  $9 = $5;
 } else {
  $9 = Math_fround(-128.0);
 }
 $6 = (($this) + 316|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $9 == $7;
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAPF32[$6>>2] = $9;
 $10 = (($this) + 536|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE28getMotionConstraintStiffnessEv($this) {
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 316|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i = $6;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $7 = Math_fround(Math_fround(1.0) - $$0$i$i);
 STACKTOP = sp;return (Math_fround($7));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE24getSeparationConstraintsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 536|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 320|0);
 __ZN5physx5cloth7SwCloth4pushERNS0_13SwConstraintsE($agg$result,$0,$2);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE26clearSeparationConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 __ZN5physx5cloth7SwCloth5clearERNS0_13SwConstraintsE($0);
 $1 = (($this) + 536|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE27getNumSeparationConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 324|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE18clearInterpolationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth9ClothImplINS0_7SwClothEE18clearInterpolationEv($0);
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE27getNumParticleAccelerationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 348|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE24setSelfCollisionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 492|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $distance;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $distance;
 $3 = (($this) + 536|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE24getSelfCollisionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 492|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE25setSelfCollisionStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(Math_fround(1.0) - $stiffness);
 $1 = $0 != Math_fround(0.0);
 if ($1) {
  $2 = +$0;
  $3 = (+Math_log((+$2)));
  $4 = $3 / 0.693147182464599609375;
  $5 = Math_fround($4);
  $9 = $5;
 } else {
  $9 = Math_fround(-128.0);
 }
 $6 = (($this) + 496|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $9 == $7;
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAPF32[$6>>2] = $9;
 $10 = (($this) + 536|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE25getSelfCollisionStiffnessEv($this) {
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = Math_fround(0), $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 496|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(-128.0));
 if ($2) {
  $3 = Math_fround($1 * Math_fround(0.693147182464599609375));
  $4 = +$3;
  $5 = (+Math_exp((+$4)));
  $6 = Math_fround($5);
  $$0$i$i = $6;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $7 = Math_fround(Math_fround(1.0) - $$0$i$i);
 STACKTOP = sp;return (Math_fround($7));
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE26getNumSelfCollisionIndicesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 504|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE16setRestPositionsENS0_5RangeIKNS_6PxVec4EEE($this,$restPositions) {
 $this = $this|0;
 $restPositions = $restPositions|0;
 var $$012$i$i$i = 0, $$03$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$restPositions>>2]|0;
 $1 = (($restPositions) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 512|0);
 $4 = $2;
 $5 = $0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE19resizeUninitializedEj($3,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($this) + 516|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + ($10<<4)|0);
 $12 = ($10|0)>(0);
 if ($12) {
  $$012$i$i$i = $8;$$03$i$i$i = $0;
 } else {
  $27 = (($this) + 536|0);
  HEAP32[$27>>2] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $13 = ($$012$i$i$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$$03$i$i$i>>2]);
   HEAPF32[$$012$i$i$i>>2] = $14;
   $15 = (($$012$i$i$i) + 4|0);
   $16 = (($$03$i$i$i) + 4|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   HEAPF32[$15>>2] = $17;
   $18 = (($$012$i$i$i) + 8|0);
   $19 = (($$03$i$i$i) + 8|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   HEAPF32[$18>>2] = $20;
   $21 = (($$012$i$i$i) + 12|0);
   $22 = (($$03$i$i$i) + 12|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$21>>2] = $23;
  }
  $24 = (($$012$i$i$i) + 16|0);
  $25 = (($$03$i$i$i) + 16|0);
  $26 = ($24>>>0)<($11>>>0);
  if ($26) {
   $$012$i$i$i = $24;$$03$i$i$i = $25;
  } else {
   break;
  }
 }
 $27 = (($this) + 536|0);
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE19getNumRestPositionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 516|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE20getBoundingBoxCenterEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE19getBoundingBoxScaleEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE17setSleepThresholdEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 532|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $threshold;
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $threshold;
 $3 = (($this) + 536|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE17getSleepThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 532|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE20setSleepTestIntervalEj($this,$interval) {
 $this = $this|0;
 $interval = $interval|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 524|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($interval|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $interval;
 $3 = (($this) + 536|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE20getSleepTestIntervalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 524|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE18setSleepAfterCountEj($this,$afterCount) {
 $this = $this|0;
 $afterCount = $afterCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 528|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($afterCount|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $afterCount;
 $3 = (($this) + 536|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE18getSleepAfterCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 528|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE17getSleepPassCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 536|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE8isAsleepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 536|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 528|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)>=($3>>>0);
 STACKTOP = sp;return ($4|0);
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE10putToSleepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 528|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 536|0);
 HEAP32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE6wakeUpEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 536|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setUserDataEPv($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 544|0);
 HEAP32[$0>>2] = $data;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE11getUserDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 544|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*12)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*12)|0)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $$01$i = $9;
 while(1) {
  $12 = ($$01$i|0)==(0|0);
  if (!($12)) {
   $13 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $13;
   $14 = (($$01$i) + 4|0);
   $15 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$14>>2] = $15;
   $16 = (($$01$i) + 8|0);
   $17 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$16>>2] = $17;
  }
  $18 = (($$01$i) + 12|0);
  $19 = ($18>>>0)<($7>>>0);
  if ($19) {
   $$01$i = $18;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = ($$$i*12)|0;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,479632,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + (($9*12)|0)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    $15 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $15;
    $16 = (($$012$i) + 4|0);
    $17 = (($$03$i) + 4|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    HEAPF32[$16>>2] = $18;
    $19 = (($$012$i) + 8|0);
    $20 = (($$03$i) + 8|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    HEAPF32[$19>>2] = $21;
   }
   $22 = (($$012$i) + 12|0);
   $23 = (($$03$i) + 12|0);
   $24 = ($22>>>0)<($10>>>0);
   if ($24) {
    $$012$i = $22;$$03$i = $23;
   } else {
    break;
   }
  }
 }
 $25 = ($10|0)==(0|0);
 if (!($25)) {
  $26 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$10>>2] = $26;
  $27 = ((($11) + (($9*12)|0)|0) + 4|0);
  $28 = (($a) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$27>>2] = $29;
  $30 = ((($11) + (($9*12)|0)|0) + 8|0);
  $31 = (($a) + 8|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$30>>2] = $32;
 }
 $33 = HEAP32[$0>>2]|0;
 $34 = ($33|0)>(-1);
 if (!($34)) {
  $37 = $9;
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $36 = (($37) + 1)|0;
  HEAP32[$8>>2] = $36;
  $38 = (($11) + (($37*12)|0)|0);
  STACKTOP = sp;return ($38|0);
 }
 $35 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$35);
 $$pre = HEAP32[$8>>2]|0;
 $37 = $$pre;
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $36 = (($37) + 1)|0;
 HEAP32[$8>>2] = $36;
 $38 = (($11) + (($37*12)|0)|0);
 STACKTOP = sp;return ($38|0);
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = ($capacity*12)|0;
  $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$1,479632,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + (($4*12)|0)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $10;
    $11 = (($$012$i) + 4|0);
    $12 = (($$03$i) + 4|0);
    $13 = Math_fround(HEAPF32[$12>>2]);
    HEAPF32[$11>>2] = $13;
    $14 = (($$012$i) + 8|0);
    $15 = (($$03$i) + 8|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    HEAPF32[$14>>2] = $16;
   }
   $17 = (($$012$i) + 12|0);
   $18 = (($$03$i) + 12|0);
   $19 = ($17>>>0)<($5>>>0);
   if ($19) {
    $$012$i = $17;$$03$i = $18;
   } else {
    break;
   }
  }
 }
 $20 = (($this) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)>(-1);
 if (!($22)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$20>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $23 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$23);
 HEAP32[$this>>2] = $6;
 HEAP32[$20>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE6resizeEjRKj($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth9IndexPairENS0_9AllocatorEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_5cloth9IndexPairENS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<3)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<3)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = $a;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = $$01$i;
   $18 = $17;
   HEAP32[$18>>2] = $13;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = $16;
  }
  $21 = (($$01$i) + 8|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth9IndexPairENS0_9AllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$1,479632,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<3)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = $$03$i;
    $11 = $10;
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + 4)|0;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = $$012$i;
    $17 = $16;
    HEAP32[$17>>2] = $12;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP32[$19>>2] = $15;
   }
   $20 = (($$012$i) + 8|0);
   $21 = (($$03$i) + 8|0);
   $22 = ($20>>>0)<($5>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$26);
 HEAP32[$this>>2] = $6;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE6resizeEjRKS4_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<3)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<3)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = $a;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = $$01$i;
   $18 = $17;
   HEAP32[$18>>2] = $13;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = $16;
  }
  $21 = (($$01$i) + 8|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth16SwInterCollisionI8Scalar4fEC1EPKNS0_20SwInterCollisionDataEjffjPFbPvS7_ER14StackAllocatorILj16EEPNS_13PxProfileZoneE($this,$instances,$n,$colDist,$stiffness,$iterations,$filter,$alloc,$zone) {
 $this = $this|0;
 $instances = $instances|0;
 $n = $n|0;
 $colDist = Math_fround($colDist);
 $stiffness = Math_fround($stiffness);
 $iterations = $iterations|0;
 $filter = $filter|0;
 $alloc = $alloc|0;
 $zone = $zone|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$014$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (($this) + 48|0);
 $2 = (($this) + 64|0);
 $3 = (($this) + 96|0);
 HEAP32[$3>>2] = $instances;
 $4 = (($this) + 100|0);
 HEAP32[$4>>2] = $n;
 $5 = (($this) + 104|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 108|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 112|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 120|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 124|0);
 HEAP32[$9>>2] = $filter;
 $10 = (($this) + 128|0);
 HEAP32[$10>>2] = $alloc;
 $11 = (($this) + 132|0);
 HEAP32[$11>>2] = $zone;
 $12 = (HEAPF32[tempDoublePtr>>2]=$colDist,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$0>>2] = $12;
 $13 = (($this) + 36|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 40|0);
 HEAP32[$14>>2] = $12;
 $15 = (($this) + 44|0);
 HEAP32[$15>>2] = 0;
 $16 = Math_fround($colDist * $colDist);
 $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$1>>2] = $17;
 $18 = (($this) + 52|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 56|0);
 HEAP32[$19>>2] = $17;
 $20 = (($this) + 60|0);
 HEAP32[$20>>2] = 0;
 $21 = (HEAPF32[tempDoublePtr>>2]=$stiffness,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$2>>2] = $21;
 $22 = (($this) + 68|0);
 HEAP32[$22>>2] = $21;
 $23 = (($this) + 72|0);
 HEAP32[$23>>2] = $21;
 $24 = (($this) + 76|0);
 HEAP32[$24>>2] = $21;
 $25 = (($this) + 92|0);
 HEAP32[$25>>2] = $iterations;
 $26 = ($n|0)==(0);
 if ($26) {
  STACKTOP = sp;return;
 } else {
  $30 = 0;$i$014$i = 0;
 }
 while(1) {
  $27 = ((($instances) + (($i$014$i*76)|0)|0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + ($30))|0;
  HEAP32[$8>>2] = $29;
  $31 = (($i$014$i) + 1)|0;
  $exitcond$i = ($31|0)==($n|0);
  if ($exitcond$i) {
   break;
  } else {
   $30 = $29;$i$014$i = $31;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth16SwInterCollisionI8Scalar4fED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth16SwInterCollisionI8Scalar4fEclEv($this) {
 $this = $this|0;
 var $$$i$i$i$i$i$i = 0, $$$i$i$i4$i$i$i = 0, $$0$i = 0, $$0$i10 = 0, $$0$i10$i = 0, $$0$i12 = 0, $$0$i12$i = 0, $$0$i130$i = 0, $$0$i15 = 0, $$0$i22 = 0, $$0$i8$i = 0, $$05$i$i = 0, $$idx = 0, $$idx$i = 0, $$idx125 = 0, $$in$i = 0, $$in$i$i = 0, $$in10$i$i = 0, $$in11$i$i = 0, $$in12$i$i = 0;
 var $$in38$i = 0, $$in39$i = 0, $$in6$i$i = 0, $$in7$i$i = 0, $$in8$i$i = 0, $$in9$i$i = 0, $$lcssa168 = 0, $$lcssa170 = 0, $$lcssa175 = 0, $$lcssa176 = 0, $$lcssa177 = 0, $$lcssa177$i = Math_fround(0), $$lcssa178 = 0, $$lcssa178$i = Math_fround(0), $$lcssa179$i = Math_fround(0), $$lcssa180$i = Math_fround(0), $$lcssa181$i = Math_fround(0), $$lcssa182$i = Math_fround(0), $$ph$be$i$i$i = 0, $$ph$i$i$i = 0;
 var $$ph10$be$i$i$i = 0, $$ph10$i$i$i = 0, $$ph11$be$i$i$i = 0, $$ph11$i$i$i = 0, $$ph12$be$i$i$i = 0, $$ph12$i$i$i = 0, $$ph13$be$i$i$i = 0, $$ph13$i$i$i = 0, $$ph9$be$i$i$i = 0, $$ph9$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i$i$i$i = 0, $$phi$trans$insert222$i = 0, $$phi$trans$insert224$i = 0, $$pn$i = 0, $$pn40$i = 0, $$pr$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i = 0;
 var $$pre$i1$i$i$i = 0, $$pre11$i$i$i$i$i = Math_fround(0), $$pre12$i$i$i$i$i = 0, $$pre221$i = Math_fround(0), $$pre223$i = Math_fround(0), $$pre225$i = Math_fround(0), $$pre238 = 0, $$pre239 = 0, $$pre240 = 0, $$pre241 = 0, $$pre246 = Math_fround(0), $$pre247 = Math_fround(0), $$pre248 = Math_fround(0), $$pre249 = Math_fround(0), $$pre250 = Math_fround(0), $$pre251 = Math_fround(0), $$pre252 = Math_fround(0), $$pre253 = Math_fround(0), $$pre254 = Math_fround(0), $$pre255 = Math_fround(0);
 var $$pre256 = Math_fround(0), $$pre257 = Math_fround(0), $$pre258 = Math_fround(0), $$pre259 = Math_fround(0), $$pre260 = Math_fround(0), $$pre7$i$i$i$i$i = Math_fround(0), $$pre8$i$i$i$i$i = 0, $$sink1$i = 0, $$sink131$i = 0, $$sum = 0, $$sum$i = 0, $$sum$i16 = 0, $$sum1 = 0, $$sum1$i = 0, $$sum10$i = 0, $$sum11$i = 0, $$sum12$i = 0, $$sum13$i = 0, $$sum14$i = 0, $$sum15$i = 0;
 var $$sum16$i = 0, $$sum17$i = 0, $$sum18$i = 0, $$sum2 = 0, $$sum2$i = 0, $$sum3 = 0, $$sum3$i = 0, $$sum4$i = 0, $$sum5$i = 0, $$sum6$i = 0, $$sum7$i = 0, $$sum8$i = 0, $$sum9$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = Math_fround(0), $1002 = Math_fround(0);
 var $1003 = 0, $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = 0, $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = 0, $101 = 0, $1010 = Math_fround(0), $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = Math_fround(0);
 var $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = 0, $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = 0, $1029 = Math_fround(0), $103 = 0, $1030 = Math_fround(0), $1031 = 0, $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = 0, $1035 = Math_fround(0), $1036 = 0, $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = 0;
 var $104 = 0, $1040 = 0, $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = 0, $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = 0;
 var $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0;
 var $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = 0, $1090 = Math_fround(0), $1091 = 0, $1092 = 0, $1093 = 0;
 var $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = 0, $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = 0, $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = 0;
 var $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = 0, $1118 = Math_fround(0), $1119 = 0, $112 = 0, $1120 = Math_fround(0), $1121 = 0, $1122 = Math_fround(0), $1123 = 0, $1124 = Math_fround(0), $1125 = 0, $1126 = Math_fround(0), $1127 = 0, $1128 = Math_fround(0), $1129 = 0;
 var $113 = 0, $1130 = Math_fround(0), $1131 = 0, $1132 = Math_fround(0), $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0;
 var $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0;
 var $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0;
 var $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0;
 var $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0;
 var $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0;
 var $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = Math_fround(0), $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = 0, $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0), $1253 = 0, $1254 = 0, $1255 = 0;
 var $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0;
 var $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = Math_fround(0), $1287 = 0, $1288 = Math_fround(0), $1289 = 0, $129 = 0, $1290 = Math_fround(0), $1291 = Math_fround(0);
 var $1292 = Math_fround(0), $1293 = Math_fround(0), $1294 = 0, $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = Math_fround(0), $1298 = 0, $1299 = Math_fround(0), $13 = 0, $130 = 0, $1300 = Math_fround(0), $1301 = 0, $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = 0, $1306 = Math_fround(0), $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0);
 var $131 = 0, $1310 = Math_fround(0), $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = Math_fround(0), $1314 = Math_fround(0), $1315 = Math_fround(0), $1316 = Math_fround(0), $1317 = Math_fround(0), $1318 = Math_fround(0), $1319 = Math_fround(0), $132 = 0, $1320 = Math_fround(0), $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = Math_fround(0), $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0);
 var $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = 0, $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = 0, $1340 = Math_fround(0), $1341 = Math_fround(0), $1342 = Math_fround(0), $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0);
 var $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0;
 var $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = Math_fround(0), $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0;
 var $1382 = 0, $1383 = 0, $1384 = 0, $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = 0, $1390 = Math_fround(0), $1391 = Math_fround(0), $1392 = Math_fround(0), $1393 = Math_fround(0), $1394 = Math_fround(0), $1395 = Math_fround(0), $1396 = Math_fround(0), $1397 = Math_fround(0), $1398 = Math_fround(0), $1399 = Math_fround(0), $14 = 0;
 var $140 = 0, $1400 = Math_fround(0), $1401 = Math_fround(0), $1402 = 0, $1403 = Math_fround(0), $1404 = Math_fround(0), $1405 = Math_fround(0), $1406 = Math_fround(0), $1407 = Math_fround(0), $1408 = Math_fround(0), $1409 = Math_fround(0), $141 = 0, $1410 = Math_fround(0), $1411 = Math_fround(0), $1412 = Math_fround(0), $1413 = Math_fround(0), $1414 = Math_fround(0), $1415 = Math_fround(0), $1416 = 0, $1417 = Math_fround(0);
 var $1418 = Math_fround(0), $1419 = Math_fround(0), $142 = 0, $1420 = Math_fround(0), $1421 = Math_fround(0), $1422 = Math_fround(0), $1423 = Math_fround(0), $1424 = Math_fround(0), $1425 = Math_fround(0), $1426 = Math_fround(0), $1427 = Math_fround(0), $1428 = Math_fround(0), $1429 = Math_fround(0), $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0;
 var $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0;
 var $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = Math_fround(0), $146 = 0, $1460 = Math_fround(0), $1461 = 0, $1462 = Math_fround(0), $1463 = 0, $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = 0, $1467 = Math_fround(0), $1468 = 0, $1469 = Math_fround(0), $147 = 0, $1470 = Math_fround(0), $1471 = 0;
 var $1472 = Math_fround(0), $1473 = 0, $1474 = Math_fround(0), $1475 = Math_fround(0), $1476 = 0, $1477 = Math_fround(0), $1478 = 0, $1479 = Math_fround(0), $148 = 0, $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0), $1486 = Math_fround(0), $1487 = Math_fround(0), $1488 = Math_fround(0), $1489 = Math_fround(0), $149 = 0;
 var $1490 = Math_fround(0), $1491 = Math_fround(0), $1492 = Math_fround(0), $1493 = Math_fround(0), $1494 = Math_fround(0), $1495 = Math_fround(0), $1496 = Math_fround(0), $1497 = Math_fround(0), $1498 = Math_fround(0), $1499 = Math_fround(0), $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0;
 var $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = Math_fround(0), $1524 = Math_fround(0), $1525 = Math_fround(0);
 var $1526 = Math_fround(0), $1527 = Math_fround(0), $1528 = Math_fround(0), $1529 = Math_fround(0), $153 = 0, $1530 = Math_fround(0), $1531 = Math_fround(0), $1532 = Math_fround(0), $1533 = Math_fround(0), $1534 = Math_fround(0), $1535 = Math_fround(0), $1536 = 0, $1537 = Math_fround(0), $1538 = Math_fround(0), $1539 = 0, $154 = 0, $1540 = Math_fround(0), $1541 = Math_fround(0), $1542 = 0, $1543 = Math_fround(0);
 var $1544 = Math_fround(0), $1545 = 0, $1546 = Math_fround(0), $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0;
 var $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0;
 var $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0;
 var $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0;
 var $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0;
 var $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0;
 var $1652 = 0, $1653 = 0, $1654 = Math_fround(0), $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0);
 var $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0);
 var $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0);
 var $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0);
 var $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0;
 var $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = 0;
 var $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0;
 var $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0);
 var $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0);
 var $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0);
 var $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0);
 var $501 = Math_fround(0), $502 = Math_fround(0), $503 = 0, $504 = Math_fround(0), $505 = 0, $506 = Math_fround(0), $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = Math_fround(0);
 var $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = Math_fround(0), $545 = 0, $546 = Math_fround(0), $547 = Math_fround(0), $548 = 0, $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = 0, $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0);
 var $556 = Math_fround(0), $557 = 0, $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = Math_fround(0), $562 = Math_fround(0), $563 = 0, $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0);
 var $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0);
 var $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = 0, $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = 0, $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = 0, $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = 0;
 var $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0);
 var $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = 0, $641 = Math_fround(0), $642 = 0, $643 = Math_fround(0), $644 = 0, $645 = Math_fround(0);
 var $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = Math_fround(0), $651 = 0, $652 = Math_fround(0), $653 = 0, $654 = Math_fround(0), $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0;
 var $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0;
 var $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = 0, $693 = Math_fround(0), $694 = Math_fround(0), $695 = 0, $696 = Math_fround(0), $697 = Math_fround(0), $698 = 0, $699 = Math_fround(0), $7 = 0;
 var $70 = 0, $700 = Math_fround(0), $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0;
 var $718 = 0, $719 = 0, $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0;
 var $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = 0, $753 = 0;
 var $754 = Math_fround(0), $755 = 0, $756 = 0, $757 = Math_fround(0), $758 = 0, $759 = 0, $76 = 0, $760 = Math_fround(0), $761 = 0, $762 = 0, $763 = Math_fround(0), $764 = 0, $765 = 0, $766 = Math_fround(0), $767 = 0, $768 = 0, $769 = Math_fround(0), $77 = 0, $770 = 0, $771 = 0;
 var $772 = Math_fround(0), $773 = 0, $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0;
 var $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0;
 var $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = 0, $821 = Math_fround(0), $822 = Math_fround(0), $823 = 0, $824 = Math_fround(0), $825 = Math_fround(0);
 var $826 = 0, $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = 0, $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0);
 var $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0, $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0;
 var $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = Math_fround(0), $88 = 0;
 var $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = 0, $892 = Math_fround(0), $893 = 0, $894 = Math_fround(0), $895 = Math_fround(0), $896 = 0, $897 = Math_fround(0), $898 = Math_fround(0);
 var $899 = 0, $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = Math_fround(0), $908 = 0, $909 = Math_fround(0), $91 = 0, $910 = 0, $911 = Math_fround(0), $912 = 0, $913 = Math_fround(0), $914 = 0, $915 = 0;
 var $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0;
 var $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0;
 var $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0;
 var $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = Math_fround(0), $976 = 0, $977 = Math_fround(0), $978 = 0, $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = 0, $982 = Math_fround(0), $983 = 0, $984 = Math_fround(0), $985 = Math_fround(0), $986 = 0, $987 = Math_fround(0), $988 = 0;
 var $989 = Math_fround(0), $99 = 0, $990 = Math_fround(0), $991 = 0, $992 = Math_fround(0), $993 = 0, $994 = Math_fround(0), $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = Math_fround(0), $bLocal$i = 0, $cWorld$i = 0, $cellSize = 0, $data = 0, $edgeLength = 0, $exitcond$i = 0, $exitcond$i$i$i$i = 0, $floorf$i = Math_fround(0);
 var $floorf$i18 = Math_fround(0), $floorf1$i = Math_fround(0), $floorf1$i19 = Math_fround(0), $floorf2$i = Math_fround(0), $floorf2$i20 = Math_fround(0), $floorf3$i = Math_fround(0), $floorf3$i21 = Math_fround(0), $gridSize = 0, $i$0$i$i$i$i = 0, $i$0$ph$i$i$i$i = 0, $i$0169 = 0, $i$0183$i = 0, $i$030$i = 0, $i$04$i$i$i$i = 0, $i1$0160$i = 0, $i1$0171 = 0, $i1$027$i = 0, $i2$0179 = 0, $i2$024$i = 0, $i3$021$i = 0;
 var $i5$019$i = 0, $indexi = 0, $it$035$i = 0, $j$0$m$0$i$i$i$i = 0, $j$0$ph$i = 0, $j$0$ph$i$i$i$i = 0, $j$0139$i = 0, $j$03$i$i$i$i = 0, $j$1$i$i$i$i = 0, $k$0156$i = 0, $k$0187 = 0, $lastCloth$0180 = 0, $lastCloth$1 = 0, $lcBounds$i = 0, $lcBounds2$i = 0, $m$02$i$i$i$i = 0, $numOverlaps$0$lcssa$i = 0, $numOverlaps$0140$i = 0, $numOverlaps$1$i = 0, $numParticles$0161$i = 0;
 var $numParticles$1$lcssa$i = 0, $numParticles$1157$i = 0, $numParticles$2$i = 0, $oIt$0146$i = 0, $or$cond$i$i$i = 0, $or$cond1$i$i$i = 0, $or$cond2$i$i$i = 0, $overlapMask$0$lcssa$i = 0, $overlapMask$0141$i = 0, $overlapMask$1$i = 0, $phitmp = 0, $phitmp123 = 0, $phitmp124 = 0, $phitmp261 = 0, $stackMem$i$i$i = 0, $startIndex$0138$i = 0, $sums$sroa$0$031$i = 0, $sums$sroa$1$032$i = 0, $sums$sroa$2$033$i = 0, $sums$sroa$3$034$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $stackMem$i$i$i = sp;
 $0 = sp + 224|0;
 $lcBounds$i = sp + 160|0;
 $cWorld$i = sp + 136|0;
 $lcBounds2$i = sp + 112|0;
 $bLocal$i = sp + 88|0;
 $1 = sp + 352|0;
 $edgeLength = sp + 40|0;
 $cellSize = sp + 24|0;
 $gridSize = sp + 8|0;
 $indexi = sp + 56|0;
 $data = sp + 72|0;
 $2 = (($this) + 140|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 136|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 120|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 << 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $$0$i = 0;$24 = $7;$27 = $5;
 } else {
  $10 = (($5) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) + 23)|0;
  $14 = $13 & -16;
  $15 = $14;
  $16 = (($15) + ($8)|0);
  $17 = (($15) + -8|0);
  $18 = (($5) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$17>>2] = $19;
  $20 = (($15) + -4|0);
  $21 = $8 & 2147483646;
  HEAP32[$20>>2] = $21;
  HEAP32[$18>>2] = $17;
  HEAP32[$10>>2] = $16;
  $phitmp = $14;
  $$pre = HEAP32[$4>>2]|0;
  $$pre238 = HEAP32[$6>>2]|0;
  $$0$i = $phitmp;$24 = $$pre238;$27 = $$pre;
 }
 $22 = (($this) + 104|0);
 HEAP32[$22>>2] = $$0$i;
 $23 = $24 << 2;
 $25 = ($23|0)==(0);
 if ($25) {
  $$0$i10 = 0;$45 = $27;
 } else {
  $26 = (($27) + 8|0);
  $28 = HEAP32[$26>>2]|0;
  $29 = $28;
  $30 = (($29) + 23)|0;
  $31 = $30 & -16;
  $32 = $31;
  $33 = (($32) + ($23)|0);
  $34 = (($32) + -8|0);
  $35 = (($27) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$34>>2] = $36;
  $37 = (($32) + -4|0);
  $38 = $23 & 2147483644;
  HEAP32[$37>>2] = $38;
  HEAP32[$35>>2] = $34;
  HEAP32[$26>>2] = $33;
  $phitmp123 = $31;
  $$pre239 = HEAP32[$4>>2]|0;
  $$0$i10 = $phitmp123;$45 = $$pre239;
 }
 $39 = (($this) + 108|0);
 HEAP32[$39>>2] = $$0$i10;
 $40 = (($this) + 100|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 << 2;
 $43 = ($42|0)==(0);
 if ($43) {
  $$0$i12 = 0;
 } else {
  $44 = (($45) + 8|0);
  $46 = HEAP32[$44>>2]|0;
  $47 = $46;
  $48 = (($47) + 23)|0;
  $49 = $48 & -16;
  $50 = $49;
  $51 = (($50) + ($42)|0);
  $52 = (($50) + -8|0);
  $53 = (($45) + 12|0);
  $54 = HEAP32[$53>>2]|0;
  HEAP32[$52>>2] = $54;
  $55 = (($50) + -4|0);
  $56 = $42 & 2147483644;
  HEAP32[$55>>2] = $56;
  HEAP32[$53>>2] = $52;
  HEAP32[$44>>2] = $51;
  $phitmp124 = $49;
  $$0$i12 = $phitmp124;
 }
 $57 = (($this) + 116|0);
 HEAP32[$57>>2] = $$0$i12;
 $58 = (($this) + 92|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0);
 if ($60) {
  $1558 = $$0$i12;
 } else {
  $61 = (($this) + 96|0);
  $62 = (($this) + 32|0);
  $63 = (($this) + 36|0);
  $64 = (($this) + 40|0);
  $65 = (($this) + 44|0);
  $66 = (($this) + 124|0);
  $67 = (($stackMem$i$i$i) + 4|0);
  $68 = (($this) + 112|0);
  $69 = (($lcBounds$i) + 4|0);
  $70 = (($lcBounds$i) + 8|0);
  $71 = (($lcBounds$i) + 12|0);
  $72 = (($lcBounds$i) + 48|0);
  $73 = (($lcBounds$i) + 52|0);
  $74 = (($lcBounds$i) + 56|0);
  $75 = (($lcBounds$i) + 60|0);
  $76 = (($lcBounds$i) + 16|0);
  $77 = (($lcBounds$i) + 20|0);
  $78 = (($lcBounds$i) + 24|0);
  $79 = (($lcBounds$i) + 28|0);
  $80 = (($lcBounds$i) + 32|0);
  $81 = (($lcBounds$i) + 36|0);
  $82 = (($lcBounds$i) + 40|0);
  $83 = (($lcBounds$i) + 44|0);
  $84 = (($lcBounds$i) + 16|0);
  $85 = (($lcBounds$i) + 32|0);
  $86 = (($lcBounds$i) + 48|0);
  $87 = (($edgeLength) + 4|0);
  $88 = (($edgeLength) + 8|0);
  $89 = (($edgeLength) + 12|0);
  $90 = (($cellSize) + 4|0);
  $91 = (($cellSize) + 8|0);
  $92 = (($cellSize) + 12|0);
  $93 = (($gridSize) + 4|0);
  $94 = (($gridSize) + 8|0);
  $95 = (($gridSize) + 12|0);
  $96 = (($data) + 4|0);
  $97 = (($data) + 8|0);
  $98 = (($data) + 12|0);
  $99 = (($indexi) + 4|0);
  $100 = (($indexi) + 8|0);
  $101 = (($indexi) + 12|0);
  $102 = (($lcBounds2$i) + 4|0);
  $103 = (($lcBounds2$i) + 8|0);
  $104 = (($lcBounds2$i) + 12|0);
  $105 = (($lcBounds2$i) + 16|0);
  $106 = (($lcBounds2$i) + 20|0);
  $107 = (($1) + 4|0);
  $108 = (($1) + 8|0);
  $109 = (($1) + 12|0);
  $110 = (($1) + 16|0);
  $111 = (($1) + 20|0);
  $112 = (($1) + 24|0);
  $113 = (($bLocal$i) + 4|0);
  $114 = (($bLocal$i) + 8|0);
  $115 = (($bLocal$i) + 12|0);
  $116 = (($bLocal$i) + 16|0);
  $117 = (($bLocal$i) + 20|0);
  $118 = (($lcBounds$i) + 4|0);
  $119 = (($lcBounds$i) + 8|0);
  $120 = (($lcBounds$i) + 12|0);
  $121 = (($lcBounds$i) + 16|0);
  $122 = (($lcBounds$i) + 20|0);
  $123 = (($cWorld$i) + 4|0);
  $124 = (($cWorld$i) + 8|0);
  $125 = (($cWorld$i) + 12|0);
  $126 = (($cWorld$i) + 16|0);
  $127 = (($cWorld$i) + 20|0);
  $1604 = 0;$1605 = 0;$1606 = 0;$1607 = 0;$k$0187 = 1;
  while(1) {
   $128 = HEAP32[$61>>2]|0;
   $129 = HEAP32[$40>>2]|0;
   $130 = HEAP32[$62>>2]|0;
   $131 = HEAP32[$63>>2]|0;
   $132 = HEAP32[$64>>2]|0;
   $133 = HEAP32[$65>>2]|0;
   $134 = HEAP32[$22>>2]|0;
   $135 = HEAP32[$39>>2]|0;
   $136 = HEAP32[$57>>2]|0;
   $137 = HEAP32[$66>>2]|0;
   $138 = HEAP32[$4>>2]|0;
   $$idx = ($129*76)|0;
   $139 = (($$idx|0) / 76)&-1;
   $140 = $139 << 5;
   $141 = ($140|0)==(0);
   if ($141) {
    $$0$i130$i = 0;$$0$i8$i = 0;$214 = 0;
   } else {
    $142 = (($138) + 8|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = $143;
    $145 = (($144) + 23)|0;
    $146 = $145 & -16;
    $147 = $146;
    $148 = (($147) + ($140)|0);
    $149 = (($147) + -8|0);
    $150 = (($138) + 12|0);
    $151 = HEAP32[$150>>2]|0;
    HEAP32[$149>>2] = $151;
    $152 = (($147) + -4|0);
    $153 = $140 & 2147483616;
    HEAP32[$152>>2] = $153;
    $154 = $146;
    $155 = $148;
    $156 = (($155) + 23)|0;
    $157 = $156 & -16;
    $158 = $157;
    $159 = (($158) + ($140)|0);
    $160 = (($158) + -8|0);
    HEAP32[$160>>2] = $149;
    $161 = (($158) + -4|0);
    HEAP32[$161>>2] = $153;
    HEAP32[$150>>2] = $160;
    HEAP32[$142>>2] = $159;
    $$0$i130$i = $147;$$0$i8$i = $158;$214 = $154;
   }
   $162 = $139 << 2;
   $163 = ($162|0)==(0);
   if ($163) {
    $$0$i10$i = 0;
   } else {
    $164 = (($138) + 8|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = $165;
    $167 = (($166) + 23)|0;
    $168 = $167 & -16;
    $169 = $168;
    $170 = (($169) + ($162)|0);
    $171 = (($169) + -8|0);
    $172 = (($138) + 12|0);
    $173 = HEAP32[$172>>2]|0;
    HEAP32[$171>>2] = $173;
    $174 = (($169) + -4|0);
    $175 = $162 & 2147483644;
    HEAP32[$174>>2] = $175;
    HEAP32[$172>>2] = $171;
    HEAP32[$164>>2] = $170;
    $$0$i10$i = $169;
   }
   $176 = ($129|0)==(0);
   if ($176) {
    $$lcssa177$i = Math_fround(-3.40282346638528859812E+38);$$lcssa178$i = Math_fround(-3.40282346638528859812E+38);$$lcssa179$i = Math_fround(-3.40282346638528859812E+38);$$lcssa180$i = Math_fround(3.40282346638528859812E+38);$$lcssa181$i = Math_fround(3.40282346638528859812E+38);$$lcssa182$i = Math_fround(3.40282346638528859812E+38);
   } else {
    $177 = (HEAP32[tempDoublePtr>>2]=$130,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $223 = Math_fround(3.40282346638528859812E+38);$226 = Math_fround(3.40282346638528859812E+38);$229 = Math_fround(3.40282346638528859812E+38);$232 = Math_fround(-3.40282346638528859812E+38);$235 = Math_fround(-3.40282346638528859812E+38);$238 = Math_fround(-3.40282346638528859812E+38);$i$0183$i = 0;
    while(1) {
     $178 = ((($128) + (($i$0183$i*76)|0)|0) + 56|0);
     $179 = Math_fround(HEAPF32[$178>>2]);
     $180 = Math_fround($177 + $179);
     $181 = ((($128) + (($i$0183$i*76)|0)|0) + 60|0);
     $182 = Math_fround(HEAPF32[$181>>2]);
     $183 = Math_fround($177 + $182);
     $184 = ((($128) + (($i$0183$i*76)|0)|0) + 64|0);
     $185 = Math_fround(HEAPF32[$184>>2]);
     $186 = Math_fround($177 + $185);
     $187 = ((($128) + (($i$0183$i*76)|0)|0) + 44|0);
     $188 = Math_fround(HEAPF32[$187>>2]);
     $189 = Math_fround($188 - $180);
     $190 = ((($128) + (($i$0183$i*76)|0)|0) + 48|0);
     $191 = Math_fround(HEAPF32[$190>>2]);
     $192 = Math_fround($191 - $183);
     $193 = ((($128) + (($i$0183$i*76)|0)|0) + 52|0);
     $194 = Math_fround(HEAPF32[$193>>2]);
     $195 = Math_fround($194 - $186);
     $196 = Math_fround($180 + $188);
     $197 = Math_fround($183 + $191);
     $198 = Math_fround($186 + $194);
     HEAPF32[$lcBounds$i>>2] = $189;
     HEAPF32[$118>>2] = $192;
     HEAPF32[$119>>2] = $195;
     HEAPF32[$120>>2] = $196;
     HEAPF32[$121>>2] = $197;
     HEAPF32[$122>>2] = $198;
     $199 = ((($128) + (($i$0183$i*76)|0)|0) + 16|0);
     __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($cWorld$i,$199,$lcBounds$i);
     $200 = Math_fround(HEAPF32[$cWorld$i>>2]);
     $201 = Math_fround(HEAPF32[$123>>2]);
     $202 = Math_fround(HEAPF32[$124>>2]);
     $203 = (HEAPF32[tempDoublePtr>>2]=$200,HEAP32[tempDoublePtr>>2]|0);
     $204 = (HEAPF32[tempDoublePtr>>2]=$201,HEAP32[tempDoublePtr>>2]|0);
     $205 = (HEAPF32[tempDoublePtr>>2]=$202,HEAP32[tempDoublePtr>>2]|0);
     $206 = Math_fround(HEAPF32[$125>>2]);
     $207 = Math_fround(HEAPF32[$126>>2]);
     $208 = Math_fround(HEAPF32[$127>>2]);
     $209 = (HEAPF32[tempDoublePtr>>2]=$206,HEAP32[tempDoublePtr>>2]|0);
     $210 = (HEAPF32[tempDoublePtr>>2]=$207,HEAP32[tempDoublePtr>>2]|0);
     $211 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
     $212 = (($$0$i10$i) + ($i$0183$i<<2)|0);
     HEAP32[$212>>2] = $i$0183$i;
     $213 = (($214) + ($i$0183$i<<5)|0);
     HEAP32[$213>>2] = $203;
     $215 = ((($214) + ($i$0183$i<<5)|0) + 4|0);
     HEAP32[$215>>2] = $204;
     $216 = ((($214) + ($i$0183$i<<5)|0) + 8|0);
     HEAP32[$216>>2] = $205;
     $217 = ((($214) + ($i$0183$i<<5)|0) + 12|0);
     HEAP32[$217>>2] = 0;
     $218 = ((($214) + ($i$0183$i<<5)|0) + 16|0);
     HEAP32[$218>>2] = $209;
     $219 = ((($214) + ($i$0183$i<<5)|0) + 20|0);
     HEAP32[$219>>2] = $210;
     $220 = ((($214) + ($i$0183$i<<5)|0) + 24|0);
     HEAP32[$220>>2] = $211;
     $221 = ((($214) + ($i$0183$i<<5)|0) + 28|0);
     HEAP32[$221>>2] = 0;
     $222 = $200 < $223;
     $224 = $222 ? $200 : $223;
     $225 = $201 < $226;
     $227 = $225 ? $201 : $226;
     $228 = $202 < $229;
     $230 = $228 ? $202 : $229;
     $231 = $232 < $206;
     $233 = $231 ? $206 : $232;
     $234 = $235 < $207;
     $236 = $234 ? $207 : $235;
     $237 = $238 < $208;
     $239 = $237 ? $208 : $238;
     $240 = (($i$0183$i) + 1)|0;
     $241 = ($240>>>0)<($139>>>0);
     if ($241) {
      $223 = $224;$226 = $227;$229 = $230;$232 = $233;$235 = $236;$238 = $239;$i$0183$i = $240;
     } else {
      $$lcssa177$i = $239;$$lcssa178$i = $236;$$lcssa179$i = $233;$$lcssa180$i = $230;$$lcssa181$i = $227;$$lcssa182$i = $224;
      break;
     }
    }
   }
   $242 = Math_fround($$lcssa179$i - $$lcssa182$i);
   $243 = Math_fround($$lcssa178$i - $$lcssa181$i);
   $244 = Math_fround($$lcssa177$i - $$lcssa180$i);
   $245 = $242 > $243;
   if ($245) {
    $246 = $242 > $244;
    $247 = $246 ? 0 : 2;
    $$0$i12$i = $247;
   } else {
    $248 = $243 > $244;
    $249 = $248 ? 1 : 2;
    $$0$i12$i = $249;
   }
   $250 = $stackMem$i$i$i;
   $251 = $250;
   HEAP32[$251>>2] = 0;
   $252 = (($250) + 4)|0;
   $253 = $252;
   HEAP32[$253>>2] = 0;
   HEAP8[$67>>0] = 0;
   HEAP32[$stackMem$i$i$i>>2] = $0;
   $254 = (($139) + -1)|0;
   $255 = ($254|0)>(0);
   if ($255) {
    $$ph$i$i$i = 0;$$ph10$i$i$i = 32;$$ph11$i$i$i = 0;$$ph12$i$i$i = 0;$$ph13$i$i$i = $254;$$ph9$i$i$i = $0;
    L30: while(1) {
     $257 = $$ph13$i$i$i;$258 = $$ph12$i$i$i;$325 = $$ph11$i$i$i;
     while(1) {
      $256 = ($257|0)>($258|0);
      if ($256) {
       $259 = (($257) - ($258))|0;
       $260 = ($259>>>0)<(5);
       if ($260) {
        $i$04$i$i$i$i = $258;
       } else {
        break;
       }
       while(1) {
        $261 = (($i$04$i$i$i$i) + 1)|0;
        $j$03$i$i$i$i = $261;$m$02$i$i$i$i = $i$04$i$i$i$i;
        while(1) {
         $262 = (($$0$i10$i) + ($j$03$i$i$i$i<<2)|0);
         $263 = HEAP32[$262>>2]|0;
         $264 = (($$0$i10$i) + ($m$02$i$i$i$i<<2)|0);
         $265 = HEAP32[$264>>2]|0;
         $266 = ((($214) + ($263<<5)|0) + ($$0$i12$i<<2)|0);
         $267 = Math_fround(HEAPF32[$266>>2]);
         $268 = ((($214) + ($265<<5)|0) + ($$0$i12$i<<2)|0);
         $269 = Math_fround(HEAPF32[$268>>2]);
         $270 = $267 < $269;
         $j$0$m$0$i$i$i$i = $270 ? $j$03$i$i$i$i : $m$02$i$i$i$i;
         $271 = (($j$03$i$i$i$i) + 1)|0;
         $272 = ($j$03$i$i$i$i|0)<($257|0);
         if ($272) {
          $j$03$i$i$i$i = $271;$m$02$i$i$i$i = $j$0$m$0$i$i$i$i;
         } else {
          break;
         }
        }
        $273 = (($$0$i10$i) + ($j$0$m$0$i$i$i$i<<2)|0);
        $274 = (($$0$i10$i) + ($i$04$i$i$i$i<<2)|0);
        $275 = HEAP32[$273>>2]|0;
        $276 = HEAP32[$274>>2]|0;
        HEAP32[$273>>2] = $276;
        HEAP32[$274>>2] = $275;
        $exitcond$i$i$i$i = ($261|0)==($257|0);
        if ($exitcond$i$i$i$i) {
         break;
        } else {
         $i$04$i$i$i$i = $261;
        }
       }
      }
      $380 = ($325|0)==(0);
      if ($380) {
       break L30;
      }
      $381 = (($325) + -1)|0;
      $382 = (($$ph9$i$i$i) + ($381<<2)|0);
      $383 = HEAP32[$382>>2]|0;
      $384 = (($325) + -2)|0;
      $385 = (($$ph9$i$i$i) + ($384<<2)|0);
      $386 = HEAP32[$385>>2]|0;
      $257 = $383;$258 = $386;$325 = $384;
     }
     $277 = (($257) + ($258))|0;
     $278 = (($277|0) / 2)&-1;
     $279 = (($$0$i10$i) + ($278<<2)|0);
     $280 = HEAP32[$279>>2]|0;
     $281 = (($$0$i10$i) + ($258<<2)|0);
     $282 = HEAP32[$281>>2]|0;
     $283 = ((($214) + ($280<<5)|0) + ($$0$i12$i<<2)|0);
     $284 = Math_fround(HEAPF32[$283>>2]);
     $285 = ((($214) + ($282<<5)|0) + ($$0$i12$i<<2)|0);
     $286 = Math_fround(HEAPF32[$285>>2]);
     $287 = $284 < $286;
     if ($287) {
      HEAP32[$281>>2] = $280;
      HEAP32[$279>>2] = $282;
      $$pre$i$i$i$i$i = HEAP32[$281>>2]|0;
      $$phi$trans$insert$i$i$i$i$i = ((($214) + ($$pre$i$i$i$i$i<<5)|0) + ($$0$i12$i<<2)|0);
      $$pre7$i$i$i$i$i = Math_fround(HEAPF32[$$phi$trans$insert$i$i$i$i$i>>2]);
      $$pre11$i$i$i$i$i = $$pre7$i$i$i$i$i;$1608 = $282;$293 = $$pre$i$i$i$i$i;
     } else {
      $$pre11$i$i$i$i$i = $286;$1608 = $280;$293 = $282;
     }
     $288 = (($$0$i10$i) + ($257<<2)|0);
     $289 = HEAP32[$288>>2]|0;
     $290 = ((($214) + ($289<<5)|0) + ($$0$i12$i<<2)|0);
     $291 = Math_fround(HEAPF32[$290>>2]);
     $292 = $291 < $$pre11$i$i$i$i$i;
     if ($292) {
      HEAP32[$281>>2] = $289;
      HEAP32[$288>>2] = $293;
      $$pre8$i$i$i$i$i = HEAP32[$279>>2]|0;
      $295 = $$pre8$i$i$i$i$i;$298 = $$pre11$i$i$i$i$i;$299 = $293;
     } else {
      $295 = $1608;$298 = $291;$299 = $289;
     }
     $294 = ((($214) + ($295<<5)|0) + ($$0$i12$i<<2)|0);
     $296 = Math_fround(HEAPF32[$294>>2]);
     $297 = $298 < $296;
     if ($297) {
      HEAP32[$279>>2] = $299;
      HEAP32[$288>>2] = $295;
      $$pre12$i$i$i$i$i = HEAP32[$279>>2]|0;
      $303 = $$pre12$i$i$i$i$i;
     } else {
      $303 = $295;
     }
     $300 = (($257) + -1)|0;
     $301 = (($$0$i10$i) + ($300<<2)|0);
     $302 = HEAP32[$301>>2]|0;
     HEAP32[$279>>2] = $302;
     HEAP32[$301>>2] = $303;
     $305 = $303;$i$0$ph$i$i$i$i = $258;$j$0$ph$i$i$i$i = $300;
     while(1) {
      $304 = ((($214) + ($305<<5)|0) + ($$0$i12$i<<2)|0);
      $306 = Math_fround(HEAPF32[$304>>2]);
      $i$0$i$i$i$i = $i$0$ph$i$i$i$i;
      while(1) {
       $307 = (($i$0$i$i$i$i) + 1)|0;
       $308 = (($$0$i10$i) + ($307<<2)|0);
       $309 = HEAP32[$308>>2]|0;
       $310 = ((($214) + ($309<<5)|0) + ($$0$i12$i<<2)|0);
       $311 = Math_fround(HEAPF32[$310>>2]);
       $312 = $311 < $306;
       if ($312) {
        $i$0$i$i$i$i = $307;
       } else {
        $j$1$i$i$i$i = $j$0$ph$i$i$i$i;
        break;
       }
      }
      while(1) {
       $313 = (($j$1$i$i$i$i) + -1)|0;
       $314 = (($$0$i10$i) + ($313<<2)|0);
       $315 = HEAP32[$314>>2]|0;
       $316 = ((($214) + ($315<<5)|0) + ($$0$i12$i<<2)|0);
       $317 = Math_fround(HEAPF32[$316>>2]);
       $318 = $306 < $317;
       if ($318) {
        $j$1$i$i$i$i = $313;
       } else {
        break;
       }
      }
      $319 = ($307|0)<($313|0);
      if (!($319)) {
       break;
      }
      HEAP32[$308>>2] = $315;
      HEAP32[$314>>2] = $309;
      $$pre$i1$i$i$i = HEAP32[$301>>2]|0;
      $305 = $$pre$i1$i$i$i;$i$0$ph$i$i$i$i = $307;$j$0$ph$i$i$i$i = $313;
     }
     HEAP32[$308>>2] = $305;
     HEAP32[$301>>2] = $309;
     $320 = (($307) - ($258))|0;
     $321 = (($257) - ($307))|0;
     $322 = ($320|0)<($321|0);
     if ($322) {
      $323 = (($$ph10$i$i$i) + -1)|0;
      $324 = ($325>>>0)<($323>>>0);
      do {
       if ($324) {
        $1609 = $$ph$i$i$i;$1610 = $$ph10$i$i$i;$349 = $$ph9$i$i$i;
       } else {
        $326 = $$ph10$i$i$i << 1;
        $327 = $$ph10$i$i$i << 3;
        $328 = ($327|0)==(0);
        if ($328) {
         $340 = 0;
        } else {
         $329 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
         $330 = HEAP32[$329>>2]|0;
         $331 = (($330) + 8|0);
         $332 = HEAP32[$331>>2]|0;
         $333 = (__Z15PxGetFoundationv()|0);
         $334 = HEAP32[$333>>2]|0;
         $335 = (($334) + 24|0);
         $336 = HEAP32[$335>>2]|0;
         $337 = (FUNCTION_TABLE_ii[$336 & 4095]($333)|0);
         $$$i$i$i4$i$i$i = $337 ? 479920 : 479888;
         $338 = (FUNCTION_TABLE_iiiiii[$332 & 255]($329,$327,$$$i$i$i4$i$i$i,479800,148)|0);
         $340 = $338;
        }
        $339 = $325 << 2;
        _memcpy(($340|0),($$ph9$i$i$i|0),($339|0))|0;
        $341 = ($$ph$i$i$i<<24>>24)==(0);
        $342 = ($$ph9$i$i$i|0)==(0|0);
        $or$cond$i$i$i = $341 | $342;
        if ($or$cond$i$i$i) {
         $1609 = 1;$1610 = $326;$349 = $340;
         break;
        }
        $343 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $344 = HEAP32[$343>>2]|0;
        $345 = (($344) + 12|0);
        $346 = HEAP32[$345>>2]|0;
        FUNCTION_TABLE_vii[$346 & 4095]($343,$$ph9$i$i$i);
        $1609 = 1;$1610 = $326;$349 = $340;
       }
      } while(0);
      $347 = (($325) + 1)|0;
      $348 = (($349) + ($325<<2)|0);
      HEAP32[$348>>2] = $258;
      $350 = (($349) + ($347<<2)|0);
      HEAP32[$350>>2] = $i$0$i$i$i$i;
      $351 = (($i$0$i$i$i$i) + 2)|0;
      $$ph$be$i$i$i = $1609;$$ph10$be$i$i$i = $1610;$$ph12$be$i$i$i = $351;$$ph13$be$i$i$i = $257;$$ph9$be$i$i$i = $349;
     } else {
      $352 = (($i$0$i$i$i$i) + 2)|0;
      $353 = (($$ph10$i$i$i) + -1)|0;
      $354 = ($325>>>0)<($353>>>0);
      do {
       if ($354) {
        $1611 = $$ph$i$i$i;$1612 = $$ph10$i$i$i;$378 = $$ph9$i$i$i;
       } else {
        $355 = $$ph10$i$i$i << 1;
        $356 = $$ph10$i$i$i << 3;
        $357 = ($356|0)==(0);
        if ($357) {
         $369 = 0;
        } else {
         $358 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
         $359 = HEAP32[$358>>2]|0;
         $360 = (($359) + 8|0);
         $361 = HEAP32[$360>>2]|0;
         $362 = (__Z15PxGetFoundationv()|0);
         $363 = HEAP32[$362>>2]|0;
         $364 = (($363) + 24|0);
         $365 = HEAP32[$364>>2]|0;
         $366 = (FUNCTION_TABLE_ii[$365 & 4095]($362)|0);
         $$$i$i$i$i$i$i = $366 ? 479920 : 479888;
         $367 = (FUNCTION_TABLE_iiiiii[$361 & 255]($358,$356,$$$i$i$i$i$i$i,479800,148)|0);
         $369 = $367;
        }
        $368 = $325 << 2;
        _memcpy(($369|0),($$ph9$i$i$i|0),($368|0))|0;
        $370 = ($$ph$i$i$i<<24>>24)==(0);
        $371 = ($$ph9$i$i$i|0)==(0|0);
        $or$cond1$i$i$i = $370 | $371;
        if ($or$cond1$i$i$i) {
         $1611 = 1;$1612 = $355;$378 = $369;
         break;
        }
        $372 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $373 = HEAP32[$372>>2]|0;
        $374 = (($373) + 12|0);
        $375 = HEAP32[$374>>2]|0;
        FUNCTION_TABLE_vii[$375 & 4095]($372,$$ph9$i$i$i);
        $1611 = 1;$1612 = $355;$378 = $369;
       }
      } while(0);
      $376 = (($325) + 1)|0;
      $377 = (($378) + ($325<<2)|0);
      HEAP32[$377>>2] = $352;
      $379 = (($378) + ($376<<2)|0);
      HEAP32[$379>>2] = $257;
      $$ph$be$i$i$i = $1611;$$ph10$be$i$i$i = $1612;$$ph12$be$i$i$i = $258;$$ph13$be$i$i$i = $i$0$i$i$i$i;$$ph9$be$i$i$i = $378;
     }
     $$ph11$be$i$i$i = (($325) + 2)|0;
     $$ph$i$i$i = $$ph$be$i$i$i;$$ph10$i$i$i = $$ph10$be$i$i$i;$$ph11$i$i$i = $$ph11$be$i$i$i;$$ph12$i$i$i = $$ph12$be$i$i$i;$$ph13$i$i$i = $$ph13$be$i$i$i;$$ph9$i$i$i = $$ph9$be$i$i$i;
    }
    $387 = ($$ph$i$i$i<<24>>24)==(0);
    $388 = ($$ph9$i$i$i|0)==(0|0);
    $or$cond2$i$i$i = $387 | $388;
    if (!($or$cond2$i$i$i)) {
     $389 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $390 = HEAP32[$389>>2]|0;
     $391 = (($390) + 12|0);
     $392 = HEAP32[$391>>2]|0;
     FUNCTION_TABLE_vii[$392 & 4095]($389,$$ph9$i$i$i);
    }
   }
   $393 = HEAP8[$67>>0]|0;
   $394 = ($393<<24>>24)==(0);
   if (!($394)) {
    $395 = HEAP32[$stackMem$i$i$i>>2]|0;
    __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem$i$i$i,$395);
   }
   if ($176) {
    $973 = 0;$976 = -8388609;$978 = 2139095039;$981 = -8388609;$983 = 2139095039;$986 = -8388609;$988 = 2139095039;$991 = -8388609;$993 = 2139095039;
   } else {
    $396 = (HEAP32[tempDoublePtr>>2]=$130,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $397 = (HEAP32[tempDoublePtr>>2]=$131,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $398 = (HEAP32[tempDoublePtr>>2]=$132,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $399 = (HEAP32[tempDoublePtr>>2]=$133,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $1613 = -8388609;$1614 = -8388609;$1615 = -8388609;$1616 = -8388609;$1617 = 2139095039;$1618 = 2139095039;$1619 = 2139095039;$1620 = 2139095039;$i1$0160$i = 0;$numParticles$0161$i = 0;
    while(1) {
     $400 = (($$0$i10$i) + ($i1$0160$i<<2)|0);
     $401 = HEAP32[$400>>2]|0;
     $402 = ((($128) + (($401*76)|0)|0) + 44|0);
     $403 = Math_fround(HEAPF32[$402>>2]);
     $404 = (($402) + 4|0);
     $405 = Math_fround(HEAPF32[$404>>2]);
     $406 = (($402) + 8|0);
     $407 = Math_fround(HEAPF32[$406>>2]);
     $408 = (($402) + 12|0);
     $409 = Math_fround(HEAPF32[$408>>2]);
     $410 = ((($128) + (($401*76)|0)|0) + 56|0);
     $411 = (($410) + 4|0);
     $412 = Math_fround(HEAPF32[$411>>2]);
     $413 = (($410) + 8|0);
     $414 = Math_fround(HEAPF32[$413>>2]);
     $415 = (($410) + 12|0);
     $416 = Math_fround(HEAPF32[$415>>2]);
     $417 = Math_fround($396 + $409);
     $418 = Math_fround($397 + $412);
     $419 = Math_fround($398 + $414);
     $420 = Math_fround($399 + $416);
     $421 = Math_fround($403 - $417);
     $422 = Math_fround($405 - $418);
     $423 = Math_fround($407 - $419);
     $424 = Math_fround($409 - $420);
     $425 = Math_fround($403 + $417);
     $426 = Math_fround($405 + $418);
     $427 = Math_fround($407 + $419);
     $428 = Math_fround($409 + $420);
     $429 = ((($128) + (($401*76)|0)|0) + 16|0);
     $430 = Math_fround(HEAPF32[$429>>2]);
     $431 = ((($128) + (($401*76)|0)|0) + 20|0);
     $432 = Math_fround(HEAPF32[$431>>2]);
     $433 = ((($128) + (($401*76)|0)|0) + 24|0);
     $434 = Math_fround(HEAPF32[$433>>2]);
     $435 = ((($128) + (($401*76)|0)|0) + 28|0);
     $436 = Math_fround(HEAPF32[$435>>2]);
     $437 = Math_fround($430 + $430);
     $438 = Math_fround($432 + $432);
     $439 = Math_fround($434 + $434);
     $440 = Math_fround($430 * $437);
     $441 = Math_fround($432 * $438);
     $442 = Math_fround($434 * $439);
     $443 = Math_fround($437 * $432);
     $444 = Math_fround($437 * $434);
     $445 = Math_fround($437 * $436);
     $446 = Math_fround($438 * $434);
     $447 = Math_fround($438 * $436);
     $448 = Math_fround($439 * $436);
     $449 = Math_fround(Math_fround(1.0) - $441);
     $450 = Math_fround($449 - $442);
     $451 = Math_fround($443 + $448);
     $452 = Math_fround($444 - $447);
     $453 = Math_fround($443 - $448);
     $454 = Math_fround(Math_fround(1.0) - $440);
     $455 = Math_fround($454 - $442);
     $456 = Math_fround($446 + $445);
     $457 = Math_fround($444 + $447);
     $458 = Math_fround($446 - $445);
     $459 = Math_fround($454 - $441);
     $460 = ((($128) + (($401*76)|0)|0) + 32|0);
     $461 = Math_fround(HEAPF32[$460>>2]);
     $462 = ((($128) + (($401*76)|0)|0) + 36|0);
     $463 = Math_fround(HEAPF32[$462>>2]);
     $464 = ((($128) + (($401*76)|0)|0) + 40|0);
     $465 = Math_fround(HEAPF32[$464>>2]);
     $466 = Math_fround($461 * Math_fround(-2.0));
     $467 = Math_fround($463 * Math_fround(-2.0));
     $468 = Math_fround($465 * Math_fround(-2.0));
     $469 = Math_fround($436 * $436);
     $470 = Math_fround($469 + Math_fround(-0.5));
     $471 = Math_fround($430 * $466);
     $472 = Math_fround($432 * $467);
     $473 = Math_fround($471 + $472);
     $474 = Math_fround($434 * $468);
     $475 = Math_fround($473 + $474);
     $476 = Math_fround($466 * $470);
     $477 = Math_fround($432 * $468);
     $478 = Math_fround($434 * $467);
     $479 = Math_fround($477 - $478);
     $480 = Math_fround($436 * $479);
     $481 = Math_fround($476 - $480);
     $482 = Math_fround($430 * $475);
     $483 = Math_fround($482 + $481);
     $484 = Math_fround($470 * $467);
     $485 = Math_fround($434 * $466);
     $486 = Math_fround($430 * $468);
     $487 = Math_fround($485 - $486);
     $488 = Math_fround($436 * $487);
     $489 = Math_fround($484 - $488);
     $490 = Math_fround($432 * $475);
     $491 = Math_fround($490 + $489);
     $492 = Math_fround($470 * $468);
     $493 = Math_fround($430 * $467);
     $494 = Math_fround($432 * $466);
     $495 = Math_fround($493 - $494);
     $496 = Math_fround($436 * $495);
     $497 = Math_fround($492 - $496);
     $498 = Math_fround($434 * $475);
     $499 = Math_fround($497 + $498);
     $500 = Math_fround(-$430);
     $501 = Math_fround(-$432);
     $502 = Math_fround(-$434);
     $503 = ((($214) + ($401<<5)|0) + ($$0$i12$i<<2)|0);
     $504 = Math_fround(HEAPF32[$503>>2]);
     $505 = (((($214) + ($401<<5)|0) + ($$0$i12$i<<2)|0) + 16|0);
     $506 = Math_fround(HEAPF32[$505>>2]);
     $507 = ($i1$0160$i|0)==(0);
     L90: do {
      if ($507) {
       $j$0$ph$i = 0;
      } else {
       $startIndex$0138$i = $i1$0160$i;
       while(1) {
        $510 = (($$0$i10$i) + ($startIndex$0138$i<<2)|0);
        $511 = HEAP32[$510>>2]|0;
        $512 = (((($214) + ($511<<5)|0) + ($$0$i12$i<<2)|0) + 16|0);
        $513 = Math_fround(HEAPF32[$512>>2]);
        $514 = $513 > $504;
        $509 = (($startIndex$0138$i) + -1)|0;
        if (!($514)) {
         $j$0$ph$i = $startIndex$0138$i;
         break L90;
        }
        $508 = ($509|0)==(0);
        if ($508) {
         $j$0$ph$i = 0;
         break;
        } else {
         $startIndex$0138$i = $509;
        }
       }
      }
     } while(0);
     $515 = ($j$0$ph$i>>>0)<($139>>>0);
     L95: do {
      if ($515) {
       $516 = ((($128) + (($401*76)|0)|0) + 72|0);
       $517 = $424 < Math_fround(0.0);
       $518 = (HEAPF32[tempDoublePtr>>2]=$424,HEAP32[tempDoublePtr>>2]|0);
       $519 = $517 ? 0 : $518;
       $520 = $428 > Math_fround(0.0);
       $521 = (HEAPF32[tempDoublePtr>>2]=$428,HEAP32[tempDoublePtr>>2]|0);
       $522 = $520 ? 0 : $521;
       $j$0139$i = $j$0$ph$i;$numOverlaps$0140$i = 0;$overlapMask$0141$i = 0;
       while(1) {
        $523 = ($i1$0160$i|0)==($j$0139$i|0);
        do {
         if ($523) {
          $numOverlaps$1$i = $numOverlaps$0140$i;$overlapMask$1$i = $overlapMask$0141$i;
         } else {
          $524 = (($$0$i10$i) + ($j$0139$i<<2)|0);
          $525 = HEAP32[$524>>2]|0;
          $526 = ((($214) + ($525<<5)|0) + ($$0$i12$i<<2)|0);
          $527 = Math_fround(HEAPF32[$526>>2]);
          $528 = $527 > $506;
          if ($528) {
           $numOverlaps$0$lcssa$i = $numOverlaps$0140$i;$overlapMask$0$lcssa$i = $overlapMask$0141$i;
           break L95;
          }
          $529 = HEAP32[$516>>2]|0;
          $530 = ((($128) + (($525*76)|0)|0) + 72|0);
          $531 = HEAP32[$530>>2]|0;
          $532 = (FUNCTION_TABLE_iii[$137 & 4095]($529,$531)|0);
          if (!($532)) {
           $numOverlaps$1$i = $numOverlaps$0140$i;$overlapMask$1$i = $overlapMask$0141$i;
           break;
          }
          $533 = HEAP32[$524>>2]|0;
          $534 = 1 << $533;
          $535 = $534 | $overlapMask$0141$i;
          $536 = ((($128) + (($525*76)|0)|0) + 56|0);
          $537 = Math_fround(HEAPF32[$536>>2]);
          $538 = Math_fround($396 + $537);
          $539 = ((($128) + (($525*76)|0)|0) + 60|0);
          $540 = Math_fround(HEAPF32[$539>>2]);
          $541 = Math_fround($396 + $540);
          $542 = ((($128) + (($525*76)|0)|0) + 64|0);
          $543 = Math_fround(HEAPF32[$542>>2]);
          $544 = Math_fround($396 + $543);
          $545 = ((($128) + (($525*76)|0)|0) + 44|0);
          $546 = Math_fround(HEAPF32[$545>>2]);
          $547 = Math_fround($546 - $538);
          $548 = ((($128) + (($525*76)|0)|0) + 48|0);
          $549 = Math_fround(HEAPF32[$548>>2]);
          $550 = Math_fround($549 - $541);
          $551 = ((($128) + (($525*76)|0)|0) + 52|0);
          $552 = Math_fround(HEAPF32[$551>>2]);
          $553 = Math_fround($552 - $544);
          $554 = Math_fround($538 + $546);
          $555 = Math_fround($541 + $549);
          $556 = Math_fround($544 + $552);
          HEAPF32[$lcBounds2$i>>2] = $547;
          HEAPF32[$102>>2] = $550;
          HEAPF32[$103>>2] = $553;
          HEAPF32[$104>>2] = $554;
          HEAPF32[$105>>2] = $555;
          HEAPF32[$106>>2] = $556;
          $557 = ((($128) + (($525*76)|0)|0) + 32|0);
          $558 = Math_fround(HEAPF32[$557>>2]);
          $559 = Math_fround($558 * Math_fround(2.0));
          $560 = ((($128) + (($525*76)|0)|0) + 36|0);
          $561 = Math_fround(HEAPF32[$560>>2]);
          $562 = Math_fround($561 * Math_fround(2.0));
          $563 = ((($128) + (($525*76)|0)|0) + 40|0);
          $564 = Math_fround(HEAPF32[$563>>2]);
          $565 = Math_fround($564 * Math_fround(2.0));
          $566 = Math_fround($559 * $500);
          $567 = Math_fround($562 * $501);
          $568 = Math_fround($566 + $567);
          $569 = Math_fround($565 * $502);
          $570 = Math_fround($568 + $569);
          $571 = Math_fround($470 * $559);
          $572 = Math_fround($565 * $501);
          $573 = Math_fround($562 * $502);
          $574 = Math_fround($572 - $573);
          $575 = Math_fround($436 * $574);
          $576 = Math_fround($571 + $575);
          $577 = Math_fround($570 * $500);
          $578 = Math_fround($577 + $576);
          $579 = Math_fround($470 * $562);
          $580 = Math_fround($559 * $502);
          $581 = Math_fround($565 * $500);
          $582 = Math_fround($580 - $581);
          $583 = Math_fround($436 * $582);
          $584 = Math_fround($579 + $583);
          $585 = Math_fround($570 * $501);
          $586 = Math_fround($585 + $584);
          $587 = Math_fround($470 * $565);
          $588 = Math_fround($562 * $500);
          $589 = Math_fround($559 * $501);
          $590 = Math_fround($588 - $589);
          $591 = Math_fround($436 * $590);
          $592 = Math_fround($587 + $591);
          $593 = Math_fround($570 * $502);
          $594 = Math_fround($592 + $593);
          $595 = Math_fround($483 + $578);
          $596 = Math_fround($491 + $586);
          $597 = Math_fround($499 + $594);
          $598 = ((($128) + (($525*76)|0)|0) + 16|0);
          $599 = Math_fround(HEAPF32[$598>>2]);
          $600 = Math_fround($436 * $599);
          $601 = ((($128) + (($525*76)|0)|0) + 28|0);
          $602 = Math_fround(HEAPF32[$601>>2]);
          $603 = Math_fround($602 * $500);
          $604 = Math_fround($600 + $603);
          $605 = ((($128) + (($525*76)|0)|0) + 24|0);
          $606 = Math_fround(HEAPF32[$605>>2]);
          $607 = Math_fround($606 * $501);
          $608 = Math_fround($604 + $607);
          $609 = ((($128) + (($525*76)|0)|0) + 20|0);
          $610 = Math_fround(HEAPF32[$609>>2]);
          $611 = Math_fround($610 * $502);
          $612 = Math_fround($608 - $611);
          $613 = Math_fround($436 * $610);
          $614 = Math_fround($602 * $501);
          $615 = Math_fround($614 + $613);
          $616 = Math_fround($599 * $502);
          $617 = Math_fround($616 + $615);
          $618 = Math_fround($606 * $500);
          $619 = Math_fround($617 - $618);
          $620 = Math_fround($436 * $606);
          $621 = Math_fround($602 * $502);
          $622 = Math_fround($621 + $620);
          $623 = Math_fround($610 * $500);
          $624 = Math_fround($623 + $622);
          $625 = Math_fround($599 * $501);
          $626 = Math_fround($624 - $625);
          $627 = Math_fround($436 * $602);
          $628 = Math_fround($599 * $500);
          $629 = Math_fround($627 - $628);
          $630 = Math_fround($610 * $501);
          $631 = Math_fround($629 - $630);
          $632 = Math_fround($606 * $502);
          $633 = Math_fround($631 - $632);
          HEAPF32[$1>>2] = $612;
          HEAPF32[$107>>2] = $619;
          HEAPF32[$108>>2] = $626;
          HEAPF32[$109>>2] = $633;
          HEAPF32[$110>>2] = $595;
          HEAPF32[$111>>2] = $596;
          HEAPF32[$112>>2] = $597;
          __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($bLocal$i,$1,$lcBounds2$i);
          $634 = Math_fround(HEAPF32[$bLocal$i>>2]);
          $635 = Math_fround(HEAPF32[$113>>2]);
          $636 = Math_fround(HEAPF32[$114>>2]);
          $637 = Math_fround(HEAPF32[$115>>2]);
          $638 = Math_fround(HEAPF32[$116>>2]);
          $639 = Math_fround(HEAPF32[$117>>2]);
          $640 = $421 < $634;
          $641 = $640 ? $634 : $421;
          $642 = $422 < $635;
          $643 = $642 ? $635 : $422;
          $644 = $423 < $636;
          $645 = $644 ? $636 : $423;
          $646 = (HEAPF32[tempDoublePtr>>2]=$641,HEAP32[tempDoublePtr>>2]|0);
          $647 = (HEAPF32[tempDoublePtr>>2]=$643,HEAP32[tempDoublePtr>>2]|0);
          $648 = (HEAPF32[tempDoublePtr>>2]=$645,HEAP32[tempDoublePtr>>2]|0);
          $649 = $637 < $425;
          $650 = $649 ? $637 : $425;
          $651 = $638 < $426;
          $652 = $651 ? $638 : $426;
          $653 = $639 < $427;
          $654 = $653 ? $639 : $427;
          $655 = (HEAPF32[tempDoublePtr>>2]=$650,HEAP32[tempDoublePtr>>2]|0);
          $656 = (HEAPF32[tempDoublePtr>>2]=$652,HEAP32[tempDoublePtr>>2]|0);
          $657 = (HEAPF32[tempDoublePtr>>2]=$654,HEAP32[tempDoublePtr>>2]|0);
          $658 = HEAP32[479712>>2]|0;
          $659 = HEAP32[((479712 + 4|0))>>2]|0;
          $660 = HEAP32[((479712 + 8|0))>>2]|0;
          $661 = HEAP32[((479712 + 12|0))>>2]|0;
          $662 = $658 & $646;
          $663 = $659 & $647;
          $664 = $660 & $648;
          $665 = $661 & $519;
          $666 = HEAP32[479728>>2]|0;
          $667 = HEAP32[((479728 + 4|0))>>2]|0;
          $668 = HEAP32[((479728 + 8|0))>>2]|0;
          $669 = HEAP32[((479728 + 12|0))>>2]|0;
          $670 = $666 & -8388609;
          $671 = $667 & -8388609;
          $672 = $668 & -8388609;
          $673 = $669 & -8388609;
          $674 = $670 | $662;
          $675 = $671 | $663;
          $676 = $672 | $664;
          $677 = $673 | $665;
          $678 = $658 & $655;
          $679 = $659 & $656;
          $680 = $660 & $657;
          $681 = $661 & $522;
          $682 = $666 & 2139095039;
          $683 = $667 & 2139095039;
          $684 = $668 & 2139095039;
          $685 = $669 & 2139095039;
          $686 = $682 | $678;
          $687 = $683 | $679;
          $688 = $684 | $680;
          $689 = $685 | $681;
          $690 = (HEAP32[tempDoublePtr>>2]=$674,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $691 = (HEAP32[tempDoublePtr>>2]=$686,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $692 = $690 > $691;
          if ($692) {
           $numOverlaps$1$i = $numOverlaps$0140$i;$overlapMask$1$i = $535;
           break;
          }
          $693 = (HEAP32[tempDoublePtr>>2]=$675,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $694 = (HEAP32[tempDoublePtr>>2]=$687,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $695 = $693 > $694;
          if ($695) {
           $numOverlaps$1$i = $numOverlaps$0140$i;$overlapMask$1$i = $535;
           break;
          }
          $696 = (HEAP32[tempDoublePtr>>2]=$676,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $697 = (HEAP32[tempDoublePtr>>2]=$688,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $698 = $696 > $697;
          if ($698) {
           $numOverlaps$1$i = $numOverlaps$0140$i;$overlapMask$1$i = $535;
           break;
          }
          $699 = (HEAP32[tempDoublePtr>>2]=$677,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $700 = (HEAP32[tempDoublePtr>>2]=$689,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $701 = $699 > $700;
          if ($701) {
           $numOverlaps$1$i = $numOverlaps$0140$i;$overlapMask$1$i = $535;
           break;
          }
          $702 = (($numOverlaps$0140$i) + 1)|0;
          $703 = (($$0$i8$i) + ($numOverlaps$0140$i<<5)|0);
          HEAP32[$703>>2] = $674;
          $704 = ((($$0$i8$i) + ($numOverlaps$0140$i<<5)|0) + 4|0);
          HEAP32[$704>>2] = $675;
          $705 = ((($$0$i8$i) + ($numOverlaps$0140$i<<5)|0) + 8|0);
          HEAP32[$705>>2] = $676;
          $706 = ((($$0$i8$i) + ($numOverlaps$0140$i<<5)|0) + 12|0);
          HEAP32[$706>>2] = $677;
          $707 = ((($$0$i8$i) + ($numOverlaps$0140$i<<5)|0) + 16|0);
          HEAP32[$707>>2] = $686;
          $708 = ((($$0$i8$i) + ($numOverlaps$0140$i<<5)|0) + 20|0);
          HEAP32[$708>>2] = $687;
          $709 = ((($$0$i8$i) + ($numOverlaps$0140$i<<5)|0) + 24|0);
          HEAP32[$709>>2] = $688;
          $710 = ((($$0$i8$i) + ($numOverlaps$0140$i<<5)|0) + 28|0);
          HEAP32[$710>>2] = $689;
          $numOverlaps$1$i = $702;$overlapMask$1$i = $535;
         }
        } while(0);
        $711 = (($j$0139$i) + 1)|0;
        $712 = ($711>>>0)<($139>>>0);
        if ($712) {
         $j$0139$i = $711;$numOverlaps$0140$i = $numOverlaps$1$i;$overlapMask$0141$i = $overlapMask$1$i;
        } else {
         $numOverlaps$0$lcssa$i = $numOverlaps$1$i;$overlapMask$0$lcssa$i = $overlapMask$1$i;
         break;
        }
       }
      } else {
       $numOverlaps$0$lcssa$i = 0;$overlapMask$0$lcssa$i = 0;
      }
     } while(0);
     $713 = HEAP32[$400>>2]|0;
     $714 = (($136) + ($713<<2)|0);
     HEAP32[$714>>2] = $overlapMask$0$lcssa$i;
     $715 = (($128) + (($401*76)|0)|0);
     $716 = HEAP32[$715>>2]|0;
     $717 = ((($128) + (($401*76)|0)|0) + 4|0);
     $718 = HEAP32[$717>>2]|0;
     $719 = ((($128) + (($713*76)|0)|0) + 68|0);
     $720 = Math_fround(HEAPF32[$719>>2]);
     $721 = Math_fround(Math_fround(1.0) / $720);
     $722 = ((($128) + (($401*76)|0)|0) + 8|0);
     $723 = HEAP32[$722>>2]|0;
     $724 = ($723|0)==(0);
     if ($724) {
      $1621 = $1613;$1622 = $1614;$1623 = $1615;$1624 = $1616;$1625 = $1617;$1626 = $1618;$1627 = $1619;$1628 = $1620;$numParticles$1$lcssa$i = $numParticles$0161$i;
     } else {
      $725 = ((($128) + (($401*76)|0)|0) + 12|0);
      $726 = HEAP32[$725>>2]|0;
      $727 = ($726|0)==(0|0);
      $728 = (($$0$i8$i) + ($numOverlaps$0$lcssa$i<<5)|0);
      $729 = ($$0$i8$i|0)==($728|0);
      $730 = $713&65535;
      $1629 = $1613;$1630 = $1614;$1631 = $1615;$1632 = $1616;$1633 = $1617;$1634 = $1618;$1635 = $1619;$1636 = $1620;$1637 = $723;$k$0156$i = 0;$numParticles$1157$i = $numParticles$0161$i;
      while(1) {
       do {
        if ($727) {
         $731 = (($716) + ($k$0156$i<<4)|0);
         $$sink1$i = $k$0156$i;$$sink131$i = $k$0156$i;$740 = $731;
        } else {
         $732 = (($726) + ($k$0156$i<<2)|0);
         $733 = HEAP32[$732>>2]|0;
         $$pr$i = HEAP32[$725>>2]|0;
         $734 = (($716) + ($733<<4)|0);
         $735 = ($$pr$i|0)==(0|0);
         if ($735) {
          $$sink1$i = $k$0156$i;$$sink131$i = $733;$740 = $734;
          break;
         }
         $736 = (($$pr$i) + ($k$0156$i<<2)|0);
         $737 = HEAP32[$736>>2]|0;
         $$sink1$i = $737;$$sink131$i = $733;$740 = $734;
        }
       } while(0);
       $738 = (($718) + ($$sink1$i<<4)|0);
       $739 = HEAP32[$740>>2]|0;
       $741 = (($740) + 4|0);
       $742 = HEAP32[$741>>2]|0;
       $743 = (($740) + 8|0);
       $744 = HEAP32[$743>>2]|0;
       $745 = (($740) + 12|0);
       $746 = HEAP32[$745>>2]|0;
       L118: do {
        if ($729) {
         $1638 = $1629;$1639 = $1630;$1640 = $1631;$1641 = $1632;$1642 = $1633;$1643 = $1634;$1644 = $1635;$1645 = $1636;$928 = $1637;$numParticles$2$i = $numParticles$1157$i;
        } else {
         $747 = (HEAP32[tempDoublePtr>>2]=$739,Math_fround(HEAPF32[tempDoublePtr>>2]));
         $748 = (HEAP32[tempDoublePtr>>2]=$742,Math_fround(HEAPF32[tempDoublePtr>>2]));
         $749 = (HEAP32[tempDoublePtr>>2]=$744,Math_fround(HEAPF32[tempDoublePtr>>2]));
         $750 = (HEAP32[tempDoublePtr>>2]=$746,Math_fround(HEAPF32[tempDoublePtr>>2]));
         $oIt$0146$i = $$0$i8$i;
         L120: while(1) {
          $751 = Math_fround(HEAPF32[$oIt$0146$i>>2]);
          $752 = $751 > $747;
          do {
           if (!($752)) {
            $753 = (($oIt$0146$i) + 4|0);
            $754 = Math_fround(HEAPF32[$753>>2]);
            $755 = $754 > $748;
            if ($755) {
             break;
            }
            $756 = (($oIt$0146$i) + 8|0);
            $757 = Math_fround(HEAPF32[$756>>2]);
            $758 = $757 > $749;
            if ($758) {
             break;
            }
            $759 = (($oIt$0146$i) + 12|0);
            $760 = Math_fround(HEAPF32[$759>>2]);
            $761 = $760 > $750;
            if ($761) {
             break;
            }
            $762 = (($oIt$0146$i) + 16|0);
            $763 = Math_fround(HEAPF32[$762>>2]);
            $764 = $747 > $763;
            if ($764) {
             break;
            }
            $765 = (($oIt$0146$i) + 20|0);
            $766 = Math_fround(HEAPF32[$765>>2]);
            $767 = $748 > $766;
            if ($767) {
             break;
            }
            $768 = (($oIt$0146$i) + 24|0);
            $769 = Math_fround(HEAPF32[$768>>2]);
            $770 = $749 > $769;
            if ($770) {
             break;
            }
            $771 = (($oIt$0146$i) + 28|0);
            $772 = Math_fround(HEAPF32[$771>>2]);
            $773 = $750 > $772;
            if (!($773)) {
             break L120;
            }
           }
          } while(0);
          $924 = (($oIt$0146$i) + 32|0);
          $925 = ($924|0)==($728|0);
          if ($925) {
           $1638 = $1629;$1639 = $1630;$1640 = $1631;$1641 = $1632;$1642 = $1633;$1643 = $1634;$1644 = $1635;$1645 = $1636;$928 = $1637;$numParticles$2$i = $numParticles$1157$i;
           break L118;
          } else {
           $oIt$0146$i = $924;
          }
         }
         $774 = Math_fround($450 * $747);
         $775 = Math_fround($451 * $747);
         $776 = Math_fround($452 * $747);
         $777 = Math_fround($747 * Math_fround(0.0));
         $778 = Math_fround($461 + $774);
         $779 = Math_fround($463 + $775);
         $780 = Math_fround($465 + $776);
         $781 = Math_fround($777 + Math_fround(1.0));
         $782 = Math_fround($453 * $748);
         $783 = Math_fround($455 * $748);
         $784 = Math_fround($456 * $748);
         $785 = Math_fround($748 * Math_fround(0.0));
         $786 = Math_fround($778 + $782);
         $787 = Math_fround($779 + $783);
         $788 = Math_fround($780 + $784);
         $789 = Math_fround($781 + $785);
         $790 = Math_fround($457 * $749);
         $791 = Math_fround($458 * $749);
         $792 = Math_fround($459 * $749);
         $793 = Math_fround($749 * Math_fround(0.0));
         $794 = Math_fround($786 + $790);
         $795 = Math_fround($787 + $791);
         $796 = Math_fround($788 + $792);
         $797 = Math_fround($789 + $793);
         $798 = (HEAPF32[tempDoublePtr>>2]=$794,HEAP32[tempDoublePtr>>2]|0);
         $799 = (HEAPF32[tempDoublePtr>>2]=$795,HEAP32[tempDoublePtr>>2]|0);
         $800 = (HEAPF32[tempDoublePtr>>2]=$796,HEAP32[tempDoublePtr>>2]|0);
         $801 = (HEAPF32[tempDoublePtr>>2]=$797,HEAP32[tempDoublePtr>>2]|0);
         $802 = HEAP32[479712>>2]|0;
         $803 = HEAP32[((479712 + 4|0))>>2]|0;
         $804 = HEAP32[((479712 + 8|0))>>2]|0;
         $805 = HEAP32[((479712 + 12|0))>>2]|0;
         $806 = $798 ^ $739;
         $807 = $799 ^ $742;
         $808 = $800 ^ $744;
         $809 = $801 ^ $746;
         $810 = $802 & $806;
         $811 = $803 & $807;
         $812 = $804 & $808;
         $813 = $805 & $809;
         $814 = $810 ^ $739;
         $815 = $811 ^ $742;
         $816 = $812 ^ $744;
         $817 = $813 ^ $746;
         HEAP32[$740>>2] = $814;
         HEAP32[$741>>2] = $815;
         HEAP32[$743>>2] = $816;
         HEAP32[$745>>2] = $817;
         $818 = Math_fround(HEAPF32[$738>>2]);
         $819 = Math_fround($747 - $818);
         $820 = ((($718) + ($$sink1$i<<4)|0) + 4|0);
         $821 = Math_fround(HEAPF32[$820>>2]);
         $822 = Math_fround($748 - $821);
         $823 = ((($718) + ($$sink1$i<<4)|0) + 8|0);
         $824 = Math_fround(HEAPF32[$823>>2]);
         $825 = Math_fround($749 - $824);
         $826 = ((($718) + ($$sink1$i<<4)|0) + 12|0);
         $827 = Math_fround(HEAPF32[$826>>2]);
         $828 = Math_fround($750 - $827);
         $829 = Math_fround($721 * $819);
         $830 = Math_fround($721 * $822);
         $831 = Math_fround($721 * $825);
         $832 = Math_fround($721 * $828);
         $833 = (HEAPF32[tempDoublePtr>>2]=$832,HEAP32[tempDoublePtr>>2]|0);
         $834 = Math_fround($450 * $829);
         $835 = Math_fround($451 * $829);
         $836 = Math_fround($452 * $829);
         $837 = Math_fround($829 * Math_fround(0.0));
         $838 = Math_fround($453 * $830);
         $839 = Math_fround($455 * $830);
         $840 = Math_fround($456 * $830);
         $841 = Math_fround($830 * Math_fround(0.0));
         $842 = Math_fround($834 + $838);
         $843 = Math_fround($835 + $839);
         $844 = Math_fround($836 + $840);
         $845 = Math_fround($837 + $841);
         $846 = Math_fround($457 * $831);
         $847 = Math_fround($458 * $831);
         $848 = Math_fround($459 * $831);
         $849 = Math_fround($831 * Math_fround(0.0));
         $850 = Math_fround($842 + $846);
         $851 = Math_fround($843 + $847);
         $852 = Math_fround($844 + $848);
         $853 = Math_fround($845 + $849);
         $854 = (HEAPF32[tempDoublePtr>>2]=$850,HEAP32[tempDoublePtr>>2]|0);
         $855 = (HEAPF32[tempDoublePtr>>2]=$851,HEAP32[tempDoublePtr>>2]|0);
         $856 = (HEAPF32[tempDoublePtr>>2]=$852,HEAP32[tempDoublePtr>>2]|0);
         $857 = (HEAPF32[tempDoublePtr>>2]=$853,HEAP32[tempDoublePtr>>2]|0);
         $858 = HEAP32[479712>>2]|0;
         $859 = HEAP32[((479712 + 4|0))>>2]|0;
         $860 = HEAP32[((479712 + 8|0))>>2]|0;
         $861 = HEAP32[((479712 + 12|0))>>2]|0;
         $862 = (HEAPF32[tempDoublePtr>>2]=$829,HEAP32[tempDoublePtr>>2]|0);
         $863 = $854 ^ $862;
         $864 = (HEAPF32[tempDoublePtr>>2]=$830,HEAP32[tempDoublePtr>>2]|0);
         $865 = $855 ^ $864;
         $866 = (HEAPF32[tempDoublePtr>>2]=$831,HEAP32[tempDoublePtr>>2]|0);
         $867 = $856 ^ $866;
         $868 = $857 ^ $833;
         $869 = $863 & $858;
         $870 = $865 & $859;
         $871 = $867 & $860;
         $872 = $868 & $861;
         $873 = $869 ^ $862;
         $874 = $870 ^ $864;
         $875 = $871 ^ $866;
         $876 = $872 ^ $833;
         HEAP32[$738>>2] = $873;
         HEAP32[$820>>2] = $874;
         HEAP32[$823>>2] = $875;
         HEAP32[$826>>2] = $876;
         $$sum$i = (($$sink131$i) + 1)|0;
         $877 = (($716) + ($$sum$i<<4)|0);
         $878 = ($740|0)==($877|0);
         L132: do {
          if ($878) {
           $1646 = $1629;$1647 = $1630;$1648 = $1631;$1649 = $1632;$1650 = $1633;$1651 = $1634;$1652 = $1635;$1653 = $1636;
          } else {
           $879 = (HEAP32[tempDoublePtr>>2]=$817,Math_fround(HEAPF32[tempDoublePtr>>2]));
           $880 = (HEAP32[tempDoublePtr>>2]=$816,Math_fround(HEAPF32[tempDoublePtr>>2]));
           $881 = (HEAP32[tempDoublePtr>>2]=$815,Math_fround(HEAPF32[tempDoublePtr>>2]));
           $$05$i$i = $740;$$in$i$i = $1629;$$in10$i$i = $1634;$$in11$i$i = $1635;$$in12$i$i = $1636;$$in6$i$i = $1630;$$in7$i$i = $1631;$$in8$i$i = $1632;$$in9$i$i = $1633;$894 = $881;$897 = $880;$900 = $879;
           while(1) {
            $882 = (HEAP32[tempDoublePtr>>2]=$$in12$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
            $883 = (HEAP32[tempDoublePtr>>2]=$$in11$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
            $884 = (HEAP32[tempDoublePtr>>2]=$$in10$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
            $885 = (HEAP32[tempDoublePtr>>2]=$$in9$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
            $886 = (HEAP32[tempDoublePtr>>2]=$$in8$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
            $887 = (HEAP32[tempDoublePtr>>2]=$$in7$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
            $888 = (HEAP32[tempDoublePtr>>2]=$$in6$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
            $889 = (HEAP32[tempDoublePtr>>2]=$$in$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
            $890 = Math_fround(HEAPF32[$$05$i$i>>2]);
            $891 = $890 < $882;
            $892 = $891 ? $890 : $882;
            $893 = $894 < $883;
            $895 = $893 ? $894 : $883;
            $896 = $897 < $884;
            $898 = $896 ? $897 : $884;
            $899 = $900 < $885;
            $901 = $899 ? $900 : $885;
            $902 = (HEAPF32[tempDoublePtr>>2]=$892,HEAP32[tempDoublePtr>>2]|0);
            $903 = (HEAPF32[tempDoublePtr>>2]=$895,HEAP32[tempDoublePtr>>2]|0);
            $904 = (HEAPF32[tempDoublePtr>>2]=$898,HEAP32[tempDoublePtr>>2]|0);
            $905 = (HEAPF32[tempDoublePtr>>2]=$901,HEAP32[tempDoublePtr>>2]|0);
            $906 = $886 < $890;
            $907 = $906 ? $890 : $886;
            $908 = $887 < $894;
            $909 = $908 ? $894 : $887;
            $910 = $888 < $897;
            $911 = $910 ? $897 : $888;
            $912 = $889 < $900;
            $913 = $912 ? $900 : $889;
            $914 = (HEAPF32[tempDoublePtr>>2]=$907,HEAP32[tempDoublePtr>>2]|0);
            $915 = (HEAPF32[tempDoublePtr>>2]=$909,HEAP32[tempDoublePtr>>2]|0);
            $916 = (HEAPF32[tempDoublePtr>>2]=$911,HEAP32[tempDoublePtr>>2]|0);
            $917 = (HEAPF32[tempDoublePtr>>2]=$913,HEAP32[tempDoublePtr>>2]|0);
            $918 = (($$05$i$i) + 16|0);
            $919 = ($918|0)==($877|0);
            if ($919) {
             $1646 = $917;$1647 = $916;$1648 = $915;$1649 = $914;$1650 = $905;$1651 = $904;$1652 = $903;$1653 = $902;
             break L132;
            }
            $$phi$trans$insert$i = (($$05$i$i) + 20|0);
            $$pre221$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
            $$phi$trans$insert222$i = (($$05$i$i) + 24|0);
            $$pre223$i = Math_fround(HEAPF32[$$phi$trans$insert222$i>>2]);
            $$phi$trans$insert224$i = (($$05$i$i) + 28|0);
            $$pre225$i = Math_fround(HEAPF32[$$phi$trans$insert224$i>>2]);
            $$05$i$i = $918;$$in$i$i = $917;$$in10$i$i = $904;$$in11$i$i = $903;$$in12$i$i = $902;$$in6$i$i = $916;$$in7$i$i = $915;$$in8$i$i = $914;$$in9$i$i = $905;$894 = $$pre221$i;$897 = $$pre223$i;$900 = $$pre225$i;
           }
          }
         } while(0);
         $920 = (($134) + ($numParticles$1157$i<<1)|0);
         HEAP16[$920>>1] = $730;
         $$idx$i = $$sink131$i << 4;
         $921 = $$idx$i >> 4;
         $922 = (($135) + ($numParticles$1157$i<<2)|0);
         HEAP32[$922>>2] = $921;
         $923 = (($numParticles$1157$i) + 1)|0;
         $$pre$i = HEAP32[$722>>2]|0;
         $1638 = $1646;$1639 = $1647;$1640 = $1648;$1641 = $1649;$1642 = $1650;$1643 = $1651;$1644 = $1652;$1645 = $1653;$928 = $$pre$i;$numParticles$2$i = $923;
        }
       } while(0);
       $926 = (($k$0156$i) + 1)|0;
       $927 = ($926>>>0)<($928>>>0);
       if ($927) {
        $1629 = $1638;$1630 = $1639;$1631 = $1640;$1632 = $1641;$1633 = $1642;$1634 = $1643;$1635 = $1644;$1636 = $1645;$1637 = $928;$k$0156$i = $926;$numParticles$1157$i = $numParticles$2$i;
       } else {
        $1621 = $1638;$1622 = $1639;$1623 = $1640;$1624 = $1641;$1625 = $1642;$1626 = $1643;$1627 = $1644;$1628 = $1645;$numParticles$1$lcssa$i = $numParticles$2$i;
        break;
       }
      }
     }
     $929 = (($i1$0160$i) + 1)|0;
     $930 = ($929>>>0)<($139>>>0);
     if ($930) {
      $1613 = $1621;$1614 = $1622;$1615 = $1623;$1616 = $1624;$1617 = $1625;$1618 = $1626;$1619 = $1627;$1620 = $1628;$i1$0160$i = $929;$numParticles$0161$i = $numParticles$1$lcssa$i;
     } else {
      $973 = $numParticles$1$lcssa$i;$976 = $1624;$978 = $1628;$981 = $1623;$983 = $1627;$986 = $1622;$988 = $1626;$991 = $1621;$993 = $1625;
      break;
     }
    }
   }
   $931 = ($$0$i10$i|0)==(0|0);
   L141: do {
    if (!($931)) {
     $932 = (($$0$i10$i) + -4|0);
     $933 = HEAP32[$932>>2]|0;
     $934 = $933 | -2147483648;
     HEAP32[$932>>2] = $934;
     $935 = (($138) + 12|0);
     $936 = HEAP32[$935>>2]|0;
     $937 = ($936|0)==(0|0);
     if (!($937)) {
      $938 = (($138) + 8|0);
      $940 = $936;
      while(1) {
       $939 = (($940) + 4|0);
       $941 = HEAP32[$939>>2]|0;
       $942 = ($941|0)<(0);
       if (!($942)) {
        break L141;
       }
       HEAP32[$938>>2] = $940;
       $943 = HEAP32[$940>>2]|0;
       HEAP32[$935>>2] = $943;
       $944 = ($943|0)==(0|0);
       if ($944) {
        break;
       } else {
        $940 = $943;
       }
      }
     }
    }
   } while(0);
   $945 = ($$0$i8$i|0)==(0|0);
   L148: do {
    if (!($945)) {
     $946 = (($$0$i8$i) + -4|0);
     $947 = HEAP32[$946>>2]|0;
     $948 = $947 | -2147483648;
     HEAP32[$946>>2] = $948;
     $949 = (($138) + 12|0);
     $950 = HEAP32[$949>>2]|0;
     $951 = ($950|0)==(0|0);
     if (!($951)) {
      $952 = (($138) + 8|0);
      $954 = $950;
      while(1) {
       $953 = (($954) + 4|0);
       $955 = HEAP32[$953>>2]|0;
       $956 = ($955|0)<(0);
       if (!($956)) {
        break L148;
       }
       HEAP32[$952>>2] = $954;
       $957 = HEAP32[$954>>2]|0;
       HEAP32[$949>>2] = $957;
       $958 = ($957|0)==(0|0);
       if ($958) {
        break;
       } else {
        $954 = $957;
       }
      }
     }
    }
   } while(0);
   $959 = ($$0$i130$i|0)==(0|0);
   L155: do {
    if (!($959)) {
     $960 = (($$0$i130$i) + -4|0);
     $961 = HEAP32[$960>>2]|0;
     $962 = $961 | -2147483648;
     HEAP32[$960>>2] = $962;
     $963 = (($138) + 12|0);
     $964 = HEAP32[$963>>2]|0;
     $965 = ($964|0)==(0|0);
     if (!($965)) {
      $966 = (($138) + 8|0);
      $968 = $964;
      while(1) {
       $967 = (($968) + 4|0);
       $969 = HEAP32[$967>>2]|0;
       $970 = ($969|0)<(0);
       if (!($970)) {
        break L155;
       }
       HEAP32[$966>>2] = $968;
       $971 = HEAP32[$968>>2]|0;
       HEAP32[$963>>2] = $971;
       $972 = ($971|0)==(0|0);
       if ($972) {
        break;
       } else {
        $968 = $971;
       }
      }
     }
    }
   } while(0);
   HEAP32[$68>>2] = $973;
   $974 = ($973|0)==(0);
   L162: do {
    if (!($974)) {
     $975 = (HEAP32[tempDoublePtr>>2]=$976,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $977 = (HEAP32[tempDoublePtr>>2]=$978,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $979 = Math_fround($975 - $977);
     $980 = (HEAP32[tempDoublePtr>>2]=$981,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $982 = (HEAP32[tempDoublePtr>>2]=$983,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $984 = Math_fround($980 - $982);
     $985 = (HEAP32[tempDoublePtr>>2]=$986,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $987 = (HEAP32[tempDoublePtr>>2]=$988,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $989 = Math_fround($985 - $987);
     $990 = (HEAP32[tempDoublePtr>>2]=$991,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $992 = (HEAP32[tempDoublePtr>>2]=$993,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $994 = Math_fround($990 - $992);
     $995 = HEAP32[479744>>2]|0;
     $996 = HEAP32[((479744 + 4|0))>>2]|0;
     $997 = HEAP32[((479744 + 8|0))>>2]|0;
     $998 = HEAP32[((479744 + 12|0))>>2]|0;
     $999 = (HEAP32[tempDoublePtr>>2]=$995,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1000 = $979 < $999;
     $1001 = $1000 ? $999 : $979;
     $1002 = (HEAP32[tempDoublePtr>>2]=$996,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1003 = $984 < $1002;
     $1004 = $1003 ? $1002 : $984;
     $1005 = (HEAP32[tempDoublePtr>>2]=$997,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1006 = $989 < $1005;
     $1007 = $1006 ? $1005 : $989;
     $1008 = (HEAP32[tempDoublePtr>>2]=$998,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1009 = $994 < $1008;
     $1010 = $1009 ? $1008 : $994;
     HEAPF32[$edgeLength>>2] = $1001;
     HEAPF32[$87>>2] = $1004;
     HEAPF32[$88>>2] = $1007;
     HEAPF32[$89>>2] = $1010;
     $1011 = $1001 > $1004;
     if ($1011) {
      $1012 = $1001 > $1007;
      $1013 = $1012 ? 0 : 2;
      $$0$i15 = $1013;
     } else {
      $1014 = $1004 > $1007;
      $1015 = $1014 ? 1 : 2;
      $$0$i15 = $1015;
     }
     $1016 = (($$0$i15) + 1)|0;
     $1017 = (($1016>>>0) % 3)&-1;
     $1018 = (($$0$i15) + 2)|0;
     $1019 = (($1018>>>0) % 3)&-1;
     $1020 = Math_fround($1001 * Math_fround(0.00395256932824850082397));
     $1021 = Math_fround($1004 * Math_fround(0.00395256932824850082397));
     $1022 = Math_fround($1007 * Math_fround(0.00395256932824850082397));
     $1023 = Math_fround($1010 * Math_fround(0.00395256932824850082397));
     $1024 = Math_fround(HEAPF32[$62>>2]);
     $1025 = $1024 < $1020;
     $1026 = $1025 ? $1020 : $1024;
     $1027 = Math_fround(HEAPF32[$63>>2]);
     $1028 = $1027 < $1021;
     $1029 = $1028 ? $1021 : $1027;
     $1030 = Math_fround(HEAPF32[$64>>2]);
     $1031 = $1030 < $1022;
     $1032 = $1031 ? $1022 : $1030;
     $1033 = Math_fround(HEAPF32[$65>>2]);
     $1034 = $1033 < $1023;
     $1035 = $1034 ? $1023 : $1033;
     HEAPF32[$cellSize>>2] = $1026;
     HEAPF32[$90>>2] = $1029;
     HEAPF32[$91>>2] = $1032;
     HEAPF32[$92>>2] = $1035;
     $1036 = (($edgeLength) + ($$0$i15<<2)|0);
     $1037 = Math_fround(HEAPF32[$1036>>2]);
     $1038 = Math_fround($1037 / Math_fround(65533.0));
     $1039 = (($cellSize) + ($$0$i15<<2)|0);
     HEAPF32[$1039>>2] = $1038;
     HEAPF32[$gridSize>>2] = Math_fround(254.0);
     HEAPF32[$93>>2] = Math_fround(254.0);
     HEAPF32[$94>>2] = Math_fround(254.0);
     HEAPF32[$95>>2] = Math_fround(254.0);
     $1040 = (($gridSize) + ($$0$i15<<2)|0);
     HEAPF32[$1040>>2] = Math_fround(65534.0);
     $1041 = Math_fround(HEAPF32[$cellSize>>2]);
     $1042 = Math_fround(Math_fround(1.0) / $1041);
     $1043 = Math_fround(HEAPF32[$90>>2]);
     $1044 = Math_fround(Math_fround(1.0) / $1043);
     $1045 = Math_fround(HEAPF32[$91>>2]);
     $1046 = Math_fround(Math_fround(1.0) / $1045);
     $1047 = Math_fround(HEAPF32[$92>>2]);
     $1048 = Math_fround(Math_fround(1.0) / $1047);
     $1049 = Math_fround($977 * $1042);
     $1050 = Math_fround($982 * $1044);
     $1051 = Math_fround($987 * $1046);
     $1052 = Math_fround($992 * $1048);
     $1053 = Math_fround(Math_fround(1.0) - $1049);
     $1054 = Math_fround(Math_fround(1.0) - $1050);
     $1055 = Math_fround(Math_fround(1.0) - $1051);
     $1056 = Math_fround(Math_fround(1.0) - $1052);
     $1057 = HEAP32[$4>>2]|0;
     $1058 = $973 << 2;
     $1059 = $973 << 3;
     $1060 = (($1058) + 4096)|0;
     $1061 = ($1060>>>0)<($1058>>>0);
     $1062 = $1061 ? $1058 : $1060;
     $1063 = (($1062) + ($1059))|0;
     $1064 = ($1063|0)==(0);
     if ($1064) {
      $$0$i22 = 0;$1078 = $973;
     } else {
      $1065 = (($1057) + 8|0);
      $1066 = HEAP32[$1065>>2]|0;
      $1067 = $1066;
      $1068 = (($1067) + 23)|0;
      $1069 = $1068 & -16;
      $1070 = $1069;
      $1071 = (($1070) + ($1063)|0);
      $1072 = (($1070) + -8|0);
      $1073 = (($1057) + 12|0);
      $1074 = HEAP32[$1073>>2]|0;
      HEAP32[$1072>>2] = $1074;
      $1075 = (($1070) + -4|0);
      $1076 = $1063 & 2147483644;
      HEAP32[$1075>>2] = $1076;
      HEAP32[$1073>>2] = $1072;
      HEAP32[$1065>>2] = $1071;
      $$pre241 = HEAP32[$68>>2]|0;
      $$0$i22 = $1070;$1078 = $$pre241;
     }
     $1077 = (($$0$i22) + ($1078<<2)|0);
     $$sum = $1078 << 1;
     $1079 = (($$0$i22) + ($$sum<<2)|0);
     $$sum1 = (($$sum) + 1024)|0;
     $1080 = (($$0$i22) + ($$sum1<<2)|0);
     $1081 = ($1079>>>0)<($1080>>>0);
     $1082 = $1081 ? $1080 : $1079;
     $1083 = ($1078|0)==(0);
     if ($1083) {
      $$lcssa168 = 0;
     } else {
      $1084 = HEAP32[$22>>2]|0;
      $1085 = HEAP32[$39>>2]|0;
      $1086 = HEAP32[$61>>2]|0;
      $1087 = Math_fround(HEAPF32[$gridSize>>2]);
      $1088 = Math_fround(HEAPF32[$93>>2]);
      $1089 = Math_fround(HEAPF32[$94>>2]);
      $1090 = Math_fround(HEAPF32[$95>>2]);
      $1091 = (($indexi) + ($$0$i15<<2)|0);
      $1092 = (($indexi) + ($1017<<2)|0);
      $1093 = (($indexi) + ($1019<<2)|0);
      $i$0169 = 0;
      while(1) {
       $1094 = (($1084) + ($i$0169<<1)|0);
       $1095 = HEAP16[$1094>>1]|0;
       $1096 = (($1085) + ($i$0169<<2)|0);
       $1097 = HEAP32[$1096>>2]|0;
       $1098 = $1095&65535;
       $1099 = (($1086) + (($1098*76)|0)|0);
       $1100 = HEAP32[$1099>>2]|0;
       $1101 = (($1100) + ($1097<<4)|0);
       $1102 = Math_fround(HEAPF32[$1101>>2]);
       $1103 = Math_fround($1042 * $1102);
       $1104 = ((($1100) + ($1097<<4)|0) + 4|0);
       $1105 = Math_fround(HEAPF32[$1104>>2]);
       $1106 = Math_fround($1044 * $1105);
       $1107 = ((($1100) + ($1097<<4)|0) + 8|0);
       $1108 = Math_fround(HEAPF32[$1107>>2]);
       $1109 = Math_fround($1046 * $1108);
       $1110 = ((($1100) + ($1097<<4)|0) + 12|0);
       $1111 = Math_fround(HEAPF32[$1110>>2]);
       $1112 = Math_fround($1048 * $1111);
       $1113 = Math_fround($1053 + $1103);
       $1114 = Math_fround($1054 + $1106);
       $1115 = Math_fround($1055 + $1109);
       $1116 = Math_fround($1056 + $1112);
       $1117 = $1087 < $1113;
       $1118 = $1117 ? $1087 : $1113;
       $1119 = $1088 < $1114;
       $1120 = $1119 ? $1088 : $1114;
       $1121 = $1089 < $1115;
       $1122 = $1121 ? $1089 : $1115;
       $1123 = $1090 < $1116;
       $1124 = $1123 ? $1090 : $1116;
       $1125 = $1118 > Math_fround(1.0);
       $1126 = $1125 ? $1118 : Math_fround(1.0);
       $1127 = $1120 > Math_fround(1.0);
       $1128 = $1127 ? $1120 : Math_fround(1.0);
       $1129 = $1122 > Math_fround(1.0);
       $1130 = $1129 ? $1122 : Math_fround(1.0);
       $1131 = $1124 > Math_fround(1.0);
       $1132 = $1131 ? $1124 : Math_fround(1.0);
       $floorf$i18 = (Math_fround(Math_floor((Math_fround($1126)))));
       $1133 = (~~(($floorf$i18)));
       $floorf1$i19 = (Math_fround(Math_floor((Math_fround($1128)))));
       $1134 = (~~(($floorf1$i19)));
       $floorf2$i20 = (Math_fround(Math_floor((Math_fround($1130)))));
       $1135 = (~~(($floorf2$i20)));
       $floorf3$i21 = (Math_fround(Math_floor((Math_fround($1132)))));
       $1136 = (~~(($floorf3$i21)));
       HEAP32[$indexi>>2] = $1133;
       HEAP32[$99>>2] = $1134;
       HEAP32[$100>>2] = $1135;
       HEAP32[$101>>2] = $1136;
       $1137 = HEAP32[$1091>>2]|0;
       $1138 = HEAP32[$1092>>2]|0;
       $1139 = $1138 << 16;
       $1140 = $1139 | $1137;
       $1141 = HEAP32[$1093>>2]|0;
       $1142 = $1141 << 24;
       $1143 = $1140 | $1142;
       $1144 = (($1082) + ($i$0169<<2)|0);
       HEAP32[$1144>>2] = $1143;
       $1145 = (($i$0169) + 1)|0;
       $1146 = HEAP32[$68>>2]|0;
       $1147 = ($1145>>>0)<($1146>>>0);
       if ($1147) {
        $i$0169 = $1145;
       } else {
        $$lcssa168 = $1146;
        break;
       }
      }
     }
     $1148 = (($1082) + ($$lcssa168<<2)|0);
     $$idx125 = $$lcssa168 << 2;
     $1149 = $$idx125 >> 2;
     $1150 = $$idx125 >> 1;
     $1151 = (($$0$i22) + ($1150<<2)|0);
     $$sum$i16 = (($1150) + 256)|0;
     $$sum1$i = (($1150) + 512)|0;
     $$sum2$i = (($1150) + 768)|0;
     _memset(($1151|0),0,4096)|0;
     $1152 = ($$lcssa168|0)==(0);
     if ($1152) {
      $i$030$i = 0;$sums$sroa$0$031$i = 0;$sums$sroa$1$032$i = 0;$sums$sroa$2$033$i = 0;$sums$sroa$3$034$i = 0;
     } else {
      $it$035$i = $1082;
      while(1) {
       $1153 = HEAP32[$it$035$i>>2]|0;
       $1154 = $1153 & 255;
       $$sum15$i = (($1154) + ($1150))|0;
       $1155 = (($$0$i22) + ($$sum15$i<<2)|0);
       $1156 = HEAP32[$1155>>2]|0;
       $1157 = (($1156) + 1)|0;
       HEAP32[$1155>>2] = $1157;
       $1158 = $1153 >>> 8;
       $1159 = $1158 & 255;
       $$sum16$i = (($1159) + ($$sum$i16))|0;
       $1160 = (($$0$i22) + ($$sum16$i<<2)|0);
       $1161 = HEAP32[$1160>>2]|0;
       $1162 = (($1161) + 1)|0;
       HEAP32[$1160>>2] = $1162;
       $1163 = $1153 >>> 16;
       $1164 = $1163 & 255;
       $$sum17$i = (($1164) + ($$sum1$i))|0;
       $1165 = (($$0$i22) + ($$sum17$i<<2)|0);
       $1166 = HEAP32[$1165>>2]|0;
       $1167 = (($1166) + 1)|0;
       HEAP32[$1165>>2] = $1167;
       $1168 = $1153 >>> 24;
       $$sum18$i = (($1168) + ($$sum2$i))|0;
       $1169 = (($$0$i22) + ($$sum18$i<<2)|0);
       $1170 = HEAP32[$1169>>2]|0;
       $1171 = (($1170) + 1)|0;
       HEAP32[$1169>>2] = $1171;
       $1172 = (($it$035$i) + 4|0);
       $1173 = ($1172|0)==($1148|0);
       if ($1173) {
        $i$030$i = 0;$sums$sroa$0$031$i = 0;$sums$sroa$1$032$i = 0;$sums$sroa$2$033$i = 0;$sums$sroa$3$034$i = 0;
        break;
       } else {
        $it$035$i = $1172;
       }
      }
     }
     while(1) {
      $$sum11$i = (($i$030$i) + ($1150))|0;
      $1175 = (($$0$i22) + ($$sum11$i<<2)|0);
      $1176 = HEAP32[$1175>>2]|0;
      $1177 = (($1176) + ($sums$sroa$0$031$i))|0;
      HEAP32[$1175>>2] = $sums$sroa$0$031$i;
      $$sum12$i = (($i$030$i) + ($$sum$i16))|0;
      $1178 = (($$0$i22) + ($$sum12$i<<2)|0);
      $1179 = HEAP32[$1178>>2]|0;
      $1180 = (($1179) + ($sums$sroa$1$032$i))|0;
      HEAP32[$1178>>2] = $sums$sroa$1$032$i;
      $$sum13$i = (($i$030$i) + ($$sum1$i))|0;
      $1181 = (($$0$i22) + ($$sum13$i<<2)|0);
      $1182 = HEAP32[$1181>>2]|0;
      $1183 = (($1182) + ($sums$sroa$2$033$i))|0;
      HEAP32[$1181>>2] = $sums$sroa$2$033$i;
      $$sum14$i = (($i$030$i) + ($$sum2$i))|0;
      $1184 = (($$0$i22) + ($$sum14$i<<2)|0);
      $1185 = HEAP32[$1184>>2]|0;
      $1186 = (($1185) + ($sums$sroa$3$034$i))|0;
      HEAP32[$1184>>2] = $sums$sroa$3$034$i;
      $1187 = (($i$030$i) + 1)|0;
      $exitcond$i = ($1187|0)==(256);
      if ($exitcond$i) {
       break;
      } else {
       $i$030$i = $1187;$sums$sroa$0$031$i = $1177;$sums$sroa$1$032$i = $1180;$sums$sroa$2$033$i = $1183;$sums$sroa$3$034$i = $1186;
      }
     }
     $1174 = ($1149|0)==(0);
     if (!($1174)) {
      $i1$027$i = 0;
      while(1) {
       $1188 = (($1082) + ($i1$027$i<<2)|0);
       $1189 = HEAP32[$1188>>2]|0;
       $1190 = $1189 & 255;
       $$sum9$i = (($1190) + ($1150))|0;
       $1191 = (($$0$i22) + ($$sum9$i<<2)|0);
       $1192 = HEAP32[$1191>>2]|0;
       $1193 = (($1192) + 1)|0;
       HEAP32[$1191>>2] = $1193;
       $$sum10$i = (($1192) + ($1149))|0;
       $1194 = (($$0$i22) + ($$sum10$i<<2)|0);
       HEAP32[$1194>>2] = $i1$027$i;
       $1195 = (($i1$027$i) + 1)|0;
       $1196 = ($1195|0)==($1149|0);
       if ($1196) {
        $$pn$i = $1149;$i2$024$i = 0;
        break;
       } else {
        $i1$027$i = $1195;
       }
      }
      while(1) {
       $$in$i = (($$0$i22) + ($$pn$i<<2)|0);
       $1197 = HEAP32[$$in$i>>2]|0;
       $1198 = (($1082) + ($1197<<2)|0);
       $1199 = HEAP32[$1198>>2]|0;
       $1200 = $1199 >>> 8;
       $1201 = $1200 & 255;
       $$sum8$i = (($1201) + ($$sum$i16))|0;
       $1202 = (($$0$i22) + ($$sum8$i<<2)|0);
       $1203 = HEAP32[$1202>>2]|0;
       $1204 = (($1203) + 1)|0;
       HEAP32[$1202>>2] = $1204;
       $1205 = (($$0$i22) + ($1203<<2)|0);
       HEAP32[$1205>>2] = $1197;
       $1206 = (($i2$024$i) + 1)|0;
       $$sum3$i = (($1206) + ($1149))|0;
       $1207 = ($1206|0)==($1149|0);
       if ($1207) {
        $$in38$i = $$0$i22;$i3$021$i = 0;
        break;
       } else {
        $$pn$i = $$sum3$i;$i2$024$i = $1206;
       }
      }
      while(1) {
       $1208 = HEAP32[$$in38$i>>2]|0;
       $1209 = (($1082) + ($1208<<2)|0);
       $1210 = HEAP32[$1209>>2]|0;
       $1211 = $1210 >>> 16;
       $1212 = $1211 & 255;
       $$sum6$i = (($1212) + ($$sum1$i))|0;
       $1213 = (($$0$i22) + ($$sum6$i<<2)|0);
       $1214 = HEAP32[$1213>>2]|0;
       $1215 = (($1214) + 1)|0;
       HEAP32[$1213>>2] = $1215;
       $$sum7$i = (($1214) + ($1149))|0;
       $1216 = (($$0$i22) + ($$sum7$i<<2)|0);
       HEAP32[$1216>>2] = $1208;
       $1217 = (($i3$021$i) + 1)|0;
       $1218 = (($$0$i22) + ($1217<<2)|0);
       $1219 = ($1217|0)==($1149|0);
       if ($1219) {
        $$pn40$i = $1149;$i5$019$i = 0;
        break;
       } else {
        $$in38$i = $1218;$i3$021$i = $1217;
       }
      }
      while(1) {
       $$in39$i = (($$0$i22) + ($$pn40$i<<2)|0);
       $1220 = HEAP32[$$in39$i>>2]|0;
       $1221 = (($1082) + ($1220<<2)|0);
       $1222 = HEAP32[$1221>>2]|0;
       $1223 = $1222 >>> 24;
       $$sum5$i = (($1223) + ($$sum2$i))|0;
       $1224 = (($$0$i22) + ($$sum5$i<<2)|0);
       $1225 = HEAP32[$1224>>2]|0;
       $1226 = (($1225) + 1)|0;
       HEAP32[$1224>>2] = $1226;
       $1227 = (($$0$i22) + ($1225<<2)|0);
       HEAP32[$1227>>2] = $1220;
       $1228 = (($i5$019$i) + 1)|0;
       $$sum4$i = (($1228) + ($1149))|0;
       $1229 = ($1228|0)==($1149|0);
       if ($1229) {
        break;
       } else {
        $$pn40$i = $$sum4$i;$i5$019$i = $1228;
       }
      }
     }
     $1230 = HEAP32[$68>>2]|0;
     $1231 = $1230 << 1;
     $1232 = (($1231) + 769)|0;
     $1233 = (($$0$i22) + ($1232<<2)|0);
     $1234 = HEAP32[$1233>>2]|0;
     $1235 = ($1230|0)==(0);
     if ($1235) {
      $$lcssa170 = 0;
     } else {
      $i1$0171 = 0;
      while(1) {
       $1236 = (($$0$i22) + ($i1$0171<<2)|0);
       $1237 = HEAP32[$1236>>2]|0;
       $1238 = (($1082) + ($1237<<2)|0);
       $1239 = HEAP32[$1238>>2]|0;
       $$sum3 = (($i1$0171) + ($1078))|0;
       $1240 = (($$0$i22) + ($$sum3<<2)|0);
       HEAP32[$1240>>2] = $1239;
       $1241 = (($i1$0171) + 1)|0;
       $1242 = HEAP32[$68>>2]|0;
       $1243 = ($1241>>>0)<($1242>>>0);
       if ($1243) {
        $i1$0171 = $1241;
       } else {
        $$lcssa170 = $1242;
        break;
       }
      }
     }
     $$sum2 = (($$lcssa170) + ($1078))|0;
     $1244 = (($$0$i22) + ($$sum2<<2)|0);
     HEAP32[$1244>>2] = -1;
     $1245 = Math_fround(HEAPF32[$62>>2]);
     $1246 = Math_fround($1042 * $1245);
     $1247 = Math_fround(HEAPF32[$63>>2]);
     $1248 = Math_fround($1044 * $1247);
     $1249 = Math_fround(HEAPF32[$64>>2]);
     $1250 = Math_fround($1046 * $1249);
     $1251 = Math_fround(HEAPF32[$65>>2]);
     $1252 = Math_fround($1048 * $1251);
     $floorf$i = (Math_fround(Math_floor((Math_fround($1246)))));
     $1253 = (~~(($floorf$i)));
     $floorf1$i = (Math_fround(Math_floor((Math_fround($1248)))));
     $1254 = (~~(($floorf1$i)));
     $floorf2$i = (Math_fround(Math_floor((Math_fround($1250)))));
     $1255 = (~~(($floorf2$i)));
     $floorf3$i = (Math_fround(Math_floor((Math_fround($1252)))));
     $1256 = (~~(($floorf3$i)));
     HEAP32[$data>>2] = $1253;
     HEAP32[$96>>2] = $1254;
     HEAP32[$97>>2] = $1255;
     HEAP32[$98>>2] = $1256;
     $1257 = (($data) + ($$0$i15<<2)|0);
     $1258 = HEAP32[$1257>>2]|0;
     $1259 = (($1258) + 2)|0;
     $1260 = HEAP32[$68>>2]|0;
     __ZN5physx5cloth16SwInterCollisionI8Scalar4fE16collideParticlesEPKjjS5_jj($this,$1077,$1234,$$0$i22,$1260,$1259);
     $1261 = HEAP32[$4>>2]|0;
     $1262 = ($$0$i22|0)==(0|0);
     if ($1262) {
      break;
     }
     $1263 = (($$0$i22) + -4|0);
     $1264 = HEAP32[$1263>>2]|0;
     $1265 = $1264 | -2147483648;
     HEAP32[$1263>>2] = $1265;
     $1266 = (($1261) + 12|0);
     $1267 = HEAP32[$1266>>2]|0;
     $1268 = ($1267|0)==(0|0);
     if ($1268) {
      break;
     }
     $1269 = (($1261) + 8|0);
     $1271 = $1267;
     while(1) {
      $1270 = (($1271) + 4|0);
      $1272 = HEAP32[$1270>>2]|0;
      $1273 = ($1272|0)<(0);
      if (!($1273)) {
       break L162;
      }
      HEAP32[$1269>>2] = $1271;
      $1274 = HEAP32[$1271>>2]|0;
      HEAP32[$1266>>2] = $1274;
      $1275 = ($1274|0)==(0|0);
      if ($1275) {
       break;
      } else {
       $1271 = $1274;
      }
     }
    }
   } while(0);
   $1276 = HEAP32[$68>>2]|0;
   $1277 = ($1276|0)==(0);
   if ($1277) {
    $$lcssa175 = $1607;$$lcssa176 = $1606;$$lcssa177 = $1605;$$lcssa178 = $1604;
   } else {
    $1278 = HEAP32[$22>>2]|0;
    $1279 = HEAP32[$61>>2]|0;
    $1280 = HEAP32[$39>>2]|0;
    $1654 = Math_fround(0.0);$1655 = $1604;$1656 = $1605;$1657 = $1606;$1658 = $1607;$i2$0179 = 0;$lastCloth$0180 = -1;
    while(1) {
     $1281 = (($1278) + ($i2$0179<<1)|0);
     $1282 = HEAP16[$1281>>1]|0;
     $1283 = $1282&65535;
     $1284 = ($1282<<16>>16)==($lastCloth$0180<<16>>16);
     if ($1284) {
      $$pre246 = Math_fround(HEAPF32[$69>>2]);
      $$pre247 = Math_fround(HEAPF32[$70>>2]);
      $$pre248 = Math_fround(HEAPF32[$71>>2]);
      $$pre249 = Math_fround(HEAPF32[$72>>2]);
      $$pre250 = Math_fround(HEAPF32[$73>>2]);
      $$pre251 = Math_fround(HEAPF32[$74>>2]);
      $$pre252 = Math_fround(HEAPF32[$75>>2]);
      $$pre253 = Math_fround(HEAPF32[$76>>2]);
      $$pre254 = Math_fround(HEAPF32[$77>>2]);
      $$pre255 = Math_fround(HEAPF32[$78>>2]);
      $$pre256 = Math_fround(HEAPF32[$79>>2]);
      $$pre257 = Math_fround(HEAPF32[$80>>2]);
      $$pre258 = Math_fround(HEAPF32[$81>>2]);
      $$pre259 = Math_fround(HEAPF32[$82>>2]);
      $$pre260 = Math_fround(HEAPF32[$83>>2]);
      $1387 = $1654;$1389 = $$pre246;$1391 = $$pre247;$1393 = $$pre248;$1395 = $$pre249;$1397 = $$pre250;$1399 = $$pre251;$1401 = $$pre252;$1405 = $$pre253;$1407 = $$pre254;$1409 = $$pre255;$1411 = $$pre256;$1419 = $$pre257;$1421 = $$pre258;$1423 = $$pre259;$1425 = $$pre260;$1461 = $1655;$1466 = $1656;$1471 = $1657;$1476 = $1658;$lastCloth$1 = $lastCloth$0180;
     } else {
      $1285 = ((($1279) + (($1283*76)|0)|0) + 32|0);
      $1286 = Math_fround(HEAPF32[$1285>>2]);
      $1287 = ((($1279) + (($1283*76)|0)|0) + 36|0);
      $1288 = Math_fround(HEAPF32[$1287>>2]);
      $1289 = ((($1279) + (($1283*76)|0)|0) + 40|0);
      $1290 = Math_fround(HEAPF32[$1289>>2]);
      $1291 = Math_fround($1286 * Math_fround(-2.0));
      $1292 = Math_fround($1288 * Math_fround(-2.0));
      $1293 = Math_fround($1290 * Math_fround(-2.0));
      $1294 = ((($1279) + (($1283*76)|0)|0) + 28|0);
      $1295 = Math_fround(HEAPF32[$1294>>2]);
      $1296 = Math_fround($1295 * $1295);
      $1297 = Math_fround($1296 + Math_fround(-0.5));
      $1298 = ((($1279) + (($1283*76)|0)|0) + 16|0);
      $1299 = Math_fround(HEAPF32[$1298>>2]);
      $1300 = Math_fround($1291 * $1299);
      $1301 = ((($1279) + (($1283*76)|0)|0) + 20|0);
      $1302 = Math_fround(HEAPF32[$1301>>2]);
      $1303 = Math_fround($1292 * $1302);
      $1304 = Math_fround($1300 + $1303);
      $1305 = ((($1279) + (($1283*76)|0)|0) + 24|0);
      $1306 = Math_fround(HEAPF32[$1305>>2]);
      $1307 = Math_fround($1293 * $1306);
      $1308 = Math_fround($1304 + $1307);
      $1309 = Math_fround($1291 * $1297);
      $1310 = Math_fround($1293 * $1302);
      $1311 = Math_fround($1292 * $1306);
      $1312 = Math_fround($1310 - $1311);
      $1313 = Math_fround($1295 * $1312);
      $1314 = Math_fround($1309 - $1313);
      $1315 = Math_fround($1299 * $1308);
      $1316 = Math_fround($1315 + $1314);
      $1317 = Math_fround($1292 * $1297);
      $1318 = Math_fround($1291 * $1306);
      $1319 = Math_fround($1293 * $1299);
      $1320 = Math_fround($1318 - $1319);
      $1321 = Math_fround($1295 * $1320);
      $1322 = Math_fround($1317 - $1321);
      $1323 = Math_fround($1302 * $1308);
      $1324 = Math_fround($1323 + $1322);
      $1325 = Math_fround($1293 * $1297);
      $1326 = Math_fround($1292 * $1299);
      $1327 = Math_fround($1291 * $1302);
      $1328 = Math_fround($1326 - $1327);
      $1329 = Math_fround($1295 * $1328);
      $1330 = Math_fround($1325 - $1329);
      $1331 = Math_fround($1306 * $1308);
      $1332 = Math_fround($1330 + $1331);
      $1333 = Math_fround(-$1299);
      $1334 = Math_fround(-$1302);
      $1335 = Math_fround(-$1306);
      $1336 = Math_fround($1333 - $1299);
      $1337 = Math_fround($1334 - $1302);
      $1338 = Math_fround($1335 - $1306);
      $1339 = Math_fround($1336 * $1333);
      $1340 = Math_fround($1337 * $1334);
      $1341 = Math_fround($1338 * $1335);
      $1342 = Math_fround($1336 * $1334);
      $1343 = Math_fround($1336 * $1335);
      $1344 = Math_fround($1295 * $1336);
      $1345 = Math_fround($1337 * $1335);
      $1346 = Math_fround($1295 * $1337);
      $1347 = Math_fround($1295 * $1338);
      $1348 = Math_fround(Math_fround(1.0) - $1340);
      $1349 = Math_fround($1348 - $1341);
      $1350 = Math_fround($1342 + $1347);
      $1351 = Math_fround($1343 - $1346);
      $1352 = Math_fround($1342 - $1347);
      $1353 = Math_fround(Math_fround(1.0) - $1339);
      $1354 = Math_fround($1353 - $1341);
      $1355 = Math_fround($1344 + $1345);
      $1356 = Math_fround($1343 + $1346);
      $1357 = Math_fround($1345 - $1344);
      $1358 = Math_fround($1353 - $1340);
      $1359 = (HEAPF32[tempDoublePtr>>2]=$1349,HEAP32[tempDoublePtr>>2]|0);
      $1360 = (HEAPF32[tempDoublePtr>>2]=$1350,HEAP32[tempDoublePtr>>2]|0);
      $1361 = (HEAPF32[tempDoublePtr>>2]=$1351,HEAP32[tempDoublePtr>>2]|0);
      HEAP32[$lcBounds$i>>2] = $1359;
      HEAP32[$69>>2] = $1360;
      HEAP32[$70>>2] = $1361;
      HEAP32[$71>>2] = 0;
      $1362 = (HEAPF32[tempDoublePtr>>2]=$1352,HEAP32[tempDoublePtr>>2]|0);
      $1363 = (HEAPF32[tempDoublePtr>>2]=$1354,HEAP32[tempDoublePtr>>2]|0);
      $1364 = (HEAPF32[tempDoublePtr>>2]=$1355,HEAP32[tempDoublePtr>>2]|0);
      HEAP32[$84>>2] = $1362;
      HEAP32[$77>>2] = $1363;
      HEAP32[$78>>2] = $1364;
      HEAP32[$79>>2] = 0;
      $1365 = (HEAPF32[tempDoublePtr>>2]=$1356,HEAP32[tempDoublePtr>>2]|0);
      $1366 = (HEAPF32[tempDoublePtr>>2]=$1357,HEAP32[tempDoublePtr>>2]|0);
      $1367 = (HEAPF32[tempDoublePtr>>2]=$1358,HEAP32[tempDoublePtr>>2]|0);
      HEAP32[$85>>2] = $1365;
      HEAP32[$81>>2] = $1366;
      HEAP32[$82>>2] = $1367;
      HEAP32[$83>>2] = 0;
      $1368 = (HEAPF32[tempDoublePtr>>2]=$1316,HEAP32[tempDoublePtr>>2]|0);
      $1369 = (HEAPF32[tempDoublePtr>>2]=$1324,HEAP32[tempDoublePtr>>2]|0);
      $1370 = (HEAPF32[tempDoublePtr>>2]=$1332,HEAP32[tempDoublePtr>>2]|0);
      HEAP32[$86>>2] = $1368;
      HEAP32[$73>>2] = $1369;
      HEAP32[$74>>2] = $1370;
      HEAP32[$75>>2] = 1065353216;
      $1371 = ((($1279) + (($1283*76)|0)|0) + 68|0);
      $1372 = Math_fround(HEAPF32[$1371>>2]);
      $1373 = (HEAPF32[tempDoublePtr>>2]=$1372,HEAP32[tempDoublePtr>>2]|0);
      $1374 = HEAP32[$22>>2]|0;
      $1375 = (($1374) + ($i2$0179<<1)|0);
      $1376 = HEAP16[$1375>>1]|0;
      $1387 = $1349;$1389 = $1350;$1391 = $1351;$1393 = Math_fround(0.0);$1395 = $1316;$1397 = $1324;$1399 = $1332;$1401 = Math_fround(1.0);$1405 = $1352;$1407 = $1354;$1409 = $1355;$1411 = Math_fround(0.0);$1419 = $1356;$1421 = $1357;$1423 = $1358;$1425 = Math_fround(0.0);$1461 = $1373;$1466 = $1373;$1471 = $1373;$1476 = $1373;$lastCloth$1 = $1376;
     }
     $1377 = (($1280) + ($i2$0179<<2)|0);
     $1378 = HEAP32[$1377>>2]|0;
     $1379 = (($1279) + (($1283*76)|0)|0);
     $1380 = HEAP32[$1379>>2]|0;
     $1381 = (($1380) + ($1378<<4)|0);
     $1382 = ((($1279) + (($1283*76)|0)|0) + 4|0);
     $1383 = HEAP32[$1382>>2]|0;
     $1384 = (($1383) + ($1378<<4)|0);
     $1385 = Math_fround(HEAPF32[$1381>>2]);
     $1386 = Math_fround($1385 * $1387);
     $1388 = Math_fround($1385 * $1389);
     $1390 = Math_fround($1385 * $1391);
     $1392 = Math_fround($1385 * $1393);
     $1394 = Math_fround($1386 + $1395);
     $1396 = Math_fround($1388 + $1397);
     $1398 = Math_fround($1390 + $1399);
     $1400 = Math_fround($1392 + $1401);
     $1402 = ((($1380) + ($1378<<4)|0) + 4|0);
     $1403 = Math_fround(HEAPF32[$1402>>2]);
     $1404 = Math_fround($1403 * $1405);
     $1406 = Math_fround($1403 * $1407);
     $1408 = Math_fround($1403 * $1409);
     $1410 = Math_fround($1403 * $1411);
     $1412 = Math_fround($1394 + $1404);
     $1413 = Math_fround($1396 + $1406);
     $1414 = Math_fround($1398 + $1408);
     $1415 = Math_fround($1400 + $1410);
     $1416 = ((($1380) + ($1378<<4)|0) + 8|0);
     $1417 = Math_fround(HEAPF32[$1416>>2]);
     $1418 = Math_fround($1417 * $1419);
     $1420 = Math_fround($1417 * $1421);
     $1422 = Math_fround($1417 * $1423);
     $1424 = Math_fround($1417 * $1425);
     $1426 = Math_fround($1412 + $1418);
     $1427 = Math_fround($1413 + $1420);
     $1428 = Math_fround($1414 + $1422);
     $1429 = Math_fround($1415 + $1424);
     $1430 = (HEAPF32[tempDoublePtr>>2]=$1426,HEAP32[tempDoublePtr>>2]|0);
     $1431 = (HEAPF32[tempDoublePtr>>2]=$1427,HEAP32[tempDoublePtr>>2]|0);
     $1432 = (HEAPF32[tempDoublePtr>>2]=$1428,HEAP32[tempDoublePtr>>2]|0);
     $1433 = (HEAPF32[tempDoublePtr>>2]=$1429,HEAP32[tempDoublePtr>>2]|0);
     $1434 = HEAP32[479712>>2]|0;
     $1435 = HEAP32[((479712 + 4|0))>>2]|0;
     $1436 = HEAP32[((479712 + 8|0))>>2]|0;
     $1437 = HEAP32[((479712 + 12|0))>>2]|0;
     $1438 = (HEAPF32[tempDoublePtr>>2]=$1385,HEAP32[tempDoublePtr>>2]|0);
     $1439 = $1430 ^ $1438;
     $1440 = (HEAPF32[tempDoublePtr>>2]=$1403,HEAP32[tempDoublePtr>>2]|0);
     $1441 = $1431 ^ $1440;
     $1442 = (HEAPF32[tempDoublePtr>>2]=$1417,HEAP32[tempDoublePtr>>2]|0);
     $1443 = $1432 ^ $1442;
     $1444 = ((($1380) + ($1378<<4)|0) + 12|0);
     $1445 = HEAP32[$1444>>2]|0;
     $1446 = $1445 ^ $1433;
     $1447 = $1439 & $1434;
     $1448 = $1441 & $1435;
     $1449 = $1443 & $1436;
     $1450 = $1446 & $1437;
     $1451 = $1447 ^ $1438;
     $1452 = $1448 ^ $1440;
     $1453 = $1449 ^ $1442;
     $1454 = $1450 ^ $1445;
     HEAP32[$1381>>2] = $1451;
     HEAP32[$1402>>2] = $1452;
     HEAP32[$1416>>2] = $1453;
     HEAP32[$1444>>2] = $1454;
     $1455 = HEAP32[479760>>2]|0;
     $1456 = HEAP32[((479760 + 4|0))>>2]|0;
     $1457 = HEAP32[((479760 + 8|0))>>2]|0;
     $1458 = HEAP32[((479760 + 12|0))>>2]|0;
     $1459 = Math_fround(HEAPF32[$1384>>2]);
     $1460 = (HEAP32[tempDoublePtr>>2]=$1461,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1462 = Math_fround($1460 * $1459);
     $1463 = ((($1383) + ($1378<<4)|0) + 4|0);
     $1464 = Math_fround(HEAPF32[$1463>>2]);
     $1465 = (HEAP32[tempDoublePtr>>2]=$1466,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1467 = Math_fround($1465 * $1464);
     $1468 = ((($1383) + ($1378<<4)|0) + 8|0);
     $1469 = Math_fround(HEAPF32[$1468>>2]);
     $1470 = (HEAP32[tempDoublePtr>>2]=$1471,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1472 = Math_fround($1470 * $1469);
     $1473 = ((($1383) + ($1378<<4)|0) + 12|0);
     $1474 = Math_fround(HEAPF32[$1473>>2]);
     $1475 = (HEAP32[tempDoublePtr>>2]=$1476,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1477 = Math_fround($1475 * $1474);
     $1478 = (HEAPF32[tempDoublePtr>>2]=$1477,HEAP32[tempDoublePtr>>2]|0);
     $1479 = Math_fround(HEAPF32[$lcBounds$i>>2]);
     $1480 = Math_fround($1462 * $1479);
     $1481 = Math_fround($1462 * $1389);
     $1482 = Math_fround($1462 * $1391);
     $1483 = Math_fround($1462 * $1393);
     $1484 = Math_fround($1467 * $1405);
     $1485 = Math_fround($1467 * $1407);
     $1486 = Math_fround($1467 * $1409);
     $1487 = Math_fround($1467 * $1411);
     $1488 = Math_fround($1480 + $1484);
     $1489 = Math_fround($1481 + $1485);
     $1490 = Math_fround($1482 + $1486);
     $1491 = Math_fround($1483 + $1487);
     $1492 = Math_fround($1472 * $1419);
     $1493 = Math_fround($1472 * $1421);
     $1494 = Math_fround($1472 * $1423);
     $1495 = Math_fround($1472 * $1425);
     $1496 = Math_fround($1488 + $1492);
     $1497 = Math_fround($1489 + $1493);
     $1498 = Math_fround($1490 + $1494);
     $1499 = Math_fround($1491 + $1495);
     $1500 = (HEAPF32[tempDoublePtr>>2]=$1496,HEAP32[tempDoublePtr>>2]|0);
     $1501 = (HEAPF32[tempDoublePtr>>2]=$1497,HEAP32[tempDoublePtr>>2]|0);
     $1502 = (HEAPF32[tempDoublePtr>>2]=$1498,HEAP32[tempDoublePtr>>2]|0);
     $1503 = (HEAPF32[tempDoublePtr>>2]=$1499,HEAP32[tempDoublePtr>>2]|0);
     $1504 = HEAP32[479712>>2]|0;
     $1505 = HEAP32[((479712 + 4|0))>>2]|0;
     $1506 = HEAP32[((479712 + 8|0))>>2]|0;
     $1507 = HEAP32[((479712 + 12|0))>>2]|0;
     $1508 = (HEAPF32[tempDoublePtr>>2]=$1462,HEAP32[tempDoublePtr>>2]|0);
     $1509 = $1500 ^ $1508;
     $1510 = (HEAPF32[tempDoublePtr>>2]=$1467,HEAP32[tempDoublePtr>>2]|0);
     $1511 = $1501 ^ $1510;
     $1512 = (HEAPF32[tempDoublePtr>>2]=$1472,HEAP32[tempDoublePtr>>2]|0);
     $1513 = $1502 ^ $1512;
     $1514 = $1503 ^ $1478;
     $1515 = $1509 & $1504;
     $1516 = $1511 & $1505;
     $1517 = $1513 & $1506;
     $1518 = $1514 & $1507;
     $1519 = $1515 ^ $1508;
     $1520 = $1516 ^ $1510;
     $1521 = $1517 ^ $1512;
     $1522 = $1518 ^ $1478;
     $1523 = (HEAP32[tempDoublePtr>>2]=$1451,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1524 = (HEAP32[tempDoublePtr>>2]=$1519,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1525 = Math_fround($1523 - $1524);
     $1526 = (HEAP32[tempDoublePtr>>2]=$1452,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1527 = (HEAP32[tempDoublePtr>>2]=$1520,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1528 = Math_fround($1526 - $1527);
     $1529 = (HEAP32[tempDoublePtr>>2]=$1453,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1530 = (HEAP32[tempDoublePtr>>2]=$1521,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1531 = Math_fround($1529 - $1530);
     $1532 = (HEAP32[tempDoublePtr>>2]=$1454,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1533 = (HEAP32[tempDoublePtr>>2]=$1522,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1534 = Math_fround($1532 - $1533);
     $1535 = (HEAP32[tempDoublePtr>>2]=$1455,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1536 = $1535 < $1525;
     $1537 = $1536 ? $1525 : $1535;
     $1538 = (HEAP32[tempDoublePtr>>2]=$1456,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1539 = $1538 < $1528;
     $1540 = $1539 ? $1528 : $1538;
     $1541 = (HEAP32[tempDoublePtr>>2]=$1457,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1542 = $1541 < $1531;
     $1543 = $1542 ? $1531 : $1541;
     $1544 = (HEAP32[tempDoublePtr>>2]=$1458,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $1545 = $1544 < $1534;
     $1546 = $1545 ? $1534 : $1544;
     $1547 = (HEAPF32[tempDoublePtr>>2]=$1537,HEAP32[tempDoublePtr>>2]|0);
     $1548 = (HEAPF32[tempDoublePtr>>2]=$1540,HEAP32[tempDoublePtr>>2]|0);
     $1549 = (HEAPF32[tempDoublePtr>>2]=$1543,HEAP32[tempDoublePtr>>2]|0);
     $1550 = (HEAPF32[tempDoublePtr>>2]=$1546,HEAP32[tempDoublePtr>>2]|0);
     HEAP32[$1384>>2] = $1547;
     HEAP32[$1463>>2] = $1548;
     HEAP32[$1468>>2] = $1549;
     HEAP32[$1473>>2] = $1550;
     $1551 = (($i2$0179) + 1)|0;
     $1552 = HEAP32[$68>>2]|0;
     $1553 = ($1551>>>0)<($1552>>>0);
     if ($1553) {
      $1654 = $1479;$1655 = $1461;$1656 = $1466;$1657 = $1471;$1658 = $1476;$i2$0179 = $1551;$lastCloth$0180 = $lastCloth$1;
     } else {
      $$lcssa175 = $1476;$$lcssa176 = $1471;$$lcssa177 = $1466;$$lcssa178 = $1461;
      break;
     }
    }
   }
   $1554 = HEAP32[$58>>2]|0;
   $1555 = ($k$0187>>>0)<($1554>>>0);
   if (!($1555)) {
    break;
   }
   $phitmp261 = (($k$0187) + 1)|0;
   $1604 = $$lcssa178;$1605 = $$lcssa177;$1606 = $$lcssa176;$1607 = $$lcssa175;$k$0187 = $phitmp261;
  }
  $$pre240 = HEAP32[$57>>2]|0;
  $1558 = $$pre240;
 }
 $1556 = HEAP32[$4>>2]|0;
 $1557 = ($1558|0)==(0|0);
 L214: do {
  if (!($1557)) {
   $1559 = (($1558) + -4|0);
   $1560 = HEAP32[$1559>>2]|0;
   $1561 = $1560 | -2147483648;
   HEAP32[$1559>>2] = $1561;
   $1562 = (($1556) + 12|0);
   $1563 = HEAP32[$1562>>2]|0;
   $1564 = ($1563|0)==(0|0);
   if (!($1564)) {
    $1565 = (($1556) + 8|0);
    $1567 = $1563;
    while(1) {
     $1566 = (($1567) + 4|0);
     $1568 = HEAP32[$1566>>2]|0;
     $1569 = ($1568|0)<(0);
     if (!($1569)) {
      break L214;
     }
     HEAP32[$1565>>2] = $1567;
     $1570 = HEAP32[$1567>>2]|0;
     HEAP32[$1562>>2] = $1570;
     $1571 = ($1570|0)==(0|0);
     if ($1571) {
      break;
     } else {
      $1567 = $1570;
     }
    }
   }
  }
 } while(0);
 $1572 = HEAP32[$4>>2]|0;
 $1573 = HEAP32[$39>>2]|0;
 $1574 = ($1573|0)==(0|0);
 L221: do {
  if (!($1574)) {
   $1575 = (($1573) + -4|0);
   $1576 = HEAP32[$1575>>2]|0;
   $1577 = $1576 | -2147483648;
   HEAP32[$1575>>2] = $1577;
   $1578 = (($1572) + 12|0);
   $1579 = HEAP32[$1578>>2]|0;
   $1580 = ($1579|0)==(0|0);
   if (!($1580)) {
    $1581 = (($1572) + 8|0);
    $1583 = $1579;
    while(1) {
     $1582 = (($1583) + 4|0);
     $1584 = HEAP32[$1582>>2]|0;
     $1585 = ($1584|0)<(0);
     if (!($1585)) {
      break L221;
     }
     HEAP32[$1581>>2] = $1583;
     $1586 = HEAP32[$1583>>2]|0;
     HEAP32[$1578>>2] = $1586;
     $1587 = ($1586|0)==(0|0);
     if ($1587) {
      break;
     } else {
      $1583 = $1586;
     }
    }
   }
  }
 } while(0);
 $1588 = HEAP32[$4>>2]|0;
 $1589 = HEAP32[$22>>2]|0;
 $1590 = ($1589|0)==(0|0);
 if ($1590) {
  STACKTOP = sp;return;
 }
 $1591 = (($1589) + -4|0);
 $1592 = HEAP32[$1591>>2]|0;
 $1593 = $1592 | -2147483648;
 HEAP32[$1591>>2] = $1593;
 $1594 = (($1588) + 12|0);
 $1595 = HEAP32[$1594>>2]|0;
 $1596 = ($1595|0)==(0|0);
 if ($1596) {
  STACKTOP = sp;return;
 }
 $1597 = (($1588) + 8|0);
 $1599 = $1595;
 while(1) {
  $1598 = (($1599) + 4|0);
  $1600 = HEAP32[$1598>>2]|0;
  $1601 = ($1600|0)<(0);
  if (!($1601)) {
   label = 161;
   break;
  }
  HEAP32[$1597>>2] = $1599;
  $1602 = HEAP32[$1599>>2]|0;
  HEAP32[$1594>>2] = $1602;
  $1603 = ($1602|0)==(0|0);
  if ($1603) {
   label = 161;
   break;
  } else {
   $1599 = $1602;
  }
 }
 if ((label|0) == 161) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx5cloth16SwInterCollisionI8Scalar4fE16collideParticlesEPKjjS5_jj($this,$keys,$firstColumnSize,$indices,$numParticles,$collisionDistance) {
 $this = $this|0;
 $keys = $keys|0;
 $firstColumnSize = $firstColumnSize|0;
 $indices = $indices|0;
 $numParticles = $numParticles|0;
 $collisionDistance = $collisionDistance|0;
 var $$lcssa = 0, $$lcssa12 = 0, $$pre = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $iIt$023 = 0, $jIt$03 = 0, $jIt$118 = 0;
 var $k5$022 = 0, $kFirst = 0, $kIt$0 = 0, $kIt$2 = 0, $kIt$2$1 = 0, $kIt$2$2 = 0, $kIt$2$3 = 0, $kIt$3 = 0, $kIt$3$1 = 0, $kIt$3$2 = 0, $kIt$3$3 = 0, $kLast = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $kFirst = sp + 20|0;
 $kLast = sp;
 $0 = HEAP32[$keys>>2]|0;
 $1 = $0 & 65535;
 $2 = ($1>>>0)>($collisionDistance>>>0);
 $3 = $2 ? $collisionDistance : $1;
 $4 = (($0) + ($collisionDistance))|0;
 $5 = $0 | 65535;
 $6 = ($4>>>0)<($5>>>0);
 $7 = $6 ? $4 : $5;
 HEAP32[$kFirst>>2] = $keys;
 $9 = $0;$kIt$0 = $keys;
 while(1) {
  $8 = ($9>>>0)<($7>>>0);
  $10 = (($kIt$0) + 4|0);
  if (!($8)) {
   break;
  }
  $$pre = HEAP32[$10>>2]|0;
  $9 = $$pre;$kIt$0 = $10;
 }
 $11 = (($0) - ($3))|0;
 HEAP32[$kLast>>2] = $kIt$0;
 $12 = (($11) + 65536)|0;
 $14 = $9;$kIt$2 = $kIt$0;
 while(1) {
  $13 = ($14>>>0)<($12>>>0);
  $15 = (($kIt$2) + 4|0);
  if (!($13)) {
   break;
  }
  $$pre45 = HEAP32[$15>>2]|0;
  $14 = $$pre45;$kIt$2 = $15;
 }
 $16 = (($kFirst) + 4|0);
 HEAP32[$16>>2] = $kIt$2;
 $17 = (($7) + 65536)|0;
 $19 = $14;$kIt$3 = $kIt$2;
 while(1) {
  $18 = ($19>>>0)<($17>>>0);
  $20 = (($kIt$3) + 4|0);
  if (!($18)) {
   break;
  }
  $$pre46 = HEAP32[$20>>2]|0;
  $19 = $$pre46;$kIt$3 = $20;
 }
 $21 = (($kLast) + 4|0);
 HEAP32[$21>>2] = $kIt$3;
 $22 = (($keys) + ($firstColumnSize<<2)|0);
 $23 = (($11) + 16711680)|0;
 $kIt$2$1 = $22;
 while(1) {
  $155 = HEAP32[$kIt$2$1>>2]|0;
  $156 = ($155>>>0)<($23>>>0);
  $157 = (($kIt$2$1) + 4|0);
  if ($156) {
   $kIt$2$1 = $157;
  } else {
   break;
  }
 }
 $158 = (($kFirst) + 8|0);
 HEAP32[$158>>2] = $kIt$2$1;
 $159 = (($7) + 16711680)|0;
 $161 = $155;$kIt$3$1 = $kIt$2$1;
 while(1) {
  $160 = ($161>>>0)<($159>>>0);
  $162 = (($kIt$3$1) + 4|0);
  if (!($160)) {
   break;
  }
  $$pre47 = HEAP32[$162>>2]|0;
  $161 = $$pre47;$kIt$3$1 = $162;
 }
 $163 = (($kLast) + 8|0);
 HEAP32[$163>>2] = $kIt$3$1;
 $164 = (($11) + 16777216)|0;
 $166 = $0;$kIt$2$2 = $keys;
 while(1) {
  $165 = ($166>>>0)<($164>>>0);
  $167 = (($kIt$2$2) + 4|0);
  if (!($165)) {
   break;
  }
  $$pre48 = HEAP32[$167>>2]|0;
  $166 = $$pre48;$kIt$2$2 = $167;
 }
 $168 = (($kFirst) + 12|0);
 HEAP32[$168>>2] = $kIt$2$2;
 $169 = (($7) + 16777216)|0;
 $171 = $166;$kIt$3$2 = $kIt$2$2;
 while(1) {
  $170 = ($171>>>0)<($169>>>0);
  $172 = (($kIt$3$2) + 4|0);
  if (!($170)) {
   break;
  }
  $$pre49 = HEAP32[$172>>2]|0;
  $171 = $$pre49;$kIt$3$2 = $172;
 }
 $173 = (($kLast) + 12|0);
 HEAP32[$173>>2] = $kIt$3$2;
 $174 = (($11) + 16842752)|0;
 $176 = $0;$kIt$2$3 = $keys;
 while(1) {
  $175 = ($176>>>0)<($174>>>0);
  $177 = (($kIt$2$3) + 4|0);
  if (!($175)) {
   break;
  }
  $$pre50 = HEAP32[$177>>2]|0;
  $176 = $$pre50;$kIt$2$3 = $177;
 }
 $178 = (($kFirst) + 16|0);
 HEAP32[$178>>2] = $kIt$2$3;
 $179 = (($7) + 16842752)|0;
 $181 = $176;$kIt$3$3 = $kIt$2$3;
 while(1) {
  $180 = ($181>>>0)<($179>>>0);
  $182 = (($kIt$3$3) + 4|0);
  if (!($180)) {
   break;
  }
  $$pre51 = HEAP32[$182>>2]|0;
  $181 = $$pre51;$kIt$3$3 = $182;
 }
 $183 = (($kLast) + 16|0);
 HEAP32[$183>>2] = $kIt$3$3;
 $154 = (($indices) + ($numParticles<<2)|0);
 $184 = ($numParticles|0)==(0);
 if ($184) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 104|0);
 $25 = (($this) + 80|0);
 $26 = (($this) + 116|0);
 $27 = (($this) + 84|0);
 $28 = (($this) + 96|0);
 $29 = (($this) + 108|0);
 $30 = (($this) + 88|0);
 $31 = (($this) + 4|0);
 $32 = (($this) + 8|0);
 $33 = (($this) + 12|0);
 $34 = (($this) + 16|0);
 $35 = (($this) + 20|0);
 $36 = (($this) + 24|0);
 $37 = (($this) + 28|0);
 $38 = $keys;
 $72 = $keys;$82 = $kIt$0;$iIt$023 = $indices;
 while(1) {
  $39 = HEAP32[$iIt$023>>2]|0;
  $40 = HEAP32[$24>>2]|0;
  $41 = (($40) + ($39<<1)|0);
  $42 = HEAP16[$41>>1]|0;
  HEAP16[$25>>1] = $42;
  $43 = $42&65535;
  $44 = HEAP32[$26>>2]|0;
  $45 = (($44) + ($43<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$27>>2] = $46;
  $47 = HEAP32[$28>>2]|0;
  $48 = HEAP32[$29>>2]|0;
  $49 = (($48) + ($39<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  HEAP32[$30>>2] = $50;
  $51 = (($47) + (($43*76)|0)|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + ($50<<4)|0);
  $54 = HEAP32[$53>>2]|0;
  HEAP32[$this>>2] = $54;
  $55 = ((($52) + ($50<<4)|0) + 4|0);
  $56 = HEAP32[$55>>2]|0;
  HEAP32[$31>>2] = $56;
  $57 = ((($52) + ($50<<4)|0) + 8|0);
  $58 = HEAP32[$57>>2]|0;
  HEAP32[$32>>2] = $58;
  $59 = ((($52) + ($50<<4)|0) + 12|0);
  $60 = HEAP32[$59>>2]|0;
  HEAP32[$33>>2] = $60;
  $61 = ((($47) + (($43*76)|0)|0) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + ($50<<4)|0);
  $64 = HEAP32[$63>>2]|0;
  HEAP32[$34>>2] = $64;
  $65 = ((($62) + ($50<<4)|0) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  HEAP32[$35>>2] = $66;
  $67 = ((($62) + ($50<<4)|0) + 8|0);
  $68 = HEAP32[$67>>2]|0;
  HEAP32[$36>>2] = $68;
  $69 = ((($62) + ($50<<4)|0) + 12|0);
  $70 = HEAP32[$69>>2]|0;
  HEAP32[$37>>2] = $70;
  $71 = HEAP32[$72>>2]|0;
  $73 = $71 & 65535;
  $74 = ($73>>>0)>($collisionDistance>>>0);
  $75 = $74 ? $collisionDistance : $73;
  $76 = (($71) - ($75))|0;
  $77 = (($71) + ($collisionDistance))|0;
  $78 = $71 | 65535;
  $79 = ($77>>>0)<($78>>>0);
  $80 = $79 ? $77 : $78;
  $81 = HEAP32[$82>>2]|0;
  $83 = ($81>>>0)<($80>>>0);
  if ($83) {
   $85 = $82;
   while(1) {
    $84 = (($85) + 4|0);
    $86 = HEAP32[$84>>2]|0;
    $87 = ($86>>>0)<($80>>>0);
    if ($87) {
     $85 = $84;
    } else {
     break;
    }
   }
   HEAP32[$kLast>>2] = $84;
   $$lcssa = $84;
  } else {
   $$lcssa = $82;
  }
  $88 = $$lcssa;
  $89 = (($88) - ($38))|0;
  $90 = $89 >> 2;
  $91 = (($indices) + ($90<<2)|0);
  $92 = (($iIt$023) + 4|0);
  $93 = ($92|0)==($91|0);
  if ($93) {
   $k5$022 = 1;
  } else {
   $jIt$03 = $92;
   while(1) {
    $94 = HEAP32[$jIt$03>>2]|0;
    __ZN5physx5cloth16SwInterCollisionI8Scalar4fE15collideParticleEj($this,$94);
    $95 = (($jIt$03) + 4|0);
    $96 = ($95|0)==($91|0);
    if ($96) {
     $k5$022 = 1;
     break;
    } else {
     $jIt$03 = $95;
    }
   }
  }
  while(1) {
   $97 = (479776 + ($k5$022<<2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($76) + ($98))|0;
   $100 = (($kFirst) + ($k5$022<<2)|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = HEAP32[$101>>2]|0;
   $103 = ($102>>>0)<($99>>>0);
   if ($103) {
    $105 = $101;
    while(1) {
     $104 = (($105) + 4|0);
     $106 = HEAP32[$104>>2]|0;
     $107 = ($106>>>0)<($99>>>0);
     if ($107) {
      $105 = $104;
     } else {
      break;
     }
    }
    HEAP32[$100>>2] = $104;
    $122 = $104;
   } else {
    $122 = $101;
   }
   $108 = (($98) + ($80))|0;
   $109 = (($kLast) + ($k5$022<<2)|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = HEAP32[$110>>2]|0;
   $112 = ($111>>>0)<($108>>>0);
   if ($112) {
    $114 = $110;
    while(1) {
     $113 = (($114) + 4|0);
     $115 = HEAP32[$113>>2]|0;
     $116 = ($115>>>0)<($108>>>0);
     if ($116) {
      $114 = $113;
     } else {
      break;
     }
    }
    HEAP32[$109>>2] = $113;
    $$lcssa12 = $113;
   } else {
    $$lcssa12 = $110;
   }
   $117 = $$lcssa12;
   $118 = (($117) - ($38))|0;
   $119 = $118 >> 2;
   $120 = (($indices) + ($119<<2)|0);
   $121 = $122;
   $123 = (($121) - ($38))|0;
   $124 = $123 >> 2;
   $125 = ($124|0)==($119|0);
   if (!($125)) {
    $126 = (($indices) + ($124<<2)|0);
    $jIt$118 = $126;
    while(1) {
     $127 = HEAP32[$jIt$118>>2]|0;
     __ZN5physx5cloth16SwInterCollisionI8Scalar4fE15collideParticleEj($this,$127);
     $128 = (($jIt$118) + 4|0);
     $129 = ($128|0)==($120|0);
     if ($129) {
      break;
     } else {
      $jIt$118 = $128;
     }
    }
   }
   $130 = (($k5$022) + 1)|0;
   $exitcond = ($130|0)==(5);
   if ($exitcond) {
    break;
   } else {
    $k5$022 = $130;
   }
  }
  $131 = HEAP32[$30>>2]|0;
  $132 = HEAP32[$51>>2]|0;
  $133 = (($132) + ($131<<4)|0);
  $134 = HEAP32[$this>>2]|0;
  HEAP32[$133>>2] = $134;
  $135 = HEAP32[$31>>2]|0;
  $136 = ((($132) + ($131<<4)|0) + 4|0);
  HEAP32[$136>>2] = $135;
  $137 = HEAP32[$32>>2]|0;
  $138 = ((($132) + ($131<<4)|0) + 8|0);
  HEAP32[$138>>2] = $137;
  $139 = HEAP32[$33>>2]|0;
  $140 = ((($132) + ($131<<4)|0) + 12|0);
  HEAP32[$140>>2] = $139;
  $141 = HEAP32[$30>>2]|0;
  $142 = HEAP32[$61>>2]|0;
  $143 = (($142) + ($141<<4)|0);
  $144 = HEAP32[$34>>2]|0;
  HEAP32[$143>>2] = $144;
  $145 = HEAP32[$35>>2]|0;
  $146 = ((($142) + ($141<<4)|0) + 4|0);
  HEAP32[$146>>2] = $145;
  $147 = HEAP32[$36>>2]|0;
  $148 = ((($142) + ($141<<4)|0) + 8|0);
  HEAP32[$148>>2] = $147;
  $149 = HEAP32[$37>>2]|0;
  $150 = ((($142) + ($141<<4)|0) + 12|0);
  HEAP32[$150>>2] = $149;
  $151 = HEAP32[$kFirst>>2]|0;
  $152 = (($151) + 4|0);
  HEAP32[$kFirst>>2] = $152;
  $153 = ($92|0)==($154|0);
  if ($153) {
   break;
  }
  $$pre52 = HEAP32[$kLast>>2]|0;
  $72 = $152;$82 = $$pre52;$iIt$023 = $92;
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth16SwInterCollisionI8Scalar4fE23estimateTemporaryMemoryEPNS0_20SwInterCollisionDataEj($cloths,$n) {
 $cloths = $cloths|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $factor = 0, $i$02 = 0, $numParticles$0$lcssa = 0, $numParticles$03 = 0, $tmp1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $numParticles$0$lcssa = 0;
 } else {
  $i$02 = 0;$numParticles$03 = 0;
  while(1) {
   $1 = ((($cloths) + (($i$02*76)|0)|0) + 8|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = (($2) + ($numParticles$03))|0;
   $4 = (($i$02) + 1)|0;
   $exitcond = ($4|0)==($n|0);
   if ($exitcond) {
    $numParticles$0$lcssa = $3;
    break;
   } else {
    $i$02 = $4;$numParticles$03 = $3;
   }
  }
 }
 $5 = $n << 6;
 $6 = $numParticles$0$lcssa << 2;
 $7 = (($6) + 4096)|0;
 $8 = ($7>>>0)<($6>>>0);
 $9 = $8 ? $6 : $7;
 $factor = $n << 3;
 $tmp1 = ($numParticles$0$lcssa*10)|0;
 $10 = (($6) + ($5))|0;
 $11 = (($10) + ($9))|0;
 $12 = (($11) + ($factor))|0;
 $13 = (($12) + ($tmp1))|0;
 STACKTOP = sp;return ($13|0);
}
function __ZN5physx5cloth16SwInterCollisionI8Scalar4fE15collideParticleEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $187 = 0, $19 = Math_fround(0);
 var $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0;
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index<<1)|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = 1 << $4;
 $6 = (($this) + 84|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5 & $7;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 96|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 108|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($index<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($11) + (($4*76)|0)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($15<<4)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$this>>2]);
 $21 = Math_fround($19 - $20);
 $22 = ((($17) + ($15<<4)|0) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 - $25);
 $27 = ((($17) + ($15<<4)|0) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 - $30);
 $32 = ((($17) + ($15<<4)|0) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 - $35);
 $37 = Math_fround($21 * $21);
 $38 = Math_fround($26 * $26);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($31 * $31);
 $41 = Math_fround($39 + $40);
 $42 = (($this) + 48|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = $41 > $43;
 if ($44) {
  $45 = (($this) + 52|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = $41 > $46;
  if ($47) {
   $48 = (($this) + 56|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = $41 > $49;
   if ($50) {
    $51 = (($this) + 60|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = $41 > $52;
    if ($53) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $54 = (Math_fround(Math_sqrt((Math_fround($41)))));
 $55 = Math_fround(Math_fround(1.0) / $54);
 $56 = (($this) + 32|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($55 * $57);
 $59 = (($this) + 36|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($55 * $60);
 $62 = (($this) + 40|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($55 * $63);
 $65 = (($this) + 44|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($55 * $66);
 $68 = HEAP32[479744>>2]|0;
 $69 = HEAP32[((479744 + 4|0))>>2]|0;
 $70 = HEAP32[((479744 + 8|0))>>2]|0;
 $71 = HEAP32[((479744 + 12|0))>>2]|0;
 $72 = (HEAP32[tempDoublePtr>>2]=$68,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $73 = Math_fround($35 + $72);
 $74 = (HEAP32[tempDoublePtr>>2]=$69,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $75 = Math_fround($35 + $74);
 $76 = (HEAP32[tempDoublePtr>>2]=$70,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $77 = Math_fround($35 + $76);
 $78 = (HEAP32[tempDoublePtr>>2]=$71,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $79 = Math_fround($35 + $78);
 $80 = Math_fround($33 + $73);
 $81 = Math_fround($33 + $75);
 $82 = Math_fround($33 + $77);
 $83 = Math_fround($33 + $79);
 $84 = Math_fround(Math_fround(1.0) / $80);
 $85 = Math_fround(Math_fround(1.0) / $81);
 $86 = Math_fround(Math_fround(1.0) / $82);
 $87 = Math_fround(Math_fround(1.0) / $83);
 $88 = (($this) + 64|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($84 * $89);
 $91 = (($this) + 68|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($85 * $92);
 $94 = (($this) + 72|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($86 * $95);
 $97 = (($this) + 76|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($87 * $98);
 $100 = Math_fround($21 * $58);
 $101 = Math_fround($26 * $61);
 $102 = Math_fround($31 * $64);
 $103 = Math_fround($36 * $67);
 $104 = Math_fround($21 - $100);
 $105 = Math_fround($26 - $101);
 $106 = Math_fround($31 - $102);
 $107 = Math_fround($36 - $103);
 $108 = Math_fround($104 * $90);
 $109 = Math_fround($105 * $93);
 $110 = Math_fround($106 * $96);
 $111 = Math_fround($107 * $99);
 $112 = (HEAPF32[tempDoublePtr>>2]=$108,HEAP32[tempDoublePtr>>2]|0);
 $113 = (HEAPF32[tempDoublePtr>>2]=$109,HEAP32[tempDoublePtr>>2]|0);
 $114 = (HEAPF32[tempDoublePtr>>2]=$110,HEAP32[tempDoublePtr>>2]|0);
 $115 = (HEAPF32[tempDoublePtr>>2]=$111,HEAP32[tempDoublePtr>>2]|0);
 $116 = HEAP32[479712>>2]|0;
 $117 = HEAP32[((479712 + 4|0))>>2]|0;
 $118 = HEAP32[((479712 + 8|0))>>2]|0;
 $119 = HEAP32[((479712 + 12|0))>>2]|0;
 $120 = $116 & $112;
 $121 = $117 & $113;
 $122 = $118 & $114;
 $123 = $119 & $115;
 $124 = (HEAP32[tempDoublePtr>>2]=$120,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $125 = Math_fround($35 * $124);
 $126 = (HEAP32[tempDoublePtr>>2]=$121,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $127 = Math_fround($35 * $126);
 $128 = (HEAP32[tempDoublePtr>>2]=$122,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $129 = Math_fround($35 * $128);
 $130 = (HEAP32[tempDoublePtr>>2]=$123,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $131 = Math_fround($35 * $130);
 $132 = Math_fround($125 + $20);
 $133 = Math_fround($127 + $25);
 $134 = Math_fround($129 + $30);
 $135 = Math_fround($35 + $131);
 $136 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
 $137 = (HEAPF32[tempDoublePtr>>2]=$133,HEAP32[tempDoublePtr>>2]|0);
 $138 = (HEAPF32[tempDoublePtr>>2]=$134,HEAP32[tempDoublePtr>>2]|0);
 $139 = (HEAPF32[tempDoublePtr>>2]=$135,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$this>>2] = $136;
 HEAP32[$24>>2] = $137;
 HEAP32[$29>>2] = $138;
 HEAP32[$34>>2] = $139;
 $140 = Math_fround($33 * $124);
 $141 = Math_fround($33 * $126);
 $142 = Math_fround($33 * $128);
 $143 = Math_fround($33 * $130);
 $144 = Math_fround($19 - $140);
 $145 = Math_fround($23 - $141);
 $146 = Math_fround(HEAPF32[$27>>2]);
 $147 = Math_fround($146 - $142);
 $148 = Math_fround(HEAPF32[$32>>2]);
 $149 = Math_fround($148 - $143);
 $150 = (HEAPF32[tempDoublePtr>>2]=$144,HEAP32[tempDoublePtr>>2]|0);
 $151 = (HEAPF32[tempDoublePtr>>2]=$145,HEAP32[tempDoublePtr>>2]|0);
 $152 = (HEAPF32[tempDoublePtr>>2]=$147,HEAP32[tempDoublePtr>>2]|0);
 $153 = (HEAPF32[tempDoublePtr>>2]=$149,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$18>>2] = $150;
 HEAP32[$22>>2] = $151;
 HEAP32[$27>>2] = $152;
 HEAP32[$32>>2] = $153;
 $154 = ((($11) + (($4*76)|0)|0) + 4|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = (($155) + ($15<<4)|0);
 $157 = (($this) + 16|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround($125 + $158);
 $160 = (($this) + 20|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = Math_fround($127 + $161);
 $163 = (($this) + 24|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = Math_fround($129 + $164);
 $166 = (($this) + 28|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = Math_fround($131 + $167);
 $169 = (HEAPF32[tempDoublePtr>>2]=$159,HEAP32[tempDoublePtr>>2]|0);
 $170 = (HEAPF32[tempDoublePtr>>2]=$162,HEAP32[tempDoublePtr>>2]|0);
 $171 = (HEAPF32[tempDoublePtr>>2]=$165,HEAP32[tempDoublePtr>>2]|0);
 $172 = (HEAPF32[tempDoublePtr>>2]=$168,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$157>>2] = $169;
 HEAP32[$160>>2] = $170;
 HEAP32[$163>>2] = $171;
 HEAP32[$166>>2] = $172;
 $173 = Math_fround(HEAPF32[$156>>2]);
 $174 = Math_fround($173 - $140);
 $175 = ((($155) + ($15<<4)|0) + 4|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = Math_fround($176 - $141);
 $178 = ((($155) + ($15<<4)|0) + 8|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround($179 - $142);
 $181 = ((($155) + ($15<<4)|0) + 12|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = Math_fround($182 - $143);
 $184 = (HEAPF32[tempDoublePtr>>2]=$174,HEAP32[tempDoublePtr>>2]|0);
 $185 = (HEAPF32[tempDoublePtr>>2]=$177,HEAP32[tempDoublePtr>>2]|0);
 $186 = (HEAPF32[tempDoublePtr>>2]=$180,HEAP32[tempDoublePtr>>2]|0);
 $187 = (HEAPF32[tempDoublePtr>>2]=$183,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$156>>2] = $184;
 HEAP32[$175>>2] = $185;
 HEAP32[$178>>2] = $186;
 HEAP32[$181>>2] = $187;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a4182() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[479712>>2] = -1;
 HEAP32[((479712 + 4|0))>>2] = -1;
 HEAP32[((479712 + 8|0))>>2] = -1;
 HEAP32[((479712 + 12|0))>>2] = 0;
 HEAP32[479728>>2] = 0;
 HEAP32[((479728 + 4|0))>>2] = 0;
 HEAP32[((479728 + 8|0))>>2] = 0;
 HEAP32[((479728 + 12|0))>>2] = -1;
 HEAPF32[479744>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((479744 + 4|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((479744 + 8|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((479744 + 12|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[479760>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((479760 + 4|0))>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((479760 + 8|0))>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((479760 + 12|0))>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth15SwSelfCollisionI8Scalar4fEC1ERNS0_11SwClothDataER14StackAllocatorILj16EE($this,$clothData,$alloc) {
 $this = $this|0;
 $clothData = $clothData|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 48|0);
 HEAP32[$2>>2] = $clothData;
 $3 = (($this) + 52|0);
 HEAP32[$3>>2] = $alloc;
 $4 = (($clothData) + 224|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (HEAPF32[tempDoublePtr>>2]=$5,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$this>>2] = $6;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 8|0);
 HEAP32[$8>>2] = $6;
 $9 = (($this) + 12|0);
 HEAP32[$9>>2] = $6;
 $10 = Math_fround($5 * $5);
 $11 = (HEAPF32[tempDoublePtr>>2]=$10,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$0>>2] = $11;
 $12 = (($this) + 20|0);
 HEAP32[$12>>2] = $11;
 $13 = (($this) + 24|0);
 HEAP32[$13>>2] = $11;
 $14 = (($this) + 28|0);
 HEAP32[$14>>2] = $11;
 $15 = HEAP32[480024>>2]|0;
 $16 = HEAP32[((480024 + 4|0))>>2]|0;
 $17 = HEAP32[((480024 + 8|0))>>2]|0;
 $18 = HEAP32[((480024 + 12|0))>>2]|0;
 $19 = (($clothData) + 228|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (HEAPF32[tempDoublePtr>>2]=$20,HEAP32[tempDoublePtr>>2]|0);
 $22 = $21 & $15;
 $23 = $21 & $16;
 $24 = $21 & $17;
 $25 = $21 & $18;
 HEAP32[$1>>2] = $22;
 $26 = (($this) + 36|0);
 HEAP32[$26>>2] = $23;
 $27 = (($this) + 40|0);
 HEAP32[$27>>2] = $24;
 $28 = (($this) + 44|0);
 HEAP32[$28>>2] = $25;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth15SwSelfCollisionI8Scalar4fED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth15SwSelfCollisionI8Scalar4fEclEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$0$i7 = 0, $$idx = 0, $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$in$i = 0, $$in38$i = 0, $$in39$i = 0, $$pn$i = 0, $$pn40$i = 0, $$pre = 0, $$sum = 0, $$sum$i = 0, $$sum1$i = 0, $$sum10$i = 0, $$sum11$i = 0, $$sum12$i = 0, $$sum13$i = 0, $$sum14$i = 0;
 var $$sum15$i = 0, $$sum16$i = 0, $$sum17$i = 0, $$sum18$i = 0, $$sum2$i = 0, $$sum3$i = 0, $$sum4$i = 0, $$sum5$i = 0, $$sum6$i = 0, $$sum7$i = 0, $$sum8$i = 0, $$sum9$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0);
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0);
 var $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0;
 var $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0);
 var $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0;
 var $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0);
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0);
 var $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $cellSize = 0, $data = 0, $edgeLength = 0;
 var $exitcond = 0, $exitcond$i = 0, $exitcond62 = 0, $exitcond63 = 0, $exitcond64 = 0, $floorf$i = Math_fround(0), $floorf$i3 = Math_fround(0), $floorf$i3$us = Math_fround(0), $floorf1$i = Math_fround(0), $floorf1$i4 = Math_fround(0), $floorf1$i4$us = Math_fround(0), $floorf2$i = Math_fround(0), $floorf2$i5 = Math_fround(0), $floorf2$i5$us = Math_fround(0), $floorf3$i = Math_fround(0), $floorf3$i6 = Math_fround(0), $floorf3$i6$us = Math_fround(0), $gridSize = 0, $i$030$i = 0, $i$059 = 0;
 var $i$059$us = 0, $i1$027$i = 0, $i1$057 = 0, $i2$024$i = 0, $i2$056 = 0, $i3$021$i = 0, $i5$019$i = 0, $it$035$i = 0, $keyi = 0, $sortedIndices$0 = 0, $sums$sroa$0$031$i = 0, $sums$sroa$1$032$i = 0, $sums$sroa$2$033$i = 0, $sums$sroa$3$034$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $edgeLength = sp + 64|0;
 $cellSize = sp;
 $gridSize = sp + 16|0;
 $keyi = sp + 32|0;
 $data = sp + 48|0;
 $0 = (($this) + 60|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 56|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $$idx = (($3) + 224|0);
 $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
 $$idx1 = (($3) + 228|0);
 $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
 $4 = $$idx$val < $$idx1$val;
 $5 = $4 ? $$idx$val : $$idx1$val;
 $6 = $5 > Math_fround(0.0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($3) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($3) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($3) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($3) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($3) + 28|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($3) + 32|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($3) + 36|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($14 - $8);
 $22 = Math_fround($16 - $10);
 $23 = Math_fround($18 - $12);
 $24 = Math_fround($20 - $14);
 $25 = HEAP32[480040>>2]|0;
 $26 = HEAP32[((480040 + 4|0))>>2]|0;
 $27 = HEAP32[((480040 + 8|0))>>2]|0;
 $28 = HEAP32[((480040 + 12|0))>>2]|0;
 $29 = (HEAP32[tempDoublePtr>>2]=$25,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $30 = $21 < $29;
 $31 = $30 ? $29 : $21;
 $32 = (HEAP32[tempDoublePtr>>2]=$26,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $33 = $22 < $32;
 $34 = $33 ? $32 : $22;
 $35 = (HEAP32[tempDoublePtr>>2]=$27,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $36 = $23 < $35;
 $37 = $36 ? $35 : $23;
 $38 = (HEAP32[tempDoublePtr>>2]=$28,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $39 = $24 < $38;
 $40 = $39 ? $38 : $24;
 HEAPF32[$edgeLength>>2] = $31;
 $41 = (($edgeLength) + 4|0);
 HEAPF32[$41>>2] = $34;
 $42 = (($edgeLength) + 8|0);
 HEAPF32[$42>>2] = $37;
 $43 = (($edgeLength) + 12|0);
 HEAPF32[$43>>2] = $40;
 $44 = $31 > $34;
 if ($44) {
  $45 = $31 > $37;
  $46 = $45 ? 0 : 2;
  $$0$i = $46;
 } else {
  $47 = $34 > $37;
  $48 = $47 ? 1 : 2;
  $$0$i = $48;
 }
 $49 = (($$0$i) + 1)|0;
 $50 = (($49>>>0) % 3)&-1;
 $51 = (($$0$i) + 2)|0;
 $52 = (($51>>>0) % 3)&-1;
 $53 = Math_fround($31 * Math_fround(0.00395256932824850082397));
 $54 = Math_fround($34 * Math_fround(0.00395256932824850082397));
 $55 = Math_fround($37 * Math_fround(0.00395256932824850082397));
 $56 = Math_fround($40 * Math_fround(0.00395256932824850082397));
 $57 = Math_fround(HEAPF32[$this>>2]);
 $58 = $57 < $53;
 $59 = $58 ? $53 : $57;
 $60 = (($this) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = $61 < $54;
 $63 = $62 ? $54 : $61;
 $64 = (($this) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = $65 < $55;
 $67 = $66 ? $55 : $65;
 $68 = (($this) + 12|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = $69 < $56;
 $71 = $70 ? $56 : $69;
 HEAPF32[$cellSize>>2] = $59;
 $72 = (($cellSize) + 4|0);
 HEAPF32[$72>>2] = $63;
 $73 = (($cellSize) + 8|0);
 HEAPF32[$73>>2] = $67;
 $74 = (($cellSize) + 12|0);
 HEAPF32[$74>>2] = $71;
 $75 = (($edgeLength) + ($$0$i<<2)|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($76 / Math_fround(65533.0));
 $78 = (($cellSize) + ($$0$i<<2)|0);
 HEAPF32[$78>>2] = $77;
 HEAPF32[$gridSize>>2] = Math_fround(254.0);
 $79 = (($gridSize) + 4|0);
 HEAPF32[$79>>2] = Math_fround(254.0);
 $80 = (($gridSize) + 8|0);
 HEAPF32[$80>>2] = Math_fround(254.0);
 $81 = (($gridSize) + 12|0);
 HEAPF32[$81>>2] = Math_fround(254.0);
 $82 = (($gridSize) + ($$0$i<<2)|0);
 HEAPF32[$82>>2] = Math_fround(65534.0);
 $83 = Math_fround(HEAPF32[$cellSize>>2]);
 $84 = Math_fround(Math_fround(1.0) / $83);
 $85 = Math_fround(HEAPF32[$72>>2]);
 $86 = Math_fround(Math_fround(1.0) / $85);
 $87 = Math_fround(HEAPF32[$73>>2]);
 $88 = Math_fround(Math_fround(1.0) / $87);
 $89 = Math_fround(HEAPF32[$74>>2]);
 $90 = Math_fround(Math_fround(1.0) / $89);
 $91 = Math_fround($8 * $84);
 $92 = Math_fround($10 * $86);
 $93 = Math_fround($12 * $88);
 $94 = Math_fround($14 * $90);
 $95 = Math_fround(Math_fround(1.0) - $91);
 $96 = Math_fround(Math_fround(1.0) - $92);
 $97 = Math_fround(Math_fround(1.0) - $93);
 $98 = Math_fround(Math_fround(1.0) - $94);
 $99 = (($3) + 232|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($this) + 52|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = $100 << 2;
 $104 = $100 << 1;
 $105 = (($104) + 2)|0;
 $106 = $105 & -4;
 $107 = (($104) + 2048)|0;
 $108 = (($106) + ($103))|0;
 $109 = (($103) + 4)|0;
 $110 = ($107>>>0)<($109>>>0);
 $111 = $110 ? $109 : $107;
 $112 = (($108) + ($111))|0;
 $113 = ($112|0)==(0);
 if ($113) {
  $$0$i7 = 0;$127 = $3;
 } else {
  $114 = (($102) + 8|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = $115;
  $117 = (($116) + 23)|0;
  $118 = $117 & -16;
  $119 = $118;
  $120 = (($119) + ($112)|0);
  $121 = (($119) + -8|0);
  $122 = (($102) + 12|0);
  $123 = HEAP32[$122>>2]|0;
  HEAP32[$121>>2] = $123;
  $124 = (($119) + -4|0);
  $125 = $112 & 2147483646;
  HEAP32[$124>>2] = $125;
  HEAP32[$122>>2] = $121;
  HEAP32[$114>>2] = $120;
  $$pre = HEAP32[$2>>2]|0;
  $$0$i7 = $119;$127 = $$pre;
 }
 $126 = (($127) + 236|0);
 $128 = HEAP32[$126>>2]|0;
 $129 = (($$0$i7) + ($100<<2)|0);
 $130 = (($100) + 1)|0;
 $131 = $130 & -2;
 $132 = (($129) + ($131<<1)|0);
 $133 = (($127) + 4|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = ($100|0)==(0);
 if (!($135)) {
  $136 = ($128|0)==(0|0);
  $137 = Math_fround(HEAPF32[$gridSize>>2]);
  $138 = Math_fround(HEAPF32[$79>>2]);
  $139 = Math_fround(HEAPF32[$80>>2]);
  $140 = Math_fround(HEAPF32[$81>>2]);
  $141 = (($keyi) + 4|0);
  $142 = (($keyi) + 8|0);
  $143 = (($keyi) + 12|0);
  $144 = (($keyi) + ($$0$i<<2)|0);
  $145 = (($keyi) + ($50<<2)|0);
  $146 = (($keyi) + ($52<<2)|0);
  if ($136) {
   $i$059$us = 0;
   while(1) {
    $147 = (($134) + ($i$059$us<<4)|0);
    $148 = Math_fround(HEAPF32[$147>>2]);
    $149 = Math_fround($84 * $148);
    $150 = ((($134) + ($i$059$us<<4)|0) + 4|0);
    $151 = Math_fround(HEAPF32[$150>>2]);
    $152 = Math_fround($86 * $151);
    $153 = ((($134) + ($i$059$us<<4)|0) + 8|0);
    $154 = Math_fround(HEAPF32[$153>>2]);
    $155 = Math_fround($88 * $154);
    $156 = ((($134) + ($i$059$us<<4)|0) + 12|0);
    $157 = Math_fround(HEAPF32[$156>>2]);
    $158 = Math_fround($90 * $157);
    $159 = Math_fround($95 + $149);
    $160 = Math_fround($96 + $152);
    $161 = Math_fround($97 + $155);
    $162 = Math_fround($98 + $158);
    $163 = $137 < $159;
    $164 = $163 ? $137 : $159;
    $165 = $138 < $160;
    $166 = $165 ? $138 : $160;
    $167 = $139 < $161;
    $168 = $167 ? $139 : $161;
    $169 = $140 < $162;
    $170 = $169 ? $140 : $162;
    $171 = $164 > Math_fround(1.0);
    $172 = $171 ? $164 : Math_fround(1.0);
    $173 = $166 > Math_fround(1.0);
    $174 = $173 ? $166 : Math_fround(1.0);
    $175 = $168 > Math_fround(1.0);
    $176 = $175 ? $168 : Math_fround(1.0);
    $177 = $170 > Math_fround(1.0);
    $178 = $177 ? $170 : Math_fround(1.0);
    $floorf$i3$us = (Math_fround(Math_floor((Math_fround($172)))));
    $179 = (~~(($floorf$i3$us)));
    $floorf1$i4$us = (Math_fround(Math_floor((Math_fround($174)))));
    $180 = (~~(($floorf1$i4$us)));
    $floorf2$i5$us = (Math_fround(Math_floor((Math_fround($176)))));
    $181 = (~~(($floorf2$i5$us)));
    $floorf3$i6$us = (Math_fround(Math_floor((Math_fround($178)))));
    $182 = (~~(($floorf3$i6$us)));
    HEAP32[$keyi>>2] = $179;
    HEAP32[$141>>2] = $180;
    HEAP32[$142>>2] = $181;
    HEAP32[$143>>2] = $182;
    $183 = HEAP32[$144>>2]|0;
    $184 = HEAP32[$145>>2]|0;
    $185 = $184 << 16;
    $186 = $185 | $183;
    $187 = HEAP32[$146>>2]|0;
    $188 = $187 << 24;
    $189 = $186 | $188;
    $190 = (($$0$i7) + ($i$059$us<<2)|0);
    HEAP32[$190>>2] = $189;
    $191 = (($i$059$us) + 1)|0;
    $exitcond64 = ($191|0)==($100|0);
    if ($exitcond64) {
     break;
    } else {
     $i$059$us = $191;
    }
   }
  } else {
   $i$059 = 0;
   while(1) {
    $192 = (($128) + ($i$059<<2)|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = (($134) + ($193<<4)|0);
    $195 = Math_fround(HEAPF32[$194>>2]);
    $196 = Math_fround($84 * $195);
    $197 = ((($134) + ($193<<4)|0) + 4|0);
    $198 = Math_fround(HEAPF32[$197>>2]);
    $199 = Math_fround($86 * $198);
    $200 = ((($134) + ($193<<4)|0) + 8|0);
    $201 = Math_fround(HEAPF32[$200>>2]);
    $202 = Math_fround($88 * $201);
    $203 = ((($134) + ($193<<4)|0) + 12|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = Math_fround($90 * $204);
    $206 = Math_fround($95 + $196);
    $207 = Math_fround($96 + $199);
    $208 = Math_fround($97 + $202);
    $209 = Math_fround($98 + $205);
    $210 = $137 < $206;
    $211 = $210 ? $137 : $206;
    $212 = $138 < $207;
    $213 = $212 ? $138 : $207;
    $214 = $139 < $208;
    $215 = $214 ? $139 : $208;
    $216 = $140 < $209;
    $217 = $216 ? $140 : $209;
    $218 = $211 > Math_fround(1.0);
    $219 = $218 ? $211 : Math_fround(1.0);
    $220 = $213 > Math_fround(1.0);
    $221 = $220 ? $213 : Math_fround(1.0);
    $222 = $215 > Math_fround(1.0);
    $223 = $222 ? $215 : Math_fround(1.0);
    $224 = $217 > Math_fround(1.0);
    $225 = $224 ? $217 : Math_fround(1.0);
    $floorf$i3 = (Math_fround(Math_floor((Math_fround($219)))));
    $226 = (~~(($floorf$i3)));
    $floorf1$i4 = (Math_fround(Math_floor((Math_fround($221)))));
    $227 = (~~(($floorf1$i4)));
    $floorf2$i5 = (Math_fround(Math_floor((Math_fround($223)))));
    $228 = (~~(($floorf2$i5)));
    $floorf3$i6 = (Math_fround(Math_floor((Math_fround($225)))));
    $229 = (~~(($floorf3$i6)));
    HEAP32[$keyi>>2] = $226;
    HEAP32[$141>>2] = $227;
    HEAP32[$142>>2] = $228;
    HEAP32[$143>>2] = $229;
    $230 = HEAP32[$144>>2]|0;
    $231 = HEAP32[$145>>2]|0;
    $232 = $231 << 16;
    $233 = $232 | $230;
    $234 = HEAP32[$146>>2]|0;
    $235 = $234 << 24;
    $236 = $233 | $235;
    $237 = (($$0$i7) + ($i$059<<2)|0);
    HEAP32[$237>>2] = $236;
    $238 = (($i$059) + 1)|0;
    $exitcond63 = ($238|0)==($100|0);
    if ($exitcond63) {
     break;
    } else {
     $i$059 = $238;
    }
   }
  }
 }
 $239 = $129;
 $240 = $$0$i7;
 $241 = (($239) - ($240))|0;
 $242 = $241 >>> 2;
 $243 = $242 & 65535;
 $244 = $243 << 1;
 $$sum = (($243) + ($100))|0;
 $245 = (($$0$i7) + ($$sum<<2)|0);
 $$sum$i = (($244) + 256)|0;
 $$sum1$i = (($244) + 512)|0;
 $$sum2$i = (($244) + 768)|0;
 _memset(($245|0),0,2048)|0;
 $246 = ($$0$i7|0)==($129|0);
 if ($246) {
  $i$030$i = 0;$sums$sroa$0$031$i = 0;$sums$sroa$1$032$i = 0;$sums$sroa$2$033$i = 0;$sums$sroa$3$034$i = 0;
 } else {
  $it$035$i = $$0$i7;
  while(1) {
   $247 = HEAP32[$it$035$i>>2]|0;
   $248 = $247 & 255;
   $$sum15$i = (($248) + ($244))|0;
   $249 = (($129) + ($$sum15$i<<1)|0);
   $250 = HEAP16[$249>>1]|0;
   $251 = (($250) + 1)<<16>>16;
   HEAP16[$249>>1] = $251;
   $252 = $247 >>> 8;
   $253 = $252 & 255;
   $$sum16$i = (($253) + ($$sum$i))|0;
   $254 = (($129) + ($$sum16$i<<1)|0);
   $255 = HEAP16[$254>>1]|0;
   $256 = (($255) + 1)<<16>>16;
   HEAP16[$254>>1] = $256;
   $257 = $247 >>> 16;
   $258 = $257 & 255;
   $$sum17$i = (($258) + ($$sum1$i))|0;
   $259 = (($129) + ($$sum17$i<<1)|0);
   $260 = HEAP16[$259>>1]|0;
   $261 = (($260) + 1)<<16>>16;
   HEAP16[$259>>1] = $261;
   $262 = $247 >>> 24;
   $$sum18$i = (($262) + ($$sum2$i))|0;
   $263 = (($129) + ($$sum18$i<<1)|0);
   $264 = HEAP16[$263>>1]|0;
   $265 = (($264) + 1)<<16>>16;
   HEAP16[$263>>1] = $265;
   $266 = (($it$035$i) + 4|0);
   $267 = ($266|0)==($129|0);
   if ($267) {
    $i$030$i = 0;$sums$sroa$0$031$i = 0;$sums$sroa$1$032$i = 0;$sums$sroa$2$033$i = 0;$sums$sroa$3$034$i = 0;
    break;
   } else {
    $it$035$i = $266;
   }
  }
 }
 while(1) {
  $$sum11$i = (($i$030$i) + ($244))|0;
  $269 = (($129) + ($$sum11$i<<1)|0);
  $270 = HEAP16[$269>>1]|0;
  $271 = $270&65535;
  $272 = $sums$sroa$0$031$i&65535;
  $273 = (($271) + ($272))|0;
  $274 = $273&65535;
  HEAP16[$269>>1] = $sums$sroa$0$031$i;
  $$sum12$i = (($i$030$i) + ($$sum$i))|0;
  $275 = (($129) + ($$sum12$i<<1)|0);
  $276 = HEAP16[$275>>1]|0;
  $277 = $276&65535;
  $278 = $sums$sroa$1$032$i&65535;
  $279 = (($277) + ($278))|0;
  $280 = $279&65535;
  HEAP16[$275>>1] = $sums$sroa$1$032$i;
  $$sum13$i = (($i$030$i) + ($$sum1$i))|0;
  $281 = (($129) + ($$sum13$i<<1)|0);
  $282 = HEAP16[$281>>1]|0;
  $283 = $282&65535;
  $284 = $sums$sroa$2$033$i&65535;
  $285 = (($283) + ($284))|0;
  $286 = $285&65535;
  HEAP16[$281>>1] = $sums$sroa$2$033$i;
  $$sum14$i = (($i$030$i) + ($$sum2$i))|0;
  $287 = (($129) + ($$sum14$i<<1)|0);
  $288 = HEAP16[$287>>1]|0;
  $289 = $288&65535;
  $290 = $sums$sroa$3$034$i&65535;
  $291 = (($289) + ($290))|0;
  $292 = $291&65535;
  HEAP16[$287>>1] = $sums$sroa$3$034$i;
  $293 = (($i$030$i) + 1)|0;
  $exitcond$i = ($293|0)==(256);
  if ($exitcond$i) {
   break;
  } else {
   $i$030$i = $293;$sums$sroa$0$031$i = $274;$sums$sroa$1$032$i = $280;$sums$sroa$2$033$i = $286;$sums$sroa$3$034$i = $292;
  }
 }
 $268 = ($243|0)==(0);
 if (!($268)) {
  $295 = 0;$i1$027$i = 0;
  while(1) {
   $294 = (($$0$i7) + ($295<<2)|0);
   $296 = HEAP32[$294>>2]|0;
   $297 = $296 & 255;
   $$sum9$i = (($297) + ($244))|0;
   $298 = (($129) + ($$sum9$i<<1)|0);
   $299 = HEAP16[$298>>1]|0;
   $300 = (($299) + 1)<<16>>16;
   HEAP16[$298>>1] = $300;
   $301 = $299&65535;
   $$sum10$i = (($301) + ($243))|0;
   $302 = (($129) + ($$sum10$i<<1)|0);
   HEAP16[$302>>1] = $i1$027$i;
   $303 = (($i1$027$i) + 1)<<16>>16;
   $304 = $303&65535;
   $305 = ($304|0)==($243|0);
   if ($305) {
    $$pn$i = $243;$i2$024$i = 0;
    break;
   } else {
    $295 = $304;$i1$027$i = $303;
   }
  }
  while(1) {
   $$in$i = (($129) + ($$pn$i<<1)|0);
   $306 = HEAP16[$$in$i>>1]|0;
   $307 = $306&65535;
   $308 = (($$0$i7) + ($307<<2)|0);
   $309 = HEAP32[$308>>2]|0;
   $310 = $309 >>> 8;
   $311 = $310 & 255;
   $$sum8$i = (($311) + ($$sum$i))|0;
   $312 = (($129) + ($$sum8$i<<1)|0);
   $313 = HEAP16[$312>>1]|0;
   $314 = (($313) + 1)<<16>>16;
   HEAP16[$312>>1] = $314;
   $315 = $313&65535;
   $316 = (($129) + ($315<<1)|0);
   HEAP16[$316>>1] = $306;
   $317 = (($i2$024$i) + 1)<<16>>16;
   $318 = $317&65535;
   $$sum3$i = (($318) + ($243))|0;
   $319 = ($318|0)==($243|0);
   if ($319) {
    $$in38$i = $129;$i3$021$i = 0;
    break;
   } else {
    $$pn$i = $$sum3$i;$i2$024$i = $317;
   }
  }
  while(1) {
   $320 = HEAP16[$$in38$i>>1]|0;
   $321 = $320&65535;
   $322 = (($$0$i7) + ($321<<2)|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = $323 >>> 16;
   $325 = $324 & 255;
   $$sum6$i = (($325) + ($$sum1$i))|0;
   $326 = (($129) + ($$sum6$i<<1)|0);
   $327 = HEAP16[$326>>1]|0;
   $328 = (($327) + 1)<<16>>16;
   HEAP16[$326>>1] = $328;
   $329 = $327&65535;
   $$sum7$i = (($329) + ($243))|0;
   $330 = (($129) + ($$sum7$i<<1)|0);
   HEAP16[$330>>1] = $320;
   $331 = (($i3$021$i) + 1)<<16>>16;
   $332 = $331&65535;
   $333 = (($129) + ($332<<1)|0);
   $334 = ($332|0)==($243|0);
   if ($334) {
    $$pn40$i = $243;$i5$019$i = 0;
    break;
   } else {
    $$in38$i = $333;$i3$021$i = $331;
   }
  }
  while(1) {
   $$in39$i = (($129) + ($$pn40$i<<1)|0);
   $335 = HEAP16[$$in39$i>>1]|0;
   $336 = $335&65535;
   $337 = (($$0$i7) + ($336<<2)|0);
   $338 = HEAP32[$337>>2]|0;
   $339 = $338 >>> 24;
   $$sum5$i = (($339) + ($$sum2$i))|0;
   $340 = (($129) + ($$sum5$i<<1)|0);
   $341 = HEAP16[$340>>1]|0;
   $342 = (($341) + 1)<<16>>16;
   HEAP16[$340>>1] = $342;
   $343 = $341&65535;
   $344 = (($129) + ($343<<1)|0);
   HEAP16[$344>>1] = $335;
   $345 = (($i5$019$i) + 1)<<16>>16;
   $346 = $345&65535;
   $$sum4$i = (($346) + ($243))|0;
   $347 = ($346|0)==($243|0);
   if ($347) {
    break;
   } else {
    $$pn40$i = $$sum4$i;$i5$019$i = $345;
   }
  }
 }
 $348 = (($104) + 769)|0;
 $349 = (($129) + ($348<<1)|0);
 $350 = HEAP16[$349>>1]|0;
 if (!($135)) {
  $i1$057 = 0;
  while(1) {
   $351 = (($129) + ($i1$057<<1)|0);
   $352 = HEAP16[$351>>1]|0;
   $353 = $352&65535;
   $354 = (($$0$i7) + ($353<<2)|0);
   $355 = HEAP32[$354>>2]|0;
   $356 = (($132) + ($i1$057<<2)|0);
   HEAP32[$356>>2] = $355;
   $357 = (($i1$057) + 1)|0;
   $exitcond62 = ($357|0)==($100|0);
   if ($exitcond62) {
    break;
   } else {
    $i1$057 = $357;
   }
  }
 }
 $358 = (($132) + ($100<<2)|0);
 HEAP32[$358>>2] = -1;
 $359 = ($128|0)==(0|0);
 if ($359) {
  $sortedIndices$0 = $129;
 } else {
  if ($135) {
   $sortedIndices$0 = $$0$i7;
  } else {
   $i2$056 = 0;
   while(1) {
    $360 = (($129) + ($i2$056<<1)|0);
    $361 = HEAP16[$360>>1]|0;
    $362 = $361&65535;
    $363 = (($128) + ($362<<2)|0);
    $364 = HEAP32[$363>>2]|0;
    $365 = $364&65535;
    $366 = (($$0$i7) + ($i2$056<<1)|0);
    HEAP16[$366>>1] = $365;
    $367 = (($i2$056) + 1)|0;
    $exitcond = ($367|0)==($100|0);
    if ($exitcond) {
     $sortedIndices$0 = $$0$i7;
     break;
    } else {
     $i2$056 = $367;
    }
   }
  }
 }
 $368 = Math_fround(HEAPF32[$this>>2]);
 $369 = Math_fround($84 * $368);
 $370 = Math_fround(HEAPF32[$60>>2]);
 $371 = Math_fround($86 * $370);
 $372 = Math_fround(HEAPF32[$64>>2]);
 $373 = Math_fround($88 * $372);
 $374 = Math_fround(HEAPF32[$68>>2]);
 $375 = Math_fround($90 * $374);
 $floorf$i = (Math_fround(Math_floor((Math_fround($369)))));
 $376 = (~~(($floorf$i)));
 $floorf1$i = (Math_fround(Math_floor((Math_fround($371)))));
 $377 = (~~(($floorf1$i)));
 $floorf2$i = (Math_fround(Math_floor((Math_fround($373)))));
 $378 = (~~(($floorf2$i)));
 $floorf3$i = (Math_fround(Math_floor((Math_fround($375)))));
 $379 = (~~(($floorf3$i)));
 HEAP32[$data>>2] = $376;
 $380 = (($data) + 4|0);
 HEAP32[$380>>2] = $377;
 $381 = (($data) + 8|0);
 HEAP32[$381>>2] = $378;
 $382 = (($data) + 12|0);
 HEAP32[$382>>2] = $379;
 $383 = (($data) + ($$0$i<<2)|0);
 $384 = HEAP32[$383>>2]|0;
 $385 = (($384) + 2)|0;
 $386 = HEAP32[$2>>2]|0;
 $387 = (($386) + 240|0);
 $388 = HEAP32[$387>>2]|0;
 $389 = ($388|0)==(0|0);
 if ($389) {
  __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb0EEEvPKjtPKtj($this,$132,$350,$sortedIndices$0,$385);
 } else {
  __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb1EEEvPKjtPKtj($this,$132,$350,$sortedIndices$0,$385);
 }
 $390 = HEAP32[$101>>2]|0;
 $391 = ($$0$i7|0)==(0|0);
 if ($391) {
  STACKTOP = sp;return;
 }
 $392 = (($$0$i7) + -4|0);
 $393 = HEAP32[$392>>2]|0;
 $394 = $393 | -2147483648;
 HEAP32[$392>>2] = $394;
 $395 = (($390) + 12|0);
 $396 = HEAP32[$395>>2]|0;
 $397 = ($396|0)==(0|0);
 if ($397) {
  STACKTOP = sp;return;
 }
 $398 = (($390) + 8|0);
 $400 = $396;
 while(1) {
  $399 = (($400) + 4|0);
  $401 = HEAP32[$399>>2]|0;
  $402 = ($401|0)<(0);
  if (!($402)) {
   label = 32;
   break;
  }
  HEAP32[$398>>2] = $400;
  $403 = HEAP32[$400>>2]|0;
  HEAP32[$395>>2] = $403;
  $404 = ($403|0)==(0|0);
  if ($404) {
   label = 32;
   break;
  } else {
   $400 = $403;
  }
 }
 if ((label|0) == 32) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb1EEEvPKjtPKtj($this,$keys,$firstColumnSize,$indices,$collisionDistance) {
 $this = $this|0;
 $keys = $keys|0;
 $firstColumnSize = $firstColumnSize|0;
 $indices = $indices|0;
 $collisionDistance = $collisionDistance|0;
 var $$lcssa = 0, $$lcssa12 = 0, $$pre = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $$pre54 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond = 0, $iIt$023 = 0, $jIt$03 = 0, $jIt$118 = 0, $k5$022 = 0, $kFirst = 0, $kIt$0 = 0, $kIt$2 = 0, $kIt$2$1 = 0, $kIt$2$2 = 0, $kIt$2$3 = 0, $kIt$3 = 0, $kIt$3$1 = 0, $kIt$3$2 = 0, $kIt$3$3 = 0, $kLast = 0, $particle = 0, $restParticle = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $kFirst = sp + 56|0;
 $kLast = sp;
 $particle = sp + 24|0;
 $restParticle = sp + 40|0;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 240|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$keys>>2]|0;
 $7 = $6 & 65535;
 $8 = ($7>>>0)>($collisionDistance>>>0);
 $9 = $8 ? $collisionDistance : $7;
 $10 = (($6) + ($collisionDistance))|0;
 $11 = $6 | 65535;
 $12 = ($10>>>0)<($11>>>0);
 $13 = $12 ? $10 : $11;
 HEAP32[$kFirst>>2] = $keys;
 $15 = $6;$kIt$0 = $keys;
 while(1) {
  $14 = ($15>>>0)<($13>>>0);
  $16 = (($kIt$0) + 4|0);
  if (!($14)) {
   break;
  }
  $$pre = HEAP32[$16>>2]|0;
  $15 = $$pre;$kIt$0 = $16;
 }
 $17 = (($6) - ($9))|0;
 HEAP32[$kLast>>2] = $kIt$0;
 $18 = (($17) + 65536)|0;
 $20 = $15;$kIt$2 = $kIt$0;
 while(1) {
  $19 = ($20>>>0)<($18>>>0);
  $21 = (($kIt$2) + 4|0);
  if (!($19)) {
   break;
  }
  $$pre45 = HEAP32[$21>>2]|0;
  $20 = $$pre45;$kIt$2 = $21;
 }
 $22 = (($kFirst) + 4|0);
 HEAP32[$22>>2] = $kIt$2;
 $23 = (($13) + 65536)|0;
 $25 = $20;$kIt$3 = $kIt$2;
 while(1) {
  $24 = ($25>>>0)<($23>>>0);
  $26 = (($kIt$3) + 4|0);
  if (!($24)) {
   break;
  }
  $$pre46 = HEAP32[$26>>2]|0;
  $25 = $$pre46;$kIt$3 = $26;
 }
 $27 = (($kLast) + 4|0);
 HEAP32[$27>>2] = $kIt$3;
 $28 = $firstColumnSize&65535;
 $29 = (($keys) + ($28<<2)|0);
 $30 = (($17) + 16711680)|0;
 $kIt$2$1 = $29;
 while(1) {
  $134 = HEAP32[$kIt$2$1>>2]|0;
  $135 = ($134>>>0)<($30>>>0);
  $136 = (($kIt$2$1) + 4|0);
  if ($135) {
   $kIt$2$1 = $136;
  } else {
   break;
  }
 }
 $137 = (($kFirst) + 8|0);
 HEAP32[$137>>2] = $kIt$2$1;
 $138 = (($13) + 16711680)|0;
 $140 = $134;$kIt$3$1 = $kIt$2$1;
 while(1) {
  $139 = ($140>>>0)<($138>>>0);
  $141 = (($kIt$3$1) + 4|0);
  if (!($139)) {
   break;
  }
  $$pre47 = HEAP32[$141>>2]|0;
  $140 = $$pre47;$kIt$3$1 = $141;
 }
 $142 = (($kLast) + 8|0);
 HEAP32[$142>>2] = $kIt$3$1;
 $143 = (($17) + 16777216)|0;
 $145 = $6;$kIt$2$2 = $keys;
 while(1) {
  $144 = ($145>>>0)<($143>>>0);
  $146 = (($kIt$2$2) + 4|0);
  if (!($144)) {
   break;
  }
  $$pre48 = HEAP32[$146>>2]|0;
  $145 = $$pre48;$kIt$2$2 = $146;
 }
 $147 = (($kFirst) + 12|0);
 HEAP32[$147>>2] = $kIt$2$2;
 $148 = (($13) + 16777216)|0;
 $150 = $145;$kIt$3$2 = $kIt$2$2;
 while(1) {
  $149 = ($150>>>0)<($148>>>0);
  $151 = (($kIt$3$2) + 4|0);
  if (!($149)) {
   break;
  }
  $$pre49 = HEAP32[$151>>2]|0;
  $150 = $$pre49;$kIt$3$2 = $151;
 }
 $152 = (($kLast) + 12|0);
 HEAP32[$152>>2] = $kIt$3$2;
 $153 = (($17) + 16842752)|0;
 $155 = $6;$kIt$2$3 = $keys;
 while(1) {
  $154 = ($155>>>0)<($153>>>0);
  $156 = (($kIt$2$3) + 4|0);
  if (!($154)) {
   break;
  }
  $$pre50 = HEAP32[$156>>2]|0;
  $155 = $$pre50;$kIt$2$3 = $156;
 }
 $157 = (($kFirst) + 16|0);
 HEAP32[$157>>2] = $kIt$2$3;
 $158 = (($13) + 16842752)|0;
 $160 = $155;$kIt$3$3 = $kIt$2$3;
 while(1) {
  $159 = ($160>>>0)<($158>>>0);
  $161 = (($kIt$3$3) + 4|0);
  if (!($159)) {
   break;
  }
  $$pre51 = HEAP32[$161>>2]|0;
  $160 = $$pre51;$kIt$3$3 = $161;
 }
 $162 = (($kLast) + 16|0);
 HEAP32[$162>>2] = $kIt$3$3;
 $163 = (($1) + 232|0);
 $164 = HEAP32[$163>>2]|0;
 $133 = (($indices) + ($164<<1)|0);
 $165 = ($164|0)==(0);
 if ($165) {
  STACKTOP = sp;return;
 }
 $31 = (($particle) + 4|0);
 $32 = (($particle) + 8|0);
 $33 = (($particle) + 12|0);
 $34 = (($restParticle) + 4|0);
 $35 = (($restParticle) + 8|0);
 $36 = (($restParticle) + 12|0);
 $37 = $keys;
 $166 = $kIt$0;$57 = $6;$66 = $15;$iIt$023 = $indices;
 while(1) {
  $38 = HEAP16[$iIt$023>>1]|0;
  $39 = $38&65535;
  $40 = (($3) + ($39<<4)|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$particle>>2] = $41;
  $42 = ((($3) + ($39<<4)|0) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  HEAP32[$31>>2] = $43;
  $44 = ((($3) + ($39<<4)|0) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  HEAP32[$32>>2] = $45;
  $46 = ((($3) + ($39<<4)|0) + 12|0);
  $47 = HEAP32[$46>>2]|0;
  HEAP32[$33>>2] = $47;
  $48 = (($5) + ($39<<4)|0);
  $49 = HEAP32[$48>>2]|0;
  HEAP32[$restParticle>>2] = $49;
  $50 = ((($5) + ($39<<4)|0) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  HEAP32[$34>>2] = $51;
  $52 = ((($5) + ($39<<4)|0) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  HEAP32[$35>>2] = $53;
  $54 = ((($5) + ($39<<4)|0) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  HEAP32[$36>>2] = $55;
  $56 = $57 & 65535;
  $58 = ($56>>>0)>($collisionDistance>>>0);
  $59 = $58 ? $collisionDistance : $56;
  $60 = (($57) - ($59))|0;
  $61 = (($57) + ($collisionDistance))|0;
  $62 = $57 | 65535;
  $63 = ($61>>>0)<($62>>>0);
  $64 = $63 ? $61 : $62;
  $65 = ($66>>>0)<($64>>>0);
  if ($65) {
   $68 = $166;
   while(1) {
    $67 = (($68) + 4|0);
    $69 = HEAP32[$67>>2]|0;
    $70 = ($69>>>0)<($64>>>0);
    if ($70) {
     $68 = $67;
    } else {
     break;
    }
   }
   HEAP32[$kLast>>2] = $67;
   $$lcssa = $67;
  } else {
   $$lcssa = $166;
  }
  $71 = $$lcssa;
  $72 = (($71) - ($37))|0;
  $73 = $72 >> 2;
  $74 = (($indices) + ($73<<1)|0);
  $75 = (($iIt$023) + 2|0);
  $76 = ($75|0)==($74|0);
  if ($76) {
   $k5$022 = 1;
  } else {
   $jIt$03 = $75;
   while(1) {
    $77 = HEAP16[$jIt$03>>1]|0;
    $78 = $77&65535;
    $79 = (($3) + ($78<<4)|0);
    $80 = (($5) + ($78<<4)|0);
    __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb1EEEvRS2_S5_RKS2_S7_($this,$particle,$79,$restParticle,$80);
    $81 = (($jIt$03) + 2|0);
    $82 = ($81|0)==($74|0);
    if ($82) {
     $k5$022 = 1;
     break;
    } else {
     $jIt$03 = $81;
    }
   }
  }
  while(1) {
   $83 = (480056 + ($k5$022<<2)|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($60) + ($84))|0;
   $86 = (($kFirst) + ($k5$022<<2)|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88>>>0)<($85>>>0);
   if ($89) {
    $91 = $87;
    while(1) {
     $90 = (($91) + 4|0);
     $92 = HEAP32[$90>>2]|0;
     $93 = ($92>>>0)<($85>>>0);
     if ($93) {
      $91 = $90;
     } else {
      break;
     }
    }
    HEAP32[$86>>2] = $90;
    $108 = $90;
   } else {
    $108 = $87;
   }
   $94 = (($84) + ($64))|0;
   $95 = (($kLast) + ($k5$022<<2)|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97>>>0)<($94>>>0);
   if ($98) {
    $100 = $96;
    while(1) {
     $99 = (($100) + 4|0);
     $101 = HEAP32[$99>>2]|0;
     $102 = ($101>>>0)<($94>>>0);
     if ($102) {
      $100 = $99;
     } else {
      break;
     }
    }
    HEAP32[$95>>2] = $99;
    $$lcssa12 = $99;
   } else {
    $$lcssa12 = $96;
   }
   $103 = $$lcssa12;
   $104 = (($103) - ($37))|0;
   $105 = $104 >> 2;
   $106 = (($indices) + ($105<<1)|0);
   $107 = $108;
   $109 = (($107) - ($37))|0;
   $110 = $109 >> 2;
   $111 = ($110|0)==($105|0);
   if (!($111)) {
    $112 = (($indices) + ($110<<1)|0);
    $jIt$118 = $112;
    while(1) {
     $113 = HEAP16[$jIt$118>>1]|0;
     $114 = $113&65535;
     $115 = (($3) + ($114<<4)|0);
     $116 = (($5) + ($114<<4)|0);
     __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb1EEEvRS2_S5_RKS2_S7_($this,$particle,$115,$restParticle,$116);
     $117 = (($jIt$118) + 2|0);
     $118 = ($117|0)==($106|0);
     if ($118) {
      break;
     } else {
      $jIt$118 = $117;
     }
    }
   }
   $119 = (($k5$022) + 1)|0;
   $exitcond = ($119|0)==(5);
   if ($exitcond) {
    break;
   } else {
    $k5$022 = $119;
   }
  }
  $120 = HEAP16[$iIt$023>>1]|0;
  $121 = $120&65535;
  $122 = (($3) + ($121<<4)|0);
  $123 = HEAP32[$particle>>2]|0;
  HEAP32[$122>>2] = $123;
  $124 = HEAP32[$31>>2]|0;
  $125 = ((($3) + ($121<<4)|0) + 4|0);
  HEAP32[$125>>2] = $124;
  $126 = HEAP32[$32>>2]|0;
  $127 = ((($3) + ($121<<4)|0) + 8|0);
  HEAP32[$127>>2] = $126;
  $128 = HEAP32[$33>>2]|0;
  $129 = ((($3) + ($121<<4)|0) + 12|0);
  HEAP32[$129>>2] = $128;
  $130 = HEAP32[$kFirst>>2]|0;
  $131 = (($130) + 4|0);
  HEAP32[$kFirst>>2] = $131;
  $132 = ($75|0)==($133|0);
  if ($132) {
   break;
  }
  $$pre52 = HEAP32[$131>>2]|0;
  $$pre53 = HEAP32[$kLast>>2]|0;
  $$pre54 = HEAP32[$$pre53>>2]|0;
  $166 = $$pre53;$57 = $$pre52;$66 = $$pre54;$iIt$023 = $75;
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb0EEEvPKjtPKtj($this,$keys,$firstColumnSize,$indices,$collisionDistance) {
 $this = $this|0;
 $keys = $keys|0;
 $firstColumnSize = $firstColumnSize|0;
 $indices = $indices|0;
 $collisionDistance = $collisionDistance|0;
 var $$lcssa = 0, $$lcssa12 = 0, $$pre = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $$pre54 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $iIt$023 = 0, $jIt$03 = 0, $jIt$118 = 0, $k5$022 = 0, $kFirst = 0, $kIt$0 = 0, $kIt$2 = 0, $kIt$2$1 = 0, $kIt$2$2 = 0, $kIt$2$3 = 0, $kIt$3 = 0, $kIt$3$1 = 0, $kIt$3$2 = 0, $kIt$3$3 = 0;
 var $kLast = 0, $particle = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $kFirst = sp + 40|0;
 $kLast = sp;
 $particle = sp + 24|0;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$keys>>2]|0;
 $5 = $4 & 65535;
 $6 = ($5>>>0)>($collisionDistance>>>0);
 $7 = $6 ? $collisionDistance : $5;
 $8 = (($4) + ($collisionDistance))|0;
 $9 = $4 | 65535;
 $10 = ($8>>>0)<($9>>>0);
 $11 = $10 ? $8 : $9;
 HEAP32[$kFirst>>2] = $keys;
 $13 = $4;$kIt$0 = $keys;
 while(1) {
  $12 = ($13>>>0)<($11>>>0);
  $14 = (($kIt$0) + 4|0);
  if (!($12)) {
   break;
  }
  $$pre = HEAP32[$14>>2]|0;
  $13 = $$pre;$kIt$0 = $14;
 }
 $15 = (($4) - ($7))|0;
 HEAP32[$kLast>>2] = $kIt$0;
 $16 = (($15) + 65536)|0;
 $18 = $13;$kIt$2 = $kIt$0;
 while(1) {
  $17 = ($18>>>0)<($16>>>0);
  $19 = (($kIt$2) + 4|0);
  if (!($17)) {
   break;
  }
  $$pre45 = HEAP32[$19>>2]|0;
  $18 = $$pre45;$kIt$2 = $19;
 }
 $20 = (($kFirst) + 4|0);
 HEAP32[$20>>2] = $kIt$2;
 $21 = (($11) + 65536)|0;
 $23 = $18;$kIt$3 = $kIt$2;
 while(1) {
  $22 = ($23>>>0)<($21>>>0);
  $24 = (($kIt$3) + 4|0);
  if (!($22)) {
   break;
  }
  $$pre46 = HEAP32[$24>>2]|0;
  $23 = $$pre46;$kIt$3 = $24;
 }
 $25 = (($kLast) + 4|0);
 HEAP32[$25>>2] = $kIt$3;
 $26 = $firstColumnSize&65535;
 $27 = (($keys) + ($26<<2)|0);
 $28 = (($15) + 16711680)|0;
 $kIt$2$1 = $27;
 while(1) {
  $119 = HEAP32[$kIt$2$1>>2]|0;
  $120 = ($119>>>0)<($28>>>0);
  $121 = (($kIt$2$1) + 4|0);
  if ($120) {
   $kIt$2$1 = $121;
  } else {
   break;
  }
 }
 $122 = (($kFirst) + 8|0);
 HEAP32[$122>>2] = $kIt$2$1;
 $123 = (($11) + 16711680)|0;
 $125 = $119;$kIt$3$1 = $kIt$2$1;
 while(1) {
  $124 = ($125>>>0)<($123>>>0);
  $126 = (($kIt$3$1) + 4|0);
  if (!($124)) {
   break;
  }
  $$pre47 = HEAP32[$126>>2]|0;
  $125 = $$pre47;$kIt$3$1 = $126;
 }
 $127 = (($kLast) + 8|0);
 HEAP32[$127>>2] = $kIt$3$1;
 $128 = (($15) + 16777216)|0;
 $130 = $4;$kIt$2$2 = $keys;
 while(1) {
  $129 = ($130>>>0)<($128>>>0);
  $131 = (($kIt$2$2) + 4|0);
  if (!($129)) {
   break;
  }
  $$pre48 = HEAP32[$131>>2]|0;
  $130 = $$pre48;$kIt$2$2 = $131;
 }
 $132 = (($kFirst) + 12|0);
 HEAP32[$132>>2] = $kIt$2$2;
 $133 = (($11) + 16777216)|0;
 $135 = $130;$kIt$3$2 = $kIt$2$2;
 while(1) {
  $134 = ($135>>>0)<($133>>>0);
  $136 = (($kIt$3$2) + 4|0);
  if (!($134)) {
   break;
  }
  $$pre49 = HEAP32[$136>>2]|0;
  $135 = $$pre49;$kIt$3$2 = $136;
 }
 $137 = (($kLast) + 12|0);
 HEAP32[$137>>2] = $kIt$3$2;
 $138 = (($15) + 16842752)|0;
 $140 = $4;$kIt$2$3 = $keys;
 while(1) {
  $139 = ($140>>>0)<($138>>>0);
  $141 = (($kIt$2$3) + 4|0);
  if (!($139)) {
   break;
  }
  $$pre50 = HEAP32[$141>>2]|0;
  $140 = $$pre50;$kIt$2$3 = $141;
 }
 $142 = (($kFirst) + 16|0);
 HEAP32[$142>>2] = $kIt$2$3;
 $143 = (($11) + 16842752)|0;
 $145 = $140;$kIt$3$3 = $kIt$2$3;
 while(1) {
  $144 = ($145>>>0)<($143>>>0);
  $146 = (($kIt$3$3) + 4|0);
  if (!($144)) {
   break;
  }
  $$pre51 = HEAP32[$146>>2]|0;
  $145 = $$pre51;$kIt$3$3 = $146;
 }
 $147 = (($kLast) + 16|0);
 HEAP32[$147>>2] = $kIt$3$3;
 $148 = (($1) + 232|0);
 $149 = HEAP32[$148>>2]|0;
 $118 = (($indices) + ($149<<1)|0);
 $150 = ($149|0)==(0);
 if ($150) {
  STACKTOP = sp;return;
 }
 $29 = (($particle) + 4|0);
 $30 = (($particle) + 8|0);
 $31 = (($particle) + 12|0);
 $32 = $keys;
 $151 = $kIt$0;$44 = $4;$53 = $13;$iIt$023 = $indices;
 while(1) {
  $33 = HEAP16[$iIt$023>>1]|0;
  $34 = $33&65535;
  $35 = (($3) + ($34<<4)|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$particle>>2] = $36;
  $37 = ((($3) + ($34<<4)|0) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$29>>2] = $38;
  $39 = ((($3) + ($34<<4)|0) + 8|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$30>>2] = $40;
  $41 = ((($3) + ($34<<4)|0) + 12|0);
  $42 = HEAP32[$41>>2]|0;
  HEAP32[$31>>2] = $42;
  $43 = $44 & 65535;
  $45 = ($43>>>0)>($collisionDistance>>>0);
  $46 = $45 ? $collisionDistance : $43;
  $47 = (($44) - ($46))|0;
  $48 = (($44) + ($collisionDistance))|0;
  $49 = $44 | 65535;
  $50 = ($48>>>0)<($49>>>0);
  $51 = $50 ? $48 : $49;
  $52 = ($53>>>0)<($51>>>0);
  if ($52) {
   $55 = $151;
   while(1) {
    $54 = (($55) + 4|0);
    $56 = HEAP32[$54>>2]|0;
    $57 = ($56>>>0)<($51>>>0);
    if ($57) {
     $55 = $54;
    } else {
     break;
    }
   }
   HEAP32[$kLast>>2] = $54;
   $$lcssa = $54;
  } else {
   $$lcssa = $151;
  }
  $58 = $$lcssa;
  $59 = (($58) - ($32))|0;
  $60 = $59 >> 2;
  $61 = (($indices) + ($60<<1)|0);
  $62 = (($iIt$023) + 2|0);
  $63 = ($62|0)==($61|0);
  if ($63) {
   $k5$022 = 1;
  } else {
   $jIt$03 = $62;
   while(1) {
    $64 = HEAP16[$jIt$03>>1]|0;
    $65 = $64&65535;
    $66 = (($3) + ($65<<4)|0);
    __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb0EEEvRS2_S5_RKS2_S7_($this,$particle,$66,0,0);
    $67 = (($jIt$03) + 2|0);
    $68 = ($67|0)==($61|0);
    if ($68) {
     $k5$022 = 1;
     break;
    } else {
     $jIt$03 = $67;
    }
   }
  }
  while(1) {
   $69 = (480056 + ($k5$022<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($47) + ($70))|0;
   $72 = (($kFirst) + ($k5$022<<2)|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74>>>0)<($71>>>0);
   if ($75) {
    $77 = $73;
    while(1) {
     $76 = (($77) + 4|0);
     $78 = HEAP32[$76>>2]|0;
     $79 = ($78>>>0)<($71>>>0);
     if ($79) {
      $77 = $76;
     } else {
      break;
     }
    }
    HEAP32[$72>>2] = $76;
    $94 = $76;
   } else {
    $94 = $73;
   }
   $80 = (($70) + ($51))|0;
   $81 = (($kLast) + ($k5$022<<2)|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83>>>0)<($80>>>0);
   if ($84) {
    $86 = $82;
    while(1) {
     $85 = (($86) + 4|0);
     $87 = HEAP32[$85>>2]|0;
     $88 = ($87>>>0)<($80>>>0);
     if ($88) {
      $86 = $85;
     } else {
      break;
     }
    }
    HEAP32[$81>>2] = $85;
    $$lcssa12 = $85;
   } else {
    $$lcssa12 = $82;
   }
   $89 = $$lcssa12;
   $90 = (($89) - ($32))|0;
   $91 = $90 >> 2;
   $92 = (($indices) + ($91<<1)|0);
   $93 = $94;
   $95 = (($93) - ($32))|0;
   $96 = $95 >> 2;
   $97 = ($96|0)==($91|0);
   if (!($97)) {
    $98 = (($indices) + ($96<<1)|0);
    $jIt$118 = $98;
    while(1) {
     $99 = HEAP16[$jIt$118>>1]|0;
     $100 = $99&65535;
     $101 = (($3) + ($100<<4)|0);
     __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb0EEEvRS2_S5_RKS2_S7_($this,$particle,$101,0,0);
     $102 = (($jIt$118) + 2|0);
     $103 = ($102|0)==($92|0);
     if ($103) {
      break;
     } else {
      $jIt$118 = $102;
     }
    }
   }
   $104 = (($k5$022) + 1)|0;
   $exitcond = ($104|0)==(5);
   if ($exitcond) {
    break;
   } else {
    $k5$022 = $104;
   }
  }
  $105 = HEAP16[$iIt$023>>1]|0;
  $106 = $105&65535;
  $107 = (($3) + ($106<<4)|0);
  $108 = HEAP32[$particle>>2]|0;
  HEAP32[$107>>2] = $108;
  $109 = HEAP32[$29>>2]|0;
  $110 = ((($3) + ($106<<4)|0) + 4|0);
  HEAP32[$110>>2] = $109;
  $111 = HEAP32[$30>>2]|0;
  $112 = ((($3) + ($106<<4)|0) + 8|0);
  HEAP32[$112>>2] = $111;
  $113 = HEAP32[$31>>2]|0;
  $114 = ((($3) + ($106<<4)|0) + 12|0);
  HEAP32[$114>>2] = $113;
  $115 = HEAP32[$kFirst>>2]|0;
  $116 = (($115) + 4|0);
  HEAP32[$kFirst>>2] = $116;
  $117 = ($62|0)==($118|0);
  if ($117) {
   break;
  }
  $$pre52 = HEAP32[$116>>2]|0;
  $$pre53 = HEAP32[$kLast>>2]|0;
  $$pre54 = HEAP32[$$pre53>>2]|0;
  $151 = $$pre53;$44 = $$pre52;$53 = $$pre54;$iIt$023 = $62;
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE23estimateTemporaryMemoryERKNS0_7SwClothE($cloth) {
 $cloth = $cloth|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0;
 var $9 = 0, $cloth$idx = 0, $cloth$idx$val = Math_fround(0), $cloth$idx1 = 0, $cloth$idx1$val = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 492|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($cloth) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $10 = $4;
 } else {
  $10 = $1;
 }
 $cloth$idx = (($cloth) + 480|0);
 $cloth$idx$val = Math_fround(HEAPF32[$cloth$idx>>2]);
 $cloth$idx1 = (($cloth) + 484|0);
 $cloth$idx1$val = Math_fround(HEAPF32[$cloth$idx1>>2]);
 $5 = Math_fround(-$cloth$idx1$val);
 $6 = $cloth$idx$val < $5;
 $7 = $6 ? $cloth$idx$val : $5;
 $8 = $7 > Math_fround(0.0);
 if (!($8)) {
  $20 = 0;
  STACKTOP = sp;return ($20|0);
 }
 $9 = $10 << 2;
 $11 = $10 << 1;
 $12 = (($11) + 2)|0;
 $13 = $12 & -4;
 $14 = (($11) + 2048)|0;
 $15 = (($13) + ($9))|0;
 $16 = (($9) + 4)|0;
 $17 = ($14>>>0)<($16>>>0);
 $18 = $17 ? $16 : $14;
 $19 = (($15) + ($18))|0;
 $20 = $19;
 STACKTOP = sp;return ($20|0);
}
function __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb0EEEvRS2_S5_RKS2_S7_($this,$pos0,$pos1,$pos0rest,$pos1rest) {
 $this = $this|0;
 $pos0 = $pos0|0;
 $pos1 = $pos1|0;
 $pos0rest = $pos0rest|0;
 $pos1rest = $pos1rest|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0;
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$pos1>>2]);
 $1 = Math_fround(HEAPF32[$pos0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($pos1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pos0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($pos1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($pos0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($pos1) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($pos0) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 - $16);
 $18 = Math_fround($2 * $2);
 $19 = Math_fround($7 * $7);
 $20 = Math_fround($18 + $19);
 $21 = Math_fround($12 * $12);
 $22 = Math_fround($20 + $21);
 $23 = (($this) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $22 > $24;
 if ($25) {
  $26 = (($this) + 20|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = $22 > $27;
  if ($28) {
   $29 = (($this) + 24|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = $22 > $30;
   if ($31) {
    $32 = (($this) + 28|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = $22 > $33;
    if ($34) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $35 = (Math_fround(Math_sqrt((Math_fround($22)))));
 $36 = Math_fround(Math_fround(1.0) / $35);
 $37 = Math_fround(HEAPF32[$this>>2]);
 $38 = Math_fround($36 * $37);
 $39 = (($this) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($36 * $40);
 $42 = (($this) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($36 * $43);
 $45 = (($this) + 12|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($36 * $46);
 $48 = HEAP32[480040>>2]|0;
 $49 = HEAP32[((480040 + 4|0))>>2]|0;
 $50 = HEAP32[((480040 + 8|0))>>2]|0;
 $51 = HEAP32[((480040 + 12|0))>>2]|0;
 $52 = (HEAP32[tempDoublePtr>>2]=$48,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $53 = Math_fround($16 + $52);
 $54 = (HEAP32[tempDoublePtr>>2]=$49,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $55 = Math_fround($16 + $54);
 $56 = (HEAP32[tempDoublePtr>>2]=$50,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $57 = Math_fround($16 + $56);
 $58 = (HEAP32[tempDoublePtr>>2]=$51,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $59 = Math_fround($16 + $58);
 $60 = Math_fround($14 + $53);
 $61 = Math_fround($14 + $55);
 $62 = Math_fround($14 + $57);
 $63 = Math_fround($14 + $59);
 $64 = Math_fround(Math_fround(1.0) / $60);
 $65 = Math_fround(Math_fround(1.0) / $61);
 $66 = Math_fround(Math_fround(1.0) / $62);
 $67 = Math_fround(Math_fround(1.0) / $63);
 $68 = (($this) + 32|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($64 * $69);
 $71 = (($this) + 36|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($65 * $72);
 $74 = (($this) + 40|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($66 * $75);
 $77 = (($this) + 44|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($67 * $78);
 $80 = Math_fround($2 * $38);
 $81 = Math_fround($7 * $41);
 $82 = Math_fround($12 * $44);
 $83 = Math_fround($17 * $47);
 $84 = Math_fround($2 - $80);
 $85 = Math_fround($7 - $81);
 $86 = Math_fround($12 - $82);
 $87 = Math_fround($17 - $83);
 $88 = Math_fround($84 * $70);
 $89 = Math_fround($85 * $73);
 $90 = Math_fround($86 * $76);
 $91 = Math_fround($87 * $79);
 $92 = (HEAPF32[tempDoublePtr>>2]=$88,HEAP32[tempDoublePtr>>2]|0);
 $93 = (HEAPF32[tempDoublePtr>>2]=$89,HEAP32[tempDoublePtr>>2]|0);
 $94 = (HEAPF32[tempDoublePtr>>2]=$90,HEAP32[tempDoublePtr>>2]|0);
 $95 = (HEAPF32[tempDoublePtr>>2]=$91,HEAP32[tempDoublePtr>>2]|0);
 $96 = HEAP32[480024>>2]|0;
 $97 = HEAP32[((480024 + 4|0))>>2]|0;
 $98 = HEAP32[((480024 + 8|0))>>2]|0;
 $99 = HEAP32[((480024 + 12|0))>>2]|0;
 $100 = $96 & $92;
 $101 = $97 & $93;
 $102 = $98 & $94;
 $103 = $99 & $95;
 $104 = (HEAP32[tempDoublePtr>>2]=$100,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $105 = Math_fround($16 * $104);
 $106 = (HEAP32[tempDoublePtr>>2]=$101,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $107 = Math_fround($16 * $106);
 $108 = (HEAP32[tempDoublePtr>>2]=$102,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $109 = Math_fround($16 * $108);
 $110 = (HEAP32[tempDoublePtr>>2]=$103,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $111 = Math_fround($16 * $110);
 $112 = Math_fround($105 + $1);
 $113 = Math_fround($107 + $6);
 $114 = Math_fround($109 + $11);
 $115 = Math_fround($16 + $111);
 $116 = (HEAPF32[tempDoublePtr>>2]=$112,HEAP32[tempDoublePtr>>2]|0);
 $117 = (HEAPF32[tempDoublePtr>>2]=$113,HEAP32[tempDoublePtr>>2]|0);
 $118 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
 $119 = (HEAPF32[tempDoublePtr>>2]=$115,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$pos0>>2] = $116;
 HEAP32[$5>>2] = $117;
 HEAP32[$10>>2] = $118;
 HEAP32[$15>>2] = $119;
 $120 = Math_fround($14 * $104);
 $121 = Math_fround($14 * $106);
 $122 = Math_fround($14 * $108);
 $123 = Math_fround($14 * $110);
 $124 = Math_fround($0 - $120);
 $125 = Math_fround($4 - $121);
 $126 = Math_fround(HEAPF32[$8>>2]);
 $127 = Math_fround($126 - $122);
 $128 = Math_fround(HEAPF32[$13>>2]);
 $129 = Math_fround($128 - $123);
 $130 = (HEAPF32[tempDoublePtr>>2]=$124,HEAP32[tempDoublePtr>>2]|0);
 $131 = (HEAPF32[tempDoublePtr>>2]=$125,HEAP32[tempDoublePtr>>2]|0);
 $132 = (HEAPF32[tempDoublePtr>>2]=$127,HEAP32[tempDoublePtr>>2]|0);
 $133 = (HEAPF32[tempDoublePtr>>2]=$129,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$pos1>>2] = $130;
 HEAP32[$3>>2] = $131;
 HEAP32[$8>>2] = $132;
 HEAP32[$13>>2] = $133;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth15SwSelfCollisionI8Scalar4fE16collideParticlesILb1EEEvRS2_S5_RKS2_S7_($this,$pos0,$pos1,$pos0rest,$pos1rest) {
 $this = $this|0;
 $pos0 = $pos0|0;
 $pos1 = $pos1|0;
 $pos0rest = $pos0rest|0;
 $pos1rest = $pos1rest|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0;
 var $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$pos1>>2]);
 $1 = Math_fround(HEAPF32[$pos0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($pos1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pos0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($pos1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($pos0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($pos1) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($pos0) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 - $16);
 $18 = Math_fround($2 * $2);
 $19 = Math_fround($7 * $7);
 $20 = Math_fround($18 + $19);
 $21 = Math_fround($12 * $12);
 $22 = Math_fround($20 + $21);
 $23 = (($this) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $22 > $24;
 if ($25) {
  $26 = (($this) + 20|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = $22 > $27;
  if ($28) {
   $29 = (($this) + 24|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = $22 > $30;
   if ($31) {
    $32 = (($this) + 28|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = $22 > $33;
    if ($34) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $35 = Math_fround(HEAPF32[$pos1rest>>2]);
 $36 = Math_fround(HEAPF32[$pos0rest>>2]);
 $37 = Math_fround($35 - $36);
 $38 = (($pos1rest) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($pos0rest) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($39 - $41);
 $43 = (($pos1rest) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($pos0rest) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($44 - $46);
 $48 = Math_fround($37 * $37);
 $49 = Math_fround($42 * $42);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($47 * $47);
 $52 = Math_fround($50 + $51);
 $53 = $24 > $52;
 if ($53) {
  $54 = (($this) + 20|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = $55 > $52;
  if ($56) {
   $57 = (($this) + 24|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = $58 > $52;
   if ($59) {
    $60 = (($this) + 28|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = $61 > $52;
    if ($62) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $63 = (Math_fround(Math_sqrt((Math_fround($22)))));
 $64 = Math_fround(Math_fround(1.0) / $63);
 $65 = Math_fround(HEAPF32[$this>>2]);
 $66 = Math_fround($64 * $65);
 $67 = (($this) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($64 * $68);
 $70 = (($this) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($64 * $71);
 $73 = (($this) + 12|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($64 * $74);
 $76 = HEAP32[480040>>2]|0;
 $77 = HEAP32[((480040 + 4|0))>>2]|0;
 $78 = HEAP32[((480040 + 8|0))>>2]|0;
 $79 = HEAP32[((480040 + 12|0))>>2]|0;
 $80 = (HEAP32[tempDoublePtr>>2]=$76,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $81 = Math_fround($16 + $80);
 $82 = (HEAP32[tempDoublePtr>>2]=$77,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $83 = Math_fround($16 + $82);
 $84 = (HEAP32[tempDoublePtr>>2]=$78,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $85 = Math_fround($16 + $84);
 $86 = (HEAP32[tempDoublePtr>>2]=$79,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $87 = Math_fround($16 + $86);
 $88 = Math_fround($14 + $81);
 $89 = Math_fround($14 + $83);
 $90 = Math_fround($14 + $85);
 $91 = Math_fround($14 + $87);
 $92 = Math_fround(Math_fround(1.0) / $88);
 $93 = Math_fround(Math_fround(1.0) / $89);
 $94 = Math_fround(Math_fround(1.0) / $90);
 $95 = Math_fround(Math_fround(1.0) / $91);
 $96 = (($this) + 32|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($92 * $97);
 $99 = (($this) + 36|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($93 * $100);
 $102 = (($this) + 40|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($94 * $103);
 $105 = (($this) + 44|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($95 * $106);
 $108 = Math_fround($2 * $66);
 $109 = Math_fround($7 * $69);
 $110 = Math_fround($12 * $72);
 $111 = Math_fround($17 * $75);
 $112 = Math_fround($2 - $108);
 $113 = Math_fround($7 - $109);
 $114 = Math_fround($12 - $110);
 $115 = Math_fround($17 - $111);
 $116 = Math_fround($112 * $98);
 $117 = Math_fround($113 * $101);
 $118 = Math_fround($114 * $104);
 $119 = Math_fround($115 * $107);
 $120 = (HEAPF32[tempDoublePtr>>2]=$116,HEAP32[tempDoublePtr>>2]|0);
 $121 = (HEAPF32[tempDoublePtr>>2]=$117,HEAP32[tempDoublePtr>>2]|0);
 $122 = (HEAPF32[tempDoublePtr>>2]=$118,HEAP32[tempDoublePtr>>2]|0);
 $123 = (HEAPF32[tempDoublePtr>>2]=$119,HEAP32[tempDoublePtr>>2]|0);
 $124 = HEAP32[480024>>2]|0;
 $125 = HEAP32[((480024 + 4|0))>>2]|0;
 $126 = HEAP32[((480024 + 8|0))>>2]|0;
 $127 = HEAP32[((480024 + 12|0))>>2]|0;
 $128 = $124 & $120;
 $129 = $125 & $121;
 $130 = $126 & $122;
 $131 = $127 & $123;
 $132 = (HEAP32[tempDoublePtr>>2]=$128,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $133 = Math_fround($16 * $132);
 $134 = (HEAP32[tempDoublePtr>>2]=$129,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $135 = Math_fround($16 * $134);
 $136 = (HEAP32[tempDoublePtr>>2]=$130,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $137 = Math_fround($16 * $136);
 $138 = (HEAP32[tempDoublePtr>>2]=$131,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $139 = Math_fround($16 * $138);
 $140 = Math_fround($133 + $1);
 $141 = Math_fround($135 + $6);
 $142 = Math_fround($137 + $11);
 $143 = Math_fround($16 + $139);
 $144 = (HEAPF32[tempDoublePtr>>2]=$140,HEAP32[tempDoublePtr>>2]|0);
 $145 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
 $146 = (HEAPF32[tempDoublePtr>>2]=$142,HEAP32[tempDoublePtr>>2]|0);
 $147 = (HEAPF32[tempDoublePtr>>2]=$143,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$pos0>>2] = $144;
 HEAP32[$5>>2] = $145;
 HEAP32[$10>>2] = $146;
 HEAP32[$15>>2] = $147;
 $148 = Math_fround($14 * $132);
 $149 = Math_fround($14 * $134);
 $150 = Math_fround($14 * $136);
 $151 = Math_fround($14 * $138);
 $152 = Math_fround($0 - $148);
 $153 = Math_fround($4 - $149);
 $154 = Math_fround(HEAPF32[$8>>2]);
 $155 = Math_fround($154 - $150);
 $156 = Math_fround(HEAPF32[$13>>2]);
 $157 = Math_fround($156 - $151);
 $158 = (HEAPF32[tempDoublePtr>>2]=$152,HEAP32[tempDoublePtr>>2]|0);
 $159 = (HEAPF32[tempDoublePtr>>2]=$153,HEAP32[tempDoublePtr>>2]|0);
 $160 = (HEAPF32[tempDoublePtr>>2]=$155,HEAP32[tempDoublePtr>>2]|0);
 $161 = (HEAPF32[tempDoublePtr>>2]=$157,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$pos1>>2] = $158;
 HEAP32[$3>>2] = $159;
 HEAP32[$8>>2] = $160;
 HEAP32[$13>>2] = $161;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a4186() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[480024>>2] = -1;
 HEAP32[((480024 + 4|0))>>2] = -1;
 HEAP32[((480024 + 8|0))>>2] = -1;
 HEAP32[((480024 + 12|0))>>2] = 0;
 HEAPF32[480040>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((480040 + 4|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((480040 + 8|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((480040 + 12|0))>>2] = Math_fround(1.1920928955078125E-7);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolverC2EPNS_13PxProfileZoneEPNS_13PxTaskManagerE($this,$profiler,$taskMgr) {
 $this = $this|0;
 $profiler = $profiler|0;
 $taskMgr = $taskMgr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$this>>2] = ((480080 + 8|0));
 HEAP32[$0>>2] = ((480080 + 68|0));
 $1 = (($this) + 8|0);
 $2 = (($this) + 12|0);
 HEAP16[$2>>1] = -1;
 $3 = (($this) + 14|0);
 HEAP16[$3>>1] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$1>>2] = ((434896 + 8|0));
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 24|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$1>>2] = ((480480 + 8|0));
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 44|0);
 $11 = (($this) + 48|0);
 HEAP16[$11>>1] = -1;
 $12 = (($this) + 50|0);
 HEAP16[$12>>1] = 0;
 $13 = (($this) + 52|0);
 HEAP32[$13>>2] = 0;
 HEAP32[$10>>2] = ((434896 + 8|0));
 $14 = (($this) + 56|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 60|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$10>>2] = ((480528 + 8|0));
 $16 = (($this) + 72|0);
 HEAP32[$16>>2] = $profiler;
 $17 = (($this) + 76|0);
 $18 = ($profiler|0)==(0|0);
 if ($18) {
  $23 = -1;
 } else {
  $19 = HEAP32[$profiler>>2]|0;
  $20 = (($19) + 36|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_iii[$21 & 4095]($profiler,480200)|0);
  $23 = $22;
 }
 HEAP16[$17>>1] = $23;
 $24 = (($this) + 80|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($this) + 84|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($this) + 88|0);
 HEAP32[$26>>2] = 1;
 $27 = (($this) + 96|0);
 $28 = (($this) + 28|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;HEAP32[$27+16>>2]=0|0;
 HEAP32[$28>>2] = $this;
 $29 = (($this) + 64|0);
 HEAP32[$29>>2] = $this;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolverD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx5cloth8SwSolverD2Ev($this);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth8SwSolverD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth8SwSolverD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolverD2Ev($this) {
 $this = $this|0;
 var $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((480080 + 8|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = ((480080 + 68|0));
 $2 = (($this) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
 }
 $5 = (($this) + 112|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7|0)!=(0);
 $9 = ($6|0)>(-1);
 $or$cond$i$i = $8 & $9;
 if ($or$cond$i$i) {
  $10 = (($this) + 104|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   FUNCTION_TABLE_vii[$16 & 4095]($13,$11);
  }
 }
 $17 = (($this) + 44|0);
 HEAP32[$17>>2] = ((434896 + 8|0));
 $18 = (($this) + 52|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 36|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + (($22*40)|0)|0);
 $24 = ($22|0)>(0);
 if ($24) {
  $$01$i$i$i = $20;
  while(1) {
   $25 = HEAP32[$$01$i$i$i>>2]|0;
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vi[$26 & 4095]($$01$i$i$i);
   $27 = (($$01$i$i$i) + 40|0);
   $28 = ($27>>>0)<($23>>>0);
   if ($28) {
    $$01$i$i$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = (($this) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 2147483647;
 $32 = ($31|0)!=(0);
 $33 = ($30|0)>(-1);
 $or$cond$i$i1 = $32 & $33;
 if (!($or$cond$i$i1)) {
  $35 = (($this) + 8|0);
  HEAP32[$35>>2] = ((434896 + 8|0));
  $36 = (($this) + 16|0);
  HEAP32[$36>>2] = 0;
  HEAP32[$this>>2] = ((478568 + 8|0));
  __ZN5physx5cloth10deallocateEPv($this);
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$19>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($19,$34);
 $35 = (($this) + 8|0);
 HEAP32[$35>>2] = ((434896 + 8|0));
 $36 = (($this) + 16|0);
 HEAP32[$36>>2] = 0;
 HEAP32[$this>>2] = ((478568 + 8|0));
 __ZN5physx5cloth10deallocateEPv($this);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth8SwSolverD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth8SwSolverD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver17EndSimulationTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver19StartSimulationTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver8addClothEPNS0_5ClothE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $$idx$pre$phiZZ2D = 0, $$idx$val = 0, $$idx1$val = 0, $$idx1$val$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 8|0;
 $3 = (($cloth) + 12|0);
 $4 = (($this) + 32|0);
 $5 = (($this) + 44|0);
 $6 = (($2) + 4|0);
 HEAP16[$6>>1] = -1;
 $7 = (($2) + 6|0);
 HEAP16[$7>>1] = 0;
 $8 = (($2) + 8|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$2>>2] = ((434896 + 8|0));
 $9 = (($2) + 12|0);
 HEAP32[$9>>2] = 0;
 $10 = (($2) + 16|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$2>>2] = ((480392 + 8|0));
 $11 = (($2) + 20|0);
 HEAP32[$11>>2] = $3;
 $12 = (($2) + 24|0);
 HEAP32[$12>>2] = $5;
 $13 = (($2) + 28|0);
 HEAP32[$13>>2] = 0;
 $14 = (($2) + 32|0);
 HEAP32[$14>>2] = 0;
 $15 = (($2) + 36|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 40|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2147483647;
 $19 = (($this) + 36|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if (!($21)) {
  (__ZN5physx6shdfnd5ArrayINS_5cloth8SwSolver22CpuClothSimulationTaskENS0_9AllocatorEE15growAndPushBackERKS4_($4,$2)|0);
  $$idx1$val$pre = HEAP32[$19>>2]|0;
  $$idx$pre$phiZZ2D = $4;$$idx1$val = $$idx1$val$pre;
  $$idx$val = HEAP32[$$idx$pre$phiZZ2D>>2]|0;
  HEAP32[$1>>2] = 2347;
  __ZN5physx6shdfnd4sortINS_5cloth8SwSolver22CpuClothSimulationTaskEPFbRKS4_S6_ENS0_19ReflectionAllocatorIS4_EEEEvPT_jRKT0_RKT1_($$idx$val,$$idx1$val,$1,$0);
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$4>>2]|0;
 $23 = (($22) + (($20*40)|0)|0);
 $24 = ($23|0)==(0|0);
 if ($24) {
  $43 = $20;
 } else {
  $25 = ((($22) + (($20*40)|0)|0) + 4|0);
  $26 = $6;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = $25;
  $33 = $32;
  HEAP16[$33>>1]=$28&65535;HEAP16[$33+2>>1]=$28>>>16;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP16[$35>>1]=$31&65535;HEAP16[$35+2>>1]=$31>>>16;
  HEAP32[$23>>2] = ((434896 + 8|0));
  $36 = ((($22) + (($20*40)|0)|0) + 12|0);
  $37 = HEAP32[$9>>2]|0;
  HEAP32[$36>>2] = $37;
  $38 = ((($22) + (($20*40)|0)|0) + 16|0);
  $39 = HEAP32[$10>>2]|0;
  HEAP32[$38>>2] = $39;
  $40 = HEAP32[$9>>2]|0;
  HEAP32[$36>>2] = $40;
  HEAP32[$23>>2] = ((480392 + 8|0));
  $41 = ((($22) + (($20*40)|0)|0) + 20|0);
  ;HEAP32[$41+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$41+16>>2]=HEAP32[$11+16>>2]|0;
  $$pre$i = HEAP32[$19>>2]|0;
  $43 = $$pre$i;
 }
 $42 = (($43) + 1)|0;
 HEAP32[$19>>2] = $42;
 $$idx$pre$phiZZ2D = $4;$$idx1$val = $42;
 $$idx$val = HEAP32[$$idx$pre$phiZZ2D>>2]|0;
 HEAP32[$1>>2] = 2347;
 __ZN5physx6shdfnd4sortINS_5cloth8SwSolver22CpuClothSimulationTaskEPFbRKS4_S6_ENS0_19ReflectionAllocatorIS4_EEEEvPT_jRKT0_RKT1_($$idx$val,$$idx1$val,$1,$0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver22CpuClothSimulationTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth8SwSolver8addClothEPNS0_5ClothE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth8SwSolver8addClothEPNS0_5ClothE($0,$cloth);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver11removeClothEPNS0_5ClothE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $$idx$val = 0, $$idx2$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tIt$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($cloth) + 12|0);
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($6*40)|0)|0);
 $8 = ($6|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $tIt$04 = $4;
 }
 while(1) {
  $11 = (($tIt$04) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($2|0);
  $10 = (($tIt$04) + 40|0);
  if ($13) {
   break;
  }
  $9 = ($10|0)==($7|0);
  if ($9) {
   label = 5;
   break;
  } else {
   $tIt$04 = $10;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return;
 }
 $14 = (($tIt$04) + 32|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx5cloth10deallocateEPv($15);
 $16 = HEAP32[$3>>2]|0;
 $17 = $tIt$04;
 $18 = $16;
 $19 = (($17) - ($18))|0;
 $20 = (($19|0) / 40)&-1;
 $21 = HEAP32[$5>>2]|0;
 $22 = (($21) + -1)|0;
 HEAP32[$5>>2] = $22;
 $23 = ((($16) + (($20*40)|0)|0) + 4|0);
 $24 = ((($16) + (($22*40)|0)|0) + 4|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAPU16[$26>>1]|(HEAPU16[$26+2>>1]<<16);
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAPU16[$29>>1]|(HEAPU16[$29+2>>1]<<16);
 $31 = $23;
 $32 = $31;
 HEAP16[$32>>1]=$27&65535;HEAP16[$32+2>>1]=$27>>>16;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP16[$34>>1]=$30&65535;HEAP16[$34+2>>1]=$30>>>16;
 $35 = ((($16) + (($22*40)|0)|0) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($16) + (($20*40)|0)|0) + 12|0);
 HEAP32[$37>>2] = $36;
 $38 = ((($16) + (($22*40)|0)|0) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($16) + (($20*40)|0)|0) + 16|0);
 HEAP32[$40>>2] = $39;
 $41 = ((($16) + (($20*40)|0)|0) + 20|0);
 $42 = ((($16) + (($22*40)|0)|0) + 20|0);
 ;HEAP32[$41+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$42+12>>2]|0;HEAP32[$41+16>>2]=HEAP32[$42+16>>2]|0;
 $43 = HEAP32[$5>>2]|0;
 $44 = HEAP32[$3>>2]|0;
 $45 = (($44) + (($43*40)|0)|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 FUNCTION_TABLE_vi[$47 & 4095]($45);
 $$idx$val = HEAP32[$3>>2]|0;
 $$idx2$val = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = 2347;
 __ZN5physx6shdfnd4sortINS_5cloth8SwSolver22CpuClothSimulationTaskEPFbRKS4_S6_ENS0_19ReflectionAllocatorIS4_EEEEvPT_jRKT0_RKT1_($$idx$val,$$idx2$val,$1,$0);
 STACKTOP = sp;return;
}
function __ZThn4_N5physx5cloth8SwSolver11removeClothEPNS0_5ClothE($this,$cloth) {
 $this = $this|0;
 $cloth = $cloth|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 __ZN5physx5cloth8SwSolver11removeClothEPNS0_5ClothE($0,$cloth);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver8simulateEfRNS_10PxBaseTaskE($this,$dt,$continuation) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $continuation = $continuation|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = HEAP32[$continuation>>2]|0;
  $4 = (($3) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($continuation);
  $$0 = $continuation;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($this) + 44|0);
 $7 = (($this) + 60|0);
 HEAP32[$7>>2] = 1;
 $8 = (($this) + 56|0);
 HEAP32[$8>>2] = $continuation;
 $9 = ($continuation|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$continuation>>2]|0;
  $11 = (($10) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($continuation);
  $13 = HEAP32[$8>>2]|0;
  $14 = (($13) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 52|0);
  HEAP32[$16>>2] = $15;
 }
 $17 = (($this) + 68|0);
 HEAPF32[$17>>2] = $dt;
 $18 = (($this) + 24|0);
 HEAP32[$18>>2] = 1;
 $19 = (($this) + 20|0);
 HEAP32[$19>>2] = $6;
 $20 = HEAP32[$6>>2]|0;
 $21 = (($20) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($6);
 $23 = HEAP32[$19>>2]|0;
 $24 = (($23) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 16|0);
 HEAP32[$26>>2] = $25;
 $27 = HEAP32[$6>>2]|0;
 $28 = (($27) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vi[$29 & 4095]($6);
 $30 = (($this) + 8|0);
 $$0 = $30;
 STACKTOP = sp;return ($$0|0);
}
function __ZThn4_N5physx5cloth8SwSolver8simulateEfRNS_10PxBaseTaskE($this,$dt,$continuation) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $continuation = $continuation|0;
 var $$0$i = 0, $$c = 0, $$c1 = 0, $$c2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $continuation$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = HEAP32[$continuation>>2]|0;
  $5 = (($4) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($continuation);
  $$0$i = $continuation;
  STACKTOP = sp;return ($$0$i|0);
 }
 $7 = (($0) + 44|0);
 $8 = (($0) + 60|0);
 HEAP32[$8>>2] = 1;
 $9 = (($0) + 56|0);
 $continuation$c = $continuation;
 HEAP32[$9>>2] = $continuation$c;
 $10 = ($continuation|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$continuation>>2]|0;
  $12 = (($11) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($continuation);
  $14 = HEAP32[$9>>2]|0;
  $15 = (($14) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($0) + 52|0);
  $$c = $16;
  HEAP32[$17>>2] = $$c;
 }
 $18 = (($0) + 68|0);
 HEAPF32[$18>>2] = $dt;
 $19 = (($0) + 24|0);
 HEAP32[$19>>2] = 1;
 $20 = (($0) + 20|0);
 $$c1 = $7;
 HEAP32[$20>>2] = $$c1;
 $21 = HEAP32[$7>>2]|0;
 $22 = (($21) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vi[$23 & 4095]($7);
 $24 = HEAP32[$20>>2]|0;
 $25 = (($24) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($0) + 16|0);
 $$c2 = $26;
 HEAP32[$27>>2] = $$c2;
 $28 = HEAP32[$7>>2]|0;
 $29 = (($28) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vi[$30 & 4095]($7);
 $31 = (($0) + 8|0);
 $$0$i = $31;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx5cloth8SwSolver14interCollisionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0);
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0;
 var $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0;
 var $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocator = 0, $collider = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $0 = sp + 240|0;
 $1 = sp;
 $2 = sp + 317|0;
 $3 = sp + 316|0;
 $allocator = sp + 224|0;
 $collider = sp + 80|0;
 $4 = (($this) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 80|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $8 == Math_fround(0.0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 104|0);
 __ZN5physx6shdfnd5ArrayINS_5cloth20SwInterCollisionDataENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($10,0,$0);
 $11 = (($this) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = (($this) + 32|0);
  $15 = (($1) + 4|0);
  $16 = (($1) + 8|0);
  $17 = (($1) + 12|0);
  $18 = (($1) + 16|0);
  $19 = (($1) + 20|0);
  $20 = (($1) + 24|0);
  $21 = (($1) + 28|0);
  $22 = (($1) + 32|0);
  $23 = (($1) + 36|0);
  $24 = (($1) + 40|0);
  $25 = (($1) + 44|0);
  $26 = (($1) + 48|0);
  $27 = (($1) + 52|0);
  $28 = (($1) + 56|0);
  $29 = (($1) + 60|0);
  $30 = (($1) + 64|0);
  $31 = (($1) + 68|0);
  $32 = (($1) + 72|0);
  $i$01 = 0;
  while(1) {
   $33 = HEAP32[$14>>2]|0;
   $34 = ((($33) + (($i$01*40)|0)|0) + 20|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($33) + (($i$01*40)|0)|0) + 36|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = (($35) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($35) + 20|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($35) + 492|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0);
   if ($44) {
    $45 = (($35) + 12|0);
    $46 = HEAP32[$45>>2]|0;
    $51 = $46;$52 = 0;
   } else {
    $47 = (($35) + 488|0);
    $48 = HEAP32[$47>>2]|0;
    $51 = $43;$52 = $48;
   }
   $49 = (($35) + 532|0);
   $50 = HEAP32[$49>>2]|0;
   HEAP32[$1>>2] = $39;
   HEAP32[$15>>2] = $41;
   HEAP32[$16>>2] = $51;
   HEAP32[$17>>2] = $52;
   $53 = (($35) + 148|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   HEAPF32[$18>>2] = $54;
   $55 = (($35) + 152|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   HEAPF32[$19>>2] = $56;
   $57 = (($35) + 156|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   HEAPF32[$20>>2] = $58;
   $59 = (($35) + 160|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   HEAPF32[$21>>2] = $60;
   $61 = (($35) + 164|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   HEAPF32[$22>>2] = $62;
   $63 = (($35) + 168|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   HEAPF32[$23>>2] = $64;
   $65 = (($35) + 172|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   HEAPF32[$24>>2] = $66;
   $67 = (($35) + 32|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   HEAPF32[$25>>2] = $68;
   $69 = (($35) + 36|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   HEAPF32[$26>>2] = $70;
   $71 = (($35) + 40|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   HEAPF32[$27>>2] = $72;
   $73 = (($35) + 44|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   HEAPF32[$28>>2] = $74;
   $75 = (($35) + 48|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   HEAPF32[$29>>2] = $76;
   $77 = (($35) + 52|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   HEAPF32[$30>>2] = $78;
   HEAPF32[$31>>2] = $37;
   HEAP32[$32>>2] = $50;
   (__ZN5physx6shdfnd5ArrayINS_5cloth20SwInterCollisionDataENS0_19ReflectionAllocatorIS3_EEE8pushBackERKS3_($10,$1)|0);
   $79 = (($i$01) + 1)|0;
   $80 = HEAP32[$11>>2]|0;
   $81 = ($79>>>0)<($80>>>0);
   if ($81) {
    $i$01 = $79;
   } else {
    break;
   }
  }
 }
 $82 = HEAP32[$10>>2]|0;
 $83 = (($this) + 108|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (__ZN5physx5cloth16SwInterCollisionI8Scalar4fE23estimateTemporaryMemoryEPNS0_20SwInterCollisionDataEj($82,$84)|0);
 $86 = (($this) + 100|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87>>>0)<($85>>>0);
 $89 = (($this) + 96|0);
 $90 = HEAP32[$89>>2]|0;
 if ($88) {
  $91 = ($90|0)==(0|0);
  if (!($91)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$90);
  }
  $92 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$85,480232,256)|0);
  HEAP32[$89>>2] = $92;
  HEAP32[$86>>2] = $85;
  $93 = $92;$95 = $85;
 } else {
  $93 = $90;$95 = $87;
 }
 HEAP32[$allocator>>2] = $93;
 $94 = (($allocator) + 4|0);
 HEAP32[$94>>2] = $95;
 $96 = (($allocator) + 8|0);
 HEAP32[$96>>2] = $93;
 $97 = (($allocator) + 12|0);
 HEAP32[$97>>2] = 0;
 $98 = HEAP32[$10>>2]|0;
 $99 = HEAP32[$83>>2]|0;
 $100 = Math_fround(HEAPF32[$7>>2]);
 $101 = (($this) + 84|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = HEAP32[$4>>2]|0;
 $104 = (($this) + 92|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($this) + 72|0);
 $107 = HEAP32[$106>>2]|0;
 __ZN5physx5cloth16SwInterCollisionI8Scalar4fEC1EPKNS0_20SwInterCollisionDataEjffjPFbPvS7_ER14StackAllocatorILj16EEPNS_13PxProfileZoneE($collider,$98,$99,$100,$102,$103,$105,$allocator,$107);
 __ZN5physx5cloth16SwInterCollisionI8Scalar4fEclEv($collider);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth20SwInterCollisionDataENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_5cloth20SwInterCollisionDataENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($size*76)|0)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + (($6*76)|0)|0);
 $10 = (($a) + 16|0);
 $11 = (($a) + 20|0);
 $12 = (($a) + 24|0);
 $13 = (($a) + 28|0);
 $14 = (($a) + 32|0);
 $15 = (($a) + 36|0);
 $16 = (($a) + 40|0);
 $17 = (($a) + 44|0);
 $18 = (($a) + 48|0);
 $19 = (($a) + 52|0);
 $20 = (($a) + 56|0);
 $21 = (($a) + 60|0);
 $22 = (($a) + 64|0);
 $23 = (($a) + 68|0);
 $$01$i = $9;
 while(1) {
  $24 = ($$01$i|0)==(0|0);
  if (!($24)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;
   $25 = (($$01$i) + 16|0);
   $26 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$25>>2] = $26;
   $27 = (($$01$i) + 20|0);
   $28 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$27>>2] = $28;
   $29 = (($$01$i) + 24|0);
   $30 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$29>>2] = $30;
   $31 = (($$01$i) + 28|0);
   $32 = Math_fround(HEAPF32[$13>>2]);
   HEAPF32[$31>>2] = $32;
   $33 = (($$01$i) + 32|0);
   $34 = Math_fround(HEAPF32[$14>>2]);
   HEAPF32[$33>>2] = $34;
   $35 = (($$01$i) + 36|0);
   $36 = Math_fround(HEAPF32[$15>>2]);
   HEAPF32[$35>>2] = $36;
   $37 = (($$01$i) + 40|0);
   $38 = Math_fround(HEAPF32[$16>>2]);
   HEAPF32[$37>>2] = $38;
   $39 = (($$01$i) + 44|0);
   $40 = Math_fround(HEAPF32[$17>>2]);
   HEAPF32[$39>>2] = $40;
   $41 = (($$01$i) + 48|0);
   $42 = Math_fround(HEAPF32[$18>>2]);
   HEAPF32[$41>>2] = $42;
   $43 = (($$01$i) + 52|0);
   $44 = Math_fround(HEAPF32[$19>>2]);
   HEAPF32[$43>>2] = $44;
   $45 = (($$01$i) + 56|0);
   $46 = Math_fround(HEAPF32[$20>>2]);
   HEAPF32[$45>>2] = $46;
   $47 = (($$01$i) + 60|0);
   $48 = Math_fround(HEAPF32[$21>>2]);
   HEAPF32[$47>>2] = $48;
   $49 = (($$01$i) + 64|0);
   $50 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$49>>2] = $50;
   $51 = (($$01$i) + 68|0);
   $52 = $23;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = $51;
   $59 = $58;
   HEAP32[$59>>2] = $54;
   $60 = (($58) + 4)|0;
   $61 = $60;
   HEAP32[$61>>2] = $57;
  }
  $62 = (($$01$i) + 76|0);
  $63 = ($62>>>0)<($7>>>0);
  if ($63) {
   $$01$i = $62;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth20SwInterCollisionDataENS0_19ReflectionAllocatorIS3_EEE8pushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$0 = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if (!($5)) {
  $6 = (__ZN5physx6shdfnd5ArrayINS_5cloth20SwInterCollisionDataENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + (($4*76)|0)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $62 = $4;$64 = $7;
 } else {
  ;HEAP32[$8+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$a+12>>2]|0;
  $10 = ((($7) + (($4*76)|0)|0) + 16|0);
  $11 = (($a) + 16|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$10>>2] = $12;
  $13 = ((($7) + (($4*76)|0)|0) + 20|0);
  $14 = (($a) + 20|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$13>>2] = $15;
  $16 = ((($7) + (($4*76)|0)|0) + 24|0);
  $17 = (($a) + 24|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$16>>2] = $18;
  $19 = ((($7) + (($4*76)|0)|0) + 28|0);
  $20 = (($a) + 28|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$19>>2] = $21;
  $22 = ((($7) + (($4*76)|0)|0) + 32|0);
  $23 = (($a) + 32|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$22>>2] = $24;
  $25 = ((($7) + (($4*76)|0)|0) + 36|0);
  $26 = (($a) + 36|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  HEAPF32[$25>>2] = $27;
  $28 = ((($7) + (($4*76)|0)|0) + 40|0);
  $29 = (($a) + 40|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  HEAPF32[$28>>2] = $30;
  $31 = ((($7) + (($4*76)|0)|0) + 44|0);
  $32 = (($a) + 44|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$31>>2] = $33;
  $34 = ((($7) + (($4*76)|0)|0) + 48|0);
  $35 = (($a) + 48|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$34>>2] = $36;
  $37 = ((($7) + (($4*76)|0)|0) + 52|0);
  $38 = (($a) + 52|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[$37>>2] = $39;
  $40 = ((($7) + (($4*76)|0)|0) + 56|0);
  $41 = (($a) + 56|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$40>>2] = $42;
  $43 = ((($7) + (($4*76)|0)|0) + 60|0);
  $44 = (($a) + 60|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$43>>2] = $45;
  $46 = ((($7) + (($4*76)|0)|0) + 64|0);
  $47 = (($a) + 64|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  HEAPF32[$46>>2] = $48;
  $49 = ((($7) + (($4*76)|0)|0) + 68|0);
  $50 = (($a) + 68|0);
  $51 = $50;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre = HEAP32[$3>>2]|0;
  $$pre1 = HEAP32[$this>>2]|0;
  $62 = $$pre;$64 = $$pre1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$3>>2] = $61;
 $63 = (($64) + (($62*76)|0)|0);
 $$0 = $63;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx5cloth8SwSolver19StartSimulationTask11runInternalEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $15 = $1;
 } else {
  $5 = (($3) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($1) + 76|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = $1;
  $12 = ($11|0)<(0);
  $13 = $12 << 31 >> 31;
  FUNCTION_TABLE_viiiii[$8 & 255]($5,$10,$11,$13,$11);
  $$pre = HEAP32[$0>>2]|0;
  $15 = $$pre;
 }
 $14 = (($15) + 32|0);
 $16 = HEAP32[$14>>2]|0;
 $17 = (($15) + 36|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + (($18*40)|0)|0);
 $20 = ($18|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 12|0);
 $tIt$01 = $16;
 while(1) {
  $22 = (($tIt$01) + 20|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 524|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 516|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($25>>>0)<($27>>>0);
  if ($28) {
   $29 = HEAP32[$21>>2]|0;
   $30 = (($tIt$01) + 16|0);
   HEAP32[$30>>2] = 1;
   $31 = (($tIt$01) + 12|0);
   HEAP32[$31>>2] = $29;
   $32 = ($29|0)==(0|0);
   if (!($32)) {
    $33 = HEAP32[$29>>2]|0;
    $34 = (($33) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    FUNCTION_TABLE_vi[$35 & 4095]($29);
    $36 = HEAP32[$31>>2]|0;
    $37 = (($36) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($tIt$01) + 8|0);
    HEAP32[$39>>2] = $38;
   }
   $40 = HEAP32[$tIt$01>>2]|0;
   $41 = (($40) + 20|0);
   $42 = HEAP32[$41>>2]|0;
   FUNCTION_TABLE_vi[$42 & 4095]($tIt$01);
  }
  $43 = (($tIt$01) + 40|0);
  $44 = ($43|0)==($19|0);
  if ($44) {
   break;
  } else {
   $tIt$01 = $43;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth8SwSolver19StartSimulationTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (480312|0);
}
function __ZN5physx5cloth8SwSolver17EndSimulationTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx5cloth8SwSolver14interCollisionEv($1);
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($4) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($2) + 76|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = $2;
 $13 = ($12|0)<(0);
 $14 = $13 << 31 >> 31;
 FUNCTION_TABLE_viiiii[$9 & 255]($6,$11,$12,$14,$12);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth8SwSolver17EndSimulationTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (480352|0);
}
function __ZN5physx5cloth8SwSolver22CpuClothSimulationTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $allocator$i = 0, $data$i = 0, $factory = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1072|0;
 $data$i = sp;
 $allocator$i = sp + 1056|0;
 $0 = sp + 256|0;
 $factory = sp + 992|0;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN5physx5cloth14SwSolverKernelI8Scalar4fE23estimateTemporaryMemoryERKNS0_7SwClothE($2)|0);
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)<($3>>>0);
 if ($6) {
  $7 = (($this) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  __ZN5physx5cloth10deallocateEPv($8);
  $9 = (__ZN5physx5cloth8allocateEj($3)|0);
  HEAP32[$7>>2] = $9;
  HEAP32[$4>>2] = $3;
 }
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = $13 == Math_fround(0.0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$1>>2]|0;
 __ZN5physx5cloth21IterationStateFactoryC2INS0_7SwClothEEERT_f($factory,$15,$13);
 $16 = (($factory) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 36|0);
 HEAPF32[$18>>2] = $17;
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$10>>2]|0;
 $21 = (($20) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 72|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 32|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$4>>2]|0;
 $28 = (($19) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 __ZN5physx5cloth11SwClothDataC2ERNS0_7SwClothERKNS0_8SwFabricE($data$i,$19,$29);
 HEAP32[$allocator$i>>2] = $26;
 $30 = (($allocator$i) + 4|0);
 HEAP32[$30>>2] = $27;
 $31 = (($allocator$i) + 8|0);
 HEAP32[$31>>2] = $26;
 $32 = (($allocator$i) + 12|0);
 HEAP32[$32>>2] = 0;
 __ZN5physx5cloth14SwSolverKernelI8Scalar4fEC1ERKNS0_7SwClothERNS0_11SwClothDataER14StackAllocatorILj16EERNS0_21IterationStateFactoryEPNS_13PxProfileZoneE($0,$19,$data$i,$allocator$i,$factory,$24);
 __ZN5physx5cloth14SwSolverKernelI8Scalar4fEclEv($0);
 $33 = (($0) + 12|0);
 __ZN5physx5cloth11SwCollisionI8Scalar4fED1Ev($33);
 __ZNK5physx5cloth11SwClothData9reconcileERNS0_7SwClothE($data$i,$19);
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth8SwSolver22CpuClothSimulationTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (480440|0);
}
function __ZN5physx5cloth8SwSolver22CpuClothSimulationTask7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 284|0);
 $7 = (($5) + 288|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($5) + 272|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$6>>2]|0;
  HEAP32[$10>>2] = $12;
  HEAP32[$6>>2] = $11;
  $13 = (($5) + 276|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$13>>2] = $8;
  HEAP32[$7>>2] = $14;
  $15 = (($5) + 280|0);
  $16 = (($5) + 292|0);
  $17 = HEAP32[$15>>2]|0;
  $18 = HEAP32[$16>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$16>>2] = $17;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($6,0,$0);
 }
 $19 = (($5) + 320|0);
 $20 = (($5) + 324|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($5) + 308|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$19>>2]|0;
  HEAP32[$23>>2] = $25;
  HEAP32[$19>>2] = $24;
  $26 = (($5) + 312|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$26>>2] = $21;
  HEAP32[$20>>2] = $27;
  $28 = (($5) + 316|0);
  $29 = (($5) + 328|0);
  $30 = HEAP32[$28>>2]|0;
  $31 = HEAP32[$29>>2]|0;
  HEAP32[$28>>2] = $31;
  HEAP32[$29>>2] = $30;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($19,0,$0);
 }
 $32 = (($5) + 368|0);
 $33 = (($5) + 372|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($5) + 356|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$32>>2]|0;
  HEAP32[$36>>2] = $38;
  HEAP32[$32>>2] = $37;
  $39 = (($5) + 360|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$39>>2] = $34;
  HEAP32[$33>>2] = $40;
  $41 = (($5) + 364|0);
  $42 = (($5) + 376|0);
  $43 = HEAP32[$41>>2]|0;
  $44 = HEAP32[$42>>2]|0;
  HEAP32[$41>>2] = $44;
  HEAP32[$42>>2] = $43;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($32,0,$1);
 }
 $45 = (($5) + 404|0);
 $46 = (($5) + 408|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0);
 if (!($48)) {
  $49 = (($5) + 392|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = HEAP32[$45>>2]|0;
  HEAP32[$49>>2] = $51;
  HEAP32[$45>>2] = $50;
  $52 = (($5) + 396|0);
  $53 = HEAP32[$52>>2]|0;
  HEAP32[$52>>2] = $47;
  HEAP32[$46>>2] = $53;
  $54 = (($5) + 400|0);
  $55 = (($5) + 412|0);
  $56 = HEAP32[$54>>2]|0;
  $57 = HEAP32[$55>>2]|0;
  HEAP32[$54>>2] = $57;
  HEAP32[$55>>2] = $56;
  __ZN5physx6shdfnd5ArrayINS_6PxVec4ENS0_16AlignedAllocatorILj16ENS0_9AllocatorEEEE6resizeEjRKS2_($45,0,$2);
 }
 $58 = (($5) + 428|0);
 $59 = (($5) + 432|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0);
 if ($61) {
  $71 = (($this) + 24|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = HEAP32[$72>>2]|0;
  $74 = (($73) + 20|0);
  $75 = HEAP32[$74>>2]|0;
  FUNCTION_TABLE_vi[$75 & 4095]($72);
  STACKTOP = sp;return;
 }
 $62 = (($5) + 416|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$58>>2]|0;
 HEAP32[$62>>2] = $64;
 HEAP32[$58>>2] = $63;
 $65 = (($5) + 420|0);
 $66 = HEAP32[$65>>2]|0;
 HEAP32[$65>>2] = $60;
 HEAP32[$59>>2] = $66;
 $67 = (($5) + 424|0);
 $68 = (($5) + 436|0);
 $69 = HEAP32[$67>>2]|0;
 $70 = HEAP32[$68>>2]|0;
 HEAP32[$67>>2] = $70;
 HEAP32[$68>>2] = $69;
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_9AllocatorEE6resizeEjRKS2_($58,0,$3);
 $71 = (($this) + 24|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73) + 20|0);
 $75 = HEAP32[$74>>2]|0;
 FUNCTION_TABLE_vi[$75 & 4095]($72);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver19StartSimulationTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver17EndSimulationTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth8SwSolver25setInterCollisionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 HEAPF32[$0>>2] = $distance;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth8SwSolver25getInterCollisionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth8SwSolver26setInterCollisionStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 HEAPF32[$0>>2] = $stiffness;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth8SwSolver26getInterCollisionStiffnessEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx5cloth8SwSolver29setInterCollisionNbIterationsEj($this,$nbIterations) {
 $this = $this|0;
 $nbIterations = $nbIterations|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 HEAP32[$0>>2] = $nbIterations;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth8SwSolver29getInterCollisionNbIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx5cloth8SwSolver23setInterCollisionFilterEPFbPvS2_E($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 HEAP32[$0>>2] = $filter;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth8SwSolver8hasErrorEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZThn4_N5physx5cloth8SwSolver25setInterCollisionDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 80|0);
 HEAPF32[$1>>2] = $distance;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth8SwSolver25getInterCollisionDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 80|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 STACKTOP = sp;return (Math_fround($2));
}
function __ZThn4_N5physx5cloth8SwSolver26setInterCollisionStiffnessEf($this,$stiffness) {
 $this = $this|0;
 $stiffness = Math_fround($stiffness);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 84|0);
 HEAPF32[$1>>2] = $stiffness;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth8SwSolver26getInterCollisionStiffnessEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 84|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 STACKTOP = sp;return (Math_fround($2));
}
function __ZThn4_N5physx5cloth8SwSolver29setInterCollisionNbIterationsEj($this,$nbIterations) {
 $this = $this|0;
 $nbIterations = $nbIterations|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 88|0);
 HEAP32[$1>>2] = $nbIterations;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth8SwSolver29getInterCollisionNbIterationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZThn4_N5physx5cloth8SwSolver23setInterCollisionFilterEPFbPvS2_E($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $0 = 0, $1 = 0, $filter$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 92|0);
 $filter$c = $filter;
 HEAP32[$1>>2] = $filter$c;
 STACKTOP = sp;return;
}
function __ZThn4_NK5physx5cloth8SwSolver8hasErrorEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx5cloth8SwSolver22CpuClothSimulationTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth21IterationStateFactoryC2INS0_7SwClothEEERT_f($this,$cloth,$frameDt) {
 $this = $this|0;
 $cloth = $cloth|0;
 $frameDt = Math_fround($frameDt);
 var $$sum$i = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0.0, $169 = 0.0;
 var $17 = Math_fround(0), $170 = 0.0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0;
 var $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0;
 var $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $countHi$06$i = 0, $countHi$1$i = 0, $countLo$05$i = 0, $countLo$1$i = 0, $end$01$i = 0, $end$1$i = 0;
 var $i$07$i = 0, $it$08$i = 0, $it$12$i = 0, $it$2$i = 0, $ramp$0$lcssa$i = Math_fround(0), $ramp$03$i = Math_fround(0), $sum$09$i = Math_fround(0), $temp$04$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cloth) + 140|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * $frameDt);
 $3 = Math_fround($2 + Math_fround(0.5));
 $4 = (~~(($3)));
 $5 = ($4|0)>(1);
 $6 = $5 ? $4 : 1;
 HEAP32[$this>>2] = $6;
 $7 = (Math_fround(($6|0)));
 $8 = Math_fround(Math_fround(1.0) / $7);
 $9 = (($this) + 4|0);
 HEAPF32[$9>>2] = $8;
 $10 = Math_fround($8 * $frameDt);
 $11 = (($this) + 8|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($cloth) + 228|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = $13 != Math_fround(0.0);
 if ($14) {
  $15 = Math_fround($10 / $13);
  $17 = $15;
 } else {
  $17 = Math_fround(1.0);
 }
 $16 = (($this) + 12|0);
 HEAPF32[$16>>2] = $17;
 $18 = (($cloth) + 232|0);
 $19 = (($cloth) + 236|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $65 = $10;
 } else {
  $22 = HEAP32[$18>>2]|0;
  $23 = (($22) + ($20<<3)|0);
  $it$08$i = $22;$sum$09$i = Math_fround(0.0);
  while(1) {
   $24 = HEAP32[$it$08$i>>2]|0;
   $25 = (Math_fround(($24>>>0)));
   $26 = (($it$08$i) + 4|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($25 * $27);
   $29 = Math_fround($sum$09$i + $28);
   $30 = (($it$08$i) + 8|0);
   $31 = ($30|0)==($23|0);
   if ($31) {
    break;
   } else {
    $it$08$i = $30;$sum$09$i = $29;
   }
  }
  $32 = (($cloth) + 244|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 >>> 3;
  $$sum$i = (($20) + -1)|0;
  $35 = (($22) + ($$sum$i<<3)|0);
  $36 = ($34|0)==(0);
  if ($36) {
   $ramp$0$lcssa$i = Math_fround(0.0);
  } else {
   $37 = HEAP32[$35>>2]|0;
   $38 = HEAP32[$22>>2]|0;
   $countHi$06$i = $37;$countLo$05$i = $38;$end$01$i = $35;$i$07$i = 0;$it$12$i = $22;$ramp$03$i = Math_fround(0.0);$temp$04$i = Math_fround(0.0);
   while(1) {
    $39 = ($i$07$i|0)==($countLo$05$i|0);
    if ($39) {
     $40 = (($it$12$i) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + ($i$07$i))|0;
     $countLo$1$i = $42;$it$2$i = $40;
    } else {
     $countLo$1$i = $countLo$05$i;$it$2$i = $it$12$i;
    }
    $43 = ($i$07$i|0)==($countHi$06$i|0);
    if ($43) {
     $44 = (($end$01$i) + -8|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($45) + ($i$07$i))|0;
     $countHi$1$i = $46;$end$1$i = $44;
    } else {
     $countHi$1$i = $countHi$06$i;$end$1$i = $end$01$i;
    }
    $47 = (($it$2$i) + 4|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = (($end$1$i) + 4|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = Math_fround($48 + $50);
    $52 = Math_fround($temp$04$i + $51);
    $53 = Math_fround($ramp$03$i + $52);
    $54 = (($i$07$i) + 1)|0;
    $55 = ($54>>>0)<($34>>>0);
    if ($55) {
     $countHi$06$i = $countHi$1$i;$countLo$05$i = $countLo$1$i;$end$01$i = $end$1$i;$i$07$i = $54;$it$12$i = $it$2$i;$ramp$03$i = $53;$temp$04$i = $52;
    } else {
     $ramp$0$lcssa$i = $53;
     break;
    }
   }
  }
  $56 = (($33) - ($34))|0;
  $57 = (($34) + 1)|0;
  $58 = Math_imul($56, $57)|0;
  $59 = (Math_fround(($57>>>0)));
  $60 = Math_fround($29 * $59);
  $61 = Math_fround($60 - $ramp$0$lcssa$i);
  $62 = (Math_fround(($58>>>0)));
  $63 = Math_fround($61 / $62);
  $65 = $63;
 }
 $64 = (($this) + 16|0);
 HEAPF32[$64>>2] = $65;
 $66 = (($cloth) + 176|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($this) + 20|0);
 HEAPF32[$68>>2] = $67;
 $69 = (($cloth) + 180|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($this) + 24|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($cloth) + 184|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($this) + 28|0);
 HEAPF32[$74>>2] = $73;
 $75 = (($cloth) + 188|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($this) + 32|0);
 HEAPF32[$77>>2] = $76;
 $78 = (($cloth) + 204|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($this) + 36|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($cloth) + 208|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($this) + 40|0);
 HEAPF32[$83>>2] = $82;
 $84 = (($cloth) + 212|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($this) + 44|0);
 HEAPF32[$86>>2] = $85;
 $87 = (($cloth) + 216|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($this) + 48|0);
 HEAPF32[$89>>2] = $88;
 $90 = (($cloth) + 220|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($this) + 52|0);
 HEAPF32[$92>>2] = $91;
 $93 = (($cloth) + 224|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($this) + 56|0);
 HEAPF32[$95>>2] = $94;
 $96 = Math_fround(Math_fround(1.0) / $frameDt);
 $97 = (($cloth) + 164|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($cloth) + 192|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($98 - $100);
 $102 = (($cloth) + 168|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($cloth) + 196|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($103 - $105);
 $107 = (($cloth) + 172|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($cloth) + 200|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($108 - $110);
 $112 = Math_fround($96 * $101);
 $113 = Math_fround($96 * $106);
 $114 = Math_fround($96 * $111);
 HEAPF32[$78>>2] = $112;
 HEAPF32[$81>>2] = $113;
 HEAPF32[$84>>2] = $114;
 $115 = Math_fround(HEAPF32[$66>>2]);
 $116 = Math_fround(-$115);
 $117 = Math_fround(HEAPF32[$69>>2]);
 $118 = Math_fround(-$117);
 $119 = Math_fround(HEAPF32[$72>>2]);
 $120 = Math_fround(-$119);
 $121 = Math_fround(HEAPF32[$75>>2]);
 $122 = (($cloth) + 160|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($123 * $116);
 $125 = (($cloth) + 148|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($121 * $126);
 $128 = Math_fround($124 + $127);
 $129 = (($cloth) + 152|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = Math_fround($130 * $120);
 $132 = Math_fround($128 + $131);
 $133 = (($cloth) + 156|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($134 * $118);
 $136 = Math_fround($132 - $135);
 $137 = Math_fround($123 * $118);
 $138 = Math_fround($121 * $130);
 $139 = Math_fround($137 + $138);
 $140 = Math_fround($134 * $116);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($126 * $120);
 $143 = Math_fround($141 - $142);
 $144 = Math_fround($123 * $120);
 $145 = Math_fround($121 * $134);
 $146 = Math_fround($144 + $145);
 $147 = Math_fround($126 * $118);
 $148 = Math_fround($147 + $146);
 $149 = Math_fround($130 * $116);
 $150 = Math_fround($148 - $149);
 $151 = Math_fround($121 * $123);
 $152 = Math_fround($126 * $116);
 $153 = Math_fround($151 - $152);
 $154 = Math_fround($130 * $118);
 $155 = Math_fround($153 - $154);
 $156 = Math_fround($134 * $120);
 $157 = Math_fround($155 - $156);
 $158 = Math_fround($136 * $136);
 $159 = Math_fround($143 * $143);
 $160 = Math_fround($158 + $159);
 $161 = Math_fround($150 * $150);
 $162 = Math_fround($160 + $161);
 $163 = (Math_fround(Math_sqrt((Math_fround($162)))));
 $164 = $163 > Math_fround(1.1920928955078125E-7);
 if (!($164)) {
  $174 = Math_fround(1.0);
  $173 = Math_fround(-$174);
  $175 = $157 >= Math_fround(0.0);
  $176 = $175 ? $174 : $173;
  $177 = Math_fround($136 * $176);
  $178 = Math_fround($143 * $176);
  $179 = Math_fround($150 * $176);
  $180 = Math_fround($96 * $177);
  $181 = Math_fround($96 * $178);
  $182 = Math_fround($96 * $179);
  HEAPF32[$87>>2] = $180;
  HEAPF32[$90>>2] = $181;
  HEAPF32[$93>>2] = $182;
  $183 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$12>>2] = $183;
  $184 = HEAP32[$this>>2]|0;
  $185 = Math_fround(HEAPF32[$11>>2]);
  __ZN5physx5cloth13MovingAverage4pushEjf($18,$184,$185);
  $186 = Math_fround(HEAPF32[$125>>2]);
  HEAPF32[$66>>2] = $186;
  $187 = Math_fround(HEAPF32[$129>>2]);
  HEAPF32[$69>>2] = $187;
  $188 = Math_fround(HEAPF32[$133>>2]);
  HEAPF32[$72>>2] = $188;
  $189 = Math_fround(HEAPF32[$122>>2]);
  HEAPF32[$75>>2] = $189;
  $190 = Math_fround(HEAPF32[$97>>2]);
  HEAPF32[$99>>2] = $190;
  $191 = Math_fround(HEAPF32[$102>>2]);
  HEAPF32[$104>>2] = $191;
  $192 = Math_fround(HEAPF32[$107>>2]);
  HEAPF32[$109>>2] = $192;
  STACKTOP = sp;return;
 }
 $165 = $163 < Math_fround(-1.0);
 $166 = $165 ? Math_fround(-1.0) : $163;
 $167 = $166 > Math_fround(1.0);
 $168 = +$166;
 $169 = $167 ? 1.0 : $168;
 $170 = (+Math_asin((+$169)));
 $171 = Math_fround($170);
 $172 = Math_fround($171 / $163);
 $174 = $172;
 $173 = Math_fround(-$174);
 $175 = $157 >= Math_fround(0.0);
 $176 = $175 ? $174 : $173;
 $177 = Math_fround($136 * $176);
 $178 = Math_fround($143 * $176);
 $179 = Math_fround($150 * $176);
 $180 = Math_fround($96 * $177);
 $181 = Math_fround($96 * $178);
 $182 = Math_fround($96 * $179);
 HEAPF32[$87>>2] = $180;
 HEAPF32[$90>>2] = $181;
 HEAPF32[$93>>2] = $182;
 $183 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$12>>2] = $183;
 $184 = HEAP32[$this>>2]|0;
 $185 = Math_fround(HEAPF32[$11>>2]);
 __ZN5physx5cloth13MovingAverage4pushEjf($18,$184,$185);
 $186 = Math_fround(HEAPF32[$125>>2]);
 HEAPF32[$66>>2] = $186;
 $187 = Math_fround(HEAPF32[$129>>2]);
 HEAPF32[$69>>2] = $187;
 $188 = Math_fround(HEAPF32[$133>>2]);
 HEAPF32[$72>>2] = $188;
 $189 = Math_fround(HEAPF32[$122>>2]);
 HEAPF32[$75>>2] = $189;
 $190 = Math_fround(HEAPF32[$97>>2]);
 HEAPF32[$99>>2] = $190;
 $191 = Math_fround(HEAPF32[$102>>2]);
 HEAPF32[$104>>2] = $191;
 $192 = Math_fround(HEAPF32[$107>>2]);
 HEAPF32[$109>>2] = $192;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth13MovingAverage4pushEjf($this,$n,$value) {
 $this = $this|0;
 $n = $n|0;
 $value = Math_fround($value);
 var $$012$i$i$i = 0, $$03$i$i$i = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $8 = 0, $9 = 0, $element = 0, $it$01$i = 0, $k$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $element = sp;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($n>>>0);
 $3 = $2 ? $n : $1;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  label = 3;
 } else {
  $7 = (($5) + -1)|0;
  $8 = HEAP32[$this>>2]|0;
  $9 = ((($8) + ($7<<3)|0) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = $10 != $value;
  if ($11) {
   label = 3;
  } else {
   $32 = (($8) + ($7<<3)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + ($3))|0;
   HEAP32[$32>>2] = $34;
   $$pre$phiZ2D = $this;
  }
 }
 do {
  if ((label|0) == 3) {
   HEAP32[$element>>2] = $3;
   $12 = (($element) + 4|0);
   HEAPF32[$12>>2] = $value;
   $13 = (($this) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $14 & 2147483647;
   $16 = ($15>>>0)>($5>>>0);
   if (!($16)) {
    (__ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE15growAndPushBackERKS4_($this,$element)|0);
    $$pre$phiZ2D = $this;
    break;
   }
   $17 = HEAP32[$this>>2]|0;
   $18 = (($17) + ($5<<3)|0);
   $19 = ($18|0)==(0|0);
   if ($19) {
    $31 = $5;
   } else {
    $20 = $element;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = $18;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
    $$pre$i = HEAP32[$4>>2]|0;
    $31 = $$pre$i;
   }
   $30 = (($31) + 1)|0;
   HEAP32[$4>>2] = $30;
   $$pre$phiZ2D = $this;
  }
 } while(0);
 $35 = (($this) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + ($3))|0;
 HEAP32[$35>>2] = $37;
 $38 = HEAP32[$$pre$phiZ2D>>2]|0;
 $39 = HEAP32[$0>>2]|0;
 $40 = ($39>>>0)<($37>>>0);
 if ($40) {
  $44 = $37;$it$01$i = $38;$k$02$i = $39;
 } else {
  $75 = HEAP32[$35>>2]|0;
  $76 = HEAP32[$0>>2]|0;
  $77 = ($75>>>0)<($76>>>0);
  $78 = $77 ? $75 : $76;
  HEAP32[$35>>2] = $78;
  STACKTOP = sp;return;
 }
 while(1) {
  $41 = HEAP32[$it$01$i>>2]|0;
  $42 = (($41) + ($k$02$i))|0;
  $43 = (($42) - ($44))|0;
  HEAP32[$it$01$i>>2] = $43;
  $45 = HEAP32[$35>>2]|0;
  $46 = ($42>>>0)<=($45>>>0);
  $47 = $46&1;
  $48 = (($it$01$i) + ($47<<3)|0);
  $49 = ($42>>>0)<($45>>>0);
  if ($49) {
   $44 = $45;$it$01$i = $48;$k$02$i = $42;
  } else {
   break;
  }
 }
 $50 = ($48|0)==($38|0);
 if ($50) {
  $75 = HEAP32[$35>>2]|0;
  $76 = HEAP32[$0>>2]|0;
  $77 = ($75>>>0)<($76>>>0);
  $78 = $77 ? $75 : $76;
  HEAP32[$35>>2] = $78;
  STACKTOP = sp;return;
 }
 $51 = HEAP32[$4>>2]|0;
 $52 = (($38) + ($51<<3)|0);
 $53 = $52;
 $54 = $48;
 $55 = (($53) - ($54))|0;
 $56 = $55 >> 3;
 __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE19resizeUninitializedEj($this,$56);
 $57 = HEAP32[$$pre$phiZ2D>>2]|0;
 $58 = HEAP32[$4>>2]|0;
 $59 = (($57) + ($58<<3)|0);
 $60 = ($58|0)>(0);
 if ($60) {
  $$012$i$i$i = $57;$$03$i$i$i = $48;
 } else {
  $75 = HEAP32[$35>>2]|0;
  $76 = HEAP32[$0>>2]|0;
  $77 = ($75>>>0)<($76>>>0);
  $78 = $77 ? $75 : $76;
  HEAP32[$35>>2] = $78;
  STACKTOP = sp;return;
 }
 while(1) {
  $61 = ($$012$i$i$i|0)==(0|0);
  if (!($61)) {
   $62 = $$03$i$i$i;
   $63 = $62;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($62) + 4)|0;
   $66 = $65;
   $67 = HEAP32[$66>>2]|0;
   $68 = $$012$i$i$i;
   $69 = $68;
   HEAP32[$69>>2] = $64;
   $70 = (($68) + 4)|0;
   $71 = $70;
   HEAP32[$71>>2] = $67;
  }
  $72 = (($$012$i$i$i) + 8|0);
  $73 = (($$03$i$i$i) + 8|0);
  $74 = ($72>>>0)<($59>>>0);
  if ($74) {
   $$012$i$i$i = $72;$$03$i$i$i = $73;
  } else {
   break;
  }
 }
 $75 = HEAP32[$35>>2]|0;
 $76 = HEAP32[$0>>2]|0;
 $77 = ($75>>>0)<($76>>>0);
 $78 = $77 ? $75 : $76;
 HEAP32[$35>>2] = $78;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth13MovingAverage7ElementENS0_9AllocatorEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,480576,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + ($9<<3)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    $15 = $$03$i;
    $16 = $15;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + 4)|0;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = $$012$i;
    $22 = $21;
    HEAP32[$22>>2] = $17;
    $23 = (($21) + 4)|0;
    $24 = $23;
    HEAP32[$24>>2] = $20;
   }
   $25 = (($$012$i) + 8|0);
   $26 = (($$03$i) + 8|0);
   $27 = ($25>>>0)<($10>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$8>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $9;
 }
 $28 = (($11) + ($29<<3)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  $31 = $a;
  $32 = $31;
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + 4)|0;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = $28;
  $38 = $37;
  HEAP32[$38>>2] = $33;
  $39 = (($37) + 4)|0;
  $40 = $39;
  HEAP32[$40>>2] = $36;
 }
 $41 = HEAP32[$0>>2]|0;
 $42 = ($41|0)>(-1);
 if (!($42)) {
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $44 = HEAP32[$8>>2]|0;
  $45 = (($44) + 1)|0;
  HEAP32[$8>>2] = $45;
  $46 = (($11) + ($44<<3)|0);
  STACKTOP = sp;return ($46|0);
 }
 $43 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$43);
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $44 = HEAP32[$8>>2]|0;
 $45 = (($44) + 1)|0;
 HEAP32[$8>>2] = $45;
 $46 = (($11) + ($44<<3)|0);
 STACKTOP = sp;return ($46|0);
}
function __ZN5physx6shdfnd5ArrayINS_5cloth20SwInterCollisionDataENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0;
 var $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0);
 var $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*76)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 480688 : 480656;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,480576,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*76)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
    $25 = (($$012$i) + 16|0);
    $26 = (($$03$i) + 16|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    HEAPF32[$25>>2] = $27;
    $28 = (($$012$i) + 20|0);
    $29 = (($$03$i) + 20|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$28>>2] = $30;
    $31 = (($$012$i) + 24|0);
    $32 = (($$03$i) + 24|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    HEAPF32[$31>>2] = $33;
    $34 = (($$012$i) + 28|0);
    $35 = (($$03$i) + 28|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    HEAPF32[$34>>2] = $36;
    $37 = (($$012$i) + 32|0);
    $38 = (($$03$i) + 32|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    HEAPF32[$37>>2] = $39;
    $40 = (($$012$i) + 36|0);
    $41 = (($$03$i) + 36|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    HEAPF32[$40>>2] = $42;
    $43 = (($$012$i) + 40|0);
    $44 = (($$03$i) + 40|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$43>>2] = $45;
    $46 = (($$012$i) + 44|0);
    $47 = (($$03$i) + 44|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    HEAPF32[$46>>2] = $48;
    $49 = (($$012$i) + 48|0);
    $50 = (($$03$i) + 48|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    HEAPF32[$49>>2] = $51;
    $52 = (($$012$i) + 52|0);
    $53 = (($$03$i) + 52|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    HEAPF32[$52>>2] = $54;
    $55 = (($$012$i) + 56|0);
    $56 = (($$03$i) + 56|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    HEAPF32[$55>>2] = $57;
    $58 = (($$012$i) + 60|0);
    $59 = (($$03$i) + 60|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    HEAPF32[$58>>2] = $60;
    $61 = (($$012$i) + 64|0);
    $62 = (($$03$i) + 64|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    HEAPF32[$61>>2] = $63;
    $64 = (($$012$i) + 68|0);
    $65 = (($$03$i) + 68|0);
    $66 = $65;
    $67 = $66;
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + 4)|0;
    $70 = $69;
    $71 = HEAP32[$70>>2]|0;
    $72 = $64;
    $73 = $72;
    HEAP32[$73>>2] = $68;
    $74 = (($72) + 4)|0;
    $75 = $74;
    HEAP32[$75>>2] = $71;
   }
   $76 = (($$012$i) + 76|0);
   $77 = (($$03$i) + 76|0);
   $78 = ($76>>>0)<($20>>>0);
   if ($78) {
    $$012$i = $76;$$03$i = $77;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $80 = $$pre;
 } else {
  $80 = $19;
 }
 $79 = (($21) + (($80*76)|0)|0);
 $81 = ($79|0)==(0|0);
 if (!($81)) {
  ;HEAP32[$79+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$a+12>>2]|0;
  $82 = ((($21) + (($80*76)|0)|0) + 16|0);
  $83 = (($a) + 16|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$82>>2] = $84;
  $85 = ((($21) + (($80*76)|0)|0) + 20|0);
  $86 = (($a) + 20|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  HEAPF32[$85>>2] = $87;
  $88 = ((($21) + (($80*76)|0)|0) + 24|0);
  $89 = (($a) + 24|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  HEAPF32[$88>>2] = $90;
  $91 = ((($21) + (($80*76)|0)|0) + 28|0);
  $92 = (($a) + 28|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  HEAPF32[$91>>2] = $93;
  $94 = ((($21) + (($80*76)|0)|0) + 32|0);
  $95 = (($a) + 32|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  HEAPF32[$94>>2] = $96;
  $97 = ((($21) + (($80*76)|0)|0) + 36|0);
  $98 = (($a) + 36|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  HEAPF32[$97>>2] = $99;
  $100 = ((($21) + (($80*76)|0)|0) + 40|0);
  $101 = (($a) + 40|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  HEAPF32[$100>>2] = $102;
  $103 = ((($21) + (($80*76)|0)|0) + 44|0);
  $104 = (($a) + 44|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  HEAPF32[$103>>2] = $105;
  $106 = ((($21) + (($80*76)|0)|0) + 48|0);
  $107 = (($a) + 48|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  HEAPF32[$106>>2] = $108;
  $109 = ((($21) + (($80*76)|0)|0) + 52|0);
  $110 = (($a) + 52|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  HEAPF32[$109>>2] = $111;
  $112 = ((($21) + (($80*76)|0)|0) + 56|0);
  $113 = (($a) + 56|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  HEAPF32[$112>>2] = $114;
  $115 = ((($21) + (($80*76)|0)|0) + 60|0);
  $116 = (($a) + 60|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  HEAPF32[$115>>2] = $117;
  $118 = ((($21) + (($80*76)|0)|0) + 64|0);
  $119 = (($a) + 64|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  HEAPF32[$118>>2] = $120;
  $121 = ((($21) + (($80*76)|0)|0) + 68|0);
  $122 = (($a) + 68|0);
  $123 = $122;
  $124 = $123;
  $125 = HEAP32[$124>>2]|0;
  $126 = (($123) + 4)|0;
  $127 = $126;
  $128 = HEAP32[$127>>2]|0;
  $129 = $121;
  $130 = $129;
  HEAP32[$130>>2] = $125;
  $131 = (($129) + 4)|0;
  $132 = $131;
  HEAP32[$132>>2] = $128;
 }
 $133 = HEAP32[$0>>2]|0;
 $134 = ($133|0)>(-1);
 if (!($134)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $141 = HEAP32[$18>>2]|0;
  $142 = (($141) + 1)|0;
  HEAP32[$18>>2] = $142;
  $143 = (($21) + (($141*76)|0)|0);
  STACKTOP = sp;return ($143|0);
 }
 $135 = HEAP32[$this>>2]|0;
 $136 = ($135|0)==(0|0);
 if ($136) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $141 = HEAP32[$18>>2]|0;
  $142 = (($141) + 1)|0;
  HEAP32[$18>>2] = $142;
  $143 = (($21) + (($141*76)|0)|0);
  STACKTOP = sp;return ($143|0);
 }
 $137 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = (($138) + 12|0);
 $140 = HEAP32[$139>>2]|0;
 FUNCTION_TABLE_vii[$140 & 4095]($137,$135);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $141 = HEAP32[$18>>2]|0;
 $142 = (($141) + 1)|0;
 HEAP32[$18>>2] = $142;
 $143 = (($21) + (($141*76)|0)|0);
 STACKTOP = sp;return ($143|0);
}
function __ZN5physx6shdfnd5ArrayINS_5cloth20SwInterCollisionDataENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*76)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 480688 : 480656;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,480576,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*76)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
    $20 = (($$012$i) + 16|0);
    $21 = (($$03$i) + 16|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    HEAPF32[$20>>2] = $22;
    $23 = (($$012$i) + 20|0);
    $24 = (($$03$i) + 20|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    HEAPF32[$23>>2] = $25;
    $26 = (($$012$i) + 24|0);
    $27 = (($$03$i) + 24|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 28|0);
    $30 = (($$03$i) + 28|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 32|0);
    $33 = (($$03$i) + 32|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
    $35 = (($$012$i) + 36|0);
    $36 = (($$03$i) + 36|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 40|0);
    $39 = (($$03$i) + 40|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 44|0);
    $42 = (($$03$i) + 44|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$41>>2] = $43;
    $44 = (($$012$i) + 48|0);
    $45 = (($$03$i) + 48|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    HEAPF32[$44>>2] = $46;
    $47 = (($$012$i) + 52|0);
    $48 = (($$03$i) + 52|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$47>>2] = $49;
    $50 = (($$012$i) + 56|0);
    $51 = (($$03$i) + 56|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    HEAPF32[$50>>2] = $52;
    $53 = (($$012$i) + 60|0);
    $54 = (($$03$i) + 60|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    HEAPF32[$53>>2] = $55;
    $56 = (($$012$i) + 64|0);
    $57 = (($$03$i) + 64|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    HEAPF32[$56>>2] = $58;
    $59 = (($$012$i) + 68|0);
    $60 = (($$03$i) + 68|0);
    $61 = $60;
    $62 = $61;
    $63 = HEAP32[$62>>2]|0;
    $64 = (($61) + 4)|0;
    $65 = $64;
    $66 = HEAP32[$65>>2]|0;
    $67 = $59;
    $68 = $67;
    HEAP32[$68>>2] = $63;
    $69 = (($67) + 4)|0;
    $70 = $69;
    HEAP32[$70>>2] = $66;
   }
   $71 = (($$012$i) + 76|0);
   $72 = (($$03$i) + 76|0);
   $73 = ($71>>>0)<($15>>>0);
   if ($73) {
    $$012$i = $71;$$03$i = $72;
   } else {
    break;
   }
  }
 }
 $74 = (($this) + 8|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)>(-1);
 if (!($76)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$74>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $77 = HEAP32[$this>>2]|0;
 $78 = ($77|0)==(0|0);
 if ($78) {
  HEAP32[$this>>2] = $16;
  HEAP32[$74>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $79 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + 12|0);
 $82 = HEAP32[$81>>2]|0;
 FUNCTION_TABLE_vii[$82 & 4095]($79,$77);
 HEAP32[$this>>2] = $16;
 HEAP32[$74>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_116clothSizeGreaterIN5physx5cloth8SwSolver22CpuClothSimulationTaskEEEbRKT_S7_($t0,$t1) {
 $t0 = $t0|0;
 $t1 = $t1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t0) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($t1) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($3>>>0)>($7>>>0);
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx6shdfnd4sortINS_5cloth8SwSolver22CpuClothSimulationTaskEPFbRKS4_S6_ENS0_19ReflectionAllocatorIS4_EEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i3 = 0, $$ph = 0, $$ph$be = 0, $$ph10 = 0, $$ph10$be = 0, $$ph11 = 0, $$ph11$be = 0, $$ph12 = 0, $$ph12$be = 0, $$ph8 = 0, $$ph8$be = 0, $$ph9 = 0, $$ph9$be = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$02$i = 0, $m$01$i = 0, $or$cond = 0, $or$cond6 = 0, $or$cond7 = 0, $stackMem = 0, $tmp$sroa$3$i$i = 0;
 var $tmp$sroa$4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $tmp$sroa$3$i$i = sp + 160|0;
 $tmp$sroa$4$i$i = sp;
 $stackMem = sp + 24|0;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 32|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph10 = 0;$$ph11 = 0;$$ph12 = $6;$$ph8 = $5;$$ph9 = 32;
  L3: while(1) {
   $10 = $$ph11;$60 = $$ph10;$9 = $$ph12;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = HEAP32[$compare>>2]|0;
       $15 = (($elements) + (($j$02$i*40)|0)|0);
       $16 = (($elements) + (($m$01$i*40)|0)|0);
       $17 = (FUNCTION_TABLE_iii[$14 & 4095]($15,$16)|0);
       $j$0$m$0$i = $17 ? $j$02$i : $m$01$i;
       $18 = (($j$02$i) + 1)|0;
       $19 = ($j$02$i|0)<($9|0);
       if ($19) {
        $j$02$i = $18;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $20 = ((($elements) + (($j$0$m$0$i*40)|0)|0) + 4|0);
      $21 = $20;
      $22 = $21;
      $23 = HEAPU16[$22>>1]|(HEAPU16[$22+2>>1]<<16);
      $24 = (($21) + 4)|0;
      $25 = $24;
      $26 = HEAPU16[$25>>1]|(HEAPU16[$25+2>>1]<<16);
      $27 = ((($elements) + (($j$0$m$0$i*40)|0)|0) + 12|0);
      $28 = ((($elements) + (($j$0$m$0$i*40)|0)|0) + 16|0);
      $29 = HEAP32[$28>>2]|0;
      HEAP32[$tmp$sroa$3$i$i>>2] = $29;
      $30 = HEAP32[$27>>2]|0;
      $31 = ((($elements) + (($j$0$m$0$i*40)|0)|0) + 20|0);
      ;HEAP32[$tmp$sroa$4$i$i+0>>2]=HEAP32[$31+0>>2]|0;HEAP32[$tmp$sroa$4$i$i+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$tmp$sroa$4$i$i+8>>2]=HEAP32[$31+8>>2]|0;HEAP32[$tmp$sroa$4$i$i+12>>2]=HEAP32[$31+12>>2]|0;HEAP32[$tmp$sroa$4$i$i+16>>2]=HEAP32[$31+16>>2]|0;
      $32 = ((($elements) + (($i$03$i*40)|0)|0) + 4|0);
      $33 = $32;
      $34 = $33;
      $35 = HEAPU16[$34>>1]|(HEAPU16[$34+2>>1]<<16);
      $36 = (($33) + 4)|0;
      $37 = $36;
      $38 = HEAPU16[$37>>1]|(HEAPU16[$37+2>>1]<<16);
      $39 = $20;
      $40 = $39;
      HEAP16[$40>>1]=$35&65535;HEAP16[$40+2>>1]=$35>>>16;
      $41 = (($39) + 4)|0;
      $42 = $41;
      HEAP16[$42>>1]=$38&65535;HEAP16[$42+2>>1]=$38>>>16;
      $43 = ((($elements) + (($i$03$i*40)|0)|0) + 12|0);
      $44 = HEAP32[$43>>2]|0;
      HEAP32[$27>>2] = $44;
      $45 = ((($elements) + (($i$03$i*40)|0)|0) + 16|0);
      $46 = HEAP32[$45>>2]|0;
      HEAP32[$28>>2] = $46;
      $47 = ((($elements) + (($i$03$i*40)|0)|0) + 20|0);
      ;HEAP32[$31+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$47+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$47+12>>2]|0;HEAP32[$31+16>>2]=HEAP32[$47+16>>2]|0;
      $48 = $32;
      $49 = $48;
      HEAP16[$49>>1]=$23&65535;HEAP16[$49+2>>1]=$23>>>16;
      $50 = (($48) + 4)|0;
      $51 = $50;
      HEAP16[$51>>1]=$26&65535;HEAP16[$51+2>>1]=$26>>>16;
      HEAP32[$43>>2] = $30;
      $52 = HEAP32[$tmp$sroa$3$i$i>>2]|0;
      HEAP32[$45>>2] = $52;
      ;HEAP32[$47+0>>2]=HEAP32[$tmp$sroa$4$i$i+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$tmp$sroa$4$i$i+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$tmp$sroa$4$i$i+8>>2]|0;HEAP32[$47+12>>2]=HEAP32[$tmp$sroa$4$i$i+12>>2]|0;HEAP32[$47+16>>2]=HEAP32[$tmp$sroa$4$i$i+16>>2]|0;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $116 = ($60|0)==(0);
    if ($116) {
     break L3;
    }
    $117 = (($60) + -1)|0;
    $118 = (($$ph8) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($60) + -2)|0;
    $121 = (($$ph8) + ($120<<2)|0);
    $122 = HEAP32[$121>>2]|0;
    $10 = $122;$60 = $120;$9 = $119;
   }
   $53 = (__ZN5physx6shdfnd8internal9partitionINS_5cloth8SwSolver22CpuClothSimulationTaskEKPFbRKS5_S7_EEEiPT_iiRT0_($elements,$10,$9,$compare)|0);
   $54 = (($53) - ($10))|0;
   $55 = (($9) - ($53))|0;
   $56 = ($54|0)<($55|0);
   if ($56) {
    $57 = (($53) + -1)|0;
    $58 = (($$ph9) + -1)|0;
    $59 = ($60>>>0)<($58>>>0);
    if ($59) {
     $132 = $$ph;$133 = $$ph9;$84 = $$ph8;
    } else {
     $61 = $$ph9 << 1;
     $62 = $$ph9 << 3;
     $63 = ($62|0)==(0);
     if ($63) {
      $75 = 0;
     } else {
      $64 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($65) + 8|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (__Z15PxGetFoundationv()|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($69) + 24|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = (FUNCTION_TABLE_ii[$71 & 4095]($68)|0);
      $$$i$i$i = $72 ? 480920 : 480656;
      $73 = (FUNCTION_TABLE_iiiiii[$67 & 255]($64,$62,$$$i$i$i,480832,148)|0);
      $75 = $73;
     }
     $74 = $60 << 2;
     _memcpy(($75|0),($$ph8|0),($74|0))|0;
     $76 = ($$ph<<24>>24)==(0);
     $77 = ($$ph8|0)==(0|0);
     $or$cond = $76 | $77;
     if ($or$cond) {
      $132 = 1;$133 = $61;$84 = $75;
     } else {
      $78 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = (($79) + 12|0);
      $81 = HEAP32[$80>>2]|0;
      FUNCTION_TABLE_vii[$81 & 4095]($78,$$ph8);
      $132 = 1;$133 = $61;$84 = $75;
     }
    }
    $82 = (($60) + 1)|0;
    $83 = (($84) + ($60<<2)|0);
    HEAP32[$83>>2] = $10;
    $85 = (($84) + ($82<<2)|0);
    HEAP32[$85>>2] = $57;
    $86 = (($53) + 1)|0;
    $$ph$be = $132;$$ph11$be = $86;$$ph12$be = $9;$$ph8$be = $84;$$ph9$be = $133;
   } else {
    $87 = (($53) + 1)|0;
    $88 = (($$ph9) + -1)|0;
    $89 = ($60>>>0)<($88>>>0);
    if ($89) {
     $113 = $$ph8;$134 = $$ph;$135 = $$ph9;
    } else {
     $90 = $$ph9 << 1;
     $91 = $$ph9 << 3;
     $92 = ($91|0)==(0);
     if ($92) {
      $104 = 0;
     } else {
      $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (($94) + 8|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (__Z15PxGetFoundationv()|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($98) + 24|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = (FUNCTION_TABLE_ii[$100 & 4095]($97)|0);
      $$$i$i$i3 = $101 ? 480920 : 480656;
      $102 = (FUNCTION_TABLE_iiiiii[$96 & 255]($93,$91,$$$i$i$i3,480832,148)|0);
      $104 = $102;
     }
     $103 = $60 << 2;
     _memcpy(($104|0),($$ph8|0),($103|0))|0;
     $105 = ($$ph<<24>>24)==(0);
     $106 = ($$ph8|0)==(0|0);
     $or$cond6 = $105 | $106;
     if ($or$cond6) {
      $113 = $104;$134 = 1;$135 = $90;
     } else {
      $107 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = (($108) + 12|0);
      $110 = HEAP32[$109>>2]|0;
      FUNCTION_TABLE_vii[$110 & 4095]($107,$$ph8);
      $113 = $104;$134 = 1;$135 = $90;
     }
    }
    $111 = (($60) + 1)|0;
    $112 = (($113) + ($60<<2)|0);
    HEAP32[$112>>2] = $87;
    $114 = (($113) + ($111<<2)|0);
    HEAP32[$114>>2] = $9;
    $115 = (($53) + -1)|0;
    $$ph$be = $134;$$ph11$be = $10;$$ph12$be = $115;$$ph8$be = $113;$$ph9$be = $135;
   }
   $$ph10$be = (($60) + 2)|0;
   $$ph = $$ph$be;$$ph10 = $$ph10$be;$$ph11 = $$ph11$be;$$ph12 = $$ph12$be;$$ph8 = $$ph8$be;$$ph9 = $$ph9$be;
  }
  $123 = ($$ph<<24>>24)==(0);
  $124 = ($$ph8|0)==(0|0);
  $or$cond7 = $123 | $124;
  if (!($or$cond7)) {
   $125 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = (($126) + 12|0);
   $128 = HEAP32[$127>>2]|0;
   FUNCTION_TABLE_vii[$128 & 4095]($125,$$ph8);
  }
 }
 $129 = HEAP8[$4>>0]|0;
 $130 = ($129<<24>>24)==(0);
 if ($130) {
  STACKTOP = sp;return;
 }
 $131 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$131);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal9partitionINS_5cloth8SwSolver22CpuClothSimulationTaskEKPFbRKS5_S7_EEEiPT_iiRT0_($elements,$first,$last,$compare) {
 $elements = $elements|0;
 $first = $first|0;
 $last = $last|0;
 $compare = $compare|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$0$ph = 0, $j$0$ph = 0;
 var $j$1 = 0, $tmp$sroa$3$i1 = 0, $tmp$sroa$4$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmp$sroa$3$i1 = sp + 20|0;
 $tmp$sroa$4$i2 = sp;
 __ZN5physx6shdfnd8internal7median3INS_5cloth8SwSolver22CpuClothSimulationTaskEKPFbRKS5_S7_EEEvPT_iiRT0_($elements,$first,$last,$compare);
 $0 = (($last) + -1)|0;
 $1 = (($elements) + (($0*40)|0)|0);
 $i$0$ph = $first;$j$0$ph = $0;
 while(1) {
  $i$0 = $i$0$ph;
  while(1) {
   $2 = HEAP32[$compare>>2]|0;
   $3 = (($i$0) + 1)|0;
   $4 = (($elements) + (($3*40)|0)|0);
   $5 = (FUNCTION_TABLE_iii[$2 & 4095]($4,$1)|0);
   if ($5) {
    $i$0 = $3;
   } else {
    $j$1 = $j$0$ph;
    break;
   }
  }
  while(1) {
   $6 = HEAP32[$compare>>2]|0;
   $7 = (($j$1) + -1)|0;
   $8 = (($elements) + (($7*40)|0)|0);
   $9 = (FUNCTION_TABLE_iii[$6 & 4095]($1,$8)|0);
   if ($9) {
    $j$1 = $7;
   } else {
    break;
   }
  }
  $10 = ($3|0)<($7|0);
  if (!($10)) {
   break;
  }
  $11 = ((($elements) + (($3*40)|0)|0) + 4|0);
  $12 = $11;
  $13 = $12;
  $14 = HEAPU16[$13>>1]|(HEAPU16[$13+2>>1]<<16);
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAPU16[$16>>1]|(HEAPU16[$16+2>>1]<<16);
  $18 = ((($elements) + (($3*40)|0)|0) + 12|0);
  $19 = ((($elements) + (($3*40)|0)|0) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$tmp$sroa$3$i1>>2] = $20;
  $21 = HEAP32[$18>>2]|0;
  $22 = ((($elements) + (($3*40)|0)|0) + 20|0);
  ;HEAP32[$tmp$sroa$4$i2+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$tmp$sroa$4$i2+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$tmp$sroa$4$i2+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$tmp$sroa$4$i2+12>>2]=HEAP32[$22+12>>2]|0;HEAP32[$tmp$sroa$4$i2+16>>2]=HEAP32[$22+16>>2]|0;
  $23 = ((($elements) + (($7*40)|0)|0) + 4|0);
  $24 = $23;
  $25 = $24;
  $26 = HEAPU16[$25>>1]|(HEAPU16[$25+2>>1]<<16);
  $27 = (($24) + 4)|0;
  $28 = $27;
  $29 = HEAPU16[$28>>1]|(HEAPU16[$28+2>>1]<<16);
  $30 = $11;
  $31 = $30;
  HEAP16[$31>>1]=$26&65535;HEAP16[$31+2>>1]=$26>>>16;
  $32 = (($30) + 4)|0;
  $33 = $32;
  HEAP16[$33>>1]=$29&65535;HEAP16[$33+2>>1]=$29>>>16;
  $34 = ((($elements) + (($7*40)|0)|0) + 12|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$18>>2] = $35;
  $36 = ((($elements) + (($7*40)|0)|0) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  HEAP32[$19>>2] = $37;
  $38 = ((($elements) + (($7*40)|0)|0) + 20|0);
  ;HEAP32[$22+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$38+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$38+16>>2]|0;
  $39 = $23;
  $40 = $39;
  HEAP16[$40>>1]=$14&65535;HEAP16[$40+2>>1]=$14>>>16;
  $41 = (($39) + 4)|0;
  $42 = $41;
  HEAP16[$42>>1]=$17&65535;HEAP16[$42+2>>1]=$17>>>16;
  HEAP32[$34>>2] = $21;
  $43 = HEAP32[$tmp$sroa$3$i1>>2]|0;
  HEAP32[$36>>2] = $43;
  ;HEAP32[$38+0>>2]=HEAP32[$tmp$sroa$4$i2+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$tmp$sroa$4$i2+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$tmp$sroa$4$i2+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$tmp$sroa$4$i2+12>>2]|0;HEAP32[$38+16>>2]=HEAP32[$tmp$sroa$4$i2+16>>2]|0;
  $i$0$ph = $3;$j$0$ph = $7;
 }
 $44 = ((($elements) + (($3*40)|0)|0) + 4|0);
 $45 = $44;
 $46 = $45;
 $47 = HEAPU16[$46>>1]|(HEAPU16[$46+2>>1]<<16);
 $48 = (($45) + 4)|0;
 $49 = $48;
 $50 = HEAPU16[$49>>1]|(HEAPU16[$49+2>>1]<<16);
 $51 = ((($elements) + (($3*40)|0)|0) + 12|0);
 $52 = ((($elements) + (($3*40)|0)|0) + 16|0);
 $53 = HEAP32[$52>>2]|0;
 HEAP32[$tmp$sroa$3$i1>>2] = $53;
 $54 = HEAP32[$51>>2]|0;
 $55 = ((($elements) + (($3*40)|0)|0) + 20|0);
 ;HEAP32[$tmp$sroa$4$i2+0>>2]=HEAP32[$55+0>>2]|0;HEAP32[$tmp$sroa$4$i2+4>>2]=HEAP32[$55+4>>2]|0;HEAP32[$tmp$sroa$4$i2+8>>2]=HEAP32[$55+8>>2]|0;HEAP32[$tmp$sroa$4$i2+12>>2]=HEAP32[$55+12>>2]|0;HEAP32[$tmp$sroa$4$i2+16>>2]=HEAP32[$55+16>>2]|0;
 $56 = ((($elements) + (($0*40)|0)|0) + 4|0);
 $57 = $56;
 $58 = $57;
 $59 = HEAPU16[$58>>1]|(HEAPU16[$58+2>>1]<<16);
 $60 = (($57) + 4)|0;
 $61 = $60;
 $62 = HEAPU16[$61>>1]|(HEAPU16[$61+2>>1]<<16);
 $63 = $44;
 $64 = $63;
 HEAP16[$64>>1]=$59&65535;HEAP16[$64+2>>1]=$59>>>16;
 $65 = (($63) + 4)|0;
 $66 = $65;
 HEAP16[$66>>1]=$62&65535;HEAP16[$66+2>>1]=$62>>>16;
 $67 = ((($elements) + (($0*40)|0)|0) + 12|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$51>>2] = $68;
 $69 = ((($elements) + (($0*40)|0)|0) + 16|0);
 $70 = HEAP32[$69>>2]|0;
 HEAP32[$52>>2] = $70;
 $71 = ((($elements) + (($0*40)|0)|0) + 20|0);
 ;HEAP32[$55+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$71+12>>2]|0;HEAP32[$55+16>>2]=HEAP32[$71+16>>2]|0;
 $72 = $56;
 $73 = $72;
 HEAP16[$73>>1]=$47&65535;HEAP16[$73+2>>1]=$47>>>16;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP16[$75>>1]=$50&65535;HEAP16[$75+2>>1]=$50>>>16;
 HEAP32[$67>>2] = $54;
 $76 = HEAP32[$tmp$sroa$3$i1>>2]|0;
 HEAP32[$69>>2] = $76;
 ;HEAP32[$71+0>>2]=HEAP32[$tmp$sroa$4$i2+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$tmp$sroa$4$i2+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$tmp$sroa$4$i2+8>>2]|0;HEAP32[$71+12>>2]=HEAP32[$tmp$sroa$4$i2+12>>2]|0;HEAP32[$71+16>>2]=HEAP32[$tmp$sroa$4$i2+16>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx6shdfnd8internal7median3INS_5cloth8SwSolver22CpuClothSimulationTaskEKPFbRKS5_S7_EEEvPT_iiRT0_($elements,$first,$last,$compare) {
 $elements = $elements|0;
 $first = $first|0;
 $last = $last|0;
 $compare = $compare|0;
 var $$pre = 0, $$pre$phi10Z2D = 0, $$pre$phi12Z2D = 0, $$pre$phi16Z2D = 0, $$pre$phi8Z2D = 0, $$pre11 = 0, $$pre13 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $tmp$sroa$3$i5 = 0, $tmp$sroa$4$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmp$sroa$3$i5 = sp + 20|0;
 $tmp$sroa$4$i6 = sp;
 $0 = (($last) + ($first))|0;
 $1 = (($0|0) / 2)&-1;
 $2 = HEAP32[$compare>>2]|0;
 $3 = (($elements) + (($1*40)|0)|0);
 $4 = (($elements) + (($first*40)|0)|0);
 $5 = (FUNCTION_TABLE_iii[$2 & 4095]($3,$4)|0);
 if ($5) {
  $6 = ((($elements) + (($first*40)|0)|0) + 4|0);
  $7 = $6;
  $8 = $7;
  $9 = HEAPU16[$8>>1]|(HEAPU16[$8+2>>1]<<16);
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAPU16[$11>>1]|(HEAPU16[$11+2>>1]<<16);
  $13 = ((($elements) + (($first*40)|0)|0) + 12|0);
  $14 = ((($elements) + (($first*40)|0)|0) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$tmp$sroa$3$i5>>2] = $15;
  $16 = HEAP32[$13>>2]|0;
  $17 = ((($elements) + (($first*40)|0)|0) + 20|0);
  ;HEAP32[$tmp$sroa$4$i6+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$tmp$sroa$4$i6+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$tmp$sroa$4$i6+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$tmp$sroa$4$i6+12>>2]=HEAP32[$17+12>>2]|0;HEAP32[$tmp$sroa$4$i6+16>>2]=HEAP32[$17+16>>2]|0;
  $18 = ((($elements) + (($1*40)|0)|0) + 4|0);
  $19 = $18;
  $20 = $19;
  $21 = HEAPU16[$20>>1]|(HEAPU16[$20+2>>1]<<16);
  $22 = (($19) + 4)|0;
  $23 = $22;
  $24 = HEAPU16[$23>>1]|(HEAPU16[$23+2>>1]<<16);
  $25 = $6;
  $26 = $25;
  HEAP16[$26>>1]=$21&65535;HEAP16[$26+2>>1]=$21>>>16;
  $27 = (($25) + 4)|0;
  $28 = $27;
  HEAP16[$28>>1]=$24&65535;HEAP16[$28+2>>1]=$24>>>16;
  $29 = ((($elements) + (($1*40)|0)|0) + 12|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$13>>2] = $30;
  $31 = ((($elements) + (($1*40)|0)|0) + 16|0);
  $32 = HEAP32[$31>>2]|0;
  HEAP32[$14>>2] = $32;
  $33 = ((($elements) + (($1*40)|0)|0) + 20|0);
  ;HEAP32[$17+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$33+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$33+16>>2]|0;
  $34 = $18;
  $35 = $34;
  HEAP16[$35>>1]=$9&65535;HEAP16[$35+2>>1]=$9>>>16;
  $36 = (($34) + 4)|0;
  $37 = $36;
  HEAP16[$37>>1]=$12&65535;HEAP16[$37+2>>1]=$12>>>16;
  HEAP32[$29>>2] = $16;
  $38 = HEAP32[$tmp$sroa$3$i5>>2]|0;
  HEAP32[$31>>2] = $38;
  ;HEAP32[$33+0>>2]=HEAP32[$tmp$sroa$4$i6+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$tmp$sroa$4$i6+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$tmp$sroa$4$i6+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$tmp$sroa$4$i6+12>>2]|0;HEAP32[$33+16>>2]=HEAP32[$tmp$sroa$4$i6+16>>2]|0;
 }
 $39 = HEAP32[$compare>>2]|0;
 $40 = (($elements) + (($last*40)|0)|0);
 $41 = (FUNCTION_TABLE_iii[$39 & 4095]($40,$4)|0);
 if ($41) {
  $42 = ((($elements) + (($first*40)|0)|0) + 4|0);
  $43 = $42;
  $44 = $43;
  $45 = HEAPU16[$44>>1]|(HEAPU16[$44+2>>1]<<16);
  $46 = (($43) + 4)|0;
  $47 = $46;
  $48 = HEAPU16[$47>>1]|(HEAPU16[$47+2>>1]<<16);
  $49 = ((($elements) + (($first*40)|0)|0) + 12|0);
  $50 = ((($elements) + (($first*40)|0)|0) + 16|0);
  $51 = HEAP32[$50>>2]|0;
  HEAP32[$tmp$sroa$3$i5>>2] = $51;
  $52 = HEAP32[$49>>2]|0;
  $53 = ((($elements) + (($first*40)|0)|0) + 20|0);
  ;HEAP32[$tmp$sroa$4$i6+0>>2]=HEAP32[$53+0>>2]|0;HEAP32[$tmp$sroa$4$i6+4>>2]=HEAP32[$53+4>>2]|0;HEAP32[$tmp$sroa$4$i6+8>>2]=HEAP32[$53+8>>2]|0;HEAP32[$tmp$sroa$4$i6+12>>2]=HEAP32[$53+12>>2]|0;HEAP32[$tmp$sroa$4$i6+16>>2]=HEAP32[$53+16>>2]|0;
  $54 = ((($elements) + (($last*40)|0)|0) + 4|0);
  $55 = $54;
  $56 = $55;
  $57 = HEAPU16[$56>>1]|(HEAPU16[$56+2>>1]<<16);
  $58 = (($55) + 4)|0;
  $59 = $58;
  $60 = HEAPU16[$59>>1]|(HEAPU16[$59+2>>1]<<16);
  $61 = $42;
  $62 = $61;
  HEAP16[$62>>1]=$57&65535;HEAP16[$62+2>>1]=$57>>>16;
  $63 = (($61) + 4)|0;
  $64 = $63;
  HEAP16[$64>>1]=$60&65535;HEAP16[$64+2>>1]=$60>>>16;
  $65 = ((($elements) + (($last*40)|0)|0) + 12|0);
  $66 = HEAP32[$65>>2]|0;
  HEAP32[$49>>2] = $66;
  $67 = ((($elements) + (($last*40)|0)|0) + 16|0);
  $68 = HEAP32[$67>>2]|0;
  HEAP32[$50>>2] = $68;
  $69 = ((($elements) + (($last*40)|0)|0) + 20|0);
  ;HEAP32[$53+0>>2]=HEAP32[$69+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$53+12>>2]=HEAP32[$69+12>>2]|0;HEAP32[$53+16>>2]=HEAP32[$69+16>>2]|0;
  $70 = $54;
  $71 = $70;
  HEAP16[$71>>1]=$45&65535;HEAP16[$71+2>>1]=$45>>>16;
  $72 = (($70) + 4)|0;
  $73 = $72;
  HEAP16[$73>>1]=$48&65535;HEAP16[$73+2>>1]=$48>>>16;
  HEAP32[$65>>2] = $52;
  $74 = HEAP32[$tmp$sroa$3$i5>>2]|0;
  HEAP32[$67>>2] = $74;
  ;HEAP32[$69+0>>2]=HEAP32[$tmp$sroa$4$i6+0>>2]|0;HEAP32[$69+4>>2]=HEAP32[$tmp$sroa$4$i6+4>>2]|0;HEAP32[$69+8>>2]=HEAP32[$tmp$sroa$4$i6+8>>2]|0;HEAP32[$69+12>>2]=HEAP32[$tmp$sroa$4$i6+12>>2]|0;HEAP32[$69+16>>2]=HEAP32[$tmp$sroa$4$i6+16>>2]|0;
 }
 $75 = HEAP32[$compare>>2]|0;
 $76 = (FUNCTION_TABLE_iii[$75 & 4095]($40,$3)|0);
 if ($76) {
  $77 = ((($elements) + (($1*40)|0)|0) + 4|0);
  $78 = $77;
  $79 = $78;
  $80 = HEAPU16[$79>>1]|(HEAPU16[$79+2>>1]<<16);
  $81 = (($78) + 4)|0;
  $82 = $81;
  $83 = HEAPU16[$82>>1]|(HEAPU16[$82+2>>1]<<16);
  $84 = ((($elements) + (($1*40)|0)|0) + 12|0);
  $85 = ((($elements) + (($1*40)|0)|0) + 16|0);
  $86 = HEAP32[$85>>2]|0;
  HEAP32[$tmp$sroa$3$i5>>2] = $86;
  $87 = HEAP32[$84>>2]|0;
  $88 = ((($elements) + (($1*40)|0)|0) + 20|0);
  ;HEAP32[$tmp$sroa$4$i6+0>>2]=HEAP32[$88+0>>2]|0;HEAP32[$tmp$sroa$4$i6+4>>2]=HEAP32[$88+4>>2]|0;HEAP32[$tmp$sroa$4$i6+8>>2]=HEAP32[$88+8>>2]|0;HEAP32[$tmp$sroa$4$i6+12>>2]=HEAP32[$88+12>>2]|0;HEAP32[$tmp$sroa$4$i6+16>>2]=HEAP32[$88+16>>2]|0;
  $89 = ((($elements) + (($last*40)|0)|0) + 4|0);
  $90 = $89;
  $91 = $90;
  $92 = HEAPU16[$91>>1]|(HEAPU16[$91+2>>1]<<16);
  $93 = (($90) + 4)|0;
  $94 = $93;
  $95 = HEAPU16[$94>>1]|(HEAPU16[$94+2>>1]<<16);
  $96 = $77;
  $97 = $96;
  HEAP16[$97>>1]=$92&65535;HEAP16[$97+2>>1]=$92>>>16;
  $98 = (($96) + 4)|0;
  $99 = $98;
  HEAP16[$99>>1]=$95&65535;HEAP16[$99+2>>1]=$95>>>16;
  $100 = ((($elements) + (($last*40)|0)|0) + 12|0);
  $101 = HEAP32[$100>>2]|0;
  HEAP32[$84>>2] = $101;
  $102 = ((($elements) + (($last*40)|0)|0) + 16|0);
  $103 = HEAP32[$102>>2]|0;
  HEAP32[$85>>2] = $103;
  $104 = ((($elements) + (($last*40)|0)|0) + 20|0);
  ;HEAP32[$88+0>>2]=HEAP32[$104+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$104+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$104+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$104+12>>2]|0;HEAP32[$88+16>>2]=HEAP32[$104+16>>2]|0;
  $105 = $89;
  $106 = $105;
  HEAP16[$106>>1]=$80&65535;HEAP16[$106+2>>1]=$80>>>16;
  $107 = (($105) + 4)|0;
  $108 = $107;
  HEAP16[$108>>1]=$83&65535;HEAP16[$108+2>>1]=$83>>>16;
  HEAP32[$100>>2] = $87;
  $109 = HEAP32[$tmp$sroa$3$i5>>2]|0;
  HEAP32[$102>>2] = $109;
  ;HEAP32[$104+0>>2]=HEAP32[$tmp$sroa$4$i6+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$tmp$sroa$4$i6+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$tmp$sroa$4$i6+8>>2]|0;HEAP32[$104+12>>2]=HEAP32[$tmp$sroa$4$i6+12>>2]|0;HEAP32[$104+16>>2]=HEAP32[$tmp$sroa$4$i6+16>>2]|0;
  $$pre$phi10Z2D = $84;$$pre$phi12Z2D = $85;$$pre$phi16Z2D = $88;$$pre$phi8Z2D = $77;
 } else {
  $$pre = ((($elements) + (($1*40)|0)|0) + 4|0);
  $$pre9 = ((($elements) + (($1*40)|0)|0) + 12|0);
  $$pre11 = ((($elements) + (($1*40)|0)|0) + 16|0);
  $$pre13 = ((($elements) + (($1*40)|0)|0) + 20|0);
  $$pre$phi10Z2D = $$pre9;$$pre$phi12Z2D = $$pre11;$$pre$phi16Z2D = $$pre13;$$pre$phi8Z2D = $$pre;
 }
 $110 = (($last) + -1)|0;
 $111 = $$pre$phi8Z2D;
 $112 = $111;
 $113 = HEAPU16[$112>>1]|(HEAPU16[$112+2>>1]<<16);
 $114 = (($111) + 4)|0;
 $115 = $114;
 $116 = HEAPU16[$115>>1]|(HEAPU16[$115+2>>1]<<16);
 $117 = HEAP32[$$pre$phi12Z2D>>2]|0;
 HEAP32[$tmp$sroa$3$i5>>2] = $117;
 $118 = HEAP32[$$pre$phi10Z2D>>2]|0;
 ;HEAP32[$tmp$sroa$4$i6+0>>2]=HEAP32[$$pre$phi16Z2D+0>>2]|0;HEAP32[$tmp$sroa$4$i6+4>>2]=HEAP32[$$pre$phi16Z2D+4>>2]|0;HEAP32[$tmp$sroa$4$i6+8>>2]=HEAP32[$$pre$phi16Z2D+8>>2]|0;HEAP32[$tmp$sroa$4$i6+12>>2]=HEAP32[$$pre$phi16Z2D+12>>2]|0;HEAP32[$tmp$sroa$4$i6+16>>2]=HEAP32[$$pre$phi16Z2D+16>>2]|0;
 $119 = ((($elements) + (($110*40)|0)|0) + 4|0);
 $120 = $119;
 $121 = $120;
 $122 = HEAPU16[$121>>1]|(HEAPU16[$121+2>>1]<<16);
 $123 = (($120) + 4)|0;
 $124 = $123;
 $125 = HEAPU16[$124>>1]|(HEAPU16[$124+2>>1]<<16);
 $126 = $$pre$phi8Z2D;
 $127 = $126;
 HEAP16[$127>>1]=$122&65535;HEAP16[$127+2>>1]=$122>>>16;
 $128 = (($126) + 4)|0;
 $129 = $128;
 HEAP16[$129>>1]=$125&65535;HEAP16[$129+2>>1]=$125>>>16;
 $130 = ((($elements) + (($110*40)|0)|0) + 12|0);
 $131 = HEAP32[$130>>2]|0;
 HEAP32[$$pre$phi10Z2D>>2] = $131;
 $132 = ((($elements) + (($110*40)|0)|0) + 16|0);
 $133 = HEAP32[$132>>2]|0;
 HEAP32[$$pre$phi12Z2D>>2] = $133;
 $134 = ((($elements) + (($110*40)|0)|0) + 20|0);
 ;HEAP32[$$pre$phi16Z2D+0>>2]=HEAP32[$134+0>>2]|0;HEAP32[$$pre$phi16Z2D+4>>2]=HEAP32[$134+4>>2]|0;HEAP32[$$pre$phi16Z2D+8>>2]=HEAP32[$134+8>>2]|0;HEAP32[$$pre$phi16Z2D+12>>2]=HEAP32[$134+12>>2]|0;HEAP32[$$pre$phi16Z2D+16>>2]=HEAP32[$134+16>>2]|0;
 $135 = $119;
 $136 = $135;
 HEAP16[$136>>1]=$113&65535;HEAP16[$136+2>>1]=$113>>>16;
 $137 = (($135) + 4)|0;
 $138 = $137;
 HEAP16[$138>>1]=$116&65535;HEAP16[$138+2>>1]=$116>>>16;
 HEAP32[$130>>2] = $118;
 $139 = HEAP32[$tmp$sroa$3$i5>>2]|0;
 HEAP32[$132>>2] = $139;
 ;HEAP32[$134+0>>2]=HEAP32[$tmp$sroa$4$i6+0>>2]|0;HEAP32[$134+4>>2]=HEAP32[$tmp$sroa$4$i6+4>>2]|0;HEAP32[$134+8>>2]=HEAP32[$tmp$sroa$4$i6+8>>2]|0;HEAP32[$134+12>>2]=HEAP32[$tmp$sroa$4$i6+12>>2]|0;HEAP32[$134+16>>2]=HEAP32[$tmp$sroa$4$i6+16>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_5cloth8SwSolver22CpuClothSimulationTaskENS0_9AllocatorEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $11 = 0;
 } else {
  $6 = ($$$i*40)|0;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,480576,558)|0);
  $11 = $7;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + (($9*40)|0)|0);
 $12 = ($9|0)>(0);
 if ($12) {
  $13 = HEAP32[$this>>2]|0;
  $$012$i = $11;$$03$i = $13;
  while(1) {
   $14 = ($$012$i|0)==(0|0);
   if (!($14)) {
    HEAP32[$$012$i>>2] = ((465880 + 8|0));
    $15 = (($$012$i) + 4|0);
    $16 = (($$03$i) + 4|0);
    $17 = $16;
    $18 = $17;
    $19 = HEAPU16[$18>>1]|(HEAPU16[$18+2>>1]<<16);
    $20 = (($17) + 4)|0;
    $21 = $20;
    $22 = HEAPU16[$21>>1]|(HEAPU16[$21+2>>1]<<16);
    $23 = $15;
    $24 = $23;
    HEAP16[$24>>1]=$19&65535;HEAP16[$24+2>>1]=$19>>>16;
    $25 = (($23) + 4)|0;
    $26 = $25;
    HEAP16[$26>>1]=$22&65535;HEAP16[$26+2>>1]=$22>>>16;
    HEAP32[$$012$i>>2] = ((434896 + 8|0));
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$27>>2] = $29;
    $30 = (($$012$i) + 16|0);
    $31 = (($$03$i) + 16|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$30>>2] = $32;
    $33 = HEAP32[$28>>2]|0;
    HEAP32[$27>>2] = $33;
    HEAP32[$$012$i>>2] = ((480392 + 8|0));
    $34 = (($$012$i) + 20|0);
    $35 = (($$03$i) + 20|0);
    ;HEAP32[$34+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$35+12>>2]|0;HEAP32[$34+16>>2]=HEAP32[$35+16>>2]|0;
   }
   $36 = (($$012$i) + 40|0);
   $37 = (($$03$i) + 40|0);
   $38 = ($36>>>0)<($10>>>0);
   if ($38) {
    $$012$i = $36;$$03$i = $37;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$8>>2]|0;
  $40 = $$pre;
 } else {
  $40 = $9;
 }
 $39 = (($11) + (($40*40)|0)|0);
 $41 = ($39|0)==(0|0);
 if ($41) {
  $65 = $40;
 } else {
  HEAP32[$39>>2] = ((465880 + 8|0));
  $42 = ((($11) + (($40*40)|0)|0) + 4|0);
  $43 = (($a) + 4|0);
  $44 = $43;
  $45 = $44;
  $46 = HEAPU16[$45>>1]|(HEAPU16[$45+2>>1]<<16);
  $47 = (($44) + 4)|0;
  $48 = $47;
  $49 = HEAPU16[$48>>1]|(HEAPU16[$48+2>>1]<<16);
  $50 = $42;
  $51 = $50;
  HEAP16[$51>>1]=$46&65535;HEAP16[$51+2>>1]=$46>>>16;
  $52 = (($50) + 4)|0;
  $53 = $52;
  HEAP16[$53>>1]=$49&65535;HEAP16[$53+2>>1]=$49>>>16;
  HEAP32[$39>>2] = ((434896 + 8|0));
  $54 = ((($11) + (($40*40)|0)|0) + 12|0);
  $55 = (($a) + 12|0);
  $56 = HEAP32[$55>>2]|0;
  HEAP32[$54>>2] = $56;
  $57 = ((($11) + (($40*40)|0)|0) + 16|0);
  $58 = (($a) + 16|0);
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$57>>2] = $59;
  $60 = HEAP32[$55>>2]|0;
  HEAP32[$54>>2] = $60;
  HEAP32[$39>>2] = ((480392 + 8|0));
  $61 = ((($11) + (($40*40)|0)|0) + 20|0);
  $62 = (($a) + 20|0);
  ;HEAP32[$61+0>>2]=HEAP32[$62+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$62+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$62+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$62+12>>2]|0;HEAP32[$61+16>>2]=HEAP32[$62+16>>2]|0;
  $$pre2 = HEAP32[$8>>2]|0;
  $65 = $$pre2;
 }
 $63 = HEAP32[$this>>2]|0;
 $64 = (($63) + (($65*40)|0)|0);
 $66 = ($65|0)>(0);
 if ($66) {
  $$01$i = $63;
  while(1) {
   $67 = HEAP32[$$01$i>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   FUNCTION_TABLE_vi[$68 & 4095]($$01$i);
   $69 = (($$01$i) + 40|0);
   $70 = ($69>>>0)<($64>>>0);
   if ($70) {
    $$01$i = $69;
   } else {
    break;
   }
  }
 }
 $71 = HEAP32[$0>>2]|0;
 $72 = ($71|0)>(-1);
 if (!($72)) {
  HEAP32[$this>>2] = $11;
  HEAP32[$0>>2] = $$$i;
  $74 = HEAP32[$8>>2]|0;
  $75 = (($74) + 1)|0;
  HEAP32[$8>>2] = $75;
  $76 = (($11) + (($74*40)|0)|0);
  STACKTOP = sp;return ($76|0);
 }
 $73 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$73);
 HEAP32[$this>>2] = $11;
 HEAP32[$0>>2] = $$$i;
 $74 = HEAP32[$8>>2]|0;
 $75 = (($74) + 1)|0;
 HEAP32[$8>>2] = $75;
 $76 = (($11) + (($74*40)|0)|0);
 STACKTOP = sp;return ($76|0);
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fEC1ERKNS0_7SwClothERNS0_11SwClothDataER14StackAllocatorILj16EERNS0_21IterationStateFactoryEPNS_13PxProfileZoneE($this,$cloth,$clothData,$allocator,$factory,$profiler) {
 $this = $this|0;
 $cloth = $cloth|0;
 $clothData = $clothData|0;
 $allocator = $allocator|0;
 $factory = $factory|0;
 $profiler = $profiler|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $cloth;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $clothData;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $allocator;
 $2 = (($this) + 12|0);
 __ZN5physx5cloth11SwCollisionI8Scalar4fEC1ERNS0_11SwClothDataER14StackAllocatorILj16EEPNS_13PxProfileZoneE($2,$clothData,$allocator,$profiler);
 $3 = (($this) + 460|0);
 __ZN5physx5cloth15SwSelfCollisionI8Scalar4fEC1ERNS0_11SwClothDataER14StackAllocatorILj16EE($3,$clothData,$allocator);
 $4 = (($this) + 524|0);
 __ZNK5physx5cloth21IterationStateFactory6createI8Scalar4fNS0_7SwClothEEENS0_14IterationStateIT_EERKT0_($4,$factory,$cloth);
 $5 = (($this) + 732|0);
 HEAP32[$5>>2] = $profiler;
 STACKTOP = sp;return;
}
function __ZNK5physx5cloth21IterationStateFactory6createI8Scalar4fNS0_7SwClothEEENS0_14IterationStateIT_EERKT0_($agg$result,$this,$cloth) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $cloth = $cloth|0;
 var $$phi$trans$insert = 0, $$pre = Math_fround(0), $$pre255 = Math_fround(0), $$pre256 = Math_fround(0), $$pre257 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0;
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = 0.0, $294 = 0.0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0.0;
 var $31 = Math_fround(0), $310 = 0.0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = 0;
 var $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = 0;
 var $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = Math_fround(0), $435 = 0;
 var $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0);
 var $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = 0, $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = Math_fround(0), $470 = Math_fround(0), $471 = 0;
 var $472 = Math_fround(0), $473 = 0, $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0);
 var $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0);
 var $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0);
 var $526 = Math_fround(0), $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0);
 var $544 = Math_fround(0), $545 = Math_fround(0), $546 = 0, $547 = 0, $548 = 0, $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = Math_fround(0);
 var $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = 0, $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0);
 var $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = 0, $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = 0;
 var $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = 0, $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = 0, $627 = Math_fround(0), $628 = Math_fround(0), $629 = 0, $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = 0, $633 = 0;
 var $634 = Math_fround(0), $635 = 0, $636 = Math_fround(0), $637 = 0, $638 = Math_fround(0), $639 = 0, $64 = 0, $640 = Math_fround(0), $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = Math_fround(0), $651 = 0;
 var $652 = Math_fround(0), $653 = 0, $654 = Math_fround(0), $655 = 0, $656 = Math_fround(0), $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = Math_fround(0), $667 = 0, $668 = Math_fround(0), $669 = 0, $67 = 0;
 var $670 = Math_fround(0), $671 = 0, $672 = Math_fround(0), $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = Math_fround(0), $680 = 0, $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = Math_fround(0), $690 = 0, $691 = 0, $692 = 0, $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = Math_fround(0), $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = Math_fround(0);
 var $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = 0, $71 = Math_fround(0), $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = Math_fround(0), $720 = 0, $721 = 0, $722 = 0, $723 = Math_fround(0);
 var $724 = Math_fround(0), $725 = Math_fround(0), $726 = 0, $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $centrifugalVelocity = 0, $coriolisMatrix = 0, $curMatrix = 0, $exitcond = 0, $firstDampScale = 0, $j$0254 = 0, $prevMatrix = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $firstDampScale = sp + 184|0;
 $curMatrix = sp;
 $prevMatrix = sp + 64|0;
 $centrifugalVelocity = sp + 128|0;
 $coriolisMatrix = sp + 144|0;
 $0 = HEAP32[$this>>2]|0;
 HEAP32[$agg$result>>2] = $0;
 $1 = (($this) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($agg$result) + 4|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($this) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($agg$result) + 8|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($cloth) + 204|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($7) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($7) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 36|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($13) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($13) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(HEAPF32[$4>>2]);
 $20 = (($cloth) + 144|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($19 * $21);
 $23 = (($cloth) + 56|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($23) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($23) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $30);
 $32 = Math_fround($24 * $31);
 $33 = Math_fround($26 * $31);
 $34 = Math_fround($28 * $31);
 $35 = (($cloth) + 68|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($35) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($35) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($35) + 12|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($22 * $36);
 $44 = Math_fround($22 * $38);
 $45 = Math_fround($22 * $40);
 $46 = Math_fround($22 * $42);
 $47 = Math_fround($43 * Math_fround(0.693147182464599609375));
 $48 = (Math_fround(+(Math_exp((+$47)))));
 $49 = Math_fround($44 * Math_fround(0.693147182464599609375));
 $50 = (Math_fround(+(Math_exp((+$49)))));
 $51 = Math_fround($45 * Math_fround(0.693147182464599609375));
 $52 = (Math_fround(+(Math_exp((+$51)))));
 $53 = Math_fround($46 * Math_fround(0.693147182464599609375));
 $54 = (Math_fround(+(Math_exp((+$53)))));
 $55 = (($this) + 12|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($48 * $56);
 $58 = Math_fround($50 * $56);
 $59 = Math_fround($52 * $56);
 $60 = Math_fround($54 * $56);
 HEAPF32[$firstDampScale>>2] = $57;
 $61 = (($firstDampScale) + 4|0);
 HEAPF32[$61>>2] = $58;
 $62 = (($firstDampScale) + 8|0);
 HEAPF32[$62>>2] = $59;
 $63 = (($firstDampScale) + 12|0);
 HEAPF32[$63>>2] = $60;
 $64 = (($cloth) + 80|0);
 $65 = (($64) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($64) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($22 * $66);
 $70 = Math_fround($22 * $68);
 $71 = Math_fround($69 * Math_fround(0.693147182464599609375));
 $72 = (Math_fround(+(Math_exp((+$71)))));
 $73 = Math_fround($70 * Math_fround(0.693147182464599609375));
 $74 = (Math_fround(+(Math_exp((+$73)))));
 $75 = Math_fround(Math_fround(1.0) - $54);
 $76 = Math_fround(Math_fround(1.0) - $72);
 $77 = Math_fround(Math_fround(1.0) - $74);
 $78 = Math_fround($19 * $75);
 $79 = Math_fround($19 * $76);
 $80 = Math_fround($19 * $77);
 $81 = Math_fround($8 * $78);
 $82 = Math_fround($10 * $79);
 $83 = Math_fround($12 * $80);
 $84 = (($cloth) + 104|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($84) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($84) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($19 * $85);
 $91 = Math_fround($19 * $87);
 $92 = Math_fround($19 * $89);
 $93 = Math_fround($14 - $8);
 $94 = Math_fround($16 - $10);
 $95 = Math_fround($18 - $12);
 $96 = Math_fround($93 * $90);
 $97 = Math_fround($94 * $91);
 $98 = Math_fround($95 * $92);
 $99 = HEAP32[$this>>2]|0;
 $100 = (($99) + 1)|0;
 $101 = (Math_fround(($100|0)));
 $102 = Math_fround($101 * Math_fround(0.5));
 $103 = Math_fround(HEAPF32[$1>>2]);
 $104 = Math_fround($103 * $102);
 $105 = Math_fround($96 * $104);
 $106 = Math_fround($97 * $104);
 $107 = Math_fround($98 * $104);
 $108 = (($this) + 20|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround(-$109);
 $111 = (($this) + 24|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround(-$112);
 $114 = (($this) + 28|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround(-$115);
 $117 = (($this) + 32|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = Math_fround($110 - $109);
 $120 = Math_fround($113 - $112);
 $121 = Math_fround($116 - $115);
 $122 = Math_fround($119 * $110);
 $123 = Math_fround($120 * $113);
 $124 = Math_fround($121 * $116);
 $125 = Math_fround($119 * $113);
 $126 = Math_fround($119 * $116);
 $127 = Math_fround($119 * $118);
 $128 = Math_fround($120 * $116);
 $129 = Math_fround($120 * $118);
 $130 = Math_fround($118 * $121);
 $131 = Math_fround(Math_fround(1.0) - $123);
 $132 = Math_fround($131 - $124);
 $133 = Math_fround($125 + $130);
 $134 = Math_fround($126 - $129);
 $135 = Math_fround($125 - $130);
 $136 = Math_fround(Math_fround(1.0) - $122);
 $137 = Math_fround($136 - $124);
 $138 = Math_fround($128 + $127);
 $139 = Math_fround($126 + $129);
 $140 = Math_fround($128 - $127);
 $141 = Math_fround($136 - $123);
 $142 = (($agg$result) + 16|0);
 $143 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
 $144 = (HEAPF32[tempDoublePtr>>2]=$133,HEAP32[tempDoublePtr>>2]|0);
 $145 = (HEAPF32[tempDoublePtr>>2]=$134,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$142>>2] = $143;
 $146 = (($agg$result) + 20|0);
 HEAP32[$146>>2] = $144;
 $147 = (($agg$result) + 24|0);
 HEAP32[$147>>2] = $145;
 $148 = (($agg$result) + 28|0);
 HEAP32[$148>>2] = 0;
 $149 = (($agg$result) + 32|0);
 $150 = (HEAPF32[tempDoublePtr>>2]=$135,HEAP32[tempDoublePtr>>2]|0);
 $151 = (HEAPF32[tempDoublePtr>>2]=$137,HEAP32[tempDoublePtr>>2]|0);
 $152 = (HEAPF32[tempDoublePtr>>2]=$138,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$149>>2] = $150;
 $153 = (($agg$result) + 36|0);
 HEAP32[$153>>2] = $151;
 $154 = (($agg$result) + 40|0);
 HEAP32[$154>>2] = $152;
 $155 = (($agg$result) + 44|0);
 HEAP32[$155>>2] = 0;
 $156 = (($agg$result) + 48|0);
 $157 = (HEAPF32[tempDoublePtr>>2]=$139,HEAP32[tempDoublePtr>>2]|0);
 $158 = (HEAPF32[tempDoublePtr>>2]=$140,HEAP32[tempDoublePtr>>2]|0);
 $159 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$156>>2] = $157;
 $160 = (($agg$result) + 52|0);
 HEAP32[$160>>2] = $158;
 $161 = (($agg$result) + 56|0);
 HEAP32[$161>>2] = $159;
 $162 = (($agg$result) + 60|0);
 HEAP32[$162>>2] = 0;
 $163 = Math_fround($32 - $81);
 $164 = Math_fround($33 - $82);
 $165 = Math_fround($34 - $83);
 $166 = (($agg$result) + 64|0);
 $167 = Math_fround($163 + $105);
 $168 = Math_fround($164 + $106);
 $169 = Math_fround($165 + $107);
 $170 = Math_fround($167 * $132);
 $171 = Math_fround($167 * $133);
 $172 = Math_fround($167 * $134);
 $173 = Math_fround($168 * $135);
 $174 = Math_fround($168 * $137);
 $175 = Math_fround($168 * $138);
 $176 = Math_fround($170 + $173);
 $177 = Math_fround($171 + $174);
 $178 = Math_fround($172 + $175);
 $179 = Math_fround($169 * $139);
 $180 = Math_fround($169 * $140);
 $181 = Math_fround($169 * $141);
 $182 = Math_fround($176 + $179);
 $183 = Math_fround($177 + $180);
 $184 = Math_fround($178 + $181);
 $185 = (HEAPF32[tempDoublePtr>>2]=$182,HEAP32[tempDoublePtr>>2]|0);
 $186 = (HEAPF32[tempDoublePtr>>2]=$183,HEAP32[tempDoublePtr>>2]|0);
 $187 = (HEAPF32[tempDoublePtr>>2]=$184,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$166>>2] = $185;
 $188 = (($agg$result) + 68|0);
 HEAP32[$188>>2] = $186;
 $189 = (($agg$result) + 72|0);
 HEAP32[$189>>2] = $187;
 $190 = (($agg$result) + 76|0);
 HEAP32[$190>>2] = 0;
 $191 = (($agg$result) + 80|0);
 $192 = Math_fround($96 - $105);
 $193 = Math_fround($97 - $106);
 $194 = Math_fround($98 - $107);
 $195 = Math_fround($192 * $132);
 $196 = Math_fround($192 * $133);
 $197 = Math_fround($192 * $134);
 $198 = Math_fround($193 * $135);
 $199 = Math_fround($193 * $137);
 $200 = Math_fround($193 * $138);
 $201 = Math_fround($195 + $198);
 $202 = Math_fround($196 + $199);
 $203 = Math_fround($197 + $200);
 $204 = Math_fround($194 * $139);
 $205 = Math_fround($194 * $140);
 $206 = Math_fround($194 * $141);
 $207 = Math_fround($201 + $204);
 $208 = Math_fround($202 + $205);
 $209 = Math_fround($203 + $206);
 $210 = (HEAPF32[tempDoublePtr>>2]=$207,HEAP32[tempDoublePtr>>2]|0);
 $211 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
 $212 = (HEAPF32[tempDoublePtr>>2]=$209,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$191>>2] = $210;
 $213 = (($agg$result) + 84|0);
 HEAP32[$213>>2] = $211;
 $214 = (($agg$result) + 88|0);
 HEAP32[$214>>2] = $212;
 $215 = (($agg$result) + 92|0);
 HEAP32[$215>>2] = 0;
 $216 = (($this) + 48|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = Math_fround($217 * $217);
 $219 = (($this) + 52|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = Math_fround($220 * $220);
 $222 = Math_fround($218 + $221);
 $223 = (($this) + 56|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = Math_fround($224 * $224);
 $226 = Math_fround($222 + $225);
 $227 = (($cloth) + 216|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 $229 = Math_fround($228 * $228);
 $230 = (($cloth) + 220|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = Math_fround($231 * $231);
 $233 = Math_fround($229 + $232);
 $234 = (($cloth) + 224|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = Math_fround($235 * $235);
 $237 = Math_fround($233 + $236);
 $238 = Math_fround($226 + $237);
 $239 = $238 > Math_fround(0.0);
 $240 = (($agg$result) + 12|0);
 $241 = $239&1;
 HEAP8[$240>>0] = $241;
 if (!($239)) {
  HEAP32[$142>>2] = -1082130432;
  HEAP32[$146>>2] = -1082130432;
  HEAP32[$147>>2] = -1082130432;
  HEAP32[$148>>2] = -1082130432;
  $716 = (($agg$result) + 96|0);
  $717 = HEAP32[$firstDampScale>>2]|0;
  $718 = HEAP32[$61>>2]|0;
  $719 = HEAP32[$62>>2]|0;
  HEAP32[$716>>2] = $717;
  $720 = (($agg$result) + 100|0);
  HEAP32[$720>>2] = $718;
  $721 = (($agg$result) + 104|0);
  HEAP32[$721>>2] = $719;
  $722 = (($agg$result) + 108|0);
  HEAP32[$722>>2] = -1082130432;
  $723 = (HEAP32[tempDoublePtr>>2]=$717,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $724 = (HEAP32[tempDoublePtr>>2]=$718,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $725 = (HEAP32[tempDoublePtr>>2]=$719,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $728 = $723;$730 = $724;$732 = $725;
  $726 = (($agg$result) + 192|0);
  $727 = Math_fround($48 - $728);
  $729 = Math_fround($50 - $730);
  $731 = Math_fround($52 - $732);
  $733 = (HEAPF32[tempDoublePtr>>2]=$727,HEAP32[tempDoublePtr>>2]|0);
  $734 = (HEAPF32[tempDoublePtr>>2]=$729,HEAP32[tempDoublePtr>>2]|0);
  $735 = (HEAPF32[tempDoublePtr>>2]=$731,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$726>>2] = $733;
  $736 = (($agg$result) + 196|0);
  HEAP32[$736>>2] = $734;
  $737 = (($agg$result) + 200|0);
  HEAP32[$737>>2] = $735;
  $738 = (($agg$result) + 204|0);
  HEAP32[$738>>2] = 0;
  STACKTOP = sp;return;
 }
 $242 = Math_fround($132 * $228);
 $243 = Math_fround($133 * $228);
 $244 = Math_fround($134 * $228);
 $245 = Math_fround($135 * $231);
 $246 = Math_fround($137 * $231);
 $247 = Math_fround($138 * $231);
 $248 = Math_fround($242 + $245);
 $249 = Math_fround($243 + $246);
 $250 = Math_fround($244 + $247);
 $251 = Math_fround($139 * $235);
 $252 = Math_fround($140 * $235);
 $253 = Math_fround($141 * $235);
 $254 = Math_fround($248 + $251);
 $255 = Math_fround($249 + $252);
 $256 = Math_fround($250 + $253);
 $257 = Math_fround($132 * $217);
 $258 = Math_fround($133 * $217);
 $259 = Math_fround($134 * $217);
 $260 = Math_fround($135 * $220);
 $261 = Math_fround($137 * $220);
 $262 = Math_fround($138 * $220);
 $263 = Math_fround($257 + $260);
 $264 = Math_fround($258 + $261);
 $265 = Math_fround($259 + $262);
 $266 = Math_fround($139 * $224);
 $267 = Math_fround($140 * $224);
 $268 = Math_fround($141 * $224);
 $269 = Math_fround($263 + $266);
 $270 = Math_fround($264 + $267);
 $271 = Math_fround($265 + $268);
 $272 = Math_fround(-$19);
 $273 = Math_fround($254 * $272);
 $274 = Math_fround($255 * $272);
 $275 = Math_fround($256 * $272);
 $276 = Math_fround($272 * Math_fround(0.0));
 $277 = Math_fround($269 * $272);
 $278 = Math_fround($270 * $272);
 $279 = Math_fround($271 * $272);
 $280 = Math_fround($273 * $273);
 $281 = Math_fround($274 * $274);
 $282 = Math_fround($280 + $281);
 $283 = Math_fround($275 * $275);
 $284 = Math_fround($283 + $282);
 $285 = (Math_fround(Math_sqrt((Math_fround($284)))));
 $286 = $285 > Math_fround(1.1920928955078125E-7);
 if ($286) {
  $287 = (Math_fround(+(Math_sin((+$285)))));
  $288 = Math_fround($287 / $285);
  $290 = $288;
 } else {
  $290 = Math_fround(1.0);
 }
 $289 = Math_fround($273 * $290);
 $291 = Math_fround($274 * $290);
 $292 = Math_fround($275 * $290);
 $293 = +$285;
 $294 = (+Math_cos((+$293)));
 $295 = Math_fround($294);
 $296 = Math_fround($277 * $277);
 $297 = Math_fround($278 * $278);
 $298 = Math_fround($296 + $297);
 $299 = Math_fround($279 * $279);
 $300 = Math_fround($299 + $298);
 $301 = (Math_fround(Math_sqrt((Math_fround($300)))));
 $302 = $301 > Math_fround(1.1920928955078125E-7);
 if ($302) {
  $303 = (Math_fround(+(Math_sin((+$301)))));
  $304 = Math_fround($303 / $301);
  $306 = $304;
 } else {
  $306 = Math_fround(1.0);
 }
 $305 = Math_fround($277 * $306);
 $307 = Math_fround($278 * $306);
 $308 = Math_fround($279 * $306);
 $309 = +$301;
 $310 = (+Math_cos((+$309)));
 $311 = Math_fround($310);
 $312 = Math_fround($289 + $289);
 $313 = Math_fround($291 + $291);
 $314 = Math_fround($292 + $292);
 $315 = Math_fround($289 * $312);
 $316 = Math_fround($291 * $313);
 $317 = Math_fround($292 * $314);
 $318 = Math_fround($291 * $312);
 $319 = Math_fround($292 * $312);
 $320 = Math_fround($312 * $295);
 $321 = Math_fround($292 * $313);
 $322 = Math_fround($313 * $295);
 $323 = Math_fround($314 * $295);
 $324 = Math_fround(Math_fround(1.0) - $316);
 $325 = Math_fround($324 - $317);
 $326 = Math_fround($318 + $323);
 $327 = Math_fround($319 - $322);
 HEAPF32[$curMatrix>>2] = $325;
 $328 = (($curMatrix) + 4|0);
 HEAPF32[$328>>2] = $326;
 $329 = (($curMatrix) + 8|0);
 HEAPF32[$329>>2] = $327;
 $330 = (($curMatrix) + 12|0);
 HEAPF32[$330>>2] = Math_fround(0.0);
 $331 = Math_fround($318 - $323);
 $332 = Math_fround(Math_fround(1.0) - $315);
 $333 = Math_fround($332 - $317);
 $334 = Math_fround($321 + $320);
 $335 = (($curMatrix) + 16|0);
 HEAPF32[$335>>2] = $331;
 $336 = (($curMatrix) + 20|0);
 HEAPF32[$336>>2] = $333;
 $337 = (($curMatrix) + 24|0);
 HEAPF32[$337>>2] = $334;
 $338 = (($curMatrix) + 28|0);
 HEAPF32[$338>>2] = Math_fround(0.0);
 $339 = Math_fround($319 + $322);
 $340 = Math_fround($321 - $320);
 $341 = Math_fround($332 - $316);
 $342 = (($curMatrix) + 32|0);
 HEAPF32[$342>>2] = $339;
 $343 = (($curMatrix) + 36|0);
 HEAPF32[$343>>2] = $340;
 $344 = (($curMatrix) + 40|0);
 HEAPF32[$344>>2] = $341;
 $345 = (($curMatrix) + 44|0);
 $346 = (($curMatrix) + 60|0);
 ;HEAP32[$345+0>>2]=0|0;HEAP32[$345+4>>2]=0|0;HEAP32[$345+8>>2]=0|0;HEAP32[$345+12>>2]=0|0;
 HEAPF32[$346>>2] = Math_fround(1.0);
 $347 = Math_fround($289 * $311);
 $348 = Math_fround($295 * $305);
 $349 = Math_fround($348 + $347);
 $350 = Math_fround($292 * $307);
 $351 = Math_fround($350 + $349);
 $352 = Math_fround($291 * $308);
 $353 = Math_fround($351 - $352);
 $354 = Math_fround($291 * $311);
 $355 = Math_fround($295 * $307);
 $356 = Math_fround($355 + $354);
 $357 = Math_fround($289 * $308);
 $358 = Math_fround($357 + $356);
 $359 = Math_fround($292 * $305);
 $360 = Math_fround($358 - $359);
 $361 = Math_fround($292 * $311);
 $362 = Math_fround($295 * $308);
 $363 = Math_fround($362 + $361);
 $364 = Math_fround($291 * $305);
 $365 = Math_fround($364 + $363);
 $366 = Math_fround($289 * $307);
 $367 = Math_fround($365 - $366);
 $368 = Math_fround($295 * $311);
 $369 = Math_fround($289 * $305);
 $370 = Math_fround($368 - $369);
 $371 = Math_fround($291 * $307);
 $372 = Math_fround($370 - $371);
 $373 = Math_fround($292 * $308);
 $374 = Math_fround($372 - $373);
 $375 = Math_fround($353 + $353);
 $376 = Math_fround($360 + $360);
 $377 = Math_fround($367 + $367);
 $378 = Math_fround($353 * $375);
 $379 = Math_fround($360 * $376);
 $380 = Math_fround($367 * $377);
 $381 = Math_fround($360 * $375);
 $382 = Math_fround($367 * $375);
 $383 = Math_fround($374 * $375);
 $384 = Math_fround($367 * $376);
 $385 = Math_fround($374 * $376);
 $386 = Math_fround($374 * $377);
 $387 = Math_fround(Math_fround(1.0) - $379);
 $388 = Math_fround($387 - $380);
 $389 = Math_fround($381 + $386);
 $390 = Math_fround($382 - $385);
 HEAPF32[$prevMatrix>>2] = $388;
 $391 = (($prevMatrix) + 4|0);
 HEAPF32[$391>>2] = $389;
 $392 = (($prevMatrix) + 8|0);
 HEAPF32[$392>>2] = $390;
 $393 = (($prevMatrix) + 12|0);
 HEAPF32[$393>>2] = Math_fround(0.0);
 $394 = Math_fround($381 - $386);
 $395 = Math_fround(Math_fround(1.0) - $378);
 $396 = Math_fround($395 - $380);
 $397 = Math_fround($384 + $383);
 $398 = (($prevMatrix) + 16|0);
 HEAPF32[$398>>2] = $394;
 $399 = (($prevMatrix) + 20|0);
 HEAPF32[$399>>2] = $396;
 $400 = (($prevMatrix) + 24|0);
 HEAPF32[$400>>2] = $397;
 $401 = (($prevMatrix) + 28|0);
 HEAPF32[$401>>2] = Math_fround(0.0);
 $402 = Math_fround($382 + $385);
 $403 = Math_fround($384 - $383);
 $404 = Math_fround($395 - $379);
 $405 = (($prevMatrix) + 32|0);
 HEAPF32[$405>>2] = $402;
 $406 = (($prevMatrix) + 36|0);
 HEAPF32[$406>>2] = $403;
 $407 = (($prevMatrix) + 40|0);
 HEAPF32[$407>>2] = $404;
 $408 = (($prevMatrix) + 44|0);
 $409 = (($prevMatrix) + 60|0);
 ;HEAP32[$408+0>>2]=0|0;HEAP32[$408+4>>2]=0|0;HEAP32[$408+8>>2]=0|0;HEAP32[$408+12>>2]=0|0;
 HEAPF32[$409>>2] = Math_fround(1.0);
 $410 = Math_fround(HEAPF32[$curMatrix>>2]);
 $411 = (($curMatrix) + 4|0);
 $412 = Math_fround(HEAPF32[$411>>2]);
 $413 = (($curMatrix) + 8|0);
 $414 = Math_fround(HEAPF32[$413>>2]);
 $415 = (($curMatrix) + 12|0);
 $416 = Math_fround(HEAPF32[$415>>2]);
 $417 = (HEAPF32[tempDoublePtr>>2]=$410,HEAP32[tempDoublePtr>>2]|0);
 $418 = (HEAPF32[tempDoublePtr>>2]=$412,HEAP32[tempDoublePtr>>2]|0);
 $419 = (HEAPF32[tempDoublePtr>>2]=$414,HEAP32[tempDoublePtr>>2]|0);
 $420 = (HEAPF32[tempDoublePtr>>2]=$416,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$142>>2] = $417;
 HEAP32[$146>>2] = $418;
 HEAP32[$147>>2] = $419;
 HEAP32[$148>>2] = $420;
 $421 = (($curMatrix) + 16|0);
 $422 = Math_fround(HEAPF32[$421>>2]);
 $423 = (($421) + 4|0);
 $424 = Math_fround(HEAPF32[$423>>2]);
 $425 = (($421) + 8|0);
 $426 = Math_fround(HEAPF32[$425>>2]);
 $427 = (($421) + 12|0);
 $428 = Math_fround(HEAPF32[$427>>2]);
 $429 = (HEAPF32[tempDoublePtr>>2]=$422,HEAP32[tempDoublePtr>>2]|0);
 $430 = (HEAPF32[tempDoublePtr>>2]=$424,HEAP32[tempDoublePtr>>2]|0);
 $431 = (HEAPF32[tempDoublePtr>>2]=$426,HEAP32[tempDoublePtr>>2]|0);
 $432 = (HEAPF32[tempDoublePtr>>2]=$428,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$149>>2] = $429;
 HEAP32[$153>>2] = $430;
 HEAP32[$154>>2] = $431;
 HEAP32[$155>>2] = $432;
 $433 = (($curMatrix) + 32|0);
 $434 = Math_fround(HEAPF32[$433>>2]);
 $435 = (($433) + 4|0);
 $436 = Math_fround(HEAPF32[$435>>2]);
 $437 = (($433) + 8|0);
 $438 = Math_fround(HEAPF32[$437>>2]);
 $439 = (($433) + 12|0);
 $440 = Math_fround(HEAPF32[$439>>2]);
 $441 = (HEAPF32[tempDoublePtr>>2]=$434,HEAP32[tempDoublePtr>>2]|0);
 $442 = (HEAPF32[tempDoublePtr>>2]=$436,HEAP32[tempDoublePtr>>2]|0);
 $443 = (HEAPF32[tempDoublePtr>>2]=$438,HEAP32[tempDoublePtr>>2]|0);
 $444 = (HEAPF32[tempDoublePtr>>2]=$440,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$156>>2] = $441;
 HEAP32[$160>>2] = $442;
 HEAP32[$161>>2] = $443;
 HEAP32[$162>>2] = $444;
 $445 = (($cloth) + 92|0);
 $446 = Math_fround(HEAPF32[$445>>2]);
 $447 = (($445) + 4|0);
 $448 = Math_fround(HEAPF32[$447>>2]);
 $449 = (($445) + 8|0);
 $450 = Math_fround(HEAPF32[$449>>2]);
 $451 = Math_fround($22 * $446);
 $452 = Math_fround($22 * $448);
 $453 = Math_fround($22 * $450);
 $454 = Math_fround($451 * Math_fround(0.693147182464599609375));
 $455 = (Math_fround(+(Math_exp((+$454)))));
 $456 = Math_fround($452 * Math_fround(0.693147182464599609375));
 $457 = (Math_fround(+(Math_exp((+$456)))));
 $458 = Math_fround($453 * Math_fround(0.693147182464599609375));
 $459 = (Math_fround(+(Math_exp((+$458)))));
 $460 = Math_fround(Math_fround(1.0) - $455);
 $461 = Math_fround(Math_fround(1.0) - $457);
 $462 = Math_fround(Math_fround(1.0) - $459);
 $463 = (($cloth) + 128|0);
 $464 = Math_fround(HEAPF32[$463>>2]);
 $465 = (($463) + 4|0);
 $466 = Math_fround(HEAPF32[$465>>2]);
 $467 = (($463) + 8|0);
 $468 = Math_fround(HEAPF32[$467>>2]);
 $469 = (($cloth) + 116|0);
 $470 = Math_fround(HEAPF32[$469>>2]);
 $471 = (($469) + 4|0);
 $472 = Math_fround(HEAPF32[$471>>2]);
 $473 = (($469) + 8|0);
 $474 = Math_fround(HEAPF32[$473>>2]);
 $475 = Math_fround($254 - $269);
 $476 = Math_fround($255 - $270);
 $477 = Math_fround($256 - $271);
 $478 = Math_fround($254 * $254);
 $479 = Math_fround($255 * $255);
 $480 = Math_fround($478 + $479);
 $481 = Math_fround($256 * $256);
 $482 = Math_fround($481 + $480);
 $483 = Math_fround($482 + Math_fround(1.08420217248550443401E-19));
 $484 = Math_fround($254 * $460);
 $485 = Math_fround($255 * $461);
 $486 = Math_fround($256 * $462);
 $487 = Math_fround($484 * $484);
 $488 = Math_fround($485 * $485);
 $489 = Math_fround($487 + $488);
 $490 = Math_fround($486 * $486);
 $491 = Math_fround($489 + $490);
 $492 = Math_fround($491 + Math_fround(1.08420217248550443401E-19));
 $493 = Math_fround($254 * $464);
 $494 = Math_fround($255 * $466);
 $495 = Math_fround($256 * $468);
 $496 = Math_fround($493 * $493);
 $497 = Math_fround($494 * $494);
 $498 = Math_fround($496 + $497);
 $499 = Math_fround($495 * $495);
 $500 = Math_fround($498 + $499);
 $501 = Math_fround($500 + Math_fround(1.08420217248550443401E-19));
 $502 = Math_fround($475 * $475);
 $503 = Math_fround($476 * $476);
 $504 = Math_fround($502 + $503);
 $505 = Math_fround($477 * $477);
 $506 = Math_fround($505 + $504);
 $507 = Math_fround($506 + Math_fround(1.08420217248550443401E-19));
 $508 = Math_fround($475 * $470);
 $509 = Math_fround($476 * $472);
 $510 = Math_fround($477 * $474);
 $511 = Math_fround($508 * $508);
 $512 = Math_fround($509 * $509);
 $513 = Math_fround($511 + $512);
 $514 = Math_fround($510 * $510);
 $515 = Math_fround($513 + $514);
 $516 = Math_fround($515 + Math_fround(1.08420217248550443401E-19));
 $517 = Math_fround($483 * $492);
 $518 = (Math_fround(Math_sqrt((Math_fround($517)))));
 $519 = Math_fround(Math_fround(1.0) / $518);
 $520 = Math_fround($492 * $519);
 $521 = Math_fround(HEAPF32[$1>>2]);
 $522 = Math_fround($507 * $516);
 $523 = (Math_fround(Math_sqrt((Math_fround($522)))));
 $524 = Math_fround(Math_fround(1.0) / $523);
 $525 = Math_fround($516 * $524);
 $526 = Math_fround($521 * $525);
 $527 = HEAP32[$this>>2]|0;
 $528 = $527 << 1;
 $529 = (($528) + -1)|0;
 $530 = (Math_fround(($529|0)));
 $531 = Math_fround($521 * $530);
 $532 = Math_fround($483 * $501);
 $533 = (Math_fround(Math_sqrt((Math_fround($532)))));
 $534 = Math_fround(Math_fround(1.0) / $533);
 $535 = Math_fround($501 * $534);
 $536 = Math_fround($535 * $531);
 $537 = Math_fround($536 - $526);
 $538 = Math_fround($273 + $277);
 $539 = Math_fround($274 + $278);
 $540 = Math_fround($275 + $279);
 $541 = Math_fround($276 + $276);
 $542 = Math_fround($538 * Math_fround(0.5));
 $543 = Math_fround($539 * Math_fround(0.5));
 $544 = Math_fround($540 * Math_fround(0.5));
 $545 = Math_fround($541 * Math_fround(0.5));
 HEAPF32[$centrifugalVelocity>>2] = $542;
 $546 = (($centrifugalVelocity) + 4|0);
 HEAPF32[$546>>2] = $543;
 $547 = (($centrifugalVelocity) + 8|0);
 HEAPF32[$547>>2] = $544;
 $548 = (($centrifugalVelocity) + 12|0);
 HEAPF32[$548>>2] = $545;
 $549 = Math_fround($542 * $542);
 $550 = Math_fround($543 * $543);
 $551 = Math_fround($549 + $550);
 $552 = Math_fround($544 * $544);
 $553 = Math_fround($551 + $552);
 $554 = Math_fround($537 * $553);
 $555 = Math_fround($542 * $537);
 $556 = Math_fround($543 * $537);
 $557 = Math_fround($544 * $537);
 $558 = Math_fround(-$556);
 $559 = Math_fround(-$557);
 $560 = Math_fround(-$555);
 HEAPF32[$coriolisMatrix>>2] = Math_fround(0.0);
 $561 = (($coriolisMatrix) + 4|0);
 HEAPF32[$561>>2] = $557;
 $562 = (($coriolisMatrix) + 8|0);
 HEAPF32[$562>>2] = $558;
 $563 = (($coriolisMatrix) + 12|0);
 HEAPF32[$563>>2] = $559;
 $564 = (($coriolisMatrix) + 16|0);
 HEAPF32[$564>>2] = Math_fround(0.0);
 $565 = (($coriolisMatrix) + 20|0);
 HEAPF32[$565>>2] = $555;
 $566 = (($coriolisMatrix) + 24|0);
 HEAPF32[$566>>2] = $556;
 $567 = (($coriolisMatrix) + 28|0);
 HEAPF32[$567>>2] = $560;
 $568 = (($coriolisMatrix) + 32|0);
 HEAPF32[$568>>2] = Math_fround(0.0);
 $569 = Math_fround($554 - $526);
 $570 = Math_fround($569 - $520);
 $572 = $542;$j$0254 = 0;
 while(1) {
  $571 = Math_fround($537 * $572);
  $573 = (($firstDampScale) + ($j$0254<<2)|0);
  $574 = Math_fround(HEAPF32[$573>>2]);
  $575 = (($coriolisMatrix) + (($j$0254*12)|0)|0);
  $576 = (($curMatrix) + ($j$0254<<4)|0);
  $577 = Math_fround($526 - $574);
  $578 = (($prevMatrix) + ($j$0254<<4)|0);
  $579 = Math_fround($526 + $574);
  $580 = Math_fround($520 + $579);
  $581 = Math_fround(HEAPF32[$575>>2]);
  $582 = Math_fround($571 * $542);
  $583 = Math_fround(-$582);
  $584 = Math_fround($583 - $581);
  $585 = Math_fround(HEAPF32[$576>>2]);
  $586 = Math_fround($577 * $585);
  $587 = Math_fround($586 + $584);
  $588 = Math_fround(HEAPF32[$578>>2]);
  $589 = Math_fround($526 * $588);
  $590 = Math_fround($587 - $589);
  HEAPF32[$578>>2] = $590;
  $591 = Math_fround($581 - $582);
  $592 = Math_fround($580 * $585);
  $593 = Math_fround($591 + $592);
  HEAPF32[$576>>2] = $593;
  $594 = (($575) + 4|0);
  $595 = Math_fround(HEAPF32[$594>>2]);
  $596 = Math_fround($571 * $543);
  $597 = Math_fround(-$596);
  $598 = Math_fround($597 - $595);
  $599 = (($576) + 4|0);
  $600 = Math_fround(HEAPF32[$599>>2]);
  $601 = Math_fround($577 * $600);
  $602 = Math_fround($601 + $598);
  $603 = (($578) + 4|0);
  $604 = Math_fround(HEAPF32[$603>>2]);
  $605 = Math_fround($526 * $604);
  $606 = Math_fround($602 - $605);
  HEAPF32[$603>>2] = $606;
  $607 = Math_fround($595 - $596);
  $608 = Math_fround($580 * $600);
  $609 = Math_fround($607 + $608);
  HEAPF32[$599>>2] = $609;
  $610 = (($575) + 8|0);
  $611 = Math_fround(HEAPF32[$610>>2]);
  $612 = Math_fround($571 * $544);
  $613 = Math_fround(-$612);
  $614 = Math_fround($613 - $611);
  $615 = (($576) + 8|0);
  $616 = Math_fround(HEAPF32[$615>>2]);
  $617 = Math_fround($577 * $616);
  $618 = Math_fround($617 + $614);
  $619 = (($578) + 8|0);
  $620 = Math_fround(HEAPF32[$619>>2]);
  $621 = Math_fround($526 * $620);
  $622 = Math_fround($618 - $621);
  HEAPF32[$619>>2] = $622;
  $623 = Math_fround($611 - $612);
  $624 = Math_fround($580 * $616);
  $625 = Math_fround($623 + $624);
  HEAPF32[$615>>2] = $625;
  $626 = (($576) + ($j$0254<<2)|0);
  $627 = Math_fround(HEAPF32[$626>>2]);
  $628 = Math_fround($570 + $627);
  HEAPF32[$626>>2] = $628;
  $629 = (($578) + ($j$0254<<2)|0);
  $630 = Math_fround(HEAPF32[$629>>2]);
  $631 = Math_fround($554 + $630);
  HEAPF32[$629>>2] = $631;
  $632 = (($j$0254) + 1)|0;
  $exitcond = ($632|0)==(3);
  if ($exitcond) {
   break;
  }
  $$phi$trans$insert = (($centrifugalVelocity) + ($632<<2)|0);
  $$pre257 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $572 = $$pre257;$j$0254 = $632;
 }
 $633 = (($agg$result) + 96|0);
 $634 = Math_fround(HEAPF32[$prevMatrix>>2]);
 $635 = (($prevMatrix) + 4|0);
 $636 = Math_fround(HEAPF32[$635>>2]);
 $637 = (($prevMatrix) + 8|0);
 $638 = Math_fround(HEAPF32[$637>>2]);
 $639 = (($prevMatrix) + 12|0);
 $640 = Math_fround(HEAPF32[$639>>2]);
 $641 = (HEAPF32[tempDoublePtr>>2]=$634,HEAP32[tempDoublePtr>>2]|0);
 $642 = (HEAPF32[tempDoublePtr>>2]=$636,HEAP32[tempDoublePtr>>2]|0);
 $643 = (HEAPF32[tempDoublePtr>>2]=$638,HEAP32[tempDoublePtr>>2]|0);
 $644 = (HEAPF32[tempDoublePtr>>2]=$640,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$633>>2] = $641;
 $645 = (($agg$result) + 100|0);
 HEAP32[$645>>2] = $642;
 $646 = (($agg$result) + 104|0);
 HEAP32[$646>>2] = $643;
 $647 = (($agg$result) + 108|0);
 HEAP32[$647>>2] = $644;
 $648 = (($agg$result) + 112|0);
 $649 = (($prevMatrix) + 16|0);
 $650 = Math_fround(HEAPF32[$649>>2]);
 $651 = (($649) + 4|0);
 $652 = Math_fround(HEAPF32[$651>>2]);
 $653 = (($649) + 8|0);
 $654 = Math_fround(HEAPF32[$653>>2]);
 $655 = (($649) + 12|0);
 $656 = Math_fround(HEAPF32[$655>>2]);
 $657 = (HEAPF32[tempDoublePtr>>2]=$650,HEAP32[tempDoublePtr>>2]|0);
 $658 = (HEAPF32[tempDoublePtr>>2]=$652,HEAP32[tempDoublePtr>>2]|0);
 $659 = (HEAPF32[tempDoublePtr>>2]=$654,HEAP32[tempDoublePtr>>2]|0);
 $660 = (HEAPF32[tempDoublePtr>>2]=$656,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$648>>2] = $657;
 $661 = (($agg$result) + 116|0);
 HEAP32[$661>>2] = $658;
 $662 = (($agg$result) + 120|0);
 HEAP32[$662>>2] = $659;
 $663 = (($agg$result) + 124|0);
 HEAP32[$663>>2] = $660;
 $664 = (($agg$result) + 128|0);
 $665 = (($prevMatrix) + 32|0);
 $666 = Math_fround(HEAPF32[$665>>2]);
 $667 = (($665) + 4|0);
 $668 = Math_fround(HEAPF32[$667>>2]);
 $669 = (($665) + 8|0);
 $670 = Math_fround(HEAPF32[$669>>2]);
 $671 = (($665) + 12|0);
 $672 = Math_fround(HEAPF32[$671>>2]);
 $673 = (HEAPF32[tempDoublePtr>>2]=$666,HEAP32[tempDoublePtr>>2]|0);
 $674 = (HEAPF32[tempDoublePtr>>2]=$668,HEAP32[tempDoublePtr>>2]|0);
 $675 = (HEAPF32[tempDoublePtr>>2]=$670,HEAP32[tempDoublePtr>>2]|0);
 $676 = (HEAPF32[tempDoublePtr>>2]=$672,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$664>>2] = $673;
 $677 = (($agg$result) + 132|0);
 HEAP32[$677>>2] = $674;
 $678 = (($agg$result) + 136|0);
 HEAP32[$678>>2] = $675;
 $679 = (($agg$result) + 140|0);
 HEAP32[$679>>2] = $676;
 $680 = (($agg$result) + 144|0);
 $681 = Math_fround(HEAPF32[$curMatrix>>2]);
 $682 = Math_fround(HEAPF32[$411>>2]);
 $683 = Math_fround(HEAPF32[$413>>2]);
 $684 = Math_fround(HEAPF32[$415>>2]);
 $685 = (HEAPF32[tempDoublePtr>>2]=$681,HEAP32[tempDoublePtr>>2]|0);
 $686 = (HEAPF32[tempDoublePtr>>2]=$682,HEAP32[tempDoublePtr>>2]|0);
 $687 = (HEAPF32[tempDoublePtr>>2]=$683,HEAP32[tempDoublePtr>>2]|0);
 $688 = (HEAPF32[tempDoublePtr>>2]=$684,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$680>>2] = $685;
 $689 = (($agg$result) + 148|0);
 HEAP32[$689>>2] = $686;
 $690 = (($agg$result) + 152|0);
 HEAP32[$690>>2] = $687;
 $691 = (($agg$result) + 156|0);
 HEAP32[$691>>2] = $688;
 $692 = (($agg$result) + 160|0);
 $693 = Math_fround(HEAPF32[$421>>2]);
 $694 = Math_fround(HEAPF32[$423>>2]);
 $695 = Math_fround(HEAPF32[$425>>2]);
 $696 = Math_fround(HEAPF32[$427>>2]);
 $697 = (HEAPF32[tempDoublePtr>>2]=$693,HEAP32[tempDoublePtr>>2]|0);
 $698 = (HEAPF32[tempDoublePtr>>2]=$694,HEAP32[tempDoublePtr>>2]|0);
 $699 = (HEAPF32[tempDoublePtr>>2]=$695,HEAP32[tempDoublePtr>>2]|0);
 $700 = (HEAPF32[tempDoublePtr>>2]=$696,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$692>>2] = $697;
 $701 = (($agg$result) + 164|0);
 HEAP32[$701>>2] = $698;
 $702 = (($agg$result) + 168|0);
 HEAP32[$702>>2] = $699;
 $703 = (($agg$result) + 172|0);
 HEAP32[$703>>2] = $700;
 $704 = (($agg$result) + 176|0);
 $705 = Math_fround(HEAPF32[$433>>2]);
 $706 = Math_fround(HEAPF32[$435>>2]);
 $707 = Math_fround(HEAPF32[$437>>2]);
 $708 = Math_fround(HEAPF32[$439>>2]);
 $709 = (HEAPF32[tempDoublePtr>>2]=$705,HEAP32[tempDoublePtr>>2]|0);
 $710 = (HEAPF32[tempDoublePtr>>2]=$706,HEAP32[tempDoublePtr>>2]|0);
 $711 = (HEAPF32[tempDoublePtr>>2]=$707,HEAP32[tempDoublePtr>>2]|0);
 $712 = (HEAPF32[tempDoublePtr>>2]=$708,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$704>>2] = $709;
 $713 = (($agg$result) + 180|0);
 HEAP32[$713>>2] = $710;
 $714 = (($agg$result) + 184|0);
 HEAP32[$714>>2] = $711;
 $715 = (($agg$result) + 188|0);
 HEAP32[$715>>2] = $712;
 $$pre = Math_fround(HEAPF32[$firstDampScale>>2]);
 $$pre255 = Math_fround(HEAPF32[$61>>2]);
 $$pre256 = Math_fround(HEAPF32[$62>>2]);
 $728 = $$pre;$730 = $$pre255;$732 = $$pre256;
 $726 = (($agg$result) + 192|0);
 $727 = Math_fround($48 - $728);
 $729 = Math_fround($50 - $730);
 $731 = Math_fround($52 - $732);
 $733 = (HEAPF32[tempDoublePtr>>2]=$727,HEAP32[tempDoublePtr>>2]|0);
 $734 = (HEAPF32[tempDoublePtr>>2]=$729,HEAP32[tempDoublePtr>>2]|0);
 $735 = (HEAPF32[tempDoublePtr>>2]=$731,HEAP32[tempDoublePtr>>2]|0);
 HEAP32[$726>>2] = $733;
 $736 = (($agg$result) + 196|0);
 HEAP32[$736>>2] = $734;
 $737 = (($agg$result) + 200|0);
 HEAP32[$737>>2] = $735;
 $738 = (($agg$result) + 204|0);
 HEAP32[$738>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fEclEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx5cloth14SwSolverKernelI8Scalar4fE13simulateClothEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE13simulateClothEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 524|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = (($this) + 460|0);
 while(1) {
  __ZN5physx5cloth14SwSolverKernelI8Scalar4fE18integrateParticlesEv($this);
  __ZN5physx5cloth14SwSolverKernelI8Scalar4fE15constrainMotionEv($this);
  __ZN5physx5cloth14SwSolverKernelI8Scalar4fE15constrainTetherEv($this);
  __ZN5physx5cloth14SwSolverKernelI8Scalar4fE11solveFabricEv($this);
  __ZN5physx5cloth14SwSolverKernelI8Scalar4fE19constrainSeparationEv($this);
  __ZN5physx5cloth11SwCollisionI8Scalar4fEclERKNS0_14IterationStateIS2_EE($3,$0);
  __ZN5physx5cloth15SwSelfCollisionI8Scalar4fEclEv($4);
  __ZN5physx5cloth14SwSolverKernelI8Scalar4fE16updateSleepStateEv($this);
  __ZN5physx5cloth14IterationStateI8Scalar4fE6updateEv($0);
  $5 = HEAP32[$0>>2]|0;
  $6 = ($5|0)==(0);
  if ($6) {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE23estimateTemporaryMemoryERKNS0_7SwClothE($cloth) {
 $cloth = $cloth|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx5cloth11SwCollisionI8Scalar4fE23estimateTemporaryMemoryERKNS0_7SwClothE($cloth)|0);
 $1 = (__ZN5physx5cloth15SwSelfCollisionI8Scalar4fE23estimateTemporaryMemoryERKNS0_7SwClothE($cloth)|0);
 $2 = ($0>>>0)<($1>>>0);
 $3 = $2 ? $1 : $0;
 $4 = (__ZN5physx5cloth11SwCollisionI8Scalar4fE24estimatePersistentMemoryERKNS0_7SwClothE($cloth)|0);
 $5 = (($4) + 1024)|0;
 $6 = (($5) + ($3))|0;
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE18integrateParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $accelIt = 0, $accelIt1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $accelIt = sp + 40|0;
 $accelIt1 = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 140|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 532|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $5);
 $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
 $8 = ($3|0)==(0|0);
 if ($8) {
  $9 = (($this) + 588|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$accelIt>>2] = $10;
  $11 = (($this) + 592|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($accelIt) + 4|0);
  HEAP32[$13>>2] = $12;
  $14 = (($this) + 596|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($accelIt) + 8|0);
  HEAP32[$16>>2] = $15;
  $17 = (($this) + 600|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($accelIt) + 12|0);
  HEAP32[$19>>2] = $18;
  $20 = (($this) + 604|0);
  __ZN5physx5cloth14SwSolverKernelI8Scalar4fE18integrateParticlesINS0_16ConstantIteratorIS2_EEEEvRT_RKS2_($this,$accelIt,$20);
  STACKTOP = sp;return;
 } else {
  $21 = HEAP32[((481120 + 12|0))>>2]|0;
  $22 = HEAP32[((481120 + 8|0))>>2]|0;
  $23 = HEAP32[((481120 + 4|0))>>2]|0;
  $24 = HEAP32[481120>>2]|0;
  $25 = $21 & $7;
  $26 = $22 & $7;
  $27 = $23 & $7;
  $28 = $24 & $7;
  $29 = (($this) + 588|0);
  HEAP32[$accelIt1>>2] = $3;
  $30 = (($accelIt1) + 4|0);
  HEAP32[$30>>2] = $28;
  $31 = (($accelIt1) + 8|0);
  HEAP32[$31>>2] = $27;
  $32 = (($accelIt1) + 12|0);
  HEAP32[$32>>2] = $26;
  $33 = (($accelIt1) + 16|0);
  HEAP32[$33>>2] = $25;
  $34 = (($accelIt1) + 20|0);
  $35 = HEAP32[$29>>2]|0;
  HEAP32[$34>>2] = $35;
  $36 = (($this) + 592|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($accelIt1) + 24|0);
  HEAP32[$38>>2] = $37;
  $39 = (($this) + 596|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($accelIt1) + 28|0);
  HEAP32[$41>>2] = $40;
  $42 = (($this) + 600|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($accelIt1) + 32|0);
  HEAP32[$44>>2] = $43;
  $45 = (($this) + 604|0);
  __ZN5physx5cloth14SwSolverKernelI8Scalar4fE18integrateParticlesINS0_17ScaleBiasIteratorIS2_PKS2_EEEEvRT_RS6_($this,$accelIt1,$45);
  STACKTOP = sp;return;
 }
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE18integrateParticlesINS0_16ConstantIteratorIS2_EEEEvRT_RKS2_($this,$accelIt,$prevBias) {
 $this = $this|0;
 $accelIt = $accelIt|0;
 $prevBias = $prevBias|0;
 var $$0154$i = 0, $$0158$i = 0, $$055$i = 0, $$059$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0);
 var $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0);
 var $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0;
 var $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0);
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $not$w$i$i$i$i = 0, $not$w$i$i$i$i9 = 0, $not$w$i$i$i5$i = 0, $not$w$i$i$i5$i5 = 0, $not$x$i$i$i$i = 0, $not$x$i$i$i$i6 = 0, $not$x$i$i$i2$i = 0;
 var $not$x$i$i$i2$i2 = 0, $not$y$i$i$i$i = 0, $not$y$i$i$i$i7 = 0, $not$y$i$i$i3$i = 0, $not$y$i$i$i3$i3 = 0, $not$z$i$i$i$i = 0, $not$z$i$i$i$i8 = 0, $not$z$i$i$i4$i = 0, $not$z$i$i$i4$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) + ($4<<4)|0);
 $6 = (($1) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 536|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 $11 = (($this) + 620|0);
 $12 = ($3|0)==($5|0);
 if ($10) {
  if ($12) {
   STACKTOP = sp;return;
  }
  $13 = (($this) + 632|0);
  $14 = (($this) + 628|0);
  $15 = (($this) + 624|0);
  $16 = HEAP32[$13>>2]|0;
  $17 = HEAP32[$14>>2]|0;
  $18 = HEAP32[$15>>2]|0;
  $19 = HEAP32[$11>>2]|0;
  $20 = (($accelIt) + 12|0);
  $21 = (($accelIt) + 8|0);
  $22 = (($accelIt) + 4|0);
  $23 = HEAP32[$20>>2]|0;
  $24 = HEAP32[$21>>2]|0;
  $25 = HEAP32[$22>>2]|0;
  $26 = HEAP32[$accelIt>>2]|0;
  $27 = (HEAP32[tempDoublePtr>>2]=$19,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $28 = (HEAP32[tempDoublePtr>>2]=$18,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $29 = (HEAP32[tempDoublePtr>>2]=$17,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $30 = (HEAP32[tempDoublePtr>>2]=$16,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $31 = (HEAP32[tempDoublePtr>>2]=$26,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $32 = (HEAP32[tempDoublePtr>>2]=$25,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $33 = (HEAP32[tempDoublePtr>>2]=$24,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $34 = (HEAP32[tempDoublePtr>>2]=$23,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $35 = (($prevBias) + 4|0);
  $36 = (($prevBias) + 8|0);
  $37 = (($prevBias) + 12|0);
  $$0158$i = $7;$$059$i = $3;
  while(1) {
   $38 = HEAP32[$$059$i>>2]|0;
   $39 = (($$059$i) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($$059$i) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($$059$i) + 12|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = HEAP32[$$0158$i>>2]|0;
   $46 = (($$0158$i) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($$0158$i) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($$0158$i) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = HEAP32[481200>>2]|0;
   $53 = HEAP32[((481200 + 4|0))>>2]|0;
   $54 = HEAP32[((481200 + 8|0))>>2]|0;
   $55 = HEAP32[((481200 + 12|0))>>2]|0;
   $56 = (HEAP32[tempDoublePtr>>2]=$38,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $57 = (HEAP32[tempDoublePtr>>2]=$52,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $58 = (HEAP32[tempDoublePtr>>2]=$40,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $59 = (HEAP32[tempDoublePtr>>2]=$53,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $60 = (HEAP32[tempDoublePtr>>2]=$42,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $61 = (HEAP32[tempDoublePtr>>2]=$54,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $62 = (HEAP32[tempDoublePtr>>2]=$44,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $63 = (HEAP32[tempDoublePtr>>2]=$55,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i2$i2 = $56 > $57;
   $not$y$i$i$i3$i3 = $58 > $59;
   $not$z$i$i$i4$i4 = $60 > $61;
   $not$w$i$i$i5$i5 = $62 > $63;
   $64 = $45 ^ $38;
   $65 = $47 ^ $40;
   $66 = $49 ^ $42;
   $67 = $51 ^ $44;
   $68 = $not$x$i$i$i2$i2 ? $64 : 0;
   $69 = $not$y$i$i$i3$i3 ? $65 : 0;
   $70 = $not$z$i$i$i4$i4 ? $66 : 0;
   $71 = $not$w$i$i$i5$i5 ? $67 : 0;
   $72 = $68 ^ $45;
   $73 = $69 ^ $47;
   $74 = $70 ^ $49;
   $75 = $71 ^ $51;
   $76 = (HEAP32[tempDoublePtr>>2]=$51,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $77 = HEAP32[481184>>2]|0;
   $78 = HEAP32[((481184 + 4|0))>>2]|0;
   $79 = HEAP32[((481184 + 8|0))>>2]|0;
   $80 = HEAP32[((481184 + 12|0))>>2]|0;
   $81 = (HEAP32[tempDoublePtr>>2]=$77,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $82 = (HEAP32[tempDoublePtr>>2]=$78,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $83 = (HEAP32[tempDoublePtr>>2]=$79,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $84 = (HEAP32[tempDoublePtr>>2]=$80,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i$i6 = $76 > $81;
   $not$y$i$i$i$i7 = $76 > $82;
   $not$z$i$i$i$i8 = $76 > $83;
   $not$w$i$i$i$i9 = $76 > $84;
   $85 = (HEAP32[tempDoublePtr>>2]=$72,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $86 = (HEAP32[tempDoublePtr>>2]=$45,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $87 = Math_fround($85 - $86);
   $88 = (HEAP32[tempDoublePtr>>2]=$73,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $89 = (HEAP32[tempDoublePtr>>2]=$47,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $90 = Math_fround($88 - $89);
   $91 = (HEAP32[tempDoublePtr>>2]=$74,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $92 = (HEAP32[tempDoublePtr>>2]=$49,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $93 = Math_fround($91 - $92);
   $94 = (HEAP32[tempDoublePtr>>2]=$75,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $95 = Math_fround($94 - $76);
   $96 = Math_fround($27 * $87);
   $97 = Math_fround($28 * $90);
   $98 = Math_fround($29 * $93);
   $99 = Math_fround($30 * $95);
   $100 = Math_fround($31 + $96);
   $101 = Math_fround($32 + $97);
   $102 = Math_fround($33 + $98);
   $103 = Math_fround($34 + $99);
   $104 = $not$x$i$i$i$i6 ? $100 : Math_fround(0.0);
   $105 = Math_fround($85 + $104);
   $106 = $not$y$i$i$i$i7 ? $101 : Math_fround(0.0);
   $107 = Math_fround($88 + $106);
   $108 = $not$z$i$i$i$i8 ? $102 : Math_fround(0.0);
   $109 = Math_fround($91 + $108);
   $110 = $not$w$i$i$i$i9 ? $103 : Math_fround(0.0);
   $111 = Math_fround($94 + $110);
   $112 = (HEAPF32[tempDoublePtr>>2]=$105,HEAP32[tempDoublePtr>>2]|0);
   $113 = (HEAPF32[tempDoublePtr>>2]=$107,HEAP32[tempDoublePtr>>2]|0);
   $114 = (HEAPF32[tempDoublePtr>>2]=$109,HEAP32[tempDoublePtr>>2]|0);
   $115 = (HEAPF32[tempDoublePtr>>2]=$111,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$059$i>>2] = $112;
   HEAP32[$39>>2] = $113;
   HEAP32[$41>>2] = $114;
   HEAP32[$43>>2] = $115;
   $116 = HEAP32[481088>>2]|0;
   $117 = HEAP32[((481088 + 4|0))>>2]|0;
   $118 = HEAP32[((481088 + 8|0))>>2]|0;
   $119 = HEAP32[((481088 + 12|0))>>2]|0;
   $120 = $116 & $68;
   $121 = $117 & $69;
   $122 = $118 & $70;
   $123 = $119 & $71;
   $124 = $120 ^ $72;
   $125 = $121 ^ $73;
   $126 = $122 ^ $74;
   $127 = $123 ^ $75;
   $128 = HEAP32[$prevBias>>2]|0;
   $129 = HEAP32[$35>>2]|0;
   $130 = HEAP32[$36>>2]|0;
   $131 = HEAP32[$37>>2]|0;
   $132 = (HEAP32[tempDoublePtr>>2]=$124,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $133 = (HEAP32[tempDoublePtr>>2]=$128,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $134 = $not$x$i$i$i$i6 ? $133 : Math_fround(0.0);
   $135 = Math_fround($132 + $134);
   $136 = (HEAP32[tempDoublePtr>>2]=$125,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $137 = (HEAP32[tempDoublePtr>>2]=$129,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $138 = $not$y$i$i$i$i7 ? $137 : Math_fround(0.0);
   $139 = Math_fround($136 + $138);
   $140 = (HEAP32[tempDoublePtr>>2]=$126,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $141 = (HEAP32[tempDoublePtr>>2]=$130,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $142 = $not$z$i$i$i$i8 ? $141 : Math_fround(0.0);
   $143 = Math_fround($140 + $142);
   $144 = (HEAP32[tempDoublePtr>>2]=$127,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $145 = (HEAP32[tempDoublePtr>>2]=$131,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $146 = $not$w$i$i$i$i9 ? $145 : Math_fround(0.0);
   $147 = Math_fround($144 + $146);
   $148 = (HEAPF32[tempDoublePtr>>2]=$135,HEAP32[tempDoublePtr>>2]|0);
   $149 = (HEAPF32[tempDoublePtr>>2]=$139,HEAP32[tempDoublePtr>>2]|0);
   $150 = (HEAPF32[tempDoublePtr>>2]=$143,HEAP32[tempDoublePtr>>2]|0);
   $151 = (HEAPF32[tempDoublePtr>>2]=$147,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$0158$i>>2] = $148;
   HEAP32[$46>>2] = $149;
   HEAP32[$48>>2] = $150;
   HEAP32[$50>>2] = $151;
   $152 = (($$059$i) + 16|0);
   $153 = (($$0158$i) + 16|0);
   $154 = ($152|0)==($5|0);
   if ($154) {
    break;
   } else {
    $$0158$i = $153;$$059$i = $152;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($12) {
   STACKTOP = sp;return;
  }
  $155 = (($accelIt) + 12|0);
  $156 = (($accelIt) + 8|0);
  $157 = (($accelIt) + 4|0);
  $158 = HEAP32[$155>>2]|0;
  $159 = HEAP32[$156>>2]|0;
  $160 = HEAP32[$157>>2]|0;
  $161 = HEAP32[$accelIt>>2]|0;
  $162 = Math_fround(HEAPF32[$11>>2]);
  $163 = (($this) + 624|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = (($this) + 628|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($this) + 632|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (HEAP32[tempDoublePtr>>2]=$161,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $170 = (HEAP32[tempDoublePtr>>2]=$160,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $171 = (HEAP32[tempDoublePtr>>2]=$159,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $172 = (HEAP32[tempDoublePtr>>2]=$158,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $173 = (($this) + 636|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = (($this) + 640|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = (($this) + 644|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = (($this) + 648|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = (($this) + 652|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = (($this) + 656|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = (($this) + 660|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = (($this) + 664|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = (($this) + 668|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($this) + 672|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = (($this) + 676|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = (($this) + 680|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = (($this) + 684|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = (($this) + 688|0);
  $200 = Math_fround(HEAPF32[$199>>2]);
  $201 = (($this) + 692|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($this) + 696|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = (($this) + 700|0);
  $206 = Math_fround(HEAPF32[$205>>2]);
  $207 = (($this) + 704|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = (($this) + 708|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $211 = (($this) + 712|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $213 = (($prevBias) + 4|0);
  $214 = (($prevBias) + 8|0);
  $215 = (($prevBias) + 12|0);
  $$0154$i = $7;$$055$i = $3;
  while(1) {
   $216 = HEAP32[$$055$i>>2]|0;
   $217 = (($$055$i) + 4|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = (($$055$i) + 8|0);
   $220 = HEAP32[$219>>2]|0;
   $221 = (($$055$i) + 12|0);
   $222 = HEAP32[$221>>2]|0;
   $223 = HEAP32[$$0154$i>>2]|0;
   $224 = (($$0154$i) + 4|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = (($$0154$i) + 8|0);
   $227 = HEAP32[$226>>2]|0;
   $228 = (($$0154$i) + 12|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = HEAP32[481200>>2]|0;
   $231 = HEAP32[((481200 + 4|0))>>2]|0;
   $232 = HEAP32[((481200 + 8|0))>>2]|0;
   $233 = HEAP32[((481200 + 12|0))>>2]|0;
   $234 = (HEAP32[tempDoublePtr>>2]=$216,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $235 = (HEAP32[tempDoublePtr>>2]=$230,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $236 = (HEAP32[tempDoublePtr>>2]=$218,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $237 = (HEAP32[tempDoublePtr>>2]=$231,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $238 = (HEAP32[tempDoublePtr>>2]=$220,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $239 = (HEAP32[tempDoublePtr>>2]=$232,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $240 = (HEAP32[tempDoublePtr>>2]=$222,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $241 = (HEAP32[tempDoublePtr>>2]=$233,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i2$i = $234 > $235;
   $not$y$i$i$i3$i = $236 > $237;
   $not$z$i$i$i4$i = $238 > $239;
   $not$w$i$i$i5$i = $240 > $241;
   $242 = $223 ^ $216;
   $243 = $225 ^ $218;
   $244 = $227 ^ $220;
   $245 = $229 ^ $222;
   $246 = $not$x$i$i$i2$i ? $242 : 0;
   $247 = $not$y$i$i$i3$i ? $243 : 0;
   $248 = $not$z$i$i$i4$i ? $244 : 0;
   $249 = $not$w$i$i$i5$i ? $245 : 0;
   $250 = $246 ^ $223;
   $251 = $247 ^ $225;
   $252 = $248 ^ $227;
   $253 = $249 ^ $229;
   $254 = (HEAP32[tempDoublePtr>>2]=$229,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $255 = HEAP32[481184>>2]|0;
   $256 = HEAP32[((481184 + 4|0))>>2]|0;
   $257 = HEAP32[((481184 + 8|0))>>2]|0;
   $258 = HEAP32[((481184 + 12|0))>>2]|0;
   $259 = (HEAP32[tempDoublePtr>>2]=$255,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $260 = (HEAP32[tempDoublePtr>>2]=$256,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $261 = (HEAP32[tempDoublePtr>>2]=$257,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $262 = (HEAP32[tempDoublePtr>>2]=$258,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i$i = $254 > $259;
   $not$y$i$i$i$i = $254 > $260;
   $not$z$i$i$i$i = $254 > $261;
   $not$w$i$i$i$i = $254 > $262;
   $263 = (HEAP32[tempDoublePtr>>2]=$223,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $264 = Math_fround($162 * $263);
   $265 = Math_fround($164 * $263);
   $266 = Math_fround($166 * $263);
   $267 = Math_fround($168 * $263);
   $268 = Math_fround($169 + $264);
   $269 = Math_fround($170 + $265);
   $270 = Math_fround($171 + $266);
   $271 = Math_fround($172 + $267);
   $272 = (HEAP32[tempDoublePtr>>2]=$225,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $273 = Math_fround($174 * $272);
   $274 = Math_fround($176 * $272);
   $275 = Math_fround($178 * $272);
   $276 = Math_fround($180 * $272);
   $277 = Math_fround($268 + $273);
   $278 = Math_fround($269 + $274);
   $279 = Math_fround($270 + $275);
   $280 = Math_fround($271 + $276);
   $281 = (HEAP32[tempDoublePtr>>2]=$227,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $282 = Math_fround($182 * $281);
   $283 = Math_fround($184 * $281);
   $284 = Math_fround($186 * $281);
   $285 = Math_fround($188 * $281);
   $286 = Math_fround($277 + $282);
   $287 = Math_fround($278 + $283);
   $288 = Math_fround($279 + $284);
   $289 = Math_fround($280 + $285);
   $290 = (HEAP32[tempDoublePtr>>2]=$250,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $291 = Math_fround($190 * $290);
   $292 = Math_fround($192 * $290);
   $293 = Math_fround($194 * $290);
   $294 = Math_fround($196 * $290);
   $295 = Math_fround($286 + $291);
   $296 = Math_fround($287 + $292);
   $297 = Math_fround($288 + $293);
   $298 = Math_fround($289 + $294);
   $299 = (HEAP32[tempDoublePtr>>2]=$251,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $300 = Math_fround($198 * $299);
   $301 = Math_fround($200 * $299);
   $302 = Math_fround($202 * $299);
   $303 = Math_fround($204 * $299);
   $304 = Math_fround($295 + $300);
   $305 = Math_fround($296 + $301);
   $306 = Math_fround($297 + $302);
   $307 = Math_fround($298 + $303);
   $308 = (HEAP32[tempDoublePtr>>2]=$252,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $309 = Math_fround($206 * $308);
   $310 = Math_fround($208 * $308);
   $311 = Math_fround($210 * $308);
   $312 = Math_fround($212 * $308);
   $313 = Math_fround($304 + $309);
   $314 = Math_fround($305 + $310);
   $315 = Math_fround($306 + $311);
   $316 = Math_fround($307 + $312);
   $317 = $not$x$i$i$i$i ? $313 : Math_fround(0.0);
   $318 = Math_fround($290 + $317);
   $319 = $not$y$i$i$i$i ? $314 : Math_fround(0.0);
   $320 = Math_fround($299 + $319);
   $321 = $not$z$i$i$i$i ? $315 : Math_fround(0.0);
   $322 = Math_fround($308 + $321);
   $323 = (HEAP32[tempDoublePtr>>2]=$253,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $324 = $not$w$i$i$i$i ? $316 : Math_fround(0.0);
   $325 = Math_fround($323 + $324);
   $326 = (HEAPF32[tempDoublePtr>>2]=$318,HEAP32[tempDoublePtr>>2]|0);
   $327 = (HEAPF32[tempDoublePtr>>2]=$320,HEAP32[tempDoublePtr>>2]|0);
   $328 = (HEAPF32[tempDoublePtr>>2]=$322,HEAP32[tempDoublePtr>>2]|0);
   $329 = (HEAPF32[tempDoublePtr>>2]=$325,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$055$i>>2] = $326;
   HEAP32[$217>>2] = $327;
   HEAP32[$219>>2] = $328;
   HEAP32[$221>>2] = $329;
   $330 = HEAP32[481088>>2]|0;
   $331 = HEAP32[((481088 + 4|0))>>2]|0;
   $332 = HEAP32[((481088 + 8|0))>>2]|0;
   $333 = HEAP32[((481088 + 12|0))>>2]|0;
   $334 = $330 & $246;
   $335 = $331 & $247;
   $336 = $332 & $248;
   $337 = $333 & $249;
   $338 = $334 ^ $250;
   $339 = $335 ^ $251;
   $340 = $336 ^ $252;
   $341 = $337 ^ $253;
   $342 = HEAP32[$prevBias>>2]|0;
   $343 = HEAP32[$213>>2]|0;
   $344 = HEAP32[$214>>2]|0;
   $345 = HEAP32[$215>>2]|0;
   $346 = (HEAP32[tempDoublePtr>>2]=$338,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $347 = (HEAP32[tempDoublePtr>>2]=$342,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $348 = $not$x$i$i$i$i ? $347 : Math_fround(0.0);
   $349 = Math_fround($346 + $348);
   $350 = (HEAP32[tempDoublePtr>>2]=$339,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $351 = (HEAP32[tempDoublePtr>>2]=$343,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $352 = $not$y$i$i$i$i ? $351 : Math_fround(0.0);
   $353 = Math_fround($350 + $352);
   $354 = (HEAP32[tempDoublePtr>>2]=$340,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $355 = (HEAP32[tempDoublePtr>>2]=$344,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $356 = $not$z$i$i$i$i ? $355 : Math_fround(0.0);
   $357 = Math_fround($354 + $356);
   $358 = (HEAP32[tempDoublePtr>>2]=$341,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $359 = (HEAP32[tempDoublePtr>>2]=$345,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $360 = $not$w$i$i$i$i ? $359 : Math_fround(0.0);
   $361 = Math_fround($358 + $360);
   $362 = (HEAPF32[tempDoublePtr>>2]=$349,HEAP32[tempDoublePtr>>2]|0);
   $363 = (HEAPF32[tempDoublePtr>>2]=$353,HEAP32[tempDoublePtr>>2]|0);
   $364 = (HEAPF32[tempDoublePtr>>2]=$357,HEAP32[tempDoublePtr>>2]|0);
   $365 = (HEAPF32[tempDoublePtr>>2]=$361,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$0154$i>>2] = $362;
   HEAP32[$224>>2] = $363;
   HEAP32[$226>>2] = $364;
   HEAP32[$228>>2] = $365;
   $366 = (($$055$i) + 16|0);
   $367 = (($$0154$i) + 16|0);
   $368 = ($366|0)==($5|0);
   if ($368) {
    break;
   } else {
    $$0154$i = $367;$$055$i = $366;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE18integrateParticlesINS0_17ScaleBiasIteratorIS2_PKS2_EEEEvRT_RS6_($this,$accelIt,$prevBias) {
 $this = $this|0;
 $accelIt = $accelIt|0;
 $prevBias = $prevBias|0;
 var $$0154$i = 0, $$0158$i = 0, $$055$i = 0, $$059$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0;
 var $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0;
 var $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0;
 var $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = 0;
 var $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0);
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $not$w$i$i$i$i = 0, $not$w$i$i$i$i9 = 0, $not$w$i$i$i5$i = 0, $not$w$i$i$i5$i5 = 0, $not$x$i$i$i$i = 0;
 var $not$x$i$i$i$i6 = 0, $not$x$i$i$i2$i = 0, $not$x$i$i$i2$i2 = 0, $not$y$i$i$i$i = 0, $not$y$i$i$i$i7 = 0, $not$y$i$i$i3$i = 0, $not$y$i$i$i3$i3 = 0, $not$z$i$i$i$i = 0, $not$z$i$i$i$i8 = 0, $not$z$i$i$i4$i = 0, $not$z$i$i$i4$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($3) + ($4<<4)|0);
 $6 = (($1) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 536|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 $11 = (($this) + 620|0);
 $12 = ($3|0)==($5|0);
 if ($10) {
  if ($12) {
   STACKTOP = sp;return;
  }
  $13 = (($this) + 632|0);
  $14 = (($this) + 628|0);
  $15 = (($this) + 624|0);
  $16 = HEAP32[$13>>2]|0;
  $17 = HEAP32[$14>>2]|0;
  $18 = HEAP32[$15>>2]|0;
  $19 = HEAP32[$11>>2]|0;
  $20 = (($accelIt) + 32|0);
  $21 = (($accelIt) + 28|0);
  $22 = (($accelIt) + 24|0);
  $23 = (($accelIt) + 20|0);
  $24 = (($accelIt) + 16|0);
  $25 = (($accelIt) + 12|0);
  $26 = (($accelIt) + 8|0);
  $27 = (($accelIt) + 4|0);
  $28 = HEAP32[$accelIt>>2]|0;
  $29 = HEAP32[$20>>2]|0;
  $30 = HEAP32[$21>>2]|0;
  $31 = HEAP32[$22>>2]|0;
  $32 = HEAP32[$23>>2]|0;
  $33 = HEAP32[$24>>2]|0;
  $34 = HEAP32[$25>>2]|0;
  $35 = HEAP32[$26>>2]|0;
  $36 = HEAP32[$27>>2]|0;
  $37 = (HEAP32[tempDoublePtr>>2]=$19,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $38 = (HEAP32[tempDoublePtr>>2]=$18,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $39 = (HEAP32[tempDoublePtr>>2]=$17,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $40 = (HEAP32[tempDoublePtr>>2]=$16,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $41 = (HEAP32[tempDoublePtr>>2]=$36,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $42 = (HEAP32[tempDoublePtr>>2]=$35,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $43 = (HEAP32[tempDoublePtr>>2]=$34,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $44 = (HEAP32[tempDoublePtr>>2]=$33,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $45 = (HEAP32[tempDoublePtr>>2]=$32,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $46 = (HEAP32[tempDoublePtr>>2]=$31,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $47 = (HEAP32[tempDoublePtr>>2]=$30,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $48 = (HEAP32[tempDoublePtr>>2]=$29,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $49 = (($prevBias) + 4|0);
  $50 = (($prevBias) + 8|0);
  $51 = (($prevBias) + 12|0);
  $$0158$i = $7;$$059$i = $3;$115 = $28;
  while(1) {
   $52 = HEAP32[$$059$i>>2]|0;
   $53 = (($$059$i) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($$059$i) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($$059$i) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = HEAP32[$$0158$i>>2]|0;
   $60 = (($$0158$i) + 4|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($$0158$i) + 8|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($$0158$i) + 12|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[481200>>2]|0;
   $67 = HEAP32[((481200 + 4|0))>>2]|0;
   $68 = HEAP32[((481200 + 8|0))>>2]|0;
   $69 = HEAP32[((481200 + 12|0))>>2]|0;
   $70 = (HEAP32[tempDoublePtr>>2]=$52,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $71 = (HEAP32[tempDoublePtr>>2]=$66,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $72 = (HEAP32[tempDoublePtr>>2]=$54,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $73 = (HEAP32[tempDoublePtr>>2]=$67,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $74 = (HEAP32[tempDoublePtr>>2]=$56,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $75 = (HEAP32[tempDoublePtr>>2]=$68,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $76 = (HEAP32[tempDoublePtr>>2]=$58,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $77 = (HEAP32[tempDoublePtr>>2]=$69,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i2$i2 = $70 > $71;
   $not$y$i$i$i3$i3 = $72 > $73;
   $not$z$i$i$i4$i4 = $74 > $75;
   $not$w$i$i$i5$i5 = $76 > $77;
   $78 = $59 ^ $52;
   $79 = $61 ^ $54;
   $80 = $63 ^ $56;
   $81 = $65 ^ $58;
   $82 = $not$x$i$i$i2$i2 ? $78 : 0;
   $83 = $not$y$i$i$i3$i3 ? $79 : 0;
   $84 = $not$z$i$i$i4$i4 ? $80 : 0;
   $85 = $not$w$i$i$i5$i5 ? $81 : 0;
   $86 = $82 ^ $59;
   $87 = $83 ^ $61;
   $88 = $84 ^ $63;
   $89 = $85 ^ $65;
   $90 = (HEAP32[tempDoublePtr>>2]=$65,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $91 = HEAP32[481184>>2]|0;
   $92 = HEAP32[((481184 + 4|0))>>2]|0;
   $93 = HEAP32[((481184 + 8|0))>>2]|0;
   $94 = HEAP32[((481184 + 12|0))>>2]|0;
   $95 = (HEAP32[tempDoublePtr>>2]=$91,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $96 = (HEAP32[tempDoublePtr>>2]=$92,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $97 = (HEAP32[tempDoublePtr>>2]=$93,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $98 = (HEAP32[tempDoublePtr>>2]=$94,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i$i6 = $90 > $95;
   $not$y$i$i$i$i7 = $90 > $96;
   $not$z$i$i$i$i8 = $90 > $97;
   $not$w$i$i$i$i9 = $90 > $98;
   $99 = (HEAP32[tempDoublePtr>>2]=$86,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $100 = (HEAP32[tempDoublePtr>>2]=$59,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $101 = Math_fround($99 - $100);
   $102 = (HEAP32[tempDoublePtr>>2]=$87,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $103 = (HEAP32[tempDoublePtr>>2]=$61,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $104 = Math_fround($102 - $103);
   $105 = (HEAP32[tempDoublePtr>>2]=$88,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $106 = (HEAP32[tempDoublePtr>>2]=$63,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $107 = Math_fround($105 - $106);
   $108 = (HEAP32[tempDoublePtr>>2]=$89,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $109 = Math_fround($108 - $90);
   $110 = Math_fround($37 * $101);
   $111 = Math_fround($38 * $104);
   $112 = Math_fround($39 * $107);
   $113 = Math_fround($40 * $109);
   $114 = Math_fround(HEAPF32[$115>>2]);
   $116 = Math_fround($41 * $114);
   $117 = (($115) + 4|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = Math_fround($42 * $118);
   $120 = (($115) + 8|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = Math_fround($43 * $121);
   $123 = (($115) + 12|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = Math_fround($44 * $124);
   $126 = Math_fround($45 + $116);
   $127 = Math_fround($46 + $119);
   $128 = Math_fround($47 + $122);
   $129 = Math_fround($48 + $125);
   $130 = Math_fround($110 + $126);
   $131 = Math_fround($111 + $127);
   $132 = Math_fround($112 + $128);
   $133 = Math_fround($113 + $129);
   $134 = $not$x$i$i$i$i6 ? $130 : Math_fround(0.0);
   $135 = Math_fround($99 + $134);
   $136 = $not$y$i$i$i$i7 ? $131 : Math_fround(0.0);
   $137 = Math_fround($102 + $136);
   $138 = $not$z$i$i$i$i8 ? $132 : Math_fround(0.0);
   $139 = Math_fround($105 + $138);
   $140 = $not$w$i$i$i$i9 ? $133 : Math_fround(0.0);
   $141 = Math_fround($108 + $140);
   $142 = (HEAPF32[tempDoublePtr>>2]=$135,HEAP32[tempDoublePtr>>2]|0);
   $143 = (HEAPF32[tempDoublePtr>>2]=$137,HEAP32[tempDoublePtr>>2]|0);
   $144 = (HEAPF32[tempDoublePtr>>2]=$139,HEAP32[tempDoublePtr>>2]|0);
   $145 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$059$i>>2] = $142;
   HEAP32[$53>>2] = $143;
   HEAP32[$55>>2] = $144;
   HEAP32[$57>>2] = $145;
   $146 = HEAP32[481088>>2]|0;
   $147 = HEAP32[((481088 + 4|0))>>2]|0;
   $148 = HEAP32[((481088 + 8|0))>>2]|0;
   $149 = HEAP32[((481088 + 12|0))>>2]|0;
   $150 = $146 & $82;
   $151 = $147 & $83;
   $152 = $148 & $84;
   $153 = $149 & $85;
   $154 = $150 ^ $86;
   $155 = $151 ^ $87;
   $156 = $152 ^ $88;
   $157 = $153 ^ $89;
   $158 = HEAP32[$prevBias>>2]|0;
   $159 = HEAP32[$49>>2]|0;
   $160 = HEAP32[$50>>2]|0;
   $161 = HEAP32[$51>>2]|0;
   $162 = (HEAP32[tempDoublePtr>>2]=$154,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $163 = (HEAP32[tempDoublePtr>>2]=$158,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $164 = $not$x$i$i$i$i6 ? $163 : Math_fround(0.0);
   $165 = Math_fround($162 + $164);
   $166 = (HEAP32[tempDoublePtr>>2]=$155,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $167 = (HEAP32[tempDoublePtr>>2]=$159,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $168 = $not$y$i$i$i$i7 ? $167 : Math_fround(0.0);
   $169 = Math_fround($166 + $168);
   $170 = (HEAP32[tempDoublePtr>>2]=$156,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $171 = (HEAP32[tempDoublePtr>>2]=$160,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $172 = $not$z$i$i$i$i8 ? $171 : Math_fround(0.0);
   $173 = Math_fround($170 + $172);
   $174 = (HEAP32[tempDoublePtr>>2]=$157,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $175 = (HEAP32[tempDoublePtr>>2]=$161,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $176 = $not$w$i$i$i$i9 ? $175 : Math_fround(0.0);
   $177 = Math_fround($174 + $176);
   $178 = (HEAPF32[tempDoublePtr>>2]=$165,HEAP32[tempDoublePtr>>2]|0);
   $179 = (HEAPF32[tempDoublePtr>>2]=$169,HEAP32[tempDoublePtr>>2]|0);
   $180 = (HEAPF32[tempDoublePtr>>2]=$173,HEAP32[tempDoublePtr>>2]|0);
   $181 = (HEAPF32[tempDoublePtr>>2]=$177,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$0158$i>>2] = $178;
   HEAP32[$60>>2] = $179;
   HEAP32[$62>>2] = $180;
   HEAP32[$64>>2] = $181;
   $182 = (($$059$i) + 16|0);
   $183 = (($$0158$i) + 16|0);
   $184 = (($115) + 16|0);
   $185 = ($182|0)==($5|0);
   if ($185) {
    break;
   } else {
    $$0158$i = $183;$$059$i = $182;$115 = $184;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($12) {
   STACKTOP = sp;return;
  }
  $186 = (($accelIt) + 32|0);
  $187 = (($accelIt) + 28|0);
  $188 = (($accelIt) + 24|0);
  $189 = (($accelIt) + 20|0);
  $190 = (($accelIt) + 16|0);
  $191 = (($accelIt) + 12|0);
  $192 = (($accelIt) + 8|0);
  $193 = (($accelIt) + 4|0);
  $194 = HEAP32[$accelIt>>2]|0;
  $195 = HEAP32[$186>>2]|0;
  $196 = HEAP32[$187>>2]|0;
  $197 = HEAP32[$188>>2]|0;
  $198 = HEAP32[$189>>2]|0;
  $199 = HEAP32[$190>>2]|0;
  $200 = HEAP32[$191>>2]|0;
  $201 = HEAP32[$192>>2]|0;
  $202 = HEAP32[$193>>2]|0;
  $203 = (HEAP32[tempDoublePtr>>2]=$202,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $204 = (HEAP32[tempDoublePtr>>2]=$201,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $205 = (HEAP32[tempDoublePtr>>2]=$200,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $206 = (HEAP32[tempDoublePtr>>2]=$199,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $207 = (HEAP32[tempDoublePtr>>2]=$198,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $208 = (HEAP32[tempDoublePtr>>2]=$197,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $209 = (HEAP32[tempDoublePtr>>2]=$196,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $210 = (HEAP32[tempDoublePtr>>2]=$195,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $211 = Math_fround(HEAPF32[$11>>2]);
  $212 = (($this) + 624|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = (($this) + 628|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($this) + 632|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($this) + 636|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = (($this) + 640|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = (($this) + 644|0);
  $223 = Math_fround(HEAPF32[$222>>2]);
  $224 = (($this) + 648|0);
  $225 = Math_fround(HEAPF32[$224>>2]);
  $226 = (($this) + 652|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = (($this) + 656|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = (($this) + 660|0);
  $231 = Math_fround(HEAPF32[$230>>2]);
  $232 = (($this) + 664|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = (($this) + 668|0);
  $235 = Math_fround(HEAPF32[$234>>2]);
  $236 = (($this) + 672|0);
  $237 = Math_fround(HEAPF32[$236>>2]);
  $238 = (($this) + 676|0);
  $239 = Math_fround(HEAPF32[$238>>2]);
  $240 = (($this) + 680|0);
  $241 = Math_fround(HEAPF32[$240>>2]);
  $242 = (($this) + 684|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = (($this) + 688|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = (($this) + 692|0);
  $247 = Math_fround(HEAPF32[$246>>2]);
  $248 = (($this) + 696|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = (($this) + 700|0);
  $251 = Math_fround(HEAPF32[$250>>2]);
  $252 = (($this) + 704|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = (($this) + 708|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = (($this) + 712|0);
  $257 = Math_fround(HEAPF32[$256>>2]);
  $258 = (($prevBias) + 4|0);
  $259 = (($prevBias) + 8|0);
  $260 = (($prevBias) + 12|0);
  $$0154$i = $7;$$055$i = $3;$309 = $194;
  while(1) {
   $261 = HEAP32[$$055$i>>2]|0;
   $262 = (($$055$i) + 4|0);
   $263 = HEAP32[$262>>2]|0;
   $264 = (($$055$i) + 8|0);
   $265 = HEAP32[$264>>2]|0;
   $266 = (($$055$i) + 12|0);
   $267 = HEAP32[$266>>2]|0;
   $268 = HEAP32[$$0154$i>>2]|0;
   $269 = (($$0154$i) + 4|0);
   $270 = HEAP32[$269>>2]|0;
   $271 = (($$0154$i) + 8|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = (($$0154$i) + 12|0);
   $274 = HEAP32[$273>>2]|0;
   $275 = HEAP32[481200>>2]|0;
   $276 = HEAP32[((481200 + 4|0))>>2]|0;
   $277 = HEAP32[((481200 + 8|0))>>2]|0;
   $278 = HEAP32[((481200 + 12|0))>>2]|0;
   $279 = (HEAP32[tempDoublePtr>>2]=$261,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $280 = (HEAP32[tempDoublePtr>>2]=$275,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $281 = (HEAP32[tempDoublePtr>>2]=$263,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $282 = (HEAP32[tempDoublePtr>>2]=$276,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $283 = (HEAP32[tempDoublePtr>>2]=$265,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $284 = (HEAP32[tempDoublePtr>>2]=$277,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $285 = (HEAP32[tempDoublePtr>>2]=$267,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $286 = (HEAP32[tempDoublePtr>>2]=$278,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i2$i = $279 > $280;
   $not$y$i$i$i3$i = $281 > $282;
   $not$z$i$i$i4$i = $283 > $284;
   $not$w$i$i$i5$i = $285 > $286;
   $287 = $268 ^ $261;
   $288 = $270 ^ $263;
   $289 = $272 ^ $265;
   $290 = $274 ^ $267;
   $291 = $not$x$i$i$i2$i ? $287 : 0;
   $292 = $not$y$i$i$i3$i ? $288 : 0;
   $293 = $not$z$i$i$i4$i ? $289 : 0;
   $294 = $not$w$i$i$i5$i ? $290 : 0;
   $295 = $291 ^ $268;
   $296 = $292 ^ $270;
   $297 = $293 ^ $272;
   $298 = $294 ^ $274;
   $299 = (HEAP32[tempDoublePtr>>2]=$274,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $300 = HEAP32[481184>>2]|0;
   $301 = HEAP32[((481184 + 4|0))>>2]|0;
   $302 = HEAP32[((481184 + 8|0))>>2]|0;
   $303 = HEAP32[((481184 + 12|0))>>2]|0;
   $304 = (HEAP32[tempDoublePtr>>2]=$300,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $305 = (HEAP32[tempDoublePtr>>2]=$301,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $306 = (HEAP32[tempDoublePtr>>2]=$302,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $307 = (HEAP32[tempDoublePtr>>2]=$303,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i$i = $299 > $304;
   $not$y$i$i$i$i = $299 > $305;
   $not$z$i$i$i$i = $299 > $306;
   $not$w$i$i$i$i = $299 > $307;
   $308 = Math_fround(HEAPF32[$309>>2]);
   $310 = Math_fround($203 * $308);
   $311 = (($309) + 4|0);
   $312 = Math_fround(HEAPF32[$311>>2]);
   $313 = Math_fround($204 * $312);
   $314 = (($309) + 8|0);
   $315 = Math_fround(HEAPF32[$314>>2]);
   $316 = Math_fround($205 * $315);
   $317 = (($309) + 12|0);
   $318 = Math_fround(HEAPF32[$317>>2]);
   $319 = Math_fround($206 * $318);
   $320 = Math_fround($207 + $310);
   $321 = Math_fround($208 + $313);
   $322 = Math_fround($209 + $316);
   $323 = Math_fround($210 + $319);
   $324 = (HEAP32[tempDoublePtr>>2]=$268,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $325 = Math_fround($211 * $324);
   $326 = Math_fround($213 * $324);
   $327 = Math_fround($215 * $324);
   $328 = Math_fround($217 * $324);
   $329 = Math_fround($325 + $320);
   $330 = Math_fround($326 + $321);
   $331 = Math_fround($327 + $322);
   $332 = Math_fround($328 + $323);
   $333 = (HEAP32[tempDoublePtr>>2]=$270,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $334 = Math_fround($219 * $333);
   $335 = Math_fround($221 * $333);
   $336 = Math_fround($223 * $333);
   $337 = Math_fround($225 * $333);
   $338 = Math_fround($334 + $329);
   $339 = Math_fround($335 + $330);
   $340 = Math_fround($336 + $331);
   $341 = Math_fround($337 + $332);
   $342 = (HEAP32[tempDoublePtr>>2]=$272,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $343 = Math_fround($227 * $342);
   $344 = Math_fround($229 * $342);
   $345 = Math_fround($231 * $342);
   $346 = Math_fround($233 * $342);
   $347 = Math_fround($343 + $338);
   $348 = Math_fround($344 + $339);
   $349 = Math_fround($345 + $340);
   $350 = Math_fround($346 + $341);
   $351 = (HEAP32[tempDoublePtr>>2]=$295,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $352 = Math_fround($235 * $351);
   $353 = Math_fround($237 * $351);
   $354 = Math_fround($239 * $351);
   $355 = Math_fround($241 * $351);
   $356 = Math_fround($352 + $347);
   $357 = Math_fround($353 + $348);
   $358 = Math_fround($354 + $349);
   $359 = Math_fround($355 + $350);
   $360 = (HEAP32[tempDoublePtr>>2]=$296,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $361 = Math_fround($243 * $360);
   $362 = Math_fround($245 * $360);
   $363 = Math_fround($247 * $360);
   $364 = Math_fround($249 * $360);
   $365 = Math_fround($361 + $356);
   $366 = Math_fround($362 + $357);
   $367 = Math_fround($363 + $358);
   $368 = Math_fround($364 + $359);
   $369 = (HEAP32[tempDoublePtr>>2]=$297,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $370 = Math_fround($251 * $369);
   $371 = Math_fround($253 * $369);
   $372 = Math_fround($255 * $369);
   $373 = Math_fround($257 * $369);
   $374 = Math_fround($370 + $365);
   $375 = Math_fround($371 + $366);
   $376 = Math_fround($372 + $367);
   $377 = Math_fround($373 + $368);
   $378 = $not$x$i$i$i$i ? $374 : Math_fround(0.0);
   $379 = Math_fround($351 + $378);
   $380 = $not$y$i$i$i$i ? $375 : Math_fround(0.0);
   $381 = Math_fround($360 + $380);
   $382 = $not$z$i$i$i$i ? $376 : Math_fround(0.0);
   $383 = Math_fround($369 + $382);
   $384 = (HEAP32[tempDoublePtr>>2]=$298,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $385 = $not$w$i$i$i$i ? $377 : Math_fround(0.0);
   $386 = Math_fround($384 + $385);
   $387 = (HEAPF32[tempDoublePtr>>2]=$379,HEAP32[tempDoublePtr>>2]|0);
   $388 = (HEAPF32[tempDoublePtr>>2]=$381,HEAP32[tempDoublePtr>>2]|0);
   $389 = (HEAPF32[tempDoublePtr>>2]=$383,HEAP32[tempDoublePtr>>2]|0);
   $390 = (HEAPF32[tempDoublePtr>>2]=$386,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$055$i>>2] = $387;
   HEAP32[$262>>2] = $388;
   HEAP32[$264>>2] = $389;
   HEAP32[$266>>2] = $390;
   $391 = HEAP32[481088>>2]|0;
   $392 = HEAP32[((481088 + 4|0))>>2]|0;
   $393 = HEAP32[((481088 + 8|0))>>2]|0;
   $394 = HEAP32[((481088 + 12|0))>>2]|0;
   $395 = $391 & $291;
   $396 = $392 & $292;
   $397 = $393 & $293;
   $398 = $394 & $294;
   $399 = $395 ^ $295;
   $400 = $396 ^ $296;
   $401 = $397 ^ $297;
   $402 = $398 ^ $298;
   $403 = HEAP32[$prevBias>>2]|0;
   $404 = HEAP32[$258>>2]|0;
   $405 = HEAP32[$259>>2]|0;
   $406 = HEAP32[$260>>2]|0;
   $407 = (HEAP32[tempDoublePtr>>2]=$399,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $408 = (HEAP32[tempDoublePtr>>2]=$403,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $409 = $not$x$i$i$i$i ? $408 : Math_fround(0.0);
   $410 = Math_fround($407 + $409);
   $411 = (HEAP32[tempDoublePtr>>2]=$400,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $412 = (HEAP32[tempDoublePtr>>2]=$404,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $413 = $not$y$i$i$i$i ? $412 : Math_fround(0.0);
   $414 = Math_fround($411 + $413);
   $415 = (HEAP32[tempDoublePtr>>2]=$401,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $416 = (HEAP32[tempDoublePtr>>2]=$405,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $417 = $not$z$i$i$i$i ? $416 : Math_fround(0.0);
   $418 = Math_fround($415 + $417);
   $419 = (HEAP32[tempDoublePtr>>2]=$402,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $420 = (HEAP32[tempDoublePtr>>2]=$406,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $421 = $not$w$i$i$i$i ? $420 : Math_fround(0.0);
   $422 = Math_fround($419 + $421);
   $423 = (HEAPF32[tempDoublePtr>>2]=$410,HEAP32[tempDoublePtr>>2]|0);
   $424 = (HEAPF32[tempDoublePtr>>2]=$414,HEAP32[tempDoublePtr>>2]|0);
   $425 = (HEAPF32[tempDoublePtr>>2]=$418,HEAP32[tempDoublePtr>>2]|0);
   $426 = (HEAPF32[tempDoublePtr>>2]=$422,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$0154$i>>2] = $423;
   HEAP32[$269>>2] = $424;
   HEAP32[$271>>2] = $425;
   HEAP32[$273>>2] = $426;
   $427 = (($$055$i) + 16|0);
   $428 = (($$0154$i) + 16|0);
   $429 = (($309) + 16|0);
   $430 = ($427|0)==($5|0);
   if ($430) {
    break;
   } else {
    $$0154$i = $428;$$055$i = $427;$309 = $429;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE15constrainTetherEv($this) {
 $this = $this|0;
 var $$lcssa = Math_fround(0), $$lcssa62 = Math_fround(0), $$lcssa63 = Math_fround(0), $$lcssa64 = Math_fround(0), $$sum$i59 = 0, $$sum1$i60 = 0, $$sum2$i61 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0;
 var $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $curIt$070 = 0, $tFirst$069 = 0, $tIt$065 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 112|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $3 == Math_fround(0.0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($1) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($1) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $8 << 2;
 $12 = (($10) + ($11<<2)|0);
 $13 = (($1) + 104|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($6<<3)|0);
 $16 = (Math_fround(($8>>>0)));
 $17 = Math_fround($3 * $16);
 $18 = (Math_fround(($6>>>0)));
 $19 = Math_fround($17 / $18);
 $20 = (HEAPF32[tempDoublePtr>>2]=$19,HEAP32[tempDoublePtr>>2]|0);
 $21 = (($1) + 116|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = ($11|0)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = HEAP32[((481120 + 12|0))>>2]|0;
 $25 = HEAP32[((481120 + 8|0))>>2]|0;
 $26 = HEAP32[((481120 + 4|0))>>2]|0;
 $27 = HEAP32[481120>>2]|0;
 $28 = $20 & $24;
 $29 = $20 & $25;
 $30 = $20 & $26;
 $31 = $20 & $27;
 $32 = (HEAP32[tempDoublePtr>>2]=$31,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $33 = (HEAP32[tempDoublePtr>>2]=$30,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $34 = (HEAP32[tempDoublePtr>>2]=$29,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $35 = (HEAP32[tempDoublePtr>>2]=$28,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $curIt$070 = $10;$tFirst$069 = $14;
 while(1) {
  $36 = Math_fround(HEAPF32[$curIt$070>>2]);
  $37 = (($curIt$070) + 4|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($curIt$070) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($curIt$070) + 12|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = ($tFirst$069>>>0)<($15>>>0);
  if ($43) {
   $44 = HEAP32[481152>>2]|0;
   $45 = HEAP32[((481152 + 4|0))>>2]|0;
   $46 = HEAP32[((481152 + 8|0))>>2]|0;
   $47 = HEAP32[((481152 + 12|0))>>2]|0;
   $48 = (HEAP32[tempDoublePtr>>2]=$44,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $49 = (HEAP32[tempDoublePtr>>2]=$45,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $50 = (HEAP32[tempDoublePtr>>2]=$46,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $51 = (HEAP32[tempDoublePtr>>2]=$47,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $108 = Math_fround(0.0);$110 = Math_fround(0.0);$112 = Math_fround(0.0);$114 = Math_fround(0.0);$tIt$065 = $tFirst$069;
   while(1) {
    $52 = HEAP16[$tIt$065>>1]|0;
    $53 = $52&65535;
    $54 = $53 << 4;
    $55 = (($10) + ($54)|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $$sum$i59 = $54 | 4;
    $57 = (($10) + ($$sum$i59)|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $$sum1$i60 = $54 | 8;
    $59 = (($10) + ($$sum1$i60)|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $$sum2$i61 = $54 | 12;
    $61 = (($10) + ($$sum2$i61)|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = Math_fround($56 - $36);
    $64 = Math_fround($58 - $38);
    $65 = Math_fround($60 - $40);
    $66 = Math_fround($62 - $42);
    $67 = Math_fround($63 * $63);
    $68 = Math_fround($64 * $64);
    $69 = Math_fround($67 + $68);
    $70 = Math_fround($65 * $65);
    $71 = Math_fround($69 + $70);
    $72 = Math_fround($48 + $71);
    $73 = Math_fround($71 + $49);
    $74 = Math_fround($71 + $50);
    $75 = Math_fround($71 + $51);
    $76 = (($tIt$065) + 4|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = Math_fround($22 * $77);
    $79 = (Math_fround(Math_sqrt((Math_fround($72)))));
    $80 = (Math_fround(Math_sqrt((Math_fround($73)))));
    $81 = (Math_fround(Math_sqrt((Math_fround($74)))));
    $82 = (Math_fround(Math_sqrt((Math_fround($75)))));
    $83 = Math_fround(Math_fround(1.0) / $79);
    $84 = Math_fround(Math_fround(1.0) / $80);
    $85 = Math_fround(Math_fround(1.0) / $81);
    $86 = Math_fround(Math_fround(1.0) / $82);
    $87 = Math_fround($78 * $83);
    $88 = Math_fround($78 * $84);
    $89 = Math_fround($78 * $85);
    $90 = Math_fround($78 * $86);
    $91 = Math_fround(Math_fround(1.0) - $87);
    $92 = Math_fround(Math_fround(1.0) - $88);
    $93 = Math_fround(Math_fround(1.0) - $89);
    $94 = Math_fround(Math_fround(1.0) - $90);
    $95 = $91 < Math_fround(0.0);
    $96 = $95 ? Math_fround(0.0) : $91;
    $97 = $92 < Math_fround(0.0);
    $98 = $97 ? Math_fround(0.0) : $92;
    $99 = $93 < Math_fround(0.0);
    $100 = $99 ? Math_fround(0.0) : $93;
    $101 = $94 < Math_fround(0.0);
    $102 = $101 ? Math_fround(0.0) : $94;
    $103 = Math_fround($63 * $96);
    $104 = Math_fround($64 * $98);
    $105 = Math_fround($65 * $100);
    $106 = Math_fround($66 * $102);
    $107 = Math_fround($108 + $103);
    $109 = Math_fround($110 + $104);
    $111 = Math_fround($112 + $105);
    $113 = Math_fround($114 + $106);
    $115 = (($tIt$065) + ($8<<3)|0);
    $116 = ($115>>>0)<($15>>>0);
    if ($116) {
     $108 = $107;$110 = $109;$112 = $111;$114 = $113;$tIt$065 = $115;
    } else {
     $$lcssa = $113;$$lcssa62 = $111;$$lcssa63 = $109;$$lcssa64 = $107;
     break;
    }
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa62 = Math_fround(0.0);$$lcssa63 = Math_fround(0.0);$$lcssa64 = Math_fround(0.0);
  }
  $117 = Math_fround($32 * $$lcssa64);
  $118 = Math_fround($33 * $$lcssa63);
  $119 = Math_fround($34 * $$lcssa62);
  $120 = Math_fround($35 * $$lcssa);
  $121 = Math_fround($36 + $117);
  $122 = Math_fround($38 + $118);
  $123 = Math_fround($40 + $119);
  $124 = Math_fround($42 + $120);
  HEAPF32[$curIt$070>>2] = $121;
  HEAPF32[$37>>2] = $122;
  HEAPF32[$39>>2] = $123;
  HEAPF32[$41>>2] = $124;
  $125 = (($curIt$070) + 16|0);
  $126 = (($tFirst$069) + 8|0);
  $127 = ($125|0)==($12|0);
  if ($127) {
   break;
  } else {
   $curIt$070 = $125;$tFirst$069 = $126;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE11solveFabricEv($this) {
 $this = $this|0;
 var $$01368$i = 0, $$01396$i = 0, $$0369$i = 0, $$0397$i = 0, $$sum = 0, $$sum$i23341$i = 0, $$sum$i23369$i = 0, $$sum$i26338$i = 0, $$sum$i26366$i = 0, $$sum$i29335$i = 0, $$sum$i29363$i = 0, $$sum$i32332$i = 0, $$sum$i32360$i = 0, $$sum$i35329$i = 0, $$sum$i35357$i = 0, $$sum$i38326$i = 0, $$sum$i38354$i = 0, $$sum$i41323$i = 0, $$sum$i41351$i = 0, $$sum$i44320$i = 0;
 var $$sum$i44348$i = 0, $$sum1$i24342$i = 0, $$sum1$i24370$i = 0, $$sum1$i27339$i = 0, $$sum1$i27367$i = 0, $$sum1$i30336$i = 0, $$sum1$i30364$i = 0, $$sum1$i33333$i = 0, $$sum1$i33361$i = 0, $$sum1$i36330$i = 0, $$sum1$i36358$i = 0, $$sum1$i39327$i = 0, $$sum1$i39355$i = 0, $$sum1$i42324$i = 0, $$sum1$i42352$i = 0, $$sum1$i45321$i = 0, $$sum1$i45349$i = 0, $$sum2$i25343$i = 0, $$sum2$i25371$i = 0, $$sum2$i28340$i = 0;
 var $$sum2$i28368$i = 0, $$sum2$i31337$i = 0, $$sum2$i31365$i = 0, $$sum2$i34334$i = 0, $$sum2$i34362$i = 0, $$sum2$i37331$i = 0, $$sum2$i37359$i = 0, $$sum2$i40328$i = 0, $$sum2$i40356$i = 0, $$sum2$i43325$i = 0, $$sum2$i43353$i = 0, $$sum2$i46322$i = 0, $$sum2$i46350$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0;
 var $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0;
 var $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0;
 var $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0);
 var $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0;
 var $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0);
 var $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0);
 var $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0);
 var $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0);
 var $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0;
 var $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0);
 var $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = 0, $444 = 0, $445 = 0, $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0);
 var $465 = Math_fround(0), $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = Math_fround(0), $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = Math_fround(0), $504 = 0, $505 = Math_fround(0), $506 = 0, $507 = Math_fround(0), $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = Math_fround(0), $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = 0, $517 = Math_fround(0), $518 = 0;
 var $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = Math_fround(0), $53 = 0, $530 = 0, $531 = Math_fround(0), $532 = 0, $533 = Math_fround(0), $534 = 0, $535 = Math_fround(0), $536 = 0;
 var $537 = Math_fround(0), $538 = 0, $539 = Math_fround(0), $54 = Math_fround(0), $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $546 = 0, $547 = Math_fround(0), $548 = 0, $549 = Math_fround(0), $55 = Math_fround(0), $550 = 0, $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = 0;
 var $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = Math_fround(0), $560 = 0, $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0);
 var $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0);
 var $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = 0, $602 = Math_fround(0), $603 = 0, $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0);
 var $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0);
 var $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0);
 var $645 = Math_fround(0), $646 = 0, $647 = Math_fround(0), $648 = Math_fround(0), $649 = 0, $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = 0, $653 = Math_fround(0), $654 = Math_fround(0), $655 = 0, $656 = Math_fround(0), $657 = 0, $658 = Math_fround(0), $659 = 0, $66 = Math_fround(0), $660 = Math_fround(0), $661 = 0, $662 = Math_fround(0);
 var $663 = 0, $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0);
 var $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0;
 var $7 = 0, $70 = 0, $700 = 0, $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0);
 var $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0;
 var $735 = 0, $736 = 0, $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0);
 var $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0);
 var $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0);
 var $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0);
 var $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $cIt$043 = 0, $not$w$i$i$i$i = 0, $not$w$i$i$i$i5 = 0, $not$x$i$i$i$i = 0, $not$x$i$i$i$i2 = 0;
 var $not$y$i$i$i$i = 0, $not$y$i$i$i$i3 = 0, $not$z$i$i$i$i = 0, $not$z$i$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($1) + 80|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($1) + 96|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 144|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 532|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = ($3|0)==($5|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = (($1) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[481104>>2]|0;
 $24 = HEAP32[((481104 + 4|0))>>2]|0;
 $25 = HEAP32[((481104 + 8|0))>>2]|0;
 $26 = HEAP32[((481104 + 12|0))>>2]|0;
 $27 = HEAP32[481136>>2]|0;
 $28 = HEAP32[((481136 + 8|0))>>2]|0;
 $29 = HEAP32[((481136 + 12|0))>>2]|0;
 $cIt$043 = $3;
 while(1) {
  $30 = HEAP16[$cIt$043>>1]|0;
  $31 = $30&65535;
  $32 = (($7) + ($31<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($11) + ($33<<2)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($9) + ($35<<2)|0);
  $$sum = (($33) + 1)|0;
  $37 = (($11) + ($$sum<<2)|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($9) + ($38<<2)|0);
  $40 = $35 << 1;
  $41 = (($13) + ($40<<1)|0);
  $42 = (($cIt$043) + 4|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = (($42) + 4|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($42) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = (($42) + 12|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (HEAPF32[tempDoublePtr>>2]=$43,HEAP32[tempDoublePtr>>2]|0);
  $51 = (HEAPF32[tempDoublePtr>>2]=$45,HEAP32[tempDoublePtr>>2]|0);
  $52 = (HEAPF32[tempDoublePtr>>2]=$47,HEAP32[tempDoublePtr>>2]|0);
  $53 = (HEAPF32[tempDoublePtr>>2]=$49,HEAP32[tempDoublePtr>>2]|0);
  $54 = Math_fround($19 * $43);
  $55 = Math_fround($19 * $45);
  $56 = Math_fround($19 * $47);
  $57 = Math_fround($19 * $49);
  $58 = Math_fround($54 * Math_fround(0.693147182464599609375));
  $59 = (Math_fround(+(Math_exp((+$58)))));
  $60 = Math_fround($55 * Math_fround(0.693147182464599609375));
  $61 = (Math_fround(+(Math_exp((+$60)))));
  $62 = Math_fround($56 * Math_fround(0.693147182464599609375));
  $63 = (Math_fround(+(Math_exp((+$62)))));
  $64 = Math_fround($57 * Math_fround(0.693147182464599609375));
  $65 = (Math_fround(+(Math_exp((+$64)))));
  $66 = Math_fround(Math_fround(1.0) - $59);
  $67 = Math_fround(Math_fround(1.0) - $61);
  $68 = Math_fround(Math_fround(1.0) - $63);
  $69 = Math_fround(Math_fround(1.0) - $65);
  $70 = (HEAPF32[tempDoublePtr>>2]=$66,HEAP32[tempDoublePtr>>2]|0);
  $71 = (HEAPF32[tempDoublePtr>>2]=$67,HEAP32[tempDoublePtr>>2]|0);
  $72 = (HEAPF32[tempDoublePtr>>2]=$68,HEAP32[tempDoublePtr>>2]|0);
  $73 = (HEAPF32[tempDoublePtr>>2]=$69,HEAP32[tempDoublePtr>>2]|0);
  $74 = $70 ^ $50;
  $75 = $71 ^ $51;
  $76 = $72 ^ $52;
  $77 = $73 ^ $53;
  $78 = $23 & $74;
  $79 = $24 & $75;
  $80 = $25 & $76;
  $81 = $26 & $77;
  $82 = $78 ^ $50;
  $83 = $79 ^ $51;
  $84 = $80 ^ $52;
  $85 = $81 ^ $53;
  $86 = $27 & $82;
  $87 = $28 & $84;
  $88 = $29 & $85;
  $89 = (HEAP32[tempDoublePtr>>2]=$86,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $90 = $89 == Math_fround(0.0);
  if ($90) {
   $91 = HEAP32[((481136 + 4|0))>>2]|0;
   $92 = $91 & $83;
   $93 = (HEAP32[tempDoublePtr>>2]=$92,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $94 = $93 == Math_fround(0.0);
   if ($94) {
    $95 = (HEAP32[tempDoublePtr>>2]=$87,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $96 = $95 == Math_fround(0.0);
    if ($96) {
     $97 = (HEAP32[tempDoublePtr>>2]=$88,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $98 = $97 == Math_fround(0.0);
     if ($98) {
      $99 = ($35|0)==($38|0);
      if (!($99)) {
       $100 = HEAP32[481168>>2]|0;
       $101 = HEAP32[((481168 + 4|0))>>2]|0;
       $102 = HEAP32[((481168 + 8|0))>>2]|0;
       $103 = HEAP32[((481168 + 12|0))>>2]|0;
       $104 = (HEAP32[tempDoublePtr>>2]=$100,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $105 = (HEAP32[tempDoublePtr>>2]=$101,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $106 = (HEAP32[tempDoublePtr>>2]=$102,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $107 = (HEAP32[tempDoublePtr>>2]=$103,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $108 = HEAP32[481152>>2]|0;
       $109 = HEAP32[((481152 + 4|0))>>2]|0;
       $110 = HEAP32[((481152 + 8|0))>>2]|0;
       $111 = HEAP32[((481152 + 12|0))>>2]|0;
       $112 = (HEAP32[tempDoublePtr>>2]=$108,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $113 = (HEAP32[tempDoublePtr>>2]=$109,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $114 = (HEAP32[tempDoublePtr>>2]=$110,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $115 = (HEAP32[tempDoublePtr>>2]=$111,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $116 = HEAP32[481120>>2]|0;
       $117 = HEAP32[((481120 + 4|0))>>2]|0;
       $118 = HEAP32[((481120 + 8|0))>>2]|0;
       $119 = HEAP32[((481120 + 12|0))>>2]|0;
       $120 = (HEAP32[tempDoublePtr>>2]=$82,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $$01368$i = $41;$$0369$i = $36;
       while(1) {
        $121 = HEAP16[$$01368$i>>1]|0;
        $122 = $121&65535;
        $123 = $122 << 4;
        $124 = (($$01368$i) + 2|0);
        $125 = HEAP16[$124>>1]|0;
        $126 = $125&65535;
        $127 = $126 << 4;
        $128 = (($$01368$i) + 4|0);
        $129 = HEAP16[$128>>1]|0;
        $130 = $129&65535;
        $131 = $130 << 4;
        $132 = (($$01368$i) + 6|0);
        $133 = HEAP16[$132>>1]|0;
        $134 = $133&65535;
        $135 = $134 << 4;
        $136 = (($$01368$i) + 8|0);
        $137 = HEAP16[$136>>1]|0;
        $138 = $137&65535;
        $139 = $138 << 4;
        $140 = (($$01368$i) + 10|0);
        $141 = HEAP16[$140>>1]|0;
        $142 = $141&65535;
        $143 = $142 << 4;
        $144 = (($$01368$i) + 12|0);
        $145 = HEAP16[$144>>1]|0;
        $146 = $145&65535;
        $147 = $146 << 4;
        $148 = (($$01368$i) + 14|0);
        $149 = HEAP16[$148>>1]|0;
        $150 = $149&65535;
        $151 = $150 << 4;
        $152 = (($22) + ($123)|0);
        $153 = Math_fround(HEAPF32[$152>>2]);
        $$sum$i44320$i = $123 | 4;
        $154 = (($22) + ($$sum$i44320$i)|0);
        $155 = Math_fround(HEAPF32[$154>>2]);
        $$sum1$i45321$i = $123 | 8;
        $156 = (($22) + ($$sum1$i45321$i)|0);
        $157 = Math_fround(HEAPF32[$156>>2]);
        $$sum2$i46322$i = $123 | 12;
        $158 = (($22) + ($$sum2$i46322$i)|0);
        $159 = Math_fround(HEAPF32[$158>>2]);
        $160 = (($22) + ($127)|0);
        $161 = Math_fround(HEAPF32[$160>>2]);
        $$sum$i41323$i = $127 | 4;
        $162 = (($22) + ($$sum$i41323$i)|0);
        $163 = Math_fround(HEAPF32[$162>>2]);
        $$sum1$i42324$i = $127 | 8;
        $164 = (($22) + ($$sum1$i42324$i)|0);
        $165 = Math_fround(HEAPF32[$164>>2]);
        $$sum2$i43325$i = $127 | 12;
        $166 = (($22) + ($$sum2$i43325$i)|0);
        $167 = Math_fround(HEAPF32[$166>>2]);
        $168 = (($22) + ($131)|0);
        $169 = Math_fround(HEAPF32[$168>>2]);
        $$sum$i38326$i = $131 | 4;
        $170 = (($22) + ($$sum$i38326$i)|0);
        $171 = Math_fround(HEAPF32[$170>>2]);
        $$sum1$i39327$i = $131 | 8;
        $172 = (($22) + ($$sum1$i39327$i)|0);
        $173 = Math_fround(HEAPF32[$172>>2]);
        $$sum2$i40328$i = $131 | 12;
        $174 = (($22) + ($$sum2$i40328$i)|0);
        $175 = Math_fround(HEAPF32[$174>>2]);
        $176 = (($22) + ($135)|0);
        $177 = Math_fround(HEAPF32[$176>>2]);
        $$sum$i35329$i = $135 | 4;
        $178 = (($22) + ($$sum$i35329$i)|0);
        $179 = Math_fround(HEAPF32[$178>>2]);
        $$sum1$i36330$i = $135 | 8;
        $180 = (($22) + ($$sum1$i36330$i)|0);
        $181 = Math_fround(HEAPF32[$180>>2]);
        $$sum2$i37331$i = $135 | 12;
        $182 = (($22) + ($$sum2$i37331$i)|0);
        $183 = Math_fround(HEAPF32[$182>>2]);
        $184 = (($22) + ($139)|0);
        $185 = Math_fround(HEAPF32[$184>>2]);
        $$sum$i32332$i = $139 | 4;
        $186 = (($22) + ($$sum$i32332$i)|0);
        $187 = Math_fround(HEAPF32[$186>>2]);
        $$sum1$i33333$i = $139 | 8;
        $188 = (($22) + ($$sum1$i33333$i)|0);
        $189 = Math_fround(HEAPF32[$188>>2]);
        $$sum2$i34334$i = $139 | 12;
        $190 = (($22) + ($$sum2$i34334$i)|0);
        $191 = Math_fround(HEAPF32[$190>>2]);
        $192 = (($22) + ($143)|0);
        $193 = Math_fround(HEAPF32[$192>>2]);
        $$sum$i29335$i = $143 | 4;
        $194 = (($22) + ($$sum$i29335$i)|0);
        $195 = Math_fround(HEAPF32[$194>>2]);
        $$sum1$i30336$i = $143 | 8;
        $196 = (($22) + ($$sum1$i30336$i)|0);
        $197 = Math_fround(HEAPF32[$196>>2]);
        $$sum2$i31337$i = $143 | 12;
        $198 = (($22) + ($$sum2$i31337$i)|0);
        $199 = Math_fround(HEAPF32[$198>>2]);
        $200 = (($22) + ($147)|0);
        $201 = Math_fround(HEAPF32[$200>>2]);
        $$sum$i26338$i = $147 | 4;
        $202 = (($22) + ($$sum$i26338$i)|0);
        $203 = Math_fround(HEAPF32[$202>>2]);
        $$sum1$i27339$i = $147 | 8;
        $204 = (($22) + ($$sum1$i27339$i)|0);
        $205 = Math_fround(HEAPF32[$204>>2]);
        $$sum2$i28340$i = $147 | 12;
        $206 = (($22) + ($$sum2$i28340$i)|0);
        $207 = Math_fround(HEAPF32[$206>>2]);
        $208 = (($22) + ($151)|0);
        $209 = Math_fround(HEAPF32[$208>>2]);
        $$sum$i23341$i = $151 | 4;
        $210 = (($22) + ($$sum$i23341$i)|0);
        $211 = Math_fround(HEAPF32[$210>>2]);
        $$sum1$i24342$i = $151 | 8;
        $212 = (($22) + ($$sum1$i24342$i)|0);
        $213 = Math_fround(HEAPF32[$212>>2]);
        $$sum2$i25343$i = $151 | 12;
        $214 = (($22) + ($$sum2$i25343$i)|0);
        $215 = Math_fround(HEAPF32[$214>>2]);
        $216 = Math_fround($104 * $153);
        $217 = Math_fround($105 * $155);
        $218 = Math_fround($106 * $157);
        $219 = Math_fround($107 * $159);
        $220 = Math_fround($216 + $161);
        $221 = Math_fround($217 + $163);
        $222 = Math_fround($218 + $165);
        $223 = Math_fround($219 + $167);
        $224 = Math_fround($104 * $169);
        $225 = Math_fround($105 * $171);
        $226 = Math_fround($106 * $173);
        $227 = Math_fround($107 * $175);
        $228 = Math_fround($224 + $177);
        $229 = Math_fround($225 + $179);
        $230 = Math_fround($226 + $181);
        $231 = Math_fround($227 + $183);
        $232 = Math_fround($104 * $185);
        $233 = Math_fround($105 * $187);
        $234 = Math_fround($106 * $189);
        $235 = Math_fround($107 * $191);
        $236 = Math_fround($232 + $193);
        $237 = Math_fround($233 + $195);
        $238 = Math_fround($234 + $197);
        $239 = Math_fround($235 + $199);
        $240 = Math_fround($104 * $201);
        $241 = Math_fround($105 * $203);
        $242 = Math_fround($106 * $205);
        $243 = Math_fround($107 * $207);
        $244 = Math_fround($240 + $209);
        $245 = Math_fround($241 + $211);
        $246 = Math_fround($242 + $213);
        $247 = Math_fround($243 + $215);
        $248 = Math_fround(HEAPF32[$$0369$i>>2]);
        $249 = (($$0369$i) + 4|0);
        $250 = Math_fround(HEAPF32[$249>>2]);
        $251 = (($$0369$i) + 8|0);
        $252 = Math_fround(HEAPF32[$251>>2]);
        $253 = (($$0369$i) + 12|0);
        $254 = Math_fround(HEAPF32[$253>>2]);
        $255 = Math_fround($220 * $220);
        $256 = Math_fround($228 * $228);
        $257 = Math_fround($236 * $236);
        $258 = Math_fround($244 * $244);
        $259 = Math_fround($112 + $255);
        $260 = Math_fround($113 + $256);
        $261 = Math_fround($114 + $257);
        $262 = Math_fround($115 + $258);
        $263 = Math_fround($221 * $221);
        $264 = Math_fround($229 * $229);
        $265 = Math_fround($237 * $237);
        $266 = Math_fround($245 * $245);
        $267 = Math_fround($263 + $259);
        $268 = Math_fround($264 + $260);
        $269 = Math_fround($265 + $261);
        $270 = Math_fround($266 + $262);
        $271 = Math_fround($222 * $222);
        $272 = Math_fround($230 * $230);
        $273 = Math_fround($238 * $238);
        $274 = Math_fround($246 * $246);
        $275 = Math_fround($271 + $267);
        $276 = Math_fround($272 + $268);
        $277 = Math_fround($273 + $269);
        $278 = Math_fround($274 + $270);
        $279 = (Math_fround(Math_sqrt((Math_fround($275)))));
        $280 = (Math_fround(Math_sqrt((Math_fround($276)))));
        $281 = (Math_fround(Math_sqrt((Math_fround($277)))));
        $282 = (Math_fround(Math_sqrt((Math_fround($278)))));
        $283 = Math_fround(Math_fround(1.0) / $279);
        $284 = Math_fround(Math_fround(1.0) / $280);
        $285 = Math_fround(Math_fround(1.0) / $281);
        $286 = Math_fround(Math_fround(1.0) / $282);
        $287 = Math_fround($248 * $283);
        $288 = Math_fround($250 * $284);
        $289 = Math_fround($252 * $285);
        $290 = Math_fround($254 * $286);
        $291 = Math_fround(Math_fround(1.0) - $287);
        $292 = Math_fround(Math_fround(1.0) - $288);
        $293 = Math_fround(Math_fround(1.0) - $289);
        $294 = Math_fround(Math_fround(1.0) - $290);
        $not$x$i$i$i$i2 = $248 > $112;
        $not$y$i$i$i$i3 = $250 > $113;
        $not$z$i$i$i$i4 = $252 > $114;
        $not$w$i$i$i$i5 = $254 > $115;
        $295 = $not$x$i$i$i$i2 ? $291 : Math_fround(0.0);
        $296 = Math_fround($120 * $295);
        $297 = $not$y$i$i$i$i3 ? $292 : Math_fround(0.0);
        $298 = Math_fround($120 * $297);
        $299 = $not$z$i$i$i$i4 ? $293 : Math_fround(0.0);
        $300 = Math_fround($120 * $299);
        $301 = $not$w$i$i$i$i5 ? $294 : Math_fround(0.0);
        $302 = Math_fround($120 * $301);
        $303 = Math_fround($112 + $223);
        $304 = Math_fround($113 + $231);
        $305 = Math_fround($114 + $239);
        $306 = Math_fround($115 + $247);
        $307 = Math_fround(Math_fround(1.0) / $303);
        $308 = Math_fround(Math_fround(1.0) / $304);
        $309 = Math_fround(Math_fround(1.0) / $305);
        $310 = Math_fround(Math_fround(1.0) / $306);
        $311 = Math_fround($296 * $307);
        $312 = Math_fround($298 * $308);
        $313 = Math_fround($300 * $309);
        $314 = Math_fround($302 * $310);
        $315 = Math_fround($220 * $311);
        $316 = Math_fround($221 * $311);
        $317 = Math_fround($222 * $311);
        $318 = Math_fround($223 * $311);
        $319 = (HEAPF32[tempDoublePtr>>2]=$315,HEAP32[tempDoublePtr>>2]|0);
        $320 = (HEAPF32[tempDoublePtr>>2]=$316,HEAP32[tempDoublePtr>>2]|0);
        $321 = (HEAPF32[tempDoublePtr>>2]=$317,HEAP32[tempDoublePtr>>2]|0);
        $322 = (HEAPF32[tempDoublePtr>>2]=$318,HEAP32[tempDoublePtr>>2]|0);
        $323 = $319 & $116;
        $324 = $320 & $117;
        $325 = $321 & $118;
        $326 = $322 & $119;
        $327 = Math_fround($228 * $312);
        $328 = Math_fround($229 * $312);
        $329 = Math_fround($230 * $312);
        $330 = Math_fround($231 * $312);
        $331 = (HEAPF32[tempDoublePtr>>2]=$327,HEAP32[tempDoublePtr>>2]|0);
        $332 = (HEAPF32[tempDoublePtr>>2]=$328,HEAP32[tempDoublePtr>>2]|0);
        $333 = (HEAPF32[tempDoublePtr>>2]=$329,HEAP32[tempDoublePtr>>2]|0);
        $334 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
        $335 = $331 & $116;
        $336 = $332 & $117;
        $337 = $333 & $118;
        $338 = $334 & $119;
        $339 = Math_fround($236 * $313);
        $340 = Math_fround($237 * $313);
        $341 = Math_fround($238 * $313);
        $342 = Math_fround($239 * $313);
        $343 = (HEAPF32[tempDoublePtr>>2]=$339,HEAP32[tempDoublePtr>>2]|0);
        $344 = (HEAPF32[tempDoublePtr>>2]=$340,HEAP32[tempDoublePtr>>2]|0);
        $345 = (HEAPF32[tempDoublePtr>>2]=$341,HEAP32[tempDoublePtr>>2]|0);
        $346 = (HEAPF32[tempDoublePtr>>2]=$342,HEAP32[tempDoublePtr>>2]|0);
        $347 = $343 & $116;
        $348 = $344 & $117;
        $349 = $345 & $118;
        $350 = $346 & $119;
        $351 = Math_fround($244 * $314);
        $352 = Math_fround($245 * $314);
        $353 = Math_fround($246 * $314);
        $354 = Math_fround($247 * $314);
        $355 = (HEAPF32[tempDoublePtr>>2]=$351,HEAP32[tempDoublePtr>>2]|0);
        $356 = (HEAPF32[tempDoublePtr>>2]=$352,HEAP32[tempDoublePtr>>2]|0);
        $357 = (HEAPF32[tempDoublePtr>>2]=$353,HEAP32[tempDoublePtr>>2]|0);
        $358 = (HEAPF32[tempDoublePtr>>2]=$354,HEAP32[tempDoublePtr>>2]|0);
        $359 = $355 & $116;
        $360 = $356 & $117;
        $361 = $357 & $118;
        $362 = $358 & $119;
        $363 = (HEAP32[tempDoublePtr>>2]=$323,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $364 = Math_fround($159 * $363);
        $365 = (HEAP32[tempDoublePtr>>2]=$324,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $366 = Math_fround($159 * $365);
        $367 = (HEAP32[tempDoublePtr>>2]=$325,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $368 = Math_fround($159 * $367);
        $369 = (HEAP32[tempDoublePtr>>2]=$326,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $370 = Math_fround($159 * $369);
        $371 = Math_fround($153 + $364);
        $372 = Math_fround($155 + $366);
        $373 = Math_fround($157 + $368);
        $374 = Math_fround($159 + $370);
        HEAPF32[$152>>2] = $371;
        HEAPF32[$154>>2] = $372;
        HEAPF32[$156>>2] = $373;
        HEAPF32[$158>>2] = $374;
        $375 = Math_fround($167 * $363);
        $376 = Math_fround($167 * $365);
        $377 = Math_fround($167 * $367);
        $378 = Math_fround($167 * $369);
        $379 = Math_fround($161 - $375);
        $380 = Math_fround($163 - $376);
        $381 = Math_fround($165 - $377);
        $382 = Math_fround($167 - $378);
        HEAPF32[$160>>2] = $379;
        HEAPF32[$162>>2] = $380;
        HEAPF32[$164>>2] = $381;
        HEAPF32[$166>>2] = $382;
        $383 = (HEAP32[tempDoublePtr>>2]=$335,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $384 = Math_fround($175 * $383);
        $385 = (HEAP32[tempDoublePtr>>2]=$336,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $386 = Math_fround($175 * $385);
        $387 = (HEAP32[tempDoublePtr>>2]=$337,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $388 = Math_fround($175 * $387);
        $389 = (HEAP32[tempDoublePtr>>2]=$338,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $390 = Math_fround($175 * $389);
        $391 = Math_fround($169 + $384);
        $392 = Math_fround($171 + $386);
        $393 = Math_fround($173 + $388);
        $394 = Math_fround($175 + $390);
        HEAPF32[$168>>2] = $391;
        HEAPF32[$170>>2] = $392;
        HEAPF32[$172>>2] = $393;
        HEAPF32[$174>>2] = $394;
        $395 = Math_fround($183 * $383);
        $396 = Math_fround($183 * $385);
        $397 = Math_fround($183 * $387);
        $398 = Math_fround($183 * $389);
        $399 = Math_fround($177 - $395);
        $400 = Math_fround($179 - $396);
        $401 = Math_fround($181 - $397);
        $402 = Math_fround($183 - $398);
        HEAPF32[$176>>2] = $399;
        HEAPF32[$178>>2] = $400;
        HEAPF32[$180>>2] = $401;
        HEAPF32[$182>>2] = $402;
        $403 = (HEAP32[tempDoublePtr>>2]=$347,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $404 = Math_fround($191 * $403);
        $405 = (HEAP32[tempDoublePtr>>2]=$348,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $406 = Math_fround($191 * $405);
        $407 = (HEAP32[tempDoublePtr>>2]=$349,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $408 = Math_fround($191 * $407);
        $409 = (HEAP32[tempDoublePtr>>2]=$350,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $410 = Math_fround($191 * $409);
        $411 = Math_fround($185 + $404);
        $412 = Math_fround($187 + $406);
        $413 = Math_fround($189 + $408);
        $414 = Math_fround($191 + $410);
        HEAPF32[$184>>2] = $411;
        HEAPF32[$186>>2] = $412;
        HEAPF32[$188>>2] = $413;
        HEAPF32[$190>>2] = $414;
        $415 = Math_fround($199 * $403);
        $416 = Math_fround($199 * $405);
        $417 = Math_fround($199 * $407);
        $418 = Math_fround($199 * $409);
        $419 = Math_fround($193 - $415);
        $420 = Math_fround($195 - $416);
        $421 = Math_fround($197 - $417);
        $422 = Math_fround($199 - $418);
        HEAPF32[$192>>2] = $419;
        HEAPF32[$194>>2] = $420;
        HEAPF32[$196>>2] = $421;
        HEAPF32[$198>>2] = $422;
        $423 = (HEAP32[tempDoublePtr>>2]=$359,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $424 = Math_fround($207 * $423);
        $425 = (HEAP32[tempDoublePtr>>2]=$360,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $426 = Math_fround($207 * $425);
        $427 = (HEAP32[tempDoublePtr>>2]=$361,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $428 = Math_fround($207 * $427);
        $429 = (HEAP32[tempDoublePtr>>2]=$362,Math_fround(HEAPF32[tempDoublePtr>>2]));
        $430 = Math_fround($207 * $429);
        $431 = Math_fround($201 + $424);
        $432 = Math_fround($203 + $426);
        $433 = Math_fround($205 + $428);
        $434 = Math_fround($207 + $430);
        HEAPF32[$200>>2] = $431;
        HEAPF32[$202>>2] = $432;
        HEAPF32[$204>>2] = $433;
        HEAPF32[$206>>2] = $434;
        $435 = Math_fround($215 * $423);
        $436 = Math_fround($215 * $425);
        $437 = Math_fround($215 * $427);
        $438 = Math_fround($215 * $429);
        $439 = Math_fround($209 - $435);
        $440 = Math_fround($211 - $436);
        $441 = Math_fround($213 - $437);
        $442 = Math_fround($215 - $438);
        HEAPF32[$208>>2] = $439;
        HEAPF32[$210>>2] = $440;
        HEAPF32[$212>>2] = $441;
        HEAPF32[$214>>2] = $442;
        $443 = (($$0369$i) + 16|0);
        $444 = (($$01368$i) + 16|0);
        $445 = ($443|0)==($39|0);
        if ($445) {
         break;
        } else {
         $$01368$i = $444;$$0369$i = $443;
        }
       }
      }
     } else {
      label = 10;
     }
    } else {
     label = 10;
    }
   } else {
    label = 10;
   }
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   label = 0;
   $446 = (HEAP32[tempDoublePtr>>2]=$85,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $447 = (HEAP32[tempDoublePtr>>2]=$84,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $448 = (HEAP32[tempDoublePtr>>2]=$83,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $449 = ($35|0)==($38|0);
   if (!($449)) {
    $450 = HEAP32[481168>>2]|0;
    $451 = HEAP32[((481168 + 4|0))>>2]|0;
    $452 = HEAP32[((481168 + 8|0))>>2]|0;
    $453 = HEAP32[((481168 + 12|0))>>2]|0;
    $454 = (HEAP32[tempDoublePtr>>2]=$450,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $455 = (HEAP32[tempDoublePtr>>2]=$451,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $456 = (HEAP32[tempDoublePtr>>2]=$452,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $457 = (HEAP32[tempDoublePtr>>2]=$453,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $458 = HEAP32[481152>>2]|0;
    $459 = HEAP32[((481152 + 4|0))>>2]|0;
    $460 = HEAP32[((481152 + 8|0))>>2]|0;
    $461 = HEAP32[((481152 + 12|0))>>2]|0;
    $462 = (HEAP32[tempDoublePtr>>2]=$458,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $463 = (HEAP32[tempDoublePtr>>2]=$459,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $464 = (HEAP32[tempDoublePtr>>2]=$460,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $465 = (HEAP32[tempDoublePtr>>2]=$461,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $466 = HEAP32[481120>>2]|0;
    $467 = HEAP32[((481120 + 4|0))>>2]|0;
    $468 = HEAP32[((481120 + 8|0))>>2]|0;
    $469 = HEAP32[((481120 + 12|0))>>2]|0;
    $470 = (HEAP32[tempDoublePtr>>2]=$82,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $$01396$i = $41;$$0397$i = $36;
    while(1) {
     $471 = HEAP16[$$01396$i>>1]|0;
     $472 = $471&65535;
     $473 = $472 << 4;
     $474 = (($$01396$i) + 2|0);
     $475 = HEAP16[$474>>1]|0;
     $476 = $475&65535;
     $477 = $476 << 4;
     $478 = (($$01396$i) + 4|0);
     $479 = HEAP16[$478>>1]|0;
     $480 = $479&65535;
     $481 = $480 << 4;
     $482 = (($$01396$i) + 6|0);
     $483 = HEAP16[$482>>1]|0;
     $484 = $483&65535;
     $485 = $484 << 4;
     $486 = (($$01396$i) + 8|0);
     $487 = HEAP16[$486>>1]|0;
     $488 = $487&65535;
     $489 = $488 << 4;
     $490 = (($$01396$i) + 10|0);
     $491 = HEAP16[$490>>1]|0;
     $492 = $491&65535;
     $493 = $492 << 4;
     $494 = (($$01396$i) + 12|0);
     $495 = HEAP16[$494>>1]|0;
     $496 = $495&65535;
     $497 = $496 << 4;
     $498 = (($$01396$i) + 14|0);
     $499 = HEAP16[$498>>1]|0;
     $500 = $499&65535;
     $501 = $500 << 4;
     $502 = (($22) + ($473)|0);
     $503 = Math_fround(HEAPF32[$502>>2]);
     $$sum$i44348$i = $473 | 4;
     $504 = (($22) + ($$sum$i44348$i)|0);
     $505 = Math_fround(HEAPF32[$504>>2]);
     $$sum1$i45349$i = $473 | 8;
     $506 = (($22) + ($$sum1$i45349$i)|0);
     $507 = Math_fround(HEAPF32[$506>>2]);
     $$sum2$i46350$i = $473 | 12;
     $508 = (($22) + ($$sum2$i46350$i)|0);
     $509 = Math_fround(HEAPF32[$508>>2]);
     $510 = (($22) + ($477)|0);
     $511 = Math_fround(HEAPF32[$510>>2]);
     $$sum$i41351$i = $477 | 4;
     $512 = (($22) + ($$sum$i41351$i)|0);
     $513 = Math_fround(HEAPF32[$512>>2]);
     $$sum1$i42352$i = $477 | 8;
     $514 = (($22) + ($$sum1$i42352$i)|0);
     $515 = Math_fround(HEAPF32[$514>>2]);
     $$sum2$i43353$i = $477 | 12;
     $516 = (($22) + ($$sum2$i43353$i)|0);
     $517 = Math_fround(HEAPF32[$516>>2]);
     $518 = (($22) + ($481)|0);
     $519 = Math_fround(HEAPF32[$518>>2]);
     $$sum$i38354$i = $481 | 4;
     $520 = (($22) + ($$sum$i38354$i)|0);
     $521 = Math_fround(HEAPF32[$520>>2]);
     $$sum1$i39355$i = $481 | 8;
     $522 = (($22) + ($$sum1$i39355$i)|0);
     $523 = Math_fround(HEAPF32[$522>>2]);
     $$sum2$i40356$i = $481 | 12;
     $524 = (($22) + ($$sum2$i40356$i)|0);
     $525 = Math_fround(HEAPF32[$524>>2]);
     $526 = (($22) + ($485)|0);
     $527 = Math_fround(HEAPF32[$526>>2]);
     $$sum$i35357$i = $485 | 4;
     $528 = (($22) + ($$sum$i35357$i)|0);
     $529 = Math_fround(HEAPF32[$528>>2]);
     $$sum1$i36358$i = $485 | 8;
     $530 = (($22) + ($$sum1$i36358$i)|0);
     $531 = Math_fround(HEAPF32[$530>>2]);
     $$sum2$i37359$i = $485 | 12;
     $532 = (($22) + ($$sum2$i37359$i)|0);
     $533 = Math_fround(HEAPF32[$532>>2]);
     $534 = (($22) + ($489)|0);
     $535 = Math_fround(HEAPF32[$534>>2]);
     $$sum$i32360$i = $489 | 4;
     $536 = (($22) + ($$sum$i32360$i)|0);
     $537 = Math_fround(HEAPF32[$536>>2]);
     $$sum1$i33361$i = $489 | 8;
     $538 = (($22) + ($$sum1$i33361$i)|0);
     $539 = Math_fround(HEAPF32[$538>>2]);
     $$sum2$i34362$i = $489 | 12;
     $540 = (($22) + ($$sum2$i34362$i)|0);
     $541 = Math_fround(HEAPF32[$540>>2]);
     $542 = (($22) + ($493)|0);
     $543 = Math_fround(HEAPF32[$542>>2]);
     $$sum$i29363$i = $493 | 4;
     $544 = (($22) + ($$sum$i29363$i)|0);
     $545 = Math_fround(HEAPF32[$544>>2]);
     $$sum1$i30364$i = $493 | 8;
     $546 = (($22) + ($$sum1$i30364$i)|0);
     $547 = Math_fround(HEAPF32[$546>>2]);
     $$sum2$i31365$i = $493 | 12;
     $548 = (($22) + ($$sum2$i31365$i)|0);
     $549 = Math_fround(HEAPF32[$548>>2]);
     $550 = (($22) + ($497)|0);
     $551 = Math_fround(HEAPF32[$550>>2]);
     $$sum$i26366$i = $497 | 4;
     $552 = (($22) + ($$sum$i26366$i)|0);
     $553 = Math_fround(HEAPF32[$552>>2]);
     $$sum1$i27367$i = $497 | 8;
     $554 = (($22) + ($$sum1$i27367$i)|0);
     $555 = Math_fround(HEAPF32[$554>>2]);
     $$sum2$i28368$i = $497 | 12;
     $556 = (($22) + ($$sum2$i28368$i)|0);
     $557 = Math_fround(HEAPF32[$556>>2]);
     $558 = (($22) + ($501)|0);
     $559 = Math_fround(HEAPF32[$558>>2]);
     $$sum$i23369$i = $501 | 4;
     $560 = (($22) + ($$sum$i23369$i)|0);
     $561 = Math_fround(HEAPF32[$560>>2]);
     $$sum1$i24370$i = $501 | 8;
     $562 = (($22) + ($$sum1$i24370$i)|0);
     $563 = Math_fround(HEAPF32[$562>>2]);
     $$sum2$i25371$i = $501 | 12;
     $564 = (($22) + ($$sum2$i25371$i)|0);
     $565 = Math_fround(HEAPF32[$564>>2]);
     $566 = Math_fround($454 * $503);
     $567 = Math_fround($455 * $505);
     $568 = Math_fround($456 * $507);
     $569 = Math_fround($457 * $509);
     $570 = Math_fround($566 + $511);
     $571 = Math_fround($567 + $513);
     $572 = Math_fround($568 + $515);
     $573 = Math_fround($569 + $517);
     $574 = Math_fround($454 * $519);
     $575 = Math_fround($455 * $521);
     $576 = Math_fround($456 * $523);
     $577 = Math_fround($457 * $525);
     $578 = Math_fround($574 + $527);
     $579 = Math_fround($575 + $529);
     $580 = Math_fround($576 + $531);
     $581 = Math_fround($577 + $533);
     $582 = Math_fround($454 * $535);
     $583 = Math_fround($455 * $537);
     $584 = Math_fround($456 * $539);
     $585 = Math_fround($457 * $541);
     $586 = Math_fround($582 + $543);
     $587 = Math_fround($583 + $545);
     $588 = Math_fround($584 + $547);
     $589 = Math_fround($585 + $549);
     $590 = Math_fround($454 * $551);
     $591 = Math_fround($455 * $553);
     $592 = Math_fround($456 * $555);
     $593 = Math_fround($457 * $557);
     $594 = Math_fround($590 + $559);
     $595 = Math_fround($591 + $561);
     $596 = Math_fround($592 + $563);
     $597 = Math_fround($593 + $565);
     $598 = Math_fround(HEAPF32[$$0397$i>>2]);
     $599 = (($$0397$i) + 4|0);
     $600 = Math_fround(HEAPF32[$599>>2]);
     $601 = (($$0397$i) + 8|0);
     $602 = Math_fround(HEAPF32[$601>>2]);
     $603 = (($$0397$i) + 12|0);
     $604 = Math_fround(HEAPF32[$603>>2]);
     $605 = Math_fround($570 * $570);
     $606 = Math_fround($578 * $578);
     $607 = Math_fround($586 * $586);
     $608 = Math_fround($594 * $594);
     $609 = Math_fround($462 + $605);
     $610 = Math_fround($463 + $606);
     $611 = Math_fround($464 + $607);
     $612 = Math_fround($465 + $608);
     $613 = Math_fround($571 * $571);
     $614 = Math_fround($579 * $579);
     $615 = Math_fround($587 * $587);
     $616 = Math_fround($595 * $595);
     $617 = Math_fround($613 + $609);
     $618 = Math_fround($614 + $610);
     $619 = Math_fround($615 + $611);
     $620 = Math_fround($616 + $612);
     $621 = Math_fround($572 * $572);
     $622 = Math_fround($580 * $580);
     $623 = Math_fround($588 * $588);
     $624 = Math_fround($596 * $596);
     $625 = Math_fround($621 + $617);
     $626 = Math_fround($622 + $618);
     $627 = Math_fround($623 + $619);
     $628 = Math_fround($624 + $620);
     $629 = (Math_fround(Math_sqrt((Math_fround($625)))));
     $630 = (Math_fround(Math_sqrt((Math_fround($626)))));
     $631 = (Math_fround(Math_sqrt((Math_fround($627)))));
     $632 = (Math_fround(Math_sqrt((Math_fround($628)))));
     $633 = Math_fround(Math_fround(1.0) / $629);
     $634 = Math_fround(Math_fround(1.0) / $630);
     $635 = Math_fround(Math_fround(1.0) / $631);
     $636 = Math_fround(Math_fround(1.0) / $632);
     $637 = Math_fround($598 * $633);
     $638 = Math_fround($600 * $634);
     $639 = Math_fround($602 * $635);
     $640 = Math_fround($604 * $636);
     $641 = Math_fround(Math_fround(1.0) - $637);
     $642 = Math_fround(Math_fround(1.0) - $638);
     $643 = Math_fround(Math_fround(1.0) - $639);
     $644 = Math_fround(Math_fround(1.0) - $640);
     $not$x$i$i$i$i = $598 > $462;
     $not$y$i$i$i$i = $600 > $463;
     $not$z$i$i$i$i = $602 > $464;
     $not$w$i$i$i$i = $604 > $465;
     $645 = $not$x$i$i$i$i ? $641 : Math_fround(0.0);
     $646 = $446 < $645;
     $647 = $646 ? $446 : $645;
     $648 = $not$y$i$i$i$i ? $642 : Math_fround(0.0);
     $649 = $446 < $648;
     $650 = $649 ? $446 : $648;
     $651 = $not$z$i$i$i$i ? $643 : Math_fround(0.0);
     $652 = $446 < $651;
     $653 = $652 ? $446 : $651;
     $654 = $not$w$i$i$i$i ? $644 : Math_fround(0.0);
     $655 = $446 < $654;
     $656 = $655 ? $446 : $654;
     $657 = $447 < $647;
     $658 = $657 ? $647 : $447;
     $659 = $447 < $650;
     $660 = $659 ? $650 : $447;
     $661 = $447 < $653;
     $662 = $661 ? $653 : $447;
     $663 = $447 < $656;
     $664 = $663 ? $656 : $447;
     $665 = Math_fround($448 * $658);
     $666 = Math_fround($448 * $660);
     $667 = Math_fround($448 * $662);
     $668 = Math_fround($448 * $664);
     $669 = Math_fround($645 - $665);
     $670 = Math_fround($648 - $666);
     $671 = Math_fround($651 - $667);
     $672 = Math_fround($654 - $668);
     $673 = Math_fround($470 * $669);
     $674 = Math_fround($470 * $670);
     $675 = Math_fround($470 * $671);
     $676 = Math_fround($470 * $672);
     $677 = Math_fround($462 + $573);
     $678 = Math_fround($463 + $581);
     $679 = Math_fround($464 + $589);
     $680 = Math_fround($465 + $597);
     $681 = Math_fround(Math_fround(1.0) / $677);
     $682 = Math_fround(Math_fround(1.0) / $678);
     $683 = Math_fround(Math_fround(1.0) / $679);
     $684 = Math_fround(Math_fround(1.0) / $680);
     $685 = Math_fround($681 * $673);
     $686 = Math_fround($682 * $674);
     $687 = Math_fround($683 * $675);
     $688 = Math_fround($684 * $676);
     $689 = Math_fround($570 * $685);
     $690 = Math_fround($571 * $685);
     $691 = Math_fround($572 * $685);
     $692 = Math_fround($573 * $685);
     $693 = (HEAPF32[tempDoublePtr>>2]=$689,HEAP32[tempDoublePtr>>2]|0);
     $694 = (HEAPF32[tempDoublePtr>>2]=$690,HEAP32[tempDoublePtr>>2]|0);
     $695 = (HEAPF32[tempDoublePtr>>2]=$691,HEAP32[tempDoublePtr>>2]|0);
     $696 = (HEAPF32[tempDoublePtr>>2]=$692,HEAP32[tempDoublePtr>>2]|0);
     $697 = $693 & $466;
     $698 = $694 & $467;
     $699 = $695 & $468;
     $700 = $696 & $469;
     $701 = Math_fround($578 * $686);
     $702 = Math_fround($579 * $686);
     $703 = Math_fround($580 * $686);
     $704 = Math_fround($581 * $686);
     $705 = (HEAPF32[tempDoublePtr>>2]=$701,HEAP32[tempDoublePtr>>2]|0);
     $706 = (HEAPF32[tempDoublePtr>>2]=$702,HEAP32[tempDoublePtr>>2]|0);
     $707 = (HEAPF32[tempDoublePtr>>2]=$703,HEAP32[tempDoublePtr>>2]|0);
     $708 = (HEAPF32[tempDoublePtr>>2]=$704,HEAP32[tempDoublePtr>>2]|0);
     $709 = $705 & $466;
     $710 = $706 & $467;
     $711 = $707 & $468;
     $712 = $708 & $469;
     $713 = Math_fround($586 * $687);
     $714 = Math_fround($587 * $687);
     $715 = Math_fround($588 * $687);
     $716 = Math_fround($589 * $687);
     $717 = (HEAPF32[tempDoublePtr>>2]=$713,HEAP32[tempDoublePtr>>2]|0);
     $718 = (HEAPF32[tempDoublePtr>>2]=$714,HEAP32[tempDoublePtr>>2]|0);
     $719 = (HEAPF32[tempDoublePtr>>2]=$715,HEAP32[tempDoublePtr>>2]|0);
     $720 = (HEAPF32[tempDoublePtr>>2]=$716,HEAP32[tempDoublePtr>>2]|0);
     $721 = $717 & $466;
     $722 = $718 & $467;
     $723 = $719 & $468;
     $724 = $720 & $469;
     $725 = Math_fround($594 * $688);
     $726 = Math_fround($595 * $688);
     $727 = Math_fround($596 * $688);
     $728 = Math_fround($597 * $688);
     $729 = (HEAPF32[tempDoublePtr>>2]=$725,HEAP32[tempDoublePtr>>2]|0);
     $730 = (HEAPF32[tempDoublePtr>>2]=$726,HEAP32[tempDoublePtr>>2]|0);
     $731 = (HEAPF32[tempDoublePtr>>2]=$727,HEAP32[tempDoublePtr>>2]|0);
     $732 = (HEAPF32[tempDoublePtr>>2]=$728,HEAP32[tempDoublePtr>>2]|0);
     $733 = $729 & $466;
     $734 = $730 & $467;
     $735 = $731 & $468;
     $736 = $732 & $469;
     $737 = (HEAP32[tempDoublePtr>>2]=$697,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $738 = Math_fround($509 * $737);
     $739 = (HEAP32[tempDoublePtr>>2]=$698,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $740 = Math_fround($509 * $739);
     $741 = (HEAP32[tempDoublePtr>>2]=$699,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $742 = Math_fround($509 * $741);
     $743 = (HEAP32[tempDoublePtr>>2]=$700,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $744 = Math_fround($509 * $743);
     $745 = Math_fround($503 + $738);
     $746 = Math_fround($505 + $740);
     $747 = Math_fround($507 + $742);
     $748 = Math_fround($509 + $744);
     HEAPF32[$502>>2] = $745;
     HEAPF32[$504>>2] = $746;
     HEAPF32[$506>>2] = $747;
     HEAPF32[$508>>2] = $748;
     $749 = Math_fround($517 * $737);
     $750 = Math_fround($517 * $739);
     $751 = Math_fround($517 * $741);
     $752 = Math_fround($517 * $743);
     $753 = Math_fround($511 - $749);
     $754 = Math_fround($513 - $750);
     $755 = Math_fround($515 - $751);
     $756 = Math_fround($517 - $752);
     HEAPF32[$510>>2] = $753;
     HEAPF32[$512>>2] = $754;
     HEAPF32[$514>>2] = $755;
     HEAPF32[$516>>2] = $756;
     $757 = (HEAP32[tempDoublePtr>>2]=$709,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $758 = Math_fround($525 * $757);
     $759 = (HEAP32[tempDoublePtr>>2]=$710,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $760 = Math_fround($525 * $759);
     $761 = (HEAP32[tempDoublePtr>>2]=$711,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $762 = Math_fround($525 * $761);
     $763 = (HEAP32[tempDoublePtr>>2]=$712,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $764 = Math_fround($525 * $763);
     $765 = Math_fround($519 + $758);
     $766 = Math_fround($521 + $760);
     $767 = Math_fround($523 + $762);
     $768 = Math_fround($525 + $764);
     HEAPF32[$518>>2] = $765;
     HEAPF32[$520>>2] = $766;
     HEAPF32[$522>>2] = $767;
     HEAPF32[$524>>2] = $768;
     $769 = Math_fround($533 * $757);
     $770 = Math_fround($533 * $759);
     $771 = Math_fround($533 * $761);
     $772 = Math_fround($533 * $763);
     $773 = Math_fround($527 - $769);
     $774 = Math_fround($529 - $770);
     $775 = Math_fround($531 - $771);
     $776 = Math_fround($533 - $772);
     HEAPF32[$526>>2] = $773;
     HEAPF32[$528>>2] = $774;
     HEAPF32[$530>>2] = $775;
     HEAPF32[$532>>2] = $776;
     $777 = (HEAP32[tempDoublePtr>>2]=$721,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $778 = Math_fround($541 * $777);
     $779 = (HEAP32[tempDoublePtr>>2]=$722,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $780 = Math_fround($541 * $779);
     $781 = (HEAP32[tempDoublePtr>>2]=$723,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $782 = Math_fround($541 * $781);
     $783 = (HEAP32[tempDoublePtr>>2]=$724,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $784 = Math_fround($541 * $783);
     $785 = Math_fround($535 + $778);
     $786 = Math_fround($537 + $780);
     $787 = Math_fround($539 + $782);
     $788 = Math_fround($541 + $784);
     HEAPF32[$534>>2] = $785;
     HEAPF32[$536>>2] = $786;
     HEAPF32[$538>>2] = $787;
     HEAPF32[$540>>2] = $788;
     $789 = Math_fround($549 * $777);
     $790 = Math_fround($549 * $779);
     $791 = Math_fround($549 * $781);
     $792 = Math_fround($549 * $783);
     $793 = Math_fround($543 - $789);
     $794 = Math_fround($545 - $790);
     $795 = Math_fround($547 - $791);
     $796 = Math_fround($549 - $792);
     HEAPF32[$542>>2] = $793;
     HEAPF32[$544>>2] = $794;
     HEAPF32[$546>>2] = $795;
     HEAPF32[$548>>2] = $796;
     $797 = (HEAP32[tempDoublePtr>>2]=$733,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $798 = Math_fround($557 * $797);
     $799 = (HEAP32[tempDoublePtr>>2]=$734,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $800 = Math_fround($557 * $799);
     $801 = (HEAP32[tempDoublePtr>>2]=$735,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $802 = Math_fround($557 * $801);
     $803 = (HEAP32[tempDoublePtr>>2]=$736,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $804 = Math_fround($557 * $803);
     $805 = Math_fround($551 + $798);
     $806 = Math_fround($553 + $800);
     $807 = Math_fround($555 + $802);
     $808 = Math_fround($557 + $804);
     HEAPF32[$550>>2] = $805;
     HEAPF32[$552>>2] = $806;
     HEAPF32[$554>>2] = $807;
     HEAPF32[$556>>2] = $808;
     $809 = Math_fround($565 * $797);
     $810 = Math_fround($565 * $799);
     $811 = Math_fround($565 * $801);
     $812 = Math_fround($565 * $803);
     $813 = Math_fround($559 - $809);
     $814 = Math_fround($561 - $810);
     $815 = Math_fround($563 - $811);
     $816 = Math_fround($565 - $812);
     HEAPF32[$558>>2] = $813;
     HEAPF32[$560>>2] = $814;
     HEAPF32[$562>>2] = $815;
     HEAPF32[$564>>2] = $816;
     $817 = (($$0397$i) + 16|0);
     $818 = (($$01396$i) + 16|0);
     $819 = ($817|0)==($39|0);
     if ($819) {
      break;
     } else {
      $$01396$i = $818;$$0397$i = $817;
     }
    }
   }
  }
  $820 = (($cIt$043) + 20|0);
  $821 = ($820|0)==($5|0);
  if ($821) {
   break;
  } else {
   $cIt$043 = $820;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE15constrainMotionEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$0245$i = 0, $$pre = 0, $$pre23 = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0);
 var $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0;
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0;
 var $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0);
 var $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0);
 var $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0);
 var $472 = Math_fround(0), $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $brmerge$i$i = 0, $brmerge1$i$i = 0, $not$w$i$i$i$i = 0, $not$w$i$i$i12$i = 0, $not$w$i$i$i4$i = 0, $not$w$i$i$i8$i = 0, $not$x$i$i$i1$i = 0, $not$x$i$i$i5$i = 0, $not$x$i$i$i9$i = 0, $not$y$i$i$i10$i = 0, $not$y$i$i$i2$i = 0, $not$y$i$i$i6$i = 0, $not$z$i$i$i11$i = 0, $not$z$i$i$i3$i = 0, $not$z$i$i$i7$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($1) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = (($6) + ($7<<4)|0);
 $9 = (($1) + 124|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = (($11) + 296|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($12) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (HEAPF32[tempDoublePtr>>2]=$13,HEAP32[tempDoublePtr>>2]|0);
 $19 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
 $20 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
 $21 = (($1) + 128|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (HEAPF32[tempDoublePtr>>2]=$22,HEAP32[tempDoublePtr>>2]|0);
 $24 = HEAP32[481120>>2]|0;
 $25 = HEAP32[((481120 + 4|0))>>2]|0;
 $26 = HEAP32[((481120 + 12|0))>>2]|0;
 $27 = $23 ^ $18;
 $28 = $23 ^ $19;
 $29 = $23 ^ $20;
 $30 = $27 & $24;
 $31 = $25 & $28;
 $32 = $26 & $29;
 $33 = $30 ^ $23;
 $34 = $31 ^ $23;
 $35 = $32 ^ $23;
 $36 = ($10|0)==(0|0);
 if ($36) {
  $37 = (HEAP32[tempDoublePtr>>2]=$33,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $38 = (HEAP32[tempDoublePtr>>2]=$34,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $39 = (HEAP32[tempDoublePtr>>2]=$35,Math_fround(HEAPF32[tempDoublePtr>>2]));
  __ZN12_GLOBAL__N_115constrainMotionI8Scalar4fPKS1_EEvPT_PKS4_RKT0_S4_($6,$8,$3,$37,$38,$39);
  STACKTOP = sp;return;
 }
 $40 = (($this) + 524|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(1);
 if ($42) {
  $43 = (HEAP32[tempDoublePtr>>2]=$33,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $44 = (HEAP32[tempDoublePtr>>2]=$34,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $45 = (HEAP32[tempDoublePtr>>2]=$35,Math_fround(HEAPF32[tempDoublePtr>>2]));
  __ZN12_GLOBAL__N_115constrainMotionI8Scalar4fPKS1_EEvPT_PKS4_RKT0_S4_($6,$8,$10,$43,$44,$45);
  STACKTOP = sp;return;
 }
 $46 = (($this) + 528|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (HEAP32[tempDoublePtr>>2]=$33,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $49 = (HEAP32[tempDoublePtr>>2]=$34,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $50 = (HEAP32[tempDoublePtr>>2]=$35,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $51 = ($6>>>0)<($8>>>0);
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (Math_fround(($41>>>0)));
 $53 = Math_fround($52 * $47);
 $54 = Math_fround(Math_fround(1.0) - $53);
 $55 = Math_fround($47 + $54);
 $$0245$i = $6;$117 = $24;$119 = $25;$122 = $26;$88 = $10;$90 = $3;
 while(1) {
  $56 = HEAP32[$$0245$i>>2]|0;
  $57 = (($$0245$i) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($$0245$i) + 8|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($$0245$i) + 12|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($$0245$i) + 16|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($$0245$i) + 20|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($$0245$i) + 24|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($$0245$i) + 28|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($$0245$i) + 32|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($$0245$i) + 36|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($$0245$i) + 40|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($$0245$i) + 44|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($$0245$i) + 48|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($$0245$i) + 52|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($$0245$i) + 56|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($$0245$i) + 60|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = Math_fround(HEAPF32[$88>>2]);
  $89 = Math_fround(HEAPF32[$90>>2]);
  $91 = Math_fround($87 - $89);
  $92 = (($88) + 4|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = (($90) + 4|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = Math_fround($93 - $95);
  $97 = (($88) + 8|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($90) + 8|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($98 - $100);
  $102 = (($88) + 12|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = (($90) + 12|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($103 - $105);
  $107 = Math_fround($55 * $91);
  $108 = Math_fround($55 * $96);
  $109 = Math_fround($55 * $101);
  $110 = Math_fround($55 * $106);
  $111 = Math_fround($89 + $107);
  $112 = Math_fround($95 + $108);
  $113 = Math_fround($100 + $109);
  $114 = Math_fround($105 + $110);
  $115 = HEAP32[((481120 + 8|0))>>2]|0;
  $116 = $117 & $56;
  $118 = $119 & $58;
  $120 = $115 & $60;
  $121 = $122 & $62;
  $123 = (HEAP32[tempDoublePtr>>2]=$116,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $124 = Math_fround($111 - $123);
  $125 = (HEAP32[tempDoublePtr>>2]=$118,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $126 = Math_fround($112 - $125);
  $127 = (HEAP32[tempDoublePtr>>2]=$120,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $128 = Math_fround($113 - $127);
  $129 = (HEAP32[tempDoublePtr>>2]=$121,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $130 = Math_fround($114 - $129);
  $131 = (($88) + 16|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($90) + 16|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($132 - $134);
  $136 = (($88) + 20|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = (($90) + 20|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($137 - $139);
  $141 = (($88) + 24|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($90) + 24|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = Math_fround($142 - $144);
  $146 = (($88) + 28|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  $148 = (($90) + 28|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = Math_fround($147 - $149);
  $151 = Math_fround($55 * $135);
  $152 = Math_fround($55 * $140);
  $153 = Math_fround($55 * $145);
  $154 = Math_fround($55 * $150);
  $155 = Math_fround($134 + $151);
  $156 = Math_fround($139 + $152);
  $157 = Math_fround($144 + $153);
  $158 = Math_fround($149 + $154);
  $159 = $117 & $64;
  $160 = $119 & $66;
  $161 = $115 & $68;
  $162 = $122 & $70;
  $163 = (HEAP32[tempDoublePtr>>2]=$159,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $164 = Math_fround($155 - $163);
  $165 = (HEAP32[tempDoublePtr>>2]=$160,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $166 = Math_fround($156 - $165);
  $167 = (HEAP32[tempDoublePtr>>2]=$161,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $168 = Math_fround($157 - $167);
  $169 = (HEAP32[tempDoublePtr>>2]=$162,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $170 = Math_fround($158 - $169);
  $171 = (($88) + 32|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = (($90) + 32|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = Math_fround($172 - $174);
  $176 = (($88) + 36|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = (($90) + 36|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = Math_fround($177 - $179);
  $181 = (($88) + 40|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = (($90) + 40|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = Math_fround($182 - $184);
  $186 = (($88) + 44|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = (($90) + 44|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = Math_fround($187 - $189);
  $191 = Math_fround($55 * $175);
  $192 = Math_fround($55 * $180);
  $193 = Math_fround($55 * $185);
  $194 = Math_fround($55 * $190);
  $195 = Math_fround($174 + $191);
  $196 = Math_fround($179 + $192);
  $197 = Math_fround($184 + $193);
  $198 = Math_fround($189 + $194);
  $199 = $117 & $72;
  $200 = $119 & $74;
  $201 = $115 & $76;
  $202 = $122 & $78;
  $203 = (HEAP32[tempDoublePtr>>2]=$199,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $204 = Math_fround($195 - $203);
  $205 = (HEAP32[tempDoublePtr>>2]=$200,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $206 = Math_fround($196 - $205);
  $207 = (HEAP32[tempDoublePtr>>2]=$201,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $208 = Math_fround($197 - $207);
  $209 = (HEAP32[tempDoublePtr>>2]=$202,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $210 = Math_fround($198 - $209);
  $211 = (($88) + 48|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $213 = (($90) + 48|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = Math_fround($212 - $214);
  $216 = (($88) + 52|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($90) + 52|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = Math_fround($217 - $219);
  $221 = (($88) + 56|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  $223 = (($90) + 56|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = Math_fround($222 - $224);
  $226 = (($88) + 60|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = (($90) + 60|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = Math_fround($227 - $229);
  $231 = Math_fround($55 * $215);
  $232 = Math_fround($55 * $220);
  $233 = Math_fround($55 * $225);
  $234 = Math_fround($55 * $230);
  $235 = Math_fround($214 + $231);
  $236 = Math_fround($219 + $232);
  $237 = Math_fround($224 + $233);
  $238 = Math_fround($229 + $234);
  $239 = $117 & $80;
  $240 = $119 & $82;
  $241 = $115 & $84;
  $242 = $122 & $86;
  $243 = (HEAP32[tempDoublePtr>>2]=$239,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $244 = Math_fround($235 - $243);
  $245 = (HEAP32[tempDoublePtr>>2]=$240,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $246 = Math_fround($236 - $245);
  $247 = (HEAP32[tempDoublePtr>>2]=$241,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $248 = Math_fround($237 - $247);
  $249 = (HEAP32[tempDoublePtr>>2]=$242,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $250 = Math_fround($238 - $249);
  $251 = (($90) + 64|0);
  $252 = (($88) + 64|0);
  $253 = HEAP32[481152>>2]|0;
  $254 = HEAP32[((481152 + 4|0))>>2]|0;
  $255 = HEAP32[((481152 + 8|0))>>2]|0;
  $256 = HEAP32[((481152 + 12|0))>>2]|0;
  $257 = Math_fround($124 * $124);
  $258 = Math_fround($164 * $164);
  $259 = Math_fround($204 * $204);
  $260 = Math_fround($244 * $244);
  $261 = (HEAP32[tempDoublePtr>>2]=$253,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $262 = Math_fround($257 + $261);
  $263 = (HEAP32[tempDoublePtr>>2]=$254,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $264 = Math_fround($258 + $263);
  $265 = (HEAP32[tempDoublePtr>>2]=$255,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $266 = Math_fround($259 + $265);
  $267 = (HEAP32[tempDoublePtr>>2]=$256,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $268 = Math_fround($260 + $267);
  $269 = Math_fround($126 * $126);
  $270 = Math_fround($166 * $166);
  $271 = Math_fround($206 * $206);
  $272 = Math_fround($246 * $246);
  $273 = Math_fround($269 + $262);
  $274 = Math_fround($270 + $264);
  $275 = Math_fround($271 + $266);
  $276 = Math_fround($272 + $268);
  $277 = Math_fround($128 * $128);
  $278 = Math_fround($168 * $168);
  $279 = Math_fround($208 * $208);
  $280 = Math_fround($248 * $248);
  $281 = Math_fround($277 + $273);
  $282 = Math_fround($278 + $274);
  $283 = Math_fround($279 + $275);
  $284 = Math_fround($280 + $276);
  $285 = Math_fround($48 * $130);
  $286 = Math_fround($48 * $170);
  $287 = Math_fround($48 * $210);
  $288 = Math_fround($48 * $250);
  $289 = Math_fround($49 + $285);
  $290 = Math_fround($49 + $286);
  $291 = Math_fround($49 + $287);
  $292 = Math_fround($49 + $288);
  $293 = $289 > Math_fround(0.0);
  $294 = $293 ? $289 : Math_fround(0.0);
  $295 = $290 > Math_fround(0.0);
  $296 = $295 ? $290 : Math_fround(0.0);
  $297 = $291 > Math_fround(0.0);
  $298 = $297 ? $291 : Math_fround(0.0);
  $299 = $292 > Math_fround(0.0);
  $300 = $299 ? $292 : Math_fround(0.0);
  $301 = (Math_fround(Math_sqrt((Math_fround($281)))));
  $302 = (Math_fround(Math_sqrt((Math_fround($282)))));
  $303 = (Math_fround(Math_sqrt((Math_fround($283)))));
  $304 = (Math_fround(Math_sqrt((Math_fround($284)))));
  $305 = Math_fround(Math_fround(1.0) / $301);
  $306 = Math_fround(Math_fround(1.0) / $302);
  $307 = Math_fround(Math_fround(1.0) / $303);
  $308 = Math_fround(Math_fround(1.0) / $304);
  $309 = Math_fround($294 * $305);
  $310 = Math_fround($296 * $306);
  $311 = Math_fround($298 * $307);
  $312 = Math_fround($300 * $308);
  $313 = Math_fround(Math_fround(1.0) - $309);
  $314 = Math_fround(Math_fround(1.0) - $310);
  $315 = Math_fround(Math_fround(1.0) - $311);
  $316 = Math_fround(Math_fround(1.0) - $312);
  $317 = $313 > Math_fround(0.0);
  $318 = $314 > Math_fround(0.0);
  $319 = $315 > Math_fround(0.0);
  $320 = $316 > Math_fround(0.0);
  $brmerge$i$i = $317 | $318;
  $brmerge1$i$i = $brmerge$i$i | $319;
  $$$i$i = $brmerge1$i$i | $320;
  if ($$$i$i) {
   $321 = (HEAPF32[tempDoublePtr>>2]=$250,HEAP32[tempDoublePtr>>2]|0);
   $322 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
   $323 = (HEAPF32[tempDoublePtr>>2]=$166,HEAP32[tempDoublePtr>>2]|0);
   $324 = (HEAPF32[tempDoublePtr>>2]=$124,HEAP32[tempDoublePtr>>2]|0);
   $325 = (HEAPF32[tempDoublePtr>>2]=$248,HEAP32[tempDoublePtr>>2]|0);
   $326 = (HEAPF32[tempDoublePtr>>2]=$246,HEAP32[tempDoublePtr>>2]|0);
   $327 = (HEAPF32[tempDoublePtr>>2]=$206,HEAP32[tempDoublePtr>>2]|0);
   $328 = (HEAPF32[tempDoublePtr>>2]=$244,HEAP32[tempDoublePtr>>2]|0);
   $329 = (HEAPF32[tempDoublePtr>>2]=$204,HEAP32[tempDoublePtr>>2]|0);
   $330 = (HEAPF32[tempDoublePtr>>2]=$164,HEAP32[tempDoublePtr>>2]|0);
   $331 = (HEAPF32[tempDoublePtr>>2]=$210,HEAP32[tempDoublePtr>>2]|0);
   $332 = (HEAPF32[tempDoublePtr>>2]=$170,HEAP32[tempDoublePtr>>2]|0);
   $333 = (HEAPF32[tempDoublePtr>>2]=$168,HEAP32[tempDoublePtr>>2]|0);
   $334 = (HEAPF32[tempDoublePtr>>2]=$130,HEAP32[tempDoublePtr>>2]|0);
   $335 = (HEAPF32[tempDoublePtr>>2]=$128,HEAP32[tempDoublePtr>>2]|0);
   $336 = (HEAPF32[tempDoublePtr>>2]=$126,HEAP32[tempDoublePtr>>2]|0);
   $337 = HEAP32[481200>>2]|0;
   $338 = HEAP32[((481200 + 4|0))>>2]|0;
   $339 = HEAP32[((481200 + 8|0))>>2]|0;
   $340 = HEAP32[((481200 + 12|0))>>2]|0;
   $341 = (HEAP32[tempDoublePtr>>2]=$337,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $342 = (HEAP32[tempDoublePtr>>2]=$338,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $343 = (HEAP32[tempDoublePtr>>2]=$339,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $344 = (HEAP32[tempDoublePtr>>2]=$340,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i9$i = $294 > $341;
   $not$y$i$i$i10$i = $294 > $342;
   $not$z$i$i$i11$i = $294 > $343;
   $not$w$i$i$i12$i = $294 > $344;
   $not$x$i$i$i5$i = $296 > $341;
   $not$y$i$i$i6$i = $296 > $342;
   $not$z$i$i$i7$i = $296 > $343;
   $not$w$i$i$i8$i = $296 > $344;
   $not$x$i$i$i1$i = $298 > $341;
   $not$y$i$i$i2$i = $298 > $342;
   $not$z$i$i$i3$i = $298 > $343;
   $not$w$i$i$i4$i = $298 > $344;
   $not$w$i$i$i$i = $300 > $344;
   $345 = Math_fround($50 * $313);
   $346 = Math_fround($50 * $314);
   $347 = Math_fround($50 * $315);
   $348 = Math_fround($50 * $316);
   $349 = $324 & $117;
   $350 = $336 & $119;
   $351 = $335 & $115;
   $352 = $334 & $122;
   $353 = $317 ? $345 : Math_fround(0.0);
   $354 = (HEAP32[tempDoublePtr>>2]=$349,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $355 = Math_fround($354 * $353);
   $356 = (HEAP32[tempDoublePtr>>2]=$350,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $357 = Math_fround($356 * $353);
   $358 = (HEAP32[tempDoublePtr>>2]=$351,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $359 = Math_fround($358 * $353);
   $360 = (HEAP32[tempDoublePtr>>2]=$352,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $361 = Math_fround($360 * $353);
   $362 = (HEAP32[tempDoublePtr>>2]=$56,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $363 = $not$x$i$i$i9$i ? $362 : Math_fround(0.0);
   $364 = Math_fround($355 + $363);
   $365 = (HEAP32[tempDoublePtr>>2]=$58,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $366 = $not$y$i$i$i10$i ? $365 : Math_fround(0.0);
   $367 = Math_fround($357 + $366);
   $368 = (HEAP32[tempDoublePtr>>2]=$60,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $369 = $not$z$i$i$i11$i ? $368 : Math_fround(0.0);
   $370 = Math_fround($359 + $369);
   $371 = (HEAP32[tempDoublePtr>>2]=$62,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $372 = $not$w$i$i$i12$i ? $371 : Math_fround(0.0);
   $373 = Math_fround($361 + $372);
   $374 = (HEAPF32[tempDoublePtr>>2]=$364,HEAP32[tempDoublePtr>>2]|0);
   $375 = (HEAPF32[tempDoublePtr>>2]=$367,HEAP32[tempDoublePtr>>2]|0);
   $376 = (HEAPF32[tempDoublePtr>>2]=$370,HEAP32[tempDoublePtr>>2]|0);
   $377 = (HEAPF32[tempDoublePtr>>2]=$373,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$0245$i>>2] = $374;
   HEAP32[$57>>2] = $375;
   HEAP32[$59>>2] = $376;
   HEAP32[$61>>2] = $377;
   $378 = HEAP32[481120>>2]|0;
   $379 = HEAP32[((481120 + 4|0))>>2]|0;
   $380 = HEAP32[((481120 + 8|0))>>2]|0;
   $381 = HEAP32[((481120 + 12|0))>>2]|0;
   $382 = $378 & $330;
   $383 = $379 & $323;
   $384 = $380 & $333;
   $385 = $381 & $332;
   $386 = $318 ? $346 : Math_fround(0.0);
   $387 = (HEAP32[tempDoublePtr>>2]=$382,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $388 = Math_fround($386 * $387);
   $389 = (HEAP32[tempDoublePtr>>2]=$383,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $390 = Math_fround($386 * $389);
   $391 = (HEAP32[tempDoublePtr>>2]=$384,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $392 = Math_fround($386 * $391);
   $393 = (HEAP32[tempDoublePtr>>2]=$385,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $394 = Math_fround($386 * $393);
   $395 = (HEAP32[tempDoublePtr>>2]=$64,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $396 = $not$x$i$i$i5$i ? $395 : Math_fround(0.0);
   $397 = Math_fround($396 + $388);
   $398 = (HEAP32[tempDoublePtr>>2]=$66,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $399 = $not$y$i$i$i6$i ? $398 : Math_fround(0.0);
   $400 = Math_fround($399 + $390);
   $401 = (HEAP32[tempDoublePtr>>2]=$68,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $402 = $not$z$i$i$i7$i ? $401 : Math_fround(0.0);
   $403 = Math_fround($402 + $392);
   $404 = (HEAP32[tempDoublePtr>>2]=$70,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $405 = $not$w$i$i$i8$i ? $404 : Math_fround(0.0);
   $406 = Math_fround($405 + $394);
   $407 = (HEAPF32[tempDoublePtr>>2]=$397,HEAP32[tempDoublePtr>>2]|0);
   $408 = (HEAPF32[tempDoublePtr>>2]=$400,HEAP32[tempDoublePtr>>2]|0);
   $409 = (HEAPF32[tempDoublePtr>>2]=$403,HEAP32[tempDoublePtr>>2]|0);
   $410 = (HEAPF32[tempDoublePtr>>2]=$406,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$63>>2] = $407;
   HEAP32[$65>>2] = $408;
   HEAP32[$67>>2] = $409;
   HEAP32[$69>>2] = $410;
   $411 = HEAP32[481120>>2]|0;
   $412 = HEAP32[((481120 + 4|0))>>2]|0;
   $413 = HEAP32[((481120 + 8|0))>>2]|0;
   $414 = HEAP32[((481120 + 12|0))>>2]|0;
   $415 = $411 & $329;
   $416 = $412 & $327;
   $417 = $413 & $322;
   $418 = $414 & $331;
   $419 = $319 ? $347 : Math_fround(0.0);
   $420 = (HEAP32[tempDoublePtr>>2]=$415,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $421 = Math_fround($419 * $420);
   $422 = (HEAP32[tempDoublePtr>>2]=$416,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $423 = Math_fround($419 * $422);
   $424 = (HEAP32[tempDoublePtr>>2]=$417,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $425 = Math_fround($419 * $424);
   $426 = (HEAP32[tempDoublePtr>>2]=$418,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $427 = Math_fround($419 * $426);
   $428 = (HEAP32[tempDoublePtr>>2]=$72,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $429 = $not$x$i$i$i1$i ? $428 : Math_fround(0.0);
   $430 = Math_fround($429 + $421);
   $431 = (HEAP32[tempDoublePtr>>2]=$74,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $432 = $not$y$i$i$i2$i ? $431 : Math_fround(0.0);
   $433 = Math_fround($432 + $423);
   $434 = (HEAP32[tempDoublePtr>>2]=$76,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $435 = $not$z$i$i$i3$i ? $434 : Math_fround(0.0);
   $436 = Math_fround($435 + $425);
   $437 = (HEAP32[tempDoublePtr>>2]=$78,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $438 = $not$w$i$i$i4$i ? $437 : Math_fround(0.0);
   $439 = Math_fround($438 + $427);
   $440 = (HEAPF32[tempDoublePtr>>2]=$430,HEAP32[tempDoublePtr>>2]|0);
   $441 = (HEAPF32[tempDoublePtr>>2]=$433,HEAP32[tempDoublePtr>>2]|0);
   $442 = (HEAPF32[tempDoublePtr>>2]=$436,HEAP32[tempDoublePtr>>2]|0);
   $443 = (HEAPF32[tempDoublePtr>>2]=$439,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$71>>2] = $440;
   HEAP32[$73>>2] = $441;
   HEAP32[$75>>2] = $442;
   HEAP32[$77>>2] = $443;
   $444 = HEAP32[481120>>2]|0;
   $445 = HEAP32[((481120 + 4|0))>>2]|0;
   $446 = HEAP32[((481120 + 8|0))>>2]|0;
   $447 = HEAP32[((481120 + 12|0))>>2]|0;
   $448 = $444 & $328;
   $449 = $445 & $326;
   $450 = $446 & $325;
   $451 = $447 & $321;
   $452 = $320 ? $348 : Math_fround(0.0);
   $453 = (HEAP32[tempDoublePtr>>2]=$448,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $454 = Math_fround($452 * $453);
   $455 = (HEAP32[tempDoublePtr>>2]=$449,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $456 = Math_fround($452 * $455);
   $457 = (HEAP32[tempDoublePtr>>2]=$450,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $458 = Math_fround($452 * $457);
   $459 = (HEAP32[tempDoublePtr>>2]=$451,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $460 = Math_fround($452 * $459);
   $461 = (HEAP32[tempDoublePtr>>2]=$80,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $462 = $not$x$i$i$i9$i ? $461 : Math_fround(0.0);
   $463 = Math_fround($462 + $454);
   $464 = (HEAP32[tempDoublePtr>>2]=$82,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $465 = $not$y$i$i$i6$i ? $464 : Math_fround(0.0);
   $466 = Math_fround($465 + $456);
   $467 = (HEAP32[tempDoublePtr>>2]=$84,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $468 = $not$z$i$i$i3$i ? $467 : Math_fround(0.0);
   $469 = Math_fround($468 + $458);
   $470 = (HEAP32[tempDoublePtr>>2]=$86,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $471 = $not$w$i$i$i$i ? $470 : Math_fround(0.0);
   $472 = Math_fround($471 + $460);
   $473 = (HEAPF32[tempDoublePtr>>2]=$463,HEAP32[tempDoublePtr>>2]|0);
   $474 = (HEAPF32[tempDoublePtr>>2]=$466,HEAP32[tempDoublePtr>>2]|0);
   $475 = (HEAPF32[tempDoublePtr>>2]=$469,HEAP32[tempDoublePtr>>2]|0);
   $476 = (HEAPF32[tempDoublePtr>>2]=$472,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$79>>2] = $473;
   HEAP32[$81>>2] = $474;
   HEAP32[$83>>2] = $475;
   HEAP32[$85>>2] = $476;
  }
  $477 = (($$0245$i) + 64|0);
  $478 = ($477>>>0)<($8>>>0);
  if (!($478)) {
   break;
  }
  $$pre = HEAP32[481120>>2]|0;
  $$pre23 = HEAP32[((481120 + 4|0))>>2]|0;
  $$pre24 = HEAP32[((481120 + 12|0))>>2]|0;
  $$0245$i = $477;$117 = $$pre;$119 = $$pre23;$122 = $$pre24;$88 = $252;$90 = $251;
 }
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_115constrainMotionI8Scalar4fPKS1_EEvPT_PKS4_RKT0_S4_($curIt,$curEnd,$spheres$val,$scaleBiasStiffness$0$0$0$val,$scaleBiasStiffness$0$0$1$val,$scaleBiasStiffness$0$0$3$val) {
 $curIt = $curIt|0;
 $curEnd = $curEnd|0;
 $spheres$val = $spheres$val|0;
 $scaleBiasStiffness$0$0$0$val = Math_fround($scaleBiasStiffness$0$0$0$val);
 $scaleBiasStiffness$0$0$1$val = Math_fround($scaleBiasStiffness$0$0$1$val);
 $scaleBiasStiffness$0$0$3$val = Math_fround($scaleBiasStiffness$0$0$3$val);
 var $$$i = 0, $$0229 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0;
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$i = 0, $brmerge1$i = 0, $not$w$i$i$i = 0, $not$w$i$i$i12 = 0, $not$w$i$i$i4 = 0, $not$w$i$i$i8 = 0, $not$x$i$i$i1 = 0, $not$x$i$i$i5 = 0, $not$x$i$i$i9 = 0, $not$y$i$i$i10 = 0, $not$y$i$i$i2 = 0, $not$y$i$i$i6 = 0, $not$z$i$i$i11 = 0, $not$z$i$i$i3 = 0, $not$z$i$i$i7 = 0, $sphIt$0230 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($curIt>>>0)<($curEnd>>>0);
 if ($0) {
  $$0229 = $curIt;$sphIt$0230 = $spheres$val;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $1 = HEAP32[$$0229>>2]|0;
  $2 = (($$0229) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($$0229) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($$0229) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($$0229) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($$0229) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($$0229) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($$0229) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($$0229) + 32|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($$0229) + 36|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($$0229) + 40|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($$0229) + 44|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($$0229) + 48|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($$0229) + 52|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($$0229) + 56|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($$0229) + 60|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[481120>>2]|0;
  $33 = HEAP32[((481120 + 4|0))>>2]|0;
  $34 = HEAP32[((481120 + 8|0))>>2]|0;
  $35 = HEAP32[((481120 + 12|0))>>2]|0;
  $36 = $32 & $1;
  $37 = $33 & $3;
  $38 = $34 & $5;
  $39 = $35 & $7;
  $40 = Math_fround(HEAPF32[$sphIt$0230>>2]);
  $41 = (HEAP32[tempDoublePtr>>2]=$36,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $42 = Math_fround($40 - $41);
  $43 = (($sphIt$0230) + 4|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (HEAP32[tempDoublePtr>>2]=$37,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $46 = Math_fround($44 - $45);
  $47 = (($sphIt$0230) + 8|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (HEAP32[tempDoublePtr>>2]=$38,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $50 = Math_fround($48 - $49);
  $51 = (($sphIt$0230) + 12|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (HEAP32[tempDoublePtr>>2]=$39,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $54 = Math_fround($52 - $53);
  $55 = $32 & $9;
  $56 = $33 & $11;
  $57 = $34 & $13;
  $58 = $35 & $15;
  $59 = (($sphIt$0230) + 16|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (HEAP32[tempDoublePtr>>2]=$55,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $62 = Math_fround($60 - $61);
  $63 = (($sphIt$0230) + 20|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (HEAP32[tempDoublePtr>>2]=$56,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $66 = Math_fround($64 - $65);
  $67 = (($sphIt$0230) + 24|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (HEAP32[tempDoublePtr>>2]=$57,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $70 = Math_fround($68 - $69);
  $71 = (($sphIt$0230) + 28|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (HEAP32[tempDoublePtr>>2]=$58,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $74 = Math_fround($72 - $73);
  $75 = $32 & $17;
  $76 = $33 & $19;
  $77 = $34 & $21;
  $78 = $35 & $23;
  $79 = (($sphIt$0230) + 32|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (HEAP32[tempDoublePtr>>2]=$75,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $82 = Math_fround($80 - $81);
  $83 = (($sphIt$0230) + 36|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = (HEAP32[tempDoublePtr>>2]=$76,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $86 = Math_fround($84 - $85);
  $87 = (($sphIt$0230) + 40|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (HEAP32[tempDoublePtr>>2]=$77,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $90 = Math_fround($88 - $89);
  $91 = (($sphIt$0230) + 44|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = (HEAP32[tempDoublePtr>>2]=$78,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $94 = Math_fround($92 - $93);
  $95 = $32 & $25;
  $96 = $33 & $27;
  $97 = $34 & $29;
  $98 = $35 & $31;
  $99 = (($sphIt$0230) + 48|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (HEAP32[tempDoublePtr>>2]=$95,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $102 = Math_fround($100 - $101);
  $103 = (($sphIt$0230) + 52|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = (HEAP32[tempDoublePtr>>2]=$96,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $106 = Math_fround($104 - $105);
  $107 = (($sphIt$0230) + 56|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = (HEAP32[tempDoublePtr>>2]=$97,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $110 = Math_fround($108 - $109);
  $111 = (($sphIt$0230) + 60|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (HEAP32[tempDoublePtr>>2]=$98,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $114 = Math_fround($112 - $113);
  $115 = (($sphIt$0230) + 64|0);
  $116 = HEAP32[481152>>2]|0;
  $117 = HEAP32[((481152 + 4|0))>>2]|0;
  $118 = HEAP32[((481152 + 8|0))>>2]|0;
  $119 = HEAP32[((481152 + 12|0))>>2]|0;
  $120 = Math_fround($42 * $42);
  $121 = Math_fround($62 * $62);
  $122 = Math_fround($82 * $82);
  $123 = Math_fround($102 * $102);
  $124 = (HEAP32[tempDoublePtr>>2]=$116,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $125 = Math_fround($120 + $124);
  $126 = (HEAP32[tempDoublePtr>>2]=$117,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $127 = Math_fround($121 + $126);
  $128 = (HEAP32[tempDoublePtr>>2]=$118,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $129 = Math_fround($122 + $128);
  $130 = (HEAP32[tempDoublePtr>>2]=$119,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $131 = Math_fround($123 + $130);
  $132 = Math_fround($46 * $46);
  $133 = Math_fround($66 * $66);
  $134 = Math_fround($86 * $86);
  $135 = Math_fround($106 * $106);
  $136 = Math_fround($132 + $125);
  $137 = Math_fround($133 + $127);
  $138 = Math_fround($134 + $129);
  $139 = Math_fround($135 + $131);
  $140 = Math_fround($50 * $50);
  $141 = Math_fround($70 * $70);
  $142 = Math_fround($90 * $90);
  $143 = Math_fround($110 * $110);
  $144 = Math_fround($140 + $136);
  $145 = Math_fround($141 + $137);
  $146 = Math_fround($142 + $138);
  $147 = Math_fround($143 + $139);
  $148 = Math_fround($54 * $scaleBiasStiffness$0$0$0$val);
  $149 = Math_fround($74 * $scaleBiasStiffness$0$0$0$val);
  $150 = Math_fround($94 * $scaleBiasStiffness$0$0$0$val);
  $151 = Math_fround($114 * $scaleBiasStiffness$0$0$0$val);
  $152 = Math_fround($148 + $scaleBiasStiffness$0$0$1$val);
  $153 = Math_fround($149 + $scaleBiasStiffness$0$0$1$val);
  $154 = Math_fround($150 + $scaleBiasStiffness$0$0$1$val);
  $155 = Math_fround($151 + $scaleBiasStiffness$0$0$1$val);
  $156 = $152 > Math_fround(0.0);
  $157 = $156 ? $152 : Math_fround(0.0);
  $158 = $153 > Math_fround(0.0);
  $159 = $158 ? $153 : Math_fround(0.0);
  $160 = $154 > Math_fround(0.0);
  $161 = $160 ? $154 : Math_fround(0.0);
  $162 = $155 > Math_fround(0.0);
  $163 = $162 ? $155 : Math_fround(0.0);
  $164 = (Math_fround(Math_sqrt((Math_fround($144)))));
  $165 = (Math_fround(Math_sqrt((Math_fround($145)))));
  $166 = (Math_fround(Math_sqrt((Math_fround($146)))));
  $167 = (Math_fround(Math_sqrt((Math_fround($147)))));
  $168 = Math_fround(Math_fround(1.0) / $164);
  $169 = Math_fround(Math_fround(1.0) / $165);
  $170 = Math_fround(Math_fround(1.0) / $166);
  $171 = Math_fround(Math_fround(1.0) / $167);
  $172 = Math_fround($157 * $168);
  $173 = Math_fround($159 * $169);
  $174 = Math_fround($161 * $170);
  $175 = Math_fround($163 * $171);
  $176 = Math_fround(Math_fround(1.0) - $172);
  $177 = Math_fround(Math_fround(1.0) - $173);
  $178 = Math_fround(Math_fround(1.0) - $174);
  $179 = Math_fround(Math_fround(1.0) - $175);
  $180 = $176 > Math_fround(0.0);
  $181 = $177 > Math_fround(0.0);
  $182 = $178 > Math_fround(0.0);
  $183 = $179 > Math_fround(0.0);
  $brmerge$i = $180 | $181;
  $brmerge1$i = $brmerge$i | $182;
  $$$i = $brmerge1$i | $183;
  if ($$$i) {
   $184 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
   $185 = (HEAPF32[tempDoublePtr>>2]=$90,HEAP32[tempDoublePtr>>2]|0);
   $186 = (HEAPF32[tempDoublePtr>>2]=$66,HEAP32[tempDoublePtr>>2]|0);
   $187 = (HEAPF32[tempDoublePtr>>2]=$42,HEAP32[tempDoublePtr>>2]|0);
   $188 = (HEAPF32[tempDoublePtr>>2]=$110,HEAP32[tempDoublePtr>>2]|0);
   $189 = (HEAPF32[tempDoublePtr>>2]=$106,HEAP32[tempDoublePtr>>2]|0);
   $190 = (HEAPF32[tempDoublePtr>>2]=$86,HEAP32[tempDoublePtr>>2]|0);
   $191 = (HEAPF32[tempDoublePtr>>2]=$102,HEAP32[tempDoublePtr>>2]|0);
   $192 = (HEAPF32[tempDoublePtr>>2]=$82,HEAP32[tempDoublePtr>>2]|0);
   $193 = (HEAPF32[tempDoublePtr>>2]=$62,HEAP32[tempDoublePtr>>2]|0);
   $194 = (HEAPF32[tempDoublePtr>>2]=$94,HEAP32[tempDoublePtr>>2]|0);
   $195 = (HEAPF32[tempDoublePtr>>2]=$74,HEAP32[tempDoublePtr>>2]|0);
   $196 = (HEAPF32[tempDoublePtr>>2]=$70,HEAP32[tempDoublePtr>>2]|0);
   $197 = (HEAPF32[tempDoublePtr>>2]=$54,HEAP32[tempDoublePtr>>2]|0);
   $198 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
   $199 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
   $200 = HEAP32[481200>>2]|0;
   $201 = HEAP32[((481200 + 4|0))>>2]|0;
   $202 = HEAP32[((481200 + 8|0))>>2]|0;
   $203 = HEAP32[((481200 + 12|0))>>2]|0;
   $204 = (HEAP32[tempDoublePtr>>2]=$200,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $205 = (HEAP32[tempDoublePtr>>2]=$201,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $206 = (HEAP32[tempDoublePtr>>2]=$202,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $207 = (HEAP32[tempDoublePtr>>2]=$203,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $not$x$i$i$i9 = $157 > $204;
   $not$y$i$i$i10 = $157 > $205;
   $not$z$i$i$i11 = $157 > $206;
   $not$w$i$i$i12 = $157 > $207;
   $not$x$i$i$i5 = $159 > $204;
   $not$y$i$i$i6 = $159 > $205;
   $not$z$i$i$i7 = $159 > $206;
   $not$w$i$i$i8 = $159 > $207;
   $not$x$i$i$i1 = $161 > $204;
   $not$y$i$i$i2 = $161 > $205;
   $not$z$i$i$i3 = $161 > $206;
   $not$w$i$i$i4 = $161 > $207;
   $not$w$i$i$i = $163 > $207;
   $208 = Math_fround($176 * $scaleBiasStiffness$0$0$3$val);
   $209 = Math_fround($177 * $scaleBiasStiffness$0$0$3$val);
   $210 = Math_fround($178 * $scaleBiasStiffness$0$0$3$val);
   $211 = Math_fround($179 * $scaleBiasStiffness$0$0$3$val);
   $212 = $187 & $32;
   $213 = $199 & $33;
   $214 = $198 & $34;
   $215 = $197 & $35;
   $216 = $180 ? $208 : Math_fround(0.0);
   $217 = (HEAP32[tempDoublePtr>>2]=$212,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $218 = Math_fround($217 * $216);
   $219 = (HEAP32[tempDoublePtr>>2]=$213,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $220 = Math_fround($219 * $216);
   $221 = (HEAP32[tempDoublePtr>>2]=$214,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $222 = Math_fround($221 * $216);
   $223 = (HEAP32[tempDoublePtr>>2]=$215,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $224 = Math_fround($223 * $216);
   $225 = (HEAP32[tempDoublePtr>>2]=$1,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $226 = $not$x$i$i$i9 ? $225 : Math_fround(0.0);
   $227 = Math_fround($218 + $226);
   $228 = (HEAP32[tempDoublePtr>>2]=$3,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $229 = $not$y$i$i$i10 ? $228 : Math_fround(0.0);
   $230 = Math_fround($220 + $229);
   $231 = (HEAP32[tempDoublePtr>>2]=$5,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $232 = $not$z$i$i$i11 ? $231 : Math_fround(0.0);
   $233 = Math_fround($222 + $232);
   $234 = (HEAP32[tempDoublePtr>>2]=$7,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $235 = $not$w$i$i$i12 ? $234 : Math_fround(0.0);
   $236 = Math_fround($224 + $235);
   $237 = (HEAPF32[tempDoublePtr>>2]=$227,HEAP32[tempDoublePtr>>2]|0);
   $238 = (HEAPF32[tempDoublePtr>>2]=$230,HEAP32[tempDoublePtr>>2]|0);
   $239 = (HEAPF32[tempDoublePtr>>2]=$233,HEAP32[tempDoublePtr>>2]|0);
   $240 = (HEAPF32[tempDoublePtr>>2]=$236,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$0229>>2] = $237;
   HEAP32[$2>>2] = $238;
   HEAP32[$4>>2] = $239;
   HEAP32[$6>>2] = $240;
   $241 = HEAP32[481120>>2]|0;
   $242 = HEAP32[((481120 + 4|0))>>2]|0;
   $243 = HEAP32[((481120 + 8|0))>>2]|0;
   $244 = HEAP32[((481120 + 12|0))>>2]|0;
   $245 = $241 & $193;
   $246 = $242 & $186;
   $247 = $243 & $196;
   $248 = $244 & $195;
   $249 = $181 ? $209 : Math_fround(0.0);
   $250 = (HEAP32[tempDoublePtr>>2]=$245,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $251 = Math_fround($249 * $250);
   $252 = (HEAP32[tempDoublePtr>>2]=$246,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $253 = Math_fround($249 * $252);
   $254 = (HEAP32[tempDoublePtr>>2]=$247,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $255 = Math_fround($249 * $254);
   $256 = (HEAP32[tempDoublePtr>>2]=$248,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $257 = Math_fround($249 * $256);
   $258 = (HEAP32[tempDoublePtr>>2]=$9,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $259 = $not$x$i$i$i5 ? $258 : Math_fround(0.0);
   $260 = Math_fround($259 + $251);
   $261 = (HEAP32[tempDoublePtr>>2]=$11,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $262 = $not$y$i$i$i6 ? $261 : Math_fround(0.0);
   $263 = Math_fround($262 + $253);
   $264 = (HEAP32[tempDoublePtr>>2]=$13,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $265 = $not$z$i$i$i7 ? $264 : Math_fround(0.0);
   $266 = Math_fround($265 + $255);
   $267 = (HEAP32[tempDoublePtr>>2]=$15,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $268 = $not$w$i$i$i8 ? $267 : Math_fround(0.0);
   $269 = Math_fround($268 + $257);
   $270 = (HEAPF32[tempDoublePtr>>2]=$260,HEAP32[tempDoublePtr>>2]|0);
   $271 = (HEAPF32[tempDoublePtr>>2]=$263,HEAP32[tempDoublePtr>>2]|0);
   $272 = (HEAPF32[tempDoublePtr>>2]=$266,HEAP32[tempDoublePtr>>2]|0);
   $273 = (HEAPF32[tempDoublePtr>>2]=$269,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$8>>2] = $270;
   HEAP32[$10>>2] = $271;
   HEAP32[$12>>2] = $272;
   HEAP32[$14>>2] = $273;
   $274 = HEAP32[481120>>2]|0;
   $275 = HEAP32[((481120 + 4|0))>>2]|0;
   $276 = HEAP32[((481120 + 8|0))>>2]|0;
   $277 = HEAP32[((481120 + 12|0))>>2]|0;
   $278 = $274 & $192;
   $279 = $275 & $190;
   $280 = $276 & $185;
   $281 = $277 & $194;
   $282 = $182 ? $210 : Math_fround(0.0);
   $283 = (HEAP32[tempDoublePtr>>2]=$278,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $284 = Math_fround($282 * $283);
   $285 = (HEAP32[tempDoublePtr>>2]=$279,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $286 = Math_fround($282 * $285);
   $287 = (HEAP32[tempDoublePtr>>2]=$280,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $288 = Math_fround($282 * $287);
   $289 = (HEAP32[tempDoublePtr>>2]=$281,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $290 = Math_fround($282 * $289);
   $291 = (HEAP32[tempDoublePtr>>2]=$17,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $292 = $not$x$i$i$i1 ? $291 : Math_fround(0.0);
   $293 = Math_fround($292 + $284);
   $294 = (HEAP32[tempDoublePtr>>2]=$19,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $295 = $not$y$i$i$i2 ? $294 : Math_fround(0.0);
   $296 = Math_fround($295 + $286);
   $297 = (HEAP32[tempDoublePtr>>2]=$21,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $298 = $not$z$i$i$i3 ? $297 : Math_fround(0.0);
   $299 = Math_fround($298 + $288);
   $300 = (HEAP32[tempDoublePtr>>2]=$23,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $301 = $not$w$i$i$i4 ? $300 : Math_fround(0.0);
   $302 = Math_fround($301 + $290);
   $303 = (HEAPF32[tempDoublePtr>>2]=$293,HEAP32[tempDoublePtr>>2]|0);
   $304 = (HEAPF32[tempDoublePtr>>2]=$296,HEAP32[tempDoublePtr>>2]|0);
   $305 = (HEAPF32[tempDoublePtr>>2]=$299,HEAP32[tempDoublePtr>>2]|0);
   $306 = (HEAPF32[tempDoublePtr>>2]=$302,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$16>>2] = $303;
   HEAP32[$18>>2] = $304;
   HEAP32[$20>>2] = $305;
   HEAP32[$22>>2] = $306;
   $307 = HEAP32[481120>>2]|0;
   $308 = HEAP32[((481120 + 4|0))>>2]|0;
   $309 = HEAP32[((481120 + 8|0))>>2]|0;
   $310 = HEAP32[((481120 + 12|0))>>2]|0;
   $311 = $307 & $191;
   $312 = $308 & $189;
   $313 = $309 & $188;
   $314 = $310 & $184;
   $315 = $183 ? $211 : Math_fround(0.0);
   $316 = (HEAP32[tempDoublePtr>>2]=$311,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $317 = Math_fround($315 * $316);
   $318 = (HEAP32[tempDoublePtr>>2]=$312,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $319 = Math_fround($315 * $318);
   $320 = (HEAP32[tempDoublePtr>>2]=$313,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $321 = Math_fround($315 * $320);
   $322 = (HEAP32[tempDoublePtr>>2]=$314,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $323 = Math_fround($315 * $322);
   $324 = (HEAP32[tempDoublePtr>>2]=$25,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $325 = $not$x$i$i$i9 ? $324 : Math_fround(0.0);
   $326 = Math_fround($325 + $317);
   $327 = (HEAP32[tempDoublePtr>>2]=$27,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $328 = $not$y$i$i$i6 ? $327 : Math_fround(0.0);
   $329 = Math_fround($328 + $319);
   $330 = (HEAP32[tempDoublePtr>>2]=$29,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $331 = $not$z$i$i$i3 ? $330 : Math_fround(0.0);
   $332 = Math_fround($331 + $321);
   $333 = (HEAP32[tempDoublePtr>>2]=$31,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $334 = $not$w$i$i$i ? $333 : Math_fround(0.0);
   $335 = Math_fround($334 + $323);
   $336 = (HEAPF32[tempDoublePtr>>2]=$326,HEAP32[tempDoublePtr>>2]|0);
   $337 = (HEAPF32[tempDoublePtr>>2]=$329,HEAP32[tempDoublePtr>>2]|0);
   $338 = (HEAPF32[tempDoublePtr>>2]=$332,HEAP32[tempDoublePtr>>2]|0);
   $339 = (HEAPF32[tempDoublePtr>>2]=$335,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$24>>2] = $336;
   HEAP32[$26>>2] = $337;
   HEAP32[$28>>2] = $338;
   HEAP32[$30>>2] = $339;
  }
  $340 = (($$0229) + 64|0);
  $341 = ($340>>>0)<($curEnd>>>0);
  if ($341) {
   $$0229 = $340;$sphIt$0230 = $115;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE19constrainSeparationEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$0169$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0);
 var $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0;
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0;
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = 0, $98 = Math_fround(0), $99 = 0, $brmerge$i$i = 0, $brmerge1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($1) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = (($6) + ($7<<4)|0);
 $9 = (($1) + 136|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  __ZN12_GLOBAL__N_119constrainSeparationI8Scalar4fPKS1_EEvPT_PKS4_RKT0_($6,$8,$3);
  STACKTOP = sp;return;
 }
 $12 = (($this) + 524|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(1);
 if ($14) {
  __ZN12_GLOBAL__N_119constrainSeparationI8Scalar4fPKS1_EEvPT_PKS4_RKT0_($6,$8,$10);
  STACKTOP = sp;return;
 }
 $15 = (($this) + 528|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = ($6>>>0)<($8>>>0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (Math_fround(($13>>>0)));
 $19 = Math_fround($18 * $16);
 $20 = Math_fround(Math_fround(1.0) - $19);
 $21 = Math_fround($16 + $20);
 $$0169$i = $6;$54 = $10;$56 = $3;
 while(1) {
  $22 = HEAP32[$$0169$i>>2]|0;
  $23 = (($$0169$i) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($$0169$i) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($$0169$i) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($$0169$i) + 16|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($$0169$i) + 20|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($$0169$i) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($$0169$i) + 28|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($$0169$i) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($$0169$i) + 36|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($$0169$i) + 40|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($$0169$i) + 44|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($$0169$i) + 48|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($$0169$i) + 52|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($$0169$i) + 56|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($$0169$i) + 60|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = Math_fround(HEAPF32[$54>>2]);
  $55 = Math_fround(HEAPF32[$56>>2]);
  $57 = Math_fround($53 - $55);
  $58 = (($54) + 4|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($56) + 4|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($59 - $61);
  $63 = (($54) + 8|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($56) + 8|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($64 - $66);
  $68 = (($54) + 12|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($56) + 12|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = Math_fround($69 - $71);
  $73 = Math_fround($21 * $57);
  $74 = Math_fround($21 * $62);
  $75 = Math_fround($21 * $67);
  $76 = Math_fround($21 * $72);
  $77 = Math_fround($55 + $73);
  $78 = Math_fround($61 + $74);
  $79 = Math_fround($66 + $75);
  $80 = Math_fround($71 + $76);
  $81 = HEAP32[481120>>2]|0;
  $82 = HEAP32[((481120 + 4|0))>>2]|0;
  $83 = HEAP32[((481120 + 8|0))>>2]|0;
  $84 = HEAP32[((481120 + 12|0))>>2]|0;
  $85 = $81 & $22;
  $86 = $82 & $24;
  $87 = $83 & $26;
  $88 = $84 & $28;
  $89 = (HEAP32[tempDoublePtr>>2]=$85,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $90 = Math_fround($77 - $89);
  $91 = (HEAP32[tempDoublePtr>>2]=$86,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $92 = Math_fround($78 - $91);
  $93 = (HEAP32[tempDoublePtr>>2]=$87,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $94 = Math_fround($79 - $93);
  $95 = (HEAP32[tempDoublePtr>>2]=$88,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $96 = Math_fround($80 - $95);
  $97 = (($54) + 16|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($56) + 16|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($98 - $100);
  $102 = (($54) + 20|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = (($56) + 20|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($103 - $105);
  $107 = (($54) + 24|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = (($56) + 24|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = Math_fround($108 - $110);
  $112 = (($54) + 28|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = (($56) + 28|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($113 - $115);
  $117 = Math_fround($21 * $101);
  $118 = Math_fround($21 * $106);
  $119 = Math_fround($21 * $111);
  $120 = Math_fround($21 * $116);
  $121 = Math_fround($100 + $117);
  $122 = Math_fround($105 + $118);
  $123 = Math_fround($110 + $119);
  $124 = Math_fround($115 + $120);
  $125 = $81 & $30;
  $126 = $82 & $32;
  $127 = $83 & $34;
  $128 = $84 & $36;
  $129 = (HEAP32[tempDoublePtr>>2]=$125,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $130 = Math_fround($121 - $129);
  $131 = (HEAP32[tempDoublePtr>>2]=$126,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $132 = Math_fround($122 - $131);
  $133 = (HEAP32[tempDoublePtr>>2]=$127,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $134 = Math_fround($123 - $133);
  $135 = (HEAP32[tempDoublePtr>>2]=$128,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $136 = Math_fround($124 - $135);
  $137 = (($54) + 32|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = (($56) + 32|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = Math_fround($138 - $140);
  $142 = (($54) + 36|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = (($56) + 36|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = Math_fround($143 - $145);
  $147 = (($54) + 40|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = (($56) + 40|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $151 = Math_fround($148 - $150);
  $152 = (($54) + 44|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  $154 = (($56) + 44|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = Math_fround($153 - $155);
  $157 = Math_fround($21 * $141);
  $158 = Math_fround($21 * $146);
  $159 = Math_fround($21 * $151);
  $160 = Math_fround($21 * $156);
  $161 = Math_fround($140 + $157);
  $162 = Math_fround($145 + $158);
  $163 = Math_fround($150 + $159);
  $164 = Math_fround($155 + $160);
  $165 = $81 & $38;
  $166 = $82 & $40;
  $167 = $83 & $42;
  $168 = $84 & $44;
  $169 = (HEAP32[tempDoublePtr>>2]=$165,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $170 = Math_fround($161 - $169);
  $171 = (HEAP32[tempDoublePtr>>2]=$166,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $172 = Math_fround($162 - $171);
  $173 = (HEAP32[tempDoublePtr>>2]=$167,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $174 = Math_fround($163 - $173);
  $175 = (HEAP32[tempDoublePtr>>2]=$168,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $176 = Math_fround($164 - $175);
  $177 = (($54) + 48|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = (($56) + 48|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = Math_fround($178 - $180);
  $182 = (($54) + 52|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = (($56) + 52|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = Math_fround($183 - $185);
  $187 = (($54) + 56|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = (($56) + 56|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = Math_fround($188 - $190);
  $192 = (($54) + 60|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($56) + 60|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($193 - $195);
  $197 = Math_fround($21 * $181);
  $198 = Math_fround($21 * $186);
  $199 = Math_fround($21 * $191);
  $200 = Math_fround($21 * $196);
  $201 = Math_fround($180 + $197);
  $202 = Math_fround($185 + $198);
  $203 = Math_fround($190 + $199);
  $204 = Math_fround($195 + $200);
  $205 = $81 & $46;
  $206 = $82 & $48;
  $207 = $83 & $50;
  $208 = $84 & $52;
  $209 = (HEAP32[tempDoublePtr>>2]=$205,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $210 = Math_fround($201 - $209);
  $211 = (HEAP32[tempDoublePtr>>2]=$206,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $212 = Math_fround($202 - $211);
  $213 = (HEAP32[tempDoublePtr>>2]=$207,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $214 = Math_fround($203 - $213);
  $215 = (HEAP32[tempDoublePtr>>2]=$208,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $216 = Math_fround($204 - $215);
  $217 = (($56) + 64|0);
  $218 = (($54) + 64|0);
  $219 = HEAP32[481152>>2]|0;
  $220 = HEAP32[((481152 + 4|0))>>2]|0;
  $221 = HEAP32[((481152 + 8|0))>>2]|0;
  $222 = HEAP32[((481152 + 12|0))>>2]|0;
  $223 = Math_fround($90 * $90);
  $224 = Math_fround($130 * $130);
  $225 = Math_fround($170 * $170);
  $226 = Math_fround($210 * $210);
  $227 = (HEAP32[tempDoublePtr>>2]=$219,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $228 = Math_fround($223 + $227);
  $229 = (HEAP32[tempDoublePtr>>2]=$220,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $230 = Math_fround($224 + $229);
  $231 = (HEAP32[tempDoublePtr>>2]=$221,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $232 = Math_fround($225 + $231);
  $233 = (HEAP32[tempDoublePtr>>2]=$222,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $234 = Math_fround($226 + $233);
  $235 = Math_fround($92 * $92);
  $236 = Math_fround($132 * $132);
  $237 = Math_fround($172 * $172);
  $238 = Math_fround($212 * $212);
  $239 = Math_fround($235 + $228);
  $240 = Math_fround($236 + $230);
  $241 = Math_fround($237 + $232);
  $242 = Math_fround($238 + $234);
  $243 = Math_fround($94 * $94);
  $244 = Math_fround($134 * $134);
  $245 = Math_fround($174 * $174);
  $246 = Math_fround($214 * $214);
  $247 = Math_fround($243 + $239);
  $248 = Math_fround($244 + $240);
  $249 = Math_fround($245 + $241);
  $250 = Math_fround($246 + $242);
  $251 = (Math_fround(Math_sqrt((Math_fround($247)))));
  $252 = (Math_fround(Math_sqrt((Math_fround($248)))));
  $253 = (Math_fround(Math_sqrt((Math_fround($249)))));
  $254 = (Math_fround(Math_sqrt((Math_fround($250)))));
  $255 = Math_fround(Math_fround(1.0) / $251);
  $256 = Math_fround(Math_fround(1.0) / $252);
  $257 = Math_fround(Math_fround(1.0) / $253);
  $258 = Math_fround(Math_fround(1.0) / $254);
  $259 = Math_fround($96 * $255);
  $260 = Math_fround($136 * $256);
  $261 = Math_fround($176 * $257);
  $262 = Math_fround($216 * $258);
  $263 = Math_fround(Math_fround(1.0) - $259);
  $264 = Math_fround(Math_fround(1.0) - $260);
  $265 = Math_fround(Math_fround(1.0) - $261);
  $266 = Math_fround(Math_fround(1.0) - $262);
  $267 = $263 < Math_fround(0.0);
  $268 = $264 < Math_fround(0.0);
  $269 = $265 < Math_fround(0.0);
  $270 = $266 < Math_fround(0.0);
  $brmerge$i$i = $267 | $268;
  $brmerge1$i$i = $brmerge$i$i | $269;
  $$$i$i = $brmerge1$i$i | $270;
  if ($$$i$i) {
   $271 = (HEAPF32[tempDoublePtr>>2]=$216,HEAP32[tempDoublePtr>>2]|0);
   $272 = (HEAPF32[tempDoublePtr>>2]=$174,HEAP32[tempDoublePtr>>2]|0);
   $273 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
   $274 = (HEAPF32[tempDoublePtr>>2]=$90,HEAP32[tempDoublePtr>>2]|0);
   $275 = (HEAPF32[tempDoublePtr>>2]=$214,HEAP32[tempDoublePtr>>2]|0);
   $276 = (HEAPF32[tempDoublePtr>>2]=$212,HEAP32[tempDoublePtr>>2]|0);
   $277 = (HEAPF32[tempDoublePtr>>2]=$172,HEAP32[tempDoublePtr>>2]|0);
   $278 = (HEAPF32[tempDoublePtr>>2]=$210,HEAP32[tempDoublePtr>>2]|0);
   $279 = (HEAPF32[tempDoublePtr>>2]=$170,HEAP32[tempDoublePtr>>2]|0);
   $280 = (HEAPF32[tempDoublePtr>>2]=$130,HEAP32[tempDoublePtr>>2]|0);
   $281 = (HEAPF32[tempDoublePtr>>2]=$176,HEAP32[tempDoublePtr>>2]|0);
   $282 = (HEAPF32[tempDoublePtr>>2]=$136,HEAP32[tempDoublePtr>>2]|0);
   $283 = (HEAPF32[tempDoublePtr>>2]=$134,HEAP32[tempDoublePtr>>2]|0);
   $284 = (HEAPF32[tempDoublePtr>>2]=$96,HEAP32[tempDoublePtr>>2]|0);
   $285 = (HEAPF32[tempDoublePtr>>2]=$94,HEAP32[tempDoublePtr>>2]|0);
   $286 = (HEAPF32[tempDoublePtr>>2]=$92,HEAP32[tempDoublePtr>>2]|0);
   $287 = $274 & $81;
   $288 = $286 & $82;
   $289 = $285 & $83;
   $290 = $284 & $84;
   $291 = $267 ? $263 : Math_fround(0.0);
   $292 = (HEAP32[tempDoublePtr>>2]=$287,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $293 = Math_fround($292 * $291);
   $294 = (HEAP32[tempDoublePtr>>2]=$288,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $295 = Math_fround($294 * $291);
   $296 = (HEAP32[tempDoublePtr>>2]=$289,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $297 = Math_fround($296 * $291);
   $298 = (HEAP32[tempDoublePtr>>2]=$290,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $299 = Math_fround($298 * $291);
   $300 = (HEAP32[tempDoublePtr>>2]=$22,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $301 = Math_fround($300 + $293);
   $302 = (HEAP32[tempDoublePtr>>2]=$24,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $303 = Math_fround($302 + $295);
   $304 = (HEAP32[tempDoublePtr>>2]=$26,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $305 = Math_fround($304 + $297);
   $306 = (HEAP32[tempDoublePtr>>2]=$28,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $307 = Math_fround($306 + $299);
   $308 = (HEAPF32[tempDoublePtr>>2]=$301,HEAP32[tempDoublePtr>>2]|0);
   $309 = (HEAPF32[tempDoublePtr>>2]=$303,HEAP32[tempDoublePtr>>2]|0);
   $310 = (HEAPF32[tempDoublePtr>>2]=$305,HEAP32[tempDoublePtr>>2]|0);
   $311 = (HEAPF32[tempDoublePtr>>2]=$307,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$0169$i>>2] = $308;
   HEAP32[$23>>2] = $309;
   HEAP32[$25>>2] = $310;
   HEAP32[$27>>2] = $311;
   $312 = HEAP32[481120>>2]|0;
   $313 = HEAP32[((481120 + 4|0))>>2]|0;
   $314 = HEAP32[((481120 + 8|0))>>2]|0;
   $315 = HEAP32[((481120 + 12|0))>>2]|0;
   $316 = $312 & $280;
   $317 = $313 & $273;
   $318 = $314 & $283;
   $319 = $315 & $282;
   $320 = $268 ? $264 : Math_fround(0.0);
   $321 = (HEAP32[tempDoublePtr>>2]=$316,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $322 = Math_fround($320 * $321);
   $323 = (HEAP32[tempDoublePtr>>2]=$317,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $324 = Math_fround($320 * $323);
   $325 = (HEAP32[tempDoublePtr>>2]=$318,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $326 = Math_fround($320 * $325);
   $327 = (HEAP32[tempDoublePtr>>2]=$319,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $328 = Math_fround($320 * $327);
   $329 = (HEAP32[tempDoublePtr>>2]=$30,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $330 = Math_fround($329 + $322);
   $331 = (HEAP32[tempDoublePtr>>2]=$32,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $332 = Math_fround($331 + $324);
   $333 = (HEAP32[tempDoublePtr>>2]=$34,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $334 = Math_fround($333 + $326);
   $335 = (HEAP32[tempDoublePtr>>2]=$36,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $336 = Math_fround($335 + $328);
   $337 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
   $338 = (HEAPF32[tempDoublePtr>>2]=$332,HEAP32[tempDoublePtr>>2]|0);
   $339 = (HEAPF32[tempDoublePtr>>2]=$334,HEAP32[tempDoublePtr>>2]|0);
   $340 = (HEAPF32[tempDoublePtr>>2]=$336,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$29>>2] = $337;
   HEAP32[$31>>2] = $338;
   HEAP32[$33>>2] = $339;
   HEAP32[$35>>2] = $340;
   $341 = HEAP32[481120>>2]|0;
   $342 = HEAP32[((481120 + 4|0))>>2]|0;
   $343 = HEAP32[((481120 + 8|0))>>2]|0;
   $344 = HEAP32[((481120 + 12|0))>>2]|0;
   $345 = $341 & $279;
   $346 = $342 & $277;
   $347 = $343 & $272;
   $348 = $344 & $281;
   $349 = $269 ? $265 : Math_fround(0.0);
   $350 = (HEAP32[tempDoublePtr>>2]=$345,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $351 = Math_fround($349 * $350);
   $352 = (HEAP32[tempDoublePtr>>2]=$346,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $353 = Math_fround($349 * $352);
   $354 = (HEAP32[tempDoublePtr>>2]=$347,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $355 = Math_fround($349 * $354);
   $356 = (HEAP32[tempDoublePtr>>2]=$348,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $357 = Math_fround($349 * $356);
   $358 = (HEAP32[tempDoublePtr>>2]=$38,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $359 = Math_fround($358 + $351);
   $360 = (HEAP32[tempDoublePtr>>2]=$40,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $361 = Math_fround($360 + $353);
   $362 = (HEAP32[tempDoublePtr>>2]=$42,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $363 = Math_fround($362 + $355);
   $364 = (HEAP32[tempDoublePtr>>2]=$44,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $365 = Math_fround($364 + $357);
   $366 = (HEAPF32[tempDoublePtr>>2]=$359,HEAP32[tempDoublePtr>>2]|0);
   $367 = (HEAPF32[tempDoublePtr>>2]=$361,HEAP32[tempDoublePtr>>2]|0);
   $368 = (HEAPF32[tempDoublePtr>>2]=$363,HEAP32[tempDoublePtr>>2]|0);
   $369 = (HEAPF32[tempDoublePtr>>2]=$365,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$37>>2] = $366;
   HEAP32[$39>>2] = $367;
   HEAP32[$41>>2] = $368;
   HEAP32[$43>>2] = $369;
   $370 = HEAP32[481120>>2]|0;
   $371 = HEAP32[((481120 + 4|0))>>2]|0;
   $372 = HEAP32[((481120 + 8|0))>>2]|0;
   $373 = HEAP32[((481120 + 12|0))>>2]|0;
   $374 = $370 & $278;
   $375 = $371 & $276;
   $376 = $372 & $275;
   $377 = $373 & $271;
   $378 = $270 ? $266 : Math_fround(0.0);
   $379 = (HEAP32[tempDoublePtr>>2]=$374,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $380 = Math_fround($378 * $379);
   $381 = (HEAP32[tempDoublePtr>>2]=$375,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $382 = Math_fround($378 * $381);
   $383 = (HEAP32[tempDoublePtr>>2]=$376,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $384 = Math_fround($378 * $383);
   $385 = (HEAP32[tempDoublePtr>>2]=$377,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $386 = Math_fround($378 * $385);
   $387 = (HEAP32[tempDoublePtr>>2]=$46,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $388 = Math_fround($387 + $380);
   $389 = (HEAP32[tempDoublePtr>>2]=$48,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $390 = Math_fround($389 + $382);
   $391 = (HEAP32[tempDoublePtr>>2]=$50,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $392 = Math_fround($391 + $384);
   $393 = (HEAP32[tempDoublePtr>>2]=$52,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $394 = Math_fround($393 + $386);
   $395 = (HEAPF32[tempDoublePtr>>2]=$388,HEAP32[tempDoublePtr>>2]|0);
   $396 = (HEAPF32[tempDoublePtr>>2]=$390,HEAP32[tempDoublePtr>>2]|0);
   $397 = (HEAPF32[tempDoublePtr>>2]=$392,HEAP32[tempDoublePtr>>2]|0);
   $398 = (HEAPF32[tempDoublePtr>>2]=$394,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$45>>2] = $395;
   HEAP32[$47>>2] = $396;
   HEAP32[$49>>2] = $397;
   HEAP32[$51>>2] = $398;
  }
  $399 = (($$0169$i) + 64|0);
  $400 = ($399>>>0)<($8>>>0);
  if ($400) {
   $$0169$i = $399;$54 = $218;$56 = $217;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_119constrainSeparationI8Scalar4fPKS1_EEvPT_PKS4_RKT0_($curIt,$curEnd,$spheres$val) {
 $curIt = $curIt|0;
 $curEnd = $curEnd|0;
 $spheres$val = $spheres$val|0;
 var $$$i = 0, $$0153 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $brmerge$i = 0, $brmerge1$i = 0, $sphIt$0154 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($curIt>>>0)<($curEnd>>>0);
 if ($0) {
  $$0153 = $curIt;$sphIt$0154 = $spheres$val;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $1 = HEAP32[$$0153>>2]|0;
  $2 = (($$0153) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($$0153) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($$0153) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($$0153) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($$0153) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($$0153) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($$0153) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($$0153) + 32|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($$0153) + 36|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($$0153) + 40|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($$0153) + 44|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($$0153) + 48|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($$0153) + 52|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($$0153) + 56|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($$0153) + 60|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[481120>>2]|0;
  $33 = HEAP32[((481120 + 4|0))>>2]|0;
  $34 = HEAP32[((481120 + 8|0))>>2]|0;
  $35 = HEAP32[((481120 + 12|0))>>2]|0;
  $36 = $32 & $1;
  $37 = $33 & $3;
  $38 = $34 & $5;
  $39 = $35 & $7;
  $40 = Math_fround(HEAPF32[$sphIt$0154>>2]);
  $41 = (HEAP32[tempDoublePtr>>2]=$36,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $42 = Math_fround($40 - $41);
  $43 = (($sphIt$0154) + 4|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (HEAP32[tempDoublePtr>>2]=$37,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $46 = Math_fround($44 - $45);
  $47 = (($sphIt$0154) + 8|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (HEAP32[tempDoublePtr>>2]=$38,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $50 = Math_fround($48 - $49);
  $51 = (($sphIt$0154) + 12|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (HEAP32[tempDoublePtr>>2]=$39,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $54 = Math_fround($52 - $53);
  $55 = $32 & $9;
  $56 = $33 & $11;
  $57 = $34 & $13;
  $58 = $35 & $15;
  $59 = (($sphIt$0154) + 16|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (HEAP32[tempDoublePtr>>2]=$55,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $62 = Math_fround($60 - $61);
  $63 = (($sphIt$0154) + 20|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (HEAP32[tempDoublePtr>>2]=$56,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $66 = Math_fround($64 - $65);
  $67 = (($sphIt$0154) + 24|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (HEAP32[tempDoublePtr>>2]=$57,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $70 = Math_fround($68 - $69);
  $71 = (($sphIt$0154) + 28|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (HEAP32[tempDoublePtr>>2]=$58,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $74 = Math_fround($72 - $73);
  $75 = $32 & $17;
  $76 = $33 & $19;
  $77 = $34 & $21;
  $78 = $35 & $23;
  $79 = (($sphIt$0154) + 32|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (HEAP32[tempDoublePtr>>2]=$75,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $82 = Math_fround($80 - $81);
  $83 = (($sphIt$0154) + 36|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = (HEAP32[tempDoublePtr>>2]=$76,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $86 = Math_fround($84 - $85);
  $87 = (($sphIt$0154) + 40|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (HEAP32[tempDoublePtr>>2]=$77,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $90 = Math_fround($88 - $89);
  $91 = (($sphIt$0154) + 44|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = (HEAP32[tempDoublePtr>>2]=$78,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $94 = Math_fround($92 - $93);
  $95 = $32 & $25;
  $96 = $33 & $27;
  $97 = $34 & $29;
  $98 = $35 & $31;
  $99 = (($sphIt$0154) + 48|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (HEAP32[tempDoublePtr>>2]=$95,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $102 = Math_fround($100 - $101);
  $103 = (($sphIt$0154) + 52|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = (HEAP32[tempDoublePtr>>2]=$96,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $106 = Math_fround($104 - $105);
  $107 = (($sphIt$0154) + 56|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = (HEAP32[tempDoublePtr>>2]=$97,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $110 = Math_fround($108 - $109);
  $111 = (($sphIt$0154) + 60|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (HEAP32[tempDoublePtr>>2]=$98,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $114 = Math_fround($112 - $113);
  $115 = (($sphIt$0154) + 64|0);
  $116 = HEAP32[481152>>2]|0;
  $117 = HEAP32[((481152 + 4|0))>>2]|0;
  $118 = HEAP32[((481152 + 8|0))>>2]|0;
  $119 = HEAP32[((481152 + 12|0))>>2]|0;
  $120 = Math_fround($42 * $42);
  $121 = Math_fround($62 * $62);
  $122 = Math_fround($82 * $82);
  $123 = Math_fround($102 * $102);
  $124 = (HEAP32[tempDoublePtr>>2]=$116,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $125 = Math_fround($120 + $124);
  $126 = (HEAP32[tempDoublePtr>>2]=$117,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $127 = Math_fround($121 + $126);
  $128 = (HEAP32[tempDoublePtr>>2]=$118,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $129 = Math_fround($122 + $128);
  $130 = (HEAP32[tempDoublePtr>>2]=$119,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $131 = Math_fround($123 + $130);
  $132 = Math_fround($46 * $46);
  $133 = Math_fround($66 * $66);
  $134 = Math_fround($86 * $86);
  $135 = Math_fround($106 * $106);
  $136 = Math_fround($132 + $125);
  $137 = Math_fround($133 + $127);
  $138 = Math_fround($134 + $129);
  $139 = Math_fround($135 + $131);
  $140 = Math_fround($50 * $50);
  $141 = Math_fround($70 * $70);
  $142 = Math_fround($90 * $90);
  $143 = Math_fround($110 * $110);
  $144 = Math_fround($140 + $136);
  $145 = Math_fround($141 + $137);
  $146 = Math_fround($142 + $138);
  $147 = Math_fround($143 + $139);
  $148 = (Math_fround(Math_sqrt((Math_fround($144)))));
  $149 = (Math_fround(Math_sqrt((Math_fround($145)))));
  $150 = (Math_fround(Math_sqrt((Math_fround($146)))));
  $151 = (Math_fround(Math_sqrt((Math_fround($147)))));
  $152 = Math_fround(Math_fround(1.0) / $148);
  $153 = Math_fround(Math_fround(1.0) / $149);
  $154 = Math_fround(Math_fround(1.0) / $150);
  $155 = Math_fround(Math_fround(1.0) / $151);
  $156 = Math_fround($54 * $152);
  $157 = Math_fround($74 * $153);
  $158 = Math_fround($94 * $154);
  $159 = Math_fround($114 * $155);
  $160 = Math_fround(Math_fround(1.0) - $156);
  $161 = Math_fround(Math_fround(1.0) - $157);
  $162 = Math_fround(Math_fround(1.0) - $158);
  $163 = Math_fround(Math_fround(1.0) - $159);
  $164 = $160 < Math_fround(0.0);
  $165 = $161 < Math_fround(0.0);
  $166 = $162 < Math_fround(0.0);
  $167 = $163 < Math_fround(0.0);
  $brmerge$i = $164 | $165;
  $brmerge1$i = $brmerge$i | $166;
  $$$i = $brmerge1$i | $167;
  if ($$$i) {
   $168 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
   $169 = (HEAPF32[tempDoublePtr>>2]=$90,HEAP32[tempDoublePtr>>2]|0);
   $170 = (HEAPF32[tempDoublePtr>>2]=$66,HEAP32[tempDoublePtr>>2]|0);
   $171 = (HEAPF32[tempDoublePtr>>2]=$42,HEAP32[tempDoublePtr>>2]|0);
   $172 = (HEAPF32[tempDoublePtr>>2]=$110,HEAP32[tempDoublePtr>>2]|0);
   $173 = (HEAPF32[tempDoublePtr>>2]=$106,HEAP32[tempDoublePtr>>2]|0);
   $174 = (HEAPF32[tempDoublePtr>>2]=$86,HEAP32[tempDoublePtr>>2]|0);
   $175 = (HEAPF32[tempDoublePtr>>2]=$102,HEAP32[tempDoublePtr>>2]|0);
   $176 = (HEAPF32[tempDoublePtr>>2]=$82,HEAP32[tempDoublePtr>>2]|0);
   $177 = (HEAPF32[tempDoublePtr>>2]=$62,HEAP32[tempDoublePtr>>2]|0);
   $178 = (HEAPF32[tempDoublePtr>>2]=$94,HEAP32[tempDoublePtr>>2]|0);
   $179 = (HEAPF32[tempDoublePtr>>2]=$74,HEAP32[tempDoublePtr>>2]|0);
   $180 = (HEAPF32[tempDoublePtr>>2]=$70,HEAP32[tempDoublePtr>>2]|0);
   $181 = (HEAPF32[tempDoublePtr>>2]=$54,HEAP32[tempDoublePtr>>2]|0);
   $182 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
   $183 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
   $184 = $171 & $32;
   $185 = $183 & $33;
   $186 = $182 & $34;
   $187 = $181 & $35;
   $188 = $164 ? $160 : Math_fround(0.0);
   $189 = (HEAP32[tempDoublePtr>>2]=$184,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $190 = Math_fround($189 * $188);
   $191 = (HEAP32[tempDoublePtr>>2]=$185,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $192 = Math_fround($191 * $188);
   $193 = (HEAP32[tempDoublePtr>>2]=$186,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $194 = Math_fround($193 * $188);
   $195 = (HEAP32[tempDoublePtr>>2]=$187,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $196 = Math_fround($195 * $188);
   $197 = (HEAP32[tempDoublePtr>>2]=$1,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $198 = Math_fround($197 + $190);
   $199 = (HEAP32[tempDoublePtr>>2]=$3,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $200 = Math_fround($199 + $192);
   $201 = (HEAP32[tempDoublePtr>>2]=$5,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $202 = Math_fround($201 + $194);
   $203 = (HEAP32[tempDoublePtr>>2]=$7,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $204 = Math_fround($203 + $196);
   $205 = (HEAPF32[tempDoublePtr>>2]=$198,HEAP32[tempDoublePtr>>2]|0);
   $206 = (HEAPF32[tempDoublePtr>>2]=$200,HEAP32[tempDoublePtr>>2]|0);
   $207 = (HEAPF32[tempDoublePtr>>2]=$202,HEAP32[tempDoublePtr>>2]|0);
   $208 = (HEAPF32[tempDoublePtr>>2]=$204,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$$0153>>2] = $205;
   HEAP32[$2>>2] = $206;
   HEAP32[$4>>2] = $207;
   HEAP32[$6>>2] = $208;
   $209 = HEAP32[481120>>2]|0;
   $210 = HEAP32[((481120 + 4|0))>>2]|0;
   $211 = HEAP32[((481120 + 8|0))>>2]|0;
   $212 = HEAP32[((481120 + 12|0))>>2]|0;
   $213 = $209 & $177;
   $214 = $210 & $170;
   $215 = $211 & $180;
   $216 = $212 & $179;
   $217 = $165 ? $161 : Math_fround(0.0);
   $218 = (HEAP32[tempDoublePtr>>2]=$213,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $219 = Math_fround($217 * $218);
   $220 = (HEAP32[tempDoublePtr>>2]=$214,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $221 = Math_fround($217 * $220);
   $222 = (HEAP32[tempDoublePtr>>2]=$215,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $223 = Math_fround($217 * $222);
   $224 = (HEAP32[tempDoublePtr>>2]=$216,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $225 = Math_fround($217 * $224);
   $226 = (HEAP32[tempDoublePtr>>2]=$9,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $227 = Math_fround($226 + $219);
   $228 = (HEAP32[tempDoublePtr>>2]=$11,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $229 = Math_fround($228 + $221);
   $230 = (HEAP32[tempDoublePtr>>2]=$13,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $231 = Math_fround($230 + $223);
   $232 = (HEAP32[tempDoublePtr>>2]=$15,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $233 = Math_fround($232 + $225);
   $234 = (HEAPF32[tempDoublePtr>>2]=$227,HEAP32[tempDoublePtr>>2]|0);
   $235 = (HEAPF32[tempDoublePtr>>2]=$229,HEAP32[tempDoublePtr>>2]|0);
   $236 = (HEAPF32[tempDoublePtr>>2]=$231,HEAP32[tempDoublePtr>>2]|0);
   $237 = (HEAPF32[tempDoublePtr>>2]=$233,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$8>>2] = $234;
   HEAP32[$10>>2] = $235;
   HEAP32[$12>>2] = $236;
   HEAP32[$14>>2] = $237;
   $238 = HEAP32[481120>>2]|0;
   $239 = HEAP32[((481120 + 4|0))>>2]|0;
   $240 = HEAP32[((481120 + 8|0))>>2]|0;
   $241 = HEAP32[((481120 + 12|0))>>2]|0;
   $242 = $238 & $176;
   $243 = $239 & $174;
   $244 = $240 & $169;
   $245 = $241 & $178;
   $246 = $166 ? $162 : Math_fround(0.0);
   $247 = (HEAP32[tempDoublePtr>>2]=$242,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $248 = Math_fround($246 * $247);
   $249 = (HEAP32[tempDoublePtr>>2]=$243,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $250 = Math_fround($246 * $249);
   $251 = (HEAP32[tempDoublePtr>>2]=$244,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $252 = Math_fround($246 * $251);
   $253 = (HEAP32[tempDoublePtr>>2]=$245,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $254 = Math_fround($246 * $253);
   $255 = (HEAP32[tempDoublePtr>>2]=$17,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $256 = Math_fround($255 + $248);
   $257 = (HEAP32[tempDoublePtr>>2]=$19,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $258 = Math_fround($257 + $250);
   $259 = (HEAP32[tempDoublePtr>>2]=$21,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $260 = Math_fround($259 + $252);
   $261 = (HEAP32[tempDoublePtr>>2]=$23,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $262 = Math_fround($261 + $254);
   $263 = (HEAPF32[tempDoublePtr>>2]=$256,HEAP32[tempDoublePtr>>2]|0);
   $264 = (HEAPF32[tempDoublePtr>>2]=$258,HEAP32[tempDoublePtr>>2]|0);
   $265 = (HEAPF32[tempDoublePtr>>2]=$260,HEAP32[tempDoublePtr>>2]|0);
   $266 = (HEAPF32[tempDoublePtr>>2]=$262,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$16>>2] = $263;
   HEAP32[$18>>2] = $264;
   HEAP32[$20>>2] = $265;
   HEAP32[$22>>2] = $266;
   $267 = HEAP32[481120>>2]|0;
   $268 = HEAP32[((481120 + 4|0))>>2]|0;
   $269 = HEAP32[((481120 + 8|0))>>2]|0;
   $270 = HEAP32[((481120 + 12|0))>>2]|0;
   $271 = $267 & $175;
   $272 = $268 & $173;
   $273 = $269 & $172;
   $274 = $270 & $168;
   $275 = $167 ? $163 : Math_fround(0.0);
   $276 = (HEAP32[tempDoublePtr>>2]=$271,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $277 = Math_fround($275 * $276);
   $278 = (HEAP32[tempDoublePtr>>2]=$272,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $279 = Math_fround($275 * $278);
   $280 = (HEAP32[tempDoublePtr>>2]=$273,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $281 = Math_fround($275 * $280);
   $282 = (HEAP32[tempDoublePtr>>2]=$274,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $283 = Math_fround($275 * $282);
   $284 = (HEAP32[tempDoublePtr>>2]=$25,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $285 = Math_fround($284 + $277);
   $286 = (HEAP32[tempDoublePtr>>2]=$27,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $287 = Math_fround($286 + $279);
   $288 = (HEAP32[tempDoublePtr>>2]=$29,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $289 = Math_fround($288 + $281);
   $290 = (HEAP32[tempDoublePtr>>2]=$31,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $291 = Math_fround($290 + $283);
   $292 = (HEAPF32[tempDoublePtr>>2]=$285,HEAP32[tempDoublePtr>>2]|0);
   $293 = (HEAPF32[tempDoublePtr>>2]=$287,HEAP32[tempDoublePtr>>2]|0);
   $294 = (HEAPF32[tempDoublePtr>>2]=$289,HEAP32[tempDoublePtr>>2]|0);
   $295 = (HEAPF32[tempDoublePtr>>2]=$291,HEAP32[tempDoublePtr>>2]|0);
   HEAP32[$24>>2] = $292;
   HEAP32[$26>>2] = $293;
   HEAP32[$28>>2] = $294;
   HEAP32[$30>>2] = $295;
  }
  $296 = (($$0153) + 64|0);
  $297 = ($296>>>0)<($curEnd>>>0);
  if ($297) {
   $$0153 = $296;$sphIt$0154 = $115;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5cloth14SwSolverKernelI8Scalar4fE16updateSleepStateEv($this) {
 $this = $this|0;
 var $$0117$i = 0, $$018$i = 0, $$lcssa$i = 0, $$lcssa14$i = 0, $$lcssa15$i = 0, $$lcssa16$i = 0, $$pre = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0;
 var $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 532|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(1000.0));
 $3 = (~~(($2))>>>0);
 $4 = ($3>>>0)>(1);
 $5 = $4 ? $3 : 1;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 248|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + ($9))|0;
 HEAP32[$8>>2] = $10;
 $11 = HEAP32[$6>>2]|0;
 $12 = (($11) + 248|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 512|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($13>>>0)<($16>>>0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = (($11) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$11>>2]|0;
 $21 = (($19) + ($20<<4)|0);
 $22 = ($19>>>0)<($21>>>0);
 if ($22) {
  $23 = (($11) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $$0117$i = $19;$$018$i = $24;$48 = 0;$52 = 0;$56 = 0;$60 = 0;
  while(1) {
   $25 = Math_fround(HEAPF32[$$0117$i>>2]);
   $26 = Math_fround(HEAPF32[$$018$i>>2]);
   $27 = Math_fround($25 - $26);
   $28 = (($$0117$i) + 4|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = (($$018$i) + 4|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = Math_fround($29 - $31);
   $33 = (($$0117$i) + 8|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = (($$018$i) + 8|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = Math_fround($34 - $36);
   $38 = (($$0117$i) + 12|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = (($$018$i) + 12|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = Math_fround($39 - $41);
   $43 = (Math_fround(Math_abs((Math_fround($27)))));
   $44 = (Math_fround(Math_abs((Math_fround($32)))));
   $45 = (Math_fround(Math_abs((Math_fround($37)))));
   $46 = (Math_fround(Math_abs((Math_fround($42)))));
   $47 = (HEAP32[tempDoublePtr>>2]=$48,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $49 = $47 < $43;
   $50 = $49 ? $43 : $47;
   $51 = (HEAP32[tempDoublePtr>>2]=$52,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $53 = $51 < $44;
   $54 = $53 ? $44 : $51;
   $55 = (HEAP32[tempDoublePtr>>2]=$56,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $57 = $55 < $45;
   $58 = $57 ? $45 : $55;
   $59 = (HEAP32[tempDoublePtr>>2]=$60,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $61 = $59 < $46;
   $62 = $61 ? $46 : $59;
   $63 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
   $64 = (HEAPF32[tempDoublePtr>>2]=$54,HEAP32[tempDoublePtr>>2]|0);
   $65 = (HEAPF32[tempDoublePtr>>2]=$58,HEAP32[tempDoublePtr>>2]|0);
   $66 = (HEAPF32[tempDoublePtr>>2]=$62,HEAP32[tempDoublePtr>>2]|0);
   $67 = (($$0117$i) + 16|0);
   $68 = (($$018$i) + 16|0);
   $69 = ($67>>>0)<($21>>>0);
   if ($69) {
    $$0117$i = $67;$$018$i = $68;$48 = $63;$52 = $64;$56 = $65;$60 = $66;
   } else {
    $$lcssa$i = $66;$$lcssa14$i = $65;$$lcssa15$i = $64;$$lcssa16$i = $63;
    break;
   }
  }
 } else {
  $$lcssa$i = 0;$$lcssa14$i = 0;$$lcssa15$i = 0;$$lcssa16$i = 0;
 }
 $70 = HEAP32[481120>>2]|0;
 $71 = HEAP32[((481120 + 4|0))>>2]|0;
 $72 = HEAP32[((481120 + 8|0))>>2]|0;
 $73 = HEAP32[((481120 + 12|0))>>2]|0;
 $74 = $70 & $$lcssa16$i;
 $75 = $72 & $$lcssa14$i;
 $76 = $73 & $$lcssa$i;
 $77 = (($11) + 244|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 1)|0;
 HEAP32[$77>>2] = $79;
 $80 = HEAP32[$this>>2]|0;
 $81 = (($80) + 520|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 * $1);
 $84 = (HEAP32[tempDoublePtr>>2]=$74,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $85 = !($84 >= $83);
 if ($85) {
  $86 = $71 & $$lcssa15$i;
  $87 = (HEAP32[tempDoublePtr>>2]=$86,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $88 = !($87 >= $83);
  if ($88) {
   $89 = (HEAP32[tempDoublePtr>>2]=$75,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $90 = !($89 >= $83);
   if ($90) {
    $91 = (HEAP32[tempDoublePtr>>2]=$76,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $92 = !($91 >= $83);
    if ($92) {
     $96 = $80;
    } else {
     label = 9;
    }
   } else {
    label = 9;
   }
  } else {
   label = 9;
  }
 } else {
  label = 9;
 }
 if ((label|0) == 9) {
  $93 = HEAP32[$6>>2]|0;
  $94 = (($93) + 244|0);
  HEAP32[$94>>2] = 0;
  $$pre = HEAP32[$this>>2]|0;
  $96 = $$pre;
 }
 $95 = (($96) + 512|0);
 $97 = HEAP32[$95>>2]|0;
 $98 = HEAP32[$6>>2]|0;
 $99 = (($98) + 248|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) - ($97))|0;
 HEAP32[$99>>2] = $101;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth14IterationStateI8Scalar4fE6updateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $exitcond = 0, $i$025 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 64|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($this) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 * $6);
  $8 = (($this) + 20|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($4 * $9);
  $11 = (($this) + 24|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($4 * $12);
  $14 = (($this) + 28|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($4 * $15);
  $17 = (($this) + 68|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($this) + 32|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($18 * $20);
  $22 = (($this) + 36|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($18 * $23);
  $25 = (($this) + 40|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($18 * $26);
  $28 = (($this) + 44|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($18 * $29);
  $31 = Math_fround($7 + $21);
  $32 = Math_fround($10 + $24);
  $33 = Math_fround($13 + $27);
  $34 = Math_fround($16 + $30);
  $35 = (($this) + 72|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($this) + 48|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround($36 * $38);
  $40 = (($this) + 52|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($36 * $41);
  $43 = (($this) + 56|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($36 * $44);
  $46 = (($this) + 60|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($36 * $47);
  $49 = Math_fround($31 + $39);
  $50 = Math_fround($32 + $42);
  $51 = Math_fround($33 + $45);
  $52 = Math_fround($34 + $48);
  $53 = (HEAPF32[tempDoublePtr>>2]=$49,HEAP32[tempDoublePtr>>2]|0);
  $54 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $55 = (HEAPF32[tempDoublePtr>>2]=$51,HEAP32[tempDoublePtr>>2]|0);
  $56 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$3>>2] = $53;
  HEAP32[$17>>2] = $54;
  HEAP32[$35>>2] = $55;
  $57 = (($this) + 76|0);
  HEAP32[$57>>2] = $56;
  $58 = (($this) + 80|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($59 * $6);
  $61 = Math_fround($59 * $9);
  $62 = Math_fround($59 * $12);
  $63 = Math_fround($59 * $15);
  $64 = (($this) + 84|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($65 * $20);
  $67 = Math_fround($65 * $23);
  $68 = Math_fround($65 * $26);
  $69 = Math_fround($65 * $29);
  $70 = Math_fround($60 + $66);
  $71 = Math_fround($61 + $67);
  $72 = Math_fround($62 + $68);
  $73 = Math_fround($63 + $69);
  $74 = (($this) + 88|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($75 * $38);
  $77 = Math_fround($75 * $41);
  $78 = Math_fround($75 * $44);
  $79 = Math_fround($75 * $47);
  $80 = Math_fround($70 + $76);
  $81 = Math_fround($71 + $77);
  $82 = Math_fround($72 + $78);
  $83 = Math_fround($73 + $79);
  $84 = (HEAPF32[tempDoublePtr>>2]=$80,HEAP32[tempDoublePtr>>2]|0);
  $85 = (HEAPF32[tempDoublePtr>>2]=$81,HEAP32[tempDoublePtr>>2]|0);
  $86 = (HEAPF32[tempDoublePtr>>2]=$82,HEAP32[tempDoublePtr>>2]|0);
  $87 = (HEAPF32[tempDoublePtr>>2]=$83,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$58>>2] = $84;
  HEAP32[$64>>2] = $85;
  HEAP32[$74>>2] = $86;
  $88 = (($this) + 92|0);
  HEAP32[$88>>2] = $87;
 }
 $89 = (($this) + 192|0);
 $90 = (($this) + 196|0);
 $91 = (($this) + 200|0);
 $92 = (($this) + 204|0);
 $i$025 = 0;
 while(1) {
  $93 = ((($this) + ($i$025<<4)|0) + 96|0);
  $94 = ((($this) + ($i$025<<4)|0) + 16|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = Math_fround(HEAPF32[$89>>2]);
  $97 = Math_fround($95 * $96);
  $98 = ((($this) + ($i$025<<4)|0) + 20|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = Math_fround(HEAPF32[$90>>2]);
  $101 = Math_fround($99 * $100);
  $102 = ((($this) + ($i$025<<4)|0) + 24|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = Math_fround(HEAPF32[$91>>2]);
  $105 = Math_fround($103 * $104);
  $106 = ((($this) + ($i$025<<4)|0) + 28|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = Math_fround(HEAPF32[$92>>2]);
  $109 = Math_fround($107 * $108);
  $110 = Math_fround(HEAPF32[$93>>2]);
  $111 = Math_fround($110 - $97);
  $112 = ((($this) + ($i$025<<4)|0) + 100|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($113 - $101);
  $115 = ((($this) + ($i$025<<4)|0) + 104|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = Math_fround($116 - $105);
  $118 = ((($this) + ($i$025<<4)|0) + 108|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround($119 - $109);
  $121 = (HEAPF32[tempDoublePtr>>2]=$111,HEAP32[tempDoublePtr>>2]|0);
  $122 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
  $123 = (HEAPF32[tempDoublePtr>>2]=$117,HEAP32[tempDoublePtr>>2]|0);
  $124 = (HEAPF32[tempDoublePtr>>2]=$120,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$93>>2] = $121;
  HEAP32[$112>>2] = $122;
  HEAP32[$115>>2] = $123;
  HEAP32[$118>>2] = $124;
  $125 = ((($this) + ($i$025<<4)|0) + 144|0);
  $126 = Math_fround(HEAPF32[$89>>2]);
  $127 = Math_fround($95 * $126);
  $128 = Math_fround(HEAPF32[$90>>2]);
  $129 = Math_fround($99 * $128);
  $130 = Math_fround(HEAPF32[$91>>2]);
  $131 = Math_fround($103 * $130);
  $132 = Math_fround(HEAPF32[$92>>2]);
  $133 = Math_fround($107 * $132);
  $134 = Math_fround(HEAPF32[$125>>2]);
  $135 = Math_fround($127 + $134);
  $136 = ((($this) + ($i$025<<4)|0) + 148|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = Math_fround($129 + $137);
  $139 = ((($this) + ($i$025<<4)|0) + 152|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = Math_fround($131 + $140);
  $142 = ((($this) + ($i$025<<4)|0) + 156|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = Math_fround($133 + $143);
  $145 = (HEAPF32[tempDoublePtr>>2]=$135,HEAP32[tempDoublePtr>>2]|0);
  $146 = (HEAPF32[tempDoublePtr>>2]=$138,HEAP32[tempDoublePtr>>2]|0);
  $147 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
  $148 = (HEAPF32[tempDoublePtr>>2]=$144,HEAP32[tempDoublePtr>>2]|0);
  HEAP32[$125>>2] = $145;
  HEAP32[$136>>2] = $146;
  HEAP32[$139>>2] = $147;
  HEAP32[$142>>2] = $148;
  $149 = (($i$025) + 1)|0;
  $exitcond = ($149|0)==(3);
  if ($exitcond) {
   break;
  } else {
   $i$025 = $149;
  }
 }
 $150 = (($this) + 192|0);
 ;HEAP32[$150+0>>2]=0|0;HEAP32[$150+4>>2]=0|0;HEAP32[$150+8>>2]=0|0;HEAP32[$150+12>>2]=0|0;
 $151 = HEAP32[$this>>2]|0;
 $152 = (($151) + -1)|0;
 HEAP32[$this>>2] = $152;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a4208() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[481088>>2] = 0;
 HEAP32[((481088 + 4|0))>>2] = 0;
 HEAP32[((481088 + 8|0))>>2] = 0;
 HEAP32[((481088 + 12|0))>>2] = -1;
 HEAP32[481104>>2] = -1;
 HEAP32[((481104 + 4|0))>>2] = -1;
 HEAP32[((481104 + 8|0))>>2] = 0;
 HEAP32[((481104 + 12|0))>>2] = 0;
 HEAP32[481120>>2] = -1;
 HEAP32[((481120 + 4|0))>>2] = -1;
 HEAP32[((481120 + 8|0))>>2] = -1;
 HEAP32[((481120 + 12|0))>>2] = 0;
 HEAP32[481136>>2] = 0;
 HEAP32[((481136 + 4|0))>>2] = -1;
 HEAP32[((481136 + 8|0))>>2] = -1;
 HEAP32[((481136 + 12|0))>>2] = -1;
 HEAPF32[481152>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((481152 + 4|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((481152 + 8|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((481152 + 12|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[481168>>2] = Math_fround(-1.0);
 HEAPF32[((481168 + 4|0))>>2] = Math_fround(-1.0);
 HEAPF32[((481168 + 8|0))>>2] = Math_fround(-1.0);
 HEAPF32[((481168 + 12|0))>>2] = Math_fround(1.0);
 HEAPF32[481184>>2] = Math_fround(0.0);
 HEAPF32[((481184 + 4|0))>>2] = Math_fround(0.0);
 HEAPF32[((481184 + 8|0))>>2] = Math_fround(0.0);
 HEAPF32[((481184 + 12|0))>>2] = Math_fround(3.40282346638528859812E+38);
 HEAPF32[481200>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((481200 + 4|0))>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((481200 + 8|0))>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[((481200 + 12|0))>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx5cloth16TripletSchedulerC2ENS0_5RangeIA4_KjEE($this,$triplets) {
 $this = $this|0;
 $triplets = $triplets|0;
 var $$012$i$i$i = 0, $$03$i$i$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$triplets>>2]|0;
 $1 = (($triplets) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = ($2>>>0)<($0>>>0);
 if ($4) {
  HEAP32[$3>>2] = 0;
  $5 = (($this) + 8|0);
  HEAP32[$5>>2] = 0;
  label = 4;
 } else {
  $6 = $2;
  $7 = $0;
  $8 = (($6) - ($7))|0;
  $9 = $8 >> 4;
  HEAP32[$3>>2] = $9;
  $10 = (($this) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = ($9|0)==(0);
  if ($11) {
   label = 4;
  } else {
   $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$8,481216,558)|0);
   $$pre$i$i = HEAP32[$3>>2]|0;
   HEAP32[$this>>2] = $12;
   $13 = (($12) + ($$pre$i$i<<4)|0);
   $14 = ($$pre$i$i|0)>(0);
   if ($14) {
    $$012$i$i$i = $12;$$03$i$i$i = $0;
    while(1) {
     $15 = ($$012$i$i$i|0)==(0|0);
     if (!($15)) {
      ;HEAP32[$$012$i$i$i+0>>2]=HEAP32[$$03$i$i$i+0>>2]|0;HEAP32[$$012$i$i$i+4>>2]=HEAP32[$$03$i$i$i+4>>2]|0;HEAP32[$$012$i$i$i+8>>2]=HEAP32[$$03$i$i$i+8>>2]|0;HEAP32[$$012$i$i$i+12>>2]=HEAP32[$$03$i$i$i+12>>2]|0;
     }
     $16 = (($$012$i$i$i) + 16|0);
     $17 = (($$03$i$i$i) + 16|0);
     $18 = ($16>>>0)<($13>>>0);
     if ($18) {
      $$012$i$i$i = $16;$$03$i$i$i = $17;
     } else {
      break;
     }
    }
   }
  }
 }
 if ((label|0) == 4) {
  HEAP32[$this>>2] = 0;
 }
 $19 = (($this) + 12|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 16|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 20|0);
 HEAP32[$21>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx5cloth16TripletScheduler4simdEjj($this,$numParticles,$simdWidth) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $simdWidth = $simdWidth|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $mark = 0, $or$cond = 0, $or$cond$i$i = 0;
 var $or$cond2 = 0, $setIndex$07 = 0, $setSize = 0, $tIt$06 = 0, $tIt$1$lcssa = 0, $tIt$1$lcssa12 = 0, $tIt$13 = 0, $tIt$2 = 0, $tIt$3 = 0, $tSwap$04 = 0, $tSwap$1 = 0, $tSwap$21 = 0, $tSwap$3 = 0, $tmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmp$i = sp + 24|0;
 $mark = sp;
 $0 = sp + 12|0;
 $setSize = sp + 16|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = -1;
 HEAP32[$mark>>2] = 0;
 $4 = (($mark) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($mark) + 8|0);
 HEAP32[$5>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE6resizeEjRKj($mark,$numParticles,$0);
 HEAP32[$setSize>>2] = 0;
 $6 = HEAP32[$this>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = (($6) + ($7<<4)|0);
 $9 = ($7|0)==(0);
 if (!($9)) {
  $10 = $8;
  $11 = (($this) + 12|0);
  $12 = (($this) + 20|0);
  $13 = (($this) + 16|0);
  $73 = 0;$setIndex$07 = 0;$tIt$06 = $6;
  while(1) {
   $14 = $tIt$06;
   $15 = (($10) - ($14))|0;
   $16 = $15 >> 4;
   $17 = ($16>>>0)>($simdWidth>>>0);
   $18 = $17 ? $simdWidth : $16;
   $19 = (($tIt$06) + ($18<<4)|0);
   $20 = ($18|0)==(0);
   $21 = ($tIt$06|0)==($8|0);
   $or$cond2 = $20 | $21;
   L8: do {
    if ($or$cond2) {
     $74 = $73;$tIt$1$lcssa = $tIt$06;$tSwap$3 = $8;
     label = 14;
    } else {
     $22 = HEAP32[$mark>>2]|0;
     $46 = $73;$tIt$13 = $tIt$06;$tSwap$04 = $8;
     while(1) {
      $23 = (($tIt$13) + 8|0);
      $24 = (($tIt$13) + 4|0);
      $tSwap$1 = $tSwap$04;
      while(1) {
       $25 = HEAP32[$tIt$13>>2]|0;
       $26 = (($22) + ($25<<2)|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($27|0)==($setIndex$07|0);
       if (!($28)) {
        $29 = HEAP32[$24>>2]|0;
        $30 = (($22) + ($29<<2)|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = ($31|0)==($setIndex$07|0);
        if (!($32)) {
         $33 = HEAP32[$23>>2]|0;
         $34 = (($22) + ($33<<2)|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = ($35|0)==($setIndex$07|0);
         if (!($36)) {
          $tSwap$21 = $tSwap$1;
          break;
         }
        }
       }
       $37 = (($tSwap$1) + -16|0);
       $38 = ($tIt$13|0)==($37|0);
       if ($38) {
        $tSwap$21 = $tIt$13;
        break;
       }
       ;HEAP32[$tmp$i+0>>2]=HEAP32[$tIt$13+0>>2]|0;HEAP32[$tmp$i+4>>2]=HEAP32[$tIt$13+4>>2]|0;HEAP32[$tmp$i+8>>2]=HEAP32[$tIt$13+8>>2]|0;HEAP32[$tmp$i+12>>2]=HEAP32[$tIt$13+12>>2]|0;
       ;HEAP32[$tIt$13+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$tIt$13+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$tIt$13+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$tIt$13+12>>2]=HEAP32[$37+12>>2]|0;
       ;HEAP32[$37+0>>2]=HEAP32[$tmp$i+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$tmp$i+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$tmp$i+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$tmp$i+12>>2]|0;
       $tSwap$1 = $37;
      }
      $39 = ($tIt$13|0)==($tSwap$21|0);
      if ($39) {
       $51 = $46;$tIt$1$lcssa12 = $tIt$13;
       label = 15;
       break L8;
      }
      HEAP32[$26>>2] = $setIndex$07;
      $40 = HEAP32[$24>>2]|0;
      $41 = (($22) + ($40<<2)|0);
      HEAP32[$41>>2] = $setIndex$07;
      $42 = HEAP32[$23>>2]|0;
      $43 = (($22) + ($42<<2)|0);
      HEAP32[$43>>2] = $setIndex$07;
      $44 = (($tIt$13) + 16|0);
      $45 = (($46) + 1)|0;
      HEAP32[$setSize>>2] = $45;
      $47 = ($44|0)==($19|0);
      $48 = ($44|0)==($tSwap$21|0);
      $or$cond = $47 | $48;
      if ($or$cond) {
       $74 = $45;$tIt$1$lcssa = $44;$tSwap$3 = $tSwap$21;
       label = 14;
       break;
      } else {
       $46 = $45;$tIt$13 = $44;$tSwap$04 = $tSwap$21;
      }
     }
    }
   } while(0);
   if ((label|0) == 14) {
    label = 0;
    $49 = ($tIt$1$lcssa|0)==($tSwap$3|0);
    if ($49) {
     $51 = $74;$tIt$1$lcssa12 = $tIt$1$lcssa;
     label = 15;
    } else {
     $75 = $74;$tIt$3 = $tIt$1$lcssa;
    }
   }
   if ((label|0) == 15) {
    label = 0;
    $50 = ($51>>>0)>($simdWidth>>>0);
    if ($50) {
     $52 = (($51>>>0) % ($simdWidth>>>0))&-1;
     $53 = (($51) - ($52))|0;
     HEAP32[$setSize>>2] = $53;
     $54 = (0 - ($52))|0;
     $55 = (($tIt$1$lcssa12) + ($54<<4)|0);
     $63 = $53;$tIt$2 = $55;
    } else {
     $63 = $51;$tIt$2 = $tIt$1$lcssa12;
    }
    $56 = HEAP32[$12>>2]|0;
    $57 = $56 & 2147483647;
    $58 = HEAP32[$13>>2]|0;
    $59 = ($57>>>0)>($58>>>0);
    if ($59) {
     $60 = HEAP32[$11>>2]|0;
     $61 = (($60) + ($58<<2)|0);
     $62 = ($61|0)==(0|0);
     if ($62) {
      $65 = $58;
     } else {
      HEAP32[$61>>2] = $63;
      $$pre$i = HEAP32[$13>>2]|0;
      $65 = $$pre$i;
     }
     $64 = (($65) + 1)|0;
     HEAP32[$13>>2] = $64;
    } else {
     (__ZN5physx6shdfnd5ArrayIjNS0_9AllocatorEE15growAndPushBackERKj($11,$setSize)|0);
    }
    HEAP32[$setSize>>2] = 0;
    $75 = 0;$tIt$3 = $tIt$2;
   }
   $66 = (($setIndex$07) + 1)|0;
   $67 = ($tIt$3|0)==($8|0);
   if ($67) {
    break;
   } else {
    $73 = $75;$setIndex$07 = $66;$tIt$06 = $tIt$3;
   }
  }
 }
 $68 = HEAP32[$5>>2]|0;
 $69 = $68 & 2147483647;
 $70 = ($69|0)!=(0);
 $71 = ($68|0)>(-1);
 $or$cond$i$i = $70 & $71;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $72 = HEAP32[$mark>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($mark,$72);
 STACKTOP = sp;return;
}
function __ZN5physx24PxvRegisterArticulationsEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[503512>>2] = 1;
 HEAP32[503520>>2] = 128;
 HEAP32[503528>>2] = 3368;
 __ZN5physx36PxsSolverCoreRegisterArticulationFnsEv();
 STACKTOP = sp;return;
}
function __ZN5physx29PxvRegisterLegacyHeightFieldsEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[((503592 + 24|0))>>2] = 103;
 HEAP32[((503592 + 80|0))>>2] = 104;
 HEAP32[((503592 + 108|0))>>2] = 105;
 HEAP32[((503592 + 136|0))>>2] = 106;
 HEAP32[((503792 + 24|0))>>2] = 103;
 HEAP32[((503792 + 80|0))>>2] = 104;
 HEAP32[((503792 + 108|0))>>2] = 105;
 HEAP32[((503792 + 136|0))>>2] = 106;
 STACKTOP = sp;return;
}
function __ZN5physx20PxvRegisterParticlesEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx10PxsContext17registerParticlesEv();
 STACKTOP = sp;return;
}
function __ZN5physx7PxvInitEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17PxcPoolMallocInitv();
 STACKTOP = sp;return;
}
function __ZN5physx7PxvTermEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17PxcPoolMallocTermv();
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManagerC2ERNS_2Cm13EventProfilerERNS_19PxcScratchAllocatorE($this,$eventProfiler,$scratchAllocator) {
 $this = $this|0;
 $eventProfiler = $eventProfiler|0;
 $scratchAllocator = $scratchAllocator|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $i$01 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $scratchAllocator;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $eventProfiler;
 $1 = (($this) + 8|0);
 $2 = (($this) + 40|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;HEAP32[$1+28>>2]=0|0;
 HEAP32[$2>>2] = 1073741823;
 $3 = (($this) + 44|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 48|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 52|0);
 HEAP32[$5>>2] = 1073741823;
 $6 = (($this) + 56|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 60|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 64|0);
 HEAP32[$8>>2] = 1073741823;
 $9 = (($this) + 68|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 72|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 80|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 84|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 88|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 92|0);
 HEAP32[$14>>2] = 64;
 $15 = (($this) + 96|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 100|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 108|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 112|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 116|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 120|0);
 HEAP32[$20>>2] = 64;
 $21 = (($this) + 124|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 128|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 136|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 140|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 144|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 148|0);
 HEAP32[$26>>2] = 64;
 $27 = (($this) + 152|0);
 $28 = (($this) + 208|0);
 dest=$27+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$28>>2] = 1073741822;
 $29 = (($this) + 212|0);
 $30 = (($this) + 232|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 236|0);
 HEAP32[$31>>2] = 0;
 ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;
 $32 = (($this) + 244|0);
 $33 = (($this) + 280|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 284|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 292|0);
 ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;HEAP32[$32+20>>2]=0|0;HEAP32[$32+24>>2]=0|0;HEAP32[$32+28>>2]=0|0;
 HEAP32[$35>>2] = 1073741823;
 $36 = (($this) + 296|0);
 $37 = (($this) + 328|0);
 ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;HEAP32[$36+16>>2]=0|0;HEAP32[$36+20>>2]=0|0;HEAP32[$36+24>>2]=0|0;HEAP32[$36+28>>2]=0|0;
 HEAP32[$37>>2] = 1073741823;
 $38 = (($this) + 332|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 336|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 340|0);
 HEAP32[$40>>2] = 1073741823;
 $41 = (($this) + 344|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 348|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 352|0);
 HEAP32[$43>>2] = 1073741823;
 $44 = (($this) + 356|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 360|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 368|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 372|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 376|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 380|0);
 HEAP32[$49>>2] = 64;
 $50 = (($this) + 16896|0);
 HEAP32[$50>>2] = $scratchAllocator;
 $51 = (($this) + 16900|0);
 HEAP32[$51>>2] = 0;
 $52 = (($this) + 16904|0);
 HEAP32[$52>>2] = 0;
 $53 = (($this) + 16912|0);
 HEAP32[$53>>2] = 0;
 $54 = (($this) + 33312|0);
 HEAP32[$54>>2] = $scratchAllocator;
 $55 = (($this) + 33316|0);
 HEAP32[$55>>2] = 0;
 $56 = (($this) + 33320|0);
 HEAP32[$56>>2] = 0;
 $57 = (($this) + 33328|0);
 HEAP32[$57>>2] = 0;
 $58 = (($this) + 37440|0);
 HEAP32[$58>>2] = $scratchAllocator;
 $59 = (($this) + 37444|0);
 HEAP32[$59>>2] = 0;
 $60 = (($this) + 37448|0);
 HEAP32[$60>>2] = 0;
 $61 = (($this) + 41552|0);
 HEAP32[$61>>2] = $scratchAllocator;
 $62 = (($this) + 41556|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 41560|0);
 HEAP32[$63>>2] = 0;
 $64 = (($this) + 41568|0);
 HEAP32[$64>>2] = 0;
 $65 = (($this) + 45680|0);
 HEAP32[$65>>2] = $scratchAllocator;
 $66 = (($this) + 45684|0);
 HEAP32[$66>>2] = 0;
 $67 = (($this) + 45688|0);
 HEAP32[$67>>2] = 0;
 $68 = (($this) + 45696|0);
 HEAP32[$68>>2] = 0;
 $69 = (($this) + 49808|0);
 HEAP32[$69>>2] = $scratchAllocator;
 $70 = (($this) + 49812|0);
 HEAP32[$70>>2] = 0;
 $71 = (($this) + 49816|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 49824|0);
 $73 = (($this) + 49868|0);
 dest=$72+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx14SingleAABBTaskC2Ev($73);
 $74 = (($this) + 50324|0);
 __ZN5physx13ActorAABBTaskC2Ev($74);
 $75 = (($this) + 50608|0);
 __ZN5physx17AggregateAABBTaskC2Ev($75);
 $76 = (($this) + 51012|0);
 $77 = (($this) + 51016|0);
 HEAP16[$77>>1] = -1;
 $78 = (($this) + 51018|0);
 HEAP16[$78>>1] = 0;
 $79 = (($this) + 51020|0);
 HEAP32[$79>>2] = 0;
 HEAP32[$76>>2] = ((434896 + 8|0));
 $80 = (($this) + 51024|0);
 HEAP32[$80>>2] = 0;
 $81 = (($this) + 51028|0);
 HEAP32[$81>>2] = 0;
 HEAP32[$76>>2] = ((482824 + 8|0));
 $82 = (($this) + 51032|0);
 HEAP32[$82>>2] = 0;
 $83 = (($this) + 51056|0);
 $84 = (($this) + 51060|0);
 HEAP16[$84>>1] = -1;
 $85 = (($this) + 51062|0);
 HEAP16[$85>>1] = 0;
 $86 = (($this) + 51064|0);
 HEAP32[$86>>2] = 0;
 HEAP32[$83>>2] = ((434896 + 8|0));
 $87 = (($this) + 51068|0);
 HEAP32[$87>>2] = 0;
 $88 = (($this) + 51072|0);
 HEAP32[$88>>2] = 0;
 HEAP32[$83>>2] = ((482872 + 8|0));
 $89 = (($this) + 51096|0);
 HEAP32[$89>>2] = 0;
 $90 = (($this) + 51100|0);
 __ZN5physx14SingleAABBTaskC2Ev($90);
 $91 = (($this) + 51556|0);
 $92 = (($this) + 51560|0);
 HEAP16[$92>>1] = -1;
 $93 = (($this) + 51562|0);
 HEAP16[$93>>1] = 0;
 $94 = (($this) + 51564|0);
 HEAP32[$94>>2] = 0;
 HEAP32[$91>>2] = ((434896 + 8|0));
 $95 = (($this) + 51568|0);
 HEAP32[$95>>2] = 0;
 $96 = (($this) + 51572|0);
 HEAP32[$96>>2] = 0;
 HEAP32[$91>>2] = ((482920 + 8|0));
 $97 = (($this) + 51596|0);
 ;HEAP32[$97+0>>2]=0|0;HEAP32[$97+4>>2]=0|0;HEAP32[$97+8>>2]=0|0;HEAP32[$97+12>>2]=0|0;HEAP32[$97+16>>2]=0|0;HEAP32[$97+20>>2]=0|0;HEAP32[$97+24>>2]=0|0;
 $i$01 = 0;
 while(1) {
  $98 = 1 << $i$01;
  $99 = ((($this) + ($i$01<<2)|0) + 384|0);
  HEAP32[$99>>2] = $98;
  $100 = (($i$01) + 1)|0;
  $exitcond = ($100|0)==(32);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $100;
  }
 }
 __ZN5physx14PxsAABBManager11preAllocateEjjj($this,64,64,0);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager11preAllocateEjjj($this,$nbStaticShapes,$nbDynamicShapes,$numAggregates) {
 $this = $this|0;
 $nbStaticShapes = $nbStaticShapes|0;
 $nbDynamicShapes = $nbDynamicShapes|0;
 $numAggregates = $numAggregates|0;
 var $$c$i$i = 0, $$c$i$i16 = 0, $$c1$i$i = 0, $$c1$i$i18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond$i$i19 = 0, $i$02$i$i = 0, $i$02$i$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($nbStaticShapes) + 31)|0;
 $3 = $2 & -32;
 $4 = (($nbDynamicShapes) + 31)|0;
 $5 = $4 & -32;
 $6 = (($5) + ($3))|0;
 $7 = $6 | $numAggregates;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)<($6>>>0);
 if ($11) {
  $12 = (($this) + 8|0);
  __ZN5physx5Elems4growEj($12,$6);
  $13 = (($this) + 48|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14>>>0)<($3>>>0);
  if ($15) {
   $16 = $3 << 3;
   $17 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$16,481512,1503)|0);
   $18 = (($this) + 44|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    $21 = $14 << 3;
    _memcpy(($17|0),($19|0),($21|0))|0;
    $22 = (($17) + ($14<<3)|0);
    $23 = (($3) - ($14))|0;
    $24 = $23 << 3;
    _memset(($22|0),0,($24|0))|0;
   }
   $25 = (($this) + 52|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($3) + -1)|0;
   $28 = (($17) + ($27<<3)|0);
   $$c$i$i16 = $26;
   HEAP32[$28>>2] = $$c$i$i16;
   $29 = ($14>>>0)<($27>>>0);
   if ($29) {
    $i$02$i$i17 = $14;
    while(1) {
     $30 = (($i$02$i$i17) + 1)|0;
     $31 = (($17) + ($i$02$i$i17<<3)|0);
     $$c1$i$i18 = $30;
     HEAP32[$31>>2] = $$c1$i$i18;
     $exitcond$i$i19 = ($30|0)==($27|0);
     if ($exitcond$i$i19) {
      break;
     } else {
      $i$02$i$i17 = $30;
     }
    }
   }
   $32 = HEAP32[$13>>2]|0;
   HEAP32[$25>>2] = $32;
   $33 = HEAP32[$18>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$33);
   HEAP32[$18>>2] = $17;
   HEAP32[$13>>2] = $3;
  }
  $34 = (($this) + 60|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35>>>0)<($5>>>0);
  if ($36) {
   $37 = $5 << 4;
   $38 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$37,481512,1503)|0);
   $39 = (($this) + 56|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if (!($41)) {
    $42 = $35 << 4;
    _memcpy(($38|0),($40|0),($42|0))|0;
    $43 = (($38) + ($35<<4)|0);
    $44 = (($5) - ($35))|0;
    $45 = $44 << 4;
    _memset(($43|0),0,($45|0))|0;
   }
   $46 = (($this) + 64|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($5) + -1)|0;
   $49 = (($38) + ($48<<4)|0);
   $$c$i$i = $47;
   HEAP32[$49>>2] = $$c$i$i;
   $50 = ($35>>>0)<($48>>>0);
   if ($50) {
    $i$02$i$i = $35;
    while(1) {
     $51 = (($i$02$i$i) + 1)|0;
     $52 = (($38) + ($i$02$i$i<<4)|0);
     $$c1$i$i = $51;
     HEAP32[$52>>2] = $$c1$i$i;
     $exitcond$i$i = ($51|0)==($48|0);
     if ($exitcond$i$i) {
      break;
     } else {
      $i$02$i$i = $51;
     }
    }
   }
   $53 = HEAP32[$34>>2]|0;
   HEAP32[$46>>2] = $53;
   $54 = HEAP32[$39>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$54);
   HEAP32[$39>>2] = $38;
   HEAP32[$34>>2] = $5;
  }
  $55 = (($this) + 92|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56>>>0)<($6>>>0);
  $58 = $57 ? $6 : $56;
  HEAP32[$55>>2] = $58;
  $59 = (($this) + 88|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($58>>>0)>($60>>>0);
  if ($61) {
   $62 = (($58) + 31)|0;
   $63 = $62 & -32;
   $64 = (($this) + 80|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = $63 << 2;
   $67 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$66,481512,76)|0);
   $68 = ($65|0)==(0|0);
   if (!($68)) {
    $69 = $60 << 2;
    _memcpy(($67|0),($65|0),($69|0))|0;
   }
   $70 = (($67) + ($60<<2)|0);
   $71 = (($63) - ($60))|0;
   $72 = $71 << 2;
   _memset(($70|0),0,($72|0))|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$65);
   HEAP32[$64>>2] = $67;
   HEAP32[$59>>2] = $63;
  }
  $73 = (($this) + 120|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74>>>0)<($6>>>0);
  $76 = $75 ? $6 : $74;
  HEAP32[$73>>2] = $76;
  $77 = (($this) + 116|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($76>>>0)>($78>>>0);
  if ($79) {
   $80 = (($76) + 31)|0;
   $81 = $80 & -32;
   $82 = (($this) + 108|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = $81 << 2;
   $85 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$84,481512,76)|0);
   $86 = ($83|0)==(0|0);
   if (!($86)) {
    $87 = $78 << 2;
    _memcpy(($85|0),($83|0),($87|0))|0;
   }
   $88 = (($85) + ($78<<2)|0);
   $89 = (($81) - ($78))|0;
   $90 = $89 << 2;
   _memset(($88|0),0,($90|0))|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$83);
   HEAP32[$82>>2] = $85;
   HEAP32[$77>>2] = $81;
  }
  $91 = (($this) + 148|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92>>>0)<($6>>>0);
  $94 = $93 ? $6 : $92;
  HEAP32[$91>>2] = $94;
  $95 = (($this) + 144|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ($94>>>0)>($96>>>0);
  if ($97) {
   $98 = (($94) + 31)|0;
   $99 = $98 & -32;
   $100 = (($this) + 136|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = $99 << 2;
   $103 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$102,481512,76)|0);
   $104 = ($101|0)==(0|0);
   if (!($104)) {
    $105 = $96 << 2;
    _memcpy(($103|0),($101|0),($105|0))|0;
   }
   $106 = (($103) + ($96<<2)|0);
   $107 = (($99) - ($96))|0;
   $108 = $107 << 2;
   _memset(($106|0),0,($108|0))|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$101);
   HEAP32[$100>>2] = $103;
   HEAP32[$95>>2] = $99;
  }
  $109 = $6 >>> 5;
  $110 = (($109) + 3)|0;
  $111 = $110 & 268435452;
  $112 = (($this) + 72|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = $113 & 2147483647;
  $115 = ($111>>>0)>($114>>>0);
  if ($115) {
   $116 = (($this) + 68|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = $111 << 2;
   $119 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$118,481512,76)|0);
   $120 = ($117|0)==(0|0);
   if (!($120)) {
    $121 = $113 << 2;
    _memcpy(($119|0),($117|0),($121|0))|0;
   }
   $122 = (($119) + ($114<<2)|0);
   $123 = (($111) - ($113))|0;
   $124 = $123 << 2;
   _memset(($122|0),0,($124|0))|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$117);
   HEAP32[$116>>2] = $119;
   $125 = $111 | -2147483648;
   HEAP32[$112>>2] = $125;
  }
  $126 = (($this) + 100|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = $127 & 2147483647;
  $129 = ($111>>>0)>($128>>>0);
  if ($129) {
   $130 = (($this) + 96|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = $111 << 2;
   $133 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$132,481512,76)|0);
   $134 = ($131|0)==(0|0);
   if (!($134)) {
    $135 = $127 << 2;
    _memcpy(($133|0),($131|0),($135|0))|0;
   }
   $136 = (($133) + ($128<<2)|0);
   $137 = (($111) - ($127))|0;
   $138 = $137 << 2;
   _memset(($136|0),0,($138|0))|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$131);
   HEAP32[$130>>2] = $133;
   $139 = $111 | -2147483648;
   HEAP32[$126>>2] = $139;
  }
  $140 = (($this) + 128|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = $141 & 2147483647;
  $143 = ($111>>>0)>($142>>>0);
  if ($143) {
   $144 = (($this) + 124|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = $111 << 2;
   $147 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$146,481512,76)|0);
   $148 = ($145|0)==(0|0);
   if (!($148)) {
    $149 = $141 << 2;
    _memcpy(($147|0),($145|0),($149|0))|0;
   }
   $150 = (($147) + ($142<<2)|0);
   $151 = (($111) - ($141))|0;
   $152 = $151 << 2;
   _memset(($150|0),0,($152|0))|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$145);
   HEAP32[$144>>2] = $147;
   $153 = $111 | -2147483648;
   HEAP32[$140>>2] = $153;
  }
 }
 $154 = (($this) + 324|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = ($155>>>0)<($6>>>0);
 if ($156) {
  $157 = (($this) + 296|0);
  $158 = (($this) + 328|0);
  HEAP32[$158>>2] = 1073741823;
  __ZN5physx5Elems4growEj($157,$6);
 }
 $159 = (($this) + 164|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = ($160>>>0)<($6>>>0);
 if ($161) {
  $162 = (($this) + 152|0);
  __ZN5physx13SingleManager6resizeEj($162,$6);
 }
 $163 = (($this) + 196|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ($164>>>0)<($numAggregates>>>0);
 if (!($165)) {
  STACKTOP = sp;return;
 }
 $166 = (($this) + 176|0);
 $167 = (($numAggregates) + 3)|0;
 $168 = $167 & -4;
 __ZN5physx16AggregateManager6resizeEj($166,$168);
 $169 = (($168) + 31)|0;
 $170 = $169 >>> 5;
 $171 = (($170) + 3)|0;
 $172 = $171 & 268435452;
 $173 = (($this) + 360|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = $174 & 2147483647;
 $176 = ($172>>>0)>($175>>>0);
 if (!($176)) {
  STACKTOP = sp;return;
 }
 $177 = (($this) + 356|0);
 $178 = HEAP32[$177>>2]|0;
 $179 = $172 << 2;
 $180 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$179,481512,76)|0);
 $181 = ($178|0)==(0|0);
 if (!($181)) {
  $182 = $174 << 2;
  _memcpy(($180|0),($178|0),($182|0))|0;
 }
 $183 = (($180) + ($175<<2)|0);
 $184 = (($172) - ($174))|0;
 $185 = $184 << 2;
 _memset(($183|0),0,($185|0))|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$178);
 HEAP32[$177>>2] = $180;
 $186 = $172 | -2147483648;
 HEAP32[$173>>2] = $186;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManagerD2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$07 = 0, $or$cond$i$i = 0;
 var $or$cond$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = (($this) + 49860|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 $$pre11 = (($this) + 49856|0);
 if (!($7)) {
  $155 = $6;$i$07 = 0;
  while(1) {
   $8 = HEAP32[$$pre11>>2]|0;
   $9 = ((($8) + (($i$07*12)|0)|0) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $22 = $155;
   } else {
    $12 = HEAP32[$10>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     $14 = (($10) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)>(-1);
     if ($16) {
      $17 = (($10) + 8|0);
      __ZN5physx6shdfnd9Allocator10deallocateEPv($17,$12);
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$10);
    $18 = HEAP32[$$pre11>>2]|0;
    $19 = ((($18) + (($i$07*12)|0)|0) + 8|0);
    HEAP32[$19>>2] = 0;
    $$pre = HEAP32[$5>>2]|0;
    $22 = $$pre;
   }
   $20 = (($i$07) + 1)|0;
   $21 = ($20>>>0)<($22>>>0);
   if ($21) {
    $155 = $22;$i$07 = $20;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 49832|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$24);
 $25 = (($this) + 49844|0);
 $26 = HEAP32[$25>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$26);
 $27 = HEAP32[$$pre11>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$27);
 $28 = (($this) + 512|0);
 __ZN5physx12InlineBufferIjLj4096EE4freeEv($28);
 $29 = (($this) + 16928|0);
 __ZN5physx12InlineBufferIjLj4096EE4freeEv($29);
 $30 = (($this) + 41584|0);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($30);
 $31 = (($this) + 45712|0);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($31);
 $32 = (($this) + 51620|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 & 2147483647;
 $35 = ($34|0)!=(0);
 $36 = ($33|0)>(-1);
 $or$cond$i$i = $35 & $36;
 if ($or$cond$i$i) {
  $37 = (($this) + 51612|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   $40 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   FUNCTION_TABLE_vii[$43 & 4095]($40,$38);
  }
 }
 $44 = (($this) + 51608|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45 & 2147483647;
 $47 = ($46|0)!=(0);
 $48 = ($45|0)>(-1);
 $or$cond$i$i1 = $47 & $48;
 if ($or$cond$i$i1) {
  $49 = (($this) + 51600|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==(0|0);
  if (!($51)) {
   $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vii[$55 & 4095]($52,$50);
  }
 }
 $56 = (($this) + 51556|0);
 HEAP32[$56>>2] = ((434896 + 8|0));
 $57 = (($this) + 51564|0);
 HEAP32[$57>>2] = 0;
 $58 = (($this) + 51100|0);
 __ZN5physx14SingleAABBTaskD2Ev($58);
 $59 = (($this) + 51056|0);
 HEAP32[$59>>2] = ((434896 + 8|0));
 $60 = (($this) + 51064|0);
 HEAP32[$60>>2] = 0;
 $61 = (($this) + 51012|0);
 HEAP32[$61>>2] = ((434896 + 8|0));
 $62 = (($this) + 51020|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 50608|0);
 __ZN5physx17AggregateAABBTaskD2Ev($63);
 $64 = (($this) + 50324|0);
 __ZN5physx13ActorAABBTaskD2Ev($64);
 $65 = (($this) + 49868|0);
 __ZN5physx14SingleAABBTaskD2Ev($65);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($31);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($30);
 $66 = (($this) + 37456|0);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($66);
 $67 = (($this) + 33344|0);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($67);
 __ZN5physx12InlineBufferIjLj4096EE4freeEv($29);
 __ZN5physx12InlineBufferIjLj4096EE4freeEv($28);
 $68 = (($this) + 356|0);
 $69 = HEAP32[$68>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$69);
 $70 = (($this) + 368|0);
 $71 = HEAP32[$70>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$71);
 $72 = HEAP32[$68>>2]|0;
 $73 = ($72|0)==(0|0);
 if (!($73)) {
  $74 = (($this) + 360|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)>(-1);
  if ($76) {
   $77 = (($this) + 364|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($77,$72);
  }
 }
 $78 = (($this) + 296|0);
 $79 = HEAP32[$78>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$79);
 $80 = (($this) + 344|0);
 $81 = HEAP32[$80>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$81);
 $82 = (($this) + 332|0);
 $83 = HEAP32[$82>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$83);
 $84 = (($this) + 244|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($85|0)==(0|0);
 if (!($86)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$85);
 }
 $87 = (($this) + 280|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0|0);
 if (!($89)) {
  $90 = (($this) + 284|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($91|0)>(-1);
  if ($92) {
   $93 = (($this) + 288|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($93,$88);
  }
 }
 $94 = (($this) + 268|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 if (!($96)) {
  $97 = (($this) + 272|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ($98|0)>(-1);
  if ($99) {
   $100 = (($this) + 276|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($100,$95);
  }
 }
 $101 = (($this) + 176|0);
 $102 = HEAP32[$101>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$102);
 $103 = (($this) + 232|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = ($104|0)==(0|0);
 if (!($105)) {
  $106 = (($this) + 236|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ($107|0)>(-1);
  if ($108) {
   $109 = (($this) + 240|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($109,$104);
  }
 }
 $110 = (($this) + 220|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = ($111|0)==(0|0);
 if (!($112)) {
  $113 = (($this) + 224|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = ($114|0)>(-1);
  if ($115) {
   $116 = (($this) + 228|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($116,$111);
  }
 }
 $117 = (($this) + 152|0);
 $118 = HEAP32[$117>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$118);
 $119 = (($this) + 124|0);
 $120 = HEAP32[$119>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$120);
 $121 = (($this) + 136|0);
 $122 = HEAP32[$121>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$122);
 $123 = HEAP32[$119>>2]|0;
 $124 = ($123|0)==(0|0);
 if (!($124)) {
  $125 = (($this) + 128|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ($126|0)>(-1);
  if ($127) {
   $128 = (($this) + 132|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($128,$123);
  }
 }
 $129 = (($this) + 96|0);
 $130 = HEAP32[$129>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$130);
 $131 = (($this) + 108|0);
 $132 = HEAP32[$131>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$132);
 $133 = HEAP32[$129>>2]|0;
 $134 = ($133|0)==(0|0);
 if (!($134)) {
  $135 = (($this) + 100|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = ($136|0)>(-1);
  if ($137) {
   $138 = (($this) + 104|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($138,$133);
  }
 }
 $139 = (($this) + 68|0);
 $140 = HEAP32[$139>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$140);
 $141 = (($this) + 80|0);
 $142 = HEAP32[$141>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$142);
 $143 = HEAP32[$139>>2]|0;
 $144 = ($143|0)==(0|0);
 if ($144) {
  $149 = (($this) + 8|0);
  $150 = HEAP32[$149>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$150);
  $151 = (($this) + 56|0);
  $152 = HEAP32[$151>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$152);
  $153 = (($this) + 44|0);
  $154 = HEAP32[$153>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$154);
  STACKTOP = sp;return;
 }
 $145 = (($this) + 72|0);
 $146 = HEAP32[$145>>2]|0;
 $147 = ($146|0)>(-1);
 if (!($147)) {
  $149 = (($this) + 8|0);
  $150 = HEAP32[$149>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$150);
  $151 = (($this) + 56|0);
  $152 = HEAP32[$151>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$152);
  $153 = (($this) + 44|0);
  $154 = HEAP32[$153>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$154);
  STACKTOP = sp;return;
 }
 $148 = (($this) + 76|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($148,$143);
 $149 = (($this) + 8|0);
 $150 = HEAP32[$149>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$150);
 $151 = (($this) + 56|0);
 $152 = HEAP32[$151>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$152);
 $153 = (($this) + 44|0);
 $154 = HEAP32[$153>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$154);
 STACKTOP = sp;return;
}
function __ZN5physx12InlineBufferIjLj4096EE4freeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$in$i = 0, $it$02$i$i = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 16388|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = ($3|0)==($this|0);
 $or$cond = $4 | $5;
 do {
  if (!($or$cond)) {
   $6 = (($this) + 16384|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$3);
    break;
   }
   $9 = (($7) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10>>>0)>($3>>>0);
   if (!($11)) {
    $12 = (($7) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($10) + ($13)|0);
    $15 = ($14>>>0)>($3>>>0);
    if ($15) {
     $16 = HEAP32[$7>>2]|0;
     __ZN5physx6shdfnd9MutexImpl4lockEv($16);
     $17 = (($7) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($7) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $i$0$in$i = $18;
     while(1) {
      $i$0$i = (($i$0$in$i) + -1)|0;
      $21 = (($20) + ($i$0$i<<2)|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22>>>0)<($3>>>0);
      if ($23) {
       $i$0$in$i = $i$0$i;
      } else {
       break;
      }
     }
     $24 = ($i$0$in$i>>>0)<($18>>>0);
     if ($24) {
      $28 = $i$0$in$i;$it$02$i$i = $21;
      while(1) {
       $25 = ($it$02$i$i|0)==(0|0);
       if (!($25)) {
        $26 = HEAP32[$19>>2]|0;
        $27 = (($26) + ($28<<2)|0);
        $29 = HEAP32[$27>>2]|0;
        HEAP32[$it$02$i$i>>2] = $29;
       }
       $30 = (($it$02$i$i) + 4|0);
       $31 = (($28) + 1)|0;
       $exitcond$i = ($31|0)==($18|0);
       if ($exitcond$i) {
        break;
       } else {
        $28 = $31;$it$02$i$i = $30;
       }
      }
     }
     $32 = (($18) + -1)|0;
     HEAP32[$17>>2] = $32;
     $33 = HEAP32[$7>>2]|0;
     __ZN5physx6shdfnd9MutexImpl6unlockEv($33);
     break;
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
  }
 } while(0);
 HEAP32[$2>>2] = 0;
 $34 = (($this) + 16392|0);
 HEAP32[$34>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx12InlineBufferIjLj1024EE4freeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$in$i = 0, $it$02$i$i = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 4100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = ($3|0)==($this|0);
 $or$cond = $4 | $5;
 do {
  if (!($or$cond)) {
   $6 = (($this) + 4096|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$3);
    break;
   }
   $9 = (($7) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10>>>0)>($3>>>0);
   if (!($11)) {
    $12 = (($7) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($10) + ($13)|0);
    $15 = ($14>>>0)>($3>>>0);
    if ($15) {
     $16 = HEAP32[$7>>2]|0;
     __ZN5physx6shdfnd9MutexImpl4lockEv($16);
     $17 = (($7) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($7) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $i$0$in$i = $18;
     while(1) {
      $i$0$i = (($i$0$in$i) + -1)|0;
      $21 = (($20) + ($i$0$i<<2)|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22>>>0)<($3>>>0);
      if ($23) {
       $i$0$in$i = $i$0$i;
      } else {
       break;
      }
     }
     $24 = ($i$0$in$i>>>0)<($18>>>0);
     if ($24) {
      $28 = $i$0$in$i;$it$02$i$i = $21;
      while(1) {
       $25 = ($it$02$i$i|0)==(0|0);
       if (!($25)) {
        $26 = HEAP32[$19>>2]|0;
        $27 = (($26) + ($28<<2)|0);
        $29 = HEAP32[$27>>2]|0;
        HEAP32[$it$02$i$i>>2] = $29;
       }
       $30 = (($it$02$i$i) + 4|0);
       $31 = (($28) + 1)|0;
       $exitcond$i = ($31|0)==($18|0);
       if ($exitcond$i) {
        break;
       } else {
        $28 = $31;$it$02$i$i = $30;
       }
      }
     }
     $32 = (($18) + -1)|0;
     HEAP32[$17>>2] = $32;
     $33 = HEAP32[$7>>2]|0;
     __ZN5physx6shdfnd9MutexImpl6unlockEv($33);
     break;
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
  }
 } while(0);
 HEAP32[$2>>2] = 0;
 $34 = (($this) + 4104|0);
 HEAP32[$34>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx20AggregateOverlapTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx20ProcessBPResultsTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx10BPWorkTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager4initEPNS_13PxvBroadPhaseE($this,$bp) {
 $this = $this|0;
 $bp = $bp|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 49828|0);
 HEAP32[$0>>2] = $bp;
 STACKTOP = sp;return;
}
function __ZN5physx13SingleManager6resizeEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $newCapacity << 3;
 $5 = (($4) + 30)|0;
 $6 = $5 & -32;
 $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$6,481512,1105)|0);
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = $3 << 2;
  _memcpy(($7|0),($9|0),($11|0))|0;
 }
 $12 = (($7) + ($3<<2)|0);
 $13 = (($newCapacity) - ($3))|0;
 $14 = $13 << 2;
 _memset(($12|0),0,($14|0))|0;
 $15 = $newCapacity << 2;
 $16 = (($15) + 15)|0;
 $17 = $16 & -16;
 $18 = (($7) + ($17)|0);
 HEAP32[$8>>2] = $7;
 $19 = ($3>>>0)<($newCapacity>>>0);
 if ($19) {
  $i$01 = $3;
  while(1) {
   $20 = (($7) + ($i$01<<2)|0);
   HEAP32[$20>>2] = 1073741823;
   $21 = (($i$01) + 1)|0;
   $exitcond = ($21|0)==($newCapacity|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $21;
   }
  }
 }
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = $3 << 2;
  _memcpy(($18|0),($23|0),($25|0))|0;
 }
 $26 = (($18) + ($3<<2)|0);
 _memset(($26|0),0,($14|0))|0;
 HEAP32[$22>>2] = $18;
 HEAP32[$2>>2] = $newCapacity;
 $27 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$27);
 $28 = HEAP32[$8>>2]|0;
 HEAP32[$this>>2] = $28;
 STACKTOP = sp;return;
}
function __ZN5physx16AggregateManager6resizeEj($this,$newAggregatesCapacity) {
 $this = $this|0;
 $newAggregatesCapacity = $newAggregatesCapacity|0;
 var $$pre = 0, $$sum = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $exitcond = 0, $factor = 0;
 var $factor10 = 0, $factor9 = 0, $i$011 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($newAggregatesCapacity) + 31)|0;
 $5 = $4 >>> 5;
 $6 = ($newAggregatesCapacity*1048)|0;
 $7 = (($6) + 15)|0;
 $8 = $7 & -16;
 $9 = $newAggregatesCapacity << 2;
 $10 = (($9) + 15)|0;
 $11 = $10 & -16;
 $12 = $newAggregatesCapacity << 4;
 $13 = $5 << 3;
 $14 = (($13) + 30)|0;
 $factor = $14 & 2147483616;
 $factor9 = $11 << 1;
 $factor10 = $newAggregatesCapacity << 5;
 $15 = (($factor) + ($8))|0;
 $16 = (($15) + ($factor9))|0;
 $17 = (($16) + ($factor10))|0;
 $18 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$17,481512,474)|0);
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = ($3*1048)|0;
  _memcpy(($18|0),($20|0),($22|0))|0;
 }
 $23 = (($18) + (($3*1048)|0)|0);
 $24 = (($newAggregatesCapacity) - ($3))|0;
 $25 = ($24*1048)|0;
 _memset(($23|0),0,($25|0))|0;
 $26 = (($18) + ($8)|0);
 HEAP32[$19>>2] = $18;
 $27 = ($3>>>0)<($newAggregatesCapacity>>>0);
 L4: do {
  if ($27) {
   $29 = $18;$i$011 = $3;
   while(1) {
    $28 = (($29) + (($i$011*1048)|0)|0);
    _memset(($28|0),0,1024)|0;
    $30 = ((($29) + (($i$011*1048)|0)|0) + 1024|0);
    HEAP8[$30>>0] = 1;
    $31 = ((($29) + (($i$011*1048)|0)|0) + 1025|0);
    HEAP8[$31>>0] = 0;
    $32 = ((($29) + (($i$011*1048)|0)|0) + 1026|0);
    HEAP8[$32>>0] = 0;
    $33 = ((($29) + (($i$011*1048)|0)|0) + 1028|0);
    HEAP32[$33>>2] = 1073741823;
    $34 = ((($29) + (($i$011*1048)|0)|0) + 1032|0);
    HEAP32[$34>>2] = 1073741823;
    $35 = ((($29) + (($i$011*1048)|0)|0) + 1036|0);
    HEAP32[$35>>2] = 1073741823;
    $36 = ((($29) + (($i$011*1048)|0)|0) + 1040|0);
    HEAP32[$36>>2] = 1073741823;
    $37 = ((($29) + (($i$011*1048)|0)|0) + 1044|0);
    HEAP32[$37>>2] = 0;
    $38 = (($i$011) + 1)|0;
    $exitcond = ($38|0)==($newAggregatesCapacity|0);
    if ($exitcond) {
     break L4;
    }
    $$pre = HEAP32[$19>>2]|0;
    $29 = $$pre;$i$011 = $38;
   }
  }
 } while(0);
 $39 = (($this) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if (!($41)) {
  $42 = $3 << 2;
  _memcpy(($26|0),($40|0),($42|0))|0;
 }
 $43 = (($26) + ($3<<2)|0);
 $44 = $24 << 2;
 _memset(($43|0),0,($44|0))|0;
 $$sum = (($8) + ($11))|0;
 $45 = (($18) + ($$sum)|0);
 HEAP32[$39>>2] = $26;
 $46 = (($this) + 36|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = $3 << 2;
  _memcpy(($45|0),($47|0),($49|0))|0;
 }
 $50 = (($45) + ($3<<2)|0);
 _memset(($50|0),0,($44|0))|0;
 $$sum5 = (($$sum) + ($11))|0;
 $51 = (($18) + ($$sum5)|0);
 HEAP32[$46>>2] = $45;
 $52 = (($this) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if (!($54)) {
  $55 = $3 << 4;
  _memcpy(($51|0),($53|0),($55|0))|0;
 }
 $56 = (($51) + ($3<<4)|0);
 $57 = $24 << 4;
 _memset(($56|0),0,($57|0))|0;
 $$sum6 = (($$sum5) + ($12))|0;
 $58 = (($18) + ($$sum6)|0);
 HEAP32[$52>>2] = $51;
 $59 = (($this) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0|0);
 if (!($61)) {
  $62 = $3 << 4;
  _memcpy(($58|0),($60|0),($62|0))|0;
 }
 $63 = (($58) + ($3<<4)|0);
 _memset(($63|0),0,($57|0))|0;
 $$sum7 = (($$sum6) + ($12))|0;
 $64 = (($18) + ($$sum7)|0);
 HEAP32[$59>>2] = $58;
 $65 = (($this) + 48|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 & 2147483647;
 $68 = (($this) + 44|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0|0);
 if (!($70)) {
  $71 = $66 << 2;
  _memcpy(($64|0),($69|0),($71|0))|0;
 }
 $72 = (($64) + ($67<<2)|0);
 $73 = (($5) - ($66))|0;
 $74 = $73 << 2;
 _memset(($72|0),0,($74|0))|0;
 $75 = $5 << 2;
 $76 = (($75) + 15)|0;
 $77 = $76 & 1073741808;
 $$sum8 = (($$sum7) + ($77))|0;
 $78 = (($18) + ($$sum8)|0);
 HEAP32[$68>>2] = $64;
 $79 = $5 | -2147483648;
 HEAP32[$65>>2] = $79;
 $80 = (($this) + 60|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = $81 & 2147483647;
 $83 = (($this) + 56|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(0|0);
 if ($85) {
  $87 = (($78) + ($82<<2)|0);
  $88 = (($5) - ($81))|0;
  $89 = $88 << 2;
  _memset(($87|0),0,($89|0))|0;
  HEAP32[$83>>2] = $78;
  HEAP32[$80>>2] = $79;
  HEAP32[$2>>2] = $newAggregatesCapacity;
  $90 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$90);
  $91 = HEAP32[$19>>2]|0;
  HEAP32[$this>>2] = $91;
  STACKTOP = sp;return;
 }
 $86 = $81 << 2;
 _memcpy(($78|0),($84|0),($86|0))|0;
 $87 = (($78) + ($82<<2)|0);
 $88 = (($5) - ($81))|0;
 $89 = $88 << 2;
 _memset(($87|0),0,($89|0))|0;
 HEAP32[$83>>2] = $78;
 HEAP32[$80>>2] = $79;
 HEAP32[$2>>2] = $newAggregatesCapacity;
 $90 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$90);
 $91 = HEAP32[$19>>2]|0;
 HEAP32[$this>>2] = $91;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager8destroyVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 49828|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($2);
 $6 = ($this|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 __ZN5physx14PxsAABBManagerD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager19freeCreatedOverlapsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 49840|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)>(64);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 49832|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
 $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,512,481296,257)|0);
 HEAP32[$5>>2] = $7;
 HEAP32[$2>>2] = 64;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager21freeDestroyedOverlapsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 49852|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)>(64);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 49844|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
 $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,512,481296,267)|0);
 HEAP32[$5>>2] = $7;
 HEAP32[$2>>2] = 64;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager9visualizeERNS_2Cm12RenderOutputE($this,$out) {
 $this = $this|0;
 $out = $out|0;
 var $$0$i$i = 0, $$0$i$i6 = 0, $$0$i1$i = 0, $$0$i1$i5 = 0, $$0$i2$i = 0, $$0$i2$i4 = 0, $$0$i3$i = 0, $$0$i3$i3 = 0, $$0$i4$i = 0, $$0$i4$i2 = 0, $$0$i5$i = 0, $$0$i5$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $elem$0 = 0, $elem$07 = 0, $elem$08 = 0, $exitcond = 0, $i$09 = 0, $idt = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $idt = sp + 56|0;
 $0 = sp;
 $1 = sp + 28|0;
 HEAPF32[$idt>>2] = Math_fround(0.0);
 $2 = (($idt) + 4|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($idt) + 8|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($idt) + 12|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($idt) + 16|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($idt) + 20|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($idt) + 24|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$idt)|0);
 $8 = (($this) + 196|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 180|0);
 $12 = (($this) + 356|0);
 $13 = (($this) + 12|0);
 $14 = (($0) + 4|0);
 $15 = (($0) + 8|0);
 $16 = (($0) + 12|0);
 $17 = (($0) + 16|0);
 $18 = (($0) + 20|0);
 $19 = (($0) + 24|0);
 $20 = (($this) + 300|0);
 $21 = (($1) + 4|0);
 $22 = (($1) + 8|0);
 $23 = (($1) + 12|0);
 $24 = (($1) + 16|0);
 $25 = (($1) + 20|0);
 $26 = (($1) + 24|0);
 $27 = (($this) + 316|0);
 $i$09 = 0;
 while(1) {
  $28 = HEAP32[$11>>2]|0;
  $29 = ((($28) + (($i$09*1048)|0)|0) + 1025|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if (!($31)) {
   $32 = $i$09 >>> 5;
   $33 = HEAP32[$12>>2]|0;
   $34 = (($33) + ($32<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $i$09 & 31;
   $37 = 1 << $36;
   $38 = $35 & $37;
   $39 = ($38|0)==(0);
   if ($39) {
    (__ZN5physx2Cm12RenderOutputlsEj($out,-16711936)|0);
   } else {
    (__ZN5physx2Cm12RenderOutputlsEj($out,-65536)|0);
   }
   $40 = ((($28) + (($i$09*1048)|0)|0) + 1028|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = HEAP32[$13>>2]|0;
   $43 = (($42) + (($41*24)|0)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ((($42) + (($41*24)|0)|0) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ((($42) + (($41*24)|0)|0) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ((($42) + (($41*24)|0)|0) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ((($42) + (($41*24)|0)|0) + 16|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($42) + (($41*24)|0)|0) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($44|0)<(0);
   $56 = $44 & 2147483647;
   $57 = $44 ^ -1;
   $$0$i5$i1 = $55 ? $56 : $57;
   $58 = ($46|0)<(0);
   $59 = $46 & 2147483647;
   $60 = $46 ^ -1;
   $$0$i4$i2 = $58 ? $59 : $60;
   $61 = ($48|0)<(0);
   $62 = $48 & 2147483647;
   $63 = $48 ^ -1;
   $$0$i3$i3 = $61 ? $62 : $63;
   $64 = ($50|0)<(0);
   $65 = $50 & 2147483647;
   $66 = $50 ^ -1;
   $$0$i2$i4 = $64 ? $65 : $66;
   $67 = ($52|0)<(0);
   $68 = $52 & 2147483647;
   $69 = $52 ^ -1;
   $$0$i1$i5 = $67 ? $68 : $69;
   $70 = ($54|0)<(0);
   $71 = $54 & 2147483647;
   $72 = $54 ^ -1;
   $$0$i$i6 = $70 ? $71 : $72;
   $73 = (HEAP32[tempDoublePtr>>2]=$$0$i5$i1,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$0>>2] = $73;
   $74 = (HEAP32[tempDoublePtr>>2]=$$0$i4$i2,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$14>>2] = $74;
   $75 = (HEAP32[tempDoublePtr>>2]=$$0$i3$i3,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$15>>2] = $75;
   $76 = (HEAP32[tempDoublePtr>>2]=$$0$i2$i4,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$16>>2] = $76;
   $77 = (HEAP32[tempDoublePtr>>2]=$$0$i1$i5,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$17>>2] = $77;
   $78 = (HEAP32[tempDoublePtr>>2]=$$0$i$i6,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$18>>2] = $78;
   HEAP8[$19>>0] = 1;
   (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$0)|0);
   $79 = ((($28) + (($i$09*1048)|0)|0) + 1032|0);
   $elem$07 = HEAP32[$79>>2]|0;
   $80 = ($elem$07|0)==(1073741823);
   if (!($80)) {
    $elem$08 = $elem$07;
    while(1) {
     (__ZN5physx2Cm12RenderOutputlsEj($out,-16711681)|0);
     $81 = HEAP32[$20>>2]|0;
     $82 = (($81) + (($elem$08*24)|0)|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ((($81) + (($elem$08*24)|0)|0) + 4|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ((($81) + (($elem$08*24)|0)|0) + 8|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = ((($81) + (($elem$08*24)|0)|0) + 12|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = ((($81) + (($elem$08*24)|0)|0) + 16|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ((($81) + (($elem$08*24)|0)|0) + 20|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ($83|0)<(0);
     $95 = $83 & 2147483647;
     $96 = $83 ^ -1;
     $$0$i5$i = $94 ? $95 : $96;
     $97 = ($85|0)<(0);
     $98 = $85 & 2147483647;
     $99 = $85 ^ -1;
     $$0$i4$i = $97 ? $98 : $99;
     $100 = ($87|0)<(0);
     $101 = $87 & 2147483647;
     $102 = $87 ^ -1;
     $$0$i3$i = $100 ? $101 : $102;
     $103 = ($89|0)<(0);
     $104 = $89 & 2147483647;
     $105 = $89 ^ -1;
     $$0$i2$i = $103 ? $104 : $105;
     $106 = ($91|0)<(0);
     $107 = $91 & 2147483647;
     $108 = $91 ^ -1;
     $$0$i1$i = $106 ? $107 : $108;
     $109 = ($93|0)<(0);
     $110 = $93 & 2147483647;
     $111 = $93 ^ -1;
     $$0$i$i = $109 ? $110 : $111;
     $112 = (HEAP32[tempDoublePtr>>2]=$$0$i5$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
     HEAPF32[$1>>2] = $112;
     $113 = (HEAP32[tempDoublePtr>>2]=$$0$i4$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
     HEAPF32[$21>>2] = $113;
     $114 = (HEAP32[tempDoublePtr>>2]=$$0$i3$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
     HEAPF32[$22>>2] = $114;
     $115 = (HEAP32[tempDoublePtr>>2]=$$0$i2$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
     HEAPF32[$23>>2] = $115;
     $116 = (HEAP32[tempDoublePtr>>2]=$$0$i1$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
     HEAPF32[$24>>2] = $116;
     $117 = (HEAP32[tempDoublePtr>>2]=$$0$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
     HEAPF32[$25>>2] = $117;
     HEAP8[$26>>0] = 1;
     (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$1)|0);
     $118 = HEAP32[$27>>2]|0;
     $119 = (($118) + ($elem$08<<2)|0);
     $elem$0 = HEAP32[$119>>2]|0;
     $120 = ($elem$0|0)==(1073741823);
     if ($120) {
      break;
     } else {
      $elem$08 = $elem$0;
     }
    }
   }
  }
  $121 = (($i$09) + 1)|0;
  $exitcond = ($121|0)==($9|0);
  if ($exitcond) {
   break;
  } else {
   $i$09 = $121;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager15createAggregateEPvb($this,$userData,$selfCollisions) {
 $this = $this|0;
 $userData = $userData|0;
 $selfCollisions = $selfCollisions|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 176|0);
 $3 = (($this) + 196|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN5physx16AggregateManager15createAggregateEPvb($2,$userData,$selfCollisions)|0);
 $6 = HEAP32[$3>>2]|0;
 $7 = ($6>>>0)>($4>>>0);
 if (!($7)) {
  $26 = $5 << 1;
  $27 = $26 | 1;
  STACKTOP = sp;return ($27|0);
 }
 $8 = (($6) + 31)|0;
 $9 = $8 >>> 5;
 $10 = (($9) + 3)|0;
 $11 = $10 & 268435452;
 $12 = (($this) + 360|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($11>>>0)>($14>>>0);
 if (!($15)) {
  $26 = $5 << 1;
  $27 = $26 | 1;
  STACKTOP = sp;return ($27|0);
 }
 $16 = (($this) + 356|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $11 << 2;
 $19 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$18,481512,76)|0);
 $20 = ($17|0)==(0|0);
 if (!($20)) {
  $21 = $13 << 2;
  _memcpy(($19|0),($17|0),($21|0))|0;
 }
 $22 = (($19) + ($14<<2)|0);
 $23 = (($11) - ($13))|0;
 $24 = $23 << 2;
 _memset(($22|0),0,($24|0))|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$17);
 HEAP32[$16>>2] = $19;
 $25 = $11 | -2147483648;
 HEAP32[$12>>2] = $25;
 $26 = $5 << 1;
 $27 = $26 | 1;
 STACKTOP = sp;return ($27|0);
}
function __ZN5physx16AggregateManager15createAggregateEPvb($this,$userData,$selfCollisions) {
 $this = $this|0;
 $userData = $userData|0;
 $selfCollisions = $selfCollisions|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $aggregate$0 = 0, $aggregateId$0 = 0, $group$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   $11 = (($this) + 16|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12>>>0)<($14>>>0);
   if ($15) {
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + (($12*1048)|0)|0);
    $19 = (($12) + 1)|0;
    HEAP32[$11>>2] = $19;
    $aggregate$0 = $18;$aggregateId$0 = $12;
    break;
   } else {
    $20 = (($12) + 32)|0;
    __ZN5physx16AggregateManager6resizeEj($this,$20);
    $21 = HEAP32[$11>>2]|0;
    $22 = (($this) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + (($21*1048)|0)|0);
    $25 = (($21) + 1)|0;
    HEAP32[$11>>2] = $25;
    $aggregate$0 = $24;$aggregateId$0 = $21;
    break;
   }
  } else {
   $3 = (($1) + -1)|0;
   $4 = (($this) + 24|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + ($3<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   HEAP32[$0>>2] = $3;
   $8 = (($this) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + (($7*1048)|0)|0);
   $aggregate$0 = $10;$aggregateId$0 = $7;
  }
 } while(0);
 $26 = (($aggregate$0) + 1024|0);
 $27 = $selfCollisions&1;
 HEAP8[$26>>0] = $27;
 $28 = (($aggregate$0) + 1044|0);
 HEAP32[$28>>2] = $userData;
 $29 = $aggregateId$0 & 31;
 $30 = 1 << $29;
 $31 = $30 ^ -1;
 $32 = $aggregateId$0 >>> 5;
 $33 = (($this) + 44|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + ($32<<2)|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & $31;
 HEAP32[$35>>2] = $37;
 $38 = (($this) + 40|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 if ($40) {
  $46 = (($this) + 32|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + -1)|0;
  HEAP32[$46>>2] = $48;
  $group$0$i = $47;
  $49 = (($aggregate$0) + 1036|0);
  HEAP32[$49>>2] = $group$0$i;
  STACKTOP = sp;return ($aggregateId$0|0);
 } else {
  $41 = (($39) + -1)|0;
  $42 = (($this) + 36|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + ($41<<2)|0);
  $45 = HEAP32[$44>>2]|0;
  HEAP32[$38>>2] = $41;
  $group$0$i = $45;
  $49 = (($aggregate$0) + 1036|0);
  HEAP32[$49>>2] = $group$0$i;
  STACKTOP = sp;return ($aggregateId$0|0);
 }
 return 0|0;
}
function __ZN5physx14PxsAABBManager15deleteAggregateEj($this,$encodedAggregateId) {
 $this = $this|0;
 $encodedAggregateId = $encodedAggregateId|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $firstFreeElem$0$lcssa$i = 0, $firstFreeElem$01$i = 0, $firstFreeElem$01$i$phi = 0, $id$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $encodedAggregateId >>> 1;
 $1 = (($this) + 180|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2) + (($0*1048)|0)|0) + 1040|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==(1073741823);
 if ($7) {
  $46 = $2;$firstFreeElem$0$lcssa$i = $6;
 } else {
  $8 = (($this) + 256|0);
  $9 = (($this) + 248|0);
  $10 = (($this) + 252|0);
  $11 = (($this) + 260|0);
  $12 = (($this) + 268|0);
  $13 = (($this) + 280|0);
  $$pre$i = HEAP32[$8>>2]|0;
  $15 = $$pre$i;$firstFreeElem$01$i = $6;$id$02$i = $4;
  while(1) {
   $14 = (($15) + ($id$02$i<<2)|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = HEAP32[$9>>2]|0;
   $18 = (($17) + (($id$02$i*24)|0)|0);
   HEAP32[$18>>2] = $firstFreeElem$01$i;
   $19 = HEAP32[$10>>2]|0;
   $20 = (($19) + ($id$02$i)|0);
   HEAP8[$20>>0] = 0;
   $21 = HEAP32[$8>>2]|0;
   $22 = (($21) + ($id$02$i<<2)|0);
   HEAP32[$22>>2] = 1073741823;
   $23 = HEAP32[$11>>2]|0;
   $24 = (($23) + ($id$02$i<<2)|0);
   HEAP32[$24>>2] = 1073741823;
   $25 = $id$02$i & 31;
   $26 = 1 << $25;
   $27 = $26 ^ -1;
   $28 = $id$02$i >>> 5;
   $29 = HEAP32[$12>>2]|0;
   $30 = (($29) + ($28<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31 & $27;
   HEAP32[$30>>2] = $32;
   $33 = HEAP32[$13>>2]|0;
   $34 = (($33) + ($28<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 & $27;
   HEAP32[$34>>2] = $36;
   $37 = ($16|0)==(1073741823);
   if ($37) {
    break;
   } else {
    $firstFreeElem$01$i$phi = $id$02$i;$15 = $21;$id$02$i = $16;$firstFreeElem$01$i = $firstFreeElem$01$i$phi;
   }
  }
  $$pre = HEAP32[$1>>2]|0;
  $46 = $$pre;$firstFreeElem$0$lcssa$i = $id$02$i;
 }
 HEAP32[$5>>2] = $firstFreeElem$0$lcssa$i;
 $38 = (($this) + 204|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($this) + 200|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + ($39<<2)|0);
 HEAP32[$42>>2] = $0;
 $43 = HEAP32[$38>>2]|0;
 $44 = (($43) + 1)|0;
 HEAP32[$38>>2] = $44;
 $45 = ((($46) + (($0*1048)|0)|0) + 1036|0);
 $47 = HEAP32[$45>>2]|0;
 $48 = (($this) + 216|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 212|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + ($49<<2)|0);
 HEAP32[$52>>2] = $47;
 $53 = HEAP32[$48>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$48>>2] = $54;
 HEAP32[$45>>2] = 1073741823;
 $55 = ((($46) + (($0*1048)|0)|0) + 1040|0);
 HEAP32[$55>>2] = 1073741823;
 $56 = (($this) + 184|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($0<<4)|0);
 ;HEAP32[$58+0>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;HEAP32[$58+12>>2]=0|0;
 $59 = (($this) + 188|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + ($0<<4)|0);
 ;HEAP32[$61+0>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;HEAP32[$61+12>>2]=0|0;
 $62 = $0 & 31;
 $63 = 1 << $62;
 $64 = $63 ^ -1;
 $65 = $encodedAggregateId >>> 6;
 $66 = (($this) + 232|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + ($65<<2)|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = $69 & $64;
 HEAP32[$68>>2] = $70;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager12createVolumeEjjjPvRKNS_9PxBounds3E($agg$result,$this,$encodedAggregateId,$encodedActorHandle,$group,$userdata,$bounds) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $encodedAggregateId = $encodedAggregateId|0;
 $encodedActorHandle = $encodedActorHandle|0;
 $group = $group|0;
 $userdata = $userdata|0;
 $bounds = $bounds|0;
 var $$0$i$i$i = 0, $$0$i$i$i15 = 0, $$0$i$i1$i = 0, $$0$i$i1$i14 = 0, $$0$i$i2$i = 0, $$0$i$i2$i13 = 0, $$0$i$i3$i = 0, $$0$i$i3$i12 = 0, $$0$i$i4$i = 0, $$0$i$i4$i11 = 0, $$0$i$i5$i = 0, $$0$i$i5$i10 = 0, $$pre = 0, $$pre$i = 0, $$pre$i8 = 0, $$pre$phi29Z2D = 0, $$pre$phiZ2D = 0, $$pre28 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $actorHandle$0 = 0, $actorId$0 = 0, $actorId7$0 = 0, $aggregateElemID4$0 = 0, $aggregateElemID4$023 = 0, $aggregateElemID4$025 = 0, $aggregateElemID4$1 = 0, $i$0$i$i = 0, $index$024 = 0, $not$$i = 0, $or$cond = 0, $or$cond16 = 0, $or$cond17 = 0, $or$cond18 = 0, $or$cond19 = 0;
 var $or$cond20 = 0, $or$cond20$not = 0, $or$cond21 = 0, $or$cond22 = 0, $singleId$0$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $vararg_buffer = sp;
 $0 = ($encodedAggregateId|0)==(-1);
 if ($0) {
  $1 = (($bounds) + 12|0);
  $2 = HEAP32[$bounds>>2]|0;
  $3 = ($2|0)<(0);
  $4 = $2 ^ -1;
  $5 = $2 | -2147483648;
  $$0$i$i5$i = $3 ? $4 : $5;
  $6 = (($$0$i$i5$i) + -16)|0;
  $7 = $6 & -16;
  $8 = (($bounds) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)<(0);
  $11 = $9 ^ -1;
  $12 = $9 | -2147483648;
  $$0$i$i4$i = $10 ? $11 : $12;
  $13 = (($$0$i$i4$i) + -16)|0;
  $14 = $13 & -16;
  $15 = (($bounds) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)<(0);
  $18 = $16 ^ -1;
  $19 = $16 | -2147483648;
  $$0$i$i3$i = $17 ? $18 : $19;
  $20 = (($$0$i$i3$i) + -16)|0;
  $21 = $20 & -16;
  $22 = HEAP32[$1>>2]|0;
  $23 = ($22|0)<(0);
  $24 = $22 ^ -1;
  $25 = $22 | -2147483648;
  $$0$i$i2$i = $23 ? $24 : $25;
  $26 = (($$0$i$i2$i) + 16)|0;
  $27 = $26 & -16;
  $28 = $27 | 1;
  $29 = (($1) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)<(0);
  $32 = $30 ^ -1;
  $33 = $30 | -2147483648;
  $$0$i$i1$i = $31 ? $32 : $33;
  $34 = (($$0$i$i1$i) + 16)|0;
  $35 = $34 & -16;
  $36 = $35 | 1;
  $37 = (($1) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)<(0);
  $40 = $38 ^ -1;
  $41 = $38 | -2147483648;
  $$0$i$i$i = $39 ? $40 : $41;
  $42 = (($$0$i$i$i) + 16)|0;
  $43 = $42 & -16;
  $44 = $43 | 1;
  $45 = (__ZN5physx14PxsAABBManager12createBPElemEv($this)|0);
  $46 = $45 & 31;
  $47 = 1 << $46;
  $48 = $45 >>> 5;
  $49 = (($this) + 96|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + ($48<<2)|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 | $47;
  HEAP32[$51>>2] = $53;
  $54 = (($this) + 16|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + ($45<<2)|0);
  HEAP32[$56>>2] = $userdata;
  $57 = (($this) + 20|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + ($45<<2)|0);
  HEAP32[$59>>2] = $group;
  $60 = (($this) + 12|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + (($45*24)|0)|0);
  HEAP32[$62>>2] = $7;
  $63 = ((($61) + (($45*24)|0)|0) + 4|0);
  HEAP32[$63>>2] = $14;
  $64 = ((($61) + (($45*24)|0)|0) + 8|0);
  HEAP32[$64>>2] = $21;
  $65 = ((($61) + (($45*24)|0)|0) + 12|0);
  HEAP32[$65>>2] = $28;
  $66 = ((($61) + (($45*24)|0)|0) + 16|0);
  HEAP32[$66>>2] = $36;
  $67 = ((($61) + (($45*24)|0)|0) + 20|0);
  HEAP32[$67>>2] = $44;
  $68 = ($encodedActorHandle|0)==(1073741823);
  if ($68) {
   $69 = (($this) + 152|0);
   $70 = (($this) + 172|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0);
   do {
    if ($72) {
     $78 = (($this) + 160|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($this) + 164|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = ($79>>>0)<($81>>>0);
     if ($82) {
      $83 = (($79) + 1)|0;
      HEAP32[$78>>2] = $83;
      $singleId$0$i = $79;
      break;
     } else {
      $84 = (($81) + 32)|0;
      __ZN5physx13SingleManager6resizeEj($69,$84);
      $85 = HEAP32[$78>>2]|0;
      $86 = (($85) + 1)|0;
      HEAP32[$78>>2] = $86;
      $singleId$0$i = $85;
      break;
     }
    } else {
     $73 = (($71) + -1)|0;
     $74 = (($this) + 168|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($75) + ($73<<2)|0);
     $77 = HEAP32[$76>>2]|0;
     HEAP32[$70>>2] = $73;
     $singleId$0$i = $77;
    }
   } while(0);
   $87 = (($this) + 156|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = $singleId$0$i << 1;
   $90 = (($this) + 24|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($91) + ($45<<2)|0);
   HEAP32[$92>>2] = $89;
   $93 = (($this) + 28|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + ($45<<2)|0);
   HEAP32[$95>>2] = 1073741823;
   $96 = (($88) + ($singleId$0$i<<2)|0);
   HEAP32[$96>>2] = $45;
   $actorHandle$0 = $singleId$0$i;
  } else {
   $97 = $encodedActorHandle >>> 1;
   $98 = (($this) + 156|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = $97 << 1;
   $101 = (($this) + 24|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($102) + ($45<<2)|0);
   HEAP32[$103>>2] = $100;
   $104 = (($99) + ($97<<2)|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($this) + 28|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($107) + ($45<<2)|0);
   HEAP32[$108>>2] = $105;
   HEAP32[$104>>2] = $45;
   $actorHandle$0 = $97;
  }
  $109 = ($45>>>0)<(536870911);
  $110 = ($actorHandle$0>>>0)<(536870911);
  $or$cond = $109 & $110;
  if ($or$cond) {
   $111 = $45 << 1;
   $112 = $actorHandle$0 << 1;
   HEAP32[$agg$result>>2] = $111;
   $113 = (($agg$result) + 4|0);
   HEAP32[$113>>2] = $112;
   STACKTOP = sp;return;
  } else {
   HEAP32[$agg$result>>2] = 1073741823;
   $114 = (($agg$result) + 4|0);
   HEAP32[$114>>2] = 1073741823;
   STACKTOP = sp;return;
  }
 }
 $115 = $encodedAggregateId >>> 1;
 $116 = (($this) + 180|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = (($117) + (($115*1048)|0)|0);
 $119 = ((($117) + (($115*1048)|0)|0) + 1032|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($120|0)==(1073741823);
 $122 = (($bounds) + 12|0);
 $123 = HEAP32[$bounds>>2]|0;
 $124 = ($123|0)<(0);
 $125 = $123 ^ -1;
 $126 = $123 | -2147483648;
 $$0$i$i5$i10 = $124 ? $125 : $126;
 $127 = (($$0$i$i5$i10) + -16)|0;
 $128 = $127 & -16;
 $129 = (($bounds) + 4|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($130|0)<(0);
 $132 = $130 ^ -1;
 $133 = $130 | -2147483648;
 $$0$i$i4$i11 = $131 ? $132 : $133;
 $134 = (($$0$i$i4$i11) + -16)|0;
 $135 = $134 & -16;
 $136 = (($bounds) + 8|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($137|0)<(0);
 $139 = $137 ^ -1;
 $140 = $137 | -2147483648;
 $$0$i$i3$i12 = $138 ? $139 : $140;
 $141 = (($$0$i$i3$i12) + -16)|0;
 $142 = $141 & -16;
 $143 = HEAP32[$122>>2]|0;
 $144 = ($143|0)<(0);
 $145 = $143 ^ -1;
 $146 = $143 | -2147483648;
 $$0$i$i2$i13 = $144 ? $145 : $146;
 $147 = (($$0$i$i2$i13) + 16)|0;
 $148 = $147 & -16;
 $149 = $148 | 1;
 $150 = (($122) + 4|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = ($151|0)<(0);
 $153 = $151 ^ -1;
 $154 = $151 | -2147483648;
 $$0$i$i1$i14 = $152 ? $153 : $154;
 $155 = (($$0$i$i1$i14) + 16)|0;
 $156 = $155 & -16;
 $157 = $156 | 1;
 $158 = (($122) + 8|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = ($159|0)<(0);
 $161 = $159 ^ -1;
 $162 = $159 | -2147483648;
 $$0$i$i$i15 = $160 ? $161 : $162;
 $163 = (($$0$i$i$i15) + 16)|0;
 $164 = $163 & -16;
 $165 = $164 | 1;
 if ($121) {
  $166 = (__ZN5physx14PxsAABBManager12createBPElemEv($this)|0);
  $167 = ((($117) + (($115*1048)|0)|0) + 1028|0);
  HEAP32[$167>>2] = $166;
  $168 = $encodedAggregateId | 1;
  $169 = (($this) + 24|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = (($170) + ($166<<2)|0);
  HEAP32[$171>>2] = $168;
  $172 = ((($117) + (($115*1048)|0)|0) + 1036|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = (($this) + 20|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = (($175) + ($166<<2)|0);
  HEAP32[$176>>2] = $173;
  $177 = (($this) + 12|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + (($166*24)|0)|0);
  HEAP32[$179>>2] = $128;
  $180 = ((($178) + (($166*24)|0)|0) + 4|0);
  HEAP32[$180>>2] = $135;
  $181 = ((($178) + (($166*24)|0)|0) + 8|0);
  HEAP32[$181>>2] = $142;
  $182 = ((($178) + (($166*24)|0)|0) + 12|0);
  HEAP32[$182>>2] = $149;
  $183 = ((($178) + (($166*24)|0)|0) + 16|0);
  HEAP32[$183>>2] = $157;
  $184 = ((($178) + (($166*24)|0)|0) + 20|0);
  HEAP32[$184>>2] = $165;
  $185 = $166 & 31;
  $186 = 1 << $185;
  $187 = $166 >>> 5;
  $188 = (($this) + 96|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = (($189) + ($187<<2)|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = $191 | $186;
  HEAP32[$190>>2] = $192;
  $193 = (__ZN5physx14PxsAABBManager19createAggregateElemEv($this)|0);
  $194 = (($this) + 304|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = (($195) + ($193<<2)|0);
  HEAP32[$196>>2] = $userdata;
  $197 = (($this) + 308|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = (($198) + ($193<<2)|0);
  HEAP32[$199>>2] = $group;
  $200 = (($this) + 300|0);
  $201 = HEAP32[$200>>2]|0;
  $202 = (($201) + (($193*24)|0)|0);
  HEAP32[$202>>2] = $128;
  $203 = ((($201) + (($193*24)|0)|0) + 4|0);
  HEAP32[$203>>2] = $135;
  $204 = ((($201) + (($193*24)|0)|0) + 8|0);
  HEAP32[$204>>2] = $142;
  $205 = ((($201) + (($193*24)|0)|0) + 12|0);
  HEAP32[$205>>2] = $149;
  $206 = ((($201) + (($193*24)|0)|0) + 16|0);
  HEAP32[$206>>2] = $157;
  $207 = ((($201) + (($193*24)|0)|0) + 20|0);
  HEAP32[$207>>2] = $165;
  $208 = (($this) + 316|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = (($209) + ($193<<2)|0);
  HEAP32[$210>>2] = 1073741823;
  $211 = (($this) + 320|0);
  $212 = HEAP32[$211>>2]|0;
  $213 = (($212) + ($193<<2)|0);
  HEAP32[$213>>2] = 1073741823;
  $214 = $encodedAggregateId >>> 6;
  $215 = (($this) + 356|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = (($216) + ($214<<2)|0);
  $218 = HEAP32[$217>>2]|0;
  $219 = $115 & 31;
  $220 = 1 << $219;
  $221 = $218 & $220;
  $222 = ($221|0)==(0);
  if ($222) {
   $223 = $218 | $220;
   HEAP32[$217>>2] = $223;
  }
  HEAP32[$119>>2] = $193;
  $224 = ((($117) + (($115*1048)|0)|0) + 1025|0);
  $225 = HEAP8[$224>>0]|0;
  $226 = (($225) + 1)<<24>>24;
  HEAP8[$224>>0] = $226;
  $227 = ((($117) + (($115*1048)|0)|0) + 1026|0);
  $228 = HEAP8[$227>>0]|0;
  $229 = (($228) + 1)<<24>>24;
  HEAP8[$227>>0] = $229;
  $230 = ($encodedActorHandle|0)==(1073741823);
  do {
   if ($230) {
    $231 = (($this) + 292|0);
    $232 = HEAP32[$231>>2]|0;
    $233 = ($232|0)==(1073741823);
    if ($233) {
     $234 = (($this) + 244|0);
     $235 = (($this) + 264|0);
     $236 = HEAP32[$235>>2]|0;
     $237 = $236 << 1;
     $238 = ($237>>>0)<(64);
     $239 = $238 ? 64 : $237;
     __ZN5physx21AggregateActorManager6resizeEj($234,$239);
     $$pre$i8 = HEAP32[$231>>2]|0;
     $243 = $$pre$i8;
    } else {
     $243 = $232;
    }
    $240 = (($this) + 248|0);
    $241 = HEAP32[$240>>2]|0;
    $242 = (($241) + (($243*24)|0)|0);
    $244 = HEAP32[$242>>2]|0;
    HEAP32[$231>>2] = $244;
    $245 = (($241) + (($243*24)|0)|0);
    HEAPF32[$245>>2] = Math_fround(8.50705866596322149529E+37);
    $246 = ((($241) + (($243*24)|0)|0) + 4|0);
    HEAPF32[$246>>2] = Math_fround(8.50705866596322149529E+37);
    $247 = ((($241) + (($243*24)|0)|0) + 8|0);
    HEAPF32[$247>>2] = Math_fround(8.50705866596322149529E+37);
    $248 = ((($241) + (($243*24)|0)|0) + 12|0);
    HEAPF32[$248>>2] = Math_fround(-8.50705866596322149529E+37);
    $249 = ((($241) + (($243*24)|0)|0) + 16|0);
    HEAPF32[$249>>2] = Math_fround(-8.50705866596322149529E+37);
    $250 = ((($241) + (($243*24)|0)|0) + 20|0);
    HEAPF32[$250>>2] = Math_fround(-8.50705866596322149529E+37);
    $251 = (($this) + 252|0);
    $252 = HEAP32[$251>>2]|0;
    $253 = (($252) + ($243)|0);
    HEAP8[$253>>0] = 0;
    $254 = (($this) + 260|0);
    $255 = HEAP32[$254>>2]|0;
    $256 = (($255) + ($243<<2)|0);
    HEAP32[$256>>2] = $115;
    $257 = ((($117) + (($115*1048)|0)|0) + 1040|0);
    $258 = HEAP32[$257>>2]|0;
    $259 = ($258|0)==(1073741823);
    $260 = (($this) + 256|0);
    $261 = HEAP32[$260>>2]|0;
    $262 = (($261) + ($243<<2)|0);
    if ($259) {
     HEAP32[$262>>2] = 1073741823;
     HEAP32[$257>>2] = $243;
     $$pre$phiZ2D = $251;$actorId$0 = $243;
     break;
    } else {
     HEAP32[$262>>2] = $258;
     HEAP32[$257>>2] = $243;
     $$pre$phiZ2D = $251;$actorId$0 = $243;
     break;
    }
   } else {
    $263 = $encodedActorHandle >>> 1;
    $$pre = (($this) + 252|0);
    $$pre$phiZ2D = $$pre;$actorId$0 = $263;
   }
  } while(0);
  $264 = $actorId$0 << 1;
  $265 = $264 | 1;
  $266 = (($this) + 312|0);
  $267 = HEAP32[$266>>2]|0;
  $268 = (($267) + ($193<<2)|0);
  HEAP32[$268>>2] = $265;
  $269 = HEAP32[$$pre$phiZ2D>>2]|0;
  $270 = (($269) + ($actorId$0)|0);
  $271 = HEAP8[$270>>0]|0;
  $272 = (($271) + 1)<<24>>24;
  HEAP8[$270>>0] = $272;
  $273 = $actorId$0 & 31;
  $274 = 1 << $273;
  $275 = $274 ^ -1;
  $276 = $actorId$0 >>> 5;
  $277 = (($this) + 280|0);
  $278 = HEAP32[$277>>2]|0;
  $279 = (($278) + ($276<<2)|0);
  $280 = HEAP32[$279>>2]|0;
  $281 = $280 & $275;
  HEAP32[$279>>2] = $281;
  $282 = ((($117) + (($115*1048)|0)|0) + 1024|0);
  $283 = HEAP8[$282>>0]|0;
  $284 = ($283<<24>>24)==(0);
  if ($284) {
   $285 = (($this) + 268|0);
   $286 = HEAP32[$285>>2]|0;
   $287 = (($286) + ($276<<2)|0);
   $288 = HEAP32[$287>>2]|0;
   $289 = $288 | $274;
   HEAP32[$287>>2] = $289;
  }
  $290 = ($encodedAggregateId>>>0)<(1073741822);
  $291 = ($actorId$0>>>0)<(536870911);
  $or$cond16 = $290 & $291;
  if ($or$cond16) {
   $292 = $193 << 1;
   $293 = $292 | 1;
   HEAP32[$agg$result>>2] = $293;
   $294 = (($agg$result) + 4|0);
   HEAP32[$294>>2] = $265;
   STACKTOP = sp;return;
  } else {
   HEAP32[$agg$result>>2] = 1073741823;
   $295 = (($agg$result) + 4|0);
   HEAP32[$295>>2] = 1073741823;
   STACKTOP = sp;return;
  }
 }
 $296 = (($this) + 188|0);
 $297 = HEAP32[$296>>2]|0;
 $i$0$i$i = 4;
 while(1) {
  $298 = (($i$0$i$i) + -1)|0;
  $299 = ($i$0$i$i|0)==(0);
  if ($299) {
   label = 38;
   break;
  }
  $300 = ((($297) + ($115<<4)|0) + ($298<<2)|0);
  $301 = HEAP32[$300>>2]|0;
  $302 = ($301|0)==(0);
  if ($302) {
   $i$0$i$i = $298;
  } else {
   label = 31;
   break;
  }
 }
 if ((label|0) == 31) {
  $303 = $298 << 5;
  $304 = $301 >>> 1;
  $305 = $304 | $301;
  $306 = $305 >>> 2;
  $307 = $306 | $305;
  $308 = $307 >>> 4;
  $309 = $308 | $307;
  $310 = $309 >>> 8;
  $311 = $310 | $309;
  $312 = $311 >>> 16;
  $313 = $312 | $311;
  $314 = Math_imul($313, 130329821)|0;
  $315 = $314 >>> 27;
  $316 = (482344 + ($315<<2)|0);
  $317 = HEAP32[$316>>2]|0;
  $318 = (($317) + ($303))|0;
  $319 = ($318|0)==(0);
  if ($319) {
   label = 38;
  } else {
   $320 = $318 & 31;
   $321 = 1 << $320;
   $322 = $321 ^ -1;
   $323 = $318 >>> 5;
   $324 = ((($297) + ($115<<4)|0) + ($323<<2)|0);
   $325 = HEAP32[$324>>2]|0;
   $326 = $325 & $322;
   HEAP32[$324>>2] = $326;
   $327 = ($318|0)==(1073741823);
   if ($327) {
    label = 38;
   } else {
    $aggregateElemID4$023 = HEAP32[$119>>2]|0;
    $328 = ($aggregateElemID4$023|0)==(1073741823);
    if (!($328)) {
     $329 = (($this) + 316|0);
     $330 = HEAP32[$329>>2]|0;
     $aggregateElemID4$025 = $aggregateElemID4$023;$index$024 = 0;
     while(1) {
      $331 = (($vararg_buffer) + ($index$024<<2)|0);
      HEAP32[$331>>2] = $aggregateElemID4$025;
      $332 = (($index$024) + 1)|0;
      $333 = (($330) + ($aggregateElemID4$025<<2)|0);
      $aggregateElemID4$0 = HEAP32[$333>>2]|0;
      $334 = ($aggregateElemID4$0|0)==(1073741823);
      if ($334) {
       break;
      } else {
       $aggregateElemID4$025 = $aggregateElemID4$0;$index$024 = $332;
      }
     }
    }
    $335 = ((($117) + (($115*1048)|0)|0) + 1025|0);
    $336 = HEAP8[$335>>0]|0;
    $337 = $336&255;
    $338 = $318 ^ -1;
    $339 = (($337) + ($338))|0;
    $340 = (($vararg_buffer) + ($339<<2)|0);
    $341 = HEAP32[$340>>2]|0;
    $342 = (($this) + 304|0);
    $343 = HEAP32[$342>>2]|0;
    $344 = (($343) + ($341<<2)|0);
    HEAP32[$344>>2] = $userdata;
    $345 = (($this) + 308|0);
    $346 = HEAP32[$345>>2]|0;
    $347 = (($346) + ($341<<2)|0);
    HEAP32[$347>>2] = $group;
    $348 = (($this) + 300|0);
    $349 = HEAP32[$348>>2]|0;
    $350 = (($349) + (($341*24)|0)|0);
    HEAP32[$350>>2] = $128;
    $351 = ((($349) + (($341*24)|0)|0) + 4|0);
    HEAP32[$351>>2] = $135;
    $352 = ((($349) + (($341*24)|0)|0) + 8|0);
    HEAP32[$352>>2] = $142;
    $353 = ((($349) + (($341*24)|0)|0) + 12|0);
    HEAP32[$353>>2] = $149;
    $354 = ((($349) + (($341*24)|0)|0) + 16|0);
    HEAP32[$354>>2] = $157;
    $355 = ((($349) + (($341*24)|0)|0) + 20|0);
    HEAP32[$355>>2] = $165;
    $356 = (($this) + 320|0);
    $357 = HEAP32[$356>>2]|0;
    $358 = (($357) + ($341<<2)|0);
    HEAP32[$358>>2] = 1073741823;
    $359 = ((($117) + (($115*1048)|0)|0) + 1026|0);
    $360 = HEAP8[$359>>0]|0;
    $361 = (($360) + 1)<<24>>24;
    HEAP8[$359>>0] = $361;
    $362 = $encodedAggregateId >>> 6;
    $363 = (($this) + 356|0);
    $364 = HEAP32[$363>>2]|0;
    $365 = (($364) + ($362<<2)|0);
    $366 = HEAP32[$365>>2]|0;
    $367 = $115 & 31;
    $368 = 1 << $367;
    $369 = $366 & $368;
    $370 = ($369|0)==(0);
    if ($370) {
     $371 = $366 | $368;
     HEAP32[$365>>2] = $371;
     $aggregateElemID4$1 = $341;
    } else {
     $aggregateElemID4$1 = $341;
    }
   }
  }
 }
 do {
  if ((label|0) == 38) {
   $372 = ((($117) + (($115*1048)|0)|0) + 1025|0);
   $373 = HEAP8[$372>>0]|0;
   $374 = ($373<<24>>24)>(-1);
   if ($374) {
    __ZN5physx14PxsAABBManager14promoteBitmapsEPNS_9AggregateE($this,$118);
    $375 = (__ZN5physx14PxsAABBManager19createAggregateElemEv($this)|0);
    $376 = HEAP32[$119>>2]|0;
    $377 = (($this) + 304|0);
    $378 = HEAP32[$377>>2]|0;
    $379 = (($378) + ($375<<2)|0);
    HEAP32[$379>>2] = $userdata;
    $380 = (($this) + 308|0);
    $381 = HEAP32[$380>>2]|0;
    $382 = (($381) + ($375<<2)|0);
    HEAP32[$382>>2] = $group;
    $383 = (($this) + 300|0);
    $384 = HEAP32[$383>>2]|0;
    $385 = (($384) + (($375*24)|0)|0);
    HEAP32[$385>>2] = $128;
    $386 = ((($384) + (($375*24)|0)|0) + 4|0);
    HEAP32[$386>>2] = $135;
    $387 = ((($384) + (($375*24)|0)|0) + 8|0);
    HEAP32[$387>>2] = $142;
    $388 = ((($384) + (($375*24)|0)|0) + 12|0);
    HEAP32[$388>>2] = $149;
    $389 = ((($384) + (($375*24)|0)|0) + 16|0);
    HEAP32[$389>>2] = $157;
    $390 = ((($384) + (($375*24)|0)|0) + 20|0);
    HEAP32[$390>>2] = $165;
    $391 = (($this) + 316|0);
    $392 = HEAP32[$391>>2]|0;
    $393 = (($392) + ($375<<2)|0);
    HEAP32[$393>>2] = $376;
    $394 = (($this) + 320|0);
    $395 = HEAP32[$394>>2]|0;
    $396 = (($395) + ($375<<2)|0);
    HEAP32[$396>>2] = 1073741823;
    HEAP32[$119>>2] = $375;
    $397 = HEAP8[$372>>0]|0;
    $398 = (($397) + 1)<<24>>24;
    HEAP8[$372>>0] = $398;
    $399 = ((($117) + (($115*1048)|0)|0) + 1026|0);
    $400 = HEAP8[$399>>0]|0;
    $401 = (($400) + 1)<<24>>24;
    HEAP8[$399>>0] = $401;
    $402 = $encodedAggregateId >>> 6;
    $403 = (($this) + 356|0);
    $404 = HEAP32[$403>>2]|0;
    $405 = (($404) + ($402<<2)|0);
    $406 = HEAP32[$405>>2]|0;
    $407 = $115 & 31;
    $408 = 1 << $407;
    $409 = $406 & $408;
    $410 = ($409|0)==(0);
    if (!($410)) {
     $aggregateElemID4$1 = $375;
     break;
    }
    $411 = $406 | $408;
    HEAP32[$405>>2] = $411;
    $aggregateElemID4$1 = $375;
    break;
   } else {
    $412 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($412,32,481296,541,481384,$vararg_buffer);
    HEAP32[$agg$result>>2] = 1073741823;
    $413 = (($agg$result) + 4|0);
    HEAP32[$413>>2] = 1073741823;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $414 = ((($117) + (($115*1048)|0)|0) + 1028|0);
 $415 = HEAP32[$414>>2]|0;
 $416 = (($this) + 12|0);
 $417 = HEAP32[$416>>2]|0;
 $418 = (($417) + (($415*24)|0)|0);
 $419 = HEAP32[$418>>2]|0;
 $420 = ((($417) + (($415*24)|0)|0) + 4|0);
 $421 = HEAP32[$420>>2]|0;
 $422 = ((($417) + (($415*24)|0)|0) + 8|0);
 $423 = HEAP32[$422>>2]|0;
 $424 = ((($417) + (($415*24)|0)|0) + 12|0);
 $425 = HEAP32[$424>>2]|0;
 $426 = ((($417) + (($415*24)|0)|0) + 16|0);
 $427 = HEAP32[$426>>2]|0;
 $428 = ((($417) + (($415*24)|0)|0) + 20|0);
 $429 = HEAP32[$428>>2]|0;
 $430 = ($419>>>0)>($128>>>0);
 $431 = ($421>>>0)>($135>>>0);
 $or$cond17 = $430 | $431;
 $432 = ($423>>>0)>($142>>>0);
 $or$cond18 = $or$cond17 | $432;
 $433 = ($425>>>0)<($149>>>0);
 $or$cond19 = $or$cond18 | $433;
 $434 = ($427>>>0)<($157>>>0);
 $or$cond20 = $or$cond19 | $434;
 $or$cond20$not = $or$cond20 ^ 1;
 $not$$i = ($429>>>0)>=($165>>>0);
 $or$cond21 = $not$$i & $or$cond20$not;
 if (!($or$cond21)) {
  $435 = ($419>>>0)<($128>>>0);
  $436 = $435 ? $419 : $128;
  $437 = ($421>>>0)<($135>>>0);
  $438 = $437 ? $421 : $135;
  $439 = ($423>>>0)<($142>>>0);
  $440 = $439 ? $423 : $142;
  $441 = $433 ? $149 : $425;
  $442 = $434 ? $157 : $427;
  $443 = ($429>>>0)<($165>>>0);
  $444 = $443 ? $165 : $429;
  HEAP32[$418>>2] = $436;
  HEAP32[$420>>2] = $438;
  HEAP32[$422>>2] = $440;
  HEAP32[$424>>2] = $441;
  HEAP32[$426>>2] = $442;
  HEAP32[$428>>2] = $444;
  $445 = $415 >>> 5;
  $446 = (($this) + 96|0);
  $447 = HEAP32[$446>>2]|0;
  $448 = (($447) + ($445<<2)|0);
  $449 = HEAP32[$448>>2]|0;
  $450 = $415 & 31;
  $451 = 1 << $450;
  $452 = $449 & $451;
  $453 = ($452|0)==(0);
  if ($453) {
   $454 = (($this) + 68|0);
   $455 = HEAP32[$454>>2]|0;
   $456 = (($455) + ($445<<2)|0);
   $457 = HEAP32[$456>>2]|0;
   $458 = $457 & $451;
   $459 = ($458|0)==(0);
   if ($459) {
    $460 = $457 | $451;
    HEAP32[$456>>2] = $460;
   }
  }
 }
 $461 = ($encodedActorHandle|0)==(1073741823);
 do {
  if ($461) {
   $462 = (($this) + 292|0);
   $463 = HEAP32[$462>>2]|0;
   $464 = ($463|0)==(1073741823);
   if ($464) {
    $465 = (($this) + 244|0);
    $466 = (($this) + 264|0);
    $467 = HEAP32[$466>>2]|0;
    $468 = $467 << 1;
    $469 = ($468>>>0)<(64);
    $470 = $469 ? 64 : $468;
    __ZN5physx21AggregateActorManager6resizeEj($465,$470);
    $$pre$i = HEAP32[$462>>2]|0;
    $474 = $$pre$i;
   } else {
    $474 = $463;
   }
   $471 = (($this) + 248|0);
   $472 = HEAP32[$471>>2]|0;
   $473 = (($472) + (($474*24)|0)|0);
   $475 = HEAP32[$473>>2]|0;
   HEAP32[$462>>2] = $475;
   $476 = (($472) + (($474*24)|0)|0);
   HEAPF32[$476>>2] = Math_fround(8.50705866596322149529E+37);
   $477 = ((($472) + (($474*24)|0)|0) + 4|0);
   HEAPF32[$477>>2] = Math_fround(8.50705866596322149529E+37);
   $478 = ((($472) + (($474*24)|0)|0) + 8|0);
   HEAPF32[$478>>2] = Math_fround(8.50705866596322149529E+37);
   $479 = ((($472) + (($474*24)|0)|0) + 12|0);
   HEAPF32[$479>>2] = Math_fround(-8.50705866596322149529E+37);
   $480 = ((($472) + (($474*24)|0)|0) + 16|0);
   HEAPF32[$480>>2] = Math_fround(-8.50705866596322149529E+37);
   $481 = ((($472) + (($474*24)|0)|0) + 20|0);
   HEAPF32[$481>>2] = Math_fround(-8.50705866596322149529E+37);
   $482 = (($this) + 252|0);
   $483 = HEAP32[$482>>2]|0;
   $484 = (($483) + ($474)|0);
   HEAP8[$484>>0] = 0;
   $485 = (($this) + 260|0);
   $486 = HEAP32[$485>>2]|0;
   $487 = (($486) + ($474<<2)|0);
   HEAP32[$487>>2] = $115;
   $488 = ((($117) + (($115*1048)|0)|0) + 1040|0);
   $489 = HEAP32[$488>>2]|0;
   $490 = ($489|0)==(1073741823);
   $491 = (($this) + 256|0);
   $492 = HEAP32[$491>>2]|0;
   $493 = (($492) + ($474<<2)|0);
   if ($490) {
    HEAP32[$493>>2] = 1073741823;
    HEAP32[$488>>2] = $474;
    $$pre$phi29Z2D = $482;$actorId7$0 = $474;
    break;
   } else {
    HEAP32[$493>>2] = $489;
    HEAP32[$488>>2] = $474;
    $$pre$phi29Z2D = $482;$actorId7$0 = $474;
    break;
   }
  } else {
   $494 = $encodedActorHandle >>> 1;
   $$pre28 = (($this) + 252|0);
   $$pre$phi29Z2D = $$pre28;$actorId7$0 = $494;
  }
 } while(0);
 $495 = $actorId7$0 << 1;
 $496 = $495 | 1;
 $497 = (($this) + 312|0);
 $498 = HEAP32[$497>>2]|0;
 $499 = (($498) + ($aggregateElemID4$1<<2)|0);
 HEAP32[$499>>2] = $496;
 $500 = HEAP32[$$pre$phi29Z2D>>2]|0;
 $501 = (($500) + ($actorId7$0)|0);
 $502 = HEAP8[$501>>0]|0;
 $503 = (($502) + 1)<<24>>24;
 HEAP8[$501>>0] = $503;
 $504 = $actorId7$0 & 31;
 $505 = 1 << $504;
 $506 = $505 ^ -1;
 $507 = $actorId7$0 >>> 5;
 $508 = (($this) + 280|0);
 $509 = HEAP32[$508>>2]|0;
 $510 = (($509) + ($507<<2)|0);
 $511 = HEAP32[$510>>2]|0;
 $512 = $511 & $506;
 HEAP32[$510>>2] = $512;
 $513 = ((($117) + (($115*1048)|0)|0) + 1024|0);
 $514 = HEAP8[$513>>0]|0;
 $515 = ($514<<24>>24)==(0);
 if ($515) {
  $516 = (($this) + 268|0);
  $517 = HEAP32[$516>>2]|0;
  $518 = (($517) + ($507<<2)|0);
  $519 = HEAP32[$518>>2]|0;
  $520 = $519 | $505;
  HEAP32[$518>>2] = $520;
 }
 $521 = ($aggregateElemID4$1>>>0)<(536870911);
 $522 = ($actorId7$0>>>0)<(536870911);
 $or$cond22 = $521 & $522;
 if ($or$cond22) {
  $523 = $aggregateElemID4$1 << 1;
  $524 = $523 | 1;
  HEAP32[$agg$result>>2] = $524;
  $525 = (($agg$result) + 4|0);
  HEAP32[$525>>2] = $496;
  STACKTOP = sp;return;
 } else {
  HEAP32[$agg$result>>2] = 1073741823;
  $526 = (($agg$result) + 4|0);
  HEAP32[$526>>2] = 1073741823;
  STACKTOP = sp;return;
 }
}
function __ZN5physx14PxsAABBManager12createBPElemEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $elemId$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1073741823);
 if (!($4)) {
  $5 = (($this) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($3<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$2>>2] = $8;
  $9 = (($this) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + (($3*24)|0)|0) + 8|0);
  HEAP32[$11>>2] = -8388609;
  $12 = ((($10) + (($3*24)|0)|0) + 4|0);
  HEAP32[$12>>2] = -8388609;
  $13 = (($10) + (($3*24)|0)|0);
  HEAP32[$13>>2] = -8388609;
  $14 = ((($10) + (($3*24)|0)|0) + 20|0);
  HEAP32[$14>>2] = 8388608;
  $15 = ((($10) + (($3*24)|0)|0) + 16|0);
  HEAP32[$15>>2] = 8388608;
  $16 = ((($10) + (($3*24)|0)|0) + 12|0);
  HEAP32[$16>>2] = 8388608;
  $17 = (($this) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($3<<2)|0);
  HEAP32[$19>>2] = 0;
  $20 = HEAP32[$5>>2]|0;
  $21 = (($20) + ($3<<2)|0);
  HEAP32[$21>>2] = 1073741823;
  $22 = (($this) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($3<<2)|0);
  HEAP32[$24>>2] = 1073741823;
  $25 = (($this) + 32|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($3<<2)|0);
  HEAP32[$27>>2] = 1073741823;
  $28 = (($this) + 28|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + ($3<<2)|0);
  HEAP32[$30>>2] = 1073741823;
  $elemId$0 = $3;
  STACKTOP = sp;return ($elemId$0|0);
 }
 $31 = (($this) + 8|0);
 $32 = (($this) + 36|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 $35 = $33 << 1;
 $$ = $34 ? 32 : $35;
 __ZN5physx5Elems4growEj($31,$$);
 $36 = (($$) + 31)|0;
 $37 = $36 >>> 5;
 $38 = (($37) + 3)|0;
 $39 = $38 & 268435452;
 $40 = (($this) + 72|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 2147483647;
 $43 = ($39>>>0)>($42>>>0);
 if ($43) {
  $44 = (($this) + 68|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $39 << 2;
  $47 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$46,481512,76)|0);
  $48 = ($45|0)==(0|0);
  if (!($48)) {
   $49 = $41 << 2;
   _memcpy(($47|0),($45|0),($49|0))|0;
  }
  $50 = (($47) + ($42<<2)|0);
  $51 = (($39) - ($41))|0;
  $52 = $51 << 2;
  _memset(($50|0),0,($52|0))|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$45);
  HEAP32[$44>>2] = $47;
  $53 = $39 | -2147483648;
  HEAP32[$40>>2] = $53;
 }
 $54 = (($this) + 100|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 & 2147483647;
 $57 = ($39>>>0)>($56>>>0);
 if ($57) {
  $58 = (($this) + 96|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $39 << 2;
  $61 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$60,481512,76)|0);
  $62 = ($59|0)==(0|0);
  if (!($62)) {
   $63 = $55 << 2;
   _memcpy(($61|0),($59|0),($63|0))|0;
  }
  $64 = (($61) + ($56<<2)|0);
  $65 = (($39) - ($55))|0;
  $66 = $65 << 2;
  _memset(($64|0),0,($66|0))|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$59);
  HEAP32[$58>>2] = $61;
  $67 = $39 | -2147483648;
  HEAP32[$54>>2] = $67;
 }
 $68 = (($this) + 128|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = $69 & 2147483647;
 $71 = ($39>>>0)>($70>>>0);
 if ($71) {
  $72 = (($this) + 124|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = $39 << 2;
  $75 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$74,481512,76)|0);
  $76 = ($73|0)==(0|0);
  if (!($76)) {
   $77 = $69 << 2;
   _memcpy(($75|0),($73|0),($77|0))|0;
  }
  $78 = (($75) + ($70<<2)|0);
  $79 = (($39) - ($69))|0;
  $80 = $79 << 2;
  _memset(($78|0),0,($80|0))|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$73);
  HEAP32[$72>>2] = $75;
  $81 = $39 | -2147483648;
  HEAP32[$68>>2] = $81;
 }
 $82 = HEAP32[$2>>2]|0;
 $83 = (($this) + 20|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($84) + ($82<<2)|0);
 $86 = HEAP32[$85>>2]|0;
 HEAP32[$2>>2] = $86;
 $87 = (($this) + 12|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ((($88) + (($82*24)|0)|0) + 8|0);
 HEAP32[$89>>2] = -8388609;
 $90 = ((($88) + (($82*24)|0)|0) + 4|0);
 HEAP32[$90>>2] = -8388609;
 $91 = (($88) + (($82*24)|0)|0);
 HEAP32[$91>>2] = -8388609;
 $92 = ((($88) + (($82*24)|0)|0) + 20|0);
 HEAP32[$92>>2] = 8388608;
 $93 = ((($88) + (($82*24)|0)|0) + 16|0);
 HEAP32[$93>>2] = 8388608;
 $94 = ((($88) + (($82*24)|0)|0) + 12|0);
 HEAP32[$94>>2] = 8388608;
 $95 = (($this) + 16|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (($96) + ($82<<2)|0);
 HEAP32[$97>>2] = 0;
 $98 = HEAP32[$83>>2]|0;
 $99 = (($98) + ($82<<2)|0);
 HEAP32[$99>>2] = 1073741823;
 $100 = (($this) + 24|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = (($101) + ($82<<2)|0);
 HEAP32[$102>>2] = 1073741823;
 $103 = (($this) + 32|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + ($82<<2)|0);
 HEAP32[$105>>2] = 1073741823;
 $106 = (($this) + 28|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($107) + ($82<<2)|0);
 HEAP32[$108>>2] = 1073741823;
 $elemId$0 = $82;
 STACKTOP = sp;return ($elemId$0|0);
}
function __ZN5physx14PxsAABBManager19createAggregateElemEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $elemId$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 328|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1073741823);
 if (!($4)) {
  $5 = (($this) + 308|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($3<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$2>>2] = $8;
  $9 = (($this) + 300|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + (($3*24)|0)|0) + 8|0);
  HEAP32[$11>>2] = -8388609;
  $12 = ((($10) + (($3*24)|0)|0) + 4|0);
  HEAP32[$12>>2] = -8388609;
  $13 = (($10) + (($3*24)|0)|0);
  HEAP32[$13>>2] = -8388609;
  $14 = ((($10) + (($3*24)|0)|0) + 20|0);
  HEAP32[$14>>2] = 8388608;
  $15 = ((($10) + (($3*24)|0)|0) + 16|0);
  HEAP32[$15>>2] = 8388608;
  $16 = ((($10) + (($3*24)|0)|0) + 12|0);
  HEAP32[$16>>2] = 8388608;
  $17 = (($this) + 304|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($3<<2)|0);
  HEAP32[$19>>2] = 0;
  $20 = HEAP32[$5>>2]|0;
  $21 = (($20) + ($3<<2)|0);
  HEAP32[$21>>2] = 1073741823;
  $22 = (($this) + 312|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($3<<2)|0);
  HEAP32[$24>>2] = 1073741823;
  $25 = (($this) + 320|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($3<<2)|0);
  HEAP32[$27>>2] = 1073741823;
  $28 = (($this) + 316|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + ($3<<2)|0);
  HEAP32[$30>>2] = 1073741823;
  $elemId$0 = $3;
  STACKTOP = sp;return ($elemId$0|0);
 }
 $31 = (($this) + 296|0);
 $32 = (($this) + 324|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 $35 = $33 << 1;
 $$ = $34 ? 32 : $35;
 __ZN5physx5Elems4growEj($31,$$);
 $36 = (($$) + 31)|0;
 $37 = $36 >>> 5;
 $38 = (($37) + 3)|0;
 $39 = $38 & 268435452;
 $40 = (($this) + 360|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 2147483647;
 $43 = ($39>>>0)>($42>>>0);
 if ($43) {
  $44 = (($this) + 356|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $39 << 2;
  $47 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$46,481512,76)|0);
  $48 = ($45|0)==(0|0);
  if (!($48)) {
   $49 = $41 << 2;
   _memcpy(($47|0),($45|0),($49|0))|0;
  }
  $50 = (($47) + ($42<<2)|0);
  $51 = (($39) - ($41))|0;
  $52 = $51 << 2;
  _memset(($50|0),0,($52|0))|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$45);
  HEAP32[$44>>2] = $47;
  $53 = $39 | -2147483648;
  HEAP32[$40>>2] = $53;
 }
 $54 = HEAP32[$2>>2]|0;
 $55 = (($this) + 308|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + ($54<<2)|0);
 $58 = HEAP32[$57>>2]|0;
 HEAP32[$2>>2] = $58;
 $59 = (($this) + 300|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($60) + (($54*24)|0)|0) + 8|0);
 HEAP32[$61>>2] = -8388609;
 $62 = ((($60) + (($54*24)|0)|0) + 4|0);
 HEAP32[$62>>2] = -8388609;
 $63 = (($60) + (($54*24)|0)|0);
 HEAP32[$63>>2] = -8388609;
 $64 = ((($60) + (($54*24)|0)|0) + 20|0);
 HEAP32[$64>>2] = 8388608;
 $65 = ((($60) + (($54*24)|0)|0) + 16|0);
 HEAP32[$65>>2] = 8388608;
 $66 = ((($60) + (($54*24)|0)|0) + 12|0);
 HEAP32[$66>>2] = 8388608;
 $67 = (($this) + 304|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + ($54<<2)|0);
 HEAP32[$69>>2] = 0;
 $70 = HEAP32[$55>>2]|0;
 $71 = (($70) + ($54<<2)|0);
 HEAP32[$71>>2] = 1073741823;
 $72 = (($this) + 312|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73) + ($54<<2)|0);
 HEAP32[$74>>2] = 1073741823;
 $75 = (($this) + 320|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + ($54<<2)|0);
 HEAP32[$77>>2] = 1073741823;
 $78 = (($this) + 316|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($79) + ($54<<2)|0);
 HEAP32[$80>>2] = 1073741823;
 $elemId$0 = $54;
 STACKTOP = sp;return ($elemId$0|0);
}
function __ZN5physx14PxsAABBManager14promoteBitmapsEPNS_9AggregateE($this,$aggregate) {
 $this = $this|0;
 $aggregate = $aggregate|0;
 var $$in = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $aggregatePairs$01 = 0, $copy$i = 0, $exitcond$i = 0, $exitcond4$i = 0, $i$02$i = 0, $j$01$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1024|0;
 $copy$i = sp;
 $0 = (($aggregate) + 1025|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 _memcpy(($copy$i|0),($aggregate|0),1024)|0;
 _memset(($aggregate|0),0,1024)|0;
 $3 = ($1<<24>>24)==(0);
 if (!($3)) {
  $i$02$i = 0;
  while(1) {
   $4 = (($i$02$i) + 1)|0;
   $5 = ($4>>>0)<($2>>>0);
   if ($5) {
    $j$01$i = $4;
    while(1) {
     $6 = (($j$01$i) + -1)|0;
     $7 = Math_imul($6, $j$01$i)|0;
     $8 = $7 >>> 1;
     $9 = (($8) + ($i$02$i))|0;
     $10 = $9 >>> 5;
     $11 = (($copy$i) + ($10<<2)|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = $9 & 31;
     $14 = 1 << $13;
     $15 = $14 & $12;
     $16 = ($15|0)==(0);
     $$pre$i = (($j$01$i) + 1)|0;
     if (!($16)) {
      $17 = Math_imul($$pre$i, $j$01$i)|0;
      $18 = $17 >>> 1;
      $19 = (($18) + ($4))|0;
      $20 = $19 & 31;
      $21 = 1 << $20;
      $22 = $19 >>> 5;
      $23 = (($aggregate) + ($22<<2)|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = $24 | $21;
      HEAP32[$23>>2] = $25;
     }
     $exitcond$i = ($$pre$i|0)==($2|0);
     if ($exitcond$i) {
      break;
     } else {
      $j$01$i = $$pre$i;
     }
    }
   }
   $exitcond4$i = ($4|0)==($2|0);
   if ($exitcond4$i) {
    break;
   } else {
    $i$02$i = $4;
   }
  }
 }
 $26 = (($this) + 49860|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($this) + 49856|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 24|0);
 $32 = (($this) + 180|0);
 $$in = $27;$aggregatePairs$01 = $30;
 while(1) {
  $33 = (($$in) + -1)|0;
  $34 = (($aggregatePairs$01) + 12|0);
  $35 = HEAP32[$aggregatePairs$01>>2]|0;
  $36 = HEAP32[$31>>2]|0;
  $37 = (($36) + ($35<<2)|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38 & 1;
  $40 = ($39|0)==(0);
  if ($40) {
   $54 = 0;
  } else {
   $41 = $38 >>> 1;
   $42 = HEAP32[$32>>2]|0;
   $43 = (($42) + (($41*1048)|0)|0);
   $54 = $43;
  }
  $44 = (($aggregatePairs$01) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($36) + ($45<<2)|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = $47 & 1;
  $49 = ($48|0)==(0);
  if ($49) {
   $56 = 0;
  } else {
   $50 = $47 >>> 1;
   $51 = HEAP32[$32>>2]|0;
   $52 = (($51) + (($50*1048)|0)|0);
   $56 = $52;
  }
  $53 = ($54|0)==(0|0);
  $55 = ($56|0)!=(0|0);
  do {
   if ($53) {
    $80 = ($56|0)==($aggregate|0);
    $or$cond = $55 & $80;
    if ($or$cond) {
     $81 = (($aggregatePairs$01) + 8|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = HEAP8[$0>>0]|0;
     $84 = $83&255;
     $85 = (__ZNK5physx14PxsAABBManager13promoteBitmapEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjjjj($this,$82,$84,1,0,-1)|0);
     HEAP32[$81>>2] = $85;
    }
   } else {
    $57 = ($54|0)==($aggregate|0);
    if (!($55)) {
     if (!($57)) {
      break;
     }
     $75 = (($aggregatePairs$01) + 8|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = HEAP8[$0>>0]|0;
     $78 = $77&255;
     $79 = (__ZNK5physx14PxsAABBManager13promoteBitmapEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjjjj($this,$76,$78,1,0,-1)|0);
     HEAP32[$75>>2] = $79;
     break;
    }
    if ($57) {
     $58 = (($aggregatePairs$01) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = HEAP8[$0>>0]|0;
     $61 = $60&255;
     $62 = (($56) + 1025|0);
     $63 = HEAP8[$62>>0]|0;
     $64 = $63&255;
     $65 = (__ZNK5physx14PxsAABBManager13promoteBitmapEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjjjj($this,$59,$61,$64,0,-1)|0);
     HEAP32[$58>>2] = $65;
     break;
    }
    $66 = ($56|0)==($aggregate|0);
    if ($66) {
     $67 = (($aggregatePairs$01) + 8|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($54) + 1025|0);
     $70 = HEAP8[$69>>0]|0;
     $71 = $70&255;
     $72 = HEAP8[$0>>0]|0;
     $73 = $72&255;
     $74 = (__ZNK5physx14PxsAABBManager13promoteBitmapEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjjjj($this,$68,$71,$73,-1,0)|0);
     HEAP32[$67>>2] = $74;
    }
   }
  } while(0);
  $86 = ($33|0)==(0);
  if ($86) {
   break;
  } else {
   $$in = $33;$aggregatePairs$01 = $34;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager17setStaticAABBDataEjRKNS_17PxcAABBDataStaticE($this,$shapeHandle,$aabbData) {
 $this = $this|0;
 $shapeHandle = $shapeHandle|0;
 $aabbData = $aabbData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $shapeHandle & 1;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($this) + 8|0);
  $3 = $shapeHandle >>> 1;
  __ZN5physx5Elems17setStaticAABBDataEjRKNS_17PxcAABBDataStaticE($2,$3,$aabbData);
  STACKTOP = sp;return;
 } else {
  $4 = $shapeHandle >>> 1;
  $5 = (($this) + 296|0);
  __ZN5physx5Elems17setStaticAABBDataEjRKNS_17PxcAABBDataStaticE($5,$4,$aabbData);
  STACKTOP = sp;return;
 }
}
function __ZN5physx5Elems17setStaticAABBDataEjRKNS_17PxcAABBDataStaticE($this,$id,$aabbData) {
 $this = $this|0;
 $id = $id|0;
 $aabbData = $aabbData|0;
 var $$c$i$i = 0, $$c1$i$i = 0, $$pre$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $i$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 36|0);
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(1073741823);
 if ($5) {
  $6 = (($this) + 40|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 << 1;
  $9 = ($8>>>0)<(64);
  $10 = $9 ? 64 : $8;
  $11 = $10 << 3;
  $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$11,481512,1503)|0);
  $13 = HEAP32[$2>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = $7 << 3;
   _memcpy(($12|0),($13|0),($15|0))|0;
   $16 = (($12) + ($7<<3)|0);
   $17 = (($10) - ($7))|0;
   $18 = $17 << 3;
   _memset(($16|0),0,($18|0))|0;
  }
  $19 = HEAP32[$3>>2]|0;
  $20 = (($10) + -1)|0;
  $21 = (($12) + ($20<<3)|0);
  $$c$i$i = $19;
  HEAP32[$21>>2] = $$c$i$i;
  $22 = ($7>>>0)<($20>>>0);
  if ($22) {
   $i$02$i$i = $7;
   while(1) {
    $23 = (($i$02$i$i) + 1)|0;
    $24 = (($12) + ($i$02$i$i<<3)|0);
    $$c1$i$i = $23;
    HEAP32[$24>>2] = $$c1$i$i;
    $exitcond$i$i = ($23|0)==($20|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$02$i$i = $23;
    }
   }
  }
  $25 = HEAP32[$6>>2]|0;
  HEAP32[$3>>2] = $25;
  $26 = HEAP32[$2>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$26);
  HEAP32[$2>>2] = $12;
  HEAP32[$6>>2] = $10;
  $$pre$i = HEAP32[$3>>2]|0;
  $28 = $12;$29 = $$pre$i;
 } else {
  $$pre1$i = HEAP32[$2>>2]|0;
  $28 = $$pre1$i;$29 = $4;
 }
 $27 = (($28) + ($29<<3)|0);
 $30 = HEAP32[$27>>2]|0;
 HEAP32[$3>>2] = $30;
 $31 = (($28) + ($29<<3)|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($28) + ($29<<3)|0) + 4|0);
 HEAP32[$32>>2] = 0;
 $33 = HEAP32[$2>>2]|0;
 $34 = (($33) + ($29<<3)|0);
 $35 = $aabbData;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + 4)|0;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = $34;
 $42 = $41;
 HEAP32[$42>>2] = $37;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $40;
 $45 = (($this) + 24|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46) + ($id<<2)|0);
 HEAP32[$47>>2] = $29;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager18setDynamicAABBDataEjRKNS_18PxcAABBDataDynamicE($this,$shapeHandle,$aabbData) {
 $this = $this|0;
 $shapeHandle = $shapeHandle|0;
 $aabbData = $aabbData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $shapeHandle & 1;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($this) + 8|0);
  $3 = $shapeHandle >>> 1;
  __ZN5physx5Elems18setDynamicAABBDataEjRKNS_18PxcAABBDataDynamicE($2,$3,$aabbData);
  STACKTOP = sp;return;
 } else {
  $4 = $shapeHandle >>> 1;
  $5 = (($this) + 296|0);
  __ZN5physx5Elems18setDynamicAABBDataEjRKNS_18PxcAABBDataDynamicE($5,$4,$aabbData);
  STACKTOP = sp;return;
 }
}
function __ZN5physx5Elems18setDynamicAABBDataEjRKNS_18PxcAABBDataDynamicE($this,$id,$aabbData) {
 $this = $this|0;
 $id = $id|0;
 $aabbData = $aabbData|0;
 var $$c$i$i = 0, $$c1$i$i = 0, $$pre$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond$i$i = 0, $i$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 48|0);
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(1073741823);
 if ($5) {
  $6 = (($this) + 52|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 << 1;
  $9 = ($8>>>0)<(64);
  $10 = $9 ? 64 : $8;
  $11 = $10 << 4;
  $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$11,481512,1503)|0);
  $13 = HEAP32[$2>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = $7 << 4;
   _memcpy(($12|0),($13|0),($15|0))|0;
   $16 = (($12) + ($7<<4)|0);
   $17 = (($10) - ($7))|0;
   $18 = $17 << 4;
   _memset(($16|0),0,($18|0))|0;
  }
  $19 = HEAP32[$3>>2]|0;
  $20 = (($10) + -1)|0;
  $21 = (($12) + ($20<<4)|0);
  $$c$i$i = $19;
  HEAP32[$21>>2] = $$c$i$i;
  $22 = ($7>>>0)<($20>>>0);
  if ($22) {
   $i$02$i$i = $7;
   while(1) {
    $23 = (($i$02$i$i) + 1)|0;
    $24 = (($12) + ($i$02$i$i<<4)|0);
    $$c1$i$i = $23;
    HEAP32[$24>>2] = $$c1$i$i;
    $exitcond$i$i = ($23|0)==($20|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$02$i$i = $23;
    }
   }
  }
  $25 = HEAP32[$6>>2]|0;
  HEAP32[$3>>2] = $25;
  $26 = HEAP32[$2>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$26);
  HEAP32[$2>>2] = $12;
  HEAP32[$6>>2] = $10;
  $$pre$i = HEAP32[$3>>2]|0;
  $28 = $12;$29 = $$pre$i;
 } else {
  $$pre1$i = HEAP32[$2>>2]|0;
  $28 = $$pre1$i;$29 = $4;
 }
 $27 = (($28) + ($29<<4)|0);
 $30 = HEAP32[$27>>2]|0;
 HEAP32[$3>>2] = $30;
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;
 $31 = HEAP32[$2>>2]|0;
 $32 = (($31) + ($29<<4)|0);
 ;HEAP32[$32+0>>2]=HEAP32[$aabbData+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$aabbData+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$aabbData+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$aabbData+12>>2]|0;
 $33 = (($this) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + ($id<<2)|0);
 HEAP32[$35>>2] = $29;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager13releaseVolumeEj($this,$shapeHandle) {
 $this = $this|0;
 $shapeHandle = $shapeHandle|0;
 var $$0$i = 0, $$c$i$i = 0, $$c$i1$i = 0, $$pre = 0, $$pre10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $elemId$03 = 0, $headId$0 = 0;
 var $headId$04 = 0, $headId$06 = 0, $idCurr$0 = 0, $idPrev$0 = 0, $idPrev$0$phi = 0, $internalIndex$0$lcssa = 0, $internalIndex$05 = 0, $phitmp = 0, $removingLastShape$0$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $shapeHandle & 1;
 $1 = ($0|0)==(0);
 $2 = $shapeHandle >>> 1;
 if ($1) {
  __ZN5physx14PxsAABBManager19purgeAggregatePairsEj($this,$2);
  $3 = $shapeHandle >>> 6;
  $4 = (($this) + 68|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($3<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $2 & 31;
  $9 = 1 << $8;
  $10 = $7 & $9;
  $11 = ($10|0)==(0);
  if (!($11)) {
   $12 = $9 ^ -1;
   $13 = $7 & $12;
   HEAP32[$6>>2] = $13;
  }
  $14 = (($this) + 96|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + ($3<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17 & $9;
  $19 = ($18|0)==(0);
  if ($19) {
   $22 = (($this) + 124|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + ($3<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 | $9;
   HEAP32[$24>>2] = $26;
  } else {
   $20 = $9 ^ -1;
   $21 = $17 & $20;
   HEAP32[$16>>2] = $21;
  }
  $27 = (($this) + 24|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + ($2<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = $30 >>> 1;
  $32 = (($this) + 156|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + ($31<<2)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($this) + 28|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<2)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($2|0)==($35|0);
  if (!($40)) {
   $idCurr$0 = $39;$idPrev$0 = $35;
   while(1) {
    $50 = ($idCurr$0|0)==($2|0);
    $51 = (($37) + ($idCurr$0<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    if ($50) {
     break;
    } else {
     $idPrev$0$phi = $idCurr$0;$idCurr$0 = $52;$idPrev$0 = $idPrev$0$phi;
    }
   }
   $53 = (($37) + ($idPrev$0<<2)|0);
   HEAP32[$53>>2] = $52;
   $54 = (($37) + ($2<<2)|0);
   HEAP32[$54>>2] = 1073741823;
   $removingLastShape$0$off0 = 0;
   STACKTOP = sp;return ($removingLastShape$0$off0|0);
  }
  $41 = ($39|0)==(1073741823);
  if ($41) {
   HEAP32[$34>>2] = 1073741823;
   $42 = (($this) + 172|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($this) + 168|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + ($43<<2)|0);
   HEAP32[$46>>2] = $31;
   $47 = HEAP32[$42>>2]|0;
   $48 = (($47) + 1)|0;
   HEAP32[$42>>2] = $48;
   $49 = (($37) + ($2<<2)|0);
   HEAP32[$49>>2] = 1073741823;
   $removingLastShape$0$off0 = 1;
   STACKTOP = sp;return ($removingLastShape$0$off0|0);
  } else {
   HEAP32[$34>>2] = $39;
   $removingLastShape$0$off0 = 0;
   STACKTOP = sp;return ($removingLastShape$0$off0|0);
  }
 }
 $55 = (($this) + 312|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + ($2<<2)|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58 >>> 1;
 $60 = (($this) + 260|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($61) + ($59<<2)|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($this) + 180|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($65) + (($63*1048)|0)|0) + 1024|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = ($67<<24>>24)==(0);
 if ($68) {
  $69 = $59 & 31;
  $70 = 1 << $69;
  $71 = $58 >>> 6;
  $72 = (($this) + 268|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($73) + ($71<<2)|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = $75 | $70;
  HEAP32[$74>>2] = $76;
 }
 $77 = (($this) + 252|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + ($59)|0);
 $80 = HEAP8[$79>>0]|0;
 $81 = (($80) + -1)<<24>>24;
 HEAP8[$79>>0] = $81;
 $82 = ($80&255)>(1);
 if ($82) {
  $$0$i = 0;
 } else {
  $83 = $59 & 31;
  $84 = 1 << $83;
  $85 = $58 >>> 6;
  $86 = (($this) + 280|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (($87) + ($85<<2)|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = $89 | $84;
  HEAP32[$88>>2] = $90;
  $$0$i = 1;
 }
 $91 = ((($65) + (($63*1048)|0)|0) + 1026|0);
 $92 = HEAP8[$91>>0]|0;
 $93 = (($92) + -1)<<24>>24;
 HEAP8[$91>>0] = $93;
 $94 = $63 >>> 5;
 $95 = (($this) + 356|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (($96) + ($94<<2)|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = $63 & 31;
 $100 = 1 << $99;
 $101 = $98 & $100;
 $102 = ($101|0)==(0);
 if ($102) {
  $103 = $98 | $100;
  HEAP32[$97>>2] = $103;
 }
 $104 = (($this) + 308|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($105) + ($2<<2)|0);
 HEAP32[$106>>2] = 1073741823;
 $107 = (($this) + 320|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($108) + ($2<<2)|0);
 HEAP32[$109>>2] = 1073741823;
 $110 = ((($65) + (($63*1048)|0)|0) + 1032|0);
 $headId$04 = HEAP32[$110>>2]|0;
 $111 = ($headId$04|0)==($2|0);
 if ($111) {
  $internalIndex$0$lcssa = -1;
 } else {
  $112 = (($this) + 316|0);
  $113 = HEAP32[$112>>2]|0;
  $headId$06 = $headId$04;$internalIndex$05 = 0;
  while(1) {
   $114 = (($internalIndex$05) + 1)|0;
   $115 = (($113) + ($headId$06<<2)|0);
   $headId$0 = HEAP32[$115>>2]|0;
   $116 = ($headId$0|0)==($2|0);
   if ($116) {
    break;
   } else {
    $headId$06 = $headId$0;$internalIndex$05 = $114;
   }
  }
  $phitmp = (-2 - ($internalIndex$05))|0;
  $internalIndex$0$lcssa = $phitmp;
 }
 $117 = ((($65) + (($63*1048)|0)|0) + 1025|0);
 $118 = HEAP8[$117>>0]|0;
 $119 = $118&255;
 $120 = (($internalIndex$0$lcssa) + ($119))|0;
 $121 = (($this) + 184|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = $120 & 31;
 $124 = 1 << $123;
 $125 = $120 >>> 5;
 $126 = ((($122) + ($63<<4)|0) + ($125<<2)|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = $124 | $127;
 HEAP32[$126>>2] = $128;
 $129 = HEAP8[$91>>0]|0;
 $130 = ($129<<24>>24)==(0);
 if (!($130)) {
  $removingLastShape$0$off0 = $$0$i;
  STACKTOP = sp;return ($removingLastShape$0$off0|0);
 }
 $131 = ((($65) + (($63*1048)|0)|0) + 1028|0);
 $132 = HEAP32[$131>>2]|0;
 __ZN5physx14PxsAABBManager19purgeAggregatePairsEj($this,$132);
 $133 = HEAP32[$95>>2]|0;
 $134 = (($133) + ($94<<2)|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = $135 & $100;
 $137 = ($136|0)==(0);
 if (!($137)) {
  $138 = $100 ^ -1;
  $139 = $135 & $138;
  HEAP32[$134>>2] = $139;
 }
 $140 = $132 >>> 5;
 $141 = (($this) + 68|0);
 $142 = HEAP32[$141>>2]|0;
 $143 = (($142) + ($140<<2)|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = $132 & 31;
 $146 = 1 << $145;
 $147 = $144 & $146;
 $148 = ($147|0)==(0);
 if (!($148)) {
  $149 = $146 ^ -1;
  $150 = $144 & $149;
  HEAP32[$143>>2] = $150;
 }
 $151 = (($this) + 96|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = (($152) + ($140<<2)|0);
 $154 = HEAP32[$153>>2]|0;
 $155 = $154 & $146;
 $156 = ($155|0)==(0);
 if ($156) {
  $159 = (($this) + 124|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = (($160) + ($140<<2)|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = $162 | $146;
  HEAP32[$161>>2] = $163;
 } else {
  $157 = $146 ^ -1;
  $158 = $154 & $157;
  HEAP32[$153>>2] = $158;
 }
 $164 = HEAP32[$110>>2]|0;
 $165 = ($164|0)==(1073741823);
 if (!($165)) {
  $166 = (($this) + 316|0);
  $167 = (($this) + 300|0);
  $168 = (($this) + 304|0);
  $169 = (($this) + 328|0);
  $170 = (($this) + 340|0);
  $171 = (($this) + 332|0);
  $172 = (($this) + 352|0);
  $173 = (($this) + 344|0);
  $$pre = HEAP32[$166>>2]|0;
  $$pre10 = HEAP32[$107>>2]|0;
  $175 = $$pre;$178 = $$pre10;$elemId$03 = $164;
  while(1) {
   $174 = (($175) + ($elemId$03<<2)|0);
   $176 = HEAP32[$174>>2]|0;
   $177 = (($178) + ($elemId$03<<2)|0);
   $179 = HEAP32[$177>>2]|0;
   $180 = ($179|0)==(1073741823);
   do {
    if (!($180)) {
     $181 = HEAP32[$104>>2]|0;
     $182 = (($181) + ($elemId$03<<2)|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = ($183|0)==(0);
     if ($184) {
      $185 = HEAP32[$170>>2]|0;
      $186 = HEAP32[$171>>2]|0;
      $187 = (($186) + ($179<<3)|0);
      $$c$i$i = $185;
      HEAP32[$187>>2] = $$c$i$i;
      HEAP32[$170>>2] = $179;
      break;
     } else {
      $188 = HEAP32[$172>>2]|0;
      $189 = HEAP32[$173>>2]|0;
      $190 = (($189) + ($179<<4)|0);
      $$c$i1$i = $188;
      HEAP32[$190>>2] = $$c$i1$i;
      HEAP32[$172>>2] = $179;
      break;
     }
    }
   } while(0);
   $191 = HEAP32[$167>>2]|0;
   $192 = ((($191) + (($elemId$03*24)|0)|0) + 8|0);
   HEAP32[$192>>2] = -8388609;
   $193 = ((($191) + (($elemId$03*24)|0)|0) + 4|0);
   HEAP32[$193>>2] = -8388609;
   $194 = (($191) + (($elemId$03*24)|0)|0);
   HEAP32[$194>>2] = -8388609;
   $195 = ((($191) + (($elemId$03*24)|0)|0) + 20|0);
   HEAP32[$195>>2] = 8388608;
   $196 = ((($191) + (($elemId$03*24)|0)|0) + 16|0);
   HEAP32[$196>>2] = 8388608;
   $197 = ((($191) + (($elemId$03*24)|0)|0) + 12|0);
   HEAP32[$197>>2] = 8388608;
   $198 = HEAP32[$168>>2]|0;
   $199 = (($198) + ($elemId$03<<2)|0);
   HEAP32[$199>>2] = 0;
   $200 = HEAP32[$104>>2]|0;
   $201 = (($200) + ($elemId$03<<2)|0);
   HEAP32[$201>>2] = 1073741823;
   $202 = HEAP32[$55>>2]|0;
   $203 = (($202) + ($elemId$03<<2)|0);
   HEAP32[$203>>2] = 1073741823;
   $204 = HEAP32[$107>>2]|0;
   $205 = (($204) + ($elemId$03<<2)|0);
   HEAP32[$205>>2] = 1073741823;
   $206 = HEAP32[$166>>2]|0;
   $207 = (($206) + ($elemId$03<<2)|0);
   HEAP32[$207>>2] = 1073741823;
   $208 = HEAP32[$169>>2]|0;
   HEAP32[$201>>2] = $208;
   HEAP32[$169>>2] = $elemId$03;
   $209 = ($176|0)==(1073741823);
   if ($209) {
    break;
   } else {
    $175 = $206;$178 = $204;$elemId$03 = $176;
   }
  }
 }
 $210 = HEAP32[$64>>2]|0;
 $211 = ((($210) + (($63*1048)|0)|0) + 1024|0);
 HEAP8[$211>>0] = 1;
 $212 = ((($210) + (($63*1048)|0)|0) + 1025|0);
 HEAP8[$212>>0] = 0;
 $213 = ((($210) + (($63*1048)|0)|0) + 1026|0);
 HEAP8[$213>>0] = 0;
 $214 = ((($210) + (($63*1048)|0)|0) + 1028|0);
 HEAP32[$214>>2] = 1073741823;
 $215 = ((($210) + (($63*1048)|0)|0) + 1032|0);
 HEAP32[$215>>2] = 1073741823;
 $216 = ((($210) + (($63*1048)|0)|0) + 1044|0);
 HEAP32[$216>>2] = 0;
 $217 = $100 ^ -1;
 $218 = (($this) + 220|0);
 $219 = HEAP32[$218>>2]|0;
 $220 = (($219) + ($94<<2)|0);
 $221 = HEAP32[$220>>2]|0;
 $222 = $221 & $217;
 HEAP32[$220>>2] = $222;
 $223 = (($this) + 232|0);
 $224 = HEAP32[$223>>2]|0;
 $225 = (($224) + ($94<<2)|0);
 $226 = HEAP32[$225>>2]|0;
 $227 = $226 & $217;
 HEAP32[$225>>2] = $227;
 $228 = HEAP32[$121>>2]|0;
 $229 = (($228) + ($63<<4)|0);
 ;HEAP32[$229+0>>2]=0|0;HEAP32[$229+4>>2]=0|0;HEAP32[$229+8>>2]=0|0;HEAP32[$229+12>>2]=0|0;
 $230 = (($this) + 188|0);
 $231 = HEAP32[$230>>2]|0;
 $232 = (($231) + ($63<<4)|0);
 ;HEAP32[$232+0>>2]=0|0;HEAP32[$232+4>>2]=0|0;HEAP32[$232+8>>2]=0|0;HEAP32[$232+12>>2]=0|0;
 $removingLastShape$0$off0 = $$0$i;
 STACKTOP = sp;return ($removingLastShape$0$off0|0);
}
function __ZN5physx14PxsAABBManager19purgeAggregatePairsEj($this,$bpElemId) {
 $this = $this|0;
 $bpElemId = $bpElemId|0;
 var $$in = 0, $$in3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$ph2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 49860|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 49856|0);
 $$in = $2;$i$0$ph2 = 0;
 L4: while(1) {
  $$in3 = $$in;
  while(1) {
   $5 = (($$in3) + -1)|0;
   $6 = HEAP32[$4>>2]|0;
   $7 = (($6) + (($i$0$ph2*12)|0)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==($bpElemId|0);
   if (!($9)) {
    $10 = ((($6) + (($i$0$ph2*12)|0)|0) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==($bpElemId|0);
    if (!($12)) {
     break;
    }
   }
   $13 = ((($6) + (($i$0$ph2*12)|0)|0) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    $25 = $6;
   } else {
    $16 = HEAP32[$14>>2]|0;
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = (($14) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)>(-1);
     if ($20) {
      $21 = (($14) + 8|0);
      __ZN5physx6shdfnd9Allocator10deallocateEPv($21,$16);
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$14);
    $22 = HEAP32[$4>>2]|0;
    $23 = ((($22) + (($i$0$ph2*12)|0)|0) + 8|0);
    HEAP32[$23>>2] = 0;
    $$pre = HEAP32[$4>>2]|0;
    $25 = $$pre;
   }
   $24 = (($25) + (($i$0$ph2*12)|0)|0);
   $26 = HEAP32[$1>>2]|0;
   $27 = (($26) + -1)|0;
   HEAP32[$1>>2] = $27;
   $28 = (($25) + (($27*12)|0)|0);
   ;HEAP32[$24+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$28+8>>2]|0;
   $29 = ($5|0)==(0);
   if ($29) {
    label = 13;
    break L4;
   } else {
    $$in3 = $5;
   }
  }
  $30 = (($i$0$ph2) + 1)|0;
  $31 = ($5|0)==(0);
  if ($31) {
   label = 13;
   break;
  } else {
   $$in = $5;$i$0$ph2 = $30;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx14PxsAABBManager15setVolumeBoundsEjRKNS_9PxBounds3E($this,$shapeHandle,$bounds) {
 $this = $this|0;
 $shapeHandle = $shapeHandle|0;
 $bounds = $bounds|0;
 var $$0$i$i$i = 0, $$0$i$i1$i = 0, $$0$i$i2$i = 0, $$0$i$i3$i = 0, $$0$i$i4$i = 0, $$0$i$i5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bounds) + 12|0);
 $1 = HEAP32[$bounds>>2]|0;
 $2 = ($1|0)<(0);
 $3 = $1 ^ -1;
 $4 = $1 | -2147483648;
 $$0$i$i5$i = $2 ? $3 : $4;
 $5 = (($$0$i$i5$i) + -16)|0;
 $6 = $5 & -16;
 $7 = (($bounds) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)<(0);
 $10 = $8 ^ -1;
 $11 = $8 | -2147483648;
 $$0$i$i4$i = $9 ? $10 : $11;
 $12 = (($$0$i$i4$i) + -16)|0;
 $13 = $12 & -16;
 $14 = (($bounds) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)<(0);
 $17 = $15 ^ -1;
 $18 = $15 | -2147483648;
 $$0$i$i3$i = $16 ? $17 : $18;
 $19 = (($$0$i$i3$i) + -16)|0;
 $20 = $19 & -16;
 $21 = HEAP32[$0>>2]|0;
 $22 = ($21|0)<(0);
 $23 = $21 ^ -1;
 $24 = $21 | -2147483648;
 $$0$i$i2$i = $22 ? $23 : $24;
 $25 = (($$0$i$i2$i) + 16)|0;
 $26 = $25 & -16;
 $27 = $26 | 1;
 $28 = (($0) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)<(0);
 $31 = $29 ^ -1;
 $32 = $29 | -2147483648;
 $$0$i$i1$i = $30 ? $31 : $32;
 $33 = (($$0$i$i1$i) + 16)|0;
 $34 = $33 & -16;
 $35 = $34 | 1;
 $36 = (($0) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)<(0);
 $39 = $37 ^ -1;
 $40 = $37 | -2147483648;
 $$0$i$i$i = $38 ? $39 : $40;
 $41 = (($$0$i$i$i) + 16)|0;
 $42 = $41 & -16;
 $43 = $42 | 1;
 $44 = $shapeHandle & 1;
 $45 = ($44|0)==(0);
 $46 = $shapeHandle >>> 1;
 if (!($45)) {
  $71 = (($this) + 300|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + (($46*24)|0)|0);
  HEAP32[$73>>2] = $6;
  $74 = ((($72) + (($46*24)|0)|0) + 4|0);
  HEAP32[$74>>2] = $13;
  $75 = ((($72) + (($46*24)|0)|0) + 8|0);
  HEAP32[$75>>2] = $20;
  $76 = ((($72) + (($46*24)|0)|0) + 12|0);
  HEAP32[$76>>2] = $27;
  $77 = ((($72) + (($46*24)|0)|0) + 16|0);
  HEAP32[$77>>2] = $35;
  $78 = ((($72) + (($46*24)|0)|0) + 20|0);
  HEAP32[$78>>2] = $43;
  $79 = (($this) + 312|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($80) + ($46<<2)|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = $82 >>> 1;
  $84 = (($this) + 260|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($85) + ($83<<2)|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = $87 >>> 5;
  $89 = (($this) + 356|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($90) + ($88<<2)|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = $87 & 31;
  $94 = 1 << $93;
  $95 = $92 & $94;
  $96 = ($95|0)==(0);
  if (!($96)) {
   STACKTOP = sp;return;
  }
  $97 = $92 | $94;
  HEAP32[$91>>2] = $97;
  STACKTOP = sp;return;
 }
 $47 = (($this) + 12|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + (($46*24)|0)|0);
 HEAP32[$49>>2] = $6;
 $50 = ((($48) + (($46*24)|0)|0) + 4|0);
 HEAP32[$50>>2] = $13;
 $51 = ((($48) + (($46*24)|0)|0) + 8|0);
 HEAP32[$51>>2] = $20;
 $52 = ((($48) + (($46*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = $27;
 $53 = ((($48) + (($46*24)|0)|0) + 16|0);
 HEAP32[$53>>2] = $35;
 $54 = ((($48) + (($46*24)|0)|0) + 20|0);
 HEAP32[$54>>2] = $43;
 $55 = $shapeHandle >>> 6;
 $56 = (($this) + 96|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($55<<2)|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = $46 & 31;
 $61 = 1 << $60;
 $62 = $59 & $61;
 $63 = ($62|0)==(0);
 if (!($63)) {
  STACKTOP = sp;return;
 }
 $64 = (($this) + 68|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + ($55<<2)|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = $67 & $61;
 $69 = ($68|0)==(0);
 if (!($69)) {
  STACKTOP = sp;return;
 }
 $70 = $67 | $61;
 HEAP32[$66>>2] = $70;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager13setActorDirtyEj($this,$actorHandle) {
 $this = $this|0;
 $actorHandle = $actorHandle|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $actorHandle & 1;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = $actorHandle >>> 1;
 $3 = (($this) + 260|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($2<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 180|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8) + (($6*1048)|0)|0) + 1024|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = $2 & 31;
 $13 = 1 << $12;
 $14 = $actorHandle >>> 6;
 $15 = (($this) + 268|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14<<2)|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 | $13;
 HEAP32[$17>>2] = $19;
 STACKTOP = sp;return;
}
function __ZNK5physx14PxsAABBManager11getBPBoundsEj($agg$result,$this,$shapeHandle) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $shapeHandle = $shapeHandle|0;
 var $$0$i$i = 0, $$0$i1$i = 0, $$0$i2$i = 0, $$0$i3$i = 0, $$0$i4$i = 0, $$0$i5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($shapeHandle*24)|0)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1) + (($shapeHandle*24)|0)|0) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1) + (($shapeHandle*24)|0)|0) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1) + (($shapeHandle*24)|0)|0) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($1) + (($shapeHandle*24)|0)|0) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($1) + (($shapeHandle*24)|0)|0) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($agg$result) + 12|0);
 $15 = ($3|0)<(0);
 $16 = $3 & 2147483647;
 $17 = $3 ^ -1;
 $$0$i5$i = $15 ? $16 : $17;
 HEAP32[$agg$result>>2] = $$0$i5$i;
 $18 = ($5|0)<(0);
 $19 = $5 & 2147483647;
 $20 = $5 ^ -1;
 $$0$i4$i = $18 ? $19 : $20;
 $21 = (($agg$result) + 4|0);
 HEAP32[$21>>2] = $$0$i4$i;
 $22 = ($7|0)<(0);
 $23 = $7 & 2147483647;
 $24 = $7 ^ -1;
 $$0$i3$i = $22 ? $23 : $24;
 $25 = (($agg$result) + 8|0);
 HEAP32[$25>>2] = $$0$i3$i;
 $26 = ($9|0)<(0);
 $27 = $9 & 2147483647;
 $28 = $9 ^ -1;
 $$0$i2$i = $26 ? $27 : $28;
 HEAP32[$14>>2] = $$0$i2$i;
 $29 = ($11|0)<(0);
 $30 = $11 & 2147483647;
 $31 = $11 ^ -1;
 $$0$i1$i = $29 ? $30 : $31;
 $32 = (($14) + 4|0);
 HEAP32[$32>>2] = $$0$i1$i;
 $33 = ($13|0)<(0);
 $34 = $13 & 2147483647;
 $35 = $13 ^ -1;
 $$0$i$i = $33 ? $34 : $35;
 $36 = (($14) + 8|0);
 HEAP32[$36>>2] = $$0$i$i;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager16updateAABBsAndBPEjjjPNS_10PxBaseTaskEPjjbPi($this,$numCpuTasks,$numSpusAABB,$numSpusBP,$continuation,$changedActorWords,$changedActorWordCount,$secondBroadPhase,$numFastMovingShapes) {
 $this = $this|0;
 $numCpuTasks = $numCpuTasks|0;
 $numSpusAABB = $numSpusAABB|0;
 $numSpusBP = $numSpusBP|0;
 $continuation = $continuation|0;
 $changedActorWords = $changedActorWords|0;
 $changedActorWordCount = $changedActorWordCount|0;
 $secondBroadPhase = $secondBroadPhase|0;
 $numFastMovingShapes = $numFastMovingShapes|0;
 var $$c$i$i = 0, $$c$i1$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre$i4 = 0, $$pre$i6 = 0, $$pre$i9 = 0, $$pre$phi$i2Z2D = 0, $$pre$phi$i5Z2D = 0, $$pre$phi$i7Z2D = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$010 = 0, $params = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $params = sp;
 HEAP32[$params>>2] = $numCpuTasks;
 $1 = (($params) + 4|0);
 HEAP32[$1>>2] = $numSpusAABB;
 $2 = (($params) + 8|0);
 HEAP32[$2>>2] = $numSpusBP;
 $3 = (($params) + 12|0);
 $4 = $secondBroadPhase&1;
 HEAP8[$3>>0] = $4;
 $5 = (($params) + 16|0);
 HEAP32[$5>>2] = $numFastMovingShapes;
 $6 = (($this) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7>>>0)>(4096);
  do {
   if ($9) {
    $10 = $7 << 2;
    $11 = (($10) + 15)|0;
    $12 = $11 & -16;
    $13 = (($this) + 16896|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     $18 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$12,481512,1936)|0);
     $19 = (($this) + 16900|0);
     HEAP32[$19>>2] = $18;
     $$pre$phi$iZ2D = $10;$22 = $18;
     break;
    } else {
     $16 = (__ZN5physx19PxcScratchAllocator5allocEjb($14,$12,1)|0);
     $17 = (($this) + 16900|0);
     HEAP32[$17>>2] = $16;
     $$pre$phi$iZ2D = $10;$22 = $16;
     break;
    }
   } else {
    $20 = (($this) + 512|0);
    $21 = (($this) + 16900|0);
    HEAP32[$21>>2] = $20;
    $$pre$i = $7 << 2;
    $$pre$phi$iZ2D = $$pre$i;$22 = $20;
   }
  } while(0);
  _memset(($22|0),0,($$pre$phi$iZ2D|0))|0;
  $23 = (($this) + 16904|0);
  HEAP32[$23>>2] = $7;
 }
 $24 = (($this) + 16912|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 324|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0);
 if (!($27)) {
  $28 = ($26>>>0)>(4096);
  do {
   if ($28) {
    $29 = $26 << 2;
    $30 = (($29) + 15)|0;
    $31 = $30 & -16;
    $32 = (($this) + 33312|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     $37 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$31,481512,1936)|0);
     $38 = (($this) + 33316|0);
     HEAP32[$38>>2] = $37;
     $$pre$phi$i2Z2D = $29;$41 = $37;
     break;
    } else {
     $35 = (__ZN5physx19PxcScratchAllocator5allocEjb($33,$31,1)|0);
     $36 = (($this) + 33316|0);
     HEAP32[$36>>2] = $35;
     $$pre$phi$i2Z2D = $29;$41 = $35;
     break;
    }
   } else {
    $39 = (($this) + 16928|0);
    $40 = (($this) + 33316|0);
    HEAP32[$40>>2] = $39;
    $$pre$i1 = $26 << 2;
    $$pre$phi$i2Z2D = $$pre$i1;$41 = $39;
   }
  } while(0);
  _memset(($41|0),0,($$pre$phi$i2Z2D|0))|0;
  $42 = (($this) + 33320|0);
  HEAP32[$42>>2] = $26;
 }
 $43 = (($this) + 33328|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 264|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = ($45>>>0)>(1024);
  do {
   if ($47) {
    $48 = $45 << 2;
    $49 = (($48) + 15)|0;
    $50 = $49 & -16;
    $51 = (($this) + 37440|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==(0|0);
    if ($53) {
     $56 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$50,481512,1936)|0);
     $57 = (($this) + 37444|0);
     HEAP32[$57>>2] = $56;
     $$pre$phi$i5Z2D = $48;$60 = $56;
     break;
    } else {
     $54 = (__ZN5physx19PxcScratchAllocator5allocEjb($52,$50,1)|0);
     $55 = (($this) + 37444|0);
     HEAP32[$55>>2] = $54;
     $$pre$phi$i5Z2D = $48;$60 = $54;
     break;
    }
   } else {
    $58 = (($this) + 33344|0);
    $59 = (($this) + 37444|0);
    HEAP32[$59>>2] = $58;
    $$pre$i4 = $45 << 2;
    $$pre$phi$i5Z2D = $$pre$i4;$60 = $58;
   }
  } while(0);
  _memset(($60|0),0,($$pre$phi$i5Z2D|0))|0;
  $61 = (($this) + 37448|0);
  HEAP32[$61>>2] = $45;
 }
 $62 = (($this) + 196|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0);
 if (!($64)) {
  $65 = ($63>>>0)>(1024);
  do {
   if ($65) {
    $66 = $63 << 2;
    $67 = (($66) + 15)|0;
    $68 = $67 & -16;
    $69 = (($this) + 41552|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==(0|0);
    if ($71) {
     $74 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$68,481512,1936)|0);
     $75 = (($this) + 41556|0);
     HEAP32[$75>>2] = $74;
     $$pre$phi$i7Z2D = $66;$78 = $74;
     break;
    } else {
     $72 = (__ZN5physx19PxcScratchAllocator5allocEjb($70,$68,1)|0);
     $73 = (($this) + 41556|0);
     HEAP32[$73>>2] = $72;
     $$pre$phi$i7Z2D = $66;$78 = $72;
     break;
    }
   } else {
    $76 = (($this) + 37456|0);
    $77 = (($this) + 41556|0);
    HEAP32[$77>>2] = $76;
    $$pre$i6 = $63 << 2;
    $$pre$phi$i7Z2D = $$pre$i6;$78 = $76;
   }
  } while(0);
  _memset(($78|0),0,($$pre$phi$i7Z2D|0))|0;
  $79 = (($this) + 41560|0);
  HEAP32[$79>>2] = $63;
 }
 $80 = (($this) + 41568|0);
 HEAP32[$80>>2] = 0;
 __ZN5physx14PxsAABBManager22computeAABBUpdateListsEPjjRKNS_20PxsComputeAABBParamsE($this,$changedActorWords,$changedActorWordCount,$params);
 __ZN5physx14PxsAABBManager31removeEmptyActorsFromAggregatesEv($this);
 $81 = (($this) + 280|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($this) + 284|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = $84 << 2;
 _memset(($82|0),0,($85|0))|0;
 $86 = (($this) + 136|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($this) + 140|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($89|0)==(0);
 if (!($90)) {
  $91 = (($this) + 32|0);
  $$pre$i9 = (($this) + 20|0);
  $92 = (($this) + 12|0);
  $93 = (($this) + 16|0);
  $94 = (($this) + 24|0);
  $95 = (($this) + 28|0);
  $96 = (($this) + 40|0);
  $97 = (($this) + 52|0);
  $98 = (($this) + 44|0);
  $99 = (($this) + 64|0);
  $100 = (($this) + 56|0);
  $$pre = HEAP32[$91>>2]|0;
  $104 = $$pre;$i$010 = 0;
  while(1) {
   $101 = (($87) + ($i$010<<2)|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($104) + ($102<<2)|0);
   $105 = HEAP32[$103>>2]|0;
   $106 = ($105|0)==(1073741823);
   do {
    if (!($106)) {
     $107 = HEAP32[$$pre$i9>>2]|0;
     $108 = (($107) + ($102<<2)|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = ($109|0)==(0);
     if ($110) {
      $111 = HEAP32[$97>>2]|0;
      $112 = HEAP32[$98>>2]|0;
      $113 = (($112) + ($105<<3)|0);
      $$c$i$i = $111;
      HEAP32[$113>>2] = $$c$i$i;
      HEAP32[$97>>2] = $105;
      break;
     } else {
      $114 = HEAP32[$99>>2]|0;
      $115 = HEAP32[$100>>2]|0;
      $116 = (($115) + ($105<<4)|0);
      $$c$i1$i = $114;
      HEAP32[$116>>2] = $$c$i1$i;
      HEAP32[$99>>2] = $105;
      break;
     }
    }
   } while(0);
   $117 = HEAP32[$92>>2]|0;
   $118 = ((($117) + (($102*24)|0)|0) + 8|0);
   HEAP32[$118>>2] = -8388609;
   $119 = ((($117) + (($102*24)|0)|0) + 4|0);
   HEAP32[$119>>2] = -8388609;
   $120 = (($117) + (($102*24)|0)|0);
   HEAP32[$120>>2] = -8388609;
   $121 = ((($117) + (($102*24)|0)|0) + 20|0);
   HEAP32[$121>>2] = 8388608;
   $122 = ((($117) + (($102*24)|0)|0) + 16|0);
   HEAP32[$122>>2] = 8388608;
   $123 = ((($117) + (($102*24)|0)|0) + 12|0);
   HEAP32[$123>>2] = 8388608;
   $124 = HEAP32[$93>>2]|0;
   $125 = (($124) + ($102<<2)|0);
   HEAP32[$125>>2] = 0;
   $126 = HEAP32[$$pre$i9>>2]|0;
   $127 = (($126) + ($102<<2)|0);
   HEAP32[$127>>2] = 1073741823;
   $128 = HEAP32[$94>>2]|0;
   $129 = (($128) + ($102<<2)|0);
   HEAP32[$129>>2] = 1073741823;
   $130 = HEAP32[$91>>2]|0;
   $131 = (($130) + ($102<<2)|0);
   HEAP32[$131>>2] = 1073741823;
   $132 = HEAP32[$95>>2]|0;
   $133 = (($132) + ($102<<2)|0);
   HEAP32[$133>>2] = 1073741823;
   $134 = HEAP32[$96>>2]|0;
   HEAP32[$127>>2] = $134;
   HEAP32[$96>>2] = $102;
   $135 = (($i$010) + 1)|0;
   $exitcond = ($135|0)==($89|0);
   if ($exitcond) {
    break;
   } else {
    $104 = $130;$i$010 = $135;
   }
  }
 }
 $136 = (($this) + 49868|0);
 $137 = (($this) + 49888|0);
 HEAP32[$137>>2] = 3;
 $138 = (($this) + 51100|0);
 $139 = (($this) + 51120|0);
 HEAP32[$139>>2] = 2;
 $140 = (($this) + 51556|0);
 $141 = (($this) + 51596|0);
 HEAP32[$141>>2] = $this;
 $142 = (($this) + 51124|0);
 HEAP32[$142>>2] = $this;
 $143 = (($this) + 51056|0);
 $144 = (($this) + 51096|0);
 HEAP32[$144>>2] = $this;
 $145 = (($this) + 51012|0);
 $146 = (($this) + 51032|0);
 HEAP32[$146>>2] = $this;
 $147 = (($this) + 50608|0);
 $148 = (($this) + 50628|0);
 HEAP32[$148>>2] = $this;
 $149 = (($this) + 49892|0);
 HEAP32[$149>>2] = $this;
 $150 = (($this) + 50324|0);
 $151 = (($this) + 50344|0);
 HEAP32[$151>>2] = $this;
 $152 = (($this) + 51576|0);
 ;HEAP32[$152+0>>2]=HEAP32[$params+0>>2]|0;HEAP32[$152+4>>2]=HEAP32[$params+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$params+8>>2]|0;HEAP32[$152+12>>2]=HEAP32[$params+12>>2]|0;HEAP32[$152+16>>2]=HEAP32[$params+16>>2]|0;
 $153 = (($this) + 51128|0);
 ;HEAP32[$153+0>>2]=HEAP32[$params+0>>2]|0;HEAP32[$153+4>>2]=HEAP32[$params+4>>2]|0;HEAP32[$153+8>>2]=HEAP32[$params+8>>2]|0;HEAP32[$153+12>>2]=HEAP32[$params+12>>2]|0;HEAP32[$153+16>>2]=HEAP32[$params+16>>2]|0;
 $154 = (($this) + 51076|0);
 ;HEAP32[$154+0>>2]=HEAP32[$params+0>>2]|0;HEAP32[$154+4>>2]=HEAP32[$params+4>>2]|0;HEAP32[$154+8>>2]=HEAP32[$params+8>>2]|0;HEAP32[$154+12>>2]=HEAP32[$params+12>>2]|0;HEAP32[$154+16>>2]=HEAP32[$params+16>>2]|0;
 $155 = (($this) + 51036|0);
 ;HEAP32[$155+0>>2]=HEAP32[$params+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$params+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$params+8>>2]|0;HEAP32[$155+12>>2]=HEAP32[$params+12>>2]|0;HEAP32[$155+16>>2]=HEAP32[$params+16>>2]|0;
 $156 = (($this) + 50632|0);
 ;HEAP32[$156+0>>2]=HEAP32[$params+0>>2]|0;HEAP32[$156+4>>2]=HEAP32[$params+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$params+8>>2]|0;HEAP32[$156+12>>2]=HEAP32[$params+12>>2]|0;HEAP32[$156+16>>2]=HEAP32[$params+16>>2]|0;
 $157 = (($this) + 49896|0);
 ;HEAP32[$157+0>>2]=HEAP32[$params+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$params+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$params+8>>2]|0;HEAP32[$157+12>>2]=HEAP32[$params+12>>2]|0;HEAP32[$157+16>>2]=HEAP32[$params+16>>2]|0;
 $158 = (($this) + 50348|0);
 ;HEAP32[$158+0>>2]=HEAP32[$params+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$params+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$params+8>>2]|0;HEAP32[$158+12>>2]=HEAP32[$params+12>>2]|0;HEAP32[$158+16>>2]=HEAP32[$params+16>>2]|0;
 $159 = (($this) + 51572|0);
 HEAP32[$159>>2] = 1;
 $160 = (($this) + 51568|0);
 HEAP32[$160>>2] = $continuation;
 $161 = ($continuation|0)==(0|0);
 if (!($161)) {
  $162 = HEAP32[$continuation>>2]|0;
  $163 = (($162) + 16|0);
  $164 = HEAP32[$163>>2]|0;
  FUNCTION_TABLE_vi[$164 & 4095]($continuation);
  $165 = HEAP32[$160>>2]|0;
  $166 = (($165) + 8|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = (($this) + 51564|0);
  HEAP32[$168>>2] = $167;
 }
 $169 = (($this) + 51116|0);
 HEAP32[$169>>2] = 1;
 $170 = (($this) + 51112|0);
 HEAP32[$170>>2] = $140;
 $171 = HEAP32[$140>>2]|0;
 $172 = (($171) + 16|0);
 $173 = HEAP32[$172>>2]|0;
 FUNCTION_TABLE_vi[$173 & 4095]($140);
 $174 = HEAP32[$170>>2]|0;
 $175 = (($174) + 8|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = (($this) + 51108|0);
 HEAP32[$177>>2] = $176;
 $178 = (($this) + 51072|0);
 HEAP32[$178>>2] = 1;
 $179 = (($this) + 51068|0);
 HEAP32[$179>>2] = $138;
 $180 = HEAP32[$138>>2]|0;
 $181 = (($180) + 16|0);
 $182 = HEAP32[$181>>2]|0;
 FUNCTION_TABLE_vi[$182 & 4095]($138);
 $183 = HEAP32[$179>>2]|0;
 $184 = (($183) + 8|0);
 $185 = HEAP32[$184>>2]|0;
 $186 = (($this) + 51064|0);
 HEAP32[$186>>2] = $185;
 $187 = (($this) + 51028|0);
 HEAP32[$187>>2] = 1;
 $188 = (($this) + 51024|0);
 HEAP32[$188>>2] = $143;
 $189 = HEAP32[$143>>2]|0;
 $190 = (($189) + 16|0);
 $191 = HEAP32[$190>>2]|0;
 FUNCTION_TABLE_vi[$191 & 4095]($143);
 $192 = HEAP32[$188>>2]|0;
 $193 = (($192) + 8|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = (($this) + 51020|0);
 HEAP32[$195>>2] = $194;
 $196 = (($this) + 50624|0);
 HEAP32[$196>>2] = 1;
 $197 = (($this) + 50620|0);
 HEAP32[$197>>2] = $145;
 $198 = HEAP32[$145>>2]|0;
 $199 = (($198) + 16|0);
 $200 = HEAP32[$199>>2]|0;
 FUNCTION_TABLE_vi[$200 & 4095]($145);
 $201 = HEAP32[$197>>2]|0;
 $202 = (($201) + 8|0);
 $203 = HEAP32[$202>>2]|0;
 $204 = (($this) + 50616|0);
 HEAP32[$204>>2] = $203;
 $205 = (($this) + 49884|0);
 HEAP32[$205>>2] = 1;
 $206 = (($this) + 49880|0);
 HEAP32[$206>>2] = $147;
 $207 = HEAP32[$147>>2]|0;
 $208 = (($207) + 16|0);
 $209 = HEAP32[$208>>2]|0;
 FUNCTION_TABLE_vi[$209 & 4095]($147);
 $210 = HEAP32[$206>>2]|0;
 $211 = (($210) + 8|0);
 $212 = HEAP32[$211>>2]|0;
 $213 = (($this) + 49876|0);
 HEAP32[$213>>2] = $212;
 $214 = (($this) + 50340|0);
 HEAP32[$214>>2] = 1;
 $215 = (($this) + 50336|0);
 HEAP32[$215>>2] = $136;
 $216 = HEAP32[$136>>2]|0;
 $217 = (($216) + 16|0);
 $218 = HEAP32[$217>>2]|0;
 FUNCTION_TABLE_vi[$218 & 4095]($136);
 $219 = HEAP32[$215>>2]|0;
 $220 = (($219) + 8|0);
 $221 = HEAP32[$220>>2]|0;
 $222 = (($this) + 50332|0);
 HEAP32[$222>>2] = $221;
 $223 = HEAP32[$140>>2]|0;
 $224 = (($223) + 20|0);
 $225 = HEAP32[$224>>2]|0;
 FUNCTION_TABLE_vi[$225 & 4095]($140);
 $226 = HEAP32[$138>>2]|0;
 $227 = (($226) + 20|0);
 $228 = HEAP32[$227>>2]|0;
 FUNCTION_TABLE_vi[$228 & 4095]($138);
 $229 = HEAP32[$143>>2]|0;
 $230 = (($229) + 20|0);
 $231 = HEAP32[$230>>2]|0;
 FUNCTION_TABLE_vi[$231 & 4095]($143);
 $232 = HEAP32[$145>>2]|0;
 $233 = (($232) + 20|0);
 $234 = HEAP32[$233>>2]|0;
 FUNCTION_TABLE_vi[$234 & 4095]($145);
 $235 = HEAP32[$147>>2]|0;
 $236 = (($235) + 20|0);
 $237 = HEAP32[$236>>2]|0;
 FUNCTION_TABLE_vi[$237 & 4095]($147);
 $238 = HEAP32[$136>>2]|0;
 $239 = (($238) + 20|0);
 $240 = HEAP32[$239>>2]|0;
 FUNCTION_TABLE_vi[$240 & 4095]($136);
 $241 = HEAP32[$150>>2]|0;
 $242 = (($241) + 20|0);
 $243 = HEAP32[$242>>2]|0;
 FUNCTION_TABLE_vi[$243 & 4095]($150);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager22computeAABBUpdateListsEPjjRKNS_20PxsComputeAABBParamsE($this,$changedActorWords,$changedActorWordCount,$params) {
 $this = $this|0;
 $changedActorWords = $changedActorWords|0;
 $changedActorWordCount = $changedActorWordCount|0;
 $params = $params|0;
 var $$ph33 = 0, $$ph34 = 0, $$ph35 = 0, $$ph36 = 0, $$ph39 = 0, $$ph51 = 0, $$ph53 = 0, $$ph54 = 0, $$ph5577 = 0, $$ph5678 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre104 = 0, $$pre113 = 0, $$pre114$pre = 0, $$pre115$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $AggregateUpdatedElemIdsSize$0$lcssa = 0, $AggregateUpdatedElemIdsSize$022 = 0, $AggregateUpdatedElemIdsSize$1$lcssa = 0, $AggregateUpdatedElemIdsSize$120 = 0, $AggregateUpdatedElemIdsSize$2 = 0, $AggregateUpdatedElemIdsSize$3 = 0, $BPUpdatedElemIdsSize$0$ph = 0, $BPUpdatedElemIdsSize$0$ph41 = 0, $BPUpdatedElemIdsSize$128 = 0, $BPUpdatedElemIdsSize$2 = 0, $NumDirtyActorAggregates$0$lcssa = 0, $NumDirtyActorAggregates$0$ph80 = 0, $NumDirtyActorAggregates$062 = 0, $NumDirtyActorAggregates$1 = 0, $NumDirtyActorAggregates$2 = 0, $changedActorsBitmap = 0;
 var $dirtyActorAggregatesBitmap = 0, $elemId$0 = 0, $elemId$019 = 0, $elemId$021 = 0, $exitcond = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$in$i = 0, $id$0 = 0, $id$027 = 0, $id$029 = 0, $index$0$ph5779 = 0, $index$061 = 0, $index2$0 = 0, $index2$0$ph = 0, $index2$0$ph37 = 0, $index2$0$ph40 = 0, $it$02$i$i = 0, $k$023 = 0, $or$cond$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 157|0;
 $1 = sp + 156|0;
 $dirtyActorAggregatesBitmap = sp;
 $changedActorsBitmap = sp + 144|0;
 $2 = (($this) + 268|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if (!($4)) {
   $5 = (($this) + 196|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$this>>2]|0;
   $8 = (($dirtyActorAggregatesBitmap) + 128|0);
   HEAP32[$8>>2] = $7;
   $9 = (($dirtyActorAggregatesBitmap) + 132|0);
   HEAP32[$9>>2] = 0;
   $10 = (($dirtyActorAggregatesBitmap) + 136|0);
   HEAP32[$10>>2] = 0;
   $11 = ($6|0)==(0);
   if (!($11)) {
    $12 = (($6) + 31)|0;
    $13 = $12 >>> 5;
    $14 = ($6>>>0)>(1024);
    do {
     if ($14) {
      $15 = $13 << 2;
      $16 = (($15) + 15)|0;
      $17 = $16 & 1073741808;
      $18 = ($7|0)==(0|0);
      if ($18) {
       $21 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$17,481512,2004)|0);
       HEAP32[$9>>2] = $21;
       $22 = $13 | -2147483648;
       HEAP32[$10>>2] = $22;
       $25 = $22;$26 = $21;
       break;
      } else {
       $19 = (__ZN5physx19PxcScratchAllocator5allocEjb($7,$17,1)|0);
       HEAP32[$9>>2] = $19;
       $20 = $13 | -2147483648;
       HEAP32[$10>>2] = $20;
       $25 = $20;$26 = $19;
       break;
      }
     } else {
      HEAP32[$9>>2] = $dirtyActorAggregatesBitmap;
      $23 = $13 | -2147483648;
      HEAP32[$10>>2] = $23;
      $25 = $23;$26 = $dirtyActorAggregatesBitmap;
     }
    } while(0);
    $24 = $25 << 2;
    _memset(($26|0),0,($24|0))|0;
   }
   $27 = (($this) + 41556|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($this) + 272|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $30 & 2147483647;
   $32 = ($31|0)==(0);
   L13: do {
    if ($32) {
     $NumDirtyActorAggregates$0$lcssa = 0;
    } else {
     $$pre$i$i$i = HEAP32[$2>>2]|0;
     $34 = 0;
     while(1) {
      $33 = (($$pre$i$i$i) + ($34<<2)|0);
      $35 = HEAP32[$33>>2]|0;
      $36 = ($35|0)==(0);
      if (!($36)) {
       break;
      }
      $37 = (($34) + 1)|0;
      $38 = ($37>>>0)<($31>>>0);
      if ($38) {
       $34 = $37;
      } else {
       $NumDirtyActorAggregates$0$lcssa = 0;
       break L13;
      }
     }
     $39 = $34 << 5;
     $40 = (0 - ($35))|0;
     $41 = $35 & $40;
     $42 = Math_imul($41, 125613361)|0;
     $43 = $42 >>> 27;
     $44 = (412480 + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = $45 | $39;
     $47 = (($35) + -1)|0;
     $48 = $47 & $35;
     $49 = ($48|0)==(0);
     L19: do {
      if ($49) {
       $51 = $34;
       while(1) {
        $50 = (($51) + 1)|0;
        $52 = ($50>>>0)<($31>>>0);
        if (!($52)) {
         $$ph53 = $50;$$ph54 = 0;
         break L19;
        }
        $53 = (($$pre$i$i$i) + ($50<<2)|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = ($54|0)==(0);
        if ($55) {
         $51 = $50;
        } else {
         $$ph53 = $50;$$ph54 = $54;
         break;
        }
       }
      } else {
       $$ph53 = $34;$$ph54 = $48;
      }
     } while(0);
     $56 = ($46|0)==(-1);
     if ($56) {
      $NumDirtyActorAggregates$0$lcssa = 0;
     } else {
      $57 = (($this) + 260|0);
      $58 = (($this) + 180|0);
      $59 = (($this) + 356|0);
      $60 = (($this) + 96|0);
      $61 = (($this) + 68|0);
      $$pre114$pre = HEAP32[$57>>2]|0;
      $$pre115$pre = HEAP32[$58>>2]|0;
      $$ph5577 = $$ph53;$$ph5678 = $$ph54;$NumDirtyActorAggregates$0$ph80 = 0;$index$0$ph5779 = $46;
      while(1) {
       $64 = $$ph5577 << 5;
       $104 = $$ph5678;$NumDirtyActorAggregates$062 = $NumDirtyActorAggregates$0$ph80;$index$061 = $index$0$ph5779;
       while(1) {
        $65 = (($$pre114$pre) + ($index$061<<2)|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = ((($$pre115$pre) + (($66*1048)|0)|0) + 1025|0);
        $68 = HEAP8[$67>>0]|0;
        $69 = ($68<<24>>24)==(0);
        if ($69) {
         $NumDirtyActorAggregates$2 = $NumDirtyActorAggregates$062;
        } else {
         $70 = $66 >>> 5;
         $71 = HEAP32[$9>>2]|0;
         $72 = (($71) + ($70<<2)|0);
         $73 = HEAP32[$72>>2]|0;
         $74 = $66 & 31;
         $75 = 1 << $74;
         $76 = $73 & $75;
         $77 = ($76|0)==(0);
         if ($77) {
          $78 = $73 | $75;
          HEAP32[$72>>2] = $78;
          $79 = (($28) + ($NumDirtyActorAggregates$062<<2)|0);
          HEAP32[$79>>2] = $66;
          $80 = (($NumDirtyActorAggregates$062) + 1)|0;
          $NumDirtyActorAggregates$1 = $80;
         } else {
          $NumDirtyActorAggregates$1 = $NumDirtyActorAggregates$062;
         }
         $81 = HEAP32[$59>>2]|0;
         $82 = (($81) + ($70<<2)|0);
         $83 = HEAP32[$82>>2]|0;
         $84 = $83 & $75;
         $85 = ($84|0)==(0);
         if ($85) {
          $86 = $83 | $75;
          HEAP32[$82>>2] = $86;
         }
         $87 = ((($$pre115$pre) + (($66*1048)|0)|0) + 1028|0);
         $88 = HEAP32[$87>>2]|0;
         $89 = $88 >>> 5;
         $90 = HEAP32[$60>>2]|0;
         $91 = (($90) + ($89<<2)|0);
         $92 = HEAP32[$91>>2]|0;
         $93 = $88 & 31;
         $94 = 1 << $93;
         $95 = $92 & $94;
         $96 = ($95|0)==(0);
         if ($96) {
          $97 = HEAP32[$61>>2]|0;
          $98 = (($97) + ($89<<2)|0);
          $99 = HEAP32[$98>>2]|0;
          $100 = $99 & $94;
          $101 = ($100|0)==(0);
          if ($101) {
           $102 = $99 | $94;
           HEAP32[$98>>2] = $102;
           $NumDirtyActorAggregates$2 = $NumDirtyActorAggregates$1;
          } else {
           $NumDirtyActorAggregates$2 = $NumDirtyActorAggregates$1;
          }
         } else {
          $NumDirtyActorAggregates$2 = $NumDirtyActorAggregates$1;
         }
        }
        $103 = ($104|0)==(0);
        if ($103) {
         $NumDirtyActorAggregates$0$lcssa = $NumDirtyActorAggregates$2;
         break L13;
        }
        $106 = (0 - ($104))|0;
        $107 = $104 & $106;
        $108 = Math_imul($107, 125613361)|0;
        $109 = $108 >>> 27;
        $110 = (412480 + ($109<<2)|0);
        $111 = HEAP32[$110>>2]|0;
        $63 = $111 | $64;
        $112 = (($104) + -1)|0;
        $113 = $112 & $104;
        $114 = HEAP32[$29>>2]|0;
        $115 = $114 & 2147483647;
        $116 = ($113|0)==(0);
        if ($116) {
         $118 = $$ph5577;
         break;
        }
        $105 = ($63|0)==(-1);
        if ($105) {
         $NumDirtyActorAggregates$0$lcssa = $NumDirtyActorAggregates$2;
         break L13;
        } else {
         $104 = $113;$NumDirtyActorAggregates$062 = $NumDirtyActorAggregates$2;$index$061 = $63;
        }
       }
       while(1) {
        $117 = (($118) + 1)|0;
        $119 = ($117>>>0)<($115>>>0);
        if (!($119)) {
         $$ph51 = 0;
         break;
        }
        $120 = HEAP32[$2>>2]|0;
        $121 = (($120) + ($117<<2)|0);
        $122 = HEAP32[$121>>2]|0;
        $123 = ($122|0)==(0);
        if ($123) {
         $118 = $117;
        } else {
         $$ph51 = $122;
         break;
        }
       }
       $62 = ($63|0)==(-1);
       if ($62) {
        $NumDirtyActorAggregates$0$lcssa = $NumDirtyActorAggregates$2;
        break;
       } else {
        $$ph5577 = $117;$$ph5678 = $$ph51;$NumDirtyActorAggregates$0$ph80 = $NumDirtyActorAggregates$2;$index$0$ph5779 = $63;
       }
      }
     }
    }
   } while(0);
   $124 = (($this) + 41568|0);
   HEAP32[$124>>2] = $NumDirtyActorAggregates$0$lcssa;
   $125 = HEAP32[$9>>2]|0;
   $126 = ($125|0)==(0|0);
   $127 = ($125|0)==($dirtyActorAggregatesBitmap|0);
   $or$cond$i$i$i = $126 | $127;
   if (!($or$cond$i$i$i)) {
    $128 = HEAP32[$8>>2]|0;
    $129 = ($128|0)==(0|0);
    if ($129) {
     __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$125);
     break;
    }
    $130 = (($128) + 16|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = ($131>>>0)>($125>>>0);
    if (!($132)) {
     $133 = (($128) + 20|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($131) + ($134)|0);
     $136 = ($135>>>0)>($125>>>0);
     if ($136) {
      $137 = HEAP32[$128>>2]|0;
      __ZN5physx6shdfnd9MutexImpl4lockEv($137);
      $138 = (($128) + 8|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = (($128) + 4|0);
      $141 = HEAP32[$140>>2]|0;
      $i$0$in$i = $139;
      while(1) {
       $i$0$i = (($i$0$in$i) + -1)|0;
       $142 = (($141) + ($i$0$i<<2)|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ($143>>>0)<($125>>>0);
       if ($144) {
        $i$0$in$i = $i$0$i;
       } else {
        break;
       }
      }
      $145 = ($i$0$in$i>>>0)<($139>>>0);
      if ($145) {
       $149 = $i$0$in$i;$it$02$i$i = $142;
       while(1) {
        $146 = ($it$02$i$i|0)==(0|0);
        if (!($146)) {
         $147 = HEAP32[$140>>2]|0;
         $148 = (($147) + ($149<<2)|0);
         $150 = HEAP32[$148>>2]|0;
         HEAP32[$it$02$i$i>>2] = $150;
        }
        $151 = (($it$02$i$i) + 4|0);
        $152 = (($149) + 1)|0;
        $exitcond$i = ($152|0)==($139|0);
        if ($exitcond$i) {
         break;
        } else {
         $149 = $152;$it$02$i$i = $151;
        }
       }
      }
      $153 = (($139) + -1)|0;
      HEAP32[$138>>2] = $153;
      $154 = HEAP32[$128>>2]|0;
      __ZN5physx6shdfnd9MutexImpl6unlockEv($154);
      break;
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$125);
   }
  }
 } while(0);
 $155 = (($this) + 16900|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = (($changedActorsBitmap) + 4|0);
 HEAP32[$changedActorsBitmap>>2] = $changedActorWords;
 $158 = $changedActorWordCount | -2147483648;
 HEAP32[$157>>2] = $158;
 $159 = $changedActorWordCount & 2147483647;
 $160 = ($159|0)==(0);
 L66: do {
  if ($160) {
   $$ph33 = 0;$$ph34 = 0;$index2$0$ph = -1;
  } else {
   $162 = 0;
   while(1) {
    $161 = (($changedActorWords) + ($162<<2)|0);
    $163 = HEAP32[$161>>2]|0;
    $164 = ($163|0)==(0);
    if (!($164)) {
     break;
    }
    $165 = (($162) + 1)|0;
    $166 = ($165>>>0)<($159>>>0);
    if ($166) {
     $162 = $165;
    } else {
     $$ph33 = $165;$$ph34 = 0;$index2$0$ph = -1;
     break L66;
    }
   }
   $167 = $162 << 5;
   $168 = (0 - ($163))|0;
   $169 = $163 & $168;
   $170 = Math_imul($169, 125613361)|0;
   $171 = $170 >>> 27;
   $172 = (412480 + ($171<<2)|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = $173 | $167;
   $175 = (($163) + -1)|0;
   $176 = $175 & $163;
   $177 = $changedActorWordCount & 2147483647;
   $178 = ($176|0)==(0);
   if ($178) {
    $180 = $162;
    while(1) {
     $179 = (($180) + 1)|0;
     $181 = ($179>>>0)<($177>>>0);
     if (!($181)) {
      $$ph33 = $179;$$ph34 = 0;$index2$0$ph = $174;
      break L66;
     }
     $182 = (($changedActorWords) + ($179<<2)|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = ($183|0)==(0);
     if ($184) {
      $180 = $179;
     } else {
      $$ph33 = $179;$$ph34 = $183;$index2$0$ph = $174;
      break;
     }
    }
   } else {
    $$ph33 = $162;$$ph34 = $176;$index2$0$ph = $174;
   }
  }
 } while(0);
 $185 = (($this) + 156|0);
 $186 = (($this) + 96|0);
 $187 = (($this) + 68|0);
 $188 = (($this) + 28|0);
 $189 = (($this) + 260|0);
 $190 = (($this) + 180|0);
 $191 = (($this) + 356|0);
 $$ph35 = $$ph33;$$ph36 = $$ph34;$BPUpdatedElemIdsSize$0$ph = 0;$index2$0$ph37 = $index2$0$ph;
 L75: while(1) {
  $192 = $$ph35 << 5;
  $$ph39 = $$ph36;$BPUpdatedElemIdsSize$0$ph41 = $BPUpdatedElemIdsSize$0$ph;$index2$0$ph40 = $index2$0$ph37;
  while(1) {
   $index2$0 = $index2$0$ph40;
   while(1) {
    if ((($index2$0|0) == 1073741823)) {
     $index2$0 = 1073741823;
    } else if ((($index2$0|0) == -1)) {
     break L75;
    } else {
     break;
    }
   }
   $193 = $index2$0 & 1;
   $194 = ($193|0)==(0);
   $195 = $index2$0 >>> 1;
   if ($194) {
    $196 = HEAP32[$185>>2]|0;
    $197 = (($196) + ($195<<2)|0);
    $id$027 = HEAP32[$197>>2]|0;
    $198 = ($id$027|0)==(1073741823);
    if ($198) {
     $BPUpdatedElemIdsSize$2 = $BPUpdatedElemIdsSize$0$ph41;
    } else {
     $$pre113 = HEAP32[$186>>2]|0;
     $BPUpdatedElemIdsSize$128 = $BPUpdatedElemIdsSize$0$ph41;$id$029 = $id$027;
     while(1) {
      $199 = (($156) + ($BPUpdatedElemIdsSize$128<<2)|0);
      HEAP32[$199>>2] = $id$029;
      $200 = (($BPUpdatedElemIdsSize$128) + 1)|0;
      $201 = $id$029 >>> 5;
      $202 = (($$pre113) + ($201<<2)|0);
      $203 = HEAP32[$202>>2]|0;
      $204 = $id$029 & 31;
      $205 = 1 << $204;
      $206 = $203 & $205;
      $207 = ($206|0)==(0);
      if ($207) {
       $208 = HEAP32[$187>>2]|0;
       $209 = (($208) + ($201<<2)|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = $210 & $205;
       $212 = ($211|0)==(0);
       if ($212) {
        $213 = $210 | $205;
        HEAP32[$209>>2] = $213;
       }
      }
      $214 = HEAP32[$188>>2]|0;
      $215 = (($214) + ($id$029<<2)|0);
      $id$0 = HEAP32[$215>>2]|0;
      $216 = ($id$0|0)==(1073741823);
      if ($216) {
       $BPUpdatedElemIdsSize$2 = $200;
       break;
      } else {
       $BPUpdatedElemIdsSize$128 = $200;$id$029 = $id$0;
      }
     }
    }
   } else {
    $217 = HEAP32[$189>>2]|0;
    $218 = (($217) + ($195<<2)|0);
    $219 = HEAP32[$218>>2]|0;
    $220 = HEAP32[$190>>2]|0;
    $221 = ((($220) + (($219*1048)|0)|0) + 1025|0);
    $222 = HEAP8[$221>>0]|0;
    $223 = ($222<<24>>24)==(0);
    if ($223) {
     $BPUpdatedElemIdsSize$2 = $BPUpdatedElemIdsSize$0$ph41;
    } else {
     $224 = $219 >>> 5;
     $225 = HEAP32[$191>>2]|0;
     $226 = (($225) + ($224<<2)|0);
     $227 = HEAP32[$226>>2]|0;
     $228 = $219 & 31;
     $229 = 1 << $228;
     $230 = $227 & $229;
     $231 = ($230|0)==(0);
     if ($231) {
      $232 = $227 | $229;
      HEAP32[$226>>2] = $232;
     }
     $233 = ((($220) + (($219*1048)|0)|0) + 1028|0);
     $234 = HEAP32[$233>>2]|0;
     $235 = $234 >>> 5;
     $236 = HEAP32[$186>>2]|0;
     $237 = (($236) + ($235<<2)|0);
     $238 = HEAP32[$237>>2]|0;
     $239 = $234 & 31;
     $240 = 1 << $239;
     $241 = $238 & $240;
     $242 = ($241|0)==(0);
     if ($242) {
      $243 = HEAP32[$187>>2]|0;
      $244 = (($243) + ($235<<2)|0);
      $245 = HEAP32[$244>>2]|0;
      $246 = $245 & $240;
      $247 = ($246|0)==(0);
      if ($247) {
       $248 = $245 | $240;
       HEAP32[$244>>2] = $248;
       $BPUpdatedElemIdsSize$2 = $BPUpdatedElemIdsSize$0$ph41;
      } else {
       $BPUpdatedElemIdsSize$2 = $BPUpdatedElemIdsSize$0$ph41;
      }
     } else {
      $BPUpdatedElemIdsSize$2 = $BPUpdatedElemIdsSize$0$ph41;
     }
    }
   }
   $249 = ($$ph39|0)==(0);
   if ($249) {
    $$ph39 = 0;$BPUpdatedElemIdsSize$0$ph41 = $BPUpdatedElemIdsSize$2;$index2$0$ph40 = -1;
    continue;
   }
   $250 = (0 - ($$ph39))|0;
   $251 = $$ph39 & $250;
   $252 = Math_imul($251, 125613361)|0;
   $253 = $252 >>> 27;
   $254 = (412480 + ($253<<2)|0);
   $255 = HEAP32[$254>>2]|0;
   $256 = $255 | $192;
   $257 = (($$ph39) + -1)|0;
   $258 = $257 & $$ph39;
   $259 = HEAP32[$157>>2]|0;
   $260 = $259 & 2147483647;
   $261 = ($258|0)==(0);
   if ($261) {
    $263 = $$ph35;
    break;
   } else {
    $$ph39 = $258;$BPUpdatedElemIdsSize$0$ph41 = $BPUpdatedElemIdsSize$2;$index2$0$ph40 = $256;
   }
  }
  while(1) {
   $262 = (($263) + 1)|0;
   $264 = ($262>>>0)<($260>>>0);
   if (!($264)) {
    $$ph35 = $262;$$ph36 = 0;$BPUpdatedElemIdsSize$0$ph = $BPUpdatedElemIdsSize$2;$index2$0$ph37 = $256;
    continue L75;
   }
   $265 = (($changedActorWords) + ($262<<2)|0);
   $266 = HEAP32[$265>>2]|0;
   $267 = ($266|0)==(0);
   if ($267) {
    $263 = $262;
   } else {
    $$ph35 = $262;$$ph36 = $266;$BPUpdatedElemIdsSize$0$ph = $BPUpdatedElemIdsSize$2;$index2$0$ph37 = $256;
    continue L75;
   }
  }
 }
 $268 = (($this) + 16912|0);
 HEAP32[$268>>2] = $BPUpdatedElemIdsSize$0$ph41;
 $269 = ($changedActorWords|0)==(0|0);
 if (!($269)) {
  $270 = HEAP32[$157>>2]|0;
  $271 = ($270|0)>(-1);
  if ($271) {
   $272 = (($changedActorsBitmap) + 8|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($272,$changedActorWords);
  }
 }
 $273 = (($this) + 356|0);
 __ZN5physx10ChangeList11computeListEv($273);
 $274 = (($this) + 33316|0);
 $275 = HEAP32[$274>>2]|0;
 $276 = (($this) + 372|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = (($this) + 368|0);
 $279 = HEAP32[$278>>2]|0;
 $280 = ($277|0)==(0);
 if ($280) {
  $AggregateUpdatedElemIdsSize$0$lcssa = 0;
  $324 = (($this) + 33328|0);
  HEAP32[$324>>2] = $AggregateUpdatedElemIdsSize$0$lcssa;
  $325 = (($this) + 68|0);
  __ZN5physx10ChangeList11computeListEv($325);
  $326 = (($this) + 96|0);
  __ZN5physx10ChangeList11computeListEv($326);
  $327 = (($this) + 124|0);
  __ZN5physx10ChangeList11computeListEv($327);
  STACKTOP = sp;return;
 }
 $281 = (($this) + 232|0);
 $282 = (($this) + 308|0);
 $283 = (($this) + 316|0);
 $$pre = HEAP32[$190>>2]|0;
 $AggregateUpdatedElemIdsSize$022 = 0;$k$023 = 0;
 while(1) {
  $284 = (($279) + ($k$023<<2)|0);
  $285 = HEAP32[$284>>2]|0;
  $286 = ((($$pre) + (($285*1048)|0)|0) + 1024|0);
  $287 = HEAP8[$286>>0]|0;
  $288 = ($287<<24>>24)==(0);
  if ($288) {
   $289 = $285 >>> 5;
   $290 = HEAP32[$281>>2]|0;
   $291 = (($290) + ($289<<2)|0);
   $292 = HEAP32[$291>>2]|0;
   $293 = $285 & 31;
   $294 = 1 << $293;
   $295 = $292 & $294;
   $296 = ($295|0)==(0);
   if ($296) {
    $AggregateUpdatedElemIdsSize$3 = $AggregateUpdatedElemIdsSize$022;
   } else {
    label = 80;
   }
  } else {
   label = 80;
  }
  if ((label|0) == 80) {
   label = 0;
   $297 = ((($$pre) + (($285*1048)|0)|0) + 1032|0);
   $elemId$019 = HEAP32[$297>>2]|0;
   $298 = ($elemId$019|0)==(1073741823);
   if ($298) {
    $AggregateUpdatedElemIdsSize$1$lcssa = $AggregateUpdatedElemIdsSize$022;
   } else {
    $$pre104 = HEAP32[$282>>2]|0;
    $AggregateUpdatedElemIdsSize$120 = $AggregateUpdatedElemIdsSize$022;$elemId$021 = $elemId$019;
    while(1) {
     $299 = (($$pre104) + ($elemId$021<<2)|0);
     $300 = HEAP32[$299>>2]|0;
     $301 = ($300|0)==(1073741823);
     if ($301) {
      $AggregateUpdatedElemIdsSize$2 = $AggregateUpdatedElemIdsSize$120;
     } else {
      $302 = (($275) + ($AggregateUpdatedElemIdsSize$120<<2)|0);
      HEAP32[$302>>2] = $elemId$021;
      $303 = (($AggregateUpdatedElemIdsSize$120) + 1)|0;
      $AggregateUpdatedElemIdsSize$2 = $303;
     }
     $304 = HEAP32[$283>>2]|0;
     $305 = (($304) + ($elemId$021<<2)|0);
     $elemId$0 = HEAP32[$305>>2]|0;
     $306 = ($elemId$0|0)==(1073741823);
     if ($306) {
      $AggregateUpdatedElemIdsSize$1$lcssa = $AggregateUpdatedElemIdsSize$2;
      break;
     } else {
      $AggregateUpdatedElemIdsSize$120 = $AggregateUpdatedElemIdsSize$2;$elemId$021 = $elemId$0;
     }
    }
   }
   $307 = ((($$pre) + (($285*1048)|0)|0) + 1028|0);
   $308 = HEAP32[$307>>2]|0;
   $309 = $308 >>> 5;
   $310 = HEAP32[$186>>2]|0;
   $311 = (($310) + ($309<<2)|0);
   $312 = HEAP32[$311>>2]|0;
   $313 = $308 & 31;
   $314 = 1 << $313;
   $315 = $312 & $314;
   $316 = ($315|0)==(0);
   if ($316) {
    $317 = HEAP32[$187>>2]|0;
    $318 = (($317) + ($309<<2)|0);
    $319 = HEAP32[$318>>2]|0;
    $320 = $319 & $314;
    $321 = ($320|0)==(0);
    if ($321) {
     $322 = $319 | $314;
     HEAP32[$318>>2] = $322;
     $AggregateUpdatedElemIdsSize$3 = $AggregateUpdatedElemIdsSize$1$lcssa;
    } else {
     $AggregateUpdatedElemIdsSize$3 = $AggregateUpdatedElemIdsSize$1$lcssa;
    }
   } else {
    $AggregateUpdatedElemIdsSize$3 = $AggregateUpdatedElemIdsSize$1$lcssa;
   }
  }
  $323 = (($k$023) + 1)|0;
  $exitcond = ($323|0)==($277|0);
  if ($exitcond) {
   $AggregateUpdatedElemIdsSize$0$lcssa = $AggregateUpdatedElemIdsSize$3;
   break;
  } else {
   $AggregateUpdatedElemIdsSize$022 = $AggregateUpdatedElemIdsSize$3;$k$023 = $323;
  }
 }
 $324 = (($this) + 33328|0);
 HEAP32[$324>>2] = $AggregateUpdatedElemIdsSize$0$lcssa;
 $325 = (($this) + 68|0);
 __ZN5physx10ChangeList11computeListEv($325);
 $326 = (($this) + 96|0);
 __ZN5physx10ChangeList11computeListEv($326);
 $327 = (($this) + 124|0);
 __ZN5physx10ChangeList11computeListEv($327);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager31removeEmptyActorsFromAggregatesEv($this) {
 $this = $this|0;
 var $$ph = 0, $$ph26 = 0, $$ph27 = 0, $$ph2861 = 0, $$ph2962 = 0, $$ph42 = 0, $$ph44 = 0, $$ph45 = 0, $$ph4665 = 0, $$ph4766 = 0, $$ph91 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $actorId4$020 = 0, $actorId4$124 = 0, $aggregatesWithEmptyActors = 0, $index$0$ph4867 = 0, $index$052 = 0, $index2$0$ph3063 = 0, $index2$033 = 0, $nextActorId5$021 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 528|0;
 $aggregatesWithEmptyActors = sp;
 $1 = (($this) + 280|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($aggregatesWithEmptyActors) + 512|0);
 HEAP32[$7>>2] = $6;
 $8 = (($aggregatesWithEmptyActors) + 516|0);
 HEAP32[$8>>2] = 0;
 $9 = (($aggregatesWithEmptyActors) + 520|0);
 HEAP32[$9>>2] = 0;
 $10 = ($5|0)==(0);
 if (!($10)) {
  $11 = (($5) + 31)|0;
  $12 = $11 >>> 5;
  $13 = ($5>>>0)>(4096);
  do {
   if ($13) {
    $14 = $12 << 2;
    $15 = (($14) + 15)|0;
    $16 = $15 & 1073741808;
    $17 = ($6|0)==(0|0);
    if ($17) {
     $20 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$16,481512,2004)|0);
     HEAP32[$8>>2] = $20;
     $21 = $12 | -2147483648;
     HEAP32[$9>>2] = $21;
     $24 = $21;$25 = $20;
     break;
    } else {
     $18 = (__ZN5physx19PxcScratchAllocator5allocEjb($6,$16,1)|0);
     HEAP32[$8>>2] = $18;
     $19 = $12 | -2147483648;
     HEAP32[$9>>2] = $19;
     $24 = $19;$25 = $18;
     break;
    }
   } else {
    HEAP32[$8>>2] = $aggregatesWithEmptyActors;
    $22 = $12 | -2147483648;
    HEAP32[$9>>2] = $22;
    $24 = $22;$25 = $aggregatesWithEmptyActors;
   }
  } while(0);
  $23 = $24 << 2;
  _memset(($25|0),0,($23|0))|0;
 }
 $26 = (($this) + 284|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 & 2147483647;
 $29 = ($28|0)==(0);
 L14: do {
  if (!($29)) {
   $$pre$i$i$i12 = HEAP32[$1>>2]|0;
   $31 = 0;
   while(1) {
    $30 = (($$pre$i$i$i12) + ($31<<2)|0);
    $32 = HEAP32[$30>>2]|0;
    $33 = ($32|0)==(0);
    if (!($33)) {
     break;
    }
    $34 = (($31) + 1)|0;
    $35 = ($34>>>0)<($28>>>0);
    if ($35) {
     $31 = $34;
    } else {
     break L14;
    }
   }
   $36 = $31 << 5;
   $37 = (0 - ($32))|0;
   $38 = $32 & $37;
   $39 = Math_imul($38, 125613361)|0;
   $40 = $39 >>> 27;
   $41 = (412480 + ($40<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = $42 | $36;
   $44 = (($32) + -1)|0;
   $45 = $44 & $32;
   $46 = ($45|0)==(0);
   L20: do {
    if ($46) {
     $48 = $31;
     while(1) {
      $47 = (($48) + 1)|0;
      $49 = ($47>>>0)<($28>>>0);
      if (!($49)) {
       $$ph44 = $47;$$ph45 = 0;
       break L20;
      }
      $50 = (($$pre$i$i$i12) + ($47<<2)|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==(0);
      if ($52) {
       $48 = $47;
      } else {
       $$ph44 = $47;$$ph45 = $51;
       break;
      }
     }
    } else {
     $$ph44 = $31;$$ph45 = $45;
    }
   } while(0);
   $53 = ($43|0)==(-1);
   if (!($53)) {
    $54 = (($this) + 260|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$8>>2]|0;
    $$ph4665 = $$ph44;$$ph4766 = $$ph45;$index$0$ph4867 = $43;
    while(1) {
     $59 = $$ph4665 << 5;
     $69 = $$ph4766;$index$052 = $index$0$ph4867;
     while(1) {
      $60 = (($55) + ($index$052<<2)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = $61 & 31;
      $63 = 1 << $62;
      $64 = $61 >>> 5;
      $65 = (($56) + ($64<<2)|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = $66 | $63;
      HEAP32[$65>>2] = $67;
      $68 = ($69|0)==(0);
      if ($68) {
       break L14;
      }
      $71 = (0 - ($69))|0;
      $72 = $69 & $71;
      $73 = Math_imul($72, 125613361)|0;
      $74 = $73 >>> 27;
      $75 = (412480 + ($74<<2)|0);
      $76 = HEAP32[$75>>2]|0;
      $58 = $76 | $59;
      $77 = (($69) + -1)|0;
      $78 = $77 & $69;
      $79 = HEAP32[$26>>2]|0;
      $80 = $79 & 2147483647;
      $81 = ($78|0)==(0);
      if ($81) {
       $83 = $$ph4665;
       break;
      }
      $70 = ($58|0)==(-1);
      if ($70) {
       break L14;
      } else {
       $69 = $78;$index$052 = $58;
      }
     }
     while(1) {
      $82 = (($83) + 1)|0;
      $84 = ($82>>>0)<($80>>>0);
      if (!($84)) {
       $$ph42 = 0;
       break;
      }
      $85 = HEAP32[$1>>2]|0;
      $86 = (($85) + ($82<<2)|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = ($87|0)==(0);
      if ($88) {
       $83 = $82;
      } else {
       $$ph42 = $87;
       break;
      }
     }
     $57 = ($58|0)==(-1);
     if ($57) {
      break;
     } else {
      $$ph4665 = $82;$$ph4766 = $$ph42;$index$0$ph4867 = $58;
     }
    }
   }
  }
 } while(0);
 $89 = (($aggregatesWithEmptyActors) + 516|0);
 $90 = HEAP32[$9>>2]|0;
 $91 = $90 & 2147483647;
 $92 = ($91|0)==(0);
 L37: do {
  if (!($92)) {
   $$pre$i$i$i = HEAP32[$89>>2]|0;
   $94 = 0;
   while(1) {
    $93 = (($$pre$i$i$i) + ($94<<2)|0);
    $95 = HEAP32[$93>>2]|0;
    $96 = ($95|0)==(0);
    if (!($96)) {
     break;
    }
    $97 = (($94) + 1)|0;
    $98 = ($97>>>0)<($91>>>0);
    if ($98) {
     $94 = $97;
    } else {
     break L37;
    }
   }
   $99 = $94 << 5;
   $100 = (0 - ($95))|0;
   $101 = $95 & $100;
   $102 = Math_imul($101, 125613361)|0;
   $103 = $102 >>> 27;
   $104 = (412480 + ($103<<2)|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = $105 | $99;
   $107 = (($95) + -1)|0;
   $108 = $107 & $95;
   $109 = ($108|0)==(0);
   L43: do {
    if ($109) {
     $111 = $94;
     while(1) {
      $110 = (($111) + 1)|0;
      $112 = ($110>>>0)<($91>>>0);
      if (!($112)) {
       $$ph26 = $110;$$ph27 = 0;
       break L43;
      }
      $113 = (($$pre$i$i$i) + ($110<<2)|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = ($114|0)==(0);
      if ($115) {
       $111 = $110;
      } else {
       $$ph26 = $110;$$ph27 = $114;
       break;
      }
     }
    } else {
     $$ph26 = $94;$$ph27 = $108;
    }
   } while(0);
   $116 = ($106|0)==(-1);
   if (!($116)) {
    $117 = (($this) + 180|0);
    $118 = (($this) + 252|0);
    $119 = (($this) + 256|0);
    $120 = (($this) + 292|0);
    $121 = (($this) + 248|0);
    $122 = (($this) + 260|0);
    $123 = (($this) + 268|0);
    $$ph2861 = $$ph26;$$ph2962 = $$ph27;$index2$0$ph3063 = $106;
    while(1) {
     $126 = $$ph2861 << 5;
     $194 = $$ph2962;$index2$033 = $index2$0$ph3063;
     while(1) {
      $127 = HEAP32[$117>>2]|0;
      $128 = ((($127) + (($index2$033*1048)|0)|0) + 1040|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ($129|0)==(1073741823);
      L53: do {
       if ($130) {
        label = 39;
       } else {
        $actorId4$020 = $129;
        while(1) {
         $131 = HEAP32[$118>>2]|0;
         $132 = (($131) + ($actorId4$020)|0);
         $133 = HEAP8[$132>>0]|0;
         $134 = ($133<<24>>24)==(0);
         if (!($134)) {
          break;
         }
         $135 = HEAP32[$119>>2]|0;
         $136 = (($135) + ($actorId4$020<<2)|0);
         $137 = HEAP32[$136>>2]|0;
         $138 = HEAP32[$120>>2]|0;
         $139 = HEAP32[$121>>2]|0;
         $140 = (($139) + (($actorId4$020*24)|0)|0);
         HEAP32[$140>>2] = $138;
         HEAP32[$120>>2] = $actorId4$020;
         HEAP8[$132>>0] = 0;
         $141 = HEAP32[$119>>2]|0;
         $142 = (($141) + ($actorId4$020<<2)|0);
         HEAP32[$142>>2] = 1073741823;
         $143 = HEAP32[$122>>2]|0;
         $144 = (($143) + ($actorId4$020<<2)|0);
         HEAP32[$144>>2] = 1073741823;
         $145 = $actorId4$020 & 31;
         $146 = 1 << $145;
         $147 = $146 ^ -1;
         $148 = $actorId4$020 >>> 5;
         $149 = HEAP32[$123>>2]|0;
         $150 = (($149) + ($148<<2)|0);
         $151 = HEAP32[$150>>2]|0;
         $152 = $151 & $147;
         HEAP32[$150>>2] = $152;
         $153 = HEAP32[$1>>2]|0;
         $154 = (($153) + ($148<<2)|0);
         $155 = HEAP32[$154>>2]|0;
         $156 = $155 & $147;
         HEAP32[$154>>2] = $156;
         $157 = ($137|0)==(1073741823);
         if ($157) {
          label = 39;
          break L53;
         } else {
          $actorId4$020 = $137;
         }
        }
        HEAP32[$128>>2] = $actorId4$020;
        $158 = ($actorId4$020|0)==(1073741823);
        if (!($158)) {
         $$pre = HEAP32[$119>>2]|0;
         $160 = $$pre;$actorId4$124 = $actorId4$020;
         L59: while(1) {
          $159 = (($160) + ($actorId4$124<<2)|0);
          $161 = HEAP32[$159>>2]|0;
          $162 = ($161|0)==(1073741823);
          if ($162) {
           $$ph91 = $160;
           break;
          } else {
           $168 = $160;$nextActorId5$021 = $161;
          }
          while(1) {
           $163 = HEAP32[$118>>2]|0;
           $164 = (($163) + ($nextActorId5$021)|0);
           $165 = HEAP8[$164>>0]|0;
           $166 = ($165<<24>>24)==(0);
           if (!($166)) {
            break;
           }
           $167 = (($168) + ($nextActorId5$021<<2)|0);
           $169 = HEAP32[$167>>2]|0;
           $170 = HEAP32[$120>>2]|0;
           $171 = HEAP32[$121>>2]|0;
           $172 = (($171) + (($nextActorId5$021*24)|0)|0);
           HEAP32[$172>>2] = $170;
           HEAP32[$120>>2] = $nextActorId5$021;
           HEAP8[$164>>0] = 0;
           $173 = HEAP32[$119>>2]|0;
           $174 = (($173) + ($nextActorId5$021<<2)|0);
           HEAP32[$174>>2] = 1073741823;
           $175 = HEAP32[$122>>2]|0;
           $176 = (($175) + ($nextActorId5$021<<2)|0);
           HEAP32[$176>>2] = 1073741823;
           $177 = $nextActorId5$021 & 31;
           $178 = 1 << $177;
           $179 = $178 ^ -1;
           $180 = $nextActorId5$021 >>> 5;
           $181 = HEAP32[$123>>2]|0;
           $182 = (($181) + ($180<<2)|0);
           $183 = HEAP32[$182>>2]|0;
           $184 = $183 & $179;
           HEAP32[$182>>2] = $184;
           $185 = HEAP32[$1>>2]|0;
           $186 = (($185) + ($180<<2)|0);
           $187 = HEAP32[$186>>2]|0;
           $188 = $187 & $179;
           HEAP32[$186>>2] = $188;
           $189 = ($169|0)==(1073741823);
           if ($189) {
            $$ph91 = $173;
            break L59;
           } else {
            $168 = $173;$nextActorId5$021 = $169;
           }
          }
          $191 = (($168) + ($actorId4$124<<2)|0);
          HEAP32[$191>>2] = $nextActorId5$021;
          $192 = ($nextActorId5$021|0)==(1073741823);
          if ($192) {
           break L53;
          } else {
           $160 = $168;$actorId4$124 = $nextActorId5$021;
          }
         }
         $190 = (($$ph91) + ($actorId4$124<<2)|0);
         HEAP32[$190>>2] = 1073741823;
        }
       }
      } while(0);
      if ((label|0) == 39) {
       label = 0;
       HEAP32[$128>>2] = 1073741823;
      }
      $193 = ($194|0)==(0);
      if ($193) {
       break L37;
      }
      $196 = (0 - ($194))|0;
      $197 = $194 & $196;
      $198 = Math_imul($197, 125613361)|0;
      $199 = $198 >>> 27;
      $200 = (412480 + ($199<<2)|0);
      $201 = HEAP32[$200>>2]|0;
      $125 = $201 | $126;
      $202 = (($194) + -1)|0;
      $203 = $202 & $194;
      $204 = HEAP32[$9>>2]|0;
      $205 = $204 & 2147483647;
      $206 = ($203|0)==(0);
      if ($206) {
       break;
      }
      $195 = ($125|0)==(-1);
      if ($195) {
       break L37;
      } else {
       $194 = $203;$index2$033 = $125;
      }
     }
     $207 = HEAP32[$89>>2]|0;
     $209 = $$ph2861;
     while(1) {
      $208 = (($209) + 1)|0;
      $210 = ($208>>>0)<($205>>>0);
      if (!($210)) {
       $$ph = 0;
       break;
      }
      $211 = (($207) + ($208<<2)|0);
      $212 = HEAP32[$211>>2]|0;
      $213 = ($212|0)==(0);
      if ($213) {
       $209 = $208;
      } else {
       $$ph = $212;
       break;
      }
     }
     $124 = ($125|0)==(-1);
     if ($124) {
      break;
     } else {
      $$ph2861 = $208;$$ph2962 = $$ph;$index2$0$ph3063 = $125;
     }
    }
   }
  }
 } while(0);
 __ZN5physx12InlineBitmapILj4096EED1Ev($aggregatesWithEmptyActors);
 STACKTOP = sp;return;
}
function __ZN5physx12InlineBitmapILj4096EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$in$i = 0, $it$02$i$i = 0, $or$cond$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 516|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = ($3|0)==($this|0);
 $or$cond$i$i = $4 | $5;
 do {
  if (!($or$cond$i$i)) {
   $6 = (($this) + 512|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$3);
    break;
   }
   $9 = (($7) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10>>>0)>($3>>>0);
   if (!($11)) {
    $12 = (($7) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($10) + ($13)|0);
    $15 = ($14>>>0)>($3>>>0);
    if ($15) {
     $16 = HEAP32[$7>>2]|0;
     __ZN5physx6shdfnd9MutexImpl4lockEv($16);
     $17 = (($7) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($7) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $i$0$in$i = $18;
     while(1) {
      $i$0$i = (($i$0$in$i) + -1)|0;
      $21 = (($20) + ($i$0$i<<2)|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22>>>0)<($3>>>0);
      if ($23) {
       $i$0$in$i = $i$0$i;
      } else {
       break;
      }
     }
     $24 = ($i$0$in$i>>>0)<($18>>>0);
     if ($24) {
      $28 = $i$0$in$i;$it$02$i$i = $21;
      while(1) {
       $25 = ($it$02$i$i|0)==(0|0);
       if (!($25)) {
        $26 = HEAP32[$19>>2]|0;
        $27 = (($26) + ($28<<2)|0);
        $29 = HEAP32[$27>>2]|0;
        HEAP32[$it$02$i$i>>2] = $29;
       }
       $30 = (($it$02$i$i) + 4|0);
       $31 = (($28) + 1)|0;
       $exitcond$i = ($31|0)==($18|0);
       if ($exitcond$i) {
        break;
       } else {
        $28 = $31;$it$02$i$i = $30;
       }
      }
     }
     $32 = (($18) + -1)|0;
     HEAP32[$17>>2] = $32;
     $33 = HEAP32[$7>>2]|0;
     __ZN5physx6shdfnd9MutexImpl6unlockEv($33);
     break;
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
  }
 } while(0);
 HEAP32[$2>>2] = 0;
 $34 = (($this) + 520|0);
 HEAP32[$34>>2] = -2147483648;
 STACKTOP = sp;return;
}
function __ZN5physx10ChangeList11computeListEv($this) {
 $this = $this|0;
 var $$ph = 0, $$ph1028 = 0, $$ph7 = 0, $$ph8 = 0, $$ph927 = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $count$01$i = 0, $exitcond$i = 0, $i$02$i = 0, $index$0$ph1130 = 0, $index$017 = 0, $numElems$0$lcssa = 0, $numElems$0$ph29 = 0, $numElems$016 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($6|0)==(0);
 if ($7) {
  $39 = $5;
 } else {
  $count$01$i = 0;$i$02$i = 0;
  while(1) {
   $8 = (($2) + ($i$02$i<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 >>> 1;
   $11 = $10 & 1431655765;
   $12 = (($9) - ($11))|0;
   $13 = $12 & 858993459;
   $14 = $12 >>> 2;
   $15 = $14 & 858993459;
   $16 = (($15) + ($13))|0;
   $17 = $16 >>> 4;
   $18 = (($17) + ($16))|0;
   $19 = $18 & 252645135;
   $20 = Math_imul($19, 16843009)|0;
   $21 = $20 >>> 24;
   $22 = (($21) + ($count$01$i))|0;
   $23 = (($i$02$i) + 1)|0;
   $exitcond$i = ($23|0)==($6|0);
   if ($exitcond$i) {
    break;
   } else {
    $count$01$i = $22;$i$02$i = $23;
   }
  }
  $24 = (($this) + 20|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($22>>>0)>($25>>>0);
  if ($26) {
   $27 = (($22) + 31)|0;
   $28 = $27 & -32;
   $29 = (($this) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $28 << 2;
   $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$31,481512,76)|0);
   $33 = ($30|0)==(0|0);
   if (!($33)) {
    $34 = $25 << 2;
    _memcpy(($32|0),($30|0),($34|0))|0;
   }
   $35 = (($32) + ($25<<2)|0);
   $36 = (($28) - ($25))|0;
   $37 = $36 << 2;
   _memset(($35|0),0,($37|0))|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$30);
   HEAP32[$29>>2] = $32;
   HEAP32[$24>>2] = $28;
   $$pre = HEAP32[$4>>2]|0;
   $39 = $$pre;
  } else {
   $39 = $5;
  }
 }
 $38 = $39 & 2147483647;
 $40 = ($38|0)==(0);
 L13: do {
  if ($40) {
   $numElems$0$lcssa = 0;
  } else {
   $$pre$i$i$i = HEAP32[$this>>2]|0;
   $42 = 0;
   while(1) {
    $41 = (($$pre$i$i$i) + ($42<<2)|0);
    $43 = HEAP32[$41>>2]|0;
    $44 = ($43|0)==(0);
    if (!($44)) {
     break;
    }
    $45 = (($42) + 1)|0;
    $46 = ($45>>>0)<($38>>>0);
    if ($46) {
     $42 = $45;
    } else {
     $numElems$0$lcssa = 0;
     break L13;
    }
   }
   $47 = $42 << 5;
   $48 = (0 - ($43))|0;
   $49 = $43 & $48;
   $50 = Math_imul($49, 125613361)|0;
   $51 = $50 >>> 27;
   $52 = (412480 + ($51<<2)|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $53 | $47;
   $55 = (($43) + -1)|0;
   $56 = $55 & $43;
   $57 = ($56|0)==(0);
   L19: do {
    if ($57) {
     $59 = $42;
     while(1) {
      $58 = (($59) + 1)|0;
      $60 = ($58>>>0)<($38>>>0);
      if (!($60)) {
       $$ph7 = $58;$$ph8 = 0;
       break L19;
      }
      $61 = (($$pre$i$i$i) + ($58<<2)|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($62|0)==(0);
      if ($63) {
       $59 = $58;
      } else {
       $$ph7 = $58;$$ph8 = $62;
       break;
      }
     }
    } else {
     $$ph7 = $42;$$ph8 = $56;
    }
   } while(0);
   $64 = ($54|0)==(-1);
   if ($64) {
    $numElems$0$lcssa = 0;
   } else {
    $65 = (($this) + 12|0);
    $66 = HEAP32[$65>>2]|0;
    $$ph1028 = $$ph8;$$ph927 = $$ph7;$index$0$ph1130 = $54;$numElems$0$ph29 = 0;
    while(1) {
     $69 = $$ph927 << 5;
     $73 = $$ph1028;$index$017 = $index$0$ph1130;$numElems$016 = $numElems$0$ph29;
     while(1) {
      $70 = (($66) + ($numElems$016<<2)|0);
      HEAP32[$70>>2] = $index$017;
      $71 = (($numElems$016) + 1)|0;
      $72 = ($73|0)==(0);
      if ($72) {
       $numElems$0$lcssa = $71;
       break L13;
      }
      $75 = (0 - ($73))|0;
      $76 = $73 & $75;
      $77 = Math_imul($76, 125613361)|0;
      $78 = $77 >>> 27;
      $79 = (412480 + ($78<<2)|0);
      $80 = HEAP32[$79>>2]|0;
      $68 = $80 | $69;
      $81 = (($73) + -1)|0;
      $82 = $81 & $73;
      $83 = HEAP32[$4>>2]|0;
      $84 = $83 & 2147483647;
      $85 = ($82|0)==(0);
      if ($85) {
       $87 = $$ph927;
       break;
      }
      $74 = ($68|0)==(-1);
      if ($74) {
       $numElems$0$lcssa = $71;
       break L13;
      } else {
       $73 = $82;$index$017 = $68;$numElems$016 = $71;
      }
     }
     while(1) {
      $86 = (($87) + 1)|0;
      $88 = ($86>>>0)<($84>>>0);
      if (!($88)) {
       $$ph = 0;
       break;
      }
      $89 = HEAP32[$this>>2]|0;
      $90 = (($89) + ($86<<2)|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = ($91|0)==(0);
      if ($92) {
       $87 = $86;
      } else {
       $$ph = $91;
       break;
      }
     }
     $67 = ($68|0)==(-1);
     if ($67) {
      $numElems$0$lcssa = $71;
      break;
     } else {
      $$ph1028 = $$ph;$$ph927 = $86;$index$0$ph1130 = $68;$numElems$0$ph29 = $71;
     }
    }
   }
  }
 } while(0);
 $93 = (($this) + 16|0);
 HEAP32[$93>>2] = $numElems$0$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager9prepareBPEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 49868|0);
 __ZNK5physx14SingleAABBTask25updateNumFastMovingShapesEv($0);
 $1 = (($this) + 50608|0);
 __ZNK5physx17AggregateAABBTask25updateNumFastMovingShapesEv($1);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager16processBPResultsERKNS_20PxsComputeAABBParamsE($this,$params) {
 $this = $this|0;
 $params = $params|0;
 var $$$i = 0, $$$i36 = 0, $$$i42 = 0, $$in = 0, $$not = 0, $$not8 = 0, $$ph = 0, $$ph59 = 0, $$ph60 = 0, $$ph61136 = 0, $$ph62137 = 0, $$ph78 = 0, $$ph80 = 0, $$ph81 = 0, $$ph82142 = 0, $$ph83143 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i20 = 0;
 var $$pre$i25 = 0, $$pre$i32 = 0, $$pre$i38 = 0, $$pre$i44 = 0, $$pre$phi$i26Z2D = 0, $$pre$phi$iZ2D = 0, $$pre1$i = 0, $$pre1$i34 = 0, $$pre1$i40 = 0, $$pre172 = 0, $$pre173 = 0, $$pre174 = 0, $$pre175 = 0, $$pre189$pre = 0, $$pre190$pre = 0, $$pre191 = 0, $$pre192 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0;
 var $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0;
 var $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $AggregateUpdatedElemIdsSize$0$lcssa = 0, $AggregateUpdatedElemIdsSize$0$ph138 = 0, $AggregateUpdatedElemIdsSize$067 = 0;
 var $AggregateUpdatedElemIdsSize$155 = 0, $AggregateUpdatedElemIdsSize$2 = 0, $AggregateUpdatedElemIdsSize$351 = 0, $AggregateUpdatedElemIdsSize$4 = 0, $AggregateUpdatedElemIdsSize$5 = 0, $NumAggregatePairsToOverlap$0$lcssa = 0, $NumAggregatePairsToOverlap$0102 = 0, $NumAggregatePairsToOverlap$1 = 0, $NumAggregatesToSort$0$lcssa = 0, $NumAggregatesToSort$0110 = 0, $NumAggregatesToSort$1 = 0, $NumAggregatesToSort$2$lcssa = 0, $NumAggregatesToSort$2104 = 0, $NumAggregatesToSort$3 = 0, $NumAggregatesToSort$4 = 0, $NumAggregatesToSort$5 = 0, $NumAggregatesToSort$6$ph144 = 0, $NumAggregatesToSort$690 = 0, $NumAggregatesToSort$7 = 0, $aggregateId0$0 = 0;
 var $aggregateId1$0 = 0, $aggregatesNeedingSorted = 0, $brmerge = 0, $brmerge9 = 0, $eitherUpdated$0$off0 = 0, $elemId$056 = 0, $elemId20$052 = 0, $exitcond = 0, $exitcond167 = 0, $exitcond168 = 0, $exitcond169 = 0, $exitcond170 = 0, $exitcond171 = 0, $handles$0131 = 0, $i$0126 = 0, $i1$0122 = 0, $i12$0109 = 0, $i15$0101 = 0, $i6$0119 = 0, $i9$0115 = 0;
 var $index$0$ph84145 = 0, $index$091 = 0, $index17$0$ph63139 = 0, $index17$068 = 0, $numCreatedAggregatePairs$0$lcssa = 0, $numCreatedAggregatePairs$0127 = 0, $numCreatedAggregatePairs$1 = 0, $numDeletedAggregatePairs$0123 = 0, $numDeletedAggregatePairs$1 = 0, $phitmp195 = 0, $phitmp197 = 0, $userData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1072|0;
 $0 = sp + 1060|0;
 $1 = sp;
 $userData = sp + 1056|0;
 $aggregatesNeedingSorted = sp + 528|0;
 $2 = (($this) + 49828|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 $8 = HEAP32[$2>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
 $13 = ($7|0)==(0);
 if (!($13)) {
  $14 = (($this) + 24|0);
  $15 = (($this) + 16|0);
  $16 = (($this) + 51600|0);
  $17 = (($this) + 51608|0);
  $18 = (($this) + 51604|0);
  $19 = (($this) + 180|0);
  $20 = (($this) + 51612|0);
  $21 = (($this) + 51620|0);
  $22 = (($this) + 51616|0);
  $$in = $7;$handles$0131 = $12;
  while(1) {
   $23 = (($$in) + -1)|0;
   $24 = (($handles$0131) + 4|0);
   $25 = HEAP32[$handles$0131>>2]|0;
   $26 = HEAP32[$14>>2]|0;
   $27 = (($26) + ($25<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $28 & 1;
   $30 = ($29|0)==(0);
   do {
    if ($30) {
     $31 = HEAP32[$15>>2]|0;
     $32 = (($31) + ($25<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     HEAP32[$userData>>2] = $33;
     $34 = HEAP32[$17>>2]|0;
     $35 = $34 & 2147483647;
     $36 = HEAP32[$18>>2]|0;
     $37 = ($35>>>0)>($36>>>0);
     if (!($37)) {
      (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($16,$userData)|0);
      break;
     }
     $39 = HEAP32[$16>>2]|0;
     $40 = (($39) + ($36<<2)|0);
     $41 = ($40|0)==(0|0);
     if (!($41)) {
      HEAP32[$40>>2] = $33;
     }
     $42 = (($36) + 1)|0;
     HEAP32[$18>>2] = $42;
    } else {
     $43 = $28 >>> 1;
     $44 = HEAP32[$19>>2]|0;
     $45 = ((($44) + (($43*1048)|0)|0) + 1044|0);
     $46 = HEAP32[$21>>2]|0;
     $47 = $46 & 2147483647;
     $48 = HEAP32[$22>>2]|0;
     $49 = ($47>>>0)>($48>>>0);
     if (!($49)) {
      (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($20,$45)|0);
      break;
     }
     $50 = HEAP32[$20>>2]|0;
     $51 = (($50) + ($48<<2)|0);
     $52 = ($51|0)==(0|0);
     if (!($52)) {
      $53 = HEAP32[$45>>2]|0;
      HEAP32[$51>>2] = $53;
     }
     $54 = (($48) + 1)|0;
     HEAP32[$22>>2] = $54;
    }
   } while(0);
   $38 = ($23|0)==(0);
   if ($38) {
    break;
   } else {
    $$in = $23;$handles$0131 = $24;
   }
  }
 }
 $55 = (($this) + 49836|0);
 HEAP32[$55>>2] = 0;
 $56 = (($this) + 49848|0);
 HEAP32[$56>>2] = 0;
 $57 = HEAP32[$2>>2]|0;
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + 48|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (FUNCTION_TABLE_ii[$60 & 4095]($57)|0);
 $62 = HEAP32[$2>>2]|0;
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 56|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (FUNCTION_TABLE_ii[$65 & 4095]($62)|0);
 $67 = HEAP32[$2>>2]|0;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + 52|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
 $72 = HEAP32[$2>>2]|0;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73) + 60|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (FUNCTION_TABLE_ii[$75 & 4095]($72)|0);
 $77 = ($61|0)==(0);
 if ($77) {
  $numCreatedAggregatePairs$0$lcssa = 0;
 } else {
  $78 = (($this) + 24|0);
  $79 = (($this) + 16|0);
  $80 = (($this) + 49840|0);
  $81 = (($this) + 49832|0);
  $i$0126 = 0;$numCreatedAggregatePairs$0127 = 0;
  while(1) {
   $87 = (($71) + ($i$0126<<3)|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ((($71) + ($i$0126<<3)|0) + 4|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = HEAP32[$78>>2]|0;
   $92 = (($91) + ($88<<2)|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($91) + ($90<<2)|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = $95 | $93;
   $97 = $96 & 1;
   $98 = ($97|0)==(0);
   if ($98) {
    $99 = HEAP32[$79>>2]|0;
    $100 = (($99) + ($88<<2)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = (($99) + ($90<<2)|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = HEAP32[$55>>2]|0;
    $105 = HEAP32[$80>>2]|0;
    $106 = ($104|0)==($105|0);
    if ($106) {
     $107 = ($104|0)==(0);
     $108 = $104 << 1;
     $$$i = $107 ? 32 : $108;
     $109 = HEAP32[$81>>2]|0;
     $110 = $$$i << 3;
     $111 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$110,481512,76)|0);
     $112 = ($109|0)==(0|0);
     if (!($112)) {
      $113 = $104 << 3;
      _memcpy(($111|0),($109|0),($113|0))|0;
     }
     $114 = (($111) + ($104<<3)|0);
     $115 = (($$$i) - ($104))|0;
     $116 = $115 << 3;
     _memset(($114|0),0,($116|0))|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$109);
     HEAP32[$81>>2] = $111;
     HEAP32[$80>>2] = $$$i;
     $$pre$i32 = HEAP32[$55>>2]|0;
     $118 = $$pre$i32;$120 = $111;
    } else {
     $$pre1$i = HEAP32[$81>>2]|0;
     $118 = $104;$120 = $$pre1$i;
    }
    $117 = (($118) + 1)|0;
    HEAP32[$55>>2] = $117;
    $119 = (($120) + ($118<<3)|0);
    HEAP32[$119>>2] = $101;
    $121 = ((($120) + ($118<<3)|0) + 4|0);
    HEAP32[$121>>2] = $103;
    $numCreatedAggregatePairs$1 = $numCreatedAggregatePairs$0127;
   } else {
    $122 = (($71) + ($numCreatedAggregatePairs$0127<<3)|0);
    HEAP32[$122>>2] = $88;
    $123 = ((($71) + ($numCreatedAggregatePairs$0127<<3)|0) + 4|0);
    HEAP32[$123>>2] = $90;
    $124 = (($numCreatedAggregatePairs$0127) + 1)|0;
    $numCreatedAggregatePairs$1 = $124;
   }
   $125 = (($i$0126) + 1)|0;
   $exitcond171 = ($125|0)==($61|0);
   if ($exitcond171) {
    $numCreatedAggregatePairs$0$lcssa = $numCreatedAggregatePairs$1;
    break;
   } else {
    $i$0126 = $125;$numCreatedAggregatePairs$0127 = $numCreatedAggregatePairs$1;
   }
  }
 }
 $82 = ($66|0)==(0);
 if (!($82)) {
  $83 = (($this) + 24|0);
  $84 = (($this) + 16|0);
  $85 = (($this) + 49852|0);
  $86 = (($this) + 49844|0);
  $i1$0122 = 0;$numDeletedAggregatePairs$0123 = 0;
  while(1) {
   $127 = (($76) + ($i1$0122<<3)|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = ((($76) + ($i1$0122<<3)|0) + 4|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = HEAP32[$83>>2]|0;
   $132 = (($131) + ($128<<2)|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = (($131) + ($130<<2)|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = $135 | $133;
   $137 = $136 & 1;
   $138 = ($137|0)==(0);
   if ($138) {
    $139 = HEAP32[$84>>2]|0;
    $140 = (($139) + ($128<<2)|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (($139) + ($130<<2)|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = HEAP32[$56>>2]|0;
    $145 = HEAP32[$85>>2]|0;
    $146 = ($144|0)==($145|0);
    if ($146) {
     $147 = ($144|0)==(0);
     $148 = $144 << 1;
     $$$i42 = $147 ? 32 : $148;
     $149 = HEAP32[$86>>2]|0;
     $150 = $$$i42 << 3;
     $151 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$150,481512,76)|0);
     $152 = ($149|0)==(0|0);
     if (!($152)) {
      $153 = $144 << 3;
      _memcpy(($151|0),($149|0),($153|0))|0;
     }
     $154 = (($151) + ($144<<3)|0);
     $155 = (($$$i42) - ($144))|0;
     $156 = $155 << 3;
     _memset(($154|0),0,($156|0))|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$149);
     HEAP32[$86>>2] = $151;
     HEAP32[$85>>2] = $$$i42;
     $$pre$i44 = HEAP32[$56>>2]|0;
     $158 = $$pre$i44;$160 = $151;
    } else {
     $$pre1$i40 = HEAP32[$86>>2]|0;
     $158 = $144;$160 = $$pre1$i40;
    }
    $157 = (($158) + 1)|0;
    HEAP32[$56>>2] = $157;
    $159 = (($160) + ($158<<3)|0);
    HEAP32[$159>>2] = $141;
    $161 = ((($160) + ($158<<3)|0) + 4|0);
    HEAP32[$161>>2] = $143;
    $numDeletedAggregatePairs$1 = $numDeletedAggregatePairs$0123;
   } else {
    $162 = (($76) + ($numDeletedAggregatePairs$0123<<3)|0);
    HEAP32[$162>>2] = $128;
    $163 = ((($76) + ($numDeletedAggregatePairs$0123<<3)|0) + 4|0);
    HEAP32[$163>>2] = $130;
    $164 = (($numDeletedAggregatePairs$0123) + 1)|0;
    $numDeletedAggregatePairs$1 = $164;
   }
   $165 = (($i1$0122) + 1)|0;
   $exitcond170 = ($165|0)==($66|0);
   if ($exitcond170) {
    break;
   } else {
    $i1$0122 = $165;$numDeletedAggregatePairs$0123 = $numDeletedAggregatePairs$1;
   }
  }
  $126 = ($numDeletedAggregatePairs$1|0)==(0);
  if (!($126)) {
   $i6$0119 = 0;
   while(1) {
    $170 = (($76) + ($i6$0119<<3)|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = ((($76) + ($i6$0119<<3)|0) + 4|0);
    $173 = HEAP32[$172>>2]|0;
    (__ZN5physx14PxsAABBManager19removeAggregatePairEjj($this,$171,$173)|0);
    $174 = (($i6$0119) + 1)|0;
    $exitcond169 = ($174|0)==($numDeletedAggregatePairs$1|0);
    if ($exitcond169) {
     break;
    } else {
     $i6$0119 = $174;
    }
   }
  }
 }
 $166 = ($numCreatedAggregatePairs$0$lcssa|0)==(0);
 if (!($166)) {
  $167 = (($this) + 49860|0);
  $168 = (($this) + 49864|0);
  $169 = (($this) + 49856|0);
  $i9$0115 = 0;
  while(1) {
   $175 = (($71) + ($i9$0115<<3)|0);
   $176 = HEAP32[$175>>2]|0;
   $177 = ((($71) + ($i9$0115<<3)|0) + 4|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = HEAP32[$167>>2]|0;
   $180 = HEAP32[$168>>2]|0;
   $181 = ($179|0)==($180|0);
   if ($181) {
    $182 = ($179|0)==(0);
    $183 = $179 << 1;
    $$$i36 = $182 ? 32 : $183;
    $184 = HEAP32[$169>>2]|0;
    $185 = ($$$i36*12)|0;
    $186 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$185,481512,76)|0);
    $187 = ($184|0)==(0|0);
    if (!($187)) {
     $188 = ($179*12)|0;
     _memcpy(($186|0),($184|0),($188|0))|0;
    }
    $189 = (($186) + (($179*12)|0)|0);
    $190 = (($$$i36) - ($179))|0;
    $191 = ($190*12)|0;
    _memset(($189|0),0,($191|0))|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$184);
    HEAP32[$169>>2] = $186;
    HEAP32[$168>>2] = $$$i36;
    $$pre$i38 = HEAP32[$167>>2]|0;
    $193 = $$pre$i38;$197 = $186;
   } else {
    $$pre1$i34 = HEAP32[$169>>2]|0;
    $193 = $179;$197 = $$pre1$i34;
   }
   $192 = (($193) + 1)|0;
   HEAP32[$167>>2] = $192;
   $194 = ($176>>>0)<($178>>>0);
   $195 = $194 ? $176 : $178;
   $196 = (($197) + (($193*12)|0)|0);
   HEAP32[$196>>2] = $195;
   $198 = $194 ? $178 : $176;
   $199 = ((($197) + (($193*12)|0)|0) + 4|0);
   HEAP32[$199>>2] = $198;
   $200 = ((($197) + (($193*12)|0)|0) + 8|0);
   HEAP32[$200>>2] = 0;
   $201 = (($i9$0115) + 1)|0;
   $exitcond168 = ($201|0)==($numCreatedAggregatePairs$0$lcssa|0);
   if ($exitcond168) {
    break;
   } else {
    $i9$0115 = $201;
   }
  }
 }
 $202 = (($this) + 196|0);
 $203 = HEAP32[$202>>2]|0;
 $204 = ($203|0)==(0);
 if ($204) {
  STACKTOP = sp;return;
 }
 $205 = HEAP32[$this>>2]|0;
 $206 = (($1) + 512|0);
 HEAP32[$206>>2] = $205;
 $207 = (($1) + 516|0);
 HEAP32[$207>>2] = 0;
 $208 = (($1) + 520|0);
 HEAP32[$208>>2] = 0;
 $209 = (($203) + 31)|0;
 $210 = $209 >>> 5;
 $211 = ($203>>>0)>(4096);
 do {
  if ($211) {
   $212 = $210 << 2;
   $213 = (($212) + 15)|0;
   $214 = $213 & 1073741808;
   $215 = ($205|0)==(0|0);
   if ($215) {
    $218 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$214,481512,2004)|0);
    HEAP32[$207>>2] = $218;
    $219 = $210 | -2147483648;
    HEAP32[$208>>2] = $219;
    $222 = $219;$223 = $218;
    break;
   } else {
    $216 = (__ZN5physx19PxcScratchAllocator5allocEjb($205,$214,1)|0);
    HEAP32[$207>>2] = $216;
    $217 = $210 | -2147483648;
    HEAP32[$208>>2] = $217;
    $222 = $217;$223 = $216;
    break;
   }
  } else {
   HEAP32[$207>>2] = $1;
   $220 = $210 | -2147483648;
   HEAP32[$208>>2] = $220;
   $222 = $220;$223 = $1;
  }
 } while(0);
 $221 = $222 << 2;
 _memset(($223|0),0,($221|0))|0;
 $$pre = HEAP32[$207>>2]|0;
 $$pre172 = HEAP32[$208>>2]|0;
 $phitmp195 = $$pre172 << 2;
 _memset(($$pre|0),0,($phitmp195|0))|0;
 $224 = HEAP32[$202>>2]|0;
 $225 = HEAP32[$this>>2]|0;
 $226 = (($aggregatesNeedingSorted) + 512|0);
 HEAP32[$226>>2] = $225;
 $227 = (($aggregatesNeedingSorted) + 516|0);
 HEAP32[$227>>2] = 0;
 $228 = (($aggregatesNeedingSorted) + 520|0);
 HEAP32[$228>>2] = 0;
 $229 = ($224|0)==(0);
 if ($229) {
  $245 = 0;$246 = 0;
 } else {
  $230 = (($224) + 31)|0;
  $231 = $230 >>> 5;
  $232 = ($224>>>0)>(4096);
  do {
   if ($232) {
    $233 = $231 << 2;
    $234 = (($233) + 15)|0;
    $235 = $234 & 1073741808;
    $236 = ($225|0)==(0|0);
    if ($236) {
     $239 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$235,481512,2004)|0);
     HEAP32[$227>>2] = $239;
     $240 = $231 | -2147483648;
     HEAP32[$228>>2] = $240;
     $243 = $240;$244 = $239;
     break;
    } else {
     $237 = (__ZN5physx19PxcScratchAllocator5allocEjb($225,$235,1)|0);
     HEAP32[$227>>2] = $237;
     $238 = $231 | -2147483648;
     HEAP32[$228>>2] = $238;
     $243 = $238;$244 = $237;
     break;
    }
   } else {
    HEAP32[$227>>2] = $aggregatesNeedingSorted;
    $241 = $231 | -2147483648;
    HEAP32[$228>>2] = $241;
    $243 = $241;$244 = $aggregatesNeedingSorted;
   }
  } while(0);
  $242 = $243 << 2;
  _memset(($244|0),0,($242|0))|0;
  $$pre173 = HEAP32[$227>>2]|0;
  $$pre174 = HEAP32[$228>>2]|0;
  $phitmp197 = $$pre174 << 2;
  $245 = $$pre173;$246 = $phitmp197;
 }
 _memset(($245|0),0,($246|0))|0;
 $247 = (($this) + 49860|0);
 $248 = HEAP32[$247>>2]|0;
 $249 = ($248|0)==(0);
 if (!($249)) {
  $250 = ($248>>>0)>(1024);
  do {
   if ($250) {
    $251 = $248 << 2;
    $252 = (($251) + 15)|0;
    $253 = $252 & -16;
    $254 = (($this) + 49808|0);
    $255 = HEAP32[$254>>2]|0;
    $256 = ($255|0)==(0|0);
    if ($256) {
     $259 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$253,481512,1936)|0);
     $260 = (($this) + 49812|0);
     HEAP32[$260>>2] = $259;
     $$pre$phi$i26Z2D = $251;$263 = $259;
     break;
    } else {
     $257 = (__ZN5physx19PxcScratchAllocator5allocEjb($255,$253,1)|0);
     $258 = (($this) + 49812|0);
     HEAP32[$258>>2] = $257;
     $$pre$phi$i26Z2D = $251;$263 = $257;
     break;
    }
   } else {
    $261 = (($this) + 45712|0);
    $262 = (($this) + 49812|0);
    HEAP32[$262>>2] = $261;
    $$pre$i25 = $248 << 2;
    $$pre$phi$i26Z2D = $$pre$i25;$263 = $261;
   }
  } while(0);
  _memset(($263|0),0,($$pre$phi$i26Z2D|0))|0;
  $264 = (($this) + 49816|0);
  HEAP32[$264>>2] = $248;
 }
 $265 = (($this) + 49812|0);
 $266 = HEAP32[$265>>2]|0;
 $267 = (($this) + 356|0);
 $268 = (($this) + 372|0);
 $269 = HEAP32[$268>>2]|0;
 $270 = (($this) + 368|0);
 $271 = HEAP32[$270>>2]|0;
 $272 = ($269|0)==(0);
 if ($272) {
  $NumAggregatesToSort$0$lcssa = 0;
 } else {
  $273 = (($this) + 180|0);
  $274 = (($this) + 232|0);
  $275 = (($this) + 220|0);
  $$pre175 = HEAP32[$273>>2]|0;
  $NumAggregatesToSort$0110 = 0;$i12$0109 = 0;
  while(1) {
   $276 = (($271) + ($i12$0109<<2)|0);
   $277 = HEAP32[$276>>2]|0;
   $278 = ((($$pre175) + (($277*1048)|0)|0) + 1024|0);
   $279 = HEAP8[$278>>0]|0;
   $280 = ($279<<24>>24)==(0);
   if ($280) {
    label = 72;
   } else {
    $281 = ((($$pre175) + (($277*1048)|0)|0) + 1026|0);
    $282 = HEAP8[$281>>0]|0;
    $283 = ($282<<24>>24)==(0);
    if ($283) {
     label = 72;
    } else {
     $284 = $277 & 31;
     $285 = 1 << $284;
     $286 = $277 >>> 5;
     $287 = HEAP32[$227>>2]|0;
     $288 = (($287) + ($286<<2)|0);
     $289 = HEAP32[$288>>2]|0;
     $290 = $289 | $285;
     HEAP32[$288>>2] = $290;
     $291 = (($NumAggregatesToSort$0110) + 1)|0;
     $NumAggregatesToSort$1 = $291;
    }
   }
   if ((label|0) == 72) {
    label = 0;
    $292 = $277 >>> 5;
    $293 = HEAP32[$274>>2]|0;
    $294 = (($293) + ($292<<2)|0);
    $295 = HEAP32[$294>>2]|0;
    $296 = $277 & 31;
    $297 = 1 << $296;
    $298 = $295 & $297;
    $299 = ($298|0)==(0);
    if ($299) {
     $300 = ((($$pre175) + (($277*1048)|0)|0) + 1026|0);
     $301 = HEAP8[$300>>0]|0;
     $302 = ($301<<24>>24)==(0);
     if ($302) {
      $NumAggregatesToSort$1 = $NumAggregatesToSort$0110;
     } else {
      $303 = HEAP32[$275>>2]|0;
      $304 = (($303) + ($292<<2)|0);
      $305 = HEAP32[$304>>2]|0;
      $306 = $305 | $297;
      HEAP32[$304>>2] = $306;
      $NumAggregatesToSort$1 = $NumAggregatesToSort$0110;
     }
    } else {
     $NumAggregatesToSort$1 = $NumAggregatesToSort$0110;
    }
   }
   $307 = (($i12$0109) + 1)|0;
   $exitcond167 = ($307|0)==($269|0);
   if ($exitcond167) {
    $NumAggregatesToSort$0$lcssa = $NumAggregatesToSort$1;
    break;
   } else {
    $NumAggregatesToSort$0110 = $NumAggregatesToSort$1;$i12$0109 = $307;
   }
  }
 }
 $308 = HEAP32[$247>>2]|0;
 $309 = ($308|0)==(0);
 if ($309) {
  $NumAggregatePairsToOverlap$0$lcssa = 0;$NumAggregatesToSort$2$lcssa = $NumAggregatesToSort$0$lcssa;
 } else {
  $310 = (($this) + 49856|0);
  $311 = HEAP32[$310>>2]|0;
  $312 = (($this) + 24|0);
  $313 = HEAP32[$312>>2]|0;
  $314 = (($this) + 68|0);
  $315 = (($this) + 96|0);
  $316 = HEAP32[$227>>2]|0;
  $317 = HEAP32[$207>>2]|0;
  $318 = (($this) + 220|0);
  $NumAggregatePairsToOverlap$0102 = 0;$NumAggregatesToSort$2104 = $NumAggregatesToSort$0$lcssa;$i15$0101 = 0;
  while(1) {
   $319 = (($311) + (($i15$0101*12)|0)|0);
   $320 = HEAP32[$319>>2]|0;
   $321 = ((($311) + (($i15$0101*12)|0)|0) + 4|0);
   $322 = HEAP32[$321>>2]|0;
   $323 = (($313) + ($320<<2)|0);
   $324 = HEAP32[$323>>2]|0;
   $325 = $324 & 1;
   $326 = ($325|0)==(0);
   if ($326) {
    $327 = $320 >>> 5;
    $328 = HEAP32[$314>>2]|0;
    $329 = (($328) + ($327<<2)|0);
    $330 = HEAP32[$329>>2]|0;
    $331 = $320 & 31;
    $332 = 1 << $331;
    $333 = $330 & $332;
    $334 = ($333|0)==(0);
    if ($334) {
     $335 = HEAP32[$315>>2]|0;
     $336 = (($335) + ($327<<2)|0);
     $337 = HEAP32[$336>>2]|0;
     $338 = $337 & $332;
     $$not = ($338|0)!=(0);
     $brmerge = $$not | $326;
     if ($brmerge) {
      $eitherUpdated$0$off0 = $$not;
     } else {
      label = 81;
     }
    } else {
     $eitherUpdated$0$off0 = 1;
    }
   } else {
    label = 81;
   }
   do {
    if ((label|0) == 81) {
     label = 0;
     $339 = $324 >>> 1;
     $340 = $324 >>> 6;
     $341 = HEAP32[$267>>2]|0;
     $342 = (($341) + ($340<<2)|0);
     $343 = HEAP32[$342>>2]|0;
     $344 = $339 & 31;
     $345 = 1 << $344;
     $346 = $343 & $345;
     $347 = ($346|0)==(0);
     if ($347) {
      $348 = $320 >>> 5;
      $349 = HEAP32[$315>>2]|0;
      $350 = (($349) + ($348<<2)|0);
      $351 = HEAP32[$350>>2]|0;
      $352 = $320 & 31;
      $353 = 1 << $352;
      $354 = $351 & $353;
      $355 = ($354|0)==(0);
      if ($355) {
       $eitherUpdated$0$off0 = 0;
       break;
      }
     }
     $eitherUpdated$0$off0 = 1;
    }
   } while(0);
   $356 = (($313) + ($322<<2)|0);
   $357 = HEAP32[$356>>2]|0;
   $358 = $357 & 1;
   $359 = ($358|0)==(0);
   if ($359) {
    $360 = $322 >>> 5;
    $361 = HEAP32[$314>>2]|0;
    $362 = (($361) + ($360<<2)|0);
    $363 = HEAP32[$362>>2]|0;
    $364 = $322 & 31;
    $365 = 1 << $364;
    $366 = $363 & $365;
    $367 = ($366|0)==(0);
    if ($367) {
     $368 = HEAP32[$315>>2]|0;
     $369 = (($368) + ($360<<2)|0);
     $370 = HEAP32[$369>>2]|0;
     $371 = $370 & $365;
     $372 = ($371|0)==(0);
     if ($372) {
      if ($359) {
       if ($eitherUpdated$0$off0) {
        label = 91;
       } else {
        $NumAggregatePairsToOverlap$1 = $NumAggregatePairsToOverlap$0102;$NumAggregatesToSort$5 = $NumAggregatesToSort$2104;
       }
      } else {
       label = 88;
      }
     } else {
      label = 91;
     }
    } else {
     label = 91;
    }
   } else {
    label = 88;
   }
   if ((label|0) == 88) {
    label = 0;
    $373 = $357 >>> 1;
    $374 = $357 >>> 6;
    $375 = HEAP32[$267>>2]|0;
    $376 = (($375) + ($374<<2)|0);
    $377 = HEAP32[$376>>2]|0;
    $378 = $373 & 31;
    $379 = 1 << $378;
    $380 = $377 & $379;
    $381 = ($380|0)==(0);
    if ($381) {
     $382 = $322 >>> 5;
     $383 = HEAP32[$315>>2]|0;
     $384 = (($383) + ($382<<2)|0);
     $385 = HEAP32[$384>>2]|0;
     $386 = $322 & 31;
     $387 = 1 << $386;
     $388 = $385 & $387;
     $$not8 = ($388|0)!=(0);
     $brmerge9 = $$not8 | $eitherUpdated$0$off0;
     if ($brmerge9) {
      label = 91;
     } else {
      $NumAggregatePairsToOverlap$1 = $NumAggregatePairsToOverlap$0102;$NumAggregatesToSort$5 = $NumAggregatesToSort$2104;
     }
    } else {
     label = 91;
    }
   }
   if ((label|0) == 91) {
    label = 0;
    if ($326) {
     $407 = $357;$aggregateId0$0 = 1073741823;
    } else {
     $389 = $324 >>> 1;
     $390 = $324 >>> 6;
     $391 = (($317) + ($390<<2)|0);
     $392 = HEAP32[$391>>2]|0;
     $393 = $389 & 31;
     $394 = 1 << $393;
     $395 = $392 & $394;
     $396 = ($395|0)==(0);
     if ($396) {
      $397 = HEAP32[$318>>2]|0;
      $398 = (($397) + ($390<<2)|0);
      $399 = HEAP32[$398>>2]|0;
      $400 = $399 & $394;
      $401 = ($400|0)==(0);
      if ($401) {
       $407 = $357;$aggregateId0$0 = $389;
      } else {
       $402 = $394 ^ -1;
       $403 = $399 & $402;
       HEAP32[$398>>2] = $403;
       $404 = HEAP32[$391>>2]|0;
       $405 = $404 | $394;
       HEAP32[$391>>2] = $405;
       $$pre192 = HEAP32[$356>>2]|0;
       $407 = $$pre192;$aggregateId0$0 = $389;
      }
     } else {
      $407 = $357;$aggregateId0$0 = $389;
     }
    }
    $406 = $407 & 1;
    $408 = ($406|0)==(0);
    if ($408) {
     $aggregateId1$0 = 1073741823;
    } else {
     $409 = $407 >>> 1;
     $410 = $407 >>> 6;
     $411 = (($317) + ($410<<2)|0);
     $412 = HEAP32[$411>>2]|0;
     $413 = $409 & 31;
     $414 = 1 << $413;
     $415 = $412 & $414;
     $416 = ($415|0)==(0);
     if ($416) {
      $417 = HEAP32[$318>>2]|0;
      $418 = (($417) + ($410<<2)|0);
      $419 = HEAP32[$418>>2]|0;
      $420 = $419 & $414;
      $421 = ($420|0)==(0);
      if ($421) {
       $aggregateId1$0 = $409;
      } else {
       $422 = $414 ^ -1;
       $423 = $419 & $422;
       HEAP32[$418>>2] = $423;
       $424 = HEAP32[$411>>2]|0;
       $425 = $424 | $414;
       HEAP32[$411>>2] = $425;
       $aggregateId1$0 = $409;
      }
     } else {
      $aggregateId1$0 = $409;
     }
    }
    $426 = ($aggregateId0$0|0)==(1073741823);
    if ($426) {
     $NumAggregatesToSort$3 = $NumAggregatesToSort$2104;
    } else {
     $427 = $aggregateId0$0 >>> 5;
     $428 = (($316) + ($427<<2)|0);
     $429 = HEAP32[$428>>2]|0;
     $430 = $aggregateId0$0 & 31;
     $431 = 1 << $430;
     $432 = $429 & $431;
     $433 = ($432|0)==(0);
     if ($433) {
      $434 = $429 | $431;
      HEAP32[$428>>2] = $434;
      $435 = (($NumAggregatesToSort$2104) + 1)|0;
      $NumAggregatesToSort$3 = $435;
     } else {
      $NumAggregatesToSort$3 = $NumAggregatesToSort$2104;
     }
    }
    $436 = ($aggregateId1$0|0)==(1073741823);
    do {
     if ($436) {
      $NumAggregatesToSort$4 = $NumAggregatesToSort$3;
     } else {
      $437 = $aggregateId1$0 >>> 5;
      $438 = (($316) + ($437<<2)|0);
      $439 = HEAP32[$438>>2]|0;
      $440 = $aggregateId1$0 & 31;
      $441 = 1 << $440;
      $442 = $439 & $441;
      $443 = ($442|0)==(0);
      if (!($443)) {
       $NumAggregatesToSort$4 = $NumAggregatesToSort$3;
       break;
      }
      $444 = $439 | $441;
      HEAP32[$438>>2] = $444;
      $445 = (($NumAggregatesToSort$3) + 1)|0;
      $NumAggregatesToSort$4 = $445;
     }
    } while(0);
    $446 = (($266) + ($NumAggregatePairsToOverlap$0102<<2)|0);
    HEAP32[$446>>2] = $i15$0101;
    $447 = (($NumAggregatePairsToOverlap$0102) + 1)|0;
    $NumAggregatePairsToOverlap$1 = $447;$NumAggregatesToSort$5 = $NumAggregatesToSort$4;
   }
   $448 = (($i15$0101) + 1)|0;
   $exitcond = ($448|0)==($308|0);
   if ($exitcond) {
    $NumAggregatePairsToOverlap$0$lcssa = $NumAggregatePairsToOverlap$1;$NumAggregatesToSort$2$lcssa = $NumAggregatesToSort$5;
    break;
   } else {
    $NumAggregatePairsToOverlap$0102 = $NumAggregatePairsToOverlap$1;$NumAggregatesToSort$2104 = $NumAggregatesToSort$5;$i15$0101 = $448;
   }
  }
 }
 $449 = (($this) + 49824|0);
 HEAP32[$449>>2] = $NumAggregatePairsToOverlap$0$lcssa;
 $450 = ($NumAggregatesToSort$2$lcssa|0)==(0);
 L155: do {
  if ($450) {
   $NumAggregatesToSort$7 = 0;
  } else {
   $451 = ($NumAggregatesToSort$2$lcssa>>>0)>(1024);
   do {
    if ($451) {
     $452 = $NumAggregatesToSort$2$lcssa << 2;
     $453 = (($452) + 15)|0;
     $454 = $453 & -16;
     $455 = (($this) + 45680|0);
     $456 = HEAP32[$455>>2]|0;
     $457 = ($456|0)==(0|0);
     if ($457) {
      $460 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$454,481512,1936)|0);
      $461 = (($this) + 45684|0);
      HEAP32[$461>>2] = $460;
      $$pre$phi$iZ2D = $452;$464 = $460;
      break;
     } else {
      $458 = (__ZN5physx19PxcScratchAllocator5allocEjb($456,$454,1)|0);
      $459 = (($this) + 45684|0);
      HEAP32[$459>>2] = $458;
      $$pre$phi$iZ2D = $452;$464 = $458;
      break;
     }
    } else {
     $462 = (($this) + 41584|0);
     $463 = (($this) + 45684|0);
     HEAP32[$463>>2] = $462;
     $$pre$i = $NumAggregatesToSort$2$lcssa << 2;
     $$pre$phi$iZ2D = $$pre$i;$464 = $462;
    }
   } while(0);
   _memset(($464|0),0,($$pre$phi$iZ2D|0))|0;
   $465 = (($this) + 45688|0);
   HEAP32[$465>>2] = $NumAggregatesToSort$2$lcssa;
   $466 = (($this) + 45684|0);
   $467 = HEAP32[$466>>2]|0;
   $468 = (($aggregatesNeedingSorted) + 516|0);
   $469 = HEAP32[$228>>2]|0;
   $470 = $469 & 2147483647;
   $471 = ($470|0)==(0);
   if ($471) {
    $NumAggregatesToSort$7 = 0;
   } else {
    $$pre$i$i$i20 = HEAP32[$468>>2]|0;
    $473 = 0;
    while(1) {
     $472 = (($$pre$i$i$i20) + ($473<<2)|0);
     $474 = HEAP32[$472>>2]|0;
     $475 = ($474|0)==(0);
     if (!($475)) {
      break;
     }
     $476 = (($473) + 1)|0;
     $477 = ($476>>>0)<($470>>>0);
     if ($477) {
      $473 = $476;
     } else {
      $NumAggregatesToSort$7 = 0;
      break L155;
     }
    }
    $478 = $473 << 5;
    $479 = (0 - ($474))|0;
    $480 = $474 & $479;
    $481 = Math_imul($480, 125613361)|0;
    $482 = $481 >>> 27;
    $483 = (412480 + ($482<<2)|0);
    $484 = HEAP32[$483>>2]|0;
    $485 = $484 | $478;
    $486 = (($474) + -1)|0;
    $487 = $486 & $474;
    $488 = ($487|0)==(0);
    L169: do {
     if ($488) {
      $490 = $473;
      while(1) {
       $489 = (($490) + 1)|0;
       $491 = ($489>>>0)<($470>>>0);
       if (!($491)) {
        $$ph80 = $489;$$ph81 = 0;
        break L169;
       }
       $492 = (($$pre$i$i$i20) + ($489<<2)|0);
       $493 = HEAP32[$492>>2]|0;
       $494 = ($493|0)==(0);
       if ($494) {
        $490 = $489;
       } else {
        $$ph80 = $489;$$ph81 = $493;
        break;
       }
      }
     } else {
      $$ph80 = $473;$$ph81 = $487;
     }
    } while(0);
    $495 = ($485|0)==(-1);
    if ($495) {
     $NumAggregatesToSort$7 = 0;
    } else {
     $496 = HEAP32[$468>>2]|0;
     $$ph82142 = $$ph80;$$ph83143 = $$ph81;$NumAggregatesToSort$6$ph144 = 0;$index$0$ph84145 = $485;
     while(1) {
      $499 = $$ph82142 << 5;
      $503 = $$ph83143;$NumAggregatesToSort$690 = $NumAggregatesToSort$6$ph144;$index$091 = $index$0$ph84145;
      while(1) {
       $500 = (($467) + ($NumAggregatesToSort$690<<2)|0);
       HEAP32[$500>>2] = $index$091;
       $501 = (($NumAggregatesToSort$690) + 1)|0;
       $502 = ($503|0)==(0);
       if ($502) {
        $NumAggregatesToSort$7 = $501;
        break L155;
       }
       $505 = (0 - ($503))|0;
       $506 = $503 & $505;
       $507 = Math_imul($506, 125613361)|0;
       $508 = $507 >>> 27;
       $509 = (412480 + ($508<<2)|0);
       $510 = HEAP32[$509>>2]|0;
       $498 = $510 | $499;
       $511 = (($503) + -1)|0;
       $512 = $511 & $503;
       $513 = HEAP32[$228>>2]|0;
       $514 = $513 & 2147483647;
       $515 = ($512|0)==(0);
       if ($515) {
        $517 = $$ph82142;
        break;
       }
       $504 = ($498|0)==(-1);
       if ($504) {
        $NumAggregatesToSort$7 = $501;
        break L155;
       } else {
        $503 = $512;$NumAggregatesToSort$690 = $501;$index$091 = $498;
       }
      }
      while(1) {
       $516 = (($517) + 1)|0;
       $518 = ($516>>>0)<($514>>>0);
       if (!($518)) {
        $$ph78 = 0;
        break;
       }
       $519 = (($496) + ($516<<2)|0);
       $520 = HEAP32[$519>>2]|0;
       $521 = ($520|0)==(0);
       if ($521) {
        $517 = $516;
       } else {
        $$ph78 = $520;
        break;
       }
      }
      $497 = ($498|0)==(-1);
      if ($497) {
       $NumAggregatesToSort$7 = $501;
       break;
      } else {
       $$ph82142 = $516;$$ph83143 = $$ph78;$NumAggregatesToSort$6$ph144 = $501;$index$0$ph84145 = $498;
      }
     }
    }
   }
  }
 } while(0);
 $522 = (($this) + 45696|0);
 HEAP32[$522>>2] = $NumAggregatesToSort$7;
 $523 = (($this) + 33316|0);
 $524 = HEAP32[$523>>2]|0;
 $525 = (($1) + 516|0);
 $526 = HEAP32[$208>>2]|0;
 $527 = $526 & 2147483647;
 $528 = ($527|0)==(0);
 L186: do {
  if ($528) {
   $AggregateUpdatedElemIdsSize$0$lcssa = 0;
  } else {
   $$pre$i$i$i = HEAP32[$525>>2]|0;
   $530 = 0;
   while(1) {
    $529 = (($$pre$i$i$i) + ($530<<2)|0);
    $531 = HEAP32[$529>>2]|0;
    $532 = ($531|0)==(0);
    if (!($532)) {
     break;
    }
    $533 = (($530) + 1)|0;
    $534 = ($533>>>0)<($527>>>0);
    if ($534) {
     $530 = $533;
    } else {
     $AggregateUpdatedElemIdsSize$0$lcssa = 0;
     break L186;
    }
   }
   $535 = $530 << 5;
   $536 = (0 - ($531))|0;
   $537 = $531 & $536;
   $538 = Math_imul($537, 125613361)|0;
   $539 = $538 >>> 27;
   $540 = (412480 + ($539<<2)|0);
   $541 = HEAP32[$540>>2]|0;
   $542 = $541 | $535;
   $543 = (($531) + -1)|0;
   $544 = $543 & $531;
   $545 = ($544|0)==(0);
   L192: do {
    if ($545) {
     $547 = $530;
     while(1) {
      $546 = (($547) + 1)|0;
      $548 = ($546>>>0)<($527>>>0);
      if (!($548)) {
       $$ph59 = $546;$$ph60 = 0;
       break L192;
      }
      $549 = (($$pre$i$i$i) + ($546<<2)|0);
      $550 = HEAP32[$549>>2]|0;
      $551 = ($550|0)==(0);
      if ($551) {
       $547 = $546;
      } else {
       $$ph59 = $546;$$ph60 = $550;
       break;
      }
     }
    } else {
     $$ph59 = $530;$$ph60 = $544;
    }
   } while(0);
   $552 = ($542|0)==(-1);
   if ($552) {
    $AggregateUpdatedElemIdsSize$0$lcssa = 0;
   } else {
    $553 = (($this) + 180|0);
    $554 = (($this) + 308|0);
    $555 = (($this) + 316|0);
    $556 = (($this) + 312|0);
    $557 = (($this) + 252|0);
    $$pre189$pre = HEAP32[$553>>2]|0;
    $$pre190$pre = HEAP32[$267>>2]|0;
    $$ph61136 = $$ph59;$$ph62137 = $$ph60;$AggregateUpdatedElemIdsSize$0$ph138 = 0;$index17$0$ph63139 = $542;
    while(1) {
     $560 = $$ph61136 << 5;
     $599 = $$ph62137;$AggregateUpdatedElemIdsSize$067 = $AggregateUpdatedElemIdsSize$0$ph138;$index17$068 = $index17$0$ph63139;
     while(1) {
      $561 = $index17$068 >>> 5;
      $562 = (($$pre190$pre) + ($561<<2)|0);
      $563 = HEAP32[$562>>2]|0;
      $564 = $index17$068 & 31;
      $565 = 1 << $564;
      $566 = $563 & $565;
      $567 = ($566|0)==(0);
      $568 = ((($$pre189$pre) + (($index17$068*1048)|0)|0) + 1032|0);
      $569 = HEAP32[$568>>2]|0;
      $570 = ($569|0)==(1073741823);
      if ($567) {
       if ($570) {
        $AggregateUpdatedElemIdsSize$5 = $AggregateUpdatedElemIdsSize$067;
       } else {
        $571 = HEAP32[$554>>2]|0;
        $572 = HEAP32[$555>>2]|0;
        $AggregateUpdatedElemIdsSize$155 = $AggregateUpdatedElemIdsSize$067;$elemId$056 = $569;
        while(1) {
         $573 = (($571) + ($elemId$056<<2)|0);
         $574 = HEAP32[$573>>2]|0;
         $575 = ($574|0)==(1073741823);
         if ($575) {
          $AggregateUpdatedElemIdsSize$2 = $AggregateUpdatedElemIdsSize$155;
         } else {
          $576 = (($524) + ($AggregateUpdatedElemIdsSize$155<<2)|0);
          HEAP32[$576>>2] = $elemId$056;
          $577 = (($AggregateUpdatedElemIdsSize$155) + 1)|0;
          $AggregateUpdatedElemIdsSize$2 = $577;
         }
         $578 = (($572) + ($elemId$056<<2)|0);
         $579 = HEAP32[$578>>2]|0;
         $580 = ($579|0)==(1073741823);
         if ($580) {
          $AggregateUpdatedElemIdsSize$5 = $AggregateUpdatedElemIdsSize$2;
          break;
         } else {
          $AggregateUpdatedElemIdsSize$155 = $AggregateUpdatedElemIdsSize$2;$elemId$056 = $579;
         }
        }
       }
      } else {
       if ($570) {
        $AggregateUpdatedElemIdsSize$5 = $AggregateUpdatedElemIdsSize$067;
       } else {
        $$pre191 = HEAP32[$554>>2]|0;
        $AggregateUpdatedElemIdsSize$351 = $AggregateUpdatedElemIdsSize$067;$elemId20$052 = $569;
        while(1) {
         $581 = (($$pre191) + ($elemId20$052<<2)|0);
         $582 = HEAP32[$581>>2]|0;
         $583 = ($582|0)==(1073741823);
         do {
          if ($583) {
           $AggregateUpdatedElemIdsSize$4 = $AggregateUpdatedElemIdsSize$351;
          } else {
           $584 = HEAP32[$556>>2]|0;
           $585 = (($584) + ($elemId20$052<<2)|0);
           $586 = HEAP32[$585>>2]|0;
           $587 = $586 >>> 1;
           $588 = HEAP32[$557>>2]|0;
           $589 = (($588) + ($587)|0);
           $590 = HEAP8[$589>>0]|0;
           $591 = ($590&255)>(1);
           if (!($591)) {
            $AggregateUpdatedElemIdsSize$4 = $AggregateUpdatedElemIdsSize$351;
            break;
           }
           $592 = (($524) + ($AggregateUpdatedElemIdsSize$351<<2)|0);
           HEAP32[$592>>2] = $elemId20$052;
           $593 = (($AggregateUpdatedElemIdsSize$351) + 1)|0;
           $AggregateUpdatedElemIdsSize$4 = $593;
          }
         } while(0);
         $594 = HEAP32[$555>>2]|0;
         $595 = (($594) + ($elemId20$052<<2)|0);
         $596 = HEAP32[$595>>2]|0;
         $597 = ($596|0)==(1073741823);
         if ($597) {
          $AggregateUpdatedElemIdsSize$5 = $AggregateUpdatedElemIdsSize$4;
          break;
         } else {
          $AggregateUpdatedElemIdsSize$351 = $AggregateUpdatedElemIdsSize$4;$elemId20$052 = $596;
         }
        }
       }
      }
      $598 = ($599|0)==(0);
      if ($598) {
       $AggregateUpdatedElemIdsSize$0$lcssa = $AggregateUpdatedElemIdsSize$5;
       break L186;
      }
      $601 = (0 - ($599))|0;
      $602 = $599 & $601;
      $603 = Math_imul($602, 125613361)|0;
      $604 = $603 >>> 27;
      $605 = (412480 + ($604<<2)|0);
      $606 = HEAP32[$605>>2]|0;
      $559 = $606 | $560;
      $607 = (($599) + -1)|0;
      $608 = $607 & $599;
      $609 = HEAP32[$208>>2]|0;
      $610 = $609 & 2147483647;
      $611 = ($608|0)==(0);
      if ($611) {
       break;
      }
      $600 = ($559|0)==(-1);
      if ($600) {
       $AggregateUpdatedElemIdsSize$0$lcssa = $AggregateUpdatedElemIdsSize$5;
       break L186;
      } else {
       $599 = $608;$AggregateUpdatedElemIdsSize$067 = $AggregateUpdatedElemIdsSize$5;$index17$068 = $559;
      }
     }
     $612 = HEAP32[$525>>2]|0;
     $614 = $$ph61136;
     while(1) {
      $613 = (($614) + 1)|0;
      $615 = ($613>>>0)<($610>>>0);
      if (!($615)) {
       $$ph = 0;
       break;
      }
      $616 = (($612) + ($613<<2)|0);
      $617 = HEAP32[$616>>2]|0;
      $618 = ($617|0)==(0);
      if ($618) {
       $614 = $613;
      } else {
       $$ph = $617;
       break;
      }
     }
     $558 = ($559|0)==(-1);
     if ($558) {
      $AggregateUpdatedElemIdsSize$0$lcssa = $AggregateUpdatedElemIdsSize$5;
      break;
     } else {
      $$ph61136 = $613;$$ph62137 = $$ph;$AggregateUpdatedElemIdsSize$0$ph138 = $AggregateUpdatedElemIdsSize$5;$index17$0$ph63139 = $559;
     }
    }
   }
  }
 } while(0);
 $619 = (($this) + 33328|0);
 HEAP32[$619>>2] = $AggregateUpdatedElemIdsSize$0$lcssa;
 __ZN5physx12InlineBitmapILj4096EED1Ev($aggregatesNeedingSorted);
 __ZN5physx12InlineBitmapILj4096EED1Ev($1);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager19removeAggregatePairEjj($this,$vol0,$vol1) {
 $this = $this|0;
 $vol0 = $vol0|0;
 $vol1 = $vol1|0;
 var $$0 = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($vol0>>>0)<($vol1>>>0);
 $2 = $1 ? $vol0 : $vol1;
 $3 = $1 ? $vol1 : $vol0;
 $4 = (($this) + 49860|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 49856|0);
 $8 = HEAP32[$7>>2]|0;
 $i$05 = 0;
 while(1) {
  $9 = (($8) + (($i$05*12)|0)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($2|0);
  if ($11) {
   $12 = ((($8) + (($i$05*12)|0)|0) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==($3|0);
   if ($14) {
    break;
   }
  }
  $57 = (($i$05) + 1)|0;
  $58 = ($57>>>0)<($5>>>0);
  if ($58) {
   $i$05 = $57;
  } else {
   $$0 = 0;
   label = 24;
   break;
  }
 }
 if ((label|0) == 24) {
  STACKTOP = sp;return ($$0|0);
 }
 $15 = ((($8) + (($i$05*12)|0)|0) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $53 = $8;$55 = $5;
 } else {
  $18 = (($this) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($2<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 1;
  $23 = ($22|0)==(0);
  if ($23) {
   $37 = 0;
  } else {
   $24 = $21 >>> 1;
   $25 = (($this) + 180|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + (($24*1048)|0)|0);
   $37 = $27;
  }
  $28 = (($19) + ($3<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $29 & 1;
  $31 = ($30|0)==(0);
  if ($31) {
   $39 = 0;
  } else {
   $32 = $29 >>> 1;
   $33 = (($this) + 180|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + (($32*1048)|0)|0);
   $39 = $35;
  }
  $36 = ($37|0)==(0|0);
  $38 = ($39|0)!=(0|0);
  do {
   if ($36) {
    if ($38) {
     __ZN5physx14PxsAABBManager25removeAggregateSinglePairEjPNS_9AggregateEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$2,$39,$16);
    }
   } else {
    if ($38) {
     __ZN5physx14PxsAABBManager28removeAggregateAggregatePairEPNS_9AggregateES2_PNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$37,$39,$16);
     break;
    } else {
     __ZN5physx14PxsAABBManager25removeAggregateSinglePairEjPNS_9AggregateEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$3,$37,$16);
     break;
    }
   }
  } while(0);
  $40 = HEAP32[$7>>2]|0;
  $41 = ((($40) + (($i$05*12)|0)|0) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   $51 = $40;
  } else {
   $44 = HEAP32[$42>>2]|0;
   $45 = ($44|0)==(0|0);
   if (!($45)) {
    $46 = (($42) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)>(-1);
    if ($48) {
     $49 = (($42) + 8|0);
     __ZN5physx6shdfnd9Allocator10deallocateEPv($49,$44);
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$42);
   $$pre8 = HEAP32[$7>>2]|0;
   $51 = $$pre8;
  }
  $50 = ((($51) + (($i$05*12)|0)|0) + 8|0);
  HEAP32[$50>>2] = 0;
  $$pre = HEAP32[$7>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $53 = $$pre;$55 = $$pre7;
 }
 $52 = (($53) + (($i$05*12)|0)|0);
 $54 = (($55) + -1)|0;
 HEAP32[$4>>2] = $54;
 $56 = (($53) + (($54*12)|0)|0);
 ;HEAP32[$52+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$52+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$52+8>>2]=HEAP32[$56+8>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx14PxsAABBManager31updateAggregateBPOverlapRecordsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 232|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 236|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 2;
 _memset(($1|0),0,($4|0))|0;
 $5 = (($this) + 49860|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 49856|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $i$01 = 0;
 while(1) {
  $12 = (($9) + (($i$01*12)|0)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + ($13<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 & 1;
  $17 = ($16|0)==(0);
  if (!($17)) {
   $18 = $15 >>> 1;
   $19 = $18 & 31;
   $20 = 1 << $19;
   $21 = $15 >>> 6;
   $22 = HEAP32[$0>>2]|0;
   $23 = (($22) + ($21<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $24 | $20;
   HEAP32[$23>>2] = $25;
  }
  $26 = ((($9) + (($i$01*12)|0)|0) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($11) + ($27<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $29 & 1;
  $31 = ($30|0)==(0);
  if (!($31)) {
   $32 = $29 >>> 1;
   $33 = $32 & 31;
   $34 = 1 << $33;
   $35 = $29 >>> 6;
   $36 = HEAP32[$0>>2]|0;
   $37 = (($36) + ($35<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38 | $34;
   HEAP32[$37>>2] = $39;
  }
  $40 = (($i$01) + 1)|0;
  $41 = HEAP32[$5>>2]|0;
  $42 = ($40>>>0)<($41>>>0);
  if ($42) {
   $i$01 = $40;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx5Elems4growEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $$pre = 0, $$sum = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $factor = 0, $i$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = ($newCapacity*24)|0;
 $3 = (($2) + 15)|0;
 $4 = $3 & -16;
 $5 = $newCapacity << 2;
 $6 = (($5) + 15)|0;
 $7 = $6 & -16;
 $factor = ($7*5)|0;
 $8 = (($factor) + ($4))|0;
 $9 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$8,481512,1594)|0);
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ($11*24)|0;
  _memcpy(($9|0),($13|0),($15|0))|0;
 }
 $16 = (($9) + (($11*24)|0)|0);
 $17 = (($newCapacity) - ($11))|0;
 $18 = ($17*24)|0;
 _memset(($16|0),0,($18|0))|0;
 $19 = (($9) + ($4)|0);
 HEAP32[$12>>2] = $9;
 $20 = HEAP32[$10>>2]|0;
 $21 = (($this) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = $20 << 2;
  _memcpy(($19|0),($22|0),($24|0))|0;
 }
 $25 = (($19) + ($20<<2)|0);
 $26 = (($newCapacity) - ($20))|0;
 $27 = $26 << 2;
 _memset(($25|0),0,($27|0))|0;
 $$sum = (($4) + ($7))|0;
 $28 = (($9) + ($$sum)|0);
 HEAP32[$21>>2] = $19;
 $29 = HEAP32[$10>>2]|0;
 $30 = (($this) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = $29 << 2;
  _memcpy(($28|0),($31|0),($33|0))|0;
 }
 $34 = (($28) + ($29<<2)|0);
 $35 = (($newCapacity) - ($29))|0;
 $36 = $35 << 2;
 _memset(($34|0),0,($36|0))|0;
 $$sum4 = (($$sum) + ($7))|0;
 $37 = (($9) + ($$sum4)|0);
 HEAP32[$30>>2] = $28;
 $38 = HEAP32[$10>>2]|0;
 $39 = (($this) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if (!($41)) {
  $42 = $38 << 2;
  _memcpy(($37|0),($40|0),($42|0))|0;
 }
 $43 = (($37) + ($38<<2)|0);
 $44 = (($newCapacity) - ($38))|0;
 $45 = $44 << 2;
 _memset(($43|0),0,($45|0))|0;
 $$sum5 = (($$sum4) + ($7))|0;
 $46 = (($9) + ($$sum5)|0);
 HEAP32[$39>>2] = $37;
 $47 = HEAP32[$10>>2]|0;
 $48 = (($this) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = $47 << 2;
  _memcpy(($46|0),($49|0),($51|0))|0;
 }
 $52 = (($46) + ($47<<2)|0);
 $53 = (($newCapacity) - ($47))|0;
 $54 = $53 << 2;
 _memset(($52|0),0,($54|0))|0;
 $$sum6 = (($$sum5) + ($7))|0;
 $55 = (($9) + ($$sum6)|0);
 HEAP32[$48>>2] = $46;
 $56 = HEAP32[$10>>2]|0;
 $57 = (($this) + 20|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0|0);
 if (!($59)) {
  $60 = $56 << 2;
  _memcpy(($55|0),($58|0),($60|0))|0;
 }
 $61 = (($55) + ($56<<2)|0);
 $62 = (($newCapacity) - ($56))|0;
 $63 = $62 << 2;
 _memset(($61|0),0,($63|0))|0;
 HEAP32[$57>>2] = $55;
 $64 = (($this) + 32|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($newCapacity) + -1)|0;
 $67 = HEAP32[$30>>2]|0;
 $68 = (($67) + ($66<<2)|0);
 HEAP32[$68>>2] = $65;
 $69 = HEAP32[$10>>2]|0;
 $70 = ($69>>>0)<($66>>>0);
 if ($70) {
  $i$07 = $69;
 } else {
  $73 = $69;
  HEAP32[$64>>2] = $73;
  $74 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$74);
  $75 = HEAP32[$12>>2]|0;
  HEAP32[$this>>2] = $75;
  HEAP32[$10>>2] = $newCapacity;
  STACKTOP = sp;return;
 }
 while(1) {
  $71 = (($i$07) + 1)|0;
  $72 = (($67) + ($i$07<<2)|0);
  HEAP32[$72>>2] = $71;
  $exitcond = ($71|0)==($66|0);
  if ($exitcond) {
   break;
  } else {
   $i$07 = $71;
  }
 }
 $$pre = HEAP32[$10>>2]|0;
 $73 = $$pre;
 HEAP32[$64>>2] = $73;
 $74 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$74);
 $75 = HEAP32[$12>>2]|0;
 HEAP32[$this>>2] = $75;
 HEAP32[$10>>2] = $newCapacity;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager28removeAggregateAggregatePairEPNS_9AggregateES2_PNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$c0,$c1,$aggregateCollBitmap) {
 $this = $this|0;
 $c0 = $c0|0;
 $c1 = $c1|0;
 $aggregateCollBitmap = $aggregateCollBitmap|0;
 var $$$i = 0, $$not = 0, $$ph = 0, $$ph1054 = 0, $$ph7 = 0, $$ph8 = 0, $$ph953 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre1$i = 0, $$pre68 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bitIndex$045 = 0, $bitIndex$130$us = 0, $brmerge = 0, $c0eleIds = 0, $c1eleIds = 0, $elemId0$049 = 0, $elemId0$1$us = 0, $elemId0$129 = 0, $elemId0$134$us = 0;
 var $elemId1$039 = 0, $elemId1$125$us = 0, $elemId1$125$us$in = 0, $exitcond = 0, $exitcond64 = 0, $exitcond65 = 0, $exitcond66 = 0, $exitcond67 = 0, $i$048 = 0, $i2$038 = 0, $i3$033$us = 0, $index$0$ph1155 = 0, $index$015 = 0, $j$043 = 0, $j4$024$us = 0, $nb1Valid$0$ = 0, $nb1Valid$0$lcssa = 0, $nb1Valid$037 = 0, $not$ = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 17|0;
 $1 = sp + 16|0;
 $c0eleIds = sp;
 $c1eleIds = sp + 8|0;
 $2 = (($c0) + 1032|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($c1) + 1032|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($c0) + 1025|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = (($c1) + 1025|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = (($c0eleIds) + 4|0);
 HEAP8[$12>>0] = 0;
 $13 = STACKTOP; STACKTOP = STACKTOP + ((((4*$8)|0)+15)&-16)|0;;
 HEAP32[$c0eleIds>>2] = $13;
 $14 = (($c1eleIds) + 4|0);
 HEAP8[$14>>0] = 0;
 $15 = STACKTOP; STACKTOP = STACKTOP + ((((4*$11)|0)+15)&-16)|0;;
 HEAP32[$c1eleIds>>2] = $15;
 $16 = ($7<<24>>24)==(0);
 if (!($16)) {
  $17 = (($this) + 308|0);
  $18 = (($this) + 316|0);
  $19 = ($10<<24>>24)==(0);
  $$pre68 = HEAP32[$17>>2]|0;
  $bitIndex$045 = 0;$elemId0$049 = $3;$i$048 = 0;
  while(1) {
   $25 = (($$pre68) + ($elemId0$049<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $$not = ($26|0)!=(1073741823);
   $brmerge = $$not | $19;
   if (!($brmerge)) {
    $27 = HEAP32[$aggregateCollBitmap>>2]|0;
    $j$043 = 0;
    while(1) {
     $28 = (($j$043) + ($bitIndex$045))|0;
     $29 = $28 & 31;
     $30 = ((($this) + ($29<<2)|0) + 384|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = $31 ^ -1;
     $33 = $28 >>> 5;
     $34 = (($27) + ($33<<2)|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = $35 & $32;
     HEAP32[$34>>2] = $36;
     $37 = (($j$043) + 1)|0;
     $exitcond64 = ($37|0)==($11|0);
     if ($exitcond64) {
      break;
     } else {
      $j$043 = $37;
     }
    }
   }
   $38 = (($13) + ($i$048<<2)|0);
   HEAP32[$38>>2] = $elemId0$049;
   $39 = (($bitIndex$045) + ($11))|0;
   $40 = HEAP32[$18>>2]|0;
   $41 = (($40) + ($elemId0$049<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($i$048) + 1)|0;
   $exitcond65 = ($43|0)==($8|0);
   if ($exitcond65) {
    break;
   } else {
    $bitIndex$045 = $39;$elemId0$049 = $42;$i$048 = $43;
   }
  }
 }
 $20 = ($10<<24>>24)==(0);
 if ($20) {
  $nb1Valid$0$lcssa = 0;
 } else {
  $21 = (($this) + 308|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($this) + 316|0);
  $24 = HEAP32[$23>>2]|0;
  $elemId1$039 = $5;$i2$038 = 0;$nb1Valid$037 = 0;
  while(1) {
   $44 = (($22) + ($elemId1$039<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $not$ = ($45|0)!=(1073741823);
   $46 = $not$&1;
   $nb1Valid$0$ = (($46) + ($nb1Valid$037))|0;
   $47 = (($15) + ($i2$038<<2)|0);
   HEAP32[$47>>2] = $elemId1$039;
   $48 = (($24) + ($elemId1$039<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($i2$038) + 1)|0;
   $exitcond = ($50|0)==($11|0);
   if ($exitcond) {
    $nb1Valid$0$lcssa = $nb1Valid$0$;
    break;
   } else {
    $elemId1$039 = $49;$i2$038 = $50;$nb1Valid$037 = $nb1Valid$0$;
   }
  }
 }
 $51 = ($nb1Valid$0$lcssa|0)==($11|0);
 if (!($51)) {
  $elemId0$129 = HEAP32[$2>>2]|0;
  if (!($16)) {
   $52 = (($this) + 316|0);
   if (!($20)) {
    $53 = (($this) + 308|0);
    $$pre = HEAP32[$53>>2]|0;
    $bitIndex$130$us = 0;$elemId0$134$us = $elemId0$129;$i3$033$us = 0;
    while(1) {
     $54 = (($$pre) + ($elemId0$134$us<<2)|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==(1073741823);
     L22: do {
      if (!($56)) {
       $elemId1$125$us$in = $4;$j4$024$us = 0;
       while(1) {
        $elemId1$125$us = HEAP32[$elemId1$125$us$in>>2]|0;
        $57 = (($$pre) + ($elemId1$125$us<<2)|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = ($58|0)==(1073741823);
        if ($59) {
         $60 = (($j4$024$us) + ($bitIndex$130$us))|0;
         $61 = $60 & 31;
         $62 = ((($this) + ($61<<2)|0) + 384|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = $63 ^ -1;
         $65 = $60 >>> 5;
         $66 = HEAP32[$aggregateCollBitmap>>2]|0;
         $67 = (($66) + ($65<<2)|0);
         $68 = HEAP32[$67>>2]|0;
         $69 = $68 & $64;
         HEAP32[$67>>2] = $69;
        }
        $70 = (($j4$024$us) + 1)|0;
        $exitcond66 = ($70|0)==($11|0);
        if ($exitcond66) {
         break L22;
        }
        $71 = HEAP32[$52>>2]|0;
        $72 = (($71) + ($elemId1$125$us<<2)|0);
        $elemId1$125$us$in = $72;$j4$024$us = $70;
       }
      }
     } while(0);
     $73 = (($bitIndex$130$us) + ($11))|0;
     $74 = HEAP32[$52>>2]|0;
     $75 = (($74) + ($elemId0$134$us<<2)|0);
     $76 = (($i3$033$us) + 1)|0;
     $elemId0$1$us = HEAP32[$75>>2]|0;
     $exitcond67 = ($76|0)==($8|0);
     if ($exitcond67) {
      break;
     } else {
      $bitIndex$130$us = $73;$elemId0$134$us = $elemId0$1$us;$i3$033$us = $76;
     }
    }
   }
  }
 }
 $77 = (($aggregateCollBitmap) + 4|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = $78 & 2147483647;
 $80 = ($79|0)==(0);
 L31: do {
  if (!($80)) {
   $$pre$i$i$i = HEAP32[$aggregateCollBitmap>>2]|0;
   $82 = 0;
   while(1) {
    $81 = (($$pre$i$i$i) + ($82<<2)|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = ($83|0)==(0);
    if (!($84)) {
     break;
    }
    $85 = (($82) + 1)|0;
    $86 = ($85>>>0)<($79>>>0);
    if ($86) {
     $82 = $85;
    } else {
     break L31;
    }
   }
   $87 = $82 << 5;
   $88 = (0 - ($83))|0;
   $89 = $83 & $88;
   $90 = Math_imul($89, 125613361)|0;
   $91 = $90 >>> 27;
   $92 = (412480 + ($91<<2)|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = $93 | $87;
   $95 = (($83) + -1)|0;
   $96 = $95 & $83;
   $97 = ($96|0)==(0);
   L37: do {
    if ($97) {
     $99 = $82;
     while(1) {
      $98 = (($99) + 1)|0;
      $100 = ($98>>>0)<($79>>>0);
      if (!($100)) {
       $$ph7 = $98;$$ph8 = 0;
       break L37;
      }
      $101 = (($$pre$i$i$i) + ($98<<2)|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = ($102|0)==(0);
      if ($103) {
       $99 = $98;
      } else {
       $$ph7 = $98;$$ph8 = $102;
       break;
      }
     }
    } else {
     $$ph7 = $82;$$ph8 = $96;
    }
   } while(0);
   $104 = ($94|0)==(-1);
   if (!($104)) {
    $105 = (($this) + 304|0);
    $106 = (($this) + 49848|0);
    $107 = (($this) + 49852|0);
    $108 = (($this) + 49844|0);
    $$ph1054 = $$ph8;$$ph953 = $$ph7;$index$0$ph1155 = $94;
    while(1) {
     $111 = $$ph953 << 5;
     $153 = $$ph1054;$index$015 = $index$0$ph1155;
     while(1) {
      $112 = (($index$015>>>0) / ($11>>>0))&-1;
      $113 = (($index$015>>>0) % ($11>>>0))&-1;
      $114 = $index$015 & 31;
      $115 = ((($this) + ($114<<2)|0) + 384|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = $116 ^ -1;
      $118 = $index$015 >>> 5;
      $119 = HEAP32[$aggregateCollBitmap>>2]|0;
      $120 = (($119) + ($118<<2)|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = $121 & $117;
      HEAP32[$120>>2] = $122;
      $123 = HEAP32[$c0eleIds>>2]|0;
      $124 = (($123) + ($112<<2)|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = HEAP32[$105>>2]|0;
      $127 = (($126) + ($125<<2)|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = HEAP32[$c1eleIds>>2]|0;
      $130 = (($129) + ($113<<2)|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = (($126) + ($131<<2)|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = HEAP32[$106>>2]|0;
      $135 = HEAP32[$107>>2]|0;
      $136 = ($134|0)==($135|0);
      if ($136) {
       $137 = ($134|0)==(0);
       $138 = $134 << 1;
       $$$i = $137 ? 32 : $138;
       $139 = HEAP32[$108>>2]|0;
       $140 = $$$i << 3;
       $141 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$140,481512,76)|0);
       $142 = ($139|0)==(0|0);
       if (!($142)) {
        $143 = $134 << 3;
        _memcpy(($141|0),($139|0),($143|0))|0;
       }
       $144 = (($141) + ($134<<3)|0);
       $145 = (($$$i) - ($134))|0;
       $146 = $145 << 3;
       _memset(($144|0),0,($146|0))|0;
       __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$139);
       HEAP32[$108>>2] = $141;
       HEAP32[$107>>2] = $$$i;
       $$pre$i = HEAP32[$106>>2]|0;
       $148 = $$pre$i;$150 = $141;
      } else {
       $$pre1$i = HEAP32[$108>>2]|0;
       $148 = $134;$150 = $$pre1$i;
      }
      $147 = (($148) + 1)|0;
      HEAP32[$106>>2] = $147;
      $149 = (($150) + ($148<<3)|0);
      HEAP32[$149>>2] = $128;
      $151 = ((($150) + ($148<<3)|0) + 4|0);
      HEAP32[$151>>2] = $133;
      $152 = ($153|0)==(0);
      if ($152) {
       break L31;
      }
      $155 = (0 - ($153))|0;
      $156 = $153 & $155;
      $157 = Math_imul($156, 125613361)|0;
      $158 = $157 >>> 27;
      $159 = (412480 + ($158<<2)|0);
      $160 = HEAP32[$159>>2]|0;
      $110 = $160 | $111;
      $161 = (($153) + -1)|0;
      $162 = $161 & $153;
      $163 = HEAP32[$77>>2]|0;
      $164 = $163 & 2147483647;
      $165 = ($162|0)==(0);
      if ($165) {
       $167 = $$ph953;
       break;
      }
      $154 = ($110|0)==(-1);
      if ($154) {
       break L31;
      } else {
       $153 = $162;$index$015 = $110;
      }
     }
     while(1) {
      $166 = (($167) + 1)|0;
      $168 = ($166>>>0)<($164>>>0);
      if (!($168)) {
       $$ph = 0;
       break;
      }
      $169 = HEAP32[$aggregateCollBitmap>>2]|0;
      $170 = (($169) + ($166<<2)|0);
      $171 = HEAP32[$170>>2]|0;
      $172 = ($171|0)==(0);
      if ($172) {
       $167 = $166;
      } else {
       $$ph = $171;
       break;
      }
     }
     $109 = ($110|0)==(-1);
     if ($109) {
      break;
     } else {
      $$ph1054 = $$ph;$$ph953 = $166;$index$0$ph1155 = $110;
     }
    }
   }
  }
 } while(0);
 $173 = HEAP8[$14>>0]|0;
 $174 = ($173<<24>>24)==(0);
 if (!($174)) {
  $175 = HEAP32[$c1eleIds>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($c1eleIds,$175);
 }
 $176 = HEAP8[$12>>0]|0;
 $177 = ($176<<24>>24)==(0);
 if ($177) {
  STACKTOP = sp;return;
 }
 $178 = HEAP32[$c0eleIds>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($c0eleIds,$178);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager25removeAggregateSinglePairEjPNS_9AggregateEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$s0,$c1,$aggregateCollBitmap) {
 $this = $this|0;
 $s0 = $s0|0;
 $c1 = $c1|0;
 $aggregateCollBitmap = $aggregateCollBitmap|0;
 var $$$i = 0, $$ph = 0, $$ph6 = 0, $$ph7 = 0, $$ph825 = 0, $$ph926 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c1eleIds = 0, $elemId1$022 = 0, $exitcond = 0, $i$023 = 0, $index$0$ph1027 = 0;
 var $index$014 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 9|0;
 $1 = sp + 8|0;
 $c1eleIds = sp;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($s0<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($c1) + 1032|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($c1) + 1025|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = (($c1eleIds) + 4|0);
 HEAP8[$11>>0] = 0;
 $12 = STACKTOP; STACKTOP = STACKTOP + ((((4*$10)|0)+15)&-16)|0;;
 HEAP32[$c1eleIds>>2] = $12;
 $13 = ($9<<24>>24)==(0);
 if (!($13)) {
  $14 = (($this) + 308|0);
  $15 = (($this) + 316|0);
  $$pre = HEAP32[$14>>2]|0;
  $elemId1$022 = $7;$i$023 = 0;
  while(1) {
   $16 = (($$pre) + ($elemId1$022<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(1073741823);
   if ($18) {
    $19 = $i$023 & 31;
    $20 = ((($this) + ($19<<2)|0) + 384|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 ^ -1;
    $23 = $i$023 >>> 5;
    $24 = HEAP32[$aggregateCollBitmap>>2]|0;
    $25 = (($24) + ($23<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = $26 & $22;
    HEAP32[$25>>2] = $27;
   }
   $28 = (($12) + ($i$023<<2)|0);
   HEAP32[$28>>2] = $elemId1$022;
   $29 = HEAP32[$15>>2]|0;
   $30 = (($29) + ($elemId1$022<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($i$023) + 1)|0;
   $exitcond = ($32|0)==($10|0);
   if ($exitcond) {
    break;
   } else {
    $elemId1$022 = $31;$i$023 = $32;
   }
  }
 }
 $33 = (($aggregateCollBitmap) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 2147483647;
 $36 = ($35|0)==(0);
 L9: do {
  if (!($36)) {
   $$pre$i$i$i = HEAP32[$aggregateCollBitmap>>2]|0;
   $38 = 0;
   while(1) {
    $37 = (($$pre$i$i$i) + ($38<<2)|0);
    $39 = HEAP32[$37>>2]|0;
    $40 = ($39|0)==(0);
    if (!($40)) {
     break;
    }
    $41 = (($38) + 1)|0;
    $42 = ($41>>>0)<($35>>>0);
    if ($42) {
     $38 = $41;
    } else {
     break L9;
    }
   }
   $43 = $38 << 5;
   $44 = (0 - ($39))|0;
   $45 = $39 & $44;
   $46 = Math_imul($45, 125613361)|0;
   $47 = $46 >>> 27;
   $48 = (412480 + ($47<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = $49 | $43;
   $51 = (($39) + -1)|0;
   $52 = $51 & $39;
   $53 = ($52|0)==(0);
   L15: do {
    if ($53) {
     $55 = $38;
     while(1) {
      $54 = (($55) + 1)|0;
      $56 = ($54>>>0)<($35>>>0);
      if (!($56)) {
       $$ph6 = $54;$$ph7 = 0;
       break L15;
      }
      $57 = (($$pre$i$i$i) + ($54<<2)|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($58|0)==(0);
      if ($59) {
       $55 = $54;
      } else {
       $$ph6 = $54;$$ph7 = $58;
       break;
      }
     }
    } else {
     $$ph6 = $38;$$ph7 = $52;
    }
   } while(0);
   $60 = ($50|0)==(-1);
   if (!($60)) {
    $61 = (($this) + 304|0);
    $62 = (($this) + 49848|0);
    $63 = (($this) + 49852|0);
    $64 = (($this) + 49844|0);
    $$ph825 = $$ph6;$$ph926 = $$ph7;$index$0$ph1027 = $50;
    while(1) {
     $67 = $$ph825 << 5;
     $102 = $$ph926;$index$014 = $index$0$ph1027;
     while(1) {
      $68 = $index$014 & 31;
      $69 = ((($this) + ($68<<2)|0) + 384|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = $70 ^ -1;
      $72 = $index$014 >>> 5;
      $73 = HEAP32[$aggregateCollBitmap>>2]|0;
      $74 = (($73) + ($72<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = $75 & $71;
      HEAP32[$74>>2] = $76;
      $77 = HEAP32[$c1eleIds>>2]|0;
      $78 = (($77) + ($index$014<<2)|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = HEAP32[$61>>2]|0;
      $81 = (($80) + ($79<<2)|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = HEAP32[$62>>2]|0;
      $84 = HEAP32[$63>>2]|0;
      $85 = ($83|0)==($84|0);
      if ($85) {
       $86 = ($83|0)==(0);
       $87 = $83 << 1;
       $$$i = $86 ? 32 : $87;
       $88 = HEAP32[$64>>2]|0;
       $89 = $$$i << 3;
       $90 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$89,481512,76)|0);
       $91 = ($88|0)==(0|0);
       if (!($91)) {
        $92 = $83 << 3;
        _memcpy(($90|0),($88|0),($92|0))|0;
       }
       $93 = (($90) + ($83<<3)|0);
       $94 = (($$$i) - ($83))|0;
       $95 = $94 << 3;
       _memset(($93|0),0,($95|0))|0;
       __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$88);
       HEAP32[$64>>2] = $90;
       HEAP32[$63>>2] = $$$i;
       $$pre$i = HEAP32[$62>>2]|0;
       $97 = $$pre$i;$99 = $90;
      } else {
       $$pre1$i = HEAP32[$64>>2]|0;
       $97 = $83;$99 = $$pre1$i;
      }
      $96 = (($97) + 1)|0;
      HEAP32[$62>>2] = $96;
      $98 = (($99) + ($97<<3)|0);
      HEAP32[$98>>2] = $5;
      $100 = ((($99) + ($97<<3)|0) + 4|0);
      HEAP32[$100>>2] = $82;
      $101 = ($102|0)==(0);
      if ($101) {
       break L9;
      }
      $104 = (0 - ($102))|0;
      $105 = $102 & $104;
      $106 = Math_imul($105, 125613361)|0;
      $107 = $106 >>> 27;
      $108 = (412480 + ($107<<2)|0);
      $109 = HEAP32[$108>>2]|0;
      $66 = $109 | $67;
      $110 = (($102) + -1)|0;
      $111 = $110 & $102;
      $112 = HEAP32[$33>>2]|0;
      $113 = $112 & 2147483647;
      $114 = ($111|0)==(0);
      if ($114) {
       $116 = $$ph825;
       break;
      }
      $103 = ($66|0)==(-1);
      if ($103) {
       break L9;
      } else {
       $102 = $111;$index$014 = $66;
      }
     }
     while(1) {
      $115 = (($116) + 1)|0;
      $117 = ($115>>>0)<($113>>>0);
      if (!($117)) {
       $$ph = 0;
       break;
      }
      $118 = HEAP32[$aggregateCollBitmap>>2]|0;
      $119 = (($118) + ($115<<2)|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = ($120|0)==(0);
      if ($121) {
       $116 = $115;
      } else {
       $$ph = $120;
       break;
      }
     }
     $65 = ($66|0)==(-1);
     if ($65) {
      break;
     } else {
      $$ph825 = $115;$$ph926 = $$ph;$index$0$ph1027 = $66;
     }
    }
   }
  }
 } while(0);
 $122 = HEAP8[$11>>0]|0;
 $123 = ($122<<24>>24)==(0);
 if ($123) {
  STACKTOP = sp;return;
 }
 $124 = HEAP32[$c1eleIds>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($c1eleIds,$124);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager14sortAggregatesEPjjS1_jPNS_19AggregateSortedDataE($this,$allRankIds,$allRankIdsCapacity,$allElemIds,$allElemIdsCapacity,$aggregateSortedData) {
 $this = $this|0;
 $allRankIds = $allRankIds|0;
 $allRankIdsCapacity = $allRankIdsCapacity|0;
 $allElemIds = $allElemIds|0;
 $allElemIdsCapacity = $allElemIdsCapacity|0;
 $aggregateSortedData = $aggregateSortedData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $elemId$0 = 0, $elemId$01 = 0, $elemId$04 = 0, $elemIds = 0, $exitcond = 0, $i$010 = 0, $j$06 = 0, $numElemIds$0$lcssa = 0, $numElemIds$03 = 0, $numSortedRanks$0$lcssa = 0, $numSortedRanks$02 = 0, $numSortedRanks$1 = 0, $numSortedTotal$011 = 0;
 var $ranks = 0, $sortedData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2064|0;
 $0 = sp + 2049|0;
 $1 = sp + 2048|0;
 $sortedData = sp + 512|0;
 $elemIds = sp;
 $ranks = sp + 1536|0;
 $2 = (($this) + 300|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 45696|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 45684|0);
 $8 = (($this) + 180|0);
 $9 = (($this) + 308|0);
 $10 = (($this) + 316|0);
 $i$010 = 0;$numSortedTotal$011 = 0;
 while(1) {
  $11 = HEAP32[$7>>2]|0;
  $12 = (($11) + ($i$010<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$8>>2]|0;
  $15 = ((($14) + (($13*1048)|0)|0) + 1032|0);
  $elemId$01 = HEAP32[$15>>2]|0;
  $16 = ($elemId$01|0)==(1073741823);
  if ($16) {
   $numElemIds$0$lcssa = 0;$numSortedRanks$0$lcssa = 0;
  } else {
   $17 = HEAP32[$9>>2]|0;
   $18 = HEAP32[$10>>2]|0;
   $elemId$04 = $elemId$01;$numElemIds$03 = 0;$numSortedRanks$02 = 0;
   while(1) {
    $19 = (($17) + ($elemId$04<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(1073741823);
    if ($21) {
     $numSortedRanks$1 = $numSortedRanks$02;
    } else {
     $22 = (($3) + (($elemId$04*24)|0)|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($sortedData) + ($numSortedRanks$02<<3)|0);
     HEAP32[$24>>2] = $23;
     $25 = ((($sortedData) + ($numSortedRanks$02<<3)|0) + 4|0);
     HEAP32[$25>>2] = $numElemIds$03;
     $26 = (($numSortedRanks$02) + 1)|0;
     $numSortedRanks$1 = $26;
    }
    $27 = (($elemIds) + ($numElemIds$03<<2)|0);
    HEAP32[$27>>2] = $elemId$04;
    $28 = (($numElemIds$03) + 1)|0;
    $29 = (($18) + ($elemId$04<<2)|0);
    $elemId$0 = HEAP32[$29>>2]|0;
    $30 = ($elemId$0|0)==(1073741823);
    if ($30) {
     $numElemIds$0$lcssa = $28;$numSortedRanks$0$lcssa = $numSortedRanks$1;
     break;
    } else {
     $elemId$04 = $elemId$0;$numElemIds$03 = $28;$numSortedRanks$02 = $numSortedRanks$1;
    }
   }
  }
  __ZN5physx6shdfnd4sortI10SortedDataNS0_4LessIS2_EENS0_19ReflectionAllocatorIS2_EEEEvPT_jRKT0_RKT1_($sortedData,$numSortedRanks$0$lcssa,$0,$1);
  $31 = ($numSortedRanks$0$lcssa|0)==(0);
  if (!($31)) {
   $j$06 = 0;
   while(1) {
    $32 = ((($sortedData) + ($j$06<<3)|0) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($ranks) + ($j$06<<2)|0);
    HEAP32[$34>>2] = $33;
    $35 = (($j$06) + 1)|0;
    $exitcond = ($35|0)==($numSortedRanks$0$lcssa|0);
    if ($exitcond) {
     break;
    } else {
     $j$06 = $35;
    }
   }
  }
  $36 = (($allRankIds) + ($numSortedTotal$011<<2)|0);
  $37 = (($aggregateSortedData) + ($13<<3)|0);
  HEAP32[$37>>2] = $36;
  $38 = (($allElemIds) + ($numSortedTotal$011<<2)|0);
  $39 = ((($aggregateSortedData) + ($13<<3)|0) + 4|0);
  HEAP32[$39>>2] = $38;
  $40 = $numSortedRanks$0$lcssa << 2;
  _memcpy(($36|0),($ranks|0),($40|0))|0;
  $41 = HEAP32[$39>>2]|0;
  $42 = $numElemIds$0$lcssa << 2;
  _memcpy(($41|0),($elemIds|0),($42|0))|0;
  $43 = (($numElemIds$0$lcssa) + ($numSortedTotal$011))|0;
  $44 = (($i$010) + 1)|0;
  $45 = HEAP32[$4>>2]|0;
  $46 = ($44>>>0)<($45>>>0);
  if ($46) {
   $i$010 = $44;$numSortedTotal$011 = $43;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager21selfCollideAggregatesEPKNS_19AggregateSortedDataE($this,$aggregateSortedDatas) {
 $this = $this|0;
 $aggregateSortedDatas = $aggregateSortedDatas|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 368|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 180|0);
 $i$01 = 0;
 while(1) {
  $6 = (($3) + ($i$01<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($aggregateSortedDatas) + ($7<<3)|0);
  $9 = HEAP32[$5>>2]|0;
  $10 = (($9) + (($7*1048)|0)|0);
  $11 = ((($9) + (($7*1048)|0)|0) + 1024|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if (!($13)) {
   $14 = ((($9) + (($7*1048)|0)|0) + 1025|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    __ZN5physx14PxsAABBManager20selfCollideAggregateERKNS_19AggregateSortedDataERKNS_9AggregateEPNS_17SelfCollideBitmapE($this,$8,$10,$10);
   }
  }
  $17 = (($i$01) + 1)|0;
  $exitcond = ($17|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $17;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager20selfCollideAggregateERKNS_19AggregateSortedDataERKNS_9AggregateEPNS_17SelfCollideBitmapE($this,$aggregateSortedData,$aggregate,$selfCollBitmap) {
 $this = $this|0;
 $aggregateSortedData = $aggregateSortedData|0;
 $aggregate = $aggregate|0;
 $selfCollBitmap = $selfCollBitmap|0;
 var $$$i = 0, $$$i12 = 0, $$0$i7 = 0, $$ph20 = 0, $$ph20$ph = 0, $$ph21$ph = 0, $$ph22 = 0, $$ph22$ph = 0, $$ph23 = 0, $$ph23$ph = 0, $$pre$i14 = 0, $$pre$i3 = 0, $$pre1$i = 0, $$pre1$i10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $RunningAddress$035 = 0, $RunningAddress$1 = 0, $RunningAddress$2 = 0, $RunningAddress2$033 = 0, $Sorted$036 = 0, $index$0 = 0, $index$0$ph = 0, $index$0$ph$ph = 0, $j$0$i = 0, $j$0$i4 = 0, $j$0$i416$ph = 0, $j$0$i416$ph$ph = 0, $j$0$i418 = 0, $newBitmap = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $0 = sp + 1025|0;
 $1 = sp + 1024|0;
 $newBitmap = sp;
 _memset(($newBitmap|0),0,1024)|0;
 $2 = HEAP32[$aggregateSortedData>>2]|0;
 $3 = (($aggregateSortedData) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 300|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($aggregate) + 1026|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = (($2) + ($9<<2)|0);
 $11 = ($8<<24>>24)==(0);
 L1: do {
  if ($11) {
   $112 = 0;
  } else {
   $12 = (($this) + 308|0);
   $13 = (($this) + 304|0);
   $14 = (($this) + 49836|0);
   $15 = (($this) + 49840|0);
   $16 = (($this) + 49832|0);
   $RunningAddress$035 = $2;$Sorted$036 = $2;
   while(1) {
    $18 = (($Sorted$036) + 4|0);
    $20 = HEAP32[$Sorted$036>>2]|0;
    $21 = (($4) + ($20<<2)|0);
    $RunningAddress$1 = $RunningAddress$035;
    while(1) {
     $22 = ($RunningAddress$1>>>0)<($10>>>0);
     if (!($22)) {
      $RunningAddress$2 = $RunningAddress$1;
      break;
     }
     $23 = (($RunningAddress$1) + 4|0);
     $24 = HEAP32[$RunningAddress$1>>2]|0;
     $25 = (($4) + ($24<<2)|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($6) + (($26*24)|0)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = HEAP32[$21>>2]|0;
     $30 = (($6) + (($29*24)|0)|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($28>>>0)<($31>>>0);
     if ($32) {
      $RunningAddress$1 = $23;
     } else {
      $RunningAddress$2 = $23;
      break;
     }
    }
    $19 = ($RunningAddress$2>>>0)<($10>>>0);
    if ($19) {
     $RunningAddress2$033 = $RunningAddress$2;
    } else {
     $112 = 0;
     break L1;
    }
    while(1) {
     $33 = (($RunningAddress2$033) + 4|0);
     $34 = HEAP32[$RunningAddress2$033>>2]|0;
     $35 = (($4) + ($34<<2)|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($6) + (($36*24)|0)|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = HEAP32[$21>>2]|0;
     $40 = ((($6) + (($39*24)|0)|0) + 12|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($38>>>0)>($41>>>0);
     if ($42) {
      break;
     }
     $43 = ($20|0)==($34|0);
     if (!($43)) {
      $44 = HEAP32[$12>>2]|0;
      $45 = (($44) + ($39<<2)|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = (($44) + ($36<<2)|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($46|0)==($48|0);
      if (!($49)) {
       $50 = ((($6) + (($39*24)|0)|0) + 20|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = ((($6) + (($36*24)|0)|0) + 8|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($51>>>0)<($53>>>0);
       if (!($54)) {
        $55 = ((($6) + (($36*24)|0)|0) + 20|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = ((($6) + (($39*24)|0)|0) + 8|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = ($56>>>0)<($58>>>0);
        if (!($59)) {
         $60 = ((($6) + (($39*24)|0)|0) + 16|0);
         $61 = HEAP32[$60>>2]|0;
         $62 = ((($6) + (($36*24)|0)|0) + 4|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = ($61>>>0)<($63>>>0);
         if (!($64)) {
          $65 = ((($6) + (($36*24)|0)|0) + 16|0);
          $66 = HEAP32[$65>>2]|0;
          $67 = ((($6) + (($39*24)|0)|0) + 4|0);
          $68 = HEAP32[$67>>2]|0;
          $69 = ($66>>>0)<($68>>>0);
          if (!($69)) {
           $70 = ($20>>>0)<($34>>>0);
           $71 = $70 ? $20 : $34;
           $72 = $70 ? $34 : $20;
           $73 = (($72) + -1)|0;
           $74 = Math_imul($73, $72)|0;
           $75 = $74 >>> 1;
           $76 = (($75) + ($71))|0;
           $77 = $76 & 31;
           $78 = 1 << $77;
           $79 = $76 >>> 5;
           $80 = (($newBitmap) + ($79<<2)|0);
           $81 = HEAP32[$80>>2]|0;
           $82 = $81 | $78;
           HEAP32[$80>>2] = $82;
           $83 = (($selfCollBitmap) + ($79<<2)|0);
           $84 = HEAP32[$83>>2]|0;
           $85 = $84 & $78;
           $86 = ($85|0)==(0);
           if ($86) {
            $87 = HEAP32[$13>>2]|0;
            $88 = (($87) + ($39<<2)|0);
            $89 = HEAP32[$88>>2]|0;
            $90 = (($87) + ($36<<2)|0);
            $91 = HEAP32[$90>>2]|0;
            $92 = HEAP32[$14>>2]|0;
            $93 = HEAP32[$15>>2]|0;
            $94 = ($92|0)==($93|0);
            if ($94) {
             $95 = ($92|0)==(0);
             $96 = $92 << 1;
             $$$i12 = $95 ? 32 : $96;
             $97 = HEAP32[$16>>2]|0;
             $98 = $$$i12 << 3;
             $99 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$98,481512,76)|0);
             $100 = ($97|0)==(0|0);
             if (!($100)) {
              $101 = $92 << 3;
              _memcpy(($99|0),($97|0),($101|0))|0;
             }
             $102 = (($99) + ($92<<3)|0);
             $103 = (($$$i12) - ($92))|0;
             $104 = $103 << 3;
             _memset(($102|0),0,($104|0))|0;
             __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$97);
             HEAP32[$16>>2] = $99;
             HEAP32[$15>>2] = $$$i12;
             $$pre$i14 = HEAP32[$14>>2]|0;
             $106 = $$pre$i14;$108 = $99;
            } else {
             $$pre1$i10 = HEAP32[$16>>2]|0;
             $106 = $92;$108 = $$pre1$i10;
            }
            $105 = (($106) + 1)|0;
            HEAP32[$14>>2] = $105;
            $107 = (($108) + ($106<<3)|0);
            HEAP32[$107>>2] = $89;
            $109 = ((($108) + ($106<<3)|0) + 4|0);
            HEAP32[$109>>2] = $91;
           }
          }
         }
        }
       }
      }
     }
     $110 = ($33>>>0)<($10>>>0);
     if ($110) {
      $RunningAddress2$033 = $33;
     } else {
      break;
     }
    }
    $17 = ($18>>>0)<($10>>>0);
    $or$cond = $19 & $17;
    if ($or$cond) {
     $RunningAddress$035 = $RunningAddress$2;$Sorted$036 = $18;
    } else {
     $112 = 0;
     break;
    }
   }
  }
 } while(0);
 while(1) {
  $111 = (($selfCollBitmap) + ($112<<2)|0);
  $113 = HEAP32[$111>>2]|0;
  $114 = ($113|0)==(0);
  if (!($114)) {
   label = 26;
   break;
  }
  $115 = (($112) + 1)|0;
  $116 = ($115>>>0)<(256);
  if ($116) {
   $112 = $115;
  } else {
   label = 25;
   break;
  }
 }
 L32: do {
  if ((label|0) == 25) {
   $117 = HEAP32[$3>>2]|0;
   $$0$i7 = -1;$159 = $117;$223 = 1;$224 = $115;$225 = 0;$226 = 0;$j$0$i418 = 0;
  }
  else if ((label|0) == 26) {
   $118 = HEAP32[$3>>2]|0;
   $119 = $112 << 5;
   $120 = (0 - ($113))|0;
   $121 = $113 & $120;
   $122 = Math_imul($121, 125613361)|0;
   $123 = $122 >>> 27;
   $124 = (412480 + ($123<<2)|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = $125 | $119;
   $j$0$i4 = 1;
   while(1) {
    $127 = (($j$0$i4) + 1)|0;
    $128 = Math_imul($127, $j$0$i4)|0;
    $129 = $128 >>> 1;
    $130 = ($129>>>0)>($126>>>0);
    if ($130) {
     break;
    } else {
     $j$0$i4 = $127;
    }
   }
   $131 = (($j$0$i4) + -1)|0;
   $132 = Math_imul($131, $j$0$i4)|0;
   $133 = $132 >>> 1;
   $134 = (($126) - ($133))|0;
   $135 = (($113) + -1)|0;
   $136 = $135 & $113;
   $137 = ($136|0)==(0);
   if ($137) {
    $139 = $112;
    while(1) {
     $138 = (($139) + 1)|0;
     $140 = ($138>>>0)<(256);
     if (!($140)) {
      $$0$i7 = $126;$159 = $118;$223 = $j$0$i4;$224 = $138;$225 = 0;$226 = $134;$j$0$i418 = $j$0$i4;
      break L32;
     }
     $141 = (($selfCollBitmap) + ($138<<2)|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ($142|0)==(0);
     if ($143) {
      $139 = $138;
     } else {
      $$0$i7 = $126;$159 = $118;$223 = $j$0$i4;$224 = $138;$225 = $142;$226 = $134;$j$0$i418 = $j$0$i4;
      break;
     }
    }
   } else {
    $$0$i7 = $126;$159 = $118;$223 = $j$0$i4;$224 = $112;$225 = $136;$226 = $134;$j$0$i418 = $j$0$i4;
   }
  }
 } while(0);
 $144 = (($this) + 308|0);
 $145 = (($this) + 304|0);
 $146 = (($this) + 49848|0);
 $147 = (($this) + 49852|0);
 $148 = (($this) + 49844|0);
 $$ph20$ph = $223;$$ph21$ph = $224;$$ph22$ph = $225;$$ph23$ph = $226;$index$0$ph$ph = $$0$i7;$j$0$i416$ph$ph = $j$0$i418;
 L42: while(1) {
  $149 = $$ph21$ph << 5;
  $$ph20 = $$ph20$ph;$$ph22 = $$ph22$ph;$$ph23 = $$ph23$ph;$index$0$ph = $index$0$ph$ph;$j$0$i416$ph = $j$0$i416$ph$ph;
  while(1) {
   $150 = (($j$0$i416$ph) + -1)|0;
   $151 = Math_imul($150, $j$0$i416$ph)|0;
   $152 = $151 >>> 1;
   $153 = (($152) + ($$ph23))|0;
   $154 = $153 >>> 5;
   $155 = (($newBitmap) + ($154<<2)|0);
   $156 = $153 & 31;
   $157 = 1 << $156;
   $158 = (($159) + ($$ph23<<2)|0);
   $160 = (($159) + ($j$0$i416$ph<<2)|0);
   $198 = $$ph22;$index$0 = $index$0$ph;
   while(1) {
    $161 = ($index$0|0)==(-1);
    if ($161) {
     break L42;
    }
    $162 = HEAP32[$155>>2]|0;
    $163 = $162 & $157;
    $164 = ($163|0)==(0);
    if ($164) {
     $165 = HEAP32[$158>>2]|0;
     $166 = HEAP32[$160>>2]|0;
     $167 = HEAP32[$144>>2]|0;
     $168 = (($167) + ($165<<2)|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = ($169|0)==(1073741823);
     if (!($170)) {
      $171 = (($167) + ($166<<2)|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = ($172|0)==(1073741823);
      if (!($173)) {
       $174 = HEAP32[$145>>2]|0;
       $175 = (($174) + ($165<<2)|0);
       $176 = HEAP32[$175>>2]|0;
       $177 = (($174) + ($166<<2)|0);
       $178 = HEAP32[$177>>2]|0;
       $179 = HEAP32[$146>>2]|0;
       $180 = HEAP32[$147>>2]|0;
       $181 = ($179|0)==($180|0);
       if ($181) {
        $182 = ($179|0)==(0);
        $183 = $179 << 1;
        $$$i = $182 ? 32 : $183;
        $184 = HEAP32[$148>>2]|0;
        $185 = $$$i << 3;
        $186 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$185,481512,76)|0);
        $187 = ($184|0)==(0|0);
        if (!($187)) {
         $188 = $179 << 3;
         _memcpy(($186|0),($184|0),($188|0))|0;
        }
        $189 = (($186) + ($179<<3)|0);
        $190 = (($$$i) - ($179))|0;
        $191 = $190 << 3;
        _memset(($189|0),0,($191|0))|0;
        __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$184);
        HEAP32[$148>>2] = $186;
        HEAP32[$147>>2] = $$$i;
        $$pre$i3 = HEAP32[$146>>2]|0;
        $193 = $$pre$i3;$195 = $186;
       } else {
        $$pre1$i = HEAP32[$148>>2]|0;
        $193 = $179;$195 = $$pre1$i;
       }
       $192 = (($193) + 1)|0;
       HEAP32[$146>>2] = $192;
       $194 = (($195) + ($193<<3)|0);
       HEAP32[$194>>2] = $176;
       $196 = ((($195) + ($193<<3)|0) + 4|0);
       HEAP32[$196>>2] = $178;
      }
     }
    }
    $197 = ($198|0)==(0);
    if ($197) {
     $198 = 0;$index$0 = -1;
    } else {
     break;
    }
   }
   $199 = (0 - ($198))|0;
   $200 = $198 & $199;
   $201 = Math_imul($200, 125613361)|0;
   $202 = $201 >>> 27;
   $203 = (412480 + ($202<<2)|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = $204 | $149;
   $j$0$i = $$ph20;
   while(1) {
    $206 = (($j$0$i) + 1)|0;
    $207 = Math_imul($206, $j$0$i)|0;
    $208 = $207 >>> 1;
    $209 = ($208>>>0)>($205>>>0);
    if ($209) {
     break;
    } else {
     $j$0$i = $206;
    }
   }
   $210 = (($j$0$i) + -1)|0;
   $211 = Math_imul($210, $j$0$i)|0;
   $212 = $211 >>> 1;
   $213 = (($205) - ($212))|0;
   $214 = (($198) + -1)|0;
   $215 = $214 & $198;
   $216 = ($215|0)==(0);
   if ($216) {
    $218 = $$ph21$ph;
    break;
   } else {
    $$ph20 = $j$0$i;$$ph22 = $215;$$ph23 = $213;$index$0$ph = $205;$j$0$i416$ph = $j$0$i;
   }
  }
  while(1) {
   $217 = (($218) + 1)|0;
   $219 = ($217>>>0)<(256);
   if (!($219)) {
    $$ph20$ph = $j$0$i;$$ph21$ph = $217;$$ph22$ph = 0;$$ph23$ph = $213;$index$0$ph$ph = $205;$j$0$i416$ph$ph = $j$0$i;
    continue L42;
   }
   $220 = (($selfCollBitmap) + ($217<<2)|0);
   $221 = HEAP32[$220>>2]|0;
   $222 = ($221|0)==(0);
   if ($222) {
    $218 = $217;
   } else {
    $$ph20$ph = $j$0$i;$$ph21$ph = $217;$$ph22$ph = $221;$$ph23$ph = $213;$index$0$ph$ph = $205;$j$0$i416$ph$ph = $j$0$i;
    continue L42;
   }
  }
 }
 _memcpy(($selfCollBitmap|0),($newBitmap|0),1024)|0;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager21processAggregatePairsEPKNS_19AggregateSortedDataE($this,$aggregateSortedData) {
 $this = $this|0;
 $aggregateSortedData = $aggregateSortedData|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$$i$i$i6 = 0, $$pre = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre$i8 = 0, $$pre12 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aggregate0$0 = 0, $aggregate1$0 = 0, $aggregateId0$0 = 0, $aggregateId1$0 = 0, $i$011 = 0, $phitmp = 0, $phitmp15 = 0;
 var $phitmp16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 49824|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 49812|0);
 $4 = (($this) + 49856|0);
 $5 = (($this) + 24|0);
 $6 = (($this) + 180|0);
 $i$011 = 0;
 while(1) {
  $7 = HEAP32[$3>>2]|0;
  $8 = (($7) + ($i$011<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$4>>2]|0;
  $11 = (($10) + (($9*12)|0)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($10) + (($9*12)|0)|0) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$5>>2]|0;
  $16 = (($15) + ($12<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17 & 1;
  $19 = ($18|0)==(0);
  if ($19) {
   $aggregate0$0 = 0;$aggregateId0$0 = 1073741823;
  } else {
   $20 = $17 >>> 1;
   $21 = HEAP32[$6>>2]|0;
   $22 = (($21) + (($20*1048)|0)|0);
   $aggregate0$0 = $22;$aggregateId0$0 = $20;
  }
  $23 = (($15) + ($14<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 & 1;
  $26 = ($25|0)==(0);
  if ($26) {
   $aggregate1$0 = 0;$aggregateId1$0 = 1073741823;
  } else {
   $27 = $24 >>> 1;
   $28 = HEAP32[$6>>2]|0;
   $29 = (($28) + (($27*1048)|0)|0);
   $aggregate1$0 = $29;$aggregateId1$0 = $27;
  }
  $30 = ($aggregate0$0|0)==(0|0);
  $31 = ($aggregate1$0|0)!=(0|0);
  do {
   if ($30) {
    if ($31) {
     $92 = ((($10) + (($9*12)|0)|0) + 8|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ($93|0)==(0|0);
     if ($94) {
      $95 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 8|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (__Z15PxGetFoundationv()|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = (($100) + 24|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = (FUNCTION_TABLE_ii[$102 & 4095]($99)|0);
      $$$i$i$i = $103 ? 481896 : 481792;
      $104 = (FUNCTION_TABLE_iiiiii[$98 & 255]($95,12,$$$i$i$i,481296,2343)|0);
      HEAP32[$104>>2] = 0;
      $105 = (($104) + 4|0);
      HEAP32[$105>>2] = 0;
      HEAP32[$92>>2] = $104;
      $106 = (($aggregate1$0) + 1025|0);
      $107 = HEAP8[$106>>0]|0;
      $108 = $107&255;
      $109 = (($108) + 31)|0;
      $110 = $109 >>> 5;
      $111 = ($110|0)==(0);
      $112 = HEAP32[$104>>2]|0;
      if ($111) {
       $117 = $112;$118 = 0;
      } else {
       $113 = ($112|0)==(0|0);
       $114 = (($104) + 8|0);
       if (!($113)) {
        __ZN5physx6shdfnd9Allocator10deallocateEPv($114,$112);
       }
       HEAP32[$105>>2] = $110;
       $115 = $110 << 2;
       $116 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($114,$115,481824,362)|0);
       HEAP32[$104>>2] = $116;
       $$pre$i = HEAP32[$105>>2]|0;
       $phitmp16 = $$pre$i << 2;
       $117 = $116;$118 = $phitmp16;
      }
      _memset(($117|0),0,($118|0))|0;
      $$pre = HEAP32[$92>>2]|0;
      $120 = $$pre;
     } else {
      $120 = $93;
     }
     $119 = (($aggregateSortedData) + ($aggregateId1$0<<3)|0);
     __ZN5physx14PxsAABBManager22processAggregateSingleERKNS_19AggregateSortedDataERKNS_9AggregateEjPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$119,$aggregate1$0,$12,$120);
    }
   } else {
    $32 = ((($10) + (($9*12)|0)|0) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)!=(0|0);
    if ($31) {
     if ($34) {
      $65 = $33;
     } else {
      $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($36) + 8|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (__Z15PxGetFoundationv()|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + 24|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (FUNCTION_TABLE_ii[$42 & 4095]($39)|0);
      $$$i$i$i1 = $43 ? 481896 : 481792;
      $44 = (FUNCTION_TABLE_iiiiii[$38 & 255]($35,12,$$$i$i$i1,481296,2316)|0);
      HEAP32[$44>>2] = 0;
      $45 = (($44) + 4|0);
      HEAP32[$45>>2] = 0;
      HEAP32[$32>>2] = $44;
      $46 = (($aggregate0$0) + 1025|0);
      $47 = HEAP8[$46>>0]|0;
      $48 = $47&255;
      $49 = (($aggregate1$0) + 1025|0);
      $50 = HEAP8[$49>>0]|0;
      $51 = $50&255;
      $52 = Math_imul($51, $48)|0;
      $53 = (($52) + 31)|0;
      $54 = $53 >>> 5;
      $55 = ($54|0)==(0);
      $56 = HEAP32[$44>>2]|0;
      if ($55) {
       $61 = $56;$62 = 0;
      } else {
       $57 = ($56|0)==(0|0);
       $58 = (($44) + 8|0);
       if (!($57)) {
        __ZN5physx6shdfnd9Allocator10deallocateEPv($58,$56);
       }
       HEAP32[$45>>2] = $54;
       $59 = $54 << 2;
       $60 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($58,$59,481824,362)|0);
       HEAP32[$44>>2] = $60;
       $$pre$i3 = HEAP32[$45>>2]|0;
       $phitmp15 = $$pre$i3 << 2;
       $61 = $60;$62 = $phitmp15;
      }
      _memset(($61|0),0,($62|0))|0;
      $$pre12 = HEAP32[$32>>2]|0;
      $65 = $$pre12;
     }
     $63 = (($aggregateSortedData) + ($aggregateId0$0<<3)|0);
     $64 = (($aggregateSortedData) + ($aggregateId1$0<<3)|0);
     __ZN5physx14PxsAABBManager25processAggregateAggregateERKNS_19AggregateSortedDataERKNS_9AggregateES3_S6_PNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$63,$aggregate0$0,$64,$aggregate1$0,$65);
     break;
    } else {
     if ($34) {
      $91 = $33;
     } else {
      $66 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 8|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (__Z15PxGetFoundationv()|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = (($71) + 24|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (FUNCTION_TABLE_ii[$73 & 4095]($70)|0);
      $$$i$i$i6 = $74 ? 481896 : 481792;
      $75 = (FUNCTION_TABLE_iiiiii[$69 & 255]($66,12,$$$i$i$i6,481296,2328)|0);
      HEAP32[$75>>2] = 0;
      $76 = (($75) + 4|0);
      HEAP32[$76>>2] = 0;
      HEAP32[$32>>2] = $75;
      $77 = (($aggregate0$0) + 1025|0);
      $78 = HEAP8[$77>>0]|0;
      $79 = $78&255;
      $80 = (($79) + 31)|0;
      $81 = $80 >>> 5;
      $82 = ($81|0)==(0);
      $83 = HEAP32[$75>>2]|0;
      if ($82) {
       $88 = $83;$89 = 0;
      } else {
       $84 = ($83|0)==(0|0);
       $85 = (($75) + 8|0);
       if (!($84)) {
        __ZN5physx6shdfnd9Allocator10deallocateEPv($85,$83);
       }
       HEAP32[$76>>2] = $81;
       $86 = $81 << 2;
       $87 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($85,$86,481824,362)|0);
       HEAP32[$75>>2] = $87;
       $$pre$i8 = HEAP32[$76>>2]|0;
       $phitmp = $$pre$i8 << 2;
       $88 = $87;$89 = $phitmp;
      }
      _memset(($88|0),0,($89|0))|0;
      $$pre13 = HEAP32[$32>>2]|0;
      $91 = $$pre13;
     }
     $90 = (($aggregateSortedData) + ($aggregateId0$0<<3)|0);
     __ZN5physx14PxsAABBManager22processAggregateSingleERKNS_19AggregateSortedDataERKNS_9AggregateEjPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$90,$aggregate0$0,$14,$91);
     break;
    }
   }
  } while(0);
  $121 = (($i$011) + 1)|0;
  $122 = HEAP32[$0>>2]|0;
  $123 = ($121>>>0)<($122>>>0);
  if ($123) {
   $i$011 = $121;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager25processAggregateAggregateERKNS_19AggregateSortedDataERKNS_9AggregateES3_S6_PNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$aggregateSortedData0,$aggregate0,$aggregateSortedData1,$aggregate1,$overlapBitmap) {
 $this = $this|0;
 $aggregateSortedData0 = $aggregateSortedData0|0;
 $aggregate0 = $aggregate0|0;
 $aggregateSortedData1 = $aggregateSortedData1|0;
 $aggregate1 = $aggregate1|0;
 $overlapBitmap = $overlapBitmap|0;
 var $$$i = 0, $$$i13 = 0, $$$i20 = 0, $$ph = 0, $$ph30 = 0, $$ph31 = 0, $$ph3262 = 0, $$ph3363 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i15 = 0, $$pre$i22 = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $$pre1$i11 = 0, $$pre1$i18 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $RunningAddress0$050 = 0, $RunningAddress0$1$lcssa = 0, $RunningAddress0$145 = 0, $RunningAddress1$059 = 0, $RunningAddress1$1$lcssa = 0, $RunningAddress1$153 = 0, $RunningAddress2_0$047 = 0, $RunningAddress2_1$056 = 0, $Sorted0$060 = 0, $Sorted1$051 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$in$i = 0;
 var $index$0$ph3464 = 0, $index$037 = 0, $it$02$i$i = 0, $newBitmap = 0, $or$cond = 0, $or$cond$i$i$i = 0, $or$cond5 = 0, $or$cond58 = 0, $phitmp$i = 0, $phitmp$i25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2080|0;
 $0 = sp + 2065|0;
 $1 = sp + 2064|0;
 $newBitmap = sp;
 $2 = (($aggregate1) + 1025|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = (($aggregateSortedData0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($aggregateSortedData1) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = (($newBitmap) + 2048|0);
 HEAP32[$10>>2] = $9;
 $11 = (($newBitmap) + 2052|0);
 $12 = (($newBitmap) + 2056|0);
 HEAP32[$11>>2] = $newBitmap;
 HEAP32[$12>>2] = -2147483136;
 _memset(($newBitmap|0),0,2048)|0;
 $13 = (($this) + 300|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$aggregateSortedData0>>2]|0;
 $16 = HEAP32[$aggregateSortedData1>>2]|0;
 $17 = (($aggregate0) + 1026|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = (($15) + ($19<<2)|0);
 $21 = (($aggregate1) + 1026|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22&255;
 $24 = (($16) + ($23<<2)|0);
 $25 = ($22<<24>>24)!=(0);
 $26 = ($18<<24>>24)!=(0);
 $or$cond58 = $25 & $26;
 L1: do {
  if ($or$cond58) {
   $27 = (($this) + 308|0);
   $28 = (($this) + 304|0);
   $29 = (($this) + 49836|0);
   $30 = (($this) + 49840|0);
   $31 = (($this) + 49832|0);
   $RunningAddress1$059 = $16;$Sorted0$060 = $15;
   while(1) {
    $33 = (($Sorted0$060) + 4|0);
    $40 = HEAP32[$Sorted0$060>>2]|0;
    $41 = ($RunningAddress1$059>>>0)<($24>>>0);
    L5: do {
     if ($41) {
      $42 = (($6) + ($40<<2)|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = (($14) + (($43*24)|0)|0);
      $45 = HEAP32[$44>>2]|0;
      $RunningAddress1$153 = $RunningAddress1$059;
      while(1) {
       $48 = HEAP32[$RunningAddress1$153>>2]|0;
       $49 = (($8) + ($48<<2)|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = (($14) + (($50*24)|0)|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52>>>0)<($45>>>0);
       $47 = (($RunningAddress1$153) + 4|0);
       if (!($53)) {
        $RunningAddress1$1$lcssa = $RunningAddress1$153;
        break L5;
       }
       $46 = ($47>>>0)<($24>>>0);
       if ($46) {
        $RunningAddress1$153 = $47;
       } else {
        $RunningAddress1$1$lcssa = $47;
        break;
       }
      }
     } else {
      $RunningAddress1$1$lcssa = $RunningAddress1$059;
     }
    } while(0);
    $34 = ($RunningAddress1$1$lcssa>>>0)<($24>>>0);
    if (!($34)) {
     break;
    }
    $54 = (($6) + ($40<<2)|0);
    $55 = Math_imul($40, $4)|0;
    $RunningAddress2_1$056 = $RunningAddress1$1$lcssa;
    while(1) {
     $56 = (($RunningAddress2_1$056) + 4|0);
     $57 = HEAP32[$RunningAddress2_1$056>>2]|0;
     $58 = (($8) + ($57<<2)|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = (($14) + (($59*24)|0)|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = HEAP32[$54>>2]|0;
     $63 = ((($14) + (($62*24)|0)|0) + 12|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($61>>>0)>($64>>>0);
     if ($65) {
      break;
     }
     $66 = HEAP32[$27>>2]|0;
     $67 = (($66) + ($62<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($66) + ($59<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($68|0)==($70|0);
     if (!($71)) {
      $72 = (($14) + (($62*24)|0)|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = ((($14) + (($59*24)|0)|0) + 12|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($73>>>0)>($75>>>0);
      if (!($76)) {
       $77 = ((($14) + (($59*24)|0)|0) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ((($14) + (($62*24)|0)|0) + 16|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = ($78>>>0)>($80>>>0);
       if (!($81)) {
        $82 = ((($14) + (($62*24)|0)|0) + 4|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = ((($14) + (($59*24)|0)|0) + 16|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = ($83>>>0)>($85>>>0);
        if (!($86)) {
         $87 = ((($14) + (($59*24)|0)|0) + 8|0);
         $88 = HEAP32[$87>>2]|0;
         $89 = ((($14) + (($62*24)|0)|0) + 20|0);
         $90 = HEAP32[$89>>2]|0;
         $91 = ($88>>>0)>($90>>>0);
         if (!($91)) {
          $92 = ((($14) + (($62*24)|0)|0) + 8|0);
          $93 = HEAP32[$92>>2]|0;
          $94 = ((($14) + (($59*24)|0)|0) + 20|0);
          $95 = HEAP32[$94>>2]|0;
          $phitmp$i25 = ($93>>>0)>($95>>>0);
          if (!($phitmp$i25)) {
           $96 = (($57) + ($55))|0;
           $97 = $96 & 31;
           $98 = ((($this) + ($97<<2)|0) + 384|0);
           $99 = HEAP32[$98>>2]|0;
           $100 = $96 >>> 5;
           $101 = HEAP32[$11>>2]|0;
           $102 = (($101) + ($100<<2)|0);
           $103 = HEAP32[$102>>2]|0;
           $104 = $103 | $99;
           HEAP32[$102>>2] = $104;
           $105 = HEAP32[$overlapBitmap>>2]|0;
           $106 = (($105) + ($100<<2)|0);
           $107 = HEAP32[$106>>2]|0;
           $108 = HEAP32[$98>>2]|0;
           $109 = $108 & $107;
           $110 = ($109|0)==(0);
           if ($110) {
            $111 = HEAP32[$28>>2]|0;
            $112 = (($111) + ($62<<2)|0);
            $113 = HEAP32[$112>>2]|0;
            $114 = (($111) + ($59<<2)|0);
            $115 = HEAP32[$114>>2]|0;
            $116 = HEAP32[$29>>2]|0;
            $117 = HEAP32[$30>>2]|0;
            $118 = ($116|0)==($117|0);
            if ($118) {
             $119 = ($116|0)==(0);
             $120 = $116 << 1;
             $$$i20 = $119 ? 32 : $120;
             $121 = HEAP32[$31>>2]|0;
             $122 = $$$i20 << 3;
             $123 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$122,481512,76)|0);
             $124 = ($121|0)==(0|0);
             if (!($124)) {
              $125 = $116 << 3;
              _memcpy(($123|0),($121|0),($125|0))|0;
             }
             $126 = (($123) + ($116<<3)|0);
             $127 = (($$$i20) - ($116))|0;
             $128 = $127 << 3;
             _memset(($126|0),0,($128|0))|0;
             __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$121);
             HEAP32[$31>>2] = $123;
             HEAP32[$30>>2] = $$$i20;
             $$pre$i22 = HEAP32[$29>>2]|0;
             $130 = $$pre$i22;$132 = $123;
            } else {
             $$pre1$i18 = HEAP32[$31>>2]|0;
             $130 = $116;$132 = $$pre1$i18;
            }
            $129 = (($130) + 1)|0;
            HEAP32[$29>>2] = $129;
            $131 = (($132) + ($130<<3)|0);
            HEAP32[$131>>2] = $113;
            $133 = ((($132) + ($130<<3)|0) + 4|0);
            HEAP32[$133>>2] = $115;
           }
          }
         }
        }
       }
      }
     }
     $134 = ($56>>>0)<($24>>>0);
     if ($134) {
      $RunningAddress2_1$056 = $56;
     } else {
      break;
     }
    }
    $32 = ($33>>>0)<($20>>>0);
    $or$cond = $34 & $32;
    if ($or$cond) {
     $RunningAddress1$059 = $RunningAddress1$1$lcssa;$Sorted0$060 = $33;
    } else {
     break;
    }
   }
   if ($or$cond58) {
    $35 = (($this) + 308|0);
    $36 = (($this) + 304|0);
    $37 = (($this) + 49836|0);
    $38 = (($this) + 49840|0);
    $39 = (($this) + 49832|0);
    $RunningAddress0$050 = $15;$Sorted1$051 = $16;
    while(1) {
     $136 = (($Sorted1$051) + 4|0);
     $138 = HEAP32[$Sorted1$051>>2]|0;
     $139 = ($RunningAddress0$050>>>0)<($20>>>0);
     L36: do {
      if ($139) {
       $140 = (($8) + ($138<<2)|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = (($14) + (($141*24)|0)|0);
       $143 = HEAP32[$142>>2]|0;
       $RunningAddress0$145 = $RunningAddress0$050;
       while(1) {
        $146 = HEAP32[$RunningAddress0$145>>2]|0;
        $147 = (($6) + ($146<<2)|0);
        $148 = HEAP32[$147>>2]|0;
        $149 = (($14) + (($148*24)|0)|0);
        $150 = HEAP32[$149>>2]|0;
        $151 = ($150>>>0)>($143>>>0);
        $145 = (($RunningAddress0$145) + 4|0);
        if ($151) {
         $RunningAddress0$1$lcssa = $RunningAddress0$145;
         break L36;
        }
        $144 = ($145>>>0)<($20>>>0);
        if ($144) {
         $RunningAddress0$145 = $145;
        } else {
         $RunningAddress0$1$lcssa = $145;
         break;
        }
       }
      } else {
       $RunningAddress0$1$lcssa = $RunningAddress0$050;
      }
     } while(0);
     $137 = ($RunningAddress0$1$lcssa>>>0)<($20>>>0);
     if (!($137)) {
      break L1;
     }
     $152 = (($8) + ($138<<2)|0);
     $RunningAddress2_0$047 = $RunningAddress0$1$lcssa;
     while(1) {
      $153 = (($RunningAddress2_0$047) + 4|0);
      $154 = HEAP32[$RunningAddress2_0$047>>2]|0;
      $155 = (($6) + ($154<<2)|0);
      $156 = HEAP32[$155>>2]|0;
      $157 = (($14) + (($156*24)|0)|0);
      $158 = HEAP32[$157>>2]|0;
      $159 = HEAP32[$152>>2]|0;
      $160 = ((($14) + (($159*24)|0)|0) + 12|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = ($158>>>0)>($161>>>0);
      if ($162) {
       break;
      }
      $163 = HEAP32[$35>>2]|0;
      $164 = (($163) + ($156<<2)|0);
      $165 = HEAP32[$164>>2]|0;
      $166 = (($163) + ($159<<2)|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = ($165|0)==($167|0);
      if (!($168)) {
       $169 = (($14) + (($159*24)|0)|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = ((($14) + (($156*24)|0)|0) + 12|0);
       $172 = HEAP32[$171>>2]|0;
       $173 = ($170>>>0)>($172>>>0);
       if (!($173)) {
        $174 = ((($14) + (($159*24)|0)|0) + 4|0);
        $175 = HEAP32[$174>>2]|0;
        $176 = ((($14) + (($156*24)|0)|0) + 16|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = ($175>>>0)>($177>>>0);
        if (!($178)) {
         $179 = ((($14) + (($156*24)|0)|0) + 4|0);
         $180 = HEAP32[$179>>2]|0;
         $181 = ((($14) + (($159*24)|0)|0) + 16|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = ($180>>>0)>($182>>>0);
         if (!($183)) {
          $184 = ((($14) + (($159*24)|0)|0) + 8|0);
          $185 = HEAP32[$184>>2]|0;
          $186 = ((($14) + (($156*24)|0)|0) + 20|0);
          $187 = HEAP32[$186>>2]|0;
          $188 = ($185>>>0)>($187>>>0);
          if (!($188)) {
           $189 = ((($14) + (($156*24)|0)|0) + 8|0);
           $190 = HEAP32[$189>>2]|0;
           $191 = ((($14) + (($159*24)|0)|0) + 20|0);
           $192 = HEAP32[$191>>2]|0;
           $phitmp$i = ($190>>>0)>($192>>>0);
           if (!($phitmp$i)) {
            $193 = Math_imul($154, $4)|0;
            $194 = (($193) + ($138))|0;
            $195 = $194 & 31;
            $196 = ((($this) + ($195<<2)|0) + 384|0);
            $197 = HEAP32[$196>>2]|0;
            $198 = $194 >>> 5;
            $199 = HEAP32[$11>>2]|0;
            $200 = (($199) + ($198<<2)|0);
            $201 = HEAP32[$200>>2]|0;
            $202 = $201 | $197;
            HEAP32[$200>>2] = $202;
            $203 = HEAP32[$overlapBitmap>>2]|0;
            $204 = (($203) + ($198<<2)|0);
            $205 = HEAP32[$204>>2]|0;
            $206 = HEAP32[$196>>2]|0;
            $207 = $206 & $205;
            $208 = ($207|0)==(0);
            if ($208) {
             $209 = HEAP32[$36>>2]|0;
             $210 = (($209) + ($156<<2)|0);
             $211 = HEAP32[$210>>2]|0;
             $212 = (($209) + ($159<<2)|0);
             $213 = HEAP32[$212>>2]|0;
             $214 = HEAP32[$37>>2]|0;
             $215 = HEAP32[$38>>2]|0;
             $216 = ($214|0)==($215|0);
             if ($216) {
              $217 = ($214|0)==(0);
              $218 = $214 << 1;
              $$$i13 = $217 ? 32 : $218;
              $219 = HEAP32[$39>>2]|0;
              $220 = $$$i13 << 3;
              $221 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$220,481512,76)|0);
              $222 = ($219|0)==(0|0);
              if (!($222)) {
               $223 = $214 << 3;
               _memcpy(($221|0),($219|0),($223|0))|0;
              }
              $224 = (($221) + ($214<<3)|0);
              $225 = (($$$i13) - ($214))|0;
              $226 = $225 << 3;
              _memset(($224|0),0,($226|0))|0;
              __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$219);
              HEAP32[$39>>2] = $221;
              HEAP32[$38>>2] = $$$i13;
              $$pre$i15 = HEAP32[$37>>2]|0;
              $228 = $$pre$i15;$230 = $221;
             } else {
              $$pre1$i11 = HEAP32[$39>>2]|0;
              $228 = $214;$230 = $$pre1$i11;
             }
             $227 = (($228) + 1)|0;
             HEAP32[$37>>2] = $227;
             $229 = (($230) + ($228<<3)|0);
             HEAP32[$229>>2] = $211;
             $231 = ((($230) + ($228<<3)|0) + 4|0);
             HEAP32[$231>>2] = $213;
            }
           }
          }
         }
        }
       }
      }
      $232 = ($153>>>0)<($20>>>0);
      if ($232) {
       $RunningAddress2_0$047 = $153;
      } else {
       break;
      }
     }
     $135 = ($136>>>0)<($24>>>0);
     $or$cond5 = $137 & $135;
     if ($or$cond5) {
      $RunningAddress0$050 = $RunningAddress0$1$lcssa;$Sorted1$051 = $136;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 $233 = (($overlapBitmap) + 4|0);
 $234 = HEAP32[$233>>2]|0;
 $235 = $234 & 2147483647;
 $236 = ($235|0)==(0);
 L64: do {
  if ($236) {
   label = 57;
  } else {
   $$pre$i$i$i = HEAP32[$overlapBitmap>>2]|0;
   $238 = 0;
   while(1) {
    $237 = (($$pre$i$i$i) + ($238<<2)|0);
    $239 = HEAP32[$237>>2]|0;
    $240 = ($239|0)==(0);
    if (!($240)) {
     break;
    }
    $241 = (($238) + 1)|0;
    $242 = ($241>>>0)<($235>>>0);
    if ($242) {
     $238 = $241;
    } else {
     label = 57;
     break L64;
    }
   }
   $243 = $238 << 5;
   $244 = (0 - ($239))|0;
   $245 = $239 & $244;
   $246 = Math_imul($245, 125613361)|0;
   $247 = $246 >>> 27;
   $248 = (412480 + ($247<<2)|0);
   $249 = HEAP32[$248>>2]|0;
   $250 = $249 | $243;
   $251 = (($239) + -1)|0;
   $252 = $251 & $239;
   $253 = ($252|0)==(0);
   L70: do {
    if ($253) {
     $255 = $238;
     while(1) {
      $254 = (($255) + 1)|0;
      $256 = ($254>>>0)<($235>>>0);
      if (!($256)) {
       $$ph30 = $254;$$ph31 = 0;
       break L70;
      }
      $257 = (($$pre$i$i$i) + ($254<<2)|0);
      $258 = HEAP32[$257>>2]|0;
      $259 = ($258|0)==(0);
      if ($259) {
       $255 = $254;
      } else {
       $$ph30 = $254;$$ph31 = $258;
       break;
      }
     }
    } else {
     $$ph30 = $238;$$ph31 = $252;
    }
   } while(0);
   $260 = ($250|0)==(-1);
   if ($260) {
    label = 57;
   } else {
    $261 = (($this) + 308|0);
    $262 = (($this) + 304|0);
    $263 = (($this) + 49848|0);
    $264 = (($this) + 49852|0);
    $265 = (($this) + 49844|0);
    $$ph3262 = $$ph30;$$ph3363 = $$ph31;$index$0$ph3464 = $250;
    L76: while(1) {
     $268 = $$ph3262 << 5;
     $316 = $$ph3363;$index$037 = $index$0$ph3464;
     while(1) {
      $269 = $index$037 >>> 5;
      $270 = HEAP32[$11>>2]|0;
      $271 = (($270) + ($269<<2)|0);
      $272 = HEAP32[$271>>2]|0;
      $273 = $index$037 & 31;
      $274 = ((($this) + ($273<<2)|0) + 384|0);
      $275 = HEAP32[$274>>2]|0;
      $276 = $275 & $272;
      $277 = ($276|0)==(0);
      if ($277) {
       $278 = (($index$037>>>0) / ($4>>>0))&-1;
       $279 = Math_imul($278, $4)|0;
       $280 = (($index$037) - ($279))|0;
       $281 = (($6) + ($278<<2)|0);
       $282 = HEAP32[$281>>2]|0;
       $283 = (($8) + ($280<<2)|0);
       $284 = HEAP32[$283>>2]|0;
       $285 = HEAP32[$261>>2]|0;
       $286 = (($285) + ($282<<2)|0);
       $287 = HEAP32[$286>>2]|0;
       $288 = ($287|0)==(1073741823);
       if (!($288)) {
        $289 = (($285) + ($284<<2)|0);
        $290 = HEAP32[$289>>2]|0;
        $291 = ($290|0)==(1073741823);
        if (!($291)) {
         $292 = HEAP32[$262>>2]|0;
         $293 = (($292) + ($282<<2)|0);
         $294 = HEAP32[$293>>2]|0;
         $295 = (($292) + ($284<<2)|0);
         $296 = HEAP32[$295>>2]|0;
         $297 = HEAP32[$263>>2]|0;
         $298 = HEAP32[$264>>2]|0;
         $299 = ($297|0)==($298|0);
         if ($299) {
          $300 = ($297|0)==(0);
          $301 = $297 << 1;
          $$$i = $300 ? 32 : $301;
          $302 = HEAP32[$265>>2]|0;
          $303 = $$$i << 3;
          $304 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$303,481512,76)|0);
          $305 = ($302|0)==(0|0);
          if (!($305)) {
           $306 = $297 << 3;
           _memcpy(($304|0),($302|0),($306|0))|0;
          }
          $307 = (($304) + ($297<<3)|0);
          $308 = (($$$i) - ($297))|0;
          $309 = $308 << 3;
          _memset(($307|0),0,($309|0))|0;
          __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$302);
          HEAP32[$265>>2] = $304;
          HEAP32[$264>>2] = $$$i;
          $$pre$i = HEAP32[$263>>2]|0;
          $311 = $$pre$i;$313 = $304;
         } else {
          $$pre1$i = HEAP32[$265>>2]|0;
          $311 = $297;$313 = $$pre1$i;
         }
         $310 = (($311) + 1)|0;
         HEAP32[$263>>2] = $310;
         $312 = (($313) + ($311<<3)|0);
         HEAP32[$312>>2] = $294;
         $314 = ((($313) + ($311<<3)|0) + 4|0);
         HEAP32[$314>>2] = $296;
        }
       }
      }
      $315 = ($316|0)==(0);
      if ($315) {
       break L76;
      }
      $318 = (0 - ($316))|0;
      $319 = $316 & $318;
      $320 = Math_imul($319, 125613361)|0;
      $321 = $320 >>> 27;
      $322 = (412480 + ($321<<2)|0);
      $323 = HEAP32[$322>>2]|0;
      $267 = $323 | $268;
      $324 = (($316) + -1)|0;
      $325 = $324 & $316;
      $326 = HEAP32[$233>>2]|0;
      $327 = $326 & 2147483647;
      $328 = ($325|0)==(0);
      if ($328) {
       $330 = $$ph3262;
       break;
      }
      $317 = ($267|0)==(-1);
      if ($317) {
       break L76;
      } else {
       $316 = $325;$index$037 = $267;
      }
     }
     while(1) {
      $329 = (($330) + 1)|0;
      $331 = ($329>>>0)<($327>>>0);
      if (!($331)) {
       $$ph = 0;
       break;
      }
      $332 = HEAP32[$overlapBitmap>>2]|0;
      $333 = (($332) + ($329<<2)|0);
      $334 = HEAP32[$333>>2]|0;
      $335 = ($334|0)==(0);
      if ($335) {
       $330 = $329;
      } else {
       $$ph = $334;
       break;
      }
     }
     $266 = ($267|0)==(-1);
     if ($266) {
      $$pre$phiZ2D = $overlapBitmap;$339 = $326;
      break L64;
     } else {
      $$ph3262 = $329;$$ph3363 = $$ph;$index$0$ph3464 = $267;
     }
    }
    $$pre = HEAP32[$233>>2]|0;
    $$pre$phiZ2D = $overlapBitmap;$339 = $$pre;
   }
  }
 } while(0);
 if ((label|0) == 57) {
  $$pre$phiZ2D = $overlapBitmap;$339 = $234;
 }
 $336 = HEAP32[$$pre$phiZ2D>>2]|0;
 $337 = HEAP32[$11>>2]|0;
 $338 = $339 << 2;
 _memcpy(($336|0),($337|0),($338|0))|0;
 $340 = HEAP32[$11>>2]|0;
 $341 = ($340|0)==(0|0);
 $342 = ($340|0)==($newBitmap|0);
 $or$cond$i$i$i = $341 | $342;
 if ($or$cond$i$i$i) {
  STACKTOP = sp;return;
 }
 $343 = HEAP32[$10>>2]|0;
 $344 = ($343|0)==(0|0);
 if ($344) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$340);
  STACKTOP = sp;return;
 }
 $345 = (($343) + 16|0);
 $346 = HEAP32[$345>>2]|0;
 $347 = ($346>>>0)>($340>>>0);
 if (!($347)) {
  $348 = (($343) + 20|0);
  $349 = HEAP32[$348>>2]|0;
  $350 = (($346) + ($349)|0);
  $351 = ($350>>>0)>($340>>>0);
  if ($351) {
   $352 = HEAP32[$343>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($352);
   $353 = (($343) + 8|0);
   $354 = HEAP32[$353>>2]|0;
   $355 = (($343) + 4|0);
   $356 = HEAP32[$355>>2]|0;
   $i$0$in$i = $354;
   while(1) {
    $i$0$i = (($i$0$in$i) + -1)|0;
    $357 = (($356) + ($i$0$i<<2)|0);
    $358 = HEAP32[$357>>2]|0;
    $359 = ($358>>>0)<($340>>>0);
    if ($359) {
     $i$0$in$i = $i$0$i;
    } else {
     break;
    }
   }
   $360 = ($i$0$in$i>>>0)<($354>>>0);
   if ($360) {
    $364 = $i$0$in$i;$it$02$i$i = $357;
    while(1) {
     $361 = ($it$02$i$i|0)==(0|0);
     if (!($361)) {
      $362 = HEAP32[$355>>2]|0;
      $363 = (($362) + ($364<<2)|0);
      $365 = HEAP32[$363>>2]|0;
      HEAP32[$it$02$i$i>>2] = $365;
     }
     $366 = (($it$02$i$i) + 4|0);
     $367 = (($364) + 1)|0;
     $exitcond$i = ($367|0)==($354|0);
     if ($exitcond$i) {
      break;
     } else {
      $364 = $367;$it$02$i$i = $366;
     }
    }
   }
   $368 = (($354) + -1)|0;
   HEAP32[$353>>2] = $368;
   $369 = HEAP32[$343>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($369);
   STACKTOP = sp;return;
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$340);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsAABBManager22processAggregateSingleERKNS_19AggregateSortedDataERKNS_9AggregateEjPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$aggregateSortedData,$aggregate,$singleId,$overlapBitmap) {
 $this = $this|0;
 $aggregateSortedData = $aggregateSortedData|0;
 $aggregate = $aggregate|0;
 $singleId = $singleId|0;
 $overlapBitmap = $overlapBitmap|0;
 var $$$i = 0, $$$i13 = 0, $$$i20 = 0, $$ph = 0, $$ph30 = 0, $$ph31 = 0, $$ph3260 = 0, $$ph3361 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i15 = 0, $$pre$i22 = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $$pre1$i11 = 0, $$pre1$i18 = 0, $$pre78 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $RunningAddress0$049 = 0, $RunningAddress0$1$lcssa = 0, $RunningAddress0$145 = 0, $RunningAddress1$1$lcssa = 0, $RunningAddress1$152 = 0, $RunningAddress2_0$047 = 0, $RunningAddress2_1$055 = 0, $Sorted1$050 = 0, $exitcond$i = 0, $i$0$i = 0;
 var $i$0$in$i = 0, $index$0$ph3462 = 0, $index$037 = 0, $it$02$i$i = 0, $newBitmap = 0, $or$cond$i$i$i = 0, $or$cond5 = 0, $phitmp$i = 0, $phitmp$i25 = 0, $singleBounds = 0, $singleGroups = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 61|0;
 $1 = sp + 60|0;
 $newBitmap = sp;
 $singleBounds = sp + 32|0;
 $singleGroups = sp + 56|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($newBitmap) + 16|0);
 HEAP32[$3>>2] = $2;
 $4 = (($newBitmap) + 20|0);
 $5 = (($newBitmap) + 24|0);
 HEAP32[$4>>2] = $newBitmap;
 HEAP32[$5>>2] = -2147483644;
 ;HEAP32[$newBitmap+0>>2]=0|0;HEAP32[$newBitmap+4>>2]=0|0;HEAP32[$newBitmap+8>>2]=0|0;HEAP32[$newBitmap+12>>2]=0|0;
 $6 = (($aggregate) + 1025|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = (($this) + 300|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 308|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$aggregateSortedData>>2]|0;
 $14 = (($aggregateSortedData) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + (($singleId*24)|0)|0);
 ;HEAP32[$singleBounds+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$singleBounds+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$singleBounds+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$singleBounds+12>>2]=HEAP32[$18+12>>2]|0;HEAP32[$singleBounds+16>>2]=HEAP32[$18+16>>2]|0;HEAP32[$singleBounds+20>>2]=HEAP32[$18+20>>2]|0;
 $19 = (($this) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($singleId<<2)|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$singleGroups>>2] = $22;
 $23 = (($aggregate) + 1026|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24&255;
 $26 = (($13) + ($25<<2)|0);
 $27 = ($24<<24>>24)==(0);
 L1: do {
  if (!($27)) {
   $33 = (($this) + 304|0);
   $34 = (($this) + 16|0);
   $35 = (($this) + 49836|0);
   $36 = (($this) + 49840|0);
   $37 = (($this) + 49832|0);
   $38 = ($24<<24>>24)==(0);
   L3: do {
    if ($38) {
     $RunningAddress1$1$lcssa = $13;
    } else {
     $39 = HEAP32[$singleBounds>>2]|0;
     $RunningAddress1$152 = $13;
     while(1) {
      $42 = HEAP32[$RunningAddress1$152>>2]|0;
      $43 = (($15) + ($42<<2)|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = (($10) + (($44*24)|0)|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46>>>0)<($39>>>0);
      $41 = (($RunningAddress1$152) + 4|0);
      if (!($47)) {
       $RunningAddress1$1$lcssa = $RunningAddress1$152;
       break L3;
      }
      $40 = ($41>>>0)<($26>>>0);
      if ($40) {
       $RunningAddress1$152 = $41;
      } else {
       $RunningAddress1$1$lcssa = $41;
       break;
      }
     }
    }
   } while(0);
   $48 = ($RunningAddress1$1$lcssa>>>0)<($26>>>0);
   L9: do {
    if ($48) {
     $49 = (($singleBounds) + 12|0);
     $50 = (($singleBounds) + 16|0);
     $51 = (($singleBounds) + 4|0);
     $52 = (($singleBounds) + 20|0);
     $53 = (($singleBounds) + 8|0);
     $$pre78 = HEAP32[$49>>2]|0;
     $RunningAddress2_1$055 = $RunningAddress1$1$lcssa;
     while(1) {
      $54 = (($RunningAddress2_1$055) + 4|0);
      $55 = HEAP32[$RunningAddress2_1$055>>2]|0;
      $56 = (($15) + ($55<<2)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($10) + (($57*24)|0)|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($59>>>0)>($$pre78>>>0);
      if ($60) {
       break L9;
      }
      $61 = (($12) + ($57<<2)|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = HEAP32[$singleGroups>>2]|0;
      $64 = ($62|0)==($63|0);
      if (!($64)) {
       $65 = HEAP32[$singleBounds>>2]|0;
       $66 = ((($10) + (($57*24)|0)|0) + 12|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = ($65>>>0)>($67>>>0);
       if (!($68)) {
        $69 = ((($10) + (($57*24)|0)|0) + 4|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = HEAP32[$50>>2]|0;
        $72 = ($70>>>0)>($71>>>0);
        if (!($72)) {
         $73 = HEAP32[$51>>2]|0;
         $74 = ((($10) + (($57*24)|0)|0) + 16|0);
         $75 = HEAP32[$74>>2]|0;
         $76 = ($73>>>0)>($75>>>0);
         if (!($76)) {
          $77 = ((($10) + (($57*24)|0)|0) + 8|0);
          $78 = HEAP32[$77>>2]|0;
          $79 = HEAP32[$52>>2]|0;
          $80 = ($78>>>0)>($79>>>0);
          if (!($80)) {
           $81 = HEAP32[$53>>2]|0;
           $82 = ((($10) + (($57*24)|0)|0) + 20|0);
           $83 = HEAP32[$82>>2]|0;
           $phitmp$i25 = ($81>>>0)>($83>>>0);
           if (!($phitmp$i25)) {
            $84 = $55 & 31;
            $85 = ((($this) + ($84<<2)|0) + 384|0);
            $86 = HEAP32[$85>>2]|0;
            $87 = $55 >>> 5;
            $88 = HEAP32[$4>>2]|0;
            $89 = (($88) + ($87<<2)|0);
            $90 = HEAP32[$89>>2]|0;
            $91 = $90 | $86;
            HEAP32[$89>>2] = $91;
            $92 = HEAP32[$overlapBitmap>>2]|0;
            $93 = (($92) + ($87<<2)|0);
            $94 = HEAP32[$93>>2]|0;
            $95 = HEAP32[$85>>2]|0;
            $96 = $95 & $94;
            $97 = ($96|0)==(0);
            if ($97) {
             $98 = HEAP32[$33>>2]|0;
             $99 = (($98) + ($57<<2)|0);
             $100 = HEAP32[$99>>2]|0;
             $101 = HEAP32[$34>>2]|0;
             $102 = (($101) + ($singleId<<2)|0);
             $103 = HEAP32[$102>>2]|0;
             $104 = HEAP32[$35>>2]|0;
             $105 = HEAP32[$36>>2]|0;
             $106 = ($104|0)==($105|0);
             if ($106) {
              $107 = ($104|0)==(0);
              $108 = $104 << 1;
              $$$i20 = $107 ? 32 : $108;
              $109 = HEAP32[$37>>2]|0;
              $110 = $$$i20 << 3;
              $111 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$110,481512,76)|0);
              $112 = ($109|0)==(0|0);
              if (!($112)) {
               $113 = $104 << 3;
               _memcpy(($111|0),($109|0),($113|0))|0;
              }
              $114 = (($111) + ($104<<3)|0);
              $115 = (($$$i20) - ($104))|0;
              $116 = $115 << 3;
              _memset(($114|0),0,($116|0))|0;
              __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$109);
              HEAP32[$37>>2] = $111;
              HEAP32[$36>>2] = $$$i20;
              $$pre$i22 = HEAP32[$35>>2]|0;
              $118 = $$pre$i22;$120 = $111;
             } else {
              $$pre1$i18 = HEAP32[$37>>2]|0;
              $118 = $104;$120 = $$pre1$i18;
             }
             $117 = (($118) + 1)|0;
             HEAP32[$35>>2] = $117;
             $119 = (($120) + ($118<<3)|0);
             HEAP32[$119>>2] = $100;
             $121 = ((($120) + ($118<<3)|0) + 4|0);
             HEAP32[$121>>2] = $103;
            }
           }
          }
         }
        }
       }
      }
      $122 = ($54>>>0)<($26>>>0);
      if ($122) {
       $RunningAddress2_1$055 = $54;
      } else {
       break;
      }
     }
    }
   } while(0);
   if (!($27)) {
    $28 = (($this) + 304|0);
    $29 = (($this) + 16|0);
    $30 = (($this) + 49836|0);
    $31 = (($this) + 49840|0);
    $32 = (($this) + 49832|0);
    $RunningAddress0$049 = 481504;$Sorted1$050 = $13;
    while(1) {
     $124 = (($Sorted1$050) + 4|0);
     $126 = HEAP32[$Sorted1$050>>2]|0;
     $127 = ($RunningAddress0$049>>>0)<(((481504 + 4|0))>>>0);
     L34: do {
      if ($127) {
       $128 = (($15) + ($126<<2)|0);
       $129 = HEAP32[$128>>2]|0;
       $130 = (($10) + (($129*24)|0)|0);
       $131 = HEAP32[$130>>2]|0;
       $RunningAddress0$145 = $RunningAddress0$049;
       while(1) {
        $134 = HEAP32[$RunningAddress0$145>>2]|0;
        $135 = (481504 + ($134<<2)|0);
        $136 = HEAP32[$135>>2]|0;
        $137 = (($singleBounds) + (($136*24)|0)|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = ($138>>>0)>($131>>>0);
        $133 = (($RunningAddress0$145) + 4|0);
        if ($139) {
         $RunningAddress0$1$lcssa = $RunningAddress0$145;
         break L34;
        }
        $132 = ($133>>>0)<(((481504 + 4|0))>>>0);
        if ($132) {
         $RunningAddress0$145 = $133;
        } else {
         $RunningAddress0$1$lcssa = $133;
         break;
        }
       }
      } else {
       $RunningAddress0$1$lcssa = $RunningAddress0$049;
      }
     } while(0);
     $125 = ($RunningAddress0$1$lcssa>>>0)<(((481504 + 4|0))>>>0);
     if (!($125)) {
      break L1;
     }
     $140 = (($15) + ($126<<2)|0);
     $RunningAddress2_0$047 = $RunningAddress0$1$lcssa;
     while(1) {
      $141 = (($RunningAddress2_0$047) + 4|0);
      $142 = HEAP32[$RunningAddress2_0$047>>2]|0;
      $143 = (481504 + ($142<<2)|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($singleBounds) + (($144*24)|0)|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = HEAP32[$140>>2]|0;
      $148 = ((($10) + (($147*24)|0)|0) + 12|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = ($146>>>0)>($149>>>0);
      if ($150) {
       break;
      }
      $151 = (($12) + ($147<<2)|0);
      $152 = HEAP32[$151>>2]|0;
      $153 = (($singleGroups) + ($144<<2)|0);
      $154 = HEAP32[$153>>2]|0;
      $155 = ($152|0)==($154|0);
      if (!($155)) {
       $156 = (($10) + (($147*24)|0)|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = ((($singleBounds) + (($144*24)|0)|0) + 12|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = ($157>>>0)>($159>>>0);
       if (!($160)) {
        $161 = ((($10) + (($147*24)|0)|0) + 4|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = ((($singleBounds) + (($144*24)|0)|0) + 16|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = ($162>>>0)>($164>>>0);
        if (!($165)) {
         $166 = ((($singleBounds) + (($144*24)|0)|0) + 4|0);
         $167 = HEAP32[$166>>2]|0;
         $168 = ((($10) + (($147*24)|0)|0) + 16|0);
         $169 = HEAP32[$168>>2]|0;
         $170 = ($167>>>0)>($169>>>0);
         if (!($170)) {
          $171 = ((($10) + (($147*24)|0)|0) + 8|0);
          $172 = HEAP32[$171>>2]|0;
          $173 = ((($singleBounds) + (($144*24)|0)|0) + 20|0);
          $174 = HEAP32[$173>>2]|0;
          $175 = ($172>>>0)>($174>>>0);
          if (!($175)) {
           $176 = ((($singleBounds) + (($144*24)|0)|0) + 8|0);
           $177 = HEAP32[$176>>2]|0;
           $178 = ((($10) + (($147*24)|0)|0) + 20|0);
           $179 = HEAP32[$178>>2]|0;
           $phitmp$i = ($177>>>0)>($179>>>0);
           if (!($phitmp$i)) {
            $180 = Math_imul($142, $8)|0;
            $181 = (($180) + ($126))|0;
            $182 = $181 & 31;
            $183 = ((($this) + ($182<<2)|0) + 384|0);
            $184 = HEAP32[$183>>2]|0;
            $185 = $181 >>> 5;
            $186 = HEAP32[$4>>2]|0;
            $187 = (($186) + ($185<<2)|0);
            $188 = HEAP32[$187>>2]|0;
            $189 = $188 | $184;
            HEAP32[$187>>2] = $189;
            $190 = HEAP32[$overlapBitmap>>2]|0;
            $191 = (($190) + ($185<<2)|0);
            $192 = HEAP32[$191>>2]|0;
            $193 = HEAP32[$183>>2]|0;
            $194 = $193 & $192;
            $195 = ($194|0)==(0);
            if ($195) {
             $196 = HEAP32[$28>>2]|0;
             $197 = (($196) + ($147<<2)|0);
             $198 = HEAP32[$197>>2]|0;
             $199 = HEAP32[$29>>2]|0;
             $200 = (($199) + ($singleId<<2)|0);
             $201 = HEAP32[$200>>2]|0;
             $202 = HEAP32[$30>>2]|0;
             $203 = HEAP32[$31>>2]|0;
             $204 = ($202|0)==($203|0);
             if ($204) {
              $205 = ($202|0)==(0);
              $206 = $202 << 1;
              $$$i13 = $205 ? 32 : $206;
              $207 = HEAP32[$32>>2]|0;
              $208 = $$$i13 << 3;
              $209 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$208,481512,76)|0);
              $210 = ($207|0)==(0|0);
              if (!($210)) {
               $211 = $202 << 3;
               _memcpy(($209|0),($207|0),($211|0))|0;
              }
              $212 = (($209) + ($202<<3)|0);
              $213 = (($$$i13) - ($202))|0;
              $214 = $213 << 3;
              _memset(($212|0),0,($214|0))|0;
              __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$207);
              HEAP32[$32>>2] = $209;
              HEAP32[$31>>2] = $$$i13;
              $$pre$i15 = HEAP32[$30>>2]|0;
              $216 = $$pre$i15;$218 = $209;
             } else {
              $$pre1$i11 = HEAP32[$32>>2]|0;
              $216 = $202;$218 = $$pre1$i11;
             }
             $215 = (($216) + 1)|0;
             HEAP32[$30>>2] = $215;
             $217 = (($218) + ($216<<3)|0);
             HEAP32[$217>>2] = $198;
             $219 = ((($218) + ($216<<3)|0) + 4|0);
             HEAP32[$219>>2] = $201;
            }
           }
          }
         }
        }
       }
      }
      $220 = ($141>>>0)<(((481504 + 4|0))>>>0);
      if ($220) {
       $RunningAddress2_0$047 = $141;
      } else {
       break;
      }
     }
     $123 = ($124>>>0)<($26>>>0);
     $or$cond5 = $125 & $123;
     if ($or$cond5) {
      $RunningAddress0$049 = $RunningAddress0$1$lcssa;$Sorted1$050 = $124;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 $221 = (($overlapBitmap) + 4|0);
 $222 = HEAP32[$221>>2]|0;
 $223 = $222 & 2147483647;
 $224 = ($223|0)==(0);
 L62: do {
  if ($224) {
   label = 55;
  } else {
   $$pre$i$i$i = HEAP32[$overlapBitmap>>2]|0;
   $226 = 0;
   while(1) {
    $225 = (($$pre$i$i$i) + ($226<<2)|0);
    $227 = HEAP32[$225>>2]|0;
    $228 = ($227|0)==(0);
    if (!($228)) {
     break;
    }
    $229 = (($226) + 1)|0;
    $230 = ($229>>>0)<($223>>>0);
    if ($230) {
     $226 = $229;
    } else {
     label = 55;
     break L62;
    }
   }
   $231 = $226 << 5;
   $232 = (0 - ($227))|0;
   $233 = $227 & $232;
   $234 = Math_imul($233, 125613361)|0;
   $235 = $234 >>> 27;
   $236 = (412480 + ($235<<2)|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = $237 | $231;
   $239 = (($227) + -1)|0;
   $240 = $239 & $227;
   $241 = ($240|0)==(0);
   L68: do {
    if ($241) {
     $243 = $226;
     while(1) {
      $242 = (($243) + 1)|0;
      $244 = ($242>>>0)<($223>>>0);
      if (!($244)) {
       $$ph30 = $242;$$ph31 = 0;
       break L68;
      }
      $245 = (($$pre$i$i$i) + ($242<<2)|0);
      $246 = HEAP32[$245>>2]|0;
      $247 = ($246|0)==(0);
      if ($247) {
       $243 = $242;
      } else {
       $$ph30 = $242;$$ph31 = $246;
       break;
      }
     }
    } else {
     $$ph30 = $226;$$ph31 = $240;
    }
   } while(0);
   $248 = ($238|0)==(-1);
   if ($248) {
    label = 55;
   } else {
    $249 = (($this) + 304|0);
    $250 = (($this) + 16|0);
    $251 = (($this) + 49848|0);
    $252 = (($this) + 49852|0);
    $253 = (($this) + 49844|0);
    $$ph3260 = $$ph30;$$ph3361 = $$ph31;$index$0$ph3462 = $238;
    L74: while(1) {
     $256 = $$ph3260 << 5;
     $298 = $$ph3361;$index$037 = $index$0$ph3462;
     while(1) {
      $257 = $index$037 >>> 5;
      $258 = HEAP32[$4>>2]|0;
      $259 = (($258) + ($257<<2)|0);
      $260 = HEAP32[$259>>2]|0;
      $261 = $index$037 & 31;
      $262 = ((($this) + ($261<<2)|0) + 384|0);
      $263 = HEAP32[$262>>2]|0;
      $264 = $263 & $260;
      $265 = ($264|0)==(0);
      if ($265) {
       $266 = (($index$037>>>0) % ($8>>>0))&-1;
       $267 = (($15) + ($266<<2)|0);
       $268 = HEAP32[$267>>2]|0;
       $269 = HEAP32[$11>>2]|0;
       $270 = (($269) + ($268<<2)|0);
       $271 = HEAP32[$270>>2]|0;
       $272 = ($271|0)==(1073741823);
       if (!($272)) {
        $273 = HEAP32[$249>>2]|0;
        $274 = (($273) + ($268<<2)|0);
        $275 = HEAP32[$274>>2]|0;
        $276 = HEAP32[$250>>2]|0;
        $277 = (($276) + ($singleId<<2)|0);
        $278 = HEAP32[$277>>2]|0;
        $279 = HEAP32[$251>>2]|0;
        $280 = HEAP32[$252>>2]|0;
        $281 = ($279|0)==($280|0);
        if ($281) {
         $282 = ($279|0)==(0);
         $283 = $279 << 1;
         $$$i = $282 ? 32 : $283;
         $284 = HEAP32[$253>>2]|0;
         $285 = $$$i << 3;
         $286 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$285,481512,76)|0);
         $287 = ($284|0)==(0|0);
         if (!($287)) {
          $288 = $279 << 3;
          _memcpy(($286|0),($284|0),($288|0))|0;
         }
         $289 = (($286) + ($279<<3)|0);
         $290 = (($$$i) - ($279))|0;
         $291 = $290 << 3;
         _memset(($289|0),0,($291|0))|0;
         __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$284);
         HEAP32[$253>>2] = $286;
         HEAP32[$252>>2] = $$$i;
         $$pre$i = HEAP32[$251>>2]|0;
         $293 = $$pre$i;$295 = $286;
        } else {
         $$pre1$i = HEAP32[$253>>2]|0;
         $293 = $279;$295 = $$pre1$i;
        }
        $292 = (($293) + 1)|0;
        HEAP32[$251>>2] = $292;
        $294 = (($295) + ($293<<3)|0);
        HEAP32[$294>>2] = $275;
        $296 = ((($295) + ($293<<3)|0) + 4|0);
        HEAP32[$296>>2] = $278;
       }
      }
      $297 = ($298|0)==(0);
      if ($297) {
       break L74;
      }
      $300 = (0 - ($298))|0;
      $301 = $298 & $300;
      $302 = Math_imul($301, 125613361)|0;
      $303 = $302 >>> 27;
      $304 = (412480 + ($303<<2)|0);
      $305 = HEAP32[$304>>2]|0;
      $255 = $305 | $256;
      $306 = (($298) + -1)|0;
      $307 = $306 & $298;
      $308 = HEAP32[$221>>2]|0;
      $309 = $308 & 2147483647;
      $310 = ($307|0)==(0);
      if ($310) {
       $312 = $$ph3260;
       break;
      }
      $299 = ($255|0)==(-1);
      if ($299) {
       break L74;
      } else {
       $298 = $307;$index$037 = $255;
      }
     }
     while(1) {
      $311 = (($312) + 1)|0;
      $313 = ($311>>>0)<($309>>>0);
      if (!($313)) {
       $$ph = 0;
       break;
      }
      $314 = HEAP32[$overlapBitmap>>2]|0;
      $315 = (($314) + ($311<<2)|0);
      $316 = HEAP32[$315>>2]|0;
      $317 = ($316|0)==(0);
      if ($317) {
       $312 = $311;
      } else {
       $$ph = $316;
       break;
      }
     }
     $254 = ($255|0)==(-1);
     if ($254) {
      $$pre$phiZ2D = $overlapBitmap;$321 = $308;
      break L62;
     } else {
      $$ph3260 = $311;$$ph3361 = $$ph;$index$0$ph3462 = $255;
     }
    }
    $$pre = HEAP32[$221>>2]|0;
    $$pre$phiZ2D = $overlapBitmap;$321 = $$pre;
   }
  }
 } while(0);
 if ((label|0) == 55) {
  $$pre$phiZ2D = $overlapBitmap;$321 = $222;
 }
 $318 = HEAP32[$$pre$phiZ2D>>2]|0;
 $319 = HEAP32[$4>>2]|0;
 $320 = $321 << 2;
 _memcpy(($318|0),($319|0),($320|0))|0;
 $322 = HEAP32[$4>>2]|0;
 $323 = ($322|0)==(0|0);
 $324 = ($322|0)==($newBitmap|0);
 $or$cond$i$i$i = $323 | $324;
 if ($or$cond$i$i$i) {
  STACKTOP = sp;return;
 }
 $325 = HEAP32[$3>>2]|0;
 $326 = ($325|0)==(0|0);
 if ($326) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$322);
  STACKTOP = sp;return;
 }
 $327 = (($325) + 16|0);
 $328 = HEAP32[$327>>2]|0;
 $329 = ($328>>>0)>($322>>>0);
 if (!($329)) {
  $330 = (($325) + 20|0);
  $331 = HEAP32[$330>>2]|0;
  $332 = (($328) + ($331)|0);
  $333 = ($332>>>0)>($322>>>0);
  if ($333) {
   $334 = HEAP32[$325>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($334);
   $335 = (($325) + 8|0);
   $336 = HEAP32[$335>>2]|0;
   $337 = (($325) + 4|0);
   $338 = HEAP32[$337>>2]|0;
   $i$0$in$i = $336;
   while(1) {
    $i$0$i = (($i$0$in$i) + -1)|0;
    $339 = (($338) + ($i$0$i<<2)|0);
    $340 = HEAP32[$339>>2]|0;
    $341 = ($340>>>0)<($322>>>0);
    if ($341) {
     $i$0$in$i = $i$0$i;
    } else {
     break;
    }
   }
   $342 = ($i$0$in$i>>>0)<($336>>>0);
   if ($342) {
    $346 = $i$0$in$i;$it$02$i$i = $339;
    while(1) {
     $343 = ($it$02$i$i|0)==(0|0);
     if (!($343)) {
      $344 = HEAP32[$337>>2]|0;
      $345 = (($344) + ($346<<2)|0);
      $347 = HEAP32[$345>>2]|0;
      HEAP32[$it$02$i$i>>2] = $347;
     }
     $348 = (($it$02$i$i) + 4|0);
     $349 = (($346) + 1)|0;
     $exitcond$i = ($349|0)==($336|0);
     if ($exitcond$i) {
      break;
     } else {
      $346 = $349;$it$02$i$i = $348;
     }
    }
   }
   $350 = (($336) + -1)|0;
   HEAP32[$335>>2] = $350;
   $351 = HEAP32[$325>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($351);
   STACKTOP = sp;return;
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$322);
 STACKTOP = sp;return;
}
function __ZNK5physx14PxsAABBManager13promoteBitmapEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjjjj($this,$bitmap,$nbX,$nbY,$newXIndex,$newYIndex) {
 $this = $this|0;
 $bitmap = $bitmap|0;
 $nbX = $nbX|0;
 $nbY = $nbY|0;
 $newXIndex = $newXIndex|0;
 $newYIndex = $newYIndex|0;
 var $$$i$i$i = 0, $$0 = 0, $$dstIndex$0$us = 0, $$dstIndex$2$us = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $dstIndex$06$us = 0, $dstIndex$22$us = 0, $exitcond = 0, $exitcond11 = 0, $i$03$us = 0, $j$07$us = 0, $phitmp = 0, $srcIndex$05$us = 0;
 var $srcIndex$11$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($bitmap|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__Z15PxGetFoundationv()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $$$i$i$i = $10 ? 481896 : 481792;
 $11 = (FUNCTION_TABLE_iiiiii[$5 & 255]($2,12,$$$i$i$i,481296,2633)|0);
 HEAP32[$11>>2] = 0;
 $12 = (($11) + 4|0);
 HEAP32[$12>>2] = 0;
 $13 = ($newXIndex|0)!=(-1);
 $14 = $13&1;
 $15 = (($14) + ($nbX))|0;
 $16 = ($newYIndex|0)!=(-1);
 $17 = $16&1;
 $18 = (($17) + ($nbY))|0;
 $19 = Math_imul($18, $15)|0;
 $20 = $19 & 127;
 $21 = ($20|0)==(0);
 if ($21) {
  $25 = $19;
 } else {
  $22 = (($19) + 128)|0;
  $23 = $22 & -128;
  $25 = $23;
 }
 $24 = (($25) + 31)|0;
 $26 = $24 >>> 5;
 $27 = ($26|0)==(0);
 if ($27) {
  $31 = 0;$32 = 0;
 } else {
  $28 = (($11) + 8|0);
  HEAP32[$12>>2] = $26;
  $29 = $26 << 2;
  $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($28,$29,481824,362)|0);
  HEAP32[$11>>2] = $30;
  $$pre$i = HEAP32[$12>>2]|0;
  $phitmp = $$pre$i << 2;
  $31 = $30;$32 = $phitmp;
 }
 _memset(($31|0),0,($32|0))|0;
 $33 = ($nbY|0)==(0);
 if (!($33)) {
  $34 = ($nbX|0)==(0);
  if (!($34)) {
   $dstIndex$06$us = 0;$j$07$us = 0;$srcIndex$05$us = 0;
   while(1) {
    $59 = ($j$07$us|0)==($newYIndex|0);
    $60 = $59 ? $15 : 0;
    $$dstIndex$0$us = (($60) + ($dstIndex$06$us))|0;
    $42 = HEAP32[$bitmap>>2]|0;
    $dstIndex$22$us = $$dstIndex$0$us;$i$03$us = 0;$srcIndex$11$us = $srcIndex$05$us;
    while(1) {
     $37 = ($i$03$us|0)==($newXIndex|0);
     $38 = $37&1;
     $$dstIndex$2$us = (($38) + ($dstIndex$22$us))|0;
     $39 = (($srcIndex$11$us) + 1)|0;
     $40 = $srcIndex$11$us >>> 5;
     $41 = (($42) + ($40<<2)|0);
     $43 = HEAP32[$41>>2]|0;
     $44 = $srcIndex$11$us & 31;
     $45 = ((($this) + ($44<<2)|0) + 384|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = $46 & $43;
     $48 = ($47|0)==(0);
     if (!($48)) {
      $49 = $$dstIndex$2$us & 31;
      $50 = ((($this) + ($49<<2)|0) + 384|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = $$dstIndex$2$us >>> 5;
      $53 = HEAP32[$11>>2]|0;
      $54 = (($53) + ($52<<2)|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = $55 | $51;
      HEAP32[$54>>2] = $56;
     }
     $57 = (($$dstIndex$2$us) + 1)|0;
     $58 = (($i$03$us) + 1)|0;
     $exitcond = ($58|0)==($nbX|0);
     if ($exitcond) {
      break;
     } else {
      $dstIndex$22$us = $57;$i$03$us = $58;$srcIndex$11$us = $39;
     }
    }
    $35 = (($srcIndex$05$us) + ($nbX))|0;
    $36 = (($j$07$us) + 1)|0;
    $exitcond11 = ($36|0)==($nbY|0);
    if ($exitcond11) {
     break;
    } else {
     $dstIndex$06$us = $57;$j$07$us = $36;$srcIndex$05$us = $35;
    }
   }
  }
 }
 $61 = HEAP32[$bitmap>>2]|0;
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  $63 = (($bitmap) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ($64|0)>(-1);
  if ($65) {
   $66 = (($bitmap) + 8|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($66,$61);
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$bitmap);
 $$0 = $11;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx14PxsAABBManager11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i12 = 0, $$0$i$i$i$i25 = 0, $$0$i$i$i19 = 0, $$0$i$i$i6 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i11 = 0, $$0$i$i1$i$i24 = 0, $$0$i$i2$i$i = 0, $$0$i$i2$i$i10 = 0, $$0$i$i2$i$i23 = 0, $$0$i$i3$i$i = 0, $$0$i$i3$i$i22 = 0, $$0$i$i3$i$i9 = 0, $$0$i$i4$i$i = 0, $$0$i$i4$i$i21 = 0, $$0$i$i4$i$i8 = 0, $$0$i$i5$i$i = 0, $$0$i$i5$i$i20 = 0;
 var $$0$i$i5$i$i7 = 0, $$0$i1$i$i = 0, $$0$i1$i$i18 = 0, $$0$i1$i$i5 = 0, $$0$i2$i$i = 0, $$0$i2$i$i17 = 0, $$0$i2$i$i4 = 0, $$0$i3$i$i = 0, $$0$i3$i$i16 = 0, $$0$i3$i$i3 = 0, $$0$i4$i$i = 0, $$0$i4$i$i15 = 0, $$0$i4$i$i2 = 0, $$0$i5$i$i = 0, $$0$i5$i$i1 = 0, $$0$i5$i$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0);
 var $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0);
 var $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0;
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $elem$0 = 0, $elem$032 = 0, $elem$033 = 0, $elem2$0 = 0, $elem2$026 = 0, $elem2$027 = 0, $exitcond = 0, $exitcond40 = 0, $i$035 = 0, $i1$028 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 196|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 180|0);
  $4 = (($this) + 12|0);
  $5 = (($shift) + 4|0);
  $6 = (($shift) + 8|0);
  $7 = (($this) + 96|0);
  $8 = (($this) + 68|0);
  $9 = (($this) + 300|0);
  $10 = (($this) + 316|0);
  $i$035 = 0;
  while(1) {
   $11 = HEAP32[$3>>2]|0;
   $12 = ((($11) + (($i$035*1048)|0)|0) + 1025|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if (!($14)) {
    $15 = ((($11) + (($i$035*1048)|0)|0) + 1028|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$4>>2]|0;
    $18 = (($17) + (($16*24)|0)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ((($17) + (($16*24)|0)|0) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($17) + (($16*24)|0)|0) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ((($17) + (($16*24)|0)|0) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($17) + (($16*24)|0)|0) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($17) + (($16*24)|0)|0) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($19|0)<(0);
    $31 = $19 & 2147483647;
    $32 = $19 ^ -1;
    $$0$i5$i$i14 = $30 ? $31 : $32;
    $33 = ($21|0)<(0);
    $34 = $21 & 2147483647;
    $35 = $21 ^ -1;
    $$0$i4$i$i15 = $33 ? $34 : $35;
    $36 = ($23|0)<(0);
    $37 = $23 & 2147483647;
    $38 = $23 ^ -1;
    $$0$i3$i$i16 = $36 ? $37 : $38;
    $39 = ($25|0)<(0);
    $40 = $25 & 2147483647;
    $41 = $25 ^ -1;
    $$0$i2$i$i17 = $39 ? $40 : $41;
    $42 = ($27|0)<(0);
    $43 = $27 & 2147483647;
    $44 = $27 ^ -1;
    $$0$i1$i$i18 = $42 ? $43 : $44;
    $45 = ($29|0)<(0);
    $46 = $29 & 2147483647;
    $47 = $29 ^ -1;
    $$0$i$i$i19 = $45 ? $46 : $47;
    $48 = Math_fround(HEAPF32[$shift>>2]);
    $49 = (HEAP32[tempDoublePtr>>2]=$$0$i5$i$i14,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $50 = Math_fround($49 - $48);
    $51 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
    $52 = Math_fround(HEAPF32[$5>>2]);
    $53 = (HEAP32[tempDoublePtr>>2]=$$0$i4$i$i15,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $54 = Math_fround($53 - $52);
    $55 = (HEAPF32[tempDoublePtr>>2]=$54,HEAP32[tempDoublePtr>>2]|0);
    $56 = Math_fround(HEAPF32[$6>>2]);
    $57 = (HEAP32[tempDoublePtr>>2]=$$0$i3$i$i16,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $58 = Math_fround($57 - $56);
    $59 = (HEAPF32[tempDoublePtr>>2]=$58,HEAP32[tempDoublePtr>>2]|0);
    $60 = (HEAP32[tempDoublePtr>>2]=$$0$i2$i$i17,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $61 = Math_fround($60 - $48);
    $62 = (HEAPF32[tempDoublePtr>>2]=$61,HEAP32[tempDoublePtr>>2]|0);
    $63 = (HEAP32[tempDoublePtr>>2]=$$0$i1$i$i18,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $64 = Math_fround($63 - $52);
    $65 = (HEAPF32[tempDoublePtr>>2]=$64,HEAP32[tempDoublePtr>>2]|0);
    $66 = (HEAP32[tempDoublePtr>>2]=$$0$i$i$i19,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $67 = Math_fround($66 - $56);
    $68 = (HEAPF32[tempDoublePtr>>2]=$67,HEAP32[tempDoublePtr>>2]|0);
    $69 = ($51|0)<(0);
    $70 = $51 ^ -1;
    $71 = $51 | -2147483648;
    $$0$i$i5$i$i20 = $69 ? $70 : $71;
    $72 = (($$0$i$i5$i$i20) + -16)|0;
    $73 = $72 & -16;
    $74 = ($55|0)<(0);
    $75 = $55 ^ -1;
    $76 = $55 | -2147483648;
    $$0$i$i4$i$i21 = $74 ? $75 : $76;
    $77 = (($$0$i$i4$i$i21) + -16)|0;
    $78 = $77 & -16;
    $79 = ($59|0)<(0);
    $80 = $59 ^ -1;
    $81 = $59 | -2147483648;
    $$0$i$i3$i$i22 = $79 ? $80 : $81;
    $82 = (($$0$i$i3$i$i22) + -16)|0;
    $83 = $82 & -16;
    $84 = ($62|0)<(0);
    $85 = $62 ^ -1;
    $86 = $62 | -2147483648;
    $$0$i$i2$i$i23 = $84 ? $85 : $86;
    $87 = (($$0$i$i2$i$i23) + 16)|0;
    $88 = $87 & -16;
    $89 = $88 | 1;
    $90 = ($65|0)<(0);
    $91 = $65 ^ -1;
    $92 = $65 | -2147483648;
    $$0$i$i1$i$i24 = $90 ? $91 : $92;
    $93 = (($$0$i$i1$i$i24) + 16)|0;
    $94 = $93 & -16;
    $95 = $94 | 1;
    $96 = ($68|0)<(0);
    $97 = $68 ^ -1;
    $98 = $68 | -2147483648;
    $$0$i$i$i$i25 = $96 ? $97 : $98;
    $99 = (($$0$i$i$i$i25) + 16)|0;
    $100 = $99 & -16;
    $101 = $100 | 1;
    HEAP32[$18>>2] = $73;
    HEAP32[$20>>2] = $78;
    HEAP32[$22>>2] = $83;
    HEAP32[$24>>2] = $89;
    HEAP32[$26>>2] = $95;
    HEAP32[$28>>2] = $101;
    $102 = $16 >>> 5;
    $103 = HEAP32[$7>>2]|0;
    $104 = (($103) + ($102<<2)|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = $16 & 31;
    $107 = 1 << $106;
    $108 = $105 & $107;
    $109 = ($108|0)==(0);
    if ($109) {
     $110 = HEAP32[$8>>2]|0;
     $111 = (($110) + ($102<<2)|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = $112 & $107;
     $114 = ($113|0)==(0);
     if ($114) {
      $115 = $112 | $107;
      HEAP32[$111>>2] = $115;
     }
    }
    $116 = ((($11) + (($i$035*1048)|0)|0) + 1032|0);
    $elem$032 = HEAP32[$116>>2]|0;
    $117 = ($elem$032|0)==(1073741823);
    if (!($117)) {
     $elem$033 = $elem$032;
     while(1) {
      $118 = HEAP32[$9>>2]|0;
      $119 = (($118) + (($elem$033*24)|0)|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = ((($118) + (($elem$033*24)|0)|0) + 4|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = ((($118) + (($elem$033*24)|0)|0) + 8|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = ((($118) + (($elem$033*24)|0)|0) + 12|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = ((($118) + (($elem$033*24)|0)|0) + 16|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = ((($118) + (($elem$033*24)|0)|0) + 20|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = ($120|0)<(0);
      $132 = $120 & 2147483647;
      $133 = $120 ^ -1;
      $$0$i5$i$i1 = $131 ? $132 : $133;
      $134 = ($122|0)<(0);
      $135 = $122 & 2147483647;
      $136 = $122 ^ -1;
      $$0$i4$i$i2 = $134 ? $135 : $136;
      $137 = ($124|0)<(0);
      $138 = $124 & 2147483647;
      $139 = $124 ^ -1;
      $$0$i3$i$i3 = $137 ? $138 : $139;
      $140 = ($126|0)<(0);
      $141 = $126 & 2147483647;
      $142 = $126 ^ -1;
      $$0$i2$i$i4 = $140 ? $141 : $142;
      $143 = ($128|0)<(0);
      $144 = $128 & 2147483647;
      $145 = $128 ^ -1;
      $$0$i1$i$i5 = $143 ? $144 : $145;
      $146 = ($130|0)<(0);
      $147 = $130 & 2147483647;
      $148 = $130 ^ -1;
      $$0$i$i$i6 = $146 ? $147 : $148;
      $149 = Math_fround(HEAPF32[$shift>>2]);
      $150 = (HEAP32[tempDoublePtr>>2]=$$0$i5$i$i1,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $151 = Math_fround($150 - $149);
      $152 = (HEAPF32[tempDoublePtr>>2]=$151,HEAP32[tempDoublePtr>>2]|0);
      $153 = Math_fround(HEAPF32[$5>>2]);
      $154 = (HEAP32[tempDoublePtr>>2]=$$0$i4$i$i2,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $155 = Math_fround($154 - $153);
      $156 = (HEAPF32[tempDoublePtr>>2]=$155,HEAP32[tempDoublePtr>>2]|0);
      $157 = Math_fround(HEAPF32[$6>>2]);
      $158 = (HEAP32[tempDoublePtr>>2]=$$0$i3$i$i3,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $159 = Math_fround($158 - $157);
      $160 = (HEAPF32[tempDoublePtr>>2]=$159,HEAP32[tempDoublePtr>>2]|0);
      $161 = (HEAP32[tempDoublePtr>>2]=$$0$i2$i$i4,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $162 = Math_fround($161 - $149);
      $163 = (HEAPF32[tempDoublePtr>>2]=$162,HEAP32[tempDoublePtr>>2]|0);
      $164 = (HEAP32[tempDoublePtr>>2]=$$0$i1$i$i5,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $165 = Math_fround($164 - $153);
      $166 = (HEAPF32[tempDoublePtr>>2]=$165,HEAP32[tempDoublePtr>>2]|0);
      $167 = (HEAP32[tempDoublePtr>>2]=$$0$i$i$i6,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $168 = Math_fround($167 - $157);
      $169 = (HEAPF32[tempDoublePtr>>2]=$168,HEAP32[tempDoublePtr>>2]|0);
      $170 = ($152|0)<(0);
      $171 = $152 ^ -1;
      $172 = $152 | -2147483648;
      $$0$i$i5$i$i7 = $170 ? $171 : $172;
      $173 = (($$0$i$i5$i$i7) + -16)|0;
      $174 = $173 & -16;
      $175 = ($156|0)<(0);
      $176 = $156 ^ -1;
      $177 = $156 | -2147483648;
      $$0$i$i4$i$i8 = $175 ? $176 : $177;
      $178 = (($$0$i$i4$i$i8) + -16)|0;
      $179 = $178 & -16;
      $180 = ($160|0)<(0);
      $181 = $160 ^ -1;
      $182 = $160 | -2147483648;
      $$0$i$i3$i$i9 = $180 ? $181 : $182;
      $183 = (($$0$i$i3$i$i9) + -16)|0;
      $184 = $183 & -16;
      $185 = ($163|0)<(0);
      $186 = $163 ^ -1;
      $187 = $163 | -2147483648;
      $$0$i$i2$i$i10 = $185 ? $186 : $187;
      $188 = (($$0$i$i2$i$i10) + 16)|0;
      $189 = $188 & -16;
      $190 = $189 | 1;
      $191 = ($166|0)<(0);
      $192 = $166 ^ -1;
      $193 = $166 | -2147483648;
      $$0$i$i1$i$i11 = $191 ? $192 : $193;
      $194 = (($$0$i$i1$i$i11) + 16)|0;
      $195 = $194 & -16;
      $196 = $195 | 1;
      $197 = ($169|0)<(0);
      $198 = $169 ^ -1;
      $199 = $169 | -2147483648;
      $$0$i$i$i$i12 = $197 ? $198 : $199;
      $200 = (($$0$i$i$i$i12) + 16)|0;
      $201 = $200 & -16;
      $202 = $201 | 1;
      HEAP32[$119>>2] = $174;
      HEAP32[$121>>2] = $179;
      HEAP32[$123>>2] = $184;
      HEAP32[$125>>2] = $190;
      HEAP32[$127>>2] = $196;
      HEAP32[$129>>2] = $202;
      $203 = HEAP32[$10>>2]|0;
      $204 = (($203) + ($elem$033<<2)|0);
      $elem$0 = HEAP32[$204>>2]|0;
      $205 = ($elem$0|0)==(1073741823);
      if ($205) {
       break;
      } else {
       $elem$033 = $elem$0;
      }
     }
    }
   }
   $206 = (($i$035) + 1)|0;
   $exitcond40 = ($206|0)==($1|0);
   if ($exitcond40) {
    break;
   } else {
    $i$035 = $206;
   }
  }
 }
 $207 = (($this) + 164|0);
 $208 = HEAP32[$207>>2]|0;
 $209 = ($208|0)==(0);
 if ($209) {
  $323 = (($this) + 49828|0);
  $324 = HEAP32[$323>>2]|0;
  $325 = HEAP32[$324>>2]|0;
  $326 = (($325) + 68|0);
  $327 = HEAP32[$326>>2]|0;
  FUNCTION_TABLE_vii[$327 & 4095]($324,$shift);
  STACKTOP = sp;return;
 }
 $210 = (($this) + 156|0);
 $211 = (($this) + 12|0);
 $212 = (($shift) + 4|0);
 $213 = (($shift) + 8|0);
 $214 = (($this) + 96|0);
 $215 = (($this) + 68|0);
 $216 = (($this) + 28|0);
 $i1$028 = 0;
 while(1) {
  $217 = HEAP32[$210>>2]|0;
  $218 = (($217) + ($i1$028<<2)|0);
  $elem2$026 = HEAP32[$218>>2]|0;
  $219 = ($elem2$026|0)==(1073741823);
  if (!($219)) {
   $elem2$027 = $elem2$026;
   while(1) {
    $220 = HEAP32[$211>>2]|0;
    $221 = (($220) + (($elem2$027*24)|0)|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = ((($220) + (($elem2$027*24)|0)|0) + 4|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = ((($220) + (($elem2$027*24)|0)|0) + 8|0);
    $226 = HEAP32[$225>>2]|0;
    $227 = ((($220) + (($elem2$027*24)|0)|0) + 12|0);
    $228 = HEAP32[$227>>2]|0;
    $229 = ((($220) + (($elem2$027*24)|0)|0) + 16|0);
    $230 = HEAP32[$229>>2]|0;
    $231 = ((($220) + (($elem2$027*24)|0)|0) + 20|0);
    $232 = HEAP32[$231>>2]|0;
    $233 = ($222|0)<(0);
    $234 = $222 & 2147483647;
    $235 = $222 ^ -1;
    $$0$i5$i$i = $233 ? $234 : $235;
    $236 = ($224|0)<(0);
    $237 = $224 & 2147483647;
    $238 = $224 ^ -1;
    $$0$i4$i$i = $236 ? $237 : $238;
    $239 = ($226|0)<(0);
    $240 = $226 & 2147483647;
    $241 = $226 ^ -1;
    $$0$i3$i$i = $239 ? $240 : $241;
    $242 = ($228|0)<(0);
    $243 = $228 & 2147483647;
    $244 = $228 ^ -1;
    $$0$i2$i$i = $242 ? $243 : $244;
    $245 = ($230|0)<(0);
    $246 = $230 & 2147483647;
    $247 = $230 ^ -1;
    $$0$i1$i$i = $245 ? $246 : $247;
    $248 = ($232|0)<(0);
    $249 = $232 & 2147483647;
    $250 = $232 ^ -1;
    $$0$i$i$i = $248 ? $249 : $250;
    $251 = Math_fround(HEAPF32[$shift>>2]);
    $252 = (HEAP32[tempDoublePtr>>2]=$$0$i5$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $253 = Math_fround($252 - $251);
    $254 = (HEAPF32[tempDoublePtr>>2]=$253,HEAP32[tempDoublePtr>>2]|0);
    $255 = Math_fround(HEAPF32[$212>>2]);
    $256 = (HEAP32[tempDoublePtr>>2]=$$0$i4$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $257 = Math_fround($256 - $255);
    $258 = (HEAPF32[tempDoublePtr>>2]=$257,HEAP32[tempDoublePtr>>2]|0);
    $259 = Math_fround(HEAPF32[$213>>2]);
    $260 = (HEAP32[tempDoublePtr>>2]=$$0$i3$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $261 = Math_fround($260 - $259);
    $262 = (HEAPF32[tempDoublePtr>>2]=$261,HEAP32[tempDoublePtr>>2]|0);
    $263 = (HEAP32[tempDoublePtr>>2]=$$0$i2$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $264 = Math_fround($263 - $251);
    $265 = (HEAPF32[tempDoublePtr>>2]=$264,HEAP32[tempDoublePtr>>2]|0);
    $266 = (HEAP32[tempDoublePtr>>2]=$$0$i1$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $267 = Math_fround($266 - $255);
    $268 = (HEAPF32[tempDoublePtr>>2]=$267,HEAP32[tempDoublePtr>>2]|0);
    $269 = (HEAP32[tempDoublePtr>>2]=$$0$i$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $270 = Math_fround($269 - $259);
    $271 = (HEAPF32[tempDoublePtr>>2]=$270,HEAP32[tempDoublePtr>>2]|0);
    $272 = ($254|0)<(0);
    $273 = $254 ^ -1;
    $274 = $254 | -2147483648;
    $$0$i$i5$i$i = $272 ? $273 : $274;
    $275 = (($$0$i$i5$i$i) + -16)|0;
    $276 = $275 & -16;
    $277 = ($258|0)<(0);
    $278 = $258 ^ -1;
    $279 = $258 | -2147483648;
    $$0$i$i4$i$i = $277 ? $278 : $279;
    $280 = (($$0$i$i4$i$i) + -16)|0;
    $281 = $280 & -16;
    $282 = ($262|0)<(0);
    $283 = $262 ^ -1;
    $284 = $262 | -2147483648;
    $$0$i$i3$i$i = $282 ? $283 : $284;
    $285 = (($$0$i$i3$i$i) + -16)|0;
    $286 = $285 & -16;
    $287 = ($265|0)<(0);
    $288 = $265 ^ -1;
    $289 = $265 | -2147483648;
    $$0$i$i2$i$i = $287 ? $288 : $289;
    $290 = (($$0$i$i2$i$i) + 16)|0;
    $291 = $290 & -16;
    $292 = $291 | 1;
    $293 = ($268|0)<(0);
    $294 = $268 ^ -1;
    $295 = $268 | -2147483648;
    $$0$i$i1$i$i = $293 ? $294 : $295;
    $296 = (($$0$i$i1$i$i) + 16)|0;
    $297 = $296 & -16;
    $298 = $297 | 1;
    $299 = ($271|0)<(0);
    $300 = $271 ^ -1;
    $301 = $271 | -2147483648;
    $$0$i$i$i$i = $299 ? $300 : $301;
    $302 = (($$0$i$i$i$i) + 16)|0;
    $303 = $302 & -16;
    $304 = $303 | 1;
    HEAP32[$221>>2] = $276;
    HEAP32[$223>>2] = $281;
    HEAP32[$225>>2] = $286;
    HEAP32[$227>>2] = $292;
    HEAP32[$229>>2] = $298;
    HEAP32[$231>>2] = $304;
    $305 = $elem2$027 >>> 5;
    $306 = HEAP32[$214>>2]|0;
    $307 = (($306) + ($305<<2)|0);
    $308 = HEAP32[$307>>2]|0;
    $309 = $elem2$027 & 31;
    $310 = 1 << $309;
    $311 = $308 & $310;
    $312 = ($311|0)==(0);
    if ($312) {
     $313 = HEAP32[$215>>2]|0;
     $314 = (($313) + ($305<<2)|0);
     $315 = HEAP32[$314>>2]|0;
     $316 = $315 & $310;
     $317 = ($316|0)==(0);
     if ($317) {
      $318 = $315 | $310;
      HEAP32[$314>>2] = $318;
     }
    }
    $319 = HEAP32[$216>>2]|0;
    $320 = (($319) + ($elem2$027<<2)|0);
    $elem2$0 = HEAP32[$320>>2]|0;
    $321 = ($elem2$0|0)==(1073741823);
    if ($321) {
     break;
    } else {
     $elem2$027 = $elem2$0;
    }
   }
  }
  $322 = (($i1$028) + 1)|0;
  $exitcond = ($322|0)==($208|0);
  if ($exitcond) {
   break;
  } else {
   $i1$028 = $322;
  }
 }
 $323 = (($this) + 49828|0);
 $324 = HEAP32[$323>>2]|0;
 $325 = HEAP32[$324>>2]|0;
 $326 = (($325) + 68|0);
 $327 = HEAP32[$326>>2]|0;
 FUNCTION_TABLE_vii[$327 & 4095]($324,$shift);
 STACKTOP = sp;return;
}
function __ZN5physx19PxcScratchAllocator5allocEjb($this,$requestedSize,$fallBackToHeap) {
 $this = $this|0;
 $requestedSize = $requestedSize|0;
 $fallBackToHeap = $fallBackToHeap|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $addr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $addr = sp;
 $0 = sp + 4|0;
 $1 = (($requestedSize) + 15)|0;
 $2 = $1 & -16;
 $3 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($3);
 $4 = (($this) + 4|0);
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 $8 = HEAP32[$4>>2]|0;
 $9 = (($8) + ($7<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $10;
 $14 = $12;
 $15 = (($13) - ($14))|0;
 $16 = ($15|0)<($2|0);
 do {
  if ($16) {
   if ($fallBackToHeap) {
    $26 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$2,481608,99)|0);
    $$0 = $26;
   } else {
    $$0 = 0;
   }
  } else {
   $17 = (0 - ($2))|0;
   $18 = (($10) + ($17)|0);
   HEAP32[$addr>>2] = $18;
   $19 = (($this) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20 & 2147483647;
   $22 = ($21>>>0)>($6>>>0);
   if (!($22)) {
    (__ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($4,$addr)|0);
    $$pre = HEAP32[$addr>>2]|0;
    $$0 = $$pre;
    break;
   }
   $23 = (($8) + ($6<<2)|0);
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    HEAP32[$23>>2] = $18;
   }
   $25 = (($6) + 1)|0;
   HEAP32[$5>>2] = $25;
   $$0 = $18;
  }
 } while(0);
 $27 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($27);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd4sortI10SortedDataNS0_4LessIS2_EENS0_19ReflectionAllocatorIS2_EEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph15 = 0, $$ph15$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0, $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph15 = $5;$$ph16 = 32;$$ph17 = 0;$$ph18 = 0;$$ph19 = $6;
  L2: while(1) {
   $10 = $$ph18;$188 = $$ph17;$9 = $$ph19;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<3)|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($elements) + ($m$01$i<<3)|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = ($15>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<3)|0);
      $22 = (($elements) + ($i$03$i<<3)|0);
      $23 = $21;
      $24 = $23;
      $25 = HEAP32[$24>>2]|0;
      $26 = (($23) + 4)|0;
      $27 = $26;
      $28 = HEAP32[$27>>2]|0;
      $29 = $22;
      $30 = $29;
      $31 = HEAP32[$30>>2]|0;
      $32 = (($29) + 4)|0;
      $33 = $32;
      $34 = HEAP32[$33>>2]|0;
      $35 = $21;
      $36 = $35;
      HEAP32[$36>>2] = $31;
      $37 = (($35) + 4)|0;
      $38 = $37;
      HEAP32[$38>>2] = $34;
      $39 = $22;
      $40 = $39;
      HEAP32[$40>>2] = $25;
      $41 = (($39) + 4)|0;
      $42 = $41;
      HEAP32[$42>>2] = $28;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $243 = ($188|0)==(0);
    if ($243) {
     break L2;
    }
    $244 = (($188) + -1)|0;
    $245 = (($$ph15) + ($244<<2)|0);
    $246 = HEAP32[$245>>2]|0;
    $247 = (($188) + -2)|0;
    $248 = (($$ph15) + ($247<<2)|0);
    $249 = HEAP32[$248>>2]|0;
    $10 = $249;$188 = $247;$9 = $246;
   }
   $43 = (($9) + ($10))|0;
   $44 = (($43|0) / 2)&-1;
   $45 = (($elements) + ($44<<3)|0);
   $46 = (($elements) + ($10<<3)|0);
   $47 = HEAP32[$45>>2]|0;
   $48 = HEAP32[$46>>2]|0;
   $49 = ($47>>>0)<($48>>>0);
   if ($49) {
    $50 = $46;
    $51 = $50;
    $52 = HEAP32[$51>>2]|0;
    $53 = (($50) + 4)|0;
    $54 = $53;
    $55 = HEAP32[$54>>2]|0;
    $56 = $45;
    $57 = $56;
    $58 = HEAP32[$57>>2]|0;
    $59 = (($56) + 4)|0;
    $60 = $59;
    $61 = HEAP32[$60>>2]|0;
    $62 = $46;
    $63 = $62;
    HEAP32[$63>>2] = $58;
    $64 = (($62) + 4)|0;
    $65 = $64;
    HEAP32[$65>>2] = $61;
    $66 = $45;
    $67 = $66;
    HEAP32[$67>>2] = $52;
    $68 = (($66) + 4)|0;
    $69 = $68;
    HEAP32[$69>>2] = $55;
    $$pre$i$i = HEAP32[$46>>2]|0;
    $259 = $52;$73 = $$pre$i$i;
   } else {
    $259 = $47;$73 = $48;
   }
   $70 = (($elements) + ($9<<3)|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71>>>0)<($73>>>0);
   if ($72) {
    $74 = $46;
    $75 = $74;
    $76 = HEAP32[$75>>2]|0;
    $77 = (($74) + 4)|0;
    $78 = $77;
    $79 = HEAP32[$78>>2]|0;
    $80 = $70;
    $81 = $80;
    $82 = HEAP32[$81>>2]|0;
    $83 = (($80) + 4)|0;
    $84 = $83;
    $85 = HEAP32[$84>>2]|0;
    $86 = $46;
    $87 = $86;
    HEAP32[$87>>2] = $82;
    $88 = (($86) + 4)|0;
    $89 = $88;
    HEAP32[$89>>2] = $85;
    $90 = $70;
    $91 = $90;
    HEAP32[$91>>2] = $76;
    $92 = (($90) + 4)|0;
    $93 = $92;
    HEAP32[$93>>2] = $79;
    $$pre1$i$i = HEAP32[$45>>2]|0;
    $95 = $76;$96 = $$pre1$i$i;
   } else {
    $95 = $71;$96 = $259;
   }
   $94 = ($95>>>0)<($96>>>0);
   if ($94) {
    $97 = $45;
    $98 = $97;
    $99 = HEAP32[$98>>2]|0;
    $100 = (($97) + 4)|0;
    $101 = $100;
    $102 = HEAP32[$101>>2]|0;
    $103 = $70;
    $104 = $103;
    $105 = HEAP32[$104>>2]|0;
    $106 = (($103) + 4)|0;
    $107 = $106;
    $108 = HEAP32[$107>>2]|0;
    $109 = $45;
    $110 = $109;
    HEAP32[$110>>2] = $105;
    $111 = (($109) + 4)|0;
    $112 = $111;
    HEAP32[$112>>2] = $108;
    $113 = $70;
    $114 = $113;
    HEAP32[$114>>2] = $99;
    $115 = (($113) + 4)|0;
    $116 = $115;
    HEAP32[$116>>2] = $102;
   }
   $117 = (($9) + -1)|0;
   $118 = (($elements) + ($117<<3)|0);
   $119 = $45;
   $120 = $119;
   $121 = HEAP32[$120>>2]|0;
   $122 = (($119) + 4)|0;
   $123 = $122;
   $124 = HEAP32[$123>>2]|0;
   $125 = $118;
   $126 = $125;
   $127 = HEAP32[$126>>2]|0;
   $128 = (($125) + 4)|0;
   $129 = $128;
   $130 = HEAP32[$129>>2]|0;
   $131 = $45;
   $132 = $131;
   HEAP32[$132>>2] = $127;
   $133 = (($131) + 4)|0;
   $134 = $133;
   HEAP32[$134>>2] = $130;
   $135 = $118;
   $136 = $135;
   HEAP32[$136>>2] = $121;
   $137 = (($135) + 4)|0;
   $138 = $137;
   HEAP32[$138>>2] = $124;
   $143 = $121;$i$0$ph$i = $10;$j$0$ph$i = $117;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $139 = (($i$0$i) + 1)|0;
     $140 = (($elements) + ($139<<3)|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = ($141>>>0)<($143>>>0);
     if ($142) {
      $i$0$i = $139;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $144 = (($j$1$i) + -1)|0;
     $145 = (($elements) + ($144<<3)|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = ($143>>>0)<($146>>>0);
     if ($147) {
      $j$1$i = $144;
     } else {
      break;
     }
    }
    $148 = ($139|0)<($144|0);
    $149 = $140;
    $150 = $149;
    $151 = HEAP32[$150>>2]|0;
    $152 = (($149) + 4)|0;
    $153 = $152;
    $154 = HEAP32[$153>>2]|0;
    if (!($148)) {
     break;
    }
    $155 = $145;
    $156 = $155;
    $157 = HEAP32[$156>>2]|0;
    $158 = (($155) + 4)|0;
    $159 = $158;
    $160 = HEAP32[$159>>2]|0;
    $161 = $140;
    $162 = $161;
    HEAP32[$162>>2] = $157;
    $163 = (($161) + 4)|0;
    $164 = $163;
    HEAP32[$164>>2] = $160;
    $165 = $145;
    $166 = $165;
    HEAP32[$166>>2] = $151;
    $167 = (($165) + 4)|0;
    $168 = $167;
    HEAP32[$168>>2] = $154;
    $$pre$i1 = HEAP32[$118>>2]|0;
    $143 = $$pre$i1;$i$0$ph$i = $139;$j$0$ph$i = $144;
   }
   $169 = $118;
   $170 = $169;
   $171 = HEAP32[$170>>2]|0;
   $172 = (($169) + 4)|0;
   $173 = $172;
   $174 = HEAP32[$173>>2]|0;
   $175 = $140;
   $176 = $175;
   HEAP32[$176>>2] = $171;
   $177 = (($175) + 4)|0;
   $178 = $177;
   HEAP32[$178>>2] = $174;
   $179 = $118;
   $180 = $179;
   HEAP32[$180>>2] = $151;
   $181 = (($179) + 4)|0;
   $182 = $181;
   HEAP32[$182>>2] = $154;
   $183 = (($139) - ($10))|0;
   $184 = (($9) - ($139))|0;
   $185 = ($183|0)<($184|0);
   if ($185) {
    $186 = (($$ph16) + -1)|0;
    $187 = ($188>>>0)<($186>>>0);
    if ($187) {
     $212 = $$ph15;$260 = $$ph;$261 = $$ph16;
    } else {
     $189 = $$ph16 << 1;
     $190 = $$ph16 << 3;
     $191 = ($190|0)==(0);
     if ($191) {
      $203 = 0;
     } else {
      $192 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $193 = HEAP32[$192>>2]|0;
      $194 = (($193) + 8|0);
      $195 = HEAP32[$194>>2]|0;
      $196 = (__Z15PxGetFoundationv()|0);
      $197 = HEAP32[$196>>2]|0;
      $198 = (($197) + 24|0);
      $199 = HEAP32[$198>>2]|0;
      $200 = (FUNCTION_TABLE_ii[$199 & 4095]($196)|0);
      $$$i$i$i4 = $200 ? 482160 : 481792;
      $201 = (FUNCTION_TABLE_iiiiii[$195 & 255]($192,$190,$$$i$i$i4,482072,148)|0);
      $203 = $201;
     }
     $202 = $188 << 2;
     _memcpy(($203|0),($$ph15|0),($202|0))|0;
     $204 = ($$ph<<24>>24)==(0);
     $205 = ($$ph15|0)==(0|0);
     $or$cond = $204 | $205;
     if ($or$cond) {
      $212 = $203;$260 = 1;$261 = $189;
     } else {
      $206 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $207 = HEAP32[$206>>2]|0;
      $208 = (($207) + 12|0);
      $209 = HEAP32[$208>>2]|0;
      FUNCTION_TABLE_vii[$209 & 4095]($206,$$ph15);
      $212 = $203;$260 = 1;$261 = $189;
     }
    }
    $210 = (($188) + 1)|0;
    $211 = (($212) + ($188<<2)|0);
    HEAP32[$211>>2] = $10;
    $213 = (($212) + ($210<<2)|0);
    HEAP32[$213>>2] = $i$0$i;
    $214 = (($i$0$i) + 2)|0;
    $$ph$be = $260;$$ph15$be = $212;$$ph16$be = $261;$$ph18$be = $214;$$ph19$be = $9;
   } else {
    $215 = (($i$0$i) + 2)|0;
    $216 = (($$ph16) + -1)|0;
    $217 = ($188>>>0)<($216>>>0);
    if ($217) {
     $241 = $$ph15;$262 = $$ph;$263 = $$ph16;
    } else {
     $218 = $$ph16 << 1;
     $219 = $$ph16 << 3;
     $220 = ($219|0)==(0);
     if ($220) {
      $232 = 0;
     } else {
      $221 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $222 = HEAP32[$221>>2]|0;
      $223 = (($222) + 8|0);
      $224 = HEAP32[$223>>2]|0;
      $225 = (__Z15PxGetFoundationv()|0);
      $226 = HEAP32[$225>>2]|0;
      $227 = (($226) + 24|0);
      $228 = HEAP32[$227>>2]|0;
      $229 = (FUNCTION_TABLE_ii[$228 & 4095]($225)|0);
      $$$i$i$i = $229 ? 482160 : 481792;
      $230 = (FUNCTION_TABLE_iiiiii[$224 & 255]($221,$219,$$$i$i$i,482072,148)|0);
      $232 = $230;
     }
     $231 = $188 << 2;
     _memcpy(($232|0),($$ph15|0),($231|0))|0;
     $233 = ($$ph<<24>>24)==(0);
     $234 = ($$ph15|0)==(0|0);
     $or$cond8 = $233 | $234;
     if ($or$cond8) {
      $241 = $232;$262 = 1;$263 = $218;
     } else {
      $235 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $236 = HEAP32[$235>>2]|0;
      $237 = (($236) + 12|0);
      $238 = HEAP32[$237>>2]|0;
      FUNCTION_TABLE_vii[$238 & 4095]($235,$$ph15);
      $241 = $232;$262 = 1;$263 = $218;
     }
    }
    $239 = (($188) + 1)|0;
    $240 = (($241) + ($188<<2)|0);
    HEAP32[$240>>2] = $215;
    $242 = (($241) + ($239<<2)|0);
    HEAP32[$242>>2] = $9;
    $$ph$be = $262;$$ph15$be = $241;$$ph16$be = $263;$$ph18$be = $10;$$ph19$be = $i$0$i;
   }
   $$ph17$be = (($188) + 2)|0;
   $$ph = $$ph$be;$$ph15 = $$ph15$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;
  }
  $250 = ($$ph<<24>>24)==(0);
  $251 = ($$ph15|0)==(0|0);
  $or$cond9 = $250 | $251;
  if (!($or$cond9)) {
   $252 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $253 = HEAP32[$252>>2]|0;
   $254 = (($253) + 12|0);
   $255 = HEAP32[$254>>2]|0;
   FUNCTION_TABLE_vii[$255 & 4095]($252,$$ph15);
  }
 }
 $256 = HEAP8[$4>>0]|0;
 $257 = ($256<<24>>24)==(0);
 if ($257) {
  STACKTOP = sp;return;
 }
 $258 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$258);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 482256 : 481792;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,481712,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx21AggregateActorManager6resizeEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $$sum = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $exitcond = 0, $factor = 0, $factor8 = 0, $i$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($newCapacity) + 31)|0;
 $5 = $4 >>> 5;
 $6 = ($newCapacity*24)|0;
 $7 = (($6) + 15)|0;
 $8 = $7 & -16;
 $9 = (($newCapacity) + 15)|0;
 $10 = $9 & -16;
 $11 = $newCapacity << 2;
 $12 = (($11) + 15)|0;
 $13 = $12 & -16;
 $14 = $5 << 3;
 $15 = (($14) + 30)|0;
 $factor = $15 & 2147483616;
 $factor8 = $13 << 1;
 $16 = (($8) + ($10))|0;
 $17 = (($16) + ($factor))|0;
 $18 = (($17) + ($factor8))|0;
 $19 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$18,481512,990)|0);
 $20 = (($this) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $23 = ($3*24)|0;
  _memcpy(($19|0),($21|0),($23|0))|0;
 }
 $24 = (($19) + (($3*24)|0)|0);
 $25 = (($newCapacity) - ($3))|0;
 $26 = ($25*24)|0;
 _memset(($24|0),0,($26|0))|0;
 $27 = (($19) + ($8)|0);
 HEAP32[$20>>2] = $19;
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  _memcpy(($27|0),($29|0),($3|0))|0;
 }
 $$sum = (($3) + ($8))|0;
 $31 = (($19) + ($$sum)|0);
 _memset(($31|0),0,($25|0))|0;
 $32 = (($19) + ($16)|0);
 HEAP32[$28>>2] = $27;
 $33 = (($this) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = $3 << 2;
  _memcpy(($32|0),($34|0),($36|0))|0;
 }
 $37 = (($32) + ($3<<2)|0);
 $38 = $25 << 2;
 _memset(($37|0),0,($38|0))|0;
 $$sum5 = (($16) + ($13))|0;
 $39 = (($19) + ($$sum5)|0);
 HEAP32[$33>>2] = $32;
 $40 = (($this) + 16|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = $3 << 2;
  _memcpy(($39|0),($41|0),($43|0))|0;
 }
 $44 = (($39) + ($3<<2)|0);
 _memset(($44|0),0,($38|0))|0;
 $$sum6 = (($$sum5) + ($13))|0;
 $45 = (($19) + ($$sum6)|0);
 HEAP32[$40>>2] = $39;
 $46 = (($this) + 28|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 & 2147483647;
 $49 = (($this) + 24|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  $52 = $47 << 2;
  _memcpy(($45|0),($50|0),($52|0))|0;
 }
 $53 = (($45) + ($48<<2)|0);
 $54 = (($5) - ($47))|0;
 $55 = $54 << 2;
 _memset(($53|0),0,($55|0))|0;
 $56 = $5 << 2;
 $57 = (($56) + 15)|0;
 $58 = $57 & 1073741808;
 $$sum7 = (($$sum6) + ($58))|0;
 $59 = (($19) + ($$sum7)|0);
 HEAP32[$49>>2] = $45;
 $60 = $5 | -2147483648;
 HEAP32[$46>>2] = $60;
 $61 = (($this) + 40|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = $62 & 2147483647;
 $64 = (($this) + 36|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if (!($66)) {
  $67 = $62 << 2;
  _memcpy(($59|0),($65|0),($67|0))|0;
 }
 $68 = (($59) + ($63<<2)|0);
 $69 = (($5) - ($62))|0;
 $70 = $69 << 2;
 _memset(($68|0),0,($70|0))|0;
 HEAP32[$64>>2] = $59;
 HEAP32[$61>>2] = $60;
 $71 = HEAP32[$this>>2]|0;
 $72 = ($71|0)==(0|0);
 if (!($72)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$71);
 }
 $73 = HEAP32[$20>>2]|0;
 HEAP32[$this>>2] = $73;
 HEAP32[$2>>2] = $newCapacity;
 $74 = (($this) + 48|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($newCapacity) + -1)|0;
 $77 = (($73) + (($76*24)|0)|0);
 HEAP32[$77>>2] = $75;
 $78 = ($3>>>0)<($76>>>0);
 if ($78) {
  $i$09 = $3;
 } else {
  HEAP32[$74>>2] = $3;
  STACKTOP = sp;return;
 }
 while(1) {
  $79 = (($i$09) + 1)|0;
  $80 = (($73) + (($i$09*24)|0)|0);
  HEAP32[$80>>2] = $79;
  $exitcond = ($79|0)==($76|0);
  if ($exitcond) {
   break;
  } else {
   $i$09 = $79;
  }
 }
 HEAP32[$74>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN5physx20AggregateOverlapTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx20AggregateOverlapTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (482472|0);
}
function __ZN5physx20ProcessBPResultsTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx20ProcessBPResultsTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (482496|0);
}
function __ZN5physx10BPWorkTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx10BPWorkTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (482520|0);
}
function __Z18computeSweptBoundsRKN5physx18PxcAABBDataDynamicERNS_9PxBounds3E($aabbData,$destBounds) {
 $aabbData = $aabbData|0;
 $destBounds = $destBounds|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0);
 var $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0);
 var $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = Math_fround(0), $450 = 0, $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = 0;
 var $459 = Math_fround(0), $46 = Math_fround(0), $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = 0, $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = 0, $474 = 0, $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0;
 var $495 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $endExtent = 0, $endOrigin = 0, $endShape2world = 0, $startBounds = 0;
 var $startShape2World = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $endShape2world = sp + 80|0;
 $endOrigin = sp;
 $endExtent = sp + 12|0;
 $startShape2World = sp + 24|0;
 $startBounds = sp + 56|0;
 $0 = HEAP32[$aabbData>>2]|0;
 $1 = (($aabbData) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($aabbData) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($aabbData) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 48|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($4) + 52|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($4) + 56|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($8 * Math_fround(-2.0));
 $14 = Math_fround($10 * Math_fround(-2.0));
 $15 = Math_fround($12 * Math_fround(-2.0));
 $16 = (($4) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $17);
 $19 = Math_fround($18 + Math_fround(-0.5));
 $20 = (($4) + 32|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($13 * $21);
 $23 = (($4) + 36|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($14 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($4) + 40|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($15 * $28);
 $30 = Math_fround($26 + $29);
 $31 = Math_fround($13 * $19);
 $32 = Math_fround($15 * $24);
 $33 = Math_fround($14 * $28);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($17 * $34);
 $36 = Math_fround($31 - $35);
 $37 = Math_fround($21 * $30);
 $38 = Math_fround($37 + $36);
 $39 = Math_fround($14 * $19);
 $40 = Math_fround($13 * $28);
 $41 = Math_fround($15 * $21);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($17 * $42);
 $44 = Math_fround($39 - $43);
 $45 = Math_fround($24 * $30);
 $46 = Math_fround($45 + $44);
 $47 = Math_fround($15 * $19);
 $48 = Math_fround($14 * $21);
 $49 = Math_fround($13 * $24);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($17 * $50);
 $52 = Math_fround($47 - $51);
 $53 = Math_fround($28 * $30);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround(-$21);
 $56 = Math_fround(-$24);
 $57 = Math_fround(-$28);
 $58 = Math_fround($38 * Math_fround(2.0));
 $59 = Math_fround($46 * Math_fround(2.0));
 $60 = Math_fround($54 * Math_fround(2.0));
 $61 = (($4) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * $62);
 $64 = Math_fround($63 + Math_fround(-0.5));
 $65 = Math_fround(HEAPF32[$4>>2]);
 $66 = Math_fround($65 * $58);
 $67 = (($4) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 * $59);
 $70 = Math_fround($66 + $69);
 $71 = (($4) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 * $60);
 $74 = Math_fround($73 + $70);
 $75 = Math_fround($64 * $58);
 $76 = Math_fround($68 * $60);
 $77 = Math_fround($72 * $59);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($62 * $78);
 $80 = Math_fround($75 + $79);
 $81 = Math_fround($65 * $74);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($64 * $59);
 $84 = Math_fround($72 * $58);
 $85 = Math_fround($65 * $60);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($62 * $86);
 $88 = Math_fround($83 + $87);
 $89 = Math_fround($68 * $74);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($64 * $60);
 $92 = Math_fround($65 * $59);
 $93 = Math_fround($68 * $58);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($62 * $94);
 $96 = Math_fround($91 + $95);
 $97 = Math_fround($72 * $74);
 $98 = Math_fround($96 + $97);
 $99 = (($4) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 + $82);
 $102 = (($4) + 20|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($103 + $90);
 $105 = (($4) + 24|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($106 + $98);
 $108 = Math_fround($62 * $55);
 $109 = Math_fround($17 * $65);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($68 * $57);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround($72 * $56);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($62 * $56);
 $116 = Math_fround($17 * $68);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($72 * $55);
 $119 = Math_fround($118 + $117);
 $120 = Math_fround($65 * $57);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($62 * $57);
 $123 = Math_fround($17 * $72);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($65 * $56);
 $126 = Math_fround($125 + $124);
 $127 = Math_fround($68 * $55);
 $128 = Math_fround($126 - $127);
 $129 = Math_fround($17 * $62);
 $130 = Math_fround($65 * $55);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($68 * $56);
 $133 = Math_fround($131 - $132);
 $134 = Math_fround($72 * $57);
 $135 = Math_fround($133 - $134);
 $136 = (($0) + 16|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($137 * Math_fround(2.0));
 $139 = (($0) + 20|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($140 * Math_fround(2.0));
 $142 = (($0) + 24|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = Math_fround($143 * Math_fround(2.0));
 $145 = Math_fround($135 * $135);
 $146 = Math_fround($145 + Math_fround(-0.5));
 $147 = Math_fround($114 * $138);
 $148 = Math_fround($121 * $141);
 $149 = Math_fround($147 + $148);
 $150 = Math_fround($128 * $144);
 $151 = Math_fround($149 + $150);
 $152 = Math_fround($146 * $138);
 $153 = Math_fround($121 * $144);
 $154 = Math_fround($128 * $141);
 $155 = Math_fround($153 - $154);
 $156 = Math_fround($135 * $155);
 $157 = Math_fround($152 + $156);
 $158 = Math_fround($114 * $151);
 $159 = Math_fround($158 + $157);
 $160 = Math_fround($146 * $141);
 $161 = Math_fround($128 * $138);
 $162 = Math_fround($114 * $144);
 $163 = Math_fround($161 - $162);
 $164 = Math_fround($135 * $163);
 $165 = Math_fround($160 + $164);
 $166 = Math_fround($121 * $151);
 $167 = Math_fround($166 + $165);
 $168 = Math_fround($146 * $144);
 $169 = Math_fround($114 * $141);
 $170 = Math_fround($121 * $138);
 $171 = Math_fround($169 - $170);
 $172 = Math_fround($135 * $171);
 $173 = Math_fround($168 + $172);
 $174 = Math_fround($128 * $151);
 $175 = Math_fround($173 + $174);
 $176 = Math_fround($101 + $159);
 $177 = Math_fround($104 + $167);
 $178 = Math_fround($107 + $175);
 $179 = Math_fround(HEAPF32[$0>>2]);
 $180 = Math_fround($135 * $179);
 $181 = (($0) + 12|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = Math_fround($114 * $182);
 $184 = Math_fround($180 + $183);
 $185 = (($0) + 8|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = Math_fround($121 * $186);
 $188 = Math_fround($184 + $187);
 $189 = (($0) + 4|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = Math_fround($128 * $190);
 $192 = Math_fround($188 - $191);
 $193 = Math_fround($135 * $190);
 $194 = Math_fround($121 * $182);
 $195 = Math_fround($194 + $193);
 $196 = Math_fround($128 * $179);
 $197 = Math_fround($196 + $195);
 $198 = Math_fround($114 * $186);
 $199 = Math_fround($197 - $198);
 $200 = Math_fround($135 * $186);
 $201 = Math_fround($128 * $182);
 $202 = Math_fround($201 + $200);
 $203 = Math_fround($114 * $190);
 $204 = Math_fround($203 + $202);
 $205 = Math_fround($121 * $179);
 $206 = Math_fround($204 - $205);
 $207 = Math_fround($135 * $182);
 $208 = Math_fround($114 * $179);
 $209 = Math_fround($207 - $208);
 $210 = Math_fround($121 * $190);
 $211 = Math_fround($209 - $210);
 $212 = Math_fround($128 * $186);
 $213 = Math_fround($211 - $212);
 HEAPF32[$endShape2world>>2] = $192;
 $214 = (($endShape2world) + 4|0);
 HEAPF32[$214>>2] = $199;
 $215 = (($endShape2world) + 8|0);
 HEAPF32[$215>>2] = $206;
 $216 = (($endShape2world) + 12|0);
 HEAPF32[$216>>2] = $213;
 $217 = (($endShape2world) + 16|0);
 HEAPF32[$217>>2] = $176;
 $218 = (($endShape2world) + 20|0);
 HEAPF32[$218>>2] = $177;
 $219 = (($endShape2world) + 24|0);
 HEAPF32[$219>>2] = $178;
 $220 = (($0) + 36|0);
 $221 = (Math_fround(__ZNK5physx2Gu13GeometryUnion29computeBoundsWithCCDThresholdERNS_6PxVec3ES3_RKNS_11PxTransformEPKNS_9PxBounds3E($220,$endOrigin,$endExtent,$endShape2world,$6)));
 $222 = Math_fround(HEAPF32[$endOrigin>>2]);
 $223 = Math_fround(HEAPF32[$endExtent>>2]);
 $224 = Math_fround($222 - $223);
 $225 = (($endOrigin) + 4|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = (($endExtent) + 4|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 $229 = Math_fround($226 - $228);
 $230 = (($endOrigin) + 8|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($endExtent) + 8|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = Math_fround($231 - $233);
 $235 = Math_fround($222 + $223);
 $236 = Math_fround($226 + $228);
 $237 = Math_fround($231 + $233);
 $238 = (($2) + 32|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($2) + 36|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = (($2) + 40|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($2) + 44|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = (($2) + 48|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = (($2) + 52|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = (($2) + 56|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = Math_fround(HEAPF32[$7>>2]);
 $253 = Math_fround(HEAPF32[$9>>2]);
 $254 = Math_fround(HEAPF32[$11>>2]);
 $255 = Math_fround($252 * Math_fround(-2.0));
 $256 = Math_fround($253 * Math_fround(-2.0));
 $257 = Math_fround($254 * Math_fround(-2.0));
 $258 = Math_fround(HEAPF32[$16>>2]);
 $259 = Math_fround($258 * $258);
 $260 = Math_fround($259 + Math_fround(-0.5));
 $261 = Math_fround(HEAPF32[$20>>2]);
 $262 = Math_fround($255 * $261);
 $263 = Math_fround(HEAPF32[$23>>2]);
 $264 = Math_fround($256 * $263);
 $265 = Math_fround($262 + $264);
 $266 = Math_fround(HEAPF32[$27>>2]);
 $267 = Math_fround($257 * $266);
 $268 = Math_fround($265 + $267);
 $269 = Math_fround($255 * $260);
 $270 = Math_fround($257 * $263);
 $271 = Math_fround($256 * $266);
 $272 = Math_fround($270 - $271);
 $273 = Math_fround($258 * $272);
 $274 = Math_fround($269 - $273);
 $275 = Math_fround($261 * $268);
 $276 = Math_fround($275 + $274);
 $277 = Math_fround($256 * $260);
 $278 = Math_fround($255 * $266);
 $279 = Math_fround($257 * $261);
 $280 = Math_fround($278 - $279);
 $281 = Math_fround($258 * $280);
 $282 = Math_fround($277 - $281);
 $283 = Math_fround($263 * $268);
 $284 = Math_fround($283 + $282);
 $285 = Math_fround($257 * $260);
 $286 = Math_fround($256 * $261);
 $287 = Math_fround($255 * $263);
 $288 = Math_fround($286 - $287);
 $289 = Math_fround($258 * $288);
 $290 = Math_fround($285 - $289);
 $291 = Math_fround($266 * $268);
 $292 = Math_fround($290 + $291);
 $293 = Math_fround(-$261);
 $294 = Math_fround(-$263);
 $295 = Math_fround(-$266);
 $296 = Math_fround($276 * Math_fround(2.0));
 $297 = Math_fround($284 * Math_fround(2.0));
 $298 = Math_fround($292 * Math_fround(2.0));
 $299 = Math_fround($245 * $245);
 $300 = Math_fround($299 + Math_fround(-0.5));
 $301 = Math_fround($239 * $296);
 $302 = Math_fround($241 * $297);
 $303 = Math_fround($301 + $302);
 $304 = Math_fround($243 * $298);
 $305 = Math_fround($304 + $303);
 $306 = Math_fround($300 * $296);
 $307 = Math_fround($241 * $298);
 $308 = Math_fround($243 * $297);
 $309 = Math_fround($307 - $308);
 $310 = Math_fround($245 * $309);
 $311 = Math_fround($306 + $310);
 $312 = Math_fround($239 * $305);
 $313 = Math_fround($312 + $311);
 $314 = Math_fround($300 * $297);
 $315 = Math_fround($243 * $296);
 $316 = Math_fround($239 * $298);
 $317 = Math_fround($315 - $316);
 $318 = Math_fround($245 * $317);
 $319 = Math_fround($314 + $318);
 $320 = Math_fround($241 * $305);
 $321 = Math_fround($320 + $319);
 $322 = Math_fround($300 * $298);
 $323 = Math_fround($239 * $297);
 $324 = Math_fround($241 * $296);
 $325 = Math_fround($323 - $324);
 $326 = Math_fround($245 * $325);
 $327 = Math_fround($322 + $326);
 $328 = Math_fround($243 * $305);
 $329 = Math_fround($327 + $328);
 $330 = Math_fround($247 + $313);
 $331 = Math_fround($249 + $321);
 $332 = Math_fround($251 + $329);
 $333 = Math_fround($245 * $293);
 $334 = Math_fround($239 * $258);
 $335 = Math_fround($334 + $333);
 $336 = Math_fround($241 * $295);
 $337 = Math_fround($335 + $336);
 $338 = Math_fround($243 * $294);
 $339 = Math_fround($337 - $338);
 $340 = Math_fround($245 * $294);
 $341 = Math_fround($241 * $258);
 $342 = Math_fround($341 + $340);
 $343 = Math_fround($243 * $293);
 $344 = Math_fround($343 + $342);
 $345 = Math_fround($239 * $295);
 $346 = Math_fround($344 - $345);
 $347 = Math_fround($245 * $295);
 $348 = Math_fround($243 * $258);
 $349 = Math_fround($348 + $347);
 $350 = Math_fround($239 * $294);
 $351 = Math_fround($350 + $349);
 $352 = Math_fround($241 * $293);
 $353 = Math_fround($351 - $352);
 $354 = Math_fround($245 * $258);
 $355 = Math_fround($239 * $293);
 $356 = Math_fround($354 - $355);
 $357 = Math_fround($241 * $294);
 $358 = Math_fround($356 - $357);
 $359 = Math_fround($243 * $295);
 $360 = Math_fround($358 - $359);
 $361 = Math_fround(HEAPF32[$136>>2]);
 $362 = Math_fround($361 * Math_fround(2.0));
 $363 = Math_fround(HEAPF32[$139>>2]);
 $364 = Math_fround($363 * Math_fround(2.0));
 $365 = Math_fround(HEAPF32[$142>>2]);
 $366 = Math_fround($365 * Math_fround(2.0));
 $367 = Math_fround($360 * $360);
 $368 = Math_fround($367 + Math_fround(-0.5));
 $369 = Math_fround($362 * $339);
 $370 = Math_fround($364 * $346);
 $371 = Math_fround($369 + $370);
 $372 = Math_fround($366 * $353);
 $373 = Math_fround($371 + $372);
 $374 = Math_fround($362 * $368);
 $375 = Math_fround($366 * $346);
 $376 = Math_fround($364 * $353);
 $377 = Math_fround($375 - $376);
 $378 = Math_fround($360 * $377);
 $379 = Math_fround($374 + $378);
 $380 = Math_fround($339 * $373);
 $381 = Math_fround($380 + $379);
 $382 = Math_fround($364 * $368);
 $383 = Math_fround($362 * $353);
 $384 = Math_fround($366 * $339);
 $385 = Math_fround($383 - $384);
 $386 = Math_fround($360 * $385);
 $387 = Math_fround($382 + $386);
 $388 = Math_fround($346 * $373);
 $389 = Math_fround($388 + $387);
 $390 = Math_fround($366 * $368);
 $391 = Math_fround($364 * $339);
 $392 = Math_fround($362 * $346);
 $393 = Math_fround($391 - $392);
 $394 = Math_fround($360 * $393);
 $395 = Math_fround($390 + $394);
 $396 = Math_fround($353 * $373);
 $397 = Math_fround($395 + $396);
 $398 = Math_fround($381 + $330);
 $399 = Math_fround($389 + $331);
 $400 = Math_fround($397 + $332);
 $401 = Math_fround(HEAPF32[$0>>2]);
 $402 = Math_fround($360 * $401);
 $403 = Math_fround(HEAPF32[$181>>2]);
 $404 = Math_fround($339 * $403);
 $405 = Math_fround($402 + $404);
 $406 = Math_fround(HEAPF32[$185>>2]);
 $407 = Math_fround($346 * $406);
 $408 = Math_fround($405 + $407);
 $409 = Math_fround(HEAPF32[$189>>2]);
 $410 = Math_fround($353 * $409);
 $411 = Math_fround($408 - $410);
 $412 = Math_fround($360 * $409);
 $413 = Math_fround($346 * $403);
 $414 = Math_fround($413 + $412);
 $415 = Math_fround($401 * $353);
 $416 = Math_fround($415 + $414);
 $417 = Math_fround($339 * $406);
 $418 = Math_fround($416 - $417);
 $419 = Math_fround($360 * $406);
 $420 = Math_fround($353 * $403);
 $421 = Math_fround($420 + $419);
 $422 = Math_fround($339 * $409);
 $423 = Math_fround($422 + $421);
 $424 = Math_fround($346 * $401);
 $425 = Math_fround($423 - $424);
 $426 = Math_fround($360 * $403);
 $427 = Math_fround($339 * $401);
 $428 = Math_fround($426 - $427);
 $429 = Math_fround($346 * $409);
 $430 = Math_fround($428 - $429);
 $431 = Math_fround($353 * $406);
 $432 = Math_fround($430 - $431);
 HEAPF32[$startShape2World>>2] = $411;
 $433 = (($startShape2World) + 4|0);
 HEAPF32[$433>>2] = $418;
 $434 = (($startShape2World) + 8|0);
 HEAPF32[$434>>2] = $425;
 $435 = (($startShape2World) + 12|0);
 HEAPF32[$435>>2] = $432;
 $436 = (($startShape2World) + 16|0);
 HEAPF32[$436>>2] = $398;
 $437 = (($startShape2World) + 20|0);
 HEAPF32[$437>>2] = $399;
 $438 = (($startShape2World) + 24|0);
 HEAPF32[$438>>2] = $400;
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($220,$startBounds,$startShape2World,Math_fround(0.0),$6);
 $439 = Math_fround(HEAPF32[$startBounds>>2]);
 $440 = $224 < $439;
 $441 = $440 ? $224 : $439;
 $442 = (($startBounds) + 4|0);
 $443 = Math_fround(HEAPF32[$442>>2]);
 $444 = $229 < $443;
 $445 = $444 ? $229 : $443;
 $446 = (($startBounds) + 8|0);
 $447 = Math_fround(HEAPF32[$446>>2]);
 $448 = $234 < $447;
 $449 = $448 ? $234 : $447;
 $450 = (($startBounds) + 12|0);
 $451 = Math_fround(HEAPF32[$450>>2]);
 $452 = $235 > $451;
 $453 = $452 ? $235 : $451;
 $454 = (($startBounds) + 16|0);
 $455 = Math_fround(HEAPF32[$454>>2]);
 $456 = $236 > $455;
 $457 = $456 ? $236 : $455;
 $458 = (($startBounds) + 20|0);
 $459 = Math_fround(HEAPF32[$458>>2]);
 $460 = $237 > $459;
 $461 = $460 ? $237 : $459;
 $462 = (($0) + 28|0);
 $463 = Math_fround(HEAPF32[$462>>2]);
 $464 = Math_fround($441 - $463);
 $465 = Math_fround($445 - $463);
 $466 = Math_fround($449 - $463);
 HEAPF32[$destBounds>>2] = $464;
 $467 = (($destBounds) + 4|0);
 HEAPF32[$467>>2] = $465;
 $468 = (($destBounds) + 8|0);
 HEAPF32[$468>>2] = $466;
 $469 = Math_fround($453 + $463);
 $470 = Math_fround($457 + $463);
 $471 = Math_fround($463 + $461);
 $472 = (($destBounds) + 12|0);
 HEAPF32[$472>>2] = $469;
 $473 = (($destBounds) + 16|0);
 HEAPF32[$473>>2] = $470;
 $474 = (($destBounds) + 20|0);
 HEAPF32[$474>>2] = $471;
 $475 = Math_fround($439 + $451);
 $476 = Math_fround($443 + $455);
 $477 = Math_fround($447 + $459);
 $478 = Math_fround($475 * Math_fround(0.5));
 $479 = Math_fround($476 * Math_fround(0.5));
 $480 = Math_fround($477 * Math_fround(0.5));
 $481 = Math_fround(HEAPF32[$endOrigin>>2]);
 $482 = Math_fround($478 - $481);
 $483 = Math_fround(HEAPF32[$225>>2]);
 $484 = Math_fround($479 - $483);
 $485 = Math_fround(HEAPF32[$230>>2]);
 $486 = Math_fround($480 - $485);
 $487 = Math_fround($482 * $482);
 $488 = Math_fround($484 * $484);
 $489 = Math_fround($487 + $488);
 $490 = Math_fround($486 * $486);
 $491 = Math_fround($489 + $490);
 $492 = Math_fround($221 * $221);
 $493 = Math_fround($491 - $492);
 $494 = $493 >= Math_fround(0.0);
 $495 = $494 ? Math_fround(1.0) : Math_fround(0.0);
 STACKTOP = sp;return (Math_fround($495));
}
function __ZN5physx14PxsComputeAABBERKNS_17PxcAABBDataStaticERNS_9PxBounds3E($aabbData,$updatedBodyShapeBounds) {
 $aabbData = $aabbData|0;
 $updatedBodyShapeBounds = $updatedBodyShapeBounds|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $globalPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $globalPose = sp;
 $0 = HEAP32[$aabbData>>2]|0;
 $1 = (($aabbData) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($2) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($2) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$2>>2]);
 $10 = (($2) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($2) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($2) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($0) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($0) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($0) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(HEAPF32[$0>>2]);
 $23 = (($0) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($0) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($0) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($15 * $15);
 $30 = Math_fround($29 + Math_fround(-0.5));
 $31 = Math_fround($17 * $30);
 $32 = Math_fround($30 * $19);
 $33 = Math_fround($30 * $21);
 $34 = Math_fround($11 * $21);
 $35 = Math_fround($13 * $19);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($13 * $17);
 $38 = Math_fround($9 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($9 * $19);
 $41 = Math_fround($11 * $17);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($15 * $36);
 $44 = Math_fround($15 * $39);
 $45 = Math_fround($15 * $42);
 $46 = Math_fround($31 + $43);
 $47 = Math_fround($32 + $44);
 $48 = Math_fround($33 + $45);
 $49 = Math_fround($9 * $17);
 $50 = Math_fround($11 * $19);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($13 * $21);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($9 * $53);
 $55 = Math_fround($11 * $53);
 $56 = Math_fround($13 * $53);
 $57 = Math_fround($54 + $46);
 $58 = Math_fround($55 + $47);
 $59 = Math_fround($48 + $56);
 $60 = Math_fround($57 * Math_fround(2.0));
 $61 = Math_fround($58 * Math_fround(2.0));
 $62 = Math_fround($59 * Math_fround(2.0));
 $63 = Math_fround($4 + $60);
 $64 = Math_fround($6 + $61);
 $65 = Math_fround($8 + $62);
 $66 = Math_fround($15 * $28);
 $67 = Math_fround($9 * $22);
 $68 = Math_fround($11 * $24);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround($13 * $26);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($66 - $71);
 $73 = Math_fround($9 * $28);
 $74 = Math_fround($11 * $28);
 $75 = Math_fround($13 * $28);
 $76 = Math_fround($15 * $22);
 $77 = Math_fround($15 * $24);
 $78 = Math_fround($15 * $26);
 $79 = Math_fround($11 * $26);
 $80 = Math_fround($13 * $24);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($13 * $22);
 $83 = Math_fround($9 * $26);
 $84 = Math_fround($82 - $83);
 $85 = Math_fround($9 * $24);
 $86 = Math_fround($11 * $22);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($76 + $73);
 $89 = Math_fround($77 + $74);
 $90 = Math_fround($78 + $75);
 $91 = Math_fround($81 + $88);
 $92 = Math_fround($84 + $89);
 $93 = Math_fround($87 + $90);
 $94 = (($globalPose) + 16|0);
 HEAPF32[$94>>2] = $63;
 $95 = (($globalPose) + 20|0);
 HEAPF32[$95>>2] = $64;
 $96 = (($globalPose) + 24|0);
 HEAPF32[$96>>2] = $65;
 HEAPF32[$globalPose>>2] = $91;
 $97 = (($globalPose) + 4|0);
 HEAPF32[$97>>2] = $92;
 $98 = (($globalPose) + 8|0);
 HEAPF32[$98>>2] = $93;
 $99 = (($globalPose) + 12|0);
 HEAPF32[$99>>2] = $72;
 $100 = (($0) + 36|0);
 $101 = (($0) + 28|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($100,$updatedBodyShapeBounds,$globalPose,$102,0);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsComputeAABBEbRKNS_18PxcAABBDataDynamicERNS_9PxBounds3E($secondBroadphase,$aabbData,$updatedBodyShapeBounds) {
 $secondBroadphase = $secondBroadphase|0;
 $aabbData = $aabbData|0;
 $updatedBodyShapeBounds = $updatedBodyShapeBounds|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $globalPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $globalPose = sp;
 $0 = HEAP32[$aabbData>>2]|0;
 $1 = (($aabbData) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($aabbData) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 if ($secondBroadphase) {
  $5 = (($2) + 28|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6 & 4;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   $228 = (Math_fround(__Z18computeSweptBoundsRKN5physx18PxcAABBDataDynamicERNS_9PxBounds3E($aabbData,$updatedBodyShapeBounds)));
   $$0 = $228;
   STACKTOP = sp;return (Math_fround($$0));
  }
 }
 $9 = (($2) + 48|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(-$10);
 $12 = (($2) + 52|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(-$13);
 $15 = (($2) + 56|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(-$16);
 $18 = (($2) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($2) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($2) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(HEAPF32[$2>>2]);
 $25 = (($2) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($2) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($2) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($2) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($31) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($31) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($31) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($38 * $38);
 $40 = Math_fround($39 + Math_fround(-0.5));
 $41 = Math_fround($40 * $11);
 $42 = Math_fround($40 * $14);
 $43 = Math_fround($40 * $17);
 $44 = Math_fround($34 * $17);
 $45 = Math_fround($36 * $14);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($36 * $11);
 $48 = Math_fround($32 * $17);
 $49 = Math_fround($47 - $48);
 $50 = Math_fround($32 * $14);
 $51 = Math_fround($34 * $11);
 $52 = Math_fround($50 - $51);
 $53 = Math_fround($38 * $46);
 $54 = Math_fround($38 * $49);
 $55 = Math_fround($38 * $52);
 $56 = Math_fround($41 - $53);
 $57 = Math_fround($42 - $54);
 $58 = Math_fround($43 - $55);
 $59 = Math_fround($32 * $11);
 $60 = Math_fround($34 * $14);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($36 * $17);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($32 * $63);
 $65 = Math_fround($34 * $63);
 $66 = Math_fround($36 * $63);
 $67 = Math_fround($64 + $56);
 $68 = Math_fround($65 + $57);
 $69 = Math_fround($66 + $58);
 $70 = Math_fround($67 * Math_fround(2.0));
 $71 = Math_fround($68 * Math_fround(2.0));
 $72 = Math_fround($69 * Math_fround(2.0));
 $73 = Math_fround(-$32);
 $74 = Math_fround(-$34);
 $75 = Math_fround(-$36);
 $76 = (($0) + 16|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($0) + 20|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($0) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround(HEAPF32[$0>>2]);
 $83 = (($0) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($0) + 8|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($0) + 12|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($30 * $30);
 $90 = Math_fround($89 + Math_fround(-0.5));
 $91 = Math_fround($90 * $70);
 $92 = Math_fround($90 * $71);
 $93 = Math_fround($90 * $72);
 $94 = Math_fround($26 * $72);
 $95 = Math_fround($28 * $71);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($28 * $70);
 $98 = Math_fround($24 * $72);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($24 * $71);
 $101 = Math_fround($26 * $70);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($30 * $96);
 $104 = Math_fround($30 * $99);
 $105 = Math_fround($30 * $102);
 $106 = Math_fround($91 + $103);
 $107 = Math_fround($92 + $104);
 $108 = Math_fround($93 + $105);
 $109 = Math_fround($24 * $70);
 $110 = Math_fround($26 * $71);
 $111 = Math_fround($109 + $110);
 $112 = Math_fround($28 * $72);
 $113 = Math_fround($112 + $111);
 $114 = Math_fround($24 * $113);
 $115 = Math_fround($26 * $113);
 $116 = Math_fround($28 * $113);
 $117 = Math_fround($106 + $114);
 $118 = Math_fround($107 + $115);
 $119 = Math_fround($108 + $116);
 $120 = Math_fround($117 * Math_fround(2.0));
 $121 = Math_fround($118 * Math_fround(2.0));
 $122 = Math_fround($119 * Math_fround(2.0));
 $123 = Math_fround($19 + $120);
 $124 = Math_fround($21 + $121);
 $125 = Math_fround($23 + $122);
 $126 = Math_fround($30 * $38);
 $127 = Math_fround($24 * $73);
 $128 = Math_fround($26 * $74);
 $129 = Math_fround($127 + $128);
 $130 = Math_fround($28 * $75);
 $131 = Math_fround($129 + $130);
 $132 = Math_fround($126 - $131);
 $133 = Math_fround($24 * $38);
 $134 = Math_fround($26 * $38);
 $135 = Math_fround($28 * $38);
 $136 = Math_fround($30 * $73);
 $137 = Math_fround($30 * $74);
 $138 = Math_fround($30 * $75);
 $139 = Math_fround($26 * $75);
 $140 = Math_fround($28 * $74);
 $141 = Math_fround($139 - $140);
 $142 = Math_fround($28 * $73);
 $143 = Math_fround($24 * $75);
 $144 = Math_fround($142 - $143);
 $145 = Math_fround($24 * $74);
 $146 = Math_fround($26 * $73);
 $147 = Math_fround($145 - $146);
 $148 = Math_fround($136 + $133);
 $149 = Math_fround($137 + $134);
 $150 = Math_fround($138 + $135);
 $151 = Math_fround($141 + $148);
 $152 = Math_fround($144 + $149);
 $153 = Math_fround($147 + $150);
 $154 = Math_fround($132 * $132);
 $155 = Math_fround($154 + Math_fround(-0.5));
 $156 = Math_fround($77 * $155);
 $157 = Math_fround($79 * $155);
 $158 = Math_fround($81 * $155);
 $159 = Math_fround($152 * $81);
 $160 = Math_fround($79 * $153);
 $161 = Math_fround($159 - $160);
 $162 = Math_fround($77 * $153);
 $163 = Math_fround($151 * $81);
 $164 = Math_fround($162 - $163);
 $165 = Math_fround($79 * $151);
 $166 = Math_fround($77 * $152);
 $167 = Math_fround($165 - $166);
 $168 = Math_fround($132 * $161);
 $169 = Math_fround($132 * $164);
 $170 = Math_fround($132 * $167);
 $171 = Math_fround($156 + $168);
 $172 = Math_fround($157 + $169);
 $173 = Math_fround($158 + $170);
 $174 = Math_fround($77 * $151);
 $175 = Math_fround($79 * $152);
 $176 = Math_fround($174 + $175);
 $177 = Math_fround($153 * $81);
 $178 = Math_fround($177 + $176);
 $179 = Math_fround($151 * $178);
 $180 = Math_fround($152 * $178);
 $181 = Math_fround($153 * $178);
 $182 = Math_fround($171 + $179);
 $183 = Math_fround($172 + $180);
 $184 = Math_fround($173 + $181);
 $185 = Math_fround($182 * Math_fround(2.0));
 $186 = Math_fround($183 * Math_fround(2.0));
 $187 = Math_fround($184 * Math_fround(2.0));
 $188 = Math_fround($185 + $123);
 $189 = Math_fround($186 + $124);
 $190 = Math_fround($187 + $125);
 $191 = Math_fround($132 * $88);
 $192 = Math_fround($151 * $82);
 $193 = Math_fround($152 * $84);
 $194 = Math_fround($192 + $193);
 $195 = Math_fround($153 * $86);
 $196 = Math_fround($194 + $195);
 $197 = Math_fround($191 - $196);
 $198 = Math_fround($151 * $88);
 $199 = Math_fround($152 * $88);
 $200 = Math_fround($153 * $88);
 $201 = Math_fround($132 * $82);
 $202 = Math_fround($132 * $84);
 $203 = Math_fround($132 * $86);
 $204 = Math_fround($152 * $86);
 $205 = Math_fround($153 * $84);
 $206 = Math_fround($204 - $205);
 $207 = Math_fround($153 * $82);
 $208 = Math_fround($151 * $86);
 $209 = Math_fround($207 - $208);
 $210 = Math_fround($151 * $84);
 $211 = Math_fround($152 * $82);
 $212 = Math_fround($210 - $211);
 $213 = Math_fround($201 + $198);
 $214 = Math_fround($202 + $199);
 $215 = Math_fround($203 + $200);
 $216 = Math_fround($206 + $213);
 $217 = Math_fround($209 + $214);
 $218 = Math_fround($212 + $215);
 $219 = (($globalPose) + 16|0);
 HEAPF32[$219>>2] = $188;
 $220 = (($globalPose) + 20|0);
 HEAPF32[$220>>2] = $189;
 $221 = (($globalPose) + 24|0);
 HEAPF32[$221>>2] = $190;
 HEAPF32[$globalPose>>2] = $216;
 $222 = (($globalPose) + 4|0);
 HEAPF32[$222>>2] = $217;
 $223 = (($globalPose) + 8|0);
 HEAPF32[$223>>2] = $218;
 $224 = (($globalPose) + 12|0);
 HEAPF32[$224>>2] = $197;
 $225 = (($0) + 36|0);
 $226 = (($0) + 28|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($225,$updatedBodyShapeBounds,$globalPose,$227,$4);
 $$0 = Math_fround(0.0);
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx24PxsComputeAABBLocalSpaceERKNS_17PxcAABBDataStaticERNS_9PxBounds3E($aabbData,$updatedBodyShapeBounds) {
 $aabbData = $aabbData|0;
 $updatedBodyShapeBounds = $updatedBodyShapeBounds|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$aabbData>>2]|0;
 $1 = (($0) + 28|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($0) + 36|0);
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($3,$updatedBodyShapeBounds,$0,$2,0);
 STACKTOP = sp;return;
}
function __ZN5physx24PxsComputeAABBLocalSpaceERKNS_18PxcAABBDataDynamicERNS_9PxBounds3E($aabbData,$updatedBodyShapeBounds) {
 $aabbData = $aabbData|0;
 $updatedBodyShapeBounds = $updatedBodyShapeBounds|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0;
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $globalPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $globalPose = sp;
 $0 = HEAP32[$aabbData>>2]|0;
 $1 = (($aabbData) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($aabbData) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 48|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 $8 = (($2) + 52|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(-$9);
 $11 = (($2) + 56|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(-$12);
 $14 = (($2) + 32|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($14) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($14) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($14) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $21);
 $23 = Math_fround($22 + Math_fround(-0.5));
 $24 = Math_fround($23 * $7);
 $25 = Math_fround($23 * $10);
 $26 = Math_fround($23 * $13);
 $27 = Math_fround($17 * $13);
 $28 = Math_fround($19 * $10);
 $29 = Math_fround($27 - $28);
 $30 = Math_fround($19 * $7);
 $31 = Math_fround($15 * $13);
 $32 = Math_fround($30 - $31);
 $33 = Math_fround($15 * $10);
 $34 = Math_fround($17 * $7);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($21 * $29);
 $37 = Math_fround($21 * $32);
 $38 = Math_fround($21 * $35);
 $39 = Math_fround($24 - $36);
 $40 = Math_fround($25 - $37);
 $41 = Math_fround($26 - $38);
 $42 = Math_fround($15 * $7);
 $43 = Math_fround($17 * $10);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($19 * $13);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($15 * $46);
 $48 = Math_fround($17 * $46);
 $49 = Math_fround($19 * $46);
 $50 = Math_fround($47 + $39);
 $51 = Math_fround($48 + $40);
 $52 = Math_fround($49 + $41);
 $53 = Math_fround($50 * Math_fround(2.0));
 $54 = Math_fround($51 * Math_fround(2.0));
 $55 = Math_fround($52 * Math_fround(2.0));
 $56 = Math_fround(-$15);
 $57 = Math_fround(-$17);
 $58 = Math_fround(-$19);
 $59 = (($0) + 16|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($0) + 20|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($0) + 24|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(HEAPF32[$0>>2]);
 $66 = (($0) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($0) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($0) + 12|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($60 * $23);
 $73 = Math_fround($23 * $62);
 $74 = Math_fround($23 * $64);
 $75 = Math_fround($64 * $57);
 $76 = Math_fround($62 * $58);
 $77 = Math_fround($75 - $76);
 $78 = Math_fround($60 * $58);
 $79 = Math_fround($64 * $56);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($62 * $56);
 $82 = Math_fround($60 * $57);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($21 * $77);
 $85 = Math_fround($21 * $80);
 $86 = Math_fround($21 * $83);
 $87 = Math_fround($72 + $84);
 $88 = Math_fround($73 + $85);
 $89 = Math_fround($74 + $86);
 $90 = Math_fround($60 * $56);
 $91 = Math_fround($62 * $57);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($64 * $58);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($94 * $56);
 $96 = Math_fround($94 * $57);
 $97 = Math_fround($94 * $58);
 $98 = Math_fround($95 + $87);
 $99 = Math_fround($96 + $88);
 $100 = Math_fround($89 + $97);
 $101 = Math_fround($98 * Math_fround(2.0));
 $102 = Math_fround($99 * Math_fround(2.0));
 $103 = Math_fround($100 * Math_fround(2.0));
 $104 = Math_fround($53 + $101);
 $105 = Math_fround($54 + $102);
 $106 = Math_fround($55 + $103);
 $107 = Math_fround($21 * $71);
 $108 = Math_fround($65 * $56);
 $109 = Math_fround($67 * $57);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($69 * $58);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround($107 - $112);
 $114 = Math_fround($71 * $56);
 $115 = Math_fround($71 * $57);
 $116 = Math_fround($71 * $58);
 $117 = Math_fround($21 * $65);
 $118 = Math_fround($21 * $67);
 $119 = Math_fround($21 * $69);
 $120 = Math_fround($69 * $57);
 $121 = Math_fround($67 * $58);
 $122 = Math_fround($120 - $121);
 $123 = Math_fround($65 * $58);
 $124 = Math_fround($69 * $56);
 $125 = Math_fround($123 - $124);
 $126 = Math_fround($67 * $56);
 $127 = Math_fround($65 * $57);
 $128 = Math_fround($126 - $127);
 $129 = Math_fround($117 + $114);
 $130 = Math_fround($118 + $115);
 $131 = Math_fround($119 + $116);
 $132 = Math_fround($122 + $129);
 $133 = Math_fround($125 + $130);
 $134 = Math_fround($128 + $131);
 $135 = (($globalPose) + 16|0);
 HEAPF32[$135>>2] = $104;
 $136 = (($globalPose) + 20|0);
 HEAPF32[$136>>2] = $105;
 $137 = (($globalPose) + 24|0);
 HEAPF32[$137>>2] = $106;
 HEAPF32[$globalPose>>2] = $132;
 $138 = (($globalPose) + 4|0);
 HEAPF32[$138>>2] = $133;
 $139 = (($globalPose) + 8|0);
 HEAPF32[$139>>2] = $134;
 $140 = (($globalPose) + 12|0);
 HEAPF32[$140>>2] = $113;
 $141 = (($0) + 36|0);
 $142 = (($0) + 28|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($141,$updatedBodyShapeBounds,$globalPose,$143,$4);
 STACKTOP = sp;return;
}
function __ZN5physx14PxsComputeAABBEPKNS_12PxsRigidCoreERKNS_9PxBounds3ERS3_($rigidCore,$localSpaceActorBounds,$updatedWorldSpaceActorBounds) {
 $rigidCore = $rigidCore|0;
 $localSpaceActorBounds = $localSpaceActorBounds|0;
 $updatedWorldSpaceActorBounds = $updatedWorldSpaceActorBounds|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($0,$rigidCore,$localSpaceActorBounds);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$updatedWorldSpaceActorBounds>>2] = $1;
 $2 = (($0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($updatedWorldSpaceActorBounds) + 4|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($updatedWorldSpaceActorBounds) + 8|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($0) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($updatedWorldSpaceActorBounds) + 12|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($0) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($updatedWorldSpaceActorBounds) + 16|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($0) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($updatedWorldSpaceActorBounds) + 20|0);
 HEAPF32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN5physx14PxsComputeAABBEbPKNS_12PxcRigidBodyEPKNS_12PxsRigidCoreERKNS_9PxBounds3ERS6_($secondBroadphase,$bodyAtom,$rigidCore,$localSpaceActorBounds,$updatedWorldSpaceActorBounds) {
 $secondBroadphase = $secondBroadphase|0;
 $bodyAtom = $bodyAtom|0;
 $rigidCore = $rigidCore|0;
 $localSpaceActorBounds = $localSpaceActorBounds|0;
 $updatedWorldSpaceActorBounds = $updatedWorldSpaceActorBounds|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $currBounds$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 48|0;
 $currBounds$i = sp;
 $1 = sp + 24|0;
 if ($secondBroadphase) {
  $2 = (($rigidCore) + 28|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3 & 4;
  $5 = ($4<<24>>24)==(0);
  if (!($5)) {
   $22 = (($bodyAtom) + 32|0);
   __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($0,$22,$localSpaceActorBounds);
   $23 = Math_fround(HEAPF32[$0>>2]);
   HEAPF32[$updatedWorldSpaceActorBounds>>2] = $23;
   $24 = (($0) + 4|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = (($updatedWorldSpaceActorBounds) + 4|0);
   HEAPF32[$26>>2] = $25;
   $27 = (($0) + 8|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = (($updatedWorldSpaceActorBounds) + 8|0);
   HEAPF32[$29>>2] = $28;
   $30 = (($0) + 12|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = (($updatedWorldSpaceActorBounds) + 12|0);
   HEAPF32[$32>>2] = $31;
   $33 = (($0) + 16|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = (($updatedWorldSpaceActorBounds) + 16|0);
   HEAPF32[$35>>2] = $34;
   $36 = (($0) + 20|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = (($updatedWorldSpaceActorBounds) + 20|0);
   HEAPF32[$38>>2] = $37;
   __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($currBounds$i,$rigidCore,$localSpaceActorBounds);
   $39 = Math_fround(HEAPF32[$updatedWorldSpaceActorBounds>>2]);
   $40 = Math_fround(HEAPF32[$currBounds$i>>2]);
   $41 = $39 < $40;
   $42 = $41 ? $39 : $40;
   $43 = Math_fround(HEAPF32[$26>>2]);
   $44 = (($currBounds$i) + 4|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = $43 < $45;
   $47 = $46 ? $43 : $45;
   $48 = Math_fround(HEAPF32[$29>>2]);
   $49 = (($currBounds$i) + 8|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = $48 < $50;
   $52 = $51 ? $48 : $50;
   HEAPF32[$updatedWorldSpaceActorBounds>>2] = $42;
   HEAPF32[$26>>2] = $47;
   HEAPF32[$29>>2] = $52;
   $53 = Math_fround(HEAPF32[$32>>2]);
   $54 = (($currBounds$i) + 12|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = $53 > $55;
   $57 = $56 ? $53 : $55;
   $58 = Math_fround(HEAPF32[$35>>2]);
   $59 = (($currBounds$i) + 16|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = $58 > $60;
   $62 = $61 ? $58 : $60;
   $63 = Math_fround(HEAPF32[$38>>2]);
   $64 = (($currBounds$i) + 20|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = $63 > $65;
   $67 = $66 ? $63 : $65;
   HEAPF32[$32>>2] = $57;
   HEAPF32[$35>>2] = $62;
   HEAPF32[$38>>2] = $67;
   $$0 = Math_fround(1.0);
   STACKTOP = sp;return (Math_fround($$0));
  }
 }
 __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($1,$rigidCore,$localSpaceActorBounds);
 $6 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$updatedWorldSpaceActorBounds>>2] = $6;
 $7 = (($1) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($updatedWorldSpaceActorBounds) + 4|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($updatedWorldSpaceActorBounds) + 8|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($1) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($updatedWorldSpaceActorBounds) + 12|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($1) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($updatedWorldSpaceActorBounds) + 16|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($1) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($updatedWorldSpaceActorBounds) + 20|0);
 HEAPF32[$21>>2] = $20;
 $$0 = Math_fround(0.0);
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx20updateBodyShapeAABBsEPKjjS1_PKNS_18PxcAABBDataDynamicEbPNS_11IntegerAABBEj($updatedAABBHandles,$numUPdatedAABBHandles,$aabbDataHandles,$aabbData,$secondBroadPhase,$bounds,$0) {
 $updatedAABBHandles = $updatedAABBHandles|0;
 $numUPdatedAABBHandles = $numUPdatedAABBHandles|0;
 $aabbDataHandles = $aabbDataHandles|0;
 $aabbData = $aabbData|0;
 $secondBroadPhase = $secondBroadPhase|0;
 $bounds = $bounds|0;
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i12 = 0, $$0$i$i$i6 = 0, $$0$i$i1$i = 0, $$0$i$i1$i11 = 0, $$0$i$i1$i5 = 0, $$0$i$i2$i = 0, $$0$i$i2$i10 = 0, $$0$i$i2$i4 = 0, $$0$i$i3$i = 0, $$0$i$i3$i3 = 0, $$0$i$i3$i9 = 0, $$0$i$i4$i = 0, $$0$i$i4$i2 = 0, $$0$i$i4$i8 = 0, $$0$i$i5$i = 0, $$0$i$i5$i1 = 0, $$0$i$i5$i7 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond30 = 0, $i$022 = 0, $i1$013 = 0, $j$019 = 0, $nextAABBData$0$lcssa = 0, $nextAABBData$024 = 0, $nextAABBData$121 = 0, $nextAABBData$2$lcssa = 0, $nextAABBData$215 = 0;
 var $numFastMovingObjects$0$lcssa = Math_fround(0), $numFastMovingObjects$023 = Math_fround(0), $numFastMovingObjects$120 = Math_fround(0), $numFastMovingObjects$2$lcssa = Math_fround(0), $numFastMovingObjects$214 = Math_fround(0), $updatedBodyShapeBounds = 0, $updatedBodyShapeBounds4 = 0, $updatedBodyShapeBounds6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $updatedBodyShapeBounds = sp + 48|0;
 $updatedBodyShapeBounds4 = sp;
 $updatedBodyShapeBounds6 = sp + 24|0;
 $1 = HEAP32[$updatedAABBHandles>>2]|0;
 $2 = (($aabbDataHandles) + ($1<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($aabbData) + ($3<<4)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($aabbData) + ($3<<4)|0) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($aabbData) + ($3<<4)|0) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($aabbData) + ($3<<4)|0) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $numUPdatedAABBHandles & 3;
 $13 = ($12|0)!=(0);
 $14 = $numUPdatedAABBHandles & -4;
 $15 = (($numUPdatedAABBHandles) + -4)|0;
 $16 = $13 ? $14 : $15;
 $17 = ($16|0)==(0);
 if ($17) {
  $nextAABBData$0$lcssa = $4;$numFastMovingObjects$0$lcssa = Math_fround(0.0);
 } else {
  $18 = (($updatedBodyShapeBounds) + 12|0);
  $19 = (($updatedBodyShapeBounds) + 4|0);
  $20 = (($updatedBodyShapeBounds) + 8|0);
  $21 = (($18) + 4|0);
  $22 = (($18) + 8|0);
  $i$022 = 0;$nextAABBData$024 = $4;$numFastMovingObjects$023 = Math_fround(0.0);
  while(1) {
   $j$019 = 0;$nextAABBData$121 = $nextAABBData$024;$numFastMovingObjects$120 = $numFastMovingObjects$023;
   while(1) {
    $30 = (($j$019) + ($i$022))|0;
    $31 = (($30) + 1)|0;
    $32 = (($updatedAABBHandles) + ($31<<2)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($aabbDataHandles) + ($33<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($aabbData) + ($35<<4)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($aabbData) + ($35<<4)|0) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ((($aabbData) + ($35<<4)|0) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($aabbData) + ($35<<4)|0) + 12|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (Math_fround(__ZN5physx14PxsComputeAABBEbRKNS_18PxcAABBDataDynamicERNS_9PxBounds3E($secondBroadPhase,$nextAABBData$121,$updatedBodyShapeBounds)));
    $45 = Math_fround($numFastMovingObjects$120 + $44);
    $46 = (($updatedAABBHandles) + ($30<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = HEAP32[$updatedBodyShapeBounds>>2]|0;
    $49 = ($48|0)<(0);
    $50 = $48 ^ -1;
    $51 = $48 | -2147483648;
    $$0$i$i5$i7 = $49 ? $50 : $51;
    $52 = (($$0$i$i5$i7) + -16)|0;
    $53 = $52 & -16;
    $54 = (($bounds) + (($47*24)|0)|0);
    HEAP32[$54>>2] = $53;
    $55 = HEAP32[$19>>2]|0;
    $56 = ($55|0)<(0);
    $57 = $55 ^ -1;
    $58 = $55 | -2147483648;
    $$0$i$i4$i8 = $56 ? $57 : $58;
    $59 = (($$0$i$i4$i8) + -16)|0;
    $60 = $59 & -16;
    $61 = ((($bounds) + (($47*24)|0)|0) + 4|0);
    HEAP32[$61>>2] = $60;
    $62 = HEAP32[$20>>2]|0;
    $63 = ($62|0)<(0);
    $64 = $62 ^ -1;
    $65 = $62 | -2147483648;
    $$0$i$i3$i9 = $63 ? $64 : $65;
    $66 = (($$0$i$i3$i9) + -16)|0;
    $67 = $66 & -16;
    $68 = ((($bounds) + (($47*24)|0)|0) + 8|0);
    HEAP32[$68>>2] = $67;
    $69 = HEAP32[$18>>2]|0;
    $70 = ($69|0)<(0);
    $71 = $69 ^ -1;
    $72 = $69 | -2147483648;
    $$0$i$i2$i10 = $70 ? $71 : $72;
    $73 = (($$0$i$i2$i10) + 16)|0;
    $74 = $73 & -16;
    $75 = $74 | 1;
    $76 = ((($bounds) + (($47*24)|0)|0) + 12|0);
    HEAP32[$76>>2] = $75;
    $77 = HEAP32[$21>>2]|0;
    $78 = ($77|0)<(0);
    $79 = $77 ^ -1;
    $80 = $77 | -2147483648;
    $$0$i$i1$i11 = $78 ? $79 : $80;
    $81 = (($$0$i$i1$i11) + 16)|0;
    $82 = $81 & -16;
    $83 = $82 | 1;
    $84 = ((($bounds) + (($47*24)|0)|0) + 16|0);
    HEAP32[$84>>2] = $83;
    $85 = HEAP32[$22>>2]|0;
    $86 = ($85|0)<(0);
    $87 = $85 ^ -1;
    $88 = $85 | -2147483648;
    $$0$i$i$i12 = $86 ? $87 : $88;
    $89 = (($$0$i$i$i12) + 16)|0;
    $90 = $89 & -16;
    $91 = $90 | 1;
    $92 = ((($bounds) + (($47*24)|0)|0) + 20|0);
    HEAP32[$92>>2] = $91;
    $93 = (($j$019) + 1)|0;
    $exitcond30 = ($93|0)==(4);
    if ($exitcond30) {
     break;
    } else {
     $j$019 = $93;$nextAABBData$121 = $36;$numFastMovingObjects$120 = $45;
    }
   }
   $94 = (($i$022) + 4)|0;
   $95 = ($94>>>0)<($16>>>0);
   if ($95) {
    $i$022 = $94;$nextAABBData$024 = $36;$numFastMovingObjects$023 = $45;
   } else {
    $nextAABBData$0$lcssa = $36;$numFastMovingObjects$0$lcssa = $45;
    break;
   }
  }
 }
 $23 = (($numUPdatedAABBHandles) + -1)|0;
 $24 = ($16>>>0)<($23>>>0);
 if ($24) {
  $25 = (($updatedBodyShapeBounds4) + 12|0);
  $26 = (($updatedBodyShapeBounds4) + 4|0);
  $27 = (($updatedBodyShapeBounds4) + 8|0);
  $28 = (($25) + 4|0);
  $29 = (($25) + 8|0);
  $i1$013 = $16;$nextAABBData$215 = $nextAABBData$0$lcssa;$numFastMovingObjects$214 = $numFastMovingObjects$0$lcssa;
  while(1) {
   $96 = (($i1$013) + 1)|0;
   $97 = (($updatedAABBHandles) + ($96<<2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($aabbDataHandles) + ($98<<2)|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($aabbData) + ($100<<4)|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ((($aabbData) + ($100<<4)|0) + 4|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ((($aabbData) + ($100<<4)|0) + 8|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ((($aabbData) + ($100<<4)|0) + 12|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (Math_fround(__ZN5physx14PxsComputeAABBEbRKNS_18PxcAABBDataDynamicERNS_9PxBounds3E($secondBroadPhase,$nextAABBData$215,$updatedBodyShapeBounds4)));
   $110 = Math_fround($numFastMovingObjects$214 + $109);
   $111 = (($updatedAABBHandles) + ($i1$013<<2)|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = HEAP32[$updatedBodyShapeBounds4>>2]|0;
   $114 = ($113|0)<(0);
   $115 = $113 ^ -1;
   $116 = $113 | -2147483648;
   $$0$i$i5$i1 = $114 ? $115 : $116;
   $117 = (($$0$i$i5$i1) + -16)|0;
   $118 = $117 & -16;
   $119 = (($bounds) + (($112*24)|0)|0);
   HEAP32[$119>>2] = $118;
   $120 = HEAP32[$26>>2]|0;
   $121 = ($120|0)<(0);
   $122 = $120 ^ -1;
   $123 = $120 | -2147483648;
   $$0$i$i4$i2 = $121 ? $122 : $123;
   $124 = (($$0$i$i4$i2) + -16)|0;
   $125 = $124 & -16;
   $126 = ((($bounds) + (($112*24)|0)|0) + 4|0);
   HEAP32[$126>>2] = $125;
   $127 = HEAP32[$27>>2]|0;
   $128 = ($127|0)<(0);
   $129 = $127 ^ -1;
   $130 = $127 | -2147483648;
   $$0$i$i3$i3 = $128 ? $129 : $130;
   $131 = (($$0$i$i3$i3) + -16)|0;
   $132 = $131 & -16;
   $133 = ((($bounds) + (($112*24)|0)|0) + 8|0);
   HEAP32[$133>>2] = $132;
   $134 = HEAP32[$25>>2]|0;
   $135 = ($134|0)<(0);
   $136 = $134 ^ -1;
   $137 = $134 | -2147483648;
   $$0$i$i2$i4 = $135 ? $136 : $137;
   $138 = (($$0$i$i2$i4) + 16)|0;
   $139 = $138 & -16;
   $140 = $139 | 1;
   $141 = ((($bounds) + (($112*24)|0)|0) + 12|0);
   HEAP32[$141>>2] = $140;
   $142 = HEAP32[$28>>2]|0;
   $143 = ($142|0)<(0);
   $144 = $142 ^ -1;
   $145 = $142 | -2147483648;
   $$0$i$i1$i5 = $143 ? $144 : $145;
   $146 = (($$0$i$i1$i5) + 16)|0;
   $147 = $146 & -16;
   $148 = $147 | 1;
   $149 = ((($bounds) + (($112*24)|0)|0) + 16|0);
   HEAP32[$149>>2] = $148;
   $150 = HEAP32[$29>>2]|0;
   $151 = ($150|0)<(0);
   $152 = $150 ^ -1;
   $153 = $150 | -2147483648;
   $$0$i$i$i6 = $151 ? $152 : $153;
   $154 = (($$0$i$i$i6) + 16)|0;
   $155 = $154 & -16;
   $156 = $155 | 1;
   $157 = ((($bounds) + (($112*24)|0)|0) + 20|0);
   HEAP32[$157>>2] = $156;
   $exitcond = ($96|0)==($23|0);
   if ($exitcond) {
    $nextAABBData$2$lcssa = $101;$numFastMovingObjects$2$lcssa = $110;
    break;
   } else {
    $i1$013 = $96;$nextAABBData$215 = $101;$numFastMovingObjects$214 = $110;
   }
  }
 } else {
  $nextAABBData$2$lcssa = $nextAABBData$0$lcssa;$numFastMovingObjects$2$lcssa = $numFastMovingObjects$0$lcssa;
 }
 $158 = (Math_fround(__ZN5physx14PxsComputeAABBEbRKNS_18PxcAABBDataDynamicERNS_9PxBounds3E($secondBroadPhase,$nextAABBData$2$lcssa,$updatedBodyShapeBounds6)));
 $159 = Math_fround($numFastMovingObjects$2$lcssa + $158);
 $160 = (($updatedAABBHandles) + ($23<<2)|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = (($updatedBodyShapeBounds6) + 12|0);
 $163 = HEAP32[$updatedBodyShapeBounds6>>2]|0;
 $164 = ($163|0)<(0);
 $165 = $163 ^ -1;
 $166 = $163 | -2147483648;
 $$0$i$i5$i = $164 ? $165 : $166;
 $167 = (($$0$i$i5$i) + -16)|0;
 $168 = $167 & -16;
 $169 = (($bounds) + (($161*24)|0)|0);
 HEAP32[$169>>2] = $168;
 $170 = (($updatedBodyShapeBounds6) + 4|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = ($171|0)<(0);
 $173 = $171 ^ -1;
 $174 = $171 | -2147483648;
 $$0$i$i4$i = $172 ? $173 : $174;
 $175 = (($$0$i$i4$i) + -16)|0;
 $176 = $175 & -16;
 $177 = ((($bounds) + (($161*24)|0)|0) + 4|0);
 HEAP32[$177>>2] = $176;
 $178 = (($updatedBodyShapeBounds6) + 8|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ($179|0)<(0);
 $181 = $179 ^ -1;
 $182 = $179 | -2147483648;
 $$0$i$i3$i = $180 ? $181 : $182;
 $183 = (($$0$i$i3$i) + -16)|0;
 $184 = $183 & -16;
 $185 = ((($bounds) + (($161*24)|0)|0) + 8|0);
 HEAP32[$185>>2] = $184;
 $186 = HEAP32[$162>>2]|0;
 $187 = ($186|0)<(0);
 $188 = $186 ^ -1;
 $189 = $186 | -2147483648;
 $$0$i$i2$i = $187 ? $188 : $189;
 $190 = (($$0$i$i2$i) + 16)|0;
 $191 = $190 & -16;
 $192 = $191 | 1;
 $193 = ((($bounds) + (($161*24)|0)|0) + 12|0);
 HEAP32[$193>>2] = $192;
 $194 = (($162) + 4|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)<(0);
 $197 = $195 ^ -1;
 $198 = $195 | -2147483648;
 $$0$i$i1$i = $196 ? $197 : $198;
 $199 = (($$0$i$i1$i) + 16)|0;
 $200 = $199 & -16;
 $201 = $200 | 1;
 $202 = ((($bounds) + (($161*24)|0)|0) + 16|0);
 HEAP32[$202>>2] = $201;
 $203 = (($162) + 8|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = ($204|0)<(0);
 $206 = $204 ^ -1;
 $207 = $204 | -2147483648;
 $$0$i$i$i = $205 ? $206 : $207;
 $208 = (($$0$i$i$i) + 16)|0;
 $209 = $208 & -16;
 $210 = $209 | 1;
 $211 = ((($bounds) + (($161*24)|0)|0) + 20|0);
 HEAP32[$211>>2] = $210;
 $212 = (~~(($159))>>>0);
 STACKTOP = sp;return ($212|0);
}
function __ZN5physx20updateBodyShapeAABBsEPKjjS1_PKNS_17PxcAABBDataStaticEPNS_11IntegerAABBEj($updatedAABBHandles,$numUPdatedAABBHandles,$aabbDataHandles,$aabbData,$bounds,$0) {
 $updatedAABBHandles = $updatedAABBHandles|0;
 $numUPdatedAABBHandles = $numUPdatedAABBHandles|0;
 $aabbDataHandles = $aabbDataHandles|0;
 $aabbData = $aabbData|0;
 $bounds = $bounds|0;
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i12 = 0, $$0$i$i$i6 = 0, $$0$i$i1$i = 0, $$0$i$i1$i11 = 0, $$0$i$i1$i5 = 0, $$0$i$i2$i = 0, $$0$i$i2$i10 = 0, $$0$i$i2$i4 = 0, $$0$i$i3$i = 0, $$0$i$i3$i3 = 0, $$0$i$i3$i9 = 0, $$0$i$i4$i = 0, $$0$i$i4$i2 = 0, $$0$i$i4$i8 = 0, $$0$i$i5$i = 0, $$0$i$i5$i1 = 0, $$0$i$i5$i7 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond23 = 0, $i$019 = 0, $i1$013 = 0, $j$017 = 0, $nextAABBData$0$lcssa = 0, $nextAABBData$020 = 0, $nextAABBData$118 = 0, $nextAABBData$2$lcssa = 0;
 var $nextAABBData$214 = 0, $updatedBodyShapeBounds = 0, $updatedBodyShapeBounds4 = 0, $updatedBodyShapeBounds6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $updatedBodyShapeBounds = sp + 48|0;
 $updatedBodyShapeBounds4 = sp;
 $updatedBodyShapeBounds6 = sp + 24|0;
 $1 = HEAP32[$updatedAABBHandles>>2]|0;
 $2 = (($aabbDataHandles) + ($1<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($aabbData) + ($3<<3)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($aabbData) + ($3<<3)|0) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $numUPdatedAABBHandles & 3;
 $9 = ($8|0)!=(0);
 $10 = $numUPdatedAABBHandles & -4;
 $11 = (($numUPdatedAABBHandles) + -4)|0;
 $12 = $9 ? $10 : $11;
 $13 = ($12|0)==(0);
 if ($13) {
  $nextAABBData$0$lcssa = $4;
 } else {
  $14 = (($updatedBodyShapeBounds) + 12|0);
  $15 = (($updatedBodyShapeBounds) + 4|0);
  $16 = (($updatedBodyShapeBounds) + 8|0);
  $17 = (($14) + 4|0);
  $18 = (($14) + 8|0);
  $i$019 = 0;$nextAABBData$020 = $4;
  while(1) {
   $j$017 = 0;$nextAABBData$118 = $nextAABBData$020;
   while(1) {
    $26 = (($j$017) + ($i$019))|0;
    $27 = (($26) + 1)|0;
    $28 = (($updatedAABBHandles) + ($27<<2)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($aabbDataHandles) + ($29<<2)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($aabbData) + ($31<<3)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ((($aabbData) + ($31<<3)|0) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    __ZN5physx14PxsComputeAABBERKNS_17PxcAABBDataStaticERNS_9PxBounds3E($nextAABBData$118,$updatedBodyShapeBounds);
    $36 = (($updatedAABBHandles) + ($26<<2)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$updatedBodyShapeBounds>>2]|0;
    $39 = ($38|0)<(0);
    $40 = $38 ^ -1;
    $41 = $38 | -2147483648;
    $$0$i$i5$i7 = $39 ? $40 : $41;
    $42 = (($$0$i$i5$i7) + -16)|0;
    $43 = $42 & -16;
    $44 = (($bounds) + (($37*24)|0)|0);
    HEAP32[$44>>2] = $43;
    $45 = HEAP32[$15>>2]|0;
    $46 = ($45|0)<(0);
    $47 = $45 ^ -1;
    $48 = $45 | -2147483648;
    $$0$i$i4$i8 = $46 ? $47 : $48;
    $49 = (($$0$i$i4$i8) + -16)|0;
    $50 = $49 & -16;
    $51 = ((($bounds) + (($37*24)|0)|0) + 4|0);
    HEAP32[$51>>2] = $50;
    $52 = HEAP32[$16>>2]|0;
    $53 = ($52|0)<(0);
    $54 = $52 ^ -1;
    $55 = $52 | -2147483648;
    $$0$i$i3$i9 = $53 ? $54 : $55;
    $56 = (($$0$i$i3$i9) + -16)|0;
    $57 = $56 & -16;
    $58 = ((($bounds) + (($37*24)|0)|0) + 8|0);
    HEAP32[$58>>2] = $57;
    $59 = HEAP32[$14>>2]|0;
    $60 = ($59|0)<(0);
    $61 = $59 ^ -1;
    $62 = $59 | -2147483648;
    $$0$i$i2$i10 = $60 ? $61 : $62;
    $63 = (($$0$i$i2$i10) + 16)|0;
    $64 = $63 & -16;
    $65 = $64 | 1;
    $66 = ((($bounds) + (($37*24)|0)|0) + 12|0);
    HEAP32[$66>>2] = $65;
    $67 = HEAP32[$17>>2]|0;
    $68 = ($67|0)<(0);
    $69 = $67 ^ -1;
    $70 = $67 | -2147483648;
    $$0$i$i1$i11 = $68 ? $69 : $70;
    $71 = (($$0$i$i1$i11) + 16)|0;
    $72 = $71 & -16;
    $73 = $72 | 1;
    $74 = ((($bounds) + (($37*24)|0)|0) + 16|0);
    HEAP32[$74>>2] = $73;
    $75 = HEAP32[$18>>2]|0;
    $76 = ($75|0)<(0);
    $77 = $75 ^ -1;
    $78 = $75 | -2147483648;
    $$0$i$i$i12 = $76 ? $77 : $78;
    $79 = (($$0$i$i$i12) + 16)|0;
    $80 = $79 & -16;
    $81 = $80 | 1;
    $82 = ((($bounds) + (($37*24)|0)|0) + 20|0);
    HEAP32[$82>>2] = $81;
    $83 = (($j$017) + 1)|0;
    $exitcond23 = ($83|0)==(4);
    if ($exitcond23) {
     break;
    } else {
     $j$017 = $83;$nextAABBData$118 = $32;
    }
   }
   $84 = (($i$019) + 4)|0;
   $85 = ($84>>>0)<($12>>>0);
   if ($85) {
    $i$019 = $84;$nextAABBData$020 = $32;
   } else {
    $nextAABBData$0$lcssa = $32;
    break;
   }
  }
 }
 $19 = (($numUPdatedAABBHandles) + -1)|0;
 $20 = ($12>>>0)<($19>>>0);
 if ($20) {
  $21 = (($updatedBodyShapeBounds4) + 12|0);
  $22 = (($updatedBodyShapeBounds4) + 4|0);
  $23 = (($updatedBodyShapeBounds4) + 8|0);
  $24 = (($21) + 4|0);
  $25 = (($21) + 8|0);
  $i1$013 = $12;$nextAABBData$214 = $nextAABBData$0$lcssa;
  while(1) {
   $86 = (($i1$013) + 1)|0;
   $87 = (($updatedAABBHandles) + ($86<<2)|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($aabbDataHandles) + ($88<<2)|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($aabbData) + ($90<<3)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ((($aabbData) + ($90<<3)|0) + 4|0);
   $94 = HEAP32[$93>>2]|0;
   __ZN5physx14PxsComputeAABBERKNS_17PxcAABBDataStaticERNS_9PxBounds3E($nextAABBData$214,$updatedBodyShapeBounds4);
   $95 = (($updatedAABBHandles) + ($i1$013<<2)|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = HEAP32[$updatedBodyShapeBounds4>>2]|0;
   $98 = ($97|0)<(0);
   $99 = $97 ^ -1;
   $100 = $97 | -2147483648;
   $$0$i$i5$i1 = $98 ? $99 : $100;
   $101 = (($$0$i$i5$i1) + -16)|0;
   $102 = $101 & -16;
   $103 = (($bounds) + (($96*24)|0)|0);
   HEAP32[$103>>2] = $102;
   $104 = HEAP32[$22>>2]|0;
   $105 = ($104|0)<(0);
   $106 = $104 ^ -1;
   $107 = $104 | -2147483648;
   $$0$i$i4$i2 = $105 ? $106 : $107;
   $108 = (($$0$i$i4$i2) + -16)|0;
   $109 = $108 & -16;
   $110 = ((($bounds) + (($96*24)|0)|0) + 4|0);
   HEAP32[$110>>2] = $109;
   $111 = HEAP32[$23>>2]|0;
   $112 = ($111|0)<(0);
   $113 = $111 ^ -1;
   $114 = $111 | -2147483648;
   $$0$i$i3$i3 = $112 ? $113 : $114;
   $115 = (($$0$i$i3$i3) + -16)|0;
   $116 = $115 & -16;
   $117 = ((($bounds) + (($96*24)|0)|0) + 8|0);
   HEAP32[$117>>2] = $116;
   $118 = HEAP32[$21>>2]|0;
   $119 = ($118|0)<(0);
   $120 = $118 ^ -1;
   $121 = $118 | -2147483648;
   $$0$i$i2$i4 = $119 ? $120 : $121;
   $122 = (($$0$i$i2$i4) + 16)|0;
   $123 = $122 & -16;
   $124 = $123 | 1;
   $125 = ((($bounds) + (($96*24)|0)|0) + 12|0);
   HEAP32[$125>>2] = $124;
   $126 = HEAP32[$24>>2]|0;
   $127 = ($126|0)<(0);
   $128 = $126 ^ -1;
   $129 = $126 | -2147483648;
   $$0$i$i1$i5 = $127 ? $128 : $129;
   $130 = (($$0$i$i1$i5) + 16)|0;
   $131 = $130 & -16;
   $132 = $131 | 1;
   $133 = ((($bounds) + (($96*24)|0)|0) + 16|0);
   HEAP32[$133>>2] = $132;
   $134 = HEAP32[$25>>2]|0;
   $135 = ($134|0)<(0);
   $136 = $134 ^ -1;
   $137 = $134 | -2147483648;
   $$0$i$i$i6 = $135 ? $136 : $137;
   $138 = (($$0$i$i$i6) + 16)|0;
   $139 = $138 & -16;
   $140 = $139 | 1;
   $141 = ((($bounds) + (($96*24)|0)|0) + 20|0);
   HEAP32[$141>>2] = $140;
   $exitcond = ($86|0)==($19|0);
   if ($exitcond) {
    $nextAABBData$2$lcssa = $91;
    break;
   } else {
    $i1$013 = $86;$nextAABBData$214 = $91;
   }
  }
 } else {
  $nextAABBData$2$lcssa = $nextAABBData$0$lcssa;
 }
 __ZN5physx14PxsComputeAABBERKNS_17PxcAABBDataStaticERNS_9PxBounds3E($nextAABBData$2$lcssa,$updatedBodyShapeBounds6);
 $142 = (($updatedAABBHandles) + ($19<<2)|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = (($updatedBodyShapeBounds6) + 12|0);
 $145 = HEAP32[$updatedBodyShapeBounds6>>2]|0;
 $146 = ($145|0)<(0);
 $147 = $145 ^ -1;
 $148 = $145 | -2147483648;
 $$0$i$i5$i = $146 ? $147 : $148;
 $149 = (($$0$i$i5$i) + -16)|0;
 $150 = $149 & -16;
 $151 = (($bounds) + (($143*24)|0)|0);
 HEAP32[$151>>2] = $150;
 $152 = (($updatedBodyShapeBounds6) + 4|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = ($153|0)<(0);
 $155 = $153 ^ -1;
 $156 = $153 | -2147483648;
 $$0$i$i4$i = $154 ? $155 : $156;
 $157 = (($$0$i$i4$i) + -16)|0;
 $158 = $157 & -16;
 $159 = ((($bounds) + (($143*24)|0)|0) + 4|0);
 HEAP32[$159>>2] = $158;
 $160 = (($updatedBodyShapeBounds6) + 8|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = ($161|0)<(0);
 $163 = $161 ^ -1;
 $164 = $161 | -2147483648;
 $$0$i$i3$i = $162 ? $163 : $164;
 $165 = (($$0$i$i3$i) + -16)|0;
 $166 = $165 & -16;
 $167 = ((($bounds) + (($143*24)|0)|0) + 8|0);
 HEAP32[$167>>2] = $166;
 $168 = HEAP32[$144>>2]|0;
 $169 = ($168|0)<(0);
 $170 = $168 ^ -1;
 $171 = $168 | -2147483648;
 $$0$i$i2$i = $169 ? $170 : $171;
 $172 = (($$0$i$i2$i) + 16)|0;
 $173 = $172 & -16;
 $174 = $173 | 1;
 $175 = ((($bounds) + (($143*24)|0)|0) + 12|0);
 HEAP32[$175>>2] = $174;
 $176 = (($144) + 4|0);
 $177 = HEAP32[$176>>2]|0;
 $178 = ($177|0)<(0);
 $179 = $177 ^ -1;
 $180 = $177 | -2147483648;
 $$0$i$i1$i = $178 ? $179 : $180;
 $181 = (($$0$i$i1$i) + 16)|0;
 $182 = $181 & -16;
 $183 = $182 | 1;
 $184 = ((($bounds) + (($143*24)|0)|0) + 16|0);
 HEAP32[$184>>2] = $183;
 $185 = (($144) + 8|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = ($186|0)<(0);
 $188 = $186 ^ -1;
 $189 = $186 | -2147483648;
 $$0$i$i$i = $187 ? $188 : $189;
 $190 = (($$0$i$i$i) + 16)|0;
 $191 = $190 & -16;
 $192 = $191 | 1;
 $193 = ((($bounds) + (($143*24)|0)|0) + 20|0);
 HEAP32[$193>>2] = $192;
 STACKTOP = sp;return;
}
function __ZN5physx20SingleAABBUpdateTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_aabbDataHandles = 0, $_bounds = 0, $_boundsCapacities = 0, $_counts = 0, $_dynamicAABBData = 0, $_groups = 0, $_starts = 0, $_staticAABBData = 0, $_updatedElemIds = 0, $exitcond = 0, $exitcond21 = 0, $i$011 = 0, $k$015 = 0, $numFastMovingShapes$0$lcssa = 0, $numFastMovingShapes$016 = 0, $numFastMovingShapes$112 = 0, $numFastMovingShapes$2 = 0, $numFastMovingShapes$3 = 0, $updateTypeCount$0 = 0, $updateTypeCount$122 = 0;
 var $updatedElemIdDynamics = 0, $updatedElemIdStatics = 0, $updatedElemIdsDynamicSize$09 = 0, $updatedElemIdsDynamicSize$1 = 0, $updatedElemIdsStaticSize$010 = 0, $updatedElemIdsStaticSize$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16464|0;
 $updatedElemIdStatics = sp + 72|0;
 $updatedElemIdDynamics = sp + 8264|0;
 $_updatedElemIds = sp + 64|0;
 $_groups = sp + 56|0;
 $_aabbDataHandles = sp + 48|0;
 $_staticAABBData = sp + 40|0;
 $_dynamicAABBData = sp + 24|0;
 $_bounds = sp + 16|0;
 $_boundsCapacities = sp + 8|0;
 $_starts = sp;
 $_counts = sp + 32|0;
 $0 = $_updatedElemIds;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = $_groups;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = $_aabbDataHandles;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 $12 = $_staticAABBData;
 $13 = $12;
 HEAP32[$13>>2] = 0;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = 0;
 $16 = $_dynamicAABBData;
 $17 = $16;
 HEAP32[$17>>2] = 0;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = 0;
 $20 = $_bounds;
 $21 = $20;
 HEAP32[$21>>2] = 0;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 $24 = $_boundsCapacities;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 $28 = $_starts;
 $29 = $28;
 HEAP32[$29>>2] = 0;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = 0;
 $32 = $_counts;
 $33 = $32;
 HEAP32[$33>>2] = 0;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 44|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 1;
 $39 = ($38|0)==(0);
 if ($39) {
  $updateTypeCount$0 = 0;
 } else {
  $40 = (($this) + 20|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 16900|0);
  $43 = HEAP32[$42>>2]|0;
  HEAP32[$_updatedElemIds>>2] = $43;
  $44 = (($41) + 20|0);
  $45 = HEAP32[$44>>2]|0;
  HEAP32[$_groups>>2] = $45;
  $46 = (($41) + 32|0);
  $47 = HEAP32[$46>>2]|0;
  HEAP32[$_aabbDataHandles>>2] = $47;
  $48 = (($41) + 44|0);
  $49 = HEAP32[$48>>2]|0;
  HEAP32[$_staticAABBData>>2] = $49;
  $50 = (($41) + 56|0);
  $51 = HEAP32[$50>>2]|0;
  HEAP32[$_dynamicAABBData>>2] = $51;
  $52 = (($41) + 12|0);
  $53 = HEAP32[$52>>2]|0;
  HEAP32[$_bounds>>2] = $53;
  $54 = (($41) + 36|0);
  $55 = HEAP32[$54>>2]|0;
  HEAP32[$_boundsCapacities>>2] = $55;
  $56 = (($this) + 48|0);
  $57 = HEAP32[$56>>2]|0;
  HEAP32[$_starts>>2] = $57;
  $58 = (($this) + 52|0);
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$_counts>>2] = $59;
  $updateTypeCount$0 = 1;
 }
 $60 = $37 & 2;
 $61 = ($60|0)==(0);
 if ($61) {
  $92 = ($updateTypeCount$0|0)==(0);
  if ($92) {
   $numFastMovingShapes$0$lcssa = 0;
   $137 = (($this) + 64|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = (($138) + ($numFastMovingShapes$0$lcssa))|0;
   HEAP32[$137>>2] = $139;
   STACKTOP = sp;return;
  } else {
   $updateTypeCount$122 = 1;
  }
 } else {
  $62 = (($this) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($63) + 33316|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($_updatedElemIds) + ($updateTypeCount$0<<2)|0);
  HEAP32[$66>>2] = $65;
  $67 = (($63) + 308|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($_groups) + ($updateTypeCount$0<<2)|0);
  HEAP32[$69>>2] = $68;
  $70 = (($63) + 320|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($_aabbDataHandles) + ($updateTypeCount$0<<2)|0);
  HEAP32[$72>>2] = $71;
  $73 = (($63) + 332|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($_staticAABBData) + ($updateTypeCount$0<<2)|0);
  HEAP32[$75>>2] = $74;
  $76 = (($63) + 344|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($_dynamicAABBData) + ($updateTypeCount$0<<2)|0);
  HEAP32[$78>>2] = $77;
  $79 = (($63) + 300|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($_bounds) + ($updateTypeCount$0<<2)|0);
  HEAP32[$81>>2] = $80;
  $82 = (($63) + 324|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($_boundsCapacities) + ($updateTypeCount$0<<2)|0);
  HEAP32[$84>>2] = $83;
  $85 = (($this) + 56|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (($_starts) + ($updateTypeCount$0<<2)|0);
  HEAP32[$87>>2] = $86;
  $88 = (($this) + 60|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (($_counts) + ($updateTypeCount$0<<2)|0);
  HEAP32[$90>>2] = $89;
  $91 = (($updateTypeCount$0) + 1)|0;
  $updateTypeCount$122 = $91;
 }
 $93 = (($this) + 36|0);
 $k$015 = 0;$numFastMovingShapes$016 = 0;
 while(1) {
  $94 = (($_updatedElemIds) + ($k$015<<2)|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($_groups) + ($k$015<<2)|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($_aabbDataHandles) + ($k$015<<2)|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = (($_staticAABBData) + ($k$015<<2)|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (($_dynamicAABBData) + ($k$015<<2)|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (($_bounds) + ($k$015<<2)|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($_boundsCapacities) + ($k$015<<2)|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($_starts) + ($k$015<<2)|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($_counts) + ($k$015<<2)|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = (($111) + ($109))|0;
  $113 = ($109>>>0)<($112>>>0);
  if ($113) {
   $i$011 = $109;$numFastMovingShapes$112 = $numFastMovingShapes$016;$updatedElemIdsDynamicSize$09 = 0;$updatedElemIdsStaticSize$010 = 0;
   while(1) {
    $114 = (($95) + ($i$011<<2)|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = (($97) + ($115<<2)|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ($117|0)==(0);
    if ($118) {
     $119 = (($updatedElemIdStatics) + ($updatedElemIdsStaticSize$010<<2)|0);
     HEAP32[$119>>2] = $115;
     $120 = (($updatedElemIdsStaticSize$010) + 1)|0;
     $121 = ($120|0)==(2048);
     if ($121) {
      __ZN5physx20updateBodyShapeAABBsEPKjjS1_PKNS_17PxcAABBDataStaticEPNS_11IntegerAABBEj($updatedElemIdStatics,2048,$99,$101,$105,$107);
      $numFastMovingShapes$2 = $numFastMovingShapes$112;$updatedElemIdsDynamicSize$1 = $updatedElemIdsDynamicSize$09;$updatedElemIdsStaticSize$1 = 0;
     } else {
      $numFastMovingShapes$2 = $numFastMovingShapes$112;$updatedElemIdsDynamicSize$1 = $updatedElemIdsDynamicSize$09;$updatedElemIdsStaticSize$1 = $120;
     }
    } else {
     $122 = (($updatedElemIdDynamics) + ($updatedElemIdsDynamicSize$09<<2)|0);
     HEAP32[$122>>2] = $115;
     $123 = (($updatedElemIdsDynamicSize$09) + 1)|0;
     $124 = ($123|0)==(2048);
     if ($124) {
      $125 = HEAP8[$93>>0]|0;
      $126 = ($125<<24>>24)!=(0);
      $127 = (__ZN5physx20updateBodyShapeAABBsEPKjjS1_PKNS_18PxcAABBDataDynamicEbPNS_11IntegerAABBEj($updatedElemIdDynamics,2048,$99,$103,$126,$105,$107)|0);
      $128 = (($127) + ($numFastMovingShapes$112))|0;
      $numFastMovingShapes$2 = $128;$updatedElemIdsDynamicSize$1 = 0;$updatedElemIdsStaticSize$1 = $updatedElemIdsStaticSize$010;
     } else {
      $numFastMovingShapes$2 = $numFastMovingShapes$112;$updatedElemIdsDynamicSize$1 = $123;$updatedElemIdsStaticSize$1 = $updatedElemIdsStaticSize$010;
     }
    }
    $129 = (($i$011) + 1)|0;
    $exitcond = ($129|0)==($112|0);
    if ($exitcond) {
     break;
    } else {
     $i$011 = $129;$numFastMovingShapes$112 = $numFastMovingShapes$2;$updatedElemIdsDynamicSize$09 = $updatedElemIdsDynamicSize$1;$updatedElemIdsStaticSize$010 = $updatedElemIdsStaticSize$1;
    }
   }
   $130 = ($updatedElemIdsStaticSize$1|0)==(0);
   if (!($130)) {
    __ZN5physx20updateBodyShapeAABBsEPKjjS1_PKNS_17PxcAABBDataStaticEPNS_11IntegerAABBEj($updatedElemIdStatics,$updatedElemIdsStaticSize$1,$99,$101,$105,$107);
   }
   $131 = ($updatedElemIdsDynamicSize$1|0)==(0);
   if ($131) {
    $numFastMovingShapes$3 = $numFastMovingShapes$2;
   } else {
    $132 = HEAP8[$93>>0]|0;
    $133 = ($132<<24>>24)!=(0);
    $134 = (__ZN5physx20updateBodyShapeAABBsEPKjjS1_PKNS_18PxcAABBDataDynamicEbPNS_11IntegerAABBEj($updatedElemIdDynamics,$updatedElemIdsDynamicSize$1,$99,$103,$133,$105,$107)|0);
    $135 = (($134) + ($numFastMovingShapes$2))|0;
    $numFastMovingShapes$3 = $135;
   }
  } else {
   $numFastMovingShapes$3 = $numFastMovingShapes$016;
  }
  $136 = (($k$015) + 1)|0;
  $exitcond21 = ($136|0)==($updateTypeCount$122|0);
  if ($exitcond21) {
   $numFastMovingShapes$0$lcssa = $numFastMovingShapes$3;
   break;
  } else {
   $k$015 = $136;$numFastMovingShapes$016 = $numFastMovingShapes$3;
  }
 }
 $137 = (($this) + 64|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = (($138) + ($numFastMovingShapes$0$lcssa))|0;
 HEAP32[$137>>2] = $139;
 STACKTOP = sp;return;
}
function __ZN5physx19ActorAABBUpdateTask11runInternalEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert15 = 0, $$pre = 0, $$pre11 = 0, $$pre14 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $actorIds = 0, $exitcond = 0, $exitcond10 = 0, $i$06 = 0;
 var $j$04 = 0, $localSpaceBounds = 0, $numShapes$02 = 0, $numShapes$1 = 0, $shapeId$0 = 0, $shapeId$01 = 0, $shapeId$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3584|0;
 $actorIds = sp + 3072|0;
 $localSpaceBounds = sp;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 $5 = ($1>>>0)<($4>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 24|0);
 $7 = (($this) + 20|0);
 $8 = (($this) + 28|0);
 $$pre = HEAP32[$7>>2]|0;
 $107 = $$pre;$13 = $$pre;$i$06 = $1;
 while(1) {
  $9 = HEAP32[$6>>2]|0;
  $10 = (($9) + ($i$06<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($13) + 180|0);
  $14 = HEAP32[$12>>2]|0;
  $15 = ((($14) + (($11*1048)|0)|0) + 1032|0);
  $shapeId$01 = HEAP32[$15>>2]|0;
  $16 = ($shapeId$01|0)==(1073741823);
  if ($16) {
   $108 = $13;$109 = $107;
  } else {
   $18 = $107;$numShapes$02 = 0;$shapeId$03 = $shapeId$01;
   while(1) {
    $17 = (($18) + 312|0);
    $19 = HEAP32[$17>>2]|0;
    $20 = (($19) + ($shapeId$03<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 >>> 1;
    $23 = HEAP32[$8>>2]|0;
    $24 = $21 >>> 6;
    $25 = HEAP32[$23>>2]|0;
    $26 = (($25) + ($24<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = $22 & 31;
    $29 = 1 << $28;
    $30 = $27 & $29;
    $31 = ($30|0)==(0);
    if ($31) {
     $60 = $18;$numShapes$1 = $numShapes$02;
    } else {
     $32 = (($18) + 248|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($33) + (($22*24)|0)|0);
     HEAPF32[$34>>2] = Math_fround(8.50705866596322149529E+37);
     $35 = ((($33) + (($22*24)|0)|0) + 4|0);
     HEAPF32[$35>>2] = Math_fround(8.50705866596322149529E+37);
     $36 = ((($33) + (($22*24)|0)|0) + 8|0);
     HEAPF32[$36>>2] = Math_fround(8.50705866596322149529E+37);
     $37 = ((($33) + (($22*24)|0)|0) + 12|0);
     HEAPF32[$37>>2] = Math_fround(-8.50705866596322149529E+37);
     $38 = ((($33) + (($22*24)|0)|0) + 16|0);
     HEAPF32[$38>>2] = Math_fround(-8.50705866596322149529E+37);
     $39 = ((($33) + (($22*24)|0)|0) + 20|0);
     HEAPF32[$39>>2] = Math_fround(-8.50705866596322149529E+37);
     $40 = (($18) + 308|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + ($shapeId$03<<2)|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(1073741823);
     if ($44) {
      $60 = $18;$numShapes$1 = $numShapes$02;
     } else {
      $45 = (($actorIds) + ($numShapes$02<<2)|0);
      HEAP32[$45>>2] = $22;
      $46 = ($43|0)==(0);
      $$phi$trans$insert = (($18) + 320|0);
      $$pre14 = HEAP32[$$phi$trans$insert>>2]|0;
      $$phi$trans$insert15 = (($$pre14) + ($shapeId$03<<2)|0);
      $$pre16 = HEAP32[$$phi$trans$insert15>>2]|0;
      if ($46) {
       label = 8;
      } else {
       $47 = (($18) + 344|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ((($48) + ($$pre16<<4)|0) + 4|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)==(0|0);
       if ($51) {
        label = 8;
       } else {
        $56 = (($48) + ($$pre16<<4)|0);
        $57 = (($localSpaceBounds) + (($numShapes$02*24)|0)|0);
        __ZN5physx24PxsComputeAABBLocalSpaceERKNS_18PxcAABBDataDynamicERNS_9PxBounds3E($56,$57);
       }
      }
      if ((label|0) == 8) {
       label = 0;
       $52 = (($18) + 332|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (($53) + ($$pre16<<3)|0);
       $55 = (($localSpaceBounds) + (($numShapes$02*24)|0)|0);
       __ZN5physx24PxsComputeAABBLocalSpaceERKNS_17PxcAABBDataStaticERNS_9PxBounds3E($54,$55);
      }
      $58 = (($numShapes$02) + 1)|0;
      $$pre11 = HEAP32[$7>>2]|0;
      $60 = $$pre11;$numShapes$1 = $58;
     }
    }
    $59 = (($60) + 316|0);
    $61 = HEAP32[$59>>2]|0;
    $62 = (($61) + ($shapeId$03<<2)|0);
    $shapeId$0 = HEAP32[$62>>2]|0;
    $63 = ($shapeId$0|0)==(1073741823);
    if ($63) {
     break;
    } else {
     $18 = $60;$numShapes$02 = $numShapes$1;$shapeId$03 = $shapeId$0;
    }
   }
   $64 = ($numShapes$1|0)==(0);
   if ($64) {
    $108 = $60;$109 = $60;
   } else {
    $65 = (($60) + 248|0);
    $66 = HEAP32[$65>>2]|0;
    $j$04 = 0;
    while(1) {
     $67 = (($actorIds) + ($j$04<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($66) + (($68*24)|0)|0);
     $70 = Math_fround(HEAPF32[$69>>2]);
     $71 = (($localSpaceBounds) + (($j$04*24)|0)|0);
     $72 = Math_fround(HEAPF32[$71>>2]);
     $73 = $70 < $72;
     $74 = $73 ? $70 : $72;
     $75 = ((($66) + (($68*24)|0)|0) + 4|0);
     $76 = Math_fround(HEAPF32[$75>>2]);
     $77 = ((($localSpaceBounds) + (($j$04*24)|0)|0) + 4|0);
     $78 = Math_fround(HEAPF32[$77>>2]);
     $79 = $76 < $78;
     $80 = $79 ? $76 : $78;
     $81 = ((($66) + (($68*24)|0)|0) + 8|0);
     $82 = Math_fround(HEAPF32[$81>>2]);
     $83 = ((($localSpaceBounds) + (($j$04*24)|0)|0) + 8|0);
     $84 = Math_fround(HEAPF32[$83>>2]);
     $85 = $82 < $84;
     $86 = $85 ? $82 : $84;
     HEAPF32[$69>>2] = $74;
     HEAPF32[$75>>2] = $80;
     HEAPF32[$81>>2] = $86;
     $87 = ((($66) + (($68*24)|0)|0) + 12|0);
     $88 = Math_fround(HEAPF32[$87>>2]);
     $89 = ((($localSpaceBounds) + (($j$04*24)|0)|0) + 12|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     $91 = $88 > $90;
     $92 = $91 ? $88 : $90;
     $93 = ((($66) + (($68*24)|0)|0) + 16|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = ((($localSpaceBounds) + (($j$04*24)|0)|0) + 16|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $97 = $94 > $96;
     $98 = $97 ? $94 : $96;
     $99 = ((($66) + (($68*24)|0)|0) + 20|0);
     $100 = Math_fround(HEAPF32[$99>>2]);
     $101 = ((($localSpaceBounds) + (($j$04*24)|0)|0) + 20|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = $100 > $102;
     $104 = $103 ? $100 : $102;
     HEAPF32[$87>>2] = $92;
     HEAPF32[$93>>2] = $98;
     HEAPF32[$99>>2] = $104;
     $105 = (($j$04) + 1)|0;
     $exitcond = ($105|0)==($numShapes$1|0);
     if ($exitcond) {
      $108 = $60;$109 = $60;
      break;
     } else {
      $j$04 = $105;
     }
    }
   }
  }
  $106 = (($i$06) + 1)|0;
  $exitcond10 = ($106|0)==($4|0);
  if ($exitcond10) {
   break;
  } else {
   $107 = $109;$13 = $108;$i$06 = $106;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23AggregateAABBUpdateTask11runInternalEv($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i6 = 0, $$0$i$i1$i = 0, $$0$i$i1$i5 = 0, $$0$i$i2$i = 0, $$0$i$i2$i4 = 0, $$0$i$i3$i = 0, $$0$i$i3$i3 = 0, $$0$i$i4$i = 0, $$0$i$i4$i2 = 0, $$0$i$i5$i = 0, $$0$i$i5$i1 = 0, $$lcssa = 0, $$lcssa10 = 0, $$lcssa11 = 0, $$lcssa24 = 0, $$lcssa25 = 0, $$lcssa26 = 0, $$lcssa27 = 0, $$lcssa28 = 0;
 var $$lcssa29 = 0, $$lcssa7 = 0, $$lcssa8 = 0, $$lcssa9 = 0, $$phi$trans$insert = 0, $$phi$trans$insert64 = 0, $$phi$trans$insert66 = 0, $$pre = 0, $$pre62 = 0, $$pre63 = 0, $$pre65 = 0, $$pre67 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0);
 var $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0;
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $actorId3$0 = 0, $actorId3$030 = 0, $actorId3$032 = 0, $elemId$0 = 0, $elemId$012 = 0;
 var $elemId$013 = 0, $elemId1$0 = 0, $elemId1$019 = 0, $elemId1$020 = 0, $exitcond = 0, $i$043 = 0, $numFastMovingShapes$044 = Math_fround(0), $numFastMovingShapes$1$lcssa = Math_fround(0), $numFastMovingShapes$131 = Math_fround(0), $numFastMovingShapes$2 = Math_fround(0), $numFastMovingShapes$3 = Math_fround(0), $numFastMovingShapes$4 = Math_fround(0), $numFastMovingShapes$5 = Math_fround(0), $worldSpaceActorBounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $worldSpaceActorBounds = sp;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $numFastMovingShapes$5 = Math_fround(0.0);
  $269 = (~~(($numFastMovingShapes$5))>>>0);
  $270 = (($this) + 56|0);
  HEAP32[$270>>2] = $269;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 368|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($4) + 300|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($1))|0;
 $14 = ($12>>>0)<($13>>>0);
 if (!($14)) {
  $numFastMovingShapes$5 = Math_fround(0.0);
  $269 = (~~(($numFastMovingShapes$5))>>>0);
  $270 = (($this) + 56|0);
  HEAP32[$270>>2] = $269;
  STACKTOP = sp;return;
 }
 $15 = (($this) + 44|0);
 $16 = (($worldSpaceActorBounds) + 12|0);
 $17 = (($worldSpaceActorBounds) + 4|0);
 $18 = (($worldSpaceActorBounds) + 8|0);
 $19 = (($16) + 4|0);
 $20 = (($16) + 8|0);
 $21 = (($worldSpaceActorBounds) + 16|0);
 $22 = (($worldSpaceActorBounds) + 20|0);
 $23 = (($this) + 36|0);
 $27 = $4;$i$043 = $12;$numFastMovingShapes$044 = Math_fround(0.0);
 while(1) {
  $24 = (($6) + ($i$043<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($27) + 180|0);
  $28 = HEAP32[$26>>2]|0;
  $29 = ((($28) + (($25*1048)|0)|0) + 1024|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $32 = $25 >>> 5;
   $33 = (($27) + 232|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + ($32<<2)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = $25 & 31;
   $38 = 1 << $37;
   $39 = $36 & $38;
   $40 = ($39|0)==(0);
   if ($40) {
    $90 = ((($28) + (($25*1048)|0)|0) + 1032|0);
    $elemId1$019 = HEAP32[$90>>2]|0;
    $91 = ($elemId1$019|0)==(1073741823);
    if (!($91)) {
     $$phi$trans$insert66 = (($27) + 308|0);
     $$pre67 = HEAP32[$$phi$trans$insert66>>2]|0;
     $elemId1$020 = $elemId1$019;
     while(1) {
      $92 = (($$pre67) + ($elemId1$020<<2)|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = ($93|0)==(1073741823);
      if (!($94)) {
       $95 = (($27) + 312|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = (($96) + ($elemId1$020<<2)|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = $98 >>> 1;
       $100 = HEAP32[$15>>2]|0;
       $101 = (($100) + ($99<<2)|0);
       HEAP32[$101>>2] = $elemId1$020;
      }
      $102 = (($27) + 316|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = (($103) + ($elemId1$020<<2)|0);
      $elemId1$0 = HEAP32[$104>>2]|0;
      $105 = ($elemId1$0|0)==(1073741823);
      if ($105) {
       break;
      } else {
       $elemId1$020 = $elemId1$0;
      }
     }
    }
    $106 = ((($28) + (($25*1048)|0)|0) + 1040|0);
    $actorId3$030 = HEAP32[$106>>2]|0;
    $107 = ($actorId3$030|0)==(1073741823);
    if ($107) {
     $$lcssa24 = -25165825;$$lcssa25 = -25165825;$$lcssa26 = -25165825;$$lcssa27 = 2122317823;$$lcssa28 = 2122317823;$$lcssa29 = 2122317823;$numFastMovingShapes$1$lcssa = $numFastMovingShapes$044;
    } else {
     $109 = $27;$187 = 2122317823;$192 = 2122317823;$197 = 2122317823;$205 = -25165825;$210 = -25165825;$215 = -25165825;$actorId3$032 = $actorId3$030;$numFastMovingShapes$131 = $numFastMovingShapes$044;
     while(1) {
      $108 = (($109) + 252|0);
      $110 = HEAP32[$108>>2]|0;
      $111 = (($110) + ($actorId3$032)|0);
      $112 = HEAP8[$111>>0]|0;
      $113 = ($112<<24>>24)==(0);
      if ($113) {
       $223 = $109;$277 = $215;$278 = $210;$279 = $205;$280 = $197;$281 = $192;$282 = $187;$numFastMovingShapes$3 = $numFastMovingShapes$131;
      } else {
       $114 = (($109) + 248|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = (($115) + (($actorId3$032*24)|0)|0);
       $117 = HEAP32[$15>>2]|0;
       $118 = (($117) + ($actorId3$032<<2)|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = (($109) + 308|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = (($121) + ($119<<2)|0);
       $123 = HEAP32[$122>>2]|0;
       $124 = ($123|0)==(0);
       $$phi$trans$insert = (($109) + 320|0);
       $$pre63 = HEAP32[$$phi$trans$insert>>2]|0;
       $$phi$trans$insert64 = (($$pre63) + ($119<<2)|0);
       $$pre65 = HEAP32[$$phi$trans$insert64>>2]|0;
       if ($124) {
        label = 21;
       } else {
        $125 = (($109) + 344|0);
        $126 = HEAP32[$125>>2]|0;
        $127 = ((($126) + ($$pre65<<4)|0) + 4|0);
        $128 = HEAP32[$127>>2]|0;
        $129 = ($128|0)==(0|0);
        if ($129) {
         label = 21;
        } else {
         $134 = ((($126) + ($$pre65<<4)|0) + 8|0);
         $135 = HEAP32[$134>>2]|0;
         $136 = HEAP8[$23>>0]|0;
         $137 = ($136<<24>>24)!=(0);
         $138 = (Math_fround(__ZN5physx14PxsComputeAABBEbPKNS_12PxcRigidBodyEPKNS_12PxsRigidCoreERKNS_9PxBounds3ERS6_($137,$128,$135,$116,$worldSpaceActorBounds)));
         $139 = Math_fround($numFastMovingShapes$131 + $138);
         $numFastMovingShapes$2 = $139;
        }
       }
       if ((label|0) == 21) {
        label = 0;
        $130 = (($109) + 332|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = ((($131) + ($$pre65<<3)|0) + 4|0);
        $133 = HEAP32[$132>>2]|0;
        __ZN5physx14PxsComputeAABBEPKNS_12PxsRigidCoreERKNS_9PxBounds3ERS3_($133,$116,$worldSpaceActorBounds);
        $numFastMovingShapes$2 = $numFastMovingShapes$131;
       }
       $140 = ($112<<24>>24)==(1);
       if ($140) {
        $141 = HEAP32[$worldSpaceActorBounds>>2]|0;
        $142 = ($141|0)<(0);
        $143 = $141 ^ -1;
        $144 = $141 | -2147483648;
        $$0$i$i5$i1 = $142 ? $143 : $144;
        $145 = (($$0$i$i5$i1) + -16)|0;
        $146 = $145 & -16;
        $147 = HEAP32[$17>>2]|0;
        $148 = ($147|0)<(0);
        $149 = $147 ^ -1;
        $150 = $147 | -2147483648;
        $$0$i$i4$i2 = $148 ? $149 : $150;
        $151 = (($$0$i$i4$i2) + -16)|0;
        $152 = $151 & -16;
        $153 = HEAP32[$18>>2]|0;
        $154 = ($153|0)<(0);
        $155 = $153 ^ -1;
        $156 = $153 | -2147483648;
        $$0$i$i3$i3 = $154 ? $155 : $156;
        $157 = (($$0$i$i3$i3) + -16)|0;
        $158 = $157 & -16;
        $159 = HEAP32[$16>>2]|0;
        $160 = ($159|0)<(0);
        $161 = $159 ^ -1;
        $162 = $159 | -2147483648;
        $$0$i$i2$i4 = $160 ? $161 : $162;
        $163 = (($$0$i$i2$i4) + 16)|0;
        $164 = $163 & -16;
        $165 = $164 | 1;
        $166 = HEAP32[$19>>2]|0;
        $167 = ($166|0)<(0);
        $168 = $166 ^ -1;
        $169 = $166 | -2147483648;
        $$0$i$i1$i5 = $167 ? $168 : $169;
        $170 = (($$0$i$i1$i5) + 16)|0;
        $171 = $170 & -16;
        $172 = $171 | 1;
        $173 = HEAP32[$20>>2]|0;
        $174 = ($173|0)<(0);
        $175 = $173 ^ -1;
        $176 = $173 | -2147483648;
        $$0$i$i$i6 = $174 ? $175 : $176;
        $177 = (($$0$i$i$i6) + 16)|0;
        $178 = $177 & -16;
        $179 = $178 | 1;
        $180 = (($10) + (($119*24)|0)|0);
        HEAP32[$180>>2] = $146;
        $181 = ((($10) + (($119*24)|0)|0) + 4|0);
        HEAP32[$181>>2] = $152;
        $182 = ((($10) + (($119*24)|0)|0) + 8|0);
        HEAP32[$182>>2] = $158;
        $183 = ((($10) + (($119*24)|0)|0) + 12|0);
        HEAP32[$183>>2] = $165;
        $184 = ((($10) + (($119*24)|0)|0) + 16|0);
        HEAP32[$184>>2] = $172;
        $185 = ((($10) + (($119*24)|0)|0) + 20|0);
        HEAP32[$185>>2] = $179;
       }
       $186 = (HEAP32[tempDoublePtr>>2]=$187,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $188 = Math_fround(HEAPF32[$worldSpaceActorBounds>>2]);
       $189 = $186 < $188;
       $190 = $189 ? $186 : $188;
       $191 = (HEAP32[tempDoublePtr>>2]=$192,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $193 = Math_fround(HEAPF32[$17>>2]);
       $194 = $191 < $193;
       $195 = $194 ? $191 : $193;
       $196 = (HEAP32[tempDoublePtr>>2]=$197,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $198 = Math_fround(HEAPF32[$18>>2]);
       $199 = $196 < $198;
       $200 = $199 ? $196 : $198;
       $201 = (HEAPF32[tempDoublePtr>>2]=$190,HEAP32[tempDoublePtr>>2]|0);
       $202 = (HEAPF32[tempDoublePtr>>2]=$195,HEAP32[tempDoublePtr>>2]|0);
       $203 = (HEAPF32[tempDoublePtr>>2]=$200,HEAP32[tempDoublePtr>>2]|0);
       $204 = (HEAP32[tempDoublePtr>>2]=$205,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $206 = Math_fround(HEAPF32[$16>>2]);
       $207 = $204 > $206;
       $208 = $207 ? $204 : $206;
       $209 = (HEAP32[tempDoublePtr>>2]=$210,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $211 = Math_fround(HEAPF32[$21>>2]);
       $212 = $209 > $211;
       $213 = $212 ? $209 : $211;
       $214 = (HEAP32[tempDoublePtr>>2]=$215,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $216 = Math_fround(HEAPF32[$22>>2]);
       $217 = $214 > $216;
       $218 = $217 ? $214 : $216;
       $219 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
       $220 = (HEAPF32[tempDoublePtr>>2]=$213,HEAP32[tempDoublePtr>>2]|0);
       $221 = (HEAPF32[tempDoublePtr>>2]=$218,HEAP32[tempDoublePtr>>2]|0);
       $$pre = HEAP32[$3>>2]|0;
       $223 = $$pre;$277 = $221;$278 = $220;$279 = $219;$280 = $203;$281 = $202;$282 = $201;$numFastMovingShapes$3 = $numFastMovingShapes$2;
      }
      $222 = (($223) + 256|0);
      $224 = HEAP32[$222>>2]|0;
      $225 = (($224) + ($actorId3$032<<2)|0);
      $actorId3$0 = HEAP32[$225>>2]|0;
      $226 = ($actorId3$0|0)==(1073741823);
      if ($226) {
       $$lcssa24 = $277;$$lcssa25 = $278;$$lcssa26 = $279;$$lcssa27 = $280;$$lcssa28 = $281;$$lcssa29 = $282;$numFastMovingShapes$1$lcssa = $numFastMovingShapes$3;
       break;
      } else {
       $109 = $223;$187 = $282;$192 = $281;$197 = $280;$205 = $279;$210 = $278;$215 = $277;$actorId3$032 = $actorId3$0;$numFastMovingShapes$131 = $numFastMovingShapes$3;
      }
     }
    }
    $227 = ((($28) + (($25*1048)|0)|0) + 1028|0);
    $228 = HEAP32[$227>>2]|0;
    $229 = ($$lcssa29|0)<(0);
    $230 = $$lcssa29 ^ -1;
    $231 = $$lcssa29 | -2147483648;
    $$0$i$i5$i = $229 ? $230 : $231;
    $232 = (($$0$i$i5$i) + -16)|0;
    $233 = $232 & -16;
    $234 = ($$lcssa28|0)<(0);
    $235 = $$lcssa28 ^ -1;
    $236 = $$lcssa28 | -2147483648;
    $$0$i$i4$i = $234 ? $235 : $236;
    $237 = (($$0$i$i4$i) + -16)|0;
    $238 = $237 & -16;
    $239 = ($$lcssa27|0)<(0);
    $240 = $$lcssa27 ^ -1;
    $241 = $$lcssa27 | -2147483648;
    $$0$i$i3$i = $239 ? $240 : $241;
    $242 = (($$0$i$i3$i) + -16)|0;
    $243 = $242 & -16;
    $244 = ($$lcssa26|0)<(0);
    $245 = $$lcssa26 ^ -1;
    $246 = $$lcssa26 | -2147483648;
    $$0$i$i2$i = $244 ? $245 : $246;
    $247 = (($$0$i$i2$i) + 16)|0;
    $248 = $247 & -16;
    $249 = $248 | 1;
    $250 = ($$lcssa25|0)<(0);
    $251 = $$lcssa25 ^ -1;
    $252 = $$lcssa25 | -2147483648;
    $$0$i$i1$i = $250 ? $251 : $252;
    $253 = (($$0$i$i1$i) + 16)|0;
    $254 = $253 & -16;
    $255 = $254 | 1;
    $256 = ($$lcssa24|0)<(0);
    $257 = $$lcssa24 ^ -1;
    $258 = $$lcssa24 | -2147483648;
    $$0$i$i$i = $256 ? $257 : $258;
    $259 = (($$0$i$i$i) + 16)|0;
    $260 = $259 & -16;
    $261 = $260 | 1;
    $262 = (($8) + (($228*24)|0)|0);
    HEAP32[$262>>2] = $233;
    $263 = ((($8) + (($228*24)|0)|0) + 4|0);
    HEAP32[$263>>2] = $238;
    $264 = ((($8) + (($228*24)|0)|0) + 8|0);
    HEAP32[$264>>2] = $243;
    $265 = ((($8) + (($228*24)|0)|0) + 12|0);
    HEAP32[$265>>2] = $249;
    $266 = ((($8) + (($228*24)|0)|0) + 16|0);
    HEAP32[$266>>2] = $255;
    $267 = ((($8) + (($228*24)|0)|0) + 20|0);
    HEAP32[$267>>2] = $261;
    $numFastMovingShapes$4 = $numFastMovingShapes$1$lcssa;
   } else {
    label = 6;
   }
  } else {
   label = 6;
  }
  if ((label|0) == 6) {
   label = 0;
   $41 = ((($28) + (($25*1048)|0)|0) + 1032|0);
   $elemId$012 = HEAP32[$41>>2]|0;
   $42 = ($elemId$012|0)==(1073741823);
   if ($42) {
    $$lcssa = 8388608;$$lcssa10 = -8388609;$$lcssa11 = -8388609;$$lcssa7 = 8388608;$$lcssa8 = 8388608;$$lcssa9 = -8388609;
   } else {
    $43 = (($27) + 308|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($27) + 316|0);
    $46 = HEAP32[$45>>2]|0;
    $53 = -8388609;$58 = -8388609;$63 = -8388609;$68 = 8388608;$73 = 8388608;$78 = 8388608;$elemId$013 = $elemId$012;
    while(1) {
     $47 = (($44) + ($elemId$013<<2)|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(1073741823);
     if ($49) {
      $271 = $78;$272 = $73;$273 = $68;$274 = $63;$275 = $58;$276 = $53;
     } else {
      $50 = (($10) + (($elemId$013*24)|0)|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($53>>>0)<($51>>>0);
      $54 = $52 ? $53 : $51;
      $55 = ((($10) + (($elemId$013*24)|0)|0) + 4|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($58>>>0)<($56>>>0);
      $59 = $57 ? $58 : $56;
      $60 = ((($10) + (($elemId$013*24)|0)|0) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($63>>>0)<($61>>>0);
      $64 = $62 ? $63 : $61;
      $65 = ((($10) + (($elemId$013*24)|0)|0) + 12|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ($68>>>0)<($66>>>0);
      $69 = $67 ? $66 : $68;
      $70 = ((($10) + (($elemId$013*24)|0)|0) + 16|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($73>>>0)<($71>>>0);
      $74 = $72 ? $71 : $73;
      $75 = ((($10) + (($elemId$013*24)|0)|0) + 20|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = ($78>>>0)<($76>>>0);
      $79 = $77 ? $76 : $78;
      $271 = $79;$272 = $74;$273 = $69;$274 = $64;$275 = $59;$276 = $54;
     }
     $80 = (($46) + ($elemId$013<<2)|0);
     $elemId$0 = HEAP32[$80>>2]|0;
     $81 = ($elemId$0|0)==(1073741823);
     if ($81) {
      $$lcssa = $271;$$lcssa10 = $275;$$lcssa11 = $276;$$lcssa7 = $272;$$lcssa8 = $273;$$lcssa9 = $274;
      break;
     } else {
      $53 = $276;$58 = $275;$63 = $274;$68 = $273;$73 = $272;$78 = $271;$elemId$013 = $elemId$0;
     }
    }
   }
   $82 = ((($28) + (($25*1048)|0)|0) + 1028|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($8) + (($83*24)|0)|0);
   HEAP32[$84>>2] = $$lcssa11;
   $85 = ((($8) + (($83*24)|0)|0) + 4|0);
   HEAP32[$85>>2] = $$lcssa10;
   $86 = ((($8) + (($83*24)|0)|0) + 8|0);
   HEAP32[$86>>2] = $$lcssa9;
   $87 = ((($8) + (($83*24)|0)|0) + 12|0);
   HEAP32[$87>>2] = $$lcssa8;
   $88 = ((($8) + (($83*24)|0)|0) + 16|0);
   HEAP32[$88>>2] = $$lcssa7;
   $89 = ((($8) + (($83*24)|0)|0) + 20|0);
   HEAP32[$89>>2] = $$lcssa;
   $numFastMovingShapes$4 = $numFastMovingShapes$044;
  }
  $268 = (($i$043) + 1)|0;
  $exitcond = ($268|0)==($13|0);
  if ($exitcond) {
   $numFastMovingShapes$5 = $numFastMovingShapes$4;
   break;
  }
  $$pre62 = HEAP32[$3>>2]|0;
  $27 = $$pre62;$i$043 = $268;$numFastMovingShapes$044 = $numFastMovingShapes$4;
 }
 $269 = (~~(($numFastMovingShapes$5))>>>0);
 $270 = (($this) + 56|0);
 HEAP32[$270>>2] = $269;
 STACKTOP = sp;return;
}
function __ZNK5physx14SingleAABBTask25updateNumFastMovingShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 180|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 $5 = (($this) + 248|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4))|0;
 $8 = (($this) + 316|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7))|0;
 $11 = (($this) + 384|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($10))|0;
 $14 = (($this) + 452|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($13))|0;
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($16))|0;
 HEAP32[$18>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK5physx17AggregateAABBTask25updateNumFastMovingShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 160|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 $5 = (($this) + 220|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4))|0;
 $8 = (($this) + 280|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7))|0;
 $11 = (($this) + 340|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($10))|0;
 $14 = (($this) + 400|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($13))|0;
 $17 = (($this) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($16))|0;
 HEAP32[$18>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN5physx14SingleAABBTaskC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$this>>2] = ((482536 + 8|0));
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = 4;
 $6 = (($this) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 48|0);
 $8 = (($this) + 52|0);
 HEAP16[$8>>1] = -1;
 $9 = (($this) + 54|0);
 HEAP16[$9>>1] = 0;
 $10 = (($this) + 56|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$7>>2] = ((434896 + 8|0));
 $11 = (($this) + 60|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 64|0);
 HEAP32[$12>>2] = 0;
 HEAP32[$7>>2] = ((482680 + 8|0));
 $13 = (($this) + 68|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 92|0);
 HEAP32[$14>>2] = 4;
 $15 = (($this) + 96|0);
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;
 $16 = (($this) + 116|0);
 $17 = (($this) + 120|0);
 HEAP16[$17>>1] = -1;
 $18 = (($this) + 122|0);
 HEAP16[$18>>1] = 0;
 $19 = (($this) + 124|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$16>>2] = ((434896 + 8|0));
 $20 = (($this) + 128|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 132|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$16>>2] = ((482680 + 8|0));
 $22 = (($this) + 136|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 160|0);
 HEAP32[$23>>2] = 4;
 $24 = (($this) + 164|0);
 ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;HEAP32[$24+16>>2]=0|0;
 $25 = (($this) + 184|0);
 $26 = (($this) + 188|0);
 HEAP16[$26>>1] = -1;
 $27 = (($this) + 190|0);
 HEAP16[$27>>1] = 0;
 $28 = (($this) + 192|0);
 HEAP32[$28>>2] = 0;
 HEAP32[$25>>2] = ((434896 + 8|0));
 $29 = (($this) + 196|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 200|0);
 HEAP32[$30>>2] = 0;
 HEAP32[$25>>2] = ((482680 + 8|0));
 $31 = (($this) + 204|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 228|0);
 HEAP32[$32>>2] = 4;
 $33 = (($this) + 232|0);
 ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;HEAP32[$33+16>>2]=0|0;
 $34 = (($this) + 252|0);
 $35 = (($this) + 256|0);
 HEAP16[$35>>1] = -1;
 $36 = (($this) + 258|0);
 HEAP16[$36>>1] = 0;
 $37 = (($this) + 260|0);
 HEAP32[$37>>2] = 0;
 HEAP32[$34>>2] = ((434896 + 8|0));
 $38 = (($this) + 264|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 268|0);
 HEAP32[$39>>2] = 0;
 HEAP32[$34>>2] = ((482680 + 8|0));
 $40 = (($this) + 272|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 296|0);
 HEAP32[$41>>2] = 4;
 $42 = (($this) + 300|0);
 ;HEAP32[$42+0>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;HEAP32[$42+12>>2]=0|0;HEAP32[$42+16>>2]=0|0;
 $43 = (($this) + 320|0);
 $44 = (($this) + 324|0);
 HEAP16[$44>>1] = -1;
 $45 = (($this) + 326|0);
 HEAP16[$45>>1] = 0;
 $46 = (($this) + 328|0);
 HEAP32[$46>>2] = 0;
 HEAP32[$43>>2] = ((434896 + 8|0));
 $47 = (($this) + 332|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 336|0);
 HEAP32[$48>>2] = 0;
 HEAP32[$43>>2] = ((482680 + 8|0));
 $49 = (($this) + 340|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 364|0);
 HEAP32[$50>>2] = 4;
 $51 = (($this) + 368|0);
 ;HEAP32[$51+0>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;HEAP32[$51+12>>2]=0|0;HEAP32[$51+16>>2]=0|0;
 $52 = (($this) + 388|0);
 $53 = (($this) + 392|0);
 HEAP16[$53>>1] = -1;
 $54 = (($this) + 394|0);
 HEAP16[$54>>1] = 0;
 $55 = (($this) + 396|0);
 HEAP32[$55>>2] = 0;
 HEAP32[$52>>2] = ((434896 + 8|0));
 $56 = (($this) + 400|0);
 HEAP32[$56>>2] = 0;
 $57 = (($this) + 404|0);
 HEAP32[$57>>2] = 0;
 HEAP32[$52>>2] = ((482680 + 8|0));
 $58 = (($this) + 408|0);
 HEAP32[$58>>2] = 0;
 $59 = (($this) + 432|0);
 HEAP32[$59>>2] = 4;
 $60 = (($this) + 436|0);
 ;HEAP32[$60+0>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;HEAP32[$60+16>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx14SingleAABBTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx14SingleAABBTaskD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 388|0);
 HEAP32[$0>>2] = ((434896 + 8|0));
 $1 = (($this) + 396|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 320|0);
 HEAP32[$2>>2] = ((434896 + 8|0));
 $3 = (($this) + 328|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 252|0);
 HEAP32[$4>>2] = ((434896 + 8|0));
 $5 = (($this) + 260|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 184|0);
 HEAP32[$6>>2] = ((434896 + 8|0));
 $7 = (($this) + 192|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 116|0);
 HEAP32[$8>>2] = ((434896 + 8|0));
 $9 = (($this) + 124|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 48|0);
 HEAP32[$10>>2] = ((434896 + 8|0));
 $11 = (($this) + 56|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $12 = (($this) + 8|0);
 HEAP32[$12>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx20SingleAABBUpdateTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx14SingleAABBTask11runInternalEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $counts = 0;
 var $counts4 = 0, $exitcond = 0, $exitcond17 = 0, $exitcond19 = 0, $exitcond21 = 0, $exitcond22 = 0, $i1$014 = 0, $i2$011 = 0, $i5$08 = 0, $i6$05 = 0, $i7$03 = 0, $numUpdatedAggregateElems$0 = 0, $numUpdatedBPElems$0 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $starts = 0, $starts3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $starts = sp + 72|0;
 $counts = sp;
 $starts3 = sp + 24|0;
 $counts4 = sp + 48|0;
 $0 = (($this) + 112|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 180|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 248|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 316|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 384|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 452|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 24|0);
 $7 = (($this) + 28|0);
 $8 = (($this) + 20|0);
 $i1$014 = 0;
 while(1) {
  $9 = HEAP32[$6>>2]|0;
  $10 = HEAP32[$8>>2]|0;
  $11 = ((($this) + (($i1$014*68)|0)|0) + 48|0);
  $12 = ((($this) + (($i1$014*68)|0)|0) + 52|0);
  HEAP16[$12>>1] = -1;
  $13 = ((($this) + (($i1$014*68)|0)|0) + 54|0);
  HEAP16[$13>>1] = 0;
  $14 = ((($this) + (($i1$014*68)|0)|0) + 56|0);
  HEAP32[$14>>2] = 0;
  HEAP32[$11>>2] = ((434896 + 8|0));
  $15 = ((($this) + (($i1$014*68)|0)|0) + 60|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($this) + (($i1$014*68)|0)|0) + 64|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$11>>2] = ((482680 + 8|0));
  $17 = ((($this) + (($i1$014*68)|0)|0) + 68|0);
  HEAP32[$17>>2] = $9;
  $18 = ((($this) + (($i1$014*68)|0)|0) + 72|0);
  ;HEAP32[$18+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$18+16>>2]=HEAP32[$7+16>>2]|0;
  $19 = ((($this) + (($i1$014*68)|0)|0) + 92|0);
  HEAP32[$19>>2] = $10;
  $20 = ((($this) + (($i1$014*68)|0)|0) + 96|0);
  ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;HEAP32[$20+16>>2]=0|0;
  $21 = (($i1$014) + 1)|0;
  $exitcond22 = ($21|0)==(6);
  if ($exitcond22) {
   break;
  } else {
   $i1$014 = $21;
  }
 }
 $22 = (($this) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)>(6);
 $25 = $24 ? 6 : $23;
 $26 = HEAP32[$8>>2]|0;
 $27 = $26 & 1;
 $28 = ($27|0)==(0);
 do {
  if ($28) {
   $48 = $26;$numUpdatedBPElems$0 = 0;
  } else {
   $29 = HEAP32[$6>>2]|0;
   $30 = (($29) + 16912|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0);
   if ($32) {
    $48 = $26;$numUpdatedBPElems$0 = 0;
   } else {
    $33 = ($25>>>0)>(1);
    $34 = ($31>>>0)>(256);
    $or$cond = $33 & $34;
    if (!($or$cond)) {
     $45 = (($this) + 96|0);
     HEAP32[$45>>2] = 0;
     $46 = (($this) + 100|0);
     HEAP32[$46>>2] = $31;
     $48 = $26;$numUpdatedBPElems$0 = $31;
     break;
    }
    __Z15computeTaskWorkILj256ELj6EEvjjPjS0_($31,$25,$starts,$counts);
    $35 = ($25|0)==(0);
    if (!($35)) {
     $36 = ($23>>>0)<(6);
     $37 = $36 ? $23 : 6;
     $i2$011 = 0;
     while(1) {
      $38 = (($starts) + ($i2$011<<2)|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = (($counts) + ($i2$011<<2)|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ((($this) + (($i2$011*68)|0)|0) + 96|0);
      HEAP32[$42>>2] = $39;
      $43 = ((($this) + (($i2$011*68)|0)|0) + 100|0);
      HEAP32[$43>>2] = $41;
      $44 = (($i2$011) + 1)|0;
      $exitcond21 = ($44|0)==($37|0);
      if ($exitcond21) {
       break;
      } else {
       $i2$011 = $44;
      }
     }
    }
    $$pre = HEAP32[$8>>2]|0;
    $48 = $$pre;$numUpdatedBPElems$0 = $31;
   }
  }
 } while(0);
 $47 = $48 & 2;
 $49 = ($47|0)==(0);
 do {
  if ($49) {
   $numUpdatedAggregateElems$0 = 0;
   label = 18;
  } else {
   $50 = HEAP32[$6>>2]|0;
   $51 = (($50) + 33328|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0);
   if ($53) {
    $numUpdatedAggregateElems$0 = 0;
    label = 18;
   } else {
    $54 = ($25>>>0)>(1);
    $55 = ($52>>>0)>(256);
    $or$cond1 = $54 & $55;
    if (!($or$cond1)) {
     $66 = (($this) + 104|0);
     HEAP32[$66>>2] = 0;
     $67 = (($this) + 108|0);
     HEAP32[$67>>2] = $52;
     $numUpdatedAggregateElems$0 = $52;
     label = 18;
     break;
    }
    __Z15computeTaskWorkILj256ELj6EEvjjPjS0_($52,$25,$starts3,$counts4);
    $56 = ($25|0)==(0);
    if (!($56)) {
     $57 = ($23>>>0)<(6);
     $58 = $57 ? $23 : 6;
     $i5$08 = 0;
     while(1) {
      $59 = (($starts3) + ($i5$08<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = (($counts4) + ($i5$08<<2)|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ((($this) + (($i5$08*68)|0)|0) + 104|0);
      HEAP32[$63>>2] = $60;
      $64 = ((($this) + (($i5$08*68)|0)|0) + 108|0);
      HEAP32[$64>>2] = $62;
      $65 = (($i5$08) + 1)|0;
      $exitcond19 = ($65|0)==($58|0);
      if ($exitcond19) {
       $numUpdatedAggregateElems$0 = $52;
       label = 18;
       break;
      } else {
       $i5$08 = $65;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $68 = ($25>>>0)>(1);
  if ($68) {
   $69 = ($numUpdatedBPElems$0>>>0)>(256);
   $70 = ($numUpdatedAggregateElems$0>>>0)>(256);
   $or$cond2 = $69 | $70;
   if ($or$cond2) {
    $71 = ($25|0)==(0);
    if ($71) {
     STACKTOP = sp;return;
    }
    $72 = (($this) + 12|0);
    $73 = ($23>>>0)<(6);
    $74 = $73 ? $23 : 6;
    $i6$05 = 0;
    while(1) {
     $77 = HEAP32[$72>>2]|0;
     $78 = ((($this) + (($i6$05*68)|0)|0) + 64|0);
     HEAP32[$78>>2] = 1;
     $79 = ((($this) + (($i6$05*68)|0)|0) + 60|0);
     HEAP32[$79>>2] = $77;
     $80 = ($77|0)==(0|0);
     if (!($80)) {
      $81 = HEAP32[$77>>2]|0;
      $82 = (($81) + 16|0);
      $83 = HEAP32[$82>>2]|0;
      FUNCTION_TABLE_vi[$83 & 4095]($77);
      $84 = HEAP32[$79>>2]|0;
      $85 = (($84) + 8|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = ((($this) + (($i6$05*68)|0)|0) + 56|0);
      HEAP32[$87>>2] = $86;
     }
     $88 = (($i6$05) + 1)|0;
     $exitcond17 = ($88|0)==($74|0);
     if ($exitcond17) {
      break;
     } else {
      $i6$05 = $88;
     }
    }
    if ($71) {
     STACKTOP = sp;return;
    }
    $75 = ($23>>>0)<(6);
    $76 = $75 ? $23 : 6;
    $i7$03 = 0;
    while(1) {
     $89 = ((($this) + (($i7$03*68)|0)|0) + 48|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = (($90) + 20|0);
     $92 = HEAP32[$91>>2]|0;
     FUNCTION_TABLE_vi[$92 & 4095]($89);
     $93 = (($i7$03) + 1)|0;
     $exitcond = ($93|0)==($76|0);
     if ($exitcond) {
      break;
     } else {
      $i7$03 = $93;
     }
    }
    STACKTOP = sp;return;
   }
  }
 }
 $94 = (($this) + 48|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = (($95) + 8|0);
 $97 = HEAP32[$96>>2]|0;
 FUNCTION_TABLE_vi[$97 & 4095]($94);
 STACKTOP = sp;return;
}
function __Z15computeTaskWorkILj256ELj6EEvjjPjS0_($numUpdated,$numTasks,$starts,$counts) {
 $numUpdated = $numUpdated|0;
 $numTasks = $numTasks|0;
 $starts = $starts|0;
 $counts = $counts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$0$lcssa = 0, $count$07 = 0, $count$12 = 0, $exitcond = 0, $exitcond17 = 0, $i$08 = 0, $i1$03 = 0, $i2$01 = 0, $lastStart$0$lcssa = 0, $lastStart$1$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($numUpdated) + 255)|0;
 $1 = $0 >>> 8;
 $2 = (($1>>>0) / ($numTasks>>>0))&-1;
 $3 = Math_imul($2, $numTasks)|0;
 $4 = $2 << 8;
 $5 = (($3) - ($1))|0;
 $6 = (($5) + ($numTasks))|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $count$0$lcssa = 0;$lastStart$0$lcssa = 0;
 } else {
  $8 = (($2) + 1)|0;
  $9 = Math_imul($8, $numTasks)|0;
  $10 = $9 << 8;
  $11 = $1 << 8;
  $12 = (($10) - ($11))|0;
  $13 = (($9) + -1)|0;
  $14 = (($13) - ($1))|0;
  $15 = Math_imul($2, $14)|0;
  $16 = (($9) - ($1))|0;
  $count$07 = 0;$i$08 = 0;
  while(1) {
   $17 = (($starts) + ($i$08<<2)|0);
   HEAP32[$17>>2] = $count$07;
   $18 = (($counts) + ($i$08<<2)|0);
   HEAP32[$18>>2] = $4;
   $19 = (($count$07) + ($4))|0;
   $20 = (($i$08) + 1)|0;
   $exitcond17 = ($20|0)==($16|0);
   if ($exitcond17) {
    break;
   } else {
    $count$07 = $19;$i$08 = $20;
   }
  }
  $21 = Math_imul($2, $12)|0;
  $22 = $15 << 8;
  $count$0$lcssa = $21;$lastStart$0$lcssa = $22;
 }
 $23 = (($4) + 256)|0;
 $24 = ($6>>>0)<($numTasks>>>0);
 if ($24) {
  $25 = (($1) + -1)|0;
  $26 = (($25) - ($3))|0;
  $27 = $2 << 8;
  $28 = (($27) + 256)|0;
  $29 = Math_imul($26, $28)|0;
  $count$12 = $count$0$lcssa;$i1$03 = $6;
  while(1) {
   $30 = (($starts) + ($i1$03<<2)|0);
   HEAP32[$30>>2] = $count$12;
   $31 = (($counts) + ($i1$03<<2)|0);
   HEAP32[$31>>2] = $23;
   $32 = (($count$12) + ($23))|0;
   $33 = (($i1$03) + 1)|0;
   $34 = ($33>>>0)<($numTasks>>>0);
   if ($34) {
    $count$12 = $32;$i1$03 = $33;
   } else {
    break;
   }
  }
  $35 = (($count$0$lcssa) + ($29))|0;
  $lastStart$1$lcssa = $35;
 } else {
  $lastStart$1$lcssa = $lastStart$0$lcssa;
 }
 $36 = (($numUpdated) - ($lastStart$1$lcssa))|0;
 $37 = (($numTasks) + -1)|0;
 $38 = (($counts) + ($37<<2)|0);
 HEAP32[$38>>2] = $36;
 $39 = ($numTasks>>>0)<(6);
 if ($39) {
  $i2$01 = $numTasks;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $40 = (($starts) + ($i2$01<<2)|0);
  HEAP32[$40>>2] = 0;
  $41 = (($counts) + ($i2$01<<2)|0);
  HEAP32[$41>>2] = 0;
  $42 = (($i2$01) + 1)|0;
  $exitcond = ($42|0)==(6);
  if ($exitcond) {
   break;
  } else {
   $i2$01 = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx13ActorAABBTaskC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$this>>2] = ((482584 + 8|0));
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 44|0);
 $7 = (($this) + 48|0);
 HEAP16[$7>>1] = -1;
 $8 = (($this) + 50|0);
 HEAP16[$8>>1] = 0;
 $9 = (($this) + 52|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$6>>2] = ((434896 + 8|0));
 $10 = (($this) + 56|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 60|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$6>>2] = ((482728 + 8|0));
 $12 = (($this) + 64|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;
 $13 = (($this) + 84|0);
 $14 = (($this) + 88|0);
 HEAP16[$14>>1] = -1;
 $15 = (($this) + 90|0);
 HEAP16[$15>>1] = 0;
 $16 = (($this) + 92|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$13>>2] = ((434896 + 8|0));
 $17 = (($this) + 96|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 100|0);
 HEAP32[$18>>2] = 0;
 HEAP32[$13>>2] = ((482728 + 8|0));
 $19 = (($this) + 104|0);
 ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;HEAP32[$19+16>>2]=0|0;
 $20 = (($this) + 124|0);
 $21 = (($this) + 128|0);
 HEAP16[$21>>1] = -1;
 $22 = (($this) + 130|0);
 HEAP16[$22>>1] = 0;
 $23 = (($this) + 132|0);
 HEAP32[$23>>2] = 0;
 HEAP32[$20>>2] = ((434896 + 8|0));
 $24 = (($this) + 136|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 140|0);
 HEAP32[$25>>2] = 0;
 HEAP32[$20>>2] = ((482728 + 8|0));
 $26 = (($this) + 144|0);
 ;HEAP32[$26+0>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;HEAP32[$26+12>>2]=0|0;HEAP32[$26+16>>2]=0|0;
 $27 = (($this) + 164|0);
 $28 = (($this) + 168|0);
 HEAP16[$28>>1] = -1;
 $29 = (($this) + 170|0);
 HEAP16[$29>>1] = 0;
 $30 = (($this) + 172|0);
 HEAP32[$30>>2] = 0;
 HEAP32[$27>>2] = ((434896 + 8|0));
 $31 = (($this) + 176|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 180|0);
 HEAP32[$32>>2] = 0;
 HEAP32[$27>>2] = ((482728 + 8|0));
 $33 = (($this) + 184|0);
 ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;HEAP32[$33+16>>2]=0|0;
 $34 = (($this) + 204|0);
 $35 = (($this) + 208|0);
 HEAP16[$35>>1] = -1;
 $36 = (($this) + 210|0);
 HEAP16[$36>>1] = 0;
 $37 = (($this) + 212|0);
 HEAP32[$37>>2] = 0;
 HEAP32[$34>>2] = ((434896 + 8|0));
 $38 = (($this) + 216|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 220|0);
 HEAP32[$39>>2] = 0;
 HEAP32[$34>>2] = ((482728 + 8|0));
 $40 = (($this) + 224|0);
 ;HEAP32[$40+0>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;HEAP32[$40+16>>2]=0|0;
 $41 = (($this) + 244|0);
 $42 = (($this) + 248|0);
 HEAP16[$42>>1] = -1;
 $43 = (($this) + 250|0);
 HEAP16[$43>>1] = 0;
 $44 = (($this) + 252|0);
 HEAP32[$44>>2] = 0;
 HEAP32[$41>>2] = ((434896 + 8|0));
 $45 = (($this) + 256|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 260|0);
 HEAP32[$46>>2] = 0;
 HEAP32[$41>>2] = ((482728 + 8|0));
 $47 = (($this) + 264|0);
 ;HEAP32[$47+0>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;HEAP32[$47+12>>2]=0|0;HEAP32[$47+16>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx13ActorAABBTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx13ActorAABBTaskD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 HEAP32[$0>>2] = ((434896 + 8|0));
 $1 = (($this) + 252|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 204|0);
 HEAP32[$2>>2] = ((434896 + 8|0));
 $3 = (($this) + 212|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 164|0);
 HEAP32[$4>>2] = ((434896 + 8|0));
 $5 = (($this) + 172|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 124|0);
 HEAP32[$6>>2] = ((434896 + 8|0));
 $7 = (($this) + 132|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 84|0);
 HEAP32[$8>>2] = ((434896 + 8|0));
 $9 = (($this) + 92|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = ((434896 + 8|0));
 $11 = (($this) + 52|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $12 = (($this) + 8|0);
 HEAP32[$12>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx19ActorAABBUpdateTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx13ActorAABBTask11runInternalEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $counts = 0, $exitcond = 0, $exitcond12 = 0, $exitcond14 = 0, $exitcond15 = 0, $i$010 = 0, $i1$08 = 0, $i2$05 = 0, $i3$03 = 0, $or$cond = 0, $starts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $starts = sp + 24|0;
 $counts = sp;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 268|0);
 $3 = (($1) + 41556|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 41568|0);
 $6 = HEAP32[$5>>2]|0;
 $14 = $1;$i$010 = 0;
 while(1) {
  $7 = ((($this) + (($i$010*40)|0)|0) + 44|0);
  $8 = ((($this) + (($i$010*40)|0)|0) + 48|0);
  HEAP16[$8>>1] = -1;
  $9 = ((($this) + (($i$010*40)|0)|0) + 50|0);
  HEAP16[$9>>1] = 0;
  $10 = ((($this) + (($i$010*40)|0)|0) + 52|0);
  HEAP32[$10>>2] = 0;
  HEAP32[$7>>2] = ((434896 + 8|0));
  $11 = ((($this) + (($i$010*40)|0)|0) + 56|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($this) + (($i$010*40)|0)|0) + 60|0);
  HEAP32[$12>>2] = 0;
  HEAP32[$7>>2] = ((482728 + 8|0));
  $13 = ((($this) + (($i$010*40)|0)|0) + 64|0);
  HEAP32[$13>>2] = $14;
  $15 = ((($this) + (($i$010*40)|0)|0) + 68|0);
  HEAP32[$15>>2] = $4;
  $16 = ((($this) + (($i$010*40)|0)|0) + 72|0);
  HEAP32[$16>>2] = $2;
  $17 = ((($this) + (($i$010*40)|0)|0) + 76|0);
  HEAP32[$17>>2] = 0;
  $18 = ((($this) + (($i$010*40)|0)|0) + 80|0);
  HEAP32[$18>>2] = 0;
  $19 = (($i$010) + 1)|0;
  $exitcond15 = ($19|0)==(6);
  if ($exitcond15) {
   break;
  }
  $$pre = HEAP32[$0>>2]|0;
  $14 = $$pre;$i$010 = $19;
 }
 $20 = (($this) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21>>>0)>(6);
 $23 = $22 ? 6 : $21;
 $24 = ($6|0)==(0);
 do {
  if (!($24)) {
   $25 = ($23>>>0)>(1);
   $26 = ($6>>>0)>(32);
   $or$cond = $25 & $26;
   if (!($or$cond)) {
    $37 = (($this) + 76|0);
    HEAP32[$37>>2] = 0;
    $38 = (($this) + 80|0);
    HEAP32[$38>>2] = $6;
    break;
   }
   __Z15computeTaskWorkILj32ELj6EEvjjPjS0_($6,$23,$starts,$counts);
   $27 = ($23|0)==(0);
   if ($27) {
    STACKTOP = sp;return;
   }
   $28 = ($21>>>0)<(6);
   $29 = $28 ? $21 : 6;
   $i1$08 = 0;
   while(1) {
    $30 = (($starts) + ($i1$08<<2)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($counts) + ($i1$08<<2)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ((($this) + (($i1$08*40)|0)|0) + 76|0);
    HEAP32[$34>>2] = $31;
    $35 = ((($this) + (($i1$08*40)|0)|0) + 80|0);
    HEAP32[$35>>2] = $33;
    $36 = (($i1$08) + 1)|0;
    $exitcond14 = ($36|0)==($29|0);
    if ($exitcond14) {
     break;
    } else {
     $i1$08 = $36;
    }
   }
   if ($or$cond) {
    $39 = ($23|0)==(0);
    if ($39) {
     STACKTOP = sp;return;
    }
    $40 = (($this) + 12|0);
    $41 = ($21>>>0)<(6);
    $42 = $41 ? $21 : 6;
    $i2$05 = 0;
    while(1) {
     $45 = HEAP32[$40>>2]|0;
     $46 = ((($this) + (($i2$05*40)|0)|0) + 60|0);
     HEAP32[$46>>2] = 1;
     $47 = ((($this) + (($i2$05*40)|0)|0) + 56|0);
     HEAP32[$47>>2] = $45;
     $48 = ($45|0)==(0|0);
     if (!($48)) {
      $49 = HEAP32[$45>>2]|0;
      $50 = (($49) + 16|0);
      $51 = HEAP32[$50>>2]|0;
      FUNCTION_TABLE_vi[$51 & 4095]($45);
      $52 = HEAP32[$47>>2]|0;
      $53 = (($52) + 8|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ((($this) + (($i2$05*40)|0)|0) + 52|0);
      HEAP32[$55>>2] = $54;
     }
     $56 = (($i2$05) + 1)|0;
     $exitcond12 = ($56|0)==($42|0);
     if ($exitcond12) {
      break;
     } else {
      $i2$05 = $56;
     }
    }
    if ($39) {
     STACKTOP = sp;return;
    }
    $43 = ($21>>>0)<(6);
    $44 = $43 ? $21 : 6;
    $i3$03 = 0;
    while(1) {
     $57 = ((($this) + (($i3$03*40)|0)|0) + 44|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($58) + 20|0);
     $60 = HEAP32[$59>>2]|0;
     FUNCTION_TABLE_vi[$60 & 4095]($57);
     $61 = (($i3$03) + 1)|0;
     $exitcond = ($61|0)==($44|0);
     if ($exitcond) {
      break;
     } else {
      $i3$03 = $61;
     }
    }
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $62 = (($this) + 44|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 FUNCTION_TABLE_vi[$65 & 4095]($62);
 STACKTOP = sp;return;
}
function __Z15computeTaskWorkILj32ELj6EEvjjPjS0_($numUpdated,$numTasks,$starts,$counts) {
 $numUpdated = $numUpdated|0;
 $numTasks = $numTasks|0;
 $starts = $starts|0;
 $counts = $counts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$0$lcssa = 0, $count$07 = 0, $count$12 = 0, $exitcond = 0, $exitcond17 = 0, $i$08 = 0, $i1$03 = 0, $i2$01 = 0, $lastStart$0$lcssa = 0, $lastStart$1$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($numUpdated) + 31)|0;
 $1 = $0 >>> 5;
 $2 = (($1>>>0) / ($numTasks>>>0))&-1;
 $3 = Math_imul($2, $numTasks)|0;
 $4 = $2 << 5;
 $5 = (($3) - ($1))|0;
 $6 = (($5) + ($numTasks))|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $count$0$lcssa = 0;$lastStart$0$lcssa = 0;
 } else {
  $8 = (($2) + 1)|0;
  $9 = Math_imul($8, $numTasks)|0;
  $10 = $9 << 5;
  $11 = $1 << 5;
  $12 = (($10) - ($11))|0;
  $13 = (($9) + -1)|0;
  $14 = (($13) - ($1))|0;
  $15 = Math_imul($2, $14)|0;
  $16 = (($9) - ($1))|0;
  $count$07 = 0;$i$08 = 0;
  while(1) {
   $17 = (($starts) + ($i$08<<2)|0);
   HEAP32[$17>>2] = $count$07;
   $18 = (($counts) + ($i$08<<2)|0);
   HEAP32[$18>>2] = $4;
   $19 = (($count$07) + ($4))|0;
   $20 = (($i$08) + 1)|0;
   $exitcond17 = ($20|0)==($16|0);
   if ($exitcond17) {
    break;
   } else {
    $count$07 = $19;$i$08 = $20;
   }
  }
  $21 = Math_imul($2, $12)|0;
  $22 = $15 << 5;
  $count$0$lcssa = $21;$lastStart$0$lcssa = $22;
 }
 $23 = (($4) + 32)|0;
 $24 = ($6>>>0)<($numTasks>>>0);
 if ($24) {
  $25 = (($1) + -1)|0;
  $26 = (($25) - ($3))|0;
  $27 = $2 << 5;
  $28 = (($27) + 32)|0;
  $29 = Math_imul($26, $28)|0;
  $count$12 = $count$0$lcssa;$i1$03 = $6;
  while(1) {
   $30 = (($starts) + ($i1$03<<2)|0);
   HEAP32[$30>>2] = $count$12;
   $31 = (($counts) + ($i1$03<<2)|0);
   HEAP32[$31>>2] = $23;
   $32 = (($count$12) + ($23))|0;
   $33 = (($i1$03) + 1)|0;
   $34 = ($33>>>0)<($numTasks>>>0);
   if ($34) {
    $count$12 = $32;$i1$03 = $33;
   } else {
    break;
   }
  }
  $35 = (($count$0$lcssa) + ($29))|0;
  $lastStart$1$lcssa = $35;
 } else {
  $lastStart$1$lcssa = $lastStart$0$lcssa;
 }
 $36 = (($numUpdated) - ($lastStart$1$lcssa))|0;
 $37 = (($numTasks) + -1)|0;
 $38 = (($counts) + ($37<<2)|0);
 HEAP32[$38>>2] = $36;
 $39 = ($numTasks>>>0)<(6);
 if ($39) {
  $i2$01 = $numTasks;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $40 = (($starts) + ($i2$01<<2)|0);
  HEAP32[$40>>2] = 0;
  $41 = (($counts) + ($i2$01<<2)|0);
  HEAP32[$41>>2] = 0;
  $42 = (($i2$01) + 1)|0;
  $exitcond = ($42|0)==(6);
  if ($exitcond) {
   break;
  } else {
   $i2$01 = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx17AggregateAABBTaskC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$this>>2] = ((482632 + 8|0));
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 44|0);
 $7 = (($this) + 48|0);
 HEAP16[$7>>1] = -1;
 $8 = (($this) + 50|0);
 HEAP16[$8>>1] = 0;
 $9 = (($this) + 52|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$6>>2] = ((434896 + 8|0));
 $10 = (($this) + 56|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 60|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$6>>2] = ((482776 + 8|0));
 $12 = (($this) + 64|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 88|0);
 ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
 $14 = (($this) + 104|0);
 $15 = (($this) + 108|0);
 HEAP16[$15>>1] = -1;
 $16 = (($this) + 110|0);
 HEAP16[$16>>1] = 0;
 $17 = (($this) + 112|0);
 HEAP32[$17>>2] = 0;
 HEAP32[$14>>2] = ((434896 + 8|0));
 $18 = (($this) + 116|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 120|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$14>>2] = ((482776 + 8|0));
 $20 = (($this) + 124|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 148|0);
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
 $22 = (($this) + 164|0);
 $23 = (($this) + 168|0);
 HEAP16[$23>>1] = -1;
 $24 = (($this) + 170|0);
 HEAP16[$24>>1] = 0;
 $25 = (($this) + 172|0);
 HEAP32[$25>>2] = 0;
 HEAP32[$22>>2] = ((434896 + 8|0));
 $26 = (($this) + 176|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 180|0);
 HEAP32[$27>>2] = 0;
 HEAP32[$22>>2] = ((482776 + 8|0));
 $28 = (($this) + 184|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 208|0);
 ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;
 $30 = (($this) + 224|0);
 $31 = (($this) + 228|0);
 HEAP16[$31>>1] = -1;
 $32 = (($this) + 230|0);
 HEAP16[$32>>1] = 0;
 $33 = (($this) + 232|0);
 HEAP32[$33>>2] = 0;
 HEAP32[$30>>2] = ((434896 + 8|0));
 $34 = (($this) + 236|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 240|0);
 HEAP32[$35>>2] = 0;
 HEAP32[$30>>2] = ((482776 + 8|0));
 $36 = (($this) + 244|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 268|0);
 ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;
 $38 = (($this) + 284|0);
 $39 = (($this) + 288|0);
 HEAP16[$39>>1] = -1;
 $40 = (($this) + 290|0);
 HEAP16[$40>>1] = 0;
 $41 = (($this) + 292|0);
 HEAP32[$41>>2] = 0;
 HEAP32[$38>>2] = ((434896 + 8|0));
 $42 = (($this) + 296|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 300|0);
 HEAP32[$43>>2] = 0;
 HEAP32[$38>>2] = ((482776 + 8|0));
 $44 = (($this) + 304|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 328|0);
 ;HEAP32[$45+0>>2]=0|0;HEAP32[$45+4>>2]=0|0;HEAP32[$45+8>>2]=0|0;HEAP32[$45+12>>2]=0|0;
 $46 = (($this) + 344|0);
 $47 = (($this) + 348|0);
 HEAP16[$47>>1] = -1;
 $48 = (($this) + 350|0);
 HEAP16[$48>>1] = 0;
 $49 = (($this) + 352|0);
 HEAP32[$49>>2] = 0;
 HEAP32[$46>>2] = ((434896 + 8|0));
 $50 = (($this) + 356|0);
 HEAP32[$50>>2] = 0;
 $51 = (($this) + 360|0);
 HEAP32[$51>>2] = 0;
 HEAP32[$46>>2] = ((482776 + 8|0));
 $52 = (($this) + 364|0);
 HEAP32[$52>>2] = 0;
 $53 = (($this) + 388|0);
 ;HEAP32[$53+0>>2]=0|0;HEAP32[$53+4>>2]=0|0;HEAP32[$53+8>>2]=0|0;HEAP32[$53+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx17AggregateAABBTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx17AggregateAABBTaskD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 344|0);
 HEAP32[$0>>2] = ((434896 + 8|0));
 $1 = (($this) + 352|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 284|0);
 HEAP32[$2>>2] = ((434896 + 8|0));
 $3 = (($this) + 292|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 224|0);
 HEAP32[$4>>2] = ((434896 + 8|0));
 $5 = (($this) + 232|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 164|0);
 HEAP32[$6>>2] = ((434896 + 8|0));
 $7 = (($this) + 172|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 104|0);
 HEAP32[$8>>2] = ((434896 + 8|0));
 $9 = (($this) + 112|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = ((434896 + 8|0));
 $11 = (($this) + 52|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $12 = (($this) + 8|0);
 HEAP32[$12>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23AggregateAABBUpdateTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx17AggregateAABBTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $counts = 0, $exitcond = 0, $exitcond14 = 0, $exitcond16 = 0, $exitcond17 = 0, $i1$011 = 0, $i2$08 = 0;
 var $i3$05 = 0, $i4$03 = 0, $or$cond = 0, $starts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $starts = sp + 24|0;
 $counts = sp;
 $0 = (($this) + 100|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 160|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 220|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 280|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 340|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 400|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 20|0);
 $7 = (($this) + 24|0);
 $i1$011 = 0;
 while(1) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 37444|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($this) + (($i1$011*60)|0)|0) + 44|0);
  $12 = ((($this) + (($i1$011*60)|0)|0) + 48|0);
  HEAP16[$12>>1] = -1;
  $13 = ((($this) + (($i1$011*60)|0)|0) + 50|0);
  HEAP16[$13>>1] = 0;
  $14 = ((($this) + (($i1$011*60)|0)|0) + 52|0);
  HEAP32[$14>>2] = 0;
  HEAP32[$11>>2] = ((434896 + 8|0));
  $15 = ((($this) + (($i1$011*60)|0)|0) + 56|0);
  HEAP32[$15>>2] = 0;
  $16 = ((($this) + (($i1$011*60)|0)|0) + 60|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$11>>2] = ((482776 + 8|0));
  $17 = ((($this) + (($i1$011*60)|0)|0) + 64|0);
  HEAP32[$17>>2] = $8;
  $18 = ((($this) + (($i1$011*60)|0)|0) + 68|0);
  ;HEAP32[$18+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$18+16>>2]=HEAP32[$7+16>>2]|0;
  $19 = ((($this) + (($i1$011*60)|0)|0) + 88|0);
  HEAP32[$19>>2] = $10;
  $20 = ((($this) + (($i1$011*60)|0)|0) + 92|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($this) + (($i1$011*60)|0)|0) + 96|0);
  HEAP32[$21>>2] = 0;
  $22 = ((($this) + (($i1$011*60)|0)|0) + 100|0);
  HEAP32[$22>>2] = 0;
  $23 = (($i1$011) + 1)|0;
  $exitcond17 = ($23|0)==(6);
  if ($exitcond17) {
   break;
  } else {
   $i1$011 = $23;
  }
 }
 $24 = (($this) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25>>>0)>(6);
 $27 = $26 ? 6 : $25;
 $28 = HEAP32[$6>>2]|0;
 $29 = (($28) + 372|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 do {
  if (!($31)) {
   $32 = ($27>>>0)>(1);
   $33 = ($30>>>0)>(32);
   $or$cond = $32 & $33;
   if (!($or$cond)) {
    $44 = (($this) + 92|0);
    HEAP32[$44>>2] = 0;
    $45 = (($this) + 96|0);
    HEAP32[$45>>2] = $30;
    break;
   }
   __Z15computeTaskWorkILj32ELj6EEvjjPjS0_($30,$27,$starts,$counts);
   $34 = ($27|0)==(0);
   if ($34) {
    STACKTOP = sp;return;
   }
   $35 = ($25>>>0)<(6);
   $36 = $35 ? $25 : 6;
   $i2$08 = 0;
   while(1) {
    $37 = (($starts) + ($i2$08<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($counts) + ($i2$08<<2)|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ((($this) + (($i2$08*60)|0)|0) + 92|0);
    HEAP32[$41>>2] = $38;
    $42 = ((($this) + (($i2$08*60)|0)|0) + 96|0);
    HEAP32[$42>>2] = $40;
    $43 = (($i2$08) + 1)|0;
    $exitcond16 = ($43|0)==($36|0);
    if ($exitcond16) {
     break;
    } else {
     $i2$08 = $43;
    }
   }
   if ($or$cond) {
    $46 = ($27|0)==(0);
    if ($46) {
     STACKTOP = sp;return;
    }
    $47 = (($this) + 12|0);
    $48 = ($25>>>0)<(6);
    $49 = $48 ? $25 : 6;
    $i3$05 = 0;
    while(1) {
     $52 = HEAP32[$47>>2]|0;
     $53 = ((($this) + (($i3$05*60)|0)|0) + 60|0);
     HEAP32[$53>>2] = 1;
     $54 = ((($this) + (($i3$05*60)|0)|0) + 56|0);
     HEAP32[$54>>2] = $52;
     $55 = ($52|0)==(0|0);
     if (!($55)) {
      $56 = HEAP32[$52>>2]|0;
      $57 = (($56) + 16|0);
      $58 = HEAP32[$57>>2]|0;
      FUNCTION_TABLE_vi[$58 & 4095]($52);
      $59 = HEAP32[$54>>2]|0;
      $60 = (($59) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ((($this) + (($i3$05*60)|0)|0) + 52|0);
      HEAP32[$62>>2] = $61;
     }
     $63 = (($i3$05) + 1)|0;
     $exitcond14 = ($63|0)==($49|0);
     if ($exitcond14) {
      break;
     } else {
      $i3$05 = $63;
     }
    }
    if ($46) {
     STACKTOP = sp;return;
    }
    $50 = ($25>>>0)<(6);
    $51 = $50 ? $25 : 6;
    $i4$03 = 0;
    while(1) {
     $64 = ((($this) + (($i4$03*60)|0)|0) + 44|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (($65) + 20|0);
     $67 = HEAP32[$66>>2]|0;
     FUNCTION_TABLE_vi[$67 & 4095]($64);
     $68 = (($i4$03) + 1)|0;
     $exitcond = ($68|0)==($51|0);
     if ($exitcond) {
      break;
     } else {
      $i4$03 = $68;
     }
    }
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $69 = (($this) + 44|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + 8|0);
 $72 = HEAP32[$71>>2]|0;
 FUNCTION_TABLE_vi[$72 & 4095]($69);
 STACKTOP = sp;return;
}
function __ZN5physx10BPWorkTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $updateData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $updateData = sp;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx14PxsAABBManager9prepareBPEv($1);
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 108|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 112|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($2) + 80|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($2) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($2) + 136|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($2) + 140|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($2) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($2) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($2) + 36|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$updateData>>2] = $4;
 $21 = (($updateData) + 4|0);
 HEAP32[$21>>2] = $6;
 $22 = (($updateData) + 8|0);
 HEAP32[$22>>2] = $8;
 $23 = (($updateData) + 12|0);
 HEAP32[$23>>2] = $10;
 $24 = (($updateData) + 16|0);
 HEAP32[$24>>2] = $12;
 $25 = (($updateData) + 20|0);
 HEAP32[$25>>2] = $14;
 $26 = (($updateData) + 24|0);
 HEAP32[$26>>2] = $16;
 $27 = (($updateData) + 28|0);
 HEAP32[$27>>2] = $18;
 $28 = (($updateData) + 32|0);
 HEAP32[$28>>2] = $20;
 $29 = (($2) + 49828|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_viiiii[$33 & 255]($30,$35,$37,$updateData,$39);
 STACKTOP = sp;return;
}
function __ZN5physx20ProcessBPResultsTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 20|0);
 __ZN5physx14PxsAABBManager16processBPResultsERKNS_20PxsComputeAABBParamsE($1,$2);
 STACKTOP = sp;return;
}
function __ZN5physx20AggregateOverlapTask11runInternalEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre$i4 = 0, $$pre$phi$i2Z2D = 0, $$pre$phi$i5Z2D = 0, $$pre$phi$iZ2D = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aggregateSortedData = 0, $elemIds = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$in$i = 0, $i$01$i = 0, $it$02$i$i = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 10304|0;
 $0 = sp + 10290|0;
 $1 = sp + 10289|0;
 $2 = sp + 4112|0;
 $3 = sp + 10288|0;
 $elemIds = sp;
 $aggregateSortedData = sp + 8224|0;
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 45696|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $96 = $5;
 } else {
  $9 = HEAP32[$5>>2]|0;
  $10 = (($2) + 4096|0);
  HEAP32[$10>>2] = $9;
  $11 = (($2) + 4100|0);
  HEAP32[$11>>2] = 0;
  $12 = (($2) + 4104|0);
  HEAP32[$12>>2] = 0;
  $13 = HEAP32[$5>>2]|0;
  $14 = (($elemIds) + 4096|0);
  HEAP32[$14>>2] = $13;
  $15 = (($elemIds) + 4100|0);
  HEAP32[$15>>2] = 0;
  $16 = (($elemIds) + 4104|0);
  HEAP32[$16>>2] = 0;
  $17 = HEAP32[$5>>2]|0;
  $18 = (($aggregateSortedData) + 2048|0);
  HEAP32[$18>>2] = $17;
  $19 = (($aggregateSortedData) + 2052|0);
  HEAP32[$19>>2] = 0;
  $20 = (($aggregateSortedData) + 2056|0);
  HEAP32[$20>>2] = 0;
  $21 = (($5) + 324|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0);
  if ($23) {
   $233 = $3;$43 = $5;
  } else {
   $24 = ($22>>>0)>(1024);
   do {
    if ($24) {
     $25 = $22 << 2;
     $26 = (($25) + 15)|0;
     $27 = $26 & -16;
     $28 = ($9|0)==(0|0);
     if ($28) {
      $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$27,482968,1936)|0);
      HEAP32[$11>>2] = $30;
      $$pre$phi$iZ2D = $25;$31 = $30;
      break;
     } else {
      $29 = (__ZN5physx19PxcScratchAllocator5allocEjb($9,$27,1)|0);
      HEAP32[$11>>2] = $29;
      $$pre$phi$iZ2D = $25;$31 = $29;
      break;
     }
    } else {
     HEAP32[$11>>2] = $2;
     $$pre$i = $22 << 2;
     $$pre$phi$iZ2D = $$pre$i;$31 = $2;
    }
   } while(0);
   _memset(($31|0),0,($$pre$phi$iZ2D|0))|0;
   HEAP32[$12>>2] = $22;
   $$pre10 = HEAP32[$4>>2]|0;
   $$phi$trans$insert = (($$pre10) + 324|0);
   $$pre11 = HEAP32[$$phi$trans$insert>>2]|0;
   $32 = ($$pre11|0)==(0);
   if ($32) {
    $233 = $3;$43 = $$pre10;
   } else {
    $33 = ($$pre11>>>0)>(1024);
    do {
     if ($33) {
      $34 = $$pre11 << 2;
      $35 = (($34) + 15)|0;
      $36 = $35 & -16;
      $37 = HEAP32[$14>>2]|0;
      $38 = ($37|0)==(0|0);
      if ($38) {
       $40 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$36,482968,1936)|0);
       HEAP32[$15>>2] = $40;
       $$pre$phi$i2Z2D = $34;$41 = $40;
       break;
      } else {
       $39 = (__ZN5physx19PxcScratchAllocator5allocEjb($37,$36,1)|0);
       HEAP32[$15>>2] = $39;
       $$pre$phi$i2Z2D = $34;$41 = $39;
       break;
      }
     } else {
      HEAP32[$15>>2] = $elemIds;
      $$pre$i1 = $$pre11 << 2;
      $$pre$phi$i2Z2D = $$pre$i1;$41 = $elemIds;
     }
    } while(0);
    _memset(($41|0),0,($$pre$phi$i2Z2D|0))|0;
    HEAP32[$16>>2] = $$pre11;
    $$pre12 = HEAP32[$4>>2]|0;
    $233 = $3;$43 = $$pre12;
   }
  }
  $42 = (($43) + 196|0);
  $44 = HEAP32[$42>>2]|0;
  $45 = ($44|0)==(0);
  if ($45) {
   $60 = $43;
  } else {
   $46 = ($44>>>0)>(256);
   do {
    if ($46) {
     $47 = $44 << 3;
     $48 = (($47) + 15)|0;
     $49 = $48 & -16;
     $50 = HEAP32[$18>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      $53 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$49,482968,1936)|0);
      HEAP32[$19>>2] = $53;
      $$pre$phi$i5Z2D = $47;$54 = $53;
      break;
     } else {
      $52 = (__ZN5physx19PxcScratchAllocator5allocEjb($50,$49,1)|0);
      HEAP32[$19>>2] = $52;
      $$pre$phi$i5Z2D = $47;$54 = $52;
      break;
     }
    } else {
     HEAP32[$19>>2] = $aggregateSortedData;
     $$pre$i4 = $44 << 3;
     $$pre$phi$i5Z2D = $$pre$i4;$54 = $aggregateSortedData;
    }
   } while(0);
   _memset(($54|0),0,($$pre$phi$i5Z2D|0))|0;
   HEAP32[$20>>2] = $44;
   $$pre13 = HEAP32[$4>>2]|0;
   $60 = $$pre13;
  }
  $55 = HEAP32[$11>>2]|0;
  $56 = HEAP32[$12>>2]|0;
  $57 = HEAP32[$15>>2]|0;
  $58 = HEAP32[$16>>2]|0;
  $59 = HEAP32[$19>>2]|0;
  __ZN5physx14PxsAABBManager14sortAggregatesEPjjS1_jPNS_19AggregateSortedDataE($60,$55,$56,$57,$58,$59);
  $61 = HEAP32[$4>>2]|0;
  $62 = HEAP32[$19>>2]|0;
  __ZN5physx14PxsAABBManager21selfCollideAggregatesEPKNS_19AggregateSortedDataE($61,$62);
  $63 = HEAP32[$4>>2]|0;
  $64 = HEAP32[$19>>2]|0;
  __ZN5physx14PxsAABBManager21processAggregatePairsEPKNS_19AggregateSortedDataE($63,$64);
  $65 = HEAP32[$19>>2]|0;
  $66 = ($65|0)==(0|0);
  $67 = ($65|0)==($aggregateSortedData|0);
  $or$cond$i$i$i = $66 | $67;
  do {
   if (!($or$cond$i$i$i)) {
    $68 = HEAP32[$18>>2]|0;
    $69 = ($68|0)==(0|0);
    if ($69) {
     __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$65);
     break;
    }
    $70 = (($68) + 16|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71>>>0)>($65>>>0);
    if (!($72)) {
     $73 = (($68) + 20|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($71) + ($74)|0);
     $76 = ($75>>>0)>($65>>>0);
     if ($76) {
      $77 = HEAP32[$68>>2]|0;
      __ZN5physx6shdfnd9MutexImpl4lockEv($77);
      $78 = (($68) + 8|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = (($68) + 4|0);
      $81 = HEAP32[$80>>2]|0;
      $i$0$in$i = $79;
      while(1) {
       $i$0$i = (($i$0$in$i) + -1)|0;
       $82 = (($81) + ($i$0$i<<2)|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = ($83>>>0)<($65>>>0);
       if ($84) {
        $i$0$in$i = $i$0$i;
       } else {
        break;
       }
      }
      $85 = ($i$0$in$i>>>0)<($79>>>0);
      if ($85) {
       $89 = $i$0$in$i;$it$02$i$i = $82;
       while(1) {
        $86 = ($it$02$i$i|0)==(0|0);
        if (!($86)) {
         $87 = HEAP32[$80>>2]|0;
         $88 = (($87) + ($89<<2)|0);
         $90 = HEAP32[$88>>2]|0;
         HEAP32[$it$02$i$i>>2] = $90;
        }
        $91 = (($it$02$i$i) + 4|0);
        $92 = (($89) + 1)|0;
        $exitcond$i = ($92|0)==($79|0);
        if ($exitcond$i) {
         break;
        } else {
         $89 = $92;$it$02$i$i = $91;
        }
       }
      }
      $93 = (($79) + -1)|0;
      HEAP32[$78>>2] = $93;
      $94 = HEAP32[$68>>2]|0;
      __ZN5physx6shdfnd9MutexImpl6unlockEv($94);
      break;
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$65);
   }
  } while(0);
  __ZN5physx12InlineBufferIjLj1024EE4freeEv($elemIds);
  __ZN5physx12InlineBufferIjLj1024EE4freeEv($2);
  $$pre = HEAP32[$4>>2]|0;
  $96 = $$pre;
 }
 $95 = (($96) + 49828|0);
 $97 = HEAP32[$95>>2]|0;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($98) + 64|0);
 $100 = HEAP32[$99>>2]|0;
 FUNCTION_TABLE_vi[$100 & 4095]($97);
 $101 = HEAP32[$4>>2]|0;
 $102 = (($101) + 116|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($101) + 120|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = ($103>>>0)>($105>>>0);
 if ($106) {
  $107 = (($101) + 108|0);
  $108 = HEAP32[$107>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$108);
  $109 = HEAP32[$104>>2]|0;
  $110 = $109 << 2;
  $111 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$110,482968,1340)|0);
  HEAP32[$107>>2] = $111;
  $112 = HEAP32[$104>>2]|0;
  HEAP32[$102>>2] = $112;
 }
 $113 = (($101) + 112|0);
 HEAP32[$113>>2] = 0;
 $114 = (($101) + 96|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ($115|0)==(0|0);
 if (!($116)) {
  $117 = (($101) + 100|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = $118 << 2;
  _memset(($115|0),0,($119|0))|0;
 }
 $120 = HEAP32[$4>>2]|0;
 $121 = (($120) + 88|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($120) + 92|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($122>>>0)>($124>>>0);
 if ($125) {
  $126 = (($120) + 80|0);
  $127 = HEAP32[$126>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$127);
  $128 = HEAP32[$123>>2]|0;
  $129 = $128 << 2;
  $130 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$129,482968,1340)|0);
  HEAP32[$126>>2] = $130;
  $131 = HEAP32[$123>>2]|0;
  HEAP32[$121>>2] = $131;
 }
 $132 = (($120) + 84|0);
 HEAP32[$132>>2] = 0;
 $133 = (($120) + 68|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = ($134|0)==(0|0);
 if (!($135)) {
  $136 = (($120) + 72|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = $137 << 2;
  _memset(($134|0),0,($138|0))|0;
 }
 $139 = HEAP32[$4>>2]|0;
 $140 = (($139) + 144|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (($139) + 148|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = ($141>>>0)>($143>>>0);
 if ($144) {
  $145 = (($139) + 136|0);
  $146 = HEAP32[$145>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$146);
  $147 = HEAP32[$142>>2]|0;
  $148 = $147 << 2;
  $149 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$148,482968,1340)|0);
  HEAP32[$145>>2] = $149;
  $150 = HEAP32[$142>>2]|0;
  HEAP32[$140>>2] = $150;
 }
 $151 = (($139) + 140|0);
 HEAP32[$151>>2] = 0;
 $152 = (($139) + 124|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = ($153|0)==(0|0);
 if (!($154)) {
  $155 = (($139) + 128|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = $156 << 2;
  _memset(($153|0),0,($157|0))|0;
 }
 $158 = HEAP32[$4>>2]|0;
 $159 = (($158) + 376|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = (($158) + 380|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = ($160>>>0)>($162>>>0);
 if ($163) {
  $164 = (($158) + 368|0);
  $165 = HEAP32[$164>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$165);
  $166 = HEAP32[$161>>2]|0;
  $167 = $166 << 2;
  $168 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$167,482968,1340)|0);
  HEAP32[$164>>2] = $168;
  $169 = HEAP32[$161>>2]|0;
  HEAP32[$159>>2] = $169;
 }
 $170 = (($158) + 372|0);
 HEAP32[$170>>2] = 0;
 $171 = (($158) + 356|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = ($172|0)==(0|0);
 if (!($173)) {
  $174 = (($158) + 360|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = $175 << 2;
  _memset(($172|0),0,($176|0))|0;
 }
 $177 = HEAP32[$4>>2]|0;
 $178 = (($177) + 512|0);
 __ZN5physx12InlineBufferIjLj4096EE4freeEv($178);
 $179 = HEAP32[$4>>2]|0;
 $180 = (($179) + 16912|0);
 HEAP32[$180>>2] = 0;
 $181 = (($179) + 16928|0);
 __ZN5physx12InlineBufferIjLj4096EE4freeEv($181);
 $182 = HEAP32[$4>>2]|0;
 $183 = (($182) + 33328|0);
 HEAP32[$183>>2] = 0;
 $184 = (($182) + 33344|0);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($184);
 $185 = HEAP32[$4>>2]|0;
 $186 = (($185) + 37456|0);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($186);
 $187 = HEAP32[$4>>2]|0;
 $188 = (($187) + 41568|0);
 HEAP32[$188>>2] = 0;
 $189 = (($187) + 41584|0);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($189);
 $190 = HEAP32[$4>>2]|0;
 $191 = (($190) + 45696|0);
 HEAP32[$191>>2] = 0;
 $192 = (($190) + 45712|0);
 __ZN5physx12InlineBufferIjLj1024EE4freeEv($192);
 $193 = HEAP32[$4>>2]|0;
 $194 = (($193) + 49824|0);
 HEAP32[$194>>2] = 0;
 $195 = (($193) + 268|0);
 $196 = HEAP32[$195>>2]|0;
 $197 = (($193) + 272|0);
 $198 = HEAP32[$197>>2]|0;
 $199 = $198 << 2;
 _memset(($196|0),0,($199|0))|0;
 $200 = HEAP32[$4>>2]|0;
 $201 = (($200) + 196|0);
 $202 = HEAP32[$201>>2]|0;
 $203 = ($202|0)==(0);
 if ($203) {
  $232 = $200;
  __ZN5physx14PxsAABBManager31updateAggregateBPOverlapRecordsEv($232);
  STACKTOP = sp;return;
 }
 $204 = (($200) + 188|0);
 $205 = (($200) + 184|0);
 $i$01$i = 0;
 while(1) {
  $206 = HEAP32[$204>>2]|0;
  $207 = HEAP32[$205>>2]|0;
  $208 = (($207) + ($i$01$i<<4)|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = (($206) + ($i$01$i<<4)|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = $211 | $209;
  HEAP32[$210>>2] = $212;
  $213 = ((($207) + ($i$01$i<<4)|0) + 4|0);
  $214 = HEAP32[$213>>2]|0;
  $215 = ((($206) + ($i$01$i<<4)|0) + 4|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = $216 | $214;
  HEAP32[$215>>2] = $217;
  $218 = ((($207) + ($i$01$i<<4)|0) + 8|0);
  $219 = HEAP32[$218>>2]|0;
  $220 = ((($206) + ($i$01$i<<4)|0) + 8|0);
  $221 = HEAP32[$220>>2]|0;
  $222 = $221 | $219;
  HEAP32[$220>>2] = $222;
  $223 = ((($207) + ($i$01$i<<4)|0) + 12|0);
  $224 = HEAP32[$223>>2]|0;
  $225 = ((($206) + ($i$01$i<<4)|0) + 12|0);
  $226 = HEAP32[$225>>2]|0;
  $227 = $226 | $224;
  HEAP32[$225>>2] = $227;
  $228 = (($207) + ($i$01$i<<4)|0);
  ;HEAP32[$228+0>>2]=0|0;HEAP32[$228+4>>2]=0|0;HEAP32[$228+8>>2]=0|0;HEAP32[$228+12>>2]=0|0;
  $229 = (($i$01$i) + 1)|0;
  $230 = HEAP32[$201>>2]|0;
  $231 = ($229>>>0)<($230>>>0);
  if ($231) {
   $i$01$i = $229;
  } else {
   break;
  }
 }
 $$pre9 = HEAP32[$4>>2]|0;
 $232 = $$pre9;
 __ZN5physx14PxsAABBManager31updateAggregateBPOverlapRecordsEv($232);
 STACKTOP = sp;return;
}
function __ZN5physx20SingleAABBUpdateTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx20SingleAABBUpdateTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (483168|0);
}
function __ZN5physx19ActorAABBUpdateTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx19ActorAABBUpdateTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (483144|0);
}
function __ZN5physx23AggregateAABBUpdateTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx23AggregateAABBUpdateTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (483120|0);
}
function __ZNK5physx14SingleAABBTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (483104|0);
}
function __ZNK5physx13ActorAABBTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (483088|0);
}
function __ZNK5physx17AggregateAABBTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (483064|0);
}
function __ZN5physx15PxsArticulationC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx15PxsArticulationD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx21PxsBodyTransformVaultC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4100|0);
 $1 = (($this) + 4356|0);
 $2 = (($this) + 4360|0);
 $3 = (($this) + 4364|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 4368|0);
 HEAP8[$1>>0] = 1;
 HEAP32[$2>>2] = $0;
 HEAP32[$4>>2] = 64;
 $5 = (($this) + 4372|0);
 HEAP32[$5>>2] = 256;
 $6 = (($this) + 4376|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 4380|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 4384|0);
 HEAP32[$8>>2] = 10240;
 $9 = (($this) + 4388|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 4392|0);
 HEAP32[$10>>2] = 0;
 _memset(($this|0),0,4096)|0;
 STACKTOP = sp;return;
}
function __ZN5physx21PxsBodyTransformVaultD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4096|0);
 __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEED2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx21PxsBodyTransformVault7addBodyERKNS_11PxsBodyCoreE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0;
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $curEntry$0$lcssa$i = 0, $curEntry$01$i = 0, $curEntry$01$i$phi = 0, $newEntry$0 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = $body;
 $1 = $0 << 15;
 $2 = $1 ^ -1;
 $3 = (($0) + ($2))|0;
 $4 = $3 >>> 10;
 $5 = $4 ^ $3;
 $6 = ($5*9)|0;
 $7 = $6 >>> 6;
 $8 = $7 ^ $6;
 $9 = $8 << 11;
 $10 = $9 ^ -1;
 $11 = (($8) + ($10))|0;
 $12 = $11 >>> 16;
 $13 = $12 ^ $11;
 $14 = $13 & 1023;
 $15 = (($this) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  label = 12;
 } else {
  $18 = (($16) + 32|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  L3: do {
   if ($20) {
    $curEntry$0$lcssa$i = $16;
   } else {
    $25 = $19;$curEntry$01$i = $16;
    while(1) {
     $21 = (($curEntry$01$i) + 28|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==($body|0);
     if ($23) {
      $curEntry$0$lcssa$i = $curEntry$01$i;
      break L3;
     }
     $24 = (($25) + 32|0);
     $26 = HEAP32[$24>>2]|0;
     $27 = ($26|0)==(0|0);
     if ($27) {
      $curEntry$0$lcssa$i = $25;
      break;
     } else {
      $curEntry$01$i$phi = $25;$25 = $26;$curEntry$01$i = $curEntry$01$i$phi;
     }
    }
   }
  } while(0);
  $28 = (($curEntry$0$lcssa$i) + 28|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==($body|0);
  if ($30) {
   $107 = (($curEntry$0$lcssa$i) + 36|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($108) + 1)|0;
   HEAP32[$107>>2] = $109;
   STACKTOP = sp;return;
  }
  $31 = ($curEntry$0$lcssa$i|0)==(0|0);
  if ($31) {
   label = 12;
  } else {
   $32 = (($this) + 4388|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    $35 = (($this) + 4096|0);
    __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($35);
    $$pre$i$i$i1 = HEAP32[$32>>2]|0;
    $37 = $$pre$i$i$i1;
   } else {
    $37 = $33;
   }
   $36 = HEAP32[$37>>2]|0;
   HEAP32[$32>>2] = $36;
   $38 = (($this) + 4376|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 1)|0;
   HEAP32[$38>>2] = $40;
   $41 = (($this) + 4380|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + -1)|0;
   HEAP32[$41>>2] = $43;
   $44 = ($37|0)==(0|0);
   if ($44) {
    $67 = 0;
   } else {
    dest=$37+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $45 = Math_fround(HEAPF32[$body>>2]);
    HEAPF32[$37>>2] = $45;
    $46 = (($body) + 4|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = (($37) + 4|0);
    HEAPF32[$48>>2] = $47;
    $49 = (($body) + 8|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = (($37) + 8|0);
    HEAPF32[$51>>2] = $50;
    $52 = (($body) + 12|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = (($37) + 12|0);
    HEAPF32[$54>>2] = $53;
    $55 = (($body) + 16|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = (($37) + 16|0);
    HEAPF32[$57>>2] = $56;
    $58 = (($body) + 20|0);
    $59 = Math_fround(HEAPF32[$58>>2]);
    $60 = (($37) + 20|0);
    HEAPF32[$60>>2] = $59;
    $61 = (($body) + 24|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = (($37) + 24|0);
    HEAPF32[$63>>2] = $62;
    $64 = (($37) + 32|0);
    HEAP32[$64>>2] = 0;
    $65 = (($37) + 28|0);
    HEAP32[$65>>2] = $body;
    $67 = $37;
   }
   $66 = (($curEntry$0$lcssa$i) + 32|0);
   HEAP32[$66>>2] = $67;
   $newEntry$0 = $67;
  }
 }
 if ((label|0) == 12) {
  $68 = (($this) + 4388|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if ($70) {
   $71 = (($this) + 4096|0);
   __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($71);
   $$pre$i$i$i = HEAP32[$68>>2]|0;
   $73 = $$pre$i$i$i;
  } else {
   $73 = $69;
  }
  $72 = HEAP32[$73>>2]|0;
  HEAP32[$68>>2] = $72;
  $74 = (($this) + 4376|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($75) + 1)|0;
  HEAP32[$74>>2] = $76;
  $77 = (($this) + 4380|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($78) + -1)|0;
  HEAP32[$77>>2] = $79;
  $80 = ($73|0)==(0|0);
  if ($80) {
   $102 = 0;
  } else {
   dest=$73+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $81 = Math_fround(HEAPF32[$body>>2]);
   HEAPF32[$73>>2] = $81;
   $82 = (($body) + 4|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = (($73) + 4|0);
   HEAPF32[$84>>2] = $83;
   $85 = (($body) + 8|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   $87 = (($73) + 8|0);
   HEAPF32[$87>>2] = $86;
   $88 = (($body) + 12|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = (($73) + 12|0);
   HEAPF32[$90>>2] = $89;
   $91 = (($body) + 16|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = (($73) + 16|0);
   HEAPF32[$93>>2] = $92;
   $94 = (($body) + 20|0);
   $95 = Math_fround(HEAPF32[$94>>2]);
   $96 = (($73) + 20|0);
   HEAPF32[$96>>2] = $95;
   $97 = (($body) + 24|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = (($73) + 24|0);
   HEAPF32[$99>>2] = $98;
   $100 = (($73) + 32|0);
   HEAP32[$100>>2] = 0;
   $101 = (($73) + 28|0);
   HEAP32[$101>>2] = $body;
   $102 = $73;
  }
  HEAP32[$15>>2] = $102;
  $newEntry$0 = $102;
 }
 $103 = (($newEntry$0) + 36|0);
 HEAP32[$103>>2] = 1;
 $104 = (($this) + 4392|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($105) + 1)|0;
 HEAP32[$104>>2] = $106;
 STACKTOP = sp;return;
}
function __ZN5physx21PxsBodyTransformVault10removeBodyERKNS_11PxsBodyCoreE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curEntry$01$i = 0, $curEntry$01$i$phi = 0, $curEntry$01$i1 = 0, $curEntry$01$i1$phi = 0, $curEntry$01$i2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = $body;
 $1 = $0 << 15;
 $2 = $1 ^ -1;
 $3 = (($0) + ($2))|0;
 $4 = $3 >>> 10;
 $5 = $4 ^ $3;
 $6 = ($5*9)|0;
 $7 = $6 >>> 6;
 $8 = $7 ^ $6;
 $9 = $8 << 11;
 $10 = $9 ^ -1;
 $11 = (($8) + ($10))|0;
 $12 = $11 >>> 16;
 $13 = $12 ^ $11;
 $14 = $13 & 1023;
 $15 = (($this) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 L1: do {
  if ($17) {
   $29 = 0;$curEntry$01$i2 = 0;
  } else {
   $18 = (($16) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $29 = $16;$curEntry$01$i2 = 0;
   } else {
    $25 = $19;$curEntry$01$i = $16;$curEntry$01$i1 = 0;
    while(1) {
     $21 = (($curEntry$01$i) + 28|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==($body|0);
     if ($23) {
      $29 = $curEntry$01$i;$curEntry$01$i2 = $curEntry$01$i1;
      break L1;
     }
     $24 = (($25) + 32|0);
     $26 = HEAP32[$24>>2]|0;
     $27 = ($26|0)==(0|0);
     if ($27) {
      $29 = $25;$curEntry$01$i2 = $curEntry$01$i;
      break;
     } else {
      $curEntry$01$i1$phi = $curEntry$01$i;$curEntry$01$i$phi = $25;$25 = $26;$curEntry$01$i1 = $curEntry$01$i1$phi;$curEntry$01$i = $curEntry$01$i$phi;
     }
    }
   }
  }
 } while(0);
 $28 = (($29) + 36|0);
 $30 = HEAP32[$28>>2]|0;
 $31 = ($30|0)==(1);
 if (!($31)) {
  $53 = (($30) + -1)|0;
  HEAP32[$28>>2] = $53;
  STACKTOP = sp;return;
 }
 $32 = ($curEntry$01$i2|0)==(0|0);
 $33 = (($29) + 32|0);
 $34 = HEAP32[$33>>2]|0;
 if ($32) {
  HEAP32[$15>>2] = $34;
  $36 = ($29|0)==(0|0);
  if (!($36)) {
   label = 9;
  }
 } else {
  $35 = (($curEntry$01$i2) + 32|0);
  HEAP32[$35>>2] = $34;
  label = 9;
 }
 if ((label|0) == 9) {
  $37 = (($this) + 4376|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + -1)|0;
  HEAP32[$37>>2] = $39;
  $40 = (($this) + 4388|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$29>>2] = $41;
  HEAP32[$40>>2] = $29;
  $42 = (($this) + 4380|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 1)|0;
  HEAP32[$42>>2] = $44;
  $45 = (($this) + 4372|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46*50)|0;
  $48 = ($43|0)<($47|0);
  if (!($48)) {
   $49 = (($this) + 4096|0);
   __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($49);
   HEAP32[$42>>2] = 0;
  }
 }
 $50 = (($this) + 4392|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + -1)|0;
 HEAP32[$50>>2] = $52;
 STACKTOP = sp;return;
}
function __ZN5physx21PxsBodyTransformVault12teleportBodyERKNS_11PxsBodyCoreE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curEntry$01$i = 0, $curEntry$01$i$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $body;
 $1 = $0 << 15;
 $2 = $1 ^ -1;
 $3 = (($0) + ($2))|0;
 $4 = $3 >>> 10;
 $5 = $4 ^ $3;
 $6 = ($5*9)|0;
 $7 = $6 >>> 6;
 $8 = $7 ^ $6;
 $9 = $8 << 11;
 $10 = $9 ^ -1;
 $11 = (($8) + ($10))|0;
 $12 = $11 >>> 16;
 $13 = $12 ^ $11;
 $14 = $13 & 1023;
 $15 = (($this) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 L1: do {
  if ($17) {
   $29 = 0;
  } else {
   $18 = (($16) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $29 = $16;
   } else {
    $25 = $19;$curEntry$01$i = $16;
    while(1) {
     $21 = (($curEntry$01$i) + 28|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==($body|0);
     if ($23) {
      $29 = $curEntry$01$i;
      break L1;
     }
     $24 = (($25) + 32|0);
     $26 = HEAP32[$24>>2]|0;
     $27 = ($26|0)==(0|0);
     if ($27) {
      $29 = $25;
      break;
     } else {
      $curEntry$01$i$phi = $25;$25 = $26;$curEntry$01$i = $curEntry$01$i$phi;
     }
    }
   }
  }
 } while(0);
 $28 = Math_fround(HEAPF32[$body>>2]);
 HEAPF32[$29>>2] = $28;
 $30 = (($body) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($29) + 4|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($body) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($29) + 8|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($body) + 12|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($29) + 12|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($body) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($29) + 16|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($body) + 20|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($29) + 20|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($body) + 24|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($29) + 24|0);
 HEAPF32[$47>>2] = $46;
 STACKTOP = sp;return;
}
function __ZNK5physx21PxsBodyTransformVault12getTransformERKNS_11PxsBodyCoreE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curEntry$0$lcssa$i = 0, $curEntry$01$i = 0, $curEntry$01$i$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $body;
 $1 = $0 << 15;
 $2 = $1 ^ -1;
 $3 = (($0) + ($2))|0;
 $4 = $3 >>> 10;
 $5 = $4 ^ $3;
 $6 = ($5*9)|0;
 $7 = $6 >>> 6;
 $8 = $7 ^ $6;
 $9 = $8 << 11;
 $10 = $9 ^ -1;
 $11 = (($8) + ($10))|0;
 $12 = $11 >>> 16;
 $13 = $12 ^ $11;
 $14 = $13 & 1023;
 $15 = (($this) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return (0|0);
 }
 $18 = (($16) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 L4: do {
  if ($20) {
   $curEntry$0$lcssa$i = $16;
  } else {
   $25 = $19;$curEntry$01$i = $16;
   while(1) {
    $21 = (($curEntry$01$i) + 28|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($body|0);
    if ($23) {
     $curEntry$0$lcssa$i = $curEntry$01$i;
     break L4;
    }
    $24 = (($25) + 32|0);
    $26 = HEAP32[$24>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     $curEntry$0$lcssa$i = $25;
     break;
    } else {
     $curEntry$01$i$phi = $25;$25 = $26;$curEntry$01$i = $curEntry$01$i$phi;
    }
   }
  }
 } while(0);
 $28 = (($curEntry$0$lcssa$i) + 28|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==($body|0);
 $$ = $30 ? $curEntry$0$lcssa$i : 0;
 STACKTOP = sp;return ($$|0);
}
function __ZN5physx21PxsBodyTransformVault6updateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $entry$0 = 0, $entry$01 = 0, $entry$02 = 0, $exitcond = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4392|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $i$03 = 0;
 }
 while(1) {
  $3 = (($this) + ($i$03<<2)|0);
  $entry$01 = HEAP32[$3>>2]|0;
  $4 = ($entry$01|0)==(0|0);
  if (!($4)) {
   $entry$02 = $entry$01;
   while(1) {
    $5 = (($entry$02) + 28|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = Math_fround(HEAPF32[$6>>2]);
    HEAPF32[$entry$02>>2] = $7;
    $8 = (($6) + 4|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = (($entry$02) + 4|0);
    HEAPF32[$10>>2] = $9;
    $11 = (($6) + 8|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    $13 = (($entry$02) + 8|0);
    HEAPF32[$13>>2] = $12;
    $14 = (($6) + 12|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = (($entry$02) + 12|0);
    HEAPF32[$16>>2] = $15;
    $17 = (($6) + 16|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = (($entry$02) + 16|0);
    HEAPF32[$19>>2] = $18;
    $20 = (($6) + 20|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = (($entry$02) + 20|0);
    HEAPF32[$22>>2] = $21;
    $23 = (($6) + 24|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = (($entry$02) + 24|0);
    HEAPF32[$25>>2] = $24;
    $26 = (($entry$02) + 32|0);
    $entry$0 = HEAP32[$26>>2]|0;
    $27 = ($entry$0|0)==(0|0);
    if ($27) {
     break;
    } else {
     $entry$02 = $entry$0;
    }
   }
  }
  $28 = (($i$03) + 1)|0;
  $exitcond = ($28|0)==(1024);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $28;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx21PxsBodyTransformVault17isInVaultInternalERKNS_11PxsBodyCoreE($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curEntry$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $body;
 $1 = $0 << 15;
 $2 = $1 ^ -1;
 $3 = (($0) + ($2))|0;
 $4 = $3 >>> 10;
 $5 = $4 ^ $3;
 $6 = ($5*9)|0;
 $7 = $6 >>> 6;
 $8 = $7 ^ $6;
 $9 = $8 << 11;
 $10 = $9 ^ -1;
 $11 = (($8) + ($10))|0;
 $12 = $11 >>> 16;
 $13 = $12 ^ $11;
 $14 = $13 & 1023;
 $15 = (($this) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $curEntry$0 = $16;
  while(1) {
   $18 = (($curEntry$0) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   $$phi$trans$insert = (($curEntry$0) + 28|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $21 = ($$pre|0)==($body|0);
   if ($20) {
    break;
   }
   if ($21) {
    $$0 = 1;
    label = 6;
    break;
   } else {
    $curEntry$0 = $19;
   }
  }
  if ((label|0) == 6) {
   STACKTOP = sp;return ($$0|0);
  }
  if ($21) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 40)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 483304 : 483272;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,483464,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 483304 : 483272;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,483464,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 483304 : 483272;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,483192,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 483304 : 483272;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,483192,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 483304 : 483272;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,483192,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 483304 : 483272;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,483552,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*40)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -40|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_21PxsBodyTransformVault13PxsBody2WorldENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_21PxsBodyTransformVault13PxsBody2WorldEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + (($30*40)|0)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 40|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN15MBP_PairManager7addPairEjjPKjPK10MBP_Object($this,$id0,$id1,$groups,$objects) {
 $this = $this|0;
 $id0 = $id0|0;
 $id1 = $id1|0;
 $groups = $groups|0;
 $objects = $objects|0;
 var $$0 = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $cond$i = 0, $cond3$i = 0, $hashValue$0 = 0, $id0$id1 = 0, $id1$id0 = 0, $offset$0$i = 0, $offset$02$i = 0, $offset$04$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($groups|0)==(0|0);
 if (!($0)) {
  $1 = $id0 >>> 2;
  $2 = $id1 >>> 2;
  $3 = (($objects) + (($1*12)|0)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($objects) + (($2*12)|0)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($groups) + ($4<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($groups) + ($6<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  if ($11) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $12 = ($id0>>>0)>($id1>>>0);
 $id1$id0 = $12 ? $id1 : $id0;
 $id0$id1 = $12 ? $id0 : $id1;
 $13 = $id1$id0 & 65535;
 $14 = $id0$id1 << 16;
 $15 = $14 | $13;
 $16 = $15 << 15;
 $17 = $16 ^ -1;
 $18 = (($15) + ($17))|0;
 $19 = $18 >> 10;
 $20 = $19 ^ $18;
 $21 = ($20*9)|0;
 $22 = $21 >> 6;
 $23 = $22 ^ $21;
 $24 = $23 << 11;
 $25 = $24 ^ -1;
 $26 = (($23) + ($25))|0;
 $27 = $26 >> 16;
 $28 = $27 ^ $26;
 $29 = (($this) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & $28;
 $32 = (($this) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 L5: do {
  if (!($34)) {
   $35 = (($this) + 20|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($this) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($33) + ($31<<2)|0);
   $offset$02$i = HEAP32[$39>>2]|0;
   $cond3$i = ($offset$02$i|0)==(-1);
   if (!($cond3$i)) {
    $offset$04$i = $offset$02$i;
    while(1) {
     $40 = (($36) + (($offset$04$i*12)|0)|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==($id1$id0|0);
     if ($42) {
      $43 = ((($36) + (($offset$04$i*12)|0)|0) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==($id0$id1|0);
      if ($45) {
       break;
      }
     }
     $46 = (($38) + ($offset$04$i<<2)|0);
     $offset$0$i = HEAP32[$46>>2]|0;
     $cond$i = ($offset$0$i|0)==(-1);
     if ($cond$i) {
      break L5;
     } else {
      $offset$04$i = $offset$0$i;
     }
    }
    $47 = ($40|0)==(0|0);
    if (!($47)) {
     $48 = ((($36) + (($offset$04$i*12)|0)|0) + 9|0);
     HEAP8[$48>>0] = 1;
     $$0 = $40;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $49 = (($this) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$this>>2]|0;
 $52 = ($50>>>0)<($51>>>0);
 if ($52) {
  $70 = $50;$75 = $33;$hashValue$0 = $31;
 } else {
  $53 = (($50) + 1)|0;
  $54 = $53 >>> 1;
  $55 = $54 | $53;
  $56 = $55 >>> 2;
  $57 = $56 | $55;
  $58 = $57 >>> 4;
  $59 = $58 | $57;
  $60 = $59 >>> 8;
  $61 = $60 | $59;
  $62 = $61 >>> 16;
  $63 = $62 | $61;
  $64 = (($63) + 1)|0;
  HEAP32[$this>>2] = $64;
  HEAP32[$29>>2] = $63;
  __ZN15MBP_PairManager12reallocPairsEv($this);
  $65 = HEAP32[$29>>2]|0;
  $66 = $65 & $28;
  $$pre = HEAP32[$49>>2]|0;
  $$pre6 = HEAP32[$32>>2]|0;
  $70 = $$pre;$75 = $$pre6;$hashValue$0 = $66;
 }
 $67 = (($this) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + (($70*12)|0)|0);
 HEAP32[$69>>2] = $id1$id0;
 $71 = ((($68) + (($70*12)|0)|0) + 4|0);
 HEAP32[$71>>2] = $id0$id1;
 $72 = ((($68) + (($70*12)|0)|0) + 8|0);
 HEAP8[$72>>0] = 1;
 $73 = ((($68) + (($70*12)|0)|0) + 9|0);
 HEAP8[$73>>0] = 0;
 $74 = (($75) + ($hashValue$0<<2)|0);
 $76 = HEAP32[$74>>2]|0;
 $77 = HEAP32[$49>>2]|0;
 $78 = (($this) + 16|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($79) + ($77<<2)|0);
 HEAP32[$80>>2] = $76;
 $81 = HEAP32[$49>>2]|0;
 $82 = (($81) + 1)|0;
 HEAP32[$49>>2] = $82;
 HEAP32[$74>>2] = $81;
 $$0 = $69;
 STACKTOP = sp;return ($$0|0);
}
function __ZN15MBP_PairManager12reallocPairsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $phitmp = 0, $phitmp4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = sp + 4|0;
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
  HEAP32[$6>>2] = 0;
 }
 $9 = HEAP32[$this>>2]|0;
 $10 = $9 << 2;
 $11 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$10,483632,1029)|0);
 HEAP32[$6>>2] = $11;
 $12 = HEAP32[$this>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  $15 = 0;
 } else {
  $14 = $12 << 2;
  _memset(($11|0),-1,($14|0))|0;
  $$pre = HEAP32[$this>>2]|0;
  $phitmp = ($$pre*12)|0;
  $15 = $phitmp;
 }
 $16 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$15,483632,1033)|0);
 $17 = HEAP32[$this>>2]|0;
 $18 = $17 << 2;
 $19 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$18,483632,1034)|0);
 $20 = (($this) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($this) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($21*12)|0;
  _memcpy(($16|0),($24|0),($25|0))|0;
  $$pre2 = HEAP32[$20>>2]|0;
  $phitmp4 = ($$pre2|0)==(0);
  if (!($phitmp4)) {
   $26 = (($this) + 20|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($this) + 4|0);
   $29 = HEAP32[$6>>2]|0;
   $i$01 = 0;
   while(1) {
    $30 = (($27) + (($i$01*12)|0)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($27) + (($i$01*12)|0)|0) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = $31 & 65535;
    $35 = $33 << 16;
    $36 = $35 | $34;
    $37 = $36 << 15;
    $38 = $37 ^ -1;
    $39 = (($36) + ($38))|0;
    $40 = $39 >> 10;
    $41 = $40 ^ $39;
    $42 = ($41*9)|0;
    $43 = $42 >> 6;
    $44 = $43 ^ $42;
    $45 = $44 << 11;
    $46 = $45 ^ -1;
    $47 = (($44) + ($46))|0;
    $48 = $47 >> 16;
    $49 = $48 ^ $47;
    $50 = HEAP32[$28>>2]|0;
    $51 = $49 & $50;
    $52 = (($29) + ($51<<2)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($19) + ($i$01<<2)|0);
    HEAP32[$54>>2] = $53;
    HEAP32[$52>>2] = $i$01;
    $55 = (($i$01) + 1)|0;
    $56 = HEAP32[$20>>2]|0;
    $57 = ($55>>>0)<($56>>>0);
    if ($57) {
     $i$01 = $55;
    } else {
     break;
    }
   }
  }
 }
 $58 = (($this) + 16|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0|0);
 if (!($60)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$59);
  HEAP32[$58>>2] = 0;
 }
 $61 = (($this) + 20|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0|0);
 if ($63) {
  HEAP32[$61>>2] = $16;
  HEAP32[$58>>2] = $19;
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$62);
 HEAP32[$61>>2] = 0;
 HEAP32[$61>>2] = $16;
 HEAP32[$58>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN15MBP_PairManager10removePairEjjjj($this,$0,$1,$hashValue,$pairIndex) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $hashValue = $hashValue|0;
 $pairIndex = $pairIndex|0;
 var $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $offset$0 = 0, $offset$03 = 0, $offset$04 = 0, $offset1$0 = 0, $offset1$01 = 0, $offset1$02 = 0, $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($hashValue<<2)|0);
 $offset$03 = HEAP32[$4>>2]|0;
 $5 = ($offset$03|0)==($pairIndex|0);
 $$phi$trans$insert = (($this) + 16|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if ($5) {
  $6 = (($this) + 16|0);
  $7 = (($$pre) + ($pairIndex<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $16 = $8;$66 = $6;
  label = 6;
 } else {
  $offset$04 = $offset$03;
  while(1) {
   $9 = (($$pre) + ($offset$04<<2)|0);
   $offset$0 = HEAP32[$9>>2]|0;
   $10 = ($offset$0|0)==($pairIndex|0);
   if ($10) {
    break;
   } else {
    $offset$04 = $offset$0;
   }
  }
  $11 = ($offset$04|0)==(-1);
  $12 = (($this) + 16|0);
  $13 = (($$pre) + ($pairIndex<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  if ($11) {
   $16 = $14;$66 = $12;
   label = 6;
  } else {
   $15 = (($$pre) + ($offset$04<<2)|0);
   HEAP32[$15>>2] = $14;
   $63 = $12;
  }
 }
 if ((label|0) == 6) {
  HEAP32[$4>>2] = $16;
  $63 = $66;
 }
 $17 = (($this) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + -1)|0;
 $20 = ($19|0)==($pairIndex|0);
 if ($20) {
  $storemerge$in = $18;
  $storemerge = (($storemerge$in) + -1)|0;
  HEAP32[$17>>2] = $storemerge;
  STACKTOP = sp;return;
 }
 $21 = (($this) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + (($19*12)|0)|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($22) + (($19*12)|0)|0) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $24 & 65535;
 $28 = $26 << 16;
 $29 = $28 | $27;
 $30 = $29 << 15;
 $31 = $30 ^ -1;
 $32 = (($29) + ($31))|0;
 $33 = $32 >> 10;
 $34 = $33 ^ $32;
 $35 = ($34*9)|0;
 $36 = $35 >> 6;
 $37 = $36 ^ $35;
 $38 = $37 << 11;
 $39 = $38 ^ -1;
 $40 = (($37) + ($39))|0;
 $41 = $40 >> 16;
 $42 = $41 ^ $40;
 $43 = (($this) + 4|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $42 & $44;
 $46 = (($3) + ($45<<2)|0);
 $offset1$01 = HEAP32[$46>>2]|0;
 $47 = ($offset1$01|0)==($19|0);
 if ($47) {
  $48 = (($$pre) + ($19<<2)|0);
  $49 = HEAP32[$48>>2]|0;
  $56 = $49;
  label = 13;
 } else {
  $offset1$02 = $offset1$01;
  while(1) {
   $50 = (($$pre) + ($offset1$02<<2)|0);
   $offset1$0 = HEAP32[$50>>2]|0;
   $51 = ($offset1$0|0)==($19|0);
   if ($51) {
    break;
   } else {
    $offset1$02 = $offset1$0;
   }
  }
  $52 = ($offset1$02|0)==(-1);
  $53 = (($$pre) + ($19<<2)|0);
  $54 = HEAP32[$53>>2]|0;
  if ($52) {
   $56 = $54;
   label = 13;
  } else {
   $55 = (($$pre) + ($offset1$02<<2)|0);
   HEAP32[$55>>2] = $54;
  }
 }
 if ((label|0) == 13) {
  HEAP32[$46>>2] = $56;
 }
 $57 = (($22) + (($pairIndex*12)|0)|0);
 $58 = (($22) + (($19*12)|0)|0);
 ;HEAP32[$57+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$58+4>>2]|0;HEAP16[$57+8>>1]=HEAP16[$58+8>>1]|0;
 $59 = HEAP32[$2>>2]|0;
 $60 = (($59) + ($45<<2)|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$63>>2]|0;
 $64 = (($62) + ($pairIndex<<2)|0);
 HEAP32[$64>>2] = $61;
 HEAP32[$60>>2] = $pairIndex;
 $65 = HEAP32[$17>>2]|0;
 $storemerge$in = $65;
 $storemerge = (($storemerge$in) + -1)|0;
 HEAP32[$17>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZN9BoxPrunerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond1$i = 0, $or$cond2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = (($this) + 76|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
  HEAP32[$5>>2] = 0;
 }
 $8 = (($this) + 112|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$9);
  HEAP32[$8>>2] = 0;
 }
 $11 = (($this) + 108|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$12);
  HEAP32[$11>>2] = 0;
 }
 $14 = (($this) + 104|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$15);
  HEAP32[$14>>2] = 0;
 }
 $17 = (($this) + 100|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$18);
  HEAP32[$17>>2] = 0;
 }
 $20 = (($this) + 96|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$21);
  HEAP32[$20>>2] = 0;
 }
 $23 = (($this) + 12984|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 12464|0);
 $26 = ($24|0)==($25|0);
 $27 = ($24|0)==(0|0);
 $or$cond$i = $26 | $27;
 if (!($or$cond$i)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$24);
  HEAP32[$23>>2] = 0;
 }
 $28 = (($this) + 12988|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 176|0);
 $31 = ($29|0)==($30|0);
 $32 = ($29|0)==(0|0);
 $or$cond1$i = $31 | $32;
 if (!($or$cond1$i)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$29);
  HEAP32[$28>>2] = 0;
 }
 $33 = (($this) + 12992|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 6320|0);
 $36 = ($34|0)==($35|0);
 $37 = ($34|0)==(0|0);
 $or$cond2$i = $36 | $37;
 if (!($or$cond2$i)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$34);
  HEAP32[$33>>2] = 0;
 }
 $38 = (($this) + 12976|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 12980|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 132|0);
 __ZN5physx2Gu17RadixSortBufferedD2Ev($40);
 $41 = (($this) + 124|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  HEAP32[$41>>2] = 0;
  $44 = (($this) + 128|0);
  HEAP32[$44>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$42);
 HEAP32[$41>>2] = 0;
 HEAP32[$41>>2] = 0;
 $44 = (($this) + 128|0);
 HEAP32[$44>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9BoxPruner10staticSortEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$arith = 0, $$overflow = 0, $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $RS = 0, $boxIndex$0 = 0, $exitcond = 0, $exitcond16 = 0, $i$08 = 0, $i1$07 = 0, $nbSorted$010 = 0, $nbSorted$1 = 0, $nbToSort$011 = 0, $nbToSort$1 = 0, $nextCandidateNonSorted$05 = 0, $nextCandidateNonSorted$1 = 0;
 var $nextCandidateSorted$0$ph = 0, $nextCandidateSorted$06 = 0, $nextCandidateSorted$1 = 0, $offsetNonSorted$04 = 0, $offsetNonSorted$1 = 0, $offsetSorted$03 = 0, $offsetSorted$1 = 0, $or$cond = 0, $sorted$0 = 0, $sorted$0$in = 0, $stackBuffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 8240|0;
 $0 = sp + 8235|0;
 $stackBuffer = sp + 40|0;
 $1 = sp + 36|0;
 $RS = sp;
 $2 = sp + 8232|0;
 $3 = sp + 8233|0;
 $4 = sp + 8234|0;
 $5 = (($this) + 168|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 84|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $9 = (($this) + 124|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$10);
   HEAP32[$9>>2] = 0;
  }
  HEAP32[$9>>2] = 0;
  $12 = (($this) + 128|0);
  HEAP32[$12>>2] = 0;
  STACKTOP = sp;return;
 }
 $13 = $7 << 2;
 $14 = $7 << 4;
 $15 = ($14>>>0)<(8193);
 if ($15) {
  $18 = $stackBuffer;
 } else {
  $16 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$14,483632,1197)|0);
  $18 = $16;
 }
 $17 = (($18) + ($13)|0);
 $19 = $7 << 3;
 $20 = (($18) + ($19)|0);
 $21 = ($7*12)|0;
 $22 = (($18) + ($21)|0);
 $23 = (($this) + 128|0);
 $24 = (($this) + 124|0);
 $25 = (($this) + 96|0);
 $i$08 = 0;$nbSorted$010 = 0;$nbToSort$011 = 0;
 while(1) {
  $26 = $i$08 >>> 5;
  $27 = HEAP32[$23>>2]|0;
  $28 = ($26>>>0)<($27>>>0);
  if ($28) {
   $32 = HEAP32[$24>>2]|0;
   $33 = (($32) + ($26<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = $i$08 & 31;
   $36 = 1 << $35;
   $37 = $34 & $36;
   $38 = ($37|0)==(0);
   $39 = HEAP32[$25>>2]|0;
   $40 = (($39) + (($i$08*24)|0)|0);
   $41 = HEAP32[$40>>2]|0;
   if ($38) {
    $46 = $41;
    label = 12;
   } else {
    $42 = (($18) + ($nbToSort$011<<2)|0);
    HEAP32[$42>>2] = $41;
    $43 = (($20) + ($nbToSort$011<<2)|0);
    HEAP32[$43>>2] = $i$08;
    $44 = (($nbToSort$011) + 1)|0;
    $nbSorted$1 = $nbSorted$010;$nbToSort$1 = $44;
   }
  } else {
   $29 = HEAP32[$25>>2]|0;
   $30 = (($29) + (($i$08*24)|0)|0);
   $31 = HEAP32[$30>>2]|0;
   $46 = $31;
   label = 12;
  }
  if ((label|0) == 12) {
   label = 0;
   $45 = (($17) + ($nbSorted$010<<2)|0);
   HEAP32[$45>>2] = $46;
   $47 = (($22) + ($nbSorted$010<<2)|0);
   HEAP32[$47>>2] = $i$08;
   $48 = (($nbSorted$010) + 1)|0;
   $nbSorted$1 = $48;$nbToSort$1 = $nbToSort$011;
  }
  $49 = (($i$08) + 1)|0;
  $exitcond16 = ($49|0)==($7|0);
  if ($exitcond16) {
   break;
  } else {
   $i$08 = $49;$nbSorted$010 = $nbSorted$1;$nbToSort$011 = $nbToSort$1;
  }
 }
 __ZN5physx2Gu17RadixSortBufferedC2Ev($RS);
 $50 = ($nbToSort$1>>>0)<(1024);
 if ($50) {
  $51 = (($this) + 132|0);
  $52 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($51,$18,$nbToSort$1,1)|0);
  $$pn = $52;
 } else {
  $53 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($RS,$18,$nbToSort$1,1)|0);
  $$pn = $53;
 }
 $sorted$0$in = (($$pn) + 8|0);
 $sorted$0 = HEAP32[$sorted$0$in>>2]|0;
 $54 = (($this) + 80|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 << 1;
 $57 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$56,483632,1245)|0);
 $58 = HEAP32[$54>>2]|0;
 $59 = (($58) + 2)|0;
 $$arith = ($59*24)|0;
 $$overflow = ($59>>>0)>(178956970);
 $60 = $$overflow ? -1 : $$arith;
 $61 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + 8|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (__Z15PxGetFoundationv()|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 24|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (FUNCTION_TABLE_ii[$68 & 4095]($65)|0);
 $$$i$i$i = $69 ? 484432 : 484000;
 $70 = (FUNCTION_TABLE_iiiiii[$64 & 255]($61,$60,$$$i$i$i,483632,1250)|0);
 $71 = (($70) + (($7*24)|0)|0);
 HEAP32[$71>>2] = -1;
 $72 = (($7) + 1)|0;
 $73 = (($70) + (($72*24)|0)|0);
 HEAP32[$73>>2] = -1;
 $74 = ($nbToSort$1|0)==(0);
 if ($74) {
  $123 = -1;
 } else {
  $75 = HEAP32[$sorted$0>>2]|0;
  $76 = (($18) + ($75<<2)|0);
  $77 = HEAP32[$76>>2]|0;
  $123 = $77;
 }
 $78 = ($nbSorted$1|0)==(0);
 if ($78) {
  $nextCandidateSorted$0$ph = -1;
 } else {
  $79 = HEAP32[$17>>2]|0;
  $nextCandidateSorted$0$ph = $79;
 }
 $80 = (($this) + 104|0);
 $81 = (($this) + 96|0);
 $82 = (($this) + 76|0);
 $i1$07 = 0;$nextCandidateNonSorted$05 = $123;$nextCandidateSorted$06 = $nextCandidateSorted$0$ph;$offsetNonSorted$04 = 0;$offsetSorted$03 = 0;
 while(1) {
  $83 = ($nextCandidateNonSorted$05>>>0)<($nextCandidateSorted$06>>>0);
  if ($83) {
   $84 = (($sorted$0) + ($offsetNonSorted$04<<2)|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($20) + ($85<<2)|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($offsetNonSorted$04) + 1)|0;
   $89 = ($88>>>0)<($nbToSort$1>>>0);
   if ($89) {
    $90 = (($sorted$0) + ($88<<2)|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($18) + ($91<<2)|0);
    $93 = HEAP32[$92>>2]|0;
    $boxIndex$0 = $87;$nextCandidateNonSorted$1 = $93;$nextCandidateSorted$1 = $nextCandidateSorted$06;$offsetNonSorted$1 = $88;$offsetSorted$1 = $offsetSorted$03;
   } else {
    $boxIndex$0 = $87;$nextCandidateNonSorted$1 = -1;$nextCandidateSorted$1 = $nextCandidateSorted$06;$offsetNonSorted$1 = $88;$offsetSorted$1 = $offsetSorted$03;
   }
  } else {
   $94 = (($22) + ($offsetSorted$03<<2)|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($offsetSorted$03) + 1)|0;
   $97 = ($96>>>0)<($nbSorted$1>>>0);
   if ($97) {
    $98 = (($17) + ($96<<2)|0);
    $99 = HEAP32[$98>>2]|0;
    $boxIndex$0 = $95;$nextCandidateNonSorted$1 = $nextCandidateNonSorted$05;$nextCandidateSorted$1 = $99;$offsetNonSorted$1 = $offsetNonSorted$04;$offsetSorted$1 = $96;
   } else {
    $boxIndex$0 = $95;$nextCandidateNonSorted$1 = $nextCandidateNonSorted$05;$nextCandidateSorted$1 = -1;$offsetNonSorted$1 = $offsetNonSorted$04;$offsetSorted$1 = $96;
   }
  }
  $100 = HEAP32[$80>>2]|0;
  $101 = (($100) + ($boxIndex$0<<1)|0);
  $102 = HEAP16[$101>>1]|0;
  $103 = (($70) + (($i1$07*24)|0)|0);
  $104 = HEAP32[$81>>2]|0;
  $105 = (($104) + (($boxIndex$0*24)|0)|0);
  ;HEAP32[$103+0>>2]=HEAP32[$105+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$105+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$105+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$105+12>>2]|0;HEAP32[$103+16>>2]=HEAP32[$105+16>>2]|0;HEAP32[$103+20>>2]=HEAP32[$105+20>>2]|0;
  $106 = (($57) + ($i1$07<<1)|0);
  HEAP16[$106>>1] = $102;
  $107 = $102&65535;
  $108 = HEAP32[$82>>2]|0;
  $109 = (($108) + ($107<<3)|0);
  HEAP32[$109>>2] = $i1$07;
  $110 = (($i1$07) + 1)|0;
  $exitcond = ($110|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $i1$07 = $110;$nextCandidateNonSorted$05 = $nextCandidateNonSorted$1;$nextCandidateSorted$06 = $nextCandidateSorted$1;$offsetNonSorted$04 = $offsetNonSorted$1;$offsetSorted$03 = $offsetSorted$1;
  }
 }
 $111 = ($18|0)!=($stackBuffer|0);
 $112 = ($18|0)!=(0|0);
 $or$cond = $111 & $112;
 if ($or$cond) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$18);
 }
 $113 = (($this) + 96|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = ($114|0)==(0|0);
 if (!($115)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$114);
  HEAP32[$113>>2] = 0;
 }
 HEAP32[$113>>2] = $70;
 $116 = (($this) + 104|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ($117|0)==(0|0);
 if (!($118)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$117);
  HEAP32[$116>>2] = 0;
 }
 HEAP32[$116>>2] = $57;
 $119 = (($this) + 124|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($120|0)==(0|0);
 if (!($121)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$120);
  HEAP32[$119>>2] = 0;
 }
 HEAP32[$119>>2] = 0;
 $122 = (($this) + 128|0);
 HEAP32[$122>>2] = 0;
 __ZN5physx2Gu17RadixSortBufferedD2Ev($RS);
 STACKTOP = sp;return;
}
function __ZN9BoxPruner13resizeObjectsEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$arith = 0, $$overflow = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 128)|0;
 $$arith = $3<<3;
 $$overflow = ($3>>>0)>(536870911);
 $4 = $$overflow ? -1 : $$arith;
 $5 = ($4|0)==(0);
 if ($5) {
  $18 = 0;
 } else {
  $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__Z15PxGetFoundationv()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
  $$$i$i$i = $14 ? 484336 : 484000;
  $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,$4,$$$i$i$i,483632,1327)|0);
  $18 = $15;
 }
 $16 = ($3|0)==(0);
 if (!($16)) {
  $17 = (($18) + ($3<<3)|0);
  $20 = $18;
  while(1) {
   $19 = (($20) + 4|0);
   HEAP32[$19>>2] = -1;
   $21 = (($20) + 8|0);
   $22 = ($21|0)==($17|0);
   if ($22) {
    break;
   } else {
    $20 = $21;
   }
  }
 }
 $23 = (($this) + 64|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 $$pre = (($this) + 76|0);
 if (!($25)) {
  $26 = HEAP32[$$pre>>2]|0;
  $27 = $24 << 3;
  _memcpy(($18|0),($26|0),($27|0))|0;
 }
 $28 = HEAP32[$$pre>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  HEAP32[$$pre>>2] = $18;
  HEAP32[$1>>2] = $3;
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$28);
 HEAP32[$$pre>>2] = 0;
 HEAP32[$$pre>>2] = $18;
 HEAP32[$1>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN9BoxPruner9addObjectERK5IAABBjb($this,$bounds,$mbpHandle,$isStatic) {
 $this = $this|0;
 $bounds = $bounds|0;
 $mbpHandle = $mbpHandle|0;
 $isStatic = $isStatic|0;
 var $$$i$i$i$i = 0, $$$i$i$i$i2 = 0, $$arith = 0, $$arith2 = 0, $$overflow = 0, $$overflow3 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$phi12Z2D = 0, $$pre$phi14Z2D = 0, $$pre$phi16Z2D = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $$pre11 = 0, $$pre13 = 0, $$pre15 = 0, $$pre6 = 0, $$pre7 = 0;
 var $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $box0$sroa$0$i = 0, $handle$0 = 0;
 var $handle$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $box0$sroa$0$i = sp;
 $0 = sp + 26|0;
 $1 = sp + 24|0;
 $2 = sp + 25|0;
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 if ($5) {
  $11 = (($this) + 68|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($this) + 64|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  if ($15) {
   __ZN9BoxPruner13resizeObjectsEv($this);
   $$pre = HEAP32[$13>>2]|0;
   $18 = $$pre;$handle$0$in = $$pre;
  } else {
   $18 = $14;$handle$0$in = $14;
  }
 } else {
  $6 = $4 & 65535;
  $7 = (($this) + 76|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($6<<3)|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$3>>2] = $10;
  $$phi$trans$insert = (($this) + 64|0);
  $$pre6 = HEAP32[$$phi$trans$insert>>2]|0;
  $18 = $$pre6;$handle$0$in = $4;
 }
 $handle$0 = $handle$0$in&65535;
 $16 = (($this) + 64|0);
 $17 = (($18) + 1)|0;
 HEAP32[$16>>2] = $17;
 if ($isStatic) {
  $19 = (($this) + 80|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($this) + 84|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($20|0)==($22|0);
  if ($23) {
   $24 = (($20) + 128)|0;
   $25 = (($this) + 96|0);
   $26 = HEAP32[$25>>2]|0;
   $$arith2 = ($24*24)|0;
   $$overflow3 = ($24>>>0)>(178956970);
   $27 = $$overflow3 ? -1 : $$arith2;
   $28 = ($27|0)==(0);
   if ($28) {
    $41 = 0;
   } else {
    $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (__Z15PxGetFoundationv()|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 24|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (FUNCTION_TABLE_ii[$36 & 4095]($33)|0);
    $$$i$i$i$i = $37 ? 484432 : 484000;
    $38 = (FUNCTION_TABLE_iiiiii[$32 & 255]($29,$27,$$$i$i$i$i,483632,1341)|0);
    $41 = $38;
   }
   $39 = ($20|0)==(0);
   if (!($39)) {
    $40 = ($20*24)|0;
    _memcpy(($41|0),($26|0),($40|0))|0;
   }
   $42 = ($26|0)==(0|0);
   if (!($42)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($box0$sroa$0$i,$26);
   }
   HEAP32[$25>>2] = $41;
   $43 = HEAP32[$21>>2]|0;
   $44 = (($this) + 104|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = $24 << 1;
   $47 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($box0$sroa$0$i,$46,483632,1350)|0);
   $48 = ($43|0)==(0);
   if (!($48)) {
    $49 = $43 << 1;
    _memcpy(($47|0),($45|0),($49|0))|0;
   }
   $50 = ($45|0)==(0|0);
   if (!($50)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$45);
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$19>>2] = $24;
   $$pre7 = HEAP32[$21>>2]|0;
   $$pre$phi12Z2D = $44;$$pre$phiZ2D = $25;$52 = $$pre7;
  } else {
   $$pre10 = (($this) + 96|0);
   $$pre11 = (($this) + 104|0);
   $$pre$phi12Z2D = $$pre11;$$pre$phiZ2D = $$pre10;$52 = $22;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$21>>2] = $51;
  $53 = HEAP32[$$pre$phiZ2D>>2]|0;
  $54 = (($53) + (($52*24)|0)|0);
  ;HEAP32[$54+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$54+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$54+20>>2]=HEAP32[$bounds+20>>2]|0;
  $55 = HEAP32[$$pre$phi12Z2D>>2]|0;
  $56 = (($55) + ($52<<1)|0);
  HEAP16[$56>>1] = $handle$0;
  $57 = (($this) + 168|0);
  HEAP8[$57>>0] = 1;
  $58 = (($this) + 124|0);
  $59 = $52 >>> 5;
  $60 = (($this) + 128|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($59>>>0)<($61>>>0);
  if ($62) {
   $$pre$i = HEAP32[$58>>2]|0;
   $85 = $$pre$i;
  } else {
   $63 = (($52) + 128)|0;
   $64 = $63 >>> 5;
   $65 = $63 & 31;
   $66 = ($65|0)!=(0);
   $67 = $66&1;
   $68 = (($67) + ($64))|0;
   $69 = $68 << 2;
   $70 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($box0$sroa$0$i,$69,483632,429)|0);
   $71 = HEAP32[$60>>2]|0;
   $72 = ($71|0)==(0);
   if ($72) {
    $76 = 0;
   } else {
    $73 = HEAP32[$58>>2]|0;
    $74 = $71 << 2;
    _memcpy(($70|0),($73|0),($74|0))|0;
    $$pre$i$i = HEAP32[$60>>2]|0;
    $76 = $$pre$i$i;
   }
   $75 = ($68|0)==($76|0);
   if (!($75)) {
    $77 = (($68) - ($76))|0;
    $78 = (($70) + ($76<<2)|0);
    $79 = $77 << 2;
    _memset(($78|0),0,($79|0))|0;
   }
   $80 = HEAP32[$58>>2]|0;
   $81 = ($80|0)==(0|0);
   if (!($81)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$80);
    HEAP32[$58>>2] = 0;
   }
   HEAP32[$58>>2] = $70;
   HEAP32[$60>>2] = $68;
   $85 = $70;
  }
  $82 = $52 & 31;
  $83 = 1 << $82;
  $84 = (($85) + ($59<<2)|0);
  $86 = HEAP32[$84>>2]|0;
  $87 = $86 | $83;
  HEAP32[$84>>2] = $87;
  $136 = $52;
 } else {
  $88 = (($this) + 88|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (($this) + 92|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($89|0)==($91|0);
  if ($92) {
   $93 = (($89) + 128)|0;
   $94 = (($this) + 100|0);
   $95 = HEAP32[$94>>2]|0;
   $$arith = ($93*24)|0;
   $$overflow = ($93>>>0)>(178956970);
   $96 = $$overflow ? -1 : $$arith;
   $97 = ($96|0)==(0);
   if ($97) {
    $110 = 0;
   } else {
    $98 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($99) + 8|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = (__Z15PxGetFoundationv()|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($103) + 24|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (FUNCTION_TABLE_ii[$105 & 4095]($102)|0);
    $$$i$i$i$i2 = $106 ? 484432 : 484000;
    $107 = (FUNCTION_TABLE_iiiiii[$101 & 255]($98,$96,$$$i$i$i$i2,483632,1341)|0);
    $110 = $107;
   }
   $108 = ($89|0)==(0);
   if (!($108)) {
    $109 = ($89*24)|0;
    _memcpy(($110|0),($95|0),($109|0))|0;
   }
   $111 = ($95|0)==(0|0);
   if (!($111)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($box0$sroa$0$i,$95);
   }
   HEAP32[$94>>2] = $110;
   $112 = HEAP32[$90>>2]|0;
   $113 = (($this) + 108|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = $93 << 1;
   $116 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($box0$sroa$0$i,$115,483632,1350)|0);
   $117 = ($112|0)==(0);
   if (!($117)) {
    $118 = $112 << 1;
    _memcpy(($116|0),($114|0),($118|0))|0;
   }
   $119 = ($114|0)==(0|0);
   if (!($119)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$114);
   }
   HEAP32[$113>>2] = $116;
   HEAP32[$88>>2] = $93;
   $120 = (($this) + 112|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($121|0)==(0|0);
   if (!($122)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$121);
    HEAP32[$120>>2] = 0;
   }
   $123 = $93 << 2;
   $124 = (($123) + 4)|0;
   $125 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$124,483632,1429)|0);
   HEAP32[$120>>2] = $125;
   $$pre8 = HEAP32[$90>>2]|0;
   $$pre$phi14Z2D = $94;$$pre$phi16Z2D = $113;$127 = $$pre8;
  } else {
   $$pre13 = (($this) + 100|0);
   $$pre15 = (($this) + 108|0);
   $$pre$phi14Z2D = $$pre13;$$pre$phi16Z2D = $$pre15;$127 = $91;
  }
  $126 = (($127) + 1)|0;
  HEAP32[$90>>2] = $126;
  $128 = HEAP32[$$pre$phi14Z2D>>2]|0;
  $129 = (($128) + (($127*24)|0)|0);
  ;HEAP32[$129+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$129+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$129+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$129+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$129+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$129+20>>2]=HEAP32[$bounds+20>>2]|0;
  $130 = HEAP32[$$pre$phi16Z2D>>2]|0;
  $131 = (($130) + ($127<<1)|0);
  HEAP16[$131>>1] = $handle$0;
  $136 = $127;
 }
 $132 = $handle$0$in & 65535;
 $133 = (($this) + 76|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = (($134) + ($132<<3)|0);
 HEAP32[$135>>2] = $136;
 $137 = ((($134) + ($132<<3)|0) + 4|0);
 HEAP32[$137>>2] = $mbpHandle;
 if ($isStatic) {
  STACKTOP = sp;return ($handle$0|0);
 }
 $138 = (($this) + 100|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = (($this) + 108|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (($this) + 116|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = ($136|0)==($143|0);
 $145 = (($139) + (($143*24)|0)|0);
 if ($144) {
  ;HEAP32[$145+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$145+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$145+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$145+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$145+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$145+20>>2]=HEAP32[$bounds+20>>2]|0;
 } else {
  ;HEAP32[$box0$sroa$0$i+0>>2]=HEAP32[$145+0>>2]|0;HEAP32[$box0$sroa$0$i+4>>2]=HEAP32[$145+4>>2]|0;HEAP32[$box0$sroa$0$i+8>>2]=HEAP32[$145+8>>2]|0;HEAP32[$box0$sroa$0$i+12>>2]=HEAP32[$145+12>>2]|0;HEAP32[$box0$sroa$0$i+16>>2]=HEAP32[$145+16>>2]|0;HEAP32[$box0$sroa$0$i+20>>2]=HEAP32[$145+20>>2]|0;
  ;HEAP32[$145+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$145+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$145+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$145+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$145+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$145+20>>2]=HEAP32[$bounds+20>>2]|0;
  $146 = (($139) + (($136*24)|0)|0);
  ;HEAP32[$146+0>>2]=HEAP32[$box0$sroa$0$i+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$box0$sroa$0$i+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$box0$sroa$0$i+8>>2]|0;HEAP32[$146+12>>2]=HEAP32[$box0$sroa$0$i+12>>2]|0;HEAP32[$146+16>>2]=HEAP32[$box0$sroa$0$i+16>>2]|0;HEAP32[$146+20>>2]=HEAP32[$box0$sroa$0$i+20>>2]|0;
  $147 = (($141) + ($143<<1)|0);
  $148 = HEAP16[$147>>1]|0;
  $149 = (($141) + ($136<<1)|0);
  $150 = HEAP16[$149>>1]|0;
  HEAP16[$147>>1] = $150;
  HEAP16[$149>>1] = $148;
  $151 = $148&65535;
  $152 = (($134) + ($151<<3)|0);
  HEAP32[$152>>2] = $136;
  HEAP32[$135>>2] = $143;
 }
 $153 = HEAP32[$142>>2]|0;
 $154 = (($153) + 1)|0;
 HEAP32[$142>>2] = $154;
 $155 = (($this) + 120|0);
 HEAP32[$155>>2] = 0;
 $156 = (($this) + 169|0);
 HEAP8[$156>>0] = 1;
 STACKTOP = sp;return ($handle$0|0);
}
function __ZN9BoxPruner12removeObjectEt($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $boxes$0 = 0, $lastIndex$0 = 0, $mapping$0 = 0, $removedBoxIndex$0 = 0, $removedBoxIndex$1 = 0, $removedBoxIndex$2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = $handle&65535;
 $3 = (($this) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($2<<3)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + ($2<<3)|0) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = (($this) + 120|0);
  HEAP32[$11>>2] = 0;
  $12 = (($this) + 169|0);
  HEAP8[$12>>0] = 1;
  $13 = (($this) + 116|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($6>>>0)<($14>>>0);
  $16 = (($this) + 92|0);
  if ($15) {
   $17 = HEAP32[$16>>2]|0;
   $18 = ($14|0)==($17|0);
   if ($18) {
    $32 = $14;$removedBoxIndex$0 = $6;
   } else {
    $19 = (($14) + -1)|0;
    $20 = (($this) + 108|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($this) + 100|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + ($19<<1)|0);
    $25 = HEAP16[$24>>1]|0;
    $26 = $25&65535;
    $27 = (($23) + (($6*24)|0)|0);
    $28 = (($23) + (($19*24)|0)|0);
    ;HEAP32[$27+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$28+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$28+12>>2]|0;HEAP32[$27+16>>2]=HEAP32[$28+16>>2]|0;HEAP32[$27+20>>2]=HEAP32[$28+20>>2]|0;
    $29 = (($21) + ($6<<1)|0);
    HEAP16[$29>>1] = $25;
    $30 = (($4) + ($26<<3)|0);
    HEAP32[$30>>2] = $6;
    $$pre = HEAP32[$13>>2]|0;
    $32 = $$pre;$removedBoxIndex$0 = $19;
   }
   $31 = (($32) + -1)|0;
   HEAP32[$13>>2] = $31;
   $removedBoxIndex$1 = $removedBoxIndex$0;
  } else {
   $removedBoxIndex$1 = $6;
  }
  $33 = (($this) + 108|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($this) + 100|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP32[$16>>2]|0;
  $38 = (($37) + -1)|0;
  HEAP32[$16>>2] = $38;
  $boxes$0 = $36;$lastIndex$0 = $38;$mapping$0 = $34;$removedBoxIndex$2 = $removedBoxIndex$1;
 } else {
  $39 = (($this) + 168|0);
  HEAP8[$39>>0] = 1;
  $40 = (($this) + 124|0);
  $41 = $6 >>> 5;
  $42 = (($this) + 128|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($41>>>0)<($43>>>0);
  if ($44) {
   $$pre$i = HEAP32[$40>>2]|0;
   $67 = $$pre$i;
  } else {
   $45 = (($6) + 128)|0;
   $46 = $45 >>> 5;
   $47 = $45 & 31;
   $48 = ($47|0)!=(0);
   $49 = $48&1;
   $50 = (($49) + ($46))|0;
   $51 = $50 << 2;
   $52 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$51,483632,429)|0);
   $53 = HEAP32[$42>>2]|0;
   $54 = ($53|0)==(0);
   if ($54) {
    $58 = 0;
   } else {
    $55 = HEAP32[$40>>2]|0;
    $56 = $53 << 2;
    _memcpy(($52|0),($55|0),($56|0))|0;
    $$pre$i$i = HEAP32[$42>>2]|0;
    $58 = $$pre$i$i;
   }
   $57 = ($50|0)==($58|0);
   if (!($57)) {
    $59 = (($50) - ($58))|0;
    $60 = (($52) + ($58<<2)|0);
    $61 = $59 << 2;
    _memset(($60|0),0,($61|0))|0;
   }
   $62 = HEAP32[$40>>2]|0;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$62);
    HEAP32[$40>>2] = 0;
   }
   HEAP32[$40>>2] = $52;
   HEAP32[$42>>2] = $50;
   $67 = $52;
  }
  $64 = $6 & 31;
  $65 = 1 << $64;
  $66 = (($67) + ($41<<2)|0);
  $68 = HEAP32[$66>>2]|0;
  $69 = $68 | $65;
  HEAP32[$66>>2] = $69;
  $70 = (($this) + 104|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($this) + 96|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($this) + 84|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($75) + -1)|0;
  HEAP32[$74>>2] = $76;
  $boxes$0 = $73;$lastIndex$0 = $76;$mapping$0 = $71;$removedBoxIndex$2 = $6;
 }
 $77 = HEAP32[$3>>2]|0;
 $78 = (($mapping$0) + ($lastIndex$0<<1)|0);
 $79 = HEAP16[$78>>1]|0;
 $80 = $79&65535;
 $81 = (($boxes$0) + (($removedBoxIndex$2*24)|0)|0);
 $82 = (($boxes$0) + (($lastIndex$0*24)|0)|0);
 ;HEAP32[$81+0>>2]=HEAP32[$82+0>>2]|0;HEAP32[$81+4>>2]=HEAP32[$82+4>>2]|0;HEAP32[$81+8>>2]=HEAP32[$82+8>>2]|0;HEAP32[$81+12>>2]=HEAP32[$82+12>>2]|0;HEAP32[$81+16>>2]=HEAP32[$82+16>>2]|0;HEAP32[$81+20>>2]=HEAP32[$82+20>>2]|0;
 $83 = (($mapping$0) + ($removedBoxIndex$2<<1)|0);
 HEAP16[$83>>1] = $79;
 $84 = (($77) + ($80<<3)|0);
 HEAP32[$84>>2] = $removedBoxIndex$2;
 $85 = (($this) + 72|0);
 $86 = HEAP32[$85>>2]|0;
 HEAP32[$5>>2] = $86;
 HEAP32[$7>>2] = -1;
 HEAP32[$85>>2] = $2;
 $87 = (($this) + 64|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($88) + -1)|0;
 HEAP32[$87>>2] = $89;
 STACKTOP = sp;return;
}
function __ZN9BoxPruner12updateObjectERK5IAABBt($this,$bounds,$handle) {
 $this = $this|0;
 $bounds = $bounds|0;
 $handle = $handle|0;
 var $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $box0$sroa$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $box0$sroa$0$i = sp;
 $0 = sp + 24|0;
 $1 = $handle&65535;
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + ($1<<3)|0) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($3) + ($1<<3)|0);
 $9 = HEAP32[$8>>2]|0;
 if ($7) {
  $10 = (($this) + 120|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9>>>0)<($11>>>0);
  if (!($12)) {
   $13 = (($this) + 169|0);
   HEAP8[$13>>0] = 1;
  }
  $14 = (($this) + 116|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($9>>>0)<($15>>>0);
  $17 = (($this) + 100|0);
  $18 = HEAP32[$17>>2]|0;
  if ($16) {
   $32 = (($18) + (($9*24)|0)|0);
   ;HEAP32[$32+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$32+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$32+20>>2]=HEAP32[$bounds+20>>2]|0;
   STACKTOP = sp;return;
  }
  $19 = (($this) + 108|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($9|0)==($15|0);
  $22 = (($18) + (($15*24)|0)|0);
  if ($21) {
   ;HEAP32[$22+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$bounds+20>>2]|0;
  } else {
   ;HEAP32[$box0$sroa$0$i+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$box0$sroa$0$i+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$box0$sroa$0$i+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$box0$sroa$0$i+12>>2]=HEAP32[$22+12>>2]|0;HEAP32[$box0$sroa$0$i+16>>2]=HEAP32[$22+16>>2]|0;HEAP32[$box0$sroa$0$i+20>>2]=HEAP32[$22+20>>2]|0;
   ;HEAP32[$22+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$bounds+20>>2]|0;
   $23 = (($18) + (($9*24)|0)|0);
   ;HEAP32[$23+0>>2]=HEAP32[$box0$sroa$0$i+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$box0$sroa$0$i+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$box0$sroa$0$i+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$box0$sroa$0$i+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$box0$sroa$0$i+16>>2]|0;HEAP32[$23+20>>2]=HEAP32[$box0$sroa$0$i+20>>2]|0;
   $24 = (($20) + ($15<<1)|0);
   $25 = HEAP16[$24>>1]|0;
   $26 = (($20) + ($9<<1)|0);
   $27 = HEAP16[$26>>1]|0;
   HEAP16[$24>>1] = $27;
   HEAP16[$26>>1] = $25;
   $28 = $25&65535;
   $29 = (($3) + ($28<<3)|0);
   HEAP32[$29>>2] = $9;
   HEAP32[$8>>2] = $15;
  }
  $30 = HEAP32[$14>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$14>>2] = $31;
  STACKTOP = sp;return;
 }
 $33 = (($this) + 96|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + (($9*24)|0)|0);
 ;HEAP32[$35+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$35+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$35+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$35+20>>2]=HEAP32[$bounds+20>>2]|0;
 $36 = (($this) + 168|0);
 HEAP8[$36>>0] = 1;
 $37 = (($this) + 124|0);
 $38 = HEAP32[$8>>2]|0;
 $39 = $38 >>> 5;
 $40 = (($this) + 128|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39>>>0)<($41>>>0);
 if ($42) {
  $$pre$i = HEAP32[$37>>2]|0;
  $65 = $$pre$i;
 } else {
  $43 = (($38) + 128)|0;
  $44 = $43 >>> 5;
  $45 = $43 & 31;
  $46 = ($45|0)!=(0);
  $47 = $46&1;
  $48 = (($47) + ($44))|0;
  $49 = $48 << 2;
  $50 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($box0$sroa$0$i,$49,483632,429)|0);
  $51 = HEAP32[$40>>2]|0;
  $52 = ($51|0)==(0);
  if ($52) {
   $56 = 0;
  } else {
   $53 = HEAP32[$37>>2]|0;
   $54 = $51 << 2;
   _memcpy(($50|0),($53|0),($54|0))|0;
   $$pre$i$i = HEAP32[$40>>2]|0;
   $56 = $$pre$i$i;
  }
  $55 = ($48|0)==($56|0);
  if (!($55)) {
   $57 = (($48) - ($56))|0;
   $58 = (($50) + ($56<<2)|0);
   $59 = $57 << 2;
   _memset(($58|0),0,($59|0))|0;
  }
  $60 = HEAP32[$37>>2]|0;
  $61 = ($60|0)==(0|0);
  if (!($61)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$60);
   HEAP32[$37>>2] = 0;
  }
  HEAP32[$37>>2] = $50;
  HEAP32[$40>>2] = $48;
  $65 = $50;
 }
 $62 = $38 & 31;
 $63 = 1 << $62;
 $64 = (($65) + ($39<<2)|0);
 $66 = HEAP32[$64>>2]|0;
 $67 = $66 | $63;
 HEAP32[$64>>2] = $67;
 STACKTOP = sp;return;
}
function __ZN16MBPOS_TmpBuffers16allocateSleepingEjj($this,$nbSleeping,$nbSentinels) {
 $this = $this|0;
 $nbSleeping = $nbSleeping|0;
 $nbSentinels = $nbSentinels|0;
 var $$$i$i$i = 0, $$arith = 0, $$overflow = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 12800|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)<($nbSleeping>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 12808|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 12288|0);
 $9 = ($7|0)==($8|0);
 $10 = ($7|0)==(0|0);
 $or$cond = $9 | $10;
 if (!($or$cond)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
  HEAP32[$6>>2] = 0;
 }
 $11 = (($this) + 12812|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($this|0);
 $14 = ($12|0)==(0|0);
 $or$cond1 = $13 | $14;
 if (!($or$cond1)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$12);
  HEAP32[$11>>2] = 0;
 }
 $15 = (($nbSentinels) + ($nbSleeping))|0;
 $16 = ($15>>>0)<(257);
 if ($16) {
  HEAP32[$11>>2] = $this;
  $storemerge = $8;
 } else {
  $$arith = ($15*24)|0;
  $$overflow = ($15>>>0)>(178956970);
  $17 = $$overflow ? -1 : $$arith;
  $18 = ($17|0)==(0);
  if ($18) {
   $29 = 0;
  } else {
   $19 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (__Z15PxGetFoundationv()|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + 24|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (FUNCTION_TABLE_ii[$26 & 4095]($23)|0);
   $$$i$i$i = $27 ? 484432 : 484000;
   $28 = (FUNCTION_TABLE_iiiiii[$22 & 255]($19,$17,$$$i$i$i,483632,1891)|0);
   $29 = $28;
  }
  HEAP32[$11>>2] = $29;
  $30 = $nbSleeping << 1;
  $31 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$30,483632,1893)|0);
  $storemerge = $31;
 }
 HEAP32[$6>>2] = $storemerge;
 HEAP32[$3>>2] = $nbSleeping;
 STACKTOP = sp;return;
}
function __ZN9BoxPruner14preparePruningER16MBPOS_TmpBuffers($this,$buffers) {
 $this = $this|0;
 $buffers = $buffers|0;
 var $$$i$i$i$i = 0, $$arith = 0, $$overflow = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond12 = 0, $exitcond13 = 0, $exitcond14 = 0, $i$08 = 0, $i1$06 = 0;
 var $i2$02 = 0, $i5$01 = 0, $inToOut_Dynamic_Sleeping$0 = 0, $or$cond = 0, $or$cond$i = 0, $sleepingDynamicBoxes$0 = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 116|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$1>>2] = 0;
 $3 = (($this) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $6 = (($this) + 169|0);
  HEAP8[$6>>0] = 1;
 }
 $7 = (($this) + 92|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = (($this) + 28|0);
  HEAP8[$10>>0] = 0;
  HEAP32[$3>>2] = 0;
  $11 = (($this) + 169|0);
  HEAP8[$11>>0] = 1;
  STACKTOP = sp;return;
 }
 $12 = (($this) + 100|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 112|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($8) - ($2))|0;
 $17 = ($2|0)==(0);
 if (!($17)) {
  $i$08 = 0;
  while(1) {
   $18 = (($13) + (($i$08*24)|0)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($15) + ($i$08<<2)|0);
   HEAP32[$20>>2] = $19;
   $21 = (($i$08) + 1)|0;
   $exitcond14 = ($21|0)==($2|0);
   if ($exitcond14) {
    break;
   } else {
    $i$08 = $21;
   }
  }
 }
 $22 = (($this) + 169|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 $25 = ($8|0)==($2|0);
 $or$cond = $24 | $25;
 if (!($or$cond)) {
  $i1$06 = 0;
  while(1) {
   $26 = (($i1$06) + ($2))|0;
   $27 = (($13) + (($26*24)|0)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($15) + ($26<<2)|0);
   HEAP32[$29>>2] = $28;
   $30 = (($i1$06) + 1)|0;
   $exitcond13 = ($30|0)==($16|0);
   if ($exitcond13) {
    break;
   } else {
    $i1$06 = $30;
   }
  }
 }
 HEAP32[$1>>2] = $2;
 if ($17) {
  $31 = (($this) + 28|0);
  HEAP8[$31>>0] = 0;
  HEAP32[$3>>2] = 0;
  HEAP8[$22>>0] = 1;
  STACKTOP = sp;return;
 }
 HEAP32[$3>>2] = $2;
 $32 = ($8|0)==($2|0);
 do {
  if ($32) {
   HEAP8[$22>>0] = 1;
   $inToOut_Dynamic_Sleeping$0 = 0;$sleepingDynamicBoxes$0 = 0;
  } else {
   if ($24) {
    $56 = (($buffers) + 12812|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($buffers) + 12808|0);
    $59 = HEAP32[$58>>2]|0;
    $inToOut_Dynamic_Sleeping$0 = $59;$sleepingDynamicBoxes$0 = $57;
    break;
   }
   $33 = (($this) + 132|0);
   $34 = (($15) + ($2<<2)|0);
   $35 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($33,$34,$16,1)|0);
   $36 = (($35) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   __ZN16MBPOS_TmpBuffers16allocateSleepingEjj($buffers,$16,2);
   $38 = (($buffers) + 12812|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($buffers) + 12808|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($this) + 108|0);
   $i2$02 = 0;
   while(1) {
    $43 = (($37) + ($i2$02<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + ($2))|0;
    $46 = (($39) + (($i2$02*24)|0)|0);
    $47 = (($13) + (($45*24)|0)|0);
    ;HEAP32[$46+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$46+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[$47+8>>2]|0;HEAP32[$46+12>>2]=HEAP32[$47+12>>2]|0;HEAP32[$46+16>>2]=HEAP32[$47+16>>2]|0;HEAP32[$46+20>>2]=HEAP32[$47+20>>2]|0;
    $48 = HEAP32[$42>>2]|0;
    $49 = (($48) + ($45<<1)|0);
    $50 = HEAP16[$49>>1]|0;
    $51 = (($41) + ($i2$02<<1)|0);
    HEAP16[$51>>1] = $50;
    $52 = (($i2$02) + 1)|0;
    $exitcond12 = ($52|0)==($16|0);
    if ($exitcond12) {
     break;
    } else {
     $i2$02 = $52;
    }
   }
   $53 = (($39) + (($16*24)|0)|0);
   HEAP32[$53>>2] = -1;
   $54 = (($16) + 1)|0;
   $55 = (($39) + (($54*24)|0)|0);
   HEAP32[$55>>2] = -1;
   HEAP8[$22>>0] = 0;
   $inToOut_Dynamic_Sleeping$0 = $41;$sleepingDynamicBoxes$0 = $39;
  }
 } while(0);
 $60 = (($this) + 132|0);
 $61 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($60,$15,$2,1)|0);
 $62 = (($61) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($buffers) + 12804|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65>>>0)<($2>>>0);
 $67 = (($buffers) + 12816|0);
 $68 = HEAP32[$67>>2]|0;
 if ($66) {
  $69 = (($buffers) + 6144|0);
  $70 = ($68|0)==($69|0);
  $71 = ($68|0)==(0|0);
  $or$cond$i = $70 | $71;
  if (!($or$cond$i)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$68);
   HEAP32[$67>>2] = 0;
  }
  $72 = (($2) + 2)|0;
  $73 = ($72>>>0)<(257);
  if ($73) {
   $storemerge$i = $69;
  } else {
   $$arith = ($72*24)|0;
   $$overflow = ($72>>>0)>(178956970);
   $74 = $$overflow ? -1 : $$arith;
   $75 = ($74|0)==(0);
   if ($75) {
    $storemerge$i = 0;
   } else {
    $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (__Z15PxGetFoundationv()|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($81) + 24|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (FUNCTION_TABLE_ii[$83 & 4095]($80)|0);
    $$$i$i$i$i = $84 ? 484432 : 484000;
    $85 = (FUNCTION_TABLE_iiiiii[$79 & 255]($76,$74,$$$i$i$i$i,483632,1921)|0);
    $storemerge$i = $85;
   }
  }
  HEAP32[$67>>2] = $storemerge$i;
  HEAP32[$64>>2] = $2;
  $92 = $storemerge$i;
 } else {
  $92 = $68;
 }
 $86 = (($this) + 144|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($this) + 108|0);
 $i5$01 = 0;
 while(1) {
  $89 = (($63) + ($i5$01<<2)|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($92) + (($i5$01*24)|0)|0);
  $93 = (($13) + (($90*24)|0)|0);
  ;HEAP32[$91+0>>2]=HEAP32[$93+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$93+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$93+8>>2]|0;HEAP32[$91+12>>2]=HEAP32[$93+12>>2]|0;HEAP32[$91+16>>2]=HEAP32[$93+16>>2]|0;HEAP32[$91+20>>2]=HEAP32[$93+20>>2]|0;
  $94 = HEAP32[$88>>2]|0;
  $95 = (($94) + ($90<<1)|0);
  $96 = HEAP16[$95>>1]|0;
  $97 = (($87) + ($i5$01<<1)|0);
  HEAP16[$97>>1] = $96;
  $98 = (($i5$01) + 1)|0;
  $exitcond = ($98|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $i5$01 = $98;
  }
 }
 $99 = (($92) + (($2*24)|0)|0);
 HEAP32[$99>>2] = -1;
 $100 = (($2) + 1)|0;
 $101 = (($92) + (($100*24)|0)|0);
 HEAP32[$101>>2] = -1;
 $102 = (($this) + 76|0);
 $103 = HEAP32[$102>>2]|0;
 HEAP32[$this>>2] = $103;
 $104 = (($this) + 4|0);
 HEAP32[$104>>2] = $92;
 $105 = (($this) + 8|0);
 HEAP32[$105>>2] = $sleepingDynamicBoxes$0;
 $106 = (($this) + 12|0);
 HEAP32[$106>>2] = $87;
 $107 = (($this) + 16|0);
 HEAP32[$107>>2] = $inToOut_Dynamic_Sleeping$0;
 $108 = (($this) + 20|0);
 HEAP32[$108>>2] = $2;
 $109 = (($this) + 24|0);
 HEAP32[$109>>2] = $16;
 $110 = (($this) + 28|0);
 HEAP8[$110>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9BoxPruner14findOverlapsMTER15MBP_PairManagerPKjPK10MBP_Object($this,$pairManager,$groups,$mbpObjects) {
 $this = $this|0;
 $pairManager = $pairManager|0;
 $groups = $groups|0;
 $mbpObjects = $mbpObjects|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index1$010$i = 0, $index1$018$i = 0, $index110$05$i = 0, $index15$010$i = 0, $index15$03$i = 0, $or$cond$i = 0, $or$cond$i1 = 0, $or$cond12$i = 0, $or$cond2$i = 0, $or$cond3$i = 0, $runningIndex$08$i = 0, $runningIndex$1$i = 0;
 var $runningIndex0$013$i = 0, $runningIndex0$05$i = 0, $runningIndex0$1$i = 0, $runningIndex0$1$i8 = 0, $runningIndex1$013$i = 0, $runningIndex1$022$i = 0, $runningIndex1$1$i = 0, $runningIndex1$1$i4 = 0, $sortedIndex$07$i = 0, $sortedIndex0$014$i = 0, $sortedIndex0$023$i = 0, $sortedIndex1$014$i = 0, $sortedIndex1$06$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 28|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 L4: do {
  if (!($5)) {
   $6 = HEAP32[$this>>2]|0;
   $7 = (($this) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($this) + 20|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($this) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0);
   if (!($19)) {
    $20 = ($16|0)==(0);
    if ($20) {
     break;
    } else {
     $runningIndex1$022$i = 0;$sortedIndex0$023$i = 0;
    }
    while(1) {
     $24 = ((($8) + (($sortedIndex0$023$i*24)|0)|0) + 12|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($8) + (($sortedIndex0$023$i*24)|0)|0);
     $27 = HEAP32[$26>>2]|0;
     $runningIndex1$1$i = $runningIndex1$022$i;
     while(1) {
      $28 = (($10) + (($runningIndex1$1$i*24)|0)|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29>>>0)<($27>>>0);
      $31 = (($runningIndex1$1$i) + 1)|0;
      if ($30) {
       $runningIndex1$1$i = $31;
      } else {
       break;
      }
     }
     $23 = (($sortedIndex0$023$i) + 1)|0;
     $32 = ($29>>>0)>($25>>>0);
     if (!($32)) {
      $33 = ((($8) + (($sortedIndex0$023$i*24)|0)|0) + 4|0);
      $34 = ((($8) + (($sortedIndex0$023$i*24)|0)|0) + 8|0);
      $35 = ((($8) + (($sortedIndex0$023$i*24)|0)|0) + 16|0);
      $36 = ((($8) + (($sortedIndex0$023$i*24)|0)|0) + 20|0);
      $37 = (($12) + ($sortedIndex0$023$i<<1)|0);
      $index1$018$i = $runningIndex1$1$i;
      while(1) {
       $38 = ((($10) + (($index1$018$i*24)|0)|0) + 16|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = HEAP32[$33>>2]|0;
       $41 = (($39) - ($40))|0;
       $42 = $41 & -2147483648;
       $43 = ((($10) + (($index1$018$i*24)|0)|0) + 20|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = HEAP32[$34>>2]|0;
       $46 = (($44) - ($45))|0;
       $47 = HEAP32[$35>>2]|0;
       $48 = ((($10) + (($index1$018$i*24)|0)|0) + 4|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = (($47) - ($49))|0;
       $51 = HEAP32[$36>>2]|0;
       $52 = ((($10) + (($index1$018$i*24)|0)|0) + 8|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (($51) - ($53))|0;
       $55 = $46 >>> 1;
       $56 = $55 & 1073741824;
       $57 = $56 | $42;
       $58 = $50 >>> 2;
       $59 = $58 & 536870912;
       $60 = $57 | $59;
       $61 = $54 >>> 3;
       $62 = $61 & 268435456;
       $63 = $60 | $62;
       $64 = ($63|0)==(0);
       if ($64) {
        $65 = HEAP16[$37>>1]|0;
        $66 = $65&65535;
        $67 = (($14) + ($index1$018$i<<1)|0);
        $68 = HEAP16[$67>>1]|0;
        $69 = $68&65535;
        $70 = ((($6) + ($66<<3)|0) + 4|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = ((($6) + ($69<<3)|0) + 4|0);
        $73 = HEAP32[$72>>2]|0;
        (__ZN15MBP_PairManager7addPairEjjPKjPK10MBP_Object($pairManager,$71,$73,$groups,$mbpObjects)|0);
       }
       $74 = (($index1$018$i) + 1)|0;
       $75 = (($10) + (($74*24)|0)|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = ($76>>>0)>($25>>>0);
       if ($77) {
        break;
       } else {
        $index1$018$i = $74;
       }
      }
     }
     $21 = ($runningIndex1$1$i>>>0)<($18>>>0);
     $22 = ($23>>>0)<($16>>>0);
     $or$cond$i = $21 & $22;
     if ($or$cond$i) {
      $runningIndex1$022$i = $runningIndex1$1$i;$sortedIndex0$023$i = $23;
     } else {
      $runningIndex0$013$i = 0;$sortedIndex1$014$i = 0;
      break;
     }
    }
    while(1) {
     $82 = ((($10) + (($sortedIndex1$014$i*24)|0)|0) + 12|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (($10) + (($sortedIndex1$014$i*24)|0)|0);
     $85 = HEAP32[$84>>2]|0;
     $runningIndex0$1$i = $runningIndex0$013$i;
     while(1) {
      $86 = (($8) + (($runningIndex0$1$i*24)|0)|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = ($87>>>0)>($85>>>0);
      $89 = (($runningIndex0$1$i) + 1)|0;
      if ($88) {
       break;
      } else {
       $runningIndex0$1$i = $89;
      }
     }
     $80 = (($sortedIndex1$014$i) + 1)|0;
     $90 = ($87>>>0)>($83>>>0);
     if (!($90)) {
      $91 = ((($10) + (($sortedIndex1$014$i*24)|0)|0) + 4|0);
      $92 = ((($10) + (($sortedIndex1$014$i*24)|0)|0) + 8|0);
      $93 = ((($10) + (($sortedIndex1$014$i*24)|0)|0) + 16|0);
      $94 = ((($10) + (($sortedIndex1$014$i*24)|0)|0) + 20|0);
      $95 = (($14) + ($sortedIndex1$014$i<<1)|0);
      $index15$010$i = $runningIndex0$1$i;
      while(1) {
       $96 = ((($8) + (($index15$010$i*24)|0)|0) + 16|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = HEAP32[$91>>2]|0;
       $99 = (($97) - ($98))|0;
       $100 = $99 & -2147483648;
       $101 = ((($8) + (($index15$010$i*24)|0)|0) + 20|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = HEAP32[$92>>2]|0;
       $104 = (($102) - ($103))|0;
       $105 = HEAP32[$93>>2]|0;
       $106 = ((($8) + (($index15$010$i*24)|0)|0) + 4|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = (($105) - ($107))|0;
       $109 = HEAP32[$94>>2]|0;
       $110 = ((($8) + (($index15$010$i*24)|0)|0) + 8|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = (($109) - ($111))|0;
       $113 = $104 >>> 1;
       $114 = $113 & 1073741824;
       $115 = $114 | $100;
       $116 = $108 >>> 2;
       $117 = $116 & 536870912;
       $118 = $115 | $117;
       $119 = $112 >>> 3;
       $120 = $119 & 268435456;
       $121 = $118 | $120;
       $122 = ($121|0)==(0);
       if ($122) {
        $123 = (($12) + ($index15$010$i<<1)|0);
        $124 = HEAP16[$123>>1]|0;
        $125 = $124&65535;
        $126 = HEAP16[$95>>1]|0;
        $127 = $126&65535;
        $128 = ((($6) + ($125<<3)|0) + 4|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = ((($6) + ($127<<3)|0) + 4|0);
        $131 = HEAP32[$130>>2]|0;
        (__ZN15MBP_PairManager7addPairEjjPKjPK10MBP_Object($pairManager,$129,$131,$groups,$mbpObjects)|0);
       }
       $132 = (($index15$010$i) + 1)|0;
       $133 = (($8) + (($132*24)|0)|0);
       $134 = HEAP32[$133>>2]|0;
       $135 = ($134>>>0)>($83>>>0);
       if ($135) {
        break;
       } else {
        $index15$010$i = $132;
       }
      }
     }
     $78 = ($runningIndex0$1$i>>>0)<($16>>>0);
     $79 = ($80>>>0)<($18>>>0);
     $or$cond3$i = $78 & $79;
     if ($or$cond3$i) {
      $runningIndex0$013$i = $runningIndex0$1$i;$sortedIndex1$014$i = $80;
     } else {
      break;
     }
    }
   }
   $81 = ($16|0)==(0);
   if (!($81)) {
    $runningIndex$08$i = 0;$sortedIndex$07$i = 0;
    while(1) {
     $136 = ((($8) + (($sortedIndex$07$i*24)|0)|0) + 12|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = (($8) + (($sortedIndex$07$i*24)|0)|0);
     $139 = HEAP32[$138>>2]|0;
     $runningIndex$1$i = $runningIndex$08$i;
     while(1) {
      $140 = (($runningIndex$1$i) + 1)|0;
      $141 = (($8) + (($runningIndex$1$i*24)|0)|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = ($142>>>0)<($139>>>0);
      if ($143) {
       $runningIndex$1$i = $140;
      } else {
       break;
      }
     }
     $144 = (($sortedIndex$07$i) + 1)|0;
     $145 = ($140>>>0)<($16>>>0);
     if (!($145)) {
      break L4;
     }
     $147 = (($8) + (($140*24)|0)|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = ($148>>>0)>($137>>>0);
     if (!($149)) {
      $150 = ((($8) + (($sortedIndex$07$i*24)|0)|0) + 4|0);
      $151 = ((($8) + (($sortedIndex$07$i*24)|0)|0) + 8|0);
      $152 = ((($8) + (($sortedIndex$07$i*24)|0)|0) + 16|0);
      $153 = ((($8) + (($sortedIndex$07$i*24)|0)|0) + 20|0);
      $154 = (($12) + ($sortedIndex$07$i<<1)|0);
      $index110$05$i = $140;
      while(1) {
       $155 = ((($8) + (($index110$05$i*24)|0)|0) + 16|0);
       $156 = HEAP32[$155>>2]|0;
       $157 = HEAP32[$150>>2]|0;
       $158 = (($156) - ($157))|0;
       $159 = $158 & -2147483648;
       $160 = ((($8) + (($index110$05$i*24)|0)|0) + 20|0);
       $161 = HEAP32[$160>>2]|0;
       $162 = HEAP32[$151>>2]|0;
       $163 = (($161) - ($162))|0;
       $164 = HEAP32[$152>>2]|0;
       $165 = ((($8) + (($index110$05$i*24)|0)|0) + 4|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = (($164) - ($166))|0;
       $168 = HEAP32[$153>>2]|0;
       $169 = ((($8) + (($index110$05$i*24)|0)|0) + 8|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = (($168) - ($170))|0;
       $172 = $163 >>> 1;
       $173 = $172 & 1073741824;
       $174 = $173 | $159;
       $175 = $167 >>> 2;
       $176 = $175 & 536870912;
       $177 = $174 | $176;
       $178 = $171 >>> 3;
       $179 = $178 & 268435456;
       $180 = $177 | $179;
       $181 = ($180|0)==(0);
       if ($181) {
        $182 = HEAP16[$154>>1]|0;
        $183 = $182&65535;
        $184 = (($12) + ($index110$05$i<<1)|0);
        $185 = HEAP16[$184>>1]|0;
        $186 = $185&65535;
        $187 = ((($6) + ($183<<3)|0) + 4|0);
        $188 = HEAP32[$187>>2]|0;
        $189 = ((($6) + ($186<<3)|0) + 4|0);
        $190 = HEAP32[$189>>2]|0;
        (__ZN15MBP_PairManager7addPairEjjPKjPK10MBP_Object($pairManager,$188,$190,$groups,$mbpObjects)|0);
       }
       $191 = (($index110$05$i) + 1)|0;
       $192 = (($8) + (($191*24)|0)|0);
       $193 = HEAP32[$192>>2]|0;
       $194 = ($193>>>0)>($137>>>0);
       if ($194) {
        break;
       } else {
        $index110$05$i = $191;
       }
      }
     }
     $146 = ($144>>>0)<($16>>>0);
     if ($146) {
      $runningIndex$08$i = $140;$sortedIndex$07$i = $144;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 $195 = (($this) + 60|0);
 $196 = HEAP8[$195>>0]|0;
 $197 = ($196<<24>>24)==(0);
 if (!($197)) {
  $198 = (($this) + 36|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = (($this) + 40|0);
  $201 = HEAP32[$200>>2]|0;
  $202 = (($this) + 32|0);
  $203 = HEAP32[$202>>2]|0;
  $204 = (($this) + 44|0);
  $205 = HEAP32[$204>>2]|0;
  $206 = (($this) + 48|0);
  $207 = HEAP32[$206>>2]|0;
  $208 = (($this) + 52|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = (($this) + 56|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = ($201|0)!=(0);
  $213 = ($199|0)!=(0);
  $or$cond12$i = $212 & $213;
  if ($or$cond12$i) {
   $runningIndex1$013$i = 0;$sortedIndex0$014$i = 0;
   while(1) {
    $217 = ((($205) + (($sortedIndex0$014$i*24)|0)|0) + 12|0);
    $218 = HEAP32[$217>>2]|0;
    $219 = (($205) + (($sortedIndex0$014$i*24)|0)|0);
    $220 = HEAP32[$219>>2]|0;
    $runningIndex1$1$i4 = $runningIndex1$013$i;
    while(1) {
     $221 = (($207) + (($runningIndex1$1$i4*24)|0)|0);
     $222 = HEAP32[$221>>2]|0;
     $223 = ($222>>>0)<($220>>>0);
     $224 = (($runningIndex1$1$i4) + 1)|0;
     if ($223) {
      $runningIndex1$1$i4 = $224;
     } else {
      break;
     }
    }
    $216 = (($sortedIndex0$014$i) + 1)|0;
    $225 = ($222>>>0)>($218>>>0);
    if (!($225)) {
     $226 = ((($205) + (($sortedIndex0$014$i*24)|0)|0) + 4|0);
     $227 = ((($205) + (($sortedIndex0$014$i*24)|0)|0) + 8|0);
     $228 = ((($205) + (($sortedIndex0$014$i*24)|0)|0) + 16|0);
     $229 = ((($205) + (($sortedIndex0$014$i*24)|0)|0) + 20|0);
     $230 = (($211) + ($sortedIndex0$014$i<<1)|0);
     $index1$010$i = $runningIndex1$1$i4;
     while(1) {
      $231 = ((($207) + (($index1$010$i*24)|0)|0) + 16|0);
      $232 = HEAP32[$231>>2]|0;
      $233 = HEAP32[$226>>2]|0;
      $234 = (($232) - ($233))|0;
      $235 = $234 & -2147483648;
      $236 = ((($207) + (($index1$010$i*24)|0)|0) + 20|0);
      $237 = HEAP32[$236>>2]|0;
      $238 = HEAP32[$227>>2]|0;
      $239 = (($237) - ($238))|0;
      $240 = HEAP32[$228>>2]|0;
      $241 = ((($207) + (($index1$010$i*24)|0)|0) + 4|0);
      $242 = HEAP32[$241>>2]|0;
      $243 = (($240) - ($242))|0;
      $244 = HEAP32[$229>>2]|0;
      $245 = ((($207) + (($index1$010$i*24)|0)|0) + 8|0);
      $246 = HEAP32[$245>>2]|0;
      $247 = (($244) - ($246))|0;
      $248 = $239 >>> 1;
      $249 = $248 & 1073741824;
      $250 = $249 | $235;
      $251 = $243 >>> 2;
      $252 = $251 & 536870912;
      $253 = $250 | $252;
      $254 = $247 >>> 3;
      $255 = $254 & 268435456;
      $256 = $253 | $255;
      $257 = ($256|0)==(0);
      if ($257) {
       $258 = HEAP16[$230>>1]|0;
       $259 = $258&65535;
       $260 = (($209) + ($index1$010$i<<1)|0);
       $261 = HEAP16[$260>>1]|0;
       $262 = $261&65535;
       $263 = ((($203) + ($259<<3)|0) + 4|0);
       $264 = HEAP32[$263>>2]|0;
       $265 = ((($203) + ($262<<3)|0) + 4|0);
       $266 = HEAP32[$265>>2]|0;
       (__ZN15MBP_PairManager7addPairEjjPKjPK10MBP_Object($pairManager,$264,$266,$groups,$mbpObjects)|0);
      }
      $267 = (($index1$010$i) + 1)|0;
      $268 = (($207) + (($267*24)|0)|0);
      $269 = HEAP32[$268>>2]|0;
      $270 = ($269>>>0)>($218>>>0);
      if (!($270)) {
       $271 = ((($207) + (($267*24)|0)|0) + 16|0);
       $272 = HEAP32[$271>>2]|0;
       $273 = HEAP32[$226>>2]|0;
       $274 = (($272) - ($273))|0;
       $275 = $274 & -2147483648;
       $276 = ((($207) + (($267*24)|0)|0) + 20|0);
       $277 = HEAP32[$276>>2]|0;
       $278 = HEAP32[$227>>2]|0;
       $279 = (($277) - ($278))|0;
       $280 = HEAP32[$228>>2]|0;
       $281 = ((($207) + (($267*24)|0)|0) + 4|0);
       $282 = HEAP32[$281>>2]|0;
       $283 = (($280) - ($282))|0;
       $284 = HEAP32[$229>>2]|0;
       $285 = ((($207) + (($267*24)|0)|0) + 8|0);
       $286 = HEAP32[$285>>2]|0;
       $287 = (($284) - ($286))|0;
       $288 = $279 >>> 1;
       $289 = $288 & 1073741824;
       $290 = $289 | $275;
       $291 = $283 >>> 2;
       $292 = $291 & 536870912;
       $293 = $290 | $292;
       $294 = $287 >>> 3;
       $295 = $294 & 268435456;
       $296 = $293 | $295;
       $297 = ($296|0)==(0);
       if ($297) {
        $298 = HEAP16[$230>>1]|0;
        $299 = $298&65535;
        $300 = (($209) + ($267<<1)|0);
        $301 = HEAP16[$300>>1]|0;
        $302 = $301&65535;
        $303 = ((($203) + ($299<<3)|0) + 4|0);
        $304 = HEAP32[$303>>2]|0;
        $305 = ((($203) + ($302<<3)|0) + 4|0);
        $306 = HEAP32[$305>>2]|0;
        (__ZN15MBP_PairManager7addPairEjjPKjPK10MBP_Object($pairManager,$304,$306,$groups,$mbpObjects)|0);
       }
      }
      $307 = (($index1$010$i) + 2)|0;
      $308 = (($207) + (($307*24)|0)|0);
      $309 = HEAP32[$308>>2]|0;
      $310 = ($309>>>0)>($218>>>0);
      if ($310) {
       break;
      } else {
       $index1$010$i = $307;
      }
     }
    }
    $214 = ($runningIndex1$1$i4>>>0)<($201>>>0);
    $215 = ($216>>>0)<($199>>>0);
    $or$cond$i1 = $214 & $215;
    if ($or$cond$i1) {
     $runningIndex1$013$i = $runningIndex1$1$i4;$sortedIndex0$014$i = $216;
    } else {
     $runningIndex0$05$i = 0;$sortedIndex1$06$i = 0;
     break;
    }
   }
   while(1) {
    $314 = ((($207) + (($sortedIndex1$06$i*24)|0)|0) + 12|0);
    $315 = HEAP32[$314>>2]|0;
    $316 = (($207) + (($sortedIndex1$06$i*24)|0)|0);
    $317 = HEAP32[$316>>2]|0;
    $runningIndex0$1$i8 = $runningIndex0$05$i;
    while(1) {
     $318 = (($205) + (($runningIndex0$1$i8*24)|0)|0);
     $319 = HEAP32[$318>>2]|0;
     $320 = ($319>>>0)>($317>>>0);
     $321 = (($runningIndex0$1$i8) + 1)|0;
     if ($320) {
      break;
     } else {
      $runningIndex0$1$i8 = $321;
     }
    }
    $313 = (($sortedIndex1$06$i) + 1)|0;
    $322 = ($319>>>0)>($315>>>0);
    if (!($322)) {
     $323 = ((($207) + (($sortedIndex1$06$i*24)|0)|0) + 4|0);
     $324 = ((($207) + (($sortedIndex1$06$i*24)|0)|0) + 8|0);
     $325 = ((($207) + (($sortedIndex1$06$i*24)|0)|0) + 16|0);
     $326 = ((($207) + (($sortedIndex1$06$i*24)|0)|0) + 20|0);
     $327 = (($209) + ($sortedIndex1$06$i<<1)|0);
     $index15$03$i = $runningIndex0$1$i8;
     while(1) {
      $328 = ((($205) + (($index15$03$i*24)|0)|0) + 16|0);
      $329 = HEAP32[$328>>2]|0;
      $330 = HEAP32[$323>>2]|0;
      $331 = (($329) - ($330))|0;
      $332 = $331 & -2147483648;
      $333 = ((($205) + (($index15$03$i*24)|0)|0) + 20|0);
      $334 = HEAP32[$333>>2]|0;
      $335 = HEAP32[$324>>2]|0;
      $336 = (($334) - ($335))|0;
      $337 = HEAP32[$325>>2]|0;
      $338 = ((($205) + (($index15$03$i*24)|0)|0) + 4|0);
      $339 = HEAP32[$338>>2]|0;
      $340 = (($337) - ($339))|0;
      $341 = HEAP32[$326>>2]|0;
      $342 = ((($205) + (($index15$03$i*24)|0)|0) + 8|0);
      $343 = HEAP32[$342>>2]|0;
      $344 = (($341) - ($343))|0;
      $345 = $336 >>> 1;
      $346 = $345 & 1073741824;
      $347 = $346 | $332;
      $348 = $340 >>> 2;
      $349 = $348 & 536870912;
      $350 = $347 | $349;
      $351 = $344 >>> 3;
      $352 = $351 & 268435456;
      $353 = $350 | $352;
      $354 = ($353|0)==(0);
      if ($354) {
       $355 = (($211) + ($index15$03$i<<1)|0);
       $356 = HEAP16[$355>>1]|0;
       $357 = $356&65535;
       $358 = HEAP16[$327>>1]|0;
       $359 = $358&65535;
       $360 = ((($203) + ($357<<3)|0) + 4|0);
       $361 = HEAP32[$360>>2]|0;
       $362 = ((($203) + ($359<<3)|0) + 4|0);
       $363 = HEAP32[$362>>2]|0;
       (__ZN15MBP_PairManager7addPairEjjPKjPK10MBP_Object($pairManager,$361,$363,$groups,$mbpObjects)|0);
      }
      $364 = (($index15$03$i) + 1)|0;
      $365 = (($205) + (($364*24)|0)|0);
      $366 = HEAP32[$365>>2]|0;
      $367 = ($366>>>0)>($315>>>0);
      if (!($367)) {
       $368 = ((($205) + (($364*24)|0)|0) + 16|0);
       $369 = HEAP32[$368>>2]|0;
       $370 = HEAP32[$323>>2]|0;
       $371 = (($369) - ($370))|0;
       $372 = $371 & -2147483648;
       $373 = ((($205) + (($364*24)|0)|0) + 20|0);
       $374 = HEAP32[$373>>2]|0;
       $375 = HEAP32[$324>>2]|0;
       $376 = (($374) - ($375))|0;
       $377 = HEAP32[$325>>2]|0;
       $378 = ((($205) + (($364*24)|0)|0) + 4|0);
       $379 = HEAP32[$378>>2]|0;
       $380 = (($377) - ($379))|0;
       $381 = HEAP32[$326>>2]|0;
       $382 = ((($205) + (($364*24)|0)|0) + 8|0);
       $383 = HEAP32[$382>>2]|0;
       $384 = (($381) - ($383))|0;
       $385 = $376 >>> 1;
       $386 = $385 & 1073741824;
       $387 = $386 | $372;
       $388 = $380 >>> 2;
       $389 = $388 & 536870912;
       $390 = $387 | $389;
       $391 = $384 >>> 3;
       $392 = $391 & 268435456;
       $393 = $390 | $392;
       $394 = ($393|0)==(0);
       if ($394) {
        $395 = (($211) + ($364<<1)|0);
        $396 = HEAP16[$395>>1]|0;
        $397 = $396&65535;
        $398 = HEAP16[$327>>1]|0;
        $399 = $398&65535;
        $400 = ((($203) + ($397<<3)|0) + 4|0);
        $401 = HEAP32[$400>>2]|0;
        $402 = ((($203) + ($399<<3)|0) + 4|0);
        $403 = HEAP32[$402>>2]|0;
        (__ZN15MBP_PairManager7addPairEjjPKjPK10MBP_Object($pairManager,$401,$403,$groups,$mbpObjects)|0);
       }
      }
      $404 = (($index15$03$i) + 2)|0;
      $405 = (($205) + (($404*24)|0)|0);
      $406 = HEAP32[$405>>2]|0;
      $407 = ($406>>>0)>($315>>>0);
      if ($407) {
       break;
      } else {
       $index15$03$i = $404;
      }
     }
    }
    $311 = ($runningIndex0$1$i8>>>0)<($199>>>0);
    $312 = ($313>>>0)<($201>>>0);
    $or$cond2$i = $311 & $312;
    if ($or$cond2$i) {
     $runningIndex0$05$i = $runningIndex0$1$i8;$sortedIndex1$06$i = $313;
    } else {
     break;
    }
   }
  }
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3MBPD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN3MBPD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN3MBPD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 HEAP32[$this>>2] = ((483728 + 8|0));
 __ZN3MBP5resetEv($this);
 $3 = (($this) + 5252|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$4);
  HEAP32[$3>>2] = 0;
 }
 HEAP32[$3>>2] = 0;
 $6 = (($this) + 5256|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 5236|0);
 __ZN5physx2Gu9ContainerD2Ev($7);
 $8 = (($this) + 96|0);
 $9 = (($this) + 4208|0);
 $11 = $9;
 while(1) {
  $10 = (($11) + -16|0);
  __ZN5physx2Gu9ContainerD2Ev($10);
  $12 = ($10|0)==($8|0);
  if ($12) {
   break;
  } else {
   $11 = $10;
  }
 }
 $13 = (($this) + 88|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$14);
  HEAP32[$13>>2] = 0;
 }
 HEAP32[$13>>2] = 0;
 $16 = (($this) + 92|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 80|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$18);
  HEAP32[$17>>2] = 0;
 }
 HEAP32[$17>>2] = 0;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 68|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$22);
  HEAP32[$21>>2] = 0;
 }
 $24 = (($this) + 72|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$25);
  HEAP32[$24>>2] = 0;
 }
 $27 = (($this) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $30 = (($this) + 52|0);
  HEAP32[$30>>2] = 0;
  $31 = (($this) + 56|0);
  HEAP32[$31>>2] = 0;
  $32 = (($this) + 60|0);
  HEAP32[$32>>2] = 0;
  $33 = (($this) + 36|0);
  __ZN5physx2Gu9ContainerD2Ev($33);
  $34 = (($this) + 20|0);
  __ZN5physx2Gu9ContainerD2Ev($34);
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$28);
 HEAP32[$27>>2] = 0;
 $30 = (($this) + 52|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 56|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 60|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 36|0);
 __ZN5physx2Gu9ContainerD2Ev($33);
 $34 = (($this) + 20|0);
 __ZN5physx2Gu9ContainerD2Ev($34);
 STACKTOP = sp;return;
}
function __ZN3MBP5resetEv($this) {
 $this = $this|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $boxPruners$04 = 0, $exitcond = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 20|0);
 $6 = ($4|0)==(0);
 if (!($6)) {
  $7 = (($this) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $$in = $4;$boxPruners$04 = $8;
  while(1) {
   $9 = (($$in) + -1)|0;
   $10 = (($boxPruners$04) + 28|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    __ZN9BoxPrunerD2Ev($11);
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
    HEAP32[$10>>2] = 0;
   }
   $13 = (($boxPruners$04) + 40|0);
   $14 = ($9|0)==(0);
   if ($14) {
    break;
   } else {
    $$in = $9;$boxPruners$04 = $13;
   }
  }
 }
 $15 = (($this) + 4|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$3>>2] = 0;
 $16 = (($this) + 12|0);
 HEAP32[$16>>2] = -1;
 $17 = (($this) + 16|0);
 HEAP32[$17>>2] = -1;
 $i$03 = 0;
 while(1) {
  $18 = ((($this) + ($i$03<<4)|0) + 96|0);
  (__ZN5physx2Gu9Container5EmptyEv($18)|0);
  $19 = ((($this) + ($i$03<<2)|0) + 4208|0);
  HEAP32[$19>>2] = -1;
  $20 = (($i$03) + 1)|0;
  $exitcond = ($20|0)==(257);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $20;
  }
 }
 (__ZN5physx2Gu9Container5EmptyEv($5)|0);
 $21 = (($this) + 36|0);
 (__ZN5physx2Gu9Container5EmptyEv($21)|0);
 $22 = (($this) + 68|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$23);
  HEAP32[$22>>2] = 0;
 }
 $25 = (($this) + 72|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$26);
  HEAP32[$25>>2] = 0;
 }
 $28 = (($this) + 64|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$29);
  HEAP32[$28>>2] = 0;
 }
 $31 = (($this) + 52|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 56|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 60|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 80|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$35);
  HEAP32[$34>>2] = 0;
 }
 HEAP32[$34>>2] = 0;
 $37 = (($this) + 84|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 88|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$39);
  HEAP32[$38>>2] = 0;
 }
 HEAP32[$38>>2] = 0;
 $41 = (($this) + 92|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 5236|0);
 (__ZN5physx2Gu9Container5EmptyEv($42)|0);
 $43 = (($this) + 5252|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  HEAP32[$43>>2] = 0;
  $46 = (($this) + 5256|0);
  HEAP32[$46>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$44);
 HEAP32[$43>>2] = 0;
 HEAP32[$43>>2] = 0;
 $46 = (($this) + 5256|0);
 HEAP32[$46>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN3MBP11preallocateEjj($this,$nbBoxPruners,$nbObjects) {
 $this = $this|0;
 $nbBoxPruners = $nbBoxPruners|0;
 $nbObjects = $nbObjects|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = ($nbBoxPruners|0)==(0);
 if (!($2)) {
  $3 = (($this) + 20|0);
  $4 = ($nbBoxPruners*10)|0;
  (__ZN5physx2Gu9Container7SetSizeEj($3,$4)|0);
 }
 $5 = ($nbObjects|0)==(0);
 if ($5) {
  STACKTOP = sp;return 1;
 }
 $6 = (($this) + 36|0);
 $7 = ($nbObjects*3)|0;
 (__ZN5physx2Gu9Container7SetSizeEj($6,$7)|0);
 $8 = $nbObjects >>> 5;
 $9 = $nbObjects & 31;
 $10 = ($9|0)!=(0);
 $11 = $10&1;
 $12 = (($11) + ($8))|0;
 $13 = (($this) + 5256|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 5252|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $18 = $12;
 } else {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$15);
  HEAP32[$14>>2] = 0;
  $$pre$i = HEAP32[$13>>2]|0;
  $18 = $$pre$i;
 }
 $17 = $18 << 2;
 $19 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$17,483632,409)|0);
 HEAP32[$14>>2] = $19;
 $20 = HEAP32[$13>>2]|0;
 $21 = $20 << 2;
 _memset(($19|0),0,($21|0))|0;
 $22 = (($this) + 52|0);
 $23 = $nbObjects << 1;
 $24 = ($23|0)==(0);
 if ($24) {
  STACKTOP = sp;return 1;
 }
 $25 = (($23) + -1)|0;
 $26 = $25 & $23;
 $27 = ($26|0)==(0);
 if ($27) {
  $$0$i = $23;
 } else {
  $28 = $nbObjects & 2147483647;
  $29 = $28 | $23;
  $30 = $29 >>> 2;
  $31 = $30 | $29;
  $32 = $31 >>> 4;
  $33 = $32 | $31;
  $34 = $33 >>> 8;
  $35 = $34 | $33;
  $36 = $35 >>> 16;
  $37 = $36 | $35;
  $38 = (($37) + 1)|0;
  $$0$i = $38;
 }
 HEAP32[$22>>2] = $$0$i;
 $39 = (($$0$i) + -1)|0;
 $40 = (($this) + 56|0);
 HEAP32[$40>>2] = $39;
 $41 = (($this) + 76|0);
 HEAP32[$41>>2] = $$0$i;
 __ZN15MBP_PairManager12reallocPairsEv($22);
 STACKTOP = sp;return 1;
}
function __ZN3MBP17populateNewRegionERK5IAABB($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $$0$i$i = 0, $$0$i1$i = 0, $$0$i2$i = 0, $$0$i3$i = 0, $$0$i4$i = 0, $$0$i5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bounds = 0, $bounds1 = 0, $decodedBounds = 0, $handles$0$i = 0, $j$04 = 0, $not$$i = 0, $not$$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $bounds = sp + 48|0;
 $decodedBounds = sp;
 $bounds1 = sp + 24|0;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3>>>0) / 3)&-1;
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($3>>>0)>(2);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 5252|0);
 $9 = (($this) + 5260|0);
 $10 = (($decodedBounds) + 4|0);
 $11 = (($bounds1) + 4|0);
 $12 = (($decodedBounds) + 8|0);
 $13 = (($bounds1) + 8|0);
 $14 = (($decodedBounds) + 12|0);
 $15 = (($bounds1) + 12|0);
 $16 = (($decodedBounds) + 16|0);
 $17 = (($bounds1) + 16|0);
 $18 = (($decodedBounds) + 20|0);
 $19 = (($bounds1) + 20|0);
 $20 = (($box) + 12|0);
 $21 = (($box) + 4|0);
 $22 = (($box) + 16|0);
 $23 = (($box) + 8|0);
 $24 = (($box) + 20|0);
 $25 = (($bounds) + 12|0);
 $26 = (($bounds) + 16|0);
 $27 = (($bounds) + 4|0);
 $28 = (($bounds) + 20|0);
 $29 = (($bounds) + 8|0);
 $j$04 = 0;
 while(1) {
  $30 = $j$04 >>> 5;
  $31 = HEAP32[$8>>2]|0;
  $32 = (($31) + ($30<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $j$04 & 31;
  $35 = 1 << $34;
  $36 = $33 & $35;
  $37 = ($36|0)==(0);
  do {
   if ($37) {
    $38 = ((($6) + (($j$04*12)|0)|0) + 6|0);
    $39 = HEAP16[$38>>1]|0;
    $40 = $39 & 4;
    $41 = ($40<<16>>16)==(0);
    if ($41) {
     $42 = ((($6) + (($j$04*12)|0)|0) + 4|0);
     $43 = HEAP16[$42>>1]|0;
     $44 = ($43<<16>>16)==(0);
     if ($44) {
      $91 = HEAP32[$9>>2]|0;
      $92 = (($6) + (($j$04*12)|0)|0);
      $93 = HEAP32[$92>>2]|0;
      __ZNK5physx14PxsAABBManager11getBPBoundsEj($decodedBounds,$91,$93);
      $94 = HEAP32[$decodedBounds>>2]|0;
      $95 = ($94|0)<(0);
      $96 = $94 ^ -2;
      $97 = $94 | -2147483648;
      $$0$i$i = $95 ? $96 : $97;
      $98 = $$0$i$i >>> 1;
      HEAP32[$bounds1>>2] = $98;
      $99 = HEAP32[$10>>2]|0;
      $100 = ($99|0)<(0);
      $101 = $99 ^ -2;
      $102 = $99 | -2147483648;
      $$0$i5$i = $100 ? $101 : $102;
      $103 = $$0$i5$i >>> 1;
      HEAP32[$11>>2] = $103;
      $104 = HEAP32[$12>>2]|0;
      $105 = ($104|0)<(0);
      $106 = $104 ^ -2;
      $107 = $104 | -2147483648;
      $$0$i4$i = $105 ? $106 : $107;
      $108 = $$0$i4$i >>> 1;
      HEAP32[$13>>2] = $108;
      $109 = HEAP32[$14>>2]|0;
      $110 = ($109|0)<(0);
      $111 = $109 ^ -2;
      $112 = $109 | -2147483648;
      $$0$i3$i = $110 ? $111 : $112;
      $113 = $$0$i3$i >>> 1;
      HEAP32[$15>>2] = $113;
      $114 = HEAP32[$16>>2]|0;
      $115 = ($114|0)<(0);
      $116 = $114 ^ -2;
      $117 = $114 | -2147483648;
      $$0$i2$i = $115 ? $116 : $117;
      $118 = $$0$i2$i >>> 1;
      HEAP32[$17>>2] = $118;
      $119 = HEAP32[$18>>2]|0;
      $120 = ($119|0)<(0);
      $121 = $119 ^ -2;
      $122 = $119 | -2147483648;
      $$0$i1$i = $120 ? $121 : $122;
      $123 = $$0$i1$i >>> 1;
      HEAP32[$19>>2] = $123;
      $124 = HEAP32[$box>>2]|0;
      $125 = ($113>>>0)<($124>>>0);
      if ($125) {
       break;
      }
      $126 = HEAP32[$20>>2]|0;
      $127 = ($126>>>0)<($98>>>0);
      if ($127) {
       break;
      }
      $128 = HEAP32[$21>>2]|0;
      $129 = ($118>>>0)<($128>>>0);
      if ($129) {
       break;
      }
      $130 = HEAP32[$22>>2]|0;
      $131 = ($130>>>0)<($103>>>0);
      if ($131) {
       break;
      }
      $132 = HEAP32[$23>>2]|0;
      $133 = ($123>>>0)<($132>>>0);
      if ($133) {
       break;
      }
      $134 = HEAP32[$24>>2]|0;
      $not$$i = ($134>>>0)<($108>>>0);
      if ($not$$i) {
       break;
      }
      $135 = ((($6) + (($j$04*12)|0)|0) + 8|0);
      $136 = HEAP32[$135>>2]|0;
      (__ZN3MBP12updateObjectEjRK5IAABB($this,$136,$bounds1)|0);
      break;
     }
     $45 = ($43<<16>>16)==(1);
     $46 = ((($6) + (($j$04*12)|0)|0) + 8|0);
     if ($45) {
      $handles$0$i = $46;
     } else {
      $47 = $43&65535;
      $48 = HEAP32[$46>>2]|0;
      $49 = ((($this) + ($47<<4)|0) + 104|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = (($50) + ($48<<2)|0);
      $handles$0$i = $51;
     }
     $52 = (($handles$0$i) + 2|0);
     $53 = HEAP16[$52>>1]|0;
     $54 = $53&65535;
     $55 = ((($1) + (($54*40)|0)|0) + 28|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP16[$handles$0$i>>1]|0;
     $58 = $57&65535;
     $59 = (($56) + 76|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($60) + ($58<<3)|0) + 4|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = $62 & 1;
     $64 = ($63|0)==(0);
     $65 = (($60) + ($58<<3)|0);
     $66 = HEAP32[$65>>2]|0;
     if ($64) {
      $67 = (($56) + 100|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (($68) + (($66*24)|0)|0);
      ;HEAP32[$bounds+0>>2]=HEAP32[$69+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$69+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$69+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$69+20>>2]|0;
     } else {
      $70 = (($56) + 96|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = (($71) + (($66*24)|0)|0);
      ;HEAP32[$bounds+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$72+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$72+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$72+20>>2]|0;
     }
     $73 = HEAP32[$61>>2]|0;
     $74 = HEAP32[$25>>2]|0;
     $75 = HEAP32[$box>>2]|0;
     $76 = ($74>>>0)<($75>>>0);
     if (!($76)) {
      $77 = HEAP32[$20>>2]|0;
      $78 = HEAP32[$bounds>>2]|0;
      $79 = ($77>>>0)<($78>>>0);
      if (!($79)) {
       $80 = HEAP32[$26>>2]|0;
       $81 = HEAP32[$21>>2]|0;
       $82 = ($80>>>0)<($81>>>0);
       if (!($82)) {
        $83 = HEAP32[$22>>2]|0;
        $84 = HEAP32[$27>>2]|0;
        $85 = ($83>>>0)<($84>>>0);
        if (!($85)) {
         $86 = HEAP32[$28>>2]|0;
         $87 = HEAP32[$23>>2]|0;
         $88 = ($86>>>0)<($87>>>0);
         if (!($88)) {
          $89 = HEAP32[$24>>2]|0;
          $90 = HEAP32[$29>>2]|0;
          $not$$i1 = ($89>>>0)<($90>>>0);
          if (!($not$$i1)) {
           (__ZN3MBP12updateObjectEjRK5IAABB($this,$73,$bounds)|0);
          }
         }
        }
       }
      }
     }
    }
   }
  } while(0);
  $137 = (($j$04) + 1)|0;
  $138 = ($137>>>0)<($4>>>0);
  if ($138) {
   $j$04 = $137;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3MBP12updateObjectEjRK5IAABB($this,$handle,$box) {
 $this = $this|0;
 $handle = $handle|0;
 $box = $box|0;
 var $$lcssa37 = 0, $$lcssa43 = 0, $$not$$i22 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i12 = 0, $$pre$i$i18 = 0, $$pre$i$i25 = 0, $$pre$i$i26 = 0, $$pre$i$i7 = 0, $$pre$i10 = 0, $$pre$i16 = 0, $$pre$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $currentOverlaps = 0, $exitcond = 0, $exitcond53 = 0, $exitcond55 = 0, $handles$0$i5058 = 0, $handles$0$i5059 = 0, $handles$0$i57 = 0, $handlesMemory$0$i = 0, $i$01$i = 0, $i$044 = 0, $i1$038 = 0, $i4$034 = 0;
 var $nbNewHandles$0$lcssa = 0, $nbNewHandles$039 = 0, $nbNewHandles$1 = 0, $nbNewHandles$2$lcssa = 0, $nbNewHandles$233 = 0, $newHandles = 0, $not$$i = 0, $not$$i21 = 0, $not$$i22 = 0, $not$or$cond63 = 0, $objectIsFullyInsideRegions$0$off0$ = 0, $objectIsFullyInsideRegions$0$off0$lcssa = 0, $objectIsFullyInsideRegions$0$off045 = 0, $objectIsFullyInsideRegions$2$off0 = 0, $or$cond = 0, $or$cond60 = 0, $or$cond61 = 0, $or$cond62 = 0, $or$cond63 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2064|0;
 $0 = sp + 2057|0;
 $1 = sp + 2056|0;
 $currentOverlaps = sp;
 $newHandles = sp + 1028|0;
 $2 = $handle >>> 2;
 $3 = $handle & 1;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 80|0);
 $11 = $handle >>> 7;
 $12 = (($this) + 84|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $$pre$i10 = HEAP32[$10>>2]|0;
  $37 = $$pre$i10;
 } else {
  $15 = (($2) + 128)|0;
  $16 = $15 >>> 5;
  $17 = $15 & 31;
  $18 = ($17|0)!=(0);
  $19 = $18&1;
  $20 = (($19) + ($16))|0;
  $21 = $20 << 2;
  $22 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$21,483632,429)|0);
  $23 = HEAP32[$12>>2]|0;
  $24 = ($23|0)==(0);
  if ($24) {
   $28 = 0;
  } else {
   $25 = HEAP32[$10>>2]|0;
   $26 = $23 << 2;
   _memcpy(($22|0),($25|0),($26|0))|0;
   $$pre$i$i12 = HEAP32[$12>>2]|0;
   $28 = $$pre$i$i12;
  }
  $27 = ($20|0)==($28|0);
  if (!($27)) {
   $29 = (($20) - ($28))|0;
   $30 = (($22) + ($28<<2)|0);
   $31 = $29 << 2;
   _memset(($30|0),0,($31|0))|0;
  }
  $32 = HEAP32[$10>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$32);
   HEAP32[$10>>2] = 0;
  }
  HEAP32[$10>>2] = $22;
  HEAP32[$12>>2] = $20;
  $37 = $22;
 }
 $34 = $2 & 31;
 $35 = 1 << $34;
 $36 = (($37) + ($11<<2)|0);
 $38 = HEAP32[$36>>2]|0;
 $39 = $38 | $35;
 HEAP32[$36>>2] = $39;
 $40 = ((($9) + (($2*12)|0)|0) + 4|0);
 $41 = HEAP16[$40>>1]|0;
 $42 = $41&65535;
 $43 = ($41<<16>>16)==(1);
 if ($43) {
  $44 = ((($9) + (($2*12)|0)|0) + 8|0);
  $45 = (($44) + 2|0);
  $46 = HEAP16[$45>>1]|0;
  $47 = $46&65535;
  $48 = ((($7) + (($47*40)|0)|0) + 32|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0);
  if ($50) {
   $51 = ((($7) + (($47*40)|0)|0) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$box>>2]|0;
   $54 = ($52>>>0)>($53>>>0);
   if (!($54)) {
    $55 = ((($7) + (($47*40)|0)|0) + 8|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($box) + 4|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($56>>>0)>($58>>>0);
    if (!($59)) {
     $60 = ((($7) + (($47*40)|0)|0) + 12|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($box) + 8|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($61>>>0)>($63>>>0);
     if (!($64)) {
      $65 = ((($7) + (($47*40)|0)|0) + 16|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = (($box) + 12|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ($66>>>0)<($68>>>0);
      if (!($69)) {
       $70 = ((($7) + (($47*40)|0)|0) + 20|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = (($box) + 16|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($71>>>0)<($73>>>0);
       if (!($74)) {
        $75 = ((($7) + (($47*40)|0)|0) + 24|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = (($box) + 20|0);
        $78 = HEAP32[$77>>2]|0;
        $not$$i = ($76>>>0)<($78>>>0);
        if (!($not$$i)) {
         $79 = (($this) + 5252|0);
         $80 = (($this) + 5256|0);
         $81 = HEAP32[$80>>2]|0;
         $82 = ($11>>>0)<($81>>>0);
         if ($82) {
          $$pre$i16 = HEAP32[$79>>2]|0;
          $103 = $$pre$i16;
         } else {
          $83 = (($2) + 128)|0;
          $84 = $83 >>> 5;
          $85 = $83 & 31;
          $86 = ($85|0)!=(0);
          $87 = $86&1;
          $88 = (($87) + ($84))|0;
          $89 = $88 << 2;
          $90 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$89,483632,429)|0);
          $91 = HEAP32[$80>>2]|0;
          $92 = ($91|0)==(0);
          if ($92) {
           $96 = 0;
          } else {
           $93 = HEAP32[$79>>2]|0;
           $94 = $91 << 2;
           _memcpy(($90|0),($93|0),($94|0))|0;
           $$pre$i$i18 = HEAP32[$80>>2]|0;
           $96 = $$pre$i$i18;
          }
          $95 = ($88|0)==($96|0);
          if (!($95)) {
           $97 = (($88) - ($96))|0;
           $98 = (($90) + ($96<<2)|0);
           $99 = $97 << 2;
           _memset(($98|0),0,($99|0))|0;
          }
          $100 = HEAP32[$79>>2]|0;
          $101 = ($100|0)==(0|0);
          if (!($101)) {
           __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$100);
           HEAP32[$79>>2] = 0;
          }
          HEAP32[$79>>2] = $90;
          HEAP32[$80>>2] = $88;
          $103 = $90;
         }
         $102 = (($103) + ($11<<2)|0);
         $104 = HEAP32[$102>>2]|0;
         $105 = $104 | $35;
         HEAP32[$102>>2] = $105;
         $106 = ((($7) + (($47*40)|0)|0) + 28|0);
         $107 = HEAP32[$106>>2]|0;
         $108 = HEAP16[$44>>1]|0;
         __ZN9BoxPruner12updateObjectERK5IAABBt($107,$box,$108);
         STACKTOP = sp;return 1;
        }
       }
      }
     }
    }
   }
  }
 }
 $109 = ($5|0)==(0);
 if ($109) {
  $$lcssa43 = 0;$objectIsFullyInsideRegions$0$off0$lcssa = 1;
 } else {
  $110 = HEAP32[$box>>2]|0;
  $111 = (($box) + 12|0);
  $112 = (($box) + 4|0);
  $113 = (($box) + 16|0);
  $114 = (($box) + 8|0);
  $115 = (($box) + 20|0);
  $144 = 0;$i$044 = 0;$objectIsFullyInsideRegions$0$off045 = 1;
  while(1) {
   $116 = ((($7) + (($i$044*40)|0)|0) + 16|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = ($117>>>0)<($110>>>0);
   if ($118) {
    $293 = $144;$objectIsFullyInsideRegions$2$off0 = $objectIsFullyInsideRegions$0$off045;
   } else {
    $119 = HEAP32[$111>>2]|0;
    $120 = ((($7) + (($i$044*40)|0)|0) + 4|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = ($119>>>0)<($121>>>0);
    if ($122) {
     $293 = $144;$objectIsFullyInsideRegions$2$off0 = $objectIsFullyInsideRegions$0$off045;
    } else {
     $123 = ((($7) + (($i$044*40)|0)|0) + 20|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = HEAP32[$112>>2]|0;
     $126 = ($124>>>0)<($125>>>0);
     if ($126) {
      $293 = $144;$objectIsFullyInsideRegions$2$off0 = $objectIsFullyInsideRegions$0$off045;
     } else {
      $127 = HEAP32[$113>>2]|0;
      $128 = ((($7) + (($i$044*40)|0)|0) + 8|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ($127>>>0)<($129>>>0);
      if ($130) {
       $293 = $144;$objectIsFullyInsideRegions$2$off0 = $objectIsFullyInsideRegions$0$off045;
      } else {
       $131 = ((($7) + (($i$044*40)|0)|0) + 24|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = HEAP32[$114>>2]|0;
       $134 = ($132>>>0)<($133>>>0);
       if ($134) {
        $293 = $144;$objectIsFullyInsideRegions$2$off0 = $objectIsFullyInsideRegions$0$off045;
       } else {
        $135 = HEAP32[$115>>2]|0;
        $136 = ((($7) + (($i$044*40)|0)|0) + 12|0);
        $137 = HEAP32[$136>>2]|0;
        $not$$i21 = ($135>>>0)<($137>>>0);
        if ($not$$i21) {
         $293 = $144;$objectIsFullyInsideRegions$2$off0 = $objectIsFullyInsideRegions$0$off045;
        } else {
         $138 = ($121>>>0)>($110>>>0);
         $139 = ($129>>>0)>($125>>>0);
         $or$cond60 = $138 | $139;
         $140 = ($137>>>0)>($133>>>0);
         $or$cond61 = $or$cond60 | $140;
         $141 = ($117>>>0)<($119>>>0);
         $or$cond62 = $or$cond61 | $141;
         $142 = ($124>>>0)<($127>>>0);
         $or$cond63 = $or$cond62 | $142;
         $not$$i22 = ($132>>>0)>=($135>>>0);
         $not$or$cond63 = $or$cond63 ^ 1;
         $$not$$i22 = $not$$i22 & $not$or$cond63;
         $objectIsFullyInsideRegions$0$off0$ = $$not$$i22 & $objectIsFullyInsideRegions$0$off045;
         $143 = (($144) + 1)|0;
         $145 = (($currentOverlaps) + ($144<<2)|0);
         HEAP32[$145>>2] = $i$044;
         $293 = $143;$objectIsFullyInsideRegions$2$off0 = $objectIsFullyInsideRegions$0$off0$;
        }
       }
      }
     }
    }
   }
   $146 = (($i$044) + 1)|0;
   $exitcond55 = ($146|0)==($5|0);
   if ($exitcond55) {
    $$lcssa43 = $293;$objectIsFullyInsideRegions$0$off0$lcssa = $objectIsFullyInsideRegions$2$off0;
    break;
   } else {
    $144 = $293;$i$044 = $146;$objectIsFullyInsideRegions$0$off045 = $objectIsFullyInsideRegions$2$off0;
   }
  }
 }
 $147 = ((($9) + (($2*12)|0)|0) + 8|0);
 if ($43) {
  $handles$0$i5058 = $147;$handles$0$i57 = $147;
  label = 41;
 } else {
  $148 = HEAP32[$147>>2]|0;
  $149 = ((($this) + ($42<<4)|0) + 104|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = (($150) + ($148<<2)|0);
  $152 = ($41<<16>>16)==(0);
  if ($152) {
   $$lcssa37 = $$lcssa43;$228 = 1;$handles$0$i5059 = $151;$nbNewHandles$0$lcssa = 0;
  } else {
   $handles$0$i5058 = $151;$handles$0$i57 = $151;
   label = 41;
  }
 }
 if ((label|0) == 41) {
  $160 = $$lcssa43;$i1$038 = 0;$nbNewHandles$039 = 0;
  while(1) {
   $155 = (($handles$0$i57) + ($i1$038<<2)|0);
   $156 = ((($handles$0$i57) + ($i1$038<<2)|0) + 2|0);
   $157 = HEAP16[$156>>1]|0;
   $158 = $157&65535;
   $159 = ($160|0)==(0);
   L58: do {
    if ($159) {
     label = 48;
    } else {
     $i$01$i = 0;
     while(1) {
      $163 = (($currentOverlaps) + ($i$01$i<<2)|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = ($164|0)==($158|0);
      $162 = (($i$01$i) + 1)|0;
      if ($165) {
       break;
      }
      $161 = ($162>>>0)<($160>>>0);
      if ($161) {
       $i$01$i = $162;
      } else {
       label = 48;
       break L58;
      }
     }
     $166 = (($160) + -1)|0;
     $167 = (($currentOverlaps) + ($166<<2)|0);
     $168 = HEAP32[$167>>2]|0;
     HEAP32[$163>>2] = $168;
     $169 = ((($7) + (($158*40)|0)|0) + 28|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = HEAP16[$155>>1]|0;
     __ZN9BoxPruner12updateObjectERK5IAABBt($170,$box,$171);
     $172 = (($nbNewHandles$039) + 1)|0;
     $173 = (($newHandles) + ($nbNewHandles$039<<2)|0);
     $174 = HEAPU16[$155>>1]|(HEAPU16[$155+2>>1]<<16);
     HEAP32[$173>>2] = $174;
     $294 = $166;$nbNewHandles$1 = $172;
    }
   } while(0);
   if ((label|0) == 48) {
    label = 0;
    $175 = ((($7) + (($158*40)|0)|0) + 28|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = HEAP16[$155>>1]|0;
    __ZN9BoxPruner12removeObjectEt($176,$177);
    $294 = $160;$nbNewHandles$1 = $nbNewHandles$039;
   }
   $178 = (($i1$038) + 1)|0;
   $exitcond53 = ($178|0)==($42|0);
   if ($exitcond53) {
    $$lcssa37 = $294;$228 = 0;$handles$0$i5059 = $handles$0$i5058;$nbNewHandles$0$lcssa = $nbNewHandles$1;
    break;
   } else {
    $160 = $294;$i1$038 = $178;$nbNewHandles$039 = $nbNewHandles$1;
   }
  }
 }
 $153 = ($$lcssa37|0)==(0);
 if ($153) {
  $nbNewHandles$2$lcssa = $nbNewHandles$0$lcssa;
 } else {
  $154 = ($3|0)!=(0);
  $i4$034 = 0;$nbNewHandles$233 = $nbNewHandles$0$lcssa;
  while(1) {
   $179 = (($currentOverlaps) + ($i4$034<<2)|0);
   $180 = HEAP32[$179>>2]|0;
   $181 = ((($7) + (($180*40)|0)|0) + 28|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = (__ZN9BoxPruner9addObjectERK5IAABBjb($182,$box,$handle,$154)|0);
   $184 = (($newHandles) + ($nbNewHandles$233<<2)|0);
   HEAP16[$184>>1] = $183;
   $185 = $180&65535;
   $186 = ((($newHandles) + ($nbNewHandles$233<<2)|0) + 2|0);
   HEAP16[$186>>1] = $185;
   $187 = (($nbNewHandles$233) + 1)|0;
   $188 = (($i4$034) + 1)|0;
   $exitcond = ($188|0)==($$lcssa37|0);
   if ($exitcond) {
    break;
   } else {
    $i4$034 = $188;$nbNewHandles$233 = $187;
   }
  }
  $189 = (($$lcssa37) + ($nbNewHandles$0$lcssa))|0;
  $nbNewHandles$2$lcssa = $189;
 }
 $190 = ($42|0)==($nbNewHandles$2$lcssa|0);
 do {
  if ($190) {
   $191 = ($41<<16>>16)==(0);
   if ($191) {
    label = 65;
   } else {
    $192 = $42 << 2;
    _memcpy(($handles$0$i5059|0),($newHandles|0),($192|0))|0;
    label = 65;
   }
  } else {
   $193 = ($41&65535)>(1);
   if ($193) {
    $194 = ((($9) + (($2*12)|0)|0) + 8|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = ((($this) + ($42<<4)|0) + 104|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = (($197) + ($195<<2)|0);
    $199 = ((($this) + ($42<<2)|0) + 4208|0);
    $200 = HEAP32[$199>>2]|0;
    HEAP32[$198>>2] = $200;
    HEAP32[$199>>2] = $195;
   }
   if ((($nbNewHandles$2$lcssa|0) == 1)) {
    $201 = HEAP32[$newHandles>>2]|0;
    $202 = ((($9) + (($2*12)|0)|0) + 8|0);
    HEAP16[$202>>1]=$201&65535;HEAP16[$202+2>>1]=$201>>>16;
    HEAP16[$40>>1] = 1;
    break;
   } else if ((($nbNewHandles$2$lcssa|0) == 0)) {
    label = 65;
    break;
   }
   $203 = ((($this) + ($nbNewHandles$2$lcssa<<4)|0) + 96|0);
   $204 = ((($this) + ($nbNewHandles$2$lcssa<<2)|0) + 4208|0);
   $205 = HEAP32[$204>>2]|0;
   $206 = ($205|0)==(-1);
   if ($206) {
    $212 = ((($this) + ($nbNewHandles$2$lcssa<<4)|0) + 100|0);
    $213 = HEAP32[$212>>2]|0;
    $214 = ((($9) + (($2*12)|0)|0) + 8|0);
    HEAP32[$214>>2] = $213;
    $215 = $nbNewHandles$2$lcssa & 1073741823;
    $216 = HEAP32[$212>>2]|0;
    $217 = (($216) + ($215))|0;
    $218 = HEAP32[$203>>2]|0;
    $219 = ($217>>>0)>($218>>>0);
    if ($219) {
     (__ZN5physx2Gu9Container6ResizeEj($203,$215)|0);
     $$pre$i$i26 = HEAP32[$212>>2]|0;
     $223 = $$pre$i$i26;
    } else {
     $223 = $216;
    }
    $220 = ((($this) + ($nbNewHandles$2$lcssa<<4)|0) + 104|0);
    $221 = HEAP32[$220>>2]|0;
    $222 = (($221) + ($223<<2)|0);
    $224 = (($223) + ($215))|0;
    HEAP32[$212>>2] = $224;
    $handlesMemory$0$i = $222;
   } else {
    $207 = ((($9) + (($2*12)|0)|0) + 8|0);
    HEAP32[$207>>2] = $205;
    $208 = ((($this) + ($nbNewHandles$2$lcssa<<4)|0) + 104|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = (($209) + ($205<<2)|0);
    $211 = HEAP32[$210>>2]|0;
    HEAP32[$204>>2] = $211;
    $handlesMemory$0$i = $210;
   }
   $225 = $nbNewHandles$2$lcssa << 2;
   _memcpy(($handlesMemory$0$i|0),($newHandles|0),($225|0))|0;
   label = 65;
  }
 } while(0);
 if ((label|0) == 65) {
  $226 = $nbNewHandles$2$lcssa&65535;
  HEAP16[$40>>1] = $226;
  $227 = ($nbNewHandles$2$lcssa|0)!=(0);
  $or$cond = $227 | $228;
  if (!($or$cond)) {
   $229 = ((($9) + (($2*12)|0)|0) + 8|0);
   HEAP32[$229>>2] = $handle;
   $230 = (($9) + (($2*12)|0)|0);
   $231 = HEAP32[$230>>2]|0;
   $232 = (($this) + 5236|0);
   $233 = (($this) + 5240|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = HEAP32[$232>>2]|0;
   $236 = ($234|0)==($235|0);
   if ($236) {
    (__ZN5physx2Gu9Container6ResizeEj($232,1)|0);
    $$pre$i$i25 = HEAP32[$233>>2]|0;
    $238 = $$pre$i$i25;
   } else {
    $238 = $234;
   }
   $237 = (($238) + 1)|0;
   HEAP32[$233>>2] = $237;
   $239 = (($this) + 5244|0);
   $240 = HEAP32[$239>>2]|0;
   $241 = (($240) + ($238<<2)|0);
   HEAP32[$241>>2] = $231;
  }
 }
 $242 = (($this) + 5252|0);
 $243 = (($this) + 5256|0);
 $244 = HEAP32[$243>>2]|0;
 $245 = ($11>>>0)<($244>>>0);
 if ($objectIsFullyInsideRegions$0$off0$lcssa) {
  if ($245) {
   $$pre$i5 = HEAP32[$242>>2]|0;
   $266 = $$pre$i5;
  } else {
   $246 = (($2) + 128)|0;
   $247 = $246 >>> 5;
   $248 = $246 & 31;
   $249 = ($248|0)!=(0);
   $250 = $249&1;
   $251 = (($250) + ($247))|0;
   $252 = $251 << 2;
   $253 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$252,483632,429)|0);
   $254 = HEAP32[$243>>2]|0;
   $255 = ($254|0)==(0);
   if ($255) {
    $259 = 0;
   } else {
    $256 = HEAP32[$242>>2]|0;
    $257 = $254 << 2;
    _memcpy(($253|0),($256|0),($257|0))|0;
    $$pre$i$i7 = HEAP32[$243>>2]|0;
    $259 = $$pre$i$i7;
   }
   $258 = ($251|0)==($259|0);
   if (!($258)) {
    $260 = (($251) - ($259))|0;
    $261 = (($253) + ($259<<2)|0);
    $262 = $260 << 2;
    _memset(($261|0),0,($262|0))|0;
   }
   $263 = HEAP32[$242>>2]|0;
   $264 = ($263|0)==(0|0);
   if (!($264)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$263);
    HEAP32[$242>>2] = 0;
   }
   HEAP32[$242>>2] = $253;
   HEAP32[$243>>2] = $251;
   $266 = $253;
  }
  $265 = (($266) + ($11<<2)|0);
  $267 = HEAP32[$265>>2]|0;
  $268 = $267 | $35;
  HEAP32[$265>>2] = $268;
  STACKTOP = sp;return 1;
 } else {
  if ($245) {
   $$pre$i = HEAP32[$242>>2]|0;
   $290 = $$pre$i;
  } else {
   $269 = (($2) + 128)|0;
   $270 = $269 >>> 5;
   $271 = $269 & 31;
   $272 = ($271|0)!=(0);
   $273 = $272&1;
   $274 = (($273) + ($270))|0;
   $275 = $274 << 2;
   $276 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$275,483632,429)|0);
   $277 = HEAP32[$243>>2]|0;
   $278 = ($277|0)==(0);
   if ($278) {
    $282 = 0;
   } else {
    $279 = HEAP32[$242>>2]|0;
    $280 = $277 << 2;
    _memcpy(($276|0),($279|0),($280|0))|0;
    $$pre$i$i = HEAP32[$243>>2]|0;
    $282 = $$pre$i$i;
   }
   $281 = ($274|0)==($282|0);
   if (!($281)) {
    $283 = (($274) - ($282))|0;
    $284 = (($276) + ($282<<2)|0);
    $285 = $283 << 2;
    _memset(($284|0),0,($285|0))|0;
   }
   $286 = HEAP32[$242>>2]|0;
   $287 = ($286|0)==(0|0);
   if (!($287)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$286);
    HEAP32[$242>>2] = 0;
   }
   HEAP32[$242>>2] = $276;
   HEAP32[$243>>2] = $274;
   $290 = $276;
  }
  $288 = $35 ^ -1;
  $289 = (($290) + ($11<<2)|0);
  $291 = HEAP32[$289>>2]|0;
  $292 = $291 & $288;
  HEAP32[$289>>2] = $292;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN3MBP12addBoxPrunerERKN5physx18PxBroadPhaseRegionEb($this,$region,$populateRegion) {
 $this = $this|0;
 $region = $region|0;
 $populateRegion = $populateRegion|0;
 var $$$i$i$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i1$i = 0, $$0$i2$i = 0, $$0$i3$i = 0, $$0$i4$i = 0, $$0$i5$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $buffer$0 = 0, $regionHandle$0 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10>>>0)>(255);
  if ($11) {
   $12 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($12,16,483632,2733,483744,$vararg_buffer);
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $13 = (($10) + 1)|0;
  HEAP32[$9>>2] = $13;
  $14 = (($this) + 20|0);
  $15 = (($this) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 10)|0;
  $18 = HEAP32[$14>>2]|0;
  $19 = ($17>>>0)>($18>>>0);
  if ($19) {
   (__ZN5physx2Gu9Container6ResizeEj($14,10)|0);
   $$pre$i = HEAP32[$15>>2]|0;
   $23 = $$pre$i;
  } else {
   $23 = $16;
  }
  $20 = (($this) + 28|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + ($23<<2)|0);
  $24 = (($23) + 10)|0;
  HEAP32[$15>>2] = $24;
  $$pre$phiZ2D = $9;$buffer$0 = $22;$regionHandle$0 = $10;
 } else {
  $3 = (($this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + (($1*40)|0)|0);
  $6 = ((($4) + (($1*40)|0)|0) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7;
  HEAP32[$0>>2] = $8;
  $$pre = (($this) + 8|0);
  $$pre$phiZ2D = $$pre;$buffer$0 = $5;$regionHandle$0 = $1;
 }
 $25 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (__Z15PxGetFoundationv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
 $$$i$i$i = $33 ? 484240 : 484000;
 $34 = (FUNCTION_TABLE_iiiiii[$28 & 255]($25,13008,$$$i$i$i,483632,2741)|0);
 $35 = (($34) + 32|0);
 ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;HEAP32[$35+20>>2]=0|0;HEAP32[$35+24>>2]=0|0;HEAP8[$35+28>>0]=0|0;
 ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;HEAP32[$34+24>>2]=0|0;HEAP8[$34+28>>0]=0|0;
 $36 = (($34) + 64|0);
 HEAP32[$36>>2] = 0;
 $37 = (($34) + 68|0);
 HEAP32[$37>>2] = 0;
 $38 = (($34) + 72|0);
 HEAP32[$38>>2] = -1;
 $39 = (($34) + 76|0);
 $40 = (($34) + 132|0);
 dest=$39+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx2Gu17RadixSortBufferedC2Ev($40);
 $41 = (($34) + 168|0);
 HEAP8[$41>>0] = 0;
 $42 = (($34) + 169|0);
 HEAP8[$42>>0] = 1;
 $43 = (($34) + 12976|0);
 ;HEAP32[$43+0>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;HEAP32[$43+16>>2]=0|0;
 $44 = (($buffer$0) + 4|0);
 $45 = HEAP32[$region>>2]|0;
 $46 = ($45|0)<(0);
 $47 = $45 ^ -2;
 $48 = $45 | -2147483648;
 $$0$i$i = $46 ? $47 : $48;
 $49 = $$0$i$i >>> 1;
 HEAP32[$44>>2] = $49;
 $50 = (($region) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)<(0);
 $53 = $51 ^ -2;
 $54 = $51 | -2147483648;
 $$0$i5$i = $52 ? $53 : $54;
 $55 = $$0$i5$i >>> 1;
 $56 = (($buffer$0) + 8|0);
 HEAP32[$56>>2] = $55;
 $57 = (($region) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)<(0);
 $60 = $58 ^ -2;
 $61 = $58 | -2147483648;
 $$0$i4$i = $59 ? $60 : $61;
 $62 = $$0$i4$i >>> 1;
 $63 = (($buffer$0) + 12|0);
 HEAP32[$63>>2] = $62;
 $64 = (($region) + 12|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)<(0);
 $67 = $65 ^ -2;
 $68 = $65 | -2147483648;
 $$0$i3$i = $66 ? $67 : $68;
 $69 = $$0$i3$i >>> 1;
 $70 = (($buffer$0) + 16|0);
 HEAP32[$70>>2] = $69;
 $71 = (($region) + 16|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)<(0);
 $74 = $72 ^ -2;
 $75 = $72 | -2147483648;
 $$0$i2$i = $73 ? $74 : $75;
 $76 = $$0$i2$i >>> 1;
 $77 = (($buffer$0) + 20|0);
 HEAP32[$77>>2] = $76;
 $78 = (($region) + 20|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($79|0)<(0);
 $81 = $79 ^ -2;
 $82 = $79 | -2147483648;
 $$0$i1$i = $80 ? $81 : $82;
 $83 = $$0$i1$i >>> 1;
 $84 = (($buffer$0) + 24|0);
 HEAP32[$84>>2] = $83;
 $85 = (($buffer$0) + 28|0);
 HEAP32[$85>>2] = $34;
 $86 = (($region) + 24|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($buffer$0) + 36|0);
 HEAP32[$88>>2] = $87;
 $89 = HEAP32[$$pre$phiZ2D>>2]|0;
 $90 = (($this) + 28|0);
 $91 = HEAP32[$90>>2]|0;
 __ZL17setupOverlapFlagsjP13BoxPrunerData($89,$91);
 if (!($populateRegion)) {
  $$0 = $regionHandle$0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN3MBP17populateNewRegionERK5IAABB($this,$44);
 $$0 = $regionHandle$0;
 STACKTOP = sp;return ($$0|0);
}
function __ZL17setupOverlapFlagsjP13BoxPrunerData($nbPruners,$pruners) {
 $nbPruners = $nbPruners|0;
 $pruners = $pruners|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond8 = 0, $exitcond9 = 0, $i$05 = 0, $i1$03 = 0, $j$0 = 0, $j$02 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nbPruners|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i$05 = 0;
 }
 while(1) {
  $1 = ((($pruners) + (($i$05*40)|0)|0) + 32|0);
  HEAP32[$1>>2] = 0;
  $2 = (($i$05) + 1)|0;
  $exitcond9 = ($2|0)==($nbPruners|0);
  if ($exitcond9) {
   break;
  } else {
   $i$05 = $2;
  }
 }
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i1$03 = 0;
 }
 while(1) {
  $3 = ((($pruners) + (($i1$03*40)|0)|0) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)!=(0|0);
  $$pre = (($i1$03) + 1)|0;
  $6 = ($$pre>>>0)<($nbPruners>>>0);
  $or$cond = $5 & $6;
  if ($or$cond) {
   $7 = ((($pruners) + (($i1$03*40)|0)|0) + 16|0);
   $8 = ((($pruners) + (($i1$03*40)|0)|0) + 4|0);
   $9 = ((($pruners) + (($i1$03*40)|0)|0) + 20|0);
   $10 = ((($pruners) + (($i1$03*40)|0)|0) + 8|0);
   $11 = ((($pruners) + (($i1$03*40)|0)|0) + 24|0);
   $12 = ((($pruners) + (($i1$03*40)|0)|0) + 12|0);
   $13 = ((($pruners) + (($i1$03*40)|0)|0) + 32|0);
   $j$02 = $$pre;
   while(1) {
    $14 = ((($pruners) + (($j$02*40)|0)|0) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     $17 = HEAP32[$7>>2]|0;
     $18 = ((($pruners) + (($j$02*40)|0)|0) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($17>>>0)>($19>>>0);
     if ($20) {
      $21 = ((($pruners) + (($j$02*40)|0)|0) + 16|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = HEAP32[$8>>2]|0;
      $24 = ($22>>>0)>($23>>>0);
      if ($24) {
       $25 = HEAP32[$9>>2]|0;
       $26 = ((($pruners) + (($j$02*40)|0)|0) + 8|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($25>>>0)>($27>>>0);
       if ($28) {
        $29 = ((($pruners) + (($j$02*40)|0)|0) + 20|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = HEAP32[$10>>2]|0;
        $32 = ($30>>>0)>($31>>>0);
        if ($32) {
         $33 = HEAP32[$11>>2]|0;
         $34 = ((($pruners) + (($j$02*40)|0)|0) + 12|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = ($33>>>0)>($35>>>0);
         if ($36) {
          $37 = ((($pruners) + (($j$02*40)|0)|0) + 24|0);
          $38 = HEAP32[$37>>2]|0;
          $39 = HEAP32[$12>>2]|0;
          $40 = ($38>>>0)>($39>>>0);
          if ($40) {
           HEAP32[$13>>2] = 1;
           $41 = ((($pruners) + (($j$02*40)|0)|0) + 32|0);
           HEAP32[$41>>2] = 1;
          }
         }
        }
       }
      }
     }
    }
    $j$0 = (($j$02) + 1)|0;
    $exitcond = ($j$0|0)==($nbPruners|0);
    if ($exitcond) {
     break;
    } else {
     $j$02 = $j$0;
    }
   }
  }
  $exitcond8 = ($$pre|0)==($nbPruners|0);
  if ($exitcond8) {
   break;
  } else {
   $i1$03 = $$pre;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3MBP15removeBoxPrunerEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $j$01 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($handle>>>0);
 if (!($2)) {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,4,483632,2762,483800,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5) + (($handle*40)|0)|0) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($9,4,483632,2772,483800,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ((($5) + (($handle*40)|0)|0) + 4|0);
 HEAP32[$10>>2] = 2134900735;
 $11 = ((($5) + (($handle*40)|0)|0) + 8|0);
 HEAP32[$11>>2] = 2134900735;
 $12 = ((($5) + (($handle*40)|0)|0) + 12|0);
 HEAP32[$12>>2] = 2134900735;
 $13 = ((($5) + (($handle*40)|0)|0) + 16|0);
 HEAP32[$13>>2] = 12582912;
 $14 = ((($5) + (($handle*40)|0)|0) + 20|0);
 HEAP32[$14>>2] = 12582912;
 $15 = ((($5) + (($handle*40)|0)|0) + 24|0);
 HEAP32[$15>>2] = 12582912;
 $16 = (($7) + 68|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($7) + 76|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==(0);
 if (!($20)) {
  $j$01 = 0;
  while(1) {
   $21 = ((($19) + ($j$01<<3)|0) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(-1);
   if (!($23)) {
    (__ZN3MBP12updateObjectEjP9BoxPruner($this,$22,$7)|0);
   }
   $24 = (($j$01) + 1)|0;
   $exitcond = ($24|0)==($17|0);
   if ($exitcond) {
    break;
   } else {
    $j$01 = $24;
   }
  }
 }
 __ZN9BoxPrunerD2Ev($7);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer1,$7);
 HEAP32[$6>>2] = 0;
 $25 = (($this) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26;
 $28 = ((($5) + (($handle*40)|0)|0) + 36|0);
 HEAP32[$28>>2] = $27;
 HEAP32[$25>>2] = $handle;
 $29 = HEAP32[$0>>2]|0;
 $30 = HEAP32[$4>>2]|0;
 __ZL17setupOverlapFlagsjP13BoxPrunerData($29,$30);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN3MBP12updateObjectEjP9BoxPruner($this,$handle,$removedPruner) {
 $this = $this|0;
 $handle = $handle|0;
 $removedPruner = $removedPruner|0;
 var $$pre$i$i = 0, $$pre$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $exitcond = 0, $handles$0$i6 = 0, $handlesMemory$0$i = 0, $i$04 = 0;
 var $nbNewHandles$05 = 0, $nbNewHandles$1 = 0, $newHandles = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $newHandles = sp;
 $0 = $handle >>> 2;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($0*12)|0)|0) + 4|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6&65535;
 $8 = ($6<<16>>16)==(1);
 $9 = ((($4) + (($0*12)|0)|0) + 8|0);
 if ($8) {
  $handles$0$i6 = $9;
  label = 4;
 } else {
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($this) + ($7<<4)|0) + 104|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($10<<2)|0);
  $14 = ($6<<16>>16)==(0);
  if ($14) {
   label = 11;
  } else {
   $handles$0$i6 = $13;
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   $i$04 = 0;$nbNewHandles$05 = 0;
   while(1) {
    $15 = ((($handles$0$i6) + ($i$04<<2)|0) + 2|0);
    $16 = HEAP16[$15>>1]|0;
    $17 = $16&65535;
    $18 = ((($2) + (($17*40)|0)|0) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($removedPruner|0);
    if ($20) {
     $nbNewHandles$1 = $nbNewHandles$05;
    } else {
     $21 = (($handles$0$i6) + ($i$04<<2)|0);
     $22 = (($nbNewHandles$05) + 1)|0;
     $23 = (($newHandles) + ($nbNewHandles$05<<2)|0);
     $24 = HEAPU16[$21>>1]|(HEAPU16[$21+2>>1]<<16);
     HEAP32[$23>>2] = $24;
     $nbNewHandles$1 = $22;
    }
    $25 = (($i$04) + 1)|0;
    $exitcond = ($25|0)==($7|0);
    if ($exitcond) {
     break;
    } else {
     $i$04 = $25;$nbNewHandles$05 = $nbNewHandles$1;
    }
   }
   $26 = ($6&65535)>(1);
   if ($26) {
    $27 = ((($4) + (($0*12)|0)|0) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ((($this) + ($7<<4)|0) + 104|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + ($28<<2)|0);
    $32 = ((($this) + ($7<<2)|0) + 4208|0);
    $33 = HEAP32[$32>>2]|0;
    HEAP32[$31>>2] = $33;
    HEAP32[$32>>2] = $28;
   }
   if ((($nbNewHandles$1|0) == 1)) {
    $34 = HEAP32[$newHandles>>2]|0;
    $35 = ((($4) + (($0*12)|0)|0) + 8|0);
    HEAP16[$35>>1]=$34&65535;HEAP16[$35+2>>1]=$34>>>16;
    HEAP16[$5>>1] = 1;
    STACKTOP = sp;return 1;
   } else if ((($nbNewHandles$1|0) == 0)) {
    label = 11;
    break;
   }
   $36 = ((($this) + ($nbNewHandles$1<<4)|0) + 96|0);
   $37 = ((($this) + ($nbNewHandles$1<<2)|0) + 4208|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(-1);
   if ($39) {
    $45 = ((($this) + ($nbNewHandles$1<<4)|0) + 100|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ((($4) + (($0*12)|0)|0) + 8|0);
    HEAP32[$47>>2] = $46;
    $48 = $nbNewHandles$1 & 1073741823;
    $49 = HEAP32[$45>>2]|0;
    $50 = (($49) + ($48))|0;
    $51 = HEAP32[$36>>2]|0;
    $52 = ($50>>>0)>($51>>>0);
    if ($52) {
     (__ZN5physx2Gu9Container6ResizeEj($36,$48)|0);
     $$pre$i$i1 = HEAP32[$45>>2]|0;
     $56 = $$pre$i$i1;
    } else {
     $56 = $49;
    }
    $53 = ((($this) + ($nbNewHandles$1<<4)|0) + 104|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + ($56<<2)|0);
    $57 = (($56) + ($48))|0;
    HEAP32[$45>>2] = $57;
    $handlesMemory$0$i = $55;
   } else {
    $40 = ((($4) + (($0*12)|0)|0) + 8|0);
    HEAP32[$40>>2] = $38;
    $41 = ((($this) + ($nbNewHandles$1<<4)|0) + 104|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + ($38<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    HEAP32[$37>>2] = $44;
    $handlesMemory$0$i = $43;
   }
   $58 = $nbNewHandles$1 << 2;
   _memcpy(($handlesMemory$0$i|0),($newHandles|0),($58|0))|0;
   $59 = $nbNewHandles$1&65535;
   HEAP16[$5>>1] = $59;
   $60 = ($nbNewHandles$1|0)==(0);
   if (!($60)) {
    STACKTOP = sp;return 1;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  HEAP16[$5>>1] = 0;
 }
 $61 = ((($4) + (($0*12)|0)|0) + 8|0);
 HEAP32[$61>>2] = $handle;
 $62 = (($4) + (($0*12)|0)|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($this) + 5236|0);
 $65 = (($this) + 5240|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$64>>2]|0;
 $68 = ($66|0)==($67|0);
 if ($68) {
  (__ZN5physx2Gu9Container6ResizeEj($64,1)|0);
  $$pre$i$i = HEAP32[$65>>2]|0;
  $70 = $$pre$i$i;
 } else {
  $70 = $66;
 }
 $69 = (($70) + 1)|0;
 HEAP32[$65>>2] = $69;
 $71 = (($this) + 5244|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($70<<2)|0);
 HEAP32[$73>>2] = $63;
 STACKTOP = sp;return 1;
}
function __ZN3MBP9addObjectERK5IAABBjb($this,$box,$userID,$isStatic) {
 $this = $this|0;
 $box = $box|0;
 $userID = $userID|0;
 $isStatic = $isStatic|0;
 var $$ = 0, $$lobit = 0, $$not$$i17 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i14 = 0, $$pre$i$i18 = 0, $$pre$i$i4 = 0, $$pre$i$i9 = 0, $$pre$i12 = 0, $$pre$i5 = 0, $$pre$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $MBPObjectIndex$0 = 0, $brmerge$demorgan = 0, $exitcond = 0, $flipFlop$0 = 0;
 var $handlesMemory$0$i = 0, $i$023 = 0, $nbHandles$0$lcssa27 = 0, $nbHandles$022 = 0, $nbHandles$1 = 0, $newObjectIsFullyInsideRegions$0$off0$ = 0, $newObjectIsFullyInsideRegions$0$off0$lcssa28 = 0, $newObjectIsFullyInsideRegions$0$off021 = 0, $newObjectIsFullyInsideRegions$2$off0 = 0, $not$$i = 0, $not$$i17 = 0, $not$or$cond31 = 0, $objectMemory$0 = 0, $or$cond = 0, $or$cond29 = 0, $or$cond30 = 0, $or$cond31 = 0, $tmpHandles = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $0 = sp + 1029|0;
 $1 = sp + 1028|0;
 $tmpHandles = sp;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 $5 = (($this) + 36|0);
 if ($4) {
  $16 = (($this) + 40|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17>>>0) / 3)&-1;
  $19 = (($17) + 3)|0;
  $20 = HEAP32[$5>>2]|0;
  $21 = ($19>>>0)>($20>>>0);
  if ($21) {
   (__ZN5physx2Gu9Container6ResizeEj($5,3)|0);
   $$pre$i5 = HEAP32[$16>>2]|0;
   $25 = $$pre$i5;
  } else {
   $25 = $17;
  }
  $22 = (($this) + 44|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($25<<2)|0);
  $26 = (($25) + 3)|0;
  HEAP32[$16>>2] = $26;
  $MBPObjectIndex$0 = $18;$flipFlop$0 = 0;$objectMemory$0 = $24;
 } else {
  $6 = (($this) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + (($3*12)|0)|0);
  $9 = ((($7) + (($3*12)|0)|0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$2>>2] = $10;
  $11 = ((($7) + (($3*12)|0)|0) + 6|0);
  $12 = HEAP16[$11>>1]|0;
  $13 = ($12&65535) >>> 1;
  $$lobit = $13 & 1;
  $14 = $$lobit ^ 1;
  $15 = $14&65535;
  $MBPObjectIndex$0 = $3;$flipFlop$0 = $15;$objectMemory$0 = $8;
 }
 $27 = $MBPObjectIndex$0 << 2;
 $28 = $flipFlop$0 << 1;
 $29 = $isStatic&1;
 $30 = $28 | $29;
 $31 = $30 | $27;
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)==(0);
 do {
  if ($36) {
   $nbHandles$0$lcssa27 = 0;$newObjectIsFullyInsideRegions$0$off0$lcssa28 = 1;
  } else {
   $37 = (($box) + 12|0);
   $38 = (($box) + 4|0);
   $39 = (($box) + 16|0);
   $40 = (($box) + 8|0);
   $41 = (($box) + 20|0);
   $i$023 = 0;$nbHandles$022 = 0;$newObjectIsFullyInsideRegions$0$off021 = 1;
   while(1) {
    $42 = ((($35) + (($i$023*40)|0)|0) + 16|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$box>>2]|0;
    $45 = ($43>>>0)<($44>>>0);
    if ($45) {
     $nbHandles$1 = $nbHandles$022;$newObjectIsFullyInsideRegions$2$off0 = $newObjectIsFullyInsideRegions$0$off021;
    } else {
     $46 = HEAP32[$37>>2]|0;
     $47 = ((($35) + (($i$023*40)|0)|0) + 4|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($46>>>0)<($48>>>0);
     if ($49) {
      $nbHandles$1 = $nbHandles$022;$newObjectIsFullyInsideRegions$2$off0 = $newObjectIsFullyInsideRegions$0$off021;
     } else {
      $50 = ((($35) + (($i$023*40)|0)|0) + 20|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = HEAP32[$38>>2]|0;
      $53 = ($51>>>0)<($52>>>0);
      if ($53) {
       $nbHandles$1 = $nbHandles$022;$newObjectIsFullyInsideRegions$2$off0 = $newObjectIsFullyInsideRegions$0$off021;
      } else {
       $54 = HEAP32[$39>>2]|0;
       $55 = ((($35) + (($i$023*40)|0)|0) + 8|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = ($54>>>0)<($56>>>0);
       if ($57) {
        $nbHandles$1 = $nbHandles$022;$newObjectIsFullyInsideRegions$2$off0 = $newObjectIsFullyInsideRegions$0$off021;
       } else {
        $58 = ((($35) + (($i$023*40)|0)|0) + 24|0);
        $59 = HEAP32[$58>>2]|0;
        $60 = HEAP32[$40>>2]|0;
        $61 = ($59>>>0)<($60>>>0);
        if ($61) {
         $nbHandles$1 = $nbHandles$022;$newObjectIsFullyInsideRegions$2$off0 = $newObjectIsFullyInsideRegions$0$off021;
        } else {
         $62 = HEAP32[$41>>2]|0;
         $63 = ((($35) + (($i$023*40)|0)|0) + 12|0);
         $64 = HEAP32[$63>>2]|0;
         $not$$i = ($62>>>0)<($64>>>0);
         if ($not$$i) {
          $nbHandles$1 = $nbHandles$022;$newObjectIsFullyInsideRegions$2$off0 = $newObjectIsFullyInsideRegions$0$off021;
         } else {
          $65 = ($48>>>0)>($44>>>0);
          $66 = ($56>>>0)>($52>>>0);
          $or$cond = $65 | $66;
          $67 = ($64>>>0)>($60>>>0);
          $or$cond29 = $or$cond | $67;
          $68 = ($43>>>0)<($46>>>0);
          $or$cond30 = $or$cond29 | $68;
          $69 = ($51>>>0)<($54>>>0);
          $or$cond31 = $or$cond30 | $69;
          $not$$i17 = ($59>>>0)>=($62>>>0);
          $not$or$cond31 = $or$cond31 ^ 1;
          $$not$$i17 = $not$$i17 & $not$or$cond31;
          $newObjectIsFullyInsideRegions$0$off0$ = $$not$$i17 & $newObjectIsFullyInsideRegions$0$off021;
          $70 = (($nbHandles$022) + 1)|0;
          $71 = ((($35) + (($i$023*40)|0)|0) + 28|0);
          $72 = HEAP32[$71>>2]|0;
          $73 = (__ZN9BoxPruner9addObjectERK5IAABBjb($72,$box,$31,$isStatic)|0);
          $74 = (($tmpHandles) + ($nbHandles$022<<2)|0);
          HEAP16[$74>>1] = $73;
          $75 = $i$023&65535;
          $76 = ((($tmpHandles) + ($nbHandles$022<<2)|0) + 2|0);
          HEAP16[$76>>1] = $75;
          $nbHandles$1 = $70;$newObjectIsFullyInsideRegions$2$off0 = $newObjectIsFullyInsideRegions$0$off0$;
         }
        }
       }
      }
     }
    }
    $77 = (($i$023) + 1)|0;
    $exitcond = ($77|0)==($33|0);
    if ($exitcond) {
     break;
    } else {
     $i$023 = $77;$nbHandles$022 = $nbHandles$1;$newObjectIsFullyInsideRegions$0$off021 = $newObjectIsFullyInsideRegions$2$off0;
    }
   }
   if ((($nbHandles$1|0) == 0)) {
    $nbHandles$0$lcssa27 = 0;$newObjectIsFullyInsideRegions$0$off0$lcssa28 = $newObjectIsFullyInsideRegions$2$off0;
    break;
   } else if ((($nbHandles$1|0) == 1)) {
    $78 = HEAP32[$tmpHandles>>2]|0;
    $79 = (($objectMemory$0) + 8|0);
    HEAP16[$79>>1]=$78&65535;HEAP16[$79+2>>1]=$78>>>16;
    $nbHandles$0$lcssa27 = 1;$newObjectIsFullyInsideRegions$0$off0$lcssa28 = $newObjectIsFullyInsideRegions$2$off0;
    break;
   }
   $80 = ((($this) + ($nbHandles$1<<4)|0) + 96|0);
   $81 = ((($this) + ($nbHandles$1<<2)|0) + 4208|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==(-1);
   if ($83) {
    $89 = ((($this) + ($nbHandles$1<<4)|0) + 100|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = (($objectMemory$0) + 8|0);
    HEAP32[$91>>2] = $90;
    $92 = $nbHandles$1 & 1073741823;
    $93 = HEAP32[$89>>2]|0;
    $94 = (($93) + ($92))|0;
    $95 = HEAP32[$80>>2]|0;
    $96 = ($94>>>0)>($95>>>0);
    if ($96) {
     (__ZN5physx2Gu9Container6ResizeEj($80,$92)|0);
     $$pre$i$i18 = HEAP32[$89>>2]|0;
     $100 = $$pre$i$i18;
    } else {
     $100 = $93;
    }
    $97 = ((($this) + ($nbHandles$1<<4)|0) + 104|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (($98) + ($100<<2)|0);
    $101 = (($100) + ($92))|0;
    HEAP32[$89>>2] = $101;
    $handlesMemory$0$i = $99;
   } else {
    $84 = (($objectMemory$0) + 8|0);
    HEAP32[$84>>2] = $82;
    $85 = ((($this) + ($nbHandles$1<<4)|0) + 104|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($86) + ($82<<2)|0);
    $88 = HEAP32[$87>>2]|0;
    HEAP32[$81>>2] = $88;
    $handlesMemory$0$i = $87;
   }
   $102 = $nbHandles$1 << 2;
   _memcpy(($handlesMemory$0$i|0),($tmpHandles|0),($102|0))|0;
   $nbHandles$0$lcssa27 = $nbHandles$1;$newObjectIsFullyInsideRegions$0$off0$lcssa28 = $newObjectIsFullyInsideRegions$2$off0;
  }
 } while(0);
 $103 = $nbHandles$0$lcssa27&65535;
 $104 = (($objectMemory$0) + 4|0);
 HEAP16[$104>>1] = $103;
 $105 = ($flipFlop$0|0)==(0);
 $$ = $105 ? 0 : 2;
 $106 = ($nbHandles$0$lcssa27|0)!=(0);
 $brmerge$demorgan = $106 & $newObjectIsFullyInsideRegions$0$off0$lcssa28;
 $107 = (($this) + 5252|0);
 $108 = $MBPObjectIndex$0 >>> 5;
 $109 = (($this) + 5256|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = ($108>>>0)<($110>>>0);
 if ($brmerge$demorgan) {
  if ($111) {
   $$pre$i12 = HEAP32[$107>>2]|0;
   $134 = $$pre$i12;
  } else {
   $112 = (($MBPObjectIndex$0) + 128)|0;
   $113 = $112 >>> 5;
   $114 = $112 & 31;
   $115 = ($114|0)!=(0);
   $116 = $115&1;
   $117 = (($116) + ($113))|0;
   $118 = $117 << 2;
   $119 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$118,483632,429)|0);
   $120 = HEAP32[$109>>2]|0;
   $121 = ($120|0)==(0);
   if ($121) {
    $125 = 0;
   } else {
    $122 = HEAP32[$107>>2]|0;
    $123 = $120 << 2;
    _memcpy(($119|0),($122|0),($123|0))|0;
    $$pre$i$i14 = HEAP32[$109>>2]|0;
    $125 = $$pre$i$i14;
   }
   $124 = ($117|0)==($125|0);
   if (!($124)) {
    $126 = (($117) - ($125))|0;
    $127 = (($119) + ($125<<2)|0);
    $128 = $126 << 2;
    _memset(($127|0),0,($128|0))|0;
   }
   $129 = HEAP32[$107>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$129);
    HEAP32[$107>>2] = 0;
   }
   HEAP32[$107>>2] = $119;
   HEAP32[$109>>2] = $117;
   $134 = $119;
  }
  $131 = $MBPObjectIndex$0 & 31;
  $132 = 1 << $131;
  $133 = (($134) + ($108<<2)|0);
  $135 = HEAP32[$133>>2]|0;
  $136 = $135 | $132;
  HEAP32[$133>>2] = $136;
 } else {
  if ($111) {
   $$pre$i7 = HEAP32[$107>>2]|0;
   $160 = $$pre$i7;
  } else {
   $137 = (($MBPObjectIndex$0) + 128)|0;
   $138 = $137 >>> 5;
   $139 = $137 & 31;
   $140 = ($139|0)!=(0);
   $141 = $140&1;
   $142 = (($141) + ($138))|0;
   $143 = $142 << 2;
   $144 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$143,483632,429)|0);
   $145 = HEAP32[$109>>2]|0;
   $146 = ($145|0)==(0);
   if ($146) {
    $150 = 0;
   } else {
    $147 = HEAP32[$107>>2]|0;
    $148 = $145 << 2;
    _memcpy(($144|0),($147|0),($148|0))|0;
    $$pre$i$i9 = HEAP32[$109>>2]|0;
    $150 = $$pre$i$i9;
   }
   $149 = ($142|0)==($150|0);
   if (!($149)) {
    $151 = (($142) - ($150))|0;
    $152 = (($144) + ($150<<2)|0);
    $153 = $151 << 2;
    _memset(($152|0),0,($153|0))|0;
   }
   $154 = HEAP32[$107>>2]|0;
   $155 = ($154|0)==(0|0);
   if (!($155)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$154);
    HEAP32[$107>>2] = 0;
   }
   HEAP32[$107>>2] = $144;
   HEAP32[$109>>2] = $142;
   $160 = $144;
  }
  $156 = $MBPObjectIndex$0 & 31;
  $157 = 1 << $156;
  $158 = $157 ^ -1;
  $159 = (($160) + ($108<<2)|0);
  $161 = HEAP32[$159>>2]|0;
  $162 = $161 & $158;
  HEAP32[$159>>2] = $162;
 }
 if (!($106)) {
  $163 = (($objectMemory$0) + 8|0);
  HEAP32[$163>>2] = $31;
  $164 = (($this) + 5236|0);
  $165 = (($this) + 5240|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = HEAP32[$164>>2]|0;
  $168 = ($166|0)==($167|0);
  if ($168) {
   (__ZN5physx2Gu9Container6ResizeEj($164,1)|0);
   $$pre$i$i4 = HEAP32[$165>>2]|0;
   $170 = $$pre$i$i4;
  } else {
   $170 = $166;
  }
  $169 = (($170) + 1)|0;
  HEAP32[$165>>2] = $169;
  $171 = (($this) + 5244|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = (($172) + ($170<<2)|0);
  HEAP32[$173>>2] = $userID;
 }
 if ($isStatic) {
  $203 = (($objectMemory$0) + 6|0);
  HEAP16[$203>>1] = $$;
  HEAP32[$objectMemory$0>>2] = $userID;
  STACKTOP = sp;return ($31|0);
 }
 $174 = (($this) + 80|0);
 $175 = (($this) + 84|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = ($108>>>0)<($176>>>0);
 if ($177) {
  $$pre$i = HEAP32[$174>>2]|0;
  $200 = $$pre$i;
 } else {
  $178 = (($MBPObjectIndex$0) + 128)|0;
  $179 = $178 >>> 5;
  $180 = $178 & 31;
  $181 = ($180|0)!=(0);
  $182 = $181&1;
  $183 = (($182) + ($179))|0;
  $184 = $183 << 2;
  $185 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$184,483632,429)|0);
  $186 = HEAP32[$175>>2]|0;
  $187 = ($186|0)==(0);
  if ($187) {
   $191 = 0;
  } else {
   $188 = HEAP32[$174>>2]|0;
   $189 = $186 << 2;
   _memcpy(($185|0),($188|0),($189|0))|0;
   $$pre$i$i = HEAP32[$175>>2]|0;
   $191 = $$pre$i$i;
  }
  $190 = ($183|0)==($191|0);
  if (!($190)) {
   $192 = (($183) - ($191))|0;
   $193 = (($185) + ($191<<2)|0);
   $194 = $192 << 2;
   _memset(($193|0),0,($194|0))|0;
  }
  $195 = HEAP32[$174>>2]|0;
  $196 = ($195|0)==(0|0);
  if (!($196)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$195);
   HEAP32[$174>>2] = 0;
  }
  HEAP32[$174>>2] = $185;
  HEAP32[$175>>2] = $183;
  $200 = $185;
 }
 $197 = $MBPObjectIndex$0 & 31;
 $198 = 1 << $197;
 $199 = (($200) + ($108<<2)|0);
 $201 = HEAP32[$199>>2]|0;
 $202 = $201 | $198;
 HEAP32[$199>>2] = $202;
 $203 = (($objectMemory$0) + 6|0);
 HEAP16[$203>>1] = $$;
 HEAP32[$objectMemory$0>>2] = $userID;
 STACKTOP = sp;return ($31|0);
}
function __ZN3MBP12removeObjectEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i4 = 0, $$pre$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $exitcond = 0, $handles$0$i = 0, $i$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = $handle >>> 2;
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($2*12)|0)|0) + 4|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $10 = ($8<<16>>16)==(0);
 if (!($10)) {
  $11 = ($8<<16>>16)==(1);
  $12 = ((($4) + (($2*12)|0)|0) + 8|0);
  if ($11) {
   $handles$0$i = $12;
  } else {
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($this) + ($9<<4)|0) + 104|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + ($13<<2)|0);
   $handles$0$i = $16;
  }
  $i$07 = 0;
  while(1) {
   $17 = ((($handles$0$i) + ($i$07<<2)|0) + 2|0);
   $18 = HEAP16[$17>>1]|0;
   $19 = $18&65535;
   $20 = ((($6) + (($19*40)|0)|0) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($handles$0$i) + ($i$07<<2)|0);
   $23 = HEAP16[$22>>1]|0;
   __ZN9BoxPruner12removeObjectEt($21,$23);
   $24 = (($i$07) + 1)|0;
   $exitcond = ($24|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$07 = $24;
   }
  }
  $25 = ($8&65535)>(1);
  if ($25) {
   $26 = ((($4) + (($2*12)|0)|0) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($this) + ($9<<4)|0) + 104|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + ($27<<2)|0);
   $31 = ((($this) + ($9<<2)|0) + 4208|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$30>>2] = $32;
   HEAP32[$31>>2] = $27;
  }
 }
 HEAP16[$7>>1] = 0;
 $33 = ((($4) + (($2*12)|0)|0) + 6|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = $34&65535;
 $36 = $35 | 4;
 $37 = $36&65535;
 HEAP16[$33>>1] = $37;
 $38 = (($this) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($4) + (($2*12)|0)|0) + 8|0);
 HEAP32[$40>>2] = $39;
 $41 = (($this) + 80|0);
 $42 = $handle >>> 7;
 $43 = (($this) + 84|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42>>>0)<($44>>>0);
 if ($45) {
  $$pre$i2 = HEAP32[$41>>2]|0;
  $68 = $$pre$i2;
 } else {
  $46 = (($2) + 128)|0;
  $47 = $46 >>> 5;
  $48 = $46 & 31;
  $49 = ($48|0)!=(0);
  $50 = $49&1;
  $51 = (($50) + ($47))|0;
  $52 = $51 << 2;
  $53 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$52,483632,429)|0);
  $54 = HEAP32[$43>>2]|0;
  $55 = ($54|0)==(0);
  if ($55) {
   $59 = 0;
  } else {
   $56 = HEAP32[$41>>2]|0;
   $57 = $54 << 2;
   _memcpy(($53|0),($56|0),($57|0))|0;
   $$pre$i$i4 = HEAP32[$43>>2]|0;
   $59 = $$pre$i$i4;
  }
  $58 = ($51|0)==($59|0);
  if (!($58)) {
   $60 = (($51) - ($59))|0;
   $61 = (($53) + ($59<<2)|0);
   $62 = $60 << 2;
   _memset(($61|0),0,($62|0))|0;
  }
  $63 = HEAP32[$41>>2]|0;
  $64 = ($63|0)==(0|0);
  if (!($64)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$63);
   HEAP32[$41>>2] = 0;
  }
  HEAP32[$41>>2] = $53;
  HEAP32[$43>>2] = $51;
  $68 = $53;
 }
 $65 = $2 & 31;
 $66 = 1 << $65;
 $67 = (($68) + ($42<<2)|0);
 $69 = HEAP32[$67>>2]|0;
 $70 = $69 | $66;
 HEAP32[$67>>2] = $70;
 HEAP32[$38>>2] = $2;
 $71 = (($this) + 88|0);
 $72 = (($this) + 92|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($42>>>0)<($73>>>0);
 if ($74) {
  $$pre$i = HEAP32[$71>>2]|0;
  $95 = $$pre$i;
  $94 = (($95) + ($42<<2)|0);
  $96 = HEAP32[$94>>2]|0;
  $97 = $96 | $66;
  HEAP32[$94>>2] = $97;
  STACKTOP = sp;return 1;
 }
 $75 = (($2) + 128)|0;
 $76 = $75 >>> 5;
 $77 = $75 & 31;
 $78 = ($77|0)!=(0);
 $79 = $78&1;
 $80 = (($79) + ($76))|0;
 $81 = $80 << 2;
 $82 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$81,483632,429)|0);
 $83 = HEAP32[$72>>2]|0;
 $84 = ($83|0)==(0);
 if ($84) {
  $88 = 0;
 } else {
  $85 = HEAP32[$71>>2]|0;
  $86 = $83 << 2;
  _memcpy(($82|0),($85|0),($86|0))|0;
  $$pre$i$i = HEAP32[$72>>2]|0;
  $88 = $$pre$i$i;
 }
 $87 = ($80|0)==($88|0);
 if (!($87)) {
  $89 = (($80) - ($88))|0;
  $90 = (($82) + ($88<<2)|0);
  $91 = $89 << 2;
  _memset(($90|0),0,($91|0))|0;
 }
 $92 = HEAP32[$71>>2]|0;
 $93 = ($92|0)==(0|0);
 if (!($93)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$92);
  HEAP32[$71>>2] = 0;
 }
 HEAP32[$71>>2] = $82;
 HEAP32[$72>>2] = $80;
 $95 = $82;
 $94 = (($95) + ($42<<2)|0);
 $96 = HEAP32[$94>>2]|0;
 $97 = $96 | $66;
 HEAP32[$94>>2] = $97;
 STACKTOP = sp;return 1;
}
function __ZN15MBP_PairManager17removeMarkedPairsEPK10MBP_ObjectPN5physx16PxsBroadPhaseMBPERK8BitArrayS8_($this,$objects,$mbp,$updated,$removed) {
 $this = $this|0;
 $objects = $objects|0;
 $mbp = $mbp|0;
 $updated = $updated|0;
 $removed = $removed|0;
 var $$pre$i = 0, $$pre$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $i$0$be = 0, $i$0$ph21 = 0, $i$018 = 0, $nbActivePairs$0$ph19 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = (($this) + 20|0);
   $6 = (($updated) + 4|0);
   $7 = (($mbp) + 120|0);
   $8 = (($mbp) + 96|0);
   $9 = (($0) + 4|0);
   $10 = (($mbp) + 104|0);
   $11 = (($mbp) + 100|0);
   $12 = (($removed) + 4|0);
   $13 = (($mbp) + 108|0);
   $14 = (($1) + 4|0);
   $15 = (($mbp) + 116|0);
   $16 = (($mbp) + 112|0);
   $17 = (($this) + 4|0);
   $i$0$ph21 = 0;$nbActivePairs$0$ph19 = $3;
   while(1) {
    $i$018 = $i$0$ph21;
    L5: while(1) {
     $18 = HEAP32[$5>>2]|0;
     $19 = (($18) + (($i$018*12)|0)|0);
     $20 = ((($18) + (($i$018*12)|0)|0) + 8|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)==(0);
     do {
      if ($22) {
       $61 = ((($18) + (($i$018*12)|0)|0) + 9|0);
       $62 = HEAP8[$61>>0]|0;
       $63 = ($62<<24>>24)==(0);
       if (!($63)) {
        HEAP8[$61>>0] = 0;
        break;
       }
       $65 = HEAP32[$19>>2]|0;
       $66 = ((($18) + (($i$018*12)|0)|0) + 4|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = $65 >>> 2;
       $69 = $67 >>> 2;
       $70 = $65 >>> 7;
       $71 = HEAP32[$6>>2]|0;
       $72 = ($70>>>0)<($71>>>0);
       if ($72) {
        $73 = HEAP32[$updated>>2]|0;
        $74 = (($73) + ($70<<2)|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = $68 & 31;
        $77 = 1 << $76;
        $78 = $75 & $77;
        $79 = ($78|0)==(0);
        if (!($79)) {
         break L5;
        }
       }
       $80 = $67 >>> 7;
       $81 = ($80>>>0)<($71>>>0);
       if ($81) {
        $82 = HEAP32[$updated>>2]|0;
        $83 = (($82) + ($80<<2)|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = $69 & 31;
        $86 = 1 << $85;
        $87 = $84 & $86;
        $88 = ($87|0)==(0);
        if (!($88)) {
         break L5;
        }
       }
      } else {
       $23 = HEAP32[$19>>2]|0;
       $24 = ((($18) + (($i$018*12)|0)|0) + 4|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = $23 >>> 2;
       $27 = $25 >>> 2;
       $28 = (($objects) + (($26*12)|0)|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($objects) + (($27*12)|0)|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = HEAP32[$7>>2]|0;
       $33 = (($32) + ($29<<2)|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + ($31<<2)|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = ($34|0)==($36|0);
       do {
        if (!($37)) {
         $38 = ($29>>>0)<($31>>>0);
         $39 = $38 ? $29 : $31;
         HEAP32[$0>>2] = $39;
         $40 = $38 ? $31 : $29;
         HEAP32[$9>>2] = $40;
         $41 = HEAP32[$10>>2]|0;
         $42 = $41 & 2147483647;
         $43 = HEAP32[$11>>2]|0;
         $44 = ($42>>>0)>($43>>>0);
         if (!($44)) {
          (__ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($8,$0)|0);
          break;
         }
         $45 = HEAP32[$8>>2]|0;
         $46 = (($45) + ($43<<3)|0);
         $47 = ($46|0)==(0|0);
         if ($47) {
          $59 = $43;
         } else {
          $48 = $0;
          $49 = $48;
          $50 = HEAP32[$49>>2]|0;
          $51 = (($48) + 4)|0;
          $52 = $51;
          $53 = HEAP32[$52>>2]|0;
          $54 = $46;
          $55 = $54;
          HEAP32[$55>>2] = $50;
          $56 = (($54) + 4)|0;
          $57 = $56;
          HEAP32[$57>>2] = $53;
          $$pre$i1 = HEAP32[$11>>2]|0;
          $59 = $$pre$i1;
         }
         $58 = (($59) + 1)|0;
         HEAP32[$11>>2] = $58;
        }
       } while(0);
       HEAP8[$20>>0] = 0;
       $60 = ((($18) + (($i$018*12)|0)|0) + 9|0);
       HEAP8[$60>>0] = 0;
      }
     } while(0);
     $i$0$be = (($i$018) + 1)|0;
     $64 = ($i$0$be>>>0)<($nbActivePairs$0$ph19>>>0);
     if ($64) {
      $i$018 = $i$0$be;
     } else {
      break L1;
     }
    }
    $89 = HEAP32[$12>>2]|0;
    $90 = ($70>>>0)<($89>>>0);
    if ($90) {
     $91 = HEAP32[$removed>>2]|0;
     $92 = (($91) + ($70<<2)|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = $68 & 31;
     $95 = 1 << $94;
     $96 = $93 & $95;
     $97 = ($96|0)==(0);
     if ($97) {
      label = 21;
     }
    } else {
     label = 21;
    }
    do {
     if ((label|0) == 21) {
      label = 0;
      $98 = $67 >>> 7;
      $99 = ($98>>>0)<($89>>>0);
      if ($99) {
       $100 = HEAP32[$removed>>2]|0;
       $101 = (($100) + ($98<<2)|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = $69 & 31;
       $104 = 1 << $103;
       $105 = $102 & $104;
       $106 = ($105|0)==(0);
       if (!($106)) {
        break;
       }
      }
      $107 = (($objects) + (($68*12)|0)|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = (($objects) + (($69*12)|0)|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = HEAP32[$7>>2]|0;
      $112 = (($111) + ($108<<2)|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = (($111) + ($110<<2)|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ($113|0)==($115|0);
      if (!($116)) {
       $117 = ($108>>>0)<($110>>>0);
       $118 = $117 ? $108 : $110;
       HEAP32[$1>>2] = $118;
       $119 = $117 ? $110 : $108;
       HEAP32[$14>>2] = $119;
       $120 = HEAP32[$15>>2]|0;
       $121 = $120 & 2147483647;
       $122 = HEAP32[$16>>2]|0;
       $123 = ($121>>>0)>($122>>>0);
       if (!($123)) {
        (__ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($13,$1)|0);
        break;
       }
       $124 = HEAP32[$13>>2]|0;
       $125 = (($124) + ($122<<3)|0);
       $126 = ($125|0)==(0|0);
       if ($126) {
        $138 = $122;
       } else {
        $127 = $1;
        $128 = $127;
        $129 = HEAP32[$128>>2]|0;
        $130 = (($127) + 4)|0;
        $131 = $130;
        $132 = HEAP32[$131>>2]|0;
        $133 = $125;
        $134 = $133;
        HEAP32[$134>>2] = $129;
        $135 = (($133) + 4)|0;
        $136 = $135;
        HEAP32[$136>>2] = $132;
        $$pre$i = HEAP32[$16>>2]|0;
        $138 = $$pre$i;
       }
       $137 = (($138) + 1)|0;
       HEAP32[$16>>2] = $137;
      }
     }
    } while(0);
    $139 = $65 & 65535;
    $140 = $67 << 16;
    $141 = $140 | $139;
    $142 = $141 << 15;
    $143 = $142 ^ -1;
    $144 = (($141) + ($143))|0;
    $145 = $144 >> 10;
    $146 = $145 ^ $144;
    $147 = ($146*9)|0;
    $148 = $147 >> 6;
    $149 = $148 ^ $147;
    $150 = $149 << 11;
    $151 = $150 ^ -1;
    $152 = (($149) + ($151))|0;
    $153 = $152 >> 16;
    $154 = $153 ^ $152;
    $155 = HEAP32[$17>>2]|0;
    $156 = $155 & $154;
    __ZN15MBP_PairManager10removePairEjjjj($this,0,0,$156,$i$018);
    $157 = (($nbActivePairs$0$ph19) + -1)|0;
    $158 = ($i$018>>>0)<($157>>>0);
    if ($158) {
     $i$0$ph21 = $i$018;$nbActivePairs$0$ph19 = $157;
    } else {
     break;
    }
   }
  }
 } while(0);
 $159 = HEAP32[$2>>2]|0;
 $160 = $159 >>> 1;
 $161 = $160 | $159;
 $162 = $161 >>> 2;
 $163 = $162 | $161;
 $164 = $163 >>> 4;
 $165 = $164 | $163;
 $166 = $165 >>> 8;
 $167 = $166 | $165;
 $168 = $167 >>> 16;
 $169 = $168 | $167;
 $170 = (($169) + 1)|0;
 $171 = HEAP32[$this>>2]|0;
 $172 = ($171|0)==($170|0);
 if ($172) {
  STACKTOP = sp;return 1;
 }
 $173 = (($this) + 24|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ($174|0)!=(0);
 $176 = ($170>>>0)<($174>>>0);
 $or$cond$i = $175 & $176;
 if ($or$cond$i) {
  STACKTOP = sp;return 1;
 }
 HEAP32[$this>>2] = $170;
 $177 = (($this) + 4|0);
 HEAP32[$177>>2] = $169;
 __ZN15MBP_PairManager12reallocPairsEv($this);
 STACKTOP = sp;return 1;
}
function __ZN3MBP17prepareOverlapsMTEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $5 = ((($3) + (($i$01*40)|0)|0) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  do {
   if (!($7)) {
    $8 = (($6) + 116|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    $11 = (($6) + 168|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = ($12<<24>>24)==(0);
    if ($10) {
     if ($13) {
      break;
     } else {
      label = 6;
     }
    } else {
     if (!($13)) {
      label = 6;
     }
    }
    if ((label|0) == 6) {
     label = 0;
     __ZN9BoxPruner10staticSortEv($6);
     $14 = (($6) + 92|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$8>>2] = $15;
     $16 = (($6) + 120|0);
     HEAP32[$16>>2] = 0;
     $17 = (($6) + 169|0);
     HEAP8[$17>>0] = 1;
    }
    $18 = (($6) + 176|0);
    __ZN9BoxPruner14preparePruningER16MBPOS_TmpBuffers($6,$18);
    $19 = HEAP32[$8>>2]|0;
    $20 = ($19|0)==(0);
    if (!($20)) {
     $21 = (($6) + 84|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0);
     if (!($23)) {
      $25 = (($6) + 76|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($6) + 32|0);
      HEAP32[$27>>2] = $26;
      $28 = (($6) + 36|0);
      HEAP32[$28>>2] = $19;
      $29 = (($6) + 40|0);
      HEAP32[$29>>2] = $22;
      $30 = (($6) + 12992|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($6) + 44|0);
      HEAP32[$32>>2] = $31;
      $33 = (($6) + 96|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($6) + 48|0);
      HEAP32[$35>>2] = $34;
      $36 = (($6) + 104|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($6) + 52|0);
      HEAP32[$38>>2] = $37;
      $39 = (($6) + 144|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($6) + 56|0);
      HEAP32[$41>>2] = $40;
      $42 = (($6) + 60|0);
      HEAP8[$42>>0] = 1;
      break;
     }
    }
    $24 = (($6) + 60|0);
    HEAP8[$24>>0] = 0;
   }
  } while(0);
  $43 = (($i$01) + 1)|0;
  $exitcond = ($43|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $43;
  }
 }
 STACKTOP = sp;return;
}
function __ZN3MBP11shiftOriginERKN5physx6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$0$i$i = 0, $$0$i$i1 = 0, $$0$i$i7 = 0, $$0$i1$i = 0, $$0$i1$i12 = 0, $$0$i1$i6 = 0, $$0$i2$i = 0, $$0$i2$i11 = 0, $$0$i2$i5 = 0, $$0$i3$i = 0, $$0$i3$i10 = 0, $$0$i3$i4 = 0, $$0$i4$i = 0, $$0$i4$i3 = 0, $$0$i4$i9 = 0, $$0$i5$i = 0, $$0$i5$i2 = 0, $$0$i5$i8 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $decodedBounds = 0, $exitcond = 0, $exitcond20 = 0, $handles$0$i = 0, $i$016 = 0, $i1$014 = 0, $j$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $decodedBounds = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==(0);
 if (!($4)) {
  $5 = (($shift) + 4|0);
  $6 = (($shift) + 8|0);
  $i$016 = 0;
  while(1) {
   $7 = ((($3) + (($i$016*40)|0)|0) + 28|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = ((($3) + (($i$016*40)|0)|0) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = $11 << 1;
    $13 = ($12|0)<(0);
    $14 = $12 & 2147483646;
    $15 = $12 ^ -1;
    $$0$i$i7 = $13 ? $14 : $15;
    $16 = ((($3) + (($i$016*40)|0)|0) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = $17 << 1;
    $19 = ($18|0)<(0);
    $20 = $18 & 2147483646;
    $21 = $18 ^ -1;
    $$0$i5$i8 = $19 ? $20 : $21;
    $22 = ((($3) + (($i$016*40)|0)|0) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = $23 << 1;
    $25 = ($24|0)<(0);
    $26 = $24 & 2147483646;
    $27 = $24 ^ -1;
    $$0$i4$i9 = $25 ? $26 : $27;
    $28 = ((($3) + (($i$016*40)|0)|0) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = $29 << 1;
    $31 = ($30|0)<(0);
    $32 = $30 & 2147483646;
    $33 = $30 ^ -1;
    $$0$i3$i10 = $31 ? $32 : $33;
    $34 = ((($3) + (($i$016*40)|0)|0) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $35 << 1;
    $37 = ($36|0)<(0);
    $38 = $36 & 2147483646;
    $39 = $36 ^ -1;
    $$0$i2$i11 = $37 ? $38 : $39;
    $40 = ((($3) + (($i$016*40)|0)|0) + 24|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $41 << 1;
    $43 = ($42|0)<(0);
    $44 = $42 & 2147483646;
    $45 = $42 ^ -1;
    $$0$i1$i12 = $43 ? $44 : $45;
    $46 = Math_fround(HEAPF32[$shift>>2]);
    $47 = (HEAP32[tempDoublePtr>>2]=$$0$i$i7,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $48 = Math_fround($47 - $46);
    $49 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
    $50 = Math_fround(HEAPF32[$5>>2]);
    $51 = (HEAP32[tempDoublePtr>>2]=$$0$i5$i8,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $52 = Math_fround($51 - $50);
    $53 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
    $54 = Math_fround(HEAPF32[$6>>2]);
    $55 = (HEAP32[tempDoublePtr>>2]=$$0$i4$i9,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $56 = Math_fround($55 - $54);
    $57 = (HEAPF32[tempDoublePtr>>2]=$56,HEAP32[tempDoublePtr>>2]|0);
    $58 = (HEAP32[tempDoublePtr>>2]=$$0$i3$i10,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $59 = Math_fround($58 - $46);
    $60 = (HEAPF32[tempDoublePtr>>2]=$59,HEAP32[tempDoublePtr>>2]|0);
    $61 = (HEAP32[tempDoublePtr>>2]=$$0$i2$i11,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $62 = Math_fround($61 - $50);
    $63 = (HEAPF32[tempDoublePtr>>2]=$62,HEAP32[tempDoublePtr>>2]|0);
    $64 = (HEAP32[tempDoublePtr>>2]=$$0$i1$i12,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $65 = Math_fround($64 - $54);
    $66 = (HEAPF32[tempDoublePtr>>2]=$65,HEAP32[tempDoublePtr>>2]|0);
    $67 = ($49|0)<(0);
    $68 = $49 ^ -2;
    $69 = $49 | -2147483648;
    $$0$i$i1 = $67 ? $68 : $69;
    $70 = $$0$i$i1 >>> 1;
    HEAP32[$10>>2] = $70;
    $71 = ($53|0)<(0);
    $72 = $53 ^ -2;
    $73 = $53 | -2147483648;
    $$0$i5$i2 = $71 ? $72 : $73;
    $74 = $$0$i5$i2 >>> 1;
    HEAP32[$16>>2] = $74;
    $75 = ($57|0)<(0);
    $76 = $57 ^ -2;
    $77 = $57 | -2147483648;
    $$0$i4$i3 = $75 ? $76 : $77;
    $78 = $$0$i4$i3 >>> 1;
    HEAP32[$22>>2] = $78;
    $79 = ($60|0)<(0);
    $80 = $60 ^ -2;
    $81 = $60 | -2147483648;
    $$0$i3$i4 = $79 ? $80 : $81;
    $82 = $$0$i3$i4 >>> 1;
    HEAP32[$28>>2] = $82;
    $83 = ($63|0)<(0);
    $84 = $63 ^ -2;
    $85 = $63 | -2147483648;
    $$0$i2$i5 = $83 ? $84 : $85;
    $86 = $$0$i2$i5 >>> 1;
    HEAP32[$34>>2] = $86;
    $87 = ($66|0)<(0);
    $88 = $66 ^ -2;
    $89 = $66 | -2147483648;
    $$0$i1$i6 = $87 ? $88 : $89;
    $90 = $$0$i1$i6 >>> 1;
    HEAP32[$40>>2] = $90;
   }
   $91 = (($i$016) + 1)|0;
   $exitcond20 = ($91|0)==($1|0);
   if ($exitcond20) {
    break;
   } else {
    $i$016 = $91;
   }
  }
 }
 $92 = (($this) + 40|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($93>>>0) / 3)&-1;
 $95 = (($this) + 44|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($93>>>0)>(2);
 if (!($97)) {
  STACKTOP = sp;return;
 }
 $98 = (($this) + 5260|0);
 $99 = (($decodedBounds) + 4|0);
 $100 = (($decodedBounds) + 8|0);
 $101 = (($decodedBounds) + 12|0);
 $102 = (($decodedBounds) + 16|0);
 $103 = (($decodedBounds) + 20|0);
 $i1$014 = 0;
 while(1) {
  $104 = ((($96) + (($i1$014*12)|0)|0) + 4|0);
  $105 = HEAP16[$104>>1]|0;
  $106 = $105&65535;
  $107 = ($105<<16>>16)==(0);
  if (!($107)) {
   $108 = HEAP32[$98>>2]|0;
   $109 = (($96) + (($i1$014*12)|0)|0);
   $110 = HEAP32[$109>>2]|0;
   __ZNK5physx14PxsAABBManager11getBPBoundsEj($decodedBounds,$108,$110);
   $111 = HEAP32[$decodedBounds>>2]|0;
   $112 = ($111|0)<(0);
   $113 = $111 ^ -2;
   $114 = $111 | -2147483648;
   $$0$i$i = $112 ? $113 : $114;
   $115 = $$0$i$i >>> 1;
   $116 = HEAP32[$99>>2]|0;
   $117 = ($116|0)<(0);
   $118 = $116 ^ -2;
   $119 = $116 | -2147483648;
   $$0$i5$i = $117 ? $118 : $119;
   $120 = $$0$i5$i >>> 1;
   $121 = HEAP32[$100>>2]|0;
   $122 = ($121|0)<(0);
   $123 = $121 ^ -2;
   $124 = $121 | -2147483648;
   $$0$i4$i = $122 ? $123 : $124;
   $125 = $$0$i4$i >>> 1;
   $126 = HEAP32[$101>>2]|0;
   $127 = ($126|0)<(0);
   $128 = $126 ^ -2;
   $129 = $126 | -2147483648;
   $$0$i3$i = $127 ? $128 : $129;
   $130 = $$0$i3$i >>> 1;
   $131 = HEAP32[$102>>2]|0;
   $132 = ($131|0)<(0);
   $133 = $131 ^ -2;
   $134 = $131 | -2147483648;
   $$0$i2$i = $132 ? $133 : $134;
   $135 = $$0$i2$i >>> 1;
   $136 = HEAP32[$103>>2]|0;
   $137 = ($136|0)<(0);
   $138 = $136 ^ -2;
   $139 = $136 | -2147483648;
   $$0$i1$i = $137 ? $138 : $139;
   $140 = $$0$i1$i >>> 1;
   $141 = ($105<<16>>16)==(1);
   $142 = ((($96) + (($i1$014*12)|0)|0) + 8|0);
   if ($141) {
    $handles$0$i = $142;
   } else {
    $143 = HEAP32[$142>>2]|0;
    $144 = ((($this) + ($106<<4)|0) + 104|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = (($145) + ($143<<2)|0);
    $handles$0$i = $146;
   }
   $j$013 = 0;
   while(1) {
    $147 = ((($handles$0$i) + ($j$013<<2)|0) + 2|0);
    $148 = HEAP16[$147>>1]|0;
    $149 = $148&65535;
    $150 = ((($3) + (($149*40)|0)|0) + 28|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = (($handles$0$i) + ($j$013<<2)|0);
    $153 = HEAP16[$152>>1]|0;
    $154 = $153&65535;
    $155 = (($151) + 76|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = ((($156) + ($154<<3)|0) + 4|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = $158 & 1;
    $160 = ($159|0)==(0);
    $161 = (($156) + ($154<<3)|0);
    $162 = HEAP32[$161>>2]|0;
    if ($160) {
     $163 = (($151) + 100|0);
     $164 = HEAP32[$163>>2]|0;
     $165 = (($164) + (($162*24)|0)|0);
     HEAP32[$165>>2] = $115;
     $166 = ((($164) + (($162*24)|0)|0) + 4|0);
     HEAP32[$166>>2] = $120;
     $167 = ((($164) + (($162*24)|0)|0) + 8|0);
     HEAP32[$167>>2] = $125;
     $168 = ((($164) + (($162*24)|0)|0) + 12|0);
     HEAP32[$168>>2] = $130;
     $169 = ((($164) + (($162*24)|0)|0) + 16|0);
     HEAP32[$169>>2] = $135;
     $170 = ((($164) + (($162*24)|0)|0) + 20|0);
     HEAP32[$170>>2] = $140;
    } else {
     $171 = (($151) + 96|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = (($172) + (($162*24)|0)|0);
     HEAP32[$173>>2] = $115;
     $174 = ((($172) + (($162*24)|0)|0) + 4|0);
     HEAP32[$174>>2] = $120;
     $175 = ((($172) + (($162*24)|0)|0) + 8|0);
     HEAP32[$175>>2] = $125;
     $176 = ((($172) + (($162*24)|0)|0) + 12|0);
     HEAP32[$176>>2] = $130;
     $177 = ((($172) + (($162*24)|0)|0) + 16|0);
     HEAP32[$177>>2] = $135;
     $178 = ((($172) + (($162*24)|0)|0) + 20|0);
     HEAP32[$178>>2] = $140;
    }
    $179 = (($j$013) + 1)|0;
    $exitcond = ($179|0)==($106|0);
    if ($exitcond) {
     break;
    } else {
     $j$013 = $179;
    }
   }
  }
  $180 = (($i1$014) + 1)|0;
  $181 = ($180>>>0)<($94>>>0);
  if ($181) {
   $i1$014 = $180;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxsBroadPhaseMBPC2ERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerERKNS_11PxSceneDescEPNS_14PxsAABBManagerE($this,$scratchAllocator,$eventProfiler,$desc,$manager) {
 $this = $this|0;
 $scratchAllocator = $scratchAllocator|0;
 $eventProfiler = $eventProfiler|0;
 $desc = $desc|0;
 $manager = $manager|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((483840 + 8|0));
 $0 = (($this) + 4|0);
 __ZN5physx17MBPUpdateWorkTaskC2ERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerE($0,$scratchAllocator,$eventProfiler);
 $1 = (($this) + 44|0);
 __ZN5physx21MBPPostUpdateWorkTaskC2ERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerE($1,$scratchAllocator,$eventProfiler);
 $2 = (($this) + 88|0);
 $3 = (($this) + 96|0);
 $4 = (($this) + 104|0);
 $5 = (($this) + 108|0);
 $6 = (($this) + 116|0);
 dest=$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__Z15PxGetFoundationv()|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
 $$$i$i$i = $15 ? 484160 : 484000;
 $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,5264,$$$i$i$i,483632,3435)|0);
 HEAP32[$16>>2] = ((483728 + 8|0));
 $17 = (($16) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($16) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 12|0);
 HEAP32[$19>>2] = -1;
 $20 = (($16) + 16|0);
 HEAP32[$20>>2] = -1;
 $21 = (($16) + 20|0);
 __ZN5physx2Gu9ContainerC2Ev($21);
 $22 = (($16) + 36|0);
 __ZN5physx2Gu9ContainerC2Ev($22);
 $23 = (($16) + 52|0);
 $24 = (($16) + 96|0);
 $25 = (($16) + 4208|0);
 dest=$23+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $26 = $24;
 while(1) {
  __ZN5physx2Gu9ContainerC2Ev($26);
  $27 = (($26) + 16|0);
  $28 = ($27|0)==($25|0);
  if ($28) {
   break;
  } else {
   $26 = $27;
  }
 }
 $29 = (($16) + 5236|0);
 __ZN5physx2Gu9ContainerC2Ev($29);
 $30 = (($16) + 5252|0);
 HEAP32[$30>>2] = 0;
 $31 = (($16) + 5256|0);
 HEAP32[$31>>2] = 0;
 $32 = (($16) + 5260|0);
 HEAP32[$32>>2] = $manager;
 _memset(($25|0),-1,1028)|0;
 $33 = (($this) + 84|0);
 HEAP32[$33>>2] = $16;
 $34 = (($desc) + 72|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($desc) + 56|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($desc) + 60|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + ($37))|0;
 (__ZN3MBP11preallocateEjj($16,$35,$40)|0);
 $41 = HEAP32[$4>>2]|0;
 $42 = $41 & 2147482624;
 $43 = ($42>>>0)<(1024);
 if ($43) {
  __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($3,1024);
 }
 $44 = HEAP32[$6>>2]|0;
 $45 = $44 & 2147482624;
 $46 = ($45>>>0)<(1024);
 if (!($46)) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($5,1024);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsBroadPhaseMBPD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx16PxsBroadPhaseMBPD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsBroadPhaseMBPD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((483840 + 8|0));
 $1 = (($this) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($2);
  HEAP32[$1>>2] = 0;
 }
 $7 = (($this) + 88|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$8);
 $9 = (($this) + 116|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11|0)!=(0);
 $13 = ($10|0)>(-1);
 $or$cond$i$i1 = $12 & $13;
 if ($or$cond$i$i1) {
  $14 = (($this) + 108|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$20 & 4095]($17,$15);
  }
 }
 $21 = (($this) + 104|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 & 2147483647;
 $24 = ($23|0)!=(0);
 $25 = ($22|0)>(-1);
 $or$cond$i$i = $24 & $25;
 if ($or$cond$i$i) {
  $26 = (($this) + 96|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if (!($28)) {
   $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
  }
 }
 $33 = (($this) + 44|0);
 HEAP32[$33>>2] = ((434896 + 8|0));
 $34 = (($this) + 52|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 4|0);
 __ZN5physx17MBPUpdateWorkTaskD2Ev($35);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxsBroadPhaseMBP7getCapsERNS_16PxBroadPhaseCapsE($this,$caps) {
 $this = $this|0;
 $caps = $caps|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$caps>>2] = 256;
 $0 = (($caps) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($caps) + 8|0);
 HEAP8[$1>>0] = 1;
 STACKTOP = sp;return 1;
}
function __ZNK5physx16PxsBroadPhaseMBP12getNbRegionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK5physx16PxsBroadPhaseMBP10getRegionsEPNS_22PxBroadPhaseRegionInfoEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$0$i$i = 0, $$0$i1$i = 0, $$0$i2$i = 0, $$0$i3$i = 0, $$0$i4$i = 0, $$0$i5$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($bufferSize>>>0);
 $7 = $6 ? $3 : $bufferSize;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return ($7|0);
 }
 $9 = $3 ^ -1;
 $10 = $bufferSize ^ -1;
 $11 = ($9>>>0)>($10>>>0);
 $umax = $11 ? $9 : $10;
 $12 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $$sum = (($i$01) + ($startIndex))|0;
  $13 = (($userBuffer) + (($i$01*40)|0)|0);
  $14 = ((($5) + (($$sum*40)|0)|0) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 << 1;
  $17 = ($16|0)<(0);
  $18 = $16 & 2147483646;
  $19 = $16 ^ -1;
  $$0$i$i = $17 ? $18 : $19;
  HEAP32[$13>>2] = $$0$i$i;
  $20 = ((($5) + (($$sum*40)|0)|0) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 << 1;
  $23 = ($22|0)<(0);
  $24 = $22 & 2147483646;
  $25 = $22 ^ -1;
  $$0$i5$i = $23 ? $24 : $25;
  $26 = ((($userBuffer) + (($i$01*40)|0)|0) + 4|0);
  HEAP32[$26>>2] = $$0$i5$i;
  $27 = ((($5) + (($$sum*40)|0)|0) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 << 1;
  $30 = ($29|0)<(0);
  $31 = $29 & 2147483646;
  $32 = $29 ^ -1;
  $$0$i4$i = $30 ? $31 : $32;
  $33 = ((($userBuffer) + (($i$01*40)|0)|0) + 8|0);
  HEAP32[$33>>2] = $$0$i4$i;
  $34 = ((($5) + (($$sum*40)|0)|0) + 16|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = $35 << 1;
  $37 = ($36|0)<(0);
  $38 = $36 & 2147483646;
  $39 = $36 ^ -1;
  $$0$i3$i = $37 ? $38 : $39;
  $40 = ((($userBuffer) + (($i$01*40)|0)|0) + 12|0);
  HEAP32[$40>>2] = $$0$i3$i;
  $41 = ((($5) + (($$sum*40)|0)|0) + 20|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 << 1;
  $44 = ($43|0)<(0);
  $45 = $43 & 2147483646;
  $46 = $43 ^ -1;
  $$0$i2$i = $44 ? $45 : $46;
  $47 = ((($userBuffer) + (($i$01*40)|0)|0) + 16|0);
  HEAP32[$47>>2] = $$0$i2$i;
  $48 = ((($5) + (($$sum*40)|0)|0) + 24|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = $49 << 1;
  $51 = ($50|0)<(0);
  $52 = $50 & 2147483646;
  $53 = $50 ^ -1;
  $$0$i1$i = $51 ? $52 : $53;
  $54 = ((($userBuffer) + (($i$01*40)|0)|0) + 20|0);
  HEAP32[$54>>2] = $$0$i1$i;
  $55 = ((($5) + (($$sum*40)|0)|0) + 28|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if ($57) {
   HEAPF32[$13>>2] = Math_fround(8.50705866596322149529E+37);
   HEAPF32[$26>>2] = Math_fround(8.50705866596322149529E+37);
   HEAPF32[$33>>2] = Math_fround(8.50705866596322149529E+37);
   $74 = ((($userBuffer) + (($i$01*40)|0)|0) + 12|0);
   HEAPF32[$74>>2] = Math_fround(-8.50705866596322149529E+37);
   HEAPF32[$47>>2] = Math_fround(-8.50705866596322149529E+37);
   HEAPF32[$54>>2] = Math_fround(-8.50705866596322149529E+37);
   $75 = ((($userBuffer) + (($i$01*40)|0)|0) + 24|0);
   ;HEAP32[$75+0>>2]=0|0;HEAP32[$75+4>>2]=0|0;HEAP32[$75+8>>2]=0|0;HEAP16[$75+12>>1]=0|0;
  } else {
   $58 = ((($5) + (($$sum*40)|0)|0) + 36|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ((($userBuffer) + (($i$01*40)|0)|0) + 24|0);
   HEAP32[$60>>2] = $59;
   $61 = ((($userBuffer) + (($i$01*40)|0)|0) + 36|0);
   HEAP8[$61>>0] = 1;
   $62 = ((($5) + (($$sum*40)|0)|0) + 32|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)!=(0);
   $65 = ((($userBuffer) + (($i$01*40)|0)|0) + 37|0);
   $66 = $64&1;
   HEAP8[$65>>0] = $66;
   $67 = HEAP32[$55>>2]|0;
   $68 = (($67) + 84|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ((($userBuffer) + (($i$01*40)|0)|0) + 28|0);
   HEAP32[$70>>2] = $69;
   $71 = (($67) + 92|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ((($userBuffer) + (($i$01*40)|0)|0) + 32|0);
   HEAP32[$73>>2] = $72;
  }
  $76 = (($i$01) + 1)|0;
  $exitcond = ($76|0)==($12|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $76;
  }
 }
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx16PxsBroadPhaseMBP9addRegionERKNS_18PxBroadPhaseRegionEb($this,$region,$populateRegion) {
 $this = $this|0;
 $region = $region|0;
 $populateRegion = $populateRegion|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN3MBP12addBoxPrunerERKN5physx18PxBroadPhaseRegionEb($1,$region,$populateRegion)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx16PxsBroadPhaseMBP12removeRegionEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN3MBP15removeBoxPrunerEj($1,$handle)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx16PxsBroadPhaseMBP7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsBroadPhaseMBP6updateEjjRKNS_23PxcBroadPhaseUpdateDataEPNS_10PxBaseTaskE($this,$numCpuTasks,$numSpus,$updateData,$continuation) {
 $this = $this|0;
 $numCpuTasks = $numCpuTasks|0;
 $numSpus = $numSpus|0;
 $updateData = $updateData|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx16PxsBroadPhaseMBP13setUpdateDataERKNS_23PxcBroadPhaseUpdateDataE($this,$updateData);
 $0 = (($this) + 44|0);
 $1 = (($this) + 64|0);
 HEAP32[$1>>2] = $this;
 $2 = (($this) + 4|0);
 $3 = (($this) + 24|0);
 HEAP32[$3>>2] = $this;
 $4 = (($this) + 68|0);
 HEAP32[$4>>2] = $numCpuTasks;
 $5 = (($this) + 28|0);
 HEAP32[$5>>2] = $numCpuTasks;
 $6 = (($this) + 72|0);
 HEAP32[$6>>2] = $numSpus;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $numSpus;
 $8 = (($this) + 60|0);
 HEAP32[$8>>2] = 1;
 $9 = (($this) + 56|0);
 HEAP32[$9>>2] = $continuation;
 $10 = ($continuation|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$continuation>>2]|0;
  $12 = (($11) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($continuation);
  $14 = HEAP32[$9>>2]|0;
  $15 = (($14) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($this) + 52|0);
  HEAP32[$17>>2] = $16;
 }
 $18 = (($this) + 20|0);
 HEAP32[$18>>2] = 1;
 $19 = (($this) + 16|0);
 HEAP32[$19>>2] = $0;
 $20 = HEAP32[$0>>2]|0;
 $21 = (($20) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($0);
 $23 = HEAP32[$19>>2]|0;
 $24 = (($23) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 12|0);
 HEAP32[$26>>2] = $25;
 $27 = HEAP32[$0>>2]|0;
 $28 = (($27) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vi[$29 & 4095]($0);
 $30 = HEAP32[$2>>2]|0;
 $31 = (($30) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vi[$32 & 4095]($2);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsBroadPhaseMBP13setUpdateDataERKNS_23PxcBroadPhaseUpdateDataE($this,$updateData) {
 $this = $this|0;
 $updateData = $updateData|0;
 var $$pre = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aabb = 0, $aabb5 = 0, $created$05 = 0, $nbToGo$08 = 0, $nbToGo1$04 = 0, $nbToGo3$02 = 0, $removed$09 = 0, $scevgep = 0, $updated$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 49|0;
 $1 = sp + 48|0;
 $aabb = sp;
 $aabb5 = sp + 24|0;
 $2 = (($updateData) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 92|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  $7 = $3 << 2;
  $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$7,483632,3552)|0);
  $9 = HEAP32[$4>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   $15 = 0;
  } else {
   $11 = (($this) + 88|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = $9 << 2;
   _memcpy(($8|0),($12|0),($13|0))|0;
   $$pre = HEAP32[$4>>2]|0;
   $15 = $$pre;
  }
  $14 = ($15>>>0)<($3>>>0);
  if ($14) {
   $16 = $15 << 2;
   $scevgep = (($8) + ($16)|0);
   $17 = (($3) - ($15))|0;
   $18 = $17 << 2;
   _memset(($scevgep|0),-1,($18|0))|0;
  }
  $19 = (($this) + 88|0);
  $20 = HEAP32[$19>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$20);
  HEAP32[$19>>2] = $8;
  HEAP32[$4>>2] = $3;
 }
 $21 = (($updateData) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($updateData) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 120|0);
 HEAP32[$25>>2] = $24;
 $26 = (($updateData) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = (($updateData) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0);
  if (!($31)) {
   $32 = (($this) + 84|0);
   $33 = (($this) + 88|0);
   $$pre13 = HEAP32[$33>>2]|0;
   $39 = $$pre13;$nbToGo$08 = $30;$removed$09 = $27;
   while(1) {
    $34 = (($nbToGo$08) + -1)|0;
    $35 = (($removed$09) + 4|0);
    $36 = HEAP32[$removed$09>>2]|0;
    $37 = HEAP32[$32>>2]|0;
    $38 = (($39) + ($36<<2)|0);
    $40 = HEAP32[$38>>2]|0;
    (__ZN3MBP12removeObjectEj($37,$40)|0);
    $41 = HEAP32[$33>>2]|0;
    $42 = (($41) + ($36<<2)|0);
    HEAP32[$42>>2] = -1;
    $43 = ($34|0)==(0);
    if ($43) {
     break;
    } else {
     $39 = $41;$nbToGo$08 = $34;$removed$09 = $35;
    }
   }
  }
 }
 $44 = HEAP32[$updateData>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = (($updateData) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0);
  if (!($48)) {
   $49 = (($aabb) + 4|0);
   $50 = (($aabb) + 8|0);
   $51 = (($aabb) + 12|0);
   $52 = (($aabb) + 16|0);
   $53 = (($aabb) + 20|0);
   $54 = (($this) + 84|0);
   $55 = (($this) + 88|0);
   $created$05 = $44;$nbToGo1$04 = $47;
   while(1) {
    $56 = (($nbToGo1$04) + -1)|0;
    $57 = (($created$05) + 4|0);
    $58 = HEAP32[$created$05>>2]|0;
    $59 = (($24) + ($58<<2)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==(0);
    $62 = (($22) + (($58*24)|0)|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = $63 >>> 1;
    HEAP32[$aabb>>2] = $64;
    $65 = ((($22) + (($58*24)|0)|0) + 4|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = $66 >>> 1;
    HEAP32[$49>>2] = $67;
    $68 = ((($22) + (($58*24)|0)|0) + 8|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = $69 >>> 1;
    HEAP32[$50>>2] = $70;
    $71 = ((($22) + (($58*24)|0)|0) + 12|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = $72 >>> 1;
    HEAP32[$51>>2] = $73;
    $74 = ((($22) + (($58*24)|0)|0) + 16|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $75 >>> 1;
    HEAP32[$52>>2] = $76;
    $77 = ((($22) + (($58*24)|0)|0) + 20|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = $78 >>> 1;
    HEAP32[$53>>2] = $79;
    $80 = HEAP32[$54>>2]|0;
    $81 = (__ZN3MBP9addObjectERK5IAABBjb($80,$aabb,$58,$61)|0);
    $82 = HEAP32[$55>>2]|0;
    $83 = (($82) + ($58<<2)|0);
    HEAP32[$83>>2] = $81;
    $84 = ($56|0)==(0);
    if ($84) {
     break;
    } else {
     $created$05 = $57;$nbToGo1$04 = $56;
    }
   }
  }
 }
 $85 = (($updateData) + 8|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(0|0);
 if ($87) {
  $124 = (($this) + 84|0);
  $125 = HEAP32[$124>>2]|0;
  __ZN3MBP17prepareOverlapsMTEv($125);
  STACKTOP = sp;return;
 }
 $88 = (($updateData) + 12|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($89|0)==(0);
 if ($90) {
  $124 = (($this) + 84|0);
  $125 = HEAP32[$124>>2]|0;
  __ZN3MBP17prepareOverlapsMTEv($125);
  STACKTOP = sp;return;
 }
 $91 = (($aabb5) + 4|0);
 $92 = (($aabb5) + 8|0);
 $93 = (($aabb5) + 12|0);
 $94 = (($aabb5) + 16|0);
 $95 = (($aabb5) + 20|0);
 $96 = (($this) + 84|0);
 $97 = (($this) + 88|0);
 $nbToGo3$02 = $89;$updated$01 = $86;
 while(1) {
  $98 = (($nbToGo3$02) + -1)|0;
  $99 = HEAP32[$updated$01>>2]|0;
  $100 = (($22) + (($99*24)|0)|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = $101 >>> 1;
  HEAP32[$aabb5>>2] = $102;
  $103 = ((($22) + (($99*24)|0)|0) + 4|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = $104 >>> 1;
  HEAP32[$91>>2] = $105;
  $106 = ((($22) + (($99*24)|0)|0) + 8|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = $107 >>> 1;
  HEAP32[$92>>2] = $108;
  $109 = ((($22) + (($99*24)|0)|0) + 12|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = $110 >>> 1;
  HEAP32[$93>>2] = $111;
  $112 = ((($22) + (($99*24)|0)|0) + 16|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = $113 >>> 1;
  HEAP32[$94>>2] = $114;
  $115 = ((($22) + (($99*24)|0)|0) + 20|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = $116 >>> 1;
  HEAP32[$95>>2] = $117;
  $118 = HEAP32[$96>>2]|0;
  $119 = HEAP32[$97>>2]|0;
  $120 = (($119) + ($99<<2)|0);
  $121 = HEAP32[$120>>2]|0;
  (__ZN3MBP12updateObjectEjRK5IAABB($118,$121,$aabb5)|0);
  $122 = ($98|0)==(0);
  if ($122) {
   break;
  }
  $123 = (($updated$01) + 4|0);
  $nbToGo3$02 = $98;$updated$01 = $123;
 }
 $124 = (($this) + 84|0);
 $125 = HEAP32[$124>>2]|0;
 __ZN3MBP17prepareOverlapsMTEv($125);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsBroadPhaseMBP9updatePPUEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($2) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($2) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($6|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($2) + 52|0);
 $i$01$i = 0;
 while(1) {
  $13 = ((($8) + (($i$01$i*40)|0)|0) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   __ZN9BoxPruner14findOverlapsMTER15MBP_PairManagerPKjPK10MBP_Object($14,$12,$4,$10);
  }
  $16 = (($i$01$i) + 1)|0;
  $exitcond$i = ($16|0)==($6|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $16;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxsBroadPhaseMBP13postUpdatePPUEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==(0);
 if (!($7)) {
  $i$01 = 0;
  while(1) {
   $8 = ((($6) + (($i$01*40)|0)|0) + 28|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($9) + 116|0);
    HEAP32[$11>>2] = 0;
   }
   $12 = (($i$01) + 1)|0;
   $exitcond = ($12|0)==($4|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $12;
   }
  }
 }
 $13 = (($2) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($2) + 52|0);
 $16 = (($2) + 80|0);
 $17 = (($2) + 88|0);
 (__ZN15MBP_PairManager17removeMarkedPairsEPK10MBP_ObjectPN5physx16PxsBroadPhaseMBPERK8BitArrayS8_($15,$14,$this,$16,$17)|0);
 $18 = HEAP32[$16>>2]|0;
 $19 = (($2) + 84|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 << 2;
 _memset(($18|0),0,($21|0))|0;
 STACKTOP = sp;return;
}
function __ZNK5physx16PxsBroadPhaseMBP18getNumCreatedPairsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx16PxsBroadPhaseMBP15getCreatedPairsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx16PxsBroadPhaseMBP18getNumDeletedPairsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx16PxsBroadPhaseMBP15getDeletedPairsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx16PxsBroadPhaseMBP24getNumOutOfBoundsObjectsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 5240|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK5physx16PxsBroadPhaseMBP21getOutOfBoundsObjectsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 5244|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx16PxsBroadPhaseMBP11freeBuffersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$4);
  HEAP32[$3>>2] = 0;
 }
 HEAP32[$3>>2] = 0;
 $6 = (($2) + 92|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 5236|0);
 (__ZN5physx2Gu9Container5EmptyEv($7)|0);
 $8 = (($this) + 96|0);
 $9 = (($this) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)>(1024);
 if ($11) {
  HEAP32[$0>>2] = 1073741823;
  $12 = (($0) + 4|0);
  HEAP32[$12>>2] = 1073741823;
  __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($8,0,$0);
  $13 = HEAP32[$9>>2]|0;
  __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($8,$13);
  $14 = (($this) + 104|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 & 2147482624;
  $17 = ($16>>>0)<(1024);
  if ($17) {
   __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($8,1024);
  }
 } else {
  HEAP32[$9>>2] = 0;
 }
 $18 = (($this) + 108|0);
 $19 = (($this) + 112|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20>>>0)>(1024);
 if (!($21)) {
  HEAP32[$19>>2] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 1073741823;
 $22 = (($0) + 4|0);
 HEAP32[$22>>2] = 1073741823;
 __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($18,0,$0);
 $23 = HEAP32[$19>>2]|0;
 __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($18,$23);
 $24 = (($this) + 116|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147482624;
 $27 = ($26>>>0)<(1024);
 if (!($27)) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($18,1024);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsBroadPhaseMBP11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN3MBP11shiftOriginERKN5physx6PxVec3E($1,$shift);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxsBroadPhaseMBP7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 484032 : 484000;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,483920,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = $$03$i;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = $$012$i;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
   }
   $30 = (($$012$i) + 8|0);
   $31 = (($$03$i) + 8|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 484032 : 484000;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,483920,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_17PxcBroadPhasePairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<3)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<3)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = $a;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = $$01$i;
   $18 = $17;
   HEAP32[$18>>2] = $13;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = $16;
  }
  $21 = (($$01$i) + 8|0);
  $22 = ($21>>>0)<($7>>>0);
  if ($22) {
   $$01$i = $21;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSapC2ERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerE($this,$scratchAllocator,$eventProfiler) {
 $this = $this|0;
 $scratchAllocator = $scratchAllocator|0;
 $eventProfiler = $eventProfiler|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$01 = 0, $i$02 = 0, $phitmp = 0, $phitmp8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 19|0;
 $1 = sp + 18|0;
 $2 = sp + 17|0;
 $3 = sp + 16|0;
 $4 = sp + 15|0;
 $5 = sp + 14|0;
 $6 = sp + 13|0;
 $7 = sp + 12|0;
 $8 = sp + 11|0;
 $9 = sp + 10|0;
 $10 = sp + 9|0;
 $11 = sp + 3|0;
 $12 = sp;
 $13 = sp + 1|0;
 $14 = sp + 2|0;
 $15 = sp + 4|0;
 $16 = sp + 5|0;
 $17 = sp + 6|0;
 $18 = sp + 7|0;
 $19 = sp + 8|0;
 HEAP32[$this>>2] = ((484520 + 8|0));
 $20 = (($this) + 4|0);
 HEAP32[$20>>2] = $scratchAllocator;
 $21 = (($this) + 8|0);
 HEAP32[$21>>2] = $eventProfiler;
 $22 = (($this) + 12|0);
 $23 = (($this) + 16|0);
 HEAP16[$23>>1] = -1;
 $24 = (($this) + 18|0);
 HEAP16[$24>>1] = 0;
 $25 = (($this) + 20|0);
 HEAP32[$25>>2] = 0;
 HEAP32[$22>>2] = ((434896 + 8|0));
 $26 = (($this) + 24|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 28|0);
 HEAP32[$27>>2] = 0;
 HEAP32[$22>>2] = ((501312 + 8|0));
 $28 = (($this) + 44|0);
 $29 = (($this) + 48|0);
 HEAP16[$29>>1] = -1;
 $30 = (($this) + 50|0);
 HEAP16[$30>>1] = 0;
 $31 = (($this) + 52|0);
 HEAP32[$31>>2] = 0;
 HEAP32[$28>>2] = ((434896 + 8|0));
 $32 = (($this) + 56|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 60|0);
 HEAP32[$33>>2] = 0;
 HEAP32[$28>>2] = ((501360 + 8|0));
 $34 = (($this) + 192|0);
 __ZN5physx14SapPairManagerC2Ev($34);
 $35 = (($this) + 256|0);
 ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;
 $36 = (($this) + 260|0);
 HEAP16[$36>>1] = -1;
 $37 = (($this) + 262|0);
 HEAP16[$37>>1] = 0;
 $38 = (($this) + 264|0);
 HEAP32[$38>>2] = 0;
 HEAP32[$35>>2] = ((434896 + 8|0));
 $39 = (($this) + 268|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 272|0);
 HEAP32[$40>>2] = 0;
 HEAP32[$35>>2] = ((484696 + 8|0));
 $41 = (($this) + 276|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 280|0);
 HEAP32[$42>>2] = -1;
 $43 = (($this) + 284|0);
 $44 = (($this) + 296|0);
 $45 = (($this) + 300|0);
 ;HEAP32[$43+0>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;HEAP32[$43+16>>2]=0|0;HEAP32[$43+20>>2]=0|0;HEAP32[$43+24>>2]=0|0;HEAP32[$43+28>>2]=0|0;
 HEAP16[$45>>1] = -1;
 $46 = (($this) + 302|0);
 HEAP16[$46>>1] = 0;
 $47 = (($this) + 304|0);
 HEAP32[$47>>2] = 0;
 HEAP32[$44>>2] = ((434896 + 8|0));
 $48 = (($this) + 308|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 312|0);
 HEAP32[$49>>2] = 0;
 HEAP32[$44>>2] = ((484696 + 8|0));
 $50 = (($this) + 316|0);
 HEAP32[$50>>2] = 0;
 $51 = (($this) + 320|0);
 HEAP32[$51>>2] = -1;
 $52 = (($this) + 324|0);
 $53 = (($this) + 336|0);
 $54 = (($this) + 340|0);
 ;HEAP32[$52+0>>2]=0|0;HEAP32[$52+4>>2]=0|0;HEAP32[$52+8>>2]=0|0;HEAP32[$52+12>>2]=0|0;HEAP32[$52+16>>2]=0|0;HEAP32[$52+20>>2]=0|0;HEAP32[$52+24>>2]=0|0;HEAP32[$52+28>>2]=0|0;
 HEAP16[$54>>1] = -1;
 $55 = (($this) + 342|0);
 HEAP16[$55>>1] = 0;
 $56 = (($this) + 344|0);
 HEAP32[$56>>2] = 0;
 HEAP32[$53>>2] = ((434896 + 8|0));
 $57 = (($this) + 348|0);
 HEAP32[$57>>2] = 0;
 $58 = (($this) + 352|0);
 HEAP32[$58>>2] = 0;
 HEAP32[$53>>2] = ((484696 + 8|0));
 $59 = (($this) + 356|0);
 HEAP32[$59>>2] = 0;
 $60 = (($this) + 360|0);
 HEAP32[$60>>2] = -1;
 $61 = (($this) + 364|0);
 HEAP32[$61>>2] = 0;
 $62 = (($this) + 368|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 372|0);
 HEAP32[$63>>2] = 0;
 $64 = (($this) + 168|0);
 HEAP32[$64>>2] = 0;
 $65 = (($this) + 172|0);
 HEAP32[$65>>2] = 0;
 $66 = (($this) + 108|0);
 HEAP32[$66>>2] = 64;
 $67 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,512,484600,477)|0);
 $68 = (($this) + 112|0);
 HEAP32[$68>>2] = $67;
 $69 = HEAP32[$66>>2]|0;
 $70 = $69 << 3;
 $71 = (($70) + 15)|0;
 $72 = $71 & -16;
 $73 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$72,484600,478)|0);
 $74 = (($this) + 116|0);
 HEAP32[$74>>2] = $73;
 $75 = HEAP32[$66>>2]|0;
 $76 = $75 << 3;
 $77 = (($76) + 15)|0;
 $78 = $77 & -16;
 $79 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$78,484600,479)|0);
 $80 = (($this) + 120|0);
 HEAP32[$80>>2] = $79;
 $81 = HEAP32[$66>>2]|0;
 $82 = ($81|0)==(0);
 if ($82) {
  $95 = 0;
 } else {
  $83 = HEAP32[$68>>2]|0;
  $84 = HEAP32[$74>>2]|0;
  $i$02 = 0;
  while(1) {
   $85 = (($83) + ($i$02<<3)|0);
   HEAP32[$85>>2] = 1073741823;
   $86 = ((($83) + ($i$02<<3)|0) + 4|0);
   HEAP32[$86>>2] = 1073741823;
   $87 = (($84) + ($i$02<<3)|0);
   HEAP32[$87>>2] = 1073741823;
   $88 = ((($84) + ($i$02<<3)|0) + 4|0);
   HEAP32[$88>>2] = 1073741823;
   $89 = (($79) + ($i$02<<3)|0);
   HEAP32[$89>>2] = 1073741823;
   $90 = ((($79) + ($i$02<<3)|0) + 4|0);
   HEAP32[$90>>2] = 1073741823;
   $91 = (($i$02) + 1)|0;
   $92 = HEAP32[$66>>2]|0;
   $93 = ($91>>>0)<($92>>>0);
   if ($93) {
    $i$02 = $91;
   } else {
    break;
   }
  }
  $phitmp = (($92) + 15)|0;
  $phitmp8 = $phitmp & -16;
  $95 = $phitmp8;
 }
 $94 = (($this) + 176|0);
 HEAP32[$94>>2] = 130;
 $96 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$95,484600,493)|0);
 $97 = (($this) + 148|0);
 HEAP32[$97>>2] = $96;
 $98 = HEAP32[$94>>2]|0;
 $99 = $98 << 2;
 $100 = (($99) + 15)|0;
 $101 = $100 & -16;
 $102 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$101,484600,494)|0);
 $103 = (($this) + 152|0);
 HEAP32[$103>>2] = $102;
 $104 = HEAP32[$94>>2]|0;
 $105 = $104 << 3;
 $106 = (($105) + 15)|0;
 $107 = $106 & -16;
 $108 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,$107,484600,495)|0);
 $109 = (($this) + 156|0);
 HEAP32[$109>>2] = $108;
 $110 = HEAP32[$94>>2]|0;
 $111 = $110 << 2;
 $112 = (($111) + 15)|0;
 $113 = $112 & -16;
 $114 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($6,$113,484600,500)|0);
 $115 = (($this) + 124|0);
 HEAP32[$115>>2] = $114;
 $116 = HEAP32[$94>>2]|0;
 $117 = $116 << 2;
 $118 = (($117) + 15)|0;
 $119 = $118 & -16;
 $120 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($7,$119,484600,501)|0);
 $121 = (($this) + 128|0);
 HEAP32[$121>>2] = $120;
 $122 = HEAP32[$94>>2]|0;
 $123 = $122 << 2;
 $124 = (($123) + 15)|0;
 $125 = $124 & -16;
 $126 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($8,$125,484600,502)|0);
 $127 = (($this) + 132|0);
 HEAP32[$127>>2] = $126;
 $128 = HEAP32[$94>>2]|0;
 $129 = $128 << 2;
 $130 = (($129) + 15)|0;
 $131 = $130 & -16;
 $132 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($9,$131,484600,503)|0);
 $133 = (($this) + 136|0);
 HEAP32[$133>>2] = $132;
 $134 = HEAP32[$94>>2]|0;
 $135 = $134 << 2;
 $136 = (($135) + 15)|0;
 $137 = $136 & -16;
 $138 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($10,$137,484600,504)|0);
 $139 = (($this) + 140|0);
 HEAP32[$139>>2] = $138;
 $140 = HEAP32[$94>>2]|0;
 $141 = $140 << 2;
 $142 = (($141) + 15)|0;
 $143 = $142 & -16;
 $144 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($11,$143,484600,505)|0);
 $145 = (($this) + 144|0);
 HEAP32[$145>>2] = $144;
 $146 = HEAP32[$115>>2]|0;
 $147 = HEAP32[$133>>2]|0;
 HEAP32[$146>>2] = 0;
 HEAP32[$147>>2] = 1073741822;
 $148 = (($146) + 4|0);
 $149 = (($147) + 4|0);
 HEAP32[$148>>2] = -1;
 HEAP32[$149>>2] = 1073741823;
 $150 = HEAP32[$121>>2]|0;
 $151 = HEAP32[$139>>2]|0;
 HEAP32[$150>>2] = 0;
 HEAP32[$151>>2] = 1073741822;
 $152 = (($150) + 4|0);
 $153 = (($151) + 4|0);
 HEAP32[$152>>2] = -1;
 HEAP32[$153>>2] = 1073741823;
 $154 = HEAP32[$127>>2]|0;
 HEAP32[$154>>2] = 0;
 HEAP32[$144>>2] = 1073741822;
 $155 = (($154) + 4|0);
 $156 = (($144) + 4|0);
 HEAP32[$155>>2] = -1;
 HEAP32[$156>>2] = 1073741823;
 $157 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($12,4096,484600,516)|0);
 $158 = (($this) + 180|0);
 HEAP32[$158>>2] = $157;
 $159 = (($this) + 184|0);
 HEAP32[$159>>2] = 0;
 $160 = (($this) + 188|0);
 HEAP32[$160>>2] = 1024;
 $161 = (($this) + 236|0);
 HEAP32[$161>>2] = 0;
 $162 = (($this) + 248|0);
 HEAP32[$162>>2] = 0;
 $163 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($13,512,484600,523)|0);
 $164 = (($this) + 232|0);
 HEAP32[$164>>2] = $163;
 $165 = (($this) + 240|0);
 HEAP32[$165>>2] = 64;
 $166 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($14,512,484600,525)|0);
 $167 = (($this) + 244|0);
 HEAP32[$167>>2] = $166;
 $168 = (($this) + 252|0);
 HEAP32[$168>>2] = 64;
 $169 = HEAP32[$94>>2]|0;
 $170 = $169 << 2;
 $171 = (($170) + 15)|0;
 $172 = $171 & -16;
 $173 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($15,$172,484600,528)|0);
 $174 = (($this) + 160|0);
 HEAP32[$174>>2] = $173;
 $175 = HEAP32[$94>>2]|0;
 $176 = $175 << 2;
 $177 = (($176) + 15)|0;
 $178 = $177 & -16;
 $179 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($16,$178,484600,529)|0);
 $180 = (($this) + 164|0);
 HEAP32[$180>>2] = $179;
 $181 = HEAP32[$94>>2]|0;
 $182 = ($181>>>0)>(1);
 $183 = HEAP32[$174>>2]|0;
 if ($182) {
  $a$01 = 1;
 } else {
  $$lcssa = $181;
  $190 = (($$lcssa) + -1)|0;
  $191 = (($183) + ($190<<2)|0);
  HEAP32[$191>>2] = $190;
  HEAP32[$179>>2] = 0;
  __ZN5physx14SapPairManager4initEj($34,64);
  $192 = (($this) + 356|0);
  HEAP32[$192>>2] = $this;
  $193 = (($this) + 360|0);
  HEAP32[$193>>2] = 2;
  $194 = (($this) + 316|0);
  HEAP32[$194>>2] = $this;
  $195 = (($this) + 320|0);
  HEAP32[$195>>2] = 1;
  $196 = (($this) + 276|0);
  HEAP32[$196>>2] = $this;
  $197 = (($this) + 280|0);
  HEAP32[$197>>2] = 0;
  $198 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($17,65536,484600,548)|0);
  $199 = (($this) + 364|0);
  HEAP32[$199>>2] = $198;
  $200 = (($this) + 372|0);
  HEAP32[$200>>2] = 8192;
  $201 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($18,65536,484600,549)|0);
  $202 = (($this) + 324|0);
  HEAP32[$202>>2] = $201;
  $203 = (($this) + 332|0);
  HEAP32[$203>>2] = 8192;
  $204 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($19,65536,484600,550)|0);
  $205 = (($this) + 284|0);
  HEAP32[$205>>2] = $204;
  $206 = (($this) + 292|0);
  HEAP32[$206>>2] = 8192;
  STACKTOP = sp;return;
 }
 while(1) {
  $184 = (($a$01) + -1)|0;
  $185 = (($183) + ($184<<2)|0);
  HEAP32[$185>>2] = $a$01;
  $186 = (($179) + ($a$01<<2)|0);
  HEAP32[$186>>2] = $184;
  $187 = (($a$01) + 1)|0;
  $188 = HEAP32[$94>>2]|0;
  $189 = ($187>>>0)<($188>>>0);
  if ($189) {
   $a$01 = $187;
  } else {
   $$lcssa = $188;
   break;
  }
 }
 $190 = (($$lcssa) + -1)|0;
 $191 = (($183) + ($190<<2)|0);
 HEAP32[$191>>2] = $190;
 HEAP32[$179>>2] = 0;
 __ZN5physx14SapPairManager4initEj($34,64);
 $192 = (($this) + 356|0);
 HEAP32[$192>>2] = $this;
 $193 = (($this) + 360|0);
 HEAP32[$193>>2] = 2;
 $194 = (($this) + 316|0);
 HEAP32[$194>>2] = $this;
 $195 = (($this) + 320|0);
 HEAP32[$195>>2] = 1;
 $196 = (($this) + 276|0);
 HEAP32[$196>>2] = $this;
 $197 = (($this) + 280|0);
 HEAP32[$197>>2] = 0;
 $198 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($17,65536,484600,548)|0);
 $199 = (($this) + 364|0);
 HEAP32[$199>>2] = $198;
 $200 = (($this) + 372|0);
 HEAP32[$200>>2] = 8192;
 $201 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($18,65536,484600,549)|0);
 $202 = (($this) + 324|0);
 HEAP32[$202>>2] = $201;
 $203 = (($this) + 332|0);
 HEAP32[$203>>2] = 8192;
 $204 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($19,65536,484600,550)|0);
 $205 = (($this) + 284|0);
 HEAP32[$205>>2] = $204;
 $206 = (($this) + 292|0);
 HEAP32[$206>>2] = 8192;
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSapD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx23PxsBroadPhaseContextSapD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSapD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 19|0;
 $1 = sp + 18|0;
 $2 = sp + 17|0;
 $3 = sp + 16|0;
 $4 = sp + 15|0;
 $5 = sp + 14|0;
 $6 = sp + 13|0;
 $7 = sp + 12|0;
 $8 = sp + 11|0;
 $9 = sp + 10|0;
 $10 = sp + 9|0;
 $11 = sp + 3|0;
 $12 = sp;
 $13 = sp + 1|0;
 $14 = sp + 2|0;
 $15 = sp + 4|0;
 $16 = sp + 5|0;
 $17 = sp + 6|0;
 $18 = sp + 7|0;
 $19 = sp + 8|0;
 HEAP32[$this>>2] = ((484520 + 8|0));
 $20 = (($this) + 112|0);
 $21 = HEAP32[$20>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$21);
 $22 = (($this) + 116|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$23);
 $24 = (($this) + 120|0);
 $25 = HEAP32[$24>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$25);
 $26 = (($this) + 124|0);
 $27 = HEAP32[$26>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$27);
 $28 = (($this) + 128|0);
 $29 = HEAP32[$28>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$29);
 $30 = (($this) + 132|0);
 $31 = HEAP32[$30>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$31);
 $32 = (($this) + 136|0);
 $33 = HEAP32[$32>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$33);
 $34 = (($this) + 140|0);
 $35 = HEAP32[$34>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$35);
 $36 = (($this) + 144|0);
 $37 = HEAP32[$36>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($8,$37);
 $38 = (($this) + 180|0);
 $39 = HEAP32[$38>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($9,$39);
 $40 = (($this) + 232|0);
 $41 = HEAP32[$40>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($10,$41);
 $42 = (($this) + 244|0);
 $43 = HEAP32[$42>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($11,$43);
 $44 = (($this) + 192|0);
 __ZN5physx14SapPairManager7releaseEv($44);
 $45 = (($this) + 284|0);
 $46 = HEAP32[$45>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($12,$46);
 $47 = (($this) + 324|0);
 $48 = HEAP32[$47>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($13,$48);
 $49 = (($this) + 364|0);
 $50 = HEAP32[$49>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($14,$50);
 $51 = (($this) + 160|0);
 $52 = HEAP32[$51>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($15,$52);
 $53 = (($this) + 164|0);
 $54 = HEAP32[$53>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($16,$54);
 $55 = (($this) + 152|0);
 $56 = HEAP32[$55>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($17,$56);
 $57 = (($this) + 156|0);
 $58 = HEAP32[$57>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($18,$58);
 $59 = (($this) + 148|0);
 $60 = HEAP32[$59>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($19,$60);
 $61 = (($this) + 336|0);
 HEAP32[$61>>2] = ((434896 + 8|0));
 $62 = (($this) + 344|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 296|0);
 HEAP32[$63>>2] = ((434896 + 8|0));
 $64 = (($this) + 304|0);
 HEAP32[$64>>2] = 0;
 $65 = (($this) + 256|0);
 HEAP32[$65>>2] = ((434896 + 8|0));
 $66 = (($this) + 264|0);
 HEAP32[$66>>2] = 0;
 $67 = (($this) + 44|0);
 HEAP32[$67>>2] = ((434896 + 8|0));
 $68 = (($this) + 52|0);
 HEAP32[$68>>2] = 0;
 $69 = (($this) + 12|0);
 HEAP32[$69>>2] = ((434896 + 8|0));
 $70 = (($this) + 20|0);
 HEAP32[$70>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx29BroadPhaseBatchUpdateWorkTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx21SapPostUpdateWorkTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx17SapUpdateWorkTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap6createERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerE($scratchAllocator,$eventProfiler) {
 $scratchAllocator = $scratchAllocator|0;
 $eventProfiler = $eventProfiler|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,376,484600,607)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return ($1|0);
 }
 __ZN5physx23PxsBroadPhaseContextSapC2ERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerE($1,$scratchAllocator,$eventProfiler);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx23PxsBroadPhaseContextSap11freeBuffersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = sp + 4|0;
 $6 = (($this) + 236|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 248|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 232|0);
 $9 = (($this) + 240|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(64);
 if (!($11)) {
  $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,512,484600,620)|0);
  $13 = HEAP32[$8>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$13);
  }
  HEAP32[$8>>2] = $12;
  HEAP32[$9>>2] = 64;
 }
 $15 = (($this) + 244|0);
 $16 = (($this) + 252|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(64);
 if (!($18)) {
  $19 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,512,484600,620)|0);
  $20 = HEAP32[$15>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$20);
  }
  HEAP32[$15>>2] = $19;
  HEAP32[$16>>2] = 64;
 }
 $22 = (($this) + 184|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 188|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)>(1024);
 if ($25) {
  $26 = (($this) + 180|0);
  $27 = HEAP32[$26>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$27);
  $28 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,4096,484600,640)|0);
  HEAP32[$26>>2] = $28;
  HEAP32[$23>>2] = 1024;
 }
 $29 = (($this) + 292|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30>>>0)>(8192);
 if ($31) {
  $32 = (($this) + 284|0);
  $33 = HEAP32[$32>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$33);
  $34 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,65536,484600,650)|0);
  HEAP32[$32>>2] = $34;
  HEAP32[$29>>2] = 8192;
 }
 $35 = (($this) + 288|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 332|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37>>>0)>(8192);
 if ($38) {
  $39 = (($this) + 324|0);
  $40 = HEAP32[$39>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$40);
  $41 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,65536,484600,650)|0);
  HEAP32[$39>>2] = $41;
  HEAP32[$36>>2] = 8192;
 }
 $42 = (($this) + 328|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 372|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44>>>0)>(8192);
 if (!($45)) {
  $49 = (($this) + 368|0);
  HEAP32[$49>>2] = 0;
  $50 = (($this) + 192|0);
  __ZN5physx14SapPairManager12shrinkMemoryEv($50);
  STACKTOP = sp;return;
 }
 $46 = (($this) + 364|0);
 $47 = HEAP32[$46>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$47);
 $48 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,65536,484600,650)|0);
 HEAP32[$46>>2] = $48;
 HEAP32[$43>>2] = 8192;
 $49 = (($this) + 368|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 192|0);
 __ZN5physx14SapPairManager12shrinkMemoryEv($50);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i14 = 0, $$0$i$i11 = 0, $$0$i$i2$i = 0, $$0$i$i2$i13 = 0, $$0$i$i4$i = 0, $$0$i$i4$i12 = 0, $$0$i6$i = 0, $$0$i6$i10 = 0, $$0$i7$i = 0, $$0$i7$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$016 = 0, $prevIsMax0$021 = 0, $prevIsMax1$019 = 0, $prevIsMax2$017 = 0, $prevVal0$022 = 0, $prevVal1$020 = 0, $prevVal2$018 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = Math_fround(HEAPF32[$shift>>2]);
 $4 = (($shift) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($shift) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 136|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 140|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 128|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 144|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 132|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($11) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($9) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($15) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($13) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($19) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($17) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($21|0)<(0);
 $33 = $21 & 2147483647;
 $34 = $21 ^ -1;
 $$0$i7$i = $32 ? $33 : $34;
 $35 = ($25|0)<(0);
 $36 = $25 & 2147483647;
 $37 = $25 ^ -1;
 $$0$i6$i = $35 ? $36 : $37;
 $38 = ($29|0)<(0);
 $39 = $29 & 2147483647;
 $40 = $29 ^ -1;
 $$0$i$i = $38 ? $39 : $40;
 $41 = (HEAP32[tempDoublePtr>>2]=$$0$i7$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $42 = Math_fround($41 - $3);
 $43 = (HEAPF32[tempDoublePtr>>2]=$42,HEAP32[tempDoublePtr>>2]|0);
 $44 = (HEAP32[tempDoublePtr>>2]=$$0$i6$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $45 = Math_fround($44 - $5);
 $46 = (HEAPF32[tempDoublePtr>>2]=$45,HEAP32[tempDoublePtr>>2]|0);
 $47 = (HEAP32[tempDoublePtr>>2]=$$0$i$i,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $48 = Math_fround($47 - $7);
 $49 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
 $50 = $23 & 1;
 $51 = ($50|0)==(0);
 $52 = ($43|0)<(0);
 $53 = $43 ^ -1;
 $54 = $43 | -2147483648;
 $$0$i$i4$i = $52 ? $53 : $54;
 if ($51) {
  $58 = (($$0$i$i4$i) + -16)|0;
  $59 = $58 & -16;
  $60 = $59;
 } else {
  $55 = (($$0$i$i4$i) + 16)|0;
  $56 = $55 & -16;
  $57 = $56 | 1;
  $60 = $57;
 }
 HEAP32[$20>>2] = $60;
 $61 = $27 & 1;
 $62 = ($61|0)==(0);
 $63 = ($46|0)<(0);
 $64 = $46 ^ -1;
 $65 = $46 | -2147483648;
 $$0$i$i2$i = $63 ? $64 : $65;
 if ($62) {
  $69 = (($$0$i$i2$i) + -16)|0;
  $70 = $69 & -16;
  $71 = $70;
 } else {
  $66 = (($$0$i$i2$i) + 16)|0;
  $67 = $66 & -16;
  $68 = $67 | 1;
  $71 = $68;
 }
 HEAP32[$24>>2] = $71;
 $72 = $31 & 1;
 $73 = ($72|0)==(0);
 $74 = ($49|0)<(0);
 $75 = $49 ^ -1;
 $76 = $49 | -2147483648;
 $$0$i$i$i = $74 ? $75 : $76;
 if ($73) {
  $80 = (($$0$i$i$i) + -16)|0;
  $81 = $80 & -16;
  $82 = $81;
 } else {
  $77 = (($$0$i$i$i) + 16)|0;
  $78 = $77 & -16;
  $79 = $78 | 1;
  $82 = $79;
 }
 HEAP32[$28>>2] = $82;
 $83 = HEAP32[$0>>2]|0;
 $84 = $83 << 1;
 $85 = ($84>>>0)<(2);
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = HEAP32[$30>>2]|0;
 $87 = HEAP32[$26>>2]|0;
 $88 = HEAP32[$22>>2]|0;
 $89 = $86 & 1;
 $90 = $87 & 1;
 $91 = HEAP32[$24>>2]|0;
 $92 = $88 & 1;
 $93 = HEAP32[$20>>2]|0;
 $i$016 = 2;$prevIsMax0$021 = $92;$prevIsMax1$019 = $90;$prevIsMax2$017 = $89;$prevVal0$022 = $93;$prevVal1$020 = $91;$prevVal2$018 = $82;
 while(1) {
  $94 = (($9) + ($i$016<<2)|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($13) + ($i$016<<2)|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($17) + ($i$016<<2)|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = $95 & 1;
  $101 = $97 & 1;
  $102 = $99 & 1;
  $103 = (($11) + ($i$016<<2)|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($15) + ($i$016<<2)|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($19) + ($i$016<<2)|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = ($104|0)<(0);
  $110 = $104 & 2147483647;
  $111 = $104 ^ -1;
  $$0$i7$i9 = $109 ? $110 : $111;
  $112 = ($106|0)<(0);
  $113 = $106 & 2147483647;
  $114 = $106 ^ -1;
  $$0$i6$i10 = $112 ? $113 : $114;
  $115 = ($108|0)<(0);
  $116 = $108 & 2147483647;
  $117 = $108 ^ -1;
  $$0$i$i11 = $115 ? $116 : $117;
  $118 = (HEAP32[tempDoublePtr>>2]=$$0$i7$i9,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $119 = Math_fround($118 - $3);
  $120 = (HEAPF32[tempDoublePtr>>2]=$119,HEAP32[tempDoublePtr>>2]|0);
  $121 = (HEAP32[tempDoublePtr>>2]=$$0$i6$i10,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $122 = Math_fround($121 - $5);
  $123 = (HEAPF32[tempDoublePtr>>2]=$122,HEAP32[tempDoublePtr>>2]|0);
  $124 = (HEAP32[tempDoublePtr>>2]=$$0$i$i11,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $125 = Math_fround($124 - $7);
  $126 = (HEAPF32[tempDoublePtr>>2]=$125,HEAP32[tempDoublePtr>>2]|0);
  $127 = ($100|0)==(0);
  $128 = ($120|0)<(0);
  $129 = $120 ^ -1;
  $130 = $120 | -2147483648;
  $$0$i$i4$i12 = $128 ? $129 : $130;
  if ($127) {
   $134 = (($$0$i$i4$i12) + -16)|0;
   $135 = $134 & -16;
   $155 = $135;
  } else {
   $131 = (($$0$i$i4$i12) + 16)|0;
   $132 = $131 & -16;
   $133 = $132 | 1;
   $155 = $133;
  }
  $136 = ($101|0)==(0);
  $137 = ($123|0)<(0);
  $138 = $123 ^ -1;
  $139 = $123 | -2147483648;
  $$0$i$i2$i13 = $137 ? $138 : $139;
  if ($136) {
   $143 = (($$0$i$i2$i13) + -16)|0;
   $144 = $143 & -16;
   $159 = $144;
  } else {
   $140 = (($$0$i$i2$i13) + 16)|0;
   $141 = $140 & -16;
   $142 = $141 | 1;
   $159 = $142;
  }
  $145 = ($102|0)==(0);
  $146 = ($126|0)<(0);
  $147 = $126 ^ -1;
  $148 = $126 | -2147483648;
  $$0$i$i$i14 = $146 ? $147 : $148;
  if ($145) {
   $152 = (($$0$i$i$i14) + -16)|0;
   $153 = $152 & -16;
   $163 = $153;
  } else {
   $149 = (($$0$i$i$i14) + 16)|0;
   $150 = $149 & -16;
   $151 = $150 | 1;
   $163 = $151;
  }
  $154 = ($155>>>0)<($prevVal0$022>>>0);
  if ($154) {
   $156 = $100 ^ $prevIsMax0$021;
   $157 = (($156) + ($prevVal0$022))|0;
   $166 = $157;
  } else {
   $166 = $155;
  }
  $158 = ($159>>>0)<($prevVal1$020>>>0);
  if ($158) {
   $160 = $101 ^ $prevIsMax1$019;
   $161 = (($160) + ($prevVal1$020))|0;
   $167 = $161;
  } else {
   $167 = $159;
  }
  $162 = ($163>>>0)<($prevVal2$018>>>0);
  if ($162) {
   $164 = $102 ^ $prevIsMax2$017;
   $165 = (($164) + ($prevVal2$018))|0;
   $168 = $165;
  } else {
   $168 = $163;
  }
  HEAP32[$103>>2] = $166;
  HEAP32[$105>>2] = $167;
  HEAP32[$107>>2] = $168;
  $169 = (($i$016) + 1)|0;
  $170 = HEAP32[$0>>2]|0;
  $171 = $170 << 1;
  $172 = ($169>>>0)>($171>>>0);
  if ($172) {
   break;
  } else {
   $i$016 = $169;$prevIsMax0$021 = $100;$prevIsMax1$019 = $101;$prevIsMax2$017 = $102;$prevVal0$022 = $166;$prevVal1$020 = $167;$prevVal2$018 = $168;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap6updateEjjRKNS_23PxcBroadPhaseUpdateDataEPNS_10PxBaseTaskE($this,$numCpuTasks,$numSpus,$updateData,$continuation) {
 $this = $this|0;
 $numCpuTasks = $numCpuTasks|0;
 $numSpus = $numSpus|0;
 $updateData = $updateData|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx23PxsBroadPhaseContextSap13setUpdateDataERKNS_23PxcBroadPhaseUpdateDataE($this,$updateData)|0);
 $0 = (($this) + 44|0);
 $1 = (($this) + 64|0);
 HEAP32[$1>>2] = $this;
 $2 = (($this) + 12|0);
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = $this;
 $4 = (($this) + 68|0);
 HEAP32[$4>>2] = $numCpuTasks;
 $5 = (($this) + 72|0);
 HEAP32[$5>>2] = $numSpus;
 $6 = (($this) + 36|0);
 HEAP32[$6>>2] = $numCpuTasks;
 $7 = (($this) + 40|0);
 HEAP32[$7>>2] = $numSpus;
 $8 = (($this) + 60|0);
 HEAP32[$8>>2] = 1;
 $9 = (($this) + 56|0);
 HEAP32[$9>>2] = $continuation;
 $10 = ($continuation|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$continuation>>2]|0;
  $12 = (($11) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($continuation);
  $14 = HEAP32[$9>>2]|0;
  $15 = (($14) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($this) + 52|0);
  HEAP32[$17>>2] = $16;
 }
 $18 = (($this) + 28|0);
 HEAP32[$18>>2] = 1;
 $19 = (($this) + 24|0);
 HEAP32[$19>>2] = $0;
 $20 = HEAP32[$0>>2]|0;
 $21 = (($20) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($0);
 $23 = HEAP32[$19>>2]|0;
 $24 = (($23) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 20|0);
 HEAP32[$26>>2] = $25;
 $27 = HEAP32[$0>>2]|0;
 $28 = (($27) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vi[$29 & 4095]($0);
 $30 = HEAP32[$2>>2]|0;
 $31 = (($30) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vi[$32 & 4095]($2);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap13setUpdateDataERKNS_23PxcBroadPhaseUpdateDataE($this,$updateData) {
 $this = $this|0;
 $updateData = $updateData|0;
 var $$pre = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$02 = 0, $a1$01 = 0, $exitcond = 0;
 var $i$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 27|0;
 $1 = sp + 26|0;
 $2 = sp + 25|0;
 $3 = sp + 24|0;
 $4 = sp + 23|0;
 $5 = sp + 22|0;
 $6 = sp + 21|0;
 $7 = sp + 20|0;
 $8 = sp + 19|0;
 $9 = sp + 18|0;
 $10 = sp + 17|0;
 $11 = sp + 16|0;
 $12 = sp + 15|0;
 $13 = sp + 14|0;
 $14 = sp + 13|0;
 $15 = sp + 5|0;
 $16 = sp;
 $17 = sp + 1|0;
 $18 = sp + 2|0;
 $19 = sp + 3|0;
 $20 = sp + 4|0;
 $21 = sp + 6|0;
 $22 = sp + 7|0;
 $23 = sp + 8|0;
 $24 = sp + 9|0;
 $25 = sp + 10|0;
 $26 = sp + 11|0;
 $27 = sp + 12|0;
 $28 = HEAP32[$updateData>>2]|0;
 $29 = (($this) + 76|0);
 HEAP32[$29>>2] = $28;
 $30 = (($updateData) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 80|0);
 HEAP32[$32>>2] = $31;
 $33 = (($updateData) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 92|0);
 HEAP32[$35>>2] = $34;
 $36 = (($updateData) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + 96|0);
 HEAP32[$38>>2] = $37;
 $39 = (($updateData) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 84|0);
 HEAP32[$41>>2] = $40;
 $42 = (($updateData) + 20|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 88|0);
 HEAP32[$44>>2] = $43;
 $45 = (($updateData) + 24|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 100|0);
 HEAP32[$47>>2] = $46;
 $48 = (($updateData) + 28|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 104|0);
 HEAP32[$50>>2] = $49;
 $51 = (($updateData) + 32|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 108|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($52>>>0)>($54>>>0);
 if ($55) {
  $56 = $52 << 3;
  $57 = (($56) + 15)|0;
  $58 = $57 & -16;
  $59 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$58,484600,949)|0);
  $60 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$58,484600,950)|0);
  $61 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$58,484600,951)|0);
  $62 = (($this) + 112|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = $54 << 3;
  _memcpy(($59|0),($63|0),($64|0))|0;
  $65 = (($this) + 116|0);
  $66 = HEAP32[$65>>2]|0;
  _memcpy(($60|0),($66|0),($64|0))|0;
  $67 = (($this) + 120|0);
  $68 = HEAP32[$67>>2]|0;
  _memcpy(($61|0),($68|0),($64|0))|0;
  $i$06 = $54;
  while(1) {
   $69 = (($59) + ($i$06<<3)|0);
   HEAP32[$69>>2] = 1073741823;
   $70 = ((($59) + ($i$06<<3)|0) + 4|0);
   HEAP32[$70>>2] = 1073741823;
   $71 = (($60) + ($i$06<<3)|0);
   HEAP32[$71>>2] = 1073741823;
   $72 = ((($60) + ($i$06<<3)|0) + 4|0);
   HEAP32[$72>>2] = 1073741823;
   $73 = (($61) + ($i$06<<3)|0);
   HEAP32[$73>>2] = 1073741823;
   $74 = ((($61) + ($i$06<<3)|0) + 4|0);
   HEAP32[$74>>2] = 1073741823;
   $75 = (($i$06) + 1)|0;
   $exitcond = ($75|0)==($52|0);
   if ($exitcond) {
    break;
   } else {
    $i$06 = $75;
   }
  }
  $76 = HEAP32[$62>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$76);
  $77 = HEAP32[$65>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$77);
  $78 = HEAP32[$67>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$78);
  HEAP32[$62>>2] = $59;
  HEAP32[$65>>2] = $60;
  HEAP32[$67>>2] = $61;
  HEAP32[$53>>2] = $52;
  $79 = (($this) + 148|0);
  $80 = HEAP32[$79>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$80);
  $81 = (($52) + 15)|0;
  $82 = $81 & -16;
  $83 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($7,$82,484600,977)|0);
  HEAP32[$79>>2] = $83;
  $$pre = HEAP32[$32>>2]|0;
  $87 = $$pre;
 } else {
  $87 = $31;
 }
 $84 = (($this) + 168|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($87) + ($85))|0;
 $88 = $86 << 1;
 $89 = (($88) + 2)|0;
 $90 = (($this) + 176|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($89>>>0)>($91>>>0);
 if ($92) {
  $93 = $89 << 2;
  $94 = (($93) + 15)|0;
  $95 = $94 & -16;
  $96 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($8,$95,484600,986)|0);
  $97 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($9,$95,484600,987)|0);
  $98 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($10,$95,484600,988)|0);
  $99 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($11,$95,484600,989)|0);
  $100 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($12,$95,484600,990)|0);
  $101 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($13,$95,484600,991)|0);
  $102 = (($this) + 160|0);
  $103 = HEAP32[$102>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($14,$103);
  $104 = (($this) + 164|0);
  $105 = HEAP32[$104>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($15,$105);
  $106 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($16,$95,484600,997)|0);
  HEAP32[$102>>2] = $106;
  $107 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($17,$95,484600,998)|0);
  HEAP32[$104>>2] = $107;
  $108 = ($88|0)==(-2);
  $$pre12 = HEAP32[$102>>2]|0;
  if (!($108)) {
   $a$02 = 1;
   while(1) {
    $109 = (($a$02) + -1)|0;
    $110 = (($$pre12) + ($109<<2)|0);
    HEAP32[$110>>2] = $a$02;
    $111 = (($107) + ($a$02<<2)|0);
    HEAP32[$111>>2] = $109;
    $112 = (($a$02) + 1)|0;
    $113 = ($112>>>0)<($89>>>0);
    if ($113) {
     $a$02 = $112;
    } else {
     break;
    }
   }
  }
  $114 = $88 | 1;
  $115 = (($$pre12) + ($114<<2)|0);
  HEAP32[$115>>2] = $114;
  HEAP32[$107>>2] = 0;
  $116 = (($this) + 124|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = HEAP32[$84>>2]|0;
  $119 = $118 << 3;
  $120 = (($119) + 8)|0;
  _memcpy(($96|0),($117|0),($120|0))|0;
  $121 = (($this) + 128|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = HEAP32[$84>>2]|0;
  $124 = $123 << 3;
  $125 = (($124) + 8)|0;
  _memcpy(($97|0),($122|0),($125|0))|0;
  $126 = (($this) + 132|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = HEAP32[$84>>2]|0;
  $129 = $128 << 3;
  $130 = (($129) + 8)|0;
  _memcpy(($98|0),($127|0),($130|0))|0;
  $131 = (($this) + 136|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = HEAP32[$84>>2]|0;
  $134 = $133 << 3;
  $135 = (($134) + 8)|0;
  _memcpy(($99|0),($132|0),($135|0))|0;
  $136 = (($this) + 140|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = HEAP32[$84>>2]|0;
  $139 = $138 << 3;
  $140 = (($139) + 8)|0;
  _memcpy(($100|0),($137|0),($140|0))|0;
  $141 = (($this) + 144|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = HEAP32[$84>>2]|0;
  $144 = $143 << 3;
  $145 = (($144) + 8)|0;
  _memcpy(($101|0),($142|0),($145|0))|0;
  $146 = HEAP32[$116>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($18,$146);
  $147 = HEAP32[$121>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($19,$147);
  $148 = HEAP32[$126>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($20,$148);
  $149 = HEAP32[$131>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($21,$149);
  $150 = HEAP32[$136>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($22,$150);
  $151 = HEAP32[$141>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($23,$151);
  HEAP32[$116>>2] = $96;
  HEAP32[$121>>2] = $97;
  HEAP32[$126>>2] = $98;
  HEAP32[$131>>2] = $99;
  HEAP32[$136>>2] = $100;
  HEAP32[$141>>2] = $101;
  HEAP32[$90>>2] = $89;
  $152 = (($this) + 152|0);
  $153 = HEAP32[$152>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($24,$153);
  $154 = (($this) + 156|0);
  $155 = HEAP32[$154>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($25,$155);
  $156 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($26,$95,484600,1033)|0);
  HEAP32[$152>>2] = $156;
  $157 = $89 << 3;
  $158 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($27,$157,484600,1034)|0);
  HEAP32[$154>>2] = $158;
 }
 $159 = (($this) + 148|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = HEAP32[$53>>2]|0;
 _memset(($160|0),0,($161|0))|0;
 $162 = HEAP32[$38>>2]|0;
 $163 = ($162|0)==(0);
 if ($163) {
  $172 = HEAP32[$32>>2]|0;
  $173 = HEAP32[$84>>2]|0;
  $174 = (($173) + ($172))|0;
  HEAP32[$84>>2] = $174;
  STACKTOP = sp;return 1;
 } else {
  $a1$01 = 0;
 }
 while(1) {
  $164 = HEAP32[$35>>2]|0;
  $165 = (($164) + ($a1$01<<2)|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = HEAP32[$159>>2]|0;
  $168 = (($167) + ($166)|0);
  HEAP8[$168>>0] = 1;
  $169 = (($a1$01) + 1)|0;
  $170 = HEAP32[$38>>2]|0;
  $171 = ($169>>>0)<($170>>>0);
  if ($171) {
   $a1$01 = $169;
  } else {
   break;
  }
 }
 $172 = HEAP32[$32>>2]|0;
 $173 = HEAP32[$84>>2]|0;
 $174 = (($173) + ($172))|0;
 HEAP32[$84>>2] = $174;
 STACKTOP = sp;return 1;
}
function __ZN5physx23PxsBroadPhaseContextSap13postUpdatePPUEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond$1 = 0, $exitcond$2 = 0, $j$01 = 0, $j$01$1 = 0, $j$01$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 192|0);
 $2 = (($this) + 180|0);
 $3 = (($this) + 184|0);
 $4 = (($this) + 188|0);
 $5 = (($this) + 288|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 284|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==(0);
 if (!($9)) {
  $j$01 = 0;
  while(1) {
   $10 = (($8) + ($j$01<<3)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($8) + ($j$01<<3)|0) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11>>>0)>($13>>>0);
   if ($14) {
    (__ZN5physx7AddPairEjjRNS_14SapPairManagerERPjRjS4_($11,$13,$1,$2,$3,$4)|0);
   } else {
    __ZN5physx10RemovePairEjjRNS_14SapPairManagerERPjRjS4_($11,$13,$1,$2,$3,$4);
   }
   $15 = (($j$01) + 1)|0;
   $exitcond = ($15|0)==($6|0);
   if ($exitcond) {
    break;
   } else {
    $j$01 = $15;
   }
  }
 }
 $16 = (($this) + 328|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 324|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==(0);
 if (!($20)) {
  $j$01$1 = 0;
  while(1) {
   $21 = (($19) + ($j$01$1<<3)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($19) + ($j$01$1<<3)|0) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22>>>0)>($24>>>0);
   if ($25) {
    (__ZN5physx7AddPairEjjRNS_14SapPairManagerERPjRjS4_($22,$24,$1,$2,$3,$4)|0);
   } else {
    __ZN5physx10RemovePairEjjRNS_14SapPairManagerERPjRjS4_($22,$24,$1,$2,$3,$4);
   }
   $26 = (($j$01$1) + 1)|0;
   $exitcond$1 = ($26|0)==($17|0);
   if ($exitcond$1) {
    break;
   } else {
    $j$01$1 = $26;
   }
  }
 }
 $27 = (($this) + 368|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 364|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($28|0)==(0);
 if (!($31)) {
  $j$01$2 = 0;
  while(1) {
   $32 = (($30) + ($j$01$2<<3)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ((($30) + ($j$01$2<<3)|0) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($33>>>0)>($35>>>0);
   if ($36) {
    (__ZN5physx7AddPairEjjRNS_14SapPairManagerERPjRjS4_($33,$35,$1,$2,$3,$4)|0);
   } else {
    __ZN5physx10RemovePairEjjRNS_14SapPairManagerERPjRjS4_($33,$35,$1,$2,$3,$4);
   }
   $37 = (($j$01$2) + 1)|0;
   $exitcond$2 = ($37|0)==($28|0);
   if ($exitcond$2) {
    break;
   } else {
    $j$01$2 = $37;
   }
  }
 }
 __ZN5physx23PxsBroadPhaseContextSap11batchCreateEv($this);
 $38 = (($this) + 104|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = (($this) + 232|0);
 $43 = (($this) + 236|0);
 $44 = (($this) + 240|0);
 $45 = (($this) + 244|0);
 $46 = (($this) + 248|0);
 $47 = (($this) + 252|0);
 __ZN5physx31ComputeCreatedDeletedPairsListsEPKjS1_jRPNS_17PxcBroadPhasePairERjS5_S4_S5_S5_RNS_14SapPairManagerE($39,$40,$41,$42,$43,$44,$45,$46,$47,$1);
 $48 = (($this) + 168|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 172|0);
 HEAP32[$50>>2] = $49;
 STACKTOP = sp;return;
}
function __ZN5physx7AddPairEjjRNS_14SapPairManagerERPjRjS4_($id0,$id1,$pairManager,$dataArray,$dataArraySize,$dataArrayCapacity) {
 $id0 = $id0|0;
 $id1 = $id1|0;
 $pairManager = $pairManager|0;
 $dataArray = $dataArray|0;
 $dataArraySize = $dataArraySize|0;
 $dataArrayCapacity = $dataArrayCapacity|0;
 var $$$i$i = 0, $$0 = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre1$i = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (__ZN5physx14SapPairManager7AddPairEjjh($pairManager,$id0,$id1,8)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($pairManager) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $2;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 3;
 $10 = (($pairManager) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9)|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 8;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $57 = $5;$61 = $11;
 } else {
  HEAP8[$12>>0] = 0;
  $16 = HEAP32[$4>>2]|0;
  $17 = $16;
  $18 = (($6) - ($17))|0;
  $19 = $18 >> 3;
  $20 = HEAP32[$10>>2]|0;
  $21 = (($20) + ($19)|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = $23 | 1;
  $25 = $24&255;
  HEAP8[$21>>0] = $25;
  $26 = HEAP32[$4>>2]|0;
  $27 = $26;
  $28 = (($6) - ($27))|0;
  $29 = $28 >>> 3;
  $30 = HEAP32[$dataArraySize>>2]|0;
  $31 = HEAP32[$dataArrayCapacity>>2]|0;
  $32 = ($30|0)==($31|0);
  if ($32) {
   $33 = ($30|0)==(0);
   $34 = $30 << 1;
   $$$i$i = $33 ? 64 : $34;
   $35 = $$$i$i << 2;
   $36 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$35,485064,217)|0);
   $37 = HEAP32[$dataArray>>2]|0;
   $38 = HEAP32[$dataArrayCapacity>>2]|0;
   $39 = $38 << 2;
   _memcpy(($36|0),($37|0),($39|0))|0;
   $40 = HEAP32[$dataArray>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$40);
   HEAP32[$dataArray>>2] = $36;
   HEAP32[$dataArrayCapacity>>2] = $$$i$i;
   $$pre$i = HEAP32[$dataArraySize>>2]|0;
   $$pre2 = HEAP32[$4>>2]|0;
   $42 = $36;$43 = $$pre$i;$47 = $$pre2;
  } else {
   $$pre1$i = HEAP32[$dataArray>>2]|0;
   $42 = $$pre1$i;$43 = $30;$47 = $26;
  }
  $41 = (($42) + ($43<<2)|0);
  HEAP32[$41>>2] = $29;
  $44 = HEAP32[$dataArraySize>>2]|0;
  $45 = (($44) + 1)|0;
  HEAP32[$dataArraySize>>2] = $45;
  $46 = $47;
  $48 = (($6) - ($46))|0;
  $49 = $48 >> 3;
  $50 = HEAP32[$10>>2]|0;
  $51 = (($50) + ($49)|0);
  $52 = HEAP8[$51>>0]|0;
  $53 = $52&255;
  $54 = $53 | 4;
  $55 = $54&255;
  HEAP8[$51>>0] = $55;
  $$pre = HEAP32[$4>>2]|0;
  $$pre1 = HEAP32[$10>>2]|0;
  $57 = $$pre;$61 = $$pre1;
 }
 $56 = $57;
 $58 = (($6) - ($56))|0;
 $59 = $58 >> 3;
 $60 = (($61) + ($59)|0);
 $62 = HEAP8[$60>>0]|0;
 $63 = $62&255;
 $64 = $63 & 253;
 $65 = $64&255;
 HEAP8[$60>>0] = $65;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx10RemovePairEjjRNS_14SapPairManagerERPjRjS4_($id0,$id1,$pairManager,$dataArray,$dataArraySize,$dataArrayCapacity) {
 $id0 = $id0|0;
 $id1 = $id1|0;
 $pairManager = $pairManager|0;
 $dataArray = $dataArray|0;
 $dataArraySize = $dataArraySize|0;
 $dataArrayCapacity = $dataArrayCapacity|0;
 var $$$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$pre = 0, $$pre1 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (__ZNK5physx14SapPairManager8FindPairEjj($pairManager,$id0,$id1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($pairManager) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $2;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 3;
 $10 = (($pairManager) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9)|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $16 = $13&255;
  $17 = $16 | 1;
  $18 = $17&255;
  HEAP8[$12>>0] = $18;
  $19 = HEAP32[$4>>2]|0;
  $20 = $19;
  $21 = (($6) - ($20))|0;
  $22 = $21 >>> 3;
  $23 = HEAP32[$dataArraySize>>2]|0;
  $24 = HEAP32[$dataArrayCapacity>>2]|0;
  $25 = ($23|0)==($24|0);
  if ($25) {
   $26 = ($23|0)==(0);
   $27 = $23 << 1;
   $$$i$i = $26 ? 64 : $27;
   $28 = $$$i$i << 2;
   $29 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$28,485064,217)|0);
   $30 = HEAP32[$dataArray>>2]|0;
   $31 = HEAP32[$dataArrayCapacity>>2]|0;
   $32 = $31 << 2;
   _memcpy(($29|0),($30|0),($32|0))|0;
   $33 = HEAP32[$dataArray>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$33);
   HEAP32[$dataArray>>2] = $29;
   HEAP32[$dataArrayCapacity>>2] = $$$i$i;
   $$pre$i = HEAP32[$dataArraySize>>2]|0;
   $$pre$pre = HEAP32[$4>>2]|0;
   $$pre = $$pre$pre;$35 = $29;$36 = $$pre$i;
  } else {
   $$pre1$i = HEAP32[$dataArray>>2]|0;
   $$pre = $19;$35 = $$pre1$i;$36 = $23;
  }
  $34 = (($35) + ($36<<2)|0);
  HEAP32[$34>>2] = $22;
  $37 = HEAP32[$dataArraySize>>2]|0;
  $38 = (($37) + 1)|0;
  HEAP32[$dataArraySize>>2] = $38;
  $$pre1 = HEAP32[$10>>2]|0;
  $40 = $$pre;$44 = $$pre1;
 } else {
  $40 = $5;$44 = $11;
 }
 $39 = $40;
 $41 = (($6) - ($39))|0;
 $42 = $41 >> 3;
 $43 = (($44) + ($42)|0);
 $45 = HEAP8[$43>>0]|0;
 $46 = $45&255;
 $47 = $46 | 2;
 $48 = $47&255;
 HEAP8[$43>>0] = $48;
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap11batchCreateEv($this) {
 $this = $this|0;
 var $$$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Axis$017 = 0, $CurrInsIdx$0$i = 0, $CurrInsIdx$0$ph4$i = 0, $CurrentData$0$ph2$i = 0, $CurrentValue$0$ph3$i = 0, $WriteIdx$0$i = 0, $WriteIdx$0$ph5$i = 0, $bd = 0, $bv = 0, $exitcond = 0, $exitcond19 = 0, $exitcond20 = 0, $exitcond23 = 0;
 var $i$07 = 0, $i1$08 = 0, $i2$010 = 0, $nepsd = 0, $nepsv = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $0 = sp + 540|0;
 $nepsv = sp;
 $bv = sp + 132|0;
 $nepsd = sp + 264|0;
 $bd = sp + 396|0;
 $1 = sp + 528|0;
 $2 = (($this) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 76|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 100|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $3 << 1;
 $10 = (($nepsv) + 128|0);
 $11 = ($9>>>0)<(33);
 if ($11) {
  $14 = $nepsv;
 } else {
  $12 = $3 << 3;
  $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$12,484968,56)|0);
  $14 = $13;
 }
 HEAP32[$10>>2] = $14;
 $15 = (($bv) + 128|0);
 if ($11) {
  $18 = $bv;
 } else {
  $16 = $3 << 3;
  $17 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$16,484968,56)|0);
  $18 = $17;
 }
 HEAP32[$15>>2] = $18;
 $19 = (($nepsd) + 128|0);
 if ($11) {
  $22 = $nepsd;
 } else {
  $20 = $3 << 3;
  $21 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$20,484968,56)|0);
  $22 = $21;
 }
 HEAP32[$19>>2] = $22;
 $23 = (($bd) + 128|0);
 if ($11) {
  $26 = $bd;$43 = $22;
 } else {
  $24 = $3 << 3;
  $25 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$24,484968,56)|0);
  $$pre = HEAP32[$19>>2]|0;
  $26 = $25;$43 = $$pre;
 }
 HEAP32[$23>>2] = $26;
 $27 = HEAP32[$10>>2]|0;
 $28 = HEAP32[$15>>2]|0;
 __ZN5physx2Gu17RadixSortBufferedC2Ev($0);
 $29 = ($9|0)==(0);
 $30 = (($this) + 168|0);
 $31 = (($9) + -1)|0;
 $32 = $3 << 1;
 $Axis$017 = 0;
 while(1) {
  $33 = (($Axis$017) + 3)|0;
  $i$07 = 0;
  while(1) {
   $34 = (($6) + ($i$07<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($8) + (($35*24)|0)|0) + ($Axis$017<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($8) + (($35*24)|0)|0) + ($33<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = $i$07 << 1;
   $41 = (($27) + ($40<<2)|0);
   HEAP32[$41>>2] = $37;
   $42 = (($43) + ($40<<2)|0);
   $44 = $35 << 1;
   HEAP32[$42>>2] = $44;
   $45 = $40 | 1;
   $46 = (($27) + ($45<<2)|0);
   HEAP32[$46>>2] = $39;
   $47 = (($43) + ($45<<2)|0);
   $$$i = $44 | 1;
   HEAP32[$47>>2] = $$$i;
   $48 = (($i$07) + 1)|0;
   $exitcond = ($48|0)==($3|0);
   if ($exitcond) {
    break;
   } else {
    $i$07 = $48;
   }
  }
  if ($29) {
   (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($0,$28,$9,1)|0);
  } else {
   $i1$08 = 0;
   while(1) {
    $49 = (($27) + ($i1$08<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($28) + ($i1$08<<2)|0);
    HEAP32[$51>>2] = $50;
    $52 = (($i1$08) + 1)|0;
    $exitcond19 = ($52|0)==($32|0);
    if ($exitcond19) {
     break;
    } else {
     $i1$08 = $52;
    }
   }
   $53 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($0,$28,$9,1)|0);
   $54 = (($53) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   if (!($29)) {
    $i2$010 = 0;
    while(1) {
     $56 = (($31) - ($i2$010))|0;
     $57 = (($55) + ($56<<2)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($27) + ($58<<2)|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (($28) + ($i2$010<<2)|0);
     HEAP32[$61>>2] = $60;
     $62 = HEAP32[$57>>2]|0;
     $63 = (($43) + ($62<<2)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($26) + ($i2$010<<2)|0);
     HEAP32[$65>>2] = $64;
     $66 = (($i2$010) + 1)|0;
     $exitcond20 = ($66|0)==($32|0);
     if ($exitcond20) {
      break;
     } else {
      $i2$010 = $66;
     }
    }
   }
  }
  $67 = ((($this) + ($Axis$017<<2)|0) + 124|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($this) + ($Axis$017<<2)|0) + 136|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = HEAP32[$30>>2]|0;
  $72 = HEAP32[$2>>2]|0;
  $73 = (($71) - ($72))|0;
  $74 = $73 << 1;
  $75 = ((($this) + ($Axis$017<<2)|0) + 112|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + ($9))|0;
  $78 = $74 | 1;
  $79 = (($68) + ($78<<2)|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = $77 | 1;
  $82 = (($68) + ($81<<2)|0);
  HEAP32[$82>>2] = $80;
  $83 = (($70) + ($78<<2)|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($70) + ($81<<2)|0);
  HEAP32[$85>>2] = $84;
  $86 = ($74|0)<(0);
  L33: do {
   if (!($86)) {
    $87 = (($70) + ($74<<2)|0);
    $88 = (($68) + ($74<<2)|0);
    $CurrInsIdx$0$ph4$i = 0;$CurrentData$0$ph2$i = $87;$CurrentValue$0$ph3$i = $88;$WriteIdx$0$ph5$i = $77;
    while(1) {
     $CurrInsIdx$0$i = $CurrInsIdx$0$ph4$i;$WriteIdx$0$i = $WriteIdx$0$ph5$i;
     while(1) {
      $89 = (($28) + ($CurrInsIdx$0$i<<2)|0);
      $90 = (($26) + ($CurrInsIdx$0$i<<2)|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = $91 & 1;
      $93 = ($92|0)!=(0);
      $94 = HEAP32[$CurrentValue$0$ph3$i>>2]|0;
      $95 = HEAP32[$89>>2]|0;
      $96 = ($94>>>0)<=($95>>>0);
      $97 = ($94>>>0)<($95>>>0);
      $98 = $93 ? $96 : $97;
      $99 = $98 ? $90 : $CurrentData$0$ph2$i;
      $100 = $98 ? $95 : $94;
      $101 = (($68) + ($WriteIdx$0$i<<2)|0);
      HEAP32[$101>>2] = $100;
      $102 = HEAP32[$99>>2]|0;
      $103 = (($70) + ($WriteIdx$0$i<<2)|0);
      HEAP32[$103>>2] = $102;
      $104 = (($WriteIdx$0$i) + -1)|0;
      $105 = HEAP32[$99>>2]|0;
      $106 = $105 & 1;
      $107 = $105 >>> 1;
      $108 = ((($76) + ($107<<3)|0) + ($106<<2)|0);
      HEAP32[$108>>2] = $WriteIdx$0$i;
      if (!($98)) {
       break;
      }
      $109 = (($CurrInsIdx$0$i) + 1)|0;
      $110 = ($109>>>0)<($9>>>0);
      if ($110) {
       $CurrInsIdx$0$i = $109;$WriteIdx$0$i = $104;
      } else {
       break L33;
      }
     }
     $111 = (($CurrentValue$0$ph3$i) + -4|0);
     $112 = (($CurrentData$0$ph2$i) + -4|0);
     $113 = ($112>>>0)<($70>>>0);
     if ($113) {
      break;
     } else {
      $CurrInsIdx$0$ph4$i = $CurrInsIdx$0$i;$CurrentData$0$ph2$i = $112;$CurrentValue$0$ph3$i = $111;$WriteIdx$0$ph5$i = $104;
     }
    }
   }
  } while(0);
  $114 = (($Axis$017) + 1)|0;
  $exitcond23 = ($114|0)==(3);
  if ($exitcond23) {
   break;
  } else {
   $Axis$017 = $114;
  }
 }
 __ZN5physx2Gu17RadixSortBufferedD2Ev($0);
 $115 = HEAP32[$23>>2]|0;
 $116 = ($115|0)==($bd|0);
 if (!($116)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$115);
 }
 $117 = HEAP32[$19>>2]|0;
 $118 = ($117|0)==($nepsd|0);
 if (!($118)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$117);
 }
 $119 = HEAP32[$15>>2]|0;
 $120 = ($119|0)==($bv|0);
 if (!($120)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$119);
 }
 $121 = HEAP32[$10>>2]|0;
 $122 = ($121|0)==($nepsv|0);
 if (!($122)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$121);
 }
 HEAP32[$1>>2] = 0;
 $123 = (($1) + 4|0);
 HEAP32[$123>>2] = 1;
 $124 = (($1) + 8|0);
 HEAP32[$124>>2] = 2;
 __ZN5physx23PxsBroadPhaseContextSap17performBoxPruningENS_2Gu4AxesE($this,$1);
 STACKTOP = sp;return;
}
function __ZN5physx29BroadPhaseBatchUpdateWorkTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 28|0);
 $6 = (($this) + 36|0);
 __ZN5physx23PxsBroadPhaseContextSap11batchUpdateEjRPNS_17PxcBroadPhasePairERjS4_($2,$4,$5,$0,$6);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap11batchUpdateEjRPNS_17PxcBroadPhasePairERjS4_($this,$Axis,$pairs,$pairsSize,$pairsCapacity) {
 $this = $this|0;
 $Axis = $Axis|0;
 $pairs = $pairs|0;
 $pairsSize = $pairsSize|0;
 $pairsCapacity = $pairsCapacity|0;
 var $$$i = 0, $$$i3 = 0, $$pn14 = 0, $$pn14$phi = 0, $$pre = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre47$pre = 0, $$pre48 = 0, $$pre48$pre = 0, $$pre53 = 0, $$pre55 = 0, $$pre56 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $CurrIndex$05 = 0, $CurrentIndex$0 = 0, $CurrentIndex$1 = 0, $CurrentIndex$2 = 0, $a$04 = 0, $a6$06 = 0, $a9$010 = 0, $boxMinMax2D = 0, $currentPocket$0$lcssa = 0, $currentPocket$028 = 0;
 var $currentPocket$1 = 0, $currentPocket$2 = 0, $currentPocket$3 = 0, $ind$027 = 0, $maxNumPairs$0$lcssa = 0, $maxNumPairs$030 = 0, $maxNumPairs$1 = 0, $maxNumPairs$2 = 0, $maxNumPairs$3 = 0, $maxNumPairs$4 = 0, $maxNumPairs$5 = 0, $maxNumPairs$6 = 0, $maxNumPairs$7 = 0, $maxNumPairs$8 = 0, $numPairs$0$lcssa = 0, $numPairs$031 = 0, $numPairs$1 = 0, $numPairs$2 = 0, $numPairs$3 = 0, $numPairs$4 = 0;
 var $numPairs$5 = 0, $numPairs$6 = 0, $or$cond$i = 0, $or$cond$i1 = 0, $or$cond1$i = 0, $or$cond1$i2 = 0, $pocket$0 = 0, $pocket$013 = 0, $pocket$015 = 0, $startIndex$0 = 0, $startIndex$1 = 0, $startIndex$2 = 0, $updateCounter$029 = 0, $updateCounter$1 = 0, $wasUpdated$026 = 0, $wasUpdated$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 25|0;
 $1 = sp + 24|0;
 $boxMinMax2D = sp;
 $2 = (($this) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = ($3*5)|0;
 $6 = (($this) + 168|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  __ZN5physx23PxsBroadPhaseContextSap21batchUpdateFewUpdatesEjRPNS_17PxcBroadPhasePairERjS4_($this,$Axis,$pairs,$pairsSize,$pairsCapacity);
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$pairsCapacity>>2]|0;
 $10 = (($this) + 100|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 116|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$boxMinMax2D>>2] = $13;
 $14 = (($boxMinMax2D) + 4|0);
 $15 = (($this) + 120|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$14>>2] = $16;
 $17 = (($boxMinMax2D) + 8|0);
 HEAP32[$17>>2] = $16;
 $18 = (($boxMinMax2D) + 12|0);
 $19 = (($this) + 112|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$18>>2] = $20;
 $21 = (($boxMinMax2D) + 16|0);
 HEAP32[$21>>2] = $20;
 $22 = (($boxMinMax2D) + 20|0);
 HEAP32[$22>>2] = $13;
 $23 = $Axis << 1;
 $24 = (($boxMinMax2D) + ($23<<2)|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $23 | 1;
 $27 = (($boxMinMax2D) + ($26<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 104|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($this) + ($Axis<<2)|0) + 112|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($this) + ($Axis<<2)|0) + 124|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($this) + ($Axis<<2)|0) + 136|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 148|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = $40 & -2;
 $42 = ($41|0)==(1073741822);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = $40 >>> 1;
 $44 = ((($11) + (($43*24)|0)|0) + ($Axis<<2)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($34) + 4|0);
 HEAP32[$46>>2] = $45;
 $47 = HEAP32[$2>>2]|0;
 $48 = (($38) + ($43)|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = (($this) + 156|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 4|0);
 HEAP32[$52>>2] = 0;
 HEAP32[$51>>2] = 0;
 $53 = (($36) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 & -2;
 $56 = ($55|0)==(1073741822);
 L11: do {
  if ($56) {
   $215 = $51;$currentPocket$0$lcssa = $51;$maxNumPairs$0$lcssa = $9;$numPairs$0$lcssa = 0;
  } else {
   $57 = $49&255;
   $58 = $47 << 1;
   $59 = HEAP8[$48>>0]|0;
   $60 = (($58) - ($57))|0;
   $61 = (($this) + 164|0);
   $62 = (($Axis) + 3)|0;
   $63 = (($this) + 160|0);
   $271 = $51;$65 = $54;$currentPocket$028 = $51;$ind$027 = 2;$maxNumPairs$030 = $9;$numPairs$031 = 0;$updateCounter$029 = $60;$wasUpdated$026 = $59;
   while(1) {
    $64 = $65 >>> 1;
    $66 = (($38) + ($64)|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67 | $wasUpdated$026;
    $69 = ($68<<24>>24)==(0);
    if ($69) {
     $209 = ($updateCounter$029|0)==(0);
     if ($209) {
      $215 = $271;$currentPocket$0$lcssa = $currentPocket$028;$maxNumPairs$0$lcssa = $maxNumPairs$030;$numPairs$0$lcssa = $numPairs$031;
      break L11;
     } else {
      $272 = $271;$currentPocket$3 = $currentPocket$028;$maxNumPairs$8 = $maxNumPairs$030;$numPairs$6 = $numPairs$031;$updateCounter$1 = $updateCounter$029;$wasUpdated$1 = $wasUpdated$026;
     }
    } else {
     $70 = $67&255;
     $71 = (($updateCounter$029) - ($70))|0;
     $72 = $65 & 1;
     $73 = (0 - ($72))|0;
     $74 = $73 & 3;
     $75 = (($74) + ($Axis))|0;
     $76 = ((($11) + (($64*24)|0)|0) + ($75<<2)|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($34) + ($ind$027<<2)|0);
     HEAP32[$78>>2] = $77;
     $79 = HEAP32[$61>>2]|0;
     $80 = (($79) + ($ind$027<<2)|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($34) + ($81<<2)|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83>>>0)>($77>>>0);
     if ($84) {
      $85 = ((($11) + (($64*24)|0)|0) + ($62<<2)|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = (($30) + ($64<<2)|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = ($72|0)==(0);
      $90 = (($25) + ($64<<3)|0);
      $91 = ((($25) + ($64<<3)|0) + 4|0);
      $92 = (($28) + ($64<<3)|0);
      $93 = ((($28) + ($64<<3)|0) + 4|0);
      if ($89) {
       $273 = $79;$CurrentIndex$0 = $81;$maxNumPairs$1 = $maxNumPairs$030;$numPairs$1 = $numPairs$031;$startIndex$0 = $ind$027;
       while(1) {
        $94 = (($36) + ($CurrentIndex$0<<2)|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = $95 & 1;
        $97 = ($96|0)==(0);
        if ($97) {
         $138 = $273;$maxNumPairs$3 = $maxNumPairs$1;$numPairs$2 = $numPairs$1;
        } else {
         $98 = $95 >>> 1;
         $99 = (($32) + ($98<<3)|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = (($34) + ($100<<2)|0);
         $102 = HEAP32[$101>>2]|0;
         $103 = ($102>>>0)<($86>>>0);
         if ($103) {
          $104 = HEAP32[$90>>2]|0;
          $105 = HEAP32[$91>>2]|0;
          $106 = HEAP32[$92>>2]|0;
          $107 = HEAP32[$93>>2]|0;
          $108 = (($25) + ($98<<3)|0);
          $109 = HEAP32[$108>>2]|0;
          $110 = ((($25) + ($98<<3)|0) + 4|0);
          $111 = HEAP32[$110>>2]|0;
          $112 = (($28) + ($98<<3)|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = ((($28) + ($98<<3)|0) + 4|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = ($105>>>0)>($109>>>0);
          $117 = ($111>>>0)>($104>>>0);
          $or$cond$i1 = $116 & $117;
          $118 = ($107>>>0)>($113>>>0);
          $or$cond1$i2 = $or$cond$i1 & $118;
          $119 = ($115>>>0)>($106>>>0);
          $$$i3 = $or$cond1$i2 & $119;
          if ($$$i3) {
           $120 = (($30) + ($98<<2)|0);
           $121 = HEAP32[$120>>2]|0;
           $122 = ($88|0)==($121|0);
           if ($122) {
            $138 = $273;$maxNumPairs$3 = $maxNumPairs$1;$numPairs$2 = $numPairs$1;
           } else {
            $123 = ($numPairs$1|0)==($maxNumPairs$1|0);
            if ($123) {
             $124 = $maxNumPairs$1 << 1;
             $125 = HEAP32[$pairs>>2]|0;
             $126 = $maxNumPairs$1 << 4;
             $127 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$126,484600,1503)|0);
             $128 = $maxNumPairs$1 << 3;
             _memcpy(($127|0),($125|0),($128|0))|0;
             __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$125);
             HEAP32[$pairs>>2] = $127;
             $$pre48$pre = HEAP32[$61>>2]|0;
             $$pre48 = $$pre48$pre;$132 = $127;$maxNumPairs$2 = $124;
            } else {
             $$pre55 = HEAP32[$pairs>>2]|0;
             $$pre48 = $273;$132 = $$pre55;$maxNumPairs$2 = $maxNumPairs$1;
            }
            $129 = ($64>>>0)<($98>>>0);
            $130 = $129 ? $98 : $64;
            $131 = (($132) + ($numPairs$1<<3)|0);
            HEAP32[$131>>2] = $130;
            $133 = $129 ? $64 : $98;
            $134 = ((($132) + ($numPairs$1<<3)|0) + 4|0);
            HEAP32[$134>>2] = $133;
            $135 = (($numPairs$1) + 1)|0;
            $138 = $$pre48;$maxNumPairs$3 = $maxNumPairs$2;$numPairs$2 = $135;
           }
          } else {
           $138 = $273;$maxNumPairs$3 = $maxNumPairs$1;$numPairs$2 = $numPairs$1;
          }
         } else {
          $138 = $273;$maxNumPairs$3 = $maxNumPairs$1;$numPairs$2 = $numPairs$1;
         }
        }
        $136 = (($startIndex$0) + -1)|0;
        $137 = (($138) + ($CurrentIndex$0<<2)|0);
        $139 = HEAP32[$137>>2]|0;
        $140 = (($34) + ($139<<2)|0);
        $141 = HEAP32[$140>>2]|0;
        $142 = ($77>>>0)<($141>>>0);
        if ($142) {
         $273 = $138;$CurrentIndex$0 = $139;$maxNumPairs$1 = $maxNumPairs$3;$numPairs$1 = $numPairs$2;$startIndex$0 = $136;
        } else {
         $191 = $138;$CurrentIndex$2 = $139;$maxNumPairs$7 = $maxNumPairs$3;$numPairs$5 = $numPairs$2;$startIndex$2 = $136;
         break;
        }
       }
      } else {
       $274 = $79;$CurrentIndex$1 = $81;$maxNumPairs$4 = $maxNumPairs$030;$numPairs$3 = $numPairs$031;$startIndex$1 = $ind$027;
       while(1) {
        $143 = (($36) + ($CurrentIndex$1<<2)|0);
        $144 = HEAP32[$143>>2]|0;
        $145 = $144 & 1;
        $146 = ($145|0)==(0);
        if ($146) {
         $147 = $144 >>> 1;
         $148 = HEAP32[$90>>2]|0;
         $149 = HEAP32[$91>>2]|0;
         $150 = HEAP32[$92>>2]|0;
         $151 = HEAP32[$93>>2]|0;
         $152 = (($25) + ($147<<3)|0);
         $153 = HEAP32[$152>>2]|0;
         $154 = ((($25) + ($147<<3)|0) + 4|0);
         $155 = HEAP32[$154>>2]|0;
         $156 = (($28) + ($147<<3)|0);
         $157 = HEAP32[$156>>2]|0;
         $158 = ((($28) + ($147<<3)|0) + 4|0);
         $159 = HEAP32[$158>>2]|0;
         $160 = ($149>>>0)>($153>>>0);
         $161 = ($155>>>0)>($148>>>0);
         $or$cond$i = $160 & $161;
         $162 = ($151>>>0)>($157>>>0);
         $or$cond1$i = $or$cond$i & $162;
         $163 = ($159>>>0)>($150>>>0);
         $$$i = $or$cond1$i & $163;
         if ($$$i) {
          $164 = (($30) + ($147<<2)|0);
          $165 = HEAP32[$164>>2]|0;
          $166 = ($88|0)==($165|0);
          if ($166) {
           $182 = $274;$maxNumPairs$6 = $maxNumPairs$4;$numPairs$4 = $numPairs$3;
          } else {
           $167 = ($numPairs$3|0)==($maxNumPairs$4|0);
           if ($167) {
            $168 = $maxNumPairs$4 << 1;
            $169 = HEAP32[$pairs>>2]|0;
            $170 = $maxNumPairs$4 << 4;
            $171 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$170,484600,1503)|0);
            $172 = $maxNumPairs$4 << 3;
            _memcpy(($171|0),($169|0),($172|0))|0;
            __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$169);
            HEAP32[$pairs>>2] = $171;
            $$pre47$pre = HEAP32[$61>>2]|0;
            $$pre47 = $$pre47$pre;$176 = $171;$maxNumPairs$5 = $168;
           } else {
            $$pre53 = HEAP32[$pairs>>2]|0;
            $$pre47 = $274;$176 = $$pre53;$maxNumPairs$5 = $maxNumPairs$4;
           }
           $173 = ($64>>>0)<($147>>>0);
           $174 = $173 ? $64 : $147;
           $175 = (($176) + ($numPairs$3<<3)|0);
           HEAP32[$175>>2] = $174;
           $177 = $173 ? $147 : $64;
           $178 = ((($176) + ($numPairs$3<<3)|0) + 4|0);
           HEAP32[$178>>2] = $177;
           $179 = (($numPairs$3) + 1)|0;
           $182 = $$pre47;$maxNumPairs$6 = $maxNumPairs$5;$numPairs$4 = $179;
          }
         } else {
          $182 = $274;$maxNumPairs$6 = $maxNumPairs$4;$numPairs$4 = $numPairs$3;
         }
        } else {
         $182 = $274;$maxNumPairs$6 = $maxNumPairs$4;$numPairs$4 = $numPairs$3;
        }
        $180 = (($startIndex$1) + -1)|0;
        $181 = (($182) + ($CurrentIndex$1<<2)|0);
        $183 = HEAP32[$181>>2]|0;
        $184 = (($34) + ($183<<2)|0);
        $185 = HEAP32[$184>>2]|0;
        $186 = ($77>>>0)<($185>>>0);
        if ($186) {
         $274 = $182;$CurrentIndex$1 = $183;$maxNumPairs$4 = $maxNumPairs$6;$numPairs$3 = $numPairs$4;$startIndex$1 = $180;
        } else {
         $191 = $182;$CurrentIndex$2 = $183;$maxNumPairs$7 = $maxNumPairs$6;$numPairs$5 = $numPairs$4;$startIndex$2 = $180;
         break;
        }
       }
      }
      $187 = HEAP32[$63>>2]|0;
      $188 = (($187) + ($ind$027<<2)|0);
      $189 = HEAP32[$188>>2]|0;
      $190 = (($191) + ($ind$027<<2)|0);
      $192 = HEAP32[$190>>2]|0;
      $193 = (($187) + ($CurrentIndex$2<<2)|0);
      $194 = HEAP32[$193>>2]|0;
      $195 = (($187) + ($192<<2)|0);
      HEAP32[$195>>2] = $189;
      $196 = (($191) + ($189<<2)|0);
      HEAP32[$196>>2] = $192;
      HEAP32[$188>>2] = $194;
      HEAP32[$190>>2] = $CurrentIndex$2;
      $197 = (($191) + ($194<<2)|0);
      HEAP32[$197>>2] = $ind$027;
      HEAP32[$193>>2] = $ind$027;
      $currentPocket$1 = $currentPocket$028;
      while(1) {
       $198 = HEAP32[$currentPocket$1>>2]|0;
       $199 = ($startIndex$2>>>0)<($198>>>0);
       $200 = (($currentPocket$1) + -8|0);
       if ($199) {
        $currentPocket$1 = $200;
       } else {
        break;
       }
      }
      $201 = HEAP32[$50>>2]|0;
      $202 = ($currentPocket$1|0)==($201|0);
      if ($202) {
       label = 31;
      } else {
       $203 = (($currentPocket$1) + 4|0);
       $204 = HEAP32[$203>>2]|0;
       $205 = (($204) + 1)|0;
       $206 = ($startIndex$2>>>0)>($205>>>0);
       if ($206) {
        label = 31;
       } else {
        $currentPocket$2 = $currentPocket$1;
       }
      }
      if ((label|0) == 31) {
       label = 0;
       $207 = (($currentPocket$1) + 8|0);
       HEAP32[$207>>2] = $startIndex$2;
       $currentPocket$2 = $207;
      }
      $208 = (($currentPocket$2) + 4|0);
      HEAP32[$208>>2] = $ind$027;
      $272 = $201;$currentPocket$3 = $currentPocket$2;$maxNumPairs$8 = $maxNumPairs$7;$numPairs$6 = $numPairs$5;$updateCounter$1 = $71;$wasUpdated$1 = 1;
     } else {
      $272 = $271;$currentPocket$3 = $currentPocket$028;$maxNumPairs$8 = $maxNumPairs$030;$numPairs$6 = $numPairs$031;$updateCounter$1 = $71;$wasUpdated$1 = $67;
     }
    }
    $210 = (($ind$027) + 1)|0;
    $211 = (($36) + ($210<<2)|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = $212 & -2;
    $214 = ($213|0)==(1073741822);
    if ($214) {
     $215 = $272;$currentPocket$0$lcssa = $currentPocket$3;$maxNumPairs$0$lcssa = $maxNumPairs$8;$numPairs$0$lcssa = $numPairs$6;
     break;
    } else {
     $271 = $272;$65 = $212;$currentPocket$028 = $currentPocket$3;$ind$027 = $210;$maxNumPairs$030 = $maxNumPairs$8;$numPairs$031 = $numPairs$6;$updateCounter$029 = $updateCounter$1;$wasUpdated$026 = $wasUpdated$1;
    }
   }
  }
 } while(0);
 HEAP32[$pairsSize>>2] = $numPairs$0$lcssa;
 HEAP32[$pairsCapacity>>2] = $maxNumPairs$0$lcssa;
 $pocket$013 = (($215) + 8|0);
 $216 = ($pocket$013>>>0)>($currentPocket$0$lcssa>>>0);
 $$pre56 = (($this) + 164|0);
 if (!($216)) {
  $217 = (($this) + 160|0);
  $$pn14 = $215;$pocket$015 = $pocket$013;
  while(1) {
   $219 = HEAP32[$pocket$015>>2]|0;
   $220 = (($$pn14) + 12|0);
   $221 = HEAP32[$220>>2]|0;
   $222 = ($219>>>0)>($221>>>0);
   if ($222) {
    $229 = $219;$230 = $221;
   } else {
    $223 = HEAP32[$$pre56>>2]|0;
    $a$04 = $219;
    while(1) {
     $224 = (($223) + ($a$04<<2)|0);
     HEAP32[$224>>2] = $a$04;
     $225 = (($a$04) + 1)|0;
     $226 = HEAP32[$220>>2]|0;
     $227 = ($225>>>0)>($226>>>0);
     if ($227) {
      break;
     } else {
      $a$04 = $225;
     }
    }
    $$pre = HEAP32[$pocket$015>>2]|0;
    $229 = $$pre;$230 = $226;
   }
   $228 = ($229>>>0)>($230>>>0);
   if ($228) {
    $260 = $229;$262 = $230;
   } else {
    $231 = (($229) + -1)|0;
    $232 = HEAP32[$217>>2]|0;
    $233 = HEAP32[$$pre56>>2]|0;
    $275 = $230;$CurrIndex$05 = $231;$a6$06 = $229;
    while(1) {
     $234 = (($232) + ($CurrIndex$05<<2)|0);
     $235 = HEAP32[$234>>2]|0;
     $236 = (($233) + ($235<<2)|0);
     $237 = HEAP32[$236>>2]|0;
     $238 = ($235|0)==($a6$06|0);
     if ($238) {
      $258 = $275;
     } else {
      $239 = (($36) + ($237<<2)|0);
      $240 = HEAP32[$239>>2]|0;
      $241 = $240 >>> 1;
      $242 = $240 & 1;
      $243 = (($34) + ($a6$06<<2)|0);
      $244 = HEAP32[$243>>2]|0;
      $245 = (($36) + ($a6$06<<2)|0);
      $246 = HEAP32[$245>>2]|0;
      $247 = (($34) + ($237<<2)|0);
      $248 = HEAP32[$247>>2]|0;
      HEAP32[$243>>2] = $248;
      $249 = HEAP32[$239>>2]|0;
      HEAP32[$245>>2] = $249;
      HEAP32[$247>>2] = $244;
      HEAP32[$239>>2] = $246;
      $250 = (($233) + ($a6$06<<2)|0);
      $251 = HEAP32[$250>>2]|0;
      $252 = (($233) + ($237<<2)|0);
      HEAP32[$252>>2] = $251;
      $253 = HEAP32[$250>>2]|0;
      $254 = (($233) + ($253<<2)|0);
      HEAP32[$254>>2] = $237;
      $255 = ((($32) + ($241<<3)|0) + ($242<<2)|0);
      HEAP32[$255>>2] = $a6$06;
      $$pre46 = HEAP32[$220>>2]|0;
      $258 = $$pre46;
     }
     $256 = (($a6$06) + 1)|0;
     $257 = ($256>>>0)>($258>>>0);
     if ($257) {
      break;
     } else {
      $275 = $258;$CurrIndex$05 = $235;$a6$06 = $256;
     }
    }
    $$pre45 = HEAP32[$pocket$015>>2]|0;
    $260 = $$pre45;$262 = $258;
   }
   $259 = (($260) + -1)|0;
   $261 = ($259>>>0)>($262>>>0);
   if (!($261)) {
    $263 = HEAP32[$$pre56>>2]|0;
    $264 = HEAP32[$217>>2]|0;
    $a9$010 = $259;
    while(1) {
     $265 = (($a9$010) + 1)|0;
     $266 = (($263) + ($265<<2)|0);
     HEAP32[$266>>2] = $a9$010;
     $267 = (($264) + ($a9$010<<2)|0);
     HEAP32[$267>>2] = $265;
     $268 = HEAP32[$220>>2]|0;
     $269 = ($265>>>0)>($268>>>0);
     if ($269) {
      break;
     } else {
      $a9$010 = $265;
     }
    }
   }
   $pocket$0 = (($pocket$015) + 8|0);
   $218 = ($pocket$0>>>0)>($currentPocket$0$lcssa>>>0);
   if ($218) {
    break;
   } else {
    $$pn14$phi = $pocket$015;$pocket$015 = $pocket$0;$$pn14 = $$pn14$phi;
   }
  }
 }
 $270 = HEAP32[$$pre56>>2]|0;
 HEAP32[$270>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap9updatePPUEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx23PxsBroadPhaseContextSap11batchRemoveEv($this);
 $0 = (($this) + 256|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($0);
 $4 = (($this) + 296|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vi[$7 & 4095]($4);
 $8 = (($this) + 336|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$11 & 4095]($8);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap11batchRemoveEv($this) {
 $this = $this|0;
 var $$MinMinIndex$0 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre25 = 0, $$pre29 = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $Axis$021 = 0, $DestIndex$0$ph19 = 0, $MinMinIndex$0$lcssa = 0, $MinMinIndex$08 = 0, $ReadIndex$0$ph20 = 0, $ReadIndex$113 = 0, $bitmap = 0, $bitmapWords = 0, $exitcond = 0, $i$07 = 0, $i1$04 = 0, $i2$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 528|0;
 $bitmapWords = sp;
 $bitmap = sp + 516|0;
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 168|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 172|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$4>>2] = $7;
 $8 = (($this) + 84|0);
 $23 = $2;$Axis$021 = 0;
 while(1) {
  $18 = ((($this) + ($Axis$021<<2)|0) + 124|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($this) + ($Axis$021<<2)|0) + 136|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($23|0)==(0);
  if ($22) {
   $MinMinIndex$0$lcssa = -1;
  } else {
   $24 = ((($this) + ($Axis$021<<2)|0) + 112|0);
   $$pre = HEAP32[$8>>2]|0;
   $$pre25 = HEAP32[$24>>2]|0;
   $MinMinIndex$08 = -1;$i$07 = 0;
   while(1) {
    $25 = (($$pre) + ($i$07<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($$pre25) + ($26<<3)|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ((($$pre25) + ($26<<3)|0) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($21) + ($28<<2)|0);
    HEAP32[$31>>2] = 1073741821;
    $32 = (($21) + ($30<<2)|0);
    HEAP32[$32>>2] = 1073741821;
    $33 = ($28>>>0)<($MinMinIndex$08>>>0);
    $$MinMinIndex$0 = $33 ? $28 : $MinMinIndex$08;
    $34 = (($i$07) + 1)|0;
    $35 = HEAP32[$1>>2]|0;
    $36 = ($34>>>0)<($35>>>0);
    if ($36) {
     $MinMinIndex$08 = $$MinMinIndex$0;$i$07 = $34;
    } else {
     $MinMinIndex$0$lcssa = $$MinMinIndex$0;
     break;
    }
   }
  }
  $37 = HEAP32[$4>>2]|0;
  $38 = $37 << 1;
  $39 = (($38) + 2)|0;
  $40 = ($MinMinIndex$0$lcssa|0)==($39|0);
  L11: do {
   if (!($40)) {
    $41 = ((($this) + ($Axis$021<<2)|0) + 112|0);
    $DestIndex$0$ph19 = $MinMinIndex$0$lcssa;$ReadIndex$0$ph20 = $MinMinIndex$0$lcssa;
    while(1) {
     $$sum = (($ReadIndex$0$ph20) + 32)|0;
     $42 = (($21) + ($$sum<<2)|0);
     $43 = ($ReadIndex$0$ph20|0)==($39|0);
     if ($43) {
      break L11;
     } else {
      $ReadIndex$113 = $ReadIndex$0$ph20;
     }
     while(1) {
      $44 = (($21) + ($ReadIndex$113<<2)|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45|0)==(1073741821);
      if (!($46)) {
       break;
      }
      $$sum2 = (($ReadIndex$113) + 32)|0;
      $47 = (($21) + ($$sum2<<2)|0);
      $48 = (($ReadIndex$113) + 1)|0;
      $49 = ($48|0)==($39|0);
      if ($49) {
       break L11;
      } else {
       $ReadIndex$113 = $48;
      }
     }
     $50 = ($ReadIndex$113|0)==($DestIndex$0$ph19|0);
     if (!($50)) {
      $51 = (($19) + ($ReadIndex$113<<2)|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (($19) + ($DestIndex$0$ph19<<2)|0);
      HEAP32[$53>>2] = $52;
      $54 = HEAP32[$44>>2]|0;
      $55 = (($21) + ($DestIndex$0$ph19<<2)|0);
      HEAP32[$55>>2] = $54;
      $56 = $54 & -2;
      $57 = ($56|0)==(1073741822);
      if (!($57)) {
       $58 = $54 >>> 1;
       $59 = $54 & 1;
       $60 = HEAP32[$41>>2]|0;
       $61 = ((($60) + ($58<<3)|0) + ($59<<2)|0);
       HEAP32[$61>>2] = $DestIndex$0$ph19;
      }
     }
     $62 = (($DestIndex$0$ph19) + 1)|0;
     $63 = (($ReadIndex$113) + 1)|0;
     $64 = ($63|0)==($39|0);
     if ($64) {
      break;
     } else {
      $DestIndex$0$ph19 = $62;$ReadIndex$0$ph20 = $63;
     }
    }
   }
  } while(0);
  $65 = (($Axis$021) + 1)|0;
  $exitcond = ($65|0)==(3);
  $10 = HEAP32[$1>>2]|0;
  if ($exitcond) {
   break;
  } else {
   $23 = $10;$Axis$021 = $65;
  }
 }
 $9 = ($10|0)==(0);
 if (!($9)) {
  $11 = HEAP32[$8>>2]|0;
  $12 = (($this) + 112|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 116|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 120|0);
  $17 = HEAP32[$16>>2]|0;
  $i1$04 = 0;
  while(1) {
   $66 = (($11) + ($i1$04<<2)|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($13) + ($67<<3)|0);
   HEAP32[$68>>2] = 1073741821;
   $69 = ((($13) + ($67<<3)|0) + 4|0);
   HEAP32[$69>>2] = 1073741821;
   $70 = (($15) + ($67<<3)|0);
   HEAP32[$70>>2] = 1073741821;
   $71 = ((($15) + ($67<<3)|0) + 4|0);
   HEAP32[$71>>2] = 1073741821;
   $72 = (($17) + ($67<<3)|0);
   HEAP32[$72>>2] = 1073741821;
   $73 = ((($17) + ($67<<3)|0) + 4|0);
   HEAP32[$73>>2] = 1073741821;
   $74 = (($i1$04) + 1)|0;
   $75 = HEAP32[$1>>2]|0;
   $76 = ($74>>>0)<($75>>>0);
   if ($76) {
    $i1$04 = $74;
   } else {
    break;
   }
  }
 }
 $77 = (($this) + 108|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = $78 >>> 5;
 $80 = (($79) + 1)|0;
 $81 = (($bitmapWords) + 512|0);
 $82 = ($80>>>0)<(129);
 if ($82) {
  $$pre29 = $80 << 2;
  $$pre$phiZ2D = $$pre29;$85 = $bitmapWords;
 } else {
  $83 = $80 << 2;
  $84 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$83,484968,56)|0);
  $$pre$phiZ2D = $83;$85 = $84;
 }
 HEAP32[$81>>2] = $85;
 _memset(($85|0),0,($$pre$phiZ2D|0))|0;
 $86 = (($bitmap) + 4|0);
 $87 = HEAP32[$81>>2]|0;
 HEAP32[$bitmap>>2] = $87;
 $88 = $80 | -2147483648;
 HEAP32[$86>>2] = $88;
 $89 = HEAP32[$1>>2]|0;
 $90 = ($89|0)==(0);
 if (!($90)) {
  $91 = HEAP32[$8>>2]|0;
  $i2$03 = 0;
  while(1) {
   $92 = (($91) + ($i2$03<<2)|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = $93 & 31;
   $95 = 1 << $94;
   $96 = $93 >>> 5;
   $97 = (($87) + ($96<<2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = $98 | $95;
   HEAP32[$97>>2] = $99;
   $100 = (($i2$03) + 1)|0;
   $101 = HEAP32[$1>>2]|0;
   $102 = ($100>>>0)<($101>>>0);
   if ($102) {
    $i2$03 = $100;
   } else {
    break;
   }
  }
 }
 $103 = (($this) + 192|0);
 (__ZN5physx14SapPairManager11RemovePairsERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($103,$bitmap)|0);
 $104 = HEAP32[$1>>2]|0;
 $105 = (($5) - ($104))|0;
 HEAP32[$4>>2] = $105;
 $106 = (($this) + 80|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($105) - ($107))|0;
 HEAP32[$6>>2] = $108;
 $109 = HEAP32[$bitmap>>2]|0;
 $110 = ($109|0)==(0|0);
 if (!($110)) {
  $111 = HEAP32[$86>>2]|0;
  $112 = ($111|0)>(-1);
  if ($112) {
   $113 = (($bitmap) + 8|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($113,$109);
  }
 }
 $114 = HEAP32[$81>>2]|0;
 $115 = ($114|0)==($bitmapWords|0);
 if ($115) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$114);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap17performBoxPruningENS_2Gu4AxesE($this,$axes) {
 $this = $this|0;
 $axes = $axes|0;
 var $$pre = 0, $$pre$phi12Z2D = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $allNewBoxesStatics = 0, $allOldBoxesStatics = 0, $bitMapMem = 0, $bitmap = 0, $minPosListNewMem = 0, $minPosListOldMem = 0, $newBoxCount = 0, $newBoxesIndicesSortedMem = 0, $oldBoxCount = 0;
 var $oldBoxesIndicesSortedMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 203|0;
 $1 = sp + 202|0;
 $2 = sp + 204|0;
 $oldBoxesIndicesSortedMem = sp + 164|0;
 $newBoxesIndicesSortedMem = sp + 128|0;
 $oldBoxCount = sp + 88|0;
 $newBoxCount = sp + 84|0;
 $bitMapMem = sp + 48|0;
 $bitmap = sp + 36|0;
 $allNewBoxesStatics = sp + 200|0;
 $allOldBoxesStatics = sp + 201|0;
 $minPosListNewMem = sp;
 $minPosListOldMem = sp + 92|0;
 $3 = HEAP32[$axes>>2]|0;
 $4 = (($this) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 168|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) - ($5))|0;
 $9 = (($oldBoxesIndicesSortedMem) + 32|0);
 $10 = ($8>>>0)<(9);
 if ($10) {
  $13 = $oldBoxesIndicesSortedMem;
 } else {
  $11 = $8 << 2;
  $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$11,484968,56)|0);
  $13 = $12;
 }
 HEAP32[$9>>2] = $13;
 $14 = (($newBoxesIndicesSortedMem) + 32|0);
 $15 = ($5>>>0)<(9);
 if ($15) {
  $18 = $newBoxesIndicesSortedMem;$44 = $13;
 } else {
  $16 = $5 << 2;
  $17 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$16,484968,56)|0);
  $$pre = HEAP32[$9>>2]|0;
  $18 = $17;$44 = $$pre;
 }
 HEAP32[$14>>2] = $18;
 HEAP32[$oldBoxCount>>2] = 0;
 HEAP32[$newBoxCount>>2] = 0;
 $19 = (($this) + 108|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 << 1;
 $22 = (($21) + 31)|0;
 $23 = $22 >>> 5;
 $24 = (($bitMapMem) + 32|0);
 $25 = ($22>>>0)<(288);
 if ($25) {
  $$pre10 = $23 << 2;
  $$pre$phiZ2D = $$pre10;$28 = $bitMapMem;
 } else {
  $26 = $23 << 2;
  $27 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$26,484968,56)|0);
  $$pre$phiZ2D = $26;$28 = $27;
 }
 HEAP32[$24>>2] = $28;
 _memset(($28|0),0,($$pre$phiZ2D|0))|0;
 $29 = (($bitmap) + 4|0);
 HEAP32[$bitmap>>2] = $28;
 $30 = $23 | -2147483648;
 HEAP32[$29>>2] = $30;
 HEAP8[$allNewBoxesStatics>>0] = 0;
 HEAP8[$allOldBoxesStatics>>0] = 0;
 $31 = HEAP32[$4>>2]|0;
 $32 = (($this) + 76|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 112|0);
 $35 = (($this) + 104|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($this) + ($3<<2)|0) + 124|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ((($this) + ($3<<2)|0) + 136|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$6>>2]|0;
 $42 = $41 << 1;
 $43 = (($42) + 2)|0;
 __ZN5physx18ComputeSortedListsEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjjPKjPPNS_8SapBox1DES7_PjSB_jRKNS_2Gu4AxesESB_RjSB_SG_RbSH_($bitmap,0,$31,$33,$34,$36,$38,$40,$43,$axes,$18,$newBoxCount,$44,$oldBoxCount,$allNewBoxesStatics,$allOldBoxesStatics);
 $45 = HEAP8[$allNewBoxesStatics>>0]|0;
 $46 = ($45<<24>>24)==(0);
 if ($46) {
  label = 12;
 } else {
  $47 = HEAP8[$allOldBoxesStatics>>0]|0;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   label = 12;
  }
 }
 if ((label|0) == 12) {
  $49 = (($5) + 1)|0;
  $50 = (($minPosListNewMem) + 32|0);
  $51 = ($49>>>0)<(9);
  if ($51) {
   $54 = $minPosListNewMem;$57 = $45;
  } else {
   $52 = $49 << 2;
   $53 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$52,484968,56)|0);
   $$pre9 = HEAP8[$allNewBoxesStatics>>0]|0;
   $54 = $53;$57 = $$pre9;
  }
  HEAP32[$50>>2] = $54;
  $55 = HEAP32[$newBoxCount>>2]|0;
  $56 = ($57<<24>>24)!=(0);
  $58 = HEAP32[$35>>2]|0;
  $59 = (($this) + 192|0);
  $60 = (($this) + 180|0);
  $61 = (($this) + 184|0);
  $62 = (($this) + 188|0);
  __ZN5physx23performBoxPruningNewNewERKNS_2Gu4AxesEPKjjbPjPPNS_8SapBox1DES5_RNS_14SapPairManagerERS6_RjSD_($axes,$18,$55,$56,$54,$34,$58,$59,$60,$61,$62);
  $63 = ($7|0)==($5|0);
  if (!($63)) {
   $64 = (($minPosListOldMem) + 32|0);
   if ($10) {
    $$pre$phi12Z2D = $minPosListOldMem;$67 = $minPosListOldMem;
   } else {
    $65 = $8 << 2;
    $66 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$65,484968,56)|0);
    $$pre$phi12Z2D = $minPosListOldMem;$67 = $66;
   }
   HEAP32[$64>>2] = $67;
   $68 = HEAP32[$newBoxCount>>2]|0;
   $69 = HEAP32[$oldBoxCount>>2]|0;
   $70 = HEAP32[$35>>2]|0;
   __ZN5physx23performBoxPruningNewOldERKNS_2Gu4AxesEPKjjS5_jPjS6_PPNS_8SapBox1DES5_RNS_14SapPairManagerERS6_RjSD_($axes,$18,$68,$44,$69,$54,$67,$34,$70,$59,$60,$61,$62);
   $71 = HEAP32[$64>>2]|0;
   $72 = ($71|0)==($$pre$phi12Z2D|0);
   if (!($72)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$71);
   }
  }
  $73 = HEAP32[$50>>2]|0;
  $74 = ($73|0)==($minPosListNewMem|0);
  if (!($74)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$73);
  }
 }
 $75 = HEAP32[$bitmap>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  $77 = HEAP32[$29>>2]|0;
  $78 = ($77|0)>(-1);
  if ($78) {
   $79 = (($bitmap) + 8|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($79,$75);
  }
 }
 $80 = HEAP32[$24>>2]|0;
 $81 = ($80|0)==($bitMapMem|0);
 if (!($81)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$80);
 }
 $82 = HEAP32[$14>>2]|0;
 $83 = ($82|0)==($newBoxesIndicesSortedMem|0);
 if (!($83)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$82);
 }
 $84 = HEAP32[$9>>2]|0;
 $85 = ($84|0)==($oldBoxesIndicesSortedMem|0);
 if ($85) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$84);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsBroadPhaseContextSap21batchUpdateFewUpdatesEjRPNS_17PxcBroadPhasePairERjS4_($this,$Axis,$pairs,$pairsSize,$pairsCapacity) {
 $this = $this|0;
 $Axis = $Axis|0;
 $pairs = $pairs|0;
 $pairsSize = $pairsSize|0;
 $pairsCapacity = $pairsCapacity|0;
 var $$$i = 0, $$$i4 = 0, $$phi$trans$insert = 0, $$phi$trans$insert58 = 0, $$phi$trans$insert68 = 0, $$phi$trans$insert70 = 0, $$pn16 = 0, $$pn16$phi = 0, $$pre = 0, $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $$pre57 = 0, $$pre57$pre = 0, $$pre59 = 0, $$pre60 = 0, $$pre60$pre = 0, $$pre61 = 0, $$pre61$pre = 0, $$pre69 = 0;
 var $$pre71 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $CurrIndex$06 = 0;
 var $CurrentIndex$0 = 0, $CurrentIndex$1 = 0, $CurrentIndex$2 = 0, $a$038 = 0, $a1$027 = 0, $a12$05 = 0, $a13$07 = 0, $a16$011 = 0, $boxMinMax2D = 0, $currentPocket$0$lcssa = 0, $currentPocket$028 = 0, $currentPocket$1 = 0, $currentPocket$2 = 0, $currentPocket$3 = 0, $currentPocket$4 = 0, $exitcond = 0, $ind$0$lcssa = 0, $ind$039 = 0, $ind$146 = 0, $ind$2 = 0;
 var $ind$3 = 0, $ind2$0 = 0, $index$045 = 0, $maxNumPairs$0$lcssa = 0, $maxNumPairs$029 = 0, $maxNumPairs$1 = 0, $maxNumPairs$2 = 0, $maxNumPairs$3 = 0, $maxNumPairs$4 = 0, $maxNumPairs$5 = 0, $maxNumPairs$6 = 0, $maxNumPairs$7 = 0, $maxNumPairs$8 = 0, $maxNumPairs$9 = 0, $numPairs$0$lcssa = 0, $numPairs$030 = 0, $numPairs$1 = 0, $numPairs$2 = 0, $numPairs$3 = 0, $numPairs$4 = 0;
 var $numPairs$5 = 0, $numPairs$6 = 0, $numPairs$7 = 0, $or$cond$i = 0, $or$cond$i2 = 0, $or$cond1$i = 0, $or$cond1$i3 = 0, $pocket$0 = 0, $pocket$015 = 0, $pocket$017 = 0, $startIndex$0 = 0, $startIndex$1 = 0, $startIndex$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 25|0;
 $1 = sp + 24|0;
 $boxMinMax2D = sp;
 $2 = HEAP32[$pairsCapacity>>2]|0;
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 116|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$boxMinMax2D>>2] = $6;
 $7 = (($boxMinMax2D) + 4|0);
 $8 = (($this) + 120|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = (($boxMinMax2D) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = (($boxMinMax2D) + 12|0);
 $12 = (($this) + 112|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$11>>2] = $13;
 $14 = (($boxMinMax2D) + 16|0);
 HEAP32[$14>>2] = $13;
 $15 = (($boxMinMax2D) + 20|0);
 HEAP32[$15>>2] = $6;
 $16 = (($this) + 104|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($this) + ($Axis<<2)|0) + 112|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($this) + ($Axis<<2)|0) + 124|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($this) + ($Axis<<2)|0) + 136|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $Axis << 1;
 $25 = (($boxMinMax2D) + ($24<<2)|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $24 | 1;
 $28 = (($boxMinMax2D) + ($27<<2)|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 148|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 168|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 << 1;
 $35 = $34 | 1;
 $36 = (($23) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & -2;
 $39 = ($38|0)==(1073741822);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 96|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41>>>0)<(512);
 L4: do {
  if ($42) {
   $45 = ($41|0)==(0);
   if ($45) {
    $$phi$trans$insert68 = (($this) + 152|0);
    $$pre69 = HEAP32[$$phi$trans$insert68>>2]|0;
    $72 = $$pre69;$ind$0$lcssa = 0;
   } else {
    $46 = (($this) + 92|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($Axis) + 3)|0;
    $49 = (($this) + 152|0);
    $50 = HEAP32[$49>>2]|0;
    $a$038 = 0;$ind$039 = 0;
    while(1) {
     $51 = (($47) + ($a$038<<2)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ((($4) + (($52*24)|0)|0) + ($Axis<<2)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ((($4) + (($52*24)|0)|0) + ($48<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($19) + ($52<<3)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($21) + ($58<<2)|0);
     HEAP32[$59>>2] = $54;
     $60 = ((($19) + ($52<<3)|0) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($21) + ($61<<2)|0);
     HEAP32[$62>>2] = $56;
     $63 = HEAP32[$57>>2]|0;
     $64 = $ind$039 | 1;
     $65 = (($50) + ($ind$039<<2)|0);
     HEAP32[$65>>2] = $63;
     $66 = HEAP32[$60>>2]|0;
     $67 = (($ind$039) + 2)|0;
     $68 = (($50) + ($64<<2)|0);
     HEAP32[$68>>2] = $66;
     $69 = (($a$038) + 1)|0;
     $70 = HEAP32[$40>>2]|0;
     $71 = ($69>>>0)<($70>>>0);
     if ($71) {
      $a$038 = $69;$ind$039 = $67;
     } else {
      $72 = $50;$ind$0$lcssa = $67;
      break;
     }
    }
   }
   __ZN5physx6shdfnd4sortIjNS0_4LessIjEENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($72,$ind$0$lcssa,$0,$1);
   $ind$3 = $ind$0$lcssa;
  } else {
   $43 = ($35|0)==(1);
   if ($43) {
    $ind$3 = 0;
   } else {
    $44 = (($this) + 152|0);
    $74 = $37;$ind$146 = 0;$index$045 = 1;
    while(1) {
     $73 = $74 & -2;
     $75 = ($73|0)==(1073741822);
     if ($75) {
      $ind$3 = $ind$146;
      break L4;
     }
     $76 = $74 >>> 1;
     $77 = (($31) + ($76)|0);
     $78 = HEAP8[$77>>0]|0;
     $79 = ($78<<24>>24)==(0);
     if ($79) {
      $ind$2 = $ind$146;
     } else {
      $80 = $74 & 1;
      $81 = (0 - ($80))|0;
      $82 = $81 & 3;
      $83 = (($82) + ($Axis))|0;
      $84 = ((($4) + (($76*24)|0)|0) + ($83<<2)|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = (($21) + ($index$045<<2)|0);
      HEAP32[$86>>2] = $85;
      $87 = (($ind$146) + 1)|0;
      $88 = HEAP32[$44>>2]|0;
      $89 = (($88) + ($ind$146<<2)|0);
      HEAP32[$89>>2] = $index$045;
      $ind$2 = $87;
     }
     $90 = (($index$045) + 1)|0;
     $91 = ($90>>>0)<($35>>>0);
     if (!($91)) {
      $ind$3 = $ind$2;
      break L4;
     }
     $$phi$trans$insert70 = (($23) + ($90<<2)|0);
     $$pre71 = HEAP32[$$phi$trans$insert70>>2]|0;
     $74 = $$pre71;$ind$146 = $ind$2;$index$045 = $90;
    }
   }
  }
 } while(0);
 $92 = (($this) + 156|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($93) + 4|0);
 HEAP32[$94>>2] = 0;
 HEAP32[$93>>2] = 0;
 $95 = ($ind$3|0)==(0);
 if ($95) {
  $255 = $93;$currentPocket$0$lcssa = $93;$maxNumPairs$0$lcssa = $2;$numPairs$0$lcssa = 0;
 } else {
  $96 = (($this) + 152|0);
  $97 = (($Axis) + 3)|0;
  $98 = (($this) + 164|0);
  $99 = (($this) + 160|0);
  $$pre57$pre = HEAP32[$98>>2]|0;
  $$pre57 = $$pre57$pre;$311 = $93;$a1$027 = 0;$currentPocket$028 = $93;$maxNumPairs$029 = $2;$numPairs$030 = 0;
  while(1) {
   $100 = HEAP32[$96>>2]|0;
   $101 = (($100) + ($a1$027<<2)|0);
   $102 = HEAP32[$101>>2]|0;
   $$phi$trans$insert = (($23) + ($102<<2)|0);
   $$pre56 = HEAP32[$$phi$trans$insert>>2]|0;
   $$phi$trans$insert58 = (($$pre57) + ($102<<2)|0);
   $$pre59 = HEAP32[$$phi$trans$insert58>>2]|0;
   $104 = $$pre56;$110 = $$pre59;$312 = $$pre57;$313 = $311;$currentPocket$1 = $currentPocket$028;$ind2$0 = $102;$maxNumPairs$1 = $maxNumPairs$029;$numPairs$1 = $numPairs$030;
   while(1) {
    $103 = $104 >>> 1;
    $105 = (($21) + ($ind2$0<<2)|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ((($4) + (($103*24)|0)|0) + ($97<<2)|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = (($21) + ($110<<2)|0);
    $111 = HEAP32[$109>>2]|0;
    $112 = ($111>>>0)>($106>>>0);
    if ($112) {
     $113 = (($17) + ($103<<2)|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = $104 & 1;
     $116 = ($115|0)==(0);
     $117 = (($26) + ($103<<3)|0);
     $118 = ((($26) + ($103<<3)|0) + 4|0);
     $119 = (($29) + ($103<<3)|0);
     $120 = ((($29) + ($103<<3)|0) + 4|0);
     if ($116) {
      $315 = $312;$CurrentIndex$0 = $110;$maxNumPairs$2 = $maxNumPairs$1;$numPairs$2 = $numPairs$1;$startIndex$0 = $ind2$0;
      while(1) {
       $121 = (($23) + ($CurrentIndex$0<<2)|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = $122 & 1;
       $124 = ($123|0)==(0);
       if ($124) {
        $165 = $315;$maxNumPairs$4 = $maxNumPairs$2;$numPairs$3 = $numPairs$2;
       } else {
        $125 = $122 >>> 1;
        $126 = (($19) + ($125<<3)|0);
        $127 = HEAP32[$126>>2]|0;
        $128 = (($21) + ($127<<2)|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = ($129>>>0)<($108>>>0);
        if ($130) {
         $131 = HEAP32[$117>>2]|0;
         $132 = HEAP32[$118>>2]|0;
         $133 = HEAP32[$119>>2]|0;
         $134 = HEAP32[$120>>2]|0;
         $135 = (($26) + ($125<<3)|0);
         $136 = HEAP32[$135>>2]|0;
         $137 = ((($26) + ($125<<3)|0) + 4|0);
         $138 = HEAP32[$137>>2]|0;
         $139 = (($29) + ($125<<3)|0);
         $140 = HEAP32[$139>>2]|0;
         $141 = ((($29) + ($125<<3)|0) + 4|0);
         $142 = HEAP32[$141>>2]|0;
         $143 = ($132>>>0)>($136>>>0);
         $144 = ($138>>>0)>($131>>>0);
         $or$cond$i2 = $143 & $144;
         $145 = ($134>>>0)>($140>>>0);
         $or$cond1$i3 = $or$cond$i2 & $145;
         $146 = ($142>>>0)>($133>>>0);
         $$$i4 = $or$cond1$i3 & $146;
         if ($$$i4) {
          $147 = (($17) + ($125<<2)|0);
          $148 = HEAP32[$147>>2]|0;
          $149 = ($114|0)==($148|0);
          if ($149) {
           $165 = $315;$maxNumPairs$4 = $maxNumPairs$2;$numPairs$3 = $numPairs$2;
          } else {
           $150 = ($numPairs$2|0)==($maxNumPairs$2|0);
           if ($150) {
            $151 = $maxNumPairs$2 << 1;
            $152 = HEAP32[$pairs>>2]|0;
            $153 = $maxNumPairs$2 << 4;
            $154 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$153,484600,1503)|0);
            $155 = $maxNumPairs$2 << 3;
            _memcpy(($154|0),($152|0),($155|0))|0;
            __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$152);
            HEAP32[$pairs>>2] = $154;
            $$pre61$pre = HEAP32[$98>>2]|0;
            $$pre61 = $$pre61$pre;$maxNumPairs$3 = $151;
           } else {
            $$pre61 = $315;$maxNumPairs$3 = $maxNumPairs$2;
           }
           $156 = ($103>>>0)<($125>>>0);
           $157 = $156 ? $125 : $103;
           $158 = HEAP32[$pairs>>2]|0;
           $159 = (($158) + ($numPairs$2<<3)|0);
           HEAP32[$159>>2] = $157;
           $160 = $156 ? $103 : $125;
           $161 = ((($158) + ($numPairs$2<<3)|0) + 4|0);
           HEAP32[$161>>2] = $160;
           $162 = (($numPairs$2) + 1)|0;
           $165 = $$pre61;$maxNumPairs$4 = $maxNumPairs$3;$numPairs$3 = $162;
          }
         } else {
          $165 = $315;$maxNumPairs$4 = $maxNumPairs$2;$numPairs$3 = $numPairs$2;
         }
        } else {
         $165 = $315;$maxNumPairs$4 = $maxNumPairs$2;$numPairs$3 = $numPairs$2;
        }
       }
       $163 = (($startIndex$0) + -1)|0;
       $164 = (($165) + ($CurrentIndex$0<<2)|0);
       $166 = HEAP32[$164>>2]|0;
       $167 = (($21) + ($166<<2)|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = ($106>>>0)<($168>>>0);
       if ($169) {
        $315 = $165;$CurrentIndex$0 = $166;$maxNumPairs$2 = $maxNumPairs$4;$numPairs$2 = $numPairs$3;$startIndex$0 = $163;
       } else {
        $218 = $165;$CurrentIndex$2 = $166;$maxNumPairs$8 = $maxNumPairs$4;$numPairs$6 = $numPairs$3;$startIndex$2 = $163;
        break;
       }
      }
     } else {
      $316 = $312;$CurrentIndex$1 = $110;$maxNumPairs$5 = $maxNumPairs$1;$numPairs$4 = $numPairs$1;$startIndex$1 = $ind2$0;
      while(1) {
       $170 = (($23) + ($CurrentIndex$1<<2)|0);
       $171 = HEAP32[$170>>2]|0;
       $172 = $171 & 1;
       $173 = ($172|0)==(0);
       if ($173) {
        $174 = $171 >>> 1;
        $175 = HEAP32[$117>>2]|0;
        $176 = HEAP32[$118>>2]|0;
        $177 = HEAP32[$119>>2]|0;
        $178 = HEAP32[$120>>2]|0;
        $179 = (($26) + ($174<<3)|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = ((($26) + ($174<<3)|0) + 4|0);
        $182 = HEAP32[$181>>2]|0;
        $183 = (($29) + ($174<<3)|0);
        $184 = HEAP32[$183>>2]|0;
        $185 = ((($29) + ($174<<3)|0) + 4|0);
        $186 = HEAP32[$185>>2]|0;
        $187 = ($176>>>0)>($180>>>0);
        $188 = ($182>>>0)>($175>>>0);
        $or$cond$i = $187 & $188;
        $189 = ($178>>>0)>($184>>>0);
        $or$cond1$i = $or$cond$i & $189;
        $190 = ($186>>>0)>($177>>>0);
        $$$i = $or$cond1$i & $190;
        if ($$$i) {
         $191 = (($17) + ($174<<2)|0);
         $192 = HEAP32[$191>>2]|0;
         $193 = ($114|0)==($192|0);
         if ($193) {
          $209 = $316;$maxNumPairs$7 = $maxNumPairs$5;$numPairs$5 = $numPairs$4;
         } else {
          $194 = ($numPairs$4|0)==($maxNumPairs$5|0);
          if ($194) {
           $195 = $maxNumPairs$5 << 1;
           $196 = HEAP32[$pairs>>2]|0;
           $197 = $maxNumPairs$5 << 4;
           $198 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$197,484600,1503)|0);
           $199 = $maxNumPairs$5 << 3;
           _memcpy(($198|0),($196|0),($199|0))|0;
           __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$196);
           HEAP32[$pairs>>2] = $198;
           $$pre60$pre = HEAP32[$98>>2]|0;
           $$pre60 = $$pre60$pre;$maxNumPairs$6 = $195;
          } else {
           $$pre60 = $316;$maxNumPairs$6 = $maxNumPairs$5;
          }
          $200 = ($103>>>0)<($174>>>0);
          $201 = $200 ? $103 : $174;
          $202 = HEAP32[$pairs>>2]|0;
          $203 = (($202) + ($numPairs$4<<3)|0);
          HEAP32[$203>>2] = $201;
          $204 = $200 ? $174 : $103;
          $205 = ((($202) + ($numPairs$4<<3)|0) + 4|0);
          HEAP32[$205>>2] = $204;
          $206 = (($numPairs$4) + 1)|0;
          $209 = $$pre60;$maxNumPairs$7 = $maxNumPairs$6;$numPairs$5 = $206;
         }
        } else {
         $209 = $316;$maxNumPairs$7 = $maxNumPairs$5;$numPairs$5 = $numPairs$4;
        }
       } else {
        $209 = $316;$maxNumPairs$7 = $maxNumPairs$5;$numPairs$5 = $numPairs$4;
       }
       $207 = (($startIndex$1) + -1)|0;
       $208 = (($209) + ($CurrentIndex$1<<2)|0);
       $210 = HEAP32[$208>>2]|0;
       $211 = (($21) + ($210<<2)|0);
       $212 = HEAP32[$211>>2]|0;
       $213 = ($106>>>0)<($212>>>0);
       if ($213) {
        $316 = $209;$CurrentIndex$1 = $210;$maxNumPairs$5 = $maxNumPairs$7;$numPairs$4 = $numPairs$5;$startIndex$1 = $207;
       } else {
        $218 = $209;$CurrentIndex$2 = $210;$maxNumPairs$8 = $maxNumPairs$7;$numPairs$6 = $numPairs$5;$startIndex$2 = $207;
        break;
       }
      }
     }
     $214 = HEAP32[$99>>2]|0;
     $215 = (($214) + ($ind2$0<<2)|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = (($218) + ($ind2$0<<2)|0);
     $219 = HEAP32[$217>>2]|0;
     $220 = (($214) + ($CurrentIndex$2<<2)|0);
     $221 = HEAP32[$220>>2]|0;
     $222 = (($214) + ($219<<2)|0);
     HEAP32[$222>>2] = $216;
     $223 = (($218) + ($216<<2)|0);
     HEAP32[$223>>2] = $219;
     HEAP32[$215>>2] = $221;
     HEAP32[$217>>2] = $CurrentIndex$2;
     $224 = (($218) + ($221<<2)|0);
     HEAP32[$224>>2] = $ind2$0;
     HEAP32[$220>>2] = $ind2$0;
     $currentPocket$2 = $currentPocket$1;
     while(1) {
      $225 = HEAP32[$currentPocket$2>>2]|0;
      $226 = ($startIndex$2>>>0)<($225>>>0);
      $227 = (($currentPocket$2) + -8|0);
      if ($226) {
       $currentPocket$2 = $227;
      } else {
       break;
      }
     }
     $228 = HEAP32[$92>>2]|0;
     $229 = ($currentPocket$2|0)==($228|0);
     if ($229) {
      label = 39;
     } else {
      $230 = (($currentPocket$2) + 4|0);
      $231 = HEAP32[$230>>2]|0;
      $232 = (($231) + 1)|0;
      $233 = ($startIndex$2>>>0)>($232>>>0);
      if ($233) {
       label = 39;
      } else {
       $currentPocket$3 = $currentPocket$2;
      }
     }
     if ((label|0) == 39) {
      label = 0;
      $234 = (($currentPocket$2) + 8|0);
      HEAP32[$234>>2] = $startIndex$2;
      $currentPocket$3 = $234;
     }
     $235 = (($currentPocket$3) + 4|0);
     HEAP32[$235>>2] = $ind2$0;
     $240 = $218;$314 = $228;$currentPocket$4 = $currentPocket$3;$maxNumPairs$9 = $maxNumPairs$8;$numPairs$7 = $numPairs$6;
    } else {
     $240 = $312;$314 = $313;$currentPocket$4 = $currentPocket$1;$maxNumPairs$9 = $maxNumPairs$1;$numPairs$7 = $numPairs$1;
    }
    $236 = (($ind2$0) + 1)|0;
    $237 = (($23) + ($236<<2)|0);
    $238 = HEAP32[$237>>2]|0;
    $239 = (($240) + ($236<<2)|0);
    $241 = HEAP32[$239>>2]|0;
    $242 = (($23) + ($241<<2)|0);
    $243 = HEAP32[$242>>2]|0;
    $244 = $238 & -2;
    $245 = ($244|0)==(1073741822);
    if ($245) {
     break;
    }
    $246 = $238 >>> 1;
    $247 = (($31) + ($246)|0);
    $248 = HEAP8[$247>>0]|0;
    $249 = ($248<<24>>24)==(0);
    if (!($249)) {
     break;
    }
    $250 = $243 >>> 1;
    $251 = (($31) + ($250)|0);
    $252 = HEAP8[$251>>0]|0;
    $253 = ($252<<24>>24)==(0);
    if ($253) {
     break;
    } else {
     $104 = $238;$110 = $241;$312 = $240;$313 = $314;$currentPocket$1 = $currentPocket$4;$ind2$0 = $236;$maxNumPairs$1 = $maxNumPairs$9;$numPairs$1 = $numPairs$7;
    }
   }
   $254 = (($a1$027) + 1)|0;
   $exitcond = ($254|0)==($ind$3|0);
   if ($exitcond) {
    $255 = $314;$currentPocket$0$lcssa = $currentPocket$4;$maxNumPairs$0$lcssa = $maxNumPairs$9;$numPairs$0$lcssa = $numPairs$7;
    break;
   } else {
    $$pre57 = $240;$311 = $314;$a1$027 = $254;$currentPocket$028 = $currentPocket$4;$maxNumPairs$029 = $maxNumPairs$9;$numPairs$030 = $numPairs$7;
   }
  }
 }
 HEAP32[$pairsSize>>2] = $numPairs$0$lcssa;
 HEAP32[$pairsCapacity>>2] = $maxNumPairs$0$lcssa;
 $pocket$015 = (($255) + 8|0);
 $256 = ($pocket$015>>>0)>($currentPocket$0$lcssa>>>0);
 if ($256) {
  STACKTOP = sp;return;
 }
 $257 = (($this) + 164|0);
 $258 = (($this) + 160|0);
 $$pn16 = $255;$pocket$017 = $pocket$015;
 while(1) {
  $260 = HEAP32[$pocket$017>>2]|0;
  $261 = (($$pn16) + 12|0);
  $262 = HEAP32[$261>>2]|0;
  $263 = ($260>>>0)>($262>>>0);
  if ($263) {
   $270 = $260;$271 = $262;
  } else {
   $264 = HEAP32[$257>>2]|0;
   $a12$05 = $260;
   while(1) {
    $265 = (($264) + ($a12$05<<2)|0);
    HEAP32[$265>>2] = $a12$05;
    $266 = (($a12$05) + 1)|0;
    $267 = HEAP32[$261>>2]|0;
    $268 = ($266>>>0)>($267>>>0);
    if ($268) {
     break;
    } else {
     $a12$05 = $266;
    }
   }
   $$pre = HEAP32[$pocket$017>>2]|0;
   $270 = $$pre;$271 = $267;
  }
  $269 = ($270>>>0)>($271>>>0);
  if ($269) {
   $301 = $270;$303 = $271;
  } else {
   $272 = (($270) + -1)|0;
   $273 = HEAP32[$258>>2]|0;
   $274 = HEAP32[$257>>2]|0;
   $317 = $271;$CurrIndex$06 = $272;$a13$07 = $270;
   while(1) {
    $275 = (($273) + ($CurrIndex$06<<2)|0);
    $276 = HEAP32[$275>>2]|0;
    $277 = (($274) + ($276<<2)|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = ($276|0)==($a13$07|0);
    if ($279) {
     $299 = $317;
    } else {
     $280 = (($23) + ($278<<2)|0);
     $281 = HEAP32[$280>>2]|0;
     $282 = $281 >>> 1;
     $283 = $281 & 1;
     $284 = (($21) + ($a13$07<<2)|0);
     $285 = HEAP32[$284>>2]|0;
     $286 = (($23) + ($a13$07<<2)|0);
     $287 = HEAP32[$286>>2]|0;
     $288 = (($21) + ($278<<2)|0);
     $289 = HEAP32[$288>>2]|0;
     HEAP32[$284>>2] = $289;
     $290 = HEAP32[$280>>2]|0;
     HEAP32[$286>>2] = $290;
     HEAP32[$288>>2] = $285;
     HEAP32[$280>>2] = $287;
     $291 = (($274) + ($a13$07<<2)|0);
     $292 = HEAP32[$291>>2]|0;
     $293 = (($274) + ($278<<2)|0);
     HEAP32[$293>>2] = $292;
     $294 = HEAP32[$291>>2]|0;
     $295 = (($274) + ($294<<2)|0);
     HEAP32[$295>>2] = $278;
     $296 = ((($19) + ($282<<3)|0) + ($283<<2)|0);
     HEAP32[$296>>2] = $a13$07;
     $$pre55 = HEAP32[$261>>2]|0;
     $299 = $$pre55;
    }
    $297 = (($a13$07) + 1)|0;
    $298 = ($297>>>0)>($299>>>0);
    if ($298) {
     break;
    } else {
     $317 = $299;$CurrIndex$06 = $276;$a13$07 = $297;
    }
   }
   $$pre54 = HEAP32[$pocket$017>>2]|0;
   $301 = $$pre54;$303 = $299;
  }
  $300 = (($301) + -1)|0;
  $302 = ($300>>>0)>($303>>>0);
  if (!($302)) {
   $304 = HEAP32[$257>>2]|0;
   $305 = HEAP32[$258>>2]|0;
   $a16$011 = $300;
   while(1) {
    $306 = (($a16$011) + 1)|0;
    $307 = (($304) + ($306<<2)|0);
    HEAP32[$307>>2] = $a16$011;
    $308 = (($305) + ($a16$011<<2)|0);
    HEAP32[$308>>2] = $306;
    $309 = HEAP32[$261>>2]|0;
    $310 = ($306>>>0)>($309>>>0);
    if ($310) {
     break;
    } else {
     $a16$011 = $306;
    }
   }
  }
  $pocket$0 = (($pocket$017) + 8|0);
  $259 = ($pocket$0>>>0)>($currentPocket$0$lcssa>>>0);
  if ($259) {
   break;
  } else {
   $$pn16$phi = $pocket$017;$pocket$017 = $pocket$0;$$pn16 = $$pn16$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx29BroadPhaseBatchUpdateWorkTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx29BroadPhaseBatchUpdateWorkTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (485040|0);
}
function __ZNK5physx16PxBroadPhaseBase7getCapsERNS_16PxBroadPhaseCapsE($this,$caps) {
 $this = $this|0;
 $caps = $caps|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$caps>>2] = 0;
 $0 = (($caps) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($caps) + 8|0);
 HEAP8[$1>>0] = 0;
 STACKTOP = sp;return 1;
}
function __ZNK5physx16PxBroadPhaseBase12getNbRegionsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx16PxBroadPhaseBase10getRegionsEPNS_22PxBroadPhaseRegionInfoEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx16PxBroadPhaseBase9addRegionERKNS_18PxBroadPhaseRegionEb($this,$region,$populateRegion) {
 $this = $this|0;
 $region = $region|0;
 $populateRegion = $populateRegion|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __ZN5physx16PxBroadPhaseBase12removeRegionEj($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx16PxBroadPhaseBase24getNumOutOfBoundsObjectsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx16PxBroadPhaseBase21getOutOfBoundsObjectsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK5physx23PxsBroadPhaseContextSap7getTypeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx23PxsBroadPhaseContextSap18getNumCreatedPairsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 236|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx23PxsBroadPhaseContextSap15getCreatedPairsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 232|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx23PxsBroadPhaseContextSap18getNumDeletedPairsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 248|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx23PxsBroadPhaseContextSap15getDeletedPairsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd4sortIjNS0_4LessIjEENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 484864 : 484832;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,484744,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 484864 : 484832;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,484744,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx21SapPostUpdateWorkTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx21SapPostUpdateWorkTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (485160|0);
}
function __ZN5physx17SapUpdateWorkTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx17SapUpdateWorkTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (485184|0);
}
function __ZN5physx14SapPairManagerC2Ev($this) {
 $this = $this|0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$this+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx14SapPairManagerD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx14SapPairManager4initEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = $size << 2;
 $5 = (($4) + 15)|0;
 $6 = $5 & -16;
 $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$6,485208,105)|0);
 HEAP32[$this>>2] = $7;
 $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$6,485208,106)|0);
 $9 = (($this) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = $size << 3;
 $11 = (($10) + 15)|0;
 $12 = $11 & -16;
 $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$12,485208,107)|0);
 $14 = (($this) + 20|0);
 HEAP32[$14>>2] = $13;
 $15 = (($size) + 15)|0;
 $16 = $15 & -16;
 $17 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$16,485208,108)|0);
 $18 = (($this) + 24|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 12|0);
 HEAP32[$19>>2] = $size;
 $20 = (($this) + 16|0);
 HEAP32[$20>>2] = $size;
 $21 = (($this) + 32|0);
 HEAP32[$21>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx14SapPairManager7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$4);
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$6);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$8);
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$10);
 dest=$this+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZNK5physx14SapPairManager8FindPairEjj($this,$id0,$id1) {
 $this = $this|0;
 $id0 = $id0|0;
 $id1 = $id1|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $Offset$0 = 0, $Offset$04 = 0, $Offset$06 = 0;
 var $cond = 0, $cond5 = 0, $id0$id1 = 0, $id1$id0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($id0>>>0)>($id1>>>0);
 $id1$id0 = $3 ? $id1 : $id0;
 $id0$id1 = $3 ? $id0 : $id1;
 $4 = $id0$id1 << 16;
 $5 = $4 | $id1$id0;
 $6 = $5 << 15;
 $7 = $6 ^ -1;
 $8 = (($5) + ($7))|0;
 $9 = $8 >> 10;
 $10 = $9 ^ $8;
 $11 = ($10*9)|0;
 $12 = $11 >> 6;
 $13 = $12 ^ $11;
 $14 = $13 << 11;
 $15 = $14 ^ -1;
 $16 = (($13) + ($15))|0;
 $17 = $16 >> 16;
 $18 = $17 ^ $16;
 $19 = (($this) + 36|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & $18;
 $22 = HEAP32[$this>>2]|0;
 $23 = (($22) + ($21<<2)|0);
 $Offset$04 = HEAP32[$23>>2]|0;
 $cond5 = ($Offset$04|0)==(1073741823);
 if ($cond5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = (($this) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 4|0);
 $Offset$06 = $Offset$04;
 while(1) {
  $27 = (($25) + ($Offset$06<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($id1$id0|0);
  if ($29) {
   $30 = ((($25) + ($Offset$06<<3)|0) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($id0$id1|0);
   if ($32) {
    break;
   }
  }
  $33 = HEAP32[$26>>2]|0;
  $34 = (($33) + ($Offset$06<<2)|0);
  $Offset$0 = HEAP32[$34>>2]|0;
  $cond = ($Offset$0|0)==(1073741823);
  if ($cond) {
   $$0 = 0;
   label = 8;
   break;
  } else {
   $Offset$06 = $Offset$0;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 $35 = (($25) + ($Offset$06<<3)|0);
 $$0 = $35;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx14SapPairManager7AddPairEjjh($this,$id0,$id1,$state) {
 $this = $this|0;
 $id0 = $id0|0;
 $id1 = $id1|0;
 $state = $state|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $HashValue$0 = 0, $Offset$0$i = 0;
 var $Offset$03$i = 0, $Offset$05$i = 0, $cond$i = 0, $cond4$i = 0, $id0$id1 = 0, $id1$id0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1073741823);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($id0>>>0)>($id1>>>0);
 $id1$id0 = $3 ? $id1 : $id0;
 $id0$id1 = $3 ? $id0 : $id1;
 $4 = $id0$id1 << 16;
 $5 = $4 | $id1$id0;
 $6 = $5 << 15;
 $7 = $6 ^ -1;
 $8 = (($5) + ($7))|0;
 $9 = $8 >> 10;
 $10 = $9 ^ $8;
 $11 = ($10*9)|0;
 $12 = $11 >> 6;
 $13 = $12 ^ $11;
 $14 = $13 << 11;
 $15 = $14 ^ -1;
 $16 = (($13) + ($15))|0;
 $17 = $16 >> 16;
 $18 = $17 ^ $16;
 $19 = (($this) + 36|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & $18;
 $22 = (($this) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 L4: do {
  if (!($24)) {
   $25 = HEAP32[$this>>2]|0;
   $26 = (($25) + ($21<<2)|0);
   $Offset$03$i = HEAP32[$26>>2]|0;
   $cond4$i = ($Offset$03$i|0)==(1073741823);
   if (!($cond4$i)) {
    $27 = (($this) + 20|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($this) + 4|0);
    $Offset$05$i = $Offset$03$i;
    while(1) {
     $30 = (($28) + ($Offset$05$i<<3)|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==($id1$id0|0);
     if ($32) {
      $33 = ((($28) + ($Offset$05$i<<3)|0) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==($id0$id1|0);
      if ($35) {
       break;
      }
     }
     $36 = HEAP32[$29>>2]|0;
     $37 = (($36) + ($Offset$05$i<<2)|0);
     $Offset$0$i = HEAP32[$37>>2]|0;
     $cond$i = ($Offset$0$i|0)==(1073741823);
     if ($cond$i) {
      break L4;
     } else {
      $Offset$05$i = $Offset$0$i;
     }
    }
    $38 = (($28) + ($Offset$05$i<<3)|0);
    $39 = ($38|0)==(0|0);
    if (!($39)) {
     $$0 = $38;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $40 = ($1>>>0)<($23>>>0);
 if ($40) {
  $61 = $1;$HashValue$0 = $21;
 } else {
  $41 = (($1) + 1)|0;
  $42 = $41 >>> 1;
  $43 = $42 | $41;
  $44 = $43 >>> 2;
  $45 = $44 | $43;
  $46 = $45 >>> 4;
  $47 = $46 | $45;
  $48 = $47 >>> 8;
  $49 = $48 | $47;
  $50 = $49 >>> 16;
  $51 = $50 | $49;
  $52 = (($51) + 1)|0;
  HEAP32[$22>>2] = $52;
  HEAP32[$19>>2] = $51;
  $53 = (($this) + 12|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($52>>>0)>($54>>>0);
  __ZN5physx14SapPairManager12reallocPairsEb($this,$55);
  $56 = HEAP32[$19>>2]|0;
  $57 = $56 & $18;
  $$pre = HEAP32[$0>>2]|0;
  $61 = $$pre;$HashValue$0 = $57;
 }
 $58 = (($this) + 20|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + ($61<<3)|0);
 HEAP32[$60>>2] = $id1$id0;
 $62 = ((($59) + ($61<<3)|0) + 4|0);
 HEAP32[$62>>2] = $id0$id1;
 $63 = HEAP32[$0>>2]|0;
 $64 = (($this) + 24|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + ($63)|0);
 HEAP8[$66>>0] = $state;
 $67 = HEAP32[$this>>2]|0;
 $68 = (($67) + ($HashValue$0<<2)|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = HEAP32[$0>>2]|0;
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + ($70<<2)|0);
 HEAP32[$73>>2] = $69;
 $74 = HEAP32[$0>>2]|0;
 $75 = (($74) + 1)|0;
 HEAP32[$0>>2] = $75;
 HEAP32[$68>>2] = $74;
 $$0 = $60;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx14SapPairManager12reallocPairsEb($this,$allocRequired) {
 $this = $this|0;
 $allocRequired = $allocRequired|0;
 var $$lcssa = 0, $$pr = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $i$02 = 0, $i1$01 = 0, $i2$07 = 0, $i3$04 = 0, $phitmp = 0, $phitmp11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 7|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = sp + 4|0;
 $6 = sp + 5|0;
 $7 = sp + 6|0;
 if (!($allocRequired)) {
  $8 = (($this) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if (!($10)) {
   $11 = HEAP32[$this>>2]|0;
   $i2$07 = 0;
   while(1) {
    $85 = (($11) + ($i2$07<<2)|0);
    HEAP32[$85>>2] = 1073741823;
    $86 = (($i2$07) + 1)|0;
    $87 = HEAP32[$8>>2]|0;
    $88 = ($86>>>0)<($87>>>0);
    if ($88) {
     $i2$07 = $86;
    } else {
     break;
    }
   }
  }
  $76 = (($this) + 28|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ($77|0)==(0);
  if ($78) {
   STACKTOP = sp;return;
  }
  $79 = (($this) + 20|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($this) + 36|0);
  $82 = HEAP32[$this>>2]|0;
  $83 = (($this) + 4|0);
  $84 = HEAP32[$83>>2]|0;
  $i3$04 = 0;
  while(1) {
   $89 = (($80) + ($i3$04<<3)|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ((($80) + ($i3$04<<3)|0) + 4|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = $92 << 16;
   $94 = $93 | $90;
   $95 = $94 << 15;
   $96 = $95 ^ -1;
   $97 = (($94) + ($96))|0;
   $98 = $97 >> 10;
   $99 = $98 ^ $97;
   $100 = ($99*9)|0;
   $101 = $100 >> 6;
   $102 = $101 ^ $100;
   $103 = $102 << 11;
   $104 = $103 ^ -1;
   $105 = (($102) + ($104))|0;
   $106 = $105 >> 16;
   $107 = $106 ^ $105;
   $108 = HEAP32[$81>>2]|0;
   $109 = $107 & $108;
   $110 = (($82) + ($109<<2)|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = (($84) + ($i3$04<<2)|0);
   HEAP32[$112>>2] = $111;
   HEAP32[$110>>2] = $i3$04;
   $113 = (($i3$04) + 1)|0;
   $114 = HEAP32[$76>>2]|0;
   $115 = ($113>>>0)<($114>>>0);
   if ($115) {
    $i3$04 = $113;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$12);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 12|0);
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 32|0);
 HEAP32[$16>>2] = $14;
 $17 = $14 << 2;
 $18 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$17,485208,456)|0);
 HEAP32[$this>>2] = $18;
 $19 = HEAP32[$13>>2]|0;
 $20 = ($19|0)==(0);
 if ($20) {
  $$lcssa = 0;
 } else {
  $i$02 = 0;
  while(1) {
   $21 = (($18) + ($i$02<<2)|0);
   HEAP32[$21>>2] = 1073741823;
   $22 = (($i$02) + 1)|0;
   $23 = HEAP32[$13>>2]|0;
   $24 = ($22>>>0)<($23>>>0);
   if ($24) {
    $i$02 = $22;
   } else {
    break;
   }
  }
  $phitmp = $23 << 3;
  $$lcssa = $phitmp;
 }
 $25 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$$lcssa,485208,464)|0);
 $26 = HEAP32[$13>>2]|0;
 $27 = $26 << 2;
 $28 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$27,485208,465)|0);
 $29 = HEAP32[$13>>2]|0;
 $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$29,485208,466)|0);
 $31 = (($this) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0);
 if ($33) {
  label = 10;
 } else {
  $34 = (($this) + 20|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = $32 << 3;
  _memcpy(($25|0),($35|0),($36|0))|0;
  $$pr = HEAP32[$31>>2]|0;
  $37 = ($$pr|0)==(0);
  if ($37) {
   label = 10;
  } else {
   $38 = (($this) + 24|0);
   $39 = HEAP32[$38>>2]|0;
   _memcpy(($30|0),($39|0),($$pr|0))|0;
   $$pre = HEAP32[$31>>2]|0;
   $phitmp11 = ($$pre|0)==(0);
   if ($phitmp11) {
    label = 10;
   } else {
    $40 = (($this) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($this) + 36|0);
    $43 = HEAP32[$this>>2]|0;
    $i1$01 = 0;
    while(1) {
     $44 = (($41) + ($i1$01<<3)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ((($41) + ($i1$01<<3)|0) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = $47 << 16;
     $49 = $48 | $45;
     $50 = $49 << 15;
     $51 = $50 ^ -1;
     $52 = (($49) + ($51))|0;
     $53 = $52 >> 10;
     $54 = $53 ^ $52;
     $55 = ($54*9)|0;
     $56 = $55 >> 6;
     $57 = $56 ^ $55;
     $58 = $57 << 11;
     $59 = $58 ^ -1;
     $60 = (($57) + ($59))|0;
     $61 = $60 >> 16;
     $62 = $61 ^ $60;
     $63 = HEAP32[$42>>2]|0;
     $64 = $62 & $63;
     $65 = (($43) + ($64<<2)|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = (($28) + ($i1$01<<2)|0);
     HEAP32[$67>>2] = $66;
     HEAP32[$65>>2] = $i1$01;
     $68 = (($i1$01) + 1)|0;
     $69 = HEAP32[$31>>2]|0;
     $70 = ($68>>>0)<($69>>>0);
     if ($70) {
      $i1$01 = $68;
     } else {
      $$pre$phiZ2D = $40;
      break;
     }
    }
   }
  }
 }
 if ((label|0) == 10) {
  $$pre10 = (($this) + 20|0);
  $$pre$phiZ2D = $$pre10;
 }
 $71 = (($this) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$72);
 $73 = HEAP32[$$pre$phiZ2D>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$73);
 $74 = (($this) + 24|0);
 $75 = HEAP32[$74>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$75);
 HEAP32[$$pre$phiZ2D>>2] = $25;
 HEAP32[$74>>2] = $30;
 HEAP32[$71>>2] = $28;
 STACKTOP = sp;return;
}
function __ZN5physx14SapPairManager10RemovePairEjjjj($this,$0,$1,$hash_value,$pair_index) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $hash_value = $hash_value|0;
 $pair_index = $pair_index|0;
 var $$phi$trans$insert = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0;
 var $Offset$0 = 0, $Offset$03 = 0, $Offset$04 = 0, $Offset1$0 = 0, $Offset1$01 = 0, $Offset1$02 = 0, $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + ($hash_value<<2)|0);
 $Offset$03 = HEAP32[$3>>2]|0;
 $4 = ($Offset$03|0)==($pair_index|0);
 $$phi$trans$insert = (($this) + 4|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if ($4) {
  $5 = (($this) + 4|0);
  $6 = (($$pre) + ($pair_index<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $15 = $7;$79 = $5;
  label = 6;
 } else {
  $Offset$04 = $Offset$03;
  while(1) {
   $8 = (($$pre) + ($Offset$04<<2)|0);
   $Offset$0 = HEAP32[$8>>2]|0;
   $9 = ($Offset$0|0)==($pair_index|0);
   if ($9) {
    break;
   } else {
    $Offset$04 = $Offset$0;
   }
  }
  $10 = ($Offset$04|0)==(1073741823);
  $11 = (($this) + 4|0);
  $12 = (($$pre) + ($pair_index<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  if ($10) {
   $15 = $13;$79 = $11;
   label = 6;
  } else {
   $14 = (($$pre) + ($Offset$04<<2)|0);
   HEAP32[$14>>2] = $13;
   $76 = $11;
  }
 }
 if ((label|0) == 6) {
  HEAP32[$3>>2] = $15;
  $76 = $79;
 }
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + -1)|0;
 $19 = ($18|0)==($pair_index|0);
 if ($19) {
  $storemerge$in = $17;
  $storemerge = (($storemerge$in) + -1)|0;
  HEAP32[$16>>2] = $storemerge;
  STACKTOP = sp;return;
 }
 $20 = (($this) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($18<<3)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($21) + ($18<<3)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 << 16;
 $27 = $26 | $23;
 $28 = $27 << 15;
 $29 = $28 ^ -1;
 $30 = (($27) + ($29))|0;
 $31 = $30 >> 10;
 $32 = $31 ^ $30;
 $33 = ($32*9)|0;
 $34 = $33 >> 6;
 $35 = $34 ^ $33;
 $36 = $35 << 11;
 $37 = $36 ^ -1;
 $38 = (($35) + ($37))|0;
 $39 = $38 >> 16;
 $40 = $39 ^ $38;
 $41 = (($this) + 36|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $40 & $42;
 $44 = (($2) + ($43<<2)|0);
 $Offset1$01 = HEAP32[$44>>2]|0;
 $45 = ($Offset1$01|0)==($18|0);
 if ($45) {
  $46 = (($$pre) + ($18<<2)|0);
  $47 = HEAP32[$46>>2]|0;
  $54 = $47;
  label = 13;
 } else {
  $Offset1$02 = $Offset1$01;
  while(1) {
   $48 = (($$pre) + ($Offset1$02<<2)|0);
   $Offset1$0 = HEAP32[$48>>2]|0;
   $49 = ($Offset1$0|0)==($18|0);
   if ($49) {
    break;
   } else {
    $Offset1$02 = $Offset1$0;
   }
  }
  $50 = ($Offset1$02|0)==(1073741823);
  $51 = (($$pre) + ($18<<2)|0);
  $52 = HEAP32[$51>>2]|0;
  if ($50) {
   $54 = $52;
   label = 13;
  } else {
   $53 = (($$pre) + ($Offset1$02<<2)|0);
   HEAP32[$53>>2] = $52;
  }
 }
 if ((label|0) == 13) {
  HEAP32[$44>>2] = $54;
 }
 $55 = (($21) + ($pair_index<<3)|0);
 $56 = (($21) + ($18<<3)|0);
 $57 = $56;
 $58 = $57;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 4)|0;
 $61 = $60;
 $62 = HEAP32[$61>>2]|0;
 $63 = $55;
 $64 = $63;
 HEAP32[$64>>2] = $59;
 $65 = (($63) + 4)|0;
 $66 = $65;
 HEAP32[$66>>2] = $62;
 $67 = (($this) + 24|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + ($18)|0);
 $70 = HEAP8[$69>>0]|0;
 $71 = (($68) + ($pair_index)|0);
 HEAP8[$71>>0] = $70;
 $72 = HEAP32[$this>>2]|0;
 $73 = (($72) + ($43<<2)|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$76>>2]|0;
 $77 = (($75) + ($pair_index<<2)|0);
 HEAP32[$77>>2] = $74;
 HEAP32[$73>>2] = $pair_index;
 $78 = HEAP32[$16>>2]|0;
 $storemerge$in = $78;
 $storemerge = (($storemerge$in) + -1)|0;
 HEAP32[$16>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZN5physx14SapPairManager10RemovePairEjj($this,$id0,$id1) {
 $this = $this|0;
 $id0 = $id0|0;
 $id1 = $id1|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $Offset$0$i = 0, $Offset$03$i = 0, $Offset$05$i = 0, $cond$i = 0, $cond4$i = 0, $id0$id1 = 0, $id1$id0 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($id0>>>0)>($id1>>>0);
 $id1$id0 = $0 ? $id1 : $id0;
 $id0$id1 = $0 ? $id0 : $id1;
 $1 = $id0$id1 << 16;
 $2 = $1 | $id1$id0;
 $3 = $2 << 15;
 $4 = $3 ^ -1;
 $5 = (($2) + ($4))|0;
 $6 = $5 >> 10;
 $7 = $6 ^ $5;
 $8 = ($7*9)|0;
 $9 = $8 >> 6;
 $10 = $9 ^ $8;
 $11 = $10 << 11;
 $12 = $11 ^ -1;
 $13 = (($10) + ($12))|0;
 $14 = $13 >> 16;
 $15 = $14 ^ $13;
 $16 = (($this) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & $15;
 $19 = (($this) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = HEAP32[$this>>2]|0;
 $23 = (($22) + ($18<<2)|0);
 $Offset$03$i = HEAP32[$23>>2]|0;
 $cond4$i = ($Offset$03$i|0)==(1073741823);
 if ($cond4$i) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = (($this) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 4|0);
 $Offset$05$i = $Offset$03$i;
 while(1) {
  $27 = (($25) + ($Offset$05$i<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($id1$id0|0);
  if ($29) {
   $30 = ((($25) + ($Offset$05$i<<3)|0) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($id0$id1|0);
   if ($32) {
    break;
   }
  }
  $33 = HEAP32[$26>>2]|0;
  $34 = (($33) + ($Offset$05$i<<2)|0);
  $Offset$0$i = HEAP32[$34>>2]|0;
  $cond$i = ($Offset$0$i|0)==(1073741823);
  if ($cond$i) {
   $$0 = 0;
   label = 14;
   break;
  } else {
   $Offset$05$i = $Offset$0$i;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return ($$0|0);
 }
 $35 = (($25) + ($Offset$05$i<<3)|0);
 $36 = ($35|0)==(0|0);
 if ($36) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx14SapPairManager10RemovePairEjjjj($this,0,0,$18,$Offset$05$i);
 $37 = (($this) + 28|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 >>> 1;
 $40 = $39 | $38;
 $41 = $40 >>> 2;
 $42 = $41 | $40;
 $43 = $42 >>> 4;
 $44 = $43 | $42;
 $45 = $44 >>> 8;
 $46 = $45 | $44;
 $47 = $46 >>> 16;
 $48 = $47 | $46;
 $49 = (($48) + 1)|0;
 $50 = HEAP32[$19>>2]|0;
 $51 = ($49|0)==($50|0);
 if ($51) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $52 = (($this) + 16|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($49>>>0)<($53>>>0);
 $55 = ($50|0)==($53|0);
 $or$cond$i = $54 & $55;
 if ($or$cond$i) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $$$i = $54 ? $53 : $49;
 HEAP32[$19>>2] = $$$i;
 $56 = (($$$i) + -1)|0;
 HEAP32[$16>>2] = $56;
 $57 = ($$$i>>>0)>($53>>>0);
 if ($57) {
  $66 = 1;
 } else {
  $58 = (($this) + 12|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $59 >>> 2;
  $61 = ($$$i>>>0)>($60>>>0);
  if ($61) {
   $62 = (($this) + 32|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = $63 >>> 2;
   $65 = ($$$i>>>0)<=($64>>>0);
   $66 = $65;
  } else {
   $66 = 1;
  }
 }
 __ZN5physx14SapPairManager12reallocPairsEb($this,$66);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx14SapPairManager12shrinkMemoryEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 1;
 $3 = $2 | $1;
 $4 = $3 >>> 2;
 $5 = $4 | $3;
 $6 = $5 >>> 4;
 $7 = $6 | $5;
 $8 = $7 >>> 8;
 $9 = $8 | $7;
 $10 = $9 >>> 16;
 $11 = $10 | $9;
 $12 = (($11) + 1)|0;
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($this) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($12>>>0)<($17>>>0);
 $19 = ($14|0)==($17|0);
 $or$cond = $18 & $19;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $$ = $18 ? $17 : $12;
 HEAP32[$13>>2] = $$;
 $20 = (($$) + -1)|0;
 $21 = (($this) + 36|0);
 HEAP32[$21>>2] = $20;
 $22 = ($$>>>0)>($17>>>0);
 if ($22) {
  $31 = 1;
 } else {
  $23 = (($this) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 >>> 2;
  $26 = ($$>>>0)>($25>>>0);
  if ($26) {
   $27 = (($this) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $28 >>> 2;
   $30 = ($$>>>0)<=($29>>>0);
   $31 = $30;
  } else {
   $31 = 1;
  }
 }
 __ZN5physx14SapPairManager12reallocPairsEb($this,$31);
 STACKTOP = sp;return;
}
function __ZN5physx14SapPairManager11RemovePairsERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$removedAABBs) {
 $this = $this|0;
 $removedAABBs = $removedAABBs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$ph1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return 1;
 }
 $3 = (($this) + 20|0);
 $4 = (($this) + 36|0);
 $47 = $1;$i$0$ph1 = 0;
 L4: while(1) {
  $46 = $47;
  while(1) {
   $5 = HEAP32[$3>>2]|0;
   $6 = (($5) + ($i$0$ph1<<3)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($5) + ($i$0$ph1<<3)|0) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $7 >>> 5;
   $11 = HEAP32[$removedAABBs>>2]|0;
   $12 = (($11) + ($10<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $7 & 31;
   $15 = 1 << $14;
   $16 = $13 & $15;
   $17 = ($16|0)==(0);
   if ($17) {
    $18 = $9 >>> 5;
    $19 = (($11) + ($18<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $9 & 31;
    $22 = 1 << $21;
    $23 = $20 & $22;
    $24 = ($23|0)==(0);
    if ($24) {
     break;
    }
   }
   $25 = $9 << 16;
   $26 = $25 | $7;
   $27 = $26 << 15;
   $28 = $27 ^ -1;
   $29 = (($26) + ($28))|0;
   $30 = $29 >> 10;
   $31 = $30 ^ $29;
   $32 = ($31*9)|0;
   $33 = $32 >> 6;
   $34 = $33 ^ $32;
   $35 = $34 << 11;
   $36 = $35 ^ -1;
   $37 = (($34) + ($36))|0;
   $38 = $37 >> 16;
   $39 = $38 ^ $37;
   $40 = HEAP32[$4>>2]|0;
   $41 = $40 & $39;
   __ZN5physx14SapPairManager10RemovePairEjjjj($this,0,0,$41,$i$0$ph1);
   $42 = HEAP32[$0>>2]|0;
   $43 = ($i$0$ph1>>>0)<($42>>>0);
   if ($43) {
    $46 = $42;
   } else {
    label = 8;
    break L4;
   }
  }
  $44 = (($i$0$ph1) + 1)|0;
  $45 = ($44>>>0)<($46>>>0);
  if ($45) {
   $47 = $46;$i$0$ph1 = $44;
  } else {
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5physx31ComputeCreatedDeletedPairsListsEPKjS1_jRPNS_17PxcBroadPhasePairERjS5_S4_S5_S5_RNS_14SapPairManagerE($boxGroups,$dataArray,$dataArraySize,$createdPairsList,$numCreatedPairs,$maxNumCreatedPairs,$deletedPairsList,$numDeletedPairs,$maxNumDeletedPairs,$pairManager) {
 $boxGroups = $boxGroups|0;
 $dataArray = $dataArray|0;
 $dataArraySize = $dataArraySize|0;
 $createdPairsList = $createdPairsList|0;
 $numCreatedPairs = $numCreatedPairs|0;
 $maxNumCreatedPairs = $maxNumCreatedPairs|0;
 $deletedPairsList = $deletedPairsList|0;
 $numDeletedPairs = $numDeletedPairs|0;
 $maxNumDeletedPairs = $maxNumDeletedPairs|0;
 $pairManager = $pairManager|0;
 var $$idx = 0, $$idx8 = 0, $$pre = 0, $$pre20 = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond = 0, $exitcond18 = 0, $exitcond19 = 0, $i$014 = 0, $i1$010 = 0, $i4$09 = 0, $numActualDeletedPairs$0$lcssa = 0, $numActualDeletedPairs$011 = 0, $numActualDeletedPairs$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = ($dataArraySize|0)==(0);
 if ($2) {
  $3 = HEAP32[$numDeletedPairs>>2]|0;
  $numActualDeletedPairs$0$lcssa = $3;
 } else {
  $4 = (($pairManager) + 20|0);
  $5 = (($pairManager) + 24|0);
  $i$014 = 0;
  while(1) {
   $6 = (($dataArray) + ($i$014<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$4>>2]|0;
   $9 = (($8) + ($7<<3)|0);
   $10 = $9;
   $$idx8 = $7 << 3;
   $11 = $$idx8 >> 3;
   $12 = HEAP32[$5>>2]|0;
   $13 = (($12) + ($11)|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 2;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $44 = $14&255;
    $45 = $44 & 254;
    $46 = $45&255;
    HEAP8[$13>>0] = $46;
    $47 = HEAP32[$4>>2]|0;
    $48 = $47;
    $49 = (($10) - ($48))|0;
    $50 = $49 >> 3;
    $51 = HEAP32[$5>>2]|0;
    $52 = (($51) + ($50)|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53 & 4;
    $55 = ($54<<24>>24)==(0);
    if (!($55)) {
     $56 = HEAP32[$numCreatedPairs>>2]|0;
     $57 = HEAP32[$maxNumCreatedPairs>>2]|0;
     $58 = ($56|0)==($57|0);
     if ($58) {
      $59 = $56 << 1;
      $60 = $56 << 4;
      $61 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$60,485208,521)|0);
      $62 = HEAP32[$createdPairsList>>2]|0;
      $63 = HEAP32[$maxNumCreatedPairs>>2]|0;
      $64 = $63 << 3;
      _memcpy(($61|0),($62|0),($64|0))|0;
      $65 = HEAP32[$createdPairsList>>2]|0;
      __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$65);
      HEAP32[$createdPairsList>>2] = $61;
      HEAP32[$maxNumCreatedPairs>>2] = $59;
      $$pre = HEAP32[$numCreatedPairs>>2]|0;
      $67 = $61;$68 = $$pre;
     } else {
      $$pre27 = HEAP32[$createdPairsList>>2]|0;
      $67 = $$pre27;$68 = $56;
     }
     $66 = (($67) + ($68<<3)|0);
     $69 = HEAP32[$9>>2]|0;
     $70 = ((($8) + ($7<<3)|0) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($69>>>0)<($71>>>0);
     $73 = $72 ? $69 : $71;
     $74 = $72 ? $71 : $69;
     $75 = $66;
     $76 = $75;
     HEAP32[$76>>2] = $73;
     $77 = (($75) + 4)|0;
     $78 = $77;
     HEAP32[$78>>2] = $74;
     $79 = HEAP32[$numCreatedPairs>>2]|0;
     $80 = (($79) + 1)|0;
     HEAP32[$numCreatedPairs>>2] = $80;
     $81 = HEAP32[$4>>2]|0;
     $82 = $81;
     $83 = (($10) - ($82))|0;
     $84 = $83 >> 3;
     $85 = HEAP32[$5>>2]|0;
     $86 = (($85) + ($84)|0);
     $87 = HEAP8[$86>>0]|0;
     $88 = $87&255;
     $89 = $88 & 251;
     $90 = $89&255;
     HEAP8[$86>>0] = $90;
    }
   } else {
    $17 = $14 & 4;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     $19 = HEAP32[$numDeletedPairs>>2]|0;
     $20 = HEAP32[$maxNumDeletedPairs>>2]|0;
     $21 = ($19|0)==($20|0);
     if ($21) {
      $22 = $19 << 1;
      $23 = $19 << 4;
      $24 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$23,485208,521)|0);
      $25 = HEAP32[$deletedPairsList>>2]|0;
      $26 = HEAP32[$maxNumDeletedPairs>>2]|0;
      $27 = $26 << 3;
      _memcpy(($24|0),($25|0),($27|0))|0;
      $28 = HEAP32[$deletedPairsList>>2]|0;
      __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$28);
      HEAP32[$deletedPairsList>>2] = $24;
      HEAP32[$maxNumDeletedPairs>>2] = $22;
      $$pre20 = HEAP32[$numDeletedPairs>>2]|0;
      $31 = $$pre20;
     } else {
      $31 = $19;
     }
     $29 = HEAP32[$deletedPairsList>>2]|0;
     $30 = (($29) + ($31<<3)|0);
     $32 = HEAP32[$9>>2]|0;
     $33 = ((($8) + ($7<<3)|0) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($32>>>0)<($34>>>0);
     $36 = $35 ? $32 : $34;
     $37 = $35 ? $34 : $32;
     $38 = $30;
     $39 = $38;
     HEAP32[$39>>2] = $36;
     $40 = (($38) + 4)|0;
     $41 = $40;
     HEAP32[$41>>2] = $37;
     $42 = HEAP32[$numDeletedPairs>>2]|0;
     $43 = (($42) + 1)|0;
     HEAP32[$numDeletedPairs>>2] = $43;
    }
   }
   $91 = (($i$014) + 1)|0;
   $exitcond19 = ($91|0)==($dataArraySize|0);
   if ($exitcond19) {
    break;
   } else {
    $i$014 = $91;
   }
  }
  $92 = HEAP32[$numDeletedPairs>>2]|0;
  if ($2) {
   $numActualDeletedPairs$0$lcssa = $92;
  } else {
   $93 = (($pairManager) + 20|0);
   $94 = (($pairManager) + 24|0);
   $i1$010 = 0;$numActualDeletedPairs$011 = $92;
   while(1) {
    $96 = (($dataArray) + ($i1$010<<2)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = HEAP32[$93>>2]|0;
    $$idx = $97 << 3;
    $99 = $$idx >> 3;
    $100 = HEAP32[$94>>2]|0;
    $101 = (($100) + ($99)|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = $102 & 6;
    $104 = ($103<<24>>24)==(6);
    if ($104) {
     $105 = HEAP32[$maxNumDeletedPairs>>2]|0;
     $106 = ($numActualDeletedPairs$011|0)==($105|0);
     if ($106) {
      $107 = $numActualDeletedPairs$011 << 1;
      $108 = $numActualDeletedPairs$011 << 4;
      $109 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$108,485208,521)|0);
      $110 = HEAP32[$deletedPairsList>>2]|0;
      $111 = HEAP32[$maxNumDeletedPairs>>2]|0;
      $112 = $111 << 3;
      _memcpy(($109|0),($110|0),($112|0))|0;
      $113 = HEAP32[$deletedPairsList>>2]|0;
      __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$113);
      HEAP32[$deletedPairsList>>2] = $109;
      HEAP32[$maxNumDeletedPairs>>2] = $107;
     }
     $114 = HEAP32[$deletedPairsList>>2]|0;
     $115 = (($114) + ($numActualDeletedPairs$011<<3)|0);
     $116 = (($98) + ($97<<3)|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ((($98) + ($97<<3)|0) + 4|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = ($117>>>0)<($119>>>0);
     $121 = $120 ? $117 : $119;
     $122 = $120 ? $119 : $117;
     $123 = $115;
     $124 = $123;
     HEAP32[$124>>2] = $121;
     $125 = (($123) + 4)|0;
     $126 = $125;
     HEAP32[$126>>2] = $122;
     $127 = (($numActualDeletedPairs$011) + 1)|0;
     $numActualDeletedPairs$1 = $127;
    } else {
     $numActualDeletedPairs$1 = $numActualDeletedPairs$011;
    }
    $128 = (($i1$010) + 1)|0;
    $exitcond18 = ($128|0)==($dataArraySize|0);
    if ($exitcond18) {
     $numActualDeletedPairs$0$lcssa = $numActualDeletedPairs$1;
     break;
    } else {
     $i1$010 = $128;$numActualDeletedPairs$011 = $numActualDeletedPairs$1;
    }
   }
  }
 }
 $95 = ($numActualDeletedPairs$0$lcssa|0)==(0);
 if ($95) {
  STACKTOP = sp;return;
 } else {
  $i4$09 = 0;
 }
 while(1) {
  $129 = HEAP32[$deletedPairsList>>2]|0;
  $130 = (($129) + ($i4$09<<3)|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ((($129) + ($i4$09<<3)|0) + 4|0);
  $133 = HEAP32[$132>>2]|0;
  (__ZN5physx14SapPairManager10RemovePairEjj($pairManager,$131,$133)|0);
  $134 = (($i4$09) + 1)|0;
  $exitcond = ($134|0)==($numActualDeletedPairs$0$lcssa|0);
  if ($exitcond) {
   break;
  } else {
   $i4$09 = $134;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx18ComputeSortedListsEPNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjjPKjPPNS_8SapBox1DES7_PjSB_jRKNS_2Gu4AxesESB_RjSB_SG_RbSH_($bitmap,$insertAABBStart,$insertAABBEnd,$createdAABBs,$asapBoxes,$asapBoxGroupIds,$0,$asapEndPointDatas,$numSortedEndPoints,$axes,$newBoxIndicesSorted,$newBoxIndicesCount,$oldBoxIndicesSorted,$oldBoxIndicesCount,$allNewBoxesStatics,$allOldBoxesStatics) {
 $bitmap = $bitmap|0;
 $insertAABBStart = $insertAABBStart|0;
 $insertAABBEnd = $insertAABBEnd|0;
 $createdAABBs = $createdAABBs|0;
 $asapBoxes = $asapBoxes|0;
 $asapBoxGroupIds = $asapBoxGroupIds|0;
 $0 = $0|0;
 $asapEndPointDatas = $asapEndPointDatas|0;
 $numSortedEndPoints = $numSortedEndPoints|0;
 $axes = $axes|0;
 $newBoxIndicesSorted = $newBoxIndicesSorted|0;
 $newBoxIndicesCount = $newBoxIndicesCount|0;
 $oldBoxIndicesSorted = $oldBoxIndicesSorted|0;
 $oldBoxIndicesCount = $oldBoxIndicesCount|0;
 $allNewBoxesStatics = $allNewBoxesStatics|0;
 $allOldBoxesStatics = $allOldBoxesStatics|0;
 var $$$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond26 = 0, $globalAABB$sroa$0$0$lcssa = 0, $globalAABB$sroa$0$09 = 0, $globalAABB$sroa$1$0$lcssa = 0, $globalAABB$sroa$1$08 = 0, $globalAABB$sroa$2$0$lcssa = 0, $globalAABB$sroa$2$07 = 0, $globalAABB$sroa$3$0$lcssa = 0, $globalAABB$sroa$3$06 = 0, $globalAABB$sroa$4$0$lcssa = 0, $globalAABB$sroa$4$011 = 0, $globalAABB$sroa$5$0$lcssa = 0, $globalAABB$sroa$5$012 = 0, $i$010 = 0, $i1$04 = 0, $newStaticCount$0$lcssa = 0;
 var $newStaticCount$03 = 0, $newStaticCount$1 = 0, $not$ = 0, $not$1 = 0, $not$or$cond3$i = 0, $oldStaticCount$0$lcssa = 0, $oldStaticCount$02 = 0, $oldStaticCount$1 = 0, $or$cond$i = 0, $or$cond1$i = 0, $or$cond2$i = 0, $or$cond3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$axes>>2]|0;
 $2 = (($axes) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($axes) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($insertAABBStart>>>0)<($insertAABBEnd>>>0);
 if ($6) {
  $7 = HEAP32[$bitmap>>2]|0;
  $8 = (($asapBoxes) + ($1<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($asapBoxes) + ($3<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($asapBoxes) + ($5<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $globalAABB$sroa$0$09 = -1;$globalAABB$sroa$1$08 = -1;$globalAABB$sroa$2$07 = -1;$globalAABB$sroa$3$06 = 0;$globalAABB$sroa$4$011 = 0;$globalAABB$sroa$5$012 = 0;$i$010 = $insertAABBStart;
  while(1) {
   $19 = (($createdAABBs) + ($i$010<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20 & 31;
   $22 = 1 << $21;
   $23 = $20 >>> 5;
   $24 = (($7) + ($23<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 | $22;
   HEAP32[$24>>2] = $26;
   $27 = (($9) + ($20<<3)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($globalAABB$sroa$0$09>>>0)<($28>>>0);
   $30 = $29 ? $globalAABB$sroa$0$09 : $28;
   $31 = (($11) + ($20<<3)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($globalAABB$sroa$1$08>>>0)<($32>>>0);
   $34 = $33 ? $globalAABB$sroa$1$08 : $32;
   $35 = (($13) + ($20<<3)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($globalAABB$sroa$2$07>>>0)<($36>>>0);
   $38 = $37 ? $globalAABB$sroa$2$07 : $36;
   $39 = ((($9) + ($20<<3)|0) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($globalAABB$sroa$3$06>>>0)<($40>>>0);
   $42 = $41 ? $40 : $globalAABB$sroa$3$06;
   $43 = ((($11) + ($20<<3)|0) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($globalAABB$sroa$4$011>>>0)<($44>>>0);
   $46 = $45 ? $44 : $globalAABB$sroa$4$011;
   $47 = ((($13) + ($20<<3)|0) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($globalAABB$sroa$5$012>>>0)<($48>>>0);
   $50 = $49 ? $48 : $globalAABB$sroa$5$012;
   $51 = (($i$010) + 1)|0;
   $exitcond26 = ($51|0)==($insertAABBEnd|0);
   if ($exitcond26) {
    $globalAABB$sroa$0$0$lcssa = $30;$globalAABB$sroa$1$0$lcssa = $34;$globalAABB$sroa$2$0$lcssa = $38;$globalAABB$sroa$3$0$lcssa = $42;$globalAABB$sroa$4$0$lcssa = $46;$globalAABB$sroa$5$0$lcssa = $50;
    break;
   } else {
    $globalAABB$sroa$0$09 = $30;$globalAABB$sroa$1$08 = $34;$globalAABB$sroa$2$07 = $38;$globalAABB$sroa$3$06 = $42;$globalAABB$sroa$4$011 = $46;$globalAABB$sroa$5$012 = $50;$i$010 = $51;
   }
  }
 } else {
  $globalAABB$sroa$0$0$lcssa = -1;$globalAABB$sroa$1$0$lcssa = -1;$globalAABB$sroa$2$0$lcssa = -1;$globalAABB$sroa$3$0$lcssa = 0;$globalAABB$sroa$4$0$lcssa = 0;$globalAABB$sroa$5$0$lcssa = 0;
 }
 $14 = (($numSortedEndPoints) + -1)|0;
 $15 = ($14>>>0)>(1);
 if (!($15)) {
  $newStaticCount$0$lcssa = 0;$oldStaticCount$0$lcssa = 0;
  $not$ = ($oldStaticCount$0$lcssa|0)==(0);
  $101 = $not$&1;
  HEAP8[$allOldBoxesStatics>>0] = $101;
  $not$1 = ($newStaticCount$0$lcssa|0)==(0);
  $102 = $not$1&1;
  HEAP8[$allNewBoxesStatics>>0] = $102;
  STACKTOP = sp;return;
 }
 $16 = (($asapBoxes) + ($1<<2)|0);
 $17 = (($asapBoxes) + ($3<<2)|0);
 $18 = (($asapBoxes) + ($5<<2)|0);
 $i1$04 = 1;$newStaticCount$03 = 0;$oldStaticCount$02 = 0;
 while(1) {
  $52 = (($asapEndPointDatas) + ($i1$04<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = $53 & 1;
  $55 = ($54|0)==(0);
  do {
   if ($55) {
    $56 = $53 >>> 1;
    $57 = $53 >>> 6;
    $58 = HEAP32[$bitmap>>2]|0;
    $59 = (($58) + ($57<<2)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = $56 & 31;
    $62 = 1 << $61;
    $63 = $60 & $62;
    $64 = ($63|0)==(0);
    if (!($64)) {
     $93 = HEAP32[$newBoxIndicesCount>>2]|0;
     $94 = (($newBoxIndicesSorted) + ($93<<2)|0);
     HEAP32[$94>>2] = $56;
     $95 = HEAP32[$newBoxIndicesCount>>2]|0;
     $96 = (($95) + 1)|0;
     HEAP32[$newBoxIndicesCount>>2] = $96;
     $97 = (($asapBoxGroupIds) + ($56<<2)|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($98) + ($newStaticCount$03))|0;
     $newStaticCount$1 = $99;$oldStaticCount$1 = $oldStaticCount$02;
     break;
    }
    $65 = HEAP32[$16>>2]|0;
    $66 = (($65) + ($56<<3)|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($65) + ($56<<3)|0) + 4|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = HEAP32[$17>>2]|0;
    $71 = (($70) + ($56<<3)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ((($70) + ($56<<3)|0) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = HEAP32[$18>>2]|0;
    $76 = (($75) + ($56<<3)|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = ((($75) + ($56<<3)|0) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($globalAABB$sroa$3$0$lcssa>>>0)<($67>>>0);
    $81 = ($69>>>0)<($globalAABB$sroa$0$0$lcssa>>>0);
    $or$cond$i = $80 | $81;
    $82 = ($globalAABB$sroa$4$0$lcssa>>>0)<($72>>>0);
    $or$cond1$i = $or$cond$i | $82;
    $83 = ($74>>>0)<($globalAABB$sroa$1$0$lcssa>>>0);
    $or$cond2$i = $or$cond1$i | $83;
    $84 = ($globalAABB$sroa$5$0$lcssa>>>0)<($77>>>0);
    $or$cond3$i = $or$cond2$i | $84;
    $85 = ($79>>>0)>=($globalAABB$sroa$2$0$lcssa>>>0);
    $not$or$cond3$i = $or$cond3$i ^ 1;
    $$$i = $85 & $not$or$cond3$i;
    if ($$$i) {
     $86 = HEAP32[$oldBoxIndicesCount>>2]|0;
     $87 = (($oldBoxIndicesSorted) + ($86<<2)|0);
     HEAP32[$87>>2] = $56;
     $88 = HEAP32[$oldBoxIndicesCount>>2]|0;
     $89 = (($88) + 1)|0;
     HEAP32[$oldBoxIndicesCount>>2] = $89;
     $90 = (($asapBoxGroupIds) + ($56<<2)|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = (($91) + ($oldStaticCount$02))|0;
     $newStaticCount$1 = $newStaticCount$03;$oldStaticCount$1 = $92;
    } else {
     $newStaticCount$1 = $newStaticCount$03;$oldStaticCount$1 = $oldStaticCount$02;
    }
   } else {
    $newStaticCount$1 = $newStaticCount$03;$oldStaticCount$1 = $oldStaticCount$02;
   }
  } while(0);
  $100 = (($i1$04) + 1)|0;
  $exitcond = ($100|0)==($14|0);
  if ($exitcond) {
   $newStaticCount$0$lcssa = $newStaticCount$1;$oldStaticCount$0$lcssa = $oldStaticCount$1;
   break;
  } else {
   $i1$04 = $100;$newStaticCount$03 = $newStaticCount$1;$oldStaticCount$02 = $oldStaticCount$1;
  }
 }
 $not$ = ($oldStaticCount$0$lcssa|0)==(0);
 $101 = $not$&1;
 HEAP8[$allOldBoxesStatics>>0] = $101;
 $not$1 = ($newStaticCount$0$lcssa|0)==(0);
 $102 = $not$1&1;
 HEAP8[$allNewBoxesStatics>>0] = $102;
 STACKTOP = sp;return;
}
function __ZN5physx23performBoxPruningNewNewERKNS_2Gu4AxesEPKjjbPjPPNS_8SapBox1DES5_RNS_14SapPairManagerERS6_RjSD_($axes,$newBoxIndicesSorted,$newBoxIndicesCount,$allNewBoxesStatics,$minPosList0,$asapBoxes,$asapBoxGroupIds,$pairManager,$dataArray,$dataArraySize,$dataArrayCapacity) {
 $axes = $axes|0;
 $newBoxIndicesSorted = $newBoxIndicesSorted|0;
 $newBoxIndicesCount = $newBoxIndicesCount|0;
 $allNewBoxesStatics = $allNewBoxesStatics|0;
 $minPosList0 = $minPosList0|0;
 $asapBoxes = $asapBoxes|0;
 $asapBoxGroupIds = $asapBoxGroupIds|0;
 $pairManager = $pairManager|0;
 $dataArray = $dataArray|0;
 $dataArraySize = $dataArraySize|0;
 $dataArrayCapacity = $dataArrayCapacity|0;
 var $$$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $RunningIndex$06 = 0, $RunningIndex$1 = 0, $RunningIndex$2 = 0, $RunningIndex2$03 = 0, $SortedIndex$05 = 0, $exitcond = 0, $i$08 = 0, $not$or$cond1$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($newBoxIndicesCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$axes>>2]|0;
 $2 = (($axes) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($axes) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($asapBoxes) + ($1<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $i$08 = 0;
 while(1) {
  $8 = (($newBoxIndicesSorted) + ($i$08<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + ($9<<3)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($minPosList0) + ($i$08<<2)|0);
  HEAP32[$12>>2] = $11;
  $13 = (($i$08) + 1)|0;
  $exitcond = ($13|0)==($newBoxIndicesCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$08 = $13;
  }
 }
 if ($allNewBoxesStatics) {
  STACKTOP = sp;return;
 }
 $14 = (($asapBoxes) + ($1<<2)|0);
 $15 = (($asapBoxes) + ($3<<2)|0);
 $16 = (($asapBoxes) + ($5<<2)|0);
 $RunningIndex$06 = 0;$SortedIndex$05 = 0;
 while(1) {
  $17 = (($SortedIndex$05) + 1)|0;
  $18 = (($newBoxIndicesSorted) + ($SortedIndex$05<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$14>>2]|0;
  $21 = ((($20) + ($19<<3)|0) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($minPosList0) + ($SortedIndex$05<<2)|0);
  $RunningIndex$1 = $RunningIndex$06;
  while(1) {
   $24 = ($RunningIndex$1>>>0)<($newBoxIndicesCount>>>0);
   if (!($24)) {
    $RunningIndex$2 = $RunningIndex$1;
    break;
   }
   $25 = (($RunningIndex$1) + 1)|0;
   $26 = (($minPosList0) + ($RunningIndex$1<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$23>>2]|0;
   $29 = ($27>>>0)<($28>>>0);
   if ($29) {
    $RunningIndex$1 = $25;
   } else {
    $RunningIndex$2 = $25;
    break;
   }
  }
  $30 = ($RunningIndex$2>>>0)<($newBoxIndicesCount>>>0);
  if (!($30)) {
   label = 17;
   break;
  }
  $32 = (($asapBoxGroupIds) + ($19<<2)|0);
  $RunningIndex2$03 = $RunningIndex$2;
  while(1) {
   $33 = (($RunningIndex2$03) + 1)|0;
   $34 = (($minPosList0) + ($RunningIndex2$03<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35>>>0)>($22>>>0);
   if ($36) {
    break;
   }
   $37 = (($newBoxIndicesSorted) + ($RunningIndex2$03<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = HEAP32[$32>>2]|0;
   $40 = (($asapBoxGroupIds) + ($38<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($39|0)==($41|0);
   if (!($42)) {
    $43 = HEAP32[$15>>2]|0;
    $44 = (($43) + ($19<<3)|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ((($43) + ($19<<3)|0) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = HEAP32[$16>>2]|0;
    $49 = (($48) + ($19<<3)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ((($48) + ($19<<3)|0) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($43) + ($38<<3)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ((($43) + ($38<<3)|0) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($48) + ($38<<3)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ((($48) + ($38<<3)|0) + 4|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($47>>>0)<($54>>>0);
    $62 = ($56>>>0)<($45>>>0);
    $or$cond$i = $61 | $62;
    $63 = ($52>>>0)<($58>>>0);
    $or$cond1$i = $or$cond$i | $63;
    $64 = ($60>>>0)>=($50>>>0);
    $not$or$cond1$i = $or$cond1$i ^ 1;
    $$$i = $64 & $not$or$cond1$i;
    if ($$$i) {
     (__ZN5physx7AddPairEjjRNS_14SapPairManagerERPjRjS4_($19,$38,$pairManager,$dataArray,$dataArraySize,$dataArrayCapacity)|0);
    }
   }
   $65 = ($33>>>0)<($newBoxIndicesCount>>>0);
   if ($65) {
    $RunningIndex2$03 = $33;
   } else {
    break;
   }
  }
  $31 = ($17>>>0)<($newBoxIndicesCount>>>0);
  $or$cond = $30 & $31;
  if ($or$cond) {
   $RunningIndex$06 = $RunningIndex$2;$SortedIndex$05 = $17;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx23performBoxPruningNewOldERKNS_2Gu4AxesEPKjjS5_jPjS6_PPNS_8SapBox1DES5_RNS_14SapPairManagerERS6_RjSD_($axes,$newBoxIndicesSorted,$newBoxIndicesCount,$oldBoxIndicesSorted,$oldBoxIndicesCount,$minPosListNew,$minPosListOld,$asapBoxes,$asapBoxGroupIds,$pairManager,$dataArray,$dataArraySize,$dataArrayCapacity) {
 $axes = $axes|0;
 $newBoxIndicesSorted = $newBoxIndicesSorted|0;
 $newBoxIndicesCount = $newBoxIndicesCount|0;
 $oldBoxIndicesSorted = $oldBoxIndicesSorted|0;
 $oldBoxIndicesCount = $oldBoxIndicesCount|0;
 $minPosListNew = $minPosListNew|0;
 $minPosListOld = $minPosListOld|0;
 $asapBoxes = $asapBoxes|0;
 $asapBoxGroupIds = $asapBoxGroupIds|0;
 $pairManager = $pairManager|0;
 $dataArray = $dataArray|0;
 $dataArraySize = $dataArraySize|0;
 $dataArrayCapacity = $dataArrayCapacity|0;
 var $$$i = 0, $$$i11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $RunningIndex0$017 = 0, $RunningIndex0$1$lcssa = 0, $RunningIndex0$112 = 0, $RunningIndex1$026 = 0, $RunningIndex1$1$lcssa = 0, $RunningIndex1$119 = 0, $RunningIndex2_0$013 = 0, $RunningIndex2_1$022 = 0, $SortedIndex0$025 = 0;
 var $SortedIndex1$016 = 0, $exitcond = 0, $exitcond36 = 0, $i$030 = 0, $i1$028 = 0, $not$or$cond1$i = 0, $not$or$cond1$i10 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i8 = 0, $or$cond1$i = 0, $or$cond1$i9 = 0, $or$cond4 = 0, $or$cond6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($newBoxIndicesCount|0)==(0);
 $1 = ($oldBoxIndicesCount|0)==(0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$axes>>2]|0;
 $3 = (($axes) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($axes) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($asapBoxes) + ($2<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $i$030 = 0;
 while(1) {
  $11 = (($newBoxIndicesSorted) + ($i$030<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($8) + ($12<<3)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($minPosListNew) + ($i$030<<2)|0);
  HEAP32[$15>>2] = $14;
  $16 = (($i$030) + 1)|0;
  $exitcond36 = ($16|0)==($newBoxIndicesCount|0);
  if ($exitcond36) {
   break;
  } else {
   $i$030 = $16;
  }
 }
 $9 = (($asapBoxes) + ($2<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $i1$028 = 0;
 while(1) {
  $20 = (($oldBoxIndicesSorted) + ($i1$028<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($10) + ($21<<3)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($minPosListOld) + ($i1$028<<2)|0);
  HEAP32[$24>>2] = $23;
  $25 = (($i1$028) + 1)|0;
  $exitcond = ($25|0)==($oldBoxIndicesCount|0);
  if ($exitcond) {
   break;
  } else {
   $i1$028 = $25;
  }
 }
 $17 = (($asapBoxes) + ($2<<2)|0);
 $18 = (($asapBoxes) + ($4<<2)|0);
 $19 = (($asapBoxes) + ($6<<2)|0);
 $RunningIndex1$026 = 0;$SortedIndex0$025 = 0;
 while(1) {
  $27 = (($SortedIndex0$025) + 1)|0;
  $32 = (($newBoxIndicesSorted) + ($SortedIndex0$025<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = HEAP32[$17>>2]|0;
  $35 = ((($34) + ($33<<3)|0) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($RunningIndex1$026>>>0)<($oldBoxIndicesCount>>>0);
  L12: do {
   if ($37) {
    $38 = (($minPosListNew) + ($SortedIndex0$025<<2)|0);
    $39 = HEAP32[$38>>2]|0;
    $RunningIndex1$119 = $RunningIndex1$026;
    while(1) {
     $42 = (($minPosListOld) + ($RunningIndex1$119<<2)|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43>>>0)<($39>>>0);
     $41 = (($RunningIndex1$119) + 1)|0;
     if (!($44)) {
      $RunningIndex1$1$lcssa = $RunningIndex1$119;
      break L12;
     }
     $40 = ($41>>>0)<($oldBoxIndicesCount>>>0);
     if ($40) {
      $RunningIndex1$119 = $41;
     } else {
      $RunningIndex1$1$lcssa = $41;
      break;
     }
    }
   } else {
    $RunningIndex1$1$lcssa = $RunningIndex1$026;
   }
  } while(0);
  $28 = ($RunningIndex1$1$lcssa>>>0)<($oldBoxIndicesCount>>>0);
  if (!($28)) {
   break;
  }
  $45 = (($asapBoxGroupIds) + ($33<<2)|0);
  $RunningIndex2_1$022 = $RunningIndex1$1$lcssa;
  while(1) {
   $46 = (($RunningIndex2_1$022) + 1)|0;
   $47 = (($minPosListOld) + ($RunningIndex2_1$022<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48>>>0)>($36>>>0);
   if ($49) {
    break;
   }
   $50 = (($oldBoxIndicesSorted) + ($RunningIndex2_1$022<<2)|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = HEAP32[$45>>2]|0;
   $53 = (($asapBoxGroupIds) + ($51<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($52|0)==($54|0);
   if (!($55)) {
    $56 = HEAP32[$18>>2]|0;
    $57 = (($56) + ($33<<3)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ((($56) + ($33<<3)|0) + 4|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = HEAP32[$19>>2]|0;
    $62 = (($61) + ($33<<3)|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = ((($61) + ($33<<3)|0) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($56) + ($51<<3)|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($56) + ($51<<3)|0) + 4|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($61) + ($51<<3)|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ((($61) + ($51<<3)|0) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($60>>>0)<($67>>>0);
    $75 = ($69>>>0)<($58>>>0);
    $or$cond$i = $74 | $75;
    $76 = ($65>>>0)<($71>>>0);
    $or$cond1$i = $or$cond$i | $76;
    $77 = ($73>>>0)>=($63>>>0);
    $not$or$cond1$i = $or$cond1$i ^ 1;
    $$$i = $77 & $not$or$cond1$i;
    if ($$$i) {
     (__ZN5physx7AddPairEjjRNS_14SapPairManagerERPjRjS4_($33,$51,$pairManager,$dataArray,$dataArraySize,$dataArrayCapacity)|0);
    }
   }
   $78 = ($46>>>0)<($oldBoxIndicesCount>>>0);
   if ($78) {
    $RunningIndex2_1$022 = $46;
   } else {
    break;
   }
  }
  $26 = ($27>>>0)<($newBoxIndicesCount>>>0);
  $or$cond4 = $28 & $26;
  if ($or$cond4) {
   $RunningIndex1$026 = $RunningIndex1$1$lcssa;$SortedIndex0$025 = $27;
  } else {
   break;
  }
 }
 $29 = (($asapBoxes) + ($2<<2)|0);
 $30 = (($asapBoxes) + ($4<<2)|0);
 $31 = (($asapBoxes) + ($6<<2)|0);
 $RunningIndex0$017 = 0;$SortedIndex1$016 = 0;
 while(1) {
  $80 = (($SortedIndex1$016) + 1)|0;
  $82 = (($oldBoxIndicesSorted) + ($SortedIndex1$016<<2)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = HEAP32[$29>>2]|0;
  $85 = ((($84) + ($83<<3)|0) + 4|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($RunningIndex0$017>>>0)<($newBoxIndicesCount>>>0);
  L30: do {
   if ($87) {
    $88 = (($minPosListOld) + ($SortedIndex1$016<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    $RunningIndex0$112 = $RunningIndex0$017;
    while(1) {
     $92 = (($minPosListNew) + ($RunningIndex0$112<<2)|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ($93>>>0)>($89>>>0);
     $91 = (($RunningIndex0$112) + 1)|0;
     if ($94) {
      $RunningIndex0$1$lcssa = $RunningIndex0$112;
      break L30;
     }
     $90 = ($91>>>0)<($newBoxIndicesCount>>>0);
     if ($90) {
      $RunningIndex0$112 = $91;
     } else {
      $RunningIndex0$1$lcssa = $91;
      break;
     }
    }
   } else {
    $RunningIndex0$1$lcssa = $RunningIndex0$017;
   }
  } while(0);
  $81 = ($RunningIndex0$1$lcssa>>>0)<($newBoxIndicesCount>>>0);
  if (!($81)) {
   label = 32;
   break;
  }
  $95 = (($asapBoxGroupIds) + ($83<<2)|0);
  $RunningIndex2_0$013 = $RunningIndex0$1$lcssa;
  while(1) {
   $96 = (($RunningIndex2_0$013) + 1)|0;
   $97 = (($minPosListNew) + ($RunningIndex2_0$013<<2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98>>>0)>($86>>>0);
   if ($99) {
    break;
   }
   $100 = (($newBoxIndicesSorted) + ($RunningIndex2_0$013<<2)|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = HEAP32[$95>>2]|0;
   $103 = (($asapBoxGroupIds) + ($101<<2)|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($102|0)==($104|0);
   if (!($105)) {
    $106 = HEAP32[$30>>2]|0;
    $107 = (($106) + ($83<<3)|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = ((($106) + ($83<<3)|0) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = HEAP32[$31>>2]|0;
    $112 = (($111) + ($83<<3)|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = ((($111) + ($83<<3)|0) + 4|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = (($106) + ($101<<3)|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ((($106) + ($101<<3)|0) + 4|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($111) + ($101<<3)|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = ((($111) + ($101<<3)|0) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = ($110>>>0)<($117>>>0);
    $125 = ($119>>>0)<($108>>>0);
    $or$cond$i8 = $124 | $125;
    $126 = ($115>>>0)<($121>>>0);
    $or$cond1$i9 = $or$cond$i8 | $126;
    $127 = ($123>>>0)>=($113>>>0);
    $not$or$cond1$i10 = $or$cond1$i9 ^ 1;
    $$$i11 = $127 & $not$or$cond1$i10;
    if ($$$i11) {
     (__ZN5physx7AddPairEjjRNS_14SapPairManagerERPjRjS4_($83,$101,$pairManager,$dataArray,$dataArraySize,$dataArrayCapacity)|0);
    }
   }
   $128 = ($96>>>0)<($newBoxIndicesCount>>>0);
   if ($128) {
    $RunningIndex2_0$013 = $96;
   } else {
    break;
   }
  }
  $79 = ($80>>>0)<($oldBoxIndicesCount>>>0);
  $or$cond6 = $81 & $79;
  if ($or$cond6) {
   $RunningIndex0$017 = $RunningIndex0$1$lcssa;$SortedIndex1$016 = $80;
  } else {
   label = 32;
   break;
  }
 }
 if ((label|0) == 32) {
  STACKTOP = sp;return;
 }
}
function __Z13sweepAABBAABBRKN5physx6PxVec3ES2_S2_S2_S2_S2_($centerA,$extentsA,$centerB,$extentsB,$trA,$trB) {
 $centerA = $centerA|0;
 $extentsA = $extentsA|0;
 $centerB = $centerB|0;
 $extentsB = $extentsB|0;
 $trA = $trA|0;
 $trB = $trB|0;
 var $$0 = Math_fround(0), $$phi$trans$insert = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre7 = Math_fround(0), $$pre8 = Math_fround(0), $$pre9 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0;
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0);
 var $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0;
 var $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0;
 var $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $a$05 = 0, $aMax = 0, $aMin = 0, $bMax = 0, $bMin = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i1 = Math_fround(0), $fabsf$i$i2 = Math_fround(0), $relTr = 0, $tfirst$03 = Math_fround(0), $tfirst$1 = Math_fround(0);
 var $tfirst$2 = Math_fround(0), $tfirst$3 = Math_fround(0), $tlast$04 = Math_fround(0), $tlast$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $relTr = sp + 48|0;
 $aMax = sp;
 $aMin = sp + 12|0;
 $bMax = sp + 24|0;
 $bMin = sp + 36|0;
 $0 = Math_fround(HEAPF32[$centerA>>2]);
 $1 = Math_fround(HEAPF32[$centerB>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($centerA) + 4|0);
 $4 = (($centerB) + 4|0);
 $5 = (($centerA) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($centerB) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = Math_fround(HEAPF32[$extentsA>>2]);
 $11 = Math_fround(HEAPF32[$extentsB>>2]);
 $12 = Math_fround($10 + $11);
 $13 = (($extentsA) + 4|0);
 $14 = (($extentsB) + 4|0);
 $15 = (($extentsA) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($extentsB) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 + $18);
 $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($2)))));
 $20 = !($fabsf$i$i2 <= $12);
 if ($20) {
  $$pre = Math_fround(HEAPF32[$3>>2]);
  $$pre7 = Math_fround(HEAPF32[$13>>2]);
  $$pre8 = Math_fround(HEAPF32[$4>>2]);
  $$pre9 = Math_fround(HEAPF32[$14>>2]);
  $46 = $$pre7;$47 = $$pre;$58 = $$pre9;$59 = $$pre8;
 } else {
  $21 = Math_fround(HEAPF32[$14>>2]);
  $22 = Math_fround(HEAPF32[$13>>2]);
  $23 = Math_fround(HEAPF32[$4>>2]);
  $24 = Math_fround(HEAPF32[$3>>2]);
  $25 = Math_fround($21 + $22);
  $26 = Math_fround($24 - $23);
  $fabsf$i$i1 = (Math_fround(Math_abs((Math_fround($26)))));
  $27 = !($fabsf$i$i1 <= $25);
  if ($27) {
   $46 = $22;$47 = $24;$58 = $21;$59 = $23;
  } else {
   $fabsf$i$i = (Math_fround(Math_abs((Math_fround($9)))));
   $28 = !($fabsf$i$i <= $19);
   if ($28) {
    $46 = $22;$47 = $24;$58 = $21;$59 = $23;
   } else {
    $$0 = Math_fround(0.0);
    STACKTOP = sp;return (Math_fround($$0));
   }
  }
 }
 $29 = Math_fround(HEAPF32[$trB>>2]);
 $30 = Math_fround(HEAPF32[$trA>>2]);
 $31 = Math_fround($29 - $30);
 $32 = (($trB) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($trA) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 - $35);
 $37 = (($trB) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($trA) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 - $40);
 HEAPF32[$relTr>>2] = $31;
 $42 = (($relTr) + 4|0);
 HEAPF32[$42>>2] = $36;
 $43 = (($relTr) + 8|0);
 HEAPF32[$43>>2] = $41;
 $44 = Math_fround($0 + $10);
 $45 = Math_fround($47 + $46);
 $48 = Math_fround($6 + $16);
 HEAPF32[$aMax>>2] = $44;
 $49 = (($aMax) + 4|0);
 HEAPF32[$49>>2] = $45;
 $50 = (($aMax) + 8|0);
 HEAPF32[$50>>2] = $48;
 $51 = Math_fround($0 - $10);
 $52 = Math_fround($47 - $46);
 $53 = Math_fround($6 - $16);
 HEAPF32[$aMin>>2] = $51;
 $54 = (($aMin) + 4|0);
 HEAPF32[$54>>2] = $52;
 $55 = (($aMin) + 8|0);
 HEAPF32[$55>>2] = $53;
 $56 = Math_fround($1 + $11);
 $57 = Math_fround($59 + $58);
 $60 = Math_fround($8 + $18);
 HEAPF32[$bMax>>2] = $56;
 $61 = (($bMax) + 4|0);
 HEAPF32[$61>>2] = $57;
 $62 = (($bMax) + 8|0);
 HEAPF32[$62>>2] = $60;
 $63 = Math_fround($1 - $11);
 $64 = Math_fround($59 - $58);
 $65 = Math_fround($8 - $18);
 HEAPF32[$bMin>>2] = $63;
 $66 = (($bMin) + 4|0);
 HEAPF32[$66>>2] = $64;
 $67 = (($bMin) + 8|0);
 HEAPF32[$67>>2] = $65;
 $71 = $31;$a$05 = 0;$tfirst$03 = Math_fround(0.0);$tlast$04 = Math_fround(1.0);
 L7: while(1) {
  $70 = $71 < Math_fround(-9.99999997475242707878E-7);
  do {
   if ($70) {
    $72 = (($bMax) + ($a$05<<2)|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = (($aMin) + ($a$05<<2)|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = $73 < $75;
    if ($76) {
     $$0 = Math_fround(3.40282346638528859812E+38);
     label = 23;
     break L7;
    }
    $77 = (($aMax) + ($a$05<<2)|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = (($bMin) + ($a$05<<2)|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = $78 < $80;
    if ($81) {
     $82 = Math_fround($78 - $80);
     $83 = Math_fround($82 / $71);
     $84 = $83 > $tfirst$03;
     $85 = $84 ? $83 : $tfirst$03;
     $tfirst$1 = $85;
    } else {
     $tfirst$1 = $tfirst$03;
    }
    $86 = $73 > $75;
    if ($86) {
     $87 = Math_fround($75 - $73);
     $88 = Math_fround($87 / $71);
     $89 = $88 < $tlast$04;
     $90 = $89 ? $88 : $tlast$04;
     $tfirst$3 = $tfirst$1;$tlast$1 = $90;
    } else {
     $tfirst$3 = $tfirst$1;$tlast$1 = $tlast$04;
    }
   } else {
    $91 = $71 > Math_fround(9.99999997475242707878E-7);
    if (!($91)) {
     $111 = (($bMax) + ($a$05<<2)|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = (($aMin) + ($a$05<<2)|0);
     $114 = Math_fround(HEAPF32[$113>>2]);
     $115 = $112 < $114;
     if ($115) {
      $$0 = Math_fround(3.40282346638528859812E+38);
      label = 23;
      break L7;
     }
     $116 = (($bMin) + ($a$05<<2)|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = (($aMax) + ($a$05<<2)|0);
     $119 = Math_fround(HEAPF32[$118>>2]);
     $120 = $117 > $119;
     if ($120) {
      $$0 = Math_fround(3.40282346638528859812E+38);
      label = 23;
      break L7;
     } else {
      $tfirst$3 = $tfirst$03;$tlast$1 = $tlast$04;
      break;
     }
    }
    $92 = (($bMin) + ($a$05<<2)|0);
    $93 = Math_fround(HEAPF32[$92>>2]);
    $94 = (($aMax) + ($a$05<<2)|0);
    $95 = Math_fround(HEAPF32[$94>>2]);
    $96 = $93 > $95;
    if ($96) {
     $$0 = Math_fround(3.40282346638528859812E+38);
     label = 23;
     break L7;
    }
    $97 = (($bMax) + ($a$05<<2)|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = (($aMin) + ($a$05<<2)|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $101 = $98 < $100;
    if ($101) {
     $102 = Math_fround($100 - $98);
     $103 = Math_fround($102 / $71);
     $104 = $103 > $tfirst$03;
     $105 = $104 ? $103 : $tfirst$03;
     $tfirst$2 = $105;
    } else {
     $tfirst$2 = $tfirst$03;
    }
    $106 = $95 > $93;
    if ($106) {
     $107 = Math_fround($95 - $93);
     $108 = Math_fround($107 / $71);
     $109 = $108 < $tlast$04;
     $110 = $109 ? $108 : $tlast$04;
     $tfirst$3 = $tfirst$2;$tlast$1 = $110;
    } else {
     $tfirst$3 = $tfirst$2;$tlast$1 = $tlast$04;
    }
   }
  } while(0);
  $121 = $tfirst$3 > $tlast$1;
  $69 = (($a$05) + 1)|0;
  if ($121) {
   $$0 = Math_fround(3.40282346638528859812E+38);
   label = 23;
   break;
  }
  $68 = ($69>>>0)<(3);
  if (!($68)) {
   $$0 = $tfirst$3;
   label = 23;
   break;
  }
  $$phi$trans$insert = (($relTr) + ($69<<2)|0);
  $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $71 = $$pre10;$a$05 = $69;$tfirst$03 = $tfirst$3;$tlast$04 = $tlast$1;
 }
 if ((label|0) == 23) {
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZN5physx13PxsCCDContextC2EPNS_10PxsContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $$$i$i$i$i$i = 0, $$$i$i$i$i$i2 = 0, $$$i$i$i$i$i5 = 0, $$$i$i$i$i$i8 = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $$pre$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP16[$1>>1] = -1;
 $2 = (($this) + 6|0);
 HEAP16[$2>>1] = 0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$this>>2] = ((487976 + 8|0));
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = $this;
 $7 = (($this) + 24|0);
 HEAP32[$7>>2] = 485304;
 $8 = (($this) + 28|0);
 $9 = (($this) + 32|0);
 HEAP16[$9>>1] = -1;
 $10 = (($this) + 34|0);
 HEAP16[$10>>1] = 0;
 $11 = (($this) + 36|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$8>>2] = ((434896 + 8|0));
 $12 = (($this) + 40|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 44|0);
 HEAP32[$13>>2] = 0;
 HEAP32[$8>>2] = ((487928 + 8|0));
 $14 = (($this) + 48|0);
 HEAP32[$14>>2] = $this;
 $15 = (($this) + 52|0);
 HEAP32[$15>>2] = 485336;
 $16 = (($this) + 56|0);
 $17 = (($this) + 60|0);
 HEAP16[$17>>1] = -1;
 $18 = (($this) + 62|0);
 HEAP16[$18>>1] = 0;
 $19 = (($this) + 64|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$16>>2] = ((434896 + 8|0));
 $20 = (($this) + 68|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 72|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$16>>2] = ((487880 + 8|0));
 $22 = (($this) + 76|0);
 HEAP32[$22>>2] = $this;
 $23 = (($this) + 80|0);
 HEAP32[$23>>2] = 485368;
 $24 = (($this) + 88|0);
 HEAP8[$24>>0] = 0;
 $25 = (($this) + 92|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 96|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 100|0);
 $28 = (($this) + 104|0);
 $29 = (($this) + 108|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;
 $30 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (__Z15PxGetFoundationv()|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (FUNCTION_TABLE_ii[$37 & 4095]($34)|0);
 $$$i$i$i$i$i2 = $38 ? 487040 : 485568;
 $39 = (FUNCTION_TABLE_iiiiii[$33 & 255]($30,2560,$$$i$i$i$i$i2,486184,203)|0);
 HEAP32[$0>>2] = $39;
 $40 = (($0) + 4|0);
 HEAP32[$40>>2] = 0;
 $41 = HEAP32[$29>>2]|0;
 $42 = $41 & 2147483647;
 $43 = HEAP32[$28>>2]|0;
 $44 = ($42>>>0)>($43>>>0);
 if ($44) {
  $45 = HEAP32[$27>>2]|0;
  $46 = (($45) + ($43<<3)|0);
  $47 = ($46|0)==(0|0);
  if ($47) {
   $59 = $43;
  } else {
   $48 = $0;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $46;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   $$pre$i$i$i3 = HEAP32[$28>>2]|0;
   $59 = $$pre$i$i$i3;
  }
  $58 = (($59) + 1)|0;
  HEAP32[$28>>2] = $58;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_10PxsCCDBodyELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($27,$0)|0);
 }
 $60 = (($this) + 116|0);
 $61 = (($this) + 120|0);
 $62 = (($this) + 124|0);
 ;HEAP32[$60+0>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;
 $63 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (__Z15PxGetFoundationv()|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + 24|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
 $$$i$i$i$i$i5 = $71 ? 486648 : 485568;
 $72 = (FUNCTION_TABLE_iiiiii[$66 & 255]($63,1024,$$$i$i$i$i$i5,486184,203)|0);
 HEAP32[$0>>2] = $72;
 $73 = (($0) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = HEAP32[$62>>2]|0;
 $75 = $74 & 2147483647;
 $76 = HEAP32[$61>>2]|0;
 $77 = ($75>>>0)>($76>>>0);
 if ($77) {
  $78 = HEAP32[$60>>2]|0;
  $79 = (($78) + ($76<<3)|0);
  $80 = ($79|0)==(0|0);
  if ($80) {
   $92 = $76;
  } else {
   $81 = $0;
   $82 = $81;
   $83 = HEAP32[$82>>2]|0;
   $84 = (($81) + 4)|0;
   $85 = $84;
   $86 = HEAP32[$85>>2]|0;
   $87 = $79;
   $88 = $87;
   HEAP32[$88>>2] = $83;
   $89 = (($87) + 4)|0;
   $90 = $89;
   HEAP32[$90>>2] = $86;
   $$pre$i$i$i6 = HEAP32[$61>>2]|0;
   $92 = $$pre$i$i$i6;
  }
  $91 = (($92) + 1)|0;
  HEAP32[$61>>2] = $91;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_13PxsCCDOverlapELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($60,$0)|0);
 }
 $93 = (($this) + 132|0);
 $94 = (($this) + 136|0);
 $95 = (($this) + 140|0);
 ;HEAP32[$93+0>>2]=0|0;HEAP32[$93+4>>2]=0|0;HEAP32[$93+8>>2]=0|0;HEAP32[$93+12>>2]=0|0;
 $96 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = (($97) + 8|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = (__Z15PxGetFoundationv()|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = (($101) + 24|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (FUNCTION_TABLE_ii[$103 & 4095]($100)|0);
 $$$i$i$i$i$i8 = $104 ? 487504 : 485568;
 $105 = (FUNCTION_TABLE_iiiiii[$99 & 255]($96,12288,$$$i$i$i$i$i8,486184,203)|0);
 HEAP32[$0>>2] = $105;
 $106 = (($0) + 4|0);
 HEAP32[$106>>2] = 0;
 $107 = HEAP32[$95>>2]|0;
 $108 = $107 & 2147483647;
 $109 = HEAP32[$94>>2]|0;
 $110 = ($108>>>0)>($109>>>0);
 if ($110) {
  $111 = HEAP32[$93>>2]|0;
  $112 = (($111) + ($109<<3)|0);
  $113 = ($112|0)==(0|0);
  if ($113) {
   $125 = $109;
  } else {
   $114 = $0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = (($114) + 4)|0;
   $118 = $117;
   $119 = HEAP32[$118>>2]|0;
   $120 = $112;
   $121 = $120;
   HEAP32[$121>>2] = $116;
   $122 = (($120) + 4)|0;
   $123 = $122;
   HEAP32[$123>>2] = $119;
   $$pre$i$i$i9 = HEAP32[$94>>2]|0;
   $125 = $$pre$i$i$i9;
  }
  $124 = (($125) + 1)|0;
  HEAP32[$94>>2] = $124;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_11PxsCCDShapeELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($93,$0)|0);
 }
 $126 = (($this) + 148|0);
 $127 = (($this) + 196|0);
 dest=$126+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$127>>2] = Math_fround(0.75);
 $128 = (($this) + 200|0);
 HEAP32[$128>>2] = -1;
 $129 = (($this) + 204|0);
 HEAP32[$129>>2] = 0;
 $130 = (($this) + 208|0);
 HEAP32[$130>>2] = 0;
 $131 = (($this) + 172|0);
 __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IPKNS_12PxsRigidCoreEPKNS_12PxsShapeCoreEEEPNS_11PxsCCDShapeEEESA_NS0_4HashISA_EENS1_11HashMapBaseISA_SD_SG_NS0_9AllocatorEE6GetKeyESI_Lb1EE15reserveInternalEj($131,64);
 $132 = (($this) + 212|0);
 $133 = (($this) + 216|0);
 $134 = (($this) + 220|0);
 ;HEAP32[$132+0>>2]=0|0;HEAP32[$132+4>>2]=0|0;HEAP32[$132+8>>2]=0|0;HEAP32[$132+12>>2]=0|0;
 $135 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = (($136) + 8|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = (__Z15PxGetFoundationv()|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = (($140) + 24|0);
 $142 = HEAP32[$141>>2]|0;
 $143 = (FUNCTION_TABLE_ii[$142 & 4095]($139)|0);
 $$$i$i$i$i$i = $143 ? 486272 : 485568;
 $144 = (FUNCTION_TABLE_iiiiii[$138 & 255]($135,13824,$$$i$i$i$i$i,486184,203)|0);
 HEAP32[$0>>2] = $144;
 $145 = (($0) + 4|0);
 HEAP32[$145>>2] = 0;
 $146 = HEAP32[$134>>2]|0;
 $147 = $146 & 2147483647;
 $148 = HEAP32[$133>>2]|0;
 $149 = ($147>>>0)>($148>>>0);
 if (!($149)) {
  (__ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_10PxsCCDPairELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($132,$0)|0);
  $165 = (($this) + 228|0);
  $166 = (($this) + 260|0);
  ;HEAP32[$165+0>>2]=0|0;HEAP32[$165+4>>2]=0|0;HEAP32[$165+8>>2]=0|0;HEAP32[$165+12>>2]=0|0;HEAP32[$165+16>>2]=0|0;HEAP32[$165+20>>2]=0|0;HEAP32[$165+24>>2]=0|0;HEAP32[$165+28>>2]=0|0;
  HEAP32[$166>>2] = 1;
  $167 = (($this) + 264|0);
  HEAP32[$167>>2] = $context;
  STACKTOP = sp;return;
 }
 $150 = HEAP32[$132>>2]|0;
 $151 = (($150) + ($148<<3)|0);
 $152 = ($151|0)==(0|0);
 if ($152) {
  $164 = $148;
 } else {
  $153 = $0;
  $154 = $153;
  $155 = HEAP32[$154>>2]|0;
  $156 = (($153) + 4)|0;
  $157 = $156;
  $158 = HEAP32[$157>>2]|0;
  $159 = $151;
  $160 = $159;
  HEAP32[$160>>2] = $155;
  $161 = (($159) + 4)|0;
  $162 = $161;
  HEAP32[$162>>2] = $158;
  $$pre$i$i$i = HEAP32[$133>>2]|0;
  $164 = $$pre$i$i$i;
 }
 $163 = (($164) + 1)|0;
 HEAP32[$133>>2] = $163;
 $165 = (($this) + 228|0);
 $166 = (($this) + 260|0);
 ;HEAP32[$165+0>>2]=0|0;HEAP32[$165+4>>2]=0|0;HEAP32[$165+8>>2]=0|0;HEAP32[$165+12>>2]=0|0;HEAP32[$165+16>>2]=0|0;HEAP32[$165+20>>2]=0|0;HEAP32[$165+24>>2]=0|0;HEAP32[$165+28>>2]=0|0;
 HEAP32[$166>>2] = 1;
 $167 = (($this) + 264|0);
 HEAP32[$167>>2] = $context;
 STACKTOP = sp;return;
}
function __ZN5physx13PxsCCDContextD2Ev($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $$pre$i$i13 = 0, $$pre$i$i19 = 0, $$pre$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i$i = 0, $i$01$i$i11 = 0, $i$01$i$i17 = 0;
 var $i$01$i$i5 = 0, $or$cond$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i$i14 = 0, $or$cond$i$i$i$i20 = 0, $or$cond$i$i$i$i8 = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 248|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3|0)!=(0);
 $5 = ($2|0)>(-1);
 $or$cond$i$i = $4 & $5;
 if ($or$cond$i$i) {
  $6 = (($this) + 240|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vii[$12 & 4095]($9,$7);
  }
 }
 $13 = (($this) + 236|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 2147483647;
 $16 = ($15|0)!=(0);
 $17 = ($14|0)>(-1);
 $or$cond$i$i1 = $16 & $17;
 if ($or$cond$i$i1) {
  $18 = (($this) + 228|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if (!($20)) {
   $21 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_vii[$24 & 4095]($21,$19);
  }
 }
 $25 = (($this) + 212|0);
 $26 = (($this) + 216|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if (!($28)) {
  $149 = $27;$i$01$i$i = 0;
  while(1) {
   $29 = HEAP32[$25>>2]|0;
   $30 = (($29) + ($i$01$i$i<<3)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    $35 = $149;
   } else {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$31);
    $$pre$i$i = HEAP32[$26>>2]|0;
    $35 = $$pre$i$i;
   }
   $33 = (($i$01$i$i) + 1)|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    $149 = $35;$i$01$i$i = $33;
   } else {
    break;
   }
  }
 }
 $36 = (($this) + 224|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 220|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 2147483647;
 $40 = ($39|0)!=(0);
 $41 = ($38|0)>(-1);
 $or$cond$i$i$i$i = $40 & $41;
 if ($or$cond$i$i$i$i) {
  $42 = HEAP32[$25>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($44,$42);
  }
 }
 $48 = (($this) + 172|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($48,$49);
 }
 $51 = (($this) + 168|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 & 2147483647;
 $54 = ($53|0)!=(0);
 $55 = ($52|0)>(-1);
 $or$cond$i$i2 = $54 & $55;
 if ($or$cond$i$i2) {
  $56 = (($this) + 160|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($60) + 12|0);
   $62 = HEAP32[$61>>2]|0;
   FUNCTION_TABLE_vii[$62 & 4095]($59,$57);
  }
 }
 $63 = (($this) + 156|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 & 2147483647;
 $66 = ($65|0)!=(0);
 $67 = ($64|0)>(-1);
 $or$cond$i$i3 = $66 & $67;
 if ($or$cond$i$i3) {
  $68 = (($this) + 148|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if (!($70)) {
   $71 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($72) + 12|0);
   $74 = HEAP32[$73>>2]|0;
   FUNCTION_TABLE_vii[$74 & 4095]($71,$69);
  }
 }
 $75 = (($this) + 132|0);
 $76 = (($this) + 136|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0);
 if (!($78)) {
  $150 = $77;$i$01$i$i5 = 0;
  while(1) {
   $79 = HEAP32[$75>>2]|0;
   $80 = (($79) + ($i$01$i$i5<<3)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0|0);
   if ($82) {
    $85 = $150;
   } else {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$81);
    $$pre$i$i7 = HEAP32[$76>>2]|0;
    $85 = $$pre$i$i7;
   }
   $83 = (($i$01$i$i5) + 1)|0;
   $84 = ($83>>>0)<($85>>>0);
   if ($84) {
    $150 = $85;$i$01$i$i5 = $83;
   } else {
    break;
   }
  }
 }
 $86 = (($this) + 144|0);
 HEAP32[$86>>2] = 0;
 $87 = (($this) + 140|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = $88 & 2147483647;
 $90 = ($89|0)!=(0);
 $91 = ($88|0)>(-1);
 $or$cond$i$i$i$i8 = $90 & $91;
 if ($or$cond$i$i$i$i8) {
  $92 = HEAP32[$75>>2]|0;
  $93 = ($92|0)==(0|0);
  if (!($93)) {
   $94 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($95) + 12|0);
   $97 = HEAP32[$96>>2]|0;
   FUNCTION_TABLE_vii[$97 & 4095]($94,$92);
  }
 }
 $98 = (($this) + 116|0);
 $99 = (($this) + 120|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = ($100|0)==(0);
 if (!($101)) {
  $151 = $100;$i$01$i$i11 = 0;
  while(1) {
   $102 = HEAP32[$98>>2]|0;
   $103 = (($102) + ($i$01$i$i11<<3)|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($104|0)==(0|0);
   if ($105) {
    $108 = $151;
   } else {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$104);
    $$pre$i$i13 = HEAP32[$99>>2]|0;
    $108 = $$pre$i$i13;
   }
   $106 = (($i$01$i$i11) + 1)|0;
   $107 = ($106>>>0)<($108>>>0);
   if ($107) {
    $151 = $108;$i$01$i$i11 = $106;
   } else {
    break;
   }
  }
 }
 $109 = (($this) + 128|0);
 HEAP32[$109>>2] = 0;
 $110 = (($this) + 124|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = $111 & 2147483647;
 $113 = ($112|0)!=(0);
 $114 = ($111|0)>(-1);
 $or$cond$i$i$i$i14 = $113 & $114;
 if ($or$cond$i$i$i$i14) {
  $115 = HEAP32[$98>>2]|0;
  $116 = ($115|0)==(0|0);
  if (!($116)) {
   $117 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($118) + 12|0);
   $120 = HEAP32[$119>>2]|0;
   FUNCTION_TABLE_vii[$120 & 4095]($117,$115);
  }
 }
 $121 = (($this) + 100|0);
 $122 = (($this) + 104|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ($123|0)==(0);
 if (!($124)) {
  $152 = $123;$i$01$i$i17 = 0;
  while(1) {
   $125 = HEAP32[$121>>2]|0;
   $126 = (($125) + ($i$01$i$i17<<3)|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)==(0|0);
   if ($128) {
    $131 = $152;
   } else {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$127);
    $$pre$i$i19 = HEAP32[$122>>2]|0;
    $131 = $$pre$i$i19;
   }
   $129 = (($i$01$i$i17) + 1)|0;
   $130 = ($129>>>0)<($131>>>0);
   if ($130) {
    $152 = $131;$i$01$i$i17 = $129;
   } else {
    break;
   }
  }
 }
 $132 = (($this) + 112|0);
 HEAP32[$132>>2] = 0;
 $133 = (($this) + 108|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = $134 & 2147483647;
 $136 = ($135|0)!=(0);
 $137 = ($134|0)>(-1);
 $or$cond$i$i$i$i20 = $136 & $137;
 if (!($or$cond$i$i$i$i20)) {
  $144 = (($this) + 56|0);
  HEAP32[$144>>2] = ((434896 + 8|0));
  $145 = (($this) + 64|0);
  HEAP32[$145>>2] = 0;
  $146 = (($this) + 28|0);
  HEAP32[$146>>2] = ((434896 + 8|0));
  $147 = (($this) + 36|0);
  HEAP32[$147>>2] = 0;
  HEAP32[$this>>2] = ((434896 + 8|0));
  $148 = (($this) + 8|0);
  HEAP32[$148>>2] = 0;
  STACKTOP = sp;return;
 }
 $138 = HEAP32[$121>>2]|0;
 $139 = ($138|0)==(0|0);
 if ($139) {
  $144 = (($this) + 56|0);
  HEAP32[$144>>2] = ((434896 + 8|0));
  $145 = (($this) + 64|0);
  HEAP32[$145>>2] = 0;
  $146 = (($this) + 28|0);
  HEAP32[$146>>2] = ((434896 + 8|0));
  $147 = (($this) + 36|0);
  HEAP32[$147>>2] = 0;
  HEAP32[$this>>2] = ((434896 + 8|0));
  $148 = (($this) + 8|0);
  HEAP32[$148>>2] = 0;
  STACKTOP = sp;return;
 }
 $140 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (($141) + 12|0);
 $143 = HEAP32[$142>>2]|0;
 FUNCTION_TABLE_vii[$143 & 4095]($140,$138);
 $144 = (($this) + 56|0);
 HEAP32[$144>>2] = ((434896 + 8|0));
 $145 = (($this) + 64|0);
 HEAP32[$145>>2] = 0;
 $146 = (($this) + 28|0);
 HEAP32[$146>>2] = ((434896 + 8|0));
 $147 = (($this) + 36|0);
 HEAP32[$147>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $148 = (($this) + 8|0);
 HEAP32[$148>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_18postCCDDepenetrateEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_14postCCDAdvanceEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_12postCCDSweepEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx13PxsCCDContext6createEPNS_10PxsContextE($context) {
 $context = $context|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,268,485408,275)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return ($1|0);
 }
 __ZN5physx13PxsCCDContextC2EPNS_10PxsContextE($1,$context);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx13PxsCCDContext7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx13PxsCCDContextD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx11PxsCCDShape10getAbsPoseEPKNS_12PxsRigidBodyE($agg$result,$this,$atom) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $atom = $atom|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0;
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0;
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($atom|0)==(0|0);
 if ($0) {
  $217 = (($this) + 4|0);
  $218 = HEAP32[$217>>2]|0;
  $219 = HEAP32[$this>>2]|0;
  $220 = (($219) + 16|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = Math_fround($221 * Math_fround(2.0));
  $223 = (($219) + 20|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = Math_fround($224 * Math_fround(2.0));
  $226 = (($219) + 24|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = Math_fround($227 * Math_fround(2.0));
  $229 = (($218) + 12|0);
  $230 = Math_fround(HEAPF32[$229>>2]);
  $231 = Math_fround($230 * $230);
  $232 = Math_fround($231 + Math_fround(-0.5));
  $233 = Math_fround(HEAPF32[$218>>2]);
  $234 = Math_fround($222 * $233);
  $235 = (($218) + 4|0);
  $236 = Math_fround(HEAPF32[$235>>2]);
  $237 = Math_fround($225 * $236);
  $238 = Math_fround($234 + $237);
  $239 = (($218) + 8|0);
  $240 = Math_fround(HEAPF32[$239>>2]);
  $241 = Math_fround($228 * $240);
  $242 = Math_fround($238 + $241);
  $243 = Math_fround($222 * $232);
  $244 = Math_fround($228 * $236);
  $245 = Math_fround($225 * $240);
  $246 = Math_fround($244 - $245);
  $247 = Math_fround($230 * $246);
  $248 = Math_fround($243 + $247);
  $249 = Math_fround($233 * $242);
  $250 = Math_fround($249 + $248);
  $251 = Math_fround($225 * $232);
  $252 = Math_fround($222 * $240);
  $253 = Math_fround($228 * $233);
  $254 = Math_fround($252 - $253);
  $255 = Math_fround($230 * $254);
  $256 = Math_fround($251 + $255);
  $257 = Math_fround($236 * $242);
  $258 = Math_fround($257 + $256);
  $259 = Math_fround($228 * $232);
  $260 = Math_fround($225 * $233);
  $261 = Math_fround($222 * $236);
  $262 = Math_fround($260 - $261);
  $263 = Math_fround($230 * $262);
  $264 = Math_fround($259 + $263);
  $265 = Math_fround($240 * $242);
  $266 = Math_fround($264 + $265);
  $267 = (($218) + 16|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = Math_fround($268 + $250);
  $270 = (($218) + 20|0);
  $271 = Math_fround(HEAPF32[$270>>2]);
  $272 = Math_fround($271 + $258);
  $273 = (($218) + 24|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = Math_fround($274 + $266);
  $276 = Math_fround(HEAPF32[$219>>2]);
  $277 = Math_fround($230 * $276);
  $278 = (($219) + 12|0);
  $279 = Math_fround(HEAPF32[$278>>2]);
  $280 = Math_fround($233 * $279);
  $281 = Math_fround($277 + $280);
  $282 = (($219) + 8|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = Math_fround($236 * $283);
  $285 = Math_fround($281 + $284);
  $286 = (($219) + 4|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $288 = Math_fround($240 * $287);
  $289 = Math_fround($285 - $288);
  $290 = Math_fround($230 * $287);
  $291 = Math_fround($236 * $279);
  $292 = Math_fround($291 + $290);
  $293 = Math_fround($240 * $276);
  $294 = Math_fround($293 + $292);
  $295 = Math_fround($233 * $283);
  $296 = Math_fround($294 - $295);
  $297 = Math_fround($230 * $283);
  $298 = Math_fround($240 * $279);
  $299 = Math_fround($298 + $297);
  $300 = Math_fround($233 * $287);
  $301 = Math_fround($300 + $299);
  $302 = Math_fround($236 * $276);
  $303 = Math_fround($301 - $302);
  $304 = Math_fround($230 * $279);
  $305 = Math_fround($233 * $276);
  $306 = Math_fround($304 - $305);
  $307 = Math_fround($236 * $287);
  $308 = Math_fround($306 - $307);
  $309 = Math_fround($240 * $283);
  $310 = Math_fround($308 - $309);
  HEAPF32[$agg$result>>2] = $289;
  $311 = (($agg$result) + 4|0);
  HEAPF32[$311>>2] = $296;
  $312 = (($agg$result) + 8|0);
  HEAPF32[$312>>2] = $303;
  $313 = (($agg$result) + 12|0);
  HEAPF32[$313>>2] = $310;
  $314 = (($agg$result) + 16|0);
  HEAPF32[$314>>2] = $269;
  $315 = (($agg$result) + 20|0);
  HEAPF32[$315>>2] = $272;
  $316 = (($agg$result) + 24|0);
  HEAPF32[$316>>2] = $275;
  STACKTOP = sp;return;
 } else {
  $1 = (($atom) + 64|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + 48|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($2) + 52|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($2) + 56|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround($4 * Math_fround(-2.0));
  $10 = Math_fround($6 * Math_fround(-2.0));
  $11 = Math_fround($8 * Math_fround(-2.0));
  $12 = (($2) + 44|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($13 * $13);
  $15 = Math_fround($14 + Math_fround(-0.5));
  $16 = (($2) + 32|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($9 * $17);
  $19 = (($2) + 36|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($10 * $20);
  $22 = Math_fround($18 + $21);
  $23 = (($2) + 40|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($11 * $24);
  $26 = Math_fround($22 + $25);
  $27 = Math_fround($9 * $15);
  $28 = Math_fround($11 * $20);
  $29 = Math_fround($10 * $24);
  $30 = Math_fround($28 - $29);
  $31 = Math_fround($13 * $30);
  $32 = Math_fround($27 - $31);
  $33 = Math_fround($17 * $26);
  $34 = Math_fround($33 + $32);
  $35 = Math_fround($10 * $15);
  $36 = Math_fround($9 * $24);
  $37 = Math_fround($11 * $17);
  $38 = Math_fround($36 - $37);
  $39 = Math_fround($13 * $38);
  $40 = Math_fround($35 - $39);
  $41 = Math_fround($20 * $26);
  $42 = Math_fround($41 + $40);
  $43 = Math_fround($11 * $15);
  $44 = Math_fround($10 * $17);
  $45 = Math_fround($9 * $20);
  $46 = Math_fround($44 - $45);
  $47 = Math_fround($13 * $46);
  $48 = Math_fround($43 - $47);
  $49 = Math_fround($24 * $26);
  $50 = Math_fround($48 + $49);
  $51 = Math_fround(-$17);
  $52 = Math_fround(-$20);
  $53 = Math_fround(-$24);
  $54 = Math_fround($34 * Math_fround(2.0));
  $55 = Math_fround($42 * Math_fround(2.0));
  $56 = Math_fround($50 * Math_fround(2.0));
  $57 = (($2) + 12|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($58 * $58);
  $60 = Math_fround($59 + Math_fround(-0.5));
  $61 = Math_fround(HEAPF32[$2>>2]);
  $62 = Math_fround($61 * $54);
  $63 = (($2) + 4|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($64 * $55);
  $66 = Math_fround($62 + $65);
  $67 = (($2) + 8|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($68 * $56);
  $70 = Math_fround($69 + $66);
  $71 = Math_fround($60 * $54);
  $72 = Math_fround($64 * $56);
  $73 = Math_fround($68 * $55);
  $74 = Math_fround($72 - $73);
  $75 = Math_fround($58 * $74);
  $76 = Math_fround($71 + $75);
  $77 = Math_fround($61 * $70);
  $78 = Math_fround($77 + $76);
  $79 = Math_fround($60 * $55);
  $80 = Math_fround($68 * $54);
  $81 = Math_fround($61 * $56);
  $82 = Math_fround($80 - $81);
  $83 = Math_fround($58 * $82);
  $84 = Math_fround($79 + $83);
  $85 = Math_fround($64 * $70);
  $86 = Math_fround($85 + $84);
  $87 = Math_fround($60 * $56);
  $88 = Math_fround($61 * $55);
  $89 = Math_fround($64 * $54);
  $90 = Math_fround($88 - $89);
  $91 = Math_fround($58 * $90);
  $92 = Math_fround($87 + $91);
  $93 = Math_fround($68 * $70);
  $94 = Math_fround($92 + $93);
  $95 = (($2) + 16|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = Math_fround($96 + $78);
  $98 = (($2) + 20|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = Math_fround($99 + $86);
  $101 = (($2) + 24|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($102 + $94);
  $104 = Math_fround($58 * $51);
  $105 = Math_fround($13 * $61);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($64 * $53);
  $108 = Math_fround($106 + $107);
  $109 = Math_fround($68 * $52);
  $110 = Math_fround($108 - $109);
  $111 = Math_fround($58 * $52);
  $112 = Math_fround($13 * $64);
  $113 = Math_fround($111 + $112);
  $114 = Math_fround($68 * $51);
  $115 = Math_fround($114 + $113);
  $116 = Math_fround($61 * $53);
  $117 = Math_fround($115 - $116);
  $118 = Math_fround($58 * $53);
  $119 = Math_fround($13 * $68);
  $120 = Math_fround($118 + $119);
  $121 = Math_fround($61 * $52);
  $122 = Math_fround($121 + $120);
  $123 = Math_fround($64 * $51);
  $124 = Math_fround($122 - $123);
  $125 = Math_fround($13 * $58);
  $126 = Math_fround($61 * $51);
  $127 = Math_fround($125 - $126);
  $128 = Math_fround($64 * $52);
  $129 = Math_fround($127 - $128);
  $130 = Math_fround($68 * $53);
  $131 = Math_fround($129 - $130);
  $132 = HEAP32[$this>>2]|0;
  $133 = (($132) + 16|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($134 * Math_fround(2.0));
  $136 = (($132) + 20|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = Math_fround($137 * Math_fround(2.0));
  $139 = (($132) + 24|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = Math_fround($140 * Math_fround(2.0));
  $142 = Math_fround($131 * $131);
  $143 = Math_fround($142 + Math_fround(-0.5));
  $144 = Math_fround($110 * $135);
  $145 = Math_fround($117 * $138);
  $146 = Math_fround($144 + $145);
  $147 = Math_fround($124 * $141);
  $148 = Math_fround($146 + $147);
  $149 = Math_fround($143 * $135);
  $150 = Math_fround($117 * $141);
  $151 = Math_fround($124 * $138);
  $152 = Math_fround($150 - $151);
  $153 = Math_fround($131 * $152);
  $154 = Math_fround($149 + $153);
  $155 = Math_fround($110 * $148);
  $156 = Math_fround($155 + $154);
  $157 = Math_fround($143 * $138);
  $158 = Math_fround($124 * $135);
  $159 = Math_fround($110 * $141);
  $160 = Math_fround($158 - $159);
  $161 = Math_fround($131 * $160);
  $162 = Math_fround($157 + $161);
  $163 = Math_fround($117 * $148);
  $164 = Math_fround($163 + $162);
  $165 = Math_fround($143 * $141);
  $166 = Math_fround($110 * $138);
  $167 = Math_fround($117 * $135);
  $168 = Math_fround($166 - $167);
  $169 = Math_fround($131 * $168);
  $170 = Math_fround($165 + $169);
  $171 = Math_fround($124 * $148);
  $172 = Math_fround($170 + $171);
  $173 = Math_fround($97 + $156);
  $174 = Math_fround($100 + $164);
  $175 = Math_fround($103 + $172);
  $176 = Math_fround(HEAPF32[$132>>2]);
  $177 = Math_fround($131 * $176);
  $178 = (($132) + 12|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = Math_fround($110 * $179);
  $181 = Math_fround($177 + $180);
  $182 = (($132) + 8|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = Math_fround($117 * $183);
  $185 = Math_fround($181 + $184);
  $186 = (($132) + 4|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = Math_fround($124 * $187);
  $189 = Math_fround($185 - $188);
  $190 = Math_fround($131 * $187);
  $191 = Math_fround($117 * $179);
  $192 = Math_fround($191 + $190);
  $193 = Math_fround($124 * $176);
  $194 = Math_fround($193 + $192);
  $195 = Math_fround($110 * $183);
  $196 = Math_fround($194 - $195);
  $197 = Math_fround($131 * $183);
  $198 = Math_fround($124 * $179);
  $199 = Math_fround($198 + $197);
  $200 = Math_fround($110 * $187);
  $201 = Math_fround($200 + $199);
  $202 = Math_fround($117 * $176);
  $203 = Math_fround($201 - $202);
  $204 = Math_fround($131 * $179);
  $205 = Math_fround($110 * $176);
  $206 = Math_fround($204 - $205);
  $207 = Math_fround($117 * $187);
  $208 = Math_fround($206 - $207);
  $209 = Math_fround($124 * $183);
  $210 = Math_fround($208 - $209);
  HEAPF32[$agg$result>>2] = $189;
  $211 = (($agg$result) + 4|0);
  HEAPF32[$211>>2] = $196;
  $212 = (($agg$result) + 8|0);
  HEAPF32[$212>>2] = $203;
  $213 = (($agg$result) + 12|0);
  HEAPF32[$213>>2] = $210;
  $214 = (($agg$result) + 16|0);
  HEAPF32[$214>>2] = $173;
  $215 = (($agg$result) + 20|0);
  HEAPF32[$215>>2] = $174;
  $216 = (($agg$result) + 24|0);
  HEAPF32[$216>>2] = $175;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx11PxsCCDShape17getLastCCDAbsPoseEPKNS_12PxsRigidBodyE($agg$result,$this,$atom) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $atom = $atom|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($atom) + 32|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($atom) + 36|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($atom) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($atom) + 44|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($atom) + 48|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($atom) + 52|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($atom) + 56|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($atom) + 64|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 48|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($15) + 52|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($15) + 56|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($17 * Math_fround(-2.0));
 $23 = Math_fround($19 * Math_fround(-2.0));
 $24 = Math_fround($21 * Math_fround(-2.0));
 $25 = (($15) + 44|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $26);
 $28 = Math_fround($27 + Math_fround(-0.5));
 $29 = (($15) + 32|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($22 * $30);
 $32 = (($15) + 36|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($23 * $33);
 $35 = Math_fround($31 + $34);
 $36 = (($15) + 40|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($24 * $37);
 $39 = Math_fround($35 + $38);
 $40 = Math_fround($22 * $28);
 $41 = Math_fround($24 * $33);
 $42 = Math_fround($23 * $37);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($26 * $43);
 $45 = Math_fround($40 - $44);
 $46 = Math_fround($30 * $39);
 $47 = Math_fround($46 + $45);
 $48 = Math_fround($23 * $28);
 $49 = Math_fround($22 * $37);
 $50 = Math_fround($24 * $30);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($26 * $51);
 $53 = Math_fround($48 - $52);
 $54 = Math_fround($33 * $39);
 $55 = Math_fround($54 + $53);
 $56 = Math_fround($24 * $28);
 $57 = Math_fround($23 * $30);
 $58 = Math_fround($22 * $33);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($26 * $59);
 $61 = Math_fround($56 - $60);
 $62 = Math_fround($37 * $39);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround(-$30);
 $65 = Math_fround(-$33);
 $66 = Math_fround(-$37);
 $67 = Math_fround($47 * Math_fround(2.0));
 $68 = Math_fround($55 * Math_fround(2.0));
 $69 = Math_fround($63 * Math_fround(2.0));
 $70 = Math_fround($7 * $7);
 $71 = Math_fround($70 + Math_fround(-0.5));
 $72 = Math_fround($1 * $67);
 $73 = Math_fround($3 * $68);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($5 * $69);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($71 * $67);
 $78 = Math_fround($3 * $69);
 $79 = Math_fround($5 * $68);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($7 * $80);
 $82 = Math_fround($77 + $81);
 $83 = Math_fround($1 * $76);
 $84 = Math_fround($83 + $82);
 $85 = Math_fround($71 * $68);
 $86 = Math_fround($5 * $67);
 $87 = Math_fround($1 * $69);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($7 * $88);
 $90 = Math_fround($85 + $89);
 $91 = Math_fround($3 * $76);
 $92 = Math_fround($91 + $90);
 $93 = Math_fround($71 * $69);
 $94 = Math_fround($1 * $68);
 $95 = Math_fround($3 * $67);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($7 * $96);
 $98 = Math_fround($93 + $97);
 $99 = Math_fround($5 * $76);
 $100 = Math_fround($98 + $99);
 $101 = Math_fround($9 + $84);
 $102 = Math_fround($11 + $92);
 $103 = Math_fround($13 + $100);
 $104 = Math_fround($7 * $64);
 $105 = Math_fround($1 * $26);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($3 * $66);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($5 * $65);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($7 * $65);
 $112 = Math_fround($3 * $26);
 $113 = Math_fround($112 + $111);
 $114 = Math_fround($5 * $64);
 $115 = Math_fround($114 + $113);
 $116 = Math_fround($1 * $66);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($7 * $66);
 $119 = Math_fround($5 * $26);
 $120 = Math_fround($119 + $118);
 $121 = Math_fround($1 * $65);
 $122 = Math_fround($121 + $120);
 $123 = Math_fround($3 * $64);
 $124 = Math_fround($122 - $123);
 $125 = Math_fround($7 * $26);
 $126 = Math_fround($1 * $64);
 $127 = Math_fround($125 - $126);
 $128 = Math_fround($3 * $65);
 $129 = Math_fround($127 - $128);
 $130 = Math_fround($5 * $66);
 $131 = Math_fround($129 - $130);
 $132 = HEAP32[$this>>2]|0;
 $133 = (($132) + 16|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($134 * Math_fround(2.0));
 $136 = (($132) + 20|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($137 * Math_fround(2.0));
 $139 = (($132) + 24|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($140 * Math_fround(2.0));
 $142 = Math_fround($131 * $131);
 $143 = Math_fround($142 + Math_fround(-0.5));
 $144 = Math_fround($135 * $110);
 $145 = Math_fround($138 * $117);
 $146 = Math_fround($144 + $145);
 $147 = Math_fround($141 * $124);
 $148 = Math_fround($146 + $147);
 $149 = Math_fround($135 * $143);
 $150 = Math_fround($117 * $141);
 $151 = Math_fround($138 * $124);
 $152 = Math_fround($150 - $151);
 $153 = Math_fround($131 * $152);
 $154 = Math_fround($149 + $153);
 $155 = Math_fround($110 * $148);
 $156 = Math_fround($155 + $154);
 $157 = Math_fround($138 * $143);
 $158 = Math_fround($135 * $124);
 $159 = Math_fround($110 * $141);
 $160 = Math_fround($158 - $159);
 $161 = Math_fround($131 * $160);
 $162 = Math_fround($157 + $161);
 $163 = Math_fround($117 * $148);
 $164 = Math_fround($163 + $162);
 $165 = Math_fround($141 * $143);
 $166 = Math_fround($138 * $110);
 $167 = Math_fround($135 * $117);
 $168 = Math_fround($166 - $167);
 $169 = Math_fround($131 * $168);
 $170 = Math_fround($165 + $169);
 $171 = Math_fround($124 * $148);
 $172 = Math_fround($170 + $171);
 $173 = Math_fround($156 + $101);
 $174 = Math_fround($164 + $102);
 $175 = Math_fround($172 + $103);
 $176 = Math_fround(HEAPF32[$132>>2]);
 $177 = Math_fround($131 * $176);
 $178 = (($132) + 12|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround($110 * $179);
 $181 = Math_fround($177 + $180);
 $182 = (($132) + 8|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = Math_fround($117 * $183);
 $185 = Math_fround($181 + $184);
 $186 = (($132) + 4|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = Math_fround($124 * $187);
 $189 = Math_fround($185 - $188);
 $190 = Math_fround($131 * $187);
 $191 = Math_fround($117 * $179);
 $192 = Math_fround($191 + $190);
 $193 = Math_fround($124 * $176);
 $194 = Math_fround($193 + $192);
 $195 = Math_fround($110 * $183);
 $196 = Math_fround($194 - $195);
 $197 = Math_fround($131 * $183);
 $198 = Math_fround($124 * $179);
 $199 = Math_fround($198 + $197);
 $200 = Math_fround($110 * $187);
 $201 = Math_fround($200 + $199);
 $202 = Math_fround($117 * $176);
 $203 = Math_fround($201 - $202);
 $204 = Math_fround($131 * $179);
 $205 = Math_fround($110 * $176);
 $206 = Math_fround($204 - $205);
 $207 = Math_fround($117 * $187);
 $208 = Math_fround($206 - $207);
 $209 = Math_fround($124 * $183);
 $210 = Math_fround($208 - $209);
 HEAPF32[$agg$result>>2] = $189;
 $211 = (($agg$result) + 4|0);
 HEAPF32[$211>>2] = $196;
 $212 = (($agg$result) + 8|0);
 HEAPF32[$212>>2] = $203;
 $213 = (($agg$result) + 12|0);
 HEAPF32[$213>>2] = $210;
 $214 = (($agg$result) + 16|0);
 HEAPF32[$214>>2] = $173;
 $215 = (($agg$result) + 20|0);
 HEAPF32[$215>>2] = $174;
 $216 = (($agg$result) + 24|0);
 HEAPF32[$216>>2] = $175;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsCCDPair12sweepFindToiERNS_16PxsThreadContextEfj($this,$context,$dt,$pass) {
 $this = $this|0;
 $context = $context|0;
 $dt = Math_fround($dt);
 $pass = $pass|0;
 var $$ = 0, $$0 = Math_fround(0), $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0);
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0;
 var $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0);
 var $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0);
 var $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0;
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $combinedMat = 0, $combiner = 0, $g0$0$off = 0, $g1$0$off = 0, $lastTm0 = 0, $lastTm1 = 0, $materialInfo = 0, $penetration$0 = Math_fround(0), $penetrationPostStep$0 = Math_fround(0), $sweepNormal = 0;
 var $sweepPoint = 0, $tm0 = 0, $tm1 = 0, $toi$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $tm0 = sp + 96|0;
 $tm1 = sp;
 $lastTm0 = sp + 32|0;
 $lastTm1 = sp + 64|0;
 $sweepNormal = sp + 156|0;
 $sweepPoint = sp + 124|0;
 $materialInfo = sp + 168|0;
 $combiner = sp + 136|0;
 $combinedMat = sp + 144|0;
 $0 = (($this) + 60|0);
 __ZN5physx10PxsCCDPair12updateShapesEv($this);
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$0>>2]|0;
 $9 = (($this) + 64|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)<($8|0);
 $$ = $11 ? $8 : $10;
 $$4 = $11 ? $10 : $8;
 $$5 = $11 ? $5 : $7;
 $$6 = $11 ? $7 : $5;
 $$7 = $11 ? $1 : $3;
 $$8 = $11 ? $3 : $1;
 $12 = (($$6) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$tm0>>2] = $13;
 $14 = (($$6) + 44|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($tm0) + 4|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($$6) + 48|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($tm0) + 8|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($$6) + 52|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($tm0) + 12|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($$6) + 56|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($tm0) + 16|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($$6) + 60|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($tm0) + 20|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($$6) + 64|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($tm0) + 24|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($$6) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$lastTm0>>2] = $33;
 $34 = (($$6) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($lastTm0) + 4|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($$6) + 20|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($lastTm0) + 8|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($$6) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($lastTm0) + 12|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($$6) + 28|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($lastTm0) + 16|0);
 HEAPF32[$45>>2] = $44;
 $46 = (($$6) + 32|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($lastTm0) + 20|0);
 HEAPF32[$48>>2] = $47;
 $49 = (($$6) + 36|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($lastTm0) + 24|0);
 HEAPF32[$51>>2] = $50;
 $52 = (($$5) + 40|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 HEAPF32[$tm1>>2] = $53;
 $54 = (($$5) + 44|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($tm1) + 4|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($$5) + 48|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($tm1) + 8|0);
 HEAPF32[$59>>2] = $58;
 $60 = (($$5) + 52|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($tm1) + 12|0);
 HEAPF32[$62>>2] = $61;
 $63 = (($$5) + 56|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($tm1) + 16|0);
 HEAPF32[$65>>2] = $64;
 $66 = (($$5) + 60|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($tm1) + 20|0);
 HEAPF32[$68>>2] = $67;
 $69 = (($$5) + 64|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($tm1) + 24|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($$5) + 12|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 HEAPF32[$lastTm1>>2] = $73;
 $74 = (($$5) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($lastTm1) + 4|0);
 HEAPF32[$76>>2] = $75;
 $77 = (($$5) + 20|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($lastTm1) + 8|0);
 HEAPF32[$79>>2] = $78;
 $80 = (($$5) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($lastTm1) + 12|0);
 HEAPF32[$82>>2] = $81;
 $83 = (($$5) + 28|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($lastTm1) + 16|0);
 HEAPF32[$85>>2] = $84;
 $86 = (($$5) + 32|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($lastTm1) + 20|0);
 HEAPF32[$88>>2] = $87;
 $89 = (($$5) + 36|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($lastTm1) + 24|0);
 HEAPF32[$91>>2] = $90;
 $92 = Math_fround($24 - $44);
 $93 = Math_fround($27 - $47);
 $94 = Math_fround($30 - $50);
 $95 = Math_fround($64 - $84);
 $96 = Math_fround($67 - $87);
 $97 = Math_fround($70 - $90);
 HEAPF32[$sweepNormal>>2] = Math_fround(0.0);
 $98 = (($sweepNormal) + 4|0);
 HEAPF32[$98>>2] = Math_fround(0.0);
 $99 = (($sweepNormal) + 8|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 HEAPF32[$sweepPoint>>2] = Math_fround(0.0);
 $100 = (($sweepPoint) + 4|0);
 HEAPF32[$100>>2] = Math_fround(0.0);
 $101 = (($sweepPoint) + 8|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = ((503992 + (($$4*28)|0)|0) + ($$<<2)|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($this) + 52|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($105) + 108|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = $107 > Math_fround(0.0);
 $109 = $108 ? $107 : Math_fround(0.0);
 $110 = (($context) + 16|0);
 $111 = (($context) + 8764|0);
 HEAPF32[$111>>2] = $dt;
 $112 = (($context) + 8772|0);
 HEAP32[$112>>2] = -1;
 $113 = (($105) + 60|0);
 $114 = (($this) + 28|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (Math_fround(FUNCTION_TABLE_fiiiiiiiifiiiif[$103 & 15]($$6,$$5,$$8,$$7,$tm0,$tm1,$lastTm0,$lastTm1,$109,$sweepNormal,$sweepPoint,$113,$110,$115)));
 $117 = !($116 >= Math_fround(1.0));
 if (!($117)) {
  $118 = (($this) + 100|0);
  HEAP32[$118>>2] = 1;
  $119 = (($this) + 48|0);
  HEAPF32[$119>>2] = Math_fround(0.0);
  $120 = (($this) + 32|0);
  HEAPF32[$120>>2] = Math_fround(0.0);
  HEAPF32[$114>>2] = Math_fround(3.40282346638528859812E+38);
  $$0 = $116;
  STACKTOP = sp;return (Math_fround($$0));
 }
 $121 = Math_fround($94 - $97);
 $122 = Math_fround($93 - $96);
 $123 = Math_fround($92 - $95);
 $124 = HEAP32[$112>>2]|0;
 $125 = (($this) + 72|0);
 HEAP32[$125>>2] = $124;
 $126 = Math_fround(HEAPF32[$sweepNormal>>2]);
 $127 = Math_fround(-$126);
 $128 = Math_fround(HEAPF32[$98>>2]);
 $129 = Math_fround(-$128);
 $130 = Math_fround(HEAPF32[$99>>2]);
 $131 = Math_fround(-$130);
 $132 = Math_fround($123 * $127);
 $133 = Math_fround($122 * $129);
 $134 = Math_fround($132 + $133);
 $135 = Math_fround($121 * $131);
 $136 = Math_fround($134 + $135);
 $137 = HEAP32[$9>>2]|0;
 $138 = HEAP32[$0>>2]|0;
 $139 = ($137|0)<($138|0);
 if ($139) {
  $207 = $126;$209 = $128;$211 = $130;
 } else {
  HEAPF32[$sweepNormal>>2] = $127;
  HEAPF32[$98>>2] = $129;
  HEAPF32[$99>>2] = $131;
  $207 = $127;$209 = $129;$211 = $131;
 }
 $140 = (($this) + 100|0);
 HEAP32[$140>>2] = 1;
 $141 = (($$6) + 8|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($$5) + 8|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround($142 + $144);
 $146 = $136 < $145;
 if ($146) {
  HEAPF32[$114>>2] = Math_fround(3.40282346638528859812E+38);
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $147 = !($116 <= Math_fround(0.0));
 if ($147) {
  $penetration$0 = Math_fround(0.0);$penetrationPostStep$0 = Math_fround(0.0);$toi$0 = $116;
 } else {
  $148 = ($$8|0)!=(0|0);
  if ($148) {
   $149 = (($$8) + 60|0);
   $150 = HEAP32[$149>>2]|0;
   $151 = (($150) + 4|0);
   $152 = Math_fround(HEAPF32[$151>>2]);
   $159 = $152;
  } else {
   $159 = Math_fround(1.0);
  }
  $153 = ($$7|0)!=(0|0);
  if ($153) {
   $154 = (($$7) + 60|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = (($155) + 4|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $160 = $157;
  } else {
   $160 = Math_fround(1.0);
  }
  $158 = $159 < $160;
  $161 = $158 ? $159 : $160;
  $162 = Math_fround(-$116);
  $163 = $161 == Math_fround(1.0);
  if ($163) {
   if ($148) {
    $164 = (($$8) + 64|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = (($165) + 60|0);
    $167 = Math_fround(HEAPF32[$166>>2]);
    $173 = $167;
   } else {
    $173 = Math_fround(1.0);
   }
   if ($153) {
    $168 = (($$7) + 64|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = (($169) + 60|0);
    $171 = Math_fround(HEAPF32[$170>>2]);
    $174 = $171;
   } else {
    $174 = Math_fround(1.0);
   }
   $172 = $173 < $174;
   $175 = $172 ? $173 : $174;
   $176 = $153 ? $144 : Math_fround(3.40282346638528859812E+38);
   $177 = $142 < $176;
   $178 = $177 ? $142 : $176;
   $179 = Math_fround($178 * $175);
   $180 = Math_fround($179 / $136);
   $penetration$0 = $162;$penetrationPostStep$0 = $180;$toi$0 = Math_fround(0.0);
  } else {
   $penetration$0 = $162;$penetrationPostStep$0 = Math_fround(0.0);$toi$0 = Math_fround(0.0);
  }
 }
 HEAPF32[$114>>2] = $toi$0;
 $181 = (($this) + 48|0);
 HEAPF32[$181>>2] = $penetration$0;
 $182 = (($this) + 32|0);
 HEAPF32[$182>>2] = $penetrationPostStep$0;
 $183 = (($this) + 36|0);
 if ($139) {
  $184 = Math_fround($92 * $toi$0);
  $185 = Math_fround($93 * $toi$0);
  $186 = Math_fround($94 * $toi$0);
  $187 = Math_fround(HEAPF32[$sweepPoint>>2]);
  $188 = Math_fround($184 + $187);
  $189 = Math_fround(HEAPF32[$100>>2]);
  $190 = Math_fround($185 + $189);
  $191 = Math_fround(HEAPF32[$101>>2]);
  $192 = Math_fround($186 + $191);
  HEAPF32[$183>>2] = $188;
  $193 = (($this) + 40|0);
  HEAPF32[$193>>2] = $190;
  $194 = (($this) + 44|0);
  HEAPF32[$194>>2] = $192;
 } else {
  $195 = Math_fround($95 * $toi$0);
  $196 = Math_fround($96 * $toi$0);
  $197 = Math_fround($97 * $toi$0);
  $198 = Math_fround(HEAPF32[$sweepPoint>>2]);
  $199 = Math_fround($195 + $198);
  $200 = Math_fround(HEAPF32[$100>>2]);
  $201 = Math_fround($196 + $200);
  $202 = Math_fround(HEAPF32[$101>>2]);
  $203 = Math_fround($197 + $202);
  HEAPF32[$183>>2] = $199;
  $204 = (($this) + 40|0);
  HEAPF32[$204>>2] = $201;
  $205 = (($this) + 44|0);
  HEAPF32[$205>>2] = $203;
 }
 $206 = (($this) + 16|0);
 HEAPF32[$206>>2] = $207;
 $208 = (($this) + 20|0);
 HEAPF32[$208>>2] = $209;
 $210 = (($this) + 24|0);
 HEAPF32[$210>>2] = $211;
 $212 = (($context) + 4496|0);
 HEAP32[$212>>2] = 0;
 $g0$0$off = (($$4) + -5)|0;
 $213 = ($g0$0$off>>>0)<(2);
 if ($213) {
  $214 = HEAP32[$125>>2]|0;
  $232 = $214;
 } else {
  $232 = -1;
 }
 $g1$0$off = (($$) + -5)|0;
 $215 = ($g1$0$off>>>0)<(2);
 if ($215) {
  $216 = HEAP32[$125>>2]|0;
  $234 = $216;
 } else {
  $234 = -1;
 }
 HEAP32[$212>>2] = 1;
 $217 = (($context) + 400|0);
 HEAPF32[$217>>2] = $207;
 $218 = Math_fround(HEAPF32[$208>>2]);
 $219 = (($context) + 404|0);
 HEAPF32[$219>>2] = $218;
 $220 = Math_fround(HEAPF32[$210>>2]);
 $221 = (($context) + 408|0);
 HEAPF32[$221>>2] = $220;
 $222 = Math_fround(HEAPF32[$183>>2]);
 $223 = (($context) + 416|0);
 HEAPF32[$223>>2] = $222;
 $224 = (($this) + 40|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = (($context) + 420|0);
 HEAPF32[$226>>2] = $225;
 $227 = (($this) + 44|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 $229 = (($context) + 424|0);
 HEAPF32[$229>>2] = $228;
 $230 = (($context) + 412|0);
 HEAPF32[$230>>2] = Math_fround(0.0);
 $231 = (($context) + 448|0);
 HEAP32[$231>>2] = $232;
 $233 = (($context) + 452|0);
 HEAP32[$233>>2] = $234;
 $235 = (504192 + ($$4<<2)|0);
 $236 = HEAP32[$235>>2]|0;
 $237 = HEAP32[$$6>>2]|0;
 (FUNCTION_TABLE_iiiii[$236 & 511]($237,0,$110,$materialInfo)|0);
 $238 = (504192 + ($$<<2)|0);
 $239 = HEAP32[$238>>2]|0;
 $240 = HEAP32[$$5>>2]|0;
 (FUNCTION_TABLE_iiiii[$239 & 511]($240,1,$110,$materialInfo)|0);
 $241 = HEAP32[$104>>2]|0;
 $242 = (($241) + 96|0);
 $243 = HEAP32[$242>>2]|0;
 $244 = HEAP16[$materialInfo>>1]|0;
 $245 = $244&65535;
 $246 = HEAP32[$243>>2]|0;
 $247 = (($246) + ($245<<5)|0);
 $248 = (($materialInfo) + 2|0);
 $249 = HEAP16[$248>>1]|0;
 $250 = $249&65535;
 $251 = (($246) + ($250<<5)|0);
 $252 = (Math_fround(__ZN5physx19PxsMaterialCombiner18combineRestitutionERKNS_15PxsMaterialDataES3_($247,$251)));
 __ZN5physx19PxsMaterialCombinerC2Eff($combiner,Math_fround(1.0),Math_fround(1.0));
 __ZN5physx19PxsMaterialCombiner24combineIsotropicFrictionERKNS_15PxsMaterialDataES3_($combinedMat,$combiner,$247,$251);
 $253 = Math_fround(HEAPF32[$combinedMat>>2]);
 $254 = (($combinedMat) + 4|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = HEAP16[$materialInfo>>1]|0;
 $257 = (($this) + 76|0);
 HEAP16[$257>>1] = $256;
 $258 = HEAP16[$248>>1]|0;
 $259 = (($this) + 78|0);
 HEAP16[$259>>1] = $258;
 $260 = (($this) + 80|0);
 HEAPF32[$260>>2] = $255;
 $261 = (($this) + 84|0);
 HEAPF32[$261>>2] = $253;
 $262 = (($this) + 88|0);
 HEAPF32[$262>>2] = $252;
 $$0 = $toi$0;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx10PxsCCDPair12updateShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0;
 var $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0);
 var $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $extents = 0, $extents2 = 0, $lastTm0 = 0;
 var $lastTm1 = 0, $origin = 0, $origin1 = 0, $tm0 = 0, $tm1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $tm0 = sp + 132|0;
 $lastTm0 = sp;
 $origin = sp + 28|0;
 $extents = sp + 40|0;
 $tm1 = sp + 52|0;
 $lastTm1 = sp + 80|0;
 $origin1 = sp + 108|0;
 $extents2 = sp + 120|0;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 60|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 92|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($5|0)==($9|0);
  if (!($10)) {
   __ZNK5physx11PxsCCDShape10getAbsPoseEPKNS_12PxsRigidBodyE($tm0,$7,$0);
   $11 = HEAP32[$6>>2]|0;
   $12 = HEAP32[$this>>2]|0;
   __ZNK5physx11PxsCCDShape17getLastCCDAbsPoseEPKNS_12PxsRigidBodyE($lastTm0,$11,$12);
   $13 = (($tm0) + 16|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = (($lastTm0) + 16|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($14 - $16);
   $18 = (($tm0) + 20|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = (($lastTm0) + 20|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = Math_fround($19 - $21);
   $23 = (($tm0) + 24|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = (($lastTm0) + 24|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = Math_fround($24 - $26);
   $28 = HEAP32[$6>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 36|0);
   (Math_fround(__ZNK5physx2Gu13GeometryUnion29computeBoundsWithCCDThresholdERNS_6PxVec3ES3_RKNS_11PxTransformEPKNS_9PxBounds3E($30,$origin,$extents,$tm0,0)));
   $31 = HEAP32[$6>>2]|0;
   $32 = Math_fround(HEAPF32[$origin>>2]);
   $33 = Math_fround($32 - $17);
   $34 = (($origin) + 4|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = Math_fround($35 - $22);
   $37 = (($origin) + 8|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($38 - $27);
   $40 = (($31) + 80|0);
   HEAPF32[$40>>2] = $33;
   $41 = (($31) + 84|0);
   HEAPF32[$41>>2] = $36;
   $42 = (($31) + 88|0);
   HEAPF32[$42>>2] = $39;
   $43 = Math_fround(HEAPF32[$extents>>2]);
   $44 = (($31) + 68|0);
   HEAPF32[$44>>2] = $43;
   $45 = (($extents) + 4|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($31) + 72|0);
   HEAPF32[$47>>2] = $46;
   $48 = (($extents) + 8|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = (($31) + 76|0);
   HEAPF32[$50>>2] = $49;
   $51 = Math_fround(HEAPF32[$lastTm0>>2]);
   $52 = (($31) + 12|0);
   HEAPF32[$52>>2] = $51;
   $53 = (($lastTm0) + 4|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = (($31) + 16|0);
   HEAPF32[$55>>2] = $54;
   $56 = (($lastTm0) + 8|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = (($31) + 20|0);
   HEAPF32[$58>>2] = $57;
   $59 = (($lastTm0) + 12|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = (($31) + 24|0);
   HEAPF32[$61>>2] = $60;
   $62 = (($31) + 28|0);
   HEAPF32[$62>>2] = $16;
   $63 = (($31) + 32|0);
   HEAPF32[$63>>2] = $21;
   $64 = (($31) + 36|0);
   HEAPF32[$64>>2] = $26;
   $65 = Math_fround(HEAPF32[$tm0>>2]);
   $66 = (($31) + 40|0);
   HEAPF32[$66>>2] = $65;
   $67 = (($tm0) + 4|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = (($31) + 44|0);
   HEAPF32[$69>>2] = $68;
   $70 = (($tm0) + 8|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = (($31) + 48|0);
   HEAPF32[$72>>2] = $71;
   $73 = (($tm0) + 12|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = (($31) + 52|0);
   HEAPF32[$75>>2] = $74;
   $76 = Math_fround(HEAPF32[$13>>2]);
   $77 = (($31) + 56|0);
   HEAPF32[$77>>2] = $76;
   $78 = Math_fround(HEAPF32[$18>>2]);
   $79 = (($31) + 60|0);
   HEAPF32[$79>>2] = $78;
   $80 = Math_fround(HEAPF32[$23>>2]);
   $81 = (($31) + 64|0);
   HEAPF32[$81>>2] = $80;
   $82 = HEAP32[$this>>2]|0;
   $83 = (($82) + 60|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($84) + 16|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($31) + 92|0);
   HEAP32[$87>>2] = $86;
  }
 }
 $88 = (($this) + 4|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($89|0)==(0|0);
 if ($90) {
  STACKTOP = sp;return;
 }
 $91 = (($89) + 60|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + 16|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($this) + 12|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (($96) + 92|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = ($94|0)==($98|0);
 if ($99) {
  STACKTOP = sp;return;
 }
 __ZNK5physx11PxsCCDShape10getAbsPoseEPKNS_12PxsRigidBodyE($tm1,$96,$89);
 $100 = HEAP32[$95>>2]|0;
 $101 = HEAP32[$88>>2]|0;
 __ZNK5physx11PxsCCDShape17getLastCCDAbsPoseEPKNS_12PxsRigidBodyE($lastTm1,$100,$101);
 $102 = (($tm1) + 16|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($lastTm1) + 16|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($103 - $105);
 $107 = (($tm1) + 20|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($lastTm1) + 20|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($108 - $110);
 $112 = (($tm1) + 24|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($lastTm1) + 24|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($113 - $115);
 $117 = HEAP32[$95>>2]|0;
 $118 = HEAP32[$117>>2]|0;
 $119 = (($118) + 36|0);
 (Math_fround(__ZNK5physx2Gu13GeometryUnion29computeBoundsWithCCDThresholdERNS_6PxVec3ES3_RKNS_11PxTransformEPKNS_9PxBounds3E($119,$origin1,$extents2,$tm1,0)));
 $120 = HEAP32[$95>>2]|0;
 $121 = Math_fround(HEAPF32[$origin1>>2]);
 $122 = Math_fround($121 - $106);
 $123 = (($origin1) + 4|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = Math_fround($124 - $111);
 $126 = (($origin1) + 8|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = Math_fround($127 - $116);
 $129 = (($120) + 80|0);
 HEAPF32[$129>>2] = $122;
 $130 = (($120) + 84|0);
 HEAPF32[$130>>2] = $125;
 $131 = (($120) + 88|0);
 HEAPF32[$131>>2] = $128;
 $132 = Math_fround(HEAPF32[$extents2>>2]);
 $133 = (($120) + 68|0);
 HEAPF32[$133>>2] = $132;
 $134 = (($extents2) + 4|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($120) + 72|0);
 HEAPF32[$136>>2] = $135;
 $137 = (($extents2) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($120) + 76|0);
 HEAPF32[$139>>2] = $138;
 $140 = Math_fround(HEAPF32[$lastTm1>>2]);
 $141 = (($120) + 12|0);
 HEAPF32[$141>>2] = $140;
 $142 = (($lastTm1) + 4|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($120) + 16|0);
 HEAPF32[$144>>2] = $143;
 $145 = (($lastTm1) + 8|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($120) + 20|0);
 HEAPF32[$147>>2] = $146;
 $148 = (($lastTm1) + 12|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($120) + 24|0);
 HEAPF32[$150>>2] = $149;
 $151 = (($120) + 28|0);
 HEAPF32[$151>>2] = $105;
 $152 = (($120) + 32|0);
 HEAPF32[$152>>2] = $110;
 $153 = (($120) + 36|0);
 HEAPF32[$153>>2] = $115;
 $154 = Math_fround(HEAPF32[$tm1>>2]);
 $155 = (($120) + 40|0);
 HEAPF32[$155>>2] = $154;
 $156 = (($tm1) + 4|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = (($120) + 44|0);
 HEAPF32[$158>>2] = $157;
 $159 = (($tm1) + 8|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($120) + 48|0);
 HEAPF32[$161>>2] = $160;
 $162 = (($tm1) + 12|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($120) + 52|0);
 HEAPF32[$164>>2] = $163;
 $165 = Math_fround(HEAPF32[$102>>2]);
 $166 = (($120) + 56|0);
 HEAPF32[$166>>2] = $165;
 $167 = Math_fround(HEAPF32[$107>>2]);
 $168 = (($120) + 60|0);
 HEAPF32[$168>>2] = $167;
 $169 = Math_fround(HEAPF32[$112>>2]);
 $170 = (($120) + 64|0);
 HEAPF32[$170>>2] = $169;
 $171 = HEAP32[$88>>2]|0;
 $172 = (($171) + 60|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = (($173) + 16|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = (($120) + 92|0);
 HEAP32[$176>>2] = $175;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsCCDPair16sweepEstimateToiEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = Math_fround(0), $$10 = 0, $$11 = 0, $$12 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0;
 var $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0;
 var $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0);
 var $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $centreA = 0, $centreB = 0, $tm0 = 0, $tm1 = 0, $trA = 0, $trB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $tm0 = sp + 100|0;
 $tm1 = sp;
 $trA = sp + 28|0;
 $trB = sp + 40|0;
 $centreA = sp + 52|0;
 $centreB = sp + 64|0;
 $0 = sp + 76|0;
 $1 = sp + 88|0;
 __ZN5physx10PxsCCDPair12updateShapesEv($this);
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 60|0);
 $10 = (($this) + 64|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = ($11|0)<($12|0);
 $$10 = $13 ? $6 : $8;
 $$11 = $13 ? $8 : $6;
 $$12 = $13 ? $3 : $4;
 $$13 = $13 ? $4 : $3;
 $14 = (($trA) + 4|0);
 $15 = (($trA) + 8|0);
 $16 = (($trB) + 4|0);
 $17 = (($trB) + 8|0);
 $18 = (($$11) + 40|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$tm0>>2] = $19;
 $20 = (($$11) + 44|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($tm0) + 4|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($$11) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($tm0) + 8|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($$11) + 52|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($tm0) + 12|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($$11) + 56|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($tm0) + 16|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($$11) + 60|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($tm0) + 20|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($$11) + 64|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($tm0) + 24|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($$11) + 28|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($$11) + 32|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($$11) + 36|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($30 - $39);
 $45 = Math_fround($33 - $41);
 $46 = Math_fround($36 - $43);
 HEAPF32[$trA>>2] = $44;
 HEAPF32[$14>>2] = $45;
 HEAPF32[$15>>2] = $46;
 $47 = (($$10) + 40|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$tm1>>2] = $48;
 $49 = (($$10) + 44|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($tm1) + 4|0);
 HEAPF32[$51>>2] = $50;
 $52 = (($$10) + 48|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($tm1) + 8|0);
 HEAPF32[$54>>2] = $53;
 $55 = (($$10) + 52|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($tm1) + 12|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($$10) + 56|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($tm1) + 16|0);
 HEAPF32[$60>>2] = $59;
 $61 = (($$10) + 60|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($tm1) + 20|0);
 HEAPF32[$63>>2] = $62;
 $64 = (($$10) + 64|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($tm1) + 24|0);
 HEAPF32[$66>>2] = $65;
 $67 = (($$10) + 28|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($$10) + 32|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($$10) + 36|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($59 - $68);
 $74 = Math_fround($62 - $70);
 $75 = Math_fround($65 - $72);
 HEAPF32[$trB>>2] = $73;
 HEAPF32[$16>>2] = $74;
 HEAPF32[$17>>2] = $75;
 $76 = (($this) + 52|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + 108|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = $79 > Math_fround(0.0);
 $81 = $80 ? $79 : Math_fround(0.0);
 $82 = Math_fround($44 - $73);
 $83 = Math_fround($45 - $74);
 $84 = Math_fround($46 - $75);
 $85 = (($$11) + 8|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($$10) + 8|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($86 + $88);
 $90 = (($this) + 100|0);
 HEAP32[$90>>2] = 0;
 $91 = Math_fround($82 * $82);
 $92 = Math_fround($83 * $83);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($84 * $84);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($89 * $89);
 $97 = !($95 <= $96);
 if (!($97)) {
  HEAP32[$90>>2] = 0;
  $98 = (($this) + 28|0);
  HEAPF32[$98>>2] = Math_fround(3.40282346638528859812E+38);
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $$ = $13 ? $12 : $11;
 if ((($$|0) == 5)) {
  $99 = (Math_fround(__ZN5physx28PxcSweepEstimateAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_f($$11,$$10,$$12,$$13,$tm0,$tm1,$81)));
  $100 = (($this) + 28|0);
  HEAPF32[$100>>2] = $99;
  $$0 = $99;
  STACKTOP = sp;return (Math_fround($$0));
 } else if ((($$|0) == 6)) {
  $101 = (Math_fround(__ZN5physx35PxcSweepEstimateAnyShapeHeightfieldERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_f($$11,$$10,$$12,$$13,$tm0,$tm1,$81)));
  $102 = (($this) + 28|0);
  HEAPF32[$102>>2] = $101;
  $$0 = $101;
  STACKTOP = sp;return (Math_fround($$0));
 } else {
  $103 = (($$11) + 80|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  HEAPF32[$centreA>>2] = $104;
  $105 = (($$11) + 84|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = (($centreA) + 4|0);
  HEAPF32[$107>>2] = $106;
  $108 = (($$11) + 88|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($centreA) + 8|0);
  HEAPF32[$110>>2] = $109;
  $111 = (($$11) + 68|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = Math_fround($81 + $112);
  $114 = (($$11) + 72|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($81 + $115);
  $117 = (($$11) + 76|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = Math_fround($81 + $118);
  $120 = (($$10) + 80|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  HEAPF32[$centreB>>2] = $121;
  $122 = (($$10) + 84|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = (($centreB) + 4|0);
  HEAPF32[$124>>2] = $123;
  $125 = (($$10) + 88|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = (($centreB) + 8|0);
  HEAPF32[$127>>2] = $126;
  $128 = (($$10) + 68|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = (($$10) + 72|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  $132 = (($$10) + 76|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = Math_fround($113 * Math_fround(1.10000002384185791016));
  $135 = Math_fround($116 * Math_fround(1.10000002384185791016));
  $136 = Math_fround($119 * Math_fround(1.10000002384185791016));
  HEAPF32[$0>>2] = $134;
  $137 = (($0) + 4|0);
  HEAPF32[$137>>2] = $135;
  $138 = (($0) + 8|0);
  HEAPF32[$138>>2] = $136;
  $139 = Math_fround($129 * Math_fround(1.10000002384185791016));
  $140 = Math_fround($131 * Math_fround(1.10000002384185791016));
  $141 = Math_fround($133 * Math_fround(1.10000002384185791016));
  HEAPF32[$1>>2] = $139;
  $142 = (($1) + 4|0);
  HEAPF32[$142>>2] = $140;
  $143 = (($1) + 8|0);
  HEAPF32[$143>>2] = $141;
  $144 = (Math_fround(__Z13sweepAABBAABBRKN5physx6PxVec3ES2_S2_S2_S2_S2_($centreA,$0,$centreB,$1,$trA,$trB)));
  $145 = (($this) + 28|0);
  HEAPF32[$145>>2] = $144;
  $$0 = $144;
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZN5physx10PxsCCDPair17sweepAdvanceToToiEfb($this,$dt,$clipTrajectoryToToi) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $clipTrajectoryToToi = $clipTrajectoryToToi|0;
 var $$0 = 0, $$pre = Math_fround(0), $$pre$i = Math_fround(0), $$pre53 = Math_fround(0), $$pre55 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0);
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0;
 var $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0);
 var $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0;
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0);
 var $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0;
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = 0;
 var $418 = Math_fround(0), $419 = 0, $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = 0, $434 = 0, $435 = Math_fround(0);
 var $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = Math_fround(0), $46 = Math_fround(0), $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = Math_fround(0), $465 = 0, $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = 0;
 var $472 = Math_fround(0), $473 = Math_fround(0), $474 = 0, $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = 0, $489 = 0, $49 = Math_fround(0);
 var $490 = Math_fround(0), $491 = 0, $492 = 0, $493 = Math_fround(0), $494 = 0, $495 = 0, $496 = 0, $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0), $504 = 0, $505 = Math_fround(0), $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0);
 var $526 = 0, $527 = Math_fround(0), $528 = Math_fround(0), $529 = 0, $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = 0, $536 = Math_fround(0), $537 = Math_fround(0), $538 = 0, $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0);
 var $544 = 0, $545 = Math_fround(0), $546 = 0, $547 = 0, $548 = Math_fround(0), $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = Math_fround(0), $552 = 0, $553 = 0, $554 = Math_fround(0), $555 = 0, $556 = 0, $557 = 0, $558 = Math_fround(0), $559 = 0, $56 = Math_fround(0), $560 = Math_fround(0), $561 = 0;
 var $562 = Math_fround(0), $563 = 0, $564 = Math_fround(0), $565 = 0, $566 = Math_fround(0), $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0);
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = Math_fround(0), $585 = 0, $586 = Math_fround(0), $587 = 0, $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = 0, $591 = Math_fround(0), $592 = Math_fround(0), $593 = 0, $594 = Math_fround(0), $595 = Math_fround(0), $596 = 0, $597 = Math_fround(0), $598 = Math_fround(0);
 var $599 = 0, $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = Math_fround(0), $613 = 0, $614 = 0, $615 = Math_fround(0);
 var $616 = 0, $617 = 0, $618 = Math_fround(0), $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = Math_fround(0), $623 = 0, $624 = Math_fround(0), $625 = 0, $626 = Math_fround(0), $627 = 0, $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = Math_fround(0), $636 = 0, $637 = 0, $638 = 0, $639 = Math_fround(0), $64 = Math_fround(0), $640 = 0, $641 = Math_fround(0), $642 = 0, $643 = Math_fround(0), $644 = Math_fround(0), $645 = 0, $646 = Math_fround(0), $647 = Math_fround(0), $648 = 0, $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = 0;
 var $652 = Math_fround(0), $653 = Math_fround(0), $654 = 0, $655 = Math_fround(0), $656 = Math_fround(0), $657 = 0, $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = 0, $664 = Math_fround(0), $665 = 0, $666 = 0, $667 = Math_fround(0), $668 = 0, $669 = 0, $67 = Math_fround(0);
 var $670 = Math_fround(0), $671 = 0, $672 = 0, $673 = Math_fround(0), $674 = 0, $675 = 0, $676 = 0, $677 = Math_fround(0), $678 = 0, $679 = Math_fround(0), $68 = 0, $680 = 0, $681 = Math_fround(0), $682 = 0, $683 = Math_fround(0), $684 = Math_fround(0), $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fricResponse$0 = Math_fround(0), $invMass0$0 = Math_fround(0);
 var $invMass1$0 = Math_fround(0), $newLastQ$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $newLastQ$i18 = sp + 32|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($3|0)==(0|0);
 if ($8) {
  label = 3;
 } else {
  $9 = (($3) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 2|0);
  $12 = HEAP16[$11>>1]|0;
  $13 = ($12<<16>>16)==(0);
  if ($13) {
   label = 6;
  } else {
   label = 3;
  }
 }
 do {
  if ((label|0) == 3) {
   $14 = ($7|0)==(0|0);
   if ($14) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $15 = (($7) + 60|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 2|0);
   $18 = HEAP16[$17>>1]|0;
   $19 = ($18<<16>>16)==(0);
   if ($19) {
    if ($8) {
     label = 7;
     break;
    } else {
     label = 6;
     break;
    }
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $20 = (($3) + 64|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 124|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = $23 == Math_fround(0.0);
  if ($24) {
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $25 = ($7|0)==(0|0);
  if ($25) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $26 = (($7) + 64|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 124|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = $29 == Math_fround(0.0);
  if ($30) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $31 = (($this) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = $32 < Math_fround(1.0);
 if (!($33)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = (($this) + 52|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 35|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if (!($38)) {
  if (!($8)) {
   $39 = (($3) + 64|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + 124|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = $42 == Math_fround(0.0);
   if ($43) {
    $87 = $32;
   } else {
    $44 = Math_fround(Math_fround(1.0) - $32);
    $45 = (($3) + 48|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = Math_fround($44 * $46);
    $48 = (($3) + 52|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = Math_fround($44 * $49);
    $51 = (($3) + 56|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = Math_fround($44 * $52);
    $54 = (($40) + 16|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = Math_fround($32 * $55);
    $57 = (($40) + 20|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($32 * $58);
    $60 = (($40) + 24|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = Math_fround($32 * $61);
    $63 = Math_fround($47 + $56);
    $64 = Math_fround($50 + $59);
    $65 = Math_fround($53 + $62);
    HEAPF32[$45>>2] = $63;
    HEAPF32[$48>>2] = $64;
    HEAPF32[$51>>2] = $65;
    $66 = (($3) + 32|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    HEAPF32[$0>>2] = $67;
    $68 = (($0) + 4|0);
    $69 = (($3) + 36|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    HEAPF32[$68>>2] = $70;
    $71 = (($0) + 8|0);
    $72 = (($3) + 40|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    HEAPF32[$71>>2] = $73;
    $74 = (($0) + 12|0);
    $75 = (($3) + 44|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    HEAPF32[$74>>2] = $76;
    $77 = (($0) + 16|0);
    HEAPF32[$77>>2] = $63;
    $78 = (($0) + 20|0);
    HEAPF32[$78>>2] = $64;
    $79 = (($0) + 24|0);
    HEAPF32[$79>>2] = $65;
    __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($newLastQ$i18,$32,$0,$40);
    $80 = Math_fround(HEAPF32[$newLastQ$i18>>2]);
    HEAPF32[$66>>2] = $80;
    $81 = (($newLastQ$i18) + 4|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    HEAPF32[$69>>2] = $82;
    $83 = (($newLastQ$i18) + 8|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    HEAPF32[$72>>2] = $84;
    $85 = (($newLastQ$i18) + 12|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    HEAPF32[$75>>2] = $86;
    $$pre53 = Math_fround(HEAPF32[$31>>2]);
    $87 = $$pre53;
   }
   __ZN5physx12PxsRigidBody12advanceToToiEffb($3,$87,$dt,0);
  }
  $88 = ($7|0)==(0|0);
  if ($88) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $89 = Math_fround(HEAPF32[$31>>2]);
  $90 = (($7) + 64|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($91) + 124|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = $93 == Math_fround(0.0);
  if ($94) {
   $138 = $89;
  } else {
   $95 = Math_fround(Math_fround(1.0) - $89);
   $96 = (($7) + 48|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = Math_fround($95 * $97);
   $99 = (($7) + 52|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = Math_fround($95 * $100);
   $102 = (($7) + 56|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = Math_fround($95 * $103);
   $105 = (($91) + 16|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = Math_fround($89 * $106);
   $108 = (($91) + 20|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = Math_fround($89 * $109);
   $111 = (($91) + 24|0);
   $112 = Math_fround(HEAPF32[$111>>2]);
   $113 = Math_fround($89 * $112);
   $114 = Math_fround($98 + $107);
   $115 = Math_fround($101 + $110);
   $116 = Math_fround($104 + $113);
   HEAPF32[$96>>2] = $114;
   HEAPF32[$99>>2] = $115;
   HEAPF32[$102>>2] = $116;
   $117 = (($7) + 32|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   HEAPF32[$0>>2] = $118;
   $119 = (($0) + 4|0);
   $120 = (($7) + 36|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   HEAPF32[$119>>2] = $121;
   $122 = (($0) + 8|0);
   $123 = (($7) + 40|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   HEAPF32[$122>>2] = $124;
   $125 = (($0) + 12|0);
   $126 = (($7) + 44|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   HEAPF32[$125>>2] = $127;
   $128 = (($0) + 16|0);
   HEAPF32[$128>>2] = $114;
   $129 = (($0) + 20|0);
   HEAPF32[$129>>2] = $115;
   $130 = (($0) + 24|0);
   HEAPF32[$130>>2] = $116;
   __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($newLastQ$i18,$89,$0,$91);
   $131 = Math_fround(HEAPF32[$newLastQ$i18>>2]);
   HEAPF32[$117>>2] = $131;
   $132 = (($newLastQ$i18) + 4|0);
   $133 = Math_fround(HEAPF32[$132>>2]);
   HEAPF32[$120>>2] = $133;
   $134 = (($newLastQ$i18) + 8|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   HEAPF32[$123>>2] = $135;
   $136 = (($newLastQ$i18) + 12|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   HEAPF32[$126>>2] = $137;
   $$pre = Math_fround(HEAPF32[$31>>2]);
   $138 = $$pre;
  }
  __ZN5physx12PxsRigidBody12advanceToToiEffb($7,$138,$dt,0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $139 = (($this) + 48|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($140 * Math_fround(-10.0));
 $142 = (($this) + 16|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($this) + 20|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($this) + 24|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = (HEAPF32[tempDoublePtr>>2]=$143,HEAP32[tempDoublePtr>>2]|0);
 $149 = $148 & 2139095040;
 $150 = ($149>>>0)<(2139095040);
 if ($150) {
  $151 = (HEAPF32[tempDoublePtr>>2]=$145,HEAP32[tempDoublePtr>>2]|0);
  $152 = $151 & 2139095040;
  $153 = ($152>>>0)<(2139095040);
  if ($153) {
   $154 = (HEAPF32[tempDoublePtr>>2]=$147,HEAP32[tempDoublePtr>>2]|0);
   $155 = $154 & 2139095040;
   $156 = ($155>>>0)<(2139095040);
   if ($156) {
    $157 = Math_fround($143 * $143);
    $158 = Math_fround($145 * $145);
    $159 = Math_fround($157 + $158);
    $160 = Math_fround($147 * $147);
    $161 = Math_fround($159 + $160);
    $162 = (Math_fround(Math_sqrt((Math_fround($161)))));
    $163 = Math_fround($162 + Math_fround(-1.0));
    $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($163)))));
    $164 = $fabsf$i$i$i < Math_fround(9.99999974737875163555E-5);
    if ($164) {
     $252 = (($this) + 88|0);
     $253 = Math_fround(HEAPF32[$252>>2]);
     $254 = (($this) + 84|0);
     $255 = Math_fround(HEAPF32[$254>>2]);
     $256 = (($this) + 80|0);
     $257 = Math_fround(HEAPF32[$256>>2]);
     $258 = (($35) + 104|0);
     $259 = Math_fround(HEAPF32[$258>>2]);
     $260 = ($3|0)!=(0|0);
     if ($260) {
      $261 = (($35) + 100|0);
      $262 = Math_fround(HEAPF32[$261>>2]);
      $263 = (($3) + 64|0);
      $264 = HEAP32[$263>>2]|0;
      $265 = HEAP32[$2>>2]|0;
      $266 = (($264) + 84|0);
      $267 = Math_fround(HEAPF32[$266>>2]);
      $268 = (($265) + 24|0);
      $269 = Math_fround(HEAPF32[$268>>2]);
      $270 = Math_fround($267 * $269);
      $271 = (($264) + 88|0);
      $272 = Math_fround(HEAPF32[$271>>2]);
      $273 = (($265) + 20|0);
      $274 = Math_fround(HEAPF32[$273>>2]);
      $275 = Math_fround($272 * $274);
      $276 = Math_fround($270 - $275);
      $277 = (($265) + 16|0);
      $278 = Math_fround(HEAPF32[$277>>2]);
      $279 = Math_fround($272 * $278);
      $280 = (($264) + 80|0);
      $281 = Math_fround(HEAPF32[$280>>2]);
      $282 = Math_fround($269 * $281);
      $283 = Math_fround($279 - $282);
      $284 = Math_fround($274 * $281);
      $285 = Math_fround($267 * $278);
      $286 = Math_fround($284 - $285);
      $287 = (($264) + 64|0);
      $288 = Math_fround(HEAPF32[$287>>2]);
      $289 = Math_fround($276 + $288);
      $290 = (($264) + 68|0);
      $291 = Math_fround(HEAPF32[$290>>2]);
      $292 = Math_fround($291 + $283);
      $293 = (($264) + 72|0);
      $294 = Math_fround(HEAPF32[$293>>2]);
      $295 = Math_fround($286 + $294);
      $296 = (($264) + 124|0);
      $297 = Math_fround(HEAPF32[$296>>2]);
      $298 = Math_fround($262 * $297);
      $337 = $289;$340 = $292;$343 = $295;$invMass0$0 = $298;
     } else {
      $337 = Math_fround(0.0);$340 = Math_fround(0.0);$343 = Math_fround(0.0);$invMass0$0 = Math_fround(0.0);
     }
     $299 = ($7|0)!=(0|0);
     if ($299) {
      $300 = (($7) + 64|0);
      $301 = HEAP32[$300>>2]|0;
      $302 = HEAP32[$5>>2]|0;
      $303 = (($301) + 84|0);
      $304 = Math_fround(HEAPF32[$303>>2]);
      $305 = (($302) + 24|0);
      $306 = Math_fround(HEAPF32[$305>>2]);
      $307 = Math_fround($304 * $306);
      $308 = (($301) + 88|0);
      $309 = Math_fround(HEAPF32[$308>>2]);
      $310 = (($302) + 20|0);
      $311 = Math_fround(HEAPF32[$310>>2]);
      $312 = Math_fround($309 * $311);
      $313 = Math_fround($307 - $312);
      $314 = (($302) + 16|0);
      $315 = Math_fround(HEAPF32[$314>>2]);
      $316 = Math_fround($309 * $315);
      $317 = (($301) + 80|0);
      $318 = Math_fround(HEAPF32[$317>>2]);
      $319 = Math_fround($306 * $318);
      $320 = Math_fround($316 - $319);
      $321 = Math_fround($311 * $318);
      $322 = Math_fround($304 * $315);
      $323 = Math_fround($321 - $322);
      $324 = (($301) + 64|0);
      $325 = Math_fround(HEAPF32[$324>>2]);
      $326 = Math_fround($313 + $325);
      $327 = (($301) + 68|0);
      $328 = Math_fround(HEAPF32[$327>>2]);
      $329 = Math_fround($328 + $320);
      $330 = (($301) + 72|0);
      $331 = Math_fround(HEAPF32[$330>>2]);
      $332 = Math_fround($323 + $331);
      $333 = (($301) + 124|0);
      $334 = Math_fround(HEAPF32[$333>>2]);
      $335 = Math_fround($259 * $334);
      $338 = $326;$341 = $329;$344 = $332;$invMass1$0 = $335;
     } else {
      $338 = Math_fround(0.0);$341 = Math_fround(0.0);$344 = Math_fround(0.0);$invMass1$0 = Math_fround(0.0);
     }
     $336 = Math_fround($338 - $337);
     $339 = Math_fround($341 - $340);
     $342 = Math_fround($344 - $343);
     $345 = Math_fround($143 * $336);
     $346 = Math_fround($145 * $339);
     $347 = Math_fround($346 + $345);
     $348 = Math_fround($147 * $342);
     $349 = Math_fround($348 + $347);
     $350 = Math_fround($141 + $349);
     $351 = $350 < Math_fround(-9.99999997475242707878E-7);
     L50: do {
      if ($351) {
       $352 = Math_fround($invMass0$0 + $invMass1$0);
       $353 = Math_fround($253 + Math_fround(1.0));
       $354 = Math_fround($353 * $350);
       $355 = Math_fround($354 / $352);
       $356 = (($this) + 104|0);
       $357 = HEAP8[$356>>0]|0;
       $358 = ($357<<24>>24)==(0);
       if ($358) {
        $393 = Math_fround($355 * $143);
        $394 = Math_fround($355 * $145);
        $395 = Math_fround($355 * $147);
        $421 = $393;$423 = $394;$425 = $395;
       } else {
        $359 = Math_fround($143 * $349);
        $360 = Math_fround($145 * $349);
        $361 = Math_fround($147 * $349);
        $362 = Math_fround($336 - $359);
        $363 = Math_fround($339 - $360);
        $364 = Math_fround($342 - $361);
        $365 = Math_fround($362 * $362);
        $366 = Math_fround($363 * $363);
        $367 = Math_fround($365 + $366);
        $368 = Math_fround($364 * $364);
        $369 = Math_fround($368 + $367);
        $370 = (Math_fround(Math_sqrt((Math_fround($369)))));
        $371 = $370 > Math_fround(0.0);
        if ($371) {
         $372 = Math_fround(Math_fround(1.0) / $370);
         $373 = Math_fround($362 * $372);
         $374 = Math_fround($363 * $372);
         $375 = Math_fround($364 * $372);
         $382 = $373;$384 = $374;$386 = $375;
        } else {
         $382 = $362;$384 = $363;$386 = $364;
        }
        $376 = Math_fround($370 / $352);
        $377 = Math_fround($255 * $355);
        $fabsf$i$i = (Math_fround(Math_abs((Math_fround($377)))));
        $378 = !($fabsf$i$i >= $376);
        if ($378) {
         $379 = Math_fround($257 * $355);
         $380 = Math_fround(-$379);
         $fricResponse$0 = $380;
        } else {
         $fricResponse$0 = $376;
        }
        $381 = Math_fround($382 * $fricResponse$0);
        $383 = Math_fround($384 * $fricResponse$0);
        $385 = Math_fround($386 * $fricResponse$0);
        $387 = Math_fround($355 * $143);
        $388 = Math_fround($355 * $145);
        $389 = Math_fround($355 * $147);
        $390 = Math_fround($381 + $387);
        $391 = Math_fround($383 + $388);
        $392 = Math_fround($385 + $389);
        $421 = $390;$423 = $391;$425 = $392;
       }
       $396 = $355 < Math_fround(0.0);
       if ($396) {
        $397 = Math_fround(-$355);
        $398 = (($this) + 96|0);
        HEAPF32[$398>>2] = $397;
        if ($260) {
         $399 = (($3) + 60|0);
         $400 = HEAP32[$399>>2]|0;
         $401 = (($400) + 2|0);
         $402 = HEAP16[$401>>1]|0;
         $403 = ($402<<16>>16)==(0);
         if ($403) {
          label = 46;
         }
        } else {
         label = 46;
        }
        do {
         if ((label|0) == 46) {
          if ($299) {
           $404 = (($7) + 60|0);
           $405 = HEAP32[$404>>2]|0;
           $406 = (($405) + 2|0);
           $407 = HEAP16[$406>>1]|0;
           $408 = ($407<<16>>16)==(0);
           if (!($408)) {
            break;
           }
          }
          if ($260) {
           $410 = (($3) + 64|0);
           $411 = HEAP32[$410>>2]|0;
           $412 = (($411) + 64|0);
           $413 = Math_fround(HEAPF32[$412>>2]);
           HEAPF32[$3>>2] = $413;
           $414 = (($411) + 68|0);
           $415 = Math_fround(HEAPF32[$414>>2]);
           $416 = (($3) + 4|0);
           HEAPF32[$416>>2] = $415;
           $417 = (($411) + 72|0);
           $418 = Math_fround(HEAPF32[$417>>2]);
           $419 = (($3) + 8|0);
           HEAPF32[$419>>2] = $418;
           $420 = Math_fround($invMass0$0 * $421);
           $422 = Math_fround($invMass0$0 * $423);
           $424 = Math_fround($invMass0$0 * $425);
           $426 = Math_fround(HEAPF32[$412>>2]);
           $427 = Math_fround($420 + $426);
           $428 = Math_fround(HEAPF32[$414>>2]);
           $429 = Math_fround($422 + $428);
           $430 = Math_fround(HEAPF32[$417>>2]);
           $431 = Math_fround($424 + $430);
           HEAPF32[$412>>2] = $427;
           HEAPF32[$414>>2] = $429;
           HEAPF32[$417>>2] = $431;
          }
          if (!($299)) {
           break L50;
          }
          $432 = (($7) + 64|0);
          $433 = HEAP32[$432>>2]|0;
          $434 = (($433) + 64|0);
          $435 = Math_fround(HEAPF32[$434>>2]);
          HEAPF32[$7>>2] = $435;
          $436 = (($433) + 68|0);
          $437 = Math_fround(HEAPF32[$436>>2]);
          $438 = (($7) + 4|0);
          HEAPF32[$438>>2] = $437;
          $439 = (($433) + 72|0);
          $440 = Math_fround(HEAPF32[$439>>2]);
          $441 = (($7) + 8|0);
          HEAPF32[$441>>2] = $440;
          $442 = Math_fround($invMass1$0 * $421);
          $443 = Math_fround($invMass1$0 * $423);
          $444 = Math_fround($invMass1$0 * $425);
          $445 = Math_fround(HEAPF32[$434>>2]);
          $446 = Math_fround($445 - $442);
          $447 = Math_fround(HEAPF32[$436>>2]);
          $448 = Math_fround($447 - $443);
          $449 = Math_fround(HEAPF32[$439>>2]);
          $450 = Math_fround($449 - $444);
          HEAPF32[$434>>2] = $446;
          HEAPF32[$436>>2] = $448;
          HEAPF32[$439>>2] = $450;
          break L50;
         }
        } while(0);
        $409 = (($this) + 32|0);
        HEAPF32[$409>>2] = Math_fround(0.0);
       }
      }
     } while(0);
     if ($260) {
      $451 = (($3) + 60|0);
      $452 = HEAP32[$451>>2]|0;
      $453 = (($452) + 2|0);
      $454 = HEAP16[$453>>1]|0;
      $455 = ($454<<16>>16)==(0);
      if ($455) {
       $456 = (($3) + 64|0);
       $457 = HEAP32[$456>>2]|0;
       $458 = (($457) + 124|0);
       $459 = Math_fround(HEAPF32[$458>>2]);
       $460 = $459 == Math_fround(0.0);
       if (!($460)) {
        $461 = Math_fround(Math_fround(1.0) - $32);
        $462 = (($3) + 48|0);
        $463 = Math_fround(HEAPF32[$462>>2]);
        $464 = Math_fround($461 * $463);
        $465 = (($3) + 52|0);
        $466 = Math_fround(HEAPF32[$465>>2]);
        $467 = Math_fround($461 * $466);
        $468 = (($3) + 56|0);
        $469 = Math_fround(HEAPF32[$468>>2]);
        $470 = Math_fround($461 * $469);
        $471 = (($457) + 16|0);
        $472 = Math_fround(HEAPF32[$471>>2]);
        $473 = Math_fround($32 * $472);
        $474 = (($457) + 20|0);
        $475 = Math_fround(HEAPF32[$474>>2]);
        $476 = Math_fround($32 * $475);
        $477 = (($457) + 24|0);
        $478 = Math_fround(HEAPF32[$477>>2]);
        $479 = Math_fround($32 * $478);
        $480 = Math_fround($464 + $473);
        $481 = Math_fround($467 + $476);
        $482 = Math_fround($470 + $479);
        HEAPF32[$462>>2] = $480;
        HEAPF32[$465>>2] = $481;
        HEAPF32[$468>>2] = $482;
        $483 = (($3) + 32|0);
        $484 = Math_fround(HEAPF32[$483>>2]);
        HEAPF32[$0>>2] = $484;
        $485 = (($0) + 4|0);
        $486 = (($3) + 36|0);
        $487 = Math_fround(HEAPF32[$486>>2]);
        HEAPF32[$485>>2] = $487;
        $488 = (($0) + 8|0);
        $489 = (($3) + 40|0);
        $490 = Math_fround(HEAPF32[$489>>2]);
        HEAPF32[$488>>2] = $490;
        $491 = (($0) + 12|0);
        $492 = (($3) + 44|0);
        $493 = Math_fround(HEAPF32[$492>>2]);
        HEAPF32[$491>>2] = $493;
        $494 = (($0) + 16|0);
        HEAPF32[$494>>2] = $480;
        $495 = (($0) + 20|0);
        HEAPF32[$495>>2] = $481;
        $496 = (($0) + 24|0);
        HEAPF32[$496>>2] = $482;
        __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($newLastQ$i18,$32,$0,$457);
        $497 = Math_fround(HEAPF32[$newLastQ$i18>>2]);
        HEAPF32[$483>>2] = $497;
        $498 = (($newLastQ$i18) + 4|0);
        $499 = Math_fround(HEAPF32[$498>>2]);
        HEAPF32[$486>>2] = $499;
        $500 = (($newLastQ$i18) + 8|0);
        $501 = Math_fround(HEAPF32[$500>>2]);
        HEAPF32[$489>>2] = $501;
        $502 = (($newLastQ$i18) + 12|0);
        $503 = Math_fround(HEAPF32[$502>>2]);
        HEAPF32[$492>>2] = $503;
       }
       if ($clipTrajectoryToToi) {
        $504 = (($this) + 32|0);
        $505 = Math_fround(HEAPF32[$504>>2]);
        $506 = $505 == Math_fround(0.0);
        $507 = $506;
       } else {
        $507 = 0;
       }
       __ZN5physx12PxsRigidBody12advanceToToiEffb($3,$32,$dt,$507);
       $508 = HEAP32[$451>>2]|0;
       $509 = (($508) + 16|0);
       $510 = HEAP32[$509>>2]|0;
       $511 = (($510) + 1)|0;
       HEAP32[$509>>2] = $511;
      }
     }
     if ($299) {
      $512 = (($7) + 60|0);
      $513 = HEAP32[$512>>2]|0;
      $514 = (($513) + 2|0);
      $515 = HEAP16[$514>>1]|0;
      $516 = ($515<<16>>16)==(0);
      if ($516) {
       $517 = (($7) + 64|0);
       $518 = HEAP32[$517>>2]|0;
       $519 = (($518) + 124|0);
       $520 = Math_fround(HEAPF32[$519>>2]);
       $521 = $520 == Math_fround(0.0);
       if (!($521)) {
        $522 = Math_fround(Math_fround(1.0) - $32);
        $523 = (($7) + 48|0);
        $524 = Math_fround(HEAPF32[$523>>2]);
        $525 = Math_fround($522 * $524);
        $526 = (($7) + 52|0);
        $527 = Math_fround(HEAPF32[$526>>2]);
        $528 = Math_fround($522 * $527);
        $529 = (($7) + 56|0);
        $530 = Math_fround(HEAPF32[$529>>2]);
        $531 = Math_fround($522 * $530);
        $532 = (($518) + 16|0);
        $533 = Math_fround(HEAPF32[$532>>2]);
        $534 = Math_fround($32 * $533);
        $535 = (($518) + 20|0);
        $536 = Math_fround(HEAPF32[$535>>2]);
        $537 = Math_fround($32 * $536);
        $538 = (($518) + 24|0);
        $539 = Math_fround(HEAPF32[$538>>2]);
        $540 = Math_fround($32 * $539);
        $541 = Math_fround($525 + $534);
        $542 = Math_fround($528 + $537);
        $543 = Math_fround($531 + $540);
        HEAPF32[$523>>2] = $541;
        HEAPF32[$526>>2] = $542;
        HEAPF32[$529>>2] = $543;
        $544 = (($7) + 32|0);
        $545 = Math_fround(HEAPF32[$544>>2]);
        HEAPF32[$0>>2] = $545;
        $546 = (($0) + 4|0);
        $547 = (($7) + 36|0);
        $548 = Math_fround(HEAPF32[$547>>2]);
        HEAPF32[$546>>2] = $548;
        $549 = (($0) + 8|0);
        $550 = (($7) + 40|0);
        $551 = Math_fround(HEAPF32[$550>>2]);
        HEAPF32[$549>>2] = $551;
        $552 = (($0) + 12|0);
        $553 = (($7) + 44|0);
        $554 = Math_fround(HEAPF32[$553>>2]);
        HEAPF32[$552>>2] = $554;
        $555 = (($0) + 16|0);
        HEAPF32[$555>>2] = $541;
        $556 = (($0) + 20|0);
        HEAPF32[$556>>2] = $542;
        $557 = (($0) + 24|0);
        HEAPF32[$557>>2] = $543;
        __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($newLastQ$i18,$32,$0,$518);
        $558 = Math_fround(HEAPF32[$newLastQ$i18>>2]);
        HEAPF32[$544>>2] = $558;
        $559 = (($newLastQ$i18) + 4|0);
        $560 = Math_fround(HEAPF32[$559>>2]);
        HEAPF32[$547>>2] = $560;
        $561 = (($newLastQ$i18) + 8|0);
        $562 = Math_fround(HEAPF32[$561>>2]);
        HEAPF32[$550>>2] = $562;
        $563 = (($newLastQ$i18) + 12|0);
        $564 = Math_fround(HEAPF32[$563>>2]);
        HEAPF32[$553>>2] = $564;
       }
       if ($clipTrajectoryToToi) {
        $565 = (($this) + 32|0);
        $566 = Math_fround(HEAPF32[$565>>2]);
        $567 = $566 == Math_fround(0.0);
        $568 = $567;
       } else {
        $568 = 0;
       }
       __ZN5physx12PxsRigidBody12advanceToToiEffb($7,$32,$dt,$568);
       $569 = HEAP32[$512>>2]|0;
       $570 = (($569) + 16|0);
       $571 = HEAP32[$570>>2]|0;
       $572 = (($571) + 1)|0;
       HEAP32[$570>>2] = $572;
      }
     }
     $573 = (($this) + 32|0);
     $574 = Math_fround(HEAPF32[$573>>2]);
     $575 = $574 > Math_fround(0.0);
     if ($575) {
      if ($260) {
       $576 = (($3) + 60|0);
       $577 = HEAP32[$576>>2]|0;
       $578 = (($577) + 2|0);
       $579 = HEAP16[$578>>1]|0;
       $580 = ($579<<16>>16)==(0);
       if ($580) {
        $581 = (($3) + 64|0);
        $582 = HEAP32[$581>>2]|0;
        $583 = (($582) + 124|0);
        $584 = Math_fround(HEAPF32[$583>>2]);
        $585 = $584 == Math_fround(0.0);
        if (!($585)) {
         $586 = Math_fround(Math_fround(1.0) - $574);
         $587 = (($3) + 48|0);
         $588 = Math_fround(HEAPF32[$587>>2]);
         $589 = Math_fround($586 * $588);
         $590 = (($3) + 52|0);
         $591 = Math_fround(HEAPF32[$590>>2]);
         $592 = Math_fround($586 * $591);
         $593 = (($3) + 56|0);
         $594 = Math_fround(HEAPF32[$593>>2]);
         $595 = Math_fround($586 * $594);
         $596 = (($582) + 16|0);
         $597 = Math_fround(HEAPF32[$596>>2]);
         $598 = Math_fround($574 * $597);
         $599 = (($582) + 20|0);
         $600 = Math_fround(HEAPF32[$599>>2]);
         $601 = Math_fround($574 * $600);
         $602 = (($582) + 24|0);
         $603 = Math_fround(HEAPF32[$602>>2]);
         $604 = Math_fround($574 * $603);
         $605 = Math_fround($589 + $598);
         $606 = Math_fround($592 + $601);
         $607 = Math_fround($595 + $604);
         HEAPF32[$587>>2] = $605;
         HEAPF32[$590>>2] = $606;
         HEAPF32[$593>>2] = $607;
         $608 = (($3) + 32|0);
         $609 = Math_fround(HEAPF32[$608>>2]);
         HEAPF32[$0>>2] = $609;
         $610 = (($0) + 4|0);
         $611 = (($3) + 36|0);
         $612 = Math_fround(HEAPF32[$611>>2]);
         HEAPF32[$610>>2] = $612;
         $613 = (($0) + 8|0);
         $614 = (($3) + 40|0);
         $615 = Math_fround(HEAPF32[$614>>2]);
         HEAPF32[$613>>2] = $615;
         $616 = (($0) + 12|0);
         $617 = (($3) + 44|0);
         $618 = Math_fround(HEAPF32[$617>>2]);
         HEAPF32[$616>>2] = $618;
         $619 = (($0) + 16|0);
         HEAPF32[$619>>2] = $605;
         $620 = (($0) + 20|0);
         HEAPF32[$620>>2] = $606;
         $621 = (($0) + 24|0);
         HEAPF32[$621>>2] = $607;
         __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($newLastQ$i18,$574,$0,$582);
         $622 = Math_fround(HEAPF32[$newLastQ$i18>>2]);
         HEAPF32[$608>>2] = $622;
         $623 = (($newLastQ$i18) + 4|0);
         $624 = Math_fround(HEAPF32[$623>>2]);
         HEAPF32[$611>>2] = $624;
         $625 = (($newLastQ$i18) + 8|0);
         $626 = Math_fround(HEAPF32[$625>>2]);
         HEAPF32[$614>>2] = $626;
         $627 = (($newLastQ$i18) + 12|0);
         $628 = Math_fround(HEAPF32[$627>>2]);
         HEAPF32[$617>>2] = $628;
        }
        if ($clipTrajectoryToToi) {
         $629 = Math_fround(HEAPF32[$573>>2]);
         __ZN5physx12PxsRigidBody12advanceToToiEffb($3,$629,$dt,1);
        }
       }
      }
      if ($299) {
       $630 = (($7) + 60|0);
       $631 = HEAP32[$630>>2]|0;
       $632 = (($631) + 2|0);
       $633 = HEAP16[$632>>1]|0;
       $634 = ($633<<16>>16)==(0);
       if ($634) {
        $635 = Math_fround(HEAPF32[$573>>2]);
        $636 = (($7) + 64|0);
        $637 = HEAP32[$636>>2]|0;
        $638 = (($637) + 124|0);
        $639 = Math_fround(HEAPF32[$638>>2]);
        $640 = $639 == Math_fround(0.0);
        if (!($640)) {
         $641 = Math_fround(Math_fround(1.0) - $635);
         $642 = (($7) + 48|0);
         $643 = Math_fround(HEAPF32[$642>>2]);
         $644 = Math_fround($641 * $643);
         $645 = (($7) + 52|0);
         $646 = Math_fround(HEAPF32[$645>>2]);
         $647 = Math_fround($641 * $646);
         $648 = (($7) + 56|0);
         $649 = Math_fround(HEAPF32[$648>>2]);
         $650 = Math_fround($641 * $649);
         $651 = (($637) + 16|0);
         $652 = Math_fround(HEAPF32[$651>>2]);
         $653 = Math_fround($635 * $652);
         $654 = (($637) + 20|0);
         $655 = Math_fround(HEAPF32[$654>>2]);
         $656 = Math_fround($635 * $655);
         $657 = (($637) + 24|0);
         $658 = Math_fround(HEAPF32[$657>>2]);
         $659 = Math_fround($635 * $658);
         $660 = Math_fround($644 + $653);
         $661 = Math_fround($647 + $656);
         $662 = Math_fround($650 + $659);
         HEAPF32[$642>>2] = $660;
         HEAPF32[$645>>2] = $661;
         HEAPF32[$648>>2] = $662;
         $663 = (($7) + 32|0);
         $664 = Math_fround(HEAPF32[$663>>2]);
         HEAPF32[$0>>2] = $664;
         $665 = (($0) + 4|0);
         $666 = (($7) + 36|0);
         $667 = Math_fround(HEAPF32[$666>>2]);
         HEAPF32[$665>>2] = $667;
         $668 = (($0) + 8|0);
         $669 = (($7) + 40|0);
         $670 = Math_fround(HEAPF32[$669>>2]);
         HEAPF32[$668>>2] = $670;
         $671 = (($0) + 12|0);
         $672 = (($7) + 44|0);
         $673 = Math_fround(HEAPF32[$672>>2]);
         HEAPF32[$671>>2] = $673;
         $674 = (($0) + 16|0);
         HEAPF32[$674>>2] = $660;
         $675 = (($0) + 20|0);
         HEAPF32[$675>>2] = $661;
         $676 = (($0) + 24|0);
         HEAPF32[$676>>2] = $662;
         __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($newLastQ$i18,$635,$0,$637);
         $677 = Math_fround(HEAPF32[$newLastQ$i18>>2]);
         HEAPF32[$663>>2] = $677;
         $678 = (($newLastQ$i18) + 4|0);
         $679 = Math_fround(HEAPF32[$678>>2]);
         HEAPF32[$666>>2] = $679;
         $680 = (($newLastQ$i18) + 8|0);
         $681 = Math_fround(HEAPF32[$680>>2]);
         HEAPF32[$669>>2] = $681;
         $682 = (($newLastQ$i18) + 12|0);
         $683 = Math_fround(HEAPF32[$682>>2]);
         HEAPF32[$672>>2] = $683;
        }
        if ($clipTrajectoryToToi) {
         $684 = Math_fround(HEAPF32[$573>>2]);
         __ZN5physx12PxsRigidBody12advanceToToiEffb($7,$684,$dt,1);
        }
       }
      }
     }
     if ($260) {
      $685 = (($3) + 60|0);
      $686 = HEAP32[$685>>2]|0;
      $687 = (($686) + 2|0);
      HEAP16[$687>>1] = 1;
     }
     if (!($299)) {
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
     $688 = (($7) + 60|0);
     $689 = HEAP32[$688>>2]|0;
     $690 = (($689) + 2|0);
     HEAP16[$690>>1] = 1;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 if ($8) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $165 = (($3) + 60|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = (($166) + 2|0);
 $168 = HEAP16[$167>>1]|0;
 $169 = ($168<<16>>16)==(0);
 if (!($169)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $170 = (($3) + 64|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = (($171) + 124|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = $173 == Math_fround(0.0);
 if (!($174)) {
  $175 = Math_fround(Math_fround(1.0) - $32);
  $176 = (($3) + 48|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround($175 * $177);
  $179 = (($3) + 52|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = Math_fround($175 * $180);
  $182 = (($3) + 56|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = Math_fround($175 * $183);
  $185 = (($171) + 16|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = Math_fround($32 * $186);
  $188 = (($171) + 20|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = Math_fround($32 * $189);
  $191 = (($171) + 24|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = Math_fround($32 * $192);
  $194 = Math_fround($178 + $187);
  $195 = Math_fround($181 + $190);
  $196 = Math_fround($184 + $193);
  HEAPF32[$176>>2] = $194;
  HEAPF32[$179>>2] = $195;
  HEAPF32[$182>>2] = $196;
  $197 = (($3) + 32|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  HEAPF32[$0>>2] = $198;
  $199 = (($0) + 4|0);
  $200 = (($3) + 36|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  HEAPF32[$199>>2] = $201;
  $202 = (($0) + 8|0);
  $203 = (($3) + 40|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  HEAPF32[$202>>2] = $204;
  $205 = (($0) + 12|0);
  $206 = (($3) + 44|0);
  $207 = Math_fround(HEAPF32[$206>>2]);
  HEAPF32[$205>>2] = $207;
  $208 = (($0) + 16|0);
  HEAPF32[$208>>2] = $194;
  $209 = (($0) + 20|0);
  HEAPF32[$209>>2] = $195;
  $210 = (($0) + 24|0);
  HEAPF32[$210>>2] = $196;
  __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($newLastQ$i18,$32,$0,$171);
  $211 = Math_fround(HEAPF32[$newLastQ$i18>>2]);
  HEAPF32[$197>>2] = $211;
  $212 = (($newLastQ$i18) + 4|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  HEAPF32[$200>>2] = $213;
  $214 = (($newLastQ$i18) + 8|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  HEAPF32[$203>>2] = $215;
  $216 = (($newLastQ$i18) + 12|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  HEAPF32[$206>>2] = $217;
 }
 $218 = HEAP32[$170>>2]|0;
 $219 = (($218) + 124|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = $220 == Math_fround(0.0);
 if ($221) {
  $$pre55 = HEAP32[$165>>2]|0;
  $249 = $$pre55;
 } else {
  $222 = (($3) + 32|0);
  $223 = (($3) + 36|0);
  $224 = (($3) + 40|0);
  $225 = (($3) + 44|0);
  $226 = (($3) + 48|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = (($3) + 52|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = (($3) + 56|0);
  $231 = Math_fround(HEAPF32[$230>>2]);
  $232 = (($218) + 16|0);
  HEAPF32[$232>>2] = $227;
  $233 = (($218) + 20|0);
  HEAPF32[$233>>2] = $229;
  $234 = (($218) + 24|0);
  HEAPF32[$234>>2] = $231;
  $235 = Math_fround(HEAPF32[$222>>2]);
  $236 = Math_fround(HEAPF32[$223>>2]);
  $237 = Math_fround(HEAPF32[$224>>2]);
  $238 = Math_fround(HEAPF32[$225>>2]);
  HEAPF32[$218>>2] = $235;
  $239 = (($218) + 4|0);
  HEAPF32[$239>>2] = $236;
  $240 = (($218) + 8|0);
  HEAPF32[$240>>2] = $237;
  $241 = (($218) + 12|0);
  HEAPF32[$241>>2] = $238;
  $$pre$i = Math_fround(Math_fround(1.0) - $32);
  $242 = HEAP32[$165>>2]|0;
  $243 = (($242) + 4|0);
  $244 = Math_fround(HEAPF32[$243>>2]);
  $245 = Math_fround($$pre$i * $244);
  $246 = $245 > Math_fround(0.00999999977648258209228);
  $247 = $246 ? $245 : Math_fround(0.00999999977648258209228);
  HEAPF32[$243>>2] = $247;
  $249 = $242;
 }
 $248 = (($249) + 16|0);
 $250 = HEAP32[$248>>2]|0;
 $251 = (($250) + 1)|0;
 HEAP32[$248>>2] = $251;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx12PxsRigidBody12advanceToToiEffb($this,$toi,$dt,$clip) {
 $this = $this|0;
 $toi = Math_fround($toi);
 $dt = Math_fround($dt);
 $clip = $clip|0;
 var $$pre = Math_fround(0), $$pre$phiZ2D = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 124|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $3 == Math_fround(0.0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($1) + 16|0);
 $6 = (($this) + 32|0);
 $7 = (($this) + 36|0);
 $8 = (($this) + 40|0);
 $9 = (($this) + 44|0);
 $10 = (($this) + 48|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 52|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 56|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 if ($clip) {
  HEAPF32[$5>>2] = $11;
  $16 = (($1) + 20|0);
  HEAPF32[$16>>2] = $13;
  $17 = (($1) + 24|0);
  HEAPF32[$17>>2] = $15;
  $18 = Math_fround(HEAPF32[$6>>2]);
  $19 = Math_fround(HEAPF32[$7>>2]);
  $20 = Math_fround(HEAPF32[$8>>2]);
  $21 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$1>>2] = $18;
  $22 = (($1) + 4|0);
  HEAPF32[$22>>2] = $19;
  $23 = (($1) + 8|0);
  HEAPF32[$23>>2] = $20;
  $24 = (($1) + 12|0);
  HEAPF32[$24>>2] = $21;
  $$pre = Math_fround(Math_fround(1.0) - $toi);
  $$pre$phiZ2D = $$pre;
 } else {
  $25 = (($1) + 64|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($26 * $dt);
  $28 = (($1) + 68|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($29 * $dt);
  $31 = (($1) + 72|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($32 * $dt);
  $34 = Math_fround(Math_fround(1.0) - $toi);
  $35 = Math_fround($34 * $27);
  $36 = Math_fround($34 * $30);
  $37 = Math_fround($34 * $33);
  $38 = Math_fround($11 + $35);
  $39 = Math_fround($13 + $36);
  $40 = Math_fround($15 + $37);
  HEAPF32[$5>>2] = $38;
  $41 = (($1) + 20|0);
  HEAPF32[$41>>2] = $39;
  $42 = (($1) + 24|0);
  HEAPF32[$42>>2] = $40;
  $43 = (($1) + 80|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($44 * $dt);
  $46 = (($1) + 84|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($47 * $dt);
  $49 = (($1) + 88|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($50 * $dt);
  $52 = Math_fround($34 * $45);
  $53 = Math_fround($34 * $48);
  $54 = Math_fround($34 * $51);
  $55 = Math_fround($52 * $52);
  $56 = Math_fround($53 * $53);
  $57 = Math_fround($55 + $56);
  $58 = Math_fround($54 * $54);
  $59 = Math_fround($57 + $58);
  $60 = (Math_fround(Math_sqrt((Math_fround($59)))));
  $61 = $60 > Math_fround(9.99999968265522538896E-21);
  if ($61) {
   $62 = Math_fround(Math_fround(1.0) / $60);
   $63 = Math_fround($52 * $62);
   $64 = Math_fround($53 * $62);
   $65 = Math_fround($54 * $62);
   $70 = $63;$72 = $64;$74 = $65;
  } else {
   $70 = Math_fround(1.0);$72 = Math_fround(0.0);$74 = Math_fround(0.0);
  }
  $66 = Math_fround($60 * Math_fround(0.5));
  $67 = (Math_fround(+(Math_sin((+$66)))));
  $68 = (Math_fround(+(Math_cos((+$66)))));
  $69 = Math_fround($70 * $67);
  $71 = Math_fround($72 * $67);
  $73 = Math_fround($74 * $67);
  $75 = Math_fround(HEAPF32[$6>>2]);
  $76 = Math_fround(HEAPF32[$7>>2]);
  $77 = Math_fround(HEAPF32[$8>>2]);
  $78 = Math_fround(HEAPF32[$9>>2]);
  $79 = Math_fround($69 * $78);
  $80 = Math_fround($68 * $75);
  $81 = Math_fround($80 + $79);
  $82 = Math_fround($73 * $76);
  $83 = Math_fround($82 + $81);
  $84 = Math_fround($71 * $77);
  $85 = Math_fround($83 - $84);
  $86 = Math_fround($71 * $78);
  $87 = Math_fround($68 * $76);
  $88 = Math_fround($87 + $86);
  $89 = Math_fround($69 * $77);
  $90 = Math_fround($89 + $88);
  $91 = Math_fround($73 * $75);
  $92 = Math_fround($90 - $91);
  $93 = Math_fround($73 * $78);
  $94 = Math_fround($68 * $77);
  $95 = Math_fround($94 + $93);
  $96 = Math_fround($71 * $75);
  $97 = Math_fround($96 + $95);
  $98 = Math_fround($69 * $76);
  $99 = Math_fround($97 - $98);
  $100 = Math_fround($68 * $78);
  $101 = Math_fround($69 * $75);
  $102 = Math_fround($100 - $101);
  $103 = Math_fround($71 * $76);
  $104 = Math_fround($102 - $103);
  $105 = Math_fround($73 * $77);
  $106 = Math_fround($104 - $105);
  HEAPF32[$1>>2] = $85;
  $107 = (($1) + 4|0);
  HEAPF32[$107>>2] = $92;
  $108 = (($1) + 8|0);
  HEAPF32[$108>>2] = $99;
  $109 = (($1) + 12|0);
  HEAPF32[$109>>2] = $106;
  $$pre$phiZ2D = $34;
 }
 $110 = (($this) + 60|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = (($111) + 4|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($$pre$phiZ2D * $113);
 $115 = $114 > Math_fround(0.00999999977648258209228);
 $116 = $115 ? $114 : Math_fround(0.00999999977648258209228);
 HEAPF32[$112>>2] = $116;
 STACKTOP = sp;return;
}
function __ZN5physx13PxsCCDContext14updateCCDBeginEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 96|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx13PxsCCDContext12updateCCDEndEv($this) {
 $this = $this|0;
 var $$phi$trans$insert$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre4$i$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 260|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 $5 = ($1|0)==($4|0);
 if ($5) {
  $6 = (($this) + 112|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 << 7;
  $9 = (($this) + 100|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($7<<3)|0) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (0 - ($8))|0;
  $14 = ($12|0)==($13|0);
  if ($14) {
   $27 = $10;
  } else {
   $15 = $7 << 7;
   $16 = (($12) + ($15))|0;
   $20 = $10;$j$01 = 0;
   while(1) {
    $17 = $j$01 & 127;
    $18 = $j$01 >>> 7;
    $19 = (($20) + ($18<<3)|0);
    $21 = HEAP32[$19>>2]|0;
    $22 = ((($21) + (($17*20)|0)|0) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + 60|0);
    HEAP32[$24>>2] = 0;
    $25 = (($j$01) + 1)|0;
    $exitcond = ($25|0)==($16|0);
    $$pre = HEAP32[$9>>2]|0;
    if ($exitcond) {
     $27 = $$pre;
     break;
    } else {
     $20 = $$pre;$j$01 = $25;
    }
   }
  }
  HEAP32[$6>>2] = 0;
  $26 = (($27) + 4|0);
  HEAP32[$26>>2] = 0;
 }
 $28 = (($this) + 144|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 132|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 192|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 if ($34) {
  $55 = HEAP32[$0>>2]|0;
  $56 = (($55) + 1)|0;
  HEAP32[$0>>2] = $56;
  STACKTOP = sp;return;
 }
 $35 = (($this) + 208|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  $55 = HEAP32[$0>>2]|0;
  $56 = (($55) + 1)|0;
  HEAP32[$0>>2] = $56;
  STACKTOP = sp;return;
 }
 $38 = (($this) + 184|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $33 << 2;
 _memset(($39|0),-1,($40|0))|0;
 $41 = (($this) + 188|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + -1)|0;
 $44 = ($43|0)==(0);
 $$phi$trans$insert$i$i = (($this) + 180|0);
 $$pre4$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
 if ($44) {
  $51 = $42;$53 = $$pre4$i$i;
 } else {
  $46 = $$pre4$i$i;$i$01$i$i = 0;
  while(1) {
   $$sum$i$i = (($i$01$i$i) + 32)|0;
   $45 = (($46) + ($$sum$i$i<<2)|0);
   $47 = (($i$01$i$i) + 1)|0;
   $48 = HEAP32[$$phi$trans$insert$i$i>>2]|0;
   $49 = (($48) + ($i$01$i$i<<2)|0);
   HEAP32[$49>>2] = $47;
   $exitcond$i$i = ($47|0)==($43|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $46 = $48;$i$01$i$i = $47;
   }
  }
  $$pre$i$i = HEAP32[$41>>2]|0;
  $51 = $$pre$i$i;$53 = $48;
 }
 $50 = (($51) + -1)|0;
 $52 = (($53) + ($50<<2)|0);
 HEAP32[$52>>2] = -1;
 $54 = (($this) + 200|0);
 HEAP32[$54>>2] = 0;
 HEAP32[$35>>2] = 0;
 $55 = HEAP32[$0>>2]|0;
 $56 = (($55) + 1)|0;
 HEAP32[$0>>2] = $56;
 STACKTOP = sp;return;
}
function __ZN5physx13PxsCCDContext9updateCCDEfPNS_10PxBaseTaskEb($this,$dt,$continuation,$disableResweep) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $continuation = $continuation|0;
 $disableResweep = $disableResweep|0;
 var $$$i$i$i$i$i = 0, $$0$i$i$ph = 0, $$0$i$i14 = 0, $$lobit = 0, $$op = 0, $$ph = 0, $$ph92 = 0, $$ph93 = 0, $$ph94113 = 0, $$ph95114 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$phiZ2D = 0, $$pre133 = 0, $$pre134 = Math_fround(0), $$pre135 = Math_fround(0), $$pre136 = Math_fround(0), $$pre137 = Math_fround(0), $$pre138 = Math_fround(0), $$pre139 = Math_fround(0);
 var $$pre140 = Math_fround(0), $$pre141 = Math_fround(0), $$pre142 = Math_fround(0), $$pre143 = Math_fround(0), $$pre144 = Math_fround(0), $$pre145 = Math_fround(0), $$pre146 = Math_fround(0), $$pre147 = Math_fround(0), $$pre148 = Math_fround(0), $$pre149 = Math_fround(0), $$pre150 = Math_fround(0), $$pre151 = Math_fround(0), $$pre152 = Math_fround(0), $$pre153 = Math_fround(0), $$pre156 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0);
 var $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0;
 var $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0;
 var $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = 0, $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0);
 var $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0);
 var $409 = Math_fround(0), $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = 0, $425 = Math_fround(0), $426 = 0;
 var $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = 0;
 var $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = Math_fround(0), $452 = 0, $453 = 0, $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0);
 var $463 = 0, $464 = Math_fround(0), $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = Math_fround(0), $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0);
 var $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = Math_fround(0), $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = Math_fround(0), $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0;
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0;
 var $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0;
 var $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0;
 var $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0;
 var $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0;
 var $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0;
 var $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0;
 var $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0;
 var $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $a$086 = 0, $a6$062 = 0, $a8$058 = 0, $batchBegin$057 = 0, $batchBegin$057$us = 0, $ccdShape0$0 = 0, $ccdShape1$0 = 0, $count$061 = 0, $exists$i25 = 0;
 var $exitcond = 0, $exitcond118 = 0, $exitcond120 = 0, $extents = 0, $extents2 = 0, $inEnabled$not$i$i$i = 0, $index$0$i$i = 0, $index$0$i$i11 = 0, $index$0$ph96115 = 0, $index$0100 = 0, $index$04$i$i = 0, $index$04$i$i7 = 0, $index$05$i$i = 0, $index$05$i$i9 = 0, $islandCount$0$lcssa = 0, $islandCount$080 = 0, $islandCount$1 = 0, $islandLabels = 0, $islandSize$075 = 0, $islandSize$1$lcssa = 0;
 var $islandSize$167 = 0, $islandSize$2 = 0, $j3$079 = 0, $j4$063 = 0, $needsSweep$0$off0$ph116 = 0, $needsSweep$0$off0101 = 0, $needsSweep$1$off0 = 0, $oldTm0 = 0, $oldTm1 = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i6 = 0, $or$cond$i26 = 0, $or$cond5 = 0, $origin = 0, $origin1 = 0, $overlaps$0 = 0, $overlaps$0$i = 0, $overlaps$01$i = 0;
 var $overlaps$02$i = 0, $overlaps$066 = 0, $overlaps$070 = 0, $rv$0$i$i = 0, $stack = 0, $stackSize$177 = 0, $stackSize$2$lcssa = 0, $stackSize$269 = 0, $stackSize$3 = 0, $threshold0$0 = Math_fround(0), $threshold1$0 = Math_fround(0), $tm0 = 0, $tm1 = 0, $top$076 = 0, $top$1$lcssa = 0, $top$168 = 0, $top$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $exists$i25 = sp + 211|0;
 $0 = sp + 200|0;
 $tm0 = sp + 172|0;
 $oldTm0 = sp + 144|0;
 $origin = sp + 132|0;
 $extents = sp + 120|0;
 $1 = sp + 112|0;
 $tm1 = sp + 80|0;
 $oldTm1 = sp + 52|0;
 $origin1 = sp + 40|0;
 $extents2 = sp + 28|0;
 $2 = sp + 24|0;
 $islandLabels = sp + 12|0;
 $3 = sp + 208|0;
 $stack = sp;
 $4 = sp + 108|0;
 $5 = sp + 210|0;
 $6 = (($this) + 88|0);
 $7 = $disableResweep&1;
 HEAP8[$6>>0] = $7;
 $8 = (($this) + 264|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 5868|0);
 $11 = (($9) + 5872|0);
 HEAP32[$11>>2] = 0;
 $12 = (($9) + 1348|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($9) + 1344|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $13 << 2;
 _memset(($15|0),0,($16|0))|0;
 $17 = (($9) + 1356|0);
 HEAP32[$17>>2] = 0;
 $18 = (($9) + 1360|0);
 HEAP32[$18>>2] = 0;
 $19 = (($9) + 1364|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 92|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  label = 3;
 } else {
  $23 = (($this) + 96|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0);
  if ($25) {
   $$pre$phiZ2D = $23;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $26 = HEAP32[$8>>2]|0;
  $27 = (($26) + 7380|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0);
  $$pre156 = (($this) + 96|0);
  if ($29) {
   $$pre$phiZ2D = $$pre156;
  } else {
   HEAP32[$$pre156>>2] = 0;
   $30 = (($26) + 224|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (__ZN5physx6shdfnd9SListImpl3popEv($31)|0);
   $33 = ($32|0)==(0|0);
   if ($33) {
    $34 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (__Z15PxGetFoundationv()|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 24|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (FUNCTION_TABLE_ii[$41 & 4095]($38)|0);
    $$$i$i$i$i$i = $42 ? 488336 : 485568;
    $43 = (FUNCTION_TABLE_iiiiii[$37 & 255]($34,9459,$$$i$i$i$i$i,488232,82)|0);
    $44 = ($43|0)==(0|0);
    if ($44) {
     $rv$0$i$i = 0;
    } else {
     $45 = (($43) + 19|0);
     $46 = $45;
     $47 = $46 & -16;
     $48 = $43;
     $49 = (($47) - ($48))|0;
     $50 = $47;
     $51 = (($50) + -4|0);
     HEAP32[$51>>2] = $49;
     $52 = $47;
     $53 = ($47|0)==(0);
     if ($53) {
      $rv$0$i$i = $52;
     } else {
      __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($52,$26);
      $rv$0$i$i = $52;
     }
    }
   } else {
    $rv$0$i$i = $32;
   }
   $54 = (($this) + 252|0);
   HEAP32[$54>>2] = $rv$0$i$i;
   $55 = (($rv$0$i$i) + 8764|0);
   HEAPF32[$55>>2] = $dt;
   $56 = (($this) + 212|0);
   $57 = (($this) + 224|0);
   HEAP32[$57>>2] = 0;
   $58 = HEAP32[$56>>2]|0;
   $59 = (($58) + 4|0);
   HEAP32[$59>>2] = 0;
   $60 = (($this) + 228|0);
   $61 = (($this) + 232|0);
   HEAP32[$61>>2] = 0;
   $62 = (($this) + 116|0);
   $63 = (($this) + 128|0);
   HEAP32[$63>>2] = 0;
   $64 = HEAP32[$62>>2]|0;
   $65 = (($64) + 4|0);
   HEAP32[$65>>2] = 0;
   $66 = HEAP32[$8>>2]|0;
   $67 = (($66) + 6736|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + 8|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = $68;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = (($71) + 4)|0;
   $75 = $74;
   $76 = HEAP32[$75>>2]|0;
   $77 = HEAPU16[545736>>1]|(HEAPU16[545736+2>>1]<<16);
   $78 = $77 & 16711680;
   $inEnabled$not$i$i$i = ($78|0)==(0);
   $79 = ($70|0)==(0|0);
   $or$cond$i$i$i = $79 | $inEnabled$not$i$i$i;
   if ($or$cond$i$i$i) {
    $85 = $66;
   } else {
    $80 = $77&65535;
    $81 = HEAP32[$70>>2]|0;
    $82 = (($81) + 8|0);
    $83 = HEAP32[$82>>2]|0;
    FUNCTION_TABLE_viiii[$83 & 511]($70,$80,$73,$76);
    $$pre = HEAP32[$8>>2]|0;
    $85 = $$pre;
   }
   $84 = (($85) + 1332|0);
   $86 = (($85) + 1336|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = $87 & 2147483647;
   $89 = ($88|0)==(0);
   L14: do {
    if (!($89)) {
     $$pre$i$i$i = HEAP32[$84>>2]|0;
     $91 = 0;
     while(1) {
      $90 = (($$pre$i$i$i) + ($91<<2)|0);
      $92 = HEAP32[$90>>2]|0;
      $93 = ($92|0)==(0);
      if (!($93)) {
       break;
      }
      $94 = (($91) + 1)|0;
      $95 = ($94>>>0)<($88>>>0);
      if ($95) {
       $91 = $94;
      } else {
       break L14;
      }
     }
     $96 = $91 << 5;
     $97 = (0 - ($92))|0;
     $98 = $92 & $97;
     $99 = Math_imul($98, 125613361)|0;
     $100 = $99 >>> 27;
     $101 = (412480 + ($100<<2)|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = $102 | $96;
     $104 = (($92) + -1)|0;
     $105 = $104 & $92;
     $106 = ($105|0)==(0);
     L20: do {
      if ($106) {
       $108 = $91;
       while(1) {
        $107 = (($108) + 1)|0;
        $109 = ($107>>>0)<($88>>>0);
        if (!($109)) {
         $$ph92 = $107;$$ph93 = 0;
         break L20;
        }
        $110 = (($$pre$i$i$i) + ($107<<2)|0);
        $111 = HEAP32[$110>>2]|0;
        $112 = ($111|0)==(0);
        if ($112) {
         $108 = $107;
        } else {
         $$ph92 = $107;$$ph93 = $111;
         break;
        }
       }
      } else {
       $$ph92 = $91;$$ph93 = $105;
      }
     } while(0);
     $113 = ($103|0)==(-1);
     if (!($113)) {
      $114 = (($this) + 192|0);
      $115 = (($this) + 132|0);
      $116 = (($0) + 4|0);
      $117 = (($this) + 172|0);
      $118 = (($oldTm0) + 4|0);
      $119 = (($tm0) + 4|0);
      $120 = (($oldTm0) + 8|0);
      $121 = (($tm0) + 8|0);
      $122 = (($oldTm0) + 12|0);
      $123 = (($tm0) + 12|0);
      $124 = (($oldTm0) + 16|0);
      $125 = (($tm0) + 16|0);
      $126 = (($oldTm0) + 20|0);
      $127 = (($tm0) + 20|0);
      $128 = (($oldTm0) + 24|0);
      $129 = (($tm0) + 24|0);
      $130 = (($origin) + 4|0);
      $131 = (($origin) + 8|0);
      $132 = (($extents) + 4|0);
      $133 = (($extents) + 8|0);
      $134 = (($1) + 4|0);
      $135 = (($oldTm1) + 4|0);
      $136 = (($tm1) + 4|0);
      $137 = (($oldTm1) + 8|0);
      $138 = (($tm1) + 8|0);
      $139 = (($oldTm1) + 12|0);
      $140 = (($tm1) + 12|0);
      $141 = (($oldTm1) + 16|0);
      $142 = (($tm1) + 16|0);
      $143 = (($oldTm1) + 20|0);
      $144 = (($tm1) + 20|0);
      $145 = (($oldTm1) + 24|0);
      $146 = (($tm1) + 24|0);
      $147 = (($origin1) + 4|0);
      $148 = (($origin1) + 8|0);
      $149 = (($extents2) + 4|0);
      $150 = (($extents2) + 8|0);
      $151 = (($this) + 100|0);
      $152 = (($this) + 112|0);
      $153 = (($this) + 184|0);
      $154 = (($this) + 176|0);
      $155 = (($this) + 180|0);
      $$ph94113 = $$ph92;$$ph95114 = $$ph93;$992 = $85;$index$0$ph96115 = $103;$needsSweep$0$off0$ph116 = 0;
      L26: while(1) {
       $158 = $$ph94113 << 5;
       $160 = $992;$581 = $$ph95114;$index$0100 = $index$0$ph96115;$needsSweep$0$off0101 = $needsSweep$0$off0$ph116;
       while(1) {
        $159 = (($160) + 708|0);
        $161 = HEAP32[$159>>2]|0;
        $162 = $index$0100 >>> $161;
        $163 = (($160) + 720|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = (($164) + ($162<<2)|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = (($160) + 696|0);
        $168 = HEAP32[$167>>2]|0;
        $169 = (($168) + -1)|0;
        $170 = $169 & $index$0100;
        $171 = (($166) + ($170<<7)|0);
        $172 = ((($166) + ($170<<7)|0) + 8|0);
        $173 = HEAP32[$172>>2]|0;
        $174 = $173 & 2;
        $175 = ($174|0)==(0);
        if ($175) {
         $993 = $160;$needsSweep$1$off0 = $needsSweep$0$off0101;
        } else {
         $176 = ((($166) + ($170<<7)|0) + 38|0);
         $177 = HEAP16[$176>>1]|0;
         $178 = $177 & 24;
         $179 = ($178<<16>>16)==(24);
         if ($179) {
          $993 = $160;$needsSweep$1$off0 = $needsSweep$0$off0101;
         } else {
          $180 = ((($166) + ($170<<7)|0) + 80|0);
          $181 = HEAP32[$180>>2]|0;
          $182 = ((($166) + ($170<<7)|0) + 84|0);
          $183 = HEAP32[$182>>2]|0;
          $184 = ((($166) + ($170<<7)|0) + 88|0);
          $185 = HEAP32[$184>>2]|0;
          $186 = ((($166) + ($170<<7)|0) + 92|0);
          $187 = HEAP32[$186>>2]|0;
          $188 = HEAP32[$171>>2]|0;
          $189 = ((($166) + ($170<<7)|0) + 4|0);
          $190 = HEAP32[$189>>2]|0;
          $191 = HEAP32[$114>>2]|0;
          $192 = ($191|0)==(0);
          do {
           if ($192) {
            $994 = 0;
            label = 42;
           } else {
            $193 = $185;
            $194 = $193 << 15;
            $195 = $194 ^ -1;
            $196 = (($193) + ($195))|0;
            $197 = $196 >>> 10;
            $198 = $197 ^ $196;
            $199 = ($198*9)|0;
            $200 = $199 >>> 6;
            $201 = $200 ^ $199;
            $202 = $201 << 11;
            $203 = $202 ^ -1;
            $204 = (($201) + ($203))|0;
            $205 = $204 >>> 16;
            $206 = $205 ^ $204;
            $207 = $181;
            $208 = $207 << 15;
            $209 = $208 ^ -1;
            $210 = (($207) + ($209))|0;
            $211 = $210 >>> 10;
            $212 = $211 ^ $210;
            $213 = ($212*9)|0;
            $214 = $213 >>> 6;
            $215 = $214 ^ $213;
            $216 = $215 << 11;
            $217 = $216 ^ -1;
            $218 = (($215) + ($217))|0;
            $219 = $218 >>> 16;
            $220 = $218 ^ -57320555;
            $221 = $220 ^ $219;
            $222 = ($221*1000007)|0;
            $223 = $206 ^ $222;
            $224 = (($191) + -1)|0;
            $225 = $223 & $224;
            $226 = HEAP32[$153>>2]|0;
            $227 = (($226) + ($225<<2)|0);
            $index$04$i$i = HEAP32[$227>>2]|0;
            $228 = ($index$04$i$i|0)==(-1);
            L35: do {
             if ($228) {
              $$0$i$i$ph = 0;
             } else {
              $229 = HEAP32[$154>>2]|0;
              $index$05$i$i = $index$04$i$i;
              while(1) {
               $230 = (($229) + (($index$05$i$i*12)|0)|0);
               $231 = HEAP32[$230>>2]|0;
               $232 = ($231|0)==($181|0);
               if ($232) {
                $233 = ((($229) + (($index$05$i$i*12)|0)|0) + 4|0);
                $234 = HEAP32[$233>>2]|0;
                $235 = ($234|0)==($185|0);
                if ($235) {
                 break;
                }
               }
               $236 = HEAP32[$155>>2]|0;
               $237 = (($236) + ($index$05$i$i<<2)|0);
               $index$0$i$i = HEAP32[$237>>2]|0;
               $238 = ($index$0$i$i|0)==(-1);
               if ($238) {
                $$0$i$i$ph = 0;
                break L35;
               } else {
                $index$05$i$i = $index$0$i$i;
               }
              }
              $239 = (($229) + (($index$05$i$i*12)|0)|0);
              $$0$i$i$ph = $239;
             }
            } while(0);
            $240 = $187;
            $241 = $240 << 15;
            $242 = $241 ^ -1;
            $243 = (($240) + ($242))|0;
            $244 = $243 >>> 10;
            $245 = $244 ^ $243;
            $246 = ($245*9)|0;
            $247 = $246 >>> 6;
            $248 = $247 ^ $246;
            $249 = $248 << 11;
            $250 = $249 ^ -1;
            $251 = (($248) + ($250))|0;
            $252 = $251 >>> 16;
            $253 = $252 ^ $251;
            $254 = $183;
            $255 = $254 << 15;
            $256 = $255 ^ -1;
            $257 = (($254) + ($256))|0;
            $258 = $257 >>> 10;
            $259 = $258 ^ $257;
            $260 = ($259*9)|0;
            $261 = $260 >>> 6;
            $262 = $261 ^ $260;
            $263 = $262 << 11;
            $264 = $263 ^ -1;
            $265 = (($262) + ($264))|0;
            $266 = $265 >>> 16;
            $267 = $265 ^ -57320555;
            $268 = $267 ^ $266;
            $269 = ($268*1000007)|0;
            $270 = $253 ^ $269;
            $271 = $224 & $270;
            $272 = (($226) + ($271<<2)|0);
            $index$04$i$i7 = HEAP32[$272>>2]|0;
            $273 = ($index$04$i$i7|0)==(-1);
            L44: do {
             if ($273) {
              $$0$i$i14 = 0;
             } else {
              $274 = HEAP32[$154>>2]|0;
              $index$05$i$i9 = $index$04$i$i7;
              while(1) {
               $275 = (($274) + (($index$05$i$i9*12)|0)|0);
               $276 = HEAP32[$275>>2]|0;
               $277 = ($276|0)==($183|0);
               if ($277) {
                $278 = ((($274) + (($index$05$i$i9*12)|0)|0) + 4|0);
                $279 = HEAP32[$278>>2]|0;
                $280 = ($279|0)==($187|0);
                if ($280) {
                 break;
                }
               }
               $281 = HEAP32[$155>>2]|0;
               $282 = (($281) + ($index$05$i$i9<<2)|0);
               $index$0$i$i11 = HEAP32[$282>>2]|0;
               $283 = ($index$0$i$i11|0)==(-1);
               if ($283) {
                $$0$i$i14 = 0;
                break L44;
               } else {
                $index$05$i$i9 = $index$0$i$i11;
               }
              }
              $284 = (($274) + (($index$05$i$i9*12)|0)|0);
              $$0$i$i14 = $284;
             }
            } while(0);
            $285 = ($$0$i$i$ph|0)==(0|0);
            if ($285) {
             $292 = 0;
            } else {
             $286 = (($$0$i$i$ph) + 8|0);
             $287 = HEAP32[$286>>2]|0;
             $292 = $287;
            }
            $288 = ($$0$i$i14|0)==(0|0);
            if ($288) {
             $995 = 0;
            } else {
             $289 = (($$0$i$i14) + 8|0);
             $290 = HEAP32[$289>>2]|0;
             $995 = $290;
            }
            $291 = ($292|0)==(0|0);
            if ($291) {
             $994 = $995;
             label = 42;
             break;
            }
            $364 = (($292) + 8|0);
            $365 = Math_fround(HEAPF32[$364>>2]);
            $366 = (($292) + 56|0);
            $367 = Math_fround(HEAPF32[$366>>2]);
            $368 = (($292) + 28|0);
            $369 = Math_fround(HEAPF32[$368>>2]);
            $370 = Math_fround($367 - $369);
            $371 = (($292) + 60|0);
            $372 = Math_fround(HEAPF32[$371>>2]);
            $373 = (($292) + 32|0);
            $374 = Math_fround(HEAPF32[$373>>2]);
            $375 = Math_fround($372 - $374);
            $376 = (($292) + 64|0);
            $377 = Math_fround(HEAPF32[$376>>2]);
            $378 = (($292) + 36|0);
            $379 = Math_fround(HEAPF32[$378>>2]);
            $380 = Math_fround($377 - $379);
            $382 = $995;$566 = $370;$569 = $375;$572 = $380;$ccdShape0$0 = $292;$threshold0$0 = $365;
           }
          } while(0);
          if ((label|0) == 42) {
           label = 0;
           $293 = (__ZN5physx16PxsCCDBlockArrayINS_11PxsCCDShapeELi128EE8pushBackEv($115)|0);
           HEAP32[$0>>2] = $181;
           HEAP32[$116>>2] = $185;
           $294 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IPKNS_12PxsRigidCoreEPKNS_12PxsShapeCoreEEEPNS_11PxsCCDShapeEEESA_NS0_4HashISA_EENS1_11HashMapBaseISA_SD_SG_NS0_9AllocatorEE6GetKeyESI_Lb1EE6createERSB_Rb($117,$0,$exists$i25)|0);
           $295 = HEAP8[$exists$i25>>0]|0;
           $296 = ($295<<24>>24)!=(0);
           $297 = ($294|0)==(0|0);
           $or$cond$i = $296 | $297;
           if (!($or$cond$i)) {
            $298 = HEAP32[$0>>2]|0;
            HEAP32[$294>>2] = $298;
            $299 = (($294) + 4|0);
            $300 = HEAP32[$116>>2]|0;
            HEAP32[$299>>2] = $300;
            $301 = (($294) + 8|0);
            HEAP32[$301>>2] = $293;
           }
           $302 = (($293) + 4|0);
           HEAP32[$302>>2] = $181;
           HEAP32[$293>>2] = $185;
           __ZNK5physx11PxsCCDShape10getAbsPoseEPKNS_12PxsRigidBodyE($tm0,$293,$188);
           $303 = ($188|0)==(0|0);
           if ($303) {
            $304 = Math_fround(HEAPF32[$tm0>>2]);
            HEAPF32[$oldTm0>>2] = $304;
            $305 = Math_fround(HEAPF32[$119>>2]);
            HEAPF32[$118>>2] = $305;
            $306 = Math_fround(HEAPF32[$121>>2]);
            HEAPF32[$120>>2] = $306;
            $307 = Math_fround(HEAPF32[$123>>2]);
            HEAPF32[$122>>2] = $307;
            $308 = Math_fround(HEAPF32[$125>>2]);
            HEAPF32[$124>>2] = $308;
            $309 = Math_fround(HEAPF32[$127>>2]);
            HEAPF32[$126>>2] = $309;
            $310 = Math_fround(HEAPF32[$129>>2]);
            HEAPF32[$128>>2] = $310;
            $312 = $308;$313 = $308;$315 = $309;$316 = $309;$318 = $310;$319 = $310;$339 = $304;$341 = $305;$343 = $306;$345 = $307;
           } else {
            __ZNK5physx11PxsCCDShape17getLastCCDAbsPoseEPKNS_12PxsRigidBodyE($oldTm0,$293,$188);
            $$pre134 = Math_fround(HEAPF32[$125>>2]);
            $$pre135 = Math_fround(HEAPF32[$124>>2]);
            $$pre136 = Math_fround(HEAPF32[$127>>2]);
            $$pre137 = Math_fround(HEAPF32[$126>>2]);
            $$pre138 = Math_fround(HEAPF32[$129>>2]);
            $$pre139 = Math_fround(HEAPF32[$128>>2]);
            $$pre140 = Math_fround(HEAPF32[$oldTm0>>2]);
            $$pre141 = Math_fround(HEAPF32[$118>>2]);
            $$pre142 = Math_fround(HEAPF32[$120>>2]);
            $$pre143 = Math_fround(HEAPF32[$122>>2]);
            $312 = $$pre135;$313 = $$pre134;$315 = $$pre137;$316 = $$pre136;$318 = $$pre139;$319 = $$pre138;$339 = $$pre140;$341 = $$pre141;$343 = $$pre142;$345 = $$pre143;
           }
           $311 = Math_fround($313 - $312);
           $314 = Math_fround($316 - $315);
           $317 = Math_fround($319 - $318);
           $320 = (($185) + 36|0);
           $321 = (Math_fround(__ZNK5physx2Gu13GeometryUnion29computeBoundsWithCCDThresholdERNS_6PxVec3ES3_RKNS_11PxTransformEPKNS_9PxBounds3E($320,$origin,$extents,$tm0,0)));
           $322 = Math_fround(HEAPF32[$origin>>2]);
           $323 = Math_fround($322 - $311);
           $324 = Math_fround(HEAPF32[$130>>2]);
           $325 = Math_fround($324 - $314);
           $326 = Math_fround(HEAPF32[$131>>2]);
           $327 = Math_fround($326 - $317);
           $328 = (($293) + 80|0);
           HEAPF32[$328>>2] = $323;
           $329 = (($293) + 84|0);
           HEAPF32[$329>>2] = $325;
           $330 = (($293) + 88|0);
           HEAPF32[$330>>2] = $327;
           $331 = Math_fround(HEAPF32[$extents>>2]);
           $332 = (($293) + 68|0);
           HEAPF32[$332>>2] = $331;
           $333 = Math_fround(HEAPF32[$132>>2]);
           $334 = (($293) + 72|0);
           HEAPF32[$334>>2] = $333;
           $335 = Math_fround(HEAPF32[$133>>2]);
           $336 = (($293) + 76|0);
           HEAPF32[$336>>2] = $335;
           $337 = (($293) + 8|0);
           HEAPF32[$337>>2] = $321;
           $338 = (($293) + 12|0);
           HEAPF32[$338>>2] = $339;
           $340 = (($293) + 16|0);
           HEAPF32[$340>>2] = $341;
           $342 = (($293) + 20|0);
           HEAPF32[$342>>2] = $343;
           $344 = (($293) + 24|0);
           HEAPF32[$344>>2] = $345;
           $346 = (($293) + 28|0);
           HEAPF32[$346>>2] = $312;
           $347 = (($293) + 32|0);
           HEAPF32[$347>>2] = $315;
           $348 = (($293) + 36|0);
           HEAPF32[$348>>2] = $318;
           $349 = Math_fround(HEAPF32[$tm0>>2]);
           $350 = (($293) + 40|0);
           HEAPF32[$350>>2] = $349;
           $351 = Math_fround(HEAPF32[$119>>2]);
           $352 = (($293) + 44|0);
           HEAPF32[$352>>2] = $351;
           $353 = Math_fround(HEAPF32[$121>>2]);
           $354 = (($293) + 48|0);
           HEAPF32[$354>>2] = $353;
           $355 = Math_fround(HEAPF32[$123>>2]);
           $356 = (($293) + 52|0);
           HEAPF32[$356>>2] = $355;
           $357 = Math_fround(HEAPF32[$125>>2]);
           $358 = (($293) + 56|0);
           HEAPF32[$358>>2] = $357;
           $359 = Math_fround(HEAPF32[$127>>2]);
           $360 = (($293) + 60|0);
           HEAPF32[$360>>2] = $359;
           $361 = Math_fround(HEAPF32[$129>>2]);
           $362 = (($293) + 64|0);
           HEAPF32[$362>>2] = $361;
           $363 = (($293) + 92|0);
           HEAP32[$363>>2] = 0;
           $382 = $994;$566 = $311;$569 = $314;$572 = $317;$ccdShape0$0 = $293;$threshold0$0 = $321;
          }
          $381 = ($382|0)==(0|0);
          if ($381) {
           $383 = (__ZN5physx16PxsCCDBlockArrayINS_11PxsCCDShapeELi128EE8pushBackEv($115)|0);
           $384 = (($383) + 4|0);
           HEAP32[$384>>2] = $183;
           HEAP32[$383>>2] = $187;
           HEAP32[$1>>2] = $183;
           HEAP32[$134>>2] = $187;
           $385 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IPKNS_12PxsRigidCoreEPKNS_12PxsShapeCoreEEEPNS_11PxsCCDShapeEEESA_NS0_4HashISA_EENS1_11HashMapBaseISA_SD_SG_NS0_9AllocatorEE6GetKeyESI_Lb1EE6createERSB_Rb($117,$1,$exists$i25)|0);
           $386 = HEAP8[$exists$i25>>0]|0;
           $387 = ($386<<24>>24)!=(0);
           $388 = ($385|0)==(0|0);
           $or$cond$i26 = $387 | $388;
           if (!($or$cond$i26)) {
            $389 = HEAP32[$1>>2]|0;
            HEAP32[$385>>2] = $389;
            $390 = (($385) + 4|0);
            $391 = HEAP32[$134>>2]|0;
            HEAP32[$390>>2] = $391;
            $392 = (($385) + 8|0);
            HEAP32[$392>>2] = $383;
           }
           __ZNK5physx11PxsCCDShape10getAbsPoseEPKNS_12PxsRigidBodyE($tm1,$383,$190);
           $393 = ($190|0)==(0|0);
           if ($393) {
            $394 = Math_fround(HEAPF32[$tm1>>2]);
            HEAPF32[$oldTm1>>2] = $394;
            $395 = Math_fround(HEAPF32[$136>>2]);
            HEAPF32[$135>>2] = $395;
            $396 = Math_fround(HEAPF32[$138>>2]);
            HEAPF32[$137>>2] = $396;
            $397 = Math_fround(HEAPF32[$140>>2]);
            HEAPF32[$139>>2] = $397;
            $398 = Math_fround(HEAPF32[$142>>2]);
            HEAPF32[$141>>2] = $398;
            $399 = Math_fround(HEAPF32[$144>>2]);
            HEAPF32[$143>>2] = $399;
            $400 = Math_fround(HEAPF32[$146>>2]);
            HEAPF32[$145>>2] = $400;
            $402 = $398;$403 = $398;$405 = $399;$406 = $399;$408 = $400;$409 = $400;$429 = $394;$431 = $395;$433 = $396;$435 = $397;
           } else {
            __ZNK5physx11PxsCCDShape17getLastCCDAbsPoseEPKNS_12PxsRigidBodyE($oldTm1,$383,$190);
            $$pre144 = Math_fround(HEAPF32[$142>>2]);
            $$pre145 = Math_fround(HEAPF32[$141>>2]);
            $$pre146 = Math_fround(HEAPF32[$144>>2]);
            $$pre147 = Math_fround(HEAPF32[$143>>2]);
            $$pre148 = Math_fround(HEAPF32[$146>>2]);
            $$pre149 = Math_fround(HEAPF32[$145>>2]);
            $$pre150 = Math_fround(HEAPF32[$oldTm1>>2]);
            $$pre151 = Math_fround(HEAPF32[$135>>2]);
            $$pre152 = Math_fround(HEAPF32[$137>>2]);
            $$pre153 = Math_fround(HEAPF32[$139>>2]);
            $402 = $$pre145;$403 = $$pre144;$405 = $$pre147;$406 = $$pre146;$408 = $$pre149;$409 = $$pre148;$429 = $$pre150;$431 = $$pre151;$433 = $$pre152;$435 = $$pre153;
           }
           $401 = Math_fround($403 - $402);
           $404 = Math_fround($406 - $405);
           $407 = Math_fround($409 - $408);
           $410 = (($187) + 36|0);
           $411 = (Math_fround(__ZNK5physx2Gu13GeometryUnion29computeBoundsWithCCDThresholdERNS_6PxVec3ES3_RKNS_11PxTransformEPKNS_9PxBounds3E($410,$origin1,$extents2,$tm1,0)));
           $412 = Math_fround(HEAPF32[$origin1>>2]);
           $413 = Math_fround($412 - $401);
           $414 = Math_fround(HEAPF32[$147>>2]);
           $415 = Math_fround($414 - $404);
           $416 = Math_fround(HEAPF32[$148>>2]);
           $417 = Math_fround($416 - $407);
           $418 = (($383) + 80|0);
           HEAPF32[$418>>2] = $413;
           $419 = (($383) + 84|0);
           HEAPF32[$419>>2] = $415;
           $420 = (($383) + 88|0);
           HEAPF32[$420>>2] = $417;
           $421 = Math_fround(HEAPF32[$extents2>>2]);
           $422 = (($383) + 68|0);
           HEAPF32[$422>>2] = $421;
           $423 = Math_fround(HEAPF32[$149>>2]);
           $424 = (($383) + 72|0);
           HEAPF32[$424>>2] = $423;
           $425 = Math_fround(HEAPF32[$150>>2]);
           $426 = (($383) + 76|0);
           HEAPF32[$426>>2] = $425;
           $427 = (($383) + 8|0);
           HEAPF32[$427>>2] = $411;
           $428 = (($383) + 12|0);
           HEAPF32[$428>>2] = $429;
           $430 = (($383) + 16|0);
           HEAPF32[$430>>2] = $431;
           $432 = (($383) + 20|0);
           HEAPF32[$432>>2] = $433;
           $434 = (($383) + 24|0);
           HEAPF32[$434>>2] = $435;
           $436 = (($383) + 28|0);
           HEAPF32[$436>>2] = $402;
           $437 = (($383) + 32|0);
           HEAPF32[$437>>2] = $405;
           $438 = (($383) + 36|0);
           HEAPF32[$438>>2] = $408;
           $439 = Math_fround(HEAPF32[$tm1>>2]);
           $440 = (($383) + 40|0);
           HEAPF32[$440>>2] = $439;
           $441 = Math_fround(HEAPF32[$136>>2]);
           $442 = (($383) + 44|0);
           HEAPF32[$442>>2] = $441;
           $443 = Math_fround(HEAPF32[$138>>2]);
           $444 = (($383) + 48|0);
           HEAPF32[$444>>2] = $443;
           $445 = Math_fround(HEAPF32[$140>>2]);
           $446 = (($383) + 52|0);
           HEAPF32[$446>>2] = $445;
           $447 = Math_fround(HEAPF32[$142>>2]);
           $448 = (($383) + 56|0);
           HEAPF32[$448>>2] = $447;
           $449 = Math_fround(HEAPF32[$144>>2]);
           $450 = (($383) + 60|0);
           HEAPF32[$450>>2] = $449;
           $451 = Math_fround(HEAPF32[$146>>2]);
           $452 = (($383) + 64|0);
           HEAPF32[$452>>2] = $451;
           $453 = (($383) + 92|0);
           HEAP32[$453>>2] = 0;
           $565 = $401;$568 = $404;$571 = $407;$ccdShape1$0 = $383;$threshold1$0 = $411;
          } else {
           $454 = (($382) + 8|0);
           $455 = Math_fround(HEAPF32[$454>>2]);
           $456 = (($382) + 56|0);
           $457 = Math_fround(HEAPF32[$456>>2]);
           $458 = (($382) + 28|0);
           $459 = Math_fround(HEAPF32[$458>>2]);
           $460 = Math_fround($457 - $459);
           $461 = (($382) + 60|0);
           $462 = Math_fround(HEAPF32[$461>>2]);
           $463 = (($382) + 32|0);
           $464 = Math_fround(HEAPF32[$463>>2]);
           $465 = Math_fround($462 - $464);
           $466 = (($382) + 64|0);
           $467 = Math_fround(HEAPF32[$466>>2]);
           $468 = (($382) + 36|0);
           $469 = Math_fround(HEAPF32[$468>>2]);
           $470 = Math_fround($467 - $469);
           $565 = $460;$568 = $465;$571 = $470;$ccdShape1$0 = $382;$threshold1$0 = $455;
          }
          $471 = ($188|0)==(0|0);
          if (!($471)) {
           $472 = (($188) + 60|0);
           $473 = HEAP32[$472>>2]|0;
           $474 = ($473|0)==(0|0);
           if ($474) {
            $475 = (__ZN5physx16PxsCCDBlockArrayINS_10PxsCCDBodyELi128EE8pushBackEv($151)|0);
            HEAP32[$472>>2] = $475;
            $476 = HEAP32[$152>>2]|0;
            $477 = $476 << 7;
            $478 = HEAP32[$151>>2]|0;
            $479 = ((($478) + ($476<<3)|0) + 4|0);
            $480 = HEAP32[$479>>2]|0;
            $481 = (($477) + 65535)|0;
            $482 = (($481) + ($480))|0;
            $483 = $482&65535;
            HEAP16[$475>>1] = $483;
            $484 = (($475) + 8|0);
            HEAP32[$484>>2] = $188;
            $485 = HEAP32[$472>>2]|0;
            $486 = (($485) + 4|0);
            HEAPF32[$486>>2] = Math_fround(1.0);
            $487 = (($485) + 12|0);
            HEAP32[$487>>2] = 0;
            $488 = HEAP32[$472>>2]|0;
            $489 = (($488) + 16|0);
            HEAP32[$489>>2] = 0;
            $491 = $488;
           } else {
            $491 = $473;
           }
           $490 = (($491) + 2|0);
           HEAP16[$490>>1] = 0;
          }
          $492 = ($190|0)==(0|0);
          L87: do {
           if (!($492)) {
            $972 = (($190) + 60|0);
            $973 = HEAP32[$972>>2]|0;
            $974 = ($973|0)==(0|0);
            if ($974) {
             $975 = (__ZN5physx16PxsCCDBlockArrayINS_10PxsCCDBodyELi128EE8pushBackEv($151)|0);
             HEAP32[$972>>2] = $975;
             $976 = HEAP32[$152>>2]|0;
             $977 = $976 << 7;
             $978 = HEAP32[$151>>2]|0;
             $979 = ((($978) + ($976<<3)|0) + 4|0);
             $980 = HEAP32[$979>>2]|0;
             $981 = (($977) + 65535)|0;
             $982 = (($981) + ($980))|0;
             $983 = $982&65535;
             HEAP16[$975>>1] = $983;
             $984 = (($975) + 8|0);
             HEAP32[$984>>2] = $190;
             $985 = HEAP32[$972>>2]|0;
             $986 = (($985) + 4|0);
             HEAPF32[$986>>2] = Math_fround(1.0);
             $987 = (($985) + 12|0);
             HEAP32[$987>>2] = 0;
             $988 = HEAP32[$972>>2]|0;
             $989 = (($988) + 16|0);
             HEAP32[$989>>2] = 0;
             $991 = $988;
            } else {
             $991 = $973;
            }
            $990 = (($991) + 2|0);
            HEAP16[$990>>1] = 0;
            $or$cond5 = $471 | $492;
            if ($or$cond5) {
             break;
            }
            $493 = (($188) + 64|0);
            $494 = HEAP32[$493>>2]|0;
            $495 = (($494) + 124|0);
            $496 = Math_fround(HEAPF32[$495>>2]);
            $497 = $496 == Math_fround(0.0);
            if ($497) {
             break;
            }
            $498 = (($190) + 64|0);
            $499 = HEAP32[$498>>2]|0;
            $500 = (($499) + 124|0);
            $501 = Math_fround(HEAPF32[$500>>2]);
            $502 = $501 == Math_fround(0.0);
            if ($502) {
             break;
            }
            $503 = (($188) + 60|0);
            $504 = HEAP32[$503>>2]|0;
            $505 = (($190) + 60|0);
            $506 = HEAP32[$505>>2]|0;
            $507 = (($504) + 12|0);
            $overlaps$01$i = HEAP32[$507>>2]|0;
            $508 = ($overlaps$01$i|0)==(0|0);
            if (!($508)) {
             $overlaps$02$i = $overlaps$01$i;
             while(1) {
              $511 = HEAP32[$overlaps$02$i>>2]|0;
              $512 = ($511|0)==($506|0);
              if ($512) {
               break L87;
              }
              $509 = (($overlaps$02$i) + 4|0);
              $overlaps$0$i = HEAP32[$509>>2]|0;
              $510 = ($overlaps$0$i|0)==(0|0);
              if ($510) {
               break;
              } else {
               $overlaps$02$i = $overlaps$0$i;
              }
             }
            }
            $513 = (__ZN5physx16PxsCCDBlockArrayINS_13PxsCCDOverlapELi128EE8pushBackEv($62)|0);
            $514 = (__ZN5physx16PxsCCDBlockArrayINS_13PxsCCDOverlapELi128EE8pushBackEv($62)|0);
            $515 = HEAP32[$505>>2]|0;
            HEAP32[$513>>2] = $515;
            $516 = HEAP32[$503>>2]|0;
            HEAP32[$514>>2] = $516;
            $517 = HEAP32[$503>>2]|0;
            $518 = (($517) + 12|0);
            $519 = HEAP32[$518>>2]|0;
            $520 = (($513) + 4|0);
            HEAP32[$520>>2] = $519;
            HEAP32[$518>>2] = $513;
            $521 = HEAP32[$505>>2]|0;
            $522 = (($521) + 12|0);
            $523 = HEAP32[$522>>2]|0;
            $524 = (($514) + 4|0);
            HEAP32[$524>>2] = $523;
            HEAP32[$522>>2] = $514;
           }
          } while(0);
          $525 = (__ZN5physx16PxsCCDBlockArrayINS_10PxsCCDPairELi128EE8pushBackEv($56)|0);
          HEAP32[$525>>2] = $188;
          $526 = (($525) + 4|0);
          HEAP32[$526>>2] = $190;
          $527 = (($525) + 8|0);
          HEAP32[$527>>2] = $ccdShape0$0;
          $528 = (($525) + 12|0);
          HEAP32[$528>>2] = $ccdShape1$0;
          $529 = (($181) + 28|0);
          $530 = HEAP8[$529>>0]|0;
          $531 = $530 & 8;
          $532 = ($531<<24>>24)==(0);
          if ($532) {
           $533 = (($183) + 28|0);
           $534 = HEAP8[$533>>0]|0;
           $535 = ($534&255) >>> 3;
           $$lobit = $535 & 1;
           $537 = $$lobit;
          } else {
           $537 = 1;
          }
          $536 = (($525) + 104|0);
          HEAP8[$536>>0] = $537;
          $538 = (($525) + 28|0);
          HEAPF32[$538>>2] = Math_fround(3.40282346638528859812E+38);
          $539 = ((($166) + ($170<<7)|0) + 112|0);
          $540 = HEAP8[$539>>0]|0;
          $541 = $540&255;
          $542 = (($525) + 60|0);
          HEAP32[$542>>2] = $541;
          $543 = ((($166) + ($170<<7)|0) + 113|0);
          $544 = HEAP8[$543>>0]|0;
          $545 = $544&255;
          $546 = (($525) + 64|0);
          HEAP32[$546>>2] = $545;
          $547 = (($525) + 52|0);
          HEAP32[$547>>2] = $171;
          $548 = (($525) + 56|0);
          HEAP32[$548>>2] = -1;
          $549 = (($525) + 68|0);
          HEAP8[$549>>0] = 0;
          $550 = (($525) + 72|0);
          HEAP32[$550>>2] = -1;
          $551 = HEAP32[$172>>2]|0;
          $552 = $551 & 1;
          $553 = (($525) + 69|0);
          $554 = $552&255;
          HEAP8[$553>>0] = $554;
          $555 = (($525) + 96|0);
          HEAPF32[$555>>2] = Math_fround(0.0);
          $556 = ($540&255)<($544&255);
          $557 = $556 ? $545 : $541;
          $558 = $556 ? $541 : $545;
          $559 = HEAP32[$8>>2]|0;
          $560 = (((($559) + (($558*28)|0)|0) + ($557<<2)|0) + 6948|0);
          $561 = HEAP32[$560>>2]|0;
          $562 = (($561) + 1)|0;
          HEAP32[$560>>2] = $562;
          $563 = Math_fround($threshold0$0 + $threshold1$0);
          if ($needsSweep$0$off0101) {
           $993 = $559;$needsSweep$1$off0 = 1;
          } else {
           $564 = Math_fround($566 - $565);
           $567 = Math_fround($569 - $568);
           $570 = Math_fround($572 - $571);
           $573 = Math_fround($564 * $564);
           $574 = Math_fround($567 * $567);
           $575 = Math_fround($574 + $573);
           $576 = Math_fround($570 * $570);
           $577 = Math_fround($576 + $575);
           $578 = Math_fround($563 * $563);
           $579 = $577 >= $578;
           $993 = $559;$needsSweep$1$off0 = $579;
          }
         }
        }
        $580 = ($581|0)==(0);
        if ($580) {
         label = 73;
         break L26;
        }
        $583 = (0 - ($581))|0;
        $584 = $581 & $583;
        $585 = Math_imul($584, 125613361)|0;
        $586 = $585 >>> 27;
        $587 = (412480 + ($586<<2)|0);
        $588 = HEAP32[$587>>2]|0;
        $157 = $588 | $158;
        $589 = (($581) + -1)|0;
        $590 = $589 & $581;
        $591 = HEAP32[$86>>2]|0;
        $592 = $591 & 2147483647;
        $593 = ($590|0)==(0);
        if ($593) {
         $595 = $$ph94113;
         break;
        }
        $582 = ($157|0)==(-1);
        if ($582) {
         label = 78;
         break L26;
        } else {
         $160 = $993;$581 = $590;$index$0100 = $157;$needsSweep$0$off0101 = $needsSweep$1$off0;
        }
       }
       while(1) {
        $594 = (($595) + 1)|0;
        $596 = ($594>>>0)<($592>>>0);
        if (!($596)) {
         $$ph = 0;
         break;
        }
        $597 = HEAP32[$84>>2]|0;
        $598 = (($597) + ($594<<2)|0);
        $599 = HEAP32[$598>>2]|0;
        $600 = ($599|0)==(0);
        if ($600) {
         $595 = $594;
        } else {
         $$ph = $599;
         break;
        }
       }
       $156 = ($157|0)==(-1);
       if ($156) {
        label = 78;
        break;
       } else {
        $$ph94113 = $594;$$ph95114 = $$ph;$992 = $993;$index$0$ph96115 = $157;$needsSweep$0$off0$ph116 = $needsSweep$1$off0;
       }
      }
      if ((label|0) == 73) {
       if (!($needsSweep$1$off0)) {
        break;
       }
      }
      else if ((label|0) == 78) {
       if (!($needsSweep$1$off0)) {
        break;
       }
      }
      if (!($or$cond$i$i$i)) {
       $609 = HEAP32[$70>>2]|0;
       $610 = (($609) + 12|0);
       $611 = HEAP32[$610>>2]|0;
       $612 = $77&65535;
       FUNCTION_TABLE_viiii[$611 & 511]($70,$612,$73,$76);
      }
      $613 = HEAP32[$57>>2]|0;
      $614 = $613 << 7;
      $615 = HEAP32[$56>>2]|0;
      $616 = ((($615) + ($613<<3)|0) + 4|0);
      $617 = HEAP32[$616>>2]|0;
      $618 = (($617) + ($614))|0;
      $619 = (($this) + 236|0);
      $620 = HEAP32[$619>>2]|0;
      $621 = $620 & 2147483647;
      $622 = ($621>>>0)<($618>>>0);
      if ($622) {
       __ZN5physx6shdfnd5ArrayIPNS_10PxsCCDPairENS0_19ReflectionAllocatorIS3_EEE8recreateEj($60,$618);
      }
      $623 = ($618|0)==(0);
      if (!($623)) {
       $624 = $613 << 7;
       $625 = (($617) + ($624))|0;
       $a$086 = 0;
       while(1) {
        $626 = $a$086 & 127;
        $627 = $a$086 >>> 7;
        $628 = HEAP32[$56>>2]|0;
        $629 = (($628) + ($627<<3)|0);
        $630 = HEAP32[$629>>2]|0;
        $631 = (($630) + (($626*108)|0)|0);
        HEAP32[$2>>2] = $631;
        $632 = HEAP32[$619>>2]|0;
        $633 = $632 & 2147483647;
        $634 = HEAP32[$61>>2]|0;
        $635 = ($633>>>0)>($634>>>0);
        if ($635) {
         $636 = HEAP32[$60>>2]|0;
         $637 = (($636) + ($634<<2)|0);
         $638 = ($637|0)==(0|0);
         if (!($638)) {
          HEAP32[$637>>2] = $631;
         }
         $639 = (($634) + 1)|0;
         HEAP32[$61>>2] = $639;
        } else {
         (__ZN5physx6shdfnd5ArrayIPNS_10PxsCCDPairENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($60,$2)|0);
        }
        $640 = (($a$086) + 1)|0;
        $exitcond120 = ($640|0)==($625|0);
        if ($exitcond120) {
         break;
        } else {
         $a$086 = $640;
        }
       }
      }
      $641 = $618 >>> 1;
      $642 = $641 | $618;
      $643 = $642 >>> 2;
      $644 = $643 | $642;
      $645 = $644 >>> 4;
      $646 = $645 | $644;
      $647 = $646 >>> 8;
      $648 = $647 | $646;
      $649 = $648 >>> 16;
      $650 = $649 | $648;
      $651 = (($650) + 1)|0;
      $652 = (($9) + 5876|0);
      $653 = HEAP32[$652>>2]|0;
      $654 = $653 & 2147483647;
      $655 = ($654>>>0)<($651>>>0);
      if ($655) {
       __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE8recreateEj($10,$651);
      }
      $656 = (($this) + 112|0);
      $657 = HEAP32[$656>>2]|0;
      $658 = $657 << 7;
      $659 = (($this) + 100|0);
      $660 = HEAP32[$659>>2]|0;
      $661 = ((($660) + ($657<<3)|0) + 4|0);
      $662 = HEAP32[$661>>2]|0;
      $663 = (($662) + ($658))|0;
      HEAP32[$islandLabels>>2] = 0;
      $664 = (($islandLabels) + 4|0);
      HEAP32[$664>>2] = 0;
      $665 = (($islandLabels) + 8|0);
      HEAP32[$665>>2] = 0;
      HEAP16[$3>>1] = 0;
      __ZN5physx6shdfnd5ArrayItNS0_19ReflectionAllocatorItEEE6resizeEjRKt($islandLabels,$663,$3);
      HEAP32[$stack>>2] = 0;
      $666 = (($stack) + 4|0);
      HEAP32[$666>>2] = 0;
      $667 = (($stack) + 8|0);
      HEAP32[$667>>2] = 0;
      $668 = ($663|0)==(0);
      if (!($668)) {
       __ZN5physx6shdfnd5ArrayIPKNS_10PxsCCDBodyENS0_19ReflectionAllocatorIS4_EEE8recreateEj($stack,$663);
      }
      HEAP32[$666>>2] = $663;
      $669 = (($this) + 160|0);
      $670 = (($this) + 164|0);
      HEAP32[$670>>2] = 0;
      $671 = (($663) + 1)|0;
      $672 = (($this) + 168|0);
      $673 = HEAP32[$672>>2]|0;
      $674 = $673 & 2147483647;
      $675 = ($674>>>0)<($671>>>0);
      if ($675) {
       __ZN5physx6shdfnd5ArrayItNS0_19ReflectionAllocatorItEEE8recreateEj($669,$671);
      }
      HEAP32[$670>>2] = $671;
      if ($668) {
       $islandCount$0$lcssa = 0;
      } else {
       $676 = HEAP32[$islandLabels>>2]|0;
       $677 = $657 << 7;
       $678 = (($662) + ($677))|0;
       $679 = $678 << 1;
       _memset(($676|0),-1,($679|0))|0;
       $680 = $657 << 7;
       $681 = (($662) + ($680))|0;
       $$pre133 = HEAP32[$islandLabels>>2]|0;
       $islandCount$080 = 0;$j3$079 = 0;
       while(1) {
        $682 = (($$pre133) + ($j3$079<<1)|0);
        $683 = HEAP16[$682>>1]|0;
        $684 = ($683<<16>>16)==(-1);
        if ($684) {
         $685 = $j3$079 & 127;
         $686 = $j3$079 >>> 7;
         $687 = HEAP32[$659>>2]|0;
         $688 = (($687) + ($686<<3)|0);
         $689 = HEAP32[$688>>2]|0;
         $690 = (($689) + (($685*20)|0)|0);
         HEAP16[$682>>1] = $islandCount$080;
         $691 = HEAP32[$stack>>2]|0;
         HEAP32[$691>>2] = $690;
         $islandSize$075 = 0;$stackSize$177 = 1;$top$076 = $690;
         while(1) {
          $693 = (($stackSize$177) + -1)|0;
          $694 = ($693>>>0)>(1);
          $$op = (($stackSize$177) + -2)|0;
          $695 = $694 ? $$op : 0;
          $696 = (($691) + ($695<<2)|0);
          $697 = HEAP32[$696>>2]|0;
          $698 = (($top$076) + 12|0);
          $overlaps$066 = HEAP32[$698>>2]|0;
          $699 = ($overlaps$066|0)==(0|0);
          if ($699) {
           $islandSize$1$lcssa = $islandSize$075;$stackSize$2$lcssa = $693;$top$1$lcssa = $697;
          } else {
           $islandSize$167 = $islandSize$075;$overlaps$070 = $overlaps$066;$stackSize$269 = $693;$top$168 = $697;
           while(1) {
            $700 = HEAP32[$overlaps$070>>2]|0;
            $701 = HEAP16[$700>>1]|0;
            $702 = $701&65535;
            $703 = (($$pre133) + ($702<<1)|0);
            $704 = HEAP16[$703>>1]|0;
            $705 = ($704<<16>>16)==(-1);
            if ($705) {
             HEAP16[$703>>1] = $islandCount$080;
             $706 = (($stackSize$269) + 1)|0;
             $707 = (($691) + ($stackSize$269<<2)|0);
             HEAP32[$707>>2] = $700;
             $708 = HEAP32[$overlaps$070>>2]|0;
             $709 = (($islandSize$167) + 1)<<16>>16;
             $islandSize$2 = $709;$stackSize$3 = $706;$top$2 = $708;
            } else {
             $islandSize$2 = $islandSize$167;$stackSize$3 = $stackSize$269;$top$2 = $top$168;
            }
            $710 = (($overlaps$070) + 4|0);
            $overlaps$0 = HEAP32[$710>>2]|0;
            $711 = ($overlaps$0|0)==(0|0);
            if ($711) {
             $islandSize$1$lcssa = $islandSize$2;$stackSize$2$lcssa = $stackSize$3;$top$1$lcssa = $top$2;
             break;
            } else {
             $islandSize$167 = $islandSize$2;$overlaps$070 = $overlaps$0;$stackSize$269 = $stackSize$3;$top$168 = $top$2;
            }
           }
          }
          $692 = ($stackSize$2$lcssa|0)==(0);
          if ($692) {
           break;
          } else {
           $islandSize$075 = $islandSize$1$lcssa;$stackSize$177 = $stackSize$2$lcssa;$top$076 = $top$1$lcssa;
          }
         }
         $712 = $islandSize$1$lcssa&65535;
         $713 = (($712) + 1)|0;
         $714 = $713&65535;
         $715 = $islandCount$080&65535;
         $716 = HEAP32[$669>>2]|0;
         $717 = (($716) + ($715<<1)|0);
         HEAP16[$717>>1] = $714;
         $718 = (($islandCount$080) + 1)<<16>>16;
         $islandCount$1 = $718;
        } else {
         $islandCount$1 = $islandCount$080;
        }
        $719 = (($j3$079) + 1)|0;
        $exitcond118 = ($719|0)==($681|0);
        if ($exitcond118) {
         $islandCount$0$lcssa = $islandCount$1;
         break;
        } else {
         $islandCount$080 = $islandCount$1;$j3$079 = $719;
        }
       }
      }
      $720 = (($this) + 240|0);
      $721 = (($this) + 244|0);
      HEAP32[$721>>2] = 0;
      $722 = $islandCount$0$lcssa&65535;
      HEAP32[$4>>2] = 0;
      __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($720,$722,$4);
      $723 = HEAP32[$61>>2]|0;
      $724 = ($723|0)==(0);
      if (!($724)) {
       $725 = HEAP32[$60>>2]|0;
       $726 = HEAP32[$720>>2]|0;
       $727 = HEAP32[$islandLabels>>2]|0;
       $j4$063 = 0;
       while(1) {
        $730 = (($725) + ($j4$063<<2)|0);
        $731 = HEAP32[$730>>2]|0;
        $732 = HEAP32[$731>>2]|0;
        $733 = ($732|0)==(0|0);
        do {
         if ($733) {
          $762 = -1;
         } else {
          $734 = (($732) + 64|0);
          $735 = HEAP32[$734>>2]|0;
          $736 = (($735) + 124|0);
          $737 = Math_fround(HEAPF32[$736>>2]);
          $738 = $737 == Math_fround(0.0);
          if ($738) {
           $762 = -1;
           break;
          }
          $739 = (($732) + 60|0);
          $740 = HEAP32[$739>>2]|0;
          $741 = HEAP16[$740>>1]|0;
          $742 = $741&65535;
          $743 = (($727) + ($742<<1)|0);
          $744 = HEAP16[$743>>1]|0;
          $745 = $744&65535;
          $762 = $745;
         }
        } while(0);
        $746 = (($731) + 4|0);
        $747 = HEAP32[$746>>2]|0;
        $748 = ($747|0)==(0|0);
        do {
         if ($748) {
          $763 = -1;
         } else {
          $749 = (($747) + 64|0);
          $750 = HEAP32[$749>>2]|0;
          $751 = (($750) + 124|0);
          $752 = Math_fround(HEAPF32[$751>>2]);
          $753 = $752 == Math_fround(0.0);
          if ($753) {
           $763 = -1;
           break;
          }
          $754 = (($747) + 60|0);
          $755 = HEAP32[$754>>2]|0;
          $756 = HEAP16[$755>>1]|0;
          $757 = $756&65535;
          $758 = (($727) + ($757<<1)|0);
          $759 = HEAP16[$758>>1]|0;
          $760 = $759&65535;
          $763 = $760;
         }
        } while(0);
        $761 = ($762>>>0)<($763>>>0);
        $764 = $761 ? $762 : $763;
        $765 = (($731) + 56|0);
        HEAP32[$765>>2] = $764;
        $766 = (($726) + ($764<<2)|0);
        $767 = HEAP32[$766>>2]|0;
        $768 = (($767) + 1)|0;
        HEAP32[$766>>2] = $768;
        $769 = (($j4$063) + 1)|0;
        $exitcond = ($769|0)==($723|0);
        if ($exitcond) {
         break;
        } else {
         $j4$063 = $769;
        }
       }
      }
      $728 = (($722) + 1)|0;
      $729 = HEAP32[$669>>2]|0;
      $771 = 0;$a6$062 = 0;$count$061 = 0;
      while(1) {
       $770 = (($729) + ($771<<1)|0);
       $772 = HEAP16[$770>>1]|0;
       HEAP16[$770>>1] = $count$061;
       $773 = $772&65535;
       $774 = $count$061&65535;
       $775 = (($773) + ($774))|0;
       $776 = $775&65535;
       $777 = (($a6$062) + 1)<<16>>16;
       $778 = $777&65535;
       $779 = ($778>>>0)<($728>>>0);
       if ($779) {
        $771 = $778;$a6$062 = $777;$count$061 = $776;
       } else {
        break;
       }
      }
      $780 = (($this) + 148|0);
      $781 = (($this) + 152|0);
      HEAP32[$781>>2] = 0;
      $782 = (($this) + 156|0);
      $783 = HEAP32[$782>>2]|0;
      $784 = $783 & 2147483647;
      $785 = ($784>>>0)<($663>>>0);
      if ($785) {
       __ZN5physx6shdfnd5ArrayIPNS_10PxsCCDBodyENS0_19ReflectionAllocatorIS3_EEE8recreateEj($780,$663);
      }
      HEAP32[$781>>2] = $663;
      $786 = HEAP32[$656>>2]|0;
      $787 = $786 << 7;
      $788 = HEAP32[$659>>2]|0;
      $789 = ((($788) + ($786<<3)|0) + 4|0);
      $790 = HEAP32[$789>>2]|0;
      $791 = (0 - ($787))|0;
      $792 = ($790|0)==($791|0);
      if (!($792)) {
       $793 = HEAP32[$islandLabels>>2]|0;
       $797 = $788;$a8$058 = 0;
       while(1) {
        $794 = $a8$058 & 127;
        $795 = $a8$058 >>> 7;
        $796 = (($797) + ($795<<3)|0);
        $798 = HEAP32[$796>>2]|0;
        $799 = (($798) + (($794*20)|0)|0);
        $800 = HEAP16[$799>>1]|0;
        $801 = $800&65535;
        $802 = (($793) + ($801<<1)|0);
        $803 = HEAP16[$802>>1]|0;
        $804 = $803&65535;
        $805 = HEAP32[$669>>2]|0;
        $806 = (($805) + ($804<<1)|0);
        $807 = HEAP16[$806>>1]|0;
        $808 = $807&65535;
        $809 = (($808) + 1)|0;
        $810 = $809&65535;
        HEAP16[$806>>1] = $810;
        $811 = (($798) + (($794*20)|0)|0);
        $812 = HEAP32[$780>>2]|0;
        $813 = (($812) + ($808<<2)|0);
        HEAP32[$813>>2] = $811;
        $814 = (($a8$058) + 1)|0;
        $815 = HEAP32[$659>>2]|0;
        $816 = ((($815) + ($786<<3)|0) + 4|0);
        $817 = HEAP32[$816>>2]|0;
        $818 = (($817) + ($787))|0;
        $819 = ($814>>>0)<($818>>>0);
        if ($819) {
         $797 = $815;$a8$058 = $814;
        } else {
         break;
        }
       }
      }
      $820 = (($this) + 56|0);
      $821 = (($this) + 72|0);
      HEAP32[$821>>2] = 1;
      $822 = (($this) + 68|0);
      HEAP32[$822>>2] = $continuation;
      $823 = ($continuation|0)==(0|0);
      if (!($823)) {
       $824 = HEAP32[$continuation>>2]|0;
       $825 = (($824) + 16|0);
       $826 = HEAP32[$825>>2]|0;
       FUNCTION_TABLE_vi[$826 & 4095]($continuation);
       $827 = HEAP32[$822>>2]|0;
       $828 = (($827) + 8|0);
       $829 = HEAP32[$828>>2]|0;
       $830 = (($this) + 64|0);
       HEAP32[$830>>2] = $829;
      }
      $831 = (($this) + 28|0);
      $832 = (($this) + 44|0);
      HEAP32[$832>>2] = 1;
      $833 = (($this) + 40|0);
      HEAP32[$833>>2] = $820;
      $834 = HEAP32[$820>>2]|0;
      $835 = (($834) + 16|0);
      $836 = HEAP32[$835>>2]|0;
      FUNCTION_TABLE_vi[$836 & 4095]($820);
      $837 = HEAP32[$833>>2]|0;
      $838 = (($837) + 8|0);
      $839 = HEAP32[$838>>2]|0;
      $840 = (($this) + 36|0);
      HEAP32[$840>>2] = $839;
      $841 = (($this) + 16|0);
      HEAP32[$841>>2] = 1;
      $842 = (($this) + 12|0);
      HEAP32[$842>>2] = $831;
      $843 = HEAP32[$831>>2]|0;
      $844 = (($843) + 16|0);
      $845 = HEAP32[$844>>2]|0;
      FUNCTION_TABLE_vi[$845 & 4095]($831);
      $846 = HEAP32[$842>>2]|0;
      $847 = (($846) + 8|0);
      $848 = HEAP32[$847>>2]|0;
      $849 = (($this) + 8|0);
      HEAP32[$849>>2] = $848;
      $850 = HEAP32[$60>>2]|0;
      $851 = HEAP32[$61>>2]|0;
      __ZN5physx6shdfnd4sortIPNS_10PxsCCDPairENS_16IslandPtrCompareENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($850,$851,$5,$exists$i25);
      $852 = HEAP32[$61>>2]|0;
      $853 = HEAP32[$8>>2]|0;
      $854 = (($853) + 6728|0);
      $855 = HEAP32[$854>>2]|0;
      $856 = HEAP32[$855>>2]|0;
      $857 = (($856) + 16|0);
      $858 = HEAP32[$857>>2]|0;
      $859 = (FUNCTION_TABLE_ii[$858 & 4095]($855)|0);
      $860 = HEAP32[$859>>2]|0;
      $861 = (($860) + 4|0);
      $862 = HEAP32[$861>>2]|0;
      $863 = (FUNCTION_TABLE_ii[$862 & 4095]($859)|0);
      $864 = ($863>>>0)>(1);
      $865 = $864 ? $863 : 1;
      $866 = (($852>>>0) / ($865>>>0))&-1;
      $867 = ($866|0)==(0);
      $868 = $867 ? 1 : $866;
      $869 = (($this) + 256|0);
      HEAP32[$869>>2] = $868;
      $870 = ($852|0)==(0);
      if (!($870)) {
       $871 = ($this|0)==(0|0);
       if ($871) {
        $batchBegin$057$us = 0;
        while(1) {
         $872 = HEAP32[$8>>2]|0;
         $873 = (($872) + 6732|0);
         $874 = HEAP32[$873>>2]|0;
         $875 = HEAP32[$874>>2]|0;
         __ZN5physx6shdfnd9MutexImpl4lockEv($875);
         $876 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($874,28,16)|0);
         $877 = HEAP32[$874>>2]|0;
         __ZN5physx6shdfnd9MutexImpl6unlockEv($877);
         $878 = HEAP32[$869>>2]|0;
         $879 = (($878) + ($batchBegin$057$us))|0;
         $880 = ($876|0)==(0|0);
         if ($880) {
          $897 = 0;
         } else {
          $881 = ($852>>>0)<($879>>>0);
          $882 = $881 ? $852 : $879;
          $883 = HEAP32[$60>>2]|0;
          $884 = (($883) + ($batchBegin$057$us<<2)|0);
          $885 = (($882) - ($batchBegin$057$us))|0;
          $886 = (($876) + 4|0);
          HEAP16[$886>>1] = -1;
          $887 = (($876) + 6|0);
          HEAP16[$887>>1] = 0;
          $888 = (($876) + 8|0);
          HEAP32[$888>>2] = 0;
          HEAP32[$876>>2] = ((434896 + 8|0));
          $889 = (($876) + 12|0);
          HEAP32[$889>>2] = 0;
          $890 = (($876) + 16|0);
          HEAP32[$890>>2] = 0;
          HEAP32[$876>>2] = ((488168 + 8|0));
          $891 = (($876) + 20|0);
          HEAP32[$891>>2] = $884;
          $892 = (($876) + 24|0);
          HEAP32[$892>>2] = $885;
          $897 = $876;
         }
         $893 = HEAP32[$8>>2]|0;
         $894 = (($893) + 6728|0);
         $895 = HEAP32[$894>>2]|0;
         $896 = (($897) + 16|0);
         HEAP32[$896>>2] = 1;
         $898 = (($897) + 12|0);
         HEAP32[$898>>2] = $this;
         $899 = (($897) + 8|0);
         HEAP32[$899>>2] = $895;
         $900 = HEAP32[$897>>2]|0;
         $901 = (($900) + 20|0);
         $902 = HEAP32[$901>>2]|0;
         FUNCTION_TABLE_vi[$902 & 4095]($897);
         $903 = HEAP32[$869>>2]|0;
         $904 = (($903) + ($batchBegin$057$us))|0;
         $905 = ($904>>>0)<($852>>>0);
         if ($905) {
          $batchBegin$057$us = $904;
         } else {
          break;
         }
        }
       } else {
        $batchBegin$057 = 0;
        while(1) {
         $906 = HEAP32[$8>>2]|0;
         $907 = (($906) + 6732|0);
         $908 = HEAP32[$907>>2]|0;
         $909 = HEAP32[$908>>2]|0;
         __ZN5physx6shdfnd9MutexImpl4lockEv($909);
         $910 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($908,28,16)|0);
         $911 = HEAP32[$908>>2]|0;
         __ZN5physx6shdfnd9MutexImpl6unlockEv($911);
         $912 = HEAP32[$869>>2]|0;
         $913 = (($912) + ($batchBegin$057))|0;
         $914 = ($910|0)==(0|0);
         if ($914) {
          $931 = 0;
         } else {
          $915 = ($852>>>0)<($913>>>0);
          $916 = $915 ? $852 : $913;
          $917 = HEAP32[$60>>2]|0;
          $918 = (($917) + ($batchBegin$057<<2)|0);
          $919 = (($916) - ($batchBegin$057))|0;
          $920 = (($910) + 4|0);
          HEAP16[$920>>1] = -1;
          $921 = (($910) + 6|0);
          HEAP16[$921>>1] = 0;
          $922 = (($910) + 8|0);
          HEAP32[$922>>2] = 0;
          HEAP32[$910>>2] = ((434896 + 8|0));
          $923 = (($910) + 12|0);
          HEAP32[$923>>2] = 0;
          $924 = (($910) + 16|0);
          HEAP32[$924>>2] = 0;
          HEAP32[$910>>2] = ((488168 + 8|0));
          $925 = (($910) + 20|0);
          HEAP32[$925>>2] = $918;
          $926 = (($910) + 24|0);
          HEAP32[$926>>2] = $919;
          $931 = $910;
         }
         $927 = HEAP32[$8>>2]|0;
         $928 = (($927) + 6728|0);
         $929 = HEAP32[$928>>2]|0;
         $930 = (($931) + 16|0);
         HEAP32[$930>>2] = 1;
         $932 = (($931) + 12|0);
         HEAP32[$932>>2] = $this;
         $933 = (($931) + 8|0);
         HEAP32[$933>>2] = $929;
         $934 = HEAP32[$this>>2]|0;
         $935 = (($934) + 16|0);
         $936 = HEAP32[$935>>2]|0;
         FUNCTION_TABLE_vi[$936 & 4095]($this);
         $937 = HEAP32[$931>>2]|0;
         $938 = (($937) + 20|0);
         $939 = HEAP32[$938>>2]|0;
         FUNCTION_TABLE_vi[$939 & 4095]($931);
         $940 = HEAP32[$869>>2]|0;
         $941 = (($940) + ($batchBegin$057))|0;
         $942 = ($941>>>0)<($852>>>0);
         if ($942) {
          $batchBegin$057 = $941;
         } else {
          break;
         }
        }
       }
      }
      $943 = HEAP32[$this>>2]|0;
      $944 = (($943) + 20|0);
      $945 = HEAP32[$944>>2]|0;
      FUNCTION_TABLE_vi[$945 & 4095]($this);
      $946 = HEAP32[$831>>2]|0;
      $947 = (($946) + 20|0);
      $948 = HEAP32[$947>>2]|0;
      FUNCTION_TABLE_vi[$948 & 4095]($831);
      $949 = HEAP32[$820>>2]|0;
      $950 = (($949) + 20|0);
      $951 = HEAP32[$950>>2]|0;
      FUNCTION_TABLE_vi[$951 & 4095]($820);
      $952 = HEAP32[$667>>2]|0;
      $953 = $952 & 2147483647;
      $954 = ($953|0)!=(0);
      $955 = ($952|0)>(-1);
      $or$cond$i$i6 = $954 & $955;
      do {
       if ($or$cond$i$i6) {
        $956 = HEAP32[$stack>>2]|0;
        $957 = ($956|0)==(0|0);
        if ($957) {
         break;
        }
        $958 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $959 = HEAP32[$958>>2]|0;
        $960 = (($959) + 12|0);
        $961 = HEAP32[$960>>2]|0;
        FUNCTION_TABLE_vii[$961 & 4095]($958,$956);
       }
      } while(0);
      $962 = HEAP32[$665>>2]|0;
      $963 = $962 & 2147483647;
      $964 = ($963|0)!=(0);
      $965 = ($962|0)>(-1);
      $or$cond$i$i = $964 & $965;
      if (!($or$cond$i$i)) {
       STACKTOP = sp;return;
      }
      $966 = HEAP32[$islandLabels>>2]|0;
      $967 = ($966|0)==(0|0);
      if ($967) {
       STACKTOP = sp;return;
      }
      $968 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $969 = HEAP32[$968>>2]|0;
      $970 = (($969) + 12|0);
      $971 = HEAP32[$970>>2]|0;
      FUNCTION_TABLE_vii[$971 & 4095]($968,$966);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   __ZN5physx13PxsCCDContext12updateCCDEndEv($this);
   $601 = HEAP32[$8>>2]|0;
   $602 = HEAP32[$54>>2]|0;
   $603 = (($601) + 224|0);
   $604 = HEAP32[$603>>2]|0;
   __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($604,$602);
   if ($or$cond$i$i$i) {
    STACKTOP = sp;return;
   }
   $605 = HEAP32[$70>>2]|0;
   $606 = (($605) + 12|0);
   $607 = HEAP32[$606>>2]|0;
   $608 = $77&65535;
   FUNCTION_TABLE_viiii[$607 & 511]($70,$608,$73,$76);
   STACKTOP = sp;return;
  }
 }
 HEAP32[$$pre$phiZ2D>>2] = 0;
 __ZN5physx13PxsCCDContext12updateCCDEndEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsCCDBlockArrayINS_11PxsCCDShapeELi128EE8pushBackEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = ((($4) + ($3<<3)|0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(128);
 if (!($7)) {
  $47 = $4;$48 = $3;$50 = $6;
  $46 = ((($47) + ($48<<3)|0) + 4|0);
  $49 = (($50) + 1)|0;
  HEAP32[$46>>2] = $49;
  $51 = HEAP32[$2>>2]|0;
  $52 = (($47) + ($51<<3)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + (($50*96)|0)|0);
  STACKTOP = sp;return ($54|0);
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($3) + 1)|0;
 $10 = ($9|0)==($8|0);
 do {
  if ($10) {
   $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__Z15PxGetFoundationv()|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
   $$$i$i$i = $19 ? 487504 : 485568;
   $20 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,12288,$$$i$i$i,486184,253)|0);
   HEAP32[$0>>2] = $20;
   $21 = (($0) + 4|0);
   HEAP32[$21>>2] = 0;
   $22 = (($this) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23 & 2147483647;
   $25 = HEAP32[$1>>2]|0;
   $26 = ($24>>>0)>($25>>>0);
   if (!($26)) {
    (__ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_11PxsCCDShapeELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$0)|0);
    break;
   }
   $27 = HEAP32[$this>>2]|0;
   $28 = (($27) + ($25<<3)|0);
   $29 = ($28|0)==(0|0);
   if ($29) {
    $41 = $25;
   } else {
    $30 = $0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = $28;
    $37 = $36;
    HEAP32[$37>>2] = $32;
    $38 = (($36) + 4)|0;
    $39 = $38;
    HEAP32[$39>>2] = $35;
    $$pre$i = HEAP32[$1>>2]|0;
    $41 = $$pre$i;
   }
   $40 = (($41) + 1)|0;
   HEAP32[$1>>2] = $40;
  }
 } while(0);
 $42 = HEAP32[$2>>2]|0;
 $43 = (($42) + 1)|0;
 HEAP32[$2>>2] = $43;
 $44 = HEAP32[$this>>2]|0;
 $45 = ((($44) + ($43<<3)|0) + 4|0);
 HEAP32[$45>>2] = 0;
 $$pre = HEAP32[$2>>2]|0;
 $$phi$trans$insert = ((($44) + ($$pre<<3)|0) + 4|0);
 $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
 $47 = $44;$48 = $$pre;$50 = $$pre1;
 $46 = ((($47) + ($48<<3)|0) + 4|0);
 $49 = (($50) + 1)|0;
 HEAP32[$46>>2] = $49;
 $51 = HEAP32[$2>>2]|0;
 $52 = (($47) + ($51<<3)|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + (($50*96)|0)|0);
 STACKTOP = sp;return ($54|0);
}
function __ZN5physx16PxsCCDBlockArrayINS_10PxsCCDBodyELi128EE8pushBackEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = ((($4) + ($3<<3)|0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(128);
 if (!($7)) {
  $47 = $4;$48 = $3;$50 = $6;
  $46 = ((($47) + ($48<<3)|0) + 4|0);
  $49 = (($50) + 1)|0;
  HEAP32[$46>>2] = $49;
  $51 = HEAP32[$2>>2]|0;
  $52 = (($47) + ($51<<3)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + (($50*20)|0)|0);
  STACKTOP = sp;return ($54|0);
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($3) + 1)|0;
 $10 = ($9|0)==($8|0);
 do {
  if ($10) {
   $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__Z15PxGetFoundationv()|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
   $$$i$i$i = $19 ? 487040 : 485568;
   $20 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,2560,$$$i$i$i,486184,253)|0);
   HEAP32[$0>>2] = $20;
   $21 = (($0) + 4|0);
   HEAP32[$21>>2] = 0;
   $22 = (($this) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23 & 2147483647;
   $25 = HEAP32[$1>>2]|0;
   $26 = ($24>>>0)>($25>>>0);
   if (!($26)) {
    (__ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_10PxsCCDBodyELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$0)|0);
    break;
   }
   $27 = HEAP32[$this>>2]|0;
   $28 = (($27) + ($25<<3)|0);
   $29 = ($28|0)==(0|0);
   if ($29) {
    $41 = $25;
   } else {
    $30 = $0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = $28;
    $37 = $36;
    HEAP32[$37>>2] = $32;
    $38 = (($36) + 4)|0;
    $39 = $38;
    HEAP32[$39>>2] = $35;
    $$pre$i = HEAP32[$1>>2]|0;
    $41 = $$pre$i;
   }
   $40 = (($41) + 1)|0;
   HEAP32[$1>>2] = $40;
  }
 } while(0);
 $42 = HEAP32[$2>>2]|0;
 $43 = (($42) + 1)|0;
 HEAP32[$2>>2] = $43;
 $44 = HEAP32[$this>>2]|0;
 $45 = ((($44) + ($43<<3)|0) + 4|0);
 HEAP32[$45>>2] = 0;
 $$pre = HEAP32[$2>>2]|0;
 $$phi$trans$insert = ((($44) + ($$pre<<3)|0) + 4|0);
 $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
 $47 = $44;$48 = $$pre;$50 = $$pre1;
 $46 = ((($47) + ($48<<3)|0) + 4|0);
 $49 = (($50) + 1)|0;
 HEAP32[$46>>2] = $49;
 $51 = HEAP32[$2>>2]|0;
 $52 = (($47) + ($51<<3)|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + (($50*20)|0)|0);
 STACKTOP = sp;return ($54|0);
}
function __ZN5physx16PxsCCDBlockArrayINS_13PxsCCDOverlapELi128EE8pushBackEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = ((($4) + ($3<<3)|0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(128);
 if (!($7)) {
  $47 = $4;$48 = $3;$50 = $6;
  $46 = ((($47) + ($48<<3)|0) + 4|0);
  $49 = (($50) + 1)|0;
  HEAP32[$46>>2] = $49;
  $51 = HEAP32[$2>>2]|0;
  $52 = (($47) + ($51<<3)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + ($50<<3)|0);
  STACKTOP = sp;return ($54|0);
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($3) + 1)|0;
 $10 = ($9|0)==($8|0);
 do {
  if ($10) {
   $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__Z15PxGetFoundationv()|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
   $$$i$i$i = $19 ? 486648 : 485568;
   $20 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,1024,$$$i$i$i,486184,253)|0);
   HEAP32[$0>>2] = $20;
   $21 = (($0) + 4|0);
   HEAP32[$21>>2] = 0;
   $22 = (($this) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23 & 2147483647;
   $25 = HEAP32[$1>>2]|0;
   $26 = ($24>>>0)>($25>>>0);
   if (!($26)) {
    (__ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_13PxsCCDOverlapELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$0)|0);
    break;
   }
   $27 = HEAP32[$this>>2]|0;
   $28 = (($27) + ($25<<3)|0);
   $29 = ($28|0)==(0|0);
   if ($29) {
    $41 = $25;
   } else {
    $30 = $0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = $28;
    $37 = $36;
    HEAP32[$37>>2] = $32;
    $38 = (($36) + 4)|0;
    $39 = $38;
    HEAP32[$39>>2] = $35;
    $$pre$i = HEAP32[$1>>2]|0;
    $41 = $$pre$i;
   }
   $40 = (($41) + 1)|0;
   HEAP32[$1>>2] = $40;
  }
 } while(0);
 $42 = HEAP32[$2>>2]|0;
 $43 = (($42) + 1)|0;
 HEAP32[$2>>2] = $43;
 $44 = HEAP32[$this>>2]|0;
 $45 = ((($44) + ($43<<3)|0) + 4|0);
 HEAP32[$45>>2] = 0;
 $$pre = HEAP32[$2>>2]|0;
 $$phi$trans$insert = ((($44) + ($$pre<<3)|0) + 4|0);
 $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
 $47 = $44;$48 = $$pre;$50 = $$pre1;
 $46 = ((($47) + ($48<<3)|0) + 4|0);
 $49 = (($50) + 1)|0;
 HEAP32[$46>>2] = $49;
 $51 = HEAP32[$2>>2]|0;
 $52 = (($47) + ($51<<3)|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + ($50<<3)|0);
 STACKTOP = sp;return ($54|0);
}
function __ZN5physx16PxsCCDBlockArrayINS_10PxsCCDPairELi128EE8pushBackEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = ((($4) + ($3<<3)|0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(128);
 if (!($7)) {
  $47 = $4;$48 = $3;$50 = $6;
  $46 = ((($47) + ($48<<3)|0) + 4|0);
  $49 = (($50) + 1)|0;
  HEAP32[$46>>2] = $49;
  $51 = HEAP32[$2>>2]|0;
  $52 = (($47) + ($51<<3)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + (($50*108)|0)|0);
  STACKTOP = sp;return ($54|0);
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($3) + 1)|0;
 $10 = ($9|0)==($8|0);
 do {
  if ($10) {
   $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__Z15PxGetFoundationv()|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
   $$$i$i$i = $19 ? 486272 : 485568;
   $20 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,13824,$$$i$i$i,486184,253)|0);
   HEAP32[$0>>2] = $20;
   $21 = (($0) + 4|0);
   HEAP32[$21>>2] = 0;
   $22 = (($this) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23 & 2147483647;
   $25 = HEAP32[$1>>2]|0;
   $26 = ($24>>>0)>($25>>>0);
   if (!($26)) {
    (__ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_10PxsCCDPairELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$0)|0);
    break;
   }
   $27 = HEAP32[$this>>2]|0;
   $28 = (($27) + ($25<<3)|0);
   $29 = ($28|0)==(0|0);
   if ($29) {
    $41 = $25;
   } else {
    $30 = $0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = $28;
    $37 = $36;
    HEAP32[$37>>2] = $32;
    $38 = (($36) + 4)|0;
    $39 = $38;
    HEAP32[$39>>2] = $35;
    $$pre$i = HEAP32[$1>>2]|0;
    $41 = $$pre$i;
   }
   $40 = (($41) + 1)|0;
   HEAP32[$1>>2] = $40;
  }
 } while(0);
 $42 = HEAP32[$2>>2]|0;
 $43 = (($42) + 1)|0;
 HEAP32[$2>>2] = $43;
 $44 = HEAP32[$this>>2]|0;
 $45 = ((($44) + ($43<<3)|0) + 4|0);
 HEAP32[$45>>2] = 0;
 $$pre = HEAP32[$2>>2]|0;
 $$phi$trans$insert = ((($44) + ($$pre<<3)|0) + 4|0);
 $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
 $47 = $44;$48 = $$pre;$50 = $$pre1;
 $46 = ((($47) + ($48<<3)|0) + 4|0);
 $49 = (($50) + 1)|0;
 HEAP32[$46>>2] = $49;
 $51 = HEAP32[$2>>2]|0;
 $52 = (($47) + ($51<<3)|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + (($50*108)|0)|0);
 STACKTOP = sp;return ($54|0);
}
function __ZN5physx13PxsCCDContext12postCCDSweepEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $firstIslandInBatch$01 = 0, $firstIslandInBatch$01$us = 0, $firstIslandPair$02 = 0, $firstIslandPair$02$us = 0, $j$0 = 0, $j$0$us = 0, $lastIslandInBatch$0 = 0, $lastIslandInBatch$0$us = 0;
 var $lastIslandInBatch$1 = 0, $lastIslandInBatch$1$us = 0, $pairSum$0 = 0, $pairSum$0$us = 0, $pairSum$1 = 0, $pairSum$1$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 240|0);
 $4 = (($this) + 256|0);
 $5 = (($this) + 264|0);
 $6 = ($continuation|0)==(0|0);
 $7 = (($this) + 92|0);
 $8 = (($this) + 260|0);
 $9 = (($this) + 228|0);
 $10 = (($this) + 232|0);
 $11 = (($this) + 100|0);
 $12 = (($this) + 252|0);
 $13 = (($this) + 148|0);
 $14 = (($this) + 160|0);
 $15 = (($this) + 88|0);
 $16 = (($this) + 96|0);
 if ($6) {
  $firstIslandInBatch$01$us = 0;$firstIslandPair$02$us = 0;
  while(1) {
   $17 = (($firstIslandInBatch$01$us) + 1)|0;
   $j$0$us = $firstIslandInBatch$01$us;$pairSum$0$us = 0;
   while(1) {
    $18 = ($j$0$us>>>0)<($1>>>0);
    if (!($18)) {
     $lastIslandInBatch$0$us = $17;$pairSum$1$us = $pairSum$0$us;
     break;
    }
    $19 = HEAP32[$3>>2]|0;
    $20 = (($19) + ($j$0$us<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + ($pairSum$0$us))|0;
    $23 = HEAP32[$4>>2]|0;
    $24 = ($22>>>0)>($23>>>0);
    $25 = (($j$0$us) + 1)|0;
    if ($24) {
     $lastIslandInBatch$0$us = $25;$pairSum$1$us = $22;
     break;
    } else {
     $j$0$us = $25;$pairSum$0$us = $22;
    }
   }
   $26 = ($j$0$us|0)==($1|0);
   if ($26) {
    $27 = ($pairSum$1$us|0)==(0);
    if ($27) {
     label = 19;
     break;
    } else {
     $lastIslandInBatch$1$us = $1;
    }
   } else {
    $lastIslandInBatch$1$us = $lastIslandInBatch$0$us;
   }
   $28 = HEAP32[$5>>2]|0;
   $29 = (($28) + 6732|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($31);
   $32 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($30,80,16)|0);
   $33 = HEAP32[$30>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($33);
   $34 = ($32|0)==(0|0);
   if ($34) {
    $76 = 0;
   } else {
    $35 = HEAP32[$8>>2]|0;
    $36 = (($35) + -1)|0;
    $37 = HEAP32[$7>>2]|0;
    $38 = ($37|0)==($36|0);
    $39 = HEAP32[$9>>2]|0;
    $40 = HEAP32[$10>>2]|0;
    $41 = HEAP32[$5>>2]|0;
    $42 = HEAP32[$12>>2]|0;
    $43 = (($42) + 8764|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = (($lastIslandInBatch$1$us) - ($firstIslandInBatch$01$us))|0;
    $46 = HEAP32[$13>>2]|0;
    $47 = HEAP32[$14>>2]|0;
    $48 = HEAP8[$15>>0]|0;
    $49 = (($32) + 4|0);
    HEAP16[$49>>1] = -1;
    $50 = (($32) + 6|0);
    HEAP16[$50>>1] = 0;
    $51 = (($32) + 8|0);
    HEAP32[$51>>2] = 0;
    HEAP32[$32>>2] = ((434896 + 8|0));
    $52 = (($32) + 12|0);
    HEAP32[$52>>2] = 0;
    $53 = (($32) + 16|0);
    HEAP32[$53>>2] = 0;
    HEAP32[$32>>2] = ((488096 + 8|0));
    $54 = (($32) + 20|0);
    HEAP32[$54>>2] = $39;
    $55 = (($32) + 24|0);
    HEAP32[$55>>2] = $40;
    $56 = (($32) + 28|0);
    HEAP32[$56>>2] = $41;
    $57 = (($32) + 32|0);
    HEAP32[$57>>2] = $this;
    $58 = (($32) + 36|0);
    HEAPF32[$58>>2] = $44;
    $59 = (($32) + 40|0);
    HEAP32[$59>>2] = $37;
    $60 = (($32) + 44|0);
    HEAP32[$60>>2] = $11;
    $61 = (($32) + 48|0);
    HEAP32[$61>>2] = $firstIslandInBatch$01$us;
    $62 = (($32) + 52|0);
    HEAP32[$62>>2] = $45;
    $63 = (($32) + 56|0);
    HEAP32[$63>>2] = $1;
    $64 = (($32) + 60|0);
    HEAP32[$64>>2] = $firstIslandPair$02$us;
    $65 = (($32) + 64|0);
    HEAP32[$65>>2] = $46;
    $66 = (($32) + 68|0);
    HEAP32[$66>>2] = $47;
    $67 = (($32) + 72|0);
    HEAP32[$67>>2] = $16;
    $68 = (($32) + 76|0);
    $69 = $38&1;
    HEAP8[$68>>0] = $69;
    $70 = (($32) + 77|0);
    HEAP8[$70>>0] = $48;
    $76 = $32;
   }
   $71 = (($pairSum$1$us) + ($firstIslandPair$02$us))|0;
   $72 = HEAP32[$5>>2]|0;
   $73 = (($72) + 6728|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($76) + 16|0);
   HEAP32[$75>>2] = 1;
   $77 = (($76) + 12|0);
   HEAP32[$77>>2] = 0;
   $78 = (($76) + 8|0);
   HEAP32[$78>>2] = $74;
   $79 = HEAP32[$76>>2]|0;
   $80 = (($79) + 20|0);
   $81 = HEAP32[$80>>2]|0;
   FUNCTION_TABLE_vi[$81 & 4095]($76);
   $82 = ($lastIslandInBatch$1$us>>>0)<($1>>>0);
   if ($82) {
    $firstIslandInBatch$01$us = $lastIslandInBatch$1$us;$firstIslandPair$02$us = $71;
   } else {
    label = 19;
    break;
   }
  }
  if ((label|0) == 19) {
   STACKTOP = sp;return;
  }
 } else {
  $firstIslandInBatch$01 = 0;$firstIslandPair$02 = 0;
  while(1) {
   $83 = (($firstIslandInBatch$01) + 1)|0;
   $j$0 = $firstIslandInBatch$01;$pairSum$0 = 0;
   while(1) {
    $84 = ($j$0>>>0)<($1>>>0);
    if (!($84)) {
     $lastIslandInBatch$0 = $83;$pairSum$1 = $pairSum$0;
     break;
    }
    $85 = HEAP32[$3>>2]|0;
    $86 = (($85) + ($j$0<<2)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = (($87) + ($pairSum$0))|0;
    $89 = HEAP32[$4>>2]|0;
    $90 = ($88>>>0)>($89>>>0);
    $91 = (($j$0) + 1)|0;
    if ($90) {
     $lastIslandInBatch$0 = $91;$pairSum$1 = $88;
     break;
    } else {
     $j$0 = $91;$pairSum$0 = $88;
    }
   }
   $92 = ($j$0|0)==($1|0);
   if ($92) {
    $93 = ($pairSum$1|0)==(0);
    if ($93) {
     label = 19;
     break;
    } else {
     $lastIslandInBatch$1 = $1;
    }
   } else {
    $lastIslandInBatch$1 = $lastIslandInBatch$0;
   }
   $94 = HEAP32[$5>>2]|0;
   $95 = (($94) + 6732|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = HEAP32[$96>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($97);
   $98 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($96,80,16)|0);
   $99 = HEAP32[$96>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($99);
   $100 = ($98|0)==(0|0);
   if ($100) {
    $142 = 0;
   } else {
    $101 = HEAP32[$8>>2]|0;
    $102 = (($101) + -1)|0;
    $103 = HEAP32[$7>>2]|0;
    $104 = ($103|0)==($102|0);
    $105 = HEAP32[$9>>2]|0;
    $106 = HEAP32[$10>>2]|0;
    $107 = HEAP32[$5>>2]|0;
    $108 = HEAP32[$12>>2]|0;
    $109 = (($108) + 8764|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $111 = (($lastIslandInBatch$1) - ($firstIslandInBatch$01))|0;
    $112 = HEAP32[$13>>2]|0;
    $113 = HEAP32[$14>>2]|0;
    $114 = HEAP8[$15>>0]|0;
    $115 = (($98) + 4|0);
    HEAP16[$115>>1] = -1;
    $116 = (($98) + 6|0);
    HEAP16[$116>>1] = 0;
    $117 = (($98) + 8|0);
    HEAP32[$117>>2] = 0;
    HEAP32[$98>>2] = ((434896 + 8|0));
    $118 = (($98) + 12|0);
    HEAP32[$118>>2] = 0;
    $119 = (($98) + 16|0);
    HEAP32[$119>>2] = 0;
    HEAP32[$98>>2] = ((488096 + 8|0));
    $120 = (($98) + 20|0);
    HEAP32[$120>>2] = $105;
    $121 = (($98) + 24|0);
    HEAP32[$121>>2] = $106;
    $122 = (($98) + 28|0);
    HEAP32[$122>>2] = $107;
    $123 = (($98) + 32|0);
    HEAP32[$123>>2] = $this;
    $124 = (($98) + 36|0);
    HEAPF32[$124>>2] = $110;
    $125 = (($98) + 40|0);
    HEAP32[$125>>2] = $103;
    $126 = (($98) + 44|0);
    HEAP32[$126>>2] = $11;
    $127 = (($98) + 48|0);
    HEAP32[$127>>2] = $firstIslandInBatch$01;
    $128 = (($98) + 52|0);
    HEAP32[$128>>2] = $111;
    $129 = (($98) + 56|0);
    HEAP32[$129>>2] = $1;
    $130 = (($98) + 60|0);
    HEAP32[$130>>2] = $firstIslandPair$02;
    $131 = (($98) + 64|0);
    HEAP32[$131>>2] = $112;
    $132 = (($98) + 68|0);
    HEAP32[$132>>2] = $113;
    $133 = (($98) + 72|0);
    HEAP32[$133>>2] = $16;
    $134 = (($98) + 76|0);
    $135 = $104&1;
    HEAP8[$134>>0] = $135;
    $136 = (($98) + 77|0);
    HEAP8[$136>>0] = $114;
    $142 = $98;
   }
   $137 = (($pairSum$1) + ($firstIslandPair$02))|0;
   $138 = HEAP32[$5>>2]|0;
   $139 = (($138) + 6728|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = (($142) + 16|0);
   HEAP32[$141>>2] = 1;
   $143 = (($142) + 12|0);
   HEAP32[$143>>2] = $continuation;
   $144 = (($142) + 8|0);
   HEAP32[$144>>2] = $140;
   $145 = HEAP32[$continuation>>2]|0;
   $146 = (($145) + 16|0);
   $147 = HEAP32[$146>>2]|0;
   FUNCTION_TABLE_vi[$147 & 4095]($continuation);
   $148 = HEAP32[$142>>2]|0;
   $149 = (($148) + 20|0);
   $150 = HEAP32[$149>>2]|0;
   FUNCTION_TABLE_vi[$150 & 4095]($142);
   $151 = ($lastIslandInBatch$1>>>0)<($1>>>0);
   if ($151) {
    $firstIslandInBatch$01 = $lastIslandInBatch$1;$firstIslandPair$02 = $137;
   } else {
    label = 19;
    break;
   }
  }
  if ((label|0) == 19) {
   STACKTOP = sp;return;
  }
 }
}
function __ZN5physx13PxsCCDContext14postCCDAdvanceEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i4 = 0, $$pre24 = 0, $$pre25 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0;
 var $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0);
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $contactCount = 0, $contactForces = 0, $contactStream = 0, $contactStreamSize = 0, $countFound$0$lcssa = 0, $countFound$016 = 0, $countFound$1$lcssa = 0, $countFound$110 = 0, $countFound$2 = 0, $countFound$3 = 0, $countRetouch$0$lcssa = 0, $countRetouch$015 = 0, $countRetouch$1$lcssa = 0;
 var $countRetouch$19 = 0, $countRetouch$2 = 0, $countRetouch$3 = 0, $elt = 0, $exitcond = 0, $index$014 = 0, $island$013 = 0, $j$08 = 0, $matInfo = 0, $statusFlag = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $matInfo = sp + 36|0;
 $contactForces = sp;
 $contactStream = sp + 4|0;
 $contactStreamSize = sp + 8|0;
 $contactCount = sp + 34|0;
 $statusFlag = sp + 32|0;
 $elt = sp + 16|0;
 $1 = (($this) + 244|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==(0);
 if ($5) {
  $216 = $4;$countFound$0$lcssa = 0;$countRetouch$0$lcssa = 0;
  $215 = (($216) + 1360|0);
  $217 = HEAP32[$215>>2]|0;
  $218 = (($217) + ($countFound$0$lcssa))|0;
  HEAP32[$215>>2] = $218;
  $219 = (($216) + 1364|0);
  $220 = HEAP32[$219>>2]|0;
  $221 = (($220) + ($countRetouch$0$lcssa))|0;
  HEAP32[$219>>2] = $221;
  STACKTOP = sp;return;
 }
 $6 = (($this) + 240|0);
 $7 = (($this) + 228|0);
 $8 = (($this) + 252|0);
 $9 = (($matInfo) + 2|0);
 $10 = (($elt) + 8|0);
 $11 = (($elt) + 12|0);
 $12 = (($elt) + 4|0);
 $13 = (($4) + 5868|0);
 $14 = (($4) + 5876|0);
 $15 = (($4) + 5872|0);
 $countFound$016 = 0;$countRetouch$015 = 0;$index$014 = 0;$island$013 = 0;
 while(1) {
  $16 = HEAP32[$6>>2]|0;
  $17 = (($16) + ($island$013<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($index$014))|0;
  $20 = ($index$014>>>0)<($19>>>0);
  L6: do {
   if ($20) {
    $countFound$110 = $countFound$016;$countRetouch$19 = $countRetouch$015;$j$08 = $index$014;
    while(1) {
     $21 = HEAP32[$7>>2]|0;
     $22 = (($21) + ($j$08<<2)|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($23) + 28|0);
     $25 = Math_fround(HEAPF32[$24>>2]);
     $26 = $25 > Math_fround(1.0);
     if ($26) {
      $countFound$1$lcssa = $countFound$110;$countRetouch$1$lcssa = $countRetouch$19;
      break L6;
     }
     $27 = (($23) + 68|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = ($28<<24>>24)==(0);
     L10: do {
      if ($29) {
       $countFound$3 = $countFound$110;$countRetouch$3 = $countRetouch$19;
      } else {
       $30 = (($23) + 52|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = (($31) + 8|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = $33 | 4;
       HEAP32[$32>>2] = $34;
       $35 = (($31) + 114|0);
       $36 = HEAP16[$35>>1]|0;
       $37 = $36 & 2;
       $38 = ($37<<16>>16)==(0);
       $39 = HEAP32[$3>>2]|0;
       $40 = (($39) + 1344|0);
       $41 = (($31) + 76|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = (($42) + 32)|0;
       $44 = $43 >>> 5;
       $45 = (($39) + 1348|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = $46 & 2147483647;
       $48 = ($44>>>0)>($47>>>0);
       if ($48) {
        $49 = (($39) + 1352|0);
        $50 = $44 << 2;
        $51 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($49,$50,488024,339)|0);
        $52 = HEAP32[$40>>2]|0;
        $53 = ($52|0)==(0|0);
        if (!($53)) {
         $54 = HEAP32[$45>>2]|0;
         $55 = $54 << 2;
         _memcpy(($51|0),($52|0),($55|0))|0;
         $56 = HEAP32[$45>>2]|0;
         $57 = ($56|0)>(-1);
         if ($57) {
          $58 = HEAP32[$40>>2]|0;
          __ZN5physx6shdfnd9Allocator10deallocateEPv($49,$58);
         }
        }
        $59 = HEAP32[$45>>2]|0;
        $60 = $59 & 2147483647;
        $61 = (($51) + ($60<<2)|0);
        $62 = (($44) - ($59))|0;
        $63 = $62 << 2;
        _memset(($61|0),0,($63|0))|0;
        HEAP32[$40>>2] = $51;
        HEAP32[$45>>2] = $44;
        $$pre24 = HEAP32[$30>>2]|0;
        $$phi$trans$insert = (($$pre24) + 114|0);
        $$pre25 = HEAP16[$$phi$trans$insert>>1]|0;
        $68 = $51;$72 = $$pre24;$74 = $$pre25;
       } else {
        $$pre$i4 = HEAP32[$40>>2]|0;
        $68 = $$pre$i4;$72 = $31;$74 = $36;
       }
       $64 = $42 & 31;
       $65 = 1 << $64;
       $66 = $42 >>> 5;
       $67 = (($68) + ($66<<2)|0);
       $69 = HEAP32[$67>>2]|0;
       $70 = $69 | $65;
       HEAP32[$67>>2] = $70;
       $71 = (($72) + 114|0);
       $73 = $74&65535;
       if ($38) {
        $75 = $73 & 65532;
        $76 = $75 | 2;
        $77 = $76&65535;
        HEAP16[$71>>1] = $77;
        $78 = (($countFound$110) + 1)|0;
        $countFound$2 = $78;$countRetouch$2 = $countRetouch$19;
       } else {
        $79 = $73 | 8;
        $80 = $79&65535;
        HEAP16[$71>>1] = $80;
        $81 = (($countRetouch$19) + 1)|0;
        $countFound$2 = $countFound$110;$countRetouch$2 = $81;
       }
       $82 = (($72) + 38|0);
       $83 = HEAP16[$82>>1]|0;
       $84 = $83&65535;
       $85 = $84 & 1;
       $86 = ($85|0)==(0);
       do {
        if ($86) {
         $87 = $84 & 256;
         $88 = ($87|0)==(0);
         if ($88) {
          $countFound$3 = $countFound$2;$countRetouch$3 = $countRetouch$2;
          break L10;
         }
         $89 = $84 & 32;
         $90 = ($89|0)==(0);
         if (!($90)) {
          $91 = (($72) + 80|0);
          $92 = HEAP32[$91>>2]|0;
          $93 = (($92) + 92|0);
          $94 = HEAP32[$93>>2]|0;
          $95 = ($94|0)==(2139095039);
          if (!($95)) {
           break;
          }
         }
         $96 = $83 & 64;
         $97 = ($96<<16>>16)==(0);
         if ($97) {
          $countFound$3 = $countFound$2;$countRetouch$3 = $countRetouch$2;
          break L10;
         }
         $98 = (($72) + 84|0);
         $99 = HEAP32[$98>>2]|0;
         $100 = (($99) + 92|0);
         $101 = HEAP32[$100>>2]|0;
         $102 = ($101|0)==(2139095039);
         if ($102) {
          $countFound$3 = $countFound$2;$countRetouch$3 = $countRetouch$2;
          break L10;
         }
        }
       } while(0);
       $103 = HEAP32[$8>>2]|0;
       $104 = (($103) + 400|0);
       $105 = (($23) + 36|0);
       $106 = Math_fround(HEAPF32[$105>>2]);
       $107 = (($103) + 416|0);
       HEAPF32[$107>>2] = $106;
       $108 = (($23) + 40|0);
       $109 = Math_fround(HEAPF32[$108>>2]);
       $110 = (($103) + 420|0);
       HEAPF32[$110>>2] = $109;
       $111 = (($23) + 44|0);
       $112 = Math_fround(HEAPF32[$111>>2]);
       $113 = (($103) + 424|0);
       HEAPF32[$113>>2] = $112;
       $114 = (($23) + 16|0);
       $115 = Math_fround(HEAPF32[$114>>2]);
       $116 = Math_fround(-$115);
       $117 = (($23) + 20|0);
       $118 = Math_fround(HEAPF32[$117>>2]);
       $119 = Math_fround(-$118);
       $120 = (($23) + 24|0);
       $121 = Math_fround(HEAPF32[$120>>2]);
       $122 = Math_fround(-$121);
       HEAPF32[$104>>2] = $116;
       $123 = (($103) + 404|0);
       HEAPF32[$123>>2] = $119;
       $124 = (($103) + 408|0);
       HEAPF32[$124>>2] = $122;
       $125 = (($23) + 72|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = (($103) + 448|0);
       HEAP32[$127>>2] = $126;
       $128 = (($103) + 452|0);
       HEAP32[$128>>2] = -1;
       $129 = (($103) + 412|0);
       HEAPF32[$129>>2] = Math_fround(0.0);
       $130 = (($23) + 88|0);
       $131 = Math_fround(HEAPF32[$130>>2]);
       $132 = (($103) + 460|0);
       HEAPF32[$132>>2] = $131;
       $133 = (($23) + 80|0);
       $134 = Math_fround(HEAPF32[$133>>2]);
       $135 = (($103) + 456|0);
       HEAPF32[$135>>2] = $134;
       $136 = (($23) + 84|0);
       $137 = Math_fround(HEAPF32[$136>>2]);
       $138 = (($103) + 444|0);
       HEAPF32[$138>>2] = $137;
       $139 = (($103) + 432|0);
       HEAPF32[$139>>2] = Math_fround(0.0);
       $140 = (($103) + 436|0);
       HEAPF32[$140>>2] = Math_fround(0.0);
       $141 = (($103) + 440|0);
       HEAPF32[$141>>2] = Math_fround(0.0);
       $142 = (($103) + 428|0);
       HEAPF32[$142>>2] = Math_fround(3.40282346638528859812E+38);
       $143 = (($23) + 76|0);
       $144 = HEAP16[$143>>1]|0;
       HEAP16[$matInfo>>1] = $144;
       $145 = (($23) + 78|0);
       $146 = HEAP16[$145>>1]|0;
       HEAP16[$9>>1] = $146;
       $147 = HEAP16[$71>>1]|0;
       HEAP16[$statusFlag>>1] = $147;
       $148 = (($72) + 40|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = (($103) + 16|0);
       $151 = (($72) + 96|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = HEAP16[$82>>1]|0;
       $154 = $153 & 128;
       $155 = ($154<<16>>16)!=(0);
       $156 = (__ZN5physx22writeCompressedContactEPKNS_2Gu12ContactPointEjRNS_18PxcNpThreadContextERtRPhRjRPfjS6_PKNS_18PxsMaterialManagerEbbPNS_15PxsMaterialInfoEjbPS4_b($104,1,$150,$contactCount,$contactStream,$contactStreamSize,$contactForces,4,$statusFlag,$152,$155,1,$matInfo,8,0,0,0)|0);
       $157 = ($156|0)==(0);
       do {
        if ($157) {
         $173 = ($149|0)==(0|0);
         if ($173) {
          $174 = HEAP32[$30>>2]|0;
          $175 = (($174) + 40|0);
          HEAP32[$175>>2] = 0;
          break;
         } else {
          $176 = (($149) + 6|0);
          HEAP16[$176>>1] = 1;
          break;
         }
        } else {
         $158 = HEAP32[$contactStream>>2]|0;
         $159 = HEAP32[$contactStreamSize>>2]|0;
         $160 = $159&65535;
         $161 = (($158) + 4|0);
         HEAP16[$161>>1] = $160;
         $162 = (($158) + 6|0);
         HEAP16[$162>>1] = 0;
         $163 = HEAP32[$30>>2]|0;
         $164 = (($163) + 40|0);
         HEAP32[$164>>2] = $158;
         $165 = HEAP16[$statusFlag>>1]|0;
         $166 = HEAP32[$30>>2]|0;
         $167 = (($166) + 114|0);
         HEAP16[$167>>1] = $165;
         $168 = ($149|0)==(0|0);
         if ($168) {
          HEAP32[$158>>2] = 0;
         } else {
          HEAP32[$158>>2] = $149;
          $169 = (($149) + 6|0);
          HEAP16[$169>>1] = 1;
         }
         $170 = (($23) + 96|0);
         $171 = Math_fround(HEAPF32[$170>>2]);
         $172 = HEAP32[$contactForces>>2]|0;
         HEAPF32[$172>>2] = $171;
        }
       } while(0);
       $177 = HEAP32[$30>>2]|0;
       $178 = (($177) + 38|0);
       $179 = HEAP16[$178>>1]|0;
       $180 = $179 & 24;
       $181 = ($180<<16>>16)==(0);
       if ($181) {
        $182 = (($23) + 96|0);
        $183 = Math_fround(HEAPF32[$182>>2]);
        $184 = $183 != Math_fround(0.0);
        if ($184) {
         HEAPF32[$10>>2] = $183;
         $185 = HEAP32[$23>>2]|0;
         $186 = ($185|0)==(0|0);
         if ($186) {
          $199 = Math_fround(3.40282346638528859812E+38);
         } else {
          $187 = (($185) + 64|0);
          $188 = HEAP32[$187>>2]|0;
          $189 = (($188) + 92|0);
          $190 = Math_fround(HEAPF32[$189>>2]);
          $199 = $190;
         }
         $191 = (($23) + 4|0);
         $192 = HEAP32[$191>>2]|0;
         $193 = ($192|0)==(0|0);
         if ($193) {
          $200 = Math_fround(3.40282346638528859812E+38);
         } else {
          $194 = (($192) + 64|0);
          $195 = HEAP32[$194>>2]|0;
          $196 = (($195) + 92|0);
          $197 = Math_fround(HEAPF32[$196>>2]);
          $200 = $197;
         }
         $198 = $199 < $200;
         $201 = $198 ? $199 : $200;
         HEAPF32[$11>>2] = $201;
         HEAP32[$elt>>2] = $185;
         HEAP32[$12>>2] = $192;
         $202 = ($192>>>0)<($185>>>0);
         if ($202) {
          HEAP32[$elt>>2] = $192;
          HEAP32[$12>>2] = $185;
         }
         $203 = HEAP32[$14>>2]|0;
         $204 = $203 & 2147483647;
         $205 = HEAP32[$15>>2]|0;
         $206 = ($204>>>0)>($205>>>0);
         if (!($206)) {
          (__ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($13,$elt)|0);
          $countFound$3 = $countFound$2;$countRetouch$3 = $countRetouch$2;
          break;
         }
         $207 = HEAP32[$13>>2]|0;
         $208 = (($207) + ($205<<4)|0);
         $209 = ($208|0)==(0|0);
         if ($209) {
          $211 = $205;
         } else {
          ;HEAP32[$208+0>>2]=HEAP32[$elt+0>>2]|0;HEAP32[$208+4>>2]=HEAP32[$elt+4>>2]|0;HEAP32[$208+8>>2]=HEAP32[$elt+8>>2]|0;HEAP32[$208+12>>2]=HEAP32[$elt+12>>2]|0;
          $$pre$i = HEAP32[$15>>2]|0;
          $211 = $$pre$i;
         }
         $210 = (($211) + 1)|0;
         HEAP32[$15>>2] = $210;
         $countFound$3 = $countFound$2;$countRetouch$3 = $countRetouch$2;
        } else {
         $countFound$3 = $countFound$2;$countRetouch$3 = $countRetouch$2;
        }
       } else {
        $countFound$3 = $countFound$2;$countRetouch$3 = $countRetouch$2;
       }
      }
     } while(0);
     $212 = (($j$08) + 1)|0;
     $213 = ($212>>>0)<($19>>>0);
     if ($213) {
      $countFound$110 = $countFound$3;$countRetouch$19 = $countRetouch$3;$j$08 = $212;
     } else {
      $countFound$1$lcssa = $countFound$3;$countRetouch$1$lcssa = $countRetouch$3;
      break;
     }
    }
   } else {
    $countFound$1$lcssa = $countFound$016;$countRetouch$1$lcssa = $countRetouch$015;
   }
  } while(0);
  $214 = (($island$013) + 1)|0;
  $exitcond = ($214|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $countFound$016 = $countFound$1$lcssa;$countRetouch$015 = $countRetouch$1$lcssa;$index$014 = $19;$island$013 = $214;
  }
 }
 $$pre = HEAP32[$3>>2]|0;
 $216 = $$pre;$countFound$0$lcssa = $countFound$1$lcssa;$countRetouch$0$lcssa = $countRetouch$1$lcssa;
 $215 = (($216) + 1360|0);
 $217 = HEAP32[$215>>2]|0;
 $218 = (($217) + ($countFound$0$lcssa))|0;
 HEAP32[$215>>2] = $218;
 $219 = (($216) + 1364|0);
 $220 = HEAP32[$219>>2]|0;
 $221 = (($220) + ($countRetouch$0$lcssa))|0;
 HEAP32[$219>>2] = $221;
 STACKTOP = sp;return;
}
function __ZN5physx13PxsCCDContext23runCCDModifiableContactEPNS_19PxModifiableContactEjPKNS_12PxsShapeCoreES5_PKNS_12PxsRigidCoreES8_PKNS_12PxsRigidBodyESB_($this,$contacts,$contactCount,$shapeCore0,$shapeCore1,$rigidCore0,$rigidCore1,$rigid0,$rigid1) {
 $this = $this|0;
 $contacts = $contacts|0;
 $contactCount = $contactCount|0;
 $shapeCore0 = $shapeCore0|0;
 $shapeCore1 = $shapeCore1|0;
 $rigidCore0 = $rigidCore0|0;
 $rigidCore1 = $rigidCore1|0;
 $rigid0 = $rigid0|0;
 $rigid1 = $rigid1|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0;
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = Math_fround(0), $330 = 0, $331 = Math_fround(0);
 var $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0);
 var $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0);
 var $459 = Math_fround(0), $46 = Math_fround(0), $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0);
 var $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = 0, $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = 0, $511 = Math_fround(0);
 var $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0);
 var $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = 0, $536 = Math_fround(0), $537 = Math_fround(0), $538 = 0, $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0);
 var $549 = Math_fround(0), $55 = Math_fround(0), $550 = 0, $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = 0, $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0);
 var $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = 0, $583 = Math_fround(0), $584 = Math_fround(0);
 var $585 = 0, $586 = Math_fround(0), $587 = Math_fround(0), $588 = 0, $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = 0, $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = 0, $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = 0;
 var $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0);
 var $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = 0, $627 = Math_fround(0), $628 = 0, $629 = Math_fround(0), $63 = Math_fround(0), $630 = 0, $631 = Math_fround(0), $632 = 0, $633 = Math_fround(0), $634 = 0, $635 = Math_fround(0), $636 = 0, $637 = Math_fround(0), $638 = 0;
 var $639 = Math_fround(0), $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $p = sp;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__Z28ScGetPxShapeFromPxsShapeCorePKN5physx12PxsShapeCoreE($shapeCore0)|0);
 $4 = (($p) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = (__Z28ScGetPxShapeFromPxsShapeCorePKN5physx12PxsShapeCoreE($shapeCore1)|0);
 $6 = (($p) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = ($rigid0|0)!=(0|0);
 if ($7) {
  $8 = (__Z32ScGetPxRigidBodyFromPxsRigidCorePKN5physx12PxsRigidCoreE($rigidCore0)|0);
  $10 = $8;
 } else {
  $9 = (__Z34ScGetPxRigidStaticFromPxsRigidCorePKN5physx12PxsRigidCoreE($rigidCore0)|0);
  $10 = $9;
 }
 HEAP32[$p>>2] = $10;
 $11 = ($rigid1|0)!=(0|0);
 if ($11) {
  $12 = (__Z32ScGetPxRigidBodyFromPxsRigidCorePKN5physx12PxsRigidCoreE($rigidCore1)|0);
  $15 = $12;
 } else {
  $13 = (__Z34ScGetPxRigidStaticFromPxsRigidCorePKN5physx12PxsRigidCoreE($rigidCore1)|0);
  $15 = $13;
 }
 $14 = (($p) + 4|0);
 HEAP32[$14>>2] = $15;
 if ($7) {
  $16 = (($rigidCore0) + 48|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($rigidCore0) + 52|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($rigidCore0) + 56|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($17 * Math_fround(-2.0));
  $23 = Math_fround($19 * Math_fround(-2.0));
  $24 = Math_fround($21 * Math_fround(-2.0));
  $25 = (($rigidCore0) + 44|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($26 * $26);
  $28 = Math_fround($27 + Math_fround(-0.5));
  $29 = (($rigidCore0) + 32|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($22 * $30);
  $32 = (($rigidCore0) + 36|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($23 * $33);
  $35 = Math_fround($31 + $34);
  $36 = (($rigidCore0) + 40|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($24 * $37);
  $39 = Math_fround($35 + $38);
  $40 = Math_fround($22 * $28);
  $41 = Math_fround($24 * $33);
  $42 = Math_fround($23 * $37);
  $43 = Math_fround($41 - $42);
  $44 = Math_fround($26 * $43);
  $45 = Math_fround($40 - $44);
  $46 = Math_fround($30 * $39);
  $47 = Math_fround($46 + $45);
  $48 = Math_fround($23 * $28);
  $49 = Math_fround($22 * $37);
  $50 = Math_fround($24 * $30);
  $51 = Math_fround($49 - $50);
  $52 = Math_fround($26 * $51);
  $53 = Math_fround($48 - $52);
  $54 = Math_fround($33 * $39);
  $55 = Math_fround($54 + $53);
  $56 = Math_fround($24 * $28);
  $57 = Math_fround($23 * $30);
  $58 = Math_fround($22 * $33);
  $59 = Math_fround($57 - $58);
  $60 = Math_fround($26 * $59);
  $61 = Math_fround($56 - $60);
  $62 = Math_fround($37 * $39);
  $63 = Math_fround($61 + $62);
  $64 = Math_fround(-$30);
  $65 = Math_fround(-$33);
  $66 = Math_fround(-$37);
  $67 = Math_fround($47 * Math_fround(2.0));
  $68 = Math_fround($55 * Math_fround(2.0));
  $69 = Math_fround($63 * Math_fround(2.0));
  $70 = (($rigidCore0) + 12|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = Math_fround($71 * $71);
  $73 = Math_fround($72 + Math_fround(-0.5));
  $74 = Math_fround(HEAPF32[$rigidCore0>>2]);
  $75 = Math_fround($74 * $67);
  $76 = (($rigidCore0) + 4|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = Math_fround($77 * $68);
  $79 = Math_fround($75 + $78);
  $80 = (($rigidCore0) + 8|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround($81 * $69);
  $83 = Math_fround($82 + $79);
  $84 = Math_fround($73 * $67);
  $85 = Math_fround($77 * $69);
  $86 = Math_fround($81 * $68);
  $87 = Math_fround($85 - $86);
  $88 = Math_fround($71 * $87);
  $89 = Math_fround($84 + $88);
  $90 = Math_fround($74 * $83);
  $91 = Math_fround($90 + $89);
  $92 = Math_fround($73 * $68);
  $93 = Math_fround($81 * $67);
  $94 = Math_fround($74 * $69);
  $95 = Math_fround($93 - $94);
  $96 = Math_fround($71 * $95);
  $97 = Math_fround($92 + $96);
  $98 = Math_fround($77 * $83);
  $99 = Math_fround($98 + $97);
  $100 = Math_fround($73 * $69);
  $101 = Math_fround($74 * $68);
  $102 = Math_fround($77 * $67);
  $103 = Math_fround($101 - $102);
  $104 = Math_fround($71 * $103);
  $105 = Math_fround($100 + $104);
  $106 = Math_fround($81 * $83);
  $107 = Math_fround($105 + $106);
  $108 = (($rigidCore0) + 16|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = Math_fround($109 + $91);
  $111 = (($rigidCore0) + 20|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = Math_fround($112 + $99);
  $114 = (($rigidCore0) + 24|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($115 + $107);
  $117 = Math_fround($71 * $64);
  $118 = Math_fround($26 * $74);
  $119 = Math_fround($117 + $118);
  $120 = Math_fround($77 * $66);
  $121 = Math_fround($119 + $120);
  $122 = Math_fround($81 * $65);
  $123 = Math_fround($121 - $122);
  $124 = Math_fround($71 * $65);
  $125 = Math_fround($26 * $77);
  $126 = Math_fround($124 + $125);
  $127 = Math_fround($81 * $64);
  $128 = Math_fround($127 + $126);
  $129 = Math_fround($74 * $66);
  $130 = Math_fround($128 - $129);
  $131 = Math_fround($71 * $66);
  $132 = Math_fround($26 * $81);
  $133 = Math_fround($131 + $132);
  $134 = Math_fround($74 * $65);
  $135 = Math_fround($134 + $133);
  $136 = Math_fround($77 * $64);
  $137 = Math_fround($135 - $136);
  $138 = Math_fround($26 * $71);
  $139 = Math_fround($74 * $64);
  $140 = Math_fround($138 - $139);
  $141 = Math_fround($77 * $65);
  $142 = Math_fround($140 - $141);
  $143 = Math_fround($81 * $66);
  $144 = Math_fround($142 - $143);
  $145 = (($shapeCore0) + 16|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = Math_fround($146 * Math_fround(2.0));
  $148 = (($shapeCore0) + 20|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = Math_fround($149 * Math_fround(2.0));
  $151 = (($shapeCore0) + 24|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = Math_fround($152 * Math_fround(2.0));
  $154 = Math_fround($144 * $144);
  $155 = Math_fround($154 + Math_fround(-0.5));
  $156 = Math_fround($123 * $147);
  $157 = Math_fround($130 * $150);
  $158 = Math_fround($156 + $157);
  $159 = Math_fround($137 * $153);
  $160 = Math_fround($158 + $159);
  $161 = Math_fround($155 * $147);
  $162 = Math_fround($130 * $153);
  $163 = Math_fround($137 * $150);
  $164 = Math_fround($162 - $163);
  $165 = Math_fround($144 * $164);
  $166 = Math_fround($161 + $165);
  $167 = Math_fround($123 * $160);
  $168 = Math_fround($167 + $166);
  $169 = Math_fround($155 * $150);
  $170 = Math_fround($137 * $147);
  $171 = Math_fround($123 * $153);
  $172 = Math_fround($170 - $171);
  $173 = Math_fround($144 * $172);
  $174 = Math_fround($169 + $173);
  $175 = Math_fround($130 * $160);
  $176 = Math_fround($175 + $174);
  $177 = Math_fround($155 * $153);
  $178 = Math_fround($123 * $150);
  $179 = Math_fround($130 * $147);
  $180 = Math_fround($178 - $179);
  $181 = Math_fround($144 * $180);
  $182 = Math_fround($177 + $181);
  $183 = Math_fround($137 * $160);
  $184 = Math_fround($182 + $183);
  $185 = Math_fround($110 + $168);
  $186 = Math_fround($113 + $176);
  $187 = Math_fround($116 + $184);
  $188 = Math_fround(HEAPF32[$shapeCore0>>2]);
  $189 = Math_fround($144 * $188);
  $190 = (($shapeCore0) + 12|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = Math_fround($123 * $191);
  $193 = Math_fround($189 + $192);
  $194 = (($shapeCore0) + 8|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($130 * $195);
  $197 = Math_fround($193 + $196);
  $198 = (($shapeCore0) + 4|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = Math_fround($137 * $199);
  $201 = Math_fround($197 - $200);
  $202 = Math_fround($144 * $199);
  $203 = Math_fround($130 * $191);
  $204 = Math_fround($203 + $202);
  $205 = Math_fround($137 * $188);
  $206 = Math_fround($205 + $204);
  $207 = Math_fround($123 * $195);
  $208 = Math_fround($206 - $207);
  $209 = Math_fround($144 * $195);
  $210 = Math_fround($137 * $191);
  $211 = Math_fround($210 + $209);
  $212 = Math_fround($123 * $199);
  $213 = Math_fround($212 + $211);
  $214 = Math_fround($130 * $188);
  $215 = Math_fround($213 - $214);
  $216 = Math_fround($144 * $191);
  $217 = Math_fround($123 * $188);
  $218 = Math_fround($216 - $217);
  $219 = Math_fround($130 * $199);
  $220 = Math_fround($218 - $219);
  $221 = Math_fround($137 * $195);
  $222 = Math_fround($220 - $221);
  $315 = $201;$317 = $208;$319 = $215;$321 = $222;$323 = $185;$325 = $186;$327 = $187;
 } else {
  $223 = (($shapeCore0) + 16|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = Math_fround($224 * Math_fround(2.0));
  $226 = (($shapeCore0) + 20|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = Math_fround($227 * Math_fround(2.0));
  $229 = (($shapeCore0) + 24|0);
  $230 = Math_fround(HEAPF32[$229>>2]);
  $231 = Math_fround($230 * Math_fround(2.0));
  $232 = (($rigidCore0) + 12|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = Math_fround($233 * $233);
  $235 = Math_fround($234 + Math_fround(-0.5));
  $236 = Math_fround(HEAPF32[$rigidCore0>>2]);
  $237 = Math_fround($225 * $236);
  $238 = (($rigidCore0) + 4|0);
  $239 = Math_fround(HEAPF32[$238>>2]);
  $240 = Math_fround($228 * $239);
  $241 = Math_fround($237 + $240);
  $242 = (($rigidCore0) + 8|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = Math_fround($231 * $243);
  $245 = Math_fround($241 + $244);
  $246 = Math_fround($225 * $235);
  $247 = Math_fround($231 * $239);
  $248 = Math_fround($228 * $243);
  $249 = Math_fround($247 - $248);
  $250 = Math_fround($233 * $249);
  $251 = Math_fround($246 + $250);
  $252 = Math_fround($236 * $245);
  $253 = Math_fround($252 + $251);
  $254 = Math_fround($228 * $235);
  $255 = Math_fround($225 * $243);
  $256 = Math_fround($231 * $236);
  $257 = Math_fround($255 - $256);
  $258 = Math_fround($233 * $257);
  $259 = Math_fround($254 + $258);
  $260 = Math_fround($239 * $245);
  $261 = Math_fround($260 + $259);
  $262 = Math_fround($231 * $235);
  $263 = Math_fround($228 * $236);
  $264 = Math_fround($225 * $239);
  $265 = Math_fround($263 - $264);
  $266 = Math_fround($233 * $265);
  $267 = Math_fround($262 + $266);
  $268 = Math_fround($243 * $245);
  $269 = Math_fround($267 + $268);
  $270 = (($rigidCore0) + 16|0);
  $271 = Math_fround(HEAPF32[$270>>2]);
  $272 = Math_fround($271 + $253);
  $273 = (($rigidCore0) + 20|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = Math_fround($274 + $261);
  $276 = (($rigidCore0) + 24|0);
  $277 = Math_fround(HEAPF32[$276>>2]);
  $278 = Math_fround($277 + $269);
  $279 = Math_fround(HEAPF32[$shapeCore0>>2]);
  $280 = Math_fround($233 * $279);
  $281 = (($shapeCore0) + 12|0);
  $282 = Math_fround(HEAPF32[$281>>2]);
  $283 = Math_fround($236 * $282);
  $284 = Math_fround($280 + $283);
  $285 = (($shapeCore0) + 8|0);
  $286 = Math_fround(HEAPF32[$285>>2]);
  $287 = Math_fround($239 * $286);
  $288 = Math_fround($284 + $287);
  $289 = (($shapeCore0) + 4|0);
  $290 = Math_fround(HEAPF32[$289>>2]);
  $291 = Math_fround($243 * $290);
  $292 = Math_fround($288 - $291);
  $293 = Math_fround($233 * $290);
  $294 = Math_fround($239 * $282);
  $295 = Math_fround($294 + $293);
  $296 = Math_fround($243 * $279);
  $297 = Math_fround($296 + $295);
  $298 = Math_fround($236 * $286);
  $299 = Math_fround($297 - $298);
  $300 = Math_fround($233 * $286);
  $301 = Math_fround($243 * $282);
  $302 = Math_fround($301 + $300);
  $303 = Math_fround($236 * $290);
  $304 = Math_fround($303 + $302);
  $305 = Math_fround($239 * $279);
  $306 = Math_fround($304 - $305);
  $307 = Math_fround($233 * $282);
  $308 = Math_fround($236 * $279);
  $309 = Math_fround($307 - $308);
  $310 = Math_fround($239 * $290);
  $311 = Math_fround($309 - $310);
  $312 = Math_fround($243 * $286);
  $313 = Math_fround($311 - $312);
  $315 = $292;$317 = $299;$319 = $306;$321 = $313;$323 = $272;$325 = $275;$327 = $278;
 }
 $314 = (($p) + 16|0);
 HEAPF32[$314>>2] = $315;
 $316 = (($p) + 20|0);
 HEAPF32[$316>>2] = $317;
 $318 = (($p) + 24|0);
 HEAPF32[$318>>2] = $319;
 $320 = (($p) + 28|0);
 HEAPF32[$320>>2] = $321;
 $322 = (($p) + 32|0);
 HEAPF32[$322>>2] = $323;
 $324 = (($p) + 36|0);
 HEAPF32[$324>>2] = $325;
 $326 = (($p) + 40|0);
 HEAPF32[$326>>2] = $327;
 if ($11) {
  $328 = (($rigidCore1) + 48|0);
  $329 = Math_fround(HEAPF32[$328>>2]);
  $330 = (($rigidCore1) + 52|0);
  $331 = Math_fround(HEAPF32[$330>>2]);
  $332 = (($rigidCore1) + 56|0);
  $333 = Math_fround(HEAPF32[$332>>2]);
  $334 = Math_fround($329 * Math_fround(-2.0));
  $335 = Math_fround($331 * Math_fround(-2.0));
  $336 = Math_fround($333 * Math_fround(-2.0));
  $337 = (($rigidCore1) + 44|0);
  $338 = Math_fround(HEAPF32[$337>>2]);
  $339 = Math_fround($338 * $338);
  $340 = Math_fround($339 + Math_fround(-0.5));
  $341 = (($rigidCore1) + 32|0);
  $342 = Math_fround(HEAPF32[$341>>2]);
  $343 = Math_fround($334 * $342);
  $344 = (($rigidCore1) + 36|0);
  $345 = Math_fround(HEAPF32[$344>>2]);
  $346 = Math_fround($335 * $345);
  $347 = Math_fround($343 + $346);
  $348 = (($rigidCore1) + 40|0);
  $349 = Math_fround(HEAPF32[$348>>2]);
  $350 = Math_fround($336 * $349);
  $351 = Math_fround($347 + $350);
  $352 = Math_fround($334 * $340);
  $353 = Math_fround($336 * $345);
  $354 = Math_fround($335 * $349);
  $355 = Math_fround($353 - $354);
  $356 = Math_fround($338 * $355);
  $357 = Math_fround($352 - $356);
  $358 = Math_fround($342 * $351);
  $359 = Math_fround($358 + $357);
  $360 = Math_fround($335 * $340);
  $361 = Math_fround($334 * $349);
  $362 = Math_fround($336 * $342);
  $363 = Math_fround($361 - $362);
  $364 = Math_fround($338 * $363);
  $365 = Math_fround($360 - $364);
  $366 = Math_fround($345 * $351);
  $367 = Math_fround($366 + $365);
  $368 = Math_fround($336 * $340);
  $369 = Math_fround($335 * $342);
  $370 = Math_fround($334 * $345);
  $371 = Math_fround($369 - $370);
  $372 = Math_fround($338 * $371);
  $373 = Math_fround($368 - $372);
  $374 = Math_fround($349 * $351);
  $375 = Math_fround($373 + $374);
  $376 = Math_fround(-$342);
  $377 = Math_fround(-$345);
  $378 = Math_fround(-$349);
  $379 = Math_fround($359 * Math_fround(2.0));
  $380 = Math_fround($367 * Math_fround(2.0));
  $381 = Math_fround($375 * Math_fround(2.0));
  $382 = (($rigidCore1) + 12|0);
  $383 = Math_fround(HEAPF32[$382>>2]);
  $384 = Math_fround($383 * $383);
  $385 = Math_fround($384 + Math_fround(-0.5));
  $386 = Math_fround(HEAPF32[$rigidCore1>>2]);
  $387 = Math_fround($386 * $379);
  $388 = (($rigidCore1) + 4|0);
  $389 = Math_fround(HEAPF32[$388>>2]);
  $390 = Math_fround($389 * $380);
  $391 = Math_fround($387 + $390);
  $392 = (($rigidCore1) + 8|0);
  $393 = Math_fround(HEAPF32[$392>>2]);
  $394 = Math_fround($393 * $381);
  $395 = Math_fround($394 + $391);
  $396 = Math_fround($385 * $379);
  $397 = Math_fround($389 * $381);
  $398 = Math_fround($393 * $380);
  $399 = Math_fround($397 - $398);
  $400 = Math_fround($383 * $399);
  $401 = Math_fround($396 + $400);
  $402 = Math_fround($386 * $395);
  $403 = Math_fround($402 + $401);
  $404 = Math_fround($385 * $380);
  $405 = Math_fround($393 * $379);
  $406 = Math_fround($386 * $381);
  $407 = Math_fround($405 - $406);
  $408 = Math_fround($383 * $407);
  $409 = Math_fround($404 + $408);
  $410 = Math_fround($389 * $395);
  $411 = Math_fround($410 + $409);
  $412 = Math_fround($385 * $381);
  $413 = Math_fround($386 * $380);
  $414 = Math_fround($389 * $379);
  $415 = Math_fround($413 - $414);
  $416 = Math_fround($383 * $415);
  $417 = Math_fround($412 + $416);
  $418 = Math_fround($393 * $395);
  $419 = Math_fround($417 + $418);
  $420 = (($rigidCore1) + 16|0);
  $421 = Math_fround(HEAPF32[$420>>2]);
  $422 = Math_fround($421 + $403);
  $423 = (($rigidCore1) + 20|0);
  $424 = Math_fround(HEAPF32[$423>>2]);
  $425 = Math_fround($424 + $411);
  $426 = (($rigidCore1) + 24|0);
  $427 = Math_fround(HEAPF32[$426>>2]);
  $428 = Math_fround($427 + $419);
  $429 = Math_fround($383 * $376);
  $430 = Math_fround($338 * $386);
  $431 = Math_fround($429 + $430);
  $432 = Math_fround($389 * $378);
  $433 = Math_fround($431 + $432);
  $434 = Math_fround($393 * $377);
  $435 = Math_fround($433 - $434);
  $436 = Math_fround($383 * $377);
  $437 = Math_fround($338 * $389);
  $438 = Math_fround($436 + $437);
  $439 = Math_fround($393 * $376);
  $440 = Math_fround($439 + $438);
  $441 = Math_fround($386 * $378);
  $442 = Math_fround($440 - $441);
  $443 = Math_fround($383 * $378);
  $444 = Math_fround($338 * $393);
  $445 = Math_fround($443 + $444);
  $446 = Math_fround($386 * $377);
  $447 = Math_fround($446 + $445);
  $448 = Math_fround($389 * $376);
  $449 = Math_fround($447 - $448);
  $450 = Math_fround($338 * $383);
  $451 = Math_fround($386 * $376);
  $452 = Math_fround($450 - $451);
  $453 = Math_fround($389 * $377);
  $454 = Math_fround($452 - $453);
  $455 = Math_fround($393 * $378);
  $456 = Math_fround($454 - $455);
  $457 = (($shapeCore1) + 16|0);
  $458 = Math_fround(HEAPF32[$457>>2]);
  $459 = Math_fround($458 * Math_fround(2.0));
  $460 = (($shapeCore1) + 20|0);
  $461 = Math_fround(HEAPF32[$460>>2]);
  $462 = Math_fround($461 * Math_fround(2.0));
  $463 = (($shapeCore1) + 24|0);
  $464 = Math_fround(HEAPF32[$463>>2]);
  $465 = Math_fround($464 * Math_fround(2.0));
  $466 = Math_fround($456 * $456);
  $467 = Math_fround($466 + Math_fround(-0.5));
  $468 = Math_fround($435 * $459);
  $469 = Math_fround($442 * $462);
  $470 = Math_fround($468 + $469);
  $471 = Math_fround($449 * $465);
  $472 = Math_fround($470 + $471);
  $473 = Math_fround($467 * $459);
  $474 = Math_fround($442 * $465);
  $475 = Math_fround($449 * $462);
  $476 = Math_fround($474 - $475);
  $477 = Math_fround($456 * $476);
  $478 = Math_fround($473 + $477);
  $479 = Math_fround($435 * $472);
  $480 = Math_fround($479 + $478);
  $481 = Math_fround($467 * $462);
  $482 = Math_fround($449 * $459);
  $483 = Math_fround($435 * $465);
  $484 = Math_fround($482 - $483);
  $485 = Math_fround($456 * $484);
  $486 = Math_fround($481 + $485);
  $487 = Math_fround($442 * $472);
  $488 = Math_fround($487 + $486);
  $489 = Math_fround($467 * $465);
  $490 = Math_fround($435 * $462);
  $491 = Math_fround($442 * $459);
  $492 = Math_fround($490 - $491);
  $493 = Math_fround($456 * $492);
  $494 = Math_fround($489 + $493);
  $495 = Math_fround($449 * $472);
  $496 = Math_fround($494 + $495);
  $497 = Math_fround($422 + $480);
  $498 = Math_fround($425 + $488);
  $499 = Math_fround($428 + $496);
  $500 = Math_fround(HEAPF32[$shapeCore1>>2]);
  $501 = Math_fround($456 * $500);
  $502 = (($shapeCore1) + 12|0);
  $503 = Math_fround(HEAPF32[$502>>2]);
  $504 = Math_fround($435 * $503);
  $505 = Math_fround($501 + $504);
  $506 = (($shapeCore1) + 8|0);
  $507 = Math_fround(HEAPF32[$506>>2]);
  $508 = Math_fround($442 * $507);
  $509 = Math_fround($505 + $508);
  $510 = (($shapeCore1) + 4|0);
  $511 = Math_fround(HEAPF32[$510>>2]);
  $512 = Math_fround($449 * $511);
  $513 = Math_fround($509 - $512);
  $514 = Math_fround($456 * $511);
  $515 = Math_fround($442 * $503);
  $516 = Math_fround($515 + $514);
  $517 = Math_fround($449 * $500);
  $518 = Math_fround($517 + $516);
  $519 = Math_fround($435 * $507);
  $520 = Math_fround($518 - $519);
  $521 = Math_fround($456 * $507);
  $522 = Math_fround($449 * $503);
  $523 = Math_fround($522 + $521);
  $524 = Math_fround($435 * $511);
  $525 = Math_fround($524 + $523);
  $526 = Math_fround($442 * $500);
  $527 = Math_fround($525 - $526);
  $528 = Math_fround($456 * $503);
  $529 = Math_fround($435 * $500);
  $530 = Math_fround($528 - $529);
  $531 = Math_fround($442 * $511);
  $532 = Math_fround($530 - $531);
  $533 = Math_fround($449 * $507);
  $534 = Math_fround($532 - $533);
  $627 = $513;$629 = $520;$631 = $527;$633 = $534;$635 = $497;$637 = $498;$639 = $499;
 } else {
  $535 = (($shapeCore1) + 16|0);
  $536 = Math_fround(HEAPF32[$535>>2]);
  $537 = Math_fround($536 * Math_fround(2.0));
  $538 = (($shapeCore1) + 20|0);
  $539 = Math_fround(HEAPF32[$538>>2]);
  $540 = Math_fround($539 * Math_fround(2.0));
  $541 = (($shapeCore1) + 24|0);
  $542 = Math_fround(HEAPF32[$541>>2]);
  $543 = Math_fround($542 * Math_fround(2.0));
  $544 = (($rigidCore1) + 12|0);
  $545 = Math_fround(HEAPF32[$544>>2]);
  $546 = Math_fround($545 * $545);
  $547 = Math_fround($546 + Math_fround(-0.5));
  $548 = Math_fround(HEAPF32[$rigidCore1>>2]);
  $549 = Math_fround($537 * $548);
  $550 = (($rigidCore1) + 4|0);
  $551 = Math_fround(HEAPF32[$550>>2]);
  $552 = Math_fround($540 * $551);
  $553 = Math_fround($549 + $552);
  $554 = (($rigidCore1) + 8|0);
  $555 = Math_fround(HEAPF32[$554>>2]);
  $556 = Math_fround($543 * $555);
  $557 = Math_fround($553 + $556);
  $558 = Math_fround($537 * $547);
  $559 = Math_fround($543 * $551);
  $560 = Math_fround($540 * $555);
  $561 = Math_fround($559 - $560);
  $562 = Math_fround($545 * $561);
  $563 = Math_fround($558 + $562);
  $564 = Math_fround($548 * $557);
  $565 = Math_fround($564 + $563);
  $566 = Math_fround($540 * $547);
  $567 = Math_fround($537 * $555);
  $568 = Math_fround($543 * $548);
  $569 = Math_fround($567 - $568);
  $570 = Math_fround($545 * $569);
  $571 = Math_fround($566 + $570);
  $572 = Math_fround($551 * $557);
  $573 = Math_fround($572 + $571);
  $574 = Math_fround($543 * $547);
  $575 = Math_fround($540 * $548);
  $576 = Math_fround($537 * $551);
  $577 = Math_fround($575 - $576);
  $578 = Math_fround($545 * $577);
  $579 = Math_fround($574 + $578);
  $580 = Math_fround($555 * $557);
  $581 = Math_fround($579 + $580);
  $582 = (($rigidCore1) + 16|0);
  $583 = Math_fround(HEAPF32[$582>>2]);
  $584 = Math_fround($583 + $565);
  $585 = (($rigidCore1) + 20|0);
  $586 = Math_fround(HEAPF32[$585>>2]);
  $587 = Math_fround($586 + $573);
  $588 = (($rigidCore1) + 24|0);
  $589 = Math_fround(HEAPF32[$588>>2]);
  $590 = Math_fround($589 + $581);
  $591 = Math_fround(HEAPF32[$shapeCore1>>2]);
  $592 = Math_fround($545 * $591);
  $593 = (($shapeCore1) + 12|0);
  $594 = Math_fround(HEAPF32[$593>>2]);
  $595 = Math_fround($548 * $594);
  $596 = Math_fround($592 + $595);
  $597 = (($shapeCore1) + 8|0);
  $598 = Math_fround(HEAPF32[$597>>2]);
  $599 = Math_fround($551 * $598);
  $600 = Math_fround($596 + $599);
  $601 = (($shapeCore1) + 4|0);
  $602 = Math_fround(HEAPF32[$601>>2]);
  $603 = Math_fround($555 * $602);
  $604 = Math_fround($600 - $603);
  $605 = Math_fround($545 * $602);
  $606 = Math_fround($551 * $594);
  $607 = Math_fround($606 + $605);
  $608 = Math_fround($555 * $591);
  $609 = Math_fround($608 + $607);
  $610 = Math_fround($548 * $598);
  $611 = Math_fround($609 - $610);
  $612 = Math_fround($545 * $598);
  $613 = Math_fround($555 * $594);
  $614 = Math_fround($613 + $612);
  $615 = Math_fround($548 * $602);
  $616 = Math_fround($615 + $614);
  $617 = Math_fround($551 * $591);
  $618 = Math_fround($616 - $617);
  $619 = Math_fround($545 * $594);
  $620 = Math_fround($548 * $591);
  $621 = Math_fround($619 - $620);
  $622 = Math_fround($551 * $602);
  $623 = Math_fround($621 - $622);
  $624 = Math_fround($555 * $598);
  $625 = Math_fround($623 - $624);
  $627 = $604;$629 = $611;$631 = $618;$633 = $625;$635 = $584;$637 = $587;$639 = $590;
 }
 $626 = (($p) + 44|0);
 HEAPF32[$626>>2] = $627;
 $628 = (($p) + 48|0);
 HEAPF32[$628>>2] = $629;
 $630 = (($p) + 52|0);
 HEAPF32[$630>>2] = $631;
 $632 = (($p) + 56|0);
 HEAPF32[$632>>2] = $633;
 $634 = (($p) + 60|0);
 HEAPF32[$634>>2] = $635;
 $636 = (($p) + 64|0);
 HEAPF32[$636>>2] = $637;
 $638 = (($p) + 68|0);
 HEAPF32[$638>>2] = $639;
 $640 = (($p) + 72|0);
 $641 = $contacts;
 $642 = $640;
 $643 = $642;
 HEAP32[$643>>2] = $contactCount;
 $644 = (($642) + 4)|0;
 $645 = $644;
 HEAP32[$645>>2] = $641;
 $646 = HEAP32[$0>>2]|0;
 $647 = HEAP32[$646>>2]|0;
 $648 = HEAP32[$647>>2]|0;
 FUNCTION_TABLE_viii[$648 & 4095]($646,$p,1);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 4;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 485600 : 485568;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,485488,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<4)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
   }
   $25 = (($$012$i) + 16|0);
   $26 = (($$03$i) + 16|0);
   $27 = ($25>>>0)<($20>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $19;
 }
 $28 = (($21) + ($29<<4)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  ;HEAP32[$28+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$a+12>>2]|0;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = HEAP32[$18>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$18>>2] = $40;
 $41 = (($21) + ($39<<4)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd4sortIPNS_10PxsCCDPairENS_16IslandPtrCompareENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$phi$trans$insert$i$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $$pre3$i$i = 0;
 var $$pre4$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0;
 var $j$02$i = 0, $j$1$i = 0, $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$77 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = (($16) + 56|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = HEAP32[$15>>2]|0;
       $20 = (($19) + 56|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($18>>>0)<($21>>>0);
       $j$0$m$0$i = $22 ? $j$02$i : $m$01$i;
       $23 = (($j$02$i) + 1)|0;
       $24 = ($j$02$i|0)<($9|0);
       if ($24) {
        $j$02$i = $23;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $25 = (($elements) + ($j$0$m$0$i<<2)|0);
      $26 = (($elements) + ($i$03$i<<2)|0);
      $27 = HEAP32[$25>>2]|0;
      $28 = HEAP32[$26>>2]|0;
      HEAP32[$25>>2] = $28;
      HEAP32[$26>>2] = $27;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $132 = ($77|0)==(0);
    if ($132) {
     break L2;
    }
    $133 = (($77) + -1)|0;
    $134 = (($$ph16) + ($133<<2)|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($77) + -2)|0;
    $137 = (($$ph16) + ($136<<2)|0);
    $138 = HEAP32[$137>>2]|0;
    $10 = $138;$77 = $136;$9 = $135;
   }
   $29 = (($9) + ($10))|0;
   $30 = (($29|0) / 2)&-1;
   $31 = (($elements) + ($30<<2)|0);
   $32 = (($elements) + ($10<<2)|0);
   $33 = HEAP32[$31>>2]|0;
   $34 = (($33) + 56|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = HEAP32[$32>>2]|0;
   $37 = (($36) + 56|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($35>>>0)<($38>>>0);
   if ($39) {
    HEAP32[$32>>2] = $33;
    HEAP32[$31>>2] = $36;
    $$pre$i$i = HEAP32[$32>>2]|0;
    $$phi$trans$insert$i$i = (($$pre$i$i) + 56|0);
    $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
    $$pre2$i$i = $$pre1$i$i;$148 = $36;$45 = $$pre$i$i;
   } else {
    $$pre2$i$i = $38;$148 = $33;$45 = $36;
   }
   $40 = (($elements) + ($9<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 56|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43>>>0)<($$pre2$i$i>>>0);
   if ($44) {
    HEAP32[$32>>2] = $41;
    HEAP32[$40>>2] = $45;
    $$pre3$i$i = HEAP32[$31>>2]|0;
    $47 = $$pre3$i$i;$50 = $$pre2$i$i;$51 = $45;
   } else {
    $47 = $148;$50 = $43;$51 = $41;
   }
   $46 = (($47) + 56|0);
   $48 = HEAP32[$46>>2]|0;
   $49 = ($50>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$31>>2] = $51;
    HEAP32[$40>>2] = $47;
    $$pre4$i$i = HEAP32[$31>>2]|0;
    $55 = $$pre4$i$i;
   } else {
    $55 = $47;
   }
   $52 = (($9) + -1)|0;
   $53 = (($elements) + ($52<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$31>>2] = $54;
   HEAP32[$53>>2] = $55;
   $57 = $55;$i$0$ph$i = $10;$j$0$ph$i = $52;
   while(1) {
    $56 = (($57) + 56|0);
    $58 = HEAP32[$56>>2]|0;
    $i$0$i = $i$0$ph$i;
    while(1) {
     $59 = (($i$0$i) + 1)|0;
     $60 = (($elements) + ($59<<2)|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($61) + 56|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63>>>0)<($58>>>0);
     if ($64) {
      $i$0$i = $59;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $65 = (($j$1$i) + -1)|0;
     $66 = (($elements) + ($65<<2)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($67) + 56|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ($58>>>0)<($69>>>0);
     if ($70) {
      $j$1$i = $65;
     } else {
      break;
     }
    }
    $71 = ($59|0)<($65|0);
    if (!($71)) {
     break;
    }
    HEAP32[$60>>2] = $67;
    HEAP32[$66>>2] = $61;
    $$pre$i1 = HEAP32[$53>>2]|0;
    $57 = $$pre$i1;$i$0$ph$i = $59;$j$0$ph$i = $65;
   }
   HEAP32[$60>>2] = $57;
   HEAP32[$53>>2] = $61;
   $72 = (($59) - ($10))|0;
   $73 = (($9) - ($59))|0;
   $74 = ($72|0)<($73|0);
   if ($74) {
    $75 = (($$ph17) + -1)|0;
    $76 = ($77>>>0)<($75>>>0);
    if ($76) {
     $101 = $$ph16;$149 = $$ph;$150 = $$ph17;
    } else {
     $78 = $$ph17 << 1;
     $79 = $$ph17 << 3;
     $80 = ($79|0)==(0);
     if ($80) {
      $92 = 0;
     } else {
      $81 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($82) + 8|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = (__Z15PxGetFoundationv()|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = (($86) + 24|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (FUNCTION_TABLE_ii[$88 & 4095]($85)|0);
      $$$i$i$i4 = $89 ? 485832 : 485568;
      $90 = (FUNCTION_TABLE_iiiiii[$84 & 255]($81,$79,$$$i$i$i4,485744,148)|0);
      $92 = $90;
     }
     $91 = $77 << 2;
     _memcpy(($92|0),($$ph16|0),($91|0))|0;
     $93 = ($$ph<<24>>24)==(0);
     $94 = ($$ph16|0)==(0|0);
     $or$cond = $93 | $94;
     if ($or$cond) {
      $101 = $92;$149 = 1;$150 = $78;
     } else {
      $95 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 12|0);
      $98 = HEAP32[$97>>2]|0;
      FUNCTION_TABLE_vii[$98 & 4095]($95,$$ph16);
      $101 = $92;$149 = 1;$150 = $78;
     }
    }
    $99 = (($77) + 1)|0;
    $100 = (($101) + ($77<<2)|0);
    HEAP32[$100>>2] = $10;
    $102 = (($101) + ($99<<2)|0);
    HEAP32[$102>>2] = $i$0$i;
    $103 = (($i$0$i) + 2)|0;
    $$ph$be = $149;$$ph16$be = $101;$$ph17$be = $150;$$ph19$be = $103;$$ph20$be = $9;
   } else {
    $104 = (($i$0$i) + 2)|0;
    $105 = (($$ph17) + -1)|0;
    $106 = ($77>>>0)<($105>>>0);
    if ($106) {
     $130 = $$ph16;$151 = $$ph;$152 = $$ph17;
    } else {
     $107 = $$ph17 << 1;
     $108 = $$ph17 << 3;
     $109 = ($108|0)==(0);
     if ($109) {
      $121 = 0;
     } else {
      $110 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = (($111) + 8|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = (__Z15PxGetFoundationv()|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = (($115) + 24|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = (FUNCTION_TABLE_ii[$117 & 4095]($114)|0);
      $$$i$i$i = $118 ? 485832 : 485568;
      $119 = (FUNCTION_TABLE_iiiiii[$113 & 255]($110,$108,$$$i$i$i,485744,148)|0);
      $121 = $119;
     }
     $120 = $77 << 2;
     _memcpy(($121|0),($$ph16|0),($120|0))|0;
     $122 = ($$ph<<24>>24)==(0);
     $123 = ($$ph16|0)==(0|0);
     $or$cond8 = $122 | $123;
     if ($or$cond8) {
      $130 = $121;$151 = 1;$152 = $107;
     } else {
      $124 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = (($125) + 12|0);
      $127 = HEAP32[$126>>2]|0;
      FUNCTION_TABLE_vii[$127 & 4095]($124,$$ph16);
      $130 = $121;$151 = 1;$152 = $107;
     }
    }
    $128 = (($77) + 1)|0;
    $129 = (($130) + ($77<<2)|0);
    HEAP32[$129>>2] = $104;
    $131 = (($130) + ($128<<2)|0);
    HEAP32[$131>>2] = $9;
    $$ph$be = $151;$$ph16$be = $130;$$ph17$be = $152;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($77) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $139 = ($$ph<<24>>24)==(0);
  $140 = ($$ph16|0)==(0|0);
  $or$cond9 = $139 | $140;
  if (!($or$cond9)) {
   $141 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = (($142) + 12|0);
   $144 = HEAP32[$143>>2]|0;
   FUNCTION_TABLE_vii[$144 & 4095]($141,$$ph16);
  }
 }
 $145 = HEAP8[$4>>0]|0;
 $146 = ($145<<24>>24)==(0);
 if ($146) {
  STACKTOP = sp;return;
 }
 $147 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$147);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_10PxsCCDBodyENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 485944 : 485568;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,485488,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPKNS_10PxsCCDBodyENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 486056 : 485568;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,485488,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_10PxsCCDPairENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 485832 : 485568;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,485488,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_10PxsCCDPairENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 485832 : 485568;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,485488,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_10PxsCCDPairELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 486456 : 485568;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,485488,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_13PxsCCDOverlapELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 486840 : 485568;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,485488,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_10PxsCCDBodyELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 487224 : 485568;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,485488,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IPKNS_12PxsRigidCoreEPKNS_12PxsShapeCoreEEEPNS_11PxsCCDShapeEEESA_NS0_4HashISA_EENS1_11HashMapBaseISA_SD_SG_NS0_9AllocatorEE6GetKeyESI_Lb1EE6createERSB_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $h$0 = 0, $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $h$0 = 0;
 } else {
  $3 = (($k) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4;
  $6 = $5 << 15;
  $7 = $6 ^ -1;
  $8 = (($5) + ($7))|0;
  $9 = $8 >>> 10;
  $10 = $9 ^ $8;
  $11 = ($10*9)|0;
  $12 = $11 >>> 6;
  $13 = $12 ^ $11;
  $14 = $13 << 11;
  $15 = $14 ^ -1;
  $16 = (($13) + ($15))|0;
  $17 = $16 >>> 16;
  $18 = $17 ^ $16;
  $19 = HEAP32[$k>>2]|0;
  $20 = $19;
  $21 = $20 << 15;
  $22 = $21 ^ -1;
  $23 = (($20) + ($22))|0;
  $24 = $23 >>> 10;
  $25 = $24 ^ $23;
  $26 = ($25*9)|0;
  $27 = $26 >>> 6;
  $28 = $27 ^ $26;
  $29 = $28 << 11;
  $30 = $29 ^ -1;
  $31 = (($28) + ($30))|0;
  $32 = $31 >>> 16;
  $33 = $31 ^ -57320555;
  $34 = $33 ^ $32;
  $35 = ($34*1000007)|0;
  $36 = $18 ^ $35;
  $37 = (($1) + -1)|0;
  $38 = $36 & $37;
  $39 = (($this) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + ($38<<2)|0);
  $index$05 = HEAP32[$41>>2]|0;
  $42 = ($index$05|0)==(-1);
  L4: do {
   if (!($42)) {
    $43 = (($this) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $46 = (($44) + (($index$06*12)|0)|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==($19|0);
     if ($48) {
      $49 = ((($44) + (($index$06*12)|0)|0) + 4|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50|0)==($4|0);
      if ($51) {
       break;
      }
     }
     $52 = HEAP32[$45>>2]|0;
     $53 = (($52) + ($index$06<<2)|0);
     $index$0 = HEAP32[$53>>2]|0;
     $54 = ($index$0|0)==(-1);
     if ($54) {
      break L4;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $55 = (($44) + (($index$06*12)|0)|0);
    $$0 = $55;
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $h$0 = $38;
 }
 HEAP8[$exists>>0] = 0;
 $56 = (($this) + 36|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($this) + 16|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($57|0)==($59|0);
 if ($60) {
  $61 = $1 << 1;
  $$$i = $2 ? 16 : $61;
  $62 = ($1>>>0)<($$$i>>>0);
  if ($62) {
   __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IPKNS_12PxsRigidCoreEPKNS_12PxsShapeCoreEEEPNS_11PxsCCDShapeEEESA_NS0_4HashISA_EENS1_11HashMapBaseISA_SD_SG_NS0_9AllocatorEE6GetKeyESI_Lb1EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $98 = $$pre;
  } else {
   $98 = $1;
  }
  $63 = (($k) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = $64;
  $66 = $65 << 15;
  $67 = $66 ^ -1;
  $68 = (($65) + ($67))|0;
  $69 = $68 >>> 10;
  $70 = $69 ^ $68;
  $71 = ($70*9)|0;
  $72 = $71 >>> 6;
  $73 = $72 ^ $71;
  $74 = $73 << 11;
  $75 = $74 ^ -1;
  $76 = (($73) + ($75))|0;
  $77 = $76 >>> 16;
  $78 = $77 ^ $76;
  $79 = HEAP32[$k>>2]|0;
  $80 = $79;
  $81 = $80 << 15;
  $82 = $81 ^ -1;
  $83 = (($80) + ($82))|0;
  $84 = $83 >>> 10;
  $85 = $84 ^ $83;
  $86 = ($85*9)|0;
  $87 = $86 >>> 6;
  $88 = $87 ^ $86;
  $89 = $88 << 11;
  $90 = $89 ^ -1;
  $91 = (($88) + ($90))|0;
  $92 = $91 >>> 16;
  $93 = $91 ^ -57320555;
  $94 = $93 ^ $92;
  $95 = ($94*1000007)|0;
  $96 = $78 ^ $95;
  $97 = (($98) + -1)|0;
  $99 = $96 & $97;
  $h$1 = $99;
 } else {
  $h$1 = $h$0;
 }
 $100 = (($this) + 28|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = (($101) + 1)|0;
 HEAP32[$100>>2] = $102;
 $103 = (($this) + 12|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + ($h$1<<2)|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = (($this) + 8|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($108) + ($101<<2)|0);
 HEAP32[$109>>2] = $106;
 HEAP32[$105>>2] = $101;
 $110 = HEAP32[$56>>2]|0;
 $111 = (($110) + 1)|0;
 HEAP32[$56>>2] = $111;
 $112 = (($this) + 32|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($113) + 1)|0;
 HEAP32[$112>>2] = $114;
 $115 = (($this) + 4|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($116) + (($101*12)|0)|0);
 $$0 = $117;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS3_IPKNS_12PxsRigidCoreEPKNS_12PxsShapeCoreEEEPNS_11PxsCCDShapeEEESA_NS0_4HashISA_EENS1_11HashMapBaseISA_SD_SG_NS0_9AllocatorEE6GetKeyESI_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $index$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = ($21*12)|0;
 $29 = (($27) + ($28))|0;
 $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$29,487416,354)|0);
 $31 = (($30) + ($22)|0);
 $32 = (($30) + ($27)|0);
 _memset(($30|0),-1,($22|0))|0;
 $33 = (($this) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 $$pre = (($this) + 4|0);
 if (!($35)) {
  $36 = (($$0) + -1)|0;
  $index$01 = 0;
  while(1) {
   $37 = HEAP32[$$pre>>2]|0;
   $38 = ((($37) + (($index$01*12)|0)|0) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = $39;
   $41 = $40 << 15;
   $42 = $41 ^ -1;
   $43 = (($40) + ($42))|0;
   $44 = $43 >>> 10;
   $45 = $44 ^ $43;
   $46 = ($45*9)|0;
   $47 = $46 >>> 6;
   $48 = $47 ^ $46;
   $49 = $48 << 11;
   $50 = $49 ^ -1;
   $51 = (($48) + ($50))|0;
   $52 = $51 >>> 16;
   $53 = $52 ^ $51;
   $54 = (($37) + (($index$01*12)|0)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = $55;
   $57 = $56 << 15;
   $58 = $57 ^ -1;
   $59 = (($56) + ($58))|0;
   $60 = $59 >>> 10;
   $61 = $60 ^ $59;
   $62 = ($61*9)|0;
   $63 = $62 >>> 6;
   $64 = $63 ^ $62;
   $65 = $64 << 11;
   $66 = $65 ^ -1;
   $67 = (($64) + ($66))|0;
   $68 = $67 >>> 16;
   $69 = $67 ^ -57320555;
   $70 = $69 ^ $68;
   $71 = ($70*1000007)|0;
   $72 = $53 ^ $71;
   $73 = $72 & $36;
   $74 = (($30) + ($73<<2)|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($31) + ($index$01<<2)|0);
   HEAP32[$76>>2] = $75;
   HEAP32[$74>>2] = $index$01;
   $77 = (($32) + (($index$01*12)|0)|0);
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    HEAP32[$77>>2] = $55;
    $79 = ((($32) + (($index$01*12)|0)|0) + 4|0);
    $80 = HEAP32[$38>>2]|0;
    HEAP32[$79>>2] = $80;
    $81 = ((($32) + (($index$01*12)|0)|0) + 8|0);
    $82 = ((($37) + (($index$01*12)|0)|0) + 8|0);
    $83 = HEAP32[$82>>2]|0;
    HEAP32[$81>>2] = $83;
   }
   $84 = (($index$01) + 1)|0;
   $85 = HEAP32[$33>>2]|0;
   $86 = ($84>>>0)<($85>>>0);
   if ($86) {
    $index$01 = $84;
   } else {
    break;
   }
  }
 }
 $87 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$87);
 HEAP32[$this>>2] = $30;
 $88 = (($this) + 12|0);
 HEAP32[$88>>2] = $30;
 $89 = (($this) + 20|0);
 HEAP32[$89>>2] = $$0;
 $90 = (($this) + 8|0);
 HEAP32[$90>>2] = $31;
 HEAP32[$$pre>>2] = $32;
 HEAP32[$15>>2] = $21;
 $91 = (($this) + 28|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(-1);
 if (!($93)) {
  STACKTOP = sp;return;
 }
 HEAP32[$91>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_16PxsCCDBlockArrayINS_11PxsCCDShapeELi128EE9BlockInfoENS0_19ReflectionAllocatorIS5_EEE15growAndPushBackERKS5_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 487688 : 485568;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,485488,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_18postCCDDepenetrateEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_18postCCDDepenetrateEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_18postCCDDepenetrateEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $j$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 7;
 $5 = (($1) + 100|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6) + ($3<<3)|0) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (0 - ($4))|0;
 $10 = ($8|0)==($9|0);
 if (!($10)) {
  $14 = $6;$j$01$i = 0;
  while(1) {
   $11 = $j$01$i & 127;
   $12 = $j$01$i >>> 7;
   $13 = (($14) + ($12<<3)|0);
   $15 = HEAP32[$13>>2]|0;
   $16 = ((($15) + (($11*20)|0)|0) + 12|0);
   HEAP32[$16>>2] = 0;
   $17 = (($j$01$i) + 1)|0;
   $18 = HEAP32[$5>>2]|0;
   $19 = ((($18) + ($3<<3)|0) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + ($4))|0;
   $22 = ($17>>>0)<($21>>>0);
   if ($22) {
    $14 = $18;$j$01$i = $17;
   } else {
    break;
   }
  }
 }
 $23 = (($1) + 128|0);
 HEAP32[$23>>2] = 0;
 $24 = (($1) + 116|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 4|0);
 HEAP32[$26>>2] = 0;
 __ZN5physx13PxsCCDContext12updateCCDEndEv($1);
 $27 = (($1) + 264|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($1) + 252|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 224|0);
 $32 = HEAP32[$31>>2]|0;
 __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($32,$30);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_14postCCDAdvanceEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_14postCCDAdvanceEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_14postCCDAdvanceEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx13PxsCCDContext14postCCDAdvanceEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_12postCCDSweepEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_12postCCDSweepEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_12postCCDSweepEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx13PxsCCDContext12postCCDSweepEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 485600 : 485568;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,485488,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<4)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
   }
   $20 = (($$012$i) + 16|0);
   $21 = (($$03$i) + 16|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx17PxsCCDAdvanceTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx17PxsCCDAdvanceTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx17PxsCCDAdvanceTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (488144|0);
}
function __ZN5physx17PxsCCDAdvanceTask11runInternalEv($this) {
 $this = $this|0;
 var $$$i$i$i$i$i = 0, $$not = 0, $$phi$trans$insert = 0, $$phi$trans$insert79 = 0, $$pr$pre = Math_fround(0), $$pre65 = Math_fround(0), $$pre77 = 0, $$pre78 = 0, $$pre80 = Math_fround(0), $$pre81 = 0, $$pre82 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0;
 var $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0);
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0;
 var $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0);
 var $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0);
 var $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $a$013 = 0, $brmerge = 0, $brmerge5 = 0, $brmerge7 = 0, $brmerge87 = 0, $dt$039 = Math_fround(0), $dt$1 = Math_fround(0), $dt$2 = Math_fround(0), $estimatePass$040 = 0, $estimatePass$1 = 0, $exitcond = 0, $exitcond59 = 0, $iFront$036 = 0, $iFront$1 = 0, $iIsland$049 = 0;
 var $index$0$lcssa = 0, $index$033 = 0, $index$033$phi = 0, $islandEnd$0$lcssa = 0, $islandEnd$0$lcssa84 = 0, $islandEnd$012 = 0, $islandStart$051 = 0, $k$0 = 0, $k$015 = 0, $k$016 = 0, $k1$0 = 0, $k1$0$in$be = 0, $k1$028 = 0, $k1$029 = 0, $kk$025 = 0, $kk$025$phi = 0, $kk3$020 = 0, $kk3$020$phi = 0, $newLastQ$i = 0, $or$cond = 0;
 var $or$cond10 = 0, $or$cond8 = 0, $or$cond86 = 0, $or$cond9 = 0, $phitmp = 0, $phitmp11 = 0, $rv$0$i$i = 0, $stepped$0$lcssa = 0, $stepped$021 = 0, $sweepTotalHits$0$lcssa = 0, $sweepTotalHits$052 = 0, $sweepTotalHits$1$lcssa = 0, $sweepTotalHits$143 = 0, $sweepTotalHits$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $newLastQ$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 104|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 224|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN5physx6shdfnd9SListImpl3popEv($5)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__Z15PxGetFoundationv()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 24|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
  $$$i$i$i$i$i = $16 ? 488336 : 485568;
  $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,9459,$$$i$i$i$i$i,488232,82)|0);
  $18 = ($17|0)==(0|0);
  if ($18) {
   $rv$0$i$i = 0;
  } else {
   $19 = (($17) + 19|0);
   $20 = $19;
   $21 = $20 & -16;
   $22 = $17;
   $23 = (($21) - ($22))|0;
   $24 = $21;
   $25 = (($24) + -4|0);
   HEAP32[$25>>2] = $23;
   $26 = $21;
   $27 = ($21|0)==(0);
   if ($27) {
    $rv$0$i$i = $26;
   } else {
    __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($26,$3);
    $rv$0$i$i = $26;
   }
  }
 } else {
  $rv$0$i$i = $6;
 }
 $28 = (($this) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 52|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + ($29))|0;
 $33 = (($this) + 56|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32>>>0)<($34>>>0);
 $36 = $35 ? $32 : $34;
 $37 = (($this) + 24|0);
 $38 = ($29>>>0)<($36>>>0);
 if (!($38)) {
  $sweepTotalHits$0$lcssa = 0;
  $389 = (($this) + 72|0);
  $390 = HEAP32[$389>>2]|0;
  (__ZN5physx6shdfnd9atomicAddEPVii($390,$sweepTotalHits$0$lcssa)|0);
  $391 = HEAP32[$2>>2]|0;
  $392 = (($391) + 224|0);
  $393 = HEAP32[$392>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($393,$rv$0$i$i);
  STACKTOP = sp;return;
 }
 $39 = (($this) + 60|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 20|0);
 $42 = (($this) + 36|0);
 $43 = (($this) + 76|0);
 $44 = (($this) + 68|0);
 $45 = (($this) + 77|0);
 $46 = (($this) + 64|0);
 $47 = (($0) + 4|0);
 $48 = (($0) + 8|0);
 $49 = (($0) + 12|0);
 $50 = (($0) + 16|0);
 $51 = (($0) + 20|0);
 $52 = (($0) + 24|0);
 $53 = (($newLastQ$i) + 4|0);
 $54 = (($newLastQ$i) + 8|0);
 $55 = (($newLastQ$i) + 12|0);
 $56 = (($newLastQ$i) + 4|0);
 $57 = (($newLastQ$i) + 8|0);
 $58 = (($newLastQ$i) + 24|0);
 $59 = (($newLastQ$i) + 28|0);
 $60 = (($newLastQ$i) + 32|0);
 $61 = (($newLastQ$i) + 16|0);
 $62 = (($newLastQ$i) + 20|0);
 $63 = (($newLastQ$i) + 64|0);
 $64 = (($newLastQ$i) + 66|0);
 $65 = (($newLastQ$i) + 56|0);
 $66 = (($newLastQ$i) + 52|0);
 $67 = (($newLastQ$i) + 60|0);
 $68 = (($newLastQ$i) + 12|0);
 $69 = (($newLastQ$i) + 48|0);
 $70 = (($newLastQ$i) + 68|0);
 $71 = (($newLastQ$i) + 36|0);
 $72 = (($newLastQ$i) + 40|0);
 $73 = (($newLastQ$i) + 44|0);
 $74 = (($this) + 32|0);
 $iIsland$049 = $29;$islandStart$051 = $40;$sweepTotalHits$052 = 0;
 while(1) {
  $75 = HEAP32[$37>>2]|0;
  $76 = ($islandStart$051>>>0)<($75>>>0);
  if (!($76)) {
   $sweepTotalHits$0$lcssa = $sweepTotalHits$052;
   label = 93;
   break;
  }
  $77 = (($islandStart$051) + 1)|0;
  $78 = ($77>>>0)<($75>>>0);
  if ($78) {
   $79 = HEAP32[$41>>2]|0;
   $islandEnd$012 = $77;
   while(1) {
    $82 = (($79) + ($islandEnd$012<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($83) + 56|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($85|0)==($iIsland$049|0);
    $81 = (($islandEnd$012) + 1)|0;
    if (!($86)) {
     $islandEnd$0$lcssa = $islandEnd$012;
     break;
    }
    $80 = ($81>>>0)<($75>>>0);
    if ($80) {
     $islandEnd$012 = $81;
    } else {
     $islandEnd$0$lcssa = $81;
     break;
    }
   }
   $87 = ($islandEnd$0$lcssa>>>0)>($77>>>0);
   if ($87) {
    $88 = HEAP32[$41>>2]|0;
    $89 = (($88) + ($islandStart$051<<2)|0);
    $90 = (($islandEnd$0$lcssa) - ($islandStart$051))|0;
    __ZN5physx6shdfnd4sortIPNS_10PxsCCDPairENS_13ToiPtrCompareENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($89,$90,$1,$newLastQ$i);
    $islandEnd$0$lcssa84 = $islandEnd$0$lcssa;
   } else {
    $islandEnd$0$lcssa84 = $islandEnd$0$lcssa;
   }
  } else {
   $islandEnd$0$lcssa84 = $77;
  }
  $91 = ($islandStart$051>>>0)<($islandEnd$0$lcssa84>>>0);
  L20: do {
   if ($91) {
    $92 = Math_fround(HEAPF32[$42>>2]);
    $93 = ($iIsland$049|0)==(0);
    $94 = (($iIsland$049) + -1)|0;
    $dt$039 = $92;$estimatePass$040 = 1;$iFront$036 = $islandStart$051;$sweepTotalHits$143 = $sweepTotalHits$052;
    while(1) {
     $95 = HEAP32[$41>>2]|0;
     $96 = (($95) + ($iFront$036<<2)|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = (($97) + 28|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     $100 = $99 > Math_fround(1.0);
     if ($100) {
      $sweepTotalHits$1$lcssa = $sweepTotalHits$143;
      break L20;
     }
     $101 = HEAP32[$97>>2]|0;
     $102 = ($101|0)==(0|0);
     if ($102) {
      $116 = 0;
     } else {
      $103 = (($101) + 60|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = (($104) + 2|0);
      $106 = HEAP16[$105>>1]|0;
      $107 = ($106<<16>>16)==(0);
      $116 = $107;
     }
     $108 = (($97) + 4|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = ($109|0)==(0|0);
     if ($110) {
      $117 = 0;
     } else {
      $111 = (($109) + 60|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = (($112) + 2|0);
      $114 = HEAP16[$113>>1]|0;
      $115 = ($114<<16>>16)==(0);
      $117 = $115;
     }
     $brmerge = $116 | $117;
     L31: do {
      if ($brmerge) {
       $118 = (($97) + 100|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==(0);
       do {
        if ($120) {
         (Math_fround(__ZN5physx10PxsCCDPair12sweepFindToiERNS_16PxsThreadContextEfj($97,$rv$0$i$i,$dt$039,0)));
         $121 = (($iFront$036) + 1)|0;
         $122 = ($121>>>0)<($islandEnd$0$lcssa84>>>0);
         if (!($122)) {
          $$pr$pre = Math_fround(HEAPF32[$98>>2]);
          $142 = $$pr$pre;
          break;
         }
         $123 = HEAP32[$41>>2]|0;
         $124 = (($123) + ($121<<2)|0);
         $125 = HEAP32[$124>>2]|0;
         $126 = (($125) + 28|0);
         $127 = Math_fround(HEAPF32[$126>>2]);
         $128 = Math_fround(HEAPF32[$98>>2]);
         $129 = $127 < $128;
         if ($129) {
          $131 = $127;$133 = $123;$134 = $125;$136 = $121;$index$033 = $iFront$036;
          while(1) {
           $130 = $131 < $128;
           if (!($130)) {
            $139 = $133;$index$0$lcssa = $index$033;
            break;
           }
           $132 = (($133) + ($index$033<<2)|0);
           HEAP32[$132>>2] = $134;
           $135 = (($136) + 1)|0;
           $137 = ($135>>>0)<($islandEnd$0$lcssa84>>>0);
           $$pre77 = HEAP32[$41>>2]|0;
           if (!($137)) {
            $139 = $$pre77;$index$0$lcssa = $136;
            break;
           }
           $$phi$trans$insert = (($$pre77) + ($135<<2)|0);
           $$pre78 = HEAP32[$$phi$trans$insert>>2]|0;
           $$phi$trans$insert79 = (($$pre78) + 28|0);
           $$pre80 = Math_fround(HEAPF32[$$phi$trans$insert79>>2]);
           $index$033$phi = $136;$131 = $$pre80;$133 = $$pre77;$134 = $$pre78;$136 = $135;$index$033 = $index$033$phi;
          }
          $138 = (($139) + ($index$0$lcssa<<2)|0);
          HEAP32[$138>>2] = $97;
          $140 = (($iFront$036) + -1)|0;
          $dt$2 = $dt$039;$estimatePass$1 = $estimatePass$040;$iFront$1 = $140;$sweepTotalHits$2 = $sweepTotalHits$143;
          break L31;
         } else {
          $142 = $128;
         }
        } else {
         $142 = $99;
        }
       } while(0);
       $141 = !($142 <= Math_fround(3.40282346638528859812E+38));
       do {
        if (!($141)) {
         $143 = (($97) + 69|0);
         $144 = HEAP8[$143>>0]|0;
         $145 = ($144<<24>>24)==(0);
         if (!($145)) {
          $146 = HEAP32[$2>>2]|0;
          $147 = (__ZNK5physx10PxsContext27getCCDContactModifyCallbackEv($146)|0);
          $148 = ($147|0)==(0|0);
          if (!($148)) {
           $149 = (($97) + 36|0);
           $150 = Math_fround(HEAPF32[$149>>2]);
           HEAPF32[$newLastQ$i>>2] = $150;
           $151 = (($97) + 40|0);
           $152 = Math_fround(HEAPF32[$151>>2]);
           HEAPF32[$56>>2] = $152;
           $153 = (($97) + 44|0);
           $154 = Math_fround(HEAPF32[$153>>2]);
           HEAPF32[$57>>2] = $154;
           $155 = (($97) + 16|0);
           $156 = Math_fround(HEAPF32[$155>>2]);
           HEAPF32[$58>>2] = $156;
           $157 = (($97) + 20|0);
           $158 = Math_fround(HEAPF32[$157>>2]);
           HEAPF32[$59>>2] = $158;
           $159 = (($97) + 24|0);
           $160 = Math_fround(HEAPF32[$159>>2]);
           HEAPF32[$60>>2] = $160;
           HEAP32[$61>>2] = -1;
           $161 = (($97) + 72|0);
           $162 = HEAP32[$161>>2]|0;
           HEAP32[$62>>2] = $162;
           $163 = (($97) + 76|0);
           $164 = HEAP16[$163>>1]|0;
           HEAP16[$63>>1] = $164;
           $165 = (($97) + 78|0);
           $166 = HEAP16[$165>>1]|0;
           HEAP16[$64>>1] = $166;
           $167 = (($97) + 80|0);
           $168 = Math_fround(HEAPF32[$167>>2]);
           HEAPF32[$65>>2] = $168;
           $169 = (($97) + 84|0);
           $170 = Math_fround(HEAPF32[$169>>2]);
           HEAPF32[$66>>2] = $170;
           $171 = (($97) + 88|0);
           $172 = Math_fround(HEAPF32[$171>>2]);
           HEAPF32[$67>>2] = $172;
           HEAPF32[$68>>2] = Math_fround(0.0);
           HEAPF32[$69>>2] = Math_fround(3.40282346638528859812E+38);
           HEAP32[$70>>2] = 0;
           HEAPF32[$71>>2] = Math_fround(0.0);
           HEAPF32[$72>>2] = Math_fround(0.0);
           HEAPF32[$73>>2] = Math_fround(0.0);
           $173 = HEAP32[$74>>2]|0;
           $174 = (($97) + 8|0);
           $175 = HEAP32[$174>>2]|0;
           $176 = HEAP32[$175>>2]|0;
           $177 = (($97) + 12|0);
           $178 = HEAP32[$177>>2]|0;
           $179 = HEAP32[$178>>2]|0;
           $180 = (($175) + 4|0);
           $181 = HEAP32[$180>>2]|0;
           $182 = (($178) + 4|0);
           $183 = HEAP32[$182>>2]|0;
           $184 = HEAP32[$97>>2]|0;
           $185 = HEAP32[$108>>2]|0;
           __ZN5physx13PxsCCDContext23runCCDModifiableContactEPNS_19PxModifiableContactEjPKNS_12PxsShapeCoreES5_PKNS_12PxsRigidCoreES8_PKNS_12PxsRigidBodyESB_($173,$newLastQ$i,1,$176,$179,$181,$183,$184,$185);
           $186 = Math_fround(HEAPF32[$69>>2]);
           $187 = $186 == Math_fround(0.0);
           if ($187) {
            HEAPF32[$98>>2] = Math_fround(3.40282346638528859812E+38);
            $dt$2 = $dt$039;$estimatePass$1 = $estimatePass$040;$iFront$1 = $iFront$036;$sweepTotalHits$2 = $sweepTotalHits$143;
            break L31;
           } else {
            $188 = Math_fround(HEAPF32[$65>>2]);
            HEAPF32[$167>>2] = $188;
            $189 = Math_fround(HEAPF32[$66>>2]);
            HEAPF32[$169>>2] = $189;
            $190 = Math_fround(HEAPF32[$67>>2]);
            HEAPF32[$171>>2] = $190;
            $191 = Math_fround(HEAPF32[$newLastQ$i>>2]);
            HEAPF32[$149>>2] = $191;
            $192 = Math_fround(HEAPF32[$56>>2]);
            HEAPF32[$151>>2] = $192;
            $193 = Math_fround(HEAPF32[$57>>2]);
            HEAPF32[$153>>2] = $193;
            $194 = Math_fround(HEAPF32[$58>>2]);
            HEAPF32[$155>>2] = $194;
            $195 = Math_fround(HEAPF32[$59>>2]);
            HEAPF32[$157>>2] = $195;
            $196 = Math_fround(HEAPF32[$60>>2]);
            HEAPF32[$159>>2] = $196;
            break;
           }
          }
         }
        }
       } while(0);
       $197 = HEAP32[$97>>2]|0;
       $198 = ($197|0)==(0|0);
       if ($198) {
        label = 38;
       } else {
        $199 = (($197) + 60|0);
        $200 = HEAP32[$199>>2]|0;
        $201 = (($200) + 2|0);
        $202 = HEAP16[$201>>1]|0;
        $203 = ($202<<16>>16)==(0);
        if ($203) {
         $213 = 0;
        } else {
         label = 38;
        }
       }
       if ((label|0) == 38) {
        label = 0;
        $phitmp = ($197|0)!=(0|0);
        $213 = $phitmp;
       }
       $204 = HEAP32[$108>>2]|0;
       $205 = ($204|0)==(0|0);
       if ($205) {
        label = 41;
       } else {
        $206 = (($204) + 60|0);
        $207 = HEAP32[$206>>2]|0;
        $208 = (($207) + 2|0);
        $209 = HEAP16[$208>>1]|0;
        $210 = ($209<<16>>16)==(0);
        if ($210) {
         $214 = 0;
        } else {
         label = 41;
        }
       }
       if ((label|0) == 41) {
        label = 0;
        $phitmp11 = ($204|0)!=(0|0);
        $214 = $phitmp11;
       }
       $211 = Math_fround(HEAPF32[$98>>2]);
       $212 = !($211 <= Math_fround(1.0));
       $brmerge5 = $212 | $213;
       $brmerge7 = $brmerge5 | $214;
       if (!($brmerge7)) {
        $215 = (($97) + 68|0);
        HEAP8[$215>>0] = 1;
       }
       $216 = HEAP8[$43>>0]|0;
       $217 = ($216<<24>>24)!=(0);
       $218 = (__ZN5physx10PxsCCDPair17sweepAdvanceToToiEfb($97,$dt$039,$217)|0);
       $219 = Math_fround(HEAPF32[$98>>2]);
       $220 = $219 < Math_fround(0.0);
       if ($220) {
        HEAPF32[$98>>2] = Math_fround(0.0);
        $222 = Math_fround(0.0);
       } else {
        $222 = $219;
       }
       $$not = $218 ^ 1;
       $221 = !($222 <= Math_fround(1.0));
       $or$cond86 = $221 | $$not;
       if ($or$cond86) {
        $dt$2 = $dt$039;$estimatePass$1 = $estimatePass$040;$iFront$1 = $iFront$036;$sweepTotalHits$2 = $sweepTotalHits$143;
       } else {
        $223 = (($sweepTotalHits$143) + 1)|0;
        $$pre81 = HEAP32[$44>>2]|0;
        if ($93) {
         $232 = 0;
        } else {
         $224 = (($$pre81) + ($94<<1)|0);
         $225 = HEAP16[$224>>1]|0;
         $226 = $225&65535;
         $232 = $226;
        }
        $227 = (($$pre81) + ($iIsland$049<<1)|0);
        $228 = HEAP16[$227>>1]|0;
        $229 = $228&65535;
        $230 = $222 > Math_fround(0.0);
        L72: do {
         if ($230) {
          $231 = ($232>>>0)<($229>>>0);
          if ($231) {
           $a$013 = $232;
           while(1) {
            $233 = HEAP32[$46>>2]|0;
            $234 = (($233) + ($a$013<<2)|0);
            $235 = HEAP32[$234>>2]|0;
            $236 = (($235) + 2|0);
            $237 = HEAP16[$236>>1]|0;
            $238 = ($237<<16>>16)==(0);
            if ($238) {
             $239 = (($235) + 8|0);
             $240 = HEAP32[$239>>2]|0;
             $241 = Math_fround(HEAPF32[$98>>2]);
             $242 = (($240) + 64|0);
             $243 = HEAP32[$242>>2]|0;
             $244 = (($243) + 124|0);
             $245 = Math_fround(HEAPF32[$244>>2]);
             $246 = $245 == Math_fround(0.0);
             if (!($246)) {
              $247 = Math_fround(Math_fround(1.0) - $241);
              $248 = (($240) + 48|0);
              $249 = Math_fround(HEAPF32[$248>>2]);
              $250 = Math_fround($247 * $249);
              $251 = (($240) + 52|0);
              $252 = Math_fround(HEAPF32[$251>>2]);
              $253 = Math_fround($247 * $252);
              $254 = (($240) + 56|0);
              $255 = Math_fround(HEAPF32[$254>>2]);
              $256 = Math_fround($247 * $255);
              $257 = (($243) + 16|0);
              $258 = Math_fround(HEAPF32[$257>>2]);
              $259 = Math_fround($241 * $258);
              $260 = (($243) + 20|0);
              $261 = Math_fround(HEAPF32[$260>>2]);
              $262 = Math_fround($241 * $261);
              $263 = (($243) + 24|0);
              $264 = Math_fround(HEAPF32[$263>>2]);
              $265 = Math_fround($241 * $264);
              $266 = Math_fround($250 + $259);
              $267 = Math_fround($253 + $262);
              $268 = Math_fround($256 + $265);
              HEAPF32[$248>>2] = $266;
              HEAPF32[$251>>2] = $267;
              HEAPF32[$254>>2] = $268;
              $269 = (($240) + 32|0);
              $270 = Math_fround(HEAPF32[$269>>2]);
              HEAPF32[$0>>2] = $270;
              $271 = (($240) + 36|0);
              $272 = Math_fround(HEAPF32[$271>>2]);
              HEAPF32[$47>>2] = $272;
              $273 = (($240) + 40|0);
              $274 = Math_fround(HEAPF32[$273>>2]);
              HEAPF32[$48>>2] = $274;
              $275 = (($240) + 44|0);
              $276 = Math_fround(HEAPF32[$275>>2]);
              HEAPF32[$49>>2] = $276;
              HEAPF32[$50>>2] = $266;
              HEAPF32[$51>>2] = $267;
              HEAPF32[$52>>2] = $268;
              __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($newLastQ$i,$241,$0,$243);
              $277 = Math_fround(HEAPF32[$newLastQ$i>>2]);
              HEAPF32[$269>>2] = $277;
              $278 = Math_fround(HEAPF32[$53>>2]);
              HEAPF32[$271>>2] = $278;
              $279 = Math_fround(HEAPF32[$54>>2]);
              HEAPF32[$273>>2] = $279;
              $280 = Math_fround(HEAPF32[$55>>2]);
              HEAPF32[$275>>2] = $280;
             }
             $281 = (($240) + 60|0);
             $282 = HEAP32[$281>>2]|0;
             $283 = (($282) + 4|0);
             $284 = Math_fround(HEAPF32[$283>>2]);
             $285 = Math_fround(HEAPF32[$98>>2]);
             $286 = Math_fround(Math_fround(1.0) - $285);
             $287 = Math_fround($284 * $286);
             $288 = $287 > Math_fround(0.00999999977648258209228);
             $289 = $288 ? $287 : Math_fround(0.00999999977648258209228);
             HEAPF32[$283>>2] = $289;
             $290 = (($282) + 16|0);
             $291 = HEAP32[$290>>2]|0;
             $292 = (($291) + 1)|0;
             HEAP32[$290>>2] = $292;
            }
            $293 = (($a$013) + 1)|0;
            $exitcond = ($293|0)==($229|0);
            if ($exitcond) {
             break;
            } else {
             $a$013 = $293;
            }
           }
           $$pre65 = Math_fround(HEAPF32[$98>>2]);
           $295 = $$pre65;
          } else {
           $295 = $222;
          }
          $294 = Math_fround($dt$039 * $295);
          $296 = Math_fround($dt$039 - $294);
          $297 = Math_fround(Math_fround(1.0) - $295);
          $298 = Math_fround(Math_fround(1.0) / $297);
          $k$015 = (($iFront$036) + 1)|0;
          $299 = ($k$015>>>0)<($islandEnd$0$lcssa84>>>0);
          if (!($299)) {
           $dt$1 = $296;
           break;
          }
          $300 = HEAP32[$41>>2]|0;
          $306 = $295;$k$016 = $k$015;
          while(1) {
           $301 = (($300) + ($k$016<<2)|0);
           $302 = HEAP32[$301>>2]|0;
           $303 = (($302) + 28|0);
           $304 = Math_fround(HEAPF32[$303>>2]);
           $305 = Math_fround($304 - $306);
           $307 = Math_fround($298 * $305);
           HEAPF32[$303>>2] = $307;
           $k$0 = (($k$016) + 1)|0;
           $exitcond59 = ($k$0|0)==($islandEnd$0$lcssa84|0);
           if ($exitcond59) {
            $dt$1 = $296;
            break L72;
           }
           $$pre82 = Math_fround(HEAPF32[$98>>2]);
           $306 = $$pre82;$k$016 = $k$0;
          }
         } else {
          $dt$1 = $dt$039;
         }
        } while(0);
        $308 = HEAP8[$45>>0]|0;
        $309 = ($308<<24>>24)==(0);
        do {
         if ($309) {
          $310 = (($97) + 52|0);
          $311 = HEAP32[$310>>2]|0;
          $312 = (($311) + 35|0);
          $313 = HEAP8[$312>>0]|0;
          $314 = ($313<<24>>24)==(0);
          if (!($314)) {
           break;
          }
          $315 = HEAP32[$97>>2]|0;
          $316 = ($315|0)==(0|0);
          if ($316) {
           $335 = 0;
          } else {
           $335 = $315;
          }
          $317 = HEAP32[$108>>2]|0;
          $318 = ($317|0)==(0|0);
          if ($318) {
           $338 = 0;
          } else {
           $338 = $317;
          }
          $k1$028 = (($iFront$036) + 1)|0;
          $319 = ($k1$028>>>0)<($islandEnd$0$lcssa84>>>0);
          if ($319) {
           $k1$029 = $k1$028;
          } else {
           break;
          }
          while(1) {
           $320 = HEAP32[$41>>2]|0;
           $321 = (($320) + ($k1$029<<2)|0);
           $322 = HEAP32[$321>>2]|0;
           $323 = HEAP32[$322>>2]|0;
           $324 = ($323|0)==(0|0);
           if ($324) {
            $325 = (($322) + 8|0);
            $326 = HEAP32[$325>>2]|0;
            $334 = $326;
           } else {
            $334 = $323;
           }
           $327 = (($322) + 4|0);
           $328 = HEAP32[$327>>2]|0;
           $329 = ($328|0)==(0|0);
           if ($329) {
            $330 = (($322) + 12|0);
            $331 = HEAP32[$330>>2]|0;
            $337 = $331;
           } else {
            $337 = $328;
           }
           $brmerge87 = $324 | $329;
           L109: do {
            if ($brmerge87) {
             $k1$0$in$be = $k1$029;
            } else {
             $333 = ($334|0)!=($335|0);
             $336 = ($337|0)==($338|0);
             $or$cond = $333 | $336;
             do {
              if ($or$cond) {
               $339 = ($337|0)!=($335|0);
               $340 = ($334|0)==($338|0);
               $or$cond8 = $339 | $340;
               if (!($or$cond8)) {
                break;
               }
               $341 = ($334|0)!=($338|0);
               $342 = ($337|0)==($335|0);
               $or$cond9 = $341 | $342;
               if (!($or$cond9)) {
                break;
               }
               $343 = ($337|0)!=($338|0);
               $344 = ($334|0)==($335|0);
               $or$cond10 = $343 | $344;
               if ($or$cond10) {
                $k1$0$in$be = $k1$029;
                break L109;
               }
              }
             } while(0);
             $345 = (($322) + 92|0);
             $346 = HEAP32[$345>>2]|0;
             $347 = ($estimatePass$040|0)==($346|0);
             if ($347) {
              $k1$0$in$be = $k1$029;
              break;
             }
             HEAP32[$345>>2] = $estimatePass$040;
             $348 = (($322) + 28|0);
             $349 = Math_fround(HEAPF32[$348>>2]);
             $350 = (Math_fround(__ZN5physx10PxsCCDPair16sweepEstimateToiEv($322)));
             $351 = $350 < $349;
             if ($351) {
              $352 = (($k1$029) + -1)|0;
              $353 = ($352>>>0)>($iFront$036>>>0);
              if ($353) {
               $356 = $352;$kk$025 = $k1$029;
              } else {
               $k1$0$in$be = $k1$029;
               break;
              }
              while(1) {
               $354 = HEAP32[$41>>2]|0;
               $355 = (($354) + ($356<<2)|0);
               $357 = HEAP32[$355>>2]|0;
               $358 = (($357) + 28|0);
               $359 = Math_fround(HEAPF32[$358>>2]);
               $360 = $359 > $350;
               if (!($360)) {
                $k1$0$in$be = $k1$029;
                break L109;
               }
               $361 = (($354) + ($kk$025<<2)|0);
               $362 = HEAP32[$361>>2]|0;
               HEAP32[$355>>2] = $362;
               $363 = HEAP32[$41>>2]|0;
               $364 = (($363) + ($kk$025<<2)|0);
               HEAP32[$364>>2] = $357;
               $365 = (($356) + -1)|0;
               $366 = ($365>>>0)>($iFront$036>>>0);
               if ($366) {
                $kk$025$phi = $356;$356 = $365;$kk$025 = $kk$025$phi;
               } else {
                $k1$0$in$be = $k1$029;
                break L109;
               }
              }
             }
             $367 = $350 > $349;
             if (!($367)) {
              $k1$0$in$be = $k1$029;
              break;
             }
             $368 = (($k1$029) + 1)|0;
             $369 = ($368>>>0)<($islandEnd$0$lcssa84>>>0);
             L124: do {
              if ($369) {
               $372 = $368;$kk3$020 = $k1$029;$stepped$021 = 0;
               while(1) {
                $370 = HEAP32[$41>>2]|0;
                $371 = (($370) + ($372<<2)|0);
                $373 = HEAP32[$371>>2]|0;
                $374 = (($373) + 28|0);
                $375 = Math_fround(HEAPF32[$374>>2]);
                $376 = $375 < $350;
                if (!($376)) {
                 $stepped$0$lcssa = $stepped$021;
                 break L124;
                }
                $377 = (($370) + ($kk3$020<<2)|0);
                $378 = HEAP32[$377>>2]|0;
                HEAP32[$371>>2] = $378;
                $379 = HEAP32[$41>>2]|0;
                $380 = (($379) + ($kk3$020<<2)|0);
                HEAP32[$380>>2] = $373;
                $381 = (($372) + 1)|0;
                $382 = ($381>>>0)<($islandEnd$0$lcssa84>>>0);
                if ($382) {
                 $kk3$020$phi = $372;$372 = $381;$stepped$021 = 1;$kk3$020 = $kk3$020$phi;
                } else {
                 $stepped$0$lcssa = 1;
                 break;
                }
               }
              } else {
               $stepped$0$lcssa = 0;
              }
             } while(0);
             $383 = (($k1$029) - ($stepped$0$lcssa))|0;
             $k1$0$in$be = $383;
            }
           } while(0);
           $k1$0 = (($k1$0$in$be) + 1)|0;
           $332 = ($k1$0>>>0)<($islandEnd$0$lcssa84>>>0);
           if ($332) {
            $k1$029 = $k1$0;
           } else {
            break;
           }
          }
         }
        } while(0);
        $384 = (($estimatePass$040) + 1)|0;
        $dt$2 = $dt$1;$estimatePass$1 = $384;$iFront$1 = $iFront$036;$sweepTotalHits$2 = $223;
       }
      } else {
       $dt$2 = $dt$039;$estimatePass$1 = $estimatePass$040;$iFront$1 = $iFront$036;$sweepTotalHits$2 = $sweepTotalHits$143;
      }
     } while(0);
     $385 = (($iFront$1) + 1)|0;
     $386 = ($385>>>0)<($islandEnd$0$lcssa84>>>0);
     if ($386) {
      $dt$039 = $dt$2;$estimatePass$040 = $estimatePass$1;$iFront$036 = $385;$sweepTotalHits$143 = $sweepTotalHits$2;
     } else {
      $sweepTotalHits$1$lcssa = $sweepTotalHits$2;
      break;
     }
    }
   } else {
    $sweepTotalHits$1$lcssa = $sweepTotalHits$052;
   }
  } while(0);
  $387 = (($iIsland$049) + 1)|0;
  $388 = ($387>>>0)<($36>>>0);
  if ($388) {
   $iIsland$049 = $387;$islandStart$051 = $islandEnd$0$lcssa84;$sweepTotalHits$052 = $sweepTotalHits$1$lcssa;
  } else {
   $sweepTotalHits$0$lcssa = $sweepTotalHits$1$lcssa;
   label = 93;
   break;
  }
 }
 if ((label|0) == 93) {
  $389 = (($this) + 72|0);
  $390 = HEAP32[$389>>2]|0;
  (__ZN5physx6shdfnd9atomicAddEPVii($390,$sweepTotalHits$0$lcssa)|0);
  $391 = HEAP32[$2>>2]|0;
  $392 = (($391) + 224|0);
  $393 = HEAP32[$392>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($393,$rv$0$i$i);
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd4sortIPNS_10PxsCCDPairENS_13ToiPtrCompareENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i9 = 0, $$ph = 0, $$ph$be = 0, $$ph22 = 0, $$ph22$be = 0, $$ph23 = 0, $$ph23$be = 0, $$ph24 = 0, $$ph24$be = 0, $$ph25 = 0, $$ph25$be = 0, $$ph26 = 0, $$ph26$be = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i3 = 0, $$pre6$i = Math_fround(0), $$pre7$i = Math_fround(0), $$pre8$i = 0;
 var $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0;
 var $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0, $m$01$i = 0, $or$cond = 0, $or$cond13 = 0, $or$cond14 = 0, $phitmp$i = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph22 = $5;$$ph23 = 32;$$ph24 = 0;$$ph25 = 0;$$ph26 = $6;
  L2: while(1) {
   $10 = $$ph25;$119 = $$ph24;$9 = $$ph26;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = (($16) + 28|0);
       $18 = Math_fround(HEAPF32[$17>>2]);
       $19 = HEAP32[$15>>2]|0;
       $20 = (($19) + 28|0);
       $21 = Math_fround(HEAPF32[$20>>2]);
       $22 = $18 < $21;
       if ($22) {
        $33 = $j$02$i;
       } else {
        $23 = $18 == $21;
        if ($23) {
         $24 = (($16) + 4|0);
         $25 = HEAP32[$24>>2]|0;
         $26 = ($25|0)==(0|0);
         if ($26) {
          $33 = $m$01$i;
         } else {
          $27 = (($19) + 4|0);
          $28 = HEAP32[$27>>2]|0;
          $29 = ($28|0)==(0|0);
          $phitmp$i = $29 ? $j$02$i : $m$01$i;
          $33 = $phitmp$i;
         }
        } else {
         $33 = $m$01$i;
        }
       }
       $30 = ($j$02$i|0)<($9|0);
       if (!($30)) {
        break;
       }
       $31 = (($j$02$i) + 1)|0;
       $j$02$i = $31;$m$01$i = $33;
      }
      $32 = (($elements) + ($33<<2)|0);
      $34 = (($elements) + ($i$03$i<<2)|0);
      $35 = HEAP32[$32>>2]|0;
      $36 = HEAP32[$34>>2]|0;
      HEAP32[$32>>2] = $36;
      HEAP32[$34>>2] = $35;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $174 = ($119|0)==(0);
    if ($174) {
     break L2;
    }
    $175 = (($119) + -1)|0;
    $176 = (($$ph22) + ($175<<2)|0);
    $177 = HEAP32[$176>>2]|0;
    $178 = (($119) + -2)|0;
    $179 = (($$ph22) + ($178<<2)|0);
    $180 = HEAP32[$179>>2]|0;
    $10 = $180;$119 = $178;$9 = $177;
   }
   $37 = (($9) + ($10))|0;
   $38 = (($37|0) / 2)&-1;
   $39 = (($elements) + ($38<<2)|0);
   $40 = (($elements) + ($10<<2)|0);
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + 28|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = HEAP32[$40>>2]|0;
   $45 = (($44) + 28|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = $43 < $46;
   if ($47) {
    label = 17;
   } else {
    $48 = $43 == $46;
    if ($48) {
     $49 = (($41) + 4|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      $$pre7$i = $46;$190 = $41;$65 = $44;
     } else {
      $52 = (($44) + 4|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==(0|0);
      if ($54) {
       label = 17;
      } else {
       $$pre7$i = $46;$190 = $41;$65 = $44;
      }
     }
    } else {
     $$pre7$i = $46;$190 = $41;$65 = $44;
    }
   }
   if ((label|0) == 17) {
    label = 0;
    HEAP32[$40>>2] = $41;
    HEAP32[$39>>2] = $44;
    $$pre$i3 = HEAP32[$40>>2]|0;
    $$phi$trans$insert$i = (($$pre$i3) + 28|0);
    $$pre6$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
    $$pre7$i = $$pre6$i;$190 = $44;$65 = $$pre$i3;
   }
   $55 = (($elements) + ($9<<2)|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 28|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = $58 < $$pre7$i;
   if ($59) {
    label = 22;
   } else {
    $60 = $58 == $$pre7$i;
    if ($60) {
     $61 = (($56) + 4|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($62|0)==(0|0);
     if ($63) {
      $69 = $190;$72 = $58;$75 = $56;
     } else {
      $64 = (($65) + 4|0);
      $66 = HEAP32[$64>>2]|0;
      $67 = ($66|0)==(0|0);
      if ($67) {
       label = 22;
      } else {
       $69 = $190;$72 = $58;$75 = $56;
      }
     }
    } else {
     $69 = $190;$72 = $58;$75 = $56;
    }
   }
   if ((label|0) == 22) {
    label = 0;
    HEAP32[$40>>2] = $56;
    HEAP32[$55>>2] = $65;
    $$pre8$i = HEAP32[$39>>2]|0;
    $69 = $$pre8$i;$72 = $$pre7$i;$75 = $65;
   }
   $68 = (($69) + 28|0);
   $70 = Math_fround(HEAPF32[$68>>2]);
   $71 = $72 < $70;
   if ($71) {
    label = 27;
   } else {
    $73 = $72 == $70;
    if ($73) {
     $74 = (($75) + 4|0);
     $76 = HEAP32[$74>>2]|0;
     $77 = ($76|0)==(0|0);
     if ($77) {
      $84 = $69;
     } else {
      $78 = (($69) + 4|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = ($79|0)==(0|0);
      if ($80) {
       label = 27;
      } else {
       $84 = $69;
      }
     }
    } else {
     $84 = $69;
    }
   }
   if ((label|0) == 27) {
    label = 0;
    HEAP32[$39>>2] = $75;
    HEAP32[$55>>2] = $69;
    $$pre9$i = HEAP32[$39>>2]|0;
    $84 = $$pre9$i;
   }
   $81 = (($9) + -1)|0;
   $82 = (($elements) + ($81<<2)|0);
   $83 = HEAP32[$82>>2]|0;
   HEAP32[$39>>2] = $83;
   HEAP32[$82>>2] = $84;
   $86 = $84;$i$0$ph$i = $10;$j$0$ph$i = $81;
   while(1) {
    $85 = (($86) + 28|0);
    $87 = Math_fround(HEAPF32[$85>>2]);
    $88 = (($86) + 4|0);
    $i$0$i = $i$0$ph$i;
    while(1) {
     $89 = (($i$0$i) + 1)|0;
     $90 = (($elements) + ($89<<2)|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = (($91) + 28|0);
     $93 = Math_fround(HEAPF32[$92>>2]);
     $94 = $93 < $87;
     if ($94) {
      $i$0$i = $89;
      continue;
     }
     $95 = $93 == $87;
     if (!($95)) {
      $j$1$i = $j$0$ph$i;
      break;
     }
     $96 = (($91) + 4|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = ($97|0)==(0|0);
     if ($98) {
      $j$1$i = $j$0$ph$i;
      break;
     }
     $99 = HEAP32[$88>>2]|0;
     $100 = ($99|0)==(0|0);
     if ($100) {
      $i$0$i = $89;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $101 = (($j$1$i) + -1)|0;
     $102 = (($elements) + ($101<<2)|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = (($103) + 28|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = $87 < $105;
     if ($106) {
      $j$1$i = $101;
      continue;
     }
     $107 = $87 == $105;
     if (!($107)) {
      break;
     }
     $108 = HEAP32[$88>>2]|0;
     $109 = ($108|0)==(0|0);
     if ($109) {
      break;
     }
     $110 = (($103) + 4|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ($111|0)==(0|0);
     if ($112) {
      $j$1$i = $101;
     } else {
      break;
     }
    }
    $113 = ($89|0)<($101|0);
    if (!($113)) {
     break;
    }
    HEAP32[$90>>2] = $103;
    HEAP32[$102>>2] = $91;
    $$pre = HEAP32[$82>>2]|0;
    $86 = $$pre;$i$0$ph$i = $89;$j$0$ph$i = $101;
   }
   HEAP32[$90>>2] = $86;
   HEAP32[$82>>2] = $91;
   $114 = (($89) - ($10))|0;
   $115 = (($9) - ($89))|0;
   $116 = ($114|0)<($115|0);
   if ($116) {
    $117 = (($$ph23) + -1)|0;
    $118 = ($119>>>0)<($117>>>0);
    if ($118) {
     $143 = $$ph22;$191 = $$ph;$192 = $$ph23;
    } else {
     $120 = $$ph23 << 1;
     $121 = $$ph23 << 3;
     $122 = ($121|0)==(0);
     if ($122) {
      $134 = 0;
     } else {
      $123 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = (($124) + 8|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = (__Z15PxGetFoundationv()|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = (($128) + 24|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = (FUNCTION_TABLE_ii[$130 & 4095]($127)|0);
      $$$i$i$i9 = $131 ? 485832 : 485568;
      $132 = (FUNCTION_TABLE_iiiiii[$126 & 255]($123,$121,$$$i$i$i9,485744,148)|0);
      $134 = $132;
     }
     $133 = $119 << 2;
     _memcpy(($134|0),($$ph22|0),($133|0))|0;
     $135 = ($$ph<<24>>24)==(0);
     $136 = ($$ph22|0)==(0|0);
     $or$cond = $135 | $136;
     if ($or$cond) {
      $143 = $134;$191 = 1;$192 = $120;
     } else {
      $137 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = (($138) + 12|0);
      $140 = HEAP32[$139>>2]|0;
      FUNCTION_TABLE_vii[$140 & 4095]($137,$$ph22);
      $143 = $134;$191 = 1;$192 = $120;
     }
    }
    $141 = (($119) + 1)|0;
    $142 = (($143) + ($119<<2)|0);
    HEAP32[$142>>2] = $10;
    $144 = (($143) + ($141<<2)|0);
    HEAP32[$144>>2] = $i$0$i;
    $145 = (($i$0$i) + 2)|0;
    $$ph$be = $191;$$ph22$be = $143;$$ph23$be = $192;$$ph25$be = $145;$$ph26$be = $9;
   } else {
    $146 = (($i$0$i) + 2)|0;
    $147 = (($$ph23) + -1)|0;
    $148 = ($119>>>0)<($147>>>0);
    if ($148) {
     $172 = $$ph22;$193 = $$ph;$194 = $$ph23;
    } else {
     $149 = $$ph23 << 1;
     $150 = $$ph23 << 3;
     $151 = ($150|0)==(0);
     if ($151) {
      $163 = 0;
     } else {
      $152 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $153 = HEAP32[$152>>2]|0;
      $154 = (($153) + 8|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = (__Z15PxGetFoundationv()|0);
      $157 = HEAP32[$156>>2]|0;
      $158 = (($157) + 24|0);
      $159 = HEAP32[$158>>2]|0;
      $160 = (FUNCTION_TABLE_ii[$159 & 4095]($156)|0);
      $$$i$i$i = $160 ? 485832 : 485568;
      $161 = (FUNCTION_TABLE_iiiiii[$155 & 255]($152,$150,$$$i$i$i,485744,148)|0);
      $163 = $161;
     }
     $162 = $119 << 2;
     _memcpy(($163|0),($$ph22|0),($162|0))|0;
     $164 = ($$ph<<24>>24)==(0);
     $165 = ($$ph22|0)==(0|0);
     $or$cond13 = $164 | $165;
     if ($or$cond13) {
      $172 = $163;$193 = 1;$194 = $149;
     } else {
      $166 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = (($167) + 12|0);
      $169 = HEAP32[$168>>2]|0;
      FUNCTION_TABLE_vii[$169 & 4095]($166,$$ph22);
      $172 = $163;$193 = 1;$194 = $149;
     }
    }
    $170 = (($119) + 1)|0;
    $171 = (($172) + ($119<<2)|0);
    HEAP32[$171>>2] = $146;
    $173 = (($172) + ($170<<2)|0);
    HEAP32[$173>>2] = $9;
    $$ph$be = $193;$$ph22$be = $172;$$ph23$be = $194;$$ph25$be = $10;$$ph26$be = $i$0$i;
   }
   $$ph24$be = (($119) + 2)|0;
   $$ph = $$ph$be;$$ph22 = $$ph22$be;$$ph23 = $$ph23$be;$$ph24 = $$ph24$be;$$ph25 = $$ph25$be;$$ph26 = $$ph26$be;
  }
  $181 = ($$ph<<24>>24)==(0);
  $182 = ($$ph22|0)==(0|0);
  $or$cond14 = $181 | $182;
  if (!($or$cond14)) {
   $183 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = (($184) + 12|0);
   $186 = HEAP32[$185>>2]|0;
   FUNCTION_TABLE_vii[$186 & 4095]($183,$$ph22);
  }
 }
 $187 = HEAP8[$4>>0]|0;
 $188 = ($187<<24>>24)==(0);
 if ($188) {
  STACKTOP = sp;return;
 }
 $189 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$189);
 STACKTOP = sp;return;
}
function __ZN5physx15PxsCCDSweepTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx15PxsCCDSweepTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx15PxsCCDSweepTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (488216|0);
}
function __ZN5physx15PxsCCDSweepTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 20|0);
 $j$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($j$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  (Math_fround(__ZN5physx10PxsCCDPair16sweepEstimateToiEv($6)));
  $7 = (($6) + 92|0);
  HEAP32[$7>>2] = 0;
  $8 = (($j$01) + 1)|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = ($8>>>0)<($9>>>0);
  if ($10) {
   $j$01 = $8;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx24PxsSetupSolverConstraintEPKNS_13PxsConstraintEPNS_17PxcSolverBodyDataERNS_24PxcConstraintBlockStreamEffRNS_23PxcSolverConstraintDescERNS_25PxsConstraintBlockManagerE($constraint,$solverBodyDataArray,$blockStream,$dt,$recipdt,$desc,$constraintBlockManager) {
 $constraint = $constraint|0;
 $solverBodyDataArray = $solverBodyDataArray|0;
 $blockStream = $blockStream|0;
 $dt = Math_fround($dt);
 $recipdt = Math_fround($recipdt);
 $desc = $desc|0;
 $constraintBlockManager = $constraintBlockManager|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 28|0;
 $1 = sp;
 $2 = (($constraint) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($constraint) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($constraint) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($constraint) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  HEAPF32[$0>>2] = Math_fround(0.0);
  $32 = (($0) + 4|0);
  HEAPF32[$32>>2] = Math_fround(0.0);
  $33 = (($0) + 8|0);
  HEAPF32[$33>>2] = Math_fround(0.0);
  $34 = (($0) + 12|0);
  HEAPF32[$34>>2] = Math_fround(1.0);
  $35 = (($0) + 16|0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  $36 = (($0) + 20|0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $37 = (($0) + 24|0);
  HEAPF32[$37>>2] = Math_fround(0.0);
 } else {
  $11 = (($9) + 64|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$0>>2] = $13;
  $14 = (($0) + 4|0);
  $15 = (($12) + 4|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$14>>2] = $16;
  $17 = (($0) + 8|0);
  $18 = (($12) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$17>>2] = $19;
  $20 = (($0) + 12|0);
  $21 = (($12) + 12|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$20>>2] = $22;
  $23 = (($0) + 16|0);
  $24 = (($12) + 16|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$23>>2] = $25;
  $26 = (($0) + 20|0);
  $27 = (($12) + 20|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$26>>2] = $28;
  $29 = (($0) + 24|0);
  $30 = (($12) + 24|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$29>>2] = $31;
 }
 $38 = (($constraint) + 40|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  HEAPF32[$1>>2] = Math_fround(0.0);
  $62 = (($1) + 4|0);
  HEAPF32[$62>>2] = Math_fround(0.0);
  $63 = (($1) + 8|0);
  HEAPF32[$63>>2] = Math_fround(0.0);
  $64 = (($1) + 12|0);
  HEAPF32[$64>>2] = Math_fround(1.0);
  $65 = (($1) + 16|0);
  HEAPF32[$65>>2] = Math_fround(0.0);
  $66 = (($1) + 20|0);
  HEAPF32[$66>>2] = Math_fround(0.0);
  $67 = (($1) + 24|0);
  HEAPF32[$67>>2] = Math_fround(0.0);
 } else {
  $41 = (($39) + 64|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = Math_fround(HEAPF32[$42>>2]);
  HEAPF32[$1>>2] = $43;
  $44 = (($1) + 4|0);
  $45 = (($42) + 4|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$44>>2] = $46;
  $47 = (($1) + 8|0);
  $48 = (($42) + 8|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  HEAPF32[$47>>2] = $49;
  $50 = (($1) + 12|0);
  $51 = (($42) + 12|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  HEAPF32[$50>>2] = $52;
  $53 = (($1) + 16|0);
  $54 = (($42) + 16|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  HEAPF32[$53>>2] = $55;
  $56 = (($1) + 20|0);
  $57 = (($42) + 20|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$56>>2] = $58;
  $59 = (($1) + 24|0);
  $60 = (($42) + 24|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  HEAPF32[$59>>2] = $61;
 }
 $68 = HEAP32[$desc>>2]|0;
 $69 = (($desc) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($desc) + 8|0);
 $72 = HEAP16[$71>>1]|0;
 $73 = ($72<<16>>16)==(-1);
 if ($73) {
  $74 = (($desc) + 10|0);
  $75 = HEAP16[$74>>1]|0;
  $76 = $75&65535;
  $78 = $76;
 } else {
  $78 = 0;
 }
 $77 = (($solverBodyDataArray) + ($78<<6)|0);
 $79 = (($desc) + 12|0);
 $80 = HEAP16[$79>>1]|0;
 $81 = ($80<<16>>16)==(-1);
 if (!($81)) {
  $86 = 0;
  $85 = (($solverBodyDataArray) + ($86<<6)|0);
  $87 = (__ZN5physx19PxsConstraintHelper21setupSolverConstraintERKNS_11PxTransformES3_PKNS_13PxcSolverBodyES6_PNS_17PxcSolverBodyDataES8_PFjPNS_14Px1DConstraintERNS_6PxVec3EjRNS_24PxConstraintInvMassScaleEPKvS3_S3_ESG_jffRNS_23PxcSolverConstraintDescERKNS_13PxsConstraintERNS_24PxcConstraintBlockStreamERNS_25PxsConstraintBlockManagerE($0,$1,$68,$70,$77,$85,$3,$5,$7,$dt,$recipdt,$desc,$constraint,$blockStream,$constraintBlockManager)|0);
  STACKTOP = sp;return ($87|0);
 }
 $82 = (($desc) + 14|0);
 $83 = HEAP16[$82>>1]|0;
 $84 = $83&65535;
 $86 = $84;
 $85 = (($solverBodyDataArray) + ($86<<6)|0);
 $87 = (__ZN5physx19PxsConstraintHelper21setupSolverConstraintERKNS_11PxTransformES3_PKNS_13PxcSolverBodyES6_PNS_17PxcSolverBodyDataES8_PFjPNS_14Px1DConstraintERNS_6PxVec3EjRNS_24PxConstraintInvMassScaleEPKvS3_S3_ESG_jffRNS_23PxcSolverConstraintDescERKNS_13PxsConstraintERNS_24PxcConstraintBlockStreamERNS_25PxsConstraintBlockManagerE($0,$1,$68,$70,$77,$85,$3,$5,$7,$dt,$recipdt,$desc,$constraint,$blockStream,$constraintBlockManager)|0);
 STACKTOP = sp;return ($87|0);
}
function __ZN5physx20PxsConstraintProjectEPKNS_13PxsConstraintEbf($constraint,$projectToBody0,$0) {
 $constraint = $constraint|0;
 $projectToBody0 = $projectToBody0|0;
 $0 = Math_fround($0);
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0);
 var $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0);
 var $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0);
 var $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $body0ToWorld = 0, $body1ToWorld = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $body0ToWorld = sp + 28|0;
 $body1ToWorld = sp;
 $1 = (($constraint) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($constraint) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==(0|0);
 if ($5) {
  HEAPF32[$body0ToWorld>>2] = Math_fround(0.0);
  $27 = (($body0ToWorld) + 4|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  $28 = (($body0ToWorld) + 8|0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  $29 = (($body0ToWorld) + 12|0);
  HEAPF32[$29>>2] = Math_fround(1.0);
  $30 = (($body0ToWorld) + 16|0);
  HEAPF32[$30>>2] = Math_fround(0.0);
  $31 = (($body0ToWorld) + 20|0);
  HEAPF32[$31>>2] = Math_fround(0.0);
  $32 = (($body0ToWorld) + 24|0);
  HEAPF32[$32>>2] = Math_fround(0.0);
 } else {
  $6 = (($2) + 64|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$body0ToWorld>>2] = $8;
  $9 = (($body0ToWorld) + 4|0);
  $10 = (($7) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$9>>2] = $11;
  $12 = (($body0ToWorld) + 8|0);
  $13 = (($7) + 8|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$12>>2] = $14;
  $15 = (($body0ToWorld) + 12|0);
  $16 = (($7) + 12|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$15>>2] = $17;
  $18 = (($body0ToWorld) + 16|0);
  $19 = (($7) + 16|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$18>>2] = $20;
  $21 = (($body0ToWorld) + 20|0);
  $22 = (($7) + 20|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$21>>2] = $23;
  $24 = (($body0ToWorld) + 24|0);
  $25 = (($7) + 24|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$24>>2] = $26;
 }
 $33 = ($4|0)==(0|0);
 if ($33) {
  HEAPF32[$body1ToWorld>>2] = Math_fround(0.0);
  $55 = (($body1ToWorld) + 4|0);
  HEAPF32[$55>>2] = Math_fround(0.0);
  $56 = (($body1ToWorld) + 8|0);
  HEAPF32[$56>>2] = Math_fround(0.0);
  $57 = (($body1ToWorld) + 12|0);
  HEAPF32[$57>>2] = Math_fround(1.0);
  $58 = (($body1ToWorld) + 16|0);
  HEAPF32[$58>>2] = Math_fround(0.0);
  $59 = (($body1ToWorld) + 20|0);
  HEAPF32[$59>>2] = Math_fround(0.0);
  $60 = (($body1ToWorld) + 24|0);
  HEAPF32[$60>>2] = Math_fround(0.0);
 } else {
  $34 = (($4) + 64|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$body1ToWorld>>2] = $36;
  $37 = (($body1ToWorld) + 4|0);
  $38 = (($35) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[$37>>2] = $39;
  $40 = (($body1ToWorld) + 8|0);
  $41 = (($35) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$40>>2] = $42;
  $43 = (($body1ToWorld) + 12|0);
  $44 = (($35) + 12|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$43>>2] = $45;
  $46 = (($body1ToWorld) + 16|0);
  $47 = (($35) + 16|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  HEAPF32[$46>>2] = $48;
  $49 = (($body1ToWorld) + 20|0);
  $50 = (($35) + 20|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  HEAPF32[$49>>2] = $51;
  $52 = (($body1ToWorld) + 24|0);
  $53 = (($35) + 24|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  HEAPF32[$52>>2] = $54;
 }
 $61 = (($constraint) + 20|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($constraint) + 28|0);
 $64 = HEAP32[$63>>2]|0;
 FUNCTION_TABLE_viiii[$62 & 511]($64,$body0ToWorld,$body1ToWorld,$projectToBody0);
 if ($projectToBody0) {
  $65 = (($4) + 64|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = Math_fround(HEAPF32[$body1ToWorld>>2]);
  HEAPF32[$66>>2] = $67;
  $68 = (($body1ToWorld) + 4|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($66) + 4|0);
  HEAPF32[$70>>2] = $69;
  $71 = (($body1ToWorld) + 8|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($66) + 8|0);
  HEAPF32[$73>>2] = $72;
  $74 = (($body1ToWorld) + 12|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = (($66) + 12|0);
  HEAPF32[$76>>2] = $75;
  $77 = (($body1ToWorld) + 16|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($66) + 16|0);
  HEAPF32[$79>>2] = $78;
  $80 = (($body1ToWorld) + 20|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($66) + 20|0);
  HEAPF32[$82>>2] = $81;
  $83 = (($body1ToWorld) + 24|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = (($66) + 24|0);
  HEAPF32[$85>>2] = $84;
  STACKTOP = sp;return;
 } else {
  $86 = (($2) + 64|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = Math_fround(HEAPF32[$body0ToWorld>>2]);
  HEAPF32[$87>>2] = $88;
  $89 = (($body0ToWorld) + 4|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = (($87) + 4|0);
  HEAPF32[$91>>2] = $90;
  $92 = (($body0ToWorld) + 8|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = (($87) + 8|0);
  HEAPF32[$94>>2] = $93;
  $95 = (($body0ToWorld) + 12|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = (($87) + 12|0);
  HEAPF32[$97>>2] = $96;
  $98 = (($body0ToWorld) + 16|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = (($87) + 16|0);
  HEAPF32[$100>>2] = $99;
  $101 = (($body0ToWorld) + 20|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = (($87) + 20|0);
  HEAPF32[$103>>2] = $102;
  $104 = (($body0ToWorld) + 24|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = (($87) + 24|0);
  HEAPF32[$106>>2] = $105;
  STACKTOP = sp;return;
 }
}
function __ZN5physx27PartitionContactConstraintsERNS_23ConstraintPartitionArgsE($args) {
 $args = $args|0;
 var $$$i = 0, $$$i42 = 0, $$$i47 = 0, $$$i58 = 0, $$demorgan$i = 0, $$demorgan$i33 = 0, $$demorgan$i43 = 0, $$demorgan$i60 = 0, $$pn$i = 0, $$pn$i51 = 0, $$pn$in$i = 0, $$pn$in$i50 = 0, $$pn$in$in$i = 0, $$pn$in$in$i49 = 0, $$pre = 0, $$sink$i = 0, $$sink$i53 = 0, $$sink$in$i = 0, $$sink$in$i52 = 0, $$sum = 0;
 var $$sum$i = 0, $$sum$i45 = 0, $$sum1$i = 0, $$sum5$i = 0, $$sum64 = 0, $$sum65 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0;
 var $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0;
 var $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0;
 var $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0;
 var $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0;
 var $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0;
 var $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0;
 var $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0;
 var $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_eaFsData = 0, $a$086 = 0, $a1$071 = 0, $a11$067 = 0, $a2$070 = 0, $a6$081 = 0, $a7$078 = 0, $accumulatedConstraintsPerPartition = 0, $accumulation$072 = 0, $accumulation5$080 = 0, $availablePartition$0$i = 0, $availablePartition$0$i21 = 0, $availablePartition$012$i = 0, $availablePartition$012$i55 = 0, $availablePartition$013$i = 0, $availablePartition$014$i = 0, $bBodyA$0$off0$i = 0, $bBodyA$0$off0$i18 = 0, $bBodyA$0$off0$i30 = 0, $bBodyA$0$off0$i7 = 0;
 var $bBodyB$0$off0$i = 0, $bBodyB$0$off0$i19 = 0, $bBodyB$0$off0$i31 = 0, $bBodyB$0$off0$i6 = 0, $brmerge$demorgan$i = 0, $brmerge$demorgan$i20 = 0, $brmerge$demorgan$i32 = 0, $brmerge$demorgan$i8 = 0, $brmerge3$i = 0, $brmerge3$i22 = 0, $desc$02$i = 0, $desc$03$i = 0, $desc$06$i = 0, $desc$07$i = 0, $desc$07$i36 = 0, $desc$08$i = 0, $desc$08$i12 = 0, $desc$08$i2 = 0, $exitcond = 0, $exitcond$i = 0;
 var $exitcond$i10 = 0, $exitcond$i24 = 0, $exitcond$i34 = 0, $exitcond$i40 = 0, $exitcond$i46 = 0, $exitcond$i57 = 0, $exitcond$i61 = 0, $exitcond90 = 0, $exitcond91 = 0, $exitcond92 = 0, $exitcond93 = 0, $exitcond94 = 0, $exitcond95 = 0, $exitcond96 = 0, $i$01$i = 0, $i$02$i = 0, $i$05$i = 0, $i$06$i = 0, $i$06$i25 = 0, $i$06$i37 = 0;
 var $i$07$i = 0, $i$07$i13 = 0, $i$082 = 0, $i9$074 = 0, $maxPartition$0$a11$0 = 0, $maxPartition$068 = 0, $numConstraintsPerPartition = 0, $numOrderedConstraints$0 = 0, $numWrittenConstraints$0$lcssa$i = 0, $numWrittenConstraints$0$lcssa$i1163 = 0, $numWrittenConstraints$012$i = 0, $numWrittenConstraints$07$i = 0, $numWrittenConstraints$1$i = 0, $numWrittenConstraints$1$i9 = 0, $or$cond$i = 0, $or$cond$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $numConstraintsPerPartition = sp + 144|0;
 $accumulatedConstraintsPerPartition = sp;
 $_eaFsData = sp + 136|0;
 $0 = sp + 276|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$args>>2]|0;
 $4 = $3;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 _memset(($numConstraintsPerPartition|0),0,132)|0;
 $15 = ($2|0)==(0);
 L1: do {
  if (!($15)) {
   $17 = $3;$a$086 = 0;
   while(1) {
    $$sum65 = (($a$086) + 8)|0;
    $16 = (($17) + ($$sum65<<5)|0);
    $18 = ((($17) + ($a$086<<5)|0) + 28|0);
    HEAP32[$18>>2] = 0;
    $19 = ((($17) + ($a$086<<5)|0) + 12|0);
    HEAP16[$19>>1] = 0;
    $20 = (($a$086) + 1)|0;
    $exitcond96 = ($20|0)==($2|0);
    if ($exitcond96) {
     break L1;
    }
    $$pre = HEAP32[$args>>2]|0;
    $17 = $$pre;$a$086 = $20;
   }
  }
 } while(0);
 $21 = ($6|0)==(0);
 if ($21) {
  $22 = (($10) + -1)|0;
  $23 = ($10|0)==(0);
  if (!($23)) {
   $desc$02$i = $12;$i$01$i = 0;
   while(1) {
    $24 = (($22) - ($i$01$i))|0;
    $25 = ($24>>>0)<(4);
    $26 = $25 ? $24 : 4;
    $27 = ((($desc$02$i) + ($26<<5)|0) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($desc$02$i) + ($26<<5)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ((($desc$02$i) + ($26<<5)|0) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($desc$02$i) + 256|0);
    $34 = HEAP32[$desc$02$i>>2]|0;
    $35 = $34;
    $36 = (($35) - ($4))|0;
    $37 = $36 >>> 5;
    $38 = (($desc$02$i) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = $39;
    $41 = (($40) - ($4))|0;
    $42 = $41 >>> 5;
    $43 = ($37>>>0)<($2>>>0);
    $44 = ($42>>>0)<($2>>>0);
    $$$i58 = $43 & $44;
    if ($$$i58) {
     $45 = (($34) + 28|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($39) + 28|0);
     $48 = HEAP32[$47>>2]|0;
     $$demorgan$i60 = $48 | $46;
     $49 = ($$demorgan$i60|0)==(-1);
     if (!($49)) {
      $50 = $$demorgan$i60 ^ -1;
      $51 = (($$demorgan$i60) + 1)|0;
      $52 = $51 & $50;
      $53 = Math_imul($52, 125613361)|0;
      $54 = $53 >>> 27;
      $55 = (412480 + ($54<<2)|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = 1 << $56;
      $58 = $57 | $48;
      $59 = $57 | $46;
      HEAP32[$45>>2] = $59;
      HEAP32[$47>>2] = $58;
      $60 = (($numConstraintsPerPartition) + ($56<<2)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = (($61) + 1)|0;
      HEAP32[$60>>2] = $62;
     }
    }
    $63 = (($i$01$i) + 1)|0;
    $64 = (($desc$02$i) + 32|0);
    $exitcond$i61 = ($63|0)==($10|0);
    if ($exitcond$i61) {
     $desc$06$i = $12;$i$05$i = 0;
     break;
    } else {
     $desc$02$i = $64;$i$01$i = $63;
    }
   }
   while(1) {
    $65 = (($22) - ($i$05$i))|0;
    $66 = ($65>>>0)<(4);
    $67 = $66 ? $65 : 4;
    $68 = ((($desc$06$i) + ($67<<5)|0) + 16|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($desc$06$i) + ($67<<5)|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ((($desc$06$i) + ($67<<5)|0) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($desc$06$i) + 256|0);
    $75 = HEAP32[$desc$06$i>>2]|0;
    $76 = $75;
    $77 = (($76) - ($4))|0;
    $78 = $77 >>> 5;
    $79 = (($desc$06$i) + 4|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = $80;
    $82 = (($81) - ($4))|0;
    $83 = $82 >>> 5;
    $84 = ($78>>>0)<($2>>>0);
    $85 = ($83>>>0)<($2>>>0);
    $$$i47 = $84 & $85;
    do {
     if (!($$$i47)) {
      $86 = ($78>>>0)>=($2>>>0);
      if ($84) {
       $87 = (($75) + 28|0);
       $88 = HEAP32[$87>>2]|0;
       $104 = $88;
      } else {
       $104 = -1;
      }
      if ($85) {
       $89 = (($80) + 28|0);
       $90 = HEAP32[$89>>2]|0;
       $92 = $90;
      } else {
       $92 = -1;
      }
      do {
       if ($86) {
        $91 = ($92|0)==(0);
        if ($91) {
         $124 = 1;$availablePartition$012$i55 = 0;
        } else {
         $93 = $92 >>> 1;
         $94 = $93 | $92;
         $95 = $94 >>> 2;
         $96 = $95 | $94;
         $97 = $96 >>> 4;
         $98 = $97 | $96;
         $99 = $98 >>> 8;
         $100 = $99 | $98;
         $101 = $100 >>> 16;
         $102 = $101 | $100;
         $$pn$in$in$i49 = $102;
         label = 21;
        }
       } else {
        $103 = ($104|0)==(0);
        if ($103) {
         $105 = $92 | 1;
         $121 = 1;$632 = $105;$availablePartition$014$i = 0;
         label = 23;
         break;
        } else {
         $106 = $104 >>> 1;
         $107 = $106 | $104;
         $108 = $107 >>> 2;
         $109 = $108 | $107;
         $110 = $109 >>> 4;
         $111 = $110 | $109;
         $112 = $111 >>> 8;
         $113 = $112 | $111;
         $114 = $113 >>> 16;
         $115 = $114 | $113;
         $$pn$in$in$i49 = $115;
         label = 21;
         break;
        }
       }
      } while(0);
      if ((label|0) == 21) {
       label = 0;
       $$pn$in$i50 = Math_imul($$pn$in$in$i49, 130329821)|0;
       $$pn$i51 = $$pn$in$i50 >>> 27;
       $$sink$in$i52 = (482344 + ($$pn$i51<<2)|0);
       $$sink$i53 = HEAP32[$$sink$in$i52>>2]|0;
       $116 = (($$sink$i53) + 1)|0;
       $117 = ($116|0)==(32);
       if ($117) {
        break;
       }
       $118 = 1 << $116;
       $119 = $118 | $92;
       if ($86) {
        $124 = $119;$availablePartition$012$i55 = $116;
       } else {
        $121 = $118;$632 = $119;$availablePartition$014$i = $116;
        label = 23;
       }
      }
      if ((label|0) == 23) {
       label = 0;
       $120 = $121 | $104;
       $122 = (($75) + 28|0);
       HEAP32[$122>>2] = $120;
       $124 = $632;$availablePartition$012$i55 = $availablePartition$014$i;
      }
      if ($85) {
       $123 = (($80) + 28|0);
       HEAP32[$123>>2] = $124;
      }
      $125 = ($availablePartition$012$i55>>>0)<(32);
      if ($125) {
       $126 = (($numConstraintsPerPartition) + ($availablePartition$012$i55<<2)|0);
       $127 = HEAP32[$126>>2]|0;
       $128 = (($127) + 1)|0;
       HEAP32[$126>>2] = $128;
      }
     }
    } while(0);
    $129 = (($i$05$i) + 1)|0;
    $130 = (($desc$06$i) + 32|0);
    $exitcond$i57 = ($129|0)==($10|0);
    if ($exitcond$i57) {
     break;
    } else {
     $desc$06$i = $130;$i$05$i = $129;
    }
   }
  }
  $a1$071 = 0;$accumulation$072 = 0;
  while(1) {
   $131 = (($accumulatedConstraintsPerPartition) + ($a1$071<<2)|0);
   HEAP32[$131>>2] = $accumulation$072;
   $132 = (($numConstraintsPerPartition) + ($a1$071<<2)|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = (($133) + ($accumulation$072))|0;
   HEAP32[$132>>2] = 0;
   $135 = (($a1$071) + 1)|0;
   $exitcond91 = ($135|0)==(33);
   if ($exitcond91) {
    break;
   } else {
    $a1$071 = $135;$accumulation$072 = $134;
   }
  }
  if (!($15)) {
   $a2$070 = 0;
   while(1) {
    $136 = HEAP32[$args>>2]|0;
    $$sum64 = (($a2$070) + 8)|0;
    $137 = (($136) + ($$sum64<<5)|0);
    $138 = ((($136) + ($a2$070<<5)|0) + 28|0);
    HEAP32[$138>>2] = 0;
    $139 = (($a2$070) + 1)|0;
    $exitcond90 = ($139|0)==($2|0);
    if ($exitcond90) {
     break;
    } else {
     $a2$070 = $139;
    }
   }
  }
  if ($23) {
   $numOrderedConstraints$0 = 0;
  } else {
   $140 = (($accumulatedConstraintsPerPartition) + 128|0);
   $141 = (($numConstraintsPerPartition) + 128|0);
   $desc$03$i = $12;$i$02$i = 0;
   while(1) {
    $142 = (($22) - ($i$02$i))|0;
    $143 = ($142>>>0)<(4);
    $144 = $143 ? $142 : 4;
    $145 = ((($desc$03$i) + ($144<<5)|0) + 16|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = (($desc$03$i) + ($144<<5)|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ((($desc$03$i) + ($144<<5)|0) + 4|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = (($desc$03$i) + 256|0);
    $152 = HEAP32[$desc$03$i>>2]|0;
    $153 = $152;
    $154 = (($153) - ($4))|0;
    $155 = $154 >>> 5;
    $156 = (($desc$03$i) + 4|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = $157;
    $159 = (($158) - ($4))|0;
    $160 = $159 >>> 5;
    $161 = ($155>>>0)<($2>>>0);
    $162 = ($160>>>0)<($2>>>0);
    $$$i42 = $161 & $162;
    do {
     if ($$$i42) {
      $163 = (($152) + 28|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = (($157) + 28|0);
      $166 = HEAP32[$165>>2]|0;
      $$demorgan$i43 = $166 | $164;
      $167 = ($$demorgan$i43|0)==(-1);
      if ($167) {
       $168 = HEAP32[$140>>2]|0;
       $169 = HEAP32[$141>>2]|0;
       $170 = (($169) + ($168))|0;
       $171 = (($14) + ($170<<5)|0);
       ;HEAP32[$171+0>>2]=HEAP32[$desc$03$i+0>>2]|0;HEAP32[$171+4>>2]=HEAP32[$desc$03$i+4>>2]|0;HEAP32[$171+8>>2]=HEAP32[$desc$03$i+8>>2]|0;HEAP32[$171+12>>2]=HEAP32[$desc$03$i+12>>2]|0;HEAP32[$171+16>>2]=HEAP32[$desc$03$i+16>>2]|0;HEAP32[$171+20>>2]=HEAP32[$desc$03$i+20>>2]|0;HEAP32[$171+24>>2]=HEAP32[$desc$03$i+24>>2]|0;HEAP32[$171+28>>2]=HEAP32[$desc$03$i+28>>2]|0;
       $$sum1$i = (($170) + 4)|0;
       $172 = (($14) + ($$sum1$i<<5)|0);
       $173 = (($169) + 1)|0;
       HEAP32[$141>>2] = $173;
       break;
      } else {
       $174 = $$demorgan$i43 ^ -1;
       $175 = (($$demorgan$i43) + 1)|0;
       $176 = $175 & $174;
       $177 = Math_imul($176, 125613361)|0;
       $178 = $177 >>> 27;
       $179 = (412480 + ($178<<2)|0);
       $180 = HEAP32[$179>>2]|0;
       $181 = 1 << $180;
       $182 = $181 | $166;
       $183 = $181 | $164;
       HEAP32[$163>>2] = $183;
       HEAP32[$165>>2] = $182;
       $184 = (($accumulatedConstraintsPerPartition) + ($180<<2)|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = (($numConstraintsPerPartition) + ($180<<2)|0);
       $187 = HEAP32[$186>>2]|0;
       $188 = (($187) + ($185))|0;
       $189 = (($14) + ($188<<5)|0);
       ;HEAP32[$189+0>>2]=HEAP32[$desc$03$i+0>>2]|0;HEAP32[$189+4>>2]=HEAP32[$desc$03$i+4>>2]|0;HEAP32[$189+8>>2]=HEAP32[$desc$03$i+8>>2]|0;HEAP32[$189+12>>2]=HEAP32[$desc$03$i+12>>2]|0;HEAP32[$189+16>>2]=HEAP32[$desc$03$i+16>>2]|0;HEAP32[$189+20>>2]=HEAP32[$desc$03$i+20>>2]|0;HEAP32[$189+24>>2]=HEAP32[$desc$03$i+24>>2]|0;HEAP32[$189+28>>2]=HEAP32[$desc$03$i+28>>2]|0;
       $$sum$i45 = (($188) + 4)|0;
       $190 = (($14) + ($$sum$i45<<5)|0);
       $191 = (($187) + 1)|0;
       HEAP32[$186>>2] = $191;
       break;
      }
     }
    } while(0);
    $192 = (($i$02$i) + 1)|0;
    $193 = (($desc$03$i) + 32|0);
    $exitcond$i46 = ($192|0)==($10|0);
    if ($exitcond$i46) {
     $desc$07$i36 = $12;$i$06$i37 = 0;
     break;
    } else {
     $desc$03$i = $193;$i$02$i = $192;
    }
   }
   while(1) {
    $194 = (($22) - ($i$06$i37))|0;
    $195 = ($194>>>0)<(4);
    $196 = $195 ? $194 : 4;
    $197 = ((($desc$07$i36) + ($196<<5)|0) + 16|0);
    $198 = HEAP32[$197>>2]|0;
    $199 = (($desc$07$i36) + ($196<<5)|0);
    $200 = HEAP32[$199>>2]|0;
    $201 = ((($desc$07$i36) + ($196<<5)|0) + 4|0);
    $202 = HEAP32[$201>>2]|0;
    $203 = (($desc$07$i36) + 256|0);
    $204 = HEAP32[$desc$07$i36>>2]|0;
    $205 = $204;
    $206 = (($205) - ($4))|0;
    $207 = $206 >>> 5;
    $208 = (($desc$07$i36) + 4|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = $209;
    $211 = (($210) - ($4))|0;
    $212 = $211 >>> 5;
    $213 = ($207>>>0)<($2>>>0);
    $214 = ($212>>>0)<($2>>>0);
    $$$i = $213 & $214;
    L62: do {
     if (!($$$i)) {
      if ($213) {
       $215 = (($204) + 28|0);
       $216 = HEAP32[$215>>2]|0;
       $232 = $216;
      } else {
       $232 = -1;
      }
      if ($214) {
       $217 = (($209) + 28|0);
       $218 = HEAP32[$217>>2]|0;
       $220 = $218;
      } else {
       $220 = -1;
      }
      do {
       if ($213) {
        $231 = ($232|0)==(0);
        if ($231) {
         $233 = $220 | 1;
         $255 = 1;$633 = $233;$availablePartition$013$i = 0;
         label = 54;
         break;
        } else {
         $234 = $232 >>> 1;
         $235 = $234 | $232;
         $236 = $235 >>> 2;
         $237 = $236 | $235;
         $238 = $237 >>> 4;
         $239 = $238 | $237;
         $240 = $239 >>> 8;
         $241 = $240 | $239;
         $242 = $241 >>> 16;
         $243 = $242 | $241;
         $$pn$in$in$i = $243;
         label = 51;
         break;
        }
       } else {
        $219 = ($220|0)==(0);
        if ($219) {
         $258 = 1;$availablePartition$012$i = 0;
        } else {
         $221 = $220 >>> 1;
         $222 = $221 | $220;
         $223 = $222 >>> 2;
         $224 = $223 | $222;
         $225 = $224 >>> 4;
         $226 = $225 | $224;
         $227 = $226 >>> 8;
         $228 = $227 | $226;
         $229 = $228 >>> 16;
         $230 = $229 | $228;
         $$pn$in$in$i = $230;
         label = 51;
        }
       }
      } while(0);
      do {
       if ((label|0) == 51) {
        label = 0;
        $$pn$in$i = Math_imul($$pn$in$in$i, 130329821)|0;
        $$pn$i = $$pn$in$i >>> 27;
        $$sink$in$i = (482344 + ($$pn$i<<2)|0);
        $$sink$i = HEAP32[$$sink$in$i>>2]|0;
        $244 = (($$sink$i) + 1)|0;
        $245 = ($244|0)==(32);
        if ($245) {
         $246 = HEAP32[$140>>2]|0;
         $247 = HEAP32[$141>>2]|0;
         $248 = (($247) + ($246))|0;
         $249 = (($14) + ($248<<5)|0);
         ;HEAP32[$249+0>>2]=HEAP32[$desc$07$i36+0>>2]|0;HEAP32[$249+4>>2]=HEAP32[$desc$07$i36+4>>2]|0;HEAP32[$249+8>>2]=HEAP32[$desc$07$i36+8>>2]|0;HEAP32[$249+12>>2]=HEAP32[$desc$07$i36+12>>2]|0;HEAP32[$249+16>>2]=HEAP32[$desc$07$i36+16>>2]|0;HEAP32[$249+20>>2]=HEAP32[$desc$07$i36+20>>2]|0;HEAP32[$249+24>>2]=HEAP32[$desc$07$i36+24>>2]|0;HEAP32[$249+28>>2]=HEAP32[$desc$07$i36+28>>2]|0;
         $$sum5$i = (($248) + 4)|0;
         $250 = (($14) + ($$sum5$i<<5)|0);
         $251 = (($247) + 1)|0;
         HEAP32[$141>>2] = $251;
         break L62;
        } else {
         $252 = 1 << $244;
         $253 = $252 | $220;
         if ($213) {
          $255 = $252;$633 = $253;$availablePartition$013$i = $244;
          label = 54;
          break;
         } else {
          $258 = $253;$availablePartition$012$i = $244;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 54) {
       label = 0;
       $254 = $255 | $232;
       $256 = (($204) + 28|0);
       HEAP32[$256>>2] = $254;
       $258 = $633;$availablePartition$012$i = $availablePartition$013$i;
      }
      if ($214) {
       $257 = (($209) + 28|0);
       HEAP32[$257>>2] = $258;
      }
      $259 = ($availablePartition$012$i>>>0)<(32);
      if ($259) {
       $260 = (($accumulatedConstraintsPerPartition) + ($availablePartition$012$i<<2)|0);
       $261 = HEAP32[$260>>2]|0;
       $262 = (($numConstraintsPerPartition) + ($availablePartition$012$i<<2)|0);
       $263 = HEAP32[$262>>2]|0;
       $264 = (($263) + ($261))|0;
       $265 = (($14) + ($264<<5)|0);
       ;HEAP32[$265+0>>2]=HEAP32[$desc$07$i36+0>>2]|0;HEAP32[$265+4>>2]=HEAP32[$desc$07$i36+4>>2]|0;HEAP32[$265+8>>2]=HEAP32[$desc$07$i36+8>>2]|0;HEAP32[$265+12>>2]=HEAP32[$desc$07$i36+12>>2]|0;HEAP32[$265+16>>2]=HEAP32[$desc$07$i36+16>>2]|0;HEAP32[$265+20>>2]=HEAP32[$desc$07$i36+20>>2]|0;HEAP32[$265+24>>2]=HEAP32[$desc$07$i36+24>>2]|0;HEAP32[$265+28>>2]=HEAP32[$desc$07$i36+28>>2]|0;
       $$sum$i = (($264) + 4)|0;
       $266 = (($14) + ($$sum$i<<5)|0);
       $267 = (($263) + 1)|0;
       HEAP32[$262>>2] = $267;
      }
     }
    } while(0);
    $268 = (($i$06$i37) + 1)|0;
    $269 = (($desc$07$i36) + 32|0);
    $exitcond$i40 = ($268|0)==($10|0);
    if ($exitcond$i40) {
     $numOrderedConstraints$0 = $10;
     break;
    } else {
     $desc$07$i36 = $269;$i$06$i37 = $268;
    }
   }
  }
 } else {
  $270 = $6 << 2;
  $271 = ($270>>>0)>(1024);
  $272 = (($_eaFsData) + 4|0);
  $273 = $271&1;
  HEAP8[$272>>0] = $273;
  if ($271) {
   $274 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$270,488456,921)|0);
   HEAP32[$_eaFsData>>2] = $274;
   $280 = $274;
  } else {
   $275 = STACKTOP; STACKTOP = STACKTOP + ((((1*$270)|0)+15)&-16)|0;;
   HEAP32[$_eaFsData>>2] = $275;
   $280 = $275;
  }
  $i$082 = 0;
  while(1) {
   $276 = (($8) + (($i$082*40)|0)|0);
   $277 = HEAP32[$276>>2]|0;
   $278 = $277;
   $279 = (($280) + ($i$082<<2)|0);
   HEAP32[$279>>2] = $278;
   $281 = (($277) + 28|0);
   HEAP32[$281>>2] = 0;
   $282 = (($277) + 14|0);
   HEAP16[$282>>1] = 0;
   $283 = (($277) + 12|0);
   HEAP16[$283>>1] = 0;
   $284 = (($i$082) + 1)|0;
   $exitcond95 = ($284|0)==($6|0);
   if ($exitcond95) {
    break;
   } else {
    $i$082 = $284;
   }
  }
  $285 = (($10) + -1)|0;
  $286 = ($10|0)==(0);
  if (!($286)) {
   $desc$07$i = $12;$i$06$i25 = 0;
   while(1) {
    $287 = (($285) - ($i$06$i25))|0;
    $288 = ($287>>>0)<(4);
    $289 = $288 ? $287 : 4;
    $290 = ((($desc$07$i) + ($289<<5)|0) + 16|0);
    $291 = HEAP32[$290>>2]|0;
    $292 = (($desc$07$i) + ($289<<5)|0);
    $293 = HEAP32[$292>>2]|0;
    $294 = ((($desc$07$i) + ($289<<5)|0) + 4|0);
    $295 = HEAP32[$294>>2]|0;
    $296 = (($desc$07$i) + 256|0);
    $297 = (($desc$07$i) + 8|0);
    $298 = HEAP16[$297>>1]|0;
    $299 = ($298<<16>>16)==(-1);
    $300 = (($desc$07$i) + 12|0);
    $301 = HEAP16[$300>>1]|0;
    $302 = ($301<<16>>16)==(-1);
    do {
     if ($299) {
      $303 = HEAP32[$desc$07$i>>2]|0;
      $304 = $303;
      $305 = (($304) - ($4))|0;
      $306 = $305 >>> 5;
      if ($302) {
       $307 = (($desc$07$i) + 4|0);
       $308 = HEAP32[$307>>2]|0;
       $309 = $308;
       $310 = (($309) - ($4))|0;
       $311 = $310 >>> 5;
       $312 = ($306>>>0)<($2>>>0);
       $313 = ($311>>>0)<($2>>>0);
       $bBodyA$0$off0$i30 = $312;$bBodyB$0$off0$i31 = $313;
       break;
      } else {
       $320 = ($306>>>0)<($2>>>0);
       $bBodyA$0$off0$i30 = $320;$bBodyB$0$off0$i31 = 1;
       break;
      }
     } else {
      if ($302) {
       $314 = (($desc$07$i) + 4|0);
       $315 = HEAP32[$314>>2]|0;
       $316 = $315;
       $317 = (($316) - ($4))|0;
       $318 = $317 >>> 5;
       $319 = ($318>>>0)<($2>>>0);
       $bBodyA$0$off0$i30 = 1;$bBodyB$0$off0$i31 = $319;
      } else {
       $bBodyA$0$off0$i30 = 1;$bBodyB$0$off0$i31 = 1;
      }
     }
    } while(0);
    $brmerge$demorgan$i32 = $bBodyA$0$off0$i30 & $bBodyB$0$off0$i31;
    if ($brmerge$demorgan$i32) {
     $321 = HEAP32[$desc$07$i>>2]|0;
     $322 = (($321) + 28|0);
     $323 = HEAP32[$322>>2]|0;
     $324 = (($desc$07$i) + 4|0);
     $325 = HEAP32[$324>>2]|0;
     $326 = (($325) + 28|0);
     $327 = HEAP32[$326>>2]|0;
     $$demorgan$i33 = $327 | $323;
     $328 = ($$demorgan$i33|0)==(-1);
     if (!($328)) {
      $329 = $$demorgan$i33 ^ -1;
      $330 = (($$demorgan$i33) + 1)|0;
      $331 = $330 & $329;
      $332 = Math_imul($331, 125613361)|0;
      $333 = $332 >>> 27;
      $334 = (412480 + ($333<<2)|0);
      $335 = HEAP32[$334>>2]|0;
      $336 = 1 << $335;
      $337 = $336 | $327;
      $338 = $336 | $323;
      HEAP32[$322>>2] = $338;
      HEAP32[$326>>2] = $337;
      $339 = (($numConstraintsPerPartition) + ($335<<2)|0);
      $340 = HEAP32[$339>>2]|0;
      $341 = (($340) + 1)|0;
      HEAP32[$339>>2] = $341;
     }
    }
    $342 = (($i$06$i25) + 1)|0;
    $343 = (($desc$07$i) + 32|0);
    $exitcond$i34 = ($342|0)==($10|0);
    if ($exitcond$i34) {
     $desc$08$i12 = $12;$i$07$i13 = 0;
     break;
    } else {
     $desc$07$i = $343;$i$06$i25 = $342;
    }
   }
   while(1) {
    $344 = (($285) - ($i$07$i13))|0;
    $345 = ($344>>>0)<(4);
    $346 = $345 ? $344 : 4;
    $347 = ((($desc$08$i12) + ($346<<5)|0) + 16|0);
    $348 = HEAP32[$347>>2]|0;
    $349 = (($desc$08$i12) + ($346<<5)|0);
    $350 = HEAP32[$349>>2]|0;
    $351 = ((($desc$08$i12) + ($346<<5)|0) + 4|0);
    $352 = HEAP32[$351>>2]|0;
    $353 = (($desc$08$i12) + 256|0);
    $354 = (($desc$08$i12) + 8|0);
    $355 = HEAP16[$354>>1]|0;
    $356 = ($355<<16>>16)==(-1);
    $357 = (($desc$08$i12) + 12|0);
    $358 = HEAP16[$357>>1]|0;
    $359 = ($358<<16>>16)==(-1);
    do {
     if ($356) {
      $360 = HEAP32[$desc$08$i12>>2]|0;
      $361 = $360;
      $362 = (($361) - ($4))|0;
      $363 = $362 >>> 5;
      if ($359) {
       $364 = (($desc$08$i12) + 4|0);
       $365 = HEAP32[$364>>2]|0;
       $366 = $365;
       $367 = (($366) - ($4))|0;
       $368 = $367 >>> 5;
       $369 = ($363>>>0)<($2>>>0);
       $370 = ($368>>>0)<($2>>>0);
       $bBodyA$0$off0$i18 = $369;$bBodyB$0$off0$i19 = $370;
       label = 82;
       break;
      } else {
       $377 = ($363>>>0)<($2>>>0);
       $bBodyA$0$off0$i18 = $377;$bBodyB$0$off0$i19 = 1;
       label = 82;
       break;
      }
     } else {
      if ($359) {
       $371 = (($desc$08$i12) + 4|0);
       $372 = HEAP32[$371>>2]|0;
       $373 = $372;
       $374 = (($373) - ($4))|0;
       $375 = $374 >>> 5;
       $376 = ($375>>>0)<($2>>>0);
       $bBodyA$0$off0$i18 = 1;$bBodyB$0$off0$i19 = $376;
       label = 82;
      }
     }
    } while(0);
    if ((label|0) == 82) {
     label = 0;
     $brmerge$demorgan$i20 = $bBodyA$0$off0$i18 & $bBodyB$0$off0$i19;
     if (!($brmerge$demorgan$i20)) {
      if ($bBodyA$0$off0$i18) {
       $378 = HEAP32[$desc$08$i12>>2]|0;
       $379 = (($378) + 28|0);
       $380 = HEAP32[$379>>2]|0;
       $402 = $380;
      } else {
       $402 = -1;
      }
      if ($bBodyB$0$off0$i19) {
       $381 = (($desc$08$i12) + 4|0);
       $382 = HEAP32[$381>>2]|0;
       $383 = (($382) + 28|0);
       $384 = HEAP32[$383>>2]|0;
       $385 = ($384|0)==(0);
       if ($385) {
        $421 = 0;$availablePartition$0$i21 = 0;
       } else {
        $386 = $384 >>> 1;
        $387 = $386 | $384;
        $388 = $387 >>> 2;
        $389 = $388 | $387;
        $390 = $389 >>> 4;
        $391 = $390 | $389;
        $392 = $391 >>> 8;
        $393 = $392 | $391;
        $394 = $393 >>> 16;
        $395 = $394 | $393;
        $396 = Math_imul($395, 130329821)|0;
        $397 = $396 >>> 27;
        $398 = (482344 + ($397<<2)|0);
        $399 = HEAP32[$398>>2]|0;
        $400 = (($399) + 1)|0;
        $421 = $384;$availablePartition$0$i21 = $400;
       }
      } else {
       $401 = ($402|0)==(0);
       if ($401) {
        $421 = -1;$availablePartition$0$i21 = 0;
       } else {
        $403 = $402 >>> 1;
        $404 = $403 | $402;
        $405 = $404 >>> 2;
        $406 = $405 | $404;
        $407 = $406 >>> 4;
        $408 = $407 | $406;
        $409 = $408 >>> 8;
        $410 = $409 | $408;
        $411 = $410 >>> 16;
        $412 = $411 | $410;
        $413 = Math_imul($412, 130329821)|0;
        $414 = $413 >>> 27;
        $415 = (482344 + ($414<<2)|0);
        $416 = HEAP32[$415>>2]|0;
        $417 = (($416) + 1)|0;
        $421 = -1;$availablePartition$0$i21 = $417;
       }
      }
      $418 = ($availablePartition$0$i21|0)!=(32);
      $brmerge3$i22 = $bBodyA$0$off0$i18 | $bBodyB$0$off0$i19;
      $or$cond$i23 = $418 & $brmerge3$i22;
      if ($or$cond$i23) {
       $419 = 1 << $availablePartition$0$i21;
       $420 = $419 | $421;
       if ($bBodyA$0$off0$i18) {
        $422 = $419 | $402;
        $423 = HEAP32[$desc$08$i12>>2]|0;
        $424 = (($423) + 28|0);
        HEAP32[$424>>2] = $422;
       }
       if ($bBodyB$0$off0$i19) {
        $425 = (($desc$08$i12) + 4|0);
        $426 = HEAP32[$425>>2]|0;
        $427 = (($426) + 28|0);
        HEAP32[$427>>2] = $420;
       }
       $428 = (($numConstraintsPerPartition) + ($availablePartition$0$i21<<2)|0);
       $429 = HEAP32[$428>>2]|0;
       $430 = (($429) + 1)|0;
       HEAP32[$428>>2] = $430;
      }
     }
    }
    $431 = (($i$07$i13) + 1)|0;
    $432 = (($desc$08$i12) + 32|0);
    $exitcond$i24 = ($431|0)==($10|0);
    if ($exitcond$i24) {
     break;
    } else {
     $desc$08$i12 = $432;$i$07$i13 = $431;
    }
   }
  }
  $a6$081 = 0;$accumulation5$080 = 0;
  while(1) {
   $433 = (($accumulatedConstraintsPerPartition) + ($a6$081<<2)|0);
   HEAP32[$433>>2] = $accumulation5$080;
   $434 = (($numConstraintsPerPartition) + ($a6$081<<2)|0);
   $435 = HEAP32[$434>>2]|0;
   $436 = (($435) + ($accumulation5$080))|0;
   HEAP32[$434>>2] = 0;
   $437 = (($a6$081) + 1)|0;
   $exitcond94 = ($437|0)==(33);
   if ($exitcond94) {
    break;
   } else {
    $a6$081 = $437;$accumulation5$080 = $436;
   }
  }
  if ($15) {
   $i9$074 = 0;
  } else {
   $a7$078 = 0;
   while(1) {
    $438 = HEAP32[$args>>2]|0;
    $$sum = (($a7$078) + 8)|0;
    $439 = (($438) + ($$sum<<5)|0);
    $440 = ((($438) + ($a7$078<<5)|0) + 28|0);
    HEAP32[$440>>2] = 0;
    $441 = (($a7$078) + 1)|0;
    $exitcond93 = ($441|0)==($2|0);
    if ($exitcond93) {
     $i9$074 = 0;
     break;
    } else {
     $a7$078 = $441;
    }
   }
  }
  while(1) {
   $442 = (($8) + (($i9$074*40)|0)|0);
   $443 = HEAP32[$442>>2]|0;
   $444 = (($443) + 28|0);
   HEAP32[$444>>2] = 0;
   $445 = (($i9$074) + 1)|0;
   $exitcond92 = ($445|0)==($6|0);
   if ($exitcond92) {
    break;
   } else {
    $i9$074 = $445;
   }
  }
  if ($286) {
   $numWrittenConstraints$0$lcssa$i = 0;$numWrittenConstraints$0$lcssa$i1163 = 0;
  } else {
   $446 = (($accumulatedConstraintsPerPartition) + 128|0);
   $447 = (($numConstraintsPerPartition) + 128|0);
   $desc$08$i2 = $12;$i$06$i = 0;$numWrittenConstraints$07$i = 0;
   while(1) {
    $448 = (($285) - ($i$06$i))|0;
    $449 = ($448>>>0)<(4);
    $450 = $449 ? $448 : 4;
    $451 = ((($desc$08$i2) + ($450<<5)|0) + 16|0);
    $452 = HEAP32[$451>>2]|0;
    $453 = (($desc$08$i2) + ($450<<5)|0);
    $454 = HEAP32[$453>>2]|0;
    $455 = ((($desc$08$i2) + ($450<<5)|0) + 4|0);
    $456 = HEAP32[$455>>2]|0;
    $457 = (($desc$08$i2) + 256|0);
    $458 = (($desc$08$i2) + 8|0);
    $459 = HEAP16[$458>>1]|0;
    $460 = ($459<<16>>16)==(-1);
    $461 = (($desc$08$i2) + 12|0);
    $462 = HEAP16[$461>>1]|0;
    $463 = ($462<<16>>16)==(-1);
    do {
     if ($460) {
      $464 = HEAP32[$desc$08$i2>>2]|0;
      $465 = $464;
      $466 = (($465) - ($4))|0;
      $467 = $466 >>> 5;
      if ($463) {
       $468 = (($desc$08$i2) + 4|0);
       $469 = HEAP32[$468>>2]|0;
       $470 = $469;
       $471 = (($470) - ($4))|0;
       $472 = $471 >>> 5;
       $473 = ($467>>>0)<($2>>>0);
       $474 = ($472>>>0)<($2>>>0);
       $bBodyA$0$off0$i7 = $473;$bBodyB$0$off0$i6 = $474;
       break;
      } else {
       $481 = ($467>>>0)<($2>>>0);
       $bBodyA$0$off0$i7 = $481;$bBodyB$0$off0$i6 = 1;
       break;
      }
     } else {
      if ($463) {
       $475 = (($desc$08$i2) + 4|0);
       $476 = HEAP32[$475>>2]|0;
       $477 = $476;
       $478 = (($477) - ($4))|0;
       $479 = $478 >>> 5;
       $480 = ($479>>>0)<($2>>>0);
       $bBodyA$0$off0$i7 = 1;$bBodyB$0$off0$i6 = $480;
      } else {
       $bBodyA$0$off0$i7 = 1;$bBodyB$0$off0$i6 = 1;
      }
     }
    } while(0);
    $brmerge$demorgan$i8 = $bBodyA$0$off0$i7 & $bBodyB$0$off0$i6;
    do {
     if ($brmerge$demorgan$i8) {
      $482 = HEAP32[$desc$08$i2>>2]|0;
      $483 = (($482) + 28|0);
      $484 = HEAP32[$483>>2]|0;
      $485 = (($desc$08$i2) + 4|0);
      $486 = HEAP32[$485>>2]|0;
      $487 = (($486) + 28|0);
      $488 = HEAP32[$487>>2]|0;
      $$demorgan$i = $488 | $484;
      $489 = ($$demorgan$i|0)==(-1);
      if ($489) {
       $490 = HEAP32[$446>>2]|0;
       $491 = HEAP32[$447>>2]|0;
       $492 = (($491) + ($490))|0;
       $493 = (($14) + ($492<<5)|0);
       ;HEAP32[$493+0>>2]=HEAP32[$desc$08$i2+0>>2]|0;HEAP32[$493+4>>2]=HEAP32[$desc$08$i2+4>>2]|0;HEAP32[$493+8>>2]=HEAP32[$desc$08$i2+8>>2]|0;HEAP32[$493+12>>2]=HEAP32[$desc$08$i2+12>>2]|0;HEAP32[$493+16>>2]=HEAP32[$desc$08$i2+16>>2]|0;HEAP32[$493+20>>2]=HEAP32[$desc$08$i2+20>>2]|0;HEAP32[$493+24>>2]=HEAP32[$desc$08$i2+24>>2]|0;HEAP32[$493+28>>2]=HEAP32[$desc$08$i2+28>>2]|0;
       $494 = (($numWrittenConstraints$07$i) + 1)|0;
       $495 = (($491) + 1)|0;
       HEAP32[$447>>2] = $495;
       $numWrittenConstraints$1$i9 = $494;
       break;
      } else {
       $496 = $$demorgan$i ^ -1;
       $497 = (($$demorgan$i) + 1)|0;
       $498 = $497 & $496;
       $499 = Math_imul($498, 125613361)|0;
       $500 = $499 >>> 27;
       $501 = (412480 + ($500<<2)|0);
       $502 = HEAP32[$501>>2]|0;
       $503 = 1 << $502;
       $504 = $503 | $488;
       $505 = $503 | $484;
       HEAP32[$483>>2] = $505;
       HEAP32[$487>>2] = $504;
       $506 = (($accumulatedConstraintsPerPartition) + ($502<<2)|0);
       $507 = HEAP32[$506>>2]|0;
       $508 = (($numConstraintsPerPartition) + ($502<<2)|0);
       $509 = HEAP32[$508>>2]|0;
       $510 = (($509) + ($507))|0;
       $511 = (($14) + ($510<<5)|0);
       ;HEAP32[$511+0>>2]=HEAP32[$desc$08$i2+0>>2]|0;HEAP32[$511+4>>2]=HEAP32[$desc$08$i2+4>>2]|0;HEAP32[$511+8>>2]=HEAP32[$desc$08$i2+8>>2]|0;HEAP32[$511+12>>2]=HEAP32[$desc$08$i2+12>>2]|0;HEAP32[$511+16>>2]=HEAP32[$desc$08$i2+16>>2]|0;HEAP32[$511+20>>2]=HEAP32[$desc$08$i2+20>>2]|0;HEAP32[$511+24>>2]=HEAP32[$desc$08$i2+24>>2]|0;HEAP32[$511+28>>2]=HEAP32[$desc$08$i2+28>>2]|0;
       $512 = (($numWrittenConstraints$07$i) + 1)|0;
       $513 = (($509) + 1)|0;
       HEAP32[$508>>2] = $513;
       $numWrittenConstraints$1$i9 = $512;
       break;
      }
     } else {
      $numWrittenConstraints$1$i9 = $numWrittenConstraints$07$i;
     }
    } while(0);
    $514 = (($i$06$i) + 1)|0;
    $515 = (($desc$08$i2) + 32|0);
    $exitcond$i10 = ($514|0)==($10|0);
    if ($exitcond$i10) {
     $desc$08$i = $12;$i$07$i = 0;$numWrittenConstraints$012$i = 0;
     break;
    } else {
     $desc$08$i2 = $515;$i$06$i = $514;$numWrittenConstraints$07$i = $numWrittenConstraints$1$i9;
    }
   }
   while(1) {
    $516 = (($285) - ($i$07$i))|0;
    $517 = ($516>>>0)<(4);
    $518 = $517 ? $516 : 4;
    $519 = ((($desc$08$i) + ($518<<5)|0) + 16|0);
    $520 = HEAP32[$519>>2]|0;
    $521 = (($desc$08$i) + ($518<<5)|0);
    $522 = HEAP32[$521>>2]|0;
    $523 = ((($desc$08$i) + ($518<<5)|0) + 4|0);
    $524 = HEAP32[$523>>2]|0;
    $525 = (($desc$08$i) + 256|0);
    $526 = (($desc$08$i) + 8|0);
    $527 = HEAP16[$526>>1]|0;
    $528 = ($527<<16>>16)==(-1);
    $529 = (($desc$08$i) + 12|0);
    $530 = HEAP16[$529>>1]|0;
    $531 = ($530<<16>>16)==(-1);
    do {
     if ($528) {
      $532 = HEAP32[$desc$08$i>>2]|0;
      $533 = $532;
      $534 = (($533) - ($4))|0;
      $535 = $534 >>> 5;
      if ($531) {
       $536 = (($desc$08$i) + 4|0);
       $537 = HEAP32[$536>>2]|0;
       $538 = $537;
       $539 = (($538) - ($4))|0;
       $540 = $539 >>> 5;
       $541 = ($535>>>0)<($2>>>0);
       $542 = ($540>>>0)<($2>>>0);
       $bBodyA$0$off0$i = $541;$bBodyB$0$off0$i = $542;
       label = 121;
       break;
      } else {
       $549 = ($535>>>0)<($2>>>0);
       $bBodyA$0$off0$i = $549;$bBodyB$0$off0$i = 1;
       label = 121;
       break;
      }
     } else {
      if ($531) {
       $543 = (($desc$08$i) + 4|0);
       $544 = HEAP32[$543>>2]|0;
       $545 = $544;
       $546 = (($545) - ($4))|0;
       $547 = $546 >>> 5;
       $548 = ($547>>>0)<($2>>>0);
       $bBodyA$0$off0$i = 1;$bBodyB$0$off0$i = $548;
       label = 121;
      } else {
       $numWrittenConstraints$1$i = $numWrittenConstraints$012$i;
      }
     }
    } while(0);
    do {
     if ((label|0) == 121) {
      label = 0;
      $brmerge$demorgan$i = $bBodyA$0$off0$i & $bBodyB$0$off0$i;
      if ($brmerge$demorgan$i) {
       $numWrittenConstraints$1$i = $numWrittenConstraints$012$i;
      } else {
       if ($bBodyA$0$off0$i) {
        $550 = HEAP32[$desc$08$i>>2]|0;
        $551 = (($550) + 28|0);
        $552 = HEAP32[$551>>2]|0;
        $574 = $552;
       } else {
        $574 = -1;
       }
       if ($bBodyB$0$off0$i) {
        $553 = (($desc$08$i) + 4|0);
        $554 = HEAP32[$553>>2]|0;
        $555 = (($554) + 28|0);
        $556 = HEAP32[$555>>2]|0;
        $557 = ($556|0)==(0);
        if ($557) {
         $601 = 0;$availablePartition$0$i = 0;
        } else {
         $558 = $556 >>> 1;
         $559 = $558 | $556;
         $560 = $559 >>> 2;
         $561 = $560 | $559;
         $562 = $561 >>> 4;
         $563 = $562 | $561;
         $564 = $563 >>> 8;
         $565 = $564 | $563;
         $566 = $565 >>> 16;
         $567 = $566 | $565;
         $568 = Math_imul($567, 130329821)|0;
         $569 = $568 >>> 27;
         $570 = (482344 + ($569<<2)|0);
         $571 = HEAP32[$570>>2]|0;
         $572 = (($571) + 1)|0;
         $601 = $556;$availablePartition$0$i = $572;
        }
       } else {
        $573 = ($574|0)==(0);
        if ($573) {
         $601 = -1;$availablePartition$0$i = 0;
        } else {
         $575 = $574 >>> 1;
         $576 = $575 | $574;
         $577 = $576 >>> 2;
         $578 = $577 | $576;
         $579 = $578 >>> 4;
         $580 = $579 | $578;
         $581 = $580 >>> 8;
         $582 = $581 | $580;
         $583 = $582 >>> 16;
         $584 = $583 | $582;
         $585 = Math_imul($584, 130329821)|0;
         $586 = $585 >>> 27;
         $587 = (482344 + ($586<<2)|0);
         $588 = HEAP32[$587>>2]|0;
         $589 = (($588) + 1)|0;
         $601 = -1;$availablePartition$0$i = $589;
        }
       }
       $590 = ($availablePartition$0$i|0)!=(32);
       $brmerge3$i = $bBodyA$0$off0$i | $bBodyB$0$off0$i;
       $or$cond$i = $590 & $brmerge3$i;
       if (!($or$cond$i)) {
        $591 = (($accumulatedConstraintsPerPartition) + ($availablePartition$0$i<<2)|0);
        $592 = HEAP32[$591>>2]|0;
        $593 = (($numConstraintsPerPartition) + ($availablePartition$0$i<<2)|0);
        $594 = HEAP32[$593>>2]|0;
        $595 = (($594) + ($592))|0;
        $596 = (($14) + ($595<<5)|0);
        ;HEAP32[$596+0>>2]=HEAP32[$desc$08$i+0>>2]|0;HEAP32[$596+4>>2]=HEAP32[$desc$08$i+4>>2]|0;HEAP32[$596+8>>2]=HEAP32[$desc$08$i+8>>2]|0;HEAP32[$596+12>>2]=HEAP32[$desc$08$i+12>>2]|0;HEAP32[$596+16>>2]=HEAP32[$desc$08$i+16>>2]|0;HEAP32[$596+20>>2]=HEAP32[$desc$08$i+20>>2]|0;HEAP32[$596+24>>2]=HEAP32[$desc$08$i+24>>2]|0;HEAP32[$596+28>>2]=HEAP32[$desc$08$i+28>>2]|0;
        $597 = (($numWrittenConstraints$012$i) + 1)|0;
        $598 = (($594) + 1)|0;
        HEAP32[$593>>2] = $598;
        $numWrittenConstraints$1$i = $597;
        break;
       }
       $599 = 1 << $availablePartition$0$i;
       $600 = $599 | $601;
       if ($bBodyA$0$off0$i) {
        $602 = $599 | $574;
        $603 = HEAP32[$desc$08$i>>2]|0;
        $604 = (($603) + 28|0);
        HEAP32[$604>>2] = $602;
       }
       if ($bBodyB$0$off0$i) {
        $605 = (($desc$08$i) + 4|0);
        $606 = HEAP32[$605>>2]|0;
        $607 = (($606) + 28|0);
        HEAP32[$607>>2] = $600;
       }
       $608 = ($availablePartition$0$i>>>0)<(32);
       if ($608) {
        $609 = (($accumulatedConstraintsPerPartition) + ($availablePartition$0$i<<2)|0);
        $610 = HEAP32[$609>>2]|0;
        $611 = (($numConstraintsPerPartition) + ($availablePartition$0$i<<2)|0);
        $612 = HEAP32[$611>>2]|0;
        $613 = (($612) + ($610))|0;
        $614 = (($14) + ($613<<5)|0);
        ;HEAP32[$614+0>>2]=HEAP32[$desc$08$i+0>>2]|0;HEAP32[$614+4>>2]=HEAP32[$desc$08$i+4>>2]|0;HEAP32[$614+8>>2]=HEAP32[$desc$08$i+8>>2]|0;HEAP32[$614+12>>2]=HEAP32[$desc$08$i+12>>2]|0;HEAP32[$614+16>>2]=HEAP32[$desc$08$i+16>>2]|0;HEAP32[$614+20>>2]=HEAP32[$desc$08$i+20>>2]|0;HEAP32[$614+24>>2]=HEAP32[$desc$08$i+24>>2]|0;HEAP32[$614+28>>2]=HEAP32[$desc$08$i+28>>2]|0;
        $615 = (($numWrittenConstraints$012$i) + 1)|0;
        $616 = (($612) + 1)|0;
        HEAP32[$611>>2] = $616;
        $numWrittenConstraints$1$i = $615;
       } else {
        $numWrittenConstraints$1$i = $numWrittenConstraints$012$i;
       }
      }
     }
    } while(0);
    $617 = (($i$07$i) + 1)|0;
    $618 = (($desc$08$i) + 32|0);
    $exitcond$i = ($617|0)==($10|0);
    if ($exitcond$i) {
     $numWrittenConstraints$0$lcssa$i = $numWrittenConstraints$1$i;$numWrittenConstraints$0$lcssa$i1163 = $numWrittenConstraints$1$i9;
     break;
    } else {
     $desc$08$i = $618;$i$07$i = $617;$numWrittenConstraints$012$i = $numWrittenConstraints$1$i;
    }
   }
  }
  $619 = (($numWrittenConstraints$0$lcssa$i) + ($numWrittenConstraints$0$lcssa$i1163))|0;
  $620 = HEAP8[$272>>0]|0;
  $621 = ($620<<24>>24)==(0);
  if ($621) {
   $numOrderedConstraints$0 = $619;
  } else {
   $622 = HEAP32[$_eaFsData>>2]|0;
   __ZN5physx6shdfnd13TempAllocator10deallocateEPv($_eaFsData,$622);
   $numOrderedConstraints$0 = $619;
  }
 }
 $623 = (($args) + 44|0);
 HEAP32[$623>>2] = 0;
 $624 = (($args) + 48|0);
 HEAP32[$624>>2] = $numOrderedConstraints$0;
 $625 = (($args) + 52|0);
 HEAP32[$625>>2] = 0;
 $a11$067 = 0;$maxPartition$068 = 0;
 while(1) {
  $628 = (($numConstraintsPerPartition) + ($a11$067<<2)|0);
  $629 = HEAP32[$628>>2]|0;
  $630 = ($629|0)==(0);
  $maxPartition$0$a11$0 = $630 ? $maxPartition$068 : $a11$067;
  $631 = (($a11$067) + 1)|0;
  $exitcond = ($631|0)==(32);
  if ($exitcond) {
   break;
  } else {
   $a11$067 = $631;$maxPartition$068 = $maxPartition$0$a11$0;
  }
 }
 $626 = (($args) + 64|0);
 $627 = HEAP32[$626>>2]|0;
 _memcpy(($627|0),($numConstraintsPerPartition|0),132)|0;
 STACKTOP = sp;return ($maxPartition$0$a11$0|0);
}
function __ZN5physx37UpdateAtomProgressesWithArticulationsEPNS_23PxcSolverConstraintDescEjjjPjj($eaOrderedConstraintDescriptors,$numConstraintDescriptors,$eaAtoms,$numAtoms,$eaFsDatas,$numArticulations) {
 $eaOrderedConstraintDescriptors = $eaOrderedConstraintDescriptors|0;
 $numConstraintDescriptors = $numConstraintDescriptors|0;
 $eaAtoms = $eaAtoms|0;
 $numAtoms = $numAtoms|0;
 $eaFsDatas = $eaFsDatas|0;
 $numArticulations = $numArticulations|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $9 = 0, $a$017 = 0, $bBodyA$0$off0815 = 0, $bBodyA$0$off0816 = 0, $bBodyB$0$off01013 = 0, $desc$019 = 0, $exitcond = 0, $maxProgress$0$lcssa = 0, $maxProgress$018 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($numConstraintDescriptors) + -1)|0;
 $1 = ($numConstraintDescriptors|0)==(0);
 if ($1) {
  $maxProgress$0$lcssa = 0;
  $78 = $maxProgress$0$lcssa&65535;
  STACKTOP = sp;return ($78|0);
 } else {
  $a$017 = 0;$desc$019 = $eaOrderedConstraintDescriptors;$maxProgress$018 = 0;
 }
 while(1) {
  $2 = (($0) - ($a$017))|0;
  $3 = ($2>>>0)<(4);
  $4 = $3 ? $2 : 4;
  $5 = (($desc$019) + ($4<<5)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($desc$019) + ($4<<5)|0) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($desc$019) + 256|0);
  $10 = (($desc$019) + 8|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = ($11<<16>>16)==(-1);
  $13 = (($desc$019) + 12|0);
  $14 = HEAP16[$13>>1]|0;
  $15 = ($14<<16>>16)==(-1);
  do {
   if ($12) {
    if ($15) {
     $16 = HEAP32[$desc$019>>2]|0;
     $17 = $16;
     $18 = (($17) - ($eaAtoms))|0;
     $19 = $18 >>> 5;
     $20 = (($desc$019) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = $21;
     $23 = (($22) - ($eaAtoms))|0;
     $24 = $23 >>> 5;
     $25 = ($19>>>0)<($numAtoms>>>0);
     $26 = ($24>>>0)<($numAtoms>>>0);
     if ($25) {
      $52 = (($16) + 12|0);
      $53 = HEAP16[$52>>1]|0;
      if ($26) {
       $79 = $16;$80 = $53;$bBodyA$0$off0816 = 1;
       label = 15;
       break;
      } else {
       $59 = $53;$61 = -1;$73 = $16;$75 = $21;$bBodyA$0$off0815 = 1;$bBodyB$0$off01013 = 0;
       break;
      }
     } else {
      if ($26) {
       $79 = $16;$80 = -1;$bBodyA$0$off0816 = 0;
       label = 15;
       break;
      } else {
       $59 = -1;$61 = -1;$73 = $16;$75 = $21;$bBodyA$0$off0815 = 0;$bBodyB$0$off01013 = 0;
       break;
      }
     }
    } else {
     label = 11;
    }
   } else {
    if (!($15)) {
     $27 = HEAP32[$desc$019>>2]|0;
     $28 = (($desc$019) + 4|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27|0)==($29|0);
     if (!($30)) {
      $50 = $27;
      label = 12;
      break;
     }
     if ($12) {
      label = 11;
      break;
     }
     if (!($15)) {
      $31 = HEAP32[$desc$019>>2]|0;
      $32 = (($desc$019) + 4|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($31|0)==($33|0);
      if ($34) {
       $50 = $31;
       label = 12;
       break;
      }
     }
    }
    $35 = (($desc$019) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36;
    $38 = (($37) - ($eaAtoms))|0;
    $39 = $38 >>> 5;
    $40 = ($39>>>0)<($numAtoms>>>0);
    $41 = HEAP32[$desc$019>>2]|0;
    $42 = (($41) + 12|0);
    $43 = HEAP16[$42>>1]|0;
    if ($40) {
     $79 = $41;$80 = $43;$bBodyA$0$off0816 = 1;
     label = 15;
    } else {
     $59 = $43;$61 = -1;$73 = $41;$75 = $36;$bBodyA$0$off0815 = 1;$bBodyB$0$off01013 = 0;
    }
   }
  } while(0);
  if ((label|0) == 11) {
   label = 0;
   $44 = HEAP32[$desc$019>>2]|0;
   $45 = $44;
   $46 = (($45) - ($eaAtoms))|0;
   $47 = $46 >>> 5;
   $48 = ($47>>>0)<($numAtoms>>>0);
   if ($48) {
    $50 = $44;
    label = 12;
   } else {
    $79 = $44;$80 = -1;$bBodyA$0$off0816 = 0;
    label = 15;
   }
  }
  if ((label|0) == 12) {
   label = 0;
   $49 = (($50) + 12|0);
   $51 = HEAP16[$49>>1]|0;
   $79 = $50;$80 = $51;$bBodyA$0$off0816 = 1;
   label = 15;
  }
  if ((label|0) == 15) {
   label = 0;
   $54 = (($desc$019) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($55) + 12|0);
   $57 = HEAP16[$56>>1]|0;
   $59 = $80;$61 = $57;$73 = $79;$75 = $55;$bBodyA$0$off0815 = $bBodyA$0$off0816;$bBodyB$0$off01013 = 1;
  }
  $58 = (($desc$019) + 28|0);
  HEAP16[$58>>1] = $59;
  $60 = (($desc$019) + 30|0);
  HEAP16[$60>>1] = $61;
  $62 = $59&65535;
  $63 = (($62) + 1)|0;
  $64 = $63&65535;
  $65 = $61&65535;
  $66 = (($65) + 1)|0;
  $67 = $66&65535;
  $68 = ($64&65535)<($67&65535);
  $69 = $68 ? $67 : $64;
  $70 = ($maxProgress$018&65535)<($69&65535);
  $71 = $70 ? $69 : $maxProgress$018;
  if ($bBodyA$0$off0815) {
   $72 = (($73) + 12|0);
   HEAP16[$72>>1] = $64;
  }
  if ($bBodyB$0$off01013) {
   $74 = (($75) + 12|0);
   HEAP16[$74>>1] = $67;
  }
  $76 = (($a$017) + 1)|0;
  $77 = (($desc$019) + 32|0);
  $exitcond = ($76|0)==($numConstraintDescriptors|0);
  if ($exitcond) {
   $maxProgress$0$lcssa = $71;
   break;
  } else {
   $a$017 = $76;$desc$019 = $77;$maxProgress$018 = $71;
  }
 }
 $78 = $maxProgress$0$lcssa&65535;
 STACKTOP = sp;return ($78|0);
}
function __ZN5physx45UpdateAtomFrictionProgressesWithArticulationsEPNS_23PxcSolverConstraintDescEjjjPjj($eaOrderedConstraintDescriptors,$numConstraintDescriptors,$eaAtoms,$numAtoms,$eaFsDatas,$numArticulations) {
 $eaOrderedConstraintDescriptors = $eaOrderedConstraintDescriptors|0;
 $numConstraintDescriptors = $numConstraintDescriptors|0;
 $eaAtoms = $eaAtoms|0;
 $numAtoms = $numAtoms|0;
 $eaFsDatas = $eaFsDatas|0;
 $numArticulations = $numArticulations|0;
 var $$phi$trans$insert$phi$trans$insert = 0, $$phi$trans$insert40 = 0, $$pre = 0, $$pre$pre = 0, $$pre41 = 0, $$pre44 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $a$030 = 0, $desc$031 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($numConstraintDescriptors) + -1)|0;
 $1 = ($numConstraintDescriptors|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $a$030 = 0;$desc$031 = $eaOrderedConstraintDescriptors;
 }
 while(1) {
  $2 = (($0) - ($a$030))|0;
  $3 = ($2>>>0)<(4);
  $4 = $3 ? $2 : 4;
  $5 = (($desc$031) + ($4<<5)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($desc$031) + ($4<<5)|0) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($desc$031) + 256|0);
  $10 = (($desc$031) + 8|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = ($11<<16>>16)==(-1);
  $13 = (($desc$031) + 12|0);
  $14 = HEAP16[$13>>1]|0;
  $15 = ($14<<16>>16)==(-1);
  do {
   if ($12) {
    if ($15) {
     $16 = HEAP32[$desc$031>>2]|0;
     $17 = $16;
     $18 = (($17) - ($eaAtoms))|0;
     $19 = $18 >>> 5;
     $20 = (($desc$031) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = $21;
     $23 = (($22) - ($eaAtoms))|0;
     $24 = $23 >>> 5;
     $25 = ($19>>>0)<($numAtoms>>>0);
     $26 = ($24>>>0)<($numAtoms>>>0);
     if ($25) {
      $55 = (($16) + 14|0);
      $56 = HEAP16[$55>>1]|0;
      $57 = (($desc$031) + 28|0);
      HEAP16[$57>>1] = $56;
      if ($26) {
       $68 = $21;$72 = $56;$76 = $16;
       label = 19;
       break;
      } else {
       $62 = $56;$66 = $16;
       label = 18;
       break;
      }
     }
     $58 = (($desc$031) + 28|0);
     HEAP16[$58>>1] = -1;
     if ($26) {
      $78 = $21;
      label = 20;
     } else {
      $59 = (($desc$031) + 30|0);
      HEAP16[$59>>1] = -1;
     }
    } else {
     label = 11;
    }
   } else {
    if (!($15)) {
     $27 = HEAP32[$desc$031>>2]|0;
     $28 = (($desc$031) + 4|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27|0)==($29|0);
     if (!($30)) {
      $$pre = $29;$52 = $27;
      label = 14;
      break;
     }
     if ($12) {
      label = 11;
      break;
     }
     if (!($15)) {
      $31 = HEAP32[$desc$031>>2]|0;
      $32 = (($desc$031) + 4|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($31|0)==($33|0);
      if ($34) {
       $$pre = $31;$52 = $31;
       label = 14;
       break;
      }
     }
    }
    $35 = (($desc$031) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36;
    $38 = (($37) - ($eaAtoms))|0;
    $39 = $38 >>> 5;
    $40 = ($39>>>0)<($numAtoms>>>0);
    $41 = HEAP32[$desc$031>>2]|0;
    $42 = (($41) + 14|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = (($desc$031) + 28|0);
    HEAP16[$44>>1] = $43;
    if ($40) {
     $68 = $36;$72 = $43;$76 = $41;
     label = 19;
    } else {
     $62 = $43;$66 = $41;
     label = 18;
    }
   }
  } while(0);
  do {
   if ((label|0) == 11) {
    label = 0;
    $45 = HEAP32[$desc$031>>2]|0;
    $46 = $45;
    $47 = (($46) - ($eaAtoms))|0;
    $48 = $47 >>> 5;
    $49 = ($48>>>0)<($numAtoms>>>0);
    if ($49) {
     $$phi$trans$insert$phi$trans$insert = (($desc$031) + 4|0);
     $$pre$pre = HEAP32[$$phi$trans$insert$phi$trans$insert>>2]|0;
     $$pre = $$pre$pre;$52 = $45;
     label = 14;
     break;
    } else {
     $50 = (($desc$031) + 28|0);
     HEAP16[$50>>1] = -1;
     $$phi$trans$insert40 = (($desc$031) + 4|0);
     $$pre41 = HEAP32[$$phi$trans$insert40>>2]|0;
     $78 = $$pre41;
     label = 20;
     break;
    }
   }
   else if ((label|0) == 18) {
    label = 0;
    $60 = (($desc$031) + 30|0);
    HEAP16[$60>>1] = -1;
    $61 = $62&65535;
    $63 = (($61) + 1)|0;
    $64 = $63&65535;
    $65 = (($66) + 14|0);
    HEAP16[$65>>1] = $64;
   }
  } while(0);
  if ((label|0) == 14) {
   label = 0;
   $51 = (($52) + 14|0);
   $53 = HEAP16[$51>>1]|0;
   $54 = (($desc$031) + 28|0);
   HEAP16[$54>>1] = $53;
   $68 = $$pre;$72 = $53;$76 = $52;
   label = 19;
  }
  else if ((label|0) == 20) {
   label = 0;
   $77 = (($78) + 14|0);
   $79 = HEAP16[$77>>1]|0;
   $80 = (($desc$031) + 30|0);
   HEAP16[$80>>1] = $79;
   $82 = $79;$86 = $78;
   label = 21;
  }
  if ((label|0) == 19) {
   label = 0;
   $67 = (($68) + 14|0);
   $69 = HEAP16[$67>>1]|0;
   $70 = (($desc$031) + 30|0);
   HEAP16[$70>>1] = $69;
   $71 = $72&65535;
   $73 = (($71) + 1)|0;
   $74 = $73&65535;
   $75 = (($76) + 14|0);
   HEAP16[$75>>1] = $74;
   $$pre44 = HEAP16[$70>>1]|0;
   $82 = $$pre44;$86 = $68;
   label = 21;
  }
  if ((label|0) == 21) {
   label = 0;
   $81 = $82&65535;
   $83 = (($81) + 1)|0;
   $84 = $83&65535;
   $85 = (($86) + 14|0);
   HEAP16[$85>>1] = $84;
  }
  $87 = (($a$030) + 1)|0;
  $88 = (($desc$031) + 32|0);
  $exitcond = ($87|0)==($numConstraintDescriptors|0);
  if ($exitcond) {
   break;
  } else {
   $a$030 = $87;$desc$031 = $88;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx33PostProcessConstraintPartitioningEPNS_13PxcSolverBodyEjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjPNS_24PxcFsSelfConstraintBlockEj($atoms,$numAtoms,$articulationDescs,$numArticulations,$eaOrderedConstraintDescriptors,$numConstraintDescriptors,$selfConstraintBlocks,$numSelfConstraintBlocks) {
 $atoms = $atoms|0;
 $numAtoms = $numAtoms|0;
 $articulationDescs = $articulationDescs|0;
 $numArticulations = $numArticulations|0;
 $eaOrderedConstraintDescriptors = $eaOrderedConstraintDescriptors|0;
 $numConstraintDescriptors = $numConstraintDescriptors|0;
 $selfConstraintBlocks = $selfConstraintBlocks|0;
 $numSelfConstraintBlocks = $numSelfConstraintBlocks|0;
 var $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $_eaFsData = 0, $a$01$i = 0, $a$06 = 0, $a3$01 = 0, $b$02 = 0, $desc$02$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond20 = 0, $exitcond21 = 0, $exitcond22 = 0, $i$015 = 0, $i1$011 = 0, $maxAtomProgress$0$lcssa$i = 0, $maxAtomProgress$03$i = 0, $maxProgress$0 = 0, $totalConstraintCount$0$lcssa = 0, $totalConstraintCount$07 = 0, $totalConstraintCount$1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_eaFsData = sp;
 $0 = sp + 8|0;
 $1 = $atoms;
 $2 = ($numAtoms|0)==(0);
 if (!($2)) {
  $i$015 = 0;
  while(1) {
   $$sum = (($i$015) + 8)|0;
   $3 = (($atoms) + ($$sum<<5)|0);
   $4 = ((($atoms) + ($i$015<<5)|0) + 28|0);
   HEAP32[$4>>2] = 0;
   $5 = ((($atoms) + ($i$015<<5)|0) + 12|0);
   HEAP16[$5>>1] = 0;
   $6 = (($i$015) + 1)|0;
   $exitcond22 = ($6|0)==($numAtoms|0);
   if ($exitcond22) {
    break;
   } else {
    $i$015 = $6;
   }
  }
 }
 $7 = ($numArticulations|0)==(0);
 if ($7) {
  $8 = (($numConstraintDescriptors) + -1)|0;
  $9 = ($numConstraintDescriptors|0)==(0);
  if ($9) {
   $maxAtomProgress$0$lcssa$i = 0;
  } else {
   $a$01$i = 0;$desc$02$i = $eaOrderedConstraintDescriptors;$maxAtomProgress$03$i = 0;
   while(1) {
    $10 = (($8) - ($a$01$i))|0;
    $11 = ($10>>>0)<(4);
    $12 = $10 & 65535;
    $13 = $11 ? $12 : 4;
    $14 = (($desc$02$i) + ($13<<5)|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ((($desc$02$i) + ($13<<5)|0) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($desc$02$i) + 256|0);
    $19 = HEAP32[$desc$02$i>>2]|0;
    $20 = $19;
    $21 = (($20) - ($1))|0;
    $22 = $21 >>> 5;
    $23 = (($desc$02$i) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = $24;
    $26 = (($25) - ($1))|0;
    $27 = $26 >>> 5;
    $28 = ($22>>>0)<($numAtoms>>>0);
    if ($28) {
     $29 = (($19) + 12|0);
     $30 = HEAP16[$29>>1]|0;
     $35 = $30;
    } else {
     $35 = -1;
    }
    $31 = ($27>>>0)<($numAtoms>>>0);
    if ($31) {
     $32 = (($24) + 12|0);
     $33 = HEAP16[$32>>1]|0;
     $37 = $33;
    } else {
     $37 = -1;
    }
    $34 = (($desc$02$i) + 28|0);
    HEAP16[$34>>1] = $35;
    $36 = (($desc$02$i) + 30|0);
    HEAP16[$36>>1] = $37;
    $38 = $35&65535;
    $39 = (($38) + 1)|0;
    $40 = $39&65535;
    $41 = $37&65535;
    $42 = (($41) + 1)|0;
    $43 = $42&65535;
    $44 = ($40&65535)<($43&65535);
    $45 = $44 ? $43 : $40;
    $46 = ($maxAtomProgress$03$i&65535)<($45&65535);
    $47 = $46 ? $45 : $maxAtomProgress$03$i;
    if ($28) {
     $48 = (($19) + 12|0);
     HEAP16[$48>>1] = $40;
    }
    if ($31) {
     $49 = (($24) + 12|0);
     HEAP16[$49>>1] = $43;
    }
    $50 = (($a$01$i) + 1)|0;
    $51 = (($desc$02$i) + 32|0);
    $exitcond$i = ($50|0)==($numConstraintDescriptors|0);
    if ($exitcond$i) {
     $maxAtomProgress$0$lcssa$i = $47;
     break;
    } else {
     $a$01$i = $50;$desc$02$i = $51;$maxAtomProgress$03$i = $47;
    }
   }
  }
  $52 = $maxAtomProgress$0$lcssa$i&65535;
  $maxProgress$0 = $52;$totalConstraintCount$1 = $numConstraintDescriptors;
 } else {
  $53 = $numArticulations << 2;
  $54 = ($53>>>0)>(1024);
  $55 = (($_eaFsData) + 4|0);
  $56 = $54&1;
  HEAP8[$55>>0] = $56;
  if ($54) {
   $57 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$53,488456,1294)|0);
   HEAP32[$_eaFsData>>2] = $57;
   $63 = $57;
  } else {
   $58 = STACKTOP; STACKTOP = STACKTOP + ((((1*$53)|0)+15)&-16)|0;;
   HEAP32[$_eaFsData>>2] = $58;
   $63 = $58;
  }
  $i1$011 = 0;
  while(1) {
   $59 = (($articulationDescs) + (($i1$011*40)|0)|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = $60;
   $62 = (($63) + ($i1$011<<2)|0);
   HEAP32[$62>>2] = $61;
   $64 = (($60) + 28|0);
   HEAP32[$64>>2] = 0;
   $65 = (($60) + 14|0);
   HEAP16[$65>>1] = 0;
   $66 = (($60) + 12|0);
   HEAP16[$66>>1] = 0;
   $67 = (($i1$011) + 1)|0;
   $exitcond21 = ($67|0)==($numArticulations|0);
   if ($exitcond21) {
    break;
   } else {
    $i1$011 = $67;
   }
  }
  $68 = (__ZN5physx37UpdateAtomProgressesWithArticulationsEPNS_23PxcSolverConstraintDescEjjjPjj($eaOrderedConstraintDescriptors,$numConstraintDescriptors,$1,$numAtoms,$63,$numArticulations)|0);
  $69 = ($numSelfConstraintBlocks|0)==(0);
  if ($69) {
   $totalConstraintCount$0$lcssa = $numConstraintDescriptors;
  } else {
   $a$06 = 0;$totalConstraintCount$07 = $numConstraintDescriptors;
   while(1) {
    $70 = ((($selfConstraintBlocks) + ($a$06<<4)|0) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($71) + ($totalConstraintCount$07))|0;
    $73 = ($71|0)==(0);
    if (!($73)) {
     $74 = ((($selfConstraintBlocks) + ($a$06<<4)|0) + 12|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = $75;
     $77 = (($76) + 12|0);
     $78 = HEAP16[$77>>1]|0;
     $79 = (($selfConstraintBlocks) + ($a$06<<4)|0);
     $80 = HEAP32[$79>>2]|0;
     $b$02 = 0;
     while(1) {
      $81 = (($80) + ($b$02))|0;
      $82 = ((($eaOrderedConstraintDescriptors) + ($81<<5)|0) + 28|0);
      HEAP16[$82>>1] = $78;
      $83 = ((($eaOrderedConstraintDescriptors) + ($81<<5)|0) + 30|0);
      HEAP16[$83>>1] = $78;
      $84 = (($b$02) + 1)|0;
      $85 = ($84>>>0)<($71>>>0);
      if ($85) {
       $b$02 = $84;
      } else {
       break;
      }
     }
     $$pre = HEAP16[$77>>1]|0;
     $86 = (($$pre) + 1)<<16>>16;
     HEAP16[$77>>1] = $86;
    }
    $87 = (($a$06) + 1)|0;
    $exitcond20 = ($87|0)==($numSelfConstraintBlocks|0);
    if ($exitcond20) {
     $totalConstraintCount$0$lcssa = $72;
     break;
    } else {
     $a$06 = $87;$totalConstraintCount$07 = $72;
    }
   }
  }
  $88 = HEAP8[$55>>0]|0;
  $89 = ($88<<24>>24)==(0);
  if ($89) {
   $maxProgress$0 = $68;$totalConstraintCount$1 = $totalConstraintCount$0$lcssa;
  } else {
   $90 = HEAP32[$_eaFsData>>2]|0;
   __ZN5physx6shdfnd13TempAllocator10deallocateEPv($_eaFsData,$90);
   $maxProgress$0 = $68;$totalConstraintCount$1 = $totalConstraintCount$0$lcssa;
  }
 }
 $91 = ($totalConstraintCount$1|0)==(0);
 if ($91) {
  STACKTOP = sp;return ($maxProgress$0|0);
 }
 $92 = ($totalConstraintCount$1>>>0)<(3);
 $93 = $92 ? $totalConstraintCount$1 : 3;
 $a3$01 = 0;
 while(1) {
  $94 = (($a3$01) + ($totalConstraintCount$1))|0;
  $95 = (($eaOrderedConstraintDescriptors) + ($94<<5)|0);
  $96 = (($eaOrderedConstraintDescriptors) + ($a3$01<<5)|0);
  ;HEAP32[$95+0>>2]=HEAP32[$96+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$95+12>>2]=HEAP32[$96+12>>2]|0;HEAP32[$95+16>>2]=HEAP32[$96+16>>2]|0;HEAP32[$95+20>>2]=HEAP32[$96+20>>2]|0;HEAP32[$95+24>>2]=HEAP32[$96+24>>2]|0;HEAP32[$95+28>>2]=HEAP32[$96+28>>2]|0;
  $97 = (($a3$01) + 1)|0;
  $exitcond = ($97|0)==($93|0);
  if ($exitcond) {
   break;
  } else {
   $a3$01 = $97;
  }
 }
 STACKTOP = sp;return ($maxProgress$0|0);
}
function __ZN5physx41PostProcessFrictionConstraintPartitioningEPNS_13PxcSolverBodyEjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjPNS_24PxcFsSelfConstraintBlockEj($atoms,$numAtoms,$articulationDescs,$numArticulations,$eaOrderedConstraintDescriptors,$numConstraintDescriptors,$selfConstraintBlocks,$numSelfConstraintBlocks) {
 $atoms = $atoms|0;
 $numAtoms = $numAtoms|0;
 $articulationDescs = $articulationDescs|0;
 $numArticulations = $numArticulations|0;
 $eaOrderedConstraintDescriptors = $eaOrderedConstraintDescriptors|0;
 $numConstraintDescriptors = $numConstraintDescriptors|0;
 $selfConstraintBlocks = $selfConstraintBlocks|0;
 $numSelfConstraintBlocks = $numSelfConstraintBlocks|0;
 var $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_eaFsData = 0, $a$01$i = 0, $a$02 = 0, $b$01 = 0, $desc$02$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond14 = 0, $exitcond15 = 0, $i$010 = 0, $i1$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_eaFsData = sp;
 $0 = sp + 8|0;
 $1 = $atoms;
 $2 = ($numAtoms|0)==(0);
 if (!($2)) {
  $i$010 = 0;
  while(1) {
   $$sum = (($i$010) + 8)|0;
   $3 = (($atoms) + ($$sum<<5)|0);
   $4 = ((($atoms) + ($i$010<<5)|0) + 28|0);
   HEAP32[$4>>2] = 0;
   $5 = ((($atoms) + ($i$010<<5)|0) + 14|0);
   HEAP16[$5>>1] = 0;
   $6 = (($i$010) + 1)|0;
   $exitcond15 = ($6|0)==($numAtoms|0);
   if ($exitcond15) {
    break;
   } else {
    $i$010 = $6;
   }
  }
 }
 $7 = ($numArticulations|0)==(0);
 if ($7) {
  $8 = (($numConstraintDescriptors) + -1)|0;
  $9 = ($numConstraintDescriptors|0)==(0);
  if ($9) {
   STACKTOP = sp;return;
  } else {
   $a$01$i = 0;$desc$02$i = $eaOrderedConstraintDescriptors;
  }
  while(1) {
   $10 = (($8) - ($a$01$i))|0;
   $11 = ($10>>>0)<(4);
   $12 = $11 ? $10 : 4;
   $13 = (($desc$02$i) + ($12<<5)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($desc$02$i) + ($12<<5)|0) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($desc$02$i) + 256|0);
   $18 = HEAP32[$desc$02$i>>2]|0;
   $19 = $18;
   $20 = (($19) - ($1))|0;
   $21 = $20 >>> 5;
   $22 = (($desc$02$i) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23;
   $25 = (($24) - ($1))|0;
   $26 = $25 >>> 5;
   $27 = ($21>>>0)<($numAtoms>>>0);
   if ($27) {
    $28 = (($18) + 14|0);
    $29 = HEAP16[$28>>1]|0;
    $34 = $29;
   } else {
    $34 = -1;
   }
   $30 = ($26>>>0)<($numAtoms>>>0);
   if ($30) {
    $31 = (($23) + 14|0);
    $32 = HEAP16[$31>>1]|0;
    $36 = $32;
   } else {
    $36 = -1;
   }
   $33 = (($desc$02$i) + 28|0);
   HEAP16[$33>>1] = $34;
   $35 = (($desc$02$i) + 30|0);
   HEAP16[$35>>1] = $36;
   if ($27) {
    $37 = $34&65535;
    $38 = (($37) + 1)|0;
    $39 = $38&65535;
    $40 = (($18) + 14|0);
    HEAP16[$40>>1] = $39;
   }
   if ($30) {
    $41 = $36&65535;
    $42 = (($41) + 1)|0;
    $43 = $42&65535;
    $44 = (($23) + 14|0);
    HEAP16[$44>>1] = $43;
   }
   $45 = (($a$01$i) + 1)|0;
   $46 = (($desc$02$i) + 32|0);
   $exitcond$i = ($45|0)==($numConstraintDescriptors|0);
   if ($exitcond$i) {
    break;
   } else {
    $a$01$i = $45;$desc$02$i = $46;
   }
  }
  STACKTOP = sp;return;
 }
 $47 = $numArticulations << 2;
 $48 = ($47>>>0)>(1024);
 $49 = (($_eaFsData) + 4|0);
 $50 = $48&1;
 HEAP8[$49>>0] = $50;
 if ($48) {
  $51 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$47,488456,1362)|0);
  HEAP32[$_eaFsData>>2] = $51;
  $57 = $51;
 } else {
  $52 = STACKTOP; STACKTOP = STACKTOP + ((((1*$47)|0)+15)&-16)|0;;
  HEAP32[$_eaFsData>>2] = $52;
  $57 = $52;
 }
 $i1$06 = 0;
 while(1) {
  $53 = (($articulationDescs) + (($i1$06*40)|0)|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = $54;
  $56 = (($57) + ($i1$06<<2)|0);
  HEAP32[$56>>2] = $55;
  $58 = (($54) + 28|0);
  HEAP32[$58>>2] = 0;
  $59 = (($54) + 14|0);
  HEAP16[$59>>1] = 0;
  $60 = (($i1$06) + 1)|0;
  $exitcond14 = ($60|0)==($numArticulations|0);
  if ($exitcond14) {
   break;
  } else {
   $i1$06 = $60;
  }
 }
 __ZN5physx45UpdateAtomFrictionProgressesWithArticulationsEPNS_23PxcSolverConstraintDescEjjjPjj($eaOrderedConstraintDescriptors,$numConstraintDescriptors,$1,$numAtoms,$57,$numArticulations);
 $61 = ($numSelfConstraintBlocks|0)==(0);
 if (!($61)) {
  $a$02 = 0;
  while(1) {
   $62 = ((($selfConstraintBlocks) + ($a$02<<4)|0) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0);
   if (!($64)) {
    $65 = ((($selfConstraintBlocks) + ($a$02<<4)|0) + 12|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = $66;
    $68 = (($67) + 14|0);
    $69 = HEAP16[$68>>1]|0;
    $70 = (($selfConstraintBlocks) + ($a$02<<4)|0);
    $71 = HEAP32[$70>>2]|0;
    $b$01 = 0;
    while(1) {
     $72 = (($71) + ($b$01))|0;
     $73 = ((($eaOrderedConstraintDescriptors) + ($72<<5)|0) + 28|0);
     HEAP16[$73>>1] = $69;
     $74 = ((($eaOrderedConstraintDescriptors) + ($72<<5)|0) + 30|0);
     HEAP16[$74>>1] = $69;
     $75 = (($b$01) + 1)|0;
     $76 = ($75>>>0)<($63>>>0);
     if ($76) {
      $b$01 = $75;
     } else {
      break;
     }
    }
    $$pre = HEAP16[$68>>1]|0;
    $77 = (($$pre) + 1)<<16>>16;
    HEAP16[$68>>1] = $77;
   }
   $78 = (($a$02) + 1)|0;
   $exitcond = ($78|0)==($numSelfConstraintBlocks|0);
   if ($exitcond) {
    break;
   } else {
    $a$02 = $78;
   }
  }
 }
 $79 = HEAP8[$49>>0]|0;
 $80 = ($79<<24>>24)==(0);
 if ($80) {
  STACKTOP = sp;return;
 }
 $81 = HEAP32[$_eaFsData>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($_eaFsData,$81);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 3;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 488664 : 488632;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,488552,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = $$03$i;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = $$012$i;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
   }
   $30 = (($$012$i) + 8|0);
   $31 = (($$03$i) + 8|0);
   $32 = ($30>>>0)<($15>>>0);
   if ($32) {
    $$012$i = $30;$$03$i = $31;
   } else {
    break;
   }
  }
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$this>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  HEAP32[$this>>2] = $16;
  HEAP32[$33>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$36);
 HEAP32[$this>>2] = $16;
 HEAP32[$33>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx14preprocessRowsEPPNS_14Px1DConstraintES1_jRKNS_17PxcSolverBodyDataES5_RKNS_24PxConstraintInvMassScaleEbb($sorted,$rows,$rowCount,$bd0,$bd1,$ims,$isExtended,$diagonalizeDrive) {
 $sorted = $sorted|0;
 $rows = $rows|0;
 $rowCount = $rowCount|0;
 $bd0 = $bd0|0;
 $bd1 = $bd1|0;
 $ims = $ims|0;
 $isExtended = $isExtended|0;
 $diagonalizeDrive = $diagonalizeDrive|0;
 var $$lcssa$i = Math_fround(0), $$lcssa688$i = Math_fround(0), $$lcssa689$i = Math_fround(0), $$lcssa690$i = Math_fround(0), $$lcssa691$i = Math_fround(0), $$lcssa692$i = Math_fround(0), $$lcssa693$i = Math_fround(0), $$lcssa694$i = Math_fround(0), $$lcssa695$i = Math_fround(0), $$lcssa696$i = Math_fround(0), $$lcssa697$i = Math_fround(0), $$lcssa698$i = Math_fround(0), $$lcssa699$i = Math_fround(0), $$lcssa700$i = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert56 = 0, $$phi$trans$insert734$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0;
 var $$pre57 = 0, $$pre735$i = Math_fround(0), $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0;
 var $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0);
 var $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0);
 var $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0);
 var $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0);
 var $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0);
 var $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0);
 var $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0);
 var $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = 0;
 var $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0);
 var $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $ang0AndT$i = 0, $ang0m$i = 0, $ang1$i = 0, $ang1m$i = 0, $bCount$0$lcssa = 0, $bCount$05 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond732$i = 0, $i$029 = 0, $i$0715$i = 0, $i2$023 = 0, $i2$1 = 0;
 var $i2$1$in = 0, $indvars$iv$i = 0, $indvars$iv$next$i = 0, $j$0$lcssa = 0, $j$026 = 0, $j$0701$i = 0, $lin0AndG$i = 0, $lin0m$i = 0, $lin1$i = 0, $lin1m$i = 0, $m = 0, $slerp$0$lcssa = 0, $slerp$020 = 0, $umax$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 896|0;
 $lin1m$i = sp + 800|0;
 $ang1m$i = sp + 704|0;
 $lin1$i = sp + 608|0;
 $ang1$i = sp + 512|0;
 $lin0m$i = sp + 416|0;
 $ang0m$i = sp + 192|0;
 $lin0AndG$i = sp + 96|0;
 $ang0AndT$i = sp;
 $m = sp + 288|0;
 $0 = ($rowCount|0)==(0);
 if (!($0)) {
  $i$029 = 0;
  while(1) {
   $1 = (($rows) + (($i$029*80)|0)|0);
   $2 = ($i$029|0)==(0);
   L4: do {
    if ($2) {
     $j$0$lcssa = 0;
    } else {
     $3 = ((($rows) + (($i$029*80)|0)|0) + 78|0);
     $4 = HEAP16[$3>>1]|0;
     $j$026 = $i$029;
     while(1) {
      $5 = (($j$026) + -1)|0;
      $6 = (($sorted) + ($5<<2)|0);
      $7 = HEAP32[$6>>2]|0;
      $8 = (($7) + 78|0);
      $9 = HEAP16[$8>>1]|0;
      $10 = ($4&65535)<($9&65535);
      if (!($10)) {
       $j$0$lcssa = $j$026;
       break L4;
      }
      $11 = (($sorted) + ($j$026<<2)|0);
      HEAP32[$11>>2] = $7;
      $12 = ($5|0)==(0);
      if ($12) {
       $j$0$lcssa = 0;
       break;
      } else {
       $j$026 = $5;
      }
     }
    }
   } while(0);
   $13 = (($sorted) + ($j$0$lcssa<<2)|0);
   HEAP32[$13>>2] = $1;
   $14 = (($i$029) + 1)|0;
   $exitcond = ($14|0)==($rowCount|0);
   if ($exitcond) {
    break;
   } else {
    $i$029 = $14;
   }
  }
 }
 if ($isExtended) {
  STACKTOP = sp;return;
 }
 $15 = Math_fround(HEAPF32[$bd0>>2]);
 $16 = (($bd0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($bd0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($bd0) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($bd0) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($bd0) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($bd0) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($bd0) + 28|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($bd0) + 32|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($ims) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($15 * $33);
 $35 = Math_fround($17 * $33);
 $36 = Math_fround($19 * $33);
 $37 = Math_fround($21 * $33);
 $38 = Math_fround($23 * $33);
 $39 = Math_fround($25 * $33);
 $40 = Math_fround($27 * $33);
 $41 = Math_fround($29 * $33);
 $42 = Math_fround($31 * $33);
 HEAPF32[$m>>2] = $34;
 $43 = (($m) + 4|0);
 HEAPF32[$43>>2] = $35;
 $44 = (($m) + 8|0);
 HEAPF32[$44>>2] = $36;
 $45 = (($m) + 12|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($m) + 16|0);
 HEAPF32[$46>>2] = $37;
 $47 = (($m) + 20|0);
 HEAPF32[$47>>2] = $38;
 $48 = (($m) + 24|0);
 HEAPF32[$48>>2] = $39;
 $49 = (($m) + 28|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($m) + 32|0);
 HEAPF32[$50>>2] = $40;
 $51 = (($m) + 36|0);
 HEAPF32[$51>>2] = $41;
 $52 = (($m) + 40|0);
 HEAPF32[$52>>2] = $42;
 $53 = (($m) + 44|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = Math_fround(HEAPF32[$bd1>>2]);
 $55 = (($bd1) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($bd1) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($bd1) + 12|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($bd1) + 16|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($bd1) + 20|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($bd1) + 24|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($bd1) + 28|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($bd1) + 32|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($ims) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($54 * $72);
 $74 = Math_fround($56 * $72);
 $75 = Math_fround($58 * $72);
 $76 = Math_fround($60 * $72);
 $77 = Math_fround($62 * $72);
 $78 = Math_fround($64 * $72);
 $79 = Math_fround($66 * $72);
 $80 = Math_fround($68 * $72);
 $81 = Math_fround($70 * $72);
 $82 = (($m) + 48|0);
 HEAPF32[$82>>2] = $73;
 $83 = (($m) + 52|0);
 HEAPF32[$83>>2] = $74;
 $84 = (($m) + 56|0);
 HEAPF32[$84>>2] = $75;
 $85 = (($m) + 60|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 $86 = (($m) + 64|0);
 HEAPF32[$86>>2] = $76;
 $87 = (($m) + 68|0);
 HEAPF32[$87>>2] = $77;
 $88 = (($m) + 72|0);
 HEAPF32[$88>>2] = $78;
 $89 = (($m) + 76|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 $90 = (($m) + 80|0);
 HEAPF32[$90>>2] = $79;
 $91 = (($m) + 84|0);
 HEAPF32[$91>>2] = $80;
 $92 = (($m) + 88|0);
 HEAPF32[$92>>2] = $81;
 $93 = (($m) + 92|0);
 HEAPF32[$93>>2] = Math_fround(0.0);
 $94 = (($bd0) + 48|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround(HEAPF32[$ims>>2]);
 $97 = Math_fround($95 * $96);
 $98 = (($m) + 96|0);
 HEAPF32[$98>>2] = $97;
 $99 = (($bd1) + 48|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($ims) + 8|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($100 * $102);
 $104 = (($m) + 112|0);
 HEAPF32[$104>>2] = $103;
 if ($0) {
  STACKTOP = sp;return;
 }
 $i2$023 = 0;
 while(1) {
  $105 = (($sorted) + ($i2$023<<2)|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($106) + 78|0);
  $108 = HEAP16[$107>>1]|0;
  $109 = $108&65535;
  $110 = $109 >>> 8;
  $i2$1$in = $i2$023;
  while(1) {
   $i2$1 = (($i2$1$in) + 1)|0;
   $111 = ($i2$1>>>0)<($rowCount>>>0);
   if (!($111)) {
    break;
   }
   $112 = (($sorted) + ($i2$1<<2)|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = (($113) + 78|0);
   $115 = HEAP16[$114>>1]|0;
   $116 = $115&65535;
   $117 = $116 >>> 8;
   $118 = ($117|0)==($110|0);
   if ($118) {
    $i2$1$in = $i2$1;
   } else {
    break;
   }
  }
  if ((($110|0) == 1)) {
   if ($diagonalizeDrive) {
    $431 = ($i2$023>>>0)<($i2$1>>>0);
    L26: do {
     if ($431) {
      $slerp$020 = $i2$023;
      while(1) {
       $434 = (($sorted) + ($slerp$020<<2)|0);
       $435 = HEAP32[$434>>2]|0;
       $436 = (($435) + 78|0);
       $437 = HEAP16[$436>>1]|0;
       $438 = $437 & 255;
       $439 = ($438<<16>>16)==(2);
       $433 = (($slerp$020) + 1)|0;
       if ($439) {
        $slerp$0$lcssa = $slerp$020;
        break L26;
       }
       $432 = ($433>>>0)<($i2$1>>>0);
       if ($432) {
        $slerp$020 = $433;
       } else {
        $slerp$0$lcssa = $433;
        break;
       }
      }
     } else {
      $slerp$0$lcssa = $i2$023;
     }
    } while(0);
    $440 = (($slerp$0$lcssa) + 2)|0;
    $441 = ($440|0)==($i2$1$in|0);
    if ($441) {
     $442 = (($sorted) + ($slerp$0$lcssa<<2)|0);
     __ZN5physx12_GLOBAL__N_111diagonalizeEPPNS_14Px1DConstraintERKNS0_9MassPropsE($442,$m);
    }
    __ZN5physx12_GLOBAL__N_111diagonalizeEPPNS_14Px1DConstraintERKNS0_9MassPropsE($105,$m);
   }
  } else if ((($110|0) == 4)) {
   $119 = ($i2$023>>>0)<($i2$1>>>0);
   L35: do {
    if ($119) {
     $123 = $108;$bCount$05 = $i2$023;
     while(1) {
      $122 = $123 & 255;
      $124 = ($122<<16>>16)==(0);
      $121 = (($bCount$05) + 1)|0;
      if (!($124)) {
       $bCount$0$lcssa = $bCount$05;
       break L35;
      }
      $120 = ($121>>>0)<($i2$1>>>0);
      if (!($120)) {
       $bCount$0$lcssa = $121;
       break L35;
      }
      $$phi$trans$insert = (($sorted) + ($121<<2)|0);
      $$pre = HEAP32[$$phi$trans$insert>>2]|0;
      $$phi$trans$insert56 = (($$pre) + 78|0);
      $$pre57 = HEAP16[$$phi$trans$insert56>>1]|0;
      $123 = $$pre57;$bCount$05 = $121;
     }
    } else {
     $bCount$0$lcssa = $i2$023;
    }
   } while(0);
   $125 = (($i2$1) - ($i2$023))|0;
   $126 = (($bCount$0$lcssa) - ($i2$023))|0;
   $127 = ($i2$1|0)==($i2$023|0);
   if (!($127)) {
    $128 = $126 ^ -1;
    $i$0715$i = 0;$indvars$iv$i = -1;
    while(1) {
     $129 = ($indvars$iv$i>>>0)>($128>>>0);
     $umax$i = $129 ? $indvars$iv$i : $128;
     $130 = $umax$i ^ -1;
     $$sum = (($i$0715$i) + ($i2$023))|0;
     $131 = (($sorted) + ($$sum<<2)|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = (($132) + 76|0);
     $134 = HEAP16[$133>>1]|0;
     $135 = $134 & 8;
     $136 = ($135<<16>>16)==(0);
     if ($136) {
      $$phi$trans$insert734$i = (($132) + 12|0);
      $$pre735$i = Math_fround(HEAPF32[$$phi$trans$insert734$i>>2]);
      $$pre$phi$iZ2D = $132;$140 = Math_fround(0.0);$443 = $$pre735$i;
     } else {
      $137 = (($132) + 12|0);
      $138 = Math_fround(HEAPF32[$137>>2]);
      $$pre$phi$iZ2D = $132;$140 = $138;$443 = $138;
     }
     $139 = (($132) + 72|0);
     HEAPF32[$139>>2] = $140;
     $141 = Math_fround(HEAPF32[$$pre$phi$iZ2D>>2]);
     $142 = (($$pre$phi$iZ2D) + 4|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = (($$pre$phi$iZ2D) + 8|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = (($132) + 16|0);
     $147 = Math_fround(HEAPF32[$146>>2]);
     $148 = (($146) + 4|0);
     $149 = Math_fround(HEAPF32[$148>>2]);
     $150 = (($146) + 8|0);
     $151 = Math_fround(HEAPF32[$150>>2]);
     $152 = (($146) + 12|0);
     $153 = Math_fround(HEAPF32[$152>>2]);
     $154 = (($132) + 32|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = (($154) + 4|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = (($154) + 8|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = (($132) + 48|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = (($160) + 4|0);
     $163 = Math_fround(HEAPF32[$162>>2]);
     $164 = (($160) + 8|0);
     $165 = Math_fround(HEAPF32[$164>>2]);
     $166 = ($i$0715$i>>>0)<($126>>>0);
     $167 = $166 ? $i$0715$i : $126;
     $168 = ($167|0)==(0);
     if ($168) {
      $$lcssa$i = $443;$$lcssa688$i = $145;$$lcssa689$i = $143;$$lcssa690$i = $141;$$lcssa691$i = $153;$$lcssa692$i = $151;$$lcssa693$i = $149;$$lcssa694$i = $147;$$lcssa695$i = $159;$$lcssa696$i = $157;$$lcssa697$i = $155;$$lcssa698$i = $165;$$lcssa699$i = $163;$$lcssa700$i = $161;$287 = $132;
     } else {
      $182 = $141;$184 = $143;$186 = $145;$188 = $155;$190 = $157;$192 = $159;$209 = $147;$211 = $149;$213 = $151;$215 = $161;$217 = $163;$219 = $165;$244 = $443;$261 = $153;$j$0701$i = 0;
      while(1) {
       $169 = (($lin1m$i) + ($j$0701$i<<4)|0);
       $170 = Math_fround(HEAPF32[$169>>2]);
       $171 = ((($lin1m$i) + ($j$0701$i<<4)|0) + 4|0);
       $172 = Math_fround(HEAPF32[$171>>2]);
       $173 = ((($lin1m$i) + ($j$0701$i<<4)|0) + 8|0);
       $174 = Math_fround(HEAPF32[$173>>2]);
       $175 = (($lin0m$i) + ($j$0701$i<<4)|0);
       $176 = Math_fround(HEAPF32[$175>>2]);
       $177 = ((($lin0m$i) + ($j$0701$i<<4)|0) + 4|0);
       $178 = Math_fround(HEAPF32[$177>>2]);
       $179 = ((($lin0m$i) + ($j$0701$i<<4)|0) + 8|0);
       $180 = Math_fround(HEAPF32[$179>>2]);
       $181 = Math_fround($182 * $176);
       $183 = Math_fround($184 * $178);
       $185 = Math_fround($186 * $180);
       $187 = Math_fround($188 * $170);
       $189 = Math_fround($190 * $172);
       $191 = Math_fround($192 * $174);
       $193 = Math_fround($187 + $181);
       $194 = Math_fround($189 + $183);
       $195 = Math_fround($191 + $185);
       $196 = (($ang1m$i) + ($j$0701$i<<4)|0);
       $197 = Math_fround(HEAPF32[$196>>2]);
       $198 = ((($ang1m$i) + ($j$0701$i<<4)|0) + 4|0);
       $199 = Math_fround(HEAPF32[$198>>2]);
       $200 = ((($ang1m$i) + ($j$0701$i<<4)|0) + 8|0);
       $201 = Math_fround(HEAPF32[$200>>2]);
       $202 = (($ang0m$i) + ($j$0701$i<<4)|0);
       $203 = Math_fround(HEAPF32[$202>>2]);
       $204 = ((($ang0m$i) + ($j$0701$i<<4)|0) + 4|0);
       $205 = Math_fround(HEAPF32[$204>>2]);
       $206 = ((($ang0m$i) + ($j$0701$i<<4)|0) + 8|0);
       $207 = Math_fround(HEAPF32[$206>>2]);
       $208 = Math_fround($209 * $203);
       $210 = Math_fround($211 * $205);
       $212 = Math_fround($213 * $207);
       $214 = Math_fround($215 * $197);
       $216 = Math_fround($217 * $199);
       $218 = Math_fround($219 * $201);
       $220 = Math_fround($214 + $208);
       $221 = Math_fround($216 + $210);
       $222 = Math_fround($218 + $212);
       $223 = Math_fround($193 + $220);
       $224 = Math_fround($194 + $221);
       $225 = Math_fround($195 + $222);
       $226 = Math_fround($223 + $224);
       $227 = Math_fround($226 + $225);
       $228 = (($lin0AndG$i) + ($j$0701$i<<4)|0);
       $229 = Math_fround(HEAPF32[$228>>2]);
       $230 = ((($lin0AndG$i) + ($j$0701$i<<4)|0) + 4|0);
       $231 = Math_fround(HEAPF32[$230>>2]);
       $232 = ((($lin0AndG$i) + ($j$0701$i<<4)|0) + 8|0);
       $233 = Math_fround(HEAPF32[$232>>2]);
       $234 = ((($lin0AndG$i) + ($j$0701$i<<4)|0) + 12|0);
       $235 = Math_fround(HEAPF32[$234>>2]);
       $236 = Math_fround($229 * $227);
       $237 = Math_fround($231 * $227);
       $238 = Math_fround($233 * $227);
       $239 = Math_fround($235 * $227);
       $240 = Math_fround($182 - $236);
       $241 = Math_fround($184 - $237);
       $242 = Math_fround($186 - $238);
       $243 = Math_fround($244 - $239);
       $245 = (($ang0AndT$i) + ($j$0701$i<<4)|0);
       $246 = Math_fround(HEAPF32[$245>>2]);
       $247 = ((($ang0AndT$i) + ($j$0701$i<<4)|0) + 4|0);
       $248 = Math_fround(HEAPF32[$247>>2]);
       $249 = ((($ang0AndT$i) + ($j$0701$i<<4)|0) + 8|0);
       $250 = Math_fround(HEAPF32[$249>>2]);
       $251 = ((($ang0AndT$i) + ($j$0701$i<<4)|0) + 12|0);
       $252 = Math_fround(HEAPF32[$251>>2]);
       $253 = Math_fround($227 * $246);
       $254 = Math_fround($227 * $248);
       $255 = Math_fround($227 * $250);
       $256 = Math_fround($227 * $252);
       $257 = Math_fround($209 - $253);
       $258 = Math_fround($211 - $254);
       $259 = Math_fround($213 - $255);
       $260 = Math_fround($261 - $256);
       $262 = (($lin1$i) + ($j$0701$i<<4)|0);
       $263 = Math_fround(HEAPF32[$262>>2]);
       $264 = ((($lin1$i) + ($j$0701$i<<4)|0) + 4|0);
       $265 = Math_fround(HEAPF32[$264>>2]);
       $266 = ((($lin1$i) + ($j$0701$i<<4)|0) + 8|0);
       $267 = Math_fround(HEAPF32[$266>>2]);
       $268 = Math_fround($227 * $263);
       $269 = Math_fround($227 * $265);
       $270 = Math_fround($227 * $267);
       $271 = Math_fround($188 - $268);
       $272 = Math_fround($190 - $269);
       $273 = Math_fround($192 - $270);
       $274 = (($ang1$i) + ($j$0701$i<<4)|0);
       $275 = Math_fround(HEAPF32[$274>>2]);
       $276 = ((($ang1$i) + ($j$0701$i<<4)|0) + 4|0);
       $277 = Math_fround(HEAPF32[$276>>2]);
       $278 = ((($ang1$i) + ($j$0701$i<<4)|0) + 8|0);
       $279 = Math_fround(HEAPF32[$278>>2]);
       $280 = Math_fround($227 * $275);
       $281 = Math_fround($227 * $277);
       $282 = Math_fround($227 * $279);
       $283 = Math_fround($215 - $280);
       $284 = Math_fround($217 - $281);
       $285 = Math_fround($219 - $282);
       $286 = (($j$0701$i) + 1)|0;
       $exitcond$i = ($286|0)==($130|0);
       if ($exitcond$i) {
        break;
       } else {
        $182 = $240;$184 = $241;$186 = $242;$188 = $271;$190 = $272;$192 = $273;$209 = $257;$211 = $258;$213 = $259;$215 = $283;$217 = $284;$219 = $285;$244 = $243;$261 = $260;$j$0701$i = $286;
       }
      }
      $$pre$i = HEAP32[$131>>2]|0;
      $$lcssa$i = $243;$$lcssa688$i = $242;$$lcssa689$i = $241;$$lcssa690$i = $240;$$lcssa691$i = $260;$$lcssa692$i = $259;$$lcssa693$i = $258;$$lcssa694$i = $257;$$lcssa695$i = $273;$$lcssa696$i = $272;$$lcssa697$i = $271;$$lcssa698$i = $285;$$lcssa699$i = $284;$$lcssa700$i = $283;$287 = $$pre$i;
     }
     HEAPF32[$287>>2] = $$lcssa690$i;
     $288 = (($287) + 4|0);
     HEAPF32[$288>>2] = $$lcssa689$i;
     $289 = (($287) + 8|0);
     HEAPF32[$289>>2] = $$lcssa688$i;
     $290 = (($287) + 12|0);
     HEAPF32[$290>>2] = $$lcssa$i;
     $291 = HEAP32[$131>>2]|0;
     $292 = (($291) + 16|0);
     HEAPF32[$292>>2] = $$lcssa694$i;
     $293 = (($291) + 20|0);
     HEAPF32[$293>>2] = $$lcssa693$i;
     $294 = (($291) + 24|0);
     HEAPF32[$294>>2] = $$lcssa692$i;
     $295 = (($291) + 28|0);
     HEAPF32[$295>>2] = $$lcssa691$i;
     $296 = HEAP32[$131>>2]|0;
     $297 = (($296) + 32|0);
     HEAPF32[$297>>2] = $$lcssa697$i;
     $298 = (($296) + 36|0);
     HEAPF32[$298>>2] = $$lcssa696$i;
     $299 = (($296) + 40|0);
     HEAPF32[$299>>2] = $$lcssa695$i;
     $300 = (($296) + 48|0);
     HEAPF32[$300>>2] = $$lcssa700$i;
     $301 = (($296) + 52|0);
     HEAPF32[$301>>2] = $$lcssa699$i;
     $302 = (($296) + 56|0);
     HEAPF32[$302>>2] = $$lcssa698$i;
     if ($166) {
      $303 = (($lin0AndG$i) + ($i$0715$i<<4)|0);
      HEAPF32[$303>>2] = $$lcssa690$i;
      $304 = ((($lin0AndG$i) + ($i$0715$i<<4)|0) + 4|0);
      HEAPF32[$304>>2] = $$lcssa689$i;
      $305 = ((($lin0AndG$i) + ($i$0715$i<<4)|0) + 8|0);
      HEAPF32[$305>>2] = $$lcssa688$i;
      $306 = ((($lin0AndG$i) + ($i$0715$i<<4)|0) + 12|0);
      HEAPF32[$306>>2] = $$lcssa$i;
      $307 = (($ang0AndT$i) + ($i$0715$i<<4)|0);
      HEAPF32[$307>>2] = $$lcssa694$i;
      $308 = ((($ang0AndT$i) + ($i$0715$i<<4)|0) + 4|0);
      HEAPF32[$308>>2] = $$lcssa693$i;
      $309 = ((($ang0AndT$i) + ($i$0715$i<<4)|0) + 8|0);
      HEAPF32[$309>>2] = $$lcssa692$i;
      $310 = ((($ang0AndT$i) + ($i$0715$i<<4)|0) + 12|0);
      HEAPF32[$310>>2] = $$lcssa691$i;
      $311 = (($lin1$i) + ($i$0715$i<<4)|0);
      HEAPF32[$311>>2] = $$lcssa697$i;
      $312 = ((($lin1$i) + ($i$0715$i<<4)|0) + 4|0);
      HEAPF32[$312>>2] = $$lcssa696$i;
      $313 = ((($lin1$i) + ($i$0715$i<<4)|0) + 8|0);
      HEAPF32[$313>>2] = $$lcssa695$i;
      $314 = ((($lin1$i) + ($i$0715$i<<4)|0) + 12|0);
      HEAPF32[$314>>2] = Math_fround(0.0);
      $315 = (($ang1$i) + ($i$0715$i<<4)|0);
      HEAPF32[$315>>2] = $$lcssa700$i;
      $316 = ((($ang1$i) + ($i$0715$i<<4)|0) + 4|0);
      HEAPF32[$316>>2] = $$lcssa699$i;
      $317 = ((($ang1$i) + ($i$0715$i<<4)|0) + 8|0);
      HEAPF32[$317>>2] = $$lcssa698$i;
      $318 = ((($ang1$i) + ($i$0715$i<<4)|0) + 12|0);
      HEAPF32[$318>>2] = Math_fround(0.0);
      $319 = Math_fround(HEAPF32[$98>>2]);
      $320 = Math_fround($$lcssa690$i * $319);
      $321 = Math_fround($$lcssa689$i * $319);
      $322 = Math_fround($$lcssa688$i * $319);
      $323 = Math_fround(HEAPF32[$104>>2]);
      $324 = Math_fround($$lcssa697$i * $323);
      $325 = Math_fround($$lcssa696$i * $323);
      $326 = Math_fround($$lcssa695$i * $323);
      $327 = Math_fround(HEAPF32[$m>>2]);
      $328 = Math_fround($$lcssa694$i * $327);
      $329 = Math_fround(HEAPF32[$46>>2]);
      $330 = Math_fround($$lcssa693$i * $329);
      $331 = Math_fround($328 + $330);
      $332 = Math_fround(HEAPF32[$50>>2]);
      $333 = Math_fround($$lcssa692$i * $332);
      $334 = Math_fround($331 + $333);
      $335 = Math_fround(HEAPF32[$43>>2]);
      $336 = Math_fround($$lcssa694$i * $335);
      $337 = Math_fround(HEAPF32[$47>>2]);
      $338 = Math_fround($$lcssa693$i * $337);
      $339 = Math_fround($336 + $338);
      $340 = Math_fround(HEAPF32[$51>>2]);
      $341 = Math_fround($$lcssa692$i * $340);
      $342 = Math_fround($339 + $341);
      $343 = Math_fround(HEAPF32[$44>>2]);
      $344 = Math_fround($$lcssa694$i * $343);
      $345 = Math_fround(HEAPF32[$48>>2]);
      $346 = Math_fround($$lcssa693$i * $345);
      $347 = Math_fround($344 + $346);
      $348 = Math_fround(HEAPF32[$52>>2]);
      $349 = Math_fround($$lcssa692$i * $348);
      $350 = Math_fround($347 + $349);
      $351 = Math_fround(HEAPF32[$82>>2]);
      $352 = Math_fround($$lcssa700$i * $351);
      $353 = Math_fround(HEAPF32[$86>>2]);
      $354 = Math_fround($$lcssa699$i * $353);
      $355 = Math_fround($352 + $354);
      $356 = Math_fround(HEAPF32[$90>>2]);
      $357 = Math_fround($$lcssa698$i * $356);
      $358 = Math_fround($355 + $357);
      $359 = Math_fround(HEAPF32[$83>>2]);
      $360 = Math_fround($$lcssa700$i * $359);
      $361 = Math_fround(HEAPF32[$87>>2]);
      $362 = Math_fround($$lcssa699$i * $361);
      $363 = Math_fround($360 + $362);
      $364 = Math_fround(HEAPF32[$91>>2]);
      $365 = Math_fround($$lcssa698$i * $364);
      $366 = Math_fround($363 + $365);
      $367 = Math_fround(HEAPF32[$84>>2]);
      $368 = Math_fround($$lcssa700$i * $367);
      $369 = Math_fround(HEAPF32[$88>>2]);
      $370 = Math_fround($$lcssa699$i * $369);
      $371 = Math_fround($368 + $370);
      $372 = Math_fround(HEAPF32[$92>>2]);
      $373 = Math_fround($$lcssa698$i * $372);
      $374 = Math_fround($371 + $373);
      $375 = Math_fround($$lcssa697$i * $324);
      $376 = Math_fround($$lcssa696$i * $325);
      $377 = Math_fround($$lcssa695$i * $326);
      $378 = Math_fround($$lcssa690$i * $320);
      $379 = Math_fround($$lcssa689$i * $321);
      $380 = Math_fround($$lcssa688$i * $322);
      $381 = Math_fround($378 + $375);
      $382 = Math_fround($379 + $376);
      $383 = Math_fround($380 + $377);
      $384 = Math_fround($$lcssa700$i * $358);
      $385 = Math_fround($$lcssa699$i * $366);
      $386 = Math_fround($$lcssa698$i * $374);
      $387 = Math_fround($$lcssa694$i * $334);
      $388 = Math_fround($$lcssa693$i * $342);
      $389 = Math_fround($$lcssa692$i * $350);
      $390 = Math_fround($387 + $384);
      $391 = Math_fround($388 + $385);
      $392 = Math_fround($389 + $386);
      $393 = Math_fround($381 + $390);
      $394 = Math_fround($382 + $391);
      $395 = Math_fround($383 + $392);
      $396 = Math_fround($393 + $394);
      $397 = Math_fround($396 + $395);
      $398 = Math_fround(Math_fround(1.0) / $397);
      $399 = !($397 > Math_fround(0.0));
      $400 = $399 ? Math_fround(0.0) : $398;
      $401 = Math_fround($320 * $400);
      $402 = Math_fround($321 * $400);
      $403 = Math_fround($322 * $400);
      $404 = Math_fround($400 * Math_fround(0.0));
      $405 = (($lin0m$i) + ($i$0715$i<<4)|0);
      HEAPF32[$405>>2] = $401;
      $406 = ((($lin0m$i) + ($i$0715$i<<4)|0) + 4|0);
      HEAPF32[$406>>2] = $402;
      $407 = ((($lin0m$i) + ($i$0715$i<<4)|0) + 8|0);
      HEAPF32[$407>>2] = $403;
      $408 = ((($lin0m$i) + ($i$0715$i<<4)|0) + 12|0);
      HEAPF32[$408>>2] = $404;
      $409 = Math_fround($334 * $400);
      $410 = Math_fround($342 * $400);
      $411 = Math_fround($350 * $400);
      $412 = (($ang0m$i) + ($i$0715$i<<4)|0);
      HEAPF32[$412>>2] = $409;
      $413 = ((($ang0m$i) + ($i$0715$i<<4)|0) + 4|0);
      HEAPF32[$413>>2] = $410;
      $414 = ((($ang0m$i) + ($i$0715$i<<4)|0) + 8|0);
      HEAPF32[$414>>2] = $411;
      $415 = ((($ang0m$i) + ($i$0715$i<<4)|0) + 12|0);
      HEAPF32[$415>>2] = $404;
      $416 = Math_fround($324 * $400);
      $417 = Math_fround($325 * $400);
      $418 = Math_fround($326 * $400);
      $419 = (($lin1m$i) + ($i$0715$i<<4)|0);
      HEAPF32[$419>>2] = $416;
      $420 = ((($lin1m$i) + ($i$0715$i<<4)|0) + 4|0);
      HEAPF32[$420>>2] = $417;
      $421 = ((($lin1m$i) + ($i$0715$i<<4)|0) + 8|0);
      HEAPF32[$421>>2] = $418;
      $422 = ((($lin1m$i) + ($i$0715$i<<4)|0) + 12|0);
      HEAPF32[$422>>2] = Math_fround(0.0);
      $423 = Math_fround($358 * $400);
      $424 = Math_fround($366 * $400);
      $425 = Math_fround($374 * $400);
      $426 = (($ang1m$i) + ($i$0715$i<<4)|0);
      HEAPF32[$426>>2] = $423;
      $427 = ((($ang1m$i) + ($i$0715$i<<4)|0) + 4|0);
      HEAPF32[$427>>2] = $424;
      $428 = ((($ang1m$i) + ($i$0715$i<<4)|0) + 8|0);
      HEAPF32[$428>>2] = $425;
      $429 = ((($ang1m$i) + ($i$0715$i<<4)|0) + 12|0);
      HEAPF32[$429>>2] = Math_fround(0.0);
     }
     $430 = (($i$0715$i) + 1)|0;
     $indvars$iv$next$i = (($indvars$iv$i) + -1)|0;
     $exitcond732$i = ($430|0)==($125|0);
     if ($exitcond732$i) {
      break;
     } else {
      $i$0715$i = $430;$indvars$iv$i = $indvars$iv$next$i;
     }
    }
   }
  }
  if ($111) {
   $i2$023 = $i2$1;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx12_GLOBAL__N_111diagonalizeEPPNS_14Px1DConstraintERKNS0_9MassPropsE($row,$m) {
 $row = $row|0;
 $m = $m|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0.0, $174 = Math_fround(0), $175 = 0.0, $176 = 0.0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0;
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0;
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0);
 var $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0);
 var $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = Math_fround(0), $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = Math_fround(0), $486 = 0, $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = 0, $493 = Math_fround(0), $494 = Math_fround(0);
 var $495 = 0, $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = 0, $502 = Math_fround(0), $503 = Math_fround(0), $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0);
 var $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0);
 var $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0);
 var $567 = 0, $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0);
 var $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $d$i = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $i$032$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $d$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = HEAP32[$row>>2]|0;
 $3 = (Math_fround(__ZN5physx12_GLOBAL__N_112innerProductERKNS_14Px1DConstraintERS1_RKNS0_9MassPropsE($2,$2,$m)));
 $4 = HEAP32[$row>>2]|0;
 $5 = (($row) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (Math_fround(__ZN5physx12_GLOBAL__N_112innerProductERKNS_14Px1DConstraintERS1_RKNS0_9MassPropsE($4,$6,$m)));
 $8 = HEAP32[$row>>2]|0;
 $9 = (($row) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (Math_fround(__ZN5physx12_GLOBAL__N_112innerProductERKNS_14Px1DConstraintERS1_RKNS0_9MassPropsE($8,$10,$m)));
 $12 = HEAP32[$5>>2]|0;
 $13 = (Math_fround(__ZN5physx12_GLOBAL__N_112innerProductERKNS_14Px1DConstraintERS1_RKNS0_9MassPropsE($12,$12,$m)));
 $14 = HEAP32[$5>>2]|0;
 $15 = HEAP32[$9>>2]|0;
 $16 = (Math_fround(__ZN5physx12_GLOBAL__N_112innerProductERKNS_14Px1DConstraintERS1_RKNS0_9MassPropsE($14,$15,$m)));
 $17 = HEAP32[$9>>2]|0;
 $18 = (Math_fround(__ZN5physx12_GLOBAL__N_112innerProductERKNS_14Px1DConstraintERS1_RKNS0_9MassPropsE($17,$17,$m)));
 $19 = (($d$i) + 4|0);
 $20 = (($d$i) + 8|0);
 $21 = (($d$i) + 12|0);
 $22 = (($d$i) + 16|0);
 $23 = (($d$i) + 20|0);
 $24 = (($d$i) + 24|0);
 $25 = (($d$i) + 28|0);
 $26 = (($d$i) + 32|0);
 $27 = (($0) + 4|0);
 $28 = (($0) + 8|0);
 $29 = (($0) + 12|0);
 $30 = (($1) + 4|0);
 $31 = (($1) + 8|0);
 $32 = (($1) + 12|0);
 $34 = Math_fround(0.0);$36 = Math_fround(0.0);$38 = Math_fround(0.0);$45 = Math_fround(1.0);$i$032$i = 0;
 while(1) {
  $33 = Math_fround($34 + $34);
  $35 = Math_fround($36 + $36);
  $37 = Math_fround($38 + $38);
  $39 = Math_fround($34 * $33);
  $40 = Math_fround($36 * $35);
  $41 = Math_fround($38 * $37);
  $42 = Math_fround($36 * $33);
  $43 = Math_fround($38 * $33);
  $44 = Math_fround($45 * $33);
  $46 = Math_fround($38 * $35);
  $47 = Math_fround($45 * $35);
  $48 = Math_fround($45 * $37);
  $49 = Math_fround(Math_fround(1.0) - $40);
  $50 = Math_fround($49 - $41);
  $51 = Math_fround($48 + $42);
  $52 = Math_fround($43 - $47);
  $53 = Math_fround($42 - $48);
  $54 = Math_fround(Math_fround(1.0) - $39);
  $55 = Math_fround($54 - $41);
  $56 = Math_fround($46 + $44);
  $57 = Math_fround($47 + $43);
  $58 = Math_fround($46 - $44);
  $59 = Math_fround($54 - $40);
  $60 = Math_fround($3 * $50);
  $61 = Math_fround($3 * $53);
  $62 = Math_fround($3 * $57);
  $63 = Math_fround($7 * $51);
  $64 = Math_fround($7 * $55);
  $65 = Math_fround($7 * $58);
  $66 = Math_fround($60 + $63);
  $67 = Math_fround($61 + $64);
  $68 = Math_fround($62 + $65);
  $69 = Math_fround($11 * $52);
  $70 = Math_fround($11 * $56);
  $71 = Math_fround($11 * $59);
  $72 = Math_fround($69 + $66);
  $73 = Math_fround($70 + $67);
  $74 = Math_fround($68 + $71);
  $75 = Math_fround($7 * $50);
  $76 = Math_fround($7 * $53);
  $77 = Math_fround($7 * $57);
  $78 = Math_fround($13 * $51);
  $79 = Math_fround($13 * $55);
  $80 = Math_fround($13 * $58);
  $81 = Math_fround($75 + $78);
  $82 = Math_fround($76 + $79);
  $83 = Math_fround($77 + $80);
  $84 = Math_fround($16 * $52);
  $85 = Math_fround($16 * $56);
  $86 = Math_fround($16 * $59);
  $87 = Math_fround($84 + $81);
  $88 = Math_fround($85 + $82);
  $89 = Math_fround($83 + $86);
  $90 = Math_fround($11 * $50);
  $91 = Math_fround($11 * $53);
  $92 = Math_fround($11 * $57);
  $93 = Math_fround($16 * $51);
  $94 = Math_fround($16 * $55);
  $95 = Math_fround($16 * $58);
  $96 = Math_fround($90 + $93);
  $97 = Math_fround($91 + $94);
  $98 = Math_fround($92 + $95);
  $99 = Math_fround($18 * $52);
  $100 = Math_fround($18 * $56);
  $101 = Math_fround($18 * $59);
  $102 = Math_fround($99 + $96);
  $103 = Math_fround($100 + $97);
  $104 = Math_fround($98 + $101);
  $105 = Math_fround($50 * $72);
  $106 = Math_fround($50 * $73);
  $107 = Math_fround($50 * $74);
  $108 = Math_fround($51 * $87);
  $109 = Math_fround($51 * $88);
  $110 = Math_fround($51 * $89);
  $111 = Math_fround($105 + $108);
  $112 = Math_fround($106 + $109);
  $113 = Math_fround($107 + $110);
  $114 = Math_fround($52 * $102);
  $115 = Math_fround($52 * $103);
  $116 = Math_fround($52 * $104);
  $117 = Math_fround($114 + $111);
  $118 = Math_fround($115 + $112);
  $119 = Math_fround($116 + $113);
  $120 = Math_fround($53 * $72);
  $121 = Math_fround($53 * $73);
  $122 = Math_fround($53 * $74);
  $123 = Math_fround($55 * $87);
  $124 = Math_fround($55 * $88);
  $125 = Math_fround($55 * $89);
  $126 = Math_fround($120 + $123);
  $127 = Math_fround($121 + $124);
  $128 = Math_fround($122 + $125);
  $129 = Math_fround($56 * $102);
  $130 = Math_fround($56 * $103);
  $131 = Math_fround($56 * $104);
  $132 = Math_fround($129 + $126);
  $133 = Math_fround($130 + $127);
  $134 = Math_fround($131 + $128);
  $135 = Math_fround($57 * $72);
  $136 = Math_fround($57 * $73);
  $137 = Math_fround($57 * $74);
  $138 = Math_fround($58 * $87);
  $139 = Math_fround($58 * $88);
  $140 = Math_fround($58 * $89);
  $141 = Math_fround($135 + $138);
  $142 = Math_fround($136 + $139);
  $143 = Math_fround($137 + $140);
  $144 = Math_fround($59 * $102);
  $145 = Math_fround($59 * $103);
  $146 = Math_fround($59 * $104);
  $147 = Math_fround($144 + $141);
  $148 = Math_fround($145 + $142);
  $149 = Math_fround($146 + $143);
  HEAPF32[$d$i>>2] = $117;
  HEAPF32[$19>>2] = $118;
  HEAPF32[$20>>2] = $119;
  HEAPF32[$21>>2] = $132;
  HEAPF32[$22>>2] = $133;
  HEAPF32[$23>>2] = $134;
  HEAPF32[$24>>2] = $147;
  HEAPF32[$25>>2] = $148;
  HEAPF32[$26>>2] = $149;
  $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($134)))));
  $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($119)))));
  $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($118)))));
  $150 = $fabsf$i$i4$i > $fabsf$i$i5$i;
  $151 = $fabsf$i$i4$i > $fabsf$i$i3$i;
  $or$cond$i = $150 & $151;
  if ($or$cond$i) {
   $155 = 0;
  } else {
   $152 = $fabsf$i$i5$i > $fabsf$i$i3$i;
   $153 = $152 ? 1 : 2;
   $155 = $153;
  }
  $154 = (($155) + 1)|0;
  $156 = $155 >>> 1;
  $157 = (($154) + ($156))|0;
  $158 = $157 & 3;
  $159 = (($157) + 1)|0;
  $160 = $158 >>> 1;
  $161 = (($159) + ($160))|0;
  $162 = $161 & 3;
  $163 = (($d$i) + (($158*12)|0)|0);
  $164 = (($163) + ($162<<2)|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  $166 = $165 == Math_fround(0.0);
  if ($166) {
   $258 = $34;$260 = $36;$262 = $38;$264 = $45;
   break;
  }
  $167 = (($163) + ($158<<2)|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($d$i) + (($162*12)|0)|0);
  $170 = (($169) + ($162<<2)|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = Math_fround($168 - $171);
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($172)))));
  $173 = +$fabsf$i$i2$i;
  $174 = Math_fround($165 * Math_fround(2.0));
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($174)))));
  $175 = +$fabsf$i$i1$i;
  $176 = $175 * 2.0E+6;
  $177 = $173 > $176;
  if ($177) {
   $258 = $34;$260 = $36;$262 = $38;$264 = $45;
   break;
  }
  $178 = Math_fround($172 / $174);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($178)))));
  $179 = $fabsf$i$i$i > Math_fround(1000.0);
  if ($179) {
   $180 = Math_fround($178 * Math_fround(4.0));
   $181 = Math_fround(Math_fround(1.0) / $180);
   HEAPF32[$0>>2] = Math_fround(0.0);
   HEAPF32[$27>>2] = Math_fround(0.0);
   HEAPF32[$28>>2] = Math_fround(0.0);
   HEAPF32[$29>>2] = Math_fround(1.0);
   $182 = (($0) + ($155<<2)|0);
   HEAPF32[$182>>2] = $181;
   $183 = Math_fround(HEAPF32[$0>>2]);
   $184 = Math_fround(HEAPF32[$27>>2]);
   $185 = Math_fround(HEAPF32[$28>>2]);
   $186 = Math_fround(HEAPF32[$29>>2]);
   $211 = $183;$213 = $186;$216 = $185;$219 = $184;
  } else {
   $187 = Math_fround($178 * $178);
   $188 = Math_fround($187 + Math_fround(1.0));
   $189 = (Math_fround(Math_sqrt((Math_fround($188)))));
   $190 = Math_fround($fabsf$i$i$i + $189);
   $191 = Math_fround(Math_fround(1.0) / $190);
   $192 = Math_fround($191 * $191);
   $193 = Math_fround($192 + Math_fround(1.0));
   $194 = (Math_fround(Math_sqrt((Math_fround($193)))));
   $195 = Math_fround(Math_fround(1.0) / $194);
   $196 = Math_fround(Math_fround(1.0) - $195);
   $197 = Math_fround($196 * Math_fround(0.5));
   $198 = (Math_fround(Math_sqrt((Math_fround($197)))));
   $199 = $178 >= Math_fround(0.0);
   $200 = $199 ? Math_fround(1.0) : Math_fround(-1.0);
   $201 = Math_fround($200 * $198);
   $202 = Math_fround($195 + Math_fround(1.0));
   $203 = Math_fround($202 * Math_fround(0.5));
   $204 = (Math_fround(Math_sqrt((Math_fround($203)))));
   HEAPF32[$1>>2] = Math_fround(0.0);
   HEAPF32[$30>>2] = Math_fround(0.0);
   HEAPF32[$31>>2] = Math_fround(0.0);
   HEAPF32[$32>>2] = $204;
   $205 = (($1) + ($155<<2)|0);
   HEAPF32[$205>>2] = $201;
   $206 = Math_fround(HEAPF32[$1>>2]);
   $207 = Math_fround(HEAPF32[$30>>2]);
   $208 = Math_fround(HEAPF32[$31>>2]);
   $209 = Math_fround(HEAPF32[$32>>2]);
   $211 = $206;$213 = $209;$216 = $208;$219 = $207;
  }
  $210 = Math_fround($45 * $211);
  $212 = Math_fround($34 * $213);
  $214 = Math_fround($212 + $210);
  $215 = Math_fround($36 * $216);
  $217 = Math_fround($215 + $214);
  $218 = Math_fround($38 * $219);
  $220 = Math_fround($217 - $218);
  $221 = Math_fround($45 * $219);
  $222 = Math_fround($36 * $213);
  $223 = Math_fround($222 + $221);
  $224 = Math_fround($38 * $211);
  $225 = Math_fround($223 + $224);
  $226 = Math_fround($34 * $216);
  $227 = Math_fround($225 - $226);
  $228 = Math_fround($45 * $216);
  $229 = Math_fround($38 * $213);
  $230 = Math_fround($229 + $228);
  $231 = Math_fround($34 * $219);
  $232 = Math_fround($231 + $230);
  $233 = Math_fround($36 * $211);
  $234 = Math_fround($232 - $233);
  $235 = Math_fround($45 * $213);
  $236 = Math_fround($34 * $211);
  $237 = Math_fround($235 - $236);
  $238 = Math_fround($36 * $219);
  $239 = Math_fround($237 - $238);
  $240 = Math_fround($38 * $216);
  $241 = Math_fround($239 - $240);
  $242 = Math_fround($220 * $220);
  $243 = Math_fround($227 * $227);
  $244 = Math_fround($243 + $242);
  $245 = Math_fround($234 * $234);
  $246 = Math_fround($245 + $244);
  $247 = Math_fround($241 * $241);
  $248 = Math_fround($247 + $246);
  $249 = (Math_fround(Math_sqrt((Math_fround($248)))));
  $250 = Math_fround(Math_fround(1.0) / $249);
  $251 = Math_fround($250 * $220);
  $252 = Math_fround($250 * $227);
  $253 = Math_fround($250 * $234);
  $254 = Math_fround($250 * $241);
  $255 = (($i$032$i) + 1)|0;
  $256 = ($255>>>0)<(5);
  if ($256) {
   $34 = $251;$36 = $252;$38 = $253;$45 = $254;$i$032$i = $255;
  } else {
   $258 = $251;$260 = $252;$262 = $253;$264 = $254;
   break;
  }
 }
 $257 = Math_fround(-$258);
 $259 = Math_fround(-$260);
 $261 = Math_fround(-$262);
 $263 = Math_fround(-$264);
 $265 = Math_fround($257 - $258);
 $266 = Math_fround($259 - $260);
 $267 = Math_fround($261 - $262);
 $268 = Math_fround($265 * $257);
 $269 = Math_fround($266 * $259);
 $270 = Math_fround($267 * $261);
 $271 = Math_fround($265 * $259);
 $272 = Math_fround($265 * $261);
 $273 = Math_fround($265 * $263);
 $274 = Math_fround($266 * $261);
 $275 = Math_fround($266 * $263);
 $276 = Math_fround($267 * $263);
 $277 = Math_fround(Math_fround(1.0) - $269);
 $278 = Math_fround($277 - $270);
 $279 = Math_fround($276 + $271);
 $280 = Math_fround($272 - $275);
 $281 = Math_fround($271 - $276);
 $282 = Math_fround(Math_fround(1.0) - $268);
 $283 = Math_fround($282 - $270);
 $284 = Math_fround($274 + $273);
 $285 = Math_fround($275 + $272);
 $286 = Math_fround($274 - $273);
 $287 = Math_fround($282 - $269);
 $288 = HEAP32[$row>>2]|0;
 $289 = HEAP32[$5>>2]|0;
 $290 = HEAP32[$9>>2]|0;
 $291 = Math_fround(HEAPF32[$288>>2]);
 $292 = Math_fround($278 * $291);
 $293 = (($288) + 4|0);
 $294 = Math_fround(HEAPF32[$293>>2]);
 $295 = Math_fround($278 * $294);
 $296 = (($288) + 8|0);
 $297 = Math_fround(HEAPF32[$296>>2]);
 $298 = Math_fround($278 * $297);
 $299 = Math_fround(HEAPF32[$289>>2]);
 $300 = Math_fround($279 * $299);
 $301 = (($289) + 4|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = Math_fround($279 * $302);
 $304 = (($289) + 8|0);
 $305 = Math_fround(HEAPF32[$304>>2]);
 $306 = Math_fround($279 * $305);
 $307 = Math_fround($292 + $300);
 $308 = Math_fround($295 + $303);
 $309 = Math_fround($298 + $306);
 $310 = Math_fround(HEAPF32[$290>>2]);
 $311 = Math_fround($280 * $310);
 $312 = (($290) + 4|0);
 $313 = Math_fround(HEAPF32[$312>>2]);
 $314 = Math_fround($280 * $313);
 $315 = (($290) + 8|0);
 $316 = Math_fround(HEAPF32[$315>>2]);
 $317 = Math_fround($280 * $316);
 $318 = Math_fround($307 + $311);
 $319 = Math_fround($308 + $314);
 $320 = Math_fround($309 + $317);
 $321 = Math_fround($281 * $291);
 $322 = Math_fround($281 * $294);
 $323 = Math_fround($281 * $297);
 $324 = Math_fround($283 * $299);
 $325 = Math_fround($283 * $302);
 $326 = Math_fround($283 * $305);
 $327 = Math_fround($321 + $324);
 $328 = Math_fround($322 + $325);
 $329 = Math_fround($323 + $326);
 $330 = Math_fround($284 * $310);
 $331 = Math_fround($284 * $313);
 $332 = Math_fround($284 * $316);
 $333 = Math_fround($327 + $330);
 $334 = Math_fround($328 + $331);
 $335 = Math_fround($329 + $332);
 $336 = Math_fround($285 * $291);
 $337 = Math_fround($285 * $294);
 $338 = Math_fround($285 * $297);
 $339 = Math_fround($286 * $299);
 $340 = Math_fround($286 * $302);
 $341 = Math_fround($286 * $305);
 $342 = Math_fround($336 + $339);
 $343 = Math_fround($337 + $340);
 $344 = Math_fround($338 + $341);
 $345 = Math_fround($287 * $310);
 $346 = Math_fround($287 * $313);
 $347 = Math_fround($287 * $316);
 $348 = Math_fround($342 + $345);
 $349 = Math_fround($343 + $346);
 $350 = Math_fround($344 + $347);
 HEAPF32[$288>>2] = $318;
 HEAPF32[$293>>2] = $319;
 HEAPF32[$296>>2] = $320;
 HEAPF32[$289>>2] = $333;
 HEAPF32[$301>>2] = $334;
 HEAPF32[$304>>2] = $335;
 HEAPF32[$290>>2] = $348;
 HEAPF32[$312>>2] = $349;
 HEAPF32[$315>>2] = $350;
 $351 = (($288) + 32|0);
 $352 = Math_fround(HEAPF32[$351>>2]);
 $353 = Math_fround($278 * $352);
 $354 = (($288) + 36|0);
 $355 = Math_fround(HEAPF32[$354>>2]);
 $356 = Math_fround($278 * $355);
 $357 = (($288) + 40|0);
 $358 = Math_fround(HEAPF32[$357>>2]);
 $359 = Math_fround($278 * $358);
 $360 = (($289) + 32|0);
 $361 = Math_fround(HEAPF32[$360>>2]);
 $362 = Math_fround($279 * $361);
 $363 = (($289) + 36|0);
 $364 = Math_fround(HEAPF32[$363>>2]);
 $365 = Math_fround($279 * $364);
 $366 = (($289) + 40|0);
 $367 = Math_fround(HEAPF32[$366>>2]);
 $368 = Math_fround($279 * $367);
 $369 = Math_fround($353 + $362);
 $370 = Math_fround($356 + $365);
 $371 = Math_fround($359 + $368);
 $372 = (($290) + 32|0);
 $373 = Math_fround(HEAPF32[$372>>2]);
 $374 = Math_fround($280 * $373);
 $375 = (($290) + 36|0);
 $376 = Math_fround(HEAPF32[$375>>2]);
 $377 = Math_fround($280 * $376);
 $378 = (($290) + 40|0);
 $379 = Math_fround(HEAPF32[$378>>2]);
 $380 = Math_fround($280 * $379);
 $381 = Math_fround($369 + $374);
 $382 = Math_fround($370 + $377);
 $383 = Math_fround($371 + $380);
 $384 = Math_fround($281 * $352);
 $385 = Math_fround($281 * $355);
 $386 = Math_fround($281 * $358);
 $387 = Math_fround($283 * $361);
 $388 = Math_fround($283 * $364);
 $389 = Math_fround($283 * $367);
 $390 = Math_fround($384 + $387);
 $391 = Math_fround($385 + $388);
 $392 = Math_fround($386 + $389);
 $393 = Math_fround($284 * $373);
 $394 = Math_fround($284 * $376);
 $395 = Math_fround($284 * $379);
 $396 = Math_fround($390 + $393);
 $397 = Math_fround($391 + $394);
 $398 = Math_fround($392 + $395);
 $399 = Math_fround($285 * $352);
 $400 = Math_fround($285 * $355);
 $401 = Math_fround($285 * $358);
 $402 = Math_fround($286 * $361);
 $403 = Math_fround($286 * $364);
 $404 = Math_fround($286 * $367);
 $405 = Math_fround($399 + $402);
 $406 = Math_fround($400 + $403);
 $407 = Math_fround($401 + $404);
 $408 = Math_fround($287 * $373);
 $409 = Math_fround($287 * $376);
 $410 = Math_fround($287 * $379);
 $411 = Math_fround($405 + $408);
 $412 = Math_fround($406 + $409);
 $413 = Math_fround($407 + $410);
 HEAPF32[$351>>2] = $381;
 HEAPF32[$354>>2] = $382;
 HEAPF32[$357>>2] = $383;
 HEAPF32[$360>>2] = $396;
 HEAPF32[$363>>2] = $397;
 HEAPF32[$366>>2] = $398;
 HEAPF32[$372>>2] = $411;
 HEAPF32[$375>>2] = $412;
 HEAPF32[$378>>2] = $413;
 $414 = HEAP32[$row>>2]|0;
 $415 = HEAP32[$5>>2]|0;
 $416 = HEAP32[$9>>2]|0;
 $417 = (($414) + 16|0);
 $418 = Math_fround(HEAPF32[$417>>2]);
 $419 = Math_fround($278 * $418);
 $420 = (($414) + 20|0);
 $421 = Math_fround(HEAPF32[$420>>2]);
 $422 = Math_fround($278 * $421);
 $423 = (($414) + 24|0);
 $424 = Math_fround(HEAPF32[$423>>2]);
 $425 = Math_fround($278 * $424);
 $426 = (($415) + 16|0);
 $427 = Math_fround(HEAPF32[$426>>2]);
 $428 = Math_fround($279 * $427);
 $429 = (($415) + 20|0);
 $430 = Math_fround(HEAPF32[$429>>2]);
 $431 = Math_fround($279 * $430);
 $432 = (($415) + 24|0);
 $433 = Math_fround(HEAPF32[$432>>2]);
 $434 = Math_fround($279 * $433);
 $435 = Math_fround($419 + $428);
 $436 = Math_fround($422 + $431);
 $437 = Math_fround($425 + $434);
 $438 = (($416) + 16|0);
 $439 = Math_fround(HEAPF32[$438>>2]);
 $440 = Math_fround($280 * $439);
 $441 = (($416) + 20|0);
 $442 = Math_fround(HEAPF32[$441>>2]);
 $443 = Math_fround($280 * $442);
 $444 = (($416) + 24|0);
 $445 = Math_fround(HEAPF32[$444>>2]);
 $446 = Math_fround($280 * $445);
 $447 = Math_fround($435 + $440);
 $448 = Math_fround($436 + $443);
 $449 = Math_fround($437 + $446);
 $450 = Math_fround($281 * $418);
 $451 = Math_fround($281 * $421);
 $452 = Math_fround($281 * $424);
 $453 = Math_fround($283 * $427);
 $454 = Math_fround($283 * $430);
 $455 = Math_fround($283 * $433);
 $456 = Math_fround($450 + $453);
 $457 = Math_fround($451 + $454);
 $458 = Math_fround($452 + $455);
 $459 = Math_fround($284 * $439);
 $460 = Math_fround($284 * $442);
 $461 = Math_fround($284 * $445);
 $462 = Math_fround($456 + $459);
 $463 = Math_fround($457 + $460);
 $464 = Math_fround($458 + $461);
 $465 = Math_fround($285 * $418);
 $466 = Math_fround($285 * $421);
 $467 = Math_fround($285 * $424);
 $468 = Math_fround($286 * $427);
 $469 = Math_fround($286 * $430);
 $470 = Math_fround($286 * $433);
 $471 = Math_fround($465 + $468);
 $472 = Math_fround($466 + $469);
 $473 = Math_fround($467 + $470);
 $474 = Math_fround($287 * $439);
 $475 = Math_fround($287 * $442);
 $476 = Math_fround($287 * $445);
 $477 = Math_fround($471 + $474);
 $478 = Math_fround($472 + $475);
 $479 = Math_fround($473 + $476);
 HEAPF32[$417>>2] = $447;
 HEAPF32[$420>>2] = $448;
 HEAPF32[$423>>2] = $449;
 HEAPF32[$426>>2] = $462;
 HEAPF32[$429>>2] = $463;
 HEAPF32[$432>>2] = $464;
 HEAPF32[$438>>2] = $477;
 HEAPF32[$441>>2] = $478;
 HEAPF32[$444>>2] = $479;
 $480 = (($414) + 48|0);
 $481 = Math_fround(HEAPF32[$480>>2]);
 $482 = Math_fround($278 * $481);
 $483 = (($414) + 52|0);
 $484 = Math_fround(HEAPF32[$483>>2]);
 $485 = Math_fround($278 * $484);
 $486 = (($414) + 56|0);
 $487 = Math_fround(HEAPF32[$486>>2]);
 $488 = Math_fround($278 * $487);
 $489 = (($415) + 48|0);
 $490 = Math_fround(HEAPF32[$489>>2]);
 $491 = Math_fround($279 * $490);
 $492 = (($415) + 52|0);
 $493 = Math_fround(HEAPF32[$492>>2]);
 $494 = Math_fround($279 * $493);
 $495 = (($415) + 56|0);
 $496 = Math_fround(HEAPF32[$495>>2]);
 $497 = Math_fround($279 * $496);
 $498 = Math_fround($482 + $491);
 $499 = Math_fround($485 + $494);
 $500 = Math_fround($488 + $497);
 $501 = (($416) + 48|0);
 $502 = Math_fround(HEAPF32[$501>>2]);
 $503 = Math_fround($280 * $502);
 $504 = (($416) + 52|0);
 $505 = Math_fround(HEAPF32[$504>>2]);
 $506 = Math_fround($280 * $505);
 $507 = (($416) + 56|0);
 $508 = Math_fround(HEAPF32[$507>>2]);
 $509 = Math_fround($280 * $508);
 $510 = Math_fround($498 + $503);
 $511 = Math_fround($499 + $506);
 $512 = Math_fround($500 + $509);
 $513 = Math_fround($281 * $481);
 $514 = Math_fround($281 * $484);
 $515 = Math_fround($281 * $487);
 $516 = Math_fround($283 * $490);
 $517 = Math_fround($283 * $493);
 $518 = Math_fround($283 * $496);
 $519 = Math_fround($513 + $516);
 $520 = Math_fround($514 + $517);
 $521 = Math_fround($515 + $518);
 $522 = Math_fround($284 * $502);
 $523 = Math_fround($284 * $505);
 $524 = Math_fround($284 * $508);
 $525 = Math_fround($519 + $522);
 $526 = Math_fround($520 + $523);
 $527 = Math_fround($521 + $524);
 $528 = Math_fround($285 * $481);
 $529 = Math_fround($285 * $484);
 $530 = Math_fround($285 * $487);
 $531 = Math_fround($286 * $490);
 $532 = Math_fround($286 * $493);
 $533 = Math_fround($286 * $496);
 $534 = Math_fround($528 + $531);
 $535 = Math_fround($529 + $532);
 $536 = Math_fround($530 + $533);
 $537 = Math_fround($287 * $502);
 $538 = Math_fround($287 * $505);
 $539 = Math_fround($287 * $508);
 $540 = Math_fround($534 + $537);
 $541 = Math_fround($535 + $538);
 $542 = Math_fround($536 + $539);
 HEAPF32[$480>>2] = $510;
 HEAPF32[$483>>2] = $511;
 HEAPF32[$486>>2] = $512;
 HEAPF32[$489>>2] = $525;
 HEAPF32[$492>>2] = $526;
 HEAPF32[$495>>2] = $527;
 HEAPF32[$501>>2] = $540;
 HEAPF32[$504>>2] = $541;
 HEAPF32[$507>>2] = $542;
 $543 = HEAP32[$row>>2]|0;
 $544 = (($543) + 28|0);
 $545 = HEAP32[$5>>2]|0;
 $546 = (($545) + 28|0);
 $547 = HEAP32[$9>>2]|0;
 $548 = (($547) + 28|0);
 $549 = Math_fround(HEAPF32[$544>>2]);
 $550 = Math_fround($278 * $549);
 $551 = Math_fround(HEAPF32[$546>>2]);
 $552 = Math_fround($279 * $551);
 $553 = Math_fround($550 + $552);
 $554 = Math_fround(HEAPF32[$548>>2]);
 $555 = Math_fround($280 * $554);
 $556 = Math_fround($553 + $555);
 $557 = Math_fround($281 * $549);
 $558 = Math_fround($283 * $551);
 $559 = Math_fround($557 + $558);
 $560 = Math_fround($284 * $554);
 $561 = Math_fround($559 + $560);
 $562 = Math_fround($285 * $549);
 $563 = Math_fround($286 * $551);
 $564 = Math_fround($562 + $563);
 $565 = Math_fround($287 * $554);
 $566 = Math_fround($564 + $565);
 HEAPF32[$544>>2] = $556;
 HEAPF32[$546>>2] = $561;
 HEAPF32[$548>>2] = $566;
 $567 = (($543) + 12|0);
 $568 = (($545) + 12|0);
 $569 = (($547) + 12|0);
 $570 = Math_fround(HEAPF32[$567>>2]);
 $571 = Math_fround($278 * $570);
 $572 = Math_fround(HEAPF32[$568>>2]);
 $573 = Math_fround($279 * $572);
 $574 = Math_fround($571 + $573);
 $575 = Math_fround(HEAPF32[$569>>2]);
 $576 = Math_fround($280 * $575);
 $577 = Math_fround($574 + $576);
 $578 = Math_fround($281 * $570);
 $579 = Math_fround($283 * $572);
 $580 = Math_fround($578 + $579);
 $581 = Math_fround($284 * $575);
 $582 = Math_fround($580 + $581);
 $583 = Math_fround($285 * $570);
 $584 = Math_fround($286 * $572);
 $585 = Math_fround($583 + $584);
 $586 = Math_fround($287 * $575);
 $587 = Math_fround($585 + $586);
 HEAPF32[$567>>2] = $577;
 HEAPF32[$568>>2] = $582;
 HEAPF32[$569>>2] = $587;
 STACKTOP = sp;return;
}
function __ZN5physx19PxsConstraintHelper21setupSolverConstraintERKNS_11PxTransformES3_PKNS_13PxcSolverBodyES6_PNS_17PxcSolverBodyDataES8_PFjPNS_14Px1DConstraintERNS_6PxVec3EjRNS_24PxConstraintInvMassScaleEPKvS3_S3_ESG_jffRNS_23PxcSolverConstraintDescERKNS_13PxsConstraintERNS_24PxcConstraintBlockStreamERNS_25PxsConstraintBlockManagerE($pose0,$pose1,$sBody0,$sBody1,$sBodyData0,$sBodyData1,$solverPrep,$constantBlock,$0,$dt,$recipdt,$desc,$constraint,$blockStream,$constraintBlockManager) {
 $pose0 = $pose0|0;
 $pose1 = $pose1|0;
 $sBody0 = $sBody0|0;
 $sBody1 = $sBody1|0;
 $sBodyData0 = $sBodyData0|0;
 $sBodyData1 = $sBodyData1|0;
 $solverPrep = $solverPrep|0;
 $constantBlock = $constantBlock|0;
 $0 = $0|0;
 $dt = Math_fround($dt);
 $recipdt = Math_fround($recipdt);
 $desc = $desc|0;
 $constraint = $constraint|0;
 $blockStream = $blockStream|0;
 $constraintBlockManager = $constraintBlockManager|0;
 var $$ = Math_fround(0), $$0$i = 0, $$1 = 0, $$28 = Math_fround(0), $$pre$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0);
 var $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0);
 var $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0;
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = 0;
 var $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0;
 var $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0);
 var $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0);
 var $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0);
 var $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $body0WorldOffset = 0, $constraints$022 = 0, $constraints$022$us = 0, $eb0 = 0, $eb1 = 0, $exitcond = 0, $exitcond25 = 0, $exitcond27 = 0, $i$024 = 0, $i1$023 = 0, $i1$023$us = 0, $ims = 0, $magicptr2 = 0, $normalVel$0 = Math_fround(0);
 var $normalVel$0$us = Math_fround(0), $or$cond = 0, $or$cond21$us = 0, $rows = 0, $sorted = 0, $split = 0, $split$sum = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1136|0;
 $rows = sp + 64|0;
 $ims = sp + 1112|0;
 $body0WorldOffset = sp + 1096|0;
 $sorted = sp + 1048|0;
 $eb0 = sp + 1024|0;
 $eb1 = sp + 1036|0;
 $1 = sp + 32|0;
 $2 = sp;
 $3 = (($desc) + 26|0);
 HEAP16[$3>>1] = 0;
 $4 = ($solverPrep|0)==(0|0);
 if ($4) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $i$024 = 0;
 while(1) {
  $5 = (($rows) + (($i$024*80)|0)|0);
  $6 = ((($rows) + (($i$024*80)|0)|0) + 48|0);
  HEAPF32[$6>>2] = Math_fround(0.0);
  $7 = ((($rows) + (($i$024*80)|0)|0) + 52|0);
  HEAPF32[$7>>2] = Math_fround(0.0);
  $8 = ((($rows) + (($i$024*80)|0)|0) + 56|0);
  HEAPF32[$8>>2] = Math_fround(0.0);
  $9 = ((($rows) + (($i$024*80)|0)|0) + 72|0);
  HEAPF32[$9>>2] = Math_fround(0.0);
  $10 = ((($rows) + (($i$024*80)|0)|0) + 44|0);
  dest=$5+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAPF32[$10>>2] = Math_fround(-3.40282346638528859812E+38);
  $11 = ((($rows) + (($i$024*80)|0)|0) + 60|0);
  HEAPF32[$11>>2] = Math_fround(3.40282346638528859812E+38);
  $12 = ((($rows) + (($i$024*80)|0)|0) + 64|0);
  HEAPF32[$12>>2] = Math_fround(0.0);
  $13 = ((($rows) + (($i$024*80)|0)|0) + 68|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = ((($rows) + (($i$024*80)|0)|0) + 76|0);
  HEAP16[$14>>1] = 0;
  $15 = ((($rows) + (($i$024*80)|0)|0) + 78|0);
  HEAP16[$15>>1] = 0;
  $16 = (($i$024) + 1)|0;
  $exitcond25 = ($16|0)==(12);
  if ($exitcond25) {
   break;
  } else {
   $i$024 = $16;
  }
 }
 ;HEAP32[$ims+0>>2]=HEAP32[488800+0>>2]|0;HEAP32[$ims+4>>2]=HEAP32[488800+4>>2]|0;HEAP32[$ims+8>>2]=HEAP32[488800+8>>2]|0;HEAP32[$ims+12>>2]=HEAP32[488800+12>>2]|0;
 HEAPF32[$body0WorldOffset>>2] = Math_fround(0.0);
 $17 = (($body0WorldOffset) + 4|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($body0WorldOffset) + 8|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (FUNCTION_TABLE_iiiiiiii[$solverPrep & 127]($rows,$body0WorldOffset,12,$ims,$constantBlock,$pose0,$pose1)|0);
 $20 = ($19|0)==(0);
 if ($20) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $21 = (($desc) + 8|0);
 $22 = HEAP16[$21>>1]|0;
 $23 = ($22<<16>>16)==(-1);
 if ($23) {
  $24 = (($desc) + 12|0);
  $25 = HEAP16[$24>>1]|0;
  $26 = ($25<<16>>16)!=(-1);
  $28 = $26;
 } else {
  $28 = 1;
 }
 $27 = $28 ? 176 : 112;
 $29 = Math_imul($27, $19)|0;
 $30 = (($29) + 48)|0;
 $31 = (($29) + 79)|0;
 $32 = $31 & -16;
 $33 = ($32>>>0)>(16384);
 do {
  if ($33) {
   $34 = HEAP32[$blockStream>>2]|0;
   $35 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($34,$32)|0);
   $$0$i = $35;
  } else {
   $36 = (($blockStream) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   $$pre$i = (($blockStream) + 8|0);
   if (!($38)) {
    $39 = HEAP32[$$pre$i>>2]|0;
    $40 = (($39) + ($32))|0;
    $41 = ($40>>>0)>(16384);
    if (!($41)) {
     $44 = (($37) + ($39)|0);
     HEAP32[$$pre$i>>2] = $40;
     $$0$i = $44;
     break;
    }
   }
   $42 = HEAP32[$blockStream>>2]|0;
   $43 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($42,$constraintBlockManager)|0);
   HEAP32[$36>>2] = $43;
   HEAP32[$$pre$i>>2] = $32;
   $$0$i = $43;
  }
 } while(0);
 $magicptr2 = $$0$i;
 if ((($magicptr2|0) == -1) | (($magicptr2|0) == 0)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $45 = (($desc) + 16|0);
 HEAP32[$45>>2] = $$0$i;
 $46 = $30 >>> 4;
 $47 = $46&65535;
 HEAP16[$3>>1] = $47;
 $48 = (($constraint) + 32|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($desc) + 20|0);
 HEAP32[$50>>2] = $49;
 $51 = (($desc) + 24|0);
 HEAP16[$51>>1] = 8;
 _memset(($$0$i|0),0,($30|0))|0;
 $52 = HEAP32[$45>>2]|0;
 $53 = (($52) + 48|0);
 $54 = $19&255;
 $55 = $28 ? 4 : 2;
 HEAP8[$52>>0] = $55;
 $56 = (($52) + 1|0);
 HEAP8[$56>>0] = $54;
 $57 = (($52) + 2|0);
 HEAP8[$57>>0] = 0;
 $58 = Math_fround(HEAPF32[$ims>>2]);
 $59 = (($52) + 32|0);
 HEAPF32[$59>>2] = $58;
 $60 = (($ims) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($52) + 36|0);
 HEAPF32[$62>>2] = $61;
 $63 = (($ims) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(-$64);
 $66 = (($52) + 40|0);
 HEAPF32[$66>>2] = $65;
 $67 = (($ims) + 12|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround(-$68);
 $70 = (($52) + 44|0);
 HEAPF32[$70>>2] = $69;
 $71 = (($52) + 16|0);
 $72 = Math_fround(HEAPF32[$body0WorldOffset>>2]);
 HEAPF32[$71>>2] = $72;
 $73 = Math_fround(HEAPF32[$17>>2]);
 $74 = (($52) + 20|0);
 HEAPF32[$74>>2] = $73;
 $75 = Math_fround(HEAPF32[$18>>2]);
 $76 = (($52) + 24|0);
 HEAPF32[$76>>2] = $75;
 $77 = Math_fround(HEAPF32[$constraint>>2]);
 $78 = Math_fround($77 * $dt);
 $79 = (($52) + 4|0);
 HEAPF32[$79>>2] = $78;
 $80 = (($constraint) + 4|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 * $dt);
 $83 = (($52) + 8|0);
 HEAPF32[$83>>2] = $82;
 $84 = (($constraint) + 52|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = $85 & 256;
 $87 = ($86|0)!=(0);
 __ZN5physx14preprocessRowsEPPNS_14Px1DConstraintES1_jRKNS_17PxcSolverBodyDataES5_RKNS_24PxConstraintInvMassScaleEbb($sorted,$rows,$19,$sBodyData0,$sBodyData1,$ims,$28,$87);
 $88 = HEAP32[$84>>2]|0;
 $89 = $88 & 128;
 $90 = ($89|0)!=(0);
 $91 = $90 ? Math_fround(0.699999988079071044921) : Math_fround(1.0);
 $92 = (($eb0) + 4|0);
 $93 = (($eb0) + 8|0);
 $94 = (($desc) + 12|0);
 $95 = (($eb1) + 4|0);
 $96 = (($eb1) + 8|0);
 $97 = (($1) + 4|0);
 $98 = (($1) + 8|0);
 $99 = (($1) + 12|0);
 $100 = (($1) + 16|0);
 $101 = (($1) + 20|0);
 $102 = (($1) + 24|0);
 $103 = (($1) + 28|0);
 $104 = (($2) + 4|0);
 $105 = (($2) + 8|0);
 $106 = (($2) + 12|0);
 $107 = (($2) + 16|0);
 $108 = (($2) + 20|0);
 $109 = (($2) + 24|0);
 $110 = (($2) + 28|0);
 $111 = (($sBodyData0) + 4|0);
 $112 = (($sBodyData0) + 8|0);
 $113 = (($sBodyData0) + 12|0);
 $114 = (($sBodyData0) + 16|0);
 $115 = (($sBodyData0) + 20|0);
 $116 = (($sBodyData0) + 24|0);
 $117 = (($sBodyData0) + 28|0);
 $118 = (($sBodyData0) + 32|0);
 $119 = (($sBodyData0) + 48|0);
 $120 = (($sBodyData1) + 4|0);
 $121 = (($sBodyData1) + 8|0);
 $122 = (($sBodyData1) + 12|0);
 $123 = (($sBodyData1) + 16|0);
 $124 = (($sBodyData1) + 20|0);
 $125 = (($sBodyData1) + 24|0);
 $126 = (($sBodyData1) + 28|0);
 $127 = (($sBodyData1) + 32|0);
 $128 = (($sBodyData1) + 48|0);
 $129 = (($sBody0) + 4|0);
 $130 = (($sBody0) + 8|0);
 $131 = (($sBody0) + 16|0);
 $132 = (($sBody0) + 20|0);
 $133 = (($sBody0) + 24|0);
 $134 = (($sBody1) + 4|0);
 $135 = (($sBody1) + 8|0);
 $136 = (($sBody1) + 16|0);
 $137 = (($sBody1) + 20|0);
 $138 = (($sBody1) + 24|0);
 $139 = $dt < Math_fround(1.0);
 $140 = $139 ? $dt : Math_fround(1.0);
 if ($28) {
  $constraints$022$us = $53;$i1$023$us = 0;
  while(1) {
   $141 = (($constraints$022$us) + 128|0);
   $142 = (($sorted) + ($i1$023$us<<2)|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = (($143) + 76|0);
   $145 = HEAP16[$144>>1]|0;
   $146 = $145 & 32;
   $147 = ($146<<16>>16)==(0);
   if ($147) {
    $154 = Math_fround(1.0);
   } else {
    $148 = HEAP32[$84>>2]|0;
    $149 = $148 & 64;
    $150 = ($149|0)==(0);
    $$ = $150 ? Math_fround(1.0) : $140;
    $154 = $$;
   }
   $151 = (($143) + 44|0);
   $152 = Math_fround(HEAPF32[$151>>2]);
   $153 = Math_fround($154 * $152);
   $155 = (($143) + 60|0);
   $156 = Math_fround(HEAPF32[$155>>2]);
   $157 = Math_fround($154 * $156);
   $158 = Math_fround(HEAPF32[$143>>2]);
   HEAPF32[$constraints$022$us>>2] = $158;
   $159 = (($143) + 4|0);
   $160 = Math_fround(HEAPF32[$159>>2]);
   $161 = (($constraints$022$us) + 4|0);
   HEAPF32[$161>>2] = $160;
   $162 = (($143) + 8|0);
   $163 = Math_fround(HEAPF32[$162>>2]);
   $164 = (($constraints$022$us) + 8|0);
   HEAPF32[$164>>2] = $163;
   $165 = (($143) + 32|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   $167 = (($constraints$022$us) + 16|0);
   HEAPF32[$167>>2] = $166;
   $168 = (($143) + 36|0);
   $169 = Math_fround(HEAPF32[$168>>2]);
   $170 = (($constraints$022$us) + 20|0);
   HEAPF32[$170>>2] = $169;
   $171 = (($143) + 40|0);
   $172 = Math_fround(HEAPF32[$171>>2]);
   $173 = (($constraints$022$us) + 24|0);
   HEAPF32[$173>>2] = $172;
   $174 = (($143) + 16|0);
   $175 = Math_fround(HEAPF32[$174>>2]);
   $176 = (($constraints$022$us) + 32|0);
   HEAPF32[$176>>2] = $175;
   $177 = (($143) + 20|0);
   $178 = Math_fround(HEAPF32[$177>>2]);
   $179 = (($constraints$022$us) + 36|0);
   HEAPF32[$179>>2] = $178;
   $180 = (($143) + 24|0);
   $181 = Math_fround(HEAPF32[$180>>2]);
   $182 = (($constraints$022$us) + 40|0);
   HEAPF32[$182>>2] = $181;
   $183 = (($143) + 48|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = (($constraints$022$us) + 48|0);
   HEAPF32[$185>>2] = $184;
   $186 = (($143) + 52|0);
   $187 = Math_fround(HEAPF32[$186>>2]);
   $188 = (($constraints$022$us) + 52|0);
   HEAPF32[$188>>2] = $187;
   $189 = (($143) + 56|0);
   $190 = Math_fround(HEAPF32[$189>>2]);
   $191 = (($constraints$022$us) + 56|0);
   HEAPF32[$191>>2] = $190;
   $192 = (($constraints$022$us) + 96|0);
   HEAPF32[$192>>2] = $153;
   $193 = (($constraints$022$us) + 100|0);
   HEAPF32[$193>>2] = $157;
   $194 = (($constraints$022$us) + 108|0);
   HEAP32[$194>>2] = 0;
   $195 = (($constraints$022$us) + 104|0);
   HEAPF32[$195>>2] = Math_fround(0.0);
   $196 = HEAP16[$21>>1]|0;
   HEAP32[$eb0>>2] = $sBody0;
   HEAP32[$92>>2] = $sBodyData0;
   HEAP16[$93>>1] = $196;
   $197 = HEAP16[$94>>1]|0;
   HEAP32[$eb1>>2] = $sBody1;
   HEAP32[$95>>2] = $sBodyData1;
   HEAP16[$96>>1] = $197;
   HEAPF32[$1>>2] = $158;
   $198 = Math_fround(HEAPF32[$161>>2]);
   HEAPF32[$97>>2] = $198;
   $199 = Math_fround(HEAPF32[$164>>2]);
   HEAPF32[$98>>2] = $199;
   HEAPF32[$99>>2] = Math_fround(0.0);
   $200 = Math_fround(HEAPF32[$176>>2]);
   HEAPF32[$100>>2] = $200;
   $201 = Math_fround(HEAPF32[$179>>2]);
   HEAPF32[$101>>2] = $201;
   $202 = Math_fround(HEAPF32[$182>>2]);
   HEAPF32[$102>>2] = $202;
   HEAPF32[$103>>2] = Math_fround(0.0);
   $203 = (($constraints$022$us) + 112|0);
   $204 = Math_fround(HEAPF32[$ims>>2]);
   $205 = Math_fround(HEAPF32[$60>>2]);
   $206 = Math_fround(HEAPF32[$167>>2]);
   $207 = Math_fround(-$206);
   $208 = Math_fround(HEAPF32[$170>>2]);
   $209 = Math_fround(-$208);
   $210 = Math_fround(HEAPF32[$173>>2]);
   $211 = Math_fround(-$210);
   $212 = Math_fround(HEAPF32[$185>>2]);
   $213 = Math_fround(-$212);
   $214 = Math_fround(HEAPF32[$188>>2]);
   $215 = Math_fround(-$214);
   $216 = Math_fround(HEAPF32[$191>>2]);
   $217 = Math_fround(-$216);
   HEAPF32[$2>>2] = $207;
   HEAPF32[$104>>2] = $209;
   HEAPF32[$105>>2] = $211;
   HEAPF32[$106>>2] = Math_fround(0.0);
   HEAPF32[$107>>2] = $213;
   HEAPF32[$108>>2] = $215;
   HEAPF32[$109>>2] = $217;
   HEAPF32[$110>>2] = Math_fround(0.0);
   $218 = (($constraints$022$us) + 144|0);
   $219 = Math_fround(HEAPF32[$63>>2]);
   $220 = Math_fround(HEAPF32[$67>>2]);
   $221 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($eb0,$1,$203,$204,$205,$eb1,$2,$218,$219,$220,1)));
   $222 = HEAP16[$144>>1]|0;
   $223 = $222&65535;
   $224 = $223 & 4;
   $225 = ($224|0)!=(0);
   $226 = $223 & 3;
   $227 = ($226|0)==(3);
   $or$cond21$us = $225 | $227;
   if ($or$cond21$us) {
    $228 = (Math_fround(__ZNK5physx16PxsSolverExtBody15projectVelocityERKNS_6PxVec3ES3_($eb0,$constraints$022$us,$176)));
    $229 = (Math_fround(__ZNK5physx16PxsSolverExtBody15projectVelocityERKNS_6PxVec3ES3_($eb1,$167,$185)));
    $230 = Math_fround($228 - $229);
    $normalVel$0$us = $230;
   } else {
    $normalVel$0$us = Math_fround(0.0);
   }
   $231 = (($constraints$022$us) + 12|0);
   $232 = (($constraints$022$us) + 28|0);
   $233 = (($constraints$022$us) + 44|0);
   $234 = (($constraints$022$us) + 60|0);
   __ZN5physx18setSolverConstantsERfS0_S0_S0_RKNS_14Px1DConstraintEfffff($231,$232,$233,$234,$143,$normalVel$0$us,$221,$91,$dt,$recipdt);
   $235 = HEAP16[$144>>1]|0;
   $236 = $235 & 16;
   $237 = ($236<<16>>16)==(0);
   if (!($237)) {
    $238 = HEAP32[$194>>2]|0;
    $239 = $238 | 2;
    HEAP32[$194>>2] = $239;
   }
   $240 = (($constraints$022$us) + ($27)|0);
   $241 = (($i1$023$us) + 1)|0;
   $exitcond27 = ($241|0)==($19|0);
   if ($exitcond27) {
    break;
   } else {
    $constraints$022$us = $240;$i1$023$us = $241;
   }
  }
 } else {
  $constraints$022 = $53;$i1$023 = 0;
  while(1) {
   $242 = (($constraints$022) + 128|0);
   $243 = (($sorted) + ($i1$023<<2)|0);
   $244 = HEAP32[$243>>2]|0;
   $245 = (($244) + 76|0);
   $246 = HEAP16[$245>>1]|0;
   $247 = $246 & 32;
   $248 = ($247<<16>>16)==(0);
   if ($248) {
    $255 = Math_fround(1.0);
   } else {
    $249 = HEAP32[$84>>2]|0;
    $250 = $249 & 64;
    $251 = ($250|0)==(0);
    $$28 = $251 ? Math_fround(1.0) : $140;
    $255 = $$28;
   }
   $252 = (($244) + 44|0);
   $253 = Math_fround(HEAPF32[$252>>2]);
   $254 = Math_fround($255 * $253);
   $256 = (($244) + 60|0);
   $257 = Math_fround(HEAPF32[$256>>2]);
   $258 = Math_fround($255 * $257);
   $259 = Math_fround(HEAPF32[$244>>2]);
   HEAPF32[$constraints$022>>2] = $259;
   $260 = (($244) + 4|0);
   $261 = Math_fround(HEAPF32[$260>>2]);
   $262 = (($constraints$022) + 4|0);
   HEAPF32[$262>>2] = $261;
   $263 = (($244) + 8|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = (($constraints$022) + 8|0);
   HEAPF32[$265>>2] = $264;
   $266 = (($244) + 32|0);
   $267 = Math_fround(HEAPF32[$266>>2]);
   $268 = (($constraints$022) + 16|0);
   HEAPF32[$268>>2] = $267;
   $269 = (($244) + 36|0);
   $270 = Math_fround(HEAPF32[$269>>2]);
   $271 = (($constraints$022) + 20|0);
   HEAPF32[$271>>2] = $270;
   $272 = (($244) + 40|0);
   $273 = Math_fround(HEAPF32[$272>>2]);
   $274 = (($constraints$022) + 24|0);
   HEAPF32[$274>>2] = $273;
   $275 = (($244) + 16|0);
   $276 = Math_fround(HEAPF32[$275>>2]);
   $277 = (($constraints$022) + 32|0);
   HEAPF32[$277>>2] = $276;
   $278 = (($244) + 20|0);
   $279 = Math_fround(HEAPF32[$278>>2]);
   $280 = (($constraints$022) + 36|0);
   HEAPF32[$280>>2] = $279;
   $281 = (($244) + 24|0);
   $282 = Math_fround(HEAPF32[$281>>2]);
   $283 = (($constraints$022) + 40|0);
   HEAPF32[$283>>2] = $282;
   $284 = (($244) + 48|0);
   $285 = Math_fround(HEAPF32[$284>>2]);
   $286 = (($constraints$022) + 48|0);
   HEAPF32[$286>>2] = $285;
   $287 = (($244) + 52|0);
   $288 = Math_fround(HEAPF32[$287>>2]);
   $289 = (($constraints$022) + 52|0);
   HEAPF32[$289>>2] = $288;
   $290 = (($244) + 56|0);
   $291 = Math_fround(HEAPF32[$290>>2]);
   $292 = (($constraints$022) + 56|0);
   HEAPF32[$292>>2] = $291;
   $293 = (($constraints$022) + 96|0);
   HEAPF32[$293>>2] = $254;
   $294 = (($constraints$022) + 100|0);
   HEAPF32[$294>>2] = $258;
   $295 = (($constraints$022) + 108|0);
   HEAP32[$295>>2] = 0;
   $296 = (($constraints$022) + 104|0);
   HEAPF32[$296>>2] = Math_fround(0.0);
   $297 = (($constraints$022) + 64|0);
   $298 = Math_fround(HEAPF32[$ims>>2]);
   $299 = Math_fround(HEAPF32[$60>>2]);
   $300 = Math_fround(HEAPF32[$275>>2]);
   $301 = Math_fround(HEAPF32[$sBodyData0>>2]);
   $302 = Math_fround($300 * $301);
   $303 = Math_fround(HEAPF32[$111>>2]);
   $304 = Math_fround($300 * $303);
   $305 = Math_fround(HEAPF32[$112>>2]);
   $306 = Math_fround($300 * $305);
   $307 = Math_fround(HEAPF32[$278>>2]);
   $308 = Math_fround(HEAPF32[$113>>2]);
   $309 = Math_fround($307 * $308);
   $310 = Math_fround(HEAPF32[$114>>2]);
   $311 = Math_fround($307 * $310);
   $312 = Math_fround(HEAPF32[$115>>2]);
   $313 = Math_fround($307 * $312);
   $314 = Math_fround($302 + $309);
   $315 = Math_fround($304 + $311);
   $316 = Math_fround($306 + $313);
   $317 = Math_fround(HEAPF32[$281>>2]);
   $318 = Math_fround(HEAPF32[$116>>2]);
   $319 = Math_fround($317 * $318);
   $320 = Math_fround(HEAPF32[$117>>2]);
   $321 = Math_fround($317 * $320);
   $322 = Math_fround(HEAPF32[$118>>2]);
   $323 = Math_fround($317 * $322);
   $324 = Math_fround($314 + $319);
   $325 = Math_fround($315 + $321);
   $326 = Math_fround($316 + $323);
   $327 = Math_fround($299 * $324);
   $328 = Math_fround($299 * $325);
   $329 = Math_fround($299 * $326);
   HEAPF32[$297>>2] = $327;
   $330 = (($constraints$022) + 68|0);
   HEAPF32[$330>>2] = $328;
   $331 = (($constraints$022) + 72|0);
   HEAPF32[$331>>2] = $329;
   $332 = Math_fround(HEAPF32[$244>>2]);
   $333 = Math_fround($332 * $332);
   $334 = Math_fround(HEAPF32[$260>>2]);
   $335 = Math_fround($334 * $334);
   $336 = Math_fround($333 + $335);
   $337 = Math_fround(HEAPF32[$263>>2]);
   $338 = Math_fround($337 * $337);
   $339 = Math_fround($336 + $338);
   $340 = Math_fround(HEAPF32[$119>>2]);
   $341 = Math_fround($340 * $339);
   $342 = Math_fround($298 * $341);
   $343 = Math_fround(HEAPF32[$275>>2]);
   $344 = Math_fround($327 * $343);
   $345 = Math_fround(HEAPF32[$278>>2]);
   $346 = Math_fround($328 * $345);
   $347 = Math_fround($344 + $346);
   $348 = Math_fround(HEAPF32[$281>>2]);
   $349 = Math_fround($329 * $348);
   $350 = Math_fround($347 + $349);
   $351 = Math_fround($342 + $350);
   $352 = Math_fround(HEAPF32[$266>>2]);
   $353 = Math_fround(HEAPF32[$269>>2]);
   $354 = Math_fround(HEAPF32[$272>>2]);
   $355 = Math_fround(HEAPF32[$284>>2]);
   $356 = Math_fround(-$355);
   $357 = Math_fround(HEAPF32[$287>>2]);
   $358 = Math_fround(-$357);
   $359 = Math_fround(HEAPF32[$290>>2]);
   $360 = Math_fround(-$359);
   $361 = (($constraints$022) + 80|0);
   $362 = Math_fround(HEAPF32[$63>>2]);
   $363 = Math_fround(HEAPF32[$67>>2]);
   $364 = Math_fround(HEAPF32[$sBodyData1>>2]);
   $365 = Math_fround($364 * $356);
   $366 = Math_fround(HEAPF32[$120>>2]);
   $367 = Math_fround($366 * $356);
   $368 = Math_fround(HEAPF32[$121>>2]);
   $369 = Math_fround($368 * $356);
   $370 = Math_fround(HEAPF32[$122>>2]);
   $371 = Math_fround($370 * $358);
   $372 = Math_fround(HEAPF32[$123>>2]);
   $373 = Math_fround($372 * $358);
   $374 = Math_fround(HEAPF32[$124>>2]);
   $375 = Math_fround($374 * $358);
   $376 = Math_fround($365 + $371);
   $377 = Math_fround($367 + $373);
   $378 = Math_fround($369 + $375);
   $379 = Math_fround(HEAPF32[$125>>2]);
   $380 = Math_fround($379 * $360);
   $381 = Math_fround(HEAPF32[$126>>2]);
   $382 = Math_fround($381 * $360);
   $383 = Math_fround(HEAPF32[$127>>2]);
   $384 = Math_fround($383 * $360);
   $385 = Math_fround($376 + $380);
   $386 = Math_fround($377 + $382);
   $387 = Math_fround($378 + $384);
   $388 = Math_fround($363 * $385);
   $389 = Math_fround($363 * $386);
   $390 = Math_fround($363 * $387);
   HEAPF32[$361>>2] = $388;
   $391 = (($constraints$022) + 84|0);
   HEAPF32[$391>>2] = $389;
   $392 = (($constraints$022) + 88|0);
   HEAPF32[$392>>2] = $390;
   $393 = Math_fround($352 * $352);
   $394 = Math_fround($353 * $353);
   $395 = Math_fround($393 + $394);
   $396 = Math_fround($354 * $354);
   $397 = Math_fround($395 + $396);
   $398 = Math_fround(HEAPF32[$128>>2]);
   $399 = Math_fround($397 * $398);
   $400 = Math_fround($362 * $399);
   $401 = Math_fround($388 * $356);
   $402 = Math_fround($389 * $358);
   $403 = Math_fround($401 + $402);
   $404 = Math_fround($390 * $360);
   $405 = Math_fround($403 + $404);
   $406 = Math_fround($400 + $405);
   $407 = Math_fround($351 + $406);
   $408 = Math_fround(HEAPF32[$119>>2]);
   $409 = Math_fround(HEAPF32[$ims>>2]);
   $410 = Math_fround($408 * $409);
   $411 = (($constraints$022) + 76|0);
   HEAPF32[$411>>2] = $410;
   $412 = Math_fround(HEAPF32[$128>>2]);
   $413 = Math_fround(HEAPF32[$63>>2]);
   $414 = Math_fround($412 * $413);
   $415 = Math_fround(-$414);
   $416 = (($constraints$022) + 92|0);
   HEAPF32[$416>>2] = $415;
   $417 = HEAP16[$245>>1]|0;
   $418 = $417&65535;
   $419 = $418 & 4;
   $420 = ($419|0)!=(0);
   $421 = $418 & 3;
   $422 = ($421|0)==(3);
   $or$cond = $420 | $422;
   if ($or$cond) {
    $423 = Math_fround(HEAPF32[$sBody0>>2]);
    $424 = Math_fround(HEAPF32[$constraints$022>>2]);
    $425 = Math_fround($423 * $424);
    $426 = Math_fround(HEAPF32[$129>>2]);
    $427 = Math_fround(HEAPF32[$262>>2]);
    $428 = Math_fround($426 * $427);
    $429 = Math_fround($425 + $428);
    $430 = Math_fround(HEAPF32[$130>>2]);
    $431 = Math_fround(HEAPF32[$265>>2]);
    $432 = Math_fround($430 * $431);
    $433 = Math_fround($429 + $432);
    $434 = Math_fround(HEAPF32[$131>>2]);
    $435 = Math_fround(HEAPF32[$277>>2]);
    $436 = Math_fround($434 * $435);
    $437 = Math_fround(HEAPF32[$132>>2]);
    $438 = Math_fround(HEAPF32[$280>>2]);
    $439 = Math_fround($437 * $438);
    $440 = Math_fround($436 + $439);
    $441 = Math_fround(HEAPF32[$133>>2]);
    $442 = Math_fround(HEAPF32[$283>>2]);
    $443 = Math_fround($441 * $442);
    $444 = Math_fround($440 + $443);
    $445 = Math_fround($433 + $444);
    $446 = Math_fround(HEAPF32[$sBody1>>2]);
    $447 = Math_fround(HEAPF32[$268>>2]);
    $448 = Math_fround($446 * $447);
    $449 = Math_fround(HEAPF32[$134>>2]);
    $450 = Math_fround(HEAPF32[$271>>2]);
    $451 = Math_fround($449 * $450);
    $452 = Math_fround($448 + $451);
    $453 = Math_fround(HEAPF32[$135>>2]);
    $454 = Math_fround(HEAPF32[$274>>2]);
    $455 = Math_fround($453 * $454);
    $456 = Math_fround($452 + $455);
    $457 = Math_fround(HEAPF32[$136>>2]);
    $458 = Math_fround(HEAPF32[$286>>2]);
    $459 = Math_fround($457 * $458);
    $460 = Math_fround(HEAPF32[$137>>2]);
    $461 = Math_fround(HEAPF32[$289>>2]);
    $462 = Math_fround($460 * $461);
    $463 = Math_fround($459 + $462);
    $464 = Math_fround(HEAPF32[$138>>2]);
    $465 = Math_fround(HEAPF32[$292>>2]);
    $466 = Math_fround($464 * $465);
    $467 = Math_fround($463 + $466);
    $468 = Math_fround($456 + $467);
    $469 = Math_fround($445 - $468);
    $normalVel$0 = $469;
   } else {
    $normalVel$0 = Math_fround(0.0);
   }
   $470 = (($constraints$022) + 12|0);
   $471 = (($constraints$022) + 28|0);
   $472 = (($constraints$022) + 44|0);
   $473 = (($constraints$022) + 60|0);
   __ZN5physx18setSolverConstantsERfS0_S0_S0_RKNS_14Px1DConstraintEfffff($470,$471,$472,$473,$244,$normalVel$0,$407,$91,$dt,$recipdt);
   $474 = HEAP16[$245>>1]|0;
   $475 = $474 & 16;
   $476 = ($475<<16>>16)==(0);
   if (!($476)) {
    $477 = HEAP32[$295>>2]|0;
    $478 = $477 | 2;
    HEAP32[$295>>2] = $478;
   }
   $479 = (($constraints$022) + ($27)|0);
   $480 = (($i1$023) + 1)|0;
   $exitcond = ($480|0)==($19|0);
   if ($exitcond) {
    break;
   } else {
    $constraints$022 = $479;$i1$023 = $480;
   }
  }
 }
 $split = (($52) + ($30)|0);
 HEAP32[$split>>2] = 0;
 $split$sum = (($29) + 52)|0;
 $481 = (($52) + ($split$sum)|0);
 HEAP32[$481>>2] = 0;
 $$1 = $19;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx18setSolverConstantsERfS0_S0_S0_RKNS_14Px1DConstraintEfffff($constant,$unbiasedConstant,$velMultiplier,$impulseMultiplier,$c,$normalVel,$unitResponse,$erp,$dt,$recipdt) {
 $constant = $constant|0;
 $unbiasedConstant = $unbiasedConstant|0;
 $velMultiplier = $velMultiplier|0;
 $impulseMultiplier = $impulseMultiplier|0;
 $c = $c|0;
 $normalVel = Math_fround($normalVel);
 $unitResponse = Math_fround($unitResponse);
 $erp = Math_fround($erp);
 $dt = Math_fround($dt);
 $recipdt = Math_fround($recipdt);
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $fabsf$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($unitResponse)))));
 $0 = Math_fround(Math_fround(1.0) / $unitResponse);
 $1 = $fabsf$i$i <= Math_fround(-0.0);
 $2 = $1 ? Math_fround(0.0) : $0;
 $3 = (($c) + 12|0);
 $4 = (($c) + 76|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = $6 & 1;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = Math_fround(HEAPF32[$3>>2]);
  $10 = Math_fround($9 * $erp);
  $11 = Math_fround($dt * $dt);
  $12 = (($c) + 64|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($11 * $13);
  $15 = (($c) + 68|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($16 * $dt);
  $18 = Math_fround($14 + $17);
  $19 = (($c) + 28|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($16 * $20);
  $22 = Math_fround($13 * $10);
  $23 = Math_fround($21 - $22);
  $24 = Math_fround($23 * $dt);
  $25 = $6 & 2;
  $26 = ($25|0)==(0);
  if ($26) {
   $34 = Math_fround($18 * $unitResponse);
   $35 = Math_fround($34 + Math_fround(1.0));
   $36 = Math_fround(Math_fround(1.0) / $35);
   $37 = Math_fround($24 * $36);
   HEAPF32[$unbiasedConstant>>2] = $37;
   HEAPF32[$constant>>2] = $37;
   $38 = Math_fround($18 * $36);
   $39 = Math_fround(-$38);
   HEAPF32[$velMultiplier>>2] = $39;
   $40 = Math_fround(Math_fround(1.0) - $36);
   HEAPF32[$impulseMultiplier>>2] = $40;
   STACKTOP = sp;return;
  } else {
   $27 = Math_fround($18 + Math_fround(1.0));
   $28 = Math_fround(Math_fround(1.0) / $27);
   $29 = Math_fround($2 * $28);
   $30 = Math_fround($24 * $29);
   HEAPF32[$unbiasedConstant>>2] = $30;
   HEAPF32[$constant>>2] = $30;
   $31 = Math_fround($18 * $29);
   $32 = Math_fround(-$31);
   HEAPF32[$velMultiplier>>2] = $32;
   $33 = Math_fround(Math_fround(1.0) - $28);
   HEAPF32[$impulseMultiplier>>2] = $33;
   STACKTOP = sp;return;
  }
 }
 $41 = Math_fround(-$2);
 HEAPF32[$velMultiplier>>2] = $41;
 HEAPF32[$impulseMultiplier>>2] = Math_fround(1.0);
 $42 = $5 & 4;
 $43 = ($42<<16>>16)==(0);
 if (!($43)) {
  $44 = Math_fround(-$normalVel);
  $45 = (($c) + 68|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = $46 < $44;
  if ($47) {
   $48 = (($c) + 64|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = Math_fround($2 * $49);
   $51 = Math_fround($50 * $44);
   HEAPF32[$constant>>2] = $51;
   HEAPF32[$unbiasedConstant>>2] = $51;
   STACKTOP = sp;return;
  }
 }
 $52 = (($c) + 28|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround(HEAPF32[$3>>2]);
 $55 = Math_fround($54 * $recipdt);
 $56 = Math_fround($53 - $55);
 $57 = Math_fround($2 * $56);
 HEAPF32[$constant>>2] = $57;
 $58 = Math_fround(HEAPF32[$52>>2]);
 $59 = (($c) + 72|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 * $recipdt);
 $62 = Math_fround($58 - $61);
 $63 = Math_fround($2 * $62);
 HEAPF32[$unbiasedConstant>>2] = $63;
 STACKTOP = sp;return;
}
function __ZN5physx12_GLOBAL__N_112innerProductERKNS_14Px1DConstraintERS1_RKNS0_9MassPropsE($row0,$row1,$m) {
 $row0 = $row0|0;
 $row1 = $row1|0;
 $m = $m|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0;
 var $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$row0>>2]);
 $1 = (($row0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($row0) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($m) + 96|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 * $6);
 $8 = Math_fround($2 * $6);
 $9 = Math_fround($4 * $6);
 $10 = Math_fround(HEAPF32[$row1>>2]);
 $11 = (($row1) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($row1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($7 * $10);
 $16 = Math_fround($8 * $12);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($9 * $14);
 $19 = Math_fround($17 + $18);
 $20 = (($row0) + 32|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($row0) + 36|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($row0) + 40|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($m) + 112|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($21 * $27);
 $29 = Math_fround($23 * $27);
 $30 = Math_fround($25 * $27);
 $31 = (($row1) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($row1) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($row1) + 40|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($28 * $32);
 $38 = Math_fround($29 * $34);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($30 * $36);
 $41 = Math_fround($39 + $40);
 $42 = (($row0) + 16|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($row0) + 20|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($row0) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround(HEAPF32[$m>>2]);
 $49 = Math_fround($43 * $48);
 $50 = (($m) + 16|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($45 * $51);
 $53 = Math_fround($49 + $52);
 $54 = (($m) + 32|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($47 * $55);
 $57 = Math_fround($53 + $56);
 $58 = (($m) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($43 * $59);
 $61 = (($m) + 20|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($45 * $62);
 $64 = Math_fround($60 + $63);
 $65 = (($m) + 36|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($47 * $66);
 $68 = Math_fround($64 + $67);
 $69 = (($m) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($43 * $70);
 $72 = (($m) + 24|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($45 * $73);
 $75 = Math_fround($71 + $74);
 $76 = (($m) + 40|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($47 * $77);
 $79 = Math_fround($75 + $78);
 $80 = (($row1) + 16|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($row1) + 20|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($row1) + 24|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($57 * $81);
 $87 = Math_fround($68 * $83);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($79 * $85);
 $90 = Math_fround($88 + $89);
 $91 = (($row0) + 48|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($row0) + 52|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($row0) + 56|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($m) + 48|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($92 * $98);
 $100 = (($m) + 64|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($94 * $101);
 $103 = Math_fround($99 + $102);
 $104 = (($m) + 80|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($96 * $105);
 $107 = Math_fround($103 + $106);
 $108 = (($m) + 52|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($92 * $109);
 $111 = (($m) + 68|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($94 * $112);
 $114 = Math_fround($110 + $113);
 $115 = (($m) + 84|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($96 * $116);
 $118 = Math_fround($114 + $117);
 $119 = (($m) + 56|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($92 * $120);
 $122 = (($m) + 72|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($94 * $123);
 $125 = Math_fround($121 + $124);
 $126 = (($m) + 88|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = Math_fround($96 * $127);
 $129 = Math_fround($125 + $128);
 $130 = (($row1) + 48|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($row1) + 52|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($row1) + 56|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($107 * $131);
 $137 = Math_fround($118 * $133);
 $138 = Math_fround($136 + $137);
 $139 = Math_fround($129 * $135);
 $140 = Math_fround($138 + $139);
 $141 = Math_fround($19 + $41);
 $142 = Math_fround($90 + $140);
 $143 = Math_fround($141 + $142);
 STACKTOP = sp;return (Math_fround($143));
}
function __ZN5physx22setupSolverConstraint4EPNS_24PxcSolverConstraint4DescEffRNS_24PxcConstraintBlockStreamERNS_25PxsConstraintBlockManagerE($constraintDescs,$dt,$recipdt,$blockStream,$constraintBlockManager) {
 $constraintDescs = $constraintDescs|0;
 $dt = Math_fround($dt);
 $recipdt = Math_fround($recipdt);
 $blockStream = $blockStream|0;
 $constraintBlockManager = $constraintBlockManager|0;
 var $$$$i = Math_fround(0), $$$$i2298 = Math_fround(0), $$$$i2299 = Math_fround(0), $$$$i2300 = Math_fround(0), $$$i = Math_fround(0), $$0 = 0, $$0$i = 0, $$pre$i = 0, $$sum = 0, $$sum2297 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = 0, $1004 = 0, $1005 = 0;
 var $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0;
 var $1024 = 0, $1025 = 0, $1026 = 0, $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = 0, $1030 = Math_fround(0), $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0;
 var $1042 = 0, $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = 0;
 var $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = Math_fround(0), $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = Math_fround(0);
 var $1079 = Math_fround(0), $108 = 0, $1080 = Math_fround(0), $1081 = 0, $1082 = Math_fround(0), $1083 = 0, $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = 0, $1088 = Math_fround(0), $1089 = 0, $109 = 0, $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = 0, $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0);
 var $1097 = 0, $1098 = Math_fround(0), $1099 = 0, $11 = 0, $110 = 0, $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = 0, $1104 = Math_fround(0), $1105 = 0, $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = 0;
 var $1114 = Math_fround(0), $1115 = 0, $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = 0, $112 = 0, $1120 = Math_fround(0), $1121 = 0, $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = 0, $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = 0, $113 = 0, $1130 = Math_fround(0), $1131 = 0;
 var $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = 0, $1136 = Math_fround(0), $1137 = 0, $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = 0, $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = Math_fround(0), $1149 = 0, $115 = 0;
 var $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = 0, $1163 = Math_fround(0), $1164 = 0, $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = 0;
 var $1169 = Math_fround(0), $117 = 0, $1170 = 0, $1171 = Math_fround(0), $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = 0, $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = 0, $1179 = Math_fround(0), $118 = 0, $1180 = 0, $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0), $1184 = 0, $1185 = Math_fround(0), $1186 = 0;
 var $1187 = Math_fround(0), $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = 0, $1190 = Math_fround(0), $1191 = Math_fround(0), $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = 0, $1195 = Math_fround(0), $1196 = 0, $1197 = Math_fround(0), $1198 = Math_fround(0), $1199 = Math_fround(0), $12 = 0, $120 = 0, $1200 = 0, $1201 = Math_fround(0), $1202 = 0, $1203 = Math_fround(0);
 var $1204 = Math_fround(0), $1205 = Math_fround(0), $1206 = 0, $1207 = Math_fround(0), $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = 0, $1210 = 0, $1211 = Math_fround(0), $1212 = 0, $1213 = Math_fround(0), $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = 0, $1217 = Math_fround(0), $1218 = 0, $1219 = Math_fround(0), $122 = 0, $1220 = Math_fround(0), $1221 = Math_fround(0);
 var $1222 = Math_fround(0), $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = Math_fround(0), $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0;
 var $1240 = Math_fround(0), $1241 = Math_fround(0), $1242 = Math_fround(0), $1243 = 0, $1244 = Math_fround(0), $1245 = 0, $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = 0, $125 = 0, $1250 = Math_fround(0), $1251 = 0, $1252 = Math_fround(0), $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = 0, $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0);
 var $1259 = 0, $126 = 0, $1260 = Math_fround(0), $1261 = 0, $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0), $1265 = 0, $1266 = Math_fround(0), $1267 = 0, $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = 0, $1276 = Math_fround(0);
 var $1277 = 0, $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = 0, $1280 = Math_fround(0), $1281 = 0, $1282 = Math_fround(0), $1283 = 0, $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = Math_fround(0), $1287 = 0, $1288 = Math_fround(0), $1289 = Math_fround(0), $129 = 0, $1290 = Math_fround(0), $1291 = 0, $1292 = Math_fround(0), $1293 = 0, $1294 = Math_fround(0);
 var $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = 0, $1298 = Math_fround(0), $1299 = 0, $13 = 0, $130 = 0, $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = Math_fround(0), $1311 = 0;
 var $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = 0, $1325 = Math_fround(0), $1326 = 0, $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = 0;
 var $1330 = 0, $1331 = Math_fround(0), $1332 = 0, $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = 0, $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = 0, $1340 = 0, $1341 = Math_fround(0), $1342 = 0, $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = 0, $1347 = Math_fround(0), $1348 = 0;
 var $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = 0, $1357 = Math_fround(0), $1358 = 0, $1359 = Math_fround(0), $136 = 0, $1360 = Math_fround(0), $1361 = Math_fround(0), $1362 = 0, $1363 = Math_fround(0), $1364 = 0, $1365 = Math_fround(0), $1366 = Math_fround(0);
 var $1367 = Math_fround(0), $1368 = 0, $1369 = Math_fround(0), $137 = 0, $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = 0, $1373 = Math_fround(0), $1374 = 0, $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = 0, $1379 = Math_fround(0), $138 = 0, $1380 = 0, $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0);
 var $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0;
 var $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0);
 var $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0);
 var $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = 0;
 var $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0;
 var $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0);
 var $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0);
 var $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0;
 var $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0;
 var $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0);
 var $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0;
 var $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0;
 var $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0);
 var $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0;
 var $477 = Math_fround(0), $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = Math_fround(0), $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = 0, $487 = Math_fround(0), $488 = 0, $489 = Math_fround(0), $49 = 0, $490 = 0, $491 = Math_fround(0), $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = Math_fround(0), $628 = 0, $629 = Math_fround(0), $63 = 0, $630 = 0, $631 = Math_fround(0), $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = 0, $636 = Math_fround(0), $637 = Math_fround(0), $638 = 0;
 var $639 = Math_fround(0), $64 = 0, $640 = 0, $641 = Math_fround(0), $642 = Math_fround(0), $643 = 0, $644 = Math_fround(0), $645 = 0, $646 = Math_fround(0), $647 = 0, $648 = Math_fround(0), $649 = 0, $65 = 0, $650 = Math_fround(0), $651 = 0, $652 = Math_fround(0), $653 = 0, $654 = Math_fround(0), $655 = 0, $656 = Math_fround(0);
 var $657 = 0, $658 = Math_fround(0), $659 = 0, $66 = 0, $660 = Math_fround(0), $661 = 0, $662 = Math_fround(0), $663 = 0, $664 = Math_fround(0), $665 = 0, $666 = Math_fround(0), $667 = 0, $668 = Math_fround(0), $669 = 0, $67 = 0, $670 = Math_fround(0), $671 = 0, $672 = Math_fround(0), $673 = 0, $674 = Math_fround(0);
 var $675 = 0, $676 = Math_fround(0), $677 = 0, $678 = Math_fround(0), $679 = 0, $68 = 0, $680 = Math_fround(0), $681 = 0, $682 = Math_fround(0), $683 = 0, $684 = Math_fround(0), $685 = 0, $686 = Math_fround(0), $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0);
 var $729 = Math_fround(0), $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0);
 var $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0);
 var $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0);
 var $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0;
 var $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0);
 var $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = 0, $836 = 0;
 var $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0, $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0);
 var $855 = 0, $856 = Math_fround(0), $857 = 0, $858 = Math_fround(0), $859 = 0, $86 = 0, $860 = Math_fround(0), $861 = 0, $862 = Math_fround(0), $863 = 0, $864 = Math_fround(0), $865 = 0, $866 = Math_fround(0), $867 = 0, $868 = Math_fround(0), $869 = 0, $87 = 0, $870 = Math_fround(0), $871 = 0, $872 = Math_fround(0);
 var $873 = 0, $874 = Math_fround(0), $875 = 0, $876 = Math_fround(0), $877 = 0, $878 = Math_fround(0), $879 = 0, $88 = 0, $880 = Math_fround(0), $881 = 0, $882 = Math_fround(0), $883 = 0, $884 = Math_fround(0), $885 = 0, $886 = Math_fround(0), $887 = 0, $888 = Math_fround(0), $889 = 0, $89 = 0, $890 = Math_fround(0);
 var $891 = 0, $892 = Math_fround(0), $893 = 0, $894 = Math_fround(0), $895 = 0, $896 = Math_fround(0), $897 = 0, $898 = Math_fround(0), $899 = 0, $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = 0, $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0);
 var $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0);
 var $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = 0, $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0);
 var $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = 0, $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = 0, $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0);
 var $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = 0, $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0);
 var $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0, $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0);
 var $a$02290 = 0, $a6$02278 = 0, $allRows = 0, $allSorted = 0, $b$02285 = 0, $body0WorldOffset = 0, $currPtr$0$lcssa = 0, $currPtr$02276 = 0, $erp = 0, $exitcond = 0, $ims = 0, $index0$02274 = 0, $index1$02273 = 0, $index2$02275 = 0, $index3$02277 = 0, $magicptr = 0, $maxRows$02292 = 0, $not$ = 0, $not$2 = 0, $not$3 = 0;
 var $not$4 = 0, $numRows$02293 = 0, $or$cond$i = 0, $or$cond$i13 = 0, $or$cond$i5 = 0, $or$cond$i9 = 0, $preppedIndex$02291 = 0, $scevgep2294 = 0, $umax = 0, $zero = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4176|0;
 $zero = sp + 3840|0;
 $allRows = sp;
 $allSorted = sp + 3984|0;
 $body0WorldOffset = sp + 3856|0;
 $ims = sp + 3904|0;
 $erp = sp + 3968|0;
 ;HEAP32[$zero+0>>2]=0|0;HEAP32[$zero+4>>2]=0|0;HEAP32[$zero+8>>2]=0|0;HEAP32[$zero+12>>2]=0|0;
 $0 = (($body0WorldOffset) + 4|0);
 $1 = (($body0WorldOffset) + 8|0);
 $2 = (($body0WorldOffset) + 12|0);
 $3 = (($body0WorldOffset) + 16|0);
 $4 = (($body0WorldOffset) + 20|0);
 $5 = (($body0WorldOffset) + 24|0);
 $6 = (($body0WorldOffset) + 28|0);
 $7 = (($body0WorldOffset) + 32|0);
 $8 = (($body0WorldOffset) + 36|0);
 $9 = (($body0WorldOffset) + 40|0);
 $10 = (($body0WorldOffset) + 44|0);
 dest=$body0WorldOffset+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$ims+0|0; src=488816+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $a$02290 = 0;$maxRows$02292 = 0;$numRows$02293 = 0;$preppedIndex$02291 = 0;
 while(1) {
  $11 = (($allRows) + (($numRows$02293*80)|0)|0);
  $12 = ((($constraintDescs) + (($a$02290*52)|0)|0) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $$0 = 1;
   label = 56;
   break;
  }
  $15 = ($preppedIndex$02291>>>0)<(12);
  if ($15) {
   $b$02285 = $preppedIndex$02291;
   while(1) {
    $$sum = (($b$02285) + ($numRows$02293))|0;
    $16 = (($allRows) + (($$sum*80)|0)|0);
    $17 = ((($allRows) + (($$sum*80)|0)|0) + 48|0);
    HEAPF32[$17>>2] = Math_fround(0.0);
    $18 = ((($allRows) + (($$sum*80)|0)|0) + 52|0);
    HEAPF32[$18>>2] = Math_fround(0.0);
    $19 = ((($allRows) + (($$sum*80)|0)|0) + 56|0);
    HEAPF32[$19>>2] = Math_fround(0.0);
    $20 = ((($allRows) + (($$sum*80)|0)|0) + 72|0);
    HEAPF32[$20>>2] = Math_fround(0.0);
    $21 = ((($allRows) + (($$sum*80)|0)|0) + 44|0);
    dest=$16+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAPF32[$21>>2] = Math_fround(-3.40282346638528859812E+38);
    $22 = ((($allRows) + (($$sum*80)|0)|0) + 60|0);
    HEAPF32[$22>>2] = Math_fround(3.40282346638528859812E+38);
    $23 = ((($allRows) + (($$sum*80)|0)|0) + 64|0);
    HEAPF32[$23>>2] = Math_fround(0.0);
    $24 = ((($allRows) + (($$sum*80)|0)|0) + 68|0);
    HEAPF32[$24>>2] = Math_fround(0.0);
    $25 = ((($allRows) + (($$sum*80)|0)|0) + 76|0);
    HEAP16[$25>>1] = 0;
    $26 = ((($allRows) + (($$sum*80)|0)|0) + 78|0);
    HEAP16[$26>>1] = 0;
    $27 = (($b$02285) + 1)|0;
    $exitcond = ($27|0)==(12);
    if ($exitcond) {
     break;
    } else {
     $b$02285 = $27;
    }
   }
  }
  $28 = (($body0WorldOffset) + (($a$02290*12)|0)|0);
  $29 = (($ims) + ($a$02290<<4)|0);
  $30 = ((($constraintDescs) + (($a$02290*52)|0)|0) + 32|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($constraintDescs) + (($a$02290*52)|0)|0) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($constraintDescs) + (($a$02290*52)|0)|0) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (FUNCTION_TABLE_iiiiiiii[$13 & 127]($11,$28,12,$29,$31,$33,$35)|0);
  $37 = ($36|0)==(0);
  if ($37) {
   $$0 = 1;
   label = 56;
   break;
  }
  $38 = ($36>>>0)<($maxRows$02292>>>0);
  $39 = $38 ? $maxRows$02292 : $36;
  $40 = (12 - ($36))|0;
  $41 = ((($constraintDescs) + (($a$02290*52)|0)|0) + 44|0);
  HEAP32[$41>>2] = $numRows$02293;
  $42 = ((($constraintDescs) + (($a$02290*52)|0)|0) + 48|0);
  HEAP32[$42>>2] = $36;
  $43 = (($36) + ($numRows$02293))|0;
  $44 = (($allSorted) + ($numRows$02293<<2)|0);
  $45 = ((($constraintDescs) + (($a$02290*52)|0)|0) + 20|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($constraintDescs) + (($a$02290*52)|0)|0) + 24|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($constraintDescs) + (($a$02290*52)|0)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + 52|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 & 256;
  $54 = ($53|0)!=(0);
  __ZN5physx14preprocessRowsEPPNS_14Px1DConstraintES1_jRKNS_17PxcSolverBodyDataES5_RKNS_24PxConstraintInvMassScaleEbb($44,$11,$36,$46,$48,$29,0,$54);
  $55 = (($a$02290) + 1)|0;
  $56 = ($55>>>0)<(4);
  if ($56) {
   $a$02290 = $55;$maxRows$02292 = $39;$numRows$02293 = $43;$preppedIndex$02291 = $40;
  } else {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  $57 = ($39*416)|0;
  $58 = (($57) + 128)|0;
  $59 = (($57) + 159)|0;
  $60 = $59 & -16;
  $61 = ($60>>>0)>(16384);
  do {
   if ($61) {
    $62 = HEAP32[$blockStream>>2]|0;
    $63 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($62,$60)|0);
    $$0$i = $63;
   } else {
    $64 = (($blockStream) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65|0)==(0|0);
    $$pre$i = (($blockStream) + 8|0);
    if (!($66)) {
     $67 = HEAP32[$$pre$i>>2]|0;
     $68 = (($67) + ($60))|0;
     $69 = ($68>>>0)>(16384);
     if (!($69)) {
      $72 = (($65) + ($67)|0);
      HEAP32[$$pre$i>>2] = $68;
      $$0$i = $72;
      break;
     }
    }
    $70 = HEAP32[$blockStream>>2]|0;
    $71 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($70,$constraintBlockManager)|0);
    HEAP32[$64>>2] = $71;
    HEAP32[$$pre$i>>2] = $60;
    $$0$i = $71;
   }
  } while(0);
  $magicptr = $$0$i;
  if ((($magicptr|0) == 0) | (($magicptr|0) == -1)) {
   $73 = (($constraintDescs) + 40|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + 16|0);
   HEAP32[$75>>2] = 0;
   $76 = HEAP32[$73>>2]|0;
   $77 = (($76) + 26|0);
   HEAP16[$77>>1] = 0;
   $78 = HEAP32[$constraintDescs>>2]|0;
   $79 = (($78) + 32|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($76) + 20|0);
   HEAP32[$81>>2] = $80;
   $82 = (($constraintDescs) + 92|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($83) + 16|0);
   HEAP32[$84>>2] = 0;
   $85 = HEAP32[$82>>2]|0;
   $86 = (($85) + 26|0);
   HEAP16[$86>>1] = 0;
   $87 = (($constraintDescs) + 52|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($88) + 32|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($85) + 20|0);
   HEAP32[$91>>2] = $90;
   $92 = (($constraintDescs) + 144|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + 16|0);
   HEAP32[$94>>2] = 0;
   $95 = HEAP32[$92>>2]|0;
   $96 = (($95) + 26|0);
   HEAP16[$96>>1] = 0;
   $97 = (($constraintDescs) + 104|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($98) + 32|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($95) + 20|0);
   HEAP32[$101>>2] = $100;
   $102 = (($constraintDescs) + 196|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (($103) + 16|0);
   HEAP32[$104>>2] = 0;
   $105 = HEAP32[$102>>2]|0;
   $106 = (($105) + 26|0);
   HEAP16[$106>>1] = 0;
   $107 = (($constraintDescs) + 156|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($108) + 32|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = (($105) + 20|0);
   HEAP32[$111>>2] = $110;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $112 = $58 >>> 4;
  $113 = $112&65535;
  $114 = (($constraintDescs) + 40|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($115) + 16|0);
  HEAP32[$116>>2] = $$0$i;
  $117 = HEAP32[$114>>2]|0;
  $118 = (($117) + 26|0);
  HEAP16[$118>>1] = $113;
  $119 = HEAP32[$constraintDescs>>2]|0;
  $120 = (($119) + 32|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = (($117) + 20|0);
  HEAP32[$122>>2] = $121;
  $123 = (($constraintDescs) + 92|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = (($124) + 16|0);
  HEAP32[$125>>2] = $$0$i;
  $126 = HEAP32[$123>>2]|0;
  $127 = (($126) + 26|0);
  HEAP16[$127>>1] = $113;
  $128 = (($constraintDescs) + 52|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (($129) + 32|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = (($126) + 20|0);
  HEAP32[$132>>2] = $131;
  $133 = (($constraintDescs) + 144|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = (($134) + 16|0);
  HEAP32[$135>>2] = $$0$i;
  $136 = HEAP32[$133>>2]|0;
  $137 = (($136) + 26|0);
  HEAP16[$137>>1] = $113;
  $138 = (($constraintDescs) + 104|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = (($139) + 32|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = (($136) + 20|0);
  HEAP32[$142>>2] = $141;
  $143 = (($constraintDescs) + 196|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = (($144) + 16|0);
  HEAP32[$145>>2] = $$0$i;
  $146 = HEAP32[$143>>2]|0;
  $147 = (($146) + 26|0);
  HEAP16[$147>>1] = $113;
  $148 = (($constraintDescs) + 156|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = (($149) + 32|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = (($146) + 20|0);
  HEAP32[$152>>2] = $151;
  $153 = HEAP32[$constraintDescs>>2]|0;
  $154 = (($153) + 52|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = $155 & 128;
  $157 = ($156|0)!=(0);
  $158 = $157 ? Math_fround(0.699999988079071044921) : Math_fround(1.0);
  HEAPF32[$erp>>2] = $158;
  $159 = HEAP32[$128>>2]|0;
  $160 = (($159) + 52|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = $161 & 128;
  $163 = ($162|0)!=(0);
  $164 = $163 ? Math_fround(0.699999988079071044921) : Math_fround(1.0);
  $165 = (($erp) + 4|0);
  HEAPF32[$165>>2] = $164;
  $166 = HEAP32[$138>>2]|0;
  $167 = (($166) + 52|0);
  $168 = HEAP32[$167>>2]|0;
  $169 = $168 & 128;
  $170 = ($169|0)!=(0);
  $171 = $170 ? Math_fround(0.699999988079071044921) : Math_fround(1.0);
  $172 = (($erp) + 8|0);
  HEAPF32[$172>>2] = $171;
  $173 = HEAP32[$148>>2]|0;
  $174 = (($173) + 52|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = $175 & 128;
  $177 = ($176|0)!=(0);
  $178 = $177 ? Math_fround(0.699999988079071044921) : Math_fround(1.0);
  $179 = (($erp) + 12|0);
  HEAPF32[$179>>2] = $178;
  $180 = (($$0$i) + 128|0);
  $181 = (($constraintDescs) + 20|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = (($constraintDescs) + 72|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = (($constraintDescs) + 124|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = (($constraintDescs) + 176|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = (($constraintDescs) + 24|0);
  $190 = HEAP32[$189>>2]|0;
  $191 = (($constraintDescs) + 76|0);
  $192 = HEAP32[$191>>2]|0;
  $193 = (($constraintDescs) + 128|0);
  $194 = HEAP32[$193>>2]|0;
  $195 = (($constraintDescs) + 180|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = Math_fround(HEAPF32[$ims>>2]);
  $198 = (($ims) + 16|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = (($ims) + 32|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (($ims) + 48|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = (($ims) + 8|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = (($ims) + 24|0);
  $207 = Math_fround(HEAPF32[$206>>2]);
  $208 = (($ims) + 40|0);
  $209 = Math_fround(HEAPF32[$208>>2]);
  $210 = (($ims) + 56|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = (($182) + 48|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = (($184) + 48|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($186) + 48|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($188) + 48|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = Math_fround($197 * $213);
  $221 = Math_fround($199 * $215);
  $222 = Math_fround($201 * $217);
  $223 = Math_fround($203 * $219);
  $224 = (($190) + 48|0);
  $225 = Math_fround(HEAPF32[$224>>2]);
  $226 = (($192) + 48|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = (($194) + 48|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = (($196) + 48|0);
  $231 = Math_fround(HEAPF32[$230>>2]);
  $232 = Math_fround($205 * $225);
  $233 = Math_fround($207 * $227);
  $234 = Math_fround($209 * $229);
  $235 = Math_fround($211 * $231);
  $236 = Math_fround(-$232);
  $237 = Math_fround(-$233);
  $238 = Math_fround(-$234);
  $239 = Math_fround(-$235);
  $240 = (($ims) + 4|0);
  $241 = Math_fround(HEAPF32[$240>>2]);
  $242 = (($ims) + 20|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = (($ims) + 36|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = (($ims) + 52|0);
  $247 = Math_fround(HEAPF32[$246>>2]);
  $248 = (($ims) + 12|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = (($ims) + 28|0);
  $251 = Math_fround(HEAPF32[$250>>2]);
  $252 = (($ims) + 44|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = (($ims) + 60|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = Math_fround(HEAPF32[$182>>2]);
  $257 = (($182) + 4|0);
  $258 = Math_fround(HEAPF32[$257>>2]);
  $259 = (($182) + 8|0);
  $260 = Math_fround(HEAPF32[$259>>2]);
  $261 = (($182) + 12|0);
  $262 = Math_fround(HEAPF32[$261>>2]);
  $263 = (($182) + 16|0);
  $264 = Math_fround(HEAPF32[$263>>2]);
  $265 = (($182) + 20|0);
  $266 = Math_fround(HEAPF32[$265>>2]);
  $267 = (($182) + 24|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = (($182) + 28|0);
  $270 = Math_fround(HEAPF32[$269>>2]);
  $271 = (($182) + 32|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = Math_fround(HEAPF32[$184>>2]);
  $274 = (($184) + 4|0);
  $275 = Math_fround(HEAPF32[$274>>2]);
  $276 = (($184) + 8|0);
  $277 = Math_fround(HEAPF32[$276>>2]);
  $278 = (($184) + 12|0);
  $279 = Math_fround(HEAPF32[$278>>2]);
  $280 = (($184) + 16|0);
  $281 = Math_fround(HEAPF32[$280>>2]);
  $282 = (($184) + 20|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = (($184) + 24|0);
  $285 = Math_fround(HEAPF32[$284>>2]);
  $286 = (($184) + 28|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $288 = (($184) + 32|0);
  $289 = Math_fround(HEAPF32[$288>>2]);
  $290 = Math_fround(HEAPF32[$186>>2]);
  $291 = (($186) + 4|0);
  $292 = Math_fround(HEAPF32[$291>>2]);
  $293 = (($186) + 8|0);
  $294 = Math_fround(HEAPF32[$293>>2]);
  $295 = (($186) + 12|0);
  $296 = Math_fround(HEAPF32[$295>>2]);
  $297 = (($186) + 16|0);
  $298 = Math_fround(HEAPF32[$297>>2]);
  $299 = (($186) + 20|0);
  $300 = Math_fround(HEAPF32[$299>>2]);
  $301 = (($186) + 24|0);
  $302 = Math_fround(HEAPF32[$301>>2]);
  $303 = (($186) + 28|0);
  $304 = Math_fround(HEAPF32[$303>>2]);
  $305 = (($186) + 32|0);
  $306 = Math_fround(HEAPF32[$305>>2]);
  $307 = Math_fround(HEAPF32[$188>>2]);
  $308 = (($188) + 4|0);
  $309 = Math_fround(HEAPF32[$308>>2]);
  $310 = (($188) + 8|0);
  $311 = Math_fround(HEAPF32[$310>>2]);
  $312 = (($188) + 12|0);
  $313 = Math_fround(HEAPF32[$312>>2]);
  $314 = (($188) + 16|0);
  $315 = Math_fround(HEAPF32[$314>>2]);
  $316 = (($188) + 20|0);
  $317 = Math_fround(HEAPF32[$316>>2]);
  $318 = (($188) + 24|0);
  $319 = Math_fround(HEAPF32[$318>>2]);
  $320 = (($188) + 28|0);
  $321 = Math_fround(HEAPF32[$320>>2]);
  $322 = (($188) + 32|0);
  $323 = Math_fround(HEAPF32[$322>>2]);
  $324 = Math_fround(HEAPF32[$190>>2]);
  $325 = (($190) + 4|0);
  $326 = Math_fround(HEAPF32[$325>>2]);
  $327 = (($190) + 8|0);
  $328 = Math_fround(HEAPF32[$327>>2]);
  $329 = (($190) + 12|0);
  $330 = Math_fround(HEAPF32[$329>>2]);
  $331 = (($190) + 16|0);
  $332 = Math_fround(HEAPF32[$331>>2]);
  $333 = (($190) + 20|0);
  $334 = Math_fround(HEAPF32[$333>>2]);
  $335 = (($190) + 24|0);
  $336 = Math_fround(HEAPF32[$335>>2]);
  $337 = (($190) + 28|0);
  $338 = Math_fround(HEAPF32[$337>>2]);
  $339 = (($190) + 32|0);
  $340 = Math_fround(HEAPF32[$339>>2]);
  $341 = Math_fround(HEAPF32[$192>>2]);
  $342 = (($192) + 4|0);
  $343 = Math_fround(HEAPF32[$342>>2]);
  $344 = (($192) + 8|0);
  $345 = Math_fround(HEAPF32[$344>>2]);
  $346 = (($192) + 12|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  $348 = (($192) + 16|0);
  $349 = Math_fround(HEAPF32[$348>>2]);
  $350 = (($192) + 20|0);
  $351 = Math_fround(HEAPF32[$350>>2]);
  $352 = (($192) + 24|0);
  $353 = Math_fround(HEAPF32[$352>>2]);
  $354 = (($192) + 28|0);
  $355 = Math_fround(HEAPF32[$354>>2]);
  $356 = (($192) + 32|0);
  $357 = Math_fround(HEAPF32[$356>>2]);
  $358 = Math_fround(HEAPF32[$194>>2]);
  $359 = (($194) + 4|0);
  $360 = Math_fround(HEAPF32[$359>>2]);
  $361 = (($194) + 8|0);
  $362 = Math_fround(HEAPF32[$361>>2]);
  $363 = (($194) + 12|0);
  $364 = Math_fround(HEAPF32[$363>>2]);
  $365 = (($194) + 16|0);
  $366 = Math_fround(HEAPF32[$365>>2]);
  $367 = (($194) + 20|0);
  $368 = Math_fround(HEAPF32[$367>>2]);
  $369 = (($194) + 24|0);
  $370 = Math_fround(HEAPF32[$369>>2]);
  $371 = (($194) + 28|0);
  $372 = Math_fround(HEAPF32[$371>>2]);
  $373 = (($194) + 32|0);
  $374 = Math_fround(HEAPF32[$373>>2]);
  $375 = Math_fround(HEAPF32[$196>>2]);
  $376 = (($196) + 4|0);
  $377 = Math_fround(HEAPF32[$376>>2]);
  $378 = (($196) + 8|0);
  $379 = Math_fround(HEAPF32[$378>>2]);
  $380 = (($196) + 12|0);
  $381 = Math_fround(HEAPF32[$380>>2]);
  $382 = (($196) + 16|0);
  $383 = Math_fround(HEAPF32[$382>>2]);
  $384 = (($196) + 20|0);
  $385 = Math_fround(HEAPF32[$384>>2]);
  $386 = (($196) + 24|0);
  $387 = Math_fround(HEAPF32[$386>>2]);
  $388 = (($196) + 28|0);
  $389 = Math_fround(HEAPF32[$388>>2]);
  $390 = (($196) + 32|0);
  $391 = Math_fround(HEAPF32[$390>>2]);
  $392 = Math_fround($241 * $256);
  $393 = Math_fround($243 * $273);
  $394 = Math_fround($245 * $290);
  $395 = Math_fround($247 * $307);
  $396 = Math_fround($241 * $258);
  $397 = Math_fround($243 * $275);
  $398 = Math_fround($245 * $292);
  $399 = Math_fround($247 * $309);
  $400 = Math_fround($241 * $260);
  $401 = Math_fround($243 * $277);
  $402 = Math_fround($245 * $294);
  $403 = Math_fround($247 * $311);
  $404 = Math_fround($241 * $262);
  $405 = Math_fround($243 * $279);
  $406 = Math_fround($245 * $296);
  $407 = Math_fround($247 * $313);
  $408 = Math_fround($241 * $264);
  $409 = Math_fround($243 * $281);
  $410 = Math_fround($245 * $298);
  $411 = Math_fround($247 * $315);
  $412 = Math_fround($241 * $266);
  $413 = Math_fround($243 * $283);
  $414 = Math_fround($245 * $300);
  $415 = Math_fround($247 * $317);
  $416 = Math_fround($241 * $268);
  $417 = Math_fround($243 * $285);
  $418 = Math_fround($245 * $302);
  $419 = Math_fround($247 * $319);
  $420 = Math_fround($241 * $270);
  $421 = Math_fround($243 * $287);
  $422 = Math_fround($245 * $304);
  $423 = Math_fround($247 * $321);
  $424 = Math_fround($241 * $272);
  $425 = Math_fround($243 * $289);
  $426 = Math_fround($245 * $306);
  $427 = Math_fround($247 * $323);
  $428 = Math_fround($249 * $324);
  $429 = Math_fround($251 * $341);
  $430 = Math_fround($253 * $358);
  $431 = Math_fround($255 * $375);
  $432 = Math_fround($249 * $326);
  $433 = Math_fround($251 * $343);
  $434 = Math_fround($253 * $360);
  $435 = Math_fround($255 * $377);
  $436 = Math_fround($249 * $328);
  $437 = Math_fround($251 * $345);
  $438 = Math_fround($253 * $362);
  $439 = Math_fround($255 * $379);
  $440 = Math_fround($249 * $330);
  $441 = Math_fround($251 * $347);
  $442 = Math_fround($253 * $364);
  $443 = Math_fround($255 * $381);
  $444 = Math_fround($249 * $332);
  $445 = Math_fround($251 * $349);
  $446 = Math_fround($253 * $366);
  $447 = Math_fround($255 * $383);
  $448 = Math_fround($249 * $334);
  $449 = Math_fround($251 * $351);
  $450 = Math_fround($253 * $368);
  $451 = Math_fround($255 * $385);
  $452 = Math_fround($249 * $336);
  $453 = Math_fround($251 * $353);
  $454 = Math_fround($253 * $370);
  $455 = Math_fround($255 * $387);
  $456 = Math_fround($249 * $338);
  $457 = Math_fround($251 * $355);
  $458 = Math_fround($253 * $372);
  $459 = Math_fround($255 * $389);
  $460 = Math_fround($249 * $340);
  $461 = Math_fround($251 * $357);
  $462 = Math_fround($253 * $374);
  $463 = Math_fround($255 * $391);
  $464 = Math_fround(HEAPF32[$body0WorldOffset>>2]);
  $465 = Math_fround(HEAPF32[$0>>2]);
  $466 = Math_fround(HEAPF32[$1>>2]);
  $467 = Math_fround(HEAPF32[$2>>2]);
  $468 = Math_fround(HEAPF32[$3>>2]);
  $469 = Math_fround(HEAPF32[$4>>2]);
  $470 = Math_fround(HEAPF32[$5>>2]);
  $471 = Math_fround(HEAPF32[$6>>2]);
  $472 = Math_fround(HEAPF32[$7>>2]);
  $473 = Math_fround(HEAPF32[$8>>2]);
  $474 = Math_fround(HEAPF32[$9>>2]);
  $475 = Math_fround(HEAPF32[$10>>2]);
  $476 = HEAP32[$constraintDescs>>2]|0;
  $477 = Math_fround(HEAPF32[$476>>2]);
  $478 = HEAP32[$128>>2]|0;
  $479 = Math_fround(HEAPF32[$478>>2]);
  $480 = HEAP32[$138>>2]|0;
  $481 = Math_fround(HEAPF32[$480>>2]);
  $482 = HEAP32[$148>>2]|0;
  $483 = Math_fround(HEAPF32[$482>>2]);
  $484 = (($476) + 4|0);
  $485 = Math_fround(HEAPF32[$484>>2]);
  $486 = (($478) + 4|0);
  $487 = Math_fround(HEAPF32[$486>>2]);
  $488 = (($480) + 4|0);
  $489 = Math_fround(HEAPF32[$488>>2]);
  $490 = (($482) + 4|0);
  $491 = Math_fround(HEAPF32[$490>>2]);
  $492 = (($$0$i) + 48|0);
  HEAPF32[$492>>2] = $220;
  $493 = (($$0$i) + 52|0);
  HEAPF32[$493>>2] = $221;
  $494 = (($$0$i) + 56|0);
  HEAPF32[$494>>2] = $222;
  $495 = (($$0$i) + 60|0);
  HEAPF32[$495>>2] = $223;
  $496 = (($$0$i) + 64|0);
  HEAPF32[$496>>2] = $236;
  $497 = (($$0$i) + 68|0);
  HEAPF32[$497>>2] = $237;
  $498 = (($$0$i) + 72|0);
  HEAPF32[$498>>2] = $238;
  $499 = (($$0$i) + 76|0);
  HEAPF32[$499>>2] = $239;
  $500 = (($$0$i) + 80|0);
  HEAPF32[$500>>2] = $464;
  $501 = (($$0$i) + 84|0);
  HEAPF32[$501>>2] = $467;
  $502 = (($$0$i) + 88|0);
  HEAPF32[$502>>2] = $470;
  $503 = (($$0$i) + 92|0);
  HEAPF32[$503>>2] = $473;
  $504 = (($$0$i) + 96|0);
  HEAPF32[$504>>2] = $465;
  $505 = (($$0$i) + 100|0);
  HEAPF32[$505>>2] = $468;
  $506 = (($$0$i) + 104|0);
  HEAPF32[$506>>2] = $471;
  $507 = (($$0$i) + 108|0);
  HEAPF32[$507>>2] = $474;
  $508 = (($$0$i) + 112|0);
  HEAPF32[$508>>2] = $466;
  $509 = (($$0$i) + 116|0);
  HEAPF32[$509>>2] = $469;
  $510 = (($$0$i) + 120|0);
  HEAPF32[$510>>2] = $472;
  $511 = (($$0$i) + 124|0);
  HEAPF32[$511>>2] = $475;
  $512 = (($$0$i) + 4|0);
  HEAP32[$512>>2] = $39;
  HEAP8[$$0$i>>0] = 9;
  $513 = Math_fround($477 * $dt);
  $514 = Math_fround($479 * $dt);
  $515 = Math_fround($481 * $dt);
  $516 = Math_fround($483 * $dt);
  $517 = (($$0$i) + 16|0);
  HEAPF32[$517>>2] = $513;
  $518 = (($$0$i) + 20|0);
  HEAPF32[$518>>2] = $514;
  $519 = (($$0$i) + 24|0);
  HEAPF32[$519>>2] = $515;
  $520 = (($$0$i) + 28|0);
  HEAPF32[$520>>2] = $516;
  $521 = Math_fround($485 * $dt);
  $522 = Math_fround($487 * $dt);
  $523 = Math_fround($489 * $dt);
  $524 = Math_fround($491 * $dt);
  $525 = (($$0$i) + 32|0);
  HEAPF32[$525>>2] = $521;
  $526 = (($$0$i) + 36|0);
  HEAPF32[$526>>2] = $522;
  $527 = (($$0$i) + 40|0);
  HEAPF32[$527>>2] = $523;
  $528 = (($$0$i) + 44|0);
  HEAPF32[$528>>2] = $524;
  $529 = (($constraintDescs) + 48|0);
  $530 = HEAP32[$529>>2]|0;
  $531 = $530&255;
  $532 = (($$0$i) + 8|0);
  HEAP8[$532>>0] = $531;
  $533 = (($constraintDescs) + 100|0);
  $534 = HEAP32[$533>>2]|0;
  $535 = $534&255;
  $536 = (($$0$i) + 9|0);
  HEAP8[$536>>0] = $535;
  $537 = (($constraintDescs) + 152|0);
  $538 = HEAP32[$537>>2]|0;
  $539 = $538&255;
  $540 = (($$0$i) + 10|0);
  HEAP8[$540>>0] = $539;
  $541 = (($constraintDescs) + 204|0);
  $542 = HEAP32[$541>>2]|0;
  $543 = $542&255;
  $544 = (($$0$i) + 11|0);
  HEAP8[$544>>0] = $543;
  $545 = HEAP32[$529>>2]|0;
  $546 = (($545) + -1)|0;
  $547 = (($constraintDescs) + 96|0);
  $548 = HEAP32[$547>>2]|0;
  $549 = HEAP32[$533>>2]|0;
  $550 = (($548) + -1)|0;
  $551 = (($550) + ($549))|0;
  $552 = (($constraintDescs) + 148|0);
  $553 = HEAP32[$552>>2]|0;
  $554 = HEAP32[$537>>2]|0;
  $555 = (($553) + -1)|0;
  $556 = (($555) + ($554))|0;
  $557 = (($constraintDescs) + 200|0);
  $558 = HEAP32[$557>>2]|0;
  $559 = HEAP32[$541>>2]|0;
  $560 = (($558) + -1)|0;
  $561 = (($560) + ($559))|0;
  $562 = ($39|0)==(0);
  if ($562) {
   $currPtr$0$lcssa = $180;
  } else {
   $563 = (($constraintDescs) + 12|0);
   $564 = (($constraintDescs) + 16|0);
   $565 = (($constraintDescs) + 64|0);
   $566 = (($constraintDescs) + 68|0);
   $567 = (($constraintDescs) + 116|0);
   $568 = (($constraintDescs) + 120|0);
   $569 = (($constraintDescs) + 168|0);
   $570 = (($constraintDescs) + 172|0);
   $571 = $dt < Math_fround(1.0);
   $$$i = $571 ? $dt : Math_fround(1.0);
   $572 = ($36>>>0)>($maxRows$02292>>>0);
   $umax = $572 ? $36 : $maxRows$02292;
   $573 = ($umax*416)|0;
   $a6$02278 = 0;$currPtr$02276 = $180;$index0$02274 = 0;$index1$02273 = $548;$index2$02275 = $553;$index3$02277 = $558;
   while(1) {
    $574 = (($currPtr$02276) + 416|0);
    $575 = (($allSorted) + ($index0$02274<<2)|0);
    $576 = HEAP32[$575>>2]|0;
    $577 = (($allSorted) + ($index1$02273<<2)|0);
    $578 = HEAP32[$577>>2]|0;
    $579 = (($allSorted) + ($index2$02275<<2)|0);
    $580 = HEAP32[$579>>2]|0;
    $581 = (($allSorted) + ($index3$02277<<2)|0);
    $582 = HEAP32[$581>>2]|0;
    $not$ = ($index0$02274|0)!=($546|0);
    $583 = $not$&1;
    $584 = (($583) + ($index0$02274))|0;
    $not$2 = ($index1$02273|0)!=($551|0);
    $585 = $not$2&1;
    $586 = (($585) + ($index1$02273))|0;
    $not$3 = ($index2$02275|0)!=($556|0);
    $587 = $not$3&1;
    $588 = (($587) + ($index2$02275))|0;
    $not$4 = ($index3$02277|0)!=($561|0);
    $589 = $not$4&1;
    $590 = (($589) + ($index3$02277))|0;
    $591 = (($576) + 76|0);
    $592 = HEAP16[$591>>1]|0;
    $593 = $592 & 32;
    $594 = ($593<<16>>16)==(0);
    if ($594) {
     $715 = Math_fround(1.0);
    } else {
     $595 = HEAP32[$constraintDescs>>2]|0;
     $596 = (($595) + 52|0);
     $597 = HEAP32[$596>>2]|0;
     $598 = $597 & 64;
     $599 = ($598|0)==(0);
     $$$$i = $599 ? Math_fround(1.0) : $$$i;
     $715 = $$$$i;
    }
    $600 = (($578) + 76|0);
    $601 = HEAP16[$600>>1]|0;
    $602 = $601 & 32;
    $603 = ($602<<16>>16)==(0);
    if ($603) {
     $717 = Math_fround(1.0);
    } else {
     $604 = HEAP32[$128>>2]|0;
     $605 = (($604) + 52|0);
     $606 = HEAP32[$605>>2]|0;
     $607 = $606 & 64;
     $608 = ($607|0)==(0);
     $$$$i2298 = $608 ? Math_fround(1.0) : $$$i;
     $717 = $$$$i2298;
    }
    $609 = (($580) + 76|0);
    $610 = HEAP16[$609>>1]|0;
    $611 = $610 & 32;
    $612 = ($611<<16>>16)==(0);
    if ($612) {
     $719 = Math_fround(1.0);
    } else {
     $613 = HEAP32[$138>>2]|0;
     $614 = (($613) + 52|0);
     $615 = HEAP32[$614>>2]|0;
     $616 = $615 & 64;
     $617 = ($616|0)==(0);
     $$$$i2299 = $617 ? Math_fround(1.0) : $$$i;
     $719 = $$$$i2299;
    }
    $618 = (($582) + 76|0);
    $619 = HEAP16[$618>>1]|0;
    $620 = $619 & 32;
    $621 = ($620<<16>>16)==(0);
    if ($621) {
     $721 = Math_fround(1.0);
    } else {
     $622 = HEAP32[$148>>2]|0;
     $623 = (($622) + 52|0);
     $624 = HEAP32[$623>>2]|0;
     $625 = $624 & 64;
     $626 = ($625|0)==(0);
     $$$$i2300 = $626 ? Math_fround(1.0) : $$$i;
     $721 = $$$$i2300;
    }
    $627 = Math_fround(HEAPF32[$576>>2]);
    $628 = (($576) + 4|0);
    $629 = Math_fround(HEAPF32[$628>>2]);
    $630 = (($576) + 8|0);
    $631 = Math_fround(HEAPF32[$630>>2]);
    $632 = Math_fround(HEAPF32[$578>>2]);
    $633 = (($578) + 4|0);
    $634 = Math_fround(HEAPF32[$633>>2]);
    $635 = (($578) + 8|0);
    $636 = Math_fround(HEAPF32[$635>>2]);
    $637 = Math_fround(HEAPF32[$580>>2]);
    $638 = (($580) + 4|0);
    $639 = Math_fround(HEAPF32[$638>>2]);
    $640 = (($580) + 8|0);
    $641 = Math_fround(HEAPF32[$640>>2]);
    $642 = Math_fround(HEAPF32[$582>>2]);
    $643 = (($582) + 4|0);
    $644 = Math_fround(HEAPF32[$643>>2]);
    $645 = (($582) + 8|0);
    $646 = Math_fround(HEAPF32[$645>>2]);
    $647 = (($576) + 16|0);
    $648 = Math_fround(HEAPF32[$647>>2]);
    $649 = (($647) + 4|0);
    $650 = Math_fround(HEAPF32[$649>>2]);
    $651 = (($647) + 8|0);
    $652 = Math_fround(HEAPF32[$651>>2]);
    $653 = (($578) + 16|0);
    $654 = Math_fround(HEAPF32[$653>>2]);
    $655 = (($653) + 4|0);
    $656 = Math_fround(HEAPF32[$655>>2]);
    $657 = (($653) + 8|0);
    $658 = Math_fround(HEAPF32[$657>>2]);
    $659 = (($580) + 16|0);
    $660 = Math_fround(HEAPF32[$659>>2]);
    $661 = (($659) + 4|0);
    $662 = Math_fround(HEAPF32[$661>>2]);
    $663 = (($659) + 8|0);
    $664 = Math_fround(HEAPF32[$663>>2]);
    $665 = (($582) + 16|0);
    $666 = Math_fround(HEAPF32[$665>>2]);
    $667 = (($665) + 4|0);
    $668 = Math_fround(HEAPF32[$667>>2]);
    $669 = (($665) + 8|0);
    $670 = Math_fround(HEAPF32[$669>>2]);
    $671 = (($576) + 60|0);
    $672 = Math_fround(HEAPF32[$671>>2]);
    $673 = (($578) + 60|0);
    $674 = Math_fround(HEAPF32[$673>>2]);
    $675 = (($580) + 60|0);
    $676 = Math_fround(HEAPF32[$675>>2]);
    $677 = (($582) + 60|0);
    $678 = Math_fround(HEAPF32[$677>>2]);
    $679 = (($576) + 44|0);
    $680 = Math_fround(HEAPF32[$679>>2]);
    $681 = (($578) + 44|0);
    $682 = Math_fround(HEAPF32[$681>>2]);
    $683 = (($580) + 44|0);
    $684 = Math_fround(HEAPF32[$683>>2]);
    $685 = (($582) + 44|0);
    $686 = Math_fround(HEAPF32[$685>>2]);
    $687 = (($currPtr$02276) + 256|0);
    $688 = (($currPtr$02276) + 260|0);
    $689 = (($currPtr$02276) + 264|0);
    $690 = (($currPtr$02276) + 268|0);
    ;HEAP32[$687+0>>2]=0|0;HEAP32[$687+4>>2]=0|0;HEAP32[$687+8>>2]=0|0;HEAP32[$687+12>>2]=0|0;
    HEAPF32[$currPtr$02276>>2] = $627;
    $691 = (($currPtr$02276) + 4|0);
    HEAPF32[$691>>2] = $632;
    $692 = (($currPtr$02276) + 8|0);
    HEAPF32[$692>>2] = $637;
    $693 = (($currPtr$02276) + 12|0);
    HEAPF32[$693>>2] = $642;
    $694 = (($currPtr$02276) + 16|0);
    HEAPF32[$694>>2] = $629;
    $695 = (($currPtr$02276) + 20|0);
    HEAPF32[$695>>2] = $634;
    $696 = (($currPtr$02276) + 24|0);
    HEAPF32[$696>>2] = $639;
    $697 = (($currPtr$02276) + 28|0);
    HEAPF32[$697>>2] = $644;
    $698 = (($currPtr$02276) + 32|0);
    HEAPF32[$698>>2] = $631;
    $699 = (($currPtr$02276) + 36|0);
    HEAPF32[$699>>2] = $636;
    $700 = (($currPtr$02276) + 40|0);
    HEAPF32[$700>>2] = $641;
    $701 = (($currPtr$02276) + 44|0);
    HEAPF32[$701>>2] = $646;
    $702 = (($currPtr$02276) + 48|0);
    HEAPF32[$702>>2] = $648;
    $703 = (($currPtr$02276) + 52|0);
    HEAPF32[$703>>2] = $654;
    $704 = (($currPtr$02276) + 56|0);
    HEAPF32[$704>>2] = $660;
    $705 = (($currPtr$02276) + 60|0);
    HEAPF32[$705>>2] = $666;
    $706 = (($currPtr$02276) + 64|0);
    HEAPF32[$706>>2] = $650;
    $707 = (($currPtr$02276) + 68|0);
    HEAPF32[$707>>2] = $656;
    $708 = (($currPtr$02276) + 72|0);
    HEAPF32[$708>>2] = $662;
    $709 = (($currPtr$02276) + 76|0);
    HEAPF32[$709>>2] = $668;
    $710 = (($currPtr$02276) + 80|0);
    HEAPF32[$710>>2] = $652;
    $711 = (($currPtr$02276) + 84|0);
    HEAPF32[$711>>2] = $658;
    $712 = (($currPtr$02276) + 88|0);
    HEAPF32[$712>>2] = $664;
    $713 = (($currPtr$02276) + 92|0);
    HEAPF32[$713>>2] = $670;
    $714 = Math_fround($715 * $680);
    $716 = Math_fround($717 * $682);
    $718 = Math_fround($719 * $684);
    $720 = Math_fround($721 * $686);
    $722 = (($currPtr$02276) + 208|0);
    HEAPF32[$722>>2] = $714;
    $723 = (($currPtr$02276) + 212|0);
    HEAPF32[$723>>2] = $716;
    $724 = (($currPtr$02276) + 216|0);
    HEAPF32[$724>>2] = $718;
    $725 = (($currPtr$02276) + 220|0);
    HEAPF32[$725>>2] = $720;
    $726 = Math_fround($715 * $672);
    $727 = Math_fround($717 * $674);
    $728 = Math_fround($719 * $676);
    $729 = Math_fround($721 * $678);
    $730 = (($currPtr$02276) + 224|0);
    HEAPF32[$730>>2] = $726;
    $731 = (($currPtr$02276) + 228|0);
    HEAPF32[$731>>2] = $727;
    $732 = (($currPtr$02276) + 232|0);
    HEAPF32[$732>>2] = $728;
    $733 = (($currPtr$02276) + 236|0);
    HEAPF32[$733>>2] = $729;
    $734 = (($currPtr$02276) + 240|0);
    ;HEAP32[$734+0>>2]=HEAP32[$zero+0>>2]|0;HEAP32[$734+4>>2]=HEAP32[$zero+4>>2]|0;HEAP32[$734+8>>2]=HEAP32[$zero+8>>2]|0;HEAP32[$734+12>>2]=HEAP32[$zero+12>>2]|0;
    $735 = Math_fround($392 * $648);
    $736 = Math_fround($393 * $654);
    $737 = Math_fround($394 * $660);
    $738 = Math_fround($395 * $666);
    $739 = Math_fround($404 * $650);
    $740 = Math_fround($405 * $656);
    $741 = Math_fround($406 * $662);
    $742 = Math_fround($407 * $668);
    $743 = Math_fround($735 + $739);
    $744 = Math_fround($736 + $740);
    $745 = Math_fround($737 + $741);
    $746 = Math_fround($738 + $742);
    $747 = Math_fround($416 * $652);
    $748 = Math_fround($417 * $658);
    $749 = Math_fround($418 * $664);
    $750 = Math_fround($419 * $670);
    $751 = Math_fround($747 + $743);
    $752 = Math_fround($748 + $744);
    $753 = Math_fround($749 + $745);
    $754 = Math_fround($750 + $746);
    $755 = Math_fround($396 * $648);
    $756 = Math_fround($397 * $654);
    $757 = Math_fround($398 * $660);
    $758 = Math_fround($399 * $666);
    $759 = Math_fround($408 * $650);
    $760 = Math_fround($409 * $656);
    $761 = Math_fround($410 * $662);
    $762 = Math_fround($411 * $668);
    $763 = Math_fround($755 + $759);
    $764 = Math_fround($756 + $760);
    $765 = Math_fround($757 + $761);
    $766 = Math_fround($758 + $762);
    $767 = Math_fround($420 * $652);
    $768 = Math_fround($421 * $658);
    $769 = Math_fround($422 * $664);
    $770 = Math_fround($423 * $670);
    $771 = Math_fround($767 + $763);
    $772 = Math_fround($768 + $764);
    $773 = Math_fround($769 + $765);
    $774 = Math_fround($770 + $766);
    $775 = Math_fround($400 * $648);
    $776 = Math_fround($401 * $654);
    $777 = Math_fround($402 * $660);
    $778 = Math_fround($403 * $666);
    $779 = Math_fround($412 * $650);
    $780 = Math_fround($413 * $656);
    $781 = Math_fround($414 * $662);
    $782 = Math_fround($415 * $668);
    $783 = Math_fround($775 + $779);
    $784 = Math_fround($776 + $780);
    $785 = Math_fround($777 + $781);
    $786 = Math_fround($778 + $782);
    $787 = Math_fround($424 * $652);
    $788 = Math_fround($425 * $658);
    $789 = Math_fround($426 * $664);
    $790 = Math_fround($427 * $670);
    $791 = Math_fround($787 + $783);
    $792 = Math_fround($788 + $784);
    $793 = Math_fround($789 + $785);
    $794 = Math_fround($790 + $786);
    $795 = Math_fround($627 * $627);
    $796 = Math_fround($632 * $632);
    $797 = Math_fround($637 * $637);
    $798 = Math_fround($642 * $642);
    $799 = Math_fround($629 * $629);
    $800 = Math_fround($634 * $634);
    $801 = Math_fround($639 * $639);
    $802 = Math_fround($644 * $644);
    $803 = Math_fround($795 + $799);
    $804 = Math_fround($796 + $800);
    $805 = Math_fround($797 + $801);
    $806 = Math_fround($798 + $802);
    $807 = Math_fround($631 * $631);
    $808 = Math_fround($636 * $636);
    $809 = Math_fround($641 * $641);
    $810 = Math_fround($646 * $646);
    $811 = Math_fround($807 + $803);
    $812 = Math_fround($808 + $804);
    $813 = Math_fround($809 + $805);
    $814 = Math_fround($810 + $806);
    $815 = Math_fround($648 * $751);
    $816 = Math_fround($654 * $752);
    $817 = Math_fround($660 * $753);
    $818 = Math_fround($666 * $754);
    $819 = Math_fround($650 * $771);
    $820 = Math_fround($656 * $772);
    $821 = Math_fround($662 * $773);
    $822 = Math_fround($668 * $774);
    $823 = Math_fround($819 + $815);
    $824 = Math_fround($820 + $816);
    $825 = Math_fround($821 + $817);
    $826 = Math_fround($822 + $818);
    $827 = Math_fround($652 * $791);
    $828 = Math_fround($658 * $792);
    $829 = Math_fround($664 * $793);
    $830 = Math_fround($670 * $794);
    $831 = Math_fround($827 + $823);
    $832 = Math_fround($828 + $824);
    $833 = Math_fround($829 + $825);
    $834 = Math_fround($830 + $826);
    $835 = (($currPtr$02276) + 96|0);
    HEAPF32[$835>>2] = $751;
    $836 = (($currPtr$02276) + 100|0);
    HEAPF32[$836>>2] = $752;
    $837 = (($currPtr$02276) + 104|0);
    HEAPF32[$837>>2] = $753;
    $838 = (($currPtr$02276) + 108|0);
    HEAPF32[$838>>2] = $754;
    $839 = (($currPtr$02276) + 112|0);
    HEAPF32[$839>>2] = $771;
    $840 = (($currPtr$02276) + 116|0);
    HEAPF32[$840>>2] = $772;
    $841 = (($currPtr$02276) + 120|0);
    HEAPF32[$841>>2] = $773;
    $842 = (($currPtr$02276) + 124|0);
    HEAPF32[$842>>2] = $774;
    $843 = (($currPtr$02276) + 128|0);
    HEAPF32[$843>>2] = $791;
    $844 = (($currPtr$02276) + 132|0);
    HEAPF32[$844>>2] = $792;
    $845 = (($currPtr$02276) + 136|0);
    HEAPF32[$845>>2] = $793;
    $846 = (($currPtr$02276) + 140|0);
    HEAPF32[$846>>2] = $794;
    $847 = Math_fround($220 * $811);
    $848 = Math_fround($221 * $812);
    $849 = Math_fround($222 * $813);
    $850 = Math_fround($223 * $814);
    $851 = Math_fround($847 + $831);
    $852 = Math_fround($848 + $832);
    $853 = Math_fround($849 + $833);
    $854 = Math_fround($850 + $834);
    $855 = (($576) + 32|0);
    ;HEAP32[$687+0>>2]=0|0;HEAP32[$687+4>>2]=0|0;HEAP32[$687+8>>2]=0|0;HEAP32[$687+12>>2]=0|0;
    $856 = Math_fround(HEAPF32[$855>>2]);
    $857 = (($855) + 4|0);
    $858 = Math_fround(HEAPF32[$857>>2]);
    $859 = (($855) + 8|0);
    $860 = Math_fround(HEAPF32[$859>>2]);
    $861 = (($578) + 32|0);
    $862 = Math_fround(HEAPF32[$861>>2]);
    $863 = (($861) + 4|0);
    $864 = Math_fround(HEAPF32[$863>>2]);
    $865 = (($861) + 8|0);
    $866 = Math_fround(HEAPF32[$865>>2]);
    $867 = (($580) + 32|0);
    $868 = Math_fround(HEAPF32[$867>>2]);
    $869 = (($867) + 4|0);
    $870 = Math_fround(HEAPF32[$869>>2]);
    $871 = (($867) + 8|0);
    $872 = Math_fround(HEAPF32[$871>>2]);
    $873 = (($582) + 32|0);
    $874 = Math_fround(HEAPF32[$873>>2]);
    $875 = (($873) + 4|0);
    $876 = Math_fround(HEAPF32[$875>>2]);
    $877 = (($873) + 8|0);
    $878 = Math_fround(HEAPF32[$877>>2]);
    $879 = (($576) + 48|0);
    $880 = Math_fround(HEAPF32[$879>>2]);
    $881 = (($879) + 4|0);
    $882 = Math_fround(HEAPF32[$881>>2]);
    $883 = (($879) + 8|0);
    $884 = Math_fround(HEAPF32[$883>>2]);
    $885 = (($578) + 48|0);
    $886 = Math_fround(HEAPF32[$885>>2]);
    $887 = (($885) + 4|0);
    $888 = Math_fround(HEAPF32[$887>>2]);
    $889 = (($885) + 8|0);
    $890 = Math_fround(HEAPF32[$889>>2]);
    $891 = (($580) + 48|0);
    $892 = Math_fround(HEAPF32[$891>>2]);
    $893 = (($891) + 4|0);
    $894 = Math_fround(HEAPF32[$893>>2]);
    $895 = (($891) + 8|0);
    $896 = Math_fround(HEAPF32[$895>>2]);
    $897 = (($582) + 48|0);
    $898 = Math_fround(HEAPF32[$897>>2]);
    $899 = (($897) + 4|0);
    $900 = Math_fround(HEAPF32[$899>>2]);
    $901 = (($897) + 8|0);
    $902 = Math_fround(HEAPF32[$901>>2]);
    $903 = Math_fround($428 * $880);
    $904 = Math_fround($429 * $886);
    $905 = Math_fround($430 * $892);
    $906 = Math_fround($431 * $898);
    $907 = Math_fround($440 * $882);
    $908 = Math_fround($441 * $888);
    $909 = Math_fround($442 * $894);
    $910 = Math_fround($443 * $900);
    $911 = Math_fround($903 + $907);
    $912 = Math_fround($904 + $908);
    $913 = Math_fround($905 + $909);
    $914 = Math_fround($906 + $910);
    $915 = Math_fround($452 * $884);
    $916 = Math_fround($453 * $890);
    $917 = Math_fround($454 * $896);
    $918 = Math_fround($455 * $902);
    $919 = Math_fround($915 + $911);
    $920 = Math_fround($916 + $912);
    $921 = Math_fround($917 + $913);
    $922 = Math_fround($918 + $914);
    $923 = Math_fround($432 * $880);
    $924 = Math_fround($433 * $886);
    $925 = Math_fround($434 * $892);
    $926 = Math_fround($435 * $898);
    $927 = Math_fround($444 * $882);
    $928 = Math_fround($445 * $888);
    $929 = Math_fround($446 * $894);
    $930 = Math_fround($447 * $900);
    $931 = Math_fround($923 + $927);
    $932 = Math_fround($924 + $928);
    $933 = Math_fround($925 + $929);
    $934 = Math_fround($926 + $930);
    $935 = Math_fround($456 * $884);
    $936 = Math_fround($457 * $890);
    $937 = Math_fround($458 * $896);
    $938 = Math_fround($459 * $902);
    $939 = Math_fround($935 + $931);
    $940 = Math_fround($936 + $932);
    $941 = Math_fround($937 + $933);
    $942 = Math_fround($938 + $934);
    $943 = Math_fround($436 * $880);
    $944 = Math_fround($437 * $886);
    $945 = Math_fround($438 * $892);
    $946 = Math_fround($439 * $898);
    $947 = Math_fround($448 * $882);
    $948 = Math_fround($449 * $888);
    $949 = Math_fround($450 * $894);
    $950 = Math_fround($451 * $900);
    $951 = Math_fround($943 + $947);
    $952 = Math_fround($944 + $948);
    $953 = Math_fround($945 + $949);
    $954 = Math_fround($946 + $950);
    $955 = Math_fround($460 * $884);
    $956 = Math_fround($461 * $890);
    $957 = Math_fround($462 * $896);
    $958 = Math_fround($463 * $902);
    $959 = Math_fround($955 + $951);
    $960 = Math_fround($956 + $952);
    $961 = Math_fround($957 + $953);
    $962 = Math_fround($958 + $954);
    $963 = Math_fround($856 * $856);
    $964 = Math_fround($862 * $862);
    $965 = Math_fround($868 * $868);
    $966 = Math_fround($874 * $874);
    $967 = Math_fround($858 * $858);
    $968 = Math_fround($864 * $864);
    $969 = Math_fround($870 * $870);
    $970 = Math_fround($876 * $876);
    $971 = Math_fround($963 + $967);
    $972 = Math_fround($964 + $968);
    $973 = Math_fround($965 + $969);
    $974 = Math_fround($966 + $970);
    $975 = Math_fround($860 * $860);
    $976 = Math_fround($866 * $866);
    $977 = Math_fround($872 * $872);
    $978 = Math_fround($878 * $878);
    $979 = Math_fround($975 + $971);
    $980 = Math_fround($976 + $972);
    $981 = Math_fround($977 + $973);
    $982 = Math_fround($978 + $974);
    $983 = Math_fround($880 * $919);
    $984 = Math_fround($886 * $920);
    $985 = Math_fround($892 * $921);
    $986 = Math_fround($898 * $922);
    $987 = Math_fround($882 * $939);
    $988 = Math_fround($888 * $940);
    $989 = Math_fround($894 * $941);
    $990 = Math_fround($900 * $942);
    $991 = Math_fround($987 + $983);
    $992 = Math_fround($988 + $984);
    $993 = Math_fround($989 + $985);
    $994 = Math_fround($990 + $986);
    $995 = Math_fround($884 * $959);
    $996 = Math_fround($890 * $960);
    $997 = Math_fround($896 * $961);
    $998 = Math_fround($902 * $962);
    $999 = Math_fround($995 + $991);
    $1000 = Math_fround($996 + $992);
    $1001 = Math_fround($997 + $993);
    $1002 = Math_fround($998 + $994);
    $1003 = (($currPtr$02276) + 272|0);
    HEAPF32[$1003>>2] = $856;
    $1004 = (($currPtr$02276) + 276|0);
    HEAPF32[$1004>>2] = $862;
    $1005 = (($currPtr$02276) + 280|0);
    HEAPF32[$1005>>2] = $868;
    $1006 = (($currPtr$02276) + 284|0);
    HEAPF32[$1006>>2] = $874;
    $1007 = (($currPtr$02276) + 288|0);
    HEAPF32[$1007>>2] = $858;
    $1008 = (($currPtr$02276) + 292|0);
    HEAPF32[$1008>>2] = $864;
    $1009 = (($currPtr$02276) + 296|0);
    HEAPF32[$1009>>2] = $870;
    $1010 = (($currPtr$02276) + 300|0);
    HEAPF32[$1010>>2] = $876;
    $1011 = (($currPtr$02276) + 304|0);
    HEAPF32[$1011>>2] = $860;
    $1012 = (($currPtr$02276) + 308|0);
    HEAPF32[$1012>>2] = $866;
    $1013 = (($currPtr$02276) + 312|0);
    HEAPF32[$1013>>2] = $872;
    $1014 = (($currPtr$02276) + 316|0);
    HEAPF32[$1014>>2] = $878;
    $1015 = (($currPtr$02276) + 320|0);
    HEAPF32[$1015>>2] = $880;
    $1016 = (($currPtr$02276) + 324|0);
    HEAPF32[$1016>>2] = $886;
    $1017 = (($currPtr$02276) + 328|0);
    HEAPF32[$1017>>2] = $892;
    $1018 = (($currPtr$02276) + 332|0);
    HEAPF32[$1018>>2] = $898;
    $1019 = (($currPtr$02276) + 336|0);
    HEAPF32[$1019>>2] = $882;
    $1020 = (($currPtr$02276) + 340|0);
    HEAPF32[$1020>>2] = $888;
    $1021 = (($currPtr$02276) + 344|0);
    HEAPF32[$1021>>2] = $894;
    $1022 = (($currPtr$02276) + 348|0);
    HEAPF32[$1022>>2] = $900;
    $1023 = (($currPtr$02276) + 352|0);
    HEAPF32[$1023>>2] = $884;
    $1024 = (($currPtr$02276) + 356|0);
    HEAPF32[$1024>>2] = $890;
    $1025 = (($currPtr$02276) + 360|0);
    HEAPF32[$1025>>2] = $896;
    $1026 = (($currPtr$02276) + 364|0);
    HEAPF32[$1026>>2] = $902;
    $1027 = Math_fround(-$919);
    $1028 = Math_fround(-$920);
    $1029 = Math_fround(-$921);
    $1030 = Math_fround(-$922);
    $1031 = (($currPtr$02276) + 368|0);
    HEAPF32[$1031>>2] = $1027;
    $1032 = (($currPtr$02276) + 372|0);
    HEAPF32[$1032>>2] = $1028;
    $1033 = (($currPtr$02276) + 376|0);
    HEAPF32[$1033>>2] = $1029;
    $1034 = (($currPtr$02276) + 380|0);
    HEAPF32[$1034>>2] = $1030;
    $1035 = Math_fround(-$939);
    $1036 = Math_fround(-$940);
    $1037 = Math_fround(-$941);
    $1038 = Math_fround(-$942);
    $1039 = (($currPtr$02276) + 384|0);
    HEAPF32[$1039>>2] = $1035;
    $1040 = (($currPtr$02276) + 388|0);
    HEAPF32[$1040>>2] = $1036;
    $1041 = (($currPtr$02276) + 392|0);
    HEAPF32[$1041>>2] = $1037;
    $1042 = (($currPtr$02276) + 396|0);
    HEAPF32[$1042>>2] = $1038;
    $1043 = Math_fround(-$959);
    $1044 = Math_fround(-$960);
    $1045 = Math_fround(-$961);
    $1046 = Math_fround(-$962);
    $1047 = (($currPtr$02276) + 400|0);
    HEAPF32[$1047>>2] = $1043;
    $1048 = (($currPtr$02276) + 404|0);
    HEAPF32[$1048>>2] = $1044;
    $1049 = (($currPtr$02276) + 408|0);
    HEAPF32[$1049>>2] = $1045;
    $1050 = (($currPtr$02276) + 412|0);
    HEAPF32[$1050>>2] = $1046;
    $1051 = Math_fround($979 * $236);
    $1052 = Math_fround($980 * $237);
    $1053 = Math_fround($981 * $238);
    $1054 = Math_fround($982 * $239);
    $1055 = Math_fround($999 - $1051);
    $1056 = Math_fround($1000 - $1052);
    $1057 = Math_fround($1001 - $1053);
    $1058 = Math_fround($1002 - $1054);
    $1059 = Math_fround($851 + $1055);
    $1060 = Math_fround($852 + $1056);
    $1061 = Math_fround($853 + $1057);
    $1062 = Math_fround($854 + $1058);
    $1063 = (($currPtr$02276) + 144|0);
    $1064 = (($currPtr$02276) + 160|0);
    $1065 = (($currPtr$02276) + 176|0);
    $1066 = (($currPtr$02276) + 192|0);
    $1067 = Math_fround(HEAPF32[$erp>>2]);
    $1068 = HEAP32[$563>>2]|0;
    $1069 = HEAP32[$564>>2]|0;
    $1070 = HEAP32[$529>>2]|0;
    $1071 = ($a6$02278>>>0)<($1070>>>0);
    if ($1071) {
     $1072 = HEAP16[$591>>1]|0;
     $1073 = $1072&65535;
     $1074 = $1073 & 4;
     $1075 = ($1074|0)!=(0);
     $1076 = $1073 & 3;
     $1077 = ($1076|0)==(3);
     $or$cond$i13 = $1075 | $1077;
     if ($or$cond$i13) {
      $1078 = Math_fround(HEAPF32[$1068>>2]);
      $1079 = Math_fround(HEAPF32[$576>>2]);
      $1080 = Math_fround($1078 * $1079);
      $1081 = (($1068) + 4|0);
      $1082 = Math_fround(HEAPF32[$1081>>2]);
      $1083 = (($576) + 4|0);
      $1084 = Math_fround(HEAPF32[$1083>>2]);
      $1085 = Math_fround($1082 * $1084);
      $1086 = Math_fround($1080 + $1085);
      $1087 = (($1068) + 8|0);
      $1088 = Math_fround(HEAPF32[$1087>>2]);
      $1089 = (($576) + 8|0);
      $1090 = Math_fround(HEAPF32[$1089>>2]);
      $1091 = Math_fround($1088 * $1090);
      $1092 = Math_fround($1086 + $1091);
      $1093 = (($1068) + 16|0);
      $1094 = Math_fround(HEAPF32[$1093>>2]);
      $1095 = Math_fround(HEAPF32[$647>>2]);
      $1096 = Math_fround($1094 * $1095);
      $1097 = (($1068) + 20|0);
      $1098 = Math_fround(HEAPF32[$1097>>2]);
      $1099 = (($576) + 20|0);
      $1100 = Math_fround(HEAPF32[$1099>>2]);
      $1101 = Math_fround($1098 * $1100);
      $1102 = Math_fround($1096 + $1101);
      $1103 = (($1068) + 24|0);
      $1104 = Math_fround(HEAPF32[$1103>>2]);
      $1105 = (($576) + 24|0);
      $1106 = Math_fround(HEAPF32[$1105>>2]);
      $1107 = Math_fround($1104 * $1106);
      $1108 = Math_fround($1102 + $1107);
      $1109 = Math_fround($1092 + $1108);
      $1110 = Math_fround(HEAPF32[$1069>>2]);
      $1111 = Math_fround(HEAPF32[$855>>2]);
      $1112 = Math_fround($1110 * $1111);
      $1113 = (($1069) + 4|0);
      $1114 = Math_fround(HEAPF32[$1113>>2]);
      $1115 = (($576) + 36|0);
      $1116 = Math_fround(HEAPF32[$1115>>2]);
      $1117 = Math_fround($1114 * $1116);
      $1118 = Math_fround($1112 + $1117);
      $1119 = (($1069) + 8|0);
      $1120 = Math_fround(HEAPF32[$1119>>2]);
      $1121 = (($576) + 40|0);
      $1122 = Math_fround(HEAPF32[$1121>>2]);
      $1123 = Math_fround($1120 * $1122);
      $1124 = Math_fround($1118 + $1123);
      $1125 = (($1069) + 16|0);
      $1126 = Math_fround(HEAPF32[$1125>>2]);
      $1127 = Math_fround(HEAPF32[$879>>2]);
      $1128 = Math_fround($1126 * $1127);
      $1129 = (($1069) + 20|0);
      $1130 = Math_fround(HEAPF32[$1129>>2]);
      $1131 = (($576) + 52|0);
      $1132 = Math_fround(HEAPF32[$1131>>2]);
      $1133 = Math_fround($1130 * $1132);
      $1134 = Math_fround($1128 + $1133);
      $1135 = (($1069) + 24|0);
      $1136 = Math_fround(HEAPF32[$1135>>2]);
      $1137 = (($576) + 56|0);
      $1138 = Math_fround(HEAPF32[$1137>>2]);
      $1139 = Math_fround($1136 * $1138);
      $1140 = Math_fround($1134 + $1139);
      $1141 = Math_fround($1124 + $1140);
      $1142 = Math_fround($1109 - $1141);
      $1143 = $1142;
     } else {
      $1143 = Math_fround(0.0);
     }
     __ZN5physx18setSolverConstantsERfS0_S0_S0_RKNS_14Px1DConstraintEfffff($1063,$1064,$1065,$1066,$576,$1143,$1059,$1067,$dt,$recipdt);
    } else {
     HEAPF32[$1063>>2] = Math_fround(0.0);
     HEAPF32[$1064>>2] = Math_fround(0.0);
     HEAPF32[$1065>>2] = Math_fround(0.0);
     HEAPF32[$1066>>2] = Math_fround(0.0);
    }
    $1144 = (($currPtr$02276) + 148|0);
    $1145 = (($currPtr$02276) + 164|0);
    $1146 = (($currPtr$02276) + 180|0);
    $1147 = (($currPtr$02276) + 196|0);
    $1148 = Math_fround(HEAPF32[$165>>2]);
    $1149 = HEAP32[$565>>2]|0;
    $1150 = HEAP32[$566>>2]|0;
    $1151 = HEAP32[$533>>2]|0;
    $1152 = ($a6$02278>>>0)<($1151>>>0);
    if ($1152) {
     $1153 = HEAP16[$600>>1]|0;
     $1154 = $1153&65535;
     $1155 = $1154 & 4;
     $1156 = ($1155|0)!=(0);
     $1157 = $1154 & 3;
     $1158 = ($1157|0)==(3);
     $or$cond$i9 = $1156 | $1158;
     if ($or$cond$i9) {
      $1159 = Math_fround(HEAPF32[$1149>>2]);
      $1160 = Math_fround(HEAPF32[$578>>2]);
      $1161 = Math_fround($1159 * $1160);
      $1162 = (($1149) + 4|0);
      $1163 = Math_fround(HEAPF32[$1162>>2]);
      $1164 = (($578) + 4|0);
      $1165 = Math_fround(HEAPF32[$1164>>2]);
      $1166 = Math_fround($1163 * $1165);
      $1167 = Math_fround($1161 + $1166);
      $1168 = (($1149) + 8|0);
      $1169 = Math_fround(HEAPF32[$1168>>2]);
      $1170 = (($578) + 8|0);
      $1171 = Math_fround(HEAPF32[$1170>>2]);
      $1172 = Math_fround($1169 * $1171);
      $1173 = Math_fround($1167 + $1172);
      $1174 = (($1149) + 16|0);
      $1175 = Math_fround(HEAPF32[$1174>>2]);
      $1176 = Math_fround(HEAPF32[$653>>2]);
      $1177 = Math_fround($1175 * $1176);
      $1178 = (($1149) + 20|0);
      $1179 = Math_fround(HEAPF32[$1178>>2]);
      $1180 = (($578) + 20|0);
      $1181 = Math_fround(HEAPF32[$1180>>2]);
      $1182 = Math_fround($1179 * $1181);
      $1183 = Math_fround($1177 + $1182);
      $1184 = (($1149) + 24|0);
      $1185 = Math_fround(HEAPF32[$1184>>2]);
      $1186 = (($578) + 24|0);
      $1187 = Math_fround(HEAPF32[$1186>>2]);
      $1188 = Math_fround($1185 * $1187);
      $1189 = Math_fround($1183 + $1188);
      $1190 = Math_fround($1173 + $1189);
      $1191 = Math_fround(HEAPF32[$1150>>2]);
      $1192 = Math_fround(HEAPF32[$861>>2]);
      $1193 = Math_fround($1191 * $1192);
      $1194 = (($1150) + 4|0);
      $1195 = Math_fround(HEAPF32[$1194>>2]);
      $1196 = (($578) + 36|0);
      $1197 = Math_fround(HEAPF32[$1196>>2]);
      $1198 = Math_fround($1195 * $1197);
      $1199 = Math_fround($1193 + $1198);
      $1200 = (($1150) + 8|0);
      $1201 = Math_fround(HEAPF32[$1200>>2]);
      $1202 = (($578) + 40|0);
      $1203 = Math_fround(HEAPF32[$1202>>2]);
      $1204 = Math_fround($1201 * $1203);
      $1205 = Math_fround($1199 + $1204);
      $1206 = (($1150) + 16|0);
      $1207 = Math_fround(HEAPF32[$1206>>2]);
      $1208 = Math_fround(HEAPF32[$885>>2]);
      $1209 = Math_fround($1207 * $1208);
      $1210 = (($1150) + 20|0);
      $1211 = Math_fround(HEAPF32[$1210>>2]);
      $1212 = (($578) + 52|0);
      $1213 = Math_fround(HEAPF32[$1212>>2]);
      $1214 = Math_fround($1211 * $1213);
      $1215 = Math_fround($1209 + $1214);
      $1216 = (($1150) + 24|0);
      $1217 = Math_fround(HEAPF32[$1216>>2]);
      $1218 = (($578) + 56|0);
      $1219 = Math_fround(HEAPF32[$1218>>2]);
      $1220 = Math_fround($1217 * $1219);
      $1221 = Math_fround($1215 + $1220);
      $1222 = Math_fround($1205 + $1221);
      $1223 = Math_fround($1190 - $1222);
      $1224 = $1223;
     } else {
      $1224 = Math_fround(0.0);
     }
     __ZN5physx18setSolverConstantsERfS0_S0_S0_RKNS_14Px1DConstraintEfffff($1144,$1145,$1146,$1147,$578,$1224,$1060,$1148,$dt,$recipdt);
    } else {
     HEAPF32[$1144>>2] = Math_fround(0.0);
     HEAPF32[$1145>>2] = Math_fround(0.0);
     HEAPF32[$1146>>2] = Math_fround(0.0);
     HEAPF32[$1147>>2] = Math_fround(0.0);
    }
    $1225 = (($currPtr$02276) + 152|0);
    $1226 = (($currPtr$02276) + 168|0);
    $1227 = (($currPtr$02276) + 184|0);
    $1228 = (($currPtr$02276) + 200|0);
    $1229 = Math_fround(HEAPF32[$172>>2]);
    $1230 = HEAP32[$567>>2]|0;
    $1231 = HEAP32[$568>>2]|0;
    $1232 = HEAP32[$537>>2]|0;
    $1233 = ($a6$02278>>>0)<($1232>>>0);
    if ($1233) {
     $1234 = HEAP16[$609>>1]|0;
     $1235 = $1234&65535;
     $1236 = $1235 & 4;
     $1237 = ($1236|0)!=(0);
     $1238 = $1235 & 3;
     $1239 = ($1238|0)==(3);
     $or$cond$i5 = $1237 | $1239;
     if ($or$cond$i5) {
      $1240 = Math_fround(HEAPF32[$1230>>2]);
      $1241 = Math_fround(HEAPF32[$580>>2]);
      $1242 = Math_fround($1240 * $1241);
      $1243 = (($1230) + 4|0);
      $1244 = Math_fround(HEAPF32[$1243>>2]);
      $1245 = (($580) + 4|0);
      $1246 = Math_fround(HEAPF32[$1245>>2]);
      $1247 = Math_fround($1244 * $1246);
      $1248 = Math_fround($1242 + $1247);
      $1249 = (($1230) + 8|0);
      $1250 = Math_fround(HEAPF32[$1249>>2]);
      $1251 = (($580) + 8|0);
      $1252 = Math_fround(HEAPF32[$1251>>2]);
      $1253 = Math_fround($1250 * $1252);
      $1254 = Math_fround($1248 + $1253);
      $1255 = (($1230) + 16|0);
      $1256 = Math_fround(HEAPF32[$1255>>2]);
      $1257 = Math_fround(HEAPF32[$659>>2]);
      $1258 = Math_fround($1256 * $1257);
      $1259 = (($1230) + 20|0);
      $1260 = Math_fround(HEAPF32[$1259>>2]);
      $1261 = (($580) + 20|0);
      $1262 = Math_fround(HEAPF32[$1261>>2]);
      $1263 = Math_fround($1260 * $1262);
      $1264 = Math_fround($1258 + $1263);
      $1265 = (($1230) + 24|0);
      $1266 = Math_fround(HEAPF32[$1265>>2]);
      $1267 = (($580) + 24|0);
      $1268 = Math_fround(HEAPF32[$1267>>2]);
      $1269 = Math_fround($1266 * $1268);
      $1270 = Math_fround($1264 + $1269);
      $1271 = Math_fround($1254 + $1270);
      $1272 = Math_fround(HEAPF32[$1231>>2]);
      $1273 = Math_fround(HEAPF32[$867>>2]);
      $1274 = Math_fround($1272 * $1273);
      $1275 = (($1231) + 4|0);
      $1276 = Math_fround(HEAPF32[$1275>>2]);
      $1277 = (($580) + 36|0);
      $1278 = Math_fround(HEAPF32[$1277>>2]);
      $1279 = Math_fround($1276 * $1278);
      $1280 = Math_fround($1274 + $1279);
      $1281 = (($1231) + 8|0);
      $1282 = Math_fround(HEAPF32[$1281>>2]);
      $1283 = (($580) + 40|0);
      $1284 = Math_fround(HEAPF32[$1283>>2]);
      $1285 = Math_fround($1282 * $1284);
      $1286 = Math_fround($1280 + $1285);
      $1287 = (($1231) + 16|0);
      $1288 = Math_fround(HEAPF32[$1287>>2]);
      $1289 = Math_fround(HEAPF32[$891>>2]);
      $1290 = Math_fround($1288 * $1289);
      $1291 = (($1231) + 20|0);
      $1292 = Math_fround(HEAPF32[$1291>>2]);
      $1293 = (($580) + 52|0);
      $1294 = Math_fround(HEAPF32[$1293>>2]);
      $1295 = Math_fround($1292 * $1294);
      $1296 = Math_fround($1290 + $1295);
      $1297 = (($1231) + 24|0);
      $1298 = Math_fround(HEAPF32[$1297>>2]);
      $1299 = (($580) + 56|0);
      $1300 = Math_fround(HEAPF32[$1299>>2]);
      $1301 = Math_fround($1298 * $1300);
      $1302 = Math_fround($1296 + $1301);
      $1303 = Math_fround($1286 + $1302);
      $1304 = Math_fround($1271 - $1303);
      $1305 = $1304;
     } else {
      $1305 = Math_fround(0.0);
     }
     __ZN5physx18setSolverConstantsERfS0_S0_S0_RKNS_14Px1DConstraintEfffff($1225,$1226,$1227,$1228,$580,$1305,$1061,$1229,$dt,$recipdt);
    } else {
     HEAPF32[$1225>>2] = Math_fround(0.0);
     HEAPF32[$1226>>2] = Math_fround(0.0);
     HEAPF32[$1227>>2] = Math_fround(0.0);
     HEAPF32[$1228>>2] = Math_fround(0.0);
    }
    $1306 = (($currPtr$02276) + 156|0);
    $1307 = (($currPtr$02276) + 172|0);
    $1308 = (($currPtr$02276) + 188|0);
    $1309 = (($currPtr$02276) + 204|0);
    $1310 = Math_fround(HEAPF32[$179>>2]);
    $1311 = HEAP32[$569>>2]|0;
    $1312 = HEAP32[$570>>2]|0;
    $1313 = HEAP32[$541>>2]|0;
    $1314 = ($a6$02278>>>0)<($1313>>>0);
    if ($1314) {
     $1315 = HEAP16[$618>>1]|0;
     $1316 = $1315&65535;
     $1317 = $1316 & 4;
     $1318 = ($1317|0)!=(0);
     $1319 = $1316 & 3;
     $1320 = ($1319|0)==(3);
     $or$cond$i = $1318 | $1320;
     if ($or$cond$i) {
      $1321 = Math_fround(HEAPF32[$1311>>2]);
      $1322 = Math_fround(HEAPF32[$582>>2]);
      $1323 = Math_fround($1321 * $1322);
      $1324 = (($1311) + 4|0);
      $1325 = Math_fround(HEAPF32[$1324>>2]);
      $1326 = (($582) + 4|0);
      $1327 = Math_fround(HEAPF32[$1326>>2]);
      $1328 = Math_fround($1325 * $1327);
      $1329 = Math_fround($1323 + $1328);
      $1330 = (($1311) + 8|0);
      $1331 = Math_fround(HEAPF32[$1330>>2]);
      $1332 = (($582) + 8|0);
      $1333 = Math_fround(HEAPF32[$1332>>2]);
      $1334 = Math_fround($1331 * $1333);
      $1335 = Math_fround($1329 + $1334);
      $1336 = (($1311) + 16|0);
      $1337 = Math_fround(HEAPF32[$1336>>2]);
      $1338 = Math_fround(HEAPF32[$665>>2]);
      $1339 = Math_fround($1337 * $1338);
      $1340 = (($1311) + 20|0);
      $1341 = Math_fround(HEAPF32[$1340>>2]);
      $1342 = (($582) + 20|0);
      $1343 = Math_fround(HEAPF32[$1342>>2]);
      $1344 = Math_fround($1341 * $1343);
      $1345 = Math_fround($1339 + $1344);
      $1346 = (($1311) + 24|0);
      $1347 = Math_fround(HEAPF32[$1346>>2]);
      $1348 = (($582) + 24|0);
      $1349 = Math_fround(HEAPF32[$1348>>2]);
      $1350 = Math_fround($1347 * $1349);
      $1351 = Math_fround($1345 + $1350);
      $1352 = Math_fround($1335 + $1351);
      $1353 = Math_fround(HEAPF32[$1312>>2]);
      $1354 = Math_fround(HEAPF32[$873>>2]);
      $1355 = Math_fround($1353 * $1354);
      $1356 = (($1312) + 4|0);
      $1357 = Math_fround(HEAPF32[$1356>>2]);
      $1358 = (($582) + 36|0);
      $1359 = Math_fround(HEAPF32[$1358>>2]);
      $1360 = Math_fround($1357 * $1359);
      $1361 = Math_fround($1355 + $1360);
      $1362 = (($1312) + 8|0);
      $1363 = Math_fround(HEAPF32[$1362>>2]);
      $1364 = (($582) + 40|0);
      $1365 = Math_fround(HEAPF32[$1364>>2]);
      $1366 = Math_fround($1363 * $1365);
      $1367 = Math_fround($1361 + $1366);
      $1368 = (($1312) + 16|0);
      $1369 = Math_fround(HEAPF32[$1368>>2]);
      $1370 = Math_fround(HEAPF32[$897>>2]);
      $1371 = Math_fround($1369 * $1370);
      $1372 = (($1312) + 20|0);
      $1373 = Math_fround(HEAPF32[$1372>>2]);
      $1374 = (($582) + 52|0);
      $1375 = Math_fround(HEAPF32[$1374>>2]);
      $1376 = Math_fround($1373 * $1375);
      $1377 = Math_fround($1371 + $1376);
      $1378 = (($1312) + 24|0);
      $1379 = Math_fround(HEAPF32[$1378>>2]);
      $1380 = (($582) + 56|0);
      $1381 = Math_fround(HEAPF32[$1380>>2]);
      $1382 = Math_fround($1379 * $1381);
      $1383 = Math_fround($1377 + $1382);
      $1384 = Math_fround($1367 + $1383);
      $1385 = Math_fround($1352 - $1384);
      $1386 = $1385;
     } else {
      $1386 = Math_fround(0.0);
     }
     __ZN5physx18setSolverConstantsERfS0_S0_S0_RKNS_14Px1DConstraintEfffff($1306,$1307,$1308,$1309,$582,$1386,$1062,$1310,$dt,$recipdt);
    } else {
     HEAPF32[$1306>>2] = Math_fround(0.0);
     HEAPF32[$1307>>2] = Math_fround(0.0);
     HEAPF32[$1308>>2] = Math_fround(0.0);
     HEAPF32[$1309>>2] = Math_fround(0.0);
    }
    $1387 = HEAP16[$591>>1]|0;
    $1388 = $1387 & 16;
    $1389 = ($1388<<16>>16)==(0);
    if (!($1389)) {
     $1390 = HEAP32[$687>>2]|0;
     $1391 = $1390 | 2;
     HEAP32[$687>>2] = $1391;
    }
    $1392 = HEAP16[$600>>1]|0;
    $1393 = $1392 & 16;
    $1394 = ($1393<<16>>16)==(0);
    if (!($1394)) {
     $1395 = HEAP32[$688>>2]|0;
     $1396 = $1395 | 2;
     HEAP32[$688>>2] = $1396;
    }
    $1397 = HEAP16[$609>>1]|0;
    $1398 = $1397 & 16;
    $1399 = ($1398<<16>>16)==(0);
    if (!($1399)) {
     $1400 = HEAP32[$689>>2]|0;
     $1401 = $1400 | 2;
     HEAP32[$689>>2] = $1401;
    }
    $1402 = HEAP16[$618>>1]|0;
    $1403 = $1402 & 16;
    $1404 = ($1403<<16>>16)==(0);
    if (!($1404)) {
     $1405 = HEAP32[$690>>2]|0;
     $1406 = $1405 | 2;
     HEAP32[$690>>2] = $1406;
    }
    $1407 = (($a6$02278) + 1)|0;
    $1408 = ($1407>>>0)<($39>>>0);
    if ($1408) {
     $a6$02278 = $1407;$currPtr$02276 = $574;$index0$02274 = $584;$index1$02273 = $586;$index2$02275 = $588;$index3$02277 = $590;
    } else {
     break;
    }
   }
   $$sum2297 = (($573) + 128)|0;
   $scevgep2294 = (($$0$i) + ($$sum2297)|0);
   $currPtr$0$lcssa = $scevgep2294;
  }
  HEAP32[$currPtr$0$lcssa>>2] = 0;
  $1409 = (($currPtr$0$lcssa) + 4|0);
  HEAP32[$1409>>2] = 0;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 56) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx17PxsContactManagerC2EPNS_10PxsContextEj($this,$0,$index) {
 $this = $this|0;
 $0 = $0|0;
 $index = $index|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 60|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 76|0);
 HEAP32[$4>>2] = $index;
 $5 = (($this) + 80|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 84|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 108|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 100|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 104|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 56|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 52|0);
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx17PxsContactManagerD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx17PxsContactManager4initERKNS_24PxvManagerDescRigidRigidEPKNS_18PxsMaterialManagerE($this,$desc,$materialManager) {
 $this = $this|0;
 $desc = $desc|0;
 $materialManager = $materialManager|0;
 var $$ = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $wuflags$1 = 0, $wuflags$2 = 0, $wuflags$3 = 0, $wuflags$4 = 0, $wuflags$5 = 0, $wuflags$6 = 0, $wuflags$7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($desc) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$this>>2] = $1;
 $2 = (($desc) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($desc) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 88|0);
 HEAP32[$7>>2] = $6;
 $8 = (($desc) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 92|0);
 HEAP32[$10>>2] = $9;
 $11 = (($desc) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 80|0);
 HEAP32[$13>>2] = $12;
 $14 = (($desc) + 32|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 84|0);
 HEAP32[$16>>2] = $15;
 $17 = (($desc) + 48|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 108|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($desc) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 100|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($desc) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($this) + 104|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($6) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27&255;
 $29 = (($this) + 112|0);
 HEAP8[$29>>0] = $28;
 $30 = (($9) + 36|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31&255;
 $33 = (($this) + 113|0);
 HEAP8[$33>>0] = $32;
 $34 = (($this) + 96|0);
 HEAP32[$34>>2] = $materialManager;
 $35 = (($desc) + 72|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 116|0);
 HEAP32[$37>>2] = $36;
 $38 = (($desc) + 76|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($this) + 120|0);
 HEAP32[$40>>2] = $39;
 $41 = (($this) + 114|0);
 HEAP16[$41>>1] = 0;
 $42 = (($this) + 36|0);
 $43 = (($this) + 40|0);
 $44 = (($this) + 16|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 32|0);
 HEAP16[$45>>1] = 0;
 $46 = (($this) + 20|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 44|0);
 $48 = (($this) + 48|0);
 HEAP16[$42>>1] = 0;
 $49 = (($this) + 64|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 72|0);
 HEAP16[$50>>1] = 0;
 $51 = (($this) + 68|0);
 HEAP32[$51>>2] = 0;
 $52 = (($this) + 60|0);
 ;HEAP32[$43+0>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;HEAP32[$43+16>>2]=0|0;
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0);
 do {
  if ($54) {
   $68 = 0;
  } else {
   $55 = $53 & 1;
   $56 = ($55|0)==(0);
   if ($56) {
    $57 = $53;
    $58 = (($57) + 33|0);
    HEAP8[$58>>0] = 0;
    $59 = (($57) + 32|0);
    HEAP8[$59>>0] = 0;
    $60 = (($57) + 16|0);
    HEAPF32[$60>>2] = Math_fround(3.40282346638528859812E+38);
    $61 = (($57) + 20|0);
    HEAPF32[$61>>2] = Math_fround(3.40282346638528859812E+38);
    $62 = (($57) + 24|0);
    HEAPF32[$62>>2] = Math_fround(3.40282346638528859812E+38);
    $63 = (($57) + 28|0);
    HEAPF32[$63>>2] = Math_fround(0.0);
    HEAPF32[$57>>2] = Math_fround(0.0);
    $64 = (($57) + 4|0);
    HEAPF32[$64>>2] = Math_fround(0.0);
    $65 = (($57) + 8|0);
    HEAPF32[$65>>2] = Math_fround(0.0);
    $66 = (($57) + 12|0);
    HEAPF32[$66>>2] = Math_fround(1.0);
    $$pre = HEAP16[$41>>1]|0;
    $68 = $$pre;
    break;
   } else {
    HEAP32[$52>>2] = 1;
    $68 = 0;
    break;
   }
  }
 } while(0);
 $67 = $68&65535;
 $69 = $67 & 65531;
 $70 = $69&65535;
 HEAP16[$41>>1] = $70;
 $71 = (($desc) + 60|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $72 & 1;
 $74 = ($73|0)==(0);
 $$ = $74 ? 0 : 8;
 $75 = $72 & 2;
 $76 = ($75|0)==(0);
 if ($76) {
  $wuflags$1 = $$;
 } else {
  $77 = $$&65535;
  $78 = $77 | 16;
  $79 = $78&65535;
  $wuflags$1 = $79;
 }
 $80 = (($desc) + 64|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = $81 & 1;
 $83 = ($82|0)==(0);
 if ($83) {
  $wuflags$2 = $wuflags$1;
 } else {
  $84 = $wuflags$1&65535;
  $85 = $84 | 32;
  $86 = $85&65535;
  $wuflags$2 = $86;
 }
 $87 = $81 & 2;
 $88 = ($87|0)==(0);
 if ($88) {
  $wuflags$3 = $wuflags$2;
 } else {
  $89 = $wuflags$2&65535;
  $90 = $89 | 64;
  $91 = $90&65535;
  $wuflags$3 = $91;
 }
 $92 = (($desc) + 52|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==(0);
 if ($94) {
  $95 = (($desc) + 44|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ($96|0)==(0);
  if ($97) {
   $98 = $wuflags$3&65535;
   $99 = $98 | 2;
   $100 = $99&65535;
   $wuflags$4 = $100;
  } else {
   $wuflags$4 = $wuflags$3;
  }
 } else {
  $wuflags$4 = $wuflags$3;
 }
 $101 = ($93|0)!=(0);
 $102 = (($this) + 34|0);
 $103 = $101&1;
 HEAP8[$102>>0] = $103;
 $104 = (($desc) + 56|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = ($105|0)!=(0);
 $107 = (($this) + 35|0);
 $108 = $106&1;
 HEAP8[$107>>0] = $108;
 $109 = (($desc) + 36|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = ($110|0)==(0);
 if ($111) {
  $112 = (($desc) + 44|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ($113|0)==(0);
  if ($114) {
   $wuflags$5 = $wuflags$4;
  } else {
   label = 16;
  }
 } else {
  label = 16;
 }
 if ((label|0) == 16) {
  $115 = $wuflags$4&65535;
  $116 = $115 | 1;
  $117 = $116&65535;
  $wuflags$5 = $117;
 }
 $118 = (($desc) + 40|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = ($119|0)==(0);
 if ($120) {
  $wuflags$6 = $wuflags$5;
 } else {
  $121 = $wuflags$5&65535;
  $122 = $121 | 256;
  $123 = $122&65535;
  $wuflags$6 = $123;
 }
 $124 = (($desc) + 44|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $wuflags$7 = $wuflags$6;
 } else {
  $127 = $wuflags$6&65535;
  $128 = $127 | 128;
  $129 = $128&65535;
  $wuflags$7 = $129;
 }
 $130 = (($this) + 38|0);
 HEAP16[$130>>1] = $wuflags$7;
 $131 = ($125|0)!=(0);
 $132 = $131&1;
 $133 = (($this) + 8|0);
 HEAP32[$133>>2] = $132;
 $134 = HEAP32[$desc>>2]|0;
 $135 = (($this) + 12|0);
 HEAP32[$135>>2] = $134;
 HEAP16[$41>>1] = 0;
 HEAP16[$42>>1] = 0;
 HEAP32[$43>>2] = 0;
 HEAP32[$44>>2] = 0;
 HEAP16[$45>>1] = 0;
 HEAP32[$46>>2] = 0;
 HEAP32[$47>>2] = 0;
 HEAP32[$48>>2] = 0;
 $136 = (($desc) + 68|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($137|0)>(0);
 if ($138) {
  HEAP16[$41>>1] = 2;
  STACKTOP = sp;return;
 }
 $139 = ($137|0)<(0);
 if (!($139)) {
  STACKTOP = sp;return;
 }
 HEAP16[$41>>1] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx17PxsContactManager6setCCDEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $flags$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -7;
 $3 = $2 | 2;
 $flags$0 = $enable ? $3 : $2;
 HEAP32[$0>>2] = $flags$0;
 STACKTOP = sp;return;
}
function __ZN5physx17PxsContactManager16resetCachedStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 HEAP16[$0>>1] = 0;
 $1 = (($this) + 40|0);
 $2 = (($this) + 64|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 72|0);
 HEAP16[$3>>1] = 0;
 $4 = (($this) + 68|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 60|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 do {
  if (!($7)) {
   $8 = $6 & 1;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = $6;
    $11 = (($10) + 33|0);
    HEAP8[$11>>0] = 0;
    $12 = (($10) + 32|0);
    HEAP8[$12>>0] = 0;
    $13 = (($10) + 16|0);
    HEAPF32[$13>>2] = Math_fround(3.40282346638528859812E+38);
    $14 = (($10) + 20|0);
    HEAPF32[$14>>2] = Math_fround(3.40282346638528859812E+38);
    $15 = (($10) + 24|0);
    HEAPF32[$15>>2] = Math_fround(3.40282346638528859812E+38);
    $16 = (($10) + 28|0);
    HEAPF32[$16>>2] = Math_fround(0.0);
    HEAPF32[$10>>2] = Math_fround(0.0);
    $17 = (($10) + 4|0);
    HEAPF32[$17>>2] = Math_fround(0.0);
    $18 = (($10) + 8|0);
    HEAPF32[$18>>2] = Math_fround(0.0);
    $19 = (($10) + 12|0);
    HEAPF32[$19>>2] = Math_fround(1.0);
    break;
   } else {
    HEAP32[$5>>2] = 1;
    break;
   }
  }
 } while(0);
 $20 = (($this) + 114|0);
 $21 = HEAP16[$20>>1]|0;
 $22 = $21&65535;
 $23 = $22 & 65531;
 $24 = $23&65535;
 HEAP16[$20>>1] = $24;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContextC2ERKNS_11PxSceneDescEPNS_13PxTaskManagerEPNS_2Cm9FlushPoolERNS6_13EventProfilerEj($this,$desc,$taskManager,$taskPool,$profiler,$bodySimRigidBodyOffset) {
 $this = $this|0;
 $desc = $desc|0;
 $taskManager = $taskManager|0;
 $taskPool = $taskPool|0;
 $profiler = $profiler|0;
 $bodySimRigidBodyOffset = $bodySimRigidBodyOffset|0;
 var $$$i$i$i = 0, $$$i$i$i$i = 0, $$$i$i$i$i$i$i = 0, $$$i$i$i$i1 = 0, $$$i$i$i$i17 = 0, $$$i$i$i$i2 = 0, $$$i$i$i$i8 = 0, $$$i$i$i$i9 = 0, $$0$i = 0, $$lobit = 0, $$pre$i$i = 0, $$pre$i$i11 = 0, $$pre$i$i20 = 0, $$pre$i$i4 = 0, $$pre1$i$i = 0, $$tr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $storemerge$i$i = 0, $storemerge$i$i13 = 0, $storemerge$i$i6 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN5physx19PxsSimObjectFactoryC2Ev($this);
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 20|0);
 __ZN5physx19PxcScratchAllocatorC2Ev($2);
 $3 = (($this) + 44|0);
 __ZN5physx17PxcNpMemBlockPoolC2ERNS_19PxcScratchAllocatorE($3,$2);
 $4 = (($this) + 224|0);
 $5 = (__ZN5physx6shdfnd9SListImpl7getSizeEv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  HEAP32[$4>>2] = 0;
 } else {
  $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__Z15PxGetFoundationv()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 24|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
  $$$i$i$i$i$i$i = $16 ? 490600 : 489216;
  $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i$i$i$i,490520,93)|0);
  HEAP32[$4>>2] = $17;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   __ZN5physx6shdfnd9SListImplC2Ev($17);
  }
 }
 $19 = (($this) + 232|0);
 HEAP32[$19>>2] = 16;
 $20 = (($this) + 236|0);
 HEAP32[$20>>2] = 1024;
 $21 = (($this) + 240|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 248|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 252|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 256|0);
 $25 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (__Z15PxGetFoundationv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
 $$$i$i$i$i1 = $33 ? 490200 : 489216;
 $34 = (FUNCTION_TABLE_iiiiii[$28 & 255]($25,4096,$$$i$i$i$i1,489376,63)|0);
 $$pre$i$i = HEAP32[$20>>2]|0;
 HEAP32[$24>>2] = $34;
 $35 = (($this) + 260|0);
 HEAP32[$35>>2] = $this;
 $36 = (($this) + 264|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 268|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 244|0);
 HEAP32[$38>>2] = 0;
 $39 = ($$pre$i$i>>>0)>(1);
 if ($39) {
  $40 = HEAP32[$19>>2]|0;
  $storemerge$i$i = 0;
  while(1) {
   $41 = 1 << $storemerge$i$i;
   $42 = ($40|0)==($41|0);
   $43 = (($storemerge$i$i) + 1)|0;
   if ($42) {
    break;
   } else {
    $storemerge$i$i = $43;
   }
  }
  HEAP32[$38>>2] = $storemerge$i$i;
 }
 $44 = (($this) + 276|0);
 HEAP32[$44>>2] = 256;
 $45 = (($this) + 280|0);
 HEAP32[$45>>2] = 1024;
 $46 = (($this) + 284|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 292|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 296|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 300|0);
 $50 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (__Z15PxGetFoundationv()|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 24|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (FUNCTION_TABLE_ii[$57 & 4095]($54)|0);
 $$$i$i$i$i2 = $58 ? 489464 : 489216;
 $59 = (FUNCTION_TABLE_iiiiii[$53 & 255]($50,4096,$$$i$i$i$i2,489376,63)|0);
 $$pre$i$i4 = HEAP32[$45>>2]|0;
 HEAP32[$49>>2] = $59;
 $60 = (($this) + 304|0);
 HEAP32[$60>>2] = $this;
 $61 = (($this) + 308|0);
 HEAP32[$61>>2] = 0;
 $62 = (($this) + 312|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 288|0);
 HEAP32[$63>>2] = 0;
 $64 = ($$pre$i$i4>>>0)>(1);
 if ($64) {
  $65 = HEAP32[$44>>2]|0;
  $storemerge$i$i6 = 0;
  while(1) {
   $66 = 1 << $storemerge$i$i6;
   $67 = ($65|0)==($66|0);
   $68 = (($storemerge$i$i6) + 1)|0;
   if ($67) {
    break;
   } else {
    $storemerge$i$i6 = $68;
   }
  }
  HEAP32[$63>>2] = $storemerge$i$i6;
 }
 $69 = (($this) + 320|0);
 $70 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0);
 if ($72) {
  HEAP32[$69>>2] = 0;
 } else {
  $73 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + 8|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (__Z15PxGetFoundationv()|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($78) + 24|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (FUNCTION_TABLE_ii[$80 & 4095]($77)|0);
  $$$i$i$i$i8 = $81 ? 491128 : 489216;
  $82 = (FUNCTION_TABLE_iiiiii[$76 & 255]($73,$71,$$$i$i$i$i8,491048,111)|0);
  HEAP32[$69>>2] = $82;
  $83 = ($82|0)==(0|0);
  if (!($83)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($82);
  }
 }
 $84 = (($this) + 324|0);
 __ZN5physx24PxsParticleSystemBatcherC2ERNS_10PxsContextE($84,$this);
 $85 = (($this) + 696|0);
 HEAP32[$85>>2] = 256;
 $86 = (($this) + 700|0);
 HEAP32[$86>>2] = 4096;
 $87 = (($this) + 704|0);
 HEAP32[$87>>2] = 0;
 $88 = (($this) + 712|0);
 HEAP32[$88>>2] = 0;
 $89 = (($this) + 716|0);
 HEAP32[$89>>2] = 0;
 $90 = (($this) + 720|0);
 $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + 8|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (__Z15PxGetFoundationv()|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (($96) + 24|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
 $$$i$i$i$i9 = $99 ? 490072 : 489216;
 $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,16384,$$$i$i$i$i9,489376,63)|0);
 $$pre$i$i11 = HEAP32[$86>>2]|0;
 HEAP32[$90>>2] = $100;
 $101 = (($this) + 724|0);
 HEAP32[$101>>2] = $this;
 $102 = (($this) + 728|0);
 HEAP32[$102>>2] = 0;
 $103 = (($this) + 732|0);
 HEAP32[$103>>2] = 0;
 $104 = (($this) + 708|0);
 HEAP32[$104>>2] = 0;
 $105 = ($$pre$i$i11>>>0)>(1);
 if ($105) {
  $106 = HEAP32[$85>>2]|0;
  $storemerge$i$i13 = 0;
  while(1) {
   $107 = 1 << $storemerge$i$i13;
   $108 = ($106|0)==($107|0);
   $109 = (($storemerge$i$i13) + 1)|0;
   if ($108) {
    break;
   } else {
    $storemerge$i$i13 = $109;
   }
  }
  HEAP32[$104>>2] = $storemerge$i$i13;
 }
 $110 = (($this) + 744|0);
 $111 = (($this) + 1000|0);
 $112 = (($this) + 1004|0);
 $113 = (($this) + 1008|0);
 HEAP32[$113>>2] = 0;
 $114 = (($this) + 1012|0);
 HEAP8[$111>>0] = 1;
 HEAP32[$112>>2] = $110;
 HEAP32[$114>>2] = 64;
 $115 = (($this) + 1016|0);
 HEAP32[$115>>2] = 32;
 $116 = (($this) + 1020|0);
 HEAP32[$116>>2] = 0;
 $117 = (($this) + 1024|0);
 HEAP32[$117>>2] = 0;
 $118 = (($this) + 1028|0);
 HEAP32[$118>>2] = 7680;
 $119 = (($this) + 1032|0);
 HEAP32[$119>>2] = 0;
 $120 = (($this) + 1040|0);
 $121 = (($this) + 1296|0);
 $122 = (($this) + 1300|0);
 $123 = (($this) + 1304|0);
 HEAP32[$123>>2] = 0;
 $124 = (($this) + 1308|0);
 HEAP8[$121>>0] = 1;
 HEAP32[$122>>2] = $120;
 HEAP32[$124>>2] = 64;
 $125 = (($this) + 1312|0);
 HEAP32[$125>>2] = 32;
 $126 = (($this) + 1316|0);
 HEAP32[$126>>2] = 0;
 $127 = (($this) + 1320|0);
 HEAP32[$127>>2] = 0;
 $128 = (($this) + 1324|0);
 HEAP32[$128>>2] = 3072;
 $129 = (($this) + 1328|0);
 HEAP32[$129>>2] = 0;
 $130 = (($this) + 1332|0);
 HEAP32[$130>>2] = 0;
 $131 = (($this) + 1336|0);
 HEAP32[$131>>2] = 0;
 $132 = (($this) + 1344|0);
 HEAP32[$132>>2] = 0;
 $133 = (($this) + 1348|0);
 HEAP32[$133>>2] = 0;
 $134 = (($this) + 1368|0);
 $135 = (($this) + 1440|0);
 dest=$134+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $136 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($137|0)==(0);
 if ($138) {
  HEAP32[$135>>2] = 0;
 } else {
  $139 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = (($140) + 8|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = (__Z15PxGetFoundationv()|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = (($144) + 24|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = (FUNCTION_TABLE_ii[$146 & 4095]($143)|0);
  $$$i$i$i$i17 = $147 ? 491128 : 489216;
  $148 = (FUNCTION_TABLE_iiiiii[$142 & 255]($139,$137,$$$i$i$i$i17,491048,111)|0);
  HEAP32[$135>>2] = $148;
  $149 = ($148|0)==(0|0);
  if (!($149)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($148);
  }
 }
 $150 = (($this) + 1444|0);
 HEAP8[$150>>0] = 0;
 $151 = (($this) + 1448|0);
 __ZN5physx21PxsBodyTransformVaultC2Ev($151);
 $152 = (($this) + 5844|0);
 HEAP32[$152>>2] = 0;
 $153 = (($this) + 5848|0);
 HEAP32[$153>>2] = 0;
 $154 = (($this) + 5856|0);
 $155 = (($this) + 5928|0);
 dest=$154+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$155>>2] = ((407136 + 8|0));
 $156 = (($this) + 5932|0);
 dest=$156+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $157 = (($this) + 6164|0);
 HEAPF32[$157>>2] = Math_fround(0.0);
 $158 = (($this) + 6168|0);
 HEAPF32[$158>>2] = Math_fround(0.0);
 $159 = (($this) + 6172|0);
 HEAPF32[$159>>2] = Math_fround(0.0);
 $160 = (($this) + 6176|0);
 __ZN5physx16PxsIslandManagerC2EjRNS_19PxcScratchAllocatorEPNS_2Cm13EventProfilerE($160,$bodySimRigidBodyOffset,$2,$profiler);
 $161 = (($this) + 6672|0);
 $162 = (($this) + 6676|0);
 HEAP16[$162>>1] = -1;
 $163 = (($this) + 6678|0);
 HEAP16[$163>>1] = 0;
 $164 = (($this) + 6680|0);
 HEAP32[$164>>2] = 0;
 HEAP32[$161>>2] = ((434896 + 8|0));
 $165 = (($this) + 6684|0);
 HEAP32[$165>>2] = 0;
 $166 = (($this) + 6688|0);
 HEAP32[$166>>2] = 0;
 HEAP32[$161>>2] = ((490776 + 8|0));
 $167 = (($this) + 6692|0);
 HEAP32[$167>>2] = $this;
 $168 = (($this) + 6696|0);
 HEAP32[$168>>2] = 488880;
 $169 = (($this) + 6700|0);
 $170 = (($this) + 6704|0);
 HEAP16[$170>>1] = -1;
 $171 = (($this) + 6706|0);
 HEAP16[$171>>1] = 0;
 $172 = (($this) + 6708|0);
 HEAP32[$172>>2] = 0;
 HEAP32[$169>>2] = ((434896 + 8|0));
 $173 = (($this) + 6712|0);
 HEAP32[$173>>2] = 0;
 $174 = (($this) + 6716|0);
 HEAP32[$174>>2] = 0;
 HEAP32[$169>>2] = ((490728 + 8|0));
 $175 = (($this) + 6720|0);
 HEAP32[$175>>2] = $this;
 $176 = (($this) + 6724|0);
 HEAP32[$176>>2] = 488928;
 $177 = (($this) + 6728|0);
 HEAP32[$177>>2] = $taskManager;
 $178 = (($this) + 6732|0);
 HEAP32[$178>>2] = $taskPool;
 $179 = (($this) + 6736|0);
 HEAP32[$179>>2] = $profiler;
 $180 = (($this) + 6752|0);
 $181 = (($this) + 7376|0);
 $182 = (($desc) + 100|0);
 _memset(($180|0),0,624)|0;
 $183 = HEAP16[$182>>1]|0;
 $184 = ($183&65535) >>> 9;
 $$tr = $184&255;
 $185 = $$tr & 1;
 HEAP8[$181>>0] = $185;
 $186 = (($this) + 7377|0);
 HEAP8[$186>>0] = 0;
 $187 = (($this) + 7378|0);
 $$lobit = ($183&65535) >>> 15;
 $188 = $$lobit&255;
 HEAP8[$187>>0] = $188;
 $189 = (($this) + 7380|0);
 $190 = (($this) + 7404|0);
 $191 = (($this) + 7412|0);
 $192 = (($this) + 7416|0);
 $193 = (($this) + 7420|0);
 $194 = (($this) + 7400|0);
 dest=$189+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx6shdfnd5ArrayINS_11PxTransformENS0_19ReflectionAllocatorIS2_EEE8recreateEj($194,512);
 $$pre$i$i20 = HEAP32[$193>>2]|0;
 $195 = $$pre$i$i20 & 2147483136;
 $196 = ($195>>>0)<(512);
 if ($196) {
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($191,512);
  $$pre1$i$i = HEAP32[$193>>2]|0;
  $199 = $$pre1$i$i;
 } else {
  $199 = $$pre$i$i20;
 }
 HEAP32[$192>>2] = 512;
 $197 = HEAP32[$191>>2]|0;
 $198 = $199 << 2;
 _memset(($197|0),0,($198|0))|0;
 HEAP32[$190>>2] = 512;
 $200 = HEAP32[$133>>2]|0;
 $201 = HEAP32[$132>>2]|0;
 $202 = $200 << 2;
 _memset(($201|0),0,($202|0))|0;
 $203 = (($this) + 1356|0);
 HEAP32[$203>>2] = 0;
 $204 = (($this) + 1360|0);
 HEAP32[$204>>2] = 0;
 $205 = (($this) + 1364|0);
 HEAP32[$205>>2] = 0;
 $206 = (($this) + 6140|0);
 HEAPF32[$206>>2] = Math_fround(-8.50705866596322149529E+37);
 $207 = (($this) + 6144|0);
 HEAPF32[$207>>2] = Math_fround(-8.50705866596322149529E+37);
 $208 = (($this) + 6148|0);
 HEAPF32[$208>>2] = Math_fround(-8.50705866596322149529E+37);
 $209 = (($this) + 6152|0);
 HEAPF32[$209>>2] = Math_fround(8.50705866596322149529E+37);
 $210 = (($this) + 6156|0);
 HEAPF32[$210>>2] = Math_fround(8.50705866596322149529E+37);
 $211 = (($this) + 6160|0);
 HEAPF32[$211>>2] = Math_fround(8.50705866596322149529E+37);
 $212 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $213 = HEAP32[$212>>2]|0;
 $214 = (($213) + 8|0);
 $215 = HEAP32[$214>>2]|0;
 $216 = (__Z15PxGetFoundationv()|0);
 $217 = HEAP32[$216>>2]|0;
 $218 = (($217) + 24|0);
 $219 = HEAP32[$218>>2]|0;
 $220 = (FUNCTION_TABLE_ii[$219 & 4095]($216)|0);
 $$$i$i$i = $220 ? 490400 : 489216;
 $221 = (FUNCTION_TABLE_iiiiii[$215 & 255]($212,51632,$$$i$i$i,488976,139)|0);
 __ZN5physx14PxsAABBManagerC2ERNS_2Cm13EventProfilerERNS_19PxcScratchAllocatorE($221,$profiler,$2);
 HEAP32[$0>>2] = $221;
 $222 = HEAP32[$179>>2]|0;
 $223 = (($desc) + 40|0);
 $224 = HEAP32[$223>>2]|0;
 $225 = ($224|0)==(1);
 if ($225) {
  $226 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $227 = HEAP32[$226>>2]|0;
  $228 = (($227) + 8|0);
  $229 = HEAP32[$228>>2]|0;
  $230 = (__Z15PxGetFoundationv()|0);
  $231 = HEAP32[$230>>2]|0;
  $232 = (($231) + 24|0);
  $233 = HEAP32[$232>>2]|0;
  $234 = (FUNCTION_TABLE_ii[$233 & 4095]($230)|0);
  $$$i$i$i$i = $234 ? 491432 : 489216;
  $235 = (FUNCTION_TABLE_iiiiii[$229 & 255]($226,124,$$$i$i$i$i,488976,88)|0);
  __ZN5physx16PxsBroadPhaseMBPC2ERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerERKNS_11PxSceneDescEPNS_14PxsAABBManagerE($235,$2,$222,$desc,$221);
  $$0$i = $235;
  $237 = HEAP32[$0>>2]|0;
  __ZN5physx14PxsAABBManager4initEPNS_13PxvBroadPhaseE($237,$$0$i);
  $238 = (__ZN5physx18PxsDynamicsContext6createEPNS_10PxsContextE($this)|0);
  HEAP32[$1>>2] = $238;
  $239 = (__ZN5physx13PxsCCDContext6createEPNS_10PxsContextE($this)|0);
  $240 = (($this) + 16|0);
  HEAP32[$240>>2] = $239;
  $241 = (($this) + 5992|0);
  _memset(($241|0),0,148)|0;
  $242 = (($desc) + 136|0);
  $243 = HEAP32[$242>>2]|0;
  $244 = (($desc) + 140|0);
  $245 = HEAP32[$244>>2]|0;
  __ZN5physx17PxcNpMemBlockPool4initEjj($3,$243,$245);
  STACKTOP = sp;return;
 } else {
  $236 = (__ZN5physx23PxsBroadPhaseContextSap6createERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerE($2,$222)|0);
  $$0$i = $236;
  $237 = HEAP32[$0>>2]|0;
  __ZN5physx14PxsAABBManager4initEPNS_13PxvBroadPhaseE($237,$$0$i);
  $238 = (__ZN5physx18PxsDynamicsContext6createEPNS_10PxsContextE($this)|0);
  HEAP32[$1>>2] = $238;
  $239 = (__ZN5physx13PxsCCDContext6createEPNS_10PxsContextE($this)|0);
  $240 = (($this) + 16|0);
  HEAP32[$240>>2] = $239;
  $241 = (($this) + 5992|0);
  _memset(($241|0),0,148)|0;
  $242 = (($desc) + 136|0);
  $243 = HEAP32[$242>>2]|0;
  $244 = (($desc) + 140|0);
  $245 = HEAP32[$244>>2]|0;
  __ZN5physx17PxcNpMemBlockPool4initEjj($3,$243,$245);
  STACKTOP = sp;return;
 }
}
function __ZN5physx10PxsContextD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i$i = 0, $or$cond$i$i$i$i$i$i = 0, $or$cond$i$i$i$i16 = 0, $or$cond$i$i1$i$i = 0, $or$cond$i$i11 = 0, $or$cond$i$i2 = 0, $or$cond$i$i3 = 0, $or$cond$i$i5 = 0, $or$cond$i$i7 = 0, $or$cond$i$i9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN5physx14PxsAABBManager8destroyVEv($2);
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZN5physx18PxsDynamicsContext7destroyEv($5);
 }
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  __ZN5physx13PxsCCDContext7destroyEv($8);
 }
 $10 = (($this) + 696|0);
 __ZN5physx11PxcPoolListINS_17PxsContactManagerENS_10PxsContextEE7destroyEv($10);
 $11 = (($this) + 7420|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2147483647;
 $14 = ($13|0)!=(0);
 $15 = ($12|0)>(-1);
 $or$cond$i$i$i$i = $14 & $15;
 if ($or$cond$i$i$i$i) {
  $16 = (($this) + 7412|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   FUNCTION_TABLE_vii[$22 & 4095]($19,$17);
  }
 }
 $23 = (($this) + 7408|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 & 2147483647;
 $26 = ($25|0)!=(0);
 $27 = ($24|0)>(-1);
 $or$cond$i$i1$i$i = $26 & $27;
 if ($or$cond$i$i1$i$i) {
  $28 = (($this) + 7400|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   $31 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 12|0);
   $34 = HEAP32[$33>>2]|0;
   FUNCTION_TABLE_vii[$34 & 4095]($31,$29);
  }
 }
 $35 = (($this) + 7396|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37|0)!=(0);
 $39 = ($36|0)>(-1);
 $or$cond$i$i$i$i$i$i = $38 & $39;
 if ($or$cond$i$i$i$i$i$i) {
  $40 = (($this) + 7388|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   FUNCTION_TABLE_vii[$46 & 4095]($43,$41);
  }
 }
 $47 = (($this) + 6700|0);
 HEAP32[$47>>2] = ((434896 + 8|0));
 $48 = (($this) + 6708|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 6672|0);
 HEAP32[$49>>2] = ((434896 + 8|0));
 $50 = (($this) + 6680|0);
 HEAP32[$50>>2] = 0;
 $51 = (($this) + 6176|0);
 __ZN5physx16PxsIslandManagerD2Ev($51);
 $52 = (($this) + 5928|0);
 __ZN5physx2Cm12RenderBufferD2Ev($52);
 $53 = (($this) + 5916|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = (($this) + 5920|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)>(-1);
  if ($58) {
   $59 = (($this) + 5924|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($59,$54);
  }
 }
 $60 = (($this) + 5880|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$61);
 }
 $63 = (($this) + 5876|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 & 2147483647;
 $66 = ($65|0)!=(0);
 $67 = ($64|0)>(-1);
 $or$cond$i$i$i = $66 & $67;
 if ($or$cond$i$i$i) {
  $68 = (($this) + 5868|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if (!($70)) {
   $71 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($72) + 12|0);
   $74 = HEAP32[$73>>2]|0;
   FUNCTION_TABLE_vii[$74 & 4095]($71,$69);
  }
 }
 $75 = (($this) + 5864|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = $76 & 2147483647;
 $78 = ($77|0)!=(0);
 $79 = ($76|0)>(-1);
 $or$cond$i$i = $78 & $79;
 if ($or$cond$i$i) {
  $80 = (($this) + 5856|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)==(0|0);
  if (!($82)) {
   $83 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($84) + 12|0);
   $86 = HEAP32[$85>>2]|0;
   FUNCTION_TABLE_vii[$86 & 4095]($83,$81);
  }
 }
 $87 = (($this) + 5844|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0|0);
 if (!($89)) {
  $90 = (($this) + 5848|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($91|0)>(-1);
  if ($92) {
   $93 = (($this) + 5852|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($93,$88);
  }
 }
 $94 = (($this) + 1448|0);
 __ZN5physx21PxsBodyTransformVaultD2Ev($94);
 $95 = (($this) + 1440|0);
 $96 = HEAP32[$95>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($96);
 $97 = HEAP32[$95>>2]|0;
 $98 = ($97|0)==(0|0);
 if (!($98)) {
  $99 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($100) + 12|0);
  $102 = HEAP32[$101>>2]|0;
  FUNCTION_TABLE_vii[$102 & 4095]($99,$97);
 }
 $103 = (($this) + 1436|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = $104 & 2147483647;
 $106 = ($105|0)!=(0);
 $107 = ($104|0)>(-1);
 $or$cond$i$i2 = $106 & $107;
 if ($or$cond$i$i2) {
  $108 = (($this) + 1428|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)==(0|0);
  if (!($110)) {
   $111 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = (($112) + 12|0);
   $114 = HEAP32[$113>>2]|0;
   FUNCTION_TABLE_vii[$114 & 4095]($111,$109);
  }
 }
 $115 = (($this) + 1424|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = $116 & 2147483647;
 $118 = ($117|0)!=(0);
 $119 = ($116|0)>(-1);
 $or$cond$i$i3 = $118 & $119;
 if ($or$cond$i$i3) {
  $120 = (($this) + 1416|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ($121|0)==(0|0);
  if (!($122)) {
   $123 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = (($124) + 12|0);
   $126 = HEAP32[$125>>2]|0;
   FUNCTION_TABLE_vii[$126 & 4095]($123,$121);
  }
 }
 $127 = (($this) + 1412|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = $128 & 2147483647;
 $130 = ($129|0)!=(0);
 $131 = ($128|0)>(-1);
 $or$cond$i$i5 = $130 & $131;
 if ($or$cond$i$i5) {
  $132 = (($this) + 1404|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(0|0);
  if (!($134)) {
   $135 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = (($136) + 12|0);
   $138 = HEAP32[$137>>2]|0;
   FUNCTION_TABLE_vii[$138 & 4095]($135,$133);
  }
 }
 $139 = (($this) + 1400|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = $140 & 2147483647;
 $142 = ($141|0)!=(0);
 $143 = ($140|0)>(-1);
 $or$cond$i$i7 = $142 & $143;
 if ($or$cond$i$i7) {
  $144 = (($this) + 1392|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = ($145|0)==(0|0);
  if (!($146)) {
   $147 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = (($148) + 12|0);
   $150 = HEAP32[$149>>2]|0;
   FUNCTION_TABLE_vii[$150 & 4095]($147,$145);
  }
 }
 $151 = (($this) + 1388|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = $152 & 2147483647;
 $154 = ($153|0)!=(0);
 $155 = ($152|0)>(-1);
 $or$cond$i$i9 = $154 & $155;
 if ($or$cond$i$i9) {
  $156 = (($this) + 1380|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = ($157|0)==(0|0);
  if (!($158)) {
   $159 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = (($160) + 12|0);
   $162 = HEAP32[$161>>2]|0;
   FUNCTION_TABLE_vii[$162 & 4095]($159,$157);
  }
 }
 $163 = (($this) + 1376|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = $164 & 2147483647;
 $166 = ($165|0)!=(0);
 $167 = ($164|0)>(-1);
 $or$cond$i$i11 = $166 & $167;
 if ($or$cond$i$i11) {
  $168 = (($this) + 1368|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = ($169|0)==(0|0);
  if (!($170)) {
   $171 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = (($172) + 12|0);
   $174 = HEAP32[$173>>2]|0;
   FUNCTION_TABLE_vii[$174 & 4095]($171,$169);
  }
 }
 $175 = (($this) + 1344|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = ($176|0)==(0|0);
 do {
  if (!($177)) {
   $178 = (($this) + 1348|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = ($179|0)>(-1);
   if (!($180)) {
    break;
   }
   $181 = (($this) + 1352|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($181,$176);
  }
 } while(0);
 $182 = (($this) + 1332|0);
 $183 = HEAP32[$182>>2]|0;
 $184 = ($183|0)==(0|0);
 do {
  if (!($184)) {
   $185 = (($this) + 1336|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = ($186|0)>(-1);
   if (!($187)) {
    break;
   }
   $188 = (($this) + 1340|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($188,$183);
  }
 } while(0);
 $189 = (($this) + 1036|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Gu31SpherePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEED2Ev($189);
 $190 = (($this) + 740|0);
 __ZN5physx6shdfnd8PoolBaseINS_2Gu30LargePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEED2Ev($190);
 __ZN5physx11PxcPoolListINS_17PxsContactManagerENS_10PxsContextEE7destroyEv($10);
 $191 = (($this) + 728|0);
 $192 = HEAP32[$191>>2]|0;
 $193 = ($192|0)==(0|0);
 do {
  if (!($193)) {
   $194 = (($this) + 732|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = ($195|0)>(-1);
   if (!($196)) {
    break;
   }
   $197 = (($this) + 736|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($197,$192);
  }
 } while(0);
 $198 = (($this) + 600|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($198);
 $199 = (($this) + 508|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($199);
 $200 = (($this) + 416|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($200);
 $201 = (($this) + 324|0);
 __ZN5physx2Cm10FanoutTaskD2Ev($201);
 $202 = (($this) + 320|0);
 $203 = HEAP32[$202>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($203);
 $204 = HEAP32[$202>>2]|0;
 $205 = ($204|0)==(0|0);
 if (!($205)) {
  $206 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $207 = HEAP32[$206>>2]|0;
  $208 = (($207) + 12|0);
  $209 = HEAP32[$208>>2]|0;
  FUNCTION_TABLE_vii[$209 & 4095]($206,$204);
 }
 $210 = (($this) + 276|0);
 __ZN5physx11PxcPoolListINS_16PxsParticleShapeENS_10PxsContextEE7destroyEv($210);
 $211 = (($this) + 308|0);
 $212 = HEAP32[$211>>2]|0;
 $213 = ($212|0)==(0|0);
 do {
  if (!($213)) {
   $214 = (($this) + 312|0);
   $215 = HEAP32[$214>>2]|0;
   $216 = ($215|0)>(-1);
   if (!($216)) {
    break;
   }
   $217 = (($this) + 316|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($217,$212);
  }
 } while(0);
 $218 = (($this) + 232|0);
 __ZN5physx11PxcPoolListINS_20PxsParticleSystemSimENS_10PxsContextEE7destroyEv($218);
 $219 = (($this) + 264|0);
 $220 = HEAP32[$219>>2]|0;
 $221 = ($220|0)==(0|0);
 do {
  if (!($221)) {
   $222 = (($this) + 268|0);
   $223 = HEAP32[$222>>2]|0;
   $224 = ($223|0)>(-1);
   if (!($224)) {
    break;
   }
   $225 = (($this) + 272|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($225,$220);
  }
 } while(0);
 $226 = (($this) + 224|0);
 __ZN5physx22PxcThreadCoherantCacheINS_16PxsThreadContextEED2Ev($226);
 $227 = (($this) + 44|0);
 __ZN5physx17PxcNpMemBlockPoolD2Ev($227);
 $228 = (($this) + 32|0);
 $229 = HEAP32[$228>>2]|0;
 $230 = $229 & 2147483647;
 $231 = ($230|0)!=(0);
 $232 = ($229|0)>(-1);
 $or$cond$i$i$i$i16 = $231 & $232;
 do {
  if ($or$cond$i$i$i$i16) {
   $233 = (($this) + 24|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = ($234|0)==(0|0);
   if ($235) {
    break;
   }
   $236 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = (($237) + 12|0);
   $239 = HEAP32[$238>>2]|0;
   FUNCTION_TABLE_vii[$239 & 4095]($236,$234);
  }
 } while(0);
 $240 = (($this) + 20|0);
 $241 = HEAP32[$240>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($241);
 $242 = HEAP32[$240>>2]|0;
 $243 = ($242|0)==(0|0);
 if ($243) {
  __ZN5physx19PxsSimObjectFactoryD2Ev($this);
  STACKTOP = sp;return;
 }
 $244 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $245 = HEAP32[$244>>2]|0;
 $246 = (($245) + 12|0);
 $247 = HEAP32[$246>>2]|0;
 FUNCTION_TABLE_vii[$247 & 4095]($244,$242);
 __ZN5physx19PxsSimObjectFactoryD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx11PxcPoolListINS_17PxsContactManagerENS_10PxsContextEE7destroyEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $i1$01 = 0, $j$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$pre = HEAP32[$this>>2]|0;
  $10 = $$pre;$30 = $4;$i$06 = 0;
  while(1) {
   $9 = ($10|0)==(0);
   if ($9) {
    $31 = 0;$7 = $30;
   } else {
    $j$02 = 0;
    while(1) {
     $11 = (($j$02) + 1)|0;
     $12 = HEAP32[$this>>2]|0;
     $13 = ($11>>>0)<($12>>>0);
     if ($13) {
      $j$02 = $11;
     } else {
      break;
     }
    }
    $$pre9 = HEAP32[$3>>2]|0;
    $31 = $12;$7 = $$pre9;
   }
   $14 = (($i$06) + 1)|0;
   $15 = ($14>>>0)<($7>>>0);
   if ($15) {
    $10 = $31;$30 = $7;$i$06 = $14;
   } else {
    break;
   }
  }
  $6 = ($7|0)==(0);
  if (!($6)) {
   $8 = (($this) + 24|0);
   $i1$01 = 0;
   while(1) {
    $16 = HEAP32[$8>>2]|0;
    $17 = (($16) + ($i1$01<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$18);
    $19 = HEAP32[$8>>2]|0;
    $20 = (($19) + ($i1$01<<2)|0);
    HEAP32[$20>>2] = 0;
    $21 = (($i1$01) + 1)|0;
    $22 = HEAP32[$3>>2]|0;
    $23 = ($21>>>0)<($22>>>0);
    if ($23) {
     $i1$01 = $21;
    } else {
     break;
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $24 = (($this) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$25);
 }
 HEAP32[$24>>2] = 0;
 $27 = (($this) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$28);
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_23prepareCMDiscreteUpdateEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext11preAllocateEjjjj($this,$nbBodies,$nbStaticShapes,$nbDynamicShapes,$numAggregates) {
 $this = $this|0;
 $nbBodies = $nbBodies|0;
 $nbStaticShapes = $nbStaticShapes|0;
 $nbDynamicShapes = $nbDynamicShapes|0;
 $numAggregates = $numAggregates|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($nbDynamicShapes) + ($nbStaticShapes))|0;
 $1 = (0 - ($numAggregates))|0;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $30 = (($this) + 6176|0);
  __ZN5physx16PxsIslandManager11preAllocateEj($30,$nbBodies);
  STACKTOP = sp;return;
 }
 $3 = $0 << 1;
 $4 = (($3) + 256)|0;
 $5 = $4 & -256;
 $6 = $5 >>> 5;
 $7 = (($this) + 5920|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($6>>>0)>($9>>>0);
 if ($10) {
  $11 = (($this) + 5924|0);
  $12 = $5 >>> 3;
  $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($11,$12,490328,339)|0);
  $14 = (($this) + 5916|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = HEAP32[$7>>2]|0;
   $18 = $17 << 2;
   _memcpy(($13|0),($15|0),($18|0))|0;
   $19 = HEAP32[$7>>2]|0;
   $20 = ($19|0)>(-1);
   if ($20) {
    $21 = HEAP32[$14>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($11,$21);
   }
  }
  $22 = HEAP32[$7>>2]|0;
  $23 = $22 & 2147483647;
  $24 = (($13) + ($23<<2)|0);
  $25 = (($6) - ($22))|0;
  $26 = $25 << 2;
  _memset(($24|0),0,($26|0))|0;
  HEAP32[$14>>2] = $13;
  HEAP32[$7>>2] = $6;
 }
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $30 = (($this) + 6176|0);
  __ZN5physx16PxsIslandManager11preAllocateEj($30,$nbBodies);
  STACKTOP = sp;return;
 }
 __ZN5physx14PxsAABBManager11preAllocateEjjj($28,$nbStaticShapes,$nbDynamicShapes,$numAggregates);
 $30 = (($this) + 6176|0);
 __ZN5physx16PxsIslandManager11preAllocateEj($30,$nbBodies);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext18setBounceThresholdEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 140|0);
 HEAPF32[$2>>2] = $threshold;
 STACKTOP = sp;return;
}
function __ZNK5physx10PxsContext18getBounceThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 140|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 STACKTOP = sp;return (Math_fround($3));
}
function __ZN5physx10PxsContext18createArticulationEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx19PxsSimObjectFactory18createArticulationEv($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx10PxsContext19destroyArticulationERNS_15PxsArticulationE($this,$articulation) {
 $this = $this|0;
 $articulation = $articulation|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx19PxsSimObjectFactory19destroyArticulationERNS_15PxsArticulationE($this,$articulation);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext17registerParticlesEv() {
 var $_ZN12_GLOBAL__N_119addParticleSystemFnE$index1 = 0, $_ZN12_GLOBAL__N_122removeParticleSystemFnE$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[489064>>0]=(229)&255;HEAP8[489064+1>>0]=((229)>>8)&255;HEAP8[489064+2>>0]=((229)>>16)&255;HEAP8[489064+3>>0]=(229)>>24;
 $_ZN12_GLOBAL__N_119addParticleSystemFnE$index1 = (489064 + 4|0);
 HEAP8[$_ZN12_GLOBAL__N_119addParticleSystemFnE$index1>>0]=0&255;HEAP8[$_ZN12_GLOBAL__N_119addParticleSystemFnE$index1+1>>0]=(0>>8)&255;HEAP8[$_ZN12_GLOBAL__N_119addParticleSystemFnE$index1+2>>0]=(0>>16)&255;HEAP8[$_ZN12_GLOBAL__N_119addParticleSystemFnE$index1+3>>0]=0>>24;
 HEAP8[489072>>0]=(1526)&255;HEAP8[489072+1>>0]=((1526)>>8)&255;HEAP8[489072+2>>0]=((1526)>>16)&255;HEAP8[489072+3>>0]=(1526)>>24;
 $_ZN12_GLOBAL__N_122removeParticleSystemFnE$index2 = (489072 + 4|0);
 HEAP8[$_ZN12_GLOBAL__N_122removeParticleSystemFnE$index2>>0]=0&255;HEAP8[$_ZN12_GLOBAL__N_122removeParticleSystemFnE$index2+1>>0]=(0>>8)&255;HEAP8[$_ZN12_GLOBAL__N_122removeParticleSystemFnE$index2+2>>0]=(0>>16)&255;HEAP8[$_ZN12_GLOBAL__N_122removeParticleSystemFnE$index2+3>>0]=0>>24;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext21addParticleSystemImplEPNS_15PxsParticleDataERKNS_26PxvParticleSystemParameterEb($this,$particleData,$parameter,$useGpuSupport) {
 $this = $this|0;
 $particleData = $particleData|0;
 $parameter = $parameter|0;
 $useGpuSupport = $useGpuSupport|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 252|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($this) + 232|0);
  $4 = (__ZN5physx11PxcPoolListINS_20PxsParticleSystemSimENS_10PxsContextEE6extendEv($3)|0);
  if ($4) {
   $$pre$i = HEAP32[$0>>2]|0;
   $6 = $$pre$i;
   label = 4;
  } else {
   $$0$i = 0;
  }
 } else {
  $6 = $1;
  label = 4;
 }
 if ((label|0) == 4) {
  $5 = (($6) + -1)|0;
  HEAP32[$0>>2] = $5;
  $7 = (($this) + 248|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($5<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 1140|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 & 31;
  $14 = 1 << $13;
  $15 = $12 >>> 5;
  $16 = (($this) + 264|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($15<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 | $14;
  HEAP32[$18>>2] = $20;
  $$0$i = $10;
 }
 __ZN5physx20PxsParticleSystemSim4initERNS_15PxsParticleDataERKNS_26PxvParticleSystemParameterE($$0$i,$particleData,$parameter);
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx10PxsContext24removeParticleSystemImplEPNS_20PxvParticleSystemSimEb($this,$particleSystem,$acquireParticleData) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $acquireParticleData = $acquireParticleData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $particleData$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 if ($acquireParticleData) {
  $0 = (__ZN5physx20PxsParticleSystemSim19obtainParticleStateEv($particleSystem)|0);
  $particleData$0 = $0;
 } else {
  $particleData$0 = 0;
 }
 __ZN5physx20PxsParticleSystemSim5clearEv($particleSystem);
 $1 = (($particleSystem) + 1140|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 31;
 $4 = 1 << $3;
 $5 = $4 ^ -1;
 $6 = $2 >>> 5;
 $7 = (($this) + 264|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & $5;
 HEAP32[$9>>2] = $11;
 $12 = (($this) + 252|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[$12>>2] = $14;
 $15 = (($this) + 248|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($13<<2)|0);
 HEAP32[$17>>2] = $particleSystem;
 STACKTOP = sp;return ($particleData$0|0);
}
function __ZN5physx10PxsContext17addParticleSystemEPNS_15PxsParticleDataERKNS_26PxvParticleSystemParameterEb($this,$particleData,$parameter,$useGpuSupport) {
 $this = $this|0;
 $particleData = $particleData|0;
 $parameter = $parameter|0;
 $useGpuSupport = $useGpuSupport|0;
 var $$field = 0, $$field2 = 0, $$index1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$field = HEAPU8[489064>>0]|(HEAPU8[489064+1>>0]<<8)|(HEAPU8[489064+2>>0]<<16)|(HEAPU8[489064+3>>0]<<24);
 $$index1 = (489064 + 4|0);
 $$field2 = HEAPU8[$$index1>>0]|(HEAPU8[$$index1+1>>0]<<8)|(HEAPU8[$$index1+2>>0]<<16)|(HEAPU8[$$index1+3>>0]<<24);
 $0 = $$field2 >> 1;
 $1 = (($this) + ($0)|0);
 $2 = $$field2 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $7 = $$field;
  $8 = $7;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = (($4) + ($$field)|0);
  $6 = HEAP32[$5>>2]|0;
  $8 = $6;
 }
 $9 = (FUNCTION_TABLE_iiiii[$8 & 511]($1,$particleData,$parameter,$useGpuSupport)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN5physx10PxsContext20removeParticleSystemEPNS_20PxvParticleSystemSimEb($this,$particleSystem,$acquireParticleData) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $acquireParticleData = $acquireParticleData|0;
 var $$field = 0, $$field2 = 0, $$index1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$field = HEAPU8[489072>>0]|(HEAPU8[489072+1>>0]<<8)|(HEAPU8[489072+2>>0]<<16)|(HEAPU8[489072+3>>0]<<24);
 $$index1 = (489072 + 4|0);
 $$field2 = HEAPU8[$$index1>>0]|(HEAPU8[$$index1+1>>0]<<8)|(HEAPU8[$$index1+2>>0]<<16)|(HEAPU8[$$index1+3>>0]<<24);
 $0 = $$field2 >> 1;
 $1 = (($this) + ($0)|0);
 $2 = $$field2 & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $7 = $$field;
  $8 = $7;
 } else {
  $4 = HEAP32[$1>>2]|0;
  $5 = (($4) + ($$field)|0);
  $6 = HEAP32[$5>>2]|0;
  $8 = $6;
 }
 $9 = (FUNCTION_TABLE_iiii[$8 & 2047]($1,$particleSystem,$acquireParticleData)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN5physx10PxsContext20createContactManagerERKNS_24PxvManagerDescRigidRigidEPNS_18PxsMaterialManagerE($this,$desc,$materialManager) {
 $this = $this|0;
 $desc = $desc|0;
 $materialManager = $materialManager|0;
 var $$0$i6 = 0, $$pre = 0, $$pre$i = 0, $$pre$i2 = 0, $$pre$i3 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 716|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = (($this) + 696|0);
   $5 = (__ZN5physx11PxcPoolListINS_17PxsContactManagerENS_10PxsContextEE6extendEv($4)|0);
   if ($5) {
    $$pre$i = HEAP32[$1>>2]|0;
    $7 = $$pre$i;
    break;
   } else {
    $$0$i6 = 0;
    STACKTOP = sp;return ($$0$i6|0);
   }
  } else {
   $7 = $2;
  }
 } while(0);
 $6 = (($7) + -1)|0;
 HEAP32[$1>>2] = $6;
 $8 = (($this) + 712|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($6<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 76|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 31;
 $15 = 1 << $14;
 $16 = $13 >>> 5;
 $17 = (($this) + 728|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + ($16<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 | $15;
 HEAP32[$19>>2] = $21;
 $22 = ($11|0)==(0|0);
 if ($22) {
  $$0$i6 = 0;
  STACKTOP = sp;return ($$0$i6|0);
 }
 __ZN5physx17PxsContactManager4initERKNS_24PxvManagerDescRigidRigidEPKNS_18PxsMaterialManagerE($11,$desc,$materialManager);
 $23 = (($this) + 7376|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 do {
  if (!($25)) {
   $26 = (($11) + 112|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = (($11) + 113|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = $27&255;
   $32 = ((489080 + (($31*7)|0)|0) + ($30)|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    $92 = (($11) + 60|0);
    HEAP32[$92>>2] = 0;
    break;
   }
   $35 = ($27&255)<(5);
   $36 = ($29&255)<(5);
   $or$cond = $35 & $36;
   if (!($or$cond)) {
    $91 = (($11) + 60|0);
    HEAP32[$91>>2] = 1;
    break;
   }
   $37 = ($27<<24>>24)==(0);
   $38 = ($29<<24>>24)==(0);
   $or$cond1 = $37 | $38;
   if ($or$cond1) {
    $39 = (($this) + 1328|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==(0|0);
    if ($41) {
     $42 = (($this) + 1036|0);
     __ZN5physx6shdfnd8PoolBaseINS_2Gu31SpherePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($42);
     $$pre$i2 = HEAP32[$39>>2]|0;
     $44 = $$pre$i2;
    } else {
     $44 = $40;
    }
    $43 = HEAP32[$44>>2]|0;
    HEAP32[$39>>2] = $43;
    $45 = (($this) + 1316|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + 1)|0;
    HEAP32[$45>>2] = $47;
    $48 = (($this) + 1320|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + -1)|0;
    HEAP32[$48>>2] = $50;
    $51 = ($44|0)==(0|0);
    if (!($51)) {
     $52 = (($44) + 48|0);
     ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
     $53 = (($44) + 4|0);
     $54 = (($44) + 8|0);
     $55 = (($44) + 12|0);
     $56 = (($44) + 16|0);
     ;HEAP32[$56+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$56+12>>2]=HEAP32[$0+12>>2]|0;
     $57 = (($44) + 32|0);
     HEAP8[$57>>0] = 0;
     $58 = (($44) + 33|0);
     HEAP8[$58>>0] = 0;
     $59 = (($44) + 44|0);
     HEAP32[$59>>2] = $52;
     HEAPF32[$56>>2] = Math_fround(3.40282346638528859812E+38);
     $60 = (($44) + 20|0);
     HEAPF32[$60>>2] = Math_fround(3.40282346638528859812E+38);
     $61 = (($44) + 24|0);
     HEAPF32[$61>>2] = Math_fround(3.40282346638528859812E+38);
     $62 = (($44) + 28|0);
     HEAPF32[$62>>2] = Math_fround(0.0);
     HEAPF32[$44>>2] = Math_fround(0.0);
     HEAPF32[$53>>2] = Math_fround(0.0);
     HEAPF32[$54>>2] = Math_fround(0.0);
     HEAPF32[$55>>2] = Math_fround(1.0);
    }
    $63 = $44;
    $64 = (($11) + 60|0);
    HEAP32[$64>>2] = $63;
    break;
   } else {
    $65 = (($this) + 1032|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    if ($67) {
     $68 = (($this) + 740|0);
     __ZN5physx6shdfnd8PoolBaseINS_2Gu30LargePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($68);
     $$pre$i3 = HEAP32[$65>>2]|0;
     $70 = $$pre$i3;
    } else {
     $70 = $66;
    }
    $69 = HEAP32[$70>>2]|0;
    HEAP32[$65>>2] = $69;
    $71 = (($this) + 1020|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($72) + 1)|0;
    HEAP32[$71>>2] = $73;
    $74 = (($this) + 1024|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($75) + -1)|0;
    HEAP32[$74>>2] = $76;
    $77 = ($70|0)==(0|0);
    if (!($77)) {
     $78 = (($70) + 48|0);
     ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
     $79 = (($70) + 4|0);
     $80 = (($70) + 8|0);
     $81 = (($70) + 12|0);
     $82 = (($70) + 16|0);
     ;HEAP32[$82+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$82+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$82+12>>2]=HEAP32[$0+12>>2]|0;
     $83 = (($70) + 32|0);
     HEAP8[$83>>0] = 0;
     $84 = (($70) + 33|0);
     HEAP8[$84>>0] = 0;
     $85 = (($70) + 44|0);
     HEAP32[$85>>2] = $78;
     HEAPF32[$82>>2] = Math_fround(3.40282346638528859812E+38);
     $86 = (($70) + 20|0);
     HEAPF32[$86>>2] = Math_fround(3.40282346638528859812E+38);
     $87 = (($70) + 24|0);
     HEAPF32[$87>>2] = Math_fround(3.40282346638528859812E+38);
     $88 = (($70) + 28|0);
     HEAPF32[$88>>2] = Math_fround(0.0);
     HEAPF32[$70>>2] = Math_fround(0.0);
     HEAPF32[$79>>2] = Math_fround(0.0);
     HEAPF32[$80>>2] = Math_fround(0.0);
     HEAPF32[$81>>2] = Math_fround(1.0);
    }
    $89 = $70;
    $90 = (($11) + 60|0);
    HEAP32[$90>>2] = $89;
    break;
   }
  }
 } while(0);
 $93 = (($this) + 5844|0);
 $94 = HEAP32[$12>>2]|0;
 $95 = (($94) + 256)|0;
 $96 = $95 & -256;
 $97 = $96 >>> 5;
 $98 = (($this) + 5848|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = $99 & 2147483647;
 $101 = ($97>>>0)>($100>>>0);
 if ($101) {
  $102 = (($this) + 5852|0);
  $103 = $96 >>> 3;
  $104 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($102,$103,490328,339)|0);
  $105 = HEAP32[$93>>2]|0;
  $106 = ($105|0)==(0|0);
  if (!($106)) {
   $107 = HEAP32[$98>>2]|0;
   $108 = $107 << 2;
   _memcpy(($104|0),($105|0),($108|0))|0;
   $109 = HEAP32[$98>>2]|0;
   $110 = ($109|0)>(-1);
   if ($110) {
    $111 = HEAP32[$93>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($102,$111);
   }
  }
  $112 = HEAP32[$98>>2]|0;
  $113 = $112 & 2147483647;
  $114 = (($104) + ($113<<2)|0);
  $115 = (($97) - ($112))|0;
  $116 = $115 << 2;
  _memset(($114|0),0,($116|0))|0;
  HEAP32[$93>>2] = $104;
  HEAP32[$98>>2] = $97;
  $$pre = HEAP32[$12>>2]|0;
  $119 = $$pre;
 } else {
  $119 = $94;
 }
 $117 = (($this) + 1332|0);
 $118 = (($119) + 256)|0;
 $120 = $118 & -256;
 $121 = $120 >>> 5;
 $122 = (($this) + 1336|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = $123 & 2147483647;
 $125 = ($121>>>0)>($124>>>0);
 if ($125) {
  $126 = (($this) + 1340|0);
  $127 = $120 >>> 3;
  $128 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($126,$127,490328,339)|0);
  $129 = HEAP32[$117>>2]|0;
  $130 = ($129|0)==(0|0);
  if (!($130)) {
   $131 = HEAP32[$122>>2]|0;
   $132 = $131 << 2;
   _memcpy(($128|0),($129|0),($132|0))|0;
   $133 = HEAP32[$122>>2]|0;
   $134 = ($133|0)>(-1);
   if ($134) {
    $135 = HEAP32[$117>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($126,$135);
   }
  }
  $136 = HEAP32[$122>>2]|0;
  $137 = $136 & 2147483647;
  $138 = (($128) + ($137<<2)|0);
  $139 = (($121) - ($136))|0;
  $140 = $139 << 2;
  _memset(($138|0),0,($140|0))|0;
  HEAP32[$117>>2] = $128;
  HEAP32[$122>>2] = $121;
  $$pre7 = HEAP32[$12>>2]|0;
  $142 = $$pre7;$146 = $128;
 } else {
  $$pre8 = HEAP32[$117>>2]|0;
  $142 = $119;$146 = $$pre8;
 }
 $141 = $142 & 31;
 $143 = 1 << $141;
 $144 = $142 >>> 5;
 $145 = (($146) + ($144<<2)|0);
 $147 = HEAP32[$145>>2]|0;
 $148 = $147 | $143;
 HEAP32[$145>>2] = $148;
 $149 = (($11) + 8|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = $150 & 1;
 $152 = ($151|0)==(0);
 if ($152) {
  $$0$i6 = $11;
  STACKTOP = sp;return ($$0$i6|0);
 }
 $153 = HEAP32[$12>>2]|0;
 $154 = $153 & 31;
 $155 = 1 << $154;
 $156 = $153 >>> 5;
 $157 = HEAP32[$93>>2]|0;
 $158 = (($157) + ($156<<2)|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = $159 | $155;
 HEAP32[$158>>2] = $160;
 $$0$i6 = $11;
 STACKTOP = sp;return ($$0$i6|0);
}
function __ZN5physx10PxsContext21destroyContactManagerEPNS_17PxsContactManagerE($this,$cm) {
 $this = $this|0;
 $cm = $cm|0;
 var $$pre$i = 0, $$pre$i12 = 0, $$pre$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cm) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = $1 & 1;
  $4 = ($3|0)==(0);
  do {
   if ($4) {
    $5 = (($cm) + 112|0);
    $6 = HEAP8[$5>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if (!($7)) {
     $8 = (($cm) + 113|0);
     $9 = HEAP8[$8>>0]|0;
     $10 = ($9<<24>>24)==(0);
     if (!($10)) {
      $27 = (($this) + 1020|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($28) + -1)|0;
      HEAP32[$27>>2] = $29;
      $30 = $1;
      $31 = (($this) + 1032|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = $1;
      HEAP32[$33>>2] = $32;
      HEAP32[$31>>2] = $30;
      $34 = (($this) + 1024|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = (($35) + 1)|0;
      HEAP32[$34>>2] = $36;
      $37 = (($this) + 1016|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38*50)|0;
      $40 = ($35|0)<($39|0);
      if ($40) {
       break;
      }
      $41 = (($this) + 740|0);
      $42 = (($this) + 1024|0);
      __ZN5physx6shdfnd8PoolBaseINS_2Gu30LargePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($41);
      HEAP32[$42>>2] = 0;
      break;
     }
    }
    $11 = (($this) + 1316|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + -1)|0;
    HEAP32[$11>>2] = $13;
    $14 = $1;
    $15 = (($this) + 1328|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $1;
    HEAP32[$17>>2] = $16;
    HEAP32[$15>>2] = $14;
    $18 = (($this) + 1320|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 1)|0;
    HEAP32[$18>>2] = $20;
    $21 = (($this) + 1312|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22*50)|0;
    $24 = ($19|0)<($23|0);
    if (!($24)) {
     $25 = (($this) + 1036|0);
     $26 = (($this) + 1320|0);
     __ZN5physx6shdfnd8PoolBaseINS_2Gu31SpherePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($25);
     HEAP32[$26>>2] = 0;
    }
   }
  } while(0);
  HEAP32[$0>>2] = 0;
 }
 $43 = (($cm) + 76|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 1332|0);
 $46 = (($44) + 32)|0;
 $47 = $46 >>> 5;
 $48 = (($this) + 1336|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49 & 2147483647;
 $51 = ($47>>>0)>($50>>>0);
 if ($51) {
  $52 = (($this) + 1340|0);
  $53 = $47 << 2;
  $54 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($52,$53,490328,339)|0);
  $55 = HEAP32[$45>>2]|0;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = HEAP32[$48>>2]|0;
   $58 = $57 << 2;
   _memcpy(($54|0),($55|0),($58|0))|0;
   $59 = HEAP32[$48>>2]|0;
   $60 = ($59|0)>(-1);
   if ($60) {
    $61 = HEAP32[$45>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($52,$61);
   }
  }
  $62 = HEAP32[$48>>2]|0;
  $63 = $62 & 2147483647;
  $64 = (($54) + ($63<<2)|0);
  $65 = (($47) - ($62))|0;
  $66 = $65 << 2;
  _memset(($64|0),0,($66|0))|0;
  HEAP32[$45>>2] = $54;
  HEAP32[$48>>2] = $47;
  $72 = $54;
 } else {
  $$pre$i12 = HEAP32[$45>>2]|0;
  $72 = $$pre$i12;
 }
 $67 = $44 & 31;
 $68 = 1 << $67;
 $69 = $68 ^ -1;
 $70 = $44 >>> 5;
 $71 = (($72) + ($70<<2)|0);
 $73 = HEAP32[$71>>2]|0;
 $74 = $73 & $69;
 HEAP32[$71>>2] = $74;
 $75 = (($this) + 5844|0);
 $76 = (($this) + 5848|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = $77 & 2147483647;
 $79 = ($47>>>0)>($78>>>0);
 if ($79) {
  $80 = (($this) + 5852|0);
  $81 = $47 << 2;
  $82 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($80,$81,490328,339)|0);
  $83 = HEAP32[$75>>2]|0;
  $84 = ($83|0)==(0|0);
  if (!($84)) {
   $85 = HEAP32[$76>>2]|0;
   $86 = $85 << 2;
   _memcpy(($82|0),($83|0),($86|0))|0;
   $87 = HEAP32[$76>>2]|0;
   $88 = ($87|0)>(-1);
   if ($88) {
    $89 = HEAP32[$75>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($80,$89);
   }
  }
  $90 = HEAP32[$76>>2]|0;
  $91 = $90 & 2147483647;
  $92 = (($82) + ($91<<2)|0);
  $93 = (($47) - ($90))|0;
  $94 = $93 << 2;
  _memset(($92|0),0,($94|0))|0;
  HEAP32[$75>>2] = $82;
  HEAP32[$76>>2] = $47;
  $96 = $82;
 } else {
  $$pre$i2 = HEAP32[$75>>2]|0;
  $96 = $$pre$i2;
 }
 $95 = (($96) + ($70<<2)|0);
 $97 = HEAP32[$95>>2]|0;
 $98 = $97 & $69;
 HEAP32[$95>>2] = $98;
 $99 = (($this) + 1344|0);
 $100 = (($this) + 1348|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = $101 & 2147483647;
 $103 = ($47>>>0)>($102>>>0);
 if (!($103)) {
  $$pre$i = HEAP32[$99>>2]|0;
  $120 = $$pre$i;
  $119 = (($120) + ($70<<2)|0);
  $121 = HEAP32[$119>>2]|0;
  $122 = $121 & $69;
  HEAP32[$119>>2] = $122;
  $123 = HEAP32[$43>>2]|0;
  $124 = $123 & 31;
  $125 = 1 << $124;
  $126 = $125 ^ -1;
  $127 = $123 >>> 5;
  $128 = (($this) + 728|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (($129) + ($127<<2)|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = $131 & $126;
  HEAP32[$130>>2] = $132;
  $133 = (($this) + 716|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = (($134) + 1)|0;
  HEAP32[$133>>2] = $135;
  $136 = (($this) + 712|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = (($137) + ($134<<2)|0);
  HEAP32[$138>>2] = $cm;
  STACKTOP = sp;return;
 }
 $104 = (($this) + 1352|0);
 $105 = $47 << 2;
 $106 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($104,$105,490328,339)|0);
 $107 = HEAP32[$99>>2]|0;
 $108 = ($107|0)==(0|0);
 if (!($108)) {
  $109 = HEAP32[$100>>2]|0;
  $110 = $109 << 2;
  _memcpy(($106|0),($107|0),($110|0))|0;
  $111 = HEAP32[$100>>2]|0;
  $112 = ($111|0)>(-1);
  if ($112) {
   $113 = HEAP32[$99>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($104,$113);
  }
 }
 $114 = HEAP32[$100>>2]|0;
 $115 = $114 & 2147483647;
 $116 = (($106) + ($115<<2)|0);
 $117 = (($47) - ($114))|0;
 $118 = $117 << 2;
 _memset(($116|0),0,($118|0))|0;
 HEAP32[$99>>2] = $106;
 HEAP32[$100>>2] = $47;
 $120 = $106;
 $119 = (($120) + ($70<<2)|0);
 $121 = HEAP32[$119>>2]|0;
 $122 = $121 & $69;
 HEAP32[$119>>2] = $122;
 $123 = HEAP32[$43>>2]|0;
 $124 = $123 & 31;
 $125 = 1 << $124;
 $126 = $125 ^ -1;
 $127 = $123 >>> 5;
 $128 = (($this) + 728|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = (($129) + ($127<<2)|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = $131 & $126;
 HEAP32[$130>>2] = $132;
 $133 = (($this) + 716|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = (($134) + 1)|0;
 HEAP32[$133>>2] = $135;
 $136 = (($this) + 712|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (($137) + ($134<<2)|0);
 HEAP32[$138>>2] = $cm;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext15setScratchBlockEPvj($this,$addr,$size) {
 $this = $this|0;
 $addr = $addr|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 36|0);
 HEAP32[$5>>2] = $addr;
 $6 = (($this) + 40|0);
 HEAP32[$6>>2] = $size;
 $7 = (($addr) + ($size)|0);
 HEAP32[$0>>2] = $7;
 $8 = (($this) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($10>>>0)>($4>>>0);
 if (!($11)) {
  (__ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($1,$0)|0);
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + ($4<<2)|0);
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  HEAP32[$13>>2] = $7;
 }
 HEAP32[$2>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$ph = 0, $$ph13 = 0, $$ph14 = 0, $$ph1630 = 0, $$ph1731 = 0, $$phi$trans$insert = 0, $$pre = Math_fround(0), $$pre$i$i$i = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0);
 var $235 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $contacts$08 = 0, $contacts$08$us = 0, $contacts$08$us$us = 0, $contacts$08$us11 = 0, $contacts$1 = 0, $contacts$1$us = 0, $exitcond = 0, $exitcond33 = 0, $exitcond34 = 0, $exitcond35 = 0, $exitcond44 = 0, $i$01$i = 0, $i$09 = 0, $i$09$us = 0, $i$09$us$us = 0, $i$09$us10 = 0;
 var $index$0$ph1832 = 0, $index$021 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$shift>>2]);
 $1 = (($shift) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($shift) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 7408|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = (($this) + 7412|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 7400|0);
  $12 = $6 & 2147483647;
  $i$01$i = 0;
  while(1) {
   $13 = (($10) + ($i$01$i<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0);
   if (!($15)) {
    $16 = HEAP32[$11>>2]|0;
    $17 = ((($16) + (($i$01$i*28)|0)|0) + 16|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = Math_fround($18 - $0);
    HEAPF32[$17>>2] = $19;
    $20 = ((($16) + (($i$01$i*28)|0)|0) + 20|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = Math_fround($21 - $2);
    HEAPF32[$20>>2] = $22;
    $23 = ((($16) + (($i$01$i*28)|0)|0) + 24|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = Math_fround($24 - $4);
    HEAPF32[$23>>2] = $25;
   }
   $26 = (($i$01$i) + 1)|0;
   $exitcond44 = ($26|0)==($12|0);
   if ($exitcond44) {
    break;
   } else {
    $i$01$i = $26;
   }
  }
 }
 $27 = (($this) + 7377|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 L9: do {
  if (!($29)) {
   $30 = (($this) + 1332|0);
   $31 = (($this) + 1336|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = $32 & 2147483647;
   $34 = ($33|0)==(0);
   if (!($34)) {
    $$pre$i$i$i = HEAP32[$30>>2]|0;
    $36 = 0;
    while(1) {
     $35 = (($$pre$i$i$i) + ($36<<2)|0);
     $37 = HEAP32[$35>>2]|0;
     $38 = ($37|0)==(0);
     if (!($38)) {
      break;
     }
     $39 = (($36) + 1)|0;
     $40 = ($39>>>0)<($33>>>0);
     if ($40) {
      $36 = $39;
     } else {
      break L9;
     }
    }
    $41 = $36 << 5;
    $42 = (0 - ($37))|0;
    $43 = $37 & $42;
    $44 = Math_imul($43, 125613361)|0;
    $45 = $44 >>> 27;
    $46 = (412480 + ($45<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = $47 | $41;
    $49 = (($37) + -1)|0;
    $50 = $49 & $37;
    $51 = ($50|0)==(0);
    L16: do {
     if ($51) {
      $53 = $36;
      while(1) {
       $52 = (($53) + 1)|0;
       $54 = ($52>>>0)<($33>>>0);
       if (!($54)) {
        $$ph13 = $52;$$ph14 = 0;
        break L16;
       }
       $55 = (($$pre$i$i$i) + ($52<<2)|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = ($56|0)==(0);
       if ($57) {
        $53 = $52;
       } else {
        $$ph13 = $52;$$ph14 = $56;
        break;
       }
      }
     } else {
      $$ph13 = $36;$$ph14 = $50;
     }
    } while(0);
    $58 = ($48|0)==(-1);
    if (!($58)) {
     $59 = (($this) + 708|0);
     $60 = (($this) + 720|0);
     $61 = (($this) + 696|0);
     $$ph1630 = $$ph13;$$ph1731 = $$ph14;$index$0$ph1832 = $48;
     while(1) {
      $64 = $$ph1630 << 5;
      $179 = $$ph1731;$index$021 = $index$0$ph1832;
      while(1) {
       $65 = HEAP32[$59>>2]|0;
       $66 = $index$021 >>> $65;
       $67 = HEAP32[$60>>2]|0;
       $68 = (($67) + ($66<<2)|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = HEAP32[$61>>2]|0;
       $71 = (($70) + -1)|0;
       $72 = $71 & $index$021;
       $73 = ((($69) + ($72<<7)|0) + 68|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($74|0)==(0|0);
       if (!($75)) {
        $76 = (($74) + 64|0);
        $77 = (($74) + 16|0);
        $78 = Math_fround(HEAPF32[$shift>>2]);
        $79 = Math_fround(HEAPF32[$77>>2]);
        $80 = Math_fround($79 - $78);
        HEAPF32[$77>>2] = $80;
        $81 = Math_fround(HEAPF32[$1>>2]);
        $82 = (($74) + 20|0);
        $83 = Math_fround(HEAPF32[$82>>2]);
        $84 = Math_fround($83 - $81);
        HEAPF32[$82>>2] = $84;
        $85 = Math_fround(HEAPF32[$3>>2]);
        $86 = (($74) + 24|0);
        $87 = Math_fround(HEAPF32[$86>>2]);
        $88 = Math_fround($87 - $85);
        HEAPF32[$86>>2] = $88;
        $89 = (($74) + 44|0);
        $90 = Math_fround(HEAPF32[$shift>>2]);
        $91 = Math_fround(HEAPF32[$89>>2]);
        $92 = Math_fround($91 - $90);
        HEAPF32[$89>>2] = $92;
        $93 = Math_fround(HEAPF32[$1>>2]);
        $94 = (($74) + 48|0);
        $95 = Math_fround(HEAPF32[$94>>2]);
        $96 = Math_fround($95 - $93);
        HEAPF32[$94>>2] = $96;
        $97 = Math_fround(HEAPF32[$3>>2]);
        $98 = (($74) + 52|0);
        $99 = Math_fround(HEAPF32[$98>>2]);
        $100 = Math_fround($99 - $97);
        HEAPF32[$98>>2] = $100;
        $101 = (($74) + 56|0);
        $102 = HEAP16[$101>>1]|0;
        $103 = $102&65535;
        $104 = (($74) + 58|0);
        $105 = HEAP8[$104>>0]|0;
        $106 = ($105<<24>>24)==(0);
        $107 = ($102<<16>>16)==(0);
        if (!($107)) {
         $108 = (($74) + 59|0);
         $109 = HEAP8[$108>>0]|0;
         $110 = ($109<<24>>24)==(0);
         $111 = (($103) + -1)|0;
         if ($110) {
          if ($106) {
           $contacts$08$us$us = $76;$i$09$us$us = 0;
           while(1) {
            $112 = ($i$09$us$us|0)==($111|0);
            if (!($112)) {
             $113 = (($contacts$08$us$us) + 128|0);
            }
            $114 = (($contacts$08$us$us) + 12|0);
            $115 = Math_fround(HEAPF32[$shift>>2]);
            $116 = Math_fround(HEAPF32[$114>>2]);
            $117 = Math_fround($116 - $115);
            HEAPF32[$114>>2] = $117;
            $118 = Math_fround(HEAPF32[$1>>2]);
            $119 = (($contacts$08$us$us) + 16|0);
            $120 = Math_fround(HEAPF32[$119>>2]);
            $121 = Math_fround($120 - $118);
            HEAPF32[$119>>2] = $121;
            $122 = Math_fround(HEAPF32[$3>>2]);
            $123 = (($contacts$08$us$us) + 20|0);
            $124 = Math_fround(HEAPF32[$123>>2]);
            $125 = Math_fround($124 - $122);
            HEAPF32[$123>>2] = $125;
            $126 = (($contacts$08$us$us) + 28|0);
            $127 = (($i$09$us$us) + 1)|0;
            $exitcond35 = ($127|0)==($103|0);
            if ($exitcond35) {
             break;
            } else {
             $contacts$08$us$us = $126;$i$09$us$us = $127;
            }
           }
          } else {
           $contacts$08$us = $76;$i$09$us = 0;
           while(1) {
            $128 = ($i$09$us|0)==($111|0);
            if (!($128)) {
             $129 = (($contacts$08$us) + 128|0);
            }
            $130 = (($contacts$08$us) + 12|0);
            $131 = Math_fround(HEAPF32[$shift>>2]);
            $132 = Math_fround(HEAPF32[$130>>2]);
            $133 = Math_fround($132 - $131);
            HEAPF32[$130>>2] = $133;
            $134 = Math_fround(HEAPF32[$1>>2]);
            $135 = (($contacts$08$us) + 16|0);
            $136 = Math_fround(HEAPF32[$135>>2]);
            $137 = Math_fround($136 - $134);
            HEAPF32[$135>>2] = $137;
            $138 = Math_fround(HEAPF32[$3>>2]);
            $139 = (($contacts$08$us) + 20|0);
            $140 = Math_fround(HEAPF32[$139>>2]);
            $141 = Math_fround($140 - $138);
            HEAPF32[$139>>2] = $141;
            $142 = (($contacts$08$us) + 36|0);
            $143 = (($i$09$us) + 1)|0;
            $exitcond33 = ($143|0)==($103|0);
            if ($exitcond33) {
             break;
            } else {
             $contacts$08$us = $142;$i$09$us = $143;
            }
           }
          }
         } else {
          if ($106) {
           $contacts$08$us11 = $76;$i$09$us10 = 0;
           while(1) {
            $144 = ($i$09$us10|0)==($111|0);
            if (!($144)) {
             $145 = (($contacts$08$us11) + 128|0);
            }
            $146 = ($i$09$us10|0)==(0);
            $147 = (($contacts$08$us11) + 12|0);
            $contacts$1$us = $146 ? $147 : $contacts$08$us11;
            $148 = Math_fround(HEAPF32[$shift>>2]);
            $149 = Math_fround(HEAPF32[$contacts$1$us>>2]);
            $150 = Math_fround($149 - $148);
            HEAPF32[$contacts$1$us>>2] = $150;
            $151 = Math_fround(HEAPF32[$1>>2]);
            $152 = (($contacts$1$us) + 4|0);
            $153 = Math_fround(HEAPF32[$152>>2]);
            $154 = Math_fround($153 - $151);
            HEAPF32[$152>>2] = $154;
            $155 = Math_fround(HEAPF32[$3>>2]);
            $156 = (($contacts$1$us) + 8|0);
            $157 = Math_fround(HEAPF32[$156>>2]);
            $158 = Math_fround($157 - $155);
            HEAPF32[$156>>2] = $158;
            $159 = (($contacts$1$us) + 16|0);
            $160 = (($i$09$us10) + 1)|0;
            $exitcond34 = ($160|0)==($103|0);
            if ($exitcond34) {
             break;
            } else {
             $contacts$08$us11 = $159;$i$09$us10 = $160;
            }
           }
          } else {
           $contacts$08 = $76;$i$09 = 0;
           while(1) {
            $161 = ($i$09|0)==($111|0);
            if (!($161)) {
             $162 = (($contacts$08) + 128|0);
            }
            $163 = ($i$09|0)==(0);
            $164 = (($contacts$08) + 12|0);
            $contacts$1 = $163 ? $164 : $contacts$08;
            $165 = Math_fround(HEAPF32[$shift>>2]);
            $166 = Math_fround(HEAPF32[$contacts$1>>2]);
            $167 = Math_fround($166 - $165);
            HEAPF32[$contacts$1>>2] = $167;
            $168 = Math_fround(HEAPF32[$1>>2]);
            $169 = (($contacts$1) + 4|0);
            $170 = Math_fround(HEAPF32[$169>>2]);
            $171 = Math_fround($170 - $168);
            HEAPF32[$169>>2] = $171;
            $172 = Math_fround(HEAPF32[$3>>2]);
            $173 = (($contacts$1) + 8|0);
            $174 = Math_fround(HEAPF32[$173>>2]);
            $175 = Math_fround($174 - $172);
            HEAPF32[$173>>2] = $175;
            $176 = (($contacts$1) + 24|0);
            $177 = (($i$09) + 1)|0;
            $exitcond = ($177|0)==($103|0);
            if ($exitcond) {
             break;
            } else {
             $contacts$08 = $176;$i$09 = $177;
            }
           }
          }
         }
        }
       }
       $178 = ($179|0)==(0);
       if ($178) {
        break L9;
       }
       $181 = (0 - ($179))|0;
       $182 = $179 & $181;
       $183 = Math_imul($182, 125613361)|0;
       $184 = $183 >>> 27;
       $185 = (412480 + ($184<<2)|0);
       $186 = HEAP32[$185>>2]|0;
       $63 = $186 | $64;
       $187 = (($179) + -1)|0;
       $188 = $187 & $179;
       $189 = HEAP32[$31>>2]|0;
       $190 = $189 & 2147483647;
       $191 = ($188|0)==(0);
       if ($191) {
        $193 = $$ph1630;
        break;
       }
       $180 = ($63|0)==(-1);
       if ($180) {
        break L9;
       } else {
        $179 = $188;$index$021 = $63;
       }
      }
      while(1) {
       $192 = (($193) + 1)|0;
       $194 = ($192>>>0)<($190>>>0);
       if (!($194)) {
        $$ph = 0;
        break;
       }
       $195 = HEAP32[$30>>2]|0;
       $196 = (($195) + ($192<<2)|0);
       $197 = HEAP32[$196>>2]|0;
       $198 = ($197|0)==(0);
       if ($198) {
        $193 = $192;
       } else {
        $$ph = $197;
        break;
       }
      }
      $62 = ($63|0)==(-1);
      if ($62) {
       break;
      } else {
       $$ph1630 = $192;$$ph1731 = $$ph;$index$0$ph1832 = $63;
      }
     }
    }
   }
  }
 } while(0);
 $199 = (($this) + 6140|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = $200 != Math_fround(-8.50705866596322149529E+37);
 $$phi$trans$insert = (($this) + 6144|0);
 $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
 $202 = $$pre != Math_fround(-8.50705866596322149529E+37);
 $or$cond = $201 | $202;
 if (!($or$cond)) {
  $203 = (($this) + 6148|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = $204 != Math_fround(-8.50705866596322149529E+37);
  if (!($205)) {
   $206 = (($this) + 6152|0);
   $207 = Math_fround(HEAPF32[$206>>2]);
   $208 = $207 != Math_fround(8.50705866596322149529E+37);
   if (!($208)) {
    $209 = (($this) + 6156|0);
    $210 = Math_fround(HEAPF32[$209>>2]);
    $211 = $210 != Math_fround(8.50705866596322149529E+37);
    if (!($211)) {
     $212 = (($this) + 6160|0);
     $213 = Math_fround(HEAPF32[$212>>2]);
     $214 = $213 != Math_fround(8.50705866596322149529E+37);
     if (!($214)) {
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $215 = Math_fround(HEAPF32[$shift>>2]);
 $216 = Math_fround($200 - $215);
 HEAPF32[$199>>2] = $216;
 $217 = Math_fround(HEAPF32[$1>>2]);
 $218 = (($this) + 6144|0);
 $219 = Math_fround($$pre - $217);
 HEAPF32[$218>>2] = $219;
 $220 = Math_fround(HEAPF32[$3>>2]);
 $221 = (($this) + 6148|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = Math_fround($222 - $220);
 HEAPF32[$221>>2] = $223;
 $224 = Math_fround(HEAPF32[$shift>>2]);
 $225 = (($this) + 6152|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = Math_fround($226 - $224);
 HEAPF32[$225>>2] = $227;
 $228 = Math_fround(HEAPF32[$1>>2]);
 $229 = (($this) + 6156|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = Math_fround($230 - $228);
 HEAPF32[$229>>2] = $231;
 $232 = Math_fround(HEAPF32[$3>>2]);
 $233 = (($this) + 6160|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = Math_fround($234 - $232);
 HEAPF32[$233>>2] = $235;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext13onShapeChangeERKNS_12PxsShapeCoreERKNS_12PxsRigidCoreEb($this,$shape,$rigidCore,$isDynamic) {
 $this = $this|0;
 $shape = $shape|0;
 $rigidCore = $rigidCore|0;
 $isDynamic = $isDynamic|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext16createFluidShapeEPNS_20PxsParticleSystemSimEPKNS_15PxsParticleCellE($this,$particleSystem,$packet) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $packet = $packet|0;
 var $$0$i1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 296|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($this) + 276|0);
  $6 = (__ZN5physx11PxcPoolListINS_16PxsParticleShapeENS_10PxsContextEE6extendEv($5)|0);
  if ($6) {
   $$pre$i = HEAP32[$2>>2]|0;
   $8 = $$pre$i;
   label = 4;
  } else {
   $$0$i1 = 0;
  }
 } else {
  $8 = $3;
  label = 4;
 }
 if ((label|0) == 4) {
  $7 = (($8) + -1)|0;
  HEAP32[$2>>2] = $7;
  $9 = (($this) + 292|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($7<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & 31;
  $16 = 1 << $15;
  $17 = $14 >>> 5;
  $18 = (($this) + 308|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($17<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 | $16;
  HEAP32[$20>>2] = $22;
  $23 = ($12|0)==(0|0);
  if ($23) {
   $$0$i1 = 0;
  } else {
   __ZN5physx16PxsParticleShape4initEPNS_20PxsParticleSystemSimEPKNS_15PxsParticleCellE($12,$particleSystem,$packet);
   $$0$i1 = $12;
  }
 }
 $24 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($24);
 STACKTOP = sp;return ($$0$i1|0);
}
function __ZN5physx10PxsContext17releaseFluidShapeEPNS_16PxsParticleShapeE($this,$shape) {
 $this = $this|0;
 $shape = $shape|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($shape) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 31;
 $5 = 1 << $4;
 $6 = $5 ^ -1;
 $7 = $3 >>> 5;
 $8 = (($this) + 308|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & $6;
 HEAP32[$10>>2] = $12;
 $13 = (($this) + 296|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1)|0;
 HEAP32[$13>>2] = $15;
 $16 = (($this) + 292|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($14<<2)|0);
 HEAP32[$18>>2] = $shape;
 $19 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($19);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext16updateBroadPhaseEPNS_10PxBaseTaskEb($this,$continuation,$secondBroadphase) {
 $this = $this|0;
 $continuation = $continuation|0;
 $secondBroadphase = $secondBroadphase|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5916|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 7380|0);
 HEAP32[$3>>2] = 0;
 $4 = (($continuation) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$0>>2]|0;
 $17 = (($this) + 5920|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 __ZN5physx14PxsAABBManager16updateAABBsAndBPEjjjPNS_10PxBaseTaskEPjjbPi($15,$13,0,0,$continuation,$16,$19,$secondBroadphase,$3);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext28runModifiableContactManagersEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$ph = 0, $$ph104 = 0, $$ph106 = 0, $$ph107 = 0, $$ph108151 = 0, $$ph109152 = 0, $$ph123 = 0, $$ph125 = 0, $$ph126 = 0, $$ph127156 = 0, $$ph128157 = 0, $$ph87 = 0, $$ph88 = 0, $$ph89146 = 0, $$ph90147 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i14 = 0;
 var $$pre$i9 = 0, $$pre190 = 0, $$sum$i = 0, $$sum$i$us = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0);
 var $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0;
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0;
 var $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = 0;
 var $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0);
 var $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = 0, $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = Math_fround(0);
 var $473 = 0, $474 = Math_fround(0), $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = Math_fround(0), $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = Math_fround(0);
 var $491 = Math_fround(0), $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = 0, $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0);
 var $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0);
 var $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = 0, $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = 0;
 var $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0);
 var $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0);
 var $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0);
 var $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = 0, $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = 0, $613 = Math_fround(0), $614 = Math_fround(0), $615 = 0, $616 = Math_fround(0);
 var $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0);
 var $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0);
 var $653 = Math_fround(0), $654 = 0, $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = 0, $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0);
 var $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = 0, $688 = Math_fround(0), $689 = Math_fround(0);
 var $69 = 0, $690 = 0, $691 = Math_fround(0), $692 = Math_fround(0), $693 = 0, $694 = Math_fround(0), $695 = Math_fround(0), $696 = 0, $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0), $702 = 0, $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = 0;
 var $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0);
 var $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = 0, $735 = Math_fround(0), $736 = Math_fround(0), $737 = 0, $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = 0, $741 = Math_fround(0), $742 = Math_fround(0);
 var $743 = Math_fround(0), $744 = Math_fround(0), $745 = 0, $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = 0, $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = 0, $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0);
 var $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = 0, $779 = Math_fround(0);
 var $78 = 0, $780 = 0, $781 = Math_fround(0), $782 = 0, $783 = Math_fround(0), $784 = 0, $785 = Math_fround(0), $786 = 0, $787 = Math_fround(0), $788 = 0, $789 = Math_fround(0), $79 = 0, $790 = 0, $791 = Math_fround(0), $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0;
 var $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0;
 var $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0;
 var $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0;
 var $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0;
 var $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0;
 var $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0;
 var $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = Math_fround(0), $92 = 0, $920 = 0, $921 = 0, $922 = 0;
 var $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0;
 var $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0;
 var $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0;
 var $978 = 0, $98 = 0, $99 = 0, $exitcond = 0, $inEnabled$not$i$i$i23 = 0, $index1$0$ph110153 = 0, $index1$0114 = 0, $index2$0$ph91149 = 0, $index2$095 = 0, $modify$0$off0$i$i = 0, $numContacts$0$lcssa = 0, $numContacts$078 = 0, $numContacts$078$us = 0, $numContacts$1$lcssa = 0, $numContacts$1$lcssa$us = 0, $numContacts$176$us$us = 0, $or$cond$i$i$i24 = 0, $pairCount$0$lcssa = 0, $pairCount$0$ph158 = 0, $pairCount$0135 = 0;
 var $patchHeaderSize$0$i$i = 0, $phitmp$us$us = 0, $pointSize$0$i$i = 0, $start$0$i$i = 0, $start$0$i$i6475$us$us = 0, $start$0$i$i6577 = 0, $start$0$i$i6577$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5912|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 6736|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAPU16[545728>>1]|(HEAPU16[545728+2>>1]<<16);
 $14 = $13 & 16711680;
 $inEnabled$not$i$i$i23 = ($14|0)==(0);
 $15 = ($6|0)==(0|0);
 $or$cond$i$i$i24 = $15 | $inEnabled$not$i$i$i23;
 if (!($or$cond$i$i$i24)) {
  $16 = $13&65535;
  $17 = HEAP32[$6>>2]|0;
  $18 = (($17) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_viiii[$19 & 511]($6,$16,$9,$12);
 }
 $20 = (($this) + 5844|0);
 $21 = (($this) + 5848|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 & 2147483647;
 $24 = ($23|0)==(0);
 L7: do {
  if ($24) {
   $pairCount$0$lcssa = 0;
  } else {
   $$pre$i$i$i = HEAP32[$20>>2]|0;
   $26 = 0;
   while(1) {
    $25 = (($$pre$i$i$i) + ($26<<2)|0);
    $27 = HEAP32[$25>>2]|0;
    $28 = ($27|0)==(0);
    if (!($28)) {
     break;
    }
    $29 = (($26) + 1)|0;
    $30 = ($29>>>0)<($23>>>0);
    if ($30) {
     $26 = $29;
    } else {
     $pairCount$0$lcssa = 0;
     break L7;
    }
   }
   $31 = $26 << 5;
   $32 = (0 - ($27))|0;
   $33 = $27 & $32;
   $34 = Math_imul($33, 125613361)|0;
   $35 = $34 >>> 27;
   $36 = (412480 + ($35<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = $37 | $31;
   $39 = (($27) + -1)|0;
   $40 = $39 & $27;
   $41 = ($40|0)==(0);
   L13: do {
    if ($41) {
     $43 = $26;
     while(1) {
      $42 = (($43) + 1)|0;
      $44 = ($42>>>0)<($23>>>0);
      if (!($44)) {
       $$ph125 = $42;$$ph126 = 0;
       break L13;
      }
      $45 = (($$pre$i$i$i) + ($42<<2)|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(0);
      if ($47) {
       $43 = $42;
      } else {
       $$ph125 = $42;$$ph126 = $46;
       break;
      }
     }
    } else {
     $$ph125 = $26;$$ph126 = $40;
    }
   } while(0);
   $48 = ($38|0)==(-1);
   if ($48) {
    $pairCount$0$lcssa = 0;
   } else {
    $$ph127156 = $$ph125;$$ph128157 = $$ph126;$pairCount$0$ph158 = 0;
    while(1) {
     $51 = $$ph127156 << 5;
     $54 = $$ph128157;$pairCount$0135 = $pairCount$0$ph158;
     while(1) {
      $52 = (($pairCount$0135) + 1)|0;
      $53 = ($54|0)==(0);
      if ($53) {
       $pairCount$0$lcssa = $52;
       break L7;
      }
      $56 = (0 - ($54))|0;
      $57 = $54 & $56;
      $58 = Math_imul($57, 125613361)|0;
      $59 = $58 >>> 27;
      $60 = (412480 + ($59<<2)|0);
      $61 = HEAP32[$60>>2]|0;
      $50 = $61 | $51;
      $62 = (($54) + -1)|0;
      $63 = $62 & $54;
      $64 = ($63|0)==(0);
      if ($64) {
       $66 = $$ph127156;
       break;
      }
      $55 = ($50|0)==(-1);
      if ($55) {
       $pairCount$0$lcssa = $52;
       break L7;
      } else {
       $54 = $63;$pairCount$0135 = $52;
      }
     }
     while(1) {
      $65 = (($66) + 1)|0;
      $67 = ($65>>>0)<($23>>>0);
      if (!($67)) {
       $$ph123 = 0;
       break;
      }
      $68 = HEAP32[$20>>2]|0;
      $69 = (($68) + ($65<<2)|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($70|0)==(0);
      if ($71) {
       $66 = $65;
      } else {
       $$ph123 = $70;
       break;
      }
     }
     $49 = ($50|0)==(-1);
     if ($49) {
      $pairCount$0$lcssa = $52;
      break;
     } else {
      $$ph127156 = $65;$$ph128157 = $$ph123;$pairCount$0$ph158 = $52;
     }
    }
   }
  }
 } while(0);
 $72 = (($this) + 5856|0);
 $73 = (($this) + 5860|0);
 HEAP32[$73>>2] = 0;
 $74 = (($this) + 5864|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = $75 & 2147483647;
 $77 = ($76>>>0)<($pairCount$0$lcssa>>>0);
 if ($77) {
  __ZN5physx6shdfnd5ArrayINS_19PxContactModifyPairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($72,$pairCount$0$lcssa);
  $$pre = HEAP32[$21>>2]|0;
  $79 = $$pre;
 } else {
  $79 = $22;
 }
 $78 = $79 & 2147483647;
 $80 = ($78|0)==(0);
 L33: do {
  if (!($80)) {
   $$pre$i14 = HEAP32[$20>>2]|0;
   $82 = 0;
   while(1) {
    $81 = (($$pre$i14) + ($82<<2)|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = ($83|0)==(0);
    if (!($84)) {
     break;
    }
    $85 = (($82) + 1)|0;
    $86 = ($85>>>0)<($78>>>0);
    if ($86) {
     $82 = $85;
    } else {
     break L33;
    }
   }
   $87 = $82 << 5;
   $88 = (0 - ($83))|0;
   $89 = $83 & $88;
   $90 = Math_imul($89, 125613361)|0;
   $91 = $90 >>> 27;
   $92 = (412480 + ($91<<2)|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = $93 | $87;
   $95 = (($83) + -1)|0;
   $96 = $95 & $83;
   $97 = ($96|0)==(0);
   L39: do {
    if ($97) {
     $99 = $82;
     while(1) {
      $98 = (($99) + 1)|0;
      $100 = ($98>>>0)<($78>>>0);
      if (!($100)) {
       $$ph106 = $98;$$ph107 = 0;
       break L39;
      }
      $101 = (($$pre$i14) + ($98<<2)|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = ($102|0)==(0);
      if ($103) {
       $99 = $98;
      } else {
       $$ph106 = $98;$$ph107 = $102;
       break;
      }
     }
    } else {
     $$ph106 = $82;$$ph107 = $96;
    }
   } while(0);
   $104 = ($94|0)==(-1);
   if (!($104)) {
    $105 = (($this) + 708|0);
    $106 = (($this) + 720|0);
    $107 = (($this) + 696|0);
    $$ph108151 = $$ph106;$$ph109152 = $$ph107;$index1$0$ph110153 = $94;
    while(1) {
     $110 = $$ph108151 << 5;
     $815 = $$ph109152;$index1$0114 = $index1$0$ph110153;
     while(1) {
      $111 = HEAP32[$105>>2]|0;
      $112 = $index1$0114 >>> $111;
      $113 = HEAP32[$106>>2]|0;
      $114 = (($113) + ($112<<2)|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = HEAP32[$107>>2]|0;
      $117 = (($116) + -1)|0;
      $118 = $117 & $index1$0114;
      $119 = ((($115) + ($118<<7)|0) + 36|0);
      $120 = HEAP16[$119>>1]|0;
      $121 = ($120<<16>>16)==(0);
      if (!($121)) {
       $122 = HEAP32[$74>>2]|0;
       $123 = $122 & 2147483647;
       $124 = HEAP32[$73>>2]|0;
       $125 = ($123>>>0)>($124>>>0);
       if ($125) {
        $130 = $124;
       } else {
        $126 = ($123|0)==(0);
        $127 = $122 << 1;
        $$$i$i = $126 ? 1 : $127;
        __ZN5physx6shdfnd5ArrayINS_19PxContactModifyPairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($72,$$$i$i);
        $$pre$i9 = HEAP32[$73>>2]|0;
        $130 = $$pre$i9;
       }
       $128 = HEAP32[$72>>2]|0;
       $129 = (($130) + 1)|0;
       HEAP32[$73>>2] = $129;
       $131 = ((($115) + ($118<<7)|0) + 88|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = (__Z28ScGetPxShapeFromPxsShapeCorePKN5physx12PxsShapeCoreE($132)|0);
       $134 = ((($128) + (($130*80)|0)|0) + 8|0);
       HEAP32[$134>>2] = $133;
       $135 = ((($115) + ($118<<7)|0) + 92|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = (__Z28ScGetPxShapeFromPxsShapeCorePKN5physx12PxsShapeCoreE($136)|0);
       $138 = ((($128) + (($130*80)|0)|0) + 12|0);
       HEAP32[$138>>2] = $137;
       $139 = ((($115) + ($118<<7)|0) + 38|0);
       $140 = HEAP16[$139>>1]|0;
       $141 = $140 & 32;
       $142 = ($141<<16>>16)==(0);
       $143 = ((($115) + ($118<<7)|0) + 80|0);
       $144 = HEAP32[$143>>2]|0;
       if ($142) {
        $146 = (__Z34ScGetPxRigidStaticFromPxsRigidCorePKN5physx12PxsRigidCoreE($144)|0);
        $148 = $146;
       } else {
        $145 = (__Z32ScGetPxRigidBodyFromPxsRigidCorePKN5physx12PxsRigidCoreE($144)|0);
        $148 = $145;
       }
       $147 = (($128) + (($130*80)|0)|0);
       HEAP32[$147>>2] = $148;
       $149 = HEAP16[$139>>1]|0;
       $150 = $149 & 64;
       $151 = ($150<<16>>16)==(0);
       $152 = ((($115) + ($118<<7)|0) + 84|0);
       $153 = HEAP32[$152>>2]|0;
       if ($151) {
        $155 = (__Z34ScGetPxRigidStaticFromPxsRigidCorePKN5physx12PxsRigidCoreE($153)|0);
        $157 = $155;
       } else {
        $154 = (__Z32ScGetPxRigidBodyFromPxsRigidCorePKN5physx12PxsRigidCoreE($153)|0);
        $157 = $154;
       }
       $156 = ((($128) + (($130*80)|0)|0) + 4|0);
       HEAP32[$156>>2] = $157;
       $158 = HEAP32[$131>>2]|0;
       $159 = HEAP32[$143>>2]|0;
       $160 = HEAP16[$139>>1]|0;
       $161 = $160 & 32;
       $162 = ($161<<16>>16)==(0);
       if ($162) {
        $370 = (($158) + 16|0);
        $371 = Math_fround(HEAPF32[$370>>2]);
        $372 = Math_fround($371 * Math_fround(2.0));
        $373 = (($158) + 20|0);
        $374 = Math_fround(HEAPF32[$373>>2]);
        $375 = Math_fround($374 * Math_fround(2.0));
        $376 = (($158) + 24|0);
        $377 = Math_fround(HEAPF32[$376>>2]);
        $378 = Math_fround($377 * Math_fround(2.0));
        $379 = (($159) + 12|0);
        $380 = Math_fround(HEAPF32[$379>>2]);
        $381 = Math_fround($380 * $380);
        $382 = Math_fround($381 + Math_fround(-0.5));
        $383 = Math_fround(HEAPF32[$159>>2]);
        $384 = Math_fround($372 * $383);
        $385 = (($159) + 4|0);
        $386 = Math_fround(HEAPF32[$385>>2]);
        $387 = Math_fround($375 * $386);
        $388 = Math_fround($384 + $387);
        $389 = (($159) + 8|0);
        $390 = Math_fround(HEAPF32[$389>>2]);
        $391 = Math_fround($378 * $390);
        $392 = Math_fround($388 + $391);
        $393 = Math_fround($372 * $382);
        $394 = Math_fround($378 * $386);
        $395 = Math_fround($375 * $390);
        $396 = Math_fround($394 - $395);
        $397 = Math_fround($380 * $396);
        $398 = Math_fround($393 + $397);
        $399 = Math_fround($383 * $392);
        $400 = Math_fround($399 + $398);
        $401 = Math_fround($375 * $382);
        $402 = Math_fround($372 * $390);
        $403 = Math_fround($378 * $383);
        $404 = Math_fround($402 - $403);
        $405 = Math_fround($380 * $404);
        $406 = Math_fround($401 + $405);
        $407 = Math_fround($386 * $392);
        $408 = Math_fround($407 + $406);
        $409 = Math_fround($378 * $382);
        $410 = Math_fround($375 * $383);
        $411 = Math_fround($372 * $386);
        $412 = Math_fround($410 - $411);
        $413 = Math_fround($380 * $412);
        $414 = Math_fround($409 + $413);
        $415 = Math_fround($390 * $392);
        $416 = Math_fround($414 + $415);
        $417 = (($159) + 16|0);
        $418 = Math_fround(HEAPF32[$417>>2]);
        $419 = Math_fround($418 + $400);
        $420 = (($159) + 20|0);
        $421 = Math_fround(HEAPF32[$420>>2]);
        $422 = Math_fround($421 + $408);
        $423 = (($159) + 24|0);
        $424 = Math_fround(HEAPF32[$423>>2]);
        $425 = Math_fround($424 + $416);
        $426 = Math_fround(HEAPF32[$158>>2]);
        $427 = Math_fround($380 * $426);
        $428 = (($158) + 12|0);
        $429 = Math_fround(HEAPF32[$428>>2]);
        $430 = Math_fround($383 * $429);
        $431 = Math_fround($427 + $430);
        $432 = (($158) + 8|0);
        $433 = Math_fround(HEAPF32[$432>>2]);
        $434 = Math_fround($386 * $433);
        $435 = Math_fround($431 + $434);
        $436 = (($158) + 4|0);
        $437 = Math_fround(HEAPF32[$436>>2]);
        $438 = Math_fround($390 * $437);
        $439 = Math_fround($435 - $438);
        $440 = Math_fround($380 * $437);
        $441 = Math_fround($386 * $429);
        $442 = Math_fround($441 + $440);
        $443 = Math_fround($390 * $426);
        $444 = Math_fround($443 + $442);
        $445 = Math_fround($383 * $433);
        $446 = Math_fround($444 - $445);
        $447 = Math_fround($380 * $433);
        $448 = Math_fround($390 * $429);
        $449 = Math_fround($448 + $447);
        $450 = Math_fround($383 * $437);
        $451 = Math_fround($450 + $449);
        $452 = Math_fround($386 * $426);
        $453 = Math_fround($451 - $452);
        $454 = Math_fround($380 * $429);
        $455 = Math_fround($383 * $426);
        $456 = Math_fround($454 - $455);
        $457 = Math_fround($386 * $437);
        $458 = Math_fround($456 - $457);
        $459 = Math_fround($390 * $433);
        $460 = Math_fround($458 - $459);
        $462 = $439;$464 = $446;$466 = $453;$468 = $460;$470 = $419;$472 = $422;$474 = $425;$478 = $160;
       } else {
        $163 = (($159) + 48|0);
        $164 = Math_fround(HEAPF32[$163>>2]);
        $165 = (($159) + 52|0);
        $166 = Math_fround(HEAPF32[$165>>2]);
        $167 = (($159) + 56|0);
        $168 = Math_fround(HEAPF32[$167>>2]);
        $169 = Math_fround($164 * Math_fround(-2.0));
        $170 = Math_fround($166 * Math_fround(-2.0));
        $171 = Math_fround($168 * Math_fround(-2.0));
        $172 = (($159) + 44|0);
        $173 = Math_fround(HEAPF32[$172>>2]);
        $174 = Math_fround($173 * $173);
        $175 = Math_fround($174 + Math_fround(-0.5));
        $176 = (($159) + 32|0);
        $177 = Math_fround(HEAPF32[$176>>2]);
        $178 = Math_fround($169 * $177);
        $179 = (($159) + 36|0);
        $180 = Math_fround(HEAPF32[$179>>2]);
        $181 = Math_fround($170 * $180);
        $182 = Math_fround($178 + $181);
        $183 = (($159) + 40|0);
        $184 = Math_fround(HEAPF32[$183>>2]);
        $185 = Math_fround($171 * $184);
        $186 = Math_fround($182 + $185);
        $187 = Math_fround($169 * $175);
        $188 = Math_fround($171 * $180);
        $189 = Math_fround($170 * $184);
        $190 = Math_fround($188 - $189);
        $191 = Math_fround($173 * $190);
        $192 = Math_fround($187 - $191);
        $193 = Math_fround($177 * $186);
        $194 = Math_fround($193 + $192);
        $195 = Math_fround($170 * $175);
        $196 = Math_fround($169 * $184);
        $197 = Math_fround($171 * $177);
        $198 = Math_fround($196 - $197);
        $199 = Math_fround($173 * $198);
        $200 = Math_fround($195 - $199);
        $201 = Math_fround($180 * $186);
        $202 = Math_fround($201 + $200);
        $203 = Math_fround($171 * $175);
        $204 = Math_fround($170 * $177);
        $205 = Math_fround($169 * $180);
        $206 = Math_fround($204 - $205);
        $207 = Math_fround($173 * $206);
        $208 = Math_fround($203 - $207);
        $209 = Math_fround($184 * $186);
        $210 = Math_fround($208 + $209);
        $211 = Math_fround(-$177);
        $212 = Math_fround(-$180);
        $213 = Math_fround(-$184);
        $214 = Math_fround($194 * Math_fround(2.0));
        $215 = Math_fround($202 * Math_fround(2.0));
        $216 = Math_fround($210 * Math_fround(2.0));
        $217 = (($159) + 12|0);
        $218 = Math_fround(HEAPF32[$217>>2]);
        $219 = Math_fround($218 * $218);
        $220 = Math_fround($219 + Math_fround(-0.5));
        $221 = Math_fround(HEAPF32[$159>>2]);
        $222 = Math_fround($221 * $214);
        $223 = (($159) + 4|0);
        $224 = Math_fround(HEAPF32[$223>>2]);
        $225 = Math_fround($224 * $215);
        $226 = Math_fround($222 + $225);
        $227 = (($159) + 8|0);
        $228 = Math_fround(HEAPF32[$227>>2]);
        $229 = Math_fround($228 * $216);
        $230 = Math_fround($229 + $226);
        $231 = Math_fround($220 * $214);
        $232 = Math_fround($224 * $216);
        $233 = Math_fround($228 * $215);
        $234 = Math_fround($232 - $233);
        $235 = Math_fround($218 * $234);
        $236 = Math_fround($231 + $235);
        $237 = Math_fround($221 * $230);
        $238 = Math_fround($237 + $236);
        $239 = Math_fround($220 * $215);
        $240 = Math_fround($228 * $214);
        $241 = Math_fround($221 * $216);
        $242 = Math_fround($240 - $241);
        $243 = Math_fround($218 * $242);
        $244 = Math_fround($239 + $243);
        $245 = Math_fround($224 * $230);
        $246 = Math_fround($245 + $244);
        $247 = Math_fround($220 * $216);
        $248 = Math_fround($221 * $215);
        $249 = Math_fround($224 * $214);
        $250 = Math_fround($248 - $249);
        $251 = Math_fround($218 * $250);
        $252 = Math_fround($247 + $251);
        $253 = Math_fround($228 * $230);
        $254 = Math_fround($252 + $253);
        $255 = (($159) + 16|0);
        $256 = Math_fround(HEAPF32[$255>>2]);
        $257 = Math_fround($256 + $238);
        $258 = (($159) + 20|0);
        $259 = Math_fround(HEAPF32[$258>>2]);
        $260 = Math_fround($259 + $246);
        $261 = (($159) + 24|0);
        $262 = Math_fround(HEAPF32[$261>>2]);
        $263 = Math_fround($262 + $254);
        $264 = Math_fround($218 * $211);
        $265 = Math_fround($173 * $221);
        $266 = Math_fround($264 + $265);
        $267 = Math_fround($224 * $213);
        $268 = Math_fround($266 + $267);
        $269 = Math_fround($228 * $212);
        $270 = Math_fround($268 - $269);
        $271 = Math_fround($218 * $212);
        $272 = Math_fround($173 * $224);
        $273 = Math_fround($271 + $272);
        $274 = Math_fround($228 * $211);
        $275 = Math_fround($274 + $273);
        $276 = Math_fround($221 * $213);
        $277 = Math_fround($275 - $276);
        $278 = Math_fround($218 * $213);
        $279 = Math_fround($173 * $228);
        $280 = Math_fround($278 + $279);
        $281 = Math_fround($221 * $212);
        $282 = Math_fround($281 + $280);
        $283 = Math_fround($224 * $211);
        $284 = Math_fround($282 - $283);
        $285 = Math_fround($173 * $218);
        $286 = Math_fround($221 * $211);
        $287 = Math_fround($285 - $286);
        $288 = Math_fround($224 * $212);
        $289 = Math_fround($287 - $288);
        $290 = Math_fround($228 * $213);
        $291 = Math_fround($289 - $290);
        $292 = (($158) + 16|0);
        $293 = Math_fround(HEAPF32[$292>>2]);
        $294 = Math_fround($293 * Math_fround(2.0));
        $295 = (($158) + 20|0);
        $296 = Math_fround(HEAPF32[$295>>2]);
        $297 = Math_fround($296 * Math_fround(2.0));
        $298 = (($158) + 24|0);
        $299 = Math_fround(HEAPF32[$298>>2]);
        $300 = Math_fround($299 * Math_fround(2.0));
        $301 = Math_fround($291 * $291);
        $302 = Math_fround($301 + Math_fround(-0.5));
        $303 = Math_fround($270 * $294);
        $304 = Math_fround($277 * $297);
        $305 = Math_fround($303 + $304);
        $306 = Math_fround($284 * $300);
        $307 = Math_fround($305 + $306);
        $308 = Math_fround($302 * $294);
        $309 = Math_fround($277 * $300);
        $310 = Math_fround($284 * $297);
        $311 = Math_fround($309 - $310);
        $312 = Math_fround($291 * $311);
        $313 = Math_fround($308 + $312);
        $314 = Math_fround($270 * $307);
        $315 = Math_fround($314 + $313);
        $316 = Math_fround($302 * $297);
        $317 = Math_fround($284 * $294);
        $318 = Math_fround($270 * $300);
        $319 = Math_fround($317 - $318);
        $320 = Math_fround($291 * $319);
        $321 = Math_fround($316 + $320);
        $322 = Math_fround($277 * $307);
        $323 = Math_fround($322 + $321);
        $324 = Math_fround($302 * $300);
        $325 = Math_fround($270 * $297);
        $326 = Math_fround($277 * $294);
        $327 = Math_fround($325 - $326);
        $328 = Math_fround($291 * $327);
        $329 = Math_fround($324 + $328);
        $330 = Math_fround($284 * $307);
        $331 = Math_fround($329 + $330);
        $332 = Math_fround($257 + $315);
        $333 = Math_fround($260 + $323);
        $334 = Math_fround($263 + $331);
        $335 = Math_fround(HEAPF32[$158>>2]);
        $336 = Math_fround($291 * $335);
        $337 = (($158) + 12|0);
        $338 = Math_fround(HEAPF32[$337>>2]);
        $339 = Math_fround($270 * $338);
        $340 = Math_fround($336 + $339);
        $341 = (($158) + 8|0);
        $342 = Math_fround(HEAPF32[$341>>2]);
        $343 = Math_fround($277 * $342);
        $344 = Math_fround($340 + $343);
        $345 = (($158) + 4|0);
        $346 = Math_fround(HEAPF32[$345>>2]);
        $347 = Math_fround($284 * $346);
        $348 = Math_fround($344 - $347);
        $349 = Math_fround($291 * $346);
        $350 = Math_fround($277 * $338);
        $351 = Math_fround($350 + $349);
        $352 = Math_fround($284 * $335);
        $353 = Math_fround($352 + $351);
        $354 = Math_fround($270 * $342);
        $355 = Math_fround($353 - $354);
        $356 = Math_fround($291 * $342);
        $357 = Math_fround($284 * $338);
        $358 = Math_fround($357 + $356);
        $359 = Math_fround($270 * $346);
        $360 = Math_fround($359 + $358);
        $361 = Math_fround($277 * $335);
        $362 = Math_fround($360 - $361);
        $363 = Math_fround($291 * $338);
        $364 = Math_fround($270 * $335);
        $365 = Math_fround($363 - $364);
        $366 = Math_fround($277 * $346);
        $367 = Math_fround($365 - $366);
        $368 = Math_fround($284 * $342);
        $369 = Math_fround($367 - $368);
        $$pre190 = HEAP16[$139>>1]|0;
        $462 = $348;$464 = $355;$466 = $362;$468 = $369;$470 = $332;$472 = $333;$474 = $334;$478 = $$pre190;
       }
       $461 = ((($128) + (($130*80)|0)|0) + 16|0);
       HEAPF32[$461>>2] = $462;
       $463 = ((($128) + (($130*80)|0)|0) + 20|0);
       HEAPF32[$463>>2] = $464;
       $465 = ((($128) + (($130*80)|0)|0) + 24|0);
       HEAPF32[$465>>2] = $466;
       $467 = ((($128) + (($130*80)|0)|0) + 28|0);
       HEAPF32[$467>>2] = $468;
       $469 = ((($128) + (($130*80)|0)|0) + 32|0);
       HEAPF32[$469>>2] = $470;
       $471 = ((($128) + (($130*80)|0)|0) + 36|0);
       HEAPF32[$471>>2] = $472;
       $473 = ((($128) + (($130*80)|0)|0) + 40|0);
       HEAPF32[$473>>2] = $474;
       $475 = HEAP32[$135>>2]|0;
       $476 = HEAP32[$152>>2]|0;
       $477 = $478 & 64;
       $479 = ($477<<16>>16)==(0);
       if ($479) {
        $687 = (($475) + 16|0);
        $688 = Math_fround(HEAPF32[$687>>2]);
        $689 = Math_fround($688 * Math_fround(2.0));
        $690 = (($475) + 20|0);
        $691 = Math_fround(HEAPF32[$690>>2]);
        $692 = Math_fround($691 * Math_fround(2.0));
        $693 = (($475) + 24|0);
        $694 = Math_fround(HEAPF32[$693>>2]);
        $695 = Math_fround($694 * Math_fround(2.0));
        $696 = (($476) + 12|0);
        $697 = Math_fround(HEAPF32[$696>>2]);
        $698 = Math_fround($697 * $697);
        $699 = Math_fround($698 + Math_fround(-0.5));
        $700 = Math_fround(HEAPF32[$476>>2]);
        $701 = Math_fround($689 * $700);
        $702 = (($476) + 4|0);
        $703 = Math_fround(HEAPF32[$702>>2]);
        $704 = Math_fround($692 * $703);
        $705 = Math_fround($701 + $704);
        $706 = (($476) + 8|0);
        $707 = Math_fround(HEAPF32[$706>>2]);
        $708 = Math_fround($695 * $707);
        $709 = Math_fround($705 + $708);
        $710 = Math_fround($689 * $699);
        $711 = Math_fround($695 * $703);
        $712 = Math_fround($692 * $707);
        $713 = Math_fround($711 - $712);
        $714 = Math_fround($697 * $713);
        $715 = Math_fround($710 + $714);
        $716 = Math_fround($700 * $709);
        $717 = Math_fround($716 + $715);
        $718 = Math_fround($692 * $699);
        $719 = Math_fround($689 * $707);
        $720 = Math_fround($695 * $700);
        $721 = Math_fround($719 - $720);
        $722 = Math_fround($697 * $721);
        $723 = Math_fround($718 + $722);
        $724 = Math_fround($703 * $709);
        $725 = Math_fround($724 + $723);
        $726 = Math_fround($695 * $699);
        $727 = Math_fround($692 * $700);
        $728 = Math_fround($689 * $703);
        $729 = Math_fround($727 - $728);
        $730 = Math_fround($697 * $729);
        $731 = Math_fround($726 + $730);
        $732 = Math_fround($707 * $709);
        $733 = Math_fround($731 + $732);
        $734 = (($476) + 16|0);
        $735 = Math_fround(HEAPF32[$734>>2]);
        $736 = Math_fround($735 + $717);
        $737 = (($476) + 20|0);
        $738 = Math_fround(HEAPF32[$737>>2]);
        $739 = Math_fround($738 + $725);
        $740 = (($476) + 24|0);
        $741 = Math_fround(HEAPF32[$740>>2]);
        $742 = Math_fround($741 + $733);
        $743 = Math_fround(HEAPF32[$475>>2]);
        $744 = Math_fround($697 * $743);
        $745 = (($475) + 12|0);
        $746 = Math_fround(HEAPF32[$745>>2]);
        $747 = Math_fround($700 * $746);
        $748 = Math_fround($744 + $747);
        $749 = (($475) + 8|0);
        $750 = Math_fround(HEAPF32[$749>>2]);
        $751 = Math_fround($703 * $750);
        $752 = Math_fround($748 + $751);
        $753 = (($475) + 4|0);
        $754 = Math_fround(HEAPF32[$753>>2]);
        $755 = Math_fround($707 * $754);
        $756 = Math_fround($752 - $755);
        $757 = Math_fround($697 * $754);
        $758 = Math_fround($703 * $746);
        $759 = Math_fround($758 + $757);
        $760 = Math_fround($707 * $743);
        $761 = Math_fround($760 + $759);
        $762 = Math_fround($700 * $750);
        $763 = Math_fround($761 - $762);
        $764 = Math_fround($697 * $750);
        $765 = Math_fround($707 * $746);
        $766 = Math_fround($765 + $764);
        $767 = Math_fround($700 * $754);
        $768 = Math_fround($767 + $766);
        $769 = Math_fround($703 * $743);
        $770 = Math_fround($768 - $769);
        $771 = Math_fround($697 * $746);
        $772 = Math_fround($700 * $743);
        $773 = Math_fround($771 - $772);
        $774 = Math_fround($703 * $754);
        $775 = Math_fround($773 - $774);
        $776 = Math_fround($707 * $750);
        $777 = Math_fround($775 - $776);
        $779 = $756;$781 = $763;$783 = $770;$785 = $777;$787 = $736;$789 = $739;$791 = $742;
       } else {
        $480 = (($476) + 48|0);
        $481 = Math_fround(HEAPF32[$480>>2]);
        $482 = (($476) + 52|0);
        $483 = Math_fround(HEAPF32[$482>>2]);
        $484 = (($476) + 56|0);
        $485 = Math_fround(HEAPF32[$484>>2]);
        $486 = Math_fround($481 * Math_fround(-2.0));
        $487 = Math_fround($483 * Math_fround(-2.0));
        $488 = Math_fround($485 * Math_fround(-2.0));
        $489 = (($476) + 44|0);
        $490 = Math_fround(HEAPF32[$489>>2]);
        $491 = Math_fround($490 * $490);
        $492 = Math_fround($491 + Math_fround(-0.5));
        $493 = (($476) + 32|0);
        $494 = Math_fround(HEAPF32[$493>>2]);
        $495 = Math_fround($486 * $494);
        $496 = (($476) + 36|0);
        $497 = Math_fround(HEAPF32[$496>>2]);
        $498 = Math_fround($487 * $497);
        $499 = Math_fround($495 + $498);
        $500 = (($476) + 40|0);
        $501 = Math_fround(HEAPF32[$500>>2]);
        $502 = Math_fround($488 * $501);
        $503 = Math_fround($499 + $502);
        $504 = Math_fround($486 * $492);
        $505 = Math_fround($488 * $497);
        $506 = Math_fround($487 * $501);
        $507 = Math_fround($505 - $506);
        $508 = Math_fround($490 * $507);
        $509 = Math_fround($504 - $508);
        $510 = Math_fround($494 * $503);
        $511 = Math_fround($510 + $509);
        $512 = Math_fround($487 * $492);
        $513 = Math_fround($486 * $501);
        $514 = Math_fround($488 * $494);
        $515 = Math_fround($513 - $514);
        $516 = Math_fround($490 * $515);
        $517 = Math_fround($512 - $516);
        $518 = Math_fround($497 * $503);
        $519 = Math_fround($518 + $517);
        $520 = Math_fround($488 * $492);
        $521 = Math_fround($487 * $494);
        $522 = Math_fround($486 * $497);
        $523 = Math_fround($521 - $522);
        $524 = Math_fround($490 * $523);
        $525 = Math_fround($520 - $524);
        $526 = Math_fround($501 * $503);
        $527 = Math_fround($525 + $526);
        $528 = Math_fround(-$494);
        $529 = Math_fround(-$497);
        $530 = Math_fround(-$501);
        $531 = Math_fround($511 * Math_fround(2.0));
        $532 = Math_fround($519 * Math_fround(2.0));
        $533 = Math_fround($527 * Math_fround(2.0));
        $534 = (($476) + 12|0);
        $535 = Math_fround(HEAPF32[$534>>2]);
        $536 = Math_fround($535 * $535);
        $537 = Math_fround($536 + Math_fround(-0.5));
        $538 = Math_fround(HEAPF32[$476>>2]);
        $539 = Math_fround($538 * $531);
        $540 = (($476) + 4|0);
        $541 = Math_fround(HEAPF32[$540>>2]);
        $542 = Math_fround($541 * $532);
        $543 = Math_fround($539 + $542);
        $544 = (($476) + 8|0);
        $545 = Math_fround(HEAPF32[$544>>2]);
        $546 = Math_fround($545 * $533);
        $547 = Math_fround($546 + $543);
        $548 = Math_fround($537 * $531);
        $549 = Math_fround($541 * $533);
        $550 = Math_fround($545 * $532);
        $551 = Math_fround($549 - $550);
        $552 = Math_fround($535 * $551);
        $553 = Math_fround($548 + $552);
        $554 = Math_fround($538 * $547);
        $555 = Math_fround($554 + $553);
        $556 = Math_fround($537 * $532);
        $557 = Math_fround($545 * $531);
        $558 = Math_fround($538 * $533);
        $559 = Math_fround($557 - $558);
        $560 = Math_fround($535 * $559);
        $561 = Math_fround($556 + $560);
        $562 = Math_fround($541 * $547);
        $563 = Math_fround($562 + $561);
        $564 = Math_fround($537 * $533);
        $565 = Math_fround($538 * $532);
        $566 = Math_fround($541 * $531);
        $567 = Math_fround($565 - $566);
        $568 = Math_fround($535 * $567);
        $569 = Math_fround($564 + $568);
        $570 = Math_fround($545 * $547);
        $571 = Math_fround($569 + $570);
        $572 = (($476) + 16|0);
        $573 = Math_fround(HEAPF32[$572>>2]);
        $574 = Math_fround($573 + $555);
        $575 = (($476) + 20|0);
        $576 = Math_fround(HEAPF32[$575>>2]);
        $577 = Math_fround($576 + $563);
        $578 = (($476) + 24|0);
        $579 = Math_fround(HEAPF32[$578>>2]);
        $580 = Math_fround($579 + $571);
        $581 = Math_fround($535 * $528);
        $582 = Math_fround($490 * $538);
        $583 = Math_fround($581 + $582);
        $584 = Math_fround($541 * $530);
        $585 = Math_fround($583 + $584);
        $586 = Math_fround($545 * $529);
        $587 = Math_fround($585 - $586);
        $588 = Math_fround($535 * $529);
        $589 = Math_fround($490 * $541);
        $590 = Math_fround($588 + $589);
        $591 = Math_fround($545 * $528);
        $592 = Math_fround($591 + $590);
        $593 = Math_fround($538 * $530);
        $594 = Math_fround($592 - $593);
        $595 = Math_fround($535 * $530);
        $596 = Math_fround($490 * $545);
        $597 = Math_fround($595 + $596);
        $598 = Math_fround($538 * $529);
        $599 = Math_fround($598 + $597);
        $600 = Math_fround($541 * $528);
        $601 = Math_fround($599 - $600);
        $602 = Math_fround($490 * $535);
        $603 = Math_fround($538 * $528);
        $604 = Math_fround($602 - $603);
        $605 = Math_fround($541 * $529);
        $606 = Math_fround($604 - $605);
        $607 = Math_fround($545 * $530);
        $608 = Math_fround($606 - $607);
        $609 = (($475) + 16|0);
        $610 = Math_fround(HEAPF32[$609>>2]);
        $611 = Math_fround($610 * Math_fround(2.0));
        $612 = (($475) + 20|0);
        $613 = Math_fround(HEAPF32[$612>>2]);
        $614 = Math_fround($613 * Math_fround(2.0));
        $615 = (($475) + 24|0);
        $616 = Math_fround(HEAPF32[$615>>2]);
        $617 = Math_fround($616 * Math_fround(2.0));
        $618 = Math_fround($608 * $608);
        $619 = Math_fround($618 + Math_fround(-0.5));
        $620 = Math_fround($587 * $611);
        $621 = Math_fround($594 * $614);
        $622 = Math_fround($620 + $621);
        $623 = Math_fround($601 * $617);
        $624 = Math_fround($622 + $623);
        $625 = Math_fround($619 * $611);
        $626 = Math_fround($594 * $617);
        $627 = Math_fround($601 * $614);
        $628 = Math_fround($626 - $627);
        $629 = Math_fround($608 * $628);
        $630 = Math_fround($625 + $629);
        $631 = Math_fround($587 * $624);
        $632 = Math_fround($631 + $630);
        $633 = Math_fround($619 * $614);
        $634 = Math_fround($601 * $611);
        $635 = Math_fround($587 * $617);
        $636 = Math_fround($634 - $635);
        $637 = Math_fround($608 * $636);
        $638 = Math_fround($633 + $637);
        $639 = Math_fround($594 * $624);
        $640 = Math_fround($639 + $638);
        $641 = Math_fround($619 * $617);
        $642 = Math_fround($587 * $614);
        $643 = Math_fround($594 * $611);
        $644 = Math_fround($642 - $643);
        $645 = Math_fround($608 * $644);
        $646 = Math_fround($641 + $645);
        $647 = Math_fround($601 * $624);
        $648 = Math_fround($646 + $647);
        $649 = Math_fround($574 + $632);
        $650 = Math_fround($577 + $640);
        $651 = Math_fround($580 + $648);
        $652 = Math_fround(HEAPF32[$475>>2]);
        $653 = Math_fround($608 * $652);
        $654 = (($475) + 12|0);
        $655 = Math_fround(HEAPF32[$654>>2]);
        $656 = Math_fround($587 * $655);
        $657 = Math_fround($653 + $656);
        $658 = (($475) + 8|0);
        $659 = Math_fround(HEAPF32[$658>>2]);
        $660 = Math_fround($594 * $659);
        $661 = Math_fround($657 + $660);
        $662 = (($475) + 4|0);
        $663 = Math_fround(HEAPF32[$662>>2]);
        $664 = Math_fround($601 * $663);
        $665 = Math_fround($661 - $664);
        $666 = Math_fround($608 * $663);
        $667 = Math_fround($594 * $655);
        $668 = Math_fround($667 + $666);
        $669 = Math_fround($601 * $652);
        $670 = Math_fround($669 + $668);
        $671 = Math_fround($587 * $659);
        $672 = Math_fround($670 - $671);
        $673 = Math_fround($608 * $659);
        $674 = Math_fround($601 * $655);
        $675 = Math_fround($674 + $673);
        $676 = Math_fround($587 * $663);
        $677 = Math_fround($676 + $675);
        $678 = Math_fround($594 * $652);
        $679 = Math_fround($677 - $678);
        $680 = Math_fround($608 * $655);
        $681 = Math_fround($587 * $652);
        $682 = Math_fround($680 - $681);
        $683 = Math_fround($594 * $663);
        $684 = Math_fround($682 - $683);
        $685 = Math_fround($601 * $659);
        $686 = Math_fround($684 - $685);
        $779 = $665;$781 = $672;$783 = $679;$785 = $686;$787 = $649;$789 = $650;$791 = $651;
       }
       $778 = ((($128) + (($130*80)|0)|0) + 44|0);
       HEAPF32[$778>>2] = $779;
       $780 = ((($128) + (($130*80)|0)|0) + 48|0);
       HEAPF32[$780>>2] = $781;
       $782 = ((($128) + (($130*80)|0)|0) + 52|0);
       HEAPF32[$782>>2] = $783;
       $784 = ((($128) + (($130*80)|0)|0) + 56|0);
       HEAPF32[$784>>2] = $785;
       $786 = ((($128) + (($130*80)|0)|0) + 60|0);
       HEAPF32[$786>>2] = $787;
       $788 = ((($128) + (($130*80)|0)|0) + 64|0);
       HEAPF32[$788>>2] = $789;
       $790 = ((($128) + (($130*80)|0)|0) + 68|0);
       HEAPF32[$790>>2] = $791;
       $792 = ((($128) + (($130*80)|0)|0) + 72|0);
       $793 = ((($115) + ($118<<7)|0) + 44|0);
       $794 = HEAP32[$793>>2]|0;
       $795 = (($794) + 24|0);
       $796 = $795;
       $797 = $120&65535;
       $798 = $792;
       $799 = $798;
       HEAP32[$799>>2] = $797;
       $800 = (($798) + 4)|0;
       $801 = $800;
       HEAP32[$801>>2] = $796;
       $802 = ((($115) + ($118<<7)|0) + 112|0);
       $803 = HEAP8[$802>>0]|0;
       $804 = ((($115) + ($118<<7)|0) + 113|0);
       $805 = HEAP8[$804>>0]|0;
       $806 = ($803&255)<($805&255);
       $807 = $806 ? $805 : $803;
       $808 = $807&255;
       $809 = $806 ? $803 : $805;
       $810 = $809&255;
       $811 = (((($this) + (($810*28)|0)|0) + ($808<<2)|0) + 7144|0);
       $812 = HEAP32[$811>>2]|0;
       $813 = (($812) + 1)|0;
       HEAP32[$811>>2] = $813;
      }
      $814 = ($815|0)==(0);
      if ($814) {
       break L33;
      }
      $817 = (0 - ($815))|0;
      $818 = $815 & $817;
      $819 = Math_imul($818, 125613361)|0;
      $820 = $819 >>> 27;
      $821 = (412480 + ($820<<2)|0);
      $822 = HEAP32[$821>>2]|0;
      $109 = $822 | $110;
      $823 = (($815) + -1)|0;
      $824 = $823 & $815;
      $825 = HEAP32[$21>>2]|0;
      $826 = $825 & 2147483647;
      $827 = ($824|0)==(0);
      if ($827) {
       $829 = $$ph108151;
       break;
      }
      $816 = ($109|0)==(-1);
      if ($816) {
       break L33;
      } else {
       $815 = $824;$index1$0114 = $109;
      }
     }
     while(1) {
      $828 = (($829) + 1)|0;
      $830 = ($828>>>0)<($826>>>0);
      if (!($830)) {
       $$ph104 = 0;
       break;
      }
      $831 = HEAP32[$20>>2]|0;
      $832 = (($831) + ($828<<2)|0);
      $833 = HEAP32[$832>>2]|0;
      $834 = ($833|0)==(0);
      if ($834) {
       $829 = $828;
      } else {
       $$ph104 = $833;
       break;
      }
     }
     $108 = ($109|0)==(-1);
     if ($108) {
      break;
     } else {
      $$ph108151 = $828;$$ph109152 = $$ph104;$index1$0$ph110153 = $109;
     }
    }
   }
  }
 } while(0);
 $835 = HEAP32[$73>>2]|0;
 $836 = ($835|0)==(0);
 if (!($836)) {
  $837 = HEAP32[$0>>2]|0;
  $838 = HEAP32[$837>>2]|0;
  $839 = HEAP32[$838>>2]|0;
  $840 = HEAP32[$72>>2]|0;
  FUNCTION_TABLE_viii[$839 & 4095]($837,$840,$835);
 }
 $841 = HEAP32[$21>>2]|0;
 $842 = $841 & 2147483647;
 $843 = ($842|0)==(0);
 L81: do {
  if (!($843)) {
   $$pre$i = HEAP32[$20>>2]|0;
   $845 = 0;
   while(1) {
    $844 = (($$pre$i) + ($845<<2)|0);
    $846 = HEAP32[$844>>2]|0;
    $847 = ($846|0)==(0);
    if (!($847)) {
     break;
    }
    $848 = (($845) + 1)|0;
    $849 = ($848>>>0)<($842>>>0);
    if ($849) {
     $845 = $848;
    } else {
     break L81;
    }
   }
   $850 = $845 << 5;
   $851 = (0 - ($846))|0;
   $852 = $846 & $851;
   $853 = Math_imul($852, 125613361)|0;
   $854 = $853 >>> 27;
   $855 = (412480 + ($854<<2)|0);
   $856 = HEAP32[$855>>2]|0;
   $857 = $856 | $850;
   $858 = (($846) + -1)|0;
   $859 = $858 & $846;
   $860 = ($859|0)==(0);
   L87: do {
    if ($860) {
     $862 = $845;
     while(1) {
      $861 = (($862) + 1)|0;
      $863 = ($861>>>0)<($842>>>0);
      if (!($863)) {
       $$ph87 = $861;$$ph88 = 0;
       break L87;
      }
      $864 = (($$pre$i) + ($861<<2)|0);
      $865 = HEAP32[$864>>2]|0;
      $866 = ($865|0)==(0);
      if ($866) {
       $862 = $861;
      } else {
       $$ph87 = $861;$$ph88 = $865;
       break;
      }
     }
    } else {
     $$ph87 = $845;$$ph88 = $859;
    }
   } while(0);
   $867 = ($857|0)==(-1);
   if (!($867)) {
    $868 = (($this) + 708|0);
    $869 = (($this) + 720|0);
    $870 = (($this) + 696|0);
    $$ph89146 = $$ph87;$$ph90147 = $$ph88;$index2$0$ph91149 = $857;
    while(1) {
     $873 = $$ph89146 << 5;
     $955 = $$ph90147;$index2$095 = $index2$0$ph91149;
     while(1) {
      $874 = HEAP32[$868>>2]|0;
      $875 = $index2$095 >>> $874;
      $876 = HEAP32[$869>>2]|0;
      $877 = (($876) + ($875<<2)|0);
      $878 = HEAP32[$877>>2]|0;
      $879 = HEAP32[$870>>2]|0;
      $880 = (($879) + -1)|0;
      $881 = $880 & $index2$095;
      $882 = ((($878) + ($881<<7)|0) + 36|0);
      $883 = HEAP16[$882>>1]|0;
      $884 = ($883<<16>>16)==(0);
      if ($884) {
       label = 78;
      } else {
       $885 = ((($878) + ($881<<7)|0) + 44|0);
       $886 = HEAP32[$885>>2]|0;
       $887 = ((($878) + ($881<<7)|0) + 48|0);
       $888 = HEAP32[$887>>2]|0;
       $889 = ($888|0)==(0);
       if ($889) {
        $modify$0$off0$i$i = 0;$patchHeaderSize$0$i$i = 0;$pointSize$0$i$i = 0;$start$0$i$i = 0;
       } else {
        $890 = (($886) + 2|0);
        $891 = HEAP16[$890>>1]|0;
        $892 = $891&65535;
        $893 = $892 & 2;
        $894 = ($893|0)!=(0);
        $895 = $893 << 3;
        $896 = $895 | 4;
        $897 = (($886) + ($896)|0);
        $898 = $894 ? 4 : 32;
        if ($894) {
         $modify$0$off0$i$i = 1;$patchHeaderSize$0$i$i = $898;$pointSize$0$i$i = 72;$start$0$i$i = $897;
        } else {
         $899 = $892 << 3;
         $900 = $899 & 8;
         $901 = $900 | 16;
         $modify$0$off0$i$i = 0;$patchHeaderSize$0$i$i = $898;$pointSize$0$i$i = $901;$start$0$i$i = $897;
        }
       }
       $902 = $start$0$i$i;
       $903 = $886;
       $904 = (($902) - ($903))|0;
       $905 = ($904>>>0)<($888>>>0);
       if ($905) {
        if ($modify$0$off0$i$i) {
         $numContacts$078$us = 0;$start$0$i$i6577$us = $start$0$i$i;
         while(1) {
          $906 = HEAP16[$start$0$i$i6577$us>>1]|0;
          $907 = $906&65535;
          $908 = Math_imul($907, $pointSize$0$i$i)|0;
          $$sum$i$us = (($908) + ($patchHeaderSize$0$i$i))|0;
          $909 = (($start$0$i$i6577$us) + ($$sum$i$us)|0);
          $910 = (($start$0$i$i6577$us) + ($patchHeaderSize$0$i$i)|0);
          $911 = ($906<<16>>16)==(0);
          if ($911) {
           $numContacts$1$lcssa$us = $numContacts$078$us;
          } else {
           $916 = 0;$numContacts$176$us$us = $numContacts$078$us;$start$0$i$i6475$us$us = $910;
           while(1) {
            $915 = (($916) + 1)|0;
            $917 = (($start$0$i$i6475$us$us) + ($pointSize$0$i$i)|0);
            $918 = (($start$0$i$i6475$us$us) + 48|0);
            $919 = Math_fround(HEAPF32[$918>>2]);
            $phitmp$us$us = $919 != Math_fround(0.0);
            $920 = $phitmp$us$us&1;
            $921 = (($920) + ($numContacts$176$us$us))|0;
            $exitcond = ($915|0)==($907|0);
            if ($exitcond) {
             $numContacts$1$lcssa$us = $921;
             break;
            } else {
             $916 = $915;$numContacts$176$us$us = $921;$start$0$i$i6475$us$us = $917;
            }
           }
          }
          $912 = $909;
          $913 = (($912) - ($903))|0;
          $914 = ($913>>>0)<($888>>>0);
          if ($914) {
           $numContacts$078$us = $numContacts$1$lcssa$us;$start$0$i$i6577$us = $909;
          } else {
           $numContacts$0$lcssa = $numContacts$1$lcssa$us;
           break;
          }
         }
        } else {
         $numContacts$078 = 0;$start$0$i$i6577 = $start$0$i$i;
         while(1) {
          $922 = HEAP16[$start$0$i$i6577>>1]|0;
          $923 = $922&65535;
          $924 = Math_imul($923, $pointSize$0$i$i)|0;
          $$sum$i = (($924) + ($patchHeaderSize$0$i$i))|0;
          $925 = (($start$0$i$i6577) + ($$sum$i)|0);
          $numContacts$1$lcssa = (($numContacts$078) + ($923))|0;
          $926 = $925;
          $927 = (($926) - ($903))|0;
          $928 = ($927>>>0)<($888>>>0);
          if ($928) {
           $numContacts$078 = $numContacts$1$lcssa;$start$0$i$i6577 = $925;
          } else {
           $numContacts$0$lcssa = $numContacts$1$lcssa;
           break;
          }
         }
        }
        $929 = ($numContacts$0$lcssa|0)==(0);
        if ($929) {
         label = 78;
        }
       } else {
        label = 78;
       }
      }
      if ((label|0) == 78) {
       label = 0;
       HEAP16[$882>>1] = 0;
       $930 = ((($878) + ($881<<7)|0) + 40|0);
       $931 = ((($878) + ($881<<7)|0) + 64|0);
       HEAP32[$931>>2] = 0;
       $932 = ((($878) + ($881<<7)|0) + 72|0);
       HEAP16[$932>>1] = 0;
       $933 = ((($878) + ($881<<7)|0) + 68|0);
       HEAP32[$933>>2] = 0;
       $934 = ((($878) + ($881<<7)|0) + 60|0);
       ;HEAP32[$930+0>>2]=0|0;HEAP32[$930+4>>2]=0|0;HEAP32[$930+8>>2]=0|0;HEAP32[$930+12>>2]=0|0;HEAP32[$930+16>>2]=0|0;
       $935 = HEAP32[$934>>2]|0;
       $936 = ($935|0)==(0);
       do {
        if (!($936)) {
         $937 = $935 & 1;
         $938 = ($937|0)==(0);
         if ($938) {
          $939 = $935;
          $940 = (($939) + 33|0);
          HEAP8[$940>>0] = 0;
          $941 = (($939) + 32|0);
          HEAP8[$941>>0] = 0;
          $942 = (($939) + 16|0);
          HEAPF32[$942>>2] = Math_fround(3.40282346638528859812E+38);
          $943 = (($939) + 20|0);
          HEAPF32[$943>>2] = Math_fround(3.40282346638528859812E+38);
          $944 = (($939) + 24|0);
          HEAPF32[$944>>2] = Math_fround(3.40282346638528859812E+38);
          $945 = (($939) + 28|0);
          HEAPF32[$945>>2] = Math_fround(0.0);
          HEAPF32[$939>>2] = Math_fround(0.0);
          $946 = (($939) + 4|0);
          HEAPF32[$946>>2] = Math_fround(0.0);
          $947 = (($939) + 8|0);
          HEAPF32[$947>>2] = Math_fround(0.0);
          $948 = (($939) + 12|0);
          HEAPF32[$948>>2] = Math_fround(1.0);
          break;
         } else {
          HEAP32[$934>>2] = 1;
          break;
         }
        }
       } while(0);
       $949 = ((($878) + ($881<<7)|0) + 114|0);
       $950 = HEAP16[$949>>1]|0;
       $951 = $950&65535;
       $952 = $951 & 65531;
       $953 = $952&65535;
       HEAP16[$949>>1] = $953;
      }
      $954 = ($955|0)==(0);
      if ($954) {
       break L81;
      }
      $957 = (0 - ($955))|0;
      $958 = $955 & $957;
      $959 = Math_imul($958, 125613361)|0;
      $960 = $959 >>> 27;
      $961 = (412480 + ($960<<2)|0);
      $962 = HEAP32[$961>>2]|0;
      $872 = $962 | $873;
      $963 = (($955) + -1)|0;
      $964 = $963 & $955;
      $965 = HEAP32[$21>>2]|0;
      $966 = $965 & 2147483647;
      $967 = ($964|0)==(0);
      if ($967) {
       $969 = $$ph89146;
       break;
      }
      $956 = ($872|0)==(-1);
      if ($956) {
       break L81;
      } else {
       $955 = $964;$index2$095 = $872;
      }
     }
     while(1) {
      $968 = (($969) + 1)|0;
      $970 = ($968>>>0)<($966>>>0);
      if (!($970)) {
       $$ph = 0;
       break;
      }
      $971 = HEAP32[$20>>2]|0;
      $972 = (($971) + ($968<<2)|0);
      $973 = HEAP32[$972>>2]|0;
      $974 = ($973|0)==(0);
      if ($974) {
       $969 = $968;
      } else {
       $$ph = $973;
       break;
      }
     }
     $871 = ($872|0)==(-1);
     if ($871) {
      break;
     } else {
      $$ph89146 = $968;$$ph90147 = $$ph;$index2$0$ph91149 = $872;
     }
    }
   }
  }
 } while(0);
 if ($or$cond$i$i$i24) {
  STACKTOP = sp;return;
 }
 $975 = HEAP32[$6>>2]|0;
 $976 = (($975) + 12|0);
 $977 = HEAP32[$976>>2]|0;
 $978 = $13&65535;
 FUNCTION_TABLE_viiii[$977 & 511]($6,$978,$9,$12);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext23prepareCMDiscreteUpdateEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$$i$i$i$i = 0, $$pre = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $rv$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 224|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN5physx6shdfnd9SListImpl3popEv($2)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__Z15PxGetFoundationv()|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
  $$$i$i$i$i = $13 ? 490928 : 489216;
  $14 = (FUNCTION_TABLE_iiiiii[$8 & 255]($5,9459,$$$i$i$i$i,490824,82)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $rv$0$i = 0;
  } else {
   $16 = (($14) + 19|0);
   $17 = $16;
   $18 = $17 & -16;
   $19 = $14;
   $20 = (($18) - ($19))|0;
   $21 = $18;
   $22 = (($21) + -4|0);
   HEAP32[$22>>2] = $20;
   $23 = $18;
   $24 = ($18|0)==(0);
   if ($24) {
    $rv$0$i = $23;
   } else {
    __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($23,$this);
    $rv$0$i = $23;
   }
  }
 } else {
  $rv$0$i = $3;
 }
 $25 = (($this) + 6748|0);
 HEAP32[$25>>2] = $rv$0$i;
 $26 = (($this) + 1344|0);
 $27 = (($this) + 1336|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 & 134217727;
 $30 = (($this) + 1348|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 & 2147483647;
 $33 = ($29>>>0)>($32>>>0);
 if ($33) {
  $34 = (($this) + 1352|0);
  $35 = $29 << 2;
  $36 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($34,$35,490328,339)|0);
  $37 = HEAP32[$26>>2]|0;
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   $39 = HEAP32[$30>>2]|0;
   $40 = $39 << 2;
   _memcpy(($36|0),($37|0),($40|0))|0;
   $41 = HEAP32[$30>>2]|0;
   $42 = ($41|0)>(-1);
   if ($42) {
    $43 = HEAP32[$26>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($34,$43);
   }
  }
  $44 = HEAP32[$30>>2]|0;
  $45 = $44 & 2147483647;
  $46 = (($36) + ($45<<2)|0);
  $47 = (($29) - ($44))|0;
  $48 = $47 << 2;
  _memset(($46|0),0,($48|0))|0;
  HEAP32[$26>>2] = $36;
  HEAP32[$30>>2] = $29;
  $$pre = HEAP32[$25>>2]|0;
  $52 = $$pre;$83 = $29;
 } else {
  $52 = $rv$0$i;$83 = $31;
 }
 $49 = (($this) + 7372|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($52) + 8776|0);
 HEAP32[$51>>2] = $50;
 $53 = (($this) + 7376|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = (($52) + 8784|0);
 HEAP8[$55>>0] = $54;
 $56 = (($this) + 7378|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = (($52) + 8787|0);
 HEAP8[$58>>0] = $57;
 $59 = (($this) + 7377|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = (($52) + 8785|0);
 HEAP8[$61>>0] = $60;
 $62 = HEAP8[$53>>0]|0;
 $63 = ($62<<24>>24)==(0);
 $64 = (($this) + 44|0);
 $65 = (($this) + 1368|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($this) + 1372|0);
 $68 = HEAP32[$67>>2]|0;
 if ($63) {
  $89 = (($this) + 1380|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($this) + 1384|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (($this) + 1392|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (($this) + 1396|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (($this) + 1404|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = (($this) + 1408|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($this) + 1416|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($this) + 1420|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($this) + 1428|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($this) + 1432|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = HEAP32[$26>>2]|0;
  $110 = $83 & 2147483647;
  $111 = (($this) + 6740|0);
  $112 = (($this) + 6744|0);
  $113 = (($this) + 6700|0);
  $114 = (($this) + 6732|0);
  $115 = HEAP32[$114>>2]|0;
  __ZN5physx13PxcRunNpBatchEjjjjjPNS_16PxsThreadContextERNS_17PxcNpMemBlockPoolEjjPNS_15PxcNpBatchEntryEjS5_jS5_jS5_jS5_jS5_jPjjRjS7_PNS_14PxLightCpuTaskERNS_2Cm9FlushPoolE(0,0,0,0,0,$52,$64,0,0,$66,$68,$90,$92,$94,$96,$98,$100,$102,$104,$106,$108,$109,$110,$111,$112,$113,$115);
  $116 = (($this) + 6700|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = (($117) + 20|0);
  $119 = HEAP32[$118>>2]|0;
  FUNCTION_TABLE_vi[$119 & 4095]($116);
  STACKTOP = sp;return;
 } else {
  $69 = (($this) + 1392|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($this) + 1396|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($this) + 1404|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($this) + 1408|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($this) + 1428|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($this) + 1432|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = HEAP32[$26>>2]|0;
  $82 = $83 & 2147483647;
  $84 = (($this) + 6740|0);
  $85 = (($this) + 6744|0);
  $86 = (($this) + 6700|0);
  $87 = (($this) + 6732|0);
  $88 = HEAP32[$87>>2]|0;
  __ZN5physx16PxcRunNpPCMBatchEjjjPNS_16PxsThreadContextERNS_17PxcNpMemBlockPoolEjjPNS_15PxcNpBatchEntryEjS5_jS5_jS5_jPjjRjS7_PNS_14PxLightCpuTaskERNS_2Cm9FlushPoolE(0,0,0,$52,$64,0,0,$66,$68,$70,$72,$74,$76,$78,$80,$81,$82,$84,$85,$86,$88);
  $116 = (($this) + 6700|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = (($117) + 20|0);
  $119 = HEAP32[$118>>2]|0;
  FUNCTION_TABLE_vi[$119 & 4095]($116);
  STACKTOP = sp;return;
 }
}
function __ZN5physx10PxsContext11swapStreamsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 __ZN5physx17PxcNpMemBlockPool18swapNpCacheStreamsEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$pn = 0, $$pre = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond11 = 0, $i$07 = 0, $inEnabled$not$i$i$i3 = 0, $j1$06 = 0, $np$01$i$i = 0;
 var $or$cond$i$i$i4 = 0, $threadContext$09$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 6748|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 224|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($4,$2);
 $5 = (($this) + 6736|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAPU16[545720>>1]|(HEAPU16[545720+2>>1]<<16);
 $16 = $15 & 16711680;
 $inEnabled$not$i$i$i3 = ($16|0)==(0);
 $17 = ($8|0)==(0|0);
 $or$cond$i$i$i4 = $17 | $inEnabled$not$i$i$i3;
 if (!($or$cond$i$i$i4)) {
  $18 = $15&65535;
  $19 = HEAP32[$8>>2]|0;
  $20 = (($19) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_viiii[$21 & 511]($8,$18,$11,$14);
 }
 $22 = (($this) + 6740|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 1356|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 HEAP32[$24>>2] = $26;
 $27 = (($this) + 6744|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 1360|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + ($28))|0;
 HEAP32[$29>>2] = $31;
 $32 = HEAP32[$3>>2]|0;
 $33 = (__ZN5physx6shdfnd9SListImpl5flushEv($32)|0);
 $34 = (($this) + 7340|0);
 HEAP32[$34>>2] = 0;
 $35 = ($33|0)==(0|0);
 do {
  if (!($35)) {
   $36 = ($33|0)==(0|0);
   if ($36) {
    $np$01$i$i = $33;
   } else {
    $37 = (($this) + 7360|0);
    $38 = (($this) + 7364|0);
    $39 = (($this) + 1344|0);
    $$pn = $33;$threadContext$09$in = $33;
    while(1) {
     $40 = HEAP32[$$pn>>2]|0;
     $41 = (($threadContext$09$in) + 9396|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = HEAP32[$24>>2]|0;
     $44 = (($43) + ($42))|0;
     HEAP32[$24>>2] = $44;
     $45 = (($threadContext$09$in) + 9392|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = HEAP32[$29>>2]|0;
     $48 = (($47) + ($46))|0;
     HEAP32[$29>>2] = $48;
     $i$07 = 0;
     while(1) {
      $49 = ((($threadContext$09$in) + (($i$07*28)|0)|0) + 120|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ((($this) + (($i$07*28)|0)|0) + 6752|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + ($50))|0;
      HEAP32[$51>>2] = $53;
      $54 = ((($threadContext$09$in) + (($i$07*28)|0)|0) + 124|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ((($this) + (($i$07*28)|0)|0) + 6756|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($57) + ($55))|0;
      HEAP32[$56>>2] = $58;
      $59 = ((($threadContext$09$in) + (($i$07*28)|0)|0) + 128|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ((($this) + (($i$07*28)|0)|0) + 6760|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = (($62) + ($60))|0;
      HEAP32[$61>>2] = $63;
      $64 = ((($threadContext$09$in) + (($i$07*28)|0)|0) + 132|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = ((($this) + (($i$07*28)|0)|0) + 6764|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + ($65))|0;
      HEAP32[$66>>2] = $68;
      $69 = ((($threadContext$09$in) + (($i$07*28)|0)|0) + 136|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ((($this) + (($i$07*28)|0)|0) + 6768|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($72) + ($70))|0;
      HEAP32[$71>>2] = $73;
      $74 = ((($threadContext$09$in) + (($i$07*28)|0)|0) + 140|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ((($this) + (($i$07*28)|0)|0) + 6772|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + ($75))|0;
      HEAP32[$76>>2] = $78;
      $79 = ((($threadContext$09$in) + (($i$07*28)|0)|0) + 144|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ((($this) + (($i$07*28)|0)|0) + 6776|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($82) + ($80))|0;
      HEAP32[$81>>2] = $83;
      $$pre = HEAP32[$34>>2]|0;
      $87 = $$pre;$j1$06 = $i$07;
      while(1) {
       $84 = (((($threadContext$09$in) + (($i$07*28)|0)|0) + ($j1$06<<2)|0) + 120|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = (($87) + ($85))|0;
       HEAP32[$34>>2] = $86;
       $88 = (($j1$06) + 1)|0;
       $exitcond = ($88|0)==(7);
       if ($exitcond) {
        break;
       } else {
        $87 = $86;$j1$06 = $88;
       }
      }
      $89 = (($i$07) + 1)|0;
      $exitcond11 = ($89|0)==(7);
      if ($exitcond11) {
       break;
      } else {
       $i$07 = $89;
      }
     }
     $90 = (($threadContext$09$in) + 16|0);
     $91 = (($threadContext$09$in) + 8788|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = HEAP32[$37>>2]|0;
     $94 = (($93) + ($92))|0;
     HEAP32[$37>>2] = $94;
     $95 = (($threadContext$09$in) + 8792|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = HEAP32[$38>>2]|0;
     $98 = (($97) + ($96))|0;
     HEAP32[$38>>2] = $98;
     __ZN5physx18PxcNpThreadContext10clearStatsEv($90);
     $99 = (($threadContext$09$in) + 9380|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = (($threadContext$09$in) + 9384|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = $102 & 2147483647;
     __ZN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEE8combine1INS4_2OREEEvPKjj($39,$100,$103);
     $104 = ($40|0)==(0|0);
     if ($104) {
      break;
     }
     $105 = ($40|0)==(0|0);
     if ($105) {
      break;
     } else {
      $$pn = $40;$threadContext$09$in = $40;
     }
    }
    if ($35) {
     break;
    } else {
     $np$01$i$i = $33;
    }
   }
   while(1) {
    $106 = HEAP32[$np$01$i$i>>2]|0;
    $107 = HEAP32[$3>>2]|0;
    __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($107,$np$01$i$i);
    $108 = ($106|0)==(0|0);
    if ($108) {
     break;
    } else {
     $np$01$i$i = $106;
    }
   }
  }
 } while(0);
 if ($or$cond$i$i$i4) {
  STACKTOP = sp;return;
 }
 $109 = HEAP32[$8>>2]|0;
 $110 = (($109) + 12|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = $15&65535;
 FUNCTION_TABLE_viiii[$111 & 511]($8,$112,$11,$14);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext20updateContactManagerEfPNS_10PxBaseTaskE($this,$dt,$continuation) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $continuation = $continuation|0;
 var $$0$i4 = 0, $$0$i40 = 0, $$lcssa17 = 0, $$lcssa845 = 0, $$lcssa846 = 0, $$lcssa943 = 0, $$lcssa944 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $i$012 = 0, $inEnabled$not$i$i$i1 = 0, $index$018 = 0, $index$1$lcssa41 = 0, $index$1$lcssa42 = 0, $index$113 = 0, $or$cond = 0, $or$cond$i$i$i2 = 0, $phitmp = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 6736|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAPU16[545704>>1]|(HEAPU16[545704+2>>1]<<16);
 $11 = $10 & 16711680;
 $inEnabled$not$i$i$i1 = ($11|0)==(0);
 $12 = ($3|0)==(0|0);
 $or$cond$i$i$i2 = $12 | $inEnabled$not$i$i$i1;
 if (!($or$cond$i$i$i2)) {
  $13 = $10&65535;
  $14 = HEAP32[$3>>2]|0;
  $15 = (($14) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiii[$16 & 511]($3,$13,$6,$9);
 }
 $17 = (($this) + 1348|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 1344|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $18 << 2;
 _memset(($20|0),0,($21|0))|0;
 $22 = (($this) + 1356|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 1360|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 1364|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 6716|0);
 HEAP32[$25>>2] = 1;
 $26 = (($this) + 6712|0);
 HEAP32[$26>>2] = $continuation;
 $27 = ($continuation|0)==(0|0);
 if (!($27)) {
  $28 = HEAP32[$continuation>>2]|0;
  $29 = (($28) + 16|0);
  $30 = HEAP32[$29>>2]|0;
  FUNCTION_TABLE_vi[$30 & 4095]($continuation);
  $31 = HEAP32[$26>>2]|0;
  $32 = (($31) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($this) + 6708|0);
  HEAP32[$34>>2] = $33;
 }
 $35 = (($this) + 6672|0);
 $36 = (($this) + 6700|0);
 $37 = (($this) + 6688|0);
 HEAP32[$37>>2] = 1;
 $38 = (($this) + 6684|0);
 HEAP32[$38>>2] = $36;
 $39 = HEAP32[$36>>2]|0;
 $40 = (($39) + 16|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vi[$41 & 4095]($36);
 $42 = HEAP32[$38>>2]|0;
 $43 = (($42) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 6680|0);
 HEAP32[$45>>2] = $44;
 $46 = (($this) + 1372|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 1384|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 1396|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 1408|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 1420|0);
 HEAP32[$50>>2] = 0;
 $51 = (($this) + 1432|0);
 HEAP32[$51>>2] = 0;
 $52 = (($this) + 1332|0);
 $53 = (($this) + 1336|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 & 2147483647;
 $56 = ($55|0)==(0);
 L7: do {
  if ($56) {
   $$0$i4 = -1;$166 = 0;$167 = 0;
  } else {
   $$pre$i$i$i = HEAP32[$52>>2]|0;
   $58 = 0;
   while(1) {
    $57 = (($$pre$i$i$i) + ($58<<2)|0);
    $59 = HEAP32[$57>>2]|0;
    $60 = ($59|0)==(0);
    if (!($60)) {
     break;
    }
    $61 = (($58) + 1)|0;
    $62 = ($61>>>0)<($55>>>0);
    if ($62) {
     $58 = $61;
    } else {
     $$0$i4 = -1;$166 = $61;$167 = 0;
     break L7;
    }
   }
   $63 = $58 << 5;
   $64 = (0 - ($59))|0;
   $65 = $59 & $64;
   $66 = Math_imul($65, 125613361)|0;
   $67 = $66 >>> 27;
   $68 = (412480 + ($67<<2)|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = $69 | $63;
   $71 = (($59) + -1)|0;
   $72 = $71 & $59;
   $73 = ($72|0)==(0);
   if ($73) {
    $75 = $58;
    while(1) {
     $74 = (($75) + 1)|0;
     $76 = ($74>>>0)<($55>>>0);
     if (!($76)) {
      $$0$i4 = $70;$166 = $74;$167 = 0;
      break L7;
     }
     $77 = (($$pre$i$i$i) + ($74<<2)|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ($78|0)==(0);
     if ($79) {
      $75 = $74;
     } else {
      $$0$i4 = $70;$166 = $74;$167 = $78;
      break;
     }
    }
   } else {
    $$0$i4 = $70;$166 = $58;$167 = $72;
   }
  }
 } while(0);
 $80 = (($this) + 6732|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = HEAP32[$81>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($82);
 $83 = ($$0$i4|0)==(-1);
 $84 = HEAP32[$80>>2]|0;
 if ($83) {
  $$lcssa17 = $84;
 } else {
  $85 = (($this) + 708|0);
  $86 = (($this) + 720|0);
  $87 = (($this) + 696|0);
  $168 = $167;$169 = $166;$88 = $84;$index$018 = $$0$i4;
  while(1) {
   $89 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($88,160,16)|0);
   $90 = ($89|0)==(0|0);
   if ($90) {
    $102 = 0;
   } else {
    $91 = (($89) + 4|0);
    HEAP16[$91>>1] = -1;
    $92 = (($89) + 6|0);
    HEAP16[$92>>1] = 0;
    $93 = (($89) + 8|0);
    HEAP32[$93>>2] = 0;
    HEAP32[$89>>2] = ((434896 + 8|0));
    $94 = (($89) + 12|0);
    HEAP32[$94>>2] = 0;
    $95 = (($89) + 16|0);
    HEAP32[$95>>2] = 0;
    $96 = (($89) + 148|0);
    HEAP32[$96>>2] = 0;
    $97 = (($89) + 152|0);
    HEAPF32[$97>>2] = $dt;
    $98 = (($89) + 156|0);
    HEAP32[$98>>2] = $this;
    $99 = (($89) + 20|0);
    dest=$99+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
    HEAP32[$89>>2] = ((491256 + 8|0));
    $102 = $89;
   }
   $100 = ($index$018|0)==(-1);
   if ($100) {
    $$lcssa846 = $169;$$lcssa944 = $168;$index$1$lcssa42 = -1;
    label = 25;
   } else {
    $101 = (($102) + 148|0);
    $117 = $168;$119 = $169;$i$012 = 0;$index$113 = $index$018;
    while(1) {
     $103 = HEAP32[$85>>2]|0;
     $104 = $index$113 >>> $103;
     $105 = HEAP32[$86>>2]|0;
     $106 = (($105) + ($104<<2)|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = HEAP32[$87>>2]|0;
     $109 = (($108) + -1)|0;
     $110 = $109 & $index$113;
     $111 = (($107) + ($110<<7)|0);
     $112 = HEAP32[$101>>2]|0;
     $113 = (($112) + 1)|0;
     HEAP32[$101>>2] = $113;
     $114 = ((($102) + ($112<<2)|0) + 20|0);
     HEAP32[$114>>2] = $111;
     $115 = (($i$012) + 1)|0;
     $116 = ($117|0)==(0);
     if ($116) {
      $$0$i40 = -1;$170 = 0;$171 = $119;
      break;
     }
     $118 = $119 << 5;
     $120 = (0 - ($117))|0;
     $121 = $117 & $120;
     $122 = Math_imul($121, 125613361)|0;
     $123 = $122 >>> 27;
     $124 = (412480 + ($123<<2)|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = $125 | $118;
     $127 = (($117) + -1)|0;
     $128 = $127 & $117;
     $129 = HEAP32[$53>>2]|0;
     $130 = $129 & 2147483647;
     $131 = ($128|0)==(0);
     L29: do {
      if ($131) {
       $133 = $119;
       while(1) {
        $132 = (($133) + 1)|0;
        $134 = ($132>>>0)<($130>>>0);
        if (!($134)) {
         $172 = $132;$173 = 0;
         break L29;
        }
        $135 = HEAP32[$52>>2]|0;
        $136 = (($135) + ($132<<2)|0);
        $137 = HEAP32[$136>>2]|0;
        $138 = ($137|0)==(0);
        if ($138) {
         $133 = $132;
        } else {
         $172 = $132;$173 = $137;
         break;
        }
       }
      } else {
       $172 = $119;$173 = $128;
      }
     } while(0);
     $139 = ($115>>>0)>(31);
     $140 = ($126|0)==(-1);
     $or$cond = $139 | $140;
     if ($or$cond) {
      $$0$i40 = $126;$170 = $173;$171 = $172;
      break;
     } else {
      $117 = $173;$119 = $172;$i$012 = $115;$index$113 = $126;
     }
    }
    $phitmp = ($115|0)==(0);
    if ($phitmp) {
     $$lcssa846 = $171;$$lcssa944 = $170;$index$1$lcssa42 = $$0$i40;
     label = 25;
    } else {
     $141 = (($102) + 16|0);
     HEAP32[$141>>2] = 1;
     $142 = (($102) + 12|0);
     HEAP32[$142>>2] = $35;
     $143 = HEAP32[$35>>2]|0;
     $144 = (($143) + 16|0);
     $145 = HEAP32[$144>>2]|0;
     FUNCTION_TABLE_vi[$145 & 4095]($35);
     $146 = HEAP32[$142>>2]|0;
     $147 = (($146) + 8|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = (($102) + 8|0);
     HEAP32[$149>>2] = $148;
     $150 = HEAP32[$102>>2]|0;
     $151 = (($150) + 20|0);
     $152 = HEAP32[$151>>2]|0;
     FUNCTION_TABLE_vi[$152 & 4095]($102);
     $$lcssa845 = $171;$$lcssa943 = $170;$index$1$lcssa41 = $$0$i40;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    $153 = HEAP32[$102>>2]|0;
    $154 = (($153) + 28|0);
    $155 = HEAP32[$154>>2]|0;
    FUNCTION_TABLE_vi[$155 & 4095]($102);
    $$lcssa845 = $$lcssa846;$$lcssa943 = $$lcssa944;$index$1$lcssa41 = $index$1$lcssa42;
   }
   $156 = ($index$1$lcssa41|0)==(-1);
   $157 = HEAP32[$80>>2]|0;
   if ($156) {
    $$lcssa17 = $157;
    break;
   } else {
    $168 = $$lcssa943;$169 = $$lcssa845;$88 = $157;$index$018 = $index$1$lcssa41;
   }
  }
 }
 $158 = HEAP32[$$lcssa17>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($158);
 $159 = HEAP32[$35>>2]|0;
 $160 = (($159) + 20|0);
 $161 = HEAP32[$160>>2]|0;
 FUNCTION_TABLE_vi[$161 & 4095]($35);
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return;
 }
 $162 = HEAP32[$3>>2]|0;
 $163 = (($162) + 12|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = $10&65535;
 FUNCTION_TABLE_viiii[$164 & 511]($3,$165,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext30secondPassUpdateContactManagerEfPNS_25NarrowPhaseContactManagerEjPNS_10PxBaseTaskE($this,$dt,$contactManagers,$numContactManagers,$continuation) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $contactManagers = $contactManagers|0;
 $numContactManagers = $numContactManagers|0;
 $continuation = $continuation|0;
 var $$op = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$03 = 0, $count$1 = 0, $exitcond = 0, $i$05 = 0, $inEnabled$not$i$i$i1 = 0, $j$04 = 0, $np$01$i$i$i = 0, $or$cond$i$i$i2 = 0, $threadContext$03$in$i = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 6736|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAPU16[545704>>1]|(HEAPU16[545704+2>>1]<<16);
 $11 = $10 & 16711680;
 $inEnabled$not$i$i$i1 = ($11|0)==(0);
 $12 = ($3|0)==(0|0);
 $or$cond$i$i$i2 = $12 | $inEnabled$not$i$i$i1;
 if (!($or$cond$i$i$i2)) {
  $13 = $10&65535;
  $14 = HEAP32[$3>>2]|0;
  $15 = (($14) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiii[$16 & 511]($3,$13,$6,$9);
 }
 $17 = (($this) + 1348|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 1344|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $18 << 2;
 _memset(($20|0),0,($21|0))|0;
 $22 = (($this) + 1356|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 1360|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 1364|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 224|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (__ZN5physx6shdfnd9SListImpl5flushEv($26)|0);
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = (($this) + 5920|0);
  $threadContext$03$in$i = $27;
  while(1) {
   $30 = HEAP32[$threadContext$03$in$i>>2]|0;
   $31 = HEAP32[$29>>2]|0;
   $32 = $31 << 5;
   $33 = HEAP32[$17>>2]|0;
   $34 = $33 << 5;
   __ZN5physx16PxsThreadContext5resetEjj($threadContext$03$in$i,$32,$34);
   $35 = ($30|0)==(0|0);
   if ($35) {
    $np$01$i$i$i = $27;
    break;
   } else {
    $threadContext$03$in$i = $30;
   }
  }
  while(1) {
   $36 = HEAP32[$np$01$i$i$i>>2]|0;
   $37 = HEAP32[$25>>2]|0;
   __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($37,$np$01$i$i$i);
   $38 = ($36|0)==(0|0);
   if ($38) {
    break;
   } else {
    $np$01$i$i$i = $36;
   }
  }
 }
 $39 = (($this) + 6716|0);
 HEAP32[$39>>2] = 1;
 $40 = (($this) + 6712|0);
 HEAP32[$40>>2] = $continuation;
 $41 = ($continuation|0)==(0|0);
 if (!($41)) {
  $42 = HEAP32[$continuation>>2]|0;
  $43 = (($42) + 16|0);
  $44 = HEAP32[$43>>2]|0;
  FUNCTION_TABLE_vi[$44 & 4095]($continuation);
  $45 = HEAP32[$40>>2]|0;
  $46 = (($45) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($this) + 6708|0);
  HEAP32[$48>>2] = $47;
 }
 $49 = (($this) + 6672|0);
 $50 = (($this) + 6700|0);
 $51 = (($this) + 6688|0);
 HEAP32[$51>>2] = 1;
 $52 = (($this) + 6684|0);
 HEAP32[$52>>2] = $50;
 $53 = HEAP32[$50>>2]|0;
 $54 = (($53) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 FUNCTION_TABLE_vi[$55 & 4095]($50);
 $56 = HEAP32[$52>>2]|0;
 $57 = (($56) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 6680|0);
 HEAP32[$59>>2] = $58;
 $60 = (($this) + 1372|0);
 HEAP32[$60>>2] = 0;
 $61 = (($this) + 1384|0);
 HEAP32[$61>>2] = 0;
 $62 = (($this) + 1396|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 1408|0);
 HEAP32[$63>>2] = 0;
 $64 = (($this) + 1420|0);
 HEAP32[$64>>2] = 0;
 $65 = (($this) + 1432|0);
 HEAP32[$65>>2] = 0;
 $66 = ($numContactManagers|0)==(0);
 if (!($66)) {
  $67 = (($this) + 6732|0);
  $68 = $numContactManagers ^ -1;
  $i$05 = 0;
  while(1) {
   $69 = HEAP32[$67>>2]|0;
   $70 = HEAP32[$69>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($70);
   $71 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($69,160,16)|0);
   $72 = HEAP32[$69>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($72);
   $73 = ($71|0)==(0|0);
   if ($73) {
    $89 = 0;
   } else {
    $74 = (($71) + 4|0);
    HEAP16[$74>>1] = -1;
    $75 = (($71) + 6|0);
    HEAP16[$75>>1] = 0;
    $76 = (($71) + 8|0);
    HEAP32[$76>>2] = 0;
    HEAP32[$71>>2] = ((434896 + 8|0));
    $77 = (($71) + 12|0);
    HEAP32[$77>>2] = 0;
    $78 = (($71) + 16|0);
    HEAP32[$78>>2] = 0;
    $79 = (($71) + 148|0);
    HEAP32[$79>>2] = 0;
    $80 = (($71) + 152|0);
    HEAPF32[$80>>2] = $dt;
    $81 = (($71) + 156|0);
    HEAP32[$81>>2] = $this;
    $82 = (($71) + 20|0);
    dest=$82+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
    HEAP32[$71>>2] = ((491256 + 8|0));
    $89 = $71;
   }
   $83 = (($numContactManagers) - ($i$05))|0;
   $84 = ($83>>>0)>(32);
   $85 = $84 ? 32 : $83;
   $86 = ($85|0)==(0);
   if ($86) {
    $87 = (($85) + ($i$05))|0;
    $128 = $87;
    label = 21;
   } else {
    $88 = (($89) + 148|0);
    $90 = (($i$05) + ($68))|0;
    $91 = ($90>>>0)>(4294967263);
    $$op = $90 ^ -1;
    $92 = $91 ? $$op : 32;
    $count$03 = 0;$j$04 = 0;
    while(1) {
     $93 = (($j$04) + ($i$05))|0;
     $94 = (($contactManagers) + ($93<<3)|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($95|0)==(0|0);
     if ($96) {
      $count$1 = $count$03;
     } else {
      $97 = HEAP32[$88>>2]|0;
      $98 = (($97) + 1)|0;
      HEAP32[$88>>2] = $98;
      $99 = ((($89) + ($97<<2)|0) + 20|0);
      HEAP32[$99>>2] = $95;
      $100 = (($count$03) + 1)|0;
      $count$1 = $100;
     }
     $101 = (($j$04) + 1)|0;
     $exitcond = ($101|0)==($92|0);
     if ($exitcond) {
      break;
     } else {
      $count$03 = $count$1;$j$04 = $101;
     }
    }
    $102 = (($85) + ($i$05))|0;
    $103 = ($count$1|0)==(0);
    if ($103) {
     $128 = $102;
     label = 21;
    } else {
     $104 = (($89) + 16|0);
     HEAP32[$104>>2] = 1;
     $105 = (($89) + 12|0);
     HEAP32[$105>>2] = $49;
     $106 = HEAP32[$49>>2]|0;
     $107 = (($106) + 16|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$108 & 4095]($49);
     $109 = HEAP32[$105>>2]|0;
     $110 = (($109) + 8|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = (($89) + 8|0);
     HEAP32[$112>>2] = $111;
     $113 = HEAP32[$89>>2]|0;
     $114 = (($113) + 20|0);
     $115 = HEAP32[$114>>2]|0;
     FUNCTION_TABLE_vi[$115 & 4095]($89);
     $120 = $102;
    }
   }
   if ((label|0) == 21) {
    label = 0;
    $116 = HEAP32[$89>>2]|0;
    $117 = (($116) + 28|0);
    $118 = HEAP32[$117>>2]|0;
    FUNCTION_TABLE_vi[$118 & 4095]($89);
    $120 = $128;
   }
   $119 = ($120>>>0)<($numContactManagers>>>0);
   if ($119) {
    $i$05 = $120;
   } else {
    break;
   }
  }
 }
 $121 = HEAP32[$49>>2]|0;
 $122 = (($121) + 20|0);
 $123 = HEAP32[$122>>2]|0;
 FUNCTION_TABLE_vi[$123 & 4095]($49);
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return;
 }
 $124 = HEAP32[$3>>2]|0;
 $125 = (($124) + 12|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = $10&65535;
 FUNCTION_TABLE_viiii[$126 & 511]($3,$127,$6,$9);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext19resetThreadContextsEv($this) {
 $this = $this|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $np$01$i$i = 0, $threadContext$03$in = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 224|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx6shdfnd9SListImpl5flushEv($1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)==(0|0);
 if ($4) {
  $np$01$i$i = $2;
 } else {
  $5 = (($this) + 5920|0);
  $6 = (($this) + 1348|0);
  $$pn = $2;$threadContext$03$in = $2;
  while(1) {
   $7 = HEAP32[$$pn>>2]|0;
   $8 = HEAP32[$5>>2]|0;
   $9 = $8 << 5;
   $10 = HEAP32[$6>>2]|0;
   $11 = $10 << 5;
   __ZN5physx16PxsThreadContext5resetEjj($threadContext$03$in,$9,$11);
   $12 = ($7|0)==(0|0);
   if ($12) {
    break;
   }
   $13 = ($7|0)==(0|0);
   if ($13) {
    break;
   } else {
    $$pn = $7;$threadContext$03$in = $7;
   }
  }
  if ($3) {
   STACKTOP = sp;return;
  } else {
   $np$01$i$i = $2;
  }
 }
 while(1) {
  $14 = HEAP32[$np$01$i$i>>2]|0;
  $15 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($15,$np$01$i$i);
  $16 = ($14|0)==(0|0);
  if ($16) {
   break;
  } else {
   $np$01$i$i = $14;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx10PxsContext25getManagerTouchEventCountEPiS1_S1_($this,$newTouch,$lostTouch,$ccdTouch) {
 $this = $this|0;
 $newTouch = $newTouch|0;
 $lostTouch = $lostTouch|0;
 $ccdTouch = $ccdTouch|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($newTouch|0)==(0|0);
 if (!($0)) {
  $1 = (($this) + 1360|0);
  $2 = HEAP32[$1>>2]|0;
  HEAP32[$newTouch>>2] = $2;
 }
 $3 = ($lostTouch|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 1356|0);
  $5 = HEAP32[$4>>2]|0;
  HEAP32[$lostTouch>>2] = $5;
 }
 $6 = ($ccdTouch|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return 1;
 }
 $7 = (($this) + 1364|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$ccdTouch>>2] = $8;
 STACKTOP = sp;return 1;
}
function __ZN5physx10PxsContext22fillManagerTouchEventsEPNS_27PxvContactManagerTouchEventERiS2_S3_S2_S3_($this,$newTouch,$newTouchCount,$lostTouch,$lostTouchCount,$ccdTouch,$ccdTouchCount) {
 $this = $this|0;
 $newTouch = $newTouch|0;
 $newTouchCount = $newTouchCount|0;
 $lostTouch = $lostTouch|0;
 $lostTouchCount = $lostTouchCount|0;
 $ccdTouch = $ccdTouch|0;
 $ccdTouchCount = $ccdTouchCount|0;
 var $$0$lcssa = 0, $$0$ph1137 = 0, $$0$ph55 = 0, $$01$ph1030 = 0, $$01$ph1036 = 0, $$01$ph54 = 0, $$02$ph43 = 0, $$02$ph53 = 0, $$026 = 0, $$ph551 = 0, $$ph652 = 0, $$ph834 = 0, $$ph935 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1344|0);
 $1 = (($this) + 1348|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0$lcssa = $newTouch;$$01$ph1030 = $lostTouch;$$02$ph43 = $ccdTouch;
  } else {
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $6 = 0;
   while(1) {
    $5 = (($$pre$i$i$i) + ($6<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0);
    if (!($8)) {
     break;
    }
    $9 = (($6) + 1)|0;
    $10 = ($9>>>0)<($3>>>0);
    if ($10) {
     $6 = $9;
    } else {
     $$0$lcssa = $newTouch;$$01$ph1030 = $lostTouch;$$02$ph43 = $ccdTouch;
     break L1;
    }
   }
   $11 = (($this) + 708|0);
   $12 = (($this) + 720|0);
   $13 = (($this) + 696|0);
   $$0$ph55 = $newTouch;$$01$ph54 = $lostTouch;$$02$ph53 = $ccdTouch;$$ph551 = $6;$$ph652 = $7;
   while(1) {
    $$0$ph1137 = $$0$ph55;$$01$ph1036 = $$01$ph54;$$ph834 = $$ph551;$$ph935 = $$ph652;
    L9: while(1) {
     $$026 = $$0$ph1137;$15 = $$ph834;$17 = $$ph935;
     while(1) {
      $14 = $15 << 5;
      $16 = (0 - ($17))|0;
      $18 = $17 & $16;
      $19 = Math_imul($18, 125613361)|0;
      $20 = $19 >>> 27;
      $21 = (412480 + ($20<<2)|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = $22 | $14;
      $24 = (($17) + -1)|0;
      $25 = $24 & $17;
      $26 = ($25|0)==(0);
      L13: do {
       if ($26) {
        $28 = $15;
        while(1) {
         $27 = (($28) + 1)|0;
         $29 = ($27>>>0)<($3>>>0);
         if (!($29)) {
          $56 = 0;$81 = $27;
          break L13;
         }
         $30 = HEAP32[$0>>2]|0;
         $31 = (($30) + ($27<<2)|0);
         $32 = HEAP32[$31>>2]|0;
         $33 = ($32|0)==(0);
         if ($33) {
          $28 = $27;
         } else {
          $56 = $32;$81 = $27;
          break;
         }
        }
       } else {
        $56 = $25;$81 = $15;
       }
      } while(0);
      $34 = ($23|0)==(-1);
      if ($34) {
       $$0$lcssa = $$026;$$01$ph1030 = $$01$ph1036;$$02$ph43 = $$02$ph53;
       break L1;
      }
      $35 = HEAP32[$11>>2]|0;
      $36 = $23 >>> $35;
      $37 = HEAP32[$12>>2]|0;
      $38 = (($37) + ($36<<2)|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = HEAP32[$13>>2]|0;
      $41 = (($40) + -1)|0;
      $42 = $41 & $23;
      $43 = (($39) + ($42<<7)|0);
      $44 = ((($39) + ($42<<7)|0) + 114|0);
      $45 = HEAP16[$44>>1]|0;
      $46 = $45&65535;
      $47 = $46 & 2;
      $48 = ($47|0)==(0);
      if ($48) {
       break;
      }
      $49 = $46 & 8;
      $50 = ($49|0)==(0);
      if (!($50)) {
       break L9;
      }
      HEAP32[$$026>>2] = $43;
      $51 = ((($39) + ($42<<7)|0) + 12|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (($$026) + 4|0);
      HEAP32[$53>>2] = $52;
      $54 = (($$026) + 8|0);
      $55 = ($56|0)==(0);
      if ($55) {
       $$0$lcssa = $54;$$01$ph1030 = $$01$ph1036;$$02$ph43 = $$02$ph53;
       break L1;
      } else {
       $$026 = $54;$15 = $81;$17 = $56;
      }
     }
     HEAP32[$$01$ph1036>>2] = $43;
     $64 = ((($39) + ($42<<7)|0) + 12|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (($$01$ph1036) + 4|0);
     HEAP32[$66>>2] = $65;
     $67 = (($$01$ph1036) + 8|0);
     $68 = ($56|0)==(0);
     if ($68) {
      $$0$lcssa = $$026;$$01$ph1030 = $67;$$02$ph43 = $$02$ph53;
      break L1;
     } else {
      $$0$ph1137 = $$026;$$01$ph1036 = $67;$$ph834 = $81;$$ph935 = $56;
     }
    }
    HEAP32[$$02$ph53>>2] = $43;
    $57 = ((($39) + ($42<<7)|0) + 12|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($$02$ph53) + 4|0);
    HEAP32[$59>>2] = $58;
    $60 = $46 & 65527;
    $61 = $60&65535;
    HEAP16[$44>>1] = $61;
    $62 = (($$02$ph53) + 8|0);
    $63 = ($56|0)==(0);
    if ($63) {
     $$0$lcssa = $$026;$$01$ph1030 = $$01$ph1036;$$02$ph43 = $62;
     break;
    } else {
     $$0$ph55 = $$026;$$01$ph54 = $$01$ph1036;$$02$ph53 = $62;$$ph551 = $81;$$ph652 = $56;
    }
   }
  }
 } while(0);
 $69 = $$0$lcssa;
 $70 = $newTouch;
 $71 = (($69) - ($70))|0;
 $72 = $71 >> 3;
 HEAP32[$newTouchCount>>2] = $72;
 $73 = $$01$ph1030;
 $74 = $lostTouch;
 $75 = (($73) - ($74))|0;
 $76 = $75 >> 3;
 HEAP32[$lostTouchCount>>2] = $76;
 $77 = $$02$ph43;
 $78 = $ccdTouch;
 $79 = (($77) - ($78))|0;
 $80 = $79 >> 3;
 HEAP32[$ccdTouchCount>>2] = $80;
 STACKTOP = sp;return 1;
}
function __ZN5physx10PxsContext13updateIslandsEfPNS_10PxBaseTaskE($this,$0,$continuation) {
 $this = $this|0;
 $0 = Math_fround($0);
 $continuation = $continuation|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 6176|0);
 __ZN5physx16PxsIslandManager13updateIslandsEPNS_10PxBaseTaskEj($1,$continuation,0);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext14updateDynamicsEfPNS_10PxBaseTaskERNS_18PxsMaterialManagerE($this,$dt,$continuation,$0) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $continuation = $continuation|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 44|0);
 __ZN5physx17PxcNpMemBlockPool23acquireConstraintMemoryEv($1);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx18PxsDynamicsContext6updateEfPNS_10PxBaseTaskE($3,$dt,$continuation);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext11beginUpdateEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6752|0);
 _memset(($0|0),0,620)|0;
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext14addThreadStatsERKNS_16PxsThreadContext14ThreadSimStatsE($this,$stats) {
 $this = $this|0;
 $stats = $stats|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$stats>>2]|0;
 $1 = (($this) + 7344|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0))|0;
 HEAP32[$1>>2] = $3;
 $4 = (($stats) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 7348|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5))|0;
 HEAP32[$6>>2] = $8;
 $9 = (($stats) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 7352|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($10))|0;
 HEAP32[$11>>2] = $13;
 $14 = (($stats) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 7356|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($15))|0;
 HEAP32[$16>>2] = $18;
 STACKTOP = sp;return;
}
function __ZNK5physx10PxsContext18getSolverBatchSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 148|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx10PxsContext18setSolverBatchSizeEj($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 148|0);
 HEAP32[$2>>2] = $i;
 STACKTOP = sp;return;
}
function __ZNK5physx10PxsContext25getVisualizationParameterENS_24PxVisualizationParameter4EnumE($this,$param) {
 $this = $this|0;
 $param = $param|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($this) + ($param<<2)|0) + 5992|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx10PxsContext25setVisualizationParameterENS_24PxVisualizationParameter4EnumEf($this,$param,$value) {
 $this = $this|0;
 $param = $param|0;
 $value = Math_fround($value);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($this) + ($param<<2)|0) + 5992|0);
 HEAPF32[$0>>2] = $value;
 STACKTOP = sp;return;
}
function __ZNK5physx10PxsContext27getCCDContactModifyCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx10PxsContext27setCCDContactModifyCallbackEPNS_26PxCCDContactModifyCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 84|0);
 HEAP32[$2>>2] = $c;
 STACKTOP = sp;return;
}
function __ZNK5physx10PxsContext15getCCDMaxPassesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 260|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx10PxsContext15setCCDMaxPassesEj($this,$ccdMaxPasses) {
 $this = $this|0;
 $ccdMaxPasses = $ccdMaxPasses|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 260|0);
 HEAP32[$2>>2] = $ccdMaxPasses;
 STACKTOP = sp;return;
}
function __ZNK5physx10PxsContext17getCurrentCCDPassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK5physx10PxsContext15getNumSweepHitsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx10PxsContext14updateCCDBeginEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx13PxsCCDContext14updateCCDBeginEv($1);
 STACKTOP = sp;return;
}
function __ZN5physx10PxsContext9updateCCDEfPNS_10PxBaseTaskEb($this,$dt,$continuation,$disableResweep) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $continuation = $continuation|0;
 $disableResweep = $disableResweep|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx13PxsCCDContext9updateCCDEfPNS_10PxBaseTaskEb($1,$dt,$continuation,$disableResweep);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_19PxContactModifyPairENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*80)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 489248 : 489216;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,489136,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*80)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
    $20 = (($$012$i) + 16|0);
    $21 = (($$03$i) + 16|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    HEAPF32[$20>>2] = $22;
    $23 = (($$012$i) + 20|0);
    $24 = (($$03$i) + 20|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    HEAPF32[$23>>2] = $25;
    $26 = (($$012$i) + 24|0);
    $27 = (($$03$i) + 24|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 28|0);
    $30 = (($$03$i) + 28|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 32|0);
    $33 = (($$03$i) + 32|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
    $35 = (($$012$i) + 36|0);
    $36 = (($$03$i) + 36|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 40|0);
    $39 = (($$03$i) + 40|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 44|0);
    $42 = (($$03$i) + 44|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$41>>2] = $43;
    $44 = (($$012$i) + 48|0);
    $45 = (($$03$i) + 48|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    HEAPF32[$44>>2] = $46;
    $47 = (($$012$i) + 52|0);
    $48 = (($$03$i) + 52|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$47>>2] = $49;
    $50 = (($$012$i) + 56|0);
    $51 = (($$03$i) + 56|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    HEAPF32[$50>>2] = $52;
    $53 = (($$012$i) + 60|0);
    $54 = (($$03$i) + 60|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    HEAPF32[$53>>2] = $55;
    $56 = (($$012$i) + 64|0);
    $57 = (($$03$i) + 64|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    HEAPF32[$56>>2] = $58;
    $59 = (($$012$i) + 68|0);
    $60 = (($$03$i) + 68|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    HEAPF32[$59>>2] = $61;
    $62 = (($$012$i) + 72|0);
    $63 = (($$03$i) + 72|0);
    $64 = $63;
    $65 = $64;
    $66 = HEAP32[$65>>2]|0;
    $67 = (($64) + 4)|0;
    $68 = $67;
    $69 = HEAP32[$68>>2]|0;
    $70 = $62;
    $71 = $70;
    HEAP32[$71>>2] = $66;
    $72 = (($70) + 4)|0;
    $73 = $72;
    HEAP32[$73>>2] = $69;
   }
   $74 = (($$012$i) + 80|0);
   $75 = (($$03$i) + 80|0);
   $76 = ($74>>>0)<($15>>>0);
   if ($76) {
    $$012$i = $74;$$03$i = $75;
   } else {
    break;
   }
  }
 }
 $77 = (($this) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)>(-1);
 if (!($79)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$77>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $80 = HEAP32[$this>>2]|0;
 $81 = ($80|0)==(0|0);
 if ($81) {
  HEAP32[$this>>2] = $16;
  HEAP32[$77>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $82 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($83) + 12|0);
 $85 = HEAP32[$84>>2]|0;
 FUNCTION_TABLE_vii[$85 & 4095]($82,$80);
 HEAP32[$this>>2] = $16;
 HEAP32[$77>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx11PxcPoolListINS_16PxsParticleShapeENS_10PxsContextEE6extendEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$$i$i1 = 0, $$0 = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $i$0 = 0, $i$03 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = ($6*52)|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__Z15PxGetFoundationv()|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
 $$$i$i = $17 ? 489464 : 489216;
 $18 = (FUNCTION_TABLE_iiiiii[$12 & 255]($9,$7,$$$i$i,489376,157)|0);
 $19 = ($18|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$1>>2]|0;
 $21 = (($20) + 1)|0;
 HEAP32[$1>>2] = $21;
 $22 = (($this) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + ($20<<2)|0);
 HEAP32[$24>>2] = $18;
 $25 = (($this) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $30 = $21;
 } else {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$26);
  $$pre = HEAP32[$1>>2]|0;
  $30 = $$pre;
 }
 $28 = HEAP32[$this>>2]|0;
 $29 = $30 << 2;
 $31 = Math_imul($29, $28)|0;
 $32 = ($31|0)==(0);
 if ($32) {
  $43 = 0;$45 = $28;$46 = $30;
 } else {
  $33 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (__Z15PxGetFoundationv()|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 24|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (FUNCTION_TABLE_ii[$40 & 4095]($37)|0);
  $$$i$i1 = $41 ? 489464 : 489216;
  $42 = (FUNCTION_TABLE_iiiiii[$36 & 255]($33,$31,$$$i$i1,489376,164)|0);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$this>>2]|0;
  $43 = $42;$45 = $$pre6;$46 = $$pre5;
 }
 HEAP32[$25>>2] = $43;
 $44 = Math_imul($45, $46)|0;
 $47 = (($44) + 31)|0;
 $48 = $47 >>> 5;
 $49 = (($this) + 36|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 2147483647;
 $52 = ($48>>>0)>($51>>>0);
 if ($52) {
  $53 = (($this) + 40|0);
  $54 = $48 << 2;
  $55 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($53,$54,490328,339)|0);
  $56 = (($this) + 32|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = HEAP32[$49>>2]|0;
   $60 = $59 << 2;
   _memcpy(($55|0),($57|0),($60|0))|0;
   $61 = HEAP32[$49>>2]|0;
   $62 = ($61|0)>(-1);
   if ($62) {
    $63 = HEAP32[$56>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($53,$63);
   }
  }
  $64 = HEAP32[$49>>2]|0;
  $65 = $64 & 2147483647;
  $66 = (($55) + ($65<<2)|0);
  $67 = (($48) - ($64))|0;
  $68 = $67 << 2;
  _memset(($66|0),0,($68|0))|0;
  HEAP32[$56>>2] = $55;
  HEAP32[$49>>2] = $48;
  $$pre7 = HEAP32[$this>>2]|0;
  $69 = $$pre7;
 } else {
  $69 = $45;
 }
 $i$03 = (($69) + -1)|0;
 $70 = ($i$03|0)>(-1);
 if (!($70)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = (($this) + 20|0);
 $72 = (($this) + 28|0);
 $i$04 = $i$03;
 while(1) {
  $73 = (($18) + (($i$04*52)|0)|0);
  $74 = ($73|0)==(0|0);
  if ($74) {
   $85 = 0;
  } else {
   $75 = HEAP32[$72>>2]|0;
   $76 = HEAP32[$1>>2]|0;
   $77 = (($76) + -1)|0;
   $78 = HEAP32[$this>>2]|0;
   $79 = Math_imul($77, $78)|0;
   $80 = (($79) + ($i$04))|0;
   __ZN5physx16PxsParticleShapeC2EPNS_10PxsContextEj($73,$75,$80);
   $85 = $73;
  }
  $81 = HEAP32[$71>>2]|0;
  $82 = (($81) + 1)|0;
  HEAP32[$71>>2] = $82;
  $83 = HEAP32[$25>>2]|0;
  $84 = (($83) + ($81<<2)|0);
  HEAP32[$84>>2] = $85;
  $i$0 = (($i$04) + -1)|0;
  $86 = ($i$0|0)>(-1);
  if ($86) {
   $i$04 = $i$0;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8PoolBaseINS_2Gu30LargePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 240)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 489584 : 489216;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,489744,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 489584 : 489216;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,489744,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 489584 : 489216;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,489136,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 489584 : 489216;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,489136,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 489584 : 489216;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,489136,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Gu31SpherePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre35 = 0, $$pre36 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0, $freeIt$2 = 0;
 var $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $phitmp = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $11 = 0;$12 = 0;$9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = ($11>>>0)>($12>>>0);
   if ($10) {
    $13 = HEAP32[$freeNodes>>2]|0;
    $14 = (($13) + ($12<<2)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     HEAP32[$14>>2] = $9;
    }
    $16 = (($12) + 1)|0;
    HEAP32[$3>>2] = $16;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$6>>2] = $18;
   $19 = ($18|0)==(0|0);
   if ($19) {
    break;
   }
   $$pre35 = HEAP32[$4>>2]|0;
   $$pre36 = HEAP32[$3>>2]|0;
   $phitmp = $$pre35 & 2147483647;
   $11 = $phitmp;$12 = $$pre36;$9 = $18;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $20 = (($$pre) + ($$pre28<<2)|0);
  $21 = (($this) + 276|0);
  $22 = HEAP32[$21>>2]|0;
  $$sum5 = (($$pre28) - ($22))|0;
  $23 = (($$pre) + ($$sum5<<2)|0);
  $24 = ($$pre28>>>0)>($22>>>0);
  if ($24) {
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($$pre,$$pre28,$1,$this);
   $25 = HEAP32[$slabNodes>>2]|0;
   $26 = (($slabNodes) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($25,$27,$2,$this);
   $28 = (($this) + 268|0);
   HEAP32[$28>>2] = 0;
   $29 = (($25) + ($27<<2)|0);
   $30 = ($27|0)==(0);
   if ($30) {
    $freeIt$3$ph = $$pre;
   } else {
    $31 = (($this) + 288|0);
    $32 = (($this) + 272|0);
    $33 = (($this) + 264|0);
    $34 = (($this) + 284|0);
    $freeIt$014 = $$pre;$slabIt$012 = $25;
    while(1) {
     $35 = ($freeIt$014>>>0)<($23>>>0);
     $36 = HEAP32[$slabIt$012>>2]|0;
     L18: do {
      if ($35) {
       $45 = $36;$freeIt$19 = $freeIt$014;
       while(1) {
        $43 = HEAP32[$freeIt$19>>2]|0;
        $44 = ($45>>>0)>($43>>>0);
        if (!($44)) {
         $54 = $45;$freeIt$1$lcssa = $freeIt$19;
         break L18;
        }
        $46 = HEAP32[$6>>2]|0;
        HEAP32[$43>>2] = $46;
        HEAP32[$6>>2] = $43;
        $47 = HEAP32[$34>>2]|0;
        $48 = (($47) + 1)|0;
        HEAP32[$34>>2] = $48;
        $49 = (($freeIt$19) + 4|0);
        $50 = ($49>>>0)<($23>>>0);
        $51 = HEAP32[$slabIt$012>>2]|0;
        if ($50) {
         $45 = $51;$freeIt$19 = $49;
        } else {
         $54 = $51;$freeIt$1$lcssa = $49;
         break;
        }
       }
      } else {
       $54 = $36;$freeIt$1$lcssa = $freeIt$014;
      }
     } while(0);
     $52 = HEAP32[$freeIt$1$lcssa>>2]|0;
     $53 = ($54|0)==($52|0);
     if ($53) {
      $55 = $54;
      $56 = HEAP32[$31>>2]|0;
      $57 = (($56) + ($55))|0;
      $58 = HEAP32[$21>>2]|0;
      $$sum = (($58) + -1)|0;
      $59 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60;
      $62 = (($61) + 96)|0;
      $63 = ($62|0)==($57|0);
      if ($63) {
       $64 = ($54|0)==(0|0);
       if ($64) {
        $70 = $58;
       } else {
        $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($66) + 12|0);
        $68 = HEAP32[$67>>2]|0;
        FUNCTION_TABLE_vii[$68 & 4095]($65,$54);
        $$pre29 = HEAP32[$21>>2]|0;
        $70 = $$pre29;
       }
       $69 = (($freeIt$1$lcssa) + ($70<<2)|0);
       $freeIt$2 = $69;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     do {
      if ((label|0) == 22) {
       label = 0;
       $71 = HEAP32[$32>>2]|0;
       $72 = $71 & 2147483647;
       $73 = HEAP32[$28>>2]|0;
       $74 = ($72>>>0)>($73>>>0);
       if (!($74)) {
        (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
        $freeIt$2 = $freeIt$1$lcssa;
        break;
       }
       $75 = HEAP32[$33>>2]|0;
       $76 = (($75) + ($73<<2)|0);
       $77 = ($76|0)==(0|0);
       if (!($77)) {
        HEAP32[$76>>2] = $54;
       }
       $78 = (($73) + 1)|0;
       HEAP32[$28>>2] = $78;
       $freeIt$2 = $freeIt$1$lcssa;
      }
     } while(0);
     $79 = (($slabIt$012) + 4|0);
     $80 = ($79|0)==($29|0);
     if ($80) {
      $freeIt$3$ph = $freeIt$2;
      break;
     } else {
      $freeIt$014 = $freeIt$2;$slabIt$012 = $79;
     }
    }
   }
  } else {
   $freeIt$3$ph = $$pre;
  }
  $37 = ($freeIt$3$ph|0)==($20|0);
  if (!($37)) {
   $freeIt$3$ph22 = $freeIt$3$ph;
   $38 = (($this) + 284|0);
   $$promoted = HEAP32[$38>>2]|0;
   $39 = (($$pre28) + -1)|0;
   $scevgep = (($$pre) + ($39<<2)|0);
   $40 = (0 - ($freeIt$3$ph22))|0;
   $uglygep = (($scevgep) + ($40)|0);
   $uglygep23 = $uglygep;
   $41 = $uglygep23 >>> 2;
   $42 = (($$promoted) + ($41))|0;
   $$pre30 = HEAP32[$6>>2]|0;
   $82 = $$pre30;$freeIt$36 = $freeIt$3$ph;
   while(1) {
    $81 = HEAP32[$freeIt$36>>2]|0;
    HEAP32[$81>>2] = $82;
    HEAP32[$6>>2] = $81;
    $83 = (($freeIt$36) + 4|0);
    $84 = ($83|0)==($20|0);
    if ($84) {
     break;
    } else {
     $82 = $81;$freeIt$36 = $83;
    }
   }
   $85 = (($42) + 1)|0;
   HEAP32[$38>>2] = $85;
  }
 }
 $86 = (($slabNodes) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i1 = $89 & $90;
 if ($or$cond$i$i1) {
  $91 = HEAP32[$slabNodes>>2]|0;
  $92 = ($91|0)==(0|0);
  if (!($92)) {
   $93 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 12|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vii[$96 & 4095]($93,$91);
  }
 }
 $97 = HEAP32[$4>>2]|0;
 $98 = $97 & 2147483647;
 $99 = ($98|0)!=(0);
 $100 = ($97|0)>(-1);
 $or$cond$i$i = $99 & $100;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $101 = HEAP32[$freeNodes>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  STACKTOP = sp;return;
 }
 $103 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 FUNCTION_TABLE_vii[$106 & 4095]($103,$101);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 489832 : 489216;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,489744,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 489832 : 489216;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,489744,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 489832 : 489216;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,489136,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 489832 : 489216;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,489136,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEE4copyINS0_15InlineAllocatorILj256ES6_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $28 = (($this) + 4|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $17 = 0;$19 = $1;
 } else {
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 489832 : 489216;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$5,$$$i$i$i,489136,558)|0);
  $$pre = HEAP32[$4>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$this>>2] = $17;
 $18 = (($17) + ($19<<2)|0);
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($other) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $$012$i = $17;$$03$i = $22;
 while(1) {
  $23 = ($$012$i|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $24;
  }
  $25 = (($$012$i) + 4|0);
  $26 = (($$03$i) + 4|0);
  $27 = ($25>>>0)<($18>>>0);
  if ($27) {
   $$012$i = $25;$$03$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Gu30LargePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 489584 : 489216;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,489992,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*240)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -240|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Gu31SpherePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $33$phi = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $14 = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i = $12 ? 489832 : 489216;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i,489992,191)|0);
  $14 = $13;
 }
 HEAP32[$0>>2] = $14;
 $15 = (($this) + 272|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 268|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($19<<2)|0);
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   HEAP32[$24>>2] = $14;
  }
  $26 = (($19) + 1)|0;
  HEAP32[$18>>2] = $26;
 } else {
  $21 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEEEE15growAndPushBackERKS2_($21,$0)|0);
 }
 $27 = (($this) + 276|0);
 $28 = HEAP32[$27>>2]|0;
 $$sum = (($28) + -1)|0;
 $29 = (($14) + (($$sum*96)|0)|0);
 $30 = ($29>>>0)<($14>>>0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 292|0);
 $32 = (($this) + 284|0);
 $$promoted = HEAP32[$32>>2]|0;
 $$pre = HEAP32[$31>>2]|0;
 $33 = $$pre;$34 = $29;$36 = $$promoted;
 while(1) {
  HEAP32[$34>>2] = $33;
  HEAP32[$31>>2] = $34;
  $35 = (($36) + 1)|0;
  $37 = (($34) + -96|0);
  $38 = ($37>>>0)<($14>>>0);
  if ($38) {
   break;
  } else {
   $33$phi = $34;$34 = $37;$36 = $35;$33 = $33$phi;
  }
 }
 HEAP32[$32>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5physx11PxcPoolListINS_17PxsContactManagerENS_10PxsContextEE6extendEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$$i$i1 = 0, $$0 = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $i$0 = 0, $i$03 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = $6 << 7;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__Z15PxGetFoundationv()|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
 $$$i$i = $17 ? 490072 : 489216;
 $18 = (FUNCTION_TABLE_iiiiii[$12 & 255]($9,$7,$$$i$i,489376,157)|0);
 $19 = ($18|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$1>>2]|0;
 $21 = (($20) + 1)|0;
 HEAP32[$1>>2] = $21;
 $22 = (($this) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + ($20<<2)|0);
 HEAP32[$24>>2] = $18;
 $25 = (($this) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $30 = $21;
 } else {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$26);
  $$pre = HEAP32[$1>>2]|0;
  $30 = $$pre;
 }
 $28 = HEAP32[$this>>2]|0;
 $29 = $30 << 2;
 $31 = Math_imul($29, $28)|0;
 $32 = ($31|0)==(0);
 if ($32) {
  $43 = 0;$45 = $28;$46 = $30;
 } else {
  $33 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (__Z15PxGetFoundationv()|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 24|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (FUNCTION_TABLE_ii[$40 & 4095]($37)|0);
  $$$i$i1 = $41 ? 490072 : 489216;
  $42 = (FUNCTION_TABLE_iiiiii[$36 & 255]($33,$31,$$$i$i1,489376,164)|0);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$this>>2]|0;
  $43 = $42;$45 = $$pre6;$46 = $$pre5;
 }
 HEAP32[$25>>2] = $43;
 $44 = Math_imul($45, $46)|0;
 $47 = (($44) + 31)|0;
 $48 = $47 >>> 5;
 $49 = (($this) + 36|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 2147483647;
 $52 = ($48>>>0)>($51>>>0);
 if ($52) {
  $53 = (($this) + 40|0);
  $54 = $48 << 2;
  $55 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($53,$54,490328,339)|0);
  $56 = (($this) + 32|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = HEAP32[$49>>2]|0;
   $60 = $59 << 2;
   _memcpy(($55|0),($57|0),($60|0))|0;
   $61 = HEAP32[$49>>2]|0;
   $62 = ($61|0)>(-1);
   if ($62) {
    $63 = HEAP32[$56>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($53,$63);
   }
  }
  $64 = HEAP32[$49>>2]|0;
  $65 = $64 & 2147483647;
  $66 = (($55) + ($65<<2)|0);
  $67 = (($48) - ($64))|0;
  $68 = $67 << 2;
  _memset(($66|0),0,($68|0))|0;
  HEAP32[$56>>2] = $55;
  HEAP32[$49>>2] = $48;
  $$pre7 = HEAP32[$this>>2]|0;
  $69 = $$pre7;
 } else {
  $69 = $45;
 }
 $i$03 = (($69) + -1)|0;
 $70 = ($i$03|0)>(-1);
 if (!($70)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = (($this) + 20|0);
 $72 = (($this) + 28|0);
 $i$04 = $i$03;
 while(1) {
  $73 = (($18) + ($i$04<<7)|0);
  $74 = ($73|0)==(0|0);
  if ($74) {
   $85 = 0;
  } else {
   $75 = HEAP32[$72>>2]|0;
   $76 = HEAP32[$1>>2]|0;
   $77 = (($76) + -1)|0;
   $78 = HEAP32[$this>>2]|0;
   $79 = Math_imul($77, $78)|0;
   $80 = (($79) + ($i$04))|0;
   __ZN5physx17PxsContactManagerC2EPNS_10PxsContextEj($73,$75,$80);
   $85 = $73;
  }
  $81 = HEAP32[$71>>2]|0;
  $82 = (($81) + 1)|0;
  HEAP32[$71>>2] = $82;
  $83 = HEAP32[$25>>2]|0;
  $84 = (($83) + ($81<<2)|0);
  HEAP32[$84>>2] = $85;
  $i$0 = (($i$04) + -1)|0;
  $86 = ($i$0|0)>(-1);
  if ($86) {
   $i$04 = $i$0;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11PxcPoolListINS_20PxsParticleSystemSimENS_10PxsContextEE6extendEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$$i$i1 = 0, $$0 = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $i$0 = 0, $i$03 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = ($6*1328)|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__Z15PxGetFoundationv()|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
 $$$i$i = $17 ? 490200 : 489216;
 $18 = (FUNCTION_TABLE_iiiiii[$12 & 255]($9,$7,$$$i$i,489376,157)|0);
 $19 = ($18|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$1>>2]|0;
 $21 = (($20) + 1)|0;
 HEAP32[$1>>2] = $21;
 $22 = (($this) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + ($20<<2)|0);
 HEAP32[$24>>2] = $18;
 $25 = (($this) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $30 = $21;
 } else {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$26);
  $$pre = HEAP32[$1>>2]|0;
  $30 = $$pre;
 }
 $28 = HEAP32[$this>>2]|0;
 $29 = $30 << 2;
 $31 = Math_imul($29, $28)|0;
 $32 = ($31|0)==(0);
 if ($32) {
  $43 = 0;$45 = $28;$46 = $30;
 } else {
  $33 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (__Z15PxGetFoundationv()|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 24|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (FUNCTION_TABLE_ii[$40 & 4095]($37)|0);
  $$$i$i1 = $41 ? 490200 : 489216;
  $42 = (FUNCTION_TABLE_iiiiii[$36 & 255]($33,$31,$$$i$i1,489376,164)|0);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$this>>2]|0;
  $43 = $42;$45 = $$pre6;$46 = $$pre5;
 }
 HEAP32[$25>>2] = $43;
 $44 = Math_imul($45, $46)|0;
 $47 = (($44) + 31)|0;
 $48 = $47 >>> 5;
 $49 = (($this) + 36|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 2147483647;
 $52 = ($48>>>0)>($51>>>0);
 if ($52) {
  $53 = (($this) + 40|0);
  $54 = $48 << 2;
  $55 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($53,$54,490328,339)|0);
  $56 = (($this) + 32|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = HEAP32[$49>>2]|0;
   $60 = $59 << 2;
   _memcpy(($55|0),($57|0),($60|0))|0;
   $61 = HEAP32[$49>>2]|0;
   $62 = ($61|0)>(-1);
   if ($62) {
    $63 = HEAP32[$56>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($53,$63);
   }
  }
  $64 = HEAP32[$49>>2]|0;
  $65 = $64 & 2147483647;
  $66 = (($55) + ($65<<2)|0);
  $67 = (($48) - ($64))|0;
  $68 = $67 << 2;
  _memset(($66|0),0,($68|0))|0;
  HEAP32[$56>>2] = $55;
  HEAP32[$49>>2] = $48;
  $$pre7 = HEAP32[$this>>2]|0;
  $69 = $$pre7;
 } else {
  $69 = $45;
 }
 $i$03 = (($69) + -1)|0;
 $70 = ($i$03|0)>(-1);
 if (!($70)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = (($this) + 20|0);
 $72 = (($this) + 28|0);
 $i$04 = $i$03;
 while(1) {
  $73 = (($18) + (($i$04*1328)|0)|0);
  $74 = ($73|0)==(0|0);
  if ($74) {
   $85 = 0;
  } else {
   $75 = HEAP32[$72>>2]|0;
   $76 = HEAP32[$1>>2]|0;
   $77 = (($76) + -1)|0;
   $78 = HEAP32[$this>>2]|0;
   $79 = Math_imul($77, $78)|0;
   $80 = (($79) + ($i$04))|0;
   __ZN5physx20PxsParticleSystemSimC2EPNS_10PxsContextEj($73,$75,$80);
   $85 = $73;
  }
  $81 = HEAP32[$71>>2]|0;
  $82 = (($81) + 1)|0;
  HEAP32[$71>>2] = $82;
  $83 = HEAP32[$25>>2]|0;
  $84 = (($83) + ($81<<2)|0);
  HEAP32[$84>>2] = $85;
  $i$0 = (($i$04) + -1)|0;
  $86 = ($i$0|0)>(-1);
  if ($86) {
   $i$04 = $i$0;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11PxcPoolListINS_16PxsParticleShapeENS_10PxsContextEE7destroyEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$06 = 0, $i1$01 = 0, $j$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($this) + 24|0);
  $$pre = HEAP32[$this>>2]|0;
  $14 = $$pre;$37 = $4;$i$06 = 0;
  while(1) {
   $10 = HEAP32[$6>>2]|0;
   $11 = (($10) + ($i$06<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($14|0)==(0);
   if ($13) {
    $38 = 0;$8 = $37;
   } else {
    $j$02 = 0;
    while(1) {
     $15 = (($12) + (($j$02*52)|0)|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     FUNCTION_TABLE_vi[$17 & 4095]($15);
     $18 = (($j$02) + 1)|0;
     $19 = HEAP32[$this>>2]|0;
     $20 = ($18>>>0)<($19>>>0);
     if ($20) {
      $j$02 = $18;
     } else {
      break;
     }
    }
    $$pre9 = HEAP32[$3>>2]|0;
    $38 = $19;$8 = $$pre9;
   }
   $21 = (($i$06) + 1)|0;
   $22 = ($21>>>0)<($8>>>0);
   if ($22) {
    $14 = $38;$37 = $8;$i$06 = $21;
   } else {
    break;
   }
  }
  $7 = ($8|0)==(0);
  if (!($7)) {
   $9 = (($this) + 24|0);
   $i1$01 = 0;
   while(1) {
    $23 = HEAP32[$9>>2]|0;
    $24 = (($23) + ($i1$01<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$25);
    $26 = HEAP32[$9>>2]|0;
    $27 = (($26) + ($i1$01<<2)|0);
    HEAP32[$27>>2] = 0;
    $28 = (($i1$01) + 1)|0;
    $29 = HEAP32[$3>>2]|0;
    $30 = ($28>>>0)<($29>>>0);
    if ($30) {
     $i1$01 = $28;
    } else {
     break;
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $31 = (($this) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$32);
 }
 HEAP32[$31>>2] = 0;
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$35);
 HEAP32[$34>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx11PxcPoolListINS_20PxsParticleSystemSimENS_10PxsContextEE7destroyEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$06 = 0, $i1$01 = 0, $j$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($this) + 24|0);
  $$pre = HEAP32[$this>>2]|0;
  $14 = $$pre;$38 = $4;$i$06 = 0;
  while(1) {
   $10 = HEAP32[$6>>2]|0;
   $11 = (($10) + ($i$06<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($14|0)==(0);
   if ($13) {
    $39 = 0;$8 = $38;
   } else {
    $j$02 = 0;
    while(1) {
     $15 = (($12) + (($j$02*1328)|0)|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($16) + 56|0);
     $18 = HEAP32[$17>>2]|0;
     FUNCTION_TABLE_vi[$18 & 4095]($15);
     $19 = (($j$02) + 1)|0;
     $20 = HEAP32[$this>>2]|0;
     $21 = ($19>>>0)<($20>>>0);
     if ($21) {
      $j$02 = $19;
     } else {
      break;
     }
    }
    $$pre9 = HEAP32[$3>>2]|0;
    $39 = $20;$8 = $$pre9;
   }
   $22 = (($i$06) + 1)|0;
   $23 = ($22>>>0)<($8>>>0);
   if ($23) {
    $14 = $39;$38 = $8;$i$06 = $22;
   } else {
    break;
   }
  }
  $7 = ($8|0)==(0);
  if (!($7)) {
   $9 = (($this) + 24|0);
   $i1$01 = 0;
   while(1) {
    $24 = HEAP32[$9>>2]|0;
    $25 = (($24) + ($i1$01<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$26);
    $27 = HEAP32[$9>>2]|0;
    $28 = (($27) + ($i1$01<<2)|0);
    HEAP32[$28>>2] = 0;
    $29 = (($i1$01) + 1)|0;
    $30 = HEAP32[$3>>2]|0;
    $31 = ($29>>>0)<($30>>>0);
    if ($31) {
     $i1$01 = $29;
    } else {
     break;
    }
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $32 = (($this) + 16|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$33);
 }
 HEAP32[$32>>2] = 0;
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$36);
 HEAP32[$35>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx22PxcThreadCoherantCacheINS_16PxsThreadContextEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $np$0$in1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN5physx6shdfnd9SListImpl3popEv($0)|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $np$0$in1 = $1;
  while(1) {
   __ZN5physx16PxsThreadContextD2Ev($np$0$in1);
   $3 = (($np$0$in1) + -4|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (0 - ($4))|0;
   $6 = (($np$0$in1) + ($5)|0);
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 12|0);
    $11 = HEAP32[$10>>2]|0;
    FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
   }
   $12 = HEAP32[$this>>2]|0;
   $13 = (__ZN5physx6shdfnd9SListImpl3popEv($12)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    break;
   } else {
    $np$0$in1 = $13;
   }
  }
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vii[$20 & 4095]($17,$15);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsThreadContextD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i2 = 0, $or$cond$i$i10 = 0, $or$cond$i$i12 = 0;
 var $or$cond$i$i13 = 0, $or$cond$i$i15 = 0, $or$cond$i$i17 = 0, $or$cond$i$i18 = 0, $or$cond$i$i20 = 0, $or$cond$i$i4 = 0, $or$cond$i$i5 = 0, $or$cond$i$i6 = 0, $or$cond$i$i8 = 0, $or$cond$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 9400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 9404|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)>(-1);
  if ($5) {
   $6 = (($this) + 9408|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$1);
  }
 }
 $7 = (($this) + 9380|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = (($this) + 9384|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)>(-1);
  if ($12) {
   $13 = (($this) + 9388|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($13,$8);
  }
 }
 $14 = (($this) + 9376|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16|0)!=(0);
 $18 = ($15|0)>(-1);
 $or$cond$i$i = $17 & $18;
 if ($or$cond$i$i) {
  $19 = (($this) + 9368|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vii[$25 & 4095]($22,$20);
  }
 }
 $26 = (($this) + 9364|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 & 2147483647;
 $29 = ($28|0)!=(0);
 $30 = ($27|0)>(-1);
 $or$cond$i$i$i = $29 & $30;
 if ($or$cond$i$i$i) {
  $31 = (($this) + 9356|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $34 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   FUNCTION_TABLE_vii[$37 & 4095]($34,$32);
  }
 }
 $38 = (($this) + 9352|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39 & 2147483647;
 $41 = ($40|0)!=(0);
 $42 = ($39|0)>(-1);
 $or$cond$i$i$i2 = $41 & $42;
 if ($or$cond$i$i$i2) {
  $43 = (($this) + 9344|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==(0|0);
  if (!($45)) {
   $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($47) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   FUNCTION_TABLE_vii[$49 & 4095]($46,$44);
  }
 }
 $50 = (($this) + 9248|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = $51 & 2147483647;
 $53 = ($52|0)!=(0);
 $54 = ($51|0)>(-1);
 $or$cond$i$i4 = $53 & $54;
 if ($or$cond$i$i4) {
  $55 = (($this) + 9240|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if (!($57)) {
   $58 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 12|0);
   $61 = HEAP32[$60>>2]|0;
   FUNCTION_TABLE_vii[$61 & 4095]($58,$56);
  }
 }
 $62 = (($this) + 9236|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = $63 & 2147483647;
 $65 = ($64|0)!=(0);
 $66 = ($63|0)>(-1);
 $or$cond$i$i5 = $65 & $66;
 if ($or$cond$i$i5) {
  $67 = (($this) + 9228|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($68|0)==(0|0);
  if (!($69)) {
   $70 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($71) + 12|0);
   $73 = HEAP32[$72>>2]|0;
   FUNCTION_TABLE_vii[$73 & 4095]($70,$68);
  }
 }
 $74 = (($this) + 9224|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = $75 & 2147483647;
 $77 = ($76|0)!=(0);
 $78 = ($75|0)>(-1);
 $or$cond$i$i6 = $77 & $78;
 if ($or$cond$i$i6) {
  $79 = (($this) + 9216|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==(0|0);
  if (!($81)) {
   $82 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($83) + 12|0);
   $85 = HEAP32[$84>>2]|0;
   FUNCTION_TABLE_vii[$85 & 4095]($82,$80);
  }
 }
 $86 = (($this) + 9212|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88|0)!=(0);
 $90 = ($87|0)>(-1);
 $or$cond$i$i8 = $89 & $90;
 if ($or$cond$i$i8) {
  $91 = (($this) + 9204|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92|0)==(0|0);
  if (!($93)) {
   $94 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($95) + 12|0);
   $97 = HEAP32[$96>>2]|0;
   FUNCTION_TABLE_vii[$97 & 4095]($94,$92);
  }
 }
 $98 = (($this) + 9200|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = $99 & 2147483647;
 $101 = ($100|0)!=(0);
 $102 = ($99|0)>(-1);
 $or$cond$i$i9 = $101 & $102;
 if ($or$cond$i$i9) {
  $103 = (($this) + 9192|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ($104|0)==(0|0);
  if (!($105)) {
   $106 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($107) + 12|0);
   $109 = HEAP32[$108>>2]|0;
   FUNCTION_TABLE_vii[$109 & 4095]($106,$104);
  }
 }
 $110 = (($this) + 9188|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = $111 & 2147483647;
 $113 = ($112|0)!=(0);
 $114 = ($111|0)>(-1);
 $or$cond$i$i10 = $113 & $114;
 if ($or$cond$i$i10) {
  $115 = (($this) + 9180|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = ($116|0)==(0|0);
  if (!($117)) {
   $118 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = (($119) + 12|0);
   $121 = HEAP32[$120>>2]|0;
   FUNCTION_TABLE_vii[$121 & 4095]($118,$116);
  }
 }
 $122 = (($this) + 9176|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = $123 & 2147483647;
 $125 = ($124|0)!=(0);
 $126 = ($123|0)>(-1);
 $or$cond$i$i12 = $125 & $126;
 if ($or$cond$i$i12) {
  $127 = (($this) + 9168|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($128|0)==(0|0);
  if (!($129)) {
   $130 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = (($131) + 12|0);
   $133 = HEAP32[$132>>2]|0;
   FUNCTION_TABLE_vii[$133 & 4095]($130,$128);
  }
 }
 $134 = (($this) + 9164|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = $135 & 2147483647;
 $137 = ($136|0)!=(0);
 $138 = ($135|0)>(-1);
 $or$cond$i$i13 = $137 & $138;
 if ($or$cond$i$i13) {
  $139 = (($this) + 9156|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = ($140|0)==(0|0);
  if (!($141)) {
   $142 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = (($143) + 12|0);
   $145 = HEAP32[$144>>2]|0;
   FUNCTION_TABLE_vii[$145 & 4095]($142,$140);
  }
 }
 $146 = (($this) + 9152|0);
 $147 = HEAP32[$146>>2]|0;
 $148 = $147 & 2147483647;
 $149 = ($148|0)!=(0);
 $150 = ($147|0)>(-1);
 $or$cond$i$i15 = $149 & $150;
 if ($or$cond$i$i15) {
  $151 = (($this) + 9144|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = ($152|0)==(0|0);
  if (!($153)) {
   $154 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = (($155) + 12|0);
   $157 = HEAP32[$156>>2]|0;
   FUNCTION_TABLE_vii[$157 & 4095]($154,$152);
  }
 }
 $158 = (($this) + 9140|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = $159 & 2147483647;
 $161 = ($160|0)!=(0);
 $162 = ($159|0)>(-1);
 $or$cond$i$i17 = $161 & $162;
 if ($or$cond$i$i17) {
  $163 = (($this) + 9132|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = ($164|0)==(0|0);
  if (!($165)) {
   $166 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = (($167) + 12|0);
   $169 = HEAP32[$168>>2]|0;
   FUNCTION_TABLE_vii[$169 & 4095]($166,$164);
  }
 }
 $170 = (($this) + 9128|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = $171 & 2147483647;
 $173 = ($172|0)!=(0);
 $174 = ($171|0)>(-1);
 $or$cond$i$i18 = $173 & $174;
 if ($or$cond$i$i18) {
  $175 = (($this) + 9120|0);
  $176 = HEAP32[$175>>2]|0;
  $177 = ($176|0)==(0|0);
  if (!($177)) {
   $178 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = (($179) + 12|0);
   $181 = HEAP32[$180>>2]|0;
   FUNCTION_TABLE_vii[$181 & 4095]($178,$176);
  }
 }
 $182 = (($this) + 9116|0);
 $183 = HEAP32[$182>>2]|0;
 $184 = $183 & 2147483647;
 $185 = ($184|0)!=(0);
 $186 = ($183|0)>(-1);
 $or$cond$i$i20 = $185 & $186;
 if (!($or$cond$i$i20)) {
  $194 = (($this) + 16|0);
  __ZN5physx18PxcNpThreadContextD2Ev($194);
  STACKTOP = sp;return;
 }
 $187 = (($this) + 9108|0);
 $188 = HEAP32[$187>>2]|0;
 $189 = ($188|0)==(0|0);
 if ($189) {
  $194 = (($this) + 16|0);
  __ZN5physx18PxcNpThreadContextD2Ev($194);
  STACKTOP = sp;return;
 }
 $190 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = (($191) + 12|0);
 $193 = HEAP32[$192>>2]|0;
 FUNCTION_TABLE_vii[$193 & 4095]($190,$188);
 $194 = (($this) + 16|0);
 __ZN5physx18PxcNpThreadContextD2Ev($194);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_23prepareCMDiscreteUpdateEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_23prepareCMDiscreteUpdateEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_23prepareCMDiscreteUpdateEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext23prepareCMDiscreteUpdateEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEE8combine1INS4_2OREEEvPKjj($this,$words,$length) {
 $this = $this|0;
 $words = $words|0;
 $length = $length|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $length & 134217727;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($0>>>0)>($3>>>0);
 if ($4) {
  $5 = (($this) + 8|0);
  $6 = $0 << 2;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,$6,490328,339)|0);
  $8 = HEAP32[$this>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = HEAP32[$1>>2]|0;
   $11 = $10 << 2;
   _memcpy(($7|0),($8|0),($11|0))|0;
   $12 = HEAP32[$1>>2]|0;
   $13 = ($12|0)>(-1);
   if ($13) {
    $14 = HEAP32[$this>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$14);
   }
  }
  $15 = HEAP32[$1>>2]|0;
  $16 = $15 & 2147483647;
  $17 = (($7) + ($16<<2)|0);
  $18 = (($0) - ($15))|0;
  $19 = $18 << 2;
  _memset(($17|0),0,($19|0))|0;
  HEAP32[$this>>2] = $7;
  HEAP32[$1>>2] = $0;
  $21 = $0;
 } else {
  $21 = $2;
 }
 $20 = $21 & 2147483647;
 $22 = ($20>>>0)<($length>>>0);
 $23 = $22 ? $20 : $length;
 $24 = ($23|0)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = $length ^ -1;
 $$not = $21 | -2147483648;
 $27 = $$not ^ 2147483647;
 $28 = ($27>>>0)<($26>>>0);
 $umax = $28 ? $26 : $27;
 $29 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $30 = (($25) + ($i$01<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($words) + ($i$01<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 | $31;
  HEAP32[$30>>2] = $34;
  $35 = (($i$01) + 1)|0;
  $exitcond = ($35|0)==($29|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $35;
  }
 }
 STACKTOP = sp;return;
}
function __ZN23PxsCMDiscreteUpdateTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN23PxsCMDiscreteUpdateTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK23PxsCMDiscreteUpdateTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (491304|0);
}
function __ZN15PxsCMUpdateTask7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 $4 = ($1|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vi[$7 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN23PxsCMDiscreteUpdateTask11runInternalEv($this) {
 $this = $this|0;
 var $$$i$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$0 = 0, $i$0$ph = 0, $i$0$ph16 = 0, $i1$0 = 0, $i1$0$ph = 0, $i1$0$ph9 = 0;
 var $inEnabled$not$i$i$i1 = 0, $lostTouchCMCount$0$ph = 0, $lostTouchCMCount$2$ph = 0, $newTouchCMCount$0$ph = 0, $newTouchCMCount$0$ph17 = 0, $newTouchCMCount$2$ph = 0, $newTouchCMCount$2$ph10 = 0, $or$cond$i$i$i2 = 0, $rv$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6736|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAPU16[545712>>1]|(HEAPU16[545712+2>>1]<<16);
 $13 = $12 & 16711680;
 $inEnabled$not$i$i$i1 = ($13|0)==(0);
 $14 = ($5|0)==(0|0);
 $or$cond$i$i$i2 = $14 | $inEnabled$not$i$i$i1;
 if ($or$cond$i$i$i2) {
  $20 = $1;
 } else {
  $15 = $12&65535;
  $16 = HEAP32[$5>>2]|0;
  $17 = (($16) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_viiii[$18 & 511]($5,$15,$8,$11);
  $$pre = HEAP32[$0>>2]|0;
  $20 = $$pre;
 }
 $19 = (($20) + 224|0);
 $21 = HEAP32[$19>>2]|0;
 $22 = (__ZN5physx6shdfnd9SListImpl3popEv($21)|0);
 $23 = ($22|0)==(0|0);
 if ($23) {
  $24 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (__Z15PxGetFoundationv()|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 24|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
  $$$i$i$i$i$i = $32 ? 490928 : 489216;
  $33 = (FUNCTION_TABLE_iiiiii[$27 & 255]($24,9459,$$$i$i$i$i$i,490824,82)|0);
  $34 = ($33|0)==(0|0);
  if ($34) {
   $rv$0$i$i = 0;
  } else {
   $35 = (($33) + 19|0);
   $36 = $35;
   $37 = $36 & -16;
   $38 = $33;
   $39 = (($37) - ($38))|0;
   $40 = $37;
   $41 = (($40) + -4|0);
   HEAP32[$41>>2] = $39;
   $42 = $37;
   $43 = ($37|0)==(0);
   if ($43) {
    $rv$0$i$i = $42;
   } else {
    __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($42,$20);
    $rv$0$i$i = $42;
   }
  }
 } else {
  $rv$0$i$i = $22;
 }
 $44 = (($this) + 152|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($rv$0$i$i) + 16|0);
 $47 = (($rv$0$i$i) + 8764|0);
 HEAPF32[$47>>2] = $45;
 $48 = HEAP32[$0>>2]|0;
 $49 = (($48) + 7376|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = ($50<<24>>24)==(0);
 $52 = (($rv$0$i$i) + 8784|0);
 HEAP8[$52>>0] = $50;
 $53 = (($48) + 7378|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = (($rv$0$i$i) + 8787|0);
 HEAP8[$55>>0] = $54;
 $56 = (($48) + 7377|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = (($rv$0$i$i) + 8785|0);
 HEAP8[$58>>0] = $57;
 $59 = (($48) + 7372|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($rv$0$i$i) + 8776|0);
 HEAP32[$61>>2] = $60;
 $62 = (($48) + 7384|0);
 $63 = (($rv$0$i$i) + 8780|0);
 HEAP32[$63>>2] = $62;
 $64 = (($this) + 148|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + -1)|0;
 $67 = (($rv$0$i$i) + 9384|0);
 $68 = (($rv$0$i$i) + 9388|0);
 $69 = (($rv$0$i$i) + 9380|0);
 if ($51) {
  $i1$0$ph = 0;$lostTouchCMCount$2$ph = 0;$newTouchCMCount$2$ph = 0;
  L10: while(1) {
   $i1$0$ph9 = $i1$0$ph;$newTouchCMCount$2$ph10 = $newTouchCMCount$2$ph;
   while(1) {
    $i1$0 = $i1$0$ph9;
    while(1) {
     $150 = ($i1$0>>>0)<($65>>>0);
     if (!($150)) {
      break L10;
     }
     $151 = (($i1$0) + 1)|0;
     $152 = ($151>>>0)<($66>>>0);
     $153 = $152 ? $151 : $66;
     $154 = (($i1$0) + 2)|0;
     $155 = ($154>>>0)<($66>>>0);
     $156 = $155 ? $154 : $66;
     $157 = ((($this) + ($153<<2)|0) + 20|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (($158) + 80|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = (($158) + 84|0);
     $162 = HEAP32[$161>>2]|0;
     $163 = (($158) + 88|0);
     $164 = HEAP32[$163>>2]|0;
     $165 = (($158) + 92|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = ((($this) + ($156<<2)|0) + 20|0);
     $168 = HEAP32[$167>>2]|0;
     $169 = HEAP32[$167>>2]|0;
     $170 = (($169) + 128|0);
     $171 = ((($this) + ($i1$0<<2)|0) + 20|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = (($172) + 114|0);
     $174 = HEAP16[$173>>1]|0;
     $175 = $174&65535;
     $176 = $175 & 2;
     $177 = $176&65535;
     $178 = (($172) + 16|0);
     __ZN5physx22PxcDiscreteNarrowPhaseERNS_18PxcNpThreadContextERNS_13PxcNpWorkUnitE($46,$178);
     $179 = HEAP32[$171>>2]|0;
     $180 = (($179) + 114|0);
     $181 = HEAP16[$180>>1]|0;
     $182 = $181&65535;
     $183 = $182 & 2;
     $184 = $183&65535;
     $185 = ($184<<16>>16)==($177<<16>>16);
     if ($185) {
      $i1$0 = $151;
     } else {
      break;
     }
    }
    $186 = (($179) + 76|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = (($187) + 32)|0;
    $189 = $188 >>> 5;
    $190 = HEAP32[$67>>2]|0;
    $191 = $190 & 2147483647;
    $192 = ($189>>>0)>($191>>>0);
    if ($192) {
     $193 = $189 << 2;
     $194 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($68,$193,490328,339)|0);
     $195 = HEAP32[$69>>2]|0;
     $196 = ($195|0)==(0|0);
     if (!($196)) {
      $197 = HEAP32[$67>>2]|0;
      $198 = $197 << 2;
      _memcpy(($194|0),($195|0),($198|0))|0;
      $199 = HEAP32[$67>>2]|0;
      $200 = ($199|0)>(-1);
      if ($200) {
       $201 = HEAP32[$69>>2]|0;
       __ZN5physx6shdfnd9Allocator10deallocateEPv($68,$201);
      }
     }
     $202 = HEAP32[$67>>2]|0;
     $203 = $202 & 2147483647;
     $204 = (($194) + ($203<<2)|0);
     $205 = (($189) - ($202))|0;
     $206 = $205 << 2;
     _memset(($204|0),0,($206|0))|0;
     HEAP32[$69>>2] = $194;
     HEAP32[$67>>2] = $189;
     $211 = $194;
    } else {
     $$pre$i = HEAP32[$69>>2]|0;
     $211 = $$pre$i;
    }
    $207 = $187 & 31;
    $208 = 1 << $207;
    $209 = $187 >>> 5;
    $210 = (($211) + ($209<<2)|0);
    $212 = HEAP32[$210>>2]|0;
    $213 = $212 | $208;
    HEAP32[$210>>2] = $213;
    $214 = ($184<<16>>16)==(0);
    $215 = (($newTouchCMCount$2$ph10) + 1)|0;
    if ($214) {
     break;
    } else {
     $i1$0$ph9 = $151;$newTouchCMCount$2$ph10 = $215;
    }
   }
   $216 = (($lostTouchCMCount$2$ph) + 1)|0;
   $i1$0$ph = $151;$lostTouchCMCount$2$ph = $216;$newTouchCMCount$2$ph = $newTouchCMCount$2$ph10;
  }
  $217 = (($rv$0$i$i) + 9392|0);
  $218 = HEAP32[$217>>2]|0;
  $219 = (($218) + ($newTouchCMCount$2$ph10))|0;
  HEAP32[$217>>2] = $219;
  $220 = (($rv$0$i$i) + 9396|0);
  $221 = HEAP32[$220>>2]|0;
  $222 = (($221) + ($lostTouchCMCount$2$ph))|0;
  HEAP32[$220>>2] = $222;
  $223 = HEAP32[$0>>2]|0;
  $224 = (($223) + 224|0);
  $225 = HEAP32[$224>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($225,$rv$0$i$i);
 } else {
  $i$0$ph = 0;$lostTouchCMCount$0$ph = 0;$newTouchCMCount$0$ph = 0;
  L28: while(1) {
   $i$0$ph16 = $i$0$ph;$newTouchCMCount$0$ph17 = $newTouchCMCount$0$ph;
   while(1) {
    $i$0 = $i$0$ph16;
    while(1) {
     $70 = ($i$0>>>0)<($65>>>0);
     if (!($70)) {
      break L28;
     }
     $71 = (($i$0) + 1)|0;
     $72 = ($71>>>0)<($66>>>0);
     $73 = $72 ? $71 : $66;
     $74 = (($i$0) + 2)|0;
     $75 = ($74>>>0)<($66>>>0);
     $76 = $75 ? $74 : $66;
     $77 = ((($this) + ($73<<2)|0) + 20|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = (($78) + 80|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (($78) + 84|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = HEAP32[$79>>2]|0;
     $84 = (($83) + 128|0);
     $85 = HEAP32[$81>>2]|0;
     $86 = (($85) + 128|0);
     $87 = (($78) + 88|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = (($78) + 92|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ((($this) + ($76<<2)|0) + 20|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = HEAP32[$91>>2]|0;
     $94 = (($93) + 128|0);
     $95 = ((($this) + ($i$0<<2)|0) + 20|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($96) + 114|0);
     $98 = HEAP16[$97>>1]|0;
     $99 = $98&65535;
     $100 = $99 & 2;
     $101 = $100&65535;
     $102 = (($96) + 16|0);
     __ZN5physx25PxcDiscreteNarrowPhasePCMERNS_18PxcNpThreadContextERNS_13PxcNpWorkUnitE($46,$102);
     $103 = HEAP32[$95>>2]|0;
     $104 = (($103) + 114|0);
     $105 = HEAP16[$104>>1]|0;
     $106 = $105&65535;
     $107 = $106 & 2;
     $108 = $107&65535;
     $109 = ($108<<16>>16)==($101<<16>>16);
     if ($109) {
      $i$0 = $71;
     } else {
      break;
     }
    }
    $110 = (($103) + 76|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = (($111) + 32)|0;
    $113 = $112 >>> 5;
    $114 = HEAP32[$67>>2]|0;
    $115 = $114 & 2147483647;
    $116 = ($113>>>0)>($115>>>0);
    if ($116) {
     $117 = $113 << 2;
     $118 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($68,$117,490328,339)|0);
     $119 = HEAP32[$69>>2]|0;
     $120 = ($119|0)==(0|0);
     if (!($120)) {
      $121 = HEAP32[$67>>2]|0;
      $122 = $121 << 2;
      _memcpy(($118|0),($119|0),($122|0))|0;
      $123 = HEAP32[$67>>2]|0;
      $124 = ($123|0)>(-1);
      if ($124) {
       $125 = HEAP32[$69>>2]|0;
       __ZN5physx6shdfnd9Allocator10deallocateEPv($68,$125);
      }
     }
     $126 = HEAP32[$67>>2]|0;
     $127 = $126 & 2147483647;
     $128 = (($118) + ($127<<2)|0);
     $129 = (($113) - ($126))|0;
     $130 = $129 << 2;
     _memset(($128|0),0,($130|0))|0;
     HEAP32[$69>>2] = $118;
     HEAP32[$67>>2] = $113;
     $135 = $118;
    } else {
     $$pre$i4 = HEAP32[$69>>2]|0;
     $135 = $$pre$i4;
    }
    $131 = $111 & 31;
    $132 = 1 << $131;
    $133 = $111 >>> 5;
    $134 = (($135) + ($133<<2)|0);
    $136 = HEAP32[$134>>2]|0;
    $137 = $136 | $132;
    HEAP32[$134>>2] = $137;
    $138 = ($108<<16>>16)==(0);
    $139 = (($newTouchCMCount$0$ph17) + 1)|0;
    if ($138) {
     break;
    } else {
     $i$0$ph16 = $71;$newTouchCMCount$0$ph17 = $139;
    }
   }
   $140 = (($lostTouchCMCount$0$ph) + 1)|0;
   $i$0$ph = $71;$lostTouchCMCount$0$ph = $140;$newTouchCMCount$0$ph = $newTouchCMCount$0$ph17;
  }
  $141 = (($rv$0$i$i) + 9392|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = (($142) + ($newTouchCMCount$0$ph17))|0;
  HEAP32[$141>>2] = $143;
  $144 = (($rv$0$i$i) + 9396|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = (($145) + ($lostTouchCMCount$0$ph))|0;
  HEAP32[$144>>2] = $146;
  $147 = HEAP32[$0>>2]|0;
  $148 = (($147) + 224|0);
  $149 = HEAP32[$148>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($149,$rv$0$i$i);
 }
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return;
 }
 $226 = HEAP32[$5>>2]|0;
 $227 = (($226) + 12|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = $12&65535;
 FUNCTION_TABLE_viiii[$228 & 511]($5,$229,$8,$11);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Gu30LargePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Gu30LargePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Gu30LargePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu30LargePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + (($30*240)|0)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 240|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Gu31SpherePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_2Gu31SpherePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_2Gu31SpherePersistentContactManifoldENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorINS_2Gu31SpherePersistentContactManifoldEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + (($30*96)|0)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 96|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx19PxcScratchAllocatorC2Ev($this) {
 $this = $this|0;
 var $$$i$i$i$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$this>>2] = 0;
 } else {
  $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z15PxGetFoundationv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
  $$$i$i$i$i = $12 ? 491128 : 489216;
  $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,$2,$$$i$i$i$i,491048,111)|0);
  HEAP32[$this>>2] = $13;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($13);
  }
 }
 $15 = (($this) + 4|0);
 $16 = (($this) + 8|0);
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;
 $17 = (($this) + 12|0);
 __ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE8recreateEj($15,64);
 $$pre = HEAP32[$17>>2]|0;
 $$pre1 = HEAP32[$16>>2]|0;
 $phitmp = $$pre & 2147483647;
 HEAP32[$0>>2] = 0;
 $18 = ($phitmp>>>0)>($$pre1>>>0);
 if (!($18)) {
  (__ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($15,$0)|0);
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$15>>2]|0;
 $20 = (($19) + ($$pre1<<2)|0);
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  HEAP32[$20>>2] = 0;
 }
 $22 = (($$pre1) + 1)|0;
 HEAP32[$16>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 491328 : 489216;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,489136,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx18PxsDynamicsContext6createEPNS_10PxsContextE($context) {
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,156,491552,135)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return ($1|0);
 }
 $3 = (($1) + 96|0);
 HEAP32[$3>>2] = $context;
 $4 = (($1) + 100|0);
 $5 = (($1) + 124|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($1) + 128|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($1) + 140|0);
 HEAPF32[$7>>2] = Math_fround(-2.0);
 $8 = (($1) + 148|0);
 HEAP32[$8>>2] = 32;
 $9 = (($1) + 76|0);
 HEAP32[$9>>2] = $1;
 HEAPF32[$1>>2] = Math_fround(0.0);
 $10 = (($1) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($1) + 8|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($1) + 16|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($1) + 20|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($1) + 24|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($1) + 80|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($1) + 32|0);
 $17 = (($1) + 72|0);
 HEAP32[$17>>2] = 0;
 $18 = (($1) + 68|0);
 dest=$16+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$18>>2] = Math_fround(3.40282346638528859812E+38);
 $19 = (($1) + 84|0);
 HEAPF32[$19>>2] = Math_fround(-3.40282346638528859812E+38);
 $20 = (($1) + 28|0);
 HEAP32[$20>>2] = 65535;
 $21 = (($1) + 12|0);
 HEAP16[$21>>1] = -1;
 $22 = (($1) + 14|0);
 HEAP16[$22>>1] = -1;
 $23 = (__ZN5physx20PxsSolverCoreGeneral6createEv()|0);
 $24 = (($1) + 136|0);
 HEAP32[$24>>2] = $23;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx18PxsDynamicsContext7destroyEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx18PxsDynamicsContextD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx18PxsDynamicsContextD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($1);
 $4 = (($this) + 120|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($6|0)!=(0);
 $8 = ($5|0)>(-1);
 $or$cond$i$i$i = $7 & $8;
 if ($or$cond$i$i$i) {
  $9 = (($this) + 112|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = (($10) + -4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (0 - ($13))|0;
   $15 = (($10) + ($14)|0);
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    FUNCTION_TABLE_vii[$20 & 4095]($17,$15);
   }
  }
 }
 $21 = (($this) + 108|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 & 2147483647;
 $24 = ($23|0)!=(0);
 $25 = ($22|0)>(-1);
 $or$cond$i$i$i1 = $24 & $25;
 if (!($or$cond$i$i$i1)) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 100|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($27) + -4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (0 - ($30))|0;
 $32 = (($27) + ($31)|0);
 $33 = ($32|0)==(0|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($34,$32);
 STACKTOP = sp;return;
}
function __ZN5physx18PxsDynamicsContext18setDescFromIndicesERNS_23PxcSolverConstraintDescERKNS_21PxsIndexedInteractionE($this,$desc,$constraint) {
 $this = $this|0;
 $desc = $desc|0;
 $constraint = $constraint|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, $offsetMap = 0, $phitmp = 0, $phitmp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offsetMap = sp;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$offsetMap>>2] = $1;
 $2 = (($offsetMap) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($constraint) + 8|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(2);
 if ($5) {
  $6 = HEAP32[$constraint>>2]|0;
  $7 = $6 & -64;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$desc>>2] = $10;
  $11 = HEAP32[$8>>2]|0;
  $12 = (($11) + 34|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = (($desc) + 10|0);
  HEAP16[$14>>1] = $13;
  $15 = $6 & 63;
  $16 = $15&65535;
  $17 = (($desc) + 8|0);
  HEAP16[$17>>1] = $16;
 } else {
  $18 = (($desc) + 8|0);
  HEAP16[$18>>1] = -1;
  $19 = HEAP8[$3>>0]|0;
  $20 = ($19<<24>>24)==(3);
  if ($20) {
   $29 = $this;
  } else {
   $21 = $19&255;
   $22 = HEAP32[$constraint>>2]|0;
   $23 = (($offsetMap) + ($21<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + ($22))|0;
   $26 = (($this) + 100|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + ($25<<5)|0);
   $29 = $28;
  }
  HEAP32[$desc>>2] = $29;
  $30 = HEAP8[$3>>0]|0;
  $31 = ($30<<24>>24)==(3);
  if ($31) {
   $39 = 0;
  } else {
   $32 = $30&255;
   $33 = HEAP32[$constraint>>2]|0;
   $34 = (($33) + 1)|0;
   $35 = (($offsetMap) + ($32<<2)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + ($36))|0;
   $phitmp = $37&65535;
   $39 = $phitmp;
  }
  $38 = (($desc) + 10|0);
  HEAP16[$38>>1] = $39;
 }
 $40 = (($constraint) + 9|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)==(2);
 if ($42) {
  $43 = (($constraint) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = $44 & -64;
  $46 = $45;
  $47 = HEAP32[$46>>2]|0;
  $48 = HEAP32[$47>>2]|0;
  $49 = (($desc) + 4|0);
  HEAP32[$49>>2] = $48;
  $50 = HEAP32[$46>>2]|0;
  $51 = (($50) + 34|0);
  $52 = HEAP16[$51>>1]|0;
  $53 = (($desc) + 14|0);
  HEAP16[$53>>1] = $52;
  $54 = $44 & 63;
  $55 = $54&65535;
  $56 = (($desc) + 12|0);
  HEAP16[$56>>1] = $55;
  STACKTOP = sp;return;
 }
 $57 = (($desc) + 12|0);
 HEAP16[$57>>1] = -1;
 $58 = HEAP8[$40>>0]|0;
 $59 = ($58<<24>>24)==(3);
 if ($59) {
  $70 = $this;
 } else {
  $60 = $58&255;
  $61 = (($constraint) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($offsetMap) + ($60<<2)|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($64) + ($62))|0;
  $66 = (($this) + 100|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($67) + ($65<<5)|0);
  $70 = $68;
 }
 $69 = (($desc) + 4|0);
 HEAP32[$69>>2] = $70;
 $71 = HEAP8[$40>>0]|0;
 $72 = ($71<<24>>24)==(3);
 if ($72) {
  $81 = 0;
 } else {
  $73 = $71&255;
  $74 = (($constraint) + 4|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($75) + 1)|0;
  $77 = (($offsetMap) + ($73<<2)|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($76) + ($78))|0;
  $phitmp1 = $79&65535;
  $81 = $phitmp1;
 }
 $80 = (($desc) + 14|0);
 HEAP16[$80>>1] = $81;
 STACKTOP = sp;return;
}
function __ZN5physx18PxsDynamicsContext6updateEfPNS_10PxBaseTaskE($this,$dt,$continuation) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $continuation = $continuation|0;
 var $$$i$i$i$i$i$i = 0, $$pre = 0, $$pre16 = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0;
 var $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0;
 var $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $constraintCount$05 = 0;
 var $emptySolverBody = 0, $emptySolverBodyData = 0, $end$0 = 0, $end$0$lcssa = 0, $end$04 = 0, $end$07 = 0, $exitcond = 0, $i$011 = 0, $or$cond = 0, $rv$0$i$i$i = 0, $start$0$pn$lcssa = 0, $start$0$pn6 = 0, $start$0$pn6$phi = 0, $start$09 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $emptySolverBody = sp + 64|0;
 $emptySolverBodyData = sp;
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6736|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = (($12) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_viiii[$14 & 511]($5,82,$8,$11);
 $15 = (($this) + 124|0);
 HEAPF32[$15>>2] = $dt;
 $16 = $dt == Math_fround(0.0);
 if ($16) {
  $19 = Math_fround(0.0);
 } else {
  $17 = Math_fround(Math_fround(1.0) / $dt);
  $19 = $17;
 }
 $18 = (($this) + 128|0);
 HEAPF32[$18>>2] = $19;
 $20 = HEAP32[$0>>2]|0;
 $21 = (($20) + 6564|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $372 = HEAP32[$5>>2]|0;
  $373 = (($372) + 12|0);
  $374 = HEAP32[$373>>2]|0;
  FUNCTION_TABLE_viiii[$374 & 511]($5,82,$8,$11);
  STACKTOP = sp;return;
 }
 $24 = (($20) + 6500|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 152|0);
 HEAP32[$26>>2] = $25;
 $27 = (($20) + 6496|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($20) + 6560|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + ($22<<4)|0);
 $32 = ($30|0)==(0|0);
 if (!($32)) {
  $33 = HEAP32[$31>>2]|0;
  $34 = (($33) + ($25))|0;
  $35 = (($this) + 100|0);
  $36 = (($this) + 108|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = $37 & 2147483647;
  $39 = ($34>>>0)>($38>>>0);
  if ($39) {
   $40 = (($34) + 31)|0;
   $41 = $40 & -32;
   $42 = ($38>>>0)<($41>>>0);
   if ($42) {
    __ZN5physx6shdfnd5ArrayINS_13PxcSolverBodyENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($35,$41);
    $$pre = HEAP32[$31>>2]|0;
    $45 = $$pre;
   } else {
    $45 = $33;
   }
   $43 = (($25) + 32)|0;
   $44 = (($43) + ($45))|0;
   $46 = $44 & -32;
   $47 = (($this) + 120|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = $48 & 2147483647;
   $50 = ($49>>>0)<($46>>>0);
   if ($50) {
    $51 = (($this) + 112|0);
    __ZN5physx6shdfnd5ArrayINS_17PxcSolverBodyDataENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($51,$46);
    $$pre16 = HEAP32[$31>>2]|0;
    $53 = $$pre16;
   } else {
    $53 = $45;
   }
  } else {
   $53 = $33;
  }
  ;HEAP32[$emptySolverBody+0>>2]=0|0;HEAP32[$emptySolverBody+4>>2]=0|0;HEAP32[$emptySolverBody+8>>2]=0|0;HEAP32[$emptySolverBody+12>>2]=0|0;HEAP32[$emptySolverBody+16>>2]=0|0;HEAP32[$emptySolverBody+20>>2]=0|0;HEAP32[$emptySolverBody+24>>2]=0|0;HEAP32[$emptySolverBody+28>>2]=0|0;
  $52 = (($53) + ($25))|0;
  __ZN5physx6shdfnd5ArrayINS_13PxcSolverBodyENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($35,$52,$emptySolverBody);
  dest=$emptySolverBodyData+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $54 = (($this) + 112|0);
  $55 = HEAP32[$31>>2]|0;
  $56 = (($25) + 1)|0;
  $57 = (($56) + ($55))|0;
  __ZN5physx6shdfnd5ArrayINS_17PxcSolverBodyDataENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($54,$57,$emptySolverBodyData);
  $58 = HEAP32[$54>>2]|0;
  $59 = (($this) + 32|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  HEAPF32[$58>>2] = $60;
  $61 = (($this) + 36|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = (($58) + 4|0);
  HEAPF32[$63>>2] = $62;
  $64 = (($this) + 40|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = (($58) + 8|0);
  HEAPF32[$66>>2] = $65;
  $67 = (($this) + 44|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($58) + 12|0);
  HEAPF32[$69>>2] = $68;
  $70 = (($this) + 48|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = (($58) + 16|0);
  HEAPF32[$72>>2] = $71;
  $73 = (($this) + 52|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($58) + 20|0);
  HEAPF32[$75>>2] = $74;
  $76 = (($this) + 56|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = (($58) + 24|0);
  HEAPF32[$78>>2] = $77;
  $79 = (($this) + 60|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (($58) + 28|0);
  HEAPF32[$81>>2] = $80;
  $82 = (($this) + 64|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($58) + 32|0);
  HEAPF32[$84>>2] = $83;
  $85 = (($58) + 36|0);
  $86 = (($this) + 68|0);
  ;HEAP32[$85+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$86+8>>2]|0;HEAP32[$85+12>>2]=HEAP32[$86+12>>2]|0;HEAP32[$85+16>>2]=HEAP32[$86+16>>2]|0;HEAP32[$85+20>>2]=HEAP32[$86+20>>2]|0;HEAP32[$85+24>>2]=HEAP32[$86+24>>2]|0;
  $87 = HEAP32[$0>>2]|0;
  $88 = (($87) + 6736|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (($89) + 8|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = $89;
  $93 = $92;
  $94 = HEAP32[$93>>2]|0;
  $95 = (($92) + 4)|0;
  $96 = $95;
  $97 = HEAP32[$96>>2]|0;
  $98 = HEAP32[$91>>2]|0;
  $99 = (($98) + 8|0);
  $100 = HEAP32[$99>>2]|0;
  FUNCTION_TABLE_viiii[$100 & 511]($91,92,$94,$97);
  $101 = ($25|0)==(0);
  if (!($101)) {
   $$pre17 = HEAP32[$35>>2]|0;
   $107 = $$pre17;$i$011 = 0;
   while(1) {
    $102 = (($28) + ($i$011<<2)|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($103) + 64|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($107) + ($i$011<<5)|0);
    $108 = (($i$011) + 1)|0;
    $109 = HEAP32[$54>>2]|0;
    $110 = (($109) + ($108<<6)|0);
    __ZN5physx16copyToSolverBodyERNS_13PxcSolverBodyERNS_17PxcSolverBodyDataERKNS_11PxsBodyCoreERNS_12PxsRigidBodyE($106,$110,$105,$103);
    $111 = HEAP32[$35>>2]|0;
    $112 = ((($111) + ($i$011<<5)|0) + 28|0);
    HEAP32[$112>>2] = 65535;
    $113 = ((($111) + ($i$011<<5)|0) + 12|0);
    HEAP16[$113>>1] = -1;
    $114 = ((($111) + ($i$011<<5)|0) + 14|0);
    HEAP16[$114>>1] = -1;
    $exitcond = ($108|0)==($25|0);
    if ($exitcond) {
     break;
    } else {
     $107 = $111;$i$011 = $108;
    }
   }
  }
  $115 = HEAP32[$91>>2]|0;
  $116 = (($115) + 12|0);
  $117 = HEAP32[$116>>2]|0;
  FUNCTION_TABLE_viiii[$117 & 511]($91,92,$94,$97);
 }
 $118 = (($this) + 148|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = ($22|0)>(0);
 if (!($120)) {
  $372 = HEAP32[$5>>2]|0;
  $373 = (($372) + 12|0);
  $374 = HEAP32[$373>>2]|0;
  FUNCTION_TABLE_viiii[$374 & 511]($5,82,$8,$11);
  STACKTOP = sp;return;
 }
 $121 = (($20) + 6580|0);
 $122 = (($20) + 6576|0);
 $123 = (($20) + 6592|0);
 $124 = (($20) + 6588|0);
 $125 = ($continuation|0)==(0|0);
 $start$09 = $30;
 while(1) {
  $126 = HEAP32[$121>>2]|0;
  $127 = (($start$09) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = $128 & 2147483647;
  $130 = (($126) + ($129<<2)|0);
  $131 = HEAP32[$122>>2]|0;
  $132 = HEAP32[$start$09>>2]|0;
  $133 = (($131) + ($132<<2)|0);
  $134 = HEAP32[$123>>2]|0;
  $135 = (($start$09) + 12|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = (($134) + ($136<<4)|0);
  $138 = HEAP32[$124>>2]|0;
  $139 = (($start$09) + 8|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = (($138) + ($140<<4)|0);
  $end$04 = (($start$09) + 16|0);
  $142 = ($end$04>>>0)<($31>>>0);
  L27: do {
   if ($142) {
    $constraintCount$05 = 0;$end$07 = $end$04;$start$0$pn6 = $start$09;
    while(1) {
     $143 = HEAP32[$end$07>>2]|0;
     $144 = (($143) - ($132))|0;
     $145 = ($144>>>0)<($119>>>0);
     $146 = ($constraintCount$05|0)==(0);
     $or$cond = $145 | $146;
     if (!($or$cond)) {
      $end$0$lcssa = $end$07;$start$0$pn$lcssa = $start$0$pn6;
      break L27;
     }
     $147 = (($start$0$pn6) + 20|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = $148 & 2147483647;
     $150 = (($149) - ($129))|0;
     $151 = ($150>>>0)<(2);
     if (!($151)) {
      $end$0$lcssa = $end$07;$start$0$pn$lcssa = $start$0$pn6;
      break L27;
     }
     $152 = (($start$0$pn6) + 36|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = $153 & 2147483647;
     $155 = (($start$0$pn6) + 44|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = (($start$0$pn6) + 40|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (($154) - ($129))|0;
     $160 = (($159) + ($156))|0;
     $161 = (($160) - ($136))|0;
     $162 = (($161) + ($158))|0;
     $163 = (($162) - ($140))|0;
     $end$0 = (($end$07) + 16|0);
     $164 = ($end$0>>>0)<($31>>>0);
     if ($164) {
      $start$0$pn6$phi = $end$07;$constraintCount$05 = $163;$end$07 = $end$0;$start$0$pn6 = $start$0$pn6$phi;
     } else {
      $end$0$lcssa = $end$0;$start$0$pn$lcssa = $end$07;
      break;
     }
    }
   } else {
    $end$0$lcssa = $end$04;$start$0$pn$lcssa = $start$09;
   }
  } while(0);
  $165 = (($start$0$pn$lcssa) + 20|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = (($166) - ($128))|0;
  $168 = $167 & 2147483647;
  $169 = HEAP32[$end$0$lcssa>>2]|0;
  $170 = (($169) - ($132))|0;
  $171 = (($start$0$pn$lcssa) + 28|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = (($172) - ($136))|0;
  $174 = (($start$0$pn$lcssa) + 24|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = (($175) - ($140))|0;
  $177 = (0 - ($170))|0;
  $178 = ($168|0)==($177|0);
  if (!($178)) {
   $180 = (($132) + ($25))|0;
   $181 = HEAP32[$0>>2]|0;
   $182 = (($181) + 6732|0);
   $183 = HEAP32[$182>>2]|0;
   $184 = HEAP32[$183>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($184);
   $185 = (($181) + 224|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = (__ZN5physx6shdfnd9SListImpl3popEv($186)|0);
   $188 = ($187|0)==(0|0);
   if ($188) {
    $189 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = (($190) + 8|0);
    $192 = HEAP32[$191>>2]|0;
    $193 = (__Z15PxGetFoundationv()|0);
    $194 = HEAP32[$193>>2]|0;
    $195 = (($194) + 24|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = (FUNCTION_TABLE_ii[$196 & 4095]($193)|0);
    $$$i$i$i$i$i$i = $197 ? 492696 : 491832;
    $198 = (FUNCTION_TABLE_iiiiii[$192 & 255]($189,9459,$$$i$i$i$i$i$i,492592,82)|0);
    $199 = ($198|0)==(0|0);
    if ($199) {
     $rv$0$i$i$i = 0;
    } else {
     $200 = (($198) + 19|0);
     $201 = $200;
     $202 = $201 & -16;
     $203 = $198;
     $204 = (($202) - ($203))|0;
     $205 = $202;
     $206 = (($205) + -4|0);
     HEAP32[$206>>2] = $204;
     $207 = $202;
     $208 = ($202|0)==(0);
     if ($208) {
      $rv$0$i$i$i = $207;
     } else {
      __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($207,$181);
      $rv$0$i$i$i = $207;
     }
    }
   } else {
    $rv$0$i$i$i = $187;
   }
   $209 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($183,68,16)|0);
   $210 = ($209|0)==(0|0);
   if ($210) {
    $356 = 0;
   } else {
    $211 = (($209) + 4|0);
    HEAP16[$211>>1] = -1;
    $212 = (($209) + 6|0);
    HEAP16[$212>>1] = 0;
    $213 = (($209) + 8|0);
    HEAP32[$213>>2] = 0;
    HEAP32[$209>>2] = ((434896 + 8|0));
    $214 = (($209) + 12|0);
    HEAP32[$214>>2] = 0;
    $215 = (($209) + 16|0);
    HEAP32[$215>>2] = 0;
    HEAP32[$209>>2] = ((493120 + 8|0));
    $216 = (($209) + 20|0);
    HEAP32[$216>>2] = $this;
    $217 = (($209) + 24|0);
    HEAP32[$217>>2] = $rv$0$i$i$i;
    $218 = (($209) + 28|0);
    HEAP32[$218>>2] = $133;
    $219 = (($209) + 32|0);
    HEAP32[$219>>2] = $130;
    $220 = (($209) + 36|0);
    HEAP32[$220>>2] = 0;
    $221 = (($209) + 40|0);
    HEAP32[$221>>2] = $141;
    $222 = (($209) + 44|0);
    HEAP32[$222>>2] = $137;
    $223 = (($209) + 48|0);
    HEAP32[$223>>2] = $170;
    $224 = (($209) + 52|0);
    HEAP32[$224>>2] = $168;
    $225 = (($209) + 56|0);
    HEAP32[$225>>2] = $176;
    $226 = (($209) + 60|0);
    HEAP32[$226>>2] = $173;
    $227 = (($209) + 64|0);
    HEAP32[$227>>2] = $180;
    $356 = $209;
   }
   $228 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($183,68,16)|0);
   $229 = ($228|0)==(0|0);
   if ($229) {
    $304 = 0;
   } else {
    $230 = (($228) + 4|0);
    HEAP16[$230>>1] = -1;
    $231 = (($228) + 6|0);
    HEAP16[$231>>1] = 0;
    $232 = (($228) + 8|0);
    HEAP32[$232>>2] = 0;
    HEAP32[$228>>2] = ((434896 + 8|0));
    $233 = (($228) + 12|0);
    HEAP32[$233>>2] = 0;
    $234 = (($228) + 16|0);
    HEAP32[$234>>2] = 0;
    HEAP32[$228>>2] = ((493048 + 8|0));
    $235 = (($228) + 20|0);
    HEAP32[$235>>2] = $this;
    $236 = (($228) + 24|0);
    HEAP32[$236>>2] = $rv$0$i$i$i;
    $237 = (($228) + 28|0);
    HEAP32[$237>>2] = $133;
    $238 = (($228) + 32|0);
    HEAP32[$238>>2] = $130;
    $239 = (($228) + 36|0);
    HEAP32[$239>>2] = 0;
    $240 = (($228) + 40|0);
    HEAP32[$240>>2] = $141;
    $241 = (($228) + 44|0);
    HEAP32[$241>>2] = $137;
    $242 = (($228) + 48|0);
    HEAP32[$242>>2] = $170;
    $243 = (($228) + 52|0);
    HEAP32[$243>>2] = $168;
    $244 = (($228) + 56|0);
    HEAP32[$244>>2] = $176;
    $245 = (($228) + 60|0);
    HEAP32[$245>>2] = $173;
    $246 = (($228) + 64|0);
    HEAP32[$246>>2] = $180;
    $304 = $228;
   }
   $247 = (($181) + 7372|0);
   $248 = HEAP32[$247>>2]|0;
   $249 = (($rv$0$i$i$i) + 8776|0);
   HEAP32[$249>>2] = $248;
   $250 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($183,48,16)|0);
   $251 = ($250|0)==(0|0);
   if ($251) {
    $328 = 0;
   } else {
    $252 = (($250) + 4|0);
    HEAP16[$252>>1] = -1;
    $253 = (($250) + 6|0);
    HEAP16[$253>>1] = 0;
    $254 = (($250) + 8|0);
    HEAP32[$254>>2] = 0;
    HEAP32[$250>>2] = ((434896 + 8|0));
    $255 = (($250) + 12|0);
    HEAP32[$255>>2] = 0;
    $256 = (($250) + 16|0);
    HEAP32[$256>>2] = 0;
    HEAP32[$250>>2] = ((491704 + 8|0));
    $257 = (($250) + 20|0);
    HEAP32[$257>>2] = $this;
    $258 = (($250) + 24|0);
    HEAP32[$258>>2] = $rv$0$i$i$i;
    $259 = (($250) + 28|0);
    HEAP32[$259>>2] = $180;
    $260 = (($250) + 32|0);
    HEAP32[$260>>2] = $170;
    $261 = (($250) + 36|0);
    HEAP32[$261>>2] = $168;
    $262 = (($250) + 40|0);
    HEAP32[$262>>2] = $176;
    $263 = (($250) + 44|0);
    HEAP32[$263>>2] = $173;
    $328 = $250;
   }
   $264 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($183,68,16)|0);
   $265 = ($264|0)==(0|0);
   if ($265) {
    $314 = 0;
   } else {
    $266 = (($264) + 4|0);
    HEAP16[$266>>1] = -1;
    $267 = (($264) + 6|0);
    HEAP16[$267>>1] = 0;
    $268 = (($264) + 8|0);
    HEAP32[$268>>2] = 0;
    HEAP32[$264>>2] = ((434896 + 8|0));
    $269 = (($264) + 12|0);
    HEAP32[$269>>2] = 0;
    $270 = (($264) + 16|0);
    HEAP32[$270>>2] = 0;
    HEAP32[$264>>2] = ((492904 + 8|0));
    $271 = (($264) + 20|0);
    HEAP32[$271>>2] = $this;
    $272 = (($264) + 24|0);
    HEAP32[$272>>2] = $rv$0$i$i$i;
    $273 = (($264) + 28|0);
    HEAP32[$273>>2] = $133;
    $274 = (($264) + 32|0);
    HEAP32[$274>>2] = $130;
    $275 = (($264) + 36|0);
    HEAP32[$275>>2] = 0;
    $276 = (($264) + 40|0);
    HEAP32[$276>>2] = $141;
    $277 = (($264) + 44|0);
    HEAP32[$277>>2] = $137;
    $278 = (($264) + 48|0);
    HEAP32[$278>>2] = $170;
    $279 = (($264) + 52|0);
    HEAP32[$279>>2] = $168;
    $280 = (($264) + 56|0);
    HEAP32[$280>>2] = $176;
    $281 = (($264) + 60|0);
    HEAP32[$281>>2] = $173;
    $282 = (($264) + 64|0);
    HEAP32[$282>>2] = $180;
    $314 = $264;
   }
   $283 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($183,68,16)|0);
   $284 = ($283|0)==(0|0);
   if ($284) {
    $342 = 0;
   } else {
    $285 = (($283) + 4|0);
    HEAP16[$285>>1] = -1;
    $286 = (($283) + 6|0);
    HEAP16[$286>>1] = 0;
    $287 = (($283) + 8|0);
    HEAP32[$287>>2] = 0;
    HEAP32[$283>>2] = ((434896 + 8|0));
    $288 = (($283) + 12|0);
    HEAP32[$288>>2] = 0;
    $289 = (($283) + 16|0);
    HEAP32[$289>>2] = 0;
    HEAP32[$283>>2] = ((492816 + 8|0));
    $290 = (($283) + 20|0);
    HEAP32[$290>>2] = $this;
    $291 = (($283) + 24|0);
    HEAP32[$291>>2] = $rv$0$i$i$i;
    $292 = (($283) + 28|0);
    HEAP32[$292>>2] = $133;
    $293 = (($283) + 32|0);
    HEAP32[$293>>2] = $130;
    $294 = (($283) + 36|0);
    HEAP32[$294>>2] = 0;
    $295 = (($283) + 40|0);
    HEAP32[$295>>2] = $141;
    $296 = (($283) + 44|0);
    HEAP32[$296>>2] = $137;
    $297 = (($283) + 48|0);
    HEAP32[$297>>2] = $170;
    $298 = (($283) + 52|0);
    HEAP32[$298>>2] = $168;
    $299 = (($283) + 56|0);
    HEAP32[$299>>2] = $176;
    $300 = (($283) + 60|0);
    HEAP32[$300>>2] = $173;
    $301 = (($283) + 64|0);
    HEAP32[$301>>2] = $180;
    $342 = $283;
   }
   $302 = HEAP32[$183>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($302);
   $303 = (($304) + 16|0);
   HEAP32[$303>>2] = 1;
   $305 = (($304) + 12|0);
   HEAP32[$305>>2] = $continuation;
   if (!($125)) {
    $306 = HEAP32[$continuation>>2]|0;
    $307 = (($306) + 16|0);
    $308 = HEAP32[$307>>2]|0;
    FUNCTION_TABLE_vi[$308 & 4095]($continuation);
    $309 = HEAP32[$305>>2]|0;
    $310 = (($309) + 8|0);
    $311 = HEAP32[$310>>2]|0;
    $312 = (($304) + 8|0);
    HEAP32[$312>>2] = $311;
   }
   $313 = (($314) + 16|0);
   HEAP32[$313>>2] = 1;
   $315 = (($314) + 12|0);
   HEAP32[$315>>2] = $304;
   $316 = ($304|0)==(0|0);
   if (!($316)) {
    $317 = HEAP32[$304>>2]|0;
    $318 = (($317) + 16|0);
    $319 = HEAP32[$318>>2]|0;
    FUNCTION_TABLE_vi[$319 & 4095]($304);
    $320 = HEAP32[$315>>2]|0;
    $321 = (($320) + 8|0);
    $322 = HEAP32[$321>>2]|0;
    $323 = (($314) + 8|0);
    HEAP32[$323>>2] = $322;
   }
   $324 = HEAP32[$304>>2]|0;
   $325 = (($324) + 20|0);
   $326 = HEAP32[$325>>2]|0;
   FUNCTION_TABLE_vi[$326 & 4095]($304);
   $327 = (($328) + 16|0);
   HEAP32[$327>>2] = 1;
   $329 = (($328) + 12|0);
   HEAP32[$329>>2] = $314;
   $330 = ($314|0)==(0|0);
   if (!($330)) {
    $331 = HEAP32[$314>>2]|0;
    $332 = (($331) + 16|0);
    $333 = HEAP32[$332>>2]|0;
    FUNCTION_TABLE_vi[$333 & 4095]($314);
    $334 = HEAP32[$329>>2]|0;
    $335 = (($334) + 8|0);
    $336 = HEAP32[$335>>2]|0;
    $337 = (($328) + 8|0);
    HEAP32[$337>>2] = $336;
   }
   $338 = HEAP32[$314>>2]|0;
   $339 = (($338) + 20|0);
   $340 = HEAP32[$339>>2]|0;
   FUNCTION_TABLE_vi[$340 & 4095]($314);
   $341 = (($342) + 16|0);
   HEAP32[$341>>2] = 1;
   $343 = (($342) + 12|0);
   HEAP32[$343>>2] = $328;
   $344 = ($328|0)==(0|0);
   if (!($344)) {
    $345 = HEAP32[$328>>2]|0;
    $346 = (($345) + 16|0);
    $347 = HEAP32[$346>>2]|0;
    FUNCTION_TABLE_vi[$347 & 4095]($328);
    $348 = HEAP32[$343>>2]|0;
    $349 = (($348) + 8|0);
    $350 = HEAP32[$349>>2]|0;
    $351 = (($342) + 8|0);
    HEAP32[$351>>2] = $350;
   }
   $352 = HEAP32[$328>>2]|0;
   $353 = (($352) + 20|0);
   $354 = HEAP32[$353>>2]|0;
   FUNCTION_TABLE_vi[$354 & 4095]($328);
   $355 = (($356) + 16|0);
   HEAP32[$355>>2] = 1;
   $357 = (($356) + 12|0);
   HEAP32[$357>>2] = $342;
   $358 = ($342|0)==(0|0);
   if (!($358)) {
    $359 = HEAP32[$342>>2]|0;
    $360 = (($359) + 16|0);
    $361 = HEAP32[$360>>2]|0;
    FUNCTION_TABLE_vi[$361 & 4095]($342);
    $362 = HEAP32[$357>>2]|0;
    $363 = (($362) + 8|0);
    $364 = HEAP32[$363>>2]|0;
    $365 = (($356) + 8|0);
    HEAP32[$365>>2] = $364;
   }
   $366 = HEAP32[$342>>2]|0;
   $367 = (($366) + 20|0);
   $368 = HEAP32[$367>>2]|0;
   FUNCTION_TABLE_vi[$368 & 4095]($342);
   $369 = HEAP32[$356>>2]|0;
   $370 = (($369) + 20|0);
   $371 = HEAP32[$370>>2]|0;
   FUNCTION_TABLE_vi[$371 & 4095]($356);
  }
  $179 = ($end$0$lcssa>>>0)<($31>>>0);
  if ($179) {
   $start$09 = $end$0$lcssa;
  } else {
   break;
  }
 }
 $372 = HEAP32[$5>>2]|0;
 $373 = (($372) + 12|0);
 $374 = HEAP32[$373>>2]|0;
 FUNCTION_TABLE_viiii[$374 & 511]($5,82,$8,$11);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_13PxcSolverBodyENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_13PxcSolverBodyENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<5)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<5)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $13 = (($a) + 16|0);
 $14 = (($a) + 20|0);
 $15 = (($a) + 24|0);
 $16 = (($a) + 28|0);
 $$01$i = $9;
 while(1) {
  $17 = ($$01$i|0)==(0|0);
  if (!($17)) {
   $18 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $18;
   $19 = (($$01$i) + 4|0);
   $20 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$19>>2] = $20;
   $21 = (($$01$i) + 8|0);
   $22 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$21>>2] = $22;
   $23 = (($$01$i) + 12|0);
   $24 = HEAPU16[$12>>1]|(HEAPU16[$12+2>>1]<<16);
   HEAP16[$23>>1]=$24&65535;HEAP16[$23+2>>1]=$24>>>16;
   $25 = (($$01$i) + 16|0);
   $26 = Math_fround(HEAPF32[$13>>2]);
   HEAPF32[$25>>2] = $26;
   $27 = (($$01$i) + 20|0);
   $28 = Math_fround(HEAPF32[$14>>2]);
   HEAPF32[$27>>2] = $28;
   $29 = (($$01$i) + 24|0);
   $30 = Math_fround(HEAPF32[$15>>2]);
   HEAPF32[$29>>2] = $30;
   $31 = (($$01$i) + 28|0);
   $32 = HEAP32[$16>>2]|0;
   HEAP32[$31>>2] = $32;
  }
  $33 = (($$01$i) + 32|0);
  $34 = ($33>>>0)<($7>>>0);
  if ($34) {
   $$01$i = $33;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_17PxcSolverBodyDataENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_17PxcSolverBodyDataENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<6)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<6)|0);
 $10 = (($a) + 4|0);
 $11 = (($a) + 8|0);
 $12 = (($a) + 12|0);
 $13 = (($a) + 16|0);
 $14 = (($a) + 20|0);
 $15 = (($a) + 24|0);
 $16 = (($a) + 28|0);
 $17 = (($a) + 32|0);
 $18 = (($a) + 36|0);
 $$01$i = $9;
 while(1) {
  $19 = ($$01$i|0)==(0|0);
  if (!($19)) {
   $20 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $20;
   $21 = (($$01$i) + 4|0);
   $22 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$21>>2] = $22;
   $23 = (($$01$i) + 8|0);
   $24 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$23>>2] = $24;
   $25 = (($$01$i) + 12|0);
   $26 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$25>>2] = $26;
   $27 = (($$01$i) + 16|0);
   $28 = Math_fround(HEAPF32[$13>>2]);
   HEAPF32[$27>>2] = $28;
   $29 = (($$01$i) + 20|0);
   $30 = Math_fround(HEAPF32[$14>>2]);
   HEAPF32[$29>>2] = $30;
   $31 = (($$01$i) + 24|0);
   $32 = Math_fround(HEAPF32[$15>>2]);
   HEAPF32[$31>>2] = $32;
   $33 = (($$01$i) + 28|0);
   $34 = Math_fround(HEAPF32[$16>>2]);
   HEAPF32[$33>>2] = $34;
   $35 = (($$01$i) + 32|0);
   $36 = Math_fround(HEAPF32[$17>>2]);
   HEAPF32[$35>>2] = $36;
   $37 = (($$01$i) + 36|0);
   ;HEAP32[$37+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$18+12>>2]|0;HEAP32[$37+16>>2]=HEAP32[$18+16>>2]|0;HEAP32[$37+20>>2]=HEAP32[$18+20>>2]|0;HEAP32[$37+24>>2]=HEAP32[$18+24>>2]|0;
  }
  $38 = (($$01$i) + 64|0);
  $39 = ($38>>>0)<($7>>>0);
  if ($39) {
   $$01$i = $38;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx18PxsDynamicsContext12mergeResultsEv($this) {
 $this = $this|0;
 var $$0$i1 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $np$01$i$i = 0, $stats = 0, $threadContext$03 = 0, $threadContext$03$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $stats = sp;
 $1 = (($this) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 6736|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$6>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_viiii[$15 & 511]($6,84,$9,$12);
 $16 = HEAP32[$1>>2]|0;
 $17 = (($16) + 5868|0);
 $18 = (($16) + 5872|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 224|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (__ZN5physx6shdfnd9SListImpl5flushEv($20)|0);
 $22 = ($21|0)==(0|0);
 if ($22) {
  $$0$i1 = 0;$83 = 0;
 } else {
  $23 = HEAP32[$21>>2]|0;
  $$0$i1 = $21;$83 = $23;
 }
 $24 = HEAP32[$1>>2]|0;
 ;HEAP32[$stats+0>>2]=0|0;HEAP32[$stats+4>>2]=0|0;HEAP32[$stats+8>>2]=0|0;HEAP32[$stats+12>>2]=0|0;
 $25 = (($24) + 6564|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0);
 if ($27) {
  $38 = (($24) + 6500|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($stats) + 8|0);
  HEAP32[$40>>2] = $39;
  $41 = (($stats) + 4|0);
  HEAP32[$41>>2] = 0;
  HEAP32[$stats>>2] = 0;
 } else {
  $28 = (($24) + 6560|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($24) + 6500|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($stats) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = (($29) + ($26<<4)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($stats) + 4|0);
  HEAP32[$35>>2] = $34;
  $36 = ((($29) + ($26<<4)|0) + 12|0);
  $37 = HEAP32[$36>>2]|0;
  HEAP32[$stats>>2] = $37;
 }
 __ZN5physx10PxsContext14addThreadStatsERKNS_16PxsThreadContext14ThreadSimStatsE($24,$stats);
 $42 = ($$0$i1|0)==(0|0);
 $43 = HEAP32[$1>>2]|0;
 L8: do {
  if ($42) {
   $$lcssa = $43;
  } else {
   $44 = (($16) + 5876|0);
   $46 = $43;$71 = $83;$threadContext$03 = $$0$i1;
   while(1) {
    $45 = (($46) + 5916|0);
    $47 = (($threadContext$03) + 9400|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($threadContext$03) + 9404|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = $50 & 2147483647;
    __ZN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEE8combine1INS4_2OREEEvPKjj($45,$48,$51);
    $52 = HEAP32[$18>>2]|0;
    $53 = (($threadContext$03) + 9360|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + ($52))|0;
    $56 = (($55) + 63)|0;
    $57 = $56 & -64;
    $58 = HEAP32[$44>>2]|0;
    $59 = $58 & 2147483647;
    $60 = ($59>>>0)<($57>>>0);
    if ($60) {
     __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE8recreateEj($17,$57);
    }
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($17,$55,$0);
    $61 = HEAP32[$17>>2]|0;
    $62 = (($61) + ($52<<4)|0);
    $63 = (($threadContext$03) + 9356|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = $54 << 4;
    _memcpy(($62|0),($64|0),($65|0))|0;
    $66 = (($threadContext$03) + 336|0);
    HEAP32[$66>>2] = 0;
    $67 = (($threadContext$03) + 340|0);
    HEAP32[$67>>2] = 0;
    $68 = (($threadContext$03) + 9412|0);
    $69 = HEAP32[$1>>2]|0;
    __ZN5physx10PxsContext14addThreadStatsERKNS_16PxsThreadContext14ThreadSimStatsE($69,$68);
    ;HEAP32[$68+0>>2]=0|0;HEAP32[$68+4>>2]=0|0;HEAP32[$68+8>>2]=0|0;HEAP32[$68+12>>2]=0|0;
    $70 = ($71|0)==(0|0);
    if ($70) {
     break;
    }
    $73 = HEAP32[$71>>2]|0;
    $74 = ($71|0)==(0|0);
    $75 = HEAP32[$1>>2]|0;
    if ($74) {
     $$lcssa = $75;
     break L8;
    } else {
     $threadContext$03$phi = $71;$46 = $75;$71 = $73;$threadContext$03 = $threadContext$03$phi;
    }
   }
   $72 = HEAP32[$1>>2]|0;
   $$lcssa = $72;
  }
 } while(0);
 $76 = (($$lcssa) + 44|0);
 __ZN5physx17PxcNpMemBlockPool23releaseConstraintMemoryEv($76);
 if ($22) {
  $80 = HEAP32[$6>>2]|0;
  $81 = (($80) + 12|0);
  $82 = HEAP32[$81>>2]|0;
  FUNCTION_TABLE_viiii[$82 & 511]($6,84,$9,$12);
  STACKTOP = sp;return;
 } else {
  $np$01$i$i = $21;
 }
 while(1) {
  $77 = HEAP32[$np$01$i$i>>2]|0;
  $78 = HEAP32[$19>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($78,$np$01$i$i);
  $79 = ($77|0)==(0|0);
  if ($79) {
   break;
  } else {
   $np$01$i$i = $77;
  }
 }
 $80 = HEAP32[$6>>2]|0;
 $81 = (($80) + 12|0);
 $82 = HEAP32[$81>>2]|0;
 FUNCTION_TABLE_viiii[$82 & 511]($6,84,$9,$12);
 STACKTOP = sp;return;
}
function __Z24_atomIntegrationParallelfPKPN5physx11PxsBodyCoreEPKPNS_12PxsRigidBodyEjPKNS_2Cm13SpatialVectorEPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEPS9_PiPViPVjSL_($dt,$bodyArray,$originalBodyArray,$_bodyCount,$accelerationArray,$solverBodyPool,$solverBodyDataPool,$0,$pCounter,$pIntegratedCount,$maxSolverPositionIterations,$maxSolverVelocityIterations) {
 $dt = Math_fround($dt);
 $bodyArray = $bodyArray|0;
 $originalBodyArray = $originalBodyArray|0;
 $_bodyCount = $_bodyCount|0;
 $accelerationArray = $accelerationArray|0;
 $solverBodyPool = $solverBodyPool|0;
 $solverBodyDataPool = $solverBodyDataPool|0;
 $0 = $0|0;
 $pCounter = $pCounter|0;
 $pIntegratedCount = $pIntegratedCount|0;
 $maxSolverPositionIterations = $maxSolverPositionIterations|0;
 $maxSolverVelocityIterations = $maxSolverVelocityIterations|0;
 var $$op = 0, $$sum = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $a$01 = 0, $exitcond = 0, $index$0 = 0, $index$05 = 0, $index$09 = 0, $localMaxPosIter$0$lcssa = 0;
 var $localMaxPosIter$08 = 0, $localMaxPosIter$1$lcssa = 0, $localMaxPosIter$13 = 0, $localMaxVelIter$0$lcssa = 0, $localMaxVelIter$07 = 0, $localMaxVelIter$1$lcssa = 0, $localMaxVelIter$12 = 0, $numIntegrated$0$lcssa = 0, $numIntegrated$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($_bodyCount) + -1)|0;
 $2 = (__ZN5physx6shdfnd9atomicAddEPVii($pCounter,32)|0);
 $index$05 = (($2) + -32)|0;
 $3 = ($index$05|0)<($_bodyCount|0);
 if (!($3)) {
  $localMaxPosIter$0$lcssa = 0;$localMaxVelIter$0$lcssa = 0;$numIntegrated$0$lcssa = 0;
  (__ZN5physx6shdfnd9atomicAddEPVii($pIntegratedCount,$numIntegrated$0$lcssa)|0);
  (__ZN5physx6shdfnd9atomicMaxEPVii($maxSolverPositionIterations,$localMaxPosIter$0$lcssa)|0);
  (__ZN5physx6shdfnd9atomicMaxEPVii($maxSolverVelocityIterations,$localMaxVelIter$0$lcssa)|0);
  STACKTOP = sp;return;
 }
 $4 = $_bodyCount ^ -1;
 $index$09 = $index$05;$localMaxPosIter$08 = 0;$localMaxVelIter$07 = 0;$numIntegrated$06 = 0;
 while(1) {
  $5 = (($_bodyCount) - ($index$09))|0;
  $6 = ($5|0)<(32);
  $7 = $6 ? $5 : 32;
  $8 = (($7) + -1)|0;
  $9 = ($8|0)>(0);
  if ($9) {
   $10 = (($index$09) + ($4))|0;
   $11 = ($10|0)>(-33);
   $$op = (-2 - ($10))|0;
   $12 = $11 ? $$op : 31;
   $a$01 = 0;$localMaxPosIter$13 = $localMaxPosIter$08;$localMaxVelIter$12 = $localMaxVelIter$07;
   while(1) {
    $13 = (($a$01) + ($index$09))|0;
    $14 = (($13) + 4)|0;
    $15 = ($14|0)<($1|0);
    $16 = $15 ? $14 : $1;
    $17 = (($bodyArray) + ($16<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$17>>2]|0;
    $20 = (($19) + 128|0);
    $21 = (($solverBodyPool) + ($14<<5)|0);
    $22 = (($solverBodyDataPool) + ($14<<6)|0);
    $$sum = (($13) + 6)|0;
    $23 = (($solverBodyDataPool) + ($$sum<<6)|0);
    $24 = (($13) + 16)|0;
    $25 = (($accelerationArray) + ($24<<5)|0);
    $26 = (($bodyArray) + ($13<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 30|0);
    $29 = HEAP16[$28>>1]|0;
    $30 = $29&65535;
    $31 = $30 & 255;
    $32 = ($31>>>0)<($localMaxPosIter$13>>>0);
    $33 = $32 ? $localMaxPosIter$13 : $31;
    $34 = $30 >>> 8;
    $35 = ($34>>>0)<($localMaxVelIter$12>>>0);
    $36 = $35 ? $localMaxVelIter$12 : $34;
    $37 = (($accelerationArray) + ($13<<5)|0);
    $38 = ((($accelerationArray) + ($13<<5)|0) + 16|0);
    __ZN5physx36bodyCoreComputeUnconstrainedVelocityERNS_11PxsBodyCoreERKNS_6PxVec3ES4_f($27,$37,$38,$dt);
    $39 = (($solverBodyPool) + ($13<<5)|0);
    $40 = (($13) + 1)|0;
    $41 = (($solverBodyDataPool) + ($40<<6)|0);
    $42 = (($originalBodyArray) + ($13<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    __ZN5physx16copyToSolverBodyERNS_13PxcSolverBodyERNS_17PxcSolverBodyDataERKNS_11PxsBodyCoreERNS_12PxsRigidBodyE($39,$41,$27,$43);
    $44 = ((($solverBodyPool) + ($13<<5)|0) + 28|0);
    HEAP32[$44>>2] = 0;
    $45 = ((($solverBodyPool) + ($13<<5)|0) + 12|0);
    HEAP16[$45>>1] = 0;
    $46 = ((($solverBodyPool) + ($13<<5)|0) + 14|0);
    HEAP16[$46>>1] = 0;
    $47 = (($a$01) + 1)|0;
    $exitcond = ($47|0)==($12|0);
    if ($exitcond) {
     $localMaxPosIter$1$lcssa = $33;$localMaxVelIter$1$lcssa = $36;
     break;
    } else {
     $a$01 = $47;$localMaxPosIter$13 = $33;$localMaxVelIter$12 = $36;
    }
   }
  } else {
   $localMaxPosIter$1$lcssa = $localMaxPosIter$08;$localMaxVelIter$1$lcssa = $localMaxVelIter$07;
  }
  $48 = (($8) + ($index$09))|0;
  $49 = (($bodyArray) + ($48<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + 30|0);
  $52 = HEAP16[$51>>1]|0;
  $53 = $52&65535;
  $54 = $53 & 255;
  $55 = ($54>>>0)<($localMaxPosIter$1$lcssa>>>0);
  $56 = $55 ? $localMaxPosIter$1$lcssa : $54;
  $57 = $53 >>> 8;
  $58 = ($57>>>0)<($localMaxVelIter$1$lcssa>>>0);
  $59 = $58 ? $localMaxVelIter$1$lcssa : $57;
  $60 = (($accelerationArray) + ($48<<5)|0);
  $61 = ((($accelerationArray) + ($48<<5)|0) + 16|0);
  __ZN5physx36bodyCoreComputeUnconstrainedVelocityERNS_11PxsBodyCoreERKNS_6PxVec3ES4_f($50,$60,$61,$dt);
  $62 = (($solverBodyPool) + ($48<<5)|0);
  $63 = (($7) + ($index$09))|0;
  $64 = (($solverBodyDataPool) + ($63<<6)|0);
  $65 = (($originalBodyArray) + ($48<<2)|0);
  $66 = HEAP32[$65>>2]|0;
  __ZN5physx16copyToSolverBodyERNS_13PxcSolverBodyERNS_17PxcSolverBodyDataERKNS_11PxsBodyCoreERNS_12PxsRigidBodyE($62,$64,$50,$66);
  $67 = ((($solverBodyPool) + ($48<<5)|0) + 28|0);
  HEAP32[$67>>2] = 0;
  $68 = ((($solverBodyPool) + ($48<<5)|0) + 12|0);
  HEAP16[$68>>1] = 0;
  $69 = ((($solverBodyPool) + ($48<<5)|0) + 14|0);
  HEAP16[$69>>1] = 0;
  $70 = (($7) + ($numIntegrated$06))|0;
  $71 = (__ZN5physx6shdfnd9atomicAddEPVii($pCounter,32)|0);
  $index$0 = (($71) + -32)|0;
  $72 = ($index$0|0)<($_bodyCount|0);
  if ($72) {
   $index$09 = $index$0;$localMaxPosIter$08 = $56;$localMaxVelIter$07 = $59;$numIntegrated$06 = $70;
  } else {
   $localMaxPosIter$0$lcssa = $56;$localMaxVelIter$0$lcssa = $59;$numIntegrated$0$lcssa = $70;
   break;
  }
 }
 (__ZN5physx6shdfnd9atomicAddEPVii($pIntegratedCount,$numIntegrated$0$lcssa)|0);
 (__ZN5physx6shdfnd9atomicMaxEPVii($maxSolverPositionIterations,$localMaxPosIter$0$lcssa)|0);
 (__ZN5physx6shdfnd9atomicMaxEPVii($maxSolverVelocityIterations,$localMaxVelIter$0$lcssa)|0);
 STACKTOP = sp;return;
}
function __ZN5physx36bodyCoreComputeUnconstrainedVelocityERNS_11PxsBodyCoreERKNS_6PxVec3ES4_f($core,$linearAccel,$angularAccel,$dt) {
 $core = $core|0;
 $linearAccel = $linearAccel|0;
 $angularAccel = $angularAccel|0;
 $dt = Math_fround($dt);
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($core) + 64|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($core) + 68|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($core) + 72|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($core) + 80|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($core) + 84|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($core) + 88|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($core) + 104|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($core) + 108|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($core) + 100|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($core) + 96|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$linearAccel>>2]);
 $21 = Math_fround($20 * $dt);
 $22 = (($linearAccel) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $dt);
 $25 = (($linearAccel) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $dt);
 $28 = Math_fround(HEAPF32[$angularAccel>>2]);
 $29 = Math_fround($28 * $dt);
 $30 = (($angularAccel) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $dt);
 $33 = (($angularAccel) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $dt);
 $36 = Math_fround($13 * $dt);
 $37 = Math_fround($15 * $dt);
 $38 = Math_fround(Math_fround(1.0) - $36);
 $39 = Math_fround(Math_fround(1.0) - $37);
 $40 = Math_fround($1 + $21);
 $41 = Math_fround($3 + $24);
 $42 = Math_fround($5 + $27);
 $43 = Math_fround($7 + $29);
 $44 = Math_fround($9 + $32);
 $45 = Math_fround($11 + $35);
 $46 = $38 >= Math_fround(0.0);
 $47 = $46 ? $38 : Math_fround(0.0);
 $48 = $39 >= Math_fround(0.0);
 $49 = $48 ? $39 : Math_fround(0.0);
 $50 = Math_fround($47 * $40);
 $51 = Math_fround($47 * $41);
 $52 = Math_fround($47 * $42);
 $53 = Math_fround($49 * $43);
 $54 = Math_fround($49 * $44);
 $55 = Math_fround($49 * $45);
 $56 = Math_fround($50 * $50);
 $57 = Math_fround($51 * $51);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($52 * $52);
 $60 = Math_fround($58 + $59);
 $61 = $60 > $17;
 if ($61) {
  $62 = Math_fround($17 / $60);
  $63 = (Math_fround(Math_sqrt((Math_fround($62)))));
  $64 = Math_fround($50 * $63);
  $65 = Math_fround($51 * $63);
  $66 = Math_fround($52 * $63);
  $78 = $64;$79 = $65;$80 = $66;
 } else {
  $78 = $50;$79 = $51;$80 = $52;
 }
 $67 = Math_fround($53 * $53);
 $68 = Math_fround($54 * $54);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround($55 * $55);
 $71 = Math_fround($69 + $70);
 $72 = $71 > $19;
 if (!($72)) {
  $81 = $53;$82 = $54;$83 = $55;
  HEAPF32[$0>>2] = $78;
  HEAPF32[$2>>2] = $79;
  HEAPF32[$4>>2] = $80;
  HEAPF32[$6>>2] = $81;
  HEAPF32[$8>>2] = $82;
  HEAPF32[$10>>2] = $83;
  STACKTOP = sp;return;
 }
 $73 = Math_fround($19 / $71);
 $74 = (Math_fround(Math_sqrt((Math_fround($73)))));
 $75 = Math_fround($53 * $74);
 $76 = Math_fround($54 * $74);
 $77 = Math_fround($55 * $74);
 $81 = $75;$82 = $76;$83 = $77;
 HEAPF32[$0>>2] = $78;
 HEAPF32[$2>>2] = $79;
 HEAPF32[$4>>2] = $80;
 HEAPF32[$6>>2] = $81;
 HEAPF32[$8>>2] = $82;
 HEAPF32[$10>>2] = $83;
 STACKTOP = sp;return;
}
function __Z15atomIntegrationfPKPN5physx11PxsBodyCoreEPKPNS_12PxsRigidBodyEjPKNS_2Cm13SpatialVectorEPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEPS9_RjSH_($dt,$bodyArray,$originalBodyArray,$bodyCount,$accelerationArray,$solverBodyPool,$solverBodyDataPool,$0,$maxSolverPositionIterations,$maxSolverVelocityIterations) {
 $dt = Math_fround($dt);
 $bodyArray = $bodyArray|0;
 $originalBodyArray = $originalBodyArray|0;
 $bodyCount = $bodyCount|0;
 $accelerationArray = $accelerationArray|0;
 $solverBodyPool = $solverBodyPool|0;
 $solverBodyDataPool = $solverBodyDataPool|0;
 $0 = $0|0;
 $maxSolverPositionIterations = $maxSolverPositionIterations|0;
 $maxSolverVelocityIterations = $maxSolverVelocityIterations|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $localMaxPosIter$0$lcssa = 0;
 var $localMaxPosIter$03 = 0, $localMaxVelIter$0$lcssa = 0, $localMaxVelIter$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($bodyCount|0)==(0);
 if ($1) {
  $localMaxPosIter$0$lcssa = 0;$localMaxVelIter$0$lcssa = 0;
 } else {
  $i$01 = 0;$localMaxPosIter$03 = 0;$localMaxVelIter$02 = 0;
  while(1) {
   $2 = (($i$01) + 1)|0;
   $3 = ($2>>>0)<($bodyCount>>>0);
   if ($3) {
    $4 = (($solverBodyPool) + ($2<<5)|0);
    $5 = (($i$01) + 2)|0;
    $6 = (($solverBodyDataPool) + ($5<<6)|0);
    $7 = (($bodyArray) + ($2<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($originalBodyArray) + ($2<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($accelerationArray) + ($2<<5)|0);
   }
   $12 = (($bodyArray) + ($i$01<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 30|0);
   $15 = HEAP16[$14>>1]|0;
   $16 = $15&65535;
   $17 = $16 & 255;
   $18 = ($17>>>0)<($localMaxPosIter$03>>>0);
   $19 = $18 ? $localMaxPosIter$03 : $17;
   $20 = $16 >>> 8;
   $21 = ($20>>>0)<($localMaxVelIter$02>>>0);
   $22 = $21 ? $localMaxVelIter$02 : $20;
   $23 = (($accelerationArray) + ($i$01<<5)|0);
   $24 = ((($accelerationArray) + ($i$01<<5)|0) + 16|0);
   __ZN5physx36bodyCoreComputeUnconstrainedVelocityERNS_11PxsBodyCoreERKNS_6PxVec3ES4_f($13,$23,$24,$dt);
   $25 = (($solverBodyPool) + ($i$01<<5)|0);
   $26 = (($solverBodyDataPool) + ($2<<6)|0);
   $27 = (($originalBodyArray) + ($i$01<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   __ZN5physx16copyToSolverBodyERNS_13PxcSolverBodyERNS_17PxcSolverBodyDataERKNS_11PxsBodyCoreERNS_12PxsRigidBodyE($25,$26,$13,$28);
   $29 = ((($solverBodyPool) + ($i$01<<5)|0) + 28|0);
   HEAP32[$29>>2] = 0;
   $30 = ((($solverBodyPool) + ($i$01<<5)|0) + 12|0);
   HEAP16[$30>>1] = 0;
   $31 = ((($solverBodyPool) + ($i$01<<5)|0) + 14|0);
   HEAP16[$31>>1] = 0;
   $exitcond = ($2|0)==($bodyCount|0);
   if ($exitcond) {
    $localMaxPosIter$0$lcssa = $19;$localMaxVelIter$0$lcssa = $22;
    break;
   } else {
    $i$01 = $2;$localMaxPosIter$03 = $19;$localMaxVelIter$02 = $22;
   }
  }
 }
 $32 = HEAP32[$maxSolverPositionIterations>>2]|0;
 $33 = ($localMaxPosIter$0$lcssa>>>0)<($32>>>0);
 $34 = $33 ? $32 : $localMaxPosIter$0$lcssa;
 HEAP32[$maxSolverPositionIterations>>2] = $34;
 $35 = HEAP32[$maxSolverVelocityIterations>>2]|0;
 $36 = ($localMaxVelIter$0$lcssa>>>0)<($35>>>0);
 $37 = $36 ? $35 : $localMaxVelIter$0$lcssa;
 HEAP32[$maxSolverVelocityIterations>>2] = $37;
 STACKTOP = sp;return;
}
function __ZN20PxsAtomIntegrateTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $inEnabled$not$i$i$i1 = 0, $or$cond$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 6736|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAPU16[545664>>1]|(HEAPU16[545664+2>>1]<<16);
 $15 = $14 & 16711680;
 $inEnabled$not$i$i$i1 = ($15|0)==(0);
 $16 = ($7|0)==(0|0);
 $or$cond$i$i$i2 = $16 | $inEnabled$not$i$i$i1;
 if (!($or$cond$i$i$i2)) {
  $17 = $14&65535;
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiii[$20 & 511]($7,$17,$10,$13);
 }
 $21 = (($this) + 48|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 28|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 52|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 44|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 32|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($this) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 56|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 60|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($this) + 64|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 68|0);
 $42 = HEAP32[$41>>2]|0;
 __Z24_atomIntegrationParallelfPKPN5physx11PxsBodyCoreEPKPNS_12PxsRigidBodyEjPKNS_2Cm13SpatialVectorEPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEPS9_PiPViPVjSL_($22,$24,$26,$28,$30,$32,$34,0,$36,$38,$40,$42);
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return;
 }
 $43 = HEAP32[$7>>2]|0;
 $44 = (($43) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $14&65535;
 FUNCTION_TABLE_viiii[$45 & 511]($7,$46,$10,$13);
 STACKTOP = sp;return;
}
function __ZN5physx18PxsDynamicsContext23atomIntegrationParallelEfPKPNS_11PxsBodyCoreEPKPNS_12PxsRigidBodyEjPKNS_2Cm13SpatialVectorEPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEPSA_RjSI_RNS_10PxBaseTaskE($this,$dt,$bodyArray,$originalBodyArray,$_bodyCount,$accelerationArray,$solverBodyPool,$solverBodyDataPool,$motionVelocityArray,$maxSolverPositionIterations,$maxSolverVelocityIterations,$task) {
 $this = $this|0;
 $dt = Math_fround($dt);
 $bodyArray = $bodyArray|0;
 $originalBodyArray = $originalBodyArray|0;
 $_bodyCount = $_bodyCount|0;
 $accelerationArray = $accelerationArray|0;
 $solverBodyPool = $solverBodyPool|0;
 $solverBodyDataPool = $solverBodyDataPool|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $maxSolverPositionIterations = $maxSolverPositionIterations|0;
 $maxSolverVelocityIterations = $maxSolverVelocityIterations|0;
 $task = $task|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $exitcond = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($task) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $10 = $_bodyCount >>> 6;
 $11 = (($10) + 1)|0;
 $12 = ($11>>>0)<($9>>>0);
 $13 = $12 ? $11 : $9;
 $14 = ($13>>>0)>(1);
 if (!($14)) {
  $68 = (($this) + 124|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  __Z15atomIntegrationfPKPN5physx11PxsBodyCoreEPKPNS_12PxsRigidBodyEjPKNS_2Cm13SpatialVectorEPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEPS9_RjSH_($69,$bodyArray,$originalBodyArray,$_bodyCount,$accelerationArray,$solverBodyPool,$solverBodyDataPool,0,$maxSolverPositionIterations,$maxSolverVelocityIterations);
  STACKTOP = sp;return;
 }
 $15 = (($this) + 96|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 6732|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($13*72)|0;
 $20 = HEAP32[$18>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($20);
 $21 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($18,$19,16)|0);
 $22 = HEAP32[$18>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
 $23 = HEAP32[$15>>2]|0;
 $24 = (($23) + 6732|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($26);
 $27 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($25,8,16)|0);
 $28 = HEAP32[$25>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($28);
 $29 = (($27) + 4|0);
 HEAP32[$27>>2] = 0;
 HEAP32[$29>>2] = 0;
 $30 = $9 ^ -1;
 $31 = (-2 - ($10))|0;
 $32 = ($31>>>0)<($30>>>0);
 $umax = $32 ? $30 : $31;
 $33 = $umax ^ -1;
 $a$01 = 0;
 while(1) {
  $34 = (($21) + (($a$01*72)|0)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $55 = 0;
  } else {
   $36 = ((($21) + (($a$01*72)|0)|0) + 4|0);
   HEAP16[$36>>1] = -1;
   $37 = ((($21) + (($a$01*72)|0)|0) + 6|0);
   HEAP16[$37>>1] = 0;
   $38 = ((($21) + (($a$01*72)|0)|0) + 8|0);
   HEAP32[$38>>2] = 0;
   HEAP32[$34>>2] = ((434896 + 8|0));
   $39 = ((($21) + (($a$01*72)|0)|0) + 12|0);
   HEAP32[$39>>2] = 0;
   $40 = ((($21) + (($a$01*72)|0)|0) + 16|0);
   HEAP32[$40>>2] = 0;
   HEAP32[$34>>2] = ((491656 + 8|0));
   $41 = ((($21) + (($a$01*72)|0)|0) + 20|0);
   HEAP32[$41>>2] = $this;
   $42 = ((($21) + (($a$01*72)|0)|0) + 24|0);
   HEAP32[$42>>2] = $bodyArray;
   $43 = ((($21) + (($a$01*72)|0)|0) + 28|0);
   HEAP32[$43>>2] = $originalBodyArray;
   $44 = ((($21) + (($a$01*72)|0)|0) + 32|0);
   HEAP32[$44>>2] = $solverBodyPool;
   $45 = ((($21) + (($a$01*72)|0)|0) + 36|0);
   HEAP32[$45>>2] = $solverBodyDataPool;
   $46 = ((($21) + (($a$01*72)|0)|0) + 40|0);
   HEAP32[$46>>2] = $motionVelocityArray;
   $47 = ((($21) + (($a$01*72)|0)|0) + 44|0);
   HEAP32[$47>>2] = $accelerationArray;
   $48 = ((($21) + (($a$01*72)|0)|0) + 48|0);
   HEAPF32[$48>>2] = $dt;
   $49 = ((($21) + (($a$01*72)|0)|0) + 52|0);
   HEAP32[$49>>2] = $_bodyCount;
   $50 = ((($21) + (($a$01*72)|0)|0) + 56|0);
   HEAP32[$50>>2] = $27;
   $51 = ((($21) + (($a$01*72)|0)|0) + 60|0);
   HEAP32[$51>>2] = $29;
   $52 = ((($21) + (($a$01*72)|0)|0) + 64|0);
   HEAP32[$52>>2] = $maxSolverPositionIterations;
   $53 = ((($21) + (($a$01*72)|0)|0) + 68|0);
   HEAP32[$53>>2] = $maxSolverVelocityIterations;
   $55 = $34;
  }
  $54 = (($55) + 16|0);
  HEAP32[$54>>2] = 1;
  $56 = (($55) + 12|0);
  HEAP32[$56>>2] = $task;
  $57 = HEAP32[$task>>2]|0;
  $58 = (($57) + 16|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vi[$59 & 4095]($task);
  $60 = HEAP32[$56>>2]|0;
  $61 = (($60) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($55) + 8|0);
  HEAP32[$63>>2] = $62;
  $64 = HEAP32[$55>>2]|0;
  $65 = (($64) + 20|0);
  $66 = HEAP32[$65>>2]|0;
  FUNCTION_TABLE_vi[$66 & 4095]($55);
  $67 = (($a$01) + 1)|0;
  $exitcond = ($67|0)==($33|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $67;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx28solveParallelDefaultFrictionERNS_18PxsDynamicsContextEjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS9_jPiSA_SA_SA_PNS_25PxcThresholdStreamElementEjSA_PNS_2Cm13SpatialVectorEPKPNS_11PxsBodyCoreERNSD_10BitMapBaseINS_6shdfnd9AllocatorEEEPKPNS_15PxsArticulationEjPViRNSL_5ArrayINS_24PxsConstraintBatchHeaderENSL_19ReflectionAllocatorISW_EEEES10_PPNS_12PxsRigidBodyE($context,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$constraintList,$constraintListSize,$frictionConstraintList,$frictionConstraintListSize,$pConstraintIndex,$pFrictionConstraintIndex,$pAtomListIndex,$pAtomIntegrationListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$motionVelocityArray,$bodyArray,$localChangedActors,$articulations,$_numArtics,$pNumObjectsIntegrated,$contactBlocks,$frictionBlocks,$rigidBodies) {
 $context = $context|0;
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $solverBodyOffset = $solverBodyOffset|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $constraintList = $constraintList|0;
 $constraintListSize = $constraintListSize|0;
 $frictionConstraintList = $frictionConstraintList|0;
 $frictionConstraintListSize = $frictionConstraintListSize|0;
 $pConstraintIndex = $pConstraintIndex|0;
 $pFrictionConstraintIndex = $pFrictionConstraintIndex|0;
 $pAtomListIndex = $pAtomListIndex|0;
 $pAtomIntegrationListIndex = $pAtomIntegrationListIndex|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $bodyArray = $bodyArray|0;
 $localChangedActors = $localChangedActors|0;
 $articulations = $articulations|0;
 $_numArtics = $_numArtics|0;
 $pNumObjectsIntegrated = $pNumObjectsIntegrated|0;
 $contactBlocks = $contactBlocks|0;
 $frictionBlocks = $frictionBlocks|0;
 $rigidBodies = $rigidBodies|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx18PxsDynamicsContext13solveParallelEjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjPiS9_S9_PNS_25PxcThresholdStreamElementEjS9_PNS_2Cm13SpatialVectorEPKPNS_11PxsBodyCoreERNSC_10BitMapBaseINS_6shdfnd9AllocatorEEEPKPNS_15PxsArticulationEjPViRNSK_5ArrayINS_24PxsConstraintBatchHeaderENSK_19ReflectionAllocatorISV_EEEESZ_PPNS_12PxsRigidBodyE($context,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$constraintList,$constraintListSize,$pConstraintIndex,$pAtomListIndex,$pAtomIntegrationListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$motionVelocityArray,$bodyArray,$localChangedActors,0,$_numArtics,$pNumObjectsIntegrated,$contactBlocks,$frictionBlocks,$rigidBodies);
 STACKTOP = sp;return;
}
function __ZN5physx18PxsDynamicsContext13solveParallelEjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjPiS9_S9_PNS_25PxcThresholdStreamElementEjS9_PNS_2Cm13SpatialVectorEPKPNS_11PxsBodyCoreERNSC_10BitMapBaseINS_6shdfnd9AllocatorEEEPKPNS_15PxsArticulationEjPViRNSK_5ArrayINS_24PxsConstraintBatchHeaderENSK_19ReflectionAllocatorISV_EEEESZ_PPNS_12PxsRigidBodyE($this,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$constraintList,$constraintListSize,$pConstraintIndex,$pAtomListIndex,$pAtomIntegrationListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$motionVelocityArray,$bodyArray,$localChangedActors,$0,$_numArtics,$pNumObjectsIntegrated,$contactBlocks,$frictionBlocks,$rigidBodies) {
 $this = $this|0;
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $solverBodyOffset = $solverBodyOffset|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $constraintList = $constraintList|0;
 $constraintListSize = $constraintListSize|0;
 $pConstraintIndex = $pConstraintIndex|0;
 $pAtomListIndex = $pAtomListIndex|0;
 $pAtomIntegrationListIndex = $pAtomIntegrationListIndex|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $bodyArray = $bodyArray|0;
 $localChangedActors = $localChangedActors|0;
 $0 = $0|0;
 $_numArtics = $_numArtics|0;
 $pNumObjectsIntegrated = $pNumObjectsIntegrated|0;
 $contactBlocks = $contactBlocks|0;
 $frictionBlocks = $frictionBlocks|0;
 $rigidBodies = $rigidBodies|0;
 var $$neg = 0, $$pre = 0, $$pre$i = 0, $$pre$pre = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$017 = 0, $a2$05 = 0, $atomRemainder$0$be = 0, $atomRemainder$0$lcssa = 0, $atomRemainder$025 = 0, $atomRemainder$18 = 0, $exitcond = 0, $exitcond36 = 0, $inEnabled$not$i$i$i2 = 0, $index$0$be = 0, $index$0$lcssa = 0, $index$027 = 0, $index$1$lcssa = 0, $index$119 = 0, $index$210 = 0;
 var $index$37 = 0, $j$015 = 0, $normalIterations = 0, $numIntegrated$0$lcssa = 0, $numIntegrated$026 = 0, $numIntegrated$1$lcssa = 0, $numIntegrated$2$lcssa = 0, $numIntegrated$29 = 0, $numIntegrated$3$lcssa = 0, $or$cond$i$i$i3 = 0, $smax = 0, $smax35 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $normalIterations = sp;
 HEAP32[$normalIterations>>2] = 0;
 $1 = (($this) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 124|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiiii[$5 & 1]($2,$7,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$constraintList,$constraintListSize,$pConstraintIndex,$pAtomListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$contactBlocks,$frictionBlocks,$motionVelocityArray,$normalIterations);
 $8 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomIntegrationListIndex,32)|0);
 $9 = (($8) + -32)|0;
 $10 = ($9|0)<($_numArtics|0);
 if ($10) {
  $11 = (($this) + 96|0);
  $12 = (($localChangedActors) + 4|0);
  $13 = (($localChangedActors) + 8|0);
  $14 = $_numArtics ^ -1;
  $atomRemainder$025 = 32;$index$027 = $9;$numIntegrated$026 = 0;
  while(1) {
   $15 = (($_numArtics) - ($index$027))|0;
   $16 = ($15|0)<(32);
   $17 = $16 ? $15 : 32;
   $18 = (($atomRemainder$025) - ($17))|0;
   $19 = ($17|0)>(0);
   if ($19) {
    $20 = (($index$027) + ($14))|0;
    $21 = ($20|0)>(-33);
    $smax35 = $21 ? $20 : -33;
    $22 = (($numIntegrated$026) + -1)|0;
    $23 = $smax35 ^ -1;
    $a$017 = 0;$index$119 = $index$027;
    while(1) {
     $24 = (($articulationListStart) + (($index$119*40)|0)|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = HEAP32[$normalIterations>>2]|0;
     $27 = (($25) + 12|0);
     $28 = HEAP16[$27>>1]|0;
     $29 = $28&65535;
     $30 = Math_imul($29, $26)|0;
     $31 = (($25) + 28|0);
     $32 = $30 & 65535;
     while(1) {
      $33 = HEAP32[$31>>2]|0;
      $34 = ($33|0)==($32|0);
      if ($34) {
       break;
      }
     }
     $35 = HEAP32[$11>>2]|0;
     $36 = (($35) + 6736|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($37) + 8|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = $37;
     $41 = $40;
     $42 = HEAP32[$41>>2]|0;
     $43 = (($40) + 4)|0;
     $44 = $43;
     $45 = HEAP32[$44>>2]|0;
     $46 = HEAPU16[545864>>1]|(HEAPU16[545864+2>>1]<<16);
     $47 = $46 & 16711680;
     $inEnabled$not$i$i$i2 = ($47|0)==(0);
     $48 = ($39|0)==(0|0);
     $or$cond$i$i$i3 = $48 | $inEnabled$not$i$i$i2;
     if (!($or$cond$i$i$i3)) {
      $49 = $46&65535;
      $50 = HEAP32[$39>>2]|0;
      $51 = (($50) + 8|0);
      $52 = HEAP32[$51>>2]|0;
      FUNCTION_TABLE_viiii[$52 & 511]($39,$49,$42,$45);
     }
     $53 = HEAP32[503520>>2]|0;
     $54 = ($53|0)==(0|0);
     if (!($54)) {
      $55 = Math_fround(HEAPF32[$6>>2]);
      __ZN5physx21PxcArticulationHelper12updateBodiesERKNS_25PxcArticulationSolverDescEf($24,$55);
     }
     $56 = ((($articulationListStart) + (($index$119*40)|0)|0) + 36|0);
     $57 = HEAP16[$56>>1]|0;
     $58 = ($57<<16>>16)==(0);
     if (!($58)) {
      $59 = ((($articulationListStart) + (($index$119*40)|0)|0) + 4|0);
      $161 = $57;$j$015 = 0;
      while(1) {
       $60 = HEAP32[$59>>2]|0;
       $61 = ((($60) + ($j$015<<5)|0) + 16|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($62) + 68|0);
       $64 = $63;
       $65 = $64;
       $66 = HEAP32[$65>>2]|0;
       $67 = (($64) + 4)|0;
       $68 = $67;
       $69 = HEAP32[$68>>2]|0;
       $70 = ($69|0)==(1073741823);
       if ($70) {
        $100 = $161;
       } else {
        $71 = (($69) + 32)|0;
        $72 = $71 >>> 5;
        $73 = HEAP32[$12>>2]|0;
        $74 = $73 & 2147483647;
        $75 = ($72>>>0)>($74>>>0);
        if ($75) {
         $76 = $72 << 2;
         $77 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($13,$76,492392,339)|0);
         $78 = HEAP32[$localChangedActors>>2]|0;
         $79 = ($78|0)==(0|0);
         if (!($79)) {
          $80 = HEAP32[$12>>2]|0;
          $81 = $80 << 2;
          _memcpy(($77|0),($78|0),($81|0))|0;
          $82 = HEAP32[$12>>2]|0;
          $83 = ($82|0)>(-1);
          if ($83) {
           $84 = HEAP32[$localChangedActors>>2]|0;
           __ZN5physx6shdfnd9Allocator10deallocateEPv($13,$84);
          }
         }
         $85 = HEAP32[$12>>2]|0;
         $86 = $85 & 2147483647;
         $87 = (($77) + ($86<<2)|0);
         $88 = (($72) - ($85))|0;
         $89 = $88 << 2;
         _memset(($87|0),0,($89|0))|0;
         HEAP32[$localChangedActors>>2] = $77;
         HEAP32[$12>>2] = $72;
         $$pre$pre = HEAP16[$56>>1]|0;
         $$pre = $$pre$pre;$95 = $77;
        } else {
         $$pre$i = HEAP32[$localChangedActors>>2]|0;
         $$pre = $161;$95 = $$pre$i;
        }
        $90 = $69 & 31;
        $91 = 1 << $90;
        $92 = (_bitshift64Lshr(($66|0),($69|0),37)|0);
        $93 = tempRet0;
        $94 = (($95) + ($92<<2)|0);
        $96 = HEAP32[$94>>2]|0;
        $97 = $96 | $91;
        HEAP32[$94>>2] = $97;
        $100 = $$pre;
       }
       $98 = (($j$015) + 1)|0;
       $99 = $100&65535;
       $101 = ($98>>>0)<($99>>>0);
       if ($101) {
        $161 = $100;$j$015 = $98;
       } else {
        break;
       }
      }
     }
     if (!($or$cond$i$i$i3)) {
      $102 = HEAP32[$39>>2]|0;
      $103 = (($102) + 12|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = $46&65535;
      FUNCTION_TABLE_viiii[$104 & 511]($39,$105,$42,$45);
     }
     $106 = (($a$017) + 1)|0;
     $107 = (($index$119) + 1)|0;
     $exitcond36 = ($106|0)==($23|0);
     if ($exitcond36) {
      break;
     } else {
      $a$017 = $106;$index$119 = $107;
     }
    }
    $108 = (($index$027) + -1)|0;
    $109 = (($108) - ($smax35))|0;
    $110 = (($22) - ($smax35))|0;
    $index$1$lcssa = $109;$numIntegrated$1$lcssa = $110;
   } else {
    $index$1$lcssa = $index$027;$numIntegrated$1$lcssa = $numIntegrated$026;
   }
   $111 = ($atomRemainder$025|0)==($17|0);
   if ($111) {
    $112 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomIntegrationListIndex,32)|0);
    $113 = (($112) + -32)|0;
    $atomRemainder$0$be = 32;$index$0$be = $113;
   } else {
    $atomRemainder$0$be = $18;$index$0$be = $index$1$lcssa;
   }
   $114 = ($index$0$be|0)<($_numArtics|0);
   if ($114) {
    $atomRemainder$025 = $atomRemainder$0$be;$index$027 = $index$0$be;$numIntegrated$026 = $numIntegrated$1$lcssa;
   } else {
    $atomRemainder$0$lcssa = $atomRemainder$0$be;$index$0$lcssa = $index$0$be;$numIntegrated$0$lcssa = $numIntegrated$1$lcssa;
    break;
   }
  }
 } else {
  $atomRemainder$0$lcssa = 32;$index$0$lcssa = $9;$numIntegrated$0$lcssa = 0;
 }
 $115 = (($index$0$lcssa) - ($_numArtics))|0;
 $116 = ($115|0)<($atomListSize|0);
 if (!($116)) {
  $numIntegrated$2$lcssa = $numIntegrated$0$lcssa;
  (__ZN5physx6shdfnd9atomicAddEPVii($pNumObjectsIntegrated,$numIntegrated$2$lcssa)|0);
  STACKTOP = sp;return;
 }
 $$neg = (-32 - ($_numArtics))|0;
 $117 = (($atomListSize) + -1)|0;
 $118 = $atomListSize ^ -1;
 $atomRemainder$18 = $atomRemainder$0$lcssa;$index$210 = $115;$numIntegrated$29 = $numIntegrated$0$lcssa;
 while(1) {
  $119 = (($atomListSize) - ($index$210))|0;
  $120 = ($119|0)<($atomRemainder$18|0);
  $121 = $120 ? $119 : $atomRemainder$18;
  $122 = ($121|0)>(0);
  if ($122) {
   $123 = $atomRemainder$18 ^ -1;
   $124 = (($index$210) + ($118))|0;
   $125 = ($124|0)<($123|0);
   $smax = $125 ? $123 : $124;
   $126 = $smax ^ -1;
   $a2$05 = 0;$index$37 = $index$210;
   while(1) {
    $127 = (($index$37) + 4)|0;
    $128 = ($127|0)<($117|0);
    $129 = $128 ? $127 : $117;
    $130 = (($bodyArray) + ($129<<2)|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = HEAP32[$130>>2]|0;
    $133 = (($132) + 128|0);
    $134 = (($atomListStart) + ($127<<5)|0);
    $135 = (($motionVelocityArray) + ($127<<5)|0);
    $136 = (($index$37) + 32)|0;
    $137 = (($bodyArray) + ($136<<2)|0);
    $138 = (($rigidBodies) + ($129<<2)|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = HEAP32[$normalIterations>>2]|0;
    $141 = ((($atomListStart) + ($index$37<<5)|0) + 12|0);
    $142 = HEAP16[$141>>1]|0;
    $143 = $142&65535;
    $144 = Math_imul($143, $140)|0;
    $145 = ((($atomListStart) + ($index$37<<5)|0) + 28|0);
    while(1) {
     $146 = HEAP32[$145>>2]|0;
     $147 = ($146|0)==($144|0);
     if ($147) {
      break;
     }
    }
    $148 = (($motionVelocityArray) + ($index$37<<5)|0);
    $149 = (($bodyArray) + ($index$37<<2)|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = (($rigidBodies) + ($index$37<<2)|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = Math_fround(HEAPF32[$6>>2]);
    __ZN5physx13integrateCoreERNS_11PxsBodyCoreERNS_12PxsRigidBodyERNS_2Cm13SpatialVectorEf($150,$152,$148,$153);
    $154 = (($a2$05) + 1)|0;
    $155 = (($index$37) + 1)|0;
    $exitcond = ($154|0)==($126|0);
    if ($exitcond) {
     break;
    } else {
     $a2$05 = $154;$index$37 = $155;
    }
   }
   $156 = (($numIntegrated$29) + -1)|0;
   $157 = (($156) - ($smax))|0;
   $numIntegrated$3$lcssa = $157;
  } else {
   $numIntegrated$3$lcssa = $numIntegrated$29;
  }
  $158 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomIntegrationListIndex,32)|0);
  $159 = (($$neg) + ($158))|0;
  $160 = ($159|0)<($atomListSize|0);
  if ($160) {
   $atomRemainder$18 = 32;$index$210 = $159;$numIntegrated$29 = $numIntegrated$3$lcssa;
  } else {
   $numIntegrated$2$lcssa = $numIntegrated$3$lcssa;
   break;
  }
 }
 (__ZN5physx6shdfnd9atomicAddEPVii($pNumObjectsIntegrated,$numIntegrated$2$lcssa)|0);
 STACKTOP = sp;return;
}
function __ZN5physx28solveParallelCouloumFrictionERNS_18PxsDynamicsContextEjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS9_jPiSA_SA_SA_PNS_25PxcThresholdStreamElementEjSA_PNS_2Cm13SpatialVectorEPKPNS_11PxsBodyCoreERNSD_10BitMapBaseINS_6shdfnd9AllocatorEEEPKPNS_15PxsArticulationEjPViRNSL_5ArrayINS_24PxsConstraintBatchHeaderENSL_19ReflectionAllocatorISW_EEEES10_PPNS_12PxsRigidBodyE($context,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$constraintList,$constraintListSize,$frictionConstraintList,$frictionConstraintListSize,$pConstraintIndex,$pFrictionConstraintIndex,$pAtomListIndex,$pAtomIntegrationListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$motionVelocityArray,$bodyArray,$localChangedActors,$articulations,$_numArtics,$pNumObjectsIntegrated,$contactBlocks,$frictionBlocks,$rigidBodies) {
 $context = $context|0;
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $solverBodyOffset = $solverBodyOffset|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $constraintList = $constraintList|0;
 $constraintListSize = $constraintListSize|0;
 $frictionConstraintList = $frictionConstraintList|0;
 $frictionConstraintListSize = $frictionConstraintListSize|0;
 $pConstraintIndex = $pConstraintIndex|0;
 $pFrictionConstraintIndex = $pFrictionConstraintIndex|0;
 $pAtomListIndex = $pAtomListIndex|0;
 $pAtomIntegrationListIndex = $pAtomIntegrationListIndex|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $bodyArray = $bodyArray|0;
 $localChangedActors = $localChangedActors|0;
 $articulations = $articulations|0;
 $_numArtics = $_numArtics|0;
 $pNumObjectsIntegrated = $pNumObjectsIntegrated|0;
 $contactBlocks = $contactBlocks|0;
 $frictionBlocks = $frictionBlocks|0;
 $rigidBodies = $rigidBodies|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx18PxsDynamicsContext20solveParallelCoulombEjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jPiS9_S9_S9_PNS_25PxcThresholdStreamElementEjS9_PNS_2Cm13SpatialVectorEPKPNS_11PxsBodyCoreERNSC_10BitMapBaseINS_6shdfnd9AllocatorEEEPKPNS_15PxsArticulationEjPViRNSK_5ArrayINS_24PxsConstraintBatchHeaderENSK_19ReflectionAllocatorISV_EEEESZ_PPNS_12PxsRigidBodyE($context,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$constraintList,$constraintListSize,$frictionConstraintList,$frictionConstraintListSize,$pConstraintIndex,$pFrictionConstraintIndex,$pAtomListIndex,$pAtomIntegrationListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$motionVelocityArray,$bodyArray,$localChangedActors,0,$_numArtics,$pNumObjectsIntegrated,$contactBlocks,$frictionBlocks,$rigidBodies);
 STACKTOP = sp;return;
}
function __ZN5physx18PxsDynamicsContext20solveParallelCoulombEjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jPiS9_S9_S9_PNS_25PxcThresholdStreamElementEjS9_PNS_2Cm13SpatialVectorEPKPNS_11PxsBodyCoreERNSC_10BitMapBaseINS_6shdfnd9AllocatorEEEPKPNS_15PxsArticulationEjPViRNSK_5ArrayINS_24PxsConstraintBatchHeaderENSK_19ReflectionAllocatorISV_EEEESZ_PPNS_12PxsRigidBodyE($this,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$constraintList,$constraintListSize,$frictionConstraintList,$frictionConstraintListSize,$pConstraintIndex,$pFrictionConstraintIndex,$pAtomListIndex,$pAtomIntegrationListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$motionVelocityArray,$bodyArray,$localChangedActors,$0,$_numArtics,$pNumObjectsIntegrated,$contactBlocks,$frictionBlocks,$rigidBodies) {
 $this = $this|0;
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $solverBodyOffset = $solverBodyOffset|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $constraintList = $constraintList|0;
 $constraintListSize = $constraintListSize|0;
 $frictionConstraintList = $frictionConstraintList|0;
 $frictionConstraintListSize = $frictionConstraintListSize|0;
 $pConstraintIndex = $pConstraintIndex|0;
 $pFrictionConstraintIndex = $pFrictionConstraintIndex|0;
 $pAtomListIndex = $pAtomListIndex|0;
 $pAtomIntegrationListIndex = $pAtomIntegrationListIndex|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $bodyArray = $bodyArray|0;
 $localChangedActors = $localChangedActors|0;
 $0 = $0|0;
 $_numArtics = $_numArtics|0;
 $pNumObjectsIntegrated = $pNumObjectsIntegrated|0;
 $contactBlocks = $contactBlocks|0;
 $frictionBlocks = $frictionBlocks|0;
 $rigidBodies = $rigidBodies|0;
 var $$neg = 0, $$pre = 0, $$pre$i = 0, $$pre$pre = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$017 = 0, $a2$05 = 0, $atomRemainder$0$be = 0, $atomRemainder$0$lcssa = 0;
 var $atomRemainder$025 = 0, $atomRemainder$18 = 0, $exitcond = 0, $exitcond36 = 0, $frictionIterations = 0, $inEnabled$not$i$i$i2 = 0, $index$0$be = 0, $index$0$lcssa = 0, $index$027 = 0, $index$1$lcssa = 0, $index$119 = 0, $index$210 = 0, $index$37 = 0, $j$015 = 0, $normalIterations = 0, $numIntegrated$0$lcssa = 0, $numIntegrated$026 = 0, $numIntegrated$1$lcssa = 0, $numIntegrated$2$lcssa = 0, $numIntegrated$29 = 0;
 var $numIntegrated$3$lcssa = 0, $or$cond$i$i$i3 = 0, $smax = 0, $smax35 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $normalIterations = sp + 4|0;
 $frictionIterations = sp;
 HEAP32[$normalIterations>>2] = 0;
 HEAP32[$frictionIterations>>2] = 0;
 $1 = (($this) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 124|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiiiiiiii[$5 & 1]($2,$7,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$constraintList,$constraintListSize,$frictionConstraintList,$frictionConstraintListSize,$pConstraintIndex,$pFrictionConstraintIndex,$pAtomListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$contactBlocks,$frictionBlocks,$motionVelocityArray,$normalIterations,$frictionIterations);
 $8 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomIntegrationListIndex,32)|0);
 $9 = (($8) + -32)|0;
 $10 = ($9|0)<($_numArtics|0);
 if ($10) {
  $11 = (($this) + 96|0);
  $12 = (($localChangedActors) + 4|0);
  $13 = (($localChangedActors) + 8|0);
  $14 = $_numArtics ^ -1;
  $atomRemainder$025 = 32;$index$027 = $9;$numIntegrated$026 = 0;
  while(1) {
   $15 = (($_numArtics) - ($index$027))|0;
   $16 = ($15|0)<(32);
   $17 = $16 ? $15 : 32;
   $18 = (($atomRemainder$025) - ($17))|0;
   $19 = ($17|0)>(0);
   if ($19) {
    $20 = (($index$027) + ($14))|0;
    $21 = ($20|0)>(-33);
    $smax35 = $21 ? $20 : -33;
    $22 = (($numIntegrated$026) + -1)|0;
    $23 = $smax35 ^ -1;
    $a$017 = 0;$index$119 = $index$027;
    while(1) {
     $24 = (($articulationListStart) + (($index$119*40)|0)|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = HEAP32[$normalIterations>>2]|0;
     $27 = (($25) + 12|0);
     $28 = HEAP16[$27>>1]|0;
     $29 = $28&65535;
     $30 = Math_imul($29, $26)|0;
     $31 = HEAP32[$frictionIterations>>2]|0;
     $32 = (($25) + 14|0);
     $33 = HEAP16[$32>>1]|0;
     $34 = $33&65535;
     $35 = Math_imul($34, $31)|0;
     $36 = (($35) + ($30))|0;
     $37 = (($25) + 28|0);
     $38 = $36 & 65535;
     while(1) {
      $39 = HEAP32[$37>>2]|0;
      $40 = ($39|0)==($38|0);
      if ($40) {
       break;
      }
     }
     $41 = HEAP32[$11>>2]|0;
     $42 = (($41) + 6736|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($43) + 8|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = $43;
     $47 = $46;
     $48 = HEAP32[$47>>2]|0;
     $49 = (($46) + 4)|0;
     $50 = $49;
     $51 = HEAP32[$50>>2]|0;
     $52 = HEAPU16[545864>>1]|(HEAPU16[545864+2>>1]<<16);
     $53 = $52 & 16711680;
     $inEnabled$not$i$i$i2 = ($53|0)==(0);
     $54 = ($45|0)==(0|0);
     $or$cond$i$i$i3 = $54 | $inEnabled$not$i$i$i2;
     if (!($or$cond$i$i$i3)) {
      $55 = $52&65535;
      $56 = HEAP32[$45>>2]|0;
      $57 = (($56) + 8|0);
      $58 = HEAP32[$57>>2]|0;
      FUNCTION_TABLE_viiii[$58 & 511]($45,$55,$48,$51);
     }
     $59 = HEAP32[503520>>2]|0;
     $60 = ($59|0)==(0|0);
     if (!($60)) {
      $61 = Math_fround(HEAPF32[$6>>2]);
      __ZN5physx21PxcArticulationHelper12updateBodiesERKNS_25PxcArticulationSolverDescEf($24,$61);
     }
     $62 = ((($articulationListStart) + (($index$119*40)|0)|0) + 36|0);
     $63 = HEAP16[$62>>1]|0;
     $64 = ($63<<16>>16)==(0);
     if (!($64)) {
      $65 = ((($articulationListStart) + (($index$119*40)|0)|0) + 4|0);
      $172 = $63;$j$015 = 0;
      while(1) {
       $66 = HEAP32[$65>>2]|0;
       $67 = ((($66) + ($j$015<<5)|0) + 16|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = (($68) + 68|0);
       $70 = $69;
       $71 = $70;
       $72 = HEAP32[$71>>2]|0;
       $73 = (($70) + 4)|0;
       $74 = $73;
       $75 = HEAP32[$74>>2]|0;
       $76 = ($75|0)==(1073741823);
       if ($76) {
        $106 = $172;
       } else {
        $77 = (($75) + 32)|0;
        $78 = $77 >>> 5;
        $79 = HEAP32[$12>>2]|0;
        $80 = $79 & 2147483647;
        $81 = ($78>>>0)>($80>>>0);
        if ($81) {
         $82 = $78 << 2;
         $83 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($13,$82,492392,339)|0);
         $84 = HEAP32[$localChangedActors>>2]|0;
         $85 = ($84|0)==(0|0);
         if (!($85)) {
          $86 = HEAP32[$12>>2]|0;
          $87 = $86 << 2;
          _memcpy(($83|0),($84|0),($87|0))|0;
          $88 = HEAP32[$12>>2]|0;
          $89 = ($88|0)>(-1);
          if ($89) {
           $90 = HEAP32[$localChangedActors>>2]|0;
           __ZN5physx6shdfnd9Allocator10deallocateEPv($13,$90);
          }
         }
         $91 = HEAP32[$12>>2]|0;
         $92 = $91 & 2147483647;
         $93 = (($83) + ($92<<2)|0);
         $94 = (($78) - ($91))|0;
         $95 = $94 << 2;
         _memset(($93|0),0,($95|0))|0;
         HEAP32[$localChangedActors>>2] = $83;
         HEAP32[$12>>2] = $78;
         $$pre$pre = HEAP16[$62>>1]|0;
         $$pre = $$pre$pre;$101 = $83;
        } else {
         $$pre$i = HEAP32[$localChangedActors>>2]|0;
         $$pre = $172;$101 = $$pre$i;
        }
        $96 = $75 & 31;
        $97 = 1 << $96;
        $98 = (_bitshift64Lshr(($72|0),($75|0),37)|0);
        $99 = tempRet0;
        $100 = (($101) + ($98<<2)|0);
        $102 = HEAP32[$100>>2]|0;
        $103 = $102 | $97;
        HEAP32[$100>>2] = $103;
        $106 = $$pre;
       }
       $104 = (($j$015) + 1)|0;
       $105 = $106&65535;
       $107 = ($104>>>0)<($105>>>0);
       if ($107) {
        $172 = $106;$j$015 = $104;
       } else {
        break;
       }
      }
     }
     if (!($or$cond$i$i$i3)) {
      $108 = HEAP32[$45>>2]|0;
      $109 = (($108) + 12|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = $52&65535;
      FUNCTION_TABLE_viiii[$110 & 511]($45,$111,$48,$51);
     }
     $112 = (($a$017) + 1)|0;
     $113 = (($index$119) + 1)|0;
     $exitcond36 = ($112|0)==($23|0);
     if ($exitcond36) {
      break;
     } else {
      $a$017 = $112;$index$119 = $113;
     }
    }
    $114 = (($index$027) + -1)|0;
    $115 = (($114) - ($smax35))|0;
    $116 = (($22) - ($smax35))|0;
    $index$1$lcssa = $115;$numIntegrated$1$lcssa = $116;
   } else {
    $index$1$lcssa = $index$027;$numIntegrated$1$lcssa = $numIntegrated$026;
   }
   $117 = ($atomRemainder$025|0)==($17|0);
   if ($117) {
    $118 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomIntegrationListIndex,32)|0);
    $119 = (($118) + -32)|0;
    $atomRemainder$0$be = 32;$index$0$be = $119;
   } else {
    $atomRemainder$0$be = $18;$index$0$be = $index$1$lcssa;
   }
   $120 = ($index$0$be|0)<($_numArtics|0);
   if ($120) {
    $atomRemainder$025 = $atomRemainder$0$be;$index$027 = $index$0$be;$numIntegrated$026 = $numIntegrated$1$lcssa;
   } else {
    $atomRemainder$0$lcssa = $atomRemainder$0$be;$index$0$lcssa = $index$0$be;$numIntegrated$0$lcssa = $numIntegrated$1$lcssa;
    break;
   }
  }
 } else {
  $atomRemainder$0$lcssa = 32;$index$0$lcssa = $9;$numIntegrated$0$lcssa = 0;
 }
 $121 = (($index$0$lcssa) - ($_numArtics))|0;
 $122 = ($121|0)<($atomListSize|0);
 if (!($122)) {
  $numIntegrated$2$lcssa = $numIntegrated$0$lcssa;
  (__ZN5physx6shdfnd9atomicAddEPVii($pNumObjectsIntegrated,$numIntegrated$2$lcssa)|0);
  STACKTOP = sp;return;
 }
 $$neg = (-32 - ($_numArtics))|0;
 $123 = (($atomListSize) + -1)|0;
 $124 = $atomListSize ^ -1;
 $atomRemainder$18 = $atomRemainder$0$lcssa;$index$210 = $121;$numIntegrated$29 = $numIntegrated$0$lcssa;
 while(1) {
  $125 = (($atomListSize) - ($index$210))|0;
  $126 = ($125|0)<($atomRemainder$18|0);
  $127 = $126 ? $125 : $atomRemainder$18;
  $128 = ($127|0)>(0);
  if ($128) {
   $129 = $atomRemainder$18 ^ -1;
   $130 = (($index$210) + ($124))|0;
   $131 = ($130|0)<($129|0);
   $smax = $131 ? $129 : $130;
   $132 = $smax ^ -1;
   $a2$05 = 0;$index$37 = $index$210;
   while(1) {
    $133 = (($index$37) + 4)|0;
    $134 = ($133|0)<($123|0);
    $135 = $134 ? $133 : $123;
    $136 = (($bodyArray) + ($135<<2)|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = HEAP32[$136>>2]|0;
    $139 = (($138) + 128|0);
    $140 = (($atomListStart) + ($133<<5)|0);
    $141 = (($motionVelocityArray) + ($133<<5)|0);
    $142 = (($index$37) + 32)|0;
    $143 = (($bodyArray) + ($142<<2)|0);
    $144 = (($rigidBodies) + ($135<<2)|0);
    $145 = HEAP32[$normalIterations>>2]|0;
    $146 = ((($atomListStart) + ($index$37<<5)|0) + 12|0);
    $147 = HEAP16[$146>>1]|0;
    $148 = $147&65535;
    $149 = Math_imul($148, $145)|0;
    $150 = HEAP32[$frictionIterations>>2]|0;
    $151 = ((($atomListStart) + ($index$37<<5)|0) + 14|0);
    $152 = HEAP16[$151>>1]|0;
    $153 = $152&65535;
    $154 = Math_imul($153, $150)|0;
    $155 = (($154) + ($149))|0;
    $156 = ((($atomListStart) + ($index$37<<5)|0) + 28|0);
    while(1) {
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)==($155|0);
     if ($158) {
      break;
     }
    }
    $159 = (($motionVelocityArray) + ($index$37<<5)|0);
    $160 = (($bodyArray) + ($index$37<<2)|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = (($rigidBodies) + ($index$37<<2)|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = Math_fround(HEAPF32[$6>>2]);
    __ZN5physx13integrateCoreERNS_11PxsBodyCoreERNS_12PxsRigidBodyERNS_2Cm13SpatialVectorEf($161,$163,$159,$164);
    $165 = (($a2$05) + 1)|0;
    $166 = (($index$37) + 1)|0;
    $exitcond = ($165|0)==($132|0);
    if ($exitcond) {
     break;
    } else {
     $a2$05 = $165;$index$37 = $166;
    }
   }
   $167 = (($numIntegrated$29) + -1)|0;
   $168 = (($167) - ($smax))|0;
   $numIntegrated$3$lcssa = $168;
  } else {
   $numIntegrated$3$lcssa = $numIntegrated$29;
  }
  $169 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomIntegrationListIndex,32)|0);
  $170 = (($$neg) + ($169))|0;
  $171 = ($170|0)<($atomListSize|0);
  if ($171) {
   $atomRemainder$18 = 32;$index$210 = $170;$numIntegrated$29 = $numIntegrated$3$lcssa;
  } else {
   $numIntegrated$2$lcssa = $numIntegrated$3$lcssa;
   break;
  }
 }
 (__ZN5physx6shdfnd9atomicAddEPVii($pNumObjectsIntegrated,$numIntegrated$2$lcssa)|0);
 STACKTOP = sp;return;
}
function __ZN5physx13integrateCoreERNS_11PxsBodyCoreERNS_12PxsRigidBodyERNS_2Cm13SpatialVectorEf($core,$body,$motionVelocity,$dt) {
 $core = $core|0;
 $body = $body|0;
 $motionVelocity = $motionVelocity|0;
 $dt = Math_fround($dt);
 var $$pre = Math_fround(0), $$pre14 = Math_fround(0), $$pre15 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0);
 var $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0);
 var $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $phitmp = Math_fround(0), $phitmp12 = Math_fround(0), $phitmp13 = Math_fround(0), $w$011 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$motionVelocity>>2]);
 $1 = Math_fround($0 * $dt);
 $2 = (($motionVelocity) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $dt);
 $5 = (($motionVelocity) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $dt);
 $8 = (($motionVelocity) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = (($motionVelocity) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($motionVelocity) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($core) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($1 + $20);
 HEAPF32[$19>>2] = $21;
 $22 = (($core) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($4 + $23);
 HEAPF32[$22>>2] = $24;
 $25 = (($core) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($7 + $26);
 HEAPF32[$25>>2] = $27;
 $28 = Math_fround(HEAPF32[$motionVelocity>>2]);
 HEAPF32[$body>>2] = $28;
 $29 = Math_fround(HEAPF32[$2>>2]);
 $30 = (($body) + 4|0);
 HEAPF32[$30>>2] = $29;
 $31 = Math_fround(HEAPF32[$5>>2]);
 $32 = (($body) + 8|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($body) + 12|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = Math_fround(HEAPF32[$8>>2]);
 $35 = (($body) + 16|0);
 HEAPF32[$35>>2] = $34;
 $36 = Math_fround(HEAPF32[$11>>2]);
 $37 = (($body) + 20|0);
 HEAPF32[$37>>2] = $36;
 $38 = Math_fround(HEAPF32[$15>>2]);
 $39 = (($body) + 24|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($body) + 28|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (Math_fround(Math_sqrt((Math_fround($18)))));
 $42 = $41 > Math_fround(1.0E+7);
 do {
  if ($42) {
   $43 = Math_fround(HEAPF32[$8>>2]);
   $44 = Math_fround($43 * $43);
   $45 = Math_fround(HEAPF32[$11>>2]);
   $46 = Math_fround($45 * $45);
   $47 = Math_fround($44 + $46);
   $48 = Math_fround(HEAPF32[$15>>2]);
   $49 = Math_fround($48 * $48);
   $50 = Math_fround($47 + $49);
   $51 = $50 > Math_fround(0.0);
   if ($51) {
    $52 = (Math_fround(Math_sqrt((Math_fround($50)))));
    $53 = Math_fround(Math_fround(1.0) / $52);
    $54 = Math_fround($43 * $53);
    $55 = Math_fround($45 * $53);
    $56 = Math_fround($48 * $53);
    $phitmp = Math_fround($54 * Math_fround(1.0E+7));
    $phitmp12 = Math_fround($55 * Math_fround(1.0E+7));
    $phitmp13 = Math_fround($56 * Math_fround(1.0E+7));
    $57 = $phitmp;$58 = $phitmp12;$59 = $phitmp13;
   } else {
    $57 = Math_fround(0.0);$58 = Math_fround(0.0);$59 = Math_fround(0.0);
   }
   HEAPF32[$8>>2] = $57;
   HEAPF32[$11>>2] = $58;
   HEAPF32[$15>>2] = $59;
   $67 = $57;$69 = $58;$71 = $59;$w$011 = Math_fround(1.0E+7);
  } else {
   $60 = $41 != Math_fround(0.0);
   if ($60) {
    $$pre = Math_fround(HEAPF32[$8>>2]);
    $$pre14 = Math_fround(HEAPF32[$11>>2]);
    $$pre15 = Math_fround(HEAPF32[$15>>2]);
    $67 = $$pre;$69 = $$pre14;$71 = $$pre15;$w$011 = $41;
    break;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $61 = Math_fround($w$011 * $dt);
 $62 = Math_fround($61 * Math_fround(0.5));
 $63 = (Math_fround(+(Math_sin((+$62)))));
 $64 = (Math_fround(+(Math_cos((+$62)))));
 $65 = Math_fround($63 / $w$011);
 $66 = Math_fround($65 * $67);
 $68 = Math_fround($65 * $69);
 $70 = Math_fround($65 * $71);
 $72 = Math_fround(HEAPF32[$core>>2]);
 $73 = Math_fround($72 * Math_fround(0.0));
 $74 = (($core) + 12|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($66 * $75);
 $77 = Math_fround($73 + $76);
 $78 = (($core) + 8|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($68 * $79);
 $81 = Math_fround($77 + $80);
 $82 = (($core) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($70 * $83);
 $85 = Math_fround($81 - $84);
 $86 = Math_fround($83 * Math_fround(0.0));
 $87 = Math_fround($68 * $75);
 $88 = Math_fround($87 + $86);
 $89 = Math_fround($72 * $70);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($66 * $79);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($79 * Math_fround(0.0));
 $94 = Math_fround($70 * $75);
 $95 = Math_fround($94 + $93);
 $96 = Math_fround($66 * $83);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($68 * $72);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($75 * Math_fround(0.0));
 $101 = Math_fround($66 * $72);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($68 * $83);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($70 * $79);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($64 * $72);
 $108 = Math_fround($64 * $83);
 $109 = Math_fround($64 * $79);
 $110 = Math_fround($64 * $75);
 $111 = Math_fround($107 + $85);
 $112 = Math_fround($108 + $92);
 $113 = Math_fround($109 + $99);
 $114 = Math_fround($110 + $106);
 $115 = Math_fround($111 * $111);
 $116 = Math_fround($112 * $112);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($113 * $113);
 $119 = Math_fround($118 + $117);
 $120 = Math_fround($114 * $114);
 $121 = Math_fround($120 + $119);
 $122 = (Math_fround(Math_sqrt((Math_fround($121)))));
 $123 = Math_fround(Math_fround(1.0) / $122);
 $124 = Math_fround($123 * $111);
 $125 = Math_fround($123 * $112);
 $126 = Math_fround($123 * $113);
 $127 = Math_fround($123 * $114);
 HEAPF32[$core>>2] = $124;
 HEAPF32[$82>>2] = $125;
 HEAPF32[$78>>2] = $126;
 HEAPF32[$74>>2] = $127;
 STACKTOP = sp;return;
}
function __Z31createFinalizeContacts_ParallelN5physx14PxFrictionType4EnumEPNS_23PxcSolverConstraintDescEPNS_17PxcSolverBodyDataEjRNS_16PxsThreadContextEPiffffPNS_10PxsContextES8_($frictionType,$0,$solverBodyData,$1,$mThreadContext,$pIndex,$dt,$invDt,$bounceThreshold,$frictionOffsetThreshold,$context,$pAxisConstraintCount) {
 $frictionType = $frictionType|0;
 $0 = $0|0;
 $solverBodyData = $solverBodyData|0;
 $1 = $1|0;
 $mThreadContext = $mThreadContext|0;
 $pIndex = $pIndex|0;
 $dt = Math_fround($dt);
 $invDt = Math_fround($invDt);
 $bounceThreshold = Math_fround($bounceThreshold);
 $frictionOffsetThreshold = Math_fround($frictionOffsetThreshold);
 $context = $context|0;
 $pAxisConstraintCount = $pAxisConstraintCount|0;
 var $$$i$i$i$i$i = 0, $$0$i$i = 0, $$lcssa10 = 0, $$lcssa8 = 0, $$pre = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$sum = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0);
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $a$0$ph39 = 0, $a$033 = 0, $axisConstraintCount$0$lcssa = 0, $axisConstraintCount$045 = 0, $axisConstraintCount$1$ph$be = 0, $axisConstraintCount$1$ph38 = 0, $axisConstraintCount$1$ph40 = 0, $axisConstraintCount$224 = 0, $axisConstraintCount$319 = 0, $core0 = 0, $core1 = 0, $descs = 0, $descs10 = 0, $exitcond = 0, $i$06 = 0, $i1$03 = 0, $i11$016 = 0, $i14$018 = 0, $i4$011 = 0;
 var $i6$023 = 0, $id = 0, $index$0 = 0, $index$0$in44 = 0, $index$043 = 0, $index$046 = 0, $n = 0, $phitmp = 0, $phitmp1 = 0, $rv$0$i$i = 0, $sBody0 = 0, $sBody1 = 0, $sbd0 = 0, $sbd1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $n = sp + 352|0;
 $descs = sp + 336|0;
 $sBody0 = sp + 320|0;
 $sBody1 = sp + 304|0;
 $sbd0 = sp + 288|0;
 $sbd1 = sp + 272|0;
 $core0 = sp + 48|0;
 $core1 = sp + 32|0;
 $id = sp;
 $descs10 = sp + 64|0;
 $2 = (($mThreadContext) + 9168|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($mThreadContext) + 9180|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($mThreadContext) + 9184|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($context) + 224|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZN5physx6shdfnd9SListImpl3popEv($9)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (__Z15PxGetFoundationv()|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
  $$$i$i$i$i$i = $20 ? 492696 : 491832;
  $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,9459,$$$i$i$i$i$i,492592,82)|0);
  $22 = ($21|0)==(0|0);
  if ($22) {
   $rv$0$i$i = 0;
  } else {
   $23 = (($21) + 19|0);
   $24 = $23;
   $25 = $24 & -16;
   $26 = $21;
   $27 = (($25) - ($26))|0;
   $28 = $25;
   $29 = (($28) + -4|0);
   HEAP32[$29>>2] = $27;
   $30 = $25;
   $31 = ($25|0)==(0);
   if ($31) {
    $rv$0$i$i = $30;
   } else {
    __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($30,$context);
    $rv$0$i$i = $30;
   }
  }
 } else {
  $rv$0$i$i = $10;
 }
 $32 = (($rv$0$i$i) + 16|0);
 $33 = (($rv$0$i$i) + 332|0);
 $34 = (($rv$0$i$i) + 336|0);
 HEAP32[$34>>2] = 0;
 $35 = (($rv$0$i$i) + 340|0);
 HEAP32[$35>>2] = 0;
 $36 = (__ZN5physx6shdfnd9atomicAddEPVii($pIndex,8)|0);
 $index$043 = (($36) + -8)|0;
 $37 = ($index$043|0)<($7|0);
 if (!($37)) {
  $axisConstraintCount$0$lcssa = 0;
  $372 = HEAP32[$8>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($372,$rv$0$i$i);
  (__ZN5physx6shdfnd9atomicAddEPVii($pAxisConstraintCount,$axisConstraintCount$0$lcssa)|0);
  STACKTOP = sp;return ($axisConstraintCount$0$lcssa|0);
 }
 $38 = (($7) + -1)|0;
 $39 = (($n) + 4|0);
 $40 = (($n) + 8|0);
 $41 = (($n) + 12|0);
 $42 = (($descs) + 4|0);
 $43 = (($descs) + 8|0);
 $44 = (($descs) + 12|0);
 $45 = (($sBody0) + 4|0);
 $46 = (($sBody0) + 8|0);
 $47 = (($sBody0) + 12|0);
 $48 = (($sBody1) + 4|0);
 $49 = (($sBody1) + 8|0);
 $50 = (($sBody1) + 12|0);
 $51 = (($sbd0) + 4|0);
 $52 = (($sbd0) + 8|0);
 $53 = (($sbd0) + 12|0);
 $54 = (($sbd1) + 4|0);
 $55 = (($sbd1) + 8|0);
 $56 = (($sbd1) + 12|0);
 $57 = (($core0) + 4|0);
 $58 = (($core0) + 8|0);
 $59 = (($core0) + 12|0);
 $60 = (($core1) + 4|0);
 $61 = (($core1) + 8|0);
 $62 = (($core1) + 12|0);
 $63 = (504440 + ($frictionType<<2)|0);
 $64 = (($mThreadContext) + 8800|0);
 $65 = (($mThreadContext) + 316|0);
 $66 = (($id) + 4|0);
 $67 = (($id) + 8|0);
 $68 = (($id) + 12|0);
 $69 = (($id) + 16|0);
 $70 = (($id) + 20|0);
 $71 = (($id) + 24|0);
 $72 = (504424 + ($frictionType<<2)|0);
 $axisConstraintCount$045 = 0;$index$0$in44 = $36;$index$046 = $index$043;
 while(1) {
  $73 = ($index$0$in44|0)<($7|0);
  $74 = $73 ? $index$0$in44 : $7;
  $75 = ($index$046>>>0)<($74>>>0);
  L11: do {
   if ($75) {
    $a$0$ph39 = $index$046;$axisConstraintCount$1$ph40 = $axisConstraintCount$045;
    while(1) {
     $a$033 = $a$0$ph39;
     while(1) {
      $77 = (($a$033) + 1)|0;
      $78 = ($77>>>0)<($38>>>0);
      $79 = $78 ? $77 : $38;
      $80 = (($5) + ($79<<3)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ((($3) + ($81<<5)|0) + 26|0);
      $83 = HEAP16[$82>>1]|0;
      L16: do {
       if ((($83<<16>>16) == 2)) {
        $87 = ((($5) + ($79<<3)|0) + 4|0);
        $88 = HEAP16[$87>>1]|0;
        $89 = ($88<<16>>16)==(0);
        if (!($89)) {
         $103 = $81;$i1$03 = 0;
         while(1) {
          $102 = (($103) + ($i1$03))|0;
          $104 = ((($3) + ($102<<5)|0) + 16|0);
          $105 = HEAP32[$104>>2]|0;
          $106 = (($105) + 28|0);
          $107 = HEAP32[$106>>2]|0;
          $108 = HEAP32[$106>>2]|0;
          $109 = (($108) + 128|0);
          $110 = HEAP32[$106>>2]|0;
          $111 = (($110) + 256|0);
          $112 = (($i1$03) + 1)|0;
          $113 = HEAP16[$87>>1]|0;
          $114 = $113&65535;
          $115 = ($112>>>0)<($114>>>0);
          if (!($115)) {
           break L16;
          }
          $$pre67 = HEAP32[$80>>2]|0;
          $103 = $$pre67;$i1$03 = $112;
         }
        }
       } else if ((($83<<16>>16) == 1)) {
        $84 = ((($5) + ($79<<3)|0) + 4|0);
        $85 = HEAP16[$84>>1]|0;
        $86 = ($85<<16>>16)==(0);
        if (!($86)) {
         $91 = $81;$i$06 = 0;
         while(1) {
          $90 = (($91) + ($i$06))|0;
          $92 = ((($3) + ($90<<5)|0) + 16|0);
          $93 = HEAP32[$92>>2]|0;
          $94 = (($93) + 44|0);
          $95 = HEAP32[$94>>2]|0;
          $96 = HEAP32[$94>>2]|0;
          $97 = (($96) + 128|0);
          $98 = (($i$06) + 1)|0;
          $99 = HEAP16[$84>>1]|0;
          $100 = $99&65535;
          $101 = ($98>>>0)<($100>>>0);
          if (!($101)) {
           break L16;
          }
          $$pre68 = HEAP32[$80>>2]|0;
          $91 = $$pre68;$i$06 = $98;
         }
        }
       }
      } while(0);
      $116 = (($a$033) + 2)|0;
      $117 = ($116>>>0)<($38>>>0);
      $118 = $117 ? $116 : $38;
      $119 = ((($5) + ($118<<3)|0) + 4|0);
      $120 = HEAP16[$119>>1]|0;
      $121 = $120&65535;
      $122 = ($120<<16>>16)==(0);
      $123 = (($5) + ($118<<3)|0);
      $124 = HEAP32[$123>>2]|0;
      if ($122) {
       $$lcssa10 = $124;$$lcssa8 = $121;
      } else {
       $126 = $124;$i4$011 = 0;
       while(1) {
        $125 = (($126) + ($i4$011))|0;
        $127 = ((($3) + ($125<<5)|0) + 16|0);
        $128 = HEAP32[$127>>2]|0;
        $129 = HEAP32[$123>>2]|0;
        $130 = (($129) + ($i4$011))|0;
        $131 = ((($3) + ($130<<5)|0) + 16|0);
        $132 = HEAP32[$131>>2]|0;
        $133 = (($132) + 128|0);
        $134 = (($i4$011) + 1)|0;
        $135 = HEAP16[$119>>1]|0;
        $136 = $135&65535;
        $137 = ($134>>>0)<($136>>>0);
        $138 = HEAP32[$123>>2]|0;
        if ($137) {
         $126 = $138;$i4$011 = $134;
        } else {
         $$lcssa10 = $138;$$lcssa8 = $136;
         break;
        }
       }
      }
      $139 = (($$lcssa10) + ($$lcssa8))|0;
      $140 = (($3) + ($139<<5)|0);
      $141 = HEAP32[$123>>2]|0;
      $142 = HEAP16[$119>>1]|0;
      $143 = $142&65535;
      $144 = (($141) + 4)|0;
      $$sum = (($144) + ($143))|0;
      $145 = (($3) + ($$sum<<5)|0);
      $146 = (($5) + ($a$033<<3)|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = (($3) + ($147<<5)|0);
      $149 = ((($3) + ($147<<5)|0) + 26|0);
      $150 = HEAP16[$149>>1]|0;
      if ((($150<<16>>16) == 1)) {
       $152 = ((($5) + ($a$033<<3)|0) + 4|0);
       $153 = HEAP16[$152>>1]|0;
       $154 = ($153<<16>>16)==(4);
       if (!($154)) {
        $237 = $153;
        label = 24;
        break;
       }
       $155 = (($147) + 1)|0;
       $156 = (($3) + ($155<<5)|0);
       $157 = (($147) + 2)|0;
       $158 = (($3) + ($157<<5)|0);
       $159 = (($147) + 3)|0;
       $160 = (($3) + ($159<<5)|0);
       $161 = ((($3) + ($147<<5)|0) + 16|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = ((($3) + ($155<<5)|0) + 16|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = ((($3) + ($157<<5)|0) + 16|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = ((($3) + ($159<<5)|0) + 16|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = (($162) + 16|0);
       HEAP32[$n>>2] = $169;
       $170 = (($164) + 16|0);
       HEAP32[$39>>2] = $170;
       $171 = (($166) + 16|0);
       HEAP32[$40>>2] = $171;
       $172 = (($168) + 16|0);
       HEAP32[$41>>2] = $172;
       HEAP32[$descs>>2] = $148;
       HEAP32[$42>>2] = $156;
       HEAP32[$43>>2] = $158;
       HEAP32[$44>>2] = $160;
       $173 = HEAP32[$148>>2]|0;
       HEAP32[$sBody0>>2] = $173;
       $174 = HEAP32[$156>>2]|0;
       HEAP32[$45>>2] = $174;
       $175 = HEAP32[$158>>2]|0;
       HEAP32[$46>>2] = $175;
       $176 = HEAP32[$160>>2]|0;
       HEAP32[$47>>2] = $176;
       $177 = ((($3) + ($147<<5)|0) + 4|0);
       $178 = HEAP32[$177>>2]|0;
       HEAP32[$sBody1>>2] = $178;
       $179 = ((($3) + ($155<<5)|0) + 4|0);
       $180 = HEAP32[$179>>2]|0;
       HEAP32[$48>>2] = $180;
       $181 = ((($3) + ($157<<5)|0) + 4|0);
       $182 = HEAP32[$181>>2]|0;
       HEAP32[$49>>2] = $182;
       $183 = ((($3) + ($159<<5)|0) + 4|0);
       $184 = HEAP32[$183>>2]|0;
       HEAP32[$50>>2] = $184;
       $185 = ((($3) + ($147<<5)|0) + 10|0);
       $186 = HEAP16[$185>>1]|0;
       $187 = $186&65535;
       $188 = (($solverBodyData) + ($187<<6)|0);
       HEAP32[$sbd0>>2] = $188;
       $189 = ((($3) + ($155<<5)|0) + 10|0);
       $190 = HEAP16[$189>>1]|0;
       $191 = $190&65535;
       $192 = (($solverBodyData) + ($191<<6)|0);
       HEAP32[$51>>2] = $192;
       $193 = ((($3) + ($157<<5)|0) + 10|0);
       $194 = HEAP16[$193>>1]|0;
       $195 = $194&65535;
       $196 = (($solverBodyData) + ($195<<6)|0);
       HEAP32[$52>>2] = $196;
       $197 = ((($3) + ($159<<5)|0) + 10|0);
       $198 = HEAP16[$197>>1]|0;
       $199 = $198&65535;
       $200 = (($solverBodyData) + ($199<<6)|0);
       HEAP32[$53>>2] = $200;
       $201 = ((($3) + ($147<<5)|0) + 14|0);
       $202 = HEAP16[$201>>1]|0;
       $203 = $202&65535;
       $204 = (($solverBodyData) + ($203<<6)|0);
       HEAP32[$sbd1>>2] = $204;
       $205 = ((($3) + ($155<<5)|0) + 14|0);
       $206 = HEAP16[$205>>1]|0;
       $207 = $206&65535;
       $208 = (($solverBodyData) + ($207<<6)|0);
       HEAP32[$54>>2] = $208;
       $209 = ((($3) + ($157<<5)|0) + 14|0);
       $210 = HEAP16[$209>>1]|0;
       $211 = $210&65535;
       $212 = (($solverBodyData) + ($211<<6)|0);
       HEAP32[$55>>2] = $212;
       $213 = ((($3) + ($159<<5)|0) + 14|0);
       $214 = HEAP16[$213>>1]|0;
       $215 = $214&65535;
       $216 = (($solverBodyData) + ($215<<6)|0);
       HEAP32[$56>>2] = $216;
       $217 = (($162) + 80|0);
       $218 = HEAP32[$217>>2]|0;
       HEAP32[$core0>>2] = $218;
       $219 = (($164) + 80|0);
       $220 = HEAP32[$219>>2]|0;
       HEAP32[$57>>2] = $220;
       $221 = (($166) + 80|0);
       $222 = HEAP32[$221>>2]|0;
       HEAP32[$58>>2] = $222;
       $223 = (($168) + 80|0);
       $224 = HEAP32[$223>>2]|0;
       HEAP32[$59>>2] = $224;
       $225 = (($162) + 84|0);
       $226 = HEAP32[$225>>2]|0;
       HEAP32[$core1>>2] = $226;
       $227 = (($164) + 84|0);
       $228 = HEAP32[$227>>2]|0;
       HEAP32[$60>>2] = $228;
       $229 = (($166) + 84|0);
       $230 = HEAP32[$229>>2]|0;
       HEAP32[$61>>2] = $230;
       $231 = (($168) + 84|0);
       $232 = HEAP32[$231>>2]|0;
       HEAP32[$62>>2] = $232;
       $233 = HEAP32[$63>>2]|0;
       $234 = Math_fround(HEAPF32[$64>>2]);
       $235 = (FUNCTION_TABLE_iiiiiiiiiiffffii[$233 & 3]($n,$32,$descs,$sBody0,$sBody1,$sbd0,$sbd1,$core0,$core1,$invDt,$bounceThreshold,$frictionOffsetThreshold,$234,$65,$frictionType)|0);
       $phitmp1 = ($235|0)==(1);
       if ($phitmp1) {
        label = 23;
        break;
       }
      } else if ((($150<<16>>16) == 2)) {
       $299 = ((($5) + ($a$033<<3)|0) + 4|0);
       $300 = HEAP16[$299>>1]|0;
       $301 = ($300<<16>>16)==(4);
       if (!($301)) {
        $358 = $300;
        label = 46;
        break;
       }
       HEAPF32[$id>>2] = Math_fround(0.0);
       HEAPF32[$66>>2] = Math_fround(0.0);
       HEAPF32[$67>>2] = Math_fround(0.0);
       HEAPF32[$68>>2] = Math_fround(1.0);
       HEAPF32[$69>>2] = Math_fround(0.0);
       HEAPF32[$70>>2] = Math_fround(0.0);
       HEAPF32[$71>>2] = Math_fround(0.0);
       $303 = $147;$i11$016 = 0;
       while(1) {
        $302 = (($303) + ($i11$016))|0;
        $304 = (($3) + ($302<<5)|0);
        $305 = ((($3) + ($302<<5)|0) + 16|0);
        $306 = HEAP32[$305>>2]|0;
        $307 = (($306) + 16|0);
        $308 = HEAP32[$307>>2]|0;
        $309 = (($306) + 28|0);
        $310 = HEAP32[$309>>2]|0;
        $311 = (($306) + 12|0);
        $312 = HEAP32[$311>>2]|0;
        $313 = (($306) + 36|0);
        $314 = HEAP32[$313>>2]|0;
        $315 = ($314|0)==(0|0);
        if ($315) {
         $347 = $id;
        } else {
         $316 = (($314) + 64|0);
         $317 = HEAP32[$316>>2]|0;
         $347 = $317;
        }
        $318 = (($306) + 40|0);
        $319 = HEAP32[$318>>2]|0;
        $320 = ($319|0)==(0|0);
        if ($320) {
         $349 = $id;
        } else {
         $321 = (($319) + 64|0);
         $322 = HEAP32[$321>>2]|0;
         $349 = $322;
        }
        $323 = HEAP32[$304>>2]|0;
        $324 = ((($3) + ($302<<5)|0) + 4|0);
        $325 = HEAP32[$324>>2]|0;
        $326 = ((($3) + ($302<<5)|0) + 8|0);
        $327 = HEAP16[$326>>1]|0;
        $328 = ($327<<16>>16)==(-1);
        if ($328) {
         $329 = ((($3) + ($302<<5)|0) + 10|0);
         $330 = HEAP16[$329>>1]|0;
         $331 = $330&65535;
         $333 = $331;
        } else {
         $333 = 0;
        }
        $332 = (($solverBodyData) + ($333<<6)|0);
        $334 = ((($3) + ($302<<5)|0) + 12|0);
        $335 = HEAP16[$334>>1]|0;
        $336 = ($335<<16>>16)==(-1);
        if ($336) {
         $337 = ((($3) + ($302<<5)|0) + 14|0);
         $338 = HEAP16[$337>>1]|0;
         $339 = $338&65535;
         $341 = $339;
        } else {
         $341 = 0;
        }
        $340 = (($solverBodyData) + ($341<<6)|0);
        $342 = ((($descs10) + (($i11$016*52)|0)|0) + 32|0);
        HEAP32[$342>>2] = $310;
        $343 = ((($descs10) + (($i11$016*52)|0)|0) + 36|0);
        HEAP32[$343>>2] = $312;
        $344 = (($descs10) + (($i11$016*52)|0)|0);
        HEAP32[$344>>2] = $306;
        $345 = ((($descs10) + (($i11$016*52)|0)|0) + 40|0);
        HEAP32[$345>>2] = $304;
        $346 = ((($descs10) + (($i11$016*52)|0)|0) + 4|0);
        HEAP32[$346>>2] = $347;
        $348 = ((($descs10) + (($i11$016*52)|0)|0) + 8|0);
        HEAP32[$348>>2] = $349;
        $350 = ((($descs10) + (($i11$016*52)|0)|0) + 20|0);
        HEAP32[$350>>2] = $332;
        $351 = ((($descs10) + (($i11$016*52)|0)|0) + 24|0);
        HEAP32[$351>>2] = $340;
        $352 = ((($descs10) + (($i11$016*52)|0)|0) + 12|0);
        HEAP32[$352>>2] = $323;
        $353 = ((($descs10) + (($i11$016*52)|0)|0) + 16|0);
        HEAP32[$353>>2] = $325;
        $354 = ((($descs10) + (($i11$016*52)|0)|0) + 28|0);
        HEAP32[$354>>2] = $308;
        $355 = (($i11$016) + 1)|0;
        $exitcond = ($355|0)==(4);
        if ($exitcond) {
         break;
        }
        $$pre65 = HEAP32[$146>>2]|0;
        $303 = $$pre65;$i11$016 = $355;
       }
       $356 = (__ZN5physx22setupSolverConstraint4EPNS_24PxcSolverConstraint4DescEffRNS_24PxcConstraintBlockStreamERNS_25PxsConstraintBlockManagerE($descs10,$dt,$invDt,$33,$65)|0);
       $phitmp = ($356|0)==(1);
       if ($phitmp) {
        label = 45;
        break;
       }
      }
      $151 = ($77>>>0)<($74>>>0);
      if ($151) {
       $a$033 = $77;
      } else {
       $axisConstraintCount$1$ph38 = $axisConstraintCount$1$ph40;
       break L11;
      }
     }
     if ((label|0) == 23) {
      label = 0;
      $$pre = HEAP16[$152>>1]|0;
      $237 = $$pre;
      label = 24;
     }
     else if ((label|0) == 45) {
      label = 0;
      $$pre66 = HEAP16[$299>>1]|0;
      $358 = $$pre66;
      label = 46;
     }
     if ((label|0) == 24) {
      label = 0;
      $236 = ($237<<16>>16)==(0);
      if ($236) {
       $axisConstraintCount$1$ph$be = $axisConstraintCount$1$ph40;
      } else {
       $axisConstraintCount$224 = $axisConstraintCount$1$ph40;$i6$023 = 0;
       while(1) {
        $238 = HEAP32[$146>>2]|0;
        $239 = (($238) + ($i6$023))|0;
        $240 = (($3) + ($239<<5)|0);
        $241 = ((($3) + ($239<<5)|0) + 16|0);
        $242 = HEAP32[$241>>2]|0;
        $243 = (($242) + 16|0);
        $244 = ((($3) + ($239<<5)|0) + 8|0);
        $245 = HEAP16[$244>>1]|0;
        $246 = ($245<<16>>16)==(-1);
        if ($246) {
         $247 = ((($3) + ($239<<5)|0) + 10|0);
         $248 = HEAP16[$247>>1]|0;
         $249 = $248&65535;
         $250 = (($solverBodyData) + ($249<<6)|0);
         $267 = $250;
        } else {
         $267 = $solverBodyData;
        }
        $251 = ((($3) + ($239<<5)|0) + 12|0);
        $252 = HEAP16[$251>>1]|0;
        $253 = ($252<<16>>16)==(-1);
        if ($253) {
         $254 = ((($3) + ($239<<5)|0) + 14|0);
         $255 = HEAP16[$254>>1]|0;
         $256 = $255&65535;
         $257 = (($solverBodyData) + ($256<<6)|0);
         $268 = $257;
        } else {
         $268 = $solverBodyData;
        }
        $258 = HEAP32[$72>>2]|0;
        $259 = HEAP32[$240>>2]|0;
        $260 = ((($3) + ($239<<5)|0) + 4|0);
        $261 = HEAP32[$260>>2]|0;
        $262 = (($242) + 80|0);
        $263 = HEAP32[$262>>2]|0;
        $264 = (($242) + 84|0);
        $265 = HEAP32[$264>>2]|0;
        $266 = Math_fround(HEAPF32[$64>>2]);
        (FUNCTION_TABLE_iiiiiiiiiiiiffffii[$258 & 3]($243,$32,0,0,$240,$259,$261,$267,$268,$263,$265,$invDt,$bounceThreshold,$frictionOffsetThreshold,$266,$65,$frictionType)|0);
        $269 = (($242) + 20|0);
        $270 = HEAP32[$269>>2]|0;
        $271 = $270 >>> 4;
        $272 = $271&65535;
        $273 = ((($3) + ($239<<5)|0) + 26|0);
        HEAP16[$273>>1] = $272;
        $274 = HEAP32[$243>>2]|0;
        HEAP32[$241>>2] = $274;
        $275 = (($242) + 114|0);
        $276 = HEAP16[$275>>1]|0;
        $277 = $276 & 16;
        $278 = ($277<<16>>16)==(0);
        if ($278) {
         $$0$i$i = 0;$290 = 0;
        } else {
         $279 = (($242) + 36|0);
         $280 = HEAP16[$279>>1]|0;
         $281 = (($242) + 44|0);
         $282 = HEAP32[$281>>2]|0;
         $283 = (($242) + 48|0);
         $284 = HEAP32[$283>>2]|0;
         $285 = (($284) + 15)|0;
         $286 = $285 & -16;
         $287 = (($282) + ($286)|0);
         $$0$i$i = $287;$290 = $280;
        }
        $288 = ((($3) + ($239<<5)|0) + 20|0);
        HEAP32[$288>>2] = $$0$i$i;
        $289 = ((($3) + ($239<<5)|0) + 24|0);
        HEAP16[$289>>1] = $290;
        $291 = (($242) + 32|0);
        $292 = HEAP16[$291>>1]|0;
        $293 = $292&65535;
        $294 = (($293) + ($axisConstraintCount$224))|0;
        $295 = (($i6$023) + 1)|0;
        $296 = HEAP16[$152>>1]|0;
        $297 = $296&65535;
        $298 = ($295>>>0)<($297>>>0);
        if ($298) {
         $axisConstraintCount$224 = $294;$i6$023 = $295;
        } else {
         $axisConstraintCount$1$ph$be = $294;
         break;
        }
       }
      }
     }
     else if ((label|0) == 46) {
      label = 0;
      $357 = ($358<<16>>16)==(0);
      if ($357) {
       $axisConstraintCount$1$ph$be = $axisConstraintCount$1$ph40;
      } else {
       $axisConstraintCount$319 = $axisConstraintCount$1$ph40;$i14$018 = 0;
       while(1) {
        $359 = HEAP32[$146>>2]|0;
        $360 = (($359) + ($i14$018))|0;
        $361 = (($3) + ($360<<5)|0);
        $362 = ((($3) + ($360<<5)|0) + 16|0);
        $363 = HEAP32[$362>>2]|0;
        $364 = (__ZN5physx24PxsSetupSolverConstraintEPKNS_13PxsConstraintEPNS_17PxcSolverBodyDataERNS_24PxcConstraintBlockStreamEffRNS_23PxcSolverConstraintDescERNS_25PxsConstraintBlockManagerE($363,$solverBodyData,$33,$dt,$invDt,$361,$65)|0);
        $365 = (($364) + ($axisConstraintCount$319))|0;
        $366 = (($i14$018) + 1)|0;
        $367 = HEAP16[$299>>1]|0;
        $368 = $367&65535;
        $369 = ($366>>>0)<($368>>>0);
        if ($369) {
         $axisConstraintCount$319 = $365;$i14$018 = $366;
        } else {
         $axisConstraintCount$1$ph$be = $365;
         break;
        }
       }
      }
     }
     $76 = ($77>>>0)<($74>>>0);
     if ($76) {
      $a$0$ph39 = $77;$axisConstraintCount$1$ph40 = $axisConstraintCount$1$ph$be;
     } else {
      $axisConstraintCount$1$ph38 = $axisConstraintCount$1$ph$be;
      break;
     }
    }
   } else {
    $axisConstraintCount$1$ph38 = $axisConstraintCount$045;
   }
  } while(0);
  $370 = (__ZN5physx6shdfnd9atomicAddEPVii($pIndex,8)|0);
  $index$0 = (($370) + -8)|0;
  $371 = ($index$0|0)<($7|0);
  if ($371) {
   $axisConstraintCount$045 = $axisConstraintCount$1$ph38;$index$0$in44 = $370;$index$046 = $index$0;
  } else {
   $axisConstraintCount$0$lcssa = $axisConstraintCount$1$ph38;
   break;
  }
 }
 $372 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($372,$rv$0$i$i);
 (__ZN5physx6shdfnd9atomicAddEPVii($pAxisConstraintCount,$axisConstraintCount$0$lcssa)|0);
 STACKTOP = sp;return ($axisConstraintCount$0$lcssa|0);
}
function __ZN5physx18PxsDynamicsContext22createFinalizeContactsENS_14PxFrictionType4EnumEPNS_23PxcSolverConstraintDescEPNS_17PxcSolverBodyDataEjPNS_10PxBaseTaskERNS_16PxsThreadContextE($this,$frictionType,$0,$solverBodyData,$1,$2,$mThreadContext) {
 $this = $this|0;
 $frictionType = $frictionType|0;
 $0 = $0|0;
 $solverBodyData = $solverBodyData|0;
 $1 = $1|0;
 $2 = $2|0;
 $mThreadContext = $mThreadContext|0;
 var $$$i$i$i$i$i = 0, $$0$i$i = 0, $$0$i$i7 = 0, $$lcssa24 = 0, $$lcssa26 = 0, $$pre = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$sum = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0;
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0;
 var $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0;
 var $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0;
 var $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0;
 var $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0;
 var $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0;
 var $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = 0, $581 = Math_fround(0), $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0;
 var $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0;
 var $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0;
 var $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$044 = 0, $axisConstraintCount$0$lcssa = 0, $axisConstraintCount$045 = 0, $axisConstraintCount$141 = 0, $axisConstraintCount$235 = 0, $axisConstraintCount$3 = 0, $axisConstraintCount$410 = 0, $axisConstraintCount$514 = 0, $axisConstraintCount$6 = 0, $core0 = 0, $core053 = 0;
 var $core1 = 0, $core154 = 0, $descs = 0, $descs13 = 0, $descs48 = 0, $exitcond = 0, $exitcond53 = 0, $exitcond55 = 0, $i$022 = 0, $i1$018 = 0, $i14$034 = 0, $i23$011 = 0, $i35$09 = 0, $i4$027 = 0, $i5$038 = 0, $i55$013 = 0, $i8$040 = 0, $id = 0, $id21 = 0, $n = 0;
 var $n47 = 0, $phitmp = 0, $phitmp1 = 0, $phitmp2 = 0, $phitmp3 = 0, $rv$0$i$i = 0, $sBody0 = 0, $sBody049 = 0, $sBody1 = 0, $sBody150 = 0, $sbd0 = 0, $sbd051 = 0, $sbd1 = 0, $sbd152 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $id = sp + 496|0;
 $descs = sp + 288|0;
 $n = sp + 272|0;
 $descs13 = sp + 256|0;
 $sBody0 = sp + 240|0;
 $sBody1 = sp + 224|0;
 $sbd0 = sp + 208|0;
 $sbd1 = sp + 192|0;
 $core0 = sp + 176|0;
 $core1 = sp + 160|0;
 $id21 = sp + 48|0;
 $n47 = sp;
 $descs48 = sp + 16|0;
 $sBody049 = sp + 32|0;
 $sBody150 = sp + 80|0;
 $sbd051 = sp + 96|0;
 $sbd152 = sp + 112|0;
 $core053 = sp + 128|0;
 $core154 = sp + 144|0;
 $3 = (($mThreadContext) + 9168|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($mThreadContext) + 9180|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($mThreadContext) + 9184|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($mThreadContext) + 9268|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 124|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 128|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 96|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 224|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (__ZN5physx6shdfnd9SListImpl3popEv($18)|0);
 $20 = ($19|0)==(0|0);
 if ($20) {
  $21 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (__Z15PxGetFoundationv()|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 24|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (FUNCTION_TABLE_ii[$28 & 4095]($25)|0);
  $$$i$i$i$i$i = $29 ? 492696 : 491832;
  $30 = (FUNCTION_TABLE_iiiiii[$24 & 255]($21,9459,$$$i$i$i$i$i,492592,82)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $rv$0$i$i = 0;
  } else {
   $32 = (($30) + 19|0);
   $33 = $32;
   $34 = $33 & -16;
   $35 = $30;
   $36 = (($34) - ($35))|0;
   $37 = $34;
   $38 = (($37) + -4|0);
   HEAP32[$38>>2] = $36;
   $39 = $34;
   $40 = ($34|0)==(0);
   if ($40) {
    $rv$0$i$i = $39;
   } else {
    __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($39,$16);
    $rv$0$i$i = $39;
   }
  }
 } else {
  $rv$0$i$i = $19;
 }
 $41 = (($rv$0$i$i) + 16|0);
 $42 = (($rv$0$i$i) + 332|0);
 $43 = (($rv$0$i$i) + 336|0);
 HEAP32[$43>>2] = 0;
 $44 = (($rv$0$i$i) + 340|0);
 HEAP32[$44>>2] = 0;
 $45 = ($8>>>0)>(1);
 if ($45) {
  $46 = (($8) + -1)|0;
  $47 = (($id) + 4|0);
  $48 = (($id) + 8|0);
  $49 = (($id) + 12|0);
  $50 = (($id) + 16|0);
  $51 = (($id) + 20|0);
  $52 = (($id) + 24|0);
  $53 = (($mThreadContext) + 316|0);
  $54 = (($n) + 4|0);
  $55 = (($n) + 8|0);
  $56 = (($n) + 12|0);
  $57 = (($descs13) + 4|0);
  $58 = (($descs13) + 8|0);
  $59 = (($descs13) + 12|0);
  $60 = (($sBody0) + 4|0);
  $61 = (($sBody0) + 8|0);
  $62 = (($sBody0) + 12|0);
  $63 = (($sBody1) + 4|0);
  $64 = (($sBody1) + 8|0);
  $65 = (($sBody1) + 12|0);
  $66 = (($sbd0) + 4|0);
  $67 = (($sbd0) + 8|0);
  $68 = (($sbd0) + 12|0);
  $69 = (($sbd1) + 4|0);
  $70 = (($sbd1) + 8|0);
  $71 = (($sbd1) + 12|0);
  $72 = (($core0) + 4|0);
  $73 = (($core0) + 8|0);
  $74 = (($core0) + 12|0);
  $75 = (($core1) + 4|0);
  $76 = (($core1) + 8|0);
  $77 = (($core1) + 12|0);
  $78 = (504440 + ($frictionType<<2)|0);
  $79 = (($this) + 140|0);
  $80 = (($this) + 144|0);
  $81 = (($mThreadContext) + 8800|0);
  $82 = (504424 + ($frictionType<<2)|0);
  $a$044 = 1;$axisConstraintCount$045 = $10;
  while(1) {
   $83 = (($a$044) + -1)|0;
   $84 = (($6) + ($a$044<<3)|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ((($4) + ($85<<5)|0) + 26|0);
   $87 = HEAP16[$86>>1]|0;
   L10: do {
    if ((($87<<16>>16) == 1)) {
     $88 = ((($6) + ($a$044<<3)|0) + 4|0);
     $89 = HEAP16[$88>>1]|0;
     $90 = ($89<<16>>16)==(0);
     if (!($90)) {
      $95 = $85;$i$022 = 0;
      while(1) {
       $94 = (($95) + ($i$022))|0;
       $96 = ((($4) + ($94<<5)|0) + 16|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = (($97) + 44|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = HEAP32[$98>>2]|0;
       $101 = (($100) + 128|0);
       $102 = (($i$022) + 1)|0;
       $103 = HEAP16[$88>>1]|0;
       $104 = $103&65535;
       $105 = ($102>>>0)<($104>>>0);
       if (!($105)) {
        break L10;
       }
       $$pre66 = HEAP32[$84>>2]|0;
       $95 = $$pre66;$i$022 = $102;
      }
     }
    } else if ((($87<<16>>16) == 2)) {
     $91 = ((($6) + ($a$044<<3)|0) + 4|0);
     $92 = HEAP16[$91>>1]|0;
     $93 = ($92<<16>>16)==(0);
     if (!($93)) {
      $107 = $85;$i1$018 = 0;
      while(1) {
       $106 = (($107) + ($i1$018))|0;
       $108 = ((($4) + ($106<<5)|0) + 16|0);
       $109 = HEAP32[$108>>2]|0;
       $110 = (($109) + 28|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = HEAP32[$110>>2]|0;
       $113 = (($112) + 128|0);
       $114 = HEAP32[$110>>2]|0;
       $115 = (($114) + 256|0);
       $116 = (($i1$018) + 1)|0;
       $117 = HEAP16[$91>>1]|0;
       $118 = $117&65535;
       $119 = ($116>>>0)<($118>>>0);
       if (!($119)) {
        break L10;
       }
       $$pre65 = HEAP32[$84>>2]|0;
       $107 = $$pre65;$i1$018 = $116;
      }
     }
    }
   } while(0);
   $120 = (($a$044) + 2)|0;
   $121 = ($120>>>0)<($46>>>0);
   $122 = $121 ? $120 : $46;
   $123 = ((($6) + ($122<<3)|0) + 4|0);
   $124 = HEAP16[$123>>1]|0;
   $125 = $124&65535;
   $126 = ($124<<16>>16)==(0);
   $127 = (($6) + ($122<<3)|0);
   $128 = HEAP32[$127>>2]|0;
   if ($126) {
    $$lcssa24 = $125;$$lcssa26 = $128;
   } else {
    $130 = $128;$i4$027 = 0;
    while(1) {
     $129 = (($130) + ($i4$027))|0;
     $131 = ((($4) + ($129<<5)|0) + 16|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = HEAP32[$127>>2]|0;
     $134 = (($133) + ($i4$027))|0;
     $135 = ((($4) + ($134<<5)|0) + 16|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = (($136) + 128|0);
     $138 = (($i4$027) + 1)|0;
     $139 = HEAP16[$123>>1]|0;
     $140 = $139&65535;
     $141 = ($138>>>0)<($140>>>0);
     $142 = HEAP32[$127>>2]|0;
     if ($141) {
      $130 = $142;$i4$027 = $138;
     } else {
      $$lcssa24 = $140;$$lcssa26 = $142;
      break;
     }
    }
   }
   $143 = (($$lcssa26) + ($$lcssa24))|0;
   $144 = (($4) + ($143<<5)|0);
   $145 = HEAP32[$127>>2]|0;
   $146 = HEAP16[$123>>1]|0;
   $147 = $146&65535;
   $148 = (($145) + 4)|0;
   $$sum = (($148) + ($147))|0;
   $149 = (($4) + ($$sum<<5)|0);
   $150 = (($6) + ($83<<3)|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (($4) + ($151<<5)|0);
   $153 = ((($4) + ($151<<5)|0) + 26|0);
   $154 = HEAP16[$153>>1]|0;
   do {
    if ((($154<<16>>16) == 2)) {
     $155 = ((($6) + ($83<<3)|0) + 4|0);
     $156 = HEAP16[$155>>1]|0;
     $157 = ($156<<16>>16)==(4);
     if ($157) {
      HEAPF32[$id>>2] = Math_fround(0.0);
      HEAPF32[$47>>2] = Math_fround(0.0);
      HEAPF32[$48>>2] = Math_fround(0.0);
      HEAPF32[$49>>2] = Math_fround(1.0);
      HEAPF32[$50>>2] = Math_fround(0.0);
      HEAPF32[$51>>2] = Math_fround(0.0);
      HEAPF32[$52>>2] = Math_fround(0.0);
      $159 = $151;$i5$038 = 0;
      while(1) {
       $158 = (($159) + ($i5$038))|0;
       $160 = (($4) + ($158<<5)|0);
       $161 = ((($4) + ($158<<5)|0) + 16|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = (($162) + 16|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = (($162) + 28|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = (($162) + 12|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = (($162) + 36|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = ($170|0)==(0|0);
       if ($171) {
        $203 = $id;
       } else {
        $172 = (($170) + 64|0);
        $173 = HEAP32[$172>>2]|0;
        $203 = $173;
       }
       $174 = (($162) + 40|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = ($175|0)==(0|0);
       if ($176) {
        $205 = $id;
       } else {
        $177 = (($175) + 64|0);
        $178 = HEAP32[$177>>2]|0;
        $205 = $178;
       }
       $179 = HEAP32[$160>>2]|0;
       $180 = ((($4) + ($158<<5)|0) + 4|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = ((($4) + ($158<<5)|0) + 8|0);
       $183 = HEAP16[$182>>1]|0;
       $184 = ($183<<16>>16)==(-1);
       if ($184) {
        $185 = ((($4) + ($158<<5)|0) + 10|0);
        $186 = HEAP16[$185>>1]|0;
        $187 = $186&65535;
        $189 = $187;
       } else {
        $189 = 0;
       }
       $188 = (($solverBodyData) + ($189<<6)|0);
       $190 = ((($4) + ($158<<5)|0) + 12|0);
       $191 = HEAP16[$190>>1]|0;
       $192 = ($191<<16>>16)==(-1);
       if ($192) {
        $193 = ((($4) + ($158<<5)|0) + 14|0);
        $194 = HEAP16[$193>>1]|0;
        $195 = $194&65535;
        $197 = $195;
       } else {
        $197 = 0;
       }
       $196 = (($solverBodyData) + ($197<<6)|0);
       $198 = ((($descs) + (($i5$038*52)|0)|0) + 32|0);
       HEAP32[$198>>2] = $166;
       $199 = ((($descs) + (($i5$038*52)|0)|0) + 36|0);
       HEAP32[$199>>2] = $168;
       $200 = (($descs) + (($i5$038*52)|0)|0);
       HEAP32[$200>>2] = $162;
       $201 = ((($descs) + (($i5$038*52)|0)|0) + 40|0);
       HEAP32[$201>>2] = $160;
       $202 = ((($descs) + (($i5$038*52)|0)|0) + 4|0);
       HEAP32[$202>>2] = $203;
       $204 = ((($descs) + (($i5$038*52)|0)|0) + 8|0);
       HEAP32[$204>>2] = $205;
       $206 = ((($descs) + (($i5$038*52)|0)|0) + 20|0);
       HEAP32[$206>>2] = $188;
       $207 = ((($descs) + (($i5$038*52)|0)|0) + 24|0);
       HEAP32[$207>>2] = $196;
       $208 = ((($descs) + (($i5$038*52)|0)|0) + 12|0);
       HEAP32[$208>>2] = $179;
       $209 = ((($descs) + (($i5$038*52)|0)|0) + 16|0);
       HEAP32[$209>>2] = $181;
       $210 = ((($descs) + (($i5$038*52)|0)|0) + 28|0);
       HEAP32[$210>>2] = $164;
       $211 = (($i5$038) + 1)|0;
       $exitcond53 = ($211|0)==(4);
       if ($exitcond53) {
        break;
       }
       $$pre62 = HEAP32[$150>>2]|0;
       $159 = $$pre62;$i5$038 = $211;
      }
      $212 = (__ZN5physx22setupSolverConstraint4EPNS_24PxcSolverConstraint4DescEffRNS_24PxcConstraintBlockStreamERNS_25PxsConstraintBlockManagerE($descs,$12,$14,$42,$53)|0);
      $phitmp3 = ($212|0)==(1);
      if (!($phitmp3)) {
       $axisConstraintCount$3 = $axisConstraintCount$045;
       break;
      }
      $$pre63 = HEAP16[$155>>1]|0;
      $214 = $$pre63;
     } else {
      $214 = $156;
     }
     $213 = ($214<<16>>16)==(0);
     if ($213) {
      $axisConstraintCount$3 = $axisConstraintCount$045;
     } else {
      $axisConstraintCount$141 = $axisConstraintCount$045;$i8$040 = 0;
      while(1) {
       $215 = HEAP32[$150>>2]|0;
       $216 = (($215) + ($i8$040))|0;
       $217 = (($4) + ($216<<5)|0);
       $218 = ((($4) + ($216<<5)|0) + 16|0);
       $219 = HEAP32[$218>>2]|0;
       $220 = (__ZN5physx24PxsSetupSolverConstraintEPKNS_13PxsConstraintEPNS_17PxcSolverBodyDataERNS_24PxcConstraintBlockStreamEffRNS_23PxcSolverConstraintDescERNS_25PxsConstraintBlockManagerE($219,$solverBodyData,$42,$12,$14,$217,$53)|0);
       $221 = (($220) + ($axisConstraintCount$141))|0;
       $222 = (($i8$040) + 1)|0;
       $223 = HEAP16[$155>>1]|0;
       $224 = $223&65535;
       $225 = ($222>>>0)<($224>>>0);
       if ($225) {
        $axisConstraintCount$141 = $221;$i8$040 = $222;
       } else {
        $axisConstraintCount$3 = $221;
        break;
       }
      }
     }
    } else if ((($154<<16>>16) == 1)) {
     $226 = ((($6) + ($83<<3)|0) + 4|0);
     $227 = HEAP16[$226>>1]|0;
     $228 = ($227<<16>>16)==(4);
     if ($228) {
      $229 = (($151) + 1)|0;
      $230 = (($4) + ($229<<5)|0);
      $231 = (($151) + 2)|0;
      $232 = (($4) + ($231<<5)|0);
      $233 = (($151) + 3)|0;
      $234 = (($4) + ($233<<5)|0);
      $235 = ((($4) + ($151<<5)|0) + 16|0);
      $236 = HEAP32[$235>>2]|0;
      $237 = ((($4) + ($229<<5)|0) + 16|0);
      $238 = HEAP32[$237>>2]|0;
      $239 = ((($4) + ($231<<5)|0) + 16|0);
      $240 = HEAP32[$239>>2]|0;
      $241 = ((($4) + ($233<<5)|0) + 16|0);
      $242 = HEAP32[$241>>2]|0;
      $243 = (($236) + 16|0);
      HEAP32[$n>>2] = $243;
      $244 = (($238) + 16|0);
      HEAP32[$54>>2] = $244;
      $245 = (($240) + 16|0);
      HEAP32[$55>>2] = $245;
      $246 = (($242) + 16|0);
      HEAP32[$56>>2] = $246;
      HEAP32[$descs13>>2] = $152;
      HEAP32[$57>>2] = $230;
      HEAP32[$58>>2] = $232;
      HEAP32[$59>>2] = $234;
      $247 = HEAP32[$152>>2]|0;
      HEAP32[$sBody0>>2] = $247;
      $248 = HEAP32[$230>>2]|0;
      HEAP32[$60>>2] = $248;
      $249 = HEAP32[$232>>2]|0;
      HEAP32[$61>>2] = $249;
      $250 = HEAP32[$234>>2]|0;
      HEAP32[$62>>2] = $250;
      $251 = ((($4) + ($151<<5)|0) + 4|0);
      $252 = HEAP32[$251>>2]|0;
      HEAP32[$sBody1>>2] = $252;
      $253 = ((($4) + ($229<<5)|0) + 4|0);
      $254 = HEAP32[$253>>2]|0;
      HEAP32[$63>>2] = $254;
      $255 = ((($4) + ($231<<5)|0) + 4|0);
      $256 = HEAP32[$255>>2]|0;
      HEAP32[$64>>2] = $256;
      $257 = ((($4) + ($233<<5)|0) + 4|0);
      $258 = HEAP32[$257>>2]|0;
      HEAP32[$65>>2] = $258;
      $259 = ((($4) + ($151<<5)|0) + 10|0);
      $260 = HEAP16[$259>>1]|0;
      $261 = $260&65535;
      $262 = (($solverBodyData) + ($261<<6)|0);
      HEAP32[$sbd0>>2] = $262;
      $263 = ((($4) + ($229<<5)|0) + 10|0);
      $264 = HEAP16[$263>>1]|0;
      $265 = $264&65535;
      $266 = (($solverBodyData) + ($265<<6)|0);
      HEAP32[$66>>2] = $266;
      $267 = ((($4) + ($231<<5)|0) + 10|0);
      $268 = HEAP16[$267>>1]|0;
      $269 = $268&65535;
      $270 = (($solverBodyData) + ($269<<6)|0);
      HEAP32[$67>>2] = $270;
      $271 = ((($4) + ($233<<5)|0) + 10|0);
      $272 = HEAP16[$271>>1]|0;
      $273 = $272&65535;
      $274 = (($solverBodyData) + ($273<<6)|0);
      HEAP32[$68>>2] = $274;
      $275 = ((($4) + ($151<<5)|0) + 14|0);
      $276 = HEAP16[$275>>1]|0;
      $277 = $276&65535;
      $278 = (($solverBodyData) + ($277<<6)|0);
      HEAP32[$sbd1>>2] = $278;
      $279 = ((($4) + ($229<<5)|0) + 14|0);
      $280 = HEAP16[$279>>1]|0;
      $281 = $280&65535;
      $282 = (($solverBodyData) + ($281<<6)|0);
      HEAP32[$69>>2] = $282;
      $283 = ((($4) + ($231<<5)|0) + 14|0);
      $284 = HEAP16[$283>>1]|0;
      $285 = $284&65535;
      $286 = (($solverBodyData) + ($285<<6)|0);
      HEAP32[$70>>2] = $286;
      $287 = ((($4) + ($233<<5)|0) + 14|0);
      $288 = HEAP16[$287>>1]|0;
      $289 = $288&65535;
      $290 = (($solverBodyData) + ($289<<6)|0);
      HEAP32[$71>>2] = $290;
      $291 = (($236) + 80|0);
      $292 = HEAP32[$291>>2]|0;
      HEAP32[$core0>>2] = $292;
      $293 = (($238) + 80|0);
      $294 = HEAP32[$293>>2]|0;
      HEAP32[$72>>2] = $294;
      $295 = (($240) + 80|0);
      $296 = HEAP32[$295>>2]|0;
      HEAP32[$73>>2] = $296;
      $297 = (($242) + 80|0);
      $298 = HEAP32[$297>>2]|0;
      HEAP32[$74>>2] = $298;
      $299 = (($236) + 84|0);
      $300 = HEAP32[$299>>2]|0;
      HEAP32[$core1>>2] = $300;
      $301 = (($238) + 84|0);
      $302 = HEAP32[$301>>2]|0;
      HEAP32[$75>>2] = $302;
      $303 = (($240) + 84|0);
      $304 = HEAP32[$303>>2]|0;
      HEAP32[$76>>2] = $304;
      $305 = (($242) + 84|0);
      $306 = HEAP32[$305>>2]|0;
      HEAP32[$77>>2] = $306;
      $307 = HEAP32[$78>>2]|0;
      $308 = Math_fround(HEAPF32[$79>>2]);
      $309 = Math_fround(HEAPF32[$80>>2]);
      $310 = Math_fround(HEAPF32[$81>>2]);
      $311 = (FUNCTION_TABLE_iiiiiiiiiiffffii[$307 & 3]($n,$41,$descs13,$sBody0,$sBody1,$sbd0,$sbd1,$core0,$core1,$14,$308,$309,$310,$53,$frictionType)|0);
      $phitmp2 = ($311|0)==(1);
      if (!($phitmp2)) {
       $axisConstraintCount$3 = $axisConstraintCount$045;
       break;
      }
      $$pre64 = HEAP16[$226>>1]|0;
      $313 = $$pre64;
     } else {
      $313 = $227;
     }
     $312 = ($313<<16>>16)==(0);
     if ($312) {
      $axisConstraintCount$3 = $axisConstraintCount$045;
     } else {
      $axisConstraintCount$235 = $axisConstraintCount$045;$i14$034 = 0;
      while(1) {
       $314 = HEAP32[$150>>2]|0;
       $315 = (($314) + ($i14$034))|0;
       $316 = (($4) + ($315<<5)|0);
       $317 = ((($4) + ($315<<5)|0) + 16|0);
       $318 = HEAP32[$317>>2]|0;
       $319 = (($318) + 16|0);
       $320 = ((($4) + ($315<<5)|0) + 8|0);
       $321 = HEAP16[$320>>1]|0;
       $322 = ($321<<16>>16)==(-1);
       if ($322) {
        $323 = ((($4) + ($315<<5)|0) + 10|0);
        $324 = HEAP16[$323>>1]|0;
        $325 = $324&65535;
        $326 = (($solverBodyData) + ($325<<6)|0);
        $346 = $326;
       } else {
        $346 = $solverBodyData;
       }
       $327 = ((($4) + ($315<<5)|0) + 12|0);
       $328 = HEAP16[$327>>1]|0;
       $329 = ($328<<16>>16)==(-1);
       if ($329) {
        $330 = ((($4) + ($315<<5)|0) + 14|0);
        $331 = HEAP16[$330>>1]|0;
        $332 = $331&65535;
        $333 = (($solverBodyData) + ($332<<6)|0);
        $347 = $333;
       } else {
        $347 = $solverBodyData;
       }
       $334 = HEAP32[$82>>2]|0;
       $335 = HEAP32[$316>>2]|0;
       $336 = ((($4) + ($315<<5)|0) + 4|0);
       $337 = HEAP32[$336>>2]|0;
       $338 = (($318) + 80|0);
       $339 = HEAP32[$338>>2]|0;
       $340 = (($318) + 84|0);
       $341 = HEAP32[$340>>2]|0;
       $342 = Math_fround(HEAPF32[$13>>2]);
       $343 = Math_fround(HEAPF32[$79>>2]);
       $344 = Math_fround(HEAPF32[$80>>2]);
       $345 = Math_fround(HEAPF32[$81>>2]);
       (FUNCTION_TABLE_iiiiiiiiiiiiffffii[$334 & 3]($319,$41,0,0,$316,$335,$337,$346,$347,$339,$341,$342,$343,$344,$345,$53,$frictionType)|0);
       $348 = (($318) + 20|0);
       $349 = HEAP32[$348>>2]|0;
       $350 = $349 >>> 4;
       $351 = $350&65535;
       $352 = ((($4) + ($315<<5)|0) + 26|0);
       HEAP16[$352>>1] = $351;
       $353 = HEAP32[$319>>2]|0;
       HEAP32[$317>>2] = $353;
       $354 = (($318) + 114|0);
       $355 = HEAP16[$354>>1]|0;
       $356 = $355 & 16;
       $357 = ($356<<16>>16)==(0);
       if ($357) {
        $$0$i$i7 = 0;$369 = 0;
       } else {
        $358 = (($318) + 36|0);
        $359 = HEAP16[$358>>1]|0;
        $360 = (($318) + 44|0);
        $361 = HEAP32[$360>>2]|0;
        $362 = (($318) + 48|0);
        $363 = HEAP32[$362>>2]|0;
        $364 = (($363) + 15)|0;
        $365 = $364 & -16;
        $366 = (($361) + ($365)|0);
        $$0$i$i7 = $366;$369 = $359;
       }
       $367 = ((($4) + ($315<<5)|0) + 20|0);
       HEAP32[$367>>2] = $$0$i$i7;
       $368 = ((($4) + ($315<<5)|0) + 24|0);
       HEAP16[$368>>1] = $369;
       $370 = (($318) + 32|0);
       $371 = HEAP16[$370>>1]|0;
       $372 = $371&65535;
       $373 = (($372) + ($axisConstraintCount$235))|0;
       $374 = (($i14$034) + 1)|0;
       $375 = HEAP16[$226>>1]|0;
       $376 = $375&65535;
       $377 = ($374>>>0)<($376>>>0);
       if ($377) {
        $axisConstraintCount$235 = $373;$i14$034 = $374;
       } else {
        $axisConstraintCount$3 = $373;
        break;
       }
      }
     }
    } else {
     $axisConstraintCount$3 = $axisConstraintCount$045;
    }
   } while(0);
   $378 = (($a$044) + 1)|0;
   $exitcond55 = ($378|0)==($8|0);
   if ($exitcond55) {
    $axisConstraintCount$0$lcssa = $axisConstraintCount$3;
    break;
   } else {
    $a$044 = $378;$axisConstraintCount$045 = $axisConstraintCount$3;
   }
  }
 } else {
  $axisConstraintCount$0$lcssa = $10;
 }
 $379 = ($8|0)==(0);
 if ($379) {
  $axisConstraintCount$6 = $axisConstraintCount$0$lcssa;
  $655 = HEAP32[$15>>2]|0;
  $656 = (($655) + 224|0);
  $657 = HEAP32[$656>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($657,$rv$0$i$i);
  HEAP32[$9>>2] = $axisConstraintCount$6;
  STACKTOP = sp;return;
 }
 $380 = (($8) + -1)|0;
 $381 = (($6) + ($380<<3)|0);
 $382 = HEAP32[$381>>2]|0;
 $383 = (($4) + ($382<<5)|0);
 $384 = ((($4) + ($382<<5)|0) + 26|0);
 $385 = HEAP16[$384>>1]|0;
 if ((($385<<16>>16) == 2)) {
  $386 = ((($6) + ($380<<3)|0) + 4|0);
  $387 = HEAP16[$386>>1]|0;
  $388 = ($387<<16>>16)==(4);
  do {
   if ($388) {
    HEAPF32[$id21>>2] = Math_fround(0.0);
    $389 = (($id21) + 4|0);
    HEAPF32[$389>>2] = Math_fround(0.0);
    $390 = (($id21) + 8|0);
    HEAPF32[$390>>2] = Math_fround(0.0);
    $391 = (($id21) + 12|0);
    HEAPF32[$391>>2] = Math_fround(1.0);
    $392 = (($id21) + 16|0);
    HEAPF32[$392>>2] = Math_fround(0.0);
    $393 = (($id21) + 20|0);
    HEAPF32[$393>>2] = Math_fround(0.0);
    $394 = (($id21) + 24|0);
    HEAPF32[$394>>2] = Math_fround(0.0);
    $396 = $382;$i23$011 = 0;
    while(1) {
     $395 = (($396) + ($i23$011))|0;
     $397 = (($4) + ($395<<5)|0);
     $398 = ((($4) + ($395<<5)|0) + 16|0);
     $399 = HEAP32[$398>>2]|0;
     $400 = (($399) + 16|0);
     $401 = HEAP32[$400>>2]|0;
     $402 = (($399) + 28|0);
     $403 = HEAP32[$402>>2]|0;
     $404 = (($399) + 12|0);
     $405 = HEAP32[$404>>2]|0;
     $406 = (($399) + 36|0);
     $407 = HEAP32[$406>>2]|0;
     $408 = ($407|0)==(0|0);
     if ($408) {
      $440 = $id21;
     } else {
      $409 = (($407) + 64|0);
      $410 = HEAP32[$409>>2]|0;
      $440 = $410;
     }
     $411 = (($399) + 40|0);
     $412 = HEAP32[$411>>2]|0;
     $413 = ($412|0)==(0|0);
     if ($413) {
      $442 = $id21;
     } else {
      $414 = (($412) + 64|0);
      $415 = HEAP32[$414>>2]|0;
      $442 = $415;
     }
     $416 = HEAP32[$397>>2]|0;
     $417 = ((($4) + ($395<<5)|0) + 4|0);
     $418 = HEAP32[$417>>2]|0;
     $419 = ((($4) + ($395<<5)|0) + 8|0);
     $420 = HEAP16[$419>>1]|0;
     $421 = ($420<<16>>16)==(-1);
     if ($421) {
      $422 = ((($4) + ($395<<5)|0) + 10|0);
      $423 = HEAP16[$422>>1]|0;
      $424 = $423&65535;
      $426 = $424;
     } else {
      $426 = 0;
     }
     $425 = (($solverBodyData) + ($426<<6)|0);
     $427 = ((($4) + ($395<<5)|0) + 12|0);
     $428 = HEAP16[$427>>1]|0;
     $429 = ($428<<16>>16)==(-1);
     if ($429) {
      $430 = ((($4) + ($395<<5)|0) + 14|0);
      $431 = HEAP16[$430>>1]|0;
      $432 = $431&65535;
      $434 = $432;
     } else {
      $434 = 0;
     }
     $433 = (($solverBodyData) + ($434<<6)|0);
     $435 = ((($descs) + (($i23$011*52)|0)|0) + 32|0);
     HEAP32[$435>>2] = $403;
     $436 = ((($descs) + (($i23$011*52)|0)|0) + 36|0);
     HEAP32[$436>>2] = $405;
     $437 = (($descs) + (($i23$011*52)|0)|0);
     HEAP32[$437>>2] = $399;
     $438 = ((($descs) + (($i23$011*52)|0)|0) + 40|0);
     HEAP32[$438>>2] = $397;
     $439 = ((($descs) + (($i23$011*52)|0)|0) + 4|0);
     HEAP32[$439>>2] = $440;
     $441 = ((($descs) + (($i23$011*52)|0)|0) + 8|0);
     HEAP32[$441>>2] = $442;
     $443 = ((($descs) + (($i23$011*52)|0)|0) + 20|0);
     HEAP32[$443>>2] = $425;
     $444 = ((($descs) + (($i23$011*52)|0)|0) + 24|0);
     HEAP32[$444>>2] = $433;
     $445 = ((($descs) + (($i23$011*52)|0)|0) + 12|0);
     HEAP32[$445>>2] = $416;
     $446 = ((($descs) + (($i23$011*52)|0)|0) + 16|0);
     HEAP32[$446>>2] = $418;
     $447 = ((($descs) + (($i23$011*52)|0)|0) + 28|0);
     HEAP32[$447>>2] = $401;
     $448 = (($i23$011) + 1)|0;
     $exitcond = ($448|0)==(4);
     if ($exitcond) {
      break;
     }
     $$pre = HEAP32[$381>>2]|0;
     $396 = $$pre;$i23$011 = $448;
    }
    $449 = (($mThreadContext) + 316|0);
    $450 = (__ZN5physx22setupSolverConstraint4EPNS_24PxcSolverConstraint4DescEffRNS_24PxcConstraintBlockStreamERNS_25PxsConstraintBlockManagerE($descs,$12,$14,$42,$449)|0);
    $phitmp1 = ($450|0)==(1);
    if ($phitmp1) {
     $$pre60 = HEAP16[$386>>1]|0;
     $452 = $$pre60;
     break;
    } else {
     $axisConstraintCount$6 = $axisConstraintCount$0$lcssa;
     $655 = HEAP32[$15>>2]|0;
     $656 = (($655) + 224|0);
     $657 = HEAP32[$656>>2]|0;
     __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($657,$rv$0$i$i);
     HEAP32[$9>>2] = $axisConstraintCount$6;
     STACKTOP = sp;return;
    }
   } else {
    $452 = $387;
   }
  } while(0);
  $451 = ($452<<16>>16)==(0);
  if ($451) {
   $axisConstraintCount$6 = $axisConstraintCount$0$lcssa;
   $655 = HEAP32[$15>>2]|0;
   $656 = (($655) + 224|0);
   $657 = HEAP32[$656>>2]|0;
   __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($657,$rv$0$i$i);
   HEAP32[$9>>2] = $axisConstraintCount$6;
   STACKTOP = sp;return;
  }
  $453 = (($mThreadContext) + 316|0);
  $axisConstraintCount$410 = $axisConstraintCount$0$lcssa;$i35$09 = 0;
  while(1) {
   $454 = HEAP32[$381>>2]|0;
   $455 = (($454) + ($i35$09))|0;
   $456 = (($4) + ($455<<5)|0);
   $457 = ((($4) + ($455<<5)|0) + 16|0);
   $458 = HEAP32[$457>>2]|0;
   $459 = (__ZN5physx24PxsSetupSolverConstraintEPKNS_13PxsConstraintEPNS_17PxcSolverBodyDataERNS_24PxcConstraintBlockStreamEffRNS_23PxcSolverConstraintDescERNS_25PxsConstraintBlockManagerE($458,$solverBodyData,$42,$12,$14,$456,$453)|0);
   $460 = (($459) + ($axisConstraintCount$410))|0;
   $461 = (($i35$09) + 1)|0;
   $462 = HEAP16[$386>>1]|0;
   $463 = $462&65535;
   $464 = ($461>>>0)<($463>>>0);
   if ($464) {
    $axisConstraintCount$410 = $460;$i35$09 = $461;
   } else {
    $axisConstraintCount$6 = $460;
    break;
   }
  }
  $655 = HEAP32[$15>>2]|0;
  $656 = (($655) + 224|0);
  $657 = HEAP32[$656>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($657,$rv$0$i$i);
  HEAP32[$9>>2] = $axisConstraintCount$6;
  STACKTOP = sp;return;
 } else if ((($385<<16>>16) == 1)) {
  $465 = ((($6) + ($380<<3)|0) + 4|0);
  $466 = HEAP16[$465>>1]|0;
  $467 = ($466<<16>>16)==(4);
  do {
   if ($467) {
    $468 = (($382) + 1)|0;
    $469 = (($4) + ($468<<5)|0);
    $470 = (($382) + 2)|0;
    $471 = (($4) + ($470<<5)|0);
    $472 = (($382) + 3)|0;
    $473 = (($4) + ($472<<5)|0);
    $474 = ((($4) + ($382<<5)|0) + 16|0);
    $475 = HEAP32[$474>>2]|0;
    $476 = ((($4) + ($468<<5)|0) + 16|0);
    $477 = HEAP32[$476>>2]|0;
    $478 = ((($4) + ($470<<5)|0) + 16|0);
    $479 = HEAP32[$478>>2]|0;
    $480 = ((($4) + ($472<<5)|0) + 16|0);
    $481 = HEAP32[$480>>2]|0;
    $482 = (($475) + 16|0);
    HEAP32[$n47>>2] = $482;
    $483 = (($n47) + 4|0);
    $484 = (($477) + 16|0);
    HEAP32[$483>>2] = $484;
    $485 = (($n47) + 8|0);
    $486 = (($479) + 16|0);
    HEAP32[$485>>2] = $486;
    $487 = (($n47) + 12|0);
    $488 = (($481) + 16|0);
    HEAP32[$487>>2] = $488;
    HEAP32[$descs48>>2] = $383;
    $489 = (($descs48) + 4|0);
    HEAP32[$489>>2] = $469;
    $490 = (($descs48) + 8|0);
    HEAP32[$490>>2] = $471;
    $491 = (($descs48) + 12|0);
    HEAP32[$491>>2] = $473;
    $492 = HEAP32[$383>>2]|0;
    HEAP32[$sBody049>>2] = $492;
    $493 = (($sBody049) + 4|0);
    $494 = HEAP32[$469>>2]|0;
    HEAP32[$493>>2] = $494;
    $495 = (($sBody049) + 8|0);
    $496 = HEAP32[$471>>2]|0;
    HEAP32[$495>>2] = $496;
    $497 = (($sBody049) + 12|0);
    $498 = HEAP32[$473>>2]|0;
    HEAP32[$497>>2] = $498;
    $499 = ((($4) + ($382<<5)|0) + 4|0);
    $500 = HEAP32[$499>>2]|0;
    HEAP32[$sBody150>>2] = $500;
    $501 = (($sBody150) + 4|0);
    $502 = ((($4) + ($468<<5)|0) + 4|0);
    $503 = HEAP32[$502>>2]|0;
    HEAP32[$501>>2] = $503;
    $504 = (($sBody150) + 8|0);
    $505 = ((($4) + ($470<<5)|0) + 4|0);
    $506 = HEAP32[$505>>2]|0;
    HEAP32[$504>>2] = $506;
    $507 = (($sBody150) + 12|0);
    $508 = ((($4) + ($472<<5)|0) + 4|0);
    $509 = HEAP32[$508>>2]|0;
    HEAP32[$507>>2] = $509;
    $510 = ((($4) + ($382<<5)|0) + 10|0);
    $511 = HEAP16[$510>>1]|0;
    $512 = $511&65535;
    $513 = (($solverBodyData) + ($512<<6)|0);
    HEAP32[$sbd051>>2] = $513;
    $514 = (($sbd051) + 4|0);
    $515 = ((($4) + ($468<<5)|0) + 10|0);
    $516 = HEAP16[$515>>1]|0;
    $517 = $516&65535;
    $518 = (($solverBodyData) + ($517<<6)|0);
    HEAP32[$514>>2] = $518;
    $519 = (($sbd051) + 8|0);
    $520 = ((($4) + ($470<<5)|0) + 10|0);
    $521 = HEAP16[$520>>1]|0;
    $522 = $521&65535;
    $523 = (($solverBodyData) + ($522<<6)|0);
    HEAP32[$519>>2] = $523;
    $524 = (($sbd051) + 12|0);
    $525 = ((($4) + ($472<<5)|0) + 10|0);
    $526 = HEAP16[$525>>1]|0;
    $527 = $526&65535;
    $528 = (($solverBodyData) + ($527<<6)|0);
    HEAP32[$524>>2] = $528;
    $529 = ((($4) + ($382<<5)|0) + 14|0);
    $530 = HEAP16[$529>>1]|0;
    $531 = $530&65535;
    $532 = (($solverBodyData) + ($531<<6)|0);
    HEAP32[$sbd152>>2] = $532;
    $533 = (($sbd152) + 4|0);
    $534 = ((($4) + ($468<<5)|0) + 14|0);
    $535 = HEAP16[$534>>1]|0;
    $536 = $535&65535;
    $537 = (($solverBodyData) + ($536<<6)|0);
    HEAP32[$533>>2] = $537;
    $538 = (($sbd152) + 8|0);
    $539 = ((($4) + ($470<<5)|0) + 14|0);
    $540 = HEAP16[$539>>1]|0;
    $541 = $540&65535;
    $542 = (($solverBodyData) + ($541<<6)|0);
    HEAP32[$538>>2] = $542;
    $543 = (($sbd152) + 12|0);
    $544 = ((($4) + ($472<<5)|0) + 14|0);
    $545 = HEAP16[$544>>1]|0;
    $546 = $545&65535;
    $547 = (($solverBodyData) + ($546<<6)|0);
    HEAP32[$543>>2] = $547;
    $548 = HEAP32[$n47>>2]|0;
    $549 = (($548) + 64|0);
    $550 = HEAP32[$549>>2]|0;
    HEAP32[$core053>>2] = $550;
    $551 = (($core053) + 4|0);
    $552 = HEAP32[$483>>2]|0;
    $553 = (($552) + 64|0);
    $554 = HEAP32[$553>>2]|0;
    HEAP32[$551>>2] = $554;
    $555 = (($core053) + 8|0);
    $556 = HEAP32[$485>>2]|0;
    $557 = (($556) + 64|0);
    $558 = HEAP32[$557>>2]|0;
    HEAP32[$555>>2] = $558;
    $559 = (($core053) + 12|0);
    $560 = HEAP32[$487>>2]|0;
    $561 = (($560) + 64|0);
    $562 = HEAP32[$561>>2]|0;
    HEAP32[$559>>2] = $562;
    $563 = (($548) + 68|0);
    $564 = HEAP32[$563>>2]|0;
    HEAP32[$core154>>2] = $564;
    $565 = (($core154) + 4|0);
    $566 = (($552) + 68|0);
    $567 = HEAP32[$566>>2]|0;
    HEAP32[$565>>2] = $567;
    $568 = (($core154) + 8|0);
    $569 = (($556) + 68|0);
    $570 = HEAP32[$569>>2]|0;
    HEAP32[$568>>2] = $570;
    $571 = (($core154) + 12|0);
    $572 = (($560) + 68|0);
    $573 = HEAP32[$572>>2]|0;
    HEAP32[$571>>2] = $573;
    $574 = (504440 + ($frictionType<<2)|0);
    $575 = HEAP32[$574>>2]|0;
    $576 = (($this) + 140|0);
    $577 = Math_fround(HEAPF32[$576>>2]);
    $578 = (($this) + 144|0);
    $579 = Math_fround(HEAPF32[$578>>2]);
    $580 = (($mThreadContext) + 8800|0);
    $581 = Math_fround(HEAPF32[$580>>2]);
    $582 = (($mThreadContext) + 316|0);
    $583 = (FUNCTION_TABLE_iiiiiiiiiiffffii[$575 & 3]($n47,$41,$descs48,$sBody049,$sBody150,$sbd051,$sbd152,$core053,$core154,$14,$577,$579,$581,$582,$frictionType)|0);
    $phitmp = ($583|0)==(1);
    if ($phitmp) {
     $$pre61 = HEAP16[$465>>1]|0;
     $585 = $$pre61;
     break;
    } else {
     $axisConstraintCount$6 = $axisConstraintCount$0$lcssa;
     $655 = HEAP32[$15>>2]|0;
     $656 = (($655) + 224|0);
     $657 = HEAP32[$656>>2]|0;
     __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($657,$rv$0$i$i);
     HEAP32[$9>>2] = $axisConstraintCount$6;
     STACKTOP = sp;return;
    }
   } else {
    $585 = $466;
   }
  } while(0);
  $584 = ($585<<16>>16)==(0);
  if ($584) {
   $axisConstraintCount$6 = $axisConstraintCount$0$lcssa;
   $655 = HEAP32[$15>>2]|0;
   $656 = (($655) + 224|0);
   $657 = HEAP32[$656>>2]|0;
   __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($657,$rv$0$i$i);
   HEAP32[$9>>2] = $axisConstraintCount$6;
   STACKTOP = sp;return;
  }
  $586 = (504424 + ($frictionType<<2)|0);
  $587 = (($this) + 140|0);
  $588 = (($this) + 144|0);
  $589 = (($mThreadContext) + 8800|0);
  $590 = (($mThreadContext) + 316|0);
  $axisConstraintCount$514 = $axisConstraintCount$0$lcssa;$i55$013 = 0;
  while(1) {
   $591 = HEAP32[$381>>2]|0;
   $592 = (($591) + ($i55$013))|0;
   $593 = (($4) + ($592<<5)|0);
   $594 = ((($4) + ($592<<5)|0) + 16|0);
   $595 = HEAP32[$594>>2]|0;
   $596 = (($595) + 16|0);
   $597 = ((($4) + ($592<<5)|0) + 8|0);
   $598 = HEAP16[$597>>1]|0;
   $599 = ($598<<16>>16)==(-1);
   if ($599) {
    $600 = ((($4) + ($592<<5)|0) + 10|0);
    $601 = HEAP16[$600>>1]|0;
    $602 = $601&65535;
    $603 = (($solverBodyData) + ($602<<6)|0);
    $623 = $603;
   } else {
    $623 = $solverBodyData;
   }
   $604 = ((($4) + ($592<<5)|0) + 12|0);
   $605 = HEAP16[$604>>1]|0;
   $606 = ($605<<16>>16)==(-1);
   if ($606) {
    $607 = ((($4) + ($592<<5)|0) + 14|0);
    $608 = HEAP16[$607>>1]|0;
    $609 = $608&65535;
    $610 = (($solverBodyData) + ($609<<6)|0);
    $624 = $610;
   } else {
    $624 = $solverBodyData;
   }
   $611 = HEAP32[$586>>2]|0;
   $612 = HEAP32[$593>>2]|0;
   $613 = ((($4) + ($592<<5)|0) + 4|0);
   $614 = HEAP32[$613>>2]|0;
   $615 = (($595) + 80|0);
   $616 = HEAP32[$615>>2]|0;
   $617 = (($595) + 84|0);
   $618 = HEAP32[$617>>2]|0;
   $619 = Math_fround(HEAPF32[$13>>2]);
   $620 = Math_fround(HEAPF32[$587>>2]);
   $621 = Math_fround(HEAPF32[$588>>2]);
   $622 = Math_fround(HEAPF32[$589>>2]);
   (FUNCTION_TABLE_iiiiiiiiiiiiffffii[$611 & 3]($596,$41,0,0,$593,$612,$614,$623,$624,$616,$618,$619,$620,$621,$622,$590,$frictionType)|0);
   $625 = (($595) + 20|0);
   $626 = HEAP32[$625>>2]|0;
   $627 = $626 >>> 4;
   $628 = $627&65535;
   $629 = ((($4) + ($592<<5)|0) + 26|0);
   HEAP16[$629>>1] = $628;
   $630 = HEAP32[$596>>2]|0;
   HEAP32[$594>>2] = $630;
   $631 = (($595) + 114|0);
   $632 = HEAP16[$631>>1]|0;
   $633 = $632 & 16;
   $634 = ($633<<16>>16)==(0);
   if ($634) {
    $$0$i$i = 0;$646 = 0;
   } else {
    $635 = (($595) + 36|0);
    $636 = HEAP16[$635>>1]|0;
    $637 = (($595) + 44|0);
    $638 = HEAP32[$637>>2]|0;
    $639 = (($595) + 48|0);
    $640 = HEAP32[$639>>2]|0;
    $641 = (($640) + 15)|0;
    $642 = $641 & -16;
    $643 = (($638) + ($642)|0);
    $$0$i$i = $643;$646 = $636;
   }
   $644 = ((($4) + ($592<<5)|0) + 20|0);
   HEAP32[$644>>2] = $$0$i$i;
   $645 = ((($4) + ($592<<5)|0) + 24|0);
   HEAP16[$645>>1] = $646;
   $647 = (($595) + 32|0);
   $648 = HEAP16[$647>>1]|0;
   $649 = $648&65535;
   $650 = (($649) + ($axisConstraintCount$514))|0;
   $651 = (($i55$013) + 1)|0;
   $652 = HEAP16[$465>>1]|0;
   $653 = $652&65535;
   $654 = ($651>>>0)<($653>>>0);
   if ($654) {
    $axisConstraintCount$514 = $650;$i55$013 = $651;
   } else {
    $axisConstraintCount$6 = $650;
    break;
   }
  }
  $655 = HEAP32[$15>>2]|0;
  $656 = (($655) + 224|0);
  $657 = HEAP32[$656>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($657,$rv$0$i$i);
  HEAP32[$9>>2] = $axisConstraintCount$6;
  STACKTOP = sp;return;
 } else {
  $axisConstraintCount$6 = $axisConstraintCount$0$lcssa;
  $655 = HEAP32[$15>>2]|0;
  $656 = (($655) + 224|0);
  $657 = HEAP32[$656>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($657,$rv$0$i$i);
  HEAP32[$9>>2] = $axisConstraintCount$6;
  STACKTOP = sp;return;
 }
}
function __ZN5physx38PxsSolverCreateFinalizeConstraintsTask11runInternalEv($this) {
 $this = $this|0;
 var $$off$us = 0, $$pre = 0, $$pre$phi33Z2D = 0, $$pre$phiZ2D = 0, $$pre31 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0);
 var $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0 = 0, $a$0$ph = 0, $a$0$ph$phi = 0, $a$0$us = 0, $a1$05 = 0, $a3$04 = 0, $accumulatedConstraintsPerPartition = 0, $accumulation$016 = 0;
 var $currentPartition$0$ph = 0, $exitcond = 0, $exitcond18 = 0, $exitcond28 = 0, $j$010$us = 0, $j$1$us = 0, $k$015 = 0, $maxJ$0$ph = 0, $numHeaders$0 = 0, $numHeaders$0$lcssa = 0, $numHeaders$0$ph = 0, $numHeaders$0$us = 0, $numHeaders$1$lcssa = 0, $numHeaders$16 = 0, $or$cond = 0, $switch$us = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $accumulatedConstraintsPerPartition = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8952|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 9148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 9184|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[$0>>2]|0;
 $8 = (($7) + 9188|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($10>>>0)<($5>>>0);
 if ($11) {
  $12 = (($7) + 9180|0);
  __ZN5physx6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENS0_19ReflectionAllocatorIS2_EEE8recreateEj($12,$5);
  $$pre = HEAP32[$0>>2]|0;
  $14 = $$pre;
 } else {
  $14 = $7;
 }
 $13 = (($14) + 9184|0);
 HEAP32[$13>>2] = $5;
 $15 = HEAP32[$0>>2]|0;
 $accumulation$016 = 0;$k$015 = 0;
 while(1) {
  $16 = ((($15) + ($k$015<<2)|0) + 8816|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($accumulation$016))|0;
  $19 = (($accumulatedConstraintsPerPartition) + ($k$015<<2)|0);
  HEAP32[$19>>2] = $18;
  $20 = (($k$015) + 1)|0;
  $exitcond28 = ($20|0)==(33);
  if ($exitcond28) {
   break;
  } else {
   $accumulation$016 = $18;$k$015 = $20;
  }
 }
 $21 = HEAP32[$accumulatedConstraintsPerPartition>>2]|0;
 $a$0$ph = 0;$currentPartition$0$ph = 0;$maxJ$0$ph = $21;$numHeaders$0$ph = 0;
 L7: while(1) {
  $22 = ($currentPartition$0$ph>>>0)<(32);
  if ($22) {
   $a$0$us = $a$0$ph;$numHeaders$0$us = $numHeaders$0$ph;
  } else {
   $a$0 = $a$0$ph;$numHeaders$0 = $numHeaders$0$ph;
   label = 16;
   break;
  }
  while(1) {
   $23 = ($a$0$us>>>0)<($3>>>0);
   if (!($23)) {
    $numHeaders$0$lcssa = $numHeaders$0$us;
    break L7;
   }
   $24 = HEAP32[$0>>2]|0;
   $25 = (($numHeaders$0$us) + 1)|0;
   $26 = (($24) + 9180|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + ($numHeaders$0$us<<3)|0);
   HEAP32[$28>>2] = $a$0$us;
   $29 = (($maxJ$0$ph) - ($a$0$us))|0;
   $30 = ($29>>>0)<(4);
   $31 = $30 ? $29 : 4;
   $32 = HEAP32[$0>>2]|0;
   $33 = (($32) + 9168|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($a$0$us<<5)|0) + 8|0);
   $36 = HEAP16[$35>>1]|0;
   $37 = ($36<<16>>16)==(-1);
   L12: do {
    if ($37) {
     $38 = ((($34) + ($a$0$us<<5)|0) + 12|0);
     $39 = HEAP16[$38>>1]|0;
     $40 = ($39<<16>>16)==(-1);
     if ($40) {
      $41 = ((($34) + ($a$0$us<<5)|0) + 26|0);
      $42 = HEAP16[$41>>1]|0;
      $$off$us = (($42) + -1)<<16>>16;
      $switch$us = ($$off$us&65535)<(2);
      $43 = ($31>>>0)>(1);
      $or$cond = $switch$us & $43;
      if ($or$cond) {
       $48 = 1;$j$010$us = 1;
       while(1) {
        $47 = (($48) + ($a$0$us))|0;
        $49 = ((($34) + ($47<<5)|0) + 26|0);
        $50 = HEAP16[$49>>1]|0;
        $51 = ($42<<16>>16)==($50<<16>>16);
        if (!($51)) {
         $j$1$us = $j$010$us;
         break L12;
        }
        $52 = ((($34) + ($47<<5)|0) + 8|0);
        $53 = HEAP16[$52>>1]|0;
        $54 = ($53<<16>>16)==(-1);
        if (!($54)) {
         $j$1$us = $j$010$us;
         break L12;
        }
        $55 = ((($34) + ($47<<5)|0) + 12|0);
        $56 = HEAP16[$55>>1]|0;
        $57 = ($56<<16>>16)==(-1);
        $45 = (($j$010$us) + 1)<<16>>16;
        if (!($57)) {
         $j$1$us = $j$010$us;
         break L12;
        }
        $44 = $45&65535;
        $46 = ($44>>>0)<($31>>>0);
        if ($46) {
         $48 = $44;$j$010$us = $45;
        } else {
         $j$1$us = $45;
         break;
        }
       }
      } else {
       $j$1$us = 1;
      }
     } else {
      $j$1$us = 1;
     }
    } else {
     $j$1$us = 1;
    }
   } while(0);
   $58 = ((($27) + ($numHeaders$0$us<<3)|0) + 4|0);
   HEAP16[$58>>1] = $j$1$us;
   $59 = $j$1$us&65535;
   $60 = (($59) + ($a$0$us))|0;
   $61 = ($maxJ$0$ph|0)==($60|0);
   if ($61) {
    break;
   } else {
    $a$0$us = $60;$numHeaders$0$us = $25;
   }
  }
  $73 = (($currentPartition$0$ph) + 1)|0;
  $74 = (($accumulatedConstraintsPerPartition) + ($73<<2)|0);
  $75 = HEAP32[$74>>2]|0;
  $a$0$ph$phi = $maxJ$0$ph;$currentPartition$0$ph = $73;$maxJ$0$ph = $75;$numHeaders$0$ph = $25;$a$0$ph = $a$0$ph$phi;
 }
 L22: do {
  if ((label|0) == 16) {
   while(1) {
    label = 0;
    $62 = ($a$0>>>0)<($3>>>0);
    if (!($62)) {
     $numHeaders$0$lcssa = $numHeaders$0;
     break L22;
    }
    $66 = HEAP32[$0>>2]|0;
    $67 = (($numHeaders$0) + 1)|0;
    $68 = (($66) + 9180|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($69) + ($numHeaders$0<<3)|0);
    HEAP32[$70>>2] = $a$0;
    $71 = ((($69) + ($numHeaders$0<<3)|0) + 4|0);
    HEAP16[$71>>1] = 1;
    $72 = (($a$0) + 1)|0;
    $a$0 = $72;$numHeaders$0 = $67;
    label = 16;
   }
  }
 } while(0);
 $63 = ($5|0)==($3|0);
 if ($63) {
  $numHeaders$1$lcssa = $numHeaders$0$lcssa;
 } else {
  $64 = (($numHeaders$0$lcssa) + ($5))|0;
  $65 = (($5) - ($3))|0;
  $a1$05 = 0;$numHeaders$16 = $numHeaders$0$lcssa;
  while(1) {
   $76 = HEAP32[$0>>2]|0;
   $77 = (($76) + 9180|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (($a1$05) + ($3))|0;
   $80 = (($78) + ($numHeaders$16<<3)|0);
   HEAP32[$80>>2] = $79;
   $81 = ((($78) + ($numHeaders$16<<3)|0) + 4|0);
   HEAP16[$81>>1] = 1;
   $82 = (($a1$05) + 1)|0;
   $exitcond18 = ($82|0)==($65|0);
   if ($exitcond18) {
    break;
   }
   $83 = (($numHeaders$16) + 1)|0;
   $a1$05 = $82;$numHeaders$16 = $83;
  }
  $84 = (($64) - ($3))|0;
  $numHeaders$1$lcssa = $84;
 }
 $85 = (($numHeaders$1$lcssa) - ($numHeaders$0$lcssa))|0;
 $86 = HEAP32[$0>>2]|0;
 $87 = (($86) + 9184|0);
 HEAP32[$87>>2] = $numHeaders$1$lcssa;
 $88 = HEAP32[$0>>2]|0;
 $89 = (($88) + 9252|0);
 HEAP32[$89>>2] = $numHeaders$0$lcssa;
 $90 = HEAP32[$0>>2]|0;
 $91 = (($90) + 9256|0);
 HEAP32[$91>>2] = $85;
 $92 = HEAP32[$0>>2]|0;
 $93 = (($92) + 9168|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = $numHeaders$1$lcssa >>> 4;
 $96 = (($95) + 1)|0;
 $97 = (($this) + 8|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$98>>2]|0;
 $100 = (($99) + 16|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = (FUNCTION_TABLE_ii[$101 & 4095]($98)|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + 4|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (FUNCTION_TABLE_ii[$105 & 4095]($102)|0);
 $107 = ($106>>>0)<($96>>>0);
 $108 = $107 ? $106 : $96;
 $109 = ($108>>>0)>(1);
 $110 = (($this) + 20|0);
 $111 = HEAP32[$110>>2]|0;
 if (!($109)) {
  $201 = HEAP32[$0>>2]|0;
  $202 = (($201) + 8776|0);
  $203 = HEAP32[$202>>2]|0;
  $204 = (($111) + 112|0);
  $205 = HEAP32[$204>>2]|0;
  __ZN5physx18PxsDynamicsContext22createFinalizeContactsENS_14PxFrictionType4EnumEPNS_23PxcSolverConstraintDescEPNS_17PxcSolverBodyDataEjPNS_10PxBaseTaskERNS_16PxsThreadContextE($111,$203,0,$205,0,0,$201);
  STACKTOP = sp;return;
 }
 $112 = (($111) + 96|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($113) + 6732|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = HEAP32[$115>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($116);
 $117 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($115,4,16)|0);
 $118 = HEAP32[$115>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($118);
 HEAP32[$117>>2] = 0;
 $119 = HEAP32[$110>>2]|0;
 $120 = (($119) + 96|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = (($121) + 6732|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ($108*68)|0;
 $125 = (($124) + -68)|0;
 $126 = HEAP32[$123>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($126);
 $127 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($123,$125,16)|0);
 $128 = HEAP32[$123>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($128);
 $129 = (($this) + 12|0);
 $130 = $106 ^ -1;
 $131 = (-2 - ($95))|0;
 $132 = ($131>>>0)<($130>>>0);
 $umax = $132 ? $130 : $131;
 $133 = $umax ^ -1;
 $a3$04 = 1;
 while(1) {
  $134 = (($a3$04) + -1)|0;
  $135 = (($127) + (($134*68)|0)|0);
  $136 = ($135|0)==(0|0);
  if ($136) {
   $$pre31 = ((($127) + (($134*68)|0)|0) + 16|0);
   $$pre32 = ((($127) + (($134*68)|0)|0) + 12|0);
   $$pre$phi33Z2D = $$pre32;$$pre$phiZ2D = $$pre31;
  } else {
   $137 = HEAP32[$0>>2]|0;
   $138 = (($137) + 8776|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = HEAP32[$110>>2]|0;
   $141 = (($140) + 124|0);
   $142 = Math_fround(HEAPF32[$141>>2]);
   $143 = (($140) + 128|0);
   $144 = Math_fround(HEAPF32[$143>>2]);
   $145 = (($140) + 140|0);
   $146 = Math_fround(HEAPF32[$145>>2]);
   $147 = (($140) + 144|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = (($137) + 9268|0);
   $150 = (($140) + 112|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (($140) + 96|0);
   $153 = HEAP32[$152>>2]|0;
   $154 = ((($127) + (($134*68)|0)|0) + 4|0);
   HEAP16[$154>>1] = -1;
   $155 = ((($127) + (($134*68)|0)|0) + 6|0);
   HEAP16[$155>>1] = 0;
   $156 = ((($127) + (($134*68)|0)|0) + 8|0);
   HEAP32[$156>>2] = 0;
   HEAP32[$135>>2] = ((434896 + 8|0));
   $157 = ((($127) + (($134*68)|0)|0) + 12|0);
   HEAP32[$157>>2] = 0;
   $158 = ((($127) + (($134*68)|0)|0) + 16|0);
   HEAP32[$158>>2] = 0;
   HEAP32[$135>>2] = ((492528 + 8|0));
   $159 = ((($127) + (($134*68)|0)|0) + 20|0);
   HEAP32[$159>>2] = $139;
   $160 = ((($127) + (($134*68)|0)|0) + 24|0);
   HEAPF32[$160>>2] = $144;
   $161 = ((($127) + (($134*68)|0)|0) + 28|0);
   HEAPF32[$161>>2] = $142;
   $162 = ((($127) + (($134*68)|0)|0) + 32|0);
   HEAPF32[$162>>2] = $146;
   $163 = ((($127) + (($134*68)|0)|0) + 36|0);
   HEAPF32[$163>>2] = $148;
   $164 = ((($127) + (($134*68)|0)|0) + 40|0);
   HEAP32[$164>>2] = $3;
   $165 = ((($127) + (($134*68)|0)|0) + 44|0);
   HEAP32[$165>>2] = $94;
   $166 = ((($127) + (($134*68)|0)|0) + 48|0);
   HEAP32[$166>>2] = $151;
   $167 = ((($127) + (($134*68)|0)|0) + 52|0);
   HEAP32[$167>>2] = $117;
   $168 = ((($127) + (($134*68)|0)|0) + 56|0);
   HEAP32[$168>>2] = $149;
   $169 = ((($127) + (($134*68)|0)|0) + 60|0);
   HEAP32[$169>>2] = $137;
   $170 = ((($127) + (($134*68)|0)|0) + 64|0);
   HEAP32[$170>>2] = $153;
   $$pre$phi33Z2D = $157;$$pre$phiZ2D = $158;
  }
  $171 = HEAP32[$129>>2]|0;
  HEAP32[$$pre$phiZ2D>>2] = 1;
  HEAP32[$$pre$phi33Z2D>>2] = $171;
  $172 = ($171|0)==(0|0);
  if (!($172)) {
   $173 = HEAP32[$171>>2]|0;
   $174 = (($173) + 16|0);
   $175 = HEAP32[$174>>2]|0;
   FUNCTION_TABLE_vi[$175 & 4095]($171);
   $176 = HEAP32[$$pre$phi33Z2D>>2]|0;
   $177 = (($176) + 8|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = ((($127) + (($134*68)|0)|0) + 8|0);
   HEAP32[$179>>2] = $178;
  }
  $180 = HEAP32[$135>>2]|0;
  $181 = (($180) + 20|0);
  $182 = HEAP32[$181>>2]|0;
  FUNCTION_TABLE_vi[$182 & 4095]($135);
  $183 = (($a3$04) + 1)|0;
  $exitcond = ($183|0)==($133|0);
  if ($exitcond) {
   break;
  } else {
   $a3$04 = $183;
  }
 }
 $184 = HEAP32[$0>>2]|0;
 $185 = (($184) + 8776|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = HEAP32[$110>>2]|0;
 $188 = (($187) + 112|0);
 $189 = HEAP32[$188>>2]|0;
 $190 = (($187) + 124|0);
 $191 = Math_fround(HEAPF32[$190>>2]);
 $192 = (($187) + 128|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($187) + 140|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = (($187) + 144|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = (($187) + 96|0);
 $199 = HEAP32[$198>>2]|0;
 $200 = (($184) + 9268|0);
 (__Z31createFinalizeContacts_ParallelN5physx14PxFrictionType4EnumEPNS_23PxcSolverConstraintDescEPNS_17PxcSolverBodyDataEjRNS_16PxsThreadContextEPiffffPNS_10PxsContextES8_($186,0,$189,0,$184,$117,$191,$193,$195,$197,$199,$200)|0);
 STACKTOP = sp;return;
}
function __ZN20PxsAtomIntegrateTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20PxsAtomIntegrateTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK20PxsAtomIntegrateTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (492504|0);
}
function __ZN5physx38PxsSolverCreateFinalizeConstraintsTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx38PxsSolverCreateFinalizeConstraintsTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx38PxsSolverCreateFinalizeConstraintsTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (492464|0);
}
function __ZN5physx6shdfnd5ArrayINS_23PxcSolverConstraintDescENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 491864 : 491832;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,491752,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<5)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;HEAP32[$$012$i+24>>2]=HEAP32[$$03$i+24>>2]|0;HEAP32[$$012$i+28>>2]=HEAP32[$$03$i+28>>2]|0;
   }
   $20 = (($$012$i) + 32|0);
   $21 = (($$03$i) + 32|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_25PxcArticulationSolverDescENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*40)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 492000 : 491832;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,491752,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*40)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    dest=$$012$i+0|0; src=$$03$i+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $20 = (($$012$i) + 40|0);
   $21 = (($$03$i) + 40|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_17PxcSolverBodyDataENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $24 = 0;
 } else {
  $1 = $capacity << 6;
  $2 = (($1) + 131)|0;
  $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__Z15PxGetFoundationv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
  $$$i$i$i$i = $11 ? 492144 : 491832;
  $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$2,$$$i$i$i$i,491752,558)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   $24 = 0;
  } else {
   $14 = (($12) + 131|0);
   $15 = $14;
   $16 = $15 & -128;
   $17 = $12;
   $18 = (($16) - ($17))|0;
   $19 = $16;
   $20 = (($19) + -4|0);
   HEAP32[$20>>2] = $18;
   $phitmp$i = $16;
   $24 = $phitmp$i;
  }
 }
 $21 = (($this) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($24) + ($22<<6)|0);
 $25 = ($22|0)>(0);
 if ($25) {
  $26 = HEAP32[$this>>2]|0;
  $$012$i = $24;$$03$i = $26;
  while(1) {
   $27 = ($$012$i|0)==(0|0);
   if (!($27)) {
    $28 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $28;
    $29 = (($$012$i) + 4|0);
    $30 = (($$03$i) + 4|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 8|0);
    $33 = (($$03$i) + 8|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
    $35 = (($$012$i) + 12|0);
    $36 = (($$03$i) + 12|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 16|0);
    $39 = (($$03$i) + 16|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 20|0);
    $42 = (($$03$i) + 20|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$41>>2] = $43;
    $44 = (($$012$i) + 24|0);
    $45 = (($$03$i) + 24|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    HEAPF32[$44>>2] = $46;
    $47 = (($$012$i) + 28|0);
    $48 = (($$03$i) + 28|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$47>>2] = $49;
    $50 = (($$012$i) + 32|0);
    $51 = (($$03$i) + 32|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    HEAPF32[$50>>2] = $52;
    $53 = (($$012$i) + 36|0);
    $54 = (($$03$i) + 36|0);
    ;HEAP32[$53+0>>2]=HEAP32[$54+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$54+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$54+8>>2]|0;HEAP32[$53+12>>2]=HEAP32[$54+12>>2]|0;HEAP32[$53+16>>2]=HEAP32[$54+16>>2]|0;HEAP32[$53+20>>2]=HEAP32[$54+20>>2]|0;HEAP32[$53+24>>2]=HEAP32[$54+24>>2]|0;
   }
   $55 = (($$012$i) + 64|0);
   $56 = (($$03$i) + 64|0);
   $57 = ($55>>>0)<($23>>>0);
   if ($57) {
    $$012$i = $55;$$03$i = $56;
   } else {
    break;
   }
  }
 }
 $58 = (($this) + 8|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)>(-1);
 if (!($60)) {
  HEAP32[$this>>2] = $24;
  HEAP32[$58>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $61 = HEAP32[$this>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  HEAP32[$this>>2] = $24;
  HEAP32[$58>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $63 = (($61) + -4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (0 - ($64))|0;
 $66 = (($61) + ($65)|0);
 $67 = ($66|0)==(0|0);
 if ($67) {
  HEAP32[$this>>2] = $24;
  HEAP32[$58>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $68 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 12|0);
 $71 = HEAP32[$70>>2]|0;
 FUNCTION_TABLE_vii[$71 & 4095]($68,$66);
 HEAP32[$this>>2] = $24;
 HEAP32[$58>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_13PxcSolverBodyENS0_16AlignedAllocatorILj128ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $24 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = (($1) + 131)|0;
  $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__Z15PxGetFoundationv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
  $$$i$i$i$i = $11 ? 492272 : 491832;
  $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$2,$$$i$i$i$i,491752,558)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   $24 = 0;
  } else {
   $14 = (($12) + 131|0);
   $15 = $14;
   $16 = $15 & -128;
   $17 = $12;
   $18 = (($16) - ($17))|0;
   $19 = $16;
   $20 = (($19) + -4|0);
   HEAP32[$20>>2] = $18;
   $phitmp$i = $16;
   $24 = $phitmp$i;
  }
 }
 $21 = (($this) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($24) + ($22<<5)|0);
 $25 = ($22|0)>(0);
 if ($25) {
  $26 = HEAP32[$this>>2]|0;
  $$012$i = $24;$$03$i = $26;
  while(1) {
   $27 = ($$012$i|0)==(0|0);
   if (!($27)) {
    $28 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $28;
    $29 = (($$012$i) + 4|0);
    $30 = (($$03$i) + 4|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 8|0);
    $33 = (($$03$i) + 8|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
    $35 = (($$012$i) + 12|0);
    $36 = (($$03$i) + 12|0);
    $37 = HEAPU16[$36>>1]|(HEAPU16[$36+2>>1]<<16);
    HEAP16[$35>>1]=$37&65535;HEAP16[$35+2>>1]=$37>>>16;
    $38 = (($$012$i) + 16|0);
    $39 = (($$03$i) + 16|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 20|0);
    $42 = (($$03$i) + 20|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$41>>2] = $43;
    $44 = (($$012$i) + 24|0);
    $45 = (($$03$i) + 24|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    HEAPF32[$44>>2] = $46;
    $47 = (($$012$i) + 28|0);
    $48 = (($$03$i) + 28|0);
    $49 = HEAP32[$48>>2]|0;
    HEAP32[$47>>2] = $49;
   }
   $50 = (($$012$i) + 32|0);
   $51 = (($$03$i) + 32|0);
   $52 = ($50>>>0)<($23>>>0);
   if ($52) {
    $$012$i = $50;$$03$i = $51;
   } else {
    break;
   }
  }
 }
 $53 = (($this) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)>(-1);
 if (!($55)) {
  HEAP32[$this>>2] = $24;
  HEAP32[$53>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $56 = HEAP32[$this>>2]|0;
 $57 = ($56|0)==(0|0);
 if ($57) {
  HEAP32[$this>>2] = $24;
  HEAP32[$53>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $58 = (($56) + -4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (0 - ($59))|0;
 $61 = (($56) + ($60)|0);
 $62 = ($61|0)==(0|0);
 if ($62) {
  HEAP32[$this>>2] = $24;
  HEAP32[$53>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $63 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 FUNCTION_TABLE_vii[$66 & 4095]($63,$61);
 HEAP32[$this>>2] = $24;
 HEAP32[$53>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN21PxsCreateFinalizeTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN21PxsCreateFinalizeTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK21PxsCreateFinalizeTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (492576|0);
}
function __ZN21PxsCreateFinalizeTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 28|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 32|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 36|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 64|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 56|0);
 $19 = HEAP32[$18>>2]|0;
 (__Z31createFinalizeContacts_ParallelN5physx14PxFrictionType4EnumEPNS_23PxcSolverConstraintDescEPNS_17PxcSolverBodyDataEjRNS_16PxsThreadContextEPiffffPNS_10PxsContextES8_($1,0,$3,0,$5,$7,$9,$11,$13,$15,$17,$19)|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<4)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<4)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;
  }
  $11 = (($$01$i) + 16|0);
  $12 = ($11>>>0)<($7>>>0);
  if ($12) {
   $$01$i = $11;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx32PxsSolverConstraintPartitionTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx32PxsSolverConstraintPartitionTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx32PxsSolverConstraintPartitionTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (492864|0);
}
function __ZN5physx32PxsSolverConstraintPartitionTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0;
 var $args = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $args = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 9144|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 9148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 9156|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 9316|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 100|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 64|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($1) + 8952|0);
 HEAP32[$16>>2] = $5;
 $17 = HEAP32[$0>>2]|0;
 $18 = (($17) + 8952|0);
 HEAP32[$18>>2] = 0;
 $19 = HEAP32[$0>>2]|0;
 $20 = (($19) + 9092|0);
 HEAP32[$20>>2] = 0;
 $21 = HEAP32[$0>>2]|0;
 $22 = (($21) + 9100|0);
 HEAP32[$22>>2] = 0;
 $23 = HEAP32[$0>>2]|0;
 $24 = (($23) + 8956|0);
 HEAP32[$24>>2] = 0;
 $25 = HEAP32[$0>>2]|0;
 $26 = (($25) + 9104|0);
 HEAP32[$26>>2] = 0;
 $27 = HEAP32[$0>>2]|0;
 $28 = (($27) + 9096|0);
 HEAP32[$28>>2] = 0;
 $29 = ($5|0)==(0);
 if ($29) {
  $78 = HEAP32[$0>>2]|0;
  $79 = (($78) + 8816|0);
  _memset(($79|0),0,132)|0;
  STACKTOP = sp;return;
 } else {
  $30 = $7;
  $31 = $9;
  $32 = (($31) - ($30))|0;
  $33 = (($13) + ($15<<5)|0);
  $34 = $32 >> 5;
  HEAP32[$args>>2] = $33;
  $35 = HEAP32[$0>>2]|0;
  $36 = (($35) + 9368|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($args) + 8|0);
  HEAP32[$38>>2] = $37;
  $39 = (($args) + 16|0);
  HEAP32[$39>>2] = $3;
  $40 = (($args) + 24|0);
  HEAP32[$40>>2] = $7;
  $41 = (($35) + 9372|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($args) + 12|0);
  HEAP32[$43>>2] = $42;
  $44 = (($this) + 48|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($args) + 4|0);
  HEAP32[$46>>2] = $45;
  $47 = (($args) + 20|0);
  HEAP32[$47>>2] = $5;
  $48 = (($args) + 28|0);
  HEAP32[$48>>2] = $34;
  $49 = (($35) + 9168|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($args) + 32|0);
  HEAP32[$51>>2] = $50;
  $52 = (($35) + 9276|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($args) + 40|0);
  HEAP32[$54>>2] = $53;
  $55 = (($args) + 44|0);
  HEAP32[$55>>2] = 0;
  $56 = (($args) + 52|0);
  HEAP32[$56>>2] = 0;
  $57 = (($args) + 48|0);
  HEAP32[$57>>2] = 0;
  $58 = (($35) + 9180|0);
  $59 = (($args) + 56|0);
  HEAP32[$59>>2] = $58;
  $60 = (($35) + 9192|0);
  $61 = (($args) + 60|0);
  HEAP32[$61>>2] = $60;
  $62 = (($35) + 8816|0);
  $63 = (($args) + 64|0);
  HEAP32[$63>>2] = $62;
  $64 = (($35) + 8960|0);
  $65 = (($args) + 68|0);
  HEAP32[$65>>2] = $64;
  $66 = (__ZN5physx27PartitionContactConstraintsERNS_23ConstraintPartitionArgsE($args)|0);
  $67 = HEAP32[$0>>2]|0;
  $68 = (($67) + 9284|0);
  HEAP32[$68>>2] = $66;
  $69 = HEAP32[$57>>2]|0;
  $70 = HEAP32[$0>>2]|0;
  $71 = (($70) + 8952|0);
  HEAP32[$71>>2] = $69;
  $72 = HEAP32[$56>>2]|0;
  $73 = HEAP32[$0>>2]|0;
  $74 = (($73) + 9092|0);
  HEAP32[$74>>2] = $72;
  $75 = HEAP32[$55>>2]|0;
  $76 = HEAP32[$0>>2]|0;
  $77 = (($76) + 9100|0);
  HEAP32[$77>>2] = $75;
  STACKTOP = sp;return;
 }
}
function __ZN5physx23PxsSolverSetupSolveTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxsSolverSetupSolveTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx23PxsSolverSetupSolveTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (493024|0);
}
function __ZN5physx23PxsSolverSetupSolveTask11runInternalEv($this) {
 $this = $this|0;
 var $$lcssa49 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre101 = 0, $$pre102 = 0, $$pre102$pre = 0, $$pre104 = 0, $$pre105 = 0, $$pre106 = 0, $$pre107 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0;
 var $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0;
 var $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0;
 var $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = Math_fround(0), $553 = 0, $554 = 0, $555 = 0;
 var $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0;
 var $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0;
 var $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = Math_fround(0), $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0;
 var $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = Math_fround(0);
 var $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0;
 var $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0;
 var $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0;
 var $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $a$050 = 0, $a16$010 = 0, $a3$029 = 0, $b$072 = 0, $b1$038 = 0, $bb$0$lcssa = 0, $bb$073 = 0, $bb$1 = 0, $bb$2$lcssa = 0, $bb$251 = 0, $bb$3$lcssa = 0, $bb$339 = 0, $bb$4 = 0, $c$060 = 0, $contactDescPtr$0$lcssa = 0, $contactDescPtr$076 = 0, $contactDescPtr$1$lcssa112 = 0, $contactDescPtr$164 = 0, $contactDescPtr$2 = 0, $exitcond = 0;
 var $exitcond100 = 0, $exitcond94 = 0, $exitcond95 = 0, $exitcond97 = 0, $exitcond99 = 0, $fricI$0$lcssa = 0, $fricI$030 = 0, $fricI$1 = 0, $frictionDescCount$0 = 0, $frictionDescPtr$0$lcssa = 0, $frictionDescPtr$032 = 0, $frictionDescPtr$1$lcssa = 0, $frictionDescPtr$124 = 0, $frictionDescPtr$3 = 0, $headers$0$lcssa = 0, $headers$031 = 0, $headers$1 = 0, $i$0$lcssa = 0, $i$074 = 0, $i$1$lcssa114 = 0;
 var $i$162 = 0, $i$2 = 0, $i$352 = 0, $i$4$lcssa = 0, $i$440 = 0, $i17$016 = 0, $i18$014 = 0, $i19$011 = 0, $inEnabled$not$i$i$i1 = 0, $inEnabled$not$i$i$i6 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $j$0$lcssa = 0, $j$075 = 0, $j$1$lcssa113 = 0, $j$163 = 0, $j$2 = 0, $j$3$lcssa = 0, $j$353 = 0, $j$4$lcssa = 0;
 var $j$441 = 0, $j$5 = 0, $lftr$wideiv = 0, $newStride$061 = 0, $newStride$1 = 0, $or$cond$i$i$i2 = 0, $or$cond$i$i$i7 = 0, $phitmp = 0, $scevgep = 0, $scevgep88 = 0, $scevgep92$sum = 0, $scevgep93 = 0, $thresholdPairsOut = 0, $type$0$lcssa = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $thresholdPairsOut = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 9168|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 100|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + ($9<<5)|0);
 $11 = (($5) + 112|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($1) + 8956|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($1) + 9252|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $63 = $1;$bb$0$lcssa = 0;$contactDescPtr$0$lcssa = $3;$i$0$lcssa = 0;$j$0$lcssa = 0;
 } else {
  $19 = $1;$b$072 = 0;$bb$073 = 0;$contactDescPtr$076 = $3;$i$074 = 0;$j$075 = 0;
  while(1) {
   $18 = (($19) + 9180|0);
   $20 = HEAP32[$18>>2]|0;
   $21 = ((($20) + ($b$072<<3)|0) + 4|0);
   $22 = HEAP16[$21>>1]|0;
   $23 = ($22<<16>>16)==(0);
   if ($23) {
    $bb$1 = $bb$073;$contactDescPtr$1$lcssa112 = $contactDescPtr$076;$i$1$lcssa114 = $i$074;$j$1$lcssa113 = $j$075;
   } else {
    $24 = (($22) + -1)<<16>>16;
    $25 = $24&65535;
    $c$060 = 0;$contactDescPtr$164 = $contactDescPtr$076;$i$162 = $i$074;$j$163 = $j$075;$newStride$061 = $22;
    while(1) {
     $26 = (($3) + ($i$162<<5)|0);
     $27 = ((($3) + ($i$162<<5)|0) + 26|0);
     $28 = HEAP16[$27>>1]|0;
     $29 = ($28<<16>>16)==(0);
     if ($29) {
      $30 = (($newStride$061) + -1)<<16>>16;
      $contactDescPtr$2 = $contactDescPtr$164;$j$2 = $j$163;$newStride$1 = $30;
     } else {
      $31 = ($i$162|0)==($j$163|0);
      if (!($31)) {
       $32 = (($3) + ($j$163<<5)|0);
       ;HEAP32[$32+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$32+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$32+20>>2]=HEAP32[$26+20>>2]|0;HEAP32[$32+24>>2]=HEAP32[$26+24>>2]|0;HEAP32[$32+28>>2]=HEAP32[$26+28>>2]|0;
      }
      $33 = (($j$163) + 1)|0;
      $34 = (($contactDescPtr$164) + 32|0);
      $contactDescPtr$2 = $34;$j$2 = $33;$newStride$1 = $newStride$061;
     }
     $i$2 = (($i$162) + 1)|0;
     $35 = (($c$060) + 1)<<16>>16;
     $36 = ($35&65535)<($22&65535);
     if ($36) {
      $c$060 = $35;$contactDescPtr$164 = $contactDescPtr$2;$i$162 = $i$2;$j$163 = $j$2;$newStride$061 = $newStride$1;
     } else {
      break;
     }
    }
    $37 = (($i$074) + 1)|0;
    $38 = (($37) + ($25))|0;
    $39 = ($newStride$1<<16>>16)==(0);
    if ($39) {
     $bb$1 = $bb$073;$contactDescPtr$1$lcssa112 = $contactDescPtr$2;$i$1$lcssa114 = $38;$j$1$lcssa113 = $j$2;
    } else {
     $40 = HEAP32[$0>>2]|0;
     $41 = (($40) + 9180|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($42) + ($bb$073<<3)|0);
     HEAP32[$43>>2] = $j$075;
     $44 = HEAP32[$0>>2]|0;
     $45 = (($44) + 9180|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ((($46) + ($bb$073<<3)|0) + 4|0);
     HEAP16[$47>>1] = $newStride$1;
     $48 = ((($3) + ($j$075<<5)|0) + 16|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = HEAP8[$49>>0]|0;
     $51 = $50&255;
     $52 = HEAP32[$0>>2]|0;
     $53 = (($52) + 9180|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ((($54) + ($bb$073<<3)|0) + 6|0);
     HEAP16[$55>>1] = $51;
     $56 = (($bb$073) + 1)|0;
     $bb$1 = $56;$contactDescPtr$1$lcssa112 = $contactDescPtr$2;$i$1$lcssa114 = $38;$j$1$lcssa113 = $j$2;
    }
   }
   $57 = (($b$072) + 1)|0;
   $exitcond100 = ($57|0)==($16|0);
   $$pre = HEAP32[$0>>2]|0;
   if ($exitcond100) {
    $63 = $$pre;$bb$0$lcssa = $bb$1;$contactDescPtr$0$lcssa = $contactDescPtr$1$lcssa112;$i$0$lcssa = $i$1$lcssa114;$j$0$lcssa = $j$1$lcssa113;
    break;
   } else {
    $19 = $$pre;$b$072 = $57;$bb$073 = $bb$1;$contactDescPtr$076 = $contactDescPtr$1$lcssa112;$i$074 = $i$1$lcssa114;$j$075 = $j$1$lcssa113;
   }
  }
 }
 $58 = $contactDescPtr$0$lcssa;
 $59 = $3;
 $60 = (($58) - ($59))|0;
 $61 = $60 >> 5;
 $62 = (($63) + 8952|0);
 HEAP32[$62>>2] = $61;
 $64 = HEAP32[$0>>2]|0;
 $65 = (($64) + 9100|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0);
 if ($67) {
  $$lcssa49 = $64;$bb$2$lcssa = $bb$0$lcssa;$j$3$lcssa = $j$0$lcssa;
 } else {
  $69 = $64;$a$050 = 0;$bb$251 = $bb$0$lcssa;$i$352 = $i$0$lcssa;$j$353 = $j$0$lcssa;
  while(1) {
   $68 = (($69) + 9276|0);
   $70 = HEAP32[$68>>2]|0;
   $71 = ((($70) + ($a$050<<4)|0) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0);
   if ($73) {
    $96 = $70;$bb$3$lcssa = $bb$251;$i$4$lcssa = $i$352;$j$4$lcssa = $j$353;
   } else {
    $b1$038 = 0;$bb$339 = $bb$251;$i$440 = $i$352;$j$441 = $j$353;
    while(1) {
     $74 = (($3) + ($i$440<<5)|0);
     $75 = ((($3) + ($i$440<<5)|0) + 26|0);
     $76 = HEAP16[$75>>1]|0;
     $77 = ($76<<16>>16)==(0);
     if ($77) {
      $bb$4 = $bb$339;$j$5 = $j$441;
     } else {
      $78 = HEAP32[$0>>2]|0;
      $79 = (($bb$339) + 1)|0;
      $80 = (($78) + 9180|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ((($81) + ($bb$339<<3)|0) + 4|0);
      HEAP16[$82>>1] = 1;
      $83 = (($81) + ($bb$339<<3)|0);
      HEAP32[$83>>2] = $j$441;
      $84 = ((($3) + ($i$440<<5)|0) + 16|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = HEAP8[$85>>0]|0;
      $87 = $86&255;
      $88 = ((($81) + ($bb$339<<3)|0) + 6|0);
      HEAP16[$88>>1] = $87;
      $89 = ($i$440|0)==($j$441|0);
      if (!($89)) {
       $90 = (($3) + ($j$441<<5)|0);
       ;HEAP32[$90+0>>2]=HEAP32[$74+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$74+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$74+12>>2]|0;HEAP32[$90+16>>2]=HEAP32[$74+16>>2]|0;HEAP32[$90+20>>2]=HEAP32[$74+20>>2]|0;HEAP32[$90+24>>2]=HEAP32[$74+24>>2]|0;HEAP32[$90+28>>2]=HEAP32[$74+28>>2]|0;
      }
      $91 = (($j$441) + 1)|0;
      $bb$4 = $79;$j$5 = $91;
     }
     $92 = (($i$440) + 1)|0;
     $93 = (($b1$038) + 1)|0;
     $exitcond97 = ($93|0)==($72|0);
     if ($exitcond97) {
      break;
     } else {
      $b1$038 = $93;$bb$339 = $bb$4;$i$440 = $92;$j$441 = $j$5;
     }
    }
    $94 = (($i$352) + ($72))|0;
    $$pre106 = HEAP32[$0>>2]|0;
    $$phi$trans$insert = (($$pre106) + 9276|0);
    $$pre107 = HEAP32[$$phi$trans$insert>>2]|0;
    $96 = $$pre107;$bb$3$lcssa = $bb$4;$i$4$lcssa = $94;$j$4$lcssa = $j$5;
   }
   $95 = (($96) + ($a$050<<4)|0);
   HEAP32[$95>>2] = $j$353;
   $97 = (($j$4$lcssa) - ($j$353))|0;
   $98 = HEAP32[$0>>2]|0;
   $99 = (($98) + 9276|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ((($100) + ($a$050<<4)|0) + 4|0);
   HEAP32[$101>>2] = $97;
   $102 = (($a$050) + 1)|0;
   $103 = HEAP32[$0>>2]|0;
   $exitcond99 = ($102|0)==($66|0);
   if ($exitcond99) {
    $$lcssa49 = $103;$bb$2$lcssa = $bb$3$lcssa;$j$3$lcssa = $j$4$lcssa;
    break;
   } else {
    $69 = $103;$a$050 = $102;$bb$251 = $bb$3$lcssa;$i$352 = $i$4$lcssa;$j$353 = $j$4$lcssa;
   }
  }
 }
 $104 = (($$lcssa49) + 9184|0);
 HEAP32[$104>>2] = $bb$2$lcssa;
 $105 = (($this) + 48|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = HEAP32[$0>>2]|0;
 $108 = (($107) + 9368|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = (($107) + 9372|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = (($107) + 9276|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($107) + 9100|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (__ZN5physx33PostProcessConstraintPartitioningEPNS_13PxcSolverBodyEjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjPNS_24PxcFsSelfConstraintBlockEj($10,$106,$109,$111,$3,$61,$113,$115)|0);
 $117 = (($j$3$lcssa) - ($61))|0;
 $118 = HEAP32[$0>>2]|0;
 $119 = (($118) + 9092|0);
 HEAP32[$119>>2] = $117;
 $120 = HEAP32[$0>>2]|0;
 $121 = (($120) + 9260|0);
 HEAP32[$121>>2] = $j$3$lcssa;
 $122 = HEAP32[$0>>2]|0;
 $123 = (($122) + 8776|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($124|0)==(0);
 if ($125) {
  $frictionDescCount$0 = $14;
 } else {
  $126 = (($122) + 9156|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = (($122) + 9192|0);
  $129 = (($122) + 9196|0);
  HEAP32[$129>>2] = 0;
  $130 = HEAP32[$0>>2]|0;
  $131 = (($130) + 9184|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = (($122) + 9200|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = $134 & 2147483647;
  $136 = ($135>>>0)<($132>>>0);
  if ($136) {
   __ZN5physx6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENS0_19ReflectionAllocatorIS2_EEE8recreateEj($128,$132);
  }
  $137 = HEAP32[$128>>2]|0;
  $138 = ($bb$0$lcssa|0)==(0);
  if ($138) {
   $312 = $137;$fricI$0$lcssa = 0;$frictionDescPtr$0$lcssa = $127;$headers$0$lcssa = $137;
  } else {
   $a3$029 = 0;$fricI$030 = 0;$frictionDescPtr$032 = $127;$headers$031 = $137;
   while(1) {
    $139 = HEAP32[$0>>2]|0;
    $140 = (($139) + 9180|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (($141) + ($a3$029<<3)|0);
    $143 = ((($141) + ($a3$029<<3)|0) + 4|0);
    $144 = HEAP16[$143>>1]|0;
    $145 = ((($141) + ($a3$029<<3)|0) + 6|0);
    $146 = HEAP16[$145>>1]|0;
    switch ($146<<16>>16) {
    case 5: case 3: case 1:  {
     $147 = ($144<<16>>16)==(0);
     if ($147) {
      $frictionDescPtr$1$lcssa = $frictionDescPtr$032;$type$0$lcssa = 0;
     } else {
      $148 = (($144) + -1)<<16>>16;
      $149 = $148&65535;
      $$pre105 = HEAP32[$142>>2]|0;
      $frictionDescPtr$124 = $frictionDescPtr$032;$indvars$iv = 0;
      while(1) {
       $150 = (($$pre105) + ($indvars$iv))|0;
       $151 = ((($3) + ($150<<5)|0) + 16|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = (($152) + 2|0);
       $154 = HEAP16[$153>>1]|0;
       $155 = $154&65535;
       $156 = (($152) + ($155)|0);
       $157 = ((($3) + ($150<<5)|0) + 26|0);
       $158 = HEAP16[$157>>1]|0;
       $159 = $158&65535;
       $160 = $159 << 4;
       $161 = (($160) - ($155))|0;
       $162 = $161 >>> 4;
       $163 = $162&65535;
       $164 = (($frictionDescPtr$124) + 26|0);
       HEAP16[$164>>1] = $163;
       $165 = (($frictionDescPtr$124) + 16|0);
       HEAP32[$165>>2] = $156;
       $166 = (($3) + ($150<<5)|0);
       $167 = HEAP32[$166>>2]|0;
       HEAP32[$frictionDescPtr$124>>2] = $167;
       $168 = ((($3) + ($150<<5)|0) + 4|0);
       $169 = HEAP32[$168>>2]|0;
       $170 = (($frictionDescPtr$124) + 4|0);
       HEAP32[$170>>2] = $169;
       $171 = ((($3) + ($150<<5)|0) + 10|0);
       $172 = HEAP16[$171>>1]|0;
       $173 = (($frictionDescPtr$124) + 10|0);
       HEAP16[$173>>1] = $172;
       $174 = ((($3) + ($150<<5)|0) + 14|0);
       $175 = HEAP16[$174>>1]|0;
       $176 = (($frictionDescPtr$124) + 14|0);
       HEAP16[$176>>1] = $175;
       $177 = ((($3) + ($150<<5)|0) + 8|0);
       $178 = HEAP16[$177>>1]|0;
       $179 = (($frictionDescPtr$124) + 8|0);
       HEAP16[$179>>1] = $178;
       $180 = ((($3) + ($150<<5)|0) + 12|0);
       $181 = HEAP16[$180>>1]|0;
       $182 = (($frictionDescPtr$124) + 12|0);
       HEAP16[$182>>1] = $181;
       $183 = (($frictionDescPtr$124) + 20|0);
       HEAP32[$183>>2] = 0;
       $184 = (($frictionDescPtr$124) + 24|0);
       HEAP16[$184>>1] = 0;
       $185 = (($frictionDescPtr$124) + 32|0);
       $indvars$iv$next = (($indvars$iv) + 1)|0;
       $lftr$wideiv = $indvars$iv$next&65535;
       $exitcond94 = ($lftr$wideiv<<16>>16)==($144<<16>>16);
       if ($exitcond94) {
        break;
       } else {
        $frictionDescPtr$124 = $185;$indvars$iv = $indvars$iv$next;
       }
      }
      $scevgep92$sum = (($149) + 1)|0;
      $scevgep93 = (($frictionDescPtr$032) + ($scevgep92$sum<<5)|0);
      $186 = HEAP8[$156>>0]|0;
      $phitmp = $186&255;
      $frictionDescPtr$1$lcssa = $scevgep93;$type$0$lcssa = $phitmp;
     }
     $187 = $144&65535;
     HEAP32[$headers$031>>2] = $fricI$030;
     $188 = (($headers$031) + 4|0);
     HEAP16[$188>>1] = $144;
     $189 = (($headers$031) + 6|0);
     HEAP16[$189>>1] = $type$0$lcssa;
     $190 = (($headers$031) + 8|0);
     $191 = (($187) + ($fricI$030))|0;
     $fricI$1 = $191;$frictionDescPtr$3 = $frictionDescPtr$1$lcssa;$headers$1 = $190;
     break;
    }
    case 8: case 7:  {
     $192 = HEAP32[$142>>2]|0;
     $193 = ((($3) + ($192<<5)|0) + 16|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = (($194) + 2|0);
     $196 = HEAP16[$195>>1]|0;
     $197 = $196&65535;
     $198 = (($194) + ($197)|0);
     $199 = ((($3) + ($192<<5)|0) + 26|0);
     $200 = HEAP16[$199>>1]|0;
     $201 = $200&65535;
     $202 = $201 << 4;
     $203 = (($202) - ($197))|0;
     $204 = HEAP8[$198>>0]|0;
     $205 = $203 >>> 4;
     $206 = $205&65535;
     $207 = (($frictionDescPtr$032) + 26|0);
     HEAP16[$207>>1] = $206;
     $208 = (($frictionDescPtr$032) + 16|0);
     HEAP32[$208>>2] = $198;
     $209 = (($3) + ($192<<5)|0);
     $210 = HEAP32[$209>>2]|0;
     HEAP32[$frictionDescPtr$032>>2] = $210;
     $211 = ((($3) + ($192<<5)|0) + 4|0);
     $212 = HEAP32[$211>>2]|0;
     $213 = (($frictionDescPtr$032) + 4|0);
     HEAP32[$213>>2] = $212;
     $214 = ((($3) + ($192<<5)|0) + 10|0);
     $215 = HEAP16[$214>>1]|0;
     $216 = (($frictionDescPtr$032) + 10|0);
     HEAP16[$216>>1] = $215;
     $217 = ((($3) + ($192<<5)|0) + 14|0);
     $218 = HEAP16[$217>>1]|0;
     $219 = (($frictionDescPtr$032) + 14|0);
     HEAP16[$219>>1] = $218;
     $220 = ((($3) + ($192<<5)|0) + 8|0);
     $221 = HEAP16[$220>>1]|0;
     $222 = (($frictionDescPtr$032) + 8|0);
     HEAP16[$222>>1] = $221;
     $223 = ((($3) + ($192<<5)|0) + 12|0);
     $224 = HEAP16[$223>>1]|0;
     $225 = (($frictionDescPtr$032) + 12|0);
     HEAP16[$225>>1] = $224;
     $226 = (($frictionDescPtr$032) + 20|0);
     HEAP32[$226>>2] = 0;
     $227 = (($frictionDescPtr$032) + 24|0);
     HEAP16[$227>>1] = 0;
     $228 = (($192) + 1)|0;
     $229 = (($frictionDescPtr$032) + 58|0);
     HEAP16[$229>>1] = $206;
     $230 = (($frictionDescPtr$032) + 48|0);
     HEAP32[$230>>2] = $198;
     $231 = (($3) + ($228<<5)|0);
     $232 = HEAP32[$231>>2]|0;
     $233 = (($frictionDescPtr$032) + 32|0);
     HEAP32[$233>>2] = $232;
     $234 = ((($3) + ($228<<5)|0) + 4|0);
     $235 = HEAP32[$234>>2]|0;
     $236 = (($frictionDescPtr$032) + 36|0);
     HEAP32[$236>>2] = $235;
     $237 = ((($3) + ($228<<5)|0) + 10|0);
     $238 = HEAP16[$237>>1]|0;
     $239 = (($frictionDescPtr$032) + 42|0);
     HEAP16[$239>>1] = $238;
     $240 = ((($3) + ($228<<5)|0) + 14|0);
     $241 = HEAP16[$240>>1]|0;
     $242 = (($frictionDescPtr$032) + 46|0);
     HEAP16[$242>>1] = $241;
     $243 = ((($3) + ($228<<5)|0) + 8|0);
     $244 = HEAP16[$243>>1]|0;
     $245 = (($frictionDescPtr$032) + 40|0);
     HEAP16[$245>>1] = $244;
     $246 = ((($3) + ($228<<5)|0) + 12|0);
     $247 = HEAP16[$246>>1]|0;
     $248 = (($frictionDescPtr$032) + 44|0);
     HEAP16[$248>>1] = $247;
     $249 = (($frictionDescPtr$032) + 52|0);
     HEAP32[$249>>2] = 0;
     $250 = (($frictionDescPtr$032) + 56|0);
     HEAP16[$250>>1] = 0;
     $251 = (($192) + 2)|0;
     $252 = (($frictionDescPtr$032) + 90|0);
     HEAP16[$252>>1] = $206;
     $253 = (($frictionDescPtr$032) + 80|0);
     HEAP32[$253>>2] = $198;
     $254 = (($3) + ($251<<5)|0);
     $255 = HEAP32[$254>>2]|0;
     $256 = (($frictionDescPtr$032) + 64|0);
     HEAP32[$256>>2] = $255;
     $257 = ((($3) + ($251<<5)|0) + 4|0);
     $258 = HEAP32[$257>>2]|0;
     $259 = (($frictionDescPtr$032) + 68|0);
     HEAP32[$259>>2] = $258;
     $260 = ((($3) + ($251<<5)|0) + 10|0);
     $261 = HEAP16[$260>>1]|0;
     $262 = (($frictionDescPtr$032) + 74|0);
     HEAP16[$262>>1] = $261;
     $263 = ((($3) + ($251<<5)|0) + 14|0);
     $264 = HEAP16[$263>>1]|0;
     $265 = (($frictionDescPtr$032) + 78|0);
     HEAP16[$265>>1] = $264;
     $266 = ((($3) + ($251<<5)|0) + 8|0);
     $267 = HEAP16[$266>>1]|0;
     $268 = (($frictionDescPtr$032) + 72|0);
     HEAP16[$268>>1] = $267;
     $269 = ((($3) + ($251<<5)|0) + 12|0);
     $270 = HEAP16[$269>>1]|0;
     $271 = (($frictionDescPtr$032) + 76|0);
     HEAP16[$271>>1] = $270;
     $272 = (($frictionDescPtr$032) + 84|0);
     HEAP32[$272>>2] = 0;
     $273 = (($frictionDescPtr$032) + 88|0);
     HEAP16[$273>>1] = 0;
     $274 = (($192) + 3)|0;
     $275 = (($frictionDescPtr$032) + 122|0);
     HEAP16[$275>>1] = $206;
     $276 = (($frictionDescPtr$032) + 112|0);
     HEAP32[$276>>2] = $198;
     $277 = (($3) + ($274<<5)|0);
     $278 = HEAP32[$277>>2]|0;
     $279 = (($frictionDescPtr$032) + 96|0);
     HEAP32[$279>>2] = $278;
     $280 = ((($3) + ($274<<5)|0) + 4|0);
     $281 = HEAP32[$280>>2]|0;
     $282 = (($frictionDescPtr$032) + 100|0);
     HEAP32[$282>>2] = $281;
     $283 = ((($3) + ($274<<5)|0) + 10|0);
     $284 = HEAP16[$283>>1]|0;
     $285 = (($frictionDescPtr$032) + 106|0);
     HEAP16[$285>>1] = $284;
     $286 = ((($3) + ($274<<5)|0) + 14|0);
     $287 = HEAP16[$286>>1]|0;
     $288 = (($frictionDescPtr$032) + 110|0);
     HEAP16[$288>>1] = $287;
     $289 = ((($3) + ($274<<5)|0) + 8|0);
     $290 = HEAP16[$289>>1]|0;
     $291 = (($frictionDescPtr$032) + 104|0);
     HEAP16[$291>>1] = $290;
     $292 = ((($3) + ($274<<5)|0) + 12|0);
     $293 = HEAP16[$292>>1]|0;
     $294 = (($frictionDescPtr$032) + 108|0);
     HEAP16[$294>>1] = $293;
     $295 = (($frictionDescPtr$032) + 116|0);
     HEAP32[$295>>2] = 0;
     $296 = (($frictionDescPtr$032) + 120|0);
     HEAP16[$296>>1] = 0;
     $scevgep88 = (($frictionDescPtr$032) + 128|0);
     HEAP32[$headers$031>>2] = $fricI$030;
     $297 = (($headers$031) + 4|0);
     HEAP16[$297>>1] = $144;
     $298 = $204&255;
     $299 = (($headers$031) + 6|0);
     HEAP16[$299>>1] = $298;
     $300 = (($headers$031) + 8|0);
     $301 = $144&65535;
     $302 = (($301) + ($fricI$030))|0;
     $fricI$1 = $302;$frictionDescPtr$3 = $scevgep88;$headers$1 = $300;
     break;
    }
    default: {
     $fricI$1 = $fricI$030;$frictionDescPtr$3 = $frictionDescPtr$032;$headers$1 = $headers$031;
    }
    }
    $303 = (($a3$029) + 1)|0;
    $exitcond95 = ($303|0)==($bb$0$lcssa|0);
    if ($exitcond95) {
     break;
    } else {
     $a3$029 = $303;$fricI$030 = $fricI$1;$frictionDescPtr$032 = $frictionDescPtr$3;$headers$031 = $headers$1;
    }
   }
   $$pre104 = HEAP32[$128>>2]|0;
   $312 = $$pre104;$fricI$0$lcssa = $fricI$1;$frictionDescPtr$0$lcssa = $frictionDescPtr$3;$headers$0$lcssa = $headers$1;
  }
  $304 = $frictionDescPtr$0$lcssa;
  $305 = $127;
  $306 = (($304) - ($305))|0;
  $307 = $306 >> 5;
  $308 = HEAP32[$0>>2]|0;
  $309 = (($308) + 8956|0);
  HEAP32[$309>>2] = $307;
  $310 = $headers$0$lcssa;
  $311 = $312;
  $313 = (($310) - ($311))|0;
  $314 = $313 >> 3;
  HEAP32[$129>>2] = $314;
  $315 = HEAP32[$105>>2]|0;
  $316 = HEAP32[$0>>2]|0;
  $317 = (($316) + 9368|0);
  $318 = HEAP32[$317>>2]|0;
  $319 = (($316) + 9372|0);
  $320 = HEAP32[$319>>2]|0;
  $321 = (($316) + 9280|0);
  $322 = HEAP32[$321>>2]|0;
  $323 = (($316) + 9104|0);
  $324 = HEAP32[$323>>2]|0;
  __ZN5physx41PostProcessFrictionConstraintPartitioningEPNS_13PxcSolverBodyEjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjPNS_24PxcFsSelfConstraintBlockEj($10,$315,$318,$320,$127,$307,$322,$324);
  $325 = (($fricI$0$lcssa) - ($307))|0;
  $326 = HEAP32[$0>>2]|0;
  $327 = (($326) + 9096|0);
  HEAP32[$327>>2] = $325;
  $328 = HEAP32[$0>>2]|0;
  $329 = (($328) + 8956|0);
  HEAP32[$329>>2] = $307;
  $330 = HEAP32[$0>>2]|0;
  $331 = (($330) + 9264|0);
  HEAP32[$331>>2] = $fricI$0$lcssa;
  $frictionDescCount$0 = $fricI$0$lcssa;
 }
 $332 = HEAP32[$4>>2]|0;
 $333 = (($332) + 96|0);
 $334 = HEAP32[$333>>2]|0;
 $335 = (($334) + 6736|0);
 $336 = HEAP32[$335>>2]|0;
 $337 = (($336) + 8|0);
 $338 = HEAP32[$337>>2]|0;
 $339 = $336;
 $340 = $339;
 $341 = HEAP32[$340>>2]|0;
 $342 = (($339) + 4)|0;
 $343 = $342;
 $344 = HEAP32[$343>>2]|0;
 $345 = HEAP32[$338>>2]|0;
 $346 = (($345) + 8|0);
 $347 = HEAP32[$346>>2]|0;
 FUNCTION_TABLE_viiii[$347 & 511]($338,85,$341,$344);
 $348 = HEAP32[$0>>2]|0;
 $349 = (($348) + 9168|0);
 $350 = HEAP32[$349>>2]|0;
 $351 = (($348) + 9156|0);
 $352 = HEAP32[$351>>2]|0;
 $scevgep = (($348) + 9320|0);
 ;HEAP32[$scevgep+0>>2]=0|0;HEAP32[$scevgep+4>>2]=0|0;HEAP32[$scevgep+8>>2]=0|0;HEAP32[$scevgep+12>>2]=0|0;HEAP32[$scevgep+16>>2]=0|0;HEAP32[$scevgep+20>>2]=0|0;
 $353 = (($348) + 9324|0);
 $354 = (($348) + 9328|0);
 $355 = (($348) + 9332|0);
 $356 = (($348) + 9336|0);
 $357 = (($348) + 9340|0);
 $358 = (($this) + 8|0);
 $359 = HEAP32[$358>>2]|0;
 $360 = HEAP32[$359>>2]|0;
 $361 = (($360) + 16|0);
 $362 = HEAP32[$361>>2]|0;
 $363 = (FUNCTION_TABLE_ii[$362 & 4095]($359)|0);
 $364 = HEAP32[$363>>2]|0;
 $365 = (($364) + 4|0);
 $366 = HEAP32[$365>>2]|0;
 $367 = (FUNCTION_TABLE_ii[$366 & 4095]($363)|0);
 $368 = $116 << 4;
 $369 = (($368) + 16)|0;
 $370 = (($j$3$lcssa>>>0) / ($369>>>0))&-1;
 $371 = (($370) + 1)|0;
 $372 = ($371>>>0)<($367>>>0);
 $373 = $372 ? $371 : $367;
 $374 = ($373>>>0)>(1);
 if ($374) {
  $375 = HEAP32[$4>>2]|0;
  $376 = (($375) + 96|0);
  $377 = HEAP32[$376>>2]|0;
  $378 = (($this) + 12|0);
  $379 = (($this) + 56|0);
  $380 = (($this) + 32|0);
  $381 = (($this) + 52|0);
  $382 = (($this) + 28|0);
  $383 = $367 ^ -1;
  $384 = $116 << 4;
  $385 = (($384) + 16)|0;
  $386 = (($j$3$lcssa>>>0) / ($385>>>0))&-1;
  $387 = (-2 - ($386))|0;
  $388 = ($387>>>0)<($383>>>0);
  $umax = $388 ? $383 : $387;
  $389 = $umax ^ -1;
  $391 = $377;$a16$010 = 1;
  while(1) {
   $390 = (($391) + 6732|0);
   $392 = HEAP32[$390>>2]|0;
   $393 = HEAP32[$392>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($393);
   $394 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($392,140,16)|0);
   $395 = HEAP32[$392>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($395);
   $396 = ($394|0)==(0|0);
   if ($396) {
    $462 = 0;
   } else {
    $397 = HEAP32[$4>>2]|0;
    $398 = HEAP32[$0>>2]|0;
    $399 = (($398) + 8776|0);
    $400 = HEAP32[$399>>2]|0;
    $401 = (($398) + 9292|0);
    $402 = HEAP32[$401>>2]|0;
    $403 = (($398) + 9296|0);
    $404 = HEAP32[$403>>2]|0;
    $405 = HEAP32[$8>>2]|0;
    $406 = HEAP32[$105>>2]|0;
    $407 = (($398) + 9368|0);
    $408 = HEAP32[$407>>2]|0;
    $409 = (($398) + 9372|0);
    $410 = HEAP32[$409>>2]|0;
    $411 = (($398) + 9344|0);
    $412 = HEAP32[$411>>2]|0;
    $413 = HEAP32[$379>>2]|0;
    $414 = (($398) + 9132|0);
    $415 = HEAP32[$414>>2]|0;
    $416 = (($398) + 9108|0);
    $417 = HEAP32[$416>>2]|0;
    $418 = (($398) + 9400|0);
    $419 = HEAP32[$380>>2]|0;
    $420 = HEAP32[$381>>2]|0;
    $421 = $420 & 2147483647;
    $422 = (($398) + 9180|0);
    $423 = (($398) + 9192|0);
    $424 = HEAP32[$382>>2]|0;
    $425 = (($394) + 4|0);
    HEAP16[$425>>1] = -1;
    $426 = (($394) + 6|0);
    HEAP16[$426>>1] = 0;
    $427 = (($394) + 8|0);
    HEAP32[$427>>2] = 0;
    HEAP32[$394>>2] = ((434896 + 8|0));
    $428 = (($394) + 12|0);
    HEAP32[$428>>2] = 0;
    $429 = (($394) + 16|0);
    HEAP32[$429>>2] = 0;
    HEAP32[$394>>2] = ((492952 + 8|0));
    $430 = (($394) + 20|0);
    HEAP32[$430>>2] = $422;
    $431 = (($394) + 24|0);
    HEAP32[$431>>2] = $423;
    $432 = (($394) + 28|0);
    HEAP32[$432>>2] = $397;
    $433 = (($394) + 32|0);
    HEAP32[$433>>2] = $402;
    $434 = (($394) + 36|0);
    HEAP32[$434>>2] = $404;
    $435 = (($394) + 40|0);
    HEAP32[$435>>2] = $10;
    $436 = (($394) + 44|0);
    HEAP32[$436>>2] = $12;
    $437 = (($394) + 48|0);
    HEAP32[$437>>2] = $405;
    $438 = (($394) + 52|0);
    HEAP32[$438>>2] = $406;
    $439 = (($394) + 56|0);
    HEAP32[$439>>2] = $350;
    $440 = (($394) + 60|0);
    HEAP32[$440>>2] = $352;
    $441 = (($394) + 64|0);
    HEAP32[$441>>2] = $408;
    $442 = (($394) + 68|0);
    HEAP32[$442>>2] = $415;
    $443 = (($394) + 72|0);
    HEAP32[$443>>2] = $417;
    $444 = (($394) + 76|0);
    HEAP32[$444>>2] = $419;
    $445 = (($394) + 80|0);
    HEAP32[$445>>2] = $421;
    $446 = (($394) + 84|0);
    HEAP32[$446>>2] = $j$3$lcssa;
    $447 = (($394) + 88|0);
    HEAP32[$447>>2] = $frictionDescCount$0;
    $448 = (($394) + 92|0);
    HEAP32[$448>>2] = $410;
    $449 = (($394) + 96|0);
    HEAP32[$449>>2] = $418;
    $450 = (($394) + 100|0);
    HEAP32[$450>>2] = $scevgep;
    $451 = (($394) + 104|0);
    HEAP32[$451>>2] = $357;
    $452 = (($394) + 108|0);
    HEAP32[$452>>2] = $353;
    $453 = (($394) + 112|0);
    HEAP32[$453>>2] = $354;
    $454 = (($394) + 116|0);
    HEAP32[$454>>2] = $355;
    $455 = (($394) + 120|0);
    HEAP32[$455>>2] = $356;
    $456 = (($394) + 124|0);
    HEAP32[$456>>2] = $412;
    $457 = (($394) + 128|0);
    HEAP32[$457>>2] = $413;
    $458 = (($394) + 132|0);
    HEAP32[$458>>2] = $400;
    $459 = (($394) + 136|0);
    HEAP32[$459>>2] = $424;
    $462 = $394;
   }
   $460 = HEAP32[$378>>2]|0;
   $461 = (($462) + 16|0);
   HEAP32[$461>>2] = 1;
   $463 = (($462) + 12|0);
   HEAP32[$463>>2] = $460;
   $464 = ($460|0)==(0|0);
   if (!($464)) {
    $465 = HEAP32[$460>>2]|0;
    $466 = (($465) + 16|0);
    $467 = HEAP32[$466>>2]|0;
    FUNCTION_TABLE_vi[$467 & 4095]($460);
    $468 = HEAP32[$463>>2]|0;
    $469 = (($468) + 8|0);
    $470 = HEAP32[$469>>2]|0;
    $471 = (($462) + 8|0);
    HEAP32[$471>>2] = $470;
   }
   $472 = HEAP32[$462>>2]|0;
   $473 = (($472) + 20|0);
   $474 = HEAP32[$473>>2]|0;
   FUNCTION_TABLE_vi[$474 & 4095]($462);
   $475 = (($a16$010) + 1)|0;
   $476 = HEAP32[$4>>2]|0;
   $477 = (($476) + 96|0);
   $478 = HEAP32[$477>>2]|0;
   $exitcond = ($475|0)==($389|0);
   if ($exitcond) {
    break;
   } else {
    $391 = $478;$a16$010 = $475;
   }
  }
  $479 = (($478) + 6736|0);
  $480 = HEAP32[$479>>2]|0;
  $481 = (($480) + 8|0);
  $482 = HEAP32[$481>>2]|0;
  $483 = $480;
  $484 = $483;
  $485 = HEAP32[$484>>2]|0;
  $486 = (($483) + 4)|0;
  $487 = $486;
  $488 = HEAP32[$487>>2]|0;
  $489 = HEAPU16[545672>>1]|(HEAPU16[545672+2>>1]<<16);
  $490 = $489 & 16711680;
  $inEnabled$not$i$i$i6 = ($490|0)==(0);
  $491 = ($482|0)==(0|0);
  $or$cond$i$i$i7 = $491 | $inEnabled$not$i$i$i6;
  if ($or$cond$i$i$i7) {
   $529 = $476;
  } else {
   $492 = $489&65535;
   $493 = HEAP32[$482>>2]|0;
   $494 = (($493) + 8|0);
   $495 = HEAP32[$494>>2]|0;
   FUNCTION_TABLE_viiii[$495 & 511]($482,$492,$485,$488);
   $$pre101 = HEAP32[$4>>2]|0;
   $529 = $$pre101;
  }
  $496 = HEAP32[$0>>2]|0;
  $497 = (($496) + 8776|0);
  $498 = HEAP32[$497>>2]|0;
  $499 = (491640 + ($498<<2)|0);
  $500 = HEAP32[$499>>2]|0;
  $501 = (($496) + 9292|0);
  $502 = HEAP32[$501>>2]|0;
  $503 = (($496) + 9296|0);
  $504 = HEAP32[$503>>2]|0;
  $505 = HEAP32[$8>>2]|0;
  $506 = HEAP32[$105>>2]|0;
  $507 = (($496) + 9368|0);
  $508 = HEAP32[$507>>2]|0;
  $509 = (($496) + 9372|0);
  $510 = HEAP32[$509>>2]|0;
  $511 = (($496) + 9344|0);
  $512 = HEAP32[$511>>2]|0;
  $513 = (($this) + 56|0);
  $514 = HEAP32[$513>>2]|0;
  $515 = (($496) + 9132|0);
  $516 = HEAP32[$515>>2]|0;
  $517 = (($496) + 9108|0);
  $518 = HEAP32[$517>>2]|0;
  $519 = (($496) + 9400|0);
  $520 = (($this) + 32|0);
  $521 = HEAP32[$520>>2]|0;
  $522 = (($this) + 52|0);
  $523 = HEAP32[$522>>2]|0;
  $524 = $523 & 2147483647;
  $525 = (($496) + 9180|0);
  $526 = (($496) + 9192|0);
  $527 = (($this) + 28|0);
  $528 = HEAP32[$527>>2]|0;
  FUNCTION_TABLE_viiiiiiiiiiiiiiiiiiiiiiiiiiiii[$500 & 3]($529,$502,$504,$10,$12,$505,$506,$508,$510,$350,$j$3$lcssa,$352,$frictionDescCount$0,$scevgep,$357,$353,$355,$512,$514,$354,$516,$518,$519,$521,$524,$356,$525,$526,$528);
  if (!($or$cond$i$i$i7)) {
   $530 = HEAP32[$482>>2]|0;
   $531 = (($530) + 12|0);
   $532 = HEAP32[$531>>2]|0;
   $533 = $489&65535;
   FUNCTION_TABLE_viiii[$532 & 511]($482,$533,$485,$488);
  }
  $534 = HEAP32[$105>>2]|0;
  $535 = HEAP32[$522>>2]|0;
  $536 = $535 & 2147483647;
  $537 = (($536) + ($534))|0;
  while(1) {
   $538 = HEAP32[$356>>2]|0;
   $539 = ($538|0)<($537|0);
   if (!($539)) {
    break;
   }
  }
  $540 = HEAP32[$354>>2]|0;
  $541 = HEAP32[$0>>2]|0;
  $542 = (($541) + 9300|0);
  HEAP32[$542>>2] = $540;
  $704 = HEAP32[$338>>2]|0;
  $705 = (($704) + 12|0);
  $706 = HEAP32[$705>>2]|0;
  FUNCTION_TABLE_viiii[$706 & 511]($338,85,$341,$344);
  STACKTOP = sp;return;
 }
 HEAP32[$thresholdPairsOut>>2] = 0;
 $543 = HEAP32[$0>>2]|0;
 $544 = (($543) + 8776|0);
 $545 = HEAP32[$544>>2]|0;
 $546 = (501752 + ($545<<2)|0);
 $547 = HEAP32[$546>>2]|0;
 $548 = HEAP32[$4>>2]|0;
 $549 = (($548) + 136|0);
 $550 = HEAP32[$549>>2]|0;
 $551 = (($548) + 124|0);
 $552 = Math_fround(HEAPF32[$551>>2]);
 $553 = (($543) + 9292|0);
 $554 = HEAP32[$553>>2]|0;
 $555 = (($543) + 9296|0);
 $556 = HEAP32[$555>>2]|0;
 $557 = HEAP32[$8>>2]|0;
 $558 = HEAP32[$105>>2]|0;
 $559 = (($543) + 9368|0);
 $560 = HEAP32[$559>>2]|0;
 $561 = (($543) + 9372|0);
 $562 = HEAP32[$561>>2]|0;
 $563 = (($543) + 9180|0);
 $564 = (($543) + 9192|0);
 $565 = (($543) + 9132|0);
 $566 = HEAP32[$565>>2]|0;
 $567 = (($543) + 9344|0);
 $568 = HEAP32[$567>>2]|0;
 $569 = (($this) + 56|0);
 $570 = HEAP32[$569>>2]|0;
 FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiii[$547 & 7]($550,$552,$554,$556,$10,$12,$557,$558,$560,$562,$350,$j$3$lcssa,$352,$frictionDescCount$0,$563,$564,$566,$568,$570,$thresholdPairsOut);
 $571 = HEAP32[$thresholdPairsOut>>2]|0;
 $572 = HEAP32[$0>>2]|0;
 $573 = (($572) + 9300|0);
 HEAP32[$573>>2] = $571;
 $574 = HEAP32[$105>>2]|0;
 $575 = (($574) + -1)|0;
 $576 = ($574|0)==(0);
 if (!($576)) {
  $577 = (($this) + 28|0);
  $i17$016 = 0;
  while(1) {
   $582 = (($i17$016) + 4)|0;
   $583 = ($582>>>0)<($575>>>0);
   $584 = $583 ? $582 : $575;
   $585 = HEAP32[$0>>2]|0;
   $586 = (($585) + 9108|0);
   $587 = HEAP32[$586>>2]|0;
   $588 = (($587) + ($584<<2)|0);
   $589 = HEAP32[$588>>2]|0;
   $590 = HEAP32[$0>>2]|0;
   $591 = (($590) + 9132|0);
   $592 = HEAP32[$591>>2]|0;
   $593 = (($592) + ($582<<5)|0);
   $594 = HEAP32[$0>>2]|0;
   $595 = (($594) + 9108|0);
   $596 = HEAP32[$595>>2]|0;
   $$sum9 = (($584) + 32)|0;
   $597 = (($596) + ($$sum9<<2)|0);
   $598 = HEAP32[$577>>2]|0;
   $599 = (($598) + ($584<<2)|0);
   $600 = HEAP32[$0>>2]|0;
   $601 = (($600) + 9108|0);
   $602 = HEAP32[$601>>2]|0;
   $603 = (($602) + ($i17$016<<2)|0);
   $604 = HEAP32[$603>>2]|0;
   $605 = HEAP32[$577>>2]|0;
   $606 = (($605) + ($i17$016<<2)|0);
   $607 = HEAP32[$606>>2]|0;
   $608 = (($600) + 9132|0);
   $609 = HEAP32[$608>>2]|0;
   $610 = (($609) + ($i17$016<<5)|0);
   $611 = HEAP32[$4>>2]|0;
   $612 = (($611) + 124|0);
   $613 = Math_fround(HEAPF32[$612>>2]);
   __ZN5physx13integrateCoreERNS_11PxsBodyCoreERNS_12PxsRigidBodyERNS_2Cm13SpatialVectorEf($604,$607,$610,$613);
   $614 = (($i17$016) + 1)|0;
   $615 = HEAP32[$105>>2]|0;
   $616 = ($614>>>0)<($615>>>0);
   if ($616) {
    $i17$016 = $614;
   } else {
    break;
   }
  }
 }
 $578 = (($this) + 52|0);
 $579 = HEAP32[$578>>2]|0;
 $580 = $579 & 2147483647;
 $581 = ($580|0)==(0);
 if ($581) {
  $704 = HEAP32[$338>>2]|0;
  $705 = (($704) + 12|0);
  $706 = HEAP32[$705>>2]|0;
  FUNCTION_TABLE_viiii[$706 & 511]($338,85,$341,$344);
  STACKTOP = sp;return;
 } else {
  $i18$014 = 0;
 }
 while(1) {
  $617 = HEAP32[$0>>2]|0;
  $618 = (($617) + 9368|0);
  $619 = HEAP32[$618>>2]|0;
  $620 = (($619) + (($i18$014*40)|0)|0);
  $621 = HEAP32[$4>>2]|0;
  $622 = (($621) + 96|0);
  $623 = HEAP32[$622>>2]|0;
  $624 = (($623) + 6736|0);
  $625 = HEAP32[$624>>2]|0;
  $626 = (($625) + 8|0);
  $627 = HEAP32[$626>>2]|0;
  $628 = $625;
  $629 = $628;
  $630 = HEAP32[$629>>2]|0;
  $631 = (($628) + 4)|0;
  $632 = $631;
  $633 = HEAP32[$632>>2]|0;
  $634 = HEAPU16[545864>>1]|(HEAPU16[545864+2>>1]<<16);
  $635 = $634 & 16711680;
  $inEnabled$not$i$i$i1 = ($635|0)==(0);
  $636 = ($627|0)==(0|0);
  $or$cond$i$i$i2 = $636 | $inEnabled$not$i$i$i1;
  if (!($or$cond$i$i$i2)) {
   $637 = $634&65535;
   $638 = HEAP32[$627>>2]|0;
   $639 = (($638) + 8|0);
   $640 = HEAP32[$639>>2]|0;
   FUNCTION_TABLE_viiii[$640 & 511]($627,$637,$630,$633);
  }
  $641 = HEAP32[503520>>2]|0;
  $642 = ($641|0)==(0|0);
  if (!($642)) {
   $643 = HEAP32[$4>>2]|0;
   $644 = (($643) + 124|0);
   $645 = Math_fround(HEAPF32[$644>>2]);
   __ZN5physx21PxcArticulationHelper12updateBodiesERKNS_25PxcArticulationSolverDescEf($620,$645);
  }
  $646 = ((($619) + (($i18$014*40)|0)|0) + 36|0);
  $647 = HEAP16[$646>>1]|0;
  $648 = ($647<<16>>16)==(0);
  if (!($648)) {
   $649 = ((($619) + (($i18$014*40)|0)|0) + 4|0);
   $707 = $647;$i19$011 = 0;
   while(1) {
    $650 = HEAP32[$649>>2]|0;
    $651 = ((($650) + ($i19$011<<5)|0) + 16|0);
    $652 = HEAP32[$651>>2]|0;
    $653 = (($652) + 68|0);
    $654 = $653;
    $655 = $654;
    $656 = HEAP32[$655>>2]|0;
    $657 = (($654) + 4)|0;
    $658 = $657;
    $659 = HEAP32[$658>>2]|0;
    $660 = ($659|0)==(1073741823);
    if ($660) {
     $694 = $707;
    } else {
     $661 = HEAP32[$0>>2]|0;
     $662 = (($661) + 9400|0);
     $663 = (($659) + 32)|0;
     $664 = $663 >>> 5;
     $665 = (($661) + 9404|0);
     $666 = HEAP32[$665>>2]|0;
     $667 = $666 & 2147483647;
     $668 = ($664>>>0)>($667>>>0);
     if ($668) {
      $669 = (($661) + 9408|0);
      $670 = $664 << 2;
      $671 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($669,$670,492392,339)|0);
      $672 = HEAP32[$662>>2]|0;
      $673 = ($672|0)==(0|0);
      if (!($673)) {
       $674 = HEAP32[$665>>2]|0;
       $675 = $674 << 2;
       _memcpy(($671|0),($672|0),($675|0))|0;
       $676 = HEAP32[$665>>2]|0;
       $677 = ($676|0)>(-1);
       if ($677) {
        $678 = HEAP32[$662>>2]|0;
        __ZN5physx6shdfnd9Allocator10deallocateEPv($669,$678);
       }
      }
      $679 = HEAP32[$665>>2]|0;
      $680 = $679 & 2147483647;
      $681 = (($671) + ($680<<2)|0);
      $682 = (($664) - ($679))|0;
      $683 = $682 << 2;
      _memset(($681|0),0,($683|0))|0;
      HEAP32[$662>>2] = $671;
      HEAP32[$665>>2] = $664;
      $$pre102$pre = HEAP16[$646>>1]|0;
      $$pre102 = $$pre102$pre;$689 = $671;
     } else {
      $$pre$i = HEAP32[$662>>2]|0;
      $$pre102 = $707;$689 = $$pre$i;
     }
     $684 = $659 & 31;
     $685 = 1 << $684;
     $686 = (_bitshift64Lshr(($656|0),($659|0),37)|0);
     $687 = tempRet0;
     $688 = (($689) + ($686<<2)|0);
     $690 = HEAP32[$688>>2]|0;
     $691 = $690 | $685;
     HEAP32[$688>>2] = $691;
     $694 = $$pre102;
    }
    $692 = (($i19$011) + 1)|0;
    $693 = $694&65535;
    $695 = ($692>>>0)<($693>>>0);
    if ($695) {
     $707 = $694;$i19$011 = $692;
    } else {
     break;
    }
   }
  }
  if (!($or$cond$i$i$i2)) {
   $696 = HEAP32[$627>>2]|0;
   $697 = (($696) + 12|0);
   $698 = HEAP32[$697>>2]|0;
   $699 = $634&65535;
   FUNCTION_TABLE_viiii[$698 & 511]($627,$699,$630,$633);
  }
  $700 = (($i18$014) + 1)|0;
  $701 = HEAP32[$578>>2]|0;
  $702 = $701 & 2147483647;
  $703 = ($700>>>0)<($702>>>0);
  if ($703) {
   $i18$014 = $700;
  } else {
   break;
  }
 }
 $704 = HEAP32[$338>>2]|0;
 $705 = (($704) + 12|0);
 $706 = HEAP32[$705>>2]|0;
 FUNCTION_TABLE_viiii[$706 & 511]($338,85,$341,$344);
 STACKTOP = sp;return;
}
function __ZN21PxsParallelSolverTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN21PxsParallelSolverTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK21PxsParallelSolverTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (493000|0);
}
function __ZN21PxsParallelSolverTask11runInternalEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $inEnabled$not$i$i$i1 = 0, $or$cond$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 6736|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAPU16[545672>>1]|(HEAPU16[545672+2>>1]<<16);
 $15 = $14 & 16711680;
 $inEnabled$not$i$i$i1 = ($15|0)==(0);
 $16 = ($7|0)==(0|0);
 $or$cond$i$i$i2 = $16 | $inEnabled$not$i$i$i1;
 if ($or$cond$i$i$i2) {
  $81 = $1;
 } else {
  $17 = $14&65535;
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiii[$20 & 511]($7,$17,$10,$13);
  $$pre = HEAP32[$0>>2]|0;
  $81 = $$pre;
 }
 $21 = (($this) + 132|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (491640 + ($22<<2)|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 32|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 36|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 44|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($this) + 48|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 52|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 64|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($this) + 92|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 56|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($this) + 84|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 60|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 88|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 100|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 104|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 108|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($this) + 116|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($this) + 124|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 128|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($this) + 112|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($this) + 68|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($this) + 72|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($this) + 96|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($this) + 76|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($this) + 80|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($this) + 120|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($this) + 20|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($this) + 24|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($this) + 136|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_viiiiiiiiiiiiiiiiiiiiiiiiiiiii[$24 & 3]($81,$26,$28,$30,$32,$34,$36,$38,$40,$42,$44,$46,$48,$50,$52,$54,$56,$58,$60,$62,$64,$66,$68,$70,$72,$74,$76,$78,$80);
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return;
 }
 $82 = HEAP32[$7>>2]|0;
 $83 = (($82) + 12|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = $14&65535;
 FUNCTION_TABLE_viiii[$84 & 511]($7,$85,$10,$13);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsSolverEndTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsSolverEndTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxsSolverEndTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (493096|0);
}
function __ZN5physx16PxsSolverEndTask11runInternalEv($this) {
 $this = $this|0;
 var $$ = 0, $$0$i = 0, $$currentManagerIndex$1 = 0, $$lcssa = 0, $$pre = 0, $$pre$i = 0, $$pre20 = 0, $$pre24 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0);
 var $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$04 = 0, $a2$08 = 0, $currentContactIndex$05 = 0;
 var $currentContactIndex$1 = 0, $currentManagerContactIndex$07 = 0, $currentManagerContactIndex$1 = 0, $currentManagerIndex$06 = 0, $currentManagerIndex$1 = 0, $exitcond = 0, $exitcond19 = 0, $i$014 = 0, $i1$011 = 0, $or$cond = 0, $pManager3$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 9268|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 9424|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 64|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + 112|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = (($this) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $110 = $15;
 } else {
  $19 = (($this) + 28|0);
  $20 = (($15) + 9404|0);
  $21 = (($15) + 9408|0);
  $22 = (($15) + 9400|0);
  $28 = $17;$i$014 = 0;
  while(1) {
   $23 = HEAP32[$19>>2]|0;
   $24 = (($23) + ($i$014<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($i$014) + 4)|0;
   $27 = (($28) + -1)|0;
   $29 = ($26>>>0)<($27>>>0);
   $30 = $29 ? $26 : $27;
   $31 = (($i$014) + 8)|0;
   $32 = ($31>>>0)<($27>>>0);
   $33 = $32 ? $31 : $27;
   $34 = (($23) + ($30<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 64|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = HEAP32[$19>>2]|0;
   $39 = (($38) + ($30<<2)|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + 64|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 128|0);
   $44 = HEAP32[$19>>2]|0;
   $45 = (($44) + ($33<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = HEAP32[$19>>2]|0;
   $48 = (($47) + ($33<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + 128|0);
   $$sum = (($31) + ($12))|0;
   $51 = (($10) + ($$sum<<5)|0);
   $52 = (($14) + ($$sum<<6)|0);
   $53 = (($i$014) + 32)|0;
   $54 = HEAP32[$19>>2]|0;
   $55 = (($54) + ($53<<2)|0);
   $$sum2 = (($i$014) + ($12))|0;
   $56 = (($25) + 64|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($10) + ($$sum2<<5)|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = (($57) + 64|0);
   HEAPF32[$60>>2] = $59;
   $61 = ((($10) + ($$sum2<<5)|0) + 4|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = (($57) + 68|0);
   HEAPF32[$63>>2] = $62;
   $64 = ((($10) + ($$sum2<<5)|0) + 8|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = (($57) + 72|0);
   HEAPF32[$66>>2] = $65;
   $67 = ((($10) + ($$sum2<<5)|0) + 16|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = (($57) + 80|0);
   HEAPF32[$69>>2] = $68;
   $70 = ((($10) + ($$sum2<<5)|0) + 20|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = (($57) + 84|0);
   HEAPF32[$72>>2] = $71;
   $73 = ((($10) + ($$sum2<<5)|0) + 24|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = (($57) + 88|0);
   HEAPF32[$75>>2] = $74;
   $76 = (($i$014) + 1)|0;
   $$sum3 = (($76) + ($12))|0;
   $77 = ((($14) + ($$sum3<<6)|0) + 40|0);
   HEAP32[$77>>2] = 0;
   $78 = (($25) + 72|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==(1073741823);
   if (!($80)) {
    $83 = (($79) + 32)|0;
    $84 = $83 >>> 5;
    $85 = HEAP32[$20>>2]|0;
    $86 = $85 & 2147483647;
    $87 = ($84>>>0)>($86>>>0);
    if ($87) {
     $88 = $84 << 2;
     $89 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($21,$88,492392,339)|0);
     $90 = HEAP32[$22>>2]|0;
     $91 = ($90|0)==(0|0);
     if (!($91)) {
      $92 = HEAP32[$20>>2]|0;
      $93 = $92 << 2;
      _memcpy(($89|0),($90|0),($93|0))|0;
      $94 = HEAP32[$20>>2]|0;
      $95 = ($94|0)>(-1);
      if ($95) {
       $96 = HEAP32[$22>>2]|0;
       __ZN5physx6shdfnd9Allocator10deallocateEPv($21,$96);
      }
     }
     $97 = HEAP32[$20>>2]|0;
     $98 = $97 & 2147483647;
     $99 = (($89) + ($98<<2)|0);
     $100 = (($84) - ($97))|0;
     $101 = $100 << 2;
     _memset(($99|0),0,($101|0))|0;
     HEAP32[$22>>2] = $89;
     HEAP32[$20>>2] = $84;
     $106 = $89;
    } else {
     $$pre$i = HEAP32[$22>>2]|0;
     $106 = $$pre$i;
    }
    $102 = $79 & 31;
    $103 = 1 << $102;
    $104 = $79 >>> 5;
    $105 = (($106) + ($104<<2)|0);
    $107 = HEAP32[$105>>2]|0;
    $108 = $107 | $103;
    HEAP32[$105>>2] = $108;
   }
   $81 = HEAP32[$16>>2]|0;
   $82 = ($76>>>0)<($81>>>0);
   if ($82) {
    $28 = $81;$i$014 = $76;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$2>>2]|0;
  $110 = $$pre;
 }
 $109 = (($110) + 9344|0);
 $111 = (($110) + 9300|0);
 $112 = HEAP32[$111>>2]|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($109,$112,$1);
 $113 = (($110) + 9356|0);
 $114 = (($110) + 9360|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (($110) + 9348|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = (($117) + ($115))|0;
 $119 = (($118) + 63)|0;
 $120 = $119 & -64;
 $121 = (($110) + 9364|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = $122 & 2147483647;
 $124 = ($123>>>0)<($120>>>0);
 if ($124) {
  __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE8recreateEj($113,$120);
 }
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($113,$118,$0);
 $125 = HEAP32[$113>>2]|0;
 $126 = (($125) + ($115<<4)|0);
 $127 = HEAP32[$109>>2]|0;
 $128 = $117 << 4;
 _memcpy(($126|0),($127|0),($128|0))|0;
 HEAP32[$116>>2] = 0;
 $129 = HEAP32[$2>>2]|0;
 $130 = (($129) + 9208|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ($131|0)==(0);
 if ($132) {
  $$lcssa = $129;
  $235 = (($$lcssa) + 9208|0);
  HEAP32[$235>>2] = 0;
  $236 = HEAP32[$2>>2]|0;
  $237 = (($236) + 328|0);
  $238 = HEAP32[$237>>2]|0;
  $239 = (($236) + 316|0);
  __ZN5physx17PxcNpMemBlockPool23releaseConstraintBlocksERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($238,$239);
  $240 = HEAP32[$7>>2]|0;
  $241 = (($240) + 96|0);
  $242 = HEAP32[$241>>2]|0;
  $243 = HEAP32[$2>>2]|0;
  $244 = (($242) + 224|0);
  $245 = HEAP32[$244>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($245,$243);
  STACKTOP = sp;return;
 } else {
  $134 = $129;$i1$011 = 0;
 }
 while(1) {
  $133 = (($134) + 9204|0);
  $135 = HEAP32[$133>>2]|0;
  $136 = (($135) + ($i1$011<<5)|0);
  $137 = ((($135) + ($i1$011<<5)|0) + 8|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = (($138) + 98|0);
  $140 = HEAP16[$139>>1]|0;
  $141 = $140 & 16;
  $142 = ($141<<16>>16)==(0);
  $$pre24 = (($138) + 28|0);
  if ($142) {
   $$0$i = 0;
  } else {
   $143 = HEAP32[$$pre24>>2]|0;
   $144 = (($138) + 32|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = (($145) + 15)|0;
   $147 = $146 & -16;
   $148 = (($143) + ($147)|0);
   $$0$i = $148;
  }
  $149 = (($138) + 20|0);
  $150 = HEAP16[$149>>1]|0;
  $151 = ((($135) + ($i1$011<<5)|0) + 12|0);
  $152 = HEAP32[$151>>2]|0;
  HEAP32[$$pre24>>2] = $152;
  $153 = ((($135) + ($i1$011<<5)|0) + 16|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = HEAP32[$137>>2]|0;
  $156 = (($155) + 32|0);
  HEAP32[$156>>2] = $154;
  $157 = ((($135) + ($i1$011<<5)|0) + 20|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = $158&65535;
  $160 = (($155) + 20|0);
  HEAP16[$160>>1] = $159;
  $161 = ((($135) + ($i1$011<<5)|0) + 4|0);
  $162 = HEAP16[$161>>1]|0;
  $163 = ($162&65535)>(1);
  if ($163) {
   $174 = $155;$a$04 = 1;
   while(1) {
    $164 = HEAP32[$2>>2]|0;
    $165 = HEAP32[$136>>2]|0;
    $166 = (($165) + ($a$04))|0;
    $167 = (($164) + 9216|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = (($168) + ($166<<2)|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = (($170) + 12|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = (($174) + 40|0);
    $175 = HEAP32[$173>>2]|0;
    $176 = (($172) + 56|0);
    HEAP32[$176>>2] = $175;
    $177 = HEAP32[$137>>2]|0;
    $178 = (($177) + 36|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = (($172) + 52|0);
    HEAP32[$180>>2] = $179;
    $181 = (($a$04) + 1)|0;
    $182 = $162&65535;
    $183 = ($181>>>0)<($182>>>0);
    if ($183) {
     $174 = $177;$a$04 = $181;
    } else {
     break;
    }
   }
  }
  $184 = ($$0$i|0)==(0|0);
  $185 = ($150<<16>>16)==(0);
  $or$cond = $184 | $185;
  if (!($or$cond)) {
   $186 = HEAP32[$136>>2]|0;
   $187 = ((($135) + ($i1$011<<5)|0) + 28|0);
   $188 = $150&65535;
   $$pre20 = HEAP32[$187>>2]|0;
   $a2$08 = 0;$currentContactIndex$05 = 0;$currentManagerContactIndex$07 = 0;$currentManagerIndex$06 = $186;
   while(1) {
    $189 = (($$pre20) + ($a2$08<<1)|0);
    $190 = HEAP16[$189>>1]|0;
    $191 = $190&65535;
    $192 = HEAP32[$2>>2]|0;
    $193 = (($192) + 9216|0);
    $194 = HEAP32[$193>>2]|0;
    $195 = (($194) + ($currentManagerIndex$06<<2)|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = (($196) + 12|0);
    $198 = HEAP32[$197>>2]|0;
    $currentContactIndex$1 = $currentContactIndex$05;$currentManagerContactIndex$1 = $currentManagerContactIndex$07;$currentManagerIndex$1 = $currentManagerIndex$06;$pManager3$0 = $198;
    while(1) {
     $199 = ($currentContactIndex$1>>>0)<($191>>>0);
     if (!($199)) {
      $200 = (($pManager3$0) + 36|0);
      $201 = HEAP16[$200>>1]|0;
      $202 = ($201<<16>>16)==(0);
      if (!($202)) {
       break;
      }
     }
     $203 = (($194) + ($currentManagerIndex$1<<2)|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = (($204) + 12|0);
     $206 = HEAP32[$205>>2]|0;
     $207 = (($191) - ($currentContactIndex$1))|0;
     $208 = (($206) + 36|0);
     $209 = HEAP16[$208>>1]|0;
     $210 = $209&65535;
     $211 = (($210) - ($currentManagerContactIndex$1))|0;
     $212 = ($207>>>0)<($211>>>0);
     $213 = $212 ? $207 : $211;
     $214 = (($213) + ($currentContactIndex$1))|0;
     $215 = (($213) + ($currentManagerContactIndex$1))|0;
     $216 = ($215|0)==($210|0);
     $217 = $216&1;
     $$currentManagerIndex$1 = (($217) + ($currentManagerIndex$1))|0;
     $$ = $216 ? 0 : $215;
     $currentContactIndex$1 = $214;$currentManagerContactIndex$1 = $$;$currentManagerIndex$1 = $$currentManagerIndex$1;$pManager3$0 = $206;
    }
    $218 = (($pManager3$0) + 114|0);
    $219 = HEAP16[$218>>1]|0;
    $220 = $219 & 16;
    $221 = ($220<<16>>16)==(0);
    if (!($221)) {
     $222 = (($$0$i) + ($a2$08<<2)|0);
     $223 = Math_fround(HEAPF32[$222>>2]);
     $224 = (($pManager3$0) + 44|0);
     $225 = HEAP32[$224>>2]|0;
     $226 = (($pManager3$0) + 48|0);
     $227 = HEAP32[$226>>2]|0;
     $228 = (($227) + 15)|0;
     $229 = $228 & -16;
     $230 = (($225) + ($229)|0);
     $231 = (($230) + ($currentManagerContactIndex$1<<2)|0);
     HEAPF32[$231>>2] = $223;
    }
    $232 = (($a2$08) + 1)|0;
    $exitcond = ($232|0)==($188|0);
    if ($exitcond) {
     break;
    } else {
     $a2$08 = $232;$currentContactIndex$05 = $currentContactIndex$1;$currentManagerContactIndex$07 = $currentManagerContactIndex$1;$currentManagerIndex$06 = $currentManagerIndex$1;
    }
   }
  }
  $233 = (($i1$011) + 1)|0;
  $234 = HEAP32[$2>>2]|0;
  $exitcond19 = ($233|0)==($131|0);
  if ($exitcond19) {
   $$lcssa = $234;
   break;
  } else {
   $134 = $234;$i1$011 = $233;
  }
 }
 $235 = (($$lcssa) + 9208|0);
 HEAP32[$235>>2] = 0;
 $236 = HEAP32[$2>>2]|0;
 $237 = (($236) + 328|0);
 $238 = HEAP32[$237>>2]|0;
 $239 = (($236) + 316|0);
 __ZN5physx17PxcNpMemBlockPool23releaseConstraintBlocksERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($238,$239);
 $240 = HEAP32[$7>>2]|0;
 $241 = (($240) + 96|0);
 $242 = HEAP32[$241>>2]|0;
 $243 = HEAP32[$2>>2]|0;
 $244 = (($242) + 224|0);
 $245 = HEAP32[$244>>2]|0;
 __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($245,$243);
 STACKTOP = sp;return;
}
function __ZN5physx18PxsSolverStartTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18PxsSolverStartTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx18PxsSolverStartTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (493768|0);
}
function __ZN5physx18PxsSolverStartTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx18PxsSolverStartTask10startTasksEv($this);
 __ZN5physx18PxsSolverStartTask16articulationTaskEv($this);
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5<<5)|0);
 $7 = (($1) + 112|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($5<<6)|0);
 $10 = (($1) + 96|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 6736|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $13;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$15>>2]|0;
 $23 = (($22) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_viiii[$24 & 511]($15,94,$18,$21);
 $25 = HEAP32[$0>>2]|0;
 $26 = (($25) + 124|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($this) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 9108|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 28|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 48|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($29) + 9120|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($29) + 9132|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($29) + 9292|0);
 $41 = (($29) + 9296|0);
 $42 = (($this) + 12|0);
 $43 = HEAP32[$42>>2]|0;
 __ZN5physx18PxsDynamicsContext23atomIntegrationParallelEfPKPNS_11PxsBodyCoreEPKPNS_12PxsRigidBodyEjPKNS_2Cm13SpatialVectorEPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEPSA_RjSI_RNS_10PxBaseTaskE($25,$27,$31,$33,$35,$37,$6,$9,$39,$40,$41,$43);
 $44 = HEAP32[$15>>2]|0;
 $45 = (($44) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_viiii[$46 & 511]($15,94,$18,$21);
 __ZN5physx18PxsSolverStartTask13setupDescTaskEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx18PxsSolverStartTask10startTasksEv($this) {
 $this = $this|0;
 var $$$pre12 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre12 = 0, $$sum = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0);
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$06 = 0, $i1$05 = 0, $inEnabled$not$i$i$i1 = 0;
 var $numArticulationConstraints$0$lcssa = 0, $numArticulationConstraints$07 = 0, $or$cond$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 6736|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAPU16[545656>>1]|(HEAPU16[545656+2>>1]<<16);
 $15 = $14 & 16711680;
 $inEnabled$not$i$i$i1 = ($15|0)==(0);
 $16 = ($7|0)==(0|0);
 $or$cond$i$i$i2 = $16 | $inEnabled$not$i$i$i1;
 if (!($or$cond$i$i$i2)) {
  $17 = $14&65535;
  $18 = HEAP32[$7>>2]|0;
  $19 = (($18) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiii[$20 & 511]($7,$17,$10,$13);
 }
 $21 = (($this) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 9292|0);
 HEAP32[$23>>2] = 0;
 $24 = HEAP32[$21>>2]|0;
 $25 = (($24) + 9296|0);
 HEAP32[$25>>2] = 0;
 $26 = HEAP32[$21>>2]|0;
 $27 = (($26) + 9268|0);
 HEAP32[$27>>2] = 0;
 $28 = HEAP32[$21>>2]|0;
 $29 = (($28) + 9144|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 9308|0);
 HEAP32[$31>>2] = $30;
 $32 = HEAP32[$21>>2]|0;
 $33 = (($32) + 9156|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 9316|0);
 HEAP32[$35>>2] = $34;
 $36 = HEAP32[$21>>2]|0;
 $37 = (($36) + 8952|0);
 HEAP32[$37>>2] = 0;
 $38 = HEAP32[$21>>2]|0;
 $39 = (($38) + 9100|0);
 HEAP32[$39>>2] = 0;
 $40 = HEAP32[$21>>2]|0;
 $41 = (($40) + 9092|0);
 HEAP32[$41>>2] = 0;
 $42 = HEAP32[$21>>2]|0;
 $43 = (($42) + 8956|0);
 HEAP32[$43>>2] = 0;
 $44 = HEAP32[$21>>2]|0;
 $45 = (($44) + 9104|0);
 HEAP32[$45>>2] = 0;
 $46 = HEAP32[$21>>2]|0;
 $47 = (($46) + 9096|0);
 HEAP32[$47>>2] = 0;
 $48 = HEAP32[$0>>2]|0;
 $49 = (($48) + 96|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 6736|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $52;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$54>>2]|0;
 $62 = (($61) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_viiii[$63 & 511]($54,83,$57,$60);
 $64 = (($this) + 52|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = $65 & 2147483647;
 $67 = ($66|0)==(0);
 if ($67) {
  $numArticulationConstraints$0$lcssa = 0;
 } else {
  $68 = (($this) + 32|0);
  $69 = HEAP32[$68>>2]|0;
  $i$06 = 0;$numArticulationConstraints$07 = 0;
  while(1) {
   $70 = (($69) + ($i$06<<2)|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = HEAP32[$71>>2]|0;
   $73 = (($72) + 36|0);
   $74 = HEAP16[$73>>1]|0;
   $75 = $74&65535;
   $76 = (($75) + ($numArticulationConstraints$07))|0;
   $77 = (($i$06) + 1)|0;
   $78 = ($77>>>0)<($66>>>0);
   if ($78) {
    $i$06 = $77;$numArticulationConstraints$07 = $76;
   } else {
    $numArticulationConstraints$0$lcssa = $76;
    break;
   }
  }
 }
 $79 = HEAP32[$21>>2]|0;
 $80 = (($79) + 8776|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ($81|0)==(0);
 $$phi$trans$insert = (($this) + 56|0);
 $$pre12 = HEAP32[$$phi$trans$insert>>2]|0;
 $$$pre12 = $82 ? 0 : $$pre12;
 $83 = (($this) + 48|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($this) + 60|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($$pre12) + ($numArticulationConstraints$0$lcssa))|0;
 $88 = (($87) + ($86))|0;
 __ZN5physx16PxsThreadContext12resizeArraysEjjjjj($79,$84,$$pre12,$88,$$$pre12,$66);
 $89 = HEAP32[$21>>2]|0;
 $90 = (($89) + 9108|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (($89) + 9120|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = HEAP32[$83>>2]|0;
 $95 = ($94|0)==(0);
 if (!($95)) {
  $96 = (($this) + 28|0);
  $$pre = HEAP32[$96>>2]|0;
  $103 = $$pre;$99 = $94;$i1$05 = 0;
  while(1) {
   $97 = (($i1$05) + 8)|0;
   $98 = (($99) + -1)|0;
   $100 = ($97>>>0)<($98>>>0);
   $101 = $100 ? $97 : $98;
   $102 = (($103) + ($101<<2)|0);
   $104 = HEAP32[$102>>2]|0;
   $105 = HEAP32[$96>>2]|0;
   $106 = (($105) + ($101<<2)|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($107) + 128|0);
   $$sum = (($i1$05) + 4)|0;
   $109 = (($93) + ($$sum<<5)|0);
   $110 = (($91) + ($i1$05<<2)|0);
   $$sum3 = (($i1$05) + 32)|0;
   $111 = (($91) + ($$sum3<<2)|0);
   $112 = HEAP32[$96>>2]|0;
   $113 = (($112) + ($$sum3<<2)|0);
   $114 = HEAP32[$96>>2]|0;
   $115 = (($114) + ($i1$05<<2)|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (($116) + 64|0);
   $118 = HEAP32[$117>>2]|0;
   HEAP32[$110>>2] = $118;
   $119 = HEAP32[$96>>2]|0;
   $120 = (($119) + ($i1$05<<2)|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = (($93) + ($i1$05<<5)|0);
   HEAPF32[$123>>2] = $122;
   $124 = (($121) + 4|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = ((($93) + ($i1$05<<5)|0) + 4|0);
   HEAPF32[$126>>2] = $125;
   $127 = (($121) + 8|0);
   $128 = Math_fround(HEAPF32[$127>>2]);
   $129 = ((($93) + ($i1$05<<5)|0) + 8|0);
   HEAPF32[$129>>2] = $128;
   $130 = ((($93) + ($i1$05<<5)|0) + 12|0);
   HEAPF32[$130>>2] = Math_fround(0.0);
   $131 = (($121) + 16|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = ((($93) + ($i1$05<<5)|0) + 16|0);
   HEAPF32[$133>>2] = $132;
   $134 = (($121) + 20|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = ((($93) + ($i1$05<<5)|0) + 20|0);
   HEAPF32[$136>>2] = $135;
   $137 = (($121) + 24|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   $139 = ((($93) + ($i1$05<<5)|0) + 24|0);
   HEAPF32[$139>>2] = $138;
   $140 = ((($93) + ($i1$05<<5)|0) + 28|0);
   HEAPF32[$140>>2] = Math_fround(0.0);
   $141 = (($i1$05) + 1)|0;
   $142 = HEAP32[$83>>2]|0;
   $143 = ($141>>>0)<($142>>>0);
   if ($143) {
    $103 = $119;$99 = $142;$i1$05 = $141;
   } else {
    break;
   }
  }
 }
 $144 = HEAP32[$54>>2]|0;
 $145 = (($144) + 12|0);
 $146 = HEAP32[$145>>2]|0;
 FUNCTION_TABLE_viiii[$146 & 511]($54,83,$57,$60);
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return;
 }
 $147 = HEAP32[$7>>2]|0;
 $148 = (($147) + 12|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = $14&65535;
 FUNCTION_TABLE_viiii[$149 & 511]($7,$150,$10,$13);
 STACKTOP = sp;return;
}
function __ZN5physx18PxsSolverStartTask16articulationTaskEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $acCount = 0, $i$01 = 0, $maxArticulationLength$0$lcssa = 0, $maxArticulationLength$02 = 0, $maxPosIters$0$lcssa = 0, $maxPosIters$03 = 0, $maxVelIters$0$lcssa = 0, $maxVelIters$04 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $acCount = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 9368|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 336|0);
 HEAP32[$4>>2] = 0;
 $5 = (($1) + 340|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8|0)==(0);
 if ($9) {
  $maxArticulationLength$0$lcssa = 0;$maxPosIters$0$lcssa = 0;$maxVelIters$0$lcssa = 0;
  $62 = HEAP32[$0>>2]|0;
  $63 = (($62) + 9292|0);
  (__ZN5physx6shdfnd9atomicMaxEPVii($63,$maxPosIters$0$lcssa)|0);
  $64 = HEAP32[$0>>2]|0;
  $65 = (($64) + 9296|0);
  (__ZN5physx6shdfnd9atomicMaxEPVii($65,$maxVelIters$0$lcssa)|0);
  $66 = HEAP32[$0>>2]|0;
  $67 = (($66) + 9304|0);
  HEAP32[$67>>2] = $maxArticulationLength$0$lcssa;
  STACKTOP = sp;return;
 }
 $10 = (($this) + 32|0);
 $11 = (($this) + 20|0);
 $i$01 = 0;$maxArticulationLength$02 = 0;$maxPosIters$03 = 0;$maxVelIters$04 = 0;
 while(1) {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + ($i$01<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($3) + (($i$01*40)|0)|0);
  $16 = HEAP32[$14>>2]|0;
  dest=$15+0|0; src=$16+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $17 = HEAP32[$11>>2]|0;
  $18 = HEAP32[$0>>2]|0;
  $19 = HEAP32[503512>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $$0$i = 0;$33 = $18;
  } else {
   $21 = (($17) + 96|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 6736|0);
   $24 = (($18) + 9308|0);
   $25 = (($17) + 124|0);
   $26 = (($18) + 316|0);
   $27 = HEAP32[$23>>2]|0;
   $28 = HEAP32[$24>>2]|0;
   $29 = (($18) + 332|0);
   $30 = Math_fround(HEAPF32[$25>>2]);
   $31 = (__ZN5physx21PxcArticulationHelper30computeUnconstrainedVelocitiesERKNS_25PxcArticulationSolverDescEfRNS_24PxcConstraintBlockStreamEPNS_23PxcSolverConstraintDescERjRNS_2Cm13EventProfilerERNS_25PxsConstraintBlockManagerE($15,$30,$29,$28,$acCount,$27,$26)|0);
   $$pre = HEAP32[$0>>2]|0;
   $$0$i = $31;$33 = $$pre;
  }
  $32 = (($33) + 9308|0);
  $34 = HEAP32[$32>>2]|0;
  $35 = (($34) + ($$0$i<<5)|0);
  HEAP32[$32>>2] = $35;
  $36 = HEAP32[$acCount>>2]|0;
  $37 = HEAP32[$0>>2]|0;
  $38 = (($37) + 9268|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + ($36))|0;
  HEAP32[$38>>2] = $40;
  $41 = ((($3) + (($i$01*40)|0)|0) + 32|0);
  $42 = HEAP16[$41>>1]|0;
  $43 = $42&65535;
  $44 = ($maxArticulationLength$02>>>0)<($43>>>0);
  $45 = $44 ? $43 : $maxArticulationLength$02;
  $46 = HEAP32[$14>>2]|0;
  $47 = (($46) + 24|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 12|0);
  $50 = HEAP16[$49>>1]|0;
  $51 = $50&65535;
  $52 = $51 >>> 8;
  $53 = ($52>>>0)<($maxVelIters$04>>>0);
  $54 = $53 ? $maxVelIters$04 : $52;
  $55 = $51 & 255;
  $56 = ($55>>>0)<($maxPosIters$03>>>0);
  $57 = $56 ? $maxPosIters$03 : $55;
  $58 = (($i$01) + 1)|0;
  $59 = HEAP32[$6>>2]|0;
  $60 = $59 & 2147483647;
  $61 = ($58>>>0)<($60>>>0);
  if ($61) {
   $i$01 = $58;$maxArticulationLength$02 = $45;$maxPosIters$03 = $57;$maxVelIters$04 = $54;
  } else {
   $maxArticulationLength$0$lcssa = $45;$maxPosIters$0$lcssa = $57;$maxVelIters$0$lcssa = $54;
   break;
  }
 }
 $62 = HEAP32[$0>>2]|0;
 $63 = (($62) + 9292|0);
 (__ZN5physx6shdfnd9atomicMaxEPVii($63,$maxPosIters$0$lcssa)|0);
 $64 = HEAP32[$0>>2]|0;
 $65 = (($64) + 9296|0);
 (__ZN5physx6shdfnd9atomicMaxEPVii($65,$maxVelIters$0$lcssa)|0);
 $66 = HEAP32[$0>>2]|0;
 $67 = (($66) + 9304|0);
 HEAP32[$67>>2] = $maxArticulationLength$0$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx18PxsSolverStartTask13setupDescTaskEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$0$i2 = 0, $$lcssa = 0, $$lcssa18 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $$pre75 = 0, $$pre76 = 0, $$pre77 = 0;
 var $$pre78 = 0, $$pre83 = 0, $$pre84 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$046 = 0, $a1$041 = 0, $a11$019 = 0, $a14$06 = 0, $a2$037 = 0, $a20$04 = 0, $a5$031 = 0, $a8$025 = 0, $accumulatedCount$0$lcssa = 0, $accumulatedCount$042 = 0, $accumulatedCount$138 = 0, $accumulatedCount$2 = 0;
 var $accumulatedCount$3$lcssa = 0, $accumulatedCount$326 = 0, $accumulatedCount$421 = 0, $accumulatedCount$5 = 0, $contactCount$0$lcssa = 0, $contactCount$09 = 0, $contactCount$1 = 0, $contactDescPtr$0$lcssa = 0, $contactDescPtr$051 = 0, $contactDescPtr$1$lcssa = 0, $contactDescPtr$111 = 0, $contactDescPtr$3 = 0, $contactDescPtr$4 = 0, $contactDescPtr$5 = 0, $i$050 = 0, $numHeaders$0$lcssa = 0, $numHeaders$05 = 0, $numHeaders$3 = 0, $numHeaders$4 = 0, $numHeaders$5 = 0;
 var $offsetMap = 0, $startDesc$010 = 0, $startDesc$2 = 0, $startIndex$0$lcssa = 0, $startIndex$08 = 0, $startIndex$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 41|0;
 $1 = sp + 40|0;
 $offsetMap = sp;
 $2 = sp + 8|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 9308|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 48|0);
 $8 = (($this) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $27 = $6;$contactDescPtr$0$lcssa = $6;
 } else {
  $11 = (($this) + 20|0);
  $12 = (($this) + 44|0);
  $contactDescPtr$051 = $6;$i$050 = 0;
  while(1) {
   $13 = HEAP32[$11>>2]|0;
   $14 = HEAP32[$12>>2]|0;
   $15 = (($14) + ($i$050<<4)|0);
   __ZN5physx18PxsDynamicsContext18setDescFromIndicesERNS_23PxcSolverConstraintDescERKNS_21PxsIndexedInteractionE($13,$contactDescPtr$051,$15);
   $16 = HEAP32[$12>>2]|0;
   $17 = ((($16) + ($i$050<<4)|0) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($contactDescPtr$051) + 16|0);
   HEAP32[$19>>2] = $18;
   $20 = (($contactDescPtr$051) + 26|0);
   HEAP16[$20>>1] = 2;
   $21 = (($contactDescPtr$051) + 32|0);
   $22 = (($i$050) + 1)|0;
   $23 = HEAP32[$8>>2]|0;
   $24 = ($22>>>0)<($23>>>0);
   if ($24) {
    $contactDescPtr$051 = $21;$i$050 = $22;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$3>>2]|0;
  $$phi$trans$insert = (($$pre) + 9308|0);
  $$pre64 = HEAP32[$$phi$trans$insert>>2]|0;
  $27 = $$pre64;$contactDescPtr$0$lcssa = $21;
 }
 $25 = $contactDescPtr$0$lcssa;
 $26 = $27;
 $28 = (($25) - ($26))|0;
 $29 = $28 >> 5;
 __ZN5physx6shdfnd4sortINS_23PxcSolverConstraintDescENS_14ConstraintLessENS0_19ReflectionAllocatorIS2_EEEEvPT_jRKT0_RKT1_($27,$29,$1,$0);
 $30 = HEAP32[$3>>2]|0;
 $31 = (($30) + 9220|0);
 HEAP32[$31>>2] = 0;
 $32 = HEAP32[$3>>2]|0;
 $33 = (($this) + 56|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 9224|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37>>>0)<($34>>>0);
 if ($38) {
  $39 = (($32) + 9216|0);
  __ZN5physx6shdfnd5ArrayIPKNS_24PxsIndexedContactManagerENS0_19ReflectionAllocatorIS4_EEE8recreateEj($39,$34);
  $$pre65 = HEAP32[$3>>2]|0;
  $$pre66 = HEAP32[$33>>2]|0;
  $41 = $$pre65;$42 = $$pre66;
 } else {
  $41 = $32;$42 = $34;
 }
 $40 = (($41) + 9220|0);
 HEAP32[$40>>2] = $42;
 $43 = HEAP32[$3>>2]|0;
 $44 = (($43) + 9232|0);
 HEAP32[$44>>2] = 0;
 $45 = HEAP32[$3>>2]|0;
 $46 = HEAP32[$33>>2]|0;
 $47 = (($45) + 9236|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 & 2147483647;
 $50 = ($49>>>0)<($46>>>0);
 if ($50) {
  $51 = (($45) + 9228|0);
  __ZN5physx6shdfnd5ArrayIPKNS_24PxsIndexedContactManagerENS0_19ReflectionAllocatorIS4_EEE8recreateEj($51,$46);
  $$pre67 = HEAP32[$3>>2]|0;
  $$pre68 = HEAP32[$33>>2]|0;
  $53 = $$pre67;$54 = $$pre68;
 } else {
  $53 = $45;$54 = $46;
 }
 $52 = (($53) + 9232|0);
 HEAP32[$52>>2] = $54;
 $55 = HEAP32[$3>>2]|0;
 $56 = (($55) + 9216|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 9208|0);
 HEAP32[$58>>2] = 0;
 $59 = HEAP32[$33>>2]|0;
 $60 = ($59|0)==(0);
 if ($60) {
  $contactDescPtr$5 = $contactDescPtr$0$lcssa;
  $402 = HEAP32[$3>>2]|0;
  $403 = (($402) + 9144|0);
  $404 = HEAP32[$403>>2]|0;
  $405 = $contactDescPtr$5;
  $406 = $404;
  $407 = (($405) - ($406))|0;
  $408 = $407 >> 5;
  $409 = (($402) + 9148|0);
  HEAP32[$409>>2] = $408;
  $410 = HEAP32[$3>>2]|0;
  $411 = (($410) + 9144|0);
  $412 = HEAP32[$411>>2]|0;
  $413 = $412;
  $414 = (($405) - ($413))|0;
  $415 = $414 >> 5;
  $416 = (($410) + 9172|0);
  HEAP32[$416>>2] = $415;
  STACKTOP = sp;return;
 }
 $61 = HEAP32[$3>>2]|0;
 $62 = (($61) + 9244|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 20|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 152|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 << 1;
 $68 = (($this) + 64|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (1 - ($69))|0;
 $71 = (($70) + ($67))|0;
 HEAP32[$offsetMap>>2] = $71;
 $72 = (($offsetMap) + 4|0);
 HEAP32[$72>>2] = 1;
 $73 = HEAP32[$7>>2]|0;
 $74 = (($66) + 1)|0;
 $75 = (($74) + ($73))|0;
 $76 = HEAP32[$3>>2]|0;
 $77 = (($76) + 9248|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = $78 & 2147483647;
 $80 = ($79>>>0)<($75>>>0);
 if ($80) {
  $81 = (($76) + 9240|0);
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($81,$75);
  $$pre69 = HEAP32[$3>>2]|0;
  $83 = $$pre69;
 } else {
  $83 = $76;
 }
 $82 = (($83) + 9244|0);
 HEAP32[$82>>2] = $75;
 $84 = HEAP32[$3>>2]|0;
 $85 = (($84) + 9240|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = $75 << 2;
 _memset(($86|0),0,($87|0))|0;
 $88 = HEAP32[$33>>2]|0;
 $89 = ($88|0)==(0);
 if ($89) {
  $417 = 0;
 } else {
  $90 = (($this) + 40|0);
  $$pre77 = HEAP32[$90>>2]|0;
  $418 = $88;$a$046 = 0;
  while(1) {
   $91 = ((($$pre77) + ($a$046<<4)|0) + 8|0);
   $92 = HEAP8[$91>>0]|0;
   $93 = ($92<<24>>24)==(2);
   if ($93) {
    $108 = $418;
   } else {
    $94 = $92&255;
    $95 = (($$pre77) + ($a$046<<4)|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($offsetMap) + ($94<<2)|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (($98) + ($96))|0;
    $100 = HEAP32[$3>>2]|0;
    $101 = (($100) + 9240|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (($102) + ($99<<2)|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($104) + 1)|0;
    HEAP32[$103>>2] = $105;
    $$pre78 = HEAP32[$33>>2]|0;
    $108 = $$pre78;
   }
   $106 = (($a$046) + 1)|0;
   $107 = ($106>>>0)<($108>>>0);
   if ($107) {
    $418 = $108;$a$046 = $106;
   } else {
    $417 = $108;
    break;
   }
  }
 }
 $109 = HEAP32[$3>>2]|0;
 $110 = (($109) + 9244|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = ($111|0)==(0);
 if ($112) {
  $114 = $417;$accumulatedCount$0$lcssa = 0;
 } else {
  $118 = $109;$a1$041 = $111;$accumulatedCount$042 = 0;
  while(1) {
   $116 = (($a1$041) + -1)|0;
   $117 = (($118) + 9240|0);
   $119 = HEAP32[$117>>2]|0;
   $120 = (($119) + ($116<<2)|0);
   $121 = HEAP32[$120>>2]|0;
   HEAP32[$120>>2] = $accumulatedCount$042;
   $122 = (($121) + ($accumulatedCount$042))|0;
   $123 = ($116|0)==(0);
   if ($123) {
    break;
   }
   $$pre84 = HEAP32[$3>>2]|0;
   $118 = $$pre84;$a1$041 = $116;$accumulatedCount$042 = $122;
  }
  $$pre70 = HEAP32[$33>>2]|0;
  $114 = $$pre70;$accumulatedCount$0$lcssa = $122;
 }
 $113 = ($114|0)==(0);
 if (!($113)) {
  $115 = (($this) + 40|0);
  $419 = $114;$a2$037 = 0;$accumulatedCount$138 = $accumulatedCount$0$lcssa;
  while(1) {
   $124 = HEAP32[$115>>2]|0;
   $125 = (($124) + ($a2$037<<4)|0);
   $126 = ((($124) + ($a2$037<<4)|0) + 8|0);
   $127 = HEAP8[$126>>0]|0;
   $128 = ($127<<24>>24)==(2);
   if ($128) {
    $143 = HEAP32[$3>>2]|0;
    $144 = (($accumulatedCount$138) + 1)|0;
    $145 = (($143) + 9228|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = (($146) + ($accumulatedCount$138<<2)|0);
    HEAP32[$147>>2] = $125;
    $150 = $419;$accumulatedCount$2 = $144;
   } else {
    $129 = $127&255;
    $130 = HEAP32[$125>>2]|0;
    $131 = (($offsetMap) + ($129<<2)|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = (($132) + ($130))|0;
    $134 = HEAP32[$3>>2]|0;
    $135 = (($134) + 9240|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($136) + ($133<<2)|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = (($138) + 1)|0;
    HEAP32[$137>>2] = $139;
    $140 = (($134) + 9228|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (($141) + ($138<<2)|0);
    HEAP32[$142>>2] = $125;
    $$pre76 = HEAP32[$33>>2]|0;
    $150 = $$pre76;$accumulatedCount$2 = $accumulatedCount$138;
   }
   $148 = (($a2$037) + 1)|0;
   $149 = ($148>>>0)<($150>>>0);
   if ($149) {
    $419 = $150;$a2$037 = $148;$accumulatedCount$138 = $accumulatedCount$2;
   } else {
    break;
   }
  }
 }
 $151 = HEAP32[$3>>2]|0;
 $152 = (($151) + 9240|0);
 $153 = HEAP32[$152>>2]|0;
 _memset(($153|0),0,($87|0))|0;
 $154 = HEAP32[$33>>2]|0;
 $155 = ($154|0)==(0);
 $156 = HEAP32[$3>>2]|0;
 if ($155) {
  $180 = $156;$420 = 0;
 } else {
  $158 = $156;$421 = $154;$a5$031 = 0;
  while(1) {
   $157 = (($158) + 9228|0);
   $159 = HEAP32[$157>>2]|0;
   $160 = (($159) + ($a5$031<<2)|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = (($161) + 9|0);
   $163 = HEAP8[$162>>0]|0;
   if ((($163<<24>>24) == 2)) {
    $178 = $421;$422 = $158;
   } else if ((($163<<24>>24) == 3)) {
    $173 = 0;
    label = 30;
   } else {
    $164 = $163&255;
    $165 = (($161) + 4|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = (($offsetMap) + ($164<<2)|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = (($168) + ($166))|0;
    $173 = $169;
    label = 30;
   }
   if ((label|0) == 30) {
    label = 0;
    $170 = (($158) + 9240|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = (($171) + ($173<<2)|0);
    $174 = HEAP32[$172>>2]|0;
    $175 = (($174) + 1)|0;
    HEAP32[$172>>2] = $175;
    $$pre74 = HEAP32[$33>>2]|0;
    $$pre75 = HEAP32[$3>>2]|0;
    $178 = $$pre74;$422 = $$pre75;
   }
   $176 = (($a5$031) + 1)|0;
   $177 = ($176>>>0)<($178>>>0);
   if ($177) {
    $158 = $422;$421 = $178;$a5$031 = $176;
   } else {
    $180 = $422;$420 = $178;
    break;
   }
  }
 }
 $179 = (($180) + 9244|0);
 $181 = HEAP32[$179>>2]|0;
 $182 = ($181|0)==(0);
 if ($182) {
  $184 = $420;$423 = $180;$accumulatedCount$3$lcssa = 0;
 } else {
  $187 = $180;$a8$025 = $181;$accumulatedCount$326 = 0;
  while(1) {
   $185 = (($a8$025) + -1)|0;
   $186 = (($187) + 9240|0);
   $188 = HEAP32[$186>>2]|0;
   $189 = (($188) + ($185<<2)|0);
   $190 = HEAP32[$189>>2]|0;
   HEAP32[$189>>2] = $accumulatedCount$326;
   $191 = (($190) + ($accumulatedCount$326))|0;
   $192 = ($185|0)==(0);
   if ($192) {
    break;
   }
   $$pre83 = HEAP32[$3>>2]|0;
   $187 = $$pre83;$a8$025 = $185;$accumulatedCount$326 = $191;
  }
  $$pre71 = HEAP32[$33>>2]|0;
  $$pre72 = HEAP32[$3>>2]|0;
  $184 = $$pre71;$423 = $$pre72;$accumulatedCount$3$lcssa = $191;
 }
 $183 = ($184|0)==(0);
 if ($183) {
  $$lcssa18 = $423;$222 = 0;
 } else {
  $194 = $423;$424 = $184;$a11$019 = 0;$accumulatedCount$421 = $accumulatedCount$3$lcssa;
  while(1) {
   $193 = (($194) + 9228|0);
   $195 = HEAP32[$193>>2]|0;
   $196 = (($195) + ($a11$019<<2)|0);
   $197 = HEAP32[$196>>2]|0;
   $198 = (($197) + 9|0);
   $199 = HEAP8[$198>>0]|0;
   if ((($199<<24>>24) == 3)) {
    $209 = 0;
    label = 39;
   } else if ((($199<<24>>24) == 2)) {
    $213 = (($accumulatedCount$421) + 1)|0;
    $214 = (($57) + ($accumulatedCount$421<<2)|0);
    HEAP32[$214>>2] = $197;
    $217 = $424;$accumulatedCount$5 = $213;
   } else {
    $200 = $199&255;
    $201 = (($197) + 4|0);
    $202 = HEAP32[$201>>2]|0;
    $203 = (($offsetMap) + ($200<<2)|0);
    $204 = HEAP32[$203>>2]|0;
    $205 = (($204) + ($202))|0;
    $209 = $205;
    label = 39;
   }
   if ((label|0) == 39) {
    label = 0;
    $206 = (($194) + 9240|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = (($207) + ($209<<2)|0);
    $210 = HEAP32[$208>>2]|0;
    $211 = (($210) + 1)|0;
    HEAP32[$208>>2] = $211;
    $212 = (($57) + ($210<<2)|0);
    HEAP32[$212>>2] = $197;
    $$pre73 = HEAP32[$33>>2]|0;
    $217 = $$pre73;$accumulatedCount$5 = $accumulatedCount$421;
   }
   $215 = (($a11$019) + 1)|0;
   $216 = ($215>>>0)<($217>>>0);
   $218 = HEAP32[$3>>2]|0;
   if ($216) {
    $194 = $218;$424 = $217;$a11$019 = $215;$accumulatedCount$421 = $accumulatedCount$5;
   } else {
    $$lcssa18 = $218;$222 = $217;
    break;
   }
  }
 }
 $219 = (($$lcssa18) + 9312|0);
 HEAP32[$219>>2] = $contactDescPtr$0$lcssa;
 $220 = HEAP32[$3>>2]|0;
 $221 = (($220) + 9204|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_25PxsCompoundContactManagerENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($221,$222,$2);
 $223 = HEAP32[$3>>2]|0;
 $224 = HEAP32[$33>>2]|0;
 $225 = (($223) + 9208|0);
 HEAP32[$225>>2] = $224;
 $226 = HEAP32[$63>>2]|0;
 $227 = HEAP32[$57>>2]|0;
 __ZN5physx18PxsDynamicsContext18setDescFromIndicesERNS_23PxcSolverConstraintDescERKNS_21PxsIndexedInteractionE($226,$contactDescPtr$0$lcssa,$227);
 $228 = HEAP32[$57>>2]|0;
 $229 = (($228) + 12|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = (($contactDescPtr$0$lcssa) + 16|0);
 HEAP32[$231>>2] = $230;
 $232 = (($contactDescPtr$0$lcssa) + 26|0);
 HEAP16[$232>>1] = 1;
 $233 = HEAP32[$57>>2]|0;
 $234 = (($233) + 12|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = (($235) + 36|0);
 $237 = HEAP16[$236>>1]|0;
 $238 = $237&65535;
 $239 = HEAP32[$33>>2]|0;
 $240 = ($239>>>0)>(1);
 if ($240) {
  $a14$06 = 1;$contactCount$09 = $238;$contactDescPtr$111 = $contactDescPtr$0$lcssa;$numHeaders$05 = 0;$startDesc$010 = $contactDescPtr$0$lcssa;$startIndex$08 = 0;
  while(1) {
   $241 = (($contactDescPtr$111) + 32|0);
   $242 = HEAP32[$63>>2]|0;
   $243 = (($57) + ($a14$06<<2)|0);
   $244 = HEAP32[$243>>2]|0;
   __ZN5physx18PxsDynamicsContext18setDescFromIndicesERNS_23PxcSolverConstraintDescERKNS_21PxsIndexedInteractionE($242,$241,$244);
   $245 = HEAP32[$243>>2]|0;
   $246 = (($245) + 12|0);
   $247 = HEAP32[$246>>2]|0;
   $248 = (($contactDescPtr$111) + 48|0);
   HEAP32[$248>>2] = $247;
   $249 = (($contactDescPtr$111) + 58|0);
   HEAP16[$249>>1] = 1;
   $250 = HEAP32[$startDesc$010>>2]|0;
   $251 = HEAP32[$241>>2]|0;
   $252 = ($250|0)==($251|0);
   if ($252) {
    $253 = (($startDesc$010) + 4|0);
    $254 = HEAP32[$253>>2]|0;
    $255 = (($contactDescPtr$111) + 36|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = ($254|0)==($256|0);
    if ($257) {
     $258 = (($startDesc$010) + 8|0);
     $259 = HEAP16[$258>>1]|0;
     $260 = ($259<<16>>16)==(-1);
     if ($260) {
      $261 = (($startDesc$010) + 12|0);
      $262 = HEAP16[$261>>1]|0;
      $263 = ($262<<16>>16)==(-1);
      if ($263) {
       $264 = (($247) + 36|0);
       $265 = HEAP16[$264>>1]|0;
       $266 = $265&65535;
       $267 = (($266) + ($contactCount$09))|0;
       $268 = ($267>>>0)>(64);
       if ($268) {
        label = 48;
       } else {
        $contactCount$1 = $contactCount$09;$contactDescPtr$3 = $contactDescPtr$111;$numHeaders$3 = $numHeaders$05;$startDesc$2 = $startDesc$010;$startIndex$1 = $startIndex$08;
       }
      } else {
       label = 48;
      }
     } else {
      label = 48;
     }
    } else {
     label = 48;
    }
   } else {
    label = 48;
   }
   do {
    if ((label|0) == 48) {
     label = 0;
     $269 = (($a14$06) - ($startIndex$08))|0;
     $270 = ($contactCount$09|0)==(0);
     if ($270) {
      ;HEAP32[$startDesc$010+0>>2]=HEAP32[$241+0>>2]|0;HEAP32[$startDesc$010+4>>2]=HEAP32[$241+4>>2]|0;HEAP32[$startDesc$010+8>>2]=HEAP32[$241+8>>2]|0;HEAP32[$startDesc$010+12>>2]=HEAP32[$241+12>>2]|0;HEAP32[$startDesc$010+16>>2]=HEAP32[$241+16>>2]|0;HEAP32[$startDesc$010+20>>2]=HEAP32[$241+20>>2]|0;HEAP32[$startDesc$010+24>>2]=HEAP32[$241+24>>2]|0;HEAP32[$startDesc$010+28>>2]=HEAP32[$241+28>>2]|0;
      $contactCount$1 = 0;$contactDescPtr$3 = $contactDescPtr$111;$numHeaders$3 = $numHeaders$05;$startDesc$2 = $startDesc$010;$startIndex$1 = $a14$06;
      break;
     }
     $271 = ($269>>>0)>(1);
     if ($271) {
      $272 = HEAP32[$3>>2]|0;
      $273 = (($numHeaders$05) + 1)|0;
      $274 = (($272) + 9204|0);
      $275 = HEAP32[$274>>2]|0;
      $276 = (($275) + ($numHeaders$05<<5)|0);
      HEAP32[$276>>2] = $startIndex$08;
      $277 = $269&65535;
      $278 = ((($275) + ($numHeaders$05<<5)|0) + 4|0);
      HEAP16[$278>>1] = $277;
      $279 = $contactCount$09&65535;
      $280 = ((($275) + ($numHeaders$05<<5)|0) + 6|0);
      HEAP16[$280>>1] = $279;
      $281 = (($57) + ($startIndex$08<<2)|0);
      $282 = HEAP32[$281>>2]|0;
      $283 = (($282) + 12|0);
      $284 = HEAP32[$283>>2]|0;
      $285 = (($284) + 16|0);
      $286 = ((($275) + ($numHeaders$05<<5)|0) + 8|0);
      HEAP32[$286>>2] = $285;
      $287 = (($284) + 44|0);
      $288 = HEAP32[$287>>2]|0;
      $289 = ((($275) + ($numHeaders$05<<5)|0) + 12|0);
      HEAP32[$289>>2] = $288;
      $290 = (($284) + 48|0);
      $291 = HEAP32[$290>>2]|0;
      $292 = ((($275) + ($numHeaders$05<<5)|0) + 16|0);
      HEAP32[$292>>2] = $291;
      $293 = (($284) + 36|0);
      $294 = HEAP16[$293>>1]|0;
      $295 = $294&65535;
      $296 = ((($275) + ($numHeaders$05<<5)|0) + 20|0);
      HEAP32[$296>>2] = $295;
      $297 = (($284) + 114|0);
      $298 = HEAP16[$297>>1]|0;
      $299 = $298 & 16;
      $300 = ($299<<16>>16)==(0);
      if ($300) {
       $$0$i2 = 0;
      } else {
       $301 = HEAP32[$287>>2]|0;
       $302 = HEAP32[$290>>2]|0;
       $303 = (($302) + 15)|0;
       $304 = $303 & -16;
       $305 = (($301) + ($304)|0);
       $$0$i2 = $305;
      }
      $306 = ((($275) + ($numHeaders$05<<5)|0) + 24|0);
      HEAP32[$306>>2] = $$0$i2;
      $contactCount$1 = 0;$contactDescPtr$3 = $241;$numHeaders$3 = $273;$startDesc$2 = $241;$startIndex$1 = $a14$06;
     } else {
      $contactCount$1 = 0;$contactDescPtr$3 = $241;$numHeaders$3 = $numHeaders$05;$startDesc$2 = $241;$startIndex$1 = $a14$06;
     }
    }
   } while(0);
   $307 = (($247) + 36|0);
   $308 = HEAP16[$307>>1]|0;
   $309 = $308&65535;
   $310 = (($309) + ($contactCount$1))|0;
   $311 = (($a14$06) + 1)|0;
   $312 = HEAP32[$33>>2]|0;
   $313 = ($311>>>0)<($312>>>0);
   if ($313) {
    $a14$06 = $311;$contactCount$09 = $310;$contactDescPtr$111 = $contactDescPtr$3;$numHeaders$05 = $numHeaders$3;$startDesc$010 = $startDesc$2;$startIndex$08 = $startIndex$1;
   } else {
    $$lcssa = $312;$contactCount$0$lcssa = $310;$contactDescPtr$1$lcssa = $contactDescPtr$3;$numHeaders$0$lcssa = $numHeaders$3;$startIndex$0$lcssa = $startIndex$1;
    break;
   }
  }
 } else {
  $$lcssa = $239;$contactCount$0$lcssa = $238;$contactDescPtr$1$lcssa = $contactDescPtr$0$lcssa;$numHeaders$0$lcssa = 0;$startIndex$0$lcssa = 0;
 }
 $314 = (($$lcssa) - ($startIndex$0$lcssa))|0;
 $315 = ($contactCount$0$lcssa|0)==(0);
 if ($315) {
  $contactDescPtr$4 = $contactDescPtr$1$lcssa;$numHeaders$5 = $numHeaders$0$lcssa;
 } else {
  $316 = ($314>>>0)>(1);
  if ($316) {
   $317 = HEAP32[$3>>2]|0;
   $318 = (($numHeaders$0$lcssa) + 1)|0;
   $319 = (($317) + 9204|0);
   $320 = HEAP32[$319>>2]|0;
   $321 = (($320) + ($numHeaders$0$lcssa<<5)|0);
   HEAP32[$321>>2] = $startIndex$0$lcssa;
   $322 = $314&65535;
   $323 = ((($320) + ($numHeaders$0$lcssa<<5)|0) + 4|0);
   HEAP16[$323>>1] = $322;
   $324 = $contactCount$0$lcssa&65535;
   $325 = ((($320) + ($numHeaders$0$lcssa<<5)|0) + 6|0);
   HEAP16[$325>>1] = $324;
   $326 = (($57) + ($startIndex$0$lcssa<<2)|0);
   $327 = HEAP32[$326>>2]|0;
   $328 = (($327) + 12|0);
   $329 = HEAP32[$328>>2]|0;
   $330 = (($329) + 16|0);
   $331 = ((($320) + ($numHeaders$0$lcssa<<5)|0) + 8|0);
   HEAP32[$331>>2] = $330;
   $332 = (($329) + 44|0);
   $333 = HEAP32[$332>>2]|0;
   $334 = ((($320) + ($numHeaders$0$lcssa<<5)|0) + 12|0);
   HEAP32[$334>>2] = $333;
   $335 = (($329) + 48|0);
   $336 = HEAP32[$335>>2]|0;
   $337 = ((($320) + ($numHeaders$0$lcssa<<5)|0) + 16|0);
   HEAP32[$337>>2] = $336;
   $338 = (($329) + 36|0);
   $339 = HEAP16[$338>>1]|0;
   $340 = $339&65535;
   $341 = ((($320) + ($numHeaders$0$lcssa<<5)|0) + 20|0);
   HEAP32[$341>>2] = $340;
   $342 = (($329) + 114|0);
   $343 = HEAP16[$342>>1]|0;
   $344 = $343 & 16;
   $345 = ($344<<16>>16)==(0);
   if ($345) {
    $$0$i = 0;
   } else {
    $346 = HEAP32[$332>>2]|0;
    $347 = HEAP32[$335>>2]|0;
    $348 = (($347) + 15)|0;
    $349 = $348 & -16;
    $350 = (($346) + ($349)|0);
    $$0$i = $350;
   }
   $351 = ((($320) + ($numHeaders$0$lcssa<<5)|0) + 24|0);
   HEAP32[$351>>2] = $$0$i;
   $numHeaders$4 = $318;
  } else {
   $numHeaders$4 = $numHeaders$0$lcssa;
  }
  $352 = (($contactDescPtr$1$lcssa) + 32|0);
  $contactDescPtr$4 = $352;$numHeaders$5 = $numHeaders$4;
 }
 $353 = HEAP32[$3>>2]|0;
 $354 = (($353) + 9208|0);
 HEAP32[$354>>2] = $numHeaders$5;
 $355 = ($numHeaders$5|0)==(0);
 if ($355) {
  $contactDescPtr$5 = $contactDescPtr$4;
  $402 = HEAP32[$3>>2]|0;
  $403 = (($402) + 9144|0);
  $404 = HEAP32[$403>>2]|0;
  $405 = $contactDescPtr$5;
  $406 = $404;
  $407 = (($405) - ($406))|0;
  $408 = $407 >> 5;
  $409 = (($402) + 9148|0);
  HEAP32[$409>>2] = $408;
  $410 = HEAP32[$3>>2]|0;
  $411 = (($410) + 9144|0);
  $412 = HEAP32[$411>>2]|0;
  $413 = $412;
  $414 = (($405) - ($413))|0;
  $415 = $414 >> 5;
  $416 = (($410) + 9172|0);
  HEAP32[$416>>2] = $415;
  STACKTOP = sp;return;
 }
 $356 = (($this) + 12|0);
 $357 = (($this) + 28|0);
 $a20$04 = 0;
 while(1) {
  $358 = HEAP32[$63>>2]|0;
  $359 = (($358) + 96|0);
  $360 = HEAP32[$359>>2]|0;
  $361 = (($360) + 6732|0);
  $362 = HEAP32[$361>>2]|0;
  $363 = HEAP32[$362>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($363);
  $364 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($362,76,16)|0);
  $365 = HEAP32[$362>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($365);
  $366 = ($364|0)==(0|0);
  if ($366) {
   $387 = 0;
  } else {
   $367 = HEAP32[$63>>2]|0;
   $368 = HEAP32[$3>>2]|0;
   $369 = HEAP32[$68>>2]|0;
   $370 = (($numHeaders$5) - ($a20$04))|0;
   $371 = ($370>>>0)>(8);
   $372 = $371 ? 8 : $370;
   $373 = (($364) + 4|0);
   HEAP16[$373>>1] = -1;
   $374 = (($364) + 6|0);
   HEAP16[$374>>1] = 0;
   $375 = (($364) + 8|0);
   HEAP32[$375>>2] = 0;
   HEAP32[$364>>2] = ((434896 + 8|0));
   $376 = (($364) + 12|0);
   HEAP32[$376>>2] = 0;
   $377 = (($364) + 16|0);
   HEAP32[$377>>2] = 0;
   HEAP32[$364>>2] = ((493168 + 8|0));
   $378 = (($364) + 20|0);
   HEAP32[$378>>2] = $367;
   $379 = (($364) + 24|0);
   HEAP32[$379>>2] = $368;
   $380 = (($364) + 28|0);
   ;HEAP32[$380+0>>2]=HEAP32[$357+0>>2]|0;HEAP32[$380+4>>2]=HEAP32[$357+4>>2]|0;HEAP32[$380+8>>2]=HEAP32[$357+8>>2]|0;HEAP32[$380+12>>2]=HEAP32[$357+12>>2]|0;HEAP32[$380+16>>2]=HEAP32[$357+16>>2]|0;
   $381 = (($364) + 48|0);
   ;HEAP32[$381+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$381+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$381+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$381+12>>2]=HEAP32[$7+12>>2]|0;
   $382 = (($364) + 64|0);
   HEAP32[$382>>2] = $369;
   $383 = (($364) + 68|0);
   HEAP32[$383>>2] = $a20$04;
   $384 = (($364) + 72|0);
   HEAP32[$384>>2] = $372;
   $387 = $364;
  }
  $385 = HEAP32[$356>>2]|0;
  $386 = (($387) + 16|0);
  HEAP32[$386>>2] = 1;
  $388 = (($387) + 12|0);
  HEAP32[$388>>2] = $385;
  $389 = ($385|0)==(0|0);
  if (!($389)) {
   $390 = HEAP32[$385>>2]|0;
   $391 = (($390) + 16|0);
   $392 = HEAP32[$391>>2]|0;
   FUNCTION_TABLE_vi[$392 & 4095]($385);
   $393 = HEAP32[$388>>2]|0;
   $394 = (($393) + 8|0);
   $395 = HEAP32[$394>>2]|0;
   $396 = (($387) + 8|0);
   HEAP32[$396>>2] = $395;
  }
  $397 = HEAP32[$387>>2]|0;
  $398 = (($397) + 20|0);
  $399 = HEAP32[$398>>2]|0;
  FUNCTION_TABLE_vi[$399 & 4095]($387);
  $400 = (($a20$04) + 8)|0;
  $401 = ($400>>>0)<($numHeaders$5>>>0);
  if ($401) {
   $a20$04 = $400;
  } else {
   $contactDescPtr$5 = $contactDescPtr$4;
   break;
  }
 }
 $402 = HEAP32[$3>>2]|0;
 $403 = (($402) + 9144|0);
 $404 = HEAP32[$403>>2]|0;
 $405 = $contactDescPtr$5;
 $406 = $404;
 $407 = (($405) - ($406))|0;
 $408 = $407 >> 5;
 $409 = (($402) + 9148|0);
 HEAP32[$409>>2] = $408;
 $410 = HEAP32[$3>>2]|0;
 $411 = (($410) + 9144|0);
 $412 = HEAP32[$411>>2]|0;
 $413 = $412;
 $414 = (($405) - ($413))|0;
 $415 = $414 >> 5;
 $416 = (($410) + 9172|0);
 HEAP32[$416>>2] = $415;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_25PxsCompoundContactManagerENS0_19ReflectionAllocatorIS2_EEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_25PxsCompoundContactManagerENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<5)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<5)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$$01$i+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$$01$i+20>>2]=HEAP32[$a+20>>2]|0;HEAP32[$$01$i+24>>2]=HEAP32[$a+24>>2]|0;HEAP32[$$01$i+28>>2]=HEAP32[$a+28>>2]|0;
  }
  $11 = (($$01$i) + 32|0);
  $12 = ($11>>>0)<($7>>>0);
  if ($12) {
   $$01$i = $11;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx34PxsSolverConstraintPostProcessTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx34PxsSolverConstraintPostProcessTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx34PxsSolverConstraintPostProcessTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (493432|0);
}
function __ZN5physx34PxsSolverConstraintPostProcessTask11runInternalEv($this) {
 $this = $this|0;
 var $$$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $exitcond = 0, $rv$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1))|0;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 96|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 224|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__ZN5physx6shdfnd9SListImpl3popEv($10)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (__Z15PxGetFoundationv()|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_ii[$20 & 4095]($17)|0);
  $$$i$i$i$i$i = $21 ? 492696 : 491832;
  $22 = (FUNCTION_TABLE_iiiiii[$16 & 255]($13,9459,$$$i$i$i$i$i,492592,82)|0);
  $23 = ($22|0)==(0|0);
  if ($23) {
   $rv$0$i$i = 0;
  } else {
   $24 = (($22) + 19|0);
   $25 = $24;
   $26 = $25 & -16;
   $27 = $22;
   $28 = (($26) - ($27))|0;
   $29 = $26;
   $30 = (($29) + -4|0);
   HEAP32[$30>>2] = $28;
   $31 = $26;
   $32 = ($26|0)==(0);
   if ($32) {
    $rv$0$i$i = $31;
   } else {
    __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($31,$8);
    $rv$0$i$i = $31;
   }
  }
 } else {
  $rv$0$i$i = $11;
 }
 $33 = (($rv$0$i$i) + 352|0);
 HEAP32[$33>>2] = 0;
 $34 = (($rv$0$i$i) + 356|0);
 HEAP32[$34>>2] = 0;
 $35 = (($rv$0$i$i) + 336|0);
 HEAP32[$35>>2] = 0;
 $36 = (($rv$0$i$i) + 340|0);
 HEAP32[$36>>2] = 0;
 $37 = HEAP32[$0>>2]|0;
 $38 = ($37>>>0)<($4>>>0);
 if (!($38)) {
  $45 = HEAP32[$5>>2]|0;
  $46 = (($45) + 96|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + 224|0);
  $49 = HEAP32[$48>>2]|0;
  __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($49,$rv$0$i$i);
  STACKTOP = sp;return;
 }
 $39 = (($this) + 24|0);
 $a$01 = $37;
 while(1) {
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 9204|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + ($a$01<<5)|0);
  __ZN5physx34PxsSolverConstraintPostProcessTask13mergeContactsERNS_25PxsCompoundContactManagerERNS_16PxsThreadContextE($this,$43,$rv$0$i$i);
  $44 = (($a$01) + 1)|0;
  $exitcond = ($44|0)==($4|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $44;
  }
 }
 $45 = HEAP32[$5>>2]|0;
 $46 = (($45) + 96|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 224|0);
 $49 = HEAP32[$48>>2]|0;
 __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($49,$rv$0$i$i);
 STACKTOP = sp;return;
}
function __ZN5physx34PxsSolverConstraintPostProcessTask13mergeContactsERNS_25PxsCompoundContactManagerERNS_16PxsThreadContextE($this,$header,$threadContext) {
 $this = $this|0;
 $header = $header|0;
 $threadContext = $threadContext|0;
 var $$ = 0, $$0$i = 0, $$64 = 0, $$in$i$in = 0, $$in$i4$in = 0, $$pre$i = 0, $$promoted = 0, $$promoted45 = 0, $$promoted46 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0;
 var $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0);
 var $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0;
 var $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0;
 var $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0;
 var $98 = 0, $99 = Math_fround(0), $a$031 = 0, $a2$015 = 0, $a3$07 = 0, $b$010 = 0, $contactForceByteSize$0 = 0, $contactForces = 0, $exitcond = 0, $faceIndices$0$off0$i$i = 0, $hasForces$0$off0$lcssa = 0, $hasForces$0$off032 = 0, $hasForces$1$off0 = 0, $histo = 0, $iter = 0, $materialInfo = 0, $modify$0$off0$i$i = 0, $patchHeaderSize$0$i$i = 0, $phitmp$i$i = 0, $pointSize$0$i$i = 0;
 var $response$0$off0$i$i = 0, $scevgep = 0, $scevgep43 = 0, $size$0$lcssa = 0, $size$033 = 0, $size$1$lcssa = 0, $size$127 = 0, $size$2$lcssa = 0, $size$220 = 0, $size$3 = 0, $size$4$lcssa = 0, $size$417 = 0, $size$5$lcssa = 0, $size$6$lcssa62 = 0, $size$6$lcssa63 = 0, $size$69 = 0, $size$7 = 0, $umax = 0, $umax42 = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1536|0;
 $materialInfo = sp + 1216|0;
 $iter = sp;
 $histo = sp + 1472|0;
 $contactForces = sp + 1212|0;
 $0 = (($threadContext) + 16|0);
 $1 = (($header) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(0);
 if ($3) {
  $hasForces$0$off0$lcssa = 0;$size$0$lcssa = 0;
 } else {
  $4 = (($this) + 24|0);
  $5 = (($iter) + 4|0);
  $6 = (($iter) + 8|0);
  $7 = (($iter) + 36|0);
  $8 = (($iter) + 40|0);
  $9 = (($iter) + 44|0);
  $10 = (($iter) + 12|0);
  $11 = (($iter) + 60|0);
  $12 = (($iter) + 56|0);
  $13 = (($iter) + 64|0);
  $14 = (($iter) + 48|0);
  $15 = (($iter) + 52|0);
  $16 = (($iter) + 24|0);
  $17 = (($iter) + 28|0);
  $18 = (($iter) + 16|0);
  $19 = (($iter) + 32|0);
  $a$031 = 0;$hasForces$0$off032 = 0;$size$033 = 0;
  while(1) {
   $20 = HEAP32[$4>>2]|0;
   $21 = HEAP32[$header>>2]|0;
   $22 = (($21) + ($a$031))|0;
   $23 = (($20) + 9216|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + ($22<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 44|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($28) + 48|0);
   $32 = HEAP32[$31>>2]|0;
   HEAPF32[$iter>>2] = Math_fround(0.0);
   HEAPF32[$5>>2] = Math_fround(0.0);
   HEAPF32[$6>>2] = Math_fround(0.0);
   HEAP32[$7>>2] = $32;
   HEAP32[$8>>2] = 0;
   HEAP32[$9>>2] = 0;
   HEAP32[$10>>2] = $30;
   $33 = ($32|0)==(0);
   if ($33) {
    $51 = 0;$faceIndices$0$off0$i$i = 0;$modify$0$off0$i$i = 0;$patchHeaderSize$0$i$i = 0;$pointSize$0$i$i = 0;$response$0$off0$i$i = 1;
   } else {
    $34 = (($30) + 2|0);
    $35 = HEAP16[$34>>1]|0;
    $36 = $35&65535;
    $37 = $36 & 2;
    $38 = ($37|0)!=(0);
    $39 = $36 & 1;
    $40 = ($39|0)!=(0);
    $41 = $37 << 3;
    $42 = $41 | 4;
    $43 = (($30) + ($42)|0);
    $44 = $38 ? 4 : 32;
    if ($38) {
     $268 = 72;
    } else {
     $45 = $39 << 3;
     $46 = $45 | 16;
     $268 = $46;
    }
    $47 = $35 & 4;
    $phitmp$i$i = ($47<<16>>16)!=(0);
    $51 = $43;$faceIndices$0$off0$i$i = $40;$modify$0$off0$i$i = $38;$patchHeaderSize$0$i$i = $44;$pointSize$0$i$i = $268;$response$0$off0$i$i = $phitmp$i$i;
   }
   $48 = $modify$0$off0$i$i&1;
   HEAP32[$11>>2] = $48;
   $49 = $faceIndices$0$off0$i$i&1;
   HEAP32[$12>>2] = $49;
   $50 = $response$0$off0$i$i&1;
   HEAP32[$13>>2] = $50;
   HEAP32[$14>>2] = $patchHeaderSize$0$i$i;
   HEAP32[$15>>2] = $pointSize$0$i$i;
   HEAP32[$16>>2] = $51;
   HEAP32[$17>>2] = $51;
   HEAP32[$18>>2] = $51;
   if ($response$0$off0$i$i) {
    $hasForces$1$off0 = $hasForces$0$off032;$size$3 = $size$033;
   } else {
    $52 = $51;
    $53 = $30;
    $54 = (($52) - ($53))|0;
    $55 = ($54>>>0)<($32>>>0);
    if ($55) {
     $$promoted45 = $51;$269 = 0;$270 = 0;$64 = $51;$66 = $52;$size$127 = $size$033;
     while(1) {
      HEAP32[$16>>2] = $64;
      $65 = (($66) - ($53))|0;
      $67 = ($65>>>0)<($32>>>0);
      if ($67) {
       $68 = HEAP16[$64>>1]|0;
       $69 = $68&65535;
       HEAP32[$8>>2] = $69;
       $70 = Math_imul($pointSize$0$i$i, $69)|0;
       $$sum$i = (($70) + ($patchHeaderSize$0$i$i))|0;
       $71 = (($64) + ($$sum$i)|0);
       HEAP32[$17>>2] = $71;
       $72 = (($64) + ($patchHeaderSize$0$i$i)|0);
       HEAP32[$18>>2] = $72;
       HEAP32[$9>>2] = 0;
       $$promoted = $72;$58 = 0;$61 = $71;$74 = $69;
      } else {
       HEAP32[$17>>2] = $64;
       $$promoted = $$promoted45;$58 = $270;$61 = $64;$74 = $269;
      }
      $73 = ($58>>>0)<($74>>>0);
      if ($73) {
       $75 = (($64) + 20|0);
       $76 = (($64) + 16|0);
       $77 = (($64) + 24|0);
       $78 = (($64) + 4|0);
       $79 = (($64) + 28|0);
       $80 = (($64) + 30|0);
       $81 = (($58) + 1)|0;
       $82 = ($74>>>0)>($81>>>0);
       $umax42 = $82 ? $74 : $81;
       $57 = (($size$127) + ($umax42))|0;
       $83 = (($umax42) - ($58))|0;
       $59 = Math_imul($pointSize$0$i$i, $83)|0;
       $84 = (($umax42) + -1)|0;
       $85 = (($84) - ($58))|0;
       $86 = Math_imul($pointSize$0$i$i, $85)|0;
       $scevgep43 = (($$promoted) + ($86)|0);
       $88 = $58;$90 = $$promoted;$size$220 = $size$127;
       while(1) {
        $87 = (($88) + 1)|0;
        $89 = (($90) + ($pointSize$0$i$i)|0);
        $91 = (($size$220) + 1)|0;
        if ($modify$0$off0$i$i) {
         $92 = (($90) + 56|0);
         $93 = Math_fround(HEAPF32[$92>>2]);
         $94 = ((($threadContext) + ($size$220<<6)|0) + 456|0);
         HEAPF32[$94>>2] = $93;
         $95 = (($90) + 52|0);
         $96 = Math_fround(HEAPF32[$95>>2]);
         $97 = ((($threadContext) + ($size$220<<6)|0) + 444|0);
         HEAPF32[$97>>2] = $96;
         $98 = (($90) + 60|0);
         $$in$i4$in = $98;
        } else {
         $99 = Math_fround(HEAPF32[$75>>2]);
         $100 = ((($threadContext) + ($size$220<<6)|0) + 456|0);
         HEAPF32[$100>>2] = $99;
         $101 = Math_fround(HEAPF32[$76>>2]);
         $102 = ((($threadContext) + ($size$220<<6)|0) + 444|0);
         HEAPF32[$102>>2] = $101;
         $$in$i4$in = $77;
        }
        $103 = Math_fround(HEAPF32[$$in$i4$in>>2]);
        $104 = ((($threadContext) + ($size$220<<6)|0) + 460|0);
        HEAPF32[$104>>2] = $103;
        if ($faceIndices$0$off0$i$i) {
         $106 = (($90) + 16|0);
         $107 = HEAP32[$106>>2]|0;
         $108 = ((($threadContext) + ($size$220<<6)|0) + 448|0);
         HEAP32[$108>>2] = $107;
         $109 = (($90) + 20|0);
         $110 = HEAP32[$109>>2]|0;
         $112 = $110;
        } else {
         $105 = ((($threadContext) + ($size$220<<6)|0) + 448|0);
         HEAP32[$105>>2] = -1;
         $112 = -1;
        }
        $111 = ((($threadContext) + ($size$220<<6)|0) + 452|0);
        HEAP32[$111>>2] = $112;
        if ($modify$0$off0$i$i) {
         $113 = (($90) + 48|0);
         $114 = Math_fround(HEAPF32[$113>>2]);
         $115 = ((($threadContext) + ($size$220<<6)|0) + 428|0);
         HEAPF32[$115>>2] = $114;
         $116 = (($90) + 36|0);
         $119 = $116;
        } else {
         $117 = ((($threadContext) + ($size$220<<6)|0) + 428|0);
         HEAPF32[$117>>2] = Math_fround(3.40282346638528859812E+38);
         $119 = $iter;
        }
        $118 = Math_fround(HEAPF32[$119>>2]);
        $120 = ((($threadContext) + ($size$220<<6)|0) + 432|0);
        HEAPF32[$120>>2] = $118;
        $121 = (($119) + 4|0);
        $122 = Math_fround(HEAPF32[$121>>2]);
        $123 = ((($threadContext) + ($size$220<<6)|0) + 436|0);
        HEAPF32[$123>>2] = $122;
        $124 = (($119) + 8|0);
        $125 = Math_fround(HEAPF32[$124>>2]);
        $126 = ((($threadContext) + ($size$220<<6)|0) + 440|0);
        HEAPF32[$126>>2] = $125;
        $127 = (($90) + 24|0);
        $$64 = $modify$0$off0$i$i ? $127 : $78;
        $128 = Math_fround(HEAPF32[$$64>>2]);
        $129 = ((($threadContext) + ($size$220<<6)|0) + 400|0);
        HEAPF32[$129>>2] = $128;
        $130 = (($$64) + 4|0);
        $131 = Math_fround(HEAPF32[$130>>2]);
        $132 = ((($threadContext) + ($size$220<<6)|0) + 404|0);
        HEAPF32[$132>>2] = $131;
        $133 = (($$64) + 8|0);
        $134 = Math_fround(HEAPF32[$133>>2]);
        $135 = ((($threadContext) + ($size$220<<6)|0) + 408|0);
        HEAPF32[$135>>2] = $134;
        $136 = Math_fround(HEAPF32[$90>>2]);
        $137 = ((($threadContext) + ($size$220<<6)|0) + 416|0);
        HEAPF32[$137>>2] = $136;
        $138 = (($90) + 4|0);
        $139 = Math_fround(HEAPF32[$138>>2]);
        $140 = ((($threadContext) + ($size$220<<6)|0) + 420|0);
        HEAPF32[$140>>2] = $139;
        $141 = (($90) + 8|0);
        $142 = Math_fround(HEAPF32[$141>>2]);
        $143 = ((($threadContext) + ($size$220<<6)|0) + 424|0);
        HEAPF32[$143>>2] = $142;
        $144 = (($90) + 12|0);
        $145 = Math_fround(HEAPF32[$144>>2]);
        $146 = ((($threadContext) + ($size$220<<6)|0) + 412|0);
        HEAPF32[$146>>2] = $145;
        if ($modify$0$off0$i$i) {
         $147 = (($90) + 64|0);
         $148 = HEAP16[$147>>1]|0;
         $149 = (($materialInfo) + ($size$220<<2)|0);
         HEAP16[$149>>1] = $148;
         $150 = (($90) + 66|0);
         $$in$i$in = $150;
        } else {
         $151 = HEAP16[$79>>1]|0;
         $152 = (($materialInfo) + ($size$220<<2)|0);
         HEAP16[$152>>1] = $151;
         $$in$i$in = $80;
        }
        $153 = HEAP16[$$in$i$in>>1]|0;
        $154 = ((($materialInfo) + ($size$220<<2)|0) + 2|0);
        HEAP16[$154>>1] = $153;
        $155 = ($87>>>0)<($74>>>0);
        if ($155) {
         $88 = $87;$90 = $89;$size$220 = $91;
        } else {
         break;
        }
       }
       $56 = (($57) - ($58))|0;
       $scevgep = (($$promoted) + ($59)|0);
       HEAP32[$9>>2] = $umax42;
       HEAP32[$18>>2] = $scevgep;
       HEAP32[$19>>2] = $scevgep43;
       $$promoted46 = $scevgep;$271 = $umax42;$size$2$lcssa = $56;
      } else {
       $$promoted46 = $$promoted;$271 = $58;$size$2$lcssa = $size$127;
      }
      $60 = $61;
      $62 = (($60) - ($53))|0;
      $63 = ($62>>>0)<($32>>>0);
      if ($63) {
       $$promoted45 = $$promoted46;$269 = $74;$270 = $271;$64 = $61;$66 = $60;$size$127 = $size$2$lcssa;
      } else {
       $size$1$lcssa = $size$2$lcssa;
       break;
      }
     }
    } else {
     $size$1$lcssa = $size$033;
    }
    if ($hasForces$0$off032) {
     $hasForces$1$off0 = 1;$size$3 = $size$1$lcssa;
    } else {
     $156 = (($28) + 114|0);
     $157 = HEAP16[$156>>1]|0;
     $158 = $157 & 16;
     $159 = ($158<<16>>16)!=(0);
     $hasForces$1$off0 = $159;$size$3 = $size$1$lcssa;
    }
   }
   $160 = (($a$031) + 1)|0;
   $161 = $2&65535;
   $162 = ($160>>>0)<($161>>>0);
   if ($162) {
    $a$031 = $160;$hasForces$0$off032 = $hasForces$1$off0;$size$033 = $size$3;
   } else {
    $hasForces$0$off0$lcssa = $hasForces$1$off0;$size$0$lcssa = $size$3;
    break;
   }
  }
 }
 $163 = (($threadContext) + 400|0);
 $164 = (($iter) + 168|0);
 HEAP32[$164>>2] = 0;
 $165 = (($iter) + 1196|0);
 HEAP32[$165>>2] = 0;
 $166 = (($iter) + 1200|0);
 HEAP32[$166>>2] = $163;
 $167 = (($iter) + 1204|0);
 HEAP32[$167>>2] = $materialInfo;
 $168 = (($iter) + 1208|0);
 HEAP32[$168>>2] = $size$0$lcssa;
 __ZN5physx19PxsContactReductionILj6EE14reduceContactsEv($iter);
 dest=$histo+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $169 = HEAP32[$164>>2]|0;
 $170 = ($169|0)==(0);
 if ($170) {
  $size$4$lcssa = 0;
 } else {
  $a2$015 = 0;$size$417 = 0;
  while(1) {
   $171 = (($iter) + (($a2$015*28)|0)|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = ($172|0)==(0);
   if ($173) {
    $size$5$lcssa = $size$417;
   } else {
    $174 = ($172>>>0)>(1);
    $umax = $174 ? $172 : 1;
    $b$010 = 0;
    while(1) {
     $175 = (((($iter) + (($a2$015*28)|0)|0) + ($b$010<<2)|0) + 4|0);
     $176 = HEAP32[$175>>2]|0;
     $177 = (($histo) + ($176)|0);
     HEAP8[$177>>0] = 1;
     $178 = (($b$010) + 1)|0;
     $179 = ($178>>>0)<($172>>>0);
     if ($179) {
      $b$010 = $178;
     } else {
      break;
     }
    }
    $180 = (($size$417) + ($umax))|0;
    $size$5$lcssa = $180;
   }
   $181 = (($a2$015) + 1)|0;
   $182 = ($181>>>0)<($169>>>0);
   if ($182) {
    $a2$015 = $181;$size$417 = $size$5$lcssa;
   } else {
    $size$4$lcssa = $size$5$lcssa;
    break;
   }
  }
 }
 $183 = (($threadContext) + 332|0);
 $184 = $size$4$lcssa << 1;
 $185 = (($this) + 24|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = (($184) + 15)|0;
 $188 = $187 & -16;
 $189 = ($188>>>0)>(16384);
 do {
  if ($189) {
   $190 = HEAP32[$183>>2]|0;
   $191 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($190,$188)|0);
   $$0$i = $191;
  } else {
   $192 = (($threadContext) + 336|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = ($193|0)==(0|0);
   $$pre$i = (($threadContext) + 340|0);
   if (!($194)) {
    $195 = HEAP32[$$pre$i>>2]|0;
    $196 = (($195) + ($188))|0;
    $197 = ($196>>>0)>(16384);
    if (!($197)) {
     $201 = (($193) + ($195)|0);
     HEAP32[$$pre$i>>2] = $196;
     $$0$i = $201;
     break;
    }
   }
   $198 = HEAP32[$183>>2]|0;
   $199 = (($186) + 316|0);
   $200 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($198,$199)|0);
   HEAP32[$192>>2] = $200;
   HEAP32[$$pre$i>>2] = $188;
   $$0$i = $200;
  }
 } while(0);
 $202 = (($header) + 28|0);
 HEAP32[$202>>2] = $$0$i;
 $203 = ($size$0$lcssa|0)==(0);
 if ($203) {
  $size$6$lcssa63 = 0;
 } else {
  $a3$07 = 0;$size$69 = 0;
  while(1) {
   $204 = (($histo) + ($a3$07)|0);
   $205 = HEAP8[$204>>0]|0;
   $206 = ($205<<24>>24)==(0);
   if ($206) {
    $size$7 = $size$69;
   } else {
    $207 = ($size$69|0)==($a3$07|0);
    if (!($207)) {
     $208 = ((($threadContext) + ($a3$07<<6)|0) + 400|0);
     $209 = Math_fround(HEAPF32[$208>>2]);
     $210 = ((($threadContext) + ($size$69<<6)|0) + 400|0);
     HEAPF32[$210>>2] = $209;
     $211 = ((($threadContext) + ($a3$07<<6)|0) + 404|0);
     $212 = Math_fround(HEAPF32[$211>>2]);
     $213 = ((($threadContext) + ($size$69<<6)|0) + 404|0);
     HEAPF32[$213>>2] = $212;
     $214 = ((($threadContext) + ($a3$07<<6)|0) + 408|0);
     $215 = Math_fround(HEAPF32[$214>>2]);
     $216 = ((($threadContext) + ($size$69<<6)|0) + 408|0);
     HEAPF32[$216>>2] = $215;
     $217 = ((($threadContext) + ($a3$07<<6)|0) + 412|0);
     $218 = Math_fround(HEAPF32[$217>>2]);
     $219 = ((($threadContext) + ($size$69<<6)|0) + 412|0);
     HEAPF32[$219>>2] = $218;
     $220 = ((($threadContext) + ($a3$07<<6)|0) + 416|0);
     $221 = Math_fround(HEAPF32[$220>>2]);
     $222 = ((($threadContext) + ($size$69<<6)|0) + 416|0);
     HEAPF32[$222>>2] = $221;
     $223 = ((($threadContext) + ($a3$07<<6)|0) + 420|0);
     $224 = Math_fround(HEAPF32[$223>>2]);
     $225 = ((($threadContext) + ($size$69<<6)|0) + 420|0);
     HEAPF32[$225>>2] = $224;
     $226 = ((($threadContext) + ($a3$07<<6)|0) + 424|0);
     $227 = Math_fround(HEAPF32[$226>>2]);
     $228 = ((($threadContext) + ($size$69<<6)|0) + 424|0);
     HEAPF32[$228>>2] = $227;
     $229 = ((($threadContext) + ($a3$07<<6)|0) + 428|0);
     $230 = Math_fround(HEAPF32[$229>>2]);
     $231 = ((($threadContext) + ($size$69<<6)|0) + 428|0);
     HEAPF32[$231>>2] = $230;
     $232 = ((($threadContext) + ($a3$07<<6)|0) + 432|0);
     $233 = Math_fround(HEAPF32[$232>>2]);
     $234 = ((($threadContext) + ($size$69<<6)|0) + 432|0);
     HEAPF32[$234>>2] = $233;
     $235 = ((($threadContext) + ($a3$07<<6)|0) + 436|0);
     $236 = Math_fround(HEAPF32[$235>>2]);
     $237 = ((($threadContext) + ($size$69<<6)|0) + 436|0);
     HEAPF32[$237>>2] = $236;
     $238 = ((($threadContext) + ($a3$07<<6)|0) + 440|0);
     $239 = Math_fround(HEAPF32[$238>>2]);
     $240 = ((($threadContext) + ($size$69<<6)|0) + 440|0);
     HEAPF32[$240>>2] = $239;
     $241 = ((($threadContext) + ($size$69<<6)|0) + 444|0);
     $242 = ((($threadContext) + ($a3$07<<6)|0) + 444|0);
     ;HEAP32[$241+0>>2]=HEAP32[$242+0>>2]|0;HEAP32[$241+4>>2]=HEAP32[$242+4>>2]|0;HEAP32[$241+8>>2]=HEAP32[$242+8>>2]|0;HEAP32[$241+12>>2]=HEAP32[$242+12>>2]|0;HEAP32[$241+16>>2]=HEAP32[$242+16>>2]|0;
     $243 = (($materialInfo) + ($size$69<<2)|0);
     $244 = (($materialInfo) + ($a3$07<<2)|0);
     $245 = HEAPU16[$244>>1]|(HEAPU16[$244+2>>1]<<16);
     HEAP16[$243>>1]=$245&65535;HEAP16[$243+2>>1]=$245>>>16;
    }
    $246 = $a3$07&65535;
    $247 = (($$0$i) + ($size$69<<1)|0);
    HEAP16[$247>>1] = $246;
    $248 = (($size$69) + 1)|0;
    $size$7 = $248;
   }
   $249 = (($a3$07) + 1)|0;
   $exitcond = ($249|0)==($size$0$lcssa|0);
   if ($exitcond) {
    break;
   } else {
    $a3$07 = $249;$size$69 = $size$7;
   }
  }
  $250 = ($size$7|0)==(0);
  if ($250) {
   $size$6$lcssa63 = 0;
  } else {
   $251 = $size$7 << 2;
   if ($hasForces$0$off0$lcssa) {
    $contactForceByteSize$0 = $251;$size$6$lcssa62 = $size$7;
    $252 = $size$6$lcssa62&65535;
    $253 = (($header) + 8|0);
    $254 = HEAP32[$253>>2]|0;
    $255 = (($254) + 20|0);
    HEAP16[$255>>1] = $252;
    $256 = (($254) + 28|0);
    $257 = (($254) + 32|0);
    $258 = (($254) + 98|0);
    $259 = (($254) + 80|0);
    $260 = HEAP32[$259>>2]|0;
    $261 = (($254) + 22|0);
    $262 = HEAP16[$261>>1]|0;
    $263 = $262 & 128;
    $264 = ($263<<16>>16)!=(0);
    $265 = HEAP32[$185>>2]|0;
    $266 = ($265|0)==(0|0);
    $267 = (($265) + 16|0);
    $$ = $266 ? 0 : $267;
    (__ZN5physx22writeCompressedContactEPKNS_2Gu12ContactPointEjRNS_18PxcNpThreadContextERtRPhRjRPfjS6_PKNS_18PxsMaterialManagerEbbPNS_15PxsMaterialInfoEjbPS4_b($163,$size$6$lcssa62,$0,$255,$256,$257,$contactForces,$contactForceByteSize$0,$258,$260,$264,0,$materialInfo,0,1,$$,0)|0);
    STACKTOP = sp;return;
   } else {
    $size$6$lcssa63 = $size$7;
   }
  }
 }
 $contactForceByteSize$0 = 0;$size$6$lcssa62 = $size$6$lcssa63;
 $252 = $size$6$lcssa62&65535;
 $253 = (($header) + 8|0);
 $254 = HEAP32[$253>>2]|0;
 $255 = (($254) + 20|0);
 HEAP16[$255>>1] = $252;
 $256 = (($254) + 28|0);
 $257 = (($254) + 32|0);
 $258 = (($254) + 98|0);
 $259 = (($254) + 80|0);
 $260 = HEAP32[$259>>2]|0;
 $261 = (($254) + 22|0);
 $262 = HEAP16[$261>>1]|0;
 $263 = $262 & 128;
 $264 = ($263<<16>>16)!=(0);
 $265 = HEAP32[$185>>2]|0;
 $266 = ($265|0)==(0|0);
 $267 = (($265) + 16|0);
 $$ = $266 ? 0 : $267;
 (__ZN5physx22writeCompressedContactEPKNS_2Gu12ContactPointEjRNS_18PxcNpThreadContextERtRPhRjRPfjS6_PKNS_18PxsMaterialManagerEbbPNS_15PxsMaterialInfoEjbPS4_b($163,$size$6$lcssa62,$0,$255,$256,$257,$contactForces,$contactForceByteSize$0,$258,$260,$264,0,$materialInfo,0,1,$$,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx19PxsContactReductionILj6EE14reduceContactsEv($this) {
 $this = $this|0;
 var $$lcssa129 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0);
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0;
 var $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0;
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0;
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0);
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = Math_fround(0), $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0);
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0;
 var $97 = Math_fround(0), $98 = 0, $99 = 0, $a$0119 = 0, $a1$0111 = 0, $b$0123 = 0, $b12$043 = 0, $b16$057 = 0, $b20$073 = 0, $b24$092 = 0, $b3$0102 = 0, $b6$014 = 0, $b8$029 = 0, $contactCount$0$lcssa166167 = 0, $contactCount$010 = 0, $deepestInd = 0, $dist$022 = Math_fround(0), $dist$1$lcssa = Math_fround(0), $dist$113 = Math_fround(0), $dist$2 = Math_fround(0);
 var $distance$1 = Math_fround(0), $distance$1$1 = Math_fround(0), $distance$1$2 = Math_fround(0), $exitcond = 0, $ind$0108 = 0, $ind$1$lcssa = 0, $ind$1101 = 0, $ind4$021 = 0, $ind4$1$lcssa = 0, $ind4$10$lcssa = 0, $ind4$1055 = 0, $ind4$11 = 0, $ind4$112 = 0, $ind4$2 = 0, $ind4$335 = 0, $ind4$4$lcssa = 0, $ind4$427 = 0, $ind4$5 = 0, $ind4$649 = 0, $ind4$7$lcssa = 0;
 var $ind4$741 = 0, $ind4$8 = 0, $ind4$9$lcssa = 0, $ind4$963 = 0, $index$0 = 0, $index21$1$1 = 0, $index21$1$2 = 0, $index21$1$3 = 0, $j$087 = 0, $k$088 = 0, $m$0130 = 0, $maxDist$036 = Math_fround(0), $maxDist$1$lcssa = Math_fround(0), $maxDist$128 = Math_fround(0), $maxDist$2 = Math_fround(0), $maxDist10$050 = Math_fround(0), $maxDist10$1$lcssa = Math_fround(0), $maxDist10$142 = Math_fround(0), $maxDist10$2 = Math_fround(0), $maxDist14$064 = Math_fround(0);
 var $maxDist14$1$lcssa = Math_fround(0), $maxDist14$156 = Math_fround(0), $maxDist14$2 = Math_fround(0), $numPatches$0$lcssa = 0, $numPatches$0132 = 0, $numPatches$1 = 0, $numReducedPatches$0$lcssa = 0, $numReducedPatches$0112 = 0, $numReducedPatches$1 = 0, $predicate = 0, $scevgep140 = 0, $scevgep145 = 0, $scevgep150$sum = 0, $scevgep151 = 0, $separation = 0, $tmpPatch$011 = 0, $tmpPatch11$0 = 0, $tmpPatch11$051 = 0, $tmpPatch15$0 = 0, $tmpPatch15$062 = 0;
 var $tmpPatch15$065 = 0, $tmpPatch19$0 = 0, $tmpPatch19$076 = 0, $tmpPatch19$077 = 0, $tmpPatch19$1 = 0, $tmpPatch19$197 = 0, $tmpPatch19$198 = 0, $tmpPatch2$0 = 0, $tmpPatch2$0109 = 0, $tmpPatch5$0 = 0, $tmpPatch5$023 = 0, $tmpPatch7$0 = 0, $tmpPatch7$034 = 0, $tmpPatch7$037 = 0, $umax = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 56|0;
 $predicate = sp + 48|0;
 $separation = sp;
 $deepestInd = sp + 24|0;
 $1 = (($this) + 1200|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 172|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($2) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 176|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($2) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 180|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($this) + 184|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 192|0);
 HEAP16[$12>>1] = 0;
 $13 = (($this) + 196|0);
 HEAP16[$13>>1] = 0;
 $14 = (($2) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 188|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($this) + 198|0);
 HEAP16[$17>>1] = 0;
 $18 = (($this) + 1208|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19>>>0)>(1);
 L1: do {
  if ($20) {
   $21 = (($this) + 1204|0);
   $26 = 1;$480 = $19;$m$0130 = 1;$numPatches$0132 = 1;
   while(1) {
    $22 = $numPatches$0132&65535;
    $23 = ($numPatches$0132<<16>>16)==(0);
    L5: do {
     if ($23) {
      $index$0 = -1;
     } else {
      $24 = HEAP32[$21>>2]|0;
      $25 = (($24) + ($26<<2)|0);
      $27 = HEAP16[$25>>1]|0;
      $28 = ((($24) + ($26<<2)|0) + 2|0);
      $b$0123 = $22;
      while(1) {
       $29 = (($b$0123) + -1)|0;
       $30 = ((($this) + (($29*28)|0)|0) + 192|0);
       $31 = HEAP16[$30>>1]|0;
       $32 = $31&65535;
       $33 = (($24) + ($32<<2)|0);
       $34 = HEAP16[$33>>1]|0;
       $35 = ($34<<16>>16)==($27<<16>>16);
       if ($35) {
        $36 = ((($24) + ($32<<2)|0) + 2|0);
        $37 = HEAP16[$36>>1]|0;
        $38 = HEAP16[$28>>1]|0;
        $39 = ($37<<16>>16)==($38<<16>>16);
        if ($39) {
         $40 = HEAP32[$1>>2]|0;
         $41 = ((($this) + (($29*28)|0)|0) + 172|0);
         $42 = Math_fround(HEAPF32[$41>>2]);
         $43 = (($40) + ($26<<6)|0);
         $44 = Math_fround(HEAPF32[$43>>2]);
         $45 = Math_fround($42 * $44);
         $46 = ((($this) + (($29*28)|0)|0) + 176|0);
         $47 = Math_fround(HEAPF32[$46>>2]);
         $48 = ((($40) + ($26<<6)|0) + 4|0);
         $49 = Math_fround(HEAPF32[$48>>2]);
         $50 = Math_fround($47 * $49);
         $51 = Math_fround($45 + $50);
         $52 = ((($this) + (($29*28)|0)|0) + 180|0);
         $53 = Math_fround(HEAPF32[$52>>2]);
         $54 = ((($40) + ($26<<6)|0) + 8|0);
         $55 = Math_fround(HEAPF32[$54>>2]);
         $56 = Math_fround($53 * $55);
         $57 = Math_fround($51 + $56);
         $58 = !($57 >= Math_fround(0.995000004768371582031));
         if (!($58)) {
          $index$0 = $29;
          break L5;
         }
        }
       }
       $59 = ($29|0)==(0);
       if ($59) {
        $index$0 = -1;
        break;
       } else {
        $b$0123 = $29;
       }
      }
     }
    } while(0);
    $60 = (($22) + -1)|0;
    $61 = ($index$0|0)==($60|0);
    if ($61) {
     $114 = $480;$numPatches$1 = $numPatches$0132;
    } else {
     $62 = ((($this) + (($60*28)|0)|0) + 192|0);
     $63 = HEAP16[$62>>1]|0;
     $64 = $63&65535;
     $65 = (($26) - ($64))|0;
     $66 = $65&65535;
     $67 = ((($this) + (($60*28)|0)|0) + 194|0);
     HEAP16[$67>>1] = $66;
     $68 = ($numPatches$0132<<16>>16)==(32);
     if ($68) {
      $$lcssa129 = $26;$numPatches$0$lcssa = 32;
      break L1;
     }
     $69 = ((($this) + (($22*28)|0)|0) + 172|0);
     $70 = ((($this) + (($22*28)|0)|0) + 192|0);
     HEAP16[$70>>1] = $m$0130;
     $71 = ((($this) + (($22*28)|0)|0) + 184|0);
     HEAP32[$71>>2] = 0;
     $72 = ($index$0|0)==(-1);
     if ($72) {
      $73 = ((($this) + (($22*28)|0)|0) + 196|0);
      HEAP16[$73>>1] = $numPatches$0132;
      $74 = HEAP32[$1>>2]|0;
      $75 = (($74) + ($26<<6)|0);
      $76 = Math_fround(HEAPF32[$75>>2]);
      HEAPF32[$69>>2] = $76;
      $77 = ((($74) + ($26<<6)|0) + 4|0);
      $78 = Math_fround(HEAPF32[$77>>2]);
      $79 = ((($this) + (($22*28)|0)|0) + 176|0);
      HEAPF32[$79>>2] = $78;
      $80 = ((($74) + ($26<<6)|0) + 8|0);
      $81 = Math_fround(HEAPF32[$80>>2]);
      $82 = ((($this) + (($22*28)|0)|0) + 180|0);
      HEAPF32[$82>>2] = $81;
      $83 = HEAP32[$1>>2]|0;
      $84 = ((($83) + ($26<<6)|0) + 12|0);
      $85 = Math_fround(HEAPF32[$84>>2]);
      $86 = ((($this) + (($22*28)|0)|0) + 188|0);
      HEAPF32[$86>>2] = $85;
      $87 = ((($this) + (($22*28)|0)|0) + 198|0);
      HEAP16[$87>>1] = $numPatches$0132;
     } else {
      $88 = ((($this) + (($index$0*28)|0)|0) + 196|0);
      $89 = HEAP16[$88>>1]|0;
      $90 = ((($this) + (($index$0*28)|0)|0) + 184|0);
      HEAP32[$90>>2] = $69;
      $91 = ((($this) + (($index$0*28)|0)|0) + 172|0);
      $92 = Math_fround(HEAPF32[$91>>2]);
      HEAPF32[$69>>2] = $92;
      $93 = ((($this) + (($index$0*28)|0)|0) + 176|0);
      $94 = Math_fround(HEAPF32[$93>>2]);
      $95 = ((($this) + (($22*28)|0)|0) + 176|0);
      HEAPF32[$95>>2] = $94;
      $96 = ((($this) + (($index$0*28)|0)|0) + 180|0);
      $97 = Math_fround(HEAPF32[$96>>2]);
      $98 = ((($this) + (($22*28)|0)|0) + 180|0);
      HEAPF32[$98>>2] = $97;
      $99 = $89&65535;
      $100 = ((($this) + (($99*28)|0)|0) + 188|0);
      $101 = Math_fround(HEAPF32[$100>>2]);
      $102 = HEAP32[$1>>2]|0;
      $103 = ((($102) + ($26<<6)|0) + 12|0);
      $104 = Math_fround(HEAPF32[$103>>2]);
      $105 = $101 < $104;
      $106 = $105 ? $101 : $104;
      $107 = ((($this) + (($22*28)|0)|0) + 188|0);
      HEAPF32[$107>>2] = $106;
      HEAPF32[$100>>2] = $106;
      $108 = ((($this) + (($22*28)|0)|0) + 196|0);
      HEAP16[$108>>1] = $89;
      $109 = ((($this) + (($22*28)|0)|0) + 198|0);
      HEAP16[$109>>1] = $numPatches$0132;
     }
     $110 = (($numPatches$0132) + 1)<<16>>16;
     $$pre = HEAP32[$18>>2]|0;
     $114 = $$pre;$numPatches$1 = $110;
    }
    $111 = (($m$0130) + 1)<<16>>16;
    $112 = $111&65535;
    $113 = ($112>>>0)<($114>>>0);
    if ($113) {
     $26 = $112;$480 = $114;$m$0130 = $111;$numPatches$0132 = $numPatches$1;
    } else {
     $$lcssa129 = $112;$numPatches$0$lcssa = $numPatches$1;
     break;
    }
   }
  } else {
   $$lcssa129 = 1;$numPatches$0$lcssa = 1;
  }
 } while(0);
 $115 = $numPatches$0$lcssa&65535;
 $116 = (($115) + -1)|0;
 $117 = ((($this) + (($116*28)|0)|0) + 192|0);
 $118 = HEAP16[$117>>1]|0;
 $119 = $118&65535;
 $120 = (($$lcssa129) - ($119))|0;
 $121 = $120&65535;
 $122 = ((($this) + (($116*28)|0)|0) + 194|0);
 HEAP16[$122>>1] = $121;
 $123 = ($numPatches$0$lcssa<<16>>16)==(0);
 if ($123) {
  HEAP8[$predicate>>0] = 0;
  $478 = (($this) + 1068|0);
  __ZN5physx6shdfnd4sortIPNS_15PxsContactPatchENS_27SortBoundsPredicateManifoldENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($478,$115,$predicate,$0);
  $numReducedPatches$0$lcssa = 0;
  $479 = (($this) + 168|0);
  HEAP32[$479>>2] = $numReducedPatches$0$lcssa;
  STACKTOP = sp;return;
 } else {
  $a$0119 = 0;
 }
 while(1) {
  $124 = ((($this) + (($a$0119*28)|0)|0) + 172|0);
  $125 = ((($this) + ($a$0119<<2)|0) + 1068|0);
  HEAP32[$125>>2] = $124;
  $126 = (($a$0119) + 1)|0;
  $exitcond = ($126|0)==($115|0);
  if ($exitcond) {
   break;
  } else {
   $a$0119 = $126;
  }
 }
 HEAP8[$predicate>>0] = 0;
 $127 = (($this) + 1068|0);
 __ZN5physx6shdfnd4sortIPNS_15PxsContactPatchENS_27SortBoundsPredicateManifoldENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($127,$115,$predicate,$0);
 if ($123) {
  $numReducedPatches$0$lcssa = 0;
  $479 = (($this) + 168|0);
  HEAP32[$479>>2] = $numReducedPatches$0$lcssa;
  STACKTOP = sp;return;
 }
 $scevgep145 = (($deepestInd) + 16|0);
 $a1$0111 = 0;$numReducedPatches$0112 = 0;
 L32: while(1) {
  $128 = ((($this) + ($a1$0111<<2)|0) + 1068|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (($129) + 24|0);
  $131 = HEAP16[$130>>1]|0;
  $132 = (($129) + 26|0);
  $133 = HEAP16[$132>>1]|0;
  $134 = ($131<<16>>16)==($133<<16>>16);
  L34: do {
   if ($134) {
    $135 = ($numReducedPatches$0112|0)==(6);
    if ($135) {
     $numReducedPatches$0$lcssa = 6;
     label = 74;
     break L32;
    }
    $136 = (($numReducedPatches$0112) + 1)|0;
    $137 = (($this) + (($numReducedPatches$0112*28)|0)|0);
    $138 = ($129|0)==(0|0);
    L37: do {
     if ($138) {
      $contactCount$0$lcssa166167 = 0;
     } else {
      $contactCount$010 = 0;$tmpPatch$011 = $129;
      while(1) {
       $139 = (($tmpPatch$011) + 22|0);
       $140 = HEAP16[$139>>1]|0;
       $141 = $140&65535;
       $142 = (($141) + ($contactCount$010))|0;
       $143 = (($tmpPatch$011) + 12|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = ($144|0)==(0|0);
       if ($145) {
        break;
       } else {
        $contactCount$010 = $142;$tmpPatch$011 = $144;
       }
      }
      $146 = ($142>>>0)<(7);
      if ($146) {
       if ($138) {
        $contactCount$0$lcssa166167 = $142;
        break;
       } else {
        $ind$0108 = 0;$tmpPatch2$0109 = $129;
       }
       while(1) {
        $147 = (($tmpPatch2$0109) + 22|0);
        $148 = HEAP16[$147>>1]|0;
        $149 = ($148<<16>>16)==(0);
        if ($149) {
         $ind$1$lcssa = $ind$0108;
        } else {
         $150 = (($tmpPatch2$0109) + 20|0);
         $151 = HEAP16[$150>>1]|0;
         $152 = $151&65535;
         $153 = $148&65535;
         $154 = ($153>>>0)>(1);
         $umax = $154 ? $153 : 1;
         $b3$0102 = 0;$ind$1101 = $ind$0108;
         while(1) {
          $155 = (($152) + ($b3$0102))|0;
          $156 = (($ind$1101) + 1)|0;
          $157 = (((($this) + (($numReducedPatches$0112*28)|0)|0) + ($ind$1101<<2)|0) + 4|0);
          HEAP32[$157>>2] = $155;
          $158 = (($b3$0102) + 1)|0;
          $159 = ($158>>>0)<($153>>>0);
          if ($159) {
           $b3$0102 = $158;$ind$1101 = $156;
          } else {
           break;
          }
         }
         $160 = (($ind$0108) + ($umax))|0;
         $ind$1$lcssa = $160;
        }
        $161 = (($tmpPatch2$0109) + 12|0);
        $tmpPatch2$0 = HEAP32[$161>>2]|0;
        $162 = ($tmpPatch2$0|0)==(0|0);
        if ($162) {
         $contactCount$0$lcssa166167 = $142;
         break L37;
        } else {
         $ind$0108 = $ind$1$lcssa;$tmpPatch2$0109 = $tmpPatch2$0;
        }
       }
      }
      if ($138) {
       $189 = 0;
      } else {
       $dist$022 = Math_fround(0.0);$ind4$021 = 0;$tmpPatch5$023 = $129;
       while(1) {
        $163 = (($tmpPatch5$023) + 22|0);
        $164 = HEAP16[$163>>1]|0;
        $165 = ($164<<16>>16)==(0);
        if ($165) {
         $dist$1$lcssa = $dist$022;$ind4$1$lcssa = $ind4$021;
        } else {
         $166 = (($tmpPatch5$023) + 20|0);
         $167 = HEAP16[$166>>1]|0;
         $168 = $167&65535;
         $169 = HEAP32[$1>>2]|0;
         $170 = $164&65535;
         $b6$014 = 0;$dist$113 = $dist$022;$ind4$112 = $ind4$021;
         while(1) {
          $171 = (($168) + ($b6$014))|0;
          $172 = ((($169) + ($171<<6)|0) + 16|0);
          $173 = Math_fround(HEAPF32[$172>>2]);
          $174 = Math_fround($173 * $173);
          $175 = ((($169) + ($171<<6)|0) + 20|0);
          $176 = Math_fround(HEAPF32[$175>>2]);
          $177 = Math_fround($176 * $176);
          $178 = Math_fround($174 + $177);
          $179 = ((($169) + ($171<<6)|0) + 24|0);
          $180 = Math_fround(HEAPF32[$179>>2]);
          $181 = Math_fround($180 * $180);
          $182 = Math_fround($178 + $181);
          $183 = $dist$113 < $182;
          $ind4$2 = $183 ? $171 : $ind4$112;
          $dist$2 = $183 ? $182 : $dist$113;
          $184 = (($b6$014) + 1)|0;
          $185 = ($184>>>0)<($170>>>0);
          if ($185) {
           $b6$014 = $184;$dist$113 = $dist$2;$ind4$112 = $ind4$2;
          } else {
           $dist$1$lcssa = $dist$2;$ind4$1$lcssa = $ind4$2;
           break;
          }
         }
        }
        $186 = (($tmpPatch5$023) + 12|0);
        $tmpPatch5$0 = HEAP32[$186>>2]|0;
        $187 = ($tmpPatch5$0|0)==(0|0);
        if ($187) {
         $189 = $ind4$1$lcssa;
         break;
        } else {
         $dist$022 = $dist$1$lcssa;$ind4$021 = $ind4$1$lcssa;$tmpPatch5$023 = $tmpPatch5$0;
        }
       }
      }
      $188 = ((($this) + (($numReducedPatches$0112*28)|0)|0) + 4|0);
      HEAP32[$188>>2] = $189;
      $190 = HEAP32[$1>>2]|0;
      $191 = ((($190) + ($189<<6)|0) + 16|0);
      $192 = Math_fround(HEAPF32[$191>>2]);
      $193 = ((($190) + ($189<<6)|0) + 20|0);
      $194 = Math_fround(HEAPF32[$193>>2]);
      $195 = ((($190) + ($189<<6)|0) + 24|0);
      $196 = Math_fround(HEAPF32[$195>>2]);
      $tmpPatch7$034 = HEAP32[$128>>2]|0;
      $197 = ($tmpPatch7$034|0)==(0|0);
      if ($197) {
       $226 = $189;
      } else {
       $ind4$335 = $189;$maxDist$036 = Math_fround(0.0);$tmpPatch7$037 = $tmpPatch7$034;
       while(1) {
        $198 = (($tmpPatch7$037) + 22|0);
        $199 = HEAP16[$198>>1]|0;
        $200 = ($199<<16>>16)==(0);
        if ($200) {
         $ind4$4$lcssa = $ind4$335;$maxDist$1$lcssa = $maxDist$036;
        } else {
         $201 = (($tmpPatch7$037) + 20|0);
         $202 = HEAP16[$201>>1]|0;
         $203 = $202&65535;
         $204 = $199&65535;
         $b8$029 = 0;$ind4$427 = $ind4$335;$maxDist$128 = $maxDist$036;
         while(1) {
          $205 = (($203) + ($b8$029))|0;
          $206 = ((($190) + ($205<<6)|0) + 16|0);
          $207 = Math_fround(HEAPF32[$206>>2]);
          $208 = Math_fround($192 - $207);
          $209 = ((($190) + ($205<<6)|0) + 20|0);
          $210 = Math_fround(HEAPF32[$209>>2]);
          $211 = Math_fround($194 - $210);
          $212 = ((($190) + ($205<<6)|0) + 24|0);
          $213 = Math_fround(HEAPF32[$212>>2]);
          $214 = Math_fround($196 - $213);
          $215 = Math_fround($208 * $208);
          $216 = Math_fround($211 * $211);
          $217 = Math_fround($215 + $216);
          $218 = Math_fround($214 * $214);
          $219 = Math_fround($217 + $218);
          $220 = $219 > $maxDist$128;
          $ind4$5 = $220 ? $205 : $ind4$427;
          $maxDist$2 = $220 ? $219 : $maxDist$128;
          $221 = (($b8$029) + 1)|0;
          $222 = ($221>>>0)<($204>>>0);
          if ($222) {
           $b8$029 = $221;$ind4$427 = $ind4$5;$maxDist$128 = $maxDist$2;
          } else {
           $ind4$4$lcssa = $ind4$5;$maxDist$1$lcssa = $maxDist$2;
           break;
          }
         }
        }
        $223 = (($tmpPatch7$037) + 12|0);
        $tmpPatch7$0 = HEAP32[$223>>2]|0;
        $224 = ($tmpPatch7$0|0)==(0|0);
        if ($224) {
         $226 = $ind4$4$lcssa;
         break;
        } else {
         $ind4$335 = $ind4$4$lcssa;$maxDist$036 = $maxDist$1$lcssa;$tmpPatch7$037 = $tmpPatch7$0;
        }
       }
      }
      $225 = ((($this) + (($numReducedPatches$0112*28)|0)|0) + 8|0);
      HEAP32[$225>>2] = $226;
      $227 = HEAP32[$1>>2]|0;
      $228 = ((($227) + ($226<<6)|0) + 16|0);
      $229 = Math_fround(HEAPF32[$228>>2]);
      $230 = ((($227) + ($226<<6)|0) + 20|0);
      $231 = Math_fround(HEAPF32[$230>>2]);
      $232 = ((($227) + ($226<<6)|0) + 24|0);
      $233 = Math_fround(HEAPF32[$232>>2]);
      $234 = Math_fround($192 - $229);
      $235 = Math_fround($194 - $231);
      $236 = Math_fround($196 - $233);
      $237 = HEAP32[$128>>2]|0;
      $238 = (($237) + 8|0);
      $239 = Math_fround(HEAPF32[$238>>2]);
      $240 = Math_fround($235 * $239);
      $241 = (($237) + 4|0);
      $242 = Math_fround(HEAPF32[$241>>2]);
      $243 = Math_fround($236 * $242);
      $244 = Math_fround($240 - $243);
      $245 = Math_fround(HEAPF32[$237>>2]);
      $246 = Math_fround($236 * $245);
      $247 = Math_fround($234 * $239);
      $248 = Math_fround($246 - $247);
      $249 = Math_fround($234 * $242);
      $250 = Math_fround($235 * $245);
      $251 = Math_fround($249 - $250);
      $252 = ($237|0)==(0|0);
      if ($252) {
       $281 = $226;
      } else {
       $ind4$649 = $226;$maxDist10$050 = Math_fround(0.0);$tmpPatch11$051 = $237;
       while(1) {
        $253 = (($tmpPatch11$051) + 22|0);
        $254 = HEAP16[$253>>1]|0;
        $255 = ($254<<16>>16)==(0);
        if ($255) {
         $ind4$7$lcssa = $ind4$649;$maxDist10$1$lcssa = $maxDist10$050;
        } else {
         $256 = (($tmpPatch11$051) + 20|0);
         $257 = HEAP16[$256>>1]|0;
         $258 = $257&65535;
         $259 = $254&65535;
         $b12$043 = 0;$ind4$741 = $ind4$649;$maxDist10$142 = $maxDist10$050;
         while(1) {
          $260 = (($258) + ($b12$043))|0;
          $261 = ((($227) + ($260<<6)|0) + 16|0);
          $262 = Math_fround(HEAPF32[$261>>2]);
          $263 = Math_fround($262 - $192);
          $264 = ((($227) + ($260<<6)|0) + 20|0);
          $265 = Math_fround(HEAPF32[$264>>2]);
          $266 = Math_fround($265 - $194);
          $267 = ((($227) + ($260<<6)|0) + 24|0);
          $268 = Math_fround(HEAPF32[$267>>2]);
          $269 = Math_fround($268 - $196);
          $270 = Math_fround($244 * $263);
          $271 = Math_fround($248 * $266);
          $272 = Math_fround($270 + $271);
          $273 = Math_fround($251 * $269);
          $274 = Math_fround($272 + $273);
          $275 = $274 > $maxDist10$142;
          $ind4$8 = $275 ? $260 : $ind4$741;
          $maxDist10$2 = $275 ? $274 : $maxDist10$142;
          $276 = (($b12$043) + 1)|0;
          $277 = ($276>>>0)<($259>>>0);
          if ($277) {
           $b12$043 = $276;$ind4$741 = $ind4$8;$maxDist10$142 = $maxDist10$2;
          } else {
           $ind4$7$lcssa = $ind4$8;$maxDist10$1$lcssa = $maxDist10$2;
           break;
          }
         }
        }
        $278 = (($tmpPatch11$051) + 12|0);
        $tmpPatch11$0 = HEAP32[$278>>2]|0;
        $279 = ($tmpPatch11$0|0)==(0|0);
        if ($279) {
         $281 = $ind4$7$lcssa;
         break;
        } else {
         $ind4$649 = $ind4$7$lcssa;$maxDist10$050 = $maxDist10$1$lcssa;$tmpPatch11$051 = $tmpPatch11$0;
        }
       }
      }
      $280 = ((($this) + (($numReducedPatches$0112*28)|0)|0) + 12|0);
      HEAP32[$280>>2] = $281;
      $tmpPatch15$062 = HEAP32[$128>>2]|0;
      $282 = ($tmpPatch15$062|0)==(0|0);
      if ($282) {
       $ind4$9$lcssa = $281;
      } else {
       $ind4$963 = $281;$maxDist14$064 = Math_fround(0.0);$tmpPatch15$065 = $tmpPatch15$062;
       while(1) {
        $283 = (($tmpPatch15$065) + 22|0);
        $284 = HEAP16[$283>>1]|0;
        $285 = ($284<<16>>16)==(0);
        if ($285) {
         $ind4$10$lcssa = $ind4$963;$maxDist14$1$lcssa = $maxDist14$064;
        } else {
         $286 = (($tmpPatch15$065) + 20|0);
         $287 = HEAP16[$286>>1]|0;
         $288 = $287&65535;
         $289 = HEAP32[$1>>2]|0;
         $290 = $284&65535;
         $b16$057 = 0;$ind4$1055 = $ind4$963;$maxDist14$156 = $maxDist14$064;
         while(1) {
          $291 = (($288) + ($b16$057))|0;
          $292 = ((($289) + ($291<<6)|0) + 16|0);
          $293 = Math_fround(HEAPF32[$292>>2]);
          $294 = Math_fround($293 - $192);
          $295 = ((($289) + ($291<<6)|0) + 20|0);
          $296 = Math_fround(HEAPF32[$295>>2]);
          $297 = Math_fround($296 - $194);
          $298 = ((($289) + ($291<<6)|0) + 24|0);
          $299 = Math_fround(HEAPF32[$298>>2]);
          $300 = Math_fround($299 - $196);
          $301 = Math_fround($244 * $294);
          $302 = Math_fround($248 * $297);
          $303 = Math_fround(-$302);
          $304 = Math_fround($303 - $301);
          $305 = Math_fround($251 * $300);
          $306 = Math_fround($304 - $305);
          $307 = $306 > $maxDist14$156;
          $ind4$11 = $307 ? $291 : $ind4$1055;
          $maxDist14$2 = $307 ? $306 : $maxDist14$156;
          $308 = (($b16$057) + 1)|0;
          $309 = ($308>>>0)<($290>>>0);
          if ($309) {
           $b16$057 = $308;$ind4$1055 = $ind4$11;$maxDist14$156 = $maxDist14$2;
          } else {
           $ind4$10$lcssa = $ind4$11;$maxDist14$1$lcssa = $maxDist14$2;
           break;
          }
         }
        }
        $310 = (($tmpPatch15$065) + 12|0);
        $tmpPatch15$0 = HEAP32[$310>>2]|0;
        $311 = ($tmpPatch15$0|0)==(0|0);
        if ($311) {
         $ind4$9$lcssa = $ind4$10$lcssa;
         break;
        } else {
         $ind4$963 = $ind4$10$lcssa;$maxDist14$064 = $maxDist14$1$lcssa;$tmpPatch15$065 = $tmpPatch15$0;
        }
       }
      }
      $312 = ((($this) + (($numReducedPatches$0112*28)|0)|0) + 16|0);
      HEAP32[$312>>2] = $ind4$9$lcssa;
      $313 = HEAP32[$1>>2]|0;
      $314 = ($numReducedPatches$0112*7)|0;
      $scevgep140 = ((($this) + ($314<<2)|0) + 4|0);
      ;HEAP32[$deepestInd+0>>2]=HEAP32[$scevgep140+0>>2]|0;HEAP32[$deepestInd+4>>2]=HEAP32[$scevgep140+4>>2]|0;HEAP32[$deepestInd+8>>2]=HEAP32[$scevgep140+8>>2]|0;HEAP32[$deepestInd+12>>2]=HEAP32[$scevgep140+12>>2]|0;
      $315 = ((($313) + ($189<<6)|0) + 12|0);
      $316 = Math_fround(HEAPF32[$315>>2]);
      $317 = Math_fround($316 + Math_fround(-0.00100000004749745130539));
      HEAPF32[$separation>>2] = $317;
      $318 = ((($313) + ($226<<6)|0) + 12|0);
      $319 = Math_fround(HEAPF32[$318>>2]);
      $320 = Math_fround($319 + Math_fround(-0.00100000004749745130539));
      $321 = (($separation) + 4|0);
      HEAPF32[$321>>2] = $320;
      $322 = ((($313) + ($281<<6)|0) + 12|0);
      $323 = Math_fround(HEAPF32[$322>>2]);
      $324 = Math_fround($323 + Math_fround(-0.00100000004749745130539));
      $325 = (($separation) + 8|0);
      HEAPF32[$325>>2] = $324;
      $326 = ((($313) + ($ind4$9$lcssa<<6)|0) + 12|0);
      $327 = Math_fround(HEAPF32[$326>>2]);
      $328 = Math_fround($327 + Math_fround(-0.00100000004749745130539));
      $329 = (($separation) + 12|0);
      HEAPF32[$329>>2] = $328;
      $tmpPatch19$076 = HEAP32[$128>>2]|0;
      $330 = ($tmpPatch19$076|0)==(0|0);
      if (!($330)) {
       $tmpPatch19$077 = $tmpPatch19$076;
       while(1) {
        $331 = (($tmpPatch19$077) + 22|0);
        $332 = HEAP16[$331>>1]|0;
        $333 = ($332<<16>>16)==(0);
        if (!($333)) {
         $334 = (($tmpPatch19$077) + 20|0);
         $335 = HEAP16[$334>>1]|0;
         $336 = $335&65535;
         $337 = $332&65535;
         $b20$073 = 0;
         while(1) {
          $338 = (($336) + ($b20$073))|0;
          $339 = ((($313) + ($338<<6)|0) + 16|0);
          $340 = Math_fround(HEAPF32[$339>>2]);
          $341 = ((($313) + ($338<<6)|0) + 20|0);
          $342 = Math_fround(HEAPF32[$341>>2]);
          $343 = ((($313) + ($338<<6)|0) + 24|0);
          $344 = Math_fround(HEAPF32[$343>>2]);
          $345 = ((($313) + ($189<<6)|0) + 16|0);
          $346 = Math_fround(HEAPF32[$345>>2]);
          $347 = Math_fround($346 - $340);
          $348 = ((($313) + ($189<<6)|0) + 20|0);
          $349 = Math_fround(HEAPF32[$348>>2]);
          $350 = Math_fround($349 - $342);
          $351 = ((($313) + ($189<<6)|0) + 24|0);
          $352 = Math_fround(HEAPF32[$351>>2]);
          $353 = Math_fround($352 - $344);
          $354 = Math_fround($347 * $347);
          $355 = Math_fround($350 * $350);
          $356 = Math_fround($354 + $355);
          $357 = Math_fround($353 * $353);
          $358 = Math_fround($356 + $357);
          $359 = $358 < Math_fround(3.40282346638528859812E+38);
          $distance$1 = $359 ? $358 : Math_fround(3.40282346638528859812E+38);
          $360 = ((($313) + ($226<<6)|0) + 16|0);
          $361 = Math_fround(HEAPF32[$360>>2]);
          $362 = Math_fround($361 - $340);
          $363 = ((($313) + ($226<<6)|0) + 20|0);
          $364 = Math_fround(HEAPF32[$363>>2]);
          $365 = Math_fround($364 - $342);
          $366 = ((($313) + ($226<<6)|0) + 24|0);
          $367 = Math_fround(HEAPF32[$366>>2]);
          $368 = Math_fround($367 - $344);
          $369 = Math_fround($362 * $362);
          $370 = Math_fround($365 * $365);
          $371 = Math_fround($369 + $370);
          $372 = Math_fround($368 * $368);
          $373 = Math_fround($371 + $372);
          $374 = $distance$1 > $373;
          $distance$1$1 = $374 ? $373 : $distance$1;
          $index21$1$1 = $374&1;
          $375 = ((($313) + ($281<<6)|0) + 16|0);
          $376 = Math_fround(HEAPF32[$375>>2]);
          $377 = Math_fround($376 - $340);
          $378 = ((($313) + ($281<<6)|0) + 20|0);
          $379 = Math_fround(HEAPF32[$378>>2]);
          $380 = Math_fround($379 - $342);
          $381 = ((($313) + ($281<<6)|0) + 24|0);
          $382 = Math_fround(HEAPF32[$381>>2]);
          $383 = Math_fround($382 - $344);
          $384 = Math_fround($377 * $377);
          $385 = Math_fround($380 * $380);
          $386 = Math_fround($384 + $385);
          $387 = Math_fround($383 * $383);
          $388 = Math_fround($386 + $387);
          $389 = $distance$1$1 > $388;
          $distance$1$2 = $389 ? $388 : $distance$1$1;
          $index21$1$2 = $389 ? 2 : $index21$1$1;
          $390 = ((($313) + ($ind4$9$lcssa<<6)|0) + 16|0);
          $391 = Math_fround(HEAPF32[$390>>2]);
          $392 = Math_fround($391 - $340);
          $393 = ((($313) + ($ind4$9$lcssa<<6)|0) + 20|0);
          $394 = Math_fround(HEAPF32[$393>>2]);
          $395 = Math_fround($394 - $342);
          $396 = ((($313) + ($ind4$9$lcssa<<6)|0) + 24|0);
          $397 = Math_fround(HEAPF32[$396>>2]);
          $398 = Math_fround($397 - $344);
          $399 = Math_fround($392 * $392);
          $400 = Math_fround($395 * $395);
          $401 = Math_fround($399 + $400);
          $402 = Math_fround($398 * $398);
          $403 = Math_fround($401 + $402);
          $404 = $distance$1$2 > $403;
          $index21$1$3 = $404 ? 3 : $index21$1$2;
          $405 = (($separation) + ($index21$1$3<<2)|0);
          $406 = Math_fround(HEAPF32[$405>>2]);
          $407 = ((($313) + ($338<<6)|0) + 12|0);
          $408 = Math_fround(HEAPF32[$407>>2]);
          $409 = $406 > $408;
          if ($409) {
           $410 = (($deepestInd) + ($index21$1$3<<2)|0);
           HEAP32[$410>>2] = $338;
           HEAPF32[$405>>2] = $408;
          }
          $411 = (($b20$073) + 1)|0;
          $412 = ($411>>>0)<($337>>>0);
          if ($412) {
           $b20$073 = $411;
          } else {
           break;
          }
         }
        }
        $413 = (($tmpPatch19$077) + 12|0);
        $tmpPatch19$0 = HEAP32[$413>>2]|0;
        $414 = ($tmpPatch19$0|0)==(0|0);
        if ($414) {
         break;
        } else {
         $tmpPatch19$077 = $tmpPatch19$0;
        }
       }
      }
      dest=$0+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
      ;HEAP32[$scevgep140+0>>2]=HEAP32[$deepestInd+0>>2]|0;HEAP32[$scevgep140+4>>2]=HEAP32[$deepestInd+4>>2]|0;HEAP32[$scevgep140+8>>2]=HEAP32[$deepestInd+8>>2]|0;HEAP32[$scevgep140+12>>2]=HEAP32[$deepestInd+12>>2]|0;
      $415 = HEAP32[$deepestInd>>2]|0;
      $416 = (($0) + ($415)|0);
      HEAP8[$416>>0] = 1;
      $417 = (($deepestInd) + 4|0);
      $418 = HEAP32[$417>>2]|0;
      $419 = (($0) + ($418)|0);
      HEAP8[$419>>0] = 1;
      $420 = (($deepestInd) + 8|0);
      $421 = HEAP32[$420>>2]|0;
      $422 = (($0) + ($421)|0);
      HEAP8[$422>>0] = 1;
      $423 = (($deepestInd) + 12|0);
      $424 = HEAP32[$423>>2]|0;
      $425 = (($0) + ($424)|0);
      HEAP8[$425>>0] = 1;
      $426 = $scevgep145;
      $427 = $426;
      HEAP32[$427>>2] = 0;
      $428 = (($426) + 4)|0;
      $429 = $428;
      HEAP32[$429>>2] = 0;
      $430 = (($separation) + 16|0);
      HEAPF32[$430>>2] = Math_fround(3.40282346638528859812E+38);
      $431 = (($separation) + 20|0);
      HEAPF32[$431>>2] = Math_fround(3.40282346638528859812E+38);
      $tmpPatch19$197 = HEAP32[$128>>2]|0;
      $432 = ($tmpPatch19$197|0)==(0|0);
      if (!($432)) {
       $tmpPatch19$198 = $tmpPatch19$197;
       while(1) {
        $433 = (($tmpPatch19$198) + 22|0);
        $434 = HEAP16[$433>>1]|0;
        $435 = ($434<<16>>16)==(0);
        if (!($435)) {
         $436 = (($tmpPatch19$198) + 20|0);
         $437 = HEAP16[$436>>1]|0;
         $438 = $437&65535;
         $439 = $434&65535;
         $b24$092 = 0;
         while(1) {
          $440 = (($438) + ($b24$092))|0;
          $441 = (($0) + ($440)|0);
          $442 = HEAP8[$441>>0]|0;
          $443 = ($442<<24>>24)==(0);
          L107: do {
           if ($443) {
            $444 = HEAP32[$1>>2]|0;
            $445 = ((($444) + ($440<<6)|0) + 12|0);
            $446 = Math_fround(HEAPF32[$445>>2]);
            $j$087 = 4;
            while(1) {
             $449 = (($separation) + ($j$087<<2)|0);
             $450 = Math_fround(HEAPF32[$449>>2]);
             $451 = $446 < $450;
             $448 = (($j$087) + 1)|0;
             if ($451) {
              break;
             }
             $447 = ($448>>>0)<(6);
             if ($447) {
              $j$087 = $448;
             } else {
              break L107;
             }
            }
            $452 = ($j$087>>>0)<(5);
            if ($452) {
             $k$088 = 5;
             while(1) {
              $453 = (($k$088) + -1)|0;
              $454 = (($separation) + ($453<<2)|0);
              $455 = Math_fround(HEAPF32[$454>>2]);
              $456 = (($separation) + ($k$088<<2)|0);
              HEAPF32[$456>>2] = $455;
              $457 = (($deepestInd) + ($453<<2)|0);
              $458 = HEAP32[$457>>2]|0;
              $459 = (($deepestInd) + ($k$088<<2)|0);
              HEAP32[$459>>2] = $458;
              $460 = ($453>>>0)>($j$087>>>0);
              if ($460) {
               $k$088 = $453;
              } else {
               break;
              }
             }
            }
            HEAPF32[$449>>2] = $446;
            $461 = (($deepestInd) + ($j$087<<2)|0);
            HEAP32[$461>>2] = $440;
           }
          } while(0);
          $462 = (($b24$092) + 1)|0;
          $463 = ($462>>>0)<($439>>>0);
          if ($463) {
           $b24$092 = $462;
          } else {
           break;
          }
         }
        }
        $464 = (($tmpPatch19$198) + 12|0);
        $tmpPatch19$1 = HEAP32[$464>>2]|0;
        $465 = ($tmpPatch19$1|0)==(0|0);
        if ($465) {
         break;
        } else {
         $tmpPatch19$198 = $tmpPatch19$1;
        }
       }
      }
      $scevgep150$sum = (($314) + 4)|0;
      $scevgep151 = ((($this) + ($scevgep150$sum<<2)|0) + 4|0);
      $466 = $scevgep145;
      $467 = $466;
      $468 = HEAP32[$467>>2]|0;
      $469 = (($466) + 4)|0;
      $470 = $469;
      $471 = HEAP32[$470>>2]|0;
      $472 = $scevgep151;
      $473 = $472;
      HEAP32[$473>>2] = $468;
      $474 = (($472) + 4)|0;
      $475 = $474;
      HEAP32[$475>>2] = $471;
      HEAP32[$137>>2] = 6;
      $numReducedPatches$1 = $136;
      break L34;
     }
    } while(0);
    HEAP32[$137>>2] = $contactCount$0$lcssa166167;
    $numReducedPatches$1 = $136;
   } else {
    $numReducedPatches$1 = $numReducedPatches$0112;
   }
  } while(0);
  $476 = (($a1$0111) + 1)|0;
  $477 = ($476>>>0)<($115>>>0);
  if ($477) {
   $a1$0111 = $476;$numReducedPatches$0112 = $numReducedPatches$1;
  } else {
   $numReducedPatches$0$lcssa = $numReducedPatches$1;
   label = 74;
   break;
  }
 }
 if ((label|0) == 74) {
  $479 = (($this) + 168|0);
  HEAP32[$479>>2] = $numReducedPatches$0$lcssa;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd4sortIPNS_15PxsContactPatchENS_27SortBoundsPredicateManifoldENS0_19ReflectionAllocatorIS3_EEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$phi$trans$insert$i$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = Math_fround(0), $$pre2$i$i = 0, $$pre3$i$i = Math_fround(0);
 var $$pre4$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0;
 var $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0;
 var $j$02$i = 0, $j$1$i = 0, $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$77 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($elements) + ($m$01$i<<2)|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = (($15) + 16|0);
       $19 = Math_fround(HEAPF32[$18>>2]);
       $20 = (($17) + 16|0);
       $21 = Math_fround(HEAPF32[$20>>2]);
       $22 = $19 < $21;
       $j$0$m$0$i = $22 ? $j$02$i : $m$01$i;
       $23 = (($j$02$i) + 1)|0;
       $24 = ($j$02$i|0)<($9|0);
       if ($24) {
        $j$02$i = $23;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $25 = (($elements) + ($j$0$m$0$i<<2)|0);
      $26 = (($elements) + ($i$03$i<<2)|0);
      $27 = HEAP32[$25>>2]|0;
      $28 = HEAP32[$26>>2]|0;
      HEAP32[$25>>2] = $28;
      HEAP32[$26>>2] = $27;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $132 = ($77|0)==(0);
    if ($132) {
     break L2;
    }
    $133 = (($77) + -1)|0;
    $134 = (($$ph16) + ($133<<2)|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($77) + -2)|0;
    $137 = (($$ph16) + ($136<<2)|0);
    $138 = HEAP32[$137>>2]|0;
    $10 = $138;$77 = $136;$9 = $135;
   }
   $29 = (($9) + ($10))|0;
   $30 = (($29|0) / 2)&-1;
   $31 = (($elements) + ($30<<2)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($elements) + ($10<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + 16|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = (($34) + 16|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = $36 < $38;
   if ($39) {
    HEAP32[$33>>2] = $32;
    HEAP32[$31>>2] = $34;
    $$pre$i$i = HEAP32[$33>>2]|0;
    $$phi$trans$insert$i$i = (($$pre$i$i) + 16|0);
    $$pre1$i$i = Math_fround(HEAPF32[$$phi$trans$insert$i$i>>2]);
    $$pre3$i$i = $$pre1$i$i;$148 = $34;$45 = $$pre$i$i;
   } else {
    $$pre3$i$i = $38;$148 = $32;$45 = $34;
   }
   $40 = (($elements) + ($9<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 16|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = $43 < $$pre3$i$i;
   if ($44) {
    HEAP32[$33>>2] = $41;
    HEAP32[$40>>2] = $45;
    $$pre2$i$i = HEAP32[$31>>2]|0;
    $47 = $$pre2$i$i;$50 = $$pre3$i$i;$51 = $45;
   } else {
    $47 = $148;$50 = $43;$51 = $41;
   }
   $46 = (($47) + 16|0);
   $48 = Math_fround(HEAPF32[$46>>2]);
   $49 = $50 < $48;
   if ($49) {
    HEAP32[$31>>2] = $51;
    HEAP32[$40>>2] = $47;
    $$pre4$i$i = HEAP32[$31>>2]|0;
    $55 = $$pre4$i$i;
   } else {
    $55 = $47;
   }
   $52 = (($9) + -1)|0;
   $53 = (($elements) + ($52<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$31>>2] = $54;
   HEAP32[$53>>2] = $55;
   $57 = $55;$i$0$ph$i = $10;$j$0$ph$i = $52;
   while(1) {
    $56 = (($57) + 16|0);
    $58 = Math_fround(HEAPF32[$56>>2]);
    $i$0$i = $i$0$ph$i;
    while(1) {
     $59 = (($i$0$i) + 1)|0;
     $60 = (($elements) + ($59<<2)|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($61) + 16|0);
     $63 = Math_fround(HEAPF32[$62>>2]);
     $64 = $63 < $58;
     if ($64) {
      $i$0$i = $59;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $65 = (($j$1$i) + -1)|0;
     $66 = (($elements) + ($65<<2)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($67) + 16|0);
     $69 = Math_fround(HEAPF32[$68>>2]);
     $70 = $58 < $69;
     if ($70) {
      $j$1$i = $65;
     } else {
      break;
     }
    }
    $71 = ($59|0)<($65|0);
    if (!($71)) {
     break;
    }
    HEAP32[$60>>2] = $67;
    HEAP32[$66>>2] = $61;
    $$pre$i1 = HEAP32[$53>>2]|0;
    $57 = $$pre$i1;$i$0$ph$i = $59;$j$0$ph$i = $65;
   }
   HEAP32[$60>>2] = $57;
   HEAP32[$53>>2] = $61;
   $72 = (($59) - ($10))|0;
   $73 = (($9) - ($59))|0;
   $74 = ($72|0)<($73|0);
   if ($74) {
    $75 = (($$ph17) + -1)|0;
    $76 = ($77>>>0)<($75>>>0);
    if ($76) {
     $101 = $$ph16;$149 = $$ph;$150 = $$ph17;
    } else {
     $78 = $$ph17 << 1;
     $79 = $$ph17 << 3;
     $80 = ($79|0)==(0);
     if ($80) {
      $92 = 0;
     } else {
      $81 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($82) + 8|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = (__Z15PxGetFoundationv()|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = (($86) + 24|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (FUNCTION_TABLE_ii[$88 & 4095]($85)|0);
      $$$i$i$i4 = $89 ? 493304 : 491832;
      $90 = (FUNCTION_TABLE_iiiiii[$84 & 255]($81,$79,$$$i$i$i4,493216,148)|0);
      $92 = $90;
     }
     $91 = $77 << 2;
     _memcpy(($92|0),($$ph16|0),($91|0))|0;
     $93 = ($$ph<<24>>24)==(0);
     $94 = ($$ph16|0)==(0|0);
     $or$cond = $93 | $94;
     if ($or$cond) {
      $101 = $92;$149 = 1;$150 = $78;
     } else {
      $95 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 12|0);
      $98 = HEAP32[$97>>2]|0;
      FUNCTION_TABLE_vii[$98 & 4095]($95,$$ph16);
      $101 = $92;$149 = 1;$150 = $78;
     }
    }
    $99 = (($77) + 1)|0;
    $100 = (($101) + ($77<<2)|0);
    HEAP32[$100>>2] = $10;
    $102 = (($101) + ($99<<2)|0);
    HEAP32[$102>>2] = $i$0$i;
    $103 = (($i$0$i) + 2)|0;
    $$ph$be = $149;$$ph16$be = $101;$$ph17$be = $150;$$ph19$be = $103;$$ph20$be = $9;
   } else {
    $104 = (($i$0$i) + 2)|0;
    $105 = (($$ph17) + -1)|0;
    $106 = ($77>>>0)<($105>>>0);
    if ($106) {
     $130 = $$ph16;$151 = $$ph;$152 = $$ph17;
    } else {
     $107 = $$ph17 << 1;
     $108 = $$ph17 << 3;
     $109 = ($108|0)==(0);
     if ($109) {
      $121 = 0;
     } else {
      $110 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = (($111) + 8|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = (__Z15PxGetFoundationv()|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = (($115) + 24|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = (FUNCTION_TABLE_ii[$117 & 4095]($114)|0);
      $$$i$i$i = $118 ? 493304 : 491832;
      $119 = (FUNCTION_TABLE_iiiiii[$113 & 255]($110,$108,$$$i$i$i,493216,148)|0);
      $121 = $119;
     }
     $120 = $77 << 2;
     _memcpy(($121|0),($$ph16|0),($120|0))|0;
     $122 = ($$ph<<24>>24)==(0);
     $123 = ($$ph16|0)==(0|0);
     $or$cond8 = $122 | $123;
     if ($or$cond8) {
      $130 = $121;$151 = 1;$152 = $107;
     } else {
      $124 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = (($125) + 12|0);
      $127 = HEAP32[$126>>2]|0;
      FUNCTION_TABLE_vii[$127 & 4095]($124,$$ph16);
      $130 = $121;$151 = 1;$152 = $107;
     }
    }
    $128 = (($77) + 1)|0;
    $129 = (($130) + ($77<<2)|0);
    HEAP32[$129>>2] = $104;
    $131 = (($130) + ($128<<2)|0);
    HEAP32[$131>>2] = $9;
    $$ph$be = $151;$$ph16$be = $130;$$ph17$be = $152;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($77) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $139 = ($$ph<<24>>24)==(0);
  $140 = ($$ph16|0)==(0|0);
  $or$cond9 = $139 | $140;
  if (!($or$cond9)) {
   $141 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = (($142) + 12|0);
   $144 = HEAP32[$143>>2]|0;
   FUNCTION_TABLE_vii[$144 & 4095]($141,$$ph16);
  }
 }
 $145 = HEAP8[$4>>0]|0;
 $146 = ($145<<24>>24)==(0);
 if ($146) {
  STACKTOP = sp;return;
 }
 $147 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$147);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_25PxsCompoundContactManagerENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 493472 : 491832;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,491752,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<5)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;HEAP32[$$012$i+24>>2]=HEAP32[$$03$i+24>>2]|0;HEAP32[$$012$i+28>>2]=HEAP32[$$03$i+28>>2]|0;
   }
   $20 = (($$012$i) + 32|0);
   $21 = (($$03$i) + 32|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPKNS_24PxsIndexedContactManagerENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 493616 : 491832;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,491752,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortINS_23PxcSolverConstraintDescENS_14ConstraintLessENS0_19ReflectionAllocatorIS2_EEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i3 = 0, $$ph = 0, $$ph$be = 0, $$ph10 = 0, $$ph10$be = 0, $$ph11 = 0, $$ph11$be = 0, $$ph12 = 0, $$ph12$be = 0, $$ph8 = 0, $$ph8$be = 0, $$ph9 = 0, $$ph9$be = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$02$i = 0, $m$01$i = 0, $or$cond = 0, $or$cond6 = 0, $or$cond7 = 0, $stackMem = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $tmp$i$i = sp + 136|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph10 = 0;$$ph11 = 0;$$ph12 = $6;$$ph8 = $5;$$ph9 = 32;
  L3: while(1) {
   $10 = $$ph11;$34 = $$ph10;$9 = $$ph12;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = ((($elements) + ($j$02$i<<5)|0) + 16|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($15) + 56|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = ((($elements) + ($m$01$i<<5)|0) + 16|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($19) + 56|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($17>>>0)>($21>>>0);
       $j$0$m$0$i = $22 ? $j$02$i : $m$01$i;
       $23 = (($j$02$i) + 1)|0;
       $24 = ($j$02$i|0)<($9|0);
       if ($24) {
        $j$02$i = $23;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $25 = (($elements) + ($j$0$m$0$i<<5)|0);
      $26 = (($elements) + ($i$03$i<<5)|0);
      ;HEAP32[$tmp$i$i+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$tmp$i$i+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$tmp$i$i+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$tmp$i$i+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$tmp$i$i+16>>2]=HEAP32[$25+16>>2]|0;HEAP32[$tmp$i$i+20>>2]=HEAP32[$25+20>>2]|0;HEAP32[$tmp$i$i+24>>2]=HEAP32[$25+24>>2]|0;HEAP32[$tmp$i$i+28>>2]=HEAP32[$25+28>>2]|0;
      ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$25+20>>2]=HEAP32[$26+20>>2]|0;HEAP32[$25+24>>2]=HEAP32[$26+24>>2]|0;HEAP32[$25+28>>2]=HEAP32[$26+28>>2]|0;
      ;HEAP32[$26+0>>2]=HEAP32[$tmp$i$i+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$tmp$i$i+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$tmp$i$i+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$tmp$i$i+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$tmp$i$i+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$tmp$i$i+20>>2]|0;HEAP32[$26+24>>2]=HEAP32[$tmp$i$i+24>>2]|0;HEAP32[$26+28>>2]=HEAP32[$tmp$i$i+28>>2]|0;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $90 = ($34|0)==(0);
    if ($90) {
     break L3;
    }
    $91 = (($34) + -1)|0;
    $92 = (($$ph8) + ($91<<2)|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($34) + -2)|0;
    $95 = (($$ph8) + ($94<<2)|0);
    $96 = HEAP32[$95>>2]|0;
    $10 = $96;$34 = $94;$9 = $93;
   }
   $27 = (__ZN5physx6shdfnd8internal9partitionINS_23PxcSolverConstraintDescEKNS_14ConstraintLessEEEiPT_iiRT0_($elements,$10,$9,$compare)|0);
   $28 = (($27) - ($10))|0;
   $29 = (($9) - ($27))|0;
   $30 = ($28|0)<($29|0);
   if ($30) {
    $31 = (($27) + -1)|0;
    $32 = (($$ph9) + -1)|0;
    $33 = ($34>>>0)<($32>>>0);
    if ($33) {
     $106 = $$ph;$107 = $$ph9;$58 = $$ph8;
    } else {
     $35 = $$ph9 << 1;
     $36 = $$ph9 << 3;
     $37 = ($36|0)==(0);
     if ($37) {
      $49 = 0;
     } else {
      $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = (($39) + 8|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (__Z15PxGetFoundationv()|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = (($43) + 24|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = (FUNCTION_TABLE_ii[$45 & 4095]($42)|0);
      $$$i$i$i3 = $46 ? 491864 : 491832;
      $47 = (FUNCTION_TABLE_iiiiii[$41 & 255]($38,$36,$$$i$i$i3,493216,148)|0);
      $49 = $47;
     }
     $48 = $34 << 2;
     _memcpy(($49|0),($$ph8|0),($48|0))|0;
     $50 = ($$ph<<24>>24)==(0);
     $51 = ($$ph8|0)==(0|0);
     $or$cond = $50 | $51;
     if ($or$cond) {
      $106 = 1;$107 = $35;$58 = $49;
     } else {
      $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (($53) + 12|0);
      $55 = HEAP32[$54>>2]|0;
      FUNCTION_TABLE_vii[$55 & 4095]($52,$$ph8);
      $106 = 1;$107 = $35;$58 = $49;
     }
    }
    $56 = (($34) + 1)|0;
    $57 = (($58) + ($34<<2)|0);
    HEAP32[$57>>2] = $10;
    $59 = (($58) + ($56<<2)|0);
    HEAP32[$59>>2] = $31;
    $60 = (($27) + 1)|0;
    $$ph$be = $106;$$ph11$be = $60;$$ph12$be = $9;$$ph8$be = $58;$$ph9$be = $107;
   } else {
    $61 = (($27) + 1)|0;
    $62 = (($$ph9) + -1)|0;
    $63 = ($34>>>0)<($62>>>0);
    if ($63) {
     $108 = $$ph;$109 = $$ph9;$87 = $$ph8;
    } else {
     $64 = $$ph9 << 1;
     $65 = $$ph9 << 3;
     $66 = ($65|0)==(0);
     if ($66) {
      $78 = 0;
     } else {
      $67 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (($68) + 8|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = (__Z15PxGetFoundationv()|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($72) + 24|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = (FUNCTION_TABLE_ii[$74 & 4095]($71)|0);
      $$$i$i$i = $75 ? 491864 : 491832;
      $76 = (FUNCTION_TABLE_iiiiii[$70 & 255]($67,$65,$$$i$i$i,493216,148)|0);
      $78 = $76;
     }
     $77 = $34 << 2;
     _memcpy(($78|0),($$ph8|0),($77|0))|0;
     $79 = ($$ph<<24>>24)==(0);
     $80 = ($$ph8|0)==(0|0);
     $or$cond6 = $79 | $80;
     if ($or$cond6) {
      $108 = 1;$109 = $64;$87 = $78;
     } else {
      $81 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($82) + 12|0);
      $84 = HEAP32[$83>>2]|0;
      FUNCTION_TABLE_vii[$84 & 4095]($81,$$ph8);
      $108 = 1;$109 = $64;$87 = $78;
     }
    }
    $85 = (($34) + 1)|0;
    $86 = (($87) + ($34<<2)|0);
    HEAP32[$86>>2] = $61;
    $88 = (($87) + ($85<<2)|0);
    HEAP32[$88>>2] = $9;
    $89 = (($27) + -1)|0;
    $$ph$be = $108;$$ph11$be = $10;$$ph12$be = $89;$$ph8$be = $87;$$ph9$be = $109;
   }
   $$ph10$be = (($34) + 2)|0;
   $$ph = $$ph$be;$$ph10 = $$ph10$be;$$ph11 = $$ph11$be;$$ph12 = $$ph12$be;$$ph8 = $$ph8$be;$$ph9 = $$ph9$be;
  }
  $97 = ($$ph<<24>>24)==(0);
  $98 = ($$ph8|0)==(0|0);
  $or$cond7 = $97 | $98;
  if (!($or$cond7)) {
   $99 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($100) + 12|0);
   $102 = HEAP32[$101>>2]|0;
   FUNCTION_TABLE_vii[$102 & 4095]($99,$$ph8);
  }
 }
 $103 = HEAP8[$4>>0]|0;
 $104 = ($103<<24>>24)==(0);
 if ($104) {
  STACKTOP = sp;return;
 }
 $105 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$105);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal9partitionINS_23PxcSolverConstraintDescEKNS_14ConstraintLessEEEiPT_iiRT0_($elements,$first,$last,$compare) {
 $elements = $elements|0;
 $first = $first|0;
 $last = $last|0;
 $compare = $compare|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert7$i = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$0$ph = 0, $j$0$ph = 0, $j$1 = 0, $tmp$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmp$i1 = sp;
 $0 = (($last) + ($first))|0;
 $1 = (($0|0) / 2)&-1;
 $2 = (($elements) + ($1<<5)|0);
 $3 = (($elements) + ($first<<5)|0);
 $4 = ((($elements) + ($1<<5)|0) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($elements) + ($first<<5)|0) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 56|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($7>>>0)>($11>>>0);
 if ($12) {
  ;HEAP32[$tmp$i1+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmp$i1+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$tmp$i1+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$tmp$i1+20>>2]=HEAP32[$3+20>>2]|0;HEAP32[$tmp$i1+24>>2]=HEAP32[$3+24>>2]|0;HEAP32[$tmp$i1+28>>2]=HEAP32[$3+28>>2]|0;
  ;HEAP32[$3+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$2+20>>2]|0;HEAP32[$3+24>>2]=HEAP32[$2+24>>2]|0;HEAP32[$3+28>>2]=HEAP32[$2+28>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$tmp$i1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$tmp$i1+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$tmp$i1+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$tmp$i1+20>>2]|0;HEAP32[$2+24>>2]=HEAP32[$tmp$i1+24>>2]|0;HEAP32[$2+28>>2]=HEAP32[$tmp$i1+28>>2]|0;
  $$pre$i = HEAP32[$8>>2]|0;
  $$phi$trans$insert$i = (($$pre$i) + 56|0);
  $$pre5$i = HEAP32[$$phi$trans$insert$i>>2]|0;
  $19 = $$pre5$i;
 } else {
  $19 = $11;
 }
 $13 = (($elements) + ($last<<5)|0);
 $14 = ((($elements) + ($last<<5)|0) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17>>>0)>($19>>>0);
 if ($18) {
  ;HEAP32[$tmp$i1+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmp$i1+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$tmp$i1+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$tmp$i1+20>>2]=HEAP32[$3+20>>2]|0;HEAP32[$tmp$i1+24>>2]=HEAP32[$3+24>>2]|0;HEAP32[$tmp$i1+28>>2]=HEAP32[$3+28>>2]|0;
  ;HEAP32[$3+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$13+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$13+20>>2]|0;HEAP32[$3+24>>2]=HEAP32[$13+24>>2]|0;HEAP32[$3+28>>2]=HEAP32[$13+28>>2]|0;
  ;HEAP32[$13+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$tmp$i1+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$tmp$i1+12>>2]|0;HEAP32[$13+16>>2]=HEAP32[$tmp$i1+16>>2]|0;HEAP32[$13+20>>2]=HEAP32[$tmp$i1+20>>2]|0;HEAP32[$13+24>>2]=HEAP32[$tmp$i1+24>>2]|0;HEAP32[$13+28>>2]=HEAP32[$tmp$i1+28>>2]|0;
  $$pre6$i = HEAP32[$14>>2]|0;
  $$phi$trans$insert7$i = (($$pre6$i) + 56|0);
  $$pre9$i = HEAP32[$$phi$trans$insert7$i>>2]|0;
  $24 = $$pre9$i;
 } else {
  $24 = $17;
 }
 $20 = HEAP32[$4>>2]|0;
 $21 = (($20) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($24>>>0)>($22>>>0);
 if ($23) {
  ;HEAP32[$tmp$i1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$tmp$i1+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$tmp$i1+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$tmp$i1+20>>2]=HEAP32[$2+20>>2]|0;HEAP32[$tmp$i1+24>>2]=HEAP32[$2+24>>2]|0;HEAP32[$tmp$i1+28>>2]=HEAP32[$2+28>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$13+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$13+20>>2]|0;HEAP32[$2+24>>2]=HEAP32[$13+24>>2]|0;HEAP32[$2+28>>2]=HEAP32[$13+28>>2]|0;
  ;HEAP32[$13+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$tmp$i1+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$tmp$i1+12>>2]|0;HEAP32[$13+16>>2]=HEAP32[$tmp$i1+16>>2]|0;HEAP32[$13+20>>2]=HEAP32[$tmp$i1+20>>2]|0;HEAP32[$13+24>>2]=HEAP32[$tmp$i1+24>>2]|0;HEAP32[$13+28>>2]=HEAP32[$tmp$i1+28>>2]|0;
  $$pre$phi$iZ2D = $2;
 } else {
  $$pre$phi$iZ2D = $2;
 }
 $25 = (($last) + -1)|0;
 $26 = (($elements) + ($25<<5)|0);
 ;HEAP32[$tmp$i1+0>>2]=HEAP32[$$pre$phi$iZ2D+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$$pre$phi$iZ2D+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$$pre$phi$iZ2D+8>>2]|0;HEAP32[$tmp$i1+12>>2]=HEAP32[$$pre$phi$iZ2D+12>>2]|0;HEAP32[$tmp$i1+16>>2]=HEAP32[$$pre$phi$iZ2D+16>>2]|0;HEAP32[$tmp$i1+20>>2]=HEAP32[$$pre$phi$iZ2D+20>>2]|0;HEAP32[$tmp$i1+24>>2]=HEAP32[$$pre$phi$iZ2D+24>>2]|0;HEAP32[$tmp$i1+28>>2]=HEAP32[$$pre$phi$iZ2D+28>>2]|0;
 ;HEAP32[$$pre$phi$iZ2D+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$$pre$phi$iZ2D+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$$pre$phi$iZ2D+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$$pre$phi$iZ2D+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$$pre$phi$iZ2D+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$$pre$phi$iZ2D+20>>2]=HEAP32[$26+20>>2]|0;HEAP32[$$pre$phi$iZ2D+24>>2]=HEAP32[$26+24>>2]|0;HEAP32[$$pre$phi$iZ2D+28>>2]=HEAP32[$26+28>>2]|0;
 ;HEAP32[$26+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$tmp$i1+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$tmp$i1+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$tmp$i1+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$tmp$i1+20>>2]|0;HEAP32[$26+24>>2]=HEAP32[$tmp$i1+24>>2]|0;HEAP32[$26+28>>2]=HEAP32[$tmp$i1+28>>2]|0;
 $27 = ((($elements) + ($25<<5)|0) + 16|0);
 $i$0$ph = $first;$j$0$ph = $25;
 while(1) {
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 56|0);
  $30 = HEAP32[$29>>2]|0;
  $i$0 = $i$0$ph;
  while(1) {
   $31 = (($i$0) + 1)|0;
   $32 = (($elements) + ($31<<5)|0);
   $33 = ((($elements) + ($31<<5)|0) + 16|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + 56|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36>>>0)>($30>>>0);
   if ($37) {
    $i$0 = $31;
   } else {
    $j$1 = $j$0$ph;
    break;
   }
  }
  while(1) {
   $38 = (($j$1) + -1)|0;
   $39 = (($elements) + ($38<<5)|0);
   $40 = ((($elements) + ($38<<5)|0) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 56|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($30>>>0)>($43>>>0);
   if ($44) {
    $j$1 = $38;
   } else {
    break;
   }
  }
  $45 = ($31|0)<($38|0);
  if (!($45)) {
   break;
  }
  ;HEAP32[$tmp$i1+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$tmp$i1+12>>2]=HEAP32[$32+12>>2]|0;HEAP32[$tmp$i1+16>>2]=HEAP32[$32+16>>2]|0;HEAP32[$tmp$i1+20>>2]=HEAP32[$32+20>>2]|0;HEAP32[$tmp$i1+24>>2]=HEAP32[$32+24>>2]|0;HEAP32[$tmp$i1+28>>2]=HEAP32[$32+28>>2]|0;
  ;HEAP32[$32+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$39+12>>2]|0;HEAP32[$32+16>>2]=HEAP32[$39+16>>2]|0;HEAP32[$32+20>>2]=HEAP32[$39+20>>2]|0;HEAP32[$32+24>>2]=HEAP32[$39+24>>2]|0;HEAP32[$32+28>>2]=HEAP32[$39+28>>2]|0;
  ;HEAP32[$39+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$tmp$i1+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$tmp$i1+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$tmp$i1+16>>2]|0;HEAP32[$39+20>>2]=HEAP32[$tmp$i1+20>>2]|0;HEAP32[$39+24>>2]=HEAP32[$tmp$i1+24>>2]|0;HEAP32[$39+28>>2]=HEAP32[$tmp$i1+28>>2]|0;
  $i$0$ph = $31;$j$0$ph = $38;
 }
 ;HEAP32[$tmp$i1+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$tmp$i1+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$tmp$i1+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$tmp$i1+12>>2]=HEAP32[$32+12>>2]|0;HEAP32[$tmp$i1+16>>2]=HEAP32[$32+16>>2]|0;HEAP32[$tmp$i1+20>>2]=HEAP32[$32+20>>2]|0;HEAP32[$tmp$i1+24>>2]=HEAP32[$32+24>>2]|0;HEAP32[$tmp$i1+28>>2]=HEAP32[$32+28>>2]|0;
 ;HEAP32[$32+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$32+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$32+20>>2]=HEAP32[$26+20>>2]|0;HEAP32[$32+24>>2]=HEAP32[$26+24>>2]|0;HEAP32[$32+28>>2]=HEAP32[$26+28>>2]|0;
 ;HEAP32[$26+0>>2]=HEAP32[$tmp$i1+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$tmp$i1+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$tmp$i1+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$tmp$i1+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$tmp$i1+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$tmp$i1+20>>2]|0;HEAP32[$26+24>>2]=HEAP32[$tmp$i1+24>>2]|0;HEAP32[$26+28>>2]=HEAP32[$tmp$i1+28>>2]|0;
 STACKTOP = sp;return ($31|0);
}
function __ZN5physx17collisionResponseERNS_19PxsParticleCollDataEbbRNS_27PxsFluidCollisionParametersE($collData,$twoWay,$isStatic,$params) {
 $collData = $collData|0;
 $twoWay = $twoWay|0;
 $isStatic = $isStatic|0;
 $params = $params|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0;
 var $97 = Math_fround(0), $98 = 0, $99 = 0, $newVel = 0, $surfaceNormal = 0, $surfaceVel = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $surfaceNormal = sp + 24|0;
 $surfaceVel = sp;
 $newVel = sp + 12|0;
 $0 = (($collData) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 $4 = $1 & 1;
 $5 = ($4|0)==(0);
 $6 = Math_fround(HEAPF32[$collData>>2]);
 HEAPF32[$surfaceNormal>>2] = $6;
 $7 = (($surfaceNormal) + 4|0);
 $8 = (($collData) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($surfaceNormal) + 8|0);
 $11 = (($collData) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$10>>2] = $12;
 if ($isStatic) {
  HEAPF32[$surfaceVel>>2] = Math_fround(0.0);
  $13 = (($surfaceVel) + 4|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = (($surfaceVel) + 8|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
 } else {
  $15 = (($collData) + 32|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$surfaceVel>>2] = $16;
  $17 = (($surfaceVel) + 4|0);
  $18 = (($collData) + 36|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$17>>2] = $19;
  $20 = (($surfaceVel) + 8|0);
  $21 = (($collData) + 40|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$20>>2] = $22;
 }
 if ($3) {
  if ($5) {
   STACKTOP = sp;return;
  }
  $32 = (($collData) + 28|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = $33 < Math_fround(3.0);
  if ($34) {
   $35 = Math_fround($33 + Math_fround(-1.5));
   $36 = $35 >= Math_fround(0.0);
   $37 = $36 ? Math_fround(0.5) : Math_fround(1.0);
   $$0$i = $37;
  } else {
   $38 = Math_fround(Math_fround(1.0) / $33);
   $$0$i = $38;
  }
  $39 = (($collData) + 16|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($$0$i * $40);
  $42 = (($collData) + 20|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($$0$i * $43);
  $45 = (($collData) + 24|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($$0$i * $46);
  $48 = (($collData) + 64|0);
  HEAPF32[$48>>2] = $41;
  $49 = (($collData) + 68|0);
  HEAPF32[$49>>2] = $44;
  $50 = (($collData) + 72|0);
  HEAPF32[$50>>2] = $47;
  $51 = (($collData) + 32|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = Math_fround($$0$i * $52);
  $54 = (($collData) + 36|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($$0$i * $55);
  $57 = (($collData) + 40|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($$0$i * $58);
  HEAPF32[$surfaceVel>>2] = $53;
  $60 = (($surfaceVel) + 4|0);
  HEAPF32[$60>>2] = $56;
  $61 = (($surfaceVel) + 8|0);
  HEAPF32[$61>>2] = $59;
  HEAPF32[$51>>2] = $53;
  HEAPF32[$54>>2] = $56;
  HEAPF32[$57>>2] = $59;
  $62 = $$0$i == Math_fround(1.0);
  if (!($62)) {
   $63 = Math_fround($6 * $6);
   $64 = Math_fround($9 * $9);
   $65 = Math_fround($63 + $64);
   $66 = Math_fround($12 * $12);
   $67 = Math_fround($65 + $66);
   $68 = (Math_fround(Math_sqrt((Math_fround($67)))));
   $69 = Math_fround(Math_fround(1.0) / $68);
   $70 = Math_fround($6 * $69);
   $71 = Math_fround($9 * $69);
   $72 = Math_fround($12 * $69);
   HEAPF32[$surfaceNormal>>2] = $70;
   HEAPF32[$7>>2] = $71;
   HEAPF32[$10>>2] = $72;
   HEAPF32[$collData>>2] = $70;
   HEAPF32[$8>>2] = $71;
   HEAPF32[$11>>2] = $72;
  }
  HEAPF32[$32>>2] = Math_fround(0.0);
 } else {
  $23 = (($collData) + 16|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($collData) + 64|0);
  HEAPF32[$25>>2] = $24;
  $26 = (($collData) + 20|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($collData) + 68|0);
  HEAPF32[$28>>2] = $27;
  $29 = (($collData) + 24|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($collData) + 72|0);
  HEAPF32[$31>>2] = $30;
 }
 $73 = (($collData) + 80|0);
 $74 = (($collData) + 76|0);
 $75 = HEAP32[$74>>2]|0;
 __ZN5physx15reflectVelocityERNS_6PxVec3ERKS0_S3_S3_S3_jRKNS_27PxsFluidCollisionParametersE($newVel,$73,$73,$surfaceNormal,$surfaceVel,$75,$params);
 if ($twoWay) {
  $76 = (($collData) + 108|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ($77|0)==(0|0);
  if (!($78)) {
   $79 = Math_fround(HEAPF32[$73>>2]);
   $80 = Math_fround(HEAPF32[$newVel>>2]);
   $81 = Math_fround($79 - $80);
   $82 = (($collData) + 84|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = (($newVel) + 4|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = Math_fround($83 - $85);
   $87 = (($collData) + 88|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = (($newVel) + 8|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = Math_fround($88 - $90);
   $92 = (($collData) + 96|0);
   HEAPF32[$92>>2] = $81;
   $93 = (($collData) + 100|0);
   HEAPF32[$93>>2] = $86;
   $94 = (($collData) + 104|0);
   HEAPF32[$94>>2] = $91;
  }
 }
 $95 = Math_fround(HEAPF32[$newVel>>2]);
 HEAPF32[$73>>2] = $95;
 $96 = (($newVel) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($collData) + 84|0);
 HEAPF32[$98>>2] = $97;
 $99 = (($newVel) + 8|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($collData) + 88|0);
 HEAPF32[$101>>2] = $100;
 STACKTOP = sp;return;
}
function __ZN5physx15reflectVelocityERNS_6PxVec3ERKS0_S3_S3_S3_jRKNS_27PxsFluidCollisionParametersE($reflectedVel,$inVel,$oldVel,$surfaceNormal,$surfaceVel,$particleIndex,$params) {
 $reflectedVel = $reflectedVel|0;
 $inVel = $inVel|0;
 $oldVel = $oldVel|0;
 $surfaceNormal = $surfaceNormal|0;
 $surfaceVel = $surfaceVel|0;
 $particleIndex = $particleIndex|0;
 $params = $params|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inVel>>2]);
 $1 = Math_fround(HEAPF32[$surfaceVel>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($inVel) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($surfaceVel) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($inVel) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($surfaceVel) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$surfaceNormal>>2]);
 $14 = Math_fround($2 * $13);
 $15 = (($surfaceNormal) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($surfaceNormal) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($12 * $20);
 $22 = Math_fround($18 + $21);
 $23 = $22 < Math_fround(0.0);
 if ($23) {
  $24 = (($params) + 20|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($params) + 24|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($params) + 16|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($13 * $22);
  $31 = Math_fround($16 * $22);
  $32 = Math_fround($20 * $22);
  $33 = Math_fround($2 - $30);
  $34 = Math_fround($7 - $31);
  $35 = Math_fround($12 - $32);
  $36 = Math_fround(HEAPF32[$oldVel>>2]);
  $37 = Math_fround($36 - $1);
  $38 = (($oldVel) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($39 - $6);
  $41 = (($oldVel) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($42 - $11);
  $44 = Math_fround($13 * $37);
  $45 = Math_fround($16 * $40);
  $46 = Math_fround($44 + $45);
  $47 = Math_fround($20 * $43);
  $48 = Math_fround($46 + $47);
  $49 = Math_fround($13 * $48);
  $50 = Math_fround($16 * $48);
  $51 = Math_fround($20 * $48);
  $52 = Math_fround($30 - $49);
  $53 = Math_fround($31 - $50);
  $54 = Math_fround($32 - $51);
  $55 = Math_fround($52 * $52);
  $56 = Math_fround($53 * $53);
  $57 = Math_fround($55 + $56);
  $58 = Math_fround($54 * $54);
  $59 = Math_fround($58 + $57);
  $60 = Math_fround($27 * $59);
  $61 = Math_fround($33 * $33);
  $62 = Math_fround($34 * $34);
  $63 = Math_fround($61 + $62);
  $64 = Math_fround($35 * $35);
  $65 = Math_fround($64 + $63);
  $66 = Math_fround($65 - $60);
  $67 = $66 >= Math_fround(0.0);
  $68 = $67 ? $33 : Math_fround(0.0);
  $69 = $67 ? $34 : Math_fround(0.0);
  $70 = $67 ? $35 : Math_fround(0.0);
  $71 = Math_fround(Math_fround(1.0) - $25);
  $72 = Math_fround($71 * $68);
  $73 = Math_fround($71 * $69);
  $74 = Math_fround($71 * $70);
  $75 = (($reflectedVel) + 4|0);
  $76 = (($reflectedVel) + 8|0);
  $77 = Math_fround($29 * $49);
  $78 = Math_fround($29 * $50);
  $79 = Math_fround($29 * $51);
  $80 = Math_fround($72 - $77);
  $81 = Math_fround($73 - $78);
  $82 = Math_fround($74 - $79);
  $83 = $48 >= Math_fround(0.0);
  $84 = $83 ? $72 : $80;
  HEAPF32[$reflectedVel>>2] = $84;
  $85 = $83 ? $73 : $81;
  HEAPF32[$75>>2] = $85;
  $86 = $83 ? $74 : $82;
  HEAPF32[$76>>2] = $86;
  $87 = Math_fround(HEAPF32[$surfaceVel>>2]);
  $88 = Math_fround($87 + $84);
  HEAPF32[$reflectedVel>>2] = $88;
  $89 = Math_fround(HEAPF32[$5>>2]);
  $90 = Math_fround($89 + $85);
  HEAPF32[$75>>2] = $90;
  $91 = Math_fround(HEAPF32[$10>>2]);
  $92 = Math_fround($91 + $86);
  HEAPF32[$76>>2] = $92;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$reflectedVel>>2] = $0;
  $93 = Math_fround(HEAPF32[$3>>2]);
  $94 = (($reflectedVel) + 4|0);
  HEAPF32[$94>>2] = $93;
  $95 = Math_fround(HEAPF32[$8>>2]);
  $96 = (($reflectedVel) + 8|0);
  HEAPF32[$96>>2] = $95;
  STACKTOP = sp;return;
 }
}
function __ZN5physx17PxsFluidCollisionC2ERNS_20PxsParticleSystemSimE($this,$particleSystem) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 HEAP32[$0>>2] = $particleSystem;
 $1 = (($this) + 100|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 104|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 108|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 144|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 148|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 152|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 188|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 192|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 196|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 232|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 236|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 240|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 276|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 280|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 284|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 320|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 324|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 328|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 364|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 368|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 372|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 408|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 412|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 416|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 452|0);
 $26 = (($this) + 456|0);
 HEAP16[$26>>1] = -1;
 $27 = (($this) + 458|0);
 HEAP16[$27>>1] = 0;
 $28 = (($this) + 460|0);
 HEAP32[$28>>2] = 0;
 HEAP32[$25>>2] = ((434896 + 8|0));
 $29 = (($this) + 464|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 468|0);
 HEAP32[$30>>2] = 0;
 HEAP32[$25>>2] = ((493920 + 8|0));
 $31 = (($this) + 472|0);
 HEAP32[$31>>2] = $this;
 $32 = (($this) + 476|0);
 HEAP32[$32>>2] = 493792;
 STACKTOP = sp;return;
}
function __ZN5physx17PxsFluidCollisionD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 452|0);
 HEAP32[$0>>2] = ((434896 + 8|0));
 $1 = (($this) + 460|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 100|0);
 $3 = (($this) + 452|0);
 $5 = $3;
 while(1) {
  $4 = (($5) + -44|0);
  $6 = (($5) + -36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & 2147483647;
  $9 = ($8|0)!=(0);
  $10 = ($7|0)>(-1);
  $or$cond$i$i$i$i = $9 & $10;
  if ($or$cond$i$i$i$i) {
   $11 = HEAP32[$4>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    $13 = (($11) + -4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (0 - ($14))|0;
    $16 = (($11) + ($15)|0);
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($19) + 12|0);
     $21 = HEAP32[$20>>2]|0;
     FUNCTION_TABLE_vii[$21 & 4095]($18,$16);
    }
   }
  }
  $22 = ($4|0)==($2|0);
  if ($22) {
   break;
  } else {
   $5 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_17PxsFluidCollisionEXadL_ZNS2_12mergeResultsEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx17PxsFluidCollision15updateCollisionEPKhRNS_10PxBaseTaskE($this,$contactManagerStream,$continuation) {
 $this = $this|0;
 $contactManagerStream = $contactManagerStream|0;
 $continuation = $continuation|0;
 var $$lcssa14 = 0, $$sum1 = 0, $$targetParticleCountPerTask$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $currentParticleCount$04 = 0, $exitcond = 0, $exitcond13 = 0, $i$08 = 0, $i1$02 = 0, $numTasks$09 = 0, $numTasks$1 = 0, $or$cond = 0, $or$cond3 = 0, $phitmp = 0, $targetParticleCountPerTask$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 452|0);
 $1 = (($this) + 468|0);
 HEAP32[$1>>2] = 1;
 $2 = (($this) + 464|0);
 HEAP32[$2>>2] = $continuation;
 $3 = ($continuation|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$continuation>>2]|0;
  $5 = (($4) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($continuation);
  $7 = HEAP32[$2>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 460|0);
  HEAP32[$10>>2] = $9;
 }
 $11 = (($this) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 >>> 3;
 $16 = ($15>>>0)<(128);
 $17 = $16 ? 128 : $15;
 $18 = (($contactManagerStream) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($contactManagerStream) + 8|0);
 $21 = (($contactManagerStream) + ($19)|0);
 $32 = $20;$i$08 = 0;$numTasks$09 = 0;$targetParticleCountPerTask$010 = $17;
 while(1) {
  $23 = ((($this) + (($i$08*44)|0)|0) + 120|0);
  HEAPF32[$23>>2] = Math_fround(8.50705866596322149529E+37);
  $24 = ((($this) + (($i$08*44)|0)|0) + 124|0);
  HEAPF32[$24>>2] = Math_fround(8.50705866596322149529E+37);
  $25 = ((($this) + (($i$08*44)|0)|0) + 128|0);
  HEAPF32[$25>>2] = Math_fround(8.50705866596322149529E+37);
  $26 = ((($this) + (($i$08*44)|0)|0) + 132|0);
  HEAPF32[$26>>2] = Math_fround(-8.50705866596322149529E+37);
  $27 = ((($this) + (($i$08*44)|0)|0) + 136|0);
  HEAPF32[$27>>2] = Math_fround(-8.50705866596322149529E+37);
  $28 = ((($this) + (($i$08*44)|0)|0) + 140|0);
  HEAPF32[$28>>2] = Math_fround(-8.50705866596322149529E+37);
  $29 = ($i$08|0)==(7);
  $$targetParticleCountPerTask$0 = $29 ? -1 : $targetParticleCountPerTask$010;
  $30 = ($$targetParticleCountPerTask$0|0)!=(0);
  $31 = ($32|0)!=($21|0);
  $or$cond3 = $30 & $31;
  if ($or$cond3) {
   $34 = $32;$currentParticleCount$04 = 0;
   while(1) {
    $33 = (($34) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = HEAP32[$33>>2]|0;
    $37 = $36 << 4;
    $$sum1 = $37 | 8;
    $38 = (($34) + ($$sum1)|0);
    $39 = (($35) + 44|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($40) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + ($currentParticleCount$04))|0;
    $44 = ($43>>>0)<($$targetParticleCountPerTask$0>>>0);
    $45 = ($38|0)!=($21|0);
    $or$cond = $44 & $45;
    if ($or$cond) {
     $34 = $38;$currentParticleCount$04 = $43;
    } else {
     break;
    }
   }
   $phitmp = ($43|0)==(0);
   if ($phitmp) {
    $$lcssa14 = $38;$numTasks$1 = $numTasks$09;
   } else {
    $46 = ((($this) + (($i$08*44)|0)|0) + 112|0);
    HEAP32[$46>>2] = $32;
    $47 = ((($this) + (($i$08*44)|0)|0) + 116|0);
    HEAP32[$47>>2] = $38;
    $48 = (($numTasks$09) + 1)|0;
    $$lcssa14 = $38;$numTasks$1 = $48;
   }
  } else {
   $$lcssa14 = $32;$numTasks$1 = $numTasks$09;
  }
  $49 = (($i$08) + 1)|0;
  $exitcond13 = ($49|0)==(8);
  if ($exitcond13) {
   break;
  } else {
   $32 = $$lcssa14;$i$08 = $49;$numTasks$09 = $numTasks$1;$targetParticleCountPerTask$010 = $$targetParticleCountPerTask$0;
  }
 }
 $22 = ($numTasks$1|0)==(0);
 if ($22) {
  $80 = HEAP32[$0>>2]|0;
  $81 = (($80) + 20|0);
  $82 = HEAP32[$81>>2]|0;
  FUNCTION_TABLE_vi[$82 & 4095]($0);
  STACKTOP = sp;return;
 }
 $i1$02 = 0;
 while(1) {
  $50 = HEAP32[$11>>2]|0;
  $51 = (($50) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + 6732|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($55);
  $56 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($54,28,16)|0);
  $57 = HEAP32[$54>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($57);
  $58 = ($56|0)==(0|0);
  if ($58) {
   $67 = 0;
  } else {
   $59 = (($56) + 4|0);
   HEAP16[$59>>1] = -1;
   $60 = (($56) + 6|0);
   HEAP16[$60>>1] = 0;
   $61 = (($56) + 8|0);
   HEAP32[$61>>2] = 0;
   HEAP32[$56>>2] = ((434896 + 8|0));
   $62 = (($56) + 12|0);
   HEAP32[$62>>2] = 0;
   $63 = (($56) + 16|0);
   HEAP32[$63>>2] = 0;
   HEAP32[$56>>2] = ((494208 + 8|0));
   $64 = (($56) + 20|0);
   HEAP32[$64>>2] = $this;
   $65 = (($56) + 24|0);
   HEAP32[$65>>2] = $i1$02;
   $67 = $56;
  }
  $66 = (($67) + 16|0);
  HEAP32[$66>>2] = 1;
  $68 = (($67) + 12|0);
  HEAP32[$68>>2] = $0;
  $69 = HEAP32[$0>>2]|0;
  $70 = (($69) + 16|0);
  $71 = HEAP32[$70>>2]|0;
  FUNCTION_TABLE_vi[$71 & 4095]($0);
  $72 = HEAP32[$68>>2]|0;
  $73 = (($72) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($67) + 8|0);
  HEAP32[$75>>2] = $74;
  $76 = HEAP32[$67>>2]|0;
  $77 = (($76) + 20|0);
  $78 = HEAP32[$77>>2]|0;
  FUNCTION_TABLE_vi[$78 & 4095]($67);
  $79 = (($i1$02) + 1)|0;
  $exitcond = ($79|0)==($numTasks$1|0);
  if ($exitcond) {
   break;
  } else {
   $i1$02 = $79;
  }
 }
 $80 = HEAP32[$0>>2]|0;
 $81 = (($80) + 20|0);
 $82 = HEAP32[$81>>2]|0;
 FUNCTION_TABLE_vi[$82 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZN5physx17PxsFluidCollision26processShapeListWithFilterEjj($this,$taskDataIndex,$skipNum) {
 $this = $this|0;
 $taskDataIndex = $taskDataIndex|0;
 $skipNum = $skipNum|0;
 var $$pre = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $streamShape = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $streamShape = sp;
 $0 = ((($this) + (($taskDataIndex*44)|0)|0) + 100|0);
 $1 = ((($this) + (($taskDataIndex*44)|0)|0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($this) + (($taskDataIndex*44)|0)|0) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($streamShape) + 4|0);
 $7 = (($streamShape) + 8|0);
 $8 = ((($this) + (($taskDataIndex*44)|0)|0) + 104|0);
 $9 = (($this) + 96|0);
 $10 = ((($this) + (($taskDataIndex*44)|0)|0) + 120|0);
 $12 = $2;$44 = $4;
 while(1) {
  $11 = (($12) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$streamShape>>2] = $13;
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$6>>2] = $14;
  $15 = (($12) + 8|0);
  HEAP32[$7>>2] = $15;
  $16 = $14 << 4;
  $$sum1 = $16 | 8;
  $17 = (($12) + ($$sum1)|0);
  $18 = ($14>>>0)<($skipNum>>>0);
  if ($18) {
   $43 = $44;
  } else {
   HEAP32[$8>>2] = 0;
   $19 = ($14|0)==(0);
   if (!($19)) {
    $i$02 = 0;
    while(1) {
     $20 = (($15) + ($i$02<<4)|0);
     __ZN5physx17PxsFluidCollision19addTempW2STransformERNS0_8TaskDataERKNS_31PxsParticleStreamContactManagerE(0,$0,$20);
     $21 = (($i$02) + 1)|0;
     $22 = ($21>>>0)<($14>>>0);
     if ($22) {
      $i$02 = $21;
     } else {
      break;
     }
    }
   }
   $23 = HEAP32[$9>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 48|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($23) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($23) + 64|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($23) + 68|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($23) + 44|0);
   $35 = (($23) + 60|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($23) + 36|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($25) + 52|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$0>>2]|0;
   __ZN5physx17PxsFluidCollision25updateFluidShapeCollisionEPNS_16PxsFluidParticleEPNS_18PxsFluidTwoWayDataEPNS_6PxVec3ES6_RNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheERNS_9PxBounds3EPKjPKfPKNS_19PxsW2STransformTempERKNS_22PxsParticleStreamShapeE($this,$27,$29,$31,$33,$34,$36,$10,$38,$40,$41,$streamShape);
   $$pre = HEAP32[$3>>2]|0;
   $43 = $$pre;
  }
  $42 = ($17|0)==($43|0);
  if ($42) {
   break;
  } else {
   $12 = $17;$44 = $43;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx17PxsFluidCollision19addTempW2STransformERNS0_8TaskDataERKNS_31PxsParticleStreamContactManagerE($this,$taskData,$cm) {
 $this = $this|0;
 $taskData = $taskData|0;
 $cm = $cm|0;
 var $$$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0;
 var $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0;
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0);
 var $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0);
 var $439 = Math_fround(0), $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0);
 var $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0);
 var $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0);
 var $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0), $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = 0, $51 = Math_fround(0);
 var $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = 0, $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0);
 var $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0);
 var $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0);
 var $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0);
 var $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0;
 var $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($taskData) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = (($taskData) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  $10 = $4;
 } else {
  $6 = ($2|0)==(0);
  $7 = $1 << 1;
  $$$i$i = $6 ? 1 : $7;
  __ZN5physx6shdfnd5ArrayINS_19PxsW2STransformTempENS0_16AlignedAllocatorILj16ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($taskData,$$$i$i);
  $$pre$i = HEAP32[$3>>2]|0;
  $10 = $$pre$i;
 }
 $8 = HEAP32[$taskData>>2]|0;
 $9 = (($10) + 1)|0;
 HEAP32[$3>>2] = $9;
 $11 = (($8) + (($10*56)|0)|0);
 $12 = (($cm) + 13|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $447 = (($cm) + 4|0);
  $448 = HEAP32[$447>>2]|0;
  $449 = (($448) + 16|0);
  $450 = Math_fround(HEAPF32[$449>>2]);
  $451 = (($448) + 20|0);
  $452 = Math_fround(HEAPF32[$451>>2]);
  $453 = (($448) + 24|0);
  $454 = Math_fround(HEAPF32[$453>>2]);
  $455 = Math_fround($450 * Math_fround(-2.0));
  $456 = Math_fround($452 * Math_fround(-2.0));
  $457 = Math_fround($454 * Math_fround(-2.0));
  $458 = (($448) + 12|0);
  $459 = Math_fround(HEAPF32[$458>>2]);
  $460 = Math_fround($459 * $459);
  $461 = Math_fround($460 + Math_fround(-0.5));
  $462 = Math_fround(HEAPF32[$448>>2]);
  $463 = Math_fround($455 * $462);
  $464 = (($448) + 4|0);
  $465 = Math_fround(HEAPF32[$464>>2]);
  $466 = Math_fround($456 * $465);
  $467 = Math_fround($463 + $466);
  $468 = (($448) + 8|0);
  $469 = Math_fround(HEAPF32[$468>>2]);
  $470 = Math_fround($457 * $469);
  $471 = Math_fround($467 + $470);
  $472 = Math_fround($455 * $461);
  $473 = Math_fround($457 * $465);
  $474 = Math_fround($456 * $469);
  $475 = Math_fround($473 - $474);
  $476 = Math_fround($459 * $475);
  $477 = Math_fround($472 - $476);
  $478 = Math_fround($462 * $471);
  $479 = Math_fround($478 + $477);
  $480 = Math_fround($456 * $461);
  $481 = Math_fround($455 * $469);
  $482 = Math_fround($457 * $462);
  $483 = Math_fround($481 - $482);
  $484 = Math_fround($459 * $483);
  $485 = Math_fround($480 - $484);
  $486 = Math_fround($465 * $471);
  $487 = Math_fround($486 + $485);
  $488 = Math_fround($457 * $461);
  $489 = Math_fround($456 * $462);
  $490 = Math_fround($455 * $465);
  $491 = Math_fround($489 - $490);
  $492 = Math_fround($459 * $491);
  $493 = Math_fround($488 - $492);
  $494 = Math_fround($469 * $471);
  $495 = Math_fround($493 + $494);
  $496 = Math_fround(-$462);
  $497 = Math_fround(-$465);
  $498 = Math_fround(-$469);
  $499 = HEAP32[$cm>>2]|0;
  $500 = (($499) + 16|0);
  $501 = Math_fround(HEAPF32[$500>>2]);
  $502 = (($499) + 20|0);
  $503 = Math_fround(HEAPF32[$502>>2]);
  $504 = (($499) + 24|0);
  $505 = Math_fround(HEAPF32[$504>>2]);
  $506 = Math_fround($501 * Math_fround(-2.0));
  $507 = Math_fround($503 * Math_fround(-2.0));
  $508 = Math_fround($505 * Math_fround(-2.0));
  $509 = (($499) + 12|0);
  $510 = Math_fround(HEAPF32[$509>>2]);
  $511 = Math_fround($510 * $510);
  $512 = Math_fround($511 + Math_fround(-0.5));
  $513 = Math_fround(HEAPF32[$499>>2]);
  $514 = Math_fround($506 * $513);
  $515 = (($499) + 4|0);
  $516 = Math_fround(HEAPF32[$515>>2]);
  $517 = Math_fround($507 * $516);
  $518 = Math_fround($514 + $517);
  $519 = (($499) + 8|0);
  $520 = Math_fround(HEAPF32[$519>>2]);
  $521 = Math_fround($508 * $520);
  $522 = Math_fround($518 + $521);
  $523 = Math_fround($506 * $512);
  $524 = Math_fround($508 * $516);
  $525 = Math_fround($507 * $520);
  $526 = Math_fround($524 - $525);
  $527 = Math_fround($510 * $526);
  $528 = Math_fround($523 - $527);
  $529 = Math_fround($513 * $522);
  $530 = Math_fround($529 + $528);
  $531 = Math_fround($507 * $512);
  $532 = Math_fround($506 * $520);
  $533 = Math_fround($508 * $513);
  $534 = Math_fround($532 - $533);
  $535 = Math_fround($510 * $534);
  $536 = Math_fround($531 - $535);
  $537 = Math_fround($516 * $522);
  $538 = Math_fround($537 + $536);
  $539 = Math_fround($508 * $512);
  $540 = Math_fround($507 * $513);
  $541 = Math_fround($506 * $516);
  $542 = Math_fround($540 - $541);
  $543 = Math_fround($510 * $542);
  $544 = Math_fround($539 - $543);
  $545 = Math_fround($520 * $522);
  $546 = Math_fround($544 + $545);
  $547 = Math_fround($530 * Math_fround(2.0));
  $548 = Math_fround($538 * Math_fround(2.0));
  $549 = Math_fround($546 * Math_fround(2.0));
  $550 = Math_fround($547 * $496);
  $551 = Math_fround($548 * $497);
  $552 = Math_fround($550 + $551);
  $553 = Math_fround($549 * $498);
  $554 = Math_fround($553 + $552);
  $555 = Math_fround($461 * $547);
  $556 = Math_fround($549 * $497);
  $557 = Math_fround($548 * $498);
  $558 = Math_fround($556 - $557);
  $559 = Math_fround($459 * $558);
  $560 = Math_fround($555 + $559);
  $561 = Math_fround($554 * $496);
  $562 = Math_fround($561 + $560);
  $563 = Math_fround($461 * $548);
  $564 = Math_fround($547 * $498);
  $565 = Math_fround($549 * $496);
  $566 = Math_fround($564 - $565);
  $567 = Math_fround($459 * $566);
  $568 = Math_fround($563 + $567);
  $569 = Math_fround($554 * $497);
  $570 = Math_fround($569 + $568);
  $571 = Math_fround($461 * $549);
  $572 = Math_fround($548 * $496);
  $573 = Math_fround($547 * $497);
  $574 = Math_fround($572 - $573);
  $575 = Math_fround($459 * $574);
  $576 = Math_fround($571 + $575);
  $577 = Math_fround($554 * $498);
  $578 = Math_fround($576 + $577);
  $579 = Math_fround($479 + $562);
  $580 = Math_fround($487 + $570);
  $581 = Math_fround($495 + $578);
  $582 = Math_fround($459 * $513);
  $583 = Math_fround($510 * $496);
  $584 = Math_fround($583 - $582);
  $585 = Math_fround($465 * $520);
  $586 = Math_fround($584 + $585);
  $587 = Math_fround($469 * $516);
  $588 = Math_fround($586 - $587);
  $589 = Math_fround($459 * $516);
  $590 = Math_fround($510 * $497);
  $591 = Math_fround($590 - $589);
  $592 = Math_fround($469 * $513);
  $593 = Math_fround($592 + $591);
  $594 = Math_fround($462 * $520);
  $595 = Math_fround($593 - $594);
  $596 = Math_fround($459 * $520);
  $597 = Math_fround($510 * $498);
  $598 = Math_fround($597 - $596);
  $599 = Math_fround($462 * $516);
  $600 = Math_fround($599 + $598);
  $601 = Math_fround($465 * $513);
  $602 = Math_fround($600 - $601);
  $603 = Math_fround($459 * $510);
  $604 = Math_fround($462 * $513);
  $605 = Math_fround($603 - $604);
  $606 = Math_fround($465 * $516);
  $607 = Math_fround($605 - $606);
  $608 = Math_fround($469 * $520);
  $609 = Math_fround($607 - $608);
  HEAPF32[$11>>2] = $588;
  $610 = ((($8) + (($10*56)|0)|0) + 4|0);
  HEAPF32[$610>>2] = $595;
  $611 = ((($8) + (($10*56)|0)|0) + 8|0);
  HEAPF32[$611>>2] = $602;
  $612 = ((($8) + (($10*56)|0)|0) + 12|0);
  HEAPF32[$612>>2] = $609;
  $613 = ((($8) + (($10*56)|0)|0) + 16|0);
  HEAPF32[$613>>2] = $579;
  $614 = ((($8) + (($10*56)|0)|0) + 20|0);
  HEAPF32[$614>>2] = $580;
  $615 = ((($8) + (($10*56)|0)|0) + 24|0);
  HEAPF32[$615>>2] = $581;
  $616 = ((($8) + (($10*56)|0)|0) + 28|0);
  HEAPF32[$616>>2] = $588;
  $617 = ((($8) + (($10*56)|0)|0) + 32|0);
  HEAPF32[$617>>2] = $595;
  $618 = ((($8) + (($10*56)|0)|0) + 36|0);
  HEAPF32[$618>>2] = $602;
  $619 = ((($8) + (($10*56)|0)|0) + 40|0);
  HEAPF32[$619>>2] = $609;
  $620 = ((($8) + (($10*56)|0)|0) + 44|0);
  HEAPF32[$620>>2] = $579;
  $621 = ((($8) + (($10*56)|0)|0) + 48|0);
  HEAPF32[$621>>2] = $580;
  $622 = ((($8) + (($10*56)|0)|0) + 52|0);
  HEAPF32[$622>>2] = $581;
  STACKTOP = sp;return;
 } else {
  $15 = HEAP32[$cm>>2]|0;
  $16 = (($cm) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround(-$18);
  $20 = (($17) + 4|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround(-$21);
  $23 = (($17) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround(-$24);
  $26 = (($17) + 12|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($15) + 48|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($17) + 16|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($29 - $31);
  $33 = (($15) + 52|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($17) + 20|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($34 - $36);
  $38 = (($15) + 56|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($17) + 24|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($39 - $41);
  $43 = Math_fround($32 * Math_fround(2.0));
  $44 = Math_fround($37 * Math_fround(2.0));
  $45 = Math_fround($42 * Math_fround(2.0));
  $46 = Math_fround($27 * $27);
  $47 = Math_fround($46 + Math_fround(-0.5));
  $48 = Math_fround($43 * $19);
  $49 = Math_fround($44 * $22);
  $50 = Math_fround($48 + $49);
  $51 = Math_fround($45 * $25);
  $52 = Math_fround($50 + $51);
  $53 = Math_fround($47 * $43);
  $54 = Math_fround($45 * $22);
  $55 = Math_fround($44 * $25);
  $56 = Math_fround($54 - $55);
  $57 = Math_fround($27 * $56);
  $58 = Math_fround($53 + $57);
  $59 = Math_fround($52 * $19);
  $60 = Math_fround($59 + $58);
  $61 = Math_fround($47 * $44);
  $62 = Math_fround($43 * $25);
  $63 = Math_fround($45 * $19);
  $64 = Math_fround($62 - $63);
  $65 = Math_fround($27 * $64);
  $66 = Math_fround($61 + $65);
  $67 = Math_fround($52 * $22);
  $68 = Math_fround($67 + $66);
  $69 = Math_fround($47 * $45);
  $70 = Math_fround($44 * $19);
  $71 = Math_fround($43 * $22);
  $72 = Math_fround($70 - $71);
  $73 = Math_fround($27 * $72);
  $74 = Math_fround($69 + $73);
  $75 = Math_fround($52 * $25);
  $76 = Math_fround($74 + $75);
  $77 = (($15) + 32|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($27 * $78);
  $80 = (($15) + 44|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround($81 * $19);
  $83 = Math_fround($79 + $82);
  $84 = (($15) + 40|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($85 * $22);
  $87 = Math_fround($83 + $86);
  $88 = (($15) + 36|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = Math_fround($89 * $25);
  $91 = Math_fround($87 - $90);
  $92 = Math_fround($27 * $89);
  $93 = Math_fround($81 * $22);
  $94 = Math_fround($93 + $92);
  $95 = Math_fround($78 * $25);
  $96 = Math_fround($95 + $94);
  $97 = Math_fround($85 * $19);
  $98 = Math_fround($96 - $97);
  $99 = Math_fround($27 * $85);
  $100 = Math_fround($81 * $25);
  $101 = Math_fround($100 + $99);
  $102 = Math_fround($89 * $19);
  $103 = Math_fround($102 + $101);
  $104 = Math_fround($78 * $22);
  $105 = Math_fround($103 - $104);
  $106 = Math_fround($27 * $81);
  $107 = Math_fround($78 * $19);
  $108 = Math_fround($106 - $107);
  $109 = Math_fround($89 * $22);
  $110 = Math_fround($108 - $109);
  $111 = Math_fround($85 * $25);
  $112 = Math_fround($110 - $111);
  $113 = (($cm) + 8|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (($114) + 16|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = (($114) + 20|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = (($114) + 24|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $121 = Math_fround($116 * Math_fround(-2.0));
  $122 = Math_fround($118 * Math_fround(-2.0));
  $123 = Math_fround($120 * Math_fround(-2.0));
  $124 = (($114) + 12|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = Math_fround($125 * $125);
  $127 = Math_fround($126 + Math_fround(-0.5));
  $128 = Math_fround(HEAPF32[$114>>2]);
  $129 = Math_fround($121 * $128);
  $130 = (($114) + 4|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  $132 = Math_fround($122 * $131);
  $133 = Math_fround($129 + $132);
  $134 = (($114) + 8|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = Math_fround($123 * $135);
  $137 = Math_fround($133 + $136);
  $138 = Math_fround($121 * $127);
  $139 = Math_fround($123 * $131);
  $140 = Math_fround($122 * $135);
  $141 = Math_fround($139 - $140);
  $142 = Math_fround($125 * $141);
  $143 = Math_fround($138 - $142);
  $144 = Math_fround($128 * $137);
  $145 = Math_fround($144 + $143);
  $146 = Math_fround($122 * $127);
  $147 = Math_fround($121 * $135);
  $148 = Math_fround($123 * $128);
  $149 = Math_fround($147 - $148);
  $150 = Math_fround($125 * $149);
  $151 = Math_fround($146 - $150);
  $152 = Math_fround($131 * $137);
  $153 = Math_fround($152 + $151);
  $154 = Math_fround($123 * $127);
  $155 = Math_fround($122 * $128);
  $156 = Math_fround($121 * $131);
  $157 = Math_fround($155 - $156);
  $158 = Math_fround($125 * $157);
  $159 = Math_fround($154 - $158);
  $160 = Math_fround($135 * $137);
  $161 = Math_fround($159 + $160);
  $162 = Math_fround(-$128);
  $163 = Math_fround(-$131);
  $164 = Math_fround(-$135);
  $165 = Math_fround($145 * Math_fround(2.0));
  $166 = Math_fround($153 * Math_fround(2.0));
  $167 = Math_fround($161 * Math_fround(2.0));
  $168 = Math_fround($112 * $112);
  $169 = Math_fround($168 + Math_fround(-0.5));
  $170 = Math_fround($91 * $165);
  $171 = Math_fround($98 * $166);
  $172 = Math_fround($170 + $171);
  $173 = Math_fround($105 * $167);
  $174 = Math_fround($173 + $172);
  $175 = Math_fround($169 * $165);
  $176 = Math_fround($98 * $167);
  $177 = Math_fround($105 * $166);
  $178 = Math_fround($176 - $177);
  $179 = Math_fround($112 * $178);
  $180 = Math_fround($175 + $179);
  $181 = Math_fround($91 * $174);
  $182 = Math_fround($181 + $180);
  $183 = Math_fround($169 * $166);
  $184 = Math_fround($105 * $165);
  $185 = Math_fround($91 * $167);
  $186 = Math_fround($184 - $185);
  $187 = Math_fround($112 * $186);
  $188 = Math_fround($183 + $187);
  $189 = Math_fround($98 * $174);
  $190 = Math_fround($189 + $188);
  $191 = Math_fround($169 * $167);
  $192 = Math_fround($91 * $166);
  $193 = Math_fround($98 * $165);
  $194 = Math_fround($192 - $193);
  $195 = Math_fround($112 * $194);
  $196 = Math_fround($191 + $195);
  $197 = Math_fround($105 * $174);
  $198 = Math_fround($196 + $197);
  $199 = Math_fround($60 + $182);
  $200 = Math_fround($68 + $190);
  $201 = Math_fround($76 + $198);
  $202 = Math_fround($112 * $162);
  $203 = Math_fround($91 * $125);
  $204 = Math_fround($203 + $202);
  $205 = Math_fround($98 * $164);
  $206 = Math_fround($204 + $205);
  $207 = Math_fround($105 * $163);
  $208 = Math_fround($206 - $207);
  $209 = Math_fround($112 * $163);
  $210 = Math_fround($98 * $125);
  $211 = Math_fround($210 + $209);
  $212 = Math_fround($105 * $162);
  $213 = Math_fround($212 + $211);
  $214 = Math_fround($91 * $164);
  $215 = Math_fround($213 - $214);
  $216 = Math_fround($112 * $164);
  $217 = Math_fround($105 * $125);
  $218 = Math_fround($217 + $216);
  $219 = Math_fround($91 * $163);
  $220 = Math_fround($219 + $218);
  $221 = Math_fround($98 * $162);
  $222 = Math_fround($220 - $221);
  $223 = Math_fround($112 * $125);
  $224 = Math_fround($91 * $162);
  $225 = Math_fround($223 - $224);
  $226 = Math_fround($98 * $163);
  $227 = Math_fround($225 - $226);
  $228 = Math_fround($105 * $164);
  $229 = Math_fround($227 - $228);
  HEAPF32[$11>>2] = $208;
  $230 = ((($8) + (($10*56)|0)|0) + 4|0);
  HEAPF32[$230>>2] = $215;
  $231 = ((($8) + (($10*56)|0)|0) + 8|0);
  HEAPF32[$231>>2] = $222;
  $232 = ((($8) + (($10*56)|0)|0) + 12|0);
  HEAPF32[$232>>2] = $229;
  $233 = ((($8) + (($10*56)|0)|0) + 16|0);
  HEAPF32[$233>>2] = $199;
  $234 = ((($8) + (($10*56)|0)|0) + 20|0);
  HEAPF32[$234>>2] = $200;
  $235 = ((($8) + (($10*56)|0)|0) + 24|0);
  HEAPF32[$235>>2] = $201;
  $236 = HEAP32[$16>>2]|0;
  $237 = Math_fround(HEAPF32[$236>>2]);
  $238 = Math_fround(-$237);
  $239 = (($236) + 4|0);
  $240 = Math_fround(HEAPF32[$239>>2]);
  $241 = Math_fround(-$240);
  $242 = (($236) + 8|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = Math_fround(-$243);
  $245 = (($236) + 12|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround(HEAPF32[$28>>2]);
  $248 = (($236) + 16|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = Math_fround($247 - $249);
  $251 = Math_fround(HEAPF32[$33>>2]);
  $252 = (($236) + 20|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = Math_fround($251 - $253);
  $255 = Math_fround(HEAPF32[$38>>2]);
  $256 = (($236) + 24|0);
  $257 = Math_fround(HEAPF32[$256>>2]);
  $258 = Math_fround($255 - $257);
  $259 = Math_fround($250 * Math_fround(2.0));
  $260 = Math_fround($254 * Math_fround(2.0));
  $261 = Math_fround($258 * Math_fround(2.0));
  $262 = Math_fround($246 * $246);
  $263 = Math_fround($262 + Math_fround(-0.5));
  $264 = Math_fround($259 * $238);
  $265 = Math_fround($260 * $241);
  $266 = Math_fround($264 + $265);
  $267 = Math_fround($261 * $244);
  $268 = Math_fround($266 + $267);
  $269 = Math_fround($263 * $259);
  $270 = Math_fround($261 * $241);
  $271 = Math_fround($260 * $244);
  $272 = Math_fround($270 - $271);
  $273 = Math_fround($246 * $272);
  $274 = Math_fround($269 + $273);
  $275 = Math_fround($268 * $238);
  $276 = Math_fround($275 + $274);
  $277 = Math_fround($263 * $260);
  $278 = Math_fround($259 * $244);
  $279 = Math_fround($261 * $238);
  $280 = Math_fround($278 - $279);
  $281 = Math_fround($246 * $280);
  $282 = Math_fround($277 + $281);
  $283 = Math_fround($268 * $241);
  $284 = Math_fround($283 + $282);
  $285 = Math_fround($263 * $261);
  $286 = Math_fround($260 * $238);
  $287 = Math_fround($259 * $241);
  $288 = Math_fround($286 - $287);
  $289 = Math_fround($246 * $288);
  $290 = Math_fround($285 + $289);
  $291 = Math_fround($268 * $244);
  $292 = Math_fround($290 + $291);
  $293 = Math_fround(HEAPF32[$77>>2]);
  $294 = Math_fround($246 * $293);
  $295 = Math_fround(HEAPF32[$80>>2]);
  $296 = Math_fround($295 * $238);
  $297 = Math_fround($294 + $296);
  $298 = Math_fround(HEAPF32[$84>>2]);
  $299 = Math_fround($298 * $241);
  $300 = Math_fround($297 + $299);
  $301 = Math_fround(HEAPF32[$88>>2]);
  $302 = Math_fround($301 * $244);
  $303 = Math_fround($300 - $302);
  $304 = Math_fround($246 * $301);
  $305 = Math_fround($295 * $241);
  $306 = Math_fround($305 + $304);
  $307 = Math_fround($293 * $244);
  $308 = Math_fround($307 + $306);
  $309 = Math_fround($298 * $238);
  $310 = Math_fround($308 - $309);
  $311 = Math_fround($246 * $298);
  $312 = Math_fround($295 * $244);
  $313 = Math_fround($312 + $311);
  $314 = Math_fround($301 * $238);
  $315 = Math_fround($314 + $313);
  $316 = Math_fround($293 * $241);
  $317 = Math_fround($315 - $316);
  $318 = Math_fround($246 * $295);
  $319 = Math_fround($293 * $238);
  $320 = Math_fround($318 - $319);
  $321 = Math_fround($301 * $241);
  $322 = Math_fround($320 - $321);
  $323 = Math_fround($298 * $244);
  $324 = Math_fround($322 - $323);
  $325 = (($15) + 16|0);
  $326 = Math_fround(HEAPF32[$325>>2]);
  $327 = (($15) + 20|0);
  $328 = Math_fround(HEAPF32[$327>>2]);
  $329 = (($15) + 24|0);
  $330 = Math_fround(HEAPF32[$329>>2]);
  $331 = Math_fround($326 * Math_fround(-2.0));
  $332 = Math_fround($328 * Math_fround(-2.0));
  $333 = Math_fround($330 * Math_fround(-2.0));
  $334 = (($15) + 12|0);
  $335 = Math_fround(HEAPF32[$334>>2]);
  $336 = Math_fround($335 * $335);
  $337 = Math_fround($336 + Math_fround(-0.5));
  $338 = Math_fround(HEAPF32[$15>>2]);
  $339 = Math_fround($331 * $338);
  $340 = (($15) + 4|0);
  $341 = Math_fround(HEAPF32[$340>>2]);
  $342 = Math_fround($332 * $341);
  $343 = Math_fround($339 + $342);
  $344 = (($15) + 8|0);
  $345 = Math_fround(HEAPF32[$344>>2]);
  $346 = Math_fround($333 * $345);
  $347 = Math_fround($343 + $346);
  $348 = Math_fround($331 * $337);
  $349 = Math_fround($333 * $341);
  $350 = Math_fround($332 * $345);
  $351 = Math_fround($349 - $350);
  $352 = Math_fround($335 * $351);
  $353 = Math_fround($348 - $352);
  $354 = Math_fround($338 * $347);
  $355 = Math_fround($354 + $353);
  $356 = Math_fround($332 * $337);
  $357 = Math_fround($331 * $345);
  $358 = Math_fround($333 * $338);
  $359 = Math_fround($357 - $358);
  $360 = Math_fround($335 * $359);
  $361 = Math_fround($356 - $360);
  $362 = Math_fround($341 * $347);
  $363 = Math_fround($362 + $361);
  $364 = Math_fround($333 * $337);
  $365 = Math_fround($332 * $338);
  $366 = Math_fround($331 * $341);
  $367 = Math_fround($365 - $366);
  $368 = Math_fround($335 * $367);
  $369 = Math_fround($364 - $368);
  $370 = Math_fround($345 * $347);
  $371 = Math_fround($369 + $370);
  $372 = Math_fround(-$338);
  $373 = Math_fround(-$341);
  $374 = Math_fround(-$345);
  $375 = Math_fround($355 * Math_fround(2.0));
  $376 = Math_fround($363 * Math_fround(2.0));
  $377 = Math_fround($371 * Math_fround(2.0));
  $378 = Math_fround($324 * $324);
  $379 = Math_fround($378 + Math_fround(-0.5));
  $380 = Math_fround($303 * $375);
  $381 = Math_fround($310 * $376);
  $382 = Math_fround($380 + $381);
  $383 = Math_fround($317 * $377);
  $384 = Math_fround($383 + $382);
  $385 = Math_fround($379 * $375);
  $386 = Math_fround($310 * $377);
  $387 = Math_fround($317 * $376);
  $388 = Math_fround($386 - $387);
  $389 = Math_fround($324 * $388);
  $390 = Math_fround($385 + $389);
  $391 = Math_fround($303 * $384);
  $392 = Math_fround($391 + $390);
  $393 = Math_fround($379 * $376);
  $394 = Math_fround($317 * $375);
  $395 = Math_fround($303 * $377);
  $396 = Math_fround($394 - $395);
  $397 = Math_fround($324 * $396);
  $398 = Math_fround($393 + $397);
  $399 = Math_fround($310 * $384);
  $400 = Math_fround($399 + $398);
  $401 = Math_fround($379 * $377);
  $402 = Math_fround($303 * $376);
  $403 = Math_fround($310 * $375);
  $404 = Math_fround($402 - $403);
  $405 = Math_fround($324 * $404);
  $406 = Math_fround($401 + $405);
  $407 = Math_fround($317 * $384);
  $408 = Math_fround($406 + $407);
  $409 = Math_fround($276 + $392);
  $410 = Math_fround($284 + $400);
  $411 = Math_fround($292 + $408);
  $412 = Math_fround($324 * $372);
  $413 = Math_fround($303 * $335);
  $414 = Math_fround($413 + $412);
  $415 = Math_fround($310 * $374);
  $416 = Math_fround($414 + $415);
  $417 = Math_fround($317 * $373);
  $418 = Math_fround($416 - $417);
  $419 = Math_fround($324 * $373);
  $420 = Math_fround($310 * $335);
  $421 = Math_fround($420 + $419);
  $422 = Math_fround($317 * $372);
  $423 = Math_fround($422 + $421);
  $424 = Math_fround($303 * $374);
  $425 = Math_fround($423 - $424);
  $426 = Math_fround($324 * $374);
  $427 = Math_fround($317 * $335);
  $428 = Math_fround($427 + $426);
  $429 = Math_fround($303 * $373);
  $430 = Math_fround($429 + $428);
  $431 = Math_fround($310 * $372);
  $432 = Math_fround($430 - $431);
  $433 = Math_fround($324 * $335);
  $434 = Math_fround($303 * $372);
  $435 = Math_fround($433 - $434);
  $436 = Math_fround($310 * $373);
  $437 = Math_fround($435 - $436);
  $438 = Math_fround($317 * $374);
  $439 = Math_fround($437 - $438);
  $440 = ((($8) + (($10*56)|0)|0) + 28|0);
  HEAPF32[$440>>2] = $418;
  $441 = ((($8) + (($10*56)|0)|0) + 32|0);
  HEAPF32[$441>>2] = $425;
  $442 = ((($8) + (($10*56)|0)|0) + 36|0);
  HEAPF32[$442>>2] = $432;
  $443 = ((($8) + (($10*56)|0)|0) + 40|0);
  HEAPF32[$443>>2] = $439;
  $444 = ((($8) + (($10*56)|0)|0) + 44|0);
  HEAPF32[$444>>2] = $409;
  $445 = ((($8) + (($10*56)|0)|0) + 48|0);
  HEAPF32[$445>>2] = $410;
  $446 = ((($8) + (($10*56)|0)|0) + 52|0);
  HEAPF32[$446>>2] = $411;
  STACKTOP = sp;return;
 }
}
function __ZN5physx17PxsFluidCollision25updateFluidShapeCollisionEPNS_16PxsFluidParticleEPNS_18PxsFluidTwoWayDataEPNS_6PxVec3ES6_RNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheERNS_9PxBounds3EPKjPKfPKNS_19PxsW2STransformTempERKNS_22PxsParticleStreamShapeE($this,$particles,$fluidTwoWayData,$transientBuf,$collisionVelocities,$constraintBufs,$opcodeCache,$worldBounds,$fluidShapeParticleIndices,$restOffsets,$w2sTransforms,$streamShape) {
 $this = $this|0;
 $particles = $particles|0;
 $fluidTwoWayData = $fluidTwoWayData|0;
 $transientBuf = $transientBuf|0;
 $collisionVelocities = $collisionVelocities|0;
 $constraintBufs = $constraintBufs|0;
 $opcodeCache = $opcodeCache|0;
 $worldBounds = $worldBounds|0;
 $fluidShapeParticleIndices = $fluidShapeParticleIndices|0;
 $restOffsets = $restOffsets|0;
 $w2sTransforms = $w2sTransforms|0;
 $streamShape = $streamShape|0;
 var $$pre = 0, $$pre17 = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0;
 var $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0;
 var $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0;
 var $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0);
 var $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $localCellHash = 0, $numParticlesSp$013 = 0, $numProcessedParticles$015 = 0, $p$07 = 0, $p2$08 = 0, $p4$011 = 0, $p5$012 = 0, $packetCorner = 0, $particlesSp = 0, $perParticleCacheSp$0 = 0, $restOffsetsSp = 0, $shareMem = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $particlesSp = sp + 560|0;
 $0 = sp + 569|0;
 $restOffsetsSp = sp + 16|0;
 $shareMem = sp + 528|0;
 $1 = sp + 568|0;
 $localCellHash = sp + 536|0;
 $packetCorner = sp;
 $2 = HEAP32[$streamShape>>2]|0;
 $3 = (($2) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($particlesSp) + 4|0);
 HEAP8[$9>>0] = 1;
 $10 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,4096,493824,282)|0);
 HEAP32[$particlesSp>>2] = $10;
 $11 = (($shareMem) + 4|0);
 HEAP8[$11>>0] = 1;
 $12 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,4608,493824,289)|0);
 HEAP32[$shareMem>>2] = $12;
 ;HEAP32[$localCellHash+0>>2]=0|0;HEAP32[$localCellHash+4>>2]=0|0;HEAP32[$localCellHash+8>>2]=0|0;HEAP32[$localCellHash+12>>2]=0|0;HEAP8[$localCellHash+16>>0]=0|0;
 $13 = ($opcodeCache|0)==(0|0);
 if ($13) {
  $14 = (($localCellHash) + 4|0);
  HEAP32[$14>>2] = $12;
  $15 = (($12) + 512|0);
  $16 = (($localCellHash) + 12|0);
  HEAP32[$16>>2] = $15;
  $17 = HEAP16[$4>>1]|0;
  $18 = (Math_fround(($17<<16>>16)));
  $19 = (($4) + 2|0);
  $20 = HEAP16[$19>>1]|0;
  $21 = (Math_fround(($20<<16>>16)));
  $22 = (($4) + 4|0);
  $23 = HEAP16[$22>>1]|0;
  $24 = (Math_fround(($23<<16>>16)));
  $25 = (($this) + 44|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($18 * $26);
  $28 = Math_fround($21 * $26);
  $29 = Math_fround($24 * $26);
  HEAPF32[$packetCorner>>2] = $27;
  $30 = (($packetCorner) + 4|0);
  HEAPF32[$30>>2] = $28;
  $31 = (($packetCorner) + 8|0);
  HEAPF32[$31>>2] = $29;
  $perParticleCacheSp$0 = 0;
 } else {
  $perParticleCacheSp$0 = $12;
 }
 $32 = ($6|0)==(0);
 if (!($32)) {
  $33 = (($6) + 127)|0;
  $34 = $33 & 127;
  $35 = (($34) + 1)|0;
  $36 = ($restOffsets|0)==(0|0);
  $37 = (($streamShape) + 8|0);
  $38 = (($streamShape) + 4|0);
  $39 = (($localCellHash) + 16|0);
  $40 = (($this) + 48|0);
  $121 = $10;$numParticlesSp$013 = $35;$numProcessedParticles$015 = 0;
  while(1) {
   $$sum = (($numProcessedParticles$015) + ($8))|0;
   $46 = $121;$p$07 = 0;
   while(1) {
    $$sum3 = (($p$07) + ($$sum))|0;
    $41 = (($fluidShapeParticleIndices) + ($$sum3<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($particles) + ($42<<5)|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = (($46) + ($p$07<<5)|0);
    HEAPF32[$45>>2] = $44;
    $47 = ((($particles) + ($42<<5)|0) + 4|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = ((($46) + ($p$07<<5)|0) + 4|0);
    HEAPF32[$49>>2] = $48;
    $50 = ((($particles) + ($42<<5)|0) + 8|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = ((($46) + ($p$07<<5)|0) + 8|0);
    HEAPF32[$52>>2] = $51;
    $53 = ((($particles) + ($42<<5)|0) + 12|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = ((($46) + ($p$07<<5)|0) + 12|0);
    HEAPF32[$55>>2] = $54;
    $56 = ((($particles) + ($42<<5)|0) + 16|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = ((($46) + ($p$07<<5)|0) + 16|0);
    HEAPF32[$58>>2] = $57;
    $59 = ((($particles) + ($42<<5)|0) + 20|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = ((($46) + ($p$07<<5)|0) + 20|0);
    HEAPF32[$61>>2] = $60;
    $62 = ((($particles) + ($42<<5)|0) + 24|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    $64 = ((($46) + ($p$07<<5)|0) + 24|0);
    HEAPF32[$64>>2] = $63;
    $65 = ((($46) + ($p$07<<5)|0) + 28|0);
    $66 = ((($particles) + ($42<<5)|0) + 28|0);
    $67 = HEAPU16[$66>>1]|(HEAPU16[$66+2>>1]<<16);
    HEAP16[$65>>1]=$67&65535;HEAP16[$65+2>>1]=$67>>>16;
    $68 = (($p$07) + 1)|0;
    $69 = ($68>>>0)<($numParticlesSp$013>>>0);
    if (!($69)) {
     break;
    }
    $$pre17 = HEAP32[$particlesSp>>2]|0;
    $46 = $$pre17;$p$07 = $68;
   }
   $70 = (($fluidShapeParticleIndices) + ($$sum<<2)|0);
   if ($36) {
    $71 = Math_fround(HEAPF32[$40>>2]);
    $p4$011 = 0;
    while(1) {
     $79 = (($restOffsetsSp) + ($p4$011<<2)|0);
     HEAPF32[$79>>2] = $71;
     $80 = (($p4$011) + 1)|0;
     $81 = ($80>>>0)<($numParticlesSp$013>>>0);
     if ($81) {
      $p4$011 = $80;
     } else {
      break;
     }
    }
   } else {
    $p2$08 = 0;
    while(1) {
     $$sum2 = (($p2$08) + ($$sum))|0;
     $72 = (($fluidShapeParticleIndices) + ($$sum2<<2)|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = (($restOffsets) + ($73<<2)|0);
     $75 = Math_fround(HEAPF32[$74>>2]);
     $76 = (($restOffsetsSp) + ($p2$08<<2)|0);
     HEAPF32[$76>>2] = $75;
     $77 = (($p2$08) + 1)|0;
     $78 = ($77>>>0)<($numParticlesSp$013>>>0);
     if ($78) {
      $p2$08 = $77;
     } else {
      break;
     }
    }
   }
   $82 = HEAP32[$particlesSp>>2]|0;
   $83 = HEAP32[$37>>2]|0;
   $84 = HEAP32[$38>>2]|0;
   __ZN5physx17PxsFluidCollision15updateSubPacketEPNS_16PxsFluidParticleEPNS_18PxsFluidTwoWayDataEPNS_6PxVec3ES6_RNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheESA_RNS_21PxsFluidLocalCellHashERNS_9PxBounds3ERKS5_PKjjPKNS_31PxsParticleStreamContactManagerEPKNS_19PxsW2STransformTempEjPKf($this,$82,$fluidTwoWayData,$transientBuf,$collisionVelocities,$constraintBufs,$perParticleCacheSp$0,$opcodeCache,$localCellHash,$worldBounds,$packetCorner,$70,$numParticlesSp$013,$83,$w2sTransforms,$84,$restOffsetsSp);
   $$pre = HEAP32[$particlesSp>>2]|0;
   $p5$012 = 0;
   while(1) {
    $$sum1 = (($p5$012) + ($$sum))|0;
    $85 = (($fluidShapeParticleIndices) + ($$sum1<<2)|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($$pre) + ($p5$012<<5)|0);
    $88 = Math_fround(HEAPF32[$87>>2]);
    $89 = (($particles) + ($86<<5)|0);
    HEAPF32[$89>>2] = $88;
    $90 = ((($$pre) + ($p5$012<<5)|0) + 4|0);
    $91 = Math_fround(HEAPF32[$90>>2]);
    $92 = ((($particles) + ($86<<5)|0) + 4|0);
    HEAPF32[$92>>2] = $91;
    $93 = ((($$pre) + ($p5$012<<5)|0) + 8|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $95 = ((($particles) + ($86<<5)|0) + 8|0);
    HEAPF32[$95>>2] = $94;
    $96 = ((($$pre) + ($p5$012<<5)|0) + 12|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = ((($particles) + ($86<<5)|0) + 12|0);
    HEAPF32[$98>>2] = $97;
    $99 = ((($$pre) + ($p5$012<<5)|0) + 16|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $101 = ((($particles) + ($86<<5)|0) + 16|0);
    HEAPF32[$101>>2] = $100;
    $102 = ((($$pre) + ($p5$012<<5)|0) + 20|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = ((($particles) + ($86<<5)|0) + 20|0);
    HEAPF32[$104>>2] = $103;
    $105 = ((($$pre) + ($p5$012<<5)|0) + 24|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $107 = ((($particles) + ($86<<5)|0) + 24|0);
    HEAPF32[$107>>2] = $106;
    $108 = ((($particles) + ($86<<5)|0) + 28|0);
    $109 = ((($$pre) + ($p5$012<<5)|0) + 28|0);
    $110 = HEAPU16[$109>>1]|(HEAPU16[$109+2>>1]<<16);
    HEAP16[$108>>1]=$110&65535;HEAP16[$108+2>>1]=$110>>>16;
    $111 = (($p5$012) + 1)|0;
    $112 = ($111>>>0)<($numParticlesSp$013>>>0);
    if ($112) {
     $p5$012 = $111;
    } else {
     break;
    }
   }
   HEAP8[$39>>0] = 0;
   $113 = (($numProcessedParticles$015) + ($numParticlesSp$013))|0;
   $114 = ($113>>>0)<($6>>>0);
   if ($114) {
    $121 = $$pre;$numParticlesSp$013 = 128;$numProcessedParticles$015 = $113;
   } else {
    break;
   }
  }
 }
 $115 = HEAP8[$11>>0]|0;
 $116 = ($115<<24>>24)==(0);
 if (!($116)) {
  $117 = HEAP32[$shareMem>>2]|0;
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($shareMem,$117);
 }
 $118 = HEAP8[$9>>0]|0;
 $119 = ($118<<24>>24)==(0);
 if ($119) {
  STACKTOP = sp;return;
 }
 $120 = HEAP32[$particlesSp>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($particlesSp,$120);
 STACKTOP = sp;return;
}
function __ZN5physx17PxsFluidCollision15updateSubPacketEPNS_16PxsFluidParticleEPNS_18PxsFluidTwoWayDataEPNS_6PxVec3ES6_RNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheESA_RNS_21PxsFluidLocalCellHashERNS_9PxBounds3ERKS5_PKjjPKNS_31PxsParticleStreamContactManagerEPKNS_19PxsW2STransformTempEjPKf($this,$particlesSp,$fluidTwoWayData,$transientBuf,$collisionVelocities,$constraintBufs,$perParticleCacheLocal,$perParticleCacheGlobal,$localCellHash,$worldBounds,$packetCorner,$particleIndicesSp,$numParticlesSp,$contactManagers,$w2sTransforms,$numContactManagers,$restOffsetsSp) {
 $this = $this|0;
 $particlesSp = $particlesSp|0;
 $fluidTwoWayData = $fluidTwoWayData|0;
 $transientBuf = $transientBuf|0;
 $collisionVelocities = $collisionVelocities|0;
 $constraintBufs = $constraintBufs|0;
 $perParticleCacheLocal = $perParticleCacheLocal|0;
 $perParticleCacheGlobal = $perParticleCacheGlobal|0;
 $localCellHash = $localCellHash|0;
 $worldBounds = $worldBounds|0;
 $packetCorner = $packetCorner|0;
 $particleIndicesSp = $particleIndicesSp|0;
 $numParticlesSp = $numParticlesSp|0;
 $contactManagers = $contactManagers|0;
 $w2sTransforms = $w2sTransforms|0;
 $numContactManagers = $numContactManagers|0;
 $restOffsetsSp = $restOffsetsSp|0;
 var $$c$i = 0, $$c$i6$us36 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0;
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0);
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0);
 var $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0;
 var $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0;
 var $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = Math_fround(0), $348 = 0;
 var $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge69 = 0, $brmerge70 = 0, $c0TwoWayBody$0 = 0, $c0Velocity = 0;
 var $c1TwoWayBody$0 = 0, $c1Velocity = 0, $exitcond = 0, $exitcond56 = 0, $exitcond57 = 0, $exitcond58 = 0, $exitcond59 = 0, $exitcond60 = 0, $exitcond61 = 0, $exitcond62 = 0, $exitcond63 = 0, $exitcond64 = 0, $exitcond65 = 0, $exitcond66 = 0, $i$048 = 0, $i3$028 = 0, $i3$028$us = 0, $i3$028$us34 = 0, $loadedCache$0$off0$lcssa = 0, $loadedCache$0$off030 = 0;
 var $loadedCache$0$off030$us33 = 0, $loadedCache$1$off0 = 0, $loadedCache$1$off0$us37 = 0, $loadedCache$2$off0 = 0, $loadedCache$2$off0$us39 = 0, $numDynamicShapes$049 = 0, $numDynamicShapes$1 = 0, $p$053 = 0, $p1$044 = 0, $p12$015 = 0, $p14$011 = 0, $p16$08 = 0, $p5$025$us35 = 0, $p7$021 = 0, $p9$018 = 0, $particleOldVel = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 37|0;
 $particleOldVel = sp;
 $c0Velocity = sp + 12|0;
 $c1Velocity = sp + 24|0;
 $1 = sp + 36|0;
 $2 = ($numParticlesSp*176)|0;
 $3 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$2,493824,374)|0);
 $4 = ($numParticlesSp|0)==(0);
 if (!($4)) {
  $5 = (($constraintBufs) + 4|0);
  $6 = (($particleOldVel) + 4|0);
  $7 = (($particleOldVel) + 8|0);
  $8 = (($this) + 4|0);
  $9 = (($this) + 8|0);
  $10 = (($this) + 88|0);
  $11 = (($this) + 56|0);
  $12 = (($this) + 12|0);
  $13 = (($this) + 64|0);
  $14 = (($c0Velocity) + 4|0);
  $15 = (($c0Velocity) + 8|0);
  $16 = (($c1Velocity) + 4|0);
  $17 = (($c1Velocity) + 8|0);
  $18 = (($constraintBufs) + 12|0);
  $19 = ($fluidTwoWayData|0)==(0|0);
  $20 = (($constraintBufs) + 8|0);
  $p$053 = 0;
  while(1) {
   $25 = (($particleIndicesSp) + ($p$053<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($particlesSp) + ($p$053<<5)|0);
   $28 = (($3) + (($p$053*176)|0)|0);
   $29 = HEAP32[$constraintBufs>>2]|0;
   $30 = (($29) + ($26<<4)|0);
   $31 = ((($3) + (($p$053*176)|0)|0) + 140|0);
   HEAP32[$31>>2] = $30;
   $32 = HEAP32[$5>>2]|0;
   $33 = (($32) + ($26<<4)|0);
   $34 = ((($3) + (($p$053*176)|0)|0) + 156|0);
   HEAP32[$34>>2] = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($particlesSp) + ($p$053<<5)|0) + 16|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   HEAPF32[$particleOldVel>>2] = $37;
   $38 = ((($particlesSp) + ($p$053<<5)|0) + 20|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   HEAPF32[$6>>2] = $39;
   $40 = ((($particlesSp) + ($p$053<<5)|0) + 24|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   HEAPF32[$7>>2] = $41;
   $42 = Math_fround(HEAPF32[$this>>2]);
   $43 = Math_fround(HEAPF32[$8>>2]);
   $44 = Math_fround(HEAPF32[$9>>2]);
   $45 = HEAP32[$10>>2]|0;
   $46 = $45 & 65536;
   $47 = ($46|0)==(0);
   if ($47) {
    $61 = $42;$63 = $43;$65 = $44;
   } else {
    $48 = (($transientBuf) + (($26*12)|0)|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = Math_fround($42 + $49);
    $51 = ((($transientBuf) + (($26*12)|0)|0) + 4|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = Math_fround($43 + $52);
    $54 = ((($transientBuf) + (($26*12)|0)|0) + 8|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = Math_fround($44 + $55);
    $61 = $50;$63 = $53;$65 = $56;
   }
   $57 = Math_fround(HEAPF32[$11>>2]);
   $58 = Math_fround(HEAPF32[$12>>2]);
   $59 = Math_fround(HEAPF32[$13>>2]);
   $60 = Math_fround($61 * $59);
   $62 = Math_fround($63 * $59);
   $64 = Math_fround($65 * $59);
   $66 = Math_fround($60 + $37);
   $67 = Math_fround($62 + $39);
   $68 = Math_fround($64 + $41);
   $69 = Math_fround($58 * $66);
   HEAPF32[$36>>2] = $69;
   $70 = Math_fround($58 * $67);
   HEAPF32[$38>>2] = $70;
   $71 = Math_fround($58 * $68);
   HEAPF32[$40>>2] = $71;
   $72 = Math_fround($69 * $69);
   $73 = Math_fround($70 * $70);
   $74 = Math_fround($72 + $73);
   $75 = Math_fround($71 * $71);
   $76 = Math_fround($75 + $74);
   $77 = (Math_fround(Math_sqrt((Math_fround($76)))));
   $78 = Math_fround($59 * $77);
   $79 = $78 > $57;
   if ($79) {
    $80 = Math_fround($57 / $78);
    $81 = Math_fround($69 * $80);
    HEAPF32[$36>>2] = $81;
    $82 = Math_fround($70 * $80);
    HEAPF32[$38>>2] = $82;
    $83 = Math_fround($71 * $80);
    HEAPF32[$40>>2] = $83;
   }
   HEAPF32[$c0Velocity>>2] = Math_fround(0.0);
   HEAPF32[$14>>2] = Math_fround(0.0);
   HEAPF32[$15>>2] = Math_fround(0.0);
   HEAPF32[$c1Velocity>>2] = Math_fround(0.0);
   HEAPF32[$16>>2] = Math_fround(0.0);
   HEAPF32[$17>>2] = Math_fround(0.0);
   $84 = ((($particlesSp) + ($p$053<<5)|0) + 30|0);
   $85 = HEAP16[$84>>1]|0;
   $86 = $85 & 4;
   $87 = ($86<<16>>16)==(0);
   if ($87) {
    $c0TwoWayBody$0 = 0;
   } else {
    $88 = HEAP32[$20>>2]|0;
    $89 = (($88) + ($26<<4)|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    HEAPF32[$c0Velocity>>2] = $90;
    $91 = ((($88) + ($26<<4)|0) + 4|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    HEAPF32[$14>>2] = $92;
    $93 = ((($88) + ($26<<4)|0) + 8|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    HEAPF32[$15>>2] = $94;
    if ($19) {
     $c0TwoWayBody$0 = 0;
    } else {
     $95 = ((($88) + ($26<<4)|0) + 12|0);
     $96 = HEAP32[$95>>2]|0;
     $c0TwoWayBody$0 = $96;
    }
   }
   $97 = $85 & 8;
   $98 = ($97<<16>>16)==(0);
   if ($98) {
    $c1TwoWayBody$0 = 0;
   } else {
    $99 = HEAP32[$18>>2]|0;
    $100 = (($99) + ($26<<4)|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    HEAPF32[$c1Velocity>>2] = $101;
    $102 = ((($99) + ($26<<4)|0) + 4|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    HEAPF32[$16>>2] = $103;
    $104 = ((($99) + ($26<<4)|0) + 8|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    HEAPF32[$17>>2] = $105;
    if ($19) {
     $c1TwoWayBody$0 = 0;
    } else {
     $106 = ((($99) + ($26<<4)|0) + 12|0);
     $107 = HEAP32[$106>>2]|0;
     $c1TwoWayBody$0 = $107;
    }
   }
   $108 = (($restOffsetsSp) + ($p$053<<2)|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   __ZN5physx31initCollDataAndApplyConstraintsERNS_19PxsParticleCollDataERKNS_16PxsFluidParticleERKNS_6PxVec3EfS7_S7_PKNS_11PxsBodyCoreESA_jRKNS_27PxsFluidCollisionParametersE($28,$27,$particleOldVel,$109,$c0Velocity,$c1Velocity,$c0TwoWayBody$0,$c1TwoWayBody$0,$26,$this);
   $110 = ((($3) + (($p$053*176)|0)|0) + 62|0);
   $111 = HEAP16[$110>>1]|0;
   $112 = $111&65535;
   $113 = $112 & 65520;
   $114 = $113&65535;
   HEAP16[$110>>1] = $114;
   $115 = (($p$053) + 1)|0;
   $exitcond63 = ($115|0)==($numParticlesSp|0);
   if ($exitcond63) {
    break;
   } else {
    $p$053 = $115;
   }
  }
 }
 $21 = ($numContactManagers|0)==(0);
 L20: do {
  if ($21) {
   $22 = (($this) + 56|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($23 * $23);
   $262 = $this;$264 = $22;$286 = $24;
   label = 43;
  } else {
   $i$048 = 0;$numDynamicShapes$049 = 0;
   while(1) {
    $116 = ((($contactManagers) + ($i$048<<4)|0) + 13|0);
    $117 = HEAP8[$116>>0]|0;
    $118 = ($117<<24>>24)==(0);
    if ($118) {
     $numDynamicShapes$1 = $numDynamicShapes$049;
    } else {
     $119 = (($contactManagers) + ($i$048<<4)|0);
     $120 = (($w2sTransforms) + (($i$048*56)|0)|0);
     __ZN5physx17PxsFluidCollision26updateFluidBodyContactPairEPKNS_16PxsFluidParticleEjPNS_19PxsParticleCollDataERNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheERNS_21PxsFluidLocalCellHashERKNS_6PxVec3ERKNS_31PxsParticleStreamContactManagerERKNS_19PxsW2STransformTempE($this,$particlesSp,$numParticlesSp,$3,$constraintBufs,$perParticleCacheLocal,$localCellHash,$packetCorner,$119,$120);
     $121 = (($numDynamicShapes$049) + 1)|0;
     $numDynamicShapes$1 = $121;
    }
    $122 = (($i$048) + 1)|0;
    $exitcond62 = ($122|0)==($numContactManagers|0);
    if ($exitcond62) {
     break;
    } else {
     $i$048 = $122;$numDynamicShapes$049 = $numDynamicShapes$1;
    }
   }
   $123 = (($this) + 56|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = Math_fround($124 * $124);
   $126 = ($numDynamicShapes$1|0)==(0);
   if (!($126)) {
    $127 = (($this) + 88|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = $128 & 1;
    $130 = ($129|0)!=(0);
    if (!($4)) {
     $p1$044 = 0;
     while(1) {
      $177 = (($3) + (($p1$044*176)|0)|0);
      __ZN5physx17collisionResponseERNS_19PxsParticleCollDataEbbRNS_27PxsFluidCollisionParametersE($177,$130,0,$this);
      $178 = Math_fround(HEAPF32[$123>>2]);
      $179 = ((($3) + (($p1$044*176)|0)|0) + 64|0);
      $180 = Math_fround(HEAPF32[$179>>2]);
      $181 = ((($3) + (($p1$044*176)|0)|0) + 48|0);
      $182 = Math_fround(HEAPF32[$181>>2]);
      $183 = Math_fround($180 - $182);
      $184 = ((($3) + (($p1$044*176)|0)|0) + 68|0);
      $185 = Math_fround(HEAPF32[$184>>2]);
      $186 = ((($3) + (($p1$044*176)|0)|0) + 52|0);
      $187 = Math_fround(HEAPF32[$186>>2]);
      $188 = Math_fround($185 - $187);
      $189 = ((($3) + (($p1$044*176)|0)|0) + 72|0);
      $190 = Math_fround(HEAPF32[$189>>2]);
      $191 = ((($3) + (($p1$044*176)|0)|0) + 56|0);
      $192 = Math_fround(HEAPF32[$191>>2]);
      $193 = Math_fround($190 - $192);
      $194 = Math_fround($183 * $183);
      $195 = Math_fround($188 * $188);
      $196 = Math_fround($194 + $195);
      $197 = Math_fround($193 * $193);
      $198 = Math_fround($196 + $197);
      $199 = $198 > $125;
      if ($199) {
       $200 = Math_fround($178 * $183);
       $201 = Math_fround($178 * $188);
       $202 = Math_fround($178 * $193);
       $203 = (Math_fround(Math_sqrt((Math_fround($198)))));
       $204 = Math_fround(Math_fround(1.0) / $203);
       $205 = Math_fround($200 * $204);
       $206 = Math_fround($201 * $204);
       $207 = Math_fround($202 * $204);
       $208 = Math_fround($182 + $205);
       $209 = Math_fround($187 + $206);
       $210 = Math_fround($192 + $207);
       HEAPF32[$179>>2] = $208;
       HEAPF32[$184>>2] = $209;
       HEAPF32[$189>>2] = $210;
      }
      $211 = ((($3) + (($p1$044*176)|0)|0) + 12|0);
      $212 = HEAP32[$211>>2]|0;
      $213 = $212 & -8;
      $214 = $213 | 4;
      HEAP32[$211>>2] = $214;
      $215 = ((($3) + (($p1$044*176)|0)|0) + 16|0);
      HEAPF32[$215>>2] = Math_fround(0.0);
      $216 = ((($3) + (($p1$044*176)|0)|0) + 20|0);
      HEAPF32[$216>>2] = Math_fround(0.0);
      $217 = ((($3) + (($p1$044*176)|0)|0) + 24|0);
      HEAPF32[$217>>2] = Math_fround(0.0);
      $218 = ((($3) + (($p1$044*176)|0)|0) + 44|0);
      HEAPF32[$218>>2] = Math_fround(1.0);
      $219 = (($p1$044) + 1)|0;
      $exitcond61 = ($219|0)==($numParticlesSp|0);
      if ($exitcond61) {
       break;
      } else {
       $p1$044 = $219;
      }
     }
    }
   }
   if ($21) {
    $262 = $this;$264 = $123;$286 = $125;
    label = 43;
   } else {
    $131 = ($perParticleCacheLocal|0)==(0|0);
    if ($131) {
     $i3$028$us = 0;
     while(1) {
      $133 = ((($contactManagers) + ($i3$028$us<<4)|0) + 13|0);
      $134 = HEAP8[$133>>0]|0;
      $135 = ($134<<24>>24)==(0);
      if ($135) {
       $136 = (($contactManagers) + ($i3$028$us<<4)|0);
       $137 = (($w2sTransforms) + (($i3$028$us*56)|0)|0);
       __ZN5physx17PxsFluidCollision26updateFluidBodyContactPairEPKNS_16PxsFluidParticleEjPNS_19PxsParticleCollDataERNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheERNS_21PxsFluidLocalCellHashERKNS_6PxVec3ERKNS_31PxsParticleStreamContactManagerERKNS_19PxsW2STransformTempE($this,$particlesSp,$numParticlesSp,$3,$constraintBufs,0,$localCellHash,$packetCorner,$136,$137);
      }
      $138 = (($i3$028$us) + 1)|0;
      $exitcond64 = ($138|0)==($numContactManagers|0);
      if ($exitcond64) {
       $262 = $this;$264 = $123;$286 = $125;
       label = 43;
       break L20;
      } else {
       $i3$028$us = $138;
      }
     }
    }
    $132 = ($numParticlesSp|0)==(0);
    if ($132) {
     $i3$028 = 0;$loadedCache$0$off030 = 0;
     while(1) {
      $220 = (($contactManagers) + ($i3$028<<4)|0);
      $221 = ((($contactManagers) + ($i3$028<<4)|0) + 13|0);
      $222 = HEAP8[$221>>0]|0;
      $223 = ($222<<24>>24)==(0);
      if ($223) {
       if ($loadedCache$0$off030) {
        $loadedCache$1$off0 = 1;
       } else {
        $224 = ((($contactManagers) + ($i3$028<<4)|0) + 4|0);
        $225 = HEAP32[$224>>2]|0;
        $226 = (($225) + 36|0);
        $227 = HEAP32[$226>>2]|0;
        $228 = ($227|0)==(5);
        $loadedCache$1$off0 = $228;
       }
       $229 = (($w2sTransforms) + (($i3$028*56)|0)|0);
       __ZN5physx17PxsFluidCollision26updateFluidBodyContactPairEPKNS_16PxsFluidParticleEjPNS_19PxsParticleCollDataERNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheERNS_21PxsFluidLocalCellHashERKNS_6PxVec3ERKNS_31PxsParticleStreamContactManagerERKNS_19PxsW2STransformTempE($this,$particlesSp,0,$3,$constraintBufs,$perParticleCacheLocal,$localCellHash,$packetCorner,$220,$229);
       $loadedCache$2$off0 = $loadedCache$1$off0;
      } else {
       $loadedCache$2$off0 = $loadedCache$0$off030;
      }
      $230 = (($i3$028) + 1)|0;
      $exitcond60 = ($230|0)==($numContactManagers|0);
      if ($exitcond60) {
       $loadedCache$0$off0$lcssa = $loadedCache$2$off0;
       break;
      } else {
       $i3$028 = $230;$loadedCache$0$off030 = $loadedCache$2$off0;
      }
     }
    } else {
     $i3$028$us34 = 0;$loadedCache$0$off030$us33 = 0;
     while(1) {
      $139 = (($contactManagers) + ($i3$028$us34<<4)|0);
      $140 = ((($contactManagers) + ($i3$028$us34<<4)|0) + 13|0);
      $141 = HEAP8[$140>>0]|0;
      $142 = ($141<<24>>24)==(0);
      if ($142) {
       if ($loadedCache$0$off030$us33) {
        $loadedCache$1$off0$us37 = 1;
       } else {
        $143 = ((($contactManagers) + ($i3$028$us34<<4)|0) + 4|0);
        $144 = HEAP32[$143>>2]|0;
        $145 = (($144) + 36|0);
        $146 = HEAP32[$145>>2]|0;
        $147 = ($146|0)==(5);
        if ($147) {
         $p5$025$us35 = 0;
         while(1) {
          $148 = (($particleIndicesSp) + ($p5$025$us35<<2)|0);
          $149 = HEAP32[$148>>2]|0;
          $150 = (($perParticleCacheLocal) + ($p5$025$us35<<5)|0);
          $151 = (($perParticleCacheGlobal) + ($149<<5)|0);
          $152 = HEAP32[$151>>2]|0;
          HEAP32[$150>>2] = $152;
          $153 = ((($perParticleCacheGlobal) + ($149<<5)|0) + 4|0);
          $154 = HEAP32[$153>>2]|0;
          $155 = ((($perParticleCacheLocal) + ($p5$025$us35<<5)|0) + 4|0);
          HEAP32[$155>>2] = $154;
          $156 = ((($perParticleCacheGlobal) + ($149<<5)|0) + 8|0);
          $157 = HEAP32[$156>>2]|0;
          $158 = ((($perParticleCacheLocal) + ($p5$025$us35<<5)|0) + 8|0);
          HEAP32[$158>>2] = $157;
          $159 = ((($perParticleCacheGlobal) + ($149<<5)|0) + 12|0);
          $160 = HEAP32[$159>>2]|0;
          $161 = ((($perParticleCacheLocal) + ($p5$025$us35<<5)|0) + 12|0);
          HEAP32[$161>>2] = $160;
          $162 = ((($perParticleCacheGlobal) + ($149<<5)|0) + 16|0);
          $163 = HEAP32[$162>>2]|0;
          $164 = ((($perParticleCacheLocal) + ($p5$025$us35<<5)|0) + 16|0);
          HEAP32[$164>>2] = $163;
          $165 = ((($perParticleCacheGlobal) + ($149<<5)|0) + 20|0);
          $166 = HEAP32[$165>>2]|0;
          $167 = ((($perParticleCacheLocal) + ($p5$025$us35<<5)|0) + 20|0);
          HEAP32[$167>>2] = $166;
          $168 = ((($perParticleCacheGlobal) + ($149<<5)|0) + 24|0);
          $169 = HEAP32[$168>>2]|0;
          $170 = ((($perParticleCacheLocal) + ($p5$025$us35<<5)|0) + 24|0);
          HEAP32[$170>>2] = $169;
          $171 = ((($perParticleCacheGlobal) + ($149<<5)|0) + 28|0);
          $172 = HEAP32[$171>>2]|0;
          $173 = ((($perParticleCacheLocal) + ($p5$025$us35<<5)|0) + 28|0);
          $$c$i6$us36 = $172;
          HEAP32[$173>>2] = $$c$i6$us36;
          $174 = (($p5$025$us35) + 1)|0;
          $exitcond65 = ($174|0)==($numParticlesSp|0);
          if ($exitcond65) {
           $loadedCache$1$off0$us37 = 1;
           break;
          } else {
           $p5$025$us35 = $174;
          }
         }
        } else {
         $loadedCache$1$off0$us37 = 0;
        }
       }
       $175 = (($w2sTransforms) + (($i3$028$us34*56)|0)|0);
       __ZN5physx17PxsFluidCollision26updateFluidBodyContactPairEPKNS_16PxsFluidParticleEjPNS_19PxsParticleCollDataERNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheERNS_21PxsFluidLocalCellHashERKNS_6PxVec3ERKNS_31PxsParticleStreamContactManagerERKNS_19PxsW2STransformTempE($this,$particlesSp,$numParticlesSp,$3,$constraintBufs,$perParticleCacheLocal,$localCellHash,$packetCorner,$139,$175);
       $loadedCache$2$off0$us39 = $loadedCache$1$off0$us37;
      } else {
       $loadedCache$2$off0$us39 = $loadedCache$0$off030$us33;
      }
      $176 = (($i3$028$us34) + 1)|0;
      $exitcond66 = ($176|0)==($numContactManagers|0);
      if ($exitcond66) {
       $loadedCache$0$off0$lcssa = $loadedCache$2$off0$us39;
       break;
      } else {
       $i3$028$us34 = $176;$loadedCache$0$off030$us33 = $loadedCache$2$off0$us39;
      }
     }
    }
    if ($loadedCache$0$off0$lcssa) {
     if (!($4)) {
      $p7$021 = 0;
      while(1) {
       $233 = (($particleIndicesSp) + ($p7$021<<2)|0);
       $234 = HEAP32[$233>>2]|0;
       $235 = (($perParticleCacheGlobal) + ($234<<5)|0);
       $236 = (($perParticleCacheLocal) + ($p7$021<<5)|0);
       $237 = HEAP32[$236>>2]|0;
       HEAP32[$235>>2] = $237;
       $238 = ((($perParticleCacheLocal) + ($p7$021<<5)|0) + 4|0);
       $239 = HEAP32[$238>>2]|0;
       $240 = ((($perParticleCacheGlobal) + ($234<<5)|0) + 4|0);
       HEAP32[$240>>2] = $239;
       $241 = ((($perParticleCacheLocal) + ($p7$021<<5)|0) + 8|0);
       $242 = HEAP32[$241>>2]|0;
       $243 = ((($perParticleCacheGlobal) + ($234<<5)|0) + 8|0);
       HEAP32[$243>>2] = $242;
       $244 = ((($perParticleCacheLocal) + ($p7$021<<5)|0) + 12|0);
       $245 = HEAP32[$244>>2]|0;
       $246 = ((($perParticleCacheGlobal) + ($234<<5)|0) + 12|0);
       HEAP32[$246>>2] = $245;
       $247 = ((($perParticleCacheLocal) + ($p7$021<<5)|0) + 16|0);
       $248 = HEAP32[$247>>2]|0;
       $249 = ((($perParticleCacheGlobal) + ($234<<5)|0) + 16|0);
       HEAP32[$249>>2] = $248;
       $250 = ((($perParticleCacheLocal) + ($p7$021<<5)|0) + 20|0);
       $251 = HEAP32[$250>>2]|0;
       $252 = ((($perParticleCacheGlobal) + ($234<<5)|0) + 20|0);
       HEAP32[$252>>2] = $251;
       $253 = ((($perParticleCacheLocal) + ($p7$021<<5)|0) + 24|0);
       $254 = HEAP32[$253>>2]|0;
       $255 = ((($perParticleCacheGlobal) + ($234<<5)|0) + 24|0);
       HEAP32[$255>>2] = $254;
       $256 = ((($perParticleCacheLocal) + ($p7$021<<5)|0) + 28|0);
       $257 = HEAP32[$256>>2]|0;
       $258 = ((($perParticleCacheGlobal) + ($234<<5)|0) + 28|0);
       $$c$i = $257;
       HEAP32[$258>>2] = $$c$i;
       $259 = (($p7$021) + 1)|0;
       $exitcond59 = ($259|0)==($numParticlesSp|0);
       if ($exitcond59) {
        $262 = $this;$264 = $123;$286 = $125;
        label = 43;
        break;
       } else {
        $p7$021 = $259;
       }
      }
     }
    } else {
     $262 = $this;$264 = $123;$286 = $125;
     label = 43;
    }
   }
  }
 } while(0);
 if ((label|0) == 43) {
  if (!($4)) {
   $231 = (($this) + 88|0);
   $232 = (($this) + 72|0);
   $p9$018 = 0;
   while(1) {
    $260 = (($3) + (($p9$018*176)|0)|0);
    $261 = (($particlesSp) + ($p9$018<<5)|0);
    __ZN5physx17collisionResponseERNS_19PxsParticleCollDataEbbRNS_27PxsFluidCollisionParametersE($260,0,1,$262);
    $263 = Math_fround(HEAPF32[$264>>2]);
    $265 = ((($3) + (($p9$018*176)|0)|0) + 64|0);
    $266 = Math_fround(HEAPF32[$265>>2]);
    $267 = ((($3) + (($p9$018*176)|0)|0) + 48|0);
    $268 = Math_fround(HEAPF32[$267>>2]);
    $269 = Math_fround($266 - $268);
    $270 = ((($3) + (($p9$018*176)|0)|0) + 68|0);
    $271 = Math_fround(HEAPF32[$270>>2]);
    $272 = ((($3) + (($p9$018*176)|0)|0) + 52|0);
    $273 = Math_fround(HEAPF32[$272>>2]);
    $274 = Math_fround($271 - $273);
    $275 = ((($3) + (($p9$018*176)|0)|0) + 72|0);
    $276 = Math_fround(HEAPF32[$275>>2]);
    $277 = ((($3) + (($p9$018*176)|0)|0) + 56|0);
    $278 = Math_fround(HEAPF32[$277>>2]);
    $279 = Math_fround($276 - $278);
    $280 = Math_fround($269 * $269);
    $281 = Math_fround($274 * $274);
    $282 = Math_fround($280 + $281);
    $283 = Math_fround($279 * $279);
    $284 = Math_fround($282 + $283);
    $285 = $284 > $286;
    if ($285) {
     $287 = Math_fround($263 * $269);
     $288 = Math_fround($263 * $274);
     $289 = Math_fround($263 * $279);
     $290 = (Math_fround(Math_sqrt((Math_fround($284)))));
     $291 = Math_fround(Math_fround(1.0) / $290);
     $292 = Math_fround($287 * $291);
     $293 = Math_fround($288 * $291);
     $294 = Math_fround($289 * $291);
     $295 = Math_fround($268 + $292);
     $296 = Math_fround($273 + $293);
     $297 = Math_fround($278 + $294);
     HEAPF32[$265>>2] = $295;
     HEAPF32[$270>>2] = $296;
     HEAPF32[$275>>2] = $297;
    }
    $298 = HEAP32[$231>>2]|0;
    $299 = $298 & 8;
    $300 = ($299|0)!=(0);
    __ZN5physx14updateParticleERNS_16PxsFluidParticleERKNS_19PxsParticleCollDataEbRKNS_7PxPlaneERNS_9PxBounds3E($261,$260,$300,$232,$worldBounds);
    $301 = (($p9$018) + 1)|0;
    $exitcond58 = ($301|0)==($numParticlesSp|0);
    if ($exitcond58) {
     break;
    } else {
     $p9$018 = $301;
    }
   }
  }
 }
 $302 = ($transientBuf|0)==(0|0);
 $brmerge = $302 | $4;
 if (!($brmerge)) {
  $p12$015 = 0;
  while(1) {
   $303 = ((($3) + (($p12$015*176)|0)|0) + 76|0);
   $304 = HEAP32[$303>>2]|0;
   $305 = (($3) + (($p12$015*176)|0)|0);
   $306 = Math_fround(HEAPF32[$305>>2]);
   $307 = (($transientBuf) + (($304*12)|0)|0);
   HEAPF32[$307>>2] = $306;
   $308 = ((($3) + (($p12$015*176)|0)|0) + 4|0);
   $309 = Math_fround(HEAPF32[$308>>2]);
   $310 = ((($transientBuf) + (($304*12)|0)|0) + 4|0);
   HEAPF32[$310>>2] = $309;
   $311 = ((($3) + (($p12$015*176)|0)|0) + 8|0);
   $312 = Math_fround(HEAPF32[$311>>2]);
   $313 = ((($transientBuf) + (($304*12)|0)|0) + 8|0);
   HEAPF32[$313>>2] = $312;
   $314 = (($p12$015) + 1)|0;
   $exitcond57 = ($314|0)==($numParticlesSp|0);
   if ($exitcond57) {
    break;
   } else {
    $p12$015 = $314;
   }
  }
 }
 $315 = ($collisionVelocities|0)==(0|0);
 $brmerge69 = $315 | $4;
 if (!($brmerge69)) {
  $p14$011 = 0;
  while(1) {
   $316 = ((($particlesSp) + ($p14$011<<5)|0) + 16|0);
   $317 = Math_fround(HEAPF32[$316>>2]);
   $318 = ((($3) + (($p14$011*176)|0)|0) + 32|0);
   $319 = Math_fround(HEAPF32[$318>>2]);
   $320 = Math_fround($317 - $319);
   $321 = ((($particlesSp) + ($p14$011<<5)|0) + 20|0);
   $322 = Math_fround(HEAPF32[$321>>2]);
   $323 = ((($3) + (($p14$011*176)|0)|0) + 36|0);
   $324 = Math_fround(HEAPF32[$323>>2]);
   $325 = Math_fround($322 - $324);
   $326 = ((($particlesSp) + ($p14$011<<5)|0) + 24|0);
   $327 = Math_fround(HEAPF32[$326>>2]);
   $328 = ((($3) + (($p14$011*176)|0)|0) + 40|0);
   $329 = Math_fround(HEAPF32[$328>>2]);
   $330 = Math_fround($327 - $329);
   $331 = ((($3) + (($p14$011*176)|0)|0) + 76|0);
   $332 = HEAP32[$331>>2]|0;
   $333 = (($collisionVelocities) + (($332*12)|0)|0);
   HEAPF32[$333>>2] = $320;
   $334 = ((($collisionVelocities) + (($332*12)|0)|0) + 4|0);
   HEAPF32[$334>>2] = $325;
   $335 = ((($collisionVelocities) + (($332*12)|0)|0) + 8|0);
   HEAPF32[$335>>2] = $330;
   $336 = (($p14$011) + 1)|0;
   $exitcond56 = ($336|0)==($numParticlesSp|0);
   if ($exitcond56) {
    break;
   } else {
    $p14$011 = $336;
   }
  }
 }
 $337 = ($fluidTwoWayData|0)==(0|0);
 $brmerge70 = $337 | $4;
 if ($brmerge70) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$3);
  STACKTOP = sp;return;
 } else {
  $p16$08 = 0;
 }
 while(1) {
  $338 = ((($3) + (($p16$08*176)|0)|0) + 108|0);
  $339 = HEAP32[$338>>2]|0;
  $340 = ((($3) + (($p16$08*176)|0)|0) + 76|0);
  $341 = HEAP32[$340>>2]|0;
  $342 = ((($fluidTwoWayData) + ($341<<4)|0) + 12|0);
  HEAP32[$342>>2] = $339;
  $343 = ((($3) + (($p16$08*176)|0)|0) + 96|0);
  $344 = Math_fround(HEAPF32[$343>>2]);
  $345 = (($fluidTwoWayData) + ($341<<4)|0);
  HEAPF32[$345>>2] = $344;
  $346 = ((($3) + (($p16$08*176)|0)|0) + 100|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  $348 = ((($fluidTwoWayData) + ($341<<4)|0) + 4|0);
  HEAPF32[$348>>2] = $347;
  $349 = ((($3) + (($p16$08*176)|0)|0) + 104|0);
  $350 = Math_fround(HEAPF32[$349>>2]);
  $351 = ((($fluidTwoWayData) + ($341<<4)|0) + 8|0);
  HEAPF32[$351>>2] = $350;
  $352 = (($p16$08) + 1)|0;
  $exitcond = ($352|0)==($numParticlesSp|0);
  if ($exitcond) {
   break;
  } else {
   $p16$08 = $352;
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx17PxsFluidCollision26updateFluidBodyContactPairEPKNS_16PxsFluidParticleEjPNS_19PxsParticleCollDataERNS_25PxsFluidConstraintBuffersEPNS_27PxsFluidParticleOpcodeCacheERNS_21PxsFluidLocalCellHashERKNS_6PxVec3ERKNS_31PxsParticleStreamContactManagerERKNS_19PxsW2STransformTempE($this,$particles,$numParticles,$particleCollData,$constraintBufs,$opcodeCacheLocal,$localCellHash,$packetCorner,$contactManager,$w2sTransform) {
 $this = $this|0;
 $particles = $particles|0;
 $numParticles = $numParticles|0;
 $particleCollData = $particleCollData|0;
 $constraintBufs = $constraintBufs|0;
 $opcodeCacheLocal = $opcodeCacheLocal|0;
 $localCellHash = $localCellHash|0;
 $packetCorner = $packetCorner|0;
 $contactManager = $contactManager|0;
 $w2sTransform = $w2sTransform|0;
 var $$pre = Math_fround(0), $$pre36 = Math_fround(0), $$pre37 = Math_fround(0), $$pre38 = Math_fround(0), $$pre39 = Math_fround(0), $$pre40 = Math_fround(0), $$pre41 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0);
 var $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $brmerge = 0, $cdTemp = 0, $exitcond = 0, $exitcond31 = 0, $exitcond32 = 0, $exitcond33 = 0, $exitcond34 = 0, $hashKeyArray = 0, $p$029 = 0, $p2$027 = 0, $p4$023 = 0, $p6$019 = 0, $p8$016 = 0, $scaledPlanesBuf = 0, $shape2World = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $shape2World = sp + 32|0;
 $scaledPlanesBuf = sp;
 $0 = sp + 61|0;
 $hashKeyArray = sp + 24|0;
 $1 = sp + 60|0;
 $cdTemp = sp + 8|0;
 $2 = (($contactManager) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 36|0);
 $5 = (($contactManager) + 13|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $277 = 0;
 } else {
  $8 = HEAP32[$contactManager>>2]|0;
  $277 = $8;
 }
 $9 = (($w2sTransform) + 28|0);
 $10 = (($w2sTransform) + 44|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($w2sTransform) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($w2sTransform) + 52|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($11 * Math_fround(-2.0));
 $17 = Math_fround($13 * Math_fround(-2.0));
 $18 = Math_fround($15 * Math_fround(-2.0));
 $19 = (($w2sTransform) + 40|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $20);
 $22 = Math_fround($21 + Math_fround(-0.5));
 $23 = Math_fround(HEAPF32[$9>>2]);
 $24 = Math_fround($16 * $23);
 $25 = (($w2sTransform) + 32|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($17 * $26);
 $28 = Math_fround($24 + $27);
 $29 = (($w2sTransform) + 36|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($18 * $30);
 $32 = Math_fround($28 + $31);
 $33 = Math_fround($16 * $22);
 $34 = Math_fround($18 * $26);
 $35 = Math_fround($17 * $30);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($20 * $36);
 $38 = Math_fround($33 - $37);
 $39 = Math_fround($23 * $32);
 $40 = Math_fround($39 + $38);
 $41 = Math_fround($17 * $22);
 $42 = Math_fround($16 * $30);
 $43 = Math_fround($18 * $23);
 $44 = Math_fround($42 - $43);
 $45 = Math_fround($20 * $44);
 $46 = Math_fround($41 - $45);
 $47 = Math_fround($26 * $32);
 $48 = Math_fround($47 + $46);
 $49 = Math_fround($18 * $22);
 $50 = Math_fround($17 * $23);
 $51 = Math_fround($16 * $26);
 $52 = Math_fround($50 - $51);
 $53 = Math_fround($20 * $52);
 $54 = Math_fround($49 - $53);
 $55 = Math_fround($30 * $32);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround(-$23);
 $58 = Math_fround(-$26);
 $59 = Math_fround(-$30);
 HEAPF32[$shape2World>>2] = $57;
 $60 = (($shape2World) + 4|0);
 HEAPF32[$60>>2] = $58;
 $61 = (($shape2World) + 8|0);
 HEAPF32[$61>>2] = $59;
 $62 = (($shape2World) + 12|0);
 HEAPF32[$62>>2] = $20;
 $63 = (($shape2World) + 16|0);
 HEAPF32[$63>>2] = $40;
 $64 = (($shape2World) + 20|0);
 HEAPF32[$64>>2] = $48;
 $65 = (($shape2World) + 24|0);
 HEAPF32[$65>>2] = $56;
 $66 = ($numParticles|0)==(0);
 L4: do {
  if (!($66)) {
   $67 = (($w2sTransform) + 12|0);
   $68 = (($w2sTransform) + 4|0);
   $69 = (($w2sTransform) + 8|0);
   $70 = (($w2sTransform) + 16|0);
   $71 = (($w2sTransform) + 20|0);
   $72 = (($w2sTransform) + 24|0);
   $73 = (($constraintBufs) + 4|0);
   $123 = $11;$125 = $13;$127 = $15;$88 = $20;$91 = $23;$93 = $26;$96 = $30;$p$029 = 0;
   while(1) {
    $74 = ((($particleCollData) + (($p$029*176)|0)|0) + 12|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $75 & 2;
    $77 = ((($particleCollData) + (($p$029*176)|0)|0) + 124|0);
    HEAP32[$77>>2] = $76;
    $78 = ((($particleCollData) + (($p$029*176)|0)|0) + 64|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = Math_fround($79 * Math_fround(2.0));
    $81 = ((($particleCollData) + (($p$029*176)|0)|0) + 68|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround($82 * Math_fround(2.0));
    $84 = ((($particleCollData) + (($p$029*176)|0)|0) + 72|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = Math_fround($85 * Math_fround(2.0));
    $87 = Math_fround($88 * $88);
    $89 = Math_fround($87 + Math_fround(-0.5));
    $90 = Math_fround($80 * $91);
    $92 = Math_fround($83 * $93);
    $94 = Math_fround($90 + $92);
    $95 = Math_fround($86 * $96);
    $97 = Math_fround($94 + $95);
    $98 = Math_fround($80 * $89);
    $99 = Math_fround($86 * $93);
    $100 = Math_fround($83 * $96);
    $101 = Math_fround($99 - $100);
    $102 = Math_fround($88 * $101);
    $103 = Math_fround($98 + $102);
    $104 = Math_fround($91 * $97);
    $105 = Math_fround($104 + $103);
    $106 = Math_fround($83 * $89);
    $107 = Math_fround($80 * $96);
    $108 = Math_fround($86 * $91);
    $109 = Math_fround($107 - $108);
    $110 = Math_fround($88 * $109);
    $111 = Math_fround($106 + $110);
    $112 = Math_fround($93 * $97);
    $113 = Math_fround($112 + $111);
    $114 = Math_fround($86 * $89);
    $115 = Math_fround($83 * $91);
    $116 = Math_fround($80 * $93);
    $117 = Math_fround($115 - $116);
    $118 = Math_fround($88 * $117);
    $119 = Math_fround($114 + $118);
    $120 = Math_fround($96 * $97);
    $121 = Math_fround($119 + $120);
    $122 = Math_fround($123 + $105);
    $124 = Math_fround($125 + $113);
    $126 = Math_fround($127 + $121);
    $128 = ((($particleCollData) + (($p$029*176)|0)|0) + 128|0);
    HEAPF32[$128>>2] = $122;
    $129 = ((($particleCollData) + (($p$029*176)|0)|0) + 132|0);
    HEAPF32[$129>>2] = $124;
    $130 = ((($particleCollData) + (($p$029*176)|0)|0) + 136|0);
    HEAPF32[$130>>2] = $126;
    $131 = ((($particleCollData) + (($p$029*176)|0)|0) + 48|0);
    $132 = Math_fround(HEAPF32[$131>>2]);
    $133 = Math_fround($132 * Math_fround(2.0));
    $134 = ((($particleCollData) + (($p$029*176)|0)|0) + 52|0);
    $135 = Math_fround(HEAPF32[$134>>2]);
    $136 = Math_fround($135 * Math_fround(2.0));
    $137 = ((($particleCollData) + (($p$029*176)|0)|0) + 56|0);
    $138 = Math_fround(HEAPF32[$137>>2]);
    $139 = Math_fround($138 * Math_fround(2.0));
    $140 = Math_fround(HEAPF32[$67>>2]);
    $141 = Math_fround($140 * $140);
    $142 = Math_fround($141 + Math_fround(-0.5));
    $143 = Math_fround(HEAPF32[$w2sTransform>>2]);
    $144 = Math_fround($133 * $143);
    $145 = Math_fround(HEAPF32[$68>>2]);
    $146 = Math_fround($136 * $145);
    $147 = Math_fround($144 + $146);
    $148 = Math_fround(HEAPF32[$69>>2]);
    $149 = Math_fround($139 * $148);
    $150 = Math_fround($147 + $149);
    $151 = Math_fround($133 * $142);
    $152 = Math_fround($139 * $145);
    $153 = Math_fround($136 * $148);
    $154 = Math_fround($152 - $153);
    $155 = Math_fround($140 * $154);
    $156 = Math_fround($151 + $155);
    $157 = Math_fround($143 * $150);
    $158 = Math_fround($157 + $156);
    $159 = Math_fround($136 * $142);
    $160 = Math_fround($133 * $148);
    $161 = Math_fround($139 * $143);
    $162 = Math_fround($160 - $161);
    $163 = Math_fround($140 * $162);
    $164 = Math_fround($159 + $163);
    $165 = Math_fround($145 * $150);
    $166 = Math_fround($165 + $164);
    $167 = Math_fround($139 * $142);
    $168 = Math_fround($136 * $143);
    $169 = Math_fround($133 * $145);
    $170 = Math_fround($168 - $169);
    $171 = Math_fround($140 * $170);
    $172 = Math_fround($167 + $171);
    $173 = Math_fround($148 * $150);
    $174 = Math_fround($172 + $173);
    $175 = Math_fround(HEAPF32[$70>>2]);
    $176 = Math_fround($175 + $158);
    $177 = Math_fround(HEAPF32[$71>>2]);
    $178 = Math_fround($177 + $166);
    $179 = Math_fround(HEAPF32[$72>>2]);
    $180 = Math_fround($179 + $174);
    $181 = ((($particleCollData) + (($p$029*176)|0)|0) + 112|0);
    HEAPF32[$181>>2] = $176;
    $182 = ((($particleCollData) + (($p$029*176)|0)|0) + 116|0);
    HEAPF32[$182>>2] = $178;
    $183 = ((($particleCollData) + (($p$029*176)|0)|0) + 120|0);
    HEAPF32[$183>>2] = $180;
    $184 = HEAP32[$constraintBufs>>2]|0;
    $185 = ((($particleCollData) + (($p$029*176)|0)|0) + 76|0);
    $186 = HEAP32[$185>>2]|0;
    $187 = (($184) + ($186<<4)|0);
    $188 = ((($particleCollData) + (($p$029*176)|0)|0) + 140|0);
    HEAP32[$188>>2] = $187;
    $189 = HEAP32[$73>>2]|0;
    $190 = (($189) + ($186<<4)|0);
    $191 = ((($particleCollData) + (($p$029*176)|0)|0) + 156|0);
    HEAP32[$191>>2] = $190;
    $192 = ((($particleCollData) + (($p$029*176)|0)|0) + 144|0);
    HEAPF32[$192>>2] = Math_fround(0.0);
    $193 = ((($particleCollData) + (($p$029*176)|0)|0) + 148|0);
    HEAPF32[$193>>2] = Math_fround(0.0);
    $194 = ((($particleCollData) + (($p$029*176)|0)|0) + 152|0);
    HEAPF32[$194>>2] = Math_fround(0.0);
    $195 = ((($particleCollData) + (($p$029*176)|0)|0) + 160|0);
    HEAPF32[$195>>2] = Math_fround(0.0);
    $196 = ((($particleCollData) + (($p$029*176)|0)|0) + 164|0);
    HEAPF32[$196>>2] = Math_fround(0.0);
    $197 = ((($particleCollData) + (($p$029*176)|0)|0) + 168|0);
    HEAPF32[$197>>2] = Math_fround(0.0);
    $198 = (($p$029) + 1)|0;
    $exitcond34 = ($198|0)==($numParticles|0);
    if ($exitcond34) {
     break L4;
    }
    $$pre = Math_fround(HEAPF32[$19>>2]);
    $$pre36 = Math_fround(HEAPF32[$9>>2]);
    $$pre37 = Math_fround(HEAPF32[$25>>2]);
    $$pre38 = Math_fround(HEAPF32[$29>>2]);
    $$pre39 = Math_fround(HEAPF32[$10>>2]);
    $$pre40 = Math_fround(HEAPF32[$12>>2]);
    $$pre41 = Math_fround(HEAPF32[$14>>2]);
    $123 = $$pre39;$125 = $$pre40;$127 = $$pre41;$88 = $$pre;$91 = $$pre36;$93 = $$pre37;$96 = $$pre38;$p$029 = $198;
   }
  }
 } while(0);
 $199 = HEAP32[$4>>2]|0;
 L10: do {
  switch ($199|0) {
  case 6:  {
   $272 = (($this) + 52|0);
   $273 = Math_fround(HEAPF32[$272>>2]);
   __ZN5physx28collideWithStaticHeightFieldEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEfRKNS_11PxTransformE($particleCollData,$numParticles,$4,$273,$shape2World);
   label = 27;
   break;
  }
  case 1:  {
   $202 = (($this) + 52|0);
   $203 = Math_fround(HEAPF32[$202>>2]);
   __ZN5physx16collideWithPlaneEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($particleCollData,$numParticles,$4,$203);
   label = 29;
   break;
  }
  case 3:  {
   $206 = (($this) + 52|0);
   $207 = Math_fround(HEAPF32[$206>>2]);
   __ZN5physx14collideWithBoxEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($particleCollData,$numParticles,$4,$207);
   label = 29;
   break;
  }
  case 2:  {
   $204 = (($this) + 52|0);
   $205 = Math_fround(HEAPF32[$204>>2]);
   __ZN5physx18collideWithCapsuleEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($particleCollData,$numParticles,$4,$205);
   label = 29;
   break;
  }
  case 0:  {
   $200 = (($this) + 52|0);
   $201 = Math_fround(HEAPF32[$200>>2]);
   __ZN5physx17collideWithSphereEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($particleCollData,$numParticles,$4,$201);
   label = 29;
   break;
  }
  case 5:  {
   $225 = ($opcodeCacheLocal|0)==(0|0);
   if (!($225)) {
    $226 = (($this) + 28|0);
    $227 = Math_fround(HEAPF32[$226>>2]);
    $228 = (($this) + 60|0);
    $229 = Math_fround(HEAPF32[$228>>2]);
    $230 = (($this) + 52|0);
    $231 = Math_fround(HEAPF32[$230>>2]);
    __ZN5physx21collideWithStaticMeshEjPNS_19PxsParticleCollDataEPNS_27PxsFluidParticleOpcodeCacheERKNS_2Gu13GeometryUnionERKNS_11PxTransformESA_fff($numParticles,$particleCollData,$opcodeCacheLocal,$4,$9,$shape2World,$227,$229,$231);
    label = 27;
    break L10;
   }
   $232 = (($localCellHash) + 16|0);
   $233 = HEAP8[$232>>0]|0;
   $234 = ($233<<24>>24)==(0);
   if ($234) {
    $235 = $numParticles << 2;
    $236 = ($235>>>0)>(1024);
    $237 = (($hashKeyArray) + 4|0);
    $238 = $236&1;
    HEAP8[$237>>0] = $238;
    if ($236) {
     $239 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,$235,493824,622)|0);
     HEAP32[$hashKeyArray>>2] = $239;
     $261 = $239;
    } else {
     $240 = STACKTOP; STACKTOP = STACKTOP + ((((1*$235)|0)+15)&-16)|0;;
     HEAP32[$hashKeyArray>>2] = $240;
     $261 = $240;
    }
    $241 = (($this) + 32|0);
    $242 = Math_fround(HEAPF32[$241>>2]);
    $243 = (($numParticles) + 1)|0;
    $244 = $243 >>> 1;
    $245 = $244 | $243;
    $246 = $245 >>> 2;
    $247 = $246 | $245;
    $248 = $247 >>> 4;
    $249 = $248 | $247;
    $250 = $249 >>> 8;
    $251 = $250 | $249;
    $252 = $251 >>> 16;
    $253 = $252 | $251;
    $254 = (($253) + 1)|0;
    $255 = ($254>>>0)>(256);
    $256 = $255 ? 256 : $254;
    $257 = (($localCellHash) + 12|0);
    $258 = HEAP32[$257>>2]|0;
    $259 = (($localCellHash) + 4|0);
    $260 = HEAP32[$259>>2]|0;
    __ZN5physx19PxsFluidSpatialHash14buildLocalHashEPKNS_16PxsFluidParticleEjPNS_15PxsParticleCellEPjPtjfRKNS_6PxVec3E($particles,$numParticles,$258,$260,$261,$256,$242,$packetCorner);
    $262 = (($localCellHash) + 8|0);
    HEAP32[$262>>2] = $256;
    HEAP32[$localCellHash>>2] = $numParticles;
    HEAP8[$232>>0] = 1;
    $263 = HEAP8[$237>>0]|0;
    $264 = ($263<<24>>24)==(0);
    if (!($264)) {
     $265 = HEAP32[$hashKeyArray>>2]|0;
     __ZN5physx6shdfnd13TempAllocator10deallocateEPv($hashKeyArray,$265);
    }
   }
   $266 = (($this) + 28|0);
   $267 = Math_fround(HEAPF32[$266>>2]);
   $268 = (($this) + 60|0);
   $269 = Math_fround(HEAPF32[$268>>2]);
   $270 = (($this) + 52|0);
   $271 = Math_fround(HEAPF32[$270>>2]);
   __ZN5physx26collideCellsWithStaticMeshEPNS_19PxsParticleCollDataERKNS_21PxsFluidLocalCellHashERKNS_2Gu13GeometryUnionERKNS_11PxTransformESB_fffRKNS_6PxVec3E($particleCollData,$localCellHash,$4,$9,$shape2World,$267,$269,$271,$packetCorner);
   label = 27;
   break;
  }
  case 4:  {
   $208 = (($3) + 72|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = (($209) + 39|0);
   $211 = HEAP8[$210>>0]|0;
   $212 = $211&255;
   $213 = $212 << 4;
   $214 = ($213>>>0)>(1024);
   $215 = (($scaledPlanesBuf) + 4|0);
   $216 = $214&1;
   HEAP8[$215>>0] = $216;
   if ($214) {
    $217 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$213,493824,606)|0);
    HEAP32[$scaledPlanesBuf>>2] = $217;
    $221 = $217;
   } else {
    $218 = STACKTOP; STACKTOP = STACKTOP + ((((16*$212)|0)+15)&-16)|0;;
    HEAP32[$scaledPlanesBuf>>2] = $218;
    $221 = $218;
   }
   $219 = (($this) + 52|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   __ZN5physx17collideWithConvexEPNS_7PxPlaneEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($221,$particleCollData,$numParticles,$4,$220);
   $222 = HEAP8[$215>>0]|0;
   $223 = ($222<<24>>24)==(0);
   if ($223) {
    label = 29;
   } else {
    $224 = HEAP32[$scaledPlanesBuf>>2]|0;
    __ZN5physx6shdfnd13TempAllocator10deallocateEPv($scaledPlanesBuf,$224);
    label = 29;
   }
   break;
  }
  default: {
   label = 29;
  }
  }
 } while(0);
 L34: do {
  if ((label|0) == 27) {
   if (!($66)) {
    $p2$027 = 0;
    while(1) {
     $274 = (($particleCollData) + (($p2$027*176)|0)|0);
     __ZN5physx24updateCollDataStaticMeshERNS_19PxsParticleCollDataERKNS_11PxTransformEf($274,$shape2World,Math_fround(0.0));
     $275 = (($p2$027) + 1)|0;
     $exitcond33 = ($275|0)==($numParticles|0);
     if ($exitcond33) {
      break;
     } else {
      $p2$027 = $275;
     }
    }
   }
  }
  else if ((label|0) == 29) {
   $276 = ($277|0)==(0|0);
   if ($276) {
    if ($66) {
     break;
    } else {
     $p6$019 = 0;
    }
    while(1) {
     $298 = (($particleCollData) + (($p6$019*176)|0)|0);
     __ZN5physx20updateCollDataStaticERNS_19PxsParticleCollDataERKNS_11PxTransformEf($298,$shape2World,Math_fround(0.0));
     $299 = (($p6$019) + 1)|0;
     $exitcond31 = ($299|0)==($numParticles|0);
     if ($exitcond31) {
      break L34;
     } else {
      $p6$019 = $299;
     }
    }
   }
   if (!($66)) {
    $278 = (($constraintBufs) + 8|0);
    $279 = (($constraintBufs) + 12|0);
    $280 = (($277) + 64|0);
    $281 = (($277) + 80|0);
    $282 = (($this) + 64|0);
    $p4$023 = 0;
    while(1) {
     $283 = (($particleCollData) + (($p4$023*176)|0)|0);
     $284 = HEAP32[$278>>2]|0;
     $285 = ($284|0)==(0|0);
     if ($285) {
      $294 = $cdTemp;
     } else {
      $286 = ((($particleCollData) + (($p4$023*176)|0)|0) + 76|0);
      $287 = HEAP32[$286>>2]|0;
      $288 = (($284) + ($287<<4)|0);
      $294 = $288;
     }
     $289 = HEAP32[$279>>2]|0;
     $290 = ($289|0)==(0|0);
     if ($290) {
      $295 = $cdTemp;
     } else {
      $291 = ((($particleCollData) + (($p4$023*176)|0)|0) + 76|0);
      $292 = HEAP32[$291>>2]|0;
      $293 = (($289) + ($292<<4)|0);
      $295 = $293;
     }
     ;HEAP32[$294+0>>2]=0|0;HEAP32[$294+4>>2]=0|0;HEAP32[$294+8>>2]=0|0;HEAP32[$294+12>>2]=0|0;
     ;HEAP32[$295+0>>2]=0|0;HEAP32[$295+4>>2]=0|0;HEAP32[$295+8>>2]=0|0;HEAP32[$295+12>>2]=0|0;
     $296 = Math_fround(HEAPF32[$282>>2]);
     __ZN5physx21updateCollDataDynamicERNS_19PxsParticleCollDataERKNS_11PxTransformERKNS_6PxVec3ES7_PKNS_11PxsBodyCoreES4_fRNS_25PxsFluidConstraintDynamicESC_($283,$277,$280,$281,$277,$shape2World,$296,$294,$295);
     $297 = (($p4$023) + 1)|0;
     $exitcond32 = ($297|0)==($numParticles|0);
     if ($exitcond32) {
      break;
     } else {
      $p4$023 = $297;
     }
    }
   }
  }
 } while(0);
 $300 = (($contactManager) + 12|0);
 $301 = HEAP8[$300>>0]|0;
 $302 = ($301<<24>>24)==(0);
 $brmerge = $302 | $66;
 if ($brmerge) {
  STACKTOP = sp;return;
 } else {
  $p8$016 = 0;
 }
 while(1) {
  $303 = ((($particleCollData) + (($p8$016*176)|0)|0) + 124|0);
  $304 = HEAP32[$303>>2]|0;
  $305 = $304 & 56;
  $306 = ($305|0)==(0);
  if (!($306)) {
   $307 = ((($particleCollData) + (($p8$016*176)|0)|0) + 60|0);
   $308 = HEAP16[$307>>1]|0;
   $309 = $308&65535;
   $310 = $309 | 8;
   $311 = $310&65535;
   HEAP16[$307>>1] = $311;
  }
  $312 = (($p8$016) + 1)|0;
  $exitcond = ($312|0)==($numParticles|0);
  if ($exitcond) {
   break;
  } else {
   $p8$016 = $312;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx24updateCollDataStaticMeshERNS_19PxsParticleCollDataERKNS_11PxTransformEf($collData,$shapeToWorld,$0) {
 $collData = $collData|0;
 $shapeToWorld = $shapeToWorld|0;
 $0 = Math_fround($0);
 var $$0$i = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0;
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0;
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($collData) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 56;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $2 & 8;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($collData) + 144|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround($8 * Math_fround(2.0));
  $10 = (($collData) + 148|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($11 * Math_fround(2.0));
  $13 = (($collData) + 152|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($14 * Math_fround(2.0));
  $16 = (($shapeToWorld) + 12|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($17 * $17);
  $19 = Math_fround($18 + Math_fround(-0.5));
  $20 = Math_fround(HEAPF32[$shapeToWorld>>2]);
  $21 = Math_fround($9 * $20);
  $22 = (($shapeToWorld) + 4|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($12 * $23);
  $25 = Math_fround($21 + $24);
  $26 = (($shapeToWorld) + 8|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($15 * $27);
  $29 = Math_fround($25 + $28);
  $30 = Math_fround($9 * $19);
  $31 = Math_fround($15 * $23);
  $32 = Math_fround($12 * $27);
  $33 = Math_fround($31 - $32);
  $34 = Math_fround($17 * $33);
  $35 = Math_fround($30 + $34);
  $36 = Math_fround($20 * $29);
  $37 = Math_fround($36 + $35);
  $38 = Math_fround($12 * $19);
  $39 = Math_fround($9 * $27);
  $40 = Math_fround($15 * $20);
  $41 = Math_fround($39 - $40);
  $42 = Math_fround($17 * $41);
  $43 = Math_fround($38 + $42);
  $44 = Math_fround($23 * $29);
  $45 = Math_fround($44 + $43);
  $46 = Math_fround($15 * $19);
  $47 = Math_fround($12 * $20);
  $48 = Math_fround($9 * $23);
  $49 = Math_fround($47 - $48);
  $50 = Math_fround($17 * $49);
  $51 = Math_fround($46 + $50);
  $52 = Math_fround($27 * $29);
  $53 = Math_fround($51 + $52);
  $54 = (($collData) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = $55 & -4;
  $57 = $56 | 2;
  HEAP32[$54>>2] = $57;
  HEAPF32[$collData>>2] = $37;
  $58 = (($collData) + 4|0);
  HEAPF32[$58>>2] = $45;
  $59 = (($collData) + 8|0);
  HEAPF32[$59>>2] = $53;
  $60 = (($collData) + 48|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($collData) + 16|0);
  HEAPF32[$62>>2] = $61;
  $63 = (($collData) + 52|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($collData) + 20|0);
  HEAPF32[$65>>2] = $64;
  $66 = (($collData) + 56|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = (($collData) + 24|0);
  HEAPF32[$68>>2] = $67;
  $69 = (($collData) + 60|0);
  $70 = HEAP16[$69>>1]|0;
  $71 = $70&65535;
  $72 = $71 | 2;
  $73 = $72&65535;
  HEAP16[$69>>1] = $73;
 }
 $74 = $2 & 16;
 $75 = ($74|0)==(0);
 if ($75) {
  STACKTOP = sp;return;
 }
 $76 = (($collData) + 172|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = $77 < Math_fround(3.0);
 if ($78) {
  $79 = Math_fround($77 + Math_fround(-1.5));
  $80 = $79 >= Math_fround(0.0);
  $81 = $80 ? Math_fround(0.5) : Math_fround(1.0);
  $$0$i = $81;
 } else {
  $82 = Math_fround(Math_fround(1.0) / $77);
  $$0$i = $82;
 }
 $83 = (($collData) + 144|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($$0$i * $84);
 $86 = (($collData) + 148|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($$0$i * $87);
 $89 = (($collData) + 152|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($$0$i * $90);
 $92 = (($collData) + 160|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($$0$i * $93);
 $95 = (($collData) + 164|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($$0$i * $96);
 $98 = (($collData) + 168|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($$0$i * $99);
 $101 = Math_fround($85 * Math_fround(2.0));
 $102 = Math_fround($88 * Math_fround(2.0));
 $103 = Math_fround($91 * Math_fround(2.0));
 $104 = (($shapeToWorld) + 12|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($105 * $105);
 $107 = Math_fround($106 + Math_fround(-0.5));
 $108 = Math_fround(HEAPF32[$shapeToWorld>>2]);
 $109 = Math_fround($101 * $108);
 $110 = (($shapeToWorld) + 4|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($102 * $111);
 $113 = Math_fround($109 + $112);
 $114 = (($shapeToWorld) + 8|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($103 * $115);
 $117 = Math_fround($113 + $116);
 $118 = Math_fround($101 * $107);
 $119 = Math_fround($103 * $111);
 $120 = Math_fround($102 * $115);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($105 * $121);
 $123 = Math_fround($118 + $122);
 $124 = Math_fround($108 * $117);
 $125 = Math_fround($124 + $123);
 $126 = Math_fround($102 * $107);
 $127 = Math_fround($101 * $115);
 $128 = Math_fround($103 * $108);
 $129 = Math_fround($127 - $128);
 $130 = Math_fround($105 * $129);
 $131 = Math_fround($126 + $130);
 $132 = Math_fround($111 * $117);
 $133 = Math_fround($132 + $131);
 $134 = Math_fround($103 * $107);
 $135 = Math_fround($102 * $108);
 $136 = Math_fround($101 * $111);
 $137 = Math_fround($135 - $136);
 $138 = Math_fround($105 * $137);
 $139 = Math_fround($134 + $138);
 $140 = Math_fround($115 * $117);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($77 * $125);
 $143 = Math_fround($77 * $133);
 $144 = Math_fround($77 * $141);
 $145 = Math_fround($94 * Math_fround(2.0));
 $146 = Math_fround($97 * Math_fround(2.0));
 $147 = Math_fround($100 * Math_fround(2.0));
 $148 = Math_fround($145 * $108);
 $149 = Math_fround($146 * $111);
 $150 = Math_fround($148 + $149);
 $151 = Math_fround($147 * $115);
 $152 = Math_fround($150 + $151);
 $153 = Math_fround($145 * $107);
 $154 = Math_fround($147 * $111);
 $155 = Math_fround($146 * $115);
 $156 = Math_fround($154 - $155);
 $157 = Math_fround($105 * $156);
 $158 = Math_fround($153 + $157);
 $159 = Math_fround($108 * $152);
 $160 = Math_fround($159 + $158);
 $161 = Math_fround($146 * $107);
 $162 = Math_fround($145 * $115);
 $163 = Math_fround($147 * $108);
 $164 = Math_fround($162 - $163);
 $165 = Math_fround($105 * $164);
 $166 = Math_fround($161 + $165);
 $167 = Math_fround($111 * $152);
 $168 = Math_fround($167 + $166);
 $169 = Math_fround($147 * $107);
 $170 = Math_fround($146 * $108);
 $171 = Math_fround($145 * $111);
 $172 = Math_fround($170 - $171);
 $173 = Math_fround($105 * $172);
 $174 = Math_fround($169 + $173);
 $175 = Math_fround($115 * $152);
 $176 = Math_fround($174 + $175);
 $177 = (($shapeToWorld) + 16|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = Math_fround($178 + $160);
 $180 = (($shapeToWorld) + 20|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = Math_fround($181 + $168);
 $183 = (($shapeToWorld) + 24|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = Math_fround($184 + $176);
 $186 = Math_fround($77 * $179);
 $187 = Math_fround($77 * $182);
 $188 = Math_fround($77 * $185);
 $189 = (($collData) + 12|0);
 $190 = HEAP32[$189>>2]|0;
 $191 = $190 | 1;
 HEAP32[$189>>2] = $191;
 $192 = $190 & 4;
 $193 = ($192|0)==(0);
 if ($193) {
  $197 = Math_fround(HEAPF32[$collData>>2]);
  $198 = Math_fround($142 + $197);
  HEAPF32[$collData>>2] = $198;
  $199 = (($collData) + 4|0);
  $200 = Math_fround(HEAPF32[$199>>2]);
  $201 = Math_fround($143 + $200);
  HEAPF32[$199>>2] = $201;
  $202 = (($collData) + 8|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = Math_fround($144 + $203);
  HEAPF32[$202>>2] = $204;
 } else {
  HEAPF32[$collData>>2] = $142;
  $194 = (($collData) + 4|0);
  HEAPF32[$194>>2] = $143;
  $195 = (($collData) + 8|0);
  HEAPF32[$195>>2] = $144;
  $196 = $191 & -5;
  HEAP32[$189>>2] = $196;
 }
 $205 = (($collData) + 16|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = Math_fround($186 + $206);
 HEAPF32[$205>>2] = $207;
 $208 = (($collData) + 20|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = Math_fround($187 + $209);
 HEAPF32[$208>>2] = $210;
 $211 = (($collData) + 24|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = Math_fround($188 + $212);
 HEAPF32[$211>>2] = $213;
 $214 = Math_fround(HEAPF32[$76>>2]);
 $215 = (($collData) + 28|0);
 $216 = Math_fround(HEAPF32[$215>>2]);
 $217 = Math_fround($214 + $216);
 HEAPF32[$215>>2] = $217;
 $218 = (($collData) + 60|0);
 $219 = HEAP16[$218>>1]|0;
 $220 = $219&65535;
 $221 = $220 | 2;
 $222 = $221&65535;
 HEAP16[$218>>1] = $222;
 STACKTOP = sp;return;
}
function __ZN5physx21updateCollDataDynamicERNS_19PxsParticleCollDataERKNS_11PxTransformERKNS_6PxVec3ES7_PKNS_11PxsBodyCoreES4_fRNS_25PxsFluidConstraintDynamicESC_($collData,$bodyToWorld,$linearVel,$angularVel,$twoWayBody,$shapeToWorld,$timeStep,$c0Dynamic,$c1Dynamic) {
 $collData = $collData|0;
 $bodyToWorld = $bodyToWorld|0;
 $linearVel = $linearVel|0;
 $angularVel = $angularVel|0;
 $twoWayBody = $twoWayBody|0;
 $shapeToWorld = $shapeToWorld|0;
 $timeStep = Math_fround($timeStep);
 $c0Dynamic = $c0Dynamic|0;
 $c1Dynamic = $c1Dynamic|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0;
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0;
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0;
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $newSurfaceNormal = 0, $newSurfacePos = 0, $newSurfaceVel = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $newSurfaceNormal = sp + 24|0;
 $newSurfacePos = sp;
 $newSurfaceVel = sp + 12|0;
 $0 = (($collData) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 56;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($collData) + 144|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = (($collData) + 148|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * Math_fround(2.0));
 $10 = (($collData) + 152|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * Math_fround(2.0));
 $13 = (($shapeToWorld) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $14);
 $16 = Math_fround($15 + Math_fround(-0.5));
 $17 = Math_fround(HEAPF32[$shapeToWorld>>2]);
 $18 = Math_fround($6 * $17);
 $19 = (($shapeToWorld) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($9 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($shapeToWorld) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($12 * $24);
 $26 = Math_fround($22 + $25);
 $27 = Math_fround($6 * $16);
 $28 = Math_fround($12 * $20);
 $29 = Math_fround($9 * $24);
 $30 = Math_fround($28 - $29);
 $31 = Math_fround($14 * $30);
 $32 = Math_fround($27 + $31);
 $33 = Math_fround($17 * $26);
 $34 = Math_fround($33 + $32);
 $35 = Math_fround($9 * $16);
 $36 = Math_fround($6 * $24);
 $37 = Math_fround($12 * $17);
 $38 = Math_fround($36 - $37);
 $39 = Math_fround($14 * $38);
 $40 = Math_fround($35 + $39);
 $41 = Math_fround($20 * $26);
 $42 = Math_fround($41 + $40);
 $43 = Math_fround($12 * $16);
 $44 = Math_fround($9 * $17);
 $45 = Math_fround($6 * $20);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($14 * $46);
 $48 = Math_fround($43 + $47);
 $49 = Math_fround($24 * $26);
 $50 = Math_fround($48 + $49);
 HEAPF32[$newSurfaceNormal>>2] = $34;
 $51 = (($newSurfaceNormal) + 4|0);
 HEAPF32[$51>>2] = $42;
 $52 = (($newSurfaceNormal) + 8|0);
 HEAPF32[$52>>2] = $50;
 $53 = (($collData) + 160|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 * Math_fround(2.0));
 $56 = (($collData) + 164|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 * Math_fround(2.0));
 $59 = (($collData) + 168|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 * Math_fround(2.0));
 $62 = Math_fround($55 * $17);
 $63 = Math_fround($58 * $20);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($61 * $24);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($55 * $16);
 $68 = Math_fround($61 * $20);
 $69 = Math_fround($58 * $24);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($14 * $70);
 $72 = Math_fround($67 + $71);
 $73 = Math_fround($17 * $66);
 $74 = Math_fround($73 + $72);
 $75 = Math_fround($58 * $16);
 $76 = Math_fround($55 * $24);
 $77 = Math_fround($61 * $17);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($14 * $78);
 $80 = Math_fround($75 + $79);
 $81 = Math_fround($20 * $66);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($61 * $16);
 $84 = Math_fround($58 * $17);
 $85 = Math_fround($55 * $20);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($14 * $86);
 $88 = Math_fround($83 + $87);
 $89 = Math_fround($24 * $66);
 $90 = Math_fround($88 + $89);
 $91 = (($shapeToWorld) + 16|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($92 + $74);
 $94 = (($shapeToWorld) + 20|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($95 + $82);
 $97 = (($shapeToWorld) + 24|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($98 + $90);
 HEAPF32[$newSurfacePos>>2] = $93;
 $100 = (($newSurfacePos) + 4|0);
 HEAPF32[$100>>2] = $96;
 $101 = (($newSurfacePos) + 8|0);
 HEAPF32[$101>>2] = $99;
 $102 = (($bodyToWorld) + 16|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($93 - $103);
 $105 = (($bodyToWorld) + 20|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($96 - $106);
 $108 = (($bodyToWorld) + 24|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($99 - $109);
 $111 = (($angularVel) + 4|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($112 * $110);
 $114 = (($angularVel) + 8|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($107 * $115);
 $117 = Math_fround($113 - $116);
 $118 = Math_fround($104 * $115);
 $119 = Math_fround(HEAPF32[$angularVel>>2]);
 $120 = Math_fround($110 * $119);
 $121 = Math_fround($118 - $120);
 $122 = Math_fround($107 * $119);
 $123 = Math_fround($104 * $112);
 $124 = Math_fround($122 - $123);
 $125 = Math_fround(HEAPF32[$linearVel>>2]);
 $126 = Math_fround($117 + $125);
 $127 = (($linearVel) + 4|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($121 + $128);
 $130 = (($linearVel) + 8|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($124 + $131);
 HEAPF32[$newSurfaceVel>>2] = $126;
 $133 = (($newSurfaceVel) + 4|0);
 HEAPF32[$133>>2] = $129;
 $134 = (($newSurfaceVel) + 8|0);
 HEAPF32[$134>>2] = $132;
 $135 = HEAP32[$0>>2]|0;
 $136 = $135 & 8;
 $137 = ($136|0)==(0);
 if (!($137)) {
  $138 = (($collData) + 12|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = $139 & -4;
  $141 = $140 | 2;
  HEAP32[$138>>2] = $141;
  $142 = Math_fround(HEAPF32[$newSurfaceNormal>>2]);
  HEAPF32[$collData>>2] = $142;
  $143 = (($collData) + 4|0);
  HEAPF32[$143>>2] = $42;
  $144 = (($collData) + 8|0);
  HEAPF32[$144>>2] = $50;
  $145 = (($collData) + 16|0);
  HEAPF32[$145>>2] = $93;
  $146 = (($collData) + 20|0);
  HEAPF32[$146>>2] = $96;
  $147 = (($collData) + 24|0);
  HEAPF32[$147>>2] = $99;
  $148 = (($collData) + 32|0);
  HEAPF32[$148>>2] = $126;
  $149 = (($collData) + 36|0);
  HEAPF32[$149>>2] = $129;
  $150 = (($collData) + 40|0);
  HEAPF32[$150>>2] = $132;
  $151 = (($collData) + 108|0);
  HEAP32[$151>>2] = $twoWayBody;
  $152 = (($collData) + 60|0);
  $153 = HEAP16[$152>>1]|0;
  $154 = $153&65535;
  $155 = $154 | 4;
  $156 = $155&65535;
  HEAP16[$152>>1] = $156;
 }
 $157 = $135 & 16;
 $158 = ($157|0)==(0);
 if (!($158)) {
  $159 = (($collData) + 12|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = $160 | 1;
  HEAP32[$159>>2] = $161;
  $162 = $160 & 4;
  $163 = ($162|0)==(0);
  $164 = Math_fround(HEAPF32[$newSurfaceNormal>>2]);
  if ($163) {
   $171 = Math_fround(HEAPF32[$collData>>2]);
   $172 = Math_fround($164 + $171);
   HEAPF32[$collData>>2] = $172;
   $173 = (($collData) + 4|0);
   $174 = Math_fround(HEAPF32[$173>>2]);
   $175 = Math_fround($42 + $174);
   HEAPF32[$173>>2] = $175;
   $176 = (($collData) + 8|0);
   $177 = Math_fround(HEAPF32[$176>>2]);
   $178 = Math_fround($50 + $177);
   HEAPF32[$176>>2] = $178;
   $179 = (($collData) + 32|0);
   $180 = Math_fround(HEAPF32[$179>>2]);
   $181 = Math_fround($126 + $180);
   HEAPF32[$179>>2] = $181;
   $182 = (($collData) + 36|0);
   $183 = Math_fround(HEAPF32[$182>>2]);
   $184 = Math_fround($129 + $183);
   HEAPF32[$182>>2] = $184;
   $185 = (($collData) + 40|0);
   $186 = Math_fround(HEAPF32[$185>>2]);
   $187 = Math_fround($132 + $186);
   HEAPF32[$185>>2] = $187;
  } else {
   HEAPF32[$collData>>2] = $164;
   $165 = (($collData) + 4|0);
   HEAPF32[$165>>2] = $42;
   $166 = (($collData) + 8|0);
   HEAPF32[$166>>2] = $50;
   $167 = (($collData) + 32|0);
   HEAPF32[$167>>2] = $126;
   $168 = (($collData) + 36|0);
   HEAPF32[$168>>2] = $129;
   $169 = (($collData) + 40|0);
   HEAPF32[$169>>2] = $132;
   $170 = $161 & -5;
   HEAP32[$159>>2] = $170;
  }
  $188 = (($collData) + 16|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = Math_fround($93 + $189);
  HEAPF32[$188>>2] = $190;
  $191 = (($collData) + 20|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = Math_fround($96 + $192);
  HEAPF32[$191>>2] = $193;
  $194 = (($collData) + 24|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($99 + $195);
  HEAPF32[$194>>2] = $196;
  $197 = (($collData) + 28|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = Math_fround($198 + Math_fround(1.0));
  HEAPF32[$197>>2] = $199;
  $200 = (($collData) + 108|0);
  HEAP32[$200>>2] = $twoWayBody;
  $201 = (($collData) + 60|0);
  $202 = HEAP16[$201>>1]|0;
  $203 = $202&65535;
  $204 = $203 | 4;
  $205 = $204&65535;
  HEAP16[$201>>1] = $205;
 }
 $206 = $135 & 40;
 $207 = ($206|0)==(0);
 if ($207) {
  STACKTOP = sp;return;
 }
 $208 = Math_fround($104 * $104);
 $209 = Math_fround($107 * $107);
 $210 = Math_fround($208 + $209);
 $211 = Math_fround($110 * $110);
 $212 = Math_fround($210 + $211);
 $213 = (Math_fround(Math_sqrt((Math_fround($212)))));
 $214 = Math_fround($117 * $timeStep);
 $215 = Math_fround($121 * $timeStep);
 $216 = Math_fround($124 * $timeStep);
 $217 = Math_fround($104 + $214);
 $218 = Math_fround($107 + $215);
 $219 = Math_fround($110 + $216);
 HEAPF32[$newSurfacePos>>2] = $217;
 HEAPF32[$100>>2] = $218;
 HEAPF32[$101>>2] = $219;
 $220 = Math_fround($217 * $217);
 $221 = Math_fround($218 * $218);
 $222 = Math_fround($220 + $221);
 $223 = Math_fround($219 * $219);
 $224 = Math_fround($223 + $222);
 $225 = $224 > Math_fround(0.0);
 if ($225) {
  $226 = (Math_fround(Math_sqrt((Math_fround($224)))));
  $227 = Math_fround(Math_fround(1.0) / $226);
  $228 = Math_fround($217 * $227);
  $229 = Math_fround($218 * $227);
  $230 = Math_fround($219 * $227);
  $232 = $228;$234 = $229;$236 = $230;
 } else {
  $232 = Math_fround(0.0);$234 = Math_fround(0.0);$236 = Math_fround(0.0);
 }
 $231 = Math_fround($213 * $232);
 $233 = Math_fround($213 * $234);
 $235 = Math_fround($213 * $236);
 $237 = Math_fround(HEAPF32[$linearVel>>2]);
 $238 = Math_fround($237 * $timeStep);
 $239 = Math_fround(HEAPF32[$127>>2]);
 $240 = Math_fround($239 * $timeStep);
 $241 = Math_fround(HEAPF32[$130>>2]);
 $242 = Math_fround($241 * $timeStep);
 $243 = Math_fround(HEAPF32[$102>>2]);
 $244 = Math_fround($238 + $243);
 $245 = Math_fround(HEAPF32[$105>>2]);
 $246 = Math_fround($240 + $245);
 $247 = Math_fround(HEAPF32[$108>>2]);
 $248 = Math_fround($242 + $247);
 $249 = Math_fround($244 + $231);
 HEAPF32[$newSurfacePos>>2] = $249;
 $250 = Math_fround($246 + $233);
 HEAPF32[$100>>2] = $250;
 $251 = Math_fround($248 + $235);
 HEAPF32[$101>>2] = $251;
 $252 = Math_fround(HEAPF32[$111>>2]);
 $253 = Math_fround($252 * $50);
 $254 = Math_fround(HEAPF32[$114>>2]);
 $255 = Math_fround($254 * $42);
 $256 = Math_fround($253 - $255);
 $257 = Math_fround(HEAPF32[$newSurfaceNormal>>2]);
 $258 = Math_fround($254 * $257);
 $259 = Math_fround(HEAPF32[$angularVel>>2]);
 $260 = Math_fround($50 * $259);
 $261 = Math_fround($258 - $260);
 $262 = Math_fround($42 * $259);
 $263 = Math_fround($252 * $257);
 $264 = Math_fround($262 - $263);
 $265 = Math_fround($256 * $timeStep);
 $266 = Math_fround($261 * $timeStep);
 $267 = Math_fround($264 * $timeStep);
 $268 = Math_fround($257 + $265);
 HEAPF32[$newSurfaceNormal>>2] = $268;
 $269 = Math_fround($42 + $266);
 HEAPF32[$51>>2] = $269;
 $270 = Math_fround($50 + $267);
 HEAPF32[$52>>2] = $270;
 $271 = Math_fround($268 * $268);
 $272 = Math_fround($269 * $269);
 $273 = Math_fround($271 + $272);
 $274 = Math_fround($270 * $270);
 $275 = Math_fround($274 + $273);
 $276 = $275 > Math_fround(0.0);
 if ($276) {
  $277 = (Math_fround(Math_sqrt((Math_fround($275)))));
  $278 = Math_fround(Math_fround(1.0) / $277);
  $279 = Math_fround($268 * $278);
  $280 = Math_fround($269 * $278);
  $281 = Math_fround($270 * $278);
  $282 = $279;$283 = $280;$284 = $281;
 } else {
  $282 = Math_fround(0.0);$283 = Math_fround(0.0);$284 = Math_fround(0.0);
 }
 HEAPF32[$newSurfaceNormal>>2] = $282;
 HEAPF32[$51>>2] = $283;
 HEAPF32[$52>>2] = $284;
 __ZN5physx20addConstraintDynamicERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_S4_PKNS_11PxsBodyCoreERNS_25PxsFluidConstraintDynamicES9_($collData,$newSurfaceNormal,$newSurfacePos,$newSurfaceVel,$twoWayBody,$c0Dynamic,$c1Dynamic);
 STACKTOP = sp;return;
}
function __ZN5physx20updateCollDataStaticERNS_19PxsParticleCollDataERKNS_11PxTransformEf($collData,$shapeToWorld,$0) {
 $collData = $collData|0;
 $shapeToWorld = $shapeToWorld|0;
 $0 = Math_fround($0);
 var $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0);
 var $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0;
 var $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $newSurfaceNormal = 0, $newSurfacePos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $newSurfaceNormal = sp + 12|0;
 $newSurfacePos = sp;
 $1 = (($collData) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 56;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($collData) + 144|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * Math_fround(2.0));
 $8 = (($collData) + 148|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * Math_fround(2.0));
 $11 = (($collData) + 152|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * Math_fround(2.0));
 $14 = (($shapeToWorld) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $15);
 $17 = Math_fround($16 + Math_fround(-0.5));
 $18 = Math_fround(HEAPF32[$shapeToWorld>>2]);
 $19 = Math_fround($7 * $18);
 $20 = (($shapeToWorld) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($10 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($shapeToWorld) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($13 * $25);
 $27 = Math_fround($23 + $26);
 $28 = Math_fround($7 * $17);
 $29 = Math_fround($13 * $21);
 $30 = Math_fround($10 * $25);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround($15 * $31);
 $33 = Math_fround($28 + $32);
 $34 = Math_fround($18 * $27);
 $35 = Math_fround($34 + $33);
 $36 = Math_fround($10 * $17);
 $37 = Math_fround($7 * $25);
 $38 = Math_fround($13 * $18);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($15 * $39);
 $41 = Math_fround($36 + $40);
 $42 = Math_fround($21 * $27);
 $43 = Math_fround($42 + $41);
 $44 = Math_fround($13 * $17);
 $45 = Math_fround($10 * $18);
 $46 = Math_fround($7 * $21);
 $47 = Math_fround($45 - $46);
 $48 = Math_fround($15 * $47);
 $49 = Math_fround($44 + $48);
 $50 = Math_fround($25 * $27);
 $51 = Math_fround($49 + $50);
 HEAPF32[$newSurfaceNormal>>2] = $35;
 $52 = (($newSurfaceNormal) + 4|0);
 HEAPF32[$52>>2] = $43;
 $53 = (($newSurfaceNormal) + 8|0);
 HEAPF32[$53>>2] = $51;
 $54 = (($collData) + 160|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * Math_fround(2.0));
 $57 = (($collData) + 164|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 * Math_fround(2.0));
 $60 = (($collData) + 168|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 * Math_fround(2.0));
 $63 = Math_fround($56 * $18);
 $64 = Math_fround($59 * $21);
 $65 = Math_fround($63 + $64);
 $66 = Math_fround($62 * $25);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($56 * $17);
 $69 = Math_fround($62 * $21);
 $70 = Math_fround($59 * $25);
 $71 = Math_fround($69 - $70);
 $72 = Math_fround($15 * $71);
 $73 = Math_fround($68 + $72);
 $74 = Math_fround($18 * $67);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($59 * $17);
 $77 = Math_fround($56 * $25);
 $78 = Math_fround($62 * $18);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($15 * $79);
 $81 = Math_fround($76 + $80);
 $82 = Math_fround($21 * $67);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($62 * $17);
 $85 = Math_fround($59 * $18);
 $86 = Math_fround($56 * $21);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($15 * $87);
 $89 = Math_fround($84 + $88);
 $90 = Math_fround($25 * $67);
 $91 = Math_fround($89 + $90);
 $92 = (($shapeToWorld) + 16|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($93 + $75);
 $95 = (($shapeToWorld) + 20|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($96 + $83);
 $98 = (($shapeToWorld) + 24|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($99 + $91);
 HEAPF32[$newSurfacePos>>2] = $94;
 $101 = (($newSurfacePos) + 4|0);
 HEAPF32[$101>>2] = $97;
 $102 = (($newSurfacePos) + 8|0);
 HEAPF32[$102>>2] = $100;
 $103 = HEAP32[$1>>2]|0;
 $104 = $103 & 8;
 $105 = ($104|0)==(0);
 if (!($105)) {
  $106 = (($collData) + 12|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = $107 & -4;
  $109 = $108 | 2;
  HEAP32[$106>>2] = $109;
  HEAPF32[$collData>>2] = $35;
  $110 = (($collData) + 4|0);
  HEAPF32[$110>>2] = $43;
  $111 = (($collData) + 8|0);
  HEAPF32[$111>>2] = $51;
  $112 = (($collData) + 16|0);
  HEAPF32[$112>>2] = $94;
  $113 = (($collData) + 20|0);
  HEAPF32[$113>>2] = $97;
  $114 = (($collData) + 24|0);
  HEAPF32[$114>>2] = $100;
  $115 = (($collData) + 60|0);
  $116 = HEAP16[$115>>1]|0;
  $117 = $116&65535;
  $118 = $117 | 2;
  $119 = $118&65535;
  HEAP16[$115>>1] = $119;
 }
 $120 = $103 & 16;
 $121 = ($120|0)==(0);
 if (!($121)) {
  $122 = (($collData) + 12|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = $123 | 1;
  HEAP32[$122>>2] = $124;
  $125 = $123 & 4;
  $126 = ($125|0)==(0);
  if ($126) {
   $130 = Math_fround(HEAPF32[$collData>>2]);
   $131 = Math_fround($35 + $130);
   HEAPF32[$collData>>2] = $131;
   $132 = (($collData) + 4|0);
   $133 = Math_fround(HEAPF32[$132>>2]);
   $134 = Math_fround($43 + $133);
   HEAPF32[$132>>2] = $134;
   $135 = (($collData) + 8|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = Math_fround($51 + $136);
   HEAPF32[$135>>2] = $137;
  } else {
   HEAPF32[$collData>>2] = $35;
   $127 = (($collData) + 4|0);
   HEAPF32[$127>>2] = $43;
   $128 = (($collData) + 8|0);
   HEAPF32[$128>>2] = $51;
   $129 = $124 & -5;
   HEAP32[$122>>2] = $129;
  }
  $138 = (($collData) + 16|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($94 + $139);
  HEAPF32[$138>>2] = $140;
  $141 = (($collData) + 20|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = Math_fround($97 + $142);
  HEAPF32[$141>>2] = $143;
  $144 = (($collData) + 24|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = Math_fround($100 + $145);
  HEAPF32[$144>>2] = $146;
  $147 = (($collData) + 28|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = Math_fround($148 + Math_fround(1.0));
  HEAPF32[$147>>2] = $149;
  $150 = (($collData) + 60|0);
  $151 = HEAP16[$150>>1]|0;
  $152 = $151&65535;
  $153 = $152 | 2;
  $154 = $153&65535;
  HEAP16[$150>>1] = $154;
 }
 $155 = $103 & 40;
 $156 = ($155|0)==(0);
 if ($156) {
  STACKTOP = sp;return;
 }
 __ZN5physx13addConstraintERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_($collData,$newSurfaceNormal,$newSurfacePos);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_17PxsFluidCollisionEXadL_ZNS2_12mergeResultsEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_17PxsFluidCollisionEXadL_ZNS2_12mergeResultsEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_17PxsFluidCollisionEXadL_ZNS2_12mergeResultsEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $$pre$i = Math_fround(0), $$pre2$i = Math_fround(0), $$pre3$i = Math_fround(0), $$pre4$i = Math_fround(0), $$pre5$i = Math_fround(0), $$pre6$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0;
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = (($5) + 28|0);
 $8 = (($5) + 32|0);
 $9 = (($5) + 36|0);
 $10 = (($5) + 40|0);
 $11 = (($5) + 44|0);
 $$pre$i = Math_fround(HEAPF32[$6>>2]);
 $$pre2$i = Math_fround(HEAPF32[$7>>2]);
 $$pre3$i = Math_fround(HEAPF32[$8>>2]);
 $$pre4$i = Math_fround(HEAPF32[$9>>2]);
 $$pre5$i = Math_fround(HEAPF32[$10>>2]);
 $$pre6$i = Math_fround(HEAPF32[$11>>2]);
 $15 = $$pre$i;$20 = $$pre2$i;$25 = $$pre3$i;$30 = $$pre4$i;$35 = $$pre5$i;$40 = $$pre6$i;$i$01$i = 0;
 while(1) {
  $12 = ((($1) + (($i$01$i*44)|0)|0) + 120|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = $15 < $13;
  $16 = $14 ? $15 : $13;
  $17 = ((($1) + (($i$01$i*44)|0)|0) + 124|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = $20 < $18;
  $21 = $19 ? $20 : $18;
  $22 = ((($1) + (($i$01$i*44)|0)|0) + 128|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = $25 < $23;
  $26 = $24 ? $25 : $23;
  HEAPF32[$6>>2] = $16;
  HEAPF32[$7>>2] = $21;
  HEAPF32[$8>>2] = $26;
  $27 = ((($1) + (($i$01$i*44)|0)|0) + 132|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = $30 > $28;
  $31 = $29 ? $30 : $28;
  $32 = ((($1) + (($i$01$i*44)|0)|0) + 136|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = $35 > $33;
  $36 = $34 ? $35 : $33;
  $37 = ((($1) + (($i$01$i*44)|0)|0) + 140|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = $40 > $38;
  $41 = $39 ? $40 : $38;
  HEAPF32[$9>>2] = $31;
  HEAPF32[$10>>2] = $36;
  HEAPF32[$11>>2] = $41;
  $42 = (($i$01$i) + 1)|0;
  $exitcond$i = ($42|0)==(8);
  if ($exitcond$i) {
   break;
  } else {
   $15 = $16;$20 = $21;$25 = $26;$30 = $31;$35 = $36;$40 = $41;$i$01$i = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx13addConstraintERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_($collData,$newSurfaceNormal,$newSurfacePos) {
 $collData = $collData|0;
 $newSurfaceNormal = $newSurfaceNormal|0;
 $newSurfacePos = $newSurfacePos|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$newSurfaceNormal>>2]);
 $1 = (($newSurfaceNormal) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($newSurfaceNormal) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$newSurfacePos>>2]);
 $6 = Math_fround($0 * $5);
 $7 = (($newSurfacePos) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($2 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($newSurfacePos) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($4 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($collData) + 62|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = $17 & 1;
 $19 = ($18|0)==(0);
 if ($19) {
  $20 = (($collData) + 140|0);
  $21 = HEAP32[$20>>2]|0;
  HEAPF32[$21>>2] = $0;
  $22 = (($21) + 4|0);
  HEAPF32[$22>>2] = $2;
  $23 = (($21) + 8|0);
  HEAPF32[$23>>2] = $4;
  $24 = (($21) + 12|0);
  HEAPF32[$24>>2] = $14;
  $25 = $17 | 1;
  $26 = $25&65535;
  HEAP16[$15>>1] = $26;
  STACKTOP = sp;return;
 }
 $27 = $17 & 2;
 $28 = ($27|0)==(0);
 if ($28) {
  $29 = (($collData) + 156|0);
  $30 = HEAP32[$29>>2]|0;
  HEAPF32[$30>>2] = $0;
  $31 = (($30) + 4|0);
  HEAPF32[$31>>2] = $2;
  $32 = (($30) + 8|0);
  HEAPF32[$32>>2] = $4;
  $33 = (($30) + 12|0);
  HEAPF32[$33>>2] = $14;
  $34 = $17 | 2;
  $35 = $34&65535;
  HEAP16[$15>>1] = $35;
  STACKTOP = sp;return;
 }
 $36 = (($collData) + 140|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($collData) + 48|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 * $40);
 $42 = (($37) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($collData) + 52|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 * $45);
 $47 = Math_fround($41 + $46);
 $48 = (($37) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($collData) + 56|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($49 * $51);
 $53 = Math_fround($47 + $52);
 $54 = (($37) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($53 - $55);
 $57 = (($collData) + 156|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($40 * $59);
 $61 = (($58) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($45 * $62);
 $64 = Math_fround($60 + $63);
 $65 = (($58) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($51 * $66);
 $68 = Math_fround($64 + $67);
 $69 = (($58) + 12|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($68 - $70);
 $72 = Math_fround($0 * $40);
 $73 = Math_fround($2 * $45);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($4 * $51);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($76 - $14);
 $78 = $56 < $71;
 if ($78) {
  $79 = $77 < $71;
  if (!($79)) {
   STACKTOP = sp;return;
  }
  HEAPF32[$58>>2] = $0;
  HEAPF32[$61>>2] = $2;
  HEAPF32[$65>>2] = $4;
  HEAPF32[$69>>2] = $14;
  $80 = $17 & 65525;
  $81 = $80 | 2;
  $82 = $81&65535;
  HEAP16[$15>>1] = $82;
  STACKTOP = sp;return;
 } else {
  $83 = $77 < $56;
  if (!($83)) {
   STACKTOP = sp;return;
  }
  HEAPF32[$37>>2] = $0;
  HEAPF32[$42>>2] = $2;
  HEAPF32[$48>>2] = $4;
  HEAPF32[$54>>2] = $14;
  $84 = $17 & 65530;
  $85 = $84 | 1;
  $86 = $85&65535;
  HEAP16[$15>>1] = $86;
  STACKTOP = sp;return;
 }
}
function __ZN5physx20addConstraintDynamicERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_S4_PKNS_11PxsBodyCoreERNS_25PxsFluidConstraintDynamicES9_($collData,$newSurfaceNormal,$newSurfacePos,$newSurfaceVel,$body,$c0Dynamic,$c1Dynamic) {
 $collData = $collData|0;
 $newSurfaceNormal = $newSurfaceNormal|0;
 $newSurfacePos = $newSurfacePos|0;
 $newSurfaceVel = $newSurfaceVel|0;
 $body = $body|0;
 $c0Dynamic = $c0Dynamic|0;
 $c1Dynamic = $c1Dynamic|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0;
 var $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0);
 var $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0);
 var $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$newSurfaceNormal>>2]);
 $1 = (($newSurfaceNormal) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($newSurfaceNormal) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$newSurfacePos>>2]);
 $6 = Math_fround($0 * $5);
 $7 = (($newSurfacePos) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($2 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($newSurfacePos) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($4 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($collData) + 62|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = $17 & 1;
 $19 = ($18|0)==(0);
 if ($19) {
  $20 = (($collData) + 140|0);
  $21 = HEAP32[$20>>2]|0;
  HEAPF32[$21>>2] = $0;
  $22 = (($21) + 4|0);
  HEAPF32[$22>>2] = $2;
  $23 = (($21) + 8|0);
  HEAPF32[$23>>2] = $4;
  $24 = (($21) + 12|0);
  HEAPF32[$24>>2] = $14;
  $25 = Math_fround(HEAPF32[$newSurfaceVel>>2]);
  HEAPF32[$c0Dynamic>>2] = $25;
  $26 = (($newSurfaceVel) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($c0Dynamic) + 4|0);
  HEAPF32[$28>>2] = $27;
  $29 = (($newSurfaceVel) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($c0Dynamic) + 8|0);
  HEAPF32[$31>>2] = $30;
  $32 = (($c0Dynamic) + 12|0);
  HEAP32[$32>>2] = $body;
  $33 = $17 | 5;
  $34 = $33&65535;
  HEAP16[$15>>1] = $34;
  STACKTOP = sp;return;
 }
 $35 = $17 & 2;
 $36 = ($35|0)==(0);
 if ($36) {
  $37 = (($collData) + 156|0);
  $38 = HEAP32[$37>>2]|0;
  HEAPF32[$38>>2] = $0;
  $39 = (($38) + 4|0);
  HEAPF32[$39>>2] = $2;
  $40 = (($38) + 8|0);
  HEAPF32[$40>>2] = $4;
  $41 = (($38) + 12|0);
  HEAPF32[$41>>2] = $14;
  $42 = Math_fround(HEAPF32[$newSurfaceVel>>2]);
  HEAPF32[$c1Dynamic>>2] = $42;
  $43 = (($newSurfaceVel) + 4|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($c1Dynamic) + 4|0);
  HEAPF32[$45>>2] = $44;
  $46 = (($newSurfaceVel) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = (($c1Dynamic) + 8|0);
  HEAPF32[$48>>2] = $47;
  $49 = (($c1Dynamic) + 12|0);
  HEAP32[$49>>2] = $body;
  $50 = $17 | 10;
  $51 = $50&65535;
  HEAP16[$15>>1] = $51;
  STACKTOP = sp;return;
 }
 $52 = (($collData) + 140|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($collData) + 48|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($54 * $56);
 $58 = (($53) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($collData) + 52|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($59 * $61);
 $63 = Math_fround($57 + $62);
 $64 = (($53) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($collData) + 56|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($65 * $67);
 $69 = Math_fround($63 + $68);
 $70 = (($53) + 12|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($69 - $71);
 $73 = (($collData) + 156|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($56 * $75);
 $77 = (($74) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($61 * $78);
 $80 = Math_fround($76 + $79);
 $81 = (($74) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($67 * $82);
 $84 = Math_fround($80 + $83);
 $85 = (($74) + 12|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($84 - $86);
 $88 = Math_fround($0 * $56);
 $89 = Math_fround($2 * $61);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround($4 * $67);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($92 - $14);
 $94 = $72 < $87;
 if ($94) {
  $95 = $93 < $87;
  if (!($95)) {
   STACKTOP = sp;return;
  }
  HEAPF32[$74>>2] = $0;
  HEAPF32[$77>>2] = $2;
  HEAPF32[$81>>2] = $4;
  HEAPF32[$85>>2] = $14;
  $96 = Math_fround(HEAPF32[$newSurfaceVel>>2]);
  HEAPF32[$c1Dynamic>>2] = $96;
  $97 = (($newSurfaceVel) + 4|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($c1Dynamic) + 4|0);
  HEAPF32[$99>>2] = $98;
  $100 = (($newSurfaceVel) + 8|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $102 = (($c1Dynamic) + 8|0);
  HEAPF32[$102>>2] = $101;
  $103 = (($c1Dynamic) + 12|0);
  HEAP32[$103>>2] = $body;
  $104 = $17 | 8;
  $105 = $104&65535;
  HEAP16[$15>>1] = $105;
  STACKTOP = sp;return;
 } else {
  $106 = $93 < $72;
  if (!($106)) {
   STACKTOP = sp;return;
  }
  HEAPF32[$53>>2] = $0;
  HEAPF32[$58>>2] = $2;
  HEAPF32[$64>>2] = $4;
  HEAPF32[$70>>2] = $14;
  $107 = Math_fround(HEAPF32[$newSurfaceVel>>2]);
  HEAPF32[$c0Dynamic>>2] = $107;
  $108 = (($newSurfaceVel) + 4|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($c0Dynamic) + 4|0);
  HEAPF32[$110>>2] = $109;
  $111 = (($newSurfaceVel) + 8|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($c0Dynamic) + 8|0);
  HEAPF32[$113>>2] = $112;
  $114 = (($c0Dynamic) + 12|0);
  HEAP32[$114>>2] = $body;
  $115 = $17 | 4;
  $116 = $115&65535;
  HEAP16[$15>>1] = $116;
  STACKTOP = sp;return;
 }
}
function __ZN5physx31initCollDataAndApplyConstraintsERNS_19PxsParticleCollDataERKNS_16PxsFluidParticleERKNS_6PxVec3EfS7_S7_PKNS_11PxsBodyCoreESA_jRKNS_27PxsFluidCollisionParametersE($collData,$particle,$oldVelocity,$restOffset,$constr0Velocity,$constr1Velocity,$constr0TwoWayBody,$constr1TwoWayBody,$particleIndex,$params) {
 $collData = $collData|0;
 $particle = $particle|0;
 $oldVelocity = $oldVelocity|0;
 $restOffset = Math_fround($restOffset);
 $constr0Velocity = $constr0Velocity|0;
 $constr1Velocity = $constr1Velocity|0;
 $constr0TwoWayBody = $constr0TwoWayBody|0;
 $constr1TwoWayBody = $constr1TwoWayBody|0;
 $particleIndex = $particleIndex|0;
 $params = $params|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $motionDir = 0, $storemerge = 0, $storemerge$in = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $motionDir = sp;
 $0 = (($particle) + 28|0);
 $1 = HEAPU16[$0>>1]|(HEAPU16[$0+2>>1]<<16);
 $2 = $1 >>> 16;
 $3 = (($collData) + 44|0);
 dest=$collData+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($collData) + 92|0);
 HEAPF32[$4>>2] = $restOffset;
 $5 = Math_fround(HEAPF32[$particle>>2]);
 $6 = (($collData) + 48|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($particle) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($collData) + 52|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($particle) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($collData) + 56|0);
 HEAPF32[$12>>2] = $11;
 $13 = $1 & 65529;
 $14 = $13&65535;
 $15 = (($collData) + 60|0);
 HEAP16[$15>>1] = $14;
 $16 = $1 >>> 17;
 $17 = $16 & 16;
 $18 = $2 & 65487;
 $19 = $17 | $18;
 $20 = $19&65535;
 $21 = (($collData) + 62|0);
 HEAP16[$21>>1] = $20;
 $22 = (($collData) + 76|0);
 HEAP32[$22>>2] = $particleIndex;
 $23 = (($collData) + 96|0);
 ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;
 $24 = (($params) + 64|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($particle) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 * $27);
 $29 = (($particle) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($25 * $30);
 $32 = (($particle) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($25 * $33);
 HEAPF32[$motionDir>>2] = $28;
 $35 = (($motionDir) + 4|0);
 HEAPF32[$35>>2] = $31;
 $36 = (($motionDir) + 8|0);
 HEAPF32[$36>>2] = $34;
 $37 = (($particle) + 30|0);
 $38 = HEAP16[$37>>1]|0;
 $39 = $38 & 3;
 $40 = ($39<<16>>16)==(0);
 if (!($40)) {
  $41 = (($collData) + 48|0);
  $42 = (($collData) + 108|0);
  $43 = (($collData) + 32|0);
  $44 = (($collData) + 140|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($collData) + 156|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (__ZN5physx16applyConstraintsERKNS_6PxVec3ERS0_S2_RPKNS_11PxsBodyCoreES3_S3_PKNS_18PxsFluidConstraintESA_S6_S6_S2_S2_jRKNS_27PxsFluidCollisionParametersERKNS_16PxvParticleFlagsE($41,$motionDir,$oldVelocity,$42,$collData,$43,$45,$47,$constr0TwoWayBody,$constr1TwoWayBody,$constr0Velocity,$constr1Velocity,$particleIndex,$params,$0)|0);
  if ($48) {
   $49 = HEAP32[$42>>2]|0;
   $50 = ($49|0)==(0|0);
   if ($50) {
    $67 = HEAP16[$15>>1]|0;
    $68 = $67&65535;
    $69 = $68 | 2;
    $storemerge$in = $69;
   } else {
    $51 = Math_fround(HEAPF32[$motionDir>>2]);
    $52 = Math_fround($28 - $51);
    $53 = Math_fround(HEAPF32[$35>>2]);
    $54 = Math_fround($31 - $53);
    $55 = Math_fround(HEAPF32[$36>>2]);
    $56 = Math_fround($34 - $55);
    $57 = (($params) + 68|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($52 * $58);
    $60 = Math_fround($54 * $58);
    $61 = Math_fround($56 * $58);
    HEAPF32[$23>>2] = $59;
    $62 = (($collData) + 100|0);
    HEAPF32[$62>>2] = $60;
    $63 = (($collData) + 104|0);
    HEAPF32[$63>>2] = $61;
    $64 = HEAP16[$15>>1]|0;
    $65 = $64&65535;
    $66 = $65 | 4;
    $storemerge$in = $66;
   }
   $storemerge = $storemerge$in&65535;
   HEAP16[$15>>1] = $storemerge;
   $70 = (($collData) + 12|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = $71 | 4;
   HEAP32[$70>>2] = $72;
  }
 }
 $73 = Math_fround(HEAPF32[$6>>2]);
 $74 = Math_fround(HEAPF32[$motionDir>>2]);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround(HEAPF32[$9>>2]);
 $77 = Math_fround(HEAPF32[$35>>2]);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround(HEAPF32[$12>>2]);
 $80 = Math_fround(HEAPF32[$36>>2]);
 $81 = Math_fround($79 + $80);
 $82 = (($collData) + 64|0);
 HEAPF32[$82>>2] = $75;
 $83 = (($collData) + 68|0);
 HEAPF32[$83>>2] = $78;
 $84 = (($collData) + 72|0);
 HEAPF32[$84>>2] = $81;
 $85 = (($params) + 68|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 * $74);
 $88 = Math_fround($86 * $77);
 $89 = Math_fround($86 * $80);
 $90 = (($collData) + 80|0);
 HEAPF32[$90>>2] = $87;
 $91 = (($collData) + 84|0);
 HEAPF32[$91>>2] = $88;
 $92 = (($collData) + 88|0);
 HEAPF32[$92>>2] = $89;
 STACKTOP = sp;return;
}
function __ZN5physx14updateParticleERNS_16PxsFluidParticleERKNS_19PxsParticleCollDataEbRKNS_7PxPlaneERNS_9PxBounds3E($particle,$collData,$projection,$projectionPlane,$worldBounds) {
 $particle = $particle|0;
 $collData = $collData|0;
 $projection = $projection|0;
 $projectionPlane = $projectionPlane|0;
 $worldBounds = $worldBounds|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($projection) {
  $46 = Math_fround(HEAPF32[$projectionPlane>>2]);
  $47 = (($collData) + 80|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($46 * $48);
  $50 = (($projectionPlane) + 4|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($collData) + 84|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($51 * $53);
  $55 = Math_fround($49 + $54);
  $56 = (($projectionPlane) + 8|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($collData) + 88|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($57 * $59);
  $61 = Math_fround($55 + $60);
  $62 = Math_fround($46 * $61);
  $63 = Math_fround($51 * $61);
  $64 = Math_fround($57 * $61);
  $65 = Math_fround($48 - $62);
  $66 = Math_fround($53 - $63);
  $67 = Math_fround($59 - $64);
  $68 = (($particle) + 16|0);
  HEAPF32[$68>>2] = $65;
  $69 = (($particle) + 20|0);
  HEAPF32[$69>>2] = $66;
  $70 = (($particle) + 24|0);
  HEAPF32[$70>>2] = $67;
  $71 = (($collData) + 64|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround(HEAPF32[$projectionPlane>>2]);
  $74 = Math_fround($72 * $73);
  $75 = (($collData) + 68|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround(HEAPF32[$50>>2]);
  $78 = Math_fround($76 * $77);
  $79 = Math_fround($74 + $78);
  $80 = (($collData) + 72|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround(HEAPF32[$56>>2]);
  $83 = Math_fround($81 * $82);
  $84 = Math_fround($79 + $83);
  $85 = (($projectionPlane) + 12|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround($86 + $84);
  $88 = Math_fround($73 * $87);
  $89 = Math_fround($77 * $87);
  $90 = Math_fround($82 * $87);
  $91 = Math_fround($72 - $88);
  $92 = Math_fround($76 - $89);
  $93 = Math_fround($81 - $90);
  HEAPF32[$particle>>2] = $91;
  $94 = (($particle) + 4|0);
  HEAPF32[$94>>2] = $92;
  $95 = (($particle) + 8|0);
  HEAPF32[$95>>2] = $93;
  $96 = Math_fround(HEAPF32[$worldBounds>>2]);
  $97 = $96 < $91;
  $98 = $97 ? $96 : $91;
  $99 = (($worldBounds) + 4|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = $100 < $92;
  $102 = $101 ? $100 : $92;
  $103 = (($worldBounds) + 8|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = $104 < $93;
  $106 = $105 ? $104 : $93;
  HEAPF32[$worldBounds>>2] = $98;
  HEAPF32[$99>>2] = $102;
  HEAPF32[$103>>2] = $106;
  $107 = (($worldBounds) + 12|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = $108 > $91;
  $110 = $109 ? $108 : $91;
  $111 = (($worldBounds) + 16|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = $112 > $92;
  $114 = $113 ? $112 : $92;
  $115 = (($worldBounds) + 20|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = $116 > $93;
  $118 = $117 ? $116 : $93;
  HEAPF32[$107>>2] = $110;
  HEAPF32[$111>>2] = $114;
  HEAPF32[$115>>2] = $118;
  $119 = (($particle) + 28|0);
  $120 = (($collData) + 60|0);
  $121 = HEAPU16[$120>>1]|(HEAPU16[$120+2>>1]<<16);
  HEAP16[$119>>1]=$121&65535;HEAP16[$119+2>>1]=$121>>>16;
  STACKTOP = sp;return;
 } else {
  $0 = (($collData) + 80|0);
  $1 = Math_fround(HEAPF32[$0>>2]);
  $2 = (($particle) + 16|0);
  HEAPF32[$2>>2] = $1;
  $3 = (($collData) + 84|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($particle) + 20|0);
  HEAPF32[$5>>2] = $4;
  $6 = (($collData) + 88|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($particle) + 24|0);
  HEAPF32[$8>>2] = $7;
  $9 = (($collData) + 64|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$particle>>2] = $10;
  $11 = (($collData) + 68|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($particle) + 4|0);
  HEAPF32[$13>>2] = $12;
  $14 = (($collData) + 72|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($particle) + 8|0);
  HEAPF32[$16>>2] = $15;
  $17 = Math_fround(HEAPF32[$worldBounds>>2]);
  $18 = Math_fround(HEAPF32[$9>>2]);
  $19 = $17 < $18;
  $20 = $19 ? $17 : $18;
  $21 = (($worldBounds) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround(HEAPF32[$11>>2]);
  $24 = $22 < $23;
  $25 = $24 ? $22 : $23;
  $26 = (($worldBounds) + 8|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround(HEAPF32[$14>>2]);
  $29 = $27 < $28;
  $30 = $29 ? $27 : $28;
  HEAPF32[$worldBounds>>2] = $20;
  HEAPF32[$21>>2] = $25;
  HEAPF32[$26>>2] = $30;
  $31 = (($worldBounds) + 12|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround(HEAPF32[$9>>2]);
  $34 = $32 > $33;
  $35 = $34 ? $32 : $33;
  $36 = (($worldBounds) + 16|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround(HEAPF32[$11>>2]);
  $39 = $37 > $38;
  $40 = $39 ? $37 : $38;
  $41 = (($worldBounds) + 20|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(HEAPF32[$14>>2]);
  $44 = $42 > $43;
  $45 = $44 ? $42 : $43;
  HEAPF32[$31>>2] = $35;
  HEAPF32[$36>>2] = $40;
  HEAPF32[$41>>2] = $45;
  $119 = (($particle) + 28|0);
  $120 = (($collData) + 60|0);
  $121 = HEAPU16[$120>>1]|(HEAPU16[$120+2>>1]<<16);
  HEAP16[$119>>1]=$121&65535;HEAP16[$119+2>>1]=$121>>>16;
  STACKTOP = sp;return;
 }
}
function __ZN5physx16applyConstraintsERKNS_6PxVec3ERS0_S2_RPKNS_11PxsBodyCoreES3_S3_PKNS_18PxsFluidConstraintESA_S6_S6_S2_S2_jRKNS_27PxsFluidCollisionParametersERKNS_16PxvParticleFlagsE($rayOrig,$rayDir,$oldVelocity,$twoWayBody,$shapeNormal,$shapeVelocity,$constr0,$constr1,$constr0TwoWayBody,$constr1TwoWayBody,$constr0Velocity,$constr1Velocity,$particleIndex,$params,$particleFlags) {
 $rayOrig = $rayOrig|0;
 $rayDir = $rayDir|0;
 $oldVelocity = $oldVelocity|0;
 $twoWayBody = $twoWayBody|0;
 $shapeNormal = $shapeNormal|0;
 $shapeVelocity = $shapeVelocity|0;
 $constr0 = $constr0|0;
 $constr1 = $constr1|0;
 $constr0TwoWayBody = $constr0TwoWayBody|0;
 $constr1TwoWayBody = $constr1TwoWayBody|0;
 $constr0Velocity = $constr0Velocity|0;
 $constr1Velocity = $constr1Velocity|0;
 $particleIndex = $particleIndex|0;
 $params = $params|0;
 $particleFlags = $particleFlags|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0);
 var $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0;
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $brmerge$demorgan = 0, $fabsf$i$i = Math_fround(0), $or$cond = 0, $rayDirTmp = 0, $storemerge = Math_fround(0), $velocity = 0, $velocity2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $rayDirTmp = sp + 24|0;
 $velocity = sp;
 $velocity2 = sp + 12|0;
 $0 = Math_fround(HEAPF32[$rayDir>>2]);
 HEAPF32[$rayDirTmp>>2] = $0;
 $1 = (($rayDirTmp) + 4|0);
 $2 = (($rayDir) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$1>>2] = $3;
 $4 = (($rayDirTmp) + 8|0);
 $5 = (($rayDir) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = Math_fround(HEAPF32[$rayOrig>>2]);
 $8 = Math_fround($7 + $0);
 $9 = (($rayOrig) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 + $3);
 $12 = (($rayOrig) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($6 + $13);
 $15 = (($particleFlags) + 2|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16 & 2;
 $18 = ($17<<16>>16)==(0);
 $19 = Math_fround(HEAPF32[$constr0>>2]);
 $20 = Math_fround($8 * $19);
 $21 = (($constr0) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($11 * $22);
 $24 = Math_fround($20 + $23);
 $25 = (($constr0) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($14 * $26);
 $28 = Math_fround($24 + $27);
 do {
  if ($18) {
   $29 = (($constr0) + 12|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = $28 < $30;
   if (!($31)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$twoWayBody>>2] = $constr0TwoWayBody;
   HEAPF32[$shapeNormal>>2] = $19;
   $32 = Math_fround(HEAPF32[$21>>2]);
   $33 = (($shapeNormal) + 4|0);
   HEAPF32[$33>>2] = $32;
   $34 = Math_fround(HEAPF32[$25>>2]);
   $35 = (($shapeNormal) + 8|0);
   HEAPF32[$35>>2] = $34;
   $36 = Math_fround(HEAPF32[$constr0Velocity>>2]);
   HEAPF32[$shapeVelocity>>2] = $36;
   $37 = (($constr0Velocity) + 4|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = (($shapeVelocity) + 4|0);
   HEAPF32[$39>>2] = $38;
   $40 = (($constr0Velocity) + 8|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = (($shapeVelocity) + 8|0);
   HEAPF32[$42>>2] = $41;
   $43 = (($params) + 68|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = Math_fround($44 * $0);
   $46 = Math_fround($44 * $3);
   $47 = Math_fround($44 * $6);
   HEAPF32[$velocity>>2] = $45;
   $48 = (($velocity) + 4|0);
   HEAPF32[$48>>2] = $46;
   $49 = (($velocity) + 8|0);
   HEAPF32[$49>>2] = $47;
   __ZN5physx15reflectVelocityERNS_6PxVec3ERKS0_S3_S3_S3_jRKNS_27PxsFluidCollisionParametersE($rayDirTmp,$velocity,$oldVelocity,$constr0,$constr0Velocity,$particleIndex,$params);
   $50 = (($params) + 64|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = Math_fround(HEAPF32[$rayDirTmp>>2]);
   $53 = Math_fround($51 * $52);
   HEAPF32[$rayDirTmp>>2] = $53;
   $54 = Math_fround(HEAPF32[$1>>2]);
   $55 = Math_fround($51 * $54);
   HEAPF32[$1>>2] = $55;
   $56 = Math_fround(HEAPF32[$4>>2]);
   $57 = Math_fround($51 * $56);
   HEAPF32[$4>>2] = $57;
   $58 = Math_fround(HEAPF32[$rayOrig>>2]);
   $59 = Math_fround($58 + $53);
   $60 = Math_fround(HEAPF32[$9>>2]);
   $61 = Math_fround($60 + $55);
   $62 = Math_fround(HEAPF32[$12>>2]);
   $63 = Math_fround($57 + $62);
   $64 = Math_fround(HEAPF32[$constr0>>2]);
   $65 = Math_fround($59 * $64);
   $66 = Math_fround(HEAPF32[$21>>2]);
   $67 = Math_fround($61 * $66);
   $68 = Math_fround($65 + $67);
   $69 = Math_fround(HEAPF32[$25>>2]);
   $70 = Math_fround($63 * $69);
   $71 = Math_fround($68 + $70);
   $72 = Math_fround(HEAPF32[$29>>2]);
   $73 = $72 > $71;
   if ($73) {
    $74 = Math_fround($72 - $71);
    $75 = Math_fround($74 * Math_fround(1.00999999046325683594));
    $76 = Math_fround($64 * $75);
    $77 = Math_fround($66 * $75);
    $78 = Math_fround($69 * $75);
    $79 = Math_fround($59 + $76);
    $80 = Math_fround($61 + $77);
    $81 = Math_fround($63 + $78);
    $82 = Math_fround($79 - $58);
    $83 = Math_fround($80 - $60);
    $84 = Math_fround($81 - $62);
    HEAPF32[$rayDirTmp>>2] = $82;
    HEAPF32[$1>>2] = $83;
    HEAPF32[$4>>2] = $84;
    $290 = $82;$292 = $83;$295 = $84;
    label = 21;
   } else {
    $305 = $53;$306 = $55;$307 = $57;
   }
  } else {
   $85 = Math_fround(HEAPF32[$constr1>>2]);
   $86 = Math_fround($8 * $85);
   $87 = (($constr1) + 4|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = Math_fround($11 * $88);
   $90 = Math_fround($86 + $89);
   $91 = (($constr1) + 8|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = Math_fround($14 * $92);
   $94 = Math_fround($90 + $93);
   $95 = (($constr0) + 12|0);
   $96 = Math_fround(HEAPF32[$95>>2]);
   $97 = $28 < $96;
   $98 = (($constr1) + 12|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $100 = $94 < $99;
   do {
    if ($97) {
     HEAP32[$twoWayBody>>2] = $constr0TwoWayBody;
     HEAPF32[$shapeNormal>>2] = $19;
     $101 = Math_fround(HEAPF32[$21>>2]);
     $102 = (($shapeNormal) + 4|0);
     HEAPF32[$102>>2] = $101;
     $103 = Math_fround(HEAPF32[$25>>2]);
     $104 = (($shapeNormal) + 8|0);
     HEAPF32[$104>>2] = $103;
     $105 = Math_fround(HEAPF32[$constr0Velocity>>2]);
     HEAPF32[$shapeVelocity>>2] = $105;
     $106 = (($constr0Velocity) + 4|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = (($shapeVelocity) + 4|0);
     HEAPF32[$108>>2] = $107;
     $109 = (($constr0Velocity) + 8|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = (($shapeVelocity) + 8|0);
     HEAPF32[$111>>2] = $110;
    } else {
     if ($100) {
      HEAP32[$twoWayBody>>2] = $constr1TwoWayBody;
      HEAPF32[$shapeNormal>>2] = $85;
      $112 = Math_fround(HEAPF32[$87>>2]);
      $113 = (($shapeNormal) + 4|0);
      HEAPF32[$113>>2] = $112;
      $114 = Math_fround(HEAPF32[$91>>2]);
      $115 = (($shapeNormal) + 8|0);
      HEAPF32[$115>>2] = $114;
      $116 = Math_fround(HEAPF32[$constr1Velocity>>2]);
      HEAPF32[$shapeVelocity>>2] = $116;
      $117 = (($constr1Velocity) + 4|0);
      $118 = Math_fround(HEAPF32[$117>>2]);
      $119 = (($shapeVelocity) + 4|0);
      HEAPF32[$119>>2] = $118;
      $120 = (($constr1Velocity) + 8|0);
      $121 = Math_fround(HEAPF32[$120>>2]);
      $122 = (($shapeVelocity) + 8|0);
      HEAPF32[$122>>2] = $121;
      break;
     } else {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $brmerge$demorgan = $97 & $100;
   if ($brmerge$demorgan) {
    $138 = (($params) + 20|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = Math_fround(Math_fround(1.0) - $139);
    $141 = Math_fround($0 * $140);
    HEAPF32[$rayDirTmp>>2] = $141;
    $142 = Math_fround($140 * $3);
    HEAPF32[$1>>2] = $142;
    $143 = Math_fround($140 * $6);
    $146 = $141;$149 = $142;$storemerge = $143;
   } else {
    $123 = (($params) + 68|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = Math_fround($124 * $0);
    $126 = Math_fround($124 * $3);
    $127 = Math_fround($124 * $6);
    HEAPF32[$velocity2>>2] = $125;
    $128 = (($velocity2) + 4|0);
    HEAPF32[$128>>2] = $126;
    $129 = (($velocity2) + 8|0);
    HEAPF32[$129>>2] = $127;
    __ZN5physx15reflectVelocityERNS_6PxVec3ERKS0_S3_S3_S3_jRKNS_27PxsFluidCollisionParametersE($rayDirTmp,$velocity2,$oldVelocity,$shapeNormal,$shapeVelocity,$particleIndex,$params);
    $130 = (($params) + 64|0);
    $131 = Math_fround(HEAPF32[$130>>2]);
    $132 = Math_fround(HEAPF32[$rayDirTmp>>2]);
    $133 = Math_fround($131 * $132);
    HEAPF32[$rayDirTmp>>2] = $133;
    $134 = Math_fround(HEAPF32[$1>>2]);
    $135 = Math_fround($131 * $134);
    HEAPF32[$1>>2] = $135;
    $136 = Math_fround(HEAPF32[$4>>2]);
    $137 = Math_fround($131 * $136);
    $146 = $133;$149 = $135;$storemerge = $137;
   }
   HEAPF32[$4>>2] = $storemerge;
   $144 = Math_fround(HEAPF32[$rayOrig>>2]);
   $145 = Math_fround($144 + $146);
   $147 = Math_fround(HEAPF32[$9>>2]);
   $148 = Math_fround($147 + $149);
   $150 = Math_fround(HEAPF32[$12>>2]);
   $151 = Math_fround($150 + $storemerge);
   $152 = Math_fround(HEAPF32[$constr0>>2]);
   $153 = Math_fround($145 * $152);
   $154 = Math_fround(HEAPF32[$21>>2]);
   $155 = Math_fround($148 * $154);
   $156 = Math_fround($153 + $155);
   $157 = Math_fround(HEAPF32[$25>>2]);
   $158 = Math_fround($151 * $157);
   $159 = Math_fround($156 + $158);
   $160 = Math_fround(HEAPF32[$constr1>>2]);
   $161 = Math_fround($152 * $160);
   $162 = Math_fround(HEAPF32[$87>>2]);
   $163 = Math_fround($154 * $162);
   $164 = Math_fround($161 + $163);
   $165 = Math_fround(HEAPF32[$91>>2]);
   $166 = Math_fround($157 * $165);
   $167 = Math_fround($164 + $166);
   $fabsf$i$i = (Math_fround(Math_abs((Math_fround($167)))));
   $168 = $fabsf$i$i > Math_fround(0.999998986721038818359);
   if ($168) {
    $169 = Math_fround(HEAPF32[$95>>2]);
    $170 = $159 < $169;
    if (!($170)) {
     $305 = $146;$306 = $149;$307 = $storemerge;
     break;
    }
    $171 = Math_fround($169 - $159);
    $172 = Math_fround($171 * Math_fround(1.00999999046325683594));
    $173 = Math_fround($152 * $172);
    $174 = Math_fround($154 * $172);
    $175 = Math_fround($157 * $172);
    $176 = Math_fround($145 + $173);
    $177 = Math_fround($148 + $174);
    $178 = Math_fround($151 + $175);
    $179 = Math_fround($176 - $144);
    $180 = Math_fround($177 - $147);
    $181 = Math_fround($178 - $150);
    HEAPF32[$rayDirTmp>>2] = $179;
    HEAPF32[$1>>2] = $180;
    HEAPF32[$4>>2] = $181;
    $290 = $179;$292 = $180;$295 = $181;
    label = 21;
    break;
   }
   $182 = Math_fround($145 * $160);
   $183 = Math_fround($148 * $162);
   $184 = Math_fround($182 + $183);
   $185 = Math_fround($151 * $165);
   $186 = Math_fround($184 + $185);
   $187 = Math_fround(HEAPF32[$95>>2]);
   $188 = Math_fround($187 - $159);
   $189 = Math_fround(HEAPF32[$98>>2]);
   $190 = Math_fround($189 - $186);
   $191 = $159 < $187;
   $192 = $186 < $189;
   $or$cond = $191 | $192;
   if ($or$cond) {
    $193 = Math_fround($165 * $190);
    $194 = Math_fround($162 * $190);
    $195 = Math_fround($160 * $190);
    $196 = Math_fround($151 + $193);
    $197 = Math_fround($148 + $194);
    $198 = Math_fround($145 + $195);
    $199 = Math_fround($198 * $152);
    $200 = Math_fround($197 * $154);
    $201 = Math_fround($199 + $200);
    $202 = Math_fround($196 * $157);
    $203 = Math_fround($201 + $202);
    $204 = $203 < $187;
    if (!($204)) {
     $271 = Math_fround($190 * Math_fround(1.00010001659393310547));
     $272 = Math_fround($271 * $160);
     $273 = Math_fround($271 * $162);
     $274 = Math_fround($271 * $165);
     $275 = Math_fround($145 + $272);
     $276 = Math_fround($148 + $273);
     $277 = Math_fround($151 + $274);
     $278 = Math_fround($275 - $144);
     $279 = Math_fround($276 - $147);
     $280 = Math_fround($277 - $150);
     HEAPF32[$rayDirTmp>>2] = $278;
     HEAPF32[$1>>2] = $279;
     HEAPF32[$4>>2] = $280;
     $290 = $278;$292 = $279;$295 = $280;
     label = 21;
     break;
    }
    $205 = Math_fround($152 * $188);
    $206 = Math_fround($154 * $188);
    $207 = Math_fround($145 + $205);
    $208 = Math_fround($148 + $206);
    $209 = Math_fround($157 * $188);
    $210 = Math_fround($208 * $162);
    $211 = Math_fround($207 * $160);
    $212 = Math_fround($151 + $209);
    $213 = Math_fround($212 * $165);
    $214 = Math_fround($211 + $210);
    $215 = Math_fround($214 + $213);
    $216 = $215 < $189;
    if ($216) {
     $217 = Math_fround($167 * $167);
     $218 = Math_fround(Math_fround(1.0) - $217);
     $219 = Math_fround(Math_fround(1.0) / $218);
     $220 = Math_fround($167 * $190);
     $221 = Math_fround($188 - $220);
     $222 = Math_fround($221 * $219);
     $223 = Math_fround($167 * $188);
     $224 = Math_fround($190 - $223);
     $225 = Math_fround($224 * $219);
     $226 = Math_fround($152 * $222);
     $227 = Math_fround($154 * $222);
     $228 = Math_fround($157 * $222);
     $229 = Math_fround($160 * $225);
     $230 = Math_fround($162 * $225);
     $231 = Math_fround($165 * $225);
     $232 = Math_fround($226 + $229);
     $233 = Math_fround($227 + $230);
     $234 = Math_fround($228 + $231);
     $235 = Math_fround($145 + $232);
     $236 = Math_fround($148 + $233);
     $237 = Math_fround($151 + $234);
     $238 = Math_fround($235 - $144);
     $239 = Math_fround($236 - $147);
     $240 = Math_fround($237 - $150);
     $241 = Math_fround($152 + $160);
     $242 = Math_fround($154 + $162);
     $243 = Math_fround($157 + $165);
     $244 = Math_fround($241 * Math_fround(0.5));
     $245 = Math_fround($242 * Math_fround(0.5));
     $246 = Math_fround($243 * Math_fround(0.5));
     $247 = Math_fround($244 * Math_fround(9.99999974737875163555E-5));
     $248 = Math_fround($245 * Math_fround(9.99999974737875163555E-5));
     $249 = Math_fround($246 * Math_fround(9.99999974737875163555E-5));
     $250 = Math_fround($238 * $238);
     $251 = Math_fround($239 * $239);
     $252 = Math_fround($250 + $251);
     $253 = Math_fround($240 * $240);
     $254 = Math_fround($253 + $252);
     $255 = Math_fround($247 * $254);
     $256 = Math_fround($248 * $254);
     $257 = Math_fround($249 * $254);
     $258 = Math_fround($238 + $255);
     HEAPF32[$rayDirTmp>>2] = $258;
     $259 = Math_fround($239 + $256);
     HEAPF32[$1>>2] = $259;
     $260 = Math_fround($240 + $257);
     HEAPF32[$4>>2] = $260;
     $290 = $258;$292 = $259;$295 = $260;
     label = 21;
     break;
    } else {
     $261 = Math_fround($188 * Math_fround(1.00010001659393310547));
     $262 = Math_fround($261 * $152);
     $263 = Math_fround($261 * $154);
     $264 = Math_fround($261 * $157);
     $265 = Math_fround($145 + $262);
     $266 = Math_fround($148 + $263);
     $267 = Math_fround($151 + $264);
     $268 = Math_fround($265 - $144);
     $269 = Math_fround($266 - $147);
     $270 = Math_fround($267 - $150);
     HEAPF32[$rayDirTmp>>2] = $268;
     HEAPF32[$1>>2] = $269;
     HEAPF32[$4>>2] = $270;
     $290 = $268;$292 = $269;$295 = $270;
     label = 21;
     break;
    }
   } else {
    $305 = $146;$306 = $149;$307 = $storemerge;
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $281 = Math_fround(HEAPF32[$rayDir>>2]);
  $282 = Math_fround($281 * $281);
  $283 = Math_fround(HEAPF32[$2>>2]);
  $284 = Math_fround($283 * $283);
  $285 = Math_fround($282 + $284);
  $286 = Math_fround(HEAPF32[$5>>2]);
  $287 = Math_fround($286 * $286);
  $288 = Math_fround($285 + $287);
  $289 = Math_fround($290 * $290);
  $291 = Math_fround($292 * $292);
  $293 = Math_fround($289 + $291);
  $294 = Math_fround($295 * $295);
  $296 = Math_fround($293 + $294);
  $297 = $296 > $288;
  if ($297) {
   $298 = (Math_fround(Math_sqrt((Math_fround($288)))));
   $299 = (Math_fround(Math_sqrt((Math_fround($296)))));
   $300 = Math_fround(Math_fround(1.0) / $299);
   $301 = Math_fround($298 * $300);
   $302 = Math_fround($290 * $301);
   HEAPF32[$rayDirTmp>>2] = $302;
   $303 = Math_fround($292 * $301);
   HEAPF32[$1>>2] = $303;
   $304 = Math_fround($301 * $295);
   HEAPF32[$4>>2] = $304;
   $305 = $302;$306 = $303;$307 = $304;
  } else {
   $305 = $290;$306 = $292;$307 = $295;
  }
 }
 HEAPF32[$rayDir>>2] = $305;
 HEAPF32[$2>>2] = $306;
 HEAPF32[$5>>2] = $307;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayINS_19PxsW2STransformTempENS0_16AlignedAllocatorILj16ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $24 = 0;
 } else {
  $1 = ($capacity*56)|0;
  $2 = (($1) + 19)|0;
  $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__Z15PxGetFoundationv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
  $$$i$i$i$i = $11 ? 494080 : 494048;
  $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$2,$$$i$i$i$i,493968,558)|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   $24 = 0;
  } else {
   $14 = (($12) + 19|0);
   $15 = $14;
   $16 = $15 & -16;
   $17 = $12;
   $18 = (($16) - ($17))|0;
   $19 = $16;
   $20 = (($19) + -4|0);
   HEAP32[$20>>2] = $18;
   $phitmp$i = $16;
   $24 = $phitmp$i;
  }
 }
 $21 = (($this) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($24) + (($22*56)|0)|0);
 $25 = ($22|0)>(0);
 if ($25) {
  $26 = HEAP32[$this>>2]|0;
  $$012$i = $24;$$03$i = $26;
  while(1) {
   $27 = ($$012$i|0)==(0|0);
   if (!($27)) {
    $28 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $28;
    $29 = (($$012$i) + 4|0);
    $30 = (($$03$i) + 4|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 8|0);
    $33 = (($$03$i) + 8|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
    $35 = (($$012$i) + 12|0);
    $36 = (($$03$i) + 12|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 16|0);
    $39 = (($$03$i) + 16|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 20|0);
    $42 = (($$03$i) + 20|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$41>>2] = $43;
    $44 = (($$012$i) + 24|0);
    $45 = (($$03$i) + 24|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    HEAPF32[$44>>2] = $46;
    $47 = (($$012$i) + 28|0);
    $48 = (($$03$i) + 28|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$47>>2] = $49;
    $50 = (($$012$i) + 32|0);
    $51 = (($$03$i) + 32|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    HEAPF32[$50>>2] = $52;
    $53 = (($$012$i) + 36|0);
    $54 = (($$03$i) + 36|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    HEAPF32[$53>>2] = $55;
    $56 = (($$012$i) + 40|0);
    $57 = (($$03$i) + 40|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    HEAPF32[$56>>2] = $58;
    $59 = (($$012$i) + 44|0);
    $60 = (($$03$i) + 44|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    HEAPF32[$59>>2] = $61;
    $62 = (($$012$i) + 48|0);
    $63 = (($$03$i) + 48|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    HEAPF32[$62>>2] = $64;
    $65 = (($$012$i) + 52|0);
    $66 = (($$03$i) + 52|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    HEAPF32[$65>>2] = $67;
   }
   $68 = (($$012$i) + 56|0);
   $69 = (($$03$i) + 56|0);
   $70 = ($68>>>0)<($23>>>0);
   if ($70) {
    $$012$i = $68;$$03$i = $69;
   } else {
    break;
   }
  }
 }
 $71 = (($this) + 8|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)>(-1);
 if (!($73)) {
  HEAP32[$this>>2] = $24;
  HEAP32[$71>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $74 = HEAP32[$this>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  HEAP32[$this>>2] = $24;
  HEAP32[$71>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $76 = (($74) + -4|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (0 - ($77))|0;
 $79 = (($74) + ($78)|0);
 $80 = ($79|0)==(0|0);
 if ($80) {
  HEAP32[$this>>2] = $24;
  HEAP32[$71>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $81 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($82) + 12|0);
 $84 = HEAP32[$83>>2]|0;
 FUNCTION_TABLE_vii[$84 & 4095]($81,$79);
 HEAP32[$this>>2] = $24;
 HEAP32[$71>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx21PxsFluidCollisionTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx21PxsFluidCollisionTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx21PxsFluidCollisionTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (494256|0);
}
function __ZN5physx21PxsFluidCollisionTask11runInternalEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $inEnabled$not$i$i$i1 = 0, $or$cond$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 6736|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAPU16[545680>>1]|(HEAPU16[545680+2>>1]<<16);
 $17 = $16 & 16711680;
 $inEnabled$not$i$i$i1 = ($17|0)==(0);
 $18 = ($9|0)==(0|0);
 $or$cond$i$i$i2 = $18 | $inEnabled$not$i$i$i1;
 if ($or$cond$i$i$i2) {
  $19 = (($this) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  __ZN5physx17PxsFluidCollision26processShapeListWithFilterEjj($1,$20,0);
  STACKTOP = sp;return;
 } else {
  $21 = $16&65535;
  $22 = HEAP32[$9>>2]|0;
  $23 = (($22) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_viiii[$24 & 511]($9,$21,$12,$15);
  $$pre = HEAP32[$0>>2]|0;
  $25 = (($this) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  __ZN5physx17PxsFluidCollision26processShapeListWithFilterEjj($$pre,$26,0);
  $27 = HEAP32[$9>>2]|0;
  $28 = (($27) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $16&65535;
  FUNCTION_TABLE_viiii[$29 & 511]($9,$30,$12,$15);
  STACKTOP = sp;return;
 }
}
function __ZN5physx14collideWithBoxEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($particleCollData,$numCollData,$boxShape,$proxRadius) {
 $particleCollData = $particleCollData|0;
 $numCollData = $numCollData|0;
 $boxShape = $boxShape|0;
 $proxRadius = Math_fround($proxRadius);
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0;
 var $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $collDataV4 = 0, $exitcond = 0, $exitcond30 = 0, $exitcond31 = 0, $j$023 = 0, $j1$025 = 0, $or$cond = 0, $or$cond19 = 0, $or$cond20 = 0, $or$cond21 = 0, $or$cond21$not = 0, $or$cond22 = 0;
 var $p$027 = 0, $phitmp$i = 0, $planes = 0, $v4Count$028 = 0, $v4Count$1 = 0, $v4Count$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $planes = sp + 320|0;
 $collDataV4 = sp;
 $0 = (($boxShape) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($boxShape) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($boxShape) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($1 * Math_fround(-1.0));
 $7 = Math_fround($5 * Math_fround(-1.0));
 $8 = Math_fround($6 - $proxRadius);
 $9 = Math_fround($7 - $proxRadius);
 $10 = Math_fround($3 + $proxRadius);
 $11 = Math_fround($3 * Math_fround(-1.0));
 $12 = Math_fround($11 - $proxRadius);
 $13 = Math_fround($1 + $proxRadius);
 $14 = Math_fround($5 + $proxRadius);
 HEAPF32[$planes>>2] = Math_fround(1.0);
 $15 = (($planes) + 4|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($planes) + 8|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = Math_fround(-$1);
 $18 = (($planes) + 12|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($planes) + 16|0);
 HEAPF32[$19>>2] = Math_fround(-1.0);
 $20 = (($planes) + 20|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($planes) + 24|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($planes) + 28|0);
 HEAPF32[$22>>2] = $17;
 $23 = (($planes) + 32|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($planes) + 36|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($planes) + 40|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = Math_fround(-$3);
 $27 = (($planes) + 44|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($planes) + 48|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($planes) + 52|0);
 HEAPF32[$29>>2] = Math_fround(-1.0);
 $30 = (($planes) + 56|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($planes) + 60|0);
 HEAPF32[$31>>2] = $26;
 $32 = (($planes) + 64|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($planes) + 68|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($planes) + 72|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = Math_fround(-$5);
 $36 = (($planes) + 76|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($planes) + 80|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($planes) + 84|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($planes) + 88|0);
 HEAPF32[$39>>2] = Math_fround(-1.0);
 $40 = (($planes) + 92|0);
 HEAPF32[$40>>2] = $35;
 $41 = ($numCollData|0)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($numCollData) + -1)|0;
 $p$027 = 0;$v4Count$028 = 0;
 while(1) {
  $43 = ((($particleCollData) + (($p$027*176)|0)|0) + 112|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = ((($particleCollData) + (($p$027*176)|0)|0) + 128|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = $44 < $46;
  $48 = $47 ? $44 : $46;
  $49 = ((($particleCollData) + (($p$027*176)|0)|0) + 116|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = ((($particleCollData) + (($p$027*176)|0)|0) + 132|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = $50 < $52;
  $54 = $53 ? $50 : $52;
  $55 = ((($particleCollData) + (($p$027*176)|0)|0) + 120|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = ((($particleCollData) + (($p$027*176)|0)|0) + 136|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = $56 < $58;
  $60 = $59 ? $56 : $58;
  $61 = $44 > $46;
  $62 = $61 ? $44 : $46;
  $63 = $50 > $52;
  $64 = $63 ? $50 : $52;
  $65 = $56 > $58;
  $66 = $65 ? $56 : $58;
  $67 = $8 > $62;
  $68 = $48 > $13;
  $or$cond = $67 | $68;
  $69 = $12 > $64;
  $or$cond19 = $or$cond | $69;
  $70 = $54 > $10;
  $or$cond20 = $or$cond19 | $70;
  $71 = $9 > $66;
  $or$cond21 = $or$cond20 | $71;
  $or$cond21$not = $or$cond21 ^ 1;
  $phitmp$i = !($60 > $14);
  $or$cond22 = $phitmp$i & $or$cond21$not;
  if ($or$cond22) {
   $72 = (($particleCollData) + (($p$027*176)|0)|0);
   $73 = ((($collDataV4) + ($v4Count$028<<4)|0) + 16|0);
   HEAPF32[$73>>2] = $44;
   $74 = ((($collDataV4) + ($v4Count$028<<4)|0) + 20|0);
   HEAPF32[$74>>2] = $50;
   $75 = ((($collDataV4) + ($v4Count$028<<4)|0) + 24|0);
   HEAPF32[$75>>2] = $56;
   $76 = ((($collDataV4) + ($v4Count$028<<4)|0) + 28|0);
   HEAPF32[$76>>2] = Math_fround(0.0);
   $77 = ((($collDataV4) + ($v4Count$028<<4)|0) + 80|0);
   HEAPF32[$77>>2] = $46;
   $78 = ((($collDataV4) + ($v4Count$028<<4)|0) + 84|0);
   HEAPF32[$78>>2] = $52;
   $79 = ((($collDataV4) + ($v4Count$028<<4)|0) + 88|0);
   HEAPF32[$79>>2] = $58;
   $80 = ((($collDataV4) + ($v4Count$028<<4)|0) + 92|0);
   HEAPF32[$80>>2] = Math_fround(0.0);
   $81 = ((($particleCollData) + (($p$027*176)|0)|0) + 124|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ((($collDataV4) + ($v4Count$028<<2)|0) + 160|0);
   HEAP32[$83>>2] = $82;
   $84 = ((($particleCollData) + (($p$027*176)|0)|0) + 92|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = ((($collDataV4) + ($v4Count$028<<2)|0) + 144|0);
   HEAPF32[$86>>2] = $85;
   $87 = ((($particleCollData) + (($p$027*176)|0)|0) + 44|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = ((($collDataV4) + ($v4Count$028<<2)|0) + 176|0);
   HEAPF32[$89>>2] = $88;
   $90 = (($collDataV4) + ($v4Count$028<<2)|0);
   HEAP32[$90>>2] = $72;
   $91 = (($v4Count$028) + 1)|0;
   $v4Count$1 = $91;
  } else {
   $v4Count$1 = $v4Count$028;
  }
  if ((($v4Count$1|0) == 0)) {
   $v4Count$2 = 0;
  } else if ((($v4Count$1|0) == 4)) {
   __ZN5physx27collideWithConvexPlanesSIMDERNS_21PxsParticleCollDataV4EPKNS_7PxPlaneEjf($collDataV4,$planes,6,$proxRadius);
   $j$023 = 0;
   while(1) {
    $92 = (($collDataV4) + ($j$023<<2)|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ((($collDataV4) + ($j$023<<2)|0) + 160|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0);
    if (!($96)) {
     $97 = (($93) + 124|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = $98 | $95;
     HEAP32[$97>>2] = $99;
     $100 = ((($collDataV4) + ($j$023<<2)|0) + 176|0);
     $101 = Math_fround(HEAPF32[$100>>2]);
     $102 = (($93) + 44|0);
     HEAPF32[$102>>2] = $101;
     $103 = ((($collDataV4) + ($j$023<<4)|0) + 192|0);
     $104 = Math_fround(HEAPF32[$103>>2]);
     $105 = (($93) + 144|0);
     HEAPF32[$105>>2] = $104;
     $106 = ((($collDataV4) + ($j$023<<4)|0) + 196|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = (($93) + 148|0);
     HEAPF32[$108>>2] = $107;
     $109 = ((($collDataV4) + ($j$023<<4)|0) + 200|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = (($93) + 152|0);
     HEAPF32[$111>>2] = $110;
     $112 = ((($collDataV4) + ($j$023<<4)|0) + 256|0);
     $113 = Math_fround(HEAPF32[$112>>2]);
     $114 = (($93) + 160|0);
     HEAPF32[$114>>2] = $113;
     $115 = ((($collDataV4) + ($j$023<<4)|0) + 260|0);
     $116 = Math_fround(HEAPF32[$115>>2]);
     $117 = (($93) + 164|0);
     HEAPF32[$117>>2] = $116;
     $118 = ((($collDataV4) + ($j$023<<4)|0) + 264|0);
     $119 = Math_fround(HEAPF32[$118>>2]);
     $120 = (($93) + 168|0);
     HEAPF32[$120>>2] = $119;
    }
    $121 = (($j$023) + 1)|0;
    $exitcond = ($121|0)==(4);
    if ($exitcond) {
     $v4Count$2 = 0;
     break;
    } else {
     $j$023 = $121;
    }
   }
  } else {
   $122 = ($p$027|0)==($42|0);
   if ($122) {
    $123 = ($v4Count$1|0)==(0);
    if ($123) {
     $v4Count$2 = 0;
    } else {
     $j1$025 = 0;
     while(1) {
      $124 = (($collDataV4) + ($j1$025<<2)|0);
      $125 = HEAP32[$124>>2]|0;
      __ZN5physx23collideWithConvexPlanesERNS_19PxsParticleCollDataEPKNS_7PxPlaneEjf($125,$planes,6,$proxRadius);
      $126 = (($j1$025) + 1)|0;
      $exitcond30 = ($126|0)==($v4Count$1|0);
      if ($exitcond30) {
       $v4Count$2 = $v4Count$1;
       break;
      } else {
       $j1$025 = $126;
      }
     }
    }
   } else {
    $v4Count$2 = $v4Count$1;
   }
  }
  $127 = (($p$027) + 1)|0;
  $exitcond31 = ($127|0)==($numCollData|0);
  if ($exitcond31) {
   break;
  } else {
   $p$027 = $127;$v4Count$028 = $v4Count$2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx31collideWithCapsuleNonContinuousERNS_19PxsParticleCollDataERKNS_6PxVec3ERKfS6_S6_($collData,$q,$h,$r,$proxRadius) {
 $collData = $collData|0;
 $q = $q|0;
 $h = $h|0;
 $r = $r|0;
 $proxRadius = $proxRadius|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $storemerge = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($collData) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = Math_fround(HEAPF32[$q>>2]);
 $5 = Math_fround(HEAPF32[$h>>2]);
 $6 = Math_fround(-$5);
 $7 = $4 > $6;
 $8 = $7 ? $4 : $6;
 $9 = $8 < $5;
 $10 = $9 ? $8 : $5;
 $11 = Math_fround($4 - $10);
 $12 = (($q) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($q) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($collData) + 144|0);
 HEAPF32[$16>>2] = $11;
 $17 = (($collData) + 148|0);
 HEAPF32[$17>>2] = $13;
 $18 = (($collData) + 152|0);
 HEAPF32[$18>>2] = $15;
 $19 = Math_fround($11 * $11);
 $20 = Math_fround($13 * $13);
 $21 = Math_fround($19 + $20);
 $22 = Math_fround($15 * $15);
 $23 = Math_fround($22 + $21);
 $24 = (Math_fround(Math_sqrt((Math_fround($23)))));
 $25 = Math_fround(HEAPF32[$r>>2]);
 $26 = Math_fround(HEAPF32[$proxRadius>>2]);
 $27 = Math_fround($25 + $26);
 $28 = $24 < $27;
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $29 = $24 != Math_fround(0.0);
 if ($29) {
  $30 = Math_fround(Math_fround(1.0) / $24);
  $31 = Math_fround($11 * $30);
  HEAPF32[$16>>2] = $31;
  $32 = Math_fround($30 * $13);
  HEAPF32[$17>>2] = $32;
  $33 = Math_fround($30 * $15);
  $39 = $31;$41 = $32;$storemerge = $33;
 } else {
  HEAPF32[$16>>2] = Math_fround(0.0);
  HEAPF32[$17>>2] = Math_fround(0.0);
  $39 = Math_fround(0.0);$41 = Math_fround(0.0);$storemerge = Math_fround(0.0);
 }
 HEAPF32[$18>>2] = $storemerge;
 $34 = Math_fround(HEAPF32[$r>>2]);
 $35 = (($collData) + 92|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 + $36);
 $38 = Math_fround($39 * $37);
 $40 = Math_fround($37 * $41);
 $42 = Math_fround($37 * $storemerge);
 $43 = Math_fround($10 + $38);
 $44 = Math_fround($40 + Math_fround(0.0));
 $45 = Math_fround($42 + Math_fround(0.0));
 $46 = (($collData) + 160|0);
 HEAPF32[$46>>2] = $43;
 $47 = (($collData) + 164|0);
 HEAPF32[$47>>2] = $44;
 $48 = (($collData) + 168|0);
 HEAPF32[$48>>2] = $45;
 $49 = $1 | 32;
 HEAP32[$0>>2] = $49;
 $50 = Math_fround(HEAPF32[$r>>2]);
 $51 = Math_fround($50 + $36);
 $52 = $24 < $51;
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = $1 | 48;
 HEAP32[$0>>2] = $53;
 STACKTOP = sp;return;
}
function __ZN5physx28collideWithCapsuleTestSphereERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_S4_RKfS6_S6_S6_S6_S6_S6_($collData,$p,$q,$d,$h,$r,$sphereH,$discS,$aS,$bS,$proxRadius) {
 $collData = $collData|0;
 $p = $p|0;
 $q = $q|0;
 $d = $d|0;
 $h = $h|0;
 $r = $r|0;
 $sphereH = $sphereH|0;
 $discS = $discS|0;
 $aS = $aS|0;
 $bS = $bS|0;
 $proxRadius = $proxRadius|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$discS>>2]);
 $1 = !($0 <= Math_fround(0.0));
 if ($1) {
  $2 = Math_fround(HEAPF32[$aS>>2]);
  $3 = $2 == Math_fround(0.0);
  if (!($3)) {
   $4 = Math_fround(HEAPF32[$bS>>2]);
   $5 = (Math_fround(Math_sqrt((Math_fround($0)))));
   $6 = Math_fround($4 + $5);
   $7 = Math_fround(-$6);
   $8 = Math_fround($7 / $2);
   $9 = $8 < Math_fround(0.0);
   $10 = $8 > Math_fround(1.0);
   $or$cond = $9 | $10;
   if ($or$cond) {
    __ZN5physx31collideWithCapsuleNonContinuousERNS_19PxsParticleCollDataERKNS_6PxVec3ERKfS6_S6_($collData,$q,$h,$r,$proxRadius);
    STACKTOP = sp;return;
   }
   $11 = (($collData) + 44|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = $8 < $12;
   if (!($13)) {
    STACKTOP = sp;return;
   }
   $14 = Math_fround(HEAPF32[$d>>2]);
   $15 = Math_fround($8 * $14);
   $16 = (($d) + 4|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround($8 * $17);
   $19 = (($d) + 8|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround($8 * $20);
   $22 = Math_fround(HEAPF32[$p>>2]);
   $23 = Math_fround($15 + $22);
   $24 = (($p) + 4|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = Math_fround($18 + $25);
   $27 = (($p) + 8|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = Math_fround($21 + $28);
   $30 = (($collData) + 144|0);
   HEAPF32[$30>>2] = $23;
   $31 = (($collData) + 148|0);
   HEAPF32[$31>>2] = $26;
   $32 = (($collData) + 152|0);
   HEAPF32[$32>>2] = $29;
   $33 = Math_fround(HEAPF32[$sphereH>>2]);
   $34 = Math_fround($23 - $33);
   HEAPF32[$30>>2] = $34;
   $35 = Math_fround(HEAPF32[$r>>2]);
   $36 = Math_fround(Math_fround(1.0) / $35);
   $37 = Math_fround($34 * $36);
   HEAPF32[$30>>2] = $37;
   $38 = Math_fround($36 * $26);
   HEAPF32[$31>>2] = $38;
   $39 = Math_fround($36 * $29);
   HEAPF32[$32>>2] = $39;
   $40 = Math_fround(HEAPF32[$p>>2]);
   $41 = (($collData) + 160|0);
   HEAPF32[$41>>2] = $40;
   $42 = Math_fround(HEAPF32[$24>>2]);
   $43 = (($collData) + 164|0);
   HEAPF32[$43>>2] = $42;
   $44 = Math_fround(HEAPF32[$27>>2]);
   $45 = (($collData) + 168|0);
   HEAPF32[$45>>2] = $44;
   HEAPF32[$11>>2] = $8;
   $46 = (($collData) + 124|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | 8;
   HEAP32[$46>>2] = $48;
   STACKTOP = sp;return;
  }
 }
 __ZN5physx31collideWithCapsuleNonContinuousERNS_19PxsParticleCollDataERKNS_6PxVec3ERKfS6_S6_($collData,$q,$h,$r,$proxRadius);
 STACKTOP = sp;return;
}
function __ZN5physx18collideWithCapsuleEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($collShapeData,$numCollData,$capsuleShape,$proxRadius) {
 $collShapeData = $collShapeData|0;
 $numCollData = $numCollData|0;
 $capsuleShape = $capsuleShape|0;
 $proxRadius = Math_fround($proxRadius);
 var $0 = 0, $1 = 0, $2 = 0, $exitcond = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numCollData|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $p$01 = 0;
 }
 while(1) {
  $1 = (($collShapeData) + (($p$01*176)|0)|0);
  __ZN5physx18collideWithCapsuleERNS_19PxsParticleCollDataERKNS_17PxCapsuleGeometryEf($1,$capsuleShape,$proxRadius);
  $2 = (($p$01) + 1)|0;
  $exitcond = ($2|0)==($numCollData|0);
  if ($exitcond) {
   break;
  } else {
   $p$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx18collideWithCapsuleERNS_19PxsParticleCollDataERKNS_17PxCapsuleGeometryEf($collData,$capsuleShapeData,$proxRadius) {
 $collData = $collData|0;
 $capsuleShapeData = $capsuleShapeData|0;
 $proxRadius = Math_fround($proxRadius);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0;
 var $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $a = 0, $b = 0, $brmerge = 0, $brmerge4 = 0, $brmerge5 = 0, $d = 0, $discs = 0, $h = 0, $or$cond = 0, $or$cond28 = 0, $or$cond29 = 0;
 var $or$cond3 = 0, $or$cond30 = 0, $r = 0, $storemerge$i = Math_fround(0), $storemerge$i6 = Math_fround(0), $storemerge$i8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $r = sp + 60|0;
 $h = sp + 56|0;
 $a = sp + 44|0;
 $b = sp + 32|0;
 $d = sp + 16|0;
 $discs = sp + 4|0;
 $1 = sp;
 $2 = sp + 28|0;
 HEAPF32[$0>>2] = $proxRadius;
 $3 = (($collData) + 112|0);
 $4 = (($collData) + 128|0);
 $5 = (($capsuleShapeData) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$r>>2] = $6;
 $7 = (($capsuleShapeData) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$h>>2] = $8;
 $9 = (($collData) + 116|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $10);
 $12 = (($collData) + 120|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($6 * $6);
 $17 = Math_fround($15 - $16);
 $18 = Math_fround(HEAPF32[$3>>2]);
 $19 = Math_fround($18 * $18);
 $20 = Math_fround($17 + $19);
 $21 = Math_fround($8 * $8);
 $22 = Math_fround($21 + $20);
 $23 = Math_fround($8 * Math_fround(2.0));
 $24 = Math_fround($23 * $18);
 $25 = Math_fround($22 - $24);
 $26 = Math_fround($24 + $22);
 $27 = $17 < Math_fround(0.0);
 $28 = $25 < Math_fround(0.0);
 $29 = $26 < Math_fround(0.0);
 $30 = $18 > $8;
 $31 = Math_fround(-$8);
 $32 = $18 < $31;
 $or$cond3 = $30 | $32;
 if ($or$cond3) {
  $brmerge5 = $28 | $29;
  if ($brmerge5) {
   label = 4;
  }
 } else {
  $brmerge = $27 | $28;
  $brmerge4 = $brmerge | $29;
  if ($brmerge4) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $33 = $18 > $31;
  $34 = $33 ? $18 : $31;
  $35 = $34 < $8;
  $36 = $35 ? $34 : $8;
  $37 = Math_fround($18 - $36);
  $38 = $37 == Math_fround(0.0);
  $39 = $10 == Math_fround(0.0);
  $or$cond28 = $38 & $39;
  $40 = $13 == Math_fround(0.0);
  $or$cond29 = $or$cond28 & $40;
  if ($or$cond29) {
   $51 = Math_fround(0.0);$53 = Math_fround(1.0);$55 = Math_fround(0.0);
  } else {
   $41 = Math_fround($37 * $37);
   $42 = Math_fround($11 + $41);
   $43 = Math_fround($14 + $42);
   $44 = $43 > Math_fround(0.0);
   if ($44) {
    $45 = (Math_fround(Math_sqrt((Math_fround($43)))));
    $46 = Math_fround(Math_fround(1.0) / $45);
    $47 = Math_fround($37 * $46);
    $48 = Math_fround($10 * $46);
    $49 = Math_fround($13 * $46);
    $51 = $47;$53 = $48;$55 = $49;
   } else {
    $51 = Math_fround(0.0);$53 = Math_fround(0.0);$55 = Math_fround(0.0);
   }
  }
  $50 = (($collData) + 144|0);
  HEAPF32[$50>>2] = $51;
  $52 = (($collData) + 148|0);
  HEAPF32[$52>>2] = $53;
  $54 = (($collData) + 152|0);
  HEAPF32[$54>>2] = $55;
  $56 = (($collData) + 92|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($6 + $57);
  $59 = Math_fround($51 * $58);
  $60 = Math_fround($58 * $53);
  $61 = Math_fround($55 * $58);
  $62 = Math_fround($36 + $59);
  $63 = Math_fround($60 + Math_fround(0.0));
  $64 = Math_fround($61 + Math_fround(0.0));
  $65 = (($collData) + 160|0);
  HEAPF32[$65>>2] = $62;
  $66 = (($collData) + 164|0);
  HEAPF32[$66>>2] = $63;
  $67 = (($collData) + 168|0);
  HEAPF32[$67>>2] = $64;
  $68 = (($collData) + 44|0);
  HEAPF32[$68>>2] = Math_fround(0.0);
  $69 = (($collData) + 124|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = $70 | 8;
  HEAP32[$69>>2] = $71;
  STACKTOP = sp;return;
 }
 $72 = Math_fround(HEAPF32[$4>>2]);
 $73 = Math_fround($72 - $18);
 $74 = (($collData) + 132|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 - $10);
 $77 = (($collData) + 136|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($78 - $13);
 HEAPF32[$d>>2] = $73;
 $80 = (($d) + 4|0);
 HEAPF32[$80>>2] = $76;
 $81 = (($d) + 8|0);
 HEAPF32[$81>>2] = $79;
 $82 = Math_fround($76 * $10);
 $83 = Math_fround($79 * $13);
 $84 = Math_fround($82 + $83);
 $85 = (($b) + 4|0);
 HEAPF32[$85>>2] = $84;
 $86 = Math_fround($73 * $18);
 $87 = Math_fround($84 + $86);
 $88 = Math_fround($73 * $8);
 $89 = Math_fround($87 - $88);
 HEAPF32[$b>>2] = $89;
 $90 = Math_fround($87 + $88);
 $91 = (($b) + 8|0);
 HEAPF32[$91>>2] = $90;
 $92 = Math_fround($76 * $76);
 $93 = Math_fround($79 * $79);
 $94 = Math_fround($92 + $93);
 $95 = (($a) + 4|0);
 HEAPF32[$95>>2] = $94;
 $96 = Math_fround($73 * $73);
 $97 = Math_fround($94 + $96);
 HEAPF32[$a>>2] = $97;
 $98 = (($a) + 8|0);
 HEAPF32[$98>>2] = $97;
 $99 = Math_fround($89 * $89);
 $100 = Math_fround($84 * $84);
 $101 = Math_fround($90 * $90);
 $102 = Math_fround($25 * $97);
 $103 = Math_fround($17 * $94);
 $104 = Math_fround($26 * $97);
 $105 = Math_fround($99 - $102);
 $106 = Math_fround($100 - $103);
 $107 = Math_fround($101 - $104);
 HEAPF32[$discs>>2] = $105;
 $108 = (($discs) + 4|0);
 HEAPF32[$108>>2] = $106;
 $109 = (($discs) + 8|0);
 HEAPF32[$109>>2] = $107;
 $110 = !($106 >= Math_fround(0.0));
 if ($110) {
  $111 = (($collData) + 124|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = $112 & 2;
  $114 = ($113|0)==(0);
  if (!($114)) {
   STACKTOP = sp;return;
  }
  $115 = $72 > $31;
  $116 = $115 ? $72 : $31;
  $117 = $116 < $8;
  $118 = $117 ? $116 : $8;
  $119 = Math_fround($72 - $118);
  $120 = (($collData) + 144|0);
  HEAPF32[$120>>2] = $119;
  $121 = (($collData) + 148|0);
  HEAPF32[$121>>2] = $75;
  $122 = (($collData) + 152|0);
  HEAPF32[$122>>2] = $78;
  $123 = Math_fround($119 * $119);
  $124 = Math_fround($75 * $75);
  $125 = Math_fround($124 + $123);
  $126 = Math_fround($78 * $78);
  $127 = Math_fround($126 + $125);
  $128 = (Math_fround(Math_sqrt((Math_fround($127)))));
  $129 = Math_fround($6 + $proxRadius);
  $130 = $128 < $129;
  if (!($130)) {
   STACKTOP = sp;return;
  }
  $131 = $128 != Math_fround(0.0);
  if ($131) {
   $132 = Math_fround(Math_fround(1.0) / $128);
   $133 = Math_fround($119 * $132);
   HEAPF32[$120>>2] = $133;
   $134 = Math_fround($75 * $132);
   HEAPF32[$121>>2] = $134;
   $135 = Math_fround($78 * $132);
   $140 = $133;$142 = $134;$storemerge$i8 = $135;
  } else {
   HEAPF32[$120>>2] = Math_fround(0.0);
   HEAPF32[$121>>2] = Math_fround(0.0);
   $140 = Math_fround(0.0);$142 = Math_fround(0.0);$storemerge$i8 = Math_fround(0.0);
  }
  HEAPF32[$122>>2] = $storemerge$i8;
  $136 = (($collData) + 92|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = Math_fround($6 + $137);
  $139 = Math_fround($140 * $138);
  $141 = Math_fround($142 * $138);
  $143 = Math_fround($storemerge$i8 * $138);
  $144 = Math_fround($118 + $139);
  $145 = Math_fround($141 + Math_fround(0.0));
  $146 = Math_fround($143 + Math_fround(0.0));
  $147 = (($collData) + 160|0);
  HEAPF32[$147>>2] = $144;
  $148 = (($collData) + 164|0);
  HEAPF32[$148>>2] = $145;
  $149 = (($collData) + 168|0);
  HEAPF32[$149>>2] = $146;
  $150 = $112 | 32;
  HEAP32[$111>>2] = $150;
  $151 = $128 < $138;
  if (!($151)) {
   STACKTOP = sp;return;
  }
  $152 = $112 | 48;
  HEAP32[$111>>2] = $152;
  STACKTOP = sp;return;
 }
 if ($27) {
  $153 = $18 > Math_fround(0.0);
  if ($153) {
   __ZN5physx28collideWithCapsuleTestSphereERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_S4_RKfS6_S6_S6_S6_S6_S6_($collData,$3,$4,$d,$h,$r,$h,$discs,$a,$b,$0);
   STACKTOP = sp;return;
  } else {
   HEAPF32[$1>>2] = $31;
   __ZN5physx28collideWithCapsuleTestSphereERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_S4_RKfS6_S6_S6_S6_S6_S6_($collData,$3,$4,$d,$h,$r,$1,$109,$98,$91,$0);
   STACKTOP = sp;return;
  }
 }
 $154 = $106 <= Math_fround(0.0);
 $155 = $94 == Math_fround(0.0);
 $or$cond30 = $154 | $155;
 if ($or$cond30) {
  $156 = (($collData) + 124|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = $157 & 2;
  $159 = ($158|0)==(0);
  if (!($159)) {
   STACKTOP = sp;return;
  }
  $160 = $72 > $31;
  $161 = $160 ? $72 : $31;
  $162 = $161 < $8;
  $163 = $162 ? $161 : $8;
  $164 = Math_fround($72 - $163);
  $165 = (($collData) + 144|0);
  HEAPF32[$165>>2] = $164;
  $166 = (($collData) + 148|0);
  HEAPF32[$166>>2] = $75;
  $167 = (($collData) + 152|0);
  HEAPF32[$167>>2] = $78;
  $168 = Math_fround($164 * $164);
  $169 = Math_fround($75 * $75);
  $170 = Math_fround($169 + $168);
  $171 = Math_fround($78 * $78);
  $172 = Math_fround($171 + $170);
  $173 = (Math_fround(Math_sqrt((Math_fround($172)))));
  $174 = Math_fround($6 + $proxRadius);
  $175 = $173 < $174;
  if (!($175)) {
   STACKTOP = sp;return;
  }
  $176 = $173 != Math_fround(0.0);
  if ($176) {
   $177 = Math_fround(Math_fround(1.0) / $173);
   $178 = Math_fround($164 * $177);
   HEAPF32[$165>>2] = $178;
   $179 = Math_fround($75 * $177);
   HEAPF32[$166>>2] = $179;
   $180 = Math_fround($78 * $177);
   $185 = $178;$187 = $179;$storemerge$i6 = $180;
  } else {
   HEAPF32[$165>>2] = Math_fround(0.0);
   HEAPF32[$166>>2] = Math_fround(0.0);
   $185 = Math_fround(0.0);$187 = Math_fround(0.0);$storemerge$i6 = Math_fround(0.0);
  }
  HEAPF32[$167>>2] = $storemerge$i6;
  $181 = (($collData) + 92|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = Math_fround($6 + $182);
  $184 = Math_fround($185 * $183);
  $186 = Math_fround($187 * $183);
  $188 = Math_fround($storemerge$i6 * $183);
  $189 = Math_fround($163 + $184);
  $190 = Math_fround($186 + Math_fround(0.0));
  $191 = Math_fround($188 + Math_fround(0.0));
  $192 = (($collData) + 160|0);
  HEAPF32[$192>>2] = $189;
  $193 = (($collData) + 164|0);
  HEAPF32[$193>>2] = $190;
  $194 = (($collData) + 168|0);
  HEAPF32[$194>>2] = $191;
  $195 = $157 | 32;
  HEAP32[$156>>2] = $195;
  $196 = $173 < $183;
  if (!($196)) {
   STACKTOP = sp;return;
  }
  $197 = $157 | 48;
  HEAP32[$156>>2] = $197;
  STACKTOP = sp;return;
 }
 $198 = (Math_fround(Math_sqrt((Math_fround($106)))));
 $199 = Math_fround($84 + $198);
 $200 = Math_fround(-$199);
 $201 = Math_fround($200 / $94);
 $202 = $201 < Math_fround(0.0);
 $203 = $201 > Math_fround(1.0);
 $or$cond = $202 | $203;
 if (!($or$cond)) {
  $246 = Math_fround($201 * $73);
  $247 = Math_fround($201 * $76);
  $248 = Math_fround($201 * $79);
  $249 = Math_fround($246 + $18);
  $250 = Math_fround($247 + $10);
  $251 = Math_fround($248 + $13);
  $252 = $249 > $8;
  if ($252) {
   __ZN5physx28collideWithCapsuleTestSphereERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_S4_RKfS6_S6_S6_S6_S6_S6_($collData,$3,$4,$d,$h,$r,$h,$discs,$a,$b,$0);
   STACKTOP = sp;return;
  }
  $253 = $249 < $31;
  if ($253) {
   HEAPF32[$2>>2] = $31;
   __ZN5physx28collideWithCapsuleTestSphereERNS_19PxsParticleCollDataERKNS_6PxVec3ES4_S4_RKfS6_S6_S6_S6_S6_S6_($collData,$3,$4,$d,$h,$r,$2,$109,$98,$91,$0);
   STACKTOP = sp;return;
  }
  $254 = (($collData) + 44|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = $201 < $255;
  if (!($256)) {
   STACKTOP = sp;return;
  }
  $257 = Math_fround(Math_fround(1.0) / $6);
  $258 = Math_fround($250 * $257);
  $259 = Math_fround($251 * $257);
  $260 = (($collData) + 144|0);
  $261 = (($collData) + 148|0);
  HEAPF32[$261>>2] = $258;
  $262 = (($collData) + 152|0);
  HEAPF32[$262>>2] = $259;
  HEAPF32[$260>>2] = Math_fround(0.0);
  $263 = (($collData) + 160|0);
  HEAPF32[$263>>2] = $18;
  $264 = (($collData) + 164|0);
  HEAPF32[$264>>2] = $10;
  $265 = (($collData) + 168|0);
  HEAPF32[$265>>2] = $13;
  HEAPF32[$254>>2] = $201;
  $266 = (($collData) + 124|0);
  $267 = HEAP32[$266>>2]|0;
  $268 = $267 | 8;
  HEAP32[$266>>2] = $268;
  STACKTOP = sp;return;
 }
 $204 = (($collData) + 124|0);
 $205 = HEAP32[$204>>2]|0;
 $206 = $205 & 2;
 $207 = ($206|0)==(0);
 if (!($207)) {
  STACKTOP = sp;return;
 }
 $208 = $72 > $31;
 $209 = $208 ? $72 : $31;
 $210 = $209 < $8;
 $211 = $210 ? $209 : $8;
 $212 = Math_fround($72 - $211);
 $213 = (($collData) + 144|0);
 HEAPF32[$213>>2] = $212;
 $214 = (($collData) + 148|0);
 HEAPF32[$214>>2] = $75;
 $215 = (($collData) + 152|0);
 HEAPF32[$215>>2] = $78;
 $216 = Math_fround($212 * $212);
 $217 = Math_fround($75 * $75);
 $218 = Math_fround($217 + $216);
 $219 = Math_fround($78 * $78);
 $220 = Math_fround($219 + $218);
 $221 = (Math_fround(Math_sqrt((Math_fround($220)))));
 $222 = Math_fround($6 + $proxRadius);
 $223 = $221 < $222;
 if (!($223)) {
  STACKTOP = sp;return;
 }
 $224 = $221 != Math_fround(0.0);
 if ($224) {
  $225 = Math_fround(Math_fround(1.0) / $221);
  $226 = Math_fround($212 * $225);
  HEAPF32[$213>>2] = $226;
  $227 = Math_fround($75 * $225);
  HEAPF32[$214>>2] = $227;
  $228 = Math_fround($78 * $225);
  $233 = $226;$235 = $227;$storemerge$i = $228;
 } else {
  HEAPF32[$213>>2] = Math_fround(0.0);
  HEAPF32[$214>>2] = Math_fround(0.0);
  $233 = Math_fround(0.0);$235 = Math_fround(0.0);$storemerge$i = Math_fround(0.0);
 }
 HEAPF32[$215>>2] = $storemerge$i;
 $229 = (($collData) + 92|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = Math_fround($6 + $230);
 $232 = Math_fround($233 * $231);
 $234 = Math_fround($235 * $231);
 $236 = Math_fround($storemerge$i * $231);
 $237 = Math_fround($211 + $232);
 $238 = Math_fround($234 + Math_fround(0.0));
 $239 = Math_fround($236 + Math_fround(0.0));
 $240 = (($collData) + 160|0);
 HEAPF32[$240>>2] = $237;
 $241 = (($collData) + 164|0);
 HEAPF32[$241>>2] = $238;
 $242 = (($collData) + 168|0);
 HEAPF32[$242>>2] = $239;
 $243 = $205 | 32;
 HEAP32[$204>>2] = $243;
 $244 = $221 < $231;
 if (!($244)) {
  STACKTOP = sp;return;
 }
 $245 = $205 | 48;
 HEAP32[$204>>2] = $245;
 STACKTOP = sp;return;
}
function __ZN5physx27collideWithConvexPlanesSIMDERNS_21PxsParticleCollDataV4EPKNS_7PxPlaneEjf($collDataV4,$convexPlanes,$numPlanes,$proxRadius) {
 $collDataV4 = $collDataV4|0;
 $convexPlanes = $convexPlanes|0;
 $numPlanes = $numPlanes|0;
 $proxRadius = Math_fround($proxRadius);
 var $$ = 0, $$$ = 0, $$2963 = 0, $$2963$ = 0, $$2968 = 0, $$2969 = 0, $$2972 = 0, $$2973 = 0, $$2974 = 0, $$2975 = 0, $$2978 = 0, $$2979 = 0, $$2982 = 0, $$2983 = 0, $$demorgan = 0, $$demorgan3041 = 0, $$demorgan3042 = 0, $$demorgan3043 = 0, $$demorgan3048 = 0, $$demorgan3049 = 0;
 var $$demorgan3050 = 0, $$demorgan3051 = 0, $$in1$i = 0, $$in1$i101 = 0, $$in1$i117 = 0, $$in1$i133 = 0, $$in1$i149 = 0, $$in1$i165 = 0, $$in1$i181 = 0, $$in1$i197 = 0, $$in1$i213 = 0, $$in1$i231 = 0, $$in1$i247 = 0, $$in1$i263 = 0, $$in1$i279 = 0, $$in1$i295 = 0, $$in1$i309 = 0, $$in1$i323 = 0, $$in1$i339 = 0, $$in1$i355 = 0;
 var $$in1$i371 = 0, $$in1$i387 = 0, $$in1$i426 = 0, $$in1$i458 = 0, $$in1$i505 = 0, $$in1$i528 = 0, $$in1$i544 = 0, $$in1$i560 = 0, $$in1$i576 = 0, $$in1$i592 = 0, $$in1$i619 = 0, $$in1$i677 = 0, $$in1$i693 = 0, $$in1$i709 = 0, $$in1$i71 = 0, $$in1$i725 = 0, $$in1$i741 = 0, $$in1$i767 = 0, $$in1$i783 = 0, $$in1$i799 = 0;
 var $$in1$i815 = 0, $$in1$i831 = 0, $$in1$i85 = 0, $$in2$i = 0, $$in2$i103 = 0, $$in2$i119 = 0, $$in2$i135 = 0, $$in2$i151 = 0, $$in2$i167 = 0, $$in2$i183 = 0, $$in2$i199 = 0, $$in2$i215 = 0, $$in2$i233 = 0, $$in2$i249 = 0, $$in2$i265 = 0, $$in2$i281 = 0, $$in2$i297 = 0, $$in2$i311 = 0, $$in2$i325 = 0, $$in2$i341 = 0;
 var $$in2$i357 = 0, $$in2$i373 = 0, $$in2$i389 = 0, $$in2$i428 = 0, $$in2$i460 = 0, $$in2$i507 = 0, $$in2$i530 = 0, $$in2$i546 = 0, $$in2$i562 = 0, $$in2$i578 = 0, $$in2$i594 = 0, $$in2$i621 = 0, $$in2$i679 = 0, $$in2$i695 = 0, $$in2$i711 = 0, $$in2$i727 = 0, $$in2$i73 = 0, $$in2$i743 = 0, $$in2$i769 = 0, $$in2$i785 = 0;
 var $$in2$i801 = 0, $$in2$i817 = 0, $$in2$i833 = 0, $$in2$i87 = 0, $$in3$i = 0, $$in3$i105 = 0, $$in3$i121 = 0, $$in3$i137 = 0, $$in3$i153 = 0, $$in3$i169 = 0, $$in3$i185 = 0, $$in3$i201 = 0, $$in3$i217 = 0, $$in3$i235 = 0, $$in3$i251 = 0, $$in3$i267 = 0, $$in3$i283 = 0, $$in3$i299 = 0, $$in3$i313 = 0, $$in3$i327 = 0;
 var $$in3$i343 = 0, $$in3$i359 = 0, $$in3$i375 = 0, $$in3$i391 = 0, $$in3$i430 = 0, $$in3$i462 = 0, $$in3$i509 = 0, $$in3$i532 = 0, $$in3$i548 = 0, $$in3$i564 = 0, $$in3$i580 = 0, $$in3$i596 = 0, $$in3$i623 = 0, $$in3$i681 = 0, $$in3$i697 = 0, $$in3$i713 = 0, $$in3$i729 = 0, $$in3$i745 = 0, $$in3$i75 = 0, $$in3$i771 = 0;
 var $$in3$i787 = 0, $$in3$i803 = 0, $$in3$i819 = 0, $$in3$i835 = 0, $$in3$i89 = 0, $$lcssa = Math_fround(0), $$lcssa3056 = Math_fround(0), $$lcssa3057 = Math_fround(0), $$lcssa3058 = Math_fround(0), $$lcssa3059 = Math_fround(0), $$lcssa3060 = Math_fround(0), $$lcssa3061 = Math_fround(0), $$lcssa3062 = Math_fround(0), $$lcssa3063 = Math_fround(0), $$lcssa3064 = Math_fround(0), $$lcssa3065 = Math_fround(0), $$lcssa3066 = Math_fround(0), $$lcssa3067 = Math_fround(0), $$lcssa3068 = Math_fround(0), $$lcssa3069 = Math_fround(0);
 var $$lcssa3070 = Math_fround(0), $$lcssa3071 = Math_fround(0), $$lcssa3072 = Math_fround(0), $$lcssa3073 = Math_fround(0), $$lcssa3074 = Math_fround(0), $$lcssa3075 = Math_fround(0), $$lcssa3076 = Math_fround(0), $$lcssa3077 = Math_fround(0), $$lcssa3078 = Math_fround(0), $$lcssa3079 = Math_fround(0), $$lcssa3080 = Math_fround(0), $$lcssa3081 = Math_fround(0), $$lcssa3082 = Math_fround(0), $$lcssa3083 = Math_fround(0), $$lcssa3084 = Math_fround(0), $$lcssa3085 = Math_fround(0), $$lcssa3086 = Math_fround(0), $$lcssa3087 = Math_fround(0), $$lcssa3088 = Math_fround(0), $$lcssa3089 = Math_fround(0);
 var $$lcssa3090 = Math_fround(0), $$lcssa3091 = Math_fround(0), $$lcssa3092 = Math_fround(0), $$lcssa3093 = Math_fround(0), $$lcssa3094 = Math_fround(0), $$lcssa3095 = Math_fround(0), $$lcssa3096 = Math_fround(0), $$lcssa3097 = Math_fround(0), $$lcssa3098 = Math_fround(0), $$lcssa3099 = Math_fround(0), $$lcssa3100 = Math_fround(0), $$lcssa3101 = Math_fround(0), $$lcssa3102 = Math_fround(0), $$lcssa3103 = Math_fround(0), $$lcssa3104 = Math_fround(0), $$lcssa3105 = Math_fround(0), $$lcssa3106 = Math_fround(0), $$lcssa3107 = Math_fround(0), $$lcssa3108 = Math_fround(0), $$lcssa3109 = Math_fround(0);
 var $$lcssa3110 = Math_fround(0), $$lcssa3111 = Math_fround(0), $$lcssa3112 = Math_fround(0), $$lcssa3113 = Math_fround(0), $$lcssa3114 = Math_fround(0), $$lcssa3115 = Math_fround(0), $$lcssa3116 = Math_fround(0), $$lcssa3117 = Math_fround(0), $$lcssa3118 = Math_fround(0), $$lcssa3119 = 0, $$lcssa3120 = 0, $$lcssa3121 = 0, $$lcssa3122 = 0, $$not2990 = 0, $$not2992 = 0, $$not2994 = 0, $$not2996 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0;
 var $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0;
 var $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0);
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0;
 var $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0);
 var $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0);
 var $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0);
 var $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0);
 var $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0);
 var $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = Math_fround(0);
 var $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0);
 var $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0);
 var $407 = Math_fround(0), $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0);
 var $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0);
 var $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = 0, $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = Math_fround(0), $455 = 0, $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0);
 var $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = 0, $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0);
 var $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0);
 var $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0);
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = Math_fround(0), $53 = 0, $530 = 0, $531 = Math_fround(0), $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = Math_fround(0), $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0);
 var $605 = Math_fround(0), $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = Math_fround(0);
 var $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0;
 var $641 = 0, $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = 0, $657 = 0, $658 = 0, $659 = 0;
 var $66 = 0, $660 = 0, $661 = 0, $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = 0, $677 = 0;
 var $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0);
 var $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0;
 var $713 = 0, $714 = 0, $715 = 0, $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = 0;
 var $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0);
 var $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = Math_fround(0), $767 = Math_fround(0);
 var $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0;
 var $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0;
 var $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0);
 var $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0);
 var $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = Math_fround(0), $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0;
 var $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = Math_fround(0), $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $88 = 0;
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $a$pn4$i = 0, $a$pn4$i212 = 0, $a$pn4$i294 = 0, $a$pn4$i308 = 0, $a$pn4$i386 = 0, $a$pn4$i425 = 0, $a$pn4$i457 = 0, $a$pn4$i504 = 0;
 var $a$pn4$i591 = 0, $a$pn4$i618 = 0, $a$pn4$i70 = 0, $a$pn4$i740 = 0, $a$pn4$i830 = 0, $a$pn6$i = 0, $a$pn6$i216 = 0, $a$pn6$i298 = 0, $a$pn6$i312 = 0, $a$pn6$i390 = 0, $a$pn6$i429 = 0, $a$pn6$i461 = 0, $a$pn6$i508 = 0, $a$pn6$i595 = 0, $a$pn6$i622 = 0, $a$pn6$i74 = 0, $a$pn6$i744 = 0, $a$pn6$i834 = 0, $b$a$i = 0, $b$a$i114 = 0;
 var $b$a$i130 = 0, $b$a$i146 = 0, $b$a$i162 = 0, $b$a$i178 = 0, $b$a$i194 = 0, $b$a$i210 = 0, $b$a$i228 = 0, $b$a$i244 = 0, $b$a$i260 = 0, $b$a$i276 = 0, $b$a$i292 = 0, $b$a$i306 = 0, $b$a$i320 = 0, $b$a$i336 = 0, $b$a$i352 = 0, $b$a$i368 = 0, $b$a$i384 = 0, $b$a$i423 = 0, $b$a$i455 = 0, $b$a$i502 = 0;
 var $b$a$i525 = 0, $b$a$i541 = 0, $b$a$i557 = 0, $b$a$i573 = 0, $b$a$i589 = 0, $b$a$i616 = 0, $b$a$i674 = 0, $b$a$i68 = 0, $b$a$i690 = 0, $b$a$i706 = 0, $b$a$i722 = 0, $b$a$i738 = 0, $b$a$i764 = 0, $b$a$i780 = 0, $b$a$i796 = 0, $b$a$i812 = 0, $b$a$i82 = 0, $b$a$i828 = 0, $b$a$i98 = 0, $b$a7$i = 0;
 var $b$a7$i214 = 0, $b$a7$i296 = 0, $b$a7$i310 = 0, $b$a7$i388 = 0, $b$a7$i427 = 0, $b$a7$i459 = 0, $b$a7$i506 = 0, $b$a7$i593 = 0, $b$a7$i620 = 0, $b$a7$i72 = 0, $b$a7$i742 = 0, $b$a7$i832 = 0, $exitcond = 0, $k$03124 = 0, $not$ = 0, $not$2991 = 0, $not$2993 = 0, $not$2995 = 0, $not$3017 = 0, $not$3020 = 0;
 var $not$3023 = 0, $not$3026 = 0, $not$3029 = 0, $not$3030 = 0, $not$3031 = 0, $not$3032 = 0, $not$3033 = 0, $not$3034 = 0, $not$3035 = 0, $not$3036 = 0, $not$3037 = 0, $not$3038 = 0, $not$3039 = 0, $not$3040 = 0, $not$3044 = 0, $not$3045 = 0, $not$3046 = 0, $not$3047 = 0, $notlhs3018 = 0, $notlhs3021 = 0;
 var $notlhs3024 = 0, $notlhs3027 = 0, $notrhs3019 = 0, $notrhs3022 = 0, $notrhs3025 = 0, $notrhs3028 = 0, $phitmp = 0, $phitmp3192 = 0, $phitmp3193 = 0, $phitmp3194 = 0, $plane$03123 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1312|0;
 $0 = sp + 1296|0;
 $1 = sp + 1280|0;
 $2 = sp + 1264|0;
 $3 = sp + 1248|0;
 $4 = sp + 1232|0;
 $5 = sp + 1216|0;
 $6 = sp + 1200|0;
 $7 = sp + 1184|0;
 $8 = sp + 1168|0;
 $9 = sp + 1152|0;
 $10 = sp + 1136|0;
 $11 = sp + 1120|0;
 $12 = sp + 1104|0;
 $13 = sp + 1088|0;
 $14 = sp + 1072|0;
 $15 = sp + 1056|0;
 $16 = sp + 1040|0;
 $17 = sp + 1024|0;
 $18 = sp + 1008|0;
 $19 = sp + 992|0;
 $20 = sp + 976|0;
 $21 = sp + 960|0;
 $22 = sp + 944|0;
 $23 = sp + 928|0;
 $24 = sp + 912|0;
 $25 = sp + 896|0;
 $26 = sp + 880|0;
 $27 = sp + 864|0;
 $28 = sp + 848|0;
 $29 = sp + 832|0;
 $30 = sp + 816|0;
 $31 = sp + 800|0;
 $32 = sp + 784|0;
 $33 = sp + 768|0;
 $34 = sp + 752|0;
 $35 = sp + 736|0;
 $36 = sp + 720|0;
 $37 = sp + 704|0;
 $38 = sp + 688|0;
 $39 = sp + 672|0;
 $40 = sp + 656|0;
 $41 = sp + 640|0;
 $42 = sp + 288|0;
 $43 = sp + 272|0;
 $44 = sp + 256|0;
 $45 = sp + 240|0;
 $46 = sp + 224|0;
 $47 = sp + 208|0;
 $48 = sp + 192|0;
 $49 = sp + 176|0;
 $50 = sp + 160|0;
 $51 = sp + 144|0;
 $52 = sp + 48|0;
 $53 = sp;
 $54 = sp + 16|0;
 $55 = sp + 32|0;
 $56 = sp + 64|0;
 $57 = sp + 80|0;
 $58 = sp + 96|0;
 $59 = sp + 112|0;
 $60 = sp + 128|0;
 $61 = sp + 304|0;
 $62 = sp + 320|0;
 $63 = sp + 336|0;
 $64 = sp + 352|0;
 $65 = sp + 368|0;
 $66 = sp + 384|0;
 $67 = sp + 400|0;
 $68 = sp + 416|0;
 $69 = sp + 432|0;
 $70 = sp + 448|0;
 $71 = sp + 464|0;
 $72 = sp + 480|0;
 $73 = sp + 496|0;
 $74 = sp + 512|0;
 $75 = sp + 528|0;
 $76 = sp + 544|0;
 $77 = sp + 560|0;
 $78 = sp + 576|0;
 $79 = sp + 592|0;
 $80 = sp + 608|0;
 $81 = sp + 624|0;
 $82 = (($collDataV4) + 80|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($82) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($82) + 8|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($82) + 12|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($collDataV4) + 16|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($90) + 4|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($90) + 8|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($90) + 12|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($collDataV4) + 96|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($98) + 4|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($98) + 8|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($98) + 12|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($collDataV4) + 32|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($106) + 4|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($106) + 8|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($106) + 12|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($collDataV4) + 112|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($114) + 4|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($114) + 8|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($114) + 12|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($collDataV4) + 48|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($122) + 4|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($122) + 8|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($122) + 12|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = (($collDataV4) + 128|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($130) + 4|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($130) + 8|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($130) + 12|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($collDataV4) + 64|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = (($138) + 4|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($138) + 8|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($138) + 12|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround($83 - $91);
 $147 = Math_fround($85 - $93);
 $148 = Math_fround($87 - $95);
 $149 = Math_fround($99 - $107);
 $150 = Math_fround($101 - $109);
 $151 = Math_fround($103 - $111);
 $152 = Math_fround($115 - $123);
 $153 = Math_fround($117 - $125);
 $154 = Math_fround($119 - $127);
 $155 = Math_fround($131 - $139);
 $156 = Math_fround($133 - $141);
 $157 = Math_fround($135 - $143);
 $158 = ($numPlanes|0)==(0);
 if ($158) {
  $$lcssa = Math_fround(-3.40282346638528859812E+38);$$lcssa3056 = Math_fround(-3.40282346638528859812E+38);$$lcssa3057 = Math_fround(-3.40282346638528859812E+38);$$lcssa3058 = Math_fround(-3.40282346638528859812E+38);$$lcssa3059 = Math_fround(3.40282346638528859812E+38);$$lcssa3060 = Math_fround(3.40282346638528859812E+38);$$lcssa3061 = Math_fround(3.40282346638528859812E+38);$$lcssa3062 = Math_fround(3.40282346638528859812E+38);$$lcssa3063 = Math_fround(-3.40282346638528859812E+38);$$lcssa3064 = Math_fround(-3.40282346638528859812E+38);$$lcssa3065 = Math_fround(-3.40282346638528859812E+38);$$lcssa3066 = Math_fround(-3.40282346638528859812E+38);$$lcssa3067 = Math_fround(-3.40282346638528859812E+38);$$lcssa3068 = Math_fround(-3.40282346638528859812E+38);$$lcssa3069 = Math_fround(-3.40282346638528859812E+38);$$lcssa3070 = Math_fround(-3.40282346638528859812E+38);$$lcssa3071 = Math_fround(0.0);$$lcssa3072 = Math_fround(0.0);$$lcssa3073 = Math_fround(0.0);$$lcssa3074 = Math_fround(0.0);$$lcssa3075 = Math_fround(0.0);$$lcssa3076 = Math_fround(0.0);$$lcssa3077 = Math_fround(0.0);$$lcssa3078 = Math_fround(0.0);$$lcssa3079 = Math_fround(0.0);$$lcssa3080 = Math_fround(0.0);$$lcssa3081 = Math_fround(0.0);$$lcssa3082 = Math_fround(0.0);$$lcssa3083 = Math_fround(0.0);$$lcssa3084 = Math_fround(0.0);$$lcssa3085 = Math_fround(0.0);$$lcssa3086 = Math_fround(0.0);$$lcssa3087 = Math_fround(0.0);$$lcssa3088 = Math_fround(0.0);$$lcssa3089 = Math_fround(0.0);$$lcssa3090 = Math_fround(0.0);$$lcssa3091 = Math_fround(0.0);$$lcssa3092 = Math_fround(0.0);$$lcssa3093 = Math_fround(0.0);$$lcssa3094 = Math_fround(0.0);$$lcssa3095 = Math_fround(0.0);$$lcssa3096 = Math_fround(0.0);$$lcssa3097 = Math_fround(0.0);$$lcssa3098 = Math_fround(0.0);$$lcssa3099 = Math_fround(0.0);$$lcssa3100 = Math_fround(0.0);$$lcssa3101 = Math_fround(0.0);$$lcssa3102 = Math_fround(0.0);$$lcssa3103 = Math_fround(0.0);$$lcssa3104 = Math_fround(0.0);$$lcssa3105 = Math_fround(0.0);$$lcssa3106 = Math_fround(0.0);$$lcssa3107 = Math_fround(0.0);$$lcssa3108 = Math_fround(0.0);$$lcssa3109 = Math_fround(0.0);$$lcssa3110 = Math_fround(0.0);$$lcssa3111 = Math_fround(0.0);$$lcssa3112 = Math_fround(0.0);$$lcssa3113 = Math_fround(0.0);$$lcssa3114 = Math_fround(0.0);$$lcssa3115 = Math_fround(0.0);$$lcssa3116 = Math_fround(0.0);$$lcssa3117 = Math_fround(0.0);$$lcssa3118 = Math_fround(0.0);$$lcssa3119 = 1;$$lcssa3120 = 1;$$lcssa3121 = 1;$$lcssa3122 = 1;
 } else {
  $159 = (($1) + 4|0);
  $160 = (($1) + 8|0);
  $161 = (($1) + 12|0);
  $162 = (($0) + 4|0);
  $163 = (($0) + 8|0);
  $164 = (($0) + 12|0);
  $165 = (($3) + 4|0);
  $166 = (($3) + 8|0);
  $167 = (($3) + 12|0);
  $168 = (($2) + 4|0);
  $169 = (($2) + 8|0);
  $170 = (($2) + 12|0);
  $171 = (($5) + 4|0);
  $172 = (($5) + 8|0);
  $173 = (($5) + 12|0);
  $174 = (($4) + 4|0);
  $175 = (($4) + 8|0);
  $176 = (($4) + 12|0);
  $177 = (($7) + 4|0);
  $178 = (($7) + 8|0);
  $179 = (($7) + 12|0);
  $180 = (($6) + 4|0);
  $181 = (($6) + 8|0);
  $182 = (($6) + 12|0);
  $183 = (($9) + 4|0);
  $184 = (($9) + 8|0);
  $185 = (($9) + 12|0);
  $186 = (($8) + 4|0);
  $187 = (($8) + 8|0);
  $188 = (($8) + 12|0);
  $189 = (($11) + 4|0);
  $190 = (($11) + 8|0);
  $191 = (($11) + 12|0);
  $192 = (($10) + 4|0);
  $193 = (($10) + 8|0);
  $194 = (($10) + 12|0);
  $195 = (($13) + 4|0);
  $196 = (($13) + 8|0);
  $197 = (($13) + 12|0);
  $198 = (($12) + 4|0);
  $199 = (($12) + 8|0);
  $200 = (($12) + 12|0);
  $201 = (($15) + 4|0);
  $202 = (($15) + 8|0);
  $203 = (($15) + 12|0);
  $204 = (($14) + 4|0);
  $205 = (($14) + 8|0);
  $206 = (($14) + 12|0);
  $207 = (($17) + 4|0);
  $208 = (($17) + 8|0);
  $209 = (($17) + 12|0);
  $210 = (($16) + 4|0);
  $211 = (($16) + 8|0);
  $212 = (($16) + 12|0);
  $213 = (($19) + 4|0);
  $214 = (($19) + 8|0);
  $215 = (($19) + 12|0);
  $216 = (($18) + 4|0);
  $217 = (($18) + 8|0);
  $218 = (($18) + 12|0);
  $219 = (($21) + 4|0);
  $220 = (($21) + 8|0);
  $221 = (($21) + 12|0);
  $222 = (($20) + 4|0);
  $223 = (($20) + 8|0);
  $224 = (($20) + 12|0);
  $225 = (($23) + 4|0);
  $226 = (($23) + 8|0);
  $227 = (($23) + 12|0);
  $228 = (($22) + 4|0);
  $229 = (($22) + 8|0);
  $230 = (($22) + 12|0);
  $231 = (($25) + 4|0);
  $232 = (($25) + 8|0);
  $233 = (($25) + 12|0);
  $234 = (($24) + 4|0);
  $235 = (($24) + 8|0);
  $236 = (($24) + 12|0);
  $237 = (($27) + 4|0);
  $238 = (($27) + 8|0);
  $239 = (($27) + 12|0);
  $240 = (($26) + 4|0);
  $241 = (($26) + 8|0);
  $242 = (($26) + 12|0);
  $243 = (($29) + 4|0);
  $244 = (($29) + 8|0);
  $245 = (($29) + 12|0);
  $246 = (($28) + 4|0);
  $247 = (($28) + 8|0);
  $248 = (($28) + 12|0);
  $249 = (($31) + 4|0);
  $250 = (($31) + 8|0);
  $251 = (($31) + 12|0);
  $252 = (($30) + 4|0);
  $253 = (($30) + 8|0);
  $254 = (($30) + 12|0);
  $255 = (($33) + 4|0);
  $256 = (($33) + 8|0);
  $257 = (($33) + 12|0);
  $258 = (($32) + 4|0);
  $259 = (($32) + 8|0);
  $260 = (($32) + 12|0);
  $318 = Math_fround(-3.40282346638528859812E+38);$320 = Math_fround(-3.40282346638528859812E+38);$322 = Math_fround(-3.40282346638528859812E+38);$324 = Math_fround(-3.40282346638528859812E+38);$329 = Math_fround(0.0);$330 = Math_fround(0.0);$331 = Math_fround(0.0);$332 = Math_fround(0.0);$337 = Math_fround(0.0);$338 = Math_fround(0.0);$339 = Math_fround(0.0);$340 = Math_fround(0.0);$345 = Math_fround(0.0);$346 = Math_fround(0.0);$347 = Math_fround(0.0);$348 = Math_fround(0.0);$353 = Math_fround(0.0);$354 = Math_fround(0.0);$355 = Math_fround(0.0);$356 = Math_fround(0.0);$366 = Math_fround(-3.40282346638528859812E+38);$368 = Math_fround(-3.40282346638528859812E+38);$370 = Math_fround(-3.40282346638528859812E+38);$372 = Math_fround(-3.40282346638528859812E+38);$377 = Math_fround(0.0);$378 = Math_fround(0.0);$379 = Math_fround(0.0);$380 = Math_fround(0.0);$385 = Math_fround(0.0);$386 = Math_fround(0.0);$387 = Math_fround(0.0);$388 = Math_fround(0.0);$393 = Math_fround(0.0);$394 = Math_fround(0.0);$395 = Math_fround(0.0);$396 = Math_fround(0.0);$401 = Math_fround(0.0);$402 = Math_fround(0.0);$403 = Math_fround(0.0);$404 = Math_fround(0.0);$411 = 0;$413 = 0;$416 = 0;$418 = 0;$450 = Math_fround(3.40282346638528859812E+38);$452 = Math_fround(3.40282346638528859812E+38);$454 = Math_fround(3.40282346638528859812E+38);$456 = Math_fround(3.40282346638528859812E+38);$462 = Math_fround(-3.40282346638528859812E+38);$464 = Math_fround(-3.40282346638528859812E+38);$466 = Math_fround(-3.40282346638528859812E+38);$468 = Math_fround(-3.40282346638528859812E+38);$473 = Math_fround(0.0);$474 = Math_fround(0.0);$475 = Math_fround(0.0);$476 = Math_fround(0.0);$481 = Math_fround(0.0);$482 = Math_fround(0.0);$483 = Math_fround(0.0);$484 = Math_fround(0.0);$489 = Math_fround(0.0);$490 = Math_fround(0.0);$491 = Math_fround(0.0);$492 = Math_fround(0.0);$497 = Math_fround(0.0);$498 = Math_fround(0.0);$499 = Math_fround(0.0);$500 = Math_fround(0.0);$k$03124 = 0;$plane$03123 = $convexPlanes;
  while(1) {
   $261 = Math_fround(HEAPF32[$plane$03123>>2]);
   $262 = (($plane$03123) + 4|0);
   $263 = Math_fround(HEAPF32[$262>>2]);
   $264 = (($plane$03123) + 8|0);
   $265 = Math_fround(HEAPF32[$264>>2]);
   $266 = (($plane$03123) + 12|0);
   $267 = Math_fround(HEAPF32[$266>>2]);
   $268 = (($plane$03123) + 16|0);
   $269 = Math_fround($83 * $261);
   $270 = Math_fround($99 * $261);
   $271 = Math_fround($115 * $261);
   $272 = Math_fround($131 * $261);
   $273 = Math_fround($269 + $267);
   $274 = Math_fround($270 + $267);
   $275 = Math_fround($271 + $267);
   $276 = Math_fround($272 + $267);
   $277 = Math_fround($85 * $263);
   $278 = Math_fround($101 * $263);
   $279 = Math_fround($117 * $263);
   $280 = Math_fround($133 * $263);
   $281 = Math_fround($277 + $273);
   $282 = Math_fround($278 + $274);
   $283 = Math_fround($279 + $275);
   $284 = Math_fround($280 + $276);
   $285 = Math_fround($87 * $265);
   $286 = Math_fround($103 * $265);
   $287 = Math_fround($119 * $265);
   $288 = Math_fround($135 * $265);
   $289 = Math_fround($285 + $281);
   $290 = Math_fround($286 + $282);
   $291 = Math_fround($287 + $283);
   $292 = Math_fround($288 + $284);
   $293 = Math_fround($91 * $261);
   $294 = Math_fround($107 * $261);
   $295 = Math_fround($123 * $261);
   $296 = Math_fround($139 * $261);
   $297 = Math_fround($293 + $267);
   $298 = Math_fround($294 + $267);
   $299 = Math_fround($295 + $267);
   $300 = Math_fround($296 + $267);
   $301 = Math_fround($93 * $263);
   $302 = Math_fround($109 * $263);
   $303 = Math_fround($125 * $263);
   $304 = Math_fround($141 * $263);
   $305 = Math_fround($301 + $297);
   $306 = Math_fround($302 + $298);
   $307 = Math_fround($303 + $299);
   $308 = Math_fround($304 + $300);
   $309 = Math_fround($95 * $265);
   $310 = Math_fround($111 * $265);
   $311 = Math_fround($127 * $265);
   $312 = Math_fround($143 * $265);
   $313 = Math_fround($309 + $305);
   $314 = Math_fround($310 + $306);
   $315 = Math_fround($311 + $307);
   $316 = Math_fround($312 + $308);
   $317 = $313 > $318;
   $319 = $314 > $320;
   $321 = $315 > $322;
   $323 = $316 > $324;
   HEAPF32[$1>>2] = $313;
   HEAPF32[$159>>2] = $314;
   HEAPF32[$160>>2] = $315;
   HEAPF32[$161>>2] = $316;
   HEAPF32[$0>>2] = $318;
   HEAPF32[$162>>2] = $320;
   HEAPF32[$163>>2] = $322;
   HEAPF32[$164>>2] = $324;
   $b$a$i828 = $317 ? $1 : $0;
   $325 = Math_fround(HEAPF32[$b$a$i828>>2]);
   $a$pn4$i830 = $319 ? $1 : $0;
   $$in1$i831 = (($a$pn4$i830) + 4|0);
   $326 = Math_fround(HEAPF32[$$in1$i831>>2]);
   $b$a7$i832 = $321 ? $1 : $0;
   $$in2$i833 = (($b$a7$i832) + 8|0);
   $327 = Math_fround(HEAPF32[$$in2$i833>>2]);
   $a$pn6$i834 = $323 ? $1 : $0;
   $$in3$i835 = (($a$pn6$i834) + 12|0);
   $328 = Math_fround(HEAPF32[$$in3$i835>>2]);
   HEAPF32[$3>>2] = $261;
   HEAPF32[$165>>2] = $263;
   HEAPF32[$166>>2] = $265;
   HEAPF32[$167>>2] = Math_fround(0.0);
   HEAPF32[$2>>2] = $329;
   HEAPF32[$168>>2] = $330;
   HEAPF32[$169>>2] = $331;
   HEAPF32[$170>>2] = $332;
   $b$a$i812 = $317 ? $3 : $2;
   $333 = Math_fround(HEAPF32[$b$a$i812>>2]);
   $$in1$i815 = (($b$a$i812) + 4|0);
   $334 = Math_fround(HEAPF32[$$in1$i815>>2]);
   $$in2$i817 = (($b$a$i812) + 8|0);
   $335 = Math_fround(HEAPF32[$$in2$i817>>2]);
   $$in3$i819 = (($b$a$i812) + 12|0);
   $336 = Math_fround(HEAPF32[$$in3$i819>>2]);
   HEAPF32[$5>>2] = $261;
   HEAPF32[$171>>2] = $263;
   HEAPF32[$172>>2] = $265;
   HEAPF32[$173>>2] = Math_fround(0.0);
   HEAPF32[$4>>2] = $337;
   HEAPF32[$174>>2] = $338;
   HEAPF32[$175>>2] = $339;
   HEAPF32[$176>>2] = $340;
   $b$a$i796 = $319 ? $5 : $4;
   $341 = Math_fround(HEAPF32[$b$a$i796>>2]);
   $$in1$i799 = (($b$a$i796) + 4|0);
   $342 = Math_fround(HEAPF32[$$in1$i799>>2]);
   $$in2$i801 = (($b$a$i796) + 8|0);
   $343 = Math_fround(HEAPF32[$$in2$i801>>2]);
   $$in3$i803 = (($b$a$i796) + 12|0);
   $344 = Math_fround(HEAPF32[$$in3$i803>>2]);
   HEAPF32[$7>>2] = $261;
   HEAPF32[$177>>2] = $263;
   HEAPF32[$178>>2] = $265;
   HEAPF32[$179>>2] = Math_fround(0.0);
   HEAPF32[$6>>2] = $345;
   HEAPF32[$180>>2] = $346;
   HEAPF32[$181>>2] = $347;
   HEAPF32[$182>>2] = $348;
   $b$a$i780 = $321 ? $7 : $6;
   $349 = Math_fround(HEAPF32[$b$a$i780>>2]);
   $$in1$i783 = (($b$a$i780) + 4|0);
   $350 = Math_fround(HEAPF32[$$in1$i783>>2]);
   $$in2$i785 = (($b$a$i780) + 8|0);
   $351 = Math_fround(HEAPF32[$$in2$i785>>2]);
   $$in3$i787 = (($b$a$i780) + 12|0);
   $352 = Math_fround(HEAPF32[$$in3$i787>>2]);
   HEAPF32[$9>>2] = $261;
   HEAPF32[$183>>2] = $263;
   HEAPF32[$184>>2] = $265;
   HEAPF32[$185>>2] = Math_fround(0.0);
   HEAPF32[$8>>2] = $353;
   HEAPF32[$186>>2] = $354;
   HEAPF32[$187>>2] = $355;
   HEAPF32[$188>>2] = $356;
   $b$a$i764 = $323 ? $9 : $8;
   $357 = Math_fround(HEAPF32[$b$a$i764>>2]);
   $$in1$i767 = (($b$a$i764) + 4|0);
   $358 = Math_fround(HEAPF32[$$in1$i767>>2]);
   $$in2$i769 = (($b$a$i764) + 8|0);
   $359 = Math_fround(HEAPF32[$$in2$i769>>2]);
   $$in3$i771 = (($b$a$i764) + 12|0);
   $360 = Math_fround(HEAPF32[$$in3$i771>>2]);
   $361 = $289 > Math_fround(0.0);
   $362 = $290 > Math_fround(0.0);
   $363 = $291 > Math_fround(0.0);
   $364 = $292 > Math_fround(0.0);
   $365 = $289 > $366;
   $367 = $290 > $368;
   $369 = $291 > $370;
   $371 = $292 > $372;
   HEAPF32[$11>>2] = $289;
   HEAPF32[$189>>2] = $290;
   HEAPF32[$190>>2] = $291;
   HEAPF32[$191>>2] = $292;
   HEAPF32[$10>>2] = $366;
   HEAPF32[$192>>2] = $368;
   HEAPF32[$193>>2] = $370;
   HEAPF32[$194>>2] = $372;
   $b$a$i738 = $365 ? $11 : $10;
   $373 = Math_fround(HEAPF32[$b$a$i738>>2]);
   $a$pn4$i740 = $367 ? $11 : $10;
   $$in1$i741 = (($a$pn4$i740) + 4|0);
   $374 = Math_fround(HEAPF32[$$in1$i741>>2]);
   $b$a7$i742 = $369 ? $11 : $10;
   $$in2$i743 = (($b$a7$i742) + 8|0);
   $375 = Math_fround(HEAPF32[$$in2$i743>>2]);
   $a$pn6$i744 = $371 ? $11 : $10;
   $$in3$i745 = (($a$pn6$i744) + 12|0);
   $376 = Math_fround(HEAPF32[$$in3$i745>>2]);
   HEAPF32[$13>>2] = $261;
   HEAPF32[$195>>2] = $263;
   HEAPF32[$196>>2] = $265;
   HEAPF32[$197>>2] = Math_fround(0.0);
   HEAPF32[$12>>2] = $377;
   HEAPF32[$198>>2] = $378;
   HEAPF32[$199>>2] = $379;
   HEAPF32[$200>>2] = $380;
   $b$a$i722 = $365 ? $13 : $12;
   $381 = Math_fround(HEAPF32[$b$a$i722>>2]);
   $$in1$i725 = (($b$a$i722) + 4|0);
   $382 = Math_fround(HEAPF32[$$in1$i725>>2]);
   $$in2$i727 = (($b$a$i722) + 8|0);
   $383 = Math_fround(HEAPF32[$$in2$i727>>2]);
   $$in3$i729 = (($b$a$i722) + 12|0);
   $384 = Math_fround(HEAPF32[$$in3$i729>>2]);
   HEAPF32[$15>>2] = $261;
   HEAPF32[$201>>2] = $263;
   HEAPF32[$202>>2] = $265;
   HEAPF32[$203>>2] = Math_fround(0.0);
   HEAPF32[$14>>2] = $385;
   HEAPF32[$204>>2] = $386;
   HEAPF32[$205>>2] = $387;
   HEAPF32[$206>>2] = $388;
   $b$a$i706 = $367 ? $15 : $14;
   $389 = Math_fround(HEAPF32[$b$a$i706>>2]);
   $$in1$i709 = (($b$a$i706) + 4|0);
   $390 = Math_fround(HEAPF32[$$in1$i709>>2]);
   $$in2$i711 = (($b$a$i706) + 8|0);
   $391 = Math_fround(HEAPF32[$$in2$i711>>2]);
   $$in3$i713 = (($b$a$i706) + 12|0);
   $392 = Math_fround(HEAPF32[$$in3$i713>>2]);
   HEAPF32[$17>>2] = $261;
   HEAPF32[$207>>2] = $263;
   HEAPF32[$208>>2] = $265;
   HEAPF32[$209>>2] = Math_fround(0.0);
   HEAPF32[$16>>2] = $393;
   HEAPF32[$210>>2] = $394;
   HEAPF32[$211>>2] = $395;
   HEAPF32[$212>>2] = $396;
   $b$a$i690 = $369 ? $17 : $16;
   $397 = Math_fround(HEAPF32[$b$a$i690>>2]);
   $$in1$i693 = (($b$a$i690) + 4|0);
   $398 = Math_fround(HEAPF32[$$in1$i693>>2]);
   $$in2$i695 = (($b$a$i690) + 8|0);
   $399 = Math_fround(HEAPF32[$$in2$i695>>2]);
   $$in3$i697 = (($b$a$i690) + 12|0);
   $400 = Math_fround(HEAPF32[$$in3$i697>>2]);
   HEAPF32[$19>>2] = $261;
   HEAPF32[$213>>2] = $263;
   HEAPF32[$214>>2] = $265;
   HEAPF32[$215>>2] = Math_fround(0.0);
   HEAPF32[$18>>2] = $401;
   HEAPF32[$216>>2] = $402;
   HEAPF32[$217>>2] = $403;
   HEAPF32[$218>>2] = $404;
   $b$a$i674 = $371 ? $19 : $18;
   $405 = Math_fround(HEAPF32[$b$a$i674>>2]);
   $$in1$i677 = (($b$a$i674) + 4|0);
   $406 = Math_fround(HEAPF32[$$in1$i677>>2]);
   $$in2$i679 = (($b$a$i674) + 8|0);
   $407 = Math_fround(HEAPF32[$$in2$i679>>2]);
   $$in3$i681 = (($b$a$i674) + 12|0);
   $408 = Math_fround(HEAPF32[$$in3$i681>>2]);
   $not$3029 = $366 > Math_fround(0.0);
   $$ = $361 & $not$3029;
   $not$3030 = $368 > Math_fround(0.0);
   $409 = $362 & $not$3030;
   $not$3031 = $370 > Math_fround(0.0);
   $$2963 = $363 & $not$3031;
   $not$3032 = $372 > Math_fround(0.0);
   $410 = $364 & $not$3032;
   $not$3033 = ($411|0)!=(0);
   $$$ = $$ | $not$3033;
   $412 = $$$ << 31 >> 31;
   $not$3034 = ($413|0)!=(0);
   $414 = $409 | $not$3034;
   $415 = $414 << 31 >> 31;
   $not$3035 = ($416|0)!=(0);
   $$2963$ = $$2963 | $not$3035;
   $417 = $$2963$ << 31 >> 31;
   $not$3036 = ($418|0)!=(0);
   $419 = $410 | $not$3036;
   $420 = $419 << 31 >> 31;
   $421 = Math_fround($146 * $261);
   $422 = Math_fround($149 * $261);
   $423 = Math_fround($152 * $261);
   $424 = Math_fround($155 * $261);
   $425 = Math_fround($147 * $263);
   $426 = Math_fround($150 * $263);
   $427 = Math_fround($153 * $263);
   $428 = Math_fround($156 * $263);
   $429 = Math_fround($421 + $425);
   $430 = Math_fround($422 + $426);
   $431 = Math_fround($423 + $427);
   $432 = Math_fround($424 + $428);
   $433 = Math_fround($148 * $265);
   $434 = Math_fround($151 * $265);
   $435 = Math_fround($154 * $265);
   $436 = Math_fround($157 * $265);
   $437 = Math_fround($433 + $429);
   $438 = Math_fround($434 + $430);
   $439 = Math_fround($435 + $431);
   $440 = Math_fround($436 + $432);
   $441 = Math_fround($313 / $437);
   $442 = Math_fround($314 / $438);
   $443 = Math_fround($315 / $439);
   $444 = Math_fround($316 / $440);
   $445 = Math_fround(-$441);
   $446 = Math_fround(-$442);
   $447 = Math_fround(-$443);
   $448 = Math_fround(-$444);
   $449 = $450 > $445;
   $451 = $452 > $446;
   $453 = $454 > $447;
   $455 = $456 > $448;
   $not$3037 = $437 > Math_fround(0.0);
   $not$3038 = $438 > Math_fround(0.0);
   $not$3039 = $439 > Math_fround(0.0);
   $not$3040 = $440 > Math_fround(0.0);
   HEAPF32[$21>>2] = $445;
   HEAPF32[$219>>2] = $446;
   HEAPF32[$220>>2] = $447;
   HEAPF32[$221>>2] = $448;
   HEAPF32[$20>>2] = $450;
   HEAPF32[$222>>2] = $452;
   HEAPF32[$223>>2] = $454;
   HEAPF32[$224>>2] = $456;
   $$demorgan = $449 & $not$3037;
   $b$a$i616 = $$demorgan ? $21 : $20;
   $457 = Math_fround(HEAPF32[$b$a$i616>>2]);
   $$demorgan3041 = $451 & $not$3038;
   $a$pn4$i618 = $$demorgan3041 ? $21 : $20;
   $$in1$i619 = (($a$pn4$i618) + 4|0);
   $458 = Math_fround(HEAPF32[$$in1$i619>>2]);
   $$demorgan3042 = $453 & $not$3039;
   $b$a7$i620 = $$demorgan3042 ? $21 : $20;
   $$in2$i621 = (($b$a7$i620) + 8|0);
   $459 = Math_fround(HEAPF32[$$in2$i621>>2]);
   $$demorgan3043 = $455 & $not$3040;
   $a$pn6$i622 = $$demorgan3043 ? $21 : $20;
   $$in3$i623 = (($a$pn6$i622) + 12|0);
   $460 = Math_fround(HEAPF32[$$in3$i623>>2]);
   $461 = $462 < $445;
   $463 = $464 < $446;
   $465 = $466 < $447;
   $467 = $468 < $448;
   $not$3044 = $437 < Math_fround(0.0);
   $not$3045 = $438 < Math_fround(0.0);
   $not$3046 = $439 < Math_fround(0.0);
   $not$3047 = $440 < Math_fround(0.0);
   HEAPF32[$23>>2] = $445;
   HEAPF32[$225>>2] = $446;
   HEAPF32[$226>>2] = $447;
   HEAPF32[$227>>2] = $448;
   HEAPF32[$22>>2] = $462;
   HEAPF32[$228>>2] = $464;
   HEAPF32[$229>>2] = $466;
   HEAPF32[$230>>2] = $468;
   $$demorgan3048 = $461 & $not$3044;
   $b$a$i589 = $$demorgan3048 ? $23 : $22;
   $469 = Math_fround(HEAPF32[$b$a$i589>>2]);
   $$demorgan3049 = $463 & $not$3045;
   $a$pn4$i591 = $$demorgan3049 ? $23 : $22;
   $$in1$i592 = (($a$pn4$i591) + 4|0);
   $470 = Math_fround(HEAPF32[$$in1$i592>>2]);
   $$demorgan3050 = $465 & $not$3046;
   $b$a7$i593 = $$demorgan3050 ? $23 : $22;
   $$in2$i594 = (($b$a7$i593) + 8|0);
   $471 = Math_fround(HEAPF32[$$in2$i594>>2]);
   $$demorgan3051 = $467 & $not$3047;
   $a$pn6$i595 = $$demorgan3051 ? $23 : $22;
   $$in3$i596 = (($a$pn6$i595) + 12|0);
   $472 = Math_fround(HEAPF32[$$in3$i596>>2]);
   HEAPF32[$25>>2] = $261;
   HEAPF32[$231>>2] = $263;
   HEAPF32[$232>>2] = $265;
   HEAPF32[$233>>2] = Math_fround(0.0);
   HEAPF32[$24>>2] = $473;
   HEAPF32[$234>>2] = $474;
   HEAPF32[$235>>2] = $475;
   HEAPF32[$236>>2] = $476;
   $b$a$i573 = $$demorgan3048 ? $25 : $24;
   $477 = Math_fround(HEAPF32[$b$a$i573>>2]);
   $$in1$i576 = (($b$a$i573) + 4|0);
   $478 = Math_fround(HEAPF32[$$in1$i576>>2]);
   $$in2$i578 = (($b$a$i573) + 8|0);
   $479 = Math_fround(HEAPF32[$$in2$i578>>2]);
   $$in3$i580 = (($b$a$i573) + 12|0);
   $480 = Math_fround(HEAPF32[$$in3$i580>>2]);
   HEAPF32[$27>>2] = $261;
   HEAPF32[$237>>2] = $263;
   HEAPF32[$238>>2] = $265;
   HEAPF32[$239>>2] = Math_fround(0.0);
   HEAPF32[$26>>2] = $481;
   HEAPF32[$240>>2] = $482;
   HEAPF32[$241>>2] = $483;
   HEAPF32[$242>>2] = $484;
   $b$a$i557 = $$demorgan3049 ? $27 : $26;
   $485 = Math_fround(HEAPF32[$b$a$i557>>2]);
   $$in1$i560 = (($b$a$i557) + 4|0);
   $486 = Math_fround(HEAPF32[$$in1$i560>>2]);
   $$in2$i562 = (($b$a$i557) + 8|0);
   $487 = Math_fround(HEAPF32[$$in2$i562>>2]);
   $$in3$i564 = (($b$a$i557) + 12|0);
   $488 = Math_fround(HEAPF32[$$in3$i564>>2]);
   HEAPF32[$29>>2] = $261;
   HEAPF32[$243>>2] = $263;
   HEAPF32[$244>>2] = $265;
   HEAPF32[$245>>2] = Math_fround(0.0);
   HEAPF32[$28>>2] = $489;
   HEAPF32[$246>>2] = $490;
   HEAPF32[$247>>2] = $491;
   HEAPF32[$248>>2] = $492;
   $b$a$i541 = $$demorgan3050 ? $29 : $28;
   $493 = Math_fround(HEAPF32[$b$a$i541>>2]);
   $$in1$i544 = (($b$a$i541) + 4|0);
   $494 = Math_fround(HEAPF32[$$in1$i544>>2]);
   $$in2$i546 = (($b$a$i541) + 8|0);
   $495 = Math_fround(HEAPF32[$$in2$i546>>2]);
   $$in3$i548 = (($b$a$i541) + 12|0);
   $496 = Math_fround(HEAPF32[$$in3$i548>>2]);
   HEAPF32[$31>>2] = $261;
   HEAPF32[$249>>2] = $263;
   HEAPF32[$250>>2] = $265;
   HEAPF32[$251>>2] = Math_fround(0.0);
   HEAPF32[$30>>2] = $497;
   HEAPF32[$252>>2] = $498;
   HEAPF32[$253>>2] = $499;
   HEAPF32[$254>>2] = $500;
   $b$a$i525 = $$demorgan3051 ? $31 : $30;
   $501 = Math_fround(HEAPF32[$b$a$i525>>2]);
   $$in1$i528 = (($b$a$i525) + 4|0);
   $502 = Math_fround(HEAPF32[$$in1$i528>>2]);
   $$in2$i530 = (($b$a$i525) + 8|0);
   $503 = Math_fround(HEAPF32[$$in2$i530>>2]);
   $$in3$i532 = (($b$a$i525) + 12|0);
   $504 = Math_fround(HEAPF32[$$in3$i532>>2]);
   $505 = $437 == Math_fround(0.0);
   $506 = $438 == Math_fround(0.0);
   $507 = $439 == Math_fround(0.0);
   $508 = $440 == Math_fround(0.0);
   $$2968 = $505 & $361;
   $509 = $506 & $362;
   $$2969 = $507 & $363;
   $510 = $508 & $364;
   HEAPF32[$33>>2] = Math_fround(1.0);
   HEAPF32[$255>>2] = Math_fround(1.0);
   HEAPF32[$256>>2] = Math_fround(1.0);
   HEAPF32[$257>>2] = Math_fround(1.0);
   HEAPF32[$32>>2] = $469;
   HEAPF32[$258>>2] = $470;
   HEAPF32[$259>>2] = $471;
   HEAPF32[$260>>2] = $472;
   $b$a$i502 = $$2968 ? $33 : $32;
   $511 = Math_fround(HEAPF32[$b$a$i502>>2]);
   $a$pn4$i504 = $509 ? $33 : $32;
   $$in1$i505 = (($a$pn4$i504) + 4|0);
   $512 = Math_fround(HEAPF32[$$in1$i505>>2]);
   $b$a7$i506 = $$2969 ? $33 : $32;
   $$in2$i507 = (($b$a7$i506) + 8|0);
   $513 = Math_fround(HEAPF32[$$in2$i507>>2]);
   $a$pn6$i508 = $510 ? $33 : $32;
   $$in3$i509 = (($a$pn6$i508) + 12|0);
   $514 = Math_fround(HEAPF32[$$in3$i509>>2]);
   $515 = (($k$03124) + 1)|0;
   $exitcond = ($515|0)==($numPlanes|0);
   if ($exitcond) {
    break;
   } else {
    $318 = $325;$320 = $326;$322 = $327;$324 = $328;$329 = $333;$330 = $334;$331 = $335;$332 = $336;$337 = $341;$338 = $342;$339 = $343;$340 = $344;$345 = $349;$346 = $350;$347 = $351;$348 = $352;$353 = $357;$354 = $358;$355 = $359;$356 = $360;$366 = $373;$368 = $374;$370 = $375;$372 = $376;$377 = $381;$378 = $382;$379 = $383;$380 = $384;$385 = $389;$386 = $390;$387 = $391;$388 = $392;$393 = $397;$394 = $398;$395 = $399;$396 = $400;$401 = $405;$402 = $406;$403 = $407;$404 = $408;$411 = $412;$413 = $415;$416 = $417;$418 = $420;$450 = $457;$452 = $458;$454 = $459;$456 = $460;$462 = $511;$464 = $512;$466 = $513;$468 = $514;$473 = $477;$474 = $478;$475 = $479;$476 = $480;$481 = $485;$482 = $486;$483 = $487;$484 = $488;$489 = $493;$490 = $494;$491 = $495;$492 = $496;$497 = $501;$498 = $502;$499 = $503;$500 = $504;$k$03124 = $515;$plane$03123 = $268;
   }
  }
  $phitmp = $$$ ^ 1;
  $phitmp3192 = $414 ^ 1;
  $phitmp3193 = $$2963$ ^ 1;
  $phitmp3194 = $419 ^ 1;
  $$lcssa = $514;$$lcssa3056 = $513;$$lcssa3057 = $512;$$lcssa3058 = $511;$$lcssa3059 = $460;$$lcssa3060 = $459;$$lcssa3061 = $458;$$lcssa3062 = $457;$$lcssa3063 = $376;$$lcssa3064 = $375;$$lcssa3065 = $374;$$lcssa3066 = $373;$$lcssa3067 = $328;$$lcssa3068 = $327;$$lcssa3069 = $326;$$lcssa3070 = $325;$$lcssa3071 = $408;$$lcssa3072 = $407;$$lcssa3073 = $406;$$lcssa3074 = $405;$$lcssa3075 = $400;$$lcssa3076 = $399;$$lcssa3077 = $398;$$lcssa3078 = $397;$$lcssa3079 = $392;$$lcssa3080 = $391;$$lcssa3081 = $390;$$lcssa3082 = $389;$$lcssa3083 = $384;$$lcssa3084 = $383;$$lcssa3085 = $382;$$lcssa3086 = $381;$$lcssa3087 = $504;$$lcssa3088 = $503;$$lcssa3089 = $502;$$lcssa3090 = $501;$$lcssa3091 = $496;$$lcssa3092 = $495;$$lcssa3093 = $494;$$lcssa3094 = $493;$$lcssa3095 = $488;$$lcssa3096 = $487;$$lcssa3097 = $486;$$lcssa3098 = $485;$$lcssa3099 = $480;$$lcssa3100 = $479;$$lcssa3101 = $478;$$lcssa3102 = $477;$$lcssa3103 = $360;$$lcssa3104 = $359;$$lcssa3105 = $358;$$lcssa3106 = $357;$$lcssa3107 = $352;$$lcssa3108 = $351;$$lcssa3109 = $350;$$lcssa3110 = $349;$$lcssa3111 = $344;$$lcssa3112 = $343;$$lcssa3113 = $342;$$lcssa3114 = $341;$$lcssa3115 = $336;$$lcssa3116 = $335;$$lcssa3117 = $334;$$lcssa3118 = $333;$$lcssa3119 = $phitmp3194;$$lcssa3120 = $phitmp3193;$$lcssa3121 = $phitmp3192;$$lcssa3122 = $phitmp;
 }
 $516 = (($collDataV4) + 160|0);
 $517 = HEAP32[$516>>2]|0;
 $518 = (($collDataV4) + 164|0);
 $519 = HEAP32[$518>>2]|0;
 $520 = (($collDataV4) + 168|0);
 $521 = HEAP32[$520>>2]|0;
 $522 = (($collDataV4) + 172|0);
 $523 = HEAP32[$522>>2]|0;
 $524 = (($collDataV4) + 144|0);
 $525 = Math_fround(HEAPF32[$524>>2]);
 $526 = (($collDataV4) + 148|0);
 $527 = Math_fround(HEAPF32[$526>>2]);
 $528 = (($collDataV4) + 152|0);
 $529 = Math_fround(HEAPF32[$528>>2]);
 $530 = (($collDataV4) + 156|0);
 $531 = Math_fround(HEAPF32[$530>>2]);
 $532 = $517 & 2;
 $533 = $519 & 2;
 $534 = $521 & 2;
 $535 = $523 & 2;
 $536 = $$lcssa3066 >= Math_fround(0.0);
 $537 = $$lcssa3065 >= Math_fround(0.0);
 $538 = $$lcssa3064 >= Math_fround(0.0);
 $539 = $$lcssa3063 >= Math_fround(0.0);
 $540 = $$lcssa3066 < $proxRadius;
 $541 = $$lcssa3065 < $proxRadius;
 $542 = $$lcssa3064 < $proxRadius;
 $543 = $$lcssa3063 < $proxRadius;
 $$not2990 = ($532|0)==(0);
 $not$ = $536 & $$not2990;
 $$2972 = $540 & $not$;
 $$not2992 = ($533|0)==(0);
 $not$2991 = $537 & $$not2992;
 $544 = $541 & $not$2991;
 $$not2994 = ($534|0)==(0);
 $not$2993 = $538 & $$not2994;
 $$2973 = $542 & $not$2993;
 $$not2996 = ($535|0)==(0);
 $not$2995 = $539 & $$not2996;
 $545 = $543 & $not$2995;
 $546 = $$lcssa3122 & $$2972;
 $$2974 = $$lcssa3121 & $544;
 $547 = $$lcssa3120 & $$2973;
 $$2975 = $$lcssa3119 & $545;
 HEAP32[$35>>2] = 32;
 $548 = (($35) + 4|0);
 HEAP32[$548>>2] = 32;
 $549 = (($35) + 8|0);
 HEAP32[$549>>2] = 32;
 $550 = (($35) + 12|0);
 HEAP32[$550>>2] = 32;
 $b$a$i455 = $546 ? $35 : $34;
 ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
 $551 = HEAP32[$b$a$i455>>2]|0;
 $a$pn4$i457 = $$2974 ? $35 : $34;
 $$in1$i458 = (($a$pn4$i457) + 4|0);
 $552 = HEAP32[$$in1$i458>>2]|0;
 $b$a7$i459 = $547 ? $35 : $34;
 $$in2$i460 = (($b$a7$i459) + 8|0);
 $553 = HEAP32[$$in2$i460>>2]|0;
 $a$pn6$i461 = $$2975 ? $35 : $34;
 $$in3$i462 = (($a$pn6$i461) + 12|0);
 $554 = HEAP32[$$in3$i462>>2]|0;
 $555 = $525 > $$lcssa3066;
 $556 = $527 > $$lcssa3065;
 $557 = $529 > $$lcssa3064;
 $558 = $531 > $$lcssa3063;
 $559 = $555 & $not$;
 $$2978 = $556 & $not$2991;
 $560 = $557 & $not$2993;
 $$2979 = $558 & $not$2995;
 HEAP32[$37>>2] = 16;
 $561 = (($37) + 4|0);
 HEAP32[$561>>2] = 16;
 $562 = (($37) + 8|0);
 HEAP32[$562>>2] = 16;
 $563 = (($37) + 12|0);
 HEAP32[$563>>2] = 16;
 $b$a$i423 = $559 ? $37 : $36;
 ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;
 $564 = HEAP32[$b$a$i423>>2]|0;
 $a$pn4$i425 = $$2978 ? $37 : $36;
 $$in1$i426 = (($a$pn4$i425) + 4|0);
 $565 = HEAP32[$$in1$i426>>2]|0;
 $b$a7$i427 = $560 ? $37 : $36;
 $$in2$i428 = (($b$a7$i427) + 8|0);
 $566 = HEAP32[$$in2$i428>>2]|0;
 $a$pn6$i429 = $$2979 ? $37 : $36;
 $$in3$i430 = (($a$pn6$i429) + 12|0);
 $567 = HEAP32[$$in3$i430>>2]|0;
 $568 = $564 | $551;
 $569 = $565 | $552;
 $570 = $566 | $553;
 $571 = $567 | $554;
 $572 = (($collDataV4) + 176|0);
 $573 = Math_fround(HEAPF32[$572>>2]);
 $574 = (($collDataV4) + 180|0);
 $575 = Math_fround(HEAPF32[$574>>2]);
 $576 = (($collDataV4) + 184|0);
 $577 = Math_fround(HEAPF32[$576>>2]);
 $578 = (($collDataV4) + 188|0);
 $579 = Math_fround(HEAPF32[$578>>2]);
 $580 = $$lcssa3062 >= $$lcssa3058;
 $581 = $$lcssa3061 >= $$lcssa3057;
 $582 = $$lcssa3060 >= $$lcssa3056;
 $583 = $$lcssa3059 >= $$lcssa;
 $notlhs3018 = $$lcssa3058 >= Math_fround(0.0);
 $notrhs3019 = $573 > $$lcssa3058;
 $not$3017 = $notrhs3019 & $notlhs3018;
 $584 = $580 & $not$3017;
 $notlhs3021 = $$lcssa3057 >= Math_fround(0.0);
 $notrhs3022 = $575 > $$lcssa3057;
 $not$3020 = $notrhs3022 & $notlhs3021;
 $$2982 = $581 & $not$3020;
 $notlhs3024 = $$lcssa3056 >= Math_fround(0.0);
 $notrhs3025 = $577 > $$lcssa3056;
 $not$3023 = $notrhs3025 & $notlhs3024;
 $585 = $582 & $not$3023;
 $notlhs3027 = $$lcssa >= Math_fround(0.0);
 $notrhs3028 = $579 > $$lcssa;
 $not$3026 = $notrhs3028 & $notlhs3027;
 $$2983 = $583 & $not$3026;
 HEAP32[$39>>2] = 8;
 $586 = (($39) + 4|0);
 HEAP32[$586>>2] = 8;
 $587 = (($39) + 8|0);
 HEAP32[$587>>2] = 8;
 $588 = (($39) + 12|0);
 HEAP32[$588>>2] = 8;
 HEAP32[$38>>2] = $568;
 $589 = (($38) + 4|0);
 HEAP32[$589>>2] = $569;
 $590 = (($38) + 8|0);
 HEAP32[$590>>2] = $570;
 $591 = (($38) + 12|0);
 HEAP32[$591>>2] = $571;
 $b$a$i384 = $584 ? $39 : $38;
 $592 = HEAP32[$b$a$i384>>2]|0;
 $a$pn4$i386 = $$2982 ? $39 : $38;
 $$in1$i387 = (($a$pn4$i386) + 4|0);
 $593 = HEAP32[$$in1$i387>>2]|0;
 $b$a7$i388 = $585 ? $39 : $38;
 $$in2$i389 = (($b$a7$i388) + 8|0);
 $594 = HEAP32[$$in2$i389>>2]|0;
 $a$pn6$i390 = $$2983 ? $39 : $38;
 $$in3$i391 = (($a$pn6$i390) + 12|0);
 $595 = HEAP32[$$in3$i391>>2]|0;
 HEAPF32[$41>>2] = $$lcssa3102;
 $596 = (($41) + 4|0);
 HEAPF32[$596>>2] = $$lcssa3101;
 $597 = (($41) + 8|0);
 HEAPF32[$597>>2] = $$lcssa3100;
 $598 = (($41) + 12|0);
 HEAPF32[$598>>2] = $$lcssa3099;
 HEAPF32[$40>>2] = $$lcssa3086;
 $599 = (($40) + 4|0);
 HEAPF32[$599>>2] = $$lcssa3085;
 $600 = (($40) + 8|0);
 HEAPF32[$600>>2] = $$lcssa3084;
 $601 = (($40) + 12|0);
 HEAPF32[$601>>2] = $$lcssa3083;
 $b$a$i368 = $584 ? $41 : $40;
 $602 = Math_fround(HEAPF32[$b$a$i368>>2]);
 $$in1$i371 = (($b$a$i368) + 4|0);
 $603 = Math_fround(HEAPF32[$$in1$i371>>2]);
 $$in2$i373 = (($b$a$i368) + 8|0);
 $604 = Math_fround(HEAPF32[$$in2$i373>>2]);
 $$in3$i375 = (($b$a$i368) + 12|0);
 $605 = Math_fround(HEAPF32[$$in3$i375>>2]);
 HEAPF32[$43>>2] = $$lcssa3098;
 $606 = (($43) + 4|0);
 HEAPF32[$606>>2] = $$lcssa3097;
 $607 = (($43) + 8|0);
 HEAPF32[$607>>2] = $$lcssa3096;
 $608 = (($43) + 12|0);
 HEAPF32[$608>>2] = $$lcssa3095;
 HEAPF32[$42>>2] = $$lcssa3082;
 $609 = (($42) + 4|0);
 HEAPF32[$609>>2] = $$lcssa3081;
 $610 = (($42) + 8|0);
 HEAPF32[$610>>2] = $$lcssa3080;
 $611 = (($42) + 12|0);
 HEAPF32[$611>>2] = $$lcssa3079;
 $b$a$i352 = $$2982 ? $43 : $42;
 $612 = Math_fround(HEAPF32[$b$a$i352>>2]);
 $$in1$i355 = (($b$a$i352) + 4|0);
 $613 = Math_fround(HEAPF32[$$in1$i355>>2]);
 $$in2$i357 = (($b$a$i352) + 8|0);
 $614 = Math_fround(HEAPF32[$$in2$i357>>2]);
 $$in3$i359 = (($b$a$i352) + 12|0);
 $615 = Math_fround(HEAPF32[$$in3$i359>>2]);
 HEAPF32[$45>>2] = $$lcssa3094;
 $616 = (($45) + 4|0);
 HEAPF32[$616>>2] = $$lcssa3093;
 $617 = (($45) + 8|0);
 HEAPF32[$617>>2] = $$lcssa3092;
 $618 = (($45) + 12|0);
 HEAPF32[$618>>2] = $$lcssa3091;
 HEAPF32[$44>>2] = $$lcssa3078;
 $619 = (($44) + 4|0);
 HEAPF32[$619>>2] = $$lcssa3077;
 $620 = (($44) + 8|0);
 HEAPF32[$620>>2] = $$lcssa3076;
 $621 = (($44) + 12|0);
 HEAPF32[$621>>2] = $$lcssa3075;
 $b$a$i336 = $585 ? $45 : $44;
 $622 = Math_fround(HEAPF32[$b$a$i336>>2]);
 $$in1$i339 = (($b$a$i336) + 4|0);
 $623 = Math_fround(HEAPF32[$$in1$i339>>2]);
 $$in2$i341 = (($b$a$i336) + 8|0);
 $624 = Math_fround(HEAPF32[$$in2$i341>>2]);
 $$in3$i343 = (($b$a$i336) + 12|0);
 $625 = Math_fround(HEAPF32[$$in3$i343>>2]);
 HEAPF32[$47>>2] = $$lcssa3090;
 $626 = (($47) + 4|0);
 HEAPF32[$626>>2] = $$lcssa3089;
 $627 = (($47) + 8|0);
 HEAPF32[$627>>2] = $$lcssa3088;
 $628 = (($47) + 12|0);
 HEAPF32[$628>>2] = $$lcssa3087;
 HEAPF32[$46>>2] = $$lcssa3074;
 $629 = (($46) + 4|0);
 HEAPF32[$629>>2] = $$lcssa3073;
 $630 = (($46) + 8|0);
 HEAPF32[$630>>2] = $$lcssa3072;
 $631 = (($46) + 12|0);
 HEAPF32[$631>>2] = $$lcssa3071;
 $b$a$i320 = $$2983 ? $47 : $46;
 $632 = Math_fround(HEAPF32[$b$a$i320>>2]);
 $$in1$i323 = (($b$a$i320) + 4|0);
 $633 = Math_fround(HEAPF32[$$in1$i323>>2]);
 $$in2$i325 = (($b$a$i320) + 8|0);
 $634 = Math_fround(HEAPF32[$$in2$i325>>2]);
 $$in3$i327 = (($b$a$i320) + 12|0);
 $635 = Math_fround(HEAPF32[$$in3$i327>>2]);
 HEAPF32[$49>>2] = $$lcssa3058;
 $636 = (($49) + 4|0);
 HEAPF32[$636>>2] = $$lcssa3057;
 $637 = (($49) + 8|0);
 HEAPF32[$637>>2] = $$lcssa3056;
 $638 = (($49) + 12|0);
 HEAPF32[$638>>2] = $$lcssa;
 HEAPF32[$48>>2] = $573;
 $639 = (($48) + 4|0);
 HEAPF32[$639>>2] = $575;
 $640 = (($48) + 8|0);
 HEAPF32[$640>>2] = $577;
 $641 = (($48) + 12|0);
 HEAPF32[$641>>2] = $579;
 $b$a$i306 = $584 ? $49 : $48;
 $642 = Math_fround(HEAPF32[$b$a$i306>>2]);
 $a$pn4$i308 = $$2982 ? $49 : $48;
 $$in1$i309 = (($a$pn4$i308) + 4|0);
 $643 = Math_fround(HEAPF32[$$in1$i309>>2]);
 $b$a7$i310 = $585 ? $49 : $48;
 $$in2$i311 = (($b$a7$i310) + 8|0);
 $644 = Math_fround(HEAPF32[$$in2$i311>>2]);
 $a$pn6$i312 = $$2983 ? $49 : $48;
 $$in3$i313 = (($a$pn6$i312) + 12|0);
 $645 = Math_fround(HEAPF32[$$in3$i313>>2]);
 HEAPF32[$51>>2] = $525;
 $646 = (($51) + 4|0);
 HEAPF32[$646>>2] = $527;
 $647 = (($51) + 8|0);
 HEAPF32[$647>>2] = $529;
 $648 = (($51) + 12|0);
 HEAPF32[$648>>2] = $531;
 HEAPF32[$50>>2] = $$lcssa3066;
 $649 = (($50) + 4|0);
 HEAPF32[$649>>2] = $$lcssa3065;
 $650 = (($50) + 8|0);
 HEAPF32[$650>>2] = $$lcssa3064;
 $651 = (($50) + 12|0);
 HEAPF32[$651>>2] = $$lcssa3063;
 $b$a$i292 = $584 ? $51 : $50;
 $652 = Math_fround(HEAPF32[$b$a$i292>>2]);
 $a$pn4$i294 = $$2982 ? $51 : $50;
 $$in1$i295 = (($a$pn4$i294) + 4|0);
 $653 = Math_fround(HEAPF32[$$in1$i295>>2]);
 $b$a7$i296 = $585 ? $51 : $50;
 $$in2$i297 = (($b$a7$i296) + 8|0);
 $654 = Math_fround(HEAPF32[$$in2$i297>>2]);
 $a$pn6$i298 = $$2983 ? $51 : $50;
 $$in3$i299 = (($a$pn6$i298) + 12|0);
 $655 = Math_fround(HEAPF32[$$in3$i299>>2]);
 HEAPF32[$53>>2] = $91;
 $656 = (($53) + 4|0);
 HEAPF32[$656>>2] = $93;
 $657 = (($53) + 8|0);
 HEAPF32[$657>>2] = $95;
 $658 = (($53) + 12|0);
 HEAPF32[$658>>2] = $97;
 HEAPF32[$52>>2] = $83;
 $659 = (($52) + 4|0);
 HEAPF32[$659>>2] = $85;
 $660 = (($52) + 8|0);
 HEAPF32[$660>>2] = $87;
 $661 = (($52) + 12|0);
 HEAPF32[$661>>2] = $89;
 $b$a$i276 = $584 ? $53 : $52;
 $662 = Math_fround(HEAPF32[$b$a$i276>>2]);
 $$in1$i279 = (($b$a$i276) + 4|0);
 $663 = Math_fround(HEAPF32[$$in1$i279>>2]);
 $$in2$i281 = (($b$a$i276) + 8|0);
 $664 = Math_fround(HEAPF32[$$in2$i281>>2]);
 $$in3$i283 = (($b$a$i276) + 12|0);
 $665 = Math_fround(HEAPF32[$$in3$i283>>2]);
 HEAPF32[$55>>2] = $107;
 $666 = (($55) + 4|0);
 HEAPF32[$666>>2] = $109;
 $667 = (($55) + 8|0);
 HEAPF32[$667>>2] = $111;
 $668 = (($55) + 12|0);
 HEAPF32[$668>>2] = $113;
 HEAPF32[$54>>2] = $99;
 $669 = (($54) + 4|0);
 HEAPF32[$669>>2] = $101;
 $670 = (($54) + 8|0);
 HEAPF32[$670>>2] = $103;
 $671 = (($54) + 12|0);
 HEAPF32[$671>>2] = $105;
 $b$a$i260 = $$2982 ? $55 : $54;
 $672 = Math_fround(HEAPF32[$b$a$i260>>2]);
 $$in1$i263 = (($b$a$i260) + 4|0);
 $673 = Math_fround(HEAPF32[$$in1$i263>>2]);
 $$in2$i265 = (($b$a$i260) + 8|0);
 $674 = Math_fround(HEAPF32[$$in2$i265>>2]);
 $$in3$i267 = (($b$a$i260) + 12|0);
 $675 = Math_fround(HEAPF32[$$in3$i267>>2]);
 HEAPF32[$57>>2] = $123;
 $676 = (($57) + 4|0);
 HEAPF32[$676>>2] = $125;
 $677 = (($57) + 8|0);
 HEAPF32[$677>>2] = $127;
 $678 = (($57) + 12|0);
 HEAPF32[$678>>2] = $129;
 HEAPF32[$56>>2] = $115;
 $679 = (($56) + 4|0);
 HEAPF32[$679>>2] = $117;
 $680 = (($56) + 8|0);
 HEAPF32[$680>>2] = $119;
 $681 = (($56) + 12|0);
 HEAPF32[$681>>2] = $121;
 $b$a$i244 = $585 ? $57 : $56;
 $682 = Math_fround(HEAPF32[$b$a$i244>>2]);
 $$in1$i247 = (($b$a$i244) + 4|0);
 $683 = Math_fround(HEAPF32[$$in1$i247>>2]);
 $$in2$i249 = (($b$a$i244) + 8|0);
 $684 = Math_fround(HEAPF32[$$in2$i249>>2]);
 $$in3$i251 = (($b$a$i244) + 12|0);
 $685 = Math_fround(HEAPF32[$$in3$i251>>2]);
 HEAPF32[$59>>2] = $139;
 $686 = (($59) + 4|0);
 HEAPF32[$686>>2] = $141;
 $687 = (($59) + 8|0);
 HEAPF32[$687>>2] = $143;
 $688 = (($59) + 12|0);
 HEAPF32[$688>>2] = $145;
 HEAPF32[$58>>2] = $131;
 $689 = (($58) + 4|0);
 HEAPF32[$689>>2] = $133;
 $690 = (($58) + 8|0);
 HEAPF32[$690>>2] = $135;
 $691 = (($58) + 12|0);
 HEAPF32[$691>>2] = $137;
 $b$a$i228 = $$2983 ? $59 : $58;
 $692 = Math_fround(HEAPF32[$b$a$i228>>2]);
 $$in1$i231 = (($b$a$i228) + 4|0);
 $693 = Math_fround(HEAPF32[$$in1$i231>>2]);
 $$in2$i233 = (($b$a$i228) + 8|0);
 $694 = Math_fround(HEAPF32[$$in2$i233>>2]);
 $$in3$i235 = (($b$a$i228) + 12|0);
 $695 = Math_fround(HEAPF32[$$in3$i235>>2]);
 $696 = $$lcssa3070 <= Math_fround(0.0);
 $697 = $$lcssa3069 <= Math_fround(0.0);
 $698 = $$lcssa3068 <= Math_fround(0.0);
 $699 = $$lcssa3067 <= Math_fround(0.0);
 HEAP32[$61>>2] = 8;
 $700 = (($61) + 4|0);
 HEAP32[$700>>2] = 8;
 $701 = (($61) + 8|0);
 HEAP32[$701>>2] = 8;
 $702 = (($61) + 12|0);
 HEAP32[$702>>2] = 8;
 HEAP32[$60>>2] = $592;
 $703 = (($60) + 4|0);
 HEAP32[$703>>2] = $593;
 $704 = (($60) + 8|0);
 HEAP32[$704>>2] = $594;
 $705 = (($60) + 12|0);
 HEAP32[$705>>2] = $595;
 $b$a$i210 = $696 ? $61 : $60;
 $706 = HEAP32[$b$a$i210>>2]|0;
 $a$pn4$i212 = $697 ? $61 : $60;
 $$in1$i213 = (($a$pn4$i212) + 4|0);
 $707 = HEAP32[$$in1$i213>>2]|0;
 $b$a7$i214 = $698 ? $61 : $60;
 $$in2$i215 = (($b$a7$i214) + 8|0);
 $708 = HEAP32[$$in2$i215>>2]|0;
 $a$pn6$i216 = $699 ? $61 : $60;
 $$in3$i217 = (($a$pn6$i216) + 12|0);
 $709 = HEAP32[$$in3$i217>>2]|0;
 HEAPF32[$63>>2] = $$lcssa3118;
 $710 = (($63) + 4|0);
 HEAPF32[$710>>2] = $$lcssa3117;
 $711 = (($63) + 8|0);
 HEAPF32[$711>>2] = $$lcssa3116;
 $712 = (($63) + 12|0);
 HEAPF32[$712>>2] = $$lcssa3115;
 HEAPF32[$62>>2] = $602;
 $713 = (($62) + 4|0);
 HEAPF32[$713>>2] = $603;
 $714 = (($62) + 8|0);
 HEAPF32[$714>>2] = $604;
 $715 = (($62) + 12|0);
 HEAPF32[$715>>2] = $605;
 $b$a$i194 = $696 ? $63 : $62;
 $716 = Math_fround(HEAPF32[$b$a$i194>>2]);
 $$in1$i197 = (($b$a$i194) + 4|0);
 $717 = Math_fround(HEAPF32[$$in1$i197>>2]);
 $$in2$i199 = (($b$a$i194) + 8|0);
 $718 = Math_fround(HEAPF32[$$in2$i199>>2]);
 $$in3$i201 = (($b$a$i194) + 12|0);
 $719 = Math_fround(HEAPF32[$$in3$i201>>2]);
 HEAPF32[$65>>2] = $$lcssa3114;
 $720 = (($65) + 4|0);
 HEAPF32[$720>>2] = $$lcssa3113;
 $721 = (($65) + 8|0);
 HEAPF32[$721>>2] = $$lcssa3112;
 $722 = (($65) + 12|0);
 HEAPF32[$722>>2] = $$lcssa3111;
 HEAPF32[$64>>2] = $612;
 $723 = (($64) + 4|0);
 HEAPF32[$723>>2] = $613;
 $724 = (($64) + 8|0);
 HEAPF32[$724>>2] = $614;
 $725 = (($64) + 12|0);
 HEAPF32[$725>>2] = $615;
 $b$a$i178 = $697 ? $65 : $64;
 $726 = Math_fround(HEAPF32[$b$a$i178>>2]);
 $$in1$i181 = (($b$a$i178) + 4|0);
 $727 = Math_fround(HEAPF32[$$in1$i181>>2]);
 $$in2$i183 = (($b$a$i178) + 8|0);
 $728 = Math_fround(HEAPF32[$$in2$i183>>2]);
 $$in3$i185 = (($b$a$i178) + 12|0);
 $729 = Math_fround(HEAPF32[$$in3$i185>>2]);
 HEAPF32[$67>>2] = $$lcssa3110;
 $730 = (($67) + 4|0);
 HEAPF32[$730>>2] = $$lcssa3109;
 $731 = (($67) + 8|0);
 HEAPF32[$731>>2] = $$lcssa3108;
 $732 = (($67) + 12|0);
 HEAPF32[$732>>2] = $$lcssa3107;
 HEAPF32[$66>>2] = $622;
 $733 = (($66) + 4|0);
 HEAPF32[$733>>2] = $623;
 $734 = (($66) + 8|0);
 HEAPF32[$734>>2] = $624;
 $735 = (($66) + 12|0);
 HEAPF32[$735>>2] = $625;
 $b$a$i162 = $698 ? $67 : $66;
 $736 = Math_fround(HEAPF32[$b$a$i162>>2]);
 $$in1$i165 = (($b$a$i162) + 4|0);
 $737 = Math_fround(HEAPF32[$$in1$i165>>2]);
 $$in2$i167 = (($b$a$i162) + 8|0);
 $738 = Math_fround(HEAPF32[$$in2$i167>>2]);
 $$in3$i169 = (($b$a$i162) + 12|0);
 $739 = Math_fround(HEAPF32[$$in3$i169>>2]);
 HEAPF32[$69>>2] = $$lcssa3106;
 $740 = (($69) + 4|0);
 HEAPF32[$740>>2] = $$lcssa3105;
 $741 = (($69) + 8|0);
 HEAPF32[$741>>2] = $$lcssa3104;
 $742 = (($69) + 12|0);
 HEAPF32[$742>>2] = $$lcssa3103;
 HEAPF32[$68>>2] = $632;
 $743 = (($68) + 4|0);
 HEAPF32[$743>>2] = $633;
 $744 = (($68) + 8|0);
 HEAPF32[$744>>2] = $634;
 $745 = (($68) + 12|0);
 HEAPF32[$745>>2] = $635;
 $b$a$i146 = $699 ? $69 : $68;
 $746 = Math_fround(HEAPF32[$b$a$i146>>2]);
 $$in1$i149 = (($b$a$i146) + 4|0);
 $747 = Math_fround(HEAPF32[$$in1$i149>>2]);
 $$in2$i151 = (($b$a$i146) + 8|0);
 $748 = Math_fround(HEAPF32[$$in2$i151>>2]);
 $$in3$i153 = (($b$a$i146) + 12|0);
 $749 = Math_fround(HEAPF32[$$in3$i153>>2]);
 HEAPF32[$71>>2] = $91;
 $750 = (($71) + 4|0);
 HEAPF32[$750>>2] = $93;
 $751 = (($71) + 8|0);
 HEAPF32[$751>>2] = $95;
 $752 = (($71) + 12|0);
 HEAPF32[$752>>2] = $97;
 HEAPF32[$70>>2] = $662;
 $753 = (($70) + 4|0);
 HEAPF32[$753>>2] = $663;
 $754 = (($70) + 8|0);
 HEAPF32[$754>>2] = $664;
 $755 = (($70) + 12|0);
 HEAPF32[$755>>2] = $665;
 $b$a$i130 = $696 ? $71 : $70;
 $756 = Math_fround(HEAPF32[$b$a$i130>>2]);
 $$in1$i133 = (($b$a$i130) + 4|0);
 $757 = Math_fround(HEAPF32[$$in1$i133>>2]);
 $$in2$i135 = (($b$a$i130) + 8|0);
 $758 = Math_fround(HEAPF32[$$in2$i135>>2]);
 $$in3$i137 = (($b$a$i130) + 12|0);
 $759 = Math_fround(HEAPF32[$$in3$i137>>2]);
 HEAPF32[$73>>2] = $107;
 $760 = (($73) + 4|0);
 HEAPF32[$760>>2] = $109;
 $761 = (($73) + 8|0);
 HEAPF32[$761>>2] = $111;
 $762 = (($73) + 12|0);
 HEAPF32[$762>>2] = $113;
 HEAPF32[$72>>2] = $672;
 $763 = (($72) + 4|0);
 HEAPF32[$763>>2] = $673;
 $764 = (($72) + 8|0);
 HEAPF32[$764>>2] = $674;
 $765 = (($72) + 12|0);
 HEAPF32[$765>>2] = $675;
 $b$a$i114 = $697 ? $73 : $72;
 $766 = Math_fround(HEAPF32[$b$a$i114>>2]);
 $$in1$i117 = (($b$a$i114) + 4|0);
 $767 = Math_fround(HEAPF32[$$in1$i117>>2]);
 $$in2$i119 = (($b$a$i114) + 8|0);
 $768 = Math_fround(HEAPF32[$$in2$i119>>2]);
 $$in3$i121 = (($b$a$i114) + 12|0);
 $769 = Math_fround(HEAPF32[$$in3$i121>>2]);
 HEAPF32[$75>>2] = $123;
 $770 = (($75) + 4|0);
 HEAPF32[$770>>2] = $125;
 $771 = (($75) + 8|0);
 HEAPF32[$771>>2] = $127;
 $772 = (($75) + 12|0);
 HEAPF32[$772>>2] = $129;
 HEAPF32[$74>>2] = $682;
 $773 = (($74) + 4|0);
 HEAPF32[$773>>2] = $683;
 $774 = (($74) + 8|0);
 HEAPF32[$774>>2] = $684;
 $775 = (($74) + 12|0);
 HEAPF32[$775>>2] = $685;
 $b$a$i98 = $698 ? $75 : $74;
 $776 = Math_fround(HEAPF32[$b$a$i98>>2]);
 $$in1$i101 = (($b$a$i98) + 4|0);
 $777 = Math_fround(HEAPF32[$$in1$i101>>2]);
 $$in2$i103 = (($b$a$i98) + 8|0);
 $778 = Math_fround(HEAPF32[$$in2$i103>>2]);
 $$in3$i105 = (($b$a$i98) + 12|0);
 $779 = Math_fround(HEAPF32[$$in3$i105>>2]);
 HEAPF32[$77>>2] = $139;
 $780 = (($77) + 4|0);
 HEAPF32[$780>>2] = $141;
 $781 = (($77) + 8|0);
 HEAPF32[$781>>2] = $143;
 $782 = (($77) + 12|0);
 HEAPF32[$782>>2] = $145;
 HEAPF32[$76>>2] = $692;
 $783 = (($76) + 4|0);
 HEAPF32[$783>>2] = $693;
 $784 = (($76) + 8|0);
 HEAPF32[$784>>2] = $694;
 $785 = (($76) + 12|0);
 HEAPF32[$785>>2] = $695;
 $b$a$i82 = $699 ? $77 : $76;
 $786 = Math_fround(HEAPF32[$b$a$i82>>2]);
 $$in1$i85 = (($b$a$i82) + 4|0);
 $787 = Math_fround(HEAPF32[$$in1$i85>>2]);
 $$in2$i87 = (($b$a$i82) + 8|0);
 $788 = Math_fround(HEAPF32[$$in2$i87>>2]);
 $$in3$i89 = (($b$a$i82) + 12|0);
 $789 = Math_fround(HEAPF32[$$in3$i89>>2]);
 HEAPF32[$79>>2] = $$lcssa3070;
 $790 = (($79) + 4|0);
 HEAPF32[$790>>2] = $$lcssa3069;
 $791 = (($79) + 8|0);
 HEAPF32[$791>>2] = $$lcssa3068;
 $792 = (($79) + 12|0);
 HEAPF32[$792>>2] = $$lcssa3067;
 HEAPF32[$78>>2] = $652;
 $793 = (($78) + 4|0);
 HEAPF32[$793>>2] = $653;
 $794 = (($78) + 8|0);
 HEAPF32[$794>>2] = $654;
 $795 = (($78) + 12|0);
 HEAPF32[$795>>2] = $655;
 $b$a$i68 = $696 ? $79 : $78;
 $796 = Math_fround(HEAPF32[$b$a$i68>>2]);
 $a$pn4$i70 = $697 ? $79 : $78;
 $$in1$i71 = (($a$pn4$i70) + 4|0);
 $797 = Math_fround(HEAPF32[$$in1$i71>>2]);
 $b$a7$i72 = $698 ? $79 : $78;
 $$in2$i73 = (($b$a7$i72) + 8|0);
 $798 = Math_fround(HEAPF32[$$in2$i73>>2]);
 $a$pn6$i74 = $699 ? $79 : $78;
 $$in3$i75 = (($a$pn6$i74) + 12|0);
 $799 = Math_fround(HEAPF32[$$in3$i75>>2]);
 ;HEAP32[$81+0>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;HEAP32[$81+12>>2]=0|0;
 HEAPF32[$80>>2] = $642;
 $800 = (($80) + 4|0);
 HEAPF32[$800>>2] = $643;
 $801 = (($80) + 8|0);
 HEAPF32[$801>>2] = $644;
 $802 = (($80) + 12|0);
 HEAPF32[$802>>2] = $645;
 $b$a$i = $696 ? $81 : $80;
 $803 = Math_fround(HEAPF32[$b$a$i>>2]);
 $a$pn4$i = $697 ? $81 : $80;
 $$in1$i = (($a$pn4$i) + 4|0);
 $804 = Math_fround(HEAPF32[$$in1$i>>2]);
 $b$a7$i = $698 ? $81 : $80;
 $$in2$i = (($b$a7$i) + 8|0);
 $805 = Math_fround(HEAPF32[$$in2$i>>2]);
 $a$pn6$i = $699 ? $81 : $80;
 $$in3$i = (($a$pn6$i) + 12|0);
 $806 = Math_fround(HEAPF32[$$in3$i>>2]);
 $807 = Math_fround($525 - $796);
 $808 = Math_fround($527 - $797);
 $809 = Math_fround($529 - $798);
 $810 = Math_fround($531 - $799);
 $811 = Math_fround($716 * $807);
 $812 = Math_fround($717 * $807);
 $813 = Math_fround($718 * $807);
 $814 = Math_fround($719 * $807);
 $815 = Math_fround($756 + $811);
 $816 = Math_fround($757 + $812);
 $817 = Math_fround($758 + $813);
 $818 = Math_fround($759 + $814);
 $819 = Math_fround($726 * $808);
 $820 = Math_fround($727 * $808);
 $821 = Math_fround($728 * $808);
 $822 = Math_fround($729 * $808);
 $823 = Math_fround($766 + $819);
 $824 = Math_fround($767 + $820);
 $825 = Math_fround($768 + $821);
 $826 = Math_fround($769 + $822);
 $827 = Math_fround($736 * $809);
 $828 = Math_fround($737 * $809);
 $829 = Math_fround($738 * $809);
 $830 = Math_fround($739 * $809);
 $831 = Math_fround($776 + $827);
 $832 = Math_fround($777 + $828);
 $833 = Math_fround($778 + $829);
 $834 = Math_fround($779 + $830);
 $835 = Math_fround($746 * $810);
 $836 = Math_fround($747 * $810);
 $837 = Math_fround($748 * $810);
 $838 = Math_fround($749 * $810);
 $839 = Math_fround($786 + $835);
 $840 = Math_fround($787 + $836);
 $841 = Math_fround($788 + $837);
 $842 = Math_fround($789 + $838);
 $843 = (($collDataV4) + 256|0);
 HEAPF32[$843>>2] = $815;
 $844 = (($collDataV4) + 260|0);
 HEAPF32[$844>>2] = $816;
 $845 = (($collDataV4) + 264|0);
 HEAPF32[$845>>2] = $817;
 $846 = (($collDataV4) + 268|0);
 HEAPF32[$846>>2] = $818;
 $847 = (($collDataV4) + 272|0);
 HEAPF32[$847>>2] = $823;
 $848 = (($collDataV4) + 276|0);
 HEAPF32[$848>>2] = $824;
 $849 = (($collDataV4) + 280|0);
 HEAPF32[$849>>2] = $825;
 $850 = (($collDataV4) + 284|0);
 HEAPF32[$850>>2] = $826;
 $851 = (($collDataV4) + 288|0);
 HEAPF32[$851>>2] = $831;
 $852 = (($collDataV4) + 292|0);
 HEAPF32[$852>>2] = $832;
 $853 = (($collDataV4) + 296|0);
 HEAPF32[$853>>2] = $833;
 $854 = (($collDataV4) + 300|0);
 HEAPF32[$854>>2] = $834;
 $855 = (($collDataV4) + 304|0);
 HEAPF32[$855>>2] = $839;
 $856 = (($collDataV4) + 308|0);
 HEAPF32[$856>>2] = $840;
 $857 = (($collDataV4) + 312|0);
 HEAPF32[$857>>2] = $841;
 $858 = (($collDataV4) + 316|0);
 HEAPF32[$858>>2] = $842;
 $859 = (($collDataV4) + 192|0);
 HEAPF32[$859>>2] = $716;
 $860 = (($collDataV4) + 196|0);
 HEAPF32[$860>>2] = $717;
 $861 = (($collDataV4) + 200|0);
 HEAPF32[$861>>2] = $718;
 $862 = (($collDataV4) + 204|0);
 HEAPF32[$862>>2] = $719;
 $863 = (($collDataV4) + 208|0);
 HEAPF32[$863>>2] = $726;
 $864 = (($collDataV4) + 212|0);
 HEAPF32[$864>>2] = $727;
 $865 = (($collDataV4) + 216|0);
 HEAPF32[$865>>2] = $728;
 $866 = (($collDataV4) + 220|0);
 HEAPF32[$866>>2] = $729;
 $867 = (($collDataV4) + 224|0);
 HEAPF32[$867>>2] = $736;
 $868 = (($collDataV4) + 228|0);
 HEAPF32[$868>>2] = $737;
 $869 = (($collDataV4) + 232|0);
 HEAPF32[$869>>2] = $738;
 $870 = (($collDataV4) + 236|0);
 HEAPF32[$870>>2] = $739;
 $871 = (($collDataV4) + 240|0);
 HEAPF32[$871>>2] = $746;
 $872 = (($collDataV4) + 244|0);
 HEAPF32[$872>>2] = $747;
 $873 = (($collDataV4) + 248|0);
 HEAPF32[$873>>2] = $748;
 $874 = (($collDataV4) + 252|0);
 HEAPF32[$874>>2] = $749;
 HEAPF32[$572>>2] = $803;
 HEAPF32[$574>>2] = $804;
 HEAPF32[$576>>2] = $805;
 HEAPF32[$578>>2] = $806;
 HEAP32[$516>>2] = $706;
 HEAP32[$518>>2] = $707;
 HEAP32[$520>>2] = $708;
 HEAP32[$522>>2] = $709;
 STACKTOP = sp;return;
}
function __ZN5physx23collideWithConvexPlanesERNS_19PxsParticleCollDataEPKNS_7PxPlaneEjf($collData,$convexPlanes,$numPlanes,$proxRadius) {
 $collData = $collData|0;
 $convexPlanes = $convexPlanes|0;
 $numPlanes = $numPlanes|0;
 $proxRadius = Math_fround($proxRadius);
 var $$$demorgan = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0;
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = Math_fround(0);
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $k$021 = 0, $latestEntry$0$lcssa = Math_fround(0), $latestEntry$025 = Math_fround(0), $newPosClosestDist$0$lcssa = Math_fround(0), $newPosClosestDist$023 = Math_fround(0), $newPosOutMask$0$off0$lcssa = 0, $newPosOutMask$0$off026 = 0, $newPosPlaneIndex$0$lcssa = 0, $newPosPlaneIndex$029 = 0;
 var $oldPosClosestDist$0$lcssa = Math_fround(0), $oldPosClosestDist$022 = Math_fround(0), $oldPosPlaneIndex$0$lcssa = 0, $oldPosPlaneIndex$028 = 0, $or$cond = 0, $or$cond2 = 0, $rayPlaneIndex$0$lcssa = 0, $rayPlaneIndex$027 = 0, $soonestExit$0$lcssa = Math_fround(0), $soonestExit$024 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($collData) + 128|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($collData) + 112|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($collData) + 132|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($collData) + 116|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($collData) + 136|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($collData) + 120|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = ($numPlanes|0)==(0);
 if ($15) {
  $latestEntry$0$lcssa = Math_fround(-3.40282346638528859812E+38);$newPosClosestDist$0$lcssa = Math_fround(-3.40282346638528859812E+38);$newPosOutMask$0$off0$lcssa = 0;$newPosPlaneIndex$0$lcssa = 0;$oldPosClosestDist$0$lcssa = Math_fround(-3.40282346638528859812E+38);$oldPosPlaneIndex$0$lcssa = 0;$rayPlaneIndex$0$lcssa = 0;$soonestExit$0$lcssa = Math_fround(3.40282346638528859812E+38);
 } else {
  $k$021 = 0;$latestEntry$025 = Math_fround(-3.40282346638528859812E+38);$newPosClosestDist$023 = Math_fround(-3.40282346638528859812E+38);$newPosOutMask$0$off026 = 0;$newPosPlaneIndex$029 = 0;$oldPosClosestDist$022 = Math_fround(-3.40282346638528859812E+38);$oldPosPlaneIndex$028 = 0;$rayPlaneIndex$027 = 0;$soonestExit$024 = Math_fround(3.40282346638528859812E+38);
  while(1) {
   $16 = (($convexPlanes) + ($k$021<<4)|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround($1 * $17);
   $19 = ((($convexPlanes) + ($k$021<<4)|0) + 4|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround($6 * $20);
   $22 = Math_fround($18 + $21);
   $23 = ((($convexPlanes) + ($k$021<<4)|0) + 8|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($11 * $24);
   $26 = Math_fround($22 + $25);
   $27 = ((($convexPlanes) + ($k$021<<4)|0) + 12|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = Math_fround($28 + $26);
   $30 = Math_fround($17 * $3);
   $31 = Math_fround($20 * $8);
   $32 = Math_fround($30 + $31);
   $33 = Math_fround($24 * $13);
   $34 = Math_fround($32 + $33);
   $35 = Math_fround($28 + $34);
   $36 = $newPosClosestDist$023 > Math_fround(0.0);
   $37 = $35 > $oldPosClosestDist$022;
   $38 = $37 ? $35 : $oldPosClosestDist$022;
   $39 = $37 ? $k$021 : $oldPosPlaneIndex$028;
   $40 = $29 > $newPosClosestDist$023;
   $41 = $40 ? $29 : $newPosClosestDist$023;
   $42 = $40 ? $k$021 : $newPosPlaneIndex$029;
   $43 = $29 > Math_fround(0.0);
   $44 = $36 & $43;
   $45 = $newPosOutMask$0$off026 | $44;
   $46 = Math_fround($4 * $17);
   $47 = Math_fround($9 * $20);
   $48 = Math_fround($46 + $47);
   $49 = Math_fround($14 * $24);
   $50 = Math_fround($48 + $49);
   $51 = Math_fround(-$35);
   $52 = Math_fround($51 / $50);
   $53 = $50 < Math_fround(0.0);
   $54 = $52 > $latestEntry$025;
   $55 = $53 & $54;
   $56 = $50 > Math_fround(0.0);
   $57 = $52 < $soonestExit$024;
   $58 = $56 & $57;
   $59 = $55 ? $52 : $latestEntry$025;
   $60 = $55 ? $k$021 : $rayPlaneIndex$027;
   $61 = $58 ? $52 : $soonestExit$024;
   $62 = $50 == Math_fround(0.0);
   $63 = $62 & $43;
   $64 = $63 ? Math_fround(3.40282346638528859812E+38) : $59;
   $65 = (($k$021) + 1)|0;
   $exitcond = ($65|0)==($numPlanes|0);
   if ($exitcond) {
    $latestEntry$0$lcssa = $64;$newPosClosestDist$0$lcssa = $41;$newPosOutMask$0$off0$lcssa = $45;$newPosPlaneIndex$0$lcssa = $42;$oldPosClosestDist$0$lcssa = $38;$oldPosPlaneIndex$0$lcssa = $39;$rayPlaneIndex$0$lcssa = $60;$soonestExit$0$lcssa = $61;
    break;
   } else {
    $k$021 = $65;$latestEntry$025 = $64;$newPosClosestDist$023 = $41;$newPosOutMask$0$off026 = $45;$newPosPlaneIndex$029 = $42;$oldPosClosestDist$022 = $38;$oldPosPlaneIndex$028 = $39;$rayPlaneIndex$027 = $60;$soonestExit$024 = $61;
   }
  }
 }
 $66 = !($oldPosClosestDist$0$lcssa <= Math_fround(0.0));
 $67 = (($collData) + 92|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = !($newPosClosestDist$0$lcssa <= $68);
 $70 = !($newPosClosestDist$0$lcssa > Math_fround(0.0));
 $71 = !($newPosClosestDist$0$lcssa <= $proxRadius);
 $or$cond = $70 | $71;
 $$$demorgan = $or$cond | $newPosOutMask$0$off0$lcssa;
 if (!($66)) {
  $72 = (($collData) + 124|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = $73 | 8;
  HEAP32[$72>>2] = $74;
  $75 = (($collData) + 44|0);
  HEAPF32[$75>>2] = Math_fround(0.0);
  $76 = (($convexPlanes) + ($oldPosPlaneIndex$0$lcssa<<4)|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = (($collData) + 144|0);
  HEAPF32[$78>>2] = $77;
  $79 = ((($convexPlanes) + ($oldPosPlaneIndex$0$lcssa<<4)|0) + 4|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (($collData) + 148|0);
  HEAPF32[$81>>2] = $80;
  $82 = ((($convexPlanes) + ($oldPosPlaneIndex$0$lcssa<<4)|0) + 8|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($collData) + 152|0);
  HEAPF32[$84>>2] = $83;
  $85 = Math_fround($68 - $oldPosClosestDist$0$lcssa);
  $86 = Math_fround(HEAPF32[$76>>2]);
  $87 = Math_fround($86 * $85);
  $88 = Math_fround(HEAPF32[$79>>2]);
  $89 = Math_fround($85 * $88);
  $90 = Math_fround(HEAPF32[$82>>2]);
  $91 = Math_fround($85 * $90);
  $92 = Math_fround($87 + $3);
  $93 = Math_fround($89 + $8);
  $94 = Math_fround($91 + $13);
  $95 = (($collData) + 160|0);
  HEAPF32[$95>>2] = $92;
  $96 = (($collData) + 164|0);
  HEAPF32[$96>>2] = $93;
  $97 = (($collData) + 168|0);
  HEAPF32[$97>>2] = $94;
  STACKTOP = sp;return;
 }
 $98 = !($latestEntry$0$lcssa >= Math_fround(0.0));
 if (!($98)) {
  $99 = (($collData) + 44|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = $latestEntry$0$lcssa < $100;
  $102 = $latestEntry$0$lcssa <= $soonestExit$0$lcssa;
  $or$cond2 = $101 & $102;
  if ($or$cond2) {
   $103 = (($convexPlanes) + ($rayPlaneIndex$0$lcssa<<4)|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = (($collData) + 144|0);
   HEAPF32[$105>>2] = $104;
   $106 = ((($convexPlanes) + ($rayPlaneIndex$0$lcssa<<4)|0) + 4|0);
   $107 = Math_fround(HEAPF32[$106>>2]);
   $108 = (($collData) + 148|0);
   HEAPF32[$108>>2] = $107;
   $109 = ((($convexPlanes) + ($rayPlaneIndex$0$lcssa<<4)|0) + 8|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = (($collData) + 152|0);
   HEAPF32[$111>>2] = $110;
   $112 = (($collData) + 160|0);
   HEAPF32[$112>>2] = $3;
   $113 = (($collData) + 164|0);
   HEAPF32[$113>>2] = $8;
   $114 = (($collData) + 168|0);
   HEAPF32[$114>>2] = $13;
   HEAPF32[$99>>2] = $latestEntry$0$lcssa;
   $115 = (($collData) + 124|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = $116 | 8;
   HEAP32[$115>>2] = $117;
   STACKTOP = sp;return;
  }
 }
 $118 = (($collData) + 124|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = $119 & 2;
 $121 = ($120|0)==(0);
 if (!($121)) {
  STACKTOP = sp;return;
 }
 if ($$$demorgan) {
  $168 = $119;
 } else {
  $122 = (($convexPlanes) + ($newPosPlaneIndex$0$lcssa<<4)|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = (($collData) + 144|0);
  HEAPF32[$124>>2] = $123;
  $125 = ((($convexPlanes) + ($newPosPlaneIndex$0$lcssa<<4)|0) + 4|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = (($collData) + 148|0);
  HEAPF32[$127>>2] = $126;
  $128 = ((($convexPlanes) + ($newPosPlaneIndex$0$lcssa<<4)|0) + 8|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = (($collData) + 152|0);
  HEAPF32[$130>>2] = $129;
  $131 = Math_fround($68 - $newPosClosestDist$0$lcssa);
  $132 = Math_fround(HEAPF32[$122>>2]);
  $133 = Math_fround($132 * $131);
  $134 = Math_fround(HEAPF32[$125>>2]);
  $135 = Math_fround($131 * $134);
  $136 = Math_fround(HEAPF32[$128>>2]);
  $137 = Math_fround($131 * $136);
  $138 = Math_fround($133 + $1);
  $139 = Math_fround($135 + $6);
  $140 = Math_fround($137 + $11);
  $141 = (($collData) + 160|0);
  HEAPF32[$141>>2] = $138;
  $142 = (($collData) + 164|0);
  HEAPF32[$142>>2] = $139;
  $143 = (($collData) + 168|0);
  HEAPF32[$143>>2] = $140;
  $144 = $119 | 32;
  HEAP32[$118>>2] = $144;
  $168 = $144;
 }
 if ($69) {
  STACKTOP = sp;return;
 }
 $145 = (($convexPlanes) + ($newPosPlaneIndex$0$lcssa<<4)|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($collData) + 144|0);
 HEAPF32[$147>>2] = $146;
 $148 = ((($convexPlanes) + ($newPosPlaneIndex$0$lcssa<<4)|0) + 4|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($collData) + 148|0);
 HEAPF32[$150>>2] = $149;
 $151 = ((($convexPlanes) + ($newPosPlaneIndex$0$lcssa<<4)|0) + 8|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($collData) + 152|0);
 HEAPF32[$153>>2] = $152;
 $154 = Math_fround($68 - $newPosClosestDist$0$lcssa);
 $155 = Math_fround(HEAPF32[$145>>2]);
 $156 = Math_fround($155 * $154);
 $157 = Math_fround(HEAPF32[$148>>2]);
 $158 = Math_fround($154 * $157);
 $159 = Math_fround(HEAPF32[$151>>2]);
 $160 = Math_fround($154 * $159);
 $161 = Math_fround($156 + $1);
 $162 = Math_fround($158 + $6);
 $163 = Math_fround($160 + $11);
 $164 = (($collData) + 160|0);
 HEAPF32[$164>>2] = $161;
 $165 = (($collData) + 164|0);
 HEAPF32[$165>>2] = $162;
 $166 = (($collData) + 168|0);
 HEAPF32[$166>>2] = $163;
 $167 = $168 | 16;
 HEAP32[$118>>2] = $167;
 STACKTOP = sp;return;
}
function __ZN5physx17collideWithConvexEPNS_7PxPlaneEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($scaledPlaneBuf,$particleCollData,$numCollData,$convexShape,$proxRadius) {
 $scaledPlaneBuf = $scaledPlaneBuf|0;
 $particleCollData = $particleCollData|0;
 $numCollData = $numCollData|0;
 $convexShape = $convexShape|0;
 $proxRadius = Math_fround($proxRadius);
 var $$ = 0, $$$$$$567 = 0, $$$$$$568 = 0, $$$$$567 = 0, $$$$$568 = 0, $$$$567 = 0, $$$$568 = 0, $$$567 = 0, $$$568 = 0, $$$i = Math_fround(0), $$$i105 = Math_fround(0), $$$i69 = Math_fround(0), $$$i75 = Math_fround(0), $$$i81 = Math_fround(0), $$$i87 = Math_fround(0), $$$i93 = Math_fround(0), $$$i99 = Math_fround(0), $$1$i = Math_fround(0), $$1$i100 = Math_fround(0), $$1$i106 = Math_fround(0);
 var $$1$i70 = Math_fround(0), $$1$i76 = Math_fround(0), $$1$i82 = Math_fround(0), $$1$i88 = Math_fround(0), $$1$i94 = Math_fround(0), $$567 = 0, $$568 = 0, $$fakeCsd = 0, $$in1$i = 0, $$in2$i = 0, $$in3$i = 0, $$op = 0, $$particleCollDataIt$2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0);
 var $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0;
 var $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0;
 var $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = 0;
 var $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0;
 var $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0);
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0);
 var $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0;
 var $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = 0;
 var $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = Math_fround(0);
 var $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = 0, $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $a$pn4$i = 0, $a$pn6$i = 0, $b$a$i = 0, $b$a7$i = 0, $collDataV4 = 0, $exitcond = 0, $exitcond606 = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0), $fakeCsd = 0;
 var $i$0591 = 0, $j$0594 = 0, $k$0598 = 0, $not$ = 0, $not$569 = 0, $not$570 = 0, $not$571 = 0, $not$572 = 0, $not$573 = 0, $not$574 = 0, $not$575 = 0, $not$576 = 0, $not$577 = 0, $not$578 = 0, $not$579 = 0, $not$580 = 0, $not$581 = 0, $not$582 = 0, $not$583 = 0, $not$584 = 0;
 var $not$585 = 0, $not$586 = 0, $not$587 = 0, $numPlanes$06$i = 0, $overlapArray = 0, $particleCollDataIt$0592 = 0, $particleCollDataIt$2 = 0, $particleCollDataIt$2$fakeCsd = 0, $particleCollDataIt$4595 = 0, $planeIt$05$i = 0, $polygonIt$04$i = 0, $scaledPlanes$0$off0602 = 0, $scaledPlanes$1$off0$lcssa = 0, $scaledPlanes$1$off0599 = 0, $scaledPlanes$3$off0 = 0, $scaling = 0, $start$0601 = 0, $v4Count$0597 = 0, $v4Count$1 = 0, $v4Count$2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1120|0;
 $0 = sp + 1024|0;
 $1 = sp;
 $scaling = sp + 1076|0;
 $2 = sp + 1040|0;
 $collDataV4 = sp + 704|0;
 $fakeCsd = sp + 528|0;
 $overlapArray = sp + 16|0;
 $3 = (($convexShape) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($convexShape) + 4|0);
 $6 = (($convexShape) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($convexShape) + 20|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($convexShape) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($convexShape) + 28|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($7 + $7);
 $15 = Math_fround($9 + $9);
 $16 = Math_fround($11 + $11);
 $17 = Math_fround($7 * $14);
 $18 = Math_fround($9 * $15);
 $19 = Math_fround($11 * $16);
 $20 = Math_fround($14 * $9);
 $21 = Math_fround($14 * $11);
 $22 = Math_fround($14 * $13);
 $23 = Math_fround($15 * $11);
 $24 = Math_fround($15 * $13);
 $25 = Math_fround($16 * $13);
 $26 = Math_fround(Math_fround(1.0) - $18);
 $27 = Math_fround($26 - $19);
 $28 = Math_fround($20 + $25);
 $29 = Math_fround($21 - $24);
 $30 = Math_fround($20 - $25);
 $31 = Math_fround(Math_fround(1.0) - $17);
 $32 = Math_fround($31 - $19);
 $33 = Math_fround($23 + $22);
 $34 = Math_fround($21 + $24);
 $35 = Math_fround($23 - $22);
 $36 = Math_fround($31 - $18);
 $37 = Math_fround(HEAPF32[$5>>2]);
 $38 = Math_fround($37 * $27);
 $39 = Math_fround($37 * $30);
 $40 = Math_fround($37 * $34);
 $41 = (($convexShape) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($28 * $42);
 $44 = Math_fround($32 * $42);
 $45 = Math_fround($35 * $42);
 $46 = (($convexShape) + 12|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($29 * $47);
 $49 = Math_fround($33 * $47);
 $50 = Math_fround($36 * $47);
 $51 = Math_fround($27 * $38);
 $52 = Math_fround($27 * $39);
 $53 = Math_fround($27 * $40);
 $54 = Math_fround($28 * $43);
 $55 = Math_fround($28 * $44);
 $56 = Math_fround($28 * $45);
 $57 = Math_fround($51 + $54);
 $58 = Math_fround($52 + $55);
 $59 = Math_fround($53 + $56);
 $60 = Math_fround($29 * $48);
 $61 = Math_fround($29 * $49);
 $62 = Math_fround($29 * $50);
 $63 = Math_fround($57 + $60);
 $64 = Math_fround($58 + $61);
 $65 = Math_fround($59 + $62);
 $66 = Math_fround($30 * $38);
 $67 = Math_fround($30 * $39);
 $68 = Math_fround($30 * $40);
 $69 = Math_fround($32 * $43);
 $70 = Math_fround($32 * $44);
 $71 = Math_fround($32 * $45);
 $72 = Math_fround($66 + $69);
 $73 = Math_fround($67 + $70);
 $74 = Math_fround($68 + $71);
 $75 = Math_fround($33 * $48);
 $76 = Math_fround($33 * $49);
 $77 = Math_fround($33 * $50);
 $78 = Math_fround($72 + $75);
 $79 = Math_fround($73 + $76);
 $80 = Math_fround($74 + $77);
 $81 = Math_fround($34 * $38);
 $82 = Math_fround($34 * $39);
 $83 = Math_fround($34 * $40);
 $84 = Math_fround($35 * $43);
 $85 = Math_fround($35 * $44);
 $86 = Math_fround($35 * $45);
 $87 = Math_fround($81 + $84);
 $88 = Math_fround($82 + $85);
 $89 = Math_fround($83 + $86);
 $90 = Math_fround($36 * $48);
 $91 = Math_fround($36 * $49);
 $92 = Math_fround($36 * $50);
 $93 = Math_fround($87 + $90);
 $94 = Math_fround($88 + $91);
 $95 = Math_fround($89 + $92);
 HEAPF32[$scaling>>2] = $63;
 $96 = (($scaling) + 4|0);
 HEAPF32[$96>>2] = $64;
 $97 = (($scaling) + 8|0);
 HEAPF32[$97>>2] = $65;
 $98 = (($scaling) + 12|0);
 HEAPF32[$98>>2] = $78;
 $99 = (($scaling) + 16|0);
 HEAPF32[$99>>2] = $79;
 $100 = (($scaling) + 20|0);
 HEAPF32[$100>>2] = $80;
 $101 = (($scaling) + 24|0);
 HEAPF32[$101>>2] = $93;
 $102 = (($scaling) + 28|0);
 HEAPF32[$102>>2] = $94;
 $103 = (($scaling) + 32|0);
 HEAPF32[$103>>2] = $95;
 __ZNK5physx7PxMat3310getInverseEv($2,$scaling);
 $104 = Math_fround(HEAPF32[$2>>2]);
 $105 = (($2) + 4|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($2) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($2) + 12|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($2) + 16|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($2) + 20|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($2) + 24|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (($2) + 28|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($2) + 32|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround(HEAPF32[$4>>2]);
 $122 = (($4) + 12|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($121 + $123);
 $125 = (($4) + 4|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($4) + 16|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($126 + $128);
 $130 = (($4) + 8|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($4) + 20|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($131 + $133);
 $135 = Math_fround($124 * Math_fround(0.5));
 $136 = Math_fround($129 * Math_fround(0.5));
 $137 = Math_fround($134 * Math_fround(0.5));
 $138 = Math_fround(HEAPF32[$scaling>>2]);
 $139 = Math_fround($135 * $138);
 $140 = Math_fround(HEAPF32[$96>>2]);
 $141 = Math_fround($135 * $140);
 $142 = Math_fround(HEAPF32[$97>>2]);
 $143 = Math_fround($135 * $142);
 $144 = Math_fround(HEAPF32[$98>>2]);
 $145 = Math_fround($136 * $144);
 $146 = Math_fround(HEAPF32[$99>>2]);
 $147 = Math_fround($136 * $146);
 $148 = Math_fround(HEAPF32[$100>>2]);
 $149 = Math_fround($136 * $148);
 $150 = Math_fround($139 + $145);
 $151 = Math_fround($141 + $147);
 $152 = Math_fround($143 + $149);
 $153 = Math_fround(HEAPF32[$101>>2]);
 $154 = Math_fround($137 * $153);
 $155 = Math_fround(HEAPF32[$102>>2]);
 $156 = Math_fround($137 * $155);
 $157 = Math_fround(HEAPF32[$103>>2]);
 $158 = Math_fround($137 * $157);
 $159 = Math_fround($150 + $154);
 $160 = Math_fround($151 + $156);
 $161 = Math_fround($152 + $158);
 $162 = Math_fround($123 - $121);
 $163 = Math_fround($128 - $126);
 $164 = Math_fround($133 - $131);
 $165 = Math_fround($162 * Math_fround(0.5));
 $166 = Math_fround($163 * Math_fround(0.5));
 $167 = Math_fround($164 * Math_fround(0.5));
 $168 = Math_fround($165 * $138);
 $169 = Math_fround($165 * $140);
 $170 = Math_fround($165 * $142);
 $171 = Math_fround($166 * $144);
 $172 = Math_fround($166 * $146);
 $173 = Math_fround($166 * $148);
 $174 = Math_fround($167 * $153);
 $175 = Math_fround($167 * $155);
 $176 = Math_fround($167 * $157);
 $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($168)))));
 $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($171)))));
 $177 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
 $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($174)))));
 $178 = Math_fround($177 + $fabsf$i$i6$i$i);
 $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($169)))));
 $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($172)))));
 $179 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
 $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($175)))));
 $180 = Math_fround($179 + $fabsf$i$i3$i$i);
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($170)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($173)))));
 $181 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($176)))));
 $182 = Math_fround($181 + $fabsf$i$i$i$i);
 $183 = Math_fround($159 - $178);
 $184 = Math_fround($160 - $180);
 $185 = Math_fround($161 - $182);
 $186 = Math_fround($159 + $178);
 $187 = Math_fround($160 + $180);
 $188 = Math_fround($161 + $182);
 $189 = Math_fround($183 - $proxRadius);
 $190 = Math_fround($184 - $proxRadius);
 $191 = Math_fround($185 - $proxRadius);
 $192 = Math_fround($186 + $proxRadius);
 $193 = Math_fround($187 + $proxRadius);
 $194 = Math_fround($188 + $proxRadius);
 $195 = (($fakeCsd) + 112|0);
 HEAPF32[$195>>2] = Math_fround(3.40282346638528859812E+38);
 $196 = (($fakeCsd) + 116|0);
 HEAPF32[$196>>2] = Math_fround(3.40282346638528859812E+38);
 $197 = (($fakeCsd) + 120|0);
 HEAPF32[$197>>2] = Math_fround(3.40282346638528859812E+38);
 $198 = (($fakeCsd) + 128|0);
 HEAPF32[$198>>2] = Math_fround(3.40282346638528859812E+38);
 $199 = (($fakeCsd) + 132|0);
 HEAPF32[$199>>2] = Math_fround(3.40282346638528859812E+38);
 $200 = (($fakeCsd) + 136|0);
 HEAPF32[$200>>2] = Math_fround(3.40282346638528859812E+38);
 $201 = ($numCollData|0)==(0);
 if ($201) {
  STACKTOP = sp;return;
 }
 $202 = (($4) + 39|0);
 $203 = (($4) + 40|0);
 $204 = (($1) + 4|0);
 $205 = (($1) + 8|0);
 $206 = (($1) + 12|0);
 $207 = $numCollData ^ -1;
 $scaledPlanes$0$off0602 = 0;$start$0601 = 0;
 while(1) {
  $208 = (($numCollData) - ($start$0601))|0;
  $209 = ($208>>>0)<(128);
  $210 = $209 ? $208 : 128;
  $211 = (($particleCollData) + (($start$0601*176)|0)|0);
  $212 = ($210|0)==(0);
  if ($212) {
   $scaledPlanes$1$off0$lcssa = $scaledPlanes$0$off0602;
  } else {
   $i$0591 = 0;$particleCollDataIt$0592 = $211;
   while(1) {
    $213 = (($particleCollDataIt$0592) + 176|0);
    $214 = $i$0591 | 1;
    $215 = ($214>>>0)<($numCollData>>>0);
    $216 = (($particleCollDataIt$0592) + 352|0);
    $$ = $215 ? $216 : $213;
    $$fakeCsd = $215 ? $213 : $fakeCsd;
    $217 = $i$0591 | 2;
    $218 = ($217>>>0)<($numCollData>>>0);
    $219 = (($$) + 176|0);
    $particleCollDataIt$2 = $218 ? $219 : $$;
    $220 = $218 ? $$ : $fakeCsd;
    $221 = $i$0591 | 3;
    $222 = ($221>>>0)<($numCollData>>>0);
    $223 = (($particleCollDataIt$2) + 176|0);
    $$particleCollDataIt$2 = $222 ? $223 : $particleCollDataIt$2;
    $particleCollDataIt$2$fakeCsd = $222 ? $particleCollDataIt$2 : $fakeCsd;
    $224 = (($particleCollDataIt$0592) + 112|0);
    $225 = Math_fround(HEAPF32[$224>>2]);
    $226 = (($224) + 4|0);
    $227 = Math_fround(HEAPF32[$226>>2]);
    $228 = (($224) + 8|0);
    $229 = Math_fround(HEAPF32[$228>>2]);
    $230 = (($particleCollDataIt$0592) + 128|0);
    $231 = Math_fround(HEAPF32[$230>>2]);
    $232 = (($230) + 4|0);
    $233 = Math_fround(HEAPF32[$232>>2]);
    $234 = (($230) + 8|0);
    $235 = Math_fround(HEAPF32[$234>>2]);
    $236 = (($$fakeCsd) + 112|0);
    $237 = Math_fround(HEAPF32[$236>>2]);
    $238 = (($236) + 4|0);
    $239 = Math_fround(HEAPF32[$238>>2]);
    $240 = (($236) + 8|0);
    $241 = Math_fround(HEAPF32[$240>>2]);
    $242 = (($$fakeCsd) + 128|0);
    $243 = Math_fround(HEAPF32[$242>>2]);
    $244 = (($242) + 4|0);
    $245 = Math_fround(HEAPF32[$244>>2]);
    $246 = (($242) + 8|0);
    $247 = Math_fround(HEAPF32[$246>>2]);
    $248 = (($220) + 112|0);
    $249 = Math_fround(HEAPF32[$248>>2]);
    $250 = (($248) + 4|0);
    $251 = Math_fround(HEAPF32[$250>>2]);
    $252 = (($248) + 8|0);
    $253 = Math_fround(HEAPF32[$252>>2]);
    $254 = (($220) + 128|0);
    $255 = Math_fround(HEAPF32[$254>>2]);
    $256 = (($254) + 4|0);
    $257 = Math_fround(HEAPF32[$256>>2]);
    $258 = (($254) + 8|0);
    $259 = Math_fround(HEAPF32[$258>>2]);
    $260 = (($particleCollDataIt$2$fakeCsd) + 112|0);
    $261 = Math_fround(HEAPF32[$260>>2]);
    $262 = (($260) + 4|0);
    $263 = Math_fround(HEAPF32[$262>>2]);
    $264 = (($260) + 8|0);
    $265 = Math_fround(HEAPF32[$264>>2]);
    $266 = (($particleCollDataIt$2$fakeCsd) + 128|0);
    $267 = Math_fround(HEAPF32[$266>>2]);
    $268 = (($266) + 4|0);
    $269 = Math_fround(HEAPF32[$268>>2]);
    $270 = (($266) + 8|0);
    $271 = Math_fround(HEAPF32[$270>>2]);
    $272 = $225 < $231;
    $$$i105 = $272 ? $225 : $231;
    $273 = $227 < $233;
    $274 = $273 ? $227 : $233;
    $275 = $229 < $235;
    $$1$i106 = $275 ? $229 : $235;
    $276 = $225 > $231;
    $$$i99 = $276 ? $225 : $231;
    $277 = $227 > $233;
    $278 = $277 ? $227 : $233;
    $279 = $229 > $235;
    $$1$i100 = $279 ? $229 : $235;
    $280 = $237 < $243;
    $$$i93 = $280 ? $237 : $243;
    $281 = $239 < $245;
    $282 = $281 ? $239 : $245;
    $283 = $241 < $247;
    $$1$i94 = $283 ? $241 : $247;
    $284 = $237 > $243;
    $$$i87 = $284 ? $237 : $243;
    $285 = $239 > $245;
    $286 = $285 ? $239 : $245;
    $287 = $241 > $247;
    $$1$i88 = $287 ? $241 : $247;
    $288 = $249 < $255;
    $$$i81 = $288 ? $249 : $255;
    $289 = $251 < $257;
    $290 = $289 ? $251 : $257;
    $291 = $253 < $259;
    $$1$i82 = $291 ? $253 : $259;
    $292 = $249 > $255;
    $$$i75 = $292 ? $249 : $255;
    $293 = $251 > $257;
    $294 = $293 ? $251 : $257;
    $295 = $253 > $259;
    $$1$i76 = $295 ? $253 : $259;
    $296 = $261 < $267;
    $$$i69 = $296 ? $261 : $267;
    $297 = $263 < $269;
    $298 = $297 ? $263 : $269;
    $299 = $265 < $271;
    $$1$i70 = $299 ? $265 : $271;
    $300 = $261 > $267;
    $$$i = $300 ? $261 : $267;
    $301 = $263 > $269;
    $302 = $301 ? $263 : $269;
    $303 = $265 > $271;
    $$1$i = $303 ? $265 : $271;
    $304 = $192 > $$$i105;
    $305 = $192 > $$$i93;
    $306 = $192 > $$$i81;
    $307 = $192 > $$$i69;
    $not$ = $193 > $274;
    $$567 = $304 & $not$;
    $not$569 = $193 > $282;
    $308 = $305 & $not$569;
    $not$570 = $193 > $290;
    $$568 = $306 & $not$570;
    $not$571 = $193 > $298;
    $309 = $307 & $not$571;
    $not$572 = $194 > $$1$i106;
    $$$567 = $$567 & $not$572;
    $not$573 = $194 > $$1$i94;
    $310 = $308 & $not$573;
    $not$574 = $194 > $$1$i82;
    $$$568 = $$568 & $not$574;
    $not$575 = $194 > $$1$i70;
    $311 = $309 & $not$575;
    $not$576 = $$$i99 > $189;
    $$$$567 = $$$567 & $not$576;
    $not$577 = $$$i87 > $189;
    $312 = $310 & $not$577;
    $not$578 = $$$i75 > $189;
    $$$$568 = $$$568 & $not$578;
    $not$579 = $$$i > $189;
    $313 = $311 & $not$579;
    $not$580 = $278 > $190;
    $$$$$567 = $$$$567 & $not$580;
    $not$581 = $286 > $190;
    $314 = $312 & $not$581;
    $not$582 = $294 > $190;
    $$$$$568 = $$$$568 & $not$582;
    $not$583 = $302 > $190;
    $315 = $313 & $not$583;
    $not$584 = $$1$i100 > $191;
    $$$$$$567 = $$$$$567 & $not$584;
    $not$585 = $$1$i88 > $191;
    $316 = $314 & $not$585;
    $not$586 = $$1$i76 > $191;
    $$$$$$568 = $$$$$568 & $not$586;
    $not$587 = $$1$i > $191;
    $317 = $315 & $not$587;
    HEAP32[$1>>2] = 1;
    HEAP32[$204>>2] = 1;
    HEAP32[$205>>2] = 1;
    HEAP32[$206>>2] = 1;
    $b$a$i = $$$$$$567 ? $1 : $0;
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    $318 = HEAP32[$b$a$i>>2]|0;
    $a$pn4$i = $316 ? $1 : $0;
    $$in1$i = (($a$pn4$i) + 4|0);
    $319 = HEAP32[$$in1$i>>2]|0;
    $b$a7$i = $$$$$$568 ? $1 : $0;
    $$in2$i = (($b$a7$i) + 8|0);
    $320 = HEAP32[$$in2$i>>2]|0;
    $a$pn6$i = $317 ? $1 : $0;
    $$in3$i = (($a$pn6$i) + 12|0);
    $321 = HEAP32[$$in3$i>>2]|0;
    $322 = (($overlapArray) + ($i$0591<<2)|0);
    HEAP32[$322>>2] = $318;
    $323 = (($overlapArray) + ($214<<2)|0);
    HEAP32[$323>>2] = $319;
    $324 = (($overlapArray) + ($217<<2)|0);
    HEAP32[$324>>2] = $320;
    $325 = (($overlapArray) + ($221<<2)|0);
    HEAP32[$325>>2] = $321;
    $326 = (($i$0591) + 4)|0;
    $327 = ($326>>>0)<($210>>>0);
    if ($327) {
     $i$0591 = $326;$particleCollDataIt$0592 = $$particleCollDataIt$2;
    } else {
     break;
    }
   }
   if ($212) {
    $scaledPlanes$1$off0$lcssa = $scaledPlanes$0$off0602;
   } else {
    $328 = (($210) + -1)|0;
    $329 = (($start$0601) + ($207))|0;
    $330 = ($329>>>0)>(4294967167);
    $$op = $329 ^ -1;
    $331 = $330 ? $$op : 128;
    $k$0598 = 0;$particleCollDataIt$4595 = $211;$scaledPlanes$1$off0599 = $scaledPlanes$0$off0602;$v4Count$0597 = 0;
    while(1) {
     $332 = (($overlapArray) + ($k$0598<<2)|0);
     $333 = HEAP32[$332>>2]|0;
     $334 = ($333|0)==(0);
     if ($334) {
      $scaledPlanes$3$off0 = $scaledPlanes$1$off0599;$v4Count$1 = $v4Count$0597;
     } else {
      if (!($scaledPlanes$1$off0599)) {
       $335 = HEAP8[$202>>0]|0;
       $336 = ($335<<24>>24)==(0);
       if (!($336)) {
        $337 = $335&255;
        $338 = HEAP32[$203>>2]|0;
        $numPlanes$06$i = $337;$planeIt$05$i = $scaledPlaneBuf;$polygonIt$04$i = $338;
        while(1) {
         $339 = Math_fround(HEAPF32[$polygonIt$04$i>>2]);
         $340 = (($polygonIt$04$i) + 4|0);
         $341 = Math_fround(HEAPF32[$340>>2]);
         $342 = (($polygonIt$04$i) + 8|0);
         $343 = Math_fround(HEAPF32[$342>>2]);
         $344 = (($polygonIt$04$i) + 12|0);
         $345 = Math_fround(HEAPF32[$344>>2]);
         $346 = Math_fround($104 * $339);
         $347 = Math_fround($106 * $341);
         $348 = Math_fround($346 + $347);
         $349 = Math_fround($108 * $343);
         $350 = Math_fround($348 + $349);
         $351 = Math_fround($110 * $339);
         $352 = Math_fround($112 * $341);
         $353 = Math_fround($351 + $352);
         $354 = Math_fround($114 * $343);
         $355 = Math_fround($353 + $354);
         $356 = Math_fround($116 * $339);
         $357 = Math_fround($118 * $341);
         $358 = Math_fround($356 + $357);
         $359 = Math_fround($120 * $343);
         $360 = Math_fround($358 + $359);
         $361 = Math_fround($350 * $350);
         $362 = Math_fround($355 * $355);
         $363 = Math_fround($361 + $362);
         $364 = Math_fround($360 * $360);
         $365 = Math_fround($364 + $363);
         $366 = (Math_fround(Math_sqrt((Math_fround($365)))));
         $367 = $366 > Math_fround(0.0);
         if ($367) {
          $368 = Math_fround(Math_fround(1.0) / $366);
          $369 = Math_fround($350 * $368);
          $370 = Math_fround($355 * $368);
          $371 = Math_fround($360 * $368);
          $373 = $369;$375 = $370;$377 = $371;
         } else {
          $373 = $350;$375 = $355;$377 = $360;
         }
         $372 = Math_fround($345 / $366);
         HEAPF32[$planeIt$05$i>>2] = $373;
         $374 = (($planeIt$05$i) + 4|0);
         HEAPF32[$374>>2] = $375;
         $376 = (($planeIt$05$i) + 8|0);
         HEAPF32[$376>>2] = $377;
         $378 = (($planeIt$05$i) + 12|0);
         HEAPF32[$378>>2] = $372;
         $379 = (($numPlanes$06$i) + -1)|0;
         $380 = (($planeIt$05$i) + 16|0);
         $381 = (($polygonIt$04$i) + 20|0);
         $382 = ($379|0)==(0);
         if ($382) {
          break;
         } else {
          $numPlanes$06$i = $379;$planeIt$05$i = $380;$polygonIt$04$i = $381;
         }
        }
       }
      }
      $383 = (($particleCollDataIt$4595) + 112|0);
      $384 = Math_fround(HEAPF32[$383>>2]);
      $385 = ((($collDataV4) + ($v4Count$0597<<4)|0) + 16|0);
      HEAPF32[$385>>2] = $384;
      $386 = (($particleCollDataIt$4595) + 116|0);
      $387 = Math_fround(HEAPF32[$386>>2]);
      $388 = ((($collDataV4) + ($v4Count$0597<<4)|0) + 20|0);
      HEAPF32[$388>>2] = $387;
      $389 = (($particleCollDataIt$4595) + 120|0);
      $390 = Math_fround(HEAPF32[$389>>2]);
      $391 = ((($collDataV4) + ($v4Count$0597<<4)|0) + 24|0);
      HEAPF32[$391>>2] = $390;
      $392 = (($particleCollDataIt$4595) + 128|0);
      $393 = Math_fround(HEAPF32[$392>>2]);
      $394 = ((($collDataV4) + ($v4Count$0597<<4)|0) + 80|0);
      HEAPF32[$394>>2] = $393;
      $395 = (($particleCollDataIt$4595) + 132|0);
      $396 = Math_fround(HEAPF32[$395>>2]);
      $397 = ((($collDataV4) + ($v4Count$0597<<4)|0) + 84|0);
      HEAPF32[$397>>2] = $396;
      $398 = (($particleCollDataIt$4595) + 136|0);
      $399 = Math_fround(HEAPF32[$398>>2]);
      $400 = ((($collDataV4) + ($v4Count$0597<<4)|0) + 88|0);
      HEAPF32[$400>>2] = $399;
      $401 = (($particleCollDataIt$4595) + 124|0);
      $402 = HEAP32[$401>>2]|0;
      $403 = ((($collDataV4) + ($v4Count$0597<<2)|0) + 160|0);
      HEAP32[$403>>2] = $402;
      $404 = (($particleCollDataIt$4595) + 92|0);
      $405 = Math_fround(HEAPF32[$404>>2]);
      $406 = ((($collDataV4) + ($v4Count$0597<<2)|0) + 144|0);
      HEAPF32[$406>>2] = $405;
      $407 = (($particleCollDataIt$4595) + 44|0);
      $408 = Math_fround(HEAPF32[$407>>2]);
      $409 = ((($collDataV4) + ($v4Count$0597<<2)|0) + 176|0);
      HEAPF32[$409>>2] = $408;
      $410 = (($collDataV4) + ($v4Count$0597<<2)|0);
      HEAP32[$410>>2] = $particleCollDataIt$4595;
      $411 = (($v4Count$0597) + 1)|0;
      $scaledPlanes$3$off0 = 1;$v4Count$1 = $411;
     }
     if ((($v4Count$1|0) == 0)) {
      $v4Count$2 = 0;
     } else if ((($v4Count$1|0) == 4)) {
      label = 17;
     } else {
      $412 = ($k$0598|0)==($328|0);
      if ($412) {
       label = 17;
      } else {
       $v4Count$2 = $v4Count$1;
      }
     }
     if ((label|0) == 17) {
      label = 0;
      $413 = HEAP8[$202>>0]|0;
      $414 = $413&255;
      __ZN5physx27collideWithConvexPlanesSIMDERNS_21PxsParticleCollDataV4EPKNS_7PxPlaneEjf($collDataV4,$scaledPlaneBuf,$414,$proxRadius);
      $415 = ($v4Count$1|0)==(0);
      if ($415) {
       $v4Count$2 = 0;
      } else {
       $j$0594 = 0;
       while(1) {
        $416 = (($collDataV4) + ($j$0594<<2)|0);
        $417 = HEAP32[$416>>2]|0;
        $418 = ((($collDataV4) + ($j$0594<<2)|0) + 160|0);
        $419 = HEAP32[$418>>2]|0;
        $420 = ($419|0)==(0);
        if (!($420)) {
         $421 = (($417) + 124|0);
         $422 = HEAP32[$421>>2]|0;
         $423 = $422 | $419;
         HEAP32[$421>>2] = $423;
         $424 = ((($collDataV4) + ($j$0594<<2)|0) + 176|0);
         $425 = Math_fround(HEAPF32[$424>>2]);
         $426 = (($417) + 44|0);
         HEAPF32[$426>>2] = $425;
         $427 = ((($collDataV4) + ($j$0594<<4)|0) + 192|0);
         $428 = Math_fround(HEAPF32[$427>>2]);
         $429 = (($417) + 144|0);
         HEAPF32[$429>>2] = $428;
         $430 = ((($collDataV4) + ($j$0594<<4)|0) + 196|0);
         $431 = Math_fround(HEAPF32[$430>>2]);
         $432 = (($417) + 148|0);
         HEAPF32[$432>>2] = $431;
         $433 = ((($collDataV4) + ($j$0594<<4)|0) + 200|0);
         $434 = Math_fround(HEAPF32[$433>>2]);
         $435 = (($417) + 152|0);
         HEAPF32[$435>>2] = $434;
         $436 = ((($collDataV4) + ($j$0594<<4)|0) + 256|0);
         $437 = Math_fround(HEAPF32[$436>>2]);
         $438 = (($417) + 160|0);
         HEAPF32[$438>>2] = $437;
         $439 = ((($collDataV4) + ($j$0594<<4)|0) + 260|0);
         $440 = Math_fround(HEAPF32[$439>>2]);
         $441 = (($417) + 164|0);
         HEAPF32[$441>>2] = $440;
         $442 = ((($collDataV4) + ($j$0594<<4)|0) + 264|0);
         $443 = Math_fround(HEAPF32[$442>>2]);
         $444 = (($417) + 168|0);
         HEAPF32[$444>>2] = $443;
        }
        $445 = (($j$0594) + 1)|0;
        $exitcond = ($445|0)==($v4Count$1|0);
        if ($exitcond) {
         $v4Count$2 = 0;
         break;
        } else {
         $j$0594 = $445;
        }
       }
      }
     }
     $446 = (($k$0598) + 1)|0;
     $447 = (($particleCollDataIt$4595) + 176|0);
     $exitcond606 = ($446|0)==($331|0);
     if ($exitcond606) {
      $scaledPlanes$1$off0$lcssa = $scaledPlanes$3$off0;
      break;
     } else {
      $k$0598 = $446;$particleCollDataIt$4595 = $447;$scaledPlanes$1$off0599 = $scaledPlanes$3$off0;$v4Count$0597 = $v4Count$2;
     }
    }
   }
  }
  $448 = (($210) + ($start$0601))|0;
  $449 = ($448>>>0)<($numCollData>>>0);
  if ($449) {
   $scaledPlanes$0$off0602 = $scaledPlanes$1$off0$lcssa;$start$0601 = $448;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx7PxMat3310getInverseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0;
 var $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 32|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 * $3);
 $5 = (($this) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 28|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = Math_fround($4 - $9);
 $11 = (($this) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($6 * $12);
 $14 = (($this) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 * $15);
 $17 = Math_fround($13 - $16);
 $18 = Math_fround($8 * $15);
 $19 = Math_fround($1 * $12);
 $20 = Math_fround($18 - $19);
 $21 = Math_fround(HEAPF32[$this>>2]);
 $22 = Math_fround($10 * $21);
 $23 = (($this) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 * $17);
 $26 = Math_fround($22 + $25);
 $27 = (($this) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($20 * $28);
 $30 = Math_fround($26 + $29);
 $31 = $30 != Math_fround(0.0);
 if ($31) {
  $32 = Math_fround(Math_fround(1.0) / $30);
  $33 = Math_fround($32 * $10);
  $34 = Math_fround($3 * $24);
  $35 = Math_fround($8 * $28);
  $36 = Math_fround($34 - $35);
  $37 = Math_fround($32 * $36);
  $38 = Math_fround(-$37);
  $39 = Math_fround($6 * $24);
  $40 = Math_fround($1 * $28);
  $41 = Math_fround($39 - $40);
  $42 = Math_fround($32 * $41);
  $43 = Math_fround($16 - $13);
  $44 = Math_fround($32 * $43);
  $45 = Math_fround(-$44);
  $46 = Math_fround($3 * $21);
  $47 = Math_fround($28 * $12);
  $48 = Math_fround($46 - $47);
  $49 = Math_fround($32 * $48);
  $50 = Math_fround($6 * $21);
  $51 = Math_fround($28 * $15);
  $52 = Math_fround($50 - $51);
  $53 = Math_fround($32 * $52);
  $54 = Math_fround(-$53);
  $55 = Math_fround($32 * $20);
  $56 = Math_fround($8 * $21);
  $57 = Math_fround($24 * $12);
  $58 = Math_fround($56 - $57);
  $59 = Math_fround($32 * $58);
  $60 = Math_fround(-$59);
  $61 = Math_fround($1 * $21);
  $62 = Math_fround($24 * $15);
  $63 = Math_fround($61 - $62);
  $64 = Math_fround($32 * $63);
  HEAPF32[$agg$result>>2] = $33;
  $65 = (($agg$result) + 4|0);
  HEAPF32[$65>>2] = $38;
  $66 = (($agg$result) + 8|0);
  HEAPF32[$66>>2] = $42;
  $67 = (($agg$result) + 12|0);
  HEAPF32[$67>>2] = $45;
  $68 = (($agg$result) + 16|0);
  HEAPF32[$68>>2] = $49;
  $69 = (($agg$result) + 20|0);
  HEAPF32[$69>>2] = $54;
  $70 = (($agg$result) + 24|0);
  HEAPF32[$70>>2] = $55;
  $71 = (($agg$result) + 28|0);
  HEAPF32[$71>>2] = $60;
  $72 = (($agg$result) + 32|0);
  HEAPF32[$72>>2] = $64;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$agg$result>>2] = Math_fround(1.0);
  $73 = (($agg$result) + 4|0);
  HEAPF32[$73>>2] = Math_fround(0.0);
  $74 = (($agg$result) + 8|0);
  HEAPF32[$74>>2] = Math_fround(0.0);
  $75 = (($agg$result) + 12|0);
  HEAPF32[$75>>2] = Math_fround(0.0);
  $76 = (($agg$result) + 16|0);
  HEAPF32[$76>>2] = Math_fround(1.0);
  $77 = (($agg$result) + 20|0);
  HEAPF32[$77>>2] = Math_fround(0.0);
  $78 = (($agg$result) + 24|0);
  HEAPF32[$78>>2] = Math_fround(0.0);
  $79 = (($agg$result) + 28|0);
  HEAPF32[$79>>2] = Math_fround(0.0);
  $80 = (($agg$result) + 32|0);
  HEAPF32[$80>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
}
function __Z14testBoundsMeshRKN5physx2Gu24InternalTriangleMeshDataERKNS_11PxTransformERKNS_2Cm23FastVertex2ShapeScalingEbRKNS_9PxBounds3ER26PxcContactCellMeshCallback($meshData,$world2Shape,$meshScaling,$idtScaleMesh,$worldBounds,$callback) {
 $meshData = $meshData|0;
 $world2Shape = $world2Shape|0;
 $meshScaling = $meshScaling|0;
 $idtScaleMesh = $idtScaleMesh|0;
 $worldBounds = $worldBounds|0;
 $callback = $callback|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0);
 var $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0);
 var $hmd = 0, $vertexSpaceOBB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 72|0;
 $vertexSpaceOBB = sp;
 $hmd = sp + 60|0;
 __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($0,$world2Shape,$worldBounds);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($0) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($0) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($0) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($0) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($1 + $7);
 $13 = Math_fround($3 + $9);
 $14 = Math_fround($5 + $11);
 $15 = Math_fround($12 * Math_fround(0.5));
 $16 = Math_fround($13 * Math_fround(0.5));
 $17 = Math_fround($14 * Math_fround(0.5));
 $18 = Math_fround($7 - $1);
 $19 = Math_fround($9 - $3);
 $20 = Math_fround($11 - $5);
 $21 = Math_fround($18 * Math_fround(0.5));
 $22 = Math_fround($19 * Math_fround(0.5));
 $23 = Math_fround($20 * Math_fround(0.5));
 HEAPF32[$vertexSpaceOBB>>2] = Math_fround(1.0);
 $24 = (($vertexSpaceOBB) + 4|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($vertexSpaceOBB) + 8|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($vertexSpaceOBB) + 12|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($vertexSpaceOBB) + 16|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($vertexSpaceOBB) + 20|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($vertexSpaceOBB) + 24|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($vertexSpaceOBB) + 28|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($vertexSpaceOBB) + 32|0);
 HEAPF32[$31>>2] = Math_fround(1.0);
 $32 = (($vertexSpaceOBB) + 36|0);
 HEAPF32[$32>>2] = $15;
 $33 = (($vertexSpaceOBB) + 40|0);
 HEAPF32[$33>>2] = $16;
 $34 = (($vertexSpaceOBB) + 44|0);
 HEAPF32[$34>>2] = $17;
 $35 = (($vertexSpaceOBB) + 48|0);
 HEAPF32[$35>>2] = $21;
 $36 = (($vertexSpaceOBB) + 52|0);
 HEAPF32[$36>>2] = $22;
 $37 = (($vertexSpaceOBB) + 56|0);
 HEAPF32[$37>>2] = $23;
 if ($idtScaleMesh) {
  $104 = (($meshData) + 16|0);
  $105 = HEAP32[$104>>2]|0;
  HEAP32[$hmd>>2] = $105;
  $106 = (($meshData) + 32|0);
  $107 = (($hmd) + 4|0);
  HEAP32[$107>>2] = $106;
  $108 = (($meshData) + 20|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($hmd) + 8|0);
  HEAPF32[$110>>2] = $109;
  __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($vertexSpaceOBB,1,$hmd,$callback,1);
  STACKTOP = sp;return;
 }
 $38 = (($meshScaling) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($15 * $39);
 $41 = (($meshScaling) + 40|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($15 * $42);
 $44 = (($meshScaling) + 44|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($15 * $45);
 $47 = (($meshScaling) + 48|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($16 * $48);
 $50 = (($meshScaling) + 52|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($16 * $51);
 $53 = (($meshScaling) + 56|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($16 * $54);
 $56 = Math_fround($40 + $49);
 $57 = Math_fround($43 + $52);
 $58 = Math_fround($46 + $55);
 $59 = (($meshScaling) + 60|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($17 * $60);
 $62 = (($meshScaling) + 64|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($17 * $63);
 $65 = (($meshScaling) + 68|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($17 * $66);
 $68 = Math_fround($56 + $61);
 $69 = Math_fround($57 + $64);
 $70 = Math_fround($58 + $67);
 $71 = Math_fround($39 * $21);
 $72 = Math_fround($42 * $21);
 $73 = Math_fround($45 * $21);
 $74 = Math_fround($48 * $22);
 $75 = Math_fround($51 * $22);
 $76 = Math_fround($54 * $22);
 $77 = Math_fround($60 * $23);
 $78 = Math_fround($63 * $23);
 $79 = Math_fround($66 * $23);
 $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($71)))));
 $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($74)))));
 $80 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
 $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($77)))));
 $81 = Math_fround($80 + $fabsf$i$i6$i$i);
 $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($72)))));
 $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($75)))));
 $82 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
 $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($78)))));
 $83 = Math_fround($82 + $fabsf$i$i3$i$i);
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($73)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($76)))));
 $84 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($79)))));
 $85 = Math_fround($84 + $fabsf$i$i$i$i);
 $86 = Math_fround($68 - $81);
 $87 = Math_fround($69 - $83);
 $88 = Math_fround($70 - $85);
 $89 = Math_fround($68 + $81);
 $90 = Math_fround($69 + $83);
 $91 = Math_fround($70 + $85);
 $92 = Math_fround($86 + $89);
 $93 = Math_fround($87 + $90);
 $94 = Math_fround($88 + $91);
 $95 = Math_fround($92 * Math_fround(0.5));
 $96 = Math_fround($93 * Math_fround(0.5));
 $97 = Math_fround($94 * Math_fround(0.5));
 HEAPF32[$32>>2] = $95;
 HEAPF32[$33>>2] = $96;
 HEAPF32[$34>>2] = $97;
 $98 = Math_fround($89 - $86);
 $99 = Math_fround($90 - $87);
 $100 = Math_fround($91 - $88);
 $101 = Math_fround($98 * Math_fround(0.5));
 $102 = Math_fround($99 * Math_fround(0.5));
 $103 = Math_fround($100 * Math_fround(0.5));
 HEAPF32[$35>>2] = $101;
 HEAPF32[$36>>2] = $102;
 HEAPF32[$37>>2] = $103;
 $104 = (($meshData) + 16|0);
 $105 = HEAP32[$104>>2]|0;
 HEAP32[$hmd>>2] = $105;
 $106 = (($meshData) + 32|0);
 $107 = (($hmd) + 4|0);
 HEAP32[$107>>2] = $106;
 $108 = (($meshData) + 20|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($hmd) + 8|0);
 HEAPF32[$110>>2] = $109;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($vertexSpaceOBB,1,$hmd,$callback,1);
 STACKTOP = sp;return;
}
function __Z24collideWithMeshTrianglesRN5physx19PxsParticleCollDataERKNS_2Gu24InternalTriangleMeshDataERKNS_2Cm23FastVertex2ShapeScalingEPKNS_6PxVec3EjfRKNS_11PxTransformE($collisionShapeData,$0,$scale,$triangleVerts,$numTriangles,$proxRadius,$shape2World) {
 $collisionShapeData = $collisionShapeData|0;
 $0 = $0|0;
 $scale = $scale|0;
 $triangleVerts = $triangleVerts|0;
 $numTriangles = $numTriangles|0;
 $proxRadius = Math_fround($proxRadius);
 $shape2World = $shape2World|0;
 var $$lobit = 0, $$pre = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0;
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $hasCC = 0, $i$01 = 0, $phitmp = 0, $tmpCCTime = 0, $tmpDistOldToSurface = 0, $tmpProxSurfaceNormal = 0, $tmpProxSurfacePos = 0, $tmpSurfaceNormal = 0, $tmpSurfacePos = 0, $v0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $1 = sp + 92|0;
 $hasCC = sp + 96|0;
 $tmpSurfaceNormal = sp + 80|0;
 $tmpSurfacePos = sp + 68|0;
 $tmpProxSurfaceNormal = sp + 56|0;
 $tmpProxSurfacePos = sp + 44|0;
 $tmpCCTime = sp + 28|0;
 $tmpDistOldToSurface = sp + 24|0;
 $v0 = sp + 12|0;
 $2 = sp;
 $3 = sp + 32|0;
 HEAPF32[$1>>2] = $proxRadius;
 $4 = (($collisionShapeData) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = $5 >>> 3;
  $$lobit = $8 & 1;
  $phitmp = $$lobit&255;
  $9 = $phitmp;
 } else {
  $9 = 1;
 }
 HEAP8[$hasCC>>0] = $9;
 HEAPF32[$tmpSurfaceNormal>>2] = Math_fround(0.0);
 $10 = (($tmpSurfaceNormal) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($tmpSurfaceNormal) + 8|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 HEAPF32[$tmpSurfacePos>>2] = Math_fround(0.0);
 $12 = (($tmpSurfacePos) + 4|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($tmpSurfacePos) + 8|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 HEAPF32[$tmpProxSurfaceNormal>>2] = Math_fround(0.0);
 $14 = (($tmpProxSurfaceNormal) + 4|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($tmpProxSurfaceNormal) + 8|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 HEAPF32[$tmpProxSurfacePos>>2] = Math_fround(0.0);
 $16 = (($tmpProxSurfacePos) + 4|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($tmpProxSurfacePos) + 8|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 HEAPF32[$tmpCCTime>>2] = Math_fround(0.0);
 HEAPF32[$tmpDistOldToSurface>>2] = Math_fround(0.0);
 $18 = ($numTriangles|0)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($scale) + 4|0);
 $20 = (($scale) + 8|0);
 $21 = (($scale) + 12|0);
 $22 = (($scale) + 16|0);
 $23 = (($scale) + 20|0);
 $24 = (($scale) + 24|0);
 $25 = (($scale) + 28|0);
 $26 = (($scale) + 32|0);
 $27 = (($v0) + 4|0);
 $28 = (($v0) + 8|0);
 $29 = (($collisionShapeData) + 112|0);
 $30 = (($collisionShapeData) + 128|0);
 $31 = (($2) + 4|0);
 $32 = (($2) + 8|0);
 $33 = (($3) + 4|0);
 $34 = (($3) + 8|0);
 $35 = (($collisionShapeData) + 92|0);
 $118 = $9;$i$01 = 0;
 while(1) {
  $36 = ($i$01*3)|0;
  $37 = (($triangleVerts) + (($36*12)|0)|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround(HEAPF32[$scale>>2]);
  $40 = Math_fround($38 * $39);
  $41 = Math_fround(HEAPF32[$19>>2]);
  $42 = Math_fround($38 * $41);
  $43 = Math_fround(HEAPF32[$20>>2]);
  $44 = Math_fround($38 * $43);
  $45 = ((($triangleVerts) + (($36*12)|0)|0) + 4|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround(HEAPF32[$21>>2]);
  $48 = Math_fround($46 * $47);
  $49 = Math_fround(HEAPF32[$22>>2]);
  $50 = Math_fround($46 * $49);
  $51 = Math_fround(HEAPF32[$23>>2]);
  $52 = Math_fround($46 * $51);
  $53 = Math_fround($40 + $48);
  $54 = Math_fround($42 + $50);
  $55 = Math_fround($44 + $52);
  $56 = ((($triangleVerts) + (($36*12)|0)|0) + 8|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround(HEAPF32[$24>>2]);
  $59 = Math_fround($57 * $58);
  $60 = Math_fround(HEAPF32[$25>>2]);
  $61 = Math_fround($57 * $60);
  $62 = Math_fround(HEAPF32[$26>>2]);
  $63 = Math_fround($57 * $62);
  $64 = Math_fround($53 + $59);
  $65 = Math_fround($54 + $61);
  $66 = Math_fround($55 + $63);
  HEAPF32[$v0>>2] = $64;
  HEAPF32[$27>>2] = $65;
  HEAPF32[$28>>2] = $66;
  $67 = (($36) + 1)|0;
  $68 = (($triangleVerts) + (($67*12)|0)|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($69 * $39);
  $71 = Math_fround($69 * $41);
  $72 = Math_fround($69 * $43);
  $73 = ((($triangleVerts) + (($67*12)|0)|0) + 4|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($74 * $47);
  $76 = Math_fround($74 * $49);
  $77 = Math_fround($74 * $51);
  $78 = Math_fround($70 + $75);
  $79 = Math_fround($71 + $76);
  $80 = Math_fround($72 + $77);
  $81 = ((($triangleVerts) + (($67*12)|0)|0) + 8|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($82 * $58);
  $84 = Math_fround($82 * $60);
  $85 = Math_fround($82 * $62);
  $86 = Math_fround($78 + $83);
  $87 = Math_fround($79 + $84);
  $88 = Math_fround($80 + $85);
  $89 = (($36) + 2)|0;
  $90 = (($triangleVerts) + (($89*12)|0)|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($39 * $91);
  $93 = Math_fround($41 * $91);
  $94 = Math_fround($43 * $91);
  $95 = ((($triangleVerts) + (($89*12)|0)|0) + 4|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = Math_fround($47 * $96);
  $98 = Math_fround($49 * $96);
  $99 = Math_fround($51 * $96);
  $100 = Math_fround($92 + $97);
  $101 = Math_fround($93 + $98);
  $102 = Math_fround($94 + $99);
  $103 = ((($triangleVerts) + (($89*12)|0)|0) + 8|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = Math_fround($58 * $104);
  $106 = Math_fround($60 * $104);
  $107 = Math_fround($62 * $104);
  $108 = Math_fround($100 + $105);
  $109 = Math_fround($101 + $106);
  $110 = Math_fround($102 + $107);
  $111 = Math_fround($86 - $64);
  $112 = Math_fround($87 - $65);
  $113 = Math_fround($88 - $66);
  HEAPF32[$2>>2] = $111;
  HEAPF32[$31>>2] = $112;
  HEAPF32[$32>>2] = $113;
  $114 = Math_fround($108 - $64);
  $115 = Math_fround($109 - $65);
  $116 = Math_fround($110 - $66);
  HEAPF32[$3>>2] = $114;
  HEAPF32[$33>>2] = $115;
  HEAPF32[$34>>2] = $116;
  $117 = ($118<<24>>24)!=(0);
  $119 = (__ZN5physx23collideWithMeshTriangleERNS_6PxVec3ES1_S1_S1_RfS2_RKS0_S4_S4_S4_S4_bRKfS6_($tmpSurfaceNormal,$tmpSurfacePos,$tmpProxSurfaceNormal,$tmpProxSurfacePos,$tmpCCTime,$tmpDistOldToSurface,$29,$30,$v0,$2,$3,$117,$35,$1)|0);
  $120 = Math_fround(HEAPF32[$tmpCCTime>>2]);
  $121 = Math_fround(HEAPF32[$tmpDistOldToSurface>>2]);
  __Z19updateCollShapeDataRN5physx19PxsParticleCollDataERbjffRKNS_6PxVec3ES5_S5_S5_RKNS_11PxTransformE($collisionShapeData,$hasCC,$119,$120,$121,$tmpSurfaceNormal,$tmpSurfacePos,$tmpProxSurfaceNormal,$tmpProxSurfacePos,$shape2World);
  $122 = (($i$01) + 1)|0;
  $exitcond = ($122|0)==($numTriangles|0);
  if ($exitcond) {
   break;
  }
  $$pre = HEAP8[$hasCC>>0]|0;
  $118 = $$pre;$i$01 = $122;
 }
 STACKTOP = sp;return;
}
function __ZN5physx23collideWithMeshTriangleERNS_6PxVec3ES1_S1_S1_RfS2_RKS0_S4_S4_S4_S4_bRKfS6_($surfaceNormal,$surfacePos,$proxSurfaceNormal,$proxSurfacePos,$ccTime,$distOldToSurface,$oldPos,$newPos,$origin,$e0,$e1,$hasCC,$collRadius,$proxRadius) {
 $surfaceNormal = $surfaceNormal|0;
 $surfacePos = $surfacePos|0;
 $proxSurfaceNormal = $proxSurfaceNormal|0;
 $proxSurfacePos = $proxSurfacePos|0;
 $ccTime = $ccTime|0;
 $distOldToSurface = $distOldToSurface|0;
 $oldPos = $oldPos|0;
 $newPos = $newPos|0;
 $origin = $origin|0;
 $e0 = $e0|0;
 $e1 = $e1|0;
 $hasCC = $hasCC|0;
 $collRadius = $collRadius|0;
 $proxRadius = $proxRadius|0;
 var $$ = 0, $$0 = 0, $$off01 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0);
 var $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = 0;
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $a$0 = Math_fround(0), $brmerge = 0, $c$0 = Math_fround(0), $flags$0 = 0, $flags$1 = 0, $insideCase$0$off0 = 0, $or$cond = 0, $or$cond2 = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$collRadius>>2]);
 $1 = Math_fround($0 * $0);
 $2 = Math_fround(HEAPF32[$proxRadius>>2]);
 $3 = Math_fround($2 * $2);
 $4 = Math_fround(HEAPF32[$newPos>>2]);
 $5 = Math_fround(HEAPF32[$oldPos>>2]);
 $6 = Math_fround($4 - $5);
 $7 = (($newPos) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($oldPos) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 - $10);
 $12 = (($newPos) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($oldPos) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = Math_fround(HEAPF32[$origin>>2]);
 $18 = Math_fround($17 - $4);
 $19 = (($origin) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 - $8);
 $22 = (($origin) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 - $13);
 $25 = Math_fround(HEAPF32[$e0>>2]);
 $26 = Math_fround($25 * $25);
 $27 = (($e0) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $28);
 $30 = Math_fround($26 + $29);
 $31 = (($e0) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $32);
 $34 = Math_fround($30 + $33);
 $35 = Math_fround(HEAPF32[$e1>>2]);
 $36 = Math_fround($25 * $35);
 $37 = (($e1) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($28 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($e1) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($32 * $42);
 $44 = Math_fround($40 + $43);
 $45 = Math_fround($35 * $35);
 $46 = Math_fround($38 * $38);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($42 * $42);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($18 * $25);
 $51 = Math_fround($21 * $28);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($24 * $32);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($18 * $35);
 $56 = Math_fround($21 * $38);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($24 * $42);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($44 * $59);
 $61 = Math_fround($54 * $49);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($54 * $44);
 $64 = Math_fround($34 * $59);
 $65 = Math_fround($63 - $64);
 $66 = Math_fround($34 * $49);
 $67 = Math_fround($44 * $44);
 $68 = Math_fround($66 - $67);
 $69 = !($62 <= Math_fround(0.0));
 do {
  if ($69) {
   $74 = !($65 <= Math_fround(0.0));
   if (!($74)) {
    $75 = $34 > Math_fround(1.17549435082228750797E-38);
    $76 = $75 ? $34 : Math_fround(1.17549435082228750797E-38);
    $77 = Math_fround(-$54);
    $78 = Math_fround($77 / $76);
    $100 = Math_fround(0.0);$97 = $78;$a$0 = $76;$c$0 = $49;$insideCase$0$off0 = 0;
    break;
   }
   $79 = Math_fround($62 + $65);
   $80 = $79 > $68;
   if ($80) {
    $81 = Math_fround($34 + $49);
    $82 = Math_fround($81 - $44);
    $83 = Math_fround($82 - $44);
    $84 = Math_fround($49 + $59);
    $85 = Math_fround($84 - $44);
    $86 = Math_fround($85 - $54);
    $87 = $83 > Math_fround(1.17549435082228750797E-38);
    $88 = $87 ? $83 : Math_fround(1.17549435082228750797E-38);
    $89 = Math_fround($86 / $88);
    $90 = Math_fround(Math_fround(1.0) - $89);
    $100 = $90;$97 = $89;$a$0 = $34;$c$0 = $49;$insideCase$0$off0 = 0;
    break;
   } else {
    $91 = $68 > Math_fround(1.17549435082228750797E-38);
    $92 = $91 ? $68 : Math_fround(1.17549435082228750797E-38);
    $93 = Math_fround(Math_fround(1.0) / $92);
    $94 = Math_fround($62 * $93);
    $95 = Math_fround($65 * $93);
    $100 = $95;$97 = $94;$a$0 = $34;$c$0 = $49;$insideCase$0$off0 = 1;
    break;
   }
  } else {
   $70 = $49 > Math_fround(1.17549435082228750797E-38);
   $71 = $70 ? $49 : Math_fround(1.17549435082228750797E-38);
   $72 = Math_fround(-$59);
   $73 = Math_fround($72 / $71);
   $100 = $73;$97 = Math_fround(0.0);$a$0 = $34;$c$0 = $71;$insideCase$0$off0 = 0;
  }
 } while(0);
 $96 = $97 > Math_fround(0.0);
 $98 = $96 ? $97 : Math_fround(0.0);
 $99 = $100 > Math_fround(0.0);
 $101 = $99 ? $100 : Math_fround(0.0);
 $102 = $98 < Math_fround(1.0);
 $103 = $102 ? $98 : Math_fround(1.0);
 $104 = $101 < Math_fround(1.0);
 $105 = $104 ? $101 : Math_fround(1.0);
 $106 = Math_fround($25 * $103);
 $107 = Math_fround($103 * $28);
 $108 = Math_fround($103 * $32);
 $109 = Math_fround($106 + $17);
 $110 = Math_fround($107 + $20);
 $111 = Math_fround($108 + $23);
 $112 = Math_fround($105 * $35);
 $113 = Math_fround($105 * $38);
 $114 = Math_fround($105 * $42);
 $115 = Math_fround($109 + $112);
 $116 = Math_fround($110 + $113);
 $117 = Math_fround($111 + $114);
 $118 = Math_fround($4 - $115);
 $119 = Math_fround($8 - $116);
 $120 = Math_fround($13 - $117);
 $121 = Math_fround($118 * $118);
 $122 = Math_fround($119 * $119);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($120 * $120);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($28 * $42);
 $127 = Math_fround($32 * $38);
 $128 = Math_fround($126 - $127);
 $129 = Math_fround($32 * $35);
 $130 = Math_fround($25 * $42);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($25 * $38);
 $133 = Math_fround($28 * $35);
 $134 = Math_fround($132 - $133);
 $135 = Math_fround($128 * $128);
 $136 = Math_fround($131 * $131);
 $137 = Math_fround($135 + $136);
 $138 = Math_fround($134 * $134);
 $139 = Math_fround($138 + $137);
 $140 = (Math_fround(Math_sqrt((Math_fround($139)))));
 $141 = Math_fround($118 * $128);
 $142 = Math_fround($131 * $119);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround($134 * $120);
 $145 = Math_fround($143 + $144);
 $146 = $145 > Math_fround(0.0);
 $147 = $125 < $3;
 $or$cond = $insideCase$0$off0 & $147;
 $$ = $or$cond & $146;
 $148 = $125 < $1;
 $$off01 = $148 & $146;
 if ($hasCC) {
  $flags$1 = 0;
 } else {
  if ($$off01) {
   $149 = $125 > Math_fround(9.99999974737875163555E-6);
   if ($149) {
    $150 = (Math_fround(Math_sqrt((Math_fround($125)))));
    $151 = Math_fround(Math_fround(1.0) / $150);
    $152 = Math_fround($118 * $151);
    $153 = Math_fround($119 * $151);
    $154 = Math_fround($120 * $151);
    HEAPF32[$surfaceNormal>>2] = $152;
    $155 = (($surfaceNormal) + 4|0);
    HEAPF32[$155>>2] = $153;
    $156 = (($surfaceNormal) + 8|0);
    HEAPF32[$156>>2] = $154;
    $165 = $152;$167 = $153;$169 = $154;
   } else {
    $157 = Math_fround(Math_fround(1.0) / $140);
    $158 = Math_fround($128 * $157);
    $159 = Math_fround($131 * $157);
    $160 = Math_fround($134 * $157);
    HEAPF32[$surfaceNormal>>2] = $158;
    $161 = (($surfaceNormal) + 4|0);
    HEAPF32[$161>>2] = $159;
    $162 = (($surfaceNormal) + 8|0);
    HEAPF32[$162>>2] = $160;
    $165 = $158;$167 = $159;$169 = $160;
   }
   $163 = Math_fround(HEAPF32[$collRadius>>2]);
   $164 = Math_fround($163 * $165);
   $166 = Math_fround($163 * $167);
   $168 = Math_fround($163 * $169);
   $170 = Math_fround($115 + $164);
   $171 = Math_fround($116 + $166);
   $172 = Math_fround($117 + $168);
   HEAPF32[$surfacePos>>2] = $170;
   $173 = (($surfacePos) + 4|0);
   HEAPF32[$173>>2] = $171;
   $174 = (($surfacePos) + 8|0);
   HEAPF32[$174>>2] = $172;
   $flags$0 = 16;
  } else {
   $flags$0 = 0;
  }
  if ($$) {
   $175 = Math_fround(Math_fround(1.0) / $140);
   $176 = Math_fround($128 * $175);
   $177 = Math_fround($131 * $175);
   $178 = Math_fround($134 * $175);
   HEAPF32[$proxSurfaceNormal>>2] = $176;
   $179 = (($proxSurfaceNormal) + 4|0);
   HEAPF32[$179>>2] = $177;
   $180 = (($proxSurfaceNormal) + 8|0);
   HEAPF32[$180>>2] = $178;
   $181 = Math_fround(HEAPF32[$collRadius>>2]);
   $182 = Math_fround($181 * $176);
   $183 = Math_fround($181 * $177);
   $184 = Math_fround($178 * $181);
   $185 = Math_fround($115 + $182);
   $186 = Math_fround($116 + $183);
   $187 = Math_fround($117 + $184);
   HEAPF32[$proxSurfacePos>>2] = $185;
   $188 = (($proxSurfacePos) + 4|0);
   HEAPF32[$188>>2] = $186;
   $189 = (($proxSurfacePos) + 8|0);
   HEAPF32[$189>>2] = $187;
   $190 = $flags$0 | 32;
   $191 = Math_fround(HEAPF32[$oldPos>>2]);
   $192 = Math_fround(HEAPF32[$origin>>2]);
   $193 = Math_fround($191 - $192);
   $194 = Math_fround(HEAPF32[$9>>2]);
   $195 = Math_fround(HEAPF32[$19>>2]);
   $196 = Math_fround($194 - $195);
   $197 = Math_fround(HEAPF32[$14>>2]);
   $198 = Math_fround(HEAPF32[$22>>2]);
   $199 = Math_fround($197 - $198);
   $200 = Math_fround(HEAPF32[$proxSurfaceNormal>>2]);
   $201 = Math_fround($193 * $200);
   $202 = Math_fround(HEAPF32[$179>>2]);
   $203 = Math_fround($196 * $202);
   $204 = Math_fround($201 + $203);
   $205 = Math_fround(HEAPF32[$180>>2]);
   $206 = Math_fround($199 * $205);
   $207 = Math_fround($204 + $206);
   HEAPF32[$distOldToSurface>>2] = $207;
   $$0 = $190;
   STACKTOP = sp;return ($$0|0);
  } else {
   $flags$1 = $flags$0;
  }
 }
 $brmerge = $$off01 | $$;
 if ($brmerge) {
  $$0 = $flags$1;
  STACKTOP = sp;return ($$0|0);
 }
 $208 = Math_fround(HEAPF32[$origin>>2]);
 $209 = Math_fround(HEAPF32[$oldPos>>2]);
 $210 = Math_fround($208 - $209);
 $211 = Math_fround(HEAPF32[$19>>2]);
 $212 = Math_fround(HEAPF32[$9>>2]);
 $213 = Math_fround($211 - $212);
 $214 = Math_fround(HEAPF32[$22>>2]);
 $215 = Math_fround(HEAPF32[$14>>2]);
 $216 = Math_fround($214 - $215);
 $217 = Math_fround($128 * $210);
 $218 = Math_fround($131 * $213);
 $219 = Math_fround($217 + $218);
 $220 = Math_fround($134 * $216);
 $221 = Math_fround($219 + $220);
 $222 = Math_fround($6 * $128);
 $223 = Math_fround($11 * $131);
 $224 = Math_fround($222 + $223);
 $225 = Math_fround($16 * $134);
 $226 = Math_fround($225 + $224);
 $227 = !($221 > Math_fround(0.0));
 $228 = !($226 >= $221);
 $or$cond2 = $227 & $228;
 if (!($or$cond2)) {
  $$0 = $flags$1;
  STACKTOP = sp;return ($$0|0);
 }
 $229 = Math_fround($221 / $226);
 $230 = Math_fround($6 * $229);
 $231 = Math_fround($11 * $229);
 $232 = Math_fround($16 * $229);
 $233 = Math_fround($209 + $230);
 $234 = Math_fround($212 + $231);
 $235 = Math_fround($215 + $232);
 $236 = Math_fround($208 - $233);
 $237 = Math_fround($211 - $234);
 $238 = Math_fround($214 - $235);
 $239 = Math_fround(HEAPF32[$e0>>2]);
 $240 = Math_fround($239 * $236);
 $241 = Math_fround(HEAPF32[$27>>2]);
 $242 = Math_fround($241 * $237);
 $243 = Math_fround($240 + $242);
 $244 = Math_fround(HEAPF32[$31>>2]);
 $245 = Math_fround($244 * $238);
 $246 = Math_fround($245 + $243);
 $247 = Math_fround(HEAPF32[$e1>>2]);
 $248 = Math_fround($236 * $247);
 $249 = Math_fround(HEAPF32[$37>>2]);
 $250 = Math_fround($237 * $249);
 $251 = Math_fround($248 + $250);
 $252 = Math_fround(HEAPF32[$41>>2]);
 $253 = Math_fround($238 * $252);
 $254 = Math_fround($251 + $253);
 $255 = Math_fround($44 * $254);
 $256 = Math_fround($c$0 * $246);
 $257 = Math_fround($255 - $256);
 $258 = Math_fround($44 * $246);
 $259 = Math_fround($a$0 * $254);
 $260 = Math_fround($258 - $259);
 $261 = Math_fround($68 * Math_fround(9.99999974737875163555E-5));
 $262 = Math_fround(-$261);
 $263 = !($257 >= $262);
 $264 = !($260 >= $262);
 $or$cond3 = $263 | $264;
 if ($or$cond3) {
  $$0 = $flags$1;
  STACKTOP = sp;return ($$0|0);
 }
 $265 = Math_fround($257 + $260);
 $266 = Math_fround($68 + $261);
 $267 = !($265 <= $266);
 if ($267) {
  $$0 = $flags$1;
  STACKTOP = sp;return ($$0|0);
 }
 $268 = Math_fround(Math_fround(1.0) / $140);
 $269 = Math_fround($221 * $268);
 $270 = Math_fround(-$269);
 HEAPF32[$distOldToSurface>>2] = $270;
 $271 = Math_fround($128 * $268);
 $272 = Math_fround($131 * $268);
 $273 = Math_fround($134 * $268);
 HEAPF32[$surfaceNormal>>2] = $271;
 $274 = (($surfaceNormal) + 4|0);
 HEAPF32[$274>>2] = $272;
 $275 = (($surfaceNormal) + 8|0);
 HEAPF32[$275>>2] = $273;
 $276 = Math_fround(HEAPF32[$oldPos>>2]);
 HEAPF32[$surfacePos>>2] = $276;
 $277 = Math_fround(HEAPF32[$9>>2]);
 $278 = (($surfacePos) + 4|0);
 HEAPF32[$278>>2] = $277;
 $279 = Math_fround(HEAPF32[$14>>2]);
 $280 = (($surfacePos) + 8|0);
 HEAPF32[$280>>2] = $279;
 HEAPF32[$ccTime>>2] = $229;
 $281 = $flags$1 | 8;
 $$0 = $281;
 STACKTOP = sp;return ($$0|0);
}
function __Z19updateCollShapeDataRN5physx19PxsParticleCollDataERbjffRKNS_6PxVec3ES5_S5_S5_RKNS_11PxTransformE($collData,$hasCC,$collFlags,$ccTime,$distOldToSurface,$surfaceNormal,$surfacePos,$proxSurfaceNormal,$proxSurfacePos,$shape2World) {
 $collData = $collData|0;
 $hasCC = $hasCC|0;
 $collFlags = $collFlags|0;
 $ccTime = Math_fround($ccTime);
 $distOldToSurface = Math_fround($distOldToSurface);
 $surfaceNormal = $surfaceNormal|0;
 $surfacePos = $surfacePos|0;
 $proxSurfaceNormal = $proxSurfaceNormal|0;
 $proxSurfacePos = $proxSurfacePos|0;
 $shape2World = $shape2World|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAPF32[$0>>2] = $distOldToSurface;
 $1 = $collFlags & 8;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($collData) + 44|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 > $ccTime;
  if ($5) {
   $6 = Math_fround(HEAPF32[$surfaceNormal>>2]);
   $7 = (($collData) + 144|0);
   HEAPF32[$7>>2] = $6;
   $8 = (($surfaceNormal) + 4|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = (($collData) + 148|0);
   HEAPF32[$10>>2] = $9;
   $11 = (($surfaceNormal) + 8|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = (($collData) + 152|0);
   HEAPF32[$13>>2] = $12;
   $14 = Math_fround(HEAPF32[$surfacePos>>2]);
   $15 = (($collData) + 160|0);
   HEAPF32[$15>>2] = $14;
   $16 = (($surfacePos) + 4|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = (($collData) + 164|0);
   HEAPF32[$18>>2] = $17;
   $19 = (($surfacePos) + 8|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = (($collData) + 168|0);
   HEAPF32[$21>>2] = $20;
   HEAPF32[$3>>2] = $ccTime;
   $22 = (($collData) + 124|0);
   HEAP32[$22>>2] = 8;
  }
  __Z17setConstraintDataRN5physx19PxsParticleCollDataERKfRKNS_6PxVec3ES6_RKNS_11PxTransformE($collData,$0,$surfaceNormal,$surfacePos,$shape2World);
  HEAP8[$hasCC>>0] = 1;
  STACKTOP = sp;return;
 }
 $23 = HEAP8[$hasCC>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 $25 = $collFlags & 32;
 $26 = ($25|0)==(0);
 if (!($26)) {
  __Z17setConstraintDataRN5physx19PxsParticleCollDataERKfRKNS_6PxVec3ES6_RKNS_11PxTransformE($collData,$0,$proxSurfaceNormal,$proxSurfacePos,$shape2World);
  $27 = (($collData) + 124|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 | 32;
  HEAP32[$27>>2] = $29;
 }
 $30 = $collFlags & 16;
 $31 = ($30|0)==(0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = Math_fround(HEAPF32[$surfaceNormal>>2]);
 $33 = (($collData) + 144|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($32 + $34);
 HEAPF32[$33>>2] = $35;
 $36 = (($surfaceNormal) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($collData) + 148|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($37 + $39);
 HEAPF32[$38>>2] = $40;
 $41 = (($surfaceNormal) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($collData) + 152|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($42 + $44);
 HEAPF32[$43>>2] = $45;
 $46 = Math_fround(HEAPF32[$surfacePos>>2]);
 $47 = (($collData) + 160|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($46 + $48);
 HEAPF32[$47>>2] = $49;
 $50 = (($surfacePos) + 4|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($collData) + 164|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($51 + $53);
 HEAPF32[$52>>2] = $54;
 $55 = (($surfacePos) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($collData) + 168|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($56 + $58);
 HEAPF32[$57>>2] = $59;
 $60 = (($collData) + 172|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 + Math_fround(1.0));
 HEAPF32[$60>>2] = $62;
 $63 = (($collData) + 124|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 | 16;
 HEAP32[$63>>2] = $65;
 STACKTOP = sp;return;
}
function __ZN5physx26collideCellsWithStaticMeshEPNS_19PxsParticleCollDataERKNS_21PxsFluidLocalCellHashERKNS_2Gu13GeometryUnionERKNS_11PxTransformESB_fffRKNS_6PxVec3E($collData,$localCellHash,$meshShape,$world2Shape,$shape2World,$0,$1,$proxRadius,$2) {
 $collData = $collData|0;
 $localCellHash = $localCellHash|0;
 $meshShape = $meshShape|0;
 $world2Shape = $world2Shape|0;
 $shape2World = $shape2World|0;
 $0 = Math_fround($0);
 $1 = Math_fround($1);
 $proxRadius = Math_fround($proxRadius);
 $2 = $2|0;
 var $$lcssa = Math_fround(0), $$lcssa1 = Math_fround(0), $$lcssa2 = Math_fround(0), $$lcssa3 = Math_fround(0), $$lcssa4 = Math_fround(0), $$lcssa5 = Math_fround(0), $$pre = 0, $$sum = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0;
 var $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0;
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$023 = 0, $callback = 0, $cellBounds = 0, $collDataIndexIt$05$i$i = 0, $exitcond$i$i = 0, $i$04$i$i = 0, $it$06 = 0, $meshScaling = 0, $or$cond = 0, $or$cond38 = 0, $or$cond39 = 0, $or$cond40 = 0, $or$cond40$not = 0, $or$cond41 = 0, $phitmp$i = 0, $shapeBounds = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $shapeBounds = sp + 288|0;
 $3 = sp;
 $4 = sp + 48|0;
 $meshScaling = sp + 80|0;
 $cellBounds = sp + 152|0;
 $callback = sp + 176|0;
 $5 = (($meshShape) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($world2Shape) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($world2Shape) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($world2Shape) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($8 * Math_fround(-2.0));
 $14 = Math_fround($10 * Math_fround(-2.0));
 $15 = Math_fround($12 * Math_fround(-2.0));
 $16 = (($world2Shape) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $17);
 $19 = Math_fround($18 + Math_fround(-0.5));
 $20 = Math_fround(HEAPF32[$world2Shape>>2]);
 $21 = Math_fround($13 * $20);
 $22 = (($world2Shape) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($14 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($world2Shape) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($15 * $27);
 $29 = Math_fround($25 + $28);
 $30 = Math_fround($13 * $19);
 $31 = Math_fround($15 * $23);
 $32 = Math_fround($14 * $27);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($17 * $33);
 $35 = Math_fround($30 - $34);
 $36 = Math_fround($20 * $29);
 $37 = Math_fround($36 + $35);
 $38 = Math_fround($14 * $19);
 $39 = Math_fround($13 * $27);
 $40 = Math_fround($15 * $20);
 $41 = Math_fround($39 - $40);
 $42 = Math_fround($17 * $41);
 $43 = Math_fround($38 - $42);
 $44 = Math_fround($23 * $29);
 $45 = Math_fround($44 + $43);
 $46 = Math_fround($15 * $19);
 $47 = Math_fround($14 * $20);
 $48 = Math_fround($13 * $23);
 $49 = Math_fround($47 - $48);
 $50 = Math_fround($17 * $49);
 $51 = Math_fround($46 - $50);
 $52 = Math_fround($27 * $29);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround(-$20);
 $55 = Math_fround(-$23);
 $56 = Math_fround(-$27);
 HEAPF32[$4>>2] = $54;
 $57 = (($4) + 4|0);
 HEAPF32[$57>>2] = $55;
 $58 = (($4) + 8|0);
 HEAPF32[$58>>2] = $56;
 $59 = (($4) + 12|0);
 HEAPF32[$59>>2] = $17;
 $60 = (($4) + 16|0);
 HEAPF32[$60>>2] = $37;
 $61 = (($4) + 20|0);
 HEAPF32[$61>>2] = $45;
 $62 = (($4) + 24|0);
 HEAPF32[$62>>2] = $53;
 $63 = (($meshShape) + 4|0);
 __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($3,$4,$63);
 $64 = (($6) + 128|0);
 __ZN5physx2Cm9transformERKNS0_8Matrix34ERKNS_9PxBounds3E($shapeBounds,$3,$64);
 $65 = Math_fround(HEAPF32[$63>>2]);
 $66 = $65 == Math_fround(1.0);
 if ($66) {
  $67 = (($meshShape) + 8|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = $68 == Math_fround(1.0);
  if ($69) {
   $70 = (($meshShape) + 12|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = $71 == Math_fround(1.0);
   $254 = $72;
  } else {
   $254 = 0;
  }
 } else {
  $254 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $73 = (($meshScaling) + 4|0);
 HEAPF32[$73>>2] = Math_fround(0.0);
 $74 = (($meshScaling) + 8|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($meshScaling) + 12|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($meshScaling) + 16|0);
 HEAPF32[$76>>2] = Math_fround(1.0);
 $77 = (($meshScaling) + 20|0);
 HEAPF32[$77>>2] = Math_fround(0.0);
 $78 = (($meshScaling) + 24|0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = (($meshScaling) + 28|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($meshScaling) + 32|0);
 HEAPF32[$80>>2] = Math_fround(1.0);
 $81 = (($meshScaling) + 36|0);
 HEAPF32[$81>>2] = Math_fround(1.0);
 $82 = (($meshScaling) + 40|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = (($meshScaling) + 44|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($meshScaling) + 48|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 $85 = (($meshScaling) + 52|0);
 HEAPF32[$85>>2] = Math_fround(1.0);
 $86 = (($meshScaling) + 56|0);
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = (($meshScaling) + 60|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($meshScaling) + 64|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($meshScaling) + 68|0);
 HEAPF32[$89>>2] = Math_fround(1.0);
 if (!($254)) {
  $90 = (($meshShape) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$63,$90);
 }
 $91 = (($localCellHash) + 8|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0);
 if ($93) {
  STACKTOP = sp;return;
 }
 $94 = (($localCellHash) + 12|0);
 $95 = (($cellBounds) + 4|0);
 $96 = (($cellBounds) + 8|0);
 $97 = (($cellBounds) + 12|0);
 $98 = (($cellBounds) + 16|0);
 $99 = (($cellBounds) + 20|0);
 $100 = (($localCellHash) + 4|0);
 $101 = Math_fround(HEAPF32[$shapeBounds>>2]);
 $102 = (($shapeBounds) + 12|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($shapeBounds) + 4|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($shapeBounds) + 16|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($shapeBounds) + 8|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($shapeBounds) + 20|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($callback) + 4|0);
 $113 = (($callback) + 8|0);
 $114 = (($callback) + 12|0);
 $115 = (($callback) + 16|0);
 $116 = (($callback) + 20|0);
 $117 = (($callback) + 24|0);
 $118 = (($callback) + 28|0);
 $119 = (($callback) + 32|0);
 $120 = (($callback) + 36|0);
 $121 = (($callback) + 40|0);
 $122 = (($callback) + 44|0);
 $123 = (($callback) + 48|0);
 $124 = (($callback) + 52|0);
 $125 = (($callback) + 56|0);
 $126 = (($callback) + 60|0);
 $127 = (($callback) + 64|0);
 $128 = (($callback) + 68|0);
 $129 = (($callback) + 72|0);
 $130 = (($callback) + 76|0);
 $131 = (($callback) + 80|0);
 $132 = (($callback) + 84|0);
 $133 = (($callback) + 88|0);
 $134 = (($callback) + 92|0);
 $135 = (($callback) + 96|0);
 $136 = (($callback) + 100|0);
 $137 = (($callback) + 104|0);
 $258 = $92;$c$023 = 0;
 while(1) {
  $138 = HEAP32[$94>>2]|0;
  $139 = ((($138) + ($c$023<<4)|0) + 8|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = ($140|0)==(-1);
  if ($141) {
   $257 = $258;
  } else {
   HEAPF32[$cellBounds>>2] = Math_fround(8.50705866596322149529E+37);
   HEAPF32[$95>>2] = Math_fround(8.50705866596322149529E+37);
   HEAPF32[$96>>2] = Math_fround(8.50705866596322149529E+37);
   HEAPF32[$97>>2] = Math_fround(-8.50705866596322149529E+37);
   HEAPF32[$98>>2] = Math_fround(-8.50705866596322149529E+37);
   HEAPF32[$99>>2] = Math_fround(-8.50705866596322149529E+37);
   $142 = HEAP32[$100>>2]|0;
   $143 = ((($138) + ($c$023<<4)|0) + 12|0);
   $144 = HEAP32[$143>>2]|0;
   $$sum = (($140) + ($144))|0;
   $145 = (($142) + ($$sum<<2)|0);
   $146 = ($140|0)==(0);
   if ($146) {
    $$lcssa = Math_fround(-8.50705866596322149529E+37);$$lcssa1 = Math_fround(-8.50705866596322149529E+37);$$lcssa2 = Math_fround(-8.50705866596322149529E+37);$$lcssa3 = Math_fround(8.50705866596322149529E+37);$$lcssa4 = Math_fround(8.50705866596322149529E+37);$$lcssa5 = Math_fround(8.50705866596322149529E+37);$206 = Math_fround(8.50705866596322149529E+37);$209 = Math_fround(8.50705866596322149529E+37);$212 = Math_fround(8.50705866596322149529E+37);$215 = Math_fround(-8.50705866596322149529E+37);$218 = Math_fround(-8.50705866596322149529E+37);$221 = Math_fround(-8.50705866596322149529E+37);
   } else {
    $147 = (($142) + ($144<<2)|0);
    $152 = Math_fround(8.50705866596322149529E+37);$157 = Math_fround(8.50705866596322149529E+37);$162 = Math_fround(8.50705866596322149529E+37);$165 = Math_fround(-8.50705866596322149529E+37);$168 = Math_fround(-8.50705866596322149529E+37);$171 = Math_fround(-8.50705866596322149529E+37);$176 = Math_fround(8.50705866596322149529E+37);$181 = Math_fround(8.50705866596322149529E+37);$186 = Math_fround(8.50705866596322149529E+37);$189 = Math_fround(-8.50705866596322149529E+37);$192 = Math_fround(-8.50705866596322149529E+37);$195 = Math_fround(-8.50705866596322149529E+37);$it$06 = $147;
    while(1) {
     $148 = HEAP32[$it$06>>2]|0;
     $149 = ((($collData) + (($148*176)|0)|0) + 48|0);
     $150 = Math_fround(HEAPF32[$149>>2]);
     $151 = $152 < $150;
     $153 = $151 ? $152 : $150;
     $154 = ((($collData) + (($148*176)|0)|0) + 52|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = $157 < $155;
     $158 = $156 ? $157 : $155;
     $159 = ((($collData) + (($148*176)|0)|0) + 56|0);
     $160 = Math_fround(HEAPF32[$159>>2]);
     $161 = $162 < $160;
     $163 = $161 ? $162 : $160;
     $164 = $165 > $150;
     $166 = $164 ? $165 : $150;
     $167 = $168 > $155;
     $169 = $167 ? $168 : $155;
     $170 = $171 > $160;
     $172 = $170 ? $171 : $160;
     $173 = ((($collData) + (($148*176)|0)|0) + 64|0);
     $174 = Math_fround(HEAPF32[$173>>2]);
     $175 = $176 < $174;
     $177 = $175 ? $176 : $174;
     $178 = ((($collData) + (($148*176)|0)|0) + 68|0);
     $179 = Math_fround(HEAPF32[$178>>2]);
     $180 = $181 < $179;
     $182 = $180 ? $181 : $179;
     $183 = ((($collData) + (($148*176)|0)|0) + 72|0);
     $184 = Math_fround(HEAPF32[$183>>2]);
     $185 = $186 < $184;
     $187 = $185 ? $186 : $184;
     $188 = $189 > $174;
     $190 = $188 ? $189 : $174;
     $191 = $192 > $179;
     $193 = $191 ? $192 : $179;
     $194 = $195 > $184;
     $196 = $194 ? $195 : $184;
     $197 = (($it$06) + 4|0);
     $198 = ($197|0)==($145|0);
     if ($198) {
      break;
     } else {
      $152 = $153;$157 = $158;$162 = $163;$165 = $166;$168 = $169;$171 = $172;$176 = $177;$181 = $182;$186 = $187;$189 = $190;$192 = $193;$195 = $196;$it$06 = $197;
     }
    }
    HEAPF32[$cellBounds>>2] = $153;
    HEAPF32[$95>>2] = $158;
    HEAPF32[$96>>2] = $163;
    HEAPF32[$97>>2] = $166;
    HEAPF32[$98>>2] = $169;
    HEAPF32[$99>>2] = $172;
    $$lcssa = $196;$$lcssa1 = $193;$$lcssa2 = $190;$$lcssa3 = $187;$$lcssa4 = $182;$$lcssa5 = $177;$206 = $153;$209 = $158;$212 = $163;$215 = $166;$218 = $169;$221 = $172;
   }
   $199 = Math_fround($$lcssa5 - $proxRadius);
   $200 = Math_fround($$lcssa4 - $proxRadius);
   $201 = Math_fround($$lcssa3 - $proxRadius);
   $202 = Math_fround($$lcssa2 + $proxRadius);
   $203 = Math_fround($$lcssa1 + $proxRadius);
   $204 = Math_fround($$lcssa + $proxRadius);
   $205 = $206 < $199;
   $207 = $205 ? $206 : $199;
   $208 = $209 < $200;
   $210 = $208 ? $209 : $200;
   $211 = $212 < $201;
   $213 = $211 ? $212 : $201;
   HEAPF32[$cellBounds>>2] = $207;
   HEAPF32[$95>>2] = $210;
   HEAPF32[$96>>2] = $213;
   $214 = $215 > $202;
   $216 = $214 ? $215 : $202;
   $217 = $218 > $203;
   $219 = $217 ? $218 : $203;
   $220 = $221 > $204;
   $222 = $220 ? $221 : $204;
   HEAPF32[$97>>2] = $216;
   HEAPF32[$98>>2] = $219;
   HEAPF32[$99>>2] = $222;
   $223 = $101 > $216;
   $224 = $207 > $103;
   $or$cond = $223 | $224;
   $225 = $105 > $219;
   $or$cond38 = $or$cond | $225;
   $226 = $210 > $107;
   $or$cond39 = $or$cond38 | $226;
   $227 = $109 > $222;
   $or$cond40 = $or$cond39 | $227;
   $or$cond40$not = $or$cond40 ^ 1;
   $phitmp$i = !($213 > $111);
   $or$cond41 = $phitmp$i & $or$cond40$not;
   if ($or$cond41) {
    $228 = (($142) + ($144<<2)|0);
    HEAP32[$112>>2] = 2;
    HEAP32[$callback>>2] = ((494280 + 8|0));
    HEAP32[$113>>2] = $collData;
    HEAP32[$114>>2] = $228;
    HEAP32[$115>>2] = $140;
    HEAP32[$116>>2] = $6;
    $229 = Math_fround(HEAPF32[$meshScaling>>2]);
    HEAPF32[$117>>2] = $229;
    $230 = Math_fround(HEAPF32[$73>>2]);
    HEAPF32[$118>>2] = $230;
    $231 = Math_fround(HEAPF32[$74>>2]);
    HEAPF32[$119>>2] = $231;
    $232 = Math_fround(HEAPF32[$75>>2]);
    HEAPF32[$120>>2] = $232;
    $233 = Math_fround(HEAPF32[$76>>2]);
    HEAPF32[$121>>2] = $233;
    $234 = Math_fround(HEAPF32[$77>>2]);
    HEAPF32[$122>>2] = $234;
    $235 = Math_fround(HEAPF32[$78>>2]);
    HEAPF32[$123>>2] = $235;
    $236 = Math_fround(HEAPF32[$79>>2]);
    HEAPF32[$124>>2] = $236;
    $237 = Math_fround(HEAPF32[$80>>2]);
    HEAPF32[$125>>2] = $237;
    $238 = Math_fround(HEAPF32[$81>>2]);
    HEAPF32[$126>>2] = $238;
    $239 = Math_fround(HEAPF32[$82>>2]);
    HEAPF32[$127>>2] = $239;
    $240 = Math_fround(HEAPF32[$83>>2]);
    HEAPF32[$128>>2] = $240;
    $241 = Math_fround(HEAPF32[$84>>2]);
    HEAPF32[$129>>2] = $241;
    $242 = Math_fround(HEAPF32[$85>>2]);
    HEAPF32[$130>>2] = $242;
    $243 = Math_fround(HEAPF32[$86>>2]);
    HEAPF32[$131>>2] = $243;
    $244 = Math_fround(HEAPF32[$87>>2]);
    HEAPF32[$132>>2] = $244;
    $245 = Math_fround(HEAPF32[$88>>2]);
    HEAPF32[$133>>2] = $245;
    $246 = Math_fround(HEAPF32[$89>>2]);
    HEAPF32[$134>>2] = $246;
    HEAPF32[$135>>2] = $proxRadius;
    HEAP32[$136>>2] = 0;
    HEAP32[$137>>2] = $shape2World;
    if (!($146)) {
     $collDataIndexIt$05$i$i = $228;$i$04$i$i = 0;
     while(1) {
      $247 = HEAP32[$collDataIndexIt$05$i$i>>2]|0;
      $248 = ((($collData) + (($247*176)|0)|0) + 144|0);
      HEAPF32[$248>>2] = Math_fround(0.0);
      $249 = ((($collData) + (($247*176)|0)|0) + 148|0);
      HEAPF32[$249>>2] = Math_fround(0.0);
      $250 = ((($collData) + (($247*176)|0)|0) + 152|0);
      HEAPF32[$250>>2] = Math_fround(0.0);
      $251 = ((($collData) + (($247*176)|0)|0) + 160|0);
      $252 = (($i$04$i$i) + 1)|0;
      $253 = (($collDataIndexIt$05$i$i) + 4|0);
      $exitcond$i$i = ($252|0)==($140|0);
      ;HEAP32[$251+0>>2]=0|0;HEAP32[$251+4>>2]=0|0;HEAP32[$251+8>>2]=0|0;HEAP32[$251+12>>2]=0|0;
      if ($exitcond$i$i) {
       break;
      } else {
       $collDataIndexIt$05$i$i = $253;$i$04$i$i = $252;
      }
     }
    }
    __Z14testBoundsMeshRKN5physx2Gu24InternalTriangleMeshDataERKNS_11PxTransformERKNS_2Cm23FastVertex2ShapeScalingEbRKNS_9PxBounds3ER26PxcContactCellMeshCallback($6,$world2Shape,$meshScaling,$254,$cellBounds,$callback);
    $$pre = HEAP32[$91>>2]|0;
    $257 = $$pre;
   } else {
    $257 = $258;
   }
  }
  $255 = (($c$023) + 1)|0;
  $256 = ($255>>>0)<($257>>>0);
  if ($256) {
   $258 = $257;$c$023 = $255;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm9transformERKNS0_8Matrix34ERKNS_9PxBounds3E($agg$result,$matrix,$bounds) {
 $agg$result = $agg$result|0;
 $matrix = $matrix|0;
 $bounds = $bounds|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0;
 var $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$bounds>>2]);
 $1 = (($bounds) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $0 > $2;
 if ($3) {
  HEAPF32[$agg$result>>2] = $0;
  $4 = (($agg$result) + 4|0);
  $5 = (($bounds) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  HEAPF32[$4>>2] = $6;
  $7 = (($agg$result) + 8|0);
  $8 = (($bounds) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$7>>2] = $9;
  $10 = (($agg$result) + 12|0);
  HEAPF32[$10>>2] = $2;
  $11 = (($agg$result) + 16|0);
  $12 = (($bounds) + 16|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $13;
  $14 = (($agg$result) + 20|0);
  $15 = (($bounds) + 20|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$14>>2] = $16;
  STACKTOP = sp;return;
 } else {
  $17 = Math_fround(HEAPF32[$matrix>>2]);
  $18 = (($matrix) + 4|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($matrix) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($matrix) + 12|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($matrix) + 16|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($matrix) + 20|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($matrix) + 24|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($matrix) + 28|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($matrix) + 32|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($0 + $2);
  $35 = (($bounds) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($bounds) + 16|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround($36 + $38);
  $40 = (($bounds) + 8|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($bounds) + 20|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($41 + $43);
  $45 = Math_fround($34 * Math_fround(0.5));
  $46 = Math_fround($39 * Math_fround(0.5));
  $47 = Math_fround($44 * Math_fround(0.5));
  $48 = Math_fround($45 * $17);
  $49 = Math_fround($45 * $19);
  $50 = Math_fround($45 * $21);
  $51 = Math_fround($46 * $23);
  $52 = Math_fround($46 * $25);
  $53 = Math_fround($46 * $27);
  $54 = Math_fround($48 + $51);
  $55 = Math_fround($49 + $52);
  $56 = Math_fround($50 + $53);
  $57 = Math_fround($47 * $29);
  $58 = Math_fround($47 * $31);
  $59 = Math_fround($47 * $33);
  $60 = Math_fround($54 + $57);
  $61 = Math_fround($55 + $58);
  $62 = Math_fround($56 + $59);
  $63 = (($matrix) + 36|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($60 + $64);
  $66 = (($matrix) + 40|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($61 + $67);
  $69 = (($matrix) + 44|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($62 + $70);
  $72 = Math_fround($2 - $0);
  $73 = Math_fround($38 - $36);
  $74 = Math_fround($43 - $41);
  $75 = Math_fround($72 * Math_fround(0.5));
  $76 = Math_fround($73 * Math_fround(0.5));
  $77 = Math_fround($74 * Math_fround(0.5));
  $78 = Math_fround($75 * $17);
  $79 = Math_fround($75 * $19);
  $80 = Math_fround($75 * $21);
  $81 = Math_fround($23 * $76);
  $82 = Math_fround($25 * $76);
  $83 = Math_fround($27 * $76);
  $84 = Math_fround($29 * $77);
  $85 = Math_fround($31 * $77);
  $86 = Math_fround($33 * $77);
  $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($78)))));
  $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($81)))));
  $87 = Math_fround($fabsf$i$i4$i + $fabsf$i$i5$i);
  $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($84)))));
  $88 = Math_fround($87 + $fabsf$i$i6$i);
  $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($79)))));
  $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($82)))));
  $89 = Math_fround($fabsf$i$i7$i + $fabsf$i$i8$i);
  $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($85)))));
  $90 = Math_fround($89 + $fabsf$i$i3$i);
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($80)))));
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($83)))));
  $91 = Math_fround($fabsf$i$i2$i + $fabsf$i$i1$i);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($86)))));
  $92 = Math_fround($91 + $fabsf$i$i$i);
  $93 = Math_fround($65 - $88);
  $94 = Math_fround($68 - $90);
  $95 = Math_fround($71 - $92);
  $96 = Math_fround($65 + $88);
  $97 = Math_fround($68 + $90);
  $98 = Math_fround($71 + $92);
  HEAPF32[$agg$result>>2] = $93;
  $99 = (($agg$result) + 4|0);
  HEAPF32[$99>>2] = $94;
  $100 = (($agg$result) + 8|0);
  HEAPF32[$100>>2] = $95;
  $101 = (($agg$result) + 12|0);
  HEAPF32[$101>>2] = $96;
  $102 = (($agg$result) + 16|0);
  HEAPF32[$102>>2] = $97;
  $103 = (($agg$result) + 20|0);
  HEAPF32[$103>>2] = $98;
  STACKTOP = sp;return;
 }
}
function __ZN26PxcContactCellMeshCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx21collideWithStaticMeshEjPNS_19PxsParticleCollDataEPNS_27PxsFluidParticleOpcodeCacheERKNS_2Gu13GeometryUnionERKNS_11PxTransformESA_fff($numParticles,$collData,$opcodeCaches,$meshShape,$world2Shape,$shape2World,$0,$collisionRange,$proxRadius) {
 $numParticles = $numParticles|0;
 $collData = $collData|0;
 $opcodeCaches = $opcodeCaches|0;
 $meshShape = $meshShape|0;
 $world2Shape = $world2Shape|0;
 $shape2World = $shape2World|0;
 $0 = Math_fround($0);
 $collisionRange = Math_fround($collisionRange);
 $proxRadius = Math_fround($proxRadius);
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0;
 var $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0;
 var $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = Math_fround(0);
 var $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0);
 var $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0);
 var $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0;
 var $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0);
 var $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0);
 var $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bounds = 0, $cachedBounds = 0, $cachedTriangleBuffer = 0, $i = 0, $j$052 = 0, $j$052$us = 0, $meshScaling = 0, $numTriangles = 0, $phitmp = 0, $phitmp57 = 0, $phitmp58 = 0, $phitmp59 = 0, $phitmp60 = 0;
 var $phitmp61 = 0, $quantizationParams = 0, $storemerge53 = 0, $triangleIndexIt$051 = 0, $triangleIndexIt$051$us = 0, $triangleVerts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 496|0;
 $meshScaling = sp + 424|0;
 $quantizationParams = sp;
 $cachedTriangleBuffer = sp + 8|0;
 $i = sp + 44|0;
 $bounds = sp + 48|0;
 $numTriangles = sp + 72|0;
 $triangleVerts = sp + 76|0;
 $cachedBounds = sp + 400|0;
 $1 = (($meshShape) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 == Math_fround(1.0);
 if ($3) {
  $4 = (($meshShape) + 8|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = $5 == Math_fround(1.0);
  if ($6) {
   $7 = (($meshShape) + 12|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = $8 == Math_fround(1.0);
   $269 = $9;
  } else {
   $269 = 0;
  }
 } else {
  $269 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $10 = (($meshScaling) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($meshScaling) + 8|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($meshScaling) + 12|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($meshScaling) + 16|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($meshScaling) + 20|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($meshScaling) + 24|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($meshScaling) + 28|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($meshScaling) + 32|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($meshScaling) + 36|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($meshScaling) + 40|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($meshScaling) + 44|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($meshScaling) + 48|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($meshScaling) + 52|0);
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($meshScaling) + 56|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($meshScaling) + 60|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($meshScaling) + 64|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($meshScaling) + 68|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 if (!($269)) {
  $27 = (($meshShape) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$1,$27);
 }
 $28 = Math_fround($collisionRange * Math_fround(4.0));
 $29 = Math_fround($28 + $proxRadius);
 $30 = Math_fround(Math_fround(1.0) / $29);
 $31 = Math_fround($30 * Math_fround(254.0));
 $32 = (($quantizationParams) + 4|0);
 HEAPF32[$32>>2] = $31;
 $33 = Math_fround($29 * Math_fround(0.00393700785934925079346));
 HEAPF32[$quantizationParams>>2] = $33;
 $34 = (($meshShape) + 40|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37>>>0)<(65536);
 HEAP32[$i>>2] = 0;
 $39 = ($numParticles|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($bounds) + 4|0);
 $41 = (($bounds) + 8|0);
 $42 = (($bounds) + 12|0);
 $43 = (($bounds) + 16|0);
 $44 = (($bounds) + 20|0);
 $45 = (($35) + 12|0);
 $46 = (($35) + 8|0);
 $47 = (($triangleVerts) + 4|0);
 $48 = (($triangleVerts) + 8|0);
 $49 = (($triangleVerts) + 12|0);
 $50 = (($triangleVerts) + 16|0);
 $51 = (($triangleVerts) + 20|0);
 $52 = (($triangleVerts) + 24|0);
 $53 = (($triangleVerts) + 28|0);
 $54 = (($triangleVerts) + 32|0);
 $55 = (($triangleVerts) + 36|0);
 $56 = (($triangleVerts) + 40|0);
 $57 = (($triangleVerts) + 44|0);
 $58 = (($triangleVerts) + 48|0);
 $59 = (($triangleVerts) + 52|0);
 $60 = (($triangleVerts) + 56|0);
 $61 = (($triangleVerts) + 60|0);
 $62 = (($triangleVerts) + 64|0);
 $63 = (($triangleVerts) + 68|0);
 $64 = (($triangleVerts) + 72|0);
 $65 = (($triangleVerts) + 76|0);
 $66 = (($triangleVerts) + 80|0);
 $67 = (($triangleVerts) + 84|0);
 $68 = (($triangleVerts) + 88|0);
 $69 = (($triangleVerts) + 92|0);
 $70 = (($triangleVerts) + 96|0);
 $71 = (($triangleVerts) + 100|0);
 $72 = (($triangleVerts) + 104|0);
 $73 = Math_fround($proxRadius * Math_fround(1.5));
 $74 = (($cachedBounds) + 4|0);
 $75 = (($cachedBounds) + 8|0);
 $76 = (($cachedBounds) + 12|0);
 $77 = (($cachedBounds) + 16|0);
 $78 = (($cachedBounds) + 20|0);
 $79 = (($triangleVerts) + 4|0);
 $80 = (($triangleVerts) + 8|0);
 $81 = (($triangleVerts) + 12|0);
 $82 = (($triangleVerts) + 16|0);
 $83 = (($triangleVerts) + 20|0);
 $84 = (($triangleVerts) + 24|0);
 $85 = (($triangleVerts) + 28|0);
 $86 = (($triangleVerts) + 32|0);
 $87 = (($triangleVerts) + 36|0);
 $88 = (($triangleVerts) + 40|0);
 $89 = (($triangleVerts) + 44|0);
 $90 = (($triangleVerts) + 48|0);
 $91 = (($triangleVerts) + 52|0);
 $92 = (($triangleVerts) + 56|0);
 $93 = (($triangleVerts) + 60|0);
 $94 = (($triangleVerts) + 64|0);
 $95 = (($triangleVerts) + 68|0);
 $96 = (($triangleVerts) + 72|0);
 $97 = (($triangleVerts) + 76|0);
 $98 = (($triangleVerts) + 80|0);
 $99 = (($triangleVerts) + 84|0);
 $100 = (($triangleVerts) + 88|0);
 $101 = (($triangleVerts) + 92|0);
 $102 = (($triangleVerts) + 96|0);
 $103 = (($triangleVerts) + 100|0);
 $104 = (($triangleVerts) + 104|0);
 $storemerge53 = 0;
 while(1) {
  $105 = (($opcodeCaches) + ($storemerge53<<5)|0);
  $106 = ((($collData) + (($storemerge53*176)|0)|0) + 64|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = Math_fround($107 - $proxRadius);
  $109 = ((($collData) + (($storemerge53*176)|0)|0) + 68|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = Math_fround($110 - $proxRadius);
  $112 = ((($collData) + (($storemerge53*176)|0)|0) + 72|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($113 - $proxRadius);
  $115 = Math_fround($107 + $proxRadius);
  $116 = Math_fround($110 + $proxRadius);
  $117 = Math_fround($113 + $proxRadius);
  $118 = ((($collData) + (($storemerge53*176)|0)|0) + 48|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = $108 < $119;
  $121 = $120 ? $108 : $119;
  $122 = ((($collData) + (($storemerge53*176)|0)|0) + 52|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = $111 < $123;
  $125 = $124 ? $111 : $123;
  $126 = ((($collData) + (($storemerge53*176)|0)|0) + 56|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = $114 < $127;
  $129 = $128 ? $114 : $127;
  HEAPF32[$bounds>>2] = $121;
  HEAPF32[$40>>2] = $125;
  HEAPF32[$41>>2] = $129;
  $130 = $115 > $119;
  $131 = $130 ? $115 : $119;
  $132 = $116 > $123;
  $133 = $132 ? $116 : $123;
  $134 = $117 > $127;
  $135 = $134 ? $117 : $127;
  HEAPF32[$42>>2] = $131;
  HEAPF32[$43>>2] = $133;
  HEAPF32[$44>>2] = $135;
  HEAP32[$numTriangles>>2] = 0;
  $136 = ((($collData) + (($storemerge53*176)|0)|0) + 62|0);
  $137 = (__ZNK5physx27PxsFluidParticleOpcodeCache4readERtRjPjRKNS_9PxBounds3ERKNS0_18QuantizationParamsEPKNS_2Gu13GeometryUnionEb($105,$136,$numTriangles,$cachedTriangleBuffer,$bounds,$quantizationParams,$meshShape,$38)|0);
  do {
   if ($137) {
    $138 = HEAP32[$numTriangles>>2]|0;
    $139 = ($138|0)==(0);
    if (!($139)) {
     $140 = HEAP32[$45>>2]|0;
     $141 = $140;
     $142 = HEAP32[$46>>2]|0;
     $143 = $142;
     if ($38) {
      $j$052$us = 0;$triangleIndexIt$051$us = $cachedTriangleBuffer;
      while(1) {
       $144 = ($j$052$us*3)|0;
       $145 = (($144) + 1)|0;
       $146 = (($144) + 2)|0;
       $147 = HEAP32[$triangleIndexIt$051$us>>2]|0;
       $148 = ($147*6)|0;
       $149 = (($148) + ($141))|0;
       $150 = $149;
       $151 = HEAP16[$150>>1]|0;
       $152 = $151&65535;
       $153 = (($150) + 2|0);
       $154 = HEAP16[$153>>1]|0;
       $155 = $154&65535;
       $156 = (($150) + 4|0);
       $157 = HEAP16[$156>>1]|0;
       $158 = $157&65535;
       $phitmp59 = ($152*12)|0;
       $phitmp60 = ($155*12)|0;
       $phitmp61 = ($158*12)|0;
       $159 = (($phitmp59) + ($143))|0;
       $160 = $159;
       $161 = (($phitmp60) + ($143))|0;
       $162 = $161;
       $163 = (($phitmp61) + ($143))|0;
       $164 = $163;
       $165 = Math_fround(HEAPF32[$160>>2]);
       $166 = (($triangleVerts) + (($144*12)|0)|0);
       HEAPF32[$166>>2] = $165;
       $167 = (($160) + 4|0);
       $168 = Math_fround(HEAPF32[$167>>2]);
       $169 = ((($triangleVerts) + (($144*12)|0)|0) + 4|0);
       HEAPF32[$169>>2] = $168;
       $170 = (($160) + 8|0);
       $171 = Math_fround(HEAPF32[$170>>2]);
       $172 = ((($triangleVerts) + (($144*12)|0)|0) + 8|0);
       HEAPF32[$172>>2] = $171;
       $173 = Math_fround(HEAPF32[$162>>2]);
       $174 = (($triangleVerts) + (($145*12)|0)|0);
       HEAPF32[$174>>2] = $173;
       $175 = (($162) + 4|0);
       $176 = Math_fround(HEAPF32[$175>>2]);
       $177 = ((($triangleVerts) + (($145*12)|0)|0) + 4|0);
       HEAPF32[$177>>2] = $176;
       $178 = (($162) + 8|0);
       $179 = Math_fround(HEAPF32[$178>>2]);
       $180 = ((($triangleVerts) + (($145*12)|0)|0) + 8|0);
       HEAPF32[$180>>2] = $179;
       $181 = Math_fround(HEAPF32[$164>>2]);
       $182 = (($triangleVerts) + (($146*12)|0)|0);
       HEAPF32[$182>>2] = $181;
       $183 = (($164) + 4|0);
       $184 = Math_fround(HEAPF32[$183>>2]);
       $185 = ((($triangleVerts) + (($146*12)|0)|0) + 4|0);
       HEAPF32[$185>>2] = $184;
       $186 = (($164) + 8|0);
       $187 = Math_fround(HEAPF32[$186>>2]);
       $188 = ((($triangleVerts) + (($146*12)|0)|0) + 8|0);
       HEAPF32[$188>>2] = $187;
       $189 = (($j$052$us) + 1)|0;
       $190 = (($triangleIndexIt$051$us) + 4|0);
       $191 = ($189>>>0)<($138>>>0);
       if ($191) {
        $j$052$us = $189;$triangleIndexIt$051$us = $190;
       } else {
        break;
       }
      }
     } else {
      $j$052 = 0;$triangleIndexIt$051 = $cachedTriangleBuffer;
      while(1) {
       $192 = ($j$052*3)|0;
       $193 = (($192) + 1)|0;
       $194 = (($192) + 2)|0;
       $195 = HEAP32[$triangleIndexIt$051>>2]|0;
       $196 = ($195*12)|0;
       $197 = (($196) + ($141))|0;
       $198 = $197;
       $199 = HEAP32[$198>>2]|0;
       $200 = (($198) + 4|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = (($198) + 8|0);
       $203 = HEAP32[$202>>2]|0;
       $phitmp = ($199*12)|0;
       $phitmp57 = ($201*12)|0;
       $phitmp58 = ($203*12)|0;
       $204 = (($phitmp) + ($143))|0;
       $205 = $204;
       $206 = (($phitmp57) + ($143))|0;
       $207 = $206;
       $208 = (($phitmp58) + ($143))|0;
       $209 = $208;
       $210 = Math_fround(HEAPF32[$205>>2]);
       $211 = (($triangleVerts) + (($192*12)|0)|0);
       HEAPF32[$211>>2] = $210;
       $212 = (($205) + 4|0);
       $213 = Math_fround(HEAPF32[$212>>2]);
       $214 = ((($triangleVerts) + (($192*12)|0)|0) + 4|0);
       HEAPF32[$214>>2] = $213;
       $215 = (($205) + 8|0);
       $216 = Math_fround(HEAPF32[$215>>2]);
       $217 = ((($triangleVerts) + (($192*12)|0)|0) + 8|0);
       HEAPF32[$217>>2] = $216;
       $218 = Math_fround(HEAPF32[$207>>2]);
       $219 = (($triangleVerts) + (($193*12)|0)|0);
       HEAPF32[$219>>2] = $218;
       $220 = (($207) + 4|0);
       $221 = Math_fround(HEAPF32[$220>>2]);
       $222 = ((($triangleVerts) + (($193*12)|0)|0) + 4|0);
       HEAPF32[$222>>2] = $221;
       $223 = (($207) + 8|0);
       $224 = Math_fround(HEAPF32[$223>>2]);
       $225 = ((($triangleVerts) + (($193*12)|0)|0) + 8|0);
       HEAPF32[$225>>2] = $224;
       $226 = Math_fround(HEAPF32[$209>>2]);
       $227 = (($triangleVerts) + (($194*12)|0)|0);
       HEAPF32[$227>>2] = $226;
       $228 = (($209) + 4|0);
       $229 = Math_fround(HEAPF32[$228>>2]);
       $230 = ((($triangleVerts) + (($194*12)|0)|0) + 4|0);
       HEAPF32[$230>>2] = $229;
       $231 = (($209) + 8|0);
       $232 = Math_fround(HEAPF32[$231>>2]);
       $233 = ((($triangleVerts) + (($194*12)|0)|0) + 8|0);
       HEAPF32[$233>>2] = $232;
       $234 = (($j$052) + 1)|0;
       $235 = (($triangleIndexIt$051) + 4|0);
       $236 = ($234>>>0)<($138>>>0);
       if ($236) {
        $j$052 = $234;$triangleIndexIt$051 = $235;
       } else {
        break;
       }
      }
     }
     $237 = HEAP32[$i>>2]|0;
     $238 = ((($collData) + (($237*176)|0)|0) + 144|0);
     HEAPF32[$238>>2] = Math_fround(0.0);
     $239 = ((($collData) + (($237*176)|0)|0) + 148|0);
     HEAPF32[$239>>2] = Math_fround(0.0);
     $240 = ((($collData) + (($237*176)|0)|0) + 152|0);
     HEAPF32[$240>>2] = Math_fround(0.0);
     $241 = ((($collData) + (($237*176)|0)|0) + 160|0);
     $242 = (($collData) + (($237*176)|0)|0);
     ;HEAP32[$241+0>>2]=0|0;HEAP32[$241+4>>2]=0|0;HEAP32[$241+8>>2]=0|0;HEAP32[$241+12>>2]=0|0;
     __Z24collideWithMeshTrianglesRN5physx19PxsParticleCollDataERKNS_2Gu24InternalTriangleMeshDataERKNS_2Cm23FastVertex2ShapeScalingEPKNS_6PxVec3EjfRKNS_11PxTransformE($242,0,$meshScaling,$triangleVerts,$138,$proxRadius,$shape2World);
    }
   } else {
    $243 = HEAP16[$136>>1]|0;
    $244 = $243 & 48;
    $245 = ($244<<16>>16)==(48);
    if ($245) {
     HEAP32[$47>>2] = 2;
     HEAP32[$triangleVerts>>2] = ((494280 + 8|0));
     HEAP32[$48>>2] = $collData;
     HEAP32[$49>>2] = $i;
     HEAP32[$50>>2] = 1;
     HEAP32[$51>>2] = $35;
     $246 = Math_fround(HEAPF32[$meshScaling>>2]);
     HEAPF32[$52>>2] = $246;
     $247 = Math_fround(HEAPF32[$10>>2]);
     HEAPF32[$53>>2] = $247;
     $248 = Math_fround(HEAPF32[$11>>2]);
     HEAPF32[$54>>2] = $248;
     $249 = Math_fround(HEAPF32[$12>>2]);
     HEAPF32[$55>>2] = $249;
     $250 = Math_fround(HEAPF32[$13>>2]);
     HEAPF32[$56>>2] = $250;
     $251 = Math_fround(HEAPF32[$14>>2]);
     HEAPF32[$57>>2] = $251;
     $252 = Math_fround(HEAPF32[$15>>2]);
     HEAPF32[$58>>2] = $252;
     $253 = Math_fround(HEAPF32[$16>>2]);
     HEAPF32[$59>>2] = $253;
     $254 = Math_fround(HEAPF32[$17>>2]);
     HEAPF32[$60>>2] = $254;
     $255 = Math_fround(HEAPF32[$18>>2]);
     HEAPF32[$61>>2] = $255;
     $256 = Math_fround(HEAPF32[$19>>2]);
     HEAPF32[$62>>2] = $256;
     $257 = Math_fround(HEAPF32[$20>>2]);
     HEAPF32[$63>>2] = $257;
     $258 = Math_fround(HEAPF32[$21>>2]);
     HEAPF32[$64>>2] = $258;
     $259 = Math_fround(HEAPF32[$22>>2]);
     HEAPF32[$65>>2] = $259;
     $260 = Math_fround(HEAPF32[$23>>2]);
     HEAPF32[$66>>2] = $260;
     $261 = Math_fround(HEAPF32[$24>>2]);
     HEAPF32[$67>>2] = $261;
     $262 = Math_fround(HEAPF32[$25>>2]);
     HEAPF32[$68>>2] = $262;
     $263 = Math_fround(HEAPF32[$26>>2]);
     HEAPF32[$69>>2] = $263;
     HEAPF32[$70>>2] = $proxRadius;
     HEAP32[$71>>2] = 0;
     HEAP32[$72>>2] = $shape2World;
     $264 = HEAP32[$i>>2]|0;
     $265 = ((($collData) + (($264*176)|0)|0) + 144|0);
     HEAPF32[$265>>2] = Math_fround(0.0);
     $266 = ((($collData) + (($264*176)|0)|0) + 148|0);
     HEAPF32[$266>>2] = Math_fround(0.0);
     $267 = ((($collData) + (($264*176)|0)|0) + 152|0);
     HEAPF32[$267>>2] = Math_fround(0.0);
     $268 = ((($collData) + (($264*176)|0)|0) + 160|0);
     ;HEAP32[$268+0>>2]=0|0;HEAP32[$268+4>>2]=0|0;HEAP32[$268+8>>2]=0|0;HEAP32[$268+12>>2]=0|0;
     __Z14testBoundsMeshRKN5physx2Gu24InternalTriangleMeshDataERKNS_11PxTransformERKNS_2Cm23FastVertex2ShapeScalingEbRKNS_9PxBounds3ER26PxcContactCellMeshCallback($35,$world2Shape,$meshScaling,$269,$bounds,$triangleVerts);
     break;
    } else {
     $270 = Math_fround(HEAPF32[$106>>2]);
     $271 = Math_fround(HEAPF32[$118>>2]);
     $272 = Math_fround($270 - $271);
     $273 = Math_fround(HEAPF32[$109>>2]);
     $274 = Math_fround(HEAPF32[$122>>2]);
     $275 = Math_fround($273 - $274);
     $276 = Math_fround(HEAPF32[$112>>2]);
     $277 = Math_fround(HEAPF32[$126>>2]);
     $278 = Math_fround($276 - $277);
     $279 = Math_fround($272 * Math_fround(3.0));
     $280 = Math_fround($275 * Math_fround(3.0));
     $281 = Math_fround($278 * Math_fround(3.0));
     $282 = Math_fround($270 + $279);
     $283 = Math_fround($273 + $280);
     $284 = Math_fround($276 + $281);
     $285 = Math_fround($282 - $73);
     $286 = Math_fround($283 - $73);
     $287 = Math_fround($284 - $73);
     $288 = Math_fround($73 + $282);
     $289 = Math_fround($73 + $283);
     $290 = Math_fround($73 + $284);
     $291 = Math_fround($270 - $73);
     $292 = Math_fround($273 - $73);
     $293 = Math_fround($276 - $73);
     $294 = Math_fround($73 + $270);
     $295 = Math_fround($73 + $273);
     $296 = Math_fround($73 + $276);
     $297 = $285 < $291;
     $298 = $297 ? $285 : $291;
     $299 = $286 < $292;
     $300 = $299 ? $286 : $292;
     $301 = $287 < $293;
     $302 = $301 ? $287 : $293;
     $303 = $288 > $294;
     $304 = $303 ? $288 : $294;
     $305 = $289 > $295;
     $306 = $305 ? $289 : $295;
     $307 = $290 > $296;
     $308 = $307 ? $290 : $296;
     $309 = $298 < $271;
     $310 = $309 ? $298 : $271;
     $311 = $300 < $274;
     $312 = $311 ? $300 : $274;
     $313 = $302 < $277;
     $314 = $313 ? $302 : $277;
     HEAPF32[$cachedBounds>>2] = $310;
     HEAPF32[$74>>2] = $312;
     HEAPF32[$75>>2] = $314;
     $315 = $304 > $271;
     $316 = $315 ? $304 : $271;
     $317 = $306 > $274;
     $318 = $317 ? $306 : $274;
     $319 = $308 > $277;
     $320 = $319 ? $308 : $277;
     HEAPF32[$76>>2] = $316;
     HEAPF32[$77>>2] = $318;
     HEAPF32[$78>>2] = $320;
     HEAP8[$105>>0] = 0;
     $321 = ((($opcodeCaches) + ($storemerge53<<5)|0) + 28|0);
     HEAP32[$321>>2] = $cachedTriangleBuffer;
     HEAP32[$79>>2] = 2;
     HEAP32[$triangleVerts>>2] = ((494280 + 8|0));
     HEAP32[$80>>2] = $collData;
     HEAP32[$81>>2] = $i;
     HEAP32[$82>>2] = 1;
     HEAP32[$83>>2] = $35;
     $322 = Math_fround(HEAPF32[$meshScaling>>2]);
     HEAPF32[$84>>2] = $322;
     $323 = Math_fround(HEAPF32[$10>>2]);
     HEAPF32[$85>>2] = $323;
     $324 = Math_fround(HEAPF32[$11>>2]);
     HEAPF32[$86>>2] = $324;
     $325 = Math_fround(HEAPF32[$12>>2]);
     HEAPF32[$87>>2] = $325;
     $326 = Math_fround(HEAPF32[$13>>2]);
     HEAPF32[$88>>2] = $326;
     $327 = Math_fround(HEAPF32[$14>>2]);
     HEAPF32[$89>>2] = $327;
     $328 = Math_fround(HEAPF32[$15>>2]);
     HEAPF32[$90>>2] = $328;
     $329 = Math_fround(HEAPF32[$16>>2]);
     HEAPF32[$91>>2] = $329;
     $330 = Math_fround(HEAPF32[$17>>2]);
     HEAPF32[$92>>2] = $330;
     $331 = Math_fround(HEAPF32[$18>>2]);
     HEAPF32[$93>>2] = $331;
     $332 = Math_fround(HEAPF32[$19>>2]);
     HEAPF32[$94>>2] = $332;
     $333 = Math_fround(HEAPF32[$20>>2]);
     HEAPF32[$95>>2] = $333;
     $334 = Math_fround(HEAPF32[$21>>2]);
     HEAPF32[$96>>2] = $334;
     $335 = Math_fround(HEAPF32[$22>>2]);
     HEAPF32[$97>>2] = $335;
     $336 = Math_fround(HEAPF32[$23>>2]);
     HEAPF32[$98>>2] = $336;
     $337 = Math_fround(HEAPF32[$24>>2]);
     HEAPF32[$99>>2] = $337;
     $338 = Math_fround(HEAPF32[$25>>2]);
     HEAPF32[$100>>2] = $338;
     $339 = Math_fround(HEAPF32[$26>>2]);
     HEAPF32[$101>>2] = $339;
     HEAPF32[$102>>2] = $proxRadius;
     HEAP32[$103>>2] = $105;
     HEAP32[$104>>2] = $shape2World;
     $340 = HEAP32[$i>>2]|0;
     $341 = ((($collData) + (($340*176)|0)|0) + 144|0);
     HEAPF32[$341>>2] = Math_fround(0.0);
     $342 = ((($collData) + (($340*176)|0)|0) + 148|0);
     HEAPF32[$342>>2] = Math_fround(0.0);
     $343 = ((($collData) + (($340*176)|0)|0) + 152|0);
     HEAPF32[$343>>2] = Math_fround(0.0);
     $344 = ((($collData) + (($340*176)|0)|0) + 160|0);
     ;HEAP32[$344+0>>2]=0|0;HEAP32[$344+4>>2]=0|0;HEAP32[$344+8>>2]=0|0;HEAP32[$344+12>>2]=0|0;
     __Z14testBoundsMeshRKN5physx2Gu24InternalTriangleMeshDataERKNS_11PxTransformERKNS_2Cm23FastVertex2ShapeScalingEbRKNS_9PxBounds3ER26PxcContactCellMeshCallback($35,$world2Shape,$meshScaling,$269,$cachedBounds,$triangleVerts);
     __ZN5physx27PxsFluidParticleOpcodeCache5writeERtRKNS_9PxBounds3ERKNS0_18QuantizationParamsERKNS_2Gu13GeometryUnionEb($105,$136,$cachedBounds,$quantizationParams,$meshShape,$38);
     break;
    }
   }
  } while(0);
  $345 = HEAP32[$i>>2]|0;
  $346 = (($345) + 1)|0;
  HEAP32[$i>>2] = $346;
  $347 = ($346>>>0)<($numParticles>>>0);
  if ($347) {
   $storemerge53 = $346;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx27PxsFluidParticleOpcodeCache4readERtRjPjRKNS_9PxBounds3ERKNS0_18QuantizationParamsEPKNS_2Gu13GeometryUnionEb($this,$internalParticleFlags,$numTriangles,$triangleBuffer,$bounds,$quantizationParams,$mesh,$isSmallMesh) {
 $this = $this|0;
 $internalParticleFlags = $internalParticleFlags|0;
 $numTriangles = $numTriangles|0;
 $triangleBuffer = $triangleBuffer|0;
 $bounds = $bounds|0;
 $quantizationParams = $quantizationParams|0;
 $mesh = $mesh|0;
 $isSmallMesh = $isSmallMesh|0;
 var $$0 = 0, $$masked$i = 0, $$masked1$i = 0, $$masked2$i = 0, $$masked3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0);
 var $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0;
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $dstIndex$02$i = 0, $dstIndex$02$i4 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i10 = Math_fround(0), $fabsf$i$i11 = Math_fround(0), $fabsf$i$i7 = Math_fround(0), $fabsf$i$i8 = Math_fround(0), $fabsf$i$i9 = Math_fround(0);
 var $or$cond = 0, $or$cond1 = 0, $ptr$01$i = 0, $ptr$01$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$internalParticleFlags>>1]|0;
 $1 = $0 & 16;
 $2 = ($1<<16>>16)==(0);
 do {
  if (!($2)) {
   $3 = (($this) + 28|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==($mesh|0);
   if ($5) {
    $6 = HEAP8[$this>>0]|0;
    $7 = $6&255;
    HEAP32[$numTriangles>>2] = $7;
    $8 = ($6&255)<(2);
    $or$cond = $8 & $isSmallMesh;
    if ($or$cond) {
     $9 = (($this) + 2|0);
     $10 = HEAP16[$9>>1]|0;
     $11 = $10&65535;
     HEAP32[$triangleBuffer>>2] = $11;
     $12 = (($this) + 4|0);
     $13 = Math_fround(HEAPF32[$bounds>>2]);
     $14 = Math_fround(HEAPF32[$12>>2]);
     $15 = Math_fround($13 - $14);
     $16 = (($bounds) + 4|0);
     $17 = Math_fround(HEAPF32[$16>>2]);
     $18 = (($this) + 8|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = Math_fround($17 - $19);
     $21 = (($bounds) + 8|0);
     $22 = Math_fround(HEAPF32[$21>>2]);
     $23 = (($this) + 12|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $25 = Math_fround($22 - $24);
     $26 = $15 < Math_fround(0.0);
     $27 = $26 ? $15 : Math_fround(0.0);
     $28 = $20 < Math_fround(0.0);
     $29 = $28 ? $20 : Math_fround(0.0);
     $30 = $25 < Math_fround(0.0);
     $31 = $30 ? $25 : Math_fround(0.0);
     $32 = (($this) + 16|0);
     $33 = Math_fround(HEAPF32[$32>>2]);
     $34 = (($bounds) + 12|0);
     $35 = Math_fround(HEAPF32[$34>>2]);
     $36 = Math_fround($33 - $35);
     $37 = (($this) + 20|0);
     $38 = Math_fround(HEAPF32[$37>>2]);
     $39 = (($bounds) + 16|0);
     $40 = Math_fround(HEAPF32[$39>>2]);
     $41 = Math_fround($38 - $40);
     $42 = (($this) + 24|0);
     $43 = Math_fround(HEAPF32[$42>>2]);
     $44 = (($bounds) + 20|0);
     $45 = Math_fround(HEAPF32[$44>>2]);
     $46 = Math_fround($43 - $45);
     $47 = $36 < Math_fround(0.0);
     $48 = $47 ? $36 : Math_fround(0.0);
     $49 = $41 < Math_fround(0.0);
     $50 = $49 ? $41 : Math_fround(0.0);
     $51 = $46 < Math_fround(0.0);
     $52 = $51 ? $46 : Math_fround(0.0);
     $53 = Math_fround($27 + $29);
     $54 = Math_fround($53 + $31);
     $55 = Math_fround($54 + $48);
     $56 = Math_fround($55 + $50);
     $57 = Math_fround($56 + $52);
     $58 = $57 == Math_fround(0.0);
     if (!($58)) {
      break;
     }
     $59 = $0&65535;
     $60 = $59 | 48;
     $61 = $60&65535;
     HEAP16[$internalParticleFlags>>1] = $61;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $62 = (($this) + 1|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = (($this) + 4|0);
    $65 = (($this) + 16|0);
    $66 = Math_fround(HEAPF32[$bounds>>2]);
    $67 = Math_fround(HEAPF32[$64>>2]);
    $68 = Math_fround($66 - $67);
    $69 = (($bounds) + 4|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = (($this) + 8|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = Math_fround($70 - $72);
    $74 = (($bounds) + 8|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = (($this) + 12|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = Math_fround($75 - $77);
    $79 = (($bounds) + 12|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = Math_fround($80 - $67);
    $82 = (($bounds) + 16|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = Math_fround($83 - $72);
    $85 = (($bounds) + 20|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $87 = Math_fround($86 - $77);
    $fabsf$i$i11 = (Math_fround(Math_abs((Math_fround($68)))));
    $fabsf$i$i10 = (Math_fround(Math_abs((Math_fround($81)))));
    $88 = $fabsf$i$i11 > $fabsf$i$i10;
    $89 = $88 ? $fabsf$i$i11 : $fabsf$i$i10;
    $fabsf$i$i9 = (Math_fround(Math_abs((Math_fround($73)))));
    $fabsf$i$i8 = (Math_fround(Math_abs((Math_fround($84)))));
    $fabsf$i$i7 = (Math_fround(Math_abs((Math_fround($78)))));
    $fabsf$i$i = (Math_fround(Math_abs((Math_fround($87)))));
    $90 = (($quantizationParams) + 4|0);
    $91 = Math_fround(HEAPF32[$90>>2]);
    $92 = Math_fround($89 * $91);
    $93 = (~~(($92))&255);
    $94 = ($93&255)<($63&255);
    if ($94) {
     $95 = $fabsf$i$i7 > $fabsf$i$i;
     $96 = $95 ? $fabsf$i$i7 : $fabsf$i$i;
     $97 = Math_fround($91 * $96);
     $98 = $fabsf$i$i9 > $fabsf$i$i8;
     $99 = (($this) + 3|0);
     $100 = (($this) + 2|0);
     $101 = (~~(($97))&255);
     $102 = $98 ? $fabsf$i$i9 : $fabsf$i$i8;
     $103 = HEAP8[$99>>0]|0;
     $104 = HEAP8[$100>>0]|0;
     $105 = Math_fround($102 * $91);
     $106 = (~~(($105))&255);
     $107 = ($106&255)<($104&255);
     $108 = ($101&255)<($103&255);
     $or$cond1 = $107 & $108;
     if ($or$cond1) {
      if (!($isSmallMesh)) {
       $176 = ($6&255)<(4);
       if (!($176)) {
        break;
       }
       $177 = (($65) + ($7<<2)|0);
       $178 = ($65|0)==($177|0);
       if (!($178)) {
        $dstIndex$02$i = 0;$ptr$01$i = $65;
        while(1) {
         $179 = (($ptr$01$i) + 4|0);
         $180 = HEAP32[$ptr$01$i>>2]|0;
         $181 = (($dstIndex$02$i) + 1)|0;
         $182 = (($triangleBuffer) + ($dstIndex$02$i<<2)|0);
         HEAP32[$182>>2] = $180;
         $183 = ($179|0)==($177|0);
         if ($183) {
          break;
         } else {
          $dstIndex$02$i = $181;$ptr$01$i = $179;
         }
        }
       }
       $184 = $0&65535;
       $185 = $184 | 48;
       $186 = $185&65535;
       HEAP16[$internalParticleFlags>>1] = $186;
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
      $109 = ($6&255)<(7);
      if (!($109)) {
       $121 = ($6&255)<(10);
       if (!($121)) {
        break;
       }
       $122 = HEAP16[$65>>1]|0;
       $123 = $122&65535;
       HEAP32[$triangleBuffer>>2] = $123;
       $124 = (($this) + 18|0);
       $125 = HEAP16[$124>>1]|0;
       $126 = $125&65535;
       $127 = $126 >>> 6;
       $128 = (($127) + ($123))|0;
       $129 = (($triangleBuffer) + 4|0);
       HEAP32[$129>>2] = $128;
       $130 = $126 << 4;
       $131 = (($this) + 20|0);
       $132 = HEAP16[$131>>1]|0;
       $133 = $132&65535;
       $134 = $133 >>> 12;
       $$masked$i = $130 & 1008;
       $135 = $$masked$i | $134;
       $136 = (($135) + ($123))|0;
       $137 = (($triangleBuffer) + 8|0);
       HEAP32[$137>>2] = $136;
       $138 = $133 >>> 2;
       $139 = $138 & 1023;
       $140 = (($139) + ($123))|0;
       $141 = (($triangleBuffer) + 12|0);
       HEAP32[$141>>2] = $140;
       $142 = $133 << 8;
       $143 = (($this) + 22|0);
       $144 = HEAP16[$143>>1]|0;
       $145 = $144&65535;
       $146 = $145 >>> 8;
       $$masked1$i = $142 & 768;
       $147 = $$masked1$i | $146;
       $148 = (($147) + ($123))|0;
       $149 = (($triangleBuffer) + 16|0);
       HEAP32[$149>>2] = $148;
       $150 = $145 << 2;
       $151 = (($this) + 24|0);
       $152 = HEAP16[$151>>1]|0;
       $153 = $152&65535;
       $154 = $153 >>> 14;
       $$masked2$i = $150 & 1020;
       $155 = $$masked2$i | $154;
       $156 = (($155) + ($123))|0;
       $157 = (($triangleBuffer) + 20|0);
       HEAP32[$157>>2] = $156;
       $158 = $153 >>> 4;
       $159 = $158 & 1023;
       $160 = (($159) + ($123))|0;
       $161 = (($triangleBuffer) + 24|0);
       HEAP32[$161>>2] = $160;
       $162 = $153 << 6;
       $163 = (($this) + 26|0);
       $164 = HEAP16[$163>>1]|0;
       $165 = $164&65535;
       $166 = $165 >>> 10;
       $$masked3$i = $162 & 960;
       $167 = $$masked3$i | $166;
       $168 = (($167) + ($123))|0;
       $169 = (($triangleBuffer) + 28|0);
       HEAP32[$169>>2] = $168;
       $170 = $165 & 1023;
       $171 = (($170) + ($123))|0;
       $172 = (($triangleBuffer) + 32|0);
       HEAP32[$172>>2] = $171;
       $173 = $0&65535;
       $174 = $173 | 48;
       $175 = $174&65535;
       HEAP16[$internalParticleFlags>>1] = $175;
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
      $110 = (($65) + ($7<<1)|0);
      $111 = ($65|0)==($110|0);
      if (!($111)) {
       $dstIndex$02$i4 = 0;$ptr$01$i5 = $65;
       while(1) {
        $112 = (($ptr$01$i5) + 2|0);
        $113 = HEAP16[$ptr$01$i5>>1]|0;
        $114 = $113&65535;
        $115 = (($dstIndex$02$i4) + 1)|0;
        $116 = (($triangleBuffer) + ($dstIndex$02$i4<<2)|0);
        HEAP32[$116>>2] = $114;
        $117 = ($112|0)==($110|0);
        if ($117) {
         break;
        } else {
         $dstIndex$02$i4 = $115;$ptr$01$i5 = $112;
        }
       }
      }
      $118 = $0&65535;
      $119 = $118 | 48;
      $120 = $119&65535;
      HEAP16[$internalParticleFlags>>1] = $120;
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 HEAP32[$numTriangles>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx27PxsFluidParticleOpcodeCache5writeERtRKNS_9PxBounds3ERKNS0_18QuantizationParamsERKNS_2Gu13GeometryUnionEb($this,$internalParticleFlags,$bounds,$quantizationParams,$mesh,$isSmallMesh) {
 $this = $this|0;
 $internalParticleFlags = $internalParticleFlags|0;
 $bounds = $bounds|0;
 $quantizationParams = $quantizationParams|0;
 $mesh = $mesh|0;
 $isSmallMesh = $isSmallMesh|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i6 = 0, $ptr$01$i = 0, $ptr$01$i5 = 0, $storemerge$i = 0, $t$02$i = 0, $t$02$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 if ($isSmallMesh) {
  $2 = HEAP8[$this>>0]|0;
  $3 = ($2&255)<(2);
  if ($3) {
   $4 = (($this) + 2|0);
   $5 = ($2<<24>>24)==(0);
   if ($5) {
    $8 = 0;
   } else {
    $6 = HEAP32[$1>>2]|0;
    $7 = $6&65535;
    $8 = $7;
   }
   HEAP16[$4>>1] = $8;
   $9 = (($this) + 4|0);
   $10 = Math_fround(HEAPF32[$bounds>>2]);
   HEAPF32[$9>>2] = $10;
   $11 = (($bounds) + 4|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = (($this) + 8|0);
   HEAPF32[$13>>2] = $12;
   $14 = (($bounds) + 8|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = (($this) + 12|0);
   HEAPF32[$16>>2] = $15;
   $17 = (($bounds) + 12|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = (($this) + 16|0);
   HEAPF32[$19>>2] = $18;
   $20 = (($bounds) + 16|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = (($this) + 20|0);
   HEAPF32[$22>>2] = $21;
   $23 = (($bounds) + 20|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = (($this) + 24|0);
   HEAPF32[$25>>2] = $24;
  } else {
   label = 6;
  }
 } else {
  label = 6;
 }
 L7: do {
  if ((label|0) == 6) {
   $26 = (($this) + 1|0);
   $27 = (($this) + 2|0);
   $28 = (($this) + 3|0);
   $29 = (($this) + 4|0);
   $30 = (($this) + 16|0);
   $31 = Math_fround(HEAPF32[$bounds>>2]);
   $32 = (($bounds) + 12|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = Math_fround($31 + $33);
   $35 = (($bounds) + 4|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = (($bounds) + 16|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($36 + $38);
   $40 = (($bounds) + 8|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = (($bounds) + 20|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = Math_fround($41 + $43);
   $45 = Math_fround($34 * Math_fround(0.5));
   $46 = Math_fround($39 * Math_fround(0.5));
   $47 = Math_fround($44 * Math_fround(0.5));
   HEAPF32[$29>>2] = $45;
   $48 = (($this) + 8|0);
   HEAPF32[$48>>2] = $46;
   $49 = (($this) + 12|0);
   HEAPF32[$49>>2] = $47;
   $50 = Math_fround(HEAPF32[$bounds>>2]);
   $51 = Math_fround(HEAPF32[$32>>2]);
   $52 = $50 > $51;
   if ($52) {
    HEAP8[$26>>0] = 0;
    HEAP8[$27>>0] = 0;
    $storemerge$i = 0;
   } else {
    $53 = Math_fround($51 - $50);
    $54 = Math_fround(HEAPF32[$37>>2]);
    $55 = Math_fround(HEAPF32[$35>>2]);
    $56 = Math_fround($54 - $55);
    $57 = Math_fround(HEAPF32[$42>>2]);
    $58 = Math_fround(HEAPF32[$40>>2]);
    $59 = Math_fround($57 - $58);
    $60 = Math_fround($53 * Math_fround(0.5));
    $61 = Math_fround($56 * Math_fround(0.5));
    $62 = Math_fround($59 * Math_fround(0.5));
    $63 = (($quantizationParams) + 4|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = Math_fround($60 * $64);
    $66 = Math_fround($65 + Math_fround(1.0));
    $67 = (~~(($66))&255);
    HEAP8[$26>>0] = $67;
    $68 = Math_fround(HEAPF32[$63>>2]);
    $69 = Math_fround($61 * $68);
    $70 = Math_fround($69 + Math_fround(1.0));
    $71 = (~~(($70))&255);
    HEAP8[$27>>0] = $71;
    $72 = Math_fround(HEAPF32[$63>>2]);
    $73 = Math_fround($62 * $72);
    $74 = Math_fround($73 + Math_fround(1.0));
    $75 = (~~(($74))&255);
    $storemerge$i = $75;
   }
   HEAP8[$28>>0] = $storemerge$i;
   $76 = HEAP8[$this>>0]|0;
   if ($isSmallMesh) {
    $77 = ($76&255)<(7);
    if ($77) {
     $78 = $76&255;
     $79 = ($76<<24>>24)==(0);
     if ($79) {
      break;
     }
     $ptr$01$i5 = $30;$t$02$i4 = 0;
     while(1) {
      $80 = (($1) + ($t$02$i4<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81&65535;
      $83 = (($ptr$01$i5) + 2|0);
      HEAP16[$ptr$01$i5>>1] = $82;
      $84 = (($t$02$i4) + 1)|0;
      $exitcond$i6 = ($84|0)==($78|0);
      if ($exitcond$i6) {
       break L7;
      } else {
       $ptr$01$i5 = $83;$t$02$i4 = $84;
      }
     }
    }
    $85 = ($76&255)<(10);
    if ($85) {
     $86 = $76&255;
     $87 = (__ZN5physx27PxsFluidParticleOpcodeCache28writeTriangles_BaseU16_9xU10EPhPKjj($30,$1,$86)|0);
     if ($87) {
      break;
     }
     $88 = HEAP16[$internalParticleFlags>>1]|0;
     $89 = $88&65535;
     $90 = $89 & 65487;
     $91 = $90&65535;
     HEAP16[$internalParticleFlags>>1] = $91;
     STACKTOP = sp;return;
    }
   } else {
    $92 = ($76&255)<(4);
    if ($92) {
     $93 = $76&255;
     $94 = ($76<<24>>24)==(0);
     if ($94) {
      break;
     }
     $ptr$01$i = $30;$t$02$i = 0;
     while(1) {
      $95 = (($1) + ($t$02$i<<2)|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($ptr$01$i) + 4|0);
      HEAP32[$ptr$01$i>>2] = $96;
      $98 = (($t$02$i) + 1)|0;
      $exitcond$i = ($98|0)==($93|0);
      if ($exitcond$i) {
       break L7;
      } else {
       $ptr$01$i = $97;$t$02$i = $98;
      }
     }
    }
   }
   $99 = HEAP16[$internalParticleFlags>>1]|0;
   $100 = $99&65535;
   $101 = $100 & 65487;
   $102 = $101&65535;
   HEAP16[$internalParticleFlags>>1] = $102;
   STACKTOP = sp;return;
  }
 } while(0);
 $103 = HEAP16[$internalParticleFlags>>1]|0;
 $104 = $103&65535;
 $105 = $104 | 48;
 $106 = $105&65535;
 HEAP16[$internalParticleFlags>>1] = $106;
 HEAP32[$0>>2] = $mesh;
 STACKTOP = sp;return;
}
function __ZN5physx28collideWithStaticHeightFieldEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEfRKNS_11PxTransformE($particleCollData,$numCollData,$heightFieldShape,$proxRadius,$shape2World) {
 $particleCollData = $particleCollData|0;
 $numCollData = $numCollData|0;
 $heightFieldShape = $heightFieldShape|0;
 $proxRadius = Math_fround($proxRadius);
 $shape2World = $shape2World|0;
 var $$lobit = 0, $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0;
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $e0 = 0, $e1 = 0, $exitcond = 0, $hasCC = 0, $hfUtil = 0, $it = 0, $itBegin = 0, $or$cond = 0, $p$010 = 0, $particleBounds = 0, $test = 0, $tmpCCTime = 0, $tmpDistOldToSurface = 0, $tmpProxSurfaceNormal = 0, $tmpProxSurfacePos = 0, $tmpSurfaceNormal = 0;
 var $tmpSurfacePos = 0, $triangle = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $0 = sp + 236|0;
 $hfUtil = sp + 216|0;
 $particleBounds = sp + 192|0;
 $test = sp + 156|0;
 $itBegin = sp + 136|0;
 $triangle = sp + 100|0;
 $hasCC = sp + 240|0;
 $tmpSurfaceNormal = sp + 88|0;
 $tmpSurfacePos = sp + 76|0;
 $tmpProxSurfaceNormal = sp + 52|0;
 $tmpProxSurfacePos = sp + 40|0;
 $tmpCCTime = sp + 36|0;
 $tmpDistOldToSurface = sp + 32|0;
 $it = sp + 12|0;
 $e0 = sp;
 $e1 = sp + 64|0;
 HEAPF32[$0>>2] = $proxRadius;
 $1 = (($hfUtil) + 12|0);
 $2 = (($heightFieldShape) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$1>>2] = $3;
 $4 = (($hfUtil) + 16|0);
 HEAP32[$4>>2] = $heightFieldShape;
 $5 = (($heightFieldShape) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(Math_fround(1.0) / $6);
 $8 = (($hfUtil) + 4|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($heightFieldShape) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(Math_fround(1.0) / $10);
 HEAPF32[$hfUtil>>2] = $11;
 $12 = (($heightFieldShape) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(Math_fround(1.0) / $13);
 $15 = (($hfUtil) + 8|0);
 HEAPF32[$15>>2] = $14;
 $16 = ($numCollData|0)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (($particleBounds) + 4|0);
 $18 = (($particleBounds) + 8|0);
 $19 = (($particleBounds) + 12|0);
 $20 = (($particleBounds) + 16|0);
 $21 = (($particleBounds) + 20|0);
 $22 = (($test) + 4|0);
 $23 = (($test) + 12|0);
 $24 = (($test) + 20|0);
 $25 = (($tmpSurfaceNormal) + 4|0);
 $26 = (($tmpSurfaceNormal) + 8|0);
 $27 = (($tmpSurfacePos) + 4|0);
 $28 = (($tmpSurfacePos) + 8|0);
 $29 = (($tmpProxSurfaceNormal) + 4|0);
 $30 = (($tmpProxSurfaceNormal) + 8|0);
 $31 = (($tmpProxSurfacePos) + 4|0);
 $32 = (($tmpProxSurfacePos) + 8|0);
 $33 = (($it) + 12|0);
 $34 = (($it) + 8|0);
 $35 = (($it) + 16|0);
 $36 = (($it) + 4|0);
 $37 = (($triangle) + 4|0);
 $38 = (($triangle) + 8|0);
 $39 = (($triangle) + 12|0);
 $40 = (($triangle) + 16|0);
 $41 = (($triangle) + 20|0);
 $42 = (($triangle) + 24|0);
 $43 = (($triangle) + 28|0);
 $44 = (($triangle) + 32|0);
 $45 = (($e0) + 4|0);
 $46 = (($e0) + 8|0);
 $47 = (($e1) + 4|0);
 $48 = (($e1) + 8|0);
 $75 = $proxRadius;$p$010 = 0;
 while(1) {
  $49 = (($particleCollData) + (($p$010*176)|0)|0);
  $50 = ((($particleCollData) + (($p$010*176)|0)|0) + 112|0);
  $51 = ((($particleCollData) + (($p$010*176)|0)|0) + 128|0);
  $52 = Math_fround(HEAPF32[$50>>2]);
  $53 = Math_fround(HEAPF32[$51>>2]);
  $54 = $52 < $53;
  $55 = $54 ? $52 : $53;
  $56 = ((($particleCollData) + (($p$010*176)|0)|0) + 116|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = ((($particleCollData) + (($p$010*176)|0)|0) + 132|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = $57 < $59;
  $61 = $60 ? $57 : $59;
  $62 = ((($particleCollData) + (($p$010*176)|0)|0) + 120|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = ((($particleCollData) + (($p$010*176)|0)|0) + 136|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = $63 < $65;
  $67 = $66 ? $63 : $65;
  $68 = $52 > $53;
  $69 = $68 ? $52 : $53;
  $70 = $57 > $59;
  $71 = $70 ? $57 : $59;
  $72 = $63 > $65;
  $73 = $72 ? $63 : $65;
  $74 = Math_fround($55 - $75);
  HEAPF32[$particleBounds>>2] = $74;
  $76 = Math_fround($61 - $75);
  HEAPF32[$17>>2] = $76;
  $77 = Math_fround($67 - $75);
  HEAPF32[$18>>2] = $77;
  $78 = Math_fround($75 + $69);
  HEAPF32[$19>>2] = $78;
  $79 = Math_fround($75 + $71);
  HEAPF32[$20>>2] = $79;
  $80 = Math_fround($75 + $73);
  HEAPF32[$21>>2] = $80;
  __ZN5physx22PxcHeightFieldAabbTestC2ERKNS_9PxBounds3ERKNS_2Gu15HeightFieldUtilE($test,$particleBounds,$hfUtil);
  __ZNK5physx22PxcHeightFieldAabbTest5beginEv($itBegin,$test);
  $81 = HEAP8[$22>>0]|0;
  $82 = ($81<<24>>24)==(0);
  if ($82) {
   $83 = HEAP32[$23>>2]|0;
   $84 = HEAP32[$24>>2]|0;
   $85 = HEAP32[$test>>2]|0;
   $86 = (($85) + 12|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 20|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = Math_imul($89, $83)|0;
   $91 = (($90) + ($84))|0;
   $107 = $91;
  } else {
   $107 = 0;
  }
  $92 = ((($particleCollData) + (($p$010*176)|0)|0) + 144|0);
  HEAPF32[$92>>2] = Math_fround(0.0);
  $93 = ((($particleCollData) + (($p$010*176)|0)|0) + 148|0);
  HEAPF32[$93>>2] = Math_fround(0.0);
  $94 = ((($particleCollData) + (($p$010*176)|0)|0) + 152|0);
  HEAPF32[$94>>2] = Math_fround(0.0);
  $95 = ((($particleCollData) + (($p$010*176)|0)|0) + 160|0);
  $96 = ((($particleCollData) + (($p$010*176)|0)|0) + 124|0);
  ;HEAP32[$95+0>>2]=0|0;HEAP32[$95+4>>2]=0|0;HEAP32[$95+8>>2]=0|0;HEAP32[$95+12>>2]=0|0;
  $97 = HEAP32[$96>>2]|0;
  $98 = $97 >>> 1;
  $$lobit = $98 & 1;
  $99 = $$lobit&255;
  HEAP8[$hasCC>>0] = $99;
  HEAPF32[$tmpSurfaceNormal>>2] = Math_fround(0.0);
  HEAPF32[$25>>2] = Math_fround(0.0);
  HEAPF32[$26>>2] = Math_fround(0.0);
  HEAPF32[$tmpSurfacePos>>2] = Math_fround(0.0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  HEAPF32[$tmpProxSurfaceNormal>>2] = Math_fround(0.0);
  HEAPF32[$29>>2] = Math_fround(0.0);
  HEAPF32[$30>>2] = Math_fround(0.0);
  HEAPF32[$tmpProxSurfacePos>>2] = Math_fround(0.0);
  HEAPF32[$31>>2] = Math_fround(0.0);
  HEAPF32[$32>>2] = Math_fround(0.0);
  $100 = ((($particleCollData) + (($p$010*176)|0)|0) + 44|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  HEAPF32[$tmpCCTime>>2] = $101;
  HEAPF32[$tmpDistOldToSurface>>2] = Math_fround(0.0);
  ;HEAP32[$it+0>>2]=HEAP32[$itBegin+0>>2]|0;HEAP32[$it+4>>2]=HEAP32[$itBegin+4>>2]|0;HEAP32[$it+8>>2]=HEAP32[$itBegin+8>>2]|0;HEAP32[$it+12>>2]=HEAP32[$itBegin+12>>2]|0;HEAP32[$it+16>>2]=HEAP32[$itBegin+16>>2]|0;
  $102 = ((($particleCollData) + (($p$010*176)|0)|0) + 92|0);
  while(1) {
   $103 = HEAP32[$34>>2]|0;
   $104 = ($103|0)==(0);
   $105 = HEAP32[$33>>2]|0;
   $106 = ($107|0)==($105|0);
   $or$cond = $104 & $106;
   if ($or$cond) {
    break;
   }
   $108 = HEAP32[$35>>2]|0;
   $109 = $105 << 1;
   $110 = (($109) + ($103))|0;
   $111 = (($108) + 32|0);
   $112 = HEAP8[$111>>0]|0;
   $113 = ($112<<24>>24)!=(0);
   $114 = $113 ? 2 : 1;
   $115 = $113 ? 1 : 2;
   $116 = HEAP32[$108>>2]|0;
   $117 = (($116) + 12|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = HEAP32[$it>>2]|0;
   $120 = HEAP32[$36>>2]|0;
   $121 = (($triangle) + (($114*12)|0)|0);
   $122 = (($triangle) + (($115*12)|0)|0);
   __ZNK5physx2Gu11HeightField19getTriangleVerticesEjjjRNS_6PxVec3ES3_S3_($118,$110,$119,$120,$triangle,$121,$122);
   $123 = HEAP32[$108>>2]|0;
   $124 = Math_fround(HEAPF32[$triangle>>2]);
   $125 = (($123) + 16|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = (($126) + 12|0);
   $128 = Math_fround(HEAPF32[$127>>2]);
   $129 = Math_fround($124 * $128);
   $130 = Math_fround(HEAPF32[$37>>2]);
   $131 = (($126) + 8|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = Math_fround($130 * $132);
   $134 = Math_fround(HEAPF32[$38>>2]);
   $135 = (($126) + 16|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = Math_fround($134 * $136);
   HEAPF32[$triangle>>2] = $129;
   HEAPF32[$37>>2] = $133;
   HEAPF32[$38>>2] = $137;
   $138 = Math_fround(HEAPF32[$39>>2]);
   $139 = Math_fround($138 * $128);
   $140 = Math_fround(HEAPF32[$40>>2]);
   $141 = Math_fround($140 * $132);
   $142 = Math_fround(HEAPF32[$41>>2]);
   $143 = Math_fround($142 * $136);
   HEAPF32[$39>>2] = $139;
   HEAPF32[$40>>2] = $141;
   HEAPF32[$41>>2] = $143;
   $144 = Math_fround(HEAPF32[$42>>2]);
   $145 = Math_fround($144 * $128);
   $146 = Math_fround(HEAPF32[$43>>2]);
   $147 = Math_fround($146 * $132);
   $148 = Math_fround(HEAPF32[$44>>2]);
   $149 = Math_fround($148 * $136);
   HEAPF32[$42>>2] = $145;
   HEAPF32[$43>>2] = $147;
   HEAPF32[$44>>2] = $149;
   $150 = Math_fround($139 - $129);
   $151 = Math_fround($141 - $133);
   $152 = Math_fround($143 - $137);
   HEAPF32[$e0>>2] = $150;
   HEAPF32[$45>>2] = $151;
   HEAPF32[$46>>2] = $152;
   $153 = Math_fround($145 - $129);
   $154 = Math_fround($147 - $133);
   $155 = Math_fround($149 - $137);
   HEAPF32[$e1>>2] = $153;
   HEAPF32[$47>>2] = $154;
   HEAPF32[$48>>2] = $155;
   $156 = HEAP8[$hasCC>>0]|0;
   $157 = ($156<<24>>24)!=(0);
   $158 = (__ZN5physx23collideWithMeshTriangleERNS_6PxVec3ES1_S1_S1_RfS2_RKS0_S4_S4_S4_S4_bRKfS6_($tmpSurfaceNormal,$tmpSurfacePos,$tmpProxSurfaceNormal,$tmpProxSurfacePos,$tmpCCTime,$tmpDistOldToSurface,$50,$51,$triangle,$e0,$e1,$157,$102,$0)|0);
   $159 = Math_fround(HEAPF32[$tmpCCTime>>2]);
   $160 = Math_fround(HEAPF32[$tmpDistOldToSurface>>2]);
   __Z19updateCollShapeDataRN5physx19PxsParticleCollDataERbjffRKNS_6PxVec3ES5_S5_S5_RKNS_11PxTransformE($49,$hasCC,$158,$159,$160,$tmpSurfaceNormal,$tmpSurfacePos,$tmpProxSurfaceNormal,$tmpProxSurfacePos,$shape2World);
   (__ZN5physx22PxcHeightFieldAabbTest8IteratorppEv($it)|0);
  }
  $161 = (($p$010) + 1)|0;
  $exitcond = ($161|0)==($numCollData|0);
  if ($exitcond) {
   break;
  }
  $$pre = Math_fround(HEAPF32[$0>>2]);
  $75 = $$pre;$p$010 = $161;
 }
 STACKTOP = sp;return;
}
function __ZNK5physx22PxcHeightFieldAabbTest5beginEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sink$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $itBegin = 0, $or$cond = 0, $or$cond$i$i = 0, $or$cond1$i$i = 0, $or$cond2$i$i = 0, $or$cond3$i$i = 0, $or$cond4$i$i = 0, $or$cond4$i$i$not = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $itBegin = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  HEAP32[$agg$result>>2] = 0;
  $3 = (($agg$result) + 4|0);
  HEAP32[$3>>2] = 0;
  $4 = (($agg$result) + 16|0);
  HEAP32[$4>>2] = $this;
  $5 = (($agg$result) + 8|0);
  HEAP32[$5>>2] = 0;
  $6 = (($agg$result) + 12|0);
  HEAP32[$6>>2] = 0;
  STACKTOP = sp;return;
 }
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$itBegin>>2] = $8;
 $11 = (($itBegin) + 4|0);
 HEAP32[$11>>2] = $10;
 $12 = (($itBegin) + 16|0);
 HEAP32[$12>>2] = $this;
 $13 = (($itBegin) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = Math_imul($18, $8)|0;
 $20 = (($19) + ($10))|0;
 $21 = (($itBegin) + 12|0);
 HEAP32[$21>>2] = $20;
 $22 = (($this) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$17>>2]|0;
 $27 = Math_imul($26, $23)|0;
 $28 = (($27) + ($25))|0;
 $29 = ($28|0)==($20|0);
 do {
  if (!($29)) {
   $30 = (($16) + 36|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $20 & 2147483647;
   $33 = ((($31) + ($32<<2)|0) + 2|0);
   $$sink$i$i$i = HEAP8[$33>>0]|0;
   $34 = $$sink$i$i$i & 127;
   $35 = ($34<<24>>24)==(127);
   if (!($35)) {
    $36 = (($31) + ($20<<2)|0);
    $37 = HEAP16[$36>>1]|0;
    $38 = (Math_fround(($37<<16>>16)));
    $39 = (($20) + 1)|0;
    $40 = (($31) + ($39<<2)|0);
    $41 = HEAP16[$40>>1]|0;
    $42 = (Math_fround(($41<<16>>16)));
    $43 = HEAP32[$17>>2]|0;
    $44 = (($43) + ($20))|0;
    $45 = (($31) + ($44<<2)|0);
    $46 = HEAP16[$45>>1]|0;
    $47 = (Math_fround(($46<<16>>16)));
    $48 = (($44) + 1)|0;
    $49 = (($31) + ($48<<2)|0);
    $50 = HEAP16[$49>>1]|0;
    $51 = (Math_fround(($50<<16>>16)));
    $52 = (($this) + 28|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = $53 < $38;
    $55 = $53 < $42;
    $or$cond$i$i = $54 & $55;
    $56 = $53 < $47;
    $or$cond1$i$i = $or$cond$i$i & $56;
    $57 = $53 < $51;
    $or$cond2$i$i = $or$cond1$i$i & $57;
    if (!($or$cond2$i$i)) {
     $58 = (($this) + 24|0);
     $59 = Math_fround(HEAPF32[$58>>2]);
     $60 = $59 > $38;
     $61 = $59 > $42;
     $or$cond3$i$i = $60 & $61;
     $62 = $59 > $47;
     $or$cond4$i$i = $or$cond3$i$i & $62;
     $or$cond4$i$i$not = $or$cond4$i$i ^ 1;
     $phitmp$i$i = !($59 > $51);
     $or$cond = $phitmp$i$i | $or$cond4$i$i$not;
     if ($or$cond) {
      break;
     }
    }
   }
   (__ZN5physx22PxcHeightFieldAabbTest8IteratorppEv($itBegin)|0);
  }
 } while(0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$itBegin+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$itBegin+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$itBegin+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$itBegin+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$itBegin+16>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx22PxcHeightFieldAabbTest8IteratorppEv($this) {
 $this = $this|0;
 var $$not = 0, $$off0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert26 = 0, $$phi$trans$insert28 = 0, $$phi$trans$insert30 = 0, $$pre = 0, $$pre25 = 0, $$pre27 = 0, $$pre29 = 0, $$pre31 = 0, $$sink$i$i = 0, $$sink$i$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0;
 var $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = Math_fround(0), $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $isec$0$off0$ph$be = 0, $isec$0$off0$ph21 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i4 = 0, $or$cond1$i = 0, $or$cond1$i5 = 0, $or$cond2$i = 0, $or$cond2$i6 = 0, $or$cond3$i = 0;
 var $or$cond3$i7 = 0, $or$cond4$i = 0, $or$cond4$i8 = 0, $or$cond4$i8$not = 0, $phitmp$i = 0, $phitmp$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 $$phi$trans$insert = (($this) + 16|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if ($2) {
  $$pre25 = HEAP32[$$pre>>2]|0;
  $$phi$trans$insert26 = (($$pre25) + 12|0);
  $$pre27 = HEAP32[$$phi$trans$insert26>>2]|0;
  $$phi$trans$insert28 = (($$pre27) + 20|0);
  $$pre29 = HEAP32[$$phi$trans$insert28>>2]|0;
  $$phi$trans$insert30 = (($this) + 12|0);
  $$pre31 = HEAP32[$$phi$trans$insert30>>2]|0;
  $$off0 = 1;$41 = $$pre29;$47 = $$pre31;
 } else {
  $3 = (($this) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$$pre>>2]|0;
  $6 = (($5) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($4<<2)|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = (Math_fround(($11<<16>>16)));
  $13 = (($4) + 1)|0;
  $14 = (($9) + ($13<<2)|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = (Math_fround(($15<<16>>16)));
  $17 = (($7) + 20|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($4))|0;
  $20 = (($9) + ($19<<2)|0);
  $21 = HEAP16[$20>>1]|0;
  $22 = (Math_fround(($21<<16>>16)));
  $23 = (($19) + 1)|0;
  $24 = (($9) + ($23<<2)|0);
  $25 = HEAP16[$24>>1]|0;
  $26 = (Math_fround(($25<<16>>16)));
  $27 = (($$pre) + 28|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = $28 < $12;
  $30 = $28 < $16;
  $or$cond$i = $29 & $30;
  $31 = $28 < $22;
  $or$cond1$i = $or$cond$i & $31;
  $32 = $28 < $26;
  $or$cond2$i = $or$cond1$i & $32;
  if ($or$cond2$i) {
   $$off0 = 0;$41 = $18;$47 = $4;
  } else {
   $33 = (($$pre) + 24|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = $34 > $12;
   $36 = $34 > $16;
   $or$cond3$i = $35 & $36;
   $37 = $34 > $22;
   $or$cond4$i = $or$cond3$i & $37;
   if ($or$cond4$i) {
    $phitmp$i = !($34 > $26);
    $$off0 = $phitmp$i;$41 = $18;$47 = $4;
   } else {
    $$off0 = 1;$41 = $18;$47 = $4;
   }
  }
 }
 $38 = (($$pre) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = Math_imul($41, $39)|0;
 $42 = (($$pre) + 20|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($40) + ($43))|0;
 $45 = (($this) + 12|0);
 $46 = ($47>>>0)<($44>>>0);
 if (!($46)) {
  STACKTOP = sp;return ($this|0);
 }
 $48 = (($this) + 4|0);
 $153 = $1;$154 = $47;$isec$0$off0$ph21 = $$off0;
 L10: while(1) {
  L12: do {
   if ($isec$0$off0$ph21) {
    $75 = $153;$82 = $154;
    while(1) {
     $$not = ($75|0)==(0);
     if ($$not) {
      HEAP32[$0>>2] = 1;
      $76 = HEAP32[$$pre>>2]|0;
      $77 = (($76) + 12|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($78) + 36|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = $82 & 2147483647;
      $83 = ((($80) + ($81<<2)|0) + 3|0);
      $$sink$i$i12 = HEAP8[$83>>0]|0;
      $84 = $$sink$i$i12 & 127;
      $85 = ($84<<24>>24)==(127);
      if ($85) {
       $111 = $82;$156 = 1;
      } else {
       label = 23;
       break L10;
      }
     } else {
      HEAP32[$0>>2] = 0;
      $86 = HEAP32[$48>>2]|0;
      $87 = (($86) + 1)|0;
      HEAP32[$48>>2] = $87;
      $88 = (($82) + 1)|0;
      HEAP32[$45>>2] = $88;
      $89 = HEAP32[$42>>2]|0;
      $90 = ($87|0)==($89|0);
      if (!($90)) {
       $120 = $88;
       break L12;
      }
      $91 = HEAP32[$this>>2]|0;
      $92 = (($91) + 1)|0;
      HEAP32[$this>>2] = $92;
      $93 = HEAP32[$$pre>>2]|0;
      $94 = (($93) + 12|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = (($95) + 20|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = HEAP32[$42>>2]|0;
      $99 = (($$pre) + 16|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = (($97) - ($98))|0;
      $102 = (($101) + ($100))|0;
      $103 = (($102) + ($88))|0;
      HEAP32[$45>>2] = $103;
      $104 = HEAP32[$38>>2]|0;
      $105 = ($92|0)==($104|0);
      if (!($105)) {
       $155 = $103;
       label = 18;
       break L12;
      }
      $106 = HEAP32[$42>>2]|0;
      $107 = HEAP32[$99>>2]|0;
      $108 = (($106) + ($103))|0;
      $109 = (($108) - ($107))|0;
      HEAP32[$45>>2] = $109;
      $111 = $109;$156 = 0;
     }
     $110 = ($111>>>0)<($44>>>0);
     if ($110) {
      $75 = $156;$82 = $111;
     } else {
      label = 23;
      break L10;
     }
    }
   } else {
    $52 = $154;
    while(1) {
     HEAP32[$0>>2] = 0;
     $49 = HEAP32[$48>>2]|0;
     $50 = (($49) + 1)|0;
     HEAP32[$48>>2] = $50;
     $51 = (($52) + 1)|0;
     HEAP32[$45>>2] = $51;
     $53 = HEAP32[$42>>2]|0;
     $54 = ($50|0)==($53|0);
     if (!($54)) {
      $120 = $51;
      break L12;
     }
     $55 = HEAP32[$this>>2]|0;
     $56 = (($55) + 1)|0;
     HEAP32[$this>>2] = $56;
     $57 = HEAP32[$$pre>>2]|0;
     $58 = (($57) + 12|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = (($59) + 20|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = HEAP32[$42>>2]|0;
     $63 = (($$pre) + 16|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($61) - ($62))|0;
     $66 = (($65) + ($64))|0;
     $67 = (($66) + ($51))|0;
     HEAP32[$45>>2] = $67;
     $68 = HEAP32[$38>>2]|0;
     $69 = ($56|0)==($68|0);
     if (!($69)) {
      $155 = $67;
      label = 18;
      break L12;
     }
     $70 = HEAP32[$42>>2]|0;
     $71 = HEAP32[$63>>2]|0;
     $72 = (($70) + ($67))|0;
     $73 = (($72) - ($71))|0;
     HEAP32[$45>>2] = $73;
     $74 = ($73>>>0)<($44>>>0);
     if ($74) {
      $52 = $73;
     } else {
      label = 23;
      break L10;
     }
    }
   }
  } while(0);
  if ((label|0) == 18) {
   label = 0;
   $112 = (($$pre) + 16|0);
   $113 = HEAP32[$112>>2]|0;
   HEAP32[$48>>2] = $113;
   $120 = $155;
  }
  $114 = HEAP32[$$pre>>2]|0;
  $115 = (($114) + 12|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($116) + 36|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($118) + ($120<<2)|0);
  $121 = HEAP16[$119>>1]|0;
  $122 = (Math_fround(($121<<16>>16)));
  $123 = (($120) + 1)|0;
  $124 = (($118) + ($123<<2)|0);
  $125 = HEAP16[$124>>1]|0;
  $126 = (Math_fround(($125<<16>>16)));
  $127 = (($116) + 20|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (($128) + ($120))|0;
  $130 = (($118) + ($129<<2)|0);
  $131 = HEAP16[$130>>1]|0;
  $132 = (Math_fround(($131<<16>>16)));
  $133 = (($129) + 1)|0;
  $134 = (($118) + ($133<<2)|0);
  $135 = HEAP16[$134>>1]|0;
  $136 = (Math_fround(($135<<16>>16)));
  $137 = (($$pre) + 28|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = $138 < $122;
  $140 = $138 < $126;
  $or$cond$i4 = $139 & $140;
  $141 = $138 < $132;
  $or$cond1$i5 = $or$cond$i4 & $141;
  $142 = $138 < $136;
  $or$cond2$i6 = $or$cond1$i5 & $142;
  if ($or$cond2$i6) {
   $isec$0$off0$ph$be = 0;
  } else {
   $143 = (($$pre) + 24|0);
   $144 = Math_fround(HEAPF32[$143>>2]);
   $145 = $144 > $122;
   $146 = $144 > $126;
   $or$cond3$i7 = $145 & $146;
   $147 = $144 > $132;
   $or$cond4$i8 = $or$cond3$i7 & $147;
   $or$cond4$i8$not = $or$cond4$i8 ^ 1;
   $phitmp$i9 = !($144 > $136);
   $or$cond = $phitmp$i9 | $or$cond4$i8$not;
   if ($or$cond) {
    $148 = $120 & 2147483647;
    $149 = ((($118) + ($148<<2)|0) + 2|0);
    $$sink$i$i = HEAP8[$149>>0]|0;
    $150 = $$sink$i$i & 127;
    $151 = ($150<<24>>24)==(127);
    if ($151) {
     $isec$0$off0$ph$be = 1;
    } else {
     label = 23;
     break;
    }
   } else {
    $isec$0$off0$ph$be = 0;
   }
  }
  $152 = ($120>>>0)<($44>>>0);
  if ($152) {
   $153 = 0;$154 = $120;$isec$0$off0$ph21 = $isec$0$off0$ph$be;
  } else {
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu11HeightField19getTriangleVerticesEjjjRNS_6PxVec3ES3_S3_($this,$triangleIndex,$row,$column,$v0,$v1,$v2) {
 $this = $this|0;
 $triangleIndex = $triangleIndex|0;
 $row = $row|0;
 $column = $column|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $triangleIndex >>> 1;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = (Math_fround(($4<<16>>16)));
 $6 = (($0) + 1)|0;
 $7 = (($2) + ($6<<2)|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = (Math_fround(($8<<16>>16)));
 $10 = (($this) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($0))|0;
 $13 = (($2) + ($12<<2)|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = (Math_fround(($14<<16>>16)));
 $16 = (($12) + 1)|0;
 $17 = (($2) + ($16<<2)|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = (Math_fround(($18<<16>>16)));
 $20 = $triangleIndex & 1;
 $21 = ($20|0)==(0);
 $22 = ((($2) + ($0<<2)|0) + 2|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)<(0);
 if ($21) {
  if ($24) {
   $25 = (($row) + 1)|0;
   $26 = (Math_fround(($25>>>0)));
   $27 = (Math_fround(($column>>>0)));
   HEAPF32[$v0>>2] = $26;
   $28 = (($v0) + 4|0);
   HEAPF32[$28>>2] = $15;
   $29 = (($v0) + 8|0);
   HEAPF32[$29>>2] = $27;
   $30 = (Math_fround(($row>>>0)));
   HEAPF32[$v1>>2] = $30;
   $31 = (($v1) + 4|0);
   HEAPF32[$31>>2] = $5;
   $32 = (($v1) + 8|0);
   HEAPF32[$32>>2] = $27;
   $33 = (($column) + 1)|0;
   $34 = (Math_fround(($33>>>0)));
   HEAPF32[$v2>>2] = $26;
   $35 = (($v2) + 4|0);
   HEAPF32[$35>>2] = $19;
   $36 = (($v2) + 8|0);
   HEAPF32[$36>>2] = $34;
   STACKTOP = sp;return;
  } else {
   $37 = (Math_fround(($row>>>0)));
   $38 = (Math_fround(($column>>>0)));
   HEAPF32[$v0>>2] = $37;
   $39 = (($v0) + 4|0);
   HEAPF32[$39>>2] = $5;
   $40 = (($v0) + 8|0);
   HEAPF32[$40>>2] = $38;
   $41 = (($column) + 1)|0;
   $42 = (Math_fround(($41>>>0)));
   HEAPF32[$v1>>2] = $37;
   $43 = (($v1) + 4|0);
   HEAPF32[$43>>2] = $9;
   $44 = (($v1) + 8|0);
   HEAPF32[$44>>2] = $42;
   $45 = (($row) + 1)|0;
   $46 = (Math_fround(($45>>>0)));
   HEAPF32[$v2>>2] = $46;
   $47 = (($v2) + 4|0);
   HEAPF32[$47>>2] = $15;
   $48 = (($v2) + 8|0);
   HEAPF32[$48>>2] = $38;
   STACKTOP = sp;return;
  }
 } else {
  if ($24) {
   $49 = (Math_fround(($row>>>0)));
   $50 = (($column) + 1)|0;
   $51 = (Math_fround(($50>>>0)));
   HEAPF32[$v0>>2] = $49;
   $52 = (($v0) + 4|0);
   HEAPF32[$52>>2] = $9;
   $53 = (($v0) + 8|0);
   HEAPF32[$53>>2] = $51;
   $54 = (($row) + 1)|0;
   $55 = (Math_fround(($54>>>0)));
   HEAPF32[$v1>>2] = $55;
   $56 = (($v1) + 4|0);
   HEAPF32[$56>>2] = $19;
   $57 = (($v1) + 8|0);
   HEAPF32[$57>>2] = $51;
   $58 = (Math_fround(($column>>>0)));
   HEAPF32[$v2>>2] = $49;
   $59 = (($v2) + 4|0);
   HEAPF32[$59>>2] = $5;
   $60 = (($v2) + 8|0);
   HEAPF32[$60>>2] = $58;
   STACKTOP = sp;return;
  } else {
   $61 = (($row) + 1)|0;
   $62 = (Math_fround(($61>>>0)));
   $63 = (($column) + 1)|0;
   $64 = (Math_fround(($63>>>0)));
   HEAPF32[$v0>>2] = $62;
   $65 = (($v0) + 4|0);
   HEAPF32[$65>>2] = $19;
   $66 = (($v0) + 8|0);
   HEAPF32[$66>>2] = $64;
   $67 = (Math_fround(($column>>>0)));
   HEAPF32[$v1>>2] = $62;
   $68 = (($v1) + 4|0);
   HEAPF32[$68>>2] = $15;
   $69 = (($v1) + 8|0);
   HEAPF32[$69>>2] = $67;
   $70 = (Math_fround(($row>>>0)));
   HEAPF32[$v2>>2] = $70;
   $71 = (($v2) + 4|0);
   HEAPF32[$71>>2] = $9;
   $72 = (($v2) + 8|0);
   HEAPF32[$72>>2] = $64;
   STACKTOP = sp;return;
  }
 }
}
function __ZN5physx22PxcHeightFieldAabbTestC2ERKNS_9PxBounds3ERKNS_2Gu15HeightFieldUtilE($this,$localBounds,$hfUtil) {
 $this = $this|0;
 $localBounds = $localBounds|0;
 $hfUtil = $hfUtil|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $or$cond = 0, $or$cond4 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $hfUtil;
 $0 = (($this) + 4|0);
 HEAP8[$0>>0] = 0;
 $1 = (($hfUtil) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$localBounds>>2]);
 $4 = (($localBounds) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($localBounds) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($localBounds) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($localBounds) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($localBounds) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$hfUtil>>2]);
 $15 = Math_fround($3 * $14);
 $16 = (($hfUtil) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($5 * $17);
 $19 = (($hfUtil) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($7 * $20);
 $22 = Math_fround($9 * $14);
 $23 = Math_fround($11 * $17);
 $24 = Math_fround($13 * $20);
 $25 = (($2) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = $26 < Math_fround(0.0);
 $28 = $27 ? $22 : $15;
 $29 = $27 ? $15 : $22;
 $30 = (($2) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = $31 < Math_fround(0.0);
 $33 = $32 ? $24 : $21;
 $34 = $32 ? $21 : $24;
 $35 = (($hfUtil) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 16|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + -1)|0;
 $40 = (Math_fround(($39>>>0)));
 $41 = $28 > $40;
 if (!($41)) {
  $42 = (($36) + 20|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + -1)|0;
  $45 = (Math_fround(($44>>>0)));
  $46 = $33 > $45;
  $47 = $29 < Math_fround(0.0);
  $or$cond = $46 | $47;
  $48 = $34 < Math_fround(0.0);
  $or$cond4 = $or$cond | $48;
  if (!($or$cond4)) {
   $49 = (Math_fround(Math_floor((Math_fround($28)))));
   $50 = (~~(($49)));
   $51 = (($38) + -2)|0;
   $52 = ($50|0)>(0);
   $53 = $52 ? $50 : 0;
   $54 = ($53|0)>($51|0);
   $55 = $54 ? $51 : $53;
   $56 = (($this) + 8|0);
   HEAP32[$56>>2] = $55;
   $57 = (Math_fround(Math_ceil((Math_fround($29)))));
   $58 = (~~(($57)));
   $59 = HEAP32[$37>>2]|0;
   $60 = (($59) + -1)|0;
   $61 = ($58|0)>(0);
   $62 = $61 ? $58 : 0;
   $63 = ($62|0)>($60|0);
   $64 = $63 ? $60 : $62;
   $65 = (($this) + 12|0);
   HEAP32[$65>>2] = $64;
   $66 = (Math_fround(Math_floor((Math_fround($33)))));
   $67 = (~~(($66)));
   $68 = HEAP32[$42>>2]|0;
   $69 = (($68) + -2)|0;
   $70 = ($67|0)>(0);
   $71 = $70 ? $67 : 0;
   $72 = ($71|0)>($69|0);
   $73 = $72 ? $69 : $71;
   $74 = (($this) + 16|0);
   HEAP32[$74>>2] = $73;
   $75 = (Math_fround(Math_ceil((Math_fround($34)))));
   $76 = (~~(($75)));
   $77 = HEAP32[$42>>2]|0;
   $78 = (($77) + -1)|0;
   $79 = ($76|0)>(0);
   $80 = $79 ? $76 : 0;
   $81 = ($80|0)>($78|0);
   $82 = $81 ? $78 : $80;
   $83 = (($this) + 20|0);
   HEAP32[$83>>2] = $82;
   $84 = ($55|0)==($64|0);
   $85 = ($73|0)==($82|0);
   $or$cond5 = $84 | $85;
   if ($or$cond5) {
    HEAP8[$0>>0] = 1;
    STACKTOP = sp;return;
   } else {
    $86 = (($this) + 24|0);
    HEAPF32[$86>>2] = $18;
    $87 = (($this) + 28|0);
    HEAPF32[$87>>2] = $23;
    $88 = (($36) + 40|0);
    $89 = Math_fround(HEAPF32[$88>>2]);
    $90 = $89 > Math_fround(0.0);
    $91 = $90&1;
    $92 = Math_fround(HEAPF32[$25>>2]);
    $93 = Math_fround(HEAPF32[$30>>2]);
    $94 = (HEAPF32[tempDoublePtr>>2]=$92,HEAP32[tempDoublePtr>>2]|0);
    $95 = (HEAPF32[tempDoublePtr>>2]=$93,HEAP32[tempDoublePtr>>2]|0);
    $96 = $95 ^ $94;
    $97 = $96 & -2147483648;
    $98 = ($91|0)!=($97|0);
    $99 = (($this) + 32|0);
    $100 = $98&1;
    HEAP8[$99>>0] = $100;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx27PxsFluidParticleOpcodeCache28writeTriangles_BaseU16_9xU10EPhPKjj($data,$triangles,$numTriangles) {
 $data = $data|0;
 $triangles = $triangles|0;
 $numTriangles = $numTriangles|0;
 var $$0 = 0, $$min$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond11 = 0, $i$0$minIndex$0 = 0, $i$04 = 0, $i1$01 = 0, $max$0$lcssa = 0, $max$02 = 0, $max$1 = 0;
 var $min$0$lcssa = 0, $min$05 = 0, $minIndex$0$lcssa = 0, $minIndex$03 = 0, $triCopy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $triCopy = sp;
 $0 = ($numTriangles|0)==(0);
 if ($0) {
  $max$0$lcssa = 0;$min$0$lcssa = -1;$minIndex$0$lcssa = -1;
 } else {
  $i$04 = 0;$max$02 = 0;$min$05 = -1;$minIndex$03 = -1;
  while(1) {
   $1 = (($triangles) + ($i$04<<2)|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = ($2>>>0)<($min$05>>>0);
   $i$0$minIndex$0 = $3 ? $i$04 : $minIndex$03;
   $$min$0 = $3 ? $2 : $min$05;
   $4 = ($2>>>0)>($max$02>>>0);
   $max$1 = $4 ? $2 : $max$02;
   $5 = (($i$04) + 1)|0;
   $exitcond11 = ($5|0)==($numTriangles|0);
   if ($exitcond11) {
    $max$0$lcssa = $max$1;$min$0$lcssa = $$min$0;$minIndex$0$lcssa = $i$0$minIndex$0;
    break;
   } else {
    $i$04 = $5;$max$02 = $max$1;$min$05 = $$min$0;$minIndex$03 = $i$0$minIndex$0;
   }
  }
 }
 $6 = (($max$0$lcssa) - ($min$0$lcssa))|0;
 $7 = ($6>>>0)<(1024);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($0)) {
  $i1$01 = 0;
  while(1) {
   $8 = (($triangles) + ($i1$01<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) - ($min$0$lcssa))|0;
   $11 = $10&65535;
   $12 = (($triCopy) + ($i1$01<<1)|0);
   HEAP16[$12>>1] = $11;
   $13 = (($i1$01) + 1)|0;
   $exitcond = ($13|0)==($numTriangles|0);
   if ($exitcond) {
    break;
   } else {
    $i1$01 = $13;
   }
  }
 }
 $14 = (($numTriangles) + -1)|0;
 $15 = (($triCopy) + ($14<<1)|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = (($triCopy) + ($minIndex$0$lcssa<<1)|0);
 HEAP16[$17>>1] = $16;
 $18 = $min$0$lcssa&65535;
 HEAP16[$data>>1] = $18;
 $19 = HEAP16[$triCopy>>1]|0;
 $20 = $19&65535;
 $21 = $20 << 6;
 $22 = (($triCopy) + 2|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = $23&65535;
 $25 = $24 >>> 4;
 $26 = $25 | $21;
 $27 = $26&65535;
 $28 = (($data) + 2|0);
 HEAP16[$28>>1] = $27;
 $29 = $24 << 12;
 $30 = (($triCopy) + 4|0);
 $31 = HEAP16[$30>>1]|0;
 $32 = $31&65535;
 $33 = $32 << 2;
 $34 = $33 | $29;
 $35 = (($triCopy) + 6|0);
 $36 = HEAP16[$35>>1]|0;
 $37 = $36&65535;
 $38 = $37 >>> 8;
 $39 = $34 | $38;
 $40 = $39&65535;
 $41 = (($data) + 4|0);
 HEAP16[$41>>1] = $40;
 $42 = $37 << 8;
 $43 = (($triCopy) + 8|0);
 $44 = HEAP16[$43>>1]|0;
 $45 = $44&65535;
 $46 = $45 >>> 2;
 $47 = $46 | $42;
 $48 = $47&65535;
 $49 = (($data) + 6|0);
 HEAP16[$49>>1] = $48;
 $50 = $45 << 14;
 $51 = (($triCopy) + 10|0);
 $52 = HEAP16[$51>>1]|0;
 $53 = $52&65535;
 $54 = $53 << 4;
 $55 = $54 | $50;
 $56 = (($triCopy) + 12|0);
 $57 = HEAP16[$56>>1]|0;
 $58 = $57&65535;
 $59 = $58 >>> 6;
 $60 = $55 | $59;
 $61 = $60&65535;
 $62 = (($data) + 8|0);
 HEAP16[$62>>1] = $61;
 $63 = $58 << 10;
 $64 = (($data) + 10|0);
 $65 = (($triCopy) + 14|0);
 $66 = HEAP16[$65>>1]|0;
 $67 = $66&65535;
 $68 = $63 | $67;
 $69 = $68&65535;
 HEAP16[$64>>1] = $69;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN26PxcContactCellMeshCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$hit,$v0,$v1,$v2,$0,$1) {
 $this = $this|0;
 $hit = $hit|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $collDataIndexIt$02$i = 0, $exitcond$i1 = 0, $i$01$i = 0, $verts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $verts = sp;
 $2 = Math_fround(HEAPF32[$v0>>2]);
 HEAPF32[$verts>>2] = $2;
 $3 = (($verts) + 4|0);
 $4 = (($v0) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$3>>2] = $5;
 $6 = (($verts) + 8|0);
 $7 = (($v0) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$6>>2] = $8;
 $9 = (($verts) + 12|0);
 $10 = Math_fround(HEAPF32[$v1>>2]);
 HEAPF32[$9>>2] = $10;
 $11 = (($verts) + 16|0);
 $12 = (($v1) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$11>>2] = $13;
 $14 = (($verts) + 20|0);
 $15 = (($v1) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$14>>2] = $16;
 $17 = (($verts) + 24|0);
 $18 = Math_fround(HEAPF32[$v2>>2]);
 HEAPF32[$17>>2] = $18;
 $19 = (($verts) + 28|0);
 $20 = (($v2) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 $22 = (($verts) + 32|0);
 $23 = (($v2) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$22>>2] = $24;
 $25 = (($this) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 16|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 24|0);
 $30 = (($this) + 96|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 104|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($28|0)==(0);
 if (!($34)) {
  $35 = (($this) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $collDataIndexIt$02$i = $36;$i$01$i = 0;
  while(1) {
   $37 = HEAP32[$collDataIndexIt$02$i>>2]|0;
   $38 = (($26) + (($37*176)|0)|0);
   __Z24collideWithMeshTrianglesRN5physx19PxsParticleCollDataERKNS_2Gu24InternalTriangleMeshDataERKNS_2Cm23FastVertex2ShapeScalingEPKNS_6PxVec3EjfRKNS_11PxTransformE($38,0,$29,$verts,1,$31,$33);
   $39 = (($i$01$i) + 1)|0;
   $40 = (($collDataIndexIt$02$i) + 4|0);
   $exitcond$i1 = ($39|0)==($28|0);
   if ($exitcond$i1) {
    break;
   } else {
    $collDataIndexIt$02$i = $40;$i$01$i = $39;
   }
  }
 }
 $41 = (($this) + 100|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return 1;
 }
 $44 = HEAP8[$42>>0]|0;
 $45 = $44&255;
 $46 = (($45) + 1)|0;
 $47 = ($46>>>0)<(10);
 if ($47) {
  $48 = (($hit) + 8|0);
  $49 = (($42) + 28|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = HEAP32[$48>>2]|0;
  $52 = (($50) + ($45<<2)|0);
  HEAP32[$52>>2] = $51;
 }
 $53 = $46&255;
 HEAP8[$42>>0] = $53;
 STACKTOP = sp;return 1;
}
function __ZN26PxcContactCellMeshCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($this,$scale,$rotation) {
 $this = $this|0;
 $scale = $scale|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $16 = Math_fround(0);
 var $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$rotation>>2]);
 $2 = (($rotation) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($rotation) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($rotation) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($1 + $1);
 $9 = Math_fround($3 + $3);
 $10 = Math_fround($5 + $5);
 $11 = Math_fround($1 * $8);
 $12 = Math_fround($3 * $9);
 $13 = Math_fround($5 * $10);
 $14 = Math_fround($8 * $3);
 $15 = Math_fround($8 * $5);
 $16 = Math_fround($8 * $7);
 $17 = Math_fround($9 * $5);
 $18 = Math_fround($9 * $7);
 $19 = Math_fround($10 * $7);
 $20 = Math_fround(Math_fround(1.0) - $12);
 $21 = Math_fround($20 - $13);
 $22 = Math_fround($14 + $19);
 $23 = Math_fround($15 - $18);
 $24 = Math_fround($14 - $19);
 $25 = Math_fround(Math_fround(1.0) - $11);
 $26 = Math_fround($25 - $13);
 $27 = Math_fround($17 + $16);
 $28 = Math_fround($15 + $18);
 $29 = Math_fround($17 - $16);
 $30 = Math_fround($25 - $12);
 HEAPF32[$this>>2] = $21;
 $31 = (($this) + 4|0);
 HEAPF32[$31>>2] = $24;
 $32 = (($this) + 8|0);
 HEAPF32[$32>>2] = $28;
 $33 = (($this) + 12|0);
 HEAPF32[$33>>2] = $22;
 $34 = (($this) + 16|0);
 HEAPF32[$34>>2] = $26;
 $35 = (($this) + 20|0);
 HEAPF32[$35>>2] = $29;
 $36 = (($this) + 24|0);
 HEAPF32[$36>>2] = $23;
 $37 = (($this) + 28|0);
 HEAPF32[$37>>2] = $27;
 $38 = (($this) + 32|0);
 HEAPF32[$38>>2] = $30;
 $39 = Math_fround(HEAPF32[$scale>>2]);
 $40 = (($scale) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($scale) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($39 * $21);
 $45 = Math_fround($39 * $24);
 $46 = Math_fround($39 * $28);
 $47 = Math_fround($22 * Math_fround(0.0));
 $48 = Math_fround($26 * Math_fround(0.0));
 $49 = Math_fround($29 * Math_fround(0.0));
 $50 = Math_fround($44 + $47);
 $51 = Math_fround($45 + $48);
 $52 = Math_fround($46 + $49);
 $53 = Math_fround($23 * Math_fround(0.0));
 $54 = Math_fround($27 * Math_fround(0.0));
 $55 = Math_fround($30 * Math_fround(0.0));
 $56 = Math_fround($50 + $53);
 $57 = Math_fround($51 + $54);
 $58 = Math_fround($55 + $52);
 $59 = Math_fround($21 * Math_fround(0.0));
 $60 = Math_fround($24 * Math_fround(0.0));
 $61 = Math_fround($28 * Math_fround(0.0));
 $62 = Math_fround($41 * $22);
 $63 = Math_fround($41 * $26);
 $64 = Math_fround($41 * $29);
 $65 = Math_fround($59 + $62);
 $66 = Math_fround($60 + $63);
 $67 = Math_fround($61 + $64);
 $68 = Math_fround($65 + $53);
 $69 = Math_fround($66 + $54);
 $70 = Math_fround($55 + $67);
 $71 = Math_fround($59 + $47);
 $72 = Math_fround($60 + $48);
 $73 = Math_fround($61 + $49);
 $74 = Math_fround($43 * $23);
 $75 = Math_fround($43 * $27);
 $76 = Math_fround($30 * $43);
 $77 = Math_fround($71 + $74);
 $78 = Math_fround($72 + $75);
 $79 = Math_fround($76 + $73);
 $80 = Math_fround($21 * $56);
 $81 = Math_fround($21 * $57);
 $82 = Math_fround($21 * $58);
 $83 = Math_fround($22 * $68);
 $84 = Math_fround($22 * $69);
 $85 = Math_fround($22 * $70);
 $86 = Math_fround($80 + $83);
 $87 = Math_fround($81 + $84);
 $88 = Math_fround($82 + $85);
 $89 = Math_fround($23 * $77);
 $90 = Math_fround($23 * $78);
 $91 = Math_fround($23 * $79);
 $92 = Math_fround($86 + $89);
 $93 = Math_fround($87 + $90);
 $94 = Math_fround($91 + $88);
 $95 = Math_fround($24 * $56);
 $96 = Math_fround($24 * $57);
 $97 = Math_fround($24 * $58);
 $98 = Math_fround($26 * $68);
 $99 = Math_fround($26 * $69);
 $100 = Math_fround($26 * $70);
 $101 = Math_fround($95 + $98);
 $102 = Math_fround($96 + $99);
 $103 = Math_fround($97 + $100);
 $104 = Math_fround($27 * $77);
 $105 = Math_fround($27 * $78);
 $106 = Math_fround($27 * $79);
 $107 = Math_fround($101 + $104);
 $108 = Math_fround($102 + $105);
 $109 = Math_fround($106 + $103);
 $110 = Math_fround($28 * $56);
 $111 = Math_fround($28 * $57);
 $112 = Math_fround($28 * $58);
 $113 = Math_fround($29 * $68);
 $114 = Math_fround($29 * $69);
 $115 = Math_fround($29 * $70);
 $116 = Math_fround($110 + $113);
 $117 = Math_fround($111 + $114);
 $118 = Math_fround($112 + $115);
 $119 = Math_fround($30 * $77);
 $120 = Math_fround($30 * $78);
 $121 = Math_fround($30 * $79);
 $122 = Math_fround($116 + $119);
 $123 = Math_fround($117 + $120);
 $124 = Math_fround($121 + $118);
 HEAPF32[$this>>2] = $92;
 HEAPF32[$31>>2] = $93;
 HEAPF32[$32>>2] = $94;
 HEAPF32[$33>>2] = $107;
 HEAPF32[$34>>2] = $108;
 HEAPF32[$35>>2] = $109;
 HEAPF32[$36>>2] = $122;
 HEAPF32[$37>>2] = $123;
 HEAPF32[$38>>2] = $124;
 __ZNK5physx7PxMat3310getInverseEv($0,$this);
 $125 = Math_fround(HEAPF32[$0>>2]);
 $126 = (($this) + 36|0);
 HEAPF32[$126>>2] = $125;
 $127 = (($0) + 4|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($this) + 40|0);
 HEAPF32[$129>>2] = $128;
 $130 = (($0) + 8|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($this) + 44|0);
 HEAPF32[$132>>2] = $131;
 $133 = (($0) + 12|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($this) + 48|0);
 HEAPF32[$135>>2] = $134;
 $136 = (($0) + 16|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($this) + 52|0);
 HEAPF32[$138>>2] = $137;
 $139 = (($0) + 20|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($this) + 56|0);
 HEAPF32[$141>>2] = $140;
 $142 = (($0) + 24|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($this) + 60|0);
 HEAPF32[$144>>2] = $143;
 $145 = (($0) + 28|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($this) + 64|0);
 HEAPF32[$147>>2] = $146;
 $148 = (($0) + 32|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($this) + 68|0);
 HEAPF32[$150>>2] = $149;
 STACKTOP = sp;return;
}
function __Z17setConstraintDataRN5physx19PxsParticleCollDataERKfRKNS_6PxVec3ES6_RKNS_11PxTransformE($collData,$distToSurface,$normal,$position,$shape2World) {
 $collData = $collData|0;
 $distToSurface = $distToSurface|0;
 $normal = $normal|0;
 $position = $position|0;
 $shape2World = $shape2World|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert4 = 0, $$pre = 0, $$pre3 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0);
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0);
 var $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0);
 var $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0);
 var $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0);
 var $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0);
 var $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0);
 var $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0);
 var $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0);
 var $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0);
 var $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = 0, $47 = Math_fround(0), $470 = 0;
 var $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = 0, $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($collData) + 62|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $179 = Math_fround(HEAPF32[$normal>>2]);
   $180 = Math_fround($179 * Math_fround(2.0));
   $181 = (($normal) + 4|0);
   $182 = Math_fround(HEAPF32[$181>>2]);
   $183 = Math_fround($182 * Math_fround(2.0));
   $184 = (($normal) + 8|0);
   $185 = Math_fround(HEAPF32[$184>>2]);
   $186 = Math_fround($185 * Math_fround(2.0));
   $187 = (($shape2World) + 12|0);
   $188 = Math_fround(HEAPF32[$187>>2]);
   $189 = Math_fround($188 * $188);
   $190 = Math_fround($189 + Math_fround(-0.5));
   $191 = Math_fround(HEAPF32[$shape2World>>2]);
   $192 = Math_fround($180 * $191);
   $193 = (($shape2World) + 4|0);
   $194 = Math_fround(HEAPF32[$193>>2]);
   $195 = Math_fround($183 * $194);
   $196 = Math_fround($192 + $195);
   $197 = (($shape2World) + 8|0);
   $198 = Math_fround(HEAPF32[$197>>2]);
   $199 = Math_fround($186 * $198);
   $200 = Math_fround($196 + $199);
   $201 = Math_fround($180 * $190);
   $202 = Math_fround($186 * $194);
   $203 = Math_fround($183 * $198);
   $204 = Math_fround($202 - $203);
   $205 = Math_fround($188 * $204);
   $206 = Math_fround($201 + $205);
   $207 = Math_fround($191 * $200);
   $208 = Math_fround($207 + $206);
   $209 = Math_fround($183 * $190);
   $210 = Math_fround($180 * $198);
   $211 = Math_fround($186 * $191);
   $212 = Math_fround($210 - $211);
   $213 = Math_fround($188 * $212);
   $214 = Math_fround($209 + $213);
   $215 = Math_fround($194 * $200);
   $216 = Math_fround($215 + $214);
   $217 = Math_fround($186 * $190);
   $218 = Math_fround($183 * $191);
   $219 = Math_fround($180 * $194);
   $220 = Math_fround($218 - $219);
   $221 = Math_fround($188 * $220);
   $222 = Math_fround($217 + $221);
   $223 = Math_fround($198 * $200);
   $224 = Math_fround($222 + $223);
   $225 = Math_fround(HEAPF32[$position>>2]);
   $226 = Math_fround($225 * Math_fround(2.0));
   $227 = (($position) + 4|0);
   $228 = Math_fround(HEAPF32[$227>>2]);
   $229 = Math_fround($228 * Math_fround(2.0));
   $230 = (($position) + 8|0);
   $231 = Math_fround(HEAPF32[$230>>2]);
   $232 = Math_fround($231 * Math_fround(2.0));
   $233 = Math_fround($191 * $226);
   $234 = Math_fround($194 * $229);
   $235 = Math_fround($233 + $234);
   $236 = Math_fround($198 * $232);
   $237 = Math_fround($235 + $236);
   $238 = Math_fround($190 * $226);
   $239 = Math_fround($194 * $232);
   $240 = Math_fround($198 * $229);
   $241 = Math_fround($239 - $240);
   $242 = Math_fround($188 * $241);
   $243 = Math_fround($238 + $242);
   $244 = Math_fround($191 * $237);
   $245 = Math_fround($244 + $243);
   $246 = Math_fround($190 * $229);
   $247 = Math_fround($198 * $226);
   $248 = Math_fround($191 * $232);
   $249 = Math_fround($247 - $248);
   $250 = Math_fround($188 * $249);
   $251 = Math_fround($246 + $250);
   $252 = Math_fround($194 * $237);
   $253 = Math_fround($252 + $251);
   $254 = Math_fround($190 * $232);
   $255 = Math_fround($191 * $229);
   $256 = Math_fround($194 * $226);
   $257 = Math_fround($255 - $256);
   $258 = Math_fround($188 * $257);
   $259 = Math_fround($254 + $258);
   $260 = Math_fround($198 * $237);
   $261 = Math_fround($259 + $260);
   $262 = (($shape2World) + 16|0);
   $263 = Math_fround(HEAPF32[$262>>2]);
   $264 = Math_fround($263 + $245);
   $265 = (($shape2World) + 20|0);
   $266 = Math_fround(HEAPF32[$265>>2]);
   $267 = Math_fround($266 + $253);
   $268 = (($shape2World) + 24|0);
   $269 = Math_fround(HEAPF32[$268>>2]);
   $270 = Math_fround($269 + $261);
   $271 = Math_fround($208 * $264);
   $272 = Math_fround($216 * $267);
   $273 = Math_fround($271 + $272);
   $274 = Math_fround($224 * $270);
   $275 = Math_fround($274 + $273);
   $$phi$trans$insert = (($collData) + 140|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $$pre3 = HEAP16[$0>>1]|0;
   $276 = $208;$277 = $$pre;$279 = $216;$281 = $224;$283 = $275;$285 = $$pre3;
  } else {
   $5 = $2 & 2;
   $6 = ($5|0)==(0);
   do {
    if ($6) {
     $289 = Math_fround(HEAPF32[$normal>>2]);
     $290 = Math_fround($289 * Math_fround(2.0));
     $291 = (($normal) + 4|0);
     $292 = Math_fround(HEAPF32[$291>>2]);
     $293 = Math_fround($292 * Math_fround(2.0));
     $294 = (($normal) + 8|0);
     $295 = Math_fround(HEAPF32[$294>>2]);
     $296 = Math_fround($295 * Math_fround(2.0));
     $297 = (($shape2World) + 12|0);
     $298 = Math_fround(HEAPF32[$297>>2]);
     $299 = Math_fround($298 * $298);
     $300 = Math_fround($299 + Math_fround(-0.5));
     $301 = Math_fround(HEAPF32[$shape2World>>2]);
     $302 = Math_fround($290 * $301);
     $303 = (($shape2World) + 4|0);
     $304 = Math_fround(HEAPF32[$303>>2]);
     $305 = Math_fround($293 * $304);
     $306 = Math_fround($302 + $305);
     $307 = (($shape2World) + 8|0);
     $308 = Math_fround(HEAPF32[$307>>2]);
     $309 = Math_fround($296 * $308);
     $310 = Math_fround($306 + $309);
     $311 = Math_fround($290 * $300);
     $312 = Math_fround($296 * $304);
     $313 = Math_fround($293 * $308);
     $314 = Math_fround($312 - $313);
     $315 = Math_fround($298 * $314);
     $316 = Math_fround($311 + $315);
     $317 = Math_fround($301 * $310);
     $318 = Math_fround($317 + $316);
     $319 = Math_fround($293 * $300);
     $320 = Math_fround($290 * $308);
     $321 = Math_fround($296 * $301);
     $322 = Math_fround($320 - $321);
     $323 = Math_fround($298 * $322);
     $324 = Math_fround($319 + $323);
     $325 = Math_fround($304 * $310);
     $326 = Math_fround($325 + $324);
     $327 = Math_fround($296 * $300);
     $328 = Math_fround($293 * $301);
     $329 = Math_fround($290 * $304);
     $330 = Math_fround($328 - $329);
     $331 = Math_fround($298 * $330);
     $332 = Math_fround($327 + $331);
     $333 = Math_fround($308 * $310);
     $334 = Math_fround($332 + $333);
     $335 = Math_fround(HEAPF32[$position>>2]);
     $336 = Math_fround($335 * Math_fround(2.0));
     $337 = (($position) + 4|0);
     $338 = Math_fround(HEAPF32[$337>>2]);
     $339 = Math_fround($338 * Math_fround(2.0));
     $340 = (($position) + 8|0);
     $341 = Math_fround(HEAPF32[$340>>2]);
     $342 = Math_fround($341 * Math_fround(2.0));
     $343 = Math_fround($301 * $336);
     $344 = Math_fround($304 * $339);
     $345 = Math_fround($343 + $344);
     $346 = Math_fround($308 * $342);
     $347 = Math_fround($345 + $346);
     $348 = Math_fround($300 * $336);
     $349 = Math_fround($304 * $342);
     $350 = Math_fround($308 * $339);
     $351 = Math_fround($349 - $350);
     $352 = Math_fround($298 * $351);
     $353 = Math_fround($348 + $352);
     $354 = Math_fround($301 * $347);
     $355 = Math_fround($354 + $353);
     $356 = Math_fround($300 * $339);
     $357 = Math_fround($308 * $336);
     $358 = Math_fround($301 * $342);
     $359 = Math_fround($357 - $358);
     $360 = Math_fround($298 * $359);
     $361 = Math_fround($356 + $360);
     $362 = Math_fround($304 * $347);
     $363 = Math_fround($362 + $361);
     $364 = Math_fround($300 * $342);
     $365 = Math_fround($301 * $339);
     $366 = Math_fround($304 * $336);
     $367 = Math_fround($365 - $366);
     $368 = Math_fround($298 * $367);
     $369 = Math_fround($364 + $368);
     $370 = Math_fround($308 * $347);
     $371 = Math_fround($369 + $370);
     $372 = (($shape2World) + 16|0);
     $373 = Math_fround(HEAPF32[$372>>2]);
     $374 = Math_fround($373 + $355);
     $375 = (($shape2World) + 20|0);
     $376 = Math_fround(HEAPF32[$375>>2]);
     $377 = Math_fround($376 + $363);
     $378 = (($shape2World) + 24|0);
     $379 = Math_fround(HEAPF32[$378>>2]);
     $380 = Math_fround($379 + $371);
     $381 = Math_fround($318 * $374);
     $382 = Math_fround($326 * $377);
     $383 = Math_fround($381 + $382);
     $384 = Math_fround($334 * $380);
     $385 = Math_fround($384 + $383);
     $$phi$trans$insert4 = (($collData) + 156|0);
     $$pre5 = HEAP32[$$phi$trans$insert4>>2]|0;
     $$pre6 = HEAP16[$0>>1]|0;
     $468 = $318;$469 = $$pre5;$471 = $326;$473 = $334;$475 = $385;$477 = $$pre6;
    } else {
     $7 = (($collData) + 112|0);
     $8 = Math_fround(HEAPF32[$7>>2]);
     $9 = Math_fround($8 * Math_fround(2.0));
     $10 = (($collData) + 116|0);
     $11 = Math_fround(HEAPF32[$10>>2]);
     $12 = Math_fround($11 * Math_fround(2.0));
     $13 = (($collData) + 120|0);
     $14 = Math_fround(HEAPF32[$13>>2]);
     $15 = Math_fround($14 * Math_fround(2.0));
     $16 = (($shape2World) + 12|0);
     $17 = Math_fround(HEAPF32[$16>>2]);
     $18 = Math_fround($17 * $17);
     $19 = Math_fround($18 + Math_fround(-0.5));
     $20 = Math_fround(HEAPF32[$shape2World>>2]);
     $21 = Math_fround($9 * $20);
     $22 = (($shape2World) + 4|0);
     $23 = Math_fround(HEAPF32[$22>>2]);
     $24 = Math_fround($12 * $23);
     $25 = Math_fround($21 + $24);
     $26 = (($shape2World) + 8|0);
     $27 = Math_fround(HEAPF32[$26>>2]);
     $28 = Math_fround($15 * $27);
     $29 = Math_fround($25 + $28);
     $30 = Math_fround($9 * $19);
     $31 = Math_fround($15 * $23);
     $32 = Math_fround($12 * $27);
     $33 = Math_fround($31 - $32);
     $34 = Math_fround($17 * $33);
     $35 = Math_fround($30 + $34);
     $36 = Math_fround($20 * $29);
     $37 = Math_fround($36 + $35);
     $38 = Math_fround($12 * $19);
     $39 = Math_fround($9 * $27);
     $40 = Math_fround($15 * $20);
     $41 = Math_fround($39 - $40);
     $42 = Math_fround($17 * $41);
     $43 = Math_fround($38 + $42);
     $44 = Math_fround($23 * $29);
     $45 = Math_fround($44 + $43);
     $46 = Math_fround($15 * $19);
     $47 = Math_fround($12 * $20);
     $48 = Math_fround($9 * $23);
     $49 = Math_fround($47 - $48);
     $50 = Math_fround($17 * $49);
     $51 = Math_fround($46 + $50);
     $52 = Math_fround($27 * $29);
     $53 = Math_fround($51 + $52);
     $54 = (($shape2World) + 16|0);
     $55 = Math_fround(HEAPF32[$54>>2]);
     $56 = Math_fround($55 + $37);
     $57 = (($shape2World) + 20|0);
     $58 = Math_fround(HEAPF32[$57>>2]);
     $59 = Math_fround($58 + $45);
     $60 = (($shape2World) + 24|0);
     $61 = Math_fround(HEAPF32[$60>>2]);
     $62 = Math_fround($61 + $53);
     $63 = (($collData) + 140|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = Math_fround(HEAPF32[$64>>2]);
     $66 = Math_fround($65 * $56);
     $67 = (($64) + 4|0);
     $68 = Math_fround(HEAPF32[$67>>2]);
     $69 = Math_fround($68 * $59);
     $70 = Math_fround($66 + $69);
     $71 = (($64) + 8|0);
     $72 = Math_fround(HEAPF32[$71>>2]);
     $73 = Math_fround($62 * $72);
     $74 = Math_fround($70 + $73);
     $75 = (($64) + 12|0);
     $76 = Math_fround(HEAPF32[$75>>2]);
     $77 = Math_fround($74 - $76);
     $78 = (($collData) + 156|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = Math_fround(HEAPF32[$79>>2]);
     $81 = Math_fround($56 * $80);
     $82 = (($79) + 4|0);
     $83 = Math_fround(HEAPF32[$82>>2]);
     $84 = Math_fround($59 * $83);
     $85 = Math_fround($81 + $84);
     $86 = (($79) + 8|0);
     $87 = Math_fround(HEAPF32[$86>>2]);
     $88 = Math_fround($62 * $87);
     $89 = Math_fround($85 + $88);
     $90 = (($79) + 12|0);
     $91 = Math_fround(HEAPF32[$90>>2]);
     $92 = Math_fround($89 - $91);
     $93 = $77 < $92;
     $94 = Math_fround(HEAPF32[$distToSurface>>2]);
     if ($93) {
      $95 = $94 < $92;
      if ($95) {
       $386 = Math_fround(HEAPF32[$normal>>2]);
       $387 = Math_fround($386 * Math_fround(2.0));
       $388 = (($normal) + 4|0);
       $389 = Math_fround(HEAPF32[$388>>2]);
       $390 = Math_fround($389 * Math_fround(2.0));
       $391 = (($normal) + 8|0);
       $392 = Math_fround(HEAPF32[$391>>2]);
       $393 = Math_fround($392 * Math_fround(2.0));
       $394 = Math_fround($20 * $387);
       $395 = Math_fround($23 * $390);
       $396 = Math_fround($394 + $395);
       $397 = Math_fround($27 * $393);
       $398 = Math_fround($396 + $397);
       $399 = Math_fround($19 * $387);
       $400 = Math_fround($23 * $393);
       $401 = Math_fround($27 * $390);
       $402 = Math_fround($400 - $401);
       $403 = Math_fround($17 * $402);
       $404 = Math_fround($399 + $403);
       $405 = Math_fround($20 * $398);
       $406 = Math_fround($405 + $404);
       $407 = Math_fround($19 * $390);
       $408 = Math_fround($27 * $387);
       $409 = Math_fround($20 * $393);
       $410 = Math_fround($408 - $409);
       $411 = Math_fround($17 * $410);
       $412 = Math_fround($407 + $411);
       $413 = Math_fround($23 * $398);
       $414 = Math_fround($413 + $412);
       $415 = Math_fround($19 * $393);
       $416 = Math_fround($20 * $390);
       $417 = Math_fround($23 * $387);
       $418 = Math_fround($416 - $417);
       $419 = Math_fround($17 * $418);
       $420 = Math_fround($415 + $419);
       $421 = Math_fround($27 * $398);
       $422 = Math_fround($420 + $421);
       $423 = Math_fround(HEAPF32[$position>>2]);
       $424 = Math_fround($423 * Math_fround(2.0));
       $425 = (($position) + 4|0);
       $426 = Math_fround(HEAPF32[$425>>2]);
       $427 = Math_fround($426 * Math_fround(2.0));
       $428 = (($position) + 8|0);
       $429 = Math_fround(HEAPF32[$428>>2]);
       $430 = Math_fround($429 * Math_fround(2.0));
       $431 = Math_fround($20 * $424);
       $432 = Math_fround($23 * $427);
       $433 = Math_fround($431 + $432);
       $434 = Math_fround($27 * $430);
       $435 = Math_fround($433 + $434);
       $436 = Math_fround($19 * $424);
       $437 = Math_fround($23 * $430);
       $438 = Math_fround($27 * $427);
       $439 = Math_fround($437 - $438);
       $440 = Math_fround($17 * $439);
       $441 = Math_fround($436 + $440);
       $442 = Math_fround($20 * $435);
       $443 = Math_fround($442 + $441);
       $444 = Math_fround($19 * $427);
       $445 = Math_fround($27 * $424);
       $446 = Math_fround($20 * $430);
       $447 = Math_fround($445 - $446);
       $448 = Math_fround($17 * $447);
       $449 = Math_fround($444 + $448);
       $450 = Math_fround($23 * $435);
       $451 = Math_fround($450 + $449);
       $452 = Math_fround($19 * $430);
       $453 = Math_fround($20 * $427);
       $454 = Math_fround($23 * $424);
       $455 = Math_fround($453 - $454);
       $456 = Math_fround($17 * $455);
       $457 = Math_fround($452 + $456);
       $458 = Math_fround($27 * $435);
       $459 = Math_fround($457 + $458);
       $460 = Math_fround($55 + $443);
       $461 = Math_fround($58 + $451);
       $462 = Math_fround($61 + $459);
       $463 = Math_fround($406 * $460);
       $464 = Math_fround($414 * $461);
       $465 = Math_fround($463 + $464);
       $466 = Math_fround($422 * $462);
       $467 = Math_fround($466 + $465);
       $468 = $406;$469 = $79;$471 = $414;$473 = $422;$475 = $467;$477 = $1;
       break;
      } else {
       STACKTOP = sp;return;
      }
     } else {
      $96 = $94 < $77;
      if ($96) {
       $97 = Math_fround(HEAPF32[$normal>>2]);
       $98 = Math_fround($97 * Math_fround(2.0));
       $99 = (($normal) + 4|0);
       $100 = Math_fround(HEAPF32[$99>>2]);
       $101 = Math_fround($100 * Math_fround(2.0));
       $102 = (($normal) + 8|0);
       $103 = Math_fround(HEAPF32[$102>>2]);
       $104 = Math_fround($103 * Math_fround(2.0));
       $105 = Math_fround($20 * $98);
       $106 = Math_fround($23 * $101);
       $107 = Math_fround($105 + $106);
       $108 = Math_fround($27 * $104);
       $109 = Math_fround($107 + $108);
       $110 = Math_fround($19 * $98);
       $111 = Math_fround($23 * $104);
       $112 = Math_fround($27 * $101);
       $113 = Math_fround($111 - $112);
       $114 = Math_fround($17 * $113);
       $115 = Math_fround($110 + $114);
       $116 = Math_fround($20 * $109);
       $117 = Math_fround($116 + $115);
       $118 = Math_fround($19 * $101);
       $119 = Math_fround($27 * $98);
       $120 = Math_fround($20 * $104);
       $121 = Math_fround($119 - $120);
       $122 = Math_fround($17 * $121);
       $123 = Math_fround($118 + $122);
       $124 = Math_fround($23 * $109);
       $125 = Math_fround($124 + $123);
       $126 = Math_fround($19 * $104);
       $127 = Math_fround($20 * $101);
       $128 = Math_fround($23 * $98);
       $129 = Math_fround($127 - $128);
       $130 = Math_fround($17 * $129);
       $131 = Math_fround($126 + $130);
       $132 = Math_fround($27 * $109);
       $133 = Math_fround($131 + $132);
       $134 = Math_fround(HEAPF32[$position>>2]);
       $135 = Math_fround($134 * Math_fround(2.0));
       $136 = (($position) + 4|0);
       $137 = Math_fround(HEAPF32[$136>>2]);
       $138 = Math_fround($137 * Math_fround(2.0));
       $139 = (($position) + 8|0);
       $140 = Math_fround(HEAPF32[$139>>2]);
       $141 = Math_fround($140 * Math_fround(2.0));
       $142 = Math_fround($20 * $135);
       $143 = Math_fround($23 * $138);
       $144 = Math_fround($142 + $143);
       $145 = Math_fround($27 * $141);
       $146 = Math_fround($144 + $145);
       $147 = Math_fround($19 * $135);
       $148 = Math_fround($23 * $141);
       $149 = Math_fround($27 * $138);
       $150 = Math_fround($148 - $149);
       $151 = Math_fround($17 * $150);
       $152 = Math_fround($147 + $151);
       $153 = Math_fround($20 * $146);
       $154 = Math_fround($153 + $152);
       $155 = Math_fround($19 * $138);
       $156 = Math_fround($27 * $135);
       $157 = Math_fround($20 * $141);
       $158 = Math_fround($156 - $157);
       $159 = Math_fround($17 * $158);
       $160 = Math_fround($155 + $159);
       $161 = Math_fround($23 * $146);
       $162 = Math_fround($161 + $160);
       $163 = Math_fround($19 * $141);
       $164 = Math_fround($20 * $138);
       $165 = Math_fround($23 * $135);
       $166 = Math_fround($164 - $165);
       $167 = Math_fround($17 * $166);
       $168 = Math_fround($163 + $167);
       $169 = Math_fround($27 * $146);
       $170 = Math_fround($168 + $169);
       $171 = Math_fround($55 + $154);
       $172 = Math_fround($58 + $162);
       $173 = Math_fround($61 + $170);
       $174 = Math_fround($117 * $171);
       $175 = Math_fround($125 * $172);
       $176 = Math_fround($174 + $175);
       $177 = Math_fround($133 * $173);
       $178 = Math_fround($177 + $176);
       $276 = $117;$277 = $64;$279 = $125;$281 = $133;$283 = $178;$285 = $1;
       break L1;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   } while(0);
   HEAPF32[$469>>2] = $468;
   $470 = (($469) + 4|0);
   HEAPF32[$470>>2] = $471;
   $472 = (($469) + 8|0);
   HEAPF32[$472>>2] = $473;
   $474 = (($469) + 12|0);
   HEAPF32[$474>>2] = $475;
   $476 = $477&65535;
   $478 = $476 & 65525;
   $479 = $478 | 2;
   $480 = $479&65535;
   HEAP16[$0>>1] = $480;
   STACKTOP = sp;return;
  }
 } while(0);
 HEAPF32[$277>>2] = $276;
 $278 = (($277) + 4|0);
 HEAPF32[$278>>2] = $279;
 $280 = (($277) + 8|0);
 HEAPF32[$280>>2] = $281;
 $282 = (($277) + 12|0);
 HEAPF32[$282>>2] = $283;
 $284 = $285&65535;
 $286 = $284 & 65530;
 $287 = $286 | 1;
 $288 = $287&65535;
 HEAP16[$0>>1] = $288;
 STACKTOP = sp;return;
}
function __ZN5physx16collideWithPlaneEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($particleCollData,$numCollData,$planeShape,$proxRadius) {
 $particleCollData = $particleCollData|0;
 $numCollData = $numCollData|0;
 $planeShape = $planeShape|0;
 $proxRadius = Math_fround($proxRadius);
 var $0 = 0, $1 = 0, $2 = 0, $exitcond = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numCollData|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $p$01 = 0;
 }
 while(1) {
  $1 = (($particleCollData) + (($p$01*176)|0)|0);
  __ZN5physx16collideWithPlaneERNS_19PxsParticleCollDataEf($1,$proxRadius);
  $2 = (($p$01) + 1)|0;
  $exitcond = ($2|0)==($numCollData|0);
  if ($exitcond) {
   break;
  } else {
   $p$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16collideWithPlaneERNS_19PxsParticleCollDataEf($collData,$proxRadius) {
 $collData = $collData|0;
 $proxRadius = Math_fround($proxRadius);
 var $$not = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $brmerge2 = 0, $brmerge4 = 0, $entryTime$0 = Math_fround(0), $hasDC$0$off08 = 0, $hasProx$1$off0 = 0, $hasProx$1$off07 = 0, $not$ = 0, $parallelMotion$0$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($collData) + 128|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($collData) + 112|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $not$ = $3 <= Math_fround(0.0);
 $4 = !($1 <= $proxRadius);
 if ($4) {
  $hasProx$1$off0 = 0;
  label = 3;
 } else {
  $5 = $1 > Math_fround(0.0);
  $6 = (($collData) + 92|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = !($1 <= $7);
  if ($8) {
   $hasProx$1$off0 = $5;
   label = 3;
  } else {
   $hasDC$0$off08 = 1;$hasProx$1$off07 = $5;
  }
 }
 if ((label|0) == 3) {
  $brmerge2 = $hasProx$1$off0 | $not$;
  if ($brmerge2) {
   $hasDC$0$off08 = 0;$hasProx$1$off07 = $hasProx$1$off0;
  } else {
   STACKTOP = sp;return;
  }
 }
 $9 = Math_fround($1 - $3);
 $10 = (($collData) + 132|0);
 $11 = (($collData) + 116|0);
 $12 = (($collData) + 136|0);
 $13 = (($collData) + 120|0);
 $14 = $9 == Math_fround(0.0);
 if ($14) {
  $15 = $1 > Math_fround(0.0);
  if ($15) {
   $entryTime$0 = Math_fround(-3.40282346638528859812E+38);$parallelMotion$0$off0 = 1;
  } else {
   $entryTime$0 = Math_fround(-3.40282346638528859812E+38);$parallelMotion$0$off0 = 0;
  }
 } else {
  $16 = $9 < Math_fround(0.0);
  if ($16) {
   $17 = Math_fround(-$3);
   $18 = Math_fround($17 / $9);
   $entryTime$0 = $18;$parallelMotion$0$off0 = 0;
  } else {
   $entryTime$0 = Math_fround(-3.40282346638528859812E+38);$parallelMotion$0$off0 = 0;
  }
 }
 if ($not$) {
  $19 = (($collData) + 124|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20 | 8;
  HEAP32[$19>>2] = $21;
  $22 = (($collData) + 44|0);
  HEAPF32[$22>>2] = Math_fround(0.0);
  $23 = (($collData) + 144|0);
  HEAPF32[$23>>2] = Math_fround(1.0);
  $24 = (($collData) + 148|0);
  HEAPF32[$24>>2] = Math_fround(0.0);
  $25 = (($collData) + 152|0);
  HEAPF32[$25>>2] = Math_fround(0.0);
  $26 = (($collData) + 160|0);
  $27 = Math_fround(HEAPF32[$11>>2]);
  $28 = (($collData) + 164|0);
  HEAPF32[$28>>2] = $27;
  $29 = Math_fround(HEAPF32[$13>>2]);
  $30 = (($collData) + 168|0);
  HEAPF32[$30>>2] = $29;
  $31 = (($collData) + 92|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($32 - $3);
  $34 = Math_fround($3 + $33);
  HEAPF32[$26>>2] = $34;
  STACKTOP = sp;return;
 }
 $35 = !($entryTime$0 >= Math_fround(0.0));
 if (!($35)) {
  $36 = (($collData) + 44|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $$not = !($entryTime$0 < $37);
  $brmerge4 = $$not | $parallelMotion$0$off0;
  if (!($brmerge4)) {
   $38 = (($collData) + 144|0);
   HEAPF32[$38>>2] = Math_fround(1.0);
   $39 = (($collData) + 148|0);
   HEAPF32[$39>>2] = Math_fround(0.0);
   $40 = (($collData) + 152|0);
   HEAPF32[$40>>2] = Math_fround(0.0);
   $41 = (($collData) + 160|0);
   HEAPF32[$41>>2] = $3;
   $42 = Math_fround(HEAPF32[$11>>2]);
   $43 = (($collData) + 164|0);
   HEAPF32[$43>>2] = $42;
   $44 = Math_fround(HEAPF32[$13>>2]);
   $45 = (($collData) + 168|0);
   HEAPF32[$45>>2] = $44;
   HEAPF32[$36>>2] = $entryTime$0;
   $46 = (($collData) + 124|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | 8;
   HEAP32[$46>>2] = $48;
   STACKTOP = sp;return;
  }
 }
 $49 = (($collData) + 124|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 2;
 $52 = ($51|0)==(0);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 if ($hasProx$1$off07) {
  $53 = $50 | 32;
  HEAP32[$49>>2] = $53;
  $55 = $53;
 } else {
  $55 = $50;
 }
 if ($hasDC$0$off08) {
  $54 = $55 | 16;
  HEAP32[$49>>2] = $54;
 }
 $56 = (($collData) + 144|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($collData) + 148|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($collData) + 152|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($collData) + 160|0);
 $60 = Math_fround(HEAPF32[$10>>2]);
 $61 = (($collData) + 164|0);
 HEAPF32[$61>>2] = $60;
 $62 = Math_fround(HEAPF32[$12>>2]);
 $63 = (($collData) + 168|0);
 HEAPF32[$63>>2] = $62;
 $64 = (($collData) + 92|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 - $1);
 $67 = Math_fround($1 + $66);
 HEAPF32[$59>>2] = $67;
 STACKTOP = sp;return;
}
function __ZN5physx17collideWithSphereEPNS_19PxsParticleCollDataEjRKNS_2Gu13GeometryUnionEf($particleCollData,$numCollData,$sphereShape,$proxRadius) {
 $particleCollData = $particleCollData|0;
 $numCollData = $numCollData|0;
 $sphereShape = $sphereShape|0;
 $proxRadius = Math_fround($proxRadius);
 var $0 = 0, $1 = 0, $2 = 0, $exitcond = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numCollData|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $p$01 = 0;
 }
 while(1) {
  $1 = (($particleCollData) + (($p$01*176)|0)|0);
  __ZN5physx17collideWithSphereERNS_19PxsParticleCollDataERKNS_16PxSphereGeometryEf($1,$sphereShape,$proxRadius);
  $2 = (($p$01) + 1)|0;
  $exitcond = ($2|0)==($numCollData|0);
  if ($exitcond) {
   break;
  } else {
   $p$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx17collideWithSphereERNS_19PxsParticleCollDataERKNS_16PxSphereGeometryEf($collData,$sphereShapeData,$proxRadius) {
 $collData = $collData|0;
 $sphereShapeData = $sphereShapeData|0;
 $proxRadius = Math_fround($proxRadius);
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0;
 var $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond2 = 0, $storemerge = Math_fround(0), $storemerge$i = Math_fround(0), $storemerge$i3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($sphereShapeData) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($collData) + 112|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = (($collData) + 116|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $6);
 $8 = Math_fround($4 + $7);
 $9 = (($collData) + 120|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $10);
 $12 = Math_fround($8 + $11);
 $13 = Math_fround($1 * $1);
 $14 = $12 < $13;
 if ($14) {
  $15 = (($collData) + 144|0);
  HEAPF32[$15>>2] = $3;
  $16 = (($collData) + 148|0);
  HEAPF32[$16>>2] = $6;
  $17 = (($collData) + 152|0);
  HEAPF32[$17>>2] = $10;
  $18 = $12 > Math_fround(0.0);
  if ($18) {
   $19 = (Math_fround(Math_sqrt((Math_fround($12)))));
   $20 = Math_fround(Math_fround(1.0) / $19);
   $21 = Math_fround($20 * $3);
   HEAPF32[$15>>2] = $21;
   $22 = Math_fround($20 * $6);
   HEAPF32[$16>>2] = $22;
   $23 = Math_fround($20 * $10);
   $28 = $21;$30 = $22;$storemerge = $23;
  } else {
   HEAPF32[$15>>2] = Math_fround(0.0);
   HEAPF32[$16>>2] = Math_fround(1.0);
   $28 = Math_fround(0.0);$30 = Math_fround(1.0);$storemerge = Math_fround(0.0);
  }
  HEAPF32[$17>>2] = $storemerge;
  $24 = (($collData) + 92|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($1 + $25);
  $27 = Math_fround($28 * $26);
  $29 = Math_fround($26 * $30);
  $31 = Math_fround($26 * $storemerge);
  $32 = (($collData) + 160|0);
  HEAPF32[$32>>2] = $27;
  $33 = (($collData) + 164|0);
  HEAPF32[$33>>2] = $29;
  $34 = (($collData) + 168|0);
  HEAPF32[$34>>2] = $31;
  $35 = (($collData) + 44|0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  $36 = (($collData) + 124|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = $37 | 8;
  HEAP32[$36>>2] = $38;
  STACKTOP = sp;return;
 }
 $39 = (($collData) + 128|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($40 - $3);
 $42 = (($collData) + 132|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 - $6);
 $45 = (($collData) + 136|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 - $10);
 $48 = Math_fround($3 * $41);
 $49 = Math_fround($6 * $44);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($10 * $47);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($52 * Math_fround(2.0));
 $54 = Math_fround($41 * $41);
 $55 = Math_fround($44 * $44);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($47 * $47);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($58 * Math_fround(2.0));
 $60 = Math_fround($53 * $53);
 $61 = Math_fround($59 * Math_fround(2.0));
 $62 = Math_fround($12 - $13);
 $63 = Math_fround($62 * $61);
 $64 = Math_fround($60 - $63);
 $65 = !($64 > Math_fround(0.0));
 $66 = $59 == Math_fround(0.0);
 $or$cond2 = $65 | $66;
 if ($or$cond2) {
  $67 = (($collData) + 124|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = $68 & 2;
  $70 = ($69|0)==(0);
  if (!($70)) {
   STACKTOP = sp;return;
  }
  $71 = Math_fround($40 * $40);
  $72 = Math_fround($43 * $43);
  $73 = Math_fround($71 + $72);
  $74 = Math_fround($46 * $46);
  $75 = Math_fround($73 + $74);
  $76 = (Math_fround(Math_sqrt((Math_fround($75)))));
  $77 = (($collData) + 144|0);
  HEAPF32[$77>>2] = $40;
  $78 = (($collData) + 148|0);
  HEAPF32[$78>>2] = $43;
  $79 = (($collData) + 152|0);
  HEAPF32[$79>>2] = $46;
  $80 = Math_fround($1 + $proxRadius);
  $81 = $76 < $80;
  if (!($81)) {
   STACKTOP = sp;return;
  }
  $82 = $76 != Math_fround(0.0);
  if ($82) {
   $83 = Math_fround(Math_fround(1.0) / $76);
   $84 = Math_fround($40 * $83);
   HEAPF32[$77>>2] = $84;
   $85 = Math_fround($43 * $83);
   HEAPF32[$78>>2] = $85;
   $86 = Math_fround($46 * $83);
   $91 = $84;$93 = $85;$storemerge$i3 = $86;
  } else {
   HEAPF32[$77>>2] = Math_fround(0.0);
   HEAPF32[$78>>2] = Math_fround(0.0);
   $91 = Math_fround(0.0);$93 = Math_fround(0.0);$storemerge$i3 = Math_fround(0.0);
  }
  HEAPF32[$79>>2] = $storemerge$i3;
  $87 = (($collData) + 92|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($1 + $88);
  $90 = Math_fround($91 * $89);
  $92 = Math_fround($93 * $89);
  $94 = Math_fround($storemerge$i3 * $89);
  $95 = (($collData) + 160|0);
  HEAPF32[$95>>2] = $90;
  $96 = (($collData) + 164|0);
  HEAPF32[$96>>2] = $92;
  $97 = (($collData) + 168|0);
  HEAPF32[$97>>2] = $94;
  $98 = $68 | 32;
  HEAP32[$67>>2] = $98;
  $99 = $76 < $89;
  if (!($99)) {
   STACKTOP = sp;return;
  }
  $100 = $68 | 48;
  HEAP32[$67>>2] = $100;
  STACKTOP = sp;return;
 }
 $101 = (Math_fround(Math_sqrt((Math_fround($64)))));
 $102 = Math_fround($53 + $101);
 $103 = Math_fround(-$102);
 $104 = Math_fround($103 / $59);
 $105 = $104 < Math_fround(0.0);
 $106 = $104 > Math_fround(1.0);
 $or$cond = $105 | $106;
 if (!($or$cond)) {
  $141 = (($collData) + 44|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = $104 < $142;
  if (!($143)) {
   STACKTOP = sp;return;
  }
  $144 = Math_fround($41 * $104);
  $145 = Math_fround($44 * $104);
  $146 = Math_fround($47 * $104);
  $147 = Math_fround($3 + $144);
  $148 = Math_fround($6 + $145);
  $149 = Math_fround($10 + $146);
  $150 = (($collData) + 144|0);
  $151 = (($collData) + 148|0);
  $152 = (($collData) + 152|0);
  $153 = Math_fround(Math_fround(1.0) / $1);
  $154 = Math_fround($153 * $147);
  HEAPF32[$150>>2] = $154;
  $155 = Math_fround($153 * $148);
  HEAPF32[$151>>2] = $155;
  $156 = Math_fround($153 * $149);
  HEAPF32[$152>>2] = $156;
  $157 = (($collData) + 160|0);
  HEAPF32[$157>>2] = $3;
  $158 = (($collData) + 164|0);
  HEAPF32[$158>>2] = $6;
  $159 = (($collData) + 168|0);
  HEAPF32[$159>>2] = $10;
  HEAPF32[$141>>2] = $104;
  $160 = (($collData) + 124|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = $161 | 8;
  HEAP32[$160>>2] = $162;
  STACKTOP = sp;return;
 }
 $107 = (($collData) + 124|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = $108 & 2;
 $110 = ($109|0)==(0);
 if (!($110)) {
  STACKTOP = sp;return;
 }
 $111 = Math_fround($40 * $40);
 $112 = Math_fround($43 * $43);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($46 * $46);
 $115 = Math_fround($113 + $114);
 $116 = (Math_fround(Math_sqrt((Math_fround($115)))));
 $117 = (($collData) + 144|0);
 HEAPF32[$117>>2] = $40;
 $118 = (($collData) + 148|0);
 HEAPF32[$118>>2] = $43;
 $119 = (($collData) + 152|0);
 HEAPF32[$119>>2] = $46;
 $120 = Math_fround($1 + $proxRadius);
 $121 = $116 < $120;
 if (!($121)) {
  STACKTOP = sp;return;
 }
 $122 = $116 != Math_fround(0.0);
 if ($122) {
  $123 = Math_fround(Math_fround(1.0) / $116);
  $124 = Math_fround($40 * $123);
  HEAPF32[$117>>2] = $124;
  $125 = Math_fround($43 * $123);
  HEAPF32[$118>>2] = $125;
  $126 = Math_fround($46 * $123);
  $131 = $124;$133 = $125;$storemerge$i = $126;
 } else {
  HEAPF32[$117>>2] = Math_fround(0.0);
  HEAPF32[$118>>2] = Math_fround(0.0);
  $131 = Math_fround(0.0);$133 = Math_fround(0.0);$storemerge$i = Math_fround(0.0);
 }
 HEAPF32[$119>>2] = $storemerge$i;
 $127 = (($collData) + 92|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($1 + $128);
 $130 = Math_fround($131 * $129);
 $132 = Math_fround($133 * $129);
 $134 = Math_fround($storemerge$i * $129);
 $135 = (($collData) + 160|0);
 HEAPF32[$135>>2] = $130;
 $136 = (($collData) + 164|0);
 HEAPF32[$136>>2] = $132;
 $137 = (($collData) + 168|0);
 HEAPF32[$137>>2] = $134;
 $138 = $108 | 32;
 HEAP32[$107>>2] = $138;
 $139 = $116 < $129;
 if (!($139)) {
  STACKTOP = sp;return;
 }
 $140 = $108 | 48;
 HEAP32[$107>>2] = $140;
 STACKTOP = sp;return;
}
function __ZN5physx20updateCellsSubpacketENS_16PxsSphUpdateTypeEPNS_6PxVec3EPNS_16PxsFluidParticleEPKNS_15PxsParticleCellEPKjjRKNS_26PxsFluidDynamicsParametersERNS_27PxsFluidDynamicsTempBuffersE($updateType,$forceBuf,$particles,$cells,$particleIndices,$numCellHashBuckets,$params,$tempBuffers) {
 $updateType = $updateType|0;
 $forceBuf = $forceBuf|0;
 $particles = $particles|0;
 $cells = $cells|0;
 $particleIndices = $particleIndices|0;
 $numCellHashBuckets = $numCellHashBuckets|0;
 $params = $params|0;
 $tempBuffers = $tempBuffers|0;
 var $$0$i = 0, $$pre$pre = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$013 = 0, $exitcond = 0, $exitcond16 = 0, $exitcond18 = 0, $exitcond19 = 0, $i$09 = 0, $n$04 = 0, $n1$012 = 0, $neighborCells = 0, $p$06 = 0, $sext = 0, $sext2 = 0, $sext3 = 0, $srcIndexCount$011 = 0, $srcIndexCount$18 = 0;
 var $srcIndexCount$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $neighborCells = sp;
 $0 = ($numCellHashBuckets|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($numCellHashBuckets) + -1)|0;
 $2 = (($tempBuffers) + 8|0);
 $3 = ($updateType|0)==(0);
 $4 = (($tempBuffers) + 28|0);
 $5 = (($tempBuffers) + 32|0);
 $c$013 = 0;
 while(1) {
  $6 = ((($cells) + ($c$013<<4)|0) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(-1);
  if (!($8)) {
   $9 = (($cells) + ($c$013<<4)|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = ((($cells) + ($c$013<<4)|0) + 2|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = ((($cells) + ($c$013<<4)|0) + 4|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = $10&65535;
   $16 = $12&65535;
   $17 = $14&65535;
   $n$04 = 0;
   while(1) {
    $18 = (494304 + (($n$04*6)|0)|0);
    $19 = HEAP16[$18>>1]|0;
    $20 = $19&65535;
    $21 = (($20) + ($15))|0;
    $22 = $21&65535;
    $23 = ((494304 + (($n$04*6)|0)|0) + 2|0);
    $24 = HEAP16[$23>>1]|0;
    $25 = $24&65535;
    $26 = (($25) + ($16))|0;
    $27 = $26&65535;
    $28 = ((494304 + (($n$04*6)|0)|0) + 4|0);
    $29 = HEAP16[$28>>1]|0;
    $30 = $29&65535;
    $31 = (($30) + ($17))|0;
    $32 = $31&65535;
    $sext = $21 << 16;
    $33 = $sext >> 16;
    $sext2 = $26 << 16;
    $34 = $sext2 >> 16;
    $35 = ($34*101)|0;
    $36 = (($35) + ($33))|0;
    $sext3 = $31 << 16;
    $37 = $sext3 >> 16;
    $38 = ($37*7919)|0;
    $39 = (($36) + ($38))|0;
    $40 = $39 & $1;
    $41 = ((($cells) + ($40<<4)|0) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(-1);
    L10: do {
     if ($43) {
      $$0$i = 0;
     } else {
      $$pre$pre = $42;$45 = $40;
      while(1) {
       $44 = (($cells) + ($45<<4)|0);
       $46 = HEAP16[$44>>1]|0;
       $47 = ($22<<16>>16)==($46<<16>>16);
       if ($47) {
        $48 = ((($cells) + ($45<<4)|0) + 2|0);
        $49 = HEAP16[$48>>1]|0;
        $50 = ($27<<16>>16)==($49<<16>>16);
        if ($50) {
         $51 = ((($cells) + ($45<<4)|0) + 4|0);
         $52 = HEAP16[$51>>1]|0;
         $53 = ($32<<16>>16)==($52<<16>>16);
         if ($53) {
          break;
         }
        }
       }
       $54 = (($45) + 1)|0;
       $55 = $54 & $1;
       $56 = ((($cells) + ($55<<4)|0) + 8|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = ($57|0)==(-1);
       if ($58) {
        $$0$i = 0;
        break L10;
       } else {
        $$pre$pre = $57;$45 = $55;
       }
      }
      $59 = ($$pre$pre|0)==(-1);
      if ($59) {
       $$0$i = 0;
      } else {
       $60 = (($cells) + ($45<<4)|0);
       $$0$i = $60;
      }
     }
    } while(0);
    $61 = (($neighborCells) + ($n$04<<2)|0);
    HEAP32[$61>>2] = $$0$i;
    $62 = (($n$04) + 1)|0;
    $exitcond = ($62|0)==(13);
    if ($exitcond) {
     break;
    } else {
     $n$04 = $62;
    }
   }
   $63 = ($7>>>0)>(1);
   if ($63) {
    $64 = ((($cells) + ($c$013<<4)|0) + 12|0);
    $69 = $7;$p$06 = 1;
    while(1) {
     $65 = HEAP32[$64>>2]|0;
     $$sum = (($65) + ($p$06))|0;
     $66 = (($particleIndices) + ($$sum<<2)|0);
     $$sum1 = (($$sum) + -1)|0;
     $67 = (($particleIndices) + ($$sum1<<2)|0);
     $68 = (($69) - ($p$06))|0;
     $70 = HEAP32[$4>>2]|0;
     $71 = HEAP32[$5>>2]|0;
     __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($forceBuf,$forceBuf,$particles,$particles,$67,1,$66,$68,1,$3,$params,$70,$71);
     $72 = (($p$06) + 1)|0;
     $73 = HEAP32[$6>>2]|0;
     $74 = ($72>>>0)<($73>>>0);
     if ($74) {
      $69 = $73;$p$06 = $72;
     } else {
      $n1$012 = 0;$srcIndexCount$011 = 0;
      break;
     }
    }
   } else {
    $n1$012 = 0;$srcIndexCount$011 = 0;
   }
   while(1) {
    $75 = (($neighborCells) + ($n1$012<<2)|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($76|0)==(0|0);
    if ($77) {
     $srcIndexCount$2 = $srcIndexCount$011;
    } else {
     $78 = (($76) + 12|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($76) + 8|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($81) + ($79))|0;
     $83 = ($79>>>0)<($82>>>0);
     if ($83) {
      $84 = HEAP32[$2>>2]|0;
      $i$09 = $79;$srcIndexCount$18 = $srcIndexCount$011;
      while(1) {
       $85 = (($particleIndices) + ($i$09<<2)|0);
       $86 = HEAP32[$85>>2]|0;
       $87 = (($srcIndexCount$18) + 1)|0;
       $88 = (($84) + ($srcIndexCount$18<<2)|0);
       HEAP32[$88>>2] = $86;
       $89 = (($i$09) + 1)|0;
       $exitcond16 = ($89|0)==($82|0);
       if ($exitcond16) {
        break;
       } else {
        $i$09 = $89;$srcIndexCount$18 = $87;
       }
      }
      $90 = (($srcIndexCount$011) + ($81))|0;
      $srcIndexCount$2 = $90;
     } else {
      $srcIndexCount$2 = $srcIndexCount$011;
     }
    }
    $91 = (($n1$012) + 1)|0;
    $exitcond18 = ($91|0)==(13);
    if ($exitcond18) {
     break;
    } else {
     $n1$012 = $91;$srcIndexCount$011 = $srcIndexCount$2;
    }
   }
   $92 = ($srcIndexCount$2|0)==(0);
   if (!($92)) {
    $93 = ((($cells) + ($c$013<<4)|0) + 12|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($particleIndices) + ($94<<2)|0);
    $96 = HEAP32[$6>>2]|0;
    $97 = HEAP32[$2>>2]|0;
    $98 = HEAP32[$4>>2]|0;
    $99 = HEAP32[$5>>2]|0;
    __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($forceBuf,$forceBuf,$particles,$particles,$95,$96,$97,$srcIndexCount$2,1,$3,$params,$98,$99);
   }
  }
  $100 = (($c$013) + 1)|0;
  $exitcond19 = ($100|0)==($numCellHashBuckets|0);
  if ($exitcond19) {
   break;
  } else {
   $c$013 = $100;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($forceBufA,$forceBufB,$particlesA,$particlesB,$particleIndicesA,$numParticlesA,$particleIndicesB,$numParticlesB,$twoWayUpdate,$isDensityMode,$params,$tempSimdPositionBuffer,$tempIndexStream) {
 $forceBufA = $forceBufA|0;
 $forceBufB = $forceBufB|0;
 $particlesA = $particlesA|0;
 $particlesB = $particlesB|0;
 $particleIndicesA = $particleIndicesA|0;
 $numParticlesA = $numParticlesA|0;
 $particleIndicesB = $particleIndicesB|0;
 $numParticlesB = $numParticlesB|0;
 $twoWayUpdate = $twoWayUpdate|0;
 $isDensityMode = $isDensityMode|0;
 $params = $params|0;
 $tempSimdPositionBuffer = $tempSimdPositionBuffer|0;
 $tempIndexStream = $tempIndexStream|0;
 var $$demorgan$i = 0, $$demorgan548$i = 0, $$demorgan549$i = 0, $$demorgan550$i = 0, $$demorgan555$i = 0, $$demorgan556$i = 0, $$demorgan557$i = 0, $$demorgan558$i = 0, $$in1$i$i = 0, $$in1$i92$i = 0, $$in2$i$i = 0, $$in2$i94$i = 0, $$in3$i$i = 0, $$in3$i96$i = 0, $$pre = Math_fround(0), $$promoted$i$i = Math_fround(0), $$promoted$i16$i = Math_fround(0), $$promoted$i27$i = Math_fround(0), $$promoted$i6$i = Math_fround(0), $$sum559$i = 0;
 var $$sum560$i = 0, $$sum561$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0);
 var $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = Math_fround(0), $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = Math_fround(0), $1030 = Math_fround(0);
 var $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = 0, $1036 = Math_fround(0), $1037 = 0, $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = Math_fround(0), $1040 = 0, $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0);
 var $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = 0, $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = 0, $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0);
 var $1068 = 0, $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0), $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0);
 var $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = Math_fround(0), $1090 = Math_fround(0), $1091 = 0, $1092 = 0, $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0);
 var $1103 = 0, $1104 = Math_fround(0), $1105 = 0, $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = 0, $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0);
 var $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = 0, $1129 = Math_fround(0), $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = 0, $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = 0, $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0);
 var $114 = Math_fround(0), $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = Math_fround(0);
 var $1158 = Math_fround(0), $1159 = 0, $116 = Math_fround(0), $1160 = 0, $1161 = Math_fround(0), $1162 = Math_fround(0), $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0), $1169 = Math_fround(0), $117 = Math_fround(0), $1170 = Math_fround(0), $1171 = 0, $1172 = Math_fround(0), $1173 = 0, $1174 = Math_fround(0), $1175 = Math_fround(0);
 var $1176 = 0, $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = Math_fround(0), $1180 = Math_fround(0), $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0), $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = Math_fround(0), $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = 0, $1190 = Math_fround(0), $1191 = Math_fround(0), $1192 = Math_fround(0), $1193 = Math_fround(0);
 var $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = 0, $1197 = Math_fround(0), $1198 = Math_fround(0), $1199 = Math_fround(0), $12 = 0, $120 = 0, $1200 = 0, $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = 0, $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = Math_fround(0), $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = 0, $1210 = Math_fround(0);
 var $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = Math_fround(0), $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = Math_fround(0), $1217 = Math_fround(0), $1218 = Math_fround(0), $1219 = Math_fround(0), $122 = 0, $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = Math_fround(0), $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = 0, $1228 = 0, $1229 = Math_fround(0);
 var $123 = 0, $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = Math_fround(0), $1233 = Math_fround(0), $1234 = Math_fround(0), $1235 = Math_fround(0), $1236 = Math_fround(0), $1237 = Math_fround(0), $1238 = Math_fround(0), $1239 = 0, $124 = 0, $1240 = Math_fround(0), $1241 = 0, $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = 0, $1245 = Math_fround(0), $1246 = Math_fround(0), $1247 = Math_fround(0);
 var $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = 0, $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0), $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = 0, $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = 0, $1265 = Math_fround(0);
 var $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = 0, $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = 0, $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = Math_fround(0), $1276 = Math_fround(0), $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = Math_fround(0), $1280 = Math_fround(0), $1281 = Math_fround(0), $1282 = Math_fround(0), $1283 = Math_fround(0);
 var $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = Math_fround(0), $1287 = Math_fround(0), $1288 = Math_fround(0), $1289 = Math_fround(0), $129 = Math_fround(0), $1290 = Math_fround(0), $1291 = Math_fround(0), $1292 = Math_fround(0), $1293 = Math_fround(0), $1294 = Math_fround(0), $1295 = 0, $1296 = 0, $1297 = Math_fround(0), $1298 = 0, $1299 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $1300 = 0;
 var $1301 = Math_fround(0), $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = Math_fround(0), $1310 = 0, $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = 0, $1314 = Math_fround(0), $1315 = Math_fround(0), $1316 = 0, $1317 = Math_fround(0), $1318 = Math_fround(0), $1319 = Math_fround(0);
 var $132 = Math_fround(0), $1320 = Math_fround(0), $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = 0, $1325 = 0, $1326 = 0, $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = Math_fround(0), $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = 0;
 var $1338 = Math_fround(0), $1339 = 0, $134 = Math_fround(0), $1340 = Math_fround(0), $1341 = Math_fround(0), $1342 = 0, $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0);
 var $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = Math_fround(0), $136 = Math_fround(0), $1360 = Math_fround(0), $1361 = Math_fround(0), $1362 = 0, $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = 0, $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = Math_fround(0), $1370 = 0, $1371 = Math_fround(0), $1372 = Math_fround(0), $1373 = Math_fround(0);
 var $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = Math_fround(0), $1379 = Math_fround(0), $138 = 0, $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = 0, $1390 = Math_fround(0), $1391 = Math_fround(0);
 var $1392 = Math_fround(0), $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = Math_fround(0), $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0;
 var $141 = Math_fround(0), $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = Math_fround(0), $1420 = Math_fround(0), $1421 = 0, $1422 = 0, $1423 = Math_fround(0), $1424 = 0, $1425 = Math_fround(0), $1426 = Math_fround(0), $1427 = 0;
 var $1428 = 0, $1429 = Math_fround(0), $143 = Math_fround(0), $1430 = 0, $1431 = Math_fround(0), $1432 = Math_fround(0), $1433 = 0, $1434 = 0, $1435 = Math_fround(0), $1436 = 0, $1437 = Math_fround(0), $1438 = Math_fround(0), $1439 = 0, $144 = Math_fround(0), $1440 = 0, $1441 = Math_fround(0), $1442 = 0, $1443 = Math_fround(0), $1444 = 0, $1445 = 0;
 var $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = Math_fround(0), $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = Math_fround(0), $1460 = 0, $1461 = 0, $1462 = 0, $1463 = Math_fround(0);
 var $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = Math_fround(0), $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = Math_fround(0), $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = Math_fround(0), $1480 = Math_fround(0), $1481 = 0;
 var $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = Math_fround(0), $1487 = 0, $1488 = 0, $1489 = 0, $149 = Math_fround(0), $1490 = 0, $1491 = 0, $1492 = Math_fround(0), $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = Math_fround(0), $1499 = 0, $15 = 0;
 var $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = Math_fround(0), $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = Math_fround(0), $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0;
 var $1518 = 0, $1519 = 0, $152 = Math_fround(0), $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = Math_fround(0), $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0;
 var $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = Math_fround(0), $1540 = Math_fround(0), $1541 = 0, $1542 = Math_fround(0), $1543 = 0, $1544 = Math_fround(0), $1545 = Math_fround(0), $1546 = Math_fround(0), $1547 = Math_fround(0), $1548 = Math_fround(0), $1549 = Math_fround(0), $155 = Math_fround(0), $1550 = Math_fround(0), $1551 = Math_fround(0), $1552 = Math_fround(0), $1553 = Math_fround(0);
 var $1554 = Math_fround(0), $1555 = Math_fround(0), $1556 = Math_fround(0), $1557 = Math_fround(0), $1558 = Math_fround(0), $1559 = Math_fround(0), $156 = Math_fround(0), $1560 = Math_fround(0), $1561 = Math_fround(0), $1562 = Math_fround(0), $1563 = Math_fround(0), $1564 = Math_fround(0), $1565 = Math_fround(0), $1566 = Math_fround(0), $1567 = Math_fround(0), $1568 = Math_fround(0), $1569 = Math_fround(0), $157 = Math_fround(0), $1570 = Math_fround(0), $1571 = Math_fround(0);
 var $1572 = Math_fround(0), $1573 = Math_fround(0), $1574 = Math_fround(0), $1575 = Math_fround(0), $1576 = Math_fround(0), $1577 = Math_fround(0), $1578 = Math_fround(0), $1579 = Math_fround(0), $158 = Math_fround(0), $1580 = Math_fround(0), $1581 = Math_fround(0), $1582 = Math_fround(0), $1583 = Math_fround(0), $1584 = Math_fround(0), $1585 = Math_fround(0), $1586 = Math_fround(0), $1587 = Math_fround(0), $1588 = Math_fround(0), $1589 = 0, $159 = 0;
 var $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = Math_fround(0), $1599 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $1600 = Math_fround(0), $1601 = 0, $1602 = Math_fround(0), $1603 = 0, $1604 = Math_fround(0), $1605 = 0, $1606 = Math_fround(0), $1607 = 0;
 var $1608 = Math_fround(0), $1609 = 0, $161 = Math_fround(0), $1610 = Math_fround(0), $1611 = 0, $1612 = Math_fround(0), $1613 = 0, $1614 = Math_fround(0), $1615 = 0, $1616 = Math_fround(0), $1617 = 0, $1618 = Math_fround(0), $1619 = 0, $162 = 0, $1620 = Math_fround(0), $1621 = Math_fround(0), $1622 = Math_fround(0), $1623 = Math_fround(0), $1624 = Math_fround(0), $1625 = Math_fround(0);
 var $1626 = Math_fround(0), $1627 = Math_fround(0), $1628 = Math_fround(0), $1629 = Math_fround(0), $163 = 0, $1630 = Math_fround(0), $1631 = Math_fround(0), $1632 = Math_fround(0), $1633 = Math_fround(0), $1634 = Math_fround(0), $1635 = Math_fround(0), $1636 = Math_fround(0), $1637 = Math_fround(0), $1638 = Math_fround(0), $1639 = Math_fround(0), $164 = Math_fround(0), $1640 = Math_fround(0), $1641 = Math_fround(0), $1642 = Math_fround(0), $1643 = Math_fround(0);
 var $1644 = Math_fround(0), $1645 = Math_fround(0), $1646 = Math_fround(0), $1647 = Math_fround(0), $1648 = Math_fround(0), $1649 = Math_fround(0), $165 = Math_fround(0), $1650 = Math_fround(0), $1651 = Math_fround(0), $1652 = Math_fround(0), $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = Math_fround(0), $1660 = 0, $1661 = 0;
 var $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = Math_fround(0), $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = Math_fround(0);
 var $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = Math_fround(0), $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0;
 var $1699 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = Math_fround(0), $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0;
 var $1716 = Math_fround(0), $1717 = 0, $1718 = Math_fround(0), $1719 = 0, $172 = Math_fround(0), $1720 = Math_fround(0), $1721 = Math_fround(0), $1722 = Math_fround(0), $1723 = Math_fround(0), $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = Math_fround(0), $1729 = Math_fround(0), $173 = Math_fround(0), $1730 = 0, $1731 = Math_fround(0), $1732 = Math_fround(0), $1733 = 0;
 var $1734 = Math_fround(0), $1735 = Math_fround(0), $1736 = Math_fround(0), $1737 = Math_fround(0), $1738 = Math_fround(0), $1739 = Math_fround(0), $174 = 0, $1740 = Math_fround(0), $1741 = Math_fround(0), $1742 = Math_fround(0), $1743 = Math_fround(0), $1744 = Math_fround(0), $1745 = Math_fround(0), $1746 = Math_fround(0), $1747 = 0, $1748 = Math_fround(0), $1749 = Math_fround(0), $175 = 0, $1750 = 0, $1751 = 0;
 var $1752 = 0, $1753 = 0, $1754 = Math_fround(0), $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = Math_fround(0), $1764 = 0, $1765 = Math_fround(0), $1766 = 0, $1767 = Math_fround(0), $1768 = Math_fround(0), $1769 = Math_fround(0), $177 = 0;
 var $1770 = Math_fround(0), $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = Math_fround(0), $1776 = Math_fround(0), $1777 = 0, $1778 = Math_fround(0), $1779 = Math_fround(0), $178 = 0, $1780 = 0, $1781 = Math_fround(0), $1782 = Math_fround(0), $1783 = Math_fround(0), $1784 = Math_fround(0), $1785 = Math_fround(0), $1786 = Math_fround(0), $1787 = Math_fround(0), $1788 = Math_fround(0);
 var $1789 = Math_fround(0), $179 = 0, $1790 = Math_fround(0), $1791 = Math_fround(0), $1792 = Math_fround(0), $1793 = Math_fround(0), $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = Math_fround(0), $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = Math_fround(0);
 var $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = Math_fround(0), $1815 = 0, $1816 = Math_fround(0), $1817 = 0, $1818 = Math_fround(0), $1819 = Math_fround(0), $182 = 0, $1820 = Math_fround(0), $1821 = Math_fround(0), $1822 = 0, $1823 = 0;
 var $1824 = 0, $1825 = 0, $1826 = Math_fround(0), $1827 = Math_fround(0), $1828 = 0, $1829 = Math_fround(0), $183 = 0, $1830 = Math_fround(0), $1831 = 0, $1832 = Math_fround(0), $1833 = Math_fround(0), $1834 = Math_fround(0), $1835 = Math_fround(0), $1836 = Math_fround(0), $1837 = Math_fround(0), $1838 = Math_fround(0), $1839 = Math_fround(0), $184 = Math_fround(0), $1840 = Math_fround(0), $1841 = Math_fround(0);
 var $1842 = Math_fround(0), $1843 = Math_fround(0), $1844 = Math_fround(0), $1845 = 0, $1846 = Math_fround(0), $1847 = Math_fround(0), $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = Math_fround(0), $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = Math_fround(0);
 var $1860 = 0, $1861 = Math_fround(0), $1862 = 0, $1863 = Math_fround(0), $1864 = 0, $1865 = Math_fround(0), $1866 = Math_fround(0), $1867 = Math_fround(0), $1868 = Math_fround(0), $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = Math_fround(0), $1874 = Math_fround(0), $1875 = 0, $1876 = Math_fround(0), $1877 = Math_fround(0), $1878 = 0;
 var $1879 = Math_fround(0), $188 = Math_fround(0), $1880 = Math_fround(0), $1881 = Math_fround(0), $1882 = Math_fround(0), $1883 = Math_fround(0), $1884 = Math_fround(0), $1885 = Math_fround(0), $1886 = Math_fround(0), $1887 = Math_fround(0), $1888 = Math_fround(0), $1889 = Math_fround(0), $189 = 0, $1890 = Math_fround(0), $1891 = Math_fround(0), $1892 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0);
 var $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0);
 var $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0;
 var $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0;
 var $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0);
 var $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0);
 var $319 = 0, $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0);
 var $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = Math_fround(0), $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0;
 var $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0;
 var $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = 0;
 var $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = 0, $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0);
 var $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0);
 var $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0);
 var $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0);
 var $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0);
 var $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = Math_fround(0), $559 = 0, $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = Math_fround(0), $565 = 0, $566 = 0, $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0);
 var $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = 0, $578 = Math_fround(0), $579 = 0, $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = 0, $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0);
 var $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = 0;
 var $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0);
 var $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = 0, $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = 0, $641 = Math_fround(0), $642 = Math_fround(0);
 var $643 = 0, $644 = Math_fround(0), $645 = Math_fround(0), $646 = 0, $647 = 0, $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = 0, $659 = Math_fround(0), $66 = Math_fround(0), $660 = 0;
 var $661 = Math_fround(0), $662 = Math_fround(0), $663 = 0, $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0);
 var $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = 0, $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = 0, $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = 0, $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0);
 var $698 = Math_fround(0), $699 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0);
 var $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = 0, $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = 0, $722 = Math_fround(0), $723 = Math_fround(0), $724 = 0, $725 = Math_fround(0), $726 = Math_fround(0), $727 = 0, $728 = 0, $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0);
 var $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = 0, $74 = Math_fround(0), $740 = Math_fround(0), $741 = 0, $742 = Math_fround(0), $743 = Math_fround(0), $744 = 0, $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0);
 var $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = 0, $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = 0, $769 = Math_fround(0);
 var $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = 0, $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0);
 var $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = 0, $8 = 0, $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = 0, $803 = Math_fround(0), $804 = Math_fround(0);
 var $805 = 0, $806 = Math_fround(0), $807 = Math_fround(0), $808 = 0, $809 = 0, $81 = Math_fround(0), $810 = Math_fround(0), $811 = 0, $812 = Math_fround(0), $813 = 0, $814 = Math_fround(0), $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = Math_fround(0), $825 = Math_fround(0), $826 = 0, $827 = Math_fround(0), $828 = Math_fround(0), $829 = 0, $83 = Math_fround(0), $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = 0, $838 = 0, $839 = 0, $84 = Math_fround(0), $840 = Math_fround(0);
 var $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0, $850 = 0, $851 = Math_fround(0), $852 = 0, $853 = Math_fround(0), $854 = Math_fround(0), $855 = 0, $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0);
 var $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = 0, $876 = Math_fround(0), $877 = Math_fround(0);
 var $878 = Math_fround(0), $879 = 0, $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = 0, $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0);
 var $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = 0, $911 = Math_fround(0), $912 = Math_fround(0);
 var $913 = 0, $914 = Math_fround(0), $915 = Math_fround(0), $916 = 0, $917 = Math_fround(0), $918 = Math_fround(0), $919 = 0, $92 = Math_fround(0), $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0;
 var $931 = 0, $932 = 0, $933 = 0, $934 = Math_fround(0), $935 = 0, $936 = Math_fround(0), $937 = 0, $938 = Math_fround(0), $939 = 0, $94 = Math_fround(0), $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0;
 var $95 = Math_fround(0), $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = Math_fround(0), $958 = Math_fround(0), $959 = 0, $96 = Math_fround(0), $960 = Math_fround(0), $961 = Math_fround(0), $962 = 0, $963 = Math_fround(0), $964 = Math_fround(0), $965 = 0, $966 = Math_fround(0), $967 = Math_fround(0);
 var $968 = 0, $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = 0, $972 = Math_fround(0), $973 = Math_fround(0), $974 = 0, $975 = Math_fround(0), $976 = Math_fround(0), $977 = 0, $978 = Math_fround(0), $979 = Math_fround(0), $98 = Math_fround(0), $980 = 0, $981 = Math_fround(0), $982 = Math_fround(0), $983 = 0, $984 = Math_fround(0), $985 = Math_fround(0);
 var $986 = 0, $987 = Math_fround(0), $988 = Math_fround(0), $989 = 0, $99 = Math_fround(0), $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $a$pn4$i$i = 0, $a$pn4$i91$i = 0, $a$pn6$i$i = 0, $a$pn6$i95$i = 0, $b$a$i$i = 0;
 var $b$a$i89$i = 0, $b$a7$i$i = 0, $b$a7$i93$i = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i1 = 0, $exitcond$i10$i = 0, $exitcond$i17 = 0, $exitcond$i20$i = 0, $exitcond$i28 = 0, $exitcond$i31$i = 0, $exitcond$i46 = 0, $exitcond11$i = 0, $exitcond11$i18 = 0, $exitcond11$i47 = 0, $exitcond12$i = 0, $exitcond13$i = 0, $exitcond30$i = 0, $fakeParticle$i = 0, $i$01$i$i = 0;
 var $i$01$i19$i = 0, $i$01$i30$i = 0, $i$01$i9$i = 0, $idxA$0578$i = 0, $idxB$0584$i = 0, $idxB$1573$i = 0, $indexStreamSize$0579$i = 0, $indexStreamSize$1$lcssa$i = 0, $indexStreamSize$1572$i = 0, $indexStreamSize$2$i = 0, $indexStreamSizeOld$0$lcssa$i = 0, $indexStreamSizeOld$0569$i = 0, $indexStreamSizeOld$1$i = 0, $interactionCountPtr$0$lcssa$i = 0, $interactionCountPtr$0568$i = 0, $interactionCountPtr$1$i = 0, $isecs$i = 0, $not$$i = 0, $not$$i21 = 0, $not$$i37 = 0;
 var $not$$i9 = 0, $not$$us$i = 0, $not$1$i = 0, $not$1$i36 = 0, $not$1$us$i = 0, $not$2$i = 0, $not$2$i35 = 0, $not$2$us$i = 0, $not$20$i = 0, $not$21$i = 0, $not$22$i = 0, $not$3$i = 0, $not$3$i34 = 0, $not$3$us$i = 0, $not$545$i = 0, $not$546$i = 0, $not$547$i = 0, $not$551$i = 0, $not$552$i = 0, $not$553$i = 0;
 var $not$554$i = 0, $or$cond$i = 0, $or$cond$i22 = 0, $or$cond$i38 = 0, $or$cond$us$i = 0, $or$cond3$i = 0, $or$cond3$i23 = 0, $or$cond3$i39 = 0, $or$cond3$us$i = 0, $or$cond5$i = 0, $or$cond5$i24 = 0, $or$cond5$i40 = 0, $or$cond5$us$i = 0, $or$cond7$i = 0, $or$cond7$i25 = 0, $or$cond7$i41 = 0, $or$cond7$us$i = 0, $or$cond9$i = 0, $or$cond9$i13 = 0, $or$cond9$i27 = 0;
 var $or$cond9$i45 = 0, $or$cond9$us$i = 0, $p$0577$i = 0, $pA$026$i = 0, $pA$07$i = 0, $pA$07$i31 = 0, $pA$07$i7 = 0, $pA$07$us$i = 0, $pB$023$i = 0, $pB$04$i = 0, $pB$04$i33 = 0, $pB$04$us$i = 0, $pB1$024$i = 0, $pB1$05$i = 0, $pB1$05$i12 = 0, $pB1$05$i44 = 0, $pB1$05$us$i = 0, $params$idx$val$i = Math_fround(0), $params$idx$val$us$i = Math_fround(0), $params$idx10$val$i = Math_fround(0);
 var $params$idx10$val$us$i = Math_fround(0), $params$idx11$val$i = Math_fround(0), $params$idx11$val$us$i = Math_fround(0), $params$idx12$val$i = Math_fround(0), $params$idx12$val$us$i = Math_fround(0), $params$idx13$val$i = Math_fround(0), $params$idx13$val$us$i = Math_fround(0), $params$idx14$val$i = Math_fround(0), $params$idx14$val$us$i = Math_fround(0), $params$idx15$val$i = Math_fround(0), $params$idx15$val$us$i = Math_fround(0), $params$idx16$val$i = Math_fround(0), $params$idx16$val$us$i = Math_fround(0), $params$idx17$val$i = Math_fround(0), $params$idx17$val$us$i = Math_fround(0), $params$idx18$val$i = Math_fround(0), $params$idx18$val$us$i = Math_fround(0), $params$idx19$val$i = Math_fround(0), $params$idx19$val$us$i = Math_fround(0), $params$idx20$val$i = Math_fround(0);
 var $params$idx20$val$us$i = Math_fround(0), $params$idx21$i = 0, $params$idx21$i3 = 0, $params$idx21$val$i = Math_fround(0), $params$idx21$val$i14 = Math_fround(0), $params$idx21$val$us$i = Math_fround(0), $params$idx22$i = 0, $params$idx22$i4 = 0, $params$idx22$val$i = Math_fround(0), $params$idx22$val$i15 = Math_fround(0), $params$idx22$val$us$i = Math_fround(0), $params$idx23$i = 0, $params$idx23$i5 = 0, $params$idx23$val$i = Math_fround(0), $params$idx23$val$i16 = Math_fround(0), $params$idx23$val$us$i = Math_fround(0), $prtB$0574$i = 0, $q$0583$i = 0, $q1$0571$i = 0, $s$03$i$i = 0;
 var $s$03$i15$i = 0, $s$03$i26$i = 0, $s$03$i5$i = 0, $s$1$lcssa$i$i = 0, $s$1$lcssa$i13$i = 0, $s$1$lcssa$i24$i = 0, $s$1$lcssa$i3$i = 0, $s$12$i$i = 0, $s$12$i18$i = 0, $s$12$i29$i = 0, $s$12$i8$i = 0, $simdParams$i = 0, $tempSimdPositionBuffer$pn$i = 0, $v$0582$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $0 = sp + 256|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $fakeParticle$i = sp + 48|0;
 $simdParams$i = sp + 80|0;
 $isecs$i = sp + 224|0;
 $4 = ($numParticlesB>>>0)<(8);
 if (!($4)) {
  $1395 = (($numParticlesB) + 7)|0;
  $1396 = $1395 & -4;
  HEAPF32[$fakeParticle$i>>2] = Math_fround(3.40282346638528859812E+38);
  $1397 = (($fakeParticle$i) + 4|0);
  HEAPF32[$1397>>2] = Math_fround(3.40282346638528859812E+38);
  $1398 = (($fakeParticle$i) + 8|0);
  HEAPF32[$1398>>2] = Math_fround(3.40282346638528859812E+38);
  $1399 = (($fakeParticle$i) + 12|0);
  HEAPF32[$1399>>2] = Math_fround(3.40282346638528859812E+38);
  $1400 = (($particleIndicesB) + ($numParticlesB<<2)|0);
  $1401 = ($1396|0)==(0);
  if (!($1401)) {
   $idxB$0584$i = $particleIndicesB;$q$0583$i = 0;$v$0582$i = 0;
   while(1) {
    $1402 = ($q$0583$i>>>0)<($numParticlesB>>>0);
    if ($1402) {
     $1403 = HEAP32[$idxB$0584$i>>2]|0;
     $1404 = (($particlesB) + ($1403<<5)|0);
     $1421 = $1404;
    } else {
     $1421 = $fakeParticle$i;
    }
    $1405 = $q$0583$i | 1;
    $1406 = ($1405>>>0)<($numParticlesB>>>0);
    if ($1406) {
     $1407 = (($idxB$0584$i) + 4|0);
     $1408 = HEAP32[$1407>>2]|0;
     $1409 = (($particlesB) + ($1408<<5)|0);
     $1427 = $1409;
    } else {
     $1427 = $fakeParticle$i;
    }
    $1410 = $q$0583$i | 2;
    $1411 = ($1410>>>0)<($numParticlesB>>>0);
    if ($1411) {
     $1412 = (($idxB$0584$i) + 8|0);
     $1413 = HEAP32[$1412>>2]|0;
     $1414 = (($particlesB) + ($1413<<5)|0);
     $1433 = $1414;
    } else {
     $1433 = $fakeParticle$i;
    }
    $1415 = $q$0583$i | 3;
    $1416 = ($1415>>>0)<($numParticlesB>>>0);
    if ($1416) {
     $1417 = (($idxB$0584$i) + 12|0);
     $1418 = HEAP32[$1417>>2]|0;
     $1419 = (($particlesB) + ($1418<<5)|0);
     $1439 = $1419;
    } else {
     $1439 = $fakeParticle$i;
    }
    $1420 = Math_fround(HEAPF32[$1421>>2]);
    $1422 = (($1421) + 4|0);
    $1423 = Math_fround(HEAPF32[$1422>>2]);
    $1424 = (($1421) + 8|0);
    $1425 = Math_fround(HEAPF32[$1424>>2]);
    $1426 = Math_fround(HEAPF32[$1427>>2]);
    $1428 = (($1427) + 4|0);
    $1429 = Math_fround(HEAPF32[$1428>>2]);
    $1430 = (($1427) + 8|0);
    $1431 = Math_fround(HEAPF32[$1430>>2]);
    $1432 = Math_fround(HEAPF32[$1433>>2]);
    $1434 = (($1433) + 4|0);
    $1435 = Math_fround(HEAPF32[$1434>>2]);
    $1436 = (($1433) + 8|0);
    $1437 = Math_fround(HEAPF32[$1436>>2]);
    $1438 = Math_fround(HEAPF32[$1439>>2]);
    $1440 = (($1439) + 4|0);
    $1441 = Math_fround(HEAPF32[$1440>>2]);
    $1442 = (($1439) + 8|0);
    $1443 = Math_fround(HEAPF32[$1442>>2]);
    $1444 = (($tempSimdPositionBuffer) + ($v$0582$i<<4)|0);
    HEAPF32[$1444>>2] = $1420;
    $1445 = ((($tempSimdPositionBuffer) + ($v$0582$i<<4)|0) + 4|0);
    HEAPF32[$1445>>2] = $1426;
    $1446 = ((($tempSimdPositionBuffer) + ($v$0582$i<<4)|0) + 8|0);
    HEAPF32[$1446>>2] = $1432;
    $1447 = ((($tempSimdPositionBuffer) + ($v$0582$i<<4)|0) + 12|0);
    HEAPF32[$1447>>2] = $1438;
    $1448 = (($v$0582$i) + 1)|0;
    $1449 = (($tempSimdPositionBuffer) + ($1448<<4)|0);
    HEAPF32[$1449>>2] = $1423;
    $1450 = ((($tempSimdPositionBuffer) + ($1448<<4)|0) + 4|0);
    HEAPF32[$1450>>2] = $1429;
    $1451 = ((($tempSimdPositionBuffer) + ($1448<<4)|0) + 8|0);
    HEAPF32[$1451>>2] = $1435;
    $1452 = ((($tempSimdPositionBuffer) + ($1448<<4)|0) + 12|0);
    HEAPF32[$1452>>2] = $1441;
    $1453 = (($v$0582$i) + 2)|0;
    $1454 = (($tempSimdPositionBuffer) + ($1453<<4)|0);
    HEAPF32[$1454>>2] = $1425;
    $1455 = ((($tempSimdPositionBuffer) + ($1453<<4)|0) + 4|0);
    HEAPF32[$1455>>2] = $1431;
    $1456 = ((($tempSimdPositionBuffer) + ($1453<<4)|0) + 8|0);
    HEAPF32[$1456>>2] = $1437;
    $1457 = ((($tempSimdPositionBuffer) + ($1453<<4)|0) + 12|0);
    HEAPF32[$1457>>2] = $1443;
    $1458 = (($q$0583$i) + 4)|0;
    $1459 = (($idxB$0584$i) + 16|0);
    $1460 = (($v$0582$i) + 3)|0;
    $1461 = ($1458>>>0)<($1396>>>0);
    if ($1461) {
     $idxB$0584$i = $1459;$q$0583$i = $1458;$v$0582$i = $1460;
    } else {
     break;
    }
   }
  }
  $1462 = (($params) + 48|0);
  $1463 = Math_fround(HEAPF32[$1462>>2]);
  HEAPF32[$simdParams$i>>2] = $1463;
  $1464 = (($simdParams$i) + 4|0);
  HEAPF32[$1464>>2] = $1463;
  $1465 = (($simdParams$i) + 8|0);
  HEAPF32[$1465>>2] = $1463;
  $1466 = (($simdParams$i) + 12|0);
  HEAPF32[$1466>>2] = $1463;
  $1467 = (($params) + 52|0);
  $1468 = Math_fround(HEAPF32[$1467>>2]);
  $1469 = (($simdParams$i) + 16|0);
  HEAPF32[$1469>>2] = $1468;
  $1470 = (($simdParams$i) + 20|0);
  HEAPF32[$1470>>2] = $1468;
  $1471 = (($simdParams$i) + 24|0);
  HEAPF32[$1471>>2] = $1468;
  $1472 = (($simdParams$i) + 28|0);
  HEAPF32[$1472>>2] = $1468;
  $1473 = (($params) + 24|0);
  $1474 = Math_fround(HEAPF32[$1473>>2]);
  $1475 = (($simdParams$i) + 32|0);
  HEAPF32[$1475>>2] = $1474;
  $1476 = (($simdParams$i) + 36|0);
  HEAPF32[$1476>>2] = $1474;
  $1477 = (($simdParams$i) + 40|0);
  HEAPF32[$1477>>2] = $1474;
  $1478 = (($simdParams$i) + 44|0);
  HEAPF32[$1478>>2] = $1474;
  $1479 = (($params) + 28|0);
  $1480 = Math_fround(HEAPF32[$1479>>2]);
  $1481 = (($simdParams$i) + 48|0);
  HEAPF32[$1481>>2] = $1480;
  $1482 = (($simdParams$i) + 52|0);
  HEAPF32[$1482>>2] = $1480;
  $1483 = (($simdParams$i) + 56|0);
  HEAPF32[$1483>>2] = $1480;
  $1484 = (($simdParams$i) + 60|0);
  HEAPF32[$1484>>2] = $1480;
  $1485 = (($params) + 32|0);
  $1486 = Math_fround(HEAPF32[$1485>>2]);
  $1487 = (($simdParams$i) + 64|0);
  HEAPF32[$1487>>2] = $1486;
  $1488 = (($simdParams$i) + 68|0);
  HEAPF32[$1488>>2] = $1486;
  $1489 = (($simdParams$i) + 72|0);
  HEAPF32[$1489>>2] = $1486;
  $1490 = (($simdParams$i) + 76|0);
  HEAPF32[$1490>>2] = $1486;
  $1491 = (($params) + 36|0);
  $1492 = Math_fround(HEAPF32[$1491>>2]);
  $1493 = (($simdParams$i) + 80|0);
  HEAPF32[$1493>>2] = $1492;
  $1494 = (($simdParams$i) + 84|0);
  HEAPF32[$1494>>2] = $1492;
  $1495 = (($simdParams$i) + 88|0);
  HEAPF32[$1495>>2] = $1492;
  $1496 = (($simdParams$i) + 92|0);
  HEAPF32[$1496>>2] = $1492;
  $1497 = (($params) + 40|0);
  $1498 = Math_fround(HEAPF32[$1497>>2]);
  $1499 = (($simdParams$i) + 96|0);
  HEAPF32[$1499>>2] = $1498;
  $1500 = (($simdParams$i) + 100|0);
  HEAPF32[$1500>>2] = $1498;
  $1501 = (($simdParams$i) + 104|0);
  HEAPF32[$1501>>2] = $1498;
  $1502 = (($simdParams$i) + 108|0);
  HEAPF32[$1502>>2] = $1498;
  $1503 = (($params) + 44|0);
  $1504 = Math_fround(HEAPF32[$1503>>2]);
  $1505 = (($simdParams$i) + 112|0);
  HEAPF32[$1505>>2] = $1504;
  $1506 = (($simdParams$i) + 116|0);
  HEAPF32[$1506>>2] = $1504;
  $1507 = (($simdParams$i) + 120|0);
  HEAPF32[$1507>>2] = $1504;
  $1508 = (($simdParams$i) + 124|0);
  HEAPF32[$1508>>2] = $1504;
  $1509 = (($params) + 16|0);
  $1510 = Math_fround(HEAPF32[$1509>>2]);
  $1511 = ($numParticlesA|0)==(0);
  if ($1511) {
   STACKTOP = sp;return;
  }
  $1512 = (($tempSimdPositionBuffer) + 4|0);
  $1513 = (($tempSimdPositionBuffer) + 8|0);
  $1514 = (($tempSimdPositionBuffer) + 12|0);
  $1515 = (($tempSimdPositionBuffer) + 16|0);
  $1516 = (($tempSimdPositionBuffer) + 20|0);
  $1517 = (($tempSimdPositionBuffer) + 24|0);
  $1518 = (($tempSimdPositionBuffer) + 28|0);
  $1519 = (($tempSimdPositionBuffer) + 32|0);
  $1520 = (($tempSimdPositionBuffer) + 36|0);
  $1521 = (($tempSimdPositionBuffer) + 40|0);
  $1522 = (($tempSimdPositionBuffer) + 44|0);
  $1523 = (($1) + 4|0);
  $1524 = (($1) + 8|0);
  $1525 = (($1) + 12|0);
  $1526 = (($isecs$i) + 4|0);
  $1527 = (($isecs$i) + 8|0);
  $1528 = (($isecs$i) + 12|0);
  $1529 = ($numParticlesB|0)==(0);
  $1530 = (($3) + 4|0);
  $1531 = (($3) + 8|0);
  $1532 = (($3) + 12|0);
  $1533 = (($tempIndexStream) + 4|0);
  $idxA$0578$i = $particleIndicesA;$indexStreamSize$0579$i = 0;$p$0577$i = 0;
  while(1) {
   $1534 = HEAP32[$idxA$0578$i>>2]|0;
   $1535 = (($indexStreamSize$0579$i) + 1)|0;
   $1536 = (($tempIndexStream) + ($indexStreamSize$0579$i<<2)|0);
   HEAP32[$1536>>2] = $1534;
   $1537 = (($indexStreamSize$0579$i) + 2)|0;
   $1538 = (($tempIndexStream) + ($1535<<2)|0);
   $1539 = (($particlesA) + ($1534<<5)|0);
   $1540 = Math_fround(HEAPF32[$1539>>2]);
   $1541 = (($1539) + 4|0);
   $1542 = Math_fround(HEAPF32[$1541>>2]);
   $1543 = (($1539) + 8|0);
   $1544 = Math_fround(HEAPF32[$1543>>2]);
   $1545 = Math_fround(HEAPF32[$tempSimdPositionBuffer>>2]);
   $1546 = Math_fround(HEAPF32[$1512>>2]);
   $1547 = Math_fround(HEAPF32[$1513>>2]);
   $1548 = Math_fround(HEAPF32[$1514>>2]);
   $1549 = Math_fround(HEAPF32[$1515>>2]);
   $1550 = Math_fround(HEAPF32[$1516>>2]);
   $1551 = Math_fround(HEAPF32[$1517>>2]);
   $1552 = Math_fround(HEAPF32[$1518>>2]);
   $1553 = Math_fround(HEAPF32[$1519>>2]);
   $1554 = Math_fround(HEAPF32[$1520>>2]);
   $1555 = Math_fround(HEAPF32[$1521>>2]);
   $1556 = Math_fround(HEAPF32[$1522>>2]);
   $1557 = Math_fround($1540 - $1545);
   $1558 = Math_fround($1540 - $1546);
   $1559 = Math_fround($1540 - $1547);
   $1560 = Math_fround($1540 - $1548);
   $1561 = Math_fround($1542 - $1549);
   $1562 = Math_fround($1542 - $1550);
   $1563 = Math_fround($1542 - $1551);
   $1564 = Math_fround($1542 - $1552);
   $1565 = Math_fround($1544 - $1553);
   $1566 = Math_fround($1544 - $1554);
   $1567 = Math_fround($1544 - $1555);
   $1568 = Math_fround($1544 - $1556);
   $1569 = Math_fround($1557 * $1557);
   $1570 = Math_fround($1558 * $1558);
   $1571 = Math_fround($1559 * $1559);
   $1572 = Math_fround($1560 * $1560);
   $1573 = Math_fround($1561 * $1561);
   $1574 = Math_fround($1562 * $1562);
   $1575 = Math_fround($1563 * $1563);
   $1576 = Math_fround($1564 * $1564);
   $1577 = Math_fround($1569 + $1573);
   $1578 = Math_fround($1570 + $1574);
   $1579 = Math_fround($1571 + $1575);
   $1580 = Math_fround($1572 + $1576);
   $1581 = Math_fround($1565 * $1565);
   $1582 = Math_fround($1566 * $1566);
   $1583 = Math_fround($1567 * $1567);
   $1584 = Math_fround($1568 * $1568);
   $1585 = Math_fround($1577 + $1581);
   $1586 = Math_fround($1578 + $1582);
   $1587 = Math_fround($1579 + $1583);
   $1588 = Math_fround($1580 + $1584);
   $1589 = $1585 > Math_fround(0.0);
   $1590 = $1586 > Math_fround(0.0);
   $1591 = $1587 > Math_fround(0.0);
   $1592 = $1588 > Math_fround(0.0);
   $not$$i = $1510 > $1585;
   $not$545$i = $1510 > $1586;
   $not$546$i = $1510 > $1587;
   $not$547$i = $1510 > $1588;
   HEAP32[$1>>2] = 1;
   HEAP32[$1523>>2] = 1;
   HEAP32[$1524>>2] = 1;
   HEAP32[$1525>>2] = 1;
   $$demorgan$i = $1589 & $not$$i;
   $b$a$i89$i = $$demorgan$i ? $1 : $0;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   $1593 = HEAP32[$b$a$i89$i>>2]|0;
   $$demorgan548$i = $1590 & $not$545$i;
   $a$pn4$i91$i = $$demorgan548$i ? $1 : $0;
   $$in1$i92$i = (($a$pn4$i91$i) + 4|0);
   $1594 = HEAP32[$$in1$i92$i>>2]|0;
   $$demorgan549$i = $1591 & $not$546$i;
   $b$a7$i93$i = $$demorgan549$i ? $1 : $0;
   $$in2$i94$i = (($b$a7$i93$i) + 8|0);
   $1595 = HEAP32[$$in2$i94$i>>2]|0;
   $$demorgan550$i = $1592 & $not$547$i;
   $a$pn6$i95$i = $$demorgan550$i ? $1 : $0;
   $$in3$i96$i = (($a$pn6$i95$i) + 12|0);
   $1596 = HEAP32[$$in3$i96$i>>2]|0;
   HEAP32[$isecs$i>>2] = $1593;
   HEAP32[$1526>>2] = $1594;
   HEAP32[$1527>>2] = $1595;
   HEAP32[$1528>>2] = $1596;
   if ($1529) {
    $indexStreamSize$1$lcssa$i = $1537;$indexStreamSizeOld$0$lcssa$i = $1537;$interactionCountPtr$0$lcssa$i = $1538;
   } else {
    $idxB$1573$i = $particleIndicesB;$indexStreamSize$1572$i = $1537;$indexStreamSizeOld$0569$i = $1537;$interactionCountPtr$0568$i = $1538;$q1$0571$i = 0;$tempSimdPositionBuffer$pn$i = $tempSimdPositionBuffer;
    while(1) {
     $prtB$0574$i = (($tempSimdPositionBuffer$pn$i) + 48|0);
     $1597 = (($tempSimdPositionBuffer$pn$i) + 48|0);
     $1598 = Math_fround(HEAPF32[$1597>>2]);
     $1599 = (($tempSimdPositionBuffer$pn$i) + 52|0);
     $1600 = Math_fround(HEAPF32[$1599>>2]);
     $1601 = (($tempSimdPositionBuffer$pn$i) + 56|0);
     $1602 = Math_fround(HEAPF32[$1601>>2]);
     $1603 = (($tempSimdPositionBuffer$pn$i) + 60|0);
     $1604 = Math_fround(HEAPF32[$1603>>2]);
     $1605 = (($tempSimdPositionBuffer$pn$i) + 64|0);
     $1606 = Math_fround(HEAPF32[$1605>>2]);
     $1607 = (($tempSimdPositionBuffer$pn$i) + 68|0);
     $1608 = Math_fround(HEAPF32[$1607>>2]);
     $1609 = (($tempSimdPositionBuffer$pn$i) + 72|0);
     $1610 = Math_fround(HEAPF32[$1609>>2]);
     $1611 = (($tempSimdPositionBuffer$pn$i) + 76|0);
     $1612 = Math_fround(HEAPF32[$1611>>2]);
     $1613 = (($tempSimdPositionBuffer$pn$i) + 80|0);
     $1614 = Math_fround(HEAPF32[$1613>>2]);
     $1615 = (($tempSimdPositionBuffer$pn$i) + 84|0);
     $1616 = Math_fround(HEAPF32[$1615>>2]);
     $1617 = (($tempSimdPositionBuffer$pn$i) + 88|0);
     $1618 = Math_fround(HEAPF32[$1617>>2]);
     $1619 = (($tempSimdPositionBuffer$pn$i) + 92|0);
     $1620 = Math_fround(HEAPF32[$1619>>2]);
     $1621 = Math_fround($1540 - $1598);
     $1622 = Math_fround($1540 - $1600);
     $1623 = Math_fround($1540 - $1602);
     $1624 = Math_fround($1540 - $1604);
     $1625 = Math_fround($1542 - $1606);
     $1626 = Math_fround($1542 - $1608);
     $1627 = Math_fround($1542 - $1610);
     $1628 = Math_fround($1542 - $1612);
     $1629 = Math_fround($1544 - $1614);
     $1630 = Math_fround($1544 - $1616);
     $1631 = Math_fround($1544 - $1618);
     $1632 = Math_fround($1544 - $1620);
     $1633 = Math_fround($1621 * $1621);
     $1634 = Math_fround($1622 * $1622);
     $1635 = Math_fround($1623 * $1623);
     $1636 = Math_fround($1624 * $1624);
     $1637 = Math_fround($1625 * $1625);
     $1638 = Math_fround($1626 * $1626);
     $1639 = Math_fround($1627 * $1627);
     $1640 = Math_fround($1628 * $1628);
     $1641 = Math_fround($1633 + $1637);
     $1642 = Math_fround($1634 + $1638);
     $1643 = Math_fround($1635 + $1639);
     $1644 = Math_fround($1636 + $1640);
     $1645 = Math_fround($1629 * $1629);
     $1646 = Math_fround($1630 * $1630);
     $1647 = Math_fround($1631 * $1631);
     $1648 = Math_fround($1632 * $1632);
     $1649 = Math_fround($1641 + $1645);
     $1650 = Math_fround($1642 + $1646);
     $1651 = Math_fround($1643 + $1647);
     $1652 = Math_fround($1644 + $1648);
     $1653 = $1649 > Math_fround(0.0);
     $1654 = $1650 > Math_fround(0.0);
     $1655 = $1651 > Math_fround(0.0);
     $1656 = $1652 > Math_fround(0.0);
     $not$551$i = $1510 > $1649;
     $not$552$i = $1510 > $1650;
     $not$553$i = $1510 > $1651;
     $not$554$i = $1510 > $1652;
     HEAP32[$3>>2] = 1;
     HEAP32[$1530>>2] = 1;
     HEAP32[$1531>>2] = 1;
     HEAP32[$1532>>2] = 1;
     $$demorgan555$i = $1653 & $not$551$i;
     $b$a$i$i = $$demorgan555$i ? $3 : $2;
     ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
     $1657 = HEAP32[$b$a$i$i>>2]|0;
     $$demorgan556$i = $1654 & $not$552$i;
     $a$pn4$i$i = $$demorgan556$i ? $3 : $2;
     $$in1$i$i = (($a$pn4$i$i) + 4|0);
     $1658 = HEAP32[$$in1$i$i>>2]|0;
     $$demorgan557$i = $1655 & $not$553$i;
     $b$a7$i$i = $$demorgan557$i ? $3 : $2;
     $$in2$i$i = (($b$a7$i$i) + 8|0);
     $1659 = HEAP32[$$in2$i$i>>2]|0;
     $$demorgan558$i = $1656 & $not$554$i;
     $a$pn6$i$i = $$demorgan558$i ? $3 : $2;
     $$in3$i$i = (($a$pn6$i$i) + 12|0);
     $1660 = HEAP32[$$in3$i$i>>2]|0;
     $1661 = (($q1$0571$i) + 4)|0;
     $1662 = $1661 & 4;
     $1663 = (($isecs$i) + ($1662<<2)|0);
     HEAP32[$1663>>2] = $1657;
     $$sum559$i = $1662 | 1;
     $1664 = (($isecs$i) + ($$sum559$i<<2)|0);
     HEAP32[$1664>>2] = $1658;
     $$sum560$i = $1662 | 2;
     $1665 = (($isecs$i) + ($$sum560$i<<2)|0);
     HEAP32[$1665>>2] = $1659;
     $$sum561$i = $1662 | 3;
     $1666 = (($isecs$i) + ($$sum561$i<<2)|0);
     HEAP32[$1666>>2] = $1660;
     $1667 = $q1$0571$i & 4;
     $1668 = (($isecs$i) + ($1667<<2)|0);
     $1669 = HEAP32[$1668>>2]|0;
     $1670 = $1667 | 1;
     $1671 = (($isecs$i) + ($1670<<2)|0);
     $1672 = HEAP32[$1671>>2]|0;
     $1673 = $1667 | 2;
     $1674 = (($isecs$i) + ($1673<<2)|0);
     $1675 = HEAP32[$1674>>2]|0;
     $1676 = $1667 | 3;
     $1677 = (($isecs$i) + ($1676<<2)|0);
     $1678 = HEAP32[$1677>>2]|0;
     $1679 = HEAP32[$idxB$1573$i>>2]|0;
     $1680 = (($tempIndexStream) + ($indexStreamSize$1572$i<<2)|0);
     HEAP32[$1680>>2] = $1679;
     $1681 = (($1669) + ($indexStreamSize$1572$i))|0;
     $1682 = (($idxB$1573$i) + 4|0);
     $1683 = ($1682>>>0)<($1400>>>0);
     if ($1683) {
      $1684 = HEAP32[$1682>>2]|0;
      $1686 = $1684;
     } else {
      $1686 = 0;
     }
     $1685 = (($tempIndexStream) + ($1681<<2)|0);
     HEAP32[$1685>>2] = $1686;
     $1687 = (($1681) + ($1672))|0;
     $1688 = (($idxB$1573$i) + 8|0);
     $1689 = ($1688>>>0)<($1400>>>0);
     if ($1689) {
      $1690 = HEAP32[$1688>>2]|0;
      $1692 = $1690;
     } else {
      $1692 = 0;
     }
     $1691 = (($tempIndexStream) + ($1687<<2)|0);
     HEAP32[$1691>>2] = $1692;
     $1693 = (($1687) + ($1675))|0;
     $1694 = (($idxB$1573$i) + 12|0);
     $1695 = ($1694>>>0)<($1400>>>0);
     if ($1695) {
      $1696 = HEAP32[$1694>>2]|0;
      $1698 = $1696;
     } else {
      $1698 = 0;
     }
     $1697 = (($tempIndexStream) + ($1693<<2)|0);
     HEAP32[$1697>>2] = $1698;
     $1699 = (($1693) + ($1678))|0;
     $1700 = (128 - ($1699))|0;
     $1701 = ($1700>>>0)>(5);
     if ($1701) {
      $indexStreamSize$2$i = $1699;$indexStreamSizeOld$1$i = $indexStreamSizeOld$0569$i;$interactionCountPtr$1$i = $interactionCountPtr$0568$i;
     } else {
      $1702 = (($1699) - ($indexStreamSizeOld$0569$i))|0;
      HEAP32[$interactionCountPtr$0568$i>>2] = $1702;
      do {
       if ($isDensityMode) {
        $1703 = ($1699|0)==(0);
        if ($twoWayUpdate) {
         if ($1703) {
          break;
         } else {
          $s$03$i26$i = 0;
         }
         while(1) {
          $1710 = (($s$03$i26$i) + 1)|0;
          $1711 = (($tempIndexStream) + ($s$03$i26$i<<2)|0);
          $1712 = HEAP32[$1711>>2]|0;
          $1706 = (($s$03$i26$i) + 2)|0;
          $1713 = (($tempIndexStream) + ($1710<<2)|0);
          $1705 = HEAP32[$1713>>2]|0;
          $1714 = ($1705|0)==(0);
          if ($1714) {
           $s$1$lcssa$i24$i = $1706;
          } else {
           $1715 = (($particlesA) + ($1712<<5)|0);
           $1716 = Math_fround(HEAPF32[$1715>>2]);
           $1717 = ((($particlesA) + ($1712<<5)|0) + 4|0);
           $1718 = Math_fround(HEAPF32[$1717>>2]);
           $1719 = ((($particlesA) + ($1712<<5)|0) + 8|0);
           $1720 = Math_fround(HEAPF32[$1719>>2]);
           $1721 = Math_fround(HEAPF32[$1467>>2]);
           $1722 = Math_fround(HEAPF32[$1479>>2]);
           $1723 = Math_fround(HEAPF32[$1485>>2]);
           $1708 = ((($particlesA) + ($1712<<5)|0) + 12|0);
           $$promoted$i27$i = Math_fround(HEAPF32[$1708>>2]);
           $1746 = $$promoted$i27$i;$i$01$i30$i = 0;$s$12$i29$i = $1706;
           while(1) {
            $1724 = (($s$12$i29$i) + 1)|0;
            $1725 = (($tempIndexStream) + ($s$12$i29$i<<2)|0);
            $1726 = HEAP32[$1725>>2]|0;
            $1727 = (($particlesB) + ($1726<<5)|0);
            $1728 = Math_fround(HEAPF32[$1727>>2]);
            $1729 = Math_fround($1716 - $1728);
            $1730 = ((($particlesB) + ($1726<<5)|0) + 4|0);
            $1731 = Math_fround(HEAPF32[$1730>>2]);
            $1732 = Math_fround($1718 - $1731);
            $1733 = ((($particlesB) + ($1726<<5)|0) + 8|0);
            $1734 = Math_fround(HEAPF32[$1733>>2]);
            $1735 = Math_fround($1720 - $1734);
            $1736 = Math_fround($1729 * $1729);
            $1737 = Math_fround($1732 * $1732);
            $1738 = Math_fround($1736 + $1737);
            $1739 = Math_fround($1735 * $1735);
            $1740 = Math_fround($1738 + $1739);
            $1741 = Math_fround($1721 * $1740);
            $1742 = Math_fround($1722 - $1741);
            $1743 = Math_fround($1723 * $1742);
            $1744 = Math_fround($1742 * $1743);
            $1745 = Math_fround($1742 * $1744);
            $1707 = Math_fround($1746 + $1745);
            $1747 = ((($particlesB) + ($1726<<5)|0) + 12|0);
            $1748 = Math_fround(HEAPF32[$1747>>2]);
            $1749 = Math_fround($1748 + $1745);
            HEAPF32[$1747>>2] = $1749;
            $1750 = (($i$01$i30$i) + 1)|0;
            $exitcond$i31$i = ($1750|0)==($1705|0);
            if ($exitcond$i31$i) {
             break;
            } else {
             $1746 = $1707;$i$01$i30$i = $1750;$s$12$i29$i = $1724;
            }
           }
           $1704 = (($1705) + ($1706))|0;
           HEAPF32[$1708>>2] = $1707;
           $s$1$lcssa$i24$i = $1704;
          }
          $1709 = ($s$1$lcssa$i24$i>>>0)<($1699>>>0);
          if ($1709) {
           $s$03$i26$i = $s$1$lcssa$i24$i;
          } else {
           break;
          }
         }
        } else {
         if ($1703) {
          break;
         } else {
          $s$03$i15$i = 0;
         }
         while(1) {
          $1757 = (($s$03$i15$i) + 1)|0;
          $1758 = (($tempIndexStream) + ($s$03$i15$i<<2)|0);
          $1759 = HEAP32[$1758>>2]|0;
          $1753 = (($s$03$i15$i) + 2)|0;
          $1760 = (($tempIndexStream) + ($1757<<2)|0);
          $1752 = HEAP32[$1760>>2]|0;
          $1761 = ($1752|0)==(0);
          if ($1761) {
           $s$1$lcssa$i13$i = $1753;
          } else {
           $1762 = (($particlesA) + ($1759<<5)|0);
           $1763 = Math_fround(HEAPF32[$1762>>2]);
           $1764 = ((($particlesA) + ($1759<<5)|0) + 4|0);
           $1765 = Math_fround(HEAPF32[$1764>>2]);
           $1766 = ((($particlesA) + ($1759<<5)|0) + 8|0);
           $1767 = Math_fround(HEAPF32[$1766>>2]);
           $1768 = Math_fround(HEAPF32[$1467>>2]);
           $1769 = Math_fround(HEAPF32[$1479>>2]);
           $1770 = Math_fround(HEAPF32[$1485>>2]);
           $1755 = ((($particlesA) + ($1759<<5)|0) + 12|0);
           $$promoted$i16$i = Math_fround(HEAPF32[$1755>>2]);
           $1793 = $$promoted$i16$i;$i$01$i19$i = 0;$s$12$i18$i = $1753;
           while(1) {
            $1771 = (($s$12$i18$i) + 1)|0;
            $1772 = (($tempIndexStream) + ($s$12$i18$i<<2)|0);
            $1773 = HEAP32[$1772>>2]|0;
            $1774 = (($particlesB) + ($1773<<5)|0);
            $1775 = Math_fround(HEAPF32[$1774>>2]);
            $1776 = Math_fround($1763 - $1775);
            $1777 = ((($particlesB) + ($1773<<5)|0) + 4|0);
            $1778 = Math_fround(HEAPF32[$1777>>2]);
            $1779 = Math_fround($1765 - $1778);
            $1780 = ((($particlesB) + ($1773<<5)|0) + 8|0);
            $1781 = Math_fround(HEAPF32[$1780>>2]);
            $1782 = Math_fround($1767 - $1781);
            $1783 = Math_fround($1776 * $1776);
            $1784 = Math_fround($1779 * $1779);
            $1785 = Math_fround($1783 + $1784);
            $1786 = Math_fround($1782 * $1782);
            $1787 = Math_fround($1785 + $1786);
            $1788 = Math_fround($1768 * $1787);
            $1789 = Math_fround($1769 - $1788);
            $1790 = Math_fround($1770 * $1789);
            $1791 = Math_fround($1789 * $1790);
            $1792 = Math_fround($1789 * $1791);
            $1754 = Math_fround($1793 + $1792);
            $1794 = (($i$01$i19$i) + 1)|0;
            $exitcond$i20$i = ($1794|0)==($1752|0);
            if ($exitcond$i20$i) {
             break;
            } else {
             $1793 = $1754;$i$01$i19$i = $1794;$s$12$i18$i = $1771;
            }
           }
           $1751 = (($1752) + ($1753))|0;
           HEAPF32[$1755>>2] = $1754;
           $s$1$lcssa$i13$i = $1751;
          }
          $1756 = ($s$1$lcssa$i13$i>>>0)<($1699>>>0);
          if ($1756) {
           $s$03$i15$i = $s$1$lcssa$i13$i;
          } else {
           break;
          }
         }
        }
       } else {
        if ($twoWayUpdate) {
         __ZN5physxL23updateStreamForceTwoWayEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjRKNS_26PxsFluidDynamicsParametersERKNS_30PxsFluidDynamicsParametersSIMDE($forceBufA,$forceBufB,$particlesA,$particlesB,$tempIndexStream,$1699,$params,$simdParams$i);
         break;
        } else {
         __ZN5physxL17updateStreamForceEPNS_6PxVec3EPNS_16PxsFluidParticleEPKS2_PKjjRKNS_26PxsFluidDynamicsParametersERKNS_30PxsFluidDynamicsParametersSIMDE($forceBufA,$particlesA,$particlesB,$tempIndexStream,$1699,$params,$simdParams$i);
         break;
        }
       }
      } while(0);
      $1795 = HEAP32[$idxA$0578$i>>2]|0;
      HEAP32[$tempIndexStream>>2] = $1795;
      $indexStreamSize$2$i = 2;$indexStreamSizeOld$1$i = 2;$interactionCountPtr$1$i = $1533;
     }
     $1796 = (($idxB$1573$i) + 16|0);
     $1797 = ($1661>>>0)<($numParticlesB>>>0);
     if ($1797) {
      $idxB$1573$i = $1796;$indexStreamSize$1572$i = $indexStreamSize$2$i;$indexStreamSizeOld$0569$i = $indexStreamSizeOld$1$i;$interactionCountPtr$0568$i = $interactionCountPtr$1$i;$q1$0571$i = $1661;$tempSimdPositionBuffer$pn$i = $prtB$0574$i;
     } else {
      $indexStreamSize$1$lcssa$i = $indexStreamSize$2$i;$indexStreamSizeOld$0$lcssa$i = $indexStreamSizeOld$1$i;$interactionCountPtr$0$lcssa$i = $interactionCountPtr$1$i;
      break;
     }
    }
   }
   $1798 = (($indexStreamSize$1$lcssa$i) - ($indexStreamSizeOld$0$lcssa$i))|0;
   HEAP32[$interactionCountPtr$0$lcssa$i>>2] = $1798;
   $1799 = (($p$0577$i) + 1)|0;
   $1800 = (($idxA$0578$i) + 4|0);
   $exitcond$i1 = ($1799|0)==($numParticlesA|0);
   if ($exitcond$i1) {
    break;
   } else {
    $idxA$0578$i = $1800;$indexStreamSize$0579$i = $indexStreamSize$1$lcssa$i;$p$0577$i = $1799;
   }
  }
  $1801 = ($indexStreamSize$1$lcssa$i|0)==(0);
  if ($1801) {
   STACKTOP = sp;return;
  }
  if (!($isDensityMode)) {
   if ($twoWayUpdate) {
    __ZN5physxL23updateStreamForceTwoWayEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjRKNS_26PxsFluidDynamicsParametersERKNS_30PxsFluidDynamicsParametersSIMDE($forceBufA,$forceBufB,$particlesA,$particlesB,$tempIndexStream,$indexStreamSize$1$lcssa$i,$params,$simdParams$i);
    STACKTOP = sp;return;
   } else {
    __ZN5physxL17updateStreamForceEPNS_6PxVec3EPNS_16PxsFluidParticleEPKS2_PKjjRKNS_26PxsFluidDynamicsParametersERKNS_30PxsFluidDynamicsParametersSIMDE($forceBufA,$particlesA,$particlesB,$tempIndexStream,$indexStreamSize$1$lcssa$i,$params,$simdParams$i);
    STACKTOP = sp;return;
   }
  }
  if ($twoWayUpdate) {
   $s$03$i5$i = 0;
   while(1) {
    $1808 = (($s$03$i5$i) + 1)|0;
    $1809 = (($tempIndexStream) + ($s$03$i5$i<<2)|0);
    $1810 = HEAP32[$1809>>2]|0;
    $1804 = (($s$03$i5$i) + 2)|0;
    $1811 = (($tempIndexStream) + ($1808<<2)|0);
    $1803 = HEAP32[$1811>>2]|0;
    $1812 = ($1803|0)==(0);
    if ($1812) {
     $s$1$lcssa$i3$i = $1804;
    } else {
     $1813 = (($particlesA) + ($1810<<5)|0);
     $1814 = Math_fround(HEAPF32[$1813>>2]);
     $1815 = ((($particlesA) + ($1810<<5)|0) + 4|0);
     $1816 = Math_fround(HEAPF32[$1815>>2]);
     $1817 = ((($particlesA) + ($1810<<5)|0) + 8|0);
     $1818 = Math_fround(HEAPF32[$1817>>2]);
     $1819 = Math_fround(HEAPF32[$1467>>2]);
     $1820 = Math_fround(HEAPF32[$1479>>2]);
     $1821 = Math_fround(HEAPF32[$1485>>2]);
     $1806 = ((($particlesA) + ($1810<<5)|0) + 12|0);
     $$promoted$i6$i = Math_fround(HEAPF32[$1806>>2]);
     $1844 = $$promoted$i6$i;$i$01$i9$i = 0;$s$12$i8$i = $1804;
     while(1) {
      $1822 = (($s$12$i8$i) + 1)|0;
      $1823 = (($tempIndexStream) + ($s$12$i8$i<<2)|0);
      $1824 = HEAP32[$1823>>2]|0;
      $1825 = (($particlesB) + ($1824<<5)|0);
      $1826 = Math_fround(HEAPF32[$1825>>2]);
      $1827 = Math_fround($1814 - $1826);
      $1828 = ((($particlesB) + ($1824<<5)|0) + 4|0);
      $1829 = Math_fround(HEAPF32[$1828>>2]);
      $1830 = Math_fround($1816 - $1829);
      $1831 = ((($particlesB) + ($1824<<5)|0) + 8|0);
      $1832 = Math_fround(HEAPF32[$1831>>2]);
      $1833 = Math_fround($1818 - $1832);
      $1834 = Math_fround($1827 * $1827);
      $1835 = Math_fround($1830 * $1830);
      $1836 = Math_fround($1834 + $1835);
      $1837 = Math_fround($1833 * $1833);
      $1838 = Math_fround($1836 + $1837);
      $1839 = Math_fround($1819 * $1838);
      $1840 = Math_fround($1820 - $1839);
      $1841 = Math_fround($1821 * $1840);
      $1842 = Math_fround($1840 * $1841);
      $1843 = Math_fround($1840 * $1842);
      $1805 = Math_fround($1844 + $1843);
      $1845 = ((($particlesB) + ($1824<<5)|0) + 12|0);
      $1846 = Math_fround(HEAPF32[$1845>>2]);
      $1847 = Math_fround($1846 + $1843);
      HEAPF32[$1845>>2] = $1847;
      $1848 = (($i$01$i9$i) + 1)|0;
      $exitcond$i10$i = ($1848|0)==($1803|0);
      if ($exitcond$i10$i) {
       break;
      } else {
       $1844 = $1805;$i$01$i9$i = $1848;$s$12$i8$i = $1822;
      }
     }
     $1802 = (($1803) + ($1804))|0;
     HEAPF32[$1806>>2] = $1805;
     $s$1$lcssa$i3$i = $1802;
    }
    $1807 = ($s$1$lcssa$i3$i>>>0)<($indexStreamSize$1$lcssa$i>>>0);
    if ($1807) {
     $s$03$i5$i = $s$1$lcssa$i3$i;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  } else {
   $s$03$i$i = 0;
   while(1) {
    $1855 = (($s$03$i$i) + 1)|0;
    $1856 = (($tempIndexStream) + ($s$03$i$i<<2)|0);
    $1857 = HEAP32[$1856>>2]|0;
    $1851 = (($s$03$i$i) + 2)|0;
    $1858 = (($tempIndexStream) + ($1855<<2)|0);
    $1850 = HEAP32[$1858>>2]|0;
    $1859 = ($1850|0)==(0);
    if ($1859) {
     $s$1$lcssa$i$i = $1851;
    } else {
     $1860 = (($particlesA) + ($1857<<5)|0);
     $1861 = Math_fround(HEAPF32[$1860>>2]);
     $1862 = ((($particlesA) + ($1857<<5)|0) + 4|0);
     $1863 = Math_fround(HEAPF32[$1862>>2]);
     $1864 = ((($particlesA) + ($1857<<5)|0) + 8|0);
     $1865 = Math_fround(HEAPF32[$1864>>2]);
     $1866 = Math_fround(HEAPF32[$1467>>2]);
     $1867 = Math_fround(HEAPF32[$1479>>2]);
     $1868 = Math_fround(HEAPF32[$1485>>2]);
     $1853 = ((($particlesA) + ($1857<<5)|0) + 12|0);
     $$promoted$i$i = Math_fround(HEAPF32[$1853>>2]);
     $1891 = $$promoted$i$i;$i$01$i$i = 0;$s$12$i$i = $1851;
     while(1) {
      $1869 = (($s$12$i$i) + 1)|0;
      $1870 = (($tempIndexStream) + ($s$12$i$i<<2)|0);
      $1871 = HEAP32[$1870>>2]|0;
      $1872 = (($particlesB) + ($1871<<5)|0);
      $1873 = Math_fround(HEAPF32[$1872>>2]);
      $1874 = Math_fround($1861 - $1873);
      $1875 = ((($particlesB) + ($1871<<5)|0) + 4|0);
      $1876 = Math_fround(HEAPF32[$1875>>2]);
      $1877 = Math_fround($1863 - $1876);
      $1878 = ((($particlesB) + ($1871<<5)|0) + 8|0);
      $1879 = Math_fround(HEAPF32[$1878>>2]);
      $1880 = Math_fround($1865 - $1879);
      $1881 = Math_fround($1874 * $1874);
      $1882 = Math_fround($1877 * $1877);
      $1883 = Math_fround($1881 + $1882);
      $1884 = Math_fround($1880 * $1880);
      $1885 = Math_fround($1883 + $1884);
      $1886 = Math_fround($1866 * $1885);
      $1887 = Math_fround($1867 - $1886);
      $1888 = Math_fround($1868 * $1887);
      $1889 = Math_fround($1887 * $1888);
      $1890 = Math_fround($1887 * $1889);
      $1852 = Math_fround($1891 + $1890);
      $1892 = (($i$01$i$i) + 1)|0;
      $exitcond$i$i = ($1892|0)==($1850|0);
      if ($exitcond$i$i) {
       break;
      } else {
       $1891 = $1852;$i$01$i$i = $1892;$s$12$i$i = $1869;
      }
     }
     $1849 = (($1850) + ($1851))|0;
     HEAPF32[$1853>>2] = $1852;
     $s$1$lcssa$i$i = $1849;
    }
    $1854 = ($s$1$lcssa$i$i>>>0)<($indexStreamSize$1$lcssa$i>>>0);
    if ($1854) {
     $s$03$i$i = $s$1$lcssa$i$i;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $5 = $numParticlesB & -4;
 $6 = (($params) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
 $9 = ($numParticlesA|0)==(0);
 if (!($isDensityMode)) {
  if ($twoWayUpdate) {
   if ($9) {
    STACKTOP = sp;return;
   }
   $382 = ($5|0)==(0);
   $383 = ($5>>>0)<($numParticlesB>>>0);
   $384 = (($params) + 52|0);
   $385 = (($params) + 24|0);
   $386 = (($params) + 44|0);
   $387 = (($params) + 28|0);
   $388 = (($params) + 36|0);
   $389 = (($params) + 48|0);
   $390 = (($params) + 40|0);
   $pA$026$i = 0;
   while(1) {
    $391 = (($particleIndicesA) + ($pA$026$i<<2)|0);
    $392 = HEAP32[$391>>2]|0;
    $393 = (($particlesA) + ($392<<5)|0);
    $394 = (($forceBufA) + (($392*12)|0)|0);
    if (!($382)) {
     $395 = Math_fround(HEAPF32[$393>>2]);
     $396 = ((($particlesA) + ($392<<5)|0) + 4|0);
     $397 = Math_fround(HEAPF32[$396>>2]);
     $398 = ((($particlesA) + ($392<<5)|0) + 8|0);
     $399 = Math_fround(HEAPF32[$398>>2]);
     $400 = ((($particlesA) + ($392<<5)|0) + 12|0);
     $401 = ((($particlesA) + ($392<<5)|0) + 16|0);
     $402 = ((($particlesA) + ($392<<5)|0) + 20|0);
     $403 = ((($particlesA) + ($392<<5)|0) + 24|0);
     $404 = ((($forceBufA) + (($392*12)|0)|0) + 4|0);
     $405 = ((($forceBufA) + (($392*12)|0)|0) + 8|0);
     $pB$023$i = 0;
     while(1) {
      $406 = (($particleIndicesB) + ($pB$023$i<<2)|0);
      $407 = HEAP32[$406>>2]|0;
      $408 = $pB$023$i | 1;
      $409 = (($particleIndicesB) + ($408<<2)|0);
      $410 = HEAP32[$409>>2]|0;
      $411 = $pB$023$i | 2;
      $412 = (($particleIndicesB) + ($411<<2)|0);
      $413 = HEAP32[$412>>2]|0;
      $414 = $pB$023$i | 3;
      $415 = (($particleIndicesB) + ($414<<2)|0);
      $416 = HEAP32[$415>>2]|0;
      $417 = (($particlesB) + ($407<<5)|0);
      $418 = Math_fround(HEAPF32[$417>>2]);
      $419 = Math_fround($395 - $418);
      $420 = ((($particlesB) + ($407<<5)|0) + 4|0);
      $421 = Math_fround(HEAPF32[$420>>2]);
      $422 = Math_fround($397 - $421);
      $423 = ((($particlesB) + ($407<<5)|0) + 8|0);
      $424 = Math_fround(HEAPF32[$423>>2]);
      $425 = Math_fround($399 - $424);
      $426 = (($particlesB) + ($410<<5)|0);
      $427 = Math_fround(HEAPF32[$426>>2]);
      $428 = Math_fround($395 - $427);
      $429 = ((($particlesB) + ($410<<5)|0) + 4|0);
      $430 = Math_fround(HEAPF32[$429>>2]);
      $431 = Math_fround($397 - $430);
      $432 = ((($particlesB) + ($410<<5)|0) + 8|0);
      $433 = Math_fround(HEAPF32[$432>>2]);
      $434 = Math_fround($399 - $433);
      $435 = (($particlesB) + ($413<<5)|0);
      $436 = Math_fround(HEAPF32[$435>>2]);
      $437 = Math_fround($395 - $436);
      $438 = ((($particlesB) + ($413<<5)|0) + 4|0);
      $439 = Math_fround(HEAPF32[$438>>2]);
      $440 = Math_fround($397 - $439);
      $441 = ((($particlesB) + ($413<<5)|0) + 8|0);
      $442 = Math_fround(HEAPF32[$441>>2]);
      $443 = Math_fround($399 - $442);
      $444 = (($particlesB) + ($416<<5)|0);
      $445 = Math_fround(HEAPF32[$444>>2]);
      $446 = Math_fround($395 - $445);
      $447 = ((($particlesB) + ($416<<5)|0) + 4|0);
      $448 = Math_fround(HEAPF32[$447>>2]);
      $449 = Math_fround($397 - $448);
      $450 = ((($particlesB) + ($416<<5)|0) + 8|0);
      $451 = Math_fround(HEAPF32[$450>>2]);
      $452 = Math_fround($399 - $451);
      $453 = Math_fround($419 * $419);
      $454 = Math_fround($422 * $422);
      $455 = Math_fround($453 + $454);
      $456 = Math_fround($425 * $425);
      $457 = Math_fround($455 + $456);
      $458 = Math_fround($428 * $428);
      $459 = Math_fround($431 * $431);
      $460 = Math_fround($458 + $459);
      $461 = Math_fround($434 * $434);
      $462 = Math_fround($460 + $461);
      $463 = Math_fround($437 * $437);
      $464 = Math_fround($440 * $440);
      $465 = Math_fround($463 + $464);
      $466 = Math_fround($443 * $443);
      $467 = Math_fround($465 + $466);
      $468 = Math_fround($446 * $446);
      $469 = Math_fround($449 * $449);
      $470 = Math_fround($468 + $469);
      $471 = Math_fround($452 * $452);
      $472 = Math_fround($470 + $471);
      $473 = Math_fround($7 - $457);
      $474 = Math_fround($7 - $462);
      $475 = Math_fround($7 - $467);
      $476 = Math_fround($7 - $472);
      $not$22$i = !($473 >= Math_fround(0.0));
      $not$21$i = !($474 >= Math_fround(0.0));
      $477 = $not$21$i & $not$22$i;
      $not$20$i = !($475 >= Math_fround(0.0));
      $478 = $477 & $not$20$i;
      $not$$i21 = !($476 >= Math_fround(0.0));
      $479 = $478 & $not$$i21;
      if (!($479)) {
       $480 = (HEAPF32[tempDoublePtr>>2]=$457,HEAP32[tempDoublePtr>>2]|0);
       $481 = (HEAPF32[tempDoublePtr>>2]=$462,HEAP32[tempDoublePtr>>2]|0);
       $482 = (HEAPF32[tempDoublePtr>>2]=$467,HEAP32[tempDoublePtr>>2]|0);
       $483 = (HEAPF32[tempDoublePtr>>2]=$472,HEAP32[tempDoublePtr>>2]|0);
       $484 = ($480>>>0)<($8>>>0);
       $485 = ($480|0)!=(0);
       $or$cond$i22 = $484 & $485;
       if ($or$cond$i22) {
        $486 = Math_fround(HEAPF32[$384>>2]);
        $487 = Math_fround($457 * $486);
        $488 = (Math_fround(Math_sqrt((Math_fround($487)))));
        $489 = Math_fround(Math_fround(1.0) / $488);
        $490 = Math_fround($487 * $489);
        $491 = Math_fround(HEAPF32[$385>>2]);
        $492 = Math_fround($491 - $490);
        $493 = Math_fround(HEAPF32[$400>>2]);
        $494 = Math_fround(HEAPF32[$386>>2]);
        $495 = Math_fround($493 - $494);
        $496 = $495 > Math_fround(0.0);
        $497 = $496 ? $495 : Math_fround(0.0);
        $498 = ((($particlesB) + ($407<<5)|0) + 12|0);
        $499 = Math_fround(HEAPF32[$498>>2]);
        $500 = Math_fround($499 - $494);
        $501 = $500 > Math_fround(0.0);
        $502 = $501 ? $500 : Math_fround(0.0);
        $503 = Math_fround($497 + $502);
        $504 = Math_fround(HEAPF32[$387>>2]);
        $505 = Math_fround($489 * $504);
        $506 = Math_fround($491 * Math_fround(2.0));
        $507 = Math_fround($505 - $506);
        $508 = Math_fround($490 + $507);
        $509 = Math_fround(HEAPF32[$388>>2]);
        $510 = Math_fround($509 * $508);
        $511 = Math_fround($503 * $510);
        $512 = Math_fround($419 * $511);
        $513 = Math_fround($422 * $511);
        $514 = Math_fround($425 * $511);
        $515 = Math_fround(HEAPF32[$389>>2]);
        $516 = Math_fround($515 * $512);
        $517 = Math_fround($515 * $513);
        $518 = Math_fround($515 * $514);
        $519 = Math_fround(HEAPF32[$390>>2]);
        $520 = Math_fround($492 * $519);
        $521 = ((($particlesB) + ($407<<5)|0) + 16|0);
        $522 = Math_fround(HEAPF32[$521>>2]);
        $523 = Math_fround(HEAPF32[$401>>2]);
        $524 = Math_fround($522 - $523);
        $525 = ((($particlesB) + ($407<<5)|0) + 20|0);
        $526 = Math_fround(HEAPF32[$525>>2]);
        $527 = Math_fround(HEAPF32[$402>>2]);
        $528 = Math_fround($526 - $527);
        $529 = ((($particlesB) + ($407<<5)|0) + 24|0);
        $530 = Math_fround(HEAPF32[$529>>2]);
        $531 = Math_fround(HEAPF32[$403>>2]);
        $532 = Math_fround($530 - $531);
        $533 = Math_fround($515 * $524);
        $534 = Math_fround($515 * $528);
        $535 = Math_fround($515 * $532);
        $536 = Math_fround($520 * $533);
        $537 = Math_fround($520 * $534);
        $538 = Math_fround($520 * $535);
        $539 = Math_fround($516 + $536);
        $540 = Math_fround($517 + $537);
        $541 = Math_fround($518 + $538);
        $542 = Math_fround(Math_fround(1.0) / $499);
        $543 = Math_fround($539 * $542);
        $544 = Math_fround($542 * $540);
        $545 = Math_fround($542 * $541);
        $546 = Math_fround(HEAPF32[$394>>2]);
        $547 = Math_fround($543 + $546);
        HEAPF32[$394>>2] = $547;
        $548 = Math_fround(HEAPF32[$404>>2]);
        $549 = Math_fround($544 + $548);
        HEAPF32[$404>>2] = $549;
        $550 = Math_fround(HEAPF32[$405>>2]);
        $551 = Math_fround($550 + $545);
        HEAPF32[$405>>2] = $551;
        $552 = Math_fround(Math_fround(1.0) / $493);
        $553 = Math_fround($539 * $552);
        $554 = Math_fround($540 * $552);
        $555 = Math_fround($541 * $552);
        $556 = (($forceBufB) + (($407*12)|0)|0);
        $557 = Math_fround(HEAPF32[$556>>2]);
        $558 = Math_fround($557 - $553);
        HEAPF32[$556>>2] = $558;
        $559 = ((($forceBufB) + (($407*12)|0)|0) + 4|0);
        $560 = Math_fround(HEAPF32[$559>>2]);
        $561 = Math_fround($560 - $554);
        HEAPF32[$559>>2] = $561;
        $562 = ((($forceBufB) + (($407*12)|0)|0) + 8|0);
        $563 = Math_fround(HEAPF32[$562>>2]);
        $564 = Math_fround($563 - $555);
        HEAPF32[$562>>2] = $564;
       }
       $565 = ($481>>>0)<($8>>>0);
       $566 = ($481|0)!=(0);
       $or$cond3$i23 = $565 & $566;
       if ($or$cond3$i23) {
        $567 = Math_fround(HEAPF32[$384>>2]);
        $568 = Math_fround($462 * $567);
        $569 = (Math_fround(Math_sqrt((Math_fround($568)))));
        $570 = Math_fround(Math_fround(1.0) / $569);
        $571 = Math_fround($568 * $570);
        $572 = Math_fround(HEAPF32[$385>>2]);
        $573 = Math_fround($572 - $571);
        $574 = Math_fround(HEAPF32[$400>>2]);
        $575 = Math_fround(HEAPF32[$386>>2]);
        $576 = Math_fround($574 - $575);
        $577 = $576 > Math_fround(0.0);
        $578 = $577 ? $576 : Math_fround(0.0);
        $579 = ((($particlesB) + ($410<<5)|0) + 12|0);
        $580 = Math_fround(HEAPF32[$579>>2]);
        $581 = Math_fround($580 - $575);
        $582 = $581 > Math_fround(0.0);
        $583 = $582 ? $581 : Math_fround(0.0);
        $584 = Math_fround($578 + $583);
        $585 = Math_fround(HEAPF32[$387>>2]);
        $586 = Math_fround($570 * $585);
        $587 = Math_fround($572 * Math_fround(2.0));
        $588 = Math_fround($586 - $587);
        $589 = Math_fround($571 + $588);
        $590 = Math_fround(HEAPF32[$388>>2]);
        $591 = Math_fround($590 * $589);
        $592 = Math_fround($584 * $591);
        $593 = Math_fround($428 * $592);
        $594 = Math_fround($431 * $592);
        $595 = Math_fround($434 * $592);
        $596 = Math_fround(HEAPF32[$389>>2]);
        $597 = Math_fround($596 * $593);
        $598 = Math_fround($596 * $594);
        $599 = Math_fround($596 * $595);
        $600 = Math_fround(HEAPF32[$390>>2]);
        $601 = Math_fround($573 * $600);
        $602 = ((($particlesB) + ($410<<5)|0) + 16|0);
        $603 = Math_fround(HEAPF32[$602>>2]);
        $604 = Math_fround(HEAPF32[$401>>2]);
        $605 = Math_fround($603 - $604);
        $606 = ((($particlesB) + ($410<<5)|0) + 20|0);
        $607 = Math_fround(HEAPF32[$606>>2]);
        $608 = Math_fround(HEAPF32[$402>>2]);
        $609 = Math_fround($607 - $608);
        $610 = ((($particlesB) + ($410<<5)|0) + 24|0);
        $611 = Math_fround(HEAPF32[$610>>2]);
        $612 = Math_fround(HEAPF32[$403>>2]);
        $613 = Math_fround($611 - $612);
        $614 = Math_fround($596 * $605);
        $615 = Math_fround($596 * $609);
        $616 = Math_fround($596 * $613);
        $617 = Math_fround($601 * $614);
        $618 = Math_fround($601 * $615);
        $619 = Math_fround($601 * $616);
        $620 = Math_fround($597 + $617);
        $621 = Math_fround($598 + $618);
        $622 = Math_fround($599 + $619);
        $623 = Math_fround(Math_fround(1.0) / $580);
        $624 = Math_fround($620 * $623);
        $625 = Math_fround($623 * $621);
        $626 = Math_fround($623 * $622);
        $627 = Math_fround(HEAPF32[$394>>2]);
        $628 = Math_fround($624 + $627);
        HEAPF32[$394>>2] = $628;
        $629 = Math_fround(HEAPF32[$404>>2]);
        $630 = Math_fround($625 + $629);
        HEAPF32[$404>>2] = $630;
        $631 = Math_fround(HEAPF32[$405>>2]);
        $632 = Math_fround($631 + $626);
        HEAPF32[$405>>2] = $632;
        $633 = Math_fround(Math_fround(1.0) / $574);
        $634 = Math_fround($620 * $633);
        $635 = Math_fround($621 * $633);
        $636 = Math_fround($622 * $633);
        $637 = (($forceBufB) + (($410*12)|0)|0);
        $638 = Math_fround(HEAPF32[$637>>2]);
        $639 = Math_fround($638 - $634);
        HEAPF32[$637>>2] = $639;
        $640 = ((($forceBufB) + (($410*12)|0)|0) + 4|0);
        $641 = Math_fround(HEAPF32[$640>>2]);
        $642 = Math_fround($641 - $635);
        HEAPF32[$640>>2] = $642;
        $643 = ((($forceBufB) + (($410*12)|0)|0) + 8|0);
        $644 = Math_fround(HEAPF32[$643>>2]);
        $645 = Math_fround($644 - $636);
        HEAPF32[$643>>2] = $645;
       }
       $646 = ($482>>>0)<($8>>>0);
       $647 = ($482|0)!=(0);
       $or$cond5$i24 = $646 & $647;
       if ($or$cond5$i24) {
        $648 = Math_fround(HEAPF32[$384>>2]);
        $649 = Math_fround($467 * $648);
        $650 = (Math_fround(Math_sqrt((Math_fround($649)))));
        $651 = Math_fround(Math_fround(1.0) / $650);
        $652 = Math_fround($649 * $651);
        $653 = Math_fround(HEAPF32[$385>>2]);
        $654 = Math_fround($653 - $652);
        $655 = Math_fround(HEAPF32[$400>>2]);
        $656 = Math_fround(HEAPF32[$386>>2]);
        $657 = Math_fround($655 - $656);
        $658 = $657 > Math_fround(0.0);
        $659 = $658 ? $657 : Math_fround(0.0);
        $660 = ((($particlesB) + ($413<<5)|0) + 12|0);
        $661 = Math_fround(HEAPF32[$660>>2]);
        $662 = Math_fround($661 - $656);
        $663 = $662 > Math_fround(0.0);
        $664 = $663 ? $662 : Math_fround(0.0);
        $665 = Math_fround($659 + $664);
        $666 = Math_fround(HEAPF32[$387>>2]);
        $667 = Math_fround($651 * $666);
        $668 = Math_fround($653 * Math_fround(2.0));
        $669 = Math_fround($667 - $668);
        $670 = Math_fround($652 + $669);
        $671 = Math_fround(HEAPF32[$388>>2]);
        $672 = Math_fround($671 * $670);
        $673 = Math_fround($665 * $672);
        $674 = Math_fround($437 * $673);
        $675 = Math_fround($440 * $673);
        $676 = Math_fround($443 * $673);
        $677 = Math_fround(HEAPF32[$389>>2]);
        $678 = Math_fround($677 * $674);
        $679 = Math_fround($677 * $675);
        $680 = Math_fround($677 * $676);
        $681 = Math_fround(HEAPF32[$390>>2]);
        $682 = Math_fround($654 * $681);
        $683 = ((($particlesB) + ($413<<5)|0) + 16|0);
        $684 = Math_fround(HEAPF32[$683>>2]);
        $685 = Math_fround(HEAPF32[$401>>2]);
        $686 = Math_fround($684 - $685);
        $687 = ((($particlesB) + ($413<<5)|0) + 20|0);
        $688 = Math_fround(HEAPF32[$687>>2]);
        $689 = Math_fround(HEAPF32[$402>>2]);
        $690 = Math_fround($688 - $689);
        $691 = ((($particlesB) + ($413<<5)|0) + 24|0);
        $692 = Math_fround(HEAPF32[$691>>2]);
        $693 = Math_fround(HEAPF32[$403>>2]);
        $694 = Math_fround($692 - $693);
        $695 = Math_fround($677 * $686);
        $696 = Math_fround($677 * $690);
        $697 = Math_fround($677 * $694);
        $698 = Math_fround($682 * $695);
        $699 = Math_fround($682 * $696);
        $700 = Math_fround($682 * $697);
        $701 = Math_fround($678 + $698);
        $702 = Math_fround($679 + $699);
        $703 = Math_fround($680 + $700);
        $704 = Math_fround(Math_fround(1.0) / $661);
        $705 = Math_fround($701 * $704);
        $706 = Math_fround($704 * $702);
        $707 = Math_fround($704 * $703);
        $708 = Math_fround(HEAPF32[$394>>2]);
        $709 = Math_fround($705 + $708);
        HEAPF32[$394>>2] = $709;
        $710 = Math_fround(HEAPF32[$404>>2]);
        $711 = Math_fround($706 + $710);
        HEAPF32[$404>>2] = $711;
        $712 = Math_fround(HEAPF32[$405>>2]);
        $713 = Math_fround($712 + $707);
        HEAPF32[$405>>2] = $713;
        $714 = Math_fround(Math_fround(1.0) / $655);
        $715 = Math_fround($701 * $714);
        $716 = Math_fround($702 * $714);
        $717 = Math_fround($703 * $714);
        $718 = (($forceBufB) + (($413*12)|0)|0);
        $719 = Math_fround(HEAPF32[$718>>2]);
        $720 = Math_fround($719 - $715);
        HEAPF32[$718>>2] = $720;
        $721 = ((($forceBufB) + (($413*12)|0)|0) + 4|0);
        $722 = Math_fround(HEAPF32[$721>>2]);
        $723 = Math_fround($722 - $716);
        HEAPF32[$721>>2] = $723;
        $724 = ((($forceBufB) + (($413*12)|0)|0) + 8|0);
        $725 = Math_fround(HEAPF32[$724>>2]);
        $726 = Math_fround($725 - $717);
        HEAPF32[$724>>2] = $726;
       }
       $727 = ($483>>>0)<($8>>>0);
       $728 = ($483|0)!=(0);
       $or$cond7$i25 = $727 & $728;
       if ($or$cond7$i25) {
        $729 = Math_fround(HEAPF32[$384>>2]);
        $730 = Math_fround($472 * $729);
        $731 = (Math_fround(Math_sqrt((Math_fround($730)))));
        $732 = Math_fround(Math_fround(1.0) / $731);
        $733 = Math_fround($730 * $732);
        $734 = Math_fround(HEAPF32[$385>>2]);
        $735 = Math_fround($734 - $733);
        $736 = Math_fround(HEAPF32[$400>>2]);
        $737 = Math_fround(HEAPF32[$386>>2]);
        $738 = Math_fround($736 - $737);
        $739 = $738 > Math_fround(0.0);
        $740 = $739 ? $738 : Math_fround(0.0);
        $741 = ((($particlesB) + ($416<<5)|0) + 12|0);
        $742 = Math_fround(HEAPF32[$741>>2]);
        $743 = Math_fround($742 - $737);
        $744 = $743 > Math_fround(0.0);
        $745 = $744 ? $743 : Math_fround(0.0);
        $746 = Math_fround($740 + $745);
        $747 = Math_fround(HEAPF32[$387>>2]);
        $748 = Math_fround($732 * $747);
        $749 = Math_fround($734 * Math_fround(2.0));
        $750 = Math_fround($748 - $749);
        $751 = Math_fround($733 + $750);
        $752 = Math_fround(HEAPF32[$388>>2]);
        $753 = Math_fround($752 * $751);
        $754 = Math_fround($746 * $753);
        $755 = Math_fround($446 * $754);
        $756 = Math_fround($449 * $754);
        $757 = Math_fround($452 * $754);
        $758 = Math_fround(HEAPF32[$389>>2]);
        $759 = Math_fround($758 * $755);
        $760 = Math_fround($758 * $756);
        $761 = Math_fround($758 * $757);
        $762 = Math_fround(HEAPF32[$390>>2]);
        $763 = Math_fround($735 * $762);
        $764 = ((($particlesB) + ($416<<5)|0) + 16|0);
        $765 = Math_fround(HEAPF32[$764>>2]);
        $766 = Math_fround(HEAPF32[$401>>2]);
        $767 = Math_fround($765 - $766);
        $768 = ((($particlesB) + ($416<<5)|0) + 20|0);
        $769 = Math_fround(HEAPF32[$768>>2]);
        $770 = Math_fround(HEAPF32[$402>>2]);
        $771 = Math_fround($769 - $770);
        $772 = ((($particlesB) + ($416<<5)|0) + 24|0);
        $773 = Math_fround(HEAPF32[$772>>2]);
        $774 = Math_fround(HEAPF32[$403>>2]);
        $775 = Math_fround($773 - $774);
        $776 = Math_fround($758 * $767);
        $777 = Math_fround($758 * $771);
        $778 = Math_fround($758 * $775);
        $779 = Math_fround($763 * $776);
        $780 = Math_fround($763 * $777);
        $781 = Math_fround($763 * $778);
        $782 = Math_fround($759 + $779);
        $783 = Math_fround($760 + $780);
        $784 = Math_fround($761 + $781);
        $785 = Math_fround(Math_fround(1.0) / $742);
        $786 = Math_fround($782 * $785);
        $787 = Math_fround($785 * $783);
        $788 = Math_fround($785 * $784);
        $789 = Math_fround(HEAPF32[$394>>2]);
        $790 = Math_fround($786 + $789);
        HEAPF32[$394>>2] = $790;
        $791 = Math_fround(HEAPF32[$404>>2]);
        $792 = Math_fround($787 + $791);
        HEAPF32[$404>>2] = $792;
        $793 = Math_fround(HEAPF32[$405>>2]);
        $794 = Math_fround($793 + $788);
        HEAPF32[$405>>2] = $794;
        $795 = Math_fround(Math_fround(1.0) / $736);
        $796 = Math_fround($782 * $795);
        $797 = Math_fround($783 * $795);
        $798 = Math_fround($784 * $795);
        $799 = (($forceBufB) + (($416*12)|0)|0);
        $800 = Math_fround(HEAPF32[$799>>2]);
        $801 = Math_fround($800 - $796);
        HEAPF32[$799>>2] = $801;
        $802 = ((($forceBufB) + (($416*12)|0)|0) + 4|0);
        $803 = Math_fround(HEAPF32[$802>>2]);
        $804 = Math_fround($803 - $797);
        HEAPF32[$802>>2] = $804;
        $805 = ((($forceBufB) + (($416*12)|0)|0) + 8|0);
        $806 = Math_fround(HEAPF32[$805>>2]);
        $807 = Math_fround($806 - $798);
        HEAPF32[$805>>2] = $807;
       }
      }
      $808 = (($pB$023$i) + 4)|0;
      $809 = ($808>>>0)<($5>>>0);
      if ($809) {
       $pB$023$i = $808;
      } else {
       break;
      }
     }
    }
    if ($383) {
     $810 = Math_fround(HEAPF32[$393>>2]);
     $811 = ((($particlesA) + ($392<<5)|0) + 4|0);
     $812 = Math_fround(HEAPF32[$811>>2]);
     $813 = ((($particlesA) + ($392<<5)|0) + 8|0);
     $814 = Math_fround(HEAPF32[$813>>2]);
     $815 = ((($particlesA) + ($392<<5)|0) + 12|0);
     $816 = ((($particlesA) + ($392<<5)|0) + 16|0);
     $817 = ((($particlesA) + ($392<<5)|0) + 20|0);
     $818 = ((($particlesA) + ($392<<5)|0) + 24|0);
     $819 = ((($forceBufA) + (($392*12)|0)|0) + 4|0);
     $820 = ((($forceBufA) + (($392*12)|0)|0) + 8|0);
     $pB1$024$i = $5;
     while(1) {
      $821 = (($particleIndicesB) + ($pB1$024$i<<2)|0);
      $822 = HEAP32[$821>>2]|0;
      $823 = (($particlesB) + ($822<<5)|0);
      $824 = Math_fround(HEAPF32[$823>>2]);
      $825 = Math_fround($810 - $824);
      $826 = ((($particlesB) + ($822<<5)|0) + 4|0);
      $827 = Math_fround(HEAPF32[$826>>2]);
      $828 = Math_fround($812 - $827);
      $829 = ((($particlesB) + ($822<<5)|0) + 8|0);
      $830 = Math_fround(HEAPF32[$829>>2]);
      $831 = Math_fround($814 - $830);
      $832 = Math_fround($825 * $825);
      $833 = Math_fround($828 * $828);
      $834 = Math_fround($832 + $833);
      $835 = Math_fround($831 * $831);
      $836 = Math_fround($834 + $835);
      $837 = (HEAPF32[tempDoublePtr>>2]=$836,HEAP32[tempDoublePtr>>2]|0);
      $838 = ($837>>>0)<($8>>>0);
      $839 = ($837|0)!=(0);
      $or$cond9$i27 = $838 & $839;
      if ($or$cond9$i27) {
       $840 = Math_fround(HEAPF32[$384>>2]);
       $841 = Math_fround($836 * $840);
       $842 = (Math_fround(Math_sqrt((Math_fround($841)))));
       $843 = Math_fround(Math_fround(1.0) / $842);
       $844 = Math_fround($841 * $843);
       $845 = Math_fround(HEAPF32[$385>>2]);
       $846 = Math_fround($845 - $844);
       $847 = Math_fround(HEAPF32[$815>>2]);
       $848 = Math_fround(HEAPF32[$386>>2]);
       $849 = Math_fround($847 - $848);
       $850 = $849 > Math_fround(0.0);
       $851 = $850 ? $849 : Math_fround(0.0);
       $852 = ((($particlesB) + ($822<<5)|0) + 12|0);
       $853 = Math_fround(HEAPF32[$852>>2]);
       $854 = Math_fround($853 - $848);
       $855 = $854 > Math_fround(0.0);
       $856 = $855 ? $854 : Math_fround(0.0);
       $857 = Math_fround($851 + $856);
       $858 = Math_fround(HEAPF32[$387>>2]);
       $859 = Math_fround($843 * $858);
       $860 = Math_fround($845 * Math_fround(2.0));
       $861 = Math_fround($859 - $860);
       $862 = Math_fround($844 + $861);
       $863 = Math_fround(HEAPF32[$388>>2]);
       $864 = Math_fround($863 * $862);
       $865 = Math_fround($857 * $864);
       $866 = Math_fround($825 * $865);
       $867 = Math_fround($828 * $865);
       $868 = Math_fround($831 * $865);
       $869 = Math_fround(HEAPF32[$389>>2]);
       $870 = Math_fround($869 * $866);
       $871 = Math_fround($869 * $867);
       $872 = Math_fround($869 * $868);
       $873 = Math_fround(HEAPF32[$390>>2]);
       $874 = Math_fround($846 * $873);
       $875 = ((($particlesB) + ($822<<5)|0) + 16|0);
       $876 = Math_fround(HEAPF32[$875>>2]);
       $877 = Math_fround(HEAPF32[$816>>2]);
       $878 = Math_fround($876 - $877);
       $879 = ((($particlesB) + ($822<<5)|0) + 20|0);
       $880 = Math_fround(HEAPF32[$879>>2]);
       $881 = Math_fround(HEAPF32[$817>>2]);
       $882 = Math_fround($880 - $881);
       $883 = ((($particlesB) + ($822<<5)|0) + 24|0);
       $884 = Math_fround(HEAPF32[$883>>2]);
       $885 = Math_fround(HEAPF32[$818>>2]);
       $886 = Math_fround($884 - $885);
       $887 = Math_fround($869 * $878);
       $888 = Math_fround($869 * $882);
       $889 = Math_fround($869 * $886);
       $890 = Math_fround($874 * $887);
       $891 = Math_fround($874 * $888);
       $892 = Math_fround($874 * $889);
       $893 = Math_fround($870 + $890);
       $894 = Math_fround($871 + $891);
       $895 = Math_fround($872 + $892);
       $896 = Math_fround(Math_fround(1.0) / $853);
       $897 = Math_fround($893 * $896);
       $898 = Math_fround($896 * $894);
       $899 = Math_fround($896 * $895);
       $900 = Math_fround(HEAPF32[$394>>2]);
       $901 = Math_fround($897 + $900);
       HEAPF32[$394>>2] = $901;
       $902 = Math_fround(HEAPF32[$819>>2]);
       $903 = Math_fround($898 + $902);
       HEAPF32[$819>>2] = $903;
       $904 = Math_fround(HEAPF32[$820>>2]);
       $905 = Math_fround($904 + $899);
       HEAPF32[$820>>2] = $905;
       $906 = Math_fround(Math_fround(1.0) / $847);
       $907 = Math_fround($893 * $906);
       $908 = Math_fround($894 * $906);
       $909 = Math_fround($895 * $906);
       $910 = (($forceBufB) + (($822*12)|0)|0);
       $911 = Math_fround(HEAPF32[$910>>2]);
       $912 = Math_fround($911 - $907);
       HEAPF32[$910>>2] = $912;
       $913 = ((($forceBufB) + (($822*12)|0)|0) + 4|0);
       $914 = Math_fround(HEAPF32[$913>>2]);
       $915 = Math_fround($914 - $908);
       HEAPF32[$913>>2] = $915;
       $916 = ((($forceBufB) + (($822*12)|0)|0) + 8|0);
       $917 = Math_fround(HEAPF32[$916>>2]);
       $918 = Math_fround($917 - $909);
       HEAPF32[$916>>2] = $918;
      }
      $919 = (($pB1$024$i) + 1)|0;
      $exitcond$i28 = ($919|0)==($numParticlesB|0);
      if ($exitcond$i28) {
       break;
      } else {
       $pB1$024$i = $919;
      }
     }
    }
    $920 = (($pA$026$i) + 1)|0;
    $exitcond30$i = ($920|0)==($numParticlesA|0);
    if ($exitcond30$i) {
     break;
    } else {
     $pA$026$i = $920;
    }
   }
   STACKTOP = sp;return;
  } else {
   if ($9) {
    STACKTOP = sp;return;
   }
   $921 = ($5|0)==(0);
   $922 = ($5>>>0)<($numParticlesB>>>0);
   $923 = (($params) + 52|0);
   $924 = (($params) + 24|0);
   $925 = (($params) + 44|0);
   $926 = (($params) + 28|0);
   $927 = (($params) + 36|0);
   $928 = (($params) + 48|0);
   $929 = (($params) + 40|0);
   $pA$07$i31 = 0;
   while(1) {
    $930 = (($particleIndicesA) + ($pA$07$i31<<2)|0);
    $931 = HEAP32[$930>>2]|0;
    $932 = (($particlesA) + ($931<<5)|0);
    $933 = (($forceBufA) + (($931*12)|0)|0);
    if (!($921)) {
     $934 = Math_fround(HEAPF32[$932>>2]);
     $935 = ((($particlesA) + ($931<<5)|0) + 4|0);
     $936 = Math_fround(HEAPF32[$935>>2]);
     $937 = ((($particlesA) + ($931<<5)|0) + 8|0);
     $938 = Math_fround(HEAPF32[$937>>2]);
     $939 = ((($particlesA) + ($931<<5)|0) + 12|0);
     $940 = ((($particlesA) + ($931<<5)|0) + 16|0);
     $941 = ((($particlesA) + ($931<<5)|0) + 20|0);
     $942 = ((($particlesA) + ($931<<5)|0) + 24|0);
     $943 = ((($forceBufA) + (($931*12)|0)|0) + 4|0);
     $944 = ((($forceBufA) + (($931*12)|0)|0) + 8|0);
     $pB$04$i33 = 0;
     while(1) {
      $945 = (($particleIndicesB) + ($pB$04$i33<<2)|0);
      $946 = HEAP32[$945>>2]|0;
      $947 = $pB$04$i33 | 1;
      $948 = (($particleIndicesB) + ($947<<2)|0);
      $949 = HEAP32[$948>>2]|0;
      $950 = $pB$04$i33 | 2;
      $951 = (($particleIndicesB) + ($950<<2)|0);
      $952 = HEAP32[$951>>2]|0;
      $953 = $pB$04$i33 | 3;
      $954 = (($particleIndicesB) + ($953<<2)|0);
      $955 = HEAP32[$954>>2]|0;
      $956 = (($particlesB) + ($946<<5)|0);
      $957 = Math_fround(HEAPF32[$956>>2]);
      $958 = Math_fround($934 - $957);
      $959 = ((($particlesB) + ($946<<5)|0) + 4|0);
      $960 = Math_fround(HEAPF32[$959>>2]);
      $961 = Math_fround($936 - $960);
      $962 = ((($particlesB) + ($946<<5)|0) + 8|0);
      $963 = Math_fround(HEAPF32[$962>>2]);
      $964 = Math_fround($938 - $963);
      $965 = (($particlesB) + ($949<<5)|0);
      $966 = Math_fround(HEAPF32[$965>>2]);
      $967 = Math_fround($934 - $966);
      $968 = ((($particlesB) + ($949<<5)|0) + 4|0);
      $969 = Math_fround(HEAPF32[$968>>2]);
      $970 = Math_fround($936 - $969);
      $971 = ((($particlesB) + ($949<<5)|0) + 8|0);
      $972 = Math_fround(HEAPF32[$971>>2]);
      $973 = Math_fround($938 - $972);
      $974 = (($particlesB) + ($952<<5)|0);
      $975 = Math_fround(HEAPF32[$974>>2]);
      $976 = Math_fround($934 - $975);
      $977 = ((($particlesB) + ($952<<5)|0) + 4|0);
      $978 = Math_fround(HEAPF32[$977>>2]);
      $979 = Math_fround($936 - $978);
      $980 = ((($particlesB) + ($952<<5)|0) + 8|0);
      $981 = Math_fround(HEAPF32[$980>>2]);
      $982 = Math_fround($938 - $981);
      $983 = (($particlesB) + ($955<<5)|0);
      $984 = Math_fround(HEAPF32[$983>>2]);
      $985 = Math_fround($934 - $984);
      $986 = ((($particlesB) + ($955<<5)|0) + 4|0);
      $987 = Math_fround(HEAPF32[$986>>2]);
      $988 = Math_fround($936 - $987);
      $989 = ((($particlesB) + ($955<<5)|0) + 8|0);
      $990 = Math_fround(HEAPF32[$989>>2]);
      $991 = Math_fround($938 - $990);
      $992 = Math_fround($958 * $958);
      $993 = Math_fround($961 * $961);
      $994 = Math_fround($992 + $993);
      $995 = Math_fround($964 * $964);
      $996 = Math_fround($994 + $995);
      $997 = Math_fround($967 * $967);
      $998 = Math_fround($970 * $970);
      $999 = Math_fround($997 + $998);
      $1000 = Math_fround($973 * $973);
      $1001 = Math_fround($999 + $1000);
      $1002 = Math_fround($976 * $976);
      $1003 = Math_fround($979 * $979);
      $1004 = Math_fround($1002 + $1003);
      $1005 = Math_fround($982 * $982);
      $1006 = Math_fround($1004 + $1005);
      $1007 = Math_fround($985 * $985);
      $1008 = Math_fround($988 * $988);
      $1009 = Math_fround($1007 + $1008);
      $1010 = Math_fround($991 * $991);
      $1011 = Math_fround($1009 + $1010);
      $1012 = Math_fround($7 - $996);
      $1013 = Math_fround($7 - $1001);
      $1014 = Math_fround($7 - $1006);
      $1015 = Math_fround($7 - $1011);
      $not$3$i34 = !($1012 >= Math_fround(0.0));
      $not$2$i35 = !($1013 >= Math_fround(0.0));
      $1016 = $not$2$i35 & $not$3$i34;
      $not$1$i36 = !($1014 >= Math_fround(0.0));
      $1017 = $1016 & $not$1$i36;
      $not$$i37 = !($1015 >= Math_fround(0.0));
      $1018 = $1017 & $not$$i37;
      if (!($1018)) {
       $1019 = (HEAPF32[tempDoublePtr>>2]=$996,HEAP32[tempDoublePtr>>2]|0);
       $1020 = (HEAPF32[tempDoublePtr>>2]=$1001,HEAP32[tempDoublePtr>>2]|0);
       $1021 = (HEAPF32[tempDoublePtr>>2]=$1006,HEAP32[tempDoublePtr>>2]|0);
       $1022 = (HEAPF32[tempDoublePtr>>2]=$1011,HEAP32[tempDoublePtr>>2]|0);
       $1023 = ($1019>>>0)<($8>>>0);
       $1024 = ($1019|0)!=(0);
       $or$cond$i38 = $1023 & $1024;
       if ($or$cond$i38) {
        $1025 = Math_fround(HEAPF32[$923>>2]);
        $1026 = Math_fround($996 * $1025);
        $1027 = (Math_fround(Math_sqrt((Math_fround($1026)))));
        $1028 = Math_fround(Math_fround(1.0) / $1027);
        $1029 = Math_fround($1026 * $1028);
        $1030 = Math_fround(HEAPF32[$924>>2]);
        $1031 = Math_fround($1030 - $1029);
        $1032 = Math_fround(HEAPF32[$939>>2]);
        $1033 = Math_fround(HEAPF32[$925>>2]);
        $1034 = Math_fround($1032 - $1033);
        $1035 = $1034 > Math_fround(0.0);
        $1036 = $1035 ? $1034 : Math_fround(0.0);
        $1037 = ((($particlesB) + ($946<<5)|0) + 12|0);
        $1038 = Math_fround(HEAPF32[$1037>>2]);
        $1039 = Math_fround($1038 - $1033);
        $1040 = $1039 > Math_fround(0.0);
        $1041 = $1040 ? $1039 : Math_fround(0.0);
        $1042 = Math_fround($1036 + $1041);
        $1043 = Math_fround(HEAPF32[$926>>2]);
        $1044 = Math_fround($1028 * $1043);
        $1045 = Math_fround($1030 * Math_fround(2.0));
        $1046 = Math_fround($1044 - $1045);
        $1047 = Math_fround($1029 + $1046);
        $1048 = Math_fround(HEAPF32[$927>>2]);
        $1049 = Math_fround($1048 * $1047);
        $1050 = Math_fround($1042 * $1049);
        $1051 = Math_fround($958 * $1050);
        $1052 = Math_fround($961 * $1050);
        $1053 = Math_fround($964 * $1050);
        $1054 = Math_fround(HEAPF32[$928>>2]);
        $1055 = Math_fround($1054 * $1051);
        $1056 = Math_fround($1054 * $1052);
        $1057 = Math_fround($1054 * $1053);
        $1058 = Math_fround(HEAPF32[$929>>2]);
        $1059 = Math_fround($1031 * $1058);
        $1060 = ((($particlesB) + ($946<<5)|0) + 16|0);
        $1061 = Math_fround(HEAPF32[$1060>>2]);
        $1062 = Math_fround(HEAPF32[$940>>2]);
        $1063 = Math_fround($1061 - $1062);
        $1064 = ((($particlesB) + ($946<<5)|0) + 20|0);
        $1065 = Math_fround(HEAPF32[$1064>>2]);
        $1066 = Math_fround(HEAPF32[$941>>2]);
        $1067 = Math_fround($1065 - $1066);
        $1068 = ((($particlesB) + ($946<<5)|0) + 24|0);
        $1069 = Math_fround(HEAPF32[$1068>>2]);
        $1070 = Math_fround(HEAPF32[$942>>2]);
        $1071 = Math_fround($1069 - $1070);
        $1072 = Math_fround($1054 * $1063);
        $1073 = Math_fround($1054 * $1067);
        $1074 = Math_fround($1054 * $1071);
        $1075 = Math_fround($1059 * $1072);
        $1076 = Math_fround($1059 * $1073);
        $1077 = Math_fround($1059 * $1074);
        $1078 = Math_fround($1055 + $1075);
        $1079 = Math_fround($1056 + $1076);
        $1080 = Math_fround($1057 + $1077);
        $1081 = Math_fround(Math_fround(1.0) / $1038);
        $1082 = Math_fround($1078 * $1081);
        $1083 = Math_fround($1081 * $1079);
        $1084 = Math_fround($1081 * $1080);
        $1085 = Math_fround(HEAPF32[$933>>2]);
        $1086 = Math_fround($1082 + $1085);
        HEAPF32[$933>>2] = $1086;
        $1087 = Math_fround(HEAPF32[$943>>2]);
        $1088 = Math_fround($1083 + $1087);
        HEAPF32[$943>>2] = $1088;
        $1089 = Math_fround(HEAPF32[$944>>2]);
        $1090 = Math_fround($1089 + $1084);
        HEAPF32[$944>>2] = $1090;
       }
       $1091 = ($1020>>>0)<($8>>>0);
       $1092 = ($1020|0)!=(0);
       $or$cond3$i39 = $1091 & $1092;
       if ($or$cond3$i39) {
        $1093 = Math_fround(HEAPF32[$923>>2]);
        $1094 = Math_fround($1001 * $1093);
        $1095 = (Math_fround(Math_sqrt((Math_fround($1094)))));
        $1096 = Math_fround(Math_fround(1.0) / $1095);
        $1097 = Math_fround($1094 * $1096);
        $1098 = Math_fround(HEAPF32[$924>>2]);
        $1099 = Math_fround($1098 - $1097);
        $1100 = Math_fround(HEAPF32[$939>>2]);
        $1101 = Math_fround(HEAPF32[$925>>2]);
        $1102 = Math_fround($1100 - $1101);
        $1103 = $1102 > Math_fround(0.0);
        $1104 = $1103 ? $1102 : Math_fround(0.0);
        $1105 = ((($particlesB) + ($949<<5)|0) + 12|0);
        $1106 = Math_fround(HEAPF32[$1105>>2]);
        $1107 = Math_fround($1106 - $1101);
        $1108 = $1107 > Math_fround(0.0);
        $1109 = $1108 ? $1107 : Math_fround(0.0);
        $1110 = Math_fround($1104 + $1109);
        $1111 = Math_fround(HEAPF32[$926>>2]);
        $1112 = Math_fround($1096 * $1111);
        $1113 = Math_fround($1098 * Math_fround(2.0));
        $1114 = Math_fround($1112 - $1113);
        $1115 = Math_fround($1097 + $1114);
        $1116 = Math_fround(HEAPF32[$927>>2]);
        $1117 = Math_fround($1116 * $1115);
        $1118 = Math_fround($1110 * $1117);
        $1119 = Math_fround($967 * $1118);
        $1120 = Math_fround($970 * $1118);
        $1121 = Math_fround($973 * $1118);
        $1122 = Math_fround(HEAPF32[$928>>2]);
        $1123 = Math_fround($1122 * $1119);
        $1124 = Math_fround($1122 * $1120);
        $1125 = Math_fround($1122 * $1121);
        $1126 = Math_fround(HEAPF32[$929>>2]);
        $1127 = Math_fround($1099 * $1126);
        $1128 = ((($particlesB) + ($949<<5)|0) + 16|0);
        $1129 = Math_fround(HEAPF32[$1128>>2]);
        $1130 = Math_fround(HEAPF32[$940>>2]);
        $1131 = Math_fround($1129 - $1130);
        $1132 = ((($particlesB) + ($949<<5)|0) + 20|0);
        $1133 = Math_fround(HEAPF32[$1132>>2]);
        $1134 = Math_fround(HEAPF32[$941>>2]);
        $1135 = Math_fround($1133 - $1134);
        $1136 = ((($particlesB) + ($949<<5)|0) + 24|0);
        $1137 = Math_fround(HEAPF32[$1136>>2]);
        $1138 = Math_fround(HEAPF32[$942>>2]);
        $1139 = Math_fround($1137 - $1138);
        $1140 = Math_fround($1122 * $1131);
        $1141 = Math_fround($1122 * $1135);
        $1142 = Math_fround($1122 * $1139);
        $1143 = Math_fround($1127 * $1140);
        $1144 = Math_fround($1127 * $1141);
        $1145 = Math_fround($1127 * $1142);
        $1146 = Math_fround($1123 + $1143);
        $1147 = Math_fround($1124 + $1144);
        $1148 = Math_fround($1125 + $1145);
        $1149 = Math_fround(Math_fround(1.0) / $1106);
        $1150 = Math_fround($1146 * $1149);
        $1151 = Math_fround($1149 * $1147);
        $1152 = Math_fround($1149 * $1148);
        $1153 = Math_fround(HEAPF32[$933>>2]);
        $1154 = Math_fround($1150 + $1153);
        HEAPF32[$933>>2] = $1154;
        $1155 = Math_fround(HEAPF32[$943>>2]);
        $1156 = Math_fround($1151 + $1155);
        HEAPF32[$943>>2] = $1156;
        $1157 = Math_fround(HEAPF32[$944>>2]);
        $1158 = Math_fround($1157 + $1152);
        HEAPF32[$944>>2] = $1158;
       }
       $1159 = ($1021>>>0)<($8>>>0);
       $1160 = ($1021|0)!=(0);
       $or$cond5$i40 = $1159 & $1160;
       if ($or$cond5$i40) {
        $1161 = Math_fround(HEAPF32[$923>>2]);
        $1162 = Math_fround($1006 * $1161);
        $1163 = (Math_fround(Math_sqrt((Math_fround($1162)))));
        $1164 = Math_fround(Math_fround(1.0) / $1163);
        $1165 = Math_fround($1162 * $1164);
        $1166 = Math_fround(HEAPF32[$924>>2]);
        $1167 = Math_fround($1166 - $1165);
        $1168 = Math_fround(HEAPF32[$939>>2]);
        $1169 = Math_fround(HEAPF32[$925>>2]);
        $1170 = Math_fround($1168 - $1169);
        $1171 = $1170 > Math_fround(0.0);
        $1172 = $1171 ? $1170 : Math_fround(0.0);
        $1173 = ((($particlesB) + ($952<<5)|0) + 12|0);
        $1174 = Math_fround(HEAPF32[$1173>>2]);
        $1175 = Math_fround($1174 - $1169);
        $1176 = $1175 > Math_fround(0.0);
        $1177 = $1176 ? $1175 : Math_fround(0.0);
        $1178 = Math_fround($1172 + $1177);
        $1179 = Math_fround(HEAPF32[$926>>2]);
        $1180 = Math_fround($1164 * $1179);
        $1181 = Math_fround($1166 * Math_fround(2.0));
        $1182 = Math_fround($1180 - $1181);
        $1183 = Math_fround($1165 + $1182);
        $1184 = Math_fround(HEAPF32[$927>>2]);
        $1185 = Math_fround($1184 * $1183);
        $1186 = Math_fround($1178 * $1185);
        $1187 = Math_fround($976 * $1186);
        $1188 = Math_fround($979 * $1186);
        $1189 = Math_fround($982 * $1186);
        $1190 = Math_fround(HEAPF32[$928>>2]);
        $1191 = Math_fround($1190 * $1187);
        $1192 = Math_fround($1190 * $1188);
        $1193 = Math_fround($1190 * $1189);
        $1194 = Math_fround(HEAPF32[$929>>2]);
        $1195 = Math_fround($1167 * $1194);
        $1196 = ((($particlesB) + ($952<<5)|0) + 16|0);
        $1197 = Math_fround(HEAPF32[$1196>>2]);
        $1198 = Math_fround(HEAPF32[$940>>2]);
        $1199 = Math_fround($1197 - $1198);
        $1200 = ((($particlesB) + ($952<<5)|0) + 20|0);
        $1201 = Math_fround(HEAPF32[$1200>>2]);
        $1202 = Math_fround(HEAPF32[$941>>2]);
        $1203 = Math_fround($1201 - $1202);
        $1204 = ((($particlesB) + ($952<<5)|0) + 24|0);
        $1205 = Math_fround(HEAPF32[$1204>>2]);
        $1206 = Math_fround(HEAPF32[$942>>2]);
        $1207 = Math_fround($1205 - $1206);
        $1208 = Math_fround($1190 * $1199);
        $1209 = Math_fround($1190 * $1203);
        $1210 = Math_fround($1190 * $1207);
        $1211 = Math_fround($1195 * $1208);
        $1212 = Math_fround($1195 * $1209);
        $1213 = Math_fround($1195 * $1210);
        $1214 = Math_fround($1191 + $1211);
        $1215 = Math_fround($1192 + $1212);
        $1216 = Math_fround($1193 + $1213);
        $1217 = Math_fround(Math_fround(1.0) / $1174);
        $1218 = Math_fround($1214 * $1217);
        $1219 = Math_fround($1217 * $1215);
        $1220 = Math_fround($1217 * $1216);
        $1221 = Math_fround(HEAPF32[$933>>2]);
        $1222 = Math_fround($1218 + $1221);
        HEAPF32[$933>>2] = $1222;
        $1223 = Math_fround(HEAPF32[$943>>2]);
        $1224 = Math_fround($1219 + $1223);
        HEAPF32[$943>>2] = $1224;
        $1225 = Math_fround(HEAPF32[$944>>2]);
        $1226 = Math_fround($1225 + $1220);
        HEAPF32[$944>>2] = $1226;
       }
       $1227 = ($1022>>>0)<($8>>>0);
       $1228 = ($1022|0)!=(0);
       $or$cond7$i41 = $1227 & $1228;
       if ($or$cond7$i41) {
        $1229 = Math_fround(HEAPF32[$923>>2]);
        $1230 = Math_fround($1011 * $1229);
        $1231 = (Math_fround(Math_sqrt((Math_fround($1230)))));
        $1232 = Math_fround(Math_fround(1.0) / $1231);
        $1233 = Math_fround($1230 * $1232);
        $1234 = Math_fround(HEAPF32[$924>>2]);
        $1235 = Math_fround($1234 - $1233);
        $1236 = Math_fround(HEAPF32[$939>>2]);
        $1237 = Math_fround(HEAPF32[$925>>2]);
        $1238 = Math_fround($1236 - $1237);
        $1239 = $1238 > Math_fround(0.0);
        $1240 = $1239 ? $1238 : Math_fround(0.0);
        $1241 = ((($particlesB) + ($955<<5)|0) + 12|0);
        $1242 = Math_fround(HEAPF32[$1241>>2]);
        $1243 = Math_fround($1242 - $1237);
        $1244 = $1243 > Math_fround(0.0);
        $1245 = $1244 ? $1243 : Math_fround(0.0);
        $1246 = Math_fround($1240 + $1245);
        $1247 = Math_fround(HEAPF32[$926>>2]);
        $1248 = Math_fround($1232 * $1247);
        $1249 = Math_fround($1234 * Math_fround(2.0));
        $1250 = Math_fround($1248 - $1249);
        $1251 = Math_fround($1233 + $1250);
        $1252 = Math_fround(HEAPF32[$927>>2]);
        $1253 = Math_fround($1252 * $1251);
        $1254 = Math_fround($1246 * $1253);
        $1255 = Math_fround($985 * $1254);
        $1256 = Math_fround($988 * $1254);
        $1257 = Math_fround($991 * $1254);
        $1258 = Math_fround(HEAPF32[$928>>2]);
        $1259 = Math_fround($1258 * $1255);
        $1260 = Math_fround($1258 * $1256);
        $1261 = Math_fround($1258 * $1257);
        $1262 = Math_fround(HEAPF32[$929>>2]);
        $1263 = Math_fround($1235 * $1262);
        $1264 = ((($particlesB) + ($955<<5)|0) + 16|0);
        $1265 = Math_fround(HEAPF32[$1264>>2]);
        $1266 = Math_fround(HEAPF32[$940>>2]);
        $1267 = Math_fround($1265 - $1266);
        $1268 = ((($particlesB) + ($955<<5)|0) + 20|0);
        $1269 = Math_fround(HEAPF32[$1268>>2]);
        $1270 = Math_fround(HEAPF32[$941>>2]);
        $1271 = Math_fround($1269 - $1270);
        $1272 = ((($particlesB) + ($955<<5)|0) + 24|0);
        $1273 = Math_fround(HEAPF32[$1272>>2]);
        $1274 = Math_fround(HEAPF32[$942>>2]);
        $1275 = Math_fround($1273 - $1274);
        $1276 = Math_fround($1258 * $1267);
        $1277 = Math_fround($1258 * $1271);
        $1278 = Math_fround($1258 * $1275);
        $1279 = Math_fround($1263 * $1276);
        $1280 = Math_fround($1263 * $1277);
        $1281 = Math_fround($1263 * $1278);
        $1282 = Math_fround($1259 + $1279);
        $1283 = Math_fround($1260 + $1280);
        $1284 = Math_fround($1261 + $1281);
        $1285 = Math_fround(Math_fround(1.0) / $1242);
        $1286 = Math_fround($1282 * $1285);
        $1287 = Math_fround($1285 * $1283);
        $1288 = Math_fround($1285 * $1284);
        $1289 = Math_fround(HEAPF32[$933>>2]);
        $1290 = Math_fround($1286 + $1289);
        HEAPF32[$933>>2] = $1290;
        $1291 = Math_fround(HEAPF32[$943>>2]);
        $1292 = Math_fround($1287 + $1291);
        HEAPF32[$943>>2] = $1292;
        $1293 = Math_fround(HEAPF32[$944>>2]);
        $1294 = Math_fround($1293 + $1288);
        HEAPF32[$944>>2] = $1294;
       }
      }
      $1295 = (($pB$04$i33) + 4)|0;
      $1296 = ($1295>>>0)<($5>>>0);
      if ($1296) {
       $pB$04$i33 = $1295;
      } else {
       break;
      }
     }
    }
    if ($922) {
     $1297 = Math_fround(HEAPF32[$932>>2]);
     $1298 = ((($particlesA) + ($931<<5)|0) + 4|0);
     $1299 = Math_fround(HEAPF32[$1298>>2]);
     $1300 = ((($particlesA) + ($931<<5)|0) + 8|0);
     $1301 = Math_fround(HEAPF32[$1300>>2]);
     $1302 = ((($particlesA) + ($931<<5)|0) + 12|0);
     $1303 = ((($particlesA) + ($931<<5)|0) + 16|0);
     $1304 = ((($particlesA) + ($931<<5)|0) + 20|0);
     $1305 = ((($particlesA) + ($931<<5)|0) + 24|0);
     $1306 = ((($forceBufA) + (($931*12)|0)|0) + 4|0);
     $1307 = ((($forceBufA) + (($931*12)|0)|0) + 8|0);
     $pB1$05$i44 = $5;
     while(1) {
      $1308 = (($particleIndicesB) + ($pB1$05$i44<<2)|0);
      $1309 = HEAP32[$1308>>2]|0;
      $1310 = (($particlesB) + ($1309<<5)|0);
      $1311 = Math_fround(HEAPF32[$1310>>2]);
      $1312 = Math_fround($1297 - $1311);
      $1313 = ((($particlesB) + ($1309<<5)|0) + 4|0);
      $1314 = Math_fround(HEAPF32[$1313>>2]);
      $1315 = Math_fround($1299 - $1314);
      $1316 = ((($particlesB) + ($1309<<5)|0) + 8|0);
      $1317 = Math_fround(HEAPF32[$1316>>2]);
      $1318 = Math_fround($1301 - $1317);
      $1319 = Math_fround($1312 * $1312);
      $1320 = Math_fround($1315 * $1315);
      $1321 = Math_fround($1319 + $1320);
      $1322 = Math_fround($1318 * $1318);
      $1323 = Math_fround($1321 + $1322);
      $1324 = (HEAPF32[tempDoublePtr>>2]=$1323,HEAP32[tempDoublePtr>>2]|0);
      $1325 = ($1324>>>0)<($8>>>0);
      $1326 = ($1324|0)!=(0);
      $or$cond9$i45 = $1325 & $1326;
      if ($or$cond9$i45) {
       $1327 = Math_fround(HEAPF32[$923>>2]);
       $1328 = Math_fround($1323 * $1327);
       $1329 = (Math_fround(Math_sqrt((Math_fround($1328)))));
       $1330 = Math_fround(Math_fround(1.0) / $1329);
       $1331 = Math_fround($1328 * $1330);
       $1332 = Math_fround(HEAPF32[$924>>2]);
       $1333 = Math_fround($1332 - $1331);
       $1334 = Math_fround(HEAPF32[$1302>>2]);
       $1335 = Math_fround(HEAPF32[$925>>2]);
       $1336 = Math_fround($1334 - $1335);
       $1337 = $1336 > Math_fround(0.0);
       $1338 = $1337 ? $1336 : Math_fround(0.0);
       $1339 = ((($particlesB) + ($1309<<5)|0) + 12|0);
       $1340 = Math_fround(HEAPF32[$1339>>2]);
       $1341 = Math_fround($1340 - $1335);
       $1342 = $1341 > Math_fround(0.0);
       $1343 = $1342 ? $1341 : Math_fround(0.0);
       $1344 = Math_fround($1338 + $1343);
       $1345 = Math_fround(HEAPF32[$926>>2]);
       $1346 = Math_fround($1330 * $1345);
       $1347 = Math_fround($1332 * Math_fround(2.0));
       $1348 = Math_fround($1346 - $1347);
       $1349 = Math_fround($1331 + $1348);
       $1350 = Math_fround(HEAPF32[$927>>2]);
       $1351 = Math_fround($1350 * $1349);
       $1352 = Math_fround($1344 * $1351);
       $1353 = Math_fround($1312 * $1352);
       $1354 = Math_fround($1315 * $1352);
       $1355 = Math_fround($1318 * $1352);
       $1356 = Math_fround(HEAPF32[$928>>2]);
       $1357 = Math_fround($1356 * $1353);
       $1358 = Math_fround($1356 * $1354);
       $1359 = Math_fround($1356 * $1355);
       $1360 = Math_fround(HEAPF32[$929>>2]);
       $1361 = Math_fround($1333 * $1360);
       $1362 = ((($particlesB) + ($1309<<5)|0) + 16|0);
       $1363 = Math_fround(HEAPF32[$1362>>2]);
       $1364 = Math_fround(HEAPF32[$1303>>2]);
       $1365 = Math_fround($1363 - $1364);
       $1366 = ((($particlesB) + ($1309<<5)|0) + 20|0);
       $1367 = Math_fround(HEAPF32[$1366>>2]);
       $1368 = Math_fround(HEAPF32[$1304>>2]);
       $1369 = Math_fround($1367 - $1368);
       $1370 = ((($particlesB) + ($1309<<5)|0) + 24|0);
       $1371 = Math_fround(HEAPF32[$1370>>2]);
       $1372 = Math_fround(HEAPF32[$1305>>2]);
       $1373 = Math_fround($1371 - $1372);
       $1374 = Math_fround($1356 * $1365);
       $1375 = Math_fround($1356 * $1369);
       $1376 = Math_fround($1356 * $1373);
       $1377 = Math_fround($1361 * $1374);
       $1378 = Math_fround($1361 * $1375);
       $1379 = Math_fround($1361 * $1376);
       $1380 = Math_fround($1357 + $1377);
       $1381 = Math_fround($1358 + $1378);
       $1382 = Math_fround($1359 + $1379);
       $1383 = Math_fround(Math_fround(1.0) / $1340);
       $1384 = Math_fround($1380 * $1383);
       $1385 = Math_fround($1383 * $1381);
       $1386 = Math_fround($1383 * $1382);
       $1387 = Math_fround(HEAPF32[$933>>2]);
       $1388 = Math_fround($1384 + $1387);
       HEAPF32[$933>>2] = $1388;
       $1389 = Math_fround(HEAPF32[$1306>>2]);
       $1390 = Math_fround($1385 + $1389);
       HEAPF32[$1306>>2] = $1390;
       $1391 = Math_fround(HEAPF32[$1307>>2]);
       $1392 = Math_fround($1391 + $1386);
       HEAPF32[$1307>>2] = $1392;
      }
      $1393 = (($pB1$05$i44) + 1)|0;
      $exitcond$i46 = ($1393|0)==($numParticlesB|0);
      if ($exitcond$i46) {
       break;
      } else {
       $pB1$05$i44 = $1393;
      }
     }
    }
    $1394 = (($pA$07$i31) + 1)|0;
    $exitcond11$i47 = ($1394|0)==($numParticlesA|0);
    if ($exitcond11$i47) {
     break;
    } else {
     $pA$07$i31 = $1394;
    }
   }
   STACKTOP = sp;return;
  }
 }
 if (!($twoWayUpdate)) {
  if ($9) {
   STACKTOP = sp;return;
  }
  $221 = ($5|0)==(0);
  $222 = ($5>>>0)<($numParticlesB>>>0);
  $params$idx21$i3 = (($params) + 28|0);
  $params$idx22$i4 = (($params) + 32|0);
  $params$idx23$i5 = (($params) + 52|0);
  $pA$07$i7 = 0;
  while(1) {
   $223 = (($particleIndicesA) + ($pA$07$i7<<2)|0);
   $224 = HEAP32[$223>>2]|0;
   $225 = (($particlesA) + ($224<<5)|0);
   if (!($221)) {
    $226 = Math_fround(HEAPF32[$225>>2]);
    $227 = ((($particlesA) + ($224<<5)|0) + 4|0);
    $228 = Math_fround(HEAPF32[$227>>2]);
    $229 = ((($particlesA) + ($224<<5)|0) + 8|0);
    $230 = Math_fround(HEAPF32[$229>>2]);
    $231 = ((($particlesA) + ($224<<5)|0) + 12|0);
    $pB$04$i = 0;
    while(1) {
     $232 = (($particleIndicesB) + ($pB$04$i<<2)|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = $pB$04$i | 1;
     $235 = (($particleIndicesB) + ($234<<2)|0);
     $236 = HEAP32[$235>>2]|0;
     $237 = $pB$04$i | 2;
     $238 = (($particleIndicesB) + ($237<<2)|0);
     $239 = HEAP32[$238>>2]|0;
     $240 = $pB$04$i | 3;
     $241 = (($particleIndicesB) + ($240<<2)|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = (($particlesB) + ($233<<5)|0);
     $244 = Math_fround(HEAPF32[$243>>2]);
     $245 = Math_fround($226 - $244);
     $246 = ((($particlesB) + ($233<<5)|0) + 4|0);
     $247 = Math_fround(HEAPF32[$246>>2]);
     $248 = Math_fround($228 - $247);
     $249 = ((($particlesB) + ($233<<5)|0) + 8|0);
     $250 = Math_fround(HEAPF32[$249>>2]);
     $251 = Math_fround($230 - $250);
     $252 = (($particlesB) + ($236<<5)|0);
     $253 = Math_fround(HEAPF32[$252>>2]);
     $254 = Math_fround($226 - $253);
     $255 = ((($particlesB) + ($236<<5)|0) + 4|0);
     $256 = Math_fround(HEAPF32[$255>>2]);
     $257 = Math_fround($228 - $256);
     $258 = ((($particlesB) + ($236<<5)|0) + 8|0);
     $259 = Math_fround(HEAPF32[$258>>2]);
     $260 = Math_fround($230 - $259);
     $261 = (($particlesB) + ($239<<5)|0);
     $262 = Math_fround(HEAPF32[$261>>2]);
     $263 = Math_fround($226 - $262);
     $264 = ((($particlesB) + ($239<<5)|0) + 4|0);
     $265 = Math_fround(HEAPF32[$264>>2]);
     $266 = Math_fround($228 - $265);
     $267 = ((($particlesB) + ($239<<5)|0) + 8|0);
     $268 = Math_fround(HEAPF32[$267>>2]);
     $269 = Math_fround($230 - $268);
     $270 = (($particlesB) + ($242<<5)|0);
     $271 = Math_fround(HEAPF32[$270>>2]);
     $272 = Math_fround($226 - $271);
     $273 = ((($particlesB) + ($242<<5)|0) + 4|0);
     $274 = Math_fround(HEAPF32[$273>>2]);
     $275 = Math_fround($228 - $274);
     $276 = ((($particlesB) + ($242<<5)|0) + 8|0);
     $277 = Math_fround(HEAPF32[$276>>2]);
     $278 = Math_fround($230 - $277);
     $279 = Math_fround($245 * $245);
     $280 = Math_fround($248 * $248);
     $281 = Math_fround($279 + $280);
     $282 = Math_fround($251 * $251);
     $283 = Math_fround($281 + $282);
     $284 = Math_fround($254 * $254);
     $285 = Math_fround($257 * $257);
     $286 = Math_fround($284 + $285);
     $287 = Math_fround($260 * $260);
     $288 = Math_fround($286 + $287);
     $289 = Math_fround($263 * $263);
     $290 = Math_fround($266 * $266);
     $291 = Math_fround($289 + $290);
     $292 = Math_fround($269 * $269);
     $293 = Math_fround($291 + $292);
     $294 = Math_fround($272 * $272);
     $295 = Math_fround($275 * $275);
     $296 = Math_fround($294 + $295);
     $297 = Math_fround($278 * $278);
     $298 = Math_fround($296 + $297);
     $299 = Math_fround($7 - $283);
     $300 = Math_fround($7 - $288);
     $301 = Math_fround($7 - $293);
     $302 = Math_fround($7 - $298);
     $not$3$i = !($299 >= Math_fround(0.0));
     $not$2$i = !($300 >= Math_fround(0.0));
     $303 = $not$2$i & $not$3$i;
     $not$1$i = !($301 >= Math_fround(0.0));
     $304 = $303 & $not$1$i;
     $not$$i9 = !($302 >= Math_fround(0.0));
     $305 = $304 & $not$$i9;
     if (!($305)) {
      $306 = (HEAPF32[tempDoublePtr>>2]=$283,HEAP32[tempDoublePtr>>2]|0);
      $307 = (HEAPF32[tempDoublePtr>>2]=$288,HEAP32[tempDoublePtr>>2]|0);
      $308 = (HEAPF32[tempDoublePtr>>2]=$293,HEAP32[tempDoublePtr>>2]|0);
      $309 = (HEAPF32[tempDoublePtr>>2]=$298,HEAP32[tempDoublePtr>>2]|0);
      $310 = ($306>>>0)<($8>>>0);
      $311 = ($306|0)!=(0);
      $or$cond$i = $310 & $311;
      if ($or$cond$i) {
       $params$idx$val$i = Math_fround(HEAPF32[$params$idx21$i3>>2]);
       $params$idx10$val$i = Math_fround(HEAPF32[$params$idx22$i4>>2]);
       $params$idx11$val$i = Math_fround(HEAPF32[$params$idx23$i5>>2]);
       $312 = Math_fround($283 * $params$idx11$val$i);
       $313 = Math_fround($params$idx$val$i - $312);
       $314 = Math_fround($params$idx10$val$i * $313);
       $315 = Math_fround($313 * $314);
       $316 = Math_fround($313 * $315);
       $317 = Math_fround(HEAPF32[$231>>2]);
       $318 = Math_fround($317 + $316);
       HEAPF32[$231>>2] = $318;
      }
      $319 = ($307>>>0)<($8>>>0);
      $320 = ($307|0)!=(0);
      $or$cond3$i = $319 & $320;
      if ($or$cond3$i) {
       $params$idx12$val$i = Math_fround(HEAPF32[$params$idx21$i3>>2]);
       $params$idx13$val$i = Math_fround(HEAPF32[$params$idx22$i4>>2]);
       $params$idx14$val$i = Math_fround(HEAPF32[$params$idx23$i5>>2]);
       $321 = Math_fround($288 * $params$idx14$val$i);
       $322 = Math_fround($params$idx12$val$i - $321);
       $323 = Math_fround($params$idx13$val$i * $322);
       $324 = Math_fround($322 * $323);
       $325 = Math_fround($322 * $324);
       $326 = Math_fround(HEAPF32[$231>>2]);
       $327 = Math_fround($326 + $325);
       HEAPF32[$231>>2] = $327;
      }
      $328 = ($308>>>0)<($8>>>0);
      $329 = ($308|0)!=(0);
      $or$cond5$i = $328 & $329;
      if ($or$cond5$i) {
       $params$idx15$val$i = Math_fround(HEAPF32[$params$idx21$i3>>2]);
       $params$idx16$val$i = Math_fround(HEAPF32[$params$idx22$i4>>2]);
       $params$idx17$val$i = Math_fround(HEAPF32[$params$idx23$i5>>2]);
       $330 = Math_fround($293 * $params$idx17$val$i);
       $331 = Math_fround($params$idx15$val$i - $330);
       $332 = Math_fround($params$idx16$val$i * $331);
       $333 = Math_fround($331 * $332);
       $334 = Math_fround($331 * $333);
       $335 = Math_fround(HEAPF32[$231>>2]);
       $336 = Math_fround($335 + $334);
       HEAPF32[$231>>2] = $336;
      }
      $337 = ($309>>>0)<($8>>>0);
      $338 = ($309|0)!=(0);
      $or$cond7$i = $337 & $338;
      if ($or$cond7$i) {
       $params$idx18$val$i = Math_fround(HEAPF32[$params$idx21$i3>>2]);
       $params$idx19$val$i = Math_fround(HEAPF32[$params$idx22$i4>>2]);
       $params$idx20$val$i = Math_fround(HEAPF32[$params$idx23$i5>>2]);
       $339 = Math_fround($298 * $params$idx20$val$i);
       $340 = Math_fround($params$idx18$val$i - $339);
       $341 = Math_fround($params$idx19$val$i * $340);
       $342 = Math_fround($340 * $341);
       $343 = Math_fround($340 * $342);
       $344 = Math_fround(HEAPF32[$231>>2]);
       $345 = Math_fround($344 + $343);
       HEAPF32[$231>>2] = $345;
      }
     }
     $346 = (($pB$04$i) + 4)|0;
     $347 = ($346>>>0)<($5>>>0);
     if ($347) {
      $pB$04$i = $346;
     } else {
      break;
     }
    }
   }
   if ($222) {
    $348 = Math_fround(HEAPF32[$225>>2]);
    $349 = ((($particlesA) + ($224<<5)|0) + 4|0);
    $350 = Math_fround(HEAPF32[$349>>2]);
    $351 = ((($particlesA) + ($224<<5)|0) + 8|0);
    $352 = Math_fround(HEAPF32[$351>>2]);
    $353 = ((($particlesA) + ($224<<5)|0) + 12|0);
    $pB1$05$i12 = $5;
    while(1) {
     $354 = (($particleIndicesB) + ($pB1$05$i12<<2)|0);
     $355 = HEAP32[$354>>2]|0;
     $356 = (($particlesB) + ($355<<5)|0);
     $357 = Math_fround(HEAPF32[$356>>2]);
     $358 = Math_fround($348 - $357);
     $359 = ((($particlesB) + ($355<<5)|0) + 4|0);
     $360 = Math_fround(HEAPF32[$359>>2]);
     $361 = Math_fround($350 - $360);
     $362 = ((($particlesB) + ($355<<5)|0) + 8|0);
     $363 = Math_fround(HEAPF32[$362>>2]);
     $364 = Math_fround($352 - $363);
     $365 = Math_fround($358 * $358);
     $366 = Math_fround($361 * $361);
     $367 = Math_fround($365 + $366);
     $368 = Math_fround($364 * $364);
     $369 = Math_fround($367 + $368);
     $370 = (HEAPF32[tempDoublePtr>>2]=$369,HEAP32[tempDoublePtr>>2]|0);
     $371 = ($370>>>0)<($8>>>0);
     $372 = ($370|0)!=(0);
     $or$cond9$i13 = $371 & $372;
     if ($or$cond9$i13) {
      $params$idx21$val$i14 = Math_fround(HEAPF32[$params$idx21$i3>>2]);
      $params$idx22$val$i15 = Math_fround(HEAPF32[$params$idx22$i4>>2]);
      $params$idx23$val$i16 = Math_fround(HEAPF32[$params$idx23$i5>>2]);
      $373 = Math_fround($369 * $params$idx23$val$i16);
      $374 = Math_fround($params$idx21$val$i14 - $373);
      $375 = Math_fround($params$idx22$val$i15 * $374);
      $376 = Math_fround($374 * $375);
      $377 = Math_fround($374 * $376);
      $378 = Math_fround(HEAPF32[$353>>2]);
      $379 = Math_fround($378 + $377);
      HEAPF32[$353>>2] = $379;
     }
     $380 = (($pB1$05$i12) + 1)|0;
     $exitcond$i17 = ($380|0)==($numParticlesB|0);
     if ($exitcond$i17) {
      break;
     } else {
      $pB1$05$i12 = $380;
     }
    }
   }
   $381 = (($pA$07$i7) + 1)|0;
   $exitcond11$i18 = ($381|0)==($numParticlesA|0);
   if ($exitcond11$i18) {
    break;
   } else {
    $pA$07$i7 = $381;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($5|0)==(0);
 $11 = ($5>>>0)<($numParticlesB>>>0);
 $params$idx21$i = (($params) + 28|0);
 $params$idx22$i = (($params) + 32|0);
 $params$idx23$i = (($params) + 52|0);
 if ($10) {
  $pA$07$i = 0;
  while(1) {
   $181 = (($particleIndicesA) + ($pA$07$i<<2)|0);
   $182 = HEAP32[$181>>2]|0;
   if ($11) {
    $183 = (($particlesA) + ($182<<5)|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    $185 = ((($particlesA) + ($182<<5)|0) + 4|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = ((($particlesA) + ($182<<5)|0) + 8|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = ((($particlesA) + ($182<<5)|0) + 12|0);
    $pB1$05$i = 0;
    while(1) {
     $190 = (($particleIndicesB) + ($pB1$05$i<<2)|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = (($particlesB) + ($191<<5)|0);
     $193 = Math_fround(HEAPF32[$192>>2]);
     $194 = Math_fround($184 - $193);
     $195 = ((($particlesB) + ($191<<5)|0) + 4|0);
     $196 = Math_fround(HEAPF32[$195>>2]);
     $197 = Math_fround($186 - $196);
     $198 = ((($particlesB) + ($191<<5)|0) + 8|0);
     $199 = Math_fround(HEAPF32[$198>>2]);
     $200 = Math_fround($188 - $199);
     $201 = Math_fround($194 * $194);
     $202 = Math_fround($197 * $197);
     $203 = Math_fround($201 + $202);
     $204 = Math_fround($200 * $200);
     $205 = Math_fround($203 + $204);
     $206 = (HEAPF32[tempDoublePtr>>2]=$205,HEAP32[tempDoublePtr>>2]|0);
     $207 = ($206>>>0)<($8>>>0);
     $208 = ($206|0)!=(0);
     $or$cond9$i = $207 & $208;
     if ($or$cond9$i) {
      $params$idx21$val$i = Math_fround(HEAPF32[$params$idx21$i>>2]);
      $params$idx22$val$i = Math_fround(HEAPF32[$params$idx22$i>>2]);
      $params$idx23$val$i = Math_fround(HEAPF32[$params$idx23$i>>2]);
      $209 = Math_fround($205 * $params$idx23$val$i);
      $210 = Math_fround($params$idx21$val$i - $209);
      $211 = Math_fround($params$idx22$val$i * $210);
      $212 = Math_fround($210 * $211);
      $213 = Math_fround($210 * $212);
      $214 = Math_fround(HEAPF32[$189>>2]);
      $215 = Math_fround($214 + $213);
      HEAPF32[$189>>2] = $215;
      $216 = ((($particlesB) + ($191<<5)|0) + 12|0);
      $217 = Math_fround(HEAPF32[$216>>2]);
      $218 = Math_fround($217 + $213);
      HEAPF32[$216>>2] = $218;
     }
     $219 = (($pB1$05$i) + 1)|0;
     $exitcond$i = ($219|0)==($numParticlesB|0);
     if ($exitcond$i) {
      break;
     } else {
      $pB1$05$i = $219;
     }
    }
   }
   $220 = (($pA$07$i) + 1)|0;
   $exitcond11$i = ($220|0)==($numParticlesA|0);
   if ($exitcond11$i) {
    break;
   } else {
    $pA$07$i = $220;
   }
  }
  STACKTOP = sp;return;
 } else {
  $115 = $7;$pA$07$us$i = 0;
 }
 while(1) {
  $176 = (($particleIndicesA) + ($pA$07$us$i<<2)|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($particlesA) + ($177<<5)|0);
  $18 = Math_fround(HEAPF32[$178>>2]);
  $179 = ((($particlesA) + ($177<<5)|0) + 4|0);
  $22 = Math_fround(HEAPF32[$179>>2]);
  $180 = ((($particlesA) + ($177<<5)|0) + 8|0);
  $26 = Math_fround(HEAPF32[$180>>2]);
  $41 = ((($particlesA) + ($177<<5)|0) + 12|0);
  $pB$04$us$i = 0;
  while(1) {
   $47 = (($particleIndicesB) + ($pB$04$us$i<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = $pB$04$us$i | 1;
   $50 = (($particleIndicesB) + ($49<<2)|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = $pB$04$us$i | 2;
   $53 = (($particleIndicesB) + ($52<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = $pB$04$us$i | 3;
   $56 = (($particleIndicesB) + ($55<<2)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($particlesB) + ($48<<5)|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = Math_fround($18 - $59);
   $61 = ((($particlesB) + ($48<<5)|0) + 4|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = Math_fround($22 - $62);
   $64 = ((($particlesB) + ($48<<5)|0) + 8|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = Math_fround($26 - $65);
   $67 = (($particlesB) + ($51<<5)|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = Math_fround($18 - $68);
   $70 = ((($particlesB) + ($51<<5)|0) + 4|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = Math_fround($22 - $71);
   $73 = ((($particlesB) + ($51<<5)|0) + 8|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = Math_fround($26 - $74);
   $76 = (($particlesB) + ($54<<5)|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = Math_fround($18 - $77);
   $79 = ((($particlesB) + ($54<<5)|0) + 4|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = Math_fround($22 - $80);
   $82 = ((($particlesB) + ($54<<5)|0) + 8|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = Math_fround($26 - $83);
   $85 = (($particlesB) + ($57<<5)|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   $87 = Math_fround($18 - $86);
   $88 = ((($particlesB) + ($57<<5)|0) + 4|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = Math_fround($22 - $89);
   $91 = ((($particlesB) + ($57<<5)|0) + 8|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = Math_fround($26 - $92);
   $94 = Math_fround($60 * $60);
   $95 = Math_fround($63 * $63);
   $96 = Math_fround($94 + $95);
   $97 = Math_fround($66 * $66);
   $98 = Math_fround($96 + $97);
   $99 = Math_fround($69 * $69);
   $100 = Math_fround($72 * $72);
   $101 = Math_fround($99 + $100);
   $102 = Math_fround($75 * $75);
   $103 = Math_fround($101 + $102);
   $104 = Math_fround($78 * $78);
   $105 = Math_fround($81 * $81);
   $106 = Math_fround($104 + $105);
   $107 = Math_fround($84 * $84);
   $108 = Math_fround($106 + $107);
   $109 = Math_fround($87 * $87);
   $110 = Math_fround($90 * $90);
   $111 = Math_fround($109 + $110);
   $112 = Math_fround($93 * $93);
   $113 = Math_fround($111 + $112);
   $114 = Math_fround($115 - $98);
   $116 = Math_fround($115 - $103);
   $117 = Math_fround($115 - $108);
   $118 = Math_fround($115 - $113);
   $not$3$us$i = !($114 >= Math_fround(0.0));
   $not$2$us$i = !($116 >= Math_fround(0.0));
   $119 = $not$2$us$i & $not$3$us$i;
   $not$1$us$i = !($117 >= Math_fround(0.0));
   $120 = $119 & $not$1$us$i;
   $not$$us$i = !($118 >= Math_fround(0.0));
   $121 = $120 & $not$$us$i;
   if (!($121)) {
    $122 = (HEAPF32[tempDoublePtr>>2]=$98,HEAP32[tempDoublePtr>>2]|0);
    $123 = (HEAPF32[tempDoublePtr>>2]=$103,HEAP32[tempDoublePtr>>2]|0);
    $124 = (HEAPF32[tempDoublePtr>>2]=$108,HEAP32[tempDoublePtr>>2]|0);
    $125 = (HEAPF32[tempDoublePtr>>2]=$113,HEAP32[tempDoublePtr>>2]|0);
    $126 = ($122>>>0)<($8>>>0);
    $127 = ($122|0)!=(0);
    $or$cond$us$i = $126 & $127;
    if ($or$cond$us$i) {
     $params$idx$val$us$i = Math_fround(HEAPF32[$params$idx21$i>>2]);
     $params$idx10$val$us$i = Math_fround(HEAPF32[$params$idx22$i>>2]);
     $params$idx11$val$us$i = Math_fround(HEAPF32[$params$idx23$i>>2]);
     $128 = Math_fround($98 * $params$idx11$val$us$i);
     $129 = Math_fround($params$idx$val$us$i - $128);
     $130 = Math_fround($params$idx10$val$us$i * $129);
     $131 = Math_fround($129 * $130);
     $132 = Math_fround($129 * $131);
     $133 = Math_fround(HEAPF32[$41>>2]);
     $134 = Math_fround($133 + $132);
     HEAPF32[$41>>2] = $134;
     $135 = ((($particlesB) + ($48<<5)|0) + 12|0);
     $136 = Math_fround(HEAPF32[$135>>2]);
     $137 = Math_fround($136 + $132);
     HEAPF32[$135>>2] = $137;
    }
    $138 = ($123>>>0)<($8>>>0);
    $139 = ($123|0)!=(0);
    $or$cond3$us$i = $138 & $139;
    if ($or$cond3$us$i) {
     $params$idx12$val$us$i = Math_fround(HEAPF32[$params$idx21$i>>2]);
     $params$idx13$val$us$i = Math_fround(HEAPF32[$params$idx22$i>>2]);
     $params$idx14$val$us$i = Math_fround(HEAPF32[$params$idx23$i>>2]);
     $140 = Math_fround($103 * $params$idx14$val$us$i);
     $141 = Math_fround($params$idx12$val$us$i - $140);
     $142 = Math_fround($params$idx13$val$us$i * $141);
     $143 = Math_fround($141 * $142);
     $144 = Math_fround($141 * $143);
     $145 = Math_fround(HEAPF32[$41>>2]);
     $146 = Math_fround($145 + $144);
     HEAPF32[$41>>2] = $146;
     $147 = ((($particlesB) + ($51<<5)|0) + 12|0);
     $148 = Math_fround(HEAPF32[$147>>2]);
     $149 = Math_fround($148 + $144);
     HEAPF32[$147>>2] = $149;
    }
    $150 = ($124>>>0)<($8>>>0);
    $151 = ($124|0)!=(0);
    $or$cond5$us$i = $150 & $151;
    if ($or$cond5$us$i) {
     $params$idx15$val$us$i = Math_fround(HEAPF32[$params$idx21$i>>2]);
     $params$idx16$val$us$i = Math_fround(HEAPF32[$params$idx22$i>>2]);
     $params$idx17$val$us$i = Math_fround(HEAPF32[$params$idx23$i>>2]);
     $152 = Math_fround($108 * $params$idx17$val$us$i);
     $153 = Math_fround($params$idx15$val$us$i - $152);
     $154 = Math_fround($params$idx16$val$us$i * $153);
     $155 = Math_fround($153 * $154);
     $156 = Math_fround($153 * $155);
     $157 = Math_fround(HEAPF32[$41>>2]);
     $158 = Math_fround($157 + $156);
     HEAPF32[$41>>2] = $158;
     $159 = ((($particlesB) + ($54<<5)|0) + 12|0);
     $160 = Math_fround(HEAPF32[$159>>2]);
     $161 = Math_fround($160 + $156);
     HEAPF32[$159>>2] = $161;
    }
    $162 = ($125>>>0)<($8>>>0);
    $163 = ($125|0)!=(0);
    $or$cond7$us$i = $162 & $163;
    if ($or$cond7$us$i) {
     $params$idx18$val$us$i = Math_fround(HEAPF32[$params$idx21$i>>2]);
     $params$idx19$val$us$i = Math_fround(HEAPF32[$params$idx22$i>>2]);
     $params$idx20$val$us$i = Math_fround(HEAPF32[$params$idx23$i>>2]);
     $164 = Math_fround($113 * $params$idx20$val$us$i);
     $165 = Math_fround($params$idx18$val$us$i - $164);
     $166 = Math_fround($params$idx19$val$us$i * $165);
     $167 = Math_fround($165 * $166);
     $168 = Math_fround($165 * $167);
     $169 = Math_fround(HEAPF32[$41>>2]);
     $170 = Math_fround($169 + $168);
     HEAPF32[$41>>2] = $170;
     $171 = ((($particlesB) + ($57<<5)|0) + 12|0);
     $172 = Math_fround(HEAPF32[$171>>2]);
     $173 = Math_fround($172 + $168);
     HEAPF32[$171>>2] = $173;
    }
   }
   $174 = (($pB$04$us$i) + 4)|0;
   $175 = ($174>>>0)<($5>>>0);
   if ($175) {
    $pB$04$us$i = $174;
   } else {
    break;
   }
  }
  if ($11) {
   $pB1$05$us$i = $5;
   while(1) {
    $13 = (($particleIndicesB) + ($pB1$05$us$i<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($particlesB) + ($14<<5)|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = Math_fround($18 - $16);
    $19 = ((($particlesB) + ($14<<5)|0) + 4|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = Math_fround($22 - $20);
    $23 = ((($particlesB) + ($14<<5)|0) + 8|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = Math_fround($26 - $24);
    $27 = Math_fround($17 * $17);
    $28 = Math_fround($21 * $21);
    $29 = Math_fround($27 + $28);
    $30 = Math_fround($25 * $25);
    $31 = Math_fround($29 + $30);
    $32 = (HEAPF32[tempDoublePtr>>2]=$31,HEAP32[tempDoublePtr>>2]|0);
    $33 = ($32>>>0)<($8>>>0);
    $34 = ($32|0)!=(0);
    $or$cond9$us$i = $33 & $34;
    if ($or$cond9$us$i) {
     $params$idx21$val$us$i = Math_fround(HEAPF32[$params$idx21$i>>2]);
     $params$idx22$val$us$i = Math_fround(HEAPF32[$params$idx22$i>>2]);
     $params$idx23$val$us$i = Math_fround(HEAPF32[$params$idx23$i>>2]);
     $35 = Math_fround($31 * $params$idx23$val$us$i);
     $36 = Math_fround($params$idx21$val$us$i - $35);
     $37 = Math_fround($params$idx22$val$us$i * $36);
     $38 = Math_fround($36 * $37);
     $39 = Math_fround($36 * $38);
     $40 = Math_fround(HEAPF32[$41>>2]);
     $42 = Math_fround($40 + $39);
     HEAPF32[$41>>2] = $42;
     $43 = ((($particlesB) + ($14<<5)|0) + 12|0);
     $44 = Math_fround(HEAPF32[$43>>2]);
     $45 = Math_fround($44 + $39);
     HEAPF32[$43>>2] = $45;
    }
    $46 = (($pB1$05$us$i) + 1)|0;
    $exitcond12$i = ($46|0)==($numParticlesB|0);
    if ($exitcond12$i) {
     break;
    } else {
     $pB1$05$us$i = $46;
    }
   }
  }
  $12 = (($pA$07$us$i) + 1)|0;
  $exitcond13$i = ($12|0)==($numParticlesA|0);
  if ($exitcond13$i) {
   break;
  }
  $$pre = Math_fround(HEAPF32[$6>>2]);
  $115 = $$pre;$pA$07$us$i = $12;
 }
 STACKTOP = sp;return;
}
function __ZN5physx24updateCellsSubpacketPairENS_16PxsSphUpdateTypeEPNS_6PxVec3ES2_PNS_16PxsFluidParticleES4_PKNS_15PxsParticleCellES7_PKjS9_jjbRKNS_26PxsFluidDynamicsParametersERNS_27PxsFluidDynamicsTempBuffersEb($updateType,$forceBufA,$forceBufB,$particlesSpA,$particlesSpB,$cellsSpA,$cellsSpB,$particleIndicesSpA,$particleIndicesSpB,$numCellHashBucketsA,$numCellHashBucketsB,$twoWayUpdate,$params,$tempBuffers,$swapAB) {
 $updateType = $updateType|0;
 $forceBufA = $forceBufA|0;
 $forceBufB = $forceBufB|0;
 $particlesSpA = $particlesSpA|0;
 $particlesSpB = $particlesSpB|0;
 $cellsSpA = $cellsSpA|0;
 $cellsSpB = $cellsSpB|0;
 $particleIndicesSpA = $particleIndicesSpA|0;
 $particleIndicesSpB = $particleIndicesSpB|0;
 $numCellHashBucketsA = $numCellHashBucketsA|0;
 $numCellHashBucketsB = $numCellHashBucketsB|0;
 $twoWayUpdate = $twoWayUpdate|0;
 $params = $params|0;
 $tempBuffers = $tempBuffers|0;
 $swapAB = $swapAB|0;
 var $$0$i = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $cellsSpA$cellsSpB = 0;
 var $cellsSpB$cellsSpA = 0, $exitcond = 0, $exitcond12 = 0, $exitcond14 = 0, $i$06 = 0, $indexCount$07 = 0, $indexCount$15 = 0, $indexCount$2 = 0, $n$03 = 0, $n1$08 = 0, $neighborCells = 0, $numCellHashBucketsA$numCellHashBucketsB = 0, $numCellHashBucketsB$numCellHashBucketsA = 0, $particleIndicesSpA$particleIndicesSpB = 0, $pcell$09 = 0, $sext = 0, $sext1 = 0, $sext2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $neighborCells = sp;
 $numCellHashBucketsB$numCellHashBucketsA = $swapAB ? $numCellHashBucketsB : $numCellHashBucketsA;
 $particleIndicesSpA$particleIndicesSpB = $swapAB ? $particleIndicesSpA : $particleIndicesSpB;
 $cellsSpA$cellsSpB = $swapAB ? $cellsSpA : $cellsSpB;
 $cellsSpB$cellsSpA = $swapAB ? $cellsSpB : $cellsSpA;
 $0 = (($cellsSpB$cellsSpA) + ($numCellHashBucketsB$numCellHashBucketsA<<4)|0);
 $1 = ($numCellHashBucketsB$numCellHashBucketsA|0)>(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $numCellHashBucketsA$numCellHashBucketsB = $swapAB ? $numCellHashBucketsA : $numCellHashBucketsB;
 $2 = (($numCellHashBucketsA$numCellHashBucketsB) + -1)|0;
 $3 = (($tempBuffers) + 8|0);
 $4 = ($updateType|0)==(0);
 $5 = (($tempBuffers) + 28|0);
 $6 = (($tempBuffers) + 32|0);
 $pcell$09 = $cellsSpB$cellsSpA;
 while(1) {
  $7 = (($pcell$09) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(-1);
  do {
   if (!($9)) {
    $10 = HEAP16[$pcell$09>>1]|0;
    $11 = (($pcell$09) + 2|0);
    $12 = HEAP16[$11>>1]|0;
    $13 = (($pcell$09) + 4|0);
    $14 = HEAP16[$13>>1]|0;
    $15 = $10&65535;
    $16 = $12&65535;
    $17 = $14&65535;
    $n$03 = 0;
    while(1) {
     $18 = (494384 + (($n$03*6)|0)|0);
     $19 = HEAP16[$18>>1]|0;
     $20 = $19&65535;
     $21 = (($20) + ($15))|0;
     $22 = $21&65535;
     $23 = ((494384 + (($n$03*6)|0)|0) + 2|0);
     $24 = HEAP16[$23>>1]|0;
     $25 = $24&65535;
     $26 = (($25) + ($16))|0;
     $27 = $26&65535;
     $28 = ((494384 + (($n$03*6)|0)|0) + 4|0);
     $29 = HEAP16[$28>>1]|0;
     $30 = $29&65535;
     $31 = (($30) + ($17))|0;
     $32 = $31&65535;
     $sext = $21 << 16;
     $33 = $sext >> 16;
     $sext1 = $26 << 16;
     $34 = $sext1 >> 16;
     $35 = ($34*101)|0;
     $36 = (($35) + ($33))|0;
     $sext2 = $31 << 16;
     $37 = $sext2 >> 16;
     $38 = ($37*7919)|0;
     $39 = (($36) + ($38))|0;
     $40 = $39 & $2;
     $41 = ((($cellsSpA$cellsSpB) + ($40<<4)|0) + 8|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(-1);
     L10: do {
      if ($43) {
       $$0$i = 0;
      } else {
       $$pre$pre = $42;$45 = $40;
       while(1) {
        $44 = (($cellsSpA$cellsSpB) + ($45<<4)|0);
        $46 = HEAP16[$44>>1]|0;
        $47 = ($22<<16>>16)==($46<<16>>16);
        if ($47) {
         $48 = ((($cellsSpA$cellsSpB) + ($45<<4)|0) + 2|0);
         $49 = HEAP16[$48>>1]|0;
         $50 = ($27<<16>>16)==($49<<16>>16);
         if ($50) {
          $51 = ((($cellsSpA$cellsSpB) + ($45<<4)|0) + 4|0);
          $52 = HEAP16[$51>>1]|0;
          $53 = ($32<<16>>16)==($52<<16>>16);
          if ($53) {
           break;
          }
         }
        }
        $54 = (($45) + 1)|0;
        $55 = $54 & $2;
        $56 = ((($cellsSpA$cellsSpB) + ($55<<4)|0) + 8|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(-1);
        if ($58) {
         $$0$i = 0;
         break L10;
        } else {
         $$pre$pre = $57;$45 = $55;
        }
       }
       $59 = ($$pre$pre|0)==(-1);
       if ($59) {
        $$0$i = 0;
       } else {
        $60 = (($cellsSpA$cellsSpB) + ($45<<4)|0);
        $$0$i = $60;
       }
      }
     } while(0);
     $61 = (($neighborCells) + ($n$03<<2)|0);
     HEAP32[$61>>2] = $$0$i;
     $62 = (($n$03) + 1)|0;
     $exitcond = ($62|0)==(27);
     if ($exitcond) {
      $indexCount$07 = 0;$n1$08 = 0;
      break;
     } else {
      $n$03 = $62;
     }
    }
    while(1) {
     $63 = (($neighborCells) + ($n1$08<<2)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)==(0|0);
     if ($65) {
      $indexCount$2 = $indexCount$07;
     } else {
      $66 = (($64) + 12|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($64) + 8|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($69) + ($67))|0;
      $71 = ($67>>>0)<($70>>>0);
      if ($71) {
       $72 = HEAP32[$3>>2]|0;
       $i$06 = $67;$indexCount$15 = $indexCount$07;
       while(1) {
        $73 = (($particleIndicesSpA$particleIndicesSpB) + ($i$06<<2)|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = (($indexCount$15) + 1)|0;
        $76 = (($72) + ($indexCount$15<<2)|0);
        HEAP32[$76>>2] = $74;
        $77 = (($i$06) + 1)|0;
        $exitcond12 = ($77|0)==($70|0);
        if ($exitcond12) {
         break;
        } else {
         $i$06 = $77;$indexCount$15 = $75;
        }
       }
       $78 = (($indexCount$07) + ($69))|0;
       $indexCount$2 = $78;
      } else {
       $indexCount$2 = $indexCount$07;
      }
     }
     $79 = (($n1$08) + 1)|0;
     $exitcond14 = ($79|0)==(27);
     if ($exitcond14) {
      break;
     } else {
      $indexCount$07 = $indexCount$2;$n1$08 = $79;
     }
    }
    $80 = ($indexCount$2|0)==(0);
    if (!($80)) {
     if ($swapAB) {
      $81 = HEAP32[$3>>2]|0;
      $82 = (($pcell$09) + 12|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = (($particleIndicesSpB) + ($83<<2)|0);
      $85 = HEAP32[$7>>2]|0;
      $86 = HEAP32[$5>>2]|0;
      $87 = HEAP32[$6>>2]|0;
      __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($forceBufA,$forceBufB,$particlesSpA,$particlesSpB,$81,$indexCount$2,$84,$85,$twoWayUpdate,$4,$params,$86,$87);
      break;
     } else {
      $88 = (($pcell$09) + 12|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = (($particleIndicesSpA) + ($89<<2)|0);
      $91 = HEAP32[$7>>2]|0;
      $92 = HEAP32[$3>>2]|0;
      $93 = HEAP32[$5>>2]|0;
      $94 = HEAP32[$6>>2]|0;
      __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($forceBufA,$forceBufB,$particlesSpA,$particlesSpB,$90,$91,$92,$indexCount$2,$twoWayUpdate,$4,$params,$93,$94);
      break;
     }
    }
   }
  } while(0);
  $95 = (($pcell$09) + 16|0);
  $96 = ($95>>>0)<($0>>>0);
  if ($96) {
   $pcell$09 = $95;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamicsC2ERNS_20PxsParticleSystemSimE($this,$particleSystem) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $particleSystem;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 96|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 100|0);
 $3 = (($this) + 104|0);
 HEAP16[$3>>1] = -1;
 $4 = (($this) + 106|0);
 HEAP16[$4>>1] = 0;
 $5 = (($this) + 108|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$2>>2] = ((434896 + 8|0));
 $6 = (($this) + 112|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 116|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$2>>2] = ((499008 + 8|0));
 $8 = (($this) + 120|0);
 HEAP32[$8>>2] = $this;
 $9 = (($this) + 124|0);
 HEAP32[$9>>2] = 498680;
 $10 = (($this) + 128|0);
 $11 = (($this) + 132|0);
 HEAP16[$11>>1] = -1;
 $12 = (($this) + 134|0);
 HEAP16[$12>>1] = 0;
 $13 = (($this) + 136|0);
 HEAP32[$13>>2] = 0;
 HEAP32[$10>>2] = ((434896 + 8|0));
 $14 = (($this) + 140|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 144|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$10>>2] = ((498960 + 8|0));
 $16 = (($this) + 148|0);
 HEAP32[$16>>2] = $this;
 $17 = (($this) + 152|0);
 HEAP32[$17>>2] = 498712;
 $18 = (($this) + 164|0);
 HEAP32[$18>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamicsD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 HEAP32[$0>>2] = ((434896 + 8|0));
 $1 = (($this) + 136|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 100|0);
 HEAP32[$2>>2] = ((434896 + 8|0));
 $3 = (($this) + 108|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_10mergeForceEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_12mergeDensityEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamics5clearEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5physx16PxsFluidDynamics17adjustTempBuffersEj($this,0);
  STACKTOP = sp;return;
 }
 $3 = (($1) + -4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (0 - ($4))|0;
 $6 = (($1) + ($5)|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
 }
 HEAP32[$0>>2] = 0;
 __ZN5physx16PxsFluidDynamics17adjustTempBuffersEj($this,0);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamics17adjustTempBuffersEj($this,$count) {
 $this = $this|0;
 $count = $count|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$0$i = 0, $$0$i2 = 0, $$lcssa6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$07 = 0, $i1$05 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 13|0;
 $1 = sp + 12|0;
 $2 = sp + 11|0;
 $3 = sp + 10|0;
 $4 = sp + 9|0;
 $5 = sp + 8|0;
 $6 = sp + 7|0;
 $7 = sp + 6|0;
 $8 = sp + 4|0;
 $9 = sp + 3|0;
 $10 = sp + 2|0;
 $11 = sp + 1|0;
 $12 = sp;
 $13 = sp + 5|0;
 $14 = (($this) + 164|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15>>>0)>($count>>>0);
 if ($16) {
  $i$07 = $count;
  while(1) {
   $18 = ((($this) + (($i$07*44)|0)|0) + 200|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$19);
    HEAP32[$18>>2] = 0;
   }
   $21 = ((($this) + (($i$07*44)|0)|0) + 208|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$22);
    HEAP32[$21>>2] = 0;
   }
   $24 = ((($this) + (($i$07*44)|0)|0) + 176|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$25);
    HEAP32[$24>>2] = 0;
   }
   $27 = ((($this) + (($i$07*44)|0)|0) + 168|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==(0|0);
   if (!($29)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$28);
    HEAP32[$27>>2] = 0;
   }
   $30 = ((($this) + (($i$07*44)|0)|0) + 172|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$31);
    HEAP32[$30>>2] = 0;
   }
   $33 = ((($this) + (($i$07*44)|0)|0) + 188|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$34);
    HEAP32[$33>>2] = 0;
   }
   $36 = ((($this) + (($i$07*44)|0)|0) + 184|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$37);
    HEAP32[$36>>2] = 0;
   }
   $39 = ((($this) + (($i$07*44)|0)|0) + 196|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if (!($41)) {
    $42 = (($40) + -4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (0 - ($43))|0;
    $45 = (($40) + ($44)|0);
    $46 = ($45|0)==(0|0);
    if (!($46)) {
     $47 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($48) + 12|0);
     $50 = HEAP32[$49>>2]|0;
     FUNCTION_TABLE_vii[$50 & 4095]($47,$45);
    }
    HEAP32[$39>>2] = 0;
   }
   $51 = ((($this) + (($i$07*44)|0)|0) + 180|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if (!($53)) {
    $54 = (($52) + -4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (0 - ($55))|0;
    $57 = (($52) + ($56)|0);
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (($60) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     FUNCTION_TABLE_vii[$62 & 4095]($59,$57);
    }
    HEAP32[$51>>2] = 0;
   }
   $63 = (($i$07) + 1)|0;
   $64 = HEAP32[$14>>2]|0;
   $65 = ($63>>>0)<($64>>>0);
   if ($65) {
    $i$07 = $63;
   } else {
    $$lcssa6 = $64;
    break;
   }
  }
 } else {
  $$lcssa6 = $15;
 }
 $17 = ($$lcssa6>>>0)<($count>>>0);
 if ($17) {
  $i1$05 = $$lcssa6;
 } else {
  HEAP32[$14>>2] = $count;
  STACKTOP = sp;return;
 }
 while(1) {
  $66 = ((($this) + (($i1$05*44)|0)|0) + 192|0);
  HEAP32[$66>>2] = 1024;
  $67 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($7,16384,498744,258)|0);
  $68 = ((($this) + (($i1$05*44)|0)|0) + 184|0);
  HEAP32[$68>>2] = $67;
  $69 = HEAP32[$66>>2]|0;
  $70 = $69 << 4;
  $71 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($8,$70,498744,259)|0);
  $72 = ((($this) + (($i1$05*44)|0)|0) + 188|0);
  HEAP32[$72>>2] = $71;
  $73 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($9,2048,498744,262)|0);
  $74 = ((($this) + (($i1$05*44)|0)|0) + 168|0);
  HEAP32[$74>>2] = $73;
  $75 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($10,2048,498744,263)|0);
  $76 = ((($this) + (($i1$05*44)|0)|0) + 172|0);
  HEAP32[$76>>2] = $75;
  $77 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($11,2048,498744,264)|0);
  $78 = ((($this) + (($i1$05*44)|0)|0) + 176|0);
  HEAP32[$78>>2] = $77;
  $79 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($80) + 8|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (__Z15PxGetFoundationv()|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + 24|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (FUNCTION_TABLE_ii[$86 & 4095]($83)|0);
  $$$i$i$i1 = $87 ? 498872 : 498840;
  $88 = (FUNCTION_TABLE_iiiiii[$82 & 255]($79,16403,$$$i$i$i1,498744,265)|0);
  $89 = ($88|0)==(0|0);
  if ($89) {
   $$0$i2 = 0;
  } else {
   $90 = (($88) + 19|0);
   $91 = $90;
   $92 = $91 & -16;
   $93 = $88;
   $94 = (($92) - ($93))|0;
   $95 = $92;
   $96 = (($95) + -4|0);
   HEAP32[$96>>2] = $94;
   $phitmp = $92;
   $$0$i2 = $phitmp;
  }
  $97 = ((($this) + (($i1$05*44)|0)|0) + 180|0);
  HEAP32[$97>>2] = $$0$i2;
  $98 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($12,1024,498744,267)|0);
  $99 = ((($this) + (($i1$05*44)|0)|0) + 208|0);
  HEAP32[$99>>2] = $98;
  $100 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (($101) + 8|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (__Z15PxGetFoundationv()|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($105) + 24|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (FUNCTION_TABLE_ii[$107 & 4095]($104)|0);
  $$$i$i$i = $108 ? 498872 : 498840;
  $109 = (FUNCTION_TABLE_iiiiii[$103 & 255]($100,6211,$$$i$i$i,498744,273)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $$0$i = 0;
  } else {
   $111 = (($109) + 19|0);
   $112 = $111;
   $113 = $112 & -16;
   $114 = $113;
   $115 = $109;
   $116 = (($113) - ($115))|0;
   $117 = $113;
   $118 = (($117) + -4|0);
   HEAP32[$118>>2] = $116;
   $$0$i = $114;
  }
  $119 = ((($this) + (($i1$05*44)|0)|0) + 196|0);
  HEAP32[$119>>2] = $$0$i;
  $120 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($13,512,498744,275)|0);
  $121 = ((($this) + (($i1$05*44)|0)|0) + 200|0);
  HEAP32[$121>>2] = $120;
  $122 = ((($this) + (($i1$05*44)|0)|0) + 204|0);
  HEAP32[$122>>2] = 496632;
  $123 = (($i1$05) + 1)|0;
  $exitcond = ($123|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i1$05 = $123;
  }
 }
 HEAP32[$14>>2] = $count;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamics9updateSphERNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $$ = 0, $$$i$i$i = 0, $$$i$i$i1 = 0, $$0$i = 0, $$0$i2 = 0, $$targetParticleCountPerTask$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0;
 var $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $currentParticleCount$06 = 0, $exitcond = 0, $exitcond16 = 0, $i$012 = 0, $i2$011 = 0, $numTasks$010 = 0, $numTasks$1 = 0, $or$cond = 0;
 var $or$cond4 = 0, $packetIndex$09 = 0, $packetIndex$1$lcssa18 = 0, $packetIndex$1$lcssa19 = 0, $packetIndex$15 = 0, $phitmp = 0, $phitmp14 = 0, $targetParticleCountPerTask$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($0) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 72|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (($2) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16 << 5;
  $18 = $17 | 19;
  $19 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (__Z15PxGetFoundationv()|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (FUNCTION_TABLE_ii[$26 & 4095]($23)|0);
  $$$i$i$i = $27 ? 498872 : 498840;
  $28 = (FUNCTION_TABLE_iiiiii[$22 & 255]($19,$18,$$$i$i$i,498744,315)|0);
  $29 = ($28|0)==(0|0);
  if ($29) {
   $$0$i = 0;
  } else {
   $30 = (($28) + 19|0);
   $31 = $30;
   $32 = $31 & -16;
   $33 = $28;
   $34 = (($32) - ($33))|0;
   $35 = $32;
   $36 = (($35) + -4|0);
   HEAP32[$36>>2] = $34;
   $phitmp = $32;
   $$0$i = $phitmp;
  }
  HEAP32[$12>>2] = $$0$i;
 }
 $37 = (($this) + 96|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $40 = HEAP32[$this>>2]|0;
  $41 = (($40) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44*12)|0;
  $46 = (($45) + 4)|0;
  $47 = (($45) + 23)|0;
  $48 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 8|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (__Z15PxGetFoundationv()|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 24|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (FUNCTION_TABLE_ii[$55 & 4095]($52)|0);
  $$$i$i$i1 = $56 ? 498872 : 498840;
  $57 = (FUNCTION_TABLE_iiiiii[$51 & 255]($48,$47,$$$i$i$i1,498744,326)|0);
  $58 = ($57|0)==(0|0);
  if ($58) {
   $$0$i2 = 0;
  } else {
   $59 = (($57) + 19|0);
   $60 = $59;
   $61 = $60 & -16;
   $62 = $61;
   $63 = $57;
   $64 = (($61) - ($63))|0;
   $65 = $61;
   $66 = (($65) + -4|0);
   HEAP32[$66>>2] = $64;
   $$0$i2 = $62;
  }
  HEAP32[$37>>2] = $$0$i2;
  _memset(($$0$i2|0),0,($46|0))|0;
 }
 $67 = ($6|0)==(0);
 if (!($67)) {
  $i$012 = 0;
  while(1) {
   $68 = (($8) + ($i$012<<2)|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = HEAP32[$12>>2]|0;
   $71 = (($4) + ($69<<5)|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = (($70) + ($i$012<<5)|0);
   HEAPF32[$73>>2] = $72;
   $74 = ((($4) + ($69<<5)|0) + 4|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = ((($70) + ($i$012<<5)|0) + 4|0);
   HEAPF32[$76>>2] = $75;
   $77 = ((($4) + ($69<<5)|0) + 8|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = ((($70) + ($i$012<<5)|0) + 8|0);
   HEAPF32[$79>>2] = $78;
   $80 = ((($4) + ($69<<5)|0) + 12|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   $82 = ((($70) + ($i$012<<5)|0) + 12|0);
   HEAPF32[$82>>2] = $81;
   $83 = ((($4) + ($69<<5)|0) + 16|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   $85 = ((($70) + ($i$012<<5)|0) + 16|0);
   HEAPF32[$85>>2] = $84;
   $86 = ((($4) + ($69<<5)|0) + 20|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = ((($70) + ($i$012<<5)|0) + 20|0);
   HEAPF32[$88>>2] = $87;
   $89 = ((($4) + ($69<<5)|0) + 24|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = ((($70) + ($i$012<<5)|0) + 24|0);
   HEAPF32[$91>>2] = $90;
   $92 = ((($70) + ($i$012<<5)|0) + 28|0);
   $93 = ((($4) + ($69<<5)|0) + 28|0);
   $94 = HEAPU16[$93>>1]|(HEAPU16[$93+2>>1]<<16);
   HEAP16[$92>>1]=$94&65535;HEAP16[$92+2>>1]=$94>>>16;
   $95 = (($i$012) + 1)|0;
   $exitcond16 = ($95|0)==($6|0);
   if ($exitcond16) {
    break;
   } else {
    $i$012 = $95;
   }
  }
 }
 $96 = $6 >>> 3;
 $97 = ($96>>>0)<(512);
 $98 = $97 ? 512 : $96;
 $i2$011 = 0;$numTasks$010 = 0;$packetIndex$09 = 0;$targetParticleCountPerTask$08 = $98;
 while(1) {
  $99 = ($i2$011|0)==(7);
  $$targetParticleCountPerTask$0 = $99 ? -1 : $targetParticleCountPerTask$08;
  $100 = ($$targetParticleCountPerTask$0|0)!=(0);
  $101 = ($packetIndex$09&65535)<(1024);
  $or$cond4 = $100 & $101;
  if ($or$cond4) {
   $currentParticleCount$06 = 0;$packetIndex$15 = $packetIndex$09;
   while(1) {
    $103 = $packetIndex$15&65535;
    $104 = ((($11) + ($103<<4)|0) + 8|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($105|0)==(-1);
    $$ = $106 ? 0 : $105;
    $107 = (($$) + ($currentParticleCount$06))|0;
    $108 = (($packetIndex$15) + 1)<<16>>16;
    $109 = ($107>>>0)<($$targetParticleCountPerTask$0>>>0);
    $110 = ($108&65535)<(1024);
    $or$cond = $109 & $110;
    if ($or$cond) {
     $currentParticleCount$06 = $107;$packetIndex$15 = $108;
    } else {
     break;
    }
   }
   $phitmp14 = ($107|0)==(0);
   $111 = ((($this) + ($i2$011<<2)|0) + 520|0);
   if ($phitmp14) {
    $114 = $111;$packetIndex$1$lcssa19 = $108;
    label = 17;
   } else {
    HEAP16[$111>>1] = $packetIndex$09;
    $112 = ((($this) + ($i2$011<<2)|0) + 522|0);
    HEAP16[$112>>1] = $108;
    $113 = (($numTasks$010) + 1)|0;
    $numTasks$1 = $113;$packetIndex$1$lcssa18 = $108;
   }
  } else {
   $102 = ((($this) + ($i2$011<<2)|0) + 520|0);
   $114 = $102;$packetIndex$1$lcssa19 = $packetIndex$09;
   label = 17;
  }
  if ((label|0) == 17) {
   label = 0;
   HEAP16[$114>>1] = -1;
   $115 = ((($this) + ($i2$011<<2)|0) + 522|0);
   HEAP16[$115>>1] = -1;
   $numTasks$1 = $numTasks$010;$packetIndex$1$lcssa18 = $packetIndex$1$lcssa19;
  }
  $116 = (($i2$011) + 1)|0;
  $exitcond = ($116|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i2$011 = $116;$numTasks$010 = $numTasks$1;$packetIndex$09 = $packetIndex$1$lcssa18;$targetParticleCountPerTask$08 = $$targetParticleCountPerTask$0;
  }
 }
 $117 = (($this) + 156|0);
 HEAP32[$117>>2] = $numTasks$1;
 $118 = (($this) + 164|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = ($numTasks$1>>>0)<($119>>>0);
 $121 = $120 ? $119 : $numTasks$1;
 __ZN5physx16PxsFluidDynamics17adjustTempBuffersEj($this,$121);
 $122 = (($this) + 144|0);
 HEAP32[$122>>2] = 1;
 $123 = (($this) + 140|0);
 HEAP32[$123>>2] = $continuation;
 $124 = ($continuation|0)==(0|0);
 if ($124) {
  $132 = (($this) + 100|0);
  $133 = (($this) + 128|0);
  $134 = (($this) + 116|0);
  HEAP32[$134>>2] = 1;
  $135 = (($this) + 112|0);
  HEAP32[$135>>2] = $133;
  $136 = HEAP32[$133>>2]|0;
  $137 = (($136) + 16|0);
  $138 = HEAP32[$137>>2]|0;
  FUNCTION_TABLE_vi[$138 & 4095]($133);
  $139 = HEAP32[$135>>2]|0;
  $140 = (($139) + 8|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = (($this) + 108|0);
  HEAP32[$142>>2] = $141;
  __ZN5physx16PxsFluidDynamics15schedulePacketsENS_16PxsSphUpdateTypeERNS_10PxBaseTaskE($this,0,$132);
  $143 = HEAP32[$132>>2]|0;
  $144 = (($143) + 20|0);
  $145 = HEAP32[$144>>2]|0;
  FUNCTION_TABLE_vi[$145 & 4095]($132);
  STACKTOP = sp;return;
 }
 $125 = HEAP32[$continuation>>2]|0;
 $126 = (($125) + 16|0);
 $127 = HEAP32[$126>>2]|0;
 FUNCTION_TABLE_vi[$127 & 4095]($continuation);
 $128 = HEAP32[$123>>2]|0;
 $129 = (($128) + 8|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (($this) + 136|0);
 HEAP32[$131>>2] = $130;
 $132 = (($this) + 100|0);
 $133 = (($this) + 128|0);
 $134 = (($this) + 116|0);
 HEAP32[$134>>2] = 1;
 $135 = (($this) + 112|0);
 HEAP32[$135>>2] = $133;
 $136 = HEAP32[$133>>2]|0;
 $137 = (($136) + 16|0);
 $138 = HEAP32[$137>>2]|0;
 FUNCTION_TABLE_vi[$138 & 4095]($133);
 $139 = HEAP32[$135>>2]|0;
 $140 = (($139) + 8|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (($this) + 108|0);
 HEAP32[$142>>2] = $141;
 __ZN5physx16PxsFluidDynamics15schedulePacketsENS_16PxsSphUpdateTypeERNS_10PxBaseTaskE($this,0,$132);
 $143 = HEAP32[$132>>2]|0;
 $144 = (($143) + 20|0);
 $145 = HEAP32[$144>>2]|0;
 FUNCTION_TABLE_vi[$145 & 4095]($132);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamics15schedulePacketsENS_16PxsSphUpdateTypeERNS_10PxBaseTaskE($this,$updateType,$continuation) {
 $this = $this|0;
 $updateType = $updateType|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 HEAP32[$0>>2] = $updateType;
 $1 = (($this) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($continuation|0)==(0|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$this>>2]|0;
  $6 = (($5) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 6732|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($10);
  $11 = (__ZN5physx2Cm9FlushPool21allocateNotThreadSafeEjj($9,28,16)|0);
  $12 = HEAP32[$9>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($12);
  $13 = ($11|0)==(0|0);
  if ($13) {
   $22 = 0;
  } else {
   $14 = (($11) + 4|0);
   HEAP16[$14>>1] = -1;
   $15 = (($11) + 6|0);
   HEAP16[$15>>1] = 0;
   $16 = (($11) + 8|0);
   HEAP32[$16>>2] = 0;
   HEAP32[$11>>2] = ((434896 + 8|0));
   $17 = (($11) + 12|0);
   HEAP32[$17>>2] = 0;
   $18 = (($11) + 16|0);
   HEAP32[$18>>2] = 0;
   HEAP32[$11>>2] = ((499056 + 8|0));
   $19 = (($11) + 20|0);
   HEAP32[$19>>2] = $this;
   $20 = (($11) + 24|0);
   HEAP32[$20>>2] = $i$01;
   $22 = $11;
  }
  $21 = (($22) + 16|0);
  HEAP32[$21>>2] = 1;
  $23 = (($22) + 12|0);
  HEAP32[$23>>2] = $continuation;
  if (!($4)) {
   $24 = HEAP32[$continuation>>2]|0;
   $25 = (($24) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vi[$26 & 4095]($continuation);
   $27 = HEAP32[$23>>2]|0;
   $28 = (($27) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($22) + 8|0);
   HEAP32[$30>>2] = $29;
  }
  $31 = HEAP32[$22>>2]|0;
  $32 = (($31) + 20|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_vi[$33 & 4095]($22);
  $34 = (($i$01) + 1)|0;
  $35 = HEAP32[$1>>2]|0;
  $36 = ($34>>>0)<($35>>>0);
  if ($36) {
   $i$01 = $34;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamics10mergeForceEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($1) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($3|0)==(0);
 if ($12) {
  $$phi$trans$insert = (($this) + 96|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $62 = $$pre;
 } else {
  $13 = (($this) + 4|0);
  $14 = (($this) + 16|0);
  $15 = (($this) + 76|0);
  $16 = (($this) + 96|0);
  $i$01 = 0;
  while(1) {
   $17 = (($11) + ($i$01<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$13>>2]|0;
   $20 = Math_fround(HEAPF32[$14>>2]);
   $21 = Math_fround(HEAPF32[$15>>2]);
   $22 = ((($19) + ($i$01<<5)|0) + 12|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($23 - $20);
   $25 = Math_fround($21 * $24);
   HEAPF32[$22>>2] = $25;
   $26 = (($19) + ($i$01<<5)|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = (($7) + ($18<<5)|0);
   HEAPF32[$28>>2] = $27;
   $29 = ((($19) + ($i$01<<5)|0) + 4|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = ((($7) + ($18<<5)|0) + 4|0);
   HEAPF32[$31>>2] = $30;
   $32 = ((($19) + ($i$01<<5)|0) + 8|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = ((($7) + ($18<<5)|0) + 8|0);
   HEAPF32[$34>>2] = $33;
   $35 = Math_fround(HEAPF32[$22>>2]);
   $36 = ((($7) + ($18<<5)|0) + 12|0);
   HEAPF32[$36>>2] = $35;
   $37 = ((($19) + ($i$01<<5)|0) + 16|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = ((($7) + ($18<<5)|0) + 16|0);
   HEAPF32[$39>>2] = $38;
   $40 = ((($19) + ($i$01<<5)|0) + 20|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = ((($7) + ($18<<5)|0) + 20|0);
   HEAPF32[$42>>2] = $41;
   $43 = ((($19) + ($i$01<<5)|0) + 24|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = ((($7) + ($18<<5)|0) + 24|0);
   HEAPF32[$45>>2] = $44;
   $46 = ((($7) + ($18<<5)|0) + 28|0);
   $47 = ((($19) + ($i$01<<5)|0) + 28|0);
   $48 = HEAPU16[$47>>1]|(HEAPU16[$47+2>>1]<<16);
   HEAP16[$46>>1]=$48&65535;HEAP16[$46+2>>1]=$48>>>16;
   $49 = HEAP32[$16>>2]|0;
   $50 = (($49) + (($i$01*12)|0)|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = (($9) + (($18*12)|0)|0);
   HEAPF32[$52>>2] = $51;
   $53 = ((($49) + (($i$01*12)|0)|0) + 4|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = ((($9) + (($18*12)|0)|0) + 4|0);
   HEAPF32[$55>>2] = $54;
   $56 = ((($49) + (($i$01*12)|0)|0) + 8|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = ((($9) + (($18*12)|0)|0) + 8|0);
   HEAPF32[$58>>2] = $57;
   $59 = (($i$01) + 1)|0;
   $exitcond = ($59|0)==($3|0);
   if ($exitcond) {
    $62 = $49;
    break;
   } else {
    $i$01 = $59;
   }
  }
 }
 $60 = (($this) + 96|0);
 $61 = ($62|0)==(0|0);
 if ($61) {
  HEAP32[$60>>2] = 0;
  STACKTOP = sp;return;
 }
 $63 = (($62) + -4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (0 - ($64))|0;
 $66 = (($62) + ($65)|0);
 $67 = ($66|0)==(0|0);
 if ($67) {
  HEAP32[$60>>2] = 0;
  STACKTOP = sp;return;
 }
 $68 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 12|0);
 $71 = HEAP32[$70>>2]|0;
 FUNCTION_TABLE_vii[$71 & 4095]($68,$66);
 HEAP32[$60>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamics12updatePacketENS_16PxsSphUpdateTypeEPNS_6PxVec3EPNS_16PxsFluidParticleERKNS_15PxsParticleCellERKNS_22PxsFluidPacketSectionsERKNS_25PxsFluidPacketHaloRegionsERNS_27PxsFluidDynamicsTempBuffersE($this,$updateType,$forceBuf,$particles,$packet,$packetSections,$haloRegions,$tempBuffers) {
 $this = $this|0;
 $updateType = $updateType|0;
 $forceBuf = $forceBuf|0;
 $particles = $particles|0;
 $packet = $packet|0;
 $packetSections = $packetSections|0;
 $haloRegions = $haloRegions|0;
 $tempBuffers = $tempBuffers|0;
 var $$sum = 0, $$sum5 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i4 = 0, $i$01$i = 0;
 var $i$01$i3 = 0, $or$cond$i = 0, $or$cond$i1 = 0, $p$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($packet) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($packet) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 16|0);
 $5 = ($updateType|0)!=(0);
 $6 = ($3|0)==(0);
 $or$cond$i = $5 | $6;
 if (!($or$cond$i)) {
  $i$01$i = 0;
  while(1) {
   $7 = Math_fround(HEAPF32[$4>>2]);
   $$sum5 = (($i$01$i) + ($1))|0;
   $8 = ((($particles) + ($$sum5<<5)|0) + 12|0);
   HEAPF32[$8>>2] = $7;
   $9 = (($forceBuf) + (($$sum5*12)|0)|0);
   HEAPF32[$9>>2] = Math_fround(0.0);
   $10 = ((($forceBuf) + (($$sum5*12)|0)|0) + 4|0);
   HEAPF32[$10>>2] = Math_fround(0.0);
   $11 = ((($forceBuf) + (($$sum5*12)|0)|0) + 8|0);
   HEAPF32[$11>>2] = Math_fround(0.0);
   $12 = (($i$01$i) + 1)|0;
   $exitcond$i = ($12|0)==($3|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $12;
   }
  }
 }
 $13 = ($3>>>0)<(101);
 if ($13) {
  $14 = (($haloRegions) + 784|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15>>>0)<(101);
  if ($16) {
   $17 = (($particles) + ($1<<5)|0);
   $18 = (($forceBuf) + (($1*12)|0)|0);
   $19 = ($3>>>0)>(1);
   if ($19) {
    $20 = (($tempBuffers) + 36|0);
    $21 = ($updateType|0)==(0);
    $22 = (($tempBuffers) + 28|0);
    $23 = (($tempBuffers) + 32|0);
    $28 = $3;$p$013 = 1;
    while(1) {
     $24 = HEAP32[$20>>2]|0;
     $25 = (($24) + ($p$013<<2)|0);
     $$sum = (($p$013) + -1)|0;
     $26 = (($24) + ($$sum<<2)|0);
     $27 = (($28) - ($p$013))|0;
     $29 = HEAP32[$22>>2]|0;
     $30 = HEAP32[$23>>2]|0;
     __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($18,$18,$17,$17,$26,1,$25,$27,1,$21,$4,$29,$30);
     $31 = (($p$013) + 1)|0;
     $32 = HEAP32[$2>>2]|0;
     $33 = ($31>>>0)<($32>>>0);
     if ($33) {
      $28 = $32;$p$013 = $31;
     } else {
      break;
     }
    }
   }
   __ZN5physx16PxsFluidDynamics29updateParticlesBruteForceHaloENS_16PxsSphUpdateTypeEPNS_6PxVec3EPNS_16PxsFluidParticleERKNS_22PxsFluidPacketSectionsERKNS_25PxsFluidPacketHaloRegionsERNS_27PxsFluidDynamicsTempBuffersE($this,$updateType,$forceBuf,$particles,$packetSections,$haloRegions,$tempBuffers);
  } else {
   label = 10;
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  __ZN5physx16PxsFluidDynamics21updatePacketLocalHashENS_16PxsSphUpdateTypeEPNS_6PxVec3EPNS_16PxsFluidParticleERKNS_15PxsParticleCellERKNS_22PxsFluidPacketSectionsERKNS_25PxsFluidPacketHaloRegionsERNS_27PxsFluidDynamicsTempBuffersE($this,$updateType,$forceBuf,$particles,$packet,$packetSections,$haloRegions,$tempBuffers);
 }
 $34 = HEAP32[$0>>2]|0;
 $35 = HEAP32[$2>>2]|0;
 $36 = ($updateType|0)!=(1);
 $37 = ($35|0)==(0);
 $or$cond$i1 = $36 | $37;
 if ($or$cond$i1) {
  STACKTOP = sp;return;
 }
 $38 = (($this) + 72|0);
 $i$01$i3 = 0;
 while(1) {
  $39 = Math_fround(HEAPF32[$38>>2]);
  $$sum9 = (($i$01$i3) + ($34))|0;
  $40 = ((($particles) + ($$sum9<<5)|0) + 12|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround(Math_fround(1.0) / $41);
  $43 = Math_fround($39 * $42);
  $44 = (($forceBuf) + (($$sum9*12)|0)|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($45 * $43);
  HEAPF32[$44>>2] = $46;
  $47 = ((($forceBuf) + (($$sum9*12)|0)|0) + 4|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($43 * $48);
  HEAPF32[$47>>2] = $49;
  $50 = ((($forceBuf) + (($$sum9*12)|0)|0) + 8|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($43 * $51);
  HEAPF32[$50>>2] = $52;
  $53 = (($i$01$i3) + 1)|0;
  $exitcond$i4 = ($53|0)==($35|0);
  if ($exitcond$i4) {
   break;
  } else {
   $i$01$i3 = $53;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamics29updateParticlesBruteForceHaloENS_16PxsSphUpdateTypeEPNS_6PxVec3EPNS_16PxsFluidParticleERKNS_22PxsFluidPacketSectionsERKNS_25PxsFluidPacketHaloRegionsERNS_27PxsFluidDynamicsTempBuffersE($this,$updateType,$forceBuf,$particles,$packetSections,$haloRegions,$tempBuffers) {
 $this = $this|0;
 $updateType = $updateType|0;
 $forceBuf = $forceBuf|0;
 $particles = $particles|0;
 $packetSections = $packetSections|0;
 $haloRegions = $haloRegions|0;
 $tempBuffers = $tempBuffers|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond11 = 0, $hpIndex$02 = 0, $i$08 = 0, $j$05 = 0, $k$03 = 0, $mergedIndexCount$04 = 0, $mergedIndexCount$1 = 0, $mergedIndexCount$21 = 0, $mergedIndexCount$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($tempBuffers) + 36|0);
 $1 = (($tempBuffers) + 8|0);
 $2 = ($updateType|0)==(0);
 $3 = (($this) + 16|0);
 $4 = (($tempBuffers) + 28|0);
 $5 = (($tempBuffers) + 32|0);
 $i$08 = 0;
 while(1) {
  $6 = (($packetSections) + ($i$08<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = ((($packetSections) + ($i$08<<2)|0) + 108|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($particles) + ($10<<5)|0);
   $12 = (($forceBuf) + (($10*12)|0)|0);
   $13 = (494552 + (($i$08*80)|0)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0);
   if (!($15)) {
    $j$05 = 0;$mergedIndexCount$04 = 0;
    while(1) {
     $16 = (((494552 + (($i$08*80)|0)|0) + ($j$05<<2)|0) + 4|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($haloRegions) + ($17<<2)|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)==(0);
     if ($20) {
      $mergedIndexCount$3 = $mergedIndexCount$04;
     } else {
      $21 = (($19) + ($mergedIndexCount$04))|0;
      $22 = ($21>>>0)>(512);
      if ($22) {
       $23 = HEAP32[$0>>2]|0;
       $24 = HEAP32[$6>>2]|0;
       $25 = HEAP32[$1>>2]|0;
       $26 = HEAP32[$4>>2]|0;
       $27 = HEAP32[$5>>2]|0;
       __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($12,$forceBuf,$11,$particles,$23,$24,$25,$mergedIndexCount$04,0,$2,$3,$26,$27);
       $$pre = HEAP32[$18>>2]|0;
       $29 = $$pre;$mergedIndexCount$1 = 0;
      } else {
       $29 = $19;$mergedIndexCount$1 = $mergedIndexCount$04;
      }
      $28 = ($29|0)==(0);
      if ($28) {
       $mergedIndexCount$3 = $mergedIndexCount$1;
      } else {
       $30 = ((($haloRegions) + ($17<<2)|0) + 392|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = HEAP32[$1>>2]|0;
       $hpIndex$02 = $31;$k$03 = 0;$mergedIndexCount$21 = $mergedIndexCount$1;
       while(1) {
        $33 = (($hpIndex$02) + 1)|0;
        $34 = (($mergedIndexCount$21) + 1)|0;
        $35 = (($32) + ($mergedIndexCount$21<<2)|0);
        HEAP32[$35>>2] = $hpIndex$02;
        $36 = (($k$03) + 1)|0;
        $37 = HEAP32[$18>>2]|0;
        $38 = ($36>>>0)<($37>>>0);
        if ($38) {
         $hpIndex$02 = $33;$k$03 = $36;$mergedIndexCount$21 = $34;
        } else {
         $mergedIndexCount$3 = $34;
         break;
        }
       }
      }
     }
     $39 = (($j$05) + 1)|0;
     $exitcond = ($39|0)==($14|0);
     if ($exitcond) {
      break;
     } else {
      $j$05 = $39;$mergedIndexCount$04 = $mergedIndexCount$3;
     }
    }
    $40 = ($mergedIndexCount$3|0)==(0);
    if (!($40)) {
     $41 = HEAP32[$0>>2]|0;
     $42 = HEAP32[$6>>2]|0;
     $43 = HEAP32[$1>>2]|0;
     $44 = HEAP32[$4>>2]|0;
     $45 = HEAP32[$5>>2]|0;
     __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($12,$forceBuf,$11,$particles,$41,$42,$43,$mergedIndexCount$3,0,$2,$3,$44,$45);
    }
   }
  }
  $46 = (($i$08) + 1)|0;
  $exitcond11 = ($46|0)==(26);
  if ($exitcond11) {
   break;
  } else {
   $i$08 = $46;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxsFluidDynamics21updatePacketLocalHashENS_16PxsSphUpdateTypeEPNS_6PxVec3EPNS_16PxsFluidParticleERKNS_15PxsParticleCellERKNS_22PxsFluidPacketSectionsERKNS_25PxsFluidPacketHaloRegionsERNS_27PxsFluidDynamicsTempBuffersE($this,$updateType,$forceBuf,$particles,$packet,$packetSections,$haloRegions,$tempBuffers) {
 $this = $this|0;
 $updateType = $updateType|0;
 $forceBuf = $forceBuf|0;
 $particles = $particles|0;
 $packet = $packet|0;
 $packetSections = $packetSections|0;
 $haloRegions = $haloRegions|0;
 $tempBuffers = $tempBuffers|0;
 var $$not5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$not = 0, $exitcond = 0, $exitcond43 = 0, $exitcond44 = 0, $exitcond45 = 0, $forceBufA$022 = 0, $forceBufA0$037 = 0, $forceBufB$032 = 0, $h$010 = 0;
 var $h7$018 = 0, $hpIndex$014 = 0, $isLocalHashValid$0$off09 = 0, $isLocalHashValid$2$off0 = 0, $k$015 = 0, $mergedIndexCount$017 = 0, $mergedIndexCount$1 = 0, $mergedIndexCount$213 = 0, $mergedIndexCount$3 = 0, $or$cond = 0, $or$cond4 = 0, $packetCorner = 0, $particlesLeftA$024 = 0, $particlesLeftA0$039 = 0, $particlesLeftB$034 = 0, $particlesLeftB3$06 = 0, $particlesSpA$023 = 0, $particlesSpA0$038 = 0, $particlesSpB$033 = 0, $particlesSpB4$07 = 0;
 var $s$028 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $packetCorner = sp;
 $0 = HEAP32[$tempBuffers>>2]|0;
 $1 = (($tempBuffers) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($tempBuffers) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($tempBuffers) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP16[$packet>>1]|0;
 $8 = (Math_fround(($7<<16>>16)));
 $9 = (($packet) + 2|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = (Math_fround(($10<<16>>16)));
 $12 = (($packet) + 4|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = (Math_fround(($13<<16>>16)));
 $15 = (($this) + 16|0);
 $16 = (($this) + 36|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($8 * $17);
 $19 = Math_fround($11 * $17);
 $20 = Math_fround($14 * $17);
 HEAPF32[$packetCorner>>2] = $18;
 $21 = (($packetCorner) + 4|0);
 HEAPF32[$21>>2] = $19;
 $22 = (($packetCorner) + 8|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($packet) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($packet) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24|0)==(0);
 L1: do {
  if (!($27)) {
   $28 = (($forceBuf) + (($26*12)|0)|0);
   $29 = (($particles) + ($26<<5)|0);
   $30 = (($tempBuffers) + 40|0);
   $31 = (($this) + 28|0);
   $forceBufA0$037 = $28;$particlesLeftA0$039 = $24;$particlesSpA0$038 = $29;
   while(1) {
    $32 = ($particlesLeftA0$039>>>0)<(512);
    $33 = $32 ? $particlesLeftA0$039 : 512;
    $34 = (($33) + 1)|0;
    $35 = $34 >>> 1;
    $36 = $35 | $34;
    $37 = $36 >>> 2;
    $38 = $37 | $36;
    $39 = $38 >>> 4;
    $40 = $39 | $38;
    $41 = $40 >>> 8;
    $42 = $41 | $40;
    $43 = $42 >>> 16;
    $44 = $43 | $42;
    $45 = (($44) + 1)|0;
    $46 = HEAP32[$30>>2]|0;
    $47 = Math_fround(HEAPF32[$31>>2]);
    __ZN5physx19PxsFluidSpatialHash14buildLocalHashEPKNS_16PxsFluidParticleEjPNS_15PxsParticleCellEPjPtjfRKNS_6PxVec3E($particlesSpA0$038,$33,$4,$0,$46,$45,$47,$packetCorner);
    __ZN5physx20updateCellsSubpacketENS_16PxsSphUpdateTypeEPNS_6PxVec3EPNS_16PxsFluidParticleEPKNS_15PxsParticleCellEPKjjRKNS_26PxsFluidDynamicsParametersERNS_27PxsFluidDynamicsTempBuffersE($updateType,$forceBufA0$037,$particlesSpA0$038,$4,$0,$45,$15,$tempBuffers);
    $48 = (($particlesLeftA0$039) - ($33))|0;
    $49 = (($particlesSpA0$038) + ($33<<5)|0);
    $50 = (($forceBufA0$037) + (($33*12)|0)|0);
    $51 = ($particlesLeftA0$039|0)==($33|0);
    if ($51) {
     break L1;
    } else {
     $forceBufB$032 = $50;$particlesLeftB$034 = $48;$particlesSpB$033 = $49;
    }
    while(1) {
     $52 = ($particlesLeftB$034>>>0)<(512);
     $53 = $52 ? $particlesLeftB$034 : 512;
     $54 = (($53) + 1)|0;
     $55 = $54 >>> 1;
     $56 = $55 | $54;
     $57 = $56 >>> 2;
     $58 = $57 | $56;
     $59 = $58 >>> 4;
     $60 = $59 | $58;
     $61 = $60 >>> 8;
     $62 = $61 | $60;
     $63 = $62 >>> 16;
     $64 = $63 | $62;
     $65 = (($64) + 1)|0;
     $66 = HEAP32[$30>>2]|0;
     $67 = Math_fround(HEAPF32[$31>>2]);
     __ZN5physx19PxsFluidSpatialHash14buildLocalHashEPKNS_16PxsFluidParticleEjPNS_15PxsParticleCellEPjPtjfRKNS_6PxVec3E($particlesSpB$033,$53,$6,$2,$66,$65,$67,$packetCorner);
     $68 = ($33>>>0)<($53>>>0);
     __ZN5physx24updateCellsSubpacketPairENS_16PxsSphUpdateTypeEPNS_6PxVec3ES2_PNS_16PxsFluidParticleES4_PKNS_15PxsParticleCellES7_PKjS9_jjbRKNS_26PxsFluidDynamicsParametersERNS_27PxsFluidDynamicsTempBuffersEb($updateType,$forceBufA0$037,$forceBufB$032,$particlesSpA0$038,$particlesSpB$033,$4,$6,$0,$2,$45,$65,1,$15,$tempBuffers,$68);
     $69 = (($particlesLeftB$034) - ($53))|0;
     $70 = (($particlesSpB$033) + ($53<<5)|0);
     $71 = (($forceBufB$032) + (($53*12)|0)|0);
     $72 = ($particlesLeftB$034|0)==($53|0);
     if ($72) {
      break;
     } else {
      $forceBufB$032 = $71;$particlesLeftB$034 = $69;$particlesSpB$033 = $70;
     }
    }
    if ($51) {
     break;
    } else {
     $forceBufA0$037 = $50;$particlesLeftA0$039 = $48;$particlesSpA0$038 = $49;
    }
   }
  }
 } while(0);
 $73 = (($haloRegions) + 784|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if ($75) {
  STACKTOP = sp;return;
 }
 $76 = (($tempBuffers) + 36|0);
 $77 = (($tempBuffers) + 8|0);
 $78 = ($updateType|0)==(0);
 $79 = (($tempBuffers) + 28|0);
 $80 = (($tempBuffers) + 32|0);
 $81 = (($tempBuffers) + 40|0);
 $82 = (($this) + 28|0);
 $s$028 = 0;
 while(1) {
  $83 = (($packetSections) + ($s$028<<2)|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ($84|0)==(0);
  if (!($85)) {
   $86 = ($84>>>0)<(201);
   $87 = (494552 + (($s$028*80)|0)|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ((($packetSections) + ($s$028<<2)|0) + 108|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($forceBuf) + (($90*12)|0)|0);
   $92 = (($particles) + ($90<<5)|0);
   $93 = ($88|0)==(0);
   $forceBufA$022 = $91;$particlesLeftA$024 = $84;$particlesSpA$023 = $92;
   while(1) {
    $94 = ($particlesLeftA$024>>>0)<(512);
    $95 = $94 ? $particlesLeftA$024 : 512;
    $96 = (($95) + 1)|0;
    $97 = $96 >>> 1;
    $98 = $97 | $96;
    $99 = $98 >>> 2;
    $100 = $99 | $98;
    $101 = $100 >>> 4;
    $102 = $101 | $100;
    $103 = $102 >>> 8;
    $104 = $103 | $102;
    $105 = $104 >>> 16;
    $106 = $105 | $104;
    $107 = (($106) + 1)|0;
    if (!($93)) {
     $h$010 = 0;$isLocalHashValid$0$off09 = 0;
     while(1) {
      $108 = (((494552 + (($s$028*80)|0)|0) + ($h$010<<2)|0) + 4|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = (($haloRegions) + ($109<<2)|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = ($111>>>0)<(201);
      $or$cond = $86 & $112;
      if ($or$cond) {
       $isLocalHashValid$2$off0 = $isLocalHashValid$0$off09;
      } else {
       if (!($isLocalHashValid$0$off09)) {
        $113 = HEAP32[$81>>2]|0;
        $114 = Math_fround(HEAPF32[$82>>2]);
        __ZN5physx19PxsFluidSpatialHash14buildLocalHashEPKNS_16PxsFluidParticleEjPNS_15PxsParticleCellEPjPtjfRKNS_6PxVec3E($particlesSpA$023,$95,$4,$0,$113,$107,$114,$packetCorner);
       }
       $115 = ($111|0)==(0);
       if ($115) {
        $isLocalHashValid$2$off0 = 1;
       } else {
        $116 = ((($haloRegions) + ($109<<2)|0) + 392|0);
        $117 = HEAP32[$116>>2]|0;
        $118 = (($particles) + ($117<<5)|0);
        $particlesLeftB3$06 = $111;$particlesSpB4$07 = $118;
        while(1) {
         $119 = ($particlesLeftB3$06>>>0)<(512);
         $120 = $119 ? $particlesLeftB3$06 : 512;
         $121 = (($120) + 1)|0;
         $122 = $121 >>> 1;
         $123 = $122 | $121;
         $124 = $123 >>> 2;
         $125 = $124 | $123;
         $126 = $125 >>> 4;
         $127 = $126 | $125;
         $128 = $127 >>> 8;
         $129 = $128 | $127;
         $130 = $129 >>> 16;
         $131 = $130 | $129;
         $132 = (($131) + 1)|0;
         $133 = HEAP32[$81>>2]|0;
         $134 = Math_fround(HEAPF32[$82>>2]);
         __ZN5physx19PxsFluidSpatialHash14buildLocalHashEPKNS_16PxsFluidParticleEjPNS_15PxsParticleCellEPjPtjfRKNS_6PxVec3E($particlesSpB4$07,$120,$6,$2,$133,$132,$134,$packetCorner);
         $135 = ($95>>>0)>($120>>>0);
         __ZN5physx24updateCellsSubpacketPairENS_16PxsSphUpdateTypeEPNS_6PxVec3ES2_PNS_16PxsFluidParticleES4_PKNS_15PxsParticleCellES7_PKjS9_jjbRKNS_26PxsFluidDynamicsParametersERNS_27PxsFluidDynamicsTempBuffersEb($updateType,$forceBufA$022,0,$particlesSpA$023,$particlesSpB4$07,$4,$6,$0,$2,$107,$132,0,$15,$tempBuffers,$135);
         $136 = (($particlesLeftB3$06) - ($120))|0;
         $137 = (($particlesSpB4$07) + ($120<<5)|0);
         $138 = ($particlesLeftB3$06|0)==($120|0);
         if ($138) {
          $isLocalHashValid$2$off0 = 1;
          break;
         } else {
          $particlesLeftB3$06 = $136;$particlesSpB4$07 = $137;
         }
        }
       }
      }
      $139 = (($h$010) + 1)|0;
      $exitcond = ($139|0)==($88|0);
      if ($exitcond) {
       break;
      } else {
       $h$010 = $139;$isLocalHashValid$0$off09 = $isLocalHashValid$2$off0;
      }
     }
     if (!($93)) {
      $h7$018 = 0;$mergedIndexCount$017 = 0;
      while(1) {
       $140 = (((494552 + (($s$028*80)|0)|0) + ($h7$018<<2)|0) + 4|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = (($haloRegions) + ($141<<2)|0);
       $143 = HEAP32[$142>>2]|0;
       $$not5 = ($143|0)!=(0);
       $brmerge$not = $86 & $$not5;
       $144 = ($143>>>0)<(201);
       $or$cond4 = $brmerge$not & $144;
       if ($or$cond4) {
        $145 = (($143) + ($mergedIndexCount$017))|0;
        $146 = ($145>>>0)>(512);
        if ($146) {
         $147 = HEAP32[$76>>2]|0;
         $148 = HEAP32[$77>>2]|0;
         $149 = HEAP32[$79>>2]|0;
         $150 = HEAP32[$80>>2]|0;
         __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($forceBufA$022,0,$particlesSpA$023,$particles,$147,$84,$148,$mergedIndexCount$017,0,$78,$15,$149,$150);
         $mergedIndexCount$1 = 0;
        } else {
         $mergedIndexCount$1 = $mergedIndexCount$017;
        }
        $151 = ((($haloRegions) + ($141<<2)|0) + 392|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = HEAP32[$77>>2]|0;
        $hpIndex$014 = $152;$k$015 = 0;$mergedIndexCount$213 = $mergedIndexCount$1;
        while(1) {
         $154 = (($hpIndex$014) + 1)|0;
         $155 = (($mergedIndexCount$213) + 1)|0;
         $156 = (($153) + ($mergedIndexCount$213<<2)|0);
         HEAP32[$156>>2] = $hpIndex$014;
         $157 = (($k$015) + 1)|0;
         $exitcond43 = ($157|0)==($143|0);
         if ($exitcond43) {
          break;
         } else {
          $hpIndex$014 = $154;$k$015 = $157;$mergedIndexCount$213 = $155;
         }
        }
        $158 = (($mergedIndexCount$1) + ($143))|0;
        $mergedIndexCount$3 = $158;
       } else {
        $mergedIndexCount$3 = $mergedIndexCount$017;
       }
       $159 = (($h7$018) + 1)|0;
       $exitcond44 = ($159|0)==($88|0);
       if ($exitcond44) {
        break;
       } else {
        $h7$018 = $159;$mergedIndexCount$017 = $mergedIndexCount$3;
       }
      }
      $160 = ($mergedIndexCount$3|0)==(0);
      if (!($160)) {
       $161 = HEAP32[$76>>2]|0;
       $162 = HEAP32[$77>>2]|0;
       $163 = HEAP32[$79>>2]|0;
       $164 = HEAP32[$80>>2]|0;
       __ZN5physxL23updateParticleGroupPairEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjS5_jbbRKNS_26PxsFluidDynamicsParametersEPhPj($forceBufA$022,0,$particlesSpA$023,$particles,$161,$84,$162,$mergedIndexCount$3,0,$78,$15,$163,$164);
      }
     }
    }
    $165 = (($particlesLeftA$024) - ($95))|0;
    $166 = (($particlesSpA$023) + ($95<<5)|0);
    $167 = (($forceBufA$022) + (($95*12)|0)|0);
    $168 = ($particlesLeftA$024|0)==($95|0);
    if ($168) {
     break;
    } else {
     $forceBufA$022 = $167;$particlesLeftA$024 = $165;$particlesSpA$023 = $166;
    }
   }
  }
  $169 = (($s$028) + 1)|0;
  $exitcond45 = ($169|0)==(26);
  if ($exitcond45) {
   break;
  } else {
   $s$028 = $169;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_10mergeForceEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_10mergeForceEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_10mergeForceEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx16PxsFluidDynamics10mergeForceEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_12mergeDensityEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_12mergeDensityEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_12mergeDensityEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 128|0);
 __ZN5physx16PxsFluidDynamics15schedulePacketsENS_16PxsSphUpdateTypeERNS_10PxBaseTaskE($1,1,$2);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($2);
 STACKTOP = sp;return;
}
function __ZN5physx23PxsFluidDynamicsSphTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxsFluidDynamicsSphTaskD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx23PxsFluidDynamicsSphTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (499104|0);
}
function __ZN5physx23PxsFluidDynamicsSphTask11runInternalEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $haloRegions$i = 0, $inEnabled$not$i$i$i1 = 0, $or$cond$i$i$i2 = 0, $p$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 800|0;
 $haloRegions$i = sp;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 6736|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAPU16[545688>>1]|(HEAPU16[545688+2>>1]<<16);
 $16 = $15 & 16711680;
 $inEnabled$not$i$i$i1 = ($16|0)==(0);
 $17 = ($8|0)==(0|0);
 $or$cond$i$i$i2 = $17 | $inEnabled$not$i$i$i1;
 if ($or$cond$i$i$i2) {
  $25 = $2;$31 = $1;
 } else {
  $18 = $15&65535;
  $19 = HEAP32[$8>>2]|0;
  $20 = (($19) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_viiii[$21 & 511]($8,$18,$11,$14);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$$pre>>2]|0;
  $25 = $$pre3;$31 = $$pre;
 }
 $22 = (($this) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + 72|0);
 $26 = HEAP32[$24>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($26) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($31) + 4|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = (($31) + 96|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($31) + ($23<<2)|0) + 520|0);
 $36 = HEAP16[$35>>1]|0;
 $37 = ((($31) + ($23<<2)|0) + 522|0);
 $38 = HEAP16[$37>>1]|0;
 $39 = ($36&65535)<($38&65535);
 if ($39) {
  $40 = $36&65535;
  $41 = (($31) + 160|0);
  $42 = ((($31) + (($23*44)|0)|0) + 168|0);
  $44 = $40;$58 = $38;$p$01$i = $36;
  while(1) {
   $43 = (($27) + ($44<<4)|0);
   $45 = ((($27) + ($44<<4)|0) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(-1);
   if ($47) {
    $53 = $58;
   } else {
    __ZN5physx19PxsFluidSpatialHash14getHaloRegionsERNS_25PxsFluidPacketHaloRegionsERKNS_17PxcGridCellVectorEPKNS_15PxsParticleCellEPKNS_22PxsFluidPacketSectionsEj($haloRegions$i,$43,$27,$29,1024);
    $48 = HEAP32[$41>>2]|0;
    $49 = (($29) + (($44*216)|0)|0);
    __ZN5physx16PxsFluidDynamics12updatePacketENS_16PxsSphUpdateTypeEPNS_6PxVec3EPNS_16PxsFluidParticleERKNS_15PxsParticleCellERKNS_22PxsFluidPacketSectionsERKNS_25PxsFluidPacketHaloRegionsERNS_27PxsFluidDynamicsTempBuffersE($31,$48,$34,$32,$43,$49,$haloRegions$i,$42);
    $$pre$i = HEAP16[$37>>1]|0;
    $53 = $$pre$i;
   }
   $50 = (($p$01$i) + 1)<<16>>16;
   $51 = $50&65535;
   $52 = ($50&65535)<($53&65535);
   if ($52) {
    $44 = $51;$58 = $53;$p$01$i = $50;
   } else {
    break;
   }
  }
 }
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return;
 }
 $54 = HEAP32[$8>>2]|0;
 $55 = (($54) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = $15&65535;
 FUNCTION_TABLE_viiii[$56 & 511]($8,$57,$11,$14);
 STACKTOP = sp;return;
}
function __ZN5physxL23updateStreamForceTwoWayEPNS_6PxVec3ES1_PNS_16PxsFluidParticleES3_PKjjRKNS_26PxsFluidDynamicsParametersERKNS_30PxsFluidDynamicsParametersSIMDE($forceBufA,$forceBufB,$particlesA,$particlesB,$indexStream,$indexStreamSize,$params,$simdParams) {
 $forceBufA = $forceBufA|0;
 $forceBufB = $forceBufB|0;
 $particlesA = $particlesA|0;
 $particlesB = $particlesB|0;
 $indexStream = $indexStream|0;
 $indexStreamSize = $indexStreamSize|0;
 $params = $params|0;
 $simdParams = $simdParams|0;
 var $$promoted = Math_fround(0), $$promoted133 = Math_fround(0), $$promoted134 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0;
 var $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0);
 var $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0;
 var $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0);
 var $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0);
 var $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0;
 var $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $forceDstT = 0, $forceSrcT = 0, $i$0126 = 0, $i1$0128 = 0, $invDensityA = 0, $posDensDstT = 0, $s$0137 = 0, $s$1127 = 0, $s$2 = 0, $s$3$lcssa = 0;
 var $s$3129 = 0, $umax = 0, $velPressDstT = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $posDensDstT = sp + 256|0;
 $forceDstT = sp;
 $0 = sp + 64|0;
 $1 = sp + 80|0;
 $2 = sp + 96|0;
 $velPressDstT = sp + 112|0;
 $invDensityA = sp + 176|0;
 $forceSrcT = sp + 192|0;
 $3 = ($indexStreamSize|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($params) + 52|0);
 $5 = (($params) + 24|0);
 $6 = (($params) + 44|0);
 $7 = (($params) + 28|0);
 $8 = (($params) + 36|0);
 $9 = (($params) + 48|0);
 $10 = (($params) + 40|0);
 $11 = (($posDensDstT) + 4|0);
 $12 = (($posDensDstT) + 8|0);
 $13 = (($posDensDstT) + 12|0);
 $14 = (($posDensDstT) + 16|0);
 $15 = (($posDensDstT) + 20|0);
 $16 = (($posDensDstT) + 24|0);
 $17 = (($posDensDstT) + 28|0);
 $18 = (($posDensDstT) + 32|0);
 $19 = (($posDensDstT) + 36|0);
 $20 = (($posDensDstT) + 40|0);
 $21 = (($posDensDstT) + 44|0);
 $22 = (($posDensDstT) + 48|0);
 $23 = (($posDensDstT) + 52|0);
 $24 = (($posDensDstT) + 56|0);
 $25 = (($posDensDstT) + 60|0);
 $26 = (($forceDstT) + 16|0);
 $27 = (($forceDstT) + 32|0);
 $28 = (($forceDstT) + 48|0);
 $29 = (($velPressDstT) + 4|0);
 $30 = (($velPressDstT) + 8|0);
 $31 = (($velPressDstT) + 12|0);
 $32 = (($velPressDstT) + 16|0);
 $33 = (($velPressDstT) + 20|0);
 $34 = (($velPressDstT) + 24|0);
 $35 = (($velPressDstT) + 28|0);
 $36 = (($velPressDstT) + 32|0);
 $37 = (($velPressDstT) + 36|0);
 $38 = (($velPressDstT) + 40|0);
 $39 = (($velPressDstT) + 44|0);
 $40 = (($velPressDstT) + 48|0);
 $41 = (($velPressDstT) + 52|0);
 $42 = (($velPressDstT) + 56|0);
 $43 = (($velPressDstT) + 60|0);
 $44 = (($invDensityA) + 4|0);
 $45 = (($invDensityA) + 8|0);
 $46 = (($invDensityA) + 12|0);
 $47 = (($forceDstT) + 16|0);
 $48 = (($forceDstT) + 32|0);
 $49 = (($forceDstT) + 4|0);
 $50 = (($forceDstT) + 20|0);
 $51 = (($forceDstT) + 36|0);
 $52 = (($forceDstT) + 8|0);
 $53 = (($forceDstT) + 24|0);
 $54 = (($forceDstT) + 40|0);
 $55 = (($forceDstT) + 12|0);
 $56 = (($forceDstT) + 28|0);
 $57 = (($forceDstT) + 44|0);
 $58 = (($forceSrcT) + 4|0);
 $59 = (($forceSrcT) + 8|0);
 $60 = (($forceSrcT) + 12|0);
 $61 = (($forceSrcT) + 16|0);
 $62 = (($forceSrcT) + 20|0);
 $63 = (($forceSrcT) + 24|0);
 $64 = (($forceSrcT) + 28|0);
 $65 = (($forceSrcT) + 32|0);
 $66 = (($forceSrcT) + 36|0);
 $67 = (($forceSrcT) + 40|0);
 $68 = (($forceSrcT) + 44|0);
 $69 = (($forceSrcT) + 48|0);
 $s$0137 = 0;
 while(1) {
  $78 = (($s$0137) + 1)|0;
  $79 = (($indexStream) + ($s$0137<<2)|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($particlesA) + ($80<<5)|0);
  $82 = (($s$0137) + 2)|0;
  $83 = (($indexStream) + ($78<<2)|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = $84 >>> 2;
  $86 = ($85|0)==(0);
  if ($86) {
   $s$2 = $82;
  } else {
   $87 = Math_fround(HEAPF32[$81>>2]);
   $88 = (($81) + 4|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = (($81) + 8|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = (($81) + 12|0);
   $93 = Math_fround(HEAPF32[$92>>2]);
   HEAPF32[$posDensDstT>>2] = $87;
   HEAPF32[$11>>2] = $87;
   HEAPF32[$12>>2] = $87;
   HEAPF32[$13>>2] = $87;
   HEAPF32[$14>>2] = $89;
   HEAPF32[$15>>2] = $89;
   HEAPF32[$16>>2] = $89;
   HEAPF32[$17>>2] = $89;
   HEAPF32[$18>>2] = $91;
   HEAPF32[$19>>2] = $91;
   HEAPF32[$20>>2] = $91;
   HEAPF32[$21>>2] = $91;
   HEAPF32[$22>>2] = $93;
   HEAPF32[$23>>2] = $93;
   HEAPF32[$24>>2] = $93;
   HEAPF32[$25>>2] = $93;
   ;HEAP32[$forceDstT+0>>2]=0|0;HEAP32[$forceDstT+4>>2]=0|0;HEAP32[$forceDstT+8>>2]=0|0;HEAP32[$forceDstT+12>>2]=0|0;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
   ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
   ;HEAP32[$26+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$0+12>>2]|0;
   ;HEAP32[$27+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$28+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$2+12>>2]|0;
   $94 = ((($particlesA) + ($80<<5)|0) + 16|0);
   $95 = Math_fround(HEAPF32[$94>>2]);
   $96 = (($94) + 4|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = (($94) + 8|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $100 = (($94) + 12|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   HEAPF32[$velPressDstT>>2] = $95;
   HEAPF32[$29>>2] = $95;
   HEAPF32[$30>>2] = $95;
   HEAPF32[$31>>2] = $95;
   HEAPF32[$32>>2] = $97;
   HEAPF32[$33>>2] = $97;
   HEAPF32[$34>>2] = $97;
   HEAPF32[$35>>2] = $97;
   HEAPF32[$36>>2] = $99;
   HEAPF32[$37>>2] = $99;
   HEAPF32[$38>>2] = $99;
   HEAPF32[$39>>2] = $99;
   HEAPF32[$40>>2] = $101;
   HEAPF32[$41>>2] = $101;
   HEAPF32[$42>>2] = $101;
   HEAPF32[$43>>2] = $101;
   $102 = Math_fround(Math_fround(1.0) / $93);
   HEAPF32[$invDensityA>>2] = $102;
   HEAPF32[$44>>2] = $102;
   HEAPF32[$45>>2] = $102;
   HEAPF32[$46>>2] = $102;
   $103 = $85 << 2;
   $i$0126 = 0;$s$1127 = $82;
   while(1) {
    $104 = (($s$1127) + 1)|0;
    $105 = (($indexStream) + ($s$1127<<2)|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = (($s$1127) + 2)|0;
    $108 = (($indexStream) + ($104<<2)|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($s$1127) + 3)|0;
    $111 = (($indexStream) + ($107<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($s$1127) + 4)|0;
    $114 = (($indexStream) + ($110<<2)|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = (($forceBufB) + (($106*12)|0)|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = (($116) + 4|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = (($116) + 8|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    $122 = (($forceBufB) + (($109*12)|0)|0);
    $123 = Math_fround(HEAPF32[$122>>2]);
    $124 = (($122) + 4|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = (($122) + 8|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = (($forceBufB) + (($112*12)|0)|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = (($128) + 4|0);
    $131 = Math_fround(HEAPF32[$130>>2]);
    $132 = (($128) + 8|0);
    $133 = Math_fround(HEAPF32[$132>>2]);
    $134 = (($forceBufB) + (($115*12)|0)|0);
    $135 = Math_fround(HEAPF32[$134>>2]);
    $136 = (($134) + 4|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = (($134) + 8|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    HEAPF32[$forceSrcT>>2] = $117;
    HEAPF32[$58>>2] = $123;
    HEAPF32[$59>>2] = $129;
    HEAPF32[$60>>2] = $135;
    HEAPF32[$61>>2] = $119;
    HEAPF32[$62>>2] = $125;
    HEAPF32[$63>>2] = $131;
    HEAPF32[$64>>2] = $137;
    HEAPF32[$65>>2] = $121;
    HEAPF32[$66>>2] = $127;
    HEAPF32[$67>>2] = $133;
    HEAPF32[$68>>2] = $139;
    $140 = (($particlesB) + ($106<<5)|0);
    $141 = (($particlesB) + ($109<<5)|0);
    $142 = (($particlesB) + ($112<<5)|0);
    $143 = (($particlesB) + ($115<<5)|0);
    ;HEAP32[$69+0>>2]=0|0;HEAP32[$69+4>>2]=0|0;HEAP32[$69+8>>2]=0|0;HEAP32[$69+12>>2]=0|0;
    __ZN5physx26calcForce4_twoWay_onlyPtrsERNS_6shdfnd3aos6Mat44VES3_PNS_16PxsFluidParticleES5_S5_S5_RKS2_S7_RKNS1_5Vec4VERKNS_30PxsFluidDynamicsParametersSIMDE($forceDstT,$forceSrcT,$140,$141,$142,$143,$posDensDstT,$velPressDstT,$invDensityA,$simdParams);
    $144 = Math_fround(HEAPF32[$forceSrcT>>2]);
    $145 = Math_fround(HEAPF32[$61>>2]);
    $146 = Math_fround(HEAPF32[$65>>2]);
    $147 = Math_fround(HEAPF32[$58>>2]);
    $148 = Math_fround(HEAPF32[$62>>2]);
    $149 = Math_fround(HEAPF32[$66>>2]);
    $150 = Math_fround(HEAPF32[$59>>2]);
    $151 = Math_fround(HEAPF32[$63>>2]);
    $152 = Math_fround(HEAPF32[$67>>2]);
    $153 = Math_fround(HEAPF32[$60>>2]);
    $154 = Math_fround(HEAPF32[$64>>2]);
    $155 = Math_fround(HEAPF32[$68>>2]);
    HEAPF32[$116>>2] = $144;
    $156 = ((($forceBufB) + (($106*12)|0)|0) + 4|0);
    HEAPF32[$156>>2] = $145;
    $157 = ((($forceBufB) + (($106*12)|0)|0) + 8|0);
    HEAPF32[$157>>2] = $146;
    HEAPF32[$122>>2] = $147;
    $158 = ((($forceBufB) + (($109*12)|0)|0) + 4|0);
    HEAPF32[$158>>2] = $148;
    $159 = ((($forceBufB) + (($109*12)|0)|0) + 8|0);
    HEAPF32[$159>>2] = $149;
    HEAPF32[$128>>2] = $150;
    $160 = ((($forceBufB) + (($112*12)|0)|0) + 4|0);
    HEAPF32[$160>>2] = $151;
    $161 = ((($forceBufB) + (($112*12)|0)|0) + 8|0);
    HEAPF32[$161>>2] = $152;
    HEAPF32[$134>>2] = $153;
    $162 = ((($forceBufB) + (($115*12)|0)|0) + 4|0);
    HEAPF32[$162>>2] = $154;
    $163 = ((($forceBufB) + (($115*12)|0)|0) + 8|0);
    HEAPF32[$163>>2] = $155;
    $164 = (($i$0126) + 1)|0;
    $165 = ($164>>>0)<($85>>>0);
    if ($165) {
     $i$0126 = $164;$s$1127 = $113;
    } else {
     break;
    }
   }
   $166 = (($82) + ($103))|0;
   $167 = Math_fround(HEAPF32[$forceDstT>>2]);
   $168 = Math_fround(HEAPF32[$47>>2]);
   $169 = Math_fround(HEAPF32[$48>>2]);
   $170 = Math_fround(HEAPF32[$49>>2]);
   $171 = Math_fround(HEAPF32[$50>>2]);
   $172 = Math_fround(HEAPF32[$51>>2]);
   $173 = Math_fround(HEAPF32[$52>>2]);
   $174 = Math_fround(HEAPF32[$53>>2]);
   $175 = Math_fround(HEAPF32[$54>>2]);
   $176 = Math_fround(HEAPF32[$55>>2]);
   $177 = Math_fround(HEAPF32[$56>>2]);
   $178 = Math_fround(HEAPF32[$57>>2]);
   $179 = Math_fround($167 + $170);
   $180 = Math_fround($168 + $171);
   $181 = Math_fround($169 + $172);
   $182 = Math_fround($173 + $176);
   $183 = Math_fround($174 + $177);
   $184 = Math_fround($175 + $178);
   $185 = Math_fround($179 + $182);
   $186 = Math_fround($180 + $183);
   $187 = Math_fround($181 + $184);
   $188 = (($forceBufA) + (($80*12)|0)|0);
   $189 = Math_fround(HEAPF32[$188>>2]);
   $190 = Math_fround($185 + $189);
   HEAPF32[$188>>2] = $190;
   $191 = ((($forceBufA) + (($80*12)|0)|0) + 4|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = Math_fround($186 + $192);
   HEAPF32[$191>>2] = $193;
   $194 = ((($forceBufA) + (($80*12)|0)|0) + 8|0);
   $195 = Math_fround(HEAPF32[$194>>2]);
   $196 = Math_fround($187 + $195);
   HEAPF32[$194>>2] = $196;
   $s$2 = $166;
  }
  $197 = $85 << 2;
  $198 = (($84) - ($197))|0;
  $199 = ($84|0)==($197|0);
  if ($199) {
   $s$3$lcssa = $s$2;
  } else {
   $200 = Math_fround(HEAPF32[$81>>2]);
   $201 = ((($particlesA) + ($80<<5)|0) + 4|0);
   $202 = Math_fround(HEAPF32[$201>>2]);
   $203 = ((($particlesA) + ($80<<5)|0) + 8|0);
   $204 = Math_fround(HEAPF32[$203>>2]);
   $205 = Math_fround(HEAPF32[$4>>2]);
   $206 = Math_fround(HEAPF32[$5>>2]);
   $207 = ((($particlesA) + ($80<<5)|0) + 12|0);
   $208 = Math_fround(HEAPF32[$207>>2]);
   $209 = Math_fround(HEAPF32[$6>>2]);
   $210 = Math_fround($208 - $209);
   $211 = $210 > Math_fround(0.0);
   $212 = $211 ? $210 : Math_fround(0.0);
   $213 = Math_fround(HEAPF32[$7>>2]);
   $214 = Math_fround($206 * Math_fround(2.0));
   $215 = Math_fround(HEAPF32[$8>>2]);
   $216 = Math_fround(HEAPF32[$9>>2]);
   $217 = Math_fround(HEAPF32[$10>>2]);
   $218 = ((($particlesA) + ($80<<5)|0) + 16|0);
   $219 = Math_fround(HEAPF32[$218>>2]);
   $220 = ((($particlesA) + ($80<<5)|0) + 20|0);
   $221 = Math_fround(HEAPF32[$220>>2]);
   $222 = ((($particlesA) + ($80<<5)|0) + 24|0);
   $223 = Math_fround(HEAPF32[$222>>2]);
   $72 = (($forceBufA) + (($80*12)|0)|0);
   $74 = ((($forceBufA) + (($80*12)|0)|0) + 4|0);
   $76 = ((($forceBufA) + (($80*12)|0)|0) + 8|0);
   $224 = Math_fround(Math_fround(1.0) / $208);
   $$promoted = Math_fround(HEAPF32[$72>>2]);
   $$promoted133 = Math_fround(HEAPF32[$74>>2]);
   $$promoted134 = Math_fround(HEAPF32[$76>>2]);
   $225 = $85 << 2;
   $226 = (($84) - ($225))|0;
   $227 = ($226>>>0)>(1);
   $umax = $227 ? $226 : 1;
   $290 = $$promoted;$291 = $$promoted133;$292 = $$promoted134;$i1$0128 = 0;$s$3129 = $s$2;
   while(1) {
    $228 = (($s$3129) + 1)|0;
    $229 = (($indexStream) + ($s$3129<<2)|0);
    $230 = HEAP32[$229>>2]|0;
    $231 = (($particlesB) + ($230<<5)|0);
    $232 = Math_fround(HEAPF32[$231>>2]);
    $233 = Math_fround($200 - $232);
    $234 = ((($particlesB) + ($230<<5)|0) + 4|0);
    $235 = Math_fround(HEAPF32[$234>>2]);
    $236 = Math_fround($202 - $235);
    $237 = ((($particlesB) + ($230<<5)|0) + 8|0);
    $238 = Math_fround(HEAPF32[$237>>2]);
    $239 = Math_fround($204 - $238);
    $240 = Math_fround($233 * $233);
    $241 = Math_fround($236 * $236);
    $242 = Math_fround($240 + $241);
    $243 = Math_fround($239 * $239);
    $244 = Math_fround($242 + $243);
    $245 = Math_fround($205 * $244);
    $246 = (Math_fround(Math_sqrt((Math_fround($245)))));
    $247 = Math_fround(Math_fround(1.0) / $246);
    $248 = Math_fround($247 * $245);
    $249 = Math_fround($206 - $248);
    $250 = ((($particlesB) + ($230<<5)|0) + 12|0);
    $251 = Math_fround(HEAPF32[$250>>2]);
    $252 = Math_fround($251 - $209);
    $253 = $252 > Math_fround(0.0);
    $254 = $253 ? $252 : Math_fround(0.0);
    $255 = Math_fround($212 + $254);
    $256 = Math_fround($247 * $213);
    $257 = Math_fround($256 - $214);
    $258 = Math_fround($248 + $257);
    $259 = Math_fround($215 * $258);
    $260 = Math_fround($255 * $259);
    $261 = Math_fround($233 * $260);
    $262 = Math_fround($236 * $260);
    $263 = Math_fround($239 * $260);
    $264 = Math_fround($216 * $261);
    $265 = Math_fround($216 * $262);
    $266 = Math_fround($216 * $263);
    $267 = Math_fround($249 * $217);
    $268 = ((($particlesB) + ($230<<5)|0) + 16|0);
    $269 = Math_fround(HEAPF32[$268>>2]);
    $270 = Math_fround($269 - $219);
    $271 = ((($particlesB) + ($230<<5)|0) + 20|0);
    $272 = Math_fround(HEAPF32[$271>>2]);
    $273 = Math_fround($272 - $221);
    $274 = ((($particlesB) + ($230<<5)|0) + 24|0);
    $275 = Math_fround(HEAPF32[$274>>2]);
    $276 = Math_fround($275 - $223);
    $277 = Math_fround($216 * $270);
    $278 = Math_fround($216 * $273);
    $279 = Math_fround($216 * $276);
    $280 = Math_fround($267 * $277);
    $281 = Math_fround($267 * $278);
    $282 = Math_fround($267 * $279);
    $283 = Math_fround($264 + $280);
    $284 = Math_fround($265 + $281);
    $285 = Math_fround($266 + $282);
    $286 = Math_fround(Math_fround(1.0) / $251);
    $287 = Math_fround($283 * $286);
    $288 = Math_fround($286 * $284);
    $289 = Math_fround($286 * $285);
    $71 = Math_fround($287 + $290);
    $73 = Math_fround($288 + $291);
    $75 = Math_fround($292 + $289);
    $293 = Math_fround($283 * $224);
    $294 = Math_fround($284 * $224);
    $295 = Math_fround($285 * $224);
    $296 = (($forceBufB) + (($230*12)|0)|0);
    $297 = Math_fround(HEAPF32[$296>>2]);
    $298 = Math_fround($297 - $293);
    HEAPF32[$296>>2] = $298;
    $299 = ((($forceBufB) + (($230*12)|0)|0) + 4|0);
    $300 = Math_fround(HEAPF32[$299>>2]);
    $301 = Math_fround($300 - $294);
    HEAPF32[$299>>2] = $301;
    $302 = ((($forceBufB) + (($230*12)|0)|0) + 8|0);
    $303 = Math_fround(HEAPF32[$302>>2]);
    $304 = Math_fround($303 - $295);
    HEAPF32[$302>>2] = $304;
    $305 = (($i1$0128) + 1)|0;
    $306 = ($305>>>0)<($198>>>0);
    if ($306) {
     $290 = $71;$291 = $73;$292 = $75;$i1$0128 = $305;$s$3129 = $228;
    } else {
     break;
    }
   }
   $70 = (($s$2) + ($umax))|0;
   HEAPF32[$72>>2] = $71;
   HEAPF32[$74>>2] = $73;
   HEAPF32[$76>>2] = $75;
   $s$3$lcssa = $70;
  }
  $77 = ($s$3$lcssa>>>0)<($indexStreamSize>>>0);
  if ($77) {
   $s$0137 = $s$3$lcssa;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physxL17updateStreamForceEPNS_6PxVec3EPNS_16PxsFluidParticleEPKS2_PKjjRKNS_26PxsFluidDynamicsParametersERKNS_30PxsFluidDynamicsParametersSIMDE($forceBufA,$particlesA,$particlesB,$indexStream,$indexStreamSize,$params,$simdParams) {
 $forceBufA = $forceBufA|0;
 $particlesA = $particlesA|0;
 $particlesB = $particlesB|0;
 $indexStream = $indexStream|0;
 $indexStreamSize = $indexStreamSize|0;
 $params = $params|0;
 $simdParams = $simdParams|0;
 var $$promoted = Math_fround(0), $$promoted72 = Math_fround(0), $$promoted73 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0;
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $forceDstT = 0, $i$065 = 0, $i1$067 = 0;
 var $posDensDstT = 0, $s$076 = 0, $s$166 = 0, $s$2 = 0, $s$3$lcssa = 0, $s$368 = 0, $umax = 0, $velPressDstT = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $posDensDstT = sp + 176|0;
 $forceDstT = sp;
 $0 = sp + 64|0;
 $1 = sp + 80|0;
 $2 = sp + 96|0;
 $velPressDstT = sp + 112|0;
 $3 = ($indexStreamSize|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($params) + 52|0);
 $5 = (($params) + 24|0);
 $6 = (($params) + 44|0);
 $7 = (($params) + 28|0);
 $8 = (($params) + 36|0);
 $9 = (($params) + 48|0);
 $10 = (($params) + 40|0);
 $11 = (($posDensDstT) + 4|0);
 $12 = (($posDensDstT) + 8|0);
 $13 = (($posDensDstT) + 12|0);
 $14 = (($posDensDstT) + 16|0);
 $15 = (($posDensDstT) + 20|0);
 $16 = (($posDensDstT) + 24|0);
 $17 = (($posDensDstT) + 28|0);
 $18 = (($posDensDstT) + 32|0);
 $19 = (($posDensDstT) + 36|0);
 $20 = (($posDensDstT) + 40|0);
 $21 = (($posDensDstT) + 44|0);
 $22 = (($posDensDstT) + 48|0);
 $23 = (($posDensDstT) + 52|0);
 $24 = (($posDensDstT) + 56|0);
 $25 = (($posDensDstT) + 60|0);
 $26 = (($forceDstT) + 16|0);
 $27 = (($forceDstT) + 32|0);
 $28 = (($forceDstT) + 48|0);
 $29 = (($velPressDstT) + 4|0);
 $30 = (($velPressDstT) + 8|0);
 $31 = (($velPressDstT) + 12|0);
 $32 = (($velPressDstT) + 16|0);
 $33 = (($velPressDstT) + 20|0);
 $34 = (($velPressDstT) + 24|0);
 $35 = (($velPressDstT) + 28|0);
 $36 = (($velPressDstT) + 32|0);
 $37 = (($velPressDstT) + 36|0);
 $38 = (($velPressDstT) + 40|0);
 $39 = (($velPressDstT) + 44|0);
 $40 = (($velPressDstT) + 48|0);
 $41 = (($velPressDstT) + 52|0);
 $42 = (($velPressDstT) + 56|0);
 $43 = (($velPressDstT) + 60|0);
 $44 = (($forceDstT) + 16|0);
 $45 = (($forceDstT) + 32|0);
 $46 = (($forceDstT) + 4|0);
 $47 = (($forceDstT) + 20|0);
 $48 = (($forceDstT) + 36|0);
 $49 = (($forceDstT) + 8|0);
 $50 = (($forceDstT) + 24|0);
 $51 = (($forceDstT) + 40|0);
 $52 = (($forceDstT) + 12|0);
 $53 = (($forceDstT) + 28|0);
 $54 = (($forceDstT) + 44|0);
 $s$076 = 0;
 while(1) {
  $63 = (($s$076) + 1)|0;
  $64 = (($indexStream) + ($s$076<<2)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($particlesA) + ($65<<5)|0);
  $67 = (($s$076) + 2)|0;
  $68 = (($indexStream) + ($63<<2)|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = $69 >>> 2;
  $71 = ($70|0)==(0);
  if ($71) {
   $s$2 = $67;
  } else {
   $72 = Math_fround(HEAPF32[$66>>2]);
   $73 = (($66) + 4|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = (($66) + 8|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = (($66) + 12|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   HEAPF32[$posDensDstT>>2] = $72;
   HEAPF32[$11>>2] = $72;
   HEAPF32[$12>>2] = $72;
   HEAPF32[$13>>2] = $72;
   HEAPF32[$14>>2] = $74;
   HEAPF32[$15>>2] = $74;
   HEAPF32[$16>>2] = $74;
   HEAPF32[$17>>2] = $74;
   HEAPF32[$18>>2] = $76;
   HEAPF32[$19>>2] = $76;
   HEAPF32[$20>>2] = $76;
   HEAPF32[$21>>2] = $76;
   HEAPF32[$22>>2] = $78;
   HEAPF32[$23>>2] = $78;
   HEAPF32[$24>>2] = $78;
   HEAPF32[$25>>2] = $78;
   ;HEAP32[$forceDstT+0>>2]=0|0;HEAP32[$forceDstT+4>>2]=0|0;HEAP32[$forceDstT+8>>2]=0|0;HEAP32[$forceDstT+12>>2]=0|0;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
   ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
   ;HEAP32[$26+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$0+12>>2]|0;
   ;HEAP32[$27+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$28+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$2+12>>2]|0;
   $79 = ((($particlesA) + ($65<<5)|0) + 16|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = (($79) + 4|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $83 = (($79) + 8|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   $85 = (($79) + 12|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   HEAPF32[$velPressDstT>>2] = $80;
   HEAPF32[$29>>2] = $80;
   HEAPF32[$30>>2] = $80;
   HEAPF32[$31>>2] = $80;
   HEAPF32[$32>>2] = $82;
   HEAPF32[$33>>2] = $82;
   HEAPF32[$34>>2] = $82;
   HEAPF32[$35>>2] = $82;
   HEAPF32[$36>>2] = $84;
   HEAPF32[$37>>2] = $84;
   HEAPF32[$38>>2] = $84;
   HEAPF32[$39>>2] = $84;
   HEAPF32[$40>>2] = $86;
   HEAPF32[$41>>2] = $86;
   HEAPF32[$42>>2] = $86;
   HEAPF32[$43>>2] = $86;
   $87 = $70 << 2;
   $i$065 = 0;$s$166 = $67;
   while(1) {
    $88 = (($s$166) + 1)|0;
    $89 = (($indexStream) + ($s$166<<2)|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = (($s$166) + 2)|0;
    $92 = (($indexStream) + ($88<<2)|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($s$166) + 3)|0;
    $95 = (($indexStream) + ($91<<2)|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($s$166) + 4)|0;
    $98 = (($indexStream) + ($94<<2)|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($particlesB) + ($90<<5)|0);
    $101 = (($particlesB) + ($93<<5)|0);
    $102 = (($particlesB) + ($96<<5)|0);
    $103 = (($particlesB) + ($99<<5)|0);
    __ZN5physx19calcForce4_onlyPtrsERNS_6shdfnd3aos6Mat44VEPKNS_16PxsFluidParticleES6_S6_S6_RKS2_S8_RKNS_30PxsFluidDynamicsParametersSIMDE($forceDstT,$100,$101,$102,$103,$posDensDstT,$velPressDstT,$simdParams);
    $104 = (($i$065) + 1)|0;
    $105 = ($104>>>0)<($70>>>0);
    if ($105) {
     $i$065 = $104;$s$166 = $97;
    } else {
     break;
    }
   }
   $106 = (($67) + ($87))|0;
   $107 = Math_fround(HEAPF32[$forceDstT>>2]);
   $108 = Math_fround(HEAPF32[$44>>2]);
   $109 = Math_fround(HEAPF32[$45>>2]);
   $110 = Math_fround(HEAPF32[$46>>2]);
   $111 = Math_fround(HEAPF32[$47>>2]);
   $112 = Math_fround(HEAPF32[$48>>2]);
   $113 = Math_fround(HEAPF32[$49>>2]);
   $114 = Math_fround(HEAPF32[$50>>2]);
   $115 = Math_fround(HEAPF32[$51>>2]);
   $116 = Math_fround(HEAPF32[$52>>2]);
   $117 = Math_fround(HEAPF32[$53>>2]);
   $118 = Math_fround(HEAPF32[$54>>2]);
   $119 = Math_fround($107 + $110);
   $120 = Math_fround($108 + $111);
   $121 = Math_fround($109 + $112);
   $122 = Math_fround($113 + $116);
   $123 = Math_fround($114 + $117);
   $124 = Math_fround($115 + $118);
   $125 = Math_fround($119 + $122);
   $126 = Math_fround($120 + $123);
   $127 = Math_fround($121 + $124);
   $128 = (($forceBufA) + (($65*12)|0)|0);
   $129 = Math_fround(HEAPF32[$128>>2]);
   $130 = Math_fround($125 + $129);
   HEAPF32[$128>>2] = $130;
   $131 = ((($forceBufA) + (($65*12)|0)|0) + 4|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = Math_fround($126 + $132);
   HEAPF32[$131>>2] = $133;
   $134 = ((($forceBufA) + (($65*12)|0)|0) + 8|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = Math_fround($127 + $135);
   HEAPF32[$134>>2] = $136;
   $s$2 = $106;
  }
  $137 = $70 << 2;
  $138 = (($69) - ($137))|0;
  $139 = ($69|0)==($137|0);
  if ($139) {
   $s$3$lcssa = $s$2;
  } else {
   $140 = Math_fround(HEAPF32[$66>>2]);
   $141 = ((($particlesA) + ($65<<5)|0) + 4|0);
   $142 = Math_fround(HEAPF32[$141>>2]);
   $143 = ((($particlesA) + ($65<<5)|0) + 8|0);
   $144 = Math_fround(HEAPF32[$143>>2]);
   $145 = Math_fround(HEAPF32[$4>>2]);
   $146 = Math_fround(HEAPF32[$5>>2]);
   $147 = ((($particlesA) + ($65<<5)|0) + 12|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = Math_fround(HEAPF32[$6>>2]);
   $150 = Math_fround($148 - $149);
   $151 = $150 > Math_fround(0.0);
   $152 = $151 ? $150 : Math_fround(0.0);
   $153 = Math_fround(HEAPF32[$7>>2]);
   $154 = Math_fround($146 * Math_fround(2.0));
   $155 = Math_fround(HEAPF32[$8>>2]);
   $156 = Math_fround(HEAPF32[$9>>2]);
   $157 = Math_fround(HEAPF32[$10>>2]);
   $158 = ((($particlesA) + ($65<<5)|0) + 16|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = ((($particlesA) + ($65<<5)|0) + 20|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = ((($particlesA) + ($65<<5)|0) + 24|0);
   $163 = Math_fround(HEAPF32[$162>>2]);
   $57 = (($forceBufA) + (($65*12)|0)|0);
   $59 = ((($forceBufA) + (($65*12)|0)|0) + 4|0);
   $61 = ((($forceBufA) + (($65*12)|0)|0) + 8|0);
   $$promoted = Math_fround(HEAPF32[$57>>2]);
   $$promoted72 = Math_fround(HEAPF32[$59>>2]);
   $$promoted73 = Math_fround(HEAPF32[$61>>2]);
   $164 = $70 << 2;
   $165 = (($69) - ($164))|0;
   $166 = ($165>>>0)>(1);
   $umax = $166 ? $165 : 1;
   $229 = $$promoted;$230 = $$promoted72;$231 = $$promoted73;$i1$067 = 0;$s$368 = $s$2;
   while(1) {
    $167 = (($s$368) + 1)|0;
    $168 = (($indexStream) + ($s$368<<2)|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = (($particlesB) + ($169<<5)|0);
    $171 = Math_fround(HEAPF32[$170>>2]);
    $172 = Math_fround($140 - $171);
    $173 = ((($particlesB) + ($169<<5)|0) + 4|0);
    $174 = Math_fround(HEAPF32[$173>>2]);
    $175 = Math_fround($142 - $174);
    $176 = ((($particlesB) + ($169<<5)|0) + 8|0);
    $177 = Math_fround(HEAPF32[$176>>2]);
    $178 = Math_fround($144 - $177);
    $179 = Math_fround($172 * $172);
    $180 = Math_fround($175 * $175);
    $181 = Math_fround($179 + $180);
    $182 = Math_fround($178 * $178);
    $183 = Math_fround($181 + $182);
    $184 = Math_fround($145 * $183);
    $185 = (Math_fround(Math_sqrt((Math_fround($184)))));
    $186 = Math_fround(Math_fround(1.0) / $185);
    $187 = Math_fround($186 * $184);
    $188 = Math_fround($146 - $187);
    $189 = ((($particlesB) + ($169<<5)|0) + 12|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = Math_fround($190 - $149);
    $192 = $191 > Math_fround(0.0);
    $193 = $192 ? $191 : Math_fround(0.0);
    $194 = Math_fround($152 + $193);
    $195 = Math_fround($186 * $153);
    $196 = Math_fround($195 - $154);
    $197 = Math_fround($187 + $196);
    $198 = Math_fround($155 * $197);
    $199 = Math_fround($194 * $198);
    $200 = Math_fround($172 * $199);
    $201 = Math_fround($175 * $199);
    $202 = Math_fround($178 * $199);
    $203 = Math_fround($156 * $200);
    $204 = Math_fround($156 * $201);
    $205 = Math_fround($156 * $202);
    $206 = Math_fround($188 * $157);
    $207 = ((($particlesB) + ($169<<5)|0) + 16|0);
    $208 = Math_fround(HEAPF32[$207>>2]);
    $209 = Math_fround($208 - $159);
    $210 = ((($particlesB) + ($169<<5)|0) + 20|0);
    $211 = Math_fround(HEAPF32[$210>>2]);
    $212 = Math_fround($211 - $161);
    $213 = ((($particlesB) + ($169<<5)|0) + 24|0);
    $214 = Math_fround(HEAPF32[$213>>2]);
    $215 = Math_fround($214 - $163);
    $216 = Math_fround($156 * $209);
    $217 = Math_fround($156 * $212);
    $218 = Math_fround($156 * $215);
    $219 = Math_fround($206 * $216);
    $220 = Math_fround($206 * $217);
    $221 = Math_fround($206 * $218);
    $222 = Math_fround($203 + $219);
    $223 = Math_fround($204 + $220);
    $224 = Math_fround($205 + $221);
    $225 = Math_fround(Math_fround(1.0) / $190);
    $226 = Math_fround($222 * $225);
    $227 = Math_fround($225 * $223);
    $228 = Math_fround($225 * $224);
    $56 = Math_fround($226 + $229);
    $58 = Math_fround($227 + $230);
    $60 = Math_fround($231 + $228);
    $232 = (($i1$067) + 1)|0;
    $233 = ($232>>>0)<($138>>>0);
    if ($233) {
     $229 = $56;$230 = $58;$231 = $60;$i1$067 = $232;$s$368 = $167;
    } else {
     break;
    }
   }
   $55 = (($s$2) + ($umax))|0;
   HEAPF32[$57>>2] = $56;
   HEAPF32[$59>>2] = $58;
   HEAPF32[$61>>2] = $60;
   $s$3$lcssa = $55;
  }
  $62 = ($s$3$lcssa>>>0)<($indexStreamSize>>>0);
  if ($62) {
   $s$076 = $s$3$lcssa;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx19calcForce4_onlyPtrsERNS_6shdfnd3aos6Mat44VEPKNS_16PxsFluidParticleES6_S6_S6_RKS2_S8_RKNS_30PxsFluidDynamicsParametersSIMDE($forceDstT,$pSrc0,$pSrc1,$pSrc2,$pSrc3,$posDensDstT,$velPressDstT,$params) {
 $forceDstT = $forceDstT|0;
 $pSrc0 = $pSrc0|0;
 $pSrc1 = $pSrc1|0;
 $pSrc2 = $pSrc2|0;
 $pSrc3 = $pSrc3|0;
 $posDensDstT = $posDensDstT|0;
 $velPressDstT = $velPressDstT|0;
 $params = $params|0;
 var $$$i = Math_fround(0), $$$i114 = Math_fround(0), $$1$i = Math_fround(0), $$1$i115 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0;
 var $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0);
 var $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0);
 var $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0);
 var $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = 0;
 var $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$pSrc0>>2]);
 $1 = (($pSrc0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($pSrc0) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pSrc0) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$pSrc1>>2]);
 $8 = (($pSrc1) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($pSrc1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($pSrc1) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$pSrc2>>2]);
 $15 = (($pSrc2) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($pSrc2) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($pSrc2) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$pSrc3>>2]);
 $22 = (($pSrc3) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($pSrc3) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($pSrc3) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround(HEAPF32[$posDensDstT>>2]);
 $29 = (($posDensDstT) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($posDensDstT) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($posDensDstT) + 12|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($28 - $0);
 $36 = Math_fround($30 - $7);
 $37 = Math_fround($32 - $14);
 $38 = Math_fround($34 - $21);
 $39 = (($posDensDstT) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($posDensDstT) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($posDensDstT) + 24|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($posDensDstT) + 28|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($40 - $2);
 $48 = Math_fround($42 - $9);
 $49 = Math_fround($44 - $16);
 $50 = Math_fround($46 - $23);
 $51 = (($posDensDstT) + 32|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($posDensDstT) + 36|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($posDensDstT) + 40|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($posDensDstT) + 44|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($52 - $4);
 $60 = Math_fround($54 - $11);
 $61 = Math_fround($56 - $18);
 $62 = Math_fround($58 - $25);
 $63 = Math_fround($35 * $35);
 $64 = Math_fround($36 * $36);
 $65 = Math_fround($37 * $37);
 $66 = Math_fround($38 * $38);
 $67 = Math_fround($47 * $47);
 $68 = Math_fround($48 * $48);
 $69 = Math_fround($49 * $49);
 $70 = Math_fround($50 * $50);
 $71 = Math_fround($63 + $67);
 $72 = Math_fround($64 + $68);
 $73 = Math_fround($65 + $69);
 $74 = Math_fround($66 + $70);
 $75 = Math_fround($59 * $59);
 $76 = Math_fround($60 * $60);
 $77 = Math_fround($61 * $61);
 $78 = Math_fround($62 * $62);
 $79 = Math_fround($71 + $75);
 $80 = Math_fround($72 + $76);
 $81 = Math_fround($73 + $77);
 $82 = Math_fround($74 + $78);
 $83 = (($params) + 16|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($params) + 20|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($params) + 24|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($params) + 28|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($79 * $84);
 $92 = Math_fround($80 * $86);
 $93 = Math_fround($81 * $88);
 $94 = Math_fround($82 * $90);
 $95 = (Math_fround(Math_sqrt((Math_fround($91)))));
 $96 = Math_fround(Math_fround(1.0) / $95);
 $97 = (Math_fround(Math_sqrt((Math_fround($92)))));
 $98 = Math_fround(Math_fround(1.0) / $97);
 $99 = (Math_fround(Math_sqrt((Math_fround($93)))));
 $100 = Math_fround(Math_fround(1.0) / $99);
 $101 = (Math_fround(Math_sqrt((Math_fround($94)))));
 $102 = Math_fround(Math_fround(1.0) / $101);
 $103 = Math_fround($91 * $96);
 $104 = Math_fround($92 * $98);
 $105 = Math_fround($93 * $100);
 $106 = Math_fround($94 * $102);
 $107 = (($params) + 32|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($params) + 36|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($params) + 40|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($params) + 44|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($108 - $103);
 $116 = Math_fround($110 - $104);
 $117 = Math_fround($112 - $105);
 $118 = Math_fround($114 - $106);
 $119 = (($pSrc0) + 16|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($119) + 4|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($119) + 8|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($pSrc1) + 16|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($125) + 4|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($125) + 8|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($pSrc2) + 16|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($131) + 4|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($131) + 8|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($pSrc3) + 16|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($137) + 4|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($137) + 8|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($posDensDstT) + 48|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = (($posDensDstT) + 52|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($posDensDstT) + 56|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = (($posDensDstT) + 60|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = (($params) + 112|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($params) + 116|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($params) + 120|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($params) + 124|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround($144 - $152);
 $160 = Math_fround($146 - $154);
 $161 = Math_fround($148 - $156);
 $162 = Math_fround($150 - $158);
 $163 = Math_fround($6 - $152);
 $164 = Math_fround($13 - $154);
 $165 = Math_fround($20 - $156);
 $166 = Math_fround($27 - $158);
 $167 = $159 > Math_fround(0.0);
 $$$i114 = $167 ? $159 : Math_fround(0.0);
 $168 = $160 > Math_fround(0.0);
 $169 = $168 ? $160 : Math_fround(0.0);
 $170 = $161 > Math_fround(0.0);
 $$1$i115 = $170 ? $161 : Math_fround(0.0);
 $171 = $162 > Math_fround(0.0);
 $172 = $171 ? $162 : Math_fround(0.0);
 $173 = $163 > Math_fround(0.0);
 $$$i = $173 ? $163 : Math_fround(0.0);
 $174 = $164 > Math_fround(0.0);
 $175 = $174 ? $164 : Math_fround(0.0);
 $176 = $165 > Math_fround(0.0);
 $$1$i = $176 ? $165 : Math_fround(0.0);
 $177 = $166 > Math_fround(0.0);
 $178 = $177 ? $166 : Math_fround(0.0);
 $179 = Math_fround($$$i114 + $$$i);
 $180 = Math_fround($169 + $175);
 $181 = Math_fround($$1$i115 + $$1$i);
 $182 = Math_fround($172 + $178);
 $183 = Math_fround($108 + $108);
 $184 = Math_fround($110 + $110);
 $185 = Math_fround($112 + $112);
 $186 = Math_fround($114 + $114);
 $187 = (($params) + 48|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($params) + 52|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($params) + 56|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($params) + 60|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround($96 * $188);
 $196 = Math_fround($98 * $190);
 $197 = Math_fround($100 * $192);
 $198 = Math_fround($102 * $194);
 $199 = Math_fround($103 + $195);
 $200 = Math_fround($104 + $196);
 $201 = Math_fround($105 + $197);
 $202 = Math_fround($106 + $198);
 $203 = Math_fround($199 - $183);
 $204 = Math_fround($200 - $184);
 $205 = Math_fround($201 - $185);
 $206 = Math_fround($202 - $186);
 $207 = (($params) + 80|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($params) + 84|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($params) + 88|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($params) + 92|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = Math_fround($203 * $208);
 $216 = Math_fround($204 * $210);
 $217 = Math_fround($205 * $212);
 $218 = Math_fround($206 * $214);
 $219 = Math_fround($179 * $215);
 $220 = Math_fround($180 * $216);
 $221 = Math_fround($181 * $217);
 $222 = Math_fround($182 * $218);
 $223 = Math_fround(HEAPF32[$params>>2]);
 $224 = (($params) + 4|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = (($params) + 8|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 $228 = (($params) + 12|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = Math_fround($219 * $223);
 $231 = Math_fround($220 * $225);
 $232 = Math_fround($221 * $227);
 $233 = Math_fround($222 * $229);
 $234 = Math_fround($35 * $230);
 $235 = Math_fround($36 * $231);
 $236 = Math_fround($37 * $232);
 $237 = Math_fround($38 * $233);
 $238 = Math_fround($47 * $230);
 $239 = Math_fround($48 * $231);
 $240 = Math_fround($49 * $232);
 $241 = Math_fround($50 * $233);
 $242 = Math_fround($59 * $230);
 $243 = Math_fround($60 * $231);
 $244 = Math_fround($61 * $232);
 $245 = Math_fround($62 * $233);
 $246 = (($params) + 96|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = (($params) + 100|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = (($params) + 104|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = (($params) + 108|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = Math_fround($115 * $247);
 $255 = Math_fround($116 * $249);
 $256 = Math_fround($117 * $251);
 $257 = Math_fround($118 * $253);
 $258 = Math_fround($223 * $254);
 $259 = Math_fround($225 * $255);
 $260 = Math_fround($227 * $256);
 $261 = Math_fround($229 * $257);
 $262 = Math_fround(HEAPF32[$velPressDstT>>2]);
 $263 = (($velPressDstT) + 4|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = (($velPressDstT) + 8|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = (($velPressDstT) + 12|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = Math_fround($120 - $262);
 $270 = Math_fround($126 - $264);
 $271 = Math_fround($132 - $266);
 $272 = Math_fround($138 - $268);
 $273 = (($velPressDstT) + 16|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 $275 = (($velPressDstT) + 20|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 $277 = (($velPressDstT) + 24|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = (($velPressDstT) + 28|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = Math_fround($122 - $274);
 $282 = Math_fround($128 - $276);
 $283 = Math_fround($134 - $278);
 $284 = Math_fround($140 - $280);
 $285 = (($velPressDstT) + 32|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = (($velPressDstT) + 36|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $289 = (($velPressDstT) + 40|0);
 $290 = Math_fround(HEAPF32[$289>>2]);
 $291 = (($velPressDstT) + 44|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = Math_fround($124 - $286);
 $294 = Math_fround($130 - $288);
 $295 = Math_fround($136 - $290);
 $296 = Math_fround($142 - $292);
 $297 = Math_fround($258 * $269);
 $298 = Math_fround($259 * $270);
 $299 = Math_fround($260 * $271);
 $300 = Math_fround($261 * $272);
 $301 = Math_fround($234 + $297);
 $302 = Math_fround($235 + $298);
 $303 = Math_fround($236 + $299);
 $304 = Math_fround($237 + $300);
 $305 = Math_fround($258 * $281);
 $306 = Math_fround($259 * $282);
 $307 = Math_fround($260 * $283);
 $308 = Math_fround($261 * $284);
 $309 = Math_fround($238 + $305);
 $310 = Math_fround($239 + $306);
 $311 = Math_fround($240 + $307);
 $312 = Math_fround($241 + $308);
 $313 = Math_fround($258 * $293);
 $314 = Math_fround($259 * $294);
 $315 = Math_fround($260 * $295);
 $316 = Math_fround($261 * $296);
 $317 = Math_fround($242 + $313);
 $318 = Math_fround($243 + $314);
 $319 = Math_fround($244 + $315);
 $320 = Math_fround($245 + $316);
 $321 = Math_fround(Math_fround(1.0) / $6);
 $322 = Math_fround(Math_fround(1.0) / $13);
 $323 = Math_fround(Math_fround(1.0) / $20);
 $324 = Math_fround(Math_fround(1.0) / $27);
 $325 = Math_fround($301 * $321);
 $326 = Math_fround($302 * $322);
 $327 = Math_fround($303 * $323);
 $328 = Math_fround($304 * $324);
 $329 = Math_fround($309 * $321);
 $330 = Math_fround($310 * $322);
 $331 = Math_fround($311 * $323);
 $332 = Math_fround($312 * $324);
 $333 = Math_fround($317 * $321);
 $334 = Math_fround($318 * $322);
 $335 = Math_fround($319 * $323);
 $336 = Math_fround($320 * $324);
 $337 = Math_fround(HEAPF32[$forceDstT>>2]);
 $338 = (($forceDstT) + 4|0);
 $339 = Math_fround(HEAPF32[$338>>2]);
 $340 = (($forceDstT) + 8|0);
 $341 = Math_fround(HEAPF32[$340>>2]);
 $342 = (($forceDstT) + 12|0);
 $343 = Math_fround(HEAPF32[$342>>2]);
 $344 = Math_fround($325 + $337);
 $345 = Math_fround($326 + $339);
 $346 = Math_fround($327 + $341);
 $347 = Math_fround($328 + $343);
 HEAPF32[$forceDstT>>2] = $344;
 HEAPF32[$338>>2] = $345;
 HEAPF32[$340>>2] = $346;
 HEAPF32[$342>>2] = $347;
 $348 = (($forceDstT) + 16|0);
 $349 = Math_fround(HEAPF32[$348>>2]);
 $350 = (($forceDstT) + 20|0);
 $351 = Math_fround(HEAPF32[$350>>2]);
 $352 = (($forceDstT) + 24|0);
 $353 = Math_fround(HEAPF32[$352>>2]);
 $354 = (($forceDstT) + 28|0);
 $355 = Math_fround(HEAPF32[$354>>2]);
 $356 = Math_fround($329 + $349);
 $357 = Math_fround($330 + $351);
 $358 = Math_fround($331 + $353);
 $359 = Math_fround($332 + $355);
 HEAPF32[$348>>2] = $356;
 HEAPF32[$350>>2] = $357;
 HEAPF32[$352>>2] = $358;
 HEAPF32[$354>>2] = $359;
 $360 = (($forceDstT) + 32|0);
 $361 = Math_fround(HEAPF32[$360>>2]);
 $362 = (($forceDstT) + 36|0);
 $363 = Math_fround(HEAPF32[$362>>2]);
 $364 = (($forceDstT) + 40|0);
 $365 = Math_fround(HEAPF32[$364>>2]);
 $366 = (($forceDstT) + 44|0);
 $367 = Math_fround(HEAPF32[$366>>2]);
 $368 = Math_fround($333 + $361);
 $369 = Math_fround($334 + $363);
 $370 = Math_fround($335 + $365);
 $371 = Math_fround($336 + $367);
 HEAPF32[$360>>2] = $368;
 HEAPF32[$362>>2] = $369;
 HEAPF32[$364>>2] = $370;
 HEAPF32[$366>>2] = $371;
 STACKTOP = sp;return;
}
function __ZN5physx26calcForce4_twoWay_onlyPtrsERNS_6shdfnd3aos6Mat44VES3_PNS_16PxsFluidParticleES5_S5_S5_RKS2_S7_RKNS1_5Vec4VERKNS_30PxsFluidDynamicsParametersSIMDE($forceDstT,$forceSrcT,$pSrc0,$pSrc1,$pSrc2,$pSrc3,$posDensDstT,$velPressDstT,$invDensityDst,$params) {
 $forceDstT = $forceDstT|0;
 $forceSrcT = $forceSrcT|0;
 $pSrc0 = $pSrc0|0;
 $pSrc1 = $pSrc1|0;
 $pSrc2 = $pSrc2|0;
 $pSrc3 = $pSrc3|0;
 $posDensDstT = $posDensDstT|0;
 $velPressDstT = $velPressDstT|0;
 $invDensityDst = $invDensityDst|0;
 $params = $params|0;
 var $$$i = Math_fround(0), $$$i126 = Math_fround(0), $$1$i = Math_fround(0), $$1$i127 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0;
 var $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0);
 var $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0);
 var $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0);
 var $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = Math_fround(0), $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0);
 var $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0;
 var $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = 0, $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$pSrc0>>2]);
 $1 = (($pSrc0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($pSrc0) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pSrc0) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$pSrc1>>2]);
 $8 = (($pSrc1) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($pSrc1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($pSrc1) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$pSrc2>>2]);
 $15 = (($pSrc2) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($pSrc2) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($pSrc2) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$pSrc3>>2]);
 $22 = (($pSrc3) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($pSrc3) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($pSrc3) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround(HEAPF32[$posDensDstT>>2]);
 $29 = (($posDensDstT) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($posDensDstT) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($posDensDstT) + 12|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($28 - $0);
 $36 = Math_fround($30 - $7);
 $37 = Math_fround($32 - $14);
 $38 = Math_fround($34 - $21);
 $39 = (($posDensDstT) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($posDensDstT) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($posDensDstT) + 24|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($posDensDstT) + 28|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($40 - $2);
 $48 = Math_fround($42 - $9);
 $49 = Math_fround($44 - $16);
 $50 = Math_fround($46 - $23);
 $51 = (($posDensDstT) + 32|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($posDensDstT) + 36|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($posDensDstT) + 40|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($posDensDstT) + 44|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($52 - $4);
 $60 = Math_fround($54 - $11);
 $61 = Math_fround($56 - $18);
 $62 = Math_fround($58 - $25);
 $63 = Math_fround($35 * $35);
 $64 = Math_fround($36 * $36);
 $65 = Math_fround($37 * $37);
 $66 = Math_fround($38 * $38);
 $67 = Math_fround($47 * $47);
 $68 = Math_fround($48 * $48);
 $69 = Math_fround($49 * $49);
 $70 = Math_fround($50 * $50);
 $71 = Math_fround($63 + $67);
 $72 = Math_fround($64 + $68);
 $73 = Math_fround($65 + $69);
 $74 = Math_fround($66 + $70);
 $75 = Math_fround($59 * $59);
 $76 = Math_fround($60 * $60);
 $77 = Math_fround($61 * $61);
 $78 = Math_fround($62 * $62);
 $79 = Math_fround($71 + $75);
 $80 = Math_fround($72 + $76);
 $81 = Math_fround($73 + $77);
 $82 = Math_fround($74 + $78);
 $83 = (($params) + 16|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($params) + 20|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($params) + 24|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($params) + 28|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($79 * $84);
 $92 = Math_fround($80 * $86);
 $93 = Math_fround($81 * $88);
 $94 = Math_fround($82 * $90);
 $95 = (Math_fround(Math_sqrt((Math_fround($91)))));
 $96 = Math_fround(Math_fround(1.0) / $95);
 $97 = (Math_fround(Math_sqrt((Math_fround($92)))));
 $98 = Math_fround(Math_fround(1.0) / $97);
 $99 = (Math_fround(Math_sqrt((Math_fround($93)))));
 $100 = Math_fround(Math_fround(1.0) / $99);
 $101 = (Math_fround(Math_sqrt((Math_fround($94)))));
 $102 = Math_fround(Math_fround(1.0) / $101);
 $103 = Math_fround($91 * $96);
 $104 = Math_fround($92 * $98);
 $105 = Math_fround($93 * $100);
 $106 = Math_fround($94 * $102);
 $107 = (($params) + 32|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($params) + 36|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($params) + 40|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($params) + 44|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($108 - $103);
 $116 = Math_fround($110 - $104);
 $117 = Math_fround($112 - $105);
 $118 = Math_fround($114 - $106);
 $119 = (($pSrc0) + 16|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($119) + 4|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($119) + 8|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($pSrc1) + 16|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($125) + 4|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($125) + 8|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($pSrc2) + 16|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($131) + 4|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($131) + 8|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($pSrc3) + 16|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($137) + 4|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($137) + 8|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($posDensDstT) + 48|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = (($posDensDstT) + 52|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($posDensDstT) + 56|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = (($posDensDstT) + 60|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = (($params) + 112|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($params) + 116|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($params) + 120|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($params) + 124|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround($144 - $152);
 $160 = Math_fround($146 - $154);
 $161 = Math_fround($148 - $156);
 $162 = Math_fround($150 - $158);
 $163 = Math_fround($6 - $152);
 $164 = Math_fround($13 - $154);
 $165 = Math_fround($20 - $156);
 $166 = Math_fround($27 - $158);
 $167 = $159 > Math_fround(0.0);
 $$$i126 = $167 ? $159 : Math_fround(0.0);
 $168 = $160 > Math_fround(0.0);
 $169 = $168 ? $160 : Math_fround(0.0);
 $170 = $161 > Math_fround(0.0);
 $$1$i127 = $170 ? $161 : Math_fround(0.0);
 $171 = $162 > Math_fround(0.0);
 $172 = $171 ? $162 : Math_fround(0.0);
 $173 = $163 > Math_fround(0.0);
 $$$i = $173 ? $163 : Math_fround(0.0);
 $174 = $164 > Math_fround(0.0);
 $175 = $174 ? $164 : Math_fround(0.0);
 $176 = $165 > Math_fround(0.0);
 $$1$i = $176 ? $165 : Math_fround(0.0);
 $177 = $166 > Math_fround(0.0);
 $178 = $177 ? $166 : Math_fround(0.0);
 $179 = Math_fround($$$i126 + $$$i);
 $180 = Math_fround($169 + $175);
 $181 = Math_fround($$1$i127 + $$1$i);
 $182 = Math_fround($172 + $178);
 $183 = Math_fround($108 + $108);
 $184 = Math_fround($110 + $110);
 $185 = Math_fround($112 + $112);
 $186 = Math_fround($114 + $114);
 $187 = (($params) + 48|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($params) + 52|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($params) + 56|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($params) + 60|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround($96 * $188);
 $196 = Math_fround($98 * $190);
 $197 = Math_fround($100 * $192);
 $198 = Math_fround($102 * $194);
 $199 = Math_fround($103 + $195);
 $200 = Math_fround($104 + $196);
 $201 = Math_fround($105 + $197);
 $202 = Math_fround($106 + $198);
 $203 = Math_fround($199 - $183);
 $204 = Math_fround($200 - $184);
 $205 = Math_fround($201 - $185);
 $206 = Math_fround($202 - $186);
 $207 = (($params) + 80|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($params) + 84|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($params) + 88|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($params) + 92|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = Math_fround($203 * $208);
 $216 = Math_fround($204 * $210);
 $217 = Math_fround($205 * $212);
 $218 = Math_fround($206 * $214);
 $219 = Math_fround($179 * $215);
 $220 = Math_fround($180 * $216);
 $221 = Math_fround($181 * $217);
 $222 = Math_fround($182 * $218);
 $223 = Math_fround(HEAPF32[$params>>2]);
 $224 = (($params) + 4|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = (($params) + 8|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 $228 = (($params) + 12|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = Math_fround($219 * $223);
 $231 = Math_fround($220 * $225);
 $232 = Math_fround($221 * $227);
 $233 = Math_fround($222 * $229);
 $234 = Math_fround($35 * $230);
 $235 = Math_fround($36 * $231);
 $236 = Math_fround($37 * $232);
 $237 = Math_fround($38 * $233);
 $238 = Math_fround($47 * $230);
 $239 = Math_fround($48 * $231);
 $240 = Math_fround($49 * $232);
 $241 = Math_fround($50 * $233);
 $242 = Math_fround($59 * $230);
 $243 = Math_fround($60 * $231);
 $244 = Math_fround($61 * $232);
 $245 = Math_fround($62 * $233);
 $246 = (($params) + 96|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = (($params) + 100|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = (($params) + 104|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = (($params) + 108|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = Math_fround($115 * $247);
 $255 = Math_fround($116 * $249);
 $256 = Math_fround($117 * $251);
 $257 = Math_fround($118 * $253);
 $258 = Math_fround($223 * $254);
 $259 = Math_fround($225 * $255);
 $260 = Math_fround($227 * $256);
 $261 = Math_fround($229 * $257);
 $262 = Math_fround(HEAPF32[$velPressDstT>>2]);
 $263 = (($velPressDstT) + 4|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = (($velPressDstT) + 8|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = (($velPressDstT) + 12|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = Math_fround($120 - $262);
 $270 = Math_fround($126 - $264);
 $271 = Math_fround($132 - $266);
 $272 = Math_fround($138 - $268);
 $273 = (($velPressDstT) + 16|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 $275 = (($velPressDstT) + 20|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 $277 = (($velPressDstT) + 24|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = (($velPressDstT) + 28|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = Math_fround($122 - $274);
 $282 = Math_fround($128 - $276);
 $283 = Math_fround($134 - $278);
 $284 = Math_fround($140 - $280);
 $285 = (($velPressDstT) + 32|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = (($velPressDstT) + 36|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $289 = (($velPressDstT) + 40|0);
 $290 = Math_fround(HEAPF32[$289>>2]);
 $291 = (($velPressDstT) + 44|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = Math_fround($124 - $286);
 $294 = Math_fround($130 - $288);
 $295 = Math_fround($136 - $290);
 $296 = Math_fround($142 - $292);
 $297 = Math_fround($258 * $269);
 $298 = Math_fround($259 * $270);
 $299 = Math_fround($260 * $271);
 $300 = Math_fround($261 * $272);
 $301 = Math_fround($234 + $297);
 $302 = Math_fround($235 + $298);
 $303 = Math_fround($236 + $299);
 $304 = Math_fround($237 + $300);
 $305 = Math_fround($258 * $281);
 $306 = Math_fround($259 * $282);
 $307 = Math_fround($260 * $283);
 $308 = Math_fround($261 * $284);
 $309 = Math_fround($238 + $305);
 $310 = Math_fround($239 + $306);
 $311 = Math_fround($240 + $307);
 $312 = Math_fround($241 + $308);
 $313 = Math_fround($258 * $293);
 $314 = Math_fround($259 * $294);
 $315 = Math_fround($260 * $295);
 $316 = Math_fround($261 * $296);
 $317 = Math_fround($242 + $313);
 $318 = Math_fround($243 + $314);
 $319 = Math_fround($244 + $315);
 $320 = Math_fround($245 + $316);
 $321 = Math_fround(HEAPF32[$invDensityDst>>2]);
 $322 = (($invDensityDst) + 4|0);
 $323 = Math_fround(HEAPF32[$322>>2]);
 $324 = (($invDensityDst) + 8|0);
 $325 = Math_fround(HEAPF32[$324>>2]);
 $326 = (($invDensityDst) + 12|0);
 $327 = Math_fround(HEAPF32[$326>>2]);
 $328 = Math_fround(HEAPF32[$forceSrcT>>2]);
 $329 = (($forceSrcT) + 4|0);
 $330 = Math_fround(HEAPF32[$329>>2]);
 $331 = (($forceSrcT) + 8|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = (($forceSrcT) + 12|0);
 $334 = Math_fround(HEAPF32[$333>>2]);
 $335 = Math_fround($301 * $321);
 $336 = Math_fround($302 * $323);
 $337 = Math_fround($303 * $325);
 $338 = Math_fround($304 * $327);
 $339 = Math_fround($328 - $335);
 $340 = Math_fround($330 - $336);
 $341 = Math_fround($332 - $337);
 $342 = Math_fround($334 - $338);
 HEAPF32[$forceSrcT>>2] = $339;
 HEAPF32[$329>>2] = $340;
 HEAPF32[$331>>2] = $341;
 HEAPF32[$333>>2] = $342;
 $343 = Math_fround(HEAPF32[$invDensityDst>>2]);
 $344 = Math_fround(HEAPF32[$322>>2]);
 $345 = Math_fround(HEAPF32[$324>>2]);
 $346 = Math_fround(HEAPF32[$326>>2]);
 $347 = (($forceSrcT) + 16|0);
 $348 = Math_fround(HEAPF32[$347>>2]);
 $349 = (($forceSrcT) + 20|0);
 $350 = Math_fround(HEAPF32[$349>>2]);
 $351 = (($forceSrcT) + 24|0);
 $352 = Math_fround(HEAPF32[$351>>2]);
 $353 = (($forceSrcT) + 28|0);
 $354 = Math_fround(HEAPF32[$353>>2]);
 $355 = Math_fround($309 * $343);
 $356 = Math_fround($310 * $344);
 $357 = Math_fround($311 * $345);
 $358 = Math_fround($312 * $346);
 $359 = Math_fround($348 - $355);
 $360 = Math_fround($350 - $356);
 $361 = Math_fround($352 - $357);
 $362 = Math_fround($354 - $358);
 HEAPF32[$347>>2] = $359;
 HEAPF32[$349>>2] = $360;
 HEAPF32[$351>>2] = $361;
 HEAPF32[$353>>2] = $362;
 $363 = Math_fround(HEAPF32[$invDensityDst>>2]);
 $364 = Math_fround(HEAPF32[$322>>2]);
 $365 = Math_fround(HEAPF32[$324>>2]);
 $366 = Math_fround(HEAPF32[$326>>2]);
 $367 = (($forceSrcT) + 32|0);
 $368 = Math_fround(HEAPF32[$367>>2]);
 $369 = (($forceSrcT) + 36|0);
 $370 = Math_fround(HEAPF32[$369>>2]);
 $371 = (($forceSrcT) + 40|0);
 $372 = Math_fround(HEAPF32[$371>>2]);
 $373 = (($forceSrcT) + 44|0);
 $374 = Math_fround(HEAPF32[$373>>2]);
 $375 = Math_fround($317 * $363);
 $376 = Math_fround($318 * $364);
 $377 = Math_fround($319 * $365);
 $378 = Math_fround($320 * $366);
 $379 = Math_fround($368 - $375);
 $380 = Math_fround($370 - $376);
 $381 = Math_fround($372 - $377);
 $382 = Math_fround($374 - $378);
 HEAPF32[$367>>2] = $379;
 HEAPF32[$369>>2] = $380;
 HEAPF32[$371>>2] = $381;
 HEAPF32[$373>>2] = $382;
 $383 = Math_fround(Math_fround(1.0) / $6);
 $384 = Math_fround(Math_fround(1.0) / $13);
 $385 = Math_fround(Math_fround(1.0) / $20);
 $386 = Math_fround(Math_fround(1.0) / $27);
 $387 = Math_fround(HEAPF32[$forceDstT>>2]);
 $388 = (($forceDstT) + 4|0);
 $389 = Math_fround(HEAPF32[$388>>2]);
 $390 = (($forceDstT) + 8|0);
 $391 = Math_fround(HEAPF32[$390>>2]);
 $392 = (($forceDstT) + 12|0);
 $393 = Math_fround(HEAPF32[$392>>2]);
 $394 = Math_fround($301 * $383);
 $395 = Math_fround($302 * $384);
 $396 = Math_fround($303 * $385);
 $397 = Math_fround($304 * $386);
 $398 = Math_fround($394 + $387);
 $399 = Math_fround($395 + $389);
 $400 = Math_fround($396 + $391);
 $401 = Math_fround($397 + $393);
 HEAPF32[$forceDstT>>2] = $398;
 HEAPF32[$388>>2] = $399;
 HEAPF32[$390>>2] = $400;
 HEAPF32[$392>>2] = $401;
 $402 = (($forceDstT) + 16|0);
 $403 = Math_fround(HEAPF32[$402>>2]);
 $404 = (($forceDstT) + 20|0);
 $405 = Math_fround(HEAPF32[$404>>2]);
 $406 = (($forceDstT) + 24|0);
 $407 = Math_fround(HEAPF32[$406>>2]);
 $408 = (($forceDstT) + 28|0);
 $409 = Math_fround(HEAPF32[$408>>2]);
 $410 = Math_fround($309 * $383);
 $411 = Math_fround($310 * $384);
 $412 = Math_fround($311 * $385);
 $413 = Math_fround($312 * $386);
 $414 = Math_fround($410 + $403);
 $415 = Math_fround($411 + $405);
 $416 = Math_fround($412 + $407);
 $417 = Math_fround($413 + $409);
 HEAPF32[$402>>2] = $414;
 HEAPF32[$404>>2] = $415;
 HEAPF32[$406>>2] = $416;
 HEAPF32[$408>>2] = $417;
 $418 = (($forceDstT) + 32|0);
 $419 = Math_fround(HEAPF32[$418>>2]);
 $420 = (($forceDstT) + 36|0);
 $421 = Math_fround(HEAPF32[$420>>2]);
 $422 = (($forceDstT) + 40|0);
 $423 = Math_fround(HEAPF32[$422>>2]);
 $424 = (($forceDstT) + 44|0);
 $425 = Math_fround(HEAPF32[$424>>2]);
 $426 = Math_fround($317 * $383);
 $427 = Math_fround($318 * $384);
 $428 = Math_fround($319 * $385);
 $429 = Math_fround($320 * $386);
 $430 = Math_fround($426 + $419);
 $431 = Math_fround($427 + $421);
 $432 = Math_fround($428 + $423);
 $433 = Math_fround($429 + $425);
 HEAPF32[$418>>2] = $430;
 HEAPF32[$420>>2] = $431;
 HEAPF32[$422>>2] = $432;
 HEAPF32[$424>>2] = $433;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a4557() {
 var $0 = 0, $1 = 0, $exitcond$i$i = 0, $i$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$01$i$i = 0;
 while(1) {
  $0 = (496632 + ($i$01$i$i<<2)|0);
  HEAP32[$0>>2] = $i$01$i$i;
  $1 = (($i$01$i$i) + 1)|0;
  $exitcond$i$i = ($1|0)==(512);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$01$i$i = $1;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx19PxsFluidSpatialHashC2Ejfjb($this,$numHashBuckets,$cellSizeInv,$packetMultLog,$supportSections) {
 $this = $this|0;
 $numHashBuckets = $numHashBuckets|0;
 $cellSizeInv = Math_fround($cellSizeInv);
 $packetMultLog = $packetMultLog|0;
 $supportSections = $supportSections|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $numHashBuckets;
 $4 = (($this) + 12|0);
 HEAPF32[$4>>2] = $cellSizeInv;
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = $packetMultLog;
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = $numHashBuckets << 4;
 $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$7,499128,54)|0);
 HEAP32[$this>>2] = $8;
 if (!($supportSections)) {
  STACKTOP = sp;return;
 }
 $9 = ($numHashBuckets*216)|0;
 $10 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$9,499128,57)|0);
 HEAP32[$6>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN5physx19PxsFluidSpatialHashD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$4);
 STACKTOP = sp;return;
}
function __ZN5physx19PxsFluidSpatialHash16updatePacketHashERjPjPNS_16PxsFluidParticleERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjPNS_10PxBaseTaskE($this,$numSorted,$sortedIndices,$particles,$particleMap,$validParticleRange,$continuation) {
 $this = $this|0;
 $numSorted = $numSorted|0;
 $sortedIndices = $sortedIndices|0;
 $particles = $particles|0;
 $particleMap = $particleMap|0;
 $validParticleRange = $validParticleRange|0;
 $continuation = $continuation|0;
 var $$lcssa$i$i$ph = 0, $$lcssa$i$i47 = 0, $$ph = 0, $$ph1028 = 0, $$ph1129 = 0, $$ph8 = 0, $$ph9 = 0, $$pre$i$i$i = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond44 = 0, $numPackets$0$lcssa = 0, $numPackets$0$ph32 = 0, $numPackets$018 = 0, $numPackets$1 = 0, $numPackets$2 = 0, $numParticles$06 = 0, $numParticles$1 = 0, $p$026 = 0, $p2$07 = 0, $particleIndex$0$ph1230 = 0, $particleIndex$016 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $p$026 = 0;
 while(1) {
  $3 = ((($2) + ($p$026<<4)|0) + 8|0);
  HEAP32[$3>>2] = -1;
  $4 = (($p$026) + 1)|0;
  $exitcond44 = ($4|0)==(1024);
  if ($exitcond44) {
   break;
  } else {
   $p$026 = $4;
  }
 }
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = 1 << $6;
 $8 = (($this) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (Math_fround(($7>>>0)));
 $11 = Math_fround($9 / $10);
 $12 = (($particleMap) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 6;
 HEAP32[$numSorted>>2] = 0;
 $15 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$14,499128,107)|0);
 $16 = HEAP32[$12>>2]|0;
 $17 = $16 & 2147483647;
 $18 = ($17|0)==(0);
 L4: do {
  if ($18) {
   $numPackets$0$lcssa = 0;
  } else {
   $$pre$i$i$i = HEAP32[$particleMap>>2]|0;
   $20 = 0;
   while(1) {
    $19 = (($$pre$i$i$i) + ($20<<2)|0);
    $21 = HEAP32[$19>>2]|0;
    $22 = ($21|0)==(0);
    if (!($22)) {
     break;
    }
    $23 = (($20) + 1)|0;
    $24 = ($23>>>0)<($17>>>0);
    if ($24) {
     $20 = $23;
    } else {
     $numPackets$0$lcssa = 0;
     break L4;
    }
   }
   $25 = $20 << 5;
   $26 = (0 - ($21))|0;
   $27 = $21 & $26;
   $28 = Math_imul($27, 125613361)|0;
   $29 = $28 >>> 27;
   $30 = (412480 + ($29<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31 | $25;
   $33 = (($21) + -1)|0;
   $34 = $33 & $21;
   $35 = ($34|0)==(0);
   L10: do {
    if ($35) {
     $37 = $20;
     while(1) {
      $36 = (($37) + 1)|0;
      $38 = ($36>>>0)<($17>>>0);
      if (!($38)) {
       $$ph8 = $36;$$ph9 = 0;
       break L10;
      }
      $39 = (($$pre$i$i$i) + ($36<<2)|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)==(0);
      if ($41) {
       $37 = $36;
      } else {
       $$ph8 = $36;$$ph9 = $40;
       break;
      }
     }
    } else {
     $$ph8 = $20;$$ph9 = $34;
    }
   } while(0);
   $42 = ($32|0)==(-1);
   if ($42) {
    $numPackets$0$lcssa = 0;
   } else {
    $43 = (($this) + 8|0);
    $$ph1028 = $$ph8;$$ph1129 = $$ph9;$numPackets$0$ph32 = 0;$particleIndex$0$ph1230 = $32;
    while(1) {
     $46 = $$ph1028 << 5;
     $123 = $$ph1129;$numPackets$018 = $numPackets$0$ph32;$particleIndex$016 = $particleIndex$0$ph1230;
     while(1) {
      $47 = ((($particles) + ($particleIndex$016<<5)|0) + 28|0);
      $48 = HEAP16[$47>>1]|0;
      $49 = $48 & 16;
      $50 = ($49<<16>>16)==(0);
      L20: do {
       if ($50) {
        $51 = (($particles) + ($particleIndex$016<<5)|0);
        $52 = Math_fround(HEAPF32[$51>>2]);
        $53 = Math_fround($11 * $52);
        $54 = ((($particles) + ($particleIndex$016<<5)|0) + 4|0);
        $55 = Math_fround(HEAPF32[$54>>2]);
        $56 = Math_fround($11 * $55);
        $57 = ((($particles) + ($particleIndex$016<<5)|0) + 8|0);
        $58 = Math_fround(HEAPF32[$57>>2]);
        $59 = Math_fround($11 * $58);
        $60 = (Math_fround(Math_floor((Math_fround($53)))));
        $61 = (~~(($60)));
        $62 = (Math_fround(Math_floor((Math_fround($56)))));
        $63 = (~~(($62)));
        $64 = (Math_fround(Math_floor((Math_fround($59)))));
        $65 = (~~(($64)));
        $66 = HEAP32[$this>>2]|0;
        $67 = HEAP32[$43>>2]|0;
        $68 = $61 << 16 >> 16;
        $69 = $63 << 16 >> 16;
        $70 = ($69*101)|0;
        $71 = (($70) + ($68))|0;
        $72 = $65 << 16 >> 16;
        $73 = ($72*7919)|0;
        $74 = (($71) + ($73))|0;
        $75 = (($67) + -1)|0;
        $76 = $74 & $75;
        $77 = ((($66) + ($76<<4)|0) + 8|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = ($78|0)==(-1);
        L22: do {
         if ($79) {
          $$lcssa$i$i$ph = $76;
          label = 20;
         } else {
          $$pre$pre = $78;$81 = $76;
          while(1) {
           $80 = (($66) + ($81<<4)|0);
           $82 = HEAP16[$80>>1]|0;
           $83 = ($61<<16>>16)==($82<<16>>16);
           if ($83) {
            $84 = ((($66) + ($81<<4)|0) + 2|0);
            $85 = HEAP16[$84>>1]|0;
            $86 = ($63<<16>>16)==($85<<16>>16);
            if ($86) {
             $87 = ((($66) + ($81<<4)|0) + 4|0);
             $88 = HEAP16[$87>>1]|0;
             $89 = ($65<<16>>16)==($88<<16>>16);
             if ($89) {
              break;
             }
            }
           }
           $90 = (($81) + 1)|0;
           $91 = $90 & $75;
           $92 = ((($66) + ($91<<4)|0) + 8|0);
           $93 = HEAP32[$92>>2]|0;
           $94 = ($93|0)==(-1);
           if ($94) {
            $$lcssa$i$i$ph = $91;
            label = 20;
            break L22;
           } else {
            $$pre$pre = $93;$81 = $91;
           }
          }
          $98 = $81&65535;
          $99 = (($15) + ($particleIndex$016<<1)|0);
          HEAP16[$99>>1] = $98;
          $100 = ((($66) + ($81<<4)|0) + 8|0);
          $101 = ($$pre$pre|0)==(-1);
          if ($101) {
           $$lcssa$i$i47 = $81;$115 = $100;
           label = 22;
          } else {
           $118 = $$pre$pre;$119 = $100;$numPackets$1 = $numPackets$018;
          }
         }
        } while(0);
        if ((label|0) == 20) {
         label = 0;
         $95 = $$lcssa$i$i$ph&65535;
         $96 = (($15) + ($particleIndex$016<<1)|0);
         HEAP16[$96>>1] = $95;
         $97 = ((($66) + ($$lcssa$i$i$ph<<4)|0) + 8|0);
         $$lcssa$i$i47 = $$lcssa$i$i$ph;$115 = $97;
         label = 22;
        }
        do {
         if ((label|0) == 22) {
          label = 0;
          $102 = ($numPackets$018>>>0)>(923);
          if ($102) {
           $103 = HEAP16[$47>>1]|0;
           $104 = $103&65535;
           $105 = $104 | 16;
           $106 = $105&65535;
           HEAP16[$47>>1] = $106;
           $107 = ((($particles) + ($particleIndex$016<<5)|0) + 30|0);
           $108 = HEAP16[$107>>1]|0;
           $109 = $108&65535;
           $110 = $109 & 65532;
           $111 = $110&65535;
           HEAP16[$107>>1] = $111;
           $numPackets$2 = $numPackets$018;
           break L20;
          } else {
           $112 = (($66) + ($$lcssa$i$i47<<4)|0);
           HEAP16[$112>>1] = $61;
           $113 = ((($66) + ($$lcssa$i$i47<<4)|0) + 2|0);
           HEAP16[$113>>1] = $63;
           $114 = ((($66) + ($$lcssa$i$i47<<4)|0) + 4|0);
           HEAP16[$114>>1] = $65;
           HEAP32[$115>>2] = 0;
           $116 = (($numPackets$018) + 1)|0;
           $118 = 0;$119 = $115;$numPackets$1 = $116;
           break;
          }
         }
        } while(0);
        $117 = (($118) + 1)|0;
        HEAP32[$119>>2] = $117;
        $120 = HEAP32[$numSorted>>2]|0;
        $121 = (($120) + 1)|0;
        HEAP32[$numSorted>>2] = $121;
        $numPackets$2 = $numPackets$1;
       } else {
        $numPackets$2 = $numPackets$018;
       }
      } while(0);
      $122 = ($123|0)==(0);
      if ($122) {
       $numPackets$0$lcssa = $numPackets$2;
       break L4;
      }
      $125 = (0 - ($123))|0;
      $126 = $123 & $125;
      $127 = Math_imul($126, 125613361)|0;
      $128 = $127 >>> 27;
      $129 = (412480 + ($128<<2)|0);
      $130 = HEAP32[$129>>2]|0;
      $45 = $130 | $46;
      $131 = (($123) + -1)|0;
      $132 = $131 & $123;
      $133 = HEAP32[$12>>2]|0;
      $134 = $133 & 2147483647;
      $135 = ($132|0)==(0);
      if ($135) {
       $137 = $$ph1028;
       break;
      }
      $124 = ($45|0)==(-1);
      if ($124) {
       $numPackets$0$lcssa = $numPackets$2;
       break L4;
      } else {
       $123 = $132;$numPackets$018 = $numPackets$2;$particleIndex$016 = $45;
      }
     }
     while(1) {
      $136 = (($137) + 1)|0;
      $138 = ($136>>>0)<($134>>>0);
      if (!($138)) {
       $$ph = 0;
       break;
      }
      $139 = HEAP32[$particleMap>>2]|0;
      $140 = (($139) + ($136<<2)|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = ($141|0)==(0);
      if ($142) {
       $137 = $136;
      } else {
       $$ph = $141;
       break;
      }
     }
     $44 = ($45|0)==(-1);
     if ($44) {
      $numPackets$0$lcssa = $numPackets$2;
      break;
     } else {
      $$ph1028 = $136;$$ph1129 = $$ph;$numPackets$0$ph32 = $numPackets$2;$particleIndex$0$ph1230 = $45;
     }
    }
   }
  }
 } while(0);
 $143 = (($this) + 4|0);
 HEAP32[$143>>2] = $numPackets$0$lcssa;
 $144 = HEAP32[$this>>2]|0;
 $numParticles$06 = 0;$p2$07 = 0;
 while(1) {
  $145 = ((($144) + ($p2$07<<4)|0) + 8|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = ($146|0)==(-1);
  if ($147) {
   $numParticles$1 = $numParticles$06;
  } else {
   $148 = ((($144) + ($p2$07<<4)|0) + 12|0);
   HEAP32[$148>>2] = $numParticles$06;
   $149 = (($146) + ($numParticles$06))|0;
   HEAP32[$145>>2] = 0;
   $numParticles$1 = $149;
  }
  $150 = (($p2$07) + 1)|0;
  $exitcond = ($150|0)==(1024);
  if ($exitcond) {
   break;
  } else {
   $numParticles$06 = $numParticles$1;$p2$07 = $150;
  }
 }
 __ZN5physx19PxsFluidSpatialHash31reorderParticleIndicesToPacketsEPjjPKNS_16PxsFluidParticleERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPt($this,$sortedIndices,$numParticles$1,$particles,$particleMap,$15);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$15);
 $151 = HEAP32[$continuation>>2]|0;
 $152 = (($151) + 20|0);
 $153 = HEAP32[$152>>2]|0;
 FUNCTION_TABLE_vi[$153 & 4095]($continuation);
 STACKTOP = sp;return;
}
function __ZN5physx19PxsFluidSpatialHash31reorderParticleIndicesToPacketsEPjjPKNS_16PxsFluidParticleERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPt($this,$sortedIndices,$numHashedParticles,$particles,$particleMap,$hashKeyArray) {
 $this = $this|0;
 $sortedIndices = $sortedIndices|0;
 $numHashedParticles = $numHashedParticles|0;
 $particles = $particles|0;
 $particleMap = $particleMap|0;
 $hashKeyArray = $hashKeyArray|0;
 var $$ph = 0, $$ph6 = 0, $$ph7 = 0, $$ph821 = 0, $$ph922 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $particleIndex$0$ph1023 = 0, $particleIndex$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($particleMap) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $$pre$i$i$i = HEAP32[$particleMap>>2]|0;
 $5 = 0;
 while(1) {
  $4 = (($$pre$i$i$i) + ($5<<2)|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = ($6|0)==(0);
  if (!($7)) {
   break;
  }
  $8 = (($5) + 1)|0;
  $9 = ($8>>>0)<($2>>>0);
  if ($9) {
   $5 = $8;
  } else {
   label = 19;
   break;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return;
 }
 $10 = $5 << 5;
 $11 = (0 - ($6))|0;
 $12 = $6 & $11;
 $13 = Math_imul($12, 125613361)|0;
 $14 = $13 >>> 27;
 $15 = (412480 + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 | $10;
 $18 = (($6) + -1)|0;
 $19 = $18 & $6;
 $20 = ($19|0)==(0);
 L10: do {
  if ($20) {
   $22 = $5;
   while(1) {
    $21 = (($22) + 1)|0;
    $23 = ($21>>>0)<($2>>>0);
    if (!($23)) {
     $$ph6 = $21;$$ph7 = 0;
     break L10;
    }
    $24 = (($$pre$i$i$i) + ($21<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(0);
    if ($26) {
     $22 = $21;
    } else {
     $$ph6 = $21;$$ph7 = $25;
     break;
    }
   }
  } else {
   $$ph6 = $5;$$ph7 = $19;
  }
 } while(0);
 $27 = ($17|0)==(-1);
 if ($27) {
  STACKTOP = sp;return;
 }
 $$ph821 = $$ph6;$$ph922 = $$ph7;$particleIndex$0$ph1023 = $17;
 L18: while(1) {
  $30 = $$ph821 << 5;
  $48 = $$ph922;$particleIndex$013 = $particleIndex$0$ph1023;
  while(1) {
   $31 = ((($particles) + ($particleIndex$013<<5)|0) + 28|0);
   $32 = HEAP16[$31>>1]|0;
   $33 = $32 & 16;
   $34 = ($33<<16>>16)==(0);
   if ($34) {
    $35 = (($hashKeyArray) + ($particleIndex$013<<1)|0);
    $36 = HEAP16[$35>>1]|0;
    $37 = $36&65535;
    $38 = HEAP32[$this>>2]|0;
    $39 = ((($38) + ($37<<4)|0) + 12|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ((($38) + ($37<<4)|0) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + ($40))|0;
    $44 = (($sortedIndices) + ($43<<2)|0);
    HEAP32[$44>>2] = $particleIndex$013;
    $45 = HEAP32[$41>>2]|0;
    $46 = (($45) + 1)|0;
    HEAP32[$41>>2] = $46;
   }
   $47 = ($48|0)==(0);
   if ($47) {
    label = 19;
    break L18;
   }
   $50 = (0 - ($48))|0;
   $51 = $48 & $50;
   $52 = Math_imul($51, 125613361)|0;
   $53 = $52 >>> 27;
   $54 = (412480 + ($53<<2)|0);
   $55 = HEAP32[$54>>2]|0;
   $29 = $55 | $30;
   $56 = (($48) + -1)|0;
   $57 = $56 & $48;
   $58 = HEAP32[$0>>2]|0;
   $59 = $58 & 2147483647;
   $60 = ($57|0)==(0);
   if ($60) {
    $62 = $$ph821;
    break;
   }
   $49 = ($29|0)==(-1);
   if ($49) {
    label = 19;
    break L18;
   } else {
    $48 = $57;$particleIndex$013 = $29;
   }
  }
  while(1) {
   $61 = (($62) + 1)|0;
   $63 = ($61>>>0)<($59>>>0);
   if (!($63)) {
    $$ph = 0;
    break;
   }
   $64 = HEAP32[$particleMap>>2]|0;
   $65 = (($64) + ($61<<2)|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0);
   if ($67) {
    $62 = $61;
   } else {
    $$ph = $66;
    break;
   }
  }
  $28 = ($29|0)==(-1);
  if ($28) {
   label = 19;
   break;
  } else {
   $$ph821 = $61;$$ph922 = $$ph;$particleIndex$0$ph1023 = $29;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx19PxsFluidSpatialHash20updatePacketSectionsEPjPNS_16PxsFluidParticleEPNS_10PxBaseTaskE($this,$particleIndices,$particles,$continuation) {
 $this = $this|0;
 $particleIndices = $particleIndices|0;
 $particles = $particles|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = (($this) + 16|0);
 $p$01 = 0;
 while(1) {
  $2 = HEAP32[$this>>2]|0;
  $3 = ((($2) + ($p$01<<4)|0) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  if (!((($4|0) == 0) | (($4|0) == -1))) {
   $5 = (($2) + ($p$01<<4)|0);
   $6 = HEAP32[$0>>2]|0;
   $7 = (($6) + (($p$01*216)|0)|0);
   $8 = HEAP32[$1>>2]|0;
   __ZN5physx19PxsFluidSpatialHash19buildPacketSectionsERKNS_15PxsParticleCellERNS_22PxsFluidPacketSectionsEjPNS_16PxsFluidParticleEPj($this,$5,$7,$8,$particles,$particleIndices);
  }
  $9 = (($p$01) + 1)|0;
  $exitcond = ($9|0)==(1024);
  if ($exitcond) {
   break;
  } else {
   $p$01 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx19PxsFluidSpatialHash19buildPacketSectionsERKNS_15PxsParticleCellERNS_22PxsFluidPacketSectionsEjPNS_16PxsFluidParticleEPj($this,$packet,$sections,$packetMultLog,$particles,$particleIndices) {
 $this = $this|0;
 $packet = $packet|0;
 $sections = $sections|0;
 $packetMultLog = $packetMultLog|0;
 $particles = $particles|0;
 $particleIndices = $particleIndices|0;
 var $$ = 0, $$$i = 0, $$$i1 = 0, $$05$i = 0, $$1$lcssa$i = 0, $$12$i = 0, $$pre = 0, $$pre$i = 0, $$pre15 = 0, $$pre16 = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond14 = 0, $indvars$iv = 0, $indvars$iv$i = 0, $indvars$iv$next = 0, $indvars$iv$next$i = 0, $indvars$iv$next13 = 0;
 var $indvars$iv$next9$i = 0, $indvars$iv12 = 0, $indvars$iv8$i = 0, $p$01$i = 0, $p$05 = 0, $pSectionIndexBuf$07 = 0, $pSectionIndexBuf$1$lcssa = 0, $pSectionIndexBuf$16 = 0, $particleIndex1$03 = 0, $s$04 = 0, $scevgep$sum = 0, $scevgep$sum$i = 0, $scevgep11 = 0, $scevgep7$i = 0, $sectionIndex$0$$i = 0, $sectionIndex$0$i = 0, $sectionIndex$1$$i = 0, $sectionIndex$1$i = 0, $sectionIndexBuf = 0, $sext$i = 0;
 var $sext1$i = 0, $sext2$i = 0, $startIdx$04$i = 0, $startIdx$04$i$phi = 0, $startIdx$09 = 0, $startIdx$09$phi = 0, $tmpIndexBuffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sectionIndexBuf = sp + 8|0;
 $0 = sp + 17|0;
 $tmpIndexBuffer = sp;
 $1 = sp + 16|0;
 $2 = 1 << $packetMultLog;
 $3 = HEAP16[$packet>>1]|0;
 $4 = $3 << 16 >> 16;
 $5 = $4 << $packetMultLog;
 $6 = (($packet) + 2|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 << 16 >> 16;
 $9 = $8 << $packetMultLog;
 $10 = (($packet) + 4|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = $11 << 16 >> 16;
 $13 = $12 << $packetMultLog;
 _memset(($sections|0),0,216)|0;
 $14 = (($packet) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 511;
 $17 = ($16|0)==(0);
 $$ = $17 ? 512 : $16;
 $18 = (($packet) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($particleIndices) + ($19<<2)|0);
 $21 = $15 << 2;
 $22 = ($21>>>0)>(1024);
 $23 = (($sectionIndexBuf) + 4|0);
 $24 = $22&1;
 HEAP8[$23>>0] = $24;
 if ($22) {
  $25 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$21,499128,268)|0);
  HEAP32[$sectionIndexBuf>>2] = $25;
  $$pre = HEAP32[$14>>2]|0;
  $137 = $25;$28 = $$pre;
 } else {
  $26 = STACKTOP; STACKTOP = STACKTOP + ((((1*$21)|0)+15)&-16)|0;;
  HEAP32[$sectionIndexBuf>>2] = $26;
  $137 = $26;$28 = $15;
 }
 $27 = ($$>>>0)>($28>>>0);
 if (!($27)) {
  $29 = (($this) + 12|0);
  $30 = $5 & 65535;
  $31 = $9 & 65535;
  $32 = $13 & 65535;
  $33 = (($$) + -1)|0;
  $138 = $28;$indvars$iv = $33;$indvars$iv12 = $$;$pSectionIndexBuf$07 = $137;$startIdx$09 = 0;
  while(1) {
   $34 = ($startIdx$09>>>0)<($indvars$iv12>>>0);
   if ($34) {
    $35 = Math_fround(HEAPF32[$29>>2]);
    $36 = (($indvars$iv) - ($startIdx$09))|0;
    $p$05 = $startIdx$09;$pSectionIndexBuf$16 = $pSectionIndexBuf$07;
    while(1) {
     $$sum = (($p$05) + ($19))|0;
     $37 = (($particleIndices) + ($$sum<<2)|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($particles) + ($38<<5)|0);
     $40 = Math_fround(HEAPF32[$39>>2]);
     $41 = Math_fround($35 * $40);
     $42 = ((($particles) + ($38<<5)|0) + 4|0);
     $43 = Math_fround(HEAPF32[$42>>2]);
     $44 = Math_fround($35 * $43);
     $45 = ((($particles) + ($38<<5)|0) + 8|0);
     $46 = Math_fround(HEAPF32[$45>>2]);
     $47 = Math_fround($35 * $46);
     $48 = (Math_fround(Math_floor((Math_fround($41)))));
     $49 = (~~(($48)));
     $50 = (Math_fround(Math_floor((Math_fround($44)))));
     $51 = (~~(($50)));
     $52 = (Math_fround(Math_floor((Math_fround($47)))));
     $53 = (~~(($52)));
     $54 = $49&65535;
     $55 = (($54) - ($30))|0;
     $56 = $51&65535;
     $57 = (($56) - ($31))|0;
     $58 = $57&65535;
     $59 = $53&65535;
     $60 = (($59) - ($32))|0;
     $61 = $60&65535;
     $sext$i = $55 << 16;
     $62 = $sext$i >> 16;
     $63 = (($62) + 1)|0;
     $64 = ($63|0)==($2|0);
     if ($64) {
      $sectionIndex$0$i = 9;
     } else {
      $65 = $55&65535;
      $66 = ($65<<16>>16)==(0);
      $$$i1 = $66 ? 0 : 18;
      $sectionIndex$0$i = $$$i1;
     }
     $sext1$i = $57 << 16;
     $67 = $sext1$i >> 16;
     $68 = (($67) + 1)|0;
     $69 = ($68|0)==($2|0);
     if ($69) {
      $70 = (($sectionIndex$0$i) + 3)|0;
      $sectionIndex$1$i = $70;
     } else {
      $71 = ($58<<16>>16)==(0);
      $72 = (($sectionIndex$0$i) + 6)|0;
      $sectionIndex$0$$i = $71 ? $sectionIndex$0$i : $72;
      $sectionIndex$1$i = $sectionIndex$0$$i;
     }
     $sext2$i = $60 << 16;
     $73 = $sext2$i >> 16;
     $74 = (($73) + 1)|0;
     $75 = ($74|0)==($2|0);
     if ($75) {
      $76 = (($sectionIndex$1$i) + 1)|0;
      $80 = $76;
     } else {
      $77 = ($61<<16>>16)==(0);
      $78 = (($sectionIndex$1$i) + 2)|0;
      $sectionIndex$1$$i = $77 ? $sectionIndex$1$i : $78;
      $80 = $sectionIndex$1$$i;
     }
     $79 = $80&65535;
     $81 = (($pSectionIndexBuf$16) + 2|0);
     HEAP16[$pSectionIndexBuf$16>>1] = $79;
     $82 = (($sections) + ($80<<2)|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (($83) + 1)|0;
     HEAP32[$82>>2] = $84;
     $85 = (($p$05) + 1)|0;
     $exitcond14 = ($85|0)==($indvars$iv12|0);
     if ($exitcond14) {
      break;
     } else {
      $p$05 = $85;$pSectionIndexBuf$16 = $81;
     }
    }
    $scevgep$sum = (($36) + 1)|0;
    $scevgep11 = (($pSectionIndexBuf$07) + ($scevgep$sum<<1)|0);
    $$pre16 = HEAP32[$14>>2]|0;
    $87 = $$pre16;$pSectionIndexBuf$1$lcssa = $scevgep11;
   } else {
    $87 = $138;$pSectionIndexBuf$1$lcssa = $pSectionIndexBuf$07;
   }
   $indvars$iv$next13 = (($indvars$iv12) + 512)|0;
   $86 = ($indvars$iv$next13>>>0)>($87>>>0);
   $indvars$iv$next = (($indvars$iv) + 512)|0;
   if ($86) {
    break;
   } else {
    $startIdx$09$phi = $indvars$iv12;$138 = $87;$indvars$iv = $indvars$iv$next;$indvars$iv12 = $indvars$iv$next13;$pSectionIndexBuf$07 = $pSectionIndexBuf$1$lcssa;$startIdx$09 = $startIdx$09$phi;
   }
  }
 }
 $88 = HEAP32[$18>>2]|0;
 $particleIndex1$03 = $88;$s$04 = 0;
 while(1) {
  $89 = ((($sections) + ($s$04<<2)|0) + 108|0);
  HEAP32[$89>>2] = $particleIndex1$03;
  $90 = (($sections) + ($s$04<<2)|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($91) + ($particleIndex1$03))|0;
  $93 = (($s$04) + 1)|0;
  $exitcond = ($93|0)==(27);
  if ($exitcond) {
   break;
  } else {
   $particleIndex1$03 = $92;$s$04 = $93;
  }
 }
 $94 = HEAP32[$14>>2]|0;
 $95 = $94 << 4;
 $96 = ($95>>>0)>(1024);
 $97 = (($tmpIndexBuffer) + 4|0);
 $98 = $96&1;
 HEAP8[$97>>0] = $98;
 if ($96) {
  $99 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,$95,499128,306)|0);
  HEAP32[$tmpIndexBuffer>>2] = $99;
  $$pre15 = HEAP32[$14>>2]|0;
  $102 = $$pre15;$103 = $99;
 } else {
  $100 = STACKTOP; STACKTOP = STACKTOP + ((((1*$95)|0)+15)&-16)|0;;
  HEAP32[$tmpIndexBuffer>>2] = $100;
  $102 = $94;$103 = $100;
 }
 $101 = $102 << 2;
 _memcpy(($103|0),($20|0),($101|0))|0;
 $104 = HEAP32[$tmpIndexBuffer>>2]|0;
 $105 = HEAP32[$sectionIndexBuf>>2]|0;
 $106 = HEAP32[$14>>2]|0;
 $107 = $106 & 511;
 $108 = ($107|0)==(0);
 $$$i = $108 ? 512 : $107;
 dest=$sections+0|0; stop=dest+108|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $109 = HEAP32[$14>>2]|0;
 $110 = ($$$i>>>0)>($109>>>0);
 if (!($110)) {
  $111 = (($$$i) + -1)|0;
  $$05$i = $105;$139 = $109;$indvars$iv$i = $111;$indvars$iv8$i = $$$i;$startIdx$04$i = 0;
  while(1) {
   $112 = ($startIdx$04$i>>>0)<($indvars$iv8$i>>>0);
   if ($112) {
    $$12$i = $$05$i;$p$01$i = $startIdx$04$i;
    while(1) {
     $113 = (($104) + ($p$01$i<<2)|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (($$12$i) + 2|0);
     $116 = HEAP16[$$12$i>>1]|0;
     $117 = $116&65535;
     $118 = ((($sections) + ($117<<2)|0) + 108|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = (($sections) + ($117<<2)|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = HEAP32[$18>>2]|0;
     $123 = (($119) + ($19))|0;
     $124 = (($123) + ($121))|0;
     $$sum2 = (($124) - ($122))|0;
     $125 = (($particleIndices) + ($$sum2<<2)|0);
     HEAP32[$125>>2] = $114;
     $126 = HEAP32[$120>>2]|0;
     $127 = (($126) + 1)|0;
     HEAP32[$120>>2] = $127;
     $128 = (($p$01$i) + 1)|0;
     $exitcond$i = ($128|0)==($indvars$iv8$i|0);
     if ($exitcond$i) {
      break;
     } else {
      $$12$i = $115;$p$01$i = $128;
     }
    }
    $129 = (($indvars$iv$i) + 1)|0;
    $scevgep$sum$i = (($129) - ($startIdx$04$i))|0;
    $scevgep7$i = (($$05$i) + ($scevgep$sum$i<<1)|0);
    $$pre$i = HEAP32[$14>>2]|0;
    $$1$lcssa$i = $scevgep7$i;$131 = $$pre$i;
   } else {
    $$1$lcssa$i = $$05$i;$131 = $139;
   }
   $indvars$iv$next9$i = (($indvars$iv8$i) + 512)|0;
   $130 = ($indvars$iv$next9$i>>>0)>($131>>>0);
   $indvars$iv$next$i = (($indvars$iv$i) + 512)|0;
   if ($130) {
    break;
   } else {
    $startIdx$04$i$phi = $indvars$iv8$i;$$05$i = $$1$lcssa$i;$139 = $131;$indvars$iv$i = $indvars$iv$next$i;$indvars$iv8$i = $indvars$iv$next9$i;$startIdx$04$i = $startIdx$04$i$phi;
   }
  }
 }
 $132 = HEAP8[$97>>0]|0;
 $133 = ($132<<24>>24)==(0);
 if (!($133)) {
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($tmpIndexBuffer,$104);
 }
 $134 = HEAP8[$23>>0]|0;
 $135 = ($134<<24>>24)==(0);
 if ($135) {
  STACKTOP = sp;return;
 }
 $136 = HEAP32[$sectionIndexBuf>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($sectionIndexBuf,$136);
 STACKTOP = sp;return;
}
function __ZN5physx19PxsFluidSpatialHash14getHaloRegionsERNS_25PxsFluidPacketHaloRegionsERKNS_17PxcGridCellVectorEPKNS_15PxsParticleCellEPKNS_22PxsFluidPacketSectionsEj($packetHalo,$packetCoords,$packets,$packetSections,$numHashBuckets) {
 $packetHalo = $packetHalo|0;
 $packetCoords = $packetCoords|0;
 $packets = $packets|0;
 $packetSections = $packetSections|0;
 $numHashBuckets = $numHashBuckets|0;
 var $$pre$pre = 0, $$pre281 = 0, $$pre282 = 0, $$pre283 = 0, $$pre285$pre = 0, $$pre286 = 0, $$pre287 = 0, $$pre288 = 0, $$pre290$pre = 0, $$pre292$pre = 0, $$pre294$pre = 0, $$pre296$pre = 0, $$pre298$pre = 0, $$pre300$pre = 0, $$pre302$pre = 0, $$pre304$pre = 0, $$pre306$pre = 0, $$pre308$pre = 0, $$pre310$pre = 0, $$pre312$pre = 0;
 var $$pre314$pre = 0, $$pre316$pre = 0, $$pre318$pre = 0, $$pre320$pre = 0, $$pre322$pre = 0, $$pre324$pre = 0, $$pre326$pre = 0, $$pre328$pre = 0, $$pre330$pre = 0, $$pre332$pre = 0, $$pre334$pre = 0, $$pre336$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0;
 var $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0;
 var $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0;
 var $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0;
 var $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0;
 var $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0;
 var $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0;
 var $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0;
 var $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0;
 var $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0;
 var $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0;
 var $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0;
 var $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0;
 var $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0;
 var $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0;
 var $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0;
 var $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0;
 var $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0;
 var $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0;
 var $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0;
 var $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0;
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0;
 var $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0;
 var $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0;
 var $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $exitcond = 0, $i$0280 = 0, $or$cond = 0, $or$cond178 = 0;
 var $or$cond180 = 0, $or$cond182 = 0, $or$cond184 = 0, $or$cond186 = 0, $or$cond188 = 0, $or$cond190 = 0, $or$cond192 = 0, $or$cond194 = 0, $or$cond196 = 0, $or$cond198 = 0, $or$cond200 = 0, $or$cond202 = 0, $or$cond204 = 0, $or$cond206 = 0, $or$cond208 = 0, $or$cond210 = 0, $or$cond212 = 0, $or$cond214 = 0, $or$cond216 = 0, $or$cond218 = 0;
 var $or$cond220 = 0, $or$cond222 = 0, $or$cond224 = 0, $or$cond226 = 0, $sext = 0, $sext227 = 0, $sext228 = 0, $sext229 = 0, $sext230 = 0, $sext231 = 0, $sext232 = 0, $sext234 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 _memset(($packetHalo|0),0,788)|0;
 $0 = HEAP16[$packetCoords>>1]|0;
 $1 = $0&65535;
 $2 = (($1) + 65535)|0;
 $3 = $2&65535;
 $4 = (($packetCoords) + 2|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = (($packetCoords) + 4|0);
 $7 = HEAP16[$6>>1]|0;
 $sext = $2 << 16;
 $8 = $sext >> 16;
 $9 = $5 << 16 >> 16;
 $10 = ($9*101)|0;
 $11 = (($8) + ($10))|0;
 $12 = $7 << 16 >> 16;
 $13 = ($12*7919)|0;
 $14 = (($11) + ($13))|0;
 $15 = (($numHashBuckets) + -1)|0;
 $16 = $14 & $15;
 $17 = ((($packets) + ($16<<4)|0) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(-1);
 L1: do {
  if ($19) {
   $42 = $0;$47 = $5;$51 = $7;
  } else {
   $$pre$pre = $18;$21 = $16;
   while(1) {
    $20 = (($packets) + ($21<<4)|0);
    $22 = HEAP16[$20>>1]|0;
    $23 = ($3<<16>>16)==($22<<16>>16);
    if ($23) {
     $24 = ((($packets) + ($21<<4)|0) + 2|0);
     $25 = HEAP16[$24>>1]|0;
     $26 = ($5<<16>>16)==($25<<16>>16);
     if ($26) {
      $27 = ((($packets) + ($21<<4)|0) + 4|0);
      $28 = HEAP16[$27>>1]|0;
      $29 = ($7<<16>>16)==($28<<16>>16);
      if ($29) {
       break;
      }
     }
    }
    $30 = (($21) + 1)|0;
    $31 = $30 & $15;
    $32 = ((($packets) + ($31<<4)|0) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(-1);
    if ($34) {
     $42 = $0;$47 = $5;$51 = $7;
     break L1;
    } else {
     $$pre$pre = $33;$21 = $31;
    }
   }
   $35 = ($$pre$pre|0)==(-1);
   $36 = (($packets) + ($21<<4)|0);
   $37 = ($36|0)==(0|0);
   $or$cond = $35 | $37;
   if ($or$cond) {
    $42 = $0;$47 = $5;$51 = $7;
   } else {
    $38 = (($packetHalo) + 392|0);
    $39 = ((($packetSections) + (($21*216)|0)|0) + 144|0);
    dest=$38+0|0; src=$39+0|0; stop=dest+36|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $40 = ((($packetSections) + (($21*216)|0)|0) + 36|0);
    dest=$packetHalo+0|0; src=$40+0|0; stop=dest+36|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $$pre281 = HEAP16[$packetCoords>>1]|0;
    $$pre282 = HEAP16[$4>>1]|0;
    $$pre283 = HEAP16[$6>>1]|0;
    $42 = $$pre281;$47 = $$pre282;$51 = $$pre283;
   }
  }
 } while(0);
 $41 = $42&65535;
 $43 = (($41) + 1)|0;
 $44 = $43&65535;
 $sext227 = $43 << 16;
 $45 = $sext227 >> 16;
 $46 = $47 << 16 >> 16;
 $48 = ($46*101)|0;
 $49 = (($45) + ($48))|0;
 $50 = $51 << 16 >> 16;
 $52 = ($50*7919)|0;
 $53 = (($49) + ($52))|0;
 $54 = $53 & $15;
 $55 = ((($packets) + ($54<<4)|0) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(-1);
 L11: do {
  if ($57) {
   $81 = $47;$85 = $42;$89 = $51;
  } else {
   $$pre285$pre = $56;$59 = $54;
   while(1) {
    $58 = (($packets) + ($59<<4)|0);
    $60 = HEAP16[$58>>1]|0;
    $61 = ($44<<16>>16)==($60<<16>>16);
    if ($61) {
     $62 = ((($packets) + ($59<<4)|0) + 2|0);
     $63 = HEAP16[$62>>1]|0;
     $64 = ($47<<16>>16)==($63<<16>>16);
     if ($64) {
      $65 = ((($packets) + ($59<<4)|0) + 4|0);
      $66 = HEAP16[$65>>1]|0;
      $67 = ($51<<16>>16)==($66<<16>>16);
      if ($67) {
       break;
      }
     }
    }
    $68 = (($59) + 1)|0;
    $69 = $68 & $15;
    $70 = ((($packets) + ($69<<4)|0) + 8|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71|0)==(-1);
    if ($72) {
     $81 = $47;$85 = $42;$89 = $51;
     break L11;
    } else {
     $$pre285$pre = $71;$59 = $69;
    }
   }
   $73 = ($$pre285$pre|0)==(-1);
   $74 = (($packets) + ($59<<4)|0);
   $75 = ($74|0)==(0|0);
   $or$cond178 = $73 | $75;
   if ($or$cond178) {
    $81 = $47;$85 = $42;$89 = $51;
   } else {
    $76 = (($packetHalo) + 428|0);
    $77 = ((($packetSections) + (($59*216)|0)|0) + 108|0);
    dest=$76+0|0; src=$77+0|0; stop=dest+36|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $78 = (($packetHalo) + 36|0);
    $79 = (($packetSections) + (($59*216)|0)|0);
    dest=$78+0|0; src=$79+0|0; stop=dest+36|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $$pre286 = HEAP16[$packetCoords>>1]|0;
    $$pre287 = HEAP16[$4>>1]|0;
    $$pre288 = HEAP16[$6>>1]|0;
    $81 = $$pre287;$85 = $$pre286;$89 = $$pre288;
   }
  }
 } while(0);
 $80 = $81&65535;
 $82 = (($80) + 65535)|0;
 $83 = $82&65535;
 $84 = $85 << 16 >> 16;
 $sext228 = $82 << 16;
 $86 = $sext228 >> 16;
 $87 = ($86*101)|0;
 $88 = $89 << 16 >> 16;
 $90 = ($88*7919)|0;
 $91 = (($90) + ($84))|0;
 $92 = (($91) + ($87))|0;
 $93 = $92 & $15;
 $94 = ((($packets) + ($93<<4)|0) + 8|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(-1);
 L21: do {
  if (!($96)) {
   $$pre290$pre = $95;$98 = $93;
   while(1) {
    $97 = (($packets) + ($98<<4)|0);
    $99 = HEAP16[$97>>1]|0;
    $100 = ($85<<16>>16)==($99<<16>>16);
    if ($100) {
     $101 = ((($packets) + ($98<<4)|0) + 2|0);
     $102 = HEAP16[$101>>1]|0;
     $103 = ($83<<16>>16)==($102<<16>>16);
     if ($103) {
      $104 = ((($packets) + ($98<<4)|0) + 4|0);
      $105 = HEAP16[$104>>1]|0;
      $106 = ($89<<16>>16)==($105<<16>>16);
      if ($106) {
       break;
      }
     }
    }
    $107 = (($98) + 1)|0;
    $108 = $107 & $15;
    $109 = ((($packets) + ($108<<4)|0) + 8|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ($110|0)==(-1);
    if ($111) {
     break L21;
    } else {
     $$pre290$pre = $110;$98 = $108;
    }
   }
   $112 = ($$pre290$pre|0)==(-1);
   $113 = (($packets) + ($98<<4)|0);
   $114 = ($113|0)==(0|0);
   $or$cond180 = $112 | $114;
   if (!($or$cond180)) {
    $115 = ((($packetSections) + (($98*216)|0)|0) + 120|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($packetHalo) + 464|0);
    HEAP32[$117>>2] = $116;
    $118 = ((($packetSections) + (($98*216)|0)|0) + 12|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($packetHalo) + 72|0);
    HEAP32[$120>>2] = $119;
    $121 = ((($packetSections) + (($98*216)|0)|0) + 124|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = (($packetHalo) + 468|0);
    HEAP32[$123>>2] = $122;
    $124 = ((($packetSections) + (($98*216)|0)|0) + 16|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = (($packetHalo) + 76|0);
    HEAP32[$126>>2] = $125;
    $127 = ((($packetSections) + (($98*216)|0)|0) + 128|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = (($packetHalo) + 472|0);
    HEAP32[$129>>2] = $128;
    $130 = ((($packetSections) + (($98*216)|0)|0) + 20|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($packetHalo) + 80|0);
    HEAP32[$132>>2] = $131;
    $133 = ((($packetSections) + (($98*216)|0)|0) + 156|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = (($packetHalo) + 476|0);
    HEAP32[$135>>2] = $134;
    $136 = ((($packetSections) + (($98*216)|0)|0) + 48|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = (($packetHalo) + 84|0);
    HEAP32[$138>>2] = $137;
    $139 = ((($packetSections) + (($98*216)|0)|0) + 160|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = (($packetHalo) + 480|0);
    HEAP32[$141>>2] = $140;
    $142 = ((($packetSections) + (($98*216)|0)|0) + 52|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = (($packetHalo) + 88|0);
    HEAP32[$144>>2] = $143;
    $145 = ((($packetSections) + (($98*216)|0)|0) + 164|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = (($packetHalo) + 484|0);
    HEAP32[$147>>2] = $146;
    $148 = ((($packetSections) + (($98*216)|0)|0) + 56|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = (($packetHalo) + 92|0);
    HEAP32[$150>>2] = $149;
    $151 = ((($packetSections) + (($98*216)|0)|0) + 192|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = (($packetHalo) + 488|0);
    HEAP32[$153>>2] = $152;
    $154 = ((($packetSections) + (($98*216)|0)|0) + 84|0);
    $155 = HEAP32[$154>>2]|0;
    $156 = (($packetHalo) + 96|0);
    HEAP32[$156>>2] = $155;
    $157 = ((($packetSections) + (($98*216)|0)|0) + 196|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($packetHalo) + 492|0);
    HEAP32[$159>>2] = $158;
    $160 = ((($packetSections) + (($98*216)|0)|0) + 88|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = (($packetHalo) + 100|0);
    HEAP32[$162>>2] = $161;
    $163 = ((($packetSections) + (($98*216)|0)|0) + 200|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = (($packetHalo) + 496|0);
    HEAP32[$165>>2] = $164;
    $166 = ((($packetSections) + (($98*216)|0)|0) + 92|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = (($packetHalo) + 104|0);
    HEAP32[$168>>2] = $167;
   }
  }
 } while(0);
 $169 = (($80) + 1)|0;
 $170 = $169&65535;
 $sext229 = $169 << 16;
 $171 = $sext229 >> 16;
 $172 = ($171*101)|0;
 $173 = (($91) + ($172))|0;
 $174 = $173 & $15;
 $175 = ((($packets) + ($174<<4)|0) + 8|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = ($176|0)==(-1);
 L31: do {
  if (!($177)) {
   $$pre292$pre = $176;$179 = $174;
   while(1) {
    $178 = (($packets) + ($179<<4)|0);
    $180 = HEAP16[$178>>1]|0;
    $181 = ($85<<16>>16)==($180<<16>>16);
    if ($181) {
     $182 = ((($packets) + ($179<<4)|0) + 2|0);
     $183 = HEAP16[$182>>1]|0;
     $184 = ($170<<16>>16)==($183<<16>>16);
     if ($184) {
      $185 = ((($packets) + ($179<<4)|0) + 4|0);
      $186 = HEAP16[$185>>1]|0;
      $187 = ($89<<16>>16)==($186<<16>>16);
      if ($187) {
       break;
      }
     }
    }
    $188 = (($179) + 1)|0;
    $189 = $188 & $15;
    $190 = ((($packets) + ($189<<4)|0) + 8|0);
    $191 = HEAP32[$190>>2]|0;
    $192 = ($191|0)==(-1);
    if ($192) {
     break L31;
    } else {
     $$pre292$pre = $191;$179 = $189;
    }
   }
   $193 = ($$pre292$pre|0)==(-1);
   $194 = (($packets) + ($179<<4)|0);
   $195 = ($194|0)==(0|0);
   $or$cond182 = $193 | $195;
   if (!($or$cond182)) {
    $196 = ((($packetSections) + (($179*216)|0)|0) + 108|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = (($packetHalo) + 500|0);
    HEAP32[$198>>2] = $197;
    $199 = (($packetSections) + (($179*216)|0)|0);
    $200 = HEAP32[$199>>2]|0;
    $201 = (($packetHalo) + 108|0);
    HEAP32[$201>>2] = $200;
    $202 = ((($packetSections) + (($179*216)|0)|0) + 112|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = (($packetHalo) + 504|0);
    HEAP32[$204>>2] = $203;
    $205 = ((($packetSections) + (($179*216)|0)|0) + 4|0);
    $206 = HEAP32[$205>>2]|0;
    $207 = (($packetHalo) + 112|0);
    HEAP32[$207>>2] = $206;
    $208 = ((($packetSections) + (($179*216)|0)|0) + 116|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = (($packetHalo) + 508|0);
    HEAP32[$210>>2] = $209;
    $211 = ((($packetSections) + (($179*216)|0)|0) + 8|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = (($packetHalo) + 116|0);
    HEAP32[$213>>2] = $212;
    $214 = ((($packetSections) + (($179*216)|0)|0) + 144|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = (($packetHalo) + 512|0);
    HEAP32[$216>>2] = $215;
    $217 = ((($packetSections) + (($179*216)|0)|0) + 36|0);
    $218 = HEAP32[$217>>2]|0;
    $219 = (($packetHalo) + 120|0);
    HEAP32[$219>>2] = $218;
    $220 = ((($packetSections) + (($179*216)|0)|0) + 148|0);
    $221 = HEAP32[$220>>2]|0;
    $222 = (($packetHalo) + 516|0);
    HEAP32[$222>>2] = $221;
    $223 = ((($packetSections) + (($179*216)|0)|0) + 40|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = (($packetHalo) + 124|0);
    HEAP32[$225>>2] = $224;
    $226 = ((($packetSections) + (($179*216)|0)|0) + 152|0);
    $227 = HEAP32[$226>>2]|0;
    $228 = (($packetHalo) + 520|0);
    HEAP32[$228>>2] = $227;
    $229 = ((($packetSections) + (($179*216)|0)|0) + 44|0);
    $230 = HEAP32[$229>>2]|0;
    $231 = (($packetHalo) + 128|0);
    HEAP32[$231>>2] = $230;
    $232 = ((($packetSections) + (($179*216)|0)|0) + 180|0);
    $233 = HEAP32[$232>>2]|0;
    $234 = (($packetHalo) + 524|0);
    HEAP32[$234>>2] = $233;
    $235 = ((($packetSections) + (($179*216)|0)|0) + 72|0);
    $236 = HEAP32[$235>>2]|0;
    $237 = (($packetHalo) + 132|0);
    HEAP32[$237>>2] = $236;
    $238 = ((($packetSections) + (($179*216)|0)|0) + 184|0);
    $239 = HEAP32[$238>>2]|0;
    $240 = (($packetHalo) + 528|0);
    HEAP32[$240>>2] = $239;
    $241 = ((($packetSections) + (($179*216)|0)|0) + 76|0);
    $242 = HEAP32[$241>>2]|0;
    $243 = (($packetHalo) + 136|0);
    HEAP32[$243>>2] = $242;
    $244 = ((($packetSections) + (($179*216)|0)|0) + 188|0);
    $245 = HEAP32[$244>>2]|0;
    $246 = (($packetHalo) + 532|0);
    HEAP32[$246>>2] = $245;
    $247 = ((($packetSections) + (($179*216)|0)|0) + 80|0);
    $248 = HEAP32[$247>>2]|0;
    $249 = (($packetHalo) + 140|0);
    HEAP32[$249>>2] = $248;
   }
  }
 } while(0);
 $250 = $89&65535;
 $251 = (($250) + 65535)|0;
 $252 = $251&65535;
 $253 = $81 << 16 >> 16;
 $254 = ($253*101)|0;
 $255 = (($254) + ($84))|0;
 $sext230 = $251 << 16;
 $256 = $sext230 >> 16;
 $257 = ($256*7919)|0;
 $258 = (($255) + ($257))|0;
 $259 = $258 & $15;
 $260 = ((($packets) + ($259<<4)|0) + 8|0);
 $261 = HEAP32[$260>>2]|0;
 $262 = ($261|0)==(-1);
 L41: do {
  if (!($262)) {
   $$pre294$pre = $261;$264 = $259;
   while(1) {
    $263 = (($packets) + ($264<<4)|0);
    $265 = HEAP16[$263>>1]|0;
    $266 = ($85<<16>>16)==($265<<16>>16);
    if ($266) {
     $267 = ((($packets) + ($264<<4)|0) + 2|0);
     $268 = HEAP16[$267>>1]|0;
     $269 = ($81<<16>>16)==($268<<16>>16);
     if ($269) {
      $270 = ((($packets) + ($264<<4)|0) + 4|0);
      $271 = HEAP16[$270>>1]|0;
      $272 = ($252<<16>>16)==($271<<16>>16);
      if ($272) {
       break;
      }
     }
    }
    $273 = (($264) + 1)|0;
    $274 = $273 & $15;
    $275 = ((($packets) + ($274<<4)|0) + 8|0);
    $276 = HEAP32[$275>>2]|0;
    $277 = ($276|0)==(-1);
    if ($277) {
     break L41;
    } else {
     $$pre294$pre = $276;$264 = $274;
    }
   }
   $278 = ($$pre294$pre|0)==(-1);
   $279 = (($packets) + ($264<<4)|0);
   $280 = ($279|0)==(0|0);
   $or$cond184 = $278 | $280;
   if (!($or$cond184)) {
    $281 = ((($packetSections) + (($264*216)|0)|0) + 112|0);
    $282 = HEAP32[$281>>2]|0;
    $283 = (($packetHalo) + 536|0);
    HEAP32[$283>>2] = $282;
    $284 = ((($packetSections) + (($264*216)|0)|0) + 4|0);
    $285 = HEAP32[$284>>2]|0;
    $286 = (($packetHalo) + 144|0);
    HEAP32[$286>>2] = $285;
    $287 = ((($packetSections) + (($264*216)|0)|0) + 124|0);
    $288 = HEAP32[$287>>2]|0;
    $289 = (($packetHalo) + 540|0);
    HEAP32[$289>>2] = $288;
    $290 = ((($packetSections) + (($264*216)|0)|0) + 16|0);
    $291 = HEAP32[$290>>2]|0;
    $292 = (($packetHalo) + 148|0);
    HEAP32[$292>>2] = $291;
    $293 = ((($packetSections) + (($264*216)|0)|0) + 136|0);
    $294 = HEAP32[$293>>2]|0;
    $295 = (($packetHalo) + 544|0);
    HEAP32[$295>>2] = $294;
    $296 = ((($packetSections) + (($264*216)|0)|0) + 28|0);
    $297 = HEAP32[$296>>2]|0;
    $298 = (($packetHalo) + 152|0);
    HEAP32[$298>>2] = $297;
    $299 = ((($packetSections) + (($264*216)|0)|0) + 148|0);
    $300 = HEAP32[$299>>2]|0;
    $301 = (($packetHalo) + 548|0);
    HEAP32[$301>>2] = $300;
    $302 = ((($packetSections) + (($264*216)|0)|0) + 40|0);
    $303 = HEAP32[$302>>2]|0;
    $304 = (($packetHalo) + 156|0);
    HEAP32[$304>>2] = $303;
    $305 = ((($packetSections) + (($264*216)|0)|0) + 160|0);
    $306 = HEAP32[$305>>2]|0;
    $307 = (($packetHalo) + 552|0);
    HEAP32[$307>>2] = $306;
    $308 = ((($packetSections) + (($264*216)|0)|0) + 52|0);
    $309 = HEAP32[$308>>2]|0;
    $310 = (($packetHalo) + 160|0);
    HEAP32[$310>>2] = $309;
    $311 = ((($packetSections) + (($264*216)|0)|0) + 172|0);
    $312 = HEAP32[$311>>2]|0;
    $313 = (($packetHalo) + 556|0);
    HEAP32[$313>>2] = $312;
    $314 = ((($packetSections) + (($264*216)|0)|0) + 64|0);
    $315 = HEAP32[$314>>2]|0;
    $316 = (($packetHalo) + 164|0);
    HEAP32[$316>>2] = $315;
    $317 = ((($packetSections) + (($264*216)|0)|0) + 184|0);
    $318 = HEAP32[$317>>2]|0;
    $319 = (($packetHalo) + 560|0);
    HEAP32[$319>>2] = $318;
    $320 = ((($packetSections) + (($264*216)|0)|0) + 76|0);
    $321 = HEAP32[$320>>2]|0;
    $322 = (($packetHalo) + 168|0);
    HEAP32[$322>>2] = $321;
    $323 = ((($packetSections) + (($264*216)|0)|0) + 196|0);
    $324 = HEAP32[$323>>2]|0;
    $325 = (($packetHalo) + 564|0);
    HEAP32[$325>>2] = $324;
    $326 = ((($packetSections) + (($264*216)|0)|0) + 88|0);
    $327 = HEAP32[$326>>2]|0;
    $328 = (($packetHalo) + 172|0);
    HEAP32[$328>>2] = $327;
    $329 = ((($packetSections) + (($264*216)|0)|0) + 208|0);
    $330 = HEAP32[$329>>2]|0;
    $331 = (($packetHalo) + 568|0);
    HEAP32[$331>>2] = $330;
    $332 = ((($packetSections) + (($264*216)|0)|0) + 100|0);
    $333 = HEAP32[$332>>2]|0;
    $334 = (($packetHalo) + 176|0);
    HEAP32[$334>>2] = $333;
   }
  }
 } while(0);
 $335 = (($250) + 1)|0;
 $336 = $335&65535;
 $sext231 = $335 << 16;
 $337 = $sext231 >> 16;
 $338 = ($337*7919)|0;
 $339 = (($255) + ($338))|0;
 $340 = $339 & $15;
 $341 = ((($packets) + ($340<<4)|0) + 8|0);
 $342 = HEAP32[$341>>2]|0;
 $343 = ($342|0)==(-1);
 L51: do {
  if (!($343)) {
   $$pre296$pre = $342;$345 = $340;
   while(1) {
    $344 = (($packets) + ($345<<4)|0);
    $346 = HEAP16[$344>>1]|0;
    $347 = ($85<<16>>16)==($346<<16>>16);
    if ($347) {
     $348 = ((($packets) + ($345<<4)|0) + 2|0);
     $349 = HEAP16[$348>>1]|0;
     $350 = ($81<<16>>16)==($349<<16>>16);
     if ($350) {
      $351 = ((($packets) + ($345<<4)|0) + 4|0);
      $352 = HEAP16[$351>>1]|0;
      $353 = ($336<<16>>16)==($352<<16>>16);
      if ($353) {
       break;
      }
     }
    }
    $354 = (($345) + 1)|0;
    $355 = $354 & $15;
    $356 = ((($packets) + ($355<<4)|0) + 8|0);
    $357 = HEAP32[$356>>2]|0;
    $358 = ($357|0)==(-1);
    if ($358) {
     break L51;
    } else {
     $$pre296$pre = $357;$345 = $355;
    }
   }
   $359 = ($$pre296$pre|0)==(-1);
   $360 = (($packets) + ($345<<4)|0);
   $361 = ($360|0)==(0|0);
   $or$cond186 = $359 | $361;
   if (!($or$cond186)) {
    $362 = ((($packetSections) + (($345*216)|0)|0) + 108|0);
    $363 = HEAP32[$362>>2]|0;
    $364 = (($packetHalo) + 572|0);
    HEAP32[$364>>2] = $363;
    $365 = (($packetSections) + (($345*216)|0)|0);
    $366 = HEAP32[$365>>2]|0;
    $367 = (($packetHalo) + 180|0);
    HEAP32[$367>>2] = $366;
    $368 = ((($packetSections) + (($345*216)|0)|0) + 120|0);
    $369 = HEAP32[$368>>2]|0;
    $370 = (($packetHalo) + 576|0);
    HEAP32[$370>>2] = $369;
    $371 = ((($packetSections) + (($345*216)|0)|0) + 12|0);
    $372 = HEAP32[$371>>2]|0;
    $373 = (($packetHalo) + 184|0);
    HEAP32[$373>>2] = $372;
    $374 = ((($packetSections) + (($345*216)|0)|0) + 132|0);
    $375 = HEAP32[$374>>2]|0;
    $376 = (($packetHalo) + 580|0);
    HEAP32[$376>>2] = $375;
    $377 = ((($packetSections) + (($345*216)|0)|0) + 24|0);
    $378 = HEAP32[$377>>2]|0;
    $379 = (($packetHalo) + 188|0);
    HEAP32[$379>>2] = $378;
    $380 = ((($packetSections) + (($345*216)|0)|0) + 144|0);
    $381 = HEAP32[$380>>2]|0;
    $382 = (($packetHalo) + 584|0);
    HEAP32[$382>>2] = $381;
    $383 = ((($packetSections) + (($345*216)|0)|0) + 36|0);
    $384 = HEAP32[$383>>2]|0;
    $385 = (($packetHalo) + 192|0);
    HEAP32[$385>>2] = $384;
    $386 = ((($packetSections) + (($345*216)|0)|0) + 156|0);
    $387 = HEAP32[$386>>2]|0;
    $388 = (($packetHalo) + 588|0);
    HEAP32[$388>>2] = $387;
    $389 = ((($packetSections) + (($345*216)|0)|0) + 48|0);
    $390 = HEAP32[$389>>2]|0;
    $391 = (($packetHalo) + 196|0);
    HEAP32[$391>>2] = $390;
    $392 = ((($packetSections) + (($345*216)|0)|0) + 168|0);
    $393 = HEAP32[$392>>2]|0;
    $394 = (($packetHalo) + 592|0);
    HEAP32[$394>>2] = $393;
    $395 = ((($packetSections) + (($345*216)|0)|0) + 60|0);
    $396 = HEAP32[$395>>2]|0;
    $397 = (($packetHalo) + 200|0);
    HEAP32[$397>>2] = $396;
    $398 = ((($packetSections) + (($345*216)|0)|0) + 180|0);
    $399 = HEAP32[$398>>2]|0;
    $400 = (($packetHalo) + 596|0);
    HEAP32[$400>>2] = $399;
    $401 = ((($packetSections) + (($345*216)|0)|0) + 72|0);
    $402 = HEAP32[$401>>2]|0;
    $403 = (($packetHalo) + 204|0);
    HEAP32[$403>>2] = $402;
    $404 = ((($packetSections) + (($345*216)|0)|0) + 192|0);
    $405 = HEAP32[$404>>2]|0;
    $406 = (($packetHalo) + 600|0);
    HEAP32[$406>>2] = $405;
    $407 = ((($packetSections) + (($345*216)|0)|0) + 84|0);
    $408 = HEAP32[$407>>2]|0;
    $409 = (($packetHalo) + 208|0);
    HEAP32[$409>>2] = $408;
    $410 = ((($packetSections) + (($345*216)|0)|0) + 204|0);
    $411 = HEAP32[$410>>2]|0;
    $412 = (($packetHalo) + 604|0);
    HEAP32[$412>>2] = $411;
    $413 = ((($packetSections) + (($345*216)|0)|0) + 96|0);
    $414 = HEAP32[$413>>2]|0;
    $415 = (($packetHalo) + 212|0);
    HEAP32[$415>>2] = $414;
   }
  }
 } while(0);
 $416 = $85&65535;
 $417 = (($416) + 65535)|0;
 $418 = $417&65535;
 $sext232 = $417 << 16;
 $419 = $sext232 >> 16;
 $420 = (($90) + ($419))|0;
 $421 = (($420) + ($87))|0;
 $422 = $421 & $15;
 $423 = ((($packets) + ($422<<4)|0) + 8|0);
 $424 = HEAP32[$423>>2]|0;
 $425 = ($424|0)==(-1);
 L61: do {
  if (!($425)) {
   $$pre298$pre = $424;$427 = $422;
   while(1) {
    $426 = (($packets) + ($427<<4)|0);
    $428 = HEAP16[$426>>1]|0;
    $429 = ($418<<16>>16)==($428<<16>>16);
    if ($429) {
     $430 = ((($packets) + ($427<<4)|0) + 2|0);
     $431 = HEAP16[$430>>1]|0;
     $432 = ($83<<16>>16)==($431<<16>>16);
     if ($432) {
      $433 = ((($packets) + ($427<<4)|0) + 4|0);
      $434 = HEAP16[$433>>1]|0;
      $435 = ($89<<16>>16)==($434<<16>>16);
      if ($435) {
       break;
      }
     }
    }
    $436 = (($427) + 1)|0;
    $437 = $436 & $15;
    $438 = ((($packets) + ($437<<4)|0) + 8|0);
    $439 = HEAP32[$438>>2]|0;
    $440 = ($439|0)==(-1);
    if ($440) {
     break L61;
    } else {
     $$pre298$pre = $439;$427 = $437;
    }
   }
   $441 = ($$pre298$pre|0)==(-1);
   $442 = (($packets) + ($427<<4)|0);
   $443 = ($442|0)==(0|0);
   $or$cond188 = $441 | $443;
   if (!($or$cond188)) {
    $444 = ((($packetSections) + (($427*216)|0)|0) + 156|0);
    $445 = HEAP32[$444>>2]|0;
    $446 = (($packetHalo) + 608|0);
    HEAP32[$446>>2] = $445;
    $447 = ((($packetSections) + (($427*216)|0)|0) + 48|0);
    $448 = HEAP32[$447>>2]|0;
    $449 = (($packetHalo) + 216|0);
    HEAP32[$449>>2] = $448;
    $450 = ((($packetSections) + (($427*216)|0)|0) + 160|0);
    $451 = HEAP32[$450>>2]|0;
    $452 = (($packetHalo) + 612|0);
    HEAP32[$452>>2] = $451;
    $453 = ((($packetSections) + (($427*216)|0)|0) + 52|0);
    $454 = HEAP32[$453>>2]|0;
    $455 = (($packetHalo) + 220|0);
    HEAP32[$455>>2] = $454;
    $456 = ((($packetSections) + (($427*216)|0)|0) + 164|0);
    $457 = HEAP32[$456>>2]|0;
    $458 = (($packetHalo) + 616|0);
    HEAP32[$458>>2] = $457;
    $459 = ((($packetSections) + (($427*216)|0)|0) + 56|0);
    $460 = HEAP32[$459>>2]|0;
    $461 = (($packetHalo) + 224|0);
    HEAP32[$461>>2] = $460;
   }
  }
 } while(0);
 $462 = (($416) + 1)|0;
 $463 = $462&65535;
 $sext234 = $462 << 16;
 $464 = $sext234 >> 16;
 $465 = (($90) + ($464))|0;
 $466 = (($465) + ($87))|0;
 $467 = $466 & $15;
 $468 = ((($packets) + ($467<<4)|0) + 8|0);
 $469 = HEAP32[$468>>2]|0;
 $470 = ($469|0)==(-1);
 L71: do {
  if (!($470)) {
   $$pre300$pre = $469;$472 = $467;
   while(1) {
    $471 = (($packets) + ($472<<4)|0);
    $473 = HEAP16[$471>>1]|0;
    $474 = ($463<<16>>16)==($473<<16>>16);
    if ($474) {
     $475 = ((($packets) + ($472<<4)|0) + 2|0);
     $476 = HEAP16[$475>>1]|0;
     $477 = ($83<<16>>16)==($476<<16>>16);
     if ($477) {
      $478 = ((($packets) + ($472<<4)|0) + 4|0);
      $479 = HEAP16[$478>>1]|0;
      $480 = ($89<<16>>16)==($479<<16>>16);
      if ($480) {
       break;
      }
     }
    }
    $481 = (($472) + 1)|0;
    $482 = $481 & $15;
    $483 = ((($packets) + ($482<<4)|0) + 8|0);
    $484 = HEAP32[$483>>2]|0;
    $485 = ($484|0)==(-1);
    if ($485) {
     break L71;
    } else {
     $$pre300$pre = $484;$472 = $482;
    }
   }
   $486 = ($$pre300$pre|0)==(-1);
   $487 = (($packets) + ($472<<4)|0);
   $488 = ($487|0)==(0|0);
   $or$cond190 = $486 | $488;
   if (!($or$cond190)) {
    $489 = ((($packetSections) + (($472*216)|0)|0) + 120|0);
    $490 = HEAP32[$489>>2]|0;
    $491 = (($packetHalo) + 620|0);
    HEAP32[$491>>2] = $490;
    $492 = ((($packetSections) + (($472*216)|0)|0) + 12|0);
    $493 = HEAP32[$492>>2]|0;
    $494 = (($packetHalo) + 228|0);
    HEAP32[$494>>2] = $493;
    $495 = ((($packetSections) + (($472*216)|0)|0) + 124|0);
    $496 = HEAP32[$495>>2]|0;
    $497 = (($packetHalo) + 624|0);
    HEAP32[$497>>2] = $496;
    $498 = ((($packetSections) + (($472*216)|0)|0) + 16|0);
    $499 = HEAP32[$498>>2]|0;
    $500 = (($packetHalo) + 232|0);
    HEAP32[$500>>2] = $499;
    $501 = ((($packetSections) + (($472*216)|0)|0) + 128|0);
    $502 = HEAP32[$501>>2]|0;
    $503 = (($packetHalo) + 628|0);
    HEAP32[$503>>2] = $502;
    $504 = ((($packetSections) + (($472*216)|0)|0) + 20|0);
    $505 = HEAP32[$504>>2]|0;
    $506 = (($packetHalo) + 236|0);
    HEAP32[$506>>2] = $505;
   }
  }
 } while(0);
 $507 = (($420) + ($172))|0;
 $508 = $507 & $15;
 $509 = ((($packets) + ($508<<4)|0) + 8|0);
 $510 = HEAP32[$509>>2]|0;
 $511 = ($510|0)==(-1);
 L81: do {
  if (!($511)) {
   $$pre302$pre = $510;$513 = $508;
   while(1) {
    $512 = (($packets) + ($513<<4)|0);
    $514 = HEAP16[$512>>1]|0;
    $515 = ($418<<16>>16)==($514<<16>>16);
    if ($515) {
     $516 = ((($packets) + ($513<<4)|0) + 2|0);
     $517 = HEAP16[$516>>1]|0;
     $518 = ($170<<16>>16)==($517<<16>>16);
     if ($518) {
      $519 = ((($packets) + ($513<<4)|0) + 4|0);
      $520 = HEAP16[$519>>1]|0;
      $521 = ($89<<16>>16)==($520<<16>>16);
      if ($521) {
       break;
      }
     }
    }
    $522 = (($513) + 1)|0;
    $523 = $522 & $15;
    $524 = ((($packets) + ($523<<4)|0) + 8|0);
    $525 = HEAP32[$524>>2]|0;
    $526 = ($525|0)==(-1);
    if ($526) {
     break L81;
    } else {
     $$pre302$pre = $525;$513 = $523;
    }
   }
   $527 = ($$pre302$pre|0)==(-1);
   $528 = (($packets) + ($513<<4)|0);
   $529 = ($528|0)==(0|0);
   $or$cond192 = $527 | $529;
   if (!($or$cond192)) {
    $530 = ((($packetSections) + (($513*216)|0)|0) + 144|0);
    $531 = HEAP32[$530>>2]|0;
    $532 = (($packetHalo) + 632|0);
    HEAP32[$532>>2] = $531;
    $533 = ((($packetSections) + (($513*216)|0)|0) + 36|0);
    $534 = HEAP32[$533>>2]|0;
    $535 = (($packetHalo) + 240|0);
    HEAP32[$535>>2] = $534;
    $536 = ((($packetSections) + (($513*216)|0)|0) + 148|0);
    $537 = HEAP32[$536>>2]|0;
    $538 = (($packetHalo) + 636|0);
    HEAP32[$538>>2] = $537;
    $539 = ((($packetSections) + (($513*216)|0)|0) + 40|0);
    $540 = HEAP32[$539>>2]|0;
    $541 = (($packetHalo) + 244|0);
    HEAP32[$541>>2] = $540;
    $542 = ((($packetSections) + (($513*216)|0)|0) + 152|0);
    $543 = HEAP32[$542>>2]|0;
    $544 = (($packetHalo) + 640|0);
    HEAP32[$544>>2] = $543;
    $545 = ((($packetSections) + (($513*216)|0)|0) + 44|0);
    $546 = HEAP32[$545>>2]|0;
    $547 = (($packetHalo) + 248|0);
    HEAP32[$547>>2] = $546;
   }
  }
 } while(0);
 $548 = (($465) + ($172))|0;
 $549 = $548 & $15;
 $550 = ((($packets) + ($549<<4)|0) + 8|0);
 $551 = HEAP32[$550>>2]|0;
 $552 = ($551|0)==(-1);
 L91: do {
  if (!($552)) {
   $$pre304$pre = $551;$554 = $549;
   while(1) {
    $553 = (($packets) + ($554<<4)|0);
    $555 = HEAP16[$553>>1]|0;
    $556 = ($463<<16>>16)==($555<<16>>16);
    if ($556) {
     $557 = ((($packets) + ($554<<4)|0) + 2|0);
     $558 = HEAP16[$557>>1]|0;
     $559 = ($170<<16>>16)==($558<<16>>16);
     if ($559) {
      $560 = ((($packets) + ($554<<4)|0) + 4|0);
      $561 = HEAP16[$560>>1]|0;
      $562 = ($89<<16>>16)==($561<<16>>16);
      if ($562) {
       break;
      }
     }
    }
    $563 = (($554) + 1)|0;
    $564 = $563 & $15;
    $565 = ((($packets) + ($564<<4)|0) + 8|0);
    $566 = HEAP32[$565>>2]|0;
    $567 = ($566|0)==(-1);
    if ($567) {
     break L91;
    } else {
     $$pre304$pre = $566;$554 = $564;
    }
   }
   $568 = ($$pre304$pre|0)==(-1);
   $569 = (($packets) + ($554<<4)|0);
   $570 = ($569|0)==(0|0);
   $or$cond194 = $568 | $570;
   if (!($or$cond194)) {
    $571 = ((($packetSections) + (($554*216)|0)|0) + 108|0);
    $572 = HEAP32[$571>>2]|0;
    $573 = (($packetHalo) + 644|0);
    HEAP32[$573>>2] = $572;
    $574 = (($packetSections) + (($554*216)|0)|0);
    $575 = HEAP32[$574>>2]|0;
    $576 = (($packetHalo) + 252|0);
    HEAP32[$576>>2] = $575;
    $577 = ((($packetSections) + (($554*216)|0)|0) + 112|0);
    $578 = HEAP32[$577>>2]|0;
    $579 = (($packetHalo) + 648|0);
    HEAP32[$579>>2] = $578;
    $580 = ((($packetSections) + (($554*216)|0)|0) + 4|0);
    $581 = HEAP32[$580>>2]|0;
    $582 = (($packetHalo) + 256|0);
    HEAP32[$582>>2] = $581;
    $583 = ((($packetSections) + (($554*216)|0)|0) + 116|0);
    $584 = HEAP32[$583>>2]|0;
    $585 = (($packetHalo) + 652|0);
    HEAP32[$585>>2] = $584;
    $586 = ((($packetSections) + (($554*216)|0)|0) + 8|0);
    $587 = HEAP32[$586>>2]|0;
    $588 = (($packetHalo) + 260|0);
    HEAP32[$588>>2] = $587;
   }
  }
 } while(0);
 $589 = (($419) + ($254))|0;
 $590 = (($589) + ($257))|0;
 $591 = $590 & $15;
 $592 = ((($packets) + ($591<<4)|0) + 8|0);
 $593 = HEAP32[$592>>2]|0;
 $594 = ($593|0)==(-1);
 L101: do {
  if (!($594)) {
   $$pre306$pre = $593;$596 = $591;
   while(1) {
    $595 = (($packets) + ($596<<4)|0);
    $597 = HEAP16[$595>>1]|0;
    $598 = ($418<<16>>16)==($597<<16>>16);
    if ($598) {
     $599 = ((($packets) + ($596<<4)|0) + 2|0);
     $600 = HEAP16[$599>>1]|0;
     $601 = ($81<<16>>16)==($600<<16>>16);
     if ($601) {
      $602 = ((($packets) + ($596<<4)|0) + 4|0);
      $603 = HEAP16[$602>>1]|0;
      $604 = ($252<<16>>16)==($603<<16>>16);
      if ($604) {
       break;
      }
     }
    }
    $605 = (($596) + 1)|0;
    $606 = $605 & $15;
    $607 = ((($packets) + ($606<<4)|0) + 8|0);
    $608 = HEAP32[$607>>2]|0;
    $609 = ($608|0)==(-1);
    if ($609) {
     break L101;
    } else {
     $$pre306$pre = $608;$596 = $606;
    }
   }
   $610 = ($$pre306$pre|0)==(-1);
   $611 = (($packets) + ($596<<4)|0);
   $612 = ($611|0)==(0|0);
   $or$cond196 = $610 | $612;
   if (!($or$cond196)) {
    $613 = ((($packetSections) + (($596*216)|0)|0) + 148|0);
    $614 = HEAP32[$613>>2]|0;
    $615 = (($packetHalo) + 656|0);
    HEAP32[$615>>2] = $614;
    $616 = ((($packetSections) + (($596*216)|0)|0) + 40|0);
    $617 = HEAP32[$616>>2]|0;
    $618 = (($packetHalo) + 264|0);
    HEAP32[$618>>2] = $617;
    $619 = ((($packetSections) + (($596*216)|0)|0) + 160|0);
    $620 = HEAP32[$619>>2]|0;
    $621 = (($packetHalo) + 660|0);
    HEAP32[$621>>2] = $620;
    $622 = ((($packetSections) + (($596*216)|0)|0) + 52|0);
    $623 = HEAP32[$622>>2]|0;
    $624 = (($packetHalo) + 268|0);
    HEAP32[$624>>2] = $623;
    $625 = ((($packetSections) + (($596*216)|0)|0) + 172|0);
    $626 = HEAP32[$625>>2]|0;
    $627 = (($packetHalo) + 664|0);
    HEAP32[$627>>2] = $626;
    $628 = ((($packetSections) + (($596*216)|0)|0) + 64|0);
    $629 = HEAP32[$628>>2]|0;
    $630 = (($packetHalo) + 272|0);
    HEAP32[$630>>2] = $629;
   }
  }
 } while(0);
 $631 = (($464) + ($254))|0;
 $632 = (($631) + ($257))|0;
 $633 = $632 & $15;
 $634 = ((($packets) + ($633<<4)|0) + 8|0);
 $635 = HEAP32[$634>>2]|0;
 $636 = ($635|0)==(-1);
 L111: do {
  if (!($636)) {
   $$pre308$pre = $635;$638 = $633;
   while(1) {
    $637 = (($packets) + ($638<<4)|0);
    $639 = HEAP16[$637>>1]|0;
    $640 = ($463<<16>>16)==($639<<16>>16);
    if ($640) {
     $641 = ((($packets) + ($638<<4)|0) + 2|0);
     $642 = HEAP16[$641>>1]|0;
     $643 = ($81<<16>>16)==($642<<16>>16);
     if ($643) {
      $644 = ((($packets) + ($638<<4)|0) + 4|0);
      $645 = HEAP16[$644>>1]|0;
      $646 = ($252<<16>>16)==($645<<16>>16);
      if ($646) {
       break;
      }
     }
    }
    $647 = (($638) + 1)|0;
    $648 = $647 & $15;
    $649 = ((($packets) + ($648<<4)|0) + 8|0);
    $650 = HEAP32[$649>>2]|0;
    $651 = ($650|0)==(-1);
    if ($651) {
     break L111;
    } else {
     $$pre308$pre = $650;$638 = $648;
    }
   }
   $652 = ($$pre308$pre|0)==(-1);
   $653 = (($packets) + ($638<<4)|0);
   $654 = ($653|0)==(0|0);
   $or$cond198 = $652 | $654;
   if (!($or$cond198)) {
    $655 = ((($packetSections) + (($638*216)|0)|0) + 112|0);
    $656 = HEAP32[$655>>2]|0;
    $657 = (($packetHalo) + 668|0);
    HEAP32[$657>>2] = $656;
    $658 = ((($packetSections) + (($638*216)|0)|0) + 4|0);
    $659 = HEAP32[$658>>2]|0;
    $660 = (($packetHalo) + 276|0);
    HEAP32[$660>>2] = $659;
    $661 = ((($packetSections) + (($638*216)|0)|0) + 124|0);
    $662 = HEAP32[$661>>2]|0;
    $663 = (($packetHalo) + 672|0);
    HEAP32[$663>>2] = $662;
    $664 = ((($packetSections) + (($638*216)|0)|0) + 16|0);
    $665 = HEAP32[$664>>2]|0;
    $666 = (($packetHalo) + 280|0);
    HEAP32[$666>>2] = $665;
    $667 = ((($packetSections) + (($638*216)|0)|0) + 136|0);
    $668 = HEAP32[$667>>2]|0;
    $669 = (($packetHalo) + 676|0);
    HEAP32[$669>>2] = $668;
    $670 = ((($packetSections) + (($638*216)|0)|0) + 28|0);
    $671 = HEAP32[$670>>2]|0;
    $672 = (($packetHalo) + 284|0);
    HEAP32[$672>>2] = $671;
   }
  }
 } while(0);
 $673 = (($589) + ($338))|0;
 $674 = $673 & $15;
 $675 = ((($packets) + ($674<<4)|0) + 8|0);
 $676 = HEAP32[$675>>2]|0;
 $677 = ($676|0)==(-1);
 L121: do {
  if (!($677)) {
   $$pre310$pre = $676;$679 = $674;
   while(1) {
    $678 = (($packets) + ($679<<4)|0);
    $680 = HEAP16[$678>>1]|0;
    $681 = ($418<<16>>16)==($680<<16>>16);
    if ($681) {
     $682 = ((($packets) + ($679<<4)|0) + 2|0);
     $683 = HEAP16[$682>>1]|0;
     $684 = ($81<<16>>16)==($683<<16>>16);
     if ($684) {
      $685 = ((($packets) + ($679<<4)|0) + 4|0);
      $686 = HEAP16[$685>>1]|0;
      $687 = ($336<<16>>16)==($686<<16>>16);
      if ($687) {
       break;
      }
     }
    }
    $688 = (($679) + 1)|0;
    $689 = $688 & $15;
    $690 = ((($packets) + ($689<<4)|0) + 8|0);
    $691 = HEAP32[$690>>2]|0;
    $692 = ($691|0)==(-1);
    if ($692) {
     break L121;
    } else {
     $$pre310$pre = $691;$679 = $689;
    }
   }
   $693 = ($$pre310$pre|0)==(-1);
   $694 = (($packets) + ($679<<4)|0);
   $695 = ($694|0)==(0|0);
   $or$cond200 = $693 | $695;
   if (!($or$cond200)) {
    $696 = ((($packetSections) + (($679*216)|0)|0) + 144|0);
    $697 = HEAP32[$696>>2]|0;
    $698 = (($packetHalo) + 680|0);
    HEAP32[$698>>2] = $697;
    $699 = ((($packetSections) + (($679*216)|0)|0) + 36|0);
    $700 = HEAP32[$699>>2]|0;
    $701 = (($packetHalo) + 288|0);
    HEAP32[$701>>2] = $700;
    $702 = ((($packetSections) + (($679*216)|0)|0) + 156|0);
    $703 = HEAP32[$702>>2]|0;
    $704 = (($packetHalo) + 684|0);
    HEAP32[$704>>2] = $703;
    $705 = ((($packetSections) + (($679*216)|0)|0) + 48|0);
    $706 = HEAP32[$705>>2]|0;
    $707 = (($packetHalo) + 292|0);
    HEAP32[$707>>2] = $706;
    $708 = ((($packetSections) + (($679*216)|0)|0) + 168|0);
    $709 = HEAP32[$708>>2]|0;
    $710 = (($packetHalo) + 688|0);
    HEAP32[$710>>2] = $709;
    $711 = ((($packetSections) + (($679*216)|0)|0) + 60|0);
    $712 = HEAP32[$711>>2]|0;
    $713 = (($packetHalo) + 296|0);
    HEAP32[$713>>2] = $712;
   }
  }
 } while(0);
 $714 = (($631) + ($338))|0;
 $715 = $714 & $15;
 $716 = ((($packets) + ($715<<4)|0) + 8|0);
 $717 = HEAP32[$716>>2]|0;
 $718 = ($717|0)==(-1);
 L131: do {
  if (!($718)) {
   $$pre312$pre = $717;$720 = $715;
   while(1) {
    $719 = (($packets) + ($720<<4)|0);
    $721 = HEAP16[$719>>1]|0;
    $722 = ($463<<16>>16)==($721<<16>>16);
    if ($722) {
     $723 = ((($packets) + ($720<<4)|0) + 2|0);
     $724 = HEAP16[$723>>1]|0;
     $725 = ($81<<16>>16)==($724<<16>>16);
     if ($725) {
      $726 = ((($packets) + ($720<<4)|0) + 4|0);
      $727 = HEAP16[$726>>1]|0;
      $728 = ($336<<16>>16)==($727<<16>>16);
      if ($728) {
       break;
      }
     }
    }
    $729 = (($720) + 1)|0;
    $730 = $729 & $15;
    $731 = ((($packets) + ($730<<4)|0) + 8|0);
    $732 = HEAP32[$731>>2]|0;
    $733 = ($732|0)==(-1);
    if ($733) {
     break L131;
    } else {
     $$pre312$pre = $732;$720 = $730;
    }
   }
   $734 = ($$pre312$pre|0)==(-1);
   $735 = (($packets) + ($720<<4)|0);
   $736 = ($735|0)==(0|0);
   $or$cond202 = $734 | $736;
   if (!($or$cond202)) {
    $737 = ((($packetSections) + (($720*216)|0)|0) + 108|0);
    $738 = HEAP32[$737>>2]|0;
    $739 = (($packetHalo) + 692|0);
    HEAP32[$739>>2] = $738;
    $740 = (($packetSections) + (($720*216)|0)|0);
    $741 = HEAP32[$740>>2]|0;
    $742 = (($packetHalo) + 300|0);
    HEAP32[$742>>2] = $741;
    $743 = ((($packetSections) + (($720*216)|0)|0) + 120|0);
    $744 = HEAP32[$743>>2]|0;
    $745 = (($packetHalo) + 696|0);
    HEAP32[$745>>2] = $744;
    $746 = ((($packetSections) + (($720*216)|0)|0) + 12|0);
    $747 = HEAP32[$746>>2]|0;
    $748 = (($packetHalo) + 304|0);
    HEAP32[$748>>2] = $747;
    $749 = ((($packetSections) + (($720*216)|0)|0) + 132|0);
    $750 = HEAP32[$749>>2]|0;
    $751 = (($packetHalo) + 700|0);
    HEAP32[$751>>2] = $750;
    $752 = ((($packetSections) + (($720*216)|0)|0) + 24|0);
    $753 = HEAP32[$752>>2]|0;
    $754 = (($packetHalo) + 308|0);
    HEAP32[$754>>2] = $753;
   }
  }
 } while(0);
 $755 = (($87) + ($84))|0;
 $756 = (($755) + ($257))|0;
 $757 = $756 & $15;
 $758 = ((($packets) + ($757<<4)|0) + 8|0);
 $759 = HEAP32[$758>>2]|0;
 $760 = ($759|0)==(-1);
 L141: do {
  if (!($760)) {
   $$pre314$pre = $759;$762 = $757;
   while(1) {
    $761 = (($packets) + ($762<<4)|0);
    $763 = HEAP16[$761>>1]|0;
    $764 = ($85<<16>>16)==($763<<16>>16);
    if ($764) {
     $765 = ((($packets) + ($762<<4)|0) + 2|0);
     $766 = HEAP16[$765>>1]|0;
     $767 = ($83<<16>>16)==($766<<16>>16);
     if ($767) {
      $768 = ((($packets) + ($762<<4)|0) + 4|0);
      $769 = HEAP16[$768>>1]|0;
      $770 = ($252<<16>>16)==($769<<16>>16);
      if ($770) {
       break;
      }
     }
    }
    $771 = (($762) + 1)|0;
    $772 = $771 & $15;
    $773 = ((($packets) + ($772<<4)|0) + 8|0);
    $774 = HEAP32[$773>>2]|0;
    $775 = ($774|0)==(-1);
    if ($775) {
     break L141;
    } else {
     $$pre314$pre = $774;$762 = $772;
    }
   }
   $776 = ($$pre314$pre|0)==(-1);
   $777 = (($packets) + ($762<<4)|0);
   $778 = ($777|0)==(0|0);
   $or$cond204 = $776 | $778;
   if (!($or$cond204)) {
    $779 = ((($packetSections) + (($762*216)|0)|0) + 124|0);
    $780 = HEAP32[$779>>2]|0;
    $781 = (($packetHalo) + 704|0);
    HEAP32[$781>>2] = $780;
    $782 = ((($packetSections) + (($762*216)|0)|0) + 16|0);
    $783 = HEAP32[$782>>2]|0;
    $784 = (($packetHalo) + 312|0);
    HEAP32[$784>>2] = $783;
    $785 = ((($packetSections) + (($762*216)|0)|0) + 160|0);
    $786 = HEAP32[$785>>2]|0;
    $787 = (($packetHalo) + 708|0);
    HEAP32[$787>>2] = $786;
    $788 = ((($packetSections) + (($762*216)|0)|0) + 52|0);
    $789 = HEAP32[$788>>2]|0;
    $790 = (($packetHalo) + 316|0);
    HEAP32[$790>>2] = $789;
    $791 = ((($packetSections) + (($762*216)|0)|0) + 196|0);
    $792 = HEAP32[$791>>2]|0;
    $793 = (($packetHalo) + 712|0);
    HEAP32[$793>>2] = $792;
    $794 = ((($packetSections) + (($762*216)|0)|0) + 88|0);
    $795 = HEAP32[$794>>2]|0;
    $796 = (($packetHalo) + 320|0);
    HEAP32[$796>>2] = $795;
   }
  }
 } while(0);
 $797 = (($172) + ($84))|0;
 $798 = (($797) + ($257))|0;
 $799 = $798 & $15;
 $800 = ((($packets) + ($799<<4)|0) + 8|0);
 $801 = HEAP32[$800>>2]|0;
 $802 = ($801|0)==(-1);
 L151: do {
  if (!($802)) {
   $$pre316$pre = $801;$804 = $799;
   L152: while(1) {
    $803 = (($packets) + ($804<<4)|0);
    $805 = HEAP16[$803>>1]|0;
    $806 = ($85<<16>>16)==($805<<16>>16);
    do {
     if ($806) {
      $807 = ((($packets) + ($804<<4)|0) + 2|0);
      $808 = HEAP16[$807>>1]|0;
      $809 = ($170<<16>>16)==($808<<16>>16);
      if (!($809)) {
       break;
      }
      $810 = ((($packets) + ($804<<4)|0) + 4|0);
      $811 = HEAP16[$810>>1]|0;
      $812 = ($252<<16>>16)==($811<<16>>16);
      if ($812) {
       break L152;
      }
     }
    } while(0);
    $813 = (($804) + 1)|0;
    $814 = $813 & $15;
    $815 = ((($packets) + ($814<<4)|0) + 8|0);
    $816 = HEAP32[$815>>2]|0;
    $817 = ($816|0)==(-1);
    if ($817) {
     break L151;
    } else {
     $$pre316$pre = $816;$804 = $814;
    }
   }
   $818 = ($$pre316$pre|0)==(-1);
   $819 = (($packets) + ($804<<4)|0);
   $820 = ($819|0)==(0|0);
   $or$cond206 = $818 | $820;
   if (!($or$cond206)) {
    $821 = ((($packetSections) + (($804*216)|0)|0) + 112|0);
    $822 = HEAP32[$821>>2]|0;
    $823 = (($packetHalo) + 716|0);
    HEAP32[$823>>2] = $822;
    $824 = ((($packetSections) + (($804*216)|0)|0) + 4|0);
    $825 = HEAP32[$824>>2]|0;
    $826 = (($packetHalo) + 324|0);
    HEAP32[$826>>2] = $825;
    $827 = ((($packetSections) + (($804*216)|0)|0) + 148|0);
    $828 = HEAP32[$827>>2]|0;
    $829 = (($packetHalo) + 720|0);
    HEAP32[$829>>2] = $828;
    $830 = ((($packetSections) + (($804*216)|0)|0) + 40|0);
    $831 = HEAP32[$830>>2]|0;
    $832 = (($packetHalo) + 328|0);
    HEAP32[$832>>2] = $831;
    $833 = ((($packetSections) + (($804*216)|0)|0) + 184|0);
    $834 = HEAP32[$833>>2]|0;
    $835 = (($packetHalo) + 724|0);
    HEAP32[$835>>2] = $834;
    $836 = ((($packetSections) + (($804*216)|0)|0) + 76|0);
    $837 = HEAP32[$836>>2]|0;
    $838 = (($packetHalo) + 332|0);
    HEAP32[$838>>2] = $837;
   }
  }
 } while(0);
 $839 = (($755) + ($338))|0;
 $840 = $839 & $15;
 $841 = ((($packets) + ($840<<4)|0) + 8|0);
 $842 = HEAP32[$841>>2]|0;
 $843 = ($842|0)==(-1);
 L161: do {
  if (!($843)) {
   $$pre318$pre = $842;$845 = $840;
   L162: while(1) {
    $844 = (($packets) + ($845<<4)|0);
    $846 = HEAP16[$844>>1]|0;
    $847 = ($85<<16>>16)==($846<<16>>16);
    do {
     if ($847) {
      $848 = ((($packets) + ($845<<4)|0) + 2|0);
      $849 = HEAP16[$848>>1]|0;
      $850 = ($83<<16>>16)==($849<<16>>16);
      if (!($850)) {
       break;
      }
      $851 = ((($packets) + ($845<<4)|0) + 4|0);
      $852 = HEAP16[$851>>1]|0;
      $853 = ($336<<16>>16)==($852<<16>>16);
      if ($853) {
       break L162;
      }
     }
    } while(0);
    $854 = (($845) + 1)|0;
    $855 = $854 & $15;
    $856 = ((($packets) + ($855<<4)|0) + 8|0);
    $857 = HEAP32[$856>>2]|0;
    $858 = ($857|0)==(-1);
    if ($858) {
     break L161;
    } else {
     $$pre318$pre = $857;$845 = $855;
    }
   }
   $859 = ($$pre318$pre|0)==(-1);
   $860 = (($packets) + ($845<<4)|0);
   $861 = ($860|0)==(0|0);
   $or$cond208 = $859 | $861;
   if (!($or$cond208)) {
    $862 = ((($packetSections) + (($845*216)|0)|0) + 120|0);
    $863 = HEAP32[$862>>2]|0;
    $864 = (($packetHalo) + 728|0);
    HEAP32[$864>>2] = $863;
    $865 = ((($packetSections) + (($845*216)|0)|0) + 12|0);
    $866 = HEAP32[$865>>2]|0;
    $867 = (($packetHalo) + 336|0);
    HEAP32[$867>>2] = $866;
    $868 = ((($packetSections) + (($845*216)|0)|0) + 156|0);
    $869 = HEAP32[$868>>2]|0;
    $870 = (($packetHalo) + 732|0);
    HEAP32[$870>>2] = $869;
    $871 = ((($packetSections) + (($845*216)|0)|0) + 48|0);
    $872 = HEAP32[$871>>2]|0;
    $873 = (($packetHalo) + 340|0);
    HEAP32[$873>>2] = $872;
    $874 = ((($packetSections) + (($845*216)|0)|0) + 192|0);
    $875 = HEAP32[$874>>2]|0;
    $876 = (($packetHalo) + 736|0);
    HEAP32[$876>>2] = $875;
    $877 = ((($packetSections) + (($845*216)|0)|0) + 84|0);
    $878 = HEAP32[$877>>2]|0;
    $879 = (($packetHalo) + 344|0);
    HEAP32[$879>>2] = $878;
   }
  }
 } while(0);
 $880 = (($797) + ($338))|0;
 $881 = $880 & $15;
 $882 = ((($packets) + ($881<<4)|0) + 8|0);
 $883 = HEAP32[$882>>2]|0;
 $884 = ($883|0)==(-1);
 L171: do {
  if (!($884)) {
   $$pre320$pre = $883;$886 = $881;
   L172: while(1) {
    $885 = (($packets) + ($886<<4)|0);
    $887 = HEAP16[$885>>1]|0;
    $888 = ($85<<16>>16)==($887<<16>>16);
    do {
     if ($888) {
      $889 = ((($packets) + ($886<<4)|0) + 2|0);
      $890 = HEAP16[$889>>1]|0;
      $891 = ($170<<16>>16)==($890<<16>>16);
      if (!($891)) {
       break;
      }
      $892 = ((($packets) + ($886<<4)|0) + 4|0);
      $893 = HEAP16[$892>>1]|0;
      $894 = ($336<<16>>16)==($893<<16>>16);
      if ($894) {
       break L172;
      }
     }
    } while(0);
    $895 = (($886) + 1)|0;
    $896 = $895 & $15;
    $897 = ((($packets) + ($896<<4)|0) + 8|0);
    $898 = HEAP32[$897>>2]|0;
    $899 = ($898|0)==(-1);
    if ($899) {
     break L171;
    } else {
     $$pre320$pre = $898;$886 = $896;
    }
   }
   $900 = ($$pre320$pre|0)==(-1);
   $901 = (($packets) + ($886<<4)|0);
   $902 = ($901|0)==(0|0);
   $or$cond210 = $900 | $902;
   if (!($or$cond210)) {
    $903 = ((($packetSections) + (($886*216)|0)|0) + 108|0);
    $904 = HEAP32[$903>>2]|0;
    $905 = (($packetHalo) + 740|0);
    HEAP32[$905>>2] = $904;
    $906 = (($packetSections) + (($886*216)|0)|0);
    $907 = HEAP32[$906>>2]|0;
    $908 = (($packetHalo) + 348|0);
    HEAP32[$908>>2] = $907;
    $909 = ((($packetSections) + (($886*216)|0)|0) + 144|0);
    $910 = HEAP32[$909>>2]|0;
    $911 = (($packetHalo) + 744|0);
    HEAP32[$911>>2] = $910;
    $912 = ((($packetSections) + (($886*216)|0)|0) + 36|0);
    $913 = HEAP32[$912>>2]|0;
    $914 = (($packetHalo) + 352|0);
    HEAP32[$914>>2] = $913;
    $915 = ((($packetSections) + (($886*216)|0)|0) + 180|0);
    $916 = HEAP32[$915>>2]|0;
    $917 = (($packetHalo) + 748|0);
    HEAP32[$917>>2] = $916;
    $918 = ((($packetSections) + (($886*216)|0)|0) + 72|0);
    $919 = HEAP32[$918>>2]|0;
    $920 = (($packetHalo) + 356|0);
    HEAP32[$920>>2] = $919;
   }
  }
 } while(0);
 $921 = (($87) + ($419))|0;
 $922 = (($921) + ($257))|0;
 $923 = $922 & $15;
 $924 = ((($packets) + ($923<<4)|0) + 8|0);
 $925 = HEAP32[$924>>2]|0;
 $926 = ($925|0)==(-1);
 L181: do {
  if (!($926)) {
   $$pre322$pre = $925;$928 = $923;
   L182: while(1) {
    $927 = (($packets) + ($928<<4)|0);
    $929 = HEAP16[$927>>1]|0;
    $930 = ($418<<16>>16)==($929<<16>>16);
    do {
     if ($930) {
      $931 = ((($packets) + ($928<<4)|0) + 2|0);
      $932 = HEAP16[$931>>1]|0;
      $933 = ($83<<16>>16)==($932<<16>>16);
      if (!($933)) {
       break;
      }
      $934 = ((($packets) + ($928<<4)|0) + 4|0);
      $935 = HEAP16[$934>>1]|0;
      $936 = ($252<<16>>16)==($935<<16>>16);
      if ($936) {
       break L182;
      }
     }
    } while(0);
    $937 = (($928) + 1)|0;
    $938 = $937 & $15;
    $939 = ((($packets) + ($938<<4)|0) + 8|0);
    $940 = HEAP32[$939>>2]|0;
    $941 = ($940|0)==(-1);
    if ($941) {
     break L181;
    } else {
     $$pre322$pre = $940;$928 = $938;
    }
   }
   $942 = ($$pre322$pre|0)==(-1);
   $943 = (($packets) + ($928<<4)|0);
   $944 = ($943|0)==(0|0);
   $or$cond212 = $942 | $944;
   if ($or$cond212) {
    break;
   }
   $945 = ((($packetSections) + (($928*216)|0)|0) + 160|0);
   $946 = HEAP32[$945>>2]|0;
   $947 = (($packetHalo) + 752|0);
   HEAP32[$947>>2] = $946;
   $948 = ((($packetSections) + (($928*216)|0)|0) + 52|0);
   $949 = HEAP32[$948>>2]|0;
   $950 = (($packetHalo) + 360|0);
   HEAP32[$950>>2] = $949;
  }
 } while(0);
 $951 = (($921) + ($338))|0;
 $952 = $951 & $15;
 $953 = ((($packets) + ($952<<4)|0) + 8|0);
 $954 = HEAP32[$953>>2]|0;
 $955 = ($954|0)==(-1);
 L191: do {
  if (!($955)) {
   $$pre324$pre = $954;$957 = $952;
   L192: while(1) {
    $956 = (($packets) + ($957<<4)|0);
    $958 = HEAP16[$956>>1]|0;
    $959 = ($418<<16>>16)==($958<<16>>16);
    do {
     if ($959) {
      $960 = ((($packets) + ($957<<4)|0) + 2|0);
      $961 = HEAP16[$960>>1]|0;
      $962 = ($83<<16>>16)==($961<<16>>16);
      if (!($962)) {
       break;
      }
      $963 = ((($packets) + ($957<<4)|0) + 4|0);
      $964 = HEAP16[$963>>1]|0;
      $965 = ($336<<16>>16)==($964<<16>>16);
      if ($965) {
       break L192;
      }
     }
    } while(0);
    $966 = (($957) + 1)|0;
    $967 = $966 & $15;
    $968 = ((($packets) + ($967<<4)|0) + 8|0);
    $969 = HEAP32[$968>>2]|0;
    $970 = ($969|0)==(-1);
    if ($970) {
     break L191;
    } else {
     $$pre324$pre = $969;$957 = $967;
    }
   }
   $971 = ($$pre324$pre|0)==(-1);
   $972 = (($packets) + ($957<<4)|0);
   $973 = ($972|0)==(0|0);
   $or$cond214 = $971 | $973;
   if ($or$cond214) {
    break;
   }
   $974 = ((($packetSections) + (($957*216)|0)|0) + 156|0);
   $975 = HEAP32[$974>>2]|0;
   $976 = (($packetHalo) + 756|0);
   HEAP32[$976>>2] = $975;
   $977 = ((($packetSections) + (($957*216)|0)|0) + 48|0);
   $978 = HEAP32[$977>>2]|0;
   $979 = (($packetHalo) + 364|0);
   HEAP32[$979>>2] = $978;
  }
 } while(0);
 $980 = (($172) + ($419))|0;
 $981 = (($980) + ($257))|0;
 $982 = $981 & $15;
 $983 = ((($packets) + ($982<<4)|0) + 8|0);
 $984 = HEAP32[$983>>2]|0;
 $985 = ($984|0)==(-1);
 L201: do {
  if (!($985)) {
   $$pre326$pre = $984;$987 = $982;
   L202: while(1) {
    $986 = (($packets) + ($987<<4)|0);
    $988 = HEAP16[$986>>1]|0;
    $989 = ($418<<16>>16)==($988<<16>>16);
    do {
     if ($989) {
      $990 = ((($packets) + ($987<<4)|0) + 2|0);
      $991 = HEAP16[$990>>1]|0;
      $992 = ($170<<16>>16)==($991<<16>>16);
      if (!($992)) {
       break;
      }
      $993 = ((($packets) + ($987<<4)|0) + 4|0);
      $994 = HEAP16[$993>>1]|0;
      $995 = ($252<<16>>16)==($994<<16>>16);
      if ($995) {
       break L202;
      }
     }
    } while(0);
    $996 = (($987) + 1)|0;
    $997 = $996 & $15;
    $998 = ((($packets) + ($997<<4)|0) + 8|0);
    $999 = HEAP32[$998>>2]|0;
    $1000 = ($999|0)==(-1);
    if ($1000) {
     break L201;
    } else {
     $$pre326$pre = $999;$987 = $997;
    }
   }
   $1001 = ($$pre326$pre|0)==(-1);
   $1002 = (($packets) + ($987<<4)|0);
   $1003 = ($1002|0)==(0|0);
   $or$cond216 = $1001 | $1003;
   if ($or$cond216) {
    break;
   }
   $1004 = ((($packetSections) + (($987*216)|0)|0) + 148|0);
   $1005 = HEAP32[$1004>>2]|0;
   $1006 = (($packetHalo) + 760|0);
   HEAP32[$1006>>2] = $1005;
   $1007 = ((($packetSections) + (($987*216)|0)|0) + 40|0);
   $1008 = HEAP32[$1007>>2]|0;
   $1009 = (($packetHalo) + 368|0);
   HEAP32[$1009>>2] = $1008;
  }
 } while(0);
 $1010 = (($980) + ($338))|0;
 $1011 = $1010 & $15;
 $1012 = ((($packets) + ($1011<<4)|0) + 8|0);
 $1013 = HEAP32[$1012>>2]|0;
 $1014 = ($1013|0)==(-1);
 L211: do {
  if (!($1014)) {
   $$pre328$pre = $1013;$1016 = $1011;
   L212: while(1) {
    $1015 = (($packets) + ($1016<<4)|0);
    $1017 = HEAP16[$1015>>1]|0;
    $1018 = ($418<<16>>16)==($1017<<16>>16);
    do {
     if ($1018) {
      $1019 = ((($packets) + ($1016<<4)|0) + 2|0);
      $1020 = HEAP16[$1019>>1]|0;
      $1021 = ($170<<16>>16)==($1020<<16>>16);
      if (!($1021)) {
       break;
      }
      $1022 = ((($packets) + ($1016<<4)|0) + 4|0);
      $1023 = HEAP16[$1022>>1]|0;
      $1024 = ($336<<16>>16)==($1023<<16>>16);
      if ($1024) {
       break L212;
      }
     }
    } while(0);
    $1025 = (($1016) + 1)|0;
    $1026 = $1025 & $15;
    $1027 = ((($packets) + ($1026<<4)|0) + 8|0);
    $1028 = HEAP32[$1027>>2]|0;
    $1029 = ($1028|0)==(-1);
    if ($1029) {
     break L211;
    } else {
     $$pre328$pre = $1028;$1016 = $1026;
    }
   }
   $1030 = ($$pre328$pre|0)==(-1);
   $1031 = (($packets) + ($1016<<4)|0);
   $1032 = ($1031|0)==(0|0);
   $or$cond218 = $1030 | $1032;
   if ($or$cond218) {
    break;
   }
   $1033 = ((($packetSections) + (($1016*216)|0)|0) + 144|0);
   $1034 = HEAP32[$1033>>2]|0;
   $1035 = (($packetHalo) + 764|0);
   HEAP32[$1035>>2] = $1034;
   $1036 = ((($packetSections) + (($1016*216)|0)|0) + 36|0);
   $1037 = HEAP32[$1036>>2]|0;
   $1038 = (($packetHalo) + 372|0);
   HEAP32[$1038>>2] = $1037;
  }
 } while(0);
 $1039 = (($87) + ($464))|0;
 $1040 = (($1039) + ($257))|0;
 $1041 = $1040 & $15;
 $1042 = ((($packets) + ($1041<<4)|0) + 8|0);
 $1043 = HEAP32[$1042>>2]|0;
 $1044 = ($1043|0)==(-1);
 L221: do {
  if (!($1044)) {
   $$pre330$pre = $1043;$1046 = $1041;
   L222: while(1) {
    $1045 = (($packets) + ($1046<<4)|0);
    $1047 = HEAP16[$1045>>1]|0;
    $1048 = ($463<<16>>16)==($1047<<16>>16);
    do {
     if ($1048) {
      $1049 = ((($packets) + ($1046<<4)|0) + 2|0);
      $1050 = HEAP16[$1049>>1]|0;
      $1051 = ($83<<16>>16)==($1050<<16>>16);
      if (!($1051)) {
       break;
      }
      $1052 = ((($packets) + ($1046<<4)|0) + 4|0);
      $1053 = HEAP16[$1052>>1]|0;
      $1054 = ($252<<16>>16)==($1053<<16>>16);
      if ($1054) {
       break L222;
      }
     }
    } while(0);
    $1055 = (($1046) + 1)|0;
    $1056 = $1055 & $15;
    $1057 = ((($packets) + ($1056<<4)|0) + 8|0);
    $1058 = HEAP32[$1057>>2]|0;
    $1059 = ($1058|0)==(-1);
    if ($1059) {
     break L221;
    } else {
     $$pre330$pre = $1058;$1046 = $1056;
    }
   }
   $1060 = ($$pre330$pre|0)==(-1);
   $1061 = (($packets) + ($1046<<4)|0);
   $1062 = ($1061|0)==(0|0);
   $or$cond220 = $1060 | $1062;
   if ($or$cond220) {
    break;
   }
   $1063 = ((($packetSections) + (($1046*216)|0)|0) + 124|0);
   $1064 = HEAP32[$1063>>2]|0;
   $1065 = (($packetHalo) + 768|0);
   HEAP32[$1065>>2] = $1064;
   $1066 = ((($packetSections) + (($1046*216)|0)|0) + 16|0);
   $1067 = HEAP32[$1066>>2]|0;
   $1068 = (($packetHalo) + 376|0);
   HEAP32[$1068>>2] = $1067;
  }
 } while(0);
 $1069 = (($1039) + ($338))|0;
 $1070 = $1069 & $15;
 $1071 = ((($packets) + ($1070<<4)|0) + 8|0);
 $1072 = HEAP32[$1071>>2]|0;
 $1073 = ($1072|0)==(-1);
 L231: do {
  if (!($1073)) {
   $$pre332$pre = $1072;$1075 = $1070;
   L232: while(1) {
    $1074 = (($packets) + ($1075<<4)|0);
    $1076 = HEAP16[$1074>>1]|0;
    $1077 = ($463<<16>>16)==($1076<<16>>16);
    do {
     if ($1077) {
      $1078 = ((($packets) + ($1075<<4)|0) + 2|0);
      $1079 = HEAP16[$1078>>1]|0;
      $1080 = ($83<<16>>16)==($1079<<16>>16);
      if (!($1080)) {
       break;
      }
      $1081 = ((($packets) + ($1075<<4)|0) + 4|0);
      $1082 = HEAP16[$1081>>1]|0;
      $1083 = ($336<<16>>16)==($1082<<16>>16);
      if ($1083) {
       break L232;
      }
     }
    } while(0);
    $1084 = (($1075) + 1)|0;
    $1085 = $1084 & $15;
    $1086 = ((($packets) + ($1085<<4)|0) + 8|0);
    $1087 = HEAP32[$1086>>2]|0;
    $1088 = ($1087|0)==(-1);
    if ($1088) {
     break L231;
    } else {
     $$pre332$pre = $1087;$1075 = $1085;
    }
   }
   $1089 = ($$pre332$pre|0)==(-1);
   $1090 = (($packets) + ($1075<<4)|0);
   $1091 = ($1090|0)==(0|0);
   $or$cond222 = $1089 | $1091;
   if ($or$cond222) {
    break;
   }
   $1092 = ((($packetSections) + (($1075*216)|0)|0) + 120|0);
   $1093 = HEAP32[$1092>>2]|0;
   $1094 = (($packetHalo) + 772|0);
   HEAP32[$1094>>2] = $1093;
   $1095 = ((($packetSections) + (($1075*216)|0)|0) + 12|0);
   $1096 = HEAP32[$1095>>2]|0;
   $1097 = (($packetHalo) + 380|0);
   HEAP32[$1097>>2] = $1096;
  }
 } while(0);
 $1098 = (($172) + ($464))|0;
 $1099 = (($1098) + ($257))|0;
 $1100 = $1099 & $15;
 $1101 = ((($packets) + ($1100<<4)|0) + 8|0);
 $1102 = HEAP32[$1101>>2]|0;
 $1103 = ($1102|0)==(-1);
 L241: do {
  if (!($1103)) {
   $$pre334$pre = $1102;$1105 = $1100;
   L242: while(1) {
    $1104 = (($packets) + ($1105<<4)|0);
    $1106 = HEAP16[$1104>>1]|0;
    $1107 = ($463<<16>>16)==($1106<<16>>16);
    do {
     if ($1107) {
      $1108 = ((($packets) + ($1105<<4)|0) + 2|0);
      $1109 = HEAP16[$1108>>1]|0;
      $1110 = ($170<<16>>16)==($1109<<16>>16);
      if (!($1110)) {
       break;
      }
      $1111 = ((($packets) + ($1105<<4)|0) + 4|0);
      $1112 = HEAP16[$1111>>1]|0;
      $1113 = ($252<<16>>16)==($1112<<16>>16);
      if ($1113) {
       break L242;
      }
     }
    } while(0);
    $1114 = (($1105) + 1)|0;
    $1115 = $1114 & $15;
    $1116 = ((($packets) + ($1115<<4)|0) + 8|0);
    $1117 = HEAP32[$1116>>2]|0;
    $1118 = ($1117|0)==(-1);
    if ($1118) {
     break L241;
    } else {
     $$pre334$pre = $1117;$1105 = $1115;
    }
   }
   $1119 = ($$pre334$pre|0)==(-1);
   $1120 = (($packets) + ($1105<<4)|0);
   $1121 = ($1120|0)==(0|0);
   $or$cond224 = $1119 | $1121;
   if ($or$cond224) {
    break;
   }
   $1122 = ((($packetSections) + (($1105*216)|0)|0) + 112|0);
   $1123 = HEAP32[$1122>>2]|0;
   $1124 = (($packetHalo) + 776|0);
   HEAP32[$1124>>2] = $1123;
   $1125 = ((($packetSections) + (($1105*216)|0)|0) + 4|0);
   $1126 = HEAP32[$1125>>2]|0;
   $1127 = (($packetHalo) + 384|0);
   HEAP32[$1127>>2] = $1126;
  }
 } while(0);
 $1128 = (($1098) + ($338))|0;
 $1129 = $1128 & $15;
 $1130 = ((($packets) + ($1129<<4)|0) + 8|0);
 $1131 = HEAP32[$1130>>2]|0;
 $1132 = ($1131|0)==(-1);
 L251: do {
  if (!($1132)) {
   $$pre336$pre = $1131;$1134 = $1129;
   L252: while(1) {
    $1133 = (($packets) + ($1134<<4)|0);
    $1135 = HEAP16[$1133>>1]|0;
    $1136 = ($463<<16>>16)==($1135<<16>>16);
    do {
     if ($1136) {
      $1137 = ((($packets) + ($1134<<4)|0) + 2|0);
      $1138 = HEAP16[$1137>>1]|0;
      $1139 = ($170<<16>>16)==($1138<<16>>16);
      if (!($1139)) {
       break;
      }
      $1140 = ((($packets) + ($1134<<4)|0) + 4|0);
      $1141 = HEAP16[$1140>>1]|0;
      $1142 = ($336<<16>>16)==($1141<<16>>16);
      if ($1142) {
       break L252;
      }
     }
    } while(0);
    $1143 = (($1134) + 1)|0;
    $1144 = $1143 & $15;
    $1145 = ((($packets) + ($1144<<4)|0) + 8|0);
    $1146 = HEAP32[$1145>>2]|0;
    $1147 = ($1146|0)==(-1);
    if ($1147) {
     break L251;
    } else {
     $$pre336$pre = $1146;$1134 = $1144;
    }
   }
   $1148 = ($$pre336$pre|0)==(-1);
   $1149 = (($packets) + ($1134<<4)|0);
   $1150 = ($1149|0)==(0|0);
   $or$cond226 = $1148 | $1150;
   if ($or$cond226) {
    break;
   }
   $1151 = ((($packetSections) + (($1134*216)|0)|0) + 108|0);
   $1152 = HEAP32[$1151>>2]|0;
   $1153 = (($packetHalo) + 780|0);
   HEAP32[$1153>>2] = $1152;
   $1154 = (($packetSections) + (($1134*216)|0)|0);
   $1155 = HEAP32[$1154>>2]|0;
   $1156 = (($packetHalo) + 388|0);
   HEAP32[$1156>>2] = $1155;
  }
 } while(0);
 $1157 = (($packetHalo) + 784|0);
 $1161 = 0;$i$0280 = 0;
 while(1) {
  $1158 = (($packetHalo) + ($i$0280<<2)|0);
  $1159 = HEAP32[$1158>>2]|0;
  $1160 = ($1161>>>0)<($1159>>>0);
  $1162 = $1160 ? $1159 : $1161;
  HEAP32[$1157>>2] = $1162;
  $1163 = (($i$0280) + 1)|0;
  $exitcond = ($1163|0)==(98);
  if ($exitcond) {
   break;
  } else {
   $1161 = $1162;$i$0280 = $1163;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx19PxsFluidSpatialHash14buildLocalHashEPKNS_16PxsFluidParticleEjPNS_15PxsParticleCellEPjPtjfRKNS_6PxVec3E($particles,$numParticles,$cells,$particleIndices,$hashKeyArray,$numHashBuckets,$cellSizeInv,$packetCorner) {
 $particles = $particles|0;
 $numParticles = $numParticles|0;
 $cells = $cells|0;
 $particleIndices = $particleIndices|0;
 $hashKeyArray = $hashKeyArray|0;
 $numHashBuckets = $numHashBuckets|0;
 $cellSizeInv = Math_fround($cellSizeInv);
 $packetCorner = $packetCorner|0;
 var $$fakeParticle = 0, $$fakeParticle4 = 0, $$lcssa$i$ph = 0, $$lcssa$i69 = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0;
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0);
 var $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0;
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0;
 var $98 = 0, $99 = Math_fround(0), $c$02$i = 0, $c$061 = 0, $c1$056 = 0, $cellCoords = 0, $cellFirstParticle$055 = 0, $cellFirstParticle$1 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond5$i = 0, $exitcond65 = 0, $exitcond66 = 0, $fakeParticle = 0, $i$057 = 0, $p$01$i = 0, $p$058 = 0, $sext = 0, $sext53 = 0, $sext54 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $fakeParticle = sp + 96|0;
 $cellCoords = sp;
 $0 = ($numHashBuckets|0)==(0);
 if (!($0)) {
  $c$061 = 0;
  while(1) {
   $1 = ((($cells) + ($c$061<<4)|0) + 8|0);
   HEAP32[$1>>2] = -1;
   $2 = (($c$061) + 1)|0;
   $exitcond66 = ($2|0)==($numHashBuckets|0);
   if ($exitcond66) {
    break;
   } else {
    $c$061 = $2;
   }
  }
 }
 HEAPF32[$fakeParticle>>2] = Math_fround(3.40282346638528859812E+38);
 $3 = (($fakeParticle) + 4|0);
 HEAPF32[$3>>2] = Math_fround(3.40282346638528859812E+38);
 $4 = (($fakeParticle) + 8|0);
 HEAPF32[$4>>2] = Math_fround(3.40282346638528859812E+38);
 $5 = (($numParticles) + 7)|0;
 $6 = $5 & -4;
 $7 = ($numParticles>>>0)>(1);
 $8 = (($particles) + 32|0);
 $$fakeParticle = $7 ? $8 : $fakeParticle;
 $9 = ($numParticles>>>0)>(2);
 $10 = (($particles) + 64|0);
 $11 = $9 ? $10 : $fakeParticle;
 $12 = ($numParticles>>>0)>(3);
 $13 = (($particles) + 96|0);
 $$fakeParticle4 = $12 ? $13 : $fakeParticle;
 $14 = Math_fround(HEAPF32[$particles>>2]);
 $15 = Math_fround(HEAPF32[$packetCorner>>2]);
 $16 = Math_fround($14 - $15);
 $17 = (($particles) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($packetCorner) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 - $20);
 $22 = (($particles) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($packetCorner) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 - $25);
 $27 = Math_fround($16 * $cellSizeInv);
 $28 = (Math_fround(Math_floor((Math_fround($27)))));
 $29 = (~~(($28)));
 HEAP32[$cellCoords>>2] = $29;
 $30 = Math_fround($21 * $cellSizeInv);
 $31 = (Math_fround(Math_floor((Math_fround($30)))));
 $32 = (~~(($31)));
 $33 = (($cellCoords) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = Math_fround($26 * $cellSizeInv);
 $35 = (Math_fround(Math_floor((Math_fround($34)))));
 $36 = (~~(($35)));
 $37 = (($cellCoords) + 8|0);
 HEAP32[$37>>2] = $36;
 $38 = Math_fround(HEAPF32[$$fakeParticle>>2]);
 $39 = Math_fround($38 - $15);
 $40 = (($$fakeParticle) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 - $20);
 $43 = (($$fakeParticle) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 - $25);
 $46 = Math_fround($39 * $cellSizeInv);
 $47 = (Math_fround(Math_floor((Math_fround($46)))));
 $48 = (~~(($47)));
 $49 = (($cellCoords) + 12|0);
 HEAP32[$49>>2] = $48;
 $50 = Math_fround($42 * $cellSizeInv);
 $51 = (Math_fround(Math_floor((Math_fround($50)))));
 $52 = (~~(($51)));
 $53 = (($cellCoords) + 16|0);
 HEAP32[$53>>2] = $52;
 $54 = Math_fround($45 * $cellSizeInv);
 $55 = (Math_fround(Math_floor((Math_fround($54)))));
 $56 = (~~(($55)));
 $57 = (($cellCoords) + 20|0);
 HEAP32[$57>>2] = $56;
 $58 = Math_fround(HEAPF32[$11>>2]);
 $59 = Math_fround($58 - $15);
 $60 = (($11) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 - $20);
 $63 = (($11) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 - $25);
 $66 = Math_fround($59 * $cellSizeInv);
 $67 = (Math_fround(Math_floor((Math_fround($66)))));
 $68 = (~~(($67)));
 $69 = (($cellCoords) + 24|0);
 HEAP32[$69>>2] = $68;
 $70 = Math_fround($62 * $cellSizeInv);
 $71 = (Math_fround(Math_floor((Math_fround($70)))));
 $72 = (~~(($71)));
 $73 = (($cellCoords) + 28|0);
 HEAP32[$73>>2] = $72;
 $74 = Math_fround($65 * $cellSizeInv);
 $75 = (Math_fround(Math_floor((Math_fround($74)))));
 $76 = (~~(($75)));
 $77 = (($cellCoords) + 32|0);
 HEAP32[$77>>2] = $76;
 $78 = Math_fround(HEAPF32[$$fakeParticle4>>2]);
 $79 = Math_fround($78 - $15);
 $80 = (($$fakeParticle4) + 4|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 - $20);
 $83 = (($$fakeParticle4) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 - $25);
 $86 = Math_fround($79 * $cellSizeInv);
 $87 = (Math_fround(Math_floor((Math_fround($86)))));
 $88 = (~~(($87)));
 $89 = (($cellCoords) + 36|0);
 HEAP32[$89>>2] = $88;
 $90 = Math_fround($82 * $cellSizeInv);
 $91 = (Math_fround(Math_floor((Math_fround($90)))));
 $92 = (~~(($91)));
 $93 = (($cellCoords) + 40|0);
 HEAP32[$93>>2] = $92;
 $94 = Math_fround($85 * $cellSizeInv);
 $95 = (Math_fround(Math_floor((Math_fround($94)))));
 $96 = (~~(($95)));
 $97 = (($cellCoords) + 44|0);
 HEAP32[$97>>2] = $96;
 $98 = ($6|0)==(0);
 if (!($98)) {
  $99 = Math_fround(HEAPF32[$packetCorner>>2]);
  $100 = (($numHashBuckets) + -1)|0;
  $p$058 = 0;
  while(1) {
   $102 = (($p$058) + 4)|0;
   $103 = ($102>>>0)<($numParticles>>>0);
   if ($103) {
    $104 = (($particles) + ($102<<5)|0);
    $116 = $104;
   } else {
    $116 = $fakeParticle;
   }
   $105 = (($p$058) + 5)|0;
   $106 = ($105>>>0)<($numParticles>>>0);
   if ($106) {
    $107 = (($particles) + ($105<<5)|0);
    $138 = $107;
   } else {
    $138 = $fakeParticle;
   }
   $108 = (($p$058) + 6)|0;
   $109 = ($108>>>0)<($numParticles>>>0);
   if ($109) {
    $110 = (($particles) + ($108<<5)|0);
    $160 = $110;
   } else {
    $160 = $fakeParticle;
   }
   $111 = (($p$058) + 7)|0;
   $112 = ($111>>>0)<($numParticles>>>0);
   if ($112) {
    $113 = (($particles) + ($111<<5)|0);
    $182 = $113;
   } else {
    $182 = $fakeParticle;
   }
   $114 = $102 & 4;
   $115 = Math_fround(HEAPF32[$116>>2]);
   $117 = Math_fround($115 - $99);
   $118 = (($116) + 4|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = Math_fround($119 - $20);
   $121 = (($116) + 8|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = Math_fround($122 - $25);
   $124 = Math_fround($117 * $cellSizeInv);
   $125 = (Math_fround(Math_floor((Math_fround($124)))));
   $126 = (~~(($125)));
   $127 = (($cellCoords) + (($114*12)|0)|0);
   HEAP32[$127>>2] = $126;
   $128 = Math_fround($120 * $cellSizeInv);
   $129 = (Math_fround(Math_floor((Math_fround($128)))));
   $130 = (~~(($129)));
   $131 = ((($cellCoords) + (($114*12)|0)|0) + 4|0);
   HEAP32[$131>>2] = $130;
   $132 = Math_fround($123 * $cellSizeInv);
   $133 = (Math_fround(Math_floor((Math_fround($132)))));
   $134 = (~~(($133)));
   $135 = ((($cellCoords) + (($114*12)|0)|0) + 8|0);
   HEAP32[$135>>2] = $134;
   $136 = $114 | 1;
   $137 = Math_fround(HEAPF32[$138>>2]);
   $139 = Math_fround($137 - $99);
   $140 = (($138) + 4|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = Math_fround($141 - $20);
   $143 = (($138) + 8|0);
   $144 = Math_fround(HEAPF32[$143>>2]);
   $145 = Math_fround($144 - $25);
   $146 = Math_fround($139 * $cellSizeInv);
   $147 = (Math_fround(Math_floor((Math_fround($146)))));
   $148 = (~~(($147)));
   $149 = (($cellCoords) + (($136*12)|0)|0);
   HEAP32[$149>>2] = $148;
   $150 = Math_fround($142 * $cellSizeInv);
   $151 = (Math_fround(Math_floor((Math_fround($150)))));
   $152 = (~~(($151)));
   $153 = ((($cellCoords) + (($136*12)|0)|0) + 4|0);
   HEAP32[$153>>2] = $152;
   $154 = Math_fround($145 * $cellSizeInv);
   $155 = (Math_fround(Math_floor((Math_fround($154)))));
   $156 = (~~(($155)));
   $157 = ((($cellCoords) + (($136*12)|0)|0) + 8|0);
   HEAP32[$157>>2] = $156;
   $158 = $114 | 2;
   $159 = Math_fround(HEAPF32[$160>>2]);
   $161 = Math_fround($159 - $99);
   $162 = (($160) + 4|0);
   $163 = Math_fround(HEAPF32[$162>>2]);
   $164 = Math_fround($163 - $20);
   $165 = (($160) + 8|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   $167 = Math_fround($166 - $25);
   $168 = Math_fround($161 * $cellSizeInv);
   $169 = (Math_fround(Math_floor((Math_fround($168)))));
   $170 = (~~(($169)));
   $171 = (($cellCoords) + (($158*12)|0)|0);
   HEAP32[$171>>2] = $170;
   $172 = Math_fround($164 * $cellSizeInv);
   $173 = (Math_fround(Math_floor((Math_fround($172)))));
   $174 = (~~(($173)));
   $175 = ((($cellCoords) + (($158*12)|0)|0) + 4|0);
   HEAP32[$175>>2] = $174;
   $176 = Math_fround($167 * $cellSizeInv);
   $177 = (Math_fround(Math_floor((Math_fround($176)))));
   $178 = (~~(($177)));
   $179 = ((($cellCoords) + (($158*12)|0)|0) + 8|0);
   HEAP32[$179>>2] = $178;
   $180 = $114 | 3;
   $181 = Math_fround(HEAPF32[$182>>2]);
   $183 = Math_fround($181 - $99);
   $184 = (($182) + 4|0);
   $185 = Math_fround(HEAPF32[$184>>2]);
   $186 = Math_fround($185 - $20);
   $187 = (($182) + 8|0);
   $188 = Math_fround(HEAPF32[$187>>2]);
   $189 = Math_fround($188 - $25);
   $190 = Math_fround($183 * $cellSizeInv);
   $191 = (Math_fround(Math_floor((Math_fround($190)))));
   $192 = (~~(($191)));
   $193 = (($cellCoords) + (($180*12)|0)|0);
   HEAP32[$193>>2] = $192;
   $194 = Math_fround($186 * $cellSizeInv);
   $195 = (Math_fround(Math_floor((Math_fround($194)))));
   $196 = (~~(($195)));
   $197 = ((($cellCoords) + (($180*12)|0)|0) + 4|0);
   HEAP32[$197>>2] = $196;
   $198 = Math_fround($189 * $cellSizeInv);
   $199 = (Math_fround(Math_floor((Math_fround($198)))));
   $200 = (~~(($199)));
   $201 = ((($cellCoords) + (($180*12)|0)|0) + 8|0);
   HEAP32[$201>>2] = $200;
   $202 = $p$058 & 4;
   $i$057 = 0;
   while(1) {
    $203 = (($i$057) + ($p$058))|0;
    $204 = ($203>>>0)<($numParticles>>>0);
    L23: do {
     if ($204) {
      $205 = (($i$057) + ($202))|0;
      $206 = (($cellCoords) + (($205*12)|0)|0);
      $207 = HEAP32[$206>>2]|0;
      $208 = $207&65535;
      $209 = ((($cellCoords) + (($205*12)|0)|0) + 4|0);
      $210 = HEAP32[$209>>2]|0;
      $211 = $210&65535;
      $212 = ((($cellCoords) + (($205*12)|0)|0) + 8|0);
      $213 = HEAP32[$212>>2]|0;
      $214 = $213&65535;
      $sext = $207 << 16;
      $215 = $sext >> 16;
      $sext53 = $210 << 16;
      $216 = $sext53 >> 16;
      $217 = ($216*101)|0;
      $218 = (($217) + ($215))|0;
      $sext54 = $213 << 16;
      $219 = $sext54 >> 16;
      $220 = ($219*7919)|0;
      $221 = (($218) + ($220))|0;
      $222 = $221 & $100;
      $223 = ((($cells) + ($222<<4)|0) + 8|0);
      $224 = HEAP32[$223>>2]|0;
      $225 = ($224|0)==(-1);
      L25: do {
       if ($225) {
        $$lcssa$i$ph = $222;
        label = 22;
       } else {
        $$pre$pre = $224;$227 = $222;
        while(1) {
         $226 = (($cells) + ($227<<4)|0);
         $228 = HEAP16[$226>>1]|0;
         $229 = ($208<<16>>16)==($228<<16>>16);
         if ($229) {
          $230 = ((($cells) + ($227<<4)|0) + 2|0);
          $231 = HEAP16[$230>>1]|0;
          $232 = ($211<<16>>16)==($231<<16>>16);
          if ($232) {
           $233 = ((($cells) + ($227<<4)|0) + 4|0);
           $234 = HEAP16[$233>>1]|0;
           $235 = ($214<<16>>16)==($234<<16>>16);
           if ($235) {
            break;
           }
          }
         }
         $236 = (($227) + 1)|0;
         $237 = $236 & $100;
         $238 = ((($cells) + ($237<<4)|0) + 8|0);
         $239 = HEAP32[$238>>2]|0;
         $240 = ($239|0)==(-1);
         if ($240) {
          $$lcssa$i$ph = $237;
          label = 22;
          break L25;
         } else {
          $$pre$pre = $239;$227 = $237;
         }
        }
        $244 = $227&65535;
        $245 = (($hashKeyArray) + ($203<<1)|0);
        HEAP16[$245>>1] = $244;
        $246 = ((($cells) + ($227<<4)|0) + 8|0);
        $247 = ($$pre$pre|0)==(-1);
        if ($247) {
         $$lcssa$i69 = $227;$251 = $246;
        } else {
         $252 = (($$pre$pre) + 1)|0;
         HEAP32[$246>>2] = $252;
         break L23;
        }
       }
      } while(0);
      if ((label|0) == 22) {
       label = 0;
       $241 = $$lcssa$i$ph&65535;
       $242 = (($hashKeyArray) + ($203<<1)|0);
       HEAP16[$242>>1] = $241;
       $243 = ((($cells) + ($$lcssa$i$ph<<4)|0) + 8|0);
       $$lcssa$i69 = $$lcssa$i$ph;$251 = $243;
      }
      $248 = (($cells) + ($$lcssa$i69<<4)|0);
      HEAP16[$248>>1] = $208;
      $249 = ((($cells) + ($$lcssa$i69<<4)|0) + 2|0);
      HEAP16[$249>>1] = $211;
      $250 = ((($cells) + ($$lcssa$i69<<4)|0) + 4|0);
      HEAP16[$250>>1] = $214;
      HEAP32[$251>>2] = 1;
     }
    } while(0);
    $253 = (($i$057) + 1)|0;
    $exitcond65 = ($253|0)==(4);
    if ($exitcond65) {
     break;
    } else {
     $i$057 = $253;
    }
   }
   $101 = ($102>>>0)<($6>>>0);
   if ($101) {
    $p$058 = $102;
   } else {
    break;
   }
  }
 }
 if (!($0)) {
  $c1$056 = 0;$cellFirstParticle$055 = 0;
  while(1) {
   $254 = ((($cells) + ($c1$056<<4)|0) + 8|0);
   $255 = HEAP32[$254>>2]|0;
   $256 = ($255|0)==(-1);
   if ($256) {
    $cellFirstParticle$1 = $cellFirstParticle$055;
   } else {
    $257 = ((($cells) + ($c1$056<<4)|0) + 12|0);
    HEAP32[$257>>2] = $cellFirstParticle$055;
    $258 = (($255) + ($cellFirstParticle$055))|0;
    $cellFirstParticle$1 = $258;
   }
   $259 = (($c1$056) + 1)|0;
   $exitcond = ($259|0)==($numHashBuckets|0);
   if ($exitcond) {
    break;
   } else {
    $c1$056 = $259;$cellFirstParticle$055 = $cellFirstParticle$1;
   }
  }
  if (!($0)) {
   $c$02$i = 0;
   while(1) {
    $261 = ((($cells) + ($c$02$i<<4)|0) + 8|0);
    $262 = HEAP32[$261>>2]|0;
    $263 = ($262|0)==(-1);
    if (!($263)) {
     HEAP32[$261>>2] = 0;
    }
    $264 = (($c$02$i) + 1)|0;
    $exitcond5$i = ($264|0)==($numHashBuckets|0);
    if ($exitcond5$i) {
     break;
    } else {
     $c$02$i = $264;
    }
   }
  }
 }
 $260 = ($numParticles|0)==(0);
 if ($260) {
  STACKTOP = sp;return;
 } else {
  $p$01$i = 0;
 }
 while(1) {
  $265 = (($hashKeyArray) + ($p$01$i<<1)|0);
  $266 = HEAP16[$265>>1]|0;
  $267 = $266&65535;
  $268 = ((($cells) + ($267<<4)|0) + 12|0);
  $269 = HEAP32[$268>>2]|0;
  $270 = ((($cells) + ($267<<4)|0) + 8|0);
  $271 = HEAP32[$270>>2]|0;
  $272 = (($271) + ($269))|0;
  $273 = (($particleIndices) + ($272<<2)|0);
  HEAP32[$273>>2] = $p$01$i;
  $274 = HEAP32[$270>>2]|0;
  $275 = (($274) + 1)|0;
  HEAP32[$270>>2] = $275;
  $276 = (($p$01$i) + 1)|0;
  $exitcond$i = ($276|0)==($numParticles|0);
  if ($exitcond$i) {
   break;
  } else {
   $p$01$i = $276;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManagerC2EjRNS_19PxcScratchAllocatorEPNS_2Cm13EventProfilerE($this,$rigidBodyOffset,$scratchAllocator,$eventProfiler) {
 $this = $this|0;
 $rigidBodyOffset = $rigidBodyOffset|0;
 $scratchAllocator = $scratchAllocator|0;
 $eventProfiler = $eventProfiler|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $rigidBodyOffset;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $scratchAllocator;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $eventProfiler;
 $2 = (($this) + 12|0);
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = -1;
 HEAP32[$2>>2] = ((499496 + 8|0));
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 44|0);
 $11 = (($this) + 92|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 96|0);
 $13 = (($this) + 100|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 104|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 108|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 112|0);
 HEAP32[$16>>2] = -1;
 HEAP32[$12>>2] = ((499520 + 8|0));
 $17 = (($this) + 116|0);
 $18 = (($this) + 184|0);
 $19 = (($this) + 188|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 192|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 196|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 200|0);
 dest=$17+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$22>>2] = -1;
 HEAP32[$18>>2] = ((499544 + 8|0));
 $23 = (($this) + 216|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 220|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 224|0);
 $26 = (($this) + 228|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 232|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 236|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 240|0);
 HEAP32[$29>>2] = -1;
 HEAP32[$25>>2] = ((499568 + 8|0));
 $30 = (($this) + 400|0);
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP32[$30+16>>2]=0|0;
 $31 = (($this) + 244|0);
 $32 = (($this) + 273|0);
 ;HEAP32[$31+0>>2]=0|0;HEAP32[$31+4>>2]=0|0;HEAP32[$31+8>>2]=0|0;HEAP32[$31+12>>2]=0|0;HEAP32[$31+16>>2]=0|0;HEAP32[$31+20>>2]=0|0;HEAP32[$31+24>>2]=0|0;HEAP8[$31+28>>0]=0|0;
 HEAP8[$32>>0] = 1;
 $33 = (($this) + 274|0);
 HEAP8[$33>>0] = 0;
 $34 = (($this) + 436|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 440|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 444|0);
 $37 = (($this) + 456|0);
 HEAP32[$37>>2] = $36;
 $38 = (($this) + 460|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 464|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 468|0);
 $41 = (($this) + 480|0);
 HEAP32[$41>>2] = $40;
 $42 = (($this) + 484|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 488|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 492|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 276|0);
 $46 = (($this) + 420|0);
 dest=$45+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$46+0>>2]=0|0;HEAP32[$46+4>>2]=0|0;HEAP32[$46+8>>2]=0|0;HEAP32[$46+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManagerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 424|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$3);
 }
 $5 = (($this) + 224|0);
 HEAP32[$5>>2] = ((499568 + 8|0));
 $6 = (($this) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
 $8 = (($this) + 184|0);
 HEAP32[$8>>2] = ((499544 + 8|0));
 $9 = (($this) + 188|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$10);
 $11 = (($this) + 144|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$12);
 }
 $14 = (($this) + 120|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$15);
 }
 $17 = (($this) + 96|0);
 HEAP32[$17>>2] = ((499520 + 8|0));
 $18 = (($this) + 100|0);
 $19 = HEAP32[$18>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$19);
 $20 = (($this) + 12|0);
 HEAP32[$20>>2] = ((499496 + 8|0));
 $21 = (($this) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$22);
 STACKTOP = sp;return;
}
function __ZN5physx23ArticulationRootManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((499568 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 STACKTOP = sp;return;
}
function __ZN5physx13IslandManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((499544 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 STACKTOP = sp;return;
}
function __ZN5physx11EdgeManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((499520 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 STACKTOP = sp;return;
}
function __ZN5physx11NodeManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((499496 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager11preAllocateEj($this,$nbBodies) {
 $this = $this|0;
 $nbBodies = $nbBodies|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nbBodies|0)==(0);
 if ($0) {
  $1 = (($this) + 12|0);
  $2 = (($this) + 24|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3>>>0)<(256);
  if ($4) {
   $5 = HEAP32[$1>>2]|0;
   $6 = (($5) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   FUNCTION_TABLE_vii[$7 & 4095]($1,256);
  }
  $8 = (($this) + 96|0);
  $9 = (($this) + 108|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10>>>0)<(256);
  if ($11) {
   $12 = HEAP32[$8>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vii[$14 & 4095]($8,256);
  }
  $15 = (($this) + 120|0);
  __ZN5physx17NodeChangeManager4initEj($15,256);
  $16 = (($this) + 144|0);
  __ZN5physx17EdgeChangeManager4initEj($16,256);
  $17 = (($this) + 184|0);
  $18 = (($this) + 196|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19>>>0)<(256);
  if ($20) {
   $21 = HEAP32[$17>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($17,256);
  }
  $24 = (($this) + 224|0);
  $25 = (($this) + 236|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26>>>0)<(32);
  if (!($27)) {
   STACKTOP = sp;return;
  }
  $28 = HEAP32[$24>>2]|0;
  $29 = (($28) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  FUNCTION_TABLE_vii[$30 & 4095]($24,32);
  STACKTOP = sp;return;
 } else {
  $31 = (($nbBodies) + 31)|0;
  $32 = $31 & -32;
  $33 = (($this) + 12|0);
  $34 = (($this) + 24|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35>>>0)<($32>>>0);
  if ($36) {
   $37 = HEAP32[$33>>2]|0;
   $38 = (($37) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   FUNCTION_TABLE_vii[$39 & 4095]($33,$32);
  }
  $40 = (($this) + 96|0);
  $41 = $32 << 1;
  $42 = (($this) + 108|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43>>>0)<($41>>>0);
  if ($44) {
   $45 = HEAP32[$40>>2]|0;
   $46 = (($45) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($40,$41);
  }
  $48 = (($this) + 120|0);
  __ZN5physx17NodeChangeManager4initEj($48,$32);
  $49 = (($this) + 144|0);
  __ZN5physx17EdgeChangeManager4initEj($49,$41);
  $50 = (($this) + 184|0);
  $51 = (($this) + 196|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52>>>0)<($32>>>0);
  if ($53) {
   $54 = HEAP32[$50>>2]|0;
   $55 = (($54) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vii[$56 & 4095]($50,$32);
  }
  $57 = (($this) + 224|0);
  $58 = (($this) + 236|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($59>>>0)<(32);
  if (!($60)) {
   STACKTOP = sp;return;
  }
  $61 = HEAP32[$57>>2]|0;
  $62 = (($61) + 8|0);
  $63 = HEAP32[$62>>2]|0;
  FUNCTION_TABLE_vii[$63 & 4095]($57,32);
  STACKTOP = sp;return;
 }
}
function __ZN5physx17NodeChangeManager4initEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  HEAP32[$2>>2] = $size;
  $21 = $size << 3;
  $22 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$21,499400,1307)|0);
  HEAP32[$this>>2] = $22;
  $23 = HEAP32[$2>>2]|0;
  $24 = (($22) + ($23<<2)|0);
  $25 = (($this) + 8|0);
  HEAP32[$25>>2] = $24;
  $26 = (($this) + 16|0);
  HEAP32[$26>>2] = $23;
  STACKTOP = sp;return;
 }
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6>>>0)<($size>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = $size << 3;
 $9 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$8,499400,1373)|0);
 $10 = (($9) + ($size<<2)|0);
 $11 = HEAP32[$this>>2]|0;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 2;
 _memcpy(($9|0),($11|0),($14|0))|0;
 $15 = (($this) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 << 2;
 _memcpy(($10|0),($16|0),($19|0))|0;
 $20 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$20);
 HEAP32[$this>>2] = $9;
 HEAP32[$15>>2] = $10;
 HEAP32[$5>>2] = $size;
 HEAP32[$2>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx17EdgeChangeManager4initEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  HEAP32[$2>>2] = $size;
  $35 = $size << 4;
  $36 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$35,499400,1437)|0);
  HEAP32[$this>>2] = $36;
  $37 = HEAP32[$2>>2]|0;
  $38 = (($36) + ($37<<2)|0);
  $39 = (($this) + 8|0);
  HEAP32[$39>>2] = $38;
  $40 = ($37*3)|0;
  $41 = (($36) + ($40<<2)|0);
  $42 = (($this) + 24|0);
  HEAP32[$42>>2] = $41;
  $43 = $37 << 1;
  $44 = (($36) + ($43<<2)|0);
  $45 = (($this) + 16|0);
  HEAP32[$45>>2] = $44;
  $46 = (($this) + 32|0);
  HEAP32[$46>>2] = $37;
  STACKTOP = sp;return;
 }
 $5 = (($this) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6>>>0)<($size>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = $size << 4;
 $9 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$8,499400,1550)|0);
 $10 = (($9) + ($size<<2)|0);
 $11 = $size << 1;
 $12 = (($9) + ($11<<2)|0);
 $13 = ($size*3)|0;
 $14 = (($9) + ($13<<2)|0);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 << 2;
 _memcpy(($9|0),($15|0),($18|0))|0;
 $19 = (($this) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 2;
 _memcpy(($10|0),($20|0),($23|0))|0;
 $24 = (($this) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 << 2;
 _memcpy(($12|0),($25|0),($28|0))|0;
 $29 = (($this) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 << 2;
 _memcpy(($14|0),($30|0),($33|0))|0;
 $34 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$34);
 HEAP32[$this>>2] = $9;
 HEAP32[$19>>2] = $10;
 HEAP32[$24>>2] = $12;
 HEAP32[$29>>2] = $14;
 HEAP32[$5>>2] = $size;
 HEAP32[$2>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager12setKinematicERKNS_20PxsIslandManagerHookIjLj4294967295EEEb($this,$hook,$isKinematic) {
 $this = $this|0;
 $hook = $hook|0;
 $isKinematic = $isKinematic|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$hook>>2]|0;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2) + (($0*12)|0)|0) + 8|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)!=(0);
 $7 = $4&255;
 $8 = $7 & 254;
 $9 = $7 | 1;
 $storemerge$in$i = $isKinematic ? $9 : $8;
 $storemerge$i = $storemerge$in$i&255;
 HEAP8[$3>>0] = $storemerge$i;
 $10 = $6 ^ $isKinematic;
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = $isKinematic ? -1 : 1;
 $12 = (($this) + 244|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($11))|0;
 HEAP32[$12>>2] = $14;
 $15 = $isKinematic ? 1 : -1;
 $16 = (($this) + 252|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($15))|0;
 HEAP32[$16>>2] = $18;
 $19 = HEAP32[$hook>>2]|0;
 $20 = (($this) + 92|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $19 & 31;
 $23 = 1 << $22;
 if ($isKinematic) {
  $24 = $19 >>> 5;
  $25 = HEAP32[$21>>2]|0;
  $26 = (($25) + ($24<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 | $23;
  HEAP32[$26>>2] = $28;
 } else {
  $29 = $23 ^ -1;
  $30 = $19 >>> 5;
  $31 = HEAP32[$21>>2]|0;
  $32 = (($31) + ($30<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 & $29;
  HEAP32[$32>>2] = $34;
 }
 $35 = (($this) + 273|0);
 HEAP8[$35>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager19addArticulationLinkERNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$hook) {
 $this = $this|0;
 $hook = $hook|0;
 var $$0$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 12|0);
 $3 = (($this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 do {
  if ($5) {
   $6 = (($this) + 24|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if ($8) {
    $$pre = (($this) + 16|0);
    $$0$i = -1;$$pre$phiZ2D = $$pre;
    break;
   } else {
    $9 = HEAP32[$2>>2]|0;
    $10 = (($9) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = $7 << 1;
    FUNCTION_TABLE_vii[$11 & 4095]($2,$12);
    $$pre$i = HEAP32[$3>>2]|0;
    $16 = $$pre$i;
    label = 5;
    break;
   }
  } else {
   $16 = $4;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  $13 = (($this) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($16<<2)|0);
  $17 = HEAP32[$15>>2]|0;
  HEAP32[$3>>2] = $17;
  HEAP32[$15>>2] = -1;
  $18 = (($this) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + (($16*12)|0)|0);
  HEAP32[$20>>2] = 0;
  $21 = ((($19) + (($16*12)|0)|0) + 4|0);
  HEAP32[$21>>2] = -1;
  $22 = ((($19) + (($16*12)|0)|0) + 8|0);
  HEAP8[$22>>0] = 0;
  $$0$i = $16;$$pre$phiZ2D = $18;
 }
 $23 = HEAP32[$$pre$phiZ2D>>2]|0;
 $24 = (($23) + (($$0$i*12)|0)|0);
 $25 = ((($23) + (($$0$i*12)|0)|0) + 4|0);
 HEAP32[$25>>2] = -1;
 $26 = ((($23) + (($$0$i*12)|0)|0) + 8|0);
 HEAP32[$24>>2] = (-1);
 HEAP8[$26>>0] = 66;
 $27 = (($this) + 120|0);
 $28 = (($this) + 124|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 136|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($29|0)==($31|0);
 if ($32) {
  $33 = $29 << 1;
  $34 = $29 << 4;
  $35 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$34,499400,1373)|0);
  $36 = (($35) + ($33<<2)|0);
  $37 = HEAP32[$27>>2]|0;
  $38 = HEAP32[$28>>2]|0;
  $39 = $38 << 2;
  _memcpy(($35|0),($37|0),($39|0))|0;
  $40 = (($this) + 128|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($this) + 132|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = $43 << 2;
  _memcpy(($36|0),($41|0),($44|0))|0;
  $45 = HEAP32[$27>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$45);
  HEAP32[$27>>2] = $35;
  HEAP32[$40>>2] = $36;
  HEAP32[$30>>2] = $33;
  $$pre$i1 = HEAP32[$28>>2]|0;
  $47 = $35;$48 = $$pre$i1;
  $46 = (($47) + ($48<<2)|0);
  HEAP32[$46>>2] = $$0$i;
  $49 = HEAP32[$28>>2]|0;
  $50 = (($49) + 1)|0;
  HEAP32[$28>>2] = $50;
  HEAP32[$hook>>2] = $$0$i;
  STACKTOP = sp;return;
 } else {
  $$pre1$i = HEAP32[$27>>2]|0;
  $47 = $$pre1$i;$48 = $29;
  $46 = (($47) + ($48<<2)|0);
  HEAP32[$46>>2] = $$0$i;
  $49 = HEAP32[$28>>2]|0;
  $50 = (($49) + 1)|0;
  HEAP32[$28>>2] = $50;
  HEAP32[$hook>>2] = $$0$i;
  STACKTOP = sp;return;
 }
}
function __ZN5physx16PxsIslandManager25setArticulationLinkHandleEjPvRKNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$link,$0,$hook) {
 $this = $this|0;
 $link = $link|0;
 $0 = $0|0;
 $hook = $hook|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $articulationLink$c$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$hook>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + (($1*12)|0)|0);
 $articulationLink$c$i = $link;
 HEAP32[$4>>2] = $articulationLink$c$i;
 $5 = (($this) + 273|0);
 HEAP8[$5>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager29setArticulationRootLinkHandleEjPvRKNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$link,$owner,$hook) {
 $this = $this|0;
 $link = $link|0;
 $owner = $owner|0;
 $hook = $hook|0;
 var $$0$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $rootArticulationId$c$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 224|0);
 $1 = (($this) + 240|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 do {
  if ($3) {
   $4 = (($this) + 236|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0);
   if ($6) {
    $$pre = (($this) + 228|0);
    $$0$i = -1;$$pre$phiZ2D = $$pre;
    break;
   } else {
    $7 = HEAP32[$0>>2]|0;
    $8 = (($7) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = $5 << 1;
    FUNCTION_TABLE_vii[$9 & 4095]($0,$10);
    $$pre$i = HEAP32[$1>>2]|0;
    $14 = $$pre$i;
    label = 5;
    break;
   }
  } else {
   $14 = $2;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  $11 = (($this) + 232|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($14<<2)|0);
  $15 = HEAP32[$13>>2]|0;
  HEAP32[$1>>2] = $15;
  HEAP32[$13>>2] = -1;
  $16 = (($this) + 228|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($14<<3)|0);
  HEAP32[$18>>2] = -1;
  $19 = ((($17) + ($14<<3)|0) + 4|0);
  HEAP32[$19>>2] = 0;
  $$0$i = $14;$$pre$phiZ2D = $16;
 }
 $20 = HEAP32[$$pre$phiZ2D>>2]|0;
 $21 = (($20) + ($$0$i<<3)|0);
 HEAP32[$21>>2] = $link;
 $22 = ((($20) + ($$0$i<<3)|0) + 4|0);
 HEAP32[$22>>2] = $owner;
 $23 = HEAP32[$hook>>2]|0;
 $24 = (($this) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($25) + (($23*12)|0)|0) + 8|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 $29 = $28 | 4;
 $30 = $29&255;
 HEAP8[$26>>0] = $30;
 $31 = (($25) + (($23*12)|0)|0);
 $rootArticulationId$c$i = $$0$i;
 HEAP32[$31>>2] = $rootArticulationId$c$i;
 $32 = (($this) + 248|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 1)|0;
 HEAP32[$32>>2] = $34;
 $35 = (($this) + 273|0);
 HEAP8[$35>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager10removeNodeERNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$hook) {
 $this = $this|0;
 $hook = $hook|0;
 var $$phi$trans$insert$i = 0, $$pre$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$hook>>2]|0;
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*12)|0)|0) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)!=(0);
 $9 = $6 & 2;
 $10 = ($9<<24>>24)==(0);
 $11 = $6&255;
 $12 = $11 | 32;
 $13 = $12&255;
 HEAP8[$5>>0] = $13;
 $14 = HEAP32[$hook>>2]|0;
 $15 = (($this) + 132|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 136|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16|0)==($18|0);
 if ($19) {
  $20 = $16 << 1;
  $21 = $16 << 4;
  $22 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$21,499400,1373)|0);
  $23 = (($22) + ($20<<2)|0);
  $24 = (($this) + 120|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($this) + 124|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 << 2;
  _memcpy(($22|0),($25|0),($28|0))|0;
  $29 = (($this) + 128|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$15>>2]|0;
  $32 = $31 << 2;
  _memcpy(($23|0),($30|0),($32|0))|0;
  $33 = HEAP32[$24>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$33);
  HEAP32[$24>>2] = $22;
  HEAP32[$29>>2] = $23;
  HEAP32[$17>>2] = $20;
  $$pre$i = HEAP32[$15>>2]|0;
  $35 = $23;$36 = $$pre$i;
 } else {
  $$phi$trans$insert$i = (($this) + 128|0);
  $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
  $35 = $$pre1$i;$36 = $16;
 }
 $34 = (($35) + ($36<<2)|0);
 HEAP32[$34>>2] = $14;
 $37 = HEAP32[$15>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$15>>2] = $38;
 if ($10) {
  $39 = $8 ^ 1;
  $40 = $39 << 31 >> 31;
  $41 = (($this) + 244|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + ($40))|0;
  HEAP32[$41>>2] = $43;
  $44 = $8 << 31 >> 31;
  $45 = (($this) + 252|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + ($44))|0;
  HEAP32[$45>>2] = $47;
 } else {
  $48 = HEAP8[$5>>0]|0;
  $49 = $48 & 4;
  $50 = ($49<<24>>24)==(0);
  if (!($50)) {
   $51 = (($this) + 248|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + -1)|0;
   HEAP32[$51>>2] = $53;
  }
 }
 $54 = HEAP8[$5>>0]|0;
 $55 = $54 & 1;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  HEAP32[$hook>>2] = -1;
  $68 = (($this) + 273|0);
  HEAP8[$68>>0] = 1;
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$hook>>2]|0;
 $58 = (($this) + 92|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = $57 & 31;
 $61 = 1 << $60;
 $62 = $61 ^ -1;
 $63 = $57 >>> 5;
 $64 = HEAP32[$59>>2]|0;
 $65 = (($64) + ($63<<2)|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 & $62;
 HEAP32[$65>>2] = $67;
 HEAP32[$hook>>2] = -1;
 $68 = (($this) + 273|0);
 HEAP8[$68>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager7addEdgeENS0_9eEdgeTypeENS_20PxsIslandManagerHookIjLj4294967295EEES3_RS3_($this,$edgeType,$body0hook,$body1hook,$cmHook) {
 $this = $this|0;
 $edgeType = $edgeType|0;
 $body0hook = $body0hook|0;
 $body1hook = $body1hook|0;
 $cmHook = $cmHook|0;
 var $$0$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre$phiZ2D = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 96|0);
 $3 = (($this) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 do {
  if ($5) {
   $6 = (($this) + 108|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if ($8) {
    $$pre2 = (($this) + 100|0);
    $$0$i = -1;$$pre$phiZ2D = $$pre2;
    break;
   } else {
    $9 = HEAP32[$2>>2]|0;
    $10 = (($9) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = $7 << 1;
    FUNCTION_TABLE_vii[$11 & 4095]($2,$12);
    $$pre$i = HEAP32[$3>>2]|0;
    $16 = $$pre$i;
    label = 5;
    break;
   }
  } else {
   $16 = $4;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  $13 = (($this) + 104|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($16<<2)|0);
  $17 = HEAP32[$15>>2]|0;
  HEAP32[$3>>2] = $17;
  HEAP32[$15>>2] = -1;
  $18 = (($this) + 100|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + (($16*12)|0)|0);
  HEAP32[$20>>2] = -1;
  $21 = ((($19) + (($16*12)|0)|0) + 4|0);
  HEAP32[$21>>2] = -1;
  $22 = ((($19) + (($16*12)|0)|0) + 8|0);
  HEAP32[$22>>2] = 0;
  $$0$i = $16;$$pre$phiZ2D = $18;
 }
 HEAP32[$cmHook>>2] = $$0$i;
 $23 = HEAP32[$$pre$phiZ2D>>2]|0;
 $24 = (($23) + (($$0$i*12)|0)|0);
 HEAP32[$24>>2] = -1;
 $25 = ((($23) + (($$0$i*12)|0)|0) + 4|0);
 HEAP32[$25>>2] = -1;
 $26 = ((($23) + (($$0$i*12)|0)|0) + 8|0);
 HEAP32[$26>>2] = 0;
 $27 = HEAP32[$body0hook>>2]|0;
 HEAP32[$24>>2] = $27;
 $28 = HEAP32[$body1hook>>2]|0;
 HEAP32[$25>>2] = $28;
 $29 = (($this) + 144|0);
 $30 = (($this) + 148|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 176|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($31|0)==($33|0);
 if ($34) {
  $35 = $31 << 1;
  $36 = $31 << 5;
  $37 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$36,499400,1550)|0);
  $38 = (($37) + ($35<<2)|0);
  $39 = $31 << 2;
  $40 = (($37) + ($39<<2)|0);
  $41 = ($31*6)|0;
  $42 = (($37) + ($41<<2)|0);
  $43 = HEAP32[$29>>2]|0;
  $44 = HEAP32[$30>>2]|0;
  $45 = $44 << 2;
  _memcpy(($37|0),($43|0),($45|0))|0;
  $46 = (($this) + 152|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($this) + 156|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = $49 << 2;
  _memcpy(($38|0),($47|0),($50|0))|0;
  $51 = (($this) + 168|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($this) + 172|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = $54 << 2;
  _memcpy(($40|0),($52|0),($55|0))|0;
  $56 = (($this) + 160|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($this) + 164|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $59 << 2;
  _memcpy(($42|0),($57|0),($60|0))|0;
  $61 = HEAP32[$29>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$61);
  HEAP32[$29>>2] = $37;
  HEAP32[$46>>2] = $38;
  HEAP32[$51>>2] = $40;
  HEAP32[$56>>2] = $42;
  HEAP32[$32>>2] = $35;
  $$pre$i1 = HEAP32[$30>>2]|0;
  $63 = $37;$64 = $$pre$i1;
  $62 = (($63) + ($64<<2)|0);
  HEAP32[$62>>2] = $$0$i;
  $65 = HEAP32[$30>>2]|0;
  $66 = (($65) + 1)|0;
  HEAP32[$30>>2] = $66;
  $67 = ((($this) + ($edgeType<<2)|0) + 256|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($68) + 1)|0;
  HEAP32[$67>>2] = $69;
  STACKTOP = sp;return;
 } else {
  $$pre = HEAP32[$29>>2]|0;
  $63 = $$pre;$64 = $31;
  $62 = (($63) + ($64<<2)|0);
  HEAP32[$62>>2] = $$0$i;
  $65 = HEAP32[$30>>2]|0;
  $66 = (($65) + 1)|0;
  HEAP32[$30>>2] = $66;
  $67 = ((($this) + ($edgeType<<2)|0) + 256|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($68) + 1)|0;
  HEAP32[$67>>2] = $69;
  STACKTOP = sp;return;
 }
}
function __ZN5physx16PxsIslandManager14setEdgeRigidCMERKNS_20PxsIslandManagerHookIjLj4294967295EEEPNS_17PxsContactManagerE($this,$edgeHook,$cm) {
 $this = $this|0;
 $edgeHook = $edgeHook|0;
 $cm = $cm|0;
 var $$c$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$edgeHook>>2]|0;
 $1 = (($this) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $cm;
 $4 = ((($2) + (($0*12)|0)|0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = $6 | $3;
 $$c$i = $7;
 HEAP32[$4>>2] = $$c$i;
 $8 = (($this) + 273|0);
 HEAP8[$8>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager16clearEdgeRigidCMERKNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$edgeHook) {
 $this = $this|0;
 $edgeHook = $edgeHook|0;
 var $$c$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$edgeHook>>2]|0;
 $1 = (($this) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2) + (($0*12)|0)|0) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = $5 & 15;
 $$c$i = $6;
 HEAP32[$3>>2] = $$c$i;
 $7 = (($this) + 273|0);
 HEAP8[$7>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager17setEdgeConstraintERKNS_20PxsIslandManagerHookIjLj4294967295EEEPNS_13PxsConstraintE($this,$edgeHook,$constraint) {
 $this = $this|0;
 $edgeHook = $edgeHook|0;
 $constraint = $constraint|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$edgeHook>>2]|0;
 $1 = (($this) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $constraint;
 $4 = ((($2) + (($0*12)|0)|0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = $3 | $6;
 $8 = $7 | 1;
 $9 = $8;
 HEAP32[$4>>2] = $9;
 $10 = (($this) + 273|0);
 HEAP8[$10>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager24setEdgeArticulationJointERKNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$edgeHook) {
 $this = $this|0;
 $edgeHook = $edgeHook|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$edgeHook>>2]|0;
 $1 = (($this) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2) + (($0*12)|0)|0) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = $5 | 2;
 $7 = $6;
 HEAP32[$3>>2] = $7;
 $8 = (($this) + 273|0);
 HEAP8[$8>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager16setEdgeConnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$edgeHook) {
 $this = $this|0;
 $edgeHook = $edgeHook|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$edgeHook>>2]|0;
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*12)|0)|0) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = $7 | 4;
 $11 = $10;
 HEAP32[$5>>2] = $11;
 $12 = (($this) + 172|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 176|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==($15|0);
 if ($16) {
  $17 = $13 << 1;
  $18 = $13 << 5;
  $19 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$18,499400,1550)|0);
  $20 = (($19) + ($17<<2)|0);
  $21 = $13 << 2;
  $22 = (($19) + ($21<<2)|0);
  $23 = ($13*6)|0;
  $24 = (($19) + ($23<<2)|0);
  $25 = (($this) + 144|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($this) + 148|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 << 2;
  _memcpy(($19|0),($26|0),($29|0))|0;
  $30 = (($this) + 152|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($this) + 156|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 << 2;
  _memcpy(($20|0),($31|0),($34|0))|0;
  $35 = (($this) + 168|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP32[$12>>2]|0;
  $38 = $37 << 2;
  _memcpy(($22|0),($36|0),($38|0))|0;
  $39 = (($this) + 160|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($this) + 164|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 << 2;
  _memcpy(($24|0),($40|0),($43|0))|0;
  $44 = HEAP32[$25>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$44);
  HEAP32[$25>>2] = $19;
  HEAP32[$30>>2] = $20;
  HEAP32[$35>>2] = $22;
  HEAP32[$39>>2] = $24;
  HEAP32[$14>>2] = $17;
  $$pre$i = HEAP32[$12>>2]|0;
  $46 = $22;$47 = $$pre$i;
 } else {
  $$phi$trans$insert = (($this) + 168|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $46 = $$pre;$47 = $13;
 }
 $45 = (($46) + ($47<<2)|0);
 HEAP32[$45>>2] = $2;
 $48 = HEAP32[$12>>2]|0;
 $49 = (($48) + 1)|0;
 HEAP32[$12>>2] = $49;
 $50 = (($this) + 273|0);
 HEAP8[$50>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager18setEdgeUnconnectedERKNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$edgeHook) {
 $this = $this|0;
 $edgeHook = $edgeHook|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$edgeHook>>2]|0;
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*12)|0)|0) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 $8 = $7 & 4;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = $7 & -5;
 $11 = $10;
 HEAP32[$5>>2] = $11;
 $12 = (($this) + 164|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 176|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==($15|0);
 if ($16) {
  $17 = $13 << 1;
  $18 = $13 << 5;
  $19 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$18,499400,1550)|0);
  $20 = (($19) + ($17<<2)|0);
  $21 = $13 << 2;
  $22 = (($19) + ($21<<2)|0);
  $23 = ($13*6)|0;
  $24 = (($19) + ($23<<2)|0);
  $25 = (($this) + 144|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($this) + 148|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 << 2;
  _memcpy(($19|0),($26|0),($29|0))|0;
  $30 = (($this) + 152|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($this) + 156|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 << 2;
  _memcpy(($20|0),($31|0),($34|0))|0;
  $35 = (($this) + 168|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($this) + 172|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38 << 2;
  _memcpy(($22|0),($36|0),($39|0))|0;
  $40 = (($this) + 160|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = HEAP32[$12>>2]|0;
  $43 = $42 << 2;
  _memcpy(($24|0),($41|0),($43|0))|0;
  $44 = HEAP32[$25>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$44);
  HEAP32[$25>>2] = $19;
  HEAP32[$30>>2] = $20;
  HEAP32[$35>>2] = $22;
  HEAP32[$40>>2] = $24;
  HEAP32[$14>>2] = $17;
  $$pre$i = HEAP32[$12>>2]|0;
  $46 = $24;$47 = $$pre$i;
 } else {
  $$phi$trans$insert = (($this) + 160|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $46 = $$pre;$47 = $13;
 }
 $45 = (($46) + ($47<<2)|0);
 HEAP32[$45>>2] = $2;
 $48 = HEAP32[$12>>2]|0;
 $49 = (($48) + 1)|0;
 HEAP32[$12>>2] = $49;
 $50 = (($this) + 273|0);
 HEAP8[$50>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager10removeEdgeENS0_9eEdgeTypeERNS_20PxsIslandManagerHookIjLj4294967295EEE($this,$edgeType,$edgeHook) {
 $this = $this|0;
 $edgeType = $edgeType|0;
 $edgeHook = $edgeHook|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$edgeHook>>2]|0;
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*12)|0)|0) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 $8 = $7 | 8;
 $9 = $8;
 HEAP32[$5>>2] = $9;
 $10 = (($this) + 156|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 176|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)==($13|0);
 if ($14) {
  $15 = $11 << 1;
  $16 = $11 << 5;
  $17 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$16,499400,1550)|0);
  $18 = (($17) + ($15<<2)|0);
  $19 = $11 << 2;
  $20 = (($17) + ($19<<2)|0);
  $21 = ($11*6)|0;
  $22 = (($17) + ($21<<2)|0);
  $23 = (($this) + 144|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($this) + 148|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26 << 2;
  _memcpy(($17|0),($24|0),($27|0))|0;
  $28 = (($this) + 152|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$10>>2]|0;
  $31 = $30 << 2;
  _memcpy(($18|0),($29|0),($31|0))|0;
  $32 = (($this) + 168|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($this) + 172|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = $35 << 2;
  _memcpy(($20|0),($33|0),($36|0))|0;
  $37 = (($this) + 160|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($this) + 164|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 << 2;
  _memcpy(($22|0),($38|0),($41|0))|0;
  $42 = HEAP32[$23>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$42);
  HEAP32[$23>>2] = $17;
  HEAP32[$28>>2] = $18;
  HEAP32[$32>>2] = $20;
  HEAP32[$37>>2] = $22;
  HEAP32[$12>>2] = $15;
  $$pre$i = HEAP32[$10>>2]|0;
  $44 = $18;$45 = $$pre$i;
  $43 = (($44) + ($45<<2)|0);
  HEAP32[$43>>2] = $2;
  $46 = HEAP32[$10>>2]|0;
  $47 = (($46) + 1)|0;
  HEAP32[$10>>2] = $47;
  HEAP32[$edgeHook>>2] = -1;
  $48 = ((($this) + ($edgeType<<2)|0) + 256|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + -1)|0;
  HEAP32[$48>>2] = $50;
  $51 = (($this) + 273|0);
  HEAP8[$51>>0] = 1;
  STACKTOP = sp;return;
 } else {
  $$phi$trans$insert = (($this) + 152|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $44 = $$pre;$45 = $11;
  $43 = (($44) + ($45<<2)|0);
  HEAP32[$43>>2] = $2;
  $46 = HEAP32[$10>>2]|0;
  $47 = (($46) + 1)|0;
  HEAP32[$10>>2] = $47;
  HEAP32[$edgeHook>>2] = -1;
  $48 = ((($this) + ($edgeType<<2)|0) + 256|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + -1)|0;
  HEAP32[$48>>2] = $50;
  $51 = (($this) + 273|0);
  HEAP8[$51>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN5physx16PxsIslandManager11freeBuffersEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 428|0);
 $1 = (($this) + 436|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 274|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = (($this) + 252|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = HEAP32[$0>>2]|0;
   $11 = (($this) + 432|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 488|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($this) + 492|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($this) + 480|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($18) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $21 << 2;
   _memset(($19|0),0,($22|0))|0;
   $23 = (($this) + 12|0);
   $24 = (($this) + 92|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($this) + 96|0);
   $27 = (($this) + 184|0);
   __ZN5physx33mergeKinematicProxiesBackToSourceERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKjS8_RNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerERS4_PjSG_($25,$10,$12,$23,$26,$27,$18,$14,$16);
  }
 }
 $28 = (($this) + 388|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 $31 = (($this) + 272|0);
 $$ = $30&1;
 HEAP8[$31>>0] = $$;
 $32 = (($this) + 273|0);
 HEAP8[$32>>0] = 0;
 HEAP8[$4>>0] = 0;
 HEAP32[$1>>2] = 0;
 $33 = (($this) + 460|0);
 HEAP32[$33>>2] = 0;
 HEAP32[$0>>2] = 0;
 $34 = (($this) + 432|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 484|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 488|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 492|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 276|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 284|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 300|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 312|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 320|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 332|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 344|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 348|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 360|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 372|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 384|0);
 HEAP32[$48>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager19resizeForKinematicsEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$0$i2 = 0, $$numEdgesWithKinematicNode$0 = 0, $$numEdgesWithKinematicNode$1 = 0, $$numEdgesWithKinematicNode$3 = 0, $$numEdgesWithKinematicNode$4 = 0, $$numEdgesWithKinematicNode$8 = 0, $$numEdgesWithKinematicNode$9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$018 = 0, $b10$09 = 0, $count$0$lcssa$i = 0, $count$02$i = 0, $exitcond = 0, $exitcond39 = 0, $exitcond43 = 0, $exitcond44 = 0, $i$0$i = 0, $i$0$i1 = 0, $i$032 = 0;
 var $i1$026 = 0, $islandsAffectedBitmap = 0, $nextEdge$0 = 0, $nextEdge$05 = 0, $nextEdge$07 = 0, $nextFree$0$i = 0, $nextFree$01$i = 0, $nextFree$03$i = 0, $numEdgesWithKinematicNode$0$lcssa = 0, $numEdgesWithKinematicNode$033 = 0, $numEdgesWithKinematicNode$1 = 0, $numEdgesWithKinematicNode$10 = 0, $numEdgesWithKinematicNode$11 = 0, $numEdgesWithKinematicNode$2 = 0, $numEdgesWithKinematicNode$3$lcssa = 0, $numEdgesWithKinematicNode$327 = 0, $numEdgesWithKinematicNode$4 = 0, $numEdgesWithKinematicNode$5 = 0, $numEdgesWithKinematicNode$616 = 0, $numEdgesWithKinematicNode$7$lcssa = 0;
 var $numEdgesWithKinematicNode$710 = 0, $numEdgesWithKinematicNode$8$lcssa = 0, $numEdgesWithKinematicNode$86 = 0, $numEdgesWithKinematicNode$9 = 0, $or$cond = 0, $phitmp = 0, $phitmp4 = 0, $phitmp46 = 0, $phitmp47 = 0, $w$022 = 0, $w9$015 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $islandsAffectedBitmap = sp;
 $0 = (($this) + 12|0);
 $1 = (($this) + 28|0);
 $nextFree$01$i = HEAP32[$1>>2]|0;
 $2 = ($nextFree$01$i|0)==(-1);
 if ($2) {
  $count$0$lcssa$i = 0;
 } else {
  $3 = (($this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $count$02$i = 0;$nextFree$03$i = $nextFree$01$i;
  while(1) {
   $5 = (($count$02$i) + 1)|0;
   $6 = (($4) + ($nextFree$03$i<<2)|0);
   $nextFree$0$i = HEAP32[$6>>2]|0;
   $7 = ($nextFree$0$i|0)==(-1);
   if ($7) {
    $count$0$lcssa$i = $5;
    break;
   } else {
    $count$02$i = $5;$nextFree$03$i = $nextFree$0$i;
   }
  }
 }
 $8 = (($this) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 100|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 148|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 144|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==(0);
 if ($16) {
  $numEdgesWithKinematicNode$0$lcssa = 0;
 } else {
  $i$032 = 0;$numEdgesWithKinematicNode$033 = 0;
  while(1) {
   $17 = (($15) + ($i$032<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ((($11) + (($18*12)|0)|0) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20;
   $22 = $21 & 4;
   $23 = ($22|0)==(0);
   if ($23) {
    $24 = (($11) + (($18*12)|0)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(-1);
    if ($26) {
     $numEdgesWithKinematicNode$1 = $numEdgesWithKinematicNode$033;
    } else {
     $27 = ((($9) + (($25*12)|0)|0) + 8|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = $28 & 1;
     $30 = $29&255;
     $$numEdgesWithKinematicNode$0 = (($30) + ($numEdgesWithKinematicNode$033))|0;
     $numEdgesWithKinematicNode$1 = $$numEdgesWithKinematicNode$0;
    }
    $31 = ((($11) + (($18*12)|0)|0) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(-1);
    if ($33) {
     $numEdgesWithKinematicNode$2 = $numEdgesWithKinematicNode$1;
    } else {
     $34 = ((($9) + (($32*12)|0)|0) + 8|0);
     $35 = HEAP8[$34>>0]|0;
     $36 = $35 & 1;
     $37 = $36&255;
     $$numEdgesWithKinematicNode$1 = (($37) + ($numEdgesWithKinematicNode$1))|0;
     $numEdgesWithKinematicNode$2 = $$numEdgesWithKinematicNode$1;
    }
   } else {
    $numEdgesWithKinematicNode$2 = $numEdgesWithKinematicNode$033;
   }
   $38 = (($i$032) + 1)|0;
   $exitcond44 = ($38|0)==($13|0);
   if ($exitcond44) {
    $numEdgesWithKinematicNode$0$lcssa = $numEdgesWithKinematicNode$2;
    break;
   } else {
    $i$032 = $38;$numEdgesWithKinematicNode$033 = $numEdgesWithKinematicNode$2;
   }
  }
 }
 $39 = (($this) + 172|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 168|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($40|0)==(0);
 if ($43) {
  $numEdgesWithKinematicNode$3$lcssa = $numEdgesWithKinematicNode$0$lcssa;
 } else {
  $i1$026 = 0;$numEdgesWithKinematicNode$327 = $numEdgesWithKinematicNode$0$lcssa;
  while(1) {
   $44 = (($42) + ($i1$026<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($11) + (($45*12)|0)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(-1);
   if ($48) {
    $numEdgesWithKinematicNode$4 = $numEdgesWithKinematicNode$327;
   } else {
    $49 = ((($9) + (($47*12)|0)|0) + 8|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = $50 & 1;
    $52 = $51&255;
    $$numEdgesWithKinematicNode$3 = (($52) + ($numEdgesWithKinematicNode$327))|0;
    $numEdgesWithKinematicNode$4 = $$numEdgesWithKinematicNode$3;
   }
   $53 = ((($11) + (($45*12)|0)|0) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(-1);
   if ($55) {
    $numEdgesWithKinematicNode$5 = $numEdgesWithKinematicNode$4;
   } else {
    $56 = ((($9) + (($54*12)|0)|0) + 8|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = $57 & 1;
    $59 = $58&255;
    $$numEdgesWithKinematicNode$4 = (($59) + ($numEdgesWithKinematicNode$4))|0;
    $numEdgesWithKinematicNode$5 = $$numEdgesWithKinematicNode$4;
   }
   $60 = (($i1$026) + 1)|0;
   $exitcond43 = ($60|0)==($40|0);
   if ($exitcond43) {
    $numEdgesWithKinematicNode$3$lcssa = $numEdgesWithKinematicNode$5;
    break;
   } else {
    $i1$026 = $60;$numEdgesWithKinematicNode$327 = $numEdgesWithKinematicNode$5;
   }
  }
 }
 $61 = (($this) + 424|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0|0);
 if ($63) {
  $numEdgesWithKinematicNode$11 = $numEdgesWithKinematicNode$3$lcssa;
 } else {
  $64 = (($islandsAffectedBitmap) + 4|0);
  $65 = (($this) + 196|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = $66 >>> 5;
  $68 = $67 << 2;
  $69 = (($68) + 15)|0;
  $70 = $69 & 1073741808;
  _memset(($62|0),0,($70|0))|0;
  HEAP32[$islandsAffectedBitmap>>2] = $62;
  $71 = $67 | -2147483648;
  HEAP32[$64>>2] = $71;
  $72 = (($this) + 92|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = HEAP32[$73>>2]|0;
  $75 = (($73) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = $76 & 2147483647;
  $i$0$i1 = $77;
  while(1) {
   $78 = (($i$0$i1) + -1)|0;
   $79 = ($i$0$i1|0)==(0);
   if ($79) {
    $$0$i2 = 1;
    break;
   }
   $80 = (($74) + ($78<<2)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0);
   if ($82) {
    $i$0$i1 = $78;
   } else {
    label = 21;
    break;
   }
  }
  if ((label|0) == 21) {
   $83 = $78 << 5;
   $84 = $81 >>> 1;
   $85 = $84 | $81;
   $86 = $85 >>> 2;
   $87 = $86 | $85;
   $88 = $87 >>> 4;
   $89 = $88 | $87;
   $90 = $89 >>> 8;
   $91 = $90 | $89;
   $92 = $91 >>> 16;
   $93 = $92 | $91;
   $94 = Math_imul($93, 130329821)|0;
   $95 = $94 >>> 27;
   $96 = (482344 + ($95<<2)|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($97) + ($83))|0;
   $phitmp = $98 >>> 5;
   $phitmp46 = (($phitmp) + 1)|0;
   $$0$i2 = $phitmp46;
  }
  $w$022 = 0;
  while(1) {
   $99 = (($74) + ($w$022<<2)|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==(0);
   if (!($101)) {
    $102 = $w$022 << 5;
    $b$018 = $100;
    while(1) {
     $103 = (0 - ($b$018))|0;
     $104 = $b$018 & $103;
     $105 = Math_imul($104, 125613361)|0;
     $106 = $105 >>> 27;
     $107 = (412480 + ($106<<2)|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = $108 | $102;
     $110 = ((($9) + (($109*12)|0)|0) + 8|0);
     $111 = HEAP8[$110>>0]|0;
     $112 = $111 & 64;
     $113 = ($112<<24>>24)==(0);
     if ($113) {
      $114 = ((($9) + (($109*12)|0)|0) + 4|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = $115 & 31;
      $117 = 1 << $116;
      $118 = $115 >>> 5;
      $119 = (($62) + ($118<<2)|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = $120 | $117;
      HEAP32[$119>>2] = $121;
     }
     $122 = (($b$018) + -1)|0;
     $123 = $122 & $b$018;
     $124 = ($123|0)==(0);
     if ($124) {
      break;
     } else {
      $b$018 = $123;
     }
    }
   }
   $125 = (($w$022) + 1)|0;
   $exitcond39 = ($125|0)==($$0$i2|0);
   if ($exitcond39) {
    break;
   } else {
    $w$022 = $125;
   }
  }
  $126 = HEAP32[$64>>2]|0;
  $127 = $126 & 2147483647;
  $i$0$i = $127;
  while(1) {
   $128 = (($i$0$i) + -1)|0;
   $129 = ($i$0$i|0)==(0);
   if ($129) {
    $$0$i = 1;
    break;
   }
   $130 = (($62) + ($128<<2)|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = ($131|0)==(0);
   if ($132) {
    $i$0$i = $128;
   } else {
    label = 32;
    break;
   }
  }
  if ((label|0) == 32) {
   $133 = $128 << 5;
   $134 = $131 >>> 1;
   $135 = $134 | $131;
   $136 = $135 >>> 2;
   $137 = $136 | $135;
   $138 = $137 >>> 4;
   $139 = $138 | $137;
   $140 = $139 >>> 8;
   $141 = $140 | $139;
   $142 = $141 >>> 16;
   $143 = $142 | $141;
   $144 = Math_imul($143, 130329821)|0;
   $145 = $144 >>> 27;
   $146 = (482344 + ($145<<2)|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = (($147) + ($133))|0;
   $phitmp4 = $148 >>> 5;
   $phitmp47 = (($phitmp4) + 1)|0;
   $$0$i = $phitmp47;
  }
  $149 = (($this) + 188|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = (($this) + 116|0);
  $152 = HEAP32[$151>>2]|0;
  $numEdgesWithKinematicNode$616 = $numEdgesWithKinematicNode$3$lcssa;$w9$015 = 0;
  while(1) {
   $153 = (($62) + ($w9$015<<2)|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ($154|0)==(0);
   if ($155) {
    $numEdgesWithKinematicNode$7$lcssa = $numEdgesWithKinematicNode$616;
   } else {
    $156 = $w9$015 << 5;
    $b10$09 = $154;$numEdgesWithKinematicNode$710 = $numEdgesWithKinematicNode$616;
    while(1) {
     $157 = (0 - ($b10$09))|0;
     $158 = $b10$09 & $157;
     $159 = Math_imul($158, 125613361)|0;
     $160 = $159 >>> 27;
     $161 = (412480 + ($160<<2)|0);
     $162 = HEAP32[$161>>2]|0;
     $163 = $162 | $156;
     $164 = ((($150) + ($163<<4)|0) + 4|0);
     $nextEdge$05 = HEAP32[$164>>2]|0;
     $165 = ($nextEdge$05|0)==(-1);
     if ($165) {
      $numEdgesWithKinematicNode$8$lcssa = $numEdgesWithKinematicNode$710;
     } else {
      $nextEdge$07 = $nextEdge$05;$numEdgesWithKinematicNode$86 = $numEdgesWithKinematicNode$710;
      while(1) {
       $166 = ((($11) + (($nextEdge$07*12)|0)|0) + 8|0);
       $167 = HEAP32[$166>>2]|0;
       $168 = $167;
       $169 = $168 & 8;
       $170 = ($169|0)==(0);
       if ($170) {
        $171 = (($11) + (($nextEdge$07*12)|0)|0);
        $172 = HEAP32[$171>>2]|0;
        $173 = ($172|0)==(-1);
        if ($173) {
         $numEdgesWithKinematicNode$9 = $numEdgesWithKinematicNode$86;
        } else {
         $174 = ((($9) + (($172*12)|0)|0) + 8|0);
         $175 = HEAP8[$174>>0]|0;
         $176 = $175 & 1;
         $177 = $176&255;
         $$numEdgesWithKinematicNode$8 = (($177) + ($numEdgesWithKinematicNode$86))|0;
         $numEdgesWithKinematicNode$9 = $$numEdgesWithKinematicNode$8;
        }
        $178 = ((($11) + (($nextEdge$07*12)|0)|0) + 4|0);
        $179 = HEAP32[$178>>2]|0;
        $180 = ($179|0)==(-1);
        if ($180) {
         $numEdgesWithKinematicNode$10 = $numEdgesWithKinematicNode$9;
        } else {
         $181 = ((($9) + (($179*12)|0)|0) + 8|0);
         $182 = HEAP8[$181>>0]|0;
         $183 = $182 & 1;
         $184 = $183&255;
         $$numEdgesWithKinematicNode$9 = (($184) + ($numEdgesWithKinematicNode$9))|0;
         $numEdgesWithKinematicNode$10 = $$numEdgesWithKinematicNode$9;
        }
       } else {
        $numEdgesWithKinematicNode$10 = $numEdgesWithKinematicNode$86;
       }
       $185 = (($152) + ($nextEdge$07<<2)|0);
       $nextEdge$0 = HEAP32[$185>>2]|0;
       $186 = ($nextEdge$0|0)==(-1);
       if ($186) {
        $numEdgesWithKinematicNode$8$lcssa = $numEdgesWithKinematicNode$10;
        break;
       } else {
        $nextEdge$07 = $nextEdge$0;$numEdgesWithKinematicNode$86 = $numEdgesWithKinematicNode$10;
       }
      }
     }
     $187 = (($b10$09) + -1)|0;
     $188 = $187 & $b10$09;
     $189 = ($188|0)==(0);
     if ($189) {
      $numEdgesWithKinematicNode$7$lcssa = $numEdgesWithKinematicNode$8$lcssa;
      break;
     } else {
      $b10$09 = $188;$numEdgesWithKinematicNode$710 = $numEdgesWithKinematicNode$8$lcssa;
     }
    }
   }
   $190 = (($w9$015) + 1)|0;
   $exitcond = ($190|0)==($$0$i|0);
   if ($exitcond) {
    break;
   } else {
    $numEdgesWithKinematicNode$616 = $numEdgesWithKinematicNode$7$lcssa;$w9$015 = $190;
   }
  }
  $191 = ($62|0)!=(0|0);
  $192 = ($126|0)>(-1);
  $or$cond = $191 & $192;
  if ($or$cond) {
   $193 = (($islandsAffectedBitmap) + 8|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($193,$62);
   $numEdgesWithKinematicNode$11 = $numEdgesWithKinematicNode$7$lcssa;
  } else {
   $numEdgesWithKinematicNode$11 = $numEdgesWithKinematicNode$7$lcssa;
  }
 }
 $194 = (($this) + 24|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = (($195) - ($count$0$lcssa$i))|0;
 $197 = (($196) + ($numEdgesWithKinematicNode$11))|0;
 $198 = ($197>>>0)>($195>>>0);
 if (!($198)) {
  STACKTOP = sp;return ($numEdgesWithKinematicNode$11|0);
 }
 $199 = (($197) + 31)|0;
 $200 = $199 & -32;
 __ZN5physx11NodeManager6resizeEj($0,$200);
 STACKTOP = sp;return ($numEdgesWithKinematicNode$11|0);
}
function __ZN5physx11NodeManager6resizeEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = ($newCapacity*12)|0;
 $3 = (($2) + 15)|0;
 $4 = $3 & -16;
 $5 = $newCapacity << 2;
 $6 = (($5) + 15)|0;
 $7 = $6 & -16;
 $8 = (($newCapacity) + 31)|0;
 $9 = $8 >>> 5;
 $10 = $9 << 2;
 $11 = (($10) + 15)|0;
 $12 = $11 & 1073741808;
 $13 = (($4) + ($7))|0;
 $14 = (($13) + ($7))|0;
 $15 = (($14) + ($12))|0;
 $16 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$15,499400,882)|0);
 $17 = (($16) + ($4)|0);
 $18 = (($16) + ($13)|0);
 $19 = (($16) + ($14)|0);
 _memset(($19|0),0,($12|0))|0;
 $20 = (($this) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $$pre = (($this) + 8|0);
  $$pre1 = (($this) + 12|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;
 } else {
  $23 = (($this) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24*12)|0;
  _memcpy(($16|0),($21|0),($25|0))|0;
  $26 = (($this) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$23>>2]|0;
  $29 = $28 << 2;
  _memcpy(($17|0),($27|0),($29|0))|0;
  $30 = (($this) + 20|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$23>>2]|0;
  $33 = $32 << 2;
  _memcpy(($18|0),($31|0),($33|0))|0;
  $34 = (($this) + 24|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($this) + 28|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = $37 << 2;
  _memcpy(($19|0),($35|0),($38|0))|0;
  $39 = HEAP32[$20>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$39);
  $$pre$phi2Z2D = $23;$$pre$phiZ2D = $26;
 }
 HEAP32[$20>>2] = $16;
 HEAP32[$$pre$phiZ2D>>2] = $17;
 $40 = HEAP32[$$pre$phi2Z2D>>2]|0;
 $41 = (($this) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($newCapacity) + -1)|0;
 $44 = (($17) + ($43<<2)|0);
 HEAP32[$44>>2] = $42;
 $45 = ($43>>>0)>($40>>>0);
 if ($45) {
  $i$01$i = $40;
  while(1) {
   $46 = (($i$01$i) + 1)|0;
   $47 = (($17) + ($i$01$i<<2)|0);
   HEAP32[$47>>2] = $46;
   $exitcond$i = ($46|0)==($43|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $46;
   }
  }
 }
 HEAP32[$41>>2] = $40;
 $48 = HEAP32[$$pre$phi2Z2D>>2]|0;
 $49 = (($18) + ($48<<2)|0);
 $50 = (($newCapacity) - ($48))|0;
 $51 = $50 << 2;
 _memset(($49|0),-1,($51|0))|0;
 $52 = (($this) + 20|0);
 HEAP32[$52>>2] = $18;
 $53 = (($this) + 28|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($19) + ($54<<2)|0);
 $56 = (($9) - ($54))|0;
 $57 = $56 << 2;
 _memset(($55|0),0,($57|0))|0;
 $58 = (($this) + 24|0);
 HEAP32[$58>>2] = $19;
 HEAP32[$53>>2] = $9;
 $59 = (($this) + 80|0);
 $60 = HEAP32[$59>>2]|0;
 HEAP32[$60>>2] = $19;
 $61 = (($60) + 4|0);
 $62 = $9 | -2147483648;
 HEAP32[$61>>2] = $62;
 HEAP32[$$pre$phi2Z2D>>2] = $newCapacity;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager12resizeArraysEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $factor = 0, $factor2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = (__ZN5physx16PxsIslandManager19resizeForKinematicsEv($this)|0);
 $5 = (($this) + 252|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4))|0;
 $8 = (($this) + 268|0);
 HEAP32[$8>>2] = $7;
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 5;
 $12 = (($this) + 256|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 260|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 264|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + ($13))|0;
 $19 = (($18) + ($17))|0;
 $20 = (($this) + 244|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 248|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + ($21))|0;
 $25 = (($21) + ($7))|0;
 $26 = (($25) + ($23))|0;
 $27 = $10 << 2;
 $28 = (($27) + 15)|0;
 $29 = $28 & -16;
 $30 = $24 << 2;
 $31 = (($30) + 15)|0;
 $32 = $31 & -16;
 $33 = $19 << 3;
 $34 = (($33) + 15)|0;
 $35 = $34 & -16;
 $36 = $21 << 2;
 $37 = (($36) + 15)|0;
 $38 = $37 & -16;
 $39 = $7 << 2;
 $40 = (($39) + 15)|0;
 $41 = $40 & -16;
 $42 = $23 << 2;
 $43 = (($42) + 15)|0;
 $44 = $43 & -16;
 $45 = $13 << 4;
 $46 = $15 << 4;
 $47 = $26 << 4;
 $48 = (($47) + 31)|0;
 $49 = $48 & -16;
 $50 = $11 << 2;
 $51 = (($50) + 15)|0;
 $52 = $51 & 1073741808;
 $factor = $44 << 1;
 $53 = (($29) + ($45))|0;
 $54 = (($53) + ($41))|0;
 $55 = (($54) + ($46))|0;
 $56 = (($55) + ($35))|0;
 $57 = (($56) + ($38))|0;
 $58 = (($57) + ($32))|0;
 $59 = (($58) + ($49))|0;
 $60 = (($59) + ($factor))|0;
 $61 = $29 << 1;
 $62 = (($60) + ($61))|0;
 $63 = $52 << 1;
 $factor2 = ($29*3)|0;
 $64 = (($62) + ($63))|0;
 $65 = (($64) + ($factor2))|0;
 $66 = (($this) + 420|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($65>>>0)>($67>>>0);
 do {
  if ($68) {
   $69 = (($65) + 16384)|0;
   HEAP32[$66>>2] = $69;
   $70 = (($this) + 424|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    $73 = $69;
   } else {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$71);
    $$pre = HEAP32[$66>>2]|0;
    $73 = $$pre;
   }
   $74 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$73,499224,895)|0);
   HEAP32[$70>>2] = $74;
   $84 = $74;
  } else {
   $75 = $67 >>> 1;
   $76 = ($65>>>0)<($75>>>0);
   $77 = ($65>>>0)>(16383);
   $or$cond = $76 & $77;
   if (!($or$cond)) {
    $$phi$trans$insert = (($this) + 424|0);
    $$pre4 = HEAP32[$$phi$trans$insert>>2]|0;
    $84 = $$pre4;
    break;
   }
   HEAP32[$66>>2] = $65;
   $78 = (($this) + 424|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    $81 = $65;
   } else {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$79);
    $$pre3 = HEAP32[$66>>2]|0;
    $81 = $$pre3;
   }
   $82 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$81,499224,902)|0);
   HEAP32[$78>>2] = $82;
   $84 = $82;
  }
 } while(0);
 $83 = (($this) + 428|0);
 HEAP32[$83>>2] = $84;
 $85 = (($84) + ($29)|0);
 $86 = (($this) + 432|0);
 HEAP32[$86>>2] = $85;
 $87 = (($84) + ($61)|0);
 $88 = (($this) + 276|0);
 HEAP32[$88>>2] = $87;
 $89 = (($this) + 280|0);
 HEAP32[$89>>2] = $60;
 $90 = (($this) + 284|0);
 HEAP32[$90>>2] = $87;
 $91 = (($32) + ($61))|0;
 $92 = (($this) + 296|0);
 HEAP32[$92>>2] = $24;
 $93 = (($this) + 288|0);
 HEAP32[$93>>2] = 0;
 $94 = (($this) + 292|0);
 HEAP32[$94>>2] = 0;
 $95 = (($84) + ($91)|0);
 $96 = (($this) + 300|0);
 HEAP32[$96>>2] = $95;
 $97 = (($91) + ($35))|0;
 $98 = (($this) + 308|0);
 HEAP32[$98>>2] = $19;
 $99 = (($this) + 304|0);
 HEAP32[$99>>2] = 0;
 $100 = (($84) + ($97)|0);
 $101 = (($this) + 312|0);
 HEAP32[$101>>2] = $100;
 $102 = (($97) + ($29))|0;
 $103 = (($this) + 316|0);
 HEAP32[$103>>2] = $10;
 $104 = (($84) + ($102)|0);
 $105 = (($this) + 320|0);
 HEAP32[$105>>2] = $104;
 $106 = (($102) + ($41))|0;
 $107 = (($this) + 328|0);
 HEAP32[$107>>2] = $7;
 $108 = (($this) + 324|0);
 HEAP32[$108>>2] = 0;
 $109 = (($84) + ($106)|0);
 $110 = (($this) + 332|0);
 HEAP32[$110>>2] = $109;
 $111 = (($106) + ($38))|0;
 $112 = HEAP32[$20>>2]|0;
 $113 = (($this) + 340|0);
 HEAP32[$113>>2] = $112;
 $114 = (($this) + 336|0);
 HEAP32[$114>>2] = 0;
 $115 = (($84) + ($111)|0);
 $116 = (($this) + 344|0);
 HEAP32[$116>>2] = $115;
 $117 = (($111) + ($44))|0;
 $118 = (($84) + ($117)|0);
 $119 = (($this) + 348|0);
 HEAP32[$119>>2] = $118;
 $120 = (($117) + ($44))|0;
 $121 = HEAP32[$22>>2]|0;
 $122 = (($this) + 356|0);
 HEAP32[$122>>2] = $121;
 $123 = (($this) + 352|0);
 HEAP32[$123>>2] = 0;
 $124 = (($84) + ($120)|0);
 $125 = (($this) + 360|0);
 HEAP32[$125>>2] = $124;
 $126 = (($120) + ($45))|0;
 $127 = (($this) + 368|0);
 HEAP32[$127>>2] = $13;
 $128 = (($this) + 364|0);
 HEAP32[$128>>2] = 0;
 $129 = (($84) + ($126)|0);
 $130 = (($this) + 372|0);
 HEAP32[$130>>2] = $129;
 $131 = (($126) + ($46))|0;
 $132 = (($this) + 380|0);
 HEAP32[$132>>2] = $15;
 $133 = (($this) + 376|0);
 HEAP32[$133>>2] = 0;
 $134 = (($84) + ($131)|0);
 $135 = (($this) + 384|0);
 HEAP32[$135>>2] = $134;
 $136 = $48 >>> 4;
 $137 = (($this) + 392|0);
 HEAP32[$137>>2] = $136;
 $138 = (($this) + 388|0);
 HEAP32[$138>>2] = 0;
 $139 = (($this) + 396|0);
 HEAP32[$139>>2] = 0;
 $140 = (($84) + ($62)|0);
 $141 = (($this) + 436|0);
 HEAP32[$141>>2] = $140;
 $142 = (($62) + ($52))|0;
 $143 = (($this) + 440|0);
 HEAP32[$143>>2] = $11;
 _memset(($140|0),0,($50|0))|0;
 $144 = (($this) + 456|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = HEAP32[$141>>2]|0;
 $147 = HEAP32[$143>>2]|0;
 HEAP32[$145>>2] = $146;
 $148 = (($145) + 4|0);
 $149 = $147 | -2147483648;
 HEAP32[$148>>2] = $149;
 $150 = (($84) + ($142)|0);
 $151 = (($this) + 460|0);
 HEAP32[$151>>2] = $150;
 $152 = (($142) + ($52))|0;
 $153 = (($this) + 464|0);
 HEAP32[$153>>2] = $11;
 _memset(($150|0),0,($50|0))|0;
 $154 = (($this) + 480|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = HEAP32[$151>>2]|0;
 $157 = HEAP32[$153>>2]|0;
 HEAP32[$155>>2] = $156;
 $158 = (($155) + 4|0);
 $159 = $157 | -2147483648;
 HEAP32[$158>>2] = $159;
 $160 = (($84) + ($152)|0);
 $161 = (($this) + 484|0);
 HEAP32[$161>>2] = $160;
 $162 = (($152) + ($29))|0;
 $163 = (($84) + ($162)|0);
 $164 = (($this) + 488|0);
 HEAP32[$164>>2] = $163;
 $165 = (($162) + ($29))|0;
 $166 = (($84) + ($165)|0);
 $167 = (($this) + 492|0);
 HEAP32[$167>>2] = $166;
 $168 = (($this) + 196|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = ($10>>>0)>($169>>>0);
 if (!($170)) {
  $172 = HEAP32[$110>>2]|0;
  $173 = (($this) + 400|0);
  HEAP32[$173>>2] = $172;
  $174 = HEAP32[$116>>2]|0;
  $175 = (($this) + 404|0);
  HEAP32[$175>>2] = $174;
  $176 = HEAP32[$119>>2]|0;
  $177 = (($this) + 408|0);
  HEAP32[$177>>2] = $176;
  $178 = HEAP32[$125>>2]|0;
  $179 = (($this) + 412|0);
  HEAP32[$179>>2] = $178;
  $180 = HEAP32[$130>>2]|0;
  $181 = (($this) + 416|0);
  HEAP32[$181>>2] = $180;
  STACKTOP = sp;return;
 }
 $171 = (($this) + 184|0);
 __ZN5physx13IslandManager6resizeEj($171,$10);
 $172 = HEAP32[$110>>2]|0;
 $173 = (($this) + 400|0);
 HEAP32[$173>>2] = $172;
 $174 = HEAP32[$116>>2]|0;
 $175 = (($this) + 404|0);
 HEAP32[$175>>2] = $174;
 $176 = HEAP32[$119>>2]|0;
 $177 = (($this) + 408|0);
 HEAP32[$177>>2] = $176;
 $178 = HEAP32[$125>>2]|0;
 $179 = (($this) + 412|0);
 HEAP32[$179>>2] = $178;
 $180 = HEAP32[$130>>2]|0;
 $181 = (($this) + 416|0);
 HEAP32[$181>>2] = $180;
 STACKTOP = sp;return;
}
function __ZN5physx13IslandManager6resizeEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = $newCapacity >>> 5;
 $3 = $newCapacity << 4;
 $4 = $newCapacity << 2;
 $5 = (($4) + 15)|0;
 $6 = $5 & -16;
 $7 = $2 << 2;
 $8 = (($7) + 15)|0;
 $9 = $8 & 1073741808;
 $10 = (($6) + ($3))|0;
 $11 = (($10) + ($9))|0;
 $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$11,499400,1044)|0);
 $13 = (($12) + ($3)|0);
 $14 = (($12) + ($10)|0);
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $$pre = (($this) + 8|0);
  $$pre1 = (($this) + 12|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;
 } else {
  $18 = (($this) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 << 4;
  _memcpy(($12|0),($16|0),($20|0))|0;
  $21 = (($this) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$18>>2]|0;
  $24 = $23 << 2;
  _memcpy(($13|0),($22|0),($24|0))|0;
  $25 = (($this) + 32|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($this) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 << 2;
  _memcpy(($14|0),($26|0),($29|0))|0;
  $30 = HEAP32[$15>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$30);
  $$pre$phi2Z2D = $18;$$pre$phiZ2D = $21;
 }
 HEAP32[$15>>2] = $12;
 HEAP32[$$pre$phiZ2D>>2] = $13;
 $31 = HEAP32[$$pre$phi2Z2D>>2]|0;
 $32 = (($this) + 16|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($newCapacity) + -1)|0;
 $35 = (($13) + ($34<<2)|0);
 HEAP32[$35>>2] = $33;
 $36 = ($34>>>0)>($31>>>0);
 if ($36) {
  $i$01$i = $31;
  while(1) {
   $37 = (($i$01$i) + 1)|0;
   $38 = (($13) + ($i$01$i<<2)|0);
   HEAP32[$38>>2] = $37;
   $exitcond$i = ($37|0)==($34|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $37;
   }
  }
 }
 HEAP32[$32>>2] = $31;
 $39 = (($this) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($14) + ($40<<2)|0);
 $42 = (($2) - ($40))|0;
 $43 = $42 << 2;
 _memset(($41|0),0,($43|0))|0;
 $44 = (($this) + 20|0);
 HEAP32[$44>>2] = $14;
 $45 = (($this) + 24|0);
 $46 = $2 | -2147483648;
 HEAP32[$45>>2] = $46;
 $47 = (($this) + 32|0);
 HEAP32[$47>>2] = $14;
 HEAP32[$39>>2] = $2;
 HEAP32[$$pre$phi2Z2D>>2] = $newCapacity;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager17cleanupEdgeEventsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$in$i = 0, $it$02$i$i = 0, $or$cond = 0, $scratchAllocated$0$off0 = 0, $vararg_buffer = 0, $workBuffer$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 144|0);
 $1 = (($this) + 164|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 172|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==(0);
 $6 = ($4|0)==(0);
 $or$cond = $5 | $6;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 108|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 2;
 $10 = (($this) + 280|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)<($9>>>0);
 if ($12) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (__ZN5physx19PxcScratchAllocator5allocEjb($16,$9,1)|0);
  $scratchAllocated$0$off0 = 1;$workBuffer$0 = $17;
 } else {
  $13 = (($this) + 276|0);
  $14 = HEAP32[$13>>2]|0;
  $scratchAllocated$0$off0 = 0;$workBuffer$0 = $14;
 }
 $18 = ($workBuffer$0|0)==(0|0);
 if ($18) {
  $46 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($46,16,499224,1092,499320,$vararg_buffer);
  HEAP32[$3>>2] = 0;
  HEAP32[$1>>2] = 0;
  STACKTOP = sp;return;
 }
 _memset(($workBuffer$0|0),0,($9|0))|0;
 __ZN5physx17EdgeChangeManager17cleanupEdgeEventsEPij($0,$workBuffer$0,$8);
 if (!($scratchAllocated$0$off0)) {
  STACKTOP = sp;return;
 }
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22>>>0)>($workBuffer$0>>>0);
 if (!($23)) {
  $24 = (($20) + 20|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($22) + ($25)|0);
  $27 = ($26>>>0)>($workBuffer$0>>>0);
  if ($27) {
   $28 = HEAP32[$20>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($28);
   $29 = (($20) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($20) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $i$0$in$i = $30;
   while(1) {
    $i$0$i = (($i$0$in$i) + -1)|0;
    $33 = (($32) + ($i$0$i<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34>>>0)<($workBuffer$0>>>0);
    if ($35) {
     $i$0$in$i = $i$0$i;
    } else {
     break;
    }
   }
   $36 = ($i$0$in$i>>>0)<($30>>>0);
   if ($36) {
    $40 = $i$0$in$i;$it$02$i$i = $33;
    while(1) {
     $37 = ($it$02$i$i|0)==(0|0);
     if (!($37)) {
      $38 = HEAP32[$31>>2]|0;
      $39 = (($38) + ($40<<2)|0);
      $41 = HEAP32[$39>>2]|0;
      HEAP32[$it$02$i$i>>2] = $41;
     }
     $42 = (($it$02$i$i) + 4|0);
     $43 = (($40) + 1)|0;
     $exitcond$i = ($43|0)==($30|0);
     if ($exitcond$i) {
      break;
     } else {
      $40 = $43;$it$02$i$i = $42;
     }
    }
   }
   $44 = (($30) + -1)|0;
   HEAP32[$29>>2] = $44;
   $45 = HEAP32[$20>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($45);
   STACKTOP = sp;return;
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$workBuffer$0);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager27setWokenPairContactManagersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 300|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 304|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $7 = ((($3) + ($i$01<<3)|0) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($1) + (($8*12)|0)|0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10;
  $12 = $11 & -16;
  $13 = $12;
  $14 = (($3) + ($i$01<<3)|0);
  HEAP32[$14>>2] = $13;
  $15 = (($i$01) + 1)|0;
  $exitcond = ($15|0)==($5|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager33removeSleepingPairContactManagersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $newNarrowPhaseContactManagersSize$0$lcssa = 0, $newNarrowPhaseContactManagersSize$02 = 0, $newNarrowPhaseContactManagersSize$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 300|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 304|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $newNarrowPhaseContactManagersSize$0$lcssa = 0;
  HEAP32[$4>>2] = $newNarrowPhaseContactManagersSize$0$lcssa;
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;$newNarrowPhaseContactManagersSize$02 = 0;
 }
 while(1) {
  $7 = ((($3) + ($i$01<<3)|0) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($1) + (($8*12)|0)|0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10>>>0)<((16)>>>0);
  if ($11) {
   $newNarrowPhaseContactManagersSize$1 = $newNarrowPhaseContactManagersSize$02;
  } else {
   $12 = (($3) + ($i$01<<3)|0);
   $13 = (($3) + ($newNarrowPhaseContactManagersSize$02<<3)|0);
   $14 = $12;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = $13;
   $21 = $20;
   HEAP32[$21>>2] = $16;
   $22 = (($20) + 4)|0;
   $23 = $22;
   HEAP32[$23>>2] = $19;
   $24 = (($newNarrowPhaseContactManagersSize$02) + 1)|0;
   $newNarrowPhaseContactManagersSize$1 = $24;
  }
  $25 = (($i$01) + 1)|0;
  $exitcond = ($25|0)==($5|0);
  if ($exitcond) {
   $newNarrowPhaseContactManagersSize$0$lcssa = $newNarrowPhaseContactManagersSize$1;
   break;
  } else {
   $i$01 = $25;$newNarrowPhaseContactManagersSize$02 = $newNarrowPhaseContactManagersSize$1;
  }
 }
 HEAP32[$4>>2] = $newNarrowPhaseContactManagersSize$0$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager19finishSolverIslandsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager13updateIslandsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($this) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 132|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 120|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 124|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 152|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 156|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 144|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 148|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 160|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 164|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 168|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 172|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 12|0);
 $28 = (($this) + 92|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 252|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 96|0);
 $33 = (($this) + 184|0);
 $34 = (($this) + 224|0);
 $35 = (($this) + 276|0);
 $36 = (($this) + 428|0);
 $37 = (($this) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 __ZN5physx17updateIslandsMainEjPKjjS1_jS1_jS1_jS1_jS1_jRKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjRNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerERNS_23ArticulationRootManagerERNS_33ProcessSleepingIslandsComputeDataERNS_30IslandManagerUpdateWorkBuffersEPNS2_13EventProfilerE($2,$4,$6,$8,$10,$12,$14,$16,$18,$20,$22,$24,$26,$29,$31,$27,$32,$33,$34,$35,$36,$38);
 HEAP32[$9>>2] = 0;
 HEAP32[$5>>2] = 0;
 $39 = (($this) + 136|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 140|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($40>>>0)>($42>>>0);
 if ($43) {
  $44 = HEAP32[$7>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$44);
  HEAP32[$7>>2] = 0;
  HEAP32[$3>>2] = 0;
  $45 = HEAP32[$41>>2]|0;
  $46 = $45 << 3;
  $47 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$46,499400,1307)|0);
  HEAP32[$7>>2] = $47;
  $48 = HEAP32[$41>>2]|0;
  $49 = (($47) + ($48<<2)|0);
  HEAP32[$3>>2] = $49;
  HEAP32[$39>>2] = $48;
 }
 HEAP32[$17>>2] = 0;
 HEAP32[$13>>2] = 0;
 HEAP32[$25>>2] = 0;
 HEAP32[$21>>2] = 0;
 $50 = (($this) + 176|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 180|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($51>>>0)>($53>>>0);
 if (!($54)) {
  STACKTOP = sp;return;
 }
 $55 = HEAP32[$15>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$55);
 HEAP32[$15>>2] = 0;
 HEAP32[$11>>2] = 0;
 HEAP32[$23>>2] = 0;
 HEAP32[$19>>2] = 0;
 $56 = HEAP32[$52>>2]|0;
 $57 = $56 << 4;
 $58 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$57,499400,1437)|0);
 HEAP32[$15>>2] = $58;
 $59 = HEAP32[$52>>2]|0;
 $60 = (($58) + ($59<<2)|0);
 HEAP32[$11>>2] = $60;
 $61 = ($59*3)|0;
 $62 = (($58) + ($61<<2)|0);
 HEAP32[$23>>2] = $62;
 $63 = $59 << 1;
 $64 = (($58) + ($63<<2)|0);
 HEAP32[$19>>2] = $64;
 HEAP32[$50>>2] = $59;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager13updateIslandsEPNS_10PxBaseTaskEj($this,$continuation,$numSpus) {
 $this = $this|0;
 $continuation = $continuation|0;
 $numSpus = $numSpus|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx16PxsIslandManager12resizeArraysEv($this);
 __ZN5physx16PxsIslandManager17cleanupEdgeEventsEv($this);
 $0 = (($this) + 272|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 273|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $6 = (($this) + 274|0);
   HEAP8[$6>>0] = 0;
   STACKTOP = sp;return;
  }
 }
 $7 = (($this) + 274|0);
 HEAP8[$7>>0] = 1;
 __ZN5physx16PxsIslandManager13updateIslandsEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager23updateIslandsSecondPassERNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$affectedIslandsBitmap) {
 $this = $this|0;
 $affectedIslandsBitmap = $affectedIslandsBitmap|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($this) + 160|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 164|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 12|0);
 $8 = (($this) + 96|0);
 $9 = (($this) + 184|0);
 $10 = (($this) + 224|0);
 $11 = (($this) + 276|0);
 $12 = (($this) + 428|0);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN5physx27updateIslandsSecondPassMainEjRNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKjjRNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerERNS_23ArticulationRootManagerERNS_33ProcessSleepingIslandsComputeDataERNS_30IslandManagerUpdateWorkBuffersEPNS0_13EventProfilerE($2,$affectedIslandsBitmap,$4,$6,$7,$8,$9,$10,$11,$12,$14);
 $15 = (($this) + 148|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 156|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 172|0);
 HEAP32[$17>>2] = 0;
 HEAP32[$5>>2] = 0;
 $18 = (($this) + 176|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 180|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19>>>0)>($21>>>0);
 if (!($22)) {
  STACKTOP = sp;return;
 }
 $23 = (($this) + 144|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$24);
 HEAP32[$23>>2] = 0;
 $25 = (($this) + 152|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 168|0);
 HEAP32[$26>>2] = 0;
 HEAP32[$3>>2] = 0;
 $27 = HEAP32[$20>>2]|0;
 $28 = $27 << 4;
 $29 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$28,499400,1437)|0);
 HEAP32[$23>>2] = $29;
 $30 = HEAP32[$20>>2]|0;
 $31 = (($29) + ($30<<2)|0);
 HEAP32[$25>>2] = $31;
 $32 = ($30*3)|0;
 $33 = (($29) + ($32<<2)|0);
 HEAP32[$26>>2] = $33;
 $34 = $30 << 1;
 $35 = (($29) + ($34<<2)|0);
 HEAP32[$3>>2] = $35;
 HEAP32[$18>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsIslandManager23updateIslandsSecondPassEPNS_10PxBaseTaskEj($this,$continuation,$numSpus) {
 $this = $this|0;
 $continuation = $continuation|0;
 $numSpus = $numSpus|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 $1 = (($this) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx17EdgeChangeManager23cleanupBrokenEdgeEventsEPKNS_4EdgeE($0,$2);
 $3 = (($this) + 480|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($4) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 << 2;
 _memset(($5|0),0,($8|0))|0;
 $9 = (($this) + 384|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 392|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 396|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) - ($14))|0;
 $16 = ($15>>>0)<($12>>>0);
 if (!($16)) {
  __ZN5physx16PxsIslandManager23updateIslandsSecondPassERNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$4);
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$4>>2]|0;
 $i$01 = $15;
 while(1) {
  $18 = ((($10) + ($i$01<<4)|0) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & 31;
  $21 = 1 << $20;
  $22 = $19 >>> 5;
  $23 = (($17) + ($22<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 | $21;
  HEAP32[$23>>2] = $25;
  $26 = (($i$01) + 1)|0;
  $exitcond = ($26|0)==($12|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $26;
  }
 }
 __ZN5physx16PxsIslandManager23updateIslandsSecondPassERNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEE($this,$4);
 STACKTOP = sp;return;
}
function __ZN5physx11NodeManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((499496 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx11EdgeManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((499520 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx11EdgeManager6resizeEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phi4Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = ($newCapacity*12)|0;
 $3 = (($2) + 15)|0;
 $4 = $3 & -16;
 $5 = $newCapacity << 2;
 $6 = (($5) + 15)|0;
 $7 = $6 & -16;
 $8 = (($4) + ($7))|0;
 $9 = (($8) + ($7))|0;
 $10 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$9,499400,969)|0);
 $11 = (($10) + ($4)|0);
 $12 = (($10) + ($8)|0);
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$pre = (($this) + 8|0);
  $$pre1 = (($this) + 20|0);
  $$pre3 = (($this) + 12|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phi4Z2D = $$pre3;$$pre$phiZ2D = $$pre;
 } else {
  $16 = (($this) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17*12)|0;
  _memcpy(($10|0),($14|0),($18|0))|0;
  $19 = (($this) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$16>>2]|0;
  $22 = $21 << 2;
  _memcpy(($11|0),($20|0),($22|0))|0;
  $23 = (($this) + 20|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$16>>2]|0;
  $26 = $25 << 2;
  _memcpy(($12|0),($24|0),($26|0))|0;
  $27 = HEAP32[$13>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$27);
  $$pre$phi2Z2D = $23;$$pre$phi4Z2D = $16;$$pre$phiZ2D = $19;
 }
 HEAP32[$13>>2] = $10;
 HEAP32[$$pre$phiZ2D>>2] = $11;
 HEAP32[$$pre$phi2Z2D>>2] = $12;
 $28 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $29 = (($this) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($newCapacity) + -1)|0;
 $32 = (($11) + ($31<<2)|0);
 HEAP32[$32>>2] = $30;
 $33 = ($31>>>0)>($28>>>0);
 if ($33) {
  $i$01$i = $28;
 } else {
  HEAP32[$29>>2] = $28;
  $36 = HEAP32[$$pre$phi4Z2D>>2]|0;
  $37 = (($12) + ($36<<2)|0);
  $38 = (($newCapacity) - ($36))|0;
  $39 = $38 << 2;
  _memset(($37|0),-1,($39|0))|0;
  HEAP32[$$pre$phi4Z2D>>2] = $newCapacity;
  STACKTOP = sp;return;
 }
 while(1) {
  $34 = (($i$01$i) + 1)|0;
  $35 = (($11) + ($i$01$i<<2)|0);
  HEAP32[$35>>2] = $34;
  $exitcond$i = ($34|0)==($31|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $34;
  }
 }
 HEAP32[$29>>2] = $28;
 $36 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $37 = (($12) + ($36<<2)|0);
 $38 = (($newCapacity) - ($36))|0;
 $39 = $38 << 2;
 _memset(($37|0),-1,($39|0))|0;
 HEAP32[$$pre$phi4Z2D>>2] = $newCapacity;
 STACKTOP = sp;return;
}
function __ZN5physx13IslandManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((499544 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx23ArticulationRootManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((499568 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx23ArticulationRootManager6resizeEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = $newCapacity << 3;
 $3 = (($2) + 15)|0;
 $4 = $3 & -16;
 $5 = $newCapacity << 2;
 $6 = (($5) + 15)|0;
 $7 = $6 & -16;
 $8 = (($4) + ($7))|0;
 $9 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$8,499400,1116)|0);
 $10 = (($9) + ($4)|0);
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$pre = (($this) + 8|0);
  $$pre1 = (($this) + 12|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;
 } else {
  $14 = (($this) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 << 3;
  _memcpy(($9|0),($12|0),($16|0))|0;
  $17 = (($this) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$14>>2]|0;
  $20 = $19 << 2;
  _memcpy(($10|0),($18|0),($20|0))|0;
  $21 = HEAP32[$11>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$21);
  $$pre$phi2Z2D = $14;$$pre$phiZ2D = $17;
 }
 HEAP32[$11>>2] = $9;
 HEAP32[$$pre$phiZ2D>>2] = $10;
 $22 = HEAP32[$$pre$phi2Z2D>>2]|0;
 $23 = (($this) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($newCapacity) + -1)|0;
 $26 = (($10) + ($25<<2)|0);
 HEAP32[$26>>2] = $24;
 $27 = ($25>>>0)>($22>>>0);
 if ($27) {
  $i$01$i = $22;
 } else {
  HEAP32[$23>>2] = $22;
  HEAP32[$$pre$phi2Z2D>>2] = $newCapacity;
  STACKTOP = sp;return;
 }
 while(1) {
  $28 = (($i$01$i) + 1)|0;
  $29 = (($10) + ($i$01$i<<2)|0);
  HEAP32[$29>>2] = $28;
  $exitcond$i = ($28|0)==($25|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $28;
  }
 }
 HEAP32[$23>>2] = $22;
 HEAP32[$$pre$phi2Z2D>>2] = $newCapacity;
 STACKTOP = sp;return;
}
function __ZN5physx17EdgeChangeManager17cleanupEdgeEventsEPij($this,$edgeEventWorkBuffer,$entryCapacity) {
 $this = $this|0;
 $edgeEventWorkBuffer = $edgeEventWorkBuffer|0;
 $entryCapacity = $entryCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $cleanupNeeded$0$off0$lcssa = 0, $cleanupNeeded$0$off017 = 0, $cleanupNeeded$1$off0$lcssa = 0, $cleanupNeeded$1$off012 = 0, $exitcond = 0, $exitcond21 = 0, $exitcond22 = 0, $exitcond24 = 0, $i$016 = 0, $i1$011 = 0, $i3$06 = 0, $i5$04 = 0, $newEdgeEventCount$0$lcssa = 0, $newEdgeEventCount$05 = 0, $newEdgeEventCount$1 = 0, $newEdgeEventCount$2$lcssa = 0, $newEdgeEventCount$23 = 0, $newEdgeEventCount$3 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($1|0)==(0);
 if ($8) {
  $cleanupNeeded$0$off0$lcssa = 0;
 } else {
  $cleanupNeeded$0$off017 = 0;$i$016 = 0;
  while(1) {
   $10 = (($5) + ($i$016<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($edgeEventWorkBuffer) + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)!=(0);
   $15 = $cleanupNeeded$0$off017 | $14;
   $16 = (($13) + -1)|0;
   HEAP32[$12>>2] = $16;
   $17 = (($i$016) + 1)|0;
   $exitcond24 = ($17|0)==($1|0);
   if ($exitcond24) {
    $cleanupNeeded$0$off0$lcssa = $15;
    break;
   } else {
    $cleanupNeeded$0$off017 = $15;$i$016 = $17;
   }
  }
 }
 $9 = ($3|0)==(0);
 if ($9) {
  $cleanupNeeded$1$off0$lcssa = $cleanupNeeded$0$off0$lcssa;
 } else {
  $cleanupNeeded$1$off012 = $cleanupNeeded$0$off0$lcssa;$i1$011 = 0;
  while(1) {
   $18 = (($7) + ($i1$011<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($edgeEventWorkBuffer) + ($19<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)!=(0);
   $23 = $cleanupNeeded$1$off012 | $22;
   $24 = (($21) + 1)|0;
   HEAP32[$20>>2] = $24;
   $25 = (($i1$011) + 1)|0;
   $exitcond22 = ($25|0)==($3|0);
   if ($exitcond22) {
    $cleanupNeeded$1$off0$lcssa = $23;
    break;
   } else {
    $cleanupNeeded$1$off012 = $23;$i1$011 = $25;
   }
  }
 }
 if (!($cleanupNeeded$1$off0$lcssa)) {
  STACKTOP = sp;return;
 }
 if ($8) {
  $newEdgeEventCount$0$lcssa = 0;
 } else {
  $i3$06 = 0;$newEdgeEventCount$05 = 0;
  while(1) {
   $26 = (($5) + ($i3$06<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($edgeEventWorkBuffer) + ($27<<2)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)<(0);
   if ($30) {
    $31 = (($5) + ($newEdgeEventCount$05<<2)|0);
    HEAP32[$31>>2] = $27;
    $32 = (($newEdgeEventCount$05) + 1)|0;
    HEAP32[$28>>2] = 0;
    $newEdgeEventCount$1 = $32;
   } else {
    $newEdgeEventCount$1 = $newEdgeEventCount$05;
   }
   $33 = (($i3$06) + 1)|0;
   $exitcond21 = ($33|0)==($1|0);
   if ($exitcond21) {
    $newEdgeEventCount$0$lcssa = $newEdgeEventCount$1;
    break;
   } else {
    $i3$06 = $33;$newEdgeEventCount$05 = $newEdgeEventCount$1;
   }
  }
 }
 HEAP32[$0>>2] = $newEdgeEventCount$0$lcssa;
 if ($9) {
  $newEdgeEventCount$2$lcssa = 0;
 } else {
  $i5$04 = 0;$newEdgeEventCount$23 = 0;
  while(1) {
   $34 = (($7) + ($i5$04<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($edgeEventWorkBuffer) + ($35<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)>(0);
   if ($38) {
    $39 = (($7) + ($newEdgeEventCount$23<<2)|0);
    HEAP32[$39>>2] = $35;
    $40 = (($newEdgeEventCount$23) + 1)|0;
    HEAP32[$36>>2] = 0;
    $newEdgeEventCount$3 = $40;
   } else {
    $newEdgeEventCount$3 = $newEdgeEventCount$23;
   }
   $41 = (($i5$04) + 1)|0;
   $exitcond = ($41|0)==($3|0);
   if ($exitcond) {
    $newEdgeEventCount$2$lcssa = $newEdgeEventCount$3;
    break;
   } else {
    $i5$04 = $41;$newEdgeEventCount$23 = $newEdgeEventCount$3;
   }
  }
 }
 HEAP32[$2>>2] = $newEdgeEventCount$2$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx17EdgeChangeManager23cleanupBrokenEdgeEventsEPKNS_4EdgeE($this,$allEdges) {
 $this = $this|0;
 $allEdges = $allEdges|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0;
 var $newBrokenEdgesSize$0$lcssa = 0, $newBrokenEdgesSize$02 = 0, $newBrokenEdgesSize$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $newBrokenEdgesSize$0$lcssa = 0;
 } else {
  $i$01 = 0;$newBrokenEdgesSize$02 = 0;
  while(1) {
   $8 = (($4) + ($i$01<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($allEdges) + (($9*12)|0)|0) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $11;
   $13 = $12 & 4;
   $14 = ($13|0)==(0);
   if ($14) {
    $15 = (($4) + ($newBrokenEdgesSize$02<<2)|0);
    HEAP32[$15>>2] = $9;
    $16 = (($newBrokenEdgesSize$02) + 1)|0;
    $newBrokenEdgesSize$1 = $16;
   } else {
    $newBrokenEdgesSize$1 = $newBrokenEdgesSize$02;
   }
   $17 = (($i$01) + 1)|0;
   $exitcond = ($17|0)==($6|0);
   if ($exitcond) {
    $newBrokenEdgesSize$0$lcssa = $newBrokenEdgesSize$1;
    break;
   } else {
    $i$01 = $17;$newBrokenEdgesSize$02 = $newBrokenEdgesSize$1;
   }
  }
 }
 HEAP32[$5>>2] = $newBrokenEdgesSize$0$lcssa;
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx33mergeKinematicProxiesBackToSourceERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKjS8_RNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerERS4_PjSG_($kinematicNodesBitmap,$kinematicProxySourceNodes,$kinematicProxyNextNodes,$nodeManager,$edgeManager,$islands,$kinematicIslandsBitmap,$graphStartIslands,$graphNextIslands) {
 $kinematicNodesBitmap = $kinematicNodesBitmap|0;
 $kinematicProxySourceNodes = $kinematicProxySourceNodes|0;
 $kinematicProxyNextNodes = $kinematicProxyNextNodes|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $kinematicIslandsBitmap = $kinematicIslandsBitmap|0;
 $graphStartIslands = $graphStartIslands|0;
 $graphNextIslands = $graphNextIslands|0;
 var $$0$i = 0, $$0$i12 = 0, $$0$i4 = 0, $$0$i9 = 0, $$pre = 0, $$pre110 = 0, $$pre111 = 0, $$pre112 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$077 = 0, $b15$020 = 0, $b3$063 = 0, $b8$042 = 0, $endNode$0$lcssa$i = 0, $exitcond = 0, $exitcond102 = 0, $exitcond86 = 0, $exitcond98 = 0, $firstIslandId$0$lcssa = 0, $i$0$i = 0, $i$0$i11 = 0, $i$0$i3 = 0, $i$0$i8 = 0, $islandId11$0$lcssa = 0;
 var $nextEdge$0 = 0, $nextEdge$059 = 0, $nextEdge$060 = 0, $nextIslandId$0 = 0, $nextIslandId$031 = 0, $nextIslandId$032 = 0, $nextIslandId0$0 = 0, $nextIslandId0$026 = 0, $nextIslandId0$027 = 0, $nextNode$0$i = 0, $nextNode$01$i = 0, $nextNode$02$i = 0, $nextNode$06$i = 0, $nextNode1$02$i = 0, $nextProxyNode$0 = 0, $nextProxyNode$0$in = 0, $nextProxyNode$0$in17 = 0, $nextProxyNode$018 = 0, $nextProxyNode$019 = 0, $nextProxyNodeId$0 = 0;
 var $nextProxyNodeId$0$in = 0, $nextProxyNodeId$0$in71 = 0, $nextProxyNodeId$072 = 0, $nextProxyNodeId$073 = 0, $nextProxyNodeId10$0 = 0, $nextProxyNodeId10$0$in = 0, $nextProxyNodeId10$0$in37 = 0, $nextProxyNodeId10$038 = 0, $nextProxyNodeId10$039 = 0, $nodeId$$i = 0, $phitmp = 0, $phitmp113 = 0, $phitmp114 = 0, $phitmp115 = 0, $phitmp116 = 0, $phitmp14 = 0, $phitmp15 = 0, $phitmp16 = 0, $undeletedNode$03$i = 0, $w$081 = 0;
 var $w14$024 = 0, $w2$067 = 0, $w7$046 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($nodeManager) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($nodeManager) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($edgeManager) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($edgeManager) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($islands) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 << 2;
 _memset(($graphStartIslands|0),-1,($10|0))|0;
 $11 = HEAP32[$8>>2]|0;
 $12 = $11 << 2;
 _memset(($graphNextIslands|0),-1,($12|0))|0;
 $13 = HEAP32[$kinematicNodesBitmap>>2]|0;
 $14 = (($kinematicNodesBitmap) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $i$0$i11 = $16;
 while(1) {
  $17 = (($i$0$i11) + -1)|0;
  $18 = ($i$0$i11|0)==(0);
  if ($18) {
   $$0$i12 = 1;
   break;
  }
  $19 = (($13) + ($17<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   $i$0$i11 = $17;
  } else {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $22 = $17 << 5;
  $23 = $20 >>> 1;
  $24 = $23 | $20;
  $25 = $24 >>> 2;
  $26 = $25 | $24;
  $27 = $26 >>> 4;
  $28 = $27 | $26;
  $29 = $28 >>> 8;
  $30 = $29 | $28;
  $31 = $30 >>> 16;
  $32 = $31 | $30;
  $33 = Math_imul($32, 130329821)|0;
  $34 = $33 >>> 27;
  $35 = (482344 + ($34<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($22))|0;
  $phitmp = $37 >>> 5;
  $phitmp113 = (($phitmp) + 1)|0;
  $$0$i12 = $phitmp113;
 }
 $w$081 = 0;
 while(1) {
  $38 = (($13) + ($w$081<<2)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0);
  if (!($40)) {
   $41 = $w$081 << 5;
   $b$077 = $39;
   while(1) {
    $42 = (0 - ($b$077))|0;
    $43 = $b$077 & $42;
    $44 = Math_imul($43, 125613361)|0;
    $45 = $44 >>> 27;
    $46 = (412480 + ($45<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = $47 | $41;
    $nextProxyNodeId$0$in71 = (($kinematicProxyNextNodes) + ($48<<2)|0);
    $nextProxyNodeId$072 = HEAP32[$nextProxyNodeId$0$in71>>2]|0;
    $49 = ($nextProxyNodeId$072|0)==(-1);
    if (!($49)) {
     $nextProxyNodeId$073 = $nextProxyNodeId$072;
     while(1) {
      $50 = ((($1) + (($nextProxyNodeId$073*12)|0)|0) + 8|0);
      $51 = HEAP8[$50>>0]|0;
      $52 = $51&255;
      $53 = $52 | 32;
      $54 = $53&255;
      HEAP8[$50>>0] = $54;
      $55 = ((($1) + (($nextProxyNodeId$073*12)|0)|0) + 4|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = (($graphStartIslands) + ($nextProxyNodeId$073<<2)|0);
      HEAP32[$57>>2] = $56;
      $58 = (($graphNextIslands) + ($nextProxyNodeId$073<<2)|0);
      HEAP32[$58>>2] = -1;
      $59 = $56 & 31;
      $60 = 1 << $59;
      $61 = $56 >>> 5;
      $62 = HEAP32[$kinematicIslandsBitmap>>2]|0;
      $63 = (($62) + ($61<<2)|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = $64 | $60;
      HEAP32[$63>>2] = $65;
      $nextProxyNodeId$0$in = (($kinematicProxyNextNodes) + ($nextProxyNodeId$073<<2)|0);
      $nextProxyNodeId$0 = HEAP32[$nextProxyNodeId$0$in>>2]|0;
      $66 = ($nextProxyNodeId$0|0)==(-1);
      if ($66) {
       break;
      } else {
       $nextProxyNodeId$073 = $nextProxyNodeId$0;
      }
     }
    }
    $67 = (($b$077) + -1)|0;
    $68 = $67 & $b$077;
    $69 = ($68|0)==(0);
    if ($69) {
     break;
    } else {
     $b$077 = $68;
    }
   }
  }
  $70 = (($w$081) + 1)|0;
  $exitcond102 = ($70|0)==($$0$i12|0);
  if ($exitcond102) {
   break;
  } else {
   $w$081 = $70;
  }
 }
 $71 = (($kinematicIslandsBitmap) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $72 & 2147483647;
 $i$0$i8 = $73;
 while(1) {
  $74 = (($i$0$i8) + -1)|0;
  $75 = ($i$0$i8|0)==(0);
  if ($75) {
   $$0$i9 = 1;
   break;
  }
  $76 = HEAP32[$kinematicIslandsBitmap>>2]|0;
  $77 = (($76) + ($74<<2)|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0);
  if ($79) {
   $i$0$i8 = $74;
  } else {
   label = 15;
   break;
  }
 }
 if ((label|0) == 15) {
  $80 = $74 << 5;
  $81 = $78 >>> 1;
  $82 = $81 | $78;
  $83 = $82 >>> 2;
  $84 = $83 | $82;
  $85 = $84 >>> 4;
  $86 = $85 | $84;
  $87 = $86 >>> 8;
  $88 = $87 | $86;
  $89 = $88 >>> 16;
  $90 = $89 | $88;
  $91 = Math_imul($90, 130329821)|0;
  $92 = $91 >>> 27;
  $93 = (482344 + ($92<<2)|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (($94) + ($80))|0;
  $phitmp14 = $95 >>> 5;
  $phitmp114 = (($phitmp14) + 1)|0;
  $$0$i9 = $phitmp114;
 }
 $96 = (($islands) + 4|0);
 $$pre110 = HEAP32[$kinematicIslandsBitmap>>2]|0;
 $w2$067 = 0;
 while(1) {
  $97 = (($$pre110) + ($w2$067<<2)|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ($98|0)==(0);
  if (!($99)) {
   $100 = $w2$067 << 5;
   $$pre = HEAP32[$96>>2]|0;
   $$pre111 = HEAP32[$0>>2]|0;
   $$pre112 = HEAP32[$2>>2]|0;
   $b3$063 = $98;
   while(1) {
    $101 = (0 - ($b3$063))|0;
    $102 = $b3$063 & $101;
    $103 = Math_imul($102, 125613361)|0;
    $104 = $103 >>> 27;
    $105 = (412480 + ($104<<2)|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = $106 | $100;
    $108 = (($$pre) + ($107<<4)|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($109|0)==(-1);
    L31: do {
     if ($110) {
      label = 22;
     } else {
      $nextNode$06$i = $109;
      while(1) {
       $111 = ((($$pre111) + (($nextNode$06$i*12)|0)|0) + 8|0);
       $112 = HEAP8[$111>>0]|0;
       $113 = $112 & 32;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        break;
       }
       $115 = (($$pre112) + ($nextNode$06$i<<2)|0);
       $116 = HEAP32[$115>>2]|0;
       HEAP32[$115>>2] = -1;
       $117 = ($116|0)==(-1);
       if ($117) {
        label = 22;
        break L31;
       } else {
        $nextNode$06$i = $116;
       }
      }
      HEAP32[$108>>2] = $nextNode$06$i;
      $undeletedNode$03$i = $nextNode$06$i;
      L36: while(1) {
       $118 = (($$pre112) + ($undeletedNode$03$i<<2)|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==(-1);
       if ($120) {
        break;
       } else {
        $nextNode1$02$i = $119;
       }
       while(1) {
        $121 = ((($$pre111) + (($nextNode1$02$i*12)|0)|0) + 8|0);
        $122 = HEAP8[$121>>0]|0;
        $123 = $122 & 32;
        $124 = ($123<<24>>24)==(0);
        if ($124) {
         break;
        }
        $125 = (($$pre112) + ($nextNode1$02$i<<2)|0);
        $126 = HEAP32[$125>>2]|0;
        HEAP32[$125>>2] = -1;
        $127 = ($126|0)==(-1);
        if ($127) {
         break L36;
        } else {
         $nextNode1$02$i = $126;
        }
       }
       HEAP32[$118>>2] = $nextNode1$02$i;
       $128 = ($nextNode1$02$i|0)==(-1);
       if ($128) {
        $endNode$0$lcssa$i = $undeletedNode$03$i;
        break L31;
       } else {
        $undeletedNode$03$i = $nextNode1$02$i;
       }
      }
      HEAP32[$118>>2] = -1;
      $endNode$0$lcssa$i = $undeletedNode$03$i;
     }
    } while(0);
    if ((label|0) == 22) {
     label = 0;
     HEAP32[$108>>2] = -1;
     $endNode$0$lcssa$i = -1;
    }
    $129 = ((($$pre) + ($107<<4)|0) + 8|0);
    HEAP32[$129>>2] = $endNode$0$lcssa$i;
    $130 = ((($$pre) + ($107<<4)|0) + 4|0);
    $nextEdge$059 = HEAP32[$130>>2]|0;
    $131 = ($nextEdge$059|0)==(-1);
    if (!($131)) {
     $nextEdge$060 = $nextEdge$059;
     while(1) {
      $132 = (($5) + (($nextEdge$060*12)|0)|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = ($133|0)==(-1);
      if (!($134)) {
       $135 = (($kinematicProxySourceNodes) + ($133<<2)|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = ($136|0)==(-1);
       if (!($137)) {
        HEAP32[$132>>2] = $136;
       }
      }
      $138 = ((($5) + (($nextEdge$060*12)|0)|0) + 4|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = ($139|0)==(-1);
      if (!($140)) {
       $141 = (($kinematicProxySourceNodes) + ($139<<2)|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ($142|0)==(-1);
       if (!($143)) {
        HEAP32[$138>>2] = $142;
       }
      }
      $144 = (($7) + ($nextEdge$060<<2)|0);
      $nextEdge$0 = HEAP32[$144>>2]|0;
      $145 = ($nextEdge$0|0)==(-1);
      if ($145) {
       break;
      } else {
       $nextEdge$060 = $nextEdge$0;
      }
     }
    }
    $146 = (($b3$063) + -1)|0;
    $147 = $146 & $b3$063;
    $148 = ($147|0)==(0);
    if ($148) {
     break;
    } else {
     $b3$063 = $147;
    }
   }
  }
  $149 = (($w2$067) + 1)|0;
  $exitcond98 = ($149|0)==($$0$i9|0);
  if ($exitcond98) {
   break;
  } else {
   $w2$067 = $149;
  }
 }
 $150 = HEAP32[$kinematicNodesBitmap>>2]|0;
 $151 = HEAP32[$14>>2]|0;
 $152 = $151 & 2147483647;
 $i$0$i3 = $152;
 while(1) {
  $153 = (($i$0$i3) + -1)|0;
  $154 = ($i$0$i3|0)==(0);
  if ($154) {
   $$0$i4 = 1;
   break;
  }
  $155 = (($150) + ($153<<2)|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = ($156|0)==(0);
  if ($157) {
   $i$0$i3 = $153;
  } else {
   label = 42;
   break;
  }
 }
 if ((label|0) == 42) {
  $158 = $153 << 5;
  $159 = $156 >>> 1;
  $160 = $159 | $156;
  $161 = $160 >>> 2;
  $162 = $161 | $160;
  $163 = $162 >>> 4;
  $164 = $163 | $162;
  $165 = $164 >>> 8;
  $166 = $165 | $164;
  $167 = $166 >>> 16;
  $168 = $167 | $166;
  $169 = Math_imul($168, 130329821)|0;
  $170 = $169 >>> 27;
  $171 = (482344 + ($170<<2)|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = (($172) + ($158))|0;
  $phitmp15 = $173 >>> 5;
  $phitmp115 = (($phitmp15) + 1)|0;
  $$0$i4 = $phitmp115;
 }
 $174 = (($islands) + 20|0);
 $175 = (($islands) + 16|0);
 $176 = (($islands) + 8|0);
 $w7$046 = 0;
 while(1) {
  $177 = (($150) + ($w7$046<<2)|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = ($178|0)==(0);
  if (!($179)) {
   $180 = $w7$046 << 5;
   $b8$042 = $178;
   while(1) {
    $181 = (0 - ($b8$042))|0;
    $182 = $b8$042 & $181;
    $183 = Math_imul($182, 125613361)|0;
    $184 = $183 >>> 27;
    $185 = (412480 + ($184<<2)|0);
    $186 = HEAP32[$185>>2]|0;
    $187 = $186 | $180;
    $188 = (($kinematicProxyNextNodes) + ($187<<2)|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = ($189|0)==(-1);
    if (!($190)) {
     $191 = (($graphStartIslands) + ($189<<2)|0);
     $nextIslandId0$026 = HEAP32[$191>>2]|0;
     $192 = ($nextIslandId0$026|0)==(-1);
     if ($192) {
      $firstIslandId$0$lcssa = -1;
     } else {
      $nextIslandId0$027 = $nextIslandId0$026;
      while(1) {
       $193 = (($graphNextIslands) + ($nextIslandId0$027<<2)|0);
       $nextIslandId0$0 = HEAP32[$193>>2]|0;
       $194 = ($nextIslandId0$0|0)==(-1);
       if ($194) {
        $firstIslandId$0$lcssa = $nextIslandId0$027;
        break;
       } else {
        $nextIslandId0$027 = $nextIslandId0$0;
       }
      }
     }
     $195 = (($kinematicProxySourceNodes) + ($189<<2)|0);
     $196 = HEAP32[$195>>2]|0;
     $197 = ((($1) + (($196*12)|0)|0) + 4|0);
     $198 = HEAP32[$96>>2]|0;
     HEAP32[$197>>2] = $firstIslandId$0$lcssa;
     $199 = (($198) + ($firstIslandId$0$lcssa<<4)|0);
     $200 = HEAP32[$199>>2]|0;
     $201 = (($3) + ($196<<2)|0);
     HEAP32[$201>>2] = $200;
     HEAP32[$199>>2] = $196;
     $202 = ((($198) + ($firstIslandId$0$lcssa<<4)|0) + 8|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = ($203|0)==(-1);
     $nodeId$$i = $204 ? $196 : $203;
     HEAP32[$202>>2] = $nodeId$$i;
     $nextProxyNodeId10$0$in37 = (($kinematicProxyNextNodes) + ($189<<2)|0);
     $nextProxyNodeId10$038 = HEAP32[$nextProxyNodeId10$0$in37>>2]|0;
     $205 = ($nextProxyNodeId10$038|0)==(-1);
     if (!($205)) {
      $nextProxyNodeId10$039 = $nextProxyNodeId10$038;
      while(1) {
       $206 = (($graphStartIslands) + ($nextProxyNodeId10$039<<2)|0);
       $nextIslandId$031 = HEAP32[$206>>2]|0;
       $207 = ($nextIslandId$031|0)==(-1);
       if ($207) {
        $islandId11$0$lcssa = -1;
       } else {
        $nextIslandId$032 = $nextIslandId$031;
        while(1) {
         $208 = (($graphNextIslands) + ($nextIslandId$032<<2)|0);
         $nextIslandId$0 = HEAP32[$208>>2]|0;
         $209 = ($nextIslandId$0|0)==(-1);
         if ($209) {
          $islandId11$0$lcssa = $nextIslandId$032;
          break;
         } else {
          $nextIslandId$032 = $nextIslandId$0;
         }
        }
       }
       $210 = ($firstIslandId$0$lcssa|0)==($islandId11$0$lcssa|0);
       if (!($210)) {
        $211 = $islandId11$0$lcssa >>> 5;
        $212 = HEAP32[$174>>2]|0;
        $213 = (($212) + ($211<<2)|0);
        $214 = HEAP32[$213>>2]|0;
        $215 = $islandId11$0$lcssa & 31;
        $216 = 1 << $215;
        $217 = $214 & $216;
        $218 = ($217|0)==(0);
        if (!($218)) {
         $220 = HEAP32[$96>>2]|0;
         $221 = (($220) + ($islandId11$0$lcssa<<4)|0);
         $nextNode$01$i = HEAP32[$221>>2]|0;
         $222 = ($nextNode$01$i|0)==(-1);
         if (!($222)) {
          $nextNode$02$i = $nextNode$01$i;
          while(1) {
           $223 = ((($1) + (($nextNode$02$i*12)|0)|0) + 4|0);
           HEAP32[$223>>2] = $firstIslandId$0$lcssa;
           $224 = (($3) + ($nextNode$02$i<<2)|0);
           $nextNode$0$i = HEAP32[$224>>2]|0;
           $225 = ($nextNode$0$i|0)==(-1);
           if ($225) {
            break;
           } else {
            $nextNode$02$i = $nextNode$0$i;
           }
          }
         }
         $226 = ((($220) + ($firstIslandId$0$lcssa<<4)|0) + 4|0);
         $227 = HEAP32[$226>>2]|0;
         $228 = ($227|0)==(-1);
         $229 = ((($220) + ($islandId11$0$lcssa<<4)|0) + 4|0);
         $230 = HEAP32[$229>>2]|0;
         if ($228) {
          HEAP32[$226>>2] = $230;
          $231 = ((($220) + ($islandId11$0$lcssa<<4)|0) + 12|0);
          $232 = HEAP32[$231>>2]|0;
          $233 = ((($220) + ($firstIslandId$0$lcssa<<4)|0) + 12|0);
          HEAP32[$233>>2] = $232;
         } else {
          $234 = ($230|0)==(-1);
          if (!($234)) {
           $235 = ((($220) + ($firstIslandId$0$lcssa<<4)|0) + 12|0);
           $236 = HEAP32[$235>>2]|0;
           $237 = (($7) + ($236<<2)|0);
           HEAP32[$237>>2] = $230;
           $238 = ((($220) + ($islandId11$0$lcssa<<4)|0) + 12|0);
           $239 = HEAP32[$238>>2]|0;
           HEAP32[$235>>2] = $239;
          }
         }
         $240 = (($220) + ($firstIslandId$0$lcssa<<4)|0);
         $241 = HEAP32[$240>>2]|0;
         $242 = ($241|0)==(-1);
         $243 = HEAP32[$221>>2]|0;
         if ($242) {
          HEAP32[$240>>2] = $243;
          $244 = ((($220) + ($islandId11$0$lcssa<<4)|0) + 8|0);
          $245 = HEAP32[$244>>2]|0;
          $246 = ((($220) + ($firstIslandId$0$lcssa<<4)|0) + 8|0);
          HEAP32[$246>>2] = $245;
         } else {
          $247 = ($243|0)==(-1);
          if (!($247)) {
           $248 = ((($220) + ($firstIslandId$0$lcssa<<4)|0) + 8|0);
           $249 = HEAP32[$248>>2]|0;
           $250 = (($3) + ($249<<2)|0);
           HEAP32[$250>>2] = $243;
           $251 = ((($220) + ($islandId11$0$lcssa<<4)|0) + 8|0);
           $252 = HEAP32[$251>>2]|0;
           HEAP32[$248>>2] = $252;
          }
         }
         $253 = (($220) + ($islandId11$0$lcssa<<4)|0);
         ;HEAP32[$253+0>>2]=4294967295|0;HEAP32[$253+4>>2]=4294967295|0;HEAP32[$253+8>>2]=4294967295|0;HEAP32[$253+12>>2]=4294967295|0;
         $254 = HEAP32[$175>>2]|0;
         $255 = HEAP32[$176>>2]|0;
         $256 = (($255) + ($islandId11$0$lcssa<<2)|0);
         HEAP32[$256>>2] = $254;
         HEAP32[$175>>2] = $islandId11$0$lcssa;
         $257 = $216 ^ -1;
         $258 = HEAP32[$174>>2]|0;
         $259 = (($258) + ($211<<2)|0);
         $260 = HEAP32[$259>>2]|0;
         $261 = $260 & $257;
         HEAP32[$259>>2] = $261;
         $262 = (($graphNextIslands) + ($islandId11$0$lcssa<<2)|0);
         HEAP32[$262>>2] = $firstIslandId$0$lcssa;
        }
       }
       $nextProxyNodeId10$0$in = (($kinematicProxyNextNodes) + ($nextProxyNodeId10$039<<2)|0);
       $nextProxyNodeId10$0 = HEAP32[$nextProxyNodeId10$0$in>>2]|0;
       $219 = ($nextProxyNodeId10$0|0)==(-1);
       if ($219) {
        break;
       } else {
        $nextProxyNodeId10$039 = $nextProxyNodeId10$0;
       }
      }
     }
    }
    $263 = (($b8$042) + -1)|0;
    $264 = $263 & $b8$042;
    $265 = ($264|0)==(0);
    if ($265) {
     break;
    } else {
     $b8$042 = $264;
    }
   }
  }
  $266 = (($w7$046) + 1)|0;
  $exitcond86 = ($266|0)==($$0$i4|0);
  if ($exitcond86) {
   break;
  } else {
   $w7$046 = $266;
  }
 }
 $267 = HEAP32[$kinematicNodesBitmap>>2]|0;
 $268 = HEAP32[$14>>2]|0;
 $269 = $268 & 2147483647;
 $i$0$i = $269;
 while(1) {
  $270 = (($i$0$i) + -1)|0;
  $271 = ($i$0$i|0)==(0);
  if ($271) {
   $$0$i = 1;
   break;
  }
  $272 = (($267) + ($270<<2)|0);
  $273 = HEAP32[$272>>2]|0;
  $274 = ($273|0)==(0);
  if ($274) {
   $i$0$i = $270;
  } else {
   label = 71;
   break;
  }
 }
 if ((label|0) == 71) {
  $275 = $270 << 5;
  $276 = $273 >>> 1;
  $277 = $276 | $273;
  $278 = $277 >>> 2;
  $279 = $278 | $277;
  $280 = $279 >>> 4;
  $281 = $280 | $279;
  $282 = $281 >>> 8;
  $283 = $282 | $281;
  $284 = $283 >>> 16;
  $285 = $284 | $283;
  $286 = Math_imul($285, 130329821)|0;
  $287 = $286 >>> 27;
  $288 = (482344 + ($287<<2)|0);
  $289 = HEAP32[$288>>2]|0;
  $290 = (($289) + ($275))|0;
  $phitmp16 = $290 >>> 5;
  $phitmp116 = (($phitmp16) + 1)|0;
  $$0$i = $phitmp116;
 }
 $291 = (($nodeManager) + 16|0);
 $292 = (($nodeManager) + 8|0);
 $w14$024 = 0;
 while(1) {
  $293 = (($267) + ($w14$024<<2)|0);
  $294 = HEAP32[$293>>2]|0;
  $295 = ($294|0)==(0);
  if (!($295)) {
   $296 = $w14$024 << 5;
   $b15$020 = $294;
   while(1) {
    $297 = (0 - ($b15$020))|0;
    $298 = $b15$020 & $297;
    $299 = Math_imul($298, 125613361)|0;
    $300 = $299 >>> 27;
    $301 = (412480 + ($300<<2)|0);
    $302 = HEAP32[$301>>2]|0;
    $303 = $302 | $296;
    $nextProxyNode$0$in17 = (($kinematicProxyNextNodes) + ($303<<2)|0);
    $nextProxyNode$018 = HEAP32[$nextProxyNode$0$in17>>2]|0;
    $304 = ($nextProxyNode$018|0)==(-1);
    if (!($304)) {
     $nextProxyNode$019 = $nextProxyNode$018;
     while(1) {
      $305 = HEAP32[$0>>2]|0;
      $306 = (($305) + (($nextProxyNode$019*12)|0)|0);
      HEAP32[$306>>2] = 0;
      $307 = ((($305) + (($nextProxyNode$019*12)|0)|0) + 4|0);
      HEAP32[$307>>2] = -1;
      $308 = ((($305) + (($nextProxyNode$019*12)|0)|0) + 8|0);
      HEAP8[$308>>0] = 0;
      $309 = HEAP32[$291>>2]|0;
      $310 = HEAP32[$292>>2]|0;
      $311 = (($310) + ($nextProxyNode$019<<2)|0);
      HEAP32[$311>>2] = $309;
      HEAP32[$291>>2] = $nextProxyNode$019;
      $nextProxyNode$0$in = (($kinematicProxyNextNodes) + ($nextProxyNode$019<<2)|0);
      $nextProxyNode$0 = HEAP32[$nextProxyNode$0$in>>2]|0;
      $312 = ($nextProxyNode$0|0)==(-1);
      if ($312) {
       break;
      } else {
       $nextProxyNode$019 = $nextProxyNode$0;
      }
     }
    }
    $313 = (($b15$020) + -1)|0;
    $314 = $313 & $b15$020;
    $315 = ($314|0)==(0);
    if ($315) {
     break;
    } else {
     $b15$020 = $314;
    }
   }
  }
  $316 = (($w14$024) + 1)|0;
  $exitcond = ($316|0)==($$0$i|0);
  if ($exitcond) {
   break;
  } else {
   $w14$024 = $316;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx17updateIslandsMainEjPKjjS1_jS1_jS1_jS1_jS1_jRKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjRNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerERNS_23ArticulationRootManagerERNS_33ProcessSleepingIslandsComputeDataERNS_30IslandManagerUpdateWorkBuffersEPNS2_13EventProfilerE($rigidBodyOffset,$deletedNodes,$numDeletedNodes,$createdNodes,$numCreatedNodes,$deletedEdges,$numDeletedEdges,$0,$1,$brokenEdges,$numBrokenEdges,$joinedEdges,$numJoinedEdges,$kinematicNodesBitmap,$numAddedKinematics,$nodeManager,$edgeManager,$islands,$articulationRootManager,$psicData,$workBuffers,$profiler) {
 $rigidBodyOffset = $rigidBodyOffset|0;
 $deletedNodes = $deletedNodes|0;
 $numDeletedNodes = $numDeletedNodes|0;
 $createdNodes = $createdNodes|0;
 $numCreatedNodes = $numCreatedNodes|0;
 $deletedEdges = $deletedEdges|0;
 $numDeletedEdges = $numDeletedEdges|0;
 $0 = $0|0;
 $1 = $1|0;
 $brokenEdges = $brokenEdges|0;
 $numBrokenEdges = $numBrokenEdges|0;
 $joinedEdges = $joinedEdges|0;
 $numJoinedEdges = $numJoinedEdges|0;
 $kinematicNodesBitmap = $kinematicNodesBitmap|0;
 $numAddedKinematics = $numAddedKinematics|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $articulationRootManager = $articulationRootManager|0;
 $psicData = $psicData|0;
 $workBuffers = $workBuffers|0;
 $profiler = $profiler|0;
 var $$0$i$i = 0, $$0$i$i28 = 0, $$0$i$i87 = 0, $$idx$val = 0, $$idx14$val = 0, $$not$i = 0, $$pre = 0, $$pre$i = 0, $$pre$pre$i = 0, $$pre158 = 0, $$pre65$i = 0, $$pre66$i = 0, $$pre67$i = 0, $$pre68$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0;
 var $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0;
 var $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0;
 var $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0;
 var $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0;
 var $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0;
 var $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0;
 var $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0;
 var $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0;
 var $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0;
 var $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0;
 var $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0;
 var $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0;
 var $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0;
 var $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0;
 var $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0;
 var $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$01$i = 0, $b$034$i = 0, $b$036$i = 0, $edgeId$$i$i = 0, $edgeId$$i3$i = 0;
 var $edgeId$$i4$i = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i31 = 0, $exitcond$i4$i = 0, $exitcond$i40 = 0, $exitcond$i44 = 0, $exitcond$i51 = 0, $exitcond$i56 = 0, $exitcond$i67 = 0, $exitcond$i75 = 0, $exitcond$i90 = 0, $exitcond50$i = 0, $exitcond54$i = 0, $exitcond64$i = 0, $i$0$i$i = 0, $i$0$i$i26 = 0, $i$0$i$i85 = 0, $i$01$i = 0, $i$01$i$i = 0;
 var $i$01$i3$i = 0, $i$01$i43 = 0, $i$01$i50 = 0, $i$01$i55 = 0, $i$01$i66 = 0, $i$01$i73 = 0, $i$042$i = 0, $i$046$i = 0, $i5$028$i = 0, $inEnabled$not$i = 0, $inEnabled$not$i15 = 0, $inEnabled$not$i17 = 0, $inEnabled$not$i20 = 0, $inEnabled$not$i23 = 0, $inEnabled$not$i33 = 0, $inEnabled$not$i36 = 0, $inEnabled$not$i46 = 0, $inEnabled$not$i59 = 0, $inEnabled$not$i62 = 0, $inEnabled$not$i69 = 0;
 var $inEnabled$not$i78 = 0, $inEnabled$not$i81 = 0, $inEnabled$not$i93 = 0, $islandId14$0$lcssa$i = 0, $islandId18$1$i = 0, $islandsToUpdate$i = 0, $nextIsland$0$i = 0, $nextIsland$016$i = 0, $nextIsland$017$i = 0, $nextIsland12$0$i = 0, $nextIsland12$021$i = 0, $nextIsland12$022$i = 0, $nextIsland15$0$i = 0, $nextIsland15$011$i = 0, $nextIsland15$012$i = 0, $nextNode$030$i = 0, $nextNode$06$i$i = 0, $nextNode$06$i6$i = 0, $nextNode1$02$i$i = 0, $nextNode1$02$i11$i = 0;
 var $nextNode13$013$i = 0, $nodeId$$i$i = 0, $nodeId$$i$i74 = 0, $nodeId$$i$i84 = 0, $nodeId$$i5$i = 0, $numIslandsToUpdate$037$i = 0, $numIslandsToUpdate$1$lcssa$i = 0, $numIslandsToUpdate$135$i = 0, $numIslandsToUpdate$2$i = 0, $or$cond$i = 0, $or$cond$i16 = 0, $or$cond$i18 = 0, $or$cond$i21 = 0, $or$cond$i24 = 0, $or$cond$i34 = 0, $or$cond$i37 = 0, $or$cond$i47 = 0, $or$cond$i60 = 0, $or$cond$i63 = 0, $or$cond$i70 = 0;
 var $or$cond$i79 = 0, $or$cond$i82 = 0, $or$cond$i89 = 0, $or$cond$i94 = 0, $or$cond1$i = 0, $or$cond2$i = 0, $phitmp$i = 0, $phitmp$i27 = 0, $phitmp$i86 = 0, $phitmp5$i = 0, $phitmp57$i = 0, $phitmp74$i = 0, $prevIslandId$043$i = 0, $prevIslandId$1$lcssa$i = 0, $prevIslandId$135$i = 0, $startNode$044$i = 0, $startNode$1$lcssa$i = 0, $startNode$136$i = 0, $startNode$2$i = 0, $undeletedNode$03$i$i = 0;
 var $undeletedNode$03$i10$i = 0, $w$02$i = 0, $w$038$i = 0, $w$042$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4096|0;
 $islandsToUpdate$i = sp;
 $2 = (($workBuffers) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($3) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 << 2;
 _memset(($4|0),0,($7|0))|0;
 $8 = ($profiler|0)!=(0|0);
 if ($8) {
  $9 = HEAP8[((545872 + 2|0))>>0]|0;
  $10 = (($profiler) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $inEnabled$not$i17 = ($9<<24>>24)==(0);
  $12 = ($11|0)==(0|0);
  $or$cond$i18 = $12 | $inEnabled$not$i17;
  if (!($or$cond$i18)) {
   $13 = $profiler;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($13) + 4)|0;
   $17 = $16;
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$11>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP16[545872>>1]|0;
   FUNCTION_TABLE_viiii[$21 & 511]($11,$22,$15,$18);
  }
 }
 $23 = (($workBuffers) + 52|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($24) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 << 2;
 _memset(($25|0),0,($28|0))|0;
 $29 = (($nodeManager) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($numDeletedNodes|0)==(0);
 if (!($31)) {
  $i$042$i = 0;
  while(1) {
   $32 = (($deletedNodes) + ($i$042$i<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ((($30) + (($33*12)|0)|0) + 8|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35 & 96;
   $37 = ($36<<24>>24)==(32);
   if ($37) {
    $38 = ((($30) + (($33*12)|0)|0) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = $39 & 31;
    $41 = 1 << $40;
    $42 = $39 >>> 5;
    $43 = HEAP32[$3>>2]|0;
    $44 = (($43) + ($42<<2)|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = $45 | $41;
    HEAP32[$44>>2] = $46;
   }
   $47 = (($i$042$i) + 1)|0;
   $exitcond64$i = ($47|0)==($numDeletedNodes|0);
   if ($exitcond64$i) {
    break;
   } else {
    $i$042$i = $47;
   }
  }
 }
 $48 = HEAP32[$5>>2]|0;
 $49 = $48 & 2147483647;
 $$pre$pre$i = HEAP32[$3>>2]|0;
 $i$0$i$i = $49;
 while(1) {
  $50 = (($i$0$i$i) + -1)|0;
  $51 = ($i$0$i$i|0)==(0);
  if ($51) {
   $$0$i$i = 1;
   break;
  }
  $52 = (($$pre$pre$i) + ($50<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0);
  if ($54) {
   $i$0$i$i = $50;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  $55 = $50 << 5;
  $56 = $53 >>> 1;
  $57 = $56 | $53;
  $58 = $57 >>> 2;
  $59 = $58 | $57;
  $60 = $59 >>> 4;
  $61 = $60 | $59;
  $62 = $61 >>> 8;
  $63 = $62 | $61;
  $64 = $63 >>> 16;
  $65 = $64 | $63;
  $66 = Math_imul($65, 130329821)|0;
  $67 = $66 >>> 27;
  $68 = (482344 + ($67<<2)|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($69) + ($55))|0;
  $phitmp$i = $70 >>> 5;
  $phitmp74$i = (($phitmp$i) + 1)|0;
  $$0$i$i = $phitmp74$i;
 }
 $71 = (($islands) + 4|0);
 $72 = (($nodeManager) + 20|0);
 $numIslandsToUpdate$037$i = 0;$w$038$i = 0;
 while(1) {
  $73 = (($$pre$pre$i) + ($w$038$i<<2)|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74|0)==(0);
  if ($75) {
   $numIslandsToUpdate$1$lcssa$i = $numIslandsToUpdate$037$i;
  } else {
   $76 = $w$038$i << 5;
   $b$036$i = $74;$numIslandsToUpdate$135$i = $numIslandsToUpdate$037$i;
   while(1) {
    $77 = (0 - ($b$036$i))|0;
    $78 = $b$036$i & $77;
    $79 = Math_imul($78, 125613361)|0;
    $80 = $79 >>> 27;
    $81 = (412480 + ($80<<2)|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = $82 | $76;
    $84 = ($numIslandsToUpdate$135$i>>>0)<(1024);
    if ($84) {
     $85 = (($islandsToUpdate$i) + ($numIslandsToUpdate$135$i<<2)|0);
     HEAP32[$85>>2] = $83;
     $86 = (($numIslandsToUpdate$135$i) + 1)|0;
     $numIslandsToUpdate$2$i = $86;
    } else {
     $$pre67$i = HEAP32[$71>>2]|0;
     $$pre68$i = HEAP32[$72>>2]|0;
     $i$01$i3$i = 0;
     while(1) {
      $87 = (($islandsToUpdate$i) + ($i$01$i3$i<<2)|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (($$pre67$i) + ($88<<4)|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = ($90|0)==(-1);
      L29: do {
       if ($91) {
        label = 21;
       } else {
        $nextNode$06$i6$i = $90;
        while(1) {
         $92 = ((($30) + (($nextNode$06$i6$i*12)|0)|0) + 8|0);
         $93 = HEAP8[$92>>0]|0;
         $94 = $93 & 32;
         $95 = ($94<<24>>24)==(0);
         if ($95) {
          break;
         }
         $96 = (($$pre68$i) + ($nextNode$06$i6$i<<2)|0);
         $97 = HEAP32[$96>>2]|0;
         HEAP32[$96>>2] = -1;
         $98 = ($97|0)==(-1);
         if ($98) {
          label = 21;
          break L29;
         } else {
          $nextNode$06$i6$i = $97;
         }
        }
        HEAP32[$89>>2] = $nextNode$06$i6$i;
        $undeletedNode$03$i10$i = $nextNode$06$i6$i;
        L34: while(1) {
         $100 = (($$pre68$i) + ($undeletedNode$03$i10$i<<2)|0);
         $101 = HEAP32[$100>>2]|0;
         $102 = ($101|0)==(-1);
         if ($102) {
          label = 26;
          break;
         } else {
          $nextNode1$02$i11$i = $101;
         }
         while(1) {
          $103 = ((($30) + (($nextNode1$02$i11$i*12)|0)|0) + 8|0);
          $104 = HEAP8[$103>>0]|0;
          $105 = $104 & 32;
          $106 = ($105<<24>>24)==(0);
          if ($106) {
           break;
          }
          $107 = (($$pre68$i) + ($nextNode1$02$i11$i<<2)|0);
          $108 = HEAP32[$107>>2]|0;
          HEAP32[$107>>2] = -1;
          $109 = ($108|0)==(-1);
          if ($109) {
           label = 26;
           break L34;
          } else {
           $nextNode1$02$i11$i = $108;
          }
         }
         HEAP32[$100>>2] = $nextNode1$02$i11$i;
         $110 = ($nextNode1$02$i11$i|0)==(-1);
         if ($110) {
          break;
         } else {
          $undeletedNode$03$i10$i = $nextNode1$02$i11$i;
         }
        }
        if ((label|0) == 26) {
         label = 0;
         HEAP32[$100>>2] = -1;
        }
        $111 = ((($$pre67$i) + ($88<<4)|0) + 8|0);
        HEAP32[$111>>2] = $undeletedNode$03$i10$i;
        $112 = ($undeletedNode$03$i10$i|0)==(-1);
        if ($112) {
         label = 29;
        }
       }
      } while(0);
      if ((label|0) == 21) {
       label = 0;
       HEAP32[$89>>2] = -1;
       $99 = ((($$pre67$i) + ($88<<4)|0) + 8|0);
       HEAP32[$99>>2] = -1;
       label = 29;
      }
      if ((label|0) == 29) {
       label = 0;
       $113 = $88 & 31;
       $114 = 1 << $113;
       $115 = $88 >>> 5;
       $116 = HEAP32[$24>>2]|0;
       $117 = (($116) + ($115<<2)|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = $118 | $114;
       HEAP32[$117>>2] = $119;
      }
      $120 = (($i$01$i3$i) + 1)|0;
      $exitcond$i4$i = ($120|0)==($numIslandsToUpdate$135$i|0);
      if ($exitcond$i4$i) {
       break;
      } else {
       $i$01$i3$i = $120;
      }
     }
     HEAP32[$islandsToUpdate$i>>2] = $83;
     $numIslandsToUpdate$2$i = 1;
    }
    $121 = (($b$036$i) + -1)|0;
    $122 = $121 & $b$036$i;
    $123 = ($122|0)==(0);
    if ($123) {
     $numIslandsToUpdate$1$lcssa$i = $numIslandsToUpdate$2$i;
     break;
    } else {
     $b$036$i = $122;$numIslandsToUpdate$135$i = $numIslandsToUpdate$2$i;
    }
   }
  }
  $124 = (($w$038$i) + 1)|0;
  $exitcond$i = ($124|0)==($$0$i$i|0);
  if ($exitcond$i) {
   break;
  } else {
   $numIslandsToUpdate$037$i = $numIslandsToUpdate$1$lcssa$i;$w$038$i = $124;
  }
 }
 $125 = ($numIslandsToUpdate$1$lcssa$i|0)==(0);
 if (!($125)) {
  $$pre65$i = HEAP32[$71>>2]|0;
  $$pre66$i = HEAP32[$72>>2]|0;
  $i$01$i$i = 0;
  while(1) {
   $126 = (($islandsToUpdate$i) + ($i$01$i$i<<2)|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($$pre65$i) + ($127<<4)|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(-1);
   L56: do {
    if ($130) {
     label = 39;
    } else {
     $nextNode$06$i$i = $129;
     while(1) {
      $131 = ((($30) + (($nextNode$06$i$i*12)|0)|0) + 8|0);
      $132 = HEAP8[$131>>0]|0;
      $133 = $132 & 32;
      $134 = ($133<<24>>24)==(0);
      if ($134) {
       break;
      }
      $135 = (($$pre66$i) + ($nextNode$06$i$i<<2)|0);
      $136 = HEAP32[$135>>2]|0;
      HEAP32[$135>>2] = -1;
      $137 = ($136|0)==(-1);
      if ($137) {
       label = 39;
       break L56;
      } else {
       $nextNode$06$i$i = $136;
      }
     }
     HEAP32[$128>>2] = $nextNode$06$i$i;
     $undeletedNode$03$i$i = $nextNode$06$i$i;
     L61: while(1) {
      $139 = (($$pre66$i) + ($undeletedNode$03$i$i<<2)|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = ($140|0)==(-1);
      if ($141) {
       label = 44;
       break;
      } else {
       $nextNode1$02$i$i = $140;
      }
      while(1) {
       $142 = ((($30) + (($nextNode1$02$i$i*12)|0)|0) + 8|0);
       $143 = HEAP8[$142>>0]|0;
       $144 = $143 & 32;
       $145 = ($144<<24>>24)==(0);
       if ($145) {
        break;
       }
       $146 = (($$pre66$i) + ($nextNode1$02$i$i<<2)|0);
       $147 = HEAP32[$146>>2]|0;
       HEAP32[$146>>2] = -1;
       $148 = ($147|0)==(-1);
       if ($148) {
        label = 44;
        break L61;
       } else {
        $nextNode1$02$i$i = $147;
       }
      }
      HEAP32[$139>>2] = $nextNode1$02$i$i;
      $149 = ($nextNode1$02$i$i|0)==(-1);
      if ($149) {
       break;
      } else {
       $undeletedNode$03$i$i = $nextNode1$02$i$i;
      }
     }
     if ((label|0) == 44) {
      label = 0;
      HEAP32[$139>>2] = -1;
     }
     $150 = ((($$pre65$i) + ($127<<4)|0) + 8|0);
     HEAP32[$150>>2] = $undeletedNode$03$i$i;
     $151 = ($undeletedNode$03$i$i|0)==(-1);
     if ($151) {
      label = 47;
     }
    }
   } while(0);
   if ((label|0) == 39) {
    label = 0;
    HEAP32[$128>>2] = -1;
    $138 = ((($$pre65$i) + ($127<<4)|0) + 8|0);
    HEAP32[$138>>2] = -1;
    label = 47;
   }
   if ((label|0) == 47) {
    label = 0;
    $152 = $127 & 31;
    $153 = 1 << $152;
    $154 = $127 >>> 5;
    $155 = HEAP32[$24>>2]|0;
    $156 = (($155) + ($154<<2)|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = $157 | $153;
    HEAP32[$156>>2] = $158;
   }
   $159 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($159|0)==($numIslandsToUpdate$1$lcssa$i|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $159;
   }
  }
 }
 $160 = HEAP32[$5>>2]|0;
 $161 = $160 << 2;
 _memset(($$pre$pre$i|0),0,($161|0))|0;
 __ZL28removeBrokenEdgesFromIslandsPKjjS0_jS0_RN5physx11NodeManagerERNS1_11EdgeManagerERNS1_13IslandManagerERNS1_2Cm10BitMapBaseINS1_6shdfnd9AllocatorEEE($brokenEdges,$numBrokenEdges,$deletedEdges,$numDeletedEdges,0,$nodeManager,$edgeManager,$islands,$3);
 $$idx$val = HEAP32[$24>>2]|0;
 $$idx14$val = HEAP32[$26>>2]|0;
 $162 = $$idx14$val & 2147483647;
 $i$0$i$i26 = $162;
 while(1) {
  $163 = (($i$0$i$i26) + -1)|0;
  $164 = ($i$0$i$i26|0)==(0);
  if ($164) {
   $$0$i$i28 = 1;
   break;
  }
  $165 = (($$idx$val) + ($163<<2)|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = ($166|0)==(0);
  if ($167) {
   $i$0$i$i26 = $163;
  } else {
   label = 52;
   break;
  }
 }
 if ((label|0) == 52) {
  $168 = $163 << 5;
  $169 = $166 >>> 1;
  $170 = $169 | $166;
  $171 = $170 >>> 2;
  $172 = $171 | $170;
  $173 = $172 >>> 4;
  $174 = $173 | $172;
  $175 = $174 >>> 8;
  $176 = $175 | $174;
  $177 = $176 >>> 16;
  $178 = $177 | $176;
  $179 = Math_imul($178, 130329821)|0;
  $180 = $179 >>> 27;
  $181 = (482344 + ($180<<2)|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = (($182) + ($168))|0;
  $phitmp$i27 = $183 >>> 5;
  $phitmp5$i = (($phitmp$i27) + 1)|0;
  $$0$i$i28 = $phitmp5$i;
 }
 $184 = (($islands) + 16|0);
 $185 = (($islands) + 8|0);
 $186 = (($islands) + 20|0);
 $w$02$i = 0;
 while(1) {
  $187 = (($$idx$val) + ($w$02$i<<2)|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = ($188|0)==(0);
  if (!($189)) {
   $190 = $w$02$i << 5;
   $b$01$i = $188;
   while(1) {
    $191 = (0 - ($b$01$i))|0;
    $192 = $b$01$i & $191;
    $193 = Math_imul($192, 125613361)|0;
    $194 = $193 >>> 27;
    $195 = (412480 + ($194<<2)|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = $196 | $190;
    $198 = HEAP32[$71>>2]|0;
    $199 = (($198) + ($197<<4)|0);
    ;HEAP32[$199+0>>2]=4294967295|0;HEAP32[$199+4>>2]=4294967295|0;HEAP32[$199+8>>2]=4294967295|0;HEAP32[$199+12>>2]=4294967295|0;
    $200 = HEAP32[$184>>2]|0;
    $201 = HEAP32[$185>>2]|0;
    $202 = (($201) + ($197<<2)|0);
    HEAP32[$202>>2] = $200;
    HEAP32[$184>>2] = $197;
    $203 = $196 & 31;
    $204 = 1 << $203;
    $205 = $204 ^ -1;
    $206 = $197 >>> 5;
    $207 = HEAP32[$186>>2]|0;
    $208 = (($207) + ($206<<2)|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = $209 & $205;
    HEAP32[$208>>2] = $210;
    $211 = HEAP32[$3>>2]|0;
    $212 = (($211) + ($206<<2)|0);
    $213 = HEAP32[$212>>2]|0;
    $214 = $213 & $205;
    HEAP32[$212>>2] = $214;
    $215 = (($b$01$i) + -1)|0;
    $216 = $215 & $b$01$i;
    $217 = ($216|0)==(0);
    if ($217) {
     break;
    } else {
     $b$01$i = $216;
    }
   }
  }
  $218 = (($w$02$i) + 1)|0;
  $exitcond$i31 = ($218|0)==($$0$i$i28|0);
  if ($exitcond$i31) {
   break;
  } else {
   $w$02$i = $218;
  }
 }
 $219 = HEAP32[$24>>2]|0;
 $220 = HEAP32[$26>>2]|0;
 $221 = $220 << 2;
 _memset(($219|0),0,($221|0))|0;
 if ($8) {
  $222 = HEAP8[((545872 + 2|0))>>0]|0;
  $223 = (($profiler) + 8|0);
  $224 = HEAP32[$223>>2]|0;
  $inEnabled$not$i62 = ($222<<24>>24)==(0);
  $225 = ($224|0)==(0|0);
  $or$cond$i63 = $225 | $inEnabled$not$i62;
  if ($or$cond$i63) {
   $238 = $224;
  } else {
   $226 = $profiler;
   $227 = $226;
   $228 = HEAP32[$227>>2]|0;
   $229 = (($226) + 4)|0;
   $230 = $229;
   $231 = HEAP32[$230>>2]|0;
   $232 = HEAP32[$224>>2]|0;
   $233 = (($232) + 12|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = HEAP16[545872>>1]|0;
   FUNCTION_TABLE_viiii[$234 & 511]($224,$235,$228,$231);
   $$pre = HEAP32[$223>>2]|0;
   $238 = $$pre;
  }
  $236 = HEAP8[((545880 + 2|0))>>0]|0;
  $inEnabled$not$i93 = ($236<<24>>24)==(0);
  $237 = ($238|0)==(0|0);
  $or$cond$i94 = $237 | $inEnabled$not$i93;
  if (!($or$cond$i94)) {
   $239 = $profiler;
   $240 = $239;
   $241 = HEAP32[$240>>2]|0;
   $242 = (($239) + 4)|0;
   $243 = $242;
   $244 = HEAP32[$243>>2]|0;
   $245 = HEAP32[$238>>2]|0;
   $246 = (($245) + 8|0);
   $247 = HEAP32[$246>>2]|0;
   $248 = HEAP16[545880>>1]|0;
   FUNCTION_TABLE_viiii[$247 & 511]($238,$248,$241,$244);
  }
 }
 $249 = HEAP32[$23>>2]|0;
 $250 = HEAP32[$249>>2]|0;
 $251 = (($249) + 4|0);
 $252 = HEAP32[$251>>2]|0;
 $253 = $252 << 2;
 _memset(($250|0),0,($253|0))|0;
 $254 = (($workBuffers) + 56|0);
 $255 = HEAP32[$254>>2]|0;
 $256 = (($workBuffers) + 60|0);
 $257 = HEAP32[$256>>2]|0;
 $258 = (($workBuffers) + 64|0);
 $259 = HEAP32[$258>>2]|0;
 $260 = HEAP32[$29>>2]|0;
 $261 = (($edgeManager) + 4|0);
 $262 = HEAP32[$261>>2]|0;
 $263 = HEAP32[$72>>2]|0;
 $264 = (($edgeManager) + 20|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = (($islands) + 12|0);
 $267 = HEAP32[$266>>2]|0;
 $268 = $267 << 2;
 _memset(($255|0),-1,($268|0))|0;
 $269 = HEAP32[$266>>2]|0;
 $270 = $269 << 2;
 _memset(($257|0),-1,($270|0))|0;
 $271 = HEAP32[$266>>2]|0;
 $272 = $271 << 2;
 _memset(($259|0),-1,($272|0))|0;
 $273 = ($numJoinedEdges|0)==(0);
 if (!($273)) {
  $i$046$i = 0;
  while(1) {
   $274 = (($joinedEdges) + ($i$046$i<<2)|0);
   $275 = HEAP32[$274>>2]|0;
   $276 = ((($262) + (($275*12)|0)|0) + 8|0);
   $277 = HEAP32[$276>>2]|0;
   $278 = $277;
   $279 = $278 & 8;
   $280 = ($279|0)==(0);
   do {
    if ($280) {
     $281 = (($262) + (($275*12)|0)|0);
     $282 = HEAP32[$281>>2]|0;
     $283 = ($282|0)==(-1);
     do {
      if (!($283)) {
       $284 = ((($260) + (($282*12)|0)|0) + 4|0);
       $285 = HEAP32[$284>>2]|0;
       $286 = ($285|0)==(-1);
       if ($286) {
        $294 = HEAP32[$184>>2]|0;
        $295 = HEAP32[$185>>2]|0;
        $296 = (($295) + ($294<<2)|0);
        $297 = HEAP32[$296>>2]|0;
        HEAP32[$184>>2] = $297;
        HEAP32[$296>>2] = -1;
        $298 = HEAP32[$71>>2]|0;
        $299 = (($298) + ($294<<4)|0);
        ;HEAP32[$299+0>>2]=4294967295|0;HEAP32[$299+4>>2]=4294967295|0;HEAP32[$299+8>>2]=4294967295|0;HEAP32[$299+12>>2]=4294967295|0;
        $300 = $294 & 31;
        $301 = 1 << $300;
        $302 = $294 >>> 5;
        $303 = HEAP32[$186>>2]|0;
        $304 = (($303) + ($302<<2)|0);
        $305 = HEAP32[$304>>2]|0;
        $306 = $305 | $301;
        HEAP32[$304>>2] = $306;
        $307 = HEAP32[$71>>2]|0;
        HEAP32[$284>>2] = $294;
        $308 = (($307) + ($294<<4)|0);
        $309 = HEAP32[$308>>2]|0;
        $310 = (($263) + ($282<<2)|0);
        HEAP32[$310>>2] = $309;
        HEAP32[$308>>2] = $282;
        $311 = ((($307) + ($294<<4)|0) + 8|0);
        $312 = HEAP32[$311>>2]|0;
        $313 = ($312|0)==(-1);
        $nodeId$$i5$i = $313 ? $282 : $312;
        HEAP32[$311>>2] = $nodeId$$i5$i;
        $314 = HEAP32[$249>>2]|0;
        $315 = (($314) + ($302<<2)|0);
        $316 = HEAP32[$315>>2]|0;
        $317 = $316 | $301;
        HEAP32[$315>>2] = $317;
        break;
       } else {
        $287 = $285 & 31;
        $288 = 1 << $287;
        $289 = $285 >>> 5;
        $290 = HEAP32[$249>>2]|0;
        $291 = (($290) + ($289<<2)|0);
        $292 = HEAP32[$291>>2]|0;
        $293 = $292 | $288;
        HEAP32[$291>>2] = $293;
        break;
       }
      }
     } while(0);
     $318 = ((($262) + (($275*12)|0)|0) + 4|0);
     $319 = HEAP32[$318>>2]|0;
     $320 = ($319|0)==(-1);
     if (!($320)) {
      $321 = ((($260) + (($319*12)|0)|0) + 4|0);
      $322 = HEAP32[$321>>2]|0;
      $323 = ($322|0)==(-1);
      if ($323) {
       $331 = HEAP32[$184>>2]|0;
       $332 = HEAP32[$185>>2]|0;
       $333 = (($332) + ($331<<2)|0);
       $334 = HEAP32[$333>>2]|0;
       HEAP32[$184>>2] = $334;
       HEAP32[$333>>2] = -1;
       $335 = HEAP32[$71>>2]|0;
       $336 = (($335) + ($331<<4)|0);
       ;HEAP32[$336+0>>2]=4294967295|0;HEAP32[$336+4>>2]=4294967295|0;HEAP32[$336+8>>2]=4294967295|0;HEAP32[$336+12>>2]=4294967295|0;
       $337 = $331 & 31;
       $338 = 1 << $337;
       $339 = $331 >>> 5;
       $340 = HEAP32[$186>>2]|0;
       $341 = (($340) + ($339<<2)|0);
       $342 = HEAP32[$341>>2]|0;
       $343 = $342 | $338;
       HEAP32[$341>>2] = $343;
       $344 = HEAP32[$71>>2]|0;
       HEAP32[$321>>2] = $331;
       $345 = (($344) + ($331<<4)|0);
       $346 = HEAP32[$345>>2]|0;
       $347 = (($263) + ($319<<2)|0);
       HEAP32[$347>>2] = $346;
       HEAP32[$345>>2] = $319;
       $348 = ((($344) + ($331<<4)|0) + 8|0);
       $349 = HEAP32[$348>>2]|0;
       $350 = ($349|0)==(-1);
       $nodeId$$i$i84 = $350 ? $319 : $349;
       HEAP32[$348>>2] = $nodeId$$i$i84;
       $351 = HEAP32[$249>>2]|0;
       $352 = (($351) + ($339<<2)|0);
       $353 = HEAP32[$352>>2]|0;
       $354 = $353 | $338;
       HEAP32[$352>>2] = $354;
       break;
      } else {
       $324 = $322 & 31;
       $325 = 1 << $324;
       $326 = $322 >>> 5;
       $327 = HEAP32[$249>>2]|0;
       $328 = (($327) + ($326<<2)|0);
       $329 = HEAP32[$328>>2]|0;
       $330 = $329 | $325;
       HEAP32[$328>>2] = $330;
       break;
      }
     }
    }
   } while(0);
   $355 = (($i$046$i) + 1)|0;
   $exitcond54$i = ($355|0)==($numJoinedEdges|0);
   if ($exitcond54$i) {
    break;
   } else {
    $i$046$i = $355;
   }
  }
 }
 $356 = HEAP32[$251>>2]|0;
 $357 = $356 & 2147483647;
 $$pre$i = HEAP32[$249>>2]|0;
 $i$0$i$i85 = $357;
 while(1) {
  $358 = (($i$0$i$i85) + -1)|0;
  $359 = ($i$0$i$i85|0)==(0);
  if ($359) {
   $$0$i$i87 = 1;
   break;
  }
  $360 = (($$pre$i) + ($358<<2)|0);
  $361 = HEAP32[$360>>2]|0;
  $362 = ($361|0)==(0);
  if ($362) {
   $i$0$i$i85 = $358;
  } else {
   label = 77;
   break;
  }
 }
 if ((label|0) == 77) {
  $363 = $358 << 5;
  $364 = $361 >>> 1;
  $365 = $364 | $361;
  $366 = $365 >>> 2;
  $367 = $366 | $365;
  $368 = $367 >>> 4;
  $369 = $368 | $367;
  $370 = $369 >>> 8;
  $371 = $370 | $369;
  $372 = $371 >>> 16;
  $373 = $372 | $371;
  $374 = Math_imul($373, 130329821)|0;
  $375 = $374 >>> 27;
  $376 = (482344 + ($375<<2)|0);
  $377 = HEAP32[$376>>2]|0;
  $378 = (($377) + ($363))|0;
  $phitmp$i86 = $378 >>> 5;
  $phitmp57$i = (($phitmp$i86) + 1)|0;
  $$0$i$i87 = $phitmp57$i;
 }
 $prevIslandId$043$i = -1;$startNode$044$i = -1;$w$042$i = 0;
 while(1) {
  $379 = (($$pre$i) + ($w$042$i<<2)|0);
  $380 = HEAP32[$379>>2]|0;
  $381 = ($380|0)==(0);
  if ($381) {
   $prevIslandId$1$lcssa$i = $prevIslandId$043$i;$startNode$1$lcssa$i = $startNode$044$i;
  } else {
   $382 = $w$042$i << 5;
   $383 = HEAP32[$71>>2]|0;
   $b$034$i = $380;$prevIslandId$135$i = $prevIslandId$043$i;$startNode$136$i = $startNode$044$i;
   while(1) {
    $384 = (0 - ($b$034$i))|0;
    $385 = $b$034$i & $384;
    $386 = Math_imul($385, 125613361)|0;
    $387 = $386 >>> 27;
    $388 = (412480 + ($387<<2)|0);
    $389 = HEAP32[$388>>2]|0;
    $390 = $389 | $382;
    $391 = (($383) + ($390<<4)|0);
    $392 = HEAP32[$391>>2]|0;
    $393 = ($prevIslandId$135$i|0)==(-1);
    if ($393) {
     $startNode$2$i = $392;
    } else {
     $394 = ((($383) + ($prevIslandId$135$i<<4)|0) + 8|0);
     $395 = HEAP32[$394>>2]|0;
     $396 = (($255) + ($395<<2)|0);
     HEAP32[$396>>2] = $392;
     $startNode$2$i = $startNode$136$i;
    }
    $397 = ($392|0)==(-1);
    if (!($397)) {
     $nextNode$030$i = $392;
     while(1) {
      $398 = ((($260) + (($nextNode$030$i*12)|0)|0) + 4|0);
      $399 = HEAP32[$398>>2]|0;
      $400 = (($263) + ($nextNode$030$i<<2)|0);
      $401 = HEAP32[$400>>2]|0;
      $402 = (($255) + ($nextNode$030$i<<2)|0);
      HEAP32[$402>>2] = $401;
      $403 = (($257) + ($nextNode$030$i<<2)|0);
      HEAP32[$403>>2] = $399;
      $404 = (($259) + ($399<<2)|0);
      HEAP32[$404>>2] = -1;
      $405 = HEAP32[$400>>2]|0;
      $406 = ($405|0)==(-1);
      if ($406) {
       break;
      } else {
       $nextNode$030$i = $405;
      }
     }
    }
    $407 = (($b$034$i) + -1)|0;
    $408 = $407 & $b$034$i;
    $409 = ($408|0)==(0);
    if ($409) {
     $prevIslandId$1$lcssa$i = $390;$startNode$1$lcssa$i = $startNode$2$i;
     break;
    } else {
     $b$034$i = $408;$prevIslandId$135$i = $390;$startNode$136$i = $startNode$2$i;
    }
   }
  }
  $410 = (($w$042$i) + 1)|0;
  $exitcond50$i = ($410|0)==($$0$i$i87|0);
  if ($exitcond50$i) {
   break;
  } else {
   $prevIslandId$043$i = $prevIslandId$1$lcssa$i;$startNode$044$i = $startNode$1$lcssa$i;$w$042$i = $410;
  }
 }
 if (!($273)) {
  $i5$028$i = 0;
  while(1) {
   $412 = (($joinedEdges) + ($i5$028$i<<2)|0);
   $413 = HEAP32[$412>>2]|0;
   $414 = ((($262) + (($413*12)|0)|0) + 8|0);
   $415 = HEAP32[$414>>2]|0;
   $416 = $415;
   $417 = $416 & 8;
   $418 = ($417|0)==(0);
   L138: do {
    if ($418) {
     $419 = (($262) + (($413*12)|0)|0);
     $420 = HEAP32[$419>>2]|0;
     $421 = ($420|0)==(-1);
     if ($421) {
      $islandId18$1$i = -1;
     } else {
      $422 = (($257) + ($420<<2)|0);
      $nextIsland$016$i = HEAP32[$422>>2]|0;
      $423 = ($nextIsland$016$i|0)==(-1);
      if ($423) {
       $islandId18$1$i = -1;
      } else {
       $nextIsland$017$i = $nextIsland$016$i;
       while(1) {
        $424 = (($259) + ($nextIsland$017$i<<2)|0);
        $nextIsland$0$i = HEAP32[$424>>2]|0;
        $425 = ($nextIsland$0$i|0)==(-1);
        if ($425) {
         $islandId18$1$i = $nextIsland$017$i;
         break;
        } else {
         $nextIsland$017$i = $nextIsland$0$i;
        }
       }
      }
     }
     $426 = ((($262) + (($413*12)|0)|0) + 4|0);
     $427 = HEAP32[$426>>2]|0;
     $428 = ($427|0)==(-1);
     do {
      if ($428) {
       $429 = ($islandId18$1$i|0)!=(-1);
       $502 = $429;$503 = 1;
      } else {
       $430 = (($257) + ($427<<2)|0);
       $nextIsland12$021$i = HEAP32[$430>>2]|0;
       $431 = ($nextIsland12$021$i|0)==(-1);
       if ($431) {
        $432 = ($islandId18$1$i|0)!=(-1);
        $502 = $432;$503 = 1;
        break;
       } else {
        $nextIsland12$022$i = $nextIsland12$021$i;
       }
       while(1) {
        $433 = (($259) + ($nextIsland12$022$i<<2)|0);
        $nextIsland12$0$i = HEAP32[$433>>2]|0;
        $434 = ($nextIsland12$0$i|0)==(-1);
        if ($434) {
         break;
        } else {
         $nextIsland12$022$i = $nextIsland12$0$i;
        }
       }
       $435 = ($islandId18$1$i|0)!=(-1);
       $$not$i = $435 ^ 1;
       $436 = ($nextIsland12$022$i|0)==(-1);
       $or$cond$i89 = $436 | $$not$i;
       if ($or$cond$i89) {
        $or$cond1$i = $435 | $436;
        if ($or$cond1$i) {
         $502 = $435;$503 = $436;
         break;
        }
        $495 = HEAP32[$71>>2]|0;
        $496 = ((($495) + ($nextIsland12$022$i<<4)|0) + 4|0);
        $497 = HEAP32[$496>>2]|0;
        $498 = (($265) + ($413<<2)|0);
        HEAP32[$498>>2] = $497;
        HEAP32[$496>>2] = $413;
        $499 = ((($495) + ($nextIsland12$022$i<<4)|0) + 12|0);
        $500 = HEAP32[$499>>2]|0;
        $501 = ($500|0)==(-1);
        $edgeId$$i3$i = $501 ? $413 : $500;
        HEAP32[$499>>2] = $edgeId$$i3$i;
        break L138;
       }
       $437 = HEAP32[$71>>2]|0;
       $438 = ((($437) + ($islandId18$1$i<<4)|0) + 4|0);
       $439 = HEAP32[$438>>2]|0;
       $440 = (($265) + ($413<<2)|0);
       HEAP32[$440>>2] = $439;
       HEAP32[$438>>2] = $413;
       $441 = ((($437) + ($islandId18$1$i<<4)|0) + 12|0);
       $442 = HEAP32[$441>>2]|0;
       $443 = ($442|0)==(-1);
       $edgeId$$i4$i = $443 ? $413 : $442;
       HEAP32[$441>>2] = $edgeId$$i4$i;
       $444 = ($islandId18$1$i|0)==($nextIsland12$022$i|0);
       if ($444) {
        break L138;
       }
       HEAP32[$433>>2] = $islandId18$1$i;
       $445 = HEAP32[$438>>2]|0;
       $446 = ($445|0)==(-1);
       $447 = ((($437) + ($nextIsland12$022$i<<4)|0) + 4|0);
       $448 = HEAP32[$447>>2]|0;
       if ($446) {
        HEAP32[$438>>2] = $448;
        $449 = ((($437) + ($nextIsland12$022$i<<4)|0) + 12|0);
        $450 = HEAP32[$449>>2]|0;
        HEAP32[$441>>2] = $450;
       } else {
        $451 = ($448|0)==(-1);
        if (!($451)) {
         $452 = HEAP32[$441>>2]|0;
         $453 = (($265) + ($452<<2)|0);
         HEAP32[$453>>2] = $448;
         $454 = ((($437) + ($nextIsland12$022$i<<4)|0) + 12|0);
         $455 = HEAP32[$454>>2]|0;
         HEAP32[$441>>2] = $455;
        }
       }
       $456 = (($437) + ($islandId18$1$i<<4)|0);
       $457 = HEAP32[$456>>2]|0;
       $458 = ($457|0)==(-1);
       $459 = (($437) + ($nextIsland12$022$i<<4)|0);
       $460 = HEAP32[$459>>2]|0;
       if ($458) {
        HEAP32[$456>>2] = $460;
        $461 = ((($437) + ($nextIsland12$022$i<<4)|0) + 8|0);
        $462 = HEAP32[$461>>2]|0;
        $463 = ((($437) + ($islandId18$1$i<<4)|0) + 8|0);
        HEAP32[$463>>2] = $462;
       } else {
        $464 = ($460|0)==(-1);
        if (!($464)) {
         $465 = ((($437) + ($islandId18$1$i<<4)|0) + 8|0);
         $466 = HEAP32[$465>>2]|0;
         $467 = (($263) + ($466<<2)|0);
         HEAP32[$467>>2] = $460;
         $468 = ((($437) + ($nextIsland12$022$i<<4)|0) + 8|0);
         $469 = HEAP32[$468>>2]|0;
         HEAP32[$465>>2] = $469;
        }
       }
       $470 = (($437) + ($nextIsland12$022$i<<4)|0);
       ;HEAP32[$470+0>>2]=4294967295|0;HEAP32[$470+4>>2]=4294967295|0;HEAP32[$470+8>>2]=4294967295|0;HEAP32[$470+12>>2]=4294967295|0;
       $471 = HEAP32[$184>>2]|0;
       $472 = HEAP32[$185>>2]|0;
       $473 = (($472) + ($nextIsland12$022$i<<2)|0);
       HEAP32[$473>>2] = $471;
       HEAP32[$184>>2] = $nextIsland12$022$i;
       $474 = $nextIsland12$022$i & 31;
       $475 = 1 << $474;
       $476 = $475 ^ -1;
       $477 = $nextIsland12$022$i >>> 5;
       $478 = HEAP32[$186>>2]|0;
       $479 = (($478) + ($477<<2)|0);
       $480 = HEAP32[$479>>2]|0;
       $481 = $480 & $476;
       HEAP32[$479>>2] = $481;
       $482 = HEAP32[$3>>2]|0;
       $483 = (($482) + ($477<<2)|0);
       $484 = HEAP32[$483>>2]|0;
       $485 = $484 & $475;
       $486 = ($485|0)==(0);
       if ($486) {
        break L138;
       }
       $487 = $islandId18$1$i & 31;
       $488 = 1 << $487;
       $489 = $islandId18$1$i >>> 5;
       $490 = (($482) + ($489<<2)|0);
       $491 = HEAP32[$490>>2]|0;
       $492 = $491 | $488;
       HEAP32[$490>>2] = $492;
       $493 = HEAP32[$483>>2]|0;
       $494 = $493 & $476;
       HEAP32[$483>>2] = $494;
       break L138;
      }
     } while(0);
     $or$cond2$i = $502 & $503;
     if ($or$cond2$i) {
      $504 = HEAP32[$71>>2]|0;
      $505 = ((($504) + ($islandId18$1$i<<4)|0) + 4|0);
      $506 = HEAP32[$505>>2]|0;
      $507 = (($265) + ($413<<2)|0);
      HEAP32[$507>>2] = $506;
      HEAP32[$505>>2] = $413;
      $508 = ((($504) + ($islandId18$1$i<<4)|0) + 12|0);
      $509 = HEAP32[$508>>2]|0;
      $510 = ($509|0)==(-1);
      $edgeId$$i$i = $510 ? $413 : $509;
      HEAP32[$508>>2] = $edgeId$$i$i;
     }
    }
   } while(0);
   $511 = (($i5$028$i) + 1)|0;
   $exitcond$i90 = ($511|0)==($numJoinedEdges|0);
   if ($exitcond$i90) {
    break;
   } else {
    $i5$028$i = $511;
   }
  }
 }
 $411 = ($startNode$1$lcssa$i|0)==(-1);
 if (!($411)) {
  $nextNode13$013$i = $startNode$1$lcssa$i;
  while(1) {
   $512 = (($257) + ($nextNode13$013$i<<2)|0);
   $nextIsland15$011$i = HEAP32[$512>>2]|0;
   $513 = ($nextIsland15$011$i|0)==(-1);
   if ($513) {
    $islandId14$0$lcssa$i = -1;
   } else {
    $nextIsland15$012$i = $nextIsland15$011$i;
    while(1) {
     $514 = (($259) + ($nextIsland15$012$i<<2)|0);
     $nextIsland15$0$i = HEAP32[$514>>2]|0;
     $515 = ($nextIsland15$0$i|0)==(-1);
     if ($515) {
      $islandId14$0$lcssa$i = $nextIsland15$012$i;
      break;
     } else {
      $nextIsland15$012$i = $nextIsland15$0$i;
     }
    }
   }
   $516 = ((($260) + (($nextNode13$013$i*12)|0)|0) + 4|0);
   HEAP32[$516>>2] = $islandId14$0$lcssa$i;
   $517 = (($255) + ($nextNode13$013$i<<2)|0);
   $518 = HEAP32[$517>>2]|0;
   $519 = ($518|0)==(-1);
   if ($519) {
    break;
   } else {
    $nextNode13$013$i = $518;
   }
  }
 }
 if ($8) {
  $520 = HEAP8[((545880 + 2|0))>>0]|0;
  $521 = (($profiler) + 8|0);
  $522 = HEAP32[$521>>2]|0;
  $inEnabled$not$i81 = ($520<<24>>24)==(0);
  $523 = ($522|0)==(0|0);
  $or$cond$i82 = $523 | $inEnabled$not$i81;
  if ($or$cond$i82) {
   $536 = $522;
  } else {
   $524 = $profiler;
   $525 = $524;
   $526 = HEAP32[$525>>2]|0;
   $527 = (($524) + 4)|0;
   $528 = $527;
   $529 = HEAP32[$528>>2]|0;
   $530 = HEAP32[$522>>2]|0;
   $531 = (($530) + 12|0);
   $532 = HEAP32[$531>>2]|0;
   $533 = HEAP16[545880>>1]|0;
   FUNCTION_TABLE_viiii[$532 & 511]($522,$533,$526,$529);
   $$pre158 = HEAP32[$521>>2]|0;
   $536 = $$pre158;
  }
  $534 = HEAP8[((545888 + 2|0))>>0]|0;
  $inEnabled$not$i78 = ($534<<24>>24)==(0);
  $535 = ($536|0)==(0|0);
  $or$cond$i79 = $535 | $inEnabled$not$i78;
  if (!($or$cond$i79)) {
   $537 = $profiler;
   $538 = $537;
   $539 = HEAP32[$538>>2]|0;
   $540 = (($537) + 4)|0;
   $541 = $540;
   $542 = HEAP32[$541>>2]|0;
   $543 = HEAP32[$536>>2]|0;
   $544 = (($543) + 8|0);
   $545 = HEAP32[$544>>2]|0;
   $546 = HEAP16[545888>>1]|0;
   FUNCTION_TABLE_viiii[$545 & 511]($536,$546,$539,$542);
  }
  $547 = HEAP32[$29>>2]|0;
  $548 = HEAP32[$72>>2]|0;
  $549 = ($numCreatedNodes|0)==(0);
  if (!($549)) {
   $i$01$i73 = 0;
   while(1) {
    $550 = (($createdNodes) + ($i$01$i73<<2)|0);
    $551 = HEAP32[$550>>2]|0;
    $552 = ((($547) + (($551*12)|0)|0) + 8|0);
    $553 = HEAP8[$552>>0]|0;
    $554 = $553&255;
    $555 = $554 & 191;
    $556 = $555&255;
    HEAP8[$552>>0] = $556;
    $557 = $553 & 32;
    $558 = ($557<<24>>24)==(0);
    if ($558) {
     $559 = ((($547) + (($551*12)|0)|0) + 4|0);
     $560 = HEAP32[$559>>2]|0;
     $561 = ($560|0)==(-1);
     if ($561) {
      $562 = HEAP32[$184>>2]|0;
      $563 = HEAP32[$185>>2]|0;
      $564 = (($563) + ($562<<2)|0);
      $565 = HEAP32[$564>>2]|0;
      HEAP32[$184>>2] = $565;
      HEAP32[$564>>2] = -1;
      $566 = HEAP32[$71>>2]|0;
      $567 = (($566) + ($562<<4)|0);
      ;HEAP32[$567+0>>2]=4294967295|0;HEAP32[$567+4>>2]=4294967295|0;HEAP32[$567+8>>2]=4294967295|0;HEAP32[$567+12>>2]=4294967295|0;
      $568 = $562 & 31;
      $569 = 1 << $568;
      $570 = $562 >>> 5;
      $571 = HEAP32[$186>>2]|0;
      $572 = (($571) + ($570<<2)|0);
      $573 = HEAP32[$572>>2]|0;
      $574 = $573 | $569;
      HEAP32[$572>>2] = $574;
      $575 = HEAP32[$71>>2]|0;
      HEAP32[$559>>2] = $562;
      $576 = (($575) + ($562<<4)|0);
      $577 = HEAP32[$576>>2]|0;
      $578 = (($548) + ($551<<2)|0);
      HEAP32[$578>>2] = $577;
      HEAP32[$576>>2] = $551;
      $579 = ((($575) + ($562<<4)|0) + 8|0);
      $580 = HEAP32[$579>>2]|0;
      $581 = ($580|0)==(-1);
      $nodeId$$i$i74 = $581 ? $551 : $580;
      HEAP32[$579>>2] = $nodeId$$i$i74;
     }
    }
    $582 = (($i$01$i73) + 1)|0;
    $exitcond$i75 = ($582|0)==($numCreatedNodes|0);
    if ($exitcond$i75) {
     break;
    } else {
     $i$01$i73 = $582;
    }
   }
  }
  $583 = HEAP8[((545888 + 2|0))>>0]|0;
  $584 = HEAP32[$521>>2]|0;
  $inEnabled$not$i69 = ($583<<24>>24)==(0);
  $585 = ($584|0)==(0|0);
  $or$cond$i70 = $585 | $inEnabled$not$i69;
  if ($or$cond$i70) {
   label = 135;
  } else {
   $586 = $profiler;
   $587 = $586;
   $588 = HEAP32[$587>>2]|0;
   $589 = (($586) + 4)|0;
   $590 = $589;
   $591 = HEAP32[$590>>2]|0;
   $592 = HEAP32[$584>>2]|0;
   $593 = (($592) + 12|0);
   $594 = HEAP32[$593>>2]|0;
   $595 = HEAP16[545888>>1]|0;
   FUNCTION_TABLE_viiii[$594 & 511]($584,$595,$588,$591);
   label = 135;
  }
 } else {
  $596 = HEAP32[$29>>2]|0;
  $597 = HEAP32[$72>>2]|0;
  $598 = ($numCreatedNodes|0)==(0);
  if ($598) {
   label = 146;
  } else {
   $i$01$i66 = 0;
   while(1) {
    $599 = (($createdNodes) + ($i$01$i66<<2)|0);
    $600 = HEAP32[$599>>2]|0;
    $601 = ((($596) + (($600*12)|0)|0) + 8|0);
    $602 = HEAP8[$601>>0]|0;
    $603 = $602&255;
    $604 = $603 & 191;
    $605 = $604&255;
    HEAP8[$601>>0] = $605;
    $606 = $602 & 32;
    $607 = ($606<<24>>24)==(0);
    if ($607) {
     $608 = ((($596) + (($600*12)|0)|0) + 4|0);
     $609 = HEAP32[$608>>2]|0;
     $610 = ($609|0)==(-1);
     if ($610) {
      $611 = HEAP32[$184>>2]|0;
      $612 = HEAP32[$185>>2]|0;
      $613 = (($612) + ($611<<2)|0);
      $614 = HEAP32[$613>>2]|0;
      HEAP32[$184>>2] = $614;
      HEAP32[$613>>2] = -1;
      $615 = HEAP32[$71>>2]|0;
      $616 = (($615) + ($611<<4)|0);
      ;HEAP32[$616+0>>2]=4294967295|0;HEAP32[$616+4>>2]=4294967295|0;HEAP32[$616+8>>2]=4294967295|0;HEAP32[$616+12>>2]=4294967295|0;
      $617 = $611 & 31;
      $618 = 1 << $617;
      $619 = $611 >>> 5;
      $620 = HEAP32[$186>>2]|0;
      $621 = (($620) + ($619<<2)|0);
      $622 = HEAP32[$621>>2]|0;
      $623 = $622 | $618;
      HEAP32[$621>>2] = $623;
      $624 = HEAP32[$71>>2]|0;
      HEAP32[$608>>2] = $611;
      $625 = (($624) + ($611<<4)|0);
      $626 = HEAP32[$625>>2]|0;
      $627 = (($597) + ($600<<2)|0);
      HEAP32[$627>>2] = $626;
      HEAP32[$625>>2] = $600;
      $628 = ((($624) + ($611<<4)|0) + 8|0);
      $629 = HEAP32[$628>>2]|0;
      $630 = ($629|0)==(-1);
      $nodeId$$i$i = $630 ? $600 : $629;
      HEAP32[$628>>2] = $nodeId$$i$i;
     }
    }
    $631 = (($i$01$i66) + 1)|0;
    $exitcond$i67 = ($631|0)==($numCreatedNodes|0);
    if ($exitcond$i67) {
     label = 135;
     break;
    } else {
     $i$01$i66 = $631;
    }
   }
  }
 }
 if ((label|0) == 135) {
  if ($8) {
   $632 = HEAP8[((545920 + 2|0))>>0]|0;
   $633 = (($profiler) + 8|0);
   $634 = HEAP32[$633>>2]|0;
   $inEnabled$not$i59 = ($632<<24>>24)==(0);
   $635 = ($634|0)==(0|0);
   $or$cond$i60 = $635 | $inEnabled$not$i59;
   if (!($or$cond$i60)) {
    $636 = $profiler;
    $637 = $636;
    $638 = HEAP32[$637>>2]|0;
    $639 = (($636) + 4)|0;
    $640 = $639;
    $641 = HEAP32[$640>>2]|0;
    $642 = HEAP32[$634>>2]|0;
    $643 = (($642) + 8|0);
    $644 = HEAP32[$643>>2]|0;
    $645 = HEAP16[545920>>1]|0;
    FUNCTION_TABLE_viiii[$644 & 511]($634,$645,$638,$641);
   }
   if (!($31)) {
    $646 = (($nodeManager) + 16|0);
    $647 = (($nodeManager) + 8|0);
    $i$01$i55 = 0;
    while(1) {
     $648 = (($deletedNodes) + ($i$01$i55<<2)|0);
     $649 = HEAP32[$648>>2]|0;
     $650 = HEAP32[$29>>2]|0;
     $651 = (($650) + (($649*12)|0)|0);
     HEAP32[$651>>2] = 0;
     $652 = ((($650) + (($649*12)|0)|0) + 4|0);
     HEAP32[$652>>2] = -1;
     $653 = ((($650) + (($649*12)|0)|0) + 8|0);
     HEAP8[$653>>0] = 0;
     $654 = HEAP32[$646>>2]|0;
     $655 = HEAP32[$647>>2]|0;
     $656 = (($655) + ($649<<2)|0);
     HEAP32[$656>>2] = $654;
     HEAP32[$646>>2] = $649;
     $657 = (($i$01$i55) + 1)|0;
     $exitcond$i56 = ($657|0)==($numDeletedNodes|0);
     if ($exitcond$i56) {
      break;
     } else {
      $i$01$i55 = $657;
     }
    }
   }
   $658 = ($numDeletedEdges|0)==(0);
   if (!($658)) {
    $659 = (($edgeManager) + 16|0);
    $660 = (($edgeManager) + 8|0);
    $i$01$i50 = 0;
    while(1) {
     $661 = (($deletedEdges) + ($i$01$i50<<2)|0);
     $662 = HEAP32[$661>>2]|0;
     $663 = HEAP32[$261>>2]|0;
     $664 = (($663) + (($662*12)|0)|0);
     HEAP32[$664>>2] = -1;
     $665 = ((($663) + (($662*12)|0)|0) + 4|0);
     HEAP32[$665>>2] = -1;
     $666 = ((($663) + (($662*12)|0)|0) + 8|0);
     HEAP32[$666>>2] = 0;
     $667 = HEAP32[$659>>2]|0;
     $668 = HEAP32[$660>>2]|0;
     $669 = (($668) + ($662<<2)|0);
     HEAP32[$669>>2] = $667;
     HEAP32[$659>>2] = $662;
     $670 = (($i$01$i50) + 1)|0;
     $exitcond$i51 = ($670|0)==($numDeletedEdges|0);
     if ($exitcond$i51) {
      break;
     } else {
      $i$01$i50 = $670;
     }
    }
   }
   $671 = HEAP8[((545920 + 2|0))>>0]|0;
   $672 = HEAP32[$633>>2]|0;
   $inEnabled$not$i46 = ($671<<24>>24)==(0);
   $673 = ($672|0)==(0|0);
   $or$cond$i47 = $673 | $inEnabled$not$i46;
   if (!($or$cond$i47)) {
    $674 = $profiler;
    $675 = $674;
    $676 = HEAP32[$675>>2]|0;
    $677 = (($674) + 4)|0;
    $678 = $677;
    $679 = HEAP32[$678>>2]|0;
    $680 = HEAP32[$672>>2]|0;
    $681 = (($680) + 12|0);
    $682 = HEAP32[$681>>2]|0;
    $683 = HEAP16[545920>>1]|0;
    FUNCTION_TABLE_viiii[$682 & 511]($672,$683,$676,$679);
   }
  } else {
   label = 146;
  }
 }
 if ((label|0) == 146) {
  if (!($31)) {
   $684 = (($nodeManager) + 16|0);
   $685 = (($nodeManager) + 8|0);
   $i$01$i43 = 0;
   while(1) {
    $686 = (($deletedNodes) + ($i$01$i43<<2)|0);
    $687 = HEAP32[$686>>2]|0;
    $688 = HEAP32[$29>>2]|0;
    $689 = (($688) + (($687*12)|0)|0);
    HEAP32[$689>>2] = 0;
    $690 = ((($688) + (($687*12)|0)|0) + 4|0);
    HEAP32[$690>>2] = -1;
    $691 = ((($688) + (($687*12)|0)|0) + 8|0);
    HEAP8[$691>>0] = 0;
    $692 = HEAP32[$684>>2]|0;
    $693 = HEAP32[$685>>2]|0;
    $694 = (($693) + ($687<<2)|0);
    HEAP32[$694>>2] = $692;
    HEAP32[$684>>2] = $687;
    $695 = (($i$01$i43) + 1)|0;
    $exitcond$i44 = ($695|0)==($numDeletedNodes|0);
    if ($exitcond$i44) {
     break;
    } else {
     $i$01$i43 = $695;
    }
   }
  }
  $696 = ($numDeletedEdges|0)==(0);
  if (!($696)) {
   $697 = (($edgeManager) + 16|0);
   $698 = (($edgeManager) + 8|0);
   $i$01$i = 0;
   while(1) {
    $699 = (($deletedEdges) + ($i$01$i<<2)|0);
    $700 = HEAP32[$699>>2]|0;
    $701 = HEAP32[$261>>2]|0;
    $702 = (($701) + (($700*12)|0)|0);
    HEAP32[$702>>2] = -1;
    $703 = ((($701) + (($700*12)|0)|0) + 4|0);
    HEAP32[$703>>2] = -1;
    $704 = ((($701) + (($700*12)|0)|0) + 8|0);
    HEAP32[$704>>2] = 0;
    $705 = HEAP32[$697>>2]|0;
    $706 = HEAP32[$698>>2]|0;
    $707 = (($706) + ($700<<2)|0);
    HEAP32[$707>>2] = $705;
    HEAP32[$697>>2] = $700;
    $708 = (($i$01$i) + 1)|0;
    $exitcond$i40 = ($708|0)==($numDeletedEdges|0);
    if ($exitcond$i40) {
     break;
    } else {
     $i$01$i = $708;
    }
   }
  }
 }
 $709 = ($numAddedKinematics|0)==(0);
 do {
  if ($709) {
   label = 159;
  } else {
   if (!($8)) {
    $740 = HEAP32[$workBuffers>>2]|0;
    $741 = (($workBuffers) + 4|0);
    $742 = HEAP32[$741>>2]|0;
    __ZL23duplicateKinematicNodesRKN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEEERNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerEPjSD_RS4_($kinematicNodesBitmap,$nodeManager,$edgeManager,$islands,$740,$742,$3);
    label = 164;
    break;
   }
   $710 = HEAP8[((545896 + 2|0))>>0]|0;
   $711 = (($profiler) + 8|0);
   $712 = HEAP32[$711>>2]|0;
   $inEnabled$not$i36 = ($710<<24>>24)==(0);
   $713 = ($712|0)==(0|0);
   $or$cond$i37 = $713 | $inEnabled$not$i36;
   if (!($or$cond$i37)) {
    $714 = $profiler;
    $715 = $714;
    $716 = HEAP32[$715>>2]|0;
    $717 = (($714) + 4)|0;
    $718 = $717;
    $719 = HEAP32[$718>>2]|0;
    $720 = HEAP32[$712>>2]|0;
    $721 = (($720) + 8|0);
    $722 = HEAP32[$721>>2]|0;
    $723 = HEAP16[545896>>1]|0;
    FUNCTION_TABLE_viiii[$722 & 511]($712,$723,$716,$719);
   }
   $724 = HEAP32[$workBuffers>>2]|0;
   $725 = (($workBuffers) + 4|0);
   $726 = HEAP32[$725>>2]|0;
   __ZL23duplicateKinematicNodesRKN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEEERNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerEPjSD_RS4_($kinematicNodesBitmap,$nodeManager,$edgeManager,$islands,$724,$726,$3);
   $727 = HEAP8[((545896 + 2|0))>>0]|0;
   $728 = HEAP32[$711>>2]|0;
   $inEnabled$not$i33 = ($727<<24>>24)==(0);
   $729 = ($728|0)==(0|0);
   $or$cond$i34 = $729 | $inEnabled$not$i33;
   if ($or$cond$i34) {
    label = 159;
   } else {
    $730 = $profiler;
    $731 = $730;
    $732 = HEAP32[$731>>2]|0;
    $733 = (($730) + 4)|0;
    $734 = $733;
    $735 = HEAP32[$734>>2]|0;
    $736 = HEAP32[$728>>2]|0;
    $737 = (($736) + 12|0);
    $738 = HEAP32[$737>>2]|0;
    $739 = HEAP16[545896>>1]|0;
    FUNCTION_TABLE_viiii[$738 & 511]($728,$739,$732,$735);
    label = 159;
   }
  }
 } while(0);
 if ((label|0) == 159) {
  if ($8) {
   $743 = HEAP8[((545904 + 2|0))>>0]|0;
   $744 = (($profiler) + 8|0);
   $745 = HEAP32[$744>>2]|0;
   $inEnabled$not$i23 = ($743<<24>>24)==(0);
   $746 = ($745|0)==(0|0);
   $or$cond$i24 = $746 | $inEnabled$not$i23;
   if (!($or$cond$i24)) {
    $747 = $profiler;
    $748 = $747;
    $749 = HEAP32[$748>>2]|0;
    $750 = (($747) + 4)|0;
    $751 = $750;
    $752 = HEAP32[$751>>2]|0;
    $753 = HEAP32[$745>>2]|0;
    $754 = (($753) + 8|0);
    $755 = HEAP32[$754>>2]|0;
    $756 = HEAP16[545904>>1]|0;
    FUNCTION_TABLE_viiii[$755 & 511]($745,$756,$749,$752);
   }
   $757 = HEAP32[$254>>2]|0;
   $758 = HEAP32[$256>>2]|0;
   $759 = HEAP32[$258>>2]|0;
   __ZL24processBrokenEdgeIslandsRKN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEEERNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerEPjSD_SD_PS4_($3,$nodeManager,$edgeManager,$islands,$757,$758,$759,0);
   $760 = HEAP8[((545904 + 2|0))>>0]|0;
   $761 = HEAP32[$744>>2]|0;
   $inEnabled$not$i20 = ($760<<24>>24)==(0);
   $762 = ($761|0)==(0|0);
   $or$cond$i21 = $762 | $inEnabled$not$i20;
   if (!($or$cond$i21)) {
    $763 = $profiler;
    $764 = $763;
    $765 = HEAP32[$764>>2]|0;
    $766 = (($763) + 4)|0;
    $767 = $766;
    $768 = HEAP32[$767>>2]|0;
    $769 = HEAP32[$761>>2]|0;
    $770 = (($769) + 12|0);
    $771 = HEAP32[$770>>2]|0;
    $772 = HEAP16[545904>>1]|0;
    FUNCTION_TABLE_viiii[$771 & 511]($761,$772,$765,$768);
   }
  } else {
   label = 164;
  }
 }
 if ((label|0) == 164) {
  $773 = HEAP32[$254>>2]|0;
  $774 = HEAP32[$256>>2]|0;
  $775 = HEAP32[$258>>2]|0;
  __ZL24processBrokenEdgeIslandsRKN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEEERNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerEPjSD_SD_PS4_($3,$nodeManager,$edgeManager,$islands,$773,$774,$775,0);
 }
 if (!($8)) {
  __ZL22processSleepingIslandsILb0EEvRKN5physx2Cm10BitMapBaseINS0_6shdfnd9AllocatorEEEjRNS0_11NodeManagerERNS0_11EdgeManagerERNS0_13IslandManagerERNS0_23ArticulationRootManagerERNS0_33ProcessSleepingIslandsComputeDataE($186,$rigidBodyOffset,$nodeManager,$edgeManager,$islands,$articulationRootManager,$psicData);
  STACKTOP = sp;return;
 }
 $776 = HEAP8[((545912 + 2|0))>>0]|0;
 $777 = (($profiler) + 8|0);
 $778 = HEAP32[$777>>2]|0;
 $inEnabled$not$i15 = ($776<<24>>24)==(0);
 $779 = ($778|0)==(0|0);
 $or$cond$i16 = $779 | $inEnabled$not$i15;
 if (!($or$cond$i16)) {
  $780 = $profiler;
  $781 = $780;
  $782 = HEAP32[$781>>2]|0;
  $783 = (($780) + 4)|0;
  $784 = $783;
  $785 = HEAP32[$784>>2]|0;
  $786 = HEAP32[$778>>2]|0;
  $787 = (($786) + 8|0);
  $788 = HEAP32[$787>>2]|0;
  $789 = HEAP16[545912>>1]|0;
  FUNCTION_TABLE_viiii[$788 & 511]($778,$789,$782,$785);
 }
 __ZL22processSleepingIslandsILb0EEvRKN5physx2Cm10BitMapBaseINS0_6shdfnd9AllocatorEEEjRNS0_11NodeManagerERNS0_11EdgeManagerERNS0_13IslandManagerERNS0_23ArticulationRootManagerERNS0_33ProcessSleepingIslandsComputeDataE($186,$rigidBodyOffset,$nodeManager,$edgeManager,$islands,$articulationRootManager,$psicData);
 $790 = HEAP8[((545912 + 2|0))>>0]|0;
 $791 = HEAP32[$777>>2]|0;
 $inEnabled$not$i = ($790<<24>>24)==(0);
 $792 = ($791|0)==(0|0);
 $or$cond$i = $792 | $inEnabled$not$i;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 }
 $793 = $profiler;
 $794 = $793;
 $795 = HEAP32[$794>>2]|0;
 $796 = (($793) + 4)|0;
 $797 = $796;
 $798 = HEAP32[$797>>2]|0;
 $799 = HEAP32[$791>>2]|0;
 $800 = (($799) + 12|0);
 $801 = HEAP32[$800>>2]|0;
 $802 = HEAP16[545912>>1]|0;
 FUNCTION_TABLE_viiii[$801 & 511]($791,$802,$795,$798);
 STACKTOP = sp;return;
}
function __ZL28removeBrokenEdgesFromIslandsPKjjS0_jS0_RN5physx11NodeManagerERNS1_11EdgeManagerERNS1_13IslandManagerERNS1_2Cm10BitMapBaseINS1_6shdfnd9AllocatorEEE($brokenEdgeIds,$numBrokenEdges,$deletedEdgeIds,$numDeletedEdges,$kinematicProxySourceNodes,$nodeManager,$edgeManager,$islands,$brokenEdgeIslandsBitmap) {
 $brokenEdgeIds = $brokenEdgeIds|0;
 $numBrokenEdges = $numBrokenEdges|0;
 $deletedEdgeIds = $deletedEdgeIds|0;
 $numDeletedEdges = $numDeletedEdges|0;
 $kinematicProxySourceNodes = $kinematicProxySourceNodes|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $brokenEdgeIslandsBitmap = $brokenEdgeIslandsBitmap|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $b$035 = 0, $endEdge$0$lcssa$i = 0, $endEdge$0$lcssa$i13 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i14 = 0, $exitcond65 = 0, $exitcond66 = 0, $exitcond67 = 0, $i$0$i = 0, $i$044 = 0, $i$044$us = 0, $i$09$i = 0, $i$09$i2 = 0, $i1$041 = 0, $islandsToUpdate = 0, $nextEdge$02$i = 0, $nextEdge$02$i3 = 0;
 var $nextEdge1$03$i = 0, $nextEdge1$03$i9 = 0, $numIslandsToUpdate$036 = 0, $numIslandsToUpdate$1$lcssa = 0, $numIslandsToUpdate$134 = 0, $numIslandsToUpdate$2 = 0, $phitmp = 0, $phitmp69 = 0, $undeletedEdge$06$i = 0, $undeletedEdge$06$i7 = 0, $w$037 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4096|0;
 $islandsToUpdate = sp;
 $0 = (($nodeManager) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($edgeManager) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($numBrokenEdges|0)==(0);
 L1: do {
  if (!($4)) {
   $5 = ($kinematicProxySourceNodes|0)==(0|0);
   if ($5) {
    $i$044$us = 0;
    while(1) {
     $6 = (($brokenEdgeIds) + ($i$044$us<<2)|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = (($3) + (($7*12)|0)|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ((($3) + (($7*12)|0)|0) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($9|0)==(-1);
     if (!($12)) {
      $13 = ((($1) + (($9*12)|0)|0) + 4|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = ($14|0)==(-1);
      if (!($15)) {
       $16 = $14 & 31;
       $17 = 1 << $16;
       $18 = $14 >>> 5;
       $19 = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
       $20 = (($19) + ($18<<2)|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = $21 | $17;
       HEAP32[$20>>2] = $22;
      }
     }
     $23 = ($11|0)==(-1);
     if (!($23)) {
      $24 = ((($1) + (($11*12)|0)|0) + 4|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25|0)==(-1);
      if (!($26)) {
       $27 = $25 & 31;
       $28 = 1 << $27;
       $29 = $25 >>> 5;
       $30 = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
       $31 = (($30) + ($29<<2)|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = $32 | $28;
       HEAP32[$31>>2] = $33;
      }
     }
     $34 = (($i$044$us) + 1)|0;
     $exitcond67 = ($34|0)==($numBrokenEdges|0);
     if ($exitcond67) {
      break L1;
     } else {
      $i$044$us = $34;
     }
    }
   } else {
    $i$044 = 0;
   }
   while(1) {
    $36 = (($brokenEdgeIds) + ($i$044<<2)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($3) + (($37*12)|0)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ((($3) + (($37*12)|0)|0) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($39|0)==(-1);
    if (!($42)) {
     $43 = ((($1) + (($39*12)|0)|0) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==(-1);
     if (!($45)) {
      $46 = $44 & 31;
      $47 = 1 << $46;
      $48 = $44 >>> 5;
      $49 = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
      $50 = (($49) + ($48<<2)|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = $51 | $47;
      HEAP32[$50>>2] = $52;
     }
     $53 = ((($1) + (($39*12)|0)|0) + 8|0);
     $54 = HEAP8[$53>>0]|0;
     $55 = $54 & 1;
     $56 = ($55<<24>>24)==(0);
     if (!($56)) {
      $57 = (($kinematicProxySourceNodes) + ($39<<2)|0);
      $58 = HEAP32[$57>>2]|0;
      HEAP32[$38>>2] = $58;
     }
    }
    $59 = ($41|0)==(-1);
    if (!($59)) {
     $60 = ((($1) + (($41*12)|0)|0) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(-1);
     if (!($62)) {
      $63 = $61 & 31;
      $64 = 1 << $63;
      $65 = $61 >>> 5;
      $66 = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
      $67 = (($66) + ($65<<2)|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = $68 | $64;
      HEAP32[$67>>2] = $69;
     }
     $70 = ((($1) + (($41*12)|0)|0) + 8|0);
     $71 = HEAP8[$70>>0]|0;
     $72 = $71 & 1;
     $73 = ($72<<24>>24)==(0);
     if (!($73)) {
      $74 = (($kinematicProxySourceNodes) + ($41<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      HEAP32[$40>>2] = $75;
     }
    }
    $76 = (($i$044) + 1)|0;
    $exitcond66 = ($76|0)==($numBrokenEdges|0);
    if ($exitcond66) {
     break;
    } else {
     $i$044 = $76;
    }
   }
  }
 } while(0);
 $35 = ($numDeletedEdges|0)==(0);
 if (!($35)) {
  $i1$041 = 0;
  while(1) {
   $77 = (($deletedEdgeIds) + ($i1$041<<2)|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ((($3) + (($78*12)|0)|0) + 8|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = $80;
   $82 = $81 & 4;
   $83 = ($82|0)==(0);
   if (!($83)) {
    $84 = $81 & -5;
    $85 = $84;
    HEAP32[$79>>2] = $85;
    $86 = (($3) + (($78*12)|0)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ((($3) + (($78*12)|0)|0) + 4|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ($87|0)==(-1);
    if (!($90)) {
     $91 = ((($1) + (($87*12)|0)|0) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($92|0)==(-1);
     if (!($93)) {
      $94 = $92 & 31;
      $95 = 1 << $94;
      $96 = $92 >>> 5;
      $97 = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
      $98 = (($97) + ($96<<2)|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = $99 | $95;
      HEAP32[$98>>2] = $100;
     }
    }
    $101 = ($89|0)==(-1);
    if (!($101)) {
     $102 = ((($1) + (($89*12)|0)|0) + 4|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ($103|0)==(-1);
     if (!($104)) {
      $105 = $103 & 31;
      $106 = 1 << $105;
      $107 = $103 >>> 5;
      $108 = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
      $109 = (($108) + ($107<<2)|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = $110 | $106;
      HEAP32[$109>>2] = $111;
     }
    }
   }
   $112 = (($i1$041) + 1)|0;
   $exitcond65 = ($112|0)==($numDeletedEdges|0);
   if ($exitcond65) {
    break;
   } else {
    $i1$041 = $112;
   }
  }
 }
 $113 = (($brokenEdgeIslandsBitmap) + 4|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = $114 & 2147483647;
 $i$0$i = $115;
 while(1) {
  $116 = (($i$0$i) + -1)|0;
  $117 = ($i$0$i|0)==(0);
  $$pre = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
  if ($117) {
   $$0$i = 1;
   break;
  }
  $118 = (($$pre) + ($116<<2)|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = ($119|0)==(0);
  if ($120) {
   $i$0$i = $116;
  } else {
   label = 33;
   break;
  }
 }
 if ((label|0) == 33) {
  $121 = $116 << 5;
  $122 = $119 >>> 1;
  $123 = $122 | $119;
  $124 = $123 >>> 2;
  $125 = $124 | $123;
  $126 = $125 >>> 4;
  $127 = $126 | $125;
  $128 = $127 >>> 8;
  $129 = $128 | $127;
  $130 = $129 >>> 16;
  $131 = $130 | $129;
  $132 = Math_imul($131, 130329821)|0;
  $133 = $132 >>> 27;
  $134 = (482344 + ($133<<2)|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + ($121))|0;
  $phitmp = $136 >>> 5;
  $phitmp69 = (($phitmp) + 1)|0;
  $$0$i = $phitmp69;
 }
 $137 = (($edgeManager) + 20|0);
 $138 = (($islands) + 4|0);
 $numIslandsToUpdate$036 = 0;$w$037 = 0;
 while(1) {
  $139 = (($$pre) + ($w$037<<2)|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = ($140|0)==(0);
  if ($141) {
   $numIslandsToUpdate$1$lcssa = $numIslandsToUpdate$036;
  } else {
   $142 = $w$037 << 5;
   $b$035 = $140;$numIslandsToUpdate$134 = $numIslandsToUpdate$036;
   while(1) {
    $143 = (0 - ($b$035))|0;
    $144 = $b$035 & $143;
    $145 = Math_imul($144, 125613361)|0;
    $146 = $145 >>> 27;
    $147 = (412480 + ($146<<2)|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = $148 | $142;
    $150 = ($numIslandsToUpdate$134>>>0)<(1024);
    if ($150) {
     $151 = (($islandsToUpdate) + ($numIslandsToUpdate$134<<2)|0);
     HEAP32[$151>>2] = $149;
     $152 = (($numIslandsToUpdate$134) + 1)|0;
     $numIslandsToUpdate$2 = $152;
    } else {
     $153 = HEAP32[$2>>2]|0;
     $154 = HEAP32[$137>>2]|0;
     $155 = HEAP32[$138>>2]|0;
     $i$09$i2 = 0;
     while(1) {
      $156 = (($islandsToUpdate) + ($i$09$i2<<2)|0);
      $157 = HEAP32[$156>>2]|0;
      $158 = ((($155) + ($157<<4)|0) + 4|0);
      $159 = HEAP32[$158>>2]|0;
      $160 = ($159|0)==(-1);
      L61: do {
       if ($160) {
        label = 43;
       } else {
        $nextEdge$02$i3 = $159;
        while(1) {
         $161 = ((($153) + (($nextEdge$02$i3*12)|0)|0) + 8|0);
         $162 = HEAP32[$161>>2]|0;
         $163 = $162;
         $164 = $163 & 4;
         $165 = ($164|0)==(0);
         if (!($165)) {
          break;
         }
         $166 = (($154) + ($nextEdge$02$i3<<2)|0);
         $167 = HEAP32[$166>>2]|0;
         HEAP32[$166>>2] = -1;
         $168 = ($167|0)==(-1);
         if ($168) {
          label = 43;
          break L61;
         } else {
          $nextEdge$02$i3 = $167;
         }
        }
        HEAP32[$158>>2] = $nextEdge$02$i3;
        $169 = ($nextEdge$02$i3|0)==(-1);
        if ($169) {
         $endEdge$0$lcssa$i13 = -1;
        } else {
         $undeletedEdge$06$i7 = $nextEdge$02$i3;
         L66: while(1) {
          $170 = (($154) + ($undeletedEdge$06$i7<<2)|0);
          $171 = HEAP32[$170>>2]|0;
          $172 = ($171|0)==(-1);
          if ($172) {
           break;
          } else {
           $nextEdge1$03$i9 = $171;
          }
          while(1) {
           $173 = ((($153) + (($nextEdge1$03$i9*12)|0)|0) + 8|0);
           $174 = HEAP32[$173>>2]|0;
           $175 = $174;
           $176 = $175 & 4;
           $177 = ($176|0)==(0);
           if (!($177)) {
            break;
           }
           $178 = (($154) + ($nextEdge1$03$i9<<2)|0);
           $179 = HEAP32[$178>>2]|0;
           HEAP32[$178>>2] = -1;
           $180 = ($179|0)==(-1);
           if ($180) {
            break L66;
           } else {
            $nextEdge1$03$i9 = $179;
           }
          }
          HEAP32[$170>>2] = $nextEdge1$03$i9;
          $181 = ($nextEdge1$03$i9|0)==(-1);
          if ($181) {
           $endEdge$0$lcssa$i13 = $undeletedEdge$06$i7;
           break L61;
          } else {
           $undeletedEdge$06$i7 = $nextEdge1$03$i9;
          }
         }
         HEAP32[$170>>2] = -1;
         $endEdge$0$lcssa$i13 = $undeletedEdge$06$i7;
        }
       }
      } while(0);
      if ((label|0) == 43) {
       label = 0;
       HEAP32[$158>>2] = -1;
       $endEdge$0$lcssa$i13 = -1;
      }
      $182 = ((($155) + ($157<<4)|0) + 12|0);
      HEAP32[$182>>2] = $endEdge$0$lcssa$i13;
      $183 = (($i$09$i2) + 1)|0;
      $exitcond$i14 = ($183|0)==($numIslandsToUpdate$134|0);
      if ($exitcond$i14) {
       break;
      } else {
       $i$09$i2 = $183;
      }
     }
     HEAP32[$islandsToUpdate>>2] = $149;
     $numIslandsToUpdate$2 = 1;
    }
    $184 = (($b$035) + -1)|0;
    $185 = $184 & $b$035;
    $186 = ($185|0)==(0);
    if ($186) {
     $numIslandsToUpdate$1$lcssa = $numIslandsToUpdate$2;
     break;
    } else {
     $b$035 = $185;$numIslandsToUpdate$134 = $numIslandsToUpdate$2;
    }
   }
  }
  $187 = (($w$037) + 1)|0;
  $exitcond = ($187|0)==($$0$i|0);
  if ($exitcond) {
   break;
  } else {
   $numIslandsToUpdate$036 = $numIslandsToUpdate$1$lcssa;$w$037 = $187;
  }
 }
 $188 = HEAP32[$2>>2]|0;
 $189 = HEAP32[$137>>2]|0;
 $190 = ($numIslandsToUpdate$1$lcssa|0)==(0);
 if ($190) {
  STACKTOP = sp;return;
 }
 $191 = HEAP32[$138>>2]|0;
 $i$09$i = 0;
 while(1) {
  $192 = (($islandsToUpdate) + ($i$09$i<<2)|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = ((($191) + ($193<<4)|0) + 4|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = ($195|0)==(-1);
  L85: do {
   if ($196) {
    label = 59;
   } else {
    $nextEdge$02$i = $195;
    while(1) {
     $197 = ((($188) + (($nextEdge$02$i*12)|0)|0) + 8|0);
     $198 = HEAP32[$197>>2]|0;
     $199 = $198;
     $200 = $199 & 4;
     $201 = ($200|0)==(0);
     if (!($201)) {
      break;
     }
     $202 = (($189) + ($nextEdge$02$i<<2)|0);
     $203 = HEAP32[$202>>2]|0;
     HEAP32[$202>>2] = -1;
     $204 = ($203|0)==(-1);
     if ($204) {
      label = 59;
      break L85;
     } else {
      $nextEdge$02$i = $203;
     }
    }
    HEAP32[$194>>2] = $nextEdge$02$i;
    $205 = ($nextEdge$02$i|0)==(-1);
    if ($205) {
     $endEdge$0$lcssa$i = -1;
    } else {
     $undeletedEdge$06$i = $nextEdge$02$i;
     L90: while(1) {
      $206 = (($189) + ($undeletedEdge$06$i<<2)|0);
      $207 = HEAP32[$206>>2]|0;
      $208 = ($207|0)==(-1);
      if ($208) {
       break;
      } else {
       $nextEdge1$03$i = $207;
      }
      while(1) {
       $209 = ((($188) + (($nextEdge1$03$i*12)|0)|0) + 8|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = $210;
       $212 = $211 & 4;
       $213 = ($212|0)==(0);
       if (!($213)) {
        break;
       }
       $214 = (($189) + ($nextEdge1$03$i<<2)|0);
       $215 = HEAP32[$214>>2]|0;
       HEAP32[$214>>2] = -1;
       $216 = ($215|0)==(-1);
       if ($216) {
        break L90;
       } else {
        $nextEdge1$03$i = $215;
       }
      }
      HEAP32[$206>>2] = $nextEdge1$03$i;
      $217 = ($nextEdge1$03$i|0)==(-1);
      if ($217) {
       $endEdge$0$lcssa$i = $undeletedEdge$06$i;
       break L85;
      } else {
       $undeletedEdge$06$i = $nextEdge1$03$i;
      }
     }
     HEAP32[$206>>2] = -1;
     $endEdge$0$lcssa$i = $undeletedEdge$06$i;
    }
   }
  } while(0);
  if ((label|0) == 59) {
   label = 0;
   HEAP32[$194>>2] = -1;
   $endEdge$0$lcssa$i = -1;
  }
  $218 = ((($191) + ($193<<4)|0) + 12|0);
  HEAP32[$218>>2] = $endEdge$0$lcssa$i;
  $219 = (($i$09$i) + 1)|0;
  $exitcond$i = ($219|0)==($numIslandsToUpdate$1$lcssa|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$09$i = $219;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23duplicateKinematicNodesRKN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEEERNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerEPjSD_RS4_($kinematicNodesBitmap,$nodeManager,$edgeManager,$islands,$kinematicProxySourceNodes,$kinematicProxyNextNodes,$kinematicIslandsBitmap) {
 $kinematicNodesBitmap = $kinematicNodesBitmap|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $kinematicProxySourceNodes = $kinematicProxySourceNodes|0;
 $kinematicProxyNextNodes = $kinematicProxyNextNodes|0;
 $kinematicIslandsBitmap = $kinematicIslandsBitmap|0;
 var $$0$i = 0, $$0$i5 = 0, $$0$i8 = 0, $$pn1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$036 = 0, $b12$012 = 0, $b3$028 = 0, $endNode$0$lcssa$i = 0, $exitcond = 0, $exitcond53 = 0, $exitcond57 = 0, $i$0$i = 0, $i$0$i4 = 0;
 var $i$0$i7 = 0, $mapLast6$0 = 0, $mapNext$0 = 0, $mapNext$0$in = 0, $mapNext7$0 = 0, $mapNext7$0$in = 0, $nextEdge$0 = 0, $nextEdge$024 = 0, $nextEdge$025 = 0, $nextNode$06$i = 0, $nextNode1$02$i = 0, $nodeId$$i = 0, $nodeId$$i2 = 0, $nodeId$$i3 = 0, $phitmp = 0, $phitmp10 = 0, $phitmp11 = 0, $phitmp63 = 0, $phitmp64 = 0, $phitmp65 = 0;
 var $undeletedNode$03$i = 0, $w$040 = 0, $w11$013 = 0, $w2$032 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($nodeManager) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($nodeManager) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($nodeManager) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($edgeManager) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($edgeManager) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $3 << 2;
 _memset(($kinematicProxySourceNodes|0),-1,($10|0))|0;
 _memset(($kinematicProxyNextNodes|0),-1,($10|0))|0;
 $11 = HEAP32[$kinematicNodesBitmap>>2]|0;
 $12 = (($kinematicNodesBitmap) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $i$0$i7 = $14;
 while(1) {
  $15 = (($i$0$i7) + -1)|0;
  $16 = ($i$0$i7|0)==(0);
  if ($16) {
   $$0$i8 = 1;
   break;
  }
  $17 = (($11) + ($15<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  if ($19) {
   $i$0$i7 = $15;
  } else {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $20 = $15 << 5;
  $21 = $18 >>> 1;
  $22 = $21 | $18;
  $23 = $22 >>> 2;
  $24 = $23 | $22;
  $25 = $24 >>> 4;
  $26 = $25 | $24;
  $27 = $26 >>> 8;
  $28 = $27 | $26;
  $29 = $28 >>> 16;
  $30 = $29 | $28;
  $31 = Math_imul($30, 130329821)|0;
  $32 = $31 >>> 27;
  $33 = (482344 + ($32<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($20))|0;
  $phitmp = $35 >>> 5;
  $phitmp63 = (($phitmp) + 1)|0;
  $$0$i8 = $phitmp63;
 }
 $w$040 = 0;
 while(1) {
  $36 = (($11) + ($w$040<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0);
  if (!($38)) {
   $39 = $w$040 << 5;
   $b$036 = $37;
   while(1) {
    $40 = (0 - ($b$036))|0;
    $41 = $b$036 & $40;
    $42 = Math_imul($41, 125613361)|0;
    $43 = $42 >>> 27;
    $44 = (412480 + ($43<<2)|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = $45 | $39;
    $47 = ((($1) + (($46*12)|0)|0) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = $48 & 31;
    $50 = 1 << $49;
    $51 = $48 >>> 5;
    $52 = HEAP32[$kinematicIslandsBitmap>>2]|0;
    $53 = (($52) + ($51<<2)|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = $54 | $50;
    HEAP32[$53>>2] = $55;
    $56 = ((($1) + (($46*12)|0)|0) + 8|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = $57&255;
    $59 = $58 | 32;
    $60 = $59&255;
    HEAP8[$56>>0] = $60;
    $61 = (($b$036) + -1)|0;
    $62 = $61 & $b$036;
    $63 = ($62|0)==(0);
    if ($63) {
     break;
    } else {
     $b$036 = $62;
    }
   }
  }
  $64 = (($w$040) + 1)|0;
  $exitcond57 = ($64|0)==($$0$i8|0);
  if ($exitcond57) {
   break;
  } else {
   $w$040 = $64;
  }
 }
 $65 = (($kinematicIslandsBitmap) + 4|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 & 2147483647;
 $i$0$i4 = $67;
 while(1) {
  $68 = (($i$0$i4) + -1)|0;
  $69 = ($i$0$i4|0)==(0);
  if ($69) {
   $$0$i5 = 1;
   break;
  }
  $70 = HEAP32[$kinematicIslandsBitmap>>2]|0;
  $71 = (($70) + ($68<<2)|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0);
  if ($73) {
   $i$0$i4 = $68;
  } else {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  $74 = $68 << 5;
  $75 = $72 >>> 1;
  $76 = $75 | $72;
  $77 = $76 >>> 2;
  $78 = $77 | $76;
  $79 = $78 >>> 4;
  $80 = $79 | $78;
  $81 = $80 >>> 8;
  $82 = $81 | $80;
  $83 = $82 >>> 16;
  $84 = $83 | $82;
  $85 = Math_imul($84, 130329821)|0;
  $86 = $85 >>> 27;
  $87 = (482344 + ($86<<2)|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + ($74))|0;
  $phitmp10 = $89 >>> 5;
  $phitmp64 = (($phitmp10) + 1)|0;
  $$0$i5 = $phitmp64;
 }
 $90 = (($islands) + 4|0);
 $91 = (($nodeManager) + 16|0);
 $92 = (($nodeManager) + 8|0);
 $w2$032 = 0;
 while(1) {
  $93 = HEAP32[$kinematicIslandsBitmap>>2]|0;
  $94 = (($93) + ($w2$032<<2)|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ($95|0)==(0);
  if (!($96)) {
   $97 = $w2$032 << 5;
   $$pre = HEAP32[$90>>2]|0;
   $108 = $$pre;$b3$028 = $95;
   while(1) {
    $98 = (0 - ($b3$028))|0;
    $99 = $b3$028 & $98;
    $100 = Math_imul($99, 125613361)|0;
    $101 = $100 >>> 27;
    $102 = (412480 + ($101<<2)|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = $103 | $97;
    $105 = HEAP32[$0>>2]|0;
    $106 = HEAP32[$4>>2]|0;
    $107 = (($108) + ($104<<4)|0);
    $109 = HEAP32[$107>>2]|0;
    $110 = ($109|0)==(-1);
    L27: do {
     if ($110) {
      label = 20;
     } else {
      $nextNode$06$i = $109;
      while(1) {
       $111 = ((($105) + (($nextNode$06$i*12)|0)|0) + 8|0);
       $112 = HEAP8[$111>>0]|0;
       $113 = $112 & 32;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        break;
       }
       $115 = (($106) + ($nextNode$06$i<<2)|0);
       $116 = HEAP32[$115>>2]|0;
       HEAP32[$115>>2] = -1;
       $117 = ($116|0)==(-1);
       if ($117) {
        label = 20;
        break L27;
       } else {
        $nextNode$06$i = $116;
       }
      }
      HEAP32[$107>>2] = $nextNode$06$i;
      $undeletedNode$03$i = $nextNode$06$i;
      L32: while(1) {
       $118 = (($106) + ($undeletedNode$03$i<<2)|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==(-1);
       if ($120) {
        break;
       } else {
        $nextNode1$02$i = $119;
       }
       while(1) {
        $121 = ((($105) + (($nextNode1$02$i*12)|0)|0) + 8|0);
        $122 = HEAP8[$121>>0]|0;
        $123 = $122 & 32;
        $124 = ($123<<24>>24)==(0);
        if ($124) {
         break;
        }
        $125 = (($106) + ($nextNode1$02$i<<2)|0);
        $126 = HEAP32[$125>>2]|0;
        HEAP32[$125>>2] = -1;
        $127 = ($126|0)==(-1);
        if ($127) {
         break L32;
        } else {
         $nextNode1$02$i = $126;
        }
       }
       HEAP32[$118>>2] = $nextNode1$02$i;
       $128 = ($nextNode1$02$i|0)==(-1);
       if ($128) {
        $endNode$0$lcssa$i = $undeletedNode$03$i;
        break L27;
       } else {
        $undeletedNode$03$i = $nextNode1$02$i;
       }
      }
      HEAP32[$118>>2] = -1;
      $endNode$0$lcssa$i = $undeletedNode$03$i;
     }
    } while(0);
    if ((label|0) == 20) {
     label = 0;
     HEAP32[$107>>2] = -1;
     $endNode$0$lcssa$i = -1;
    }
    $129 = ((($108) + ($104<<4)|0) + 8|0);
    HEAP32[$129>>2] = $endNode$0$lcssa$i;
    $130 = ((($108) + ($104<<4)|0) + 4|0);
    $nextEdge$024 = HEAP32[$130>>2]|0;
    $131 = ($nextEdge$024|0)==(-1);
    if ($131) {
     $262 = $108;
    } else {
     $263 = $108;$nextEdge$025 = $nextEdge$024;
     while(1) {
      $132 = (($7) + (($nextEdge$025*12)|0)|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = ($133|0)==(-1);
      if ($134) {
       $264 = $263;
      } else {
       $135 = ((($1) + (($133*12)|0)|0) + 8|0);
       $136 = HEAP8[$135>>0]|0;
       $137 = $136 & 1;
       $138 = ($137<<24>>24)==(0);
       if ($138) {
        $264 = $263;
       } else {
        $139 = HEAP32[$91>>2]|0;
        $140 = HEAP32[$92>>2]|0;
        $141 = (($140) + ($139<<2)|0);
        $142 = HEAP32[$141>>2]|0;
        HEAP32[$91>>2] = $142;
        HEAP32[$141>>2] = -1;
        $143 = HEAP32[$0>>2]|0;
        $144 = (($143) + (($139*12)|0)|0);
        HEAP32[$144>>2] = 0;
        $145 = ((($143) + (($139*12)|0)|0) + 4|0);
        HEAP32[$145>>2] = -1;
        $146 = ((($143) + (($139*12)|0)|0) + 8|0);
        HEAP8[$146>>0] = 0;
        $147 = (($kinematicProxySourceNodes) + ($139<<2)|0);
        HEAP32[$147>>2] = $133;
        $$pn1 = $133;
        while(1) {
         $mapNext$0$in = (($kinematicProxyNextNodes) + ($$pn1<<2)|0);
         $mapNext$0 = HEAP32[$mapNext$0$in>>2]|0;
         $148 = ($mapNext$0|0)==(-1);
         if ($148) {
          break;
         } else {
          $$pn1 = $mapNext$0;
         }
        }
        HEAP32[$mapNext$0$in>>2] = $139;
        $149 = (($kinematicProxyNextNodes) + ($139<<2)|0);
        HEAP32[$149>>2] = -1;
        $150 = (($1) + (($133*12)|0)|0);
        $151 = HEAP32[$150>>2]|0;
        $152 = (($1) + (($139*12)|0)|0);
        HEAP32[$152>>2] = $151;
        $153 = HEAP8[$135>>0]|0;
        $154 = $153&255;
        $155 = $154 & 223;
        $156 = $155&255;
        $157 = ((($1) + (($139*12)|0)|0) + 8|0);
        HEAP8[$157>>0] = $156;
        $158 = HEAP32[$90>>2]|0;
        $159 = ((($1) + (($139*12)|0)|0) + 4|0);
        HEAP32[$159>>2] = $104;
        $160 = (($158) + ($104<<4)|0);
        $161 = HEAP32[$160>>2]|0;
        $162 = (($5) + ($139<<2)|0);
        HEAP32[$162>>2] = $161;
        HEAP32[$160>>2] = $139;
        $163 = ((($158) + ($104<<4)|0) + 8|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = ($164|0)==(-1);
        $nodeId$$i3 = $165 ? $139 : $164;
        HEAP32[$163>>2] = $nodeId$$i3;
        HEAP32[$132>>2] = $139;
        $264 = $158;
       }
      }
      $166 = ((($7) + (($nextEdge$025*12)|0)|0) + 4|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = ($167|0)==(-1);
      if ($168) {
       $265 = $264;
      } else {
       $169 = ((($1) + (($167*12)|0)|0) + 8|0);
       $170 = HEAP8[$169>>0]|0;
       $171 = $170 & 1;
       $172 = ($171<<24>>24)==(0);
       if ($172) {
        $265 = $264;
       } else {
        $173 = HEAP32[$91>>2]|0;
        $174 = HEAP32[$92>>2]|0;
        $175 = (($174) + ($173<<2)|0);
        $176 = HEAP32[$175>>2]|0;
        HEAP32[$91>>2] = $176;
        HEAP32[$175>>2] = -1;
        $177 = HEAP32[$0>>2]|0;
        $178 = (($177) + (($173*12)|0)|0);
        HEAP32[$178>>2] = 0;
        $179 = ((($177) + (($173*12)|0)|0) + 4|0);
        HEAP32[$179>>2] = -1;
        $180 = ((($177) + (($173*12)|0)|0) + 8|0);
        HEAP8[$180>>0] = 0;
        $181 = (($kinematicProxySourceNodes) + ($173<<2)|0);
        HEAP32[$181>>2] = $167;
        $mapLast6$0 = $167;
        while(1) {
         $mapNext7$0$in = (($kinematicProxyNextNodes) + ($mapLast6$0<<2)|0);
         $mapNext7$0 = HEAP32[$mapNext7$0$in>>2]|0;
         $182 = ($mapNext7$0|0)==(-1);
         if ($182) {
          break;
         } else {
          $mapLast6$0 = $mapNext7$0;
         }
        }
        HEAP32[$mapNext7$0$in>>2] = $173;
        $183 = (($kinematicProxyNextNodes) + ($173<<2)|0);
        HEAP32[$183>>2] = -1;
        $184 = (($1) + (($167*12)|0)|0);
        $185 = HEAP32[$184>>2]|0;
        $186 = (($1) + (($173*12)|0)|0);
        HEAP32[$186>>2] = $185;
        $187 = HEAP8[$169>>0]|0;
        $188 = $187&255;
        $189 = $188 & 223;
        $190 = $189&255;
        $191 = ((($1) + (($173*12)|0)|0) + 8|0);
        HEAP8[$191>>0] = $190;
        $192 = HEAP32[$90>>2]|0;
        $193 = ((($1) + (($173*12)|0)|0) + 4|0);
        HEAP32[$193>>2] = $104;
        $194 = (($192) + ($104<<4)|0);
        $195 = HEAP32[$194>>2]|0;
        $196 = (($5) + ($173<<2)|0);
        HEAP32[$196>>2] = $195;
        HEAP32[$194>>2] = $173;
        $197 = ((($192) + ($104<<4)|0) + 8|0);
        $198 = HEAP32[$197>>2]|0;
        $199 = ($198|0)==(-1);
        $nodeId$$i2 = $199 ? $173 : $198;
        HEAP32[$197>>2] = $nodeId$$i2;
        HEAP32[$166>>2] = $173;
        $265 = $192;
       }
      }
      $200 = (($9) + ($nextEdge$025<<2)|0);
      $nextEdge$0 = HEAP32[$200>>2]|0;
      $201 = ($nextEdge$0|0)==(-1);
      if ($201) {
       $262 = $265;
       break;
      } else {
       $263 = $265;$nextEdge$025 = $nextEdge$0;
      }
     }
    }
    $202 = (($b3$028) + -1)|0;
    $203 = $202 & $b3$028;
    $204 = ($203|0)==(0);
    if ($204) {
     break;
    } else {
     $108 = $262;$b3$028 = $203;
    }
   }
  }
  $205 = (($w2$032) + 1)|0;
  $exitcond53 = ($205|0)==($$0$i5|0);
  if ($exitcond53) {
   break;
  } else {
   $w2$032 = $205;
  }
 }
 $206 = HEAP32[$kinematicNodesBitmap>>2]|0;
 $207 = HEAP32[$12>>2]|0;
 $208 = $207 & 2147483647;
 $i$0$i = $208;
 while(1) {
  $209 = (($i$0$i) + -1)|0;
  $210 = ($i$0$i|0)==(0);
  if ($210) {
   $$0$i = 1;
   break;
  }
  $211 = (($206) + ($209<<2)|0);
  $212 = HEAP32[$211>>2]|0;
  $213 = ($212|0)==(0);
  if ($213) {
   $i$0$i = $209;
  } else {
   label = 44;
   break;
  }
 }
 if ((label|0) == 44) {
  $214 = $209 << 5;
  $215 = $212 >>> 1;
  $216 = $215 | $212;
  $217 = $216 >>> 2;
  $218 = $217 | $216;
  $219 = $218 >>> 4;
  $220 = $219 | $218;
  $221 = $220 >>> 8;
  $222 = $221 | $220;
  $223 = $222 >>> 16;
  $224 = $223 | $222;
  $225 = Math_imul($224, 130329821)|0;
  $226 = $225 >>> 27;
  $227 = (482344 + ($226<<2)|0);
  $228 = HEAP32[$227>>2]|0;
  $229 = (($228) + ($214))|0;
  $phitmp11 = $229 >>> 5;
  $phitmp65 = (($phitmp11) + 1)|0;
  $$0$i = $phitmp65;
 }
 $w11$013 = 0;
 while(1) {
  $230 = (($206) + ($w11$013<<2)|0);
  $231 = HEAP32[$230>>2]|0;
  $232 = ($231|0)==(0);
  if (!($232)) {
   $233 = $w11$013 << 5;
   $b12$012 = $231;
   while(1) {
    $234 = (0 - ($b12$012))|0;
    $235 = $b12$012 & $234;
    $236 = Math_imul($235, 125613361)|0;
    $237 = $236 >>> 27;
    $238 = (412480 + ($237<<2)|0);
    $239 = HEAP32[$238>>2]|0;
    $240 = $239 | $233;
    $241 = ((($1) + (($240*12)|0)|0) + 8|0);
    $242 = HEAP8[$241>>0]|0;
    $243 = $242&255;
    $244 = $243 & 223;
    $245 = $244&255;
    HEAP8[$241>>0] = $245;
    $246 = (($kinematicProxyNextNodes) + ($240<<2)|0);
    $247 = HEAP32[$246>>2]|0;
    $248 = ($247|0)==(-1);
    $249 = ((($1) + (($240*12)|0)|0) + 4|0);
    if ($248) {
     $250 = HEAP32[$249>>2]|0;
     $251 = HEAP32[$90>>2]|0;
     $252 = (($251) + ($250<<4)|0);
     $253 = HEAP32[$252>>2]|0;
     $254 = (($5) + ($240<<2)|0);
     HEAP32[$254>>2] = $253;
     HEAP32[$252>>2] = $240;
     $255 = ((($251) + ($250<<4)|0) + 8|0);
     $256 = HEAP32[$255>>2]|0;
     $257 = ($256|0)==(-1);
     $nodeId$$i = $257 ? $240 : $256;
     HEAP32[$255>>2] = $nodeId$$i;
    } else {
     HEAP32[$249>>2] = -1;
    }
    $258 = (($b12$012) + -1)|0;
    $259 = $258 & $b12$012;
    $260 = ($259|0)==(0);
    if ($260) {
     break;
    } else {
     $b12$012 = $259;
    }
   }
  }
  $261 = (($w11$013) + 1)|0;
  $exitcond = ($261|0)==($$0$i|0);
  if ($exitcond) {
   break;
  } else {
   $w11$013 = $261;
  }
 }
 STACKTOP = sp;return;
}
function __ZL24processBrokenEdgeIslandsRKN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEEERNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerEPjSD_SD_PS4_($brokenEdgeIslandsBitmap,$nodeManager,$edgeManager,$islands,$graphNextNodes,$graphStartIslands,$graphNextIslands,$affectedIslandsBitmap) {
 $brokenEdgeIslandsBitmap = $brokenEdgeIslandsBitmap|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $graphNextNodes = $graphNextNodes|0;
 $graphStartIslands = $graphStartIslands|0;
 $graphNextIslands = $graphNextIslands|0;
 $affectedIslandsBitmap = $affectedIslandsBitmap|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b$01 = 0, $exitcond = 0, $i$0$i = 0, $islandsToUpdate = 0, $numIslandsToUpdate$04 = 0, $numIslandsToUpdate$1$lcssa = 0;
 var $numIslandsToUpdate$12 = 0, $numIslandsToUpdate$2 = 0, $phitmp = 0, $phitmp9 = 0, $w$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4096|0;
 $islandsToUpdate = sp;
 $0 = (($brokenEdgeIslandsBitmap) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $i$0$i = $2;
 while(1) {
  $3 = (($i$0$i) + -1)|0;
  $4 = ($i$0$i|0)==(0);
  if ($4) {
   $$0$i = 1;
   break;
  }
  $5 = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
  $6 = (($5) + ($3<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $i$0$i = $3;
  } else {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $9 = $3 << 5;
  $10 = $7 >>> 1;
  $11 = $10 | $7;
  $12 = $11 >>> 2;
  $13 = $12 | $11;
  $14 = $13 >>> 4;
  $15 = $14 | $13;
  $16 = $15 >>> 8;
  $17 = $16 | $15;
  $18 = $17 >>> 16;
  $19 = $18 | $17;
  $20 = Math_imul($19, 130329821)|0;
  $21 = $20 >>> 27;
  $22 = (482344 + ($21<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($9))|0;
  $phitmp = $24 >>> 5;
  $phitmp9 = (($phitmp) + 1)|0;
  $$0$i = $phitmp9;
 }
 $25 = (($islands) + 20|0);
 $numIslandsToUpdate$04 = 0;$w$03 = 0;
 while(1) {
  $26 = HEAP32[$brokenEdgeIslandsBitmap>>2]|0;
  $27 = (($26) + ($w$03<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0);
  if ($29) {
   $numIslandsToUpdate$1$lcssa = $numIslandsToUpdate$04;
  } else {
   $30 = $w$03 << 5;
   $b$01 = $28;$numIslandsToUpdate$12 = $numIslandsToUpdate$04;
   while(1) {
    $31 = (0 - ($b$01))|0;
    $32 = $b$01 & $31;
    $33 = Math_imul($32, 125613361)|0;
    $34 = $33 >>> 27;
    $35 = (412480 + ($34<<2)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36 | $30;
    $38 = $37 >>> 5;
    $39 = HEAP32[$25>>2]|0;
    $40 = (($39) + ($38<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $36 & 31;
    $43 = 1 << $42;
    $44 = $41 & $43;
    $45 = ($44|0)==(0);
    do {
     if ($45) {
      $numIslandsToUpdate$2 = $numIslandsToUpdate$12;
     } else {
      $46 = ($numIslandsToUpdate$12>>>0)<(1024);
      if ($46) {
       $47 = (($islandsToUpdate) + ($numIslandsToUpdate$12<<2)|0);
       HEAP32[$47>>2] = $37;
       $48 = (($numIslandsToUpdate$12) + 1)|0;
       $numIslandsToUpdate$2 = $48;
       break;
      } else {
       __ZL25processBrokenEdgeIslands2PKjjRN5physx11NodeManagerERNS1_11EdgeManagerERNS1_13IslandManagerEPjS8_S8_PNS1_2Cm10BitMapBaseINS1_6shdfnd9AllocatorEEE($islandsToUpdate,$numIslandsToUpdate$12,$nodeManager,$edgeManager,$islands,$graphNextNodes,$graphStartIslands,$graphNextIslands,$affectedIslandsBitmap);
       HEAP32[$islandsToUpdate>>2] = $37;
       $numIslandsToUpdate$2 = 1;
       break;
      }
     }
    } while(0);
    $49 = (($b$01) + -1)|0;
    $50 = $49 & $b$01;
    $51 = ($50|0)==(0);
    if ($51) {
     $numIslandsToUpdate$1$lcssa = $numIslandsToUpdate$2;
     break;
    } else {
     $b$01 = $50;$numIslandsToUpdate$12 = $numIslandsToUpdate$2;
    }
   }
  }
  $52 = (($w$03) + 1)|0;
  $exitcond = ($52|0)==($$0$i|0);
  if ($exitcond) {
   break;
  } else {
   $numIslandsToUpdate$04 = $numIslandsToUpdate$1$lcssa;$w$03 = $52;
  }
 }
 __ZL25processBrokenEdgeIslands2PKjjRN5physx11NodeManagerERNS1_11EdgeManagerERNS1_13IslandManagerEPjS8_S8_PNS1_2Cm10BitMapBaseINS1_6shdfnd9AllocatorEEE($islandsToUpdate,$numIslandsToUpdate$1$lcssa,$nodeManager,$edgeManager,$islands,$graphNextNodes,$graphStartIslands,$graphNextIslands,$affectedIslandsBitmap);
 STACKTOP = sp;return;
}
function __ZL22processSleepingIslandsILb0EEvRKN5physx2Cm10BitMapBaseINS0_6shdfnd9AllocatorEEEjRNS0_11NodeManagerERNS0_11EdgeManagerERNS0_13IslandManagerERNS0_23ArticulationRootManagerERNS0_33ProcessSleepingIslandsComputeDataE($islandsToUpdate,$rigidBodyOffset,$nodeManager,$edgeManager,$islands,$articulationRootManager,$psicData) {
 $islandsToUpdate = $islandsToUpdate|0;
 $rigidBodyOffset = $rigidBodyOffset|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $articulationRootManager = $articulationRootManager|0;
 $psicData = $psicData|0;
 var $$0$i = 0, $$not = 0, $$not27 = 0, $$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$0140 = 0, $bodiesToSleepSize$0173 = 0, $bodiesToSleepSize$1$lcssa = 0, $bodiesToSleepSize$1149 = 0, $bodiesToSleepSize$2$ph$be = 0, $bodiesToSleepSize$2$ph135 = 0, $bodiesToSleepSize$4 = 0, $bodiesToWakeSize$0174 = 0, $bodiesToWakeSize$1$lcssa = 0, $bodiesToWakeSize$1150 = 0;
 var $bodiesToWakeSize$2 = 0, $bodiesToWakeSize$2$ph = 0, $bodiesToWakeSize$2$ph50 = 0, $bodiesToWakeSize$2$ph54 = 0, $bodiesToWakeSize$3 = 0, $bodiesToWakeSize$4 = 0, $body1$0 = 0, $body1$1 = 0, $body1$136 = 0, $body1$137 = 0, $body2$038 = 0, $body2$039 = 0, $brmerge = 0, $brmerge26 = 0, $brmerge29 = 0, $exitcond = 0, $hasSecondPassPairs$0$off0$ph = 0, $hasSecondPassPairs$0$off0$ph$ph = 0, $hasStaticContact$0$off0 = 0, $hasStaticContact$0$off0$ph = 0;
 var $hasStaticContact$0$off0$ph$ph = 0, $hasStaticContact$0$off0$ph$ph125 = 0, $hasStaticContact$0$off0$ph70 = 0, $hasStaticContact$1$off0 = 0, $hasStaticContact$2$off0 = 0, $hasStaticContact$2$off030 = 0, $hasStaticContact$2$off031 = 0, $i$0$i = 0, $islandFlags$044 = 0, $islandIndicesSecondPassSize$0165 = 0, $islandIndicesSecondPassSize$1$lcssa = 0, $islandIndicesSecondPassSize$1141 = 0, $islandIndicesSecondPassSize$2 = 0, $islandIndicesSize$0166 = 0, $islandIndicesSize$1$lcssa = 0, $islandIndicesSize$1142 = 0, $islandIndicesSize$2 = 0, $nextEdgeId$0 = 0, $nextEdgeId$0$in = 0, $nextEdgeId$0$in$ph = 0;
 var $nextEdgeId$0$in$ph$ph = 0, $nextEdgeId$0$in$ph$ph126 = 0, $nextEdgeId$0$in$ph71 = 0, $nextNode$0 = 0, $nextNode$0115 = 0, $nextNode$0115137 = 0, $nextNode$0116 = 0, $nextNode0$0 = 0, $nextNode0$043 = 0, $nextNode0$045 = 0, $nextNode2$0 = 0, $nextNode2$0$in = 0, $nextNode2$0$in$ph = 0, $nextNode2$0$in$ph47 = 0, $nextNode2$0$in$ph52 = 0, $node1IsKineOrStatic$0$off0 = 0, $node1IsKineOrStatic$1 = 0, $node1IsKineOrStatic$2$off0 = 0, $node1Type$0 = 0, $node1Type$1 = 0;
 var $node1Type$132 = 0, $node1Type$133 = 0, $node2IsKineOrStatic$0$off0 = 0, $node2IsKineOrStatic$0$off040 = 0, $node2Type$034 = 0, $node2Type$035 = 0, $npContactManagersSize$0172 = 0, $npContactManagersSize$1$lcssa = 0, $npContactManagersSize$1148 = 0, $npContactManagersSize$2$ph$ph = 0, $npContactManagersSize$2$ph$ph128 = 0, $npContactManagersSize$4 = 0, $or$cond = 0, $phitmp = 0, $phitmp178 = 0, $phitmp247 = 0, $phitmp41 = 0, $solverArticulationsSize$0169 = 0, $solverArticulationsSize$1$lcssa = 0, $solverArticulationsSize$1145 = 0;
 var $solverArticulationsSize$2$ph = 0, $solverArticulationsSize$4 = 0, $solverBodiesSize$0170 = 0, $solverBodiesSize$1$lcssa = 0, $solverBodiesSize$1146 = 0, $solverBodiesSize$2$ph = 0, $solverBodiesSize$2$ph48 = 0, $solverBodiesSize$4 = 0, $solverConstraintsSize$0167 = 0, $solverConstraintsSize$1$lcssa = 0, $solverConstraintsSize$1143 = 0, $solverConstraintsSize$2$ph = 0, $solverConstraintsSize$2$ph$ph = 0, $solverConstraintsSize$2$ph$ph127 = 0, $solverConstraintsSize$2$ph72 = 0, $solverConstraintsSize$4 = 0, $solverContactManagersSize$0168 = 0, $solverContactManagersSize$1$lcssa = 0, $solverContactManagersSize$1144 = 0, $solverContactManagersSize$2$ph$ph = 0;
 var $solverContactManagersSize$4 = 0, $solverKinematicsSize$0171 = 0, $solverKinematicsSize$1$lcssa = 0, $solverKinematicsSize$1147 = 0, $solverKinematicsSize$2$ph = 0, $solverKinematicsSize$2$ph49 = 0, $solverKinematicsSize$2$ph53 = 0, $solverKinematicsSize$4 = 0, $w$0164 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($psicData) + 12|0);
 HEAP32[$0>>2] = 0;
 $1 = (($psicData) + 16|0);
 HEAP32[$1>>2] = 0;
 $2 = (($psicData) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = (($psicData) + 48|0);
 HEAP32[$3>>2] = 0;
 $4 = (($psicData) + 60|0);
 HEAP32[$4>>2] = 0;
 $5 = (($psicData) + 76|0);
 HEAP32[$5>>2] = 0;
 $6 = (($psicData) + 88|0);
 HEAP32[$6>>2] = 0;
 $7 = (($psicData) + 100|0);
 HEAP32[$7>>2] = 0;
 $8 = (($psicData) + 112|0);
 HEAP32[$8>>2] = 0;
 $9 = (($psicData) + 120|0);
 HEAP32[$9>>2] = 0;
 $10 = (($nodeManager) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($nodeManager) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($edgeManager) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($edgeManager) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($articulationRootManager) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($islands) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($psicData) + 36|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($psicData) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($psicData) + 20|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($psicData) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($psicData) + 44|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($psicData) + 56|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($psicData) + 68|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($psicData) + 72|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($psicData) + 84|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($psicData) + 96|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($psicData) + 108|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($psicData) + 116|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$islandsToUpdate>>2]|0;
 $47 = (($islandsToUpdate) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 & 2147483647;
 $i$0$i = $49;
 while(1) {
  $50 = (($i$0$i) + -1)|0;
  $51 = ($i$0$i|0)==(0);
  if ($51) {
   $$0$i = 1;
   break;
  }
  $52 = (($46) + ($50<<2)|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0);
  if ($54) {
   $i$0$i = $50;
  } else {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $55 = $50 << 5;
  $56 = $53 >>> 1;
  $57 = $56 | $53;
  $58 = $57 >>> 2;
  $59 = $58 | $57;
  $60 = $59 >>> 4;
  $61 = $60 | $59;
  $62 = $61 >>> 8;
  $63 = $62 | $61;
  $64 = $63 >>> 16;
  $65 = $64 | $63;
  $66 = Math_imul($65, 130329821)|0;
  $67 = $66 >>> 27;
  $68 = (482344 + ($67<<2)|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($69) + ($55))|0;
  $phitmp41 = $70 >>> 5;
  $phitmp247 = (($phitmp41) + 1)|0;
  $$0$i = $phitmp247;
 }
 $71 = (($27) + -1)|0;
 $bodiesToSleepSize$0173 = 0;$bodiesToWakeSize$0174 = 0;$islandIndicesSecondPassSize$0165 = 0;$islandIndicesSize$0166 = 0;$npContactManagersSize$0172 = 0;$solverArticulationsSize$0169 = 0;$solverBodiesSize$0170 = 0;$solverConstraintsSize$0167 = 0;$solverContactManagersSize$0168 = 0;$solverKinematicsSize$0171 = 0;$w$0164 = 0;
 while(1) {
  $72 = (($46) + ($w$0164<<2)|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==(0);
  if ($74) {
   $bodiesToSleepSize$1$lcssa = $bodiesToSleepSize$0173;$bodiesToWakeSize$1$lcssa = $bodiesToWakeSize$0174;$islandIndicesSecondPassSize$1$lcssa = $islandIndicesSecondPassSize$0165;$islandIndicesSize$1$lcssa = $islandIndicesSize$0166;$npContactManagersSize$1$lcssa = $npContactManagersSize$0172;$solverArticulationsSize$1$lcssa = $solverArticulationsSize$0169;$solverBodiesSize$1$lcssa = $solverBodiesSize$0170;$solverConstraintsSize$1$lcssa = $solverConstraintsSize$0167;$solverContactManagersSize$1$lcssa = $solverContactManagersSize$0168;$solverKinematicsSize$1$lcssa = $solverKinematicsSize$0171;
  } else {
   $75 = $w$0164 << 5;
   $b$0140 = $73;$bodiesToSleepSize$1149 = $bodiesToSleepSize$0173;$bodiesToWakeSize$1150 = $bodiesToWakeSize$0174;$islandIndicesSecondPassSize$1141 = $islandIndicesSecondPassSize$0165;$islandIndicesSize$1142 = $islandIndicesSize$0166;$npContactManagersSize$1148 = $npContactManagersSize$0172;$solverArticulationsSize$1145 = $solverArticulationsSize$0169;$solverBodiesSize$1146 = $solverBodiesSize$0170;$solverConstraintsSize$1143 = $solverConstraintsSize$0167;$solverContactManagersSize$1144 = $solverContactManagersSize$0168;$solverKinematicsSize$1147 = $solverKinematicsSize$0171;
   while(1) {
    $76 = (0 - ($b$0140))|0;
    $77 = $b$0140 & $76;
    $78 = Math_imul($77, 125613361)|0;
    $79 = $78 >>> 27;
    $80 = (412480 + ($79<<2)|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = $81 | $75;
    $83 = (($21) + ($82<<4)|0);
    $nextNode0$043 = HEAP32[$83>>2]|0;
    $84 = ($nextNode0$043|0)==(-1);
    L13: do {
     if ($84) {
      $bodiesToSleepSize$4 = $bodiesToSleepSize$1149;$bodiesToWakeSize$4 = $bodiesToWakeSize$1150;$islandIndicesSecondPassSize$2 = $islandIndicesSecondPassSize$1141;$islandIndicesSize$2 = $islandIndicesSize$1142;$npContactManagersSize$4 = $npContactManagersSize$1148;$solverArticulationsSize$4 = $solverArticulationsSize$1145;$solverBodiesSize$4 = $solverBodiesSize$1146;$solverConstraintsSize$4 = $solverConstraintsSize$1143;$solverContactManagersSize$4 = $solverContactManagersSize$1144;$solverKinematicsSize$4 = $solverKinematicsSize$1147;
     } else {
      $islandFlags$044 = 0;$nextNode0$045 = $nextNode0$043;
      while(1) {
       $85 = ((($11) + (($nextNode0$045*12)|0)|0) + 8|0);
       $86 = HEAP8[$85>>0]|0;
       $87 = $86&255;
       $88 = $87 | $islandFlags$044;
       $89 = (($13) + ($nextNode0$045<<2)|0);
       $nextNode0$0 = HEAP32[$89>>2]|0;
       $90 = ($nextNode0$0|0)==(-1);
       if ($90) {
        break;
       } else {
        $islandFlags$044 = $88;$nextNode0$045 = $nextNode0$0;
       }
      }
      $phitmp = $88 & 8;
      $phitmp178 = ($phitmp|0)==(0);
      if ($phitmp178) {
       if ($84) {
        $bodiesToSleepSize$4 = $bodiesToSleepSize$1149;$bodiesToWakeSize$4 = $bodiesToWakeSize$1150;$islandIndicesSecondPassSize$2 = $islandIndicesSecondPassSize$1141;$islandIndicesSize$2 = $islandIndicesSize$1142;$npContactManagersSize$4 = $npContactManagersSize$1148;$solverArticulationsSize$4 = $solverArticulationsSize$1145;$solverBodiesSize$4 = $solverBodiesSize$1146;$solverConstraintsSize$4 = $solverConstraintsSize$1143;$solverContactManagersSize$4 = $solverContactManagersSize$1144;$solverKinematicsSize$4 = $solverKinematicsSize$1147;
        break;
       } else {
        $bodiesToSleepSize$2$ph135 = $bodiesToSleepSize$1149;$nextNode$0115137 = $nextNode0$043;
       }
       while(1) {
        $nextNode$0116 = $nextNode$0115137;
        L21: while(1) {
         $91 = (($11) + (($nextNode$0116*12)|0)|0);
         $92 = (($13) + ($nextNode$0116<<2)|0);
         $93 = HEAP32[$92>>2]|0;
         $94 = (($11) + (($93*12)|0)|0);
         $95 = $94;
         $96 = (($95) + 128)|0;
         $97 = $96 & -128;
         $98 = $97;
         $99 = ((($11) + (($nextNode$0116*12)|0)|0) + 8|0);
         $100 = HEAP8[$99>>0]|0;
         $101 = $100 & 16;
         $102 = ($101<<24>>24)==(0);
         do {
          if ($102) {
           $104 = $100 & 2;
           $105 = ($104<<24>>24)==(0);
           if ($105) {
            $106 = $100 & 1;
            $107 = ($106<<24>>24)==(0);
            if ($107) {
             label = 17;
             break L21;
            } else {
             break;
            }
           } else {
            $121 = $100 & 4;
            $122 = ($121<<24>>24)==(0);
            if ($122) {
             break;
            } else {
             label = 20;
             break L21;
            }
           }
          }
         } while(0);
         $nextNode$0 = HEAP32[$92>>2]|0;
         $103 = ($nextNode$0|0)==(-1);
         if ($103) {
          $bodiesToSleepSize$4 = $bodiesToSleepSize$2$ph135;$bodiesToWakeSize$4 = $bodiesToWakeSize$1150;$islandIndicesSecondPassSize$2 = $islandIndicesSecondPassSize$1141;$islandIndicesSize$2 = $islandIndicesSize$1142;$npContactManagersSize$4 = $npContactManagersSize$1148;$solverArticulationsSize$4 = $solverArticulationsSize$1145;$solverBodiesSize$4 = $solverBodiesSize$1146;$solverConstraintsSize$4 = $solverConstraintsSize$1143;$solverContactManagersSize$4 = $solverContactManagersSize$1144;$solverKinematicsSize$4 = $solverKinematicsSize$1147;
          break L13;
         } else {
          $nextNode$0116 = $nextNode$0;
         }
        }
        if ((label|0) == 17) {
         label = 0;
         $108 = $100&255;
         $109 = $108 | 16;
         $110 = $109&255;
         HEAP8[$99>>0] = $110;
         $111 = HEAP32[$91>>2]|0;
         $112 = (($71) - ($bodiesToSleepSize$2$ph135))|0;
         $113 = (($25) + ($112<<2)|0);
         HEAP32[$113>>2] = $111;
         $114 = (($112) + -1)|0;
         $115 = (($25) + ($114<<2)|0);
         $116 = $115;
         $117 = (($116) + 128)|0;
         $118 = $117 & -128;
         $119 = $118;
        }
        else if ((label|0) == 20) {
         label = 0;
         $123 = $100&255;
         $124 = $123 | 16;
         $125 = $124&255;
         HEAP8[$99>>0] = $125;
         $126 = HEAP32[$91>>2]|0;
         $127 = ((($19) + ($126<<3)|0) + 4|0);
         $128 = HEAP32[$127>>2]|0;
         $129 = $128;
         $130 = $129 | 1;
         $131 = $130;
         $132 = (($71) - ($bodiesToSleepSize$2$ph135))|0;
         $133 = (($25) + ($132<<2)|0);
         HEAP32[$133>>2] = $131;
         $134 = (($132) + -1)|0;
         $135 = (($25) + ($134<<2)|0);
         $136 = $135;
         $137 = (($136) + 128)|0;
         $138 = $137 & -128;
         $139 = $138;
        }
        $bodiesToSleepSize$2$ph$be = (($bodiesToSleepSize$2$ph135) + 1)|0;
        $nextNode$0115 = HEAP32[$92>>2]|0;
        $120 = ($nextNode$0115|0)==(-1);
        if ($120) {
         $bodiesToSleepSize$4 = $bodiesToSleepSize$2$ph$be;$bodiesToWakeSize$4 = $bodiesToWakeSize$1150;$islandIndicesSecondPassSize$2 = $islandIndicesSecondPassSize$1141;$islandIndicesSize$2 = $islandIndicesSize$1142;$npContactManagersSize$4 = $npContactManagersSize$1148;$solverArticulationsSize$4 = $solverArticulationsSize$1145;$solverBodiesSize$4 = $solverBodiesSize$1146;$solverConstraintsSize$4 = $solverConstraintsSize$1143;$solverContactManagersSize$4 = $solverContactManagersSize$1144;$solverKinematicsSize$4 = $solverKinematicsSize$1147;
         break L13;
        } else {
         $bodiesToSleepSize$2$ph135 = $bodiesToSleepSize$2$ph$be;$nextNode$0115137 = $nextNode$0115;
        }
       }
      }
      $140 = ((($43) + ($islandIndicesSize$1142<<4)|0) + 4|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = $solverArticulationsSize$1145 & 2147483647;
      $143 = $141 & -2147483648;
      $144 = $143 | $142;
      HEAP32[$140>>2] = $144;
      $145 = (($43) + ($islandIndicesSize$1142<<4)|0);
      HEAP32[$145>>2] = $solverBodiesSize$1146;
      $146 = ((($43) + ($islandIndicesSize$1142<<4)|0) + 8|0);
      HEAP32[$146>>2] = $solverContactManagersSize$1144;
      $147 = ((($43) + ($islandIndicesSize$1142<<4)|0) + 12|0);
      HEAP32[$147>>2] = $solverConstraintsSize$1143;
      $148 = (($islandIndicesSize$1142) + 1)|0;
      $149 = (($43) + ($148<<4)|0);
      $150 = $149;
      $151 = (($150) + 128)|0;
      $152 = $151 & -128;
      $153 = $152;
      $bodiesToWakeSize$2$ph = $bodiesToWakeSize$1150;$nextNode2$0$in$ph = $83;$solverArticulationsSize$2$ph = $solverArticulationsSize$1145;$solverBodiesSize$2$ph = $solverBodiesSize$1146;$solverKinematicsSize$2$ph = $solverKinematicsSize$1147;
      L34: while(1) {
       $bodiesToWakeSize$2$ph50 = $bodiesToWakeSize$2$ph;$nextNode2$0$in$ph47 = $nextNode2$0$in$ph;$solverBodiesSize$2$ph48 = $solverBodiesSize$2$ph;$solverKinematicsSize$2$ph49 = $solverKinematicsSize$2$ph;
       L36: while(1) {
        $bodiesToWakeSize$2$ph54 = $bodiesToWakeSize$2$ph50;$nextNode2$0$in$ph52 = $nextNode2$0$in$ph47;$solverKinematicsSize$2$ph53 = $solverKinematicsSize$2$ph49;
        L38: while(1) {
         $bodiesToWakeSize$2 = $bodiesToWakeSize$2$ph54;$nextNode2$0$in = $nextNode2$0$in$ph52;
         while(1) {
          $nextNode2$0 = HEAP32[$nextNode2$0$in>>2]|0;
          $154 = ($nextNode2$0|0)==(-1);
          if ($154) {
           break L34;
          }
          $155 = (($11) + (($nextNode2$0*12)|0)|0);
          $156 = (($13) + ($nextNode2$0<<2)|0);
          $157 = HEAP32[$156>>2]|0;
          $158 = (($11) + (($157*12)|0)|0);
          $159 = $158;
          $160 = (($159) + 128)|0;
          $161 = $160 & -128;
          $162 = $161;
          $163 = ((($11) + (($nextNode2$0*12)|0)|0) + 8|0);
          $164 = HEAP8[$163>>0]|0;
          $165 = $164 & 16;
          $166 = ($165<<24>>24)==(0);
          do {
           if ($166) {
            $bodiesToWakeSize$3 = $bodiesToWakeSize$2;
           } else {
            $167 = $164 & 2;
            $168 = ($167<<24>>24)==(0);
            if ($168) {
             $169 = $164 & 1;
             $170 = ($169<<24>>24)==(0);
             if (!($170)) {
              $bodiesToWakeSize$3 = $bodiesToWakeSize$2;
              break;
             }
             $171 = $164&255;
             $172 = $171 & 239;
             $173 = $172&255;
             HEAP8[$163>>0] = $173;
             $174 = HEAP32[$155>>2]|0;
             $175 = (($25) + ($bodiesToWakeSize$2<<2)|0);
             HEAP32[$175>>2] = $174;
             $176 = (($bodiesToWakeSize$2) + 1)|0;
             $177 = (($25) + ($176<<2)|0);
             $178 = $177;
             $179 = (($178) + 128)|0;
             $180 = $179 & -128;
             $181 = $180;
             $bodiesToWakeSize$3 = $176;
             break;
            } else {
             $182 = $164 & 4;
             $183 = ($182<<24>>24)==(0);
             if ($183) {
              $bodiesToWakeSize$3 = $bodiesToWakeSize$2;
              break;
             }
             $184 = $164&255;
             $185 = $184 & 239;
             $186 = $185&255;
             HEAP8[$163>>0] = $186;
             $187 = HEAP32[$155>>2]|0;
             $188 = ((($19) + ($187<<3)|0) + 4|0);
             $189 = HEAP32[$188>>2]|0;
             $190 = $189;
             $191 = $190 | 1;
             $192 = $191;
             $193 = (($25) + ($bodiesToWakeSize$2<<2)|0);
             HEAP32[$193>>2] = $192;
             $194 = (($bodiesToWakeSize$2) + 1)|0;
             $195 = (($25) + ($194<<2)|0);
             $196 = $195;
             $197 = (($196) + 128)|0;
             $198 = $197 & -128;
             $199 = $198;
             $bodiesToWakeSize$3 = $194;
             break;
            }
           }
          } while(0);
          $200 = HEAP8[$163>>0]|0;
          $201 = $200 & 1;
          $202 = ($201<<24>>24)==(0);
          if (!($202)) {
           break;
          }
          $203 = $200 & 2;
          $204 = ($203<<24>>24)==(0);
          if ($204) {
           break L38;
          }
          $215 = $200 & 4;
          $216 = ($215<<24>>24)==(0);
          if ($216) {
           $bodiesToWakeSize$2 = $bodiesToWakeSize$3;$nextNode2$0$in = $156;
          } else {
           break L36;
          }
         }
         $237 = (($23) + ($nextNode2$0<<2)|0);
         HEAP32[$237>>2] = $solverKinematicsSize$2$ph53;
         $238 = HEAP32[$155>>2]|0;
         $239 = (($238) + ($rigidBodyOffset)|0);
         $240 = (($31) + ($solverKinematicsSize$2$ph53<<2)|0);
         HEAP32[$240>>2] = $239;
         $241 = (($solverKinematicsSize$2$ph53) + 1)|0;
         $242 = (($31) + ($241<<2)|0);
         $243 = $242;
         $244 = (($243) + 128)|0;
         $245 = $244 & -128;
         $246 = $245;
         $bodiesToWakeSize$2$ph54 = $bodiesToWakeSize$3;$nextNode2$0$in$ph52 = $156;$solverKinematicsSize$2$ph53 = $241;
        }
        $205 = (($23) + ($nextNode2$0<<2)|0);
        HEAP32[$205>>2] = $solverBodiesSize$2$ph48;
        $206 = HEAP32[$155>>2]|0;
        $207 = (($206) + ($rigidBodyOffset)|0);
        $208 = (($33) + ($solverBodiesSize$2$ph48<<2)|0);
        HEAP32[$208>>2] = $207;
        $209 = (($solverBodiesSize$2$ph48) + 1)|0;
        $210 = (($33) + ($209<<2)|0);
        $211 = $210;
        $212 = (($211) + 128)|0;
        $213 = $212 & -128;
        $214 = $213;
        $bodiesToWakeSize$2$ph50 = $bodiesToWakeSize$3;$nextNode2$0$in$ph47 = $156;$solverBodiesSize$2$ph48 = $209;$solverKinematicsSize$2$ph49 = $solverKinematicsSize$2$ph53;
       }
       $217 = HEAP32[$155>>2]|0;
       $218 = (($19) + ($217<<3)|0);
       $219 = HEAP32[$218>>2]|0;
       $220 = ((($19) + ($217<<3)|0) + 4|0);
       $221 = HEAP32[$220>>2]|0;
       $222 = $219 & -64;
       $223 = $222;
       $224 = (($35) + ($solverArticulationsSize$2$ph<<2)|0);
       HEAP32[$224>>2] = $223;
       $225 = (($37) + ($solverArticulationsSize$2$ph<<2)|0);
       HEAP32[$225>>2] = $221;
       $226 = (($solverArticulationsSize$2$ph) + 1)|0;
       $227 = (($35) + ($226<<2)|0);
       $228 = $227;
       $229 = (($228) + 128)|0;
       $230 = $229 & -128;
       $231 = $230;
       $232 = (($37) + ($226<<2)|0);
       $233 = $232;
       $234 = (($233) + 128)|0;
       $235 = $234 & -128;
       $236 = $235;
       $bodiesToWakeSize$2$ph = $bodiesToWakeSize$3;$nextNode2$0$in$ph = $156;$solverArticulationsSize$2$ph = $226;$solverBodiesSize$2$ph = $solverBodiesSize$2$ph48;$solverKinematicsSize$2$ph = $solverKinematicsSize$2$ph53;
      }
      $247 = ((($21) + ($82<<4)|0) + 4|0);
      $hasStaticContact$0$off0$ph$ph = 0;$nextEdgeId$0$in$ph$ph = $247;$npContactManagersSize$2$ph$ph = $npContactManagersSize$1148;$solverConstraintsSize$2$ph$ph = $solverConstraintsSize$1143;$solverContactManagersSize$2$ph$ph = $solverContactManagersSize$1144;
      L57: while(1) {
       $hasSecondPassPairs$0$off0$ph$ph = 0;$hasStaticContact$0$off0$ph$ph125 = $hasStaticContact$0$off0$ph$ph;$nextEdgeId$0$in$ph$ph126 = $nextEdgeId$0$in$ph$ph;$npContactManagersSize$2$ph$ph128 = $npContactManagersSize$2$ph$ph;$solverConstraintsSize$2$ph$ph127 = $solverConstraintsSize$2$ph$ph;
       L59: while(1) {
        $hasSecondPassPairs$0$off0$ph = $hasSecondPassPairs$0$off0$ph$ph;$hasStaticContact$0$off0$ph = $hasStaticContact$0$off0$ph$ph125;$nextEdgeId$0$in$ph = $nextEdgeId$0$in$ph$ph126;$solverConstraintsSize$2$ph = $solverConstraintsSize$2$ph$ph127;
        L61: while(1) {
         $hasStaticContact$0$off0$ph70 = $hasStaticContact$0$off0$ph;$nextEdgeId$0$in$ph71 = $nextEdgeId$0$in$ph;$solverConstraintsSize$2$ph72 = $solverConstraintsSize$2$ph;
         while(1) {
          $hasStaticContact$0$off0 = $hasStaticContact$0$off0$ph70;$nextEdgeId$0$in = $nextEdgeId$0$in$ph71;
          while(1) {
           $nextEdgeId$0 = HEAP32[$nextEdgeId$0$in>>2]|0;
           $248 = ($nextEdgeId$0|0)==(-1);
           if ($248) {
            break L57;
           }
           $249 = (($17) + ($nextEdgeId$0<<2)|0);
           $250 = HEAP32[$249>>2]|0;
           $251 = (($15) + (($250*12)|0)|0);
           $252 = $251;
           $253 = (($252) + 128)|0;
           $254 = $253 & -128;
           $255 = $254;
           $256 = (($15) + (($nextEdgeId$0*12)|0)|0);
           $257 = HEAP32[$256>>2]|0;
           $258 = ((($15) + (($nextEdgeId$0*12)|0)|0) + 4|0);
           $259 = HEAP32[$258>>2]|0;
           $260 = ($257|0)!=(-1);
           do {
            if ($hasSecondPassPairs$0$off0$ph) {
             if ($260) {
              $290 = ((($11) + (($257*12)|0)|0) + 8|0);
              $291 = HEAP8[$290>>0]|0;
              $292 = $291 & 2;
              $293 = ($292<<24>>24)==(0);
              if ($293) {
               $294 = $291 & 1;
               $295 = ($294<<24>>24)!=(0);
               $node1IsKineOrStatic$1 = $295;
              } else {
               $node1IsKineOrStatic$1 = 0;
              }
             } else {
              $node1IsKineOrStatic$1 = 1;
             }
             $296 = ($259|0)==(-1);
             if ($296) {
              $body1$1 = -1;$hasStaticContact$2$off0 = $hasStaticContact$0$off0;$node1IsKineOrStatic$2$off0 = $node1IsKineOrStatic$1;$node1Type$1 = 3;$node2IsKineOrStatic$0$off0 = 1;
              label = 61;
             } else {
              $297 = ((($11) + (($259*12)|0)|0) + 8|0);
              $298 = HEAP8[$297>>0]|0;
              $299 = $298 & 2;
              $300 = ($299<<24>>24)==(0);
              if ($300) {
               $301 = $298 & 1;
               $302 = ($301<<24>>24)!=(0);
               if ($node1IsKineOrStatic$1) {
                $body1$137 = -1;$body2$039 = -1;$hasStaticContact$2$off031 = $hasStaticContact$0$off0;$node1Type$133 = 3;$node2IsKineOrStatic$0$off040 = $302;$node2Type$035 = 3;
                label = 62;
               } else {
                $$off0 = 0;$body1$136 = -1;$body2$038 = -1;$hasStaticContact$2$off030 = $hasStaticContact$0$off0;$node1Type$132 = 3;$node2Type$034 = 3;
               }
              } else {
               $body1$1 = -1;$hasStaticContact$2$off0 = $hasStaticContact$0$off0;$node1IsKineOrStatic$2$off0 = $node1IsKineOrStatic$1;$node1Type$1 = 3;$node2IsKineOrStatic$0$off0 = 0;
               label = 61;
              }
             }
            } else {
             do {
              if ($260) {
               $261 = ((($11) + (($257*12)|0)|0) + 8|0);
               $262 = HEAP8[$261>>0]|0;
               $263 = $262 & 2;
               $264 = ($263<<24>>24)==(0);
               if ($264) {
                $265 = $262 & 1;
                $266 = ($265<<24>>24)!=(0);
                $267 = (($23) + ($257<<2)|0);
                $268 = HEAP32[$267>>2]|0;
                $body1$0 = $268;$hasStaticContact$1$off0 = $hasStaticContact$0$off0;$node1IsKineOrStatic$0$off0 = $266;$node1Type$0 = $265;
                break;
               }
               $269 = (($11) + (($257*12)|0)|0);
               $270 = $262 & 4;
               $271 = ($270<<24>>24)==(0);
               $272 = HEAP32[$269>>2]|0;
               if ($271) {
                $body1$0 = $272;$hasStaticContact$1$off0 = $hasStaticContact$0$off0;$node1IsKineOrStatic$0$off0 = 0;$node1Type$0 = 2;
               } else {
                $273 = (($19) + ($272<<3)|0);
                $274 = HEAP32[$273>>2]|0;
                $body1$0 = $274;$hasStaticContact$1$off0 = $hasStaticContact$0$off0;$node1IsKineOrStatic$0$off0 = 0;$node1Type$0 = 2;
               }
              } else {
               $body1$0 = -1;$hasStaticContact$1$off0 = 1;$node1IsKineOrStatic$0$off0 = 1;$node1Type$0 = 3;
              }
             } while(0);
             $275 = ($259|0)==(-1);
             if ($275) {
              $body1$1 = $body1$0;$hasStaticContact$2$off0 = 1;$node1IsKineOrStatic$2$off0 = $node1IsKineOrStatic$0$off0;$node1Type$1 = $node1Type$0;$node2IsKineOrStatic$0$off0 = 1;
              label = 61;
             } else {
              $276 = ((($11) + (($259*12)|0)|0) + 8|0);
              $277 = HEAP8[$276>>0]|0;
              $278 = $277 & 2;
              $279 = ($278<<24>>24)==(0);
              if ($279) {
               $280 = $277 & 1;
               $281 = ($280<<24>>24)!=(0);
               $282 = (($23) + ($259<<2)|0);
               $283 = HEAP32[$282>>2]|0;
               if ($node1IsKineOrStatic$0$off0) {
                $body1$137 = $body1$0;$body2$039 = $283;$hasStaticContact$2$off031 = $hasStaticContact$1$off0;$node1Type$133 = $node1Type$0;$node2IsKineOrStatic$0$off040 = $281;$node2Type$035 = $280;
                label = 62;
                break;
               } else {
                $$off0 = 0;$body1$136 = $body1$0;$body2$038 = $283;$hasStaticContact$2$off030 = $hasStaticContact$1$off0;$node1Type$132 = $node1Type$0;$node2Type$034 = $280;
                break;
               }
              }
              $284 = (($11) + (($259*12)|0)|0);
              $285 = $277 & 4;
              $286 = ($285<<24>>24)==(0);
              $287 = HEAP32[$284>>2]|0;
              if ($286) {
               if ($node1IsKineOrStatic$0$off0) {
                $body1$137 = $body1$0;$body2$039 = $287;$hasStaticContact$2$off031 = $hasStaticContact$1$off0;$node1Type$133 = $node1Type$0;$node2IsKineOrStatic$0$off040 = 0;$node2Type$035 = 2;
                label = 62;
                break;
               } else {
                $$off0 = 0;$body1$136 = $body1$0;$body2$038 = $287;$hasStaticContact$2$off030 = $hasStaticContact$1$off0;$node1Type$132 = $node1Type$0;$node2Type$034 = 2;
                break;
               }
              } else {
               $288 = (($19) + ($287<<3)|0);
               $289 = HEAP32[$288>>2]|0;
               if ($node1IsKineOrStatic$0$off0) {
                $body1$137 = $body1$0;$body2$039 = $289;$hasStaticContact$2$off031 = $hasStaticContact$1$off0;$node1Type$133 = $node1Type$0;$node2IsKineOrStatic$0$off040 = 0;$node2Type$035 = 2;
                label = 62;
                break;
               } else {
                $$off0 = 0;$body1$136 = $body1$0;$body2$038 = $289;$hasStaticContact$2$off030 = $hasStaticContact$1$off0;$node1Type$132 = $node1Type$0;$node2Type$034 = 2;
                break;
               }
              }
             }
            }
           } while(0);
           if ((label|0) == 61) {
            label = 0;
            if ($node1IsKineOrStatic$2$off0) {
             $body1$137 = $body1$1;$body2$039 = -1;$hasStaticContact$2$off031 = $hasStaticContact$2$off0;$node1Type$133 = $node1Type$1;$node2IsKineOrStatic$0$off040 = $node2IsKineOrStatic$0$off0;$node2Type$035 = 3;
             label = 62;
            } else {
             $$off0 = 0;$body1$136 = $body1$1;$body2$038 = -1;$hasStaticContact$2$off030 = $hasStaticContact$2$off0;$node1Type$132 = $node1Type$1;$node2Type$034 = 3;
            }
           }
           if ((label|0) == 62) {
            label = 0;
            $$off0 = $node2IsKineOrStatic$0$off040;$body1$136 = $body1$137;$body2$038 = $body2$039;$hasStaticContact$2$off030 = $hasStaticContact$2$off031;$node1Type$132 = $node1Type$133;$node2Type$034 = $node2Type$035;
           }
           $303 = ((($15) + (($nextEdgeId$0*12)|0)|0) + 8|0);
           $304 = HEAP32[$303>>2]|0;
           $305 = $304;
           $306 = $305 & 3;
           $307 = ($306|0)!=(0);
           $$not = ($304>>>0)>=((16)>>>0);
           $brmerge = $$not | $$off0;
           $or$cond = $307 | $brmerge;
           if (!($or$cond)) {
            break L61;
           }
           if ($hasSecondPassPairs$0$off0$ph) {
            $hasSecondPassPairs$0$off0$ph = 1;$hasStaticContact$0$off0$ph = $hasStaticContact$2$off030;$nextEdgeId$0$in$ph = $249;$solverConstraintsSize$2$ph = $solverConstraintsSize$2$ph72;
            continue L61;
           }
           $brmerge26 = $307 | $$off0;
           if (!($brmerge26)) {
            break L59;
           }
           $329 = $305 & 1;
           $$not27 = ($329|0)==(0);
           $brmerge29 = $$not27 | $$off0;
           if ($brmerge29) {
            $hasStaticContact$0$off0 = $hasStaticContact$2$off030;$nextEdgeId$0$in = $249;
           } else {
            break;
           }
          }
          $330 = $304;
          $331 = $330 & -16;
          $332 = $331;
          $333 = ((($41) + ($solverConstraintsSize$2$ph72<<4)|0) + 12|0);
          HEAP32[$333>>2] = $332;
          $334 = ((($41) + ($solverConstraintsSize$2$ph72<<4)|0) + 8|0);
          HEAP8[$334>>0] = $node1Type$132;
          $335 = ((($41) + ($solverConstraintsSize$2$ph72<<4)|0) + 9|0);
          HEAP8[$335>>0] = $node2Type$034;
          $336 = (($41) + ($solverConstraintsSize$2$ph72<<4)|0);
          HEAP32[$336>>2] = $body1$136;
          $337 = ((($41) + ($solverConstraintsSize$2$ph72<<4)|0) + 4|0);
          HEAP32[$337>>2] = $body2$038;
          $338 = (($solverConstraintsSize$2$ph72) + 1)|0;
          $339 = (($41) + ($338<<4)|0);
          $340 = $339;
          $341 = (($340) + 128)|0;
          $342 = $341 & -128;
          $343 = $342;
          $hasStaticContact$0$off0$ph70 = $hasStaticContact$2$off030;$nextEdgeId$0$in$ph71 = $249;$solverConstraintsSize$2$ph72 = $338;
         }
        }
        $308 = ((($29) + ($npContactManagersSize$2$ph$ph128<<3)|0) + 4|0);
        HEAP32[$308>>2] = $nextEdgeId$0;
        $309 = (($29) + ($npContactManagersSize$2$ph$ph128<<3)|0);
        HEAP32[$309>>2] = 0;
        $310 = (($npContactManagersSize$2$ph$ph128) + 1)|0;
        $311 = (($29) + ($310<<3)|0);
        $312 = $311;
        $313 = (($312) + 128)|0;
        $314 = $313 & -128;
        $315 = $314;
        $hasSecondPassPairs$0$off0$ph$ph = 1;$hasStaticContact$0$off0$ph$ph125 = $hasStaticContact$2$off030;$nextEdgeId$0$in$ph$ph126 = $249;$npContactManagersSize$2$ph$ph128 = $310;$solverConstraintsSize$2$ph$ph127 = $solverConstraintsSize$2$ph72;
       }
       $316 = $305 & -16;
       $317 = $316;
       $318 = ((($39) + ($solverContactManagersSize$2$ph$ph<<4)|0) + 12|0);
       HEAP32[$318>>2] = $317;
       $319 = ((($39) + ($solverContactManagersSize$2$ph$ph<<4)|0) + 8|0);
       HEAP8[$319>>0] = $node1Type$132;
       $320 = ((($39) + ($solverContactManagersSize$2$ph$ph<<4)|0) + 9|0);
       HEAP8[$320>>0] = $node2Type$034;
       $321 = (($39) + ($solverContactManagersSize$2$ph$ph<<4)|0);
       HEAP32[$321>>2] = $body1$136;
       $322 = ((($39) + ($solverContactManagersSize$2$ph$ph<<4)|0) + 4|0);
       HEAP32[$322>>2] = $body2$038;
       $323 = (($solverContactManagersSize$2$ph$ph) + 1)|0;
       $324 = (($39) + ($323<<4)|0);
       $325 = $324;
       $326 = (($325) + 128)|0;
       $327 = $326 & -128;
       $328 = $327;
       $hasStaticContact$0$off0$ph$ph = $hasStaticContact$2$off030;$nextEdgeId$0$in$ph$ph = $249;$npContactManagersSize$2$ph$ph = $npContactManagersSize$2$ph$ph128;$solverConstraintsSize$2$ph$ph = $solverConstraintsSize$2$ph72;$solverContactManagersSize$2$ph$ph = $323;
      }
      if ($hasSecondPassPairs$0$off0$ph) {
       $349 = (($islandIndicesSecondPassSize$1141) + 1)|0;
       $350 = (($45) - ($349))|0;
       $351 = ((($43) + ($350<<4)|0) + 12|0);
       HEAP32[$351>>2] = $82;
       $bodiesToSleepSize$4 = $bodiesToSleepSize$1149;$bodiesToWakeSize$4 = $bodiesToWakeSize$2;$islandIndicesSecondPassSize$2 = $349;$islandIndicesSize$2 = $islandIndicesSize$1142;$npContactManagersSize$4 = $npContactManagersSize$2$ph$ph128;$solverArticulationsSize$4 = $solverArticulationsSize$1145;$solverBodiesSize$4 = $solverBodiesSize$1146;$solverConstraintsSize$4 = $solverConstraintsSize$1143;$solverContactManagersSize$4 = $solverContactManagersSize$1144;$solverKinematicsSize$4 = $solverKinematicsSize$1147;
       break;
      } else {
       $344 = $hasStaticContact$0$off0&1;
       $345 = HEAP32[$140>>2]|0;
       $346 = $344 << 31;
       $347 = $345 & 2147483647;
       $348 = $347 | $346;
       HEAP32[$140>>2] = $348;
       $bodiesToSleepSize$4 = $bodiesToSleepSize$1149;$bodiesToWakeSize$4 = $bodiesToWakeSize$2;$islandIndicesSecondPassSize$2 = $islandIndicesSecondPassSize$1141;$islandIndicesSize$2 = $148;$npContactManagersSize$4 = $npContactManagersSize$2$ph$ph128;$solverArticulationsSize$4 = $solverArticulationsSize$2$ph;$solverBodiesSize$4 = $solverBodiesSize$2$ph48;$solverConstraintsSize$4 = $solverConstraintsSize$2$ph72;$solverContactManagersSize$4 = $solverContactManagersSize$2$ph$ph;$solverKinematicsSize$4 = $solverKinematicsSize$2$ph53;
       break;
      }
     }
    } while(0);
    $352 = (($b$0140) + -1)|0;
    $353 = $352 & $b$0140;
    $354 = ($353|0)==(0);
    if ($354) {
     $bodiesToSleepSize$1$lcssa = $bodiesToSleepSize$4;$bodiesToWakeSize$1$lcssa = $bodiesToWakeSize$4;$islandIndicesSecondPassSize$1$lcssa = $islandIndicesSecondPassSize$2;$islandIndicesSize$1$lcssa = $islandIndicesSize$2;$npContactManagersSize$1$lcssa = $npContactManagersSize$4;$solverArticulationsSize$1$lcssa = $solverArticulationsSize$4;$solverBodiesSize$1$lcssa = $solverBodiesSize$4;$solverConstraintsSize$1$lcssa = $solverConstraintsSize$4;$solverContactManagersSize$1$lcssa = $solverContactManagersSize$4;$solverKinematicsSize$1$lcssa = $solverKinematicsSize$4;
     break;
    } else {
     $b$0140 = $353;$bodiesToSleepSize$1149 = $bodiesToSleepSize$4;$bodiesToWakeSize$1150 = $bodiesToWakeSize$4;$islandIndicesSecondPassSize$1141 = $islandIndicesSecondPassSize$2;$islandIndicesSize$1142 = $islandIndicesSize$2;$npContactManagersSize$1148 = $npContactManagersSize$4;$solverArticulationsSize$1145 = $solverArticulationsSize$4;$solverBodiesSize$1146 = $solverBodiesSize$4;$solverConstraintsSize$1143 = $solverConstraintsSize$4;$solverContactManagersSize$1144 = $solverContactManagersSize$4;$solverKinematicsSize$1147 = $solverKinematicsSize$4;
    }
   }
  }
  $355 = (($w$0164) + 1)|0;
  $exitcond = ($355|0)==($$0$i|0);
  if ($exitcond) {
   break;
  } else {
   $bodiesToSleepSize$0173 = $bodiesToSleepSize$1$lcssa;$bodiesToWakeSize$0174 = $bodiesToWakeSize$1$lcssa;$islandIndicesSecondPassSize$0165 = $islandIndicesSecondPassSize$1$lcssa;$islandIndicesSize$0166 = $islandIndicesSize$1$lcssa;$npContactManagersSize$0172 = $npContactManagersSize$1$lcssa;$solverArticulationsSize$0169 = $solverArticulationsSize$1$lcssa;$solverBodiesSize$0170 = $solverBodiesSize$1$lcssa;$solverConstraintsSize$0167 = $solverConstraintsSize$1$lcssa;$solverContactManagersSize$0168 = $solverContactManagersSize$1$lcssa;$solverKinematicsSize$0171 = $solverKinematicsSize$1$lcssa;$w$0164 = $355;
  }
 }
 $356 = HEAP32[$42>>2]|0;
 $357 = (($356) + ($islandIndicesSize$1$lcssa<<4)|0);
 HEAP32[$357>>2] = $solverBodiesSize$1$lcssa;
 $358 = ((($356) + ($islandIndicesSize$1$lcssa<<4)|0) + 4|0);
 $359 = HEAP32[$358>>2]|0;
 $360 = $solverArticulationsSize$1$lcssa & 2147483647;
 $361 = $359 & -2147483648;
 $362 = $361 | $360;
 HEAP32[$358>>2] = $362;
 $363 = HEAP32[$42>>2]|0;
 $364 = ((($363) + ($islandIndicesSize$1$lcssa<<4)|0) + 8|0);
 HEAP32[$364>>2] = $solverContactManagersSize$1$lcssa;
 $365 = ((($363) + ($islandIndicesSize$1$lcssa<<4)|0) + 12|0);
 HEAP32[$365>>2] = $solverConstraintsSize$1$lcssa;
 HEAP32[$0>>2] = $bodiesToWakeSize$1$lcssa;
 HEAP32[$1>>2] = $bodiesToSleepSize$1$lcssa;
 HEAP32[$2>>2] = $npContactManagersSize$1$lcssa;
 HEAP32[$3>>2] = $solverKinematicsSize$1$lcssa;
 HEAP32[$4>>2] = $solverBodiesSize$1$lcssa;
 HEAP32[$5>>2] = $solverArticulationsSize$1$lcssa;
 HEAP32[$6>>2] = $solverContactManagersSize$1$lcssa;
 HEAP32[$7>>2] = $solverConstraintsSize$1$lcssa;
 HEAP32[$8>>2] = $islandIndicesSize$1$lcssa;
 HEAP32[$9>>2] = $islandIndicesSecondPassSize$1$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx27updateIslandsSecondPassMainEjRNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKjjRNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerERNS_23ArticulationRootManagerERNS_33ProcessSleepingIslandsComputeDataERNS_30IslandManagerUpdateWorkBuffersEPNS0_13EventProfilerE($rigidBodyOffset,$affectedIslandsBitmap,$brokenEdges,$numBrokenEdges,$nodeManager,$edgeManager,$islands,$articulationRootManager,$psicData,$workBuffers,$profiler) {
 $rigidBodyOffset = $rigidBodyOffset|0;
 $affectedIslandsBitmap = $affectedIslandsBitmap|0;
 $brokenEdges = $brokenEdges|0;
 $numBrokenEdges = $numBrokenEdges|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $articulationRootManager = $articulationRootManager|0;
 $psicData = $psicData|0;
 $workBuffers = $workBuffers|0;
 $profiler = $profiler|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $inEnabled$not$i = 0, $inEnabled$not$i12 = 0, $inEnabled$not$i15 = 0, $inEnabled$not$i18 = 0, $inEnabled$not$i7 = 0, $inEnabled$not$i9 = 0, $or$cond$i = 0, $or$cond$i10 = 0, $or$cond$i13 = 0, $or$cond$i16 = 0, $or$cond$i19 = 0, $or$cond$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($workBuffers) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($1) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 2;
 _memset(($2|0),0,($5|0))|0;
 $6 = ($profiler|0)!=(0|0);
 if ($6) {
  $7 = HEAP8[((545872 + 2|0))>>0]|0;
  $8 = (($profiler) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $inEnabled$not$i9 = ($7<<24>>24)==(0);
  $10 = ($9|0)==(0|0);
  $or$cond$i10 = $10 | $inEnabled$not$i9;
  if (!($or$cond$i10)) {
   $11 = $profiler;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4)|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$9>>2]|0;
   $18 = (($17) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP16[545872>>1]|0;
   FUNCTION_TABLE_viiii[$19 & 511]($9,$20,$13,$16);
  }
  $21 = HEAP32[$workBuffers>>2]|0;
  __ZL28removeBrokenEdgesFromIslandsPKjjS0_jS0_RN5physx11NodeManagerERNS1_11EdgeManagerERNS1_13IslandManagerERNS1_2Cm10BitMapBaseINS1_6shdfnd9AllocatorEEE($brokenEdges,$numBrokenEdges,0,0,$21,$nodeManager,$edgeManager,$islands,$1);
  $22 = HEAP8[((545872 + 2|0))>>0]|0;
  $23 = HEAP32[$8>>2]|0;
  $inEnabled$not$i18 = ($22<<24>>24)==(0);
  $24 = ($23|0)==(0|0);
  $or$cond$i19 = $24 | $inEnabled$not$i18;
  if (!($or$cond$i19)) {
   $25 = $profiler;
   $26 = $25;
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 4)|0;
   $29 = $28;
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$23>>2]|0;
   $32 = (($31) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP16[545872>>1]|0;
   FUNCTION_TABLE_viiii[$33 & 511]($23,$34,$27,$30);
  }
  $35 = HEAP8[((545904 + 2|0))>>0]|0;
  $36 = HEAP32[$8>>2]|0;
  $inEnabled$not$i15 = ($35<<24>>24)==(0);
  $37 = ($36|0)==(0|0);
  $or$cond$i16 = $37 | $inEnabled$not$i15;
  if (!($or$cond$i16)) {
   $38 = $profiler;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = (($38) + 4)|0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = HEAP32[$36>>2]|0;
   $45 = (($44) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = HEAP16[545904>>1]|0;
   FUNCTION_TABLE_viiii[$46 & 511]($36,$47,$40,$43);
  }
  $48 = (($workBuffers) + 56|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($workBuffers) + 60|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($workBuffers) + 64|0);
  $53 = HEAP32[$52>>2]|0;
  __ZL24processBrokenEdgeIslandsRKN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEEERNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerEPjSD_SD_PS4_($1,$nodeManager,$edgeManager,$islands,$49,$51,$53,$affectedIslandsBitmap);
  $54 = HEAP8[((545904 + 2|0))>>0]|0;
  $55 = HEAP32[$8>>2]|0;
  $inEnabled$not$i12 = ($54<<24>>24)==(0);
  $56 = ($55|0)==(0|0);
  $or$cond$i13 = $56 | $inEnabled$not$i12;
  if (!($or$cond$i13)) {
   $57 = $profiler;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + 4)|0;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = HEAP32[$55>>2]|0;
   $64 = (($63) + 12|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP16[545904>>1]|0;
   FUNCTION_TABLE_viiii[$65 & 511]($55,$66,$59,$62);
  }
  if ($6) {
   $74 = HEAP8[((545912 + 2|0))>>0]|0;
   $75 = (($profiler) + 8|0);
   $76 = HEAP32[$75>>2]|0;
   $inEnabled$not$i7 = ($74<<24>>24)==(0);
   $77 = ($76|0)==(0|0);
   $or$cond$i8 = $77 | $inEnabled$not$i7;
   if (!($or$cond$i8)) {
    $78 = $profiler;
    $79 = $78;
    $80 = HEAP32[$79>>2]|0;
    $81 = (($78) + 4)|0;
    $82 = $81;
    $83 = HEAP32[$82>>2]|0;
    $84 = HEAP32[$76>>2]|0;
    $85 = (($84) + 8|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = HEAP16[545912>>1]|0;
    FUNCTION_TABLE_viiii[$86 & 511]($76,$87,$80,$83);
   }
   __ZL22processSleepingIslandsILb1EEvRKN5physx2Cm10BitMapBaseINS0_6shdfnd9AllocatorEEEjRNS0_11NodeManagerERNS0_11EdgeManagerERNS0_13IslandManagerERNS0_23ArticulationRootManagerERNS0_33ProcessSleepingIslandsComputeDataE($affectedIslandsBitmap,$rigidBodyOffset,$nodeManager,$edgeManager,$islands,$articulationRootManager,$psicData);
   $88 = HEAP8[((545912 + 2|0))>>0]|0;
   $89 = HEAP32[$75>>2]|0;
   $inEnabled$not$i = ($88<<24>>24)==(0);
   $90 = ($89|0)==(0|0);
   $or$cond$i = $90 | $inEnabled$not$i;
   if ($or$cond$i) {
    STACKTOP = sp;return;
   }
   $91 = $profiler;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   $94 = (($91) + 4)|0;
   $95 = $94;
   $96 = HEAP32[$95>>2]|0;
   $97 = HEAP32[$89>>2]|0;
   $98 = (($97) + 12|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = HEAP16[545912>>1]|0;
   FUNCTION_TABLE_viiii[$99 & 511]($89,$100,$93,$96);
   STACKTOP = sp;return;
  }
 } else {
  $67 = HEAP32[$workBuffers>>2]|0;
  __ZL28removeBrokenEdgesFromIslandsPKjjS0_jS0_RN5physx11NodeManagerERNS1_11EdgeManagerERNS1_13IslandManagerERNS1_2Cm10BitMapBaseINS1_6shdfnd9AllocatorEEE($brokenEdges,$numBrokenEdges,0,0,$67,$nodeManager,$edgeManager,$islands,$1);
  $68 = (($workBuffers) + 56|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($workBuffers) + 60|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($workBuffers) + 64|0);
  $73 = HEAP32[$72>>2]|0;
  __ZL24processBrokenEdgeIslandsRKN5physx2Cm10BitMapBaseINS_6shdfnd9AllocatorEEERNS_11NodeManagerERNS_11EdgeManagerERNS_13IslandManagerEPjSD_SD_PS4_($1,$nodeManager,$edgeManager,$islands,$69,$71,$73,$affectedIslandsBitmap);
 }
 __ZL22processSleepingIslandsILb1EEvRKN5physx2Cm10BitMapBaseINS0_6shdfnd9AllocatorEEEjRNS0_11NodeManagerERNS0_11EdgeManagerERNS0_13IslandManagerERNS0_23ArticulationRootManagerERNS0_33ProcessSleepingIslandsComputeDataE($affectedIslandsBitmap,$rigidBodyOffset,$nodeManager,$edgeManager,$islands,$articulationRootManager,$psicData);
 STACKTOP = sp;return;
}
function __ZL22processSleepingIslandsILb1EEvRKN5physx2Cm10BitMapBaseINS0_6shdfnd9AllocatorEEEjRNS0_11NodeManagerERNS0_11EdgeManagerERNS0_13IslandManagerERNS0_23ArticulationRootManagerERNS0_33ProcessSleepingIslandsComputeDataE($islandsToUpdate,$rigidBodyOffset,$nodeManager,$edgeManager,$islands,$articulationRootManager,$psicData) {
 $islandsToUpdate = $islandsToUpdate|0;
 $rigidBodyOffset = $rigidBodyOffset|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $articulationRootManager = $articulationRootManager|0;
 $psicData = $psicData|0;
 var $$0$i = 0, $$not = 0, $$not8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$074 = 0, $bodiesToSleepSize$099 = 0, $bodiesToSleepSize$1$lcssa = 0, $bodiesToSleepSize$181 = 0, $bodiesToSleepSize$2$ph$be = 0, $bodiesToSleepSize$2$ph70 = 0, $bodiesToSleepSize$4 = 0, $body1$0 = 0, $body2$0 = 0, $brmerge = 0, $brmerge10 = 0, $exitcond = 0, $hasStaticContact$0$off0 = 0, $hasStaticContact$0$off0$ph = 0, $hasStaticContact$0$off0$ph32 = 0;
 var $hasStaticContact$1$off0 = 0, $hasStaticContact$2$off0 = 0, $i$0$i = 0, $islandFlags$013 = 0, $islandIndicesSize$093 = 0, $islandIndicesSize$1$lcssa = 0, $islandIndicesSize$175 = 0, $islandIndicesSize$2 = 0, $nextEdgeId$0 = 0, $nextEdgeId$0$in = 0, $nextEdgeId$0$in$ph = 0, $nextEdgeId$0$in$ph33 = 0, $nextNode$0 = 0, $nextNode$059 = 0, $nextNode$05972 = 0, $nextNode$060 = 0, $nextNode0$0 = 0, $nextNode0$012 = 0, $nextNode0$014 = 0, $nextNode2$0 = 0;
 var $nextNode2$0$in = 0, $nextNode2$0$in$ph = 0, $nextNode2$0$in$ph16 = 0, $nextNode2$0$in$ph20 = 0, $node1IsKineOrStatic$0$off0 = 0, $node1Type$0 = 0, $node2IsKineOrStatic$0$off0 = 0, $node2IsKineOrStatic$0$off0$ = 0, $node2IsKineOrStatic$0$off0$$not = 0, $node2Type$0 = 0, $phitmp = 0, $phitmp103 = 0, $phitmp104 = 0, $phitmp11 = 0, $phitmp147 = 0, $phitmp7 = 0, $solverArticulationsSize$096 = 0, $solverArticulationsSize$1$lcssa = 0, $solverArticulationsSize$178 = 0, $solverArticulationsSize$2$ph = 0;
 var $solverArticulationsSize$4 = 0, $solverBodiesSize$097 = 0, $solverBodiesSize$1$lcssa = 0, $solverBodiesSize$179 = 0, $solverBodiesSize$2$ph = 0, $solverBodiesSize$2$ph17 = 0, $solverBodiesSize$4 = 0, $solverConstraintsSize$094 = 0, $solverConstraintsSize$1$lcssa = 0, $solverConstraintsSize$176 = 0, $solverConstraintsSize$2$ph = 0, $solverConstraintsSize$4 = 0, $solverContactManagersSize$095 = 0, $solverContactManagersSize$1$lcssa = 0, $solverContactManagersSize$177 = 0, $solverContactManagersSize$2$ph = 0, $solverContactManagersSize$2$ph34 = 0, $solverContactManagersSize$4 = 0, $solverKinematicsSize$098 = 0, $solverKinematicsSize$1$lcssa = 0;
 var $solverKinematicsSize$180 = 0, $solverKinematicsSize$2$ph = 0, $solverKinematicsSize$2$ph18 = 0, $solverKinematicsSize$2$ph21 = 0, $solverKinematicsSize$4 = 0, $w$092 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($psicData) + 12|0);
 HEAP32[$0>>2] = 0;
 $1 = (($psicData) + 16|0);
 HEAP32[$1>>2] = 0;
 $2 = (($nodeManager) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($nodeManager) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($edgeManager) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($edgeManager) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($articulationRootManager) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($islands) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($psicData) + 36|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($psicData) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($psicData) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($psicData) + 44|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($psicData) + 56|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($psicData) + 68|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($psicData) + 72|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($psicData) + 84|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($psicData) + 96|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($psicData) + 108|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($psicData) + 48|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($psicData) + 60|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($psicData) + 76|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($psicData) + 88|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($psicData) + 100|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($psicData) + 112|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($psicData) + 120|0);
 $47 = HEAP32[$islandsToUpdate>>2]|0;
 $48 = (($islandsToUpdate) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49 & 2147483647;
 $i$0$i = $50;
 while(1) {
  $51 = (($i$0$i) + -1)|0;
  $52 = ($i$0$i|0)==(0);
  if ($52) {
   $$0$i = 1;
   break;
  }
  $53 = (($47) + ($51<<2)|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0);
  if ($55) {
   $i$0$i = $51;
  } else {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $56 = $51 << 5;
  $57 = $54 >>> 1;
  $58 = $57 | $54;
  $59 = $58 >>> 2;
  $60 = $59 | $58;
  $61 = $60 >>> 4;
  $62 = $61 | $60;
  $63 = $62 >>> 8;
  $64 = $63 | $62;
  $65 = $64 >>> 16;
  $66 = $65 | $64;
  $67 = Math_imul($66, 130329821)|0;
  $68 = $67 >>> 27;
  $69 = (482344 + ($68<<2)|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($70) + ($56))|0;
  $phitmp = $71 >>> 5;
  $phitmp147 = (($phitmp) + 1)|0;
  $$0$i = $phitmp147;
 }
 $72 = (($19) + -1)|0;
 $bodiesToSleepSize$099 = 0;$islandIndicesSize$093 = $45;$solverArticulationsSize$096 = $39;$solverBodiesSize$097 = $37;$solverConstraintsSize$094 = $43;$solverContactManagersSize$095 = $41;$solverKinematicsSize$098 = $35;$w$092 = 0;
 while(1) {
  $73 = (($47) + ($w$092<<2)|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74|0)==(0);
  if ($75) {
   $bodiesToSleepSize$1$lcssa = $bodiesToSleepSize$099;$islandIndicesSize$1$lcssa = $islandIndicesSize$093;$solverArticulationsSize$1$lcssa = $solverArticulationsSize$096;$solverBodiesSize$1$lcssa = $solverBodiesSize$097;$solverConstraintsSize$1$lcssa = $solverConstraintsSize$094;$solverContactManagersSize$1$lcssa = $solverContactManagersSize$095;$solverKinematicsSize$1$lcssa = $solverKinematicsSize$098;
  } else {
   $76 = $w$092 << 5;
   $b$074 = $74;$bodiesToSleepSize$181 = $bodiesToSleepSize$099;$islandIndicesSize$175 = $islandIndicesSize$093;$solverArticulationsSize$178 = $solverArticulationsSize$096;$solverBodiesSize$179 = $solverBodiesSize$097;$solverConstraintsSize$176 = $solverConstraintsSize$094;$solverContactManagersSize$177 = $solverContactManagersSize$095;$solverKinematicsSize$180 = $solverKinematicsSize$098;
   while(1) {
    $77 = (0 - ($b$074))|0;
    $78 = $b$074 & $77;
    $79 = Math_imul($78, 125613361)|0;
    $80 = $79 >>> 27;
    $81 = (412480 + ($80<<2)|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = $82 | $76;
    $84 = (($13) + ($83<<4)|0);
    $nextNode0$012 = HEAP32[$84>>2]|0;
    $85 = ($nextNode0$012|0)==(-1);
    L13: do {
     if ($85) {
      $bodiesToSleepSize$4 = $bodiesToSleepSize$181;$islandIndicesSize$2 = $islandIndicesSize$175;$solverArticulationsSize$4 = $solverArticulationsSize$178;$solverBodiesSize$4 = $solverBodiesSize$179;$solverConstraintsSize$4 = $solverConstraintsSize$176;$solverContactManagersSize$4 = $solverContactManagersSize$177;$solverKinematicsSize$4 = $solverKinematicsSize$180;
     } else {
      $islandFlags$013 = 0;$nextNode0$014 = $nextNode0$012;
      while(1) {
       $86 = ((($3) + (($nextNode0$014*12)|0)|0) + 8|0);
       $87 = HEAP8[$86>>0]|0;
       $88 = $87&255;
       $89 = $88 | $islandFlags$013;
       $90 = (($5) + ($nextNode0$014<<2)|0);
       $nextNode0$0 = HEAP32[$90>>2]|0;
       $91 = ($nextNode0$0|0)==(-1);
       if ($91) {
        break;
       } else {
        $islandFlags$013 = $89;$nextNode0$014 = $nextNode0$0;
       }
      }
      $phitmp103 = $89 & 8;
      $phitmp104 = ($phitmp103|0)==(0);
      if ($phitmp104) {
       if ($85) {
        $bodiesToSleepSize$4 = $bodiesToSleepSize$181;$islandIndicesSize$2 = $islandIndicesSize$175;$solverArticulationsSize$4 = $solverArticulationsSize$178;$solverBodiesSize$4 = $solverBodiesSize$179;$solverConstraintsSize$4 = $solverConstraintsSize$176;$solverContactManagersSize$4 = $solverContactManagersSize$177;$solverKinematicsSize$4 = $solverKinematicsSize$180;
        break;
       } else {
        $bodiesToSleepSize$2$ph70 = $bodiesToSleepSize$181;$nextNode$05972 = $nextNode0$012;
       }
       while(1) {
        $nextNode$060 = $nextNode$05972;
        while(1) {
         $92 = (($3) + (($nextNode$060*12)|0)|0);
         $93 = (($5) + ($nextNode$060<<2)|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = (($3) + (($94*12)|0)|0);
         $96 = $95;
         $97 = (($96) + 128)|0;
         $98 = $97 & -128;
         $99 = $98;
         $100 = ((($3) + (($nextNode$060*12)|0)|0) + 8|0);
         $101 = HEAP8[$100>>0]|0;
         $102 = $101 & 2;
         $103 = ($102<<24>>24)==(0);
         if ($103) {
          $104 = $101 & 1;
          $105 = ($104<<24>>24)==(0);
          if ($105) {
           label = 16;
           break;
          }
         } else {
          $119 = $101 & 4;
          $120 = ($119<<24>>24)==(0);
          if (!($120)) {
           label = 18;
           break;
          }
         }
         $nextNode$0 = HEAP32[$93>>2]|0;
         $106 = ($nextNode$0|0)==(-1);
         if ($106) {
          $bodiesToSleepSize$4 = $bodiesToSleepSize$2$ph70;$islandIndicesSize$2 = $islandIndicesSize$175;$solverArticulationsSize$4 = $solverArticulationsSize$178;$solverBodiesSize$4 = $solverBodiesSize$179;$solverConstraintsSize$4 = $solverConstraintsSize$176;$solverContactManagersSize$4 = $solverContactManagersSize$177;$solverKinematicsSize$4 = $solverKinematicsSize$180;
          break L13;
         } else {
          $nextNode$060 = $nextNode$0;
         }
        }
        if ((label|0) == 16) {
         label = 0;
         $107 = $101&255;
         $108 = $107 | 16;
         $109 = $108&255;
         HEAP8[$100>>0] = $109;
         $110 = HEAP32[$92>>2]|0;
         $111 = (($72) - ($bodiesToSleepSize$2$ph70))|0;
         $112 = (($17) + ($111<<2)|0);
         HEAP32[$112>>2] = $110;
         $113 = (($111) + -1)|0;
         $114 = (($17) + ($113<<2)|0);
         $115 = $114;
         $116 = (($115) + 128)|0;
         $117 = $116 & -128;
         $118 = $117;
        }
        else if ((label|0) == 18) {
         label = 0;
         $121 = $101&255;
         $122 = $121 | 16;
         $123 = $122&255;
         HEAP8[$100>>0] = $123;
         $124 = HEAP32[$92>>2]|0;
         $125 = ((($11) + ($124<<3)|0) + 4|0);
         $126 = HEAP32[$125>>2]|0;
         $127 = $126;
         $128 = $127 | 1;
         $129 = $128;
         $130 = (($72) - ($bodiesToSleepSize$2$ph70))|0;
         $131 = (($17) + ($130<<2)|0);
         HEAP32[$131>>2] = $129;
         $132 = (($130) + -1)|0;
         $133 = (($17) + ($132<<2)|0);
         $134 = $133;
         $135 = (($134) + 128)|0;
         $136 = $135 & -128;
         $137 = $136;
        }
        $bodiesToSleepSize$2$ph$be = (($bodiesToSleepSize$2$ph70) + 1)|0;
        $nextNode$059 = HEAP32[$93>>2]|0;
        $138 = ($nextNode$059|0)==(-1);
        if ($138) {
         $bodiesToSleepSize$4 = $bodiesToSleepSize$2$ph$be;$islandIndicesSize$2 = $islandIndicesSize$175;$solverArticulationsSize$4 = $solverArticulationsSize$178;$solverBodiesSize$4 = $solverBodiesSize$179;$solverConstraintsSize$4 = $solverConstraintsSize$176;$solverContactManagersSize$4 = $solverContactManagersSize$177;$solverKinematicsSize$4 = $solverKinematicsSize$180;
         break L13;
        } else {
         $bodiesToSleepSize$2$ph70 = $bodiesToSleepSize$2$ph$be;$nextNode$05972 = $nextNode$059;
        }
       }
      }
      $139 = ((($33) + ($islandIndicesSize$175<<4)|0) + 4|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = $solverArticulationsSize$178 & 2147483647;
      $142 = $140 & -2147483648;
      $143 = $142 | $141;
      HEAP32[$139>>2] = $143;
      $144 = (($33) + ($islandIndicesSize$175<<4)|0);
      HEAP32[$144>>2] = $solverBodiesSize$179;
      $145 = ((($33) + ($islandIndicesSize$175<<4)|0) + 8|0);
      HEAP32[$145>>2] = $solverContactManagersSize$177;
      $146 = ((($33) + ($islandIndicesSize$175<<4)|0) + 12|0);
      HEAP32[$146>>2] = $solverConstraintsSize$176;
      $147 = (($islandIndicesSize$175) + 1)|0;
      $148 = (($33) + ($147<<4)|0);
      $149 = $148;
      $150 = (($149) + 128)|0;
      $151 = $150 & -128;
      $152 = $151;
      $nextNode2$0$in$ph = $84;$solverArticulationsSize$2$ph = $solverArticulationsSize$178;$solverBodiesSize$2$ph = $solverBodiesSize$179;$solverKinematicsSize$2$ph = $solverKinematicsSize$180;
      L32: while(1) {
       $nextNode2$0$in$ph16 = $nextNode2$0$in$ph;$solverBodiesSize$2$ph17 = $solverBodiesSize$2$ph;$solverKinematicsSize$2$ph18 = $solverKinematicsSize$2$ph;
       L34: while(1) {
        $nextNode2$0$in$ph20 = $nextNode2$0$in$ph16;$solverKinematicsSize$2$ph21 = $solverKinematicsSize$2$ph18;
        L36: while(1) {
         $nextNode2$0$in = $nextNode2$0$in$ph20;
         while(1) {
          $nextNode2$0 = HEAP32[$nextNode2$0$in>>2]|0;
          $153 = ($nextNode2$0|0)==(-1);
          if ($153) {
           break L32;
          }
          $154 = (($3) + (($nextNode2$0*12)|0)|0);
          $155 = (($5) + ($nextNode2$0<<2)|0);
          $156 = HEAP32[$155>>2]|0;
          $157 = (($3) + (($156*12)|0)|0);
          $158 = $157;
          $159 = (($158) + 128)|0;
          $160 = $159 & -128;
          $161 = $160;
          $162 = ((($3) + (($nextNode2$0*12)|0)|0) + 8|0);
          $163 = HEAP8[$162>>0]|0;
          $164 = $163 & 1;
          $165 = ($164<<24>>24)==(0);
          if (!($165)) {
           break;
          }
          $166 = $163 & 2;
          $167 = ($166<<24>>24)==(0);
          if ($167) {
           break L36;
          }
          $178 = $163 & 4;
          $179 = ($178<<24>>24)==(0);
          if ($179) {
           $nextNode2$0$in = $155;
          } else {
           break L34;
          }
         }
         $200 = (($15) + ($nextNode2$0<<2)|0);
         HEAP32[$200>>2] = $solverKinematicsSize$2$ph21;
         $201 = HEAP32[$154>>2]|0;
         $202 = (($201) + ($rigidBodyOffset)|0);
         $203 = (($21) + ($solverKinematicsSize$2$ph21<<2)|0);
         HEAP32[$203>>2] = $202;
         $204 = (($solverKinematicsSize$2$ph21) + 1)|0;
         $205 = (($21) + ($204<<2)|0);
         $206 = $205;
         $207 = (($206) + 128)|0;
         $208 = $207 & -128;
         $209 = $208;
         $nextNode2$0$in$ph20 = $155;$solverKinematicsSize$2$ph21 = $204;
        }
        $168 = (($15) + ($nextNode2$0<<2)|0);
        HEAP32[$168>>2] = $solverBodiesSize$2$ph17;
        $169 = HEAP32[$154>>2]|0;
        $170 = (($169) + ($rigidBodyOffset)|0);
        $171 = (($23) + ($solverBodiesSize$2$ph17<<2)|0);
        HEAP32[$171>>2] = $170;
        $172 = (($solverBodiesSize$2$ph17) + 1)|0;
        $173 = (($23) + ($172<<2)|0);
        $174 = $173;
        $175 = (($174) + 128)|0;
        $176 = $175 & -128;
        $177 = $176;
        $nextNode2$0$in$ph16 = $155;$solverBodiesSize$2$ph17 = $172;$solverKinematicsSize$2$ph18 = $solverKinematicsSize$2$ph21;
       }
       $180 = HEAP32[$154>>2]|0;
       $181 = (($11) + ($180<<3)|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = ((($11) + ($180<<3)|0) + 4|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = $182 & -64;
       $186 = $185;
       $187 = (($25) + ($solverArticulationsSize$2$ph<<2)|0);
       HEAP32[$187>>2] = $186;
       $188 = (($27) + ($solverArticulationsSize$2$ph<<2)|0);
       HEAP32[$188>>2] = $184;
       $189 = (($solverArticulationsSize$2$ph) + 1)|0;
       $190 = (($25) + ($189<<2)|0);
       $191 = $190;
       $192 = (($191) + 128)|0;
       $193 = $192 & -128;
       $194 = $193;
       $195 = (($27) + ($189<<2)|0);
       $196 = $195;
       $197 = (($196) + 128)|0;
       $198 = $197 & -128;
       $199 = $198;
       $nextNode2$0$in$ph = $155;$solverArticulationsSize$2$ph = $189;$solverBodiesSize$2$ph = $solverBodiesSize$2$ph17;$solverKinematicsSize$2$ph = $solverKinematicsSize$2$ph21;
      }
      $210 = ((($13) + ($83<<4)|0) + 4|0);
      $hasStaticContact$0$off0$ph = 0;$nextEdgeId$0$in$ph = $210;$solverConstraintsSize$2$ph = $solverConstraintsSize$176;$solverContactManagersSize$2$ph = $solverContactManagersSize$177;
      L47: while(1) {
       $hasStaticContact$0$off0$ph32 = $hasStaticContact$0$off0$ph;$nextEdgeId$0$in$ph33 = $nextEdgeId$0$in$ph;$solverContactManagersSize$2$ph34 = $solverContactManagersSize$2$ph;
       L49: while(1) {
        $hasStaticContact$0$off0 = $hasStaticContact$0$off0$ph32;$nextEdgeId$0$in = $nextEdgeId$0$in$ph33;
        while(1) {
         $nextEdgeId$0 = HEAP32[$nextEdgeId$0$in>>2]|0;
         $211 = ($nextEdgeId$0|0)==(-1);
         if ($211) {
          break L47;
         }
         $212 = (($9) + ($nextEdgeId$0<<2)|0);
         $213 = HEAP32[$212>>2]|0;
         $214 = (($7) + (($213*12)|0)|0);
         $215 = $214;
         $216 = (($215) + 128)|0;
         $217 = $216 & -128;
         $218 = $217;
         $219 = (($7) + (($nextEdgeId$0*12)|0)|0);
         $220 = HEAP32[$219>>2]|0;
         $221 = ((($7) + (($nextEdgeId$0*12)|0)|0) + 4|0);
         $222 = HEAP32[$221>>2]|0;
         $223 = ($220|0)==(-1);
         do {
          if ($223) {
           $body1$0 = -1;$hasStaticContact$1$off0 = 1;$node1IsKineOrStatic$0$off0 = 0;$node1Type$0 = 3;
          } else {
           $224 = ((($3) + (($220*12)|0)|0) + 8|0);
           $225 = HEAP8[$224>>0]|0;
           $226 = $225 & 2;
           $227 = ($226<<24>>24)==(0);
           if ($227) {
            $228 = $225 & 1;
            $229 = (($15) + ($220<<2)|0);
            $230 = HEAP32[$229>>2]|0;
            $phitmp11 = ($228<<24>>24)==(0);
            $body1$0 = $230;$hasStaticContact$1$off0 = $hasStaticContact$0$off0;$node1IsKineOrStatic$0$off0 = $phitmp11;$node1Type$0 = $228;
            break;
           }
           $231 = (($3) + (($220*12)|0)|0);
           $232 = $225 & 4;
           $233 = ($232<<24>>24)==(0);
           $234 = HEAP32[$231>>2]|0;
           if ($233) {
            $body1$0 = $234;$hasStaticContact$1$off0 = $hasStaticContact$0$off0;$node1IsKineOrStatic$0$off0 = 1;$node1Type$0 = 2;
           } else {
            $235 = (($11) + ($234<<3)|0);
            $236 = HEAP32[$235>>2]|0;
            $body1$0 = $236;$hasStaticContact$1$off0 = $hasStaticContact$0$off0;$node1IsKineOrStatic$0$off0 = 1;$node1Type$0 = 2;
           }
          }
         } while(0);
         $237 = ($222|0)==(-1);
         do {
          if ($237) {
           $body2$0 = -1;$hasStaticContact$2$off0 = 1;$node2IsKineOrStatic$0$off0 = 0;$node2Type$0 = 3;
          } else {
           $238 = ((($3) + (($222*12)|0)|0) + 8|0);
           $239 = HEAP8[$238>>0]|0;
           $240 = $239 & 2;
           $241 = ($240<<24>>24)==(0);
           if ($241) {
            $242 = $239 & 1;
            $243 = (($15) + ($222<<2)|0);
            $244 = HEAP32[$243>>2]|0;
            $phitmp7 = ($242<<24>>24)==(0);
            $body2$0 = $244;$hasStaticContact$2$off0 = $hasStaticContact$1$off0;$node2IsKineOrStatic$0$off0 = $phitmp7;$node2Type$0 = $242;
            break;
           }
           $245 = (($3) + (($222*12)|0)|0);
           $246 = $239 & 4;
           $247 = ($246<<24>>24)==(0);
           $248 = HEAP32[$245>>2]|0;
           if ($247) {
            $body2$0 = $248;$hasStaticContact$2$off0 = $hasStaticContact$1$off0;$node2IsKineOrStatic$0$off0 = 1;$node2Type$0 = 2;
           } else {
            $249 = (($11) + ($248<<3)|0);
            $250 = HEAP32[$249>>2]|0;
            $body2$0 = $250;$hasStaticContact$2$off0 = $hasStaticContact$1$off0;$node2IsKineOrStatic$0$off0 = 1;$node2Type$0 = 2;
           }
          }
         } while(0);
         $node2IsKineOrStatic$0$off0$ = $node2IsKineOrStatic$0$off0 | $node1IsKineOrStatic$0$off0;
         $251 = ((($7) + (($nextEdgeId$0*12)|0)|0) + 8|0);
         $252 = HEAP32[$251>>2]|0;
         $253 = $252;
         $254 = $253 & 3;
         $$not = ($254|0)!=(0);
         $node2IsKineOrStatic$0$off0$$not = $node2IsKineOrStatic$0$off0$ ^ 1;
         $brmerge = $$not | $node2IsKineOrStatic$0$off0$$not;
         if (!($brmerge)) {
          break;
         }
         $268 = $253 & 1;
         $$not8 = ($268|0)==(0);
         $brmerge10 = $$not8 | $node2IsKineOrStatic$0$off0$$not;
         if ($brmerge10) {
          $hasStaticContact$0$off0 = $hasStaticContact$2$off0;$nextEdgeId$0$in = $212;
         } else {
          break L49;
         }
        }
        $255 = $253 & -16;
        $256 = $255;
        $257 = ((($29) + ($solverContactManagersSize$2$ph34<<4)|0) + 12|0);
        HEAP32[$257>>2] = $256;
        $258 = ((($29) + ($solverContactManagersSize$2$ph34<<4)|0) + 8|0);
        HEAP8[$258>>0] = $node1Type$0;
        $259 = ((($29) + ($solverContactManagersSize$2$ph34<<4)|0) + 9|0);
        HEAP8[$259>>0] = $node2Type$0;
        $260 = (($29) + ($solverContactManagersSize$2$ph34<<4)|0);
        HEAP32[$260>>2] = $body1$0;
        $261 = ((($29) + ($solverContactManagersSize$2$ph34<<4)|0) + 4|0);
        HEAP32[$261>>2] = $body2$0;
        $262 = (($solverContactManagersSize$2$ph34) + 1)|0;
        $263 = (($29) + ($262<<4)|0);
        $264 = $263;
        $265 = (($264) + 128)|0;
        $266 = $265 & -128;
        $267 = $266;
        $hasStaticContact$0$off0$ph32 = $hasStaticContact$2$off0;$nextEdgeId$0$in$ph33 = $212;$solverContactManagersSize$2$ph34 = $262;
       }
       $269 = $252;
       $270 = $269 & -16;
       $271 = $270;
       $272 = ((($31) + ($solverConstraintsSize$2$ph<<4)|0) + 12|0);
       HEAP32[$272>>2] = $271;
       $273 = ((($31) + ($solverConstraintsSize$2$ph<<4)|0) + 8|0);
       HEAP8[$273>>0] = $node1Type$0;
       $274 = ((($31) + ($solverConstraintsSize$2$ph<<4)|0) + 9|0);
       HEAP8[$274>>0] = $node2Type$0;
       $275 = (($31) + ($solverConstraintsSize$2$ph<<4)|0);
       HEAP32[$275>>2] = $body1$0;
       $276 = ((($31) + ($solverConstraintsSize$2$ph<<4)|0) + 4|0);
       HEAP32[$276>>2] = $body2$0;
       $277 = (($solverConstraintsSize$2$ph) + 1)|0;
       $278 = (($31) + ($277<<4)|0);
       $279 = $278;
       $280 = (($279) + 128)|0;
       $281 = $280 & -128;
       $282 = $281;
       $hasStaticContact$0$off0$ph = $hasStaticContact$2$off0;$nextEdgeId$0$in$ph = $212;$solverConstraintsSize$2$ph = $277;$solverContactManagersSize$2$ph = $solverContactManagersSize$2$ph34;
      }
      $283 = $hasStaticContact$0$off0&1;
      $284 = HEAP32[$139>>2]|0;
      $285 = $283 << 31;
      $286 = $284 & 2147483647;
      $287 = $286 | $285;
      HEAP32[$139>>2] = $287;
      $bodiesToSleepSize$4 = $bodiesToSleepSize$181;$islandIndicesSize$2 = $147;$solverArticulationsSize$4 = $solverArticulationsSize$2$ph;$solverBodiesSize$4 = $solverBodiesSize$2$ph17;$solverConstraintsSize$4 = $solverConstraintsSize$2$ph;$solverContactManagersSize$4 = $solverContactManagersSize$2$ph34;$solverKinematicsSize$4 = $solverKinematicsSize$2$ph21;
     }
    } while(0);
    $288 = (($b$074) + -1)|0;
    $289 = $288 & $b$074;
    $290 = ($289|0)==(0);
    if ($290) {
     $bodiesToSleepSize$1$lcssa = $bodiesToSleepSize$4;$islandIndicesSize$1$lcssa = $islandIndicesSize$2;$solverArticulationsSize$1$lcssa = $solverArticulationsSize$4;$solverBodiesSize$1$lcssa = $solverBodiesSize$4;$solverConstraintsSize$1$lcssa = $solverConstraintsSize$4;$solverContactManagersSize$1$lcssa = $solverContactManagersSize$4;$solverKinematicsSize$1$lcssa = $solverKinematicsSize$4;
     break;
    } else {
     $b$074 = $289;$bodiesToSleepSize$181 = $bodiesToSleepSize$4;$islandIndicesSize$175 = $islandIndicesSize$2;$solverArticulationsSize$178 = $solverArticulationsSize$4;$solverBodiesSize$179 = $solverBodiesSize$4;$solverConstraintsSize$176 = $solverConstraintsSize$4;$solverContactManagersSize$177 = $solverContactManagersSize$4;$solverKinematicsSize$180 = $solverKinematicsSize$4;
    }
   }
  }
  $291 = (($w$092) + 1)|0;
  $exitcond = ($291|0)==($$0$i|0);
  if ($exitcond) {
   break;
  } else {
   $bodiesToSleepSize$099 = $bodiesToSleepSize$1$lcssa;$islandIndicesSize$093 = $islandIndicesSize$1$lcssa;$solverArticulationsSize$096 = $solverArticulationsSize$1$lcssa;$solverBodiesSize$097 = $solverBodiesSize$1$lcssa;$solverConstraintsSize$094 = $solverConstraintsSize$1$lcssa;$solverContactManagersSize$095 = $solverContactManagersSize$1$lcssa;$solverKinematicsSize$098 = $solverKinematicsSize$1$lcssa;$w$092 = $291;
  }
 }
 $292 = HEAP32[$32>>2]|0;
 $293 = (($292) + ($islandIndicesSize$1$lcssa<<4)|0);
 HEAP32[$293>>2] = $solverBodiesSize$1$lcssa;
 $294 = ((($292) + ($islandIndicesSize$1$lcssa<<4)|0) + 4|0);
 $295 = HEAP32[$294>>2]|0;
 $296 = $solverArticulationsSize$1$lcssa & 2147483647;
 $297 = $295 & -2147483648;
 $298 = $297 | $296;
 HEAP32[$294>>2] = $298;
 $299 = HEAP32[$32>>2]|0;
 $300 = ((($299) + ($islandIndicesSize$1$lcssa<<4)|0) + 8|0);
 HEAP32[$300>>2] = $solverContactManagersSize$1$lcssa;
 $301 = ((($299) + ($islandIndicesSize$1$lcssa<<4)|0) + 12|0);
 HEAP32[$301>>2] = $solverConstraintsSize$1$lcssa;
 HEAP32[$1>>2] = $bodiesToSleepSize$1$lcssa;
 HEAP32[$34>>2] = $solverKinematicsSize$1$lcssa;
 HEAP32[$36>>2] = $solverBodiesSize$1$lcssa;
 HEAP32[$38>>2] = $solverArticulationsSize$1$lcssa;
 HEAP32[$40>>2] = $solverContactManagersSize$1$lcssa;
 HEAP32[$42>>2] = $solverConstraintsSize$1$lcssa;
 HEAP32[$44>>2] = $islandIndicesSize$1$lcssa;
 HEAP32[$46>>2] = 0;
 STACKTOP = sp;return;
}
function __ZL25processBrokenEdgeIslands2PKjjRN5physx11NodeManagerERNS1_11EdgeManagerERNS1_13IslandManagerEPjS8_S8_PNS1_2Cm10BitMapBaseINS1_6shdfnd9AllocatorEEE($islandsToUpdate,$numIslandsToUpdate,$nodeManager,$edgeManager,$islands,$graphNextNodes,$graphStartIslands,$graphNextIslands,$affectedIslandsBitmap) {
 $islandsToUpdate = $islandsToUpdate|0;
 $numIslandsToUpdate = $numIslandsToUpdate|0;
 $nodeManager = $nodeManager|0;
 $edgeManager = $edgeManager|0;
 $islands = $islands|0;
 $graphNextNodes = $graphNextNodes|0;
 $graphStartIslands = $graphStartIslands|0;
 $graphNextIslands = $graphNextIslands|0;
 $affectedIslandsBitmap = $affectedIslandsBitmap|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $depth1$07 = 0, $depth1$1 = 0, $depth2$012 = 0, $edgeId$$i = 0, $edgeId$$i2 = 0, $exitcond = 0, $i$034 = 0, $islandId$0$lcssa = 0, $islandId1$1 = 0, $nextEdge$018 = 0, $nextEdge$131 = 0, $nextIsland$0 = 0, $nextIsland$06 = 0, $nextIsland$08 = 0, $nextIsland1$0 = 0, $nextIsland1$011 = 0;
 var $nextIsland1$013 = 0, $nextIsland2$020 = 0, $nextNode$05 = 0, $nextNode$126 = 0, $nextNode$229 = 0, $nextNode$229$us = 0, $nodeId$$i = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($nodeManager) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($edgeManager) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($nodeManager) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($edgeManager) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($islands) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 << 2;
 _memset(($graphNextNodes|0),-1,($10|0))|0;
 $11 = HEAP32[$8>>2]|0;
 $12 = $11 << 2;
 _memset(($graphStartIslands|0),-1,($12|0))|0;
 $13 = HEAP32[$8>>2]|0;
 $14 = $13 << 2;
 _memset(($graphNextIslands|0),-1,($14|0))|0;
 $15 = ($numIslandsToUpdate|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($islands) + 4|0);
 $17 = (($islands) + 16|0);
 $18 = (($islands) + 8|0);
 $19 = (($islands) + 20|0);
 $20 = ($affectedIslandsBitmap|0)==(0|0);
 $i$034 = 0;
 while(1) {
  $21 = (($islandsToUpdate) + ($i$034<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$16>>2]|0;
  $24 = (($23) + ($22<<4)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($23) + ($22<<4)|0) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($23) + ($22<<4)|0);
  ;HEAP32[$28+0>>2]=4294967295|0;HEAP32[$28+4>>2]=4294967295|0;HEAP32[$28+8>>2]=4294967295|0;HEAP32[$28+12>>2]=4294967295|0;
  $29 = HEAP32[$17>>2]|0;
  $30 = HEAP32[$18>>2]|0;
  $31 = (($30) + ($22<<2)|0);
  HEAP32[$31>>2] = $29;
  HEAP32[$17>>2] = $22;
  $32 = $22 & 31;
  $33 = 1 << $32;
  $34 = $33 ^ -1;
  $35 = $22 >>> 5;
  $36 = HEAP32[$19>>2]|0;
  $37 = (($36) + ($35<<2)|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38 & $34;
  HEAP32[$37>>2] = $39;
  $40 = ($25|0)==(-1);
  L6: do {
   if (!($40)) {
    $43 = $30;$nextNode$05 = $25;
    while(1) {
     $41 = HEAP32[$17>>2]|0;
     $42 = (($43) + ($41<<2)|0);
     $44 = HEAP32[$42>>2]|0;
     HEAP32[$17>>2] = $44;
     HEAP32[$42>>2] = -1;
     $45 = HEAP32[$16>>2]|0;
     $46 = (($45) + ($41<<4)|0);
     ;HEAP32[$46+0>>2]=4294967295|0;HEAP32[$46+4>>2]=4294967295|0;HEAP32[$46+8>>2]=4294967295|0;HEAP32[$46+12>>2]=4294967295|0;
     $47 = $41 & 31;
     $48 = 1 << $47;
     $49 = $41 >>> 5;
     $50 = HEAP32[$19>>2]|0;
     $51 = (($50) + ($49<<2)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = $52 | $48;
     HEAP32[$51>>2] = $53;
     $54 = (($5) + ($nextNode$05<<2)|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($graphNextNodes) + ($nextNode$05<<2)|0);
     HEAP32[$56>>2] = $55;
     $57 = (($graphStartIslands) + ($nextNode$05<<2)|0);
     HEAP32[$57>>2] = $41;
     $58 = (($graphNextIslands) + ($41<<2)|0);
     HEAP32[$58>>2] = -1;
     $59 = HEAP32[$54>>2]|0;
     $60 = ($59|0)==(-1);
     if ($60) {
      break L6;
     }
     $$pre = HEAP32[$18>>2]|0;
     $43 = $$pre;$nextNode$05 = $59;
    }
   }
  } while(0);
  $61 = ($27|0)==(-1);
  if (!($61)) {
   $nextEdge$018 = $27;
   while(1) {
    $62 = (($7) + ($nextEdge$018<<2)|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($3) + (($nextEdge$018*12)|0)|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ((($3) + (($nextEdge$018*12)|0)|0) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($65|0)==(-1);
    if ($68) {
     $depth1$1 = 0;$islandId1$1 = -1;
    } else {
     $69 = (($graphStartIslands) + ($65<<2)|0);
     $nextIsland$06 = HEAP32[$69>>2]|0;
     $70 = ($nextIsland$06|0)==(-1);
     if ($70) {
      $depth1$1 = 0;$islandId1$1 = -1;
     } else {
      $depth1$07 = 0;$nextIsland$08 = $nextIsland$06;
      while(1) {
       $71 = (($graphNextIslands) + ($nextIsland$08<<2)|0);
       $72 = (($depth1$07) + 1)|0;
       $nextIsland$0 = HEAP32[$71>>2]|0;
       $73 = ($nextIsland$0|0)==(-1);
       if ($73) {
        $depth1$1 = $72;$islandId1$1 = $nextIsland$08;
        break;
       } else {
        $depth1$07 = $72;$nextIsland$08 = $nextIsland$0;
       }
      }
     }
    }
    $74 = ($67|0)==(-1);
    do {
     if (!($74)) {
      $75 = (($graphStartIslands) + ($67<<2)|0);
      $nextIsland1$011 = HEAP32[$75>>2]|0;
      $76 = ($nextIsland1$011|0)==(-1);
      if (!($76)) {
       $depth2$012 = 0;$nextIsland1$013 = $nextIsland1$011;
       while(1) {
        $77 = (($graphNextIslands) + ($nextIsland1$013<<2)|0);
        $78 = (($depth2$012) + 1)|0;
        $nextIsland1$0 = HEAP32[$77>>2]|0;
        $79 = ($nextIsland1$0|0)==(-1);
        if ($79) {
         break;
        } else {
         $depth2$012 = $78;$nextIsland1$013 = $nextIsland1$0;
        }
       }
       $80 = ($islandId1$1|0)==(-1);
       $81 = ($nextIsland1$013|0)==(-1);
       $or$cond = $80 | $81;
       $82 = ($islandId1$1|0)==($nextIsland1$013|0);
       $or$cond1 = $or$cond | $82;
       if (!($or$cond1)) {
        $83 = ($depth1$1>>>0)<($78>>>0);
        if ($83) {
         $84 = (($graphNextIslands) + ($islandId1$1<<2)|0);
         HEAP32[$84>>2] = $nextIsland1$013;
         break;
        } else {
         $85 = (($graphNextIslands) + ($nextIsland1$013<<2)|0);
         HEAP32[$85>>2] = $islandId1$1;
         break;
        }
       }
      }
     }
    } while(0);
    $86 = ($63|0)==(-1);
    if ($86) {
     break;
    } else {
     $nextEdge$018 = $63;
    }
   }
  }
  L30: do {
   if (!($40)) {
    $87 = HEAP32[$16>>2]|0;
    $nextNode$126 = $25;
    while(1) {
     $88 = (($graphStartIslands) + ($nextNode$126<<2)|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = ($89|0)==(-1);
     if ($90) {
      $islandId$0$lcssa = -1;
     } else {
      $nextIsland2$020 = $89;
      while(1) {
       $91 = (($graphNextIslands) + ($nextIsland2$020<<2)|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = ($92|0)==(-1);
       if ($93) {
        $islandId$0$lcssa = $nextIsland2$020;
        break;
       } else {
        $nextIsland2$020 = $92;
       }
      }
     }
     $94 = ((($1) + (($nextNode$126*12)|0)|0) + 4|0);
     HEAP32[$94>>2] = $islandId$0$lcssa;
     $95 = (($87) + ($islandId$0$lcssa<<4)|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($5) + ($nextNode$126<<2)|0);
     HEAP32[$97>>2] = $96;
     HEAP32[$95>>2] = $nextNode$126;
     $98 = ((($87) + ($islandId$0$lcssa<<4)|0) + 8|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ($99|0)==(-1);
     $nodeId$$i = $100 ? $nextNode$126 : $99;
     HEAP32[$98>>2] = $nodeId$$i;
     $101 = (($graphNextNodes) + ($nextNode$126<<2)|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = ($102|0)==(-1);
     if ($103) {
      break;
     } else {
      $nextNode$126 = $102;
     }
    }
    if (!($40)) {
     if ($20) {
      $nextNode$229$us = $25;
      while(1) {
       $104 = (($graphStartIslands) + ($nextNode$229$us<<2)|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = HEAP32[$16>>2]|0;
       $107 = (($106) + ($105<<4)|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ($108|0)==(-1);
       if ($109) {
        $110 = (($106) + ($105<<4)|0);
        ;HEAP32[$110+0>>2]=4294967295|0;HEAP32[$110+4>>2]=4294967295|0;HEAP32[$110+8>>2]=4294967295|0;HEAP32[$110+12>>2]=4294967295|0;
        $111 = HEAP32[$17>>2]|0;
        $112 = HEAP32[$18>>2]|0;
        $113 = (($112) + ($105<<2)|0);
        HEAP32[$113>>2] = $111;
        HEAP32[$17>>2] = $105;
        $114 = $105 & 31;
        $115 = 1 << $114;
        $116 = $115 ^ -1;
        $117 = $105 >>> 5;
        $118 = HEAP32[$19>>2]|0;
        $119 = (($118) + ($117<<2)|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = $120 & $116;
        HEAP32[$119>>2] = $121;
       }
       $122 = (($graphNextNodes) + ($nextNode$229$us<<2)|0);
       $123 = HEAP32[$122>>2]|0;
       $124 = ($123|0)==(-1);
       if ($124) {
        break L30;
       } else {
        $nextNode$229$us = $123;
       }
      }
     } else {
      $nextNode$229 = $25;
     }
     while(1) {
      $125 = (($graphStartIslands) + ($nextNode$229<<2)|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = HEAP32[$16>>2]|0;
      $128 = (($127) + ($126<<4)|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ($129|0)==(-1);
      if ($130) {
       $131 = (($127) + ($126<<4)|0);
       ;HEAP32[$131+0>>2]=4294967295|0;HEAP32[$131+4>>2]=4294967295|0;HEAP32[$131+8>>2]=4294967295|0;HEAP32[$131+12>>2]=4294967295|0;
       $132 = HEAP32[$17>>2]|0;
       $133 = HEAP32[$18>>2]|0;
       $134 = (($133) + ($126<<2)|0);
       HEAP32[$134>>2] = $132;
       HEAP32[$17>>2] = $126;
       $135 = $126 & 31;
       $136 = 1 << $135;
       $137 = $136 ^ -1;
       $138 = $126 >>> 5;
       $139 = HEAP32[$19>>2]|0;
       $140 = (($139) + ($138<<2)|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = $141 & $137;
       HEAP32[$140>>2] = $142;
       $143 = HEAP32[$affectedIslandsBitmap>>2]|0;
       $144 = (($143) + ($138<<2)|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = $145 & $137;
       HEAP32[$144>>2] = $146;
      } else {
       $147 = $126 & 31;
       $148 = 1 << $147;
       $149 = $126 >>> 5;
       $150 = HEAP32[$affectedIslandsBitmap>>2]|0;
       $151 = (($150) + ($149<<2)|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = $152 | $148;
       HEAP32[$151>>2] = $153;
      }
      $154 = (($graphNextNodes) + ($nextNode$229<<2)|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = ($155|0)==(-1);
      if ($156) {
       break;
      } else {
       $nextNode$229 = $155;
      }
     }
    }
   }
  } while(0);
  if (!($61)) {
   $nextEdge$131 = $27;
   while(1) {
    $157 = (($7) + ($nextEdge$131<<2)|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($3) + (($nextEdge$131*12)|0)|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = ((($3) + (($nextEdge$131*12)|0)|0) + 4|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = ($160|0)==(-1);
    if ($163) {
     $172 = ($162|0)==(-1);
     if (!($172)) {
      $173 = ((($1) + (($162*12)|0)|0) + 4|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = HEAP32[$16>>2]|0;
      $176 = ((($175) + ($174<<4)|0) + 4|0);
      $177 = HEAP32[$176>>2]|0;
      HEAP32[$157>>2] = $177;
      HEAP32[$176>>2] = $nextEdge$131;
      $178 = ((($175) + ($174<<4)|0) + 12|0);
      $179 = HEAP32[$178>>2]|0;
      $180 = ($179|0)==(-1);
      $edgeId$$i = $180 ? $nextEdge$131 : $179;
      HEAP32[$178>>2] = $edgeId$$i;
     }
    } else {
     $164 = ((($1) + (($160*12)|0)|0) + 4|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = HEAP32[$16>>2]|0;
     $167 = ((($166) + ($165<<4)|0) + 4|0);
     $168 = HEAP32[$167>>2]|0;
     HEAP32[$157>>2] = $168;
     HEAP32[$167>>2] = $nextEdge$131;
     $169 = ((($166) + ($165<<4)|0) + 12|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = ($170|0)==(-1);
     $edgeId$$i2 = $171 ? $nextEdge$131 : $170;
     HEAP32[$169>>2] = $edgeId$$i2;
    }
    $181 = ($158|0)==(-1);
    if ($181) {
     break;
    } else {
     $nextEdge$131 = $158;
    }
   }
  }
  $182 = (($i$034) + 1)|0;
  $exitcond = ($182|0)==($numIslandsToUpdate|0);
  if ($exitcond) {
   break;
  } else {
   $i$034 = $182;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx17MBPUpdateWorkTaskC2ERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerE($this,$scratchAllocator,$eventProfiler) {
 $this = $this|0;
 $scratchAllocator = $scratchAllocator|0;
 $eventProfiler = $eventProfiler|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 28|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$this>>2] = ((499592 + 8|0));
 $8 = (($this) + 32|0);
 HEAP32[$8>>2] = $scratchAllocator;
 $9 = (($this) + 36|0);
 HEAP32[$9>>2] = $eventProfiler;
 STACKTOP = sp;return;
}
function __ZN5physx17MBPUpdateWorkTaskD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx17MBPUpdateWorkTaskD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx21MBPPostUpdateWorkTaskC2ERNS_19PxcScratchAllocatorERNS_2Cm13EventProfilerE($this,$scratchAllocator,$eventProfiler) {
 $this = $this|0;
 $scratchAllocator = $scratchAllocator|0;
 $eventProfiler = $eventProfiler|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 28|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$this>>2] = ((499640 + 8|0));
 $8 = (($this) + 32|0);
 HEAP32[$8>>2] = $scratchAllocator;
 $9 = (($this) + 36|0);
 HEAP32[$9>>2] = $eventProfiler;
 STACKTOP = sp;return;
}
function __ZN5physx17MBPUpdateWorkTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx16PxsBroadPhaseMBP9updatePPUEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx21MBPPostUpdateWorkTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx16PxsBroadPhaseMBP13postUpdatePPUEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZNK5physx17MBPUpdateWorkTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (499712|0);
}
function __ZN5physx21MBPPostUpdateWorkTaskD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx21MBPPostUpdateWorkTaskD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx21MBPPostUpdateWorkTask7getNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (499688|0);
}
function __ZN5physx19PxsMaterialCombinerC2Eff($this,$staticFrictionScaling,$dynamicFrictionScaling) {
 $this = $this|0;
 $staticFrictionScaling = Math_fround($staticFrictionScaling);
 $dynamicFrictionScaling = Math_fround($dynamicFrictionScaling);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = $staticFrictionScaling;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = $dynamicFrictionScaling;
 STACKTOP = sp;return;
}
function __ZN5physx19PxsMaterialCombiner18combineRestitutionERKNS_15PxsMaterialDataES3_($mat0,$mat1) {
 $mat0 = $mat0|0;
 $mat1 = $mat1|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($mat0) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($mat1) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($mat0) + 14|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 & 15;
 $8 = (($mat1) + 14|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 & 15;
 $12 = ($7>>>0)<($11>>>0);
 $13 = $12 ? $11 : $7;
 if ((($13|0) == 3)) {
  $19 = $1 > $3;
  $20 = $19 ? $1 : $3;
  $$0$i = $20;
 } else if ((($13|0) == 0)) {
  $14 = Math_fround($1 + $3);
  $15 = Math_fround($14 * Math_fround(0.5));
  $$0$i = $15;
 } else if ((($13|0) == 1)) {
  $16 = $1 < $3;
  $17 = $16 ? $1 : $3;
  $$0$i = $17;
 } else if ((($13|0) == 2)) {
  $18 = Math_fround($1 * $3);
  $$0$i = $18;
 } else {
  $$0$i = Math_fround(0.0);
 }
 STACKTOP = sp;return (Math_fround($$0$i));
}
function __ZN5physx19PxsMaterialCombiner24combineIsotropicFrictionERKNS_15PxsMaterialDataES3_($agg$result,$this,$mat0,$mat1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $mat0 = $mat0|0;
 $mat1 = $mat1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $dynFriction$0 = Math_fround(0), $staFriction$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($mat0) + 12|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($mat1) + 12|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 | $1;
 $5 = $4&65535;
 $6 = (($agg$result) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = $5 & 1;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $68 = $5 | 2;
  HEAP32[$6>>2] = $68;
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $69 = (($agg$result) + 4|0);
  HEAPF32[$69>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $9 = (($mat0) + 14|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = $11 >>> 4;
 $13 = (($mat1) + 14|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 >>> 4;
 $17 = ($12>>>0)<($16>>>0);
 $18 = $17 ? $16 : $12;
 if ((($18|0) == 2)) {
  $39 = Math_fround(HEAPF32[$mat0>>2]);
  $40 = Math_fround(HEAPF32[$mat1>>2]);
  $41 = Math_fround($39 * $40);
  $42 = (($mat0) + 4|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = (($mat1) + 4|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($43 * $45);
  $dynFriction$0 = $41;$staFriction$0 = $46;
 } else if ((($18|0) == 1)) {
  $29 = Math_fround(HEAPF32[$mat0>>2]);
  $30 = Math_fround(HEAPF32[$mat1>>2]);
  $31 = $29 < $30;
  $32 = $31 ? $29 : $30;
  $33 = (($mat0) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($mat1) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = $34 < $36;
  $38 = $37 ? $34 : $36;
  $dynFriction$0 = $32;$staFriction$0 = $38;
 } else if ((($18|0) == 3)) {
  $47 = Math_fround(HEAPF32[$mat0>>2]);
  $48 = Math_fround(HEAPF32[$mat1>>2]);
  $49 = $47 > $48;
  $50 = $49 ? $47 : $48;
  $51 = (($mat0) + 4|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (($mat1) + 4|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = $52 > $54;
  $56 = $55 ? $52 : $54;
  $dynFriction$0 = $50;$staFriction$0 = $56;
 } else if ((($18|0) == 0)) {
  $19 = Math_fround(HEAPF32[$mat0>>2]);
  $20 = Math_fround(HEAPF32[$mat1>>2]);
  $21 = Math_fround($19 + $20);
  $22 = Math_fround($21 * Math_fround(0.5));
  $23 = (($mat0) + 4|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($mat1) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($24 + $26);
  $28 = Math_fround($27 * Math_fround(0.5));
  $dynFriction$0 = $22;$staFriction$0 = $28;
 } else {
  $dynFriction$0 = Math_fround(0.0);$staFriction$0 = Math_fround(0.0);
 }
 $57 = (($this) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($dynFriction$0 * $58);
 $60 = Math_fround(HEAPF32[$this>>2]);
 $61 = Math_fround($staFriction$0 * $60);
 $62 = $59 > Math_fround(0.0);
 $63 = $62 ? $59 : Math_fround(0.0);
 $64 = Math_fround($61 - $63);
 $65 = $64 >= Math_fround(0.0);
 $66 = $65 ? $61 : $63;
 $67 = (($agg$result) + 4|0);
 HEAPF32[$67>>2] = $63;
 HEAPF32[$agg$result>>2] = $66;
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleDataC2ERNS_30PxvParticleSystemStateDataDescERKNS_9PxBounds3E($this,$particles,$bounds) {
 $this = $this|0;
 $particles = $particles|0;
 $bounds = $bounds|0;
 var $$pre$i2 = 0, $$sum = 0, $$sum$i = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0);
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0;
 var $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$09 = 0;
 var $b2$07 = 0, $i$016 = 0, $w$014 = 0, $w1$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((499736 + 8|0));
 $0 = (($this) + 56|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 60|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP8[$2>>0] = 1;
 $3 = HEAP32[$particles>>2]|0;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = (($particles) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)!=(0|0);
 $8 = (($this) + 12|0);
 $9 = $7&1;
 HEAP8[$8>>0] = $9;
 $10 = (($particles) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 20|0);
 HEAP32[$12>>2] = $11;
 $13 = (($particles) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 16|0);
 HEAP32[$15>>2] = $14;
 $16 = Math_fround(HEAPF32[$bounds>>2]);
 $17 = (($this) + 24|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($bounds) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 28|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($bounds) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 32|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($bounds) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 36|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($bounds) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 40|0);
 HEAPF32[$29>>2] = $28;
 $30 = (($bounds) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 44|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($this) + 80|0);
 $34 = (($3) + 31)|0;
 $35 = $34 >>> 5;
 $36 = $35 << 2;
 HEAP32[$0>>2] = $33;
 $37 = $35 | -2147483648;
 HEAP32[$1>>2] = $37;
 $38 = (($36) + 15)|0;
 $39 = $38 & 1073741808;
 $40 = (($33) + ($39)|0);
 $41 = (($this) + 48|0);
 HEAP32[$41>>2] = $40;
 if ($7) {
  $42 = $3 << 5;
  $$sum$i = (($39) + ($42))|0;
  $43 = (($33) + ($$sum$i)|0);
  $45 = $43;
 } else {
  $45 = 0;
 }
 $44 = (($this) + 52|0);
 HEAP32[$44>>2] = $45;
 $46 = (($particles) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  $69 = $35 << 2;
  _memset(($33|0),0,($69|0))|0;
 } else {
  $49 = (($47) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 134217727;
  $52 = ($51>>>0)>($35>>>0);
  if ($52) {
   $53 = (($this) + 64|0);
   HEAP32[$1>>2] = $51;
   $54 = $51 << 2;
   $55 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($53,$54,500048,362)|0);
   HEAP32[$0>>2] = $55;
   $$pre$i2 = HEAP32[$49>>2]|0;
   $58 = $$pre$i2;$59 = $55;
  } else {
   $58 = $50;$59 = $33;
  }
  $56 = HEAP32[$47>>2]|0;
  $57 = $58 << 2;
  _memcpy(($59|0),($56|0),($57|0))|0;
  $60 = HEAP32[$1>>2]|0;
  $61 = $60 & 2147483647;
  $62 = HEAP32[$49>>2]|0;
  $63 = $62 & 2147483647;
  $64 = ($61>>>0)>($63>>>0);
  if ($64) {
   $65 = HEAP32[$0>>2]|0;
   $66 = (($65) + ($63<<2)|0);
   $67 = (($60) - ($62))|0;
   $68 = $67 << 2;
   _memset(($66|0),0,($68|0))|0;
  }
 }
 $70 = HEAP32[$15>>2]|0;
 $71 = ($70|0)==(0);
 if ($71) {
  STACKTOP = sp;return;
 }
 $72 = HEAP32[$41>>2]|0;
 $i$016 = 0;
 while(1) {
  $80 = ((($72) + ($i$016<<5)|0) + 28|0);
  HEAP16[$80>>1] = 0;
  $81 = (($i$016) + 1)|0;
  $82 = ($81>>>0)<($70>>>0);
  if ($82) {
   $i$016 = $81;
  } else {
   break;
  }
 }
 $73 = HEAP32[$0>>2]|0;
 $74 = (($70) + -1)|0;
 $75 = $74 >>> 5;
 $76 = (($particles) + 16|0);
 $77 = (($particles) + 20|0);
 $78 = (($particles) + 24|0);
 $79 = (($particles) + 28|0);
 $w$014 = 0;
 while(1) {
  $83 = (($73) + ($w$014<<2)|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ($84|0)==(0);
  if (!($85)) {
   $86 = $w$014 << 5;
   $87 = HEAP32[$41>>2]|0;
   $88 = HEAP32[$76>>2]|0;
   $89 = HEAP32[$77>>2]|0;
   $90 = HEAP32[$78>>2]|0;
   $91 = HEAP32[$79>>2]|0;
   $b$09 = $84;
   while(1) {
    $92 = (0 - ($b$09))|0;
    $93 = $b$09 & $92;
    $94 = Math_imul($93, 125613361)|0;
    $95 = $94 >>> 27;
    $96 = (412480 + ($95<<2)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = $97 | $86;
    $99 = Math_imul($89, $98)|0;
    $100 = (($88) + ($99)|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = (($87) + ($98<<5)|0);
    HEAPF32[$102>>2] = $101;
    $$sum = (($99) + 4)|0;
    $103 = (($88) + ($$sum)|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = ((($87) + ($98<<5)|0) + 4|0);
    HEAPF32[$105>>2] = $104;
    $$sum4 = (($99) + 8)|0;
    $106 = (($88) + ($$sum4)|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = ((($87) + ($98<<5)|0) + 8|0);
    HEAPF32[$108>>2] = $107;
    $109 = Math_imul($91, $98)|0;
    $110 = (($90) + ($109)|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = ((($87) + ($98<<5)|0) + 16|0);
    HEAPF32[$112>>2] = $111;
    $$sum5 = (($109) + 4)|0;
    $113 = (($90) + ($$sum5)|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = ((($87) + ($98<<5)|0) + 20|0);
    HEAPF32[$115>>2] = $114;
    $$sum6 = (($109) + 8)|0;
    $116 = (($90) + ($$sum6)|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = ((($87) + ($98<<5)|0) + 24|0);
    HEAPF32[$118>>2] = $117;
    $119 = ((($87) + ($98<<5)|0) + 12|0);
    HEAPF32[$119>>2] = Math_fround(0.0);
    $120 = ((($87) + ($98<<5)|0) + 30|0);
    HEAP16[$120>>1] = 0;
    $121 = ((($87) + ($98<<5)|0) + 28|0);
    HEAP16[$121>>1] = 1;
    $122 = (($b$09) + -1)|0;
    $123 = $122 & $b$09;
    $124 = ($123|0)==(0);
    if ($124) {
     break;
    } else {
     $b$09 = $123;
    }
   }
  }
  $125 = (($w$014) + 1)|0;
  $126 = ($125>>>0)>($75>>>0);
  if ($126) {
   break;
  } else {
   $w$014 = $125;
  }
 }
 $127 = HEAP8[$8>>0]|0;
 $128 = ($127<<24>>24)==(0);
 if ($128) {
  STACKTOP = sp;return;
 }
 $129 = (($particles) + 44|0);
 $w1$08 = 0;
 while(1) {
  $130 = (($73) + ($w1$08<<2)|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ($131|0)==(0);
  if (!($132)) {
   $133 = $w1$08 << 5;
   $134 = HEAP32[$5>>2]|0;
   $135 = HEAP32[$129>>2]|0;
   $136 = HEAP32[$44>>2]|0;
   $b2$07 = $131;
   while(1) {
    $137 = (0 - ($b2$07))|0;
    $138 = $b2$07 & $137;
    $139 = Math_imul($138, 125613361)|0;
    $140 = $139 >>> 27;
    $141 = (412480 + ($140<<2)|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = $142 | $133;
    $144 = Math_imul($135, $143)|0;
    $145 = (($134) + ($144)|0);
    $146 = Math_fround(HEAPF32[$145>>2]);
    $147 = (($136) + ($143<<2)|0);
    HEAPF32[$147>>2] = $146;
    $148 = (($b2$07) + -1)|0;
    $149 = $148 & $b2$07;
    $150 = ($149|0)==(0);
    if ($150) {
     break;
    } else {
     $b2$07 = $149;
    }
   }
  }
  $151 = (($w1$08) + 1)|0;
  $152 = ($151>>>0)>($75>>>0);
  if ($152) {
   break;
  } else {
   $w1$08 = $151;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleDataD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $align16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $align16$i = sp;
 HEAP32[$this>>2] = ((499736 + 8|0));
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + -4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = (($1) + ($5)|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($align16$i,$6);
 }
 $7 = (($this) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $10 = (($this) + 60|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)>(-1);
 if (!($12)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $13 = (($this) + 64|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($13,$8);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleDataD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $align16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $align16 = sp;
 HEAP32[$this>>2] = ((499736 + 8|0));
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + -4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = (($1) + ($5)|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($align16,$6);
 }
 $7 = (($this) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 60|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)>(-1);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 64|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($13,$8);
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData10exportDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b$01$i = 0, $w$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + -1)|0;
  $6 = $5 >>> 5;
  $7 = (($this) + 48|0);
  $w$02$i = 0;
  while(1) {
   $8 = (($4) + ($w$02$i<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0);
   if (!($10)) {
    $11 = $w$02$i << 5;
    $12 = HEAP32[$7>>2]|0;
    $b$01$i = $9;
    while(1) {
     $13 = (0 - ($b$01$i))|0;
     $14 = $b$01$i & $13;
     $15 = Math_imul($14, 125613361)|0;
     $16 = $15 >>> 27;
     $17 = (412480 + ($16<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = $18 | $11;
     $20 = ((($12) + ($19<<5)|0) + 30|0);
     HEAP16[$20>>1] = 0;
     $21 = ((($12) + ($19<<5)|0) + 12|0);
     HEAPF32[$21>>2] = Math_fround(0.0);
     $22 = (($b$01$i) + -1)|0;
     $23 = $22 & $b$01$i;
     $24 = ($23|0)==(0);
     if ($24) {
      break;
     } else {
      $b$01$i = $23;
     }
    }
   }
   $25 = (($w$02$i) + 1)|0;
   $26 = ($25>>>0)>($6>>>0);
   if ($26) {
    break;
   } else {
    $w$02$i = $25;
   }
  }
 }
 $27 = HEAP32[$stream>>2]|0;
 $28 = (($27) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$29 & 4095]($stream,16);
 $30 = HEAP32[$stream>>2]|0;
 $31 = (($30) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 12|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)!=(0);
 $38 = (($34) + 31)|0;
 $39 = $38 >>> 5;
 $40 = $39 << 2;
 $41 = (($40) + 15)|0;
 $42 = $41 & 1073741808;
 $43 = $34 << 5;
 $44 = $34 << 2;
 $$$i$i$i = $37 ? $44 : 0;
 $45 = (($43) + 80)|0;
 $46 = (($45) + ($$$i$i$i))|0;
 $47 = (($46) + ($42))|0;
 FUNCTION_TABLE_viii[$32 & 4095]($stream,$this,$47);
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData13clearSimStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b$01 = 0, $w$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + -1)|0;
 $6 = $5 >>> 5;
 $7 = (($this) + 48|0);
 $w$02 = 0;
 while(1) {
  $8 = (($4) + ($w$02<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if (!($10)) {
   $11 = $w$02 << 5;
   $12 = HEAP32[$7>>2]|0;
   $b$01 = $9;
   while(1) {
    $13 = (0 - ($b$01))|0;
    $14 = $b$01 & $13;
    $15 = Math_imul($14, 125613361)|0;
    $16 = $15 >>> 27;
    $17 = (412480 + ($16<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = $18 | $11;
    $20 = ((($12) + ($19<<5)|0) + 30|0);
    HEAP16[$20>>1] = 0;
    $21 = ((($12) + ($19<<5)|0) + 12|0);
    HEAPF32[$21>>2] = Math_fround(0.0);
    $22 = (($b$01) + -1)|0;
    $23 = $22 & $b$01;
    $24 = ($23|0)==(0);
    if ($24) {
     break;
    } else {
     $b$01 = $23;
    }
   }
  }
  $25 = (($w$02) + 1)|0;
  $26 = ($25>>>0)>($6>>>0);
  if ($26) {
   break;
  } else {
   $w$02 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$pre$phi5Z2D = 0, $$pre$phi7Z2D = 0, $$pre$phiZ2D = 0, $$pre4 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $b$01 = 0, $w$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$pre4 = (($shift) + 4|0);
  $$pre6 = (($shift) + 8|0);
  $$pre$phi5Z2D = $$pre4;$$pre$phi7Z2D = $$pre6;$$pre$phiZ2D = $shift;
 } else {
  $3 = (($this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + -1)|0;
  $6 = $5 >>> 5;
  $7 = (($this) + 48|0);
  $8 = (($shift) + 4|0);
  $9 = (($shift) + 8|0);
  $w$02 = 0;
  while(1) {
   $10 = (($4) + ($w$02<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0);
   if (!($12)) {
    $13 = $w$02 << 5;
    $14 = HEAP32[$7>>2]|0;
    $b$01 = $11;
    while(1) {
     $15 = (0 - ($b$01))|0;
     $16 = $b$01 & $15;
     $17 = Math_imul($16, 125613361)|0;
     $18 = $17 >>> 27;
     $19 = (412480 + ($18<<2)|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = $20 | $13;
     $22 = Math_fround(HEAPF32[$shift>>2]);
     $23 = (($14) + ($21<<5)|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $25 = Math_fround($24 - $22);
     HEAPF32[$23>>2] = $25;
     $26 = Math_fround(HEAPF32[$8>>2]);
     $27 = ((($14) + ($21<<5)|0) + 4|0);
     $28 = Math_fround(HEAPF32[$27>>2]);
     $29 = Math_fround($28 - $26);
     HEAPF32[$27>>2] = $29;
     $30 = Math_fround(HEAPF32[$9>>2]);
     $31 = ((($14) + ($21<<5)|0) + 8|0);
     $32 = Math_fround(HEAPF32[$31>>2]);
     $33 = Math_fround($32 - $30);
     HEAPF32[$31>>2] = $33;
     $34 = (($b$01) + -1)|0;
     $35 = $34 & $b$01;
     $36 = ($35|0)==(0);
     if ($36) {
      break;
     } else {
      $b$01 = $35;
     }
    }
   }
   $37 = (($w$02) + 1)|0;
   $38 = ($37>>>0)>($6>>>0);
   if ($38) {
    $$pre$phi5Z2D = $8;$$pre$phi7Z2D = $9;$$pre$phiZ2D = $shift;
    break;
   } else {
    $w$02 = $37;
   }
  }
 }
 $39 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $40 = (($this) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 - $39);
 HEAPF32[$40>>2] = $42;
 $43 = Math_fround(HEAPF32[$$pre$phi5Z2D>>2]);
 $44 = (($this) + 28|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 - $43);
 HEAPF32[$44>>2] = $46;
 $47 = Math_fround(HEAPF32[$$pre$phi7Z2D>>2]);
 $48 = (($this) + 32|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 - $47);
 HEAPF32[$48>>2] = $50;
 $51 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $52 = (($this) + 36|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 - $51);
 HEAPF32[$52>>2] = $54;
 $55 = Math_fround(HEAPF32[$$pre$phi5Z2D>>2]);
 $56 = (($this) + 40|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 - $55);
 HEAPF32[$56>>2] = $58;
 $59 = Math_fround(HEAPF32[$$pre$phi7Z2D>>2]);
 $60 = (($this) + 44|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 - $59);
 HEAPF32[$60>>2] = $62;
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData6createERNS_30PxvParticleSystemStateDataDescERKNS_9PxBounds3E($particles,$bounds) {
 $particles = $particles|0;
 $bounds = $bounds|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$particles>>2]|0;
 $1 = (($particles) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)!=(0|0);
 $4 = (($0) + 31)|0;
 $5 = $4 >>> 5;
 $6 = $5 << 2;
 $7 = (($6) + 15)|0;
 $8 = $7 & 1073741808;
 $9 = $0 << 5;
 $10 = $0 << 2;
 $$$i$i$i1 = $3 ? $10 : 0;
 $11 = (($9) + 99)|0;
 $12 = (($11) + ($$$i$i$i1))|0;
 $13 = (($12) + ($8))|0;
 $14 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (__Z15PxGetFoundationv()|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 4095]($18)|0);
 $$$i$i$i = $22 ? 499928 : 499896;
 $23 = (FUNCTION_TABLE_iiiiii[$17 & 255]($14,$13,$$$i$i$i,499800,230)|0);
 $24 = ($23|0)==(0|0);
 if ($24) {
  $34 = 0;
  STACKTOP = sp;return ($34|0);
 }
 $25 = (($23) + 19|0);
 $26 = $25;
 $27 = $26 & -16;
 $28 = $23;
 $29 = (($27) - ($28))|0;
 $30 = $27;
 $31 = (($30) + -4|0);
 HEAP32[$31>>2] = $29;
 $32 = $27;
 $33 = ($27|0)==(0);
 if ($33) {
  $34 = $32;
  STACKTOP = sp;return ($34|0);
 }
 __ZN5physx15PxsParticleDataC2ERNS_30PxvParticleSystemStateDataDescERKNS_9PxBounds3E($32,$particles,$bounds);
 $34 = $32;
 STACKTOP = sp;return ($34|0);
}
function __ZN5physx15PxsParticleData6createEjb($maxParticles,$perParticleRestOffsets) {
 $maxParticles = $maxParticles|0;
 $perParticleRestOffsets = $perParticleRestOffsets|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($maxParticles) + 31)|0;
 $1 = $0 >>> 5;
 $2 = $1 << 2;
 $3 = (($2) + 15)|0;
 $4 = $3 & 1073741808;
 $5 = $maxParticles << 5;
 $6 = $maxParticles << 2;
 $$$i$i$i1 = $perParticleRestOffsets ? $6 : 0;
 $7 = (($5) + 99)|0;
 $8 = (($7) + ($$$i$i$i1))|0;
 $9 = (($8) + ($4))|0;
 $10 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__Z15PxGetFoundationv()|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($14)|0);
 $$$i$i$i = $18 ? 499928 : 499896;
 $19 = (FUNCTION_TABLE_iiiiii[$13 & 255]($10,$9,$$$i$i$i,499800,240)|0);
 $20 = ($19|0)==(0|0);
 if ($20) {
  $51 = 0;
  STACKTOP = sp;return ($51|0);
 }
 $21 = (($19) + 19|0);
 $22 = $21;
 $23 = $22 & -16;
 $24 = $19;
 $25 = (($23) - ($24))|0;
 $26 = $23;
 $27 = (($26) + -4|0);
 HEAP32[$27>>2] = $25;
 $28 = $23;
 $29 = ($23|0)==(0);
 if ($29) {
  $51 = $28;
  STACKTOP = sp;return ($51|0);
 }
 HEAP32[$28>>2] = ((499736 + 8|0));
 $30 = (($28) + 56|0);
 $31 = (($28) + 60|0);
 $32 = (($28) + 4|0);
 HEAP8[$32>>0] = 1;
 $33 = (($28) + 8|0);
 HEAP32[$33>>2] = $maxParticles;
 $34 = (($28) + 12|0);
 $35 = $perParticleRestOffsets&1;
 HEAP8[$34>>0] = $35;
 $36 = (($28) + 20|0);
 HEAP32[$36>>2] = 0;
 $37 = (($28) + 16|0);
 HEAP32[$37>>2] = 0;
 $38 = (($28) + 24|0);
 HEAPF32[$38>>2] = Math_fround(8.50705866596322149529E+37);
 $39 = (($28) + 28|0);
 HEAPF32[$39>>2] = Math_fround(8.50705866596322149529E+37);
 $40 = (($28) + 32|0);
 HEAPF32[$40>>2] = Math_fround(8.50705866596322149529E+37);
 $41 = (($28) + 36|0);
 HEAPF32[$41>>2] = Math_fround(-8.50705866596322149529E+37);
 $42 = (($28) + 40|0);
 HEAPF32[$42>>2] = Math_fround(-8.50705866596322149529E+37);
 $43 = (($28) + 44|0);
 HEAPF32[$43>>2] = Math_fround(-8.50705866596322149529E+37);
 $44 = (($28) + 80|0);
 HEAP32[$30>>2] = $44;
 $45 = $1 | -2147483648;
 HEAP32[$31>>2] = $45;
 $46 = (($44) + ($4)|0);
 $47 = (($28) + 48|0);
 HEAP32[$47>>2] = $46;
 if ($perParticleRestOffsets) {
  $$sum$i$i = (($4) + ($5))|0;
  $48 = (($44) + ($$sum$i$i)|0);
  $50 = $48;
 } else {
  $50 = 0;
 }
 $49 = (($28) + 52|0);
 HEAP32[$49>>2] = $50;
 _memset(($44|0),0,($2|0))|0;
 $51 = $28;
 STACKTOP = sp;return ($51|0);
}
function __ZN5physx15PxsParticleData7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $align16 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $align16 = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = ($this|0)==(0|0);
 $or$cond = $2 | $3;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + -4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (0 - ($5))|0;
 $7 = (($this) + ($6)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($align16,$7);
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData13addParticlesVERKNS_22PxParticleCreationDataE($this,$creationData) {
 $this = $this|0;
 $creationData = $creationData|0;
 var $$ph = 0, $$ph13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0;
 var $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$014 = 0, $i1$012 = 0, $zeroVector = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $zeroVector = sp;
 HEAPF32[$zeroVector>>2] = Math_fround(0.0);
 $0 = (($zeroVector) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($zeroVector) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($creationData) + 4|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $5;
 $10 = (($creationData) + 12|0);
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $13;
 $18 = (($creationData) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $$ph = 0;$$ph13 = $zeroVector;
 } else {
  $21 = $18;
  $22 = $21;
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21) + 4)|0;
  $25 = $24;
  $26 = HEAP32[$25>>2]|0;
  $27 = $23;
  $$ph = $26;$$ph13 = $27;
 }
 $28 = HEAP32[$creationData>>2]|0;
 $29 = ($28|0)==(0);
 if ($29) {
  $117 = 0;
 } else {
  $30 = (($this) + 48|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($this) + 56|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($this) + 16|0);
  $35 = (($this) + 24|0);
  $36 = (($this) + 28|0);
  $37 = (($this) + 32|0);
  $38 = (($this) + 36|0);
  $39 = (($this) + 40|0);
  $40 = (($this) + 44|0);
  $42 = $9;$53 = $17;$62 = $$ph13;$i$014 = 0;
  while(1) {
   $41 = HEAP32[$42>>2]|0;
   $43 = $41 & 31;
   $44 = 1 << $43;
   $45 = $41 >>> 5;
   $46 = (($33) + ($45<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | $44;
   HEAP32[$46>>2] = $48;
   $49 = (($41) + 1)|0;
   $50 = HEAP32[$34>>2]|0;
   $51 = ($49>>>0)>($50>>>0);
   if ($51) {
    HEAP32[$34>>2] = $49;
   }
   $52 = Math_fround(HEAPF32[$53>>2]);
   $54 = (($31) + ($41<<5)|0);
   HEAPF32[$54>>2] = $52;
   $55 = (($53) + 4|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = ((($31) + ($41<<5)|0) + 4|0);
   HEAPF32[$57>>2] = $56;
   $58 = (($53) + 8|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = ((($31) + ($41<<5)|0) + 8|0);
   HEAPF32[$60>>2] = $59;
   $61 = Math_fround(HEAPF32[$62>>2]);
   $63 = ((($31) + ($41<<5)|0) + 16|0);
   HEAPF32[$63>>2] = $61;
   $64 = (($62) + 4|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = ((($31) + ($41<<5)|0) + 20|0);
   HEAPF32[$66>>2] = $65;
   $67 = (($62) + 8|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = ((($31) + ($41<<5)|0) + 24|0);
   HEAPF32[$69>>2] = $68;
   $70 = ((($31) + ($41<<5)|0) + 30|0);
   HEAP16[$70>>1] = 0;
   $71 = ((($31) + ($41<<5)|0) + 28|0);
   HEAP16[$71>>1] = 1;
   $72 = ((($31) + ($41<<5)|0) + 12|0);
   HEAPF32[$72>>2] = Math_fround(0.0);
   $73 = Math_fround(HEAPF32[$35>>2]);
   $74 = $73 < $52;
   $75 = $74 ? $73 : $52;
   $76 = Math_fround(HEAPF32[$36>>2]);
   $77 = $76 < $56;
   $78 = $77 ? $76 : $56;
   $79 = Math_fround(HEAPF32[$37>>2]);
   $80 = $79 < $59;
   $81 = $80 ? $79 : $59;
   HEAPF32[$35>>2] = $75;
   HEAPF32[$36>>2] = $78;
   HEAPF32[$37>>2] = $81;
   $82 = Math_fround(HEAPF32[$38>>2]);
   $83 = Math_fround(HEAPF32[$54>>2]);
   $84 = $82 > $83;
   $85 = $84 ? $82 : $83;
   $86 = Math_fround(HEAPF32[$39>>2]);
   $87 = Math_fround(HEAPF32[$57>>2]);
   $88 = $86 > $87;
   $89 = $88 ? $86 : $87;
   $90 = Math_fround(HEAPF32[$40>>2]);
   $91 = Math_fround(HEAPF32[$60>>2]);
   $92 = $90 > $91;
   $93 = $92 ? $90 : $91;
   HEAPF32[$38>>2] = $85;
   HEAPF32[$39>>2] = $89;
   HEAPF32[$40>>2] = $93;
   $94 = (($53) + ($16)|0);
   $95 = (($62) + ($$ph)|0);
   $96 = (($42) + ($8)|0);
   $97 = (($i$014) + 1)|0;
   $98 = HEAP32[$creationData>>2]|0;
   $99 = ($97>>>0)<($98>>>0);
   if ($99) {
    $42 = $96;$53 = $94;$62 = $95;$i$014 = $97;
   } else {
    $117 = $98;
    break;
   }
  }
 }
 $100 = (($this) + 52|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  $132 = $117;
  $129 = (($this) + 20|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($130) + ($132))|0;
  HEAP32[$129>>2] = $131;
  STACKTOP = sp;return 1;
 }
 $103 = (($creationData) + 28|0);
 $104 = $103;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = (($104) + 4)|0;
 $108 = $107;
 $109 = HEAP32[$108>>2]|0;
 $110 = $2;
 $111 = $110;
 $112 = HEAP32[$111>>2]|0;
 $113 = (($110) + 4)|0;
 $114 = $113;
 $115 = HEAP32[$114>>2]|0;
 $116 = ($117|0)==(0);
 if ($116) {
  $132 = 0;
  $129 = (($this) + 20|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($130) + ($132))|0;
  HEAP32[$129>>2] = $131;
  STACKTOP = sp;return 1;
 }
 $118 = $112;
 $119 = $106;
 $121 = $118;$123 = $119;$i1$012 = 0;
 while(1) {
  $120 = HEAP32[$121>>2]|0;
  $122 = Math_fround(HEAPF32[$123>>2]);
  $124 = (($101) + ($120<<2)|0);
  HEAPF32[$124>>2] = $122;
  $125 = (($123) + ($109)|0);
  $126 = (($121) + ($115)|0);
  $127 = (($i1$012) + 1)|0;
  $128 = ($127>>>0)<($117>>>0);
  if ($128) {
   $121 = $126;$123 = $125;$i1$012 = $127;
  } else {
   $132 = $117;
   break;
  }
 }
 $129 = (($this) + 20|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (($130) + ($132))|0;
 HEAP32[$129>>2] = $131;
 STACKTOP = sp;return 1;
}
function __ZN5physx15PxsParticleData16removeParticlesVEjRKNS_16PxStrideIteratorIKjEE($this,$count,$indices) {
 $this = $this|0;
 $count = $count|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$0$i = 0, $i$02 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if (!($0)) {
  $1 = HEAP32[$indices>>2]|0;
  $2 = (($indices) + 4|0);
  $3 = (($this) + 48|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($this) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $i$02 = 0;
  while(1) {
   $7 = HEAP32[$2>>2]|0;
   $8 = Math_imul($7, $i$02)|0;
   $9 = (($1) + ($8)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($4) + ($10<<5)|0) + 28|0);
   HEAP16[$11>>1] = 0;
   $12 = $10 & 31;
   $13 = 1 << $12;
   $14 = $13 ^ -1;
   $15 = $10 >>> 5;
   $16 = (($6) + ($15<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $17 & $14;
   HEAP32[$16>>2] = $18;
   $19 = (($i$02) + 1)|0;
   $exitcond = ($19|0)==($count|0);
   if ($exitcond) {
    break;
   } else {
    $i$02 = $19;
   }
  }
 }
 $20 = (($this) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) - ($count))|0;
 HEAP32[$20>>2] = $22;
 $23 = ($21|0)==($count|0);
 if ($23) {
  $51 = 0;
  $50 = (($this) + 16|0);
  HEAP32[$50>>2] = $51;
  STACKTOP = sp;return;
 }
 $24 = (($this) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = (($this) + 56|0);
 $i$0$i = $26;
 while(1) {
  $28 = (($i$0$i) + -1)|0;
  $29 = ($i$0$i|0)==(0);
  if ($29) {
   $51 = 1;
   label = 9;
   break;
  }
  $30 = HEAP32[$27>>2]|0;
  $31 = (($30) + ($28<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(0);
  if ($33) {
   $i$0$i = $28;
  } else {
   break;
  }
 }
 if ((label|0) == 9) {
  $50 = (($this) + 16|0);
  HEAP32[$50>>2] = $51;
  STACKTOP = sp;return;
 }
 $34 = $28 << 5;
 $35 = $32 >>> 1;
 $36 = $35 | $32;
 $37 = $36 >>> 2;
 $38 = $37 | $36;
 $39 = $38 >>> 4;
 $40 = $39 | $38;
 $41 = $40 >>> 8;
 $42 = $41 | $40;
 $43 = $42 >>> 16;
 $44 = $43 | $42;
 $45 = Math_imul($44, 130329821)|0;
 $46 = $45 >>> 27;
 $47 = (482344 + ($46<<2)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $34 | 1;
 $phitmp = (($49) + ($48))|0;
 $51 = $phitmp;
 $50 = (($this) + 16|0);
 HEAP32[$50>>2] = $51;
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData16removeParticlesVEv($this) {
 $this = $this|0;
 var $$ph = 0, $$ph6 = 0, $$ph7 = 0, $$ph821 = 0, $$ph922 = 0, $$phi$trans$insert$i$i$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $particleIndex$0$ph1023 = 0, $particleIndex$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $$phi$trans$insert$i$i$i = (($this) + 56|0);
   $$pre$i$i$i = HEAP32[$$phi$trans$insert$i$i$i>>2]|0;
   $5 = 0;
   while(1) {
    $4 = (($$pre$i$i$i) + ($5<<2)|0);
    $6 = HEAP32[$4>>2]|0;
    $7 = ($6|0)==(0);
    if (!($7)) {
     break;
    }
    $8 = (($5) + 1)|0;
    $9 = ($8>>>0)<($2>>>0);
    if ($9) {
     $5 = $8;
    } else {
     break L1;
    }
   }
   $10 = $5 << 5;
   $11 = (0 - ($6))|0;
   $12 = $6 & $11;
   $13 = Math_imul($12, 125613361)|0;
   $14 = $13 >>> 27;
   $15 = (412480 + ($14<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16 | $10;
   $18 = (($6) + -1)|0;
   $19 = $18 & $6;
   $20 = ($19|0)==(0);
   L7: do {
    if ($20) {
     $22 = $5;
     while(1) {
      $21 = (($22) + 1)|0;
      $23 = ($21>>>0)<($2>>>0);
      if (!($23)) {
       $$ph6 = $21;$$ph7 = 0;
       break L7;
      }
      $24 = (($$pre$i$i$i) + ($21<<2)|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25|0)==(0);
      if ($26) {
       $22 = $21;
      } else {
       $$ph6 = $21;$$ph7 = $25;
       break;
      }
     }
    } else {
     $$ph6 = $5;$$ph7 = $19;
    }
   } while(0);
   $27 = ($17|0)==(-1);
   if (!($27)) {
    $28 = (($this) + 48|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($this) + 56|0);
    $31 = HEAP32[$30>>2]|0;
    $$ph821 = $$ph6;$$ph922 = $$ph7;$particleIndex$0$ph1023 = $17;
    while(1) {
     $34 = $$ph821 << 5;
     $44 = $$ph922;$particleIndex$013 = $particleIndex$0$ph1023;
     while(1) {
      $35 = ((($29) + ($particleIndex$013<<5)|0) + 28|0);
      HEAP16[$35>>1] = 0;
      $36 = $particleIndex$013 & 31;
      $37 = 1 << $36;
      $38 = $37 ^ -1;
      $39 = $particleIndex$013 >>> 5;
      $40 = (($31) + ($39<<2)|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = $41 & $38;
      HEAP32[$40>>2] = $42;
      $43 = ($44|0)==(0);
      if ($43) {
       break L1;
      }
      $46 = (0 - ($44))|0;
      $47 = $44 & $46;
      $48 = Math_imul($47, 125613361)|0;
      $49 = $48 >>> 27;
      $50 = (412480 + ($49<<2)|0);
      $51 = HEAP32[$50>>2]|0;
      $33 = $51 | $34;
      $52 = (($44) + -1)|0;
      $53 = $52 & $44;
      $54 = HEAP32[$0>>2]|0;
      $55 = $54 & 2147483647;
      $56 = ($53|0)==(0);
      if ($56) {
       $58 = $$ph821;
       break;
      }
      $45 = ($33|0)==(-1);
      if ($45) {
       break L1;
      } else {
       $44 = $53;$particleIndex$013 = $33;
      }
     }
     while(1) {
      $57 = (($58) + 1)|0;
      $59 = ($57>>>0)<($55>>>0);
      if (!($59)) {
       $$ph = 0;
       break;
      }
      $60 = (($31) + ($57<<2)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0);
      if ($62) {
       $58 = $57;
      } else {
       $$ph = $61;
       break;
      }
     }
     $32 = ($33|0)==(-1);
     if ($32) {
      break;
     } else {
      $$ph821 = $57;$$ph922 = $$ph;$particleIndex$0$ph1023 = $33;
     }
    }
   }
  }
 } while(0);
 $63 = (($this) + 20|0);
 HEAP32[$63>>2] = 0;
 $64 = (($this) + 16|0);
 HEAP32[$64>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx15PxsParticleData17getParticleCountVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx15PxsParticleData13getParticlesVERNS_30PxvParticleSystemStateDataDescEbb($this,$particles,$0,$1) {
 $this = $this|0;
 $particles = $particles|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 56|0);
 $3 = (($particles) + 12|0);
 HEAP32[$3>>2] = $2;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($particles) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$particles>>2] = $8;
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($particles) + 8|0);
 HEAP32[$11>>2] = $10;
 $12 = HEAP32[$4>>2]|0;
 $13 = ($12|0)==(0);
 $14 = (($particles) + 16|0);
 if ($13) {
  $15 = $14;
  $16 = $15;
  HEAP32[$16>>2] = 0;
  $17 = (($15) + 4)|0;
  $18 = $17;
  HEAP32[$18>>2] = 12;
  $19 = (($particles) + 24|0);
  $20 = $19;
  $21 = $20;
  HEAP32[$21>>2] = 0;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = 12;
  $24 = (($particles) + 32|0);
  $25 = $24;
  $26 = $25;
  HEAP32[$26>>2] = 0;
  $27 = (($25) + 4)|0;
  $28 = $27;
  HEAP32[$28>>2] = 4;
  $29 = (($particles) + 40|0);
  $30 = $29;
  $31 = $30;
  HEAP32[$31>>2] = 0;
  $32 = (($30) + 4)|0;
  $33 = $32;
  HEAP32[$33>>2] = 4;
  STACKTOP = sp;return;
 } else {
  $34 = (($this) + 48|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = $35;
  $37 = $14;
  $38 = $37;
  HEAP32[$38>>2] = $36;
  $39 = (($37) + 4)|0;
  $40 = $39;
  HEAP32[$40>>2] = 32;
  $41 = (($particles) + 24|0);
  $42 = HEAP32[$34>>2]|0;
  $43 = (($42) + 16|0);
  $44 = $43;
  $45 = $41;
  $46 = $45;
  HEAP32[$46>>2] = $44;
  $47 = (($45) + 4)|0;
  $48 = $47;
  HEAP32[$48>>2] = 32;
  $49 = (($particles) + 32|0);
  $50 = HEAP32[$34>>2]|0;
  $51 = (($50) + 28|0);
  $52 = $51;
  $53 = $49;
  $54 = $53;
  HEAP32[$54>>2] = $52;
  $55 = (($53) + 4)|0;
  $56 = $55;
  HEAP32[$56>>2] = 32;
  $57 = (($particles) + 40|0);
  $58 = (($this) + 52|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $59;
  $61 = $57;
  $62 = $61;
  HEAP32[$62>>2] = $60;
  $63 = (($61) + 4)|0;
  $64 = $63;
  HEAP32[$64>>2] = 4;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15PxsParticleData13setPositionsVEjRKNS_16PxStrideIteratorIKjEERKNS1_IKNS_6PxVec3EEE($this,$numParticles,$indices,$positions) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indices = $indices|0;
 $positions = $positions|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $indices;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $positions;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($numParticles|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = $8;
 $14 = $2;
 $15 = (($this) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 24|0);
 $18 = (($this) + 28|0);
 $19 = (($this) + 32|0);
 $20 = (($this) + 36|0);
 $21 = (($this) + 40|0);
 $22 = (($this) + 44|0);
 $24 = $14;$27 = $13;$i$05 = 0;
 while(1) {
  $23 = (($24) + ($5)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($27) + ($11)|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($16) + ($25<<5)|0);
  HEAPF32[$29>>2] = $28;
  $30 = (($27) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = ((($16) + ($25<<5)|0) + 4|0);
  HEAPF32[$32>>2] = $31;
  $33 = (($27) + 8|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = ((($16) + ($25<<5)|0) + 8|0);
  HEAPF32[$35>>2] = $34;
  $36 = Math_fround(HEAPF32[$17>>2]);
  $37 = $36 < $28;
  $38 = $37 ? $36 : $28;
  $39 = Math_fround(HEAPF32[$18>>2]);
  $40 = $39 < $31;
  $41 = $40 ? $39 : $31;
  $42 = Math_fround(HEAPF32[$19>>2]);
  $43 = $42 < $34;
  $44 = $43 ? $42 : $34;
  HEAPF32[$17>>2] = $38;
  HEAPF32[$18>>2] = $41;
  HEAPF32[$19>>2] = $44;
  $45 = Math_fround(HEAPF32[$20>>2]);
  $46 = Math_fround(HEAPF32[$29>>2]);
  $47 = $45 > $46;
  $48 = $47 ? $45 : $46;
  $49 = Math_fround(HEAPF32[$21>>2]);
  $50 = Math_fround(HEAPF32[$32>>2]);
  $51 = $49 > $50;
  $52 = $51 ? $49 : $50;
  $53 = Math_fround(HEAPF32[$22>>2]);
  $54 = Math_fround(HEAPF32[$35>>2]);
  $55 = $53 > $54;
  $56 = $55 ? $53 : $54;
  HEAPF32[$20>>2] = $48;
  HEAPF32[$21>>2] = $52;
  HEAPF32[$22>>2] = $56;
  $57 = (($i$05) + 1)|0;
  $58 = ($57|0)==($numParticles|0);
  if ($58) {
   break;
  } else {
   $24 = $23;$27 = $26;$i$05 = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData14setVelocitiesVEjRKNS_16PxStrideIteratorIKjEERKNS1_IKNS_6PxVec3EEE($this,$numParticles,$indices,$velocities) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indices = $indices|0;
 $velocities = $velocities|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $indices;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $velocities;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($numParticles|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = $8;
 $14 = $2;
 $15 = (($this) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 $18 = $14;$21 = $13;$i$05 = 0;
 while(1) {
  $17 = (($18) + ($5)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($21) + ($11)|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = ((($16) + ($19<<5)|0) + 16|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($21) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($16) + ($19<<5)|0) + 20|0);
  HEAPF32[$26>>2] = $25;
  $27 = (($21) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = ((($16) + ($19<<5)|0) + 24|0);
  HEAPF32[$29>>2] = $28;
  $30 = (($i$05) + 1)|0;
  $31 = ($30|0)==($numParticles|0);
  if ($31) {
   break;
  } else {
   $18 = $17;$21 = $20;$i$05 = $30;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData15setRestOffsetsVEjRKNS_16PxStrideIteratorIKjEERKNS1_IKfEE($this,$numParticles,$indices,$restOffsets) {
 $this = $this|0;
 $numParticles = $numParticles|0;
 $indices = $indices|0;
 $restOffsets = $restOffsets|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $indices;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $restOffsets;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($numParticles|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = $8;
 $14 = $2;
 $15 = (($this) + 52|0);
 $16 = HEAP32[$15>>2]|0;
 $18 = $14;$21 = $13;$i$05 = 0;
 while(1) {
  $17 = (($18) + ($5)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($21) + ($11)|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($16) + ($19<<2)|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($i$05) + 1)|0;
  $25 = ($24|0)==($numParticles|0);
  if ($25) {
   break;
  } else {
   $18 = $17;$21 = $20;$i$05 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxsParticleData19addDeltaVelocitiesVERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKNS_6PxVec3Ef($this,$bufferMap,$buffer,$multiplier) {
 $this = $this|0;
 $bufferMap = $bufferMap|0;
 $buffer = $buffer|0;
 $multiplier = Math_fround($multiplier);
 var $$ph = 0, $$ph6 = 0, $$ph7 = 0, $$ph821 = 0, $$ph922 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0;
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $particleIndex$0$ph1023 = 0, $particleIndex$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bufferMap) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $$pre$i$i$i = HEAP32[$bufferMap>>2]|0;
 $5 = 0;
 while(1) {
  $4 = (($$pre$i$i$i) + ($5<<2)|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = ($6|0)==(0);
  if (!($7)) {
   break;
  }
  $8 = (($5) + 1)|0;
  $9 = ($8>>>0)<($2>>>0);
  if ($9) {
   $5 = $8;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
 $10 = $5 << 5;
 $11 = (0 - ($6))|0;
 $12 = $6 & $11;
 $13 = Math_imul($12, 125613361)|0;
 $14 = $13 >>> 27;
 $15 = (412480 + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 | $10;
 $18 = (($6) + -1)|0;
 $19 = $18 & $6;
 $20 = ($19|0)==(0);
 L10: do {
  if ($20) {
   $22 = $5;
   while(1) {
    $21 = (($22) + 1)|0;
    $23 = ($21>>>0)<($2>>>0);
    if (!($23)) {
     $$ph6 = $21;$$ph7 = 0;
     break L10;
    }
    $24 = (($$pre$i$i$i) + ($21<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(0);
    if ($26) {
     $22 = $21;
    } else {
     $$ph6 = $21;$$ph7 = $25;
     break;
    }
   }
  } else {
   $$ph6 = $5;$$ph7 = $19;
  }
 } while(0);
 $27 = ($17|0)==(-1);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (($this) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 $$ph821 = $$ph6;$$ph922 = $$ph7;$particleIndex$0$ph1023 = $17;
 L18: while(1) {
  $32 = $$ph821 << 5;
  $52 = $$ph922;$particleIndex$013 = $particleIndex$0$ph1023;
  while(1) {
   $33 = (($buffer) + (($particleIndex$013*12)|0)|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = Math_fround($34 * $multiplier);
   $36 = ((($buffer) + (($particleIndex$013*12)|0)|0) + 4|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = Math_fround($37 * $multiplier);
   $39 = ((($buffer) + (($particleIndex$013*12)|0)|0) + 8|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = Math_fround($40 * $multiplier);
   $42 = ((($29) + ($particleIndex$013<<5)|0) + 16|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = Math_fround($35 + $43);
   HEAPF32[$42>>2] = $44;
   $45 = ((($29) + ($particleIndex$013<<5)|0) + 20|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = Math_fround($38 + $46);
   HEAPF32[$45>>2] = $47;
   $48 = ((($29) + ($particleIndex$013<<5)|0) + 24|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = Math_fround($41 + $49);
   HEAPF32[$48>>2] = $50;
   $51 = ($52|0)==(0);
   if ($51) {
    label = 17;
    break L18;
   }
   $54 = (0 - ($52))|0;
   $55 = $52 & $54;
   $56 = Math_imul($55, 125613361)|0;
   $57 = $56 >>> 27;
   $58 = (412480 + ($57<<2)|0);
   $59 = HEAP32[$58>>2]|0;
   $31 = $59 | $32;
   $60 = (($52) + -1)|0;
   $61 = $60 & $52;
   $62 = ($61|0)==(0);
   if ($62) {
    $64 = $$ph821;
    break;
   }
   $53 = ($31|0)==(-1);
   if ($53) {
    label = 17;
    break L18;
   } else {
    $52 = $61;$particleIndex$013 = $31;
   }
  }
  while(1) {
   $63 = (($64) + 1)|0;
   $65 = ($63>>>0)<($2>>>0);
   if (!($65)) {
    $$ph = 0;
    break;
   }
   $66 = HEAP32[$bufferMap>>2]|0;
   $67 = (($66) + ($63<<2)|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(0);
   if ($69) {
    $64 = $63;
   } else {
    $$ph = $68;
    break;
   }
  }
  $30 = ($31|0)==(-1);
  if ($30) {
   label = 17;
   break;
  } else {
   $$ph821 = $63;$$ph922 = $$ph;$particleIndex$0$ph1023 = $31;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx15PxsParticleData15getWorldBoundsVEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 28|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 32|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 $8 = (($agg$result) + 12|0);
 $9 = (($this) + 36|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $10;
 $11 = (($agg$result) + 16|0);
 $12 = (($this) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$11>>2] = $13;
 $14 = (($agg$result) + 20|0);
 $15 = (($this) + 44|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$14>>2] = $16;
 STACKTOP = sp;return;
}
function __ZNK5physx15PxsParticleData16getMaxParticlesVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx16PxsParticleShapeC2EPNS_10PxsContextEj($this,$0,$index) {
 $this = $this|0;
 $0 = $0|0;
 $index = $index|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((500120 + 8|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $index;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 44|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 48|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsParticleShapeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx16PxsParticleShapeD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsParticleShape4initEPNS_20PxsParticleSystemSimEPKNS_15PxsParticleCellE($this,$particleSystem,$packet) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $packet = $packet|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $particleSystem;
 $1 = (($this) + 44|0);
 HEAP32[$1>>2] = $packet;
 $2 = HEAP16[$packet>>1]|0;
 $3 = (($this) + 36|0);
 HEAP16[$3>>1] = $2;
 $4 = (($packet) + 2|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = (($this) + 38|0);
 HEAP16[$6>>1] = $5;
 $7 = (($packet) + 4|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = (($this) + 40|0);
 HEAP16[$9>>1] = $8;
 $10 = (Math_fround(($2<<16>>16)));
 $11 = (Math_fround(($5<<16>>16)));
 $12 = (Math_fround(($8<<16>>16)));
 $13 = (($particleSystem) + 684|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($10 * $14);
 $16 = Math_fround($11 * $14);
 $17 = Math_fround($12 * $14);
 $18 = (($particleSystem) + 700|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($15 - $19);
 $21 = Math_fround($16 - $19);
 $22 = Math_fround($17 - $19);
 $23 = (($this) + 12|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($this) + 16|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($this) + 20|0);
 HEAPF32[$25>>2] = $22;
 $26 = Math_fround(HEAPF32[$13>>2]);
 $27 = Math_fround($15 + $26);
 $28 = Math_fround($16 + $26);
 $29 = Math_fround($17 + $26);
 $30 = Math_fround($19 + $27);
 $31 = Math_fround($19 + $28);
 $32 = Math_fround($19 + $29);
 $33 = (($this) + 24|0);
 HEAPF32[$33>>2] = $30;
 $34 = (($this) + 28|0);
 HEAPF32[$34>>2] = $31;
 $35 = (($this) + 32|0);
 HEAPF32[$35>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsParticleShape8destroyVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx10PxsContext17releaseFluidShapeEPNS_16PxsParticleShapeE($3,$this);
 HEAP32[$0>>2] = 0;
 $4 = (($this) + 44|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 48|0);
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx16PxsParticleShape10getBoundsVEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 20|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 $8 = (($agg$result) + 12|0);
 $9 = (($this) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $10;
 $11 = (($agg$result) + 16|0);
 $12 = (($this) + 28|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$11>>2] = $13;
 $14 = (($agg$result) + 20|0);
 $15 = (($this) + 32|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$14>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsParticleShape12setUserDataVEPv($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAP32[$0>>2] = $data;
 STACKTOP = sp;return;
}
function __ZNK5physx16PxsParticleShape12getUserDataVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx24PxsParticleSystemBatcherC2ERNS_10PxsContextE($this,$_context) {
 $this = $this|0;
 $_context = $_context|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Cm10FanoutTaskC2EPKc($this,500152);
 $0 = (($this) + 92|0);
 __ZN5physx2Cm10FanoutTaskC2EPKc($0,500192);
 $1 = (($this) + 184|0);
 __ZN5physx2Cm10FanoutTaskC2EPKc($1,500232);
 $2 = (($this) + 276|0);
 __ZN5physx2Cm10FanoutTaskC2EPKc($2,500272);
 $3 = (($this) + 368|0);
 HEAP32[$3>>2] = $_context;
 STACKTOP = sp;return;
}
function __ZN5physx24PxsParticleSystemBatcher23scheduleShapeGenerationEPPNS_20PxvParticleSystemSimEPNS_28PxvParticleShapesUpdateInputEjRNS_10PxBaseTaskE($this,$particleSystems,$inputs,$batchSize,$continuation) {
 $this = $this|0;
 $particleSystems = $particleSystems|0;
 $inputs = $inputs|0;
 $batchSize = $batchSize|0;
 $continuation = $continuation|0;
 var $$0$i = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($batchSize|0)==(0);
 if ($1) {
  $$pre$i = (($this) + 12|0);
  $$pre$phi$iZ2D = $$pre$i;
 } else {
  $2 = (($this) + 88|0);
  $3 = (($this) + 12|0);
  $4 = (($this) + 8|0);
  $5 = (($this) + 48|0);
  $6 = (($this) + 44|0);
  $7 = (($this) + 40|0);
  $8 = (($this) + 84|0);
  $9 = (($this) + 20|0);
  $i$01$i = 0;
  while(1) {
   $10 = (($particleSystems) + ($i$01$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($inputs) + ($i$01$i<<3)|0);
   $13 = (__ZN5physx20PxsParticleSystemSim26schedulePacketShapesUpdateERKNS_28PxvParticleShapesUpdateInputERNS_10PxBaseTaskE($11,$12,$continuation)|0);
   $14 = HEAP32[$2>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($14);
   (__ZN5physx6shdfnd15atomicIncrementEPVi($3)|0);
   $15 = (($13) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   HEAP32[$4>>2] = $16;
   HEAP32[$0>>2] = $13;
   $17 = HEAP32[$5>>2]|0;
   $18 = $17 & 2147483647;
   $19 = HEAP32[$6>>2]|0;
   $20 = ($18>>>0)>($19>>>0);
   if ($20) {
    $21 = HEAP32[$7>>2]|0;
    $22 = (($21) + ($19<<2)|0);
    $23 = ($22|0)==(0|0);
    if (!($23)) {
     HEAP32[$22>>2] = $13;
    }
    $24 = (($19) + 1)|0;
    HEAP32[$6>>2] = $24;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($9,$0)|0);
   }
   $25 = HEAP32[$13>>2]|0;
   $26 = (($25) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   FUNCTION_TABLE_vi[$27 & 4095]($13);
   HEAP8[$8>>0] = 1;
   $28 = HEAP32[$2>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($28);
   $29 = HEAP32[$13>>2]|0;
   $30 = (($29) + 20|0);
   $31 = HEAP32[$30>>2]|0;
   FUNCTION_TABLE_vi[$31 & 4095]($13);
   $32 = (($i$01$i) + 1)|0;
   $exitcond$i = ($32|0)==($batchSize|0);
   if ($exitcond$i) {
    $$pre$phi$iZ2D = $3;
    break;
   } else {
    $i$01$i = $32;
   }
  }
 }
 $33 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $34 = ($33|0)==(0);
 if ($34) {
  $37 = HEAP32[$continuation>>2]|0;
  $38 = (($37) + 16|0);
  $39 = HEAP32[$38>>2]|0;
  FUNCTION_TABLE_vi[$39 & 4095]($continuation);
  $$0$i = $continuation;
  STACKTOP = sp;return ($$0$i|0);
 }
 $35 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $36 = ($35|0)>(1);
 if ($36) {
  while(1) {
   __ZN5physx2Cm10FanoutTask15removeReferenceEv($this);
   $40 = HEAP32[$$pre$phi$iZ2D>>2]|0;
   $41 = ($40|0)>(1);
   if (!($41)) {
    break;
   }
  }
 }
 $$0$i = $this;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx24PxsParticleSystemBatcher19scheduleDynamicsCpuEPPNS_20PxvParticleSystemSimEjRNS_10PxBaseTaskE($this,$particleSystems,$batchSize,$continuation) {
 $this = $this|0;
 $particleSystems = $particleSystems|0;
 $batchSize = $batchSize|0;
 $continuation = $continuation|0;
 var $$0$i = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($batchSize|0)==(0);
 if ($1) {
  $$pre$i = (($this) + 104|0);
  $$pre$phi$iZ2D = $$pre$i;
 } else {
  $2 = (($this) + 180|0);
  $3 = (($this) + 104|0);
  $4 = (($this) + 100|0);
  $5 = (($this) + 140|0);
  $6 = (($this) + 136|0);
  $7 = (($this) + 132|0);
  $8 = (($this) + 176|0);
  $9 = (($this) + 112|0);
  $i$01$i = 0;
  while(1) {
   $10 = (($particleSystems) + ($i$01$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__ZN5physx20PxsParticleSystemSim22scheduleDynamicsUpdateERNS_10PxBaseTaskE($11,$continuation)|0);
   $13 = HEAP32[$2>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($13);
   (__ZN5physx6shdfnd15atomicIncrementEPVi($3)|0);
   $14 = (($12) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$4>>2] = $15;
   HEAP32[$0>>2] = $12;
   $16 = HEAP32[$5>>2]|0;
   $17 = $16 & 2147483647;
   $18 = HEAP32[$6>>2]|0;
   $19 = ($17>>>0)>($18>>>0);
   if ($19) {
    $20 = HEAP32[$7>>2]|0;
    $21 = (($20) + ($18<<2)|0);
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     HEAP32[$21>>2] = $12;
    }
    $23 = (($18) + 1)|0;
    HEAP32[$6>>2] = $23;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($9,$0)|0);
   }
   $24 = HEAP32[$12>>2]|0;
   $25 = (($24) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vi[$26 & 4095]($12);
   HEAP8[$8>>0] = 1;
   $27 = HEAP32[$2>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($27);
   $28 = HEAP32[$12>>2]|0;
   $29 = (($28) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vi[$30 & 4095]($12);
   $31 = (($i$01$i) + 1)|0;
   $exitcond$i = ($31|0)==($batchSize|0);
   if ($exitcond$i) {
    $$pre$phi$iZ2D = $3;
    break;
   } else {
    $i$01$i = $31;
   }
  }
 }
 $32 = (($this) + 92|0);
 $33 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $34 = ($33|0)==(0);
 if ($34) {
  $37 = HEAP32[$continuation>>2]|0;
  $38 = (($37) + 16|0);
  $39 = HEAP32[$38>>2]|0;
  FUNCTION_TABLE_vi[$39 & 4095]($continuation);
  $$0$i = $continuation;
  STACKTOP = sp;return ($$0$i|0);
 }
 $35 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $36 = ($35|0)>(1);
 if ($36) {
  while(1) {
   __ZN5physx2Cm10FanoutTask15removeReferenceEv($32);
   $40 = HEAP32[$$pre$phi$iZ2D>>2]|0;
   $41 = ($40|0)>(1);
   if (!($41)) {
    break;
   }
  }
 }
 $$0$i = $32;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx24PxsParticleSystemBatcher21scheduleCollisionPrepEPPNS_20PxvParticleSystemSimEPPNS_14PxLightCpuTaskEjRNS_10PxBaseTaskE($this,$particleSystems,$inputPrepTasks,$batchSize,$continuation) {
 $this = $this|0;
 $particleSystems = $particleSystems|0;
 $inputPrepTasks = $inputPrepTasks|0;
 $batchSize = $batchSize|0;
 $continuation = $continuation|0;
 var $$0$i = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $exitcond$i = 0, $exitcond5$i = 0, $i$01$i = 0, $i$01$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($batchSize|0)==(0);
 if ($1) {
  $$pre$i = (($this) + 196|0);
  $$pre$phi$iZ2D = $$pre$i;
 } else {
  $2 = ($continuation|0)==(0|0);
  $3 = (($this) + 272|0);
  $4 = (($this) + 196|0);
  $5 = (($this) + 192|0);
  $6 = (($this) + 232|0);
  $7 = (($this) + 228|0);
  $8 = (($this) + 224|0);
  $9 = (($this) + 268|0);
  $10 = (($this) + 204|0);
  if ($2) {
   $i$01$us$i = 0;
   while(1) {
    $11 = (($inputPrepTasks) + ($i$01$us$i<<2)|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 16|0);
    HEAP32[$13>>2] = 1;
    $14 = (($12) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = HEAP32[$11>>2]|0;
    $16 = HEAP32[$3>>2]|0;
    __ZN5physx6shdfnd9MutexImpl4lockEv($16);
    (__ZN5physx6shdfnd15atomicIncrementEPVi($4)|0);
    $17 = (($15) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$5>>2] = $18;
    HEAP32[$0>>2] = $15;
    $19 = HEAP32[$6>>2]|0;
    $20 = $19 & 2147483647;
    $21 = HEAP32[$7>>2]|0;
    $22 = ($20>>>0)>($21>>>0);
    if ($22) {
     $23 = HEAP32[$8>>2]|0;
     $24 = (($23) + ($21<<2)|0);
     $25 = ($24|0)==(0|0);
     if (!($25)) {
      HEAP32[$24>>2] = $15;
     }
     $26 = (($21) + 1)|0;
     HEAP32[$7>>2] = $26;
    } else {
     (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($10,$0)|0);
    }
    $27 = HEAP32[$15>>2]|0;
    $28 = (($27) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    FUNCTION_TABLE_vi[$29 & 4095]($15);
    HEAP8[$9>>0] = 1;
    $30 = HEAP32[$3>>2]|0;
    __ZN5physx6shdfnd9MutexImpl6unlockEv($30);
    $31 = HEAP32[$11>>2]|0;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($32) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    FUNCTION_TABLE_vi[$34 & 4095]($31);
    $35 = (($i$01$us$i) + 1)|0;
    $exitcond5$i = ($35|0)==($batchSize|0);
    if ($exitcond5$i) {
     $$pre$phi$iZ2D = $4;
     break;
    } else {
     $i$01$us$i = $35;
    }
   }
  } else {
   $i$01$i = 0;
   while(1) {
    $36 = (($inputPrepTasks) + ($i$01$i<<2)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + 16|0);
    HEAP32[$38>>2] = 1;
    $39 = (($37) + 12|0);
    HEAP32[$39>>2] = $continuation;
    $40 = HEAP32[$continuation>>2]|0;
    $41 = (($40) + 16|0);
    $42 = HEAP32[$41>>2]|0;
    FUNCTION_TABLE_vi[$42 & 4095]($continuation);
    $43 = HEAP32[$39>>2]|0;
    $44 = (($43) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($37) + 8|0);
    HEAP32[$46>>2] = $45;
    $47 = HEAP32[$36>>2]|0;
    $48 = HEAP32[$3>>2]|0;
    __ZN5physx6shdfnd9MutexImpl4lockEv($48);
    (__ZN5physx6shdfnd15atomicIncrementEPVi($4)|0);
    $49 = (($47) + 8|0);
    $50 = HEAP32[$49>>2]|0;
    HEAP32[$5>>2] = $50;
    HEAP32[$0>>2] = $47;
    $51 = HEAP32[$6>>2]|0;
    $52 = $51 & 2147483647;
    $53 = HEAP32[$7>>2]|0;
    $54 = ($52>>>0)>($53>>>0);
    if ($54) {
     $55 = HEAP32[$8>>2]|0;
     $56 = (($55) + ($53<<2)|0);
     $57 = ($56|0)==(0|0);
     if (!($57)) {
      HEAP32[$56>>2] = $47;
     }
     $58 = (($53) + 1)|0;
     HEAP32[$7>>2] = $58;
    } else {
     (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($10,$0)|0);
    }
    $59 = HEAP32[$47>>2]|0;
    $60 = (($59) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    FUNCTION_TABLE_vi[$61 & 4095]($47);
    HEAP8[$9>>0] = 1;
    $62 = HEAP32[$3>>2]|0;
    __ZN5physx6shdfnd9MutexImpl6unlockEv($62);
    $63 = HEAP32[$36>>2]|0;
    $64 = HEAP32[$63>>2]|0;
    $65 = (($64) + 20|0);
    $66 = HEAP32[$65>>2]|0;
    FUNCTION_TABLE_vi[$66 & 4095]($63);
    $67 = (($i$01$i) + 1)|0;
    $exitcond$i = ($67|0)==($batchSize|0);
    if ($exitcond$i) {
     $$pre$phi$iZ2D = $4;
     break;
    } else {
     $i$01$i = $67;
    }
   }
  }
 }
 $68 = (($this) + 184|0);
 $69 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $70 = ($69|0)==(0);
 if ($70) {
  $73 = HEAP32[$continuation>>2]|0;
  $74 = (($73) + 16|0);
  $75 = HEAP32[$74>>2]|0;
  FUNCTION_TABLE_vi[$75 & 4095]($continuation);
  $$0$i = $continuation;
  STACKTOP = sp;return ($$0$i|0);
 }
 $71 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $72 = ($71|0)>(1);
 if ($72) {
  while(1) {
   __ZN5physx2Cm10FanoutTask15removeReferenceEv($68);
   $76 = HEAP32[$$pre$phi$iZ2D>>2]|0;
   $77 = ($76|0)>(1);
   if (!($77)) {
    break;
   }
  }
 }
 $$0$i = $68;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx24PxsParticleSystemBatcher20scheduleCollisionCpuEPPNS_20PxvParticleSystemSimEjRNS_10PxBaseTaskE($this,$particleSystems,$batchSize,$continuation) {
 $this = $this|0;
 $particleSystems = $particleSystems|0;
 $batchSize = $batchSize|0;
 $continuation = $continuation|0;
 var $$0$i = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($batchSize|0)==(0);
 if ($1) {
  $$pre$i = (($this) + 288|0);
  $$pre$phi$iZ2D = $$pre$i;
 } else {
  $2 = (($this) + 364|0);
  $3 = (($this) + 288|0);
  $4 = (($this) + 284|0);
  $5 = (($this) + 324|0);
  $6 = (($this) + 320|0);
  $7 = (($this) + 316|0);
  $8 = (($this) + 360|0);
  $9 = (($this) + 296|0);
  $i$01$i = 0;
  while(1) {
   $10 = (($particleSystems) + ($i$01$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__ZN5physx20PxsParticleSystemSim23scheduleCollisionUpdateERNS_10PxBaseTaskE($11,$continuation)|0);
   $13 = HEAP32[$2>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($13);
   (__ZN5physx6shdfnd15atomicIncrementEPVi($3)|0);
   $14 = (($12) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$4>>2] = $15;
   HEAP32[$0>>2] = $12;
   $16 = HEAP32[$5>>2]|0;
   $17 = $16 & 2147483647;
   $18 = HEAP32[$6>>2]|0;
   $19 = ($17>>>0)>($18>>>0);
   if ($19) {
    $20 = HEAP32[$7>>2]|0;
    $21 = (($20) + ($18<<2)|0);
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     HEAP32[$21>>2] = $12;
    }
    $23 = (($18) + 1)|0;
    HEAP32[$6>>2] = $23;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_10PxBaseTaskENS0_15InlineAllocatorILj16ENS0_19ReflectionAllocatorIS3_EEEEE15growAndPushBackERKS3_($9,$0)|0);
   }
   $24 = HEAP32[$12>>2]|0;
   $25 = (($24) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vi[$26 & 4095]($12);
   HEAP8[$8>>0] = 1;
   $27 = HEAP32[$2>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($27);
   $28 = HEAP32[$12>>2]|0;
   $29 = (($28) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vi[$30 & 4095]($12);
   $31 = (($i$01$i) + 1)|0;
   $exitcond$i = ($31|0)==($batchSize|0);
   if ($exitcond$i) {
    $$pre$phi$iZ2D = $3;
    break;
   } else {
    $i$01$i = $31;
   }
  }
 }
 $32 = (($this) + 276|0);
 $33 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $34 = ($33|0)==(0);
 if ($34) {
  $37 = HEAP32[$continuation>>2]|0;
  $38 = (($37) + 16|0);
  $39 = HEAP32[$38>>2]|0;
  FUNCTION_TABLE_vi[$39 & 4095]($continuation);
  $$0$i = $continuation;
  STACKTOP = sp;return ($$0$i|0);
 }
 $35 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $36 = ($35|0)>(1);
 if ($36) {
  while(1) {
   __ZN5physx2Cm10FanoutTask15removeReferenceEv($32);
   $40 = HEAP32[$$pre$phi$iZ2D>>2]|0;
   $41 = ($40|0)>(1);
   if (!($41)) {
    break;
   }
  }
 }
 $$0$i = $32;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx24PxsParticleSystemBatcher17registerParticlesEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim17getParticleStateVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx20PxsParticleSystemSim19getSimParticleDataVERNS_28PxvParticleSystemSimDataDescEb($this,$simParticleData,$0) {
 $this = $this|0;
 $simParticleData = $simParticleData|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert33 = 0, $$pre = 0, $$pre31 = 0, $$pre32 = 0, $$pre34 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $simParticleData;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 4;
 $5 = (($simParticleData) + 8|0);
 $6 = $5;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 12;
 $10 = (($simParticleData) + 16|0);
 $11 = $10;
 $12 = $11;
 HEAP32[$12>>2] = 0;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = 12;
 $15 = (($simParticleData) + 24|0);
 $16 = $15;
 $17 = $16;
 HEAP32[$17>>2] = 0;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = 12;
 $20 = (($simParticleData) + 32|0);
 $21 = $20;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = 4;
 $25 = (($this) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 20|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($this) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 80|0);
 $36 = HEAP16[$35>>1]|0;
 $37 = $36 & 64;
 $38 = ($37<<16>>16)==(0);
 if ($38) {
  $48 = $36;
 } else {
  $39 = (($26) + 48|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 12|0);
  $42 = $41;
  $43 = $simParticleData;
  $44 = $43;
  HEAP32[$44>>2] = $42;
  $45 = (($43) + 4)|0;
  $46 = $45;
  HEAP32[$46>>2] = 32;
  $$pre = HEAP32[$33>>2]|0;
  $$phi$trans$insert = (($$pre) + 80|0);
  $$pre31 = HEAP16[$$phi$trans$insert>>1]|0;
  $48 = $$pre31;
 }
 $47 = $48 & 16;
 $49 = ($47<<16>>16)==(0);
 if ($49) {
  $58 = $48;
 } else {
  $50 = (($this) + 64|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = $51;
  $53 = $5;
  $54 = $53;
  HEAP32[$54>>2] = $52;
  $55 = (($53) + 4)|0;
  $56 = $55;
  HEAP32[$56>>2] = 12;
  $$pre32 = HEAP32[$33>>2]|0;
  $$phi$trans$insert33 = (($$pre32) + 80|0);
  $$pre34 = HEAP16[$$phi$trans$insert33>>1]|0;
  $58 = $$pre34;
 }
 $57 = $58 & 32;
 $59 = ($57<<16>>16)==(0);
 if (!($59)) {
  $60 = (($this) + 68|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = $61;
  $63 = $10;
  $64 = $63;
  HEAP32[$64>>2] = $62;
  $65 = (($63) + 4)|0;
  $66 = $65;
  HEAP32[$66>>2] = 12;
 }
 $67 = (($this) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0|0);
 if ($69) {
  STACKTOP = sp;return;
 }
 $70 = $68;
 $71 = $15;
 $72 = $71;
 HEAP32[$72>>2] = $70;
 $73 = (($71) + 4)|0;
 $74 = $73;
 HEAP32[$74>>2] = 16;
 $75 = HEAP32[$67>>2]|0;
 $76 = (($75) + 12|0);
 $77 = $76;
 $78 = $20;
 $79 = $78;
 HEAP32[$79>>2] = $77;
 $80 = (($78) + 4)|0;
 $81 = $80;
 HEAP32[$81>>2] = 16;
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsParticleSystemSim16getShapesUpdateVERNS_29PxvParticleShapeUpdateResultsE($this,$updateResults) {
 $this = $this|0;
 $updateResults = $updateResults|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($updateResults) + 12|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($updateResults) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($updateResults) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = (($9) + ($10<<2)|0);
 HEAP32[$updateResults>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim26schedulePacketShapesUpdateERKNS_28PxvParticleShapesUpdateInputERNS_10PxBaseTaskE($this,$input,$continuation) {
 $this = $this|0;
 $input = $input|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1172|0);
 $1 = (($this) + 1188|0);
 HEAP32[$1>>2] = 1;
 $2 = (($this) + 1184|0);
 HEAP32[$2>>2] = $continuation;
 $3 = ($continuation|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$continuation>>2]|0;
  $5 = (($4) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($continuation);
  $7 = HEAP32[$2>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 1180|0);
  HEAP32[$10>>2] = $9;
 }
 $11 = (($this) + 1160|0);
 HEAP32[$11>>2] = 1;
 $12 = (($this) + 1156|0);
 HEAP32[$12>>2] = $0;
 $13 = HEAP32[$0>>2]|0;
 $14 = (($13) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 4095]($0);
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 1152|0);
 HEAP32[$19>>2] = $18;
 $20 = HEAP32[$0>>2]|0;
 $21 = (($20) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($0);
 $23 = (($this) + 1312|0);
 $24 = $input;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $23;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (($this) + 1144|0);
 STACKTOP = sp;return ($34|0);
}
function __ZN5physx20PxsParticleSystemSim22scheduleDynamicsUpdateERNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 65536;
 $5 = ($4|0)==(0);
 if ($5) {
  $17 = HEAP32[$continuation>>2]|0;
  $18 = (($17) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vi[$19 & 4095]($continuation);
  $$0 = $continuation;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($this) + 1216|0);
 HEAP32[$6>>2] = 1;
 $7 = (($this) + 1212|0);
 HEAP32[$7>>2] = $continuation;
 $8 = ($continuation|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$continuation>>2]|0;
  $10 = (($9) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($continuation);
  $12 = HEAP32[$7>>2]|0;
  $13 = (($12) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($this) + 1208|0);
  HEAP32[$15>>2] = $14;
 }
 $16 = (($this) + 1200|0);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx20PxsParticleSystemSim23scheduleCollisionUpdateERNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1256|0);
 $1 = (($this) + 1272|0);
 HEAP32[$1>>2] = 1;
 $2 = (($this) + 1268|0);
 HEAP32[$2>>2] = $continuation;
 $3 = ($continuation|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$continuation>>2]|0;
  $5 = (($4) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($continuation);
  $7 = HEAP32[$2>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 1264|0);
  HEAP32[$10>>2] = $9;
 }
 $11 = (($this) + 1244|0);
 HEAP32[$11>>2] = 1;
 $12 = (($this) + 1240|0);
 HEAP32[$12>>2] = $0;
 $13 = HEAP32[$0>>2]|0;
 $14 = (($13) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 4095]($0);
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 1236|0);
 HEAP32[$19>>2] = $18;
 $20 = HEAP32[$0>>2]|0;
 $21 = (($20) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($0);
 $23 = (($this) + 1228|0);
 STACKTOP = sp;return ($23|0);
}
function __ZN5physx20PxsParticleSystemSim18packetShapesUpdateEPNS_10PxBaseTaskE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$$i$i$i = 0, $$0$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $cont$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 28|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (($4) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 << 2;
  $14 = (($13) + 19)|0;
  $15 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (__Z15PxGetFoundationv()|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
  $$$i$i$i = $23 ? 501080 : 501048;
  $24 = (FUNCTION_TABLE_iiiiii[$18 & 255]($15,$14,$$$i$i$i,500312,167)|0);
  $25 = ($24|0)==(0|0);
  if ($25) {
   $$0$i = 0;
  } else {
   $26 = (($24) + 19|0);
   $27 = $26;
   $28 = $27 & -16;
   $29 = $24;
   $30 = (($28) - ($29))|0;
   $31 = $28;
   $32 = (($31) + -4|0);
   HEAP32[$32>>2] = $30;
   $$0$i = $31;
  }
  HEAP32[$8>>2] = $$0$i;
 }
 $33 = (($this) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 20|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 65536;
 $38 = ($37|0)==(0);
 if ($38) {
  $50 = (($this) + 1172|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + 16|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vi[$53 & 4095]($50);
  $cont$0 = $50;
 } else {
  $39 = (($this) + 1284|0);
  $40 = (($this) + 1172|0);
  $41 = (($this) + 1300|0);
  HEAP32[$41>>2] = 1;
  $42 = (($this) + 1296|0);
  HEAP32[$42>>2] = $40;
  $43 = HEAP32[$40>>2]|0;
  $44 = (($43) + 16|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vi[$45 & 4095]($40);
  $46 = HEAP32[$42>>2]|0;
  $47 = (($46) + 8|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($this) + 1292|0);
  HEAP32[$49>>2] = $48;
  $cont$0 = $39;
 }
 $54 = (($this) + 72|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($this) + 40|0);
 $57 = HEAP32[$8>>2]|0;
 $58 = HEAP32[$3>>2]|0;
 $59 = (($58) + 48|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($58) + 56|0);
 $62 = (($58) + 16|0);
 $63 = HEAP32[$62>>2]|0;
 __ZN5physx19PxsFluidSpatialHash16updatePacketHashERjPjPNS_16PxsFluidParticleERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEjPNS_10PxBaseTaskE($55,$56,$57,$60,$61,$63,$cont$0);
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim20remapShapesToPacketsEPKPNS_16PxvParticleShapeEj($this,$shapes,$numShapes) {
 $this = $this|0;
 $shapes = $shapes|0;
 $numShapes = $numShapes|0;
 var $$pre$i = 0, $$pre$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre13 = 0, $$promoted = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond5 = 0, $exitcond6 = 0, $i$03 = 0, $i2$01 = 0, $mappedFluidPackets = 0, $p$02 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mappedFluidPackets = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = ($numShapes|0)==(0);
  if ($5) {
   STACKTOP = sp;return;
  }
  $6 = (($this) + 32|0);
  $7 = (($this) + 24|0);
  $$promoted = HEAP32[$6>>2]|0;
  $101 = $$promoted;$i2$01 = 0;
  while(1) {
   $98 = (($shapes) + ($i2$01<<2)|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (($101) + 1)|0;
   $102 = HEAP32[$7>>2]|0;
   $103 = (($102) + ($101<<2)|0);
   HEAP32[$103>>2] = $99;
   $104 = (($i2$01) + 1)|0;
   $exitcond = ($104|0)==($numShapes|0);
   if ($exitcond) {
    break;
   } else {
    $101 = $100;$i2$01 = $104;
   }
  }
  $105 = (($$promoted) + ($numShapes))|0;
  HEAP32[$6>>2] = $105;
  STACKTOP = sp;return;
 }
 HEAP32[$mappedFluidPackets>>2] = 0;
 $8 = (($mappedFluidPackets) + 4|0);
 $9 = (($mappedFluidPackets) + 8|0);
 HEAP32[$8>>2] = 32;
 $10 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($9,128,501168,362)|0);
 HEAP32[$mappedFluidPackets>>2] = $10;
 $$pre$i = HEAP32[$8>>2]|0;
 $11 = $$pre$i << 2;
 _memset(($10|0),0,($11|0))|0;
 $12 = ($numShapes|0)==(0);
 $$pre10 = (($this) + 72|0);
 $$pre11 = (($this) + 32|0);
 $$pre13 = (($this) + 24|0);
 if (!($12)) {
  $i$03 = 0;
  while(1) {
   $13 = (($shapes) + ($i$03<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$$pre10>>2]|0;
   $16 = (($14) + 36|0);
   $17 = HEAP16[$16>>1]|0;
   $18 = (($14) + 38|0);
   $19 = HEAP16[$18>>1]|0;
   $20 = (($14) + 40|0);
   $21 = HEAP16[$20>>1]|0;
   $22 = HEAP32[$15>>2]|0;
   $23 = (($15) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $17 << 16 >> 16;
   $26 = $19 << 16 >> 16;
   $27 = ($26*101)|0;
   $28 = (($27) + ($25))|0;
   $29 = $21 << 16 >> 16;
   $30 = ($29*7919)|0;
   $31 = (($28) + ($30))|0;
   $32 = (($24) + -1)|0;
   $33 = $31 & $32;
   $34 = ((($22) + ($33<<4)|0) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(-1);
   L14: do {
    if ($36) {
     label = 13;
    } else {
     $$pre$pre = $35;$38 = $33;
     while(1) {
      $37 = (($22) + ($38<<4)|0);
      $39 = HEAP16[$37>>1]|0;
      $40 = ($17<<16>>16)==($39<<16>>16);
      if ($40) {
       $41 = ((($22) + ($38<<4)|0) + 2|0);
       $42 = HEAP16[$41>>1]|0;
       $43 = ($19<<16>>16)==($42<<16>>16);
       if ($43) {
        $44 = ((($22) + ($38<<4)|0) + 4|0);
        $45 = HEAP16[$44>>1]|0;
        $46 = ($21<<16>>16)==($45<<16>>16);
        if ($46) {
         break;
        }
       }
      }
      $47 = (($38) + 1)|0;
      $48 = $47 & $32;
      $49 = ((($22) + ($48<<4)|0) + 8|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50|0)==(-1);
      if ($51) {
       label = 13;
       break L14;
      } else {
       $$pre$pre = $50;$38 = $48;
      }
     }
     $52 = ($$pre$pre|0)==(-1);
     if ($52) {
      label = 13;
     } else {
      $53 = (($22) + ($38<<4)|0);
      $54 = ($53|0)==(0|0);
      if ($54) {
       label = 13;
      } else {
       $55 = (($14) + 44|0);
       HEAP32[$55>>2] = $53;
       $56 = $38 & 31;
       $57 = 1 << $56;
       $58 = $38 >>> 5;
       $59 = HEAP32[$mappedFluidPackets>>2]|0;
       $60 = (($59) + ($58<<2)|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = $61 | $57;
       HEAP32[$60>>2] = $62;
      }
     }
    }
   } while(0);
   if ((label|0) == 13) {
    label = 0;
    $63 = HEAP32[$$pre11>>2]|0;
    $64 = (($63) + 1)|0;
    HEAP32[$$pre11>>2] = $64;
    $65 = HEAP32[$$pre13>>2]|0;
    $66 = (($65) + ($63<<2)|0);
    HEAP32[$66>>2] = $14;
   }
   $67 = (($i$03) + 1)|0;
   $exitcond6 = ($67|0)==($numShapes|0);
   if ($exitcond6) {
    break;
   } else {
    $i$03 = $67;
   }
  }
 }
 $68 = HEAP32[$$pre10>>2]|0;
 $69 = HEAP32[$68>>2]|0;
 $70 = (($this) + 4|0);
 $71 = (($this) + 28|0);
 $p$02 = 0;
 while(1) {
  $72 = $p$02 >>> 5;
  $73 = HEAP32[$mappedFluidPackets>>2]|0;
  $74 = (($73) + ($72<<2)|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = $p$02 & 31;
  $77 = 1 << $76;
  $78 = $75 & $77;
  $79 = ($78|0)==(0);
  if ($79) {
   $80 = ((($69) + ($p$02<<4)|0) + 8|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(-1);
   if (!($82)) {
    $83 = (($69) + ($p$02<<4)|0);
    $84 = HEAP32[$70>>2]|0;
    $85 = (__ZN5physx10PxsContext16createFluidShapeEPNS_20PxsParticleSystemSimEPKNS_15PxsParticleCellE($84,$this,$83)|0);
    $86 = ($85|0)==(0|0);
    if (!($86)) {
     $87 = HEAP32[$$pre11>>2]|0;
     $88 = HEAP32[$71>>2]|0;
     $89 = (($88) + 1)|0;
     HEAP32[$71>>2] = $89;
     $90 = (($88) + ($87))|0;
     $91 = HEAP32[$$pre13>>2]|0;
     $92 = (($91) + ($90<<2)|0);
     HEAP32[$92>>2] = $85;
    }
   }
  }
  $93 = (($p$02) + 1)|0;
  $exitcond5 = ($93|0)==(1024);
  if ($exitcond5) {
   break;
  } else {
   $p$02 = $93;
  }
 }
 $94 = HEAP32[$mappedFluidPackets>>2]|0;
 $95 = ($94|0)==(0|0);
 if ($95) {
  STACKTOP = sp;return;
 }
 $96 = HEAP32[$8>>2]|0;
 $97 = ($96|0)>(-1);
 if (!($97)) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($9,$94);
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim15collisionUpdateEPNS_10PxBaseTaskE($this,$continuation) {
 $this = $this|0;
 $continuation = $continuation|0;
 var $$0$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 44|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 1120|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($3 * $5);
 $7 = $6 < Math_fround(1.0);
 if ($7) {
  $8 = Math_fround(Math_fround(1.0) - $6);
  $$0$i$i = $8;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $9 = (($this) + 652|0);
 HEAPF32[$9>>2] = $$0$i$i;
 $10 = (($this) + 1128|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 640|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($this) + 1132|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 644|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($this) + 1136|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 648|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($1) + 64|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 712|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($1) + 68|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 716|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($1) + 72|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 720|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($1) + 76|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($this) + 724|0);
 HEAPF32[$30>>2] = $29;
 $31 = (($this) + 704|0);
 HEAPF32[$31>>2] = $5;
 $32 = $5 > Math_fround(0.0);
 if ($32) {
  $33 = Math_fround(Math_fround(1.0) / $5);
  $35 = $33;
 } else {
  $35 = Math_fround(0.0);
 }
 $34 = (($this) + 708|0);
 HEAPF32[$34>>2] = $35;
 $36 = (($1) + 28|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = $37 < Math_fround(0.0);
 $39 = $38 ? Math_fround(0.0) : $37;
 $40 = $39 > Math_fround(0.949999988079071044921);
 $41 = $40 ? Math_fround(0.949999988079071044921) : $39;
 $42 = (($this) + 656|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($1) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = $44 < Math_fround(0.00100000004749745130539);
 $46 = $45 ? Math_fround(0.00100000004749745130539) : $44;
 $47 = $46 > Math_fround(1.0);
 $48 = $47 ? Math_fround(1.0) : $46;
 $49 = (($this) + 660|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($1) + 36|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $51);
 $53 = (($this) + 664|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($1) + 84|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = Math_imul($55, 4999879)|0;
 $57 = Math_imul($56, $55)|0;
 $58 = $57 & 65535;
 $59 = (($this) + 732|0);
 HEAP32[$59>>2] = $58;
 $60 = (($1) + 20|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($this) + 728|0);
 HEAP32[$62>>2] = $61;
 $63 = (($this) + 8|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 24|0);
 HEAPF32[$65>>2] = Math_fround(8.50705866596322149529E+37);
 $66 = (($64) + 28|0);
 HEAPF32[$66>>2] = Math_fround(8.50705866596322149529E+37);
 $67 = (($64) + 32|0);
 HEAPF32[$67>>2] = Math_fround(8.50705866596322149529E+37);
 $68 = (($64) + 36|0);
 HEAPF32[$68>>2] = Math_fround(-8.50705866596322149529E+37);
 $69 = (($64) + 40|0);
 HEAPF32[$69>>2] = Math_fround(-8.50705866596322149529E+37);
 $70 = (($64) + 44|0);
 HEAPF32[$70>>2] = Math_fround(-8.50705866596322149529E+37);
 $71 = (($this) + 640|0);
 $72 = (($this) + 1320|0);
 $73 = HEAP32[$72>>2]|0;
 __ZN5physx17PxsFluidCollision15updateCollisionEPKhRNS_10PxBaseTaskE($71,$73,$continuation);
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim24setExternalAccelerationVERKNS_6PxVec3E($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$v>>2]);
 $1 = (($this) + 1128|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($v) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 1132|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($v) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 1136|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsParticleSystemSim24getExternalAccelerationVEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1128|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx20PxsParticleSystemSim22setSimulationTimeStepVEf($this,$value) {
 $this = $this|0;
 $value = Math_fround($value);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1120|0);
 HEAPF32[$0>>2] = $value;
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsParticleSystemSim22getSimulationTimeStepVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1120|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx20PxsParticleSystemSim13setSimulatedVEb($this,$isSimulated) {
 $this = $this|0;
 $isSimulated = $isSimulated|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1124|0);
 $1 = $isSimulated&1;
 HEAP8[$0>>0] = $1;
 if ($isSimulated) {
  STACKTOP = sp;return;
 }
 __ZN5physx20PxsParticleSystemSim24clearParticleConstraintsEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim24clearParticleConstraintsEv($this) {
 $this = $this|0;
 var $$ph = 0, $$ph6 = 0, $$ph7 = 0, $$ph821 = 0, $$ph922 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $particleIndex$0$ph1023 = 0, $particleIndex$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 56|0);
 $5 = (($1) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $$pre$i$i$i = HEAP32[$4>>2]|0;
 $10 = 0;
 while(1) {
  $9 = (($$pre$i$i$i) + ($10<<2)|0);
  $11 = HEAP32[$9>>2]|0;
  $12 = ($11|0)==(0);
  if (!($12)) {
   break;
  }
  $13 = (($10) + 1)|0;
  $14 = ($13>>>0)<($7>>>0);
  if ($14) {
   $10 = $13;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
 $15 = $10 << 5;
 $16 = (0 - ($11))|0;
 $17 = $11 & $16;
 $18 = Math_imul($17, 125613361)|0;
 $19 = $18 >>> 27;
 $20 = (412480 + ($19<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 | $15;
 $23 = (($11) + -1)|0;
 $24 = $23 & $11;
 $25 = ($24|0)==(0);
 L10: do {
  if ($25) {
   $27 = $10;
   while(1) {
    $26 = (($27) + 1)|0;
    $28 = ($26>>>0)<($7>>>0);
    if (!($28)) {
     $$ph6 = $26;$$ph7 = 0;
     break L10;
    }
    $29 = (($$pre$i$i$i) + ($26<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==(0);
    if ($31) {
     $27 = $26;
    } else {
     $$ph6 = $26;$$ph7 = $30;
     break;
    }
   }
  } else {
   $$ph6 = $10;$$ph7 = $24;
  }
 } while(0);
 $32 = ($22|0)==(-1);
 if ($32) {
  STACKTOP = sp;return;
 }
 $$ph821 = $$ph6;$$ph922 = $$ph7;$particleIndex$0$ph1023 = $22;
 L18: while(1) {
  $35 = $$ph821 << 5;
  $42 = $$ph922;$particleIndex$013 = $particleIndex$0$ph1023;
  while(1) {
   $36 = ((($3) + ($particleIndex$013<<5)|0) + 30|0);
   $37 = HEAP16[$36>>1]|0;
   $38 = $37&65535;
   $39 = $38 & 65532;
   $40 = $39&65535;
   HEAP16[$36>>1] = $40;
   $41 = ($42|0)==(0);
   if ($41) {
    label = 17;
    break L18;
   }
   $44 = (0 - ($42))|0;
   $45 = $42 & $44;
   $46 = Math_imul($45, 125613361)|0;
   $47 = $46 >>> 27;
   $48 = (412480 + ($47<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $34 = $49 | $35;
   $50 = (($42) + -1)|0;
   $51 = $50 & $42;
   $52 = ($51|0)==(0);
   if ($52) {
    $54 = $$ph821;
    break;
   }
   $43 = ($34|0)==(-1);
   if ($43) {
    label = 17;
    break L18;
   } else {
    $42 = $51;$particleIndex$013 = $34;
   }
  }
  while(1) {
   $53 = (($54) + 1)|0;
   $55 = ($53>>>0)<($7>>>0);
   if (!($55)) {
    $$ph = 0;
    break;
   }
   $56 = HEAP32[$4>>2]|0;
   $57 = (($56) + ($53<<2)|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==(0);
   if ($59) {
    $54 = $53;
   } else {
    $$ph = $58;
    break;
   }
  }
  $33 = ($34|0)==(-1);
  if ($33) {
   label = 17;
   break;
  } else {
   $$ph821 = $53;$$ph922 = $$ph;$particleIndex$0$ph1023 = $34;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx20PxsParticleSystemSim12isSimulatedVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1124|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx20PxsParticleSystemSimC2EPNS_10PxsContextEj($this,$context,$index) {
 $this = $this|0;
 $context = $context|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((500408 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $context;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 20|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 24|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 40|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 60|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 64|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 68|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 80|0);
 __ZN5physx16PxsFluidDynamicsC2ERNS_20PxsParticleSystemSimE($10,$this);
 $11 = (($this) + 640|0);
 __ZN5physx17PxsFluidCollisionC2ERNS_20PxsParticleSystemSimE($11,$this);
 $12 = (($this) + 1140|0);
 HEAP32[$12>>2] = $index;
 $13 = (($this) + 1144|0);
 $14 = (($this) + 1148|0);
 HEAP16[$14>>1] = -1;
 $15 = (($this) + 1150|0);
 HEAP16[$15>>1] = 0;
 $16 = (($this) + 1152|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$13>>2] = ((434896 + 8|0));
 $17 = (($this) + 1156|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 1160|0);
 HEAP32[$18>>2] = 0;
 HEAP32[$13>>2] = ((501000 + 8|0));
 $19 = (($this) + 1164|0);
 HEAP32[$19>>2] = $this;
 $20 = (($this) + 1168|0);
 HEAP32[$20>>2] = 500480;
 $21 = (($this) + 1172|0);
 $22 = (($this) + 1176|0);
 HEAP16[$22>>1] = -1;
 $23 = (($this) + 1178|0);
 HEAP16[$23>>1] = 0;
 $24 = (($this) + 1180|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$21>>2] = ((434896 + 8|0));
 $25 = (($this) + 1184|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 1188|0);
 HEAP32[$26>>2] = 0;
 HEAP32[$21>>2] = ((500952 + 8|0));
 $27 = (($this) + 1192|0);
 HEAP32[$27>>2] = $this;
 $28 = (($this) + 1196|0);
 HEAP32[$28>>2] = 500528;
 $29 = (($this) + 1200|0);
 $30 = (($this) + 1204|0);
 HEAP16[$30>>1] = -1;
 $31 = (($this) + 1206|0);
 HEAP16[$31>>1] = 0;
 $32 = (($this) + 1208|0);
 HEAP32[$32>>2] = 0;
 HEAP32[$29>>2] = ((434896 + 8|0));
 $33 = (($this) + 1212|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 1216|0);
 HEAP32[$34>>2] = 0;
 HEAP32[$29>>2] = ((500904 + 8|0));
 $35 = (($this) + 1220|0);
 HEAP32[$35>>2] = $this;
 $36 = (($this) + 1224|0);
 HEAP32[$36>>2] = 500576;
 $37 = (($this) + 1228|0);
 $38 = (($this) + 1232|0);
 HEAP16[$38>>1] = -1;
 $39 = (($this) + 1234|0);
 HEAP16[$39>>1] = 0;
 $40 = (($this) + 1236|0);
 HEAP32[$40>>2] = 0;
 HEAP32[$37>>2] = ((434896 + 8|0));
 $41 = (($this) + 1240|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 1244|0);
 HEAP32[$42>>2] = 0;
 HEAP32[$37>>2] = ((500856 + 8|0));
 $43 = (($this) + 1248|0);
 HEAP32[$43>>2] = $this;
 $44 = (($this) + 1252|0);
 HEAP32[$44>>2] = 500616;
 $45 = (($this) + 1256|0);
 $46 = (($this) + 1260|0);
 HEAP16[$46>>1] = -1;
 $47 = (($this) + 1262|0);
 HEAP16[$47>>1] = 0;
 $48 = (($this) + 1264|0);
 HEAP32[$48>>2] = 0;
 HEAP32[$45>>2] = ((434896 + 8|0));
 $49 = (($this) + 1268|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 1272|0);
 HEAP32[$50>>2] = 0;
 HEAP32[$45>>2] = ((500808 + 8|0));
 $51 = (($this) + 1276|0);
 HEAP32[$51>>2] = $this;
 $52 = (($this) + 1280|0);
 HEAP32[$52>>2] = 500656;
 $53 = (($this) + 1284|0);
 $54 = (($this) + 1288|0);
 HEAP16[$54>>1] = -1;
 $55 = (($this) + 1290|0);
 HEAP16[$55>>1] = 0;
 $56 = (($this) + 1292|0);
 HEAP32[$56>>2] = 0;
 HEAP32[$53>>2] = ((434896 + 8|0));
 $57 = (($this) + 1296|0);
 HEAP32[$57>>2] = 0;
 $58 = (($this) + 1300|0);
 HEAP32[$58>>2] = 0;
 HEAP32[$53>>2] = ((500760 + 8|0));
 $59 = (($this) + 1304|0);
 HEAP32[$59>>2] = $this;
 $60 = (($this) + 1308|0);
 HEAP32[$60>>2] = 500704;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSimD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((500408 + 8|0));
 $0 = (($this) + 1284|0);
 HEAP32[$0>>2] = ((434896 + 8|0));
 $1 = (($this) + 1292|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 1256|0);
 HEAP32[$2>>2] = ((434896 + 8|0));
 $3 = (($this) + 1264|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 1228|0);
 HEAP32[$4>>2] = ((434896 + 8|0));
 $5 = (($this) + 1236|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 1200|0);
 HEAP32[$6>>2] = ((434896 + 8|0));
 $7 = (($this) + 1208|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 1172|0);
 HEAP32[$8>>2] = ((434896 + 8|0));
 $9 = (($this) + 1180|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 1144|0);
 HEAP32[$10>>2] = ((434896 + 8|0));
 $11 = (($this) + 1152|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 640|0);
 __ZN5physx17PxsFluidCollisionD2Ev($12);
 $13 = (($this) + 80|0);
 __ZN5physx16PxsFluidDynamicsD2Ev($13);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSimD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((500408 + 8|0));
 $0 = (($this) + 1284|0);
 HEAP32[$0>>2] = ((434896 + 8|0));
 $1 = (($this) + 1292|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 1256|0);
 HEAP32[$2>>2] = ((434896 + 8|0));
 $3 = (($this) + 1264|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 1228|0);
 HEAP32[$4>>2] = ((434896 + 8|0));
 $5 = (($this) + 1236|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 1200|0);
 HEAP32[$6>>2] = ((434896 + 8|0));
 $7 = (($this) + 1208|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 1172|0);
 HEAP32[$8>>2] = ((434896 + 8|0));
 $9 = (($this) + 1180|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 1144|0);
 HEAP32[$10>>2] = ((434896 + 8|0));
 $11 = (($this) + 1152|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 640|0);
 __ZN5physx17PxsFluidCollisionD2Ev($12);
 $13 = (($this) + 80|0);
 __ZN5physx16PxsFluidDynamicsD2Ev($13);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_25spatialHashUpdateSectionsEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_21collisionFinalizationEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_15collisionUpdateEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_14dynamicsUpdateEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_24packetShapesFinalizationEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_18packetShapesUpdateEPNS_10PxBaseTaskEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim4initERNS_15PxsParticleDataERKNS_26PxvParticleSystemParameterE($this,$particleData,$parameter) {
 $this = $this|0;
 $particleData = $particleData|0;
 $parameter = $parameter|0;
 var $$$i$i$i = 0, $$$i$i$i11 = 0, $$$i$i$i14 = 0, $$$i$i$i17 = 0, $$$i$i$i2 = 0, $$$i$i$i20 = 0, $$$i$i$i5 = 0, $$$i$i$i8 = 0, $$0$i = 0, $$0$i12 = 0, $$0$i15 = 0, $$0$i18 = 0, $$0$i21 = 0, $$0$i3 = 0, $$0$i6 = 0, $$0$i9 = 0, $$phi$trans$insert = 0, $$phi$trans$insert34 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert40 = 0;
 var $$pre = 0, $$pre32 = 0, $$pre33 = 0, $$pre35 = 0, $$pre36 = 0, $$pre38 = 0, $$pre39 = 0, $$pre41 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, $phitmp25 = 0, $phitmp26 = 0, $phitmp27 = 0, $phitmp28 = 0, $phitmp29 = 0, $phitmp30 = 0, $phitmp31 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $particleData;
 __ZN5physx15PxsParticleData13clearSimStateEv($particleData);
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $parameter;
 $4 = (($this) + 1120|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 1128|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 1132|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 1136|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 0;
 __ZN5physx20PxsParticleSystemSim19initializeParameterEv($this);
 $9 = HEAP32[$2>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 << 4;
 $13 = (($12) + 19)|0;
 $14 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (__Z15PxGetFoundationv()|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 4095]($18)|0);
 $$$i$i$i2 = $22 ? 501080 : 501048;
 $23 = (FUNCTION_TABLE_iiiiii[$17 & 255]($14,$13,$$$i$i$i2,500312,347)|0);
 $24 = ($23|0)==(0|0);
 if ($24) {
  $$0$i3 = 0;
 } else {
  $25 = (($23) + 19|0);
  $26 = $25;
  $27 = $26 & -16;
  $28 = $23;
  $29 = (($27) - ($28))|0;
  $30 = $27;
  $31 = (($30) + -4|0);
  HEAP32[$31>>2] = $29;
  $phitmp = $27;
  $$0$i3 = $phitmp;
 }
 $32 = (($this) + 44|0);
 HEAP32[$32>>2] = $$0$i3;
 $33 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (__Z15PxGetFoundationv()|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (FUNCTION_TABLE_ii[$40 & 4095]($37)|0);
 $$$i$i$i5 = $41 ? 501080 : 501048;
 $42 = (FUNCTION_TABLE_iiiiii[$36 & 255]($33,$13,$$$i$i$i5,500312,348)|0);
 $43 = ($42|0)==(0|0);
 if ($43) {
  $$0$i6 = 0;
 } else {
  $44 = (($42) + 19|0);
  $45 = $44;
  $46 = $45 & -16;
  $47 = $42;
  $48 = (($46) - ($47))|0;
  $49 = $46;
  $50 = (($49) + -4|0);
  HEAP32[$50>>2] = $48;
  $phitmp25 = $46;
  $$0$i6 = $phitmp25;
 }
 $51 = (($this) + 48|0);
 HEAP32[$51>>2] = $$0$i6;
 $52 = HEAP32[$3>>2]|0;
 $53 = (($52) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 & 2;
 $56 = ($55|0)==(0);
 if ($56) {
  $95 = (($this) + 52|0);
  HEAP32[$95>>2] = 0;
  $96 = (($this) + 56|0);
  HEAP32[$96>>2] = 0;
  $214 = $52;$98 = $54;
 } else {
  $57 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + 8|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (__Z15PxGetFoundationv()|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + 24|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (FUNCTION_TABLE_ii[$64 & 4095]($61)|0);
  $$$i$i$i8 = $65 ? 501080 : 501048;
  $66 = (FUNCTION_TABLE_iiiiii[$60 & 255]($57,$13,$$$i$i$i8,500312,351)|0);
  $67 = ($66|0)==(0|0);
  if ($67) {
   $$0$i9 = 0;
  } else {
   $68 = (($66) + 19|0);
   $69 = $68;
   $70 = $69 & -16;
   $71 = $66;
   $72 = (($70) - ($71))|0;
   $73 = $70;
   $74 = (($73) + -4|0);
   HEAP32[$74>>2] = $72;
   $phitmp26 = $70;
   $$0$i9 = $phitmp26;
  }
  $75 = (($this) + 52|0);
  HEAP32[$75>>2] = $$0$i9;
  $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($77) + 8|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (__Z15PxGetFoundationv()|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($81) + 24|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (FUNCTION_TABLE_ii[$83 & 4095]($80)|0);
  $$$i$i$i11 = $84 ? 501080 : 501048;
  $85 = (FUNCTION_TABLE_iiiiii[$79 & 255]($76,$13,$$$i$i$i11,500312,352)|0);
  $86 = ($85|0)==(0|0);
  if ($86) {
   $$0$i12 = 0;
  } else {
   $87 = (($85) + 19|0);
   $88 = $87;
   $89 = $88 & -16;
   $90 = $85;
   $91 = (($89) - ($90))|0;
   $92 = $89;
   $93 = (($92) + -4|0);
   HEAP32[$93>>2] = $91;
   $phitmp27 = $89;
   $$0$i12 = $phitmp27;
  }
  $94 = (($this) + 56|0);
  HEAP32[$94>>2] = $$0$i12;
  $$pre = HEAP32[$3>>2]|0;
  $$phi$trans$insert = (($$pre) + 20|0);
  $$pre32 = HEAP32[$$phi$trans$insert>>2]|0;
  $214 = $$pre;$98 = $$pre32;
 }
 $97 = $98 & 3;
 $99 = ($97|0)==(3);
 if ($99) {
  $100 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (($101) + 8|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (__Z15PxGetFoundationv()|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($105) + 24|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (FUNCTION_TABLE_ii[$107 & 4095]($104)|0);
  $$$i$i$i14 = $108 ? 501080 : 501048;
  $109 = (FUNCTION_TABLE_iiiiii[$103 & 255]($100,$13,$$$i$i$i14,500312,362)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $$0$i15 = 0;
  } else {
   $111 = (($109) + 19|0);
   $112 = $111;
   $113 = $112 & -16;
   $114 = $109;
   $115 = (($113) - ($114))|0;
   $116 = $113;
   $117 = (($116) + -4|0);
   HEAP32[$117>>2] = $115;
   $phitmp28 = $113;
   $$0$i15 = $phitmp28;
  }
  $118 = (($this) + 20|0);
  HEAP32[$118>>2] = $$0$i15;
  $$pre33 = HEAP32[$3>>2]|0;
  $$phi$trans$insert34 = (($$pre33) + 20|0);
  $$pre35 = HEAP32[$$phi$trans$insert34>>2]|0;
  $120 = $$pre35;$215 = $$pre33;
 } else {
  $120 = $98;$215 = $214;
 }
 $119 = $120 & 32;
 $121 = ($119|0)==(0);
 if ($121) {
  $144 = $120;$147 = $215;
 } else {
  $122 = $11 << 5;
  $123 = $122 | 19;
  $124 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (($125) + 8|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = (__Z15PxGetFoundationv()|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (($129) + 24|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = (FUNCTION_TABLE_ii[$131 & 4095]($128)|0);
  $$$i$i$i17 = $132 ? 501080 : 501048;
  $133 = (FUNCTION_TABLE_iiiiii[$127 & 255]($124,$123,$$$i$i$i17,500312,378)|0);
  $134 = ($133|0)==(0|0);
  if ($134) {
   $$0$i18 = 0;
  } else {
   $135 = (($133) + 19|0);
   $136 = $135;
   $137 = $136 & -16;
   $138 = $133;
   $139 = (($137) - ($138))|0;
   $140 = $137;
   $141 = (($140) + -4|0);
   HEAP32[$141>>2] = $139;
   $phitmp29 = $137;
   $$0$i18 = $phitmp29;
  }
  $142 = (($this) + 60|0);
  HEAP32[$142>>2] = $$0$i18;
  $$pre36 = HEAP32[$3>>2]|0;
  $$phi$trans$insert37 = (($$pre36) + 20|0);
  $$pre38 = HEAP32[$$phi$trans$insert37>>2]|0;
  $144 = $$pre38;$147 = $$pre36;
 }
 $143 = $144 & 65536;
 $145 = ($143|0)==(0);
 if ($145) {
  $146 = (($147) + 80|0);
  $148 = HEAP16[$146>>1]|0;
  $149 = $148 & 16;
  $150 = ($149<<16>>16)==(0);
  if ($150) {
   $173 = $148;
  } else {
   label = 22;
  }
 } else {
  label = 22;
 }
 if ((label|0) == 22) {
  $151 = ($11*12)|0;
  $152 = (($151) + 19)|0;
  $153 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = (($154) + 8|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = (__Z15PxGetFoundationv()|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = (($158) + 24|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = (FUNCTION_TABLE_ii[$160 & 4095]($157)|0);
  $$$i$i$i20 = $161 ? 501080 : 501048;
  $162 = (FUNCTION_TABLE_iiiiii[$156 & 255]($153,$152,$$$i$i$i20,500312,386)|0);
  $163 = ($162|0)==(0|0);
  if ($163) {
   $$0$i21 = 0;
  } else {
   $164 = (($162) + 19|0);
   $165 = $164;
   $166 = $165 & -16;
   $167 = $162;
   $168 = (($166) - ($167))|0;
   $169 = $166;
   $170 = (($169) + -4|0);
   HEAP32[$170>>2] = $168;
   $phitmp30 = $166;
   $$0$i21 = $phitmp30;
  }
  $171 = (($this) + 64|0);
  HEAP32[$171>>2] = $$0$i21;
  $$pre39 = HEAP32[$3>>2]|0;
  $$phi$trans$insert40 = (($$pre39) + 80|0);
  $$pre41 = HEAP16[$$phi$trans$insert40>>1]|0;
  $173 = $$pre41;
 }
 $172 = $173 & 32;
 $174 = ($172<<16>>16)==(0);
 if (!($174)) {
  $175 = ($11*12)|0;
  $176 = (($175) + 19)|0;
  $177 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + 8|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = (__Z15PxGetFoundationv()|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = (($182) + 24|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = (FUNCTION_TABLE_ii[$184 & 4095]($181)|0);
  $$$i$i$i = $185 ? 501080 : 501048;
  $186 = (FUNCTION_TABLE_iiiiii[$180 & 255]($177,$176,$$$i$i$i,500312,389)|0);
  $187 = ($186|0)==(0|0);
  if ($187) {
   $$0$i = 0;
  } else {
   $188 = (($186) + 19|0);
   $189 = $188;
   $190 = $189 & -16;
   $191 = $186;
   $192 = (($190) - ($191))|0;
   $193 = $190;
   $194 = (($193) + -4|0);
   HEAP32[$194>>2] = $192;
   $phitmp31 = $190;
   $$0$i = $phitmp31;
  }
  $195 = (($this) + 68|0);
  HEAP32[$195>>2] = $$0$i;
 }
 $196 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,8192,500312,391)|0);
 $197 = (($this) + 24|0);
 HEAP32[$197>>2] = $196;
 $198 = (($this) + 28|0);
 HEAP32[$198>>2] = 0;
 $199 = (($this) + 32|0);
 HEAP32[$199>>2] = 0;
 $200 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,24,500312,396)|0);
 $201 = (($this) + 72|0);
 HEAP32[$201>>2] = $200;
 $202 = ($200|0)==(0|0);
 if ($202) {
  $212 = (($this) + 1320|0);
  HEAP32[$212>>2] = 0;
  $213 = (($this) + 16|0);
  HEAP32[$213>>2] = 0;
  STACKTOP = sp;return;
 }
 $203 = (($this) + 108|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = HEAP32[$3>>2]|0;
 $206 = (($205) + 24|0);
 $207 = HEAP32[$206>>2]|0;
 $208 = (($205) + 20|0);
 $209 = HEAP32[$208>>2]|0;
 $210 = $209 & 65536;
 $211 = ($210|0)!=(0);
 __ZN5physx19PxsFluidSpatialHashC2Ejfjb($200,1024,$204,$207,$211);
 $212 = (($this) + 1320|0);
 HEAP32[$212>>2] = 0;
 $213 = (($this) + 16|0);
 HEAP32[$213>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim19initializeParameterEv($this) {
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0;
 var $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($1) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 140|0);
 HEAPF32[$5>>2] = $4;
 $6 = Math_fround($4 * Math_fround(0.00100000004749745130539));
 $7 = (($this) + 100|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($1) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($2 * $9);
 $11 = (($this) + 104|0);
 HEAPF32[$11>>2] = $10;
 $12 = Math_fround(Math_fround(1.0) / $10);
 $13 = (($this) + 108|0);
 HEAPF32[$13>>2] = $12;
 $14 = Math_fround($10 * $10);
 $15 = (($this) + 112|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($1) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = 1 << $17;
 $19 = (Math_fround(($18|0)));
 $20 = Math_fround($10 * $19);
 $21 = (($this) + 116|0);
 HEAPF32[$21>>2] = $20;
 $22 = Math_fround(HEAPF32[$8>>2]);
 $23 = Math_fround($22 * Math_fround(0.100000001490116119385));
 $24 = Math_fround($23 * $23);
 $25 = Math_fround($24 * $24);
 $26 = Math_fround($24 * $25);
 $27 = Math_fround($24 * $26);
 $28 = Math_fround($23 * $27);
 $29 = Math_fround($28 * Math_fround(201.0619354248046875));
 $30 = Math_fround(Math_fround(315.0) / $29);
 $31 = Math_fround($26 * Math_fround(3.14159274101257324219));
 $32 = Math_fround(Math_fround(22.5) / $31);
 $33 = (($this) + 120|0);
 HEAPF32[$33>>2] = $23;
 $34 = (($this) + 124|0);
 HEAPF32[$34>>2] = $24;
 $35 = Math_fround($30 * $6);
 $36 = (($this) + 128|0);
 HEAPF32[$36>>2] = $35;
 $37 = Math_fround($32 * $6);
 $38 = (($1) + 48|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($37 * $39);
 $41 = (($this) + 132|0);
 HEAPF32[$41>>2] = $40;
 $42 = Math_fround($24 * $35);
 $43 = Math_fround($24 * $42);
 $44 = Math_fround($24 * $43);
 $45 = (($this) + 96|0);
 HEAPF32[$45>>2] = $44;
 $46 = Math_fround(Math_fround(0.100000001490116119385) / $2);
 $47 = (($this) + 144|0);
 HEAPF32[$47>>2] = $46;
 $48 = Math_fround($46 * $46);
 $49 = (($this) + 148|0);
 HEAPF32[$49>>2] = $48;
 $50 = Math_fround(Math_fround(1.0) / $46);
 $51 = (($this) + 152|0);
 HEAPF32[$51>>2] = $50;
 $52 = (($this) + 160|0);
 HEAP32[$52>>2] = $17;
 $53 = Math_fround($4 - $44);
 $54 = $53 > Math_fround(0.0);
 if ($54) {
  $55 = Math_fround(Math_fround(1.0) / $53);
  $57 = $55;
 } else {
  $57 = Math_fround(0.0);
 }
 $56 = (($this) + 156|0);
 HEAPF32[$56>>2] = $57;
 $58 = Math_fround(HEAPF32[$8>>2]);
 $59 = Math_fround($58 * Math_fround(0.100000001490116119385));
 $60 = Math_fround($59 * $59);
 $61 = Math_fround($60 * $60);
 $62 = Math_fround($60 * $61);
 $63 = (($1) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($62 * Math_fround(3.14159274101257324219));
 $66 = Math_fround(Math_fround(45.0) / $65);
 $67 = Math_fround($64 * $66);
 $68 = Math_fround($6 * $67);
 $69 = (($this) + 136|0);
 HEAPF32[$69>>2] = $68;
 $70 = (($this) + 668|0);
 HEAPF32[$70>>2] = $10;
 $71 = (($this) + 672|0);
 HEAPF32[$71>>2] = $12;
 $72 = HEAP32[$16>>2]|0;
 $73 = (($this) + 676|0);
 HEAP32[$73>>2] = $72;
 $74 = HEAP32[$16>>2]|0;
 $75 = 1 << $74;
 $76 = (($this) + 680|0);
 HEAP32[$76>>2] = $75;
 $77 = (($this) + 684|0);
 HEAPF32[$77>>2] = $20;
 $78 = (($1) + 56|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($this) + 688|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($1) + 60|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($this) + 692|0);
 HEAPF32[$83>>2] = $82;
 $84 = (($1) + 52|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($this) + 696|0);
 HEAPF32[$86>>2] = $85;
 $87 = Math_fround($85 + $82);
 $88 = Math_fround($87 + Math_fround(0.00100000004749745130539));
 $89 = (($this) + 700|0);
 HEAPF32[$89>>2] = $88;
 $90 = (($1) + 44|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($this) + 1120|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($91 * $93);
 $95 = $94 < Math_fround(1.0);
 if ($95) {
  $96 = Math_fround(Math_fround(1.0) - $94);
  $$0$i$i = $96;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $97 = (($this) + 652|0);
 HEAPF32[$97>>2] = $$0$i$i;
 $98 = (($this) + 1128|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($this) + 640|0);
 HEAPF32[$100>>2] = $99;
 $101 = (($this) + 1132|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($this) + 644|0);
 HEAPF32[$103>>2] = $102;
 $104 = (($this) + 1136|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($this) + 648|0);
 HEAPF32[$106>>2] = $105;
 $107 = (($1) + 64|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($this) + 712|0);
 HEAPF32[$109>>2] = $108;
 $110 = (($1) + 68|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($this) + 716|0);
 HEAPF32[$112>>2] = $111;
 $113 = (($1) + 72|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($this) + 720|0);
 HEAPF32[$115>>2] = $114;
 $116 = (($1) + 76|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($this) + 724|0);
 HEAPF32[$118>>2] = $117;
 $119 = (($this) + 704|0);
 HEAPF32[$119>>2] = $93;
 $120 = $93 > Math_fround(0.0);
 if (!($120)) {
  $123 = Math_fround(0.0);
  $122 = (($this) + 708|0);
  HEAPF32[$122>>2] = $123;
  $124 = (($1) + 28|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = $125 < Math_fround(0.0);
  $127 = $126 ? Math_fround(0.0) : $125;
  $128 = $127 > Math_fround(0.949999988079071044921);
  $129 = $128 ? Math_fround(0.949999988079071044921) : $127;
  $130 = (($this) + 656|0);
  HEAPF32[$130>>2] = $129;
  $131 = (($1) + 32|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = $132 < Math_fround(0.00100000004749745130539);
  $134 = $133 ? Math_fround(0.00100000004749745130539) : $132;
  $135 = $134 > Math_fround(1.0);
  $136 = $135 ? Math_fround(1.0) : $134;
  $137 = (($this) + 660|0);
  HEAPF32[$137>>2] = $136;
  $138 = (($1) + 36|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($139 * $139);
  $141 = (($this) + 664|0);
  HEAPF32[$141>>2] = $140;
  $142 = (($1) + 84|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = Math_imul($143, 4999879)|0;
  $145 = Math_imul($144, $143)|0;
  $146 = $145 & 65535;
  $147 = (($this) + 732|0);
  HEAP32[$147>>2] = $146;
  $148 = (($1) + 20|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = (($this) + 728|0);
  HEAP32[$150>>2] = $149;
  STACKTOP = sp;return;
 }
 $121 = Math_fround(Math_fround(1.0) / $93);
 $123 = $121;
 $122 = (($this) + 708|0);
 HEAPF32[$122>>2] = $123;
 $124 = (($1) + 28|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = $125 < Math_fround(0.0);
 $127 = $126 ? Math_fround(0.0) : $125;
 $128 = $127 > Math_fround(0.949999988079071044921);
 $129 = $128 ? Math_fround(0.949999988079071044921) : $127;
 $130 = (($this) + 656|0);
 HEAPF32[$130>>2] = $129;
 $131 = (($1) + 32|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = $132 < Math_fround(0.00100000004749745130539);
 $134 = $133 ? Math_fround(0.00100000004749745130539) : $132;
 $135 = $134 > Math_fround(1.0);
 $136 = $135 ? Math_fround(1.0) : $134;
 $137 = (($this) + 660|0);
 HEAPF32[$137>>2] = $136;
 $138 = (($1) + 36|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($139 * $139);
 $141 = (($this) + 664|0);
 HEAPF32[$141>>2] = $140;
 $142 = (($1) + 84|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = Math_imul($143, 4999879)|0;
 $145 = Math_imul($144, $143)|0;
 $146 = $145 & 65535;
 $147 = (($this) + 732|0);
 HEAP32[$147>>2] = $146;
 $148 = (($1) + 20|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = (($this) + 728|0);
 HEAP32[$150>>2] = $149;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim5clearEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 80|0);
 __ZN5physx16PxsFluidDynamics5clearEv($2);
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  __ZN5physx19PxsFluidSpatialHashD2Ev($4);
  $6 = HEAP32[$3>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
  HEAP32[$3>>2] = 0;
 }
 $7 = (($this) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = (($8) + -4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (0 - ($11))|0;
  $13 = (($8) + ($12)|0);
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$13);
  }
 }
 HEAP32[$7>>2] = 0;
 $19 = (($this) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = (($20) + -4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (0 - ($23))|0;
  $25 = (($20) + ($24)|0);
  $26 = ($25|0)==(0|0);
  if (!($26)) {
   $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vii[$30 & 4095]($27,$25);
  }
 }
 HEAP32[$19>>2] = 0;
 $31 = (($this) + 52|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = (($32) + -4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (0 - ($35))|0;
  $37 = (($32) + ($36)|0);
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   $39 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + 12|0);
   $42 = HEAP32[$41>>2]|0;
   FUNCTION_TABLE_vii[$42 & 4095]($39,$37);
  }
  HEAP32[$31>>2] = 0;
 }
 $43 = (($this) + 56|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = (($44) + -4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (0 - ($47))|0;
  $49 = (($44) + ($48)|0);
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + 12|0);
   $54 = HEAP32[$53>>2]|0;
   FUNCTION_TABLE_vii[$54 & 4095]($51,$49);
  }
  HEAP32[$43>>2] = 0;
 }
 $55 = (($this) + 60|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0|0);
 if (!($57)) {
  $58 = (($56) + -4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (0 - ($59))|0;
  $61 = (($56) + ($60)|0);
  $62 = ($61|0)==(0|0);
  if (!($62)) {
   $63 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 12|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vii[$66 & 4095]($63,$61);
  }
  HEAP32[$55>>2] = 0;
 }
 $67 = (($this) + 64|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0|0);
 if (!($69)) {
  $70 = (($68) + -4|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (0 - ($71))|0;
  $73 = (($68) + ($72)|0);
  $74 = ($73|0)==(0|0);
  if (!($74)) {
   $75 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($76) + 12|0);
   $78 = HEAP32[$77>>2]|0;
   FUNCTION_TABLE_vii[$78 & 4095]($75,$73);
  }
  HEAP32[$67>>2] = 0;
 }
 $79 = (($this) + 68|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0|0);
 if (!($81)) {
  $82 = (($80) + -4|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (0 - ($83))|0;
  $85 = (($80) + ($84)|0);
  $86 = ($85|0)==(0|0);
  if (!($86)) {
   $87 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($88) + 12|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_vii[$90 & 4095]($87,$85);
  }
  HEAP32[$79>>2] = 0;
 }
 $91 = (($this) + 24|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0|0);
 if (!($93)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$92);
  HEAP32[$91>>2] = 0;
 }
 $94 = (($this) + 36|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 if (!($96)) {
  $97 = (($95) + -4|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = (0 - ($98))|0;
  $100 = (($95) + ($99)|0);
  $101 = ($100|0)==(0|0);
  if (!($101)) {
   $102 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (($103) + 12|0);
   $105 = HEAP32[$104>>2]|0;
   FUNCTION_TABLE_vii[$105 & 4095]($102,$100);
  }
  HEAP32[$94>>2] = 0;
 }
 $106 = (($this) + 40|0);
 HEAP32[$106>>2] = 0;
 $107 = (($this) + 20|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108|0)==(0|0);
 if (!($109)) {
  $110 = (($108) + -4|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = (0 - ($111))|0;
  $113 = (($108) + ($112)|0);
  $114 = ($113|0)==(0|0);
  if (!($114)) {
   $115 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (($116) + 12|0);
   $118 = HEAP32[$117>>2]|0;
   FUNCTION_TABLE_vii[$118 & 4095]($115,$113);
  }
  HEAP32[$107>>2] = 0;
 }
 $119 = (($this) + 16|0);
 HEAP32[$119>>2] = 0;
 $120 = (($this) + 8|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($121|0)==(0|0);
 if ($122) {
  STACKTOP = sp;return;
 }
 __ZN5physx15PxsParticleData7releaseEv($121);
 HEAP32[$120>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim19obtainParticleStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx20PxsParticleSystemSim18removeInteractionVERKNS_16PxvParticleShapeEjjbbb($this,$particleShape,$shape,$body,$isDynamic,$isDyingRb,$0) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 $shape = $shape|0;
 $body = $body|0;
 $isDynamic = $isDynamic|0;
 $isDyingRb = $isDyingRb|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $shape;
 if (!($isDyingRb)) {
  STACKTOP = sp;return;
 }
 if ($isDynamic) {
  $2 = (($this) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   STACKTOP = sp;return;
  }
  $5 = $body;
  __ZN5physx20PxsParticleSystemSim24removeTwoWayRbReferencesERKNS_16PxsParticleShapeEPKNS_11PxsBodyCoreE($this,$particleShape,$5);
  STACKTOP = sp;return;
 }
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($1) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(5);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($particleShape) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($13) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($13) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19))|0;
 $23 = ($19>>>0)<($22>>>0);
 if (!($23)) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 36|0);
 $25 = HEAP32[$24>>2]|0;
 $i$01$i = $19;
 while(1) {
  $26 = (($25) + ($i$01$i<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($17) + ($27<<5)|0) + 30|0);
  $29 = HEAP16[$28>>1]|0;
  $30 = $29 & 48;
  $31 = ($30<<16>>16)==(0);
  if (!($31)) {
   $32 = ((($7) + ($27<<5)|0) + 28|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==($9|0);
   if ($34) {
    $35 = $29&65535;
    $36 = $35 & 65487;
    $37 = $36&65535;
    HEAP16[$28>>1] = $37;
   }
  }
  $38 = (($i$01$i) + 1)|0;
  $exitcond$i = ($38|0)==($22|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $38;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim24removeTwoWayRbReferencesERKNS_16PxsParticleShapeEPKNS_11PxsBodyCoreE($this,$particleShape,$rigidBody) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 $rigidBody = $rigidBody|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($particleShape) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7))|0;
 $11 = ($7>>>0)<($10>>>0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 36|0);
 $13 = (($this) + 44|0);
 $14 = (($this) + 48|0);
 $15 = (($this) + 52|0);
 $16 = (($this) + 56|0);
 $i$01 = $7;
 while(1) {
  $17 = HEAP32[$12>>2]|0;
  $18 = (($17) + ($i$01<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($5) + ($19<<5)|0) + 28|0);
  $21 = HEAP16[$20>>1]|0;
  $22 = $21 & 1;
  $23 = ($22<<16>>16)==(0);
  do {
   if (!($23)) {
    $24 = ((($5) + ($19<<5)|0) + 30|0);
    $25 = HEAP16[$24>>1]|0;
    $26 = $25&65535;
    $27 = $26 & 3;
    $28 = ($27|0)==(0);
    if (!($28)) {
     $29 = HEAP32[$13>>2]|0;
     $30 = HEAP32[$14>>2]|0;
     $31 = HEAP32[$15>>2]|0;
     $32 = HEAP32[$16>>2]|0;
     $33 = ((($32) + ($19<<4)|0) + 12|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==($rigidBody|0);
     if ($35) {
      $36 = $26 & 65525;
      $37 = $36&65535;
      HEAP16[$24>>1] = $37;
      $42 = $37;
     } else {
      $42 = $25;
     }
     $38 = ((($31) + ($19<<4)|0) + 12|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==($rigidBody|0);
     if ($40) {
      $41 = $42&65535;
      $43 = $41 & 2;
      $44 = ($43|0)==(0);
      if ($44) {
       $45 = $41 & 65530;
       $46 = $45&65535;
       HEAP16[$24>>1] = $46;
       break;
      } else {
       $47 = (($30) + ($19<<4)|0);
       $48 = Math_fround(HEAPF32[$47>>2]);
       $49 = (($29) + ($19<<4)|0);
       HEAPF32[$49>>2] = $48;
       $50 = ((($30) + ($19<<4)|0) + 4|0);
       $51 = Math_fround(HEAPF32[$50>>2]);
       $52 = ((($29) + ($19<<4)|0) + 4|0);
       HEAPF32[$52>>2] = $51;
       $53 = ((($30) + ($19<<4)|0) + 8|0);
       $54 = Math_fround(HEAPF32[$53>>2]);
       $55 = ((($29) + ($19<<4)|0) + 8|0);
       HEAPF32[$55>>2] = $54;
       $56 = ((($30) + ($19<<4)|0) + 12|0);
       $57 = Math_fround(HEAPF32[$56>>2]);
       $58 = ((($29) + ($19<<4)|0) + 12|0);
       HEAPF32[$58>>2] = $57;
       $59 = (($32) + ($19<<4)|0);
       $60 = Math_fround(HEAPF32[$59>>2]);
       $61 = (($31) + ($19<<4)|0);
       HEAPF32[$61>>2] = $60;
       $62 = ((($32) + ($19<<4)|0) + 4|0);
       $63 = Math_fround(HEAPF32[$62>>2]);
       $64 = ((($31) + ($19<<4)|0) + 4|0);
       HEAPF32[$64>>2] = $63;
       $65 = ((($32) + ($19<<4)|0) + 8|0);
       $66 = Math_fround(HEAPF32[$65>>2]);
       $67 = ((($31) + ($19<<4)|0) + 8|0);
       HEAPF32[$67>>2] = $66;
       HEAP32[$38>>2] = $34;
       $68 = $41 & 65525;
       $69 = $68&65535;
       HEAP16[$24>>1] = $69;
       break;
      }
     }
    }
   }
  } while(0);
  $70 = (($i$01) + 1)|0;
  $exitcond = ($70|0)==($10|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $70;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim16onRbShapeChangeVERKNS_16PxvParticleShapeEjj($this,$particleShape,$shape,$0) {
 $this = $this|0;
 $particleShape = $particleShape|0;
 $shape = $shape|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $shape;
 $5 = (($4) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(5);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($particleShape) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($9) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($9) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($15))|0;
 $19 = ($15>>>0)<($18>>>0);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = (($this) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $i$01$i = $15;
 while(1) {
  $22 = (($21) + ($i$01$i<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($13) + ($23<<5)|0) + 30|0);
  $25 = HEAP16[$24>>1]|0;
  $26 = $25 & 48;
  $27 = ($26<<16>>16)==(0);
  if (!($27)) {
   $28 = ((($2) + ($23<<5)|0) + 28|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==($5|0);
   if ($30) {
    $31 = $25&65535;
    $32 = $31 & 65487;
    $33 = $32&65535;
    HEAP16[$24>>1] = $33;
   }
  }
  $34 = (($i$01$i) + 1)|0;
  $exitcond$i = ($34|0)==($18|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $34;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim19passCollisionInputVENS_31PxvParticleCollisionUpdateInputE($this,$input) {
 $this = $this|0;
 $input = $input|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$input>>2]|0;
 $1 = (($this) + 1320|0);
 HEAP32[$1>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim15addInteractionVERKNS_16PxvParticleShapeEjjbb($this,$0,$1,$2,$3,$4) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsParticleSystemSim32flushBufferedInteractionUpdatesVEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_25spatialHashUpdateSectionsEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_25spatialHashUpdateSectionsEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_25spatialHashUpdateSectionsEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx19PxsFluidSpatialHash20updatePacketSectionsEPjPNS_16PxsFluidParticleEPNS_10PxBaseTaskE($5,$7,$11,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_21collisionFinalizationEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_21collisionFinalizationEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_21collisionFinalizationEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1320|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$4);
 HEAP32[$3>>2] = 0;
 $5 = (($2) + 16|0);
 HEAP32[$5>>2] = 1;
 $6 = (($2) + 32|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 28|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_15collisionUpdateEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_15collisionUpdateEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_15collisionUpdateEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx20PxsParticleSystemSim15collisionUpdateEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_14dynamicsUpdateEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_14dynamicsUpdateEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_14dynamicsUpdateEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($1) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * Math_fround(0.100000001490116119385));
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($12 * $12);
 $14 = Math_fround($12 * $13);
 $15 = (($8) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($1) + 100|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($14 * Math_fround(3.14159274101257324219));
 $20 = Math_fround(Math_fround(45.0) / $19);
 $21 = Math_fround($16 * $20);
 $22 = Math_fround($18 * $21);
 $23 = (($1) + 136|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($8) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 65536;
 $27 = ($26|0)==(0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (($1) + 80|0);
 __ZN5physx16PxsFluidDynamics9updateSphERNS_10PxBaseTaskE($28,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_24packetShapesFinalizationEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_24packetShapesFinalizationEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_24packetShapesFinalizationEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1312|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 1316|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx20PxsParticleSystemSim20remapShapesToPacketsEPKPNS_16PxvParticleShapeEj($2,$4,$6);
 $7 = HEAP32[$3>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_18packetShapesUpdateEPNS_10PxBaseTaskEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((434896 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_18packetShapesUpdateEPNS_10PxBaseTaskEEEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_18packetShapesUpdateEPNS_10PxBaseTaskEEEE11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx20PxsParticleSystemSim18packetShapesUpdateEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx12PxsRigidBody23updatePoseDependenciesVERNS_10PxsContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1073741823);
 if (!($2)) {
  $3 = (($context) + 5916|0);
  $4 = (($1) + 32)|0;
  $5 = $4 >>> 5;
  $6 = (($context) + 5920|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & 2147483647;
  $9 = ($5>>>0)>($8>>>0);
  if ($9) {
   $10 = (($context) + 5924|0);
   $11 = $5 << 2;
   $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($10,$11,501240,339)|0);
   $13 = HEAP32[$3>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    $15 = HEAP32[$6>>2]|0;
    $16 = $15 << 2;
    _memcpy(($12|0),($13|0),($16|0))|0;
    $17 = HEAP32[$6>>2]|0;
    $18 = ($17|0)>(-1);
    if ($18) {
     $19 = HEAP32[$3>>2]|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($10,$19);
    }
   }
   $20 = HEAP32[$6>>2]|0;
   $21 = $20 & 2147483647;
   $22 = (($12) + ($21<<2)|0);
   $23 = (($5) - ($20))|0;
   $24 = $23 << 2;
   _memset(($22|0),0,($24|0))|0;
   HEAP32[$3>>2] = $12;
   HEAP32[$6>>2] = $5;
   $29 = $12;
  } else {
   $$pre$i = HEAP32[$3>>2]|0;
   $29 = $$pre$i;
  }
  $25 = $1 & 31;
  $26 = 1 << $25;
  $27 = $1 >>> 5;
  $28 = (($29) + ($27<<2)|0);
  $30 = HEAP32[$28>>2]|0;
  $31 = $30 | $26;
  HEAP32[$28>>2] = $31;
 }
 $32 = (($context) + 1448|0);
 $33 = (($this) + 64|0);
 $34 = (($context) + 5840|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$33>>2]|0;
 $38 = (__ZNK5physx21PxsBodyTransformVault17isInVaultInternalERKNS_11PxsBodyCoreE($32,$37)|0);
 if (!($38)) {
  STACKTOP = sp;return;
 }
 $39 = HEAP32[$33>>2]|0;
 __ZN5physx21PxsBodyTransformVault12teleportBodyERKNS_11PxsBodyCoreE($32,$39);
 STACKTOP = sp;return;
}
function __ZN5physx16copyToSolverBodyERNS_13PxcSolverBodyERNS_17PxcSolverBodyDataERKNS_11PxsBodyCoreERNS_12PxsRigidBodyE($solverBody,$data,$core,$body) {
 $solverBody = $solverBody|0;
 $data = $data|0;
 $core = $core|0;
 $body = $body|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0;
 var $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 44|0);
 HEAP32[$0>>2] = $solverBody;
 $1 = (($data) + 40|0);
 HEAP32[$1>>2] = $body;
 $2 = (($core) + 64|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$solverBody>>2] = $3;
 $4 = (($core) + 68|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($solverBody) + 4|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($core) + 72|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($solverBody) + 8|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($core) + 80|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($solverBody) + 16|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($core) + 84|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($solverBody) + 20|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($core) + 88|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($solverBody) + 24|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($core) + 124|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($data) + 48|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($core) + 76|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($data) + 52|0);
 HEAPF32[$24>>2] = $23;
 $25 = Math_fround(HEAPF32[$core>>2]);
 $26 = (($core) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($core) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($core) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($25 + $25);
 $33 = Math_fround($27 + $27);
 $34 = Math_fround($29 + $29);
 $35 = Math_fround($25 * $32);
 $36 = Math_fround($27 * $33);
 $37 = Math_fround($29 * $34);
 $38 = Math_fround($32 * $27);
 $39 = Math_fround($32 * $29);
 $40 = Math_fround($32 * $31);
 $41 = Math_fround($33 * $29);
 $42 = Math_fround($33 * $31);
 $43 = Math_fround($34 * $31);
 $44 = Math_fround(Math_fround(1.0) - $36);
 $45 = Math_fround($44 - $37);
 $46 = Math_fround($38 + $43);
 $47 = Math_fround($39 - $42);
 $48 = Math_fround($38 - $43);
 $49 = Math_fround(Math_fround(1.0) - $35);
 $50 = Math_fround($49 - $37);
 $51 = Math_fround($41 + $40);
 $52 = Math_fround($39 + $42);
 $53 = Math_fround($41 - $40);
 $54 = Math_fround($49 - $36);
 $55 = (($core) + 112|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 * $45);
 $58 = Math_fround($56 * $46);
 $59 = Math_fround($56 * $47);
 $60 = (($core) + 116|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 * $48);
 $63 = Math_fround($61 * $50);
 $64 = Math_fround($61 * $51);
 $65 = (($core) + 120|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($52 * $66);
 $68 = Math_fround($53 * $66);
 $69 = Math_fround($54 * $66);
 $70 = Math_fround($45 * $57);
 $71 = Math_fround($48 * $62);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($52 * $67);
 $74 = Math_fround($72 + $73);
 HEAPF32[$data>>2] = $74;
 $75 = Math_fround($46 * $58);
 $76 = Math_fround($50 * $63);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($53 * $68);
 $79 = Math_fround($77 + $78);
 $80 = (($data) + 12|0);
 $81 = (($80) + 4|0);
 HEAPF32[$81>>2] = $79;
 $82 = Math_fround($47 * $59);
 $83 = Math_fround($51 * $64);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($54 * $69);
 $86 = Math_fround($84 + $85);
 $87 = (($data) + 24|0);
 $88 = (($87) + 8|0);
 HEAPF32[$88>>2] = $86;
 $89 = Math_fround($46 * $57);
 $90 = Math_fround($50 * $62);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($53 * $67);
 $93 = Math_fround($91 + $92);
 $94 = (($data) + 4|0);
 HEAPF32[$94>>2] = $93;
 HEAPF32[$80>>2] = $93;
 $95 = Math_fround($47 * $57);
 $96 = Math_fround($51 * $62);
 $97 = Math_fround($95 + $96);
 $98 = Math_fround($54 * $67);
 $99 = Math_fround($97 + $98);
 $100 = (($data) + 8|0);
 HEAPF32[$100>>2] = $99;
 HEAPF32[$87>>2] = $99;
 $101 = Math_fround($47 * $58);
 $102 = Math_fround($51 * $63);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($54 * $68);
 $105 = Math_fround($103 + $104);
 $106 = (($80) + 8|0);
 HEAPF32[$106>>2] = $105;
 $107 = (($87) + 4|0);
 HEAPF32[$107>>2] = $105;
 $108 = (($core) + 92|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($data) + 36|0);
 HEAPF32[$110>>2] = $109;
 STACKTOP = sp;return;
}
function __ZN5physx17SapUpdateWorkTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx23PxsBroadPhaseContextSap9updatePPUEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx21SapPostUpdateWorkTask11runInternalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx23PxsBroadPhaseContextSap13postUpdatePPUEPNS_10PxBaseTaskE($1,$3);
 STACKTOP = sp;return;
}
function __ZN5physx19PxsSimObjectFactoryC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,296,501408,47)|0);
 HEAP32[$this>>2] = $1;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 4|0);
 $4 = (($1) + 260|0);
 $5 = (($1) + 264|0);
 $6 = (($1) + 272|0);
 _memset(($1|0),0,292)|0;
 HEAP8[$4>>0] = 1;
 HEAP32[$5>>2] = $3;
 HEAP32[$6>>2] = 64;
 $7 = (($1) + 276|0);
 HEAP32[$7>>2] = 32;
 $8 = (($1) + 280|0);
 HEAP32[$8>>2] = 0;
 $9 = (($1) + 284|0);
 HEAP32[$9>>2] = 0;
 $10 = (($1) + 288|0);
 HEAP32[$10>>2] = 2048;
 $11 = (($1) + 292|0);
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx19PxsSimObjectFactoryD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd8PoolBaseINS_15PxsArticulationENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEED2Ev($1);
 $2 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 STACKTOP = sp;return;
}
function __ZN5physx19PxsSimObjectFactory18createArticulationEv($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 292|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN5physx6shdfnd8PoolBaseINS_15PxsArticulationENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE12allocateSlabEv($0);
  $$pre$i$i = HEAP32[$1>>2]|0;
  $5 = $$pre$i$i;
 } else {
  $5 = $2;
 }
 $4 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $4;
 $6 = (($0) + 280|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 HEAP32[$6>>2] = $8;
 $9 = (($0) + 284|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + -1)|0;
 HEAP32[$9>>2] = $11;
 $12 = ($5|0)==(0|0);
 if ($12) {
  $13 = 0;
  STACKTOP = sp;return ($13|0);
 }
 __ZN5physx15PxsArticulationC2Ev($5);
 $13 = $5;
 STACKTOP = sp;return ($13|0);
}
function __ZN5physx19PxsSimObjectFactory19destroyArticulationERNS_15PxsArticulationE($this,$articulation) {
 $this = $this|0;
 $articulation = $articulation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($articulation|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 280|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($0) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$articulation>>2] = $6;
 HEAP32[$5>>2] = $articulation;
 $7 = (($0) + 284|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 1)|0;
 HEAP32[$7>>2] = $9;
 $10 = (($0) + 276|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11*50)|0;
 $13 = ($8|0)<($12|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd8PoolBaseINS_15PxsArticulationENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE17releaseEmptySlabsEv($0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_15PxsArticulationENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE17releaseEmptySlabsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre28 = 0, $$promoted = 0, $$sum = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $freeIt$014 = 0, $freeIt$1$lcssa = 0, $freeIt$19 = 0;
 var $freeIt$2 = 0, $freeIt$3$ph = 0, $freeIt$3$ph22 = 0, $freeIt$36 = 0, $freeNodes = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $scevgep = 0, $slabIt$012 = 0, $slabNodes = 0, $uglygep = 0, $uglygep23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 16|0;
 $slabNodes = sp;
 $0 = sp + 12|0;
 $1 = sp + 29|0;
 $2 = sp + 28|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 4|0);
 __ZN5physx6shdfnd5ArrayIPvNS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE4copyINS0_15InlineAllocatorILj256ES5_EEEEvRKNS1_IS2_T_EE($slabNodes,$5);
 $6 = (($this) + 292|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = $7;
  while(1) {
   HEAP32[$0>>2] = $9;
   $10 = HEAP32[$4>>2]|0;
   $11 = $10 & 2147483647;
   $12 = HEAP32[$3>>2]|0;
   $13 = ($11>>>0)>($12>>>0);
   if ($13) {
    $14 = HEAP32[$freeNodes>>2]|0;
    $15 = (($14) + ($12<<2)|0);
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     HEAP32[$15>>2] = $9;
    }
    $17 = (($12) + 1)|0;
    HEAP32[$3>>2] = $17;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $18 = HEAP32[$6>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$6>>2] = $19;
   $20 = ($19|0)==(0|0);
   if ($20) {
    break;
   } else {
    $9 = $19;
   }
  }
 }
 $21 = HEAP32[$freeNodes>>2]|0;
 $22 = HEAP32[$3>>2]|0;
 $23 = (($21) + ($22<<2)|0);
 $24 = (($this) + 276|0);
 $25 = HEAP32[$24>>2]|0;
 $$sum5 = (($22) - ($25))|0;
 $26 = (($21) + ($$sum5<<2)|0);
 $27 = ($22>>>0)>($25>>>0);
 if ($27) {
  __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEEEvPT_jRKT0_RKT1_($21,$22,$1,$this);
  $28 = HEAP32[$slabNodes>>2]|0;
  $29 = (($slabNodes) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEEEvPT_jRKT0_RKT1_($28,$30,$2,$this);
  $31 = (($this) + 268|0);
  HEAP32[$31>>2] = 0;
  $32 = HEAP32[$slabNodes>>2]|0;
  $33 = HEAP32[$29>>2]|0;
  $34 = (($32) + ($33<<2)|0);
  $35 = ($33|0)==(0);
  if ($35) {
   $freeIt$3$ph = $21;
  } else {
   $36 = (($this) + 288|0);
   $37 = (($this) + 272|0);
   $38 = (($this) + 264|0);
   $39 = (($this) + 284|0);
   $freeIt$014 = $21;$slabIt$012 = $32;
   while(1) {
    $40 = ($freeIt$014>>>0)<($26>>>0);
    $41 = HEAP32[$slabIt$012>>2]|0;
    L17: do {
     if ($40) {
      $50 = $41;$freeIt$19 = $freeIt$014;
      while(1) {
       $48 = HEAP32[$freeIt$19>>2]|0;
       $49 = ($50>>>0)>($48>>>0);
       if (!($49)) {
        $59 = $50;$freeIt$1$lcssa = $freeIt$19;
        break L17;
       }
       $51 = HEAP32[$6>>2]|0;
       HEAP32[$48>>2] = $51;
       HEAP32[$6>>2] = $48;
       $52 = HEAP32[$39>>2]|0;
       $53 = (($52) + 1)|0;
       HEAP32[$39>>2] = $53;
       $54 = (($freeIt$19) + 4|0);
       $55 = ($54>>>0)<($26>>>0);
       $56 = HEAP32[$slabIt$012>>2]|0;
       if ($55) {
        $50 = $56;$freeIt$19 = $54;
       } else {
        $59 = $56;$freeIt$1$lcssa = $54;
        break;
       }
      }
     } else {
      $59 = $41;$freeIt$1$lcssa = $freeIt$014;
     }
    } while(0);
    $57 = HEAP32[$freeIt$1$lcssa>>2]|0;
    $58 = ($59|0)==($57|0);
    if ($58) {
     $60 = $59;
     $61 = HEAP32[$36>>2]|0;
     $62 = (($61) + ($60))|0;
     $63 = HEAP32[$24>>2]|0;
     $$sum = (($63) + -1)|0;
     $64 = (($freeIt$1$lcssa) + ($$sum<<2)|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = $65;
     $67 = (($66) + 64)|0;
     $68 = ($67|0)==($62|0);
     if ($68) {
      $69 = ($59|0)==(0|0);
      if ($69) {
       $75 = $63;
      } else {
       $70 = (($59) + -4|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = (0 - ($71))|0;
       $73 = (($59) + ($72)|0);
       __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$73);
       $$pre = HEAP32[$24>>2]|0;
       $75 = $$pre;
      }
      $74 = (($freeIt$1$lcssa) + ($75<<2)|0);
      $freeIt$2 = $74;
     } else {
      label = 21;
     }
    } else {
     label = 21;
    }
    do {
     if ((label|0) == 21) {
      label = 0;
      $76 = HEAP32[$37>>2]|0;
      $77 = $76 & 2147483647;
      $78 = HEAP32[$31>>2]|0;
      $79 = ($77>>>0)>($78>>>0);
      if (!($79)) {
       (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEEEE15growAndPushBackERKS2_($5,$slabIt$012)|0);
       $freeIt$2 = $freeIt$1$lcssa;
       break;
      }
      $80 = HEAP32[$38>>2]|0;
      $81 = (($80) + ($78<<2)|0);
      $82 = ($81|0)==(0|0);
      if (!($82)) {
       HEAP32[$81>>2] = $59;
      }
      $83 = (($78) + 1)|0;
      HEAP32[$31>>2] = $83;
      $freeIt$2 = $freeIt$1$lcssa;
     }
    } while(0);
    $84 = (($slabIt$012) + 4|0);
    $85 = ($84|0)==($34|0);
    if ($85) {
     $freeIt$3$ph = $freeIt$2;
     break;
    } else {
     $freeIt$014 = $freeIt$2;$slabIt$012 = $84;
    }
   }
  }
 } else {
  $freeIt$3$ph = $21;
 }
 $42 = ($freeIt$3$ph|0)==($23|0);
 if (!($42)) {
  $freeIt$3$ph22 = $freeIt$3$ph;
  $43 = (($this) + 284|0);
  $$promoted = HEAP32[$43>>2]|0;
  $44 = (($22) + -1)|0;
  $scevgep = (($21) + ($44<<2)|0);
  $45 = (0 - ($freeIt$3$ph22))|0;
  $uglygep = (($scevgep) + ($45)|0);
  $uglygep23 = $uglygep;
  $46 = $uglygep23 >>> 2;
  $47 = (($$promoted) + ($46))|0;
  $$pre28 = HEAP32[$6>>2]|0;
  $87 = $$pre28;$freeIt$36 = $freeIt$3$ph;
  while(1) {
   $86 = HEAP32[$freeIt$36>>2]|0;
   HEAP32[$86>>2] = $87;
   HEAP32[$6>>2] = $86;
   $88 = (($freeIt$36) + 4|0);
   $89 = ($88|0)==($23|0);
   if ($89) {
    break;
   } else {
    $87 = $86;$freeIt$36 = $88;
   }
  }
  $90 = (($47) + 1)|0;
  HEAP32[$43>>2] = $90;
 }
 $91 = (($slabNodes) + 8|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = $92 & 2147483647;
 $94 = ($93|0)!=(0);
 $95 = ($92|0)>(-1);
 $or$cond$i$i1 = $94 & $95;
 if ($or$cond$i$i1) {
  $96 = HEAP32[$slabNodes>>2]|0;
  $97 = ($96|0)==(0|0);
  if (!($97)) {
   $98 = (($96) + -4|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (0 - ($99))|0;
   $101 = (($96) + ($100)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($slabNodes,$101);
  }
 }
 $102 = HEAP32[$4>>2]|0;
 $103 = $102 & 2147483647;
 $104 = ($103|0)!=(0);
 $105 = ($102|0)>(-1);
 $or$cond$i$i = $104 & $105;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $106 = HEAP32[$freeNodes>>2]|0;
 $107 = ($106|0)==(0|0);
 if ($107) {
  STACKTOP = sp;return;
 }
 $108 = (($106) + -4|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = (0 - ($109))|0;
 $111 = (($106) + ($110)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($freeNodes,$111);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$0$i$i$i = 0, $$0$i$i$i6 = 0, $$ph = 0, $$ph18 = 0, $$pr = 0, $$pr33 = 0, $$pr37 = 0, $$pr38 = 0, $$pr39 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i2 = 0, $$pre$i8 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0, $m$01$i = 0, $or$cond = 0, $stack = 0, $stackMem = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $stackMem = sp;
 $stack = sp + 136|0;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($stack) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($stack) + 8|0);
 HEAP32[$7>>2] = 32;
 $8 = (($stack) + 12|0);
 HEAP32[$8>>2] = $5;
 $9 = (($stack) + 16|0);
 HEAP8[$9>>0] = 0;
 $10 = (($count) + -1)|0;
 $11 = ($10|0)>(0);
 if ($11) {
  $$ph = 0;$$ph18 = $10;$$pr33 = 0;$150 = $5;
  L3: while(1) {
   $12 = ($$ph18|0)>($$ph|0);
   L5: do {
    if ($12) {
     $13 = (($elements) + ($$ph<<2)|0);
     $$pr38 = $$pr33;$$pre1$i = $150;$15 = $$ph18;
     while(1) {
      $14 = (($15) - ($$ph))|0;
      $16 = ($14>>>0)<(5);
      if ($16) {
       $i$03$i = $$ph;
       label = 6;
       break;
      }
      $29 = (($15) + ($$ph))|0;
      $30 = (($29|0) / 2)&-1;
      $31 = (($elements) + ($30<<2)|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = HEAP32[$13>>2]|0;
      $34 = ($32>>>0)<($33>>>0);
      if ($34) {
       HEAP32[$13>>2] = $32;
       HEAP32[$31>>2] = $33;
       $$pre$i$i = HEAP32[$13>>2]|0;
       $151 = $33;$38 = $$pre$i$i;
      } else {
       $151 = $32;$38 = $33;
      }
      $35 = (($elements) + ($15<<2)|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($36>>>0)<($38>>>0);
      if ($37) {
       HEAP32[$13>>2] = $36;
       HEAP32[$35>>2] = $38;
       $$pre1$i$i = HEAP32[$31>>2]|0;
       $40 = $38;$41 = $$pre1$i$i;
      } else {
       $40 = $36;$41 = $151;
      }
      $39 = ($40>>>0)<($41>>>0);
      if ($39) {
       HEAP32[$31>>2] = $40;
       HEAP32[$35>>2] = $41;
       $$pre2$i$i = HEAP32[$31>>2]|0;
       $45 = $$pre2$i$i;
      } else {
       $45 = $41;
      }
      $42 = (($15) + -1)|0;
      $43 = (($elements) + ($42<<2)|0);
      $44 = HEAP32[$43>>2]|0;
      HEAP32[$31>>2] = $44;
      HEAP32[$43>>2] = $45;
      $50 = $45;$i$0$ph$i = $$ph;$j$0$ph$i = $42;
      while(1) {
       $i$0$i = $i$0$ph$i;
       while(1) {
        $46 = (($i$0$i) + 1)|0;
        $47 = (($elements) + ($46<<2)|0);
        $48 = HEAP32[$47>>2]|0;
        $49 = ($48>>>0)<($50>>>0);
        if ($49) {
         $i$0$i = $46;
        } else {
         $j$1$i = $j$0$ph$i;
         break;
        }
       }
       while(1) {
        $51 = (($j$1$i) + -1)|0;
        $52 = (($elements) + ($51<<2)|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($50>>>0)<($53>>>0);
        if ($54) {
         $j$1$i = $51;
        } else {
         break;
        }
       }
       $55 = ($46|0)<($51|0);
       if (!($55)) {
        break;
       }
       HEAP32[$47>>2] = $53;
       HEAP32[$52>>2] = $48;
       $$pre$i2 = HEAP32[$43>>2]|0;
       $50 = $$pre$i2;$i$0$ph$i = $46;$j$0$ph$i = $51;
      }
      HEAP32[$47>>2] = $50;
      HEAP32[$43>>2] = $48;
      $56 = (($46) - ($$ph))|0;
      $57 = (($15) - ($46))|0;
      $58 = ($56|0)<($57|0);
      if ($58) {
       break;
      }
      $95 = (($i$0$i) + 2)|0;
      $96 = HEAP32[$6>>2]|0;
      $97 = HEAP32[$7>>2]|0;
      $98 = (($97) + -1)|0;
      $99 = ($96>>>0)<($98>>>0);
      if ($99) {
       $$pr39 = $$pr38;$125 = $96;$127 = $$pre1$i;
      } else {
       $100 = $97 << 1;
       HEAP32[$7>>2] = $100;
       $101 = $97 << 3;
       $102 = (($101) + 67)|0;
       $103 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($stack,$102,501584,148)|0);
       $104 = ($103|0)==(0|0);
       if ($104) {
        $$0$i$i$i = 0;
       } else {
        $105 = (($103) + 67|0);
        $106 = $105;
        $107 = $106 & -64;
        $108 = $107;
        $109 = $103;
        $110 = (($107) - ($109))|0;
        $111 = $107;
        $112 = (($111) + -4|0);
        HEAP32[$112>>2] = $110;
        $$0$i$i$i = $108;
       }
       $113 = HEAP32[$8>>2]|0;
       $114 = HEAP32[$6>>2]|0;
       $115 = $114 << 2;
       _memcpy(($$0$i$i$i|0),($113|0),($115|0))|0;
       $116 = HEAP8[$9>>0]|0;
       $117 = ($116<<24>>24)==(0);
       if (!($117)) {
        $118 = HEAP32[$8>>2]|0;
        $119 = ($118|0)==(0|0);
        if (!($119)) {
         $120 = (($118) + -4|0);
         $121 = HEAP32[$120>>2]|0;
         $122 = (0 - ($121))|0;
         $123 = (($118) + ($122)|0);
         __ZN5physx6shdfnd9Allocator10deallocateEPv($stack,$123);
        }
       }
       HEAP8[$9>>0] = 1;
       HEAP32[$8>>2] = $$0$i$i$i;
       $$pre$i = HEAP32[$6>>2]|0;
       $$pr39 = 1;$125 = $$pre$i;$127 = $$0$i$i$i;
      }
      $124 = (($125) + 1)|0;
      HEAP32[$6>>2] = $124;
      $126 = (($127) + ($125<<2)|0);
      HEAP32[$126>>2] = $95;
      $128 = HEAP32[$6>>2]|0;
      $129 = (($128) + 1)|0;
      HEAP32[$6>>2] = $129;
      $130 = (($127) + ($128<<2)|0);
      HEAP32[$130>>2] = $15;
      $131 = ($i$0$i|0)>($$ph|0);
      if ($131) {
       $$pr38 = $$pr39;$$pre1$i = $127;$15 = $i$0$i;
      } else {
       $$pr = $$pr39;$136 = $127;
       break L5;
      }
     }
     if ((label|0) == 6) {
      while(1) {
       label = 0;
       $17 = (($i$03$i) + 1)|0;
       $j$02$i = $17;$m$01$i = $i$03$i;
       while(1) {
        $18 = (($elements) + ($j$02$i<<2)|0);
        $19 = (($elements) + ($m$01$i<<2)|0);
        $20 = HEAP32[$18>>2]|0;
        $21 = HEAP32[$19>>2]|0;
        $22 = ($20>>>0)<($21>>>0);
        $j$0$m$0$i = $22 ? $j$02$i : $m$01$i;
        $23 = (($j$02$i) + 1)|0;
        $24 = ($j$02$i|0)<($15|0);
        if ($24) {
         $j$02$i = $23;$m$01$i = $j$0$m$0$i;
        } else {
         break;
        }
       }
       $25 = (($elements) + ($j$0$m$0$i<<2)|0);
       $26 = (($elements) + ($i$03$i<<2)|0);
       $27 = HEAP32[$25>>2]|0;
       $28 = HEAP32[$26>>2]|0;
       HEAP32[$25>>2] = $28;
       HEAP32[$26>>2] = $27;
       $exitcond$i = ($17|0)==($15|0);
       if ($exitcond$i) {
        $$pr = $$pr38;$136 = $$pre1$i;
        break L5;
       } else {
        $i$03$i = $17;
        label = 6;
       }
      }
     }
     $59 = HEAP32[$6>>2]|0;
     $60 = HEAP32[$7>>2]|0;
     $61 = (($60) + -1)|0;
     $62 = ($59>>>0)<($61>>>0);
     if ($62) {
      $$pr37 = $$pr38;$88 = $59;$90 = $$pre1$i;
     } else {
      $63 = $60 << 1;
      HEAP32[$7>>2] = $63;
      $64 = $60 << 3;
      $65 = (($64) + 67)|0;
      $66 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($stack,$65,501584,148)|0);
      $67 = ($66|0)==(0|0);
      if ($67) {
       $$0$i$i$i6 = 0;
      } else {
       $68 = (($66) + 67|0);
       $69 = $68;
       $70 = $69 & -64;
       $71 = $70;
       $72 = $66;
       $73 = (($70) - ($72))|0;
       $74 = $70;
       $75 = (($74) + -4|0);
       HEAP32[$75>>2] = $73;
       $$0$i$i$i6 = $71;
      }
      $76 = HEAP32[$8>>2]|0;
      $77 = HEAP32[$6>>2]|0;
      $78 = $77 << 2;
      _memcpy(($$0$i$i$i6|0),($76|0),($78|0))|0;
      $79 = HEAP8[$9>>0]|0;
      $80 = ($79<<24>>24)==(0);
      if (!($80)) {
       $81 = HEAP32[$8>>2]|0;
       $82 = ($81|0)==(0|0);
       if (!($82)) {
        $83 = (($81) + -4|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = (0 - ($84))|0;
        $86 = (($81) + ($85)|0);
        __ZN5physx6shdfnd9Allocator10deallocateEPv($stack,$86);
       }
      }
      HEAP8[$9>>0] = 1;
      HEAP32[$8>>2] = $$0$i$i$i6;
      $$pre$i8 = HEAP32[$6>>2]|0;
      $$pr37 = 1;$88 = $$pre$i8;$90 = $$0$i$i$i6;
     }
     $87 = (($88) + 1)|0;
     HEAP32[$6>>2] = $87;
     $89 = (($90) + ($88<<2)|0);
     HEAP32[$89>>2] = $$ph;
     $91 = HEAP32[$6>>2]|0;
     $92 = (($91) + 1)|0;
     HEAP32[$6>>2] = $92;
     $93 = (($90) + ($91<<2)|0);
     HEAP32[$93>>2] = $i$0$i;
     $94 = (($i$0$i) + 2)|0;
     $$ph = $94;$$ph18 = $15;$$pr33 = $$pr37;$150 = $90;
     continue L3;
    } else {
     $$pr = $$pr33;$136 = $150;
    }
   } while(0);
   $132 = HEAP32[$6>>2]|0;
   $133 = ($132|0)==(0);
   if ($133) {
    break;
   }
   $134 = (($132) + -1)|0;
   HEAP32[$6>>2] = $134;
   $135 = (($136) + ($134<<2)|0);
   $137 = HEAP32[$135>>2]|0;
   $138 = (($132) + -2)|0;
   HEAP32[$6>>2] = $138;
   $139 = (($136) + ($138<<2)|0);
   $140 = HEAP32[$139>>2]|0;
   $$ph = $140;$$ph18 = $137;$$pr33 = $$pr;$150 = $136;
  }
  $141 = ($$pr<<24>>24)==(0);
  $142 = ($136|0)==(0|0);
  $or$cond = $141 | $142;
  if (!($or$cond)) {
   $143 = (($136) + -4|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = (0 - ($144))|0;
   $146 = (($136) + ($145)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($stack,$146);
  }
 }
 $147 = HEAP8[$4>>0]|0;
 $148 = ($147<<24>>24)==(0);
 if ($148) {
  STACKTOP = sp;return;
 }
 $149 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$149);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($this) + 256|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(257);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = (($6) + 67)|0;
   $12 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$11,501504,558)|0);
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$i$i = 0;
   } else {
    $14 = (($12) + 67|0);
    $15 = $14;
    $16 = $15 & -64;
    $17 = $16;
    $18 = $12;
    $19 = (($16) - ($18))|0;
    $20 = $16;
    $21 = (($20) + -4|0);
    HEAP32[$21>>2] = $19;
    $$0$i$i = $17;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 264|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<2)|0);
 $26 = (($this) + 260|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $30;
   }
   $31 = (($$012$i) + 4|0);
   $32 = (($$03$i) + 4|0);
   $33 = ($31>>>0)<($24>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
 }
 $34 = ($24|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$a>>2]|0;
  HEAP32[$24>>2] = $35;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = ($36|0)>(-1);
 do {
  if ($37) {
   $38 = HEAP32[$26>>2]|0;
   $39 = ($this|0)==($38|0);
   if ($39) {
    $40 = (($this) + 256|0);
    HEAP8[$40>>0] = 0;
    $47 = $23;
    break;
   }
   $41 = ($38|0)==(0|0);
   if ($41) {
    $47 = $23;
   } else {
    $42 = (($38) + -4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (0 - ($43))|0;
    $45 = (($38) + ($44)|0);
    __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$45);
    $$pre = HEAP32[$22>>2]|0;
    $47 = $$pre;
   }
  } else {
   $47 = $23;
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $46 = (($47) + 1)|0;
 HEAP32[$22>>2] = $46;
 $48 = (($25) + ($47<<2)|0);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $20 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = (($6) + 67)|0;
  $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$7,501504,558)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $20 = 0;
  } else {
   $10 = (($8) + 67|0);
   $11 = $10;
   $12 = $11 & -64;
   $13 = $8;
   $14 = (($12) - ($13))|0;
   $15 = $12;
   $16 = (($15) + -4|0);
   HEAP32[$16>>2] = $14;
   $phitmp$i = $12;
   $20 = $phitmp$i;
  }
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<2)|0);
 $21 = ($18|0)>(0);
 if ($21) {
  $22 = HEAP32[$this>>2]|0;
  $$012$i = $20;$$03$i = $22;
  while(1) {
   $23 = ($$012$i|0)==(0|0);
   if (!($23)) {
    $24 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $24;
   }
   $25 = (($$012$i) + 4|0);
   $26 = (($$03$i) + 4|0);
   $27 = ($25>>>0)<($19>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
 }
 $28 = ($19|0)==(0|0);
 if (!($28)) {
  $29 = HEAP32[$a>>2]|0;
  HEAP32[$19>>2] = $29;
 }
 $30 = HEAP32[$0>>2]|0;
 $31 = ($30|0)>(-1);
 if ($31) {
  $32 = HEAP32[$this>>2]|0;
  $33 = ($32|0)==(0|0);
  if ($33) {
   $39 = $18;
  } else {
   $34 = (($32) + -4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (0 - ($35))|0;
   $37 = (($32) + ($36)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$37);
   $$pre = HEAP32[$17>>2]|0;
   $39 = $$pre;
  }
 } else {
  $39 = $18;
 }
 HEAP32[$this>>2] = $20;
 HEAP32[$0>>2] = $$$i;
 $38 = (($39) + 1)|0;
 HEAP32[$17>>2] = $38;
 $40 = (($20) + ($39<<2)|0);
 STACKTOP = sp;return ($40|0);
}
function __ZN5physx6shdfnd5ArrayIPvNS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE4copyINS0_15InlineAllocatorILj256ES5_EEEEvRKNS1_IS2_T_EE($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 264|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $27 = (($this) + 4|0);
  HEAP32[$27>>2] = 0;
  $28 = (($this) + 8|0);
  HEAP32[$28>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $1;
 $5 = $1 << 2;
 $6 = (($5) + 67)|0;
 $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$6,501504,558)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  $16 = 0;
 } else {
  $9 = (($7) + 67|0);
  $10 = $9;
  $11 = $10 & -64;
  $12 = $7;
  $13 = (($11) - ($12))|0;
  $14 = $11;
  $15 = (($14) + -4|0);
  HEAP32[$15>>2] = $13;
  $phitmp$i = $11;
  $16 = $phitmp$i;
 }
 HEAP32[$this>>2] = $16;
 $17 = HEAP32[$4>>2]|0;
 $18 = (($16) + ($17<<2)|0);
 $19 = ($17|0)>(0);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = (($other) + 260|0);
 $21 = HEAP32[$20>>2]|0;
 $$012$i = $16;$$03$i = $21;
 while(1) {
  $22 = ($$012$i|0)==(0|0);
  if (!($22)) {
   $23 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $23;
  }
  $24 = (($$012$i) + 4|0);
  $25 = (($$03$i) + 4|0);
  $26 = ($24>>>0)<($18>>>0);
  if ($26) {
   $$012$i = $24;$$03$i = $25;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_15PxsArticulationENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE12allocateSlabEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$pre = 0, $$promoted = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $32$phi = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 67)|0;
 $4 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$3,501672,191)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0$i = 0;
 } else {
  $6 = (($4) + 67|0);
  $7 = $6;
  $8 = $7 & -64;
  $9 = $8;
  $10 = $4;
  $11 = (($8) - ($10))|0;
  $12 = $8;
  $13 = (($12) + -4|0);
  HEAP32[$13>>2] = $11;
  $$0$i = $9;
 }
 HEAP32[$0>>2] = $$0$i;
 $14 = (($this) + 272|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = (($this) + 268|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16>>>0)>($18>>>0);
 if ($19) {
  $21 = (($this) + 264|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + ($18<<2)|0);
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   HEAP32[$23>>2] = $$0$i;
  }
  $25 = (($18) + 1)|0;
  HEAP32[$17>>2] = $25;
 } else {
  $20 = (($this) + 4|0);
  (__ZN5physx6shdfnd5ArrayIPvNS0_15InlineAllocatorILj256ENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEEEE15growAndPushBackERKS2_($20,$0)|0);
 }
 $26 = (($this) + 276|0);
 $27 = HEAP32[$26>>2]|0;
 $$sum = (($27) + -1)|0;
 $28 = (($$0$i) + ($$sum<<6)|0);
 $29 = ($28>>>0)<($$0$i>>>0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($this) + 292|0);
 $31 = (($this) + 284|0);
 $$promoted = HEAP32[$31>>2]|0;
 $$pre = HEAP32[$30>>2]|0;
 $32 = $$pre;$33 = $28;$35 = $$promoted;
 while(1) {
  HEAP32[$33>>2] = $32;
  HEAP32[$30>>2] = $33;
  $34 = (($35) + 1)|0;
  $36 = (($33) + -64|0);
  $37 = ($36>>>0)<($$0$i>>>0);
  if ($37) {
   break;
  } else {
   $32$phi = $33;$33 = $36;$35 = $34;$32 = $32$phi;
  }
 }
 HEAP32[$31>>2] = $34;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_15PxsArticulationENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseINS_15PxsArticulationENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE15disposeElementsEv($this);
 }
 $3 = (($this) + 4|0);
 $4 = (($this) + 264|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 268|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($7<<2)|0);
 $9 = ($7|0)==(0);
 if (!($9)) {
  $slabIt$01 = $5;
  while(1) {
   $10 = HEAP32[$slabIt$01>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = (($10) + -4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (0 - ($13))|0;
    $15 = (($10) + ($14)|0);
    __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$15);
   }
   $16 = (($slabIt$01) + 4|0);
   $17 = ($16|0)==($8|0);
   if ($17) {
    break;
   } else {
    $slabIt$01 = $16;
   }
  }
 }
 $18 = (($this) + 272|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & 2147483647;
 $21 = ($20|0)!=(0);
 $22 = ($19|0)>(-1);
 $or$cond$i$i$i = $21 & $22;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $23 = HEAP32[$4>>2]|0;
 $24 = ($3|0)==($23|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($23|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (($23) + -4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (0 - ($28))|0;
 $30 = (($23) + ($29)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$30);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseINS_15PxsArticulationENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre12 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $freeIt$04 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0, $or$cond$i$i = 0, $phitmp = 0, $slabIt$05 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre15 = HEAP32[$4>>2]|0;
   $$pre16 = HEAP32[$3>>2]|0;
   $phitmp = $$pre15 & 2147483647;
   $10 = $phitmp;$11 = $$pre16;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre12;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_16AlignedAllocatorILj64ENS0_9AllocatorEEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = HEAP32[$freeNodes>>2]|0;
  $30 = (($this) + 276|0);
  $freeIt$04 = $29;$slabIt$05 = $25;
  while(1) {
   $31 = HEAP32[$slabIt$05>>2]|0;
   $32 = HEAP32[$30>>2]|0;
   $33 = (($31) + ($32<<6)|0);
   $34 = ($31|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$04;
   } else {
    $freeIt$11 = $freeIt$04;$tIt$02 = $31;
    while(1) {
     $35 = HEAP32[$freeNodes>>2]|0;
     $36 = HEAP32[$3>>2]|0;
     $37 = (($35) + ($36<<2)|0);
     $38 = ($freeIt$11|0)==($37|0);
     if ($38) {
      label = 16;
     } else {
      $39 = HEAP32[$freeIt$11>>2]|0;
      $40 = ($39|0)==($tIt$02|0);
      if ($40) {
       $41 = (($freeIt$11) + 4|0);
       $freeIt$2 = $41;
      } else {
       label = 16;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $freeIt$2 = $freeIt$11;
     }
     $42 = (($tIt$02) + 64|0);
     $43 = ($42|0)==($33|0);
     if ($43) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $42;
     }
    }
   }
   $44 = (($slabIt$05) + 4|0);
   $45 = ($44|0)==($27|0);
   if ($45) {
    break;
   } else {
    $freeIt$04 = $freeIt$1$lcssa;$slabIt$05 = $44;
   }
  }
 }
 $46 = HEAP32[$4>>2]|0;
 $47 = $46 & 2147483647;
 $48 = ($47|0)!=(0);
 $49 = ($46|0)>(-1);
 $or$cond$i$i = $48 & $49;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$freeNodes>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $52 = (($50) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (0 - ($53))|0;
 $55 = (($50) + ($54)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($freeNodes,$55);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxsSolverExtBody15projectVelocityERKNS_6PxVec3ES3_($this,$linear,$angular) {
 $this = $this|0;
 $linear = $linear|0;
 $angular = $angular|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(-1);
 if ($2) {
  $3 = HEAP32[$this>>2]|0;
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = Math_fround(HEAPF32[$linear>>2]);
  $6 = Math_fround($4 * $5);
  $7 = (($3) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($linear) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround($8 * $10);
  $12 = Math_fround($6 + $11);
  $13 = (($3) + 8|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($linear) + 8|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($14 * $16);
  $18 = Math_fround($12 + $17);
  $19 = (($3) + 16|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround(HEAPF32[$angular>>2]);
  $22 = Math_fround($20 * $21);
  $23 = (($3) + 20|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($angular) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($24 * $26);
  $28 = Math_fround($22 + $27);
  $29 = (($3) + 24|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($angular) + 8|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($30 * $32);
  $34 = Math_fround($28 + $33);
  $35 = Math_fround($18 + $34);
  $$0 = $35;
  STACKTOP = sp;return (Math_fround($$0));
 } else {
  $36 = $1&65535;
  $37 = HEAP32[$this>>2]|0;
  $38 = (($37) + 128|0);
  $39 = (($38) + ($36<<5)|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = ((($38) + ($36<<5)|0) + 4|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = ((($38) + ($36<<5)|0) + 8|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = ((($38) + ($36<<5)|0) + 16|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = ((($38) + ($36<<5)|0) + 20|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = ((($38) + ($36<<5)|0) + 24|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround(HEAPF32[$linear>>2]);
  $52 = (($linear) + 4|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($linear) + 8|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround(HEAPF32[$angular>>2]);
  $57 = (($angular) + 4|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($angular) + 8|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($40 * $51);
  $62 = Math_fround($42 * $53);
  $63 = Math_fround($61 + $62);
  $64 = Math_fround($44 * $55);
  $65 = Math_fround($63 + $64);
  $66 = Math_fround($46 * $56);
  $67 = Math_fround($48 * $58);
  $68 = Math_fround($66 + $67);
  $69 = Math_fround($50 * $60);
  $70 = Math_fround($68 + $69);
  $71 = Math_fround($65 + $70);
  $$0 = $71;
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZNK5physx16PxsSolverExtBody9getLinVelEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0);
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(-1);
 if ($2) {
  $3 = HEAP32[$this>>2]|0;
  $4 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$agg$result>>2] = $4;
  $5 = (($agg$result) + 4|0);
  $6 = (($3) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  HEAPF32[$5>>2] = $7;
  $8 = (($agg$result) + 8|0);
  $9 = (($3) + 8|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$8>>2] = $10;
  STACKTOP = sp;return;
 } else {
  $11 = HEAP32[$this>>2]|0;
  $12 = $1&65535;
  $13 = (($11) + 128|0);
  $14 = (($13) + ($12<<5)|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = ((($13) + ($12<<5)|0) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = ((($13) + ($12<<5)|0) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$agg$result>>2] = $15;
  $20 = (($agg$result) + 4|0);
  HEAPF32[$20>>2] = $17;
  $21 = (($agg$result) + 8|0);
  HEAPF32[$21>>2] = $19;
  STACKTOP = sp;return;
 }
}
function __ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$impulse0,$deltaV0,$dom0,$angDom0,$b1,$impulse1,$deltaV1,$dom1,$angDom1,$0) {
 $b0 = $b0|0;
 $impulse0 = $impulse0|0;
 $deltaV0 = $deltaV0|0;
 $dom0 = Math_fround($dom0);
 $angDom0 = Math_fround($angDom0);
 $b1 = $b1|0;
 $impulse1 = $impulse1|0;
 $deltaV1 = $deltaV1|0;
 $dom1 = Math_fround($dom1);
 $angDom1 = Math_fround($angDom1);
 $0 = $0|0;
 var $$phi$trans$insert10 = 0, $$phi$trans$insert12 = 0, $$phi$trans$insert14 = 0, $$phi$trans$insert16 = 0, $$phi$trans$insert18 = 0, $$pre = Math_fround(0), $$pre11 = Math_fround(0), $$pre13 = Math_fround(0), $$pre15 = Math_fround(0), $$pre17 = Math_fround(0), $$pre19 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0;
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0;
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0);
 var $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0);
 var $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0;
 var $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $1 = sp + 32|0;
 $2 = sp;
 $3 = (($b0) + 8|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(-1);
 if ($5) {
  $6 = Math_fround(HEAPF32[$impulse0>>2]);
  $7 = Math_fround($6 * $dom0);
  $8 = (($impulse0) + 4|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($9 * $dom0);
  $11 = (($impulse0) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($12 * $dom0);
  $14 = (($impulse0) + 16|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($15 * $angDom0);
  $17 = (($impulse0) + 20|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($18 * $angDom0);
  $20 = (($impulse0) + 24|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($21 * $angDom0);
  $23 = (($b0) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 48|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($7 * $26);
  $28 = Math_fround($10 * $26);
  $29 = Math_fround($13 * $26);
  HEAPF32[$deltaV0>>2] = $27;
  $30 = (($deltaV0) + 4|0);
  HEAPF32[$30>>2] = $28;
  $31 = (($deltaV0) + 8|0);
  HEAPF32[$31>>2] = $29;
  $32 = Math_fround(HEAPF32[$24>>2]);
  $33 = Math_fround($16 * $32);
  $34 = (($24) + 4|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($16 * $35);
  $37 = (($24) + 8|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround($16 * $38);
  $40 = (($24) + 12|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($19 * $41);
  $43 = (($24) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($19 * $44);
  $46 = (($24) + 20|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($19 * $47);
  $49 = Math_fround($33 + $42);
  $50 = Math_fround($36 + $45);
  $51 = Math_fround($39 + $48);
  $52 = (($24) + 24|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($22 * $53);
  $55 = (($24) + 28|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($22 * $56);
  $58 = (($24) + 32|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($22 * $59);
  $61 = Math_fround($49 + $54);
  $62 = Math_fround($50 + $57);
  $63 = Math_fround($51 + $60);
  $64 = (($deltaV0) + 16|0);
  HEAPF32[$64>>2] = $61;
  $65 = (($deltaV0) + 20|0);
  HEAPF32[$65>>2] = $62;
  $66 = (($deltaV0) + 24|0);
  HEAPF32[$66>>2] = $63;
 } else {
  $67 = $4&65535;
  $68 = HEAP32[$b0>>2]|0;
  $69 = Math_fround(HEAPF32[$impulse0>>2]);
  $70 = Math_fround($69 * $dom0);
  $71 = (($impulse0) + 4|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($72 * $dom0);
  $74 = (($impulse0) + 8|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($75 * $dom0);
  $77 = (($impulse0) + 16|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($78 * $angDom0);
  $80 = (($impulse0) + 20|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround($81 * $angDom0);
  $83 = (($impulse0) + 24|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = Math_fround($84 * $angDom0);
  HEAPF32[$1>>2] = $70;
  $86 = (($1) + 4|0);
  HEAPF32[$86>>2] = $73;
  $87 = (($1) + 8|0);
  HEAPF32[$87>>2] = $76;
  $88 = (($1) + 12|0);
  HEAPF32[$88>>2] = Math_fround(0.0);
  $89 = (($1) + 16|0);
  HEAPF32[$89>>2] = $79;
  $90 = (($1) + 20|0);
  HEAPF32[$90>>2] = $82;
  $91 = (($1) + 24|0);
  HEAPF32[$91>>2] = $85;
  $92 = (($1) + 28|0);
  HEAPF32[$92>>2] = Math_fround(0.0);
  __ZN5physx21PxcArticulationHelper18getImpulseResponseERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS4_($68,$67,$1,$deltaV0);
 }
 $93 = (($b1) + 8|0);
 $94 = HEAP16[$93>>1]|0;
 $95 = ($94<<16>>16)==(-1);
 if ($95) {
  $96 = Math_fround(HEAPF32[$impulse1>>2]);
  $97 = Math_fround($96 * $dom1);
  $98 = (($impulse1) + 4|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = Math_fround($99 * $dom1);
  $101 = (($impulse1) + 8|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($102 * $dom1);
  $104 = (($impulse1) + 16|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($105 * $angDom1);
  $107 = (($impulse1) + 20|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($108 * $angDom1);
  $110 = (($impulse1) + 24|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround($111 * $angDom1);
  $113 = (($b1) + 4|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (($114) + 48|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = Math_fround($97 * $116);
  $118 = Math_fround($100 * $116);
  $119 = Math_fround($103 * $116);
  HEAPF32[$deltaV1>>2] = $117;
  $120 = (($deltaV1) + 4|0);
  HEAPF32[$120>>2] = $118;
  $121 = (($deltaV1) + 8|0);
  HEAPF32[$121>>2] = $119;
  $122 = Math_fround(HEAPF32[$114>>2]);
  $123 = Math_fround($106 * $122);
  $124 = (($114) + 4|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = Math_fround($106 * $125);
  $127 = (($114) + 8|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = Math_fround($106 * $128);
  $130 = (($114) + 12|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  $132 = Math_fround($109 * $131);
  $133 = (($114) + 16|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($109 * $134);
  $136 = (($114) + 20|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = Math_fround($109 * $137);
  $139 = Math_fround($123 + $132);
  $140 = Math_fround($126 + $135);
  $141 = Math_fround($129 + $138);
  $142 = (($114) + 24|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = Math_fround($112 * $143);
  $145 = (($114) + 28|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = Math_fround($112 * $146);
  $148 = (($114) + 32|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = Math_fround($112 * $149);
  $151 = Math_fround($139 + $144);
  $152 = Math_fround($140 + $147);
  $153 = Math_fround($141 + $150);
  $154 = (($deltaV1) + 16|0);
  HEAPF32[$154>>2] = $151;
  $155 = (($deltaV1) + 20|0);
  HEAPF32[$155>>2] = $152;
  $156 = (($deltaV1) + 24|0);
  HEAPF32[$156>>2] = $153;
  $218 = $117;$222 = $118;$227 = $119;$232 = $151;$236 = $152;$241 = $153;
 } else {
  $157 = $94&65535;
  $158 = HEAP32[$b1>>2]|0;
  $159 = Math_fround(HEAPF32[$impulse1>>2]);
  $160 = Math_fround($159 * $dom1);
  $161 = (($impulse1) + 4|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($162 * $dom1);
  $164 = (($impulse1) + 8|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  $166 = Math_fround($165 * $dom1);
  $167 = (($impulse1) + 16|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = Math_fround($168 * $angDom1);
  $170 = (($impulse1) + 20|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = Math_fround($171 * $angDom1);
  $173 = (($impulse1) + 24|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = Math_fround($174 * $angDom1);
  HEAPF32[$2>>2] = $160;
  $176 = (($2) + 4|0);
  HEAPF32[$176>>2] = $163;
  $177 = (($2) + 8|0);
  HEAPF32[$177>>2] = $166;
  $178 = (($2) + 12|0);
  HEAPF32[$178>>2] = Math_fround(0.0);
  $179 = (($2) + 16|0);
  HEAPF32[$179>>2] = $169;
  $180 = (($2) + 20|0);
  HEAPF32[$180>>2] = $172;
  $181 = (($2) + 24|0);
  HEAPF32[$181>>2] = $175;
  $182 = (($2) + 28|0);
  HEAPF32[$182>>2] = Math_fround(0.0);
  __ZN5physx21PxcArticulationHelper18getImpulseResponseERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS4_($158,$157,$2,$deltaV1);
  $$pre = Math_fround(HEAPF32[$deltaV1>>2]);
  $$phi$trans$insert10 = (($deltaV1) + 4|0);
  $$pre11 = Math_fround(HEAPF32[$$phi$trans$insert10>>2]);
  $$phi$trans$insert12 = (($deltaV1) + 8|0);
  $$pre13 = Math_fround(HEAPF32[$$phi$trans$insert12>>2]);
  $$phi$trans$insert14 = (($deltaV1) + 16|0);
  $$pre15 = Math_fround(HEAPF32[$$phi$trans$insert14>>2]);
  $$phi$trans$insert16 = (($deltaV1) + 20|0);
  $$pre17 = Math_fround(HEAPF32[$$phi$trans$insert16>>2]);
  $$phi$trans$insert18 = (($deltaV1) + 24|0);
  $$pre19 = Math_fround(HEAPF32[$$phi$trans$insert18>>2]);
  $218 = $$pre;$222 = $$pre11;$227 = $$pre13;$232 = $$pre15;$236 = $$pre17;$241 = $$pre19;
 }
 $183 = Math_fround(HEAPF32[$impulse0>>2]);
 $184 = Math_fround(HEAPF32[$deltaV0>>2]);
 $185 = Math_fround($183 * $184);
 $186 = (($impulse0) + 4|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = (($deltaV0) + 4|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = Math_fround($187 * $189);
 $191 = Math_fround($185 + $190);
 $192 = (($impulse0) + 8|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($deltaV0) + 8|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = Math_fround($193 * $195);
 $197 = Math_fround($191 + $196);
 $198 = (($impulse0) + 16|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($deltaV0) + 16|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = Math_fround($199 * $201);
 $203 = (($impulse0) + 20|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = (($deltaV0) + 20|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = Math_fround($204 * $206);
 $208 = Math_fround($202 + $207);
 $209 = (($impulse0) + 24|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($deltaV0) + 24|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = Math_fround($210 * $212);
 $214 = Math_fround($208 + $213);
 $215 = Math_fround($197 + $214);
 $216 = Math_fround(HEAPF32[$impulse1>>2]);
 $217 = Math_fround($216 * $218);
 $219 = (($impulse1) + 4|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = Math_fround($220 * $222);
 $223 = Math_fround($217 + $221);
 $224 = (($impulse1) + 8|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = Math_fround($225 * $227);
 $228 = Math_fround($223 + $226);
 $229 = (($impulse1) + 16|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = Math_fround($230 * $232);
 $233 = (($impulse1) + 20|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = Math_fround($234 * $236);
 $237 = Math_fround($231 + $235);
 $238 = (($impulse1) + 24|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = Math_fround($239 * $241);
 $242 = Math_fround($237 + $240);
 $243 = Math_fround($228 + $242);
 $244 = Math_fround($215 + $243);
 STACKTOP = sp;return (Math_fround($244));
}
function __ZN5physx33setupFinalizeExtSolverConstraintsERNS_13PxcNpWorkUnitERKNS_2Gu13ContactBufferERKNS_20PxcCorrelationBufferERKNS_11PxTransformESB_bPhRKNS_16PxsSolverExtBodyESF_RKNS_17PxcSolverBodyDataESI_ffffff($n,$buffer,$c,$bodyFrame0,$bodyFrame1,$perPointFriction,$workspace,$b0,$b1,$0,$1,$invDtF32,$bounceThresholdF32,$invMassScale0,$invInertiaScale0,$invMassScale1,$invInertiaScale1) {
 $n = $n|0;
 $buffer = $buffer|0;
 $c = $c|0;
 $bodyFrame0 = $bodyFrame0|0;
 $bodyFrame1 = $bodyFrame1|0;
 $perPointFriction = $perPointFriction|0;
 $workspace = $workspace|0;
 $b0 = $b0|0;
 $b1 = $b1|0;
 $0 = $0|0;
 $1 = $1|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $invMassScale0 = Math_fround($invMassScale0);
 $invInertiaScale0 = Math_fround($invInertiaScale0);
 $invMassScale1 = Math_fround($invMassScale1);
 $invInertiaScale1 = Math_fround($invInertiaScale1);
 var $$$i = Math_fround(0), $$$i$us = Math_fround(0), $$$us = 0, $$0$i$us = Math_fround(0), $$0$i201$us = Math_fround(0), $$in = 0, $$in1 = 0, $$in930 = 0, $$in931 = 0, $$in932 = 0, $$in933 = 0, $$in934 = 0, $$in935 = 0, $$pn = 0, $$sum = 0, $$sum$i = 0, $$sum$i102 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0;
 var $$sum12$us = 0, $$sum2 = 0, $$sum56 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $$sum936937 = 0, $$sum938939 = 0, $$sum940941 = 0, $$sum942943 = 0, $$sum944945 = 0, $$sum946947 = 0, $$sum948 = 0, $$sum949 = 0, $$sum950 = 0, $$sum951 = 0, $$sum952 = 0, $$sum953 = 0, $$sum954 = 0, $$sum955 = 0;
 var $$sum956 = 0, $$sum957 = 0, $$sum958 = 0, $$sum959 = 0, $$sum960 = 0, $$sum961 = 0, $$sum962 = 0, $10 = 0, $100 = 0, $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0;
 var $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = 0, $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0);
 var $1029 = Math_fround(0), $103 = 0, $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = 0, $1035 = Math_fround(0), $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = 0, $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0);
 var $1047 = 0, $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = 0, $1050 = Math_fround(0), $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = 0, $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0);
 var $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = 0, $1080 = Math_fround(0), $1081 = 0, $1082 = 0;
 var $1083 = 0, $1084 = 0, $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = Math_fround(0), $11 = 0, $110 = 0;
 var $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0);
 var $1119 = Math_fround(0), $112 = 0, $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = 0, $113 = 0, $1130 = Math_fround(0), $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = Math_fround(0);
 var $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = 0, $114 = 0, $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = 0, $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0;
 var $1155 = 0, $1156 = 0, $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = Math_fround(0), $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = Math_fround(0), $1171 = Math_fround(0), $1172 = Math_fround(0);
 var $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0;
 var $1191 = Math_fround(0), $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0;
 var $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0);
 var $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = Math_fround(0), $269 = 0;
 var $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0);
 var $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0);
 var $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0);
 var $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = Math_fround(0);
 var $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = 0, $441 = Math_fround(0), $442 = Math_fround(0), $443 = 0, $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0), $449 = Math_fround(0);
 var $45 = Math_fround(0), $450 = Math_fround(0), $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0);
 var $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0);
 var $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = Math_fround(0), $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0;
 var $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = Math_fround(0), $548 = 0, $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = Math_fround(0), $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = Math_fround(0), $605 = 0, $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0);
 var $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0);
 var $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = 0, $644 = Math_fround(0), $645 = Math_fround(0), $646 = 0, $647 = Math_fround(0);
 var $648 = Math_fround(0), $649 = 0, $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0);
 var $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0);
 var $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0);
 var $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0);
 var $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = 0, $733 = Math_fround(0), $734 = 0, $735 = 0, $736 = 0, $737 = 0;
 var $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = 0, $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = 0, $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = Math_fround(0);
 var $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = 0, $772 = 0, $773 = 0;
 var $774 = 0, $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0);
 var $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0);
 var $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = 0, $827 = Math_fround(0);
 var $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = 0, $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = 0, $840 = 0, $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = 0;
 var $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = 0, $863 = 0;
 var $864 = 0, $865 = 0, $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0);
 var $882 = Math_fround(0), $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0;
 var $90 = 0, $900 = 0, $901 = 0, $902 = Math_fround(0), $903 = Math_fround(0), $904 = 0, $905 = Math_fround(0), $906 = Math_fround(0), $907 = 0, $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0);
 var $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0);
 var $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = 0, $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = 0, $946 = Math_fround(0), $947 = Math_fround(0), $948 = 0, $949 = Math_fround(0), $95 = 0, $950 = Math_fround(0), $951 = 0, $952 = Math_fround(0), $953 = Math_fround(0);
 var $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = 0, $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = 0, $970 = Math_fround(0), $971 = Math_fround(0);
 var $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0;
 var $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $deltaV0 = 0, $deltaV011 = 0, $deltaV06 = 0, $deltaV1 = 0, $deltaV112 = 0, $deltaV17 = 0, $exitcond = 0, $exitcond987 = 0, $frictionPatchWritebackAddrIndex$0982 = 0, $frictionPatchWritebackAddrIndex$1 = 0;
 var $i$0976 = 0, $j$0963 = 0, $j$0963$us = 0, $j1$0971 = 0, $j1$0971$us = 0, $normalS = 0, $p$0$lcssa = 0, $p$0964 = 0, $p$0964$us = 0, $patch$0965 = 0, $phitmp = 0, $phitmp927 = 0, $ptr$0983 = 0, $ptr$1$lcssa = 0, $ptr$1966 = 0, $ptr$2972 = 0, $ptr$2972$us = 0, $ptr$3 = 0, $ptr$4 = 0, $split = 0;
 var $t0 = 0, $t1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $deltaV0 = sp + 352|0;
 $deltaV1 = sp + 256|0;
 $2 = sp + 288|0;
 $3 = sp + 320|0;
 $normalS = sp + 384|0;
 $t0 = sp + 396|0;
 $t1 = sp + 408|0;
 $4 = sp + 420|0;
 $deltaV06 = sp + 224|0;
 $deltaV17 = sp + 160|0;
 $5 = sp + 128|0;
 $6 = sp + 96|0;
 $deltaV011 = sp + 64|0;
 $deltaV112 = sp + 32|0;
 $7 = sp;
 $8 = sp + 192|0;
 $9 = (($buffer) + 4096|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($b0) + 8|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = ($13<<16>>16)==(-1);
 if ($14) {
  $15 = (($b0) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 52|0);
  $$in = $17;
 } else {
  $18 = $13&65535;
  $19 = HEAP32[$b0>>2]|0;
  $20 = (($19) + 128|0);
  $21 = (($19) + 8|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22&65535;
  $$sum$i = ($23*80)|0;
  $24 = (($20) + ($$sum$i)|0);
  $25 = (($24) + ($18<<2)|0);
  $$in = $25;
 }
 $26 = Math_fround(HEAPF32[$$in>>2]);
 $27 = (($b1) + 8|0);
 $28 = HEAP16[$27>>1]|0;
 $29 = ($28<<16>>16)==(-1);
 if ($29) {
  $30 = (($b1) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 52|0);
  $$in1 = $32;
 } else {
  $33 = $28&65535;
  $34 = HEAP32[$b1>>2]|0;
  $35 = (($34) + 128|0);
  $36 = (($34) + 8|0);
  $37 = HEAP16[$36>>1]|0;
  $38 = $37&65535;
  $$sum$i102 = ($38*80)|0;
  $39 = (($35) + ($$sum$i102)|0);
  $40 = (($39) + ($33<<2)|0);
  $$in1 = $40;
 }
 $41 = Math_fround(HEAPF32[$$in1>>2]);
 $42 = $26 > $41;
 $43 = $42 ? $26 : $41;
 $44 = (($n) + 84|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 * $invMassScale0);
 $47 = (($n) + 88|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($48 * $invMassScale1);
 $50 = Math_fround($45 * $invInertiaScale0);
 $51 = Math_fround($48 * $invInertiaScale1);
 $52 = (($n) + 92|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($c) + 4100|0);
 $55 = (($54) + 128|0);
 $56 = Math_fround($invDtF32 * Math_fround(0.800000011920928955078));
 $57 = (($n) + 22|0);
 $58 = HEAP16[$57>>1]|0;
 $59 = $58 & 24;
 $60 = ($59<<16>>16)!=(0);
 $61 = (($c) + 4232|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  STACKTOP = sp;return;
 }
 $64 = $60 ? 128 : 96;
 $65 = (($normalS) + 4|0);
 $66 = (($normalS) + 8|0);
 $67 = (($4) + 4|0);
 $68 = (($4) + 8|0);
 $69 = (($t0) + 4|0);
 $70 = (($t0) + 8|0);
 $71 = (($t1) + 4|0);
 $72 = (($t1) + 8|0);
 $73 = (($n) + 40|0);
 $$sum = $64 << 1;
 $$sum2 = (($64) + 80)|0;
 $74 = (($bodyFrame0) + 12|0);
 $75 = (($bodyFrame0) + 4|0);
 $76 = (($bodyFrame0) + 8|0);
 $77 = (($bodyFrame1) + 12|0);
 $78 = (($bodyFrame1) + 4|0);
 $79 = (($bodyFrame1) + 8|0);
 $80 = (($bodyFrame0) + 16|0);
 $81 = (($bodyFrame0) + 20|0);
 $82 = (($bodyFrame0) + 24|0);
 $83 = (($bodyFrame1) + 16|0);
 $84 = (($bodyFrame1) + 20|0);
 $85 = (($bodyFrame1) + 24|0);
 $86 = (($5) + 4|0);
 $87 = (($5) + 8|0);
 $88 = (($5) + 12|0);
 $89 = (($5) + 16|0);
 $90 = (($5) + 20|0);
 $91 = (($5) + 24|0);
 $92 = (($5) + 28|0);
 $93 = (($6) + 4|0);
 $94 = (($6) + 8|0);
 $95 = (($6) + 12|0);
 $96 = (($6) + 16|0);
 $97 = (($6) + 20|0);
 $98 = (($6) + 24|0);
 $99 = (($6) + 28|0);
 $100 = (($deltaV06) + 16|0);
 $101 = (($deltaV06) + 20|0);
 $102 = (($deltaV06) + 24|0);
 $103 = (($deltaV17) + 16|0);
 $104 = (($deltaV17) + 20|0);
 $105 = (($deltaV17) + 24|0);
 $106 = (($deltaV06) + 4|0);
 $107 = (($deltaV06) + 8|0);
 $108 = (($deltaV17) + 4|0);
 $109 = (($deltaV17) + 8|0);
 $110 = (($7) + 4|0);
 $111 = (($7) + 8|0);
 $112 = (($7) + 12|0);
 $113 = (($7) + 16|0);
 $114 = (($7) + 20|0);
 $115 = (($7) + 24|0);
 $116 = (($7) + 28|0);
 $117 = (($8) + 4|0);
 $118 = (($8) + 8|0);
 $119 = (($8) + 12|0);
 $120 = (($8) + 16|0);
 $121 = (($8) + 20|0);
 $122 = (($8) + 24|0);
 $123 = (($8) + 28|0);
 $$sum936937 = $64 | 4;
 $$sum938939 = $64 | 8;
 $$sum940941 = $64 | 12;
 $$sum56 = $64 | 16;
 $$sum942943 = $64 | 20;
 $$sum944945 = $64 | 24;
 $$sum946947 = $64 | 28;
 $$sum7 = (($64) + 32)|0;
 $$sum948 = (($64) + 36)|0;
 $$sum949 = (($64) + 40)|0;
 $$sum950 = (($64) + 44)|0;
 $$sum8 = (($64) + 48)|0;
 $124 = (($deltaV011) + 16|0);
 $125 = (($deltaV011) + 20|0);
 $126 = (($deltaV011) + 24|0);
 $$sum951 = (($64) + 52)|0;
 $$sum952 = (($64) + 56)|0;
 $$sum953 = (($64) + 60)|0;
 $$sum9 = (($64) + 64)|0;
 $127 = (($deltaV112) + 16|0);
 $128 = (($deltaV112) + 20|0);
 $129 = (($deltaV112) + 24|0);
 $$sum954 = (($64) + 68)|0;
 $$sum955 = (($64) + 72)|0;
 $$sum956 = (($64) + 76)|0;
 $$sum10 = (($64) + 96)|0;
 $130 = (($deltaV011) + 4|0);
 $131 = (($deltaV011) + 8|0);
 $$sum957 = (($64) + 100)|0;
 $$sum958 = (($64) + 104)|0;
 $$sum959 = (($64) + 108)|0;
 $$sum11 = (($64) + 112)|0;
 $132 = (($deltaV112) + 4|0);
 $133 = (($deltaV112) + 8|0);
 $$sum960 = (($64) + 116)|0;
 $$sum961 = (($64) + 120)|0;
 $$sum962 = (($64) + 124)|0;
 $134 = (($2) + 4|0);
 $135 = (($2) + 8|0);
 $136 = (($2) + 12|0);
 $137 = (($2) + 16|0);
 $138 = (($2) + 20|0);
 $139 = (($2) + 24|0);
 $140 = (($2) + 28|0);
 $141 = (($3) + 4|0);
 $142 = (($3) + 8|0);
 $143 = (($3) + 12|0);
 $144 = (($3) + 16|0);
 $145 = (($3) + 20|0);
 $146 = (($3) + 24|0);
 $147 = (($3) + 28|0);
 $148 = (($deltaV0) + 16|0);
 $149 = (($deltaV0) + 20|0);
 $150 = (($deltaV0) + 24|0);
 $151 = (($deltaV1) + 16|0);
 $152 = (($deltaV1) + 20|0);
 $153 = (($deltaV1) + 24|0);
 $154 = (($deltaV0) + 4|0);
 $155 = (($deltaV0) + 8|0);
 $156 = (($deltaV1) + 4|0);
 $157 = (($deltaV1) + 8|0);
 $frictionPatchWritebackAddrIndex$0982 = 0;$i$0976 = 0;$ptr$0983 = $workspace;
 while(1) {
  $158 = ((($c) + ($i$0976<<2)|0) + 3840|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = ($159|0)==(0);
  if ($160) {
   $frictionPatchWritebackAddrIndex$1 = $frictionPatchWritebackAddrIndex$0982;$ptr$4 = $ptr$0983;
  } else {
   $161 = ((($c) + ($i$0976<<2)|0) + 3968|0);
   $162 = HEAP32[$161>>2]|0;
   $163 = (($c) + (($162*12)|0)|0);
   $164 = HEAP16[$163>>1]|0;
   $165 = $164&65535;
   $166 = ((($buffer) + ($165<<6)|0) + 60|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = ((($buffer) + ($165<<6)|0) + 44|0);
   $169 = Math_fround(HEAPF32[$168>>2]);
   $170 = ((($buffer) + ($165<<6)|0) + 56|0);
   $171 = Math_fround(HEAPF32[$170>>2]);
   $172 = ((($buffer) + ($165<<6)|0) + 52|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = $173 & 1;
   $175 = (($ptr$0983) + 32|0);
   $176 = (($ptr$0983) + 160|0);
   $177 = (($ptr$0983) + 288|0);
   $178 = (($ptr$0983) + 416|0);
   $179 = ($174|0)==(0);
   $180 = $159&255;
   $181 = (($ptr$0983) + 5|0);
   HEAP8[$181>>0] = $180;
   if ($179) {
    $182 = ((($c) + (($i$0976*96)|0)|0) + 784|0);
    $183 = HEAP16[$182>>1]|0;
    $184 = $183&65535;
    $185 = $184 << 1;
    $phitmp = $185&255;
    $187 = $phitmp;
   } else {
    $187 = 0;
   }
   $186 = (($ptr$0983) + 6|0);
   HEAP8[$186>>0] = $187;
   if ($60) {
    $192 = 3;
   } else {
    $188 = ($187<<24>>24)==(0);
    if ($188) {
     $192 = 6;
    } else {
     $189 = HEAP16[$57>>1]|0;
     $190 = $189 & 64;
     $191 = ($190<<16>>16)==(0);
     $phitmp927 = $191 ? 5 : 1;
     $192 = $phitmp927;
    }
   }
   HEAP8[$ptr$0983>>0] = $192;
   $193 = (($ptr$0983) + 16|0);
   HEAPF32[$193>>2] = $169;
   $194 = (($ptr$0983) + 20|0);
   HEAPF32[$194>>2] = $171;
   $195 = (($ptr$0983) + 24|0);
   HEAPF32[$195>>2] = $46;
   $196 = (($ptr$0983) + 28|0);
   HEAPF32[$196>>2] = $49;
   $197 = (($ptr$0983) + 8|0);
   HEAPF32[$197>>2] = $50;
   $198 = (($ptr$0983) + 12|0);
   HEAPF32[$198>>2] = $51;
   $199 = HEAP32[$161>>2]|0;
   $200 = ($199|0)==(65535);
   if ($200) {
    $ptr$1$lcssa = $175;
   } else {
    $201 = $167 > Math_fround(0.0);
    $patch$0965 = $199;$ptr$1966 = $175;
    while(1) {
     $202 = ((($c) + (($patch$0965*12)|0)|0) + 2|0);
     $203 = HEAP16[$202>>1]|0;
     $204 = (($c) + (($patch$0965*12)|0)|0);
     $205 = HEAP16[$204>>1]|0;
     $206 = $205&65535;
     $207 = ($203<<16>>16)==(0);
     if ($207) {
      $p$0$lcssa = $ptr$1966;
     } else {
      $208 = $203&65535;
      if ($201) {
       $j$0963$us = 0;$p$0964$us = $ptr$1966;
       while(1) {
        $$sum12$us = (($j$0963$us) + ($206))|0;
        $209 = (($p$0964$us) + ($64)|0);
        $210 = (($buffer) + ($$sum12$us<<6)|0);
        $211 = Math_fround(HEAPF32[$210>>2]);
        $212 = ((($buffer) + ($$sum12$us<<6)|0) + 4|0);
        $213 = Math_fround(HEAPF32[$212>>2]);
        $214 = ((($buffer) + ($$sum12$us<<6)|0) + 8|0);
        $215 = Math_fround(HEAPF32[$214>>2]);
        $216 = ((($buffer) + ($$sum12$us<<6)|0) + 12|0);
        $217 = Math_fround(HEAPF32[$216>>2]);
        $218 = Math_fround($217 - $53);
        $219 = ((($buffer) + ($$sum12$us<<6)|0) + 16|0);
        $220 = Math_fround(HEAPF32[$219>>2]);
        $221 = Math_fround(HEAPF32[$80>>2]);
        $222 = Math_fround($220 - $221);
        $223 = ((($buffer) + ($$sum12$us<<6)|0) + 20|0);
        $224 = Math_fround(HEAPF32[$223>>2]);
        $225 = Math_fround(HEAPF32[$81>>2]);
        $226 = Math_fround($224 - $225);
        $227 = ((($buffer) + ($$sum12$us<<6)|0) + 24|0);
        $228 = Math_fround(HEAPF32[$227>>2]);
        $229 = Math_fround(HEAPF32[$82>>2]);
        $230 = Math_fround($228 - $229);
        $231 = Math_fround(HEAPF32[$83>>2]);
        $232 = Math_fround($220 - $231);
        $233 = Math_fround(HEAPF32[$84>>2]);
        $234 = Math_fround($224 - $233);
        $235 = Math_fround(HEAPF32[$85>>2]);
        $236 = Math_fround($228 - $235);
        $237 = Math_fround($226 * $215);
        $238 = Math_fround($230 * $213);
        $239 = Math_fround($237 - $238);
        $240 = Math_fround($230 * $211);
        $241 = Math_fround($222 * $215);
        $242 = Math_fround($240 - $241);
        $243 = Math_fround($222 * $213);
        $244 = Math_fround($226 * $211);
        $245 = Math_fround($243 - $244);
        $246 = Math_fround($234 * $215);
        $247 = Math_fround($236 * $213);
        $248 = Math_fround($246 - $247);
        $249 = Math_fround($236 * $211);
        $250 = Math_fround($232 * $215);
        $251 = Math_fround($249 - $250);
        $252 = Math_fround($232 * $213);
        $253 = Math_fround($234 * $211);
        $254 = Math_fround($252 - $253);
        HEAPF32[$2>>2] = $211;
        HEAPF32[$134>>2] = $213;
        HEAPF32[$135>>2] = $215;
        HEAPF32[$136>>2] = Math_fround(0.0);
        HEAPF32[$137>>2] = $239;
        HEAPF32[$138>>2] = $242;
        HEAPF32[$139>>2] = $245;
        HEAPF32[$140>>2] = Math_fround(0.0);
        $255 = Math_fround(-$211);
        $256 = Math_fround(-$213);
        $257 = Math_fround(-$215);
        $258 = Math_fround(-$248);
        $259 = Math_fround(-$251);
        $260 = Math_fround(-$254);
        HEAPF32[$3>>2] = $255;
        HEAPF32[$141>>2] = $256;
        HEAPF32[$142>>2] = $257;
        HEAPF32[$143>>2] = Math_fround(0.0);
        HEAPF32[$144>>2] = $258;
        HEAPF32[$145>>2] = $259;
        HEAPF32[$146>>2] = $260;
        HEAPF32[$147>>2] = Math_fround(0.0);
        $261 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$2,$deltaV0,$46,$50,$b1,$3,$deltaV1,$49,$51,0)));
        $262 = HEAP16[$12>>1]|0;
        $263 = ($262<<16>>16)==(-1);
        if ($263) {
         $293 = HEAP32[$b0>>2]|0;
         $294 = Math_fround(HEAPF32[$293>>2]);
         $295 = Math_fround(HEAPF32[$210>>2]);
         $296 = Math_fround($294 * $295);
         $297 = (($293) + 4|0);
         $298 = Math_fround(HEAPF32[$297>>2]);
         $299 = Math_fround(HEAPF32[$212>>2]);
         $300 = Math_fround($298 * $299);
         $301 = Math_fround($296 + $300);
         $302 = (($293) + 8|0);
         $303 = Math_fround(HEAPF32[$302>>2]);
         $304 = Math_fround(HEAPF32[$214>>2]);
         $305 = Math_fround($303 * $304);
         $306 = Math_fround($301 + $305);
         $307 = (($293) + 16|0);
         $308 = Math_fround(HEAPF32[$307>>2]);
         $309 = Math_fround($239 * $308);
         $310 = (($293) + 20|0);
         $311 = Math_fround(HEAPF32[$310>>2]);
         $312 = Math_fround($242 * $311);
         $313 = Math_fround($309 + $312);
         $314 = (($293) + 24|0);
         $315 = Math_fround(HEAPF32[$314>>2]);
         $316 = Math_fround($245 * $315);
         $317 = Math_fround($313 + $316);
         $318 = Math_fround($306 + $317);
         $$0$i201$us = $318;$337 = $295;$339 = $299;$342 = $304;
        } else {
         $264 = $262&65535;
         $265 = HEAP32[$b0>>2]|0;
         $266 = (($265) + 128|0);
         $267 = (($266) + ($264<<5)|0);
         $268 = Math_fround(HEAPF32[$267>>2]);
         $269 = ((($266) + ($264<<5)|0) + 4|0);
         $270 = Math_fround(HEAPF32[$269>>2]);
         $271 = ((($266) + ($264<<5)|0) + 8|0);
         $272 = Math_fround(HEAPF32[$271>>2]);
         $273 = ((($266) + ($264<<5)|0) + 16|0);
         $274 = Math_fround(HEAPF32[$273>>2]);
         $275 = ((($266) + ($264<<5)|0) + 20|0);
         $276 = Math_fround(HEAPF32[$275>>2]);
         $277 = ((($266) + ($264<<5)|0) + 24|0);
         $278 = Math_fround(HEAPF32[$277>>2]);
         $279 = Math_fround(HEAPF32[$210>>2]);
         $280 = Math_fround(HEAPF32[$212>>2]);
         $281 = Math_fround(HEAPF32[$214>>2]);
         $282 = Math_fround($268 * $279);
         $283 = Math_fround($270 * $280);
         $284 = Math_fround($282 + $283);
         $285 = Math_fround($272 * $281);
         $286 = Math_fround($284 + $285);
         $287 = Math_fround($239 * $274);
         $288 = Math_fround($242 * $276);
         $289 = Math_fround($287 + $288);
         $290 = Math_fround($245 * $278);
         $291 = Math_fround($289 + $290);
         $292 = Math_fround($291 + $286);
         $$0$i201$us = $292;$337 = $279;$339 = $280;$342 = $281;
        }
        $319 = HEAP16[$27>>1]|0;
        $320 = ($319<<16>>16)==(-1);
        if ($320) {
         $350 = HEAP32[$b1>>2]|0;
         $351 = Math_fround(HEAPF32[$350>>2]);
         $352 = Math_fround($351 * $337);
         $353 = (($350) + 4|0);
         $354 = Math_fround(HEAPF32[$353>>2]);
         $355 = Math_fround($354 * $339);
         $356 = Math_fround($352 + $355);
         $357 = (($350) + 8|0);
         $358 = Math_fround(HEAPF32[$357>>2]);
         $359 = Math_fround($358 * $342);
         $360 = Math_fround($356 + $359);
         $361 = (($350) + 16|0);
         $362 = Math_fround(HEAPF32[$361>>2]);
         $363 = Math_fround($248 * $362);
         $364 = (($350) + 20|0);
         $365 = Math_fround(HEAPF32[$364>>2]);
         $366 = Math_fround($251 * $365);
         $367 = Math_fround($363 + $366);
         $368 = (($350) + 24|0);
         $369 = Math_fround(HEAPF32[$368>>2]);
         $370 = Math_fround($254 * $369);
         $371 = Math_fround($367 + $370);
         $372 = Math_fround($360 + $371);
         $$0$i$us = $372;
        } else {
         $321 = $319&65535;
         $322 = HEAP32[$b1>>2]|0;
         $323 = (($322) + 128|0);
         $324 = (($323) + ($321<<5)|0);
         $325 = Math_fround(HEAPF32[$324>>2]);
         $326 = ((($323) + ($321<<5)|0) + 4|0);
         $327 = Math_fround(HEAPF32[$326>>2]);
         $328 = ((($323) + ($321<<5)|0) + 8|0);
         $329 = Math_fround(HEAPF32[$328>>2]);
         $330 = ((($323) + ($321<<5)|0) + 16|0);
         $331 = Math_fround(HEAPF32[$330>>2]);
         $332 = ((($323) + ($321<<5)|0) + 20|0);
         $333 = Math_fround(HEAPF32[$332>>2]);
         $334 = ((($323) + ($321<<5)|0) + 24|0);
         $335 = Math_fround(HEAPF32[$334>>2]);
         $336 = Math_fround($325 * $337);
         $338 = Math_fround($327 * $339);
         $340 = Math_fround($336 + $338);
         $341 = Math_fround($329 * $342);
         $343 = Math_fround($340 + $341);
         $344 = Math_fround($248 * $331);
         $345 = Math_fround($251 * $333);
         $346 = Math_fround($344 + $345);
         $347 = Math_fround($254 * $335);
         $348 = Math_fround($346 + $347);
         $349 = Math_fround($348 + $343);
         $$0$i$us = $349;
        }
        $373 = Math_fround($$0$i201$us - $$0$i$us);
        $374 = Math_fround(Math_fround(1.0) / $261);
        $375 = $261 != Math_fround(0.0);
        $376 = $375 ? $374 : Math_fround(0.0);
        $377 = Math_fround($56 * $218);
        $378 = $43 > $377;
        $$$i$us = $378 ? $43 : $377;
        $379 = Math_fround($$$i$us * $376);
        $380 = Math_fround($218 * $invDtF32);
        $381 = $373 < $bounceThresholdF32;
        $382 = Math_fround(-$373);
        $383 = $380 < $382;
        $$$us = $383 & $381;
        $384 = $$$us ? Math_fround(0.0) : $379;
        $385 = Math_fround($167 * $382);
        $386 = $$$us ? $385 : Math_fround(0.0);
        HEAPF32[$p$0964$us>>2] = $211;
        $387 = (($p$0964$us) + 4|0);
        HEAPF32[$387>>2] = $213;
        $388 = (($p$0964$us) + 8|0);
        HEAPF32[$388>>2] = $215;
        $389 = (($p$0964$us) + 12|0);
        HEAPF32[$389>>2] = $376;
        $390 = (($p$0964$us) + 16|0);
        HEAPF32[$390>>2] = $239;
        $391 = (($p$0964$us) + 20|0);
        HEAPF32[$391>>2] = $242;
        $392 = (($p$0964$us) + 24|0);
        HEAPF32[$392>>2] = $245;
        $393 = (($p$0964$us) + 28|0);
        HEAPF32[$393>>2] = Math_fround(0.0);
        $394 = (($p$0964$us) + 32|0);
        HEAPF32[$394>>2] = $248;
        $395 = (($p$0964$us) + 36|0);
        HEAPF32[$395>>2] = $251;
        $396 = (($p$0964$us) + 40|0);
        HEAPF32[$396>>2] = $254;
        $397 = (($p$0964$us) + 44|0);
        HEAPF32[$397>>2] = Math_fround(0.0);
        $398 = Math_fround(HEAPF32[$148>>2]);
        $399 = Math_fround(HEAPF32[$149>>2]);
        $400 = Math_fround(HEAPF32[$150>>2]);
        $401 = (($p$0964$us) + 64|0);
        HEAPF32[$401>>2] = $398;
        $402 = (($p$0964$us) + 68|0);
        HEAPF32[$402>>2] = $399;
        $403 = (($p$0964$us) + 72|0);
        HEAPF32[$403>>2] = $400;
        $404 = (($p$0964$us) + 76|0);
        HEAPF32[$404>>2] = Math_fround(0.0);
        $405 = Math_fround(HEAPF32[$151>>2]);
        $406 = Math_fround(HEAPF32[$152>>2]);
        $407 = Math_fround(HEAPF32[$153>>2]);
        $408 = (($p$0964$us) + 80|0);
        HEAPF32[$408>>2] = $405;
        $409 = (($p$0964$us) + 84|0);
        HEAPF32[$409>>2] = $406;
        $410 = (($p$0964$us) + 88|0);
        HEAPF32[$410>>2] = $407;
        $411 = (($p$0964$us) + 92|0);
        HEAPF32[$411>>2] = Math_fround(0.0);
        $412 = Math_fround(HEAPF32[$deltaV0>>2]);
        $413 = Math_fround(HEAPF32[$154>>2]);
        $414 = Math_fround(HEAPF32[$155>>2]);
        $415 = (($p$0964$us) + 96|0);
        HEAPF32[$415>>2] = $412;
        $416 = (($p$0964$us) + 100|0);
        HEAPF32[$416>>2] = $413;
        $417 = (($p$0964$us) + 104|0);
        HEAPF32[$417>>2] = $414;
        $418 = (($p$0964$us) + 108|0);
        HEAPF32[$418>>2] = Math_fround(0.0);
        $419 = Math_fround(HEAPF32[$deltaV1>>2]);
        $420 = Math_fround(HEAPF32[$156>>2]);
        $421 = Math_fround(HEAPF32[$157>>2]);
        $422 = (($p$0964$us) + 112|0);
        HEAPF32[$422>>2] = $419;
        $423 = (($p$0964$us) + 116|0);
        HEAPF32[$423>>2] = $420;
        $424 = (($p$0964$us) + 120|0);
        HEAPF32[$424>>2] = $421;
        $425 = (($p$0964$us) + 124|0);
        HEAPF32[$425>>2] = Math_fround(0.0);
        $426 = ((($buffer) + ($$sum12$us<<6)|0) + 28|0);
        $427 = Math_fround(HEAPF32[$426>>2]);
        $428 = (($p$0964$us) + 48|0);
        HEAPF32[$428>>2] = $384;
        $429 = (($p$0964$us) + 52|0);
        HEAPF32[$429>>2] = $386;
        $430 = (($p$0964$us) + 56|0);
        HEAPF32[$430>>2] = $427;
        $431 = (($p$0964$us) + 60|0);
        HEAPF32[$431>>2] = Math_fround(0.0);
        $432 = (($j$0963$us) + 1)|0;
        $exitcond987 = ($432|0)==($208|0);
        if ($exitcond987) {
         break;
        } else {
         $j$0963$us = $432;$p$0964$us = $209;
        }
       }
      } else {
       $j$0963 = 0;$p$0964 = $ptr$1966;
       while(1) {
        $$sum12 = (($j$0963) + ($206))|0;
        $433 = (($p$0964) + ($64)|0);
        $434 = (($buffer) + ($$sum12<<6)|0);
        $435 = Math_fround(HEAPF32[$434>>2]);
        $436 = ((($buffer) + ($$sum12<<6)|0) + 4|0);
        $437 = Math_fround(HEAPF32[$436>>2]);
        $438 = ((($buffer) + ($$sum12<<6)|0) + 8|0);
        $439 = Math_fround(HEAPF32[$438>>2]);
        $440 = ((($buffer) + ($$sum12<<6)|0) + 12|0);
        $441 = Math_fround(HEAPF32[$440>>2]);
        $442 = Math_fround($441 - $53);
        $443 = ((($buffer) + ($$sum12<<6)|0) + 16|0);
        $444 = Math_fround(HEAPF32[$443>>2]);
        $445 = Math_fround(HEAPF32[$80>>2]);
        $446 = Math_fround($444 - $445);
        $447 = ((($buffer) + ($$sum12<<6)|0) + 20|0);
        $448 = Math_fround(HEAPF32[$447>>2]);
        $449 = Math_fround(HEAPF32[$81>>2]);
        $450 = Math_fround($448 - $449);
        $451 = ((($buffer) + ($$sum12<<6)|0) + 24|0);
        $452 = Math_fround(HEAPF32[$451>>2]);
        $453 = Math_fround(HEAPF32[$82>>2]);
        $454 = Math_fround($452 - $453);
        $455 = Math_fround(HEAPF32[$83>>2]);
        $456 = Math_fround($444 - $455);
        $457 = Math_fround(HEAPF32[$84>>2]);
        $458 = Math_fround($448 - $457);
        $459 = Math_fround(HEAPF32[$85>>2]);
        $460 = Math_fround($452 - $459);
        $461 = Math_fround($450 * $439);
        $462 = Math_fround($454 * $437);
        $463 = Math_fround($461 - $462);
        $464 = Math_fround($454 * $435);
        $465 = Math_fround($446 * $439);
        $466 = Math_fround($464 - $465);
        $467 = Math_fround($446 * $437);
        $468 = Math_fround($450 * $435);
        $469 = Math_fround($467 - $468);
        $470 = Math_fround($458 * $439);
        $471 = Math_fround($460 * $437);
        $472 = Math_fround($470 - $471);
        $473 = Math_fround($460 * $435);
        $474 = Math_fround($456 * $439);
        $475 = Math_fround($473 - $474);
        $476 = Math_fround($456 * $437);
        $477 = Math_fround($458 * $435);
        $478 = Math_fround($476 - $477);
        HEAPF32[$2>>2] = $435;
        HEAPF32[$134>>2] = $437;
        HEAPF32[$135>>2] = $439;
        HEAPF32[$136>>2] = Math_fround(0.0);
        HEAPF32[$137>>2] = $463;
        HEAPF32[$138>>2] = $466;
        HEAPF32[$139>>2] = $469;
        HEAPF32[$140>>2] = Math_fround(0.0);
        $479 = Math_fround(-$435);
        $480 = Math_fround(-$437);
        $481 = Math_fround(-$439);
        $482 = Math_fround(-$472);
        $483 = Math_fround(-$475);
        $484 = Math_fround(-$478);
        HEAPF32[$3>>2] = $479;
        HEAPF32[$141>>2] = $480;
        HEAPF32[$142>>2] = $481;
        HEAPF32[$143>>2] = Math_fround(0.0);
        HEAPF32[$144>>2] = $482;
        HEAPF32[$145>>2] = $483;
        HEAPF32[$146>>2] = $484;
        HEAPF32[$147>>2] = Math_fround(0.0);
        $485 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$2,$deltaV0,$46,$50,$b1,$3,$deltaV1,$49,$51,0)));
        $486 = Math_fround(Math_fround(1.0) / $485);
        $487 = $485 != Math_fround(0.0);
        $488 = $487 ? $486 : Math_fround(0.0);
        $489 = Math_fround($56 * $442);
        $490 = $43 > $489;
        $$$i = $490 ? $43 : $489;
        $491 = Math_fround($$$i * $488);
        HEAPF32[$p$0964>>2] = $435;
        $492 = (($p$0964) + 4|0);
        HEAPF32[$492>>2] = $437;
        $493 = (($p$0964) + 8|0);
        HEAPF32[$493>>2] = $439;
        $494 = (($p$0964) + 12|0);
        HEAPF32[$494>>2] = $488;
        $495 = (($p$0964) + 16|0);
        HEAPF32[$495>>2] = $463;
        $496 = (($p$0964) + 20|0);
        HEAPF32[$496>>2] = $466;
        $497 = (($p$0964) + 24|0);
        HEAPF32[$497>>2] = $469;
        $498 = (($p$0964) + 28|0);
        HEAPF32[$498>>2] = Math_fround(0.0);
        $499 = (($p$0964) + 32|0);
        HEAPF32[$499>>2] = $472;
        $500 = (($p$0964) + 36|0);
        HEAPF32[$500>>2] = $475;
        $501 = (($p$0964) + 40|0);
        HEAPF32[$501>>2] = $478;
        $502 = (($p$0964) + 44|0);
        HEAPF32[$502>>2] = Math_fround(0.0);
        $503 = Math_fround(HEAPF32[$148>>2]);
        $504 = Math_fround(HEAPF32[$149>>2]);
        $505 = Math_fround(HEAPF32[$150>>2]);
        $506 = (($p$0964) + 64|0);
        HEAPF32[$506>>2] = $503;
        $507 = (($p$0964) + 68|0);
        HEAPF32[$507>>2] = $504;
        $508 = (($p$0964) + 72|0);
        HEAPF32[$508>>2] = $505;
        $509 = (($p$0964) + 76|0);
        HEAPF32[$509>>2] = Math_fround(0.0);
        $510 = Math_fround(HEAPF32[$151>>2]);
        $511 = Math_fround(HEAPF32[$152>>2]);
        $512 = Math_fround(HEAPF32[$153>>2]);
        $513 = (($p$0964) + 80|0);
        HEAPF32[$513>>2] = $510;
        $514 = (($p$0964) + 84|0);
        HEAPF32[$514>>2] = $511;
        $515 = (($p$0964) + 88|0);
        HEAPF32[$515>>2] = $512;
        $516 = (($p$0964) + 92|0);
        HEAPF32[$516>>2] = Math_fround(0.0);
        $517 = Math_fround(HEAPF32[$deltaV0>>2]);
        $518 = Math_fround(HEAPF32[$154>>2]);
        $519 = Math_fround(HEAPF32[$155>>2]);
        $520 = (($p$0964) + 96|0);
        HEAPF32[$520>>2] = $517;
        $521 = (($p$0964) + 100|0);
        HEAPF32[$521>>2] = $518;
        $522 = (($p$0964) + 104|0);
        HEAPF32[$522>>2] = $519;
        $523 = (($p$0964) + 108|0);
        HEAPF32[$523>>2] = Math_fround(0.0);
        $524 = Math_fround(HEAPF32[$deltaV1>>2]);
        $525 = Math_fround(HEAPF32[$156>>2]);
        $526 = Math_fround(HEAPF32[$157>>2]);
        $527 = (($p$0964) + 112|0);
        HEAPF32[$527>>2] = $524;
        $528 = (($p$0964) + 116|0);
        HEAPF32[$528>>2] = $525;
        $529 = (($p$0964) + 120|0);
        HEAPF32[$529>>2] = $526;
        $530 = (($p$0964) + 124|0);
        HEAPF32[$530>>2] = Math_fround(0.0);
        $531 = ((($buffer) + ($$sum12<<6)|0) + 28|0);
        $532 = Math_fround(HEAPF32[$531>>2]);
        $533 = (($p$0964) + 48|0);
        HEAPF32[$533>>2] = $491;
        $534 = (($p$0964) + 52|0);
        HEAPF32[$534>>2] = Math_fround(0.0);
        $535 = (($p$0964) + 56|0);
        HEAPF32[$535>>2] = $532;
        $536 = (($p$0964) + 60|0);
        HEAPF32[$536>>2] = Math_fround(0.0);
        $537 = (($j$0963) + 1)|0;
        $exitcond = ($537|0)==($208|0);
        if ($exitcond) {
         break;
        } else {
         $j$0963 = $537;$p$0964 = $433;
        }
       }
      }
      $$pn = Math_imul($64, $208)|0;
      $split = (($ptr$1966) + ($$pn)|0);
      $p$0$lcssa = $split;
     }
     $538 = ((($c) + (($patch$0965*12)|0)|0) + 4|0);
     $539 = HEAP16[$538>>1]|0;
     $540 = $539&65535;
     $541 = ($539<<16>>16)==(-1);
     if ($541) {
      $ptr$1$lcssa = $p$0$lcssa;
      break;
     } else {
      $patch$0965 = $540;$ptr$1966 = $p$0$lcssa;
     }
    }
   }
   if ($179) {
    $542 = HEAP32[$161>>2]|0;
    $543 = (($c) + (($542*12)|0)|0);
    $544 = HEAP16[$543>>1]|0;
    $545 = $544&65535;
    $546 = (($buffer) + ($545<<6)|0);
    $547 = Math_fround(HEAPF32[$546>>2]);
    HEAPF32[$normalS>>2] = $547;
    $548 = ((($buffer) + ($545<<6)|0) + 4|0);
    $549 = Math_fround(HEAPF32[$548>>2]);
    HEAPF32[$65>>2] = $549;
    $550 = ((($buffer) + ($545<<6)|0) + 8|0);
    $551 = Math_fround(HEAPF32[$550>>2]);
    HEAPF32[$66>>2] = $551;
    $552 = HEAP16[$12>>1]|0;
    $553 = ($552<<16>>16)==(-1);
    if ($553) {
     $554 = HEAP32[$b0>>2]|0;
     $555 = (($554) + 4|0);
     $556 = (($554) + 8|0);
     $$in930 = $556;$$in931 = $555;$$in932 = $554;
    } else {
     $557 = HEAP32[$b0>>2]|0;
     $558 = $552&65535;
     $559 = (($557) + 128|0);
     $560 = (($559) + ($558<<5)|0);
     $561 = ((($559) + ($558<<5)|0) + 4|0);
     $562 = ((($559) + ($558<<5)|0) + 8|0);
     $$in930 = $562;$$in931 = $561;$$in932 = $560;
    }
    $563 = Math_fround(HEAPF32[$$in932>>2]);
    $564 = Math_fround(HEAPF32[$$in931>>2]);
    $565 = Math_fround(HEAPF32[$$in930>>2]);
    $566 = HEAP16[$27>>1]|0;
    $567 = ($566<<16>>16)==(-1);
    if ($567) {
     $568 = HEAP32[$b1>>2]|0;
     $569 = (($568) + 4|0);
     $570 = (($568) + 8|0);
     $$in933 = $570;$$in934 = $569;$$in935 = $568;
    } else {
     $571 = HEAP32[$b1>>2]|0;
     $572 = $566&65535;
     $573 = (($571) + 128|0);
     $574 = (($573) + ($572<<5)|0);
     $575 = ((($573) + ($572<<5)|0) + 4|0);
     $576 = ((($573) + ($572<<5)|0) + 8|0);
     $$in933 = $576;$$in934 = $575;$$in935 = $574;
    }
    $577 = Math_fround(HEAPF32[$$in935>>2]);
    $578 = Math_fround(HEAPF32[$$in934>>2]);
    $579 = Math_fround(HEAPF32[$$in933>>2]);
    $580 = Math_fround($563 - $577);
    $581 = Math_fround($564 - $578);
    $582 = Math_fround($565 - $579);
    HEAPF32[$4>>2] = $580;
    HEAPF32[$67>>2] = $581;
    HEAPF32[$68>>2] = $582;
    __ZN5physx23computeFrictionTangentsERKNS_6PxVec3ES2_RS0_S3_($4,$normalS,$t0,$t1);
    $583 = Math_fround(HEAPF32[$t0>>2]);
    $584 = Math_fround(HEAPF32[$69>>2]);
    $585 = Math_fround(HEAPF32[$70>>2]);
    $586 = Math_fround(HEAPF32[$t1>>2]);
    $587 = Math_fround(HEAPF32[$71>>2]);
    $588 = Math_fround(HEAPF32[$72>>2]);
    $589 = HEAP32[$73>>2]|0;
    $590 = ($frictionPatchWritebackAddrIndex$0982*96)|0;
    $591 = (($589) + ($590)|0);
    $592 = ((($c) + (($i$0976*96)|0)|0) + 784|0);
    $593 = HEAP16[$592>>1]|0;
    $594 = ($593<<16>>16)==(0);
    if ($594) {
     $ptr$3 = $ptr$1$lcssa;
    } else {
     if ($perPointFriction) {
      $j1$0971$us = 0;$ptr$2972$us = $ptr$1$lcssa;
      while(1) {
       $595 = (($ptr$2972$us) + ($64)|0);
       $596 = (($ptr$2972$us) + ($$sum)|0);
       $597 = (($ptr$2972$us) + 80|0);
       HEAP32[$597>>2] = $591;
       $598 = (($ptr$2972$us) + ($$sum2)|0);
       HEAP32[$598>>2] = $591;
       $599 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971$us*12)|0)|0) + 816|0);
       $600 = Math_fround(HEAPF32[$599>>2]);
       $601 = Math_fround($600 * Math_fround(2.0));
       $602 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971$us*12)|0)|0) + 820|0);
       $603 = Math_fround(HEAPF32[$602>>2]);
       $604 = Math_fround($603 * Math_fround(2.0));
       $605 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971$us*12)|0)|0) + 824|0);
       $606 = Math_fround(HEAPF32[$605>>2]);
       $607 = Math_fround($606 * Math_fround(2.0));
       $608 = Math_fround(HEAPF32[$74>>2]);
       $609 = Math_fround($608 * $608);
       $610 = Math_fround($609 + Math_fround(-0.5));
       $611 = Math_fround(HEAPF32[$bodyFrame0>>2]);
       $612 = Math_fround($601 * $611);
       $613 = Math_fround(HEAPF32[$75>>2]);
       $614 = Math_fround($604 * $613);
       $615 = Math_fround($612 + $614);
       $616 = Math_fround(HEAPF32[$76>>2]);
       $617 = Math_fround($607 * $616);
       $618 = Math_fround($615 + $617);
       $619 = Math_fround($601 * $610);
       $620 = Math_fround($607 * $613);
       $621 = Math_fround($604 * $616);
       $622 = Math_fround($620 - $621);
       $623 = Math_fround($608 * $622);
       $624 = Math_fround($619 + $623);
       $625 = Math_fround($611 * $618);
       $626 = Math_fround($625 + $624);
       $627 = Math_fround($604 * $610);
       $628 = Math_fround($601 * $616);
       $629 = Math_fround($607 * $611);
       $630 = Math_fround($628 - $629);
       $631 = Math_fround($608 * $630);
       $632 = Math_fround($627 + $631);
       $633 = Math_fround($613 * $618);
       $634 = Math_fround($633 + $632);
       $635 = Math_fround($607 * $610);
       $636 = Math_fround($604 * $611);
       $637 = Math_fround($601 * $613);
       $638 = Math_fround($636 - $637);
       $639 = Math_fround($608 * $638);
       $640 = Math_fround($635 + $639);
       $641 = Math_fround($616 * $618);
       $642 = Math_fround($640 + $641);
       $643 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971$us*12)|0)|0) + 840|0);
       $644 = Math_fround(HEAPF32[$643>>2]);
       $645 = Math_fround($644 * Math_fround(2.0));
       $646 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971$us*12)|0)|0) + 844|0);
       $647 = Math_fround(HEAPF32[$646>>2]);
       $648 = Math_fround($647 * Math_fround(2.0));
       $649 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971$us*12)|0)|0) + 848|0);
       $650 = Math_fround(HEAPF32[$649>>2]);
       $651 = Math_fround($650 * Math_fround(2.0));
       $652 = Math_fround(HEAPF32[$77>>2]);
       $653 = Math_fround($652 * $652);
       $654 = Math_fround($653 + Math_fround(-0.5));
       $655 = Math_fround(HEAPF32[$bodyFrame1>>2]);
       $656 = Math_fround($645 * $655);
       $657 = Math_fround(HEAPF32[$78>>2]);
       $658 = Math_fround($648 * $657);
       $659 = Math_fround($656 + $658);
       $660 = Math_fround(HEAPF32[$79>>2]);
       $661 = Math_fround($651 * $660);
       $662 = Math_fround($659 + $661);
       $663 = Math_fround($645 * $654);
       $664 = Math_fround($651 * $657);
       $665 = Math_fround($648 * $660);
       $666 = Math_fround($664 - $665);
       $667 = Math_fround($652 * $666);
       $668 = Math_fround($663 + $667);
       $669 = Math_fround($655 * $662);
       $670 = Math_fround($669 + $668);
       $671 = Math_fround($648 * $654);
       $672 = Math_fround($645 * $660);
       $673 = Math_fround($651 * $655);
       $674 = Math_fround($672 - $673);
       $675 = Math_fround($652 * $674);
       $676 = Math_fround($671 + $675);
       $677 = Math_fround($657 * $662);
       $678 = Math_fround($677 + $676);
       $679 = Math_fround($651 * $654);
       $680 = Math_fround($648 * $655);
       $681 = Math_fround($645 * $657);
       $682 = Math_fround($680 - $681);
       $683 = Math_fround($652 * $682);
       $684 = Math_fround($679 + $683);
       $685 = Math_fround($660 * $662);
       $686 = Math_fround($684 + $685);
       $687 = Math_fround(HEAPF32[$80>>2]);
       $688 = Math_fround($626 + $687);
       $689 = Math_fround(HEAPF32[$81>>2]);
       $690 = Math_fround($634 + $689);
       $691 = Math_fround(HEAPF32[$82>>2]);
       $692 = Math_fround($642 + $691);
       $693 = Math_fround(HEAPF32[$83>>2]);
       $694 = Math_fround($693 + $670);
       $695 = Math_fround(HEAPF32[$84>>2]);
       $696 = Math_fround($678 + $695);
       $697 = Math_fround(HEAPF32[$85>>2]);
       $698 = Math_fround($686 + $697);
       $699 = Math_fround($688 - $694);
       $700 = Math_fround($690 - $696);
       $701 = Math_fround($692 - $698);
       $702 = Math_fround(HEAPF32[$70>>2]);
       $703 = Math_fround($634 * $702);
       $704 = Math_fround(HEAPF32[$69>>2]);
       $705 = Math_fround($642 * $704);
       $706 = Math_fround($703 - $705);
       $707 = Math_fround(HEAPF32[$t0>>2]);
       $708 = Math_fround($642 * $707);
       $709 = Math_fround($626 * $702);
       $710 = Math_fround($708 - $709);
       $711 = Math_fround($626 * $704);
       $712 = Math_fround($634 * $707);
       $713 = Math_fround($711 - $712);
       $714 = Math_fround($678 * $702);
       $715 = Math_fround($686 * $704);
       $716 = Math_fround($714 - $715);
       $717 = Math_fround($686 * $707);
       $718 = Math_fround($670 * $702);
       $719 = Math_fround($717 - $718);
       $720 = Math_fround($670 * $704);
       $721 = Math_fround($678 * $707);
       $722 = Math_fround($720 - $721);
       HEAPF32[$5>>2] = $707;
       HEAPF32[$86>>2] = $704;
       HEAPF32[$87>>2] = $702;
       HEAPF32[$88>>2] = Math_fround(0.0);
       HEAPF32[$89>>2] = $706;
       HEAPF32[$90>>2] = $710;
       HEAPF32[$91>>2] = $713;
       HEAPF32[$92>>2] = Math_fround(0.0);
       $723 = Math_fround(-$707);
       $724 = Math_fround(-$704);
       $725 = Math_fround(-$702);
       $726 = Math_fround(-$716);
       $727 = Math_fround(-$719);
       $728 = Math_fround(-$722);
       HEAPF32[$6>>2] = $723;
       HEAPF32[$93>>2] = $724;
       HEAPF32[$94>>2] = $725;
       HEAPF32[$95>>2] = Math_fround(0.0);
       HEAPF32[$96>>2] = $726;
       HEAPF32[$97>>2] = $727;
       HEAPF32[$98>>2] = $728;
       HEAPF32[$99>>2] = Math_fround(0.0);
       $729 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$5,$deltaV06,$46,$50,$b1,$6,$deltaV17,$49,$51,0)));
       $730 = Math_fround(Math_fround(1.0) / $729);
       $731 = Math_fround($730 * Math_fround(0.800000011920928955078));
       $732 = !($729 > Math_fround(0.0));
       $733 = $732 ? Math_fround(0.0) : $731;
       $734 = (((($c) + ($i$0976<<2)|0) + ($j1$0971$us<<1)|0) + 4100|0);
       $735 = HEAP16[$734>>1]|0;
       $736 = $735&65535;
       $737 = ((($buffer) + ($736<<6)|0) + 32|0);
       $738 = Math_fround(HEAPF32[$737>>2]);
       $739 = Math_fround($738 * $707);
       $740 = ((($buffer) + ($736<<6)|0) + 36|0);
       $741 = Math_fround(HEAPF32[$740>>2]);
       $742 = Math_fround($741 * $704);
       $743 = Math_fround($739 + $742);
       $744 = ((($buffer) + ($736<<6)|0) + 40|0);
       $745 = Math_fround(HEAPF32[$744>>2]);
       $746 = Math_fround($745 * $702);
       $747 = Math_fround($743 + $746);
       HEAPF32[$ptr$2972$us>>2] = $583;
       $748 = (($ptr$2972$us) + 4|0);
       HEAPF32[$748>>2] = $584;
       $749 = (($ptr$2972$us) + 8|0);
       HEAPF32[$749>>2] = $585;
       $750 = (($ptr$2972$us) + 12|0);
       HEAPF32[$750>>2] = Math_fround(0.0);
       $751 = (($ptr$2972$us) + 16|0);
       HEAPF32[$751>>2] = $706;
       $752 = (($ptr$2972$us) + 20|0);
       HEAPF32[$752>>2] = $710;
       $753 = (($ptr$2972$us) + 24|0);
       HEAPF32[$753>>2] = $713;
       $754 = (($ptr$2972$us) + 28|0);
       HEAPF32[$754>>2] = $733;
       $755 = Math_fround(HEAPF32[$t0>>2]);
       $756 = Math_fround($699 * $755);
       $757 = Math_fround(HEAPF32[$69>>2]);
       $758 = Math_fround($700 * $757);
       $759 = Math_fround($756 + $758);
       $760 = Math_fround(HEAPF32[$70>>2]);
       $761 = Math_fround($701 * $760);
       $762 = Math_fround($759 + $761);
       $763 = Math_fround($762 * $invDtF32);
       $764 = (($ptr$2972$us) + 32|0);
       HEAPF32[$764>>2] = $716;
       $765 = (($ptr$2972$us) + 36|0);
       HEAPF32[$765>>2] = $719;
       $766 = (($ptr$2972$us) + 40|0);
       HEAPF32[$766>>2] = $722;
       $767 = (($ptr$2972$us) + 44|0);
       HEAPF32[$767>>2] = $763;
       $768 = Math_fround(HEAPF32[$100>>2]);
       $769 = Math_fround(HEAPF32[$101>>2]);
       $770 = Math_fround(HEAPF32[$102>>2]);
       $771 = (($ptr$2972$us) + 48|0);
       HEAPF32[$771>>2] = $768;
       $772 = (($ptr$2972$us) + 52|0);
       HEAPF32[$772>>2] = $769;
       $773 = (($ptr$2972$us) + 56|0);
       HEAPF32[$773>>2] = $770;
       $774 = (($ptr$2972$us) + 60|0);
       HEAPF32[$774>>2] = Math_fround(0.0);
       $775 = Math_fround(HEAPF32[$103>>2]);
       $776 = Math_fround(HEAPF32[$104>>2]);
       $777 = Math_fround(HEAPF32[$105>>2]);
       $778 = (($ptr$2972$us) + 64|0);
       HEAPF32[$778>>2] = $775;
       $779 = (($ptr$2972$us) + 68|0);
       HEAPF32[$779>>2] = $776;
       $780 = (($ptr$2972$us) + 72|0);
       HEAPF32[$780>>2] = $777;
       $781 = (($ptr$2972$us) + 76|0);
       HEAPF32[$781>>2] = $747;
       $782 = Math_fround(HEAPF32[$deltaV06>>2]);
       $783 = Math_fround(HEAPF32[$106>>2]);
       $784 = Math_fround(HEAPF32[$107>>2]);
       $785 = (($ptr$2972$us) + 96|0);
       HEAPF32[$785>>2] = $782;
       $786 = (($ptr$2972$us) + 100|0);
       HEAPF32[$786>>2] = $783;
       $787 = (($ptr$2972$us) + 104|0);
       HEAPF32[$787>>2] = $784;
       $788 = (($ptr$2972$us) + 108|0);
       HEAPF32[$788>>2] = Math_fround(0.0);
       $789 = Math_fround(HEAPF32[$deltaV17>>2]);
       $790 = Math_fround(HEAPF32[$108>>2]);
       $791 = Math_fround(HEAPF32[$109>>2]);
       $792 = (($ptr$2972$us) + 112|0);
       HEAPF32[$792>>2] = $789;
       $793 = (($ptr$2972$us) + 116|0);
       HEAPF32[$793>>2] = $790;
       $794 = (($ptr$2972$us) + 120|0);
       HEAPF32[$794>>2] = $791;
       $795 = (($ptr$2972$us) + 124|0);
       HEAPF32[$795>>2] = Math_fround(0.0);
       $796 = Math_fround(HEAPF32[$72>>2]);
       $797 = Math_fround($634 * $796);
       $798 = Math_fround(HEAPF32[$71>>2]);
       $799 = Math_fround($642 * $798);
       $800 = Math_fround($797 - $799);
       $801 = Math_fround(HEAPF32[$t1>>2]);
       $802 = Math_fround($642 * $801);
       $803 = Math_fround($626 * $796);
       $804 = Math_fround($802 - $803);
       $805 = Math_fround($626 * $798);
       $806 = Math_fround($634 * $801);
       $807 = Math_fround($805 - $806);
       $808 = Math_fround($678 * $796);
       $809 = Math_fround($686 * $798);
       $810 = Math_fround($808 - $809);
       $811 = Math_fround($686 * $801);
       $812 = Math_fround($670 * $796);
       $813 = Math_fround($811 - $812);
       $814 = Math_fround($670 * $798);
       $815 = Math_fround($678 * $801);
       $816 = Math_fround($814 - $815);
       HEAPF32[$7>>2] = $801;
       HEAPF32[$110>>2] = $798;
       HEAPF32[$111>>2] = $796;
       HEAPF32[$112>>2] = Math_fround(0.0);
       HEAPF32[$113>>2] = $800;
       HEAPF32[$114>>2] = $804;
       HEAPF32[$115>>2] = $807;
       HEAPF32[$116>>2] = Math_fround(0.0);
       $817 = Math_fround(-$801);
       $818 = Math_fround(-$798);
       $819 = Math_fround(-$796);
       $820 = Math_fround(-$810);
       $821 = Math_fround(-$813);
       $822 = Math_fround(-$816);
       HEAPF32[$8>>2] = $817;
       HEAPF32[$117>>2] = $818;
       HEAPF32[$118>>2] = $819;
       HEAPF32[$119>>2] = Math_fround(0.0);
       HEAPF32[$120>>2] = $820;
       HEAPF32[$121>>2] = $821;
       HEAPF32[$122>>2] = $822;
       HEAPF32[$123>>2] = Math_fround(0.0);
       $823 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$7,$deltaV011,$46,$50,$b1,$8,$deltaV112,$49,$51,0)));
       $824 = Math_fround(Math_fround(1.0) / $823);
       $825 = Math_fround($824 * Math_fround(0.800000011920928955078));
       $826 = !($823 > Math_fround(0.0));
       $827 = $826 ? Math_fround(0.0) : $825;
       $828 = (((($c) + ($i$0976<<2)|0) + ($j1$0971$us<<1)|0) + 4100|0);
       $829 = HEAP16[$828>>1]|0;
       $830 = $829&65535;
       $831 = ((($buffer) + ($830<<6)|0) + 32|0);
       $832 = Math_fround(HEAPF32[$831>>2]);
       $833 = Math_fround(HEAPF32[$t0>>2]);
       $834 = Math_fround($832 * $833);
       $835 = ((($buffer) + ($830<<6)|0) + 36|0);
       $836 = Math_fround(HEAPF32[$835>>2]);
       $837 = Math_fround(HEAPF32[$69>>2]);
       $838 = Math_fround($836 * $837);
       $839 = Math_fround($834 + $838);
       $840 = ((($buffer) + ($830<<6)|0) + 40|0);
       $841 = Math_fround(HEAPF32[$840>>2]);
       $842 = Math_fround(HEAPF32[$70>>2]);
       $843 = Math_fround($841 * $842);
       $844 = Math_fround($839 + $843);
       HEAPF32[$595>>2] = $586;
       $845 = (($ptr$2972$us) + ($$sum936937)|0);
       HEAPF32[$845>>2] = $587;
       $846 = (($ptr$2972$us) + ($$sum938939)|0);
       HEAPF32[$846>>2] = $588;
       $847 = (($ptr$2972$us) + ($$sum940941)|0);
       HEAPF32[$847>>2] = Math_fround(0.0);
       $848 = (($ptr$2972$us) + ($$sum56)|0);
       HEAPF32[$848>>2] = $800;
       $849 = (($ptr$2972$us) + ($$sum942943)|0);
       HEAPF32[$849>>2] = $804;
       $850 = (($ptr$2972$us) + ($$sum944945)|0);
       HEAPF32[$850>>2] = $807;
       $851 = (($ptr$2972$us) + ($$sum946947)|0);
       HEAPF32[$851>>2] = $827;
       $852 = (($ptr$2972$us) + ($$sum7)|0);
       $853 = Math_fround(HEAPF32[$t1>>2]);
       $854 = Math_fround($699 * $853);
       $855 = Math_fround(HEAPF32[$71>>2]);
       $856 = Math_fround($700 * $855);
       $857 = Math_fround($854 + $856);
       $858 = Math_fround(HEAPF32[$72>>2]);
       $859 = Math_fround($701 * $858);
       $860 = Math_fround($857 + $859);
       $861 = Math_fround($860 * $invDtF32);
       HEAPF32[$852>>2] = $810;
       $862 = (($ptr$2972$us) + ($$sum948)|0);
       HEAPF32[$862>>2] = $813;
       $863 = (($ptr$2972$us) + ($$sum949)|0);
       HEAPF32[$863>>2] = $816;
       $864 = (($ptr$2972$us) + ($$sum950)|0);
       HEAPF32[$864>>2] = $861;
       $865 = (($ptr$2972$us) + ($$sum8)|0);
       $866 = Math_fround(HEAPF32[$124>>2]);
       $867 = Math_fround(HEAPF32[$125>>2]);
       $868 = Math_fround(HEAPF32[$126>>2]);
       HEAPF32[$865>>2] = $866;
       $869 = (($ptr$2972$us) + ($$sum951)|0);
       HEAPF32[$869>>2] = $867;
       $870 = (($ptr$2972$us) + ($$sum952)|0);
       HEAPF32[$870>>2] = $868;
       $871 = (($ptr$2972$us) + ($$sum953)|0);
       HEAPF32[$871>>2] = Math_fround(0.0);
       $872 = (($ptr$2972$us) + ($$sum9)|0);
       $873 = Math_fround(HEAPF32[$127>>2]);
       $874 = Math_fround(HEAPF32[$128>>2]);
       $875 = Math_fround(HEAPF32[$129>>2]);
       HEAPF32[$872>>2] = $873;
       $876 = (($ptr$2972$us) + ($$sum954)|0);
       HEAPF32[$876>>2] = $874;
       $877 = (($ptr$2972$us) + ($$sum955)|0);
       HEAPF32[$877>>2] = $875;
       $878 = (($ptr$2972$us) + ($$sum956)|0);
       HEAPF32[$878>>2] = $844;
       $879 = (($ptr$2972$us) + ($$sum10)|0);
       $880 = Math_fround(HEAPF32[$deltaV011>>2]);
       $881 = Math_fround(HEAPF32[$130>>2]);
       $882 = Math_fround(HEAPF32[$131>>2]);
       HEAPF32[$879>>2] = $880;
       $883 = (($ptr$2972$us) + ($$sum957)|0);
       HEAPF32[$883>>2] = $881;
       $884 = (($ptr$2972$us) + ($$sum958)|0);
       HEAPF32[$884>>2] = $882;
       $885 = (($ptr$2972$us) + ($$sum959)|0);
       HEAPF32[$885>>2] = Math_fround(0.0);
       $886 = (($ptr$2972$us) + ($$sum11)|0);
       $887 = Math_fround(HEAPF32[$deltaV112>>2]);
       $888 = Math_fround(HEAPF32[$132>>2]);
       $889 = Math_fround(HEAPF32[$133>>2]);
       HEAPF32[$886>>2] = $887;
       $890 = (($ptr$2972$us) + ($$sum960)|0);
       HEAPF32[$890>>2] = $888;
       $891 = (($ptr$2972$us) + ($$sum961)|0);
       HEAPF32[$891>>2] = $889;
       $892 = (($ptr$2972$us) + ($$sum962)|0);
       HEAPF32[$892>>2] = Math_fround(0.0);
       $893 = (($j1$0971$us) + 1)|0;
       $894 = HEAP16[$592>>1]|0;
       $895 = $894&65535;
       $896 = ($893>>>0)<($895>>>0);
       if ($896) {
        $j1$0971$us = $893;$ptr$2972$us = $596;
       } else {
        $ptr$3 = $596;
        break;
       }
      }
     } else {
      $j1$0971 = 0;$ptr$2972 = $ptr$1$lcssa;
      while(1) {
       $897 = (($ptr$2972) + ($64)|0);
       $898 = (($ptr$2972) + ($$sum)|0);
       $899 = (($ptr$2972) + 80|0);
       HEAP32[$899>>2] = $591;
       $900 = (($ptr$2972) + ($$sum2)|0);
       HEAP32[$900>>2] = $591;
       $901 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971*12)|0)|0) + 816|0);
       $902 = Math_fround(HEAPF32[$901>>2]);
       $903 = Math_fround($902 * Math_fround(2.0));
       $904 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971*12)|0)|0) + 820|0);
       $905 = Math_fround(HEAPF32[$904>>2]);
       $906 = Math_fround($905 * Math_fround(2.0));
       $907 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971*12)|0)|0) + 824|0);
       $908 = Math_fround(HEAPF32[$907>>2]);
       $909 = Math_fround($908 * Math_fround(2.0));
       $910 = Math_fround(HEAPF32[$74>>2]);
       $911 = Math_fround($910 * $910);
       $912 = Math_fround($911 + Math_fround(-0.5));
       $913 = Math_fround(HEAPF32[$bodyFrame0>>2]);
       $914 = Math_fround($903 * $913);
       $915 = Math_fround(HEAPF32[$75>>2]);
       $916 = Math_fround($906 * $915);
       $917 = Math_fround($914 + $916);
       $918 = Math_fround(HEAPF32[$76>>2]);
       $919 = Math_fround($909 * $918);
       $920 = Math_fround($917 + $919);
       $921 = Math_fround($903 * $912);
       $922 = Math_fround($909 * $915);
       $923 = Math_fround($906 * $918);
       $924 = Math_fround($922 - $923);
       $925 = Math_fround($910 * $924);
       $926 = Math_fround($921 + $925);
       $927 = Math_fround($913 * $920);
       $928 = Math_fround($927 + $926);
       $929 = Math_fround($906 * $912);
       $930 = Math_fround($903 * $918);
       $931 = Math_fround($909 * $913);
       $932 = Math_fround($930 - $931);
       $933 = Math_fround($910 * $932);
       $934 = Math_fround($929 + $933);
       $935 = Math_fround($915 * $920);
       $936 = Math_fround($935 + $934);
       $937 = Math_fround($909 * $912);
       $938 = Math_fround($906 * $913);
       $939 = Math_fround($903 * $915);
       $940 = Math_fround($938 - $939);
       $941 = Math_fround($910 * $940);
       $942 = Math_fround($937 + $941);
       $943 = Math_fround($918 * $920);
       $944 = Math_fround($942 + $943);
       $945 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971*12)|0)|0) + 840|0);
       $946 = Math_fround(HEAPF32[$945>>2]);
       $947 = Math_fround($946 * Math_fround(2.0));
       $948 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971*12)|0)|0) + 844|0);
       $949 = Math_fround(HEAPF32[$948>>2]);
       $950 = Math_fround($949 * Math_fround(2.0));
       $951 = (((($c) + (($i$0976*96)|0)|0) + (($j1$0971*12)|0)|0) + 848|0);
       $952 = Math_fround(HEAPF32[$951>>2]);
       $953 = Math_fround($952 * Math_fround(2.0));
       $954 = Math_fround(HEAPF32[$77>>2]);
       $955 = Math_fround($954 * $954);
       $956 = Math_fround($955 + Math_fround(-0.5));
       $957 = Math_fround(HEAPF32[$bodyFrame1>>2]);
       $958 = Math_fround($947 * $957);
       $959 = Math_fround(HEAPF32[$78>>2]);
       $960 = Math_fround($950 * $959);
       $961 = Math_fround($958 + $960);
       $962 = Math_fround(HEAPF32[$79>>2]);
       $963 = Math_fround($953 * $962);
       $964 = Math_fround($961 + $963);
       $965 = Math_fround($947 * $956);
       $966 = Math_fround($953 * $959);
       $967 = Math_fround($950 * $962);
       $968 = Math_fround($966 - $967);
       $969 = Math_fround($954 * $968);
       $970 = Math_fround($965 + $969);
       $971 = Math_fround($957 * $964);
       $972 = Math_fround($971 + $970);
       $973 = Math_fround($950 * $956);
       $974 = Math_fround($947 * $962);
       $975 = Math_fround($953 * $957);
       $976 = Math_fround($974 - $975);
       $977 = Math_fround($954 * $976);
       $978 = Math_fround($973 + $977);
       $979 = Math_fround($959 * $964);
       $980 = Math_fround($979 + $978);
       $981 = Math_fround($953 * $956);
       $982 = Math_fround($950 * $957);
       $983 = Math_fround($947 * $959);
       $984 = Math_fround($982 - $983);
       $985 = Math_fround($954 * $984);
       $986 = Math_fround($981 + $985);
       $987 = Math_fround($962 * $964);
       $988 = Math_fround($986 + $987);
       $989 = Math_fround(HEAPF32[$80>>2]);
       $990 = Math_fround($928 + $989);
       $991 = Math_fround(HEAPF32[$81>>2]);
       $992 = Math_fround($936 + $991);
       $993 = Math_fround(HEAPF32[$82>>2]);
       $994 = Math_fround($944 + $993);
       $995 = Math_fround(HEAPF32[$83>>2]);
       $996 = Math_fround($995 + $972);
       $997 = Math_fround(HEAPF32[$84>>2]);
       $998 = Math_fround($980 + $997);
       $999 = Math_fround(HEAPF32[$85>>2]);
       $1000 = Math_fround($988 + $999);
       $1001 = Math_fround($990 - $996);
       $1002 = Math_fround($992 - $998);
       $1003 = Math_fround($994 - $1000);
       $1004 = Math_fround(HEAPF32[$70>>2]);
       $1005 = Math_fround($936 * $1004);
       $1006 = Math_fround(HEAPF32[$69>>2]);
       $1007 = Math_fround($944 * $1006);
       $1008 = Math_fround($1005 - $1007);
       $1009 = Math_fround(HEAPF32[$t0>>2]);
       $1010 = Math_fround($944 * $1009);
       $1011 = Math_fround($928 * $1004);
       $1012 = Math_fround($1010 - $1011);
       $1013 = Math_fround($928 * $1006);
       $1014 = Math_fround($936 * $1009);
       $1015 = Math_fround($1013 - $1014);
       $1016 = Math_fround($980 * $1004);
       $1017 = Math_fround($988 * $1006);
       $1018 = Math_fround($1016 - $1017);
       $1019 = Math_fround($988 * $1009);
       $1020 = Math_fround($972 * $1004);
       $1021 = Math_fround($1019 - $1020);
       $1022 = Math_fround($972 * $1006);
       $1023 = Math_fround($980 * $1009);
       $1024 = Math_fround($1022 - $1023);
       HEAPF32[$5>>2] = $1009;
       HEAPF32[$86>>2] = $1006;
       HEAPF32[$87>>2] = $1004;
       HEAPF32[$88>>2] = Math_fround(0.0);
       HEAPF32[$89>>2] = $1008;
       HEAPF32[$90>>2] = $1012;
       HEAPF32[$91>>2] = $1015;
       HEAPF32[$92>>2] = Math_fround(0.0);
       $1025 = Math_fround(-$1009);
       $1026 = Math_fround(-$1006);
       $1027 = Math_fround(-$1004);
       $1028 = Math_fround(-$1018);
       $1029 = Math_fround(-$1021);
       $1030 = Math_fround(-$1024);
       HEAPF32[$6>>2] = $1025;
       HEAPF32[$93>>2] = $1026;
       HEAPF32[$94>>2] = $1027;
       HEAPF32[$95>>2] = Math_fround(0.0);
       HEAPF32[$96>>2] = $1028;
       HEAPF32[$97>>2] = $1029;
       HEAPF32[$98>>2] = $1030;
       HEAPF32[$99>>2] = Math_fround(0.0);
       $1031 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$5,$deltaV06,$46,$50,$b1,$6,$deltaV17,$49,$51,0)));
       $1032 = Math_fround(Math_fround(1.0) / $1031);
       $1033 = Math_fround($1032 * Math_fround(0.800000011920928955078));
       $1034 = !($1031 > Math_fround(0.0));
       $1035 = $1034 ? Math_fround(0.0) : $1033;
       $1036 = HEAP32[$161>>2]|0;
       $1037 = (($c) + (($1036*12)|0)|0);
       $1038 = HEAP16[$1037>>1]|0;
       $1039 = $1038&65535;
       $1040 = ((($buffer) + ($1039<<6)|0) + 32|0);
       $1041 = Math_fround(HEAPF32[$1040>>2]);
       $1042 = Math_fround($1041 * $1009);
       $1043 = ((($buffer) + ($1039<<6)|0) + 36|0);
       $1044 = Math_fround(HEAPF32[$1043>>2]);
       $1045 = Math_fround($1044 * $1006);
       $1046 = Math_fround($1042 + $1045);
       $1047 = ((($buffer) + ($1039<<6)|0) + 40|0);
       $1048 = Math_fround(HEAPF32[$1047>>2]);
       $1049 = Math_fround($1048 * $1004);
       $1050 = Math_fround($1046 + $1049);
       HEAPF32[$ptr$2972>>2] = $583;
       $1051 = (($ptr$2972) + 4|0);
       HEAPF32[$1051>>2] = $584;
       $1052 = (($ptr$2972) + 8|0);
       HEAPF32[$1052>>2] = $585;
       $1053 = (($ptr$2972) + 12|0);
       HEAPF32[$1053>>2] = Math_fround(0.0);
       $1054 = (($ptr$2972) + 16|0);
       HEAPF32[$1054>>2] = $1008;
       $1055 = (($ptr$2972) + 20|0);
       HEAPF32[$1055>>2] = $1012;
       $1056 = (($ptr$2972) + 24|0);
       HEAPF32[$1056>>2] = $1015;
       $1057 = (($ptr$2972) + 28|0);
       HEAPF32[$1057>>2] = $1035;
       $1058 = Math_fround(HEAPF32[$t0>>2]);
       $1059 = Math_fround($1001 * $1058);
       $1060 = Math_fround(HEAPF32[$69>>2]);
       $1061 = Math_fround($1002 * $1060);
       $1062 = Math_fround($1059 + $1061);
       $1063 = Math_fround(HEAPF32[$70>>2]);
       $1064 = Math_fround($1003 * $1063);
       $1065 = Math_fround($1062 + $1064);
       $1066 = Math_fround($1065 * $invDtF32);
       $1067 = (($ptr$2972) + 32|0);
       HEAPF32[$1067>>2] = $1018;
       $1068 = (($ptr$2972) + 36|0);
       HEAPF32[$1068>>2] = $1021;
       $1069 = (($ptr$2972) + 40|0);
       HEAPF32[$1069>>2] = $1024;
       $1070 = (($ptr$2972) + 44|0);
       HEAPF32[$1070>>2] = $1066;
       $1071 = Math_fround(HEAPF32[$100>>2]);
       $1072 = Math_fround(HEAPF32[$101>>2]);
       $1073 = Math_fround(HEAPF32[$102>>2]);
       $1074 = (($ptr$2972) + 48|0);
       HEAPF32[$1074>>2] = $1071;
       $1075 = (($ptr$2972) + 52|0);
       HEAPF32[$1075>>2] = $1072;
       $1076 = (($ptr$2972) + 56|0);
       HEAPF32[$1076>>2] = $1073;
       $1077 = (($ptr$2972) + 60|0);
       HEAPF32[$1077>>2] = Math_fround(0.0);
       $1078 = Math_fround(HEAPF32[$103>>2]);
       $1079 = Math_fround(HEAPF32[$104>>2]);
       $1080 = Math_fround(HEAPF32[$105>>2]);
       $1081 = (($ptr$2972) + 64|0);
       HEAPF32[$1081>>2] = $1078;
       $1082 = (($ptr$2972) + 68|0);
       HEAPF32[$1082>>2] = $1079;
       $1083 = (($ptr$2972) + 72|0);
       HEAPF32[$1083>>2] = $1080;
       $1084 = (($ptr$2972) + 76|0);
       HEAPF32[$1084>>2] = $1050;
       $1085 = Math_fround(HEAPF32[$deltaV06>>2]);
       $1086 = Math_fround(HEAPF32[$106>>2]);
       $1087 = Math_fround(HEAPF32[$107>>2]);
       $1088 = (($ptr$2972) + 96|0);
       HEAPF32[$1088>>2] = $1085;
       $1089 = (($ptr$2972) + 100|0);
       HEAPF32[$1089>>2] = $1086;
       $1090 = (($ptr$2972) + 104|0);
       HEAPF32[$1090>>2] = $1087;
       $1091 = (($ptr$2972) + 108|0);
       HEAPF32[$1091>>2] = Math_fround(0.0);
       $1092 = Math_fround(HEAPF32[$deltaV17>>2]);
       $1093 = Math_fround(HEAPF32[$108>>2]);
       $1094 = Math_fround(HEAPF32[$109>>2]);
       $1095 = (($ptr$2972) + 112|0);
       HEAPF32[$1095>>2] = $1092;
       $1096 = (($ptr$2972) + 116|0);
       HEAPF32[$1096>>2] = $1093;
       $1097 = (($ptr$2972) + 120|0);
       HEAPF32[$1097>>2] = $1094;
       $1098 = (($ptr$2972) + 124|0);
       HEAPF32[$1098>>2] = Math_fround(0.0);
       $1099 = Math_fround(HEAPF32[$72>>2]);
       $1100 = Math_fround($936 * $1099);
       $1101 = Math_fround(HEAPF32[$71>>2]);
       $1102 = Math_fround($944 * $1101);
       $1103 = Math_fround($1100 - $1102);
       $1104 = Math_fround(HEAPF32[$t1>>2]);
       $1105 = Math_fround($944 * $1104);
       $1106 = Math_fround($928 * $1099);
       $1107 = Math_fround($1105 - $1106);
       $1108 = Math_fround($928 * $1101);
       $1109 = Math_fround($936 * $1104);
       $1110 = Math_fround($1108 - $1109);
       $1111 = Math_fround($980 * $1099);
       $1112 = Math_fround($988 * $1101);
       $1113 = Math_fround($1111 - $1112);
       $1114 = Math_fround($988 * $1104);
       $1115 = Math_fround($972 * $1099);
       $1116 = Math_fround($1114 - $1115);
       $1117 = Math_fround($972 * $1101);
       $1118 = Math_fround($980 * $1104);
       $1119 = Math_fround($1117 - $1118);
       HEAPF32[$7>>2] = $1104;
       HEAPF32[$110>>2] = $1101;
       HEAPF32[$111>>2] = $1099;
       HEAPF32[$112>>2] = Math_fround(0.0);
       HEAPF32[$113>>2] = $1103;
       HEAPF32[$114>>2] = $1107;
       HEAPF32[$115>>2] = $1110;
       HEAPF32[$116>>2] = Math_fround(0.0);
       $1120 = Math_fround(-$1104);
       $1121 = Math_fround(-$1101);
       $1122 = Math_fround(-$1099);
       $1123 = Math_fround(-$1113);
       $1124 = Math_fround(-$1116);
       $1125 = Math_fround(-$1119);
       HEAPF32[$8>>2] = $1120;
       HEAPF32[$117>>2] = $1121;
       HEAPF32[$118>>2] = $1122;
       HEAPF32[$119>>2] = Math_fround(0.0);
       HEAPF32[$120>>2] = $1123;
       HEAPF32[$121>>2] = $1124;
       HEAPF32[$122>>2] = $1125;
       HEAPF32[$123>>2] = Math_fround(0.0);
       $1126 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$7,$deltaV011,$46,$50,$b1,$8,$deltaV112,$49,$51,0)));
       $1127 = Math_fround(Math_fround(1.0) / $1126);
       $1128 = Math_fround($1127 * Math_fround(0.800000011920928955078));
       $1129 = !($1126 > Math_fround(0.0));
       $1130 = $1129 ? Math_fround(0.0) : $1128;
       $1131 = HEAP32[$161>>2]|0;
       $1132 = (($c) + (($1131*12)|0)|0);
       $1133 = HEAP16[$1132>>1]|0;
       $1134 = $1133&65535;
       $1135 = ((($buffer) + ($1134<<6)|0) + 32|0);
       $1136 = Math_fround(HEAPF32[$1135>>2]);
       $1137 = Math_fround(HEAPF32[$t0>>2]);
       $1138 = Math_fround($1136 * $1137);
       $1139 = ((($buffer) + ($1134<<6)|0) + 36|0);
       $1140 = Math_fround(HEAPF32[$1139>>2]);
       $1141 = Math_fround(HEAPF32[$69>>2]);
       $1142 = Math_fround($1140 * $1141);
       $1143 = Math_fround($1138 + $1142);
       $1144 = ((($buffer) + ($1134<<6)|0) + 40|0);
       $1145 = Math_fround(HEAPF32[$1144>>2]);
       $1146 = Math_fround(HEAPF32[$70>>2]);
       $1147 = Math_fround($1145 * $1146);
       $1148 = Math_fround($1143 + $1147);
       HEAPF32[$897>>2] = $586;
       $1149 = (($ptr$2972) + ($$sum936937)|0);
       HEAPF32[$1149>>2] = $587;
       $1150 = (($ptr$2972) + ($$sum938939)|0);
       HEAPF32[$1150>>2] = $588;
       $1151 = (($ptr$2972) + ($$sum940941)|0);
       HEAPF32[$1151>>2] = Math_fround(0.0);
       $1152 = (($ptr$2972) + ($$sum56)|0);
       HEAPF32[$1152>>2] = $1103;
       $1153 = (($ptr$2972) + ($$sum942943)|0);
       HEAPF32[$1153>>2] = $1107;
       $1154 = (($ptr$2972) + ($$sum944945)|0);
       HEAPF32[$1154>>2] = $1110;
       $1155 = (($ptr$2972) + ($$sum946947)|0);
       HEAPF32[$1155>>2] = $1130;
       $1156 = (($ptr$2972) + ($$sum7)|0);
       $1157 = Math_fround(HEAPF32[$t1>>2]);
       $1158 = Math_fround($1001 * $1157);
       $1159 = Math_fround(HEAPF32[$71>>2]);
       $1160 = Math_fround($1002 * $1159);
       $1161 = Math_fround($1158 + $1160);
       $1162 = Math_fround(HEAPF32[$72>>2]);
       $1163 = Math_fround($1003 * $1162);
       $1164 = Math_fround($1161 + $1163);
       $1165 = Math_fround($1164 * $invDtF32);
       HEAPF32[$1156>>2] = $1113;
       $1166 = (($ptr$2972) + ($$sum948)|0);
       HEAPF32[$1166>>2] = $1116;
       $1167 = (($ptr$2972) + ($$sum949)|0);
       HEAPF32[$1167>>2] = $1119;
       $1168 = (($ptr$2972) + ($$sum950)|0);
       HEAPF32[$1168>>2] = $1165;
       $1169 = (($ptr$2972) + ($$sum8)|0);
       $1170 = Math_fround(HEAPF32[$124>>2]);
       $1171 = Math_fround(HEAPF32[$125>>2]);
       $1172 = Math_fround(HEAPF32[$126>>2]);
       HEAPF32[$1169>>2] = $1170;
       $1173 = (($ptr$2972) + ($$sum951)|0);
       HEAPF32[$1173>>2] = $1171;
       $1174 = (($ptr$2972) + ($$sum952)|0);
       HEAPF32[$1174>>2] = $1172;
       $1175 = (($ptr$2972) + ($$sum953)|0);
       HEAPF32[$1175>>2] = Math_fround(0.0);
       $1176 = (($ptr$2972) + ($$sum9)|0);
       $1177 = Math_fround(HEAPF32[$127>>2]);
       $1178 = Math_fround(HEAPF32[$128>>2]);
       $1179 = Math_fround(HEAPF32[$129>>2]);
       HEAPF32[$1176>>2] = $1177;
       $1180 = (($ptr$2972) + ($$sum954)|0);
       HEAPF32[$1180>>2] = $1178;
       $1181 = (($ptr$2972) + ($$sum955)|0);
       HEAPF32[$1181>>2] = $1179;
       $1182 = (($ptr$2972) + ($$sum956)|0);
       HEAPF32[$1182>>2] = $1148;
       $1183 = (($ptr$2972) + ($$sum10)|0);
       $1184 = Math_fround(HEAPF32[$deltaV011>>2]);
       $1185 = Math_fround(HEAPF32[$130>>2]);
       $1186 = Math_fround(HEAPF32[$131>>2]);
       HEAPF32[$1183>>2] = $1184;
       $1187 = (($ptr$2972) + ($$sum957)|0);
       HEAPF32[$1187>>2] = $1185;
       $1188 = (($ptr$2972) + ($$sum958)|0);
       HEAPF32[$1188>>2] = $1186;
       $1189 = (($ptr$2972) + ($$sum959)|0);
       HEAPF32[$1189>>2] = Math_fround(0.0);
       $1190 = (($ptr$2972) + ($$sum11)|0);
       $1191 = Math_fround(HEAPF32[$deltaV112>>2]);
       $1192 = Math_fround(HEAPF32[$132>>2]);
       $1193 = Math_fround(HEAPF32[$133>>2]);
       HEAPF32[$1190>>2] = $1191;
       $1194 = (($ptr$2972) + ($$sum960)|0);
       HEAPF32[$1194>>2] = $1192;
       $1195 = (($ptr$2972) + ($$sum961)|0);
       HEAPF32[$1195>>2] = $1193;
       $1196 = (($ptr$2972) + ($$sum962)|0);
       HEAPF32[$1196>>2] = Math_fround(0.0);
       $1197 = (($j1$0971) + 1)|0;
       $1198 = HEAP16[$592>>1]|0;
       $1199 = $1198&65535;
       $1200 = ($1197>>>0)<($1199>>>0);
       if ($1200) {
        $j1$0971 = $1197;$ptr$2972 = $898;
       } else {
        $ptr$3 = $898;
        break;
       }
      }
     }
    }
   } else {
    $ptr$3 = $ptr$1$lcssa;
   }
   $1201 = (($frictionPatchWritebackAddrIndex$0982) + 1)|0;
   $frictionPatchWritebackAddrIndex$1 = $1201;$ptr$4 = $ptr$3;
  }
  $1202 = (($i$0976) + 1)|0;
  $1203 = HEAP32[$61>>2]|0;
  $1204 = ($1202>>>0)<($1203>>>0);
  if ($1204) {
   $frictionPatchWritebackAddrIndex$0982 = $frictionPatchWritebackAddrIndex$1;$i$0976 = $1202;$ptr$0983 = $ptr$4;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23computeFrictionTangentsERKNS_6PxVec3ES2_RS0_S3_($vrel,$unitNormal,$t0,$t1) {
 $vrel = $vrel|0;
 $unitNormal = $unitNormal|0;
 $t0 = $t0|0;
 $t1 = $t1|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $9 = 0, $fabsf$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$unitNormal>>2]);
 $1 = Math_fround(HEAPF32[$vrel>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($unitNormal) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($vrel) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($unitNormal) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($vrel) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = Math_fround($0 * $14);
 $16 = Math_fround($4 * $14);
 $17 = Math_fround($10 * $14);
 $18 = Math_fround($1 - $15);
 $19 = Math_fround($6 - $16);
 $20 = Math_fround($12 - $17);
 HEAPF32[$t0>>2] = $18;
 $21 = (($t0) + 4|0);
 HEAPF32[$21>>2] = $19;
 $22 = (($t0) + 8|0);
 HEAPF32[$22>>2] = $20;
 $23 = Math_fround($18 * $18);
 $24 = Math_fround($19 * $19);
 $25 = Math_fround($23 + $24);
 $26 = Math_fround($20 * $20);
 $27 = Math_fround($25 + $26);
 $28 = $27 > Math_fround(0.100000001490116119385);
 if ($28) {
  $29 = (Math_fround(Math_sqrt((Math_fround($27)))));
  $30 = Math_fround(Math_fround(1.0) / $29);
  $31 = Math_fround($18 * $30);
  HEAPF32[$t0>>2] = $31;
  $32 = Math_fround($30 * $19);
  HEAPF32[$21>>2] = $32;
  $33 = Math_fround($30 * $20);
  HEAPF32[$22>>2] = $33;
  $34 = Math_fround(HEAPF32[$3>>2]);
  $35 = Math_fround($34 * $33);
  $36 = Math_fround(HEAPF32[$9>>2]);
  $37 = Math_fround($36 * $32);
  $38 = Math_fround($35 - $37);
  $39 = Math_fround($36 * $31);
  $40 = Math_fround(HEAPF32[$unitNormal>>2]);
  $41 = Math_fround($33 * $40);
  $42 = Math_fround($39 - $41);
  $43 = Math_fround($32 * $40);
  $44 = Math_fround($34 * $31);
  $45 = Math_fround($43 - $44);
  HEAPF32[$t1>>2] = $38;
  $46 = (($t1) + 4|0);
  HEAPF32[$46>>2] = $42;
  $47 = (($t1) + 8|0);
  HEAPF32[$47>>2] = $45;
  STACKTOP = sp;return;
 }
 $48 = Math_fround(HEAPF32[$unitNormal>>2]);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($48)))));
 $49 = $fabsf$i$i$i < Math_fround(0.707106769084930419921);
 if ($49) {
  $50 = Math_fround(HEAPF32[$9>>2]);
  $51 = Math_fround(-$50);
  $52 = Math_fround(HEAPF32[$3>>2]);
  $55 = Math_fround(0.0);$56 = $51;$57 = $52;
 } else {
  $53 = Math_fround(HEAPF32[$3>>2]);
  $54 = Math_fround(-$53);
  $55 = $54;$56 = $48;$57 = Math_fround(0.0);
 }
 HEAPF32[$t0>>2] = $55;
 HEAPF32[$21>>2] = $56;
 HEAPF32[$22>>2] = $57;
 $58 = Math_fround($55 * $55);
 $59 = Math_fround($56 * $56);
 $60 = Math_fround($59 + $58);
 $61 = Math_fround($57 * $57);
 $62 = Math_fround($61 + $60);
 $63 = (Math_fround(Math_sqrt((Math_fround($62)))));
 $64 = $63 > Math_fround(0.0);
 if ($64) {
  $65 = Math_fround(Math_fround(1.0) / $63);
  $66 = Math_fround($55 * $65);
  HEAPF32[$t0>>2] = $66;
  $67 = Math_fround($56 * $65);
  HEAPF32[$21>>2] = $67;
  $68 = Math_fround($57 * $65);
  HEAPF32[$22>>2] = $68;
  $71 = $68;$74 = $67;$77 = $66;
 } else {
  $71 = $57;$74 = $56;$77 = $55;
 }
 $69 = Math_fround(HEAPF32[$3>>2]);
 $70 = Math_fround($71 * $69);
 $72 = Math_fround(HEAPF32[$9>>2]);
 $73 = Math_fround($74 * $72);
 $75 = Math_fround($70 - $73);
 $76 = Math_fround($77 * $72);
 $78 = Math_fround(HEAPF32[$unitNormal>>2]);
 $79 = Math_fround($71 * $78);
 $80 = Math_fround($76 - $79);
 $81 = Math_fround($74 * $78);
 $82 = Math_fround($77 * $69);
 $83 = Math_fround($81 - $82);
 HEAPF32[$t1>>2] = $75;
 $84 = (($t1) + 4|0);
 HEAPF32[$84>>2] = $80;
 $85 = (($t1) + 8|0);
 HEAPF32[$85>>2] = $83;
 STACKTOP = sp;return;
}
function __ZN5physx40setupFinalizeExtSolverConstraintsCoulombERNS_13PxcNpWorkUnitERKNS_2Gu13ContactBufferERKNS_27PxcCorrelationBufferCoulombERKNS_11PxTransformESB_bPhffRNS_16PxsSolverExtBodyESE_jffff($n,$buffer,$c,$bodyFrame0,$bodyFrame1,$0,$workspace,$invDt,$bounceThreshold,$b0,$b1,$frictionCountPerPoint,$invMassScale0,$invInertiaScale0,$invMassScale1,$invInertiaScale1) {
 $n = $n|0;
 $buffer = $buffer|0;
 $c = $c|0;
 $bodyFrame0 = $bodyFrame0|0;
 $bodyFrame1 = $bodyFrame1|0;
 $0 = $0|0;
 $workspace = $workspace|0;
 $invDt = Math_fround($invDt);
 $bounceThreshold = Math_fround($bounceThreshold);
 $b0 = $b0|0;
 $b1 = $b1|0;
 $frictionCountPerPoint = $frictionCountPerPoint|0;
 $invMassScale0 = Math_fround($invMassScale0);
 $invInertiaScale0 = Math_fround($invInertiaScale0);
 $invMassScale1 = Math_fround($invMassScale1);
 $invInertiaScale1 = Math_fround($invInertiaScale1);
 var $$$i = Math_fround(0), $$in = 0, $$in1 = 0, $$lobit = 0, $$pre$pre = 0, $$sum = 0, $$sum$i = 0, $$sum$i33 = 0, $$sum156 = 0, $$sum157 = 0, $$sum158 = 0, $$sum4$us = 0, $$sum5 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0);
 var $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0);
 var $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0);
 var $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = 0, $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = 0;
 var $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0);
 var $411 = Math_fround(0), $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0);
 var $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0), $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0);
 var $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0);
 var $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = Math_fround(0), $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = Math_fround(0), $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = Math_fround(0), $537 = Math_fround(0);
 var $538 = 0, $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $deltaV0 = 0, $deltaV017 = 0, $deltaV1 = 0, $deltaV118 = 0, $exitcond = 0, $exitcond204 = 0, $exitcond205 = 0, $exitcond207 = 0, $exitcond208 = 0, $hasFriction$0$off0$lcssa = 0, $hasFriction$0$off0181 = 0, $hasFriction$1$off0 = 0;
 var $i$0199 = 0, $i1$0180 = 0, $ind$0171 = 0, $ind$1$lcssa = 0, $ind$1163$us = 0, $ind$2159$us = 0, $ispos = 0, $j$0187 = 0, $j11$0165$us = 0, $k$0161$us = 0, $neg = 0, $normal = 0, $or$cond$i = 0, $p$0$lcssa = 0, $p$0188 = 0, $p10$0$lcssa = 0, $p10$0164$us = 0, $p10$1160$us = 0, $patch$0194 = 0, $patch7$0175 = 0;
 var $phitmp = 0, $phitmp155 = 0, $ptr$0200 = 0, $ptr$1195 = 0, $ptr$2 = 0, $ptr$3183 = 0, $ptr$4176 = 0, $ptr$5 = 0, $ptr2$0182 = 0, $ptr2$1 = 0, $raXn = 0, $rbXn = 0, $scaledBias$0$i = Math_fround(0), $scevgep = 0, $scevgep206 = 0, $t0Fallback1 = 0, $t0Fallback1$t0Fallback2 = 0, $t0Fallback2 = 0, $t0_ = 0, $tFallback = 0;
 var $tFallback1 = 0, $targetVelocity$0$i = Math_fround(0), $totalPatchContactCount$0172 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $normal = sp + 376|0;
 $raXn = sp + 364|0;
 $rbXn = sp + 352|0;
 $deltaV0 = sp + 64|0;
 $deltaV1 = sp + 96|0;
 $1 = sp + 128|0;
 $2 = sp + 160|0;
 $t0Fallback1 = sp + 340|0;
 $t0Fallback2 = sp + 328|0;
 $tFallback1 = sp + 256|0;
 $3 = sp + 268|0;
 $4 = sp + 280|0;
 $t0_ = sp + 292|0;
 $tFallback = sp + 304|0;
 $deltaV017 = sp;
 $deltaV118 = sp + 192|0;
 $5 = sp + 224|0;
 $6 = sp + 32|0;
 $7 = (($b0) + 8|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = ($8<<16>>16)==(-1);
 if ($9) {
  $10 = (($b0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 52|0);
  $$in = $12;
 } else {
  $13 = $8&65535;
  $14 = HEAP32[$b0>>2]|0;
  $15 = (($14) + 128|0);
  $16 = (($14) + 8|0);
  $17 = HEAP16[$16>>1]|0;
  $18 = $17&65535;
  $$sum$i = ($18*80)|0;
  $19 = (($15) + ($$sum$i)|0);
  $20 = (($19) + ($13<<2)|0);
  $$in = $20;
 }
 $21 = Math_fround(HEAPF32[$$in>>2]);
 $22 = (($b1) + 8|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = ($23<<16>>16)==(-1);
 if ($24) {
  $25 = (($b1) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 52|0);
  $$in1 = $27;
 } else {
  $28 = $8&65535;
  $29 = HEAP32[$b1>>2]|0;
  $30 = (($29) + 128|0);
  $31 = (($29) + 8|0);
  $32 = HEAP16[$31>>1]|0;
  $33 = $32&65535;
  $$sum$i33 = ($33*80)|0;
  $34 = (($30) + ($$sum$i33)|0);
  $35 = (($34) + ($28<<2)|0);
  $$in1 = $35;
 }
 $36 = Math_fround(HEAPF32[$$in1>>2]);
 $37 = $21 > $36;
 $38 = $37 ? $21 : $36;
 $39 = Math_fround($38 / $invDt);
 $40 = (($n) + 92|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($c) + 1664|0);
 $43 = (($c) + 1792|0);
 $44 = (($n) + 22|0);
 $45 = HEAP16[$44>>1]|0;
 $46 = $45&65535;
 $47 = $46 & 24;
 $48 = ($47|0)!=(0);
 $49 = (($c) + 1796|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $46 >>> 6;
 $52 = $48 ? 112 : 80;
 $53 = $48 ? 128 : 96;
 if ($48) {
  $175 = 3;$441 = 12;
 } else {
  $$lobit = $51 << 2;
  $54 = $$lobit & 4;
  $55 = $54 ^ 5;
  $56 = $55&255;
  $57 = $51 & 1;
  $58 = $57 ^ 11;
  $phitmp = $58&255;
  $175 = $56;$441 = $phitmp;
 }
 $59 = (($n) + 84|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 * $invMassScale0);
 $62 = (($n) + 88|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $invMassScale1);
 $65 = Math_fround($60 * $invInertiaScale0);
 $66 = Math_fround($63 * $invInertiaScale1);
 $67 = ($50|0)==(0);
 if ($67) {
  $hasFriction$0$off0$lcssa = 0;
  STACKTOP = sp;return ($hasFriction$0$off0$lcssa|0);
 }
 $68 = (($normal) + 4|0);
 $69 = (($normal) + 8|0);
 $70 = (($bodyFrame0) + 16|0);
 $71 = (($bodyFrame0) + 20|0);
 $72 = (($bodyFrame0) + 24|0);
 $73 = (($bodyFrame1) + 16|0);
 $74 = (($bodyFrame1) + 20|0);
 $75 = (($bodyFrame1) + 24|0);
 $76 = (($raXn) + 4|0);
 $77 = (($raXn) + 8|0);
 $78 = (($rbXn) + 4|0);
 $79 = (($rbXn) + 8|0);
 $80 = (($1) + 4|0);
 $81 = (($1) + 8|0);
 $82 = (($1) + 12|0);
 $83 = (($1) + 16|0);
 $84 = (($1) + 20|0);
 $85 = (($1) + 24|0);
 $86 = (($1) + 28|0);
 $87 = (($2) + 4|0);
 $88 = (($2) + 8|0);
 $89 = (($2) + 12|0);
 $90 = (($2) + 16|0);
 $91 = (($2) + 20|0);
 $92 = (($2) + 24|0);
 $93 = (($2) + 28|0);
 $94 = (($deltaV0) + 16|0);
 $95 = (($deltaV0) + 20|0);
 $96 = (($deltaV0) + 24|0);
 $97 = (($deltaV0) + 4|0);
 $98 = (($deltaV0) + 8|0);
 $99 = (($deltaV1) + 16|0);
 $100 = (($deltaV1) + 20|0);
 $101 = (($deltaV1) + 24|0);
 $102 = (($deltaV1) + 4|0);
 $103 = (($deltaV1) + 8|0);
 $i$0199 = 0;$ptr$0200 = $workspace;
 while(1) {
  $153 = ((($c) + ($i$0199<<2)|0) + 1408|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = ($154|0)==(0);
  if ($155) {
   $ptr$2 = $ptr$0200;
  } else {
   $156 = ((($c) + ($i$0199<<2)|0) + 1536|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($c) + (($157*12)|0)|0);
   $159 = HEAP16[$158>>1]|0;
   $160 = $159&65535;
   $161 = ((($c) + (($i$0199*20)|0)|0) + 768|0);
   $162 = Math_fround(HEAPF32[$161>>2]);
   $163 = ((($c) + (($i$0199*20)|0)|0) + 772|0);
   $164 = Math_fround(HEAPF32[$163>>2]);
   $165 = ((($c) + (($i$0199*20)|0)|0) + 776|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   HEAPF32[$normal>>2] = $162;
   HEAPF32[$68>>2] = $164;
   HEAPF32[$69>>2] = $166;
   $167 = ((($buffer) + ($160<<6)|0) + 60|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = (($ptr$0200) + 48|0);
   $170 = (($ptr$0200) + 176|0);
   $171 = (($ptr$0200) + 304|0);
   $172 = (($ptr$0200) + 432|0);
   $173 = $154&255;
   $174 = (($ptr$0200) + 1|0);
   HEAP8[$174>>0] = $173;
   HEAP8[$ptr$0200>>0] = $175;
   $176 = (($ptr$0200) + 4|0);
   HEAPF32[$176>>2] = $168;
   $177 = (($ptr$0200) + 8|0);
   HEAPF32[$177>>2] = $61;
   $178 = (($ptr$0200) + 12|0);
   HEAPF32[$178>>2] = $64;
   $179 = (($ptr$0200) + 28|0);
   HEAPF32[$179>>2] = $65;
   $180 = (($ptr$0200) + 32|0);
   HEAPF32[$180>>2] = $66;
   $181 = (($ptr$0200) + 16|0);
   HEAPF32[$181>>2] = $162;
   $182 = (($ptr$0200) + 20|0);
   HEAPF32[$182>>2] = $164;
   $183 = (($ptr$0200) + 24|0);
   HEAPF32[$183>>2] = $166;
   $184 = HEAP32[$156>>2]|0;
   $185 = ($184|0)==(65535);
   if ($185) {
    $ptr$2 = $169;
   } else {
    $patch$0194 = $184;$ptr$1195 = $169;
    while(1) {
     $186 = ((($c) + (($patch$0194*12)|0)|0) + 2|0);
     $187 = HEAP16[$186>>1]|0;
     $188 = (($c) + (($patch$0194*12)|0)|0);
     $189 = HEAP16[$188>>1]|0;
     $190 = $189&65535;
     $191 = ($187<<16>>16)==(0);
     if ($191) {
      $p$0$lcssa = $ptr$1195;
     } else {
      $192 = $187&65535;
      $193 = Math_imul($52, $192)|0;
      $j$0187 = 0;$p$0188 = $ptr$1195;
      while(1) {
       $$sum5 = (($j$0187) + ($190))|0;
       $194 = (($p$0188) + ($52)|0);
       $195 = ((($buffer) + ($$sum5<<6)|0) + 12|0);
       $196 = Math_fround(HEAPF32[$195>>2]);
       $197 = ((($buffer) + ($$sum5<<6)|0) + 16|0);
       $198 = Math_fround(HEAPF32[$197>>2]);
       $199 = Math_fround(HEAPF32[$70>>2]);
       $200 = Math_fround($198 - $199);
       $201 = ((($buffer) + ($$sum5<<6)|0) + 20|0);
       $202 = Math_fround(HEAPF32[$201>>2]);
       $203 = Math_fround(HEAPF32[$71>>2]);
       $204 = Math_fround($202 - $203);
       $205 = ((($buffer) + ($$sum5<<6)|0) + 24|0);
       $206 = Math_fround(HEAPF32[$205>>2]);
       $207 = Math_fround(HEAPF32[$72>>2]);
       $208 = Math_fround($206 - $207);
       $209 = Math_fround(HEAPF32[$73>>2]);
       $210 = Math_fround($198 - $209);
       $211 = Math_fround(HEAPF32[$74>>2]);
       $212 = Math_fround($202 - $211);
       $213 = Math_fround(HEAPF32[$75>>2]);
       $214 = Math_fround($206 - $213);
       $215 = ((($buffer) + ($$sum5<<6)|0) + 32|0);
       $216 = Math_fround(HEAPF32[$215>>2]);
       $217 = ((($buffer) + ($$sum5<<6)|0) + 36|0);
       $218 = Math_fround(HEAPF32[$217>>2]);
       $219 = ((($buffer) + ($$sum5<<6)|0) + 40|0);
       $220 = Math_fround(HEAPF32[$219>>2]);
       $221 = ((($buffer) + ($$sum5<<6)|0) + 28|0);
       $222 = Math_fround(HEAPF32[$221>>2]);
       $223 = Math_fround($196 - $41);
       $224 = $39 > $223;
       $$$i = $224 ? $39 : $223;
       $225 = Math_fround($162 * $216);
       $226 = Math_fround($164 * $218);
       $227 = Math_fround($225 + $226);
       $228 = Math_fround($166 * $220);
       $229 = Math_fround($227 + $228);
       $230 = (($p$0188) + 32|0);
       HEAPF32[$230>>2] = $$$i;
       $231 = (($p$0188) + 36|0);
       HEAPF32[$231>>2] = $229;
       $232 = (($p$0188) + 40|0);
       HEAPF32[$232>>2] = $222;
       $233 = (($p$0188) + 44|0);
       HEAPF32[$233>>2] = Math_fround(0.0);
       $234 = Math_fround(HEAPF32[$69>>2]);
       $235 = Math_fround($204 * $234);
       $236 = Math_fround(HEAPF32[$68>>2]);
       $237 = Math_fround($208 * $236);
       $238 = Math_fround($235 - $237);
       $239 = Math_fround(HEAPF32[$normal>>2]);
       $240 = Math_fround($208 * $239);
       $241 = Math_fround($200 * $234);
       $242 = Math_fround($240 - $241);
       $243 = Math_fround($200 * $236);
       $244 = Math_fround($204 * $239);
       $245 = Math_fround($243 - $244);
       HEAPF32[$raXn>>2] = $238;
       HEAPF32[$76>>2] = $242;
       HEAPF32[$77>>2] = $245;
       $246 = Math_fround($212 * $234);
       $247 = Math_fround($214 * $236);
       $248 = Math_fround($246 - $247);
       $249 = Math_fround($214 * $239);
       $250 = Math_fround($210 * $234);
       $251 = Math_fround($249 - $250);
       $252 = Math_fround($210 * $236);
       $253 = Math_fround($212 * $239);
       $254 = Math_fround($252 - $253);
       HEAPF32[$rbXn>>2] = $248;
       HEAPF32[$78>>2] = $251;
       HEAPF32[$79>>2] = $254;
       HEAPF32[$1>>2] = $239;
       HEAPF32[$80>>2] = $236;
       HEAPF32[$81>>2] = $234;
       HEAPF32[$82>>2] = Math_fround(0.0);
       HEAPF32[$83>>2] = $238;
       HEAPF32[$84>>2] = $242;
       HEAPF32[$85>>2] = $245;
       HEAPF32[$86>>2] = Math_fround(0.0);
       $255 = Math_fround(-$239);
       $256 = Math_fround(-$236);
       $257 = Math_fround(-$234);
       $258 = Math_fround(-$248);
       $259 = Math_fround(-$251);
       $260 = Math_fround(-$254);
       HEAPF32[$2>>2] = $255;
       HEAPF32[$87>>2] = $256;
       HEAPF32[$88>>2] = $257;
       HEAPF32[$89>>2] = Math_fround(0.0);
       HEAPF32[$90>>2] = $258;
       HEAPF32[$91>>2] = $259;
       HEAPF32[$92>>2] = $260;
       HEAPF32[$93>>2] = Math_fround(0.0);
       $261 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$1,$deltaV0,$61,$65,$b1,$2,$deltaV1,$64,$66,0)));
       $262 = (Math_fround(__ZNK5physx16PxsSolverExtBody15projectVelocityERKNS_6PxVec3ES3_($b0,$normal,$raXn)));
       $263 = (Math_fround(__ZNK5physx16PxsSolverExtBody15projectVelocityERKNS_6PxVec3ES3_($b1,$normal,$rbXn)));
       $264 = Math_fround($262 - $263);
       $265 = Math_fround(HEAPF32[$raXn>>2]);
       $266 = Math_fround(HEAPF32[$76>>2]);
       $267 = Math_fround(HEAPF32[$77>>2]);
       HEAPF32[$p$0188>>2] = $265;
       $268 = (($p$0188) + 4|0);
       HEAPF32[$268>>2] = $266;
       $269 = (($p$0188) + 8|0);
       HEAPF32[$269>>2] = $267;
       $270 = (($p$0188) + 12|0);
       HEAPF32[$270>>2] = Math_fround(0.0);
       $271 = Math_fround(HEAPF32[$rbXn>>2]);
       $272 = Math_fround(HEAPF32[$78>>2]);
       $273 = Math_fround(HEAPF32[$79>>2]);
       $274 = (($p$0188) + 16|0);
       HEAPF32[$274>>2] = $271;
       $275 = (($p$0188) + 20|0);
       HEAPF32[$275>>2] = $272;
       $276 = (($p$0188) + 24|0);
       HEAPF32[$276>>2] = $273;
       $277 = (($p$0188) + 28|0);
       HEAPF32[$277>>2] = Math_fround(0.0);
       $278 = Math_fround(HEAPF32[$176>>2]);
       $279 = $261 != Math_fround(0.0);
       if ($279) {
        $280 = Math_fround(Math_fround(1.0) / $261);
        $283 = $280;
       } else {
        $283 = Math_fround(0.0);
       }
       $281 = Math_fround(HEAPF32[$230>>2]);
       $282 = Math_fround($283 * Math_fround(0.800000011920928955078));
       $284 = Math_fround($281 * $282);
       $285 = Math_fround($284 * $invDt);
       $286 = $278 > Math_fround(0.0);
       $287 = $264 < $bounceThreshold;
       $or$cond$i = $286 & $287;
       if ($or$cond$i) {
        $288 = Math_fround($264 * $278);
        $289 = Math_fround(-$288);
        $scaledBias$0$i = Math_fround(0.0);$targetVelocity$0$i = $289;
       } else {
        $scaledBias$0$i = $285;$targetVelocity$0$i = Math_fround(0.0);
       }
       HEAPF32[$277>>2] = $283;
       HEAPF32[$230>>2] = $scaledBias$0$i;
       HEAPF32[$231>>2] = $targetVelocity$0$i;
       HEAPF32[$270>>2] = Math_fround(0.0);
       $290 = Math_fround(HEAPF32[$94>>2]);
       $291 = Math_fround(HEAPF32[$95>>2]);
       $292 = Math_fround(HEAPF32[$96>>2]);
       $293 = Math_fround(HEAPF32[$deltaV0>>2]);
       $294 = (($p$0188) + 80|0);
       HEAPF32[$294>>2] = $293;
       $295 = Math_fround(HEAPF32[$97>>2]);
       $296 = (($p$0188) + 84|0);
       HEAPF32[$296>>2] = $295;
       $297 = Math_fround(HEAPF32[$98>>2]);
       $298 = (($p$0188) + 88|0);
       HEAPF32[$298>>2] = $297;
       $299 = (($p$0188) + 92|0);
       HEAPF32[$299>>2] = Math_fround(0.0);
       $300 = (($p$0188) + 48|0);
       HEAPF32[$300>>2] = $290;
       $301 = (($p$0188) + 52|0);
       HEAPF32[$301>>2] = $291;
       $302 = (($p$0188) + 56|0);
       HEAPF32[$302>>2] = $292;
       $303 = (($p$0188) + 60|0);
       HEAPF32[$303>>2] = Math_fround(0.0);
       $304 = Math_fround(HEAPF32[$99>>2]);
       $305 = Math_fround(HEAPF32[$100>>2]);
       $306 = Math_fround(HEAPF32[$101>>2]);
       $307 = Math_fround(HEAPF32[$deltaV1>>2]);
       $308 = (($p$0188) + 96|0);
       HEAPF32[$308>>2] = $307;
       $309 = Math_fround(HEAPF32[$102>>2]);
       $310 = (($p$0188) + 100|0);
       HEAPF32[$310>>2] = $309;
       $311 = Math_fround(HEAPF32[$103>>2]);
       $312 = (($p$0188) + 104|0);
       HEAPF32[$312>>2] = $311;
       $313 = (($p$0188) + 108|0);
       HEAPF32[$313>>2] = Math_fround(0.0);
       $314 = (($p$0188) + 64|0);
       HEAPF32[$314>>2] = $304;
       $315 = (($p$0188) + 68|0);
       HEAPF32[$315>>2] = $305;
       $316 = (($p$0188) + 72|0);
       HEAPF32[$316>>2] = $306;
       $317 = (($p$0188) + 76|0);
       HEAPF32[$317>>2] = Math_fround(0.0);
       $318 = (($j$0187) + 1)|0;
       $exitcond207 = ($318|0)==($192|0);
       if ($exitcond207) {
        break;
       } else {
        $j$0187 = $318;$p$0188 = $194;
       }
      }
      $scevgep206 = (($ptr$1195) + ($193)|0);
      $p$0$lcssa = $scevgep206;
     }
     $319 = ((($c) + (($patch$0194*12)|0)|0) + 4|0);
     $320 = HEAP16[$319>>1]|0;
     $321 = $320&65535;
     $322 = ($320<<16>>16)==(-1);
     if ($322) {
      $ptr$2 = $p$0$lcssa;
      break;
     } else {
      $patch$0194 = $321;$ptr$1195 = $p$0$lcssa;
     }
    }
   }
  }
  $323 = (($i$0199) + 1)|0;
  $exitcond208 = ($323|0)==($50|0);
  if ($exitcond208) {
   break;
  } else {
   $i$0199 = $323;$ptr$0200 = $ptr$2;
  }
 }
 if ($67) {
  $hasFriction$0$off0$lcssa = 0;
  STACKTOP = sp;return ($hasFriction$0$off0$lcssa|0);
 }
 $104 = (($t0Fallback1) + 4|0);
 $105 = (($t0Fallback1) + 8|0);
 $106 = (($t0Fallback2) + 4|0);
 $107 = (($t0Fallback2) + 8|0);
 $108 = (($tFallback1) + 4|0);
 $109 = (($tFallback1) + 8|0);
 $110 = (($3) + 4|0);
 $111 = (($4) + 4|0);
 $112 = (($3) + 8|0);
 $113 = (($4) + 8|0);
 $114 = (($t0_) + 4|0);
 $115 = (($t0_) + 8|0);
 $116 = (($tFallback) + 4|0);
 $117 = (($tFallback) + 8|0);
 $118 = (($tFallback) + 12|0);
 $119 = (($tFallback) + 16|0);
 $120 = (($tFallback) + 20|0);
 $121 = (($bodyFrame0) + 16|0);
 $122 = (($bodyFrame0) + 20|0);
 $123 = (($bodyFrame0) + 24|0);
 $124 = (($bodyFrame1) + 16|0);
 $125 = (($bodyFrame1) + 20|0);
 $126 = (($bodyFrame1) + 24|0);
 $127 = ($frictionCountPerPoint|0)==(0);
 $128 = (($5) + 4|0);
 $129 = (($5) + 8|0);
 $130 = (($5) + 12|0);
 $131 = (($5) + 16|0);
 $132 = (($5) + 20|0);
 $133 = (($5) + 24|0);
 $134 = (($5) + 28|0);
 $135 = (($6) + 4|0);
 $136 = (($6) + 8|0);
 $137 = (($6) + 12|0);
 $138 = (($6) + 16|0);
 $139 = (($6) + 20|0);
 $140 = (($6) + 24|0);
 $141 = (($6) + 28|0);
 $142 = (($deltaV017) + 16|0);
 $143 = (($deltaV017) + 20|0);
 $144 = (($deltaV017) + 24|0);
 $145 = (($deltaV017) + 4|0);
 $146 = (($deltaV017) + 8|0);
 $147 = (($deltaV118) + 16|0);
 $148 = (($deltaV118) + 20|0);
 $149 = (($deltaV118) + 24|0);
 $150 = (($deltaV118) + 4|0);
 $151 = (($deltaV118) + 8|0);
 $152 = Math_imul($53, $frictionCountPerPoint)|0;
 $hasFriction$0$off0181 = 0;$i1$0180 = 0;$ptr$3183 = $ptr$2;$ptr2$0182 = $workspace;
 while(1) {
  $324 = ((($c) + ($i1$0180<<2)|0) + 1408|0);
  $325 = HEAP32[$324>>2]|0;
  $326 = ($325|0)==(0);
  if ($326) {
   $hasFriction$1$off0 = $hasFriction$0$off0181;$ptr$5 = $ptr$3183;$ptr2$1 = $ptr2$0182;
  } else {
   $327 = $ptr$3183;
   $328 = $ptr2$0182;
   $329 = (($327) - ($328))|0;
   $330 = $329&65535;
   $331 = (($ptr2$0182) + 2|0);
   HEAP16[$331>>1] = $330;
   $332 = (($ptr2$0182) + 1|0);
   $333 = HEAP8[$332>>0]|0;
   $334 = $333&255;
   $335 = Math_imul($334, $52)|0;
   $336 = (($335) + 48)|0;
   $337 = (($ptr2$0182) + ($336)|0);
   $338 = ((($c) + (($i1$0180*20)|0)|0) + 768|0);
   $339 = Math_fround(HEAPF32[$338>>2]);
   $340 = ((($c) + (($i1$0180*20)|0)|0) + 772|0);
   $341 = Math_fround(HEAPF32[$340>>2]);
   $342 = ((($c) + (($i1$0180*20)|0)|0) + 776|0);
   $343 = Math_fround(HEAPF32[$342>>2]);
   $344 = ((($c) + ($i1$0180<<2)|0) + 1536|0);
   $345 = HEAP32[$344>>2]|0;
   $346 = (($c) + (($345*12)|0)|0);
   $347 = HEAP16[$346>>1]|0;
   $348 = $347&65535;
   $349 = ((($buffer) + ($348<<6)|0) + 44|0);
   $350 = Math_fround(HEAPF32[$349>>2]);
   $351 = ((($buffer) + ($348<<6)|0) + 52|0);
   $352 = HEAP32[$351>>2]|0;
   $353 = $352 & 1;
   $354 = ($353|0)==(0);
   $355 = $325&255;
   $356 = (($ptr$3183) + 1|0);
   HEAP8[$356>>0] = $355;
   if ($354) {
    $357 = ((($c) + (($i1$0180*20)|0)|0) + 784|0);
    $358 = HEAP16[$357>>1]|0;
    $phitmp155 = $358&255;
    $360 = $phitmp155;
   } else {
    $360 = 0;
   }
   $359 = (($ptr$3183) + 2|0);
   HEAP8[$359>>0] = $360;
   $361 = HEAP32[$324>>2]|0;
   $362 = $361 << 2;
   $363 = (($362) + 44)|0;
   $$sum = $363 & -16;
   $364 = (($ptr$3183) + ($$sum)|0);
   $$sum156 = (($$sum) + 128)|0;
   $365 = (($ptr$3183) + ($$sum156)|0);
   $$sum157 = (($$sum) + 256)|0;
   $366 = (($ptr$3183) + ($$sum157)|0);
   $$sum158 = (($$sum) + 384)|0;
   $367 = (($ptr$3183) + ($$sum158)|0);
   $368 = Math_fround(-$343);
   HEAPF32[$t0Fallback1>>2] = Math_fround(0.0);
   HEAPF32[$104>>2] = $368;
   HEAPF32[$105>>2] = $341;
   $369 = Math_fround(-$341);
   HEAPF32[$t0Fallback2>>2] = $369;
   HEAPF32[$106>>2] = $339;
   HEAPF32[$107>>2] = Math_fround(0.0);
   $370 = (~~(($339)));
   $ispos = ($370|0)>(-1);
   $neg = (0 - ($370))|0;
   $371 = $ispos ? $370 : $neg;
   $372 = (Math_fround(($371|0)));
   $373 = $372 < Math_fround(0.707106769084930419921);
   $t0Fallback1$t0Fallback2 = $373 ? $t0Fallback1 : $t0Fallback2;
   $374 = Math_fround(HEAPF32[$t0Fallback1$t0Fallback2>>2]);
   HEAPF32[$tFallback1>>2] = $374;
   $375 = (($t0Fallback1$t0Fallback2) + 4|0);
   $376 = Math_fround(HEAPF32[$375>>2]);
   HEAPF32[$108>>2] = $376;
   $377 = (($t0Fallback1$t0Fallback2) + 8|0);
   $378 = Math_fround(HEAPF32[$377>>2]);
   HEAPF32[$109>>2] = $378;
   __ZNK5physx16PxsSolverExtBody9getLinVelEv($3,$b0);
   __ZNK5physx16PxsSolverExtBody9getLinVelEv($4,$b1);
   $379 = Math_fround(HEAPF32[$3>>2]);
   $380 = Math_fround(HEAPF32[$4>>2]);
   $381 = Math_fround($379 - $380);
   $382 = Math_fround(HEAPF32[$110>>2]);
   $383 = Math_fround(HEAPF32[$111>>2]);
   $384 = Math_fround($382 - $383);
   $385 = Math_fround(HEAPF32[$112>>2]);
   $386 = Math_fround(HEAPF32[$113>>2]);
   $387 = Math_fround($385 - $386);
   $388 = Math_fround($339 * $381);
   $389 = Math_fround($341 * $384);
   $390 = Math_fround($388 + $389);
   $391 = Math_fround($343 * $387);
   $392 = Math_fround($390 + $391);
   $393 = Math_fround($339 * $392);
   $394 = Math_fround($341 * $392);
   $395 = Math_fround($343 * $392);
   $396 = Math_fround($381 - $393);
   $397 = Math_fround($384 - $394);
   $398 = Math_fround($387 - $395);
   HEAPF32[$t0_>>2] = $396;
   HEAPF32[$114>>2] = $397;
   HEAPF32[$115>>2] = $398;
   $399 = Math_fround($396 * $396);
   $400 = Math_fround($397 * $397);
   $401 = Math_fround($399 + $400);
   $402 = Math_fround($398 * $398);
   $403 = Math_fround($401 + $402);
   $404 = $403 > Math_fround(9.99999974737875163555E-6);
   $405 = $404 ? $t0_ : $tFallback1;
   $406 = Math_fround(HEAPF32[$405>>2]);
   $407 = Math_fround($406 * $406);
   $408 = (($405) + 4|0);
   $409 = Math_fround(HEAPF32[$408>>2]);
   $410 = Math_fround($409 * $409);
   $411 = Math_fround($407 + $410);
   $412 = (($405) + 8|0);
   $413 = Math_fround(HEAPF32[$412>>2]);
   $414 = Math_fround($413 * $413);
   $415 = Math_fround($411 + $414);
   $416 = $415 > Math_fround(0.0);
   if ($416) {
    $417 = (Math_fround(Math_sqrt((Math_fround($415)))));
    $418 = Math_fround(Math_fround(1.0) / $417);
    $419 = Math_fround($406 * $418);
    $420 = Math_fround($409 * $418);
    $421 = Math_fround($413 * $418);
    $423 = $420;$425 = $421;$429 = $419;
   } else {
    $423 = Math_fround(0.0);$425 = Math_fround(0.0);$429 = Math_fround(0.0);
   }
   $422 = Math_fround($343 * $423);
   $424 = Math_fround($341 * $425);
   $426 = Math_fround($422 - $424);
   $427 = Math_fround($339 * $425);
   $428 = Math_fround($343 * $429);
   $430 = Math_fround($427 - $428);
   $431 = Math_fround($341 * $429);
   $432 = Math_fround($339 * $423);
   $433 = Math_fround($431 - $432);
   HEAPF32[$tFallback>>2] = $429;
   HEAPF32[$116>>2] = $423;
   HEAPF32[$117>>2] = $425;
   HEAPF32[$118>>2] = $426;
   HEAPF32[$119>>2] = $430;
   HEAPF32[$120>>2] = $433;
   if ($354) {
    $434 = (($ptr$3183) + 4|0);
    HEAPF32[$434>>2] = $350;
    $435 = Math_fround(HEAPF32[$59>>2]);
    $436 = (($ptr$3183) + 8|0);
    HEAPF32[$436>>2] = $435;
    $437 = Math_fround(HEAPF32[$62>>2]);
    $438 = (($ptr$3183) + 12|0);
    HEAPF32[$438>>2] = $437;
    $439 = (($ptr$3183) + 16|0);
    HEAPF32[$439>>2] = $65;
    $440 = (($ptr$3183) + 20|0);
    HEAPF32[$440>>2] = $66;
    HEAP8[$ptr$3183>>0] = $441;
    $442 = HEAP32[$344>>2]|0;
    $443 = ($442|0)==(65535);
    if ($443) {
     $hasFriction$1$off0 = 1;$ptr$5 = $364;$ptr2$1 = $337;
    } else {
     $ind$0171 = 0;$patch7$0175 = $442;$ptr$4176 = $364;$totalPatchContactCount$0172 = 0;
     while(1) {
      $444 = ((($c) + (($patch7$0175*12)|0)|0) + 2|0);
      $445 = HEAP16[$444>>1]|0;
      $446 = (($c) + (($patch7$0175*12)|0)|0);
      $447 = HEAP16[$446>>1]|0;
      $448 = $447&65535;
      $449 = ($445<<16>>16)==(0);
      $brmerge = $449 | $127;
      if ($brmerge) {
       $548 = $445;$ind$1$lcssa = $ind$0171;$p10$0$lcssa = $ptr$4176;
      } else {
       $450 = $445&65535;
       $ind$1163$us = $ind$0171;$j11$0165$us = 0;$p10$0164$us = $ptr$4176;
       while(1) {
        $454 = (($j11$0165$us) + ($totalPatchContactCount$0172))|0;
        $$sum4$us = (($j11$0165$us) + ($448))|0;
        $535 = ((($buffer) + ($$sum4$us<<6)|0) + 16|0);
        $536 = Math_fround(HEAPF32[$535>>2]);
        $537 = Math_fround(HEAPF32[$121>>2]);
        $469 = Math_fround($536 - $537);
        $538 = ((($buffer) + ($$sum4$us<<6)|0) + 20|0);
        $539 = Math_fround(HEAPF32[$538>>2]);
        $540 = Math_fround(HEAPF32[$122>>2]);
        $463 = Math_fround($539 - $540);
        $541 = ((($buffer) + ($$sum4$us<<6)|0) + 24|0);
        $542 = Math_fround(HEAPF32[$541>>2]);
        $543 = Math_fround(HEAPF32[$123>>2]);
        $465 = Math_fround($542 - $543);
        $544 = Math_fround(HEAPF32[$124>>2]);
        $481 = Math_fround($536 - $544);
        $545 = Math_fround(HEAPF32[$125>>2]);
        $475 = Math_fround($539 - $545);
        $546 = Math_fround(HEAPF32[$126>>2]);
        $477 = Math_fround($542 - $546);
        $ind$2159$us = $ind$1163$us;$k$0161$us = 0;$p10$1160$us = $p10$0164$us;
        while(1) {
         $452 = (($p10$1160$us) + ($53)|0);
         $453 = (($p10$1160$us) + 80|0);
         HEAP32[$453>>2] = $454;
         $455 = (($tFallback) + (($ind$2159$us*12)|0)|0);
         $456 = Math_fround(HEAPF32[$455>>2]);
         $457 = ((($tFallback) + (($ind$2159$us*12)|0)|0) + 4|0);
         $458 = Math_fround(HEAPF32[$457>>2]);
         $459 = ((($tFallback) + (($ind$2159$us*12)|0)|0) + 8|0);
         $460 = Math_fround(HEAPF32[$459>>2]);
         $461 = (1 - ($ind$2159$us))|0;
         $462 = Math_fround($463 * $460);
         $464 = Math_fround($465 * $458);
         $466 = Math_fround($462 - $464);
         $467 = Math_fround($465 * $456);
         $468 = Math_fround($469 * $460);
         $470 = Math_fround($467 - $468);
         $471 = Math_fround($469 * $458);
         $472 = Math_fround($463 * $456);
         $473 = Math_fround($471 - $472);
         $474 = Math_fround($475 * $460);
         $476 = Math_fround($477 * $458);
         $478 = Math_fround($474 - $476);
         $479 = Math_fround($477 * $456);
         $480 = Math_fround($481 * $460);
         $482 = Math_fround($479 - $480);
         $483 = Math_fround($481 * $458);
         $484 = Math_fround($475 * $456);
         $485 = Math_fround($483 - $484);
         HEAPF32[$5>>2] = $456;
         HEAPF32[$128>>2] = $458;
         HEAPF32[$129>>2] = $460;
         HEAPF32[$130>>2] = Math_fround(0.0);
         HEAPF32[$131>>2] = $466;
         HEAPF32[$132>>2] = $470;
         HEAPF32[$133>>2] = $473;
         HEAPF32[$134>>2] = Math_fround(0.0);
         $486 = Math_fround(-$456);
         $487 = Math_fround(-$458);
         $488 = Math_fround(-$460);
         $489 = Math_fround(-$478);
         $490 = Math_fround(-$482);
         $491 = Math_fround(-$485);
         HEAPF32[$6>>2] = $486;
         HEAPF32[$135>>2] = $487;
         HEAPF32[$136>>2] = $488;
         HEAPF32[$137>>2] = Math_fround(0.0);
         HEAPF32[$138>>2] = $489;
         HEAPF32[$139>>2] = $490;
         HEAPF32[$140>>2] = $491;
         HEAPF32[$141>>2] = Math_fround(0.0);
         $492 = (Math_fround(__ZN5physx18getImpulseResponseERKNS_16PxsSolverExtBodyERKNS_2Cm13SpatialVectorERS4_ffS2_S6_S7_ffb($b0,$5,$deltaV017,$61,$65,$b1,$6,$deltaV118,$64,$66,0)));
         $493 = $492 > Math_fround(0.0);
         if ($493) {
          $494 = Math_fround(Math_fround(1.0) / $492);
          $496 = $494;
         } else {
          $496 = Math_fround(0.0);
         }
         $495 = (($p10$1160$us) + 28|0);
         HEAPF32[$495>>2] = $496;
         $497 = (($p10$1160$us) + 16|0);
         HEAPF32[$497>>2] = $466;
         $498 = (($p10$1160$us) + 20|0);
         HEAPF32[$498>>2] = $470;
         $499 = (($p10$1160$us) + 24|0);
         HEAPF32[$499>>2] = $473;
         $500 = (($p10$1160$us) + 32|0);
         HEAPF32[$500>>2] = $478;
         $501 = (($p10$1160$us) + 36|0);
         HEAPF32[$501>>2] = $482;
         $502 = (($p10$1160$us) + 40|0);
         HEAPF32[$502>>2] = $485;
         HEAPF32[$p10$1160$us>>2] = $456;
         $503 = (($p10$1160$us) + 4|0);
         HEAPF32[$503>>2] = $458;
         $504 = (($p10$1160$us) + 8|0);
         HEAPF32[$504>>2] = $460;
         $505 = (($p10$1160$us) + 12|0);
         HEAPF32[$505>>2] = Math_fround(0.0);
         $506 = Math_fround(HEAPF32[$142>>2]);
         $507 = Math_fround(HEAPF32[$143>>2]);
         $508 = Math_fround(HEAPF32[$144>>2]);
         $509 = Math_fround(HEAPF32[$deltaV017>>2]);
         $510 = (($p10$1160$us) + 96|0);
         HEAPF32[$510>>2] = $509;
         $511 = Math_fround(HEAPF32[$145>>2]);
         $512 = (($p10$1160$us) + 100|0);
         HEAPF32[$512>>2] = $511;
         $513 = Math_fround(HEAPF32[$146>>2]);
         $514 = (($p10$1160$us) + 104|0);
         HEAPF32[$514>>2] = $513;
         $515 = (($p10$1160$us) + 108|0);
         HEAPF32[$515>>2] = Math_fround(0.0);
         $516 = (($p10$1160$us) + 48|0);
         HEAPF32[$516>>2] = $506;
         $517 = (($p10$1160$us) + 52|0);
         HEAPF32[$517>>2] = $507;
         $518 = (($p10$1160$us) + 56|0);
         HEAPF32[$518>>2] = $508;
         $519 = (($p10$1160$us) + 60|0);
         HEAPF32[$519>>2] = Math_fround(0.0);
         $520 = Math_fround(HEAPF32[$147>>2]);
         $521 = Math_fround(HEAPF32[$148>>2]);
         $522 = Math_fround(HEAPF32[$149>>2]);
         $523 = Math_fround(HEAPF32[$deltaV118>>2]);
         $524 = (($p10$1160$us) + 112|0);
         HEAPF32[$524>>2] = $523;
         $525 = Math_fround(HEAPF32[$150>>2]);
         $526 = (($p10$1160$us) + 116|0);
         HEAPF32[$526>>2] = $525;
         $527 = Math_fround(HEAPF32[$151>>2]);
         $528 = (($p10$1160$us) + 120|0);
         HEAPF32[$528>>2] = $527;
         $529 = (($p10$1160$us) + 124|0);
         HEAPF32[$529>>2] = Math_fround(0.0);
         $530 = (($p10$1160$us) + 64|0);
         HEAPF32[$530>>2] = $520;
         $531 = (($p10$1160$us) + 68|0);
         HEAPF32[$531>>2] = $521;
         $532 = (($p10$1160$us) + 72|0);
         HEAPF32[$532>>2] = $522;
         $533 = (($p10$1160$us) + 76|0);
         HEAPF32[$533>>2] = Math_fround(0.0);
         $534 = (($k$0161$us) + 1)|0;
         $exitcond = ($534|0)==($frictionCountPerPoint|0);
         if ($exitcond) {
          break;
         } else {
          $ind$2159$us = $461;$k$0161$us = $534;$p10$1160$us = $452;
         }
        }
        $scevgep = (($p10$0164$us) + ($152)|0);
        $451 = (($j11$0165$us) + 1)|0;
        $exitcond204 = ($451|0)==($450|0);
        if ($exitcond204) {
         break;
        } else {
         $ind$1163$us = $461;$j11$0165$us = $451;$p10$0164$us = $scevgep;
        }
       }
       $$pre$pre = HEAP16[$444>>1]|0;
       $548 = $$pre$pre;$ind$1$lcssa = $461;$p10$0$lcssa = $scevgep;
      }
      $547 = $548&65535;
      $549 = (($547) + ($totalPatchContactCount$0172))|0;
      $550 = ((($c) + (($patch7$0175*12)|0)|0) + 4|0);
      $551 = HEAP16[$550>>1]|0;
      $552 = $551&65535;
      $553 = ($551<<16>>16)==(-1);
      if ($553) {
       $hasFriction$1$off0 = 1;$ptr$5 = $p10$0$lcssa;$ptr2$1 = $337;
       break;
      } else {
       $ind$0171 = $ind$1$lcssa;$patch7$0175 = $552;$ptr$4176 = $p10$0$lcssa;$totalPatchContactCount$0172 = $549;
      }
     }
    }
   } else {
    $hasFriction$1$off0 = $hasFriction$0$off0181;$ptr$5 = $364;$ptr2$1 = $337;
   }
  }
  $554 = (($i1$0180) + 1)|0;
  $exitcond205 = ($554|0)==($50|0);
  if ($exitcond205) {
   $hasFriction$0$off0$lcssa = $hasFriction$1$off0;
   break;
  } else {
   $hasFriction$0$off0181 = $hasFriction$1$off0;$i1$0180 = $554;$ptr$3183 = $ptr$5;$ptr2$0182 = $ptr2$1;
  }
 }
 STACKTOP = sp;return ($hasFriction$0$off0$lcssa|0);
}
function __ZN5physx30setupFinalizeSolverConstraintsERNS_13PxcNpWorkUnitERKNS_2Gu13ContactBufferERKNS_20PxcCorrelationBufferERKNS_11PxTransformESB_bPhRKNS_13PxcSolverBodyESF_RKNS_17PxcSolverBodyDataESI_ffffff($n,$buffer,$c,$bodyFrame0,$bodyFrame1,$0,$workspace,$b0,$b1,$data0,$data1,$invDtF32,$bounceThresholdF32,$invMassScale0,$invInertiaScale0,$invMassScale1,$invInertiaScale1) {
 $n = $n|0;
 $buffer = $buffer|0;
 $c = $c|0;
 $bodyFrame0 = $bodyFrame0|0;
 $bodyFrame1 = $bodyFrame1|0;
 $0 = $0|0;
 $workspace = $workspace|0;
 $b0 = $b0|0;
 $b1 = $b1|0;
 $data0 = $data0|0;
 $data1 = $data1|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $invMassScale0 = Math_fround($invMassScale0);
 $invInertiaScale0 = Math_fround($invInertiaScale0);
 $invMassScale1 = Math_fround($invMassScale1);
 $invInertiaScale1 = Math_fround($invInertiaScale1);
 var $$$i = Math_fround(0), $$$i$us$us = Math_fround(0), $$$i546 = Math_fround(0), $$$us$us = 0, $$in1$i = 0, $$in1$i238 = 0, $$in2$i = 0, $$in2$i240 = 0, $$mux = 0, $$phi$trans$insert = 0, $$phi$trans$insert2427 = 0, $$pre = 0, $$pre2426 = 0, $$pre2428 = 0, $$sum = 0, $$sum1 = 0, $$sum23 = 0, $$sum23672368 = 0, $$sum23692370 = 0, $$sum23712372 = 0;
 var $$sum23732374 = 0, $$sum23752376 = 0, $$sum23772378 = 0, $$sum2379 = 0, $$sum2380 = 0, $$sum2381 = 0, $$sum2382 = 0, $$sum2383 = 0, $$sum2384 = 0, $$sum2385 = 0, $$sum2386 = 0, $$sum2387 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum7$us$us = 0, $$tr = 0, $1 = 0, $10 = 0;
 var $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0;
 var $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0);
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0;
 var $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0);
 var $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0;
 var $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0);
 var $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0);
 var $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0);
 var $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0);
 var $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0);
 var $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0;
 var $371 = 0, $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0);
 var $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0);
 var $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0);
 var $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0);
 var $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0);
 var $461 = Math_fround(0), $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = Math_fround(0), $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = Math_fround(0), $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0;
 var $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = 0, $502 = Math_fround(0), $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = Math_fround(0);
 var $533 = Math_fround(0), $534 = 0, $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0);
 var $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = 0, $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0);
 var $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = Math_fround(0), $589 = 0, $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = Math_fround(0), $593 = 0, $594 = Math_fround(0), $595 = 0, $596 = Math_fround(0), $597 = 0, $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0);
 var $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0);
 var $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0);
 var $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0);
 var $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0);
 var $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0);
 var $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0);
 var $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0);
 var $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = 0, $737 = Math_fround(0), $738 = 0, $739 = 0, $74 = Math_fround(0), $740 = 0, $741 = 0, $742 = 0, $743 = Math_fround(0), $744 = 0, $745 = Math_fround(0), $746 = 0, $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0);
 var $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = Math_fround(0), $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = 0, $767 = 0;
 var $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = 0, $778 = 0, $779 = 0, $78 = Math_fround(0), $780 = 0, $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0);
 var $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0);
 var $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0);
 var $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0);
 var $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = 0, $844 = Math_fround(0), $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = Math_fround(0), $850 = Math_fround(0), $851 = 0, $852 = Math_fround(0), $853 = 0, $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0);
 var $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = 0, $875 = 0;
 var $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = Math_fround(0), $890 = 0, $891 = 0, $892 = 0, $893 = 0;
 var $894 = 0, $895 = 0, $896 = 0, $897 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $b$a$i209 = 0, $b$a$i235 = 0, $exitcond = 0, $exitcond2423 = 0, $fabsf$i$i$i = Math_fround(0);
 var $frictionPatchWritebackAddrIndex$02416 = 0, $frictionPatchWritebackAddrIndex$1 = 0, $i$02411 = 0, $j$02388 = 0, $j$02388$us$us = 0, $j4$02405 = 0, $p$0$lcssa = 0, $p$0$lcssa$us = 0, $p$02389 = 0, $p$02389$us$us = 0, $patch$02390 = 0, $patch$02390$us = 0, $ptr$02417 = 0, $ptr$1$lcssa = 0, $ptr$12391 = 0, $ptr$12391$us = 0, $ptr$22406 = 0, $ptr$3 = 0, $ptr$4 = 0, $scevgep = 0;
 var $scevgep2422 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $1 = sp + 48|0;
 $2 = sp;
 $3 = sp + 16|0;
 $4 = sp + 32|0;
 $5 = (($buffer) + 4096|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($n) + 22|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = ($9&65535) >>> 8;
 $$tr = $10&255;
 $11 = $$tr & 1;
 $12 = (($n) + 84|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($n) + 88|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 * $invMassScale0);
 $17 = Math_fround($15 * $invMassScale1);
 $18 = Math_fround($13 * $invInertiaScale0);
 $19 = Math_fround($15 * $invInertiaScale1);
 $20 = (($n) + 92|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($data0) + 52|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($data1) + 52|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = $23 > $25;
 $$$i546 = $26 ? $23 : $25;
 $27 = Math_fround(HEAPF32[$bodyFrame0>>2]);
 $28 = (($bodyFrame0) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($bodyFrame0) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($bodyFrame0) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($bodyFrame0) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($bodyFrame0) + 20|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($bodyFrame0) + 24|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround(HEAPF32[$bodyFrame1>>2]);
 $41 = (($bodyFrame1) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($bodyFrame1) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($bodyFrame1) + 12|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($bodyFrame1) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($bodyFrame1) + 20|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($bodyFrame1) + 24|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($c) + 4100|0);
 $54 = (($c) + 4228|0);
 $55 = Math_fround(HEAPF32[$b0>>2]);
 $56 = (($b0) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($b0) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround(HEAPF32[$b1>>2]);
 $61 = (($b1) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($b1) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($b0) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($b0) + 20|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($b0) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($b1) + 16|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($b1) + 20|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($b1) + 24|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($data0) + 48|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($data1) + 48|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround(HEAPF32[$data0>>2]);
 $82 = (($data0) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($data0) + 8|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($data0) + 12|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($data0) + 16|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($data0) + 20|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($data0) + 24|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($data0) + 28|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($data0) + 32|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround(HEAPF32[$data1>>2]);
 $99 = (($data1) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($data1) + 8|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($data1) + 12|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($data1) + 16|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($data1) + 20|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($data1) + 24|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($data1) + 28|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($data1) + 32|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($invDtF32 * Math_fround(0.800000011920928955078));
 $116 = HEAP16[$8>>1]|0;
 $117 = $116 & 24;
 $118 = ($117<<16>>16)!=(0);
 $119 = Math_fround($16 * $78);
 $120 = Math_fround($17 * $80);
 $121 = Math_fround(-$120);
 $122 = Math_fround($18 * $81);
 $123 = Math_fround($18 * $83);
 $124 = Math_fround($18 * $85);
 $125 = Math_fround($18 * $87);
 $126 = Math_fround($18 * $89);
 $127 = Math_fround($18 * $91);
 $128 = Math_fround($18 * $93);
 $129 = Math_fround($18 * $95);
 $130 = Math_fround($18 * $97);
 $131 = Math_fround($19 * $98);
 $132 = Math_fround($19 * $100);
 $133 = Math_fround($19 * $102);
 $134 = Math_fround($19 * $104);
 $135 = Math_fround($19 * $106);
 $136 = Math_fround($19 * $108);
 $137 = Math_fround($19 * $110);
 $138 = Math_fround($19 * $112);
 $139 = Math_fround($19 * $114);
 $140 = (($c) + 4232|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = ($141|0)==(0);
 if ($142) {
  STACKTOP = sp;return;
 }
 $143 = $118 ? 128 : 96;
 $$mux = $118 ? 3 : 6;
 $144 = Math_fround($55 - $60);
 $145 = Math_fround($57 - $62);
 $146 = Math_fround($59 - $64);
 $147 = (($2) + 4|0);
 $148 = (($2) + 8|0);
 $149 = (($2) + 12|0);
 $150 = (($1) + 4|0);
 $151 = (($1) + 8|0);
 $152 = (($1) + 12|0);
 $153 = (($4) + 4|0);
 $154 = (($4) + 8|0);
 $155 = (($4) + 12|0);
 $156 = (($3) + 4|0);
 $157 = (($3) + 8|0);
 $158 = (($3) + 12|0);
 $159 = (($n) + 40|0);
 $$sum = $143 << 1;
 $$sum1 = (($143) + 80)|0;
 $160 = Math_fround($33 * $33);
 $161 = Math_fround($160 + Math_fround(-0.5));
 $162 = Math_fround($46 * $46);
 $163 = Math_fround($162 + Math_fround(-0.5));
 $$sum23672368 = $143 | 4;
 $$sum23692370 = $143 | 8;
 $$sum23712372 = $143 | 12;
 $$sum23 = $143 | 16;
 $$sum23732374 = $143 | 20;
 $$sum23752376 = $143 | 24;
 $$sum23772378 = $143 | 28;
 $$sum4 = (($143) + 32)|0;
 $$sum2379 = (($143) + 36)|0;
 $$sum2380 = (($143) + 40)|0;
 $$sum2381 = (($143) + 44)|0;
 $$sum5 = (($143) + 48)|0;
 $$sum2382 = (($143) + 52)|0;
 $$sum2383 = (($143) + 56)|0;
 $$sum2384 = (($143) + 60)|0;
 $$sum6 = (($143) + 64)|0;
 $$sum2385 = (($143) + 68)|0;
 $$sum2386 = (($143) + 72)|0;
 $$sum2387 = (($143) + 76)|0;
 $896 = $141;$frictionPatchWritebackAddrIndex$02416 = 0;$i$02411 = 0;$ptr$02417 = $workspace;
 while(1) {
  $164 = ((($c) + ($i$02411<<2)|0) + 3840|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = ($165|0)==(0);
  if ($166) {
   $895 = $896;$frictionPatchWritebackAddrIndex$1 = $frictionPatchWritebackAddrIndex$02416;$ptr$4 = $ptr$02417;
  } else {
   $167 = ((($c) + ($i$02411<<2)|0) + 3968|0);
   $168 = HEAP32[$167>>2]|0;
   $169 = (($c) + (($168*12)|0)|0);
   $170 = HEAP16[$169>>1]|0;
   $171 = $170&65535;
   $172 = ((($buffer) + ($171<<6)|0) + 60|0);
   $173 = Math_fround(HEAPF32[$172>>2]);
   $174 = (($ptr$02417) + 32|0);
   $175 = (($ptr$02417) + 160|0);
   $176 = (($ptr$02417) + 288|0);
   $177 = (($ptr$02417) + 4|0);
   HEAP8[$177>>0] = $11;
   $178 = HEAP32[$167>>2]|0;
   $179 = (($c) + (($178*12)|0)|0);
   $180 = HEAP16[$179>>1]|0;
   $181 = $180&65535;
   $182 = (($buffer) + ($181<<6)|0);
   $183 = Math_fround(HEAPF32[$182>>2]);
   $184 = ((($buffer) + ($181<<6)|0) + 4|0);
   $185 = Math_fround(HEAPF32[$184>>2]);
   $186 = ((($buffer) + ($181<<6)|0) + 8|0);
   $187 = Math_fround(HEAPF32[$186>>2]);
   $188 = Math_fround($183 * $183);
   $189 = Math_fround($185 * $185);
   $190 = Math_fround($188 + $189);
   $191 = Math_fround($187 * $187);
   $192 = Math_fround($190 + $191);
   $193 = Math_fround($55 * $183);
   $194 = Math_fround($57 * $185);
   $195 = Math_fround($193 + $194);
   $196 = Math_fround($59 * $187);
   $197 = Math_fround($195 + $196);
   $198 = Math_fround($60 * $183);
   $199 = Math_fround($62 * $185);
   $200 = Math_fround($198 + $199);
   $201 = Math_fround($64 * $187);
   $202 = Math_fround($200 + $201);
   $203 = Math_fround($119 * $192);
   $204 = Math_fround($192 * $121);
   $205 = ($178|0)==(65535);
   L11: do {
    if ($205) {
     $ptr$1$lcssa = $174;
    } else {
     $206 = $173 > Math_fround(0.0);
     if ($206) {
      $210 = $180;$patch$02390$us = $178;$ptr$12391$us = $174;
      while(1) {
       $207 = ((($c) + (($patch$02390$us*12)|0)|0) + 2|0);
       $208 = HEAP16[$207>>1]|0;
       $209 = $210&65535;
       $211 = ($208<<16>>16)==(0);
       if ($211) {
        $p$0$lcssa$us = $ptr$12391$us;
       } else {
        $361 = $208&65535;
        $362 = Math_imul($143, $361)|0;
        $j$02388$us$us = 0;$p$02389$us$us = $ptr$12391$us;
        while(1) {
         $216 = (($p$02389$us$us) + 256|0);
         $$sum7$us$us = (($j$02388$us$us) + ($209))|0;
         $217 = (($p$02389$us$us) + ($143)|0);
         $218 = ((($buffer) + ($$sum7$us$us<<6)|0) + 16|0);
         $219 = Math_fround(HEAPF32[$218>>2]);
         $220 = ((($buffer) + ($$sum7$us$us<<6)|0) + 20|0);
         $221 = Math_fround(HEAPF32[$220>>2]);
         $222 = ((($buffer) + ($$sum7$us$us<<6)|0) + 24|0);
         $223 = Math_fround(HEAPF32[$222>>2]);
         $224 = ((($buffer) + ($$sum7$us$us<<6)|0) + 12|0);
         $225 = Math_fround(HEAPF32[$224>>2]);
         $226 = ((($buffer) + ($$sum7$us$us<<6)|0) + 32|0);
         $227 = Math_fround(HEAPF32[$226>>2]);
         $228 = ((($buffer) + ($$sum7$us$us<<6)|0) + 36|0);
         $229 = Math_fround(HEAPF32[$228>>2]);
         $230 = ((($buffer) + ($$sum7$us$us<<6)|0) + 40|0);
         $231 = Math_fround(HEAPF32[$230>>2]);
         $232 = Math_fround($183 * $227);
         $233 = Math_fround($185 * $229);
         $234 = Math_fround($232 + $233);
         $235 = Math_fround($187 * $231);
         $236 = Math_fround($234 + $235);
         $237 = Math_fround($219 - $35);
         $238 = Math_fround($221 - $37);
         $239 = Math_fround($223 - $39);
         $240 = Math_fround($219 - $48);
         $241 = Math_fround($221 - $50);
         $242 = Math_fround($223 - $52);
         $243 = Math_fround($187 * $238);
         $244 = Math_fround($185 * $239);
         $245 = Math_fround($243 - $244);
         $246 = Math_fround($183 * $239);
         $247 = Math_fround($187 * $237);
         $248 = Math_fround($246 - $247);
         $249 = Math_fround($185 * $237);
         $250 = Math_fround($183 * $238);
         $251 = Math_fround($249 - $250);
         $252 = Math_fround($187 * $241);
         $253 = Math_fround($185 * $242);
         $254 = Math_fround($252 - $253);
         $255 = Math_fround($183 * $242);
         $256 = Math_fround($187 * $240);
         $257 = Math_fround($255 - $256);
         $258 = Math_fround($185 * $240);
         $259 = Math_fround($183 * $241);
         $260 = Math_fround($258 - $259);
         $261 = Math_fround($122 * $245);
         $262 = Math_fround($123 * $245);
         $263 = Math_fround($124 * $245);
         $264 = Math_fround($125 * $248);
         $265 = Math_fround($126 * $248);
         $266 = Math_fround($127 * $248);
         $267 = Math_fround($264 + $261);
         $268 = Math_fround($265 + $262);
         $269 = Math_fround($266 + $263);
         $270 = Math_fround($128 * $251);
         $271 = Math_fround($129 * $251);
         $272 = Math_fround($130 * $251);
         $273 = Math_fround($270 + $267);
         $274 = Math_fround($271 + $268);
         $275 = Math_fround($272 + $269);
         $276 = Math_fround($131 * $254);
         $277 = Math_fround($132 * $254);
         $278 = Math_fround($133 * $254);
         $279 = Math_fround($134 * $257);
         $280 = Math_fround($135 * $257);
         $281 = Math_fround($136 * $257);
         $282 = Math_fround($279 + $276);
         $283 = Math_fround($280 + $277);
         $284 = Math_fround($281 + $278);
         $285 = Math_fround($137 * $260);
         $286 = Math_fround($138 * $260);
         $287 = Math_fround($139 * $260);
         $288 = Math_fround($285 + $282);
         $289 = Math_fround($286 + $283);
         $290 = Math_fround($287 + $284);
         $291 = Math_fround($245 * $273);
         $292 = Math_fround($248 * $274);
         $293 = Math_fround($291 + $292);
         $294 = Math_fround($251 * $275);
         $295 = Math_fround($294 + $293);
         $296 = Math_fround($203 + $295);
         $297 = Math_fround($254 * $288);
         $298 = Math_fround($257 * $289);
         $299 = Math_fround($297 + $298);
         $300 = Math_fround($260 * $290);
         $301 = Math_fround($300 + $299);
         $302 = Math_fround($301 - $204);
         $303 = Math_fround($296 + $302);
         $304 = Math_fround($66 * $245);
         $305 = Math_fround($68 * $248);
         $306 = Math_fround($304 + $305);
         $307 = Math_fround($70 * $251);
         $308 = Math_fround($307 + $306);
         $309 = Math_fround($197 + $308);
         $310 = Math_fround($72 * $254);
         $311 = Math_fround($74 * $257);
         $312 = Math_fround($310 + $311);
         $313 = Math_fround($76 * $260);
         $314 = Math_fround($313 + $312);
         $315 = Math_fround($202 + $314);
         $316 = Math_fround($309 - $315);
         $317 = Math_fround(Math_fround(1.0) / $303);
         $318 = !($303 > Math_fround(0.0));
         $319 = $318 ? Math_fround(0.0) : $317;
         $320 = Math_fround($225 - $21);
         $321 = Math_fround($320 * $invDtF32);
         $322 = Math_fround($115 * $320);
         $323 = $$$i546 > $322;
         $$$i$us$us = $323 ? $$$i546 : $322;
         $324 = Math_fround($$$i$us$us * $319);
         $325 = $316 < $bounceThresholdF32;
         $326 = Math_fround(-$316);
         $327 = $321 < $326;
         $$$us$us = $327 & $325;
         $328 = $$$us$us ? Math_fround(0.0) : $324;
         $329 = Math_fround($173 * $326);
         $330 = $$$us$us ? $329 : Math_fround(0.0);
         $331 = Math_fround($236 + $330);
         HEAPF32[$p$02389$us$us>>2] = $183;
         $332 = (($p$02389$us$us) + 4|0);
         HEAPF32[$332>>2] = $185;
         $333 = (($p$02389$us$us) + 8|0);
         HEAPF32[$333>>2] = $187;
         $334 = (($p$02389$us$us) + 12|0);
         HEAPF32[$334>>2] = $319;
         $335 = (($p$02389$us$us) + 64|0);
         HEAPF32[$335>>2] = $273;
         $336 = (($p$02389$us$us) + 68|0);
         HEAPF32[$336>>2] = $274;
         $337 = (($p$02389$us$us) + 72|0);
         HEAPF32[$337>>2] = $275;
         $338 = (($p$02389$us$us) + 76|0);
         HEAPF32[$338>>2] = $119;
         $339 = Math_fround(-$288);
         $340 = Math_fround(-$289);
         $341 = Math_fround(-$290);
         $342 = (($p$02389$us$us) + 80|0);
         HEAPF32[$342>>2] = $339;
         $343 = (($p$02389$us$us) + 84|0);
         HEAPF32[$343>>2] = $340;
         $344 = (($p$02389$us$us) + 88|0);
         HEAPF32[$344>>2] = $341;
         $345 = (($p$02389$us$us) + 92|0);
         HEAPF32[$345>>2] = $121;
         $346 = (($p$02389$us$us) + 16|0);
         HEAPF32[$346>>2] = $245;
         $347 = (($p$02389$us$us) + 20|0);
         HEAPF32[$347>>2] = $248;
         $348 = (($p$02389$us$us) + 24|0);
         HEAPF32[$348>>2] = $251;
         $349 = (($p$02389$us$us) + 28|0);
         HEAPF32[$349>>2] = Math_fround(0.0);
         $350 = (($p$02389$us$us) + 32|0);
         HEAPF32[$350>>2] = $254;
         $351 = (($p$02389$us$us) + 36|0);
         HEAPF32[$351>>2] = $257;
         $352 = (($p$02389$us$us) + 40|0);
         HEAPF32[$352>>2] = $260;
         $353 = (($p$02389$us$us) + 44|0);
         HEAPF32[$353>>2] = Math_fround(0.0);
         $354 = ((($buffer) + ($$sum7$us$us<<6)|0) + 28|0);
         $355 = Math_fround(HEAPF32[$354>>2]);
         $356 = (($p$02389$us$us) + 48|0);
         HEAPF32[$356>>2] = $328;
         $357 = (($p$02389$us$us) + 52|0);
         HEAPF32[$357>>2] = $331;
         $358 = (($p$02389$us$us) + 56|0);
         HEAPF32[$358>>2] = $355;
         $359 = (($p$02389$us$us) + 60|0);
         HEAPF32[$359>>2] = Math_fround(0.0);
         $360 = (($j$02388$us$us) + 1)|0;
         $exitcond2423 = ($360|0)==($361|0);
         if ($exitcond2423) {
          break;
         } else {
          $j$02388$us$us = $360;$p$02389$us$us = $217;
         }
        }
        $scevgep2422 = (($ptr$12391$us) + ($362)|0);
        $p$0$lcssa$us = $scevgep2422;
       }
       $212 = ((($c) + (($patch$02390$us*12)|0)|0) + 4|0);
       $213 = HEAP16[$212>>1]|0;
       $214 = $213&65535;
       $215 = ($213<<16>>16)==(-1);
       if ($215) {
        $ptr$1$lcssa = $p$0$lcssa$us;
        break L11;
       }
       $$phi$trans$insert = (($c) + (($214*12)|0)|0);
       $$pre2426 = HEAP16[$$phi$trans$insert>>1]|0;
       $210 = $$pre2426;$patch$02390$us = $214;$ptr$12391$us = $p$0$lcssa$us;
      }
     } else {
      $366 = $180;$patch$02390 = $178;$ptr$12391 = $174;
      while(1) {
       $363 = ((($c) + (($patch$02390*12)|0)|0) + 2|0);
       $364 = HEAP16[$363>>1]|0;
       $365 = $366&65535;
       $367 = ($364<<16>>16)==(0);
       if ($367) {
        $p$0$lcssa = $ptr$12391;
       } else {
        $368 = $364&65535;
        $369 = Math_imul($143, $368)|0;
        $j$02388 = 0;$p$02389 = $ptr$12391;
        while(1) {
         $370 = (($p$02389) + 256|0);
         $$sum7 = (($j$02388) + ($365))|0;
         $371 = (($p$02389) + ($143)|0);
         $372 = ((($buffer) + ($$sum7<<6)|0) + 16|0);
         $373 = Math_fround(HEAPF32[$372>>2]);
         $374 = ((($buffer) + ($$sum7<<6)|0) + 20|0);
         $375 = Math_fround(HEAPF32[$374>>2]);
         $376 = ((($buffer) + ($$sum7<<6)|0) + 24|0);
         $377 = Math_fround(HEAPF32[$376>>2]);
         $378 = ((($buffer) + ($$sum7<<6)|0) + 12|0);
         $379 = Math_fround(HEAPF32[$378>>2]);
         $380 = ((($buffer) + ($$sum7<<6)|0) + 32|0);
         $381 = Math_fround(HEAPF32[$380>>2]);
         $382 = ((($buffer) + ($$sum7<<6)|0) + 36|0);
         $383 = Math_fround(HEAPF32[$382>>2]);
         $384 = ((($buffer) + ($$sum7<<6)|0) + 40|0);
         $385 = Math_fround(HEAPF32[$384>>2]);
         $386 = Math_fround($183 * $381);
         $387 = Math_fround($185 * $383);
         $388 = Math_fround($386 + $387);
         $389 = Math_fround($187 * $385);
         $390 = Math_fround($388 + $389);
         $391 = Math_fround($373 - $35);
         $392 = Math_fround($375 - $37);
         $393 = Math_fround($377 - $39);
         $394 = Math_fround($373 - $48);
         $395 = Math_fround($375 - $50);
         $396 = Math_fround($377 - $52);
         $397 = Math_fround($187 * $392);
         $398 = Math_fround($185 * $393);
         $399 = Math_fround($397 - $398);
         $400 = Math_fround($183 * $393);
         $401 = Math_fround($187 * $391);
         $402 = Math_fround($400 - $401);
         $403 = Math_fround($185 * $391);
         $404 = Math_fround($183 * $392);
         $405 = Math_fround($403 - $404);
         $406 = Math_fround($187 * $395);
         $407 = Math_fround($185 * $396);
         $408 = Math_fround($406 - $407);
         $409 = Math_fround($183 * $396);
         $410 = Math_fround($187 * $394);
         $411 = Math_fround($409 - $410);
         $412 = Math_fround($185 * $394);
         $413 = Math_fround($183 * $395);
         $414 = Math_fround($412 - $413);
         $415 = Math_fround($122 * $399);
         $416 = Math_fround($123 * $399);
         $417 = Math_fround($124 * $399);
         $418 = Math_fround($125 * $402);
         $419 = Math_fround($126 * $402);
         $420 = Math_fround($127 * $402);
         $421 = Math_fround($418 + $415);
         $422 = Math_fround($419 + $416);
         $423 = Math_fround($420 + $417);
         $424 = Math_fround($128 * $405);
         $425 = Math_fround($129 * $405);
         $426 = Math_fround($130 * $405);
         $427 = Math_fround($424 + $421);
         $428 = Math_fround($425 + $422);
         $429 = Math_fround($426 + $423);
         $430 = Math_fround($131 * $408);
         $431 = Math_fround($132 * $408);
         $432 = Math_fround($133 * $408);
         $433 = Math_fround($134 * $411);
         $434 = Math_fround($135 * $411);
         $435 = Math_fround($136 * $411);
         $436 = Math_fround($433 + $430);
         $437 = Math_fround($434 + $431);
         $438 = Math_fround($435 + $432);
         $439 = Math_fround($137 * $414);
         $440 = Math_fround($138 * $414);
         $441 = Math_fround($139 * $414);
         $442 = Math_fround($439 + $436);
         $443 = Math_fround($440 + $437);
         $444 = Math_fround($441 + $438);
         $445 = Math_fround($399 * $427);
         $446 = Math_fround($402 * $428);
         $447 = Math_fround($445 + $446);
         $448 = Math_fround($405 * $429);
         $449 = Math_fround($448 + $447);
         $450 = Math_fround($203 + $449);
         $451 = Math_fround($408 * $442);
         $452 = Math_fround($411 * $443);
         $453 = Math_fround($451 + $452);
         $454 = Math_fround($414 * $444);
         $455 = Math_fround($454 + $453);
         $456 = Math_fround($455 - $204);
         $457 = Math_fround($450 + $456);
         $458 = Math_fround(Math_fround(1.0) / $457);
         $459 = !($457 > Math_fround(0.0));
         $460 = $459 ? Math_fround(0.0) : $458;
         $461 = Math_fround($379 - $21);
         $462 = Math_fround($115 * $461);
         $463 = $$$i546 > $462;
         $$$i = $463 ? $$$i546 : $462;
         $464 = Math_fround($$$i * $460);
         $465 = Math_fround($390 + Math_fround(0.0));
         HEAPF32[$p$02389>>2] = $183;
         $466 = (($p$02389) + 4|0);
         HEAPF32[$466>>2] = $185;
         $467 = (($p$02389) + 8|0);
         HEAPF32[$467>>2] = $187;
         $468 = (($p$02389) + 12|0);
         HEAPF32[$468>>2] = $460;
         $469 = (($p$02389) + 64|0);
         HEAPF32[$469>>2] = $427;
         $470 = (($p$02389) + 68|0);
         HEAPF32[$470>>2] = $428;
         $471 = (($p$02389) + 72|0);
         HEAPF32[$471>>2] = $429;
         $472 = (($p$02389) + 76|0);
         HEAPF32[$472>>2] = $119;
         $473 = Math_fround(-$442);
         $474 = Math_fround(-$443);
         $475 = Math_fround(-$444);
         $476 = (($p$02389) + 80|0);
         HEAPF32[$476>>2] = $473;
         $477 = (($p$02389) + 84|0);
         HEAPF32[$477>>2] = $474;
         $478 = (($p$02389) + 88|0);
         HEAPF32[$478>>2] = $475;
         $479 = (($p$02389) + 92|0);
         HEAPF32[$479>>2] = $121;
         $480 = (($p$02389) + 16|0);
         HEAPF32[$480>>2] = $399;
         $481 = (($p$02389) + 20|0);
         HEAPF32[$481>>2] = $402;
         $482 = (($p$02389) + 24|0);
         HEAPF32[$482>>2] = $405;
         $483 = (($p$02389) + 28|0);
         HEAPF32[$483>>2] = Math_fround(0.0);
         $484 = (($p$02389) + 32|0);
         HEAPF32[$484>>2] = $408;
         $485 = (($p$02389) + 36|0);
         HEAPF32[$485>>2] = $411;
         $486 = (($p$02389) + 40|0);
         HEAPF32[$486>>2] = $414;
         $487 = (($p$02389) + 44|0);
         HEAPF32[$487>>2] = Math_fround(0.0);
         $488 = ((($buffer) + ($$sum7<<6)|0) + 28|0);
         $489 = Math_fround(HEAPF32[$488>>2]);
         $490 = (($p$02389) + 48|0);
         HEAPF32[$490>>2] = $464;
         $491 = (($p$02389) + 52|0);
         HEAPF32[$491>>2] = $465;
         $492 = (($p$02389) + 56|0);
         HEAPF32[$492>>2] = $489;
         $493 = (($p$02389) + 60|0);
         HEAPF32[$493>>2] = Math_fround(0.0);
         $494 = (($j$02388) + 1)|0;
         $exitcond = ($494|0)==($368|0);
         if ($exitcond) {
          break;
         } else {
          $j$02388 = $494;$p$02389 = $371;
         }
        }
        $scevgep = (($ptr$12391) + ($369)|0);
        $p$0$lcssa = $scevgep;
       }
       $495 = ((($c) + (($patch$02390*12)|0)|0) + 4|0);
       $496 = HEAP16[$495>>1]|0;
       $497 = $496&65535;
       $498 = ($496<<16>>16)==(-1);
       if ($498) {
        $ptr$1$lcssa = $p$0$lcssa;
        break L11;
       }
       $$phi$trans$insert2427 = (($c) + (($497*12)|0)|0);
       $$pre2428 = HEAP16[$$phi$trans$insert2427>>1]|0;
       $366 = $$pre2428;$patch$02390 = $497;$ptr$12391 = $p$0$lcssa;
      }
     }
    }
   } while(0);
   $499 = ((($buffer) + ($171<<6)|0) + 44|0);
   $500 = Math_fround(HEAPF32[$499>>2]);
   $501 = ((($buffer) + ($171<<6)|0) + 56|0);
   $502 = Math_fround(HEAPF32[$501>>2]);
   $503 = ((($buffer) + ($171<<6)|0) + 52|0);
   $504 = HEAP32[$503>>2]|0;
   $505 = $504 & 1;
   $506 = ($505|0)==(0);
   if ($506) {
    $509 = ((($c) + (($i$02411*96)|0)|0) + 784|0);
    $510 = HEAP16[$509>>1]|0;
    $511 = ($510<<16>>16)==(0);
    $512 = $165&255;
    $513 = (($ptr$02417) + 5|0);
    HEAP8[$513>>0] = $512;
    if ($511) {
     label = 22;
    } else {
     $515 = HEAP16[$509>>1]|0;
     $516 = $515&65535;
     $517 = $516 << 1;
     $518 = $517&255;
     $519 = (($ptr$02417) + 6|0);
     HEAP8[$519>>0] = $518;
     if ($118) {
      $525 = $$mux;$897 = 1;
     } else {
      $520 = HEAP16[$8>>1]|0;
      $521 = $520 & 64;
      $522 = ($521<<16>>16)==(0);
      $523 = $522 ? 5 : 1;
      $525 = $523;$897 = 1;
     }
    }
   } else {
    $507 = $165&255;
    $508 = (($ptr$02417) + 5|0);
    HEAP8[$508>>0] = $507;
    label = 22;
   }
   if ((label|0) == 22) {
    label = 0;
    $514 = (($ptr$02417) + 6|0);
    HEAP8[$514>>0] = 0;
    $525 = $$mux;$897 = 0;
   }
   $524 = $525&255;
   HEAP8[$ptr$02417>>0] = $524;
   $526 = (($ptr$02417) + 16|0);
   HEAPF32[$526>>2] = $500;
   $527 = (($ptr$02417) + 20|0);
   HEAPF32[$527>>2] = $502;
   $528 = (($ptr$02417) + 24|0);
   HEAPF32[$528>>2] = $13;
   $529 = (($ptr$02417) + 28|0);
   HEAPF32[$529>>2] = $15;
   $530 = (($ptr$02417) + 8|0);
   HEAPF32[$530>>2] = $18;
   $531 = (($ptr$02417) + 12|0);
   HEAPF32[$531>>2] = $19;
   if ($897) {
    $532 = Math_fround(-$187);
    $533 = Math_fround(-$185);
    $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($183)))));
    $534 = $fabsf$i$i$i < Math_fround(0.707106769084930419921);
    HEAPF32[$2>>2] = Math_fround(0.0);
    HEAPF32[$147>>2] = $532;
    HEAPF32[$148>>2] = $185;
    HEAPF32[$149>>2] = Math_fround(0.0);
    HEAPF32[$1>>2] = $533;
    HEAPF32[$150>>2] = $183;
    HEAPF32[$151>>2] = Math_fround(0.0);
    HEAPF32[$152>>2] = Math_fround(0.0);
    $b$a$i235 = $534 ? $2 : $1;
    $535 = Math_fround(HEAPF32[$b$a$i235>>2]);
    $$in1$i238 = (($b$a$i235) + 4|0);
    $536 = Math_fround(HEAPF32[$$in1$i238>>2]);
    $$in2$i240 = (($b$a$i235) + 8|0);
    $537 = Math_fround(HEAPF32[$$in2$i240>>2]);
    $538 = Math_fround($144 * $183);
    $539 = Math_fround($145 * $185);
    $540 = Math_fround($538 + $539);
    $541 = Math_fround($146 * $187);
    $542 = Math_fround($540 + $541);
    $543 = Math_fround($183 * $542);
    $544 = Math_fround($185 * $542);
    $545 = Math_fround($187 * $542);
    $546 = Math_fround($144 - $543);
    $547 = Math_fround($145 - $544);
    $548 = Math_fround($146 - $545);
    $549 = Math_fround($546 * $546);
    $550 = Math_fround($547 * $547);
    $551 = Math_fround($549 + $550);
    $552 = Math_fround($548 * $548);
    $553 = Math_fround($552 + $551);
    $554 = $553 > Math_fround(0.100000001490116119385);
    HEAPF32[$4>>2] = $546;
    HEAPF32[$153>>2] = $547;
    HEAPF32[$154>>2] = $548;
    HEAPF32[$155>>2] = Math_fround(0.0);
    HEAPF32[$3>>2] = $535;
    HEAPF32[$156>>2] = $536;
    HEAPF32[$157>>2] = $537;
    HEAPF32[$158>>2] = Math_fround(0.0);
    $b$a$i209 = $554 ? $4 : $3;
    $555 = Math_fround(HEAPF32[$b$a$i209>>2]);
    $$in1$i = (($b$a$i209) + 4|0);
    $556 = Math_fround(HEAPF32[$$in1$i>>2]);
    $$in2$i = (($b$a$i209) + 8|0);
    $557 = Math_fround(HEAPF32[$$in2$i>>2]);
    $558 = Math_fround($555 * $555);
    $559 = Math_fround($556 * $556);
    $560 = Math_fround($558 + $559);
    $561 = Math_fround($557 * $557);
    $562 = Math_fround($560 + $561);
    $563 = (Math_fround(Math_sqrt((Math_fround($562)))));
    $564 = Math_fround(Math_fround(1.0) / $563);
    $565 = Math_fround($555 * $564);
    $566 = Math_fround($556 * $564);
    $567 = Math_fround($557 * $564);
    $568 = Math_fround($185 * $567);
    $569 = Math_fround($187 * $566);
    $570 = Math_fround($568 - $569);
    $571 = Math_fround($187 * $565);
    $572 = Math_fround($183 * $567);
    $573 = Math_fround($571 - $572);
    $574 = Math_fround($183 * $566);
    $575 = Math_fround($185 * $565);
    $576 = Math_fround($574 - $575);
    $577 = HEAP32[$159>>2]|0;
    $578 = ($frictionPatchWritebackAddrIndex$02416*96)|0;
    $579 = (($577) + ($578)|0);
    $580 = ((($c) + (($i$02411*96)|0)|0) + 784|0);
    $581 = HEAP16[$580>>1]|0;
    $582 = ($581<<16>>16)==(0);
    if ($582) {
     $ptr$3 = $ptr$1$lcssa;
    } else {
     $j4$02405 = 0;$ptr$22406 = $ptr$1$lcssa;
     while(1) {
      $583 = (($ptr$22406) + 256|0);
      $584 = (($ptr$22406) + 384|0);
      $585 = (($ptr$22406) + ($143)|0);
      $586 = (($ptr$22406) + ($$sum)|0);
      $587 = (((($c) + (($i$02411*96)|0)|0) + (($j4$02405*12)|0)|0) + 816|0);
      $588 = Math_fround(HEAPF32[$587>>2]);
      $589 = (((($c) + (($i$02411*96)|0)|0) + (($j4$02405*12)|0)|0) + 820|0);
      $590 = Math_fround(HEAPF32[$589>>2]);
      $591 = (((($c) + (($i$02411*96)|0)|0) + (($j4$02405*12)|0)|0) + 824|0);
      $592 = Math_fround(HEAPF32[$591>>2]);
      $593 = (((($c) + (($i$02411*96)|0)|0) + (($j4$02405*12)|0)|0) + 840|0);
      $594 = Math_fround(HEAPF32[$593>>2]);
      $595 = (((($c) + (($i$02411*96)|0)|0) + (($j4$02405*12)|0)|0) + 844|0);
      $596 = Math_fround(HEAPF32[$595>>2]);
      $597 = (((($c) + (($i$02411*96)|0)|0) + (($j4$02405*12)|0)|0) + 848|0);
      $598 = Math_fround(HEAPF32[$597>>2]);
      $599 = (($ptr$22406) + 80|0);
      HEAP32[$599>>2] = $579;
      $600 = (($ptr$22406) + ($$sum1)|0);
      HEAP32[$600>>2] = $579;
      $601 = Math_fround($161 * $588);
      $602 = Math_fround($161 * $590);
      $603 = Math_fround($161 * $592);
      $604 = Math_fround($29 * $592);
      $605 = Math_fround($31 * $590);
      $606 = Math_fround($604 - $605);
      $607 = Math_fround($31 * $588);
      $608 = Math_fround($27 * $592);
      $609 = Math_fround($607 - $608);
      $610 = Math_fround($27 * $590);
      $611 = Math_fround($29 * $588);
      $612 = Math_fround($610 - $611);
      $613 = Math_fround($33 * $606);
      $614 = Math_fround($33 * $609);
      $615 = Math_fround($33 * $612);
      $616 = Math_fround($601 + $613);
      $617 = Math_fround($602 + $614);
      $618 = Math_fround($603 + $615);
      $619 = Math_fround($27 * $588);
      $620 = Math_fround($29 * $590);
      $621 = Math_fround($619 + $620);
      $622 = Math_fround($31 * $592);
      $623 = Math_fround($621 + $622);
      $624 = Math_fround($27 * $623);
      $625 = Math_fround($29 * $623);
      $626 = Math_fround($31 * $623);
      $627 = Math_fround($624 + $616);
      $628 = Math_fround($625 + $617);
      $629 = Math_fround($618 + $626);
      $630 = Math_fround($627 * Math_fround(2.0));
      $631 = Math_fround($628 * Math_fround(2.0));
      $632 = Math_fround($629 * Math_fround(2.0));
      $633 = Math_fround($163 * $594);
      $634 = Math_fround($163 * $596);
      $635 = Math_fround($163 * $598);
      $636 = Math_fround($42 * $598);
      $637 = Math_fround($44 * $596);
      $638 = Math_fround($636 - $637);
      $639 = Math_fround($44 * $594);
      $640 = Math_fround($40 * $598);
      $641 = Math_fround($639 - $640);
      $642 = Math_fround($40 * $596);
      $643 = Math_fround($42 * $594);
      $644 = Math_fround($642 - $643);
      $645 = Math_fround($46 * $638);
      $646 = Math_fround($46 * $641);
      $647 = Math_fround($46 * $644);
      $648 = Math_fround($633 + $645);
      $649 = Math_fround($634 + $646);
      $650 = Math_fround($635 + $647);
      $651 = Math_fround($40 * $594);
      $652 = Math_fround($42 * $596);
      $653 = Math_fround($651 + $652);
      $654 = Math_fround($44 * $598);
      $655 = Math_fround($653 + $654);
      $656 = Math_fround($40 * $655);
      $657 = Math_fround($42 * $655);
      $658 = Math_fround($44 * $655);
      $659 = Math_fround($656 + $648);
      $660 = Math_fround($657 + $649);
      $661 = Math_fround($650 + $658);
      $662 = Math_fround($659 * Math_fround(2.0));
      $663 = Math_fround($660 * Math_fround(2.0));
      $664 = Math_fround($661 * Math_fround(2.0));
      $665 = Math_fround($35 + $630);
      $666 = Math_fround($37 + $631);
      $667 = Math_fround($39 + $632);
      $668 = Math_fround($48 + $662);
      $669 = Math_fround($50 + $663);
      $670 = Math_fround($52 + $664);
      $671 = Math_fround($665 - $668);
      $672 = Math_fround($666 - $669);
      $673 = Math_fround($667 - $670);
      $674 = Math_fround($567 * $631);
      $675 = Math_fround($566 * $632);
      $676 = Math_fround($674 - $675);
      $677 = Math_fround($565 * $632);
      $678 = Math_fround($567 * $630);
      $679 = Math_fround($677 - $678);
      $680 = Math_fround($566 * $630);
      $681 = Math_fround($565 * $631);
      $682 = Math_fround($680 - $681);
      $683 = Math_fround($567 * $663);
      $684 = Math_fround($566 * $664);
      $685 = Math_fround($683 - $684);
      $686 = Math_fround($565 * $664);
      $687 = Math_fround($567 * $662);
      $688 = Math_fround($686 - $687);
      $689 = Math_fround($566 * $662);
      $690 = Math_fround($565 * $663);
      $691 = Math_fround($689 - $690);
      $692 = Math_fround($122 * $676);
      $693 = Math_fround($125 * $679);
      $694 = Math_fround($692 + $693);
      $695 = Math_fround($128 * $682);
      $696 = Math_fround($695 + $694);
      $697 = Math_fround($123 * $676);
      $698 = Math_fround($126 * $679);
      $699 = Math_fround($697 + $698);
      $700 = Math_fround($129 * $682);
      $701 = Math_fround($700 + $699);
      $702 = Math_fround($124 * $676);
      $703 = Math_fround($127 * $679);
      $704 = Math_fround($702 + $703);
      $705 = Math_fround($130 * $682);
      $706 = Math_fround($705 + $704);
      $707 = Math_fround($131 * $685);
      $708 = Math_fround($134 * $688);
      $709 = Math_fround($707 + $708);
      $710 = Math_fround($137 * $691);
      $711 = Math_fround($710 + $709);
      $712 = Math_fround($132 * $685);
      $713 = Math_fround($135 * $688);
      $714 = Math_fround($712 + $713);
      $715 = Math_fround($138 * $691);
      $716 = Math_fround($715 + $714);
      $717 = Math_fround($133 * $685);
      $718 = Math_fround($136 * $688);
      $719 = Math_fround($717 + $718);
      $720 = Math_fround($139 * $691);
      $721 = Math_fround($720 + $719);
      $722 = Math_fround($676 * $696);
      $723 = Math_fround($679 * $701);
      $724 = Math_fround($722 + $723);
      $725 = Math_fround($682 * $706);
      $726 = Math_fround($725 + $724);
      $727 = Math_fround($119 + $726);
      $728 = Math_fround($685 * $711);
      $729 = Math_fround($688 * $716);
      $730 = Math_fround($728 + $729);
      $731 = Math_fround($691 * $721);
      $732 = Math_fround($731 + $730);
      $733 = Math_fround($120 + $732);
      $734 = Math_fround($727 + $733);
      $735 = Math_fround(Math_fround(0.800000011920928955078) / $734);
      $736 = !($734 > Math_fround(0.0));
      $737 = $736 ? Math_fround(0.0) : $735;
      $738 = HEAP32[$167>>2]|0;
      $739 = (($c) + (($738*12)|0)|0);
      $740 = HEAP16[$739>>1]|0;
      $741 = $740&65535;
      $742 = ((($buffer) + ($741<<6)|0) + 32|0);
      $743 = Math_fround(HEAPF32[$742>>2]);
      $744 = ((($buffer) + ($741<<6)|0) + 36|0);
      $745 = Math_fround(HEAPF32[$744>>2]);
      $746 = ((($buffer) + ($741<<6)|0) + 40|0);
      $747 = Math_fround(HEAPF32[$746>>2]);
      $748 = Math_fround($565 * $743);
      $749 = Math_fround($566 * $745);
      $750 = Math_fround($748 + $749);
      $751 = Math_fround($567 * $747);
      $752 = Math_fround($750 + $751);
      HEAPF32[$ptr$22406>>2] = $565;
      $753 = (($ptr$22406) + 4|0);
      HEAPF32[$753>>2] = $566;
      $754 = (($ptr$22406) + 8|0);
      HEAPF32[$754>>2] = $567;
      $755 = (($ptr$22406) + 12|0);
      HEAPF32[$755>>2] = Math_fround(0.0);
      $756 = (($ptr$22406) + 16|0);
      HEAPF32[$756>>2] = $676;
      $757 = (($ptr$22406) + 20|0);
      HEAPF32[$757>>2] = $679;
      $758 = (($ptr$22406) + 24|0);
      HEAPF32[$758>>2] = $682;
      $759 = (($ptr$22406) + 28|0);
      HEAPF32[$759>>2] = $737;
      $760 = Math_fround($565 * $671);
      $761 = Math_fround($566 * $672);
      $762 = Math_fround($760 + $761);
      $763 = Math_fround($567 * $673);
      $764 = Math_fround($763 + $762);
      $765 = Math_fround($764 * $invDtF32);
      $766 = (($ptr$22406) + 32|0);
      HEAPF32[$766>>2] = $685;
      $767 = (($ptr$22406) + 36|0);
      HEAPF32[$767>>2] = $688;
      $768 = (($ptr$22406) + 40|0);
      HEAPF32[$768>>2] = $691;
      $769 = (($ptr$22406) + 44|0);
      HEAPF32[$769>>2] = $765;
      $770 = (($ptr$22406) + 48|0);
      HEAPF32[$770>>2] = $696;
      $771 = (($ptr$22406) + 52|0);
      HEAPF32[$771>>2] = $701;
      $772 = (($ptr$22406) + 56|0);
      HEAPF32[$772>>2] = $706;
      $773 = (($ptr$22406) + 60|0);
      HEAPF32[$773>>2] = Math_fround(0.0);
      $774 = Math_fround(-$711);
      $775 = Math_fround(-$716);
      $776 = Math_fround(-$721);
      $777 = (($ptr$22406) + 64|0);
      HEAPF32[$777>>2] = $774;
      $778 = (($ptr$22406) + 68|0);
      HEAPF32[$778>>2] = $775;
      $779 = (($ptr$22406) + 72|0);
      HEAPF32[$779>>2] = $776;
      $780 = (($ptr$22406) + 76|0);
      HEAPF32[$780>>2] = $752;
      $781 = Math_fround($576 * $631);
      $782 = Math_fround($573 * $632);
      $783 = Math_fround($781 - $782);
      $784 = Math_fround($570 * $632);
      $785 = Math_fround($576 * $630);
      $786 = Math_fround($784 - $785);
      $787 = Math_fround($573 * $630);
      $788 = Math_fround($570 * $631);
      $789 = Math_fround($787 - $788);
      $790 = Math_fround($576 * $663);
      $791 = Math_fround($573 * $664);
      $792 = Math_fround($790 - $791);
      $793 = Math_fround($570 * $664);
      $794 = Math_fround($576 * $662);
      $795 = Math_fround($793 - $794);
      $796 = Math_fround($573 * $662);
      $797 = Math_fround($570 * $663);
      $798 = Math_fround($796 - $797);
      $799 = Math_fround($122 * $783);
      $800 = Math_fround($125 * $786);
      $801 = Math_fround($799 + $800);
      $802 = Math_fround($128 * $789);
      $803 = Math_fround($802 + $801);
      $804 = Math_fround($123 * $783);
      $805 = Math_fround($126 * $786);
      $806 = Math_fround($804 + $805);
      $807 = Math_fround($129 * $789);
      $808 = Math_fround($807 + $806);
      $809 = Math_fround($124 * $783);
      $810 = Math_fround($127 * $786);
      $811 = Math_fround($809 + $810);
      $812 = Math_fround($130 * $789);
      $813 = Math_fround($812 + $811);
      $814 = Math_fround($131 * $792);
      $815 = Math_fround($134 * $795);
      $816 = Math_fround($814 + $815);
      $817 = Math_fround($137 * $798);
      $818 = Math_fround($817 + $816);
      $819 = Math_fround($132 * $792);
      $820 = Math_fround($135 * $795);
      $821 = Math_fround($819 + $820);
      $822 = Math_fround($138 * $798);
      $823 = Math_fround($822 + $821);
      $824 = Math_fround($133 * $792);
      $825 = Math_fround($136 * $795);
      $826 = Math_fround($824 + $825);
      $827 = Math_fround($139 * $798);
      $828 = Math_fround($827 + $826);
      $829 = Math_fround($783 * $803);
      $830 = Math_fround($786 * $808);
      $831 = Math_fround($829 + $830);
      $832 = Math_fround($789 * $813);
      $833 = Math_fround($832 + $831);
      $834 = Math_fround($119 + $833);
      $835 = Math_fround($792 * $818);
      $836 = Math_fround($795 * $823);
      $837 = Math_fround($835 + $836);
      $838 = Math_fround($798 * $828);
      $839 = Math_fround($838 + $837);
      $840 = Math_fround($120 + $839);
      $841 = Math_fround($834 + $840);
      $842 = Math_fround(Math_fround(0.800000011920928955078) / $841);
      $843 = !($841 > Math_fround(0.0));
      $844 = $843 ? Math_fround(0.0) : $842;
      $845 = HEAP32[$167>>2]|0;
      $846 = (($c) + (($845*12)|0)|0);
      $847 = HEAP16[$846>>1]|0;
      $848 = $847&65535;
      $849 = ((($buffer) + ($848<<6)|0) + 32|0);
      $850 = Math_fround(HEAPF32[$849>>2]);
      $851 = ((($buffer) + ($848<<6)|0) + 36|0);
      $852 = Math_fround(HEAPF32[$851>>2]);
      $853 = ((($buffer) + ($848<<6)|0) + 40|0);
      $854 = Math_fround(HEAPF32[$853>>2]);
      $855 = Math_fround($570 * $850);
      $856 = Math_fround($573 * $852);
      $857 = Math_fround($855 + $856);
      $858 = Math_fround($576 * $854);
      $859 = Math_fround($857 + $858);
      HEAPF32[$585>>2] = $570;
      $860 = (($ptr$22406) + ($$sum23672368)|0);
      HEAPF32[$860>>2] = $573;
      $861 = (($ptr$22406) + ($$sum23692370)|0);
      HEAPF32[$861>>2] = $576;
      $862 = (($ptr$22406) + ($$sum23712372)|0);
      HEAPF32[$862>>2] = Math_fround(0.0);
      $863 = (($ptr$22406) + ($$sum23)|0);
      HEAPF32[$863>>2] = $783;
      $864 = (($ptr$22406) + ($$sum23732374)|0);
      HEAPF32[$864>>2] = $786;
      $865 = (($ptr$22406) + ($$sum23752376)|0);
      HEAPF32[$865>>2] = $789;
      $866 = (($ptr$22406) + ($$sum23772378)|0);
      HEAPF32[$866>>2] = $844;
      $867 = (($ptr$22406) + ($$sum4)|0);
      $868 = Math_fround($570 * $671);
      $869 = Math_fround($573 * $672);
      $870 = Math_fround($868 + $869);
      $871 = Math_fround($576 * $673);
      $872 = Math_fround($871 + $870);
      $873 = Math_fround($872 * $invDtF32);
      HEAPF32[$867>>2] = $792;
      $874 = (($ptr$22406) + ($$sum2379)|0);
      HEAPF32[$874>>2] = $795;
      $875 = (($ptr$22406) + ($$sum2380)|0);
      HEAPF32[$875>>2] = $798;
      $876 = (($ptr$22406) + ($$sum2381)|0);
      HEAPF32[$876>>2] = $873;
      $877 = (($ptr$22406) + ($$sum5)|0);
      HEAPF32[$877>>2] = $803;
      $878 = (($ptr$22406) + ($$sum2382)|0);
      HEAPF32[$878>>2] = $808;
      $879 = (($ptr$22406) + ($$sum2383)|0);
      HEAPF32[$879>>2] = $813;
      $880 = (($ptr$22406) + ($$sum2384)|0);
      HEAPF32[$880>>2] = Math_fround(0.0);
      $881 = (($ptr$22406) + ($$sum6)|0);
      $882 = Math_fround(-$818);
      $883 = Math_fround(-$823);
      $884 = Math_fround(-$828);
      HEAPF32[$881>>2] = $882;
      $885 = (($ptr$22406) + ($$sum2385)|0);
      HEAPF32[$885>>2] = $883;
      $886 = (($ptr$22406) + ($$sum2386)|0);
      HEAPF32[$886>>2] = $884;
      $887 = (($ptr$22406) + ($$sum2387)|0);
      HEAPF32[$887>>2] = $859;
      $888 = (($j4$02405) + 1)|0;
      $889 = HEAP16[$580>>1]|0;
      $890 = $889&65535;
      $891 = ($888>>>0)<($890>>>0);
      if ($891) {
       $j4$02405 = $888;$ptr$22406 = $586;
      } else {
       $ptr$3 = $586;
       break;
      }
     }
    }
   } else {
    $ptr$3 = $ptr$1$lcssa;
   }
   $892 = (($frictionPatchWritebackAddrIndex$02416) + 1)|0;
   $$pre = HEAP32[$140>>2]|0;
   $895 = $$pre;$frictionPatchWritebackAddrIndex$1 = $892;$ptr$4 = $ptr$3;
  }
  $893 = (($i$02411) + 1)|0;
  $894 = ($893>>>0)<($895>>>0);
  if ($894) {
   $896 = $895;$frictionPatchWritebackAddrIndex$02416 = $frictionPatchWritebackAddrIndex$1;$i$02411 = $893;$ptr$02417 = $ptr$4;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx31setupFinalizeSolverConstraints4EPNS_21PxcSolverContact4DescERNS_18PxcNpThreadContextEPhffRKNS_6shdfnd3aos5Vec4VES9_S9_S9_($descs,$threadContext,$workspace,$invDtF32,$bounceThresholdF32,$invMassScale0,$invInertiaScale0,$invMassScale1,$invInertiaScale1) {
 $descs = $descs|0;
 $threadContext = $threadContext|0;
 $workspace = $workspace|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $invMassScale0 = $invMassScale0|0;
 $invInertiaScale0 = $invInertiaScale0|0;
 $invMassScale1 = $invMassScale1|0;
 $invInertiaScale1 = $invInertiaScale1|0;
 var $$ = 0, $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i1595 = Math_fround(0), $$1 = 0, $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i1596 = Math_fround(0), $$2 = 0, $$3 = 0, $$8025 = 0, $$8026 = 0, $$8111 = Math_fround(0), $$8111$us = Math_fround(0), $$8112 = Math_fround(0), $$8112$us = Math_fround(0), $$in1$i = 0, $$in1$i$us = 0, $$in1$i1046 = 0, $$in1$i378 = 0;
 var $$in1$i378$us = 0, $$in1$i790 = 0, $$in1$i804 = 0, $$in1$i818 = 0, $$in1$i870 = 0, $$in1$i884 = 0, $$in1$i900 = 0, $$in1$i943 = 0, $$in1$i965 = 0, $$in1$i987 = 0, $$in2$i = 0, $$in2$i$us = 0, $$in2$i1048 = 0, $$in2$i380 = 0, $$in2$i380$us = 0, $$in2$i792 = 0, $$in2$i806 = 0, $$in2$i820 = 0, $$in2$i872 = 0, $$in2$i886 = 0;
 var $$in2$i902 = 0, $$in2$i945 = 0, $$in2$i967 = 0, $$in2$i989 = 0, $$in3$i = 0, $$in3$i$us = 0, $$in3$i1050 = 0, $$in3$i382 = 0, $$in3$i382$us = 0, $$in3$i794 = 0, $$in3$i808 = 0, $$in3$i822 = 0, $$in3$i874 = 0, $$in3$i888 = 0, $$in3$i904 = 0, $$in3$i947 = 0, $$in3$i969 = 0, $$in3$i991 = 0, $$lobit = 0, $$lobit4 = 0;
 var $$lobit5 = 0, $$lobit6 = 0, $$ph8119 = 0, $$ph8120 = 0, $$ph8121 = 0, $$ph8122 = 0, $$ph8122$phi = 0, $$ph8123 = 0, $$ph8124 = 0, $$ph8125 = 0, $$ph8126 = 0, $$pn = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0;
 var $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum7 = 0, $$sum8 = 0, $$sum80488049 = 0, $$sum80508051 = 0, $$sum80528053 = 0, $$sum8054 = 0, $$sum8055 = 0;
 var $$sum8056 = 0, $$sum8057 = 0, $$sum8058 = 0, $$sum8059 = 0, $$sum8060 = 0, $$sum8061 = 0, $$sum8062 = 0, $$sum8063 = 0, $$sum8064 = 0, $$sum8065 = 0, $$sum8066 = 0, $$sum8067 = 0, $$sum8068 = 0, $$sum8069 = 0, $$sum8070 = 0, $$sum8071 = 0, $$sum8072 = 0, $$sum8073 = 0, $$sum8074 = 0, $$sum8075 = 0;
 var $$sum8076 = 0, $$sum8077 = 0, $$sum8078 = 0, $$sum8079 = 0, $$sum8080 = 0, $$sum8081 = 0, $$sum8082 = 0, $$sum8083 = 0, $$sum8084 = 0, $$sum8085 = 0, $$sum8086 = 0, $$sum8087 = 0, $$sum8088 = 0, $$sum8089 = 0, $$sum8090 = 0, $$sum8091 = 0, $$sum8092 = 0, $$sum8093 = 0, $$sum8094 = 0, $$sum8095 = 0;
 var $$sum8096 = 0, $$sum8097 = 0, $$sum8098 = 0, $$sum8099 = 0, $$sum8100 = 0, $$sum8101 = 0, $$sum8102 = 0, $$sum8103 = 0, $$sum8104 = 0, $$sum8105 = 0, $$sum8106 = 0, $$sum8107 = 0, $$sum8108 = 0, $$sum8109 = 0, $$sum8110 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0);
 var $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0;
 var $1019 = 0, $102 = Math_fround(0), $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = Math_fround(0), $1030 = Math_fround(0), $1031 = 0, $1032 = Math_fround(0), $1033 = 0, $1034 = Math_fround(0), $1035 = 0, $1036 = Math_fround(0);
 var $1037 = 0, $1038 = Math_fround(0), $1039 = 0, $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = 0, $1042 = Math_fround(0), $1043 = 0, $1044 = Math_fround(0), $1045 = 0, $1046 = Math_fround(0), $1047 = 0, $1048 = Math_fround(0), $1049 = 0, $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = 0, $1052 = Math_fround(0), $1053 = 0, $1054 = Math_fround(0);
 var $1055 = 0, $1056 = Math_fround(0), $1057 = 0, $1058 = Math_fround(0), $1059 = 0, $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = 0, $1062 = Math_fround(0), $1063 = 0, $1064 = Math_fround(0), $1065 = 0, $1066 = Math_fround(0), $1067 = 0, $1068 = Math_fround(0), $1069 = 0, $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = 0, $1072 = Math_fround(0);
 var $1073 = 0, $1074 = Math_fround(0), $1075 = 0, $1076 = Math_fround(0), $1077 = 0, $1078 = Math_fround(0), $1079 = 0, $108 = 0, $1080 = Math_fround(0), $1081 = 0, $1082 = Math_fround(0), $1083 = 0, $1084 = Math_fround(0), $1085 = 0, $1086 = Math_fround(0), $1087 = 0, $1088 = Math_fround(0), $1089 = 0, $109 = Math_fround(0), $1090 = Math_fround(0);
 var $1091 = 0, $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = 0, $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0);
 var $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = 0, $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0);
 var $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0), $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = Math_fround(0), $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0);
 var $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = Math_fround(0), $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = Math_fround(0);
 var $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0), $1169 = Math_fround(0), $117 = Math_fround(0), $1170 = Math_fround(0), $1171 = Math_fround(0), $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = Math_fround(0), $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = 0, $1180 = Math_fround(0);
 var $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0), $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = Math_fround(0), $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = 0, $1190 = Math_fround(0), $1191 = Math_fround(0), $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = Math_fround(0), $1197 = Math_fround(0), $1198 = Math_fround(0), $1199 = Math_fround(0);
 var $12 = 0, $120 = 0, $1200 = Math_fround(0), $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = Math_fround(0), $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = Math_fround(0), $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = Math_fround(0), $1210 = Math_fround(0), $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = Math_fround(0), $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = Math_fround(0);
 var $1217 = Math_fround(0), $1218 = Math_fround(0), $1219 = Math_fround(0), $122 = 0, $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = Math_fround(0), $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = Math_fround(0), $1229 = Math_fround(0), $123 = 0, $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = Math_fround(0), $1233 = Math_fround(0), $1234 = Math_fround(0);
 var $1235 = Math_fround(0), $1236 = Math_fround(0), $1237 = Math_fround(0), $1238 = Math_fround(0), $1239 = Math_fround(0), $124 = 0, $1240 = Math_fround(0), $1241 = Math_fround(0), $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = Math_fround(0), $1245 = Math_fround(0), $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = Math_fround(0), $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0);
 var $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = 0, $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0), $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0);
 var $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = Math_fround(0), $1276 = Math_fround(0), $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = 0, $1280 = Math_fround(0), $1281 = Math_fround(0), $1282 = Math_fround(0), $1283 = Math_fround(0), $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = Math_fround(0), $1287 = Math_fround(0), $1288 = Math_fround(0), $1289 = Math_fround(0);
 var $129 = Math_fround(0), $1290 = Math_fround(0), $1291 = Math_fround(0), $1292 = Math_fround(0), $1293 = Math_fround(0), $1294 = Math_fround(0), $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = Math_fround(0), $1298 = Math_fround(0), $1299 = Math_fround(0), $13 = 0, $130 = 0, $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = Math_fround(0);
 var $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0), $131 = 0, $1310 = Math_fround(0), $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = Math_fround(0), $1314 = Math_fround(0), $1315 = Math_fround(0), $1316 = Math_fround(0), $1317 = Math_fround(0), $1318 = Math_fround(0), $1319 = Math_fround(0), $132 = 0, $1320 = Math_fround(0), $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = Math_fround(0);
 var $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = Math_fround(0), $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = 0, $1340 = Math_fround(0), $1341 = Math_fround(0), $1342 = Math_fround(0);
 var $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = Math_fround(0), $136 = 0, $1360 = Math_fround(0);
 var $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = Math_fround(0), $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = Math_fround(0), $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = Math_fround(0), $1379 = Math_fround(0);
 var $138 = 0, $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = 0, $1390 = Math_fround(0), $1391 = Math_fround(0), $1392 = Math_fround(0), $1393 = Math_fround(0), $1394 = Math_fround(0), $1395 = Math_fround(0), $1396 = Math_fround(0), $1397 = Math_fround(0);
 var $1398 = Math_fround(0), $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = Math_fround(0), $1401 = Math_fround(0), $1402 = Math_fround(0), $1403 = Math_fround(0), $1404 = Math_fround(0), $1405 = Math_fround(0), $1406 = Math_fround(0), $1407 = Math_fround(0), $1408 = Math_fround(0), $1409 = Math_fround(0), $141 = Math_fround(0), $1410 = Math_fround(0), $1411 = Math_fround(0), $1412 = Math_fround(0), $1413 = Math_fround(0), $1414 = Math_fround(0);
 var $1415 = Math_fround(0), $1416 = Math_fround(0), $1417 = Math_fround(0), $1418 = Math_fround(0), $1419 = Math_fround(0), $142 = 0, $1420 = Math_fround(0), $1421 = Math_fround(0), $1422 = Math_fround(0), $1423 = Math_fround(0), $1424 = Math_fround(0), $1425 = Math_fround(0), $1426 = Math_fround(0), $1427 = Math_fround(0), $1428 = Math_fround(0), $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0;
 var $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = Math_fround(0), $1442 = Math_fround(0), $1443 = Math_fround(0), $1444 = Math_fround(0), $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = Math_fround(0), $145 = Math_fround(0), $1450 = Math_fround(0);
 var $1451 = Math_fround(0), $1452 = Math_fround(0), $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = 0, $1460 = Math_fround(0), $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = Math_fround(0), $1467 = 0, $1468 = Math_fround(0), $1469 = 0;
 var $147 = 0, $1470 = Math_fround(0), $1471 = 0, $1472 = Math_fround(0), $1473 = Math_fround(0), $1474 = Math_fround(0), $1475 = Math_fround(0), $1476 = Math_fround(0), $1477 = Math_fround(0), $1478 = Math_fround(0), $1479 = Math_fround(0), $148 = 0, $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0), $1486 = Math_fround(0), $1487 = Math_fround(0);
 var $1488 = Math_fround(0), $1489 = 0, $149 = Math_fround(0), $1490 = 0, $1491 = Math_fround(0), $1492 = 0, $1493 = 0, $1494 = Math_fround(0), $1495 = Math_fround(0), $1496 = Math_fround(0), $1497 = Math_fround(0), $1498 = Math_fround(0), $1499 = Math_fround(0), $15 = 0, $150 = 0, $1500 = Math_fround(0), $1501 = Math_fround(0), $1502 = Math_fround(0), $1503 = Math_fround(0), $1504 = Math_fround(0);
 var $1505 = Math_fround(0), $1506 = Math_fround(0), $1507 = Math_fround(0), $1508 = Math_fround(0), $1509 = Math_fround(0), $151 = 0, $1510 = Math_fround(0), $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = Math_fround(0), $1518 = Math_fround(0), $1519 = Math_fround(0), $152 = Math_fround(0), $1520 = Math_fround(0), $1521 = Math_fround(0), $1522 = Math_fround(0);
 var $1523 = Math_fround(0), $1524 = Math_fround(0), $1525 = Math_fround(0), $1526 = Math_fround(0), $1527 = Math_fround(0), $1528 = Math_fround(0), $1529 = Math_fround(0), $153 = 0, $1530 = Math_fround(0), $1531 = Math_fround(0), $1532 = Math_fround(0), $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0;
 var $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = Math_fround(0), $155 = Math_fround(0), $1550 = Math_fround(0), $1551 = Math_fround(0), $1552 = Math_fround(0), $1553 = Math_fround(0), $1554 = Math_fround(0), $1555 = Math_fround(0), $1556 = Math_fround(0), $1557 = 0, $1558 = 0, $1559 = 0;
 var $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = Math_fround(0), $1566 = Math_fround(0), $1567 = Math_fround(0), $1568 = Math_fround(0), $1569 = 0, $157 = Math_fround(0), $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0;
 var $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = Math_fround(0), $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0;
 var $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = Math_fround(0), $1610 = 0, $1611 = 0, $1612 = 0;
 var $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = Math_fround(0), $1630 = 0;
 var $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0;
 var $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = Math_fround(0), $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0;
 var $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = Math_fround(0), $1680 = Math_fround(0), $1681 = 0, $1682 = Math_fround(0), $1683 = 0, $1684 = Math_fround(0), $1685 = 0;
 var $1686 = Math_fround(0), $1687 = 0, $1688 = Math_fround(0), $1689 = 0, $169 = 0, $1690 = Math_fround(0), $1691 = 0, $1692 = Math_fround(0), $1693 = 0, $1694 = Math_fround(0), $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = Math_fround(0), $1700 = 0, $1701 = 0, $1702 = 0;
 var $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0;
 var $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = Math_fround(0), $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0;
 var $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = Math_fround(0), $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0;
 var $1758 = Math_fround(0), $1759 = Math_fround(0), $176 = 0, $1760 = Math_fround(0), $1761 = Math_fround(0), $1762 = 0, $1763 = 0, $1764 = Math_fround(0), $1765 = 0, $1766 = 0, $1767 = Math_fround(0), $1768 = 0, $1769 = 0, $177 = Math_fround(0), $1770 = 0, $1771 = 0, $1772 = Math_fround(0), $1773 = Math_fround(0), $1774 = Math_fround(0), $1775 = Math_fround(0);
 var $1776 = Math_fround(0), $1777 = Math_fround(0), $1778 = Math_fround(0), $1779 = Math_fround(0), $178 = 0, $1780 = Math_fround(0), $1781 = Math_fround(0), $1782 = Math_fround(0), $1783 = Math_fround(0), $1784 = Math_fround(0), $1785 = Math_fround(0), $1786 = Math_fround(0), $1787 = Math_fround(0), $1788 = Math_fround(0), $1789 = Math_fround(0), $179 = 0, $1790 = Math_fround(0), $1791 = Math_fround(0), $1792 = Math_fround(0), $1793 = Math_fround(0);
 var $1794 = Math_fround(0), $1795 = Math_fround(0), $1796 = Math_fround(0), $1797 = Math_fround(0), $1798 = Math_fround(0), $1799 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $1800 = Math_fround(0), $1801 = Math_fround(0), $1802 = Math_fround(0), $1803 = Math_fround(0), $1804 = Math_fround(0), $1805 = Math_fround(0), $1806 = Math_fround(0), $1807 = Math_fround(0), $1808 = Math_fround(0), $1809 = Math_fround(0), $181 = 0, $1810 = Math_fround(0);
 var $1811 = Math_fround(0), $1812 = Math_fround(0), $1813 = Math_fround(0), $1814 = Math_fround(0), $1815 = Math_fround(0), $1816 = Math_fround(0), $1817 = Math_fround(0), $1818 = Math_fround(0), $1819 = Math_fround(0), $182 = Math_fround(0), $1820 = Math_fround(0), $1821 = Math_fround(0), $1822 = Math_fround(0), $1823 = Math_fround(0), $1824 = Math_fround(0), $1825 = Math_fround(0), $1826 = Math_fround(0), $1827 = Math_fround(0), $1828 = Math_fround(0), $1829 = Math_fround(0);
 var $183 = 0, $1830 = Math_fround(0), $1831 = Math_fround(0), $1832 = Math_fround(0), $1833 = Math_fround(0), $1834 = Math_fround(0), $1835 = Math_fround(0), $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = Math_fround(0), $1840 = Math_fround(0), $1841 = Math_fround(0), $1842 = Math_fround(0), $1843 = Math_fround(0), $1844 = Math_fround(0), $1845 = Math_fround(0), $1846 = Math_fround(0), $1847 = Math_fround(0);
 var $1848 = Math_fround(0), $1849 = Math_fround(0), $185 = 0, $1850 = Math_fround(0), $1851 = Math_fround(0), $1852 = Math_fround(0), $1853 = Math_fround(0), $1854 = Math_fround(0), $1855 = Math_fround(0), $1856 = Math_fround(0), $1857 = Math_fround(0), $1858 = Math_fround(0), $1859 = Math_fround(0), $186 = 0, $1860 = Math_fround(0), $1861 = Math_fround(0), $1862 = Math_fround(0), $1863 = Math_fround(0), $1864 = Math_fround(0), $1865 = Math_fround(0);
 var $1866 = Math_fround(0), $1867 = Math_fround(0), $1868 = Math_fround(0), $1869 = Math_fround(0), $187 = Math_fround(0), $1870 = Math_fround(0), $1871 = Math_fround(0), $1872 = Math_fround(0), $1873 = Math_fround(0), $1874 = Math_fround(0), $1875 = Math_fround(0), $1876 = Math_fround(0), $1877 = Math_fround(0), $1878 = Math_fround(0), $1879 = Math_fround(0), $188 = 0, $1880 = Math_fround(0), $1881 = Math_fround(0), $1882 = Math_fround(0), $1883 = Math_fround(0);
 var $1884 = Math_fround(0), $1885 = Math_fround(0), $1886 = Math_fround(0), $1887 = Math_fround(0), $1888 = Math_fround(0), $1889 = Math_fround(0), $189 = Math_fround(0), $1890 = Math_fround(0), $1891 = Math_fround(0), $1892 = Math_fround(0), $1893 = Math_fround(0), $1894 = Math_fround(0), $1895 = Math_fround(0), $1896 = Math_fround(0), $1897 = Math_fround(0), $1898 = Math_fround(0), $1899 = Math_fround(0), $19 = 0, $190 = 0, $1900 = Math_fround(0);
 var $1901 = Math_fround(0), $1902 = Math_fround(0), $1903 = Math_fround(0), $1904 = Math_fround(0), $1905 = Math_fround(0), $1906 = Math_fround(0), $1907 = Math_fround(0), $1908 = Math_fround(0), $1909 = Math_fround(0), $191 = Math_fround(0), $1910 = Math_fround(0), $1911 = Math_fround(0), $1912 = Math_fround(0), $1913 = Math_fround(0), $1914 = Math_fround(0), $1915 = Math_fround(0), $1916 = Math_fround(0), $1917 = Math_fround(0), $1918 = Math_fround(0), $1919 = Math_fround(0);
 var $192 = 0, $1920 = Math_fround(0), $1921 = Math_fround(0), $1922 = Math_fround(0), $1923 = Math_fround(0), $1924 = Math_fround(0), $1925 = Math_fround(0), $1926 = Math_fround(0), $1927 = Math_fround(0), $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0;
 var $1938 = 0, $1939 = 0, $194 = Math_fround(0), $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0;
 var $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = Math_fround(0), $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0;
 var $1974 = Math_fround(0), $1975 = Math_fround(0), $1976 = Math_fround(0), $1977 = Math_fround(0), $1978 = Math_fround(0), $1979 = Math_fround(0), $198 = Math_fround(0), $1980 = Math_fround(0), $1981 = Math_fround(0), $1982 = Math_fround(0), $1983 = Math_fround(0), $1984 = Math_fround(0), $1985 = Math_fround(0), $1986 = Math_fround(0), $1987 = Math_fround(0), $1988 = Math_fround(0), $1989 = Math_fround(0), $199 = 0, $1990 = Math_fround(0), $1991 = Math_fround(0);
 var $1992 = Math_fround(0), $1993 = Math_fround(0), $1994 = Math_fround(0), $1995 = Math_fround(0), $1996 = Math_fround(0), $1997 = Math_fround(0), $1998 = Math_fround(0), $1999 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $2000 = Math_fround(0), $2001 = Math_fround(0), $2002 = Math_fround(0), $2003 = Math_fround(0), $2004 = Math_fround(0), $2005 = Math_fround(0), $2006 = Math_fround(0), $2007 = Math_fround(0), $2008 = Math_fround(0);
 var $2009 = Math_fround(0), $201 = Math_fround(0), $2010 = Math_fround(0), $2011 = Math_fround(0), $2012 = Math_fround(0), $2013 = Math_fround(0), $2014 = Math_fround(0), $2015 = Math_fround(0), $2016 = Math_fround(0), $2017 = Math_fround(0), $2018 = Math_fround(0), $2019 = Math_fround(0), $202 = 0, $2020 = Math_fround(0), $2021 = Math_fround(0), $2022 = Math_fround(0), $2023 = Math_fround(0), $2024 = Math_fround(0), $2025 = Math_fround(0), $2026 = Math_fround(0);
 var $2027 = Math_fround(0), $2028 = 0, $2029 = Math_fround(0), $203 = Math_fround(0), $2030 = 0, $2031 = Math_fround(0), $2032 = 0, $2033 = Math_fround(0), $2034 = 0, $2035 = Math_fround(0), $2036 = 0, $2037 = Math_fround(0), $2038 = 0, $2039 = Math_fround(0), $204 = 0, $2040 = 0, $2041 = Math_fround(0), $2042 = 0, $2043 = Math_fround(0), $2044 = 0;
 var $2045 = Math_fround(0), $2046 = 0, $2047 = Math_fround(0), $2048 = 0, $2049 = Math_fround(0), $205 = Math_fround(0), $2050 = 0, $2051 = Math_fround(0), $2052 = Math_fround(0), $2053 = Math_fround(0), $2054 = Math_fround(0), $2055 = Math_fround(0), $2056 = Math_fround(0), $2057 = Math_fround(0), $2058 = Math_fround(0), $2059 = Math_fround(0), $206 = 0, $2060 = Math_fround(0), $2061 = Math_fround(0), $2062 = Math_fround(0);
 var $2063 = Math_fround(0), $2064 = Math_fround(0), $2065 = Math_fround(0), $2066 = Math_fround(0), $2067 = Math_fround(0), $2068 = Math_fround(0), $2069 = Math_fround(0), $207 = 0, $2070 = Math_fround(0), $2071 = Math_fround(0), $2072 = Math_fround(0), $2073 = Math_fround(0), $2074 = Math_fround(0), $2075 = Math_fround(0), $2076 = Math_fround(0), $2077 = Math_fround(0), $2078 = Math_fround(0), $2079 = Math_fround(0), $208 = Math_fround(0), $2080 = Math_fround(0);
 var $2081 = Math_fround(0), $2082 = Math_fround(0), $2083 = Math_fround(0), $2084 = Math_fround(0), $2085 = Math_fround(0), $2086 = Math_fround(0), $2087 = Math_fround(0), $2088 = Math_fround(0), $2089 = Math_fround(0), $209 = 0, $2090 = Math_fround(0), $2091 = Math_fround(0), $2092 = Math_fround(0), $2093 = Math_fround(0), $2094 = Math_fround(0), $2095 = Math_fround(0), $2096 = Math_fround(0), $2097 = Math_fround(0), $2098 = Math_fround(0), $2099 = Math_fround(0);
 var $21 = 0, $210 = Math_fround(0), $2100 = Math_fround(0), $2101 = Math_fround(0), $2102 = Math_fround(0), $2103 = Math_fround(0), $2104 = Math_fround(0), $2105 = Math_fround(0), $2106 = Math_fround(0), $2107 = Math_fround(0), $2108 = Math_fround(0), $2109 = Math_fround(0), $211 = 0, $2110 = Math_fround(0), $2111 = Math_fround(0), $2112 = Math_fround(0), $2113 = Math_fround(0), $2114 = Math_fround(0), $2115 = Math_fround(0), $2116 = Math_fround(0);
 var $2117 = Math_fround(0), $2118 = Math_fround(0), $2119 = Math_fround(0), $212 = Math_fround(0), $2120 = Math_fround(0), $2121 = Math_fround(0), $2122 = Math_fround(0), $2123 = Math_fround(0), $2124 = Math_fround(0), $2125 = Math_fround(0), $2126 = Math_fround(0), $2127 = Math_fround(0), $2128 = Math_fround(0), $2129 = Math_fround(0), $213 = 0, $2130 = Math_fround(0), $2131 = Math_fround(0), $2132 = Math_fround(0), $2133 = Math_fround(0), $2134 = Math_fround(0);
 var $2135 = Math_fround(0), $2136 = Math_fround(0), $2137 = Math_fround(0), $2138 = Math_fround(0), $2139 = Math_fround(0), $214 = 0, $2140 = Math_fround(0), $2141 = Math_fround(0), $2142 = Math_fround(0), $2143 = Math_fround(0), $2144 = Math_fround(0), $2145 = Math_fround(0), $2146 = Math_fround(0), $2147 = Math_fround(0), $2148 = Math_fround(0), $2149 = Math_fround(0), $215 = Math_fround(0), $2150 = Math_fround(0), $2151 = Math_fround(0), $2152 = Math_fround(0);
 var $2153 = Math_fround(0), $2154 = Math_fround(0), $2155 = Math_fround(0), $2156 = Math_fround(0), $2157 = Math_fround(0), $2158 = Math_fround(0), $2159 = Math_fround(0), $216 = 0, $2160 = Math_fround(0), $2161 = Math_fround(0), $2162 = Math_fround(0), $2163 = Math_fround(0), $2164 = Math_fround(0), $2165 = Math_fround(0), $2166 = Math_fround(0), $2167 = Math_fround(0), $2168 = Math_fround(0), $2169 = Math_fround(0), $217 = Math_fround(0), $2170 = Math_fround(0);
 var $2171 = Math_fround(0), $2172 = Math_fround(0), $2173 = Math_fround(0), $2174 = Math_fround(0), $2175 = Math_fround(0), $2176 = Math_fround(0), $2177 = Math_fround(0), $2178 = Math_fround(0), $2179 = Math_fround(0), $218 = 0, $2180 = Math_fround(0), $2181 = Math_fround(0), $2182 = Math_fround(0), $2183 = Math_fround(0), $2184 = Math_fround(0), $2185 = Math_fround(0), $2186 = Math_fround(0), $2187 = Math_fround(0), $2188 = Math_fround(0), $2189 = Math_fround(0);
 var $219 = Math_fround(0), $2190 = Math_fround(0), $2191 = Math_fround(0), $2192 = 0, $2193 = Math_fround(0), $2194 = 0, $2195 = Math_fround(0), $2196 = 0, $2197 = Math_fround(0), $2198 = 0, $2199 = Math_fround(0), $22 = 0, $220 = 0, $2200 = 0, $2201 = Math_fround(0), $2202 = 0, $2203 = Math_fround(0), $2204 = 0, $2205 = Math_fround(0), $2206 = 0;
 var $2207 = Math_fround(0), $2208 = 0, $2209 = Math_fround(0), $221 = Math_fround(0), $2210 = 0, $2211 = Math_fround(0), $2212 = 0, $2213 = Math_fround(0), $2214 = 0, $2215 = Math_fround(0), $2216 = Math_fround(0), $2217 = Math_fround(0), $2218 = Math_fround(0), $2219 = Math_fround(0), $222 = 0, $2220 = Math_fround(0), $2221 = Math_fround(0), $2222 = Math_fround(0), $2223 = Math_fround(0), $2224 = Math_fround(0);
 var $2225 = Math_fround(0), $2226 = Math_fround(0), $2227 = Math_fround(0), $2228 = Math_fround(0), $2229 = Math_fround(0), $223 = Math_fround(0), $2230 = Math_fround(0), $2231 = Math_fround(0), $2232 = Math_fround(0), $2233 = Math_fround(0), $2234 = Math_fround(0), $2235 = Math_fround(0), $2236 = Math_fround(0), $2237 = Math_fround(0), $2238 = Math_fround(0), $2239 = Math_fround(0), $224 = 0, $2240 = Math_fround(0), $2241 = Math_fround(0), $2242 = Math_fround(0);
 var $2243 = Math_fround(0), $2244 = Math_fround(0), $2245 = Math_fround(0), $2246 = Math_fround(0), $2247 = Math_fround(0), $2248 = Math_fround(0), $2249 = Math_fround(0), $225 = Math_fround(0), $2250 = Math_fround(0), $2251 = Math_fround(0), $2252 = Math_fround(0), $2253 = Math_fround(0), $2254 = Math_fround(0), $2255 = Math_fround(0), $2256 = Math_fround(0), $2257 = Math_fround(0), $2258 = Math_fround(0), $2259 = Math_fround(0), $226 = 0, $2260 = Math_fround(0);
 var $2261 = Math_fround(0), $2262 = Math_fround(0), $2263 = Math_fround(0), $2264 = Math_fround(0), $2265 = Math_fround(0), $2266 = Math_fround(0), $2267 = Math_fround(0), $2268 = Math_fround(0), $2269 = Math_fround(0), $227 = Math_fround(0), $2270 = Math_fround(0), $2271 = Math_fround(0), $2272 = Math_fround(0), $2273 = Math_fround(0), $2274 = Math_fround(0), $2275 = Math_fround(0), $2276 = Math_fround(0), $2277 = Math_fround(0), $2278 = Math_fround(0), $2279 = Math_fround(0);
 var $228 = 0, $2280 = Math_fround(0), $2281 = Math_fround(0), $2282 = Math_fround(0), $2283 = Math_fround(0), $2284 = Math_fround(0), $2285 = Math_fround(0), $2286 = Math_fround(0), $2287 = Math_fround(0), $2288 = Math_fround(0), $2289 = Math_fround(0), $229 = Math_fround(0), $2290 = Math_fround(0), $2291 = Math_fround(0), $2292 = Math_fround(0), $2293 = Math_fround(0), $2294 = Math_fround(0), $2295 = Math_fround(0), $2296 = Math_fround(0), $2297 = Math_fround(0);
 var $2298 = Math_fround(0), $2299 = Math_fround(0), $23 = 0, $230 = 0, $2300 = Math_fround(0), $2301 = Math_fround(0), $2302 = Math_fround(0), $2303 = Math_fround(0), $2304 = Math_fround(0), $2305 = Math_fround(0), $2306 = Math_fround(0), $2307 = Math_fround(0), $2308 = Math_fround(0), $2309 = Math_fround(0), $231 = Math_fround(0), $2310 = Math_fround(0), $2311 = Math_fround(0), $2312 = Math_fround(0), $2313 = Math_fround(0), $2314 = Math_fround(0);
 var $2315 = Math_fround(0), $2316 = Math_fround(0), $2317 = Math_fround(0), $2318 = Math_fround(0), $2319 = Math_fround(0), $232 = 0, $2320 = Math_fround(0), $2321 = Math_fround(0), $2322 = Math_fround(0), $2323 = Math_fround(0), $2324 = Math_fround(0), $2325 = Math_fround(0), $2326 = Math_fround(0), $2327 = Math_fround(0), $2328 = Math_fround(0), $2329 = Math_fround(0), $233 = Math_fround(0), $2330 = Math_fround(0), $2331 = Math_fround(0), $2332 = Math_fround(0);
 var $2333 = Math_fround(0), $2334 = Math_fround(0), $2335 = Math_fround(0), $2336 = Math_fround(0), $2337 = Math_fround(0), $2338 = Math_fround(0), $2339 = Math_fround(0), $234 = 0, $2340 = Math_fround(0), $2341 = Math_fround(0), $2342 = Math_fround(0), $2343 = Math_fround(0), $2344 = Math_fround(0), $2345 = Math_fround(0), $2346 = Math_fround(0), $2347 = Math_fround(0), $2348 = Math_fround(0), $2349 = Math_fround(0), $235 = Math_fround(0), $2350 = Math_fround(0);
 var $2351 = Math_fround(0), $2352 = Math_fround(0), $2353 = Math_fround(0), $2354 = Math_fround(0), $2355 = Math_fround(0), $2356 = Math_fround(0), $2357 = Math_fround(0), $2358 = Math_fround(0), $2359 = Math_fround(0), $236 = 0, $2360 = Math_fround(0), $2361 = Math_fround(0), $2362 = Math_fround(0), $2363 = Math_fround(0), $2364 = Math_fround(0), $2365 = Math_fround(0), $2366 = Math_fround(0), $2367 = Math_fround(0), $2368 = Math_fround(0), $2369 = Math_fround(0);
 var $237 = Math_fround(0), $2370 = Math_fround(0), $2371 = Math_fround(0), $2372 = Math_fround(0), $2373 = Math_fround(0), $2374 = Math_fround(0), $2375 = Math_fround(0), $2376 = Math_fround(0), $2377 = Math_fround(0), $2378 = Math_fround(0), $2379 = Math_fround(0), $238 = 0, $2380 = Math_fround(0), $2381 = Math_fround(0), $2382 = Math_fround(0), $2383 = Math_fround(0), $2384 = Math_fround(0), $2385 = Math_fround(0), $2386 = Math_fround(0), $2387 = Math_fround(0);
 var $2388 = Math_fround(0), $2389 = Math_fround(0), $239 = Math_fround(0), $2390 = Math_fround(0), $2391 = Math_fround(0), $2392 = Math_fround(0), $2393 = Math_fround(0), $2394 = Math_fround(0), $2395 = Math_fround(0), $2396 = Math_fround(0), $2397 = Math_fround(0), $2398 = Math_fround(0), $2399 = Math_fround(0), $24 = 0, $240 = 0, $2400 = Math_fround(0), $2401 = Math_fround(0), $2402 = Math_fround(0), $2403 = Math_fround(0), $2404 = Math_fround(0);
 var $2405 = Math_fround(0), $2406 = Math_fround(0), $2407 = Math_fround(0), $2408 = Math_fround(0), $2409 = Math_fround(0), $241 = Math_fround(0), $2410 = Math_fround(0), $2411 = Math_fround(0), $2412 = Math_fround(0), $2413 = Math_fround(0), $2414 = Math_fround(0), $2415 = Math_fround(0), $2416 = Math_fround(0), $2417 = Math_fround(0), $2418 = Math_fround(0), $2419 = Math_fround(0), $242 = 0, $2420 = Math_fround(0), $2421 = Math_fround(0), $2422 = Math_fround(0);
 var $2423 = Math_fround(0), $2424 = Math_fround(0), $2425 = Math_fround(0), $2426 = Math_fround(0), $2427 = Math_fround(0), $2428 = Math_fround(0), $2429 = Math_fround(0), $243 = Math_fround(0), $2430 = Math_fround(0), $2431 = Math_fround(0), $2432 = Math_fround(0), $2433 = Math_fround(0), $2434 = Math_fround(0), $2435 = Math_fround(0), $2436 = Math_fround(0), $2437 = Math_fround(0), $2438 = Math_fround(0), $2439 = Math_fround(0), $244 = 0, $2440 = Math_fround(0);
 var $2441 = Math_fround(0), $2442 = Math_fround(0), $2443 = Math_fround(0), $2444 = Math_fround(0), $2445 = Math_fround(0), $2446 = Math_fround(0), $2447 = Math_fround(0), $2448 = Math_fround(0), $2449 = Math_fround(0), $245 = Math_fround(0), $2450 = Math_fround(0), $2451 = Math_fround(0), $2452 = Math_fround(0), $2453 = Math_fround(0), $2454 = Math_fround(0), $2455 = Math_fround(0), $2456 = Math_fround(0), $2457 = Math_fround(0), $2458 = Math_fround(0), $2459 = Math_fround(0);
 var $246 = 0, $2460 = Math_fround(0), $2461 = Math_fround(0), $2462 = Math_fround(0), $2463 = Math_fround(0), $2464 = Math_fround(0), $2465 = Math_fround(0), $2466 = Math_fround(0), $2467 = Math_fround(0), $2468 = Math_fround(0), $2469 = Math_fround(0), $247 = Math_fround(0), $2470 = Math_fround(0), $2471 = Math_fround(0), $2472 = Math_fround(0), $2473 = Math_fround(0), $2474 = Math_fround(0), $2475 = Math_fround(0), $2476 = Math_fround(0), $2477 = Math_fround(0);
 var $2478 = Math_fround(0), $2479 = Math_fround(0), $248 = 0, $2480 = Math_fround(0), $2481 = Math_fround(0), $2482 = Math_fround(0), $2483 = Math_fround(0), $2484 = Math_fround(0), $2485 = Math_fround(0), $2486 = Math_fround(0), $2487 = Math_fround(0), $2488 = Math_fround(0), $2489 = Math_fround(0), $249 = Math_fround(0), $2490 = Math_fround(0), $2491 = Math_fround(0), $2492 = Math_fround(0), $2493 = Math_fround(0), $2494 = Math_fround(0), $2495 = Math_fround(0);
 var $2496 = Math_fround(0), $2497 = Math_fround(0), $2498 = Math_fround(0), $2499 = Math_fround(0), $25 = 0, $250 = 0, $2500 = Math_fround(0), $2501 = Math_fround(0), $2502 = Math_fround(0), $2503 = Math_fround(0), $2504 = Math_fround(0), $2505 = Math_fround(0), $2506 = Math_fround(0), $2507 = Math_fround(0), $2508 = Math_fround(0), $2509 = Math_fround(0), $251 = Math_fround(0), $2510 = Math_fround(0), $2511 = Math_fround(0), $2512 = Math_fround(0);
 var $2513 = Math_fround(0), $2514 = Math_fround(0), $2515 = Math_fround(0), $2516 = Math_fround(0), $2517 = Math_fround(0), $2518 = Math_fround(0), $2519 = Math_fround(0), $252 = 0, $2520 = Math_fround(0), $2521 = Math_fround(0), $2522 = Math_fround(0), $2523 = Math_fround(0), $2524 = Math_fround(0), $2525 = Math_fround(0), $2526 = Math_fround(0), $2527 = Math_fround(0), $2528 = Math_fround(0), $2529 = Math_fround(0), $253 = Math_fround(0), $2530 = Math_fround(0);
 var $2531 = Math_fround(0), $2532 = Math_fround(0), $2533 = Math_fround(0), $2534 = Math_fround(0), $2535 = Math_fround(0), $2536 = Math_fround(0), $2537 = Math_fround(0), $2538 = Math_fround(0), $2539 = Math_fround(0), $254 = 0, $2540 = Math_fround(0), $2541 = Math_fround(0), $2542 = Math_fround(0), $2543 = Math_fround(0), $2544 = Math_fround(0), $2545 = Math_fround(0), $2546 = Math_fround(0), $2547 = Math_fround(0), $2548 = Math_fround(0), $2549 = Math_fround(0);
 var $255 = Math_fround(0), $2550 = Math_fround(0), $2551 = Math_fround(0), $2552 = Math_fround(0), $2553 = Math_fround(0), $2554 = Math_fround(0), $2555 = Math_fround(0), $2556 = Math_fround(0), $2557 = Math_fround(0), $2558 = Math_fround(0), $2559 = Math_fround(0), $256 = 0, $2560 = Math_fround(0), $2561 = Math_fround(0), $2562 = Math_fround(0), $2563 = Math_fround(0), $2564 = Math_fround(0), $2565 = Math_fround(0), $2566 = Math_fround(0), $2567 = Math_fround(0);
 var $2568 = Math_fround(0), $2569 = Math_fround(0), $257 = Math_fround(0), $2570 = Math_fround(0), $2571 = Math_fround(0), $2572 = Math_fround(0), $2573 = Math_fround(0), $2574 = Math_fround(0), $2575 = Math_fround(0), $2576 = Math_fround(0), $2577 = Math_fround(0), $2578 = Math_fround(0), $2579 = Math_fround(0), $258 = 0, $2580 = Math_fround(0), $2581 = Math_fround(0), $2582 = Math_fround(0), $2583 = Math_fround(0), $2584 = Math_fround(0), $2585 = Math_fround(0);
 var $2586 = Math_fround(0), $2587 = Math_fround(0), $2588 = Math_fround(0), $2589 = Math_fround(0), $259 = Math_fround(0), $2590 = Math_fround(0), $2591 = Math_fround(0), $2592 = Math_fround(0), $2593 = Math_fround(0), $2594 = Math_fround(0), $2595 = Math_fround(0), $2596 = Math_fround(0), $2597 = Math_fround(0), $2598 = Math_fround(0), $2599 = Math_fround(0), $26 = 0, $260 = 0, $2600 = Math_fround(0), $2601 = Math_fround(0), $2602 = Math_fround(0);
 var $2603 = Math_fround(0), $2604 = Math_fround(0), $2605 = Math_fround(0), $2606 = Math_fround(0), $2607 = Math_fround(0), $2608 = Math_fround(0), $2609 = Math_fround(0), $261 = Math_fround(0), $2610 = Math_fround(0), $2611 = Math_fround(0), $2612 = 0, $2613 = 0, $2614 = 0, $2615 = 0, $2616 = 0, $2617 = 0, $2618 = 0, $2619 = 0, $262 = 0, $2620 = 0;
 var $2621 = 0, $2622 = 0, $2623 = 0, $2624 = Math_fround(0), $2625 = Math_fround(0), $2626 = Math_fround(0), $2627 = Math_fround(0), $2628 = 0, $2629 = 0, $263 = Math_fround(0), $2630 = 0, $2631 = 0, $2632 = Math_fround(0), $2633 = Math_fround(0), $2634 = Math_fround(0), $2635 = Math_fround(0), $2636 = 0, $2637 = 0, $2638 = 0, $2639 = 0;
 var $264 = 0, $2640 = Math_fround(0), $2641 = Math_fround(0), $2642 = Math_fround(0), $2643 = Math_fround(0), $2644 = 0, $2645 = 0, $2646 = 0, $2647 = 0, $2648 = 0, $2649 = 0, $265 = Math_fround(0), $2650 = 0, $2651 = 0, $2652 = Math_fround(0), $2653 = Math_fround(0), $2654 = Math_fround(0), $2655 = Math_fround(0), $2656 = Math_fround(0), $2657 = Math_fround(0);
 var $2658 = Math_fround(0), $2659 = Math_fround(0), $266 = 0, $2660 = Math_fround(0), $2661 = Math_fround(0), $2662 = Math_fround(0), $2663 = Math_fround(0), $2664 = Math_fround(0), $2665 = Math_fround(0), $2666 = Math_fround(0), $2667 = Math_fround(0), $2668 = Math_fround(0), $2669 = Math_fround(0), $267 = Math_fround(0), $2670 = Math_fround(0), $2671 = Math_fround(0), $2672 = Math_fround(0), $2673 = Math_fround(0), $2674 = Math_fround(0), $2675 = Math_fround(0);
 var $2676 = Math_fround(0), $2677 = Math_fround(0), $2678 = Math_fround(0), $2679 = Math_fround(0), $268 = Math_fround(0), $2680 = Math_fround(0), $2681 = Math_fround(0), $2682 = Math_fround(0), $2683 = Math_fround(0), $2684 = Math_fround(0), $2685 = Math_fround(0), $2686 = Math_fround(0), $2687 = Math_fround(0), $2688 = Math_fround(0), $2689 = Math_fround(0), $269 = Math_fround(0), $2690 = Math_fround(0), $2691 = Math_fround(0), $2692 = Math_fround(0), $2693 = Math_fround(0);
 var $2694 = Math_fround(0), $2695 = Math_fround(0), $2696 = Math_fround(0), $2697 = Math_fround(0), $2698 = Math_fround(0), $2699 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $2700 = Math_fround(0), $2701 = Math_fround(0), $2702 = Math_fround(0), $2703 = Math_fround(0), $2704 = Math_fround(0), $2705 = Math_fround(0), $2706 = Math_fround(0), $2707 = Math_fround(0), $2708 = Math_fround(0), $2709 = Math_fround(0), $271 = Math_fround(0), $2710 = Math_fround(0);
 var $2711 = Math_fround(0), $2712 = Math_fround(0), $2713 = Math_fround(0), $2714 = Math_fround(0), $2715 = Math_fround(0), $2716 = Math_fround(0), $2717 = Math_fround(0), $2718 = Math_fround(0), $2719 = Math_fround(0), $272 = Math_fround(0), $2720 = Math_fround(0), $2721 = Math_fround(0), $2722 = Math_fround(0), $2723 = Math_fround(0), $2724 = Math_fround(0), $2725 = Math_fround(0), $2726 = Math_fround(0), $2727 = Math_fround(0), $2728 = 0, $2729 = 0;
 var $273 = Math_fround(0), $2730 = 0, $2731 = Math_fround(0), $2732 = Math_fround(0), $2733 = Math_fround(0), $2734 = Math_fround(0), $2735 = 0, $2736 = 0, $2737 = 0, $2738 = 0, $2739 = Math_fround(0), $274 = Math_fround(0), $2740 = Math_fround(0), $2741 = Math_fround(0), $2742 = Math_fround(0), $2743 = 0, $2744 = 0, $2745 = 0, $2746 = 0, $2747 = 0;
 var $2748 = 0, $2749 = 0, $275 = Math_fround(0), $2750 = 0, $2751 = 0, $2752 = 0, $2753 = 0, $2754 = 0, $2755 = 0, $2756 = 0, $2757 = 0, $2758 = 0, $2759 = 0, $276 = Math_fround(0), $2760 = 0, $2761 = 0, $2762 = 0, $2763 = 0, $2764 = 0, $2765 = 0;
 var $2766 = 0, $2767 = 0, $2768 = 0, $2769 = 0, $277 = Math_fround(0), $2770 = 0, $2771 = 0, $2772 = Math_fround(0), $2773 = Math_fround(0), $2774 = Math_fround(0), $2775 = Math_fround(0), $2776 = 0, $2777 = 0, $2778 = 0, $2779 = 0, $278 = Math_fround(0), $2780 = 0, $2781 = 0, $2782 = 0, $2783 = 0;
 var $2784 = 0, $2785 = 0, $2786 = 0, $2787 = 0, $2788 = 0, $2789 = 0, $279 = Math_fround(0), $2790 = 0, $2791 = 0, $2792 = 0, $2793 = 0, $2794 = 0, $2795 = 0, $2796 = 0, $2797 = Math_fround(0), $2798 = Math_fround(0), $2799 = Math_fround(0), $28 = 0, $280 = 0, $2800 = Math_fround(0);
 var $2801 = Math_fround(0), $2802 = Math_fround(0), $2803 = Math_fround(0), $2804 = Math_fround(0), $2805 = Math_fround(0), $2806 = Math_fround(0), $2807 = Math_fround(0), $2808 = Math_fround(0), $2809 = Math_fround(0), $281 = Math_fround(0), $2810 = Math_fround(0), $2811 = Math_fround(0), $2812 = Math_fround(0), $2813 = Math_fround(0), $2814 = Math_fround(0), $2815 = Math_fround(0), $2816 = Math_fround(0), $2817 = Math_fround(0), $2818 = Math_fround(0), $2819 = Math_fround(0);
 var $282 = 0, $2820 = Math_fround(0), $2821 = Math_fround(0), $2822 = Math_fround(0), $2823 = Math_fround(0), $2824 = Math_fround(0), $2825 = Math_fround(0), $2826 = Math_fround(0), $2827 = Math_fround(0), $2828 = Math_fround(0), $2829 = Math_fround(0), $283 = Math_fround(0), $2830 = Math_fround(0), $2831 = Math_fround(0), $2832 = Math_fround(0), $2833 = Math_fround(0), $2834 = Math_fround(0), $2835 = Math_fround(0), $2836 = Math_fround(0), $2837 = Math_fround(0);
 var $2838 = Math_fround(0), $2839 = Math_fround(0), $284 = 0, $2840 = Math_fround(0), $2841 = Math_fround(0), $2842 = Math_fround(0), $2843 = Math_fround(0), $2844 = Math_fround(0), $2845 = Math_fround(0), $2846 = Math_fround(0), $2847 = Math_fround(0), $2848 = Math_fround(0), $2849 = Math_fround(0), $285 = Math_fround(0), $2850 = Math_fround(0), $2851 = Math_fround(0), $2852 = Math_fround(0), $2853 = Math_fround(0), $2854 = Math_fround(0), $2855 = Math_fround(0);
 var $2856 = Math_fround(0), $2857 = Math_fround(0), $2858 = Math_fround(0), $2859 = Math_fround(0), $286 = 0, $2860 = Math_fround(0), $2861 = Math_fround(0), $2862 = Math_fround(0), $2863 = Math_fround(0), $2864 = Math_fround(0), $2865 = Math_fround(0), $2866 = Math_fround(0), $2867 = Math_fround(0), $2868 = Math_fround(0), $2869 = Math_fround(0), $287 = Math_fround(0), $2870 = Math_fround(0), $2871 = Math_fround(0), $2872 = Math_fround(0), $2873 = Math_fround(0);
 var $2874 = Math_fround(0), $2875 = Math_fround(0), $2876 = Math_fround(0), $2877 = Math_fround(0), $2878 = Math_fround(0), $2879 = Math_fround(0), $288 = 0, $2880 = Math_fround(0), $2881 = Math_fround(0), $2882 = Math_fround(0), $2883 = Math_fround(0), $2884 = Math_fround(0), $2885 = Math_fround(0), $2886 = Math_fround(0), $2887 = Math_fround(0), $2888 = Math_fround(0), $2889 = Math_fround(0), $289 = Math_fround(0), $2890 = Math_fround(0), $2891 = Math_fround(0);
 var $2892 = Math_fround(0), $2893 = Math_fround(0), $2894 = Math_fround(0), $2895 = Math_fround(0), $2896 = Math_fround(0), $2897 = Math_fround(0), $2898 = Math_fround(0), $2899 = Math_fround(0), $29 = 0, $290 = 0, $2900 = Math_fround(0), $2901 = Math_fround(0), $2902 = Math_fround(0), $2903 = Math_fround(0), $2904 = Math_fround(0), $2905 = Math_fround(0), $2906 = Math_fround(0), $2907 = Math_fround(0), $2908 = Math_fround(0), $2909 = Math_fround(0);
 var $291 = Math_fround(0), $2910 = Math_fround(0), $2911 = Math_fround(0), $2912 = Math_fround(0), $2913 = Math_fround(0), $2914 = Math_fround(0), $2915 = Math_fround(0), $2916 = Math_fround(0), $2917 = Math_fround(0), $2918 = Math_fround(0), $2919 = Math_fround(0), $292 = 0, $2920 = Math_fround(0), $2921 = Math_fround(0), $2922 = Math_fround(0), $2923 = Math_fround(0), $2924 = Math_fround(0), $2925 = Math_fround(0), $2926 = Math_fround(0), $2927 = Math_fround(0);
 var $2928 = Math_fround(0), $2929 = Math_fround(0), $293 = Math_fround(0), $2930 = Math_fround(0), $2931 = Math_fround(0), $2932 = Math_fround(0), $2933 = Math_fround(0), $2934 = Math_fround(0), $2935 = Math_fround(0), $2936 = Math_fround(0), $2937 = Math_fround(0), $2938 = Math_fround(0), $2939 = Math_fround(0), $294 = 0, $2940 = Math_fround(0), $2941 = Math_fround(0), $2942 = Math_fround(0), $2943 = Math_fround(0), $2944 = Math_fround(0), $2945 = Math_fround(0);
 var $2946 = Math_fround(0), $2947 = Math_fround(0), $2948 = Math_fround(0), $2949 = Math_fround(0), $295 = Math_fround(0), $2950 = Math_fround(0), $2951 = Math_fround(0), $2952 = Math_fround(0), $2953 = Math_fround(0), $2954 = Math_fround(0), $2955 = Math_fround(0), $2956 = Math_fround(0), $2957 = Math_fround(0), $2958 = Math_fround(0), $2959 = Math_fround(0), $296 = Math_fround(0), $2960 = Math_fround(0), $2961 = Math_fround(0), $2962 = Math_fround(0), $2963 = Math_fround(0);
 var $2964 = Math_fround(0), $2965 = Math_fround(0), $2966 = Math_fround(0), $2967 = Math_fround(0), $2968 = Math_fround(0), $2969 = Math_fround(0), $297 = Math_fround(0), $2970 = Math_fround(0), $2971 = Math_fround(0), $2972 = Math_fround(0), $2973 = Math_fround(0), $2974 = Math_fround(0), $2975 = Math_fround(0), $2976 = Math_fround(0), $2977 = Math_fround(0), $2978 = Math_fround(0), $2979 = Math_fround(0), $298 = Math_fround(0), $2980 = Math_fround(0), $2981 = Math_fround(0);
 var $2982 = Math_fround(0), $2983 = Math_fround(0), $2984 = Math_fround(0), $2985 = Math_fround(0), $2986 = Math_fround(0), $2987 = Math_fround(0), $2988 = Math_fround(0), $2989 = Math_fround(0), $299 = Math_fround(0), $2990 = Math_fround(0), $2991 = Math_fround(0), $2992 = Math_fround(0), $2993 = Math_fround(0), $2994 = Math_fround(0), $2995 = Math_fround(0), $2996 = Math_fround(0), $2997 = Math_fround(0), $2998 = Math_fround(0), $2999 = Math_fround(0), $3 = 0;
 var $30 = 0, $300 = Math_fround(0), $3000 = Math_fround(0), $3001 = Math_fround(0), $3002 = Math_fround(0), $3003 = Math_fround(0), $3004 = Math_fround(0), $3005 = Math_fround(0), $3006 = Math_fround(0), $3007 = Math_fround(0), $3008 = Math_fround(0), $3009 = Math_fround(0), $301 = Math_fround(0), $3010 = Math_fround(0), $3011 = Math_fround(0), $3012 = Math_fround(0), $3013 = Math_fround(0), $3014 = Math_fround(0), $3015 = Math_fround(0), $3016 = Math_fround(0);
 var $3017 = Math_fround(0), $3018 = Math_fround(0), $3019 = Math_fround(0), $302 = Math_fround(0), $3020 = Math_fround(0), $3021 = Math_fround(0), $3022 = Math_fround(0), $3023 = Math_fround(0), $3024 = Math_fround(0), $3025 = Math_fround(0), $3026 = Math_fround(0), $3027 = Math_fround(0), $3028 = Math_fround(0), $3029 = Math_fround(0), $303 = Math_fround(0), $3030 = Math_fround(0), $3031 = Math_fround(0), $3032 = Math_fround(0), $3033 = Math_fround(0), $3034 = Math_fround(0);
 var $3035 = Math_fround(0), $3036 = Math_fround(0), $3037 = Math_fround(0), $3038 = Math_fround(0), $3039 = Math_fround(0), $304 = Math_fround(0), $3040 = Math_fround(0), $3041 = 0, $3042 = 0, $3043 = 0, $3044 = 0, $3045 = 0, $3046 = 0, $3047 = 0, $3048 = 0, $3049 = 0, $305 = Math_fround(0), $3050 = 0, $3051 = 0, $3052 = 0;
 var $3053 = 0, $3054 = Math_fround(0), $3055 = Math_fround(0), $3056 = Math_fround(0), $3057 = Math_fround(0), $3058 = 0, $3059 = 0, $306 = Math_fround(0), $3060 = 0, $3061 = 0, $3062 = Math_fround(0), $3063 = Math_fround(0), $3064 = Math_fround(0), $3065 = Math_fround(0), $3066 = 0, $3067 = 0, $3068 = 0, $3069 = 0, $307 = Math_fround(0), $3070 = Math_fround(0);
 var $3071 = Math_fround(0), $3072 = Math_fround(0), $3073 = Math_fround(0), $3074 = 0, $3075 = 0, $3076 = 0, $3077 = 0, $3078 = 0, $3079 = 0, $308 = Math_fround(0), $3080 = 0, $3081 = Math_fround(0), $3082 = Math_fround(0), $3083 = Math_fround(0), $3084 = Math_fround(0), $3085 = Math_fround(0), $3086 = Math_fround(0), $3087 = Math_fround(0), $3088 = Math_fround(0), $3089 = Math_fround(0);
 var $309 = 0, $3090 = Math_fround(0), $3091 = Math_fround(0), $3092 = Math_fround(0), $3093 = Math_fround(0), $3094 = Math_fround(0), $3095 = Math_fround(0), $3096 = Math_fround(0), $3097 = Math_fround(0), $3098 = Math_fround(0), $3099 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $3100 = Math_fround(0), $3101 = Math_fround(0), $3102 = Math_fround(0), $3103 = Math_fround(0), $3104 = Math_fround(0), $3105 = Math_fround(0), $3106 = Math_fround(0);
 var $3107 = Math_fround(0), $3108 = Math_fround(0), $3109 = Math_fround(0), $311 = 0, $3110 = Math_fround(0), $3111 = Math_fround(0), $3112 = Math_fround(0), $3113 = Math_fround(0), $3114 = Math_fround(0), $3115 = Math_fround(0), $3116 = Math_fround(0), $3117 = Math_fround(0), $3118 = Math_fround(0), $3119 = Math_fround(0), $312 = Math_fround(0), $3120 = Math_fround(0), $3121 = Math_fround(0), $3122 = Math_fround(0), $3123 = Math_fround(0), $3124 = Math_fround(0);
 var $3125 = Math_fround(0), $3126 = Math_fround(0), $3127 = Math_fround(0), $3128 = Math_fround(0), $3129 = Math_fround(0), $313 = 0, $3130 = Math_fround(0), $3131 = Math_fround(0), $3132 = Math_fround(0), $3133 = Math_fround(0), $3134 = Math_fround(0), $3135 = Math_fround(0), $3136 = Math_fround(0), $3137 = Math_fround(0), $3138 = Math_fround(0), $3139 = Math_fround(0), $314 = Math_fround(0), $3140 = Math_fround(0), $3141 = Math_fround(0), $3142 = Math_fround(0);
 var $3143 = Math_fround(0), $3144 = Math_fround(0), $3145 = Math_fround(0), $3146 = Math_fround(0), $3147 = Math_fround(0), $3148 = Math_fround(0), $3149 = 0, $315 = 0, $3150 = 0, $3151 = 0, $3152 = 0, $3153 = Math_fround(0), $3154 = Math_fround(0), $3155 = Math_fround(0), $3156 = Math_fround(0), $3157 = 0, $3158 = 0, $3159 = 0, $316 = Math_fround(0), $3160 = 0;
 var $3161 = Math_fround(0), $3162 = Math_fround(0), $3163 = Math_fround(0), $3164 = Math_fround(0), $3165 = 0, $3166 = 0, $3167 = 0, $3168 = 0, $3169 = 0, $317 = 0, $3170 = 0, $3171 = 0, $3172 = 0, $3173 = 0, $3174 = 0, $3175 = 0, $3176 = 0, $3177 = 0, $3178 = 0, $3179 = 0;
 var $318 = Math_fround(0), $3180 = 0, $3181 = 0, $3182 = 0, $3183 = 0, $3184 = 0, $3185 = 0, $3186 = 0, $3187 = 0, $3188 = 0, $3189 = 0, $319 = 0, $3190 = 0, $3191 = 0, $3192 = 0, $3193 = 0, $3194 = 0, $3195 = 0, $3196 = 0, $3197 = Math_fround(0);
 var $3198 = Math_fround(0), $3199 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $3200 = Math_fround(0), $3201 = Math_fround(0), $3202 = Math_fround(0), $3203 = Math_fround(0), $3204 = Math_fround(0), $3205 = 0, $3206 = 0, $3207 = 0, $3208 = 0, $3209 = 0, $321 = 0, $3210 = 0, $3211 = 0, $3212 = 0, $3213 = Math_fround(0), $3214 = Math_fround(0);
 var $3215 = Math_fround(0), $3216 = Math_fround(0), $3217 = 0, $3218 = 0, $3219 = 0, $322 = Math_fround(0), $3220 = 0, $3221 = 0, $3222 = 0, $3223 = 0, $3224 = 0, $3225 = 0, $3226 = 0, $3227 = 0, $3228 = 0, $3229 = 0, $323 = 0, $3230 = 0, $3231 = 0, $3232 = 0;
 var $3233 = 0, $3234 = 0, $3235 = 0, $3236 = 0, $3237 = 0, $3238 = 0, $3239 = 0, $324 = Math_fround(0), $3240 = 0, $3241 = 0, $3242 = 0, $3243 = Math_fround(0), $3244 = Math_fround(0), $3245 = Math_fround(0), $3246 = Math_fround(0), $3247 = Math_fround(0), $3248 = Math_fround(0), $3249 = Math_fround(0), $325 = Math_fround(0), $3250 = Math_fround(0);
 var $3251 = Math_fround(0), $3252 = Math_fround(0), $3253 = Math_fround(0), $3254 = Math_fround(0), $3255 = Math_fround(0), $3256 = Math_fround(0), $3257 = Math_fround(0), $3258 = Math_fround(0), $3259 = Math_fround(0), $326 = 0, $3260 = Math_fround(0), $3261 = Math_fround(0), $3262 = Math_fround(0), $3263 = Math_fround(0), $3264 = Math_fround(0), $3265 = Math_fround(0), $3266 = Math_fround(0), $3267 = Math_fround(0), $3268 = Math_fround(0), $3269 = Math_fround(0);
 var $327 = Math_fround(0), $3270 = Math_fround(0), $3271 = Math_fround(0), $3272 = Math_fround(0), $3273 = Math_fround(0), $3274 = Math_fround(0), $3275 = Math_fround(0), $3276 = Math_fround(0), $3277 = Math_fround(0), $3278 = Math_fround(0), $3279 = Math_fround(0), $328 = 0, $3280 = Math_fround(0), $3281 = Math_fround(0), $3282 = Math_fround(0), $3283 = Math_fround(0), $3284 = Math_fround(0), $3285 = Math_fround(0), $3286 = Math_fround(0), $3287 = Math_fround(0);
 var $3288 = Math_fround(0), $3289 = Math_fround(0), $329 = Math_fround(0), $3290 = Math_fround(0), $3291 = Math_fround(0), $3292 = Math_fround(0), $3293 = Math_fround(0), $3294 = Math_fround(0), $3295 = Math_fround(0), $3296 = Math_fround(0), $3297 = 0, $3298 = Math_fround(0), $3299 = 0, $33 = 0, $330 = 0, $3300 = Math_fround(0), $3301 = 0, $3302 = Math_fround(0), $3303 = 0, $3304 = Math_fround(0);
 var $3305 = 0, $3306 = Math_fround(0), $3307 = 0, $3308 = Math_fround(0), $3309 = 0, $331 = Math_fround(0), $3310 = Math_fround(0), $3311 = 0, $3312 = Math_fround(0), $3313 = 0, $3314 = Math_fround(0), $3315 = 0, $3316 = Math_fround(0), $3317 = 0, $3318 = Math_fround(0), $3319 = 0, $332 = 0, $3320 = Math_fround(0), $3321 = Math_fround(0), $3322 = Math_fround(0);
 var $3323 = Math_fround(0), $3324 = Math_fround(0), $3325 = Math_fround(0), $3326 = Math_fround(0), $3327 = Math_fround(0), $3328 = Math_fround(0), $3329 = Math_fround(0), $333 = Math_fround(0), $3330 = Math_fround(0), $3331 = Math_fround(0), $3332 = Math_fround(0), $3333 = Math_fround(0), $3334 = Math_fround(0), $3335 = Math_fround(0), $3336 = Math_fround(0), $3337 = Math_fround(0), $3338 = Math_fround(0), $3339 = Math_fround(0), $334 = 0, $3340 = Math_fround(0);
 var $3341 = Math_fround(0), $3342 = Math_fround(0), $3343 = Math_fround(0), $3344 = Math_fround(0), $3345 = Math_fround(0), $3346 = Math_fround(0), $3347 = Math_fround(0), $3348 = Math_fround(0), $3349 = Math_fround(0), $335 = Math_fround(0), $3350 = Math_fround(0), $3351 = Math_fround(0), $3352 = Math_fround(0), $3353 = Math_fround(0), $3354 = Math_fround(0), $3355 = Math_fround(0), $3356 = Math_fround(0), $3357 = Math_fround(0), $3358 = Math_fround(0), $3359 = Math_fround(0);
 var $336 = 0, $3360 = Math_fround(0), $3361 = Math_fround(0), $3362 = Math_fround(0), $3363 = Math_fround(0), $3364 = Math_fround(0), $3365 = Math_fround(0), $3366 = Math_fround(0), $3367 = Math_fround(0), $3368 = Math_fround(0), $3369 = Math_fround(0), $337 = Math_fround(0), $3370 = Math_fround(0), $3371 = Math_fround(0), $3372 = Math_fround(0), $3373 = Math_fround(0), $3374 = Math_fround(0), $3375 = Math_fround(0), $3376 = Math_fround(0), $3377 = Math_fround(0);
 var $3378 = Math_fround(0), $3379 = Math_fround(0), $338 = 0, $3380 = Math_fround(0), $3381 = Math_fround(0), $3382 = Math_fround(0), $3383 = Math_fround(0), $3384 = Math_fround(0), $3385 = Math_fround(0), $3386 = Math_fround(0), $3387 = Math_fround(0), $3388 = Math_fround(0), $3389 = Math_fround(0), $339 = Math_fround(0), $3390 = Math_fround(0), $3391 = Math_fround(0), $3392 = Math_fround(0), $3393 = Math_fround(0), $3394 = Math_fround(0), $3395 = Math_fround(0);
 var $3396 = Math_fround(0), $3397 = Math_fround(0), $3398 = Math_fround(0), $3399 = Math_fround(0), $34 = 0, $340 = 0, $3400 = Math_fround(0), $3401 = Math_fround(0), $3402 = Math_fround(0), $3403 = Math_fround(0), $3404 = Math_fround(0), $3405 = Math_fround(0), $3406 = Math_fround(0), $3407 = Math_fround(0), $3408 = Math_fround(0), $3409 = Math_fround(0), $341 = Math_fround(0), $3410 = Math_fround(0), $3411 = Math_fround(0), $3412 = Math_fround(0);
 var $3413 = Math_fround(0), $3414 = Math_fround(0), $3415 = Math_fround(0), $3416 = Math_fround(0), $3417 = Math_fround(0), $3418 = Math_fround(0), $3419 = Math_fround(0), $342 = Math_fround(0), $3420 = Math_fround(0), $3421 = Math_fround(0), $3422 = Math_fround(0), $3423 = Math_fround(0), $3424 = Math_fround(0), $3425 = Math_fround(0), $3426 = Math_fround(0), $3427 = Math_fround(0), $3428 = Math_fround(0), $3429 = Math_fround(0), $343 = 0, $3430 = Math_fround(0);
 var $3431 = Math_fround(0), $3432 = Math_fround(0), $3433 = Math_fround(0), $3434 = Math_fround(0), $3435 = Math_fround(0), $3436 = Math_fround(0), $3437 = Math_fround(0), $3438 = Math_fround(0), $3439 = Math_fround(0), $344 = Math_fround(0), $3440 = Math_fround(0), $3441 = Math_fround(0), $3442 = Math_fround(0), $3443 = Math_fround(0), $3444 = Math_fround(0), $3445 = Math_fround(0), $3446 = Math_fround(0), $3447 = Math_fround(0), $3448 = Math_fround(0), $3449 = Math_fround(0);
 var $345 = 0, $3450 = Math_fround(0), $3451 = Math_fround(0), $3452 = Math_fround(0), $3453 = Math_fround(0), $3454 = Math_fround(0), $3455 = Math_fround(0), $3456 = Math_fround(0), $3457 = Math_fround(0), $3458 = Math_fround(0), $3459 = Math_fround(0), $346 = Math_fround(0), $3460 = Math_fround(0), $3461 = 0, $3462 = Math_fround(0), $3463 = 0, $3464 = Math_fround(0), $3465 = 0, $3466 = Math_fround(0), $3467 = 0;
 var $3468 = Math_fround(0), $3469 = 0, $347 = 0, $3470 = Math_fround(0), $3471 = 0, $3472 = Math_fround(0), $3473 = 0, $3474 = Math_fround(0), $3475 = 0, $3476 = Math_fround(0), $3477 = 0, $3478 = Math_fround(0), $3479 = 0, $348 = Math_fround(0), $3480 = Math_fround(0), $3481 = 0, $3482 = Math_fround(0), $3483 = 0, $3484 = Math_fround(0), $3485 = Math_fround(0);
 var $3486 = Math_fround(0), $3487 = Math_fround(0), $3488 = Math_fround(0), $3489 = Math_fround(0), $349 = 0, $3490 = Math_fround(0), $3491 = Math_fround(0), $3492 = Math_fround(0), $3493 = Math_fround(0), $3494 = Math_fround(0), $3495 = Math_fround(0), $3496 = Math_fround(0), $3497 = Math_fround(0), $3498 = Math_fround(0), $3499 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $3500 = Math_fround(0), $3501 = Math_fround(0), $3502 = Math_fround(0);
 var $3503 = Math_fround(0), $3504 = Math_fround(0), $3505 = Math_fround(0), $3506 = Math_fround(0), $3507 = Math_fround(0), $3508 = Math_fround(0), $3509 = Math_fround(0), $351 = 0, $3510 = Math_fround(0), $3511 = Math_fround(0), $3512 = Math_fround(0), $3513 = Math_fround(0), $3514 = Math_fround(0), $3515 = Math_fround(0), $3516 = Math_fround(0), $3517 = Math_fround(0), $3518 = Math_fround(0), $3519 = Math_fround(0), $352 = Math_fround(0), $3520 = Math_fround(0);
 var $3521 = Math_fround(0), $3522 = Math_fround(0), $3523 = Math_fround(0), $3524 = Math_fround(0), $3525 = Math_fround(0), $3526 = Math_fround(0), $3527 = Math_fround(0), $3528 = Math_fround(0), $3529 = Math_fround(0), $353 = 0, $3530 = Math_fround(0), $3531 = Math_fround(0), $3532 = Math_fround(0), $3533 = Math_fround(0), $3534 = Math_fround(0), $3535 = Math_fround(0), $3536 = Math_fround(0), $3537 = Math_fround(0), $3538 = Math_fround(0), $3539 = Math_fround(0);
 var $354 = Math_fround(0), $3540 = Math_fround(0), $3541 = Math_fround(0), $3542 = Math_fround(0), $3543 = Math_fround(0), $3544 = Math_fround(0), $3545 = Math_fround(0), $3546 = Math_fround(0), $3547 = Math_fround(0), $3548 = Math_fround(0), $3549 = Math_fround(0), $355 = 0, $3550 = Math_fround(0), $3551 = Math_fround(0), $3552 = Math_fround(0), $3553 = Math_fround(0), $3554 = Math_fround(0), $3555 = Math_fround(0), $3556 = Math_fround(0), $3557 = Math_fround(0);
 var $3558 = Math_fround(0), $3559 = Math_fround(0), $356 = Math_fround(0), $3560 = Math_fround(0), $3561 = Math_fround(0), $3562 = Math_fround(0), $3563 = Math_fround(0), $3564 = Math_fround(0), $3565 = Math_fround(0), $3566 = Math_fround(0), $3567 = Math_fround(0), $3568 = Math_fround(0), $3569 = Math_fround(0), $357 = 0, $3570 = Math_fround(0), $3571 = Math_fround(0), $3572 = Math_fround(0), $3573 = Math_fround(0), $3574 = Math_fround(0), $3575 = Math_fround(0);
 var $3576 = Math_fround(0), $3577 = Math_fround(0), $3578 = Math_fround(0), $3579 = Math_fround(0), $358 = Math_fround(0), $3580 = Math_fround(0), $3581 = Math_fround(0), $3582 = Math_fround(0), $3583 = Math_fround(0), $3584 = Math_fround(0), $3585 = Math_fround(0), $3586 = Math_fround(0), $3587 = Math_fround(0), $3588 = Math_fround(0), $3589 = Math_fround(0), $359 = Math_fround(0), $3590 = Math_fround(0), $3591 = Math_fround(0), $3592 = Math_fround(0), $3593 = Math_fround(0);
 var $3594 = Math_fround(0), $3595 = Math_fround(0), $3596 = Math_fround(0), $3597 = Math_fround(0), $3598 = Math_fround(0), $3599 = Math_fround(0), $36 = 0, $360 = 0, $3600 = Math_fround(0), $3601 = Math_fround(0), $3602 = Math_fround(0), $3603 = Math_fround(0), $3604 = Math_fround(0), $3605 = Math_fround(0), $3606 = Math_fround(0), $3607 = Math_fround(0), $3608 = Math_fround(0), $3609 = Math_fround(0), $361 = Math_fround(0), $3610 = Math_fround(0);
 var $3611 = Math_fround(0), $3612 = Math_fround(0), $3613 = Math_fround(0), $3614 = Math_fround(0), $3615 = Math_fround(0), $3616 = Math_fround(0), $3617 = Math_fround(0), $3618 = Math_fround(0), $3619 = Math_fround(0), $362 = 0, $3620 = Math_fround(0), $3621 = Math_fround(0), $3622 = Math_fround(0), $3623 = Math_fround(0), $3624 = Math_fround(0), $3625 = Math_fround(0), $3626 = Math_fround(0), $3627 = Math_fround(0), $3628 = Math_fround(0), $3629 = Math_fround(0);
 var $363 = Math_fround(0), $3630 = Math_fround(0), $3631 = Math_fround(0), $3632 = Math_fround(0), $3633 = Math_fround(0), $3634 = Math_fround(0), $3635 = Math_fround(0), $3636 = Math_fround(0), $3637 = Math_fround(0), $3638 = Math_fround(0), $3639 = Math_fround(0), $364 = 0, $3640 = Math_fround(0), $3641 = Math_fround(0), $3642 = Math_fround(0), $3643 = Math_fround(0), $3644 = Math_fround(0), $3645 = Math_fround(0), $3646 = Math_fround(0), $3647 = Math_fround(0);
 var $3648 = Math_fround(0), $3649 = Math_fround(0), $365 = Math_fround(0), $3650 = Math_fround(0), $3651 = Math_fround(0), $3652 = Math_fround(0), $3653 = Math_fround(0), $3654 = Math_fround(0), $3655 = Math_fround(0), $3656 = Math_fround(0), $3657 = Math_fround(0), $3658 = Math_fround(0), $3659 = Math_fround(0), $366 = 0, $3660 = Math_fround(0), $3661 = Math_fround(0), $3662 = Math_fround(0), $3663 = Math_fround(0), $3664 = Math_fround(0), $3665 = Math_fround(0);
 var $3666 = Math_fround(0), $3667 = Math_fround(0), $3668 = Math_fround(0), $3669 = Math_fround(0), $367 = Math_fround(0), $3670 = Math_fround(0), $3671 = Math_fround(0), $3672 = Math_fround(0), $3673 = Math_fround(0), $3674 = Math_fround(0), $3675 = Math_fround(0), $3676 = Math_fround(0), $3677 = Math_fround(0), $3678 = Math_fround(0), $3679 = Math_fround(0), $368 = 0, $3680 = Math_fround(0), $3681 = Math_fround(0), $3682 = Math_fround(0), $3683 = Math_fround(0);
 var $3684 = Math_fround(0), $3685 = Math_fround(0), $3686 = Math_fround(0), $3687 = Math_fround(0), $3688 = Math_fround(0), $3689 = Math_fround(0), $369 = Math_fround(0), $3690 = Math_fround(0), $3691 = Math_fround(0), $3692 = Math_fround(0), $3693 = Math_fround(0), $3694 = Math_fround(0), $3695 = Math_fround(0), $3696 = Math_fround(0), $3697 = Math_fround(0), $3698 = Math_fround(0), $3699 = Math_fround(0), $37 = 0, $370 = 0, $3700 = Math_fround(0);
 var $3701 = Math_fround(0), $3702 = Math_fround(0), $3703 = Math_fround(0), $3704 = Math_fround(0), $3705 = Math_fround(0), $3706 = Math_fround(0), $3707 = Math_fround(0), $3708 = Math_fround(0), $3709 = Math_fround(0), $371 = Math_fround(0), $3710 = Math_fround(0), $3711 = Math_fround(0), $3712 = Math_fround(0), $3713 = Math_fround(0), $3714 = Math_fround(0), $3715 = Math_fround(0), $3716 = Math_fround(0), $3717 = Math_fround(0), $3718 = Math_fround(0), $3719 = Math_fround(0);
 var $372 = 0, $3720 = Math_fround(0), $3721 = Math_fround(0), $3722 = Math_fround(0), $3723 = Math_fround(0), $3724 = Math_fround(0), $3725 = Math_fround(0), $3726 = Math_fround(0), $3727 = Math_fround(0), $3728 = Math_fround(0), $3729 = Math_fround(0), $373 = Math_fround(0), $3730 = Math_fround(0), $3731 = Math_fround(0), $3732 = Math_fround(0), $3733 = Math_fround(0), $3734 = Math_fround(0), $3735 = Math_fround(0), $3736 = Math_fround(0), $3737 = Math_fround(0);
 var $3738 = Math_fround(0), $3739 = Math_fround(0), $374 = 0, $3740 = Math_fround(0), $3741 = Math_fround(0), $3742 = Math_fround(0), $3743 = Math_fround(0), $3744 = Math_fround(0), $3745 = Math_fround(0), $3746 = Math_fround(0), $3747 = Math_fround(0), $3748 = Math_fround(0), $3749 = Math_fround(0), $375 = Math_fround(0), $3750 = Math_fround(0), $3751 = Math_fround(0), $3752 = Math_fround(0), $3753 = Math_fround(0), $3754 = Math_fround(0), $3755 = Math_fround(0);
 var $3756 = Math_fround(0), $3757 = 0, $3758 = 0, $3759 = 0, $376 = Math_fround(0), $3760 = 0, $3761 = Math_fround(0), $3762 = Math_fround(0), $3763 = Math_fround(0), $3764 = Math_fround(0), $3765 = Math_fround(0), $3766 = Math_fround(0), $3767 = Math_fround(0), $3768 = Math_fround(0), $3769 = Math_fround(0), $377 = 0, $3770 = Math_fround(0), $3771 = Math_fround(0), $3772 = Math_fround(0), $3773 = Math_fround(0);
 var $3774 = Math_fround(0), $3775 = Math_fround(0), $3776 = Math_fround(0), $3777 = Math_fround(0), $3778 = Math_fround(0), $3779 = Math_fround(0), $378 = Math_fround(0), $3780 = Math_fround(0), $3781 = Math_fround(0), $3782 = Math_fround(0), $3783 = Math_fround(0), $3784 = Math_fround(0), $3785 = Math_fround(0), $3786 = Math_fround(0), $3787 = Math_fround(0), $3788 = Math_fround(0), $3789 = Math_fround(0), $379 = 0, $3790 = Math_fround(0), $3791 = Math_fround(0);
 var $3792 = Math_fround(0), $3793 = Math_fround(0), $3794 = Math_fround(0), $3795 = Math_fround(0), $3796 = Math_fround(0), $3797 = Math_fround(0), $3798 = Math_fround(0), $3799 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $3800 = Math_fround(0), $3801 = Math_fround(0), $3802 = Math_fround(0), $3803 = Math_fround(0), $3804 = Math_fround(0), $3805 = Math_fround(0), $3806 = Math_fround(0), $3807 = Math_fround(0), $3808 = Math_fround(0), $3809 = Math_fround(0);
 var $381 = 0, $3810 = Math_fround(0), $3811 = Math_fround(0), $3812 = Math_fround(0), $3813 = Math_fround(0), $3814 = Math_fround(0), $3815 = Math_fround(0), $3816 = Math_fround(0), $3817 = Math_fround(0), $3818 = Math_fround(0), $3819 = Math_fround(0), $382 = Math_fround(0), $3820 = Math_fround(0), $3821 = Math_fround(0), $3822 = Math_fround(0), $3823 = Math_fround(0), $3824 = Math_fround(0), $3825 = Math_fround(0), $3826 = Math_fround(0), $3827 = Math_fround(0);
 var $3828 = Math_fround(0), $3829 = Math_fround(0), $383 = 0, $3830 = Math_fround(0), $3831 = Math_fround(0), $3832 = Math_fround(0), $3833 = Math_fround(0), $3834 = Math_fround(0), $3835 = Math_fround(0), $3836 = Math_fround(0), $3837 = 0, $3838 = 0, $3839 = 0, $384 = Math_fround(0), $3840 = Math_fround(0), $3841 = Math_fround(0), $3842 = Math_fround(0), $3843 = Math_fround(0), $3844 = 0, $3845 = 0;
 var $3846 = 0, $3847 = 0, $3848 = Math_fround(0), $3849 = Math_fround(0), $385 = 0, $3850 = Math_fround(0), $3851 = Math_fround(0), $3852 = 0, $3853 = 0, $3854 = 0, $3855 = 0, $3856 = 0, $3857 = 0, $3858 = 0, $3859 = 0, $386 = Math_fround(0), $3860 = 0, $3861 = 0, $3862 = 0, $3863 = 0;
 var $3864 = 0, $3865 = 0, $3866 = 0, $3867 = 0, $3868 = 0, $3869 = 0, $387 = 0, $3870 = 0, $3871 = 0, $3872 = 0, $3873 = 0, $3874 = 0, $3875 = 0, $3876 = 0, $3877 = 0, $3878 = 0, $3879 = 0, $388 = Math_fround(0), $3880 = 0, $3881 = Math_fround(0);
 var $3882 = Math_fround(0), $3883 = Math_fround(0), $3884 = Math_fround(0), $3885 = 0, $3886 = 0, $3887 = 0, $3888 = 0, $3889 = 0, $389 = 0, $3890 = 0, $3891 = 0, $3892 = 0, $3893 = 0, $3894 = 0, $3895 = 0, $3896 = 0, $3897 = 0, $3898 = 0, $3899 = 0, $39 = 0;
 var $390 = Math_fround(0), $3900 = 0, $3901 = 0, $3902 = 0, $3903 = 0, $3904 = 0, $3905 = 0, $3906 = Math_fround(0), $3907 = Math_fround(0), $3908 = Math_fround(0), $3909 = Math_fround(0), $391 = 0, $3910 = Math_fround(0), $3911 = Math_fround(0), $3912 = Math_fround(0), $3913 = Math_fround(0), $3914 = Math_fround(0), $3915 = Math_fround(0), $3916 = Math_fround(0), $3917 = Math_fround(0);
 var $3918 = Math_fround(0), $3919 = Math_fround(0), $392 = Math_fround(0), $3920 = Math_fround(0), $3921 = Math_fround(0), $3922 = Math_fround(0), $3923 = Math_fround(0), $3924 = Math_fround(0), $3925 = Math_fround(0), $3926 = Math_fround(0), $3927 = Math_fround(0), $3928 = Math_fround(0), $3929 = Math_fround(0), $393 = Math_fround(0), $3930 = Math_fround(0), $3931 = Math_fround(0), $3932 = Math_fround(0), $3933 = Math_fround(0), $3934 = Math_fround(0), $3935 = Math_fround(0);
 var $3936 = Math_fround(0), $3937 = Math_fround(0), $3938 = Math_fround(0), $3939 = Math_fround(0), $394 = 0, $3940 = Math_fround(0), $3941 = Math_fround(0), $3942 = Math_fround(0), $3943 = Math_fround(0), $3944 = Math_fround(0), $3945 = Math_fround(0), $3946 = Math_fround(0), $3947 = Math_fround(0), $3948 = Math_fround(0), $3949 = Math_fround(0), $395 = Math_fround(0), $3950 = Math_fround(0), $3951 = Math_fround(0), $3952 = Math_fround(0), $3953 = Math_fround(0);
 var $3954 = Math_fround(0), $3955 = Math_fround(0), $3956 = Math_fround(0), $3957 = Math_fround(0), $3958 = Math_fround(0), $3959 = Math_fround(0), $396 = 0, $3960 = Math_fround(0), $3961 = Math_fround(0), $3962 = Math_fround(0), $3963 = Math_fround(0), $3964 = Math_fround(0), $3965 = Math_fround(0), $3966 = Math_fround(0), $3967 = Math_fround(0), $3968 = Math_fround(0), $3969 = Math_fround(0), $397 = Math_fround(0), $3970 = Math_fround(0), $3971 = Math_fround(0);
 var $3972 = Math_fround(0), $3973 = Math_fround(0), $3974 = Math_fround(0), $3975 = Math_fround(0), $3976 = Math_fround(0), $3977 = Math_fround(0), $3978 = Math_fround(0), $3979 = Math_fround(0), $398 = 0, $3980 = Math_fround(0), $3981 = Math_fround(0), $3982 = Math_fround(0), $3983 = Math_fround(0), $3984 = Math_fround(0), $3985 = Math_fround(0), $3986 = Math_fround(0), $3987 = Math_fround(0), $3988 = Math_fround(0), $3989 = Math_fround(0), $399 = Math_fround(0);
 var $3990 = Math_fround(0), $3991 = Math_fround(0), $3992 = Math_fround(0), $3993 = Math_fround(0), $3994 = Math_fround(0), $3995 = Math_fround(0), $3996 = Math_fround(0), $3997 = Math_fround(0), $3998 = Math_fround(0), $3999 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $4000 = Math_fround(0), $4001 = Math_fround(0), $4002 = Math_fround(0), $4003 = Math_fround(0), $4004 = Math_fround(0), $4005 = Math_fround(0), $4006 = Math_fround(0);
 var $4007 = Math_fround(0), $4008 = Math_fround(0), $4009 = Math_fround(0), $401 = Math_fround(0), $4010 = Math_fround(0), $4011 = Math_fround(0), $4012 = Math_fround(0), $4013 = Math_fround(0), $4014 = Math_fround(0), $4015 = Math_fround(0), $4016 = Math_fround(0), $4017 = Math_fround(0), $4018 = Math_fround(0), $4019 = Math_fround(0), $402 = 0, $4020 = Math_fround(0), $4021 = Math_fround(0), $4022 = Math_fround(0), $4023 = Math_fround(0), $4024 = Math_fround(0);
 var $4025 = Math_fround(0), $4026 = 0, $4027 = 0, $4028 = 0, $4029 = 0, $403 = Math_fround(0), $4030 = Math_fround(0), $4031 = Math_fround(0), $4032 = Math_fround(0), $4033 = Math_fround(0), $4034 = Math_fround(0), $4035 = Math_fround(0), $4036 = Math_fround(0), $4037 = Math_fround(0), $4038 = Math_fround(0), $4039 = Math_fround(0), $404 = 0, $4040 = Math_fround(0), $4041 = Math_fround(0), $4042 = Math_fround(0);
 var $4043 = Math_fround(0), $4044 = Math_fround(0), $4045 = Math_fround(0), $4046 = Math_fround(0), $4047 = Math_fround(0), $4048 = Math_fround(0), $4049 = Math_fround(0), $405 = Math_fround(0), $4050 = Math_fround(0), $4051 = Math_fround(0), $4052 = Math_fround(0), $4053 = Math_fround(0), $4054 = Math_fround(0), $4055 = Math_fround(0), $4056 = Math_fround(0), $4057 = Math_fround(0), $4058 = Math_fround(0), $4059 = Math_fround(0), $406 = 0, $4060 = Math_fround(0);
 var $4061 = Math_fround(0), $4062 = Math_fround(0), $4063 = Math_fround(0), $4064 = Math_fround(0), $4065 = Math_fround(0), $4066 = Math_fround(0), $4067 = Math_fround(0), $4068 = Math_fround(0), $4069 = Math_fround(0), $407 = Math_fround(0), $4070 = Math_fround(0), $4071 = Math_fround(0), $4072 = Math_fround(0), $4073 = Math_fround(0), $4074 = Math_fround(0), $4075 = Math_fround(0), $4076 = Math_fround(0), $4077 = Math_fround(0), $4078 = Math_fround(0), $4079 = Math_fround(0);
 var $408 = 0, $4080 = Math_fround(0), $4081 = Math_fround(0), $4082 = Math_fround(0), $4083 = Math_fround(0), $4084 = Math_fround(0), $4085 = Math_fround(0), $4086 = Math_fround(0), $4087 = Math_fround(0), $4088 = Math_fround(0), $4089 = Math_fround(0), $409 = Math_fround(0), $4090 = Math_fround(0), $4091 = Math_fround(0), $4092 = Math_fround(0), $4093 = Math_fround(0), $4094 = Math_fround(0), $4095 = Math_fround(0), $4096 = Math_fround(0), $4097 = Math_fround(0);
 var $4098 = 0, $4099 = 0, $41 = 0, $410 = Math_fround(0), $4100 = 0, $4101 = 0, $4102 = Math_fround(0), $4103 = Math_fround(0), $4104 = Math_fround(0), $4105 = Math_fround(0), $4106 = 0, $4107 = 0, $4108 = 0, $4109 = 0, $411 = 0, $4110 = Math_fround(0), $4111 = Math_fround(0), $4112 = Math_fround(0), $4113 = Math_fround(0), $4114 = 0;
 var $4115 = 0, $4116 = 0, $4117 = 0, $4118 = 0, $4119 = 0, $412 = Math_fround(0), $4120 = 0, $4121 = 0, $4122 = 0, $4123 = 0, $4124 = 0, $4125 = 0, $4126 = 0, $4127 = 0, $4128 = 0, $4129 = 0, $413 = 0, $4130 = 0, $4131 = 0, $4132 = 0;
 var $4133 = 0, $4134 = 0, $4135 = 0, $4136 = 0, $4137 = 0, $4138 = 0, $4139 = 0, $414 = Math_fround(0), $4140 = 0, $4141 = 0, $4142 = 0, $4143 = 0, $4144 = 0, $4145 = 0, $4146 = Math_fround(0), $4147 = Math_fround(0), $4148 = Math_fround(0), $4149 = Math_fround(0), $415 = 0, $4150 = Math_fround(0);
 var $4151 = Math_fround(0), $4152 = Math_fround(0), $4153 = Math_fround(0), $4154 = 0, $4155 = 0, $4156 = 0, $4157 = 0, $4158 = 0, $4159 = 0, $416 = Math_fround(0), $4160 = 0, $4161 = 0, $4162 = Math_fround(0), $4163 = Math_fround(0), $4164 = Math_fround(0), $4165 = Math_fround(0), $4166 = 0, $4167 = 0, $4168 = 0, $4169 = 0;
 var $417 = 0, $4170 = 0, $4171 = 0, $4172 = 0, $4173 = 0, $4174 = 0, $4175 = 0, $4176 = 0, $4177 = 0, $4178 = 0, $4179 = 0, $418 = Math_fround(0), $4180 = 0, $4181 = 0, $4182 = 0, $4183 = 0, $4184 = 0, $4185 = 0, $4186 = 0, $4187 = 0;
 var $4188 = 0, $4189 = 0, $419 = 0, $4190 = 0, $4191 = 0, $4192 = 0, $4193 = 0, $4194 = 0, $42 = 0, $420 = Math_fround(0), $421 = 0, $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = Math_fround(0), $43 = 0;
 var $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0);
 var $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0);
 var $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0);
 var $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0);
 var $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = 0, $518 = 0, $519 = 0, $52 = 0;
 var $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = 0, $528 = Math_fround(0), $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = 0, $532 = Math_fround(0), $533 = 0, $534 = 0, $535 = 0, $536 = Math_fround(0), $537 = 0, $538 = Math_fround(0);
 var $539 = 0, $54 = 0, $540 = Math_fround(0), $541 = 0, $542 = 0, $543 = 0, $544 = Math_fround(0), $545 = 0, $546 = Math_fround(0), $547 = 0, $548 = Math_fround(0), $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = Math_fround(0), $553 = 0, $554 = Math_fround(0), $555 = 0, $556 = Math_fround(0);
 var $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = Math_fround(0), $561 = 0, $562 = Math_fround(0), $563 = 0, $564 = Math_fround(0), $565 = 0, $566 = 0, $567 = 0, $568 = Math_fround(0), $569 = 0, $57 = 0, $570 = Math_fround(0), $571 = 0, $572 = Math_fround(0), $573 = 0, $574 = 0;
 var $575 = 0, $576 = Math_fround(0), $577 = 0, $578 = Math_fround(0), $579 = 0, $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = 0, $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = Math_fround(0), $589 = 0, $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = Math_fround(0);
 var $593 = 0, $594 = Math_fround(0), $595 = Math_fround(0), $596 = 0, $597 = Math_fround(0), $598 = 0, $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = 0, $601 = Math_fround(0), $602 = Math_fround(0), $603 = 0, $604 = Math_fround(0), $605 = 0, $606 = Math_fround(0), $607 = 0, $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0);
 var $610 = 0, $611 = Math_fround(0), $612 = 0, $613 = Math_fround(0), $614 = 0, $615 = Math_fround(0), $616 = Math_fround(0), $617 = 0, $618 = Math_fround(0), $619 = 0, $62 = 0, $620 = Math_fround(0), $621 = 0, $622 = Math_fround(0), $623 = Math_fround(0), $624 = 0, $625 = Math_fround(0), $626 = 0, $627 = Math_fround(0), $628 = 0;
 var $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = 0, $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = 0, $636 = Math_fround(0), $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0;
 var $647 = 0, $648 = 0, $649 = 0, $65 = Math_fround(0), $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0;
 var $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0;
 var $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = Math_fround(0), $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0;
 var $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0, $717 = 0, $718 = 0;
 var $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = Math_fround(0), $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0;
 var $737 = 0, $738 = 0, $739 = 0, $74 = Math_fround(0), $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0;
 var $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = Math_fround(0), $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0;
 var $773 = 0, $774 = 0, $775 = 0, $776 = Math_fround(0), $777 = 0, $778 = Math_fround(0), $779 = 0, $78 = Math_fround(0), $780 = Math_fround(0), $781 = 0, $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0;
 var $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = Math_fround(0), $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0;
 var $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0, $812 = 0, $813 = Math_fround(0), $814 = 0, $815 = Math_fround(0), $816 = 0, $817 = Math_fround(0), $818 = 0, $819 = Math_fround(0), $82 = Math_fround(0), $820 = 0, $821 = Math_fround(0), $822 = 0, $823 = Math_fround(0), $824 = 0, $825 = Math_fround(0), $826 = 0;
 var $827 = Math_fround(0), $828 = 0, $829 = Math_fround(0), $83 = Math_fround(0), $830 = 0, $831 = Math_fround(0), $832 = 0, $833 = Math_fround(0), $834 = 0, $835 = Math_fround(0), $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = Math_fround(0), $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0;
 var $845 = 0, $846 = 0, $847 = 0, $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0);
 var $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = 0, $880 = Math_fround(0);
 var $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = Math_fround(0), $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0;
 var $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = Math_fround(0), $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0;
 var $917 = 0, $918 = 0, $919 = 0, $92 = Math_fround(0), $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0;
 var $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = Math_fround(0), $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = Math_fround(0), $950 = 0, $951 = 0, $952 = 0;
 var $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = Math_fround(0), $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0;
 var $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = Math_fround(0), $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0;
 var $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $a$pn4$i = 0, $a$pn4$i$us = 0, $a$pn4$i1045 = 0, $a$pn4$i377 = 0, $a$pn4$i377$us = 0, $a$pn4$i789 = 0, $a$pn4$i803 = 0, $a$pn4$i817 = 0, $a$pn4$i869 = 0;
 var $a$pn4$i883 = 0, $a$pn4$i899 = 0, $a$pn4$i942 = 0, $a$pn4$i964 = 0, $a$pn4$i986 = 0, $a$pn6$i = 0, $a$pn6$i$us = 0, $a$pn6$i1049 = 0, $a$pn6$i381 = 0, $a$pn6$i381$us = 0, $a$pn6$i793 = 0, $a$pn6$i807 = 0, $a$pn6$i821 = 0, $a$pn6$i873 = 0, $a$pn6$i887 = 0, $a$pn6$i903 = 0, $a$pn6$i946 = 0, $a$pn6$i968 = 0, $a$pn6$i990 = 0, $b$a$i = 0;
 var $b$a$i$us = 0, $b$a$i1043 = 0, $b$a$i375 = 0, $b$a$i375$us = 0, $b$a$i787 = 0, $b$a$i801 = 0, $b$a$i815 = 0, $b$a$i867 = 0, $b$a$i881 = 0, $b$a$i897 = 0, $b$a$i940 = 0, $b$a$i962 = 0, $b$a$i984 = 0, $b$a7$i = 0, $b$a7$i$us = 0, $b$a7$i1047 = 0, $b$a7$i379 = 0, $b$a7$i379$us = 0, $b$a7$i791 = 0, $b$a7$i805 = 0;
 var $b$a7$i819 = 0, $b$a7$i871 = 0, $b$a7$i885 = 0, $b$a7$i901 = 0, $b$a7$i944 = 0, $b$a7$i966 = 0, $b$a7$i988 = 0, $contactCount$0 = 0, $contactCount$0$ph = 0, $finished$0 = 0, $finished$0$ph = 0, $finished$0$phi = 0, $frictionIndex0$08160 = 0, $frictionIndex1$08159 = 0, $frictionIndex2$08158 = 0, $frictionIndex3$08157 = 0, $frictionPatchWritebackAddrIndex0$08164 = 0, $index0$08146 = 0, $index0$08146$us = 0, $index1$08147 = 0;
 var $index1$08147$us = 0, $index2$08148 = 0, $index2$08148$us = 0, $index3$08149 = 0, $index3$08149$us = 0, $j$08150 = 0, $j$08150$us = 0, $newContact$0$lcssa$i = 0, $newContact$0$lcssa$i8021 = 0, $newContact$0$lcssa$i917 = 0, $newContact$0$lcssa$i9178019 = 0, $newContact$0$lcssa$i924 = 0, $newContact$0$lcssa$i9248017 = 0, $newContact$0$lcssa$i931 = 0, $newContact$0$lcssa$i9318015 = 0, $newContact$02$i = 0, $newContact$02$i1348 = 0, $newContact$02$i1354 = 0, $newContact$02$i1360 = 0, $newContact$02$i1366 = 0;
 var $newContact$02$i915 = 0, $newContact$02$i922 = 0, $newContact$02$i929 = 0, $newFinished$0 = 0, $newFinished$0$ph = 0, $newFinished$1 = 0, $newFinished$2 = 0, $newFinished$3 = 0, $newPatch$0$lcssa$i = 0, $newPatch$0$lcssa$i$i = 0, $newPatch$0$lcssa$i$i1373 = 0, $newPatch$0$lcssa$i$i13737991 = 0, $newPatch$0$lcssa$i$i13737992 = 0, $newPatch$0$lcssa$i$i13737992$ph = 0, $newPatch$0$lcssa$i$i13737993 = 0, $newPatch$0$lcssa$i$i13738003 = 0, $newPatch$0$lcssa$i$i137380048154 = 0, $newPatch$0$lcssa$i$i13738005 = 0, $newPatch$0$lcssa$i$i13738005$ph = 0, $newPatch$0$lcssa$i$i13738006 = 0;
 var $newPatch$0$lcssa$i$i1377 = 0, $newPatch$0$lcssa$i$i13777994 = 0, $newPatch$0$lcssa$i$i13777995 = 0, $newPatch$0$lcssa$i$i13777995$ph = 0, $newPatch$0$lcssa$i$i13777996 = 0, $newPatch$0$lcssa$i$i13778007 = 0, $newPatch$0$lcssa$i$i137780088153 = 0, $newPatch$0$lcssa$i$i13778009 = 0, $newPatch$0$lcssa$i$i13778009$ph = 0, $newPatch$0$lcssa$i$i13778010 = 0, $newPatch$0$lcssa$i$i1381 = 0, $newPatch$0$lcssa$i$i13817997 = 0, $newPatch$0$lcssa$i$i13817998 = 0, $newPatch$0$lcssa$i$i13817998$ph = 0, $newPatch$0$lcssa$i$i13817999 = 0, $newPatch$0$lcssa$i$i13818011 = 0, $newPatch$0$lcssa$i$i138180128152 = 0, $newPatch$0$lcssa$i$i13818013 = 0, $newPatch$0$lcssa$i$i13818013$ph = 0, $newPatch$0$lcssa$i$i13818014 = 0;
 var $newPatch$0$lcssa$i$i7989 = 0, $newPatch$0$lcssa$i$i7990$ph = 0, $newPatch$0$lcssa$i$i8000 = 0, $newPatch$0$lcssa$i$i80018155 = 0, $newPatch$0$lcssa$i$i8002$ph = 0, $newPatch$0$lcssa$i$i8002$ph$phi = 0, $newPatch$0$lcssa$i8022 = 0, $newPatch$0$lcssa$i918 = 0, $newPatch$0$lcssa$i9188020 = 0, $newPatch$0$lcssa$i925 = 0, $newPatch$0$lcssa$i9258018 = 0, $newPatch$0$lcssa$i932 = 0, $newPatch$0$lcssa$i9328016 = 0, $newPatch$01$i = 0, $newPatch$01$i$i = 0, $newPatch$01$i$i1371 = 0, $newPatch$01$i$i1375 = 0, $newPatch$01$i$i1379 = 0, $newPatch$01$i1349 = 0, $newPatch$01$i1355 = 0;
 var $newPatch$01$i1361 = 0, $newPatch$01$i1367 = 0, $newPatch$01$i916 = 0, $newPatch$01$i923 = 0, $newPatch$01$i930 = 0, $not$ = 0, $not$8037 = 0, $not$8042 = 0, $not$8045 = 0, $notlhs8038 = 0, $notlhs8040 = 0, $notlhs8043 = 0, $notlhs8046 = 0, $notrhs8039 = 0, $notrhs8041 = 0, $notrhs8044 = 0, $notrhs8047 = 0, $or$cond = 0, $or$cond8113 = 0, $or$cond8114 = 0;
 var $or$cond8115 = 0, $p$0 = 0, $p$0$ph = 0, $phitmp = 0, $phitmp8027 = 0, $phitmp8028 = 0, $phitmp8029 = 0, $phitmp8030 = 0, $phitmp8031 = 0, $phitmp8032 = 0, $phitmp8033 = 0, $ptr$08165 = 0, $ptr$1$lcssa = 0, $ptr$18151 = 0, $ptr$18151$us = 0, $split = 0, $umax8192 = 0, $umax8193 = 0, $umax8194 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $0 = sp + 368|0;
 $1 = sp + 352|0;
 $2 = sp + 336|0;
 $3 = sp + 320|0;
 $4 = sp + 304|0;
 $5 = sp + 288|0;
 $6 = sp + 272|0;
 $7 = sp + 256|0;
 $8 = sp + 240|0;
 $9 = sp + 224|0;
 $10 = sp + 208|0;
 $11 = sp + 192|0;
 $12 = sp + 176|0;
 $13 = sp + 64|0;
 $14 = sp;
 $15 = sp + 16|0;
 $16 = sp + 32|0;
 $17 = sp + 48|0;
 $18 = sp + 80|0;
 $19 = sp + 96|0;
 $20 = sp + 112|0;
 $21 = sp + 128|0;
 $22 = sp + 144|0;
 $23 = sp + 160|0;
 $24 = HEAP32[$descs>>2]|0;
 $25 = (($24) + 22|0);
 $26 = HEAP16[$25>>1]|0;
 $27 = $26&65535;
 $28 = $27 >>> 8;
 $$lobit = $28 & 1;
 $29 = $$lobit&255;
 $30 = (($descs) + 56|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 22|0);
 $33 = HEAP16[$32>>1]|0;
 $34 = $33&65535;
 $35 = $34 >>> 8;
 $$lobit4 = $35 & 1;
 $36 = $$lobit4&255;
 $37 = (($descs) + 112|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 22|0);
 $40 = HEAP16[$39>>1]|0;
 $41 = $40&65535;
 $42 = $41 >>> 8;
 $$lobit5 = $42 & 1;
 $43 = $$lobit5&255;
 $44 = (($descs) + 168|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 22|0);
 $47 = HEAP16[$46>>1]|0;
 $48 = $47&65535;
 $49 = $48 >>> 8;
 $$lobit6 = $49 & 1;
 $50 = $$lobit6&255;
 $51 = $33 | $26;
 $52 = $51 | $40;
 $53 = $52 | $47;
 $54 = $53 & 64;
 $55 = ($54<<16>>16)!=(0);
 $56 = $55 ? 272 : 176;
 $57 = $55 ? 336 : 240;
 $58 = (($24) + 84|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($31) + 84|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($38) + 84|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($45) + 84|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($24) + 88|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($31) + 88|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($38) + 88|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($45) + 88|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround(HEAPF32[$invMassScale0>>2]);
 $75 = (($invMassScale0) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($invMassScale0) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($invMassScale0) + 12|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($59 * $74);
 $82 = Math_fround($61 * $76);
 $83 = Math_fround($63 * $78);
 $84 = Math_fround($65 * $80);
 $85 = Math_fround(HEAPF32[$invMassScale1>>2]);
 $86 = (($invMassScale1) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($invMassScale1) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($invMassScale1) + 12|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($67 * $85);
 $93 = Math_fround($69 * $87);
 $94 = Math_fround($71 * $89);
 $95 = Math_fround($73 * $91);
 $96 = Math_fround(HEAPF32[$invInertiaScale0>>2]);
 $97 = (($invInertiaScale0) + 4|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($invInertiaScale0) + 8|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($invInertiaScale0) + 12|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($59 * $96);
 $104 = Math_fround($61 * $98);
 $105 = Math_fround($63 * $100);
 $106 = Math_fround($65 * $102);
 $107 = Math_fround(HEAPF32[$invInertiaScale1>>2]);
 $108 = (($invInertiaScale1) + 4|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($invInertiaScale1) + 8|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($invInertiaScale1) + 12|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($67 * $107);
 $115 = Math_fround($69 * $109);
 $116 = Math_fround($71 * $111);
 $117 = Math_fround($73 * $113);
 $118 = (($descs) + 44|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (($119) + 52|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($descs) + 100|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($123) + 52|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($descs) + 156|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = (($127) + 52|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = (($descs) + 212|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = (($131) + 52|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($descs) + 48|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($135) + 52|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($descs) + 104|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = (($139) + 52|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($descs) + 160|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = (($143) + 52|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($descs) + 216|0);
 $147 = HEAP32[$146>>2]|0;
 $148 = (($147) + 52|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = $121 > $137;
 $$$i1595 = $150 ? $121 : $137;
 $151 = $125 > $141;
 $152 = $151 ? $125 : $141;
 $153 = $129 > $145;
 $$1$i1596 = $153 ? $129 : $145;
 $154 = $133 > $149;
 $155 = $154 ? $133 : $149;
 $156 = (($24) + 92|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = (($31) + 92|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($38) + 92|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($45) + 92|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($descs) + 36|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = (($165) + 4|0);
 $168 = Math_fround(HEAPF32[$167>>2]);
 $169 = (($165) + 8|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = (($descs) + 92|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = (($172) + 4|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = (($172) + 8|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = (($descs) + 148|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = (($179) + 4|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = (($179) + 8|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = (($descs) + 204|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = (($186) + 4|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = (($186) + 8|0);
 $191 = Math_fround(HEAPF32[$190>>2]);
 $192 = (($descs) + 40|0);
 $193 = HEAP32[$192>>2]|0;
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($193) + 4|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($193) + 8|0);
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = (($descs) + 96|0);
 $200 = HEAP32[$199>>2]|0;
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = (($200) + 4|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = (($200) + 8|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($descs) + 152|0);
 $207 = HEAP32[$206>>2]|0;
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($207) + 4|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($207) + 8|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($descs) + 208|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = (($214) + 4|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = (($214) + 8|0);
 $219 = Math_fround(HEAPF32[$218>>2]);
 $220 = (($165) + 16|0);
 $221 = Math_fround(HEAPF32[$220>>2]);
 $222 = (($220) + 4|0);
 $223 = Math_fround(HEAPF32[$222>>2]);
 $224 = (($220) + 8|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = (($172) + 16|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 $228 = (($226) + 4|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = (($226) + 8|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($179) + 16|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = (($232) + 4|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = (($232) + 8|0);
 $237 = Math_fround(HEAPF32[$236>>2]);
 $238 = (($186) + 16|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($238) + 4|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = (($238) + 8|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($193) + 16|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = (($244) + 4|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = (($244) + 8|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = (($200) + 16|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = (($250) + 4|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = (($250) + 8|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = (($207) + 16|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = (($256) + 4|0);
 $259 = Math_fround(HEAPF32[$258>>2]);
 $260 = (($256) + 8|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = (($214) + 16|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 $264 = (($262) + 4|0);
 $265 = Math_fround(HEAPF32[$264>>2]);
 $266 = (($262) + 8|0);
 $267 = Math_fround(HEAPF32[$266>>2]);
 $268 = Math_fround($166 - $194);
 $269 = Math_fround($173 - $201);
 $270 = Math_fround($180 - $208);
 $271 = Math_fround($187 - $215);
 $272 = Math_fround($168 - $196);
 $273 = Math_fround($175 - $203);
 $274 = Math_fround($182 - $210);
 $275 = Math_fround($189 - $217);
 $276 = Math_fround($170 - $198);
 $277 = Math_fround($177 - $205);
 $278 = Math_fround($184 - $212);
 $279 = Math_fround($191 - $219);
 $280 = (($119) + 48|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = (($123) + 48|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = (($127) + 48|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = (($131) + 48|0);
 $287 = Math_fround(HEAPF32[$286>>2]);
 $288 = (($135) + 48|0);
 $289 = Math_fround(HEAPF32[$288>>2]);
 $290 = (($139) + 48|0);
 $291 = Math_fround(HEAPF32[$290>>2]);
 $292 = (($143) + 48|0);
 $293 = Math_fround(HEAPF32[$292>>2]);
 $294 = (($147) + 48|0);
 $295 = Math_fround(HEAPF32[$294>>2]);
 $296 = Math_fround($81 * $281);
 $297 = Math_fround($82 * $283);
 $298 = Math_fround($83 * $285);
 $299 = Math_fround($84 * $287);
 $300 = Math_fround($92 * $289);
 $301 = Math_fround(-$300);
 $302 = Math_fround($93 * $291);
 $303 = Math_fround(-$302);
 $304 = Math_fround($94 * $293);
 $305 = Math_fround(-$304);
 $306 = Math_fround($95 * $295);
 $307 = Math_fround(-$306);
 $308 = Math_fround(HEAPF32[$119>>2]);
 $309 = (($119) + 4|0);
 $310 = Math_fround(HEAPF32[$309>>2]);
 $311 = (($119) + 8|0);
 $312 = Math_fround(HEAPF32[$311>>2]);
 $313 = (($119) + 12|0);
 $314 = Math_fround(HEAPF32[$313>>2]);
 $315 = (($119) + 16|0);
 $316 = Math_fround(HEAPF32[$315>>2]);
 $317 = (($119) + 20|0);
 $318 = Math_fround(HEAPF32[$317>>2]);
 $319 = (($119) + 24|0);
 $320 = Math_fround(HEAPF32[$319>>2]);
 $321 = (($119) + 28|0);
 $322 = Math_fround(HEAPF32[$321>>2]);
 $323 = (($119) + 32|0);
 $324 = Math_fround(HEAPF32[$323>>2]);
 $325 = Math_fround(HEAPF32[$123>>2]);
 $326 = (($123) + 4|0);
 $327 = Math_fround(HEAPF32[$326>>2]);
 $328 = (($123) + 8|0);
 $329 = Math_fround(HEAPF32[$328>>2]);
 $330 = (($123) + 12|0);
 $331 = Math_fround(HEAPF32[$330>>2]);
 $332 = (($123) + 16|0);
 $333 = Math_fround(HEAPF32[$332>>2]);
 $334 = (($123) + 20|0);
 $335 = Math_fround(HEAPF32[$334>>2]);
 $336 = (($123) + 24|0);
 $337 = Math_fround(HEAPF32[$336>>2]);
 $338 = (($123) + 28|0);
 $339 = Math_fround(HEAPF32[$338>>2]);
 $340 = (($123) + 32|0);
 $341 = Math_fround(HEAPF32[$340>>2]);
 $342 = Math_fround(HEAPF32[$127>>2]);
 $343 = (($127) + 4|0);
 $344 = Math_fround(HEAPF32[$343>>2]);
 $345 = (($127) + 8|0);
 $346 = Math_fround(HEAPF32[$345>>2]);
 $347 = (($127) + 12|0);
 $348 = Math_fround(HEAPF32[$347>>2]);
 $349 = (($127) + 16|0);
 $350 = Math_fround(HEAPF32[$349>>2]);
 $351 = (($127) + 20|0);
 $352 = Math_fround(HEAPF32[$351>>2]);
 $353 = (($127) + 24|0);
 $354 = Math_fround(HEAPF32[$353>>2]);
 $355 = (($127) + 28|0);
 $356 = Math_fround(HEAPF32[$355>>2]);
 $357 = (($127) + 32|0);
 $358 = Math_fround(HEAPF32[$357>>2]);
 $359 = Math_fround(HEAPF32[$131>>2]);
 $360 = (($131) + 4|0);
 $361 = Math_fround(HEAPF32[$360>>2]);
 $362 = (($131) + 8|0);
 $363 = Math_fround(HEAPF32[$362>>2]);
 $364 = (($131) + 12|0);
 $365 = Math_fround(HEAPF32[$364>>2]);
 $366 = (($131) + 16|0);
 $367 = Math_fround(HEAPF32[$366>>2]);
 $368 = (($131) + 20|0);
 $369 = Math_fround(HEAPF32[$368>>2]);
 $370 = (($131) + 24|0);
 $371 = Math_fround(HEAPF32[$370>>2]);
 $372 = (($131) + 28|0);
 $373 = Math_fround(HEAPF32[$372>>2]);
 $374 = (($131) + 32|0);
 $375 = Math_fround(HEAPF32[$374>>2]);
 $376 = Math_fround(HEAPF32[$135>>2]);
 $377 = (($135) + 4|0);
 $378 = Math_fround(HEAPF32[$377>>2]);
 $379 = (($135) + 8|0);
 $380 = Math_fround(HEAPF32[$379>>2]);
 $381 = (($135) + 12|0);
 $382 = Math_fround(HEAPF32[$381>>2]);
 $383 = (($135) + 16|0);
 $384 = Math_fround(HEAPF32[$383>>2]);
 $385 = (($135) + 20|0);
 $386 = Math_fround(HEAPF32[$385>>2]);
 $387 = (($135) + 24|0);
 $388 = Math_fround(HEAPF32[$387>>2]);
 $389 = (($135) + 28|0);
 $390 = Math_fround(HEAPF32[$389>>2]);
 $391 = (($135) + 32|0);
 $392 = Math_fround(HEAPF32[$391>>2]);
 $393 = Math_fround(HEAPF32[$139>>2]);
 $394 = (($139) + 4|0);
 $395 = Math_fround(HEAPF32[$394>>2]);
 $396 = (($139) + 8|0);
 $397 = Math_fround(HEAPF32[$396>>2]);
 $398 = (($139) + 12|0);
 $399 = Math_fround(HEAPF32[$398>>2]);
 $400 = (($139) + 16|0);
 $401 = Math_fround(HEAPF32[$400>>2]);
 $402 = (($139) + 20|0);
 $403 = Math_fround(HEAPF32[$402>>2]);
 $404 = (($139) + 24|0);
 $405 = Math_fround(HEAPF32[$404>>2]);
 $406 = (($139) + 28|0);
 $407 = Math_fround(HEAPF32[$406>>2]);
 $408 = (($139) + 32|0);
 $409 = Math_fround(HEAPF32[$408>>2]);
 $410 = Math_fround(HEAPF32[$143>>2]);
 $411 = (($143) + 4|0);
 $412 = Math_fround(HEAPF32[$411>>2]);
 $413 = (($143) + 8|0);
 $414 = Math_fround(HEAPF32[$413>>2]);
 $415 = (($143) + 12|0);
 $416 = Math_fround(HEAPF32[$415>>2]);
 $417 = (($143) + 16|0);
 $418 = Math_fround(HEAPF32[$417>>2]);
 $419 = (($143) + 20|0);
 $420 = Math_fround(HEAPF32[$419>>2]);
 $421 = (($143) + 24|0);
 $422 = Math_fround(HEAPF32[$421>>2]);
 $423 = (($143) + 28|0);
 $424 = Math_fround(HEAPF32[$423>>2]);
 $425 = (($143) + 32|0);
 $426 = Math_fround(HEAPF32[$425>>2]);
 $427 = Math_fround(HEAPF32[$147>>2]);
 $428 = (($147) + 4|0);
 $429 = Math_fround(HEAPF32[$428>>2]);
 $430 = (($147) + 8|0);
 $431 = Math_fround(HEAPF32[$430>>2]);
 $432 = (($147) + 12|0);
 $433 = Math_fround(HEAPF32[$432>>2]);
 $434 = (($147) + 16|0);
 $435 = Math_fround(HEAPF32[$434>>2]);
 $436 = (($147) + 20|0);
 $437 = Math_fround(HEAPF32[$436>>2]);
 $438 = (($147) + 24|0);
 $439 = Math_fround(HEAPF32[$438>>2]);
 $440 = (($147) + 28|0);
 $441 = Math_fround(HEAPF32[$440>>2]);
 $442 = (($147) + 32|0);
 $443 = Math_fround(HEAPF32[$442>>2]);
 $444 = Math_fround($103 * $308);
 $445 = Math_fround($104 * $325);
 $446 = Math_fround($105 * $342);
 $447 = Math_fround($106 * $359);
 $448 = Math_fround($103 * $310);
 $449 = Math_fround($104 * $327);
 $450 = Math_fround($105 * $344);
 $451 = Math_fround($106 * $361);
 $452 = Math_fround($103 * $312);
 $453 = Math_fround($104 * $329);
 $454 = Math_fround($105 * $346);
 $455 = Math_fround($106 * $363);
 $456 = Math_fround($103 * $314);
 $457 = Math_fround($104 * $331);
 $458 = Math_fround($105 * $348);
 $459 = Math_fround($106 * $365);
 $460 = Math_fround($103 * $316);
 $461 = Math_fround($104 * $333);
 $462 = Math_fround($105 * $350);
 $463 = Math_fround($106 * $367);
 $464 = Math_fround($103 * $318);
 $465 = Math_fround($104 * $335);
 $466 = Math_fround($105 * $352);
 $467 = Math_fround($106 * $369);
 $468 = Math_fround($103 * $320);
 $469 = Math_fround($104 * $337);
 $470 = Math_fround($105 * $354);
 $471 = Math_fround($106 * $371);
 $472 = Math_fround($103 * $322);
 $473 = Math_fround($104 * $339);
 $474 = Math_fround($105 * $356);
 $475 = Math_fround($106 * $373);
 $476 = Math_fround($103 * $324);
 $477 = Math_fround($104 * $341);
 $478 = Math_fround($105 * $358);
 $479 = Math_fround($106 * $375);
 $480 = Math_fround($114 * $376);
 $481 = Math_fround($115 * $393);
 $482 = Math_fround($116 * $410);
 $483 = Math_fround($117 * $427);
 $484 = Math_fround($114 * $378);
 $485 = Math_fround($115 * $395);
 $486 = Math_fround($116 * $412);
 $487 = Math_fround($117 * $429);
 $488 = Math_fround($114 * $380);
 $489 = Math_fround($115 * $397);
 $490 = Math_fround($116 * $414);
 $491 = Math_fround($117 * $431);
 $492 = Math_fround($114 * $382);
 $493 = Math_fround($115 * $399);
 $494 = Math_fround($116 * $416);
 $495 = Math_fround($117 * $433);
 $496 = Math_fround($114 * $384);
 $497 = Math_fround($115 * $401);
 $498 = Math_fround($116 * $418);
 $499 = Math_fround($117 * $435);
 $500 = Math_fround($114 * $386);
 $501 = Math_fround($115 * $403);
 $502 = Math_fround($116 * $420);
 $503 = Math_fround($117 * $437);
 $504 = Math_fround($114 * $388);
 $505 = Math_fround($115 * $405);
 $506 = Math_fround($116 * $422);
 $507 = Math_fround($117 * $439);
 $508 = Math_fround($114 * $390);
 $509 = Math_fround($115 * $407);
 $510 = Math_fround($116 * $424);
 $511 = Math_fround($117 * $441);
 $512 = Math_fround($114 * $392);
 $513 = Math_fround($115 * $409);
 $514 = Math_fround($116 * $426);
 $515 = Math_fround($117 * $443);
 $516 = Math_fround($invDtF32 * Math_fround(0.800000011920928955078));
 $517 = (($descs) + 28|0);
 $518 = HEAP32[$517>>2]|0;
 $519 = (($518) + 16|0);
 $520 = Math_fround(HEAPF32[$519>>2]);
 $521 = (($518) + 20|0);
 $522 = Math_fround(HEAPF32[$521>>2]);
 $523 = (($518) + 24|0);
 $524 = Math_fround(HEAPF32[$523>>2]);
 $525 = (($descs) + 84|0);
 $526 = HEAP32[$525>>2]|0;
 $527 = (($526) + 16|0);
 $528 = Math_fround(HEAPF32[$527>>2]);
 $529 = (($526) + 20|0);
 $530 = Math_fround(HEAPF32[$529>>2]);
 $531 = (($526) + 24|0);
 $532 = Math_fround(HEAPF32[$531>>2]);
 $533 = (($descs) + 140|0);
 $534 = HEAP32[$533>>2]|0;
 $535 = (($534) + 16|0);
 $536 = Math_fround(HEAPF32[$535>>2]);
 $537 = (($534) + 20|0);
 $538 = Math_fround(HEAPF32[$537>>2]);
 $539 = (($534) + 24|0);
 $540 = Math_fround(HEAPF32[$539>>2]);
 $541 = (($descs) + 196|0);
 $542 = HEAP32[$541>>2]|0;
 $543 = (($542) + 16|0);
 $544 = Math_fround(HEAPF32[$543>>2]);
 $545 = (($542) + 20|0);
 $546 = Math_fround(HEAPF32[$545>>2]);
 $547 = (($542) + 24|0);
 $548 = Math_fround(HEAPF32[$547>>2]);
 $549 = (($descs) + 32|0);
 $550 = HEAP32[$549>>2]|0;
 $551 = (($550) + 16|0);
 $552 = Math_fround(HEAPF32[$551>>2]);
 $553 = (($550) + 20|0);
 $554 = Math_fround(HEAPF32[$553>>2]);
 $555 = (($550) + 24|0);
 $556 = Math_fround(HEAPF32[$555>>2]);
 $557 = (($descs) + 88|0);
 $558 = HEAP32[$557>>2]|0;
 $559 = (($558) + 16|0);
 $560 = Math_fround(HEAPF32[$559>>2]);
 $561 = (($558) + 20|0);
 $562 = Math_fround(HEAPF32[$561>>2]);
 $563 = (($558) + 24|0);
 $564 = Math_fround(HEAPF32[$563>>2]);
 $565 = (($descs) + 144|0);
 $566 = HEAP32[$565>>2]|0;
 $567 = (($566) + 16|0);
 $568 = Math_fround(HEAPF32[$567>>2]);
 $569 = (($566) + 20|0);
 $570 = Math_fround(HEAPF32[$569>>2]);
 $571 = (($566) + 24|0);
 $572 = Math_fround(HEAPF32[$571>>2]);
 $573 = (($descs) + 200|0);
 $574 = HEAP32[$573>>2]|0;
 $575 = (($574) + 16|0);
 $576 = Math_fround(HEAPF32[$575>>2]);
 $577 = (($574) + 20|0);
 $578 = Math_fround(HEAPF32[$577>>2]);
 $579 = (($574) + 24|0);
 $580 = Math_fround(HEAPF32[$579>>2]);
 $581 = Math_fround(HEAPF32[$518>>2]);
 $582 = (($518) + 4|0);
 $583 = Math_fround(HEAPF32[$582>>2]);
 $584 = (($518) + 8|0);
 $585 = Math_fround(HEAPF32[$584>>2]);
 $586 = (($518) + 12|0);
 $587 = Math_fround(HEAPF32[$586>>2]);
 $588 = Math_fround(HEAPF32[$526>>2]);
 $589 = (($526) + 4|0);
 $590 = Math_fround(HEAPF32[$589>>2]);
 $591 = (($526) + 8|0);
 $592 = Math_fround(HEAPF32[$591>>2]);
 $593 = (($526) + 12|0);
 $594 = Math_fround(HEAPF32[$593>>2]);
 $595 = Math_fround(HEAPF32[$534>>2]);
 $596 = (($534) + 4|0);
 $597 = Math_fround(HEAPF32[$596>>2]);
 $598 = (($534) + 8|0);
 $599 = Math_fround(HEAPF32[$598>>2]);
 $600 = (($534) + 12|0);
 $601 = Math_fround(HEAPF32[$600>>2]);
 $602 = Math_fround(HEAPF32[$542>>2]);
 $603 = (($542) + 4|0);
 $604 = Math_fround(HEAPF32[$603>>2]);
 $605 = (($542) + 8|0);
 $606 = Math_fround(HEAPF32[$605>>2]);
 $607 = (($542) + 12|0);
 $608 = Math_fround(HEAPF32[$607>>2]);
 $609 = Math_fround(HEAPF32[$550>>2]);
 $610 = (($550) + 4|0);
 $611 = Math_fround(HEAPF32[$610>>2]);
 $612 = (($550) + 8|0);
 $613 = Math_fround(HEAPF32[$612>>2]);
 $614 = (($550) + 12|0);
 $615 = Math_fround(HEAPF32[$614>>2]);
 $616 = Math_fround(HEAPF32[$558>>2]);
 $617 = (($558) + 4|0);
 $618 = Math_fround(HEAPF32[$617>>2]);
 $619 = (($558) + 8|0);
 $620 = Math_fround(HEAPF32[$619>>2]);
 $621 = (($558) + 12|0);
 $622 = Math_fround(HEAPF32[$621>>2]);
 $623 = Math_fround(HEAPF32[$566>>2]);
 $624 = (($566) + 4|0);
 $625 = Math_fround(HEAPF32[$624>>2]);
 $626 = (($566) + 8|0);
 $627 = Math_fround(HEAPF32[$626>>2]);
 $628 = (($566) + 12|0);
 $629 = Math_fround(HEAPF32[$628>>2]);
 $630 = Math_fround(HEAPF32[$574>>2]);
 $631 = (($574) + 4|0);
 $632 = Math_fround(HEAPF32[$631>>2]);
 $633 = (($574) + 8|0);
 $634 = Math_fround(HEAPF32[$633>>2]);
 $635 = (($574) + 12|0);
 $636 = Math_fround(HEAPF32[$635>>2]);
 $637 = (($threadContext) + 8596|0);
 $638 = (($threadContext) + 8724|0);
 $639 = (($descs) + 8|0);
 $640 = HEAP32[$639>>2]|0;
 $641 = (($descs) + 64|0);
 $642 = HEAP32[$641>>2]|0;
 $643 = (($descs) + 120|0);
 $644 = HEAP32[$643>>2]|0;
 $645 = (($descs) + 176|0);
 $646 = HEAP32[$645>>2]|0;
 $647 = ($644>>>0)<($646>>>0);
 $648 = $647 ? $646 : $644;
 $649 = ($642>>>0)<($648>>>0);
 $650 = $649 ? $648 : $642;
 $651 = ($640>>>0)<($650>>>0);
 $652 = $651 ? $650 : $640;
 $653 = ($652|0)==(0);
 if ($653) {
  STACKTOP = sp;return;
 }
 $654 = (($1) + 4|0);
 $655 = (($1) + 8|0);
 $656 = (($1) + 12|0);
 $657 = (($2) + 4|0);
 $658 = (($2) + 8|0);
 $659 = (($2) + 12|0);
 $660 = (($5) + 4|0);
 $661 = (($5) + 8|0);
 $662 = (($5) + 12|0);
 $663 = (($4) + 4|0);
 $664 = (($4) + 8|0);
 $665 = (($4) + 12|0);
 $666 = (($6) + 4|0);
 $667 = (($6) + 8|0);
 $668 = (($6) + 12|0);
 $669 = $55 ? 7 : 8;
 $670 = (($8) + 4|0);
 $671 = (($8) + 8|0);
 $672 = (($8) + 12|0);
 $673 = (($11) + 4|0);
 $674 = (($11) + 8|0);
 $675 = (($11) + 12|0);
 $676 = (($10) + 4|0);
 $677 = (($10) + 8|0);
 $678 = (($10) + 12|0);
 $679 = (($13) + 4|0);
 $680 = (($13) + 8|0);
 $681 = (($13) + 12|0);
 $682 = (($15) + 4|0);
 $683 = (($15) + 8|0);
 $684 = (($15) + 12|0);
 $685 = (($14) + 4|0);
 $686 = (($14) + 8|0);
 $687 = (($14) + 12|0);
 $688 = (($17) + 4|0);
 $689 = (($17) + 8|0);
 $690 = (($17) + 12|0);
 $691 = (($16) + 4|0);
 $692 = (($16) + 8|0);
 $693 = (($16) + 12|0);
 $694 = (($19) + 4|0);
 $695 = (($19) + 8|0);
 $696 = (($19) + 12|0);
 $697 = (($18) + 4|0);
 $698 = (($18) + 8|0);
 $699 = (($18) + 12|0);
 $$sum = $57 << 1;
 $700 = Math_fround($587 * $587);
 $701 = Math_fround($700 + Math_fround(-0.5));
 $702 = Math_fround($594 * $594);
 $703 = Math_fround($702 + Math_fround(-0.5));
 $704 = Math_fround($601 * $601);
 $705 = Math_fround($704 + Math_fround(-0.5));
 $706 = Math_fround($608 * $608);
 $707 = Math_fround($706 + Math_fround(-0.5));
 $708 = Math_fround($615 * $615);
 $709 = Math_fround($708 + Math_fround(-0.5));
 $710 = Math_fround($622 * $622);
 $711 = Math_fround($710 + Math_fround(-0.5));
 $712 = Math_fround($629 * $629);
 $713 = Math_fround($712 + Math_fround(-0.5));
 $714 = Math_fround($636 * $636);
 $715 = Math_fround($714 + Math_fround(-0.5));
 $716 = (($21) + 4|0);
 $717 = (($21) + 8|0);
 $718 = (($21) + 12|0);
 $$sum24 = (($57) + 240)|0;
 $$sum8093 = (($57) + 244)|0;
 $$sum8094 = (($57) + 248)|0;
 $$sum8095 = (($57) + 252)|0;
 $$sum25 = (($57) + 256)|0;
 $$sum8096 = (($57) + 260)|0;
 $$sum8097 = (($57) + 264)|0;
 $$sum8098 = (($57) + 268)|0;
 $$sum26 = (($57) + 272)|0;
 $$sum8099 = (($57) + 276)|0;
 $$sum8100 = (($57) + 280)|0;
 $$sum8101 = (($57) + 284)|0;
 $$sum27 = (($57) + 288)|0;
 $$sum8102 = (($57) + 292)|0;
 $$sum8103 = (($57) + 296)|0;
 $$sum8104 = (($57) + 300)|0;
 $$sum28 = (($57) + 304)|0;
 $$sum8105 = (($57) + 308)|0;
 $$sum8106 = (($57) + 312)|0;
 $$sum8107 = (($57) + 316)|0;
 $$sum29 = (($57) + 320)|0;
 $$sum8108 = (($57) + 324)|0;
 $$sum8109 = (($57) + 328)|0;
 $$sum8110 = (($57) + 332)|0;
 $719 = (($23) + 4|0);
 $720 = (($23) + 8|0);
 $721 = (($23) + 12|0);
 $$sum80488049 = $57 | 4;
 $$sum80508051 = $57 | 8;
 $$sum80528053 = $57 | 12;
 $$sum7 = (($57) + 16)|0;
 $$sum8054 = (($57) + 20)|0;
 $$sum8055 = (($57) + 24)|0;
 $$sum8056 = (($57) + 28)|0;
 $$sum8 = (($57) + 32)|0;
 $$sum8057 = (($57) + 36)|0;
 $$sum8058 = (($57) + 40)|0;
 $$sum8059 = (($57) + 44)|0;
 $$sum9 = (($57) + 48)|0;
 $$sum8060 = (($57) + 52)|0;
 $$sum8061 = (($57) + 56)|0;
 $$sum8062 = (($57) + 60)|0;
 $$sum10 = (($57) + 64)|0;
 $$sum8063 = (($57) + 68)|0;
 $$sum8064 = (($57) + 72)|0;
 $$sum8065 = (($57) + 76)|0;
 $$sum11 = (($57) + 80)|0;
 $$sum8066 = (($57) + 84)|0;
 $$sum8067 = (($57) + 88)|0;
 $$sum8068 = (($57) + 92)|0;
 $$sum12 = (($57) + 96)|0;
 $$sum8069 = (($57) + 100)|0;
 $$sum8070 = (($57) + 104)|0;
 $$sum8071 = (($57) + 108)|0;
 $$sum13 = (($57) + 112)|0;
 $$sum8072 = (($57) + 116)|0;
 $$sum8073 = (($57) + 120)|0;
 $$sum8074 = (($57) + 124)|0;
 $$sum14 = (($57) + 128)|0;
 $$sum8075 = (($57) + 132)|0;
 $$sum8076 = (($57) + 136)|0;
 $$sum8077 = (($57) + 140)|0;
 $$sum15 = (($57) + 144)|0;
 $$sum8078 = (($57) + 148)|0;
 $$sum8079 = (($57) + 152)|0;
 $$sum8080 = (($57) + 156)|0;
 $$sum16 = (($57) + 160)|0;
 $$sum8081 = (($57) + 164)|0;
 $$sum8082 = (($57) + 168)|0;
 $$sum8083 = (($57) + 172)|0;
 $$sum17 = (($57) + 176)|0;
 $$sum8084 = (($57) + 180)|0;
 $$sum8085 = (($57) + 184)|0;
 $$sum8086 = (($57) + 188)|0;
 $$sum18 = (($57) + 192)|0;
 $$sum8087 = (($57) + 196)|0;
 $$sum8088 = (($57) + 200)|0;
 $$sum8089 = (($57) + 204)|0;
 $$sum19 = (($57) + 208)|0;
 $$sum8090 = (($57) + 212)|0;
 $$sum8091 = (($57) + 216)|0;
 $$sum8092 = (($57) + 220)|0;
 $$sum20 = (($57) + 224)|0;
 $$sum21 = (($57) + 228)|0;
 $$sum22 = (($57) + 232)|0;
 $$sum23 = (($57) + 236)|0;
 $722 = (($descs) + 172|0);
 $723 = (($descs) + 116|0);
 $724 = (($descs) + 60|0);
 $725 = (($descs) + 4|0);
 $726 = $57 << 1;
 $4181 = 0;$4182 = 0;$4183 = 0;$4184 = 0;$frictionIndex0$08160 = 0;$frictionIndex1$08159 = 0;$frictionIndex2$08158 = 0;$frictionIndex3$08157 = 0;$frictionPatchWritebackAddrIndex0$08164 = 0;$newPatch$0$lcssa$i$i137380048154 = 0;$newPatch$0$lcssa$i$i137780088153 = 0;$newPatch$0$lcssa$i$i138180128152 = 0;$newPatch$0$lcssa$i$i80018155 = 0;$ptr$08165 = $workspace;
 while(1) {
  $727 = HEAP32[$639>>2]|0;
  $728 = ($frictionPatchWritebackAddrIndex0$08164>>>0)>=($727>>>0);
  $729 = HEAP32[$641>>2]|0;
  $730 = ($frictionPatchWritebackAddrIndex0$08164>>>0)>=($729>>>0);
  $731 = HEAP32[$643>>2]|0;
  $732 = ($frictionPatchWritebackAddrIndex0$08164>>>0)>=($731>>>0);
  $733 = HEAP32[$645>>2]|0;
  $734 = ($frictionPatchWritebackAddrIndex0$08164>>>0)>=($733>>>0);
  if ($728) {
   $744 = $frictionIndex0$08160;
  } else {
   $735 = HEAP32[$725>>2]|0;
   $736 = (($735) + ($frictionPatchWritebackAddrIndex0$08164))|0;
   $744 = $736;
  }
  if ($730) {
   $747 = $frictionIndex1$08159;
  } else {
   $737 = HEAP32[$724>>2]|0;
   $738 = (($737) + ($frictionPatchWritebackAddrIndex0$08164))|0;
   $747 = $738;
  }
  if ($732) {
   $750 = $frictionIndex2$08158;
  } else {
   $739 = HEAP32[$723>>2]|0;
   $740 = (($739) + ($frictionPatchWritebackAddrIndex0$08164))|0;
   $750 = $740;
  }
  if ($734) {
   $753 = $frictionIndex3$08157;
  } else {
   $741 = HEAP32[$722>>2]|0;
   $742 = (($741) + ($frictionPatchWritebackAddrIndex0$08164))|0;
   $753 = $742;
  }
  if ($728) {
   $793 = 0;
  } else {
   $743 = ((($threadContext) + ($744<<2)|0) + 8336|0);
   $745 = HEAP32[$743>>2]|0;
   $phitmp = $745&255;
   $793 = $phitmp;
  }
  if ($730) {
   $795 = 0;
  } else {
   $746 = ((($threadContext) + ($747<<2)|0) + 8336|0);
   $748 = HEAP32[$746>>2]|0;
   $phitmp8027 = $748&255;
   $795 = $phitmp8027;
  }
  if ($732) {
   $797 = 0;
  } else {
   $749 = ((($threadContext) + ($750<<2)|0) + 8336|0);
   $751 = HEAP32[$749>>2]|0;
   $phitmp8028 = $751&255;
   $797 = $phitmp8028;
  }
  if ($734) {
   $799 = 0;
  } else {
   $752 = ((($threadContext) + ($753<<2)|0) + 8336|0);
   $754 = HEAP32[$752>>2]|0;
   $phitmp8029 = $754&255;
   $799 = $phitmp8029;
  }
  $755 = ((($threadContext) + ($744<<2)|0) + 8464|0);
  $756 = HEAP32[$755>>2]|0;
  $757 = ((($threadContext) + ($747<<2)|0) + 8464|0);
  $758 = HEAP32[$757>>2]|0;
  $759 = ((($threadContext) + ($750<<2)|0) + 8464|0);
  $760 = HEAP32[$759>>2]|0;
  $761 = ((($threadContext) + ($753<<2)|0) + 8464|0);
  $762 = HEAP32[$761>>2]|0;
  $763 = ((($threadContext) + (($756*12)|0)|0) + 4496|0);
  $764 = HEAP16[$763>>1]|0;
  $765 = $764&65535;
  $766 = ((($threadContext) + (($758*12)|0)|0) + 4496|0);
  $767 = HEAP16[$766>>1]|0;
  $768 = $767&65535;
  $769 = ((($threadContext) + (($760*12)|0)|0) + 4496|0);
  $770 = HEAP16[$769>>1]|0;
  $771 = $770&65535;
  $772 = ((($threadContext) + (($762*12)|0)|0) + 4496|0);
  $773 = HEAP16[$772>>1]|0;
  $774 = $773&65535;
  $775 = ((($threadContext) + ($765<<6)|0) + 444|0);
  $776 = Math_fround(HEAPF32[$775>>2]);
  $777 = ((($threadContext) + ($768<<6)|0) + 444|0);
  $778 = Math_fround(HEAPF32[$777>>2]);
  $779 = ((($threadContext) + ($771<<6)|0) + 444|0);
  $780 = Math_fround(HEAPF32[$779>>2]);
  $781 = ((($threadContext) + ($774<<6)|0) + 444|0);
  $782 = Math_fround(HEAPF32[$781>>2]);
  $783 = Math_fround(-$776);
  $784 = Math_fround(-$778);
  $785 = Math_fround(-$780);
  $786 = Math_fround(-$782);
  $787 = (($ptr$08165) + 144|0);
  $788 = (($ptr$08165) + 4|0);
  HEAP8[$788>>0] = $29;
  $789 = (($ptr$08165) + 5|0);
  HEAP8[$789>>0] = $36;
  $790 = (($ptr$08165) + 6|0);
  HEAP8[$790>>0] = $43;
  $791 = (($ptr$08165) + 7|0);
  HEAP8[$791>>0] = $50;
  $792 = (($ptr$08165) + 8|0);
  HEAP8[$792>>0] = $793;
  $794 = (($ptr$08165) + 9|0);
  HEAP8[$794>>0] = $795;
  $796 = (($ptr$08165) + 10|0);
  HEAP8[$796>>0] = $797;
  $798 = (($ptr$08165) + 11|0);
  HEAP8[$798>>0] = $799;
  $800 = (($ptr$08165) + 64|0);
  HEAPF32[$800>>2] = $296;
  $801 = (($ptr$08165) + 68|0);
  HEAPF32[$801>>2] = $297;
  $802 = (($ptr$08165) + 72|0);
  HEAPF32[$802>>2] = $298;
  $803 = (($ptr$08165) + 76|0);
  HEAPF32[$803>>2] = $299;
  $804 = (($ptr$08165) + 80|0);
  HEAPF32[$804>>2] = $301;
  $805 = (($ptr$08165) + 84|0);
  HEAPF32[$805>>2] = $303;
  $806 = (($ptr$08165) + 88|0);
  HEAPF32[$806>>2] = $305;
  $807 = (($ptr$08165) + 92|0);
  HEAPF32[$807>>2] = $307;
  $808 = (($ptr$08165) + 16|0);
  HEAPF32[$808>>2] = $783;
  $809 = (($ptr$08165) + 20|0);
  HEAPF32[$809>>2] = $784;
  $810 = (($ptr$08165) + 24|0);
  HEAPF32[$810>>2] = $785;
  $811 = (($ptr$08165) + 28|0);
  HEAPF32[$811>>2] = $786;
  $812 = ((($threadContext) + ($765<<6)|0) + 384|0);
  $813 = Math_fround(HEAPF32[$812>>2]);
  $814 = (($812) + 4|0);
  $815 = Math_fround(HEAPF32[$814>>2]);
  $816 = (($812) + 8|0);
  $817 = Math_fround(HEAPF32[$816>>2]);
  $818 = ((($threadContext) + ($768<<6)|0) + 384|0);
  $819 = Math_fround(HEAPF32[$818>>2]);
  $820 = (($818) + 4|0);
  $821 = Math_fround(HEAPF32[$820>>2]);
  $822 = (($818) + 8|0);
  $823 = Math_fround(HEAPF32[$822>>2]);
  $824 = ((($threadContext) + ($771<<6)|0) + 384|0);
  $825 = Math_fround(HEAPF32[$824>>2]);
  $826 = (($824) + 4|0);
  $827 = Math_fround(HEAPF32[$826>>2]);
  $828 = (($824) + 8|0);
  $829 = Math_fround(HEAPF32[$828>>2]);
  $830 = ((($threadContext) + ($774<<6)|0) + 384|0);
  $831 = Math_fround(HEAPF32[$830>>2]);
  $832 = (($830) + 4|0);
  $833 = Math_fround(HEAPF32[$832>>2]);
  $834 = (($830) + 8|0);
  $835 = Math_fround(HEAPF32[$834>>2]);
  $836 = (($ptr$08165) + 96|0);
  HEAPF32[$836>>2] = $813;
  $837 = (($ptr$08165) + 100|0);
  HEAPF32[$837>>2] = $819;
  $838 = (($ptr$08165) + 104|0);
  HEAPF32[$838>>2] = $825;
  $839 = (($ptr$08165) + 108|0);
  HEAPF32[$839>>2] = $831;
  $840 = (($ptr$08165) + 112|0);
  HEAPF32[$840>>2] = $815;
  $841 = (($ptr$08165) + 116|0);
  HEAPF32[$841>>2] = $821;
  $842 = (($ptr$08165) + 120|0);
  HEAPF32[$842>>2] = $827;
  $843 = (($ptr$08165) + 124|0);
  HEAPF32[$843>>2] = $833;
  $844 = (($ptr$08165) + 128|0);
  HEAPF32[$844>>2] = $817;
  $845 = (($ptr$08165) + 132|0);
  HEAPF32[$845>>2] = $823;
  $846 = (($ptr$08165) + 136|0);
  HEAPF32[$846>>2] = $829;
  $847 = (($ptr$08165) + 140|0);
  HEAPF32[$847>>2] = $835;
  $848 = Math_fround($166 * $813);
  $849 = Math_fround($173 * $819);
  $850 = Math_fround($180 * $825);
  $851 = Math_fround($187 * $831);
  $852 = Math_fround($168 * $815);
  $853 = Math_fround($175 * $821);
  $854 = Math_fround($182 * $827);
  $855 = Math_fround($189 * $833);
  $856 = Math_fround($848 + $852);
  $857 = Math_fround($849 + $853);
  $858 = Math_fround($850 + $854);
  $859 = Math_fround($851 + $855);
  $860 = Math_fround($170 * $817);
  $861 = Math_fround($177 * $823);
  $862 = Math_fround($184 * $829);
  $863 = Math_fround($191 * $835);
  $864 = Math_fround($860 + $856);
  $865 = Math_fround($861 + $857);
  $866 = Math_fround($862 + $858);
  $867 = Math_fround($863 + $859);
  $868 = Math_fround($194 * $813);
  $869 = Math_fround($201 * $819);
  $870 = Math_fround($208 * $825);
  $871 = Math_fround($215 * $831);
  $872 = Math_fround($196 * $815);
  $873 = Math_fround($203 * $821);
  $874 = Math_fround($210 * $827);
  $875 = Math_fround($217 * $833);
  $876 = Math_fround($868 + $872);
  $877 = Math_fround($869 + $873);
  $878 = Math_fround($870 + $874);
  $879 = Math_fround($871 + $875);
  $880 = Math_fround($198 * $817);
  $881 = Math_fround($205 * $823);
  $882 = Math_fround($212 * $829);
  $883 = Math_fround($219 * $835);
  $884 = Math_fround($880 + $876);
  $885 = Math_fround($881 + $877);
  $886 = Math_fround($882 + $878);
  $887 = Math_fround($883 + $879);
  $888 = Math_fround($864 - $884);
  $889 = Math_fround($865 - $885);
  $890 = Math_fround($866 - $886);
  $891 = Math_fround($867 - $887);
  $892 = $728&1;
  $893 = $730&1;
  $894 = $893 << 1;
  $895 = $894 | $892;
  $896 = $732&1;
  $897 = $896 << 2;
  $898 = $895 | $897;
  $899 = $734&1;
  $900 = $899 << 3;
  $901 = $898 | $900;
  $902 = ($756|0)==(65535);
  L30: do {
   if ($902) {
    $newPatch$0$lcssa$i$i1381 = 65535;
   } else {
    $newPatch$01$i$i1379 = $756;
    while(1) {
     $903 = ((($threadContext) + (($newPatch$01$i$i1379*12)|0)|0) + 4498|0);
     $904 = HEAP16[$903>>1]|0;
     $905 = ($904<<16>>16)==(0);
     if (!($905)) {
      $newPatch$0$lcssa$i$i1381 = $newPatch$01$i$i1379;
      break L30;
     }
     $906 = ((($threadContext) + (($newPatch$01$i$i1379*12)|0)|0) + 4500|0);
     $907 = HEAP16[$906>>1]|0;
     $908 = $907&65535;
     $909 = ($907<<16>>16)==(-1);
     if ($909) {
      $newPatch$0$lcssa$i$i1381 = $908;
      break;
     } else {
      $newPatch$01$i$i1379 = $908;
     }
    }
   }
  } while(0);
  $910 = ($758|0)==(65535);
  L35: do {
   if ($910) {
    $newPatch$0$lcssa$i$i1377 = 65535;
   } else {
    $newPatch$01$i$i1375 = $758;
    while(1) {
     $911 = ((($threadContext) + (($newPatch$01$i$i1375*12)|0)|0) + 4498|0);
     $912 = HEAP16[$911>>1]|0;
     $913 = ($912<<16>>16)==(0);
     if (!($913)) {
      $newPatch$0$lcssa$i$i1377 = $newPatch$01$i$i1375;
      break L35;
     }
     $914 = ((($threadContext) + (($newPatch$01$i$i1375*12)|0)|0) + 4500|0);
     $915 = HEAP16[$914>>1]|0;
     $916 = $915&65535;
     $917 = ($915<<16>>16)==(-1);
     if ($917) {
      $newPatch$0$lcssa$i$i1377 = $916;
      break;
     } else {
      $newPatch$01$i$i1375 = $916;
     }
    }
   }
  } while(0);
  $918 = ($760|0)==(65535);
  L40: do {
   if ($918) {
    $newPatch$0$lcssa$i$i1373 = 65535;
   } else {
    $newPatch$01$i$i1371 = $760;
    while(1) {
     $919 = ((($threadContext) + (($newPatch$01$i$i1371*12)|0)|0) + 4498|0);
     $920 = HEAP16[$919>>1]|0;
     $921 = ($920<<16>>16)==(0);
     if (!($921)) {
      $newPatch$0$lcssa$i$i1373 = $newPatch$01$i$i1371;
      break L40;
     }
     $922 = ((($threadContext) + (($newPatch$01$i$i1371*12)|0)|0) + 4500|0);
     $923 = HEAP16[$922>>1]|0;
     $924 = $923&65535;
     $925 = ($923<<16>>16)==(-1);
     if ($925) {
      $newPatch$0$lcssa$i$i1373 = $924;
      break;
     } else {
      $newPatch$01$i$i1371 = $924;
     }
    }
   }
  } while(0);
  $926 = ($762|0)==(65535);
  L45: do {
   if ($926) {
    $newPatch$0$lcssa$i$i = 65535;
   } else {
    $newPatch$01$i$i = $762;
    while(1) {
     $927 = ((($threadContext) + (($newPatch$01$i$i*12)|0)|0) + 4498|0);
     $928 = HEAP16[$927>>1]|0;
     $929 = ($928<<16>>16)==(0);
     if (!($929)) {
      $newPatch$0$lcssa$i$i = $newPatch$01$i$i;
      break L45;
     }
     $930 = ((($threadContext) + (($newPatch$01$i$i*12)|0)|0) + 4500|0);
     $931 = HEAP16[$930>>1]|0;
     $932 = $931&65535;
     $933 = ($931<<16>>16)==(-1);
     if ($933) {
      $newPatch$0$lcssa$i$i = $932;
      break;
     } else {
      $newPatch$01$i$i = $932;
     }
    }
   }
  } while(0);
  L50: do {
   if ($728) {
    $4185 = $4184;$974 = 0;$newPatch$0$lcssa$i$i13817997 = $newPatch$0$lcssa$i$i1381;$newPatch$0$lcssa$i$i13818011 = $newPatch$0$lcssa$i$i138180128152;
   } else {
    $934 = ($newPatch$0$lcssa$i$i1381|0)==(65535);
    if ($934) {
     $4185 = 0;$974 = 1;$newPatch$0$lcssa$i$i13817997 = 65535;$newPatch$0$lcssa$i$i13818011 = 65535;
    } else {
     $newContact$02$i1366 = 1;$newPatch$01$i1367 = $newPatch$0$lcssa$i$i1381;
     while(1) {
      $935 = ((($threadContext) + (($newPatch$01$i1367*12)|0)|0) + 4498|0);
      $936 = HEAP16[$935>>1]|0;
      $937 = $936&65535;
      $938 = ($newContact$02$i1366|0)==($937|0);
      if (!($938)) {
       $4185 = 0;$974 = $newContact$02$i1366;$newPatch$0$lcssa$i$i13817997 = $newPatch$01$i1367;$newPatch$0$lcssa$i$i13818011 = $newPatch$0$lcssa$i$i1381;
       break L50;
      }
      $939 = ((($threadContext) + (($newPatch$01$i1367*12)|0)|0) + 4500|0);
      $940 = HEAP16[$939>>1]|0;
      $941 = $940&65535;
      $942 = ($940<<16>>16)==(-1);
      if ($942) {
       $4185 = 0;$974 = 0;$newPatch$0$lcssa$i$i13817997 = $941;$newPatch$0$lcssa$i$i13818011 = $newPatch$0$lcssa$i$i1381;
       break;
      } else {
       $newContact$02$i1366 = 0;$newPatch$01$i1367 = $941;
      }
     }
    }
   }
  } while(0);
  L56: do {
   if ($730) {
    $4186 = $4183;$981 = 0;$newPatch$0$lcssa$i$i13777994 = $newPatch$0$lcssa$i$i1377;$newPatch$0$lcssa$i$i13778007 = $newPatch$0$lcssa$i$i137780088153;
   } else {
    $943 = ($newPatch$0$lcssa$i$i1377|0)==(65535);
    if ($943) {
     $4186 = 0;$981 = 1;$newPatch$0$lcssa$i$i13777994 = 65535;$newPatch$0$lcssa$i$i13778007 = 65535;
    } else {
     $newContact$02$i1360 = 1;$newPatch$01$i1361 = $newPatch$0$lcssa$i$i1377;
     while(1) {
      $944 = ((($threadContext) + (($newPatch$01$i1361*12)|0)|0) + 4498|0);
      $945 = HEAP16[$944>>1]|0;
      $946 = $945&65535;
      $947 = ($newContact$02$i1360|0)==($946|0);
      if (!($947)) {
       $4186 = 0;$981 = $newContact$02$i1360;$newPatch$0$lcssa$i$i13777994 = $newPatch$01$i1361;$newPatch$0$lcssa$i$i13778007 = $newPatch$0$lcssa$i$i1377;
       break L56;
      }
      $948 = ((($threadContext) + (($newPatch$01$i1361*12)|0)|0) + 4500|0);
      $949 = HEAP16[$948>>1]|0;
      $950 = $949&65535;
      $951 = ($949<<16>>16)==(-1);
      if ($951) {
       $4186 = 0;$981 = 0;$newPatch$0$lcssa$i$i13777994 = $950;$newPatch$0$lcssa$i$i13778007 = $newPatch$0$lcssa$i$i1377;
       break;
      } else {
       $newContact$02$i1360 = 0;$newPatch$01$i1361 = $950;
      }
     }
    }
   }
  } while(0);
  L62: do {
   if ($732) {
    $4187 = $4182;$990 = 0;$newPatch$0$lcssa$i$i13737991 = $newPatch$0$lcssa$i$i1373;$newPatch$0$lcssa$i$i13738003 = $newPatch$0$lcssa$i$i137380048154;
   } else {
    $952 = ($newPatch$0$lcssa$i$i1373|0)==(65535);
    if ($952) {
     $4187 = 0;$990 = 1;$newPatch$0$lcssa$i$i13737991 = 65535;$newPatch$0$lcssa$i$i13738003 = 65535;
    } else {
     $newContact$02$i1354 = 1;$newPatch$01$i1355 = $newPatch$0$lcssa$i$i1373;
     while(1) {
      $953 = ((($threadContext) + (($newPatch$01$i1355*12)|0)|0) + 4498|0);
      $954 = HEAP16[$953>>1]|0;
      $955 = $954&65535;
      $956 = ($newContact$02$i1354|0)==($955|0);
      if (!($956)) {
       $4187 = 0;$990 = $newContact$02$i1354;$newPatch$0$lcssa$i$i13737991 = $newPatch$01$i1355;$newPatch$0$lcssa$i$i13738003 = $newPatch$0$lcssa$i$i1373;
       break L62;
      }
      $957 = ((($threadContext) + (($newPatch$01$i1355*12)|0)|0) + 4500|0);
      $958 = HEAP16[$957>>1]|0;
      $959 = $958&65535;
      $960 = ($958<<16>>16)==(-1);
      if ($960) {
       $4187 = 0;$990 = 0;$newPatch$0$lcssa$i$i13737991 = $959;$newPatch$0$lcssa$i$i13738003 = $newPatch$0$lcssa$i$i1373;
       break;
      } else {
       $newContact$02$i1354 = 0;$newPatch$01$i1355 = $959;
      }
     }
    }
   }
  } while(0);
  L68: do {
   if ($734) {
    $4188 = $4181;$999 = 0;$newPatch$0$lcssa$i$i7989 = $newPatch$0$lcssa$i$i;$newPatch$0$lcssa$i$i8000 = $newPatch$0$lcssa$i$i80018155;
   } else {
    $961 = ($newPatch$0$lcssa$i$i|0)==(65535);
    if ($961) {
     $4188 = 0;$999 = 1;$newPatch$0$lcssa$i$i7989 = 65535;$newPatch$0$lcssa$i$i8000 = 65535;
    } else {
     $newContact$02$i1348 = 1;$newPatch$01$i1349 = $newPatch$0$lcssa$i$i;
     while(1) {
      $962 = ((($threadContext) + (($newPatch$01$i1349*12)|0)|0) + 4498|0);
      $963 = HEAP16[$962>>1]|0;
      $964 = $963&65535;
      $965 = ($newContact$02$i1348|0)==($964|0);
      if (!($965)) {
       $4188 = 0;$999 = $newContact$02$i1348;$newPatch$0$lcssa$i$i7989 = $newPatch$01$i1349;$newPatch$0$lcssa$i$i8000 = $newPatch$0$lcssa$i$i;
       break L68;
      }
      $966 = ((($threadContext) + (($newPatch$01$i1349*12)|0)|0) + 4500|0);
      $967 = HEAP16[$966>>1]|0;
      $968 = $967&65535;
      $969 = ($967<<16>>16)==(-1);
      if ($969) {
       $4188 = 0;$999 = 0;$newPatch$0$lcssa$i$i7989 = $968;$newPatch$0$lcssa$i$i8000 = $newPatch$0$lcssa$i$i;
       break;
      } else {
       $newContact$02$i1348 = 0;$newPatch$01$i1349 = $968;
      }
     }
    }
   }
  } while(0);
  $970 = ($newPatch$0$lcssa$i$i13817997|0)==(65535);
  $or$cond = $728 | $970;
  if ($or$cond) {
   $976 = 1;
  } else {
   $971 = ((($threadContext) + (($newPatch$0$lcssa$i$i13817997*12)|0)|0) + 4498|0);
   $972 = HEAP16[$971>>1]|0;
   $973 = $972&65535;
   $phitmp8030 = ($974>>>0)>=($973>>>0);
   $976 = $phitmp8030;
  }
  $975 = $976&1;
  $977 = ($newPatch$0$lcssa$i$i13777994|0)==(65535);
  $or$cond8113 = $730 | $977;
  if ($or$cond8113) {
   $983 = 1;
  } else {
   $978 = ((($threadContext) + (($newPatch$0$lcssa$i$i13777994*12)|0)|0) + 4498|0);
   $979 = HEAP16[$978>>1]|0;
   $980 = $979&65535;
   $phitmp8031 = ($981>>>0)>=($980>>>0);
   $983 = $phitmp8031;
  }
  $982 = $983&1;
  $984 = $982 << 1;
  $985 = $984 | $975;
  $986 = ($newPatch$0$lcssa$i$i13737991|0)==(65535);
  $or$cond8114 = $732 | $986;
  if ($or$cond8114) {
   $992 = 1;
  } else {
   $987 = ((($threadContext) + (($newPatch$0$lcssa$i$i13737991*12)|0)|0) + 4498|0);
   $988 = HEAP16[$987>>1]|0;
   $989 = $988&65535;
   $phitmp8032 = ($990>>>0)>=($989>>>0);
   $992 = $phitmp8032;
  }
  $991 = $992&1;
  $993 = $991 << 2;
  $994 = $985 | $993;
  $995 = ($newPatch$0$lcssa$i$i7989|0)==(65535);
  $or$cond8115 = $734 | $995;
  if ($or$cond8115) {
   $1001 = 1;
  } else {
   $996 = ((($threadContext) + (($newPatch$0$lcssa$i$i7989*12)|0)|0) + 4498|0);
   $997 = HEAP16[$996>>1]|0;
   $998 = $997&65535;
   $phitmp8033 = ($999>>>0)>=($998>>>0);
   $1001 = $phitmp8033;
  }
  $1000 = $1001&1;
  $1002 = $1000 << 3;
  $1003 = $994 | $1002;
  $notlhs8038 = $776 > Math_fround(-0.0);
  $notlhs8040 = $778 > Math_fround(-0.0);
  $notlhs8043 = $780 > Math_fround(-0.0);
  $notlhs8046 = $782 > Math_fround(-0.0);
  $$ph8119 = $4185;$$ph8120 = $4186;$$ph8121 = $4187;$$ph8122 = $4188;$$ph8123 = $974;$$ph8124 = $981;$$ph8125 = $990;$$ph8126 = $999;$contactCount$0$ph = 0;$finished$0$ph = $901;$newFinished$0$ph = $1003;$newPatch$0$lcssa$i$i13737992$ph = $newPatch$0$lcssa$i$i13737991;$newPatch$0$lcssa$i$i13738005$ph = $newPatch$0$lcssa$i$i13738003;$newPatch$0$lcssa$i$i13777995$ph = $newPatch$0$lcssa$i$i13777994;$newPatch$0$lcssa$i$i13778009$ph = $newPatch$0$lcssa$i$i13778007;$newPatch$0$lcssa$i$i13817998$ph = $newPatch$0$lcssa$i$i13817997;$newPatch$0$lcssa$i$i13818013$ph = $newPatch$0$lcssa$i$i13818011;$newPatch$0$lcssa$i$i7990$ph = $newPatch$0$lcssa$i$i7989;$newPatch$0$lcssa$i$i8002$ph = $newPatch$0$lcssa$i$i8000;$p$0$ph = $787;
  L86: while(1) {
   $1004 = ((($threadContext) + (($newPatch$0$lcssa$i$i8002$ph*12)|0)|0) + 4496|0);
   $1015 = $$ph8119;$1020 = $$ph8120;$1025 = $$ph8121;$1592 = $$ph8123;$1614 = $$ph8124;$1637 = $$ph8125;$contactCount$0 = $contactCount$0$ph;$finished$0 = $finished$0$ph;$newFinished$0 = $newFinished$0$ph;$newPatch$0$lcssa$i$i13737992 = $newPatch$0$lcssa$i$i13737992$ph;$newPatch$0$lcssa$i$i13738005 = $newPatch$0$lcssa$i$i13738005$ph;$newPatch$0$lcssa$i$i13777995 = $newPatch$0$lcssa$i$i13777995$ph;$newPatch$0$lcssa$i$i13778009 = $newPatch$0$lcssa$i$i13778009$ph;$newPatch$0$lcssa$i$i13817998 = $newPatch$0$lcssa$i$i13817998$ph;$newPatch$0$lcssa$i$i13818013 = $newPatch$0$lcssa$i$i13818013$ph;$p$0 = $p$0$ph;
   while(1) {
    $1005 = ($finished$0|0)==(15);
    if ($1005) {
     break L86;
    }
    $1006 = (($contactCount$0) + 1)|0;
    $1007 = (($p$0) + 384|0);
    $1008 = (($p$0) + 512|0);
    $1009 = (($p$0) + 640|0);
    $1010 = (($p$0) + ($56)|0);
    $1011 = ((($threadContext) + (($newPatch$0$lcssa$i$i13818013*12)|0)|0) + 4496|0);
    $1012 = HEAP16[$1011>>1]|0;
    $1013 = $1012&65535;
    $1014 = (($1013) + ($1015))|0;
    $1016 = ((($threadContext) + (($newPatch$0$lcssa$i$i13778009*12)|0)|0) + 4496|0);
    $1017 = HEAP16[$1016>>1]|0;
    $1018 = $1017&65535;
    $1019 = (($1018) + ($1020))|0;
    $1021 = ((($threadContext) + (($newPatch$0$lcssa$i$i13738005*12)|0)|0) + 4496|0);
    $1022 = HEAP16[$1021>>1]|0;
    $1023 = $1022&65535;
    $1024 = (($1023) + ($1025))|0;
    $1026 = HEAP16[$1004>>1]|0;
    $1027 = $1026&65535;
    $1028 = (($1027) + ($$ph8122))|0;
    $1029 = ((($threadContext) + ($1014<<6)|0) + 400|0);
    $1030 = Math_fround(HEAPF32[$1029>>2]);
    $1031 = (($1029) + 4|0);
    $1032 = Math_fround(HEAPF32[$1031>>2]);
    $1033 = (($1029) + 8|0);
    $1034 = Math_fround(HEAPF32[$1033>>2]);
    $1035 = ((($threadContext) + ($1019<<6)|0) + 400|0);
    $1036 = Math_fround(HEAPF32[$1035>>2]);
    $1037 = (($1035) + 4|0);
    $1038 = Math_fround(HEAPF32[$1037>>2]);
    $1039 = (($1035) + 8|0);
    $1040 = Math_fround(HEAPF32[$1039>>2]);
    $1041 = ((($threadContext) + ($1024<<6)|0) + 400|0);
    $1042 = Math_fround(HEAPF32[$1041>>2]);
    $1043 = (($1041) + 4|0);
    $1044 = Math_fround(HEAPF32[$1043>>2]);
    $1045 = (($1041) + 8|0);
    $1046 = Math_fround(HEAPF32[$1045>>2]);
    $1047 = ((($threadContext) + ($1028<<6)|0) + 400|0);
    $1048 = Math_fround(HEAPF32[$1047>>2]);
    $1049 = (($1047) + 4|0);
    $1050 = Math_fround(HEAPF32[$1049>>2]);
    $1051 = (($1047) + 8|0);
    $1052 = Math_fround(HEAPF32[$1051>>2]);
    $1053 = ((($threadContext) + ($1014<<6)|0) + 416|0);
    $1054 = Math_fround(HEAPF32[$1053>>2]);
    $1055 = (($1053) + 4|0);
    $1056 = Math_fround(HEAPF32[$1055>>2]);
    $1057 = (($1053) + 8|0);
    $1058 = Math_fround(HEAPF32[$1057>>2]);
    $1059 = ((($threadContext) + ($1019<<6)|0) + 416|0);
    $1060 = Math_fround(HEAPF32[$1059>>2]);
    $1061 = (($1059) + 4|0);
    $1062 = Math_fround(HEAPF32[$1061>>2]);
    $1063 = (($1059) + 8|0);
    $1064 = Math_fround(HEAPF32[$1063>>2]);
    $1065 = ((($threadContext) + ($1024<<6)|0) + 416|0);
    $1066 = Math_fround(HEAPF32[$1065>>2]);
    $1067 = (($1065) + 4|0);
    $1068 = Math_fround(HEAPF32[$1067>>2]);
    $1069 = (($1065) + 8|0);
    $1070 = Math_fround(HEAPF32[$1069>>2]);
    $1071 = ((($threadContext) + ($1028<<6)|0) + 416|0);
    $1072 = Math_fround(HEAPF32[$1071>>2]);
    $1073 = (($1071) + 4|0);
    $1074 = Math_fround(HEAPF32[$1073>>2]);
    $1075 = (($1071) + 8|0);
    $1076 = Math_fround(HEAPF32[$1075>>2]);
    $1077 = ((($threadContext) + ($1014<<6)|0) + 396|0);
    $1078 = Math_fround(HEAPF32[$1077>>2]);
    $1079 = ((($threadContext) + ($1019<<6)|0) + 396|0);
    $1080 = Math_fround(HEAPF32[$1079>>2]);
    $1081 = ((($threadContext) + ($1024<<6)|0) + 396|0);
    $1082 = Math_fround(HEAPF32[$1081>>2]);
    $1083 = ((($threadContext) + ($1028<<6)|0) + 396|0);
    $1084 = Math_fround(HEAPF32[$1083>>2]);
    $1085 = ((($threadContext) + ($1014<<6)|0) + 412|0);
    $1086 = Math_fround(HEAPF32[$1085>>2]);
    $1087 = ((($threadContext) + ($1019<<6)|0) + 412|0);
    $1088 = Math_fround(HEAPF32[$1087>>2]);
    $1089 = ((($threadContext) + ($1024<<6)|0) + 412|0);
    $1090 = Math_fround(HEAPF32[$1089>>2]);
    $1091 = ((($threadContext) + ($1028<<6)|0) + 412|0);
    $1092 = Math_fround(HEAPF32[$1091>>2]);
    $1093 = Math_fround($817 * $1058);
    $1094 = Math_fround($823 * $1064);
    $1095 = Math_fround($829 * $1070);
    $1096 = Math_fround($835 * $1076);
    $1097 = Math_fround($815 * $1056);
    $1098 = Math_fround($821 * $1062);
    $1099 = Math_fround($827 * $1068);
    $1100 = Math_fround($833 * $1074);
    $1101 = Math_fround($1097 + $1093);
    $1102 = Math_fround($1098 + $1094);
    $1103 = Math_fround($1099 + $1095);
    $1104 = Math_fround($1100 + $1096);
    $1105 = Math_fround($813 * $1054);
    $1106 = Math_fround($819 * $1060);
    $1107 = Math_fround($825 * $1066);
    $1108 = Math_fround($831 * $1072);
    $1109 = Math_fround($1105 + $1101);
    $1110 = Math_fround($1106 + $1102);
    $1111 = Math_fround($1107 + $1103);
    $1112 = Math_fround($1108 + $1104);
    $1113 = Math_fround($1030 - $520);
    $1114 = Math_fround($1036 - $528);
    $1115 = Math_fround($1042 - $536);
    $1116 = Math_fround($1048 - $544);
    $1117 = Math_fround($1032 - $522);
    $1118 = Math_fround($1038 - $530);
    $1119 = Math_fround($1044 - $538);
    $1120 = Math_fround($1050 - $546);
    $1121 = Math_fround($1034 - $524);
    $1122 = Math_fround($1040 - $532);
    $1123 = Math_fround($1046 - $540);
    $1124 = Math_fround($1052 - $548);
    $1125 = Math_fround($1030 - $552);
    $1126 = Math_fround($1036 - $560);
    $1127 = Math_fround($1042 - $568);
    $1128 = Math_fround($1048 - $576);
    $1129 = Math_fround($1032 - $554);
    $1130 = Math_fround($1038 - $562);
    $1131 = Math_fround($1044 - $570);
    $1132 = Math_fround($1050 - $578);
    $1133 = Math_fround($1034 - $556);
    $1134 = Math_fround($1040 - $564);
    $1135 = Math_fround($1046 - $572);
    $1136 = Math_fround($1052 - $580);
    $1137 = Math_fround($817 * $1117);
    $1138 = Math_fround($823 * $1118);
    $1139 = Math_fround($829 * $1119);
    $1140 = Math_fround($835 * $1120);
    $1141 = Math_fround($815 * $1121);
    $1142 = Math_fround($821 * $1122);
    $1143 = Math_fround($827 * $1123);
    $1144 = Math_fround($833 * $1124);
    $1145 = Math_fround($1137 - $1141);
    $1146 = Math_fround($1138 - $1142);
    $1147 = Math_fround($1139 - $1143);
    $1148 = Math_fround($1140 - $1144);
    $1149 = Math_fround($813 * $1121);
    $1150 = Math_fround($819 * $1122);
    $1151 = Math_fround($825 * $1123);
    $1152 = Math_fround($831 * $1124);
    $1153 = Math_fround($817 * $1113);
    $1154 = Math_fround($823 * $1114);
    $1155 = Math_fround($829 * $1115);
    $1156 = Math_fround($835 * $1116);
    $1157 = Math_fround($1149 - $1153);
    $1158 = Math_fround($1150 - $1154);
    $1159 = Math_fround($1151 - $1155);
    $1160 = Math_fround($1152 - $1156);
    $1161 = Math_fround($815 * $1113);
    $1162 = Math_fround($821 * $1114);
    $1163 = Math_fround($827 * $1115);
    $1164 = Math_fround($833 * $1116);
    $1165 = Math_fround($813 * $1117);
    $1166 = Math_fround($819 * $1118);
    $1167 = Math_fround($825 * $1119);
    $1168 = Math_fround($831 * $1120);
    $1169 = Math_fround($1161 - $1165);
    $1170 = Math_fround($1162 - $1166);
    $1171 = Math_fround($1163 - $1167);
    $1172 = Math_fround($1164 - $1168);
    $1173 = Math_fround($444 * $1145);
    $1174 = Math_fround($445 * $1146);
    $1175 = Math_fround($446 * $1147);
    $1176 = Math_fround($447 * $1148);
    $1177 = Math_fround($456 * $1145);
    $1178 = Math_fround($457 * $1146);
    $1179 = Math_fround($458 * $1147);
    $1180 = Math_fround($459 * $1148);
    $1181 = Math_fround($468 * $1145);
    $1182 = Math_fround($469 * $1146);
    $1183 = Math_fround($470 * $1147);
    $1184 = Math_fround($471 * $1148);
    $1185 = Math_fround($448 * $1157);
    $1186 = Math_fround($449 * $1158);
    $1187 = Math_fround($450 * $1159);
    $1188 = Math_fround($451 * $1160);
    $1189 = Math_fround($1185 + $1173);
    $1190 = Math_fround($1186 + $1174);
    $1191 = Math_fround($1187 + $1175);
    $1192 = Math_fround($1188 + $1176);
    $1193 = Math_fround($460 * $1157);
    $1194 = Math_fround($461 * $1158);
    $1195 = Math_fround($462 * $1159);
    $1196 = Math_fround($463 * $1160);
    $1197 = Math_fround($1193 + $1177);
    $1198 = Math_fround($1194 + $1178);
    $1199 = Math_fround($1195 + $1179);
    $1200 = Math_fround($1196 + $1180);
    $1201 = Math_fround($472 * $1157);
    $1202 = Math_fround($473 * $1158);
    $1203 = Math_fround($474 * $1159);
    $1204 = Math_fround($475 * $1160);
    $1205 = Math_fround($1201 + $1181);
    $1206 = Math_fround($1202 + $1182);
    $1207 = Math_fround($1203 + $1183);
    $1208 = Math_fround($1204 + $1184);
    $1209 = Math_fround($452 * $1169);
    $1210 = Math_fround($453 * $1170);
    $1211 = Math_fround($454 * $1171);
    $1212 = Math_fround($455 * $1172);
    $1213 = Math_fround($1209 + $1189);
    $1214 = Math_fround($1210 + $1190);
    $1215 = Math_fround($1211 + $1191);
    $1216 = Math_fround($1212 + $1192);
    $1217 = Math_fround($464 * $1169);
    $1218 = Math_fround($465 * $1170);
    $1219 = Math_fround($466 * $1171);
    $1220 = Math_fround($467 * $1172);
    $1221 = Math_fround($1217 + $1197);
    $1222 = Math_fround($1218 + $1198);
    $1223 = Math_fround($1219 + $1199);
    $1224 = Math_fround($1220 + $1200);
    $1225 = Math_fround($476 * $1169);
    $1226 = Math_fround($477 * $1170);
    $1227 = Math_fround($478 * $1171);
    $1228 = Math_fround($479 * $1172);
    $1229 = Math_fround($1225 + $1205);
    $1230 = Math_fround($1226 + $1206);
    $1231 = Math_fround($1227 + $1207);
    $1232 = Math_fround($1228 + $1208);
    $1233 = Math_fround($1145 * $1213);
    $1234 = Math_fround($1146 * $1214);
    $1235 = Math_fround($1147 * $1215);
    $1236 = Math_fround($1148 * $1216);
    $1237 = Math_fround($1157 * $1221);
    $1238 = Math_fround($1158 * $1222);
    $1239 = Math_fround($1159 * $1223);
    $1240 = Math_fround($1160 * $1224);
    $1241 = Math_fround($1237 + $1233);
    $1242 = Math_fround($1238 + $1234);
    $1243 = Math_fround($1239 + $1235);
    $1244 = Math_fround($1240 + $1236);
    $1245 = Math_fround($1169 * $1229);
    $1246 = Math_fround($1170 * $1230);
    $1247 = Math_fround($1171 * $1231);
    $1248 = Math_fround($1172 * $1232);
    $1249 = Math_fround($1245 + $1241);
    $1250 = Math_fround($1246 + $1242);
    $1251 = Math_fround($1247 + $1243);
    $1252 = Math_fround($1248 + $1244);
    $1253 = Math_fround($221 * $1145);
    $1254 = Math_fround($227 * $1146);
    $1255 = Math_fround($233 * $1147);
    $1256 = Math_fround($239 * $1148);
    $1257 = Math_fround($223 * $1157);
    $1258 = Math_fround($229 * $1158);
    $1259 = Math_fround($235 * $1159);
    $1260 = Math_fround($241 * $1160);
    $1261 = Math_fround($1257 + $1253);
    $1262 = Math_fround($1258 + $1254);
    $1263 = Math_fround($1259 + $1255);
    $1264 = Math_fround($1260 + $1256);
    $1265 = Math_fround($225 * $1169);
    $1266 = Math_fround($231 * $1170);
    $1267 = Math_fround($237 * $1171);
    $1268 = Math_fround($243 * $1172);
    $1269 = Math_fround($1265 + $1261);
    $1270 = Math_fround($1266 + $1262);
    $1271 = Math_fround($1267 + $1263);
    $1272 = Math_fround($1268 + $1264);
    $1273 = Math_fround($296 + $1249);
    $1274 = Math_fround($297 + $1250);
    $1275 = Math_fround($298 + $1251);
    $1276 = Math_fround($299 + $1252);
    $1277 = Math_fround($888 + $1269);
    $1278 = Math_fround($889 + $1270);
    $1279 = Math_fround($890 + $1271);
    $1280 = Math_fround($891 + $1272);
    if ($55) {
     $1281 = Math_fround($817 * $1129);
     $1282 = Math_fround($823 * $1130);
     $1283 = Math_fround($829 * $1131);
     $1284 = Math_fround($835 * $1132);
     $1285 = Math_fround($815 * $1133);
     $1286 = Math_fround($821 * $1134);
     $1287 = Math_fround($827 * $1135);
     $1288 = Math_fround($833 * $1136);
     $1289 = Math_fround($1281 - $1285);
     $1290 = Math_fround($1282 - $1286);
     $1291 = Math_fround($1283 - $1287);
     $1292 = Math_fround($1284 - $1288);
     $1293 = Math_fround($813 * $1133);
     $1294 = Math_fround($819 * $1134);
     $1295 = Math_fround($825 * $1135);
     $1296 = Math_fround($831 * $1136);
     $1297 = Math_fround($817 * $1125);
     $1298 = Math_fround($823 * $1126);
     $1299 = Math_fround($829 * $1127);
     $1300 = Math_fround($835 * $1128);
     $1301 = Math_fround($1293 - $1297);
     $1302 = Math_fround($1294 - $1298);
     $1303 = Math_fround($1295 - $1299);
     $1304 = Math_fround($1296 - $1300);
     $1305 = Math_fround($815 * $1125);
     $1306 = Math_fround($821 * $1126);
     $1307 = Math_fround($827 * $1127);
     $1308 = Math_fround($833 * $1128);
     $1309 = Math_fround($813 * $1129);
     $1310 = Math_fround($819 * $1130);
     $1311 = Math_fround($825 * $1131);
     $1312 = Math_fround($831 * $1132);
     $1313 = Math_fround($1305 - $1309);
     $1314 = Math_fround($1306 - $1310);
     $1315 = Math_fround($1307 - $1311);
     $1316 = Math_fround($1308 - $1312);
     $1317 = Math_fround($480 * $1289);
     $1318 = Math_fround($481 * $1290);
     $1319 = Math_fround($482 * $1291);
     $1320 = Math_fround($483 * $1292);
     $1321 = Math_fround($492 * $1289);
     $1322 = Math_fround($493 * $1290);
     $1323 = Math_fround($494 * $1291);
     $1324 = Math_fround($495 * $1292);
     $1325 = Math_fround($504 * $1289);
     $1326 = Math_fround($505 * $1290);
     $1327 = Math_fround($506 * $1291);
     $1328 = Math_fround($507 * $1292);
     $1329 = Math_fround($484 * $1301);
     $1330 = Math_fround($485 * $1302);
     $1331 = Math_fround($486 * $1303);
     $1332 = Math_fround($487 * $1304);
     $1333 = Math_fround($1329 + $1317);
     $1334 = Math_fround($1330 + $1318);
     $1335 = Math_fround($1331 + $1319);
     $1336 = Math_fround($1332 + $1320);
     $1337 = Math_fround($496 * $1301);
     $1338 = Math_fround($497 * $1302);
     $1339 = Math_fround($498 * $1303);
     $1340 = Math_fround($499 * $1304);
     $1341 = Math_fround($1337 + $1321);
     $1342 = Math_fround($1338 + $1322);
     $1343 = Math_fround($1339 + $1323);
     $1344 = Math_fround($1340 + $1324);
     $1345 = Math_fround($508 * $1301);
     $1346 = Math_fround($509 * $1302);
     $1347 = Math_fround($510 * $1303);
     $1348 = Math_fround($511 * $1304);
     $1349 = Math_fround($1345 + $1325);
     $1350 = Math_fround($1346 + $1326);
     $1351 = Math_fround($1347 + $1327);
     $1352 = Math_fround($1348 + $1328);
     $1353 = Math_fround($488 * $1313);
     $1354 = Math_fround($489 * $1314);
     $1355 = Math_fround($490 * $1315);
     $1356 = Math_fround($491 * $1316);
     $1357 = Math_fround($1353 + $1333);
     $1358 = Math_fround($1354 + $1334);
     $1359 = Math_fround($1355 + $1335);
     $1360 = Math_fround($1356 + $1336);
     $1361 = Math_fround($500 * $1313);
     $1362 = Math_fround($501 * $1314);
     $1363 = Math_fround($502 * $1315);
     $1364 = Math_fround($503 * $1316);
     $1365 = Math_fround($1361 + $1341);
     $1366 = Math_fround($1362 + $1342);
     $1367 = Math_fround($1363 + $1343);
     $1368 = Math_fround($1364 + $1344);
     $1369 = Math_fround($512 * $1313);
     $1370 = Math_fround($513 * $1314);
     $1371 = Math_fround($514 * $1315);
     $1372 = Math_fround($515 * $1316);
     $1373 = Math_fround($1369 + $1349);
     $1374 = Math_fround($1370 + $1350);
     $1375 = Math_fround($1371 + $1351);
     $1376 = Math_fround($1372 + $1352);
     $1377 = Math_fround($1289 * $1357);
     $1378 = Math_fround($1290 * $1358);
     $1379 = Math_fround($1291 * $1359);
     $1380 = Math_fround($1292 * $1360);
     $1381 = Math_fround($1301 * $1365);
     $1382 = Math_fround($1302 * $1366);
     $1383 = Math_fround($1303 * $1367);
     $1384 = Math_fround($1304 * $1368);
     $1385 = Math_fround($1381 + $1377);
     $1386 = Math_fround($1382 + $1378);
     $1387 = Math_fround($1383 + $1379);
     $1388 = Math_fround($1384 + $1380);
     $1389 = Math_fround($1313 * $1373);
     $1390 = Math_fround($1314 * $1374);
     $1391 = Math_fround($1315 * $1375);
     $1392 = Math_fround($1316 * $1376);
     $1393 = Math_fround($1389 + $1385);
     $1394 = Math_fround($1390 + $1386);
     $1395 = Math_fround($1391 + $1387);
     $1396 = Math_fround($1392 + $1388);
     $1397 = Math_fround($245 * $1289);
     $1398 = Math_fround($251 * $1290);
     $1399 = Math_fround($257 * $1291);
     $1400 = Math_fround($263 * $1292);
     $1401 = Math_fround($247 * $1301);
     $1402 = Math_fround($253 * $1302);
     $1403 = Math_fround($259 * $1303);
     $1404 = Math_fround($265 * $1304);
     $1405 = Math_fround($1401 + $1397);
     $1406 = Math_fround($1402 + $1398);
     $1407 = Math_fround($1403 + $1399);
     $1408 = Math_fround($1404 + $1400);
     $1409 = Math_fround($249 * $1313);
     $1410 = Math_fround($255 * $1314);
     $1411 = Math_fround($261 * $1315);
     $1412 = Math_fround($267 * $1316);
     $1413 = Math_fround($1409 + $1405);
     $1414 = Math_fround($1410 + $1406);
     $1415 = Math_fround($1411 + $1407);
     $1416 = Math_fround($1412 + $1408);
     $1417 = Math_fround($300 + $1393);
     $1418 = Math_fround($302 + $1394);
     $1419 = Math_fround($304 + $1395);
     $1420 = Math_fround($306 + $1396);
     $1421 = Math_fround($1273 + $1417);
     $1422 = Math_fround($1274 + $1418);
     $1423 = Math_fround($1275 + $1419);
     $1424 = Math_fround($1276 + $1420);
     $1425 = Math_fround($1277 - $1413);
     $1426 = Math_fround($1278 - $1414);
     $1427 = Math_fround($1279 - $1415);
     $1428 = Math_fround($1280 - $1416);
     $1429 = (($p$0) + 176|0);
     HEAPF32[$1429>>2] = $1289;
     $1430 = (($p$0) + 180|0);
     HEAPF32[$1430>>2] = $1290;
     $1431 = (($p$0) + 184|0);
     HEAPF32[$1431>>2] = $1291;
     $1432 = (($p$0) + 188|0);
     HEAPF32[$1432>>2] = $1292;
     $1433 = (($p$0) + 192|0);
     HEAPF32[$1433>>2] = $1301;
     $1434 = (($p$0) + 196|0);
     HEAPF32[$1434>>2] = $1302;
     $1435 = (($p$0) + 200|0);
     HEAPF32[$1435>>2] = $1303;
     $1436 = (($p$0) + 204|0);
     HEAPF32[$1436>>2] = $1304;
     $1437 = (($p$0) + 208|0);
     HEAPF32[$1437>>2] = $1313;
     $1438 = (($p$0) + 212|0);
     HEAPF32[$1438>>2] = $1314;
     $1439 = (($p$0) + 216|0);
     HEAPF32[$1439>>2] = $1315;
     $1440 = (($p$0) + 220|0);
     HEAPF32[$1440>>2] = $1316;
     $1441 = Math_fround(-$1357);
     $1442 = Math_fround(-$1358);
     $1443 = Math_fround(-$1359);
     $1444 = Math_fround(-$1360);
     $1445 = (($p$0) + 224|0);
     HEAPF32[$1445>>2] = $1441;
     $1446 = (($p$0) + 228|0);
     HEAPF32[$1446>>2] = $1442;
     $1447 = (($p$0) + 232|0);
     HEAPF32[$1447>>2] = $1443;
     $1448 = (($p$0) + 236|0);
     HEAPF32[$1448>>2] = $1444;
     $1449 = Math_fround(-$1365);
     $1450 = Math_fround(-$1366);
     $1451 = Math_fround(-$1367);
     $1452 = Math_fround(-$1368);
     $1453 = (($p$0) + 240|0);
     HEAPF32[$1453>>2] = $1449;
     $1454 = (($p$0) + 244|0);
     HEAPF32[$1454>>2] = $1450;
     $1455 = (($p$0) + 248|0);
     HEAPF32[$1455>>2] = $1451;
     $1456 = (($p$0) + 252|0);
     HEAPF32[$1456>>2] = $1452;
     $1457 = Math_fround(-$1373);
     $1458 = Math_fround(-$1374);
     $1459 = Math_fround(-$1375);
     $1460 = Math_fround(-$1376);
     $1461 = (($p$0) + 256|0);
     HEAPF32[$1461>>2] = $1457;
     $1462 = (($p$0) + 260|0);
     HEAPF32[$1462>>2] = $1458;
     $1463 = (($p$0) + 264|0);
     HEAPF32[$1463>>2] = $1459;
     $1464 = (($p$0) + 268|0);
     HEAPF32[$1464>>2] = $1460;
     $1466 = $1421;$1468 = $1422;$1470 = $1423;$1472 = $1424;$1504 = $1425;$1506 = $1426;$1508 = $1427;$1510 = $1428;
    } else {
     $1466 = $1273;$1468 = $1274;$1470 = $1275;$1472 = $1276;$1504 = $1277;$1506 = $1278;$1508 = $1279;$1510 = $1280;
    }
    $1465 = $1466 > Math_fround(0.0);
    $1467 = $1468 > Math_fround(0.0);
    $1469 = $1470 > Math_fround(0.0);
    $1471 = $1472 > Math_fround(0.0);
    $1473 = Math_fround(Math_fround(1.0) / $1466);
    $1474 = Math_fround(Math_fround(1.0) / $1468);
    $1475 = Math_fround(Math_fround(1.0) / $1470);
    $1476 = Math_fround(Math_fround(1.0) / $1472);
    HEAPF32[$1>>2] = $1473;
    HEAPF32[$654>>2] = $1474;
    HEAPF32[$655>>2] = $1475;
    HEAPF32[$656>>2] = $1476;
    $b$a$i1043 = $1465 ? $1 : $0;
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    $1477 = Math_fround(HEAPF32[$b$a$i1043>>2]);
    $a$pn4$i1045 = $1467 ? $1 : $0;
    $$in1$i1046 = (($a$pn4$i1045) + 4|0);
    $1478 = Math_fround(HEAPF32[$$in1$i1046>>2]);
    $b$a7$i1047 = $1469 ? $1 : $0;
    $$in2$i1048 = (($b$a7$i1047) + 8|0);
    $1479 = Math_fround(HEAPF32[$$in2$i1048>>2]);
    $a$pn6$i1049 = $1471 ? $1 : $0;
    $$in3$i1050 = (($a$pn6$i1049) + 12|0);
    $1480 = Math_fround(HEAPF32[$$in3$i1050>>2]);
    $1481 = Math_fround($1078 - $157);
    $1482 = Math_fround($1080 - $159);
    $1483 = Math_fround($1082 - $161);
    $1484 = Math_fround($1084 - $163);
    $1485 = Math_fround($516 * $1481);
    $1486 = Math_fround($516 * $1482);
    $1487 = Math_fround($516 * $1483);
    $1488 = Math_fround($516 * $1484);
    $1489 = $$$i1595 > $1485;
    $$$i = $1489 ? $$$i1595 : $1485;
    $1490 = $152 > $1486;
    $1491 = $1490 ? $152 : $1486;
    $1492 = $$1$i1596 > $1487;
    $$1$i = $1492 ? $$1$i1596 : $1487;
    $1493 = $155 > $1488;
    $1494 = $1493 ? $155 : $1488;
    $1495 = Math_fround($$$i * $1477);
    $1496 = Math_fround($1491 * $1478);
    $1497 = Math_fround($$1$i * $1479);
    $1498 = Math_fround($1494 * $1480);
    $1499 = Math_fround($1481 * $invDtF32);
    $1500 = Math_fround($1482 * $invDtF32);
    $1501 = Math_fround($1483 * $invDtF32);
    $1502 = Math_fround($1484 * $invDtF32);
    $1503 = Math_fround(-$1504);
    $1505 = Math_fround(-$1506);
    $1507 = Math_fround(-$1508);
    $1509 = Math_fround(-$1510);
    $1511 = $1499 < $1503;
    $1512 = $1500 < $1505;
    $1513 = $1501 < $1507;
    $1514 = $1502 < $1509;
    $notrhs8039 = $1504 < $bounceThresholdF32;
    $not$8037 = $notrhs8039 & $notlhs8038;
    $$8025 = $1511 & $not$8037;
    $notrhs8041 = $1506 < $bounceThresholdF32;
    $not$ = $notrhs8041 & $notlhs8040;
    $1515 = $1512 & $not$;
    $notrhs8044 = $1508 < $bounceThresholdF32;
    $not$8042 = $notrhs8044 & $notlhs8043;
    $$8026 = $1513 & $not$8042;
    $notrhs8047 = $1510 < $bounceThresholdF32;
    $not$8045 = $notrhs8047 & $notlhs8046;
    $1516 = $1514 & $not$8045;
    $1517 = Math_fround(-$1495);
    $1518 = Math_fround(-$1496);
    $1519 = Math_fround(-$1497);
    $1520 = Math_fround(-$1498);
    ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
    HEAPF32[$2>>2] = $1517;
    HEAPF32[$657>>2] = $1518;
    HEAPF32[$658>>2] = $1519;
    HEAPF32[$659>>2] = $1520;
    $b$a$i984 = $$8025 ? $3 : $2;
    $1521 = Math_fround(HEAPF32[$b$a$i984>>2]);
    $a$pn4$i986 = $1515 ? $3 : $2;
    $$in1$i987 = (($a$pn4$i986) + 4|0);
    $1522 = Math_fround(HEAPF32[$$in1$i987>>2]);
    $b$a7$i988 = $$8026 ? $3 : $2;
    $$in2$i989 = (($b$a7$i988) + 8|0);
    $1523 = Math_fround(HEAPF32[$$in2$i989>>2]);
    $a$pn6$i990 = $1516 ? $3 : $2;
    $$in3$i991 = (($a$pn6$i990) + 12|0);
    $1524 = Math_fround(HEAPF32[$$in3$i991>>2]);
    $1525 = Math_fround($1504 * $783);
    $1526 = Math_fround($1506 * $784);
    $1527 = Math_fround($1508 * $785);
    $1528 = Math_fround($1510 * $786);
    $1529 = Math_fround($1525 * $1477);
    $1530 = Math_fround($1526 * $1478);
    $1531 = Math_fround($1527 * $1479);
    $1532 = Math_fround($1528 * $1480);
    HEAPF32[$p$0>>2] = $1145;
    $1533 = (($p$0) + 4|0);
    HEAPF32[$1533>>2] = $1146;
    $1534 = (($p$0) + 8|0);
    HEAPF32[$1534>>2] = $1147;
    $1535 = (($p$0) + 12|0);
    HEAPF32[$1535>>2] = $1148;
    $1536 = (($p$0) + 16|0);
    HEAPF32[$1536>>2] = $1157;
    $1537 = (($p$0) + 20|0);
    HEAPF32[$1537>>2] = $1158;
    $1538 = (($p$0) + 24|0);
    HEAPF32[$1538>>2] = $1159;
    $1539 = (($p$0) + 28|0);
    HEAPF32[$1539>>2] = $1160;
    $1540 = (($p$0) + 32|0);
    HEAPF32[$1540>>2] = $1169;
    $1541 = (($p$0) + 36|0);
    HEAPF32[$1541>>2] = $1170;
    $1542 = (($p$0) + 40|0);
    HEAPF32[$1542>>2] = $1171;
    $1543 = (($p$0) + 44|0);
    HEAPF32[$1543>>2] = $1172;
    $1544 = (($p$0) + 96|0);
    HEAPF32[$1544>>2] = $1477;
    $1545 = (($p$0) + 100|0);
    HEAPF32[$1545>>2] = $1478;
    $1546 = (($p$0) + 104|0);
    HEAPF32[$1546>>2] = $1479;
    $1547 = (($p$0) + 108|0);
    HEAPF32[$1547>>2] = $1480;
    $1548 = (($p$0) + 112|0);
    ;HEAP32[$1548+0>>2]=0|0;HEAP32[$1548+4>>2]=0|0;HEAP32[$1548+8>>2]=0|0;HEAP32[$1548+12>>2]=0|0;
    HEAPF32[$5>>2] = $1529;
    HEAPF32[$660>>2] = $1530;
    HEAPF32[$661>>2] = $1531;
    HEAPF32[$662>>2] = $1532;
    HEAPF32[$4>>2] = $1521;
    HEAPF32[$663>>2] = $1522;
    HEAPF32[$664>>2] = $1523;
    HEAPF32[$665>>2] = $1524;
    $b$a$i962 = $$8025 ? $5 : $4;
    $1549 = Math_fround(HEAPF32[$b$a$i962>>2]);
    $a$pn4$i964 = $1515 ? $5 : $4;
    $$in1$i965 = (($a$pn4$i964) + 4|0);
    $1550 = Math_fround(HEAPF32[$$in1$i965>>2]);
    $b$a7$i966 = $$8026 ? $5 : $4;
    $$in2$i967 = (($b$a7$i966) + 8|0);
    $1551 = Math_fround(HEAPF32[$$in2$i967>>2]);
    $a$pn6$i968 = $1516 ? $5 : $4;
    $$in3$i969 = (($a$pn6$i968) + 12|0);
    $1552 = Math_fround(HEAPF32[$$in3$i969>>2]);
    $1553 = Math_fround($1109 + $1549);
    $1554 = Math_fround($1110 + $1550);
    $1555 = Math_fround($1111 + $1551);
    $1556 = Math_fround($1112 + $1552);
    $1557 = (($p$0) + 144|0);
    HEAPF32[$1557>>2] = $1553;
    $1558 = (($p$0) + 148|0);
    HEAPF32[$1558>>2] = $1554;
    $1559 = (($p$0) + 152|0);
    HEAPF32[$1559>>2] = $1555;
    $1560 = (($p$0) + 156|0);
    HEAPF32[$1560>>2] = $1556;
    $1561 = $1521 <= Math_fround(0.0);
    $1562 = $1522 <= Math_fround(0.0);
    $1563 = $1523 <= Math_fround(0.0);
    $1564 = $1524 <= Math_fround(0.0);
    ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
    HEAPF32[$6>>2] = $1521;
    HEAPF32[$666>>2] = $1522;
    HEAPF32[$667>>2] = $1523;
    HEAPF32[$668>>2] = $1524;
    $b$a$i940 = $1561 ? $7 : $6;
    $1565 = Math_fround(HEAPF32[$b$a$i940>>2]);
    $a$pn4$i942 = $1562 ? $7 : $6;
    $$in1$i943 = (($a$pn4$i942) + 4|0);
    $1566 = Math_fround(HEAPF32[$$in1$i943>>2]);
    $b$a7$i944 = $1563 ? $7 : $6;
    $$in2$i945 = (($b$a7$i944) + 8|0);
    $1567 = Math_fround(HEAPF32[$$in2$i945>>2]);
    $a$pn6$i946 = $1564 ? $7 : $6;
    $$in3$i947 = (($a$pn6$i946) + 12|0);
    $1568 = Math_fround(HEAPF32[$$in3$i947>>2]);
    $1569 = (($p$0) + 128|0);
    HEAPF32[$1569>>2] = $1565;
    $1570 = (($p$0) + 132|0);
    HEAPF32[$1570>>2] = $1566;
    $1571 = (($p$0) + 136|0);
    HEAPF32[$1571>>2] = $1567;
    $1572 = (($p$0) + 140|0);
    HEAPF32[$1572>>2] = $1568;
    $1573 = (($p$0) + 160|0);
    HEAPF32[$1573>>2] = $1086;
    $1574 = (($p$0) + 164|0);
    HEAPF32[$1574>>2] = $1088;
    $1575 = (($p$0) + 168|0);
    HEAPF32[$1575>>2] = $1090;
    $1576 = (($p$0) + 172|0);
    HEAPF32[$1576>>2] = $1092;
    $1577 = (($p$0) + 48|0);
    HEAPF32[$1577>>2] = $1213;
    $1578 = (($p$0) + 52|0);
    HEAPF32[$1578>>2] = $1214;
    $1579 = (($p$0) + 56|0);
    HEAPF32[$1579>>2] = $1215;
    $1580 = (($p$0) + 60|0);
    HEAPF32[$1580>>2] = $1216;
    $1581 = (($p$0) + 64|0);
    HEAPF32[$1581>>2] = $1221;
    $1582 = (($p$0) + 68|0);
    HEAPF32[$1582>>2] = $1222;
    $1583 = (($p$0) + 72|0);
    HEAPF32[$1583>>2] = $1223;
    $1584 = (($p$0) + 76|0);
    HEAPF32[$1584>>2] = $1224;
    $1585 = (($p$0) + 80|0);
    HEAPF32[$1585>>2] = $1229;
    $1586 = (($p$0) + 84|0);
    HEAPF32[$1586>>2] = $1230;
    $1587 = (($p$0) + 88|0);
    HEAPF32[$1587>>2] = $1231;
    $1588 = (($p$0) + 92|0);
    HEAPF32[$1588>>2] = $1232;
    $1589 = $newFinished$0 & 1;
    $1590 = ($1589|0)==(0);
    if ($1590) {
     $1591 = (($1592) + 1)|0;
     $1593 = ($newPatch$0$lcssa$i$i13817998|0)==(65535);
     do {
      if ($1593) {
       $1608 = 0;$newContact$0$lcssa$i9318015 = $1591;$newPatch$0$lcssa$i9328016 = 65535;
      } else {
       $newContact$02$i929 = $1591;$newPatch$01$i930 = $newPatch$0$lcssa$i$i13817998;
       while(1) {
        $1594 = ((($threadContext) + (($newPatch$01$i930*12)|0)|0) + 4498|0);
        $1595 = HEAP16[$1594>>1]|0;
        $1596 = $1595&65535;
        $1597 = ($newContact$02$i929|0)==($1596|0);
        if (!($1597)) {
         $newContact$0$lcssa$i931 = $newContact$02$i929;$newPatch$0$lcssa$i932 = $newPatch$01$i930;
         break;
        }
        $1598 = ((($threadContext) + (($newPatch$01$i930*12)|0)|0) + 4500|0);
        $1599 = HEAP16[$1598>>1]|0;
        $1600 = $1599&65535;
        $1601 = ($1599<<16>>16)==(-1);
        if ($1601) {
         $newContact$0$lcssa$i931 = 0;$newPatch$0$lcssa$i932 = $1600;
         break;
        } else {
         $newContact$02$i929 = 0;$newPatch$01$i930 = $1600;
        }
       }
       $1602 = ($newPatch$0$lcssa$i932|0)==(65535);
       if ($1602) {
        $1608 = 0;$newContact$0$lcssa$i9318015 = $newContact$0$lcssa$i931;$newPatch$0$lcssa$i9328016 = 65535;
        break;
       }
       $1603 = ((($threadContext) + (($newPatch$0$lcssa$i932*12)|0)|0) + 4498|0);
       $1604 = HEAP16[$1603>>1]|0;
       $1605 = $1604&65535;
       $1606 = ($newContact$0$lcssa$i931>>>0)<($1605>>>0);
       $1608 = $1606;$newContact$0$lcssa$i9318015 = $newContact$0$lcssa$i931;$newPatch$0$lcssa$i9328016 = $newPatch$0$lcssa$i932;
      }
     } while(0);
     $1607 = $1608&1;
     $1609 = $1607 ^ 1;
     $1610 = $1609 | $newFinished$0;
     $4189 = $1592;$4190 = $newContact$0$lcssa$i9318015;$newFinished$1 = $1610;$newPatch$0$lcssa$i$i13817999 = $newPatch$0$lcssa$i9328016;$newPatch$0$lcssa$i$i13818014 = $newPatch$0$lcssa$i$i13817998;
    } else {
     $4189 = $1015;$4190 = $1592;$newFinished$1 = $newFinished$0;$newPatch$0$lcssa$i$i13817999 = $newPatch$0$lcssa$i$i13817998;$newPatch$0$lcssa$i$i13818014 = $newPatch$0$lcssa$i$i13818013;
    }
    $1611 = $newFinished$0 & 2;
    $1612 = ($1611|0)==(0);
    if ($1612) {
     $1613 = (($1614) + 1)|0;
     $1615 = ($newPatch$0$lcssa$i$i13777995|0)==(65535);
     do {
      if ($1615) {
       $1630 = 0;$newContact$0$lcssa$i9248017 = $1613;$newPatch$0$lcssa$i9258018 = 65535;
      } else {
       $newContact$02$i922 = $1613;$newPatch$01$i923 = $newPatch$0$lcssa$i$i13777995;
       while(1) {
        $1616 = ((($threadContext) + (($newPatch$01$i923*12)|0)|0) + 4498|0);
        $1617 = HEAP16[$1616>>1]|0;
        $1618 = $1617&65535;
        $1619 = ($newContact$02$i922|0)==($1618|0);
        if (!($1619)) {
         $newContact$0$lcssa$i924 = $newContact$02$i922;$newPatch$0$lcssa$i925 = $newPatch$01$i923;
         break;
        }
        $1620 = ((($threadContext) + (($newPatch$01$i923*12)|0)|0) + 4500|0);
        $1621 = HEAP16[$1620>>1]|0;
        $1622 = $1621&65535;
        $1623 = ($1621<<16>>16)==(-1);
        if ($1623) {
         $newContact$0$lcssa$i924 = 0;$newPatch$0$lcssa$i925 = $1622;
         break;
        } else {
         $newContact$02$i922 = 0;$newPatch$01$i923 = $1622;
        }
       }
       $1624 = ($newPatch$0$lcssa$i925|0)==(65535);
       if ($1624) {
        $1630 = 0;$newContact$0$lcssa$i9248017 = $newContact$0$lcssa$i924;$newPatch$0$lcssa$i9258018 = 65535;
        break;
       }
       $1625 = ((($threadContext) + (($newPatch$0$lcssa$i925*12)|0)|0) + 4498|0);
       $1626 = HEAP16[$1625>>1]|0;
       $1627 = $1626&65535;
       $1628 = ($newContact$0$lcssa$i924>>>0)<($1627>>>0);
       $1630 = $1628;$newContact$0$lcssa$i9248017 = $newContact$0$lcssa$i924;$newPatch$0$lcssa$i9258018 = $newPatch$0$lcssa$i925;
      }
     } while(0);
     $1629 = $1630&1;
     $1631 = $1629 << 1;
     $1632 = $1631 ^ 2;
     $1633 = $1632 | $newFinished$1;
     $4191 = $1614;$4192 = $newContact$0$lcssa$i9248017;$newFinished$2 = $1633;$newPatch$0$lcssa$i$i13777996 = $newPatch$0$lcssa$i9258018;$newPatch$0$lcssa$i$i13778010 = $newPatch$0$lcssa$i$i13777995;
    } else {
     $4191 = $1020;$4192 = $1614;$newFinished$2 = $newFinished$1;$newPatch$0$lcssa$i$i13777996 = $newPatch$0$lcssa$i$i13777995;$newPatch$0$lcssa$i$i13778010 = $newPatch$0$lcssa$i$i13778009;
    }
    $1634 = $newFinished$0 & 4;
    $1635 = ($1634|0)==(0);
    if ($1635) {
     $1636 = (($1637) + 1)|0;
     $1638 = ($newPatch$0$lcssa$i$i13737992|0)==(65535);
     do {
      if ($1638) {
       $1653 = 0;$newContact$0$lcssa$i9178019 = $1636;$newPatch$0$lcssa$i9188020 = 65535;
      } else {
       $newContact$02$i915 = $1636;$newPatch$01$i916 = $newPatch$0$lcssa$i$i13737992;
       while(1) {
        $1639 = ((($threadContext) + (($newPatch$01$i916*12)|0)|0) + 4498|0);
        $1640 = HEAP16[$1639>>1]|0;
        $1641 = $1640&65535;
        $1642 = ($newContact$02$i915|0)==($1641|0);
        if (!($1642)) {
         $newContact$0$lcssa$i917 = $newContact$02$i915;$newPatch$0$lcssa$i918 = $newPatch$01$i916;
         break;
        }
        $1643 = ((($threadContext) + (($newPatch$01$i916*12)|0)|0) + 4500|0);
        $1644 = HEAP16[$1643>>1]|0;
        $1645 = $1644&65535;
        $1646 = ($1644<<16>>16)==(-1);
        if ($1646) {
         $newContact$0$lcssa$i917 = 0;$newPatch$0$lcssa$i918 = $1645;
         break;
        } else {
         $newContact$02$i915 = 0;$newPatch$01$i916 = $1645;
        }
       }
       $1647 = ($newPatch$0$lcssa$i918|0)==(65535);
       if ($1647) {
        $1653 = 0;$newContact$0$lcssa$i9178019 = $newContact$0$lcssa$i917;$newPatch$0$lcssa$i9188020 = 65535;
        break;
       }
       $1648 = ((($threadContext) + (($newPatch$0$lcssa$i918*12)|0)|0) + 4498|0);
       $1649 = HEAP16[$1648>>1]|0;
       $1650 = $1649&65535;
       $1651 = ($newContact$0$lcssa$i917>>>0)<($1650>>>0);
       $1653 = $1651;$newContact$0$lcssa$i9178019 = $newContact$0$lcssa$i917;$newPatch$0$lcssa$i9188020 = $newPatch$0$lcssa$i918;
      }
     } while(0);
     $1652 = $1653&1;
     $1654 = $1652 << 2;
     $1655 = $1654 ^ 4;
     $1656 = $1655 | $newFinished$2;
     $4193 = $1637;$4194 = $newContact$0$lcssa$i9178019;$newFinished$3 = $1656;$newPatch$0$lcssa$i$i13737993 = $newPatch$0$lcssa$i9188020;$newPatch$0$lcssa$i$i13738006 = $newPatch$0$lcssa$i$i13737992;
    } else {
     $4193 = $1025;$4194 = $1637;$newFinished$3 = $newFinished$2;$newPatch$0$lcssa$i$i13737993 = $newPatch$0$lcssa$i$i13737992;$newPatch$0$lcssa$i$i13738006 = $newPatch$0$lcssa$i$i13738005;
    }
    $1657 = $newFinished$0 & 8;
    $1658 = ($1657|0)==(0);
    if ($1658) {
     break;
    } else {
     $finished$0$phi = $newFinished$0;$1015 = $4189;$1020 = $4191;$1025 = $4193;$1592 = $4190;$1614 = $4192;$1637 = $4194;$contactCount$0 = $1006;$newFinished$0 = $newFinished$3;$newPatch$0$lcssa$i$i13737992 = $newPatch$0$lcssa$i$i13737993;$newPatch$0$lcssa$i$i13738005 = $newPatch$0$lcssa$i$i13738006;$newPatch$0$lcssa$i$i13777995 = $newPatch$0$lcssa$i$i13777996;$newPatch$0$lcssa$i$i13778009 = $newPatch$0$lcssa$i$i13778010;$newPatch$0$lcssa$i$i13817998 = $newPatch$0$lcssa$i$i13817999;$newPatch$0$lcssa$i$i13818013 = $newPatch$0$lcssa$i$i13818014;$p$0 = $1010;$finished$0 = $finished$0$phi;
    }
   }
   $1659 = (($$ph8126) + 1)|0;
   $1660 = ($newPatch$0$lcssa$i$i7990$ph|0)==(65535);
   do {
    if ($1660) {
     $1675 = 0;$newContact$0$lcssa$i8021 = $1659;$newPatch$0$lcssa$i8022 = 65535;
    } else {
     $newContact$02$i = $1659;$newPatch$01$i = $newPatch$0$lcssa$i$i7990$ph;
     while(1) {
      $1661 = ((($threadContext) + (($newPatch$01$i*12)|0)|0) + 4498|0);
      $1662 = HEAP16[$1661>>1]|0;
      $1663 = $1662&65535;
      $1664 = ($newContact$02$i|0)==($1663|0);
      if (!($1664)) {
       $newContact$0$lcssa$i = $newContact$02$i;$newPatch$0$lcssa$i = $newPatch$01$i;
       break;
      }
      $1665 = ((($threadContext) + (($newPatch$01$i*12)|0)|0) + 4500|0);
      $1666 = HEAP16[$1665>>1]|0;
      $1667 = $1666&65535;
      $1668 = ($1666<<16>>16)==(-1);
      if ($1668) {
       $newContact$0$lcssa$i = 0;$newPatch$0$lcssa$i = $1667;
       break;
      } else {
       $newContact$02$i = 0;$newPatch$01$i = $1667;
      }
     }
     $1669 = ($newPatch$0$lcssa$i|0)==(65535);
     if ($1669) {
      $1675 = 0;$newContact$0$lcssa$i8021 = $newContact$0$lcssa$i;$newPatch$0$lcssa$i8022 = 65535;
      break;
     }
     $1670 = ((($threadContext) + (($newPatch$0$lcssa$i*12)|0)|0) + 4498|0);
     $1671 = HEAP16[$1670>>1]|0;
     $1672 = $1671&65535;
     $1673 = ($newContact$0$lcssa$i>>>0)<($1672>>>0);
     $1675 = $1673;$newContact$0$lcssa$i8021 = $newContact$0$lcssa$i;$newPatch$0$lcssa$i8022 = $newPatch$0$lcssa$i;
    }
   } while(0);
   $1674 = $1675&1;
   $1676 = $1674 << 3;
   $1677 = $1676 ^ 8;
   $1678 = $1677 | $newFinished$3;
   $newPatch$0$lcssa$i$i8002$ph$phi = $newPatch$0$lcssa$i$i7990$ph;$$ph8122$phi = $$ph8126;$$ph8119 = $4189;$$ph8120 = $4191;$$ph8121 = $4193;$$ph8123 = $4190;$$ph8124 = $4192;$$ph8125 = $4194;$$ph8126 = $newContact$0$lcssa$i8021;$contactCount$0$ph = $1006;$finished$0$ph = $newFinished$0;$newFinished$0$ph = $1678;$newPatch$0$lcssa$i$i13737992$ph = $newPatch$0$lcssa$i$i13737993;$newPatch$0$lcssa$i$i13738005$ph = $newPatch$0$lcssa$i$i13738006;$newPatch$0$lcssa$i$i13777995$ph = $newPatch$0$lcssa$i$i13777996;$newPatch$0$lcssa$i$i13778009$ph = $newPatch$0$lcssa$i$i13778010;$newPatch$0$lcssa$i$i13817998$ph = $newPatch$0$lcssa$i$i13817999;$newPatch$0$lcssa$i$i13818013$ph = $newPatch$0$lcssa$i$i13818014;$newPatch$0$lcssa$i$i7990$ph = $newPatch$0$lcssa$i8022;$p$0$ph = $1010;$newPatch$0$lcssa$i$i8002$ph = $newPatch$0$lcssa$i$i8002$ph$phi;$$ph8122 = $$ph8122$phi;
  }
  $1679 = ((($threadContext) + ($765<<6)|0) + 428|0);
  $1680 = Math_fround(HEAPF32[$1679>>2]);
  $1681 = ((($threadContext) + ($768<<6)|0) + 428|0);
  $1682 = Math_fround(HEAPF32[$1681>>2]);
  $1683 = ((($threadContext) + ($771<<6)|0) + 428|0);
  $1684 = Math_fround(HEAPF32[$1683>>2]);
  $1685 = ((($threadContext) + ($774<<6)|0) + 428|0);
  $1686 = Math_fround(HEAPF32[$1685>>2]);
  $1687 = ((($threadContext) + ($765<<6)|0) + 440|0);
  $1688 = Math_fround(HEAPF32[$1687>>2]);
  $1689 = ((($threadContext) + ($768<<6)|0) + 440|0);
  $1690 = Math_fround(HEAPF32[$1689>>2]);
  $1691 = ((($threadContext) + ($771<<6)|0) + 440|0);
  $1692 = Math_fround(HEAPF32[$1691>>2]);
  $1693 = ((($threadContext) + ($774<<6)|0) + 440|0);
  $1694 = Math_fround(HEAPF32[$1693>>2]);
  $1695 = $contactCount$0&255;
  $1696 = (($ptr$08165) + 1|0);
  HEAP8[$1696>>0] = $1695;
  HEAP8[$792>>0] = $793;
  HEAP8[$794>>0] = $795;
  HEAP8[$796>>0] = $797;
  HEAP8[$798>>0] = $799;
  $1697 = (($ptr$08165) + 48|0);
  HEAPF32[$1697>>2] = $1688;
  $1698 = (($ptr$08165) + 52|0);
  HEAPF32[$1698>>2] = $1690;
  $1699 = (($ptr$08165) + 56|0);
  HEAPF32[$1699>>2] = $1692;
  $1700 = (($ptr$08165) + 60|0);
  HEAPF32[$1700>>2] = $1694;
  $1701 = (($ptr$08165) + 32|0);
  HEAPF32[$1701>>2] = $1680;
  $1702 = (($ptr$08165) + 36|0);
  HEAPF32[$1702>>2] = $1682;
  $1703 = (($ptr$08165) + 40|0);
  HEAPF32[$1703>>2] = $1684;
  $1704 = (($ptr$08165) + 44|0);
  HEAPF32[$1704>>2] = $1686;
  $1705 = ((($threadContext) + (($747*96)|0)|0) + 5280|0);
  $1706 = HEAP16[$1705>>1]|0;
  $1707 = $1706&65535;
  $1708 = ((($threadContext) + (($750*96)|0)|0) + 5280|0);
  $1709 = HEAP16[$1708>>1]|0;
  $1710 = $1709&65535;
  $1711 = ((($threadContext) + (($753*96)|0)|0) + 5280|0);
  $1712 = HEAP16[$1711>>1]|0;
  $1713 = $1712&65535;
  if ($728) {
   $1741 = 0;
  } else {
   $1714 = ((($threadContext) + (($744*96)|0)|0) + 5280|0);
   $1715 = HEAP16[$1714>>1]|0;
   $1716 = $1715&65535;
   $1717 = ((($threadContext) + ($765<<6)|0) + 436|0);
   $1718 = HEAP32[$1717>>2]|0;
   $1719 = $1718 & 1;
   $1720 = ($1719|0)!=(0);
   $$ = $1720 ? 0 : $1716;
   $1741 = $$;
  }
  if ($730) {
   $1738 = 0;
  } else {
   $1721 = ((($threadContext) + ($768<<6)|0) + 436|0);
   $1722 = HEAP32[$1721>>2]|0;
   $1723 = $1722 & 1;
   $1724 = ($1723|0)!=(0);
   $$1 = $1724 ? 0 : $1707;
   $1738 = $$1;
  }
  if ($732) {
   $1734 = 0;
  } else {
   $1725 = ((($threadContext) + ($771<<6)|0) + 436|0);
   $1726 = HEAP32[$1725>>2]|0;
   $1727 = $1726 & 1;
   $1728 = ($1727|0)!=(0);
   $$2 = $1728 ? 0 : $1710;
   $1734 = $$2;
  }
  if ($734) {
   $1735 = 0;
  } else {
   $1729 = ((($threadContext) + ($774<<6)|0) + 436|0);
   $1730 = HEAP32[$1729>>2]|0;
   $1731 = $1730 & 1;
   $1732 = ($1731|0)!=(0);
   $$3 = $1732 ? 0 : $1713;
   $1735 = $$3;
  }
  $1733 = ($1734>>>0)<($1735>>>0);
  $1736 = $1733 ? $1735 : $1734;
  $1737 = ($1738>>>0)<($1736>>>0);
  $1739 = $1737 ? $1736 : $1738;
  $1740 = ($1741>>>0)<($1739>>>0);
  $1742 = $1740 ? $1739 : $1741;
  $1743 = $1742 << 1;
  $1744 = $1743&255;
  $1745 = (($ptr$08165) + 2|0);
  HEAP8[$1745>>0] = $1744;
  $1746 = $1741 << 1;
  $1747 = $1746&255;
  $1748 = (($ptr$08165) + 12|0);
  HEAP8[$1748>>0] = $1747;
  $1749 = $1738 << 1;
  $1750 = $1749&255;
  $1751 = (($ptr$08165) + 13|0);
  HEAP8[$1751>>0] = $1750;
  $1752 = $1734 << 1;
  $1753 = $1752&255;
  $1754 = (($ptr$08165) + 14|0);
  HEAP8[$1754>>0] = $1753;
  $1755 = $1735 << 1;
  $1756 = $1755&255;
  $1757 = (($ptr$08165) + 15|0);
  HEAP8[$1757>>0] = $1756;
  HEAP8[$ptr$08165>>0] = $669;
  $1758 = Math_fround(-$813);
  $1759 = Math_fround(-$819);
  $1760 = Math_fround(-$825);
  $1761 = Math_fround(-$831);
  $1762 = $813 > $1758;
  $$$i$i = $1762 ? $813 : $1758;
  $1763 = $819 > $1759;
  $1764 = $1763 ? $819 : $1759;
  $1765 = $825 > $1760;
  $$1$i$i = $1765 ? $825 : $1760;
  $1766 = $831 > $1761;
  $1767 = $1766 ? $831 : $1761;
  $1768 = $$$i$i < Math_fround(0.707106769084930419921);
  $1769 = $1764 < Math_fround(0.707106769084930419921);
  $1770 = $$1$i$i < Math_fround(0.707106769084930419921);
  $1771 = $1767 < Math_fround(0.707106769084930419921);
  $1772 = Math_fround(-$815);
  $1773 = Math_fround(-$821);
  $1774 = Math_fround(-$827);
  $1775 = Math_fround(-$833);
  ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
  HEAPF32[$8>>2] = $1772;
  HEAPF32[$670>>2] = $1773;
  HEAPF32[$671>>2] = $1774;
  HEAPF32[$672>>2] = $1775;
  $b$a$i897 = $1768 ? $9 : $8;
  $1776 = Math_fround(HEAPF32[$b$a$i897>>2]);
  $a$pn4$i899 = $1769 ? $9 : $8;
  $$in1$i900 = (($a$pn4$i899) + 4|0);
  $1777 = Math_fround(HEAPF32[$$in1$i900>>2]);
  $b$a7$i901 = $1770 ? $9 : $8;
  $$in2$i902 = (($b$a7$i901) + 8|0);
  $1778 = Math_fround(HEAPF32[$$in2$i902>>2]);
  $a$pn6$i903 = $1771 ? $9 : $8;
  $$in3$i904 = (($a$pn6$i903) + 12|0);
  $1779 = Math_fround(HEAPF32[$$in3$i904>>2]);
  $1780 = Math_fround(-$817);
  $1781 = Math_fround(-$823);
  $1782 = Math_fround(-$829);
  $1783 = Math_fround(-$835);
  HEAPF32[$11>>2] = $1780;
  HEAPF32[$673>>2] = $1781;
  HEAPF32[$674>>2] = $1782;
  HEAPF32[$675>>2] = $1783;
  HEAPF32[$10>>2] = $813;
  HEAPF32[$676>>2] = $819;
  HEAPF32[$677>>2] = $825;
  HEAPF32[$678>>2] = $831;
  $b$a$i881 = $1768 ? $11 : $10;
  $1784 = Math_fround(HEAPF32[$b$a$i881>>2]);
  $a$pn4$i883 = $1769 ? $11 : $10;
  $$in1$i884 = (($a$pn4$i883) + 4|0);
  $1785 = Math_fround(HEAPF32[$$in1$i884>>2]);
  $b$a7$i885 = $1770 ? $11 : $10;
  $$in2$i886 = (($b$a7$i885) + 8|0);
  $1786 = Math_fround(HEAPF32[$$in2$i886>>2]);
  $a$pn6$i887 = $1771 ? $11 : $10;
  $$in3$i888 = (($a$pn6$i887) + 12|0);
  $1787 = Math_fround(HEAPF32[$$in3$i888>>2]);
  HEAPF32[$13>>2] = $815;
  HEAPF32[$679>>2] = $821;
  HEAPF32[$680>>2] = $827;
  HEAPF32[$681>>2] = $833;
  $b$a$i867 = $1768 ? $13 : $12;
  ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
  $1788 = Math_fround(HEAPF32[$b$a$i867>>2]);
  $a$pn4$i869 = $1769 ? $13 : $12;
  $$in1$i870 = (($a$pn4$i869) + 4|0);
  $1789 = Math_fround(HEAPF32[$$in1$i870>>2]);
  $b$a7$i871 = $1770 ? $13 : $12;
  $$in2$i872 = (($b$a7$i871) + 8|0);
  $1790 = Math_fround(HEAPF32[$$in2$i872>>2]);
  $a$pn6$i873 = $1771 ? $13 : $12;
  $$in3$i874 = (($a$pn6$i873) + 12|0);
  $1791 = Math_fround(HEAPF32[$$in3$i874>>2]);
  $1792 = Math_fround($813 * $888);
  $1793 = Math_fround($819 * $889);
  $1794 = Math_fround($825 * $890);
  $1795 = Math_fround($831 * $891);
  $1796 = Math_fround($268 - $1792);
  $1797 = Math_fround($269 - $1793);
  $1798 = Math_fround($270 - $1794);
  $1799 = Math_fround($271 - $1795);
  $1800 = Math_fround($815 * $888);
  $1801 = Math_fround($821 * $889);
  $1802 = Math_fround($827 * $890);
  $1803 = Math_fround($833 * $891);
  $1804 = Math_fround($272 - $1800);
  $1805 = Math_fround($273 - $1801);
  $1806 = Math_fround($274 - $1802);
  $1807 = Math_fround($275 - $1803);
  $1808 = Math_fround($817 * $888);
  $1809 = Math_fround($823 * $889);
  $1810 = Math_fround($829 * $890);
  $1811 = Math_fround($835 * $891);
  $1812 = Math_fround($276 - $1808);
  $1813 = Math_fround($277 - $1809);
  $1814 = Math_fround($278 - $1810);
  $1815 = Math_fround($279 - $1811);
  $1816 = Math_fround($1812 * $1812);
  $1817 = Math_fround($1813 * $1813);
  $1818 = Math_fround($1814 * $1814);
  $1819 = Math_fround($1815 * $1815);
  $1820 = Math_fround($1804 * $1804);
  $1821 = Math_fround($1805 * $1805);
  $1822 = Math_fround($1806 * $1806);
  $1823 = Math_fround($1807 * $1807);
  $1824 = Math_fround($1820 + $1816);
  $1825 = Math_fround($1821 + $1817);
  $1826 = Math_fround($1822 + $1818);
  $1827 = Math_fround($1823 + $1819);
  $1828 = Math_fround($1796 * $1796);
  $1829 = Math_fround($1797 * $1797);
  $1830 = Math_fround($1798 * $1798);
  $1831 = Math_fround($1799 * $1799);
  $1832 = Math_fround($1828 + $1824);
  $1833 = Math_fround($1829 + $1825);
  $1834 = Math_fround($1830 + $1826);
  $1835 = Math_fround($1831 + $1827);
  $1836 = $1832 > Math_fround(0.100000001490116119385);
  $1837 = $1833 > Math_fround(0.100000001490116119385);
  $1838 = $1834 > Math_fround(0.100000001490116119385);
  $1839 = $1835 > Math_fround(0.100000001490116119385);
  HEAPF32[$15>>2] = $1796;
  HEAPF32[$682>>2] = $1797;
  HEAPF32[$683>>2] = $1798;
  HEAPF32[$684>>2] = $1799;
  HEAPF32[$14>>2] = $1776;
  HEAPF32[$685>>2] = $1777;
  HEAPF32[$686>>2] = $1778;
  HEAPF32[$687>>2] = $1779;
  $b$a$i815 = $1836 ? $15 : $14;
  $1840 = Math_fround(HEAPF32[$b$a$i815>>2]);
  $a$pn4$i817 = $1837 ? $15 : $14;
  $$in1$i818 = (($a$pn4$i817) + 4|0);
  $1841 = Math_fround(HEAPF32[$$in1$i818>>2]);
  $b$a7$i819 = $1838 ? $15 : $14;
  $$in2$i820 = (($b$a7$i819) + 8|0);
  $1842 = Math_fround(HEAPF32[$$in2$i820>>2]);
  $a$pn6$i821 = $1839 ? $15 : $14;
  $$in3$i822 = (($a$pn6$i821) + 12|0);
  $1843 = Math_fround(HEAPF32[$$in3$i822>>2]);
  HEAPF32[$17>>2] = $1804;
  HEAPF32[$688>>2] = $1805;
  HEAPF32[$689>>2] = $1806;
  HEAPF32[$690>>2] = $1807;
  HEAPF32[$16>>2] = $1784;
  HEAPF32[$691>>2] = $1785;
  HEAPF32[$692>>2] = $1786;
  HEAPF32[$693>>2] = $1787;
  $b$a$i801 = $1836 ? $17 : $16;
  $1844 = Math_fround(HEAPF32[$b$a$i801>>2]);
  $a$pn4$i803 = $1837 ? $17 : $16;
  $$in1$i804 = (($a$pn4$i803) + 4|0);
  $1845 = Math_fround(HEAPF32[$$in1$i804>>2]);
  $b$a7$i805 = $1838 ? $17 : $16;
  $$in2$i806 = (($b$a7$i805) + 8|0);
  $1846 = Math_fround(HEAPF32[$$in2$i806>>2]);
  $a$pn6$i807 = $1839 ? $17 : $16;
  $$in3$i808 = (($a$pn6$i807) + 12|0);
  $1847 = Math_fround(HEAPF32[$$in3$i808>>2]);
  HEAPF32[$19>>2] = $1812;
  HEAPF32[$694>>2] = $1813;
  HEAPF32[$695>>2] = $1814;
  HEAPF32[$696>>2] = $1815;
  HEAPF32[$18>>2] = $1788;
  HEAPF32[$697>>2] = $1789;
  HEAPF32[$698>>2] = $1790;
  HEAPF32[$699>>2] = $1791;
  $b$a$i787 = $1836 ? $19 : $18;
  $1848 = Math_fround(HEAPF32[$b$a$i787>>2]);
  $a$pn4$i789 = $1837 ? $19 : $18;
  $$in1$i790 = (($a$pn4$i789) + 4|0);
  $1849 = Math_fround(HEAPF32[$$in1$i790>>2]);
  $b$a7$i791 = $1838 ? $19 : $18;
  $$in2$i792 = (($b$a7$i791) + 8|0);
  $1850 = Math_fround(HEAPF32[$$in2$i792>>2]);
  $a$pn6$i793 = $1839 ? $19 : $18;
  $$in3$i794 = (($a$pn6$i793) + 12|0);
  $1851 = Math_fround(HEAPF32[$$in3$i794>>2]);
  $1852 = Math_fround($1840 * $1840);
  $1853 = Math_fround($1841 * $1841);
  $1854 = Math_fround($1842 * $1842);
  $1855 = Math_fround($1843 * $1843);
  $1856 = Math_fround($1844 * $1844);
  $1857 = Math_fround($1845 * $1845);
  $1858 = Math_fround($1846 * $1846);
  $1859 = Math_fround($1847 * $1847);
  $1860 = Math_fround($1852 + $1856);
  $1861 = Math_fround($1853 + $1857);
  $1862 = Math_fround($1854 + $1858);
  $1863 = Math_fround($1855 + $1859);
  $1864 = Math_fround($1848 * $1848);
  $1865 = Math_fround($1849 * $1849);
  $1866 = Math_fround($1850 * $1850);
  $1867 = Math_fround($1851 * $1851);
  $1868 = Math_fround($1860 + $1864);
  $1869 = Math_fround($1861 + $1865);
  $1870 = Math_fround($1862 + $1866);
  $1871 = Math_fround($1863 + $1867);
  $1872 = (Math_fround(Math_sqrt((Math_fround($1868)))));
  $1873 = Math_fround(Math_fround(1.0) / $1872);
  $1874 = (Math_fround(Math_sqrt((Math_fround($1869)))));
  $1875 = Math_fround(Math_fround(1.0) / $1874);
  $1876 = (Math_fround(Math_sqrt((Math_fround($1870)))));
  $1877 = Math_fround(Math_fround(1.0) / $1876);
  $1878 = (Math_fround(Math_sqrt((Math_fround($1871)))));
  $1879 = Math_fround(Math_fround(1.0) / $1878);
  $1880 = Math_fround($1840 * $1873);
  $1881 = Math_fround($1841 * $1875);
  $1882 = Math_fround($1842 * $1877);
  $1883 = Math_fround($1843 * $1879);
  $1884 = Math_fround($1844 * $1873);
  $1885 = Math_fround($1845 * $1875);
  $1886 = Math_fround($1846 * $1877);
  $1887 = Math_fround($1847 * $1879);
  $1888 = Math_fround($1848 * $1873);
  $1889 = Math_fround($1849 * $1875);
  $1890 = Math_fround($1850 * $1877);
  $1891 = Math_fround($1851 * $1879);
  $1892 = Math_fround($815 * $1888);
  $1893 = Math_fround($821 * $1889);
  $1894 = Math_fround($827 * $1890);
  $1895 = Math_fround($833 * $1891);
  $1896 = Math_fround($817 * $1884);
  $1897 = Math_fround($823 * $1885);
  $1898 = Math_fround($829 * $1886);
  $1899 = Math_fround($835 * $1887);
  $1900 = Math_fround($1892 - $1896);
  $1901 = Math_fround($1893 - $1897);
  $1902 = Math_fround($1894 - $1898);
  $1903 = Math_fround($1895 - $1899);
  $1904 = Math_fround($817 * $1880);
  $1905 = Math_fround($823 * $1881);
  $1906 = Math_fround($829 * $1882);
  $1907 = Math_fround($835 * $1883);
  $1908 = Math_fround($813 * $1888);
  $1909 = Math_fround($819 * $1889);
  $1910 = Math_fround($825 * $1890);
  $1911 = Math_fround($831 * $1891);
  $1912 = Math_fround($1904 - $1908);
  $1913 = Math_fround($1905 - $1909);
  $1914 = Math_fround($1906 - $1910);
  $1915 = Math_fround($1907 - $1911);
  $1916 = Math_fround($813 * $1884);
  $1917 = Math_fround($819 * $1885);
  $1918 = Math_fround($825 * $1886);
  $1919 = Math_fround($831 * $1887);
  $1920 = Math_fround($815 * $1880);
  $1921 = Math_fround($821 * $1881);
  $1922 = Math_fround($827 * $1882);
  $1923 = Math_fround($833 * $1883);
  $1924 = Math_fround($1916 - $1920);
  $1925 = Math_fround($1917 - $1921);
  $1926 = Math_fround($1918 - $1922);
  $1927 = Math_fround($1919 - $1923);
  $1928 = HEAP32[$descs>>2]|0;
  $1929 = (($1928) + 40|0);
  $1930 = HEAP32[$1929>>2]|0;
  $1931 = ($frictionPatchWritebackAddrIndex0$08164*96)|0;
  $1932 = (($1930) + ($1931)|0);
  $1933 = HEAP32[$30>>2]|0;
  $1934 = (($1933) + 40|0);
  $1935 = HEAP32[$1934>>2]|0;
  $1936 = (($1935) + ($1931)|0);
  $1937 = HEAP32[$37>>2]|0;
  $1938 = (($1937) + 40|0);
  $1939 = HEAP32[$1938>>2]|0;
  $1940 = (($1939) + ($1931)|0);
  $1941 = HEAP32[$44>>2]|0;
  $1942 = (($1941) + 40|0);
  $1943 = HEAP32[$1942>>2]|0;
  $1944 = (($1943) + ($1931)|0);
  $1945 = ($1742|0)==(0);
  if ($1945) {
   $ptr$1$lcssa = $p$0;
  } else {
   $1946 = ((($threadContext) + ($765<<6)|0) + 416|0);
   $1947 = (($1946) + 4|0);
   $1948 = (($1946) + 8|0);
   $1949 = ((($threadContext) + ($768<<6)|0) + 416|0);
   $1950 = (($1949) + 4|0);
   $1951 = (($1949) + 8|0);
   $1952 = ((($threadContext) + ($771<<6)|0) + 416|0);
   $1953 = (($1952) + 4|0);
   $1954 = (($1952) + 8|0);
   $1955 = ((($threadContext) + ($774<<6)|0) + 416|0);
   $1956 = (($1955) + 4|0);
   $1957 = (($1955) + 8|0);
   $1958 = ($1734>>>0)>($1735>>>0);
   $umax8192 = $1958 ? $1734 : $1735;
   $1959 = ($umax8192>>>0)>($1738>>>0);
   $umax8193 = $1959 ? $umax8192 : $1738;
   $1960 = ($umax8193>>>0)>($1741>>>0);
   $umax8194 = $1960 ? $umax8193 : $1741;
   if ($55) {
    $1974 = Math_fround(1.0);$1976 = Math_fround(1.0);$1977 = Math_fround(1.0);$1979 = Math_fround(1.0);$1981 = $1880;$1983 = $1881;$1985 = $1882;$1987 = $1883;$1989 = $1884;$1991 = $1885;$1993 = $1886;$1995 = $1887;$1997 = $1888;$1999 = $1889;$2001 = $1890;$2003 = $1891;$2005 = $1900;$2007 = $1901;$2009 = $1902;$2011 = $1903;$2013 = $1912;$2015 = $1913;$2017 = $1914;$2019 = $1915;$2021 = $1924;$2023 = $1925;$2025 = $1926;$2027 = $1927;$index0$08146$us = 0;$index1$08147$us = 0;$index2$08148$us = 0;$index3$08149$us = 0;$j$08150$us = 0;$ptr$18151$us = $p$0;
    while(1) {
     $1961 = (($ptr$18151$us) + 384|0);
     $1962 = (($ptr$18151$us) + 512|0);
     $1963 = (($ptr$18151$us) + 640|0);
     $1964 = (($ptr$18151$us) + ($57)|0);
     $1965 = (($ptr$18151$us) + ($$sum)|0);
     $1966 = ($j$08150$us>>>0)<($1741>>>0);
     $1967 = $1966 ? $j$08150$us : $index0$08146$us;
     $1968 = ($j$08150$us>>>0)<($1738>>>0);
     $1969 = $1968 ? $j$08150$us : $index1$08147$us;
     $1970 = ($j$08150$us>>>0)<($1734>>>0);
     $1971 = $1970 ? $j$08150$us : $index2$08148$us;
     $1972 = ($j$08150$us>>>0)<($1735>>>0);
     $1973 = $1972 ? $j$08150$us : $index3$08149$us;
     $$8111$us = $1966 ? $1974 : Math_fround(0.0);
     $1975 = $1968 ? $1976 : Math_fround(0.0);
     $$8112$us = $1970 ? $1977 : Math_fround(0.0);
     $1978 = $1972 ? $1979 : Math_fround(0.0);
     $1980 = Math_fround($1981 * $$8111$us);
     $1982 = Math_fround($1983 * $1975);
     $1984 = Math_fround($1985 * $$8112$us);
     $1986 = Math_fround($1987 * $1978);
     $1988 = Math_fround($1989 * $$8111$us);
     $1990 = Math_fround($1991 * $1975);
     $1992 = Math_fround($1993 * $$8112$us);
     $1994 = Math_fround($1995 * $1978);
     $1996 = Math_fround($1997 * $$8111$us);
     $1998 = Math_fround($1999 * $1975);
     $2000 = Math_fround($2001 * $$8112$us);
     $2002 = Math_fround($2003 * $1978);
     $2004 = Math_fround($2005 * $$8111$us);
     $2006 = Math_fround($2007 * $1975);
     $2008 = Math_fround($2009 * $$8112$us);
     $2010 = Math_fround($2011 * $1978);
     $2012 = Math_fround($2013 * $$8111$us);
     $2014 = Math_fround($2015 * $1975);
     $2016 = Math_fround($2017 * $$8112$us);
     $2018 = Math_fround($2019 * $1978);
     $2020 = Math_fround($2021 * $$8111$us);
     $2022 = Math_fround($2023 * $1975);
     $2024 = Math_fround($2025 * $$8112$us);
     $2026 = Math_fround($2027 * $1978);
     $2028 = (((($threadContext) + (($744*96)|0)|0) + (($1967*12)|0)|0) + 5312|0);
     $2029 = Math_fround(HEAPF32[$2028>>2]);
     $2030 = (((($threadContext) + (($744*96)|0)|0) + (($1967*12)|0)|0) + 5316|0);
     $2031 = Math_fround(HEAPF32[$2030>>2]);
     $2032 = (((($threadContext) + (($744*96)|0)|0) + (($1967*12)|0)|0) + 5320|0);
     $2033 = Math_fround(HEAPF32[$2032>>2]);
     $2034 = (((($threadContext) + (($747*96)|0)|0) + (($1969*12)|0)|0) + 5312|0);
     $2035 = Math_fround(HEAPF32[$2034>>2]);
     $2036 = (((($threadContext) + (($747*96)|0)|0) + (($1969*12)|0)|0) + 5316|0);
     $2037 = Math_fround(HEAPF32[$2036>>2]);
     $2038 = (((($threadContext) + (($747*96)|0)|0) + (($1969*12)|0)|0) + 5320|0);
     $2039 = Math_fround(HEAPF32[$2038>>2]);
     $2040 = (((($threadContext) + (($750*96)|0)|0) + (($1971*12)|0)|0) + 5312|0);
     $2041 = Math_fround(HEAPF32[$2040>>2]);
     $2042 = (((($threadContext) + (($750*96)|0)|0) + (($1971*12)|0)|0) + 5316|0);
     $2043 = Math_fround(HEAPF32[$2042>>2]);
     $2044 = (((($threadContext) + (($750*96)|0)|0) + (($1971*12)|0)|0) + 5320|0);
     $2045 = Math_fround(HEAPF32[$2044>>2]);
     $2046 = (((($threadContext) + (($753*96)|0)|0) + (($1973*12)|0)|0) + 5312|0);
     $2047 = Math_fround(HEAPF32[$2046>>2]);
     $2048 = (((($threadContext) + (($753*96)|0)|0) + (($1973*12)|0)|0) + 5316|0);
     $2049 = Math_fround(HEAPF32[$2048>>2]);
     $2050 = (((($threadContext) + (($753*96)|0)|0) + (($1973*12)|0)|0) + 5320|0);
     $2051 = Math_fround(HEAPF32[$2050>>2]);
     $2052 = Math_fround($701 * $2029);
     $2053 = Math_fround($701 * $2031);
     $2054 = Math_fround($701 * $2033);
     $2055 = Math_fround($583 * $2033);
     $2056 = Math_fround($585 * $2031);
     $2057 = Math_fround($2055 - $2056);
     $2058 = Math_fround($585 * $2029);
     $2059 = Math_fround($581 * $2033);
     $2060 = Math_fround($2058 - $2059);
     $2061 = Math_fround($581 * $2031);
     $2062 = Math_fround($583 * $2029);
     $2063 = Math_fround($2061 - $2062);
     $2064 = Math_fround($587 * $2057);
     $2065 = Math_fround($587 * $2060);
     $2066 = Math_fround($587 * $2063);
     $2067 = Math_fround($2052 + $2064);
     $2068 = Math_fround($2053 + $2065);
     $2069 = Math_fround($2054 + $2066);
     $2070 = Math_fround($581 * $2029);
     $2071 = Math_fround($583 * $2031);
     $2072 = Math_fround($2070 + $2071);
     $2073 = Math_fround($585 * $2033);
     $2074 = Math_fround($2072 + $2073);
     $2075 = Math_fround($581 * $2074);
     $2076 = Math_fround($583 * $2074);
     $2077 = Math_fround($585 * $2074);
     $2078 = Math_fround($2075 + $2067);
     $2079 = Math_fround($2076 + $2068);
     $2080 = Math_fround($2069 + $2077);
     $2081 = Math_fround($2078 * Math_fround(2.0));
     $2082 = Math_fround($2079 * Math_fround(2.0));
     $2083 = Math_fround($2080 * Math_fround(2.0));
     $2084 = Math_fround($703 * $2035);
     $2085 = Math_fround($703 * $2037);
     $2086 = Math_fround($703 * $2039);
     $2087 = Math_fround($590 * $2039);
     $2088 = Math_fround($592 * $2037);
     $2089 = Math_fround($2087 - $2088);
     $2090 = Math_fround($592 * $2035);
     $2091 = Math_fround($588 * $2039);
     $2092 = Math_fround($2090 - $2091);
     $2093 = Math_fround($588 * $2037);
     $2094 = Math_fround($590 * $2035);
     $2095 = Math_fround($2093 - $2094);
     $2096 = Math_fround($594 * $2089);
     $2097 = Math_fround($594 * $2092);
     $2098 = Math_fround($594 * $2095);
     $2099 = Math_fround($2084 + $2096);
     $2100 = Math_fround($2085 + $2097);
     $2101 = Math_fround($2086 + $2098);
     $2102 = Math_fround($588 * $2035);
     $2103 = Math_fround($590 * $2037);
     $2104 = Math_fround($2102 + $2103);
     $2105 = Math_fround($592 * $2039);
     $2106 = Math_fround($2104 + $2105);
     $2107 = Math_fround($588 * $2106);
     $2108 = Math_fround($590 * $2106);
     $2109 = Math_fround($592 * $2106);
     $2110 = Math_fround($2107 + $2099);
     $2111 = Math_fround($2108 + $2100);
     $2112 = Math_fround($2101 + $2109);
     $2113 = Math_fround($2110 * Math_fround(2.0));
     $2114 = Math_fround($2111 * Math_fround(2.0));
     $2115 = Math_fround($2112 * Math_fround(2.0));
     $2116 = Math_fround($705 * $2041);
     $2117 = Math_fround($705 * $2043);
     $2118 = Math_fround($705 * $2045);
     $2119 = Math_fround($597 * $2045);
     $2120 = Math_fround($599 * $2043);
     $2121 = Math_fround($2119 - $2120);
     $2122 = Math_fround($599 * $2041);
     $2123 = Math_fround($595 * $2045);
     $2124 = Math_fround($2122 - $2123);
     $2125 = Math_fround($595 * $2043);
     $2126 = Math_fround($597 * $2041);
     $2127 = Math_fround($2125 - $2126);
     $2128 = Math_fround($601 * $2121);
     $2129 = Math_fround($601 * $2124);
     $2130 = Math_fround($601 * $2127);
     $2131 = Math_fround($2116 + $2128);
     $2132 = Math_fround($2117 + $2129);
     $2133 = Math_fround($2118 + $2130);
     $2134 = Math_fround($595 * $2041);
     $2135 = Math_fround($597 * $2043);
     $2136 = Math_fround($2134 + $2135);
     $2137 = Math_fround($599 * $2045);
     $2138 = Math_fround($2136 + $2137);
     $2139 = Math_fround($595 * $2138);
     $2140 = Math_fround($597 * $2138);
     $2141 = Math_fround($599 * $2138);
     $2142 = Math_fround($2139 + $2131);
     $2143 = Math_fround($2140 + $2132);
     $2144 = Math_fround($2133 + $2141);
     $2145 = Math_fround($2142 * Math_fround(2.0));
     $2146 = Math_fround($2143 * Math_fround(2.0));
     $2147 = Math_fround($2144 * Math_fround(2.0));
     $2148 = Math_fround($707 * $2047);
     $2149 = Math_fround($707 * $2049);
     $2150 = Math_fround($707 * $2051);
     $2151 = Math_fround($604 * $2051);
     $2152 = Math_fround($606 * $2049);
     $2153 = Math_fround($2151 - $2152);
     $2154 = Math_fround($606 * $2047);
     $2155 = Math_fround($602 * $2051);
     $2156 = Math_fround($2154 - $2155);
     $2157 = Math_fround($602 * $2049);
     $2158 = Math_fround($604 * $2047);
     $2159 = Math_fround($2157 - $2158);
     $2160 = Math_fround($608 * $2153);
     $2161 = Math_fround($608 * $2156);
     $2162 = Math_fround($608 * $2159);
     $2163 = Math_fround($2148 + $2160);
     $2164 = Math_fround($2149 + $2161);
     $2165 = Math_fround($2150 + $2162);
     $2166 = Math_fround($602 * $2047);
     $2167 = Math_fround($604 * $2049);
     $2168 = Math_fround($2166 + $2167);
     $2169 = Math_fround($606 * $2051);
     $2170 = Math_fround($2168 + $2169);
     $2171 = Math_fround($602 * $2170);
     $2172 = Math_fround($604 * $2170);
     $2173 = Math_fround($606 * $2170);
     $2174 = Math_fround($2171 + $2163);
     $2175 = Math_fround($2172 + $2164);
     $2176 = Math_fround($2165 + $2173);
     $2177 = Math_fround($2174 * Math_fround(2.0));
     $2178 = Math_fround($2175 * Math_fround(2.0));
     $2179 = Math_fround($2176 * Math_fround(2.0));
     $2180 = Math_fround($520 + $2081);
     $2181 = Math_fround($528 + $2113);
     $2182 = Math_fround($536 + $2145);
     $2183 = Math_fround($544 + $2177);
     $2184 = Math_fround($522 + $2082);
     $2185 = Math_fround($530 + $2114);
     $2186 = Math_fround($538 + $2146);
     $2187 = Math_fround($546 + $2178);
     $2188 = Math_fround($524 + $2083);
     $2189 = Math_fround($532 + $2115);
     $2190 = Math_fround($540 + $2147);
     $2191 = Math_fround($548 + $2179);
     $2192 = (((($threadContext) + (($744*96)|0)|0) + (($1967*12)|0)|0) + 5336|0);
     $2193 = Math_fround(HEAPF32[$2192>>2]);
     $2194 = (((($threadContext) + (($744*96)|0)|0) + (($1967*12)|0)|0) + 5340|0);
     $2195 = Math_fround(HEAPF32[$2194>>2]);
     $2196 = (((($threadContext) + (($744*96)|0)|0) + (($1967*12)|0)|0) + 5344|0);
     $2197 = Math_fround(HEAPF32[$2196>>2]);
     $2198 = (((($threadContext) + (($747*96)|0)|0) + (($1969*12)|0)|0) + 5336|0);
     $2199 = Math_fround(HEAPF32[$2198>>2]);
     $2200 = (((($threadContext) + (($747*96)|0)|0) + (($1969*12)|0)|0) + 5340|0);
     $2201 = Math_fround(HEAPF32[$2200>>2]);
     $2202 = (((($threadContext) + (($747*96)|0)|0) + (($1969*12)|0)|0) + 5344|0);
     $2203 = Math_fround(HEAPF32[$2202>>2]);
     $2204 = (((($threadContext) + (($750*96)|0)|0) + (($1971*12)|0)|0) + 5336|0);
     $2205 = Math_fround(HEAPF32[$2204>>2]);
     $2206 = (((($threadContext) + (($750*96)|0)|0) + (($1971*12)|0)|0) + 5340|0);
     $2207 = Math_fround(HEAPF32[$2206>>2]);
     $2208 = (((($threadContext) + (($750*96)|0)|0) + (($1971*12)|0)|0) + 5344|0);
     $2209 = Math_fround(HEAPF32[$2208>>2]);
     $2210 = (((($threadContext) + (($753*96)|0)|0) + (($1973*12)|0)|0) + 5336|0);
     $2211 = Math_fround(HEAPF32[$2210>>2]);
     $2212 = (((($threadContext) + (($753*96)|0)|0) + (($1973*12)|0)|0) + 5340|0);
     $2213 = Math_fround(HEAPF32[$2212>>2]);
     $2214 = (((($threadContext) + (($753*96)|0)|0) + (($1973*12)|0)|0) + 5344|0);
     $2215 = Math_fround(HEAPF32[$2214>>2]);
     $2216 = Math_fround($709 * $2193);
     $2217 = Math_fround($709 * $2195);
     $2218 = Math_fround($709 * $2197);
     $2219 = Math_fround($611 * $2197);
     $2220 = Math_fround($613 * $2195);
     $2221 = Math_fround($2219 - $2220);
     $2222 = Math_fround($613 * $2193);
     $2223 = Math_fround($609 * $2197);
     $2224 = Math_fround($2222 - $2223);
     $2225 = Math_fround($609 * $2195);
     $2226 = Math_fround($611 * $2193);
     $2227 = Math_fround($2225 - $2226);
     $2228 = Math_fround($615 * $2221);
     $2229 = Math_fround($615 * $2224);
     $2230 = Math_fround($615 * $2227);
     $2231 = Math_fround($2216 + $2228);
     $2232 = Math_fround($2217 + $2229);
     $2233 = Math_fround($2218 + $2230);
     $2234 = Math_fround($609 * $2193);
     $2235 = Math_fround($611 * $2195);
     $2236 = Math_fround($2234 + $2235);
     $2237 = Math_fround($613 * $2197);
     $2238 = Math_fround($2236 + $2237);
     $2239 = Math_fround($609 * $2238);
     $2240 = Math_fround($611 * $2238);
     $2241 = Math_fround($613 * $2238);
     $2242 = Math_fround($2239 + $2231);
     $2243 = Math_fround($2240 + $2232);
     $2244 = Math_fround($2233 + $2241);
     $2245 = Math_fround($2242 * Math_fround(2.0));
     $2246 = Math_fround($2243 * Math_fround(2.0));
     $2247 = Math_fround($2244 * Math_fround(2.0));
     $2248 = Math_fround($711 * $2199);
     $2249 = Math_fround($711 * $2201);
     $2250 = Math_fround($711 * $2203);
     $2251 = Math_fround($618 * $2203);
     $2252 = Math_fround($620 * $2201);
     $2253 = Math_fround($2251 - $2252);
     $2254 = Math_fround($620 * $2199);
     $2255 = Math_fround($616 * $2203);
     $2256 = Math_fround($2254 - $2255);
     $2257 = Math_fround($616 * $2201);
     $2258 = Math_fround($618 * $2199);
     $2259 = Math_fround($2257 - $2258);
     $2260 = Math_fround($622 * $2253);
     $2261 = Math_fround($622 * $2256);
     $2262 = Math_fround($622 * $2259);
     $2263 = Math_fround($2248 + $2260);
     $2264 = Math_fround($2249 + $2261);
     $2265 = Math_fround($2250 + $2262);
     $2266 = Math_fround($616 * $2199);
     $2267 = Math_fround($618 * $2201);
     $2268 = Math_fround($2266 + $2267);
     $2269 = Math_fround($620 * $2203);
     $2270 = Math_fround($2268 + $2269);
     $2271 = Math_fround($616 * $2270);
     $2272 = Math_fround($618 * $2270);
     $2273 = Math_fround($620 * $2270);
     $2274 = Math_fround($2271 + $2263);
     $2275 = Math_fround($2272 + $2264);
     $2276 = Math_fround($2265 + $2273);
     $2277 = Math_fround($2274 * Math_fround(2.0));
     $2278 = Math_fround($2275 * Math_fround(2.0));
     $2279 = Math_fround($2276 * Math_fround(2.0));
     $2280 = Math_fround($713 * $2205);
     $2281 = Math_fround($713 * $2207);
     $2282 = Math_fround($713 * $2209);
     $2283 = Math_fround($625 * $2209);
     $2284 = Math_fround($627 * $2207);
     $2285 = Math_fround($2283 - $2284);
     $2286 = Math_fround($627 * $2205);
     $2287 = Math_fround($623 * $2209);
     $2288 = Math_fround($2286 - $2287);
     $2289 = Math_fround($623 * $2207);
     $2290 = Math_fround($625 * $2205);
     $2291 = Math_fround($2289 - $2290);
     $2292 = Math_fround($629 * $2285);
     $2293 = Math_fround($629 * $2288);
     $2294 = Math_fround($629 * $2291);
     $2295 = Math_fround($2280 + $2292);
     $2296 = Math_fround($2281 + $2293);
     $2297 = Math_fround($2282 + $2294);
     $2298 = Math_fround($623 * $2205);
     $2299 = Math_fround($625 * $2207);
     $2300 = Math_fround($2298 + $2299);
     $2301 = Math_fround($627 * $2209);
     $2302 = Math_fround($2300 + $2301);
     $2303 = Math_fround($623 * $2302);
     $2304 = Math_fround($625 * $2302);
     $2305 = Math_fround($627 * $2302);
     $2306 = Math_fround($2303 + $2295);
     $2307 = Math_fround($2304 + $2296);
     $2308 = Math_fround($2297 + $2305);
     $2309 = Math_fround($2306 * Math_fround(2.0));
     $2310 = Math_fround($2307 * Math_fround(2.0));
     $2311 = Math_fround($2308 * Math_fround(2.0));
     $2312 = Math_fround($715 * $2211);
     $2313 = Math_fround($715 * $2213);
     $2314 = Math_fround($715 * $2215);
     $2315 = Math_fround($632 * $2215);
     $2316 = Math_fround($634 * $2213);
     $2317 = Math_fround($2315 - $2316);
     $2318 = Math_fround($634 * $2211);
     $2319 = Math_fround($630 * $2215);
     $2320 = Math_fround($2318 - $2319);
     $2321 = Math_fround($630 * $2213);
     $2322 = Math_fround($632 * $2211);
     $2323 = Math_fround($2321 - $2322);
     $2324 = Math_fround($636 * $2317);
     $2325 = Math_fround($636 * $2320);
     $2326 = Math_fround($636 * $2323);
     $2327 = Math_fround($2312 + $2324);
     $2328 = Math_fround($2313 + $2325);
     $2329 = Math_fround($2314 + $2326);
     $2330 = Math_fround($630 * $2211);
     $2331 = Math_fround($632 * $2213);
     $2332 = Math_fround($2330 + $2331);
     $2333 = Math_fround($634 * $2215);
     $2334 = Math_fround($2332 + $2333);
     $2335 = Math_fround($630 * $2334);
     $2336 = Math_fround($632 * $2334);
     $2337 = Math_fround($634 * $2334);
     $2338 = Math_fround($2335 + $2327);
     $2339 = Math_fround($2336 + $2328);
     $2340 = Math_fround($2329 + $2337);
     $2341 = Math_fround($2338 * Math_fround(2.0));
     $2342 = Math_fround($2339 * Math_fround(2.0));
     $2343 = Math_fround($2340 * Math_fround(2.0));
     $2344 = Math_fround($552 + $2245);
     $2345 = Math_fround($560 + $2277);
     $2346 = Math_fround($568 + $2309);
     $2347 = Math_fround($576 + $2341);
     $2348 = Math_fround($554 + $2246);
     $2349 = Math_fround($562 + $2278);
     $2350 = Math_fround($570 + $2310);
     $2351 = Math_fround($578 + $2342);
     $2352 = Math_fround($556 + $2247);
     $2353 = Math_fround($564 + $2279);
     $2354 = Math_fround($572 + $2311);
     $2355 = Math_fround($580 + $2343);
     $2356 = Math_fround($2180 - $2344);
     $2357 = Math_fround($2181 - $2345);
     $2358 = Math_fround($2182 - $2346);
     $2359 = Math_fround($2183 - $2347);
     $2360 = Math_fround($2184 - $2348);
     $2361 = Math_fround($2185 - $2349);
     $2362 = Math_fround($2186 - $2350);
     $2363 = Math_fround($2187 - $2351);
     $2364 = Math_fround($2188 - $2352);
     $2365 = Math_fround($2189 - $2353);
     $2366 = Math_fround($2190 - $2354);
     $2367 = Math_fround($2191 - $2355);
     $2368 = Math_fround($1996 * $2082);
     $2369 = Math_fround($1998 * $2114);
     $2370 = Math_fround($2000 * $2146);
     $2371 = Math_fround($2002 * $2178);
     $2372 = Math_fround($1988 * $2083);
     $2373 = Math_fround($1990 * $2115);
     $2374 = Math_fround($1992 * $2147);
     $2375 = Math_fround($1994 * $2179);
     $2376 = Math_fround($2368 - $2372);
     $2377 = Math_fround($2369 - $2373);
     $2378 = Math_fround($2370 - $2374);
     $2379 = Math_fround($2371 - $2375);
     $2380 = Math_fround($1980 * $2083);
     $2381 = Math_fround($1982 * $2115);
     $2382 = Math_fround($1984 * $2147);
     $2383 = Math_fround($1986 * $2179);
     $2384 = Math_fround($1996 * $2081);
     $2385 = Math_fround($1998 * $2113);
     $2386 = Math_fround($2000 * $2145);
     $2387 = Math_fround($2002 * $2177);
     $2388 = Math_fround($2380 - $2384);
     $2389 = Math_fround($2381 - $2385);
     $2390 = Math_fround($2382 - $2386);
     $2391 = Math_fround($2383 - $2387);
     $2392 = Math_fround($1988 * $2081);
     $2393 = Math_fround($1990 * $2113);
     $2394 = Math_fround($1992 * $2145);
     $2395 = Math_fround($1994 * $2177);
     $2396 = Math_fround($1980 * $2082);
     $2397 = Math_fround($1982 * $2114);
     $2398 = Math_fround($1984 * $2146);
     $2399 = Math_fround($1986 * $2178);
     $2400 = Math_fround($2392 - $2396);
     $2401 = Math_fround($2393 - $2397);
     $2402 = Math_fround($2394 - $2398);
     $2403 = Math_fround($2395 - $2399);
     $2404 = Math_fround($444 * $2376);
     $2405 = Math_fround($445 * $2377);
     $2406 = Math_fround($446 * $2378);
     $2407 = Math_fround($447 * $2379);
     $2408 = Math_fround($456 * $2376);
     $2409 = Math_fround($457 * $2377);
     $2410 = Math_fround($458 * $2378);
     $2411 = Math_fround($459 * $2379);
     $2412 = Math_fround($468 * $2376);
     $2413 = Math_fround($469 * $2377);
     $2414 = Math_fround($470 * $2378);
     $2415 = Math_fround($471 * $2379);
     $2416 = Math_fround($448 * $2388);
     $2417 = Math_fround($449 * $2389);
     $2418 = Math_fround($450 * $2390);
     $2419 = Math_fround($451 * $2391);
     $2420 = Math_fround($2416 + $2404);
     $2421 = Math_fround($2417 + $2405);
     $2422 = Math_fround($2418 + $2406);
     $2423 = Math_fround($2419 + $2407);
     $2424 = Math_fround($460 * $2388);
     $2425 = Math_fround($461 * $2389);
     $2426 = Math_fround($462 * $2390);
     $2427 = Math_fround($463 * $2391);
     $2428 = Math_fround($2424 + $2408);
     $2429 = Math_fround($2425 + $2409);
     $2430 = Math_fround($2426 + $2410);
     $2431 = Math_fround($2427 + $2411);
     $2432 = Math_fround($472 * $2388);
     $2433 = Math_fround($473 * $2389);
     $2434 = Math_fround($474 * $2390);
     $2435 = Math_fround($475 * $2391);
     $2436 = Math_fround($2432 + $2412);
     $2437 = Math_fround($2433 + $2413);
     $2438 = Math_fround($2434 + $2414);
     $2439 = Math_fround($2435 + $2415);
     $2440 = Math_fround($452 * $2400);
     $2441 = Math_fround($453 * $2401);
     $2442 = Math_fround($454 * $2402);
     $2443 = Math_fround($455 * $2403);
     $2444 = Math_fround($2440 + $2420);
     $2445 = Math_fround($2441 + $2421);
     $2446 = Math_fround($2442 + $2422);
     $2447 = Math_fround($2443 + $2423);
     $2448 = Math_fround($464 * $2400);
     $2449 = Math_fround($465 * $2401);
     $2450 = Math_fround($466 * $2402);
     $2451 = Math_fround($467 * $2403);
     $2452 = Math_fround($2448 + $2428);
     $2453 = Math_fround($2449 + $2429);
     $2454 = Math_fround($2450 + $2430);
     $2455 = Math_fround($2451 + $2431);
     $2456 = Math_fround($476 * $2400);
     $2457 = Math_fround($477 * $2401);
     $2458 = Math_fround($478 * $2402);
     $2459 = Math_fround($479 * $2403);
     $2460 = Math_fround($2456 + $2436);
     $2461 = Math_fround($2457 + $2437);
     $2462 = Math_fround($2458 + $2438);
     $2463 = Math_fround($2459 + $2439);
     $2464 = Math_fround($2376 * $2444);
     $2465 = Math_fround($2377 * $2445);
     $2466 = Math_fround($2378 * $2446);
     $2467 = Math_fround($2379 * $2447);
     $2468 = Math_fround($2388 * $2452);
     $2469 = Math_fround($2389 * $2453);
     $2470 = Math_fround($2390 * $2454);
     $2471 = Math_fround($2391 * $2455);
     $2472 = Math_fround($2468 + $2464);
     $2473 = Math_fround($2469 + $2465);
     $2474 = Math_fround($2470 + $2466);
     $2475 = Math_fround($2471 + $2467);
     $2476 = Math_fround($2400 * $2460);
     $2477 = Math_fround($2401 * $2461);
     $2478 = Math_fround($2402 * $2462);
     $2479 = Math_fround($2403 * $2463);
     $2480 = Math_fround($2476 + $2472);
     $2481 = Math_fround($2477 + $2473);
     $2482 = Math_fround($2478 + $2474);
     $2483 = Math_fround($2479 + $2475);
     $2484 = Math_fround($296 + $2480);
     $2485 = Math_fround($297 + $2481);
     $2486 = Math_fround($298 + $2482);
     $2487 = Math_fround($299 + $2483);
     $2488 = Math_fround($1996 * $2246);
     $2489 = Math_fround($1998 * $2278);
     $2490 = Math_fround($2000 * $2310);
     $2491 = Math_fround($2002 * $2342);
     $2492 = Math_fround($1988 * $2247);
     $2493 = Math_fround($1990 * $2279);
     $2494 = Math_fround($1992 * $2311);
     $2495 = Math_fround($1994 * $2343);
     $2496 = Math_fround($2488 - $2492);
     $2497 = Math_fround($2489 - $2493);
     $2498 = Math_fround($2490 - $2494);
     $2499 = Math_fround($2491 - $2495);
     $2500 = Math_fround($1980 * $2247);
     $2501 = Math_fround($1982 * $2279);
     $2502 = Math_fround($1984 * $2311);
     $2503 = Math_fround($1986 * $2343);
     $2504 = Math_fround($1996 * $2245);
     $2505 = Math_fround($1998 * $2277);
     $2506 = Math_fround($2000 * $2309);
     $2507 = Math_fround($2002 * $2341);
     $2508 = Math_fround($2500 - $2504);
     $2509 = Math_fround($2501 - $2505);
     $2510 = Math_fround($2502 - $2506);
     $2511 = Math_fround($2503 - $2507);
     $2512 = Math_fround($1988 * $2245);
     $2513 = Math_fround($1990 * $2277);
     $2514 = Math_fround($1992 * $2309);
     $2515 = Math_fround($1994 * $2341);
     $2516 = Math_fround($1980 * $2246);
     $2517 = Math_fround($1982 * $2278);
     $2518 = Math_fround($1984 * $2310);
     $2519 = Math_fround($1986 * $2342);
     $2520 = Math_fround($2512 - $2516);
     $2521 = Math_fround($2513 - $2517);
     $2522 = Math_fround($2514 - $2518);
     $2523 = Math_fround($2515 - $2519);
     $2524 = Math_fround($480 * $2496);
     $2525 = Math_fround($481 * $2497);
     $2526 = Math_fround($482 * $2498);
     $2527 = Math_fround($483 * $2499);
     $2528 = Math_fround($492 * $2496);
     $2529 = Math_fround($493 * $2497);
     $2530 = Math_fround($494 * $2498);
     $2531 = Math_fround($495 * $2499);
     $2532 = Math_fround($504 * $2496);
     $2533 = Math_fround($505 * $2497);
     $2534 = Math_fround($506 * $2498);
     $2535 = Math_fround($507 * $2499);
     $2536 = Math_fround($484 * $2508);
     $2537 = Math_fround($485 * $2509);
     $2538 = Math_fround($486 * $2510);
     $2539 = Math_fround($487 * $2511);
     $2540 = Math_fround($2536 + $2524);
     $2541 = Math_fround($2537 + $2525);
     $2542 = Math_fround($2538 + $2526);
     $2543 = Math_fround($2539 + $2527);
     $2544 = Math_fround($496 * $2508);
     $2545 = Math_fround($497 * $2509);
     $2546 = Math_fround($498 * $2510);
     $2547 = Math_fround($499 * $2511);
     $2548 = Math_fround($2544 + $2528);
     $2549 = Math_fround($2545 + $2529);
     $2550 = Math_fround($2546 + $2530);
     $2551 = Math_fround($2547 + $2531);
     $2552 = Math_fround($508 * $2508);
     $2553 = Math_fround($509 * $2509);
     $2554 = Math_fround($510 * $2510);
     $2555 = Math_fround($511 * $2511);
     $2556 = Math_fround($2552 + $2532);
     $2557 = Math_fround($2553 + $2533);
     $2558 = Math_fround($2554 + $2534);
     $2559 = Math_fround($2555 + $2535);
     $2560 = Math_fround($488 * $2520);
     $2561 = Math_fround($489 * $2521);
     $2562 = Math_fround($490 * $2522);
     $2563 = Math_fround($491 * $2523);
     $2564 = Math_fround($2560 + $2540);
     $2565 = Math_fround($2561 + $2541);
     $2566 = Math_fround($2562 + $2542);
     $2567 = Math_fround($2563 + $2543);
     $2568 = Math_fround($500 * $2520);
     $2569 = Math_fround($501 * $2521);
     $2570 = Math_fround($502 * $2522);
     $2571 = Math_fround($503 * $2523);
     $2572 = Math_fround($2568 + $2548);
     $2573 = Math_fround($2569 + $2549);
     $2574 = Math_fround($2570 + $2550);
     $2575 = Math_fround($2571 + $2551);
     $2576 = Math_fround($512 * $2520);
     $2577 = Math_fround($513 * $2521);
     $2578 = Math_fround($514 * $2522);
     $2579 = Math_fround($515 * $2523);
     $2580 = Math_fround($2576 + $2556);
     $2581 = Math_fround($2577 + $2557);
     $2582 = Math_fround($2578 + $2558);
     $2583 = Math_fround($2579 + $2559);
     $2584 = Math_fround($2496 * $2564);
     $2585 = Math_fround($2497 * $2565);
     $2586 = Math_fround($2498 * $2566);
     $2587 = Math_fround($2499 * $2567);
     $2588 = Math_fround($2508 * $2572);
     $2589 = Math_fround($2509 * $2573);
     $2590 = Math_fround($2510 * $2574);
     $2591 = Math_fround($2511 * $2575);
     $2592 = Math_fround($2588 + $2584);
     $2593 = Math_fround($2589 + $2585);
     $2594 = Math_fround($2590 + $2586);
     $2595 = Math_fround($2591 + $2587);
     $2596 = Math_fround($2520 * $2580);
     $2597 = Math_fround($2521 * $2581);
     $2598 = Math_fround($2522 * $2582);
     $2599 = Math_fround($2523 * $2583);
     $2600 = Math_fround($2596 + $2592);
     $2601 = Math_fround($2597 + $2593);
     $2602 = Math_fround($2598 + $2594);
     $2603 = Math_fround($2599 + $2595);
     $2604 = Math_fround($300 + $2600);
     $2605 = Math_fround($302 + $2601);
     $2606 = Math_fround($304 + $2602);
     $2607 = Math_fround($306 + $2603);
     $2608 = Math_fround($2484 + $2604);
     $2609 = Math_fround($2485 + $2605);
     $2610 = Math_fround($2486 + $2606);
     $2611 = Math_fround($2487 + $2607);
     $2612 = (($ptr$18151$us) + 240|0);
     HEAPF32[$2612>>2] = $2496;
     $2613 = (($ptr$18151$us) + 244|0);
     HEAPF32[$2613>>2] = $2497;
     $2614 = (($ptr$18151$us) + 248|0);
     HEAPF32[$2614>>2] = $2498;
     $2615 = (($ptr$18151$us) + 252|0);
     HEAPF32[$2615>>2] = $2499;
     $2616 = (($ptr$18151$us) + 256|0);
     HEAPF32[$2616>>2] = $2508;
     $2617 = (($ptr$18151$us) + 260|0);
     HEAPF32[$2617>>2] = $2509;
     $2618 = (($ptr$18151$us) + 264|0);
     HEAPF32[$2618>>2] = $2510;
     $2619 = (($ptr$18151$us) + 268|0);
     HEAPF32[$2619>>2] = $2511;
     $2620 = (($ptr$18151$us) + 272|0);
     HEAPF32[$2620>>2] = $2520;
     $2621 = (($ptr$18151$us) + 276|0);
     HEAPF32[$2621>>2] = $2521;
     $2622 = (($ptr$18151$us) + 280|0);
     HEAPF32[$2622>>2] = $2522;
     $2623 = (($ptr$18151$us) + 284|0);
     HEAPF32[$2623>>2] = $2523;
     $2624 = Math_fround(-$2564);
     $2625 = Math_fround(-$2565);
     $2626 = Math_fround(-$2566);
     $2627 = Math_fround(-$2567);
     $2628 = (($ptr$18151$us) + 288|0);
     HEAPF32[$2628>>2] = $2624;
     $2629 = (($ptr$18151$us) + 292|0);
     HEAPF32[$2629>>2] = $2625;
     $2630 = (($ptr$18151$us) + 296|0);
     HEAPF32[$2630>>2] = $2626;
     $2631 = (($ptr$18151$us) + 300|0);
     HEAPF32[$2631>>2] = $2627;
     $2632 = Math_fround(-$2572);
     $2633 = Math_fround(-$2573);
     $2634 = Math_fround(-$2574);
     $2635 = Math_fround(-$2575);
     $2636 = (($ptr$18151$us) + 304|0);
     HEAPF32[$2636>>2] = $2632;
     $2637 = (($ptr$18151$us) + 308|0);
     HEAPF32[$2637>>2] = $2633;
     $2638 = (($ptr$18151$us) + 312|0);
     HEAPF32[$2638>>2] = $2634;
     $2639 = (($ptr$18151$us) + 316|0);
     HEAPF32[$2639>>2] = $2635;
     $2640 = Math_fround(-$2580);
     $2641 = Math_fround(-$2581);
     $2642 = Math_fround(-$2582);
     $2643 = Math_fround(-$2583);
     $2644 = (($ptr$18151$us) + 320|0);
     HEAPF32[$2644>>2] = $2640;
     $2645 = (($ptr$18151$us) + 324|0);
     HEAPF32[$2645>>2] = $2641;
     $2646 = (($ptr$18151$us) + 328|0);
     HEAPF32[$2646>>2] = $2642;
     $2647 = (($ptr$18151$us) + 332|0);
     HEAPF32[$2647>>2] = $2643;
     $2648 = $2608 > Math_fround(0.0);
     $2649 = $2609 > Math_fround(0.0);
     $2650 = $2610 > Math_fround(0.0);
     $2651 = $2611 > Math_fround(0.0);
     $2652 = Math_fround(Math_fround(0.800000011920928955078) / $2608);
     $2653 = Math_fround(Math_fround(0.800000011920928955078) / $2609);
     $2654 = Math_fround(Math_fround(0.800000011920928955078) / $2610);
     $2655 = Math_fround(Math_fround(0.800000011920928955078) / $2611);
     HEAPF32[$21>>2] = $2652;
     HEAPF32[$716>>2] = $2653;
     HEAPF32[$717>>2] = $2654;
     HEAPF32[$718>>2] = $2655;
     $b$a$i375$us = $2648 ? $21 : $20;
     ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;
     $2656 = Math_fround(HEAPF32[$b$a$i375$us>>2]);
     $a$pn4$i377$us = $2649 ? $21 : $20;
     $$in1$i378$us = (($a$pn4$i377$us) + 4|0);
     $2657 = Math_fround(HEAPF32[$$in1$i378$us>>2]);
     $b$a7$i379$us = $2650 ? $21 : $20;
     $$in2$i380$us = (($b$a7$i379$us) + 8|0);
     $2658 = Math_fround(HEAPF32[$$in2$i380$us>>2]);
     $a$pn6$i381$us = $2651 ? $21 : $20;
     $$in3$i382$us = (($a$pn6$i381$us) + 12|0);
     $2659 = Math_fround(HEAPF32[$$in3$i382$us>>2]);
     $2660 = Math_fround(HEAPF32[$1946>>2]);
     $2661 = Math_fround(HEAPF32[$1947>>2]);
     $2662 = Math_fround(HEAPF32[$1948>>2]);
     $2663 = Math_fround(HEAPF32[$1949>>2]);
     $2664 = Math_fround(HEAPF32[$1950>>2]);
     $2665 = Math_fround(HEAPF32[$1951>>2]);
     $2666 = Math_fround(HEAPF32[$1952>>2]);
     $2667 = Math_fround(HEAPF32[$1953>>2]);
     $2668 = Math_fround(HEAPF32[$1954>>2]);
     $2669 = Math_fround(HEAPF32[$1955>>2]);
     $2670 = Math_fround(HEAPF32[$1956>>2]);
     $2671 = Math_fround(HEAPF32[$1957>>2]);
     $2672 = Math_fround($1980 * $2660);
     $2673 = Math_fround($1982 * $2663);
     $2674 = Math_fround($1984 * $2666);
     $2675 = Math_fround($1986 * $2669);
     $2676 = Math_fround($1988 * $2661);
     $2677 = Math_fround($1990 * $2664);
     $2678 = Math_fround($1992 * $2667);
     $2679 = Math_fround($1994 * $2670);
     $2680 = Math_fround($2672 + $2676);
     $2681 = Math_fround($2673 + $2677);
     $2682 = Math_fround($2674 + $2678);
     $2683 = Math_fround($2675 + $2679);
     $2684 = Math_fround($1996 * $2662);
     $2685 = Math_fround($1998 * $2665);
     $2686 = Math_fround($2000 * $2668);
     $2687 = Math_fround($2002 * $2671);
     $2688 = Math_fround($2684 + $2680);
     $2689 = Math_fround($2685 + $2681);
     $2690 = Math_fround($2686 + $2682);
     $2691 = Math_fround($2687 + $2683);
     $2692 = Math_fround($2656 * $2688);
     $2693 = Math_fround($2657 * $2689);
     $2694 = Math_fround($2658 * $2690);
     $2695 = Math_fround($2659 * $2691);
     $2696 = Math_fround($1980 * $2356);
     $2697 = Math_fround($1982 * $2357);
     $2698 = Math_fround($1984 * $2358);
     $2699 = Math_fround($1986 * $2359);
     $2700 = Math_fround($1988 * $2360);
     $2701 = Math_fround($1990 * $2361);
     $2702 = Math_fround($1992 * $2362);
     $2703 = Math_fround($1994 * $2363);
     $2704 = Math_fround($2700 + $2696);
     $2705 = Math_fround($2701 + $2697);
     $2706 = Math_fround($2702 + $2698);
     $2707 = Math_fround($2703 + $2699);
     $2708 = Math_fround($1996 * $2364);
     $2709 = Math_fround($1998 * $2365);
     $2710 = Math_fround($2000 * $2366);
     $2711 = Math_fround($2002 * $2367);
     $2712 = Math_fround($2708 + $2704);
     $2713 = Math_fround($2709 + $2705);
     $2714 = Math_fround($2710 + $2706);
     $2715 = Math_fround($2711 + $2707);
     $2716 = Math_fround($2712 * $invDtF32);
     $2717 = Math_fround($2713 * $invDtF32);
     $2718 = Math_fround($2714 * $invDtF32);
     $2719 = Math_fround($2715 * $invDtF32);
     $2720 = Math_fround($2716 * $2656);
     $2721 = Math_fround($2717 * $2657);
     $2722 = Math_fround($2718 * $2658);
     $2723 = Math_fround($2719 * $2659);
     $2724 = Math_fround($$8111$us * $1980);
     $2725 = Math_fround($1975 * $1982);
     $2726 = Math_fround($$8112$us * $1984);
     $2727 = Math_fround($1978 * $1986);
     HEAPF32[$ptr$18151$us>>2] = $2724;
     $2728 = (($ptr$18151$us) + 4|0);
     HEAPF32[$2728>>2] = $2725;
     $2729 = (($ptr$18151$us) + 8|0);
     HEAPF32[$2729>>2] = $2726;
     $2730 = (($ptr$18151$us) + 12|0);
     HEAPF32[$2730>>2] = $2727;
     $2731 = Math_fround($$8111$us * $1988);
     $2732 = Math_fround($1975 * $1990);
     $2733 = Math_fround($$8112$us * $1992);
     $2734 = Math_fround($1978 * $1994);
     $2735 = (($ptr$18151$us) + 16|0);
     HEAPF32[$2735>>2] = $2731;
     $2736 = (($ptr$18151$us) + 20|0);
     HEAPF32[$2736>>2] = $2732;
     $2737 = (($ptr$18151$us) + 24|0);
     HEAPF32[$2737>>2] = $2733;
     $2738 = (($ptr$18151$us) + 28|0);
     HEAPF32[$2738>>2] = $2734;
     $2739 = Math_fround($$8111$us * $1996);
     $2740 = Math_fround($1975 * $1998);
     $2741 = Math_fround($$8112$us * $2000);
     $2742 = Math_fround($1978 * $2002);
     $2743 = (($ptr$18151$us) + 32|0);
     HEAPF32[$2743>>2] = $2739;
     $2744 = (($ptr$18151$us) + 36|0);
     HEAPF32[$2744>>2] = $2740;
     $2745 = (($ptr$18151$us) + 40|0);
     HEAPF32[$2745>>2] = $2741;
     $2746 = (($ptr$18151$us) + 44|0);
     HEAPF32[$2746>>2] = $2742;
     $2747 = (($ptr$18151$us) + 48|0);
     $2748 = (($ptr$18151$us) + 64|0);
     ;HEAP32[$2747+0>>2]=0|0;HEAP32[$2747+4>>2]=0|0;HEAP32[$2747+8>>2]=0|0;HEAP32[$2747+12>>2]=0|0;
     HEAPF32[$2748>>2] = $2376;
     $2749 = (($ptr$18151$us) + 68|0);
     HEAPF32[$2749>>2] = $2377;
     $2750 = (($ptr$18151$us) + 72|0);
     HEAPF32[$2750>>2] = $2378;
     $2751 = (($ptr$18151$us) + 76|0);
     HEAPF32[$2751>>2] = $2379;
     $2752 = (($ptr$18151$us) + 80|0);
     HEAPF32[$2752>>2] = $2388;
     $2753 = (($ptr$18151$us) + 84|0);
     HEAPF32[$2753>>2] = $2389;
     $2754 = (($ptr$18151$us) + 88|0);
     HEAPF32[$2754>>2] = $2390;
     $2755 = (($ptr$18151$us) + 92|0);
     HEAPF32[$2755>>2] = $2391;
     $2756 = (($ptr$18151$us) + 96|0);
     HEAPF32[$2756>>2] = $2400;
     $2757 = (($ptr$18151$us) + 100|0);
     HEAPF32[$2757>>2] = $2401;
     $2758 = (($ptr$18151$us) + 104|0);
     HEAPF32[$2758>>2] = $2402;
     $2759 = (($ptr$18151$us) + 108|0);
     HEAPF32[$2759>>2] = $2403;
     $2760 = (($ptr$18151$us) + 112|0);
     HEAPF32[$2760>>2] = $2444;
     $2761 = (($ptr$18151$us) + 116|0);
     HEAPF32[$2761>>2] = $2445;
     $2762 = (($ptr$18151$us) + 120|0);
     HEAPF32[$2762>>2] = $2446;
     $2763 = (($ptr$18151$us) + 124|0);
     HEAPF32[$2763>>2] = $2447;
     $2764 = (($ptr$18151$us) + 128|0);
     HEAPF32[$2764>>2] = $2452;
     $2765 = (($ptr$18151$us) + 132|0);
     HEAPF32[$2765>>2] = $2453;
     $2766 = (($ptr$18151$us) + 136|0);
     HEAPF32[$2766>>2] = $2454;
     $2767 = (($ptr$18151$us) + 140|0);
     HEAPF32[$2767>>2] = $2455;
     $2768 = (($ptr$18151$us) + 144|0);
     HEAPF32[$2768>>2] = $2460;
     $2769 = (($ptr$18151$us) + 148|0);
     HEAPF32[$2769>>2] = $2461;
     $2770 = (($ptr$18151$us) + 152|0);
     HEAPF32[$2770>>2] = $2462;
     $2771 = (($ptr$18151$us) + 156|0);
     HEAPF32[$2771>>2] = $2463;
     $2772 = Math_fround($2720 - $2692);
     $2773 = Math_fround($2721 - $2693);
     $2774 = Math_fround($2722 - $2694);
     $2775 = Math_fround($2723 - $2695);
     $2776 = (($ptr$18151$us) + 160|0);
     HEAPF32[$2776>>2] = $2772;
     $2777 = (($ptr$18151$us) + 164|0);
     HEAPF32[$2777>>2] = $2773;
     $2778 = (($ptr$18151$us) + 168|0);
     HEAPF32[$2778>>2] = $2774;
     $2779 = (($ptr$18151$us) + 172|0);
     HEAPF32[$2779>>2] = $2775;
     $2780 = (($ptr$18151$us) + 176|0);
     $2781 = (($ptr$18151$us) + 192|0);
     ;HEAP32[$2780+0>>2]=0|0;HEAP32[$2780+4>>2]=0|0;HEAP32[$2780+8>>2]=0|0;HEAP32[$2780+12>>2]=0|0;
     HEAPF32[$2781>>2] = $2720;
     $2782 = (($ptr$18151$us) + 196|0);
     HEAPF32[$2782>>2] = $2721;
     $2783 = (($ptr$18151$us) + 200|0);
     HEAPF32[$2783>>2] = $2722;
     $2784 = (($ptr$18151$us) + 204|0);
     HEAPF32[$2784>>2] = $2723;
     $2785 = (($ptr$18151$us) + 208|0);
     HEAPF32[$2785>>2] = $2656;
     $2786 = (($ptr$18151$us) + 212|0);
     HEAPF32[$2786>>2] = $2657;
     $2787 = (($ptr$18151$us) + 216|0);
     HEAPF32[$2787>>2] = $2658;
     $2788 = (($ptr$18151$us) + 220|0);
     HEAPF32[$2788>>2] = $2659;
     $2789 = $1966 ? $1932 : 0;
     $2790 = (($ptr$18151$us) + 224|0);
     HEAP32[$2790>>2] = $2789;
     $2791 = $1968 ? $1936 : 0;
     $2792 = (($ptr$18151$us) + 228|0);
     HEAP32[$2792>>2] = $2791;
     $2793 = $1970 ? $1940 : 0;
     $2794 = (($ptr$18151$us) + 232|0);
     HEAP32[$2794>>2] = $2793;
     $2795 = $1972 ? $1944 : 0;
     $2796 = (($ptr$18151$us) + 236|0);
     HEAP32[$2796>>2] = $2795;
     $2797 = Math_fround($2020 * $2082);
     $2798 = Math_fround($2022 * $2114);
     $2799 = Math_fround($2024 * $2146);
     $2800 = Math_fround($2026 * $2178);
     $2801 = Math_fround($2012 * $2083);
     $2802 = Math_fround($2014 * $2115);
     $2803 = Math_fround($2016 * $2147);
     $2804 = Math_fround($2018 * $2179);
     $2805 = Math_fround($2797 - $2801);
     $2806 = Math_fround($2798 - $2802);
     $2807 = Math_fround($2799 - $2803);
     $2808 = Math_fround($2800 - $2804);
     $2809 = Math_fround($2004 * $2083);
     $2810 = Math_fround($2006 * $2115);
     $2811 = Math_fround($2008 * $2147);
     $2812 = Math_fround($2010 * $2179);
     $2813 = Math_fround($2020 * $2081);
     $2814 = Math_fround($2022 * $2113);
     $2815 = Math_fround($2024 * $2145);
     $2816 = Math_fround($2026 * $2177);
     $2817 = Math_fround($2809 - $2813);
     $2818 = Math_fround($2810 - $2814);
     $2819 = Math_fround($2811 - $2815);
     $2820 = Math_fround($2812 - $2816);
     $2821 = Math_fround($2012 * $2081);
     $2822 = Math_fround($2014 * $2113);
     $2823 = Math_fround($2016 * $2145);
     $2824 = Math_fround($2018 * $2177);
     $2825 = Math_fround($2004 * $2082);
     $2826 = Math_fround($2006 * $2114);
     $2827 = Math_fround($2008 * $2146);
     $2828 = Math_fround($2010 * $2178);
     $2829 = Math_fround($2821 - $2825);
     $2830 = Math_fround($2822 - $2826);
     $2831 = Math_fround($2823 - $2827);
     $2832 = Math_fround($2824 - $2828);
     $2833 = Math_fround($444 * $2805);
     $2834 = Math_fround($445 * $2806);
     $2835 = Math_fround($446 * $2807);
     $2836 = Math_fround($447 * $2808);
     $2837 = Math_fround($456 * $2805);
     $2838 = Math_fround($457 * $2806);
     $2839 = Math_fround($458 * $2807);
     $2840 = Math_fround($459 * $2808);
     $2841 = Math_fround($468 * $2805);
     $2842 = Math_fround($469 * $2806);
     $2843 = Math_fround($470 * $2807);
     $2844 = Math_fround($471 * $2808);
     $2845 = Math_fround($448 * $2817);
     $2846 = Math_fround($449 * $2818);
     $2847 = Math_fround($450 * $2819);
     $2848 = Math_fround($451 * $2820);
     $2849 = Math_fround($2845 + $2833);
     $2850 = Math_fround($2846 + $2834);
     $2851 = Math_fround($2847 + $2835);
     $2852 = Math_fround($2848 + $2836);
     $2853 = Math_fround($460 * $2817);
     $2854 = Math_fround($461 * $2818);
     $2855 = Math_fround($462 * $2819);
     $2856 = Math_fround($463 * $2820);
     $2857 = Math_fround($2853 + $2837);
     $2858 = Math_fround($2854 + $2838);
     $2859 = Math_fround($2855 + $2839);
     $2860 = Math_fround($2856 + $2840);
     $2861 = Math_fround($472 * $2817);
     $2862 = Math_fround($473 * $2818);
     $2863 = Math_fround($474 * $2819);
     $2864 = Math_fround($475 * $2820);
     $2865 = Math_fround($2861 + $2841);
     $2866 = Math_fround($2862 + $2842);
     $2867 = Math_fround($2863 + $2843);
     $2868 = Math_fround($2864 + $2844);
     $2869 = Math_fround($452 * $2829);
     $2870 = Math_fround($453 * $2830);
     $2871 = Math_fround($454 * $2831);
     $2872 = Math_fround($455 * $2832);
     $2873 = Math_fround($2869 + $2849);
     $2874 = Math_fround($2870 + $2850);
     $2875 = Math_fround($2871 + $2851);
     $2876 = Math_fround($2872 + $2852);
     $2877 = Math_fround($464 * $2829);
     $2878 = Math_fround($465 * $2830);
     $2879 = Math_fround($466 * $2831);
     $2880 = Math_fround($467 * $2832);
     $2881 = Math_fround($2877 + $2857);
     $2882 = Math_fround($2878 + $2858);
     $2883 = Math_fround($2879 + $2859);
     $2884 = Math_fround($2880 + $2860);
     $2885 = Math_fround($476 * $2829);
     $2886 = Math_fround($477 * $2830);
     $2887 = Math_fround($478 * $2831);
     $2888 = Math_fround($479 * $2832);
     $2889 = Math_fround($2885 + $2865);
     $2890 = Math_fround($2886 + $2866);
     $2891 = Math_fround($2887 + $2867);
     $2892 = Math_fround($2888 + $2868);
     $2893 = Math_fround($2805 * $2873);
     $2894 = Math_fround($2806 * $2874);
     $2895 = Math_fround($2807 * $2875);
     $2896 = Math_fround($2808 * $2876);
     $2897 = Math_fround($2817 * $2881);
     $2898 = Math_fround($2818 * $2882);
     $2899 = Math_fround($2819 * $2883);
     $2900 = Math_fround($2820 * $2884);
     $2901 = Math_fround($2897 + $2893);
     $2902 = Math_fround($2898 + $2894);
     $2903 = Math_fround($2899 + $2895);
     $2904 = Math_fround($2900 + $2896);
     $2905 = Math_fround($2829 * $2889);
     $2906 = Math_fround($2830 * $2890);
     $2907 = Math_fround($2831 * $2891);
     $2908 = Math_fround($2832 * $2892);
     $2909 = Math_fround($2905 + $2901);
     $2910 = Math_fround($2906 + $2902);
     $2911 = Math_fround($2907 + $2903);
     $2912 = Math_fround($2908 + $2904);
     $2913 = Math_fround($296 + $2909);
     $2914 = Math_fround($297 + $2910);
     $2915 = Math_fround($298 + $2911);
     $2916 = Math_fround($299 + $2912);
     $2917 = Math_fround($2020 * $2246);
     $2918 = Math_fround($2022 * $2278);
     $2919 = Math_fround($2024 * $2310);
     $2920 = Math_fround($2026 * $2342);
     $2921 = Math_fround($2012 * $2247);
     $2922 = Math_fround($2014 * $2279);
     $2923 = Math_fround($2016 * $2311);
     $2924 = Math_fround($2018 * $2343);
     $2925 = Math_fround($2917 - $2921);
     $2926 = Math_fround($2918 - $2922);
     $2927 = Math_fround($2919 - $2923);
     $2928 = Math_fround($2920 - $2924);
     $2929 = Math_fround($2004 * $2247);
     $2930 = Math_fround($2006 * $2279);
     $2931 = Math_fround($2008 * $2311);
     $2932 = Math_fround($2010 * $2343);
     $2933 = Math_fround($2020 * $2245);
     $2934 = Math_fround($2022 * $2277);
     $2935 = Math_fround($2024 * $2309);
     $2936 = Math_fround($2026 * $2341);
     $2937 = Math_fround($2929 - $2933);
     $2938 = Math_fround($2930 - $2934);
     $2939 = Math_fround($2931 - $2935);
     $2940 = Math_fround($2932 - $2936);
     $2941 = Math_fround($2012 * $2245);
     $2942 = Math_fround($2014 * $2277);
     $2943 = Math_fround($2016 * $2309);
     $2944 = Math_fround($2018 * $2341);
     $2945 = Math_fround($2004 * $2246);
     $2946 = Math_fround($2006 * $2278);
     $2947 = Math_fround($2008 * $2310);
     $2948 = Math_fround($2010 * $2342);
     $2949 = Math_fround($2941 - $2945);
     $2950 = Math_fround($2942 - $2946);
     $2951 = Math_fround($2943 - $2947);
     $2952 = Math_fround($2944 - $2948);
     $2953 = Math_fround($480 * $2925);
     $2954 = Math_fround($481 * $2926);
     $2955 = Math_fround($482 * $2927);
     $2956 = Math_fround($483 * $2928);
     $2957 = Math_fround($492 * $2925);
     $2958 = Math_fround($493 * $2926);
     $2959 = Math_fround($494 * $2927);
     $2960 = Math_fround($495 * $2928);
     $2961 = Math_fround($504 * $2925);
     $2962 = Math_fround($505 * $2926);
     $2963 = Math_fround($506 * $2927);
     $2964 = Math_fround($507 * $2928);
     $2965 = Math_fround($484 * $2937);
     $2966 = Math_fround($485 * $2938);
     $2967 = Math_fround($486 * $2939);
     $2968 = Math_fround($487 * $2940);
     $2969 = Math_fround($2965 + $2953);
     $2970 = Math_fround($2966 + $2954);
     $2971 = Math_fround($2967 + $2955);
     $2972 = Math_fround($2968 + $2956);
     $2973 = Math_fround($496 * $2937);
     $2974 = Math_fround($497 * $2938);
     $2975 = Math_fround($498 * $2939);
     $2976 = Math_fround($499 * $2940);
     $2977 = Math_fround($2973 + $2957);
     $2978 = Math_fround($2974 + $2958);
     $2979 = Math_fround($2975 + $2959);
     $2980 = Math_fround($2976 + $2960);
     $2981 = Math_fround($508 * $2937);
     $2982 = Math_fround($509 * $2938);
     $2983 = Math_fround($510 * $2939);
     $2984 = Math_fround($511 * $2940);
     $2985 = Math_fround($2981 + $2961);
     $2986 = Math_fround($2982 + $2962);
     $2987 = Math_fround($2983 + $2963);
     $2988 = Math_fround($2984 + $2964);
     $2989 = Math_fround($488 * $2949);
     $2990 = Math_fround($489 * $2950);
     $2991 = Math_fround($490 * $2951);
     $2992 = Math_fround($491 * $2952);
     $2993 = Math_fround($2989 + $2969);
     $2994 = Math_fround($2990 + $2970);
     $2995 = Math_fround($2991 + $2971);
     $2996 = Math_fround($2992 + $2972);
     $2997 = Math_fround($500 * $2949);
     $2998 = Math_fround($501 * $2950);
     $2999 = Math_fround($502 * $2951);
     $3000 = Math_fround($503 * $2952);
     $3001 = Math_fround($2997 + $2977);
     $3002 = Math_fround($2998 + $2978);
     $3003 = Math_fround($2999 + $2979);
     $3004 = Math_fround($3000 + $2980);
     $3005 = Math_fround($512 * $2949);
     $3006 = Math_fround($513 * $2950);
     $3007 = Math_fround($514 * $2951);
     $3008 = Math_fround($515 * $2952);
     $3009 = Math_fround($3005 + $2985);
     $3010 = Math_fround($3006 + $2986);
     $3011 = Math_fround($3007 + $2987);
     $3012 = Math_fround($3008 + $2988);
     $3013 = Math_fround($2925 * $2993);
     $3014 = Math_fround($2926 * $2994);
     $3015 = Math_fround($2927 * $2995);
     $3016 = Math_fround($2928 * $2996);
     $3017 = Math_fround($2937 * $3001);
     $3018 = Math_fround($2938 * $3002);
     $3019 = Math_fround($2939 * $3003);
     $3020 = Math_fround($2940 * $3004);
     $3021 = Math_fround($3017 + $3013);
     $3022 = Math_fround($3018 + $3014);
     $3023 = Math_fround($3019 + $3015);
     $3024 = Math_fround($3020 + $3016);
     $3025 = Math_fround($2949 * $3009);
     $3026 = Math_fround($2950 * $3010);
     $3027 = Math_fround($2951 * $3011);
     $3028 = Math_fround($2952 * $3012);
     $3029 = Math_fround($3025 + $3021);
     $3030 = Math_fround($3026 + $3022);
     $3031 = Math_fround($3027 + $3023);
     $3032 = Math_fround($3028 + $3024);
     $3033 = Math_fround($300 + $3029);
     $3034 = Math_fround($302 + $3030);
     $3035 = Math_fround($304 + $3031);
     $3036 = Math_fround($306 + $3032);
     $3037 = Math_fround($2913 + $3033);
     $3038 = Math_fround($2914 + $3034);
     $3039 = Math_fround($2915 + $3035);
     $3040 = Math_fround($2916 + $3036);
     $3041 = (($ptr$18151$us) + ($$sum24)|0);
     HEAPF32[$3041>>2] = $2925;
     $3042 = (($ptr$18151$us) + ($$sum8093)|0);
     HEAPF32[$3042>>2] = $2926;
     $3043 = (($ptr$18151$us) + ($$sum8094)|0);
     HEAPF32[$3043>>2] = $2927;
     $3044 = (($ptr$18151$us) + ($$sum8095)|0);
     HEAPF32[$3044>>2] = $2928;
     $3045 = (($ptr$18151$us) + ($$sum25)|0);
     HEAPF32[$3045>>2] = $2937;
     $3046 = (($ptr$18151$us) + ($$sum8096)|0);
     HEAPF32[$3046>>2] = $2938;
     $3047 = (($ptr$18151$us) + ($$sum8097)|0);
     HEAPF32[$3047>>2] = $2939;
     $3048 = (($ptr$18151$us) + ($$sum8098)|0);
     HEAPF32[$3048>>2] = $2940;
     $3049 = (($ptr$18151$us) + ($$sum26)|0);
     HEAPF32[$3049>>2] = $2949;
     $3050 = (($ptr$18151$us) + ($$sum8099)|0);
     HEAPF32[$3050>>2] = $2950;
     $3051 = (($ptr$18151$us) + ($$sum8100)|0);
     HEAPF32[$3051>>2] = $2951;
     $3052 = (($ptr$18151$us) + ($$sum8101)|0);
     HEAPF32[$3052>>2] = $2952;
     $3053 = (($ptr$18151$us) + ($$sum27)|0);
     $3054 = Math_fround(-$2993);
     $3055 = Math_fround(-$2994);
     $3056 = Math_fround(-$2995);
     $3057 = Math_fround(-$2996);
     HEAPF32[$3053>>2] = $3054;
     $3058 = (($ptr$18151$us) + ($$sum8102)|0);
     HEAPF32[$3058>>2] = $3055;
     $3059 = (($ptr$18151$us) + ($$sum8103)|0);
     HEAPF32[$3059>>2] = $3056;
     $3060 = (($ptr$18151$us) + ($$sum8104)|0);
     HEAPF32[$3060>>2] = $3057;
     $3061 = (($ptr$18151$us) + ($$sum28)|0);
     $3062 = Math_fround(-$3001);
     $3063 = Math_fround(-$3002);
     $3064 = Math_fround(-$3003);
     $3065 = Math_fround(-$3004);
     HEAPF32[$3061>>2] = $3062;
     $3066 = (($ptr$18151$us) + ($$sum8105)|0);
     HEAPF32[$3066>>2] = $3063;
     $3067 = (($ptr$18151$us) + ($$sum8106)|0);
     HEAPF32[$3067>>2] = $3064;
     $3068 = (($ptr$18151$us) + ($$sum8107)|0);
     HEAPF32[$3068>>2] = $3065;
     $3069 = (($ptr$18151$us) + ($$sum29)|0);
     $3070 = Math_fround(-$3009);
     $3071 = Math_fround(-$3010);
     $3072 = Math_fround(-$3011);
     $3073 = Math_fround(-$3012);
     HEAPF32[$3069>>2] = $3070;
     $3074 = (($ptr$18151$us) + ($$sum8108)|0);
     HEAPF32[$3074>>2] = $3071;
     $3075 = (($ptr$18151$us) + ($$sum8109)|0);
     HEAPF32[$3075>>2] = $3072;
     $3076 = (($ptr$18151$us) + ($$sum8110)|0);
     HEAPF32[$3076>>2] = $3073;
     $3077 = $3037 > Math_fround(0.0);
     $3078 = $3038 > Math_fround(0.0);
     $3079 = $3039 > Math_fround(0.0);
     $3080 = $3040 > Math_fround(0.0);
     $3081 = Math_fround(Math_fround(0.800000011920928955078) / $3037);
     $3082 = Math_fround(Math_fround(0.800000011920928955078) / $3038);
     $3083 = Math_fround(Math_fround(0.800000011920928955078) / $3039);
     $3084 = Math_fround(Math_fround(0.800000011920928955078) / $3040);
     HEAPF32[$23>>2] = $3081;
     HEAPF32[$719>>2] = $3082;
     HEAPF32[$720>>2] = $3083;
     HEAPF32[$721>>2] = $3084;
     $b$a$i$us = $3077 ? $23 : $22;
     ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;
     $3085 = Math_fround(HEAPF32[$b$a$i$us>>2]);
     $a$pn4$i$us = $3078 ? $23 : $22;
     $$in1$i$us = (($a$pn4$i$us) + 4|0);
     $3086 = Math_fround(HEAPF32[$$in1$i$us>>2]);
     $b$a7$i$us = $3079 ? $23 : $22;
     $$in2$i$us = (($b$a7$i$us) + 8|0);
     $3087 = Math_fround(HEAPF32[$$in2$i$us>>2]);
     $a$pn6$i$us = $3080 ? $23 : $22;
     $$in3$i$us = (($a$pn6$i$us) + 12|0);
     $3088 = Math_fround(HEAPF32[$$in3$i$us>>2]);
     $3089 = Math_fround(HEAPF32[$1946>>2]);
     $3090 = Math_fround(HEAPF32[$1947>>2]);
     $3091 = Math_fround(HEAPF32[$1948>>2]);
     $3092 = Math_fround(HEAPF32[$1949>>2]);
     $3093 = Math_fround(HEAPF32[$1950>>2]);
     $3094 = Math_fround(HEAPF32[$1951>>2]);
     $3095 = Math_fround(HEAPF32[$1952>>2]);
     $3096 = Math_fround(HEAPF32[$1953>>2]);
     $3097 = Math_fround(HEAPF32[$1954>>2]);
     $3098 = Math_fround(HEAPF32[$1955>>2]);
     $3099 = Math_fround(HEAPF32[$1956>>2]);
     $3100 = Math_fround(HEAPF32[$1957>>2]);
     $3101 = Math_fround($2004 * $3089);
     $3102 = Math_fround($2006 * $3092);
     $3103 = Math_fround($2008 * $3095);
     $3104 = Math_fround($2010 * $3098);
     $3105 = Math_fround($2012 * $3090);
     $3106 = Math_fround($2014 * $3093);
     $3107 = Math_fround($2016 * $3096);
     $3108 = Math_fround($2018 * $3099);
     $3109 = Math_fround($3101 + $3105);
     $3110 = Math_fround($3102 + $3106);
     $3111 = Math_fround($3103 + $3107);
     $3112 = Math_fround($3104 + $3108);
     $3113 = Math_fround($2020 * $3091);
     $3114 = Math_fround($2022 * $3094);
     $3115 = Math_fround($2024 * $3097);
     $3116 = Math_fround($2026 * $3100);
     $3117 = Math_fround($3113 + $3109);
     $3118 = Math_fround($3114 + $3110);
     $3119 = Math_fround($3115 + $3111);
     $3120 = Math_fround($3116 + $3112);
     $3121 = Math_fround($2004 * $2356);
     $3122 = Math_fround($2006 * $2357);
     $3123 = Math_fround($2008 * $2358);
     $3124 = Math_fround($2010 * $2359);
     $3125 = Math_fround($2012 * $2360);
     $3126 = Math_fround($2014 * $2361);
     $3127 = Math_fround($2016 * $2362);
     $3128 = Math_fround($2018 * $2363);
     $3129 = Math_fround($3125 + $3121);
     $3130 = Math_fround($3126 + $3122);
     $3131 = Math_fround($3127 + $3123);
     $3132 = Math_fround($3128 + $3124);
     $3133 = Math_fround($2020 * $2364);
     $3134 = Math_fround($2022 * $2365);
     $3135 = Math_fround($2024 * $2366);
     $3136 = Math_fround($2026 * $2367);
     $3137 = Math_fround($3133 + $3129);
     $3138 = Math_fround($3134 + $3130);
     $3139 = Math_fround($3135 + $3131);
     $3140 = Math_fround($3136 + $3132);
     $3141 = Math_fround($3137 * $invDtF32);
     $3142 = Math_fround($3138 * $invDtF32);
     $3143 = Math_fround($3139 * $invDtF32);
     $3144 = Math_fround($3140 * $invDtF32);
     $3145 = Math_fround($$8111$us * $2004);
     $3146 = Math_fround($1975 * $2006);
     $3147 = Math_fround($$8112$us * $2008);
     $3148 = Math_fround($1978 * $2010);
     HEAPF32[$1964>>2] = $3145;
     $3149 = (($ptr$18151$us) + ($$sum80488049)|0);
     HEAPF32[$3149>>2] = $3146;
     $3150 = (($ptr$18151$us) + ($$sum80508051)|0);
     HEAPF32[$3150>>2] = $3147;
     $3151 = (($ptr$18151$us) + ($$sum80528053)|0);
     HEAPF32[$3151>>2] = $3148;
     $3152 = (($ptr$18151$us) + ($$sum7)|0);
     $3153 = Math_fround($$8111$us * $2012);
     $3154 = Math_fround($1975 * $2014);
     $3155 = Math_fround($$8112$us * $2016);
     $3156 = Math_fround($1978 * $2018);
     HEAPF32[$3152>>2] = $3153;
     $3157 = (($ptr$18151$us) + ($$sum8054)|0);
     HEAPF32[$3157>>2] = $3154;
     $3158 = (($ptr$18151$us) + ($$sum8055)|0);
     HEAPF32[$3158>>2] = $3155;
     $3159 = (($ptr$18151$us) + ($$sum8056)|0);
     HEAPF32[$3159>>2] = $3156;
     $3160 = (($ptr$18151$us) + ($$sum8)|0);
     $3161 = Math_fround($$8111$us * $2020);
     $3162 = Math_fround($1975 * $2022);
     $3163 = Math_fround($$8112$us * $2024);
     $3164 = Math_fround($1978 * $2026);
     HEAPF32[$3160>>2] = $3161;
     $3165 = (($ptr$18151$us) + ($$sum8057)|0);
     HEAPF32[$3165>>2] = $3162;
     $3166 = (($ptr$18151$us) + ($$sum8058)|0);
     HEAPF32[$3166>>2] = $3163;
     $3167 = (($ptr$18151$us) + ($$sum8059)|0);
     HEAPF32[$3167>>2] = $3164;
     $3168 = (($ptr$18151$us) + ($$sum9)|0);
     HEAPF32[$3168>>2] = Math_fround(0.0);
     $3169 = (($ptr$18151$us) + ($$sum8060)|0);
     HEAPF32[$3169>>2] = Math_fround(0.0);
     $3170 = (($ptr$18151$us) + ($$sum8061)|0);
     HEAPF32[$3170>>2] = Math_fround(0.0);
     $3171 = (($ptr$18151$us) + ($$sum8062)|0);
     HEAPF32[$3171>>2] = Math_fround(0.0);
     $3172 = (($ptr$18151$us) + ($$sum10)|0);
     HEAPF32[$3172>>2] = $2805;
     $3173 = (($ptr$18151$us) + ($$sum8063)|0);
     HEAPF32[$3173>>2] = $2806;
     $3174 = (($ptr$18151$us) + ($$sum8064)|0);
     HEAPF32[$3174>>2] = $2807;
     $3175 = (($ptr$18151$us) + ($$sum8065)|0);
     HEAPF32[$3175>>2] = $2808;
     $3176 = (($ptr$18151$us) + ($$sum11)|0);
     HEAPF32[$3176>>2] = $2817;
     $3177 = (($ptr$18151$us) + ($$sum8066)|0);
     HEAPF32[$3177>>2] = $2818;
     $3178 = (($ptr$18151$us) + ($$sum8067)|0);
     HEAPF32[$3178>>2] = $2819;
     $3179 = (($ptr$18151$us) + ($$sum8068)|0);
     HEAPF32[$3179>>2] = $2820;
     $3180 = (($ptr$18151$us) + ($$sum12)|0);
     HEAPF32[$3180>>2] = $2829;
     $3181 = (($ptr$18151$us) + ($$sum8069)|0);
     HEAPF32[$3181>>2] = $2830;
     $3182 = (($ptr$18151$us) + ($$sum8070)|0);
     HEAPF32[$3182>>2] = $2831;
     $3183 = (($ptr$18151$us) + ($$sum8071)|0);
     HEAPF32[$3183>>2] = $2832;
     $3184 = (($ptr$18151$us) + ($$sum13)|0);
     HEAPF32[$3184>>2] = $2873;
     $3185 = (($ptr$18151$us) + ($$sum8072)|0);
     HEAPF32[$3185>>2] = $2874;
     $3186 = (($ptr$18151$us) + ($$sum8073)|0);
     HEAPF32[$3186>>2] = $2875;
     $3187 = (($ptr$18151$us) + ($$sum8074)|0);
     HEAPF32[$3187>>2] = $2876;
     $3188 = (($ptr$18151$us) + ($$sum14)|0);
     HEAPF32[$3188>>2] = $2881;
     $3189 = (($ptr$18151$us) + ($$sum8075)|0);
     HEAPF32[$3189>>2] = $2882;
     $3190 = (($ptr$18151$us) + ($$sum8076)|0);
     HEAPF32[$3190>>2] = $2883;
     $3191 = (($ptr$18151$us) + ($$sum8077)|0);
     HEAPF32[$3191>>2] = $2884;
     $3192 = (($ptr$18151$us) + ($$sum15)|0);
     HEAPF32[$3192>>2] = $2889;
     $3193 = (($ptr$18151$us) + ($$sum8078)|0);
     HEAPF32[$3193>>2] = $2890;
     $3194 = (($ptr$18151$us) + ($$sum8079)|0);
     HEAPF32[$3194>>2] = $2891;
     $3195 = (($ptr$18151$us) + ($$sum8080)|0);
     HEAPF32[$3195>>2] = $2892;
     $3196 = (($ptr$18151$us) + ($$sum16)|0);
     $3197 = Math_fround($3141 - $3117);
     $3198 = Math_fround($3142 - $3118);
     $3199 = Math_fround($3143 - $3119);
     $3200 = Math_fround($3144 - $3120);
     $3201 = Math_fround($3085 * $3197);
     $3202 = Math_fround($3086 * $3198);
     $3203 = Math_fround($3087 * $3199);
     $3204 = Math_fround($3088 * $3200);
     HEAPF32[$3196>>2] = $3201;
     $3205 = (($ptr$18151$us) + ($$sum8081)|0);
     HEAPF32[$3205>>2] = $3202;
     $3206 = (($ptr$18151$us) + ($$sum8082)|0);
     HEAPF32[$3206>>2] = $3203;
     $3207 = (($ptr$18151$us) + ($$sum8083)|0);
     HEAPF32[$3207>>2] = $3204;
     $3208 = (($ptr$18151$us) + ($$sum17)|0);
     HEAPF32[$3208>>2] = Math_fround(0.0);
     $3209 = (($ptr$18151$us) + ($$sum8084)|0);
     HEAPF32[$3209>>2] = Math_fround(0.0);
     $3210 = (($ptr$18151$us) + ($$sum8085)|0);
     HEAPF32[$3210>>2] = Math_fround(0.0);
     $3211 = (($ptr$18151$us) + ($$sum8086)|0);
     HEAPF32[$3211>>2] = Math_fround(0.0);
     $3212 = (($ptr$18151$us) + ($$sum18)|0);
     $3213 = Math_fround($3141 * $3085);
     $3214 = Math_fround($3142 * $3086);
     $3215 = Math_fround($3143 * $3087);
     $3216 = Math_fround($3144 * $3088);
     HEAPF32[$3212>>2] = $3213;
     $3217 = (($ptr$18151$us) + ($$sum8087)|0);
     HEAPF32[$3217>>2] = $3214;
     $3218 = (($ptr$18151$us) + ($$sum8088)|0);
     HEAPF32[$3218>>2] = $3215;
     $3219 = (($ptr$18151$us) + ($$sum8089)|0);
     HEAPF32[$3219>>2] = $3216;
     $3220 = (($ptr$18151$us) + ($$sum19)|0);
     HEAPF32[$3220>>2] = $3085;
     $3221 = (($ptr$18151$us) + ($$sum8090)|0);
     HEAPF32[$3221>>2] = $3086;
     $3222 = (($ptr$18151$us) + ($$sum8091)|0);
     HEAPF32[$3222>>2] = $3087;
     $3223 = (($ptr$18151$us) + ($$sum8092)|0);
     HEAPF32[$3223>>2] = $3088;
     $3224 = (($ptr$18151$us) + ($$sum20)|0);
     HEAP32[$3224>>2] = $2789;
     $3225 = (($ptr$18151$us) + ($$sum21)|0);
     HEAP32[$3225>>2] = $2791;
     $3226 = (($ptr$18151$us) + ($$sum22)|0);
     HEAP32[$3226>>2] = $2793;
     $3227 = (($ptr$18151$us) + ($$sum23)|0);
     HEAP32[$3227>>2] = $2795;
     $3228 = (($j$08150$us) + 1)|0;
     $3229 = ($3228>>>0)<($1742>>>0);
     if ($3229) {
      $1974 = $$8111$us;$1976 = $1975;$1977 = $$8112$us;$1979 = $1978;$1981 = $1980;$1983 = $1982;$1985 = $1984;$1987 = $1986;$1989 = $1988;$1991 = $1990;$1993 = $1992;$1995 = $1994;$1997 = $1996;$1999 = $1998;$2001 = $2000;$2003 = $2002;$2005 = $2004;$2007 = $2006;$2009 = $2008;$2011 = $2010;$2013 = $2012;$2015 = $2014;$2017 = $2016;$2019 = $2018;$2021 = $2020;$2023 = $2022;$2025 = $2024;$2027 = $2026;$index0$08146$us = $1967;$index1$08147$us = $1969;$index2$08148$us = $1971;$index3$08149$us = $1973;$j$08150$us = $3228;$ptr$18151$us = $1965;
     } else {
      break;
     }
    }
   } else {
    $3243 = Math_fround(1.0);$3245 = Math_fround(1.0);$3246 = Math_fround(1.0);$3248 = Math_fround(1.0);$3250 = $1880;$3252 = $1881;$3254 = $1882;$3256 = $1883;$3258 = $1884;$3260 = $1885;$3262 = $1886;$3264 = $1887;$3266 = $1888;$3268 = $1889;$3270 = $1890;$3272 = $1891;$3274 = $1900;$3276 = $1901;$3278 = $1902;$3280 = $1903;$3282 = $1912;$3284 = $1913;$3286 = $1914;$3288 = $1915;$3290 = $1924;$3292 = $1925;$3294 = $1926;$3296 = $1927;$index0$08146 = 0;$index1$08147 = 0;$index2$08148 = 0;$index3$08149 = 0;$j$08150 = 0;$ptr$18151 = $p$0;
    while(1) {
     $3230 = (($ptr$18151) + 384|0);
     $3231 = (($ptr$18151) + 512|0);
     $3232 = (($ptr$18151) + 640|0);
     $3233 = (($ptr$18151) + ($57)|0);
     $3234 = (($ptr$18151) + ($$sum)|0);
     $3235 = ($j$08150>>>0)<($1741>>>0);
     $3236 = $3235 ? $j$08150 : $index0$08146;
     $3237 = ($j$08150>>>0)<($1738>>>0);
     $3238 = $3237 ? $j$08150 : $index1$08147;
     $3239 = ($j$08150>>>0)<($1734>>>0);
     $3240 = $3239 ? $j$08150 : $index2$08148;
     $3241 = ($j$08150>>>0)<($1735>>>0);
     $3242 = $3241 ? $j$08150 : $index3$08149;
     $$8111 = $3235 ? $3243 : Math_fround(0.0);
     $3244 = $3237 ? $3245 : Math_fround(0.0);
     $$8112 = $3239 ? $3246 : Math_fround(0.0);
     $3247 = $3241 ? $3248 : Math_fround(0.0);
     $3249 = Math_fround($3250 * $$8111);
     $3251 = Math_fround($3252 * $3244);
     $3253 = Math_fround($3254 * $$8112);
     $3255 = Math_fround($3256 * $3247);
     $3257 = Math_fround($3258 * $$8111);
     $3259 = Math_fround($3260 * $3244);
     $3261 = Math_fround($3262 * $$8112);
     $3263 = Math_fround($3264 * $3247);
     $3265 = Math_fround($3266 * $$8111);
     $3267 = Math_fround($3268 * $3244);
     $3269 = Math_fround($3270 * $$8112);
     $3271 = Math_fround($3272 * $3247);
     $3273 = Math_fround($3274 * $$8111);
     $3275 = Math_fround($3276 * $3244);
     $3277 = Math_fround($3278 * $$8112);
     $3279 = Math_fround($3280 * $3247);
     $3281 = Math_fround($3282 * $$8111);
     $3283 = Math_fround($3284 * $3244);
     $3285 = Math_fround($3286 * $$8112);
     $3287 = Math_fround($3288 * $3247);
     $3289 = Math_fround($3290 * $$8111);
     $3291 = Math_fround($3292 * $3244);
     $3293 = Math_fround($3294 * $$8112);
     $3295 = Math_fround($3296 * $3247);
     $3297 = (((($threadContext) + (($744*96)|0)|0) + (($3236*12)|0)|0) + 5312|0);
     $3298 = Math_fround(HEAPF32[$3297>>2]);
     $3299 = (((($threadContext) + (($744*96)|0)|0) + (($3236*12)|0)|0) + 5316|0);
     $3300 = Math_fround(HEAPF32[$3299>>2]);
     $3301 = (((($threadContext) + (($744*96)|0)|0) + (($3236*12)|0)|0) + 5320|0);
     $3302 = Math_fround(HEAPF32[$3301>>2]);
     $3303 = (((($threadContext) + (($747*96)|0)|0) + (($3238*12)|0)|0) + 5312|0);
     $3304 = Math_fround(HEAPF32[$3303>>2]);
     $3305 = (((($threadContext) + (($747*96)|0)|0) + (($3238*12)|0)|0) + 5316|0);
     $3306 = Math_fround(HEAPF32[$3305>>2]);
     $3307 = (((($threadContext) + (($747*96)|0)|0) + (($3238*12)|0)|0) + 5320|0);
     $3308 = Math_fround(HEAPF32[$3307>>2]);
     $3309 = (((($threadContext) + (($750*96)|0)|0) + (($3240*12)|0)|0) + 5312|0);
     $3310 = Math_fround(HEAPF32[$3309>>2]);
     $3311 = (((($threadContext) + (($750*96)|0)|0) + (($3240*12)|0)|0) + 5316|0);
     $3312 = Math_fround(HEAPF32[$3311>>2]);
     $3313 = (((($threadContext) + (($750*96)|0)|0) + (($3240*12)|0)|0) + 5320|0);
     $3314 = Math_fround(HEAPF32[$3313>>2]);
     $3315 = (((($threadContext) + (($753*96)|0)|0) + (($3242*12)|0)|0) + 5312|0);
     $3316 = Math_fround(HEAPF32[$3315>>2]);
     $3317 = (((($threadContext) + (($753*96)|0)|0) + (($3242*12)|0)|0) + 5316|0);
     $3318 = Math_fround(HEAPF32[$3317>>2]);
     $3319 = (((($threadContext) + (($753*96)|0)|0) + (($3242*12)|0)|0) + 5320|0);
     $3320 = Math_fround(HEAPF32[$3319>>2]);
     $3321 = Math_fround($701 * $3298);
     $3322 = Math_fround($701 * $3300);
     $3323 = Math_fround($701 * $3302);
     $3324 = Math_fround($583 * $3302);
     $3325 = Math_fround($585 * $3300);
     $3326 = Math_fround($3324 - $3325);
     $3327 = Math_fround($585 * $3298);
     $3328 = Math_fround($581 * $3302);
     $3329 = Math_fround($3327 - $3328);
     $3330 = Math_fround($581 * $3300);
     $3331 = Math_fround($583 * $3298);
     $3332 = Math_fround($3330 - $3331);
     $3333 = Math_fround($587 * $3326);
     $3334 = Math_fround($587 * $3329);
     $3335 = Math_fround($587 * $3332);
     $3336 = Math_fround($3321 + $3333);
     $3337 = Math_fround($3322 + $3334);
     $3338 = Math_fround($3323 + $3335);
     $3339 = Math_fround($581 * $3298);
     $3340 = Math_fround($583 * $3300);
     $3341 = Math_fround($3339 + $3340);
     $3342 = Math_fround($585 * $3302);
     $3343 = Math_fround($3341 + $3342);
     $3344 = Math_fround($581 * $3343);
     $3345 = Math_fround($583 * $3343);
     $3346 = Math_fround($585 * $3343);
     $3347 = Math_fround($3344 + $3336);
     $3348 = Math_fround($3345 + $3337);
     $3349 = Math_fround($3338 + $3346);
     $3350 = Math_fround($3347 * Math_fround(2.0));
     $3351 = Math_fround($3348 * Math_fround(2.0));
     $3352 = Math_fround($3349 * Math_fround(2.0));
     $3353 = Math_fround($703 * $3304);
     $3354 = Math_fround($703 * $3306);
     $3355 = Math_fround($703 * $3308);
     $3356 = Math_fround($590 * $3308);
     $3357 = Math_fround($592 * $3306);
     $3358 = Math_fround($3356 - $3357);
     $3359 = Math_fround($592 * $3304);
     $3360 = Math_fround($588 * $3308);
     $3361 = Math_fround($3359 - $3360);
     $3362 = Math_fround($588 * $3306);
     $3363 = Math_fround($590 * $3304);
     $3364 = Math_fround($3362 - $3363);
     $3365 = Math_fround($594 * $3358);
     $3366 = Math_fround($594 * $3361);
     $3367 = Math_fround($594 * $3364);
     $3368 = Math_fround($3353 + $3365);
     $3369 = Math_fround($3354 + $3366);
     $3370 = Math_fround($3355 + $3367);
     $3371 = Math_fround($588 * $3304);
     $3372 = Math_fround($590 * $3306);
     $3373 = Math_fround($3371 + $3372);
     $3374 = Math_fround($592 * $3308);
     $3375 = Math_fround($3373 + $3374);
     $3376 = Math_fround($588 * $3375);
     $3377 = Math_fround($590 * $3375);
     $3378 = Math_fround($592 * $3375);
     $3379 = Math_fround($3376 + $3368);
     $3380 = Math_fround($3377 + $3369);
     $3381 = Math_fround($3370 + $3378);
     $3382 = Math_fround($3379 * Math_fround(2.0));
     $3383 = Math_fround($3380 * Math_fround(2.0));
     $3384 = Math_fround($3381 * Math_fround(2.0));
     $3385 = Math_fround($705 * $3310);
     $3386 = Math_fround($705 * $3312);
     $3387 = Math_fround($705 * $3314);
     $3388 = Math_fround($597 * $3314);
     $3389 = Math_fround($599 * $3312);
     $3390 = Math_fround($3388 - $3389);
     $3391 = Math_fround($599 * $3310);
     $3392 = Math_fround($595 * $3314);
     $3393 = Math_fround($3391 - $3392);
     $3394 = Math_fround($595 * $3312);
     $3395 = Math_fround($597 * $3310);
     $3396 = Math_fround($3394 - $3395);
     $3397 = Math_fround($601 * $3390);
     $3398 = Math_fround($601 * $3393);
     $3399 = Math_fround($601 * $3396);
     $3400 = Math_fround($3385 + $3397);
     $3401 = Math_fround($3386 + $3398);
     $3402 = Math_fround($3387 + $3399);
     $3403 = Math_fround($595 * $3310);
     $3404 = Math_fround($597 * $3312);
     $3405 = Math_fround($3403 + $3404);
     $3406 = Math_fround($599 * $3314);
     $3407 = Math_fround($3405 + $3406);
     $3408 = Math_fround($595 * $3407);
     $3409 = Math_fround($597 * $3407);
     $3410 = Math_fround($599 * $3407);
     $3411 = Math_fround($3408 + $3400);
     $3412 = Math_fround($3409 + $3401);
     $3413 = Math_fround($3402 + $3410);
     $3414 = Math_fround($3411 * Math_fround(2.0));
     $3415 = Math_fround($3412 * Math_fround(2.0));
     $3416 = Math_fround($3413 * Math_fround(2.0));
     $3417 = Math_fround($707 * $3316);
     $3418 = Math_fround($707 * $3318);
     $3419 = Math_fround($707 * $3320);
     $3420 = Math_fround($604 * $3320);
     $3421 = Math_fround($606 * $3318);
     $3422 = Math_fround($3420 - $3421);
     $3423 = Math_fround($606 * $3316);
     $3424 = Math_fround($602 * $3320);
     $3425 = Math_fround($3423 - $3424);
     $3426 = Math_fround($602 * $3318);
     $3427 = Math_fround($604 * $3316);
     $3428 = Math_fround($3426 - $3427);
     $3429 = Math_fround($608 * $3422);
     $3430 = Math_fround($608 * $3425);
     $3431 = Math_fround($608 * $3428);
     $3432 = Math_fround($3417 + $3429);
     $3433 = Math_fround($3418 + $3430);
     $3434 = Math_fround($3419 + $3431);
     $3435 = Math_fround($602 * $3316);
     $3436 = Math_fround($604 * $3318);
     $3437 = Math_fround($3435 + $3436);
     $3438 = Math_fround($606 * $3320);
     $3439 = Math_fround($3437 + $3438);
     $3440 = Math_fround($602 * $3439);
     $3441 = Math_fround($604 * $3439);
     $3442 = Math_fround($606 * $3439);
     $3443 = Math_fround($3440 + $3432);
     $3444 = Math_fround($3441 + $3433);
     $3445 = Math_fround($3434 + $3442);
     $3446 = Math_fround($3443 * Math_fround(2.0));
     $3447 = Math_fround($3444 * Math_fround(2.0));
     $3448 = Math_fround($3445 * Math_fround(2.0));
     $3449 = Math_fround($520 + $3350);
     $3450 = Math_fround($528 + $3382);
     $3451 = Math_fround($536 + $3414);
     $3452 = Math_fround($544 + $3446);
     $3453 = Math_fround($522 + $3351);
     $3454 = Math_fround($530 + $3383);
     $3455 = Math_fround($538 + $3415);
     $3456 = Math_fround($546 + $3447);
     $3457 = Math_fround($524 + $3352);
     $3458 = Math_fround($532 + $3384);
     $3459 = Math_fround($540 + $3416);
     $3460 = Math_fround($548 + $3448);
     $3461 = (((($threadContext) + (($744*96)|0)|0) + (($3236*12)|0)|0) + 5336|0);
     $3462 = Math_fround(HEAPF32[$3461>>2]);
     $3463 = (((($threadContext) + (($744*96)|0)|0) + (($3236*12)|0)|0) + 5340|0);
     $3464 = Math_fround(HEAPF32[$3463>>2]);
     $3465 = (((($threadContext) + (($744*96)|0)|0) + (($3236*12)|0)|0) + 5344|0);
     $3466 = Math_fround(HEAPF32[$3465>>2]);
     $3467 = (((($threadContext) + (($747*96)|0)|0) + (($3238*12)|0)|0) + 5336|0);
     $3468 = Math_fround(HEAPF32[$3467>>2]);
     $3469 = (((($threadContext) + (($747*96)|0)|0) + (($3238*12)|0)|0) + 5340|0);
     $3470 = Math_fround(HEAPF32[$3469>>2]);
     $3471 = (((($threadContext) + (($747*96)|0)|0) + (($3238*12)|0)|0) + 5344|0);
     $3472 = Math_fround(HEAPF32[$3471>>2]);
     $3473 = (((($threadContext) + (($750*96)|0)|0) + (($3240*12)|0)|0) + 5336|0);
     $3474 = Math_fround(HEAPF32[$3473>>2]);
     $3475 = (((($threadContext) + (($750*96)|0)|0) + (($3240*12)|0)|0) + 5340|0);
     $3476 = Math_fround(HEAPF32[$3475>>2]);
     $3477 = (((($threadContext) + (($750*96)|0)|0) + (($3240*12)|0)|0) + 5344|0);
     $3478 = Math_fround(HEAPF32[$3477>>2]);
     $3479 = (((($threadContext) + (($753*96)|0)|0) + (($3242*12)|0)|0) + 5336|0);
     $3480 = Math_fround(HEAPF32[$3479>>2]);
     $3481 = (((($threadContext) + (($753*96)|0)|0) + (($3242*12)|0)|0) + 5340|0);
     $3482 = Math_fround(HEAPF32[$3481>>2]);
     $3483 = (((($threadContext) + (($753*96)|0)|0) + (($3242*12)|0)|0) + 5344|0);
     $3484 = Math_fround(HEAPF32[$3483>>2]);
     $3485 = Math_fround($709 * $3462);
     $3486 = Math_fround($709 * $3464);
     $3487 = Math_fround($709 * $3466);
     $3488 = Math_fround($611 * $3466);
     $3489 = Math_fround($613 * $3464);
     $3490 = Math_fround($3488 - $3489);
     $3491 = Math_fround($613 * $3462);
     $3492 = Math_fround($609 * $3466);
     $3493 = Math_fround($3491 - $3492);
     $3494 = Math_fround($609 * $3464);
     $3495 = Math_fround($611 * $3462);
     $3496 = Math_fround($3494 - $3495);
     $3497 = Math_fround($615 * $3490);
     $3498 = Math_fround($615 * $3493);
     $3499 = Math_fround($615 * $3496);
     $3500 = Math_fround($3485 + $3497);
     $3501 = Math_fround($3486 + $3498);
     $3502 = Math_fround($3487 + $3499);
     $3503 = Math_fround($609 * $3462);
     $3504 = Math_fround($611 * $3464);
     $3505 = Math_fround($3503 + $3504);
     $3506 = Math_fround($613 * $3466);
     $3507 = Math_fround($3505 + $3506);
     $3508 = Math_fround($609 * $3507);
     $3509 = Math_fround($611 * $3507);
     $3510 = Math_fround($613 * $3507);
     $3511 = Math_fround($3508 + $3500);
     $3512 = Math_fround($3509 + $3501);
     $3513 = Math_fround($3502 + $3510);
     $3514 = Math_fround($3511 * Math_fround(2.0));
     $3515 = Math_fround($3512 * Math_fround(2.0));
     $3516 = Math_fround($3513 * Math_fround(2.0));
     $3517 = Math_fround($711 * $3468);
     $3518 = Math_fround($711 * $3470);
     $3519 = Math_fround($711 * $3472);
     $3520 = Math_fround($618 * $3472);
     $3521 = Math_fround($620 * $3470);
     $3522 = Math_fround($3520 - $3521);
     $3523 = Math_fround($620 * $3468);
     $3524 = Math_fround($616 * $3472);
     $3525 = Math_fround($3523 - $3524);
     $3526 = Math_fround($616 * $3470);
     $3527 = Math_fround($618 * $3468);
     $3528 = Math_fround($3526 - $3527);
     $3529 = Math_fround($622 * $3522);
     $3530 = Math_fround($622 * $3525);
     $3531 = Math_fround($622 * $3528);
     $3532 = Math_fround($3517 + $3529);
     $3533 = Math_fround($3518 + $3530);
     $3534 = Math_fround($3519 + $3531);
     $3535 = Math_fround($616 * $3468);
     $3536 = Math_fround($618 * $3470);
     $3537 = Math_fround($3535 + $3536);
     $3538 = Math_fround($620 * $3472);
     $3539 = Math_fround($3537 + $3538);
     $3540 = Math_fround($616 * $3539);
     $3541 = Math_fround($618 * $3539);
     $3542 = Math_fround($620 * $3539);
     $3543 = Math_fround($3540 + $3532);
     $3544 = Math_fround($3541 + $3533);
     $3545 = Math_fround($3534 + $3542);
     $3546 = Math_fround($3543 * Math_fround(2.0));
     $3547 = Math_fround($3544 * Math_fround(2.0));
     $3548 = Math_fround($3545 * Math_fround(2.0));
     $3549 = Math_fround($713 * $3474);
     $3550 = Math_fround($713 * $3476);
     $3551 = Math_fround($713 * $3478);
     $3552 = Math_fround($625 * $3478);
     $3553 = Math_fround($627 * $3476);
     $3554 = Math_fround($3552 - $3553);
     $3555 = Math_fround($627 * $3474);
     $3556 = Math_fround($623 * $3478);
     $3557 = Math_fround($3555 - $3556);
     $3558 = Math_fround($623 * $3476);
     $3559 = Math_fround($625 * $3474);
     $3560 = Math_fround($3558 - $3559);
     $3561 = Math_fround($629 * $3554);
     $3562 = Math_fround($629 * $3557);
     $3563 = Math_fround($629 * $3560);
     $3564 = Math_fround($3549 + $3561);
     $3565 = Math_fround($3550 + $3562);
     $3566 = Math_fround($3551 + $3563);
     $3567 = Math_fround($623 * $3474);
     $3568 = Math_fround($625 * $3476);
     $3569 = Math_fround($3567 + $3568);
     $3570 = Math_fround($627 * $3478);
     $3571 = Math_fround($3569 + $3570);
     $3572 = Math_fround($623 * $3571);
     $3573 = Math_fround($625 * $3571);
     $3574 = Math_fround($627 * $3571);
     $3575 = Math_fround($3572 + $3564);
     $3576 = Math_fround($3573 + $3565);
     $3577 = Math_fround($3566 + $3574);
     $3578 = Math_fround($3575 * Math_fround(2.0));
     $3579 = Math_fround($3576 * Math_fround(2.0));
     $3580 = Math_fround($3577 * Math_fround(2.0));
     $3581 = Math_fround($715 * $3480);
     $3582 = Math_fround($715 * $3482);
     $3583 = Math_fround($715 * $3484);
     $3584 = Math_fround($632 * $3484);
     $3585 = Math_fround($634 * $3482);
     $3586 = Math_fround($3584 - $3585);
     $3587 = Math_fround($634 * $3480);
     $3588 = Math_fround($630 * $3484);
     $3589 = Math_fround($3587 - $3588);
     $3590 = Math_fround($630 * $3482);
     $3591 = Math_fround($632 * $3480);
     $3592 = Math_fround($3590 - $3591);
     $3593 = Math_fround($636 * $3586);
     $3594 = Math_fround($636 * $3589);
     $3595 = Math_fround($636 * $3592);
     $3596 = Math_fround($3581 + $3593);
     $3597 = Math_fround($3582 + $3594);
     $3598 = Math_fround($3583 + $3595);
     $3599 = Math_fround($630 * $3480);
     $3600 = Math_fround($632 * $3482);
     $3601 = Math_fround($3599 + $3600);
     $3602 = Math_fround($634 * $3484);
     $3603 = Math_fround($3601 + $3602);
     $3604 = Math_fround($630 * $3603);
     $3605 = Math_fround($632 * $3603);
     $3606 = Math_fround($634 * $3603);
     $3607 = Math_fround($3604 + $3596);
     $3608 = Math_fround($3605 + $3597);
     $3609 = Math_fround($3598 + $3606);
     $3610 = Math_fround($3607 * Math_fround(2.0));
     $3611 = Math_fround($3608 * Math_fround(2.0));
     $3612 = Math_fround($3609 * Math_fround(2.0));
     $3613 = Math_fround($552 + $3514);
     $3614 = Math_fround($560 + $3546);
     $3615 = Math_fround($568 + $3578);
     $3616 = Math_fround($576 + $3610);
     $3617 = Math_fround($554 + $3515);
     $3618 = Math_fround($562 + $3547);
     $3619 = Math_fround($570 + $3579);
     $3620 = Math_fround($578 + $3611);
     $3621 = Math_fround($556 + $3516);
     $3622 = Math_fround($564 + $3548);
     $3623 = Math_fround($572 + $3580);
     $3624 = Math_fround($580 + $3612);
     $3625 = Math_fround($3449 - $3613);
     $3626 = Math_fround($3450 - $3614);
     $3627 = Math_fround($3451 - $3615);
     $3628 = Math_fround($3452 - $3616);
     $3629 = Math_fround($3453 - $3617);
     $3630 = Math_fround($3454 - $3618);
     $3631 = Math_fround($3455 - $3619);
     $3632 = Math_fround($3456 - $3620);
     $3633 = Math_fround($3457 - $3621);
     $3634 = Math_fround($3458 - $3622);
     $3635 = Math_fround($3459 - $3623);
     $3636 = Math_fround($3460 - $3624);
     $3637 = Math_fround($3265 * $3351);
     $3638 = Math_fround($3267 * $3383);
     $3639 = Math_fround($3269 * $3415);
     $3640 = Math_fround($3271 * $3447);
     $3641 = Math_fround($3257 * $3352);
     $3642 = Math_fround($3259 * $3384);
     $3643 = Math_fround($3261 * $3416);
     $3644 = Math_fround($3263 * $3448);
     $3645 = Math_fround($3637 - $3641);
     $3646 = Math_fround($3638 - $3642);
     $3647 = Math_fround($3639 - $3643);
     $3648 = Math_fround($3640 - $3644);
     $3649 = Math_fround($3249 * $3352);
     $3650 = Math_fround($3251 * $3384);
     $3651 = Math_fround($3253 * $3416);
     $3652 = Math_fround($3255 * $3448);
     $3653 = Math_fround($3265 * $3350);
     $3654 = Math_fround($3267 * $3382);
     $3655 = Math_fround($3269 * $3414);
     $3656 = Math_fround($3271 * $3446);
     $3657 = Math_fround($3649 - $3653);
     $3658 = Math_fround($3650 - $3654);
     $3659 = Math_fround($3651 - $3655);
     $3660 = Math_fround($3652 - $3656);
     $3661 = Math_fround($3257 * $3350);
     $3662 = Math_fround($3259 * $3382);
     $3663 = Math_fround($3261 * $3414);
     $3664 = Math_fround($3263 * $3446);
     $3665 = Math_fround($3249 * $3351);
     $3666 = Math_fround($3251 * $3383);
     $3667 = Math_fround($3253 * $3415);
     $3668 = Math_fround($3255 * $3447);
     $3669 = Math_fround($3661 - $3665);
     $3670 = Math_fround($3662 - $3666);
     $3671 = Math_fround($3663 - $3667);
     $3672 = Math_fround($3664 - $3668);
     $3673 = Math_fround($444 * $3645);
     $3674 = Math_fround($445 * $3646);
     $3675 = Math_fround($446 * $3647);
     $3676 = Math_fround($447 * $3648);
     $3677 = Math_fround($456 * $3645);
     $3678 = Math_fround($457 * $3646);
     $3679 = Math_fround($458 * $3647);
     $3680 = Math_fround($459 * $3648);
     $3681 = Math_fround($468 * $3645);
     $3682 = Math_fround($469 * $3646);
     $3683 = Math_fround($470 * $3647);
     $3684 = Math_fround($471 * $3648);
     $3685 = Math_fround($448 * $3657);
     $3686 = Math_fround($449 * $3658);
     $3687 = Math_fround($450 * $3659);
     $3688 = Math_fround($451 * $3660);
     $3689 = Math_fround($3685 + $3673);
     $3690 = Math_fround($3686 + $3674);
     $3691 = Math_fround($3687 + $3675);
     $3692 = Math_fround($3688 + $3676);
     $3693 = Math_fround($460 * $3657);
     $3694 = Math_fround($461 * $3658);
     $3695 = Math_fround($462 * $3659);
     $3696 = Math_fround($463 * $3660);
     $3697 = Math_fround($3693 + $3677);
     $3698 = Math_fround($3694 + $3678);
     $3699 = Math_fround($3695 + $3679);
     $3700 = Math_fround($3696 + $3680);
     $3701 = Math_fround($472 * $3657);
     $3702 = Math_fround($473 * $3658);
     $3703 = Math_fround($474 * $3659);
     $3704 = Math_fround($475 * $3660);
     $3705 = Math_fround($3701 + $3681);
     $3706 = Math_fround($3702 + $3682);
     $3707 = Math_fround($3703 + $3683);
     $3708 = Math_fround($3704 + $3684);
     $3709 = Math_fround($452 * $3669);
     $3710 = Math_fround($453 * $3670);
     $3711 = Math_fround($454 * $3671);
     $3712 = Math_fround($455 * $3672);
     $3713 = Math_fround($3709 + $3689);
     $3714 = Math_fround($3710 + $3690);
     $3715 = Math_fround($3711 + $3691);
     $3716 = Math_fround($3712 + $3692);
     $3717 = Math_fround($464 * $3669);
     $3718 = Math_fround($465 * $3670);
     $3719 = Math_fround($466 * $3671);
     $3720 = Math_fround($467 * $3672);
     $3721 = Math_fround($3717 + $3697);
     $3722 = Math_fround($3718 + $3698);
     $3723 = Math_fround($3719 + $3699);
     $3724 = Math_fround($3720 + $3700);
     $3725 = Math_fround($476 * $3669);
     $3726 = Math_fround($477 * $3670);
     $3727 = Math_fround($478 * $3671);
     $3728 = Math_fround($479 * $3672);
     $3729 = Math_fround($3725 + $3705);
     $3730 = Math_fround($3726 + $3706);
     $3731 = Math_fround($3727 + $3707);
     $3732 = Math_fround($3728 + $3708);
     $3733 = Math_fround($3645 * $3713);
     $3734 = Math_fround($3646 * $3714);
     $3735 = Math_fround($3647 * $3715);
     $3736 = Math_fround($3648 * $3716);
     $3737 = Math_fround($3657 * $3721);
     $3738 = Math_fround($3658 * $3722);
     $3739 = Math_fround($3659 * $3723);
     $3740 = Math_fround($3660 * $3724);
     $3741 = Math_fround($3737 + $3733);
     $3742 = Math_fround($3738 + $3734);
     $3743 = Math_fround($3739 + $3735);
     $3744 = Math_fround($3740 + $3736);
     $3745 = Math_fround($3669 * $3729);
     $3746 = Math_fround($3670 * $3730);
     $3747 = Math_fround($3671 * $3731);
     $3748 = Math_fround($3672 * $3732);
     $3749 = Math_fround($3745 + $3741);
     $3750 = Math_fround($3746 + $3742);
     $3751 = Math_fround($3747 + $3743);
     $3752 = Math_fround($3748 + $3744);
     $3753 = Math_fround($296 + $3749);
     $3754 = Math_fround($297 + $3750);
     $3755 = Math_fround($298 + $3751);
     $3756 = Math_fround($299 + $3752);
     $3757 = $3753 > Math_fround(0.0);
     $3758 = $3754 > Math_fround(0.0);
     $3759 = $3755 > Math_fround(0.0);
     $3760 = $3756 > Math_fround(0.0);
     $3761 = Math_fround(Math_fround(0.800000011920928955078) / $3753);
     $3762 = Math_fround(Math_fround(0.800000011920928955078) / $3754);
     $3763 = Math_fround(Math_fround(0.800000011920928955078) / $3755);
     $3764 = Math_fround(Math_fround(0.800000011920928955078) / $3756);
     HEAPF32[$21>>2] = $3761;
     HEAPF32[$716>>2] = $3762;
     HEAPF32[$717>>2] = $3763;
     HEAPF32[$718>>2] = $3764;
     $b$a$i375 = $3757 ? $21 : $20;
     ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;
     $3765 = Math_fround(HEAPF32[$b$a$i375>>2]);
     $a$pn4$i377 = $3758 ? $21 : $20;
     $$in1$i378 = (($a$pn4$i377) + 4|0);
     $3766 = Math_fround(HEAPF32[$$in1$i378>>2]);
     $b$a7$i379 = $3759 ? $21 : $20;
     $$in2$i380 = (($b$a7$i379) + 8|0);
     $3767 = Math_fround(HEAPF32[$$in2$i380>>2]);
     $a$pn6$i381 = $3760 ? $21 : $20;
     $$in3$i382 = (($a$pn6$i381) + 12|0);
     $3768 = Math_fround(HEAPF32[$$in3$i382>>2]);
     $3769 = Math_fround(HEAPF32[$1946>>2]);
     $3770 = Math_fround(HEAPF32[$1947>>2]);
     $3771 = Math_fround(HEAPF32[$1948>>2]);
     $3772 = Math_fround(HEAPF32[$1949>>2]);
     $3773 = Math_fround(HEAPF32[$1950>>2]);
     $3774 = Math_fround(HEAPF32[$1951>>2]);
     $3775 = Math_fround(HEAPF32[$1952>>2]);
     $3776 = Math_fround(HEAPF32[$1953>>2]);
     $3777 = Math_fround(HEAPF32[$1954>>2]);
     $3778 = Math_fround(HEAPF32[$1955>>2]);
     $3779 = Math_fround(HEAPF32[$1956>>2]);
     $3780 = Math_fround(HEAPF32[$1957>>2]);
     $3781 = Math_fround($3249 * $3769);
     $3782 = Math_fround($3251 * $3772);
     $3783 = Math_fround($3253 * $3775);
     $3784 = Math_fround($3255 * $3778);
     $3785 = Math_fround($3257 * $3770);
     $3786 = Math_fround($3259 * $3773);
     $3787 = Math_fround($3261 * $3776);
     $3788 = Math_fround($3263 * $3779);
     $3789 = Math_fround($3781 + $3785);
     $3790 = Math_fround($3782 + $3786);
     $3791 = Math_fround($3783 + $3787);
     $3792 = Math_fround($3784 + $3788);
     $3793 = Math_fround($3265 * $3771);
     $3794 = Math_fround($3267 * $3774);
     $3795 = Math_fround($3269 * $3777);
     $3796 = Math_fround($3271 * $3780);
     $3797 = Math_fround($3793 + $3789);
     $3798 = Math_fround($3794 + $3790);
     $3799 = Math_fround($3795 + $3791);
     $3800 = Math_fround($3796 + $3792);
     $3801 = Math_fround($3765 * $3797);
     $3802 = Math_fround($3766 * $3798);
     $3803 = Math_fround($3767 * $3799);
     $3804 = Math_fround($3768 * $3800);
     $3805 = Math_fround($3249 * $3625);
     $3806 = Math_fround($3251 * $3626);
     $3807 = Math_fround($3253 * $3627);
     $3808 = Math_fround($3255 * $3628);
     $3809 = Math_fround($3257 * $3629);
     $3810 = Math_fround($3259 * $3630);
     $3811 = Math_fround($3261 * $3631);
     $3812 = Math_fround($3263 * $3632);
     $3813 = Math_fround($3809 + $3805);
     $3814 = Math_fround($3810 + $3806);
     $3815 = Math_fround($3811 + $3807);
     $3816 = Math_fround($3812 + $3808);
     $3817 = Math_fround($3265 * $3633);
     $3818 = Math_fround($3267 * $3634);
     $3819 = Math_fround($3269 * $3635);
     $3820 = Math_fround($3271 * $3636);
     $3821 = Math_fround($3817 + $3813);
     $3822 = Math_fround($3818 + $3814);
     $3823 = Math_fround($3819 + $3815);
     $3824 = Math_fround($3820 + $3816);
     $3825 = Math_fround($3821 * $invDtF32);
     $3826 = Math_fround($3822 * $invDtF32);
     $3827 = Math_fround($3823 * $invDtF32);
     $3828 = Math_fround($3824 * $invDtF32);
     $3829 = Math_fround($3825 * $3765);
     $3830 = Math_fround($3826 * $3766);
     $3831 = Math_fround($3827 * $3767);
     $3832 = Math_fround($3828 * $3768);
     $3833 = Math_fround($$8111 * $3249);
     $3834 = Math_fround($3244 * $3251);
     $3835 = Math_fround($$8112 * $3253);
     $3836 = Math_fround($3247 * $3255);
     HEAPF32[$ptr$18151>>2] = $3833;
     $3837 = (($ptr$18151) + 4|0);
     HEAPF32[$3837>>2] = $3834;
     $3838 = (($ptr$18151) + 8|0);
     HEAPF32[$3838>>2] = $3835;
     $3839 = (($ptr$18151) + 12|0);
     HEAPF32[$3839>>2] = $3836;
     $3840 = Math_fround($$8111 * $3257);
     $3841 = Math_fround($3244 * $3259);
     $3842 = Math_fround($$8112 * $3261);
     $3843 = Math_fround($3247 * $3263);
     $3844 = (($ptr$18151) + 16|0);
     HEAPF32[$3844>>2] = $3840;
     $3845 = (($ptr$18151) + 20|0);
     HEAPF32[$3845>>2] = $3841;
     $3846 = (($ptr$18151) + 24|0);
     HEAPF32[$3846>>2] = $3842;
     $3847 = (($ptr$18151) + 28|0);
     HEAPF32[$3847>>2] = $3843;
     $3848 = Math_fround($$8111 * $3265);
     $3849 = Math_fround($3244 * $3267);
     $3850 = Math_fround($$8112 * $3269);
     $3851 = Math_fround($3247 * $3271);
     $3852 = (($ptr$18151) + 32|0);
     HEAPF32[$3852>>2] = $3848;
     $3853 = (($ptr$18151) + 36|0);
     HEAPF32[$3853>>2] = $3849;
     $3854 = (($ptr$18151) + 40|0);
     HEAPF32[$3854>>2] = $3850;
     $3855 = (($ptr$18151) + 44|0);
     HEAPF32[$3855>>2] = $3851;
     $3856 = (($ptr$18151) + 48|0);
     $3857 = (($ptr$18151) + 64|0);
     ;HEAP32[$3856+0>>2]=0|0;HEAP32[$3856+4>>2]=0|0;HEAP32[$3856+8>>2]=0|0;HEAP32[$3856+12>>2]=0|0;
     HEAPF32[$3857>>2] = $3645;
     $3858 = (($ptr$18151) + 68|0);
     HEAPF32[$3858>>2] = $3646;
     $3859 = (($ptr$18151) + 72|0);
     HEAPF32[$3859>>2] = $3647;
     $3860 = (($ptr$18151) + 76|0);
     HEAPF32[$3860>>2] = $3648;
     $3861 = (($ptr$18151) + 80|0);
     HEAPF32[$3861>>2] = $3657;
     $3862 = (($ptr$18151) + 84|0);
     HEAPF32[$3862>>2] = $3658;
     $3863 = (($ptr$18151) + 88|0);
     HEAPF32[$3863>>2] = $3659;
     $3864 = (($ptr$18151) + 92|0);
     HEAPF32[$3864>>2] = $3660;
     $3865 = (($ptr$18151) + 96|0);
     HEAPF32[$3865>>2] = $3669;
     $3866 = (($ptr$18151) + 100|0);
     HEAPF32[$3866>>2] = $3670;
     $3867 = (($ptr$18151) + 104|0);
     HEAPF32[$3867>>2] = $3671;
     $3868 = (($ptr$18151) + 108|0);
     HEAPF32[$3868>>2] = $3672;
     $3869 = (($ptr$18151) + 112|0);
     HEAPF32[$3869>>2] = $3713;
     $3870 = (($ptr$18151) + 116|0);
     HEAPF32[$3870>>2] = $3714;
     $3871 = (($ptr$18151) + 120|0);
     HEAPF32[$3871>>2] = $3715;
     $3872 = (($ptr$18151) + 124|0);
     HEAPF32[$3872>>2] = $3716;
     $3873 = (($ptr$18151) + 128|0);
     HEAPF32[$3873>>2] = $3721;
     $3874 = (($ptr$18151) + 132|0);
     HEAPF32[$3874>>2] = $3722;
     $3875 = (($ptr$18151) + 136|0);
     HEAPF32[$3875>>2] = $3723;
     $3876 = (($ptr$18151) + 140|0);
     HEAPF32[$3876>>2] = $3724;
     $3877 = (($ptr$18151) + 144|0);
     HEAPF32[$3877>>2] = $3729;
     $3878 = (($ptr$18151) + 148|0);
     HEAPF32[$3878>>2] = $3730;
     $3879 = (($ptr$18151) + 152|0);
     HEAPF32[$3879>>2] = $3731;
     $3880 = (($ptr$18151) + 156|0);
     HEAPF32[$3880>>2] = $3732;
     $3881 = Math_fround($3829 - $3801);
     $3882 = Math_fround($3830 - $3802);
     $3883 = Math_fround($3831 - $3803);
     $3884 = Math_fround($3832 - $3804);
     $3885 = (($ptr$18151) + 160|0);
     HEAPF32[$3885>>2] = $3881;
     $3886 = (($ptr$18151) + 164|0);
     HEAPF32[$3886>>2] = $3882;
     $3887 = (($ptr$18151) + 168|0);
     HEAPF32[$3887>>2] = $3883;
     $3888 = (($ptr$18151) + 172|0);
     HEAPF32[$3888>>2] = $3884;
     $3889 = (($ptr$18151) + 176|0);
     $3890 = (($ptr$18151) + 192|0);
     ;HEAP32[$3889+0>>2]=0|0;HEAP32[$3889+4>>2]=0|0;HEAP32[$3889+8>>2]=0|0;HEAP32[$3889+12>>2]=0|0;
     HEAPF32[$3890>>2] = $3829;
     $3891 = (($ptr$18151) + 196|0);
     HEAPF32[$3891>>2] = $3830;
     $3892 = (($ptr$18151) + 200|0);
     HEAPF32[$3892>>2] = $3831;
     $3893 = (($ptr$18151) + 204|0);
     HEAPF32[$3893>>2] = $3832;
     $3894 = (($ptr$18151) + 208|0);
     HEAPF32[$3894>>2] = $3765;
     $3895 = (($ptr$18151) + 212|0);
     HEAPF32[$3895>>2] = $3766;
     $3896 = (($ptr$18151) + 216|0);
     HEAPF32[$3896>>2] = $3767;
     $3897 = (($ptr$18151) + 220|0);
     HEAPF32[$3897>>2] = $3768;
     $3898 = $3235 ? $1932 : 0;
     $3899 = (($ptr$18151) + 224|0);
     HEAP32[$3899>>2] = $3898;
     $3900 = $3237 ? $1936 : 0;
     $3901 = (($ptr$18151) + 228|0);
     HEAP32[$3901>>2] = $3900;
     $3902 = $3239 ? $1940 : 0;
     $3903 = (($ptr$18151) + 232|0);
     HEAP32[$3903>>2] = $3902;
     $3904 = $3241 ? $1944 : 0;
     $3905 = (($ptr$18151) + 236|0);
     HEAP32[$3905>>2] = $3904;
     $3906 = Math_fround($3289 * $3351);
     $3907 = Math_fround($3291 * $3383);
     $3908 = Math_fround($3293 * $3415);
     $3909 = Math_fround($3295 * $3447);
     $3910 = Math_fround($3281 * $3352);
     $3911 = Math_fround($3283 * $3384);
     $3912 = Math_fround($3285 * $3416);
     $3913 = Math_fround($3287 * $3448);
     $3914 = Math_fround($3906 - $3910);
     $3915 = Math_fround($3907 - $3911);
     $3916 = Math_fround($3908 - $3912);
     $3917 = Math_fround($3909 - $3913);
     $3918 = Math_fround($3273 * $3352);
     $3919 = Math_fround($3275 * $3384);
     $3920 = Math_fround($3277 * $3416);
     $3921 = Math_fround($3279 * $3448);
     $3922 = Math_fround($3289 * $3350);
     $3923 = Math_fround($3291 * $3382);
     $3924 = Math_fround($3293 * $3414);
     $3925 = Math_fround($3295 * $3446);
     $3926 = Math_fround($3918 - $3922);
     $3927 = Math_fround($3919 - $3923);
     $3928 = Math_fround($3920 - $3924);
     $3929 = Math_fround($3921 - $3925);
     $3930 = Math_fround($3281 * $3350);
     $3931 = Math_fround($3283 * $3382);
     $3932 = Math_fround($3285 * $3414);
     $3933 = Math_fround($3287 * $3446);
     $3934 = Math_fround($3273 * $3351);
     $3935 = Math_fround($3275 * $3383);
     $3936 = Math_fround($3277 * $3415);
     $3937 = Math_fround($3279 * $3447);
     $3938 = Math_fround($3930 - $3934);
     $3939 = Math_fround($3931 - $3935);
     $3940 = Math_fround($3932 - $3936);
     $3941 = Math_fround($3933 - $3937);
     $3942 = Math_fround($444 * $3914);
     $3943 = Math_fround($445 * $3915);
     $3944 = Math_fround($446 * $3916);
     $3945 = Math_fround($447 * $3917);
     $3946 = Math_fround($456 * $3914);
     $3947 = Math_fround($457 * $3915);
     $3948 = Math_fround($458 * $3916);
     $3949 = Math_fround($459 * $3917);
     $3950 = Math_fround($468 * $3914);
     $3951 = Math_fround($469 * $3915);
     $3952 = Math_fround($470 * $3916);
     $3953 = Math_fround($471 * $3917);
     $3954 = Math_fround($448 * $3926);
     $3955 = Math_fround($449 * $3927);
     $3956 = Math_fround($450 * $3928);
     $3957 = Math_fround($451 * $3929);
     $3958 = Math_fround($3954 + $3942);
     $3959 = Math_fround($3955 + $3943);
     $3960 = Math_fround($3956 + $3944);
     $3961 = Math_fround($3957 + $3945);
     $3962 = Math_fround($460 * $3926);
     $3963 = Math_fround($461 * $3927);
     $3964 = Math_fround($462 * $3928);
     $3965 = Math_fround($463 * $3929);
     $3966 = Math_fround($3962 + $3946);
     $3967 = Math_fround($3963 + $3947);
     $3968 = Math_fround($3964 + $3948);
     $3969 = Math_fround($3965 + $3949);
     $3970 = Math_fround($472 * $3926);
     $3971 = Math_fround($473 * $3927);
     $3972 = Math_fround($474 * $3928);
     $3973 = Math_fround($475 * $3929);
     $3974 = Math_fround($3970 + $3950);
     $3975 = Math_fround($3971 + $3951);
     $3976 = Math_fround($3972 + $3952);
     $3977 = Math_fround($3973 + $3953);
     $3978 = Math_fround($452 * $3938);
     $3979 = Math_fround($453 * $3939);
     $3980 = Math_fround($454 * $3940);
     $3981 = Math_fround($455 * $3941);
     $3982 = Math_fround($3978 + $3958);
     $3983 = Math_fround($3979 + $3959);
     $3984 = Math_fround($3980 + $3960);
     $3985 = Math_fround($3981 + $3961);
     $3986 = Math_fround($464 * $3938);
     $3987 = Math_fround($465 * $3939);
     $3988 = Math_fround($466 * $3940);
     $3989 = Math_fround($467 * $3941);
     $3990 = Math_fround($3986 + $3966);
     $3991 = Math_fround($3987 + $3967);
     $3992 = Math_fround($3988 + $3968);
     $3993 = Math_fround($3989 + $3969);
     $3994 = Math_fround($476 * $3938);
     $3995 = Math_fround($477 * $3939);
     $3996 = Math_fround($478 * $3940);
     $3997 = Math_fround($479 * $3941);
     $3998 = Math_fround($3994 + $3974);
     $3999 = Math_fround($3995 + $3975);
     $4000 = Math_fround($3996 + $3976);
     $4001 = Math_fround($3997 + $3977);
     $4002 = Math_fround($3914 * $3982);
     $4003 = Math_fround($3915 * $3983);
     $4004 = Math_fround($3916 * $3984);
     $4005 = Math_fround($3917 * $3985);
     $4006 = Math_fround($3926 * $3990);
     $4007 = Math_fround($3927 * $3991);
     $4008 = Math_fround($3928 * $3992);
     $4009 = Math_fround($3929 * $3993);
     $4010 = Math_fround($4006 + $4002);
     $4011 = Math_fround($4007 + $4003);
     $4012 = Math_fround($4008 + $4004);
     $4013 = Math_fround($4009 + $4005);
     $4014 = Math_fround($3938 * $3998);
     $4015 = Math_fround($3939 * $3999);
     $4016 = Math_fround($3940 * $4000);
     $4017 = Math_fround($3941 * $4001);
     $4018 = Math_fround($4014 + $4010);
     $4019 = Math_fround($4015 + $4011);
     $4020 = Math_fround($4016 + $4012);
     $4021 = Math_fround($4017 + $4013);
     $4022 = Math_fround($296 + $4018);
     $4023 = Math_fround($297 + $4019);
     $4024 = Math_fround($298 + $4020);
     $4025 = Math_fround($299 + $4021);
     $4026 = $4022 > Math_fround(0.0);
     $4027 = $4023 > Math_fround(0.0);
     $4028 = $4024 > Math_fround(0.0);
     $4029 = $4025 > Math_fround(0.0);
     $4030 = Math_fround(Math_fround(0.800000011920928955078) / $4022);
     $4031 = Math_fround(Math_fround(0.800000011920928955078) / $4023);
     $4032 = Math_fround(Math_fround(0.800000011920928955078) / $4024);
     $4033 = Math_fround(Math_fround(0.800000011920928955078) / $4025);
     HEAPF32[$23>>2] = $4030;
     HEAPF32[$719>>2] = $4031;
     HEAPF32[$720>>2] = $4032;
     HEAPF32[$721>>2] = $4033;
     $b$a$i = $4026 ? $23 : $22;
     ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;
     $4034 = Math_fround(HEAPF32[$b$a$i>>2]);
     $a$pn4$i = $4027 ? $23 : $22;
     $$in1$i = (($a$pn4$i) + 4|0);
     $4035 = Math_fround(HEAPF32[$$in1$i>>2]);
     $b$a7$i = $4028 ? $23 : $22;
     $$in2$i = (($b$a7$i) + 8|0);
     $4036 = Math_fround(HEAPF32[$$in2$i>>2]);
     $a$pn6$i = $4029 ? $23 : $22;
     $$in3$i = (($a$pn6$i) + 12|0);
     $4037 = Math_fround(HEAPF32[$$in3$i>>2]);
     $4038 = Math_fround(HEAPF32[$1946>>2]);
     $4039 = Math_fround(HEAPF32[$1947>>2]);
     $4040 = Math_fround(HEAPF32[$1948>>2]);
     $4041 = Math_fround(HEAPF32[$1949>>2]);
     $4042 = Math_fround(HEAPF32[$1950>>2]);
     $4043 = Math_fround(HEAPF32[$1951>>2]);
     $4044 = Math_fround(HEAPF32[$1952>>2]);
     $4045 = Math_fround(HEAPF32[$1953>>2]);
     $4046 = Math_fround(HEAPF32[$1954>>2]);
     $4047 = Math_fround(HEAPF32[$1955>>2]);
     $4048 = Math_fround(HEAPF32[$1956>>2]);
     $4049 = Math_fround(HEAPF32[$1957>>2]);
     $4050 = Math_fround($3273 * $4038);
     $4051 = Math_fround($3275 * $4041);
     $4052 = Math_fround($3277 * $4044);
     $4053 = Math_fround($3279 * $4047);
     $4054 = Math_fround($3281 * $4039);
     $4055 = Math_fround($3283 * $4042);
     $4056 = Math_fround($3285 * $4045);
     $4057 = Math_fround($3287 * $4048);
     $4058 = Math_fround($4050 + $4054);
     $4059 = Math_fround($4051 + $4055);
     $4060 = Math_fround($4052 + $4056);
     $4061 = Math_fround($4053 + $4057);
     $4062 = Math_fround($3289 * $4040);
     $4063 = Math_fround($3291 * $4043);
     $4064 = Math_fround($3293 * $4046);
     $4065 = Math_fround($3295 * $4049);
     $4066 = Math_fround($4062 + $4058);
     $4067 = Math_fround($4063 + $4059);
     $4068 = Math_fround($4064 + $4060);
     $4069 = Math_fround($4065 + $4061);
     $4070 = Math_fround($3273 * $3625);
     $4071 = Math_fround($3275 * $3626);
     $4072 = Math_fround($3277 * $3627);
     $4073 = Math_fround($3279 * $3628);
     $4074 = Math_fround($3281 * $3629);
     $4075 = Math_fround($3283 * $3630);
     $4076 = Math_fround($3285 * $3631);
     $4077 = Math_fround($3287 * $3632);
     $4078 = Math_fround($4074 + $4070);
     $4079 = Math_fround($4075 + $4071);
     $4080 = Math_fround($4076 + $4072);
     $4081 = Math_fround($4077 + $4073);
     $4082 = Math_fround($3289 * $3633);
     $4083 = Math_fround($3291 * $3634);
     $4084 = Math_fround($3293 * $3635);
     $4085 = Math_fround($3295 * $3636);
     $4086 = Math_fround($4082 + $4078);
     $4087 = Math_fround($4083 + $4079);
     $4088 = Math_fround($4084 + $4080);
     $4089 = Math_fround($4085 + $4081);
     $4090 = Math_fround($4086 * $invDtF32);
     $4091 = Math_fround($4087 * $invDtF32);
     $4092 = Math_fround($4088 * $invDtF32);
     $4093 = Math_fround($4089 * $invDtF32);
     $4094 = Math_fround($$8111 * $3273);
     $4095 = Math_fround($3244 * $3275);
     $4096 = Math_fround($$8112 * $3277);
     $4097 = Math_fround($3247 * $3279);
     HEAPF32[$3233>>2] = $4094;
     $4098 = (($ptr$18151) + ($$sum80488049)|0);
     HEAPF32[$4098>>2] = $4095;
     $4099 = (($ptr$18151) + ($$sum80508051)|0);
     HEAPF32[$4099>>2] = $4096;
     $4100 = (($ptr$18151) + ($$sum80528053)|0);
     HEAPF32[$4100>>2] = $4097;
     $4101 = (($ptr$18151) + ($$sum7)|0);
     $4102 = Math_fround($$8111 * $3281);
     $4103 = Math_fround($3244 * $3283);
     $4104 = Math_fround($$8112 * $3285);
     $4105 = Math_fround($3247 * $3287);
     HEAPF32[$4101>>2] = $4102;
     $4106 = (($ptr$18151) + ($$sum8054)|0);
     HEAPF32[$4106>>2] = $4103;
     $4107 = (($ptr$18151) + ($$sum8055)|0);
     HEAPF32[$4107>>2] = $4104;
     $4108 = (($ptr$18151) + ($$sum8056)|0);
     HEAPF32[$4108>>2] = $4105;
     $4109 = (($ptr$18151) + ($$sum8)|0);
     $4110 = Math_fround($$8111 * $3289);
     $4111 = Math_fround($3244 * $3291);
     $4112 = Math_fround($$8112 * $3293);
     $4113 = Math_fround($3247 * $3295);
     HEAPF32[$4109>>2] = $4110;
     $4114 = (($ptr$18151) + ($$sum8057)|0);
     HEAPF32[$4114>>2] = $4111;
     $4115 = (($ptr$18151) + ($$sum8058)|0);
     HEAPF32[$4115>>2] = $4112;
     $4116 = (($ptr$18151) + ($$sum8059)|0);
     HEAPF32[$4116>>2] = $4113;
     $4117 = (($ptr$18151) + ($$sum9)|0);
     HEAPF32[$4117>>2] = Math_fround(0.0);
     $4118 = (($ptr$18151) + ($$sum8060)|0);
     HEAPF32[$4118>>2] = Math_fround(0.0);
     $4119 = (($ptr$18151) + ($$sum8061)|0);
     HEAPF32[$4119>>2] = Math_fround(0.0);
     $4120 = (($ptr$18151) + ($$sum8062)|0);
     HEAPF32[$4120>>2] = Math_fround(0.0);
     $4121 = (($ptr$18151) + ($$sum10)|0);
     HEAPF32[$4121>>2] = $3914;
     $4122 = (($ptr$18151) + ($$sum8063)|0);
     HEAPF32[$4122>>2] = $3915;
     $4123 = (($ptr$18151) + ($$sum8064)|0);
     HEAPF32[$4123>>2] = $3916;
     $4124 = (($ptr$18151) + ($$sum8065)|0);
     HEAPF32[$4124>>2] = $3917;
     $4125 = (($ptr$18151) + ($$sum11)|0);
     HEAPF32[$4125>>2] = $3926;
     $4126 = (($ptr$18151) + ($$sum8066)|0);
     HEAPF32[$4126>>2] = $3927;
     $4127 = (($ptr$18151) + ($$sum8067)|0);
     HEAPF32[$4127>>2] = $3928;
     $4128 = (($ptr$18151) + ($$sum8068)|0);
     HEAPF32[$4128>>2] = $3929;
     $4129 = (($ptr$18151) + ($$sum12)|0);
     HEAPF32[$4129>>2] = $3938;
     $4130 = (($ptr$18151) + ($$sum8069)|0);
     HEAPF32[$4130>>2] = $3939;
     $4131 = (($ptr$18151) + ($$sum8070)|0);
     HEAPF32[$4131>>2] = $3940;
     $4132 = (($ptr$18151) + ($$sum8071)|0);
     HEAPF32[$4132>>2] = $3941;
     $4133 = (($ptr$18151) + ($$sum13)|0);
     HEAPF32[$4133>>2] = $3982;
     $4134 = (($ptr$18151) + ($$sum8072)|0);
     HEAPF32[$4134>>2] = $3983;
     $4135 = (($ptr$18151) + ($$sum8073)|0);
     HEAPF32[$4135>>2] = $3984;
     $4136 = (($ptr$18151) + ($$sum8074)|0);
     HEAPF32[$4136>>2] = $3985;
     $4137 = (($ptr$18151) + ($$sum14)|0);
     HEAPF32[$4137>>2] = $3990;
     $4138 = (($ptr$18151) + ($$sum8075)|0);
     HEAPF32[$4138>>2] = $3991;
     $4139 = (($ptr$18151) + ($$sum8076)|0);
     HEAPF32[$4139>>2] = $3992;
     $4140 = (($ptr$18151) + ($$sum8077)|0);
     HEAPF32[$4140>>2] = $3993;
     $4141 = (($ptr$18151) + ($$sum15)|0);
     HEAPF32[$4141>>2] = $3998;
     $4142 = (($ptr$18151) + ($$sum8078)|0);
     HEAPF32[$4142>>2] = $3999;
     $4143 = (($ptr$18151) + ($$sum8079)|0);
     HEAPF32[$4143>>2] = $4000;
     $4144 = (($ptr$18151) + ($$sum8080)|0);
     HEAPF32[$4144>>2] = $4001;
     $4145 = (($ptr$18151) + ($$sum16)|0);
     $4146 = Math_fround($4090 - $4066);
     $4147 = Math_fround($4091 - $4067);
     $4148 = Math_fround($4092 - $4068);
     $4149 = Math_fround($4093 - $4069);
     $4150 = Math_fround($4034 * $4146);
     $4151 = Math_fround($4035 * $4147);
     $4152 = Math_fround($4036 * $4148);
     $4153 = Math_fround($4037 * $4149);
     HEAPF32[$4145>>2] = $4150;
     $4154 = (($ptr$18151) + ($$sum8081)|0);
     HEAPF32[$4154>>2] = $4151;
     $4155 = (($ptr$18151) + ($$sum8082)|0);
     HEAPF32[$4155>>2] = $4152;
     $4156 = (($ptr$18151) + ($$sum8083)|0);
     HEAPF32[$4156>>2] = $4153;
     $4157 = (($ptr$18151) + ($$sum17)|0);
     HEAPF32[$4157>>2] = Math_fround(0.0);
     $4158 = (($ptr$18151) + ($$sum8084)|0);
     HEAPF32[$4158>>2] = Math_fround(0.0);
     $4159 = (($ptr$18151) + ($$sum8085)|0);
     HEAPF32[$4159>>2] = Math_fround(0.0);
     $4160 = (($ptr$18151) + ($$sum8086)|0);
     HEAPF32[$4160>>2] = Math_fround(0.0);
     $4161 = (($ptr$18151) + ($$sum18)|0);
     $4162 = Math_fround($4090 * $4034);
     $4163 = Math_fround($4091 * $4035);
     $4164 = Math_fround($4092 * $4036);
     $4165 = Math_fround($4093 * $4037);
     HEAPF32[$4161>>2] = $4162;
     $4166 = (($ptr$18151) + ($$sum8087)|0);
     HEAPF32[$4166>>2] = $4163;
     $4167 = (($ptr$18151) + ($$sum8088)|0);
     HEAPF32[$4167>>2] = $4164;
     $4168 = (($ptr$18151) + ($$sum8089)|0);
     HEAPF32[$4168>>2] = $4165;
     $4169 = (($ptr$18151) + ($$sum19)|0);
     HEAPF32[$4169>>2] = $4034;
     $4170 = (($ptr$18151) + ($$sum8090)|0);
     HEAPF32[$4170>>2] = $4035;
     $4171 = (($ptr$18151) + ($$sum8091)|0);
     HEAPF32[$4171>>2] = $4036;
     $4172 = (($ptr$18151) + ($$sum8092)|0);
     HEAPF32[$4172>>2] = $4037;
     $4173 = (($ptr$18151) + ($$sum20)|0);
     HEAP32[$4173>>2] = $3898;
     $4174 = (($ptr$18151) + ($$sum21)|0);
     HEAP32[$4174>>2] = $3900;
     $4175 = (($ptr$18151) + ($$sum22)|0);
     HEAP32[$4175>>2] = $3902;
     $4176 = (($ptr$18151) + ($$sum23)|0);
     HEAP32[$4176>>2] = $3904;
     $4177 = (($j$08150) + 1)|0;
     $4178 = ($4177>>>0)<($1742>>>0);
     if ($4178) {
      $3243 = $$8111;$3245 = $3244;$3246 = $$8112;$3248 = $3247;$3250 = $3249;$3252 = $3251;$3254 = $3253;$3256 = $3255;$3258 = $3257;$3260 = $3259;$3262 = $3261;$3264 = $3263;$3266 = $3265;$3268 = $3267;$3270 = $3269;$3272 = $3271;$3274 = $3273;$3276 = $3275;$3278 = $3277;$3280 = $3279;$3282 = $3281;$3284 = $3283;$3286 = $3285;$3288 = $3287;$3290 = $3289;$3292 = $3291;$3294 = $3293;$3296 = $3295;$index0$08146 = $3236;$index1$08147 = $3238;$index2$08148 = $3240;$index3$08149 = $3242;$j$08150 = $4177;$ptr$18151 = $3234;
     } else {
      break;
     }
    }
   }
   $$pn = Math_imul($726, $umax8194)|0;
   $split = (($p$0) + ($$pn)|0);
   $ptr$1$lcssa = $split;
  }
  $4179 = (($frictionPatchWritebackAddrIndex0$08164) + 1)|0;
  $4180 = ($4179>>>0)<($652>>>0);
  if ($4180) {
   $4181 = $$ph8122;$4182 = $1025;$4183 = $1020;$4184 = $1015;$frictionIndex0$08160 = $744;$frictionIndex1$08159 = $747;$frictionIndex2$08158 = $750;$frictionIndex3$08157 = $753;$frictionPatchWritebackAddrIndex0$08164 = $4179;$newPatch$0$lcssa$i$i137380048154 = $newPatch$0$lcssa$i$i13738005;$newPatch$0$lcssa$i$i137780088153 = $newPatch$0$lcssa$i$i13778009;$newPatch$0$lcssa$i$i138180128152 = $newPatch$0$lcssa$i$i13818013;$newPatch$0$lcssa$i$i80018155 = $newPatch$0$lcssa$i$i8002$ph;$ptr$08165 = $ptr$1$lcssa;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx38setupFinalizeSolverConstraintsCoulomb4EPNS_21PxcSolverContact4DescERNS_18PxcNpThreadContextEPhffRNS_27PxcCorrelationBufferCoulombEjjjRKNS_6shdfnd3aos5Vec4VESB_SB_SB_($descs,$threadContext,$workspace,$invDtF32,$bounceThresholdF32,$c,$numFrictionPerPoint,$numContactPoints4,$0,$invMassScale0,$invInertiaScale0,$invMassScale1,$invInertiaScale1) {
 $descs = $descs|0;
 $threadContext = $threadContext|0;
 $workspace = $workspace|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $c = $c|0;
 $numFrictionPerPoint = $numFrictionPerPoint|0;
 $numContactPoints4 = $numContactPoints4|0;
 $0 = $0|0;
 $invMassScale0 = $invMassScale0|0;
 $invInertiaScale0 = $invInertiaScale0|0;
 $invMassScale1 = $invMassScale1|0;
 $invInertiaScale1 = $invInertiaScale1|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i1125 = Math_fround(0), $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i1126 = Math_fround(0), $$5693 = 0, $$5694 = 0, $$in1$i = 0, $$in1$i$us = 0, $$in1$i273 = 0, $$in1$i293 = 0, $$in1$i350 = 0, $$in1$i760 = 0, $$in1$i774 = 0, $$in1$i788 = 0, $$in1$i856 = 0, $$in1$i870 = 0, $$in1$i886 = 0, $$in2$i = 0;
 var $$in2$i$us = 0, $$in2$i275 = 0, $$in2$i295 = 0, $$in2$i352 = 0, $$in2$i762 = 0, $$in2$i776 = 0, $$in2$i790 = 0, $$in2$i858 = 0, $$in2$i872 = 0, $$in2$i888 = 0, $$in3$i = 0, $$in3$i$us = 0, $$in3$i277 = 0, $$in3$i297 = 0, $$in3$i354 = 0, $$in3$i764 = 0, $$in3$i778 = 0, $$in3$i792 = 0, $$in3$i860 = 0, $$in3$i874 = 0;
 var $$in3$i890 = 0, $$lobit = 0, $$lobit1 = 0, $$lobit2 = 0, $$lobit3 = 0, $$ph = 0, $$ph5719 = 0, $$ph5720 = 0, $$ph5721 = 0, $$ph5722 = 0, $$ph5723 = 0, $$ph5724 = 0, $$ph5725 = 0, $$ph5725$phi = 0, $$ph5726 = 0, $$ph5727 = 0, $$ph5728 = 0, $$ph5729 = 0, $$ph5729$phi = 0, $1 = 0;
 var $10 = 0, $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0);
 var $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = Math_fround(0), $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = Math_fround(0), $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = 0, $1034 = 0;
 var $1035 = 0, $1036 = 0, $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = 0, $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0);
 var $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = 0, $1070 = Math_fround(0);
 var $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0), $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0);
 var $109 = 0, $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0);
 var $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0);
 var $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = Math_fround(0), $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = Math_fround(0), $1140 = 0, $1141 = 0, $1142 = 0;
 var $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0;
 var $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0;
 var $118 = Math_fround(0), $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0;
 var $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0;
 var $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = Math_fround(0), $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0;
 var $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0;
 var $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = Math_fround(0), $1260 = 0, $1261 = Math_fround(0), $1262 = 0, $1263 = Math_fround(0), $1264 = 0, $1265 = Math_fround(0), $1266 = 0, $1267 = Math_fround(0), $1268 = 0, $1269 = Math_fround(0);
 var $127 = 0, $1270 = 0, $1271 = Math_fround(0), $1272 = 0, $1273 = Math_fround(0), $1274 = 0, $1275 = Math_fround(0), $1276 = 0, $1277 = Math_fround(0), $1278 = 0, $1279 = Math_fround(0), $128 = 0, $1280 = 0, $1281 = Math_fround(0), $1282 = 0, $1283 = Math_fround(0), $1284 = 0, $1285 = Math_fround(0), $1286 = 0, $1287 = Math_fround(0);
 var $1288 = 0, $1289 = Math_fround(0), $129 = 0, $1290 = 0, $1291 = Math_fround(0), $1292 = 0, $1293 = Math_fround(0), $1294 = 0, $1295 = Math_fround(0), $1296 = 0, $1297 = Math_fround(0), $1298 = 0, $1299 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $1300 = 0, $1301 = Math_fround(0), $1302 = 0, $1303 = Math_fround(0), $1304 = 0;
 var $1305 = Math_fround(0), $1306 = 0, $1307 = Math_fround(0), $1308 = 0, $1309 = Math_fround(0), $131 = 0, $1310 = 0, $1311 = Math_fround(0), $1312 = 0, $1313 = Math_fround(0), $1314 = 0, $1315 = Math_fround(0), $1316 = 0, $1317 = Math_fround(0), $1318 = 0, $1319 = Math_fround(0), $132 = 0, $1320 = 0, $1321 = Math_fround(0), $1322 = 0;
 var $1323 = Math_fround(0), $1324 = Math_fround(0), $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = 0, $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = Math_fround(0), $1340 = Math_fround(0);
 var $1341 = Math_fround(0), $1342 = Math_fround(0), $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = Math_fround(0);
 var $136 = 0, $1360 = Math_fround(0), $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = 0, $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = Math_fround(0), $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0);
 var $1378 = Math_fround(0), $1379 = Math_fround(0), $138 = Math_fround(0), $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = 0, $1390 = Math_fround(0), $1391 = Math_fround(0), $1392 = Math_fround(0), $1393 = Math_fround(0), $1394 = Math_fround(0), $1395 = Math_fround(0);
 var $1396 = Math_fround(0), $1397 = Math_fround(0), $1398 = Math_fround(0), $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = Math_fround(0), $1401 = Math_fround(0), $1402 = Math_fround(0), $1403 = Math_fround(0), $1404 = Math_fround(0), $1405 = Math_fround(0), $1406 = Math_fround(0), $1407 = Math_fround(0), $1408 = Math_fround(0), $1409 = Math_fround(0), $141 = 0, $1410 = Math_fround(0), $1411 = Math_fround(0), $1412 = Math_fround(0);
 var $1413 = Math_fround(0), $1414 = Math_fround(0), $1415 = Math_fround(0), $1416 = Math_fround(0), $1417 = Math_fround(0), $1418 = Math_fround(0), $1419 = Math_fround(0), $142 = Math_fround(0), $1420 = Math_fround(0), $1421 = Math_fround(0), $1422 = Math_fround(0), $1423 = Math_fround(0), $1424 = Math_fround(0), $1425 = Math_fround(0), $1426 = Math_fround(0), $1427 = Math_fround(0), $1428 = Math_fround(0), $1429 = Math_fround(0), $143 = 0, $1430 = Math_fround(0);
 var $1431 = Math_fround(0), $1432 = Math_fround(0), $1433 = Math_fround(0), $1434 = Math_fround(0), $1435 = Math_fround(0), $1436 = Math_fround(0), $1437 = Math_fround(0), $1438 = Math_fround(0), $1439 = Math_fround(0), $144 = 0, $1440 = Math_fround(0), $1441 = Math_fround(0), $1442 = Math_fround(0), $1443 = Math_fround(0), $1444 = Math_fround(0), $1445 = Math_fround(0), $1446 = Math_fround(0), $1447 = Math_fround(0), $1448 = Math_fround(0), $1449 = Math_fround(0);
 var $145 = 0, $1450 = Math_fround(0), $1451 = Math_fround(0), $1452 = Math_fround(0), $1453 = Math_fround(0), $1454 = Math_fround(0), $1455 = Math_fround(0), $1456 = Math_fround(0), $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = Math_fround(0), $1460 = Math_fround(0), $1461 = Math_fround(0), $1462 = Math_fround(0), $1463 = Math_fround(0), $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = Math_fround(0), $1467 = Math_fround(0);
 var $1468 = Math_fround(0), $1469 = Math_fround(0), $147 = 0, $1470 = Math_fround(0), $1471 = Math_fround(0), $1472 = Math_fround(0), $1473 = Math_fround(0), $1474 = Math_fround(0), $1475 = Math_fround(0), $1476 = Math_fround(0), $1477 = Math_fround(0), $1478 = Math_fround(0), $1479 = Math_fround(0), $148 = 0, $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0);
 var $1486 = Math_fround(0), $1487 = Math_fround(0), $1488 = Math_fround(0), $1489 = Math_fround(0), $149 = Math_fround(0), $1490 = Math_fround(0), $1491 = Math_fround(0), $1492 = Math_fround(0), $1493 = Math_fround(0), $1494 = Math_fround(0), $1495 = Math_fround(0), $1496 = Math_fround(0), $1497 = Math_fround(0), $1498 = Math_fround(0), $1499 = Math_fround(0), $15 = 0, $150 = 0, $1500 = Math_fround(0), $1501 = Math_fround(0), $1502 = Math_fround(0);
 var $1503 = Math_fround(0), $1504 = Math_fround(0), $1505 = Math_fround(0), $1506 = Math_fround(0), $1507 = Math_fround(0), $1508 = Math_fround(0), $1509 = Math_fround(0), $151 = 0, $1510 = Math_fround(0), $1511 = Math_fround(0), $1512 = Math_fround(0), $1513 = Math_fround(0), $1514 = Math_fround(0), $1515 = Math_fround(0), $1516 = Math_fround(0), $1517 = Math_fround(0), $1518 = Math_fround(0), $1519 = Math_fround(0), $152 = Math_fround(0), $1520 = Math_fround(0);
 var $1521 = Math_fround(0), $1522 = Math_fround(0), $1523 = Math_fround(0), $1524 = Math_fround(0), $1525 = Math_fround(0), $1526 = Math_fround(0), $1527 = Math_fround(0), $1528 = Math_fround(0), $1529 = Math_fround(0), $153 = 0, $1530 = Math_fround(0), $1531 = Math_fround(0), $1532 = Math_fround(0), $1533 = Math_fround(0), $1534 = Math_fround(0), $1535 = Math_fround(0), $1536 = Math_fround(0), $1537 = Math_fround(0), $1538 = Math_fround(0), $1539 = Math_fround(0);
 var $154 = Math_fround(0), $1540 = Math_fround(0), $1541 = Math_fround(0), $1542 = Math_fround(0), $1543 = Math_fround(0), $1544 = Math_fround(0), $1545 = Math_fround(0), $1546 = Math_fround(0), $1547 = Math_fround(0), $1548 = Math_fround(0), $1549 = Math_fround(0), $155 = 0, $1550 = Math_fround(0), $1551 = Math_fround(0), $1552 = Math_fround(0), $1553 = Math_fround(0), $1554 = Math_fround(0), $1555 = Math_fround(0), $1556 = Math_fround(0), $1557 = Math_fround(0);
 var $1558 = Math_fround(0), $1559 = Math_fround(0), $156 = Math_fround(0), $1560 = Math_fround(0), $1561 = Math_fround(0), $1562 = Math_fround(0), $1563 = Math_fround(0), $1564 = Math_fround(0), $1565 = Math_fround(0), $1566 = Math_fround(0), $1567 = Math_fround(0), $1568 = Math_fround(0), $1569 = Math_fround(0), $157 = 0, $1570 = Math_fround(0), $1571 = Math_fround(0), $1572 = Math_fround(0), $1573 = Math_fround(0), $1574 = Math_fround(0), $1575 = Math_fround(0);
 var $1576 = Math_fround(0), $1577 = Math_fround(0), $1578 = Math_fround(0), $1579 = Math_fround(0), $158 = Math_fround(0), $1580 = Math_fround(0), $1581 = Math_fround(0), $1582 = Math_fround(0), $1583 = Math_fround(0), $1584 = Math_fround(0), $1585 = Math_fround(0), $1586 = Math_fround(0), $1587 = Math_fround(0), $1588 = Math_fround(0), $1589 = Math_fround(0), $159 = 0, $1590 = Math_fround(0), $1591 = Math_fround(0), $1592 = Math_fround(0), $1593 = Math_fround(0);
 var $1594 = Math_fround(0), $1595 = Math_fround(0), $1596 = Math_fround(0), $1597 = Math_fround(0), $1598 = Math_fround(0), $1599 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $1600 = Math_fround(0), $1601 = Math_fround(0), $1602 = Math_fround(0), $1603 = Math_fround(0), $1604 = Math_fround(0), $1605 = Math_fround(0), $1606 = Math_fround(0), $1607 = Math_fround(0), $1608 = Math_fround(0), $1609 = Math_fround(0), $161 = 0, $1610 = Math_fround(0);
 var $1611 = Math_fround(0), $1612 = Math_fround(0), $1613 = Math_fround(0), $1614 = Math_fround(0), $1615 = Math_fround(0), $1616 = Math_fround(0), $1617 = Math_fround(0), $1618 = Math_fround(0), $1619 = Math_fround(0), $162 = 0, $1620 = Math_fround(0), $1621 = Math_fround(0), $1622 = Math_fround(0), $1623 = Math_fround(0), $1624 = Math_fround(0), $1625 = Math_fround(0), $1626 = Math_fround(0), $1627 = Math_fround(0), $1628 = Math_fround(0), $1629 = Math_fround(0);
 var $163 = Math_fround(0), $1630 = Math_fround(0), $1631 = Math_fround(0), $1632 = Math_fround(0), $1633 = Math_fround(0), $1634 = Math_fround(0), $1635 = Math_fround(0), $1636 = Math_fround(0), $1637 = Math_fround(0), $1638 = Math_fround(0), $1639 = Math_fround(0), $164 = 0, $1640 = Math_fround(0), $1641 = Math_fround(0), $1642 = Math_fround(0), $1643 = Math_fround(0), $1644 = Math_fround(0), $1645 = Math_fround(0), $1646 = Math_fround(0), $1647 = Math_fround(0);
 var $1648 = Math_fround(0), $1649 = Math_fround(0), $165 = Math_fround(0), $1650 = Math_fround(0), $1651 = Math_fround(0), $1652 = Math_fround(0), $1653 = Math_fround(0), $1654 = Math_fround(0), $1655 = Math_fround(0), $1656 = Math_fround(0), $1657 = Math_fround(0), $1658 = Math_fround(0), $1659 = Math_fround(0), $166 = 0, $1660 = Math_fround(0), $1661 = Math_fround(0), $1662 = Math_fround(0), $1663 = Math_fround(0), $1664 = 0, $1665 = 0;
 var $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = Math_fround(0), $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = Math_fround(0), $1677 = Math_fround(0), $1678 = Math_fround(0), $1679 = Math_fround(0), $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0;
 var $1684 = Math_fround(0), $1685 = Math_fround(0), $1686 = Math_fround(0), $1687 = Math_fround(0), $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = Math_fround(0), $1693 = Math_fround(0), $1694 = Math_fround(0), $1695 = Math_fround(0), $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = Math_fround(0), $1700 = 0;
 var $1701 = Math_fround(0), $1702 = 0, $1703 = Math_fround(0), $1704 = 0, $1705 = Math_fround(0), $1706 = 0, $1707 = Math_fround(0), $1708 = Math_fround(0), $1709 = Math_fround(0), $171 = 0, $1710 = Math_fround(0), $1711 = Math_fround(0), $1712 = Math_fround(0), $1713 = Math_fround(0), $1714 = Math_fround(0), $1715 = Math_fround(0), $1716 = Math_fround(0), $1717 = Math_fround(0), $1718 = Math_fround(0), $1719 = Math_fround(0);
 var $172 = Math_fround(0), $1720 = Math_fround(0), $1721 = Math_fround(0), $1722 = Math_fround(0), $1723 = Math_fround(0), $1724 = 0, $1725 = 0, $1726 = Math_fround(0), $1727 = 0, $1728 = 0, $1729 = Math_fround(0), $173 = 0, $1730 = Math_fround(0), $1731 = Math_fround(0), $1732 = Math_fround(0), $1733 = Math_fround(0), $1734 = Math_fround(0), $1735 = Math_fround(0), $1736 = Math_fround(0), $1737 = Math_fround(0);
 var $1738 = Math_fround(0), $1739 = Math_fround(0), $174 = Math_fround(0), $1740 = Math_fround(0), $1741 = Math_fround(0), $1742 = Math_fround(0), $1743 = Math_fround(0), $1744 = Math_fround(0), $1745 = Math_fround(0), $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = Math_fround(0), $1753 = Math_fround(0), $1754 = Math_fround(0), $1755 = Math_fround(0);
 var $1756 = Math_fround(0), $1757 = Math_fround(0), $1758 = Math_fround(0), $1759 = Math_fround(0), $176 = 0, $1760 = Math_fround(0), $1761 = Math_fround(0), $1762 = Math_fround(0), $1763 = Math_fround(0), $1764 = Math_fround(0), $1765 = Math_fround(0), $1766 = Math_fround(0), $1767 = Math_fround(0), $1768 = 0, $1769 = 0, $177 = Math_fround(0), $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0;
 var $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = Math_fround(0), $1790 = 0, $1791 = 0;
 var $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = Math_fround(0), $1809 = Math_fround(0);
 var $181 = Math_fround(0), $1810 = Math_fround(0), $1811 = Math_fround(0), $1812 = Math_fround(0), $1813 = Math_fround(0), $1814 = Math_fround(0), $1815 = Math_fround(0), $1816 = Math_fround(0), $1817 = Math_fround(0), $1818 = Math_fround(0), $1819 = Math_fround(0), $182 = 0, $1820 = 0, $1821 = 0, $1822 = Math_fround(0), $1823 = 0, $1824 = Math_fround(0), $1825 = 0, $1826 = Math_fround(0), $1827 = 0;
 var $1828 = Math_fround(0), $1829 = 0, $183 = 0, $1830 = Math_fround(0), $1831 = 0, $1832 = Math_fround(0), $1833 = 0, $1834 = Math_fround(0), $1835 = 0, $1836 = Math_fround(0), $1837 = 0, $1838 = Math_fround(0), $1839 = 0, $184 = Math_fround(0), $1840 = Math_fround(0), $1841 = 0, $1842 = Math_fround(0), $1843 = 0, $1844 = Math_fround(0), $1845 = 0;
 var $1846 = Math_fround(0), $1847 = Math_fround(0), $1848 = Math_fround(0), $1849 = Math_fround(0), $185 = 0, $1850 = Math_fround(0), $1851 = Math_fround(0), $1852 = Math_fround(0), $1853 = Math_fround(0), $1854 = Math_fround(0), $1855 = Math_fround(0), $1856 = Math_fround(0), $1857 = Math_fround(0), $1858 = Math_fround(0), $1859 = Math_fround(0), $186 = Math_fround(0), $1860 = Math_fround(0), $1861 = Math_fround(0), $1862 = Math_fround(0), $1863 = Math_fround(0);
 var $1864 = Math_fround(0), $1865 = Math_fround(0), $1866 = Math_fround(0), $1867 = Math_fround(0), $1868 = Math_fround(0), $1869 = Math_fround(0), $187 = 0, $1870 = Math_fround(0), $1871 = Math_fround(0), $1872 = Math_fround(0), $1873 = Math_fround(0), $1874 = Math_fround(0), $1875 = Math_fround(0), $1876 = Math_fround(0), $1877 = Math_fround(0), $1878 = Math_fround(0), $1879 = Math_fround(0), $188 = Math_fround(0), $1880 = Math_fround(0), $1881 = Math_fround(0);
 var $1882 = Math_fround(0), $1883 = Math_fround(0), $1884 = Math_fround(0), $1885 = Math_fround(0), $1886 = Math_fround(0), $1887 = Math_fround(0), $1888 = Math_fround(0), $1889 = Math_fround(0), $189 = 0, $1890 = Math_fround(0), $1891 = Math_fround(0), $1892 = Math_fround(0), $1893 = Math_fround(0), $1894 = Math_fround(0), $1895 = Math_fround(0), $1896 = Math_fround(0), $1897 = Math_fround(0), $1898 = Math_fround(0), $1899 = Math_fround(0), $19 = 0;
 var $190 = 0, $1900 = Math_fround(0), $1901 = Math_fround(0), $1902 = Math_fround(0), $1903 = Math_fround(0), $1904 = Math_fround(0), $1905 = Math_fround(0), $1906 = Math_fround(0), $1907 = Math_fround(0), $1908 = Math_fround(0), $1909 = Math_fround(0), $191 = Math_fround(0), $1910 = Math_fround(0), $1911 = Math_fround(0), $1912 = Math_fround(0), $1913 = Math_fround(0), $1914 = Math_fround(0), $1915 = Math_fround(0), $1916 = Math_fround(0), $1917 = Math_fround(0);
 var $1918 = Math_fround(0), $1919 = Math_fround(0), $192 = 0, $1920 = Math_fround(0), $1921 = Math_fround(0), $1922 = Math_fround(0), $1923 = Math_fround(0), $1924 = Math_fround(0), $1925 = Math_fround(0), $1926 = Math_fround(0), $1927 = Math_fround(0), $1928 = Math_fround(0), $1929 = Math_fround(0), $193 = Math_fround(0), $1930 = Math_fround(0), $1931 = Math_fround(0), $1932 = Math_fround(0), $1933 = Math_fround(0), $1934 = Math_fround(0), $1935 = Math_fround(0);
 var $1936 = Math_fround(0), $1937 = Math_fround(0), $1938 = Math_fround(0), $1939 = Math_fround(0), $194 = 0, $1940 = Math_fround(0), $1941 = Math_fround(0), $1942 = Math_fround(0), $1943 = Math_fround(0), $1944 = Math_fround(0), $1945 = Math_fround(0), $1946 = Math_fround(0), $1947 = Math_fround(0), $1948 = Math_fround(0), $1949 = Math_fround(0), $195 = Math_fround(0), $1950 = Math_fround(0), $1951 = Math_fround(0), $1952 = Math_fround(0), $1953 = Math_fround(0);
 var $1954 = Math_fround(0), $1955 = Math_fround(0), $1956 = Math_fround(0), $1957 = Math_fround(0), $1958 = Math_fround(0), $1959 = Math_fround(0), $196 = 0, $1960 = Math_fround(0), $1961 = Math_fround(0), $1962 = Math_fround(0), $1963 = Math_fround(0), $1964 = Math_fround(0), $1965 = Math_fround(0), $1966 = Math_fround(0), $1967 = Math_fround(0), $1968 = Math_fround(0), $1969 = Math_fround(0), $197 = 0, $1970 = Math_fround(0), $1971 = Math_fround(0);
 var $1972 = Math_fround(0), $1973 = Math_fround(0), $1974 = Math_fround(0), $1975 = Math_fround(0), $1976 = Math_fround(0), $1977 = Math_fround(0), $1978 = Math_fround(0), $1979 = Math_fround(0), $198 = Math_fround(0), $1980 = Math_fround(0), $1981 = Math_fround(0), $1982 = Math_fround(0), $1983 = Math_fround(0), $1984 = Math_fround(0), $1985 = Math_fround(0), $1986 = Math_fround(0), $1987 = Math_fround(0), $1988 = Math_fround(0), $1989 = Math_fround(0), $199 = 0;
 var $1990 = Math_fround(0), $1991 = Math_fround(0), $1992 = Math_fround(0), $1993 = Math_fround(0), $1994 = Math_fround(0), $1995 = Math_fround(0), $1996 = Math_fround(0), $1997 = Math_fround(0), $1998 = Math_fround(0), $1999 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $2000 = Math_fround(0), $2001 = Math_fround(0), $2002 = Math_fround(0), $2003 = Math_fround(0), $2004 = Math_fround(0), $2005 = Math_fround(0), $2006 = Math_fround(0);
 var $2007 = Math_fround(0), $2008 = Math_fround(0), $2009 = Math_fround(0), $201 = 0, $2010 = Math_fround(0), $2011 = Math_fround(0), $2012 = Math_fround(0), $2013 = Math_fround(0), $2014 = Math_fround(0), $2015 = Math_fround(0), $2016 = Math_fround(0), $2017 = Math_fround(0), $2018 = Math_fround(0), $2019 = Math_fround(0), $202 = Math_fround(0), $2020 = Math_fround(0), $2021 = Math_fround(0), $2022 = Math_fround(0), $2023 = Math_fround(0), $2024 = Math_fround(0);
 var $2025 = Math_fround(0), $2026 = Math_fround(0), $2027 = Math_fround(0), $2028 = Math_fround(0), $2029 = Math_fround(0), $203 = 0, $2030 = Math_fround(0), $2031 = Math_fround(0), $2032 = Math_fround(0), $2033 = Math_fround(0), $2034 = Math_fround(0), $2035 = Math_fround(0), $2036 = Math_fround(0), $2037 = Math_fround(0), $2038 = Math_fround(0), $2039 = Math_fround(0), $204 = 0, $2040 = Math_fround(0), $2041 = Math_fround(0), $2042 = Math_fround(0);
 var $2043 = Math_fround(0), $2044 = Math_fround(0), $2045 = Math_fround(0), $2046 = Math_fround(0), $2047 = Math_fround(0), $2048 = Math_fround(0), $2049 = Math_fround(0), $205 = Math_fround(0), $2050 = Math_fround(0), $2051 = Math_fround(0), $2052 = Math_fround(0), $2053 = Math_fround(0), $2054 = Math_fround(0), $2055 = Math_fround(0), $2056 = Math_fround(0), $2057 = Math_fround(0), $2058 = Math_fround(0), $2059 = Math_fround(0), $206 = 0, $2060 = Math_fround(0);
 var $2061 = Math_fround(0), $2062 = Math_fround(0), $2063 = Math_fround(0), $2064 = Math_fround(0), $2065 = Math_fround(0), $2066 = Math_fround(0), $2067 = Math_fround(0), $2068 = Math_fround(0), $2069 = Math_fround(0), $207 = Math_fround(0), $2070 = Math_fround(0), $2071 = Math_fround(0), $2072 = Math_fround(0), $2073 = Math_fround(0), $2074 = Math_fround(0), $2075 = Math_fround(0), $2076 = Math_fround(0), $2077 = Math_fround(0), $2078 = Math_fround(0), $2079 = Math_fround(0);
 var $208 = 0, $2080 = Math_fround(0), $2081 = Math_fround(0), $2082 = Math_fround(0), $2083 = Math_fround(0), $2084 = Math_fround(0), $2085 = Math_fround(0), $2086 = Math_fround(0), $2087 = Math_fround(0), $2088 = Math_fround(0), $2089 = Math_fround(0), $209 = Math_fround(0), $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0;
 var $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = Math_fround(0), $2103 = Math_fround(0), $2104 = Math_fround(0), $2105 = Math_fround(0), $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0, $2110 = Math_fround(0), $2111 = Math_fround(0), $2112 = Math_fround(0), $2113 = Math_fround(0), $2114 = 0;
 var $2115 = 0, $2116 = 0, $2117 = 0, $2118 = Math_fround(0), $2119 = Math_fround(0), $212 = Math_fround(0), $2120 = Math_fround(0), $2121 = Math_fround(0), $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0, $2130 = Math_fround(0), $2131 = Math_fround(0), $2132 = Math_fround(0);
 var $2133 = Math_fround(0), $2134 = Math_fround(0), $2135 = Math_fround(0), $2136 = Math_fround(0), $2137 = Math_fround(0), $2138 = Math_fround(0), $2139 = Math_fround(0), $214 = Math_fround(0), $2140 = Math_fround(0), $2141 = Math_fround(0), $2142 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = 0;
 var $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = Math_fround(0), $2160 = 0, $2161 = 0, $2162 = 0, $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0, $2167 = 0, $2168 = 0, $2169 = 0;
 var $217 = 0, $2170 = 0, $2171 = Math_fround(0), $2172 = Math_fround(0), $2173 = Math_fround(0), $2174 = Math_fround(0), $2175 = Math_fround(0), $2176 = Math_fround(0), $2177 = Math_fround(0), $2178 = Math_fround(0), $2179 = Math_fround(0), $218 = Math_fround(0), $2180 = Math_fround(0), $2181 = Math_fround(0), $2182 = Math_fround(0), $2183 = Math_fround(0), $2184 = Math_fround(0), $2185 = Math_fround(0), $2186 = Math_fround(0), $2187 = Math_fround(0);
 var $2188 = Math_fround(0), $2189 = Math_fround(0), $219 = 0, $2190 = Math_fround(0), $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0, $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0, $22 = 0, $220 = Math_fround(0), $2200 = 0, $2201 = 0, $2202 = 0, $2203 = 0, $2204 = 0;
 var $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = Math_fround(0), $221 = 0, $2210 = 0, $2211 = Math_fround(0), $2212 = 0, $2213 = Math_fround(0), $2214 = 0, $2215 = Math_fround(0), $2216 = 0, $2217 = Math_fround(0), $2218 = 0, $2219 = Math_fround(0), $222 = Math_fround(0), $2220 = 0, $2221 = Math_fround(0), $2222 = 0;
 var $2223 = Math_fround(0), $2224 = 0, $2225 = Math_fround(0), $2226 = 0, $2227 = Math_fround(0), $2228 = 0, $2229 = Math_fround(0), $223 = 0, $2230 = 0, $2231 = Math_fround(0), $2232 = 0, $2233 = Math_fround(0), $2234 = Math_fround(0), $2235 = Math_fround(0), $2236 = Math_fround(0), $2237 = Math_fround(0), $2238 = Math_fround(0), $2239 = Math_fround(0), $224 = Math_fround(0), $2240 = Math_fround(0);
 var $2241 = Math_fround(0), $2242 = Math_fround(0), $2243 = Math_fround(0), $2244 = Math_fround(0), $2245 = Math_fround(0), $2246 = Math_fround(0), $2247 = Math_fround(0), $2248 = Math_fround(0), $2249 = Math_fround(0), $225 = 0, $2250 = Math_fround(0), $2251 = Math_fround(0), $2252 = Math_fround(0), $2253 = Math_fround(0), $2254 = Math_fround(0), $2255 = Math_fround(0), $2256 = Math_fround(0), $2257 = Math_fround(0), $2258 = Math_fround(0), $2259 = Math_fround(0);
 var $226 = Math_fround(0), $2260 = Math_fround(0), $2261 = Math_fround(0), $2262 = Math_fround(0), $2263 = Math_fround(0), $2264 = Math_fround(0), $2265 = Math_fround(0), $2266 = Math_fround(0), $2267 = Math_fround(0), $2268 = Math_fround(0), $2269 = Math_fround(0), $227 = 0, $2270 = Math_fround(0), $2271 = Math_fround(0), $2272 = Math_fround(0), $2273 = Math_fround(0), $2274 = Math_fround(0), $2275 = Math_fround(0), $2276 = Math_fround(0), $2277 = Math_fround(0);
 var $2278 = Math_fround(0), $2279 = Math_fround(0), $228 = Math_fround(0), $2280 = Math_fround(0), $2281 = Math_fround(0), $2282 = Math_fround(0), $2283 = Math_fround(0), $2284 = Math_fround(0), $2285 = Math_fround(0), $2286 = Math_fround(0), $2287 = Math_fround(0), $2288 = Math_fround(0), $2289 = Math_fround(0), $229 = 0, $2290 = Math_fround(0), $2291 = Math_fround(0), $2292 = Math_fround(0), $2293 = Math_fround(0), $2294 = Math_fround(0), $2295 = Math_fround(0);
 var $2296 = Math_fround(0), $2297 = Math_fround(0), $2298 = Math_fround(0), $2299 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $2300 = Math_fround(0), $2301 = Math_fround(0), $2302 = Math_fround(0), $2303 = Math_fround(0), $2304 = Math_fround(0), $2305 = Math_fround(0), $2306 = Math_fround(0), $2307 = Math_fround(0), $2308 = Math_fround(0), $2309 = Math_fround(0), $231 = 0, $2310 = Math_fround(0), $2311 = Math_fround(0), $2312 = Math_fround(0);
 var $2313 = Math_fround(0), $2314 = Math_fround(0), $2315 = Math_fround(0), $2316 = Math_fround(0), $2317 = Math_fround(0), $2318 = Math_fround(0), $2319 = Math_fround(0), $232 = Math_fround(0), $2320 = Math_fround(0), $2321 = Math_fround(0), $2322 = Math_fround(0), $2323 = Math_fround(0), $2324 = Math_fround(0), $2325 = Math_fround(0), $2326 = Math_fround(0), $2327 = Math_fround(0), $2328 = Math_fround(0), $2329 = Math_fround(0), $233 = 0, $2330 = Math_fround(0);
 var $2331 = Math_fround(0), $2332 = Math_fround(0), $2333 = Math_fround(0), $2334 = Math_fround(0), $2335 = Math_fround(0), $2336 = Math_fround(0), $2337 = Math_fround(0), $2338 = Math_fround(0), $2339 = Math_fround(0), $234 = Math_fround(0), $2340 = Math_fround(0), $2341 = Math_fround(0), $2342 = Math_fround(0), $2343 = Math_fround(0), $2344 = Math_fround(0), $2345 = Math_fround(0), $2346 = Math_fround(0), $2347 = Math_fround(0), $2348 = Math_fround(0), $2349 = Math_fround(0);
 var $235 = 0, $2350 = Math_fround(0), $2351 = Math_fround(0), $2352 = Math_fround(0), $2353 = 0, $2354 = 0, $2355 = 0, $2356 = 0, $2357 = Math_fround(0), $2358 = Math_fround(0), $2359 = Math_fround(0), $236 = Math_fround(0), $2360 = Math_fround(0), $2361 = Math_fround(0), $2362 = Math_fround(0), $2363 = Math_fround(0), $2364 = Math_fround(0), $2365 = Math_fround(0), $2366 = Math_fround(0), $2367 = Math_fround(0);
 var $2368 = Math_fround(0), $2369 = 0, $237 = 0, $2370 = 0, $2371 = 0, $2372 = 0, $2373 = 0, $2374 = 0, $2375 = 0, $2376 = 0, $2377 = 0, $2378 = 0, $2379 = 0, $238 = Math_fround(0), $2380 = 0, $2381 = 0, $2382 = 0, $2383 = 0, $2384 = 0, $2385 = 0;
 var $2386 = 0, $2387 = 0, $2388 = 0, $2389 = 0, $239 = 0, $2390 = 0, $2391 = 0, $2392 = 0, $2393 = 0, $2394 = 0, $2395 = 0, $2396 = 0, $2397 = 0, $2398 = Math_fround(0), $2399 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $2400 = Math_fround(0), $2401 = Math_fround(0), $2402 = Math_fround(0);
 var $2403 = Math_fround(0), $2404 = Math_fround(0), $2405 = Math_fround(0), $2406 = Math_fround(0), $2407 = Math_fround(0), $2408 = Math_fround(0), $2409 = Math_fround(0), $241 = 0, $2410 = Math_fround(0), $2411 = Math_fround(0), $2412 = Math_fround(0), $2413 = Math_fround(0), $2414 = Math_fround(0), $2415 = Math_fround(0), $2416 = Math_fround(0), $2417 = Math_fround(0), $2418 = 0, $2419 = 0, $242 = Math_fround(0), $2420 = 0;
 var $2421 = 0, $2422 = 0, $2423 = 0, $2424 = 0, $2425 = 0, $2426 = 0, $2427 = 0, $2428 = 0, $2429 = 0, $243 = 0, $2430 = 0, $2431 = 0, $2432 = 0, $2433 = 0, $2434 = 0, $2435 = 0, $2436 = 0, $2437 = 0, $2438 = 0, $2439 = 0;
 var $244 = Math_fround(0), $2440 = 0, $2441 = 0, $2442 = 0, $2443 = 0, $2444 = 0, $2445 = 0, $2446 = 0, $2447 = 0, $2448 = 0, $2449 = 0, $245 = 0, $2450 = 0, $2451 = 0, $2452 = 0, $2453 = 0, $2454 = 0, $2455 = 0, $2456 = 0, $2457 = 0;
 var $2458 = 0, $2459 = 0, $246 = Math_fround(0), $2460 = 0, $2461 = 0, $2462 = 0, $2463 = 0, $2464 = 0, $2465 = 0, $2466 = 0, $2467 = 0, $2468 = 0, $2469 = 0, $247 = 0, $2470 = 0, $2471 = 0, $2472 = 0, $2473 = 0, $2474 = 0, $2475 = 0;
 var $2476 = 0, $2477 = 0, $2478 = 0, $2479 = 0, $248 = Math_fround(0), $2480 = 0, $2481 = 0, $2482 = 0, $2483 = 0, $2484 = 0, $2485 = 0, $2486 = 0, $2487 = 0, $2488 = 0, $2489 = 0, $249 = 0, $2490 = 0, $2491 = 0, $2492 = 0, $2493 = 0;
 var $2494 = 0, $2495 = 0, $2496 = 0, $2497 = 0, $2498 = 0, $2499 = 0, $25 = 0, $250 = Math_fround(0), $2500 = 0, $2501 = 0, $2502 = 0, $2503 = 0, $2504 = 0, $2505 = 0, $2506 = 0, $2507 = 0, $2508 = 0, $2509 = 0, $251 = 0, $2510 = 0;
 var $2511 = 0, $2512 = 0, $2513 = 0, $2514 = 0, $2515 = 0, $2516 = 0, $2517 = 0, $2518 = 0, $2519 = 0, $252 = Math_fround(0), $2520 = 0, $2521 = 0, $2522 = 0, $2523 = 0, $2524 = 0, $2525 = 0, $2526 = 0, $2527 = 0, $2528 = 0, $2529 = 0;
 var $253 = 0, $2530 = 0, $2531 = 0, $2532 = 0, $2533 = 0, $2534 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0);
 var $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0);
 var $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0;
 var $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0);
 var $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0);
 var $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0;
 var $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0);
 var $393 = 0, $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0), $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = 0;
 var $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0);
 var $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0);
 var $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0);
 var $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0;
 var $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = Math_fround(0), $518 = 0;
 var $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = 0, $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = Math_fround(0), $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = 0, $535 = Math_fround(0), $536 = 0;
 var $537 = Math_fround(0), $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $546 = 0, $547 = 0, $548 = 0, $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = 0;
 var $555 = 0, $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = Math_fround(0), $560 = 0, $561 = Math_fround(0), $562 = 0, $563 = 0, $564 = 0, $565 = Math_fround(0), $566 = 0, $567 = Math_fround(0), $568 = 0, $569 = Math_fround(0), $57 = 0, $570 = 0, $571 = 0, $572 = 0;
 var $573 = Math_fround(0), $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0;
 var $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0;
 var $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0;
 var $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0;
 var $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0;
 var $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = Math_fround(0), $680 = 0;
 var $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0;
 var $7 = 0, $70 = Math_fround(0), $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = Math_fround(0), $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0;
 var $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = Math_fround(0), $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0;
 var $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = Math_fround(0), $750 = 0, $751 = 0, $752 = 0;
 var $753 = Math_fround(0), $754 = 0, $755 = Math_fround(0), $756 = 0, $757 = Math_fround(0), $758 = 0, $759 = Math_fround(0), $76 = 0, $760 = 0, $761 = Math_fround(0), $762 = 0, $763 = Math_fround(0), $764 = 0, $765 = Math_fround(0), $766 = 0, $767 = Math_fround(0), $768 = 0, $769 = 0, $77 = Math_fround(0), $770 = 0;
 var $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = Math_fround(0), $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0;
 var $79 = Math_fround(0), $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = Math_fround(0), $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0;
 var $807 = 0, $808 = 0, $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = Math_fround(0), $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0;
 var $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = Math_fround(0), $833 = 0, $834 = Math_fround(0), $835 = 0, $836 = Math_fround(0), $837 = 0, $838 = Math_fround(0), $839 = 0, $84 = Math_fround(0), $840 = Math_fround(0), $841 = 0, $842 = Math_fround(0);
 var $843 = 0, $844 = Math_fround(0), $845 = 0, $846 = Math_fround(0), $847 = 0, $848 = Math_fround(0), $849 = 0, $85 = 0, $850 = Math_fround(0), $851 = 0, $852 = Math_fround(0), $853 = 0, $854 = Math_fround(0), $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = Math_fround(0), $860 = 0;
 var $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = 0, $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0);
 var $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0);
 var $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0);
 var $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = Math_fround(0), $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = Math_fround(0), $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0);
 var $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = 0, $94 = 0, $940 = 0, $941 = Math_fround(0), $942 = 0, $943 = 0, $944 = Math_fround(0), $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = Math_fround(0), $95 = Math_fround(0), $950 = Math_fround(0);
 var $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = 0, $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0);
 var $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0);
 var $988 = Math_fround(0), $989 = Math_fround(0), $99 = Math_fround(0), $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $a$05717 = 0, $a$05717$us = 0, $a$pn4$i = 0, $a$pn4$i$us = 0, $a$pn4$i272 = 0, $a$pn4$i292 = 0, $a$pn4$i349 = 0;
 var $a$pn4$i759 = 0, $a$pn4$i773 = 0, $a$pn4$i787 = 0, $a$pn4$i855 = 0, $a$pn4$i869 = 0, $a$pn4$i885 = 0, $a$pn6$i = 0, $a$pn6$i$us = 0, $a$pn6$i276 = 0, $a$pn6$i296 = 0, $a$pn6$i353 = 0, $a$pn6$i763 = 0, $a$pn6$i777 = 0, $a$pn6$i791 = 0, $a$pn6$i859 = 0, $a$pn6$i873 = 0, $a$pn6$i889 = 0, $b$a$i = 0, $b$a$i$us = 0, $b$a$i270 = 0;
 var $b$a$i290 = 0, $b$a$i347 = 0, $b$a$i757 = 0, $b$a$i771 = 0, $b$a$i785 = 0, $b$a$i853 = 0, $b$a$i867 = 0, $b$a$i883 = 0, $b$a7$i = 0, $b$a7$i$us = 0, $b$a7$i274 = 0, $b$a7$i294 = 0, $b$a7$i351 = 0, $b$a7$i761 = 0, $b$a7$i775 = 0, $b$a7$i789 = 0, $b$a7$i857 = 0, $b$a7$i871 = 0, $b$a7$i887 = 0, $exitcond = 0;
 var $exitcond5756 = 0, $finished$0 = 0, $finished$0$ph = 0, $finished$0$phi = 0, $fricIndex$0 = 0, $fricIndex$0$ph = 0, $fricIndex$1$lcssa = 0, $fricIndex$15715 = 0, $fricIndex$15715$us = 0, $frictionIndex0$05748 = 0, $frictionIndex1$05747 = 0, $frictionIndex2$05746 = 0, $frictionIndex3$05745 = 0, $i$05743 = 0, $newContact$0$lcssa$i = 0, $newContact$0$lcssa$i15 = 0, $newContact$0$lcssa$i155686 = 0, $newContact$0$lcssa$i22 = 0, $newContact$0$lcssa$i225684 = 0, $newContact$0$lcssa$i5690 = 0;
 var $newContact$0$lcssa$i658 = 0, $newContact$0$lcssa$i664 = 0, $newContact$0$lcssa$i670 = 0, $newContact$0$lcssa$i676 = 0, $newContact$0$lcssa$i8 = 0, $newContact$0$lcssa$i85688 = 0, $newContact$02$i = 0, $newContact$02$i13 = 0, $newContact$02$i20 = 0, $newContact$02$i6 = 0, $newContact$02$i656 = 0, $newContact$02$i662 = 0, $newContact$02$i668 = 0, $newContact$02$i674 = 0, $newFinished$0 = 0, $newFinished$0$ph = 0, $newFinished$1 = 0, $newFinished$2 = 0, $newFinished$3 = 0, $newPatch$0$lcssa$i = 0;
 var $newPatch$0$lcssa$i$i = 0, $newPatch$0$lcssa$i$i5677$ph = 0, $newPatch$0$lcssa$i$i681 = 0, $newPatch$0$lcssa$i$i6815678 = 0, $newPatch$0$lcssa$i$i6815678$ph = 0, $newPatch$0$lcssa$i$i6815679 = 0, $newPatch$0$lcssa$i$i685 = 0, $newPatch$0$lcssa$i$i6855680 = 0, $newPatch$0$lcssa$i$i6855680$ph = 0, $newPatch$0$lcssa$i$i6855681 = 0, $newPatch$0$lcssa$i$i689 = 0, $newPatch$0$lcssa$i$i6895682 = 0, $newPatch$0$lcssa$i$i6895682$ph = 0, $newPatch$0$lcssa$i$i6895683 = 0, $newPatch$0$lcssa$i16 = 0, $newPatch$0$lcssa$i165687 = 0, $newPatch$0$lcssa$i23 = 0, $newPatch$0$lcssa$i235685 = 0, $newPatch$0$lcssa$i5691 = 0, $newPatch$0$lcssa$i659 = 0;
 var $newPatch$0$lcssa$i665 = 0, $newPatch$0$lcssa$i671 = 0, $newPatch$0$lcssa$i677 = 0, $newPatch$0$lcssa$i9 = 0, $newPatch$0$lcssa$i95689 = 0, $newPatch$01$i = 0, $newPatch$01$i$i = 0, $newPatch$01$i$i679 = 0, $newPatch$01$i$i683 = 0, $newPatch$01$i$i687 = 0, $newPatch$01$i14 = 0, $newPatch$01$i21 = 0, $newPatch$01$i657 = 0, $newPatch$01$i663 = 0, $newPatch$01$i669 = 0, $newPatch$01$i675 = 0, $newPatch$01$i7 = 0, $not$ = 0, $not$5701 = 0, $not$5706 = 0;
 var $not$5709 = 0, $notlhs5702 = 0, $notlhs5704 = 0, $notlhs5707 = 0, $notlhs5710 = 0, $notrhs5703 = 0, $notrhs5705 = 0, $notrhs5708 = 0, $notrhs5711 = 0, $or$cond = 0, $or$cond5712 = 0, $or$cond5713 = 0, $or$cond5714 = 0, $p$0 = 0, $p$0$ph = 0, $phitmp = 0, $phitmp5695 = 0, $phitmp5696 = 0, $phitmp5697 = 0, $ptr$05749 = 0;
 var $ptr2$05744 = 0, $ptr2$1 = 0, $ptr2$1$ph = 0, $ptr2$2$lcssa = 0, $ptr2$25716 = 0, $ptr2$25716$us = 0, $split = 0, $split5718 = 0, $tFallbackX = 0, $tFallbackY = 0, $tFallbackZ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $1 = sp + 400|0;
 $2 = sp + 384|0;
 $3 = sp + 368|0;
 $4 = sp + 352|0;
 $5 = sp + 336|0;
 $6 = sp + 320|0;
 $7 = sp + 304|0;
 $8 = sp + 288|0;
 $9 = sp + 272|0;
 $10 = sp + 256|0;
 $11 = sp + 240|0;
 $12 = sp + 224|0;
 $13 = sp + 64|0;
 $14 = sp;
 $15 = sp + 16|0;
 $16 = sp + 32|0;
 $17 = sp + 48|0;
 $18 = sp + 80|0;
 $19 = sp + 96|0;
 $20 = sp + 112|0;
 $tFallbackX = sp + 128|0;
 $tFallbackY = sp + 160|0;
 $tFallbackZ = sp + 192|0;
 $21 = HEAP32[$descs>>2]|0;
 $22 = (($21) + 22|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = $23&65535;
 $25 = $24 >>> 8;
 $$lobit = $25 & 1;
 $26 = $$lobit&255;
 $27 = (($descs) + 56|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 22|0);
 $30 = HEAP16[$29>>1]|0;
 $31 = $30&65535;
 $32 = $31 >>> 8;
 $$lobit1 = $32 & 1;
 $33 = $$lobit1&255;
 $34 = (($descs) + 112|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 22|0);
 $37 = HEAP16[$36>>1]|0;
 $38 = $37&65535;
 $39 = $38 >>> 8;
 $$lobit2 = $39 & 1;
 $40 = $$lobit2&255;
 $41 = (($descs) + 168|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 22|0);
 $44 = HEAP16[$43>>1]|0;
 $45 = $44&65535;
 $46 = $45 >>> 8;
 $$lobit3 = $46 & 1;
 $47 = $$lobit3&255;
 $48 = $30 | $23;
 $49 = $48 | $37;
 $50 = $49 | $44;
 $51 = $50 & 64;
 $52 = ($51<<16>>16)!=(0);
 $53 = $52 ? 272 : 176;
 $54 = $52 ? 288 : 192;
 $55 = (($21) + 84|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($28) + 84|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($35) + 84|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($42) + 84|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($21) + 88|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($28) + 88|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($35) + 88|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($42) + 88|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround(HEAPF32[$invMassScale0>>2]);
 $72 = (($invMassScale0) + 4|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($invMassScale0) + 8|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($invMassScale0) + 12|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($56 * $71);
 $79 = Math_fround($58 * $73);
 $80 = Math_fround($60 * $75);
 $81 = Math_fround($62 * $77);
 $82 = Math_fround(HEAPF32[$invMassScale1>>2]);
 $83 = (($invMassScale1) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($invMassScale1) + 8|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($invMassScale1) + 12|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($64 * $82);
 $90 = Math_fround($66 * $84);
 $91 = Math_fround($68 * $86);
 $92 = Math_fround($70 * $88);
 $93 = Math_fround(HEAPF32[$invInertiaScale0>>2]);
 $94 = (($invInertiaScale0) + 4|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($invInertiaScale0) + 8|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($invInertiaScale0) + 12|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($56 * $93);
 $101 = Math_fround($58 * $95);
 $102 = Math_fround($60 * $97);
 $103 = Math_fround($62 * $99);
 $104 = Math_fround(HEAPF32[$invInertiaScale1>>2]);
 $105 = (($invInertiaScale1) + 4|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($invInertiaScale1) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($invInertiaScale1) + 12|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($64 * $104);
 $112 = Math_fround($66 * $106);
 $113 = Math_fround($68 * $108);
 $114 = Math_fround($70 * $110);
 $115 = (($descs) + 44|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($116) + 52|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($descs) + 100|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = (($120) + 52|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($descs) + 156|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($124) + 52|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($descs) + 212|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = (($128) + 52|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($descs) + 48|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = (($132) + 52|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($descs) + 104|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = (($136) + 52|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($descs) + 160|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = (($140) + 52|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($descs) + 216|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = (($144) + 52|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = $118 > $134;
 $$$i1125 = $147 ? $118 : $134;
 $148 = $122 > $138;
 $149 = $148 ? $122 : $138;
 $150 = $126 > $142;
 $$1$i1126 = $150 ? $126 : $142;
 $151 = $130 > $146;
 $152 = $151 ? $130 : $146;
 $153 = (($21) + 92|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($28) + 92|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($35) + 92|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($42) + 92|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($descs) + 36|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($162) + 4|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = (($162) + 8|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = (($descs) + 92|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = (($169) + 4|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = (($169) + 8|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($descs) + 148|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = (($176) + 4|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = (($176) + 8|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = (($descs) + 204|0);
 $183 = HEAP32[$182>>2]|0;
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = (($183) + 4|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($183) + 8|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($descs) + 40|0);
 $190 = HEAP32[$189>>2]|0;
 $191 = Math_fround(HEAPF32[$190>>2]);
 $192 = (($190) + 4|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($190) + 8|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = (($descs) + 96|0);
 $197 = HEAP32[$196>>2]|0;
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = (($197) + 4|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = (($197) + 8|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($descs) + 152|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($204) + 4|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = (($204) + 8|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = (($descs) + 208|0);
 $211 = HEAP32[$210>>2]|0;
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($211) + 4|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = (($211) + 8|0);
 $216 = Math_fround(HEAPF32[$215>>2]);
 $217 = (($162) + 16|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 $219 = (($217) + 4|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = (($217) + 8|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = (($169) + 16|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = (($223) + 4|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = (($223) + 8|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 $229 = (($176) + 16|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = (($229) + 4|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = (($229) + 8|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = (($183) + 16|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = (($235) + 4|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = (($235) + 8|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 $241 = (($190) + 16|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 $243 = (($241) + 4|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = (($241) + 8|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = (($197) + 16|0);
 $248 = Math_fround(HEAPF32[$247>>2]);
 $249 = (($247) + 4|0);
 $250 = Math_fround(HEAPF32[$249>>2]);
 $251 = (($247) + 8|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 $253 = (($204) + 16|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = (($253) + 4|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 $257 = (($253) + 8|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 $259 = (($211) + 16|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = (($259) + 4|0);
 $262 = Math_fround(HEAPF32[$261>>2]);
 $263 = (($259) + 8|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = Math_fround($163 - $191);
 $266 = Math_fround($170 - $198);
 $267 = Math_fround($177 - $205);
 $268 = Math_fround($184 - $212);
 $269 = Math_fround($165 - $193);
 $270 = Math_fround($172 - $200);
 $271 = Math_fround($179 - $207);
 $272 = Math_fround($186 - $214);
 $273 = Math_fround($167 - $195);
 $274 = Math_fround($174 - $202);
 $275 = Math_fround($181 - $209);
 $276 = Math_fround($188 - $216);
 $277 = (($116) + 48|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = (($120) + 48|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = (($124) + 48|0);
 $282 = Math_fround(HEAPF32[$281>>2]);
 $283 = (($128) + 48|0);
 $284 = Math_fround(HEAPF32[$283>>2]);
 $285 = (($132) + 48|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = (($136) + 48|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $289 = (($140) + 48|0);
 $290 = Math_fround(HEAPF32[$289>>2]);
 $291 = (($144) + 48|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = Math_fround($78 * $278);
 $294 = Math_fround($79 * $280);
 $295 = Math_fround($80 * $282);
 $296 = Math_fround($81 * $284);
 $297 = Math_fround($89 * $286);
 $298 = Math_fround(-$297);
 $299 = Math_fround($90 * $288);
 $300 = Math_fround(-$299);
 $301 = Math_fround($91 * $290);
 $302 = Math_fround(-$301);
 $303 = Math_fround($92 * $292);
 $304 = Math_fround(-$303);
 $305 = Math_fround(HEAPF32[$116>>2]);
 $306 = (($116) + 4|0);
 $307 = Math_fround(HEAPF32[$306>>2]);
 $308 = (($116) + 8|0);
 $309 = Math_fround(HEAPF32[$308>>2]);
 $310 = (($116) + 12|0);
 $311 = Math_fround(HEAPF32[$310>>2]);
 $312 = (($116) + 16|0);
 $313 = Math_fround(HEAPF32[$312>>2]);
 $314 = (($116) + 20|0);
 $315 = Math_fround(HEAPF32[$314>>2]);
 $316 = (($116) + 24|0);
 $317 = Math_fround(HEAPF32[$316>>2]);
 $318 = (($116) + 28|0);
 $319 = Math_fround(HEAPF32[$318>>2]);
 $320 = (($116) + 32|0);
 $321 = Math_fround(HEAPF32[$320>>2]);
 $322 = Math_fround(HEAPF32[$120>>2]);
 $323 = (($120) + 4|0);
 $324 = Math_fround(HEAPF32[$323>>2]);
 $325 = (($120) + 8|0);
 $326 = Math_fround(HEAPF32[$325>>2]);
 $327 = (($120) + 12|0);
 $328 = Math_fround(HEAPF32[$327>>2]);
 $329 = (($120) + 16|0);
 $330 = Math_fround(HEAPF32[$329>>2]);
 $331 = (($120) + 20|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = (($120) + 24|0);
 $334 = Math_fround(HEAPF32[$333>>2]);
 $335 = (($120) + 28|0);
 $336 = Math_fround(HEAPF32[$335>>2]);
 $337 = (($120) + 32|0);
 $338 = Math_fround(HEAPF32[$337>>2]);
 $339 = Math_fround(HEAPF32[$124>>2]);
 $340 = (($124) + 4|0);
 $341 = Math_fround(HEAPF32[$340>>2]);
 $342 = (($124) + 8|0);
 $343 = Math_fround(HEAPF32[$342>>2]);
 $344 = (($124) + 12|0);
 $345 = Math_fround(HEAPF32[$344>>2]);
 $346 = (($124) + 16|0);
 $347 = Math_fround(HEAPF32[$346>>2]);
 $348 = (($124) + 20|0);
 $349 = Math_fround(HEAPF32[$348>>2]);
 $350 = (($124) + 24|0);
 $351 = Math_fround(HEAPF32[$350>>2]);
 $352 = (($124) + 28|0);
 $353 = Math_fround(HEAPF32[$352>>2]);
 $354 = (($124) + 32|0);
 $355 = Math_fround(HEAPF32[$354>>2]);
 $356 = Math_fround(HEAPF32[$128>>2]);
 $357 = (($128) + 4|0);
 $358 = Math_fround(HEAPF32[$357>>2]);
 $359 = (($128) + 8|0);
 $360 = Math_fround(HEAPF32[$359>>2]);
 $361 = (($128) + 12|0);
 $362 = Math_fround(HEAPF32[$361>>2]);
 $363 = (($128) + 16|0);
 $364 = Math_fround(HEAPF32[$363>>2]);
 $365 = (($128) + 20|0);
 $366 = Math_fround(HEAPF32[$365>>2]);
 $367 = (($128) + 24|0);
 $368 = Math_fround(HEAPF32[$367>>2]);
 $369 = (($128) + 28|0);
 $370 = Math_fround(HEAPF32[$369>>2]);
 $371 = (($128) + 32|0);
 $372 = Math_fround(HEAPF32[$371>>2]);
 $373 = Math_fround(HEAPF32[$132>>2]);
 $374 = (($132) + 4|0);
 $375 = Math_fround(HEAPF32[$374>>2]);
 $376 = (($132) + 8|0);
 $377 = Math_fround(HEAPF32[$376>>2]);
 $378 = (($132) + 12|0);
 $379 = Math_fround(HEAPF32[$378>>2]);
 $380 = (($132) + 16|0);
 $381 = Math_fround(HEAPF32[$380>>2]);
 $382 = (($132) + 20|0);
 $383 = Math_fround(HEAPF32[$382>>2]);
 $384 = (($132) + 24|0);
 $385 = Math_fround(HEAPF32[$384>>2]);
 $386 = (($132) + 28|0);
 $387 = Math_fround(HEAPF32[$386>>2]);
 $388 = (($132) + 32|0);
 $389 = Math_fround(HEAPF32[$388>>2]);
 $390 = Math_fround(HEAPF32[$136>>2]);
 $391 = (($136) + 4|0);
 $392 = Math_fround(HEAPF32[$391>>2]);
 $393 = (($136) + 8|0);
 $394 = Math_fround(HEAPF32[$393>>2]);
 $395 = (($136) + 12|0);
 $396 = Math_fround(HEAPF32[$395>>2]);
 $397 = (($136) + 16|0);
 $398 = Math_fround(HEAPF32[$397>>2]);
 $399 = (($136) + 20|0);
 $400 = Math_fround(HEAPF32[$399>>2]);
 $401 = (($136) + 24|0);
 $402 = Math_fround(HEAPF32[$401>>2]);
 $403 = (($136) + 28|0);
 $404 = Math_fround(HEAPF32[$403>>2]);
 $405 = (($136) + 32|0);
 $406 = Math_fround(HEAPF32[$405>>2]);
 $407 = Math_fround(HEAPF32[$140>>2]);
 $408 = (($140) + 4|0);
 $409 = Math_fround(HEAPF32[$408>>2]);
 $410 = (($140) + 8|0);
 $411 = Math_fround(HEAPF32[$410>>2]);
 $412 = (($140) + 12|0);
 $413 = Math_fround(HEAPF32[$412>>2]);
 $414 = (($140) + 16|0);
 $415 = Math_fround(HEAPF32[$414>>2]);
 $416 = (($140) + 20|0);
 $417 = Math_fround(HEAPF32[$416>>2]);
 $418 = (($140) + 24|0);
 $419 = Math_fround(HEAPF32[$418>>2]);
 $420 = (($140) + 28|0);
 $421 = Math_fround(HEAPF32[$420>>2]);
 $422 = (($140) + 32|0);
 $423 = Math_fround(HEAPF32[$422>>2]);
 $424 = Math_fround(HEAPF32[$144>>2]);
 $425 = (($144) + 4|0);
 $426 = Math_fround(HEAPF32[$425>>2]);
 $427 = (($144) + 8|0);
 $428 = Math_fround(HEAPF32[$427>>2]);
 $429 = (($144) + 12|0);
 $430 = Math_fround(HEAPF32[$429>>2]);
 $431 = (($144) + 16|0);
 $432 = Math_fround(HEAPF32[$431>>2]);
 $433 = (($144) + 20|0);
 $434 = Math_fround(HEAPF32[$433>>2]);
 $435 = (($144) + 24|0);
 $436 = Math_fround(HEAPF32[$435>>2]);
 $437 = (($144) + 28|0);
 $438 = Math_fround(HEAPF32[$437>>2]);
 $439 = (($144) + 32|0);
 $440 = Math_fround(HEAPF32[$439>>2]);
 $441 = Math_fround($100 * $305);
 $442 = Math_fround($101 * $322);
 $443 = Math_fround($102 * $339);
 $444 = Math_fround($103 * $356);
 $445 = Math_fround($100 * $307);
 $446 = Math_fround($101 * $324);
 $447 = Math_fround($102 * $341);
 $448 = Math_fround($103 * $358);
 $449 = Math_fround($100 * $309);
 $450 = Math_fround($101 * $326);
 $451 = Math_fround($102 * $343);
 $452 = Math_fround($103 * $360);
 $453 = Math_fround($100 * $311);
 $454 = Math_fround($101 * $328);
 $455 = Math_fround($102 * $345);
 $456 = Math_fround($103 * $362);
 $457 = Math_fround($100 * $313);
 $458 = Math_fround($101 * $330);
 $459 = Math_fround($102 * $347);
 $460 = Math_fround($103 * $364);
 $461 = Math_fround($100 * $315);
 $462 = Math_fround($101 * $332);
 $463 = Math_fround($102 * $349);
 $464 = Math_fround($103 * $366);
 $465 = Math_fround($100 * $317);
 $466 = Math_fround($101 * $334);
 $467 = Math_fround($102 * $351);
 $468 = Math_fround($103 * $368);
 $469 = Math_fround($100 * $319);
 $470 = Math_fround($101 * $336);
 $471 = Math_fround($102 * $353);
 $472 = Math_fround($103 * $370);
 $473 = Math_fround($100 * $321);
 $474 = Math_fround($101 * $338);
 $475 = Math_fround($102 * $355);
 $476 = Math_fround($103 * $372);
 $477 = Math_fround($111 * $373);
 $478 = Math_fround($112 * $390);
 $479 = Math_fround($113 * $407);
 $480 = Math_fround($114 * $424);
 $481 = Math_fround($111 * $375);
 $482 = Math_fround($112 * $392);
 $483 = Math_fround($113 * $409);
 $484 = Math_fround($114 * $426);
 $485 = Math_fround($111 * $377);
 $486 = Math_fround($112 * $394);
 $487 = Math_fround($113 * $411);
 $488 = Math_fround($114 * $428);
 $489 = Math_fround($111 * $379);
 $490 = Math_fround($112 * $396);
 $491 = Math_fround($113 * $413);
 $492 = Math_fround($114 * $430);
 $493 = Math_fround($111 * $381);
 $494 = Math_fround($112 * $398);
 $495 = Math_fround($113 * $415);
 $496 = Math_fround($114 * $432);
 $497 = Math_fround($111 * $383);
 $498 = Math_fround($112 * $400);
 $499 = Math_fround($113 * $417);
 $500 = Math_fround($114 * $434);
 $501 = Math_fround($111 * $385);
 $502 = Math_fround($112 * $402);
 $503 = Math_fround($113 * $419);
 $504 = Math_fround($114 * $436);
 $505 = Math_fround($111 * $387);
 $506 = Math_fround($112 * $404);
 $507 = Math_fround($113 * $421);
 $508 = Math_fround($114 * $438);
 $509 = Math_fround($111 * $389);
 $510 = Math_fround($112 * $406);
 $511 = Math_fround($113 * $423);
 $512 = Math_fround($114 * $440);
 $513 = Math_fround($invDtF32 * Math_fround(0.800000011920928955078));
 $514 = (($descs) + 28|0);
 $515 = HEAP32[$514>>2]|0;
 $516 = (($515) + 16|0);
 $517 = Math_fround(HEAPF32[$516>>2]);
 $518 = (($515) + 20|0);
 $519 = Math_fround(HEAPF32[$518>>2]);
 $520 = (($515) + 24|0);
 $521 = Math_fround(HEAPF32[$520>>2]);
 $522 = (($descs) + 84|0);
 $523 = HEAP32[$522>>2]|0;
 $524 = (($523) + 16|0);
 $525 = Math_fround(HEAPF32[$524>>2]);
 $526 = (($523) + 20|0);
 $527 = Math_fround(HEAPF32[$526>>2]);
 $528 = (($523) + 24|0);
 $529 = Math_fround(HEAPF32[$528>>2]);
 $530 = (($descs) + 140|0);
 $531 = HEAP32[$530>>2]|0;
 $532 = (($531) + 16|0);
 $533 = Math_fround(HEAPF32[$532>>2]);
 $534 = (($531) + 20|0);
 $535 = Math_fround(HEAPF32[$534>>2]);
 $536 = (($531) + 24|0);
 $537 = Math_fround(HEAPF32[$536>>2]);
 $538 = (($descs) + 196|0);
 $539 = HEAP32[$538>>2]|0;
 $540 = (($539) + 16|0);
 $541 = Math_fround(HEAPF32[$540>>2]);
 $542 = (($539) + 20|0);
 $543 = Math_fround(HEAPF32[$542>>2]);
 $544 = (($539) + 24|0);
 $545 = Math_fround(HEAPF32[$544>>2]);
 $546 = (($descs) + 32|0);
 $547 = HEAP32[$546>>2]|0;
 $548 = (($547) + 16|0);
 $549 = Math_fround(HEAPF32[$548>>2]);
 $550 = (($547) + 20|0);
 $551 = Math_fround(HEAPF32[$550>>2]);
 $552 = (($547) + 24|0);
 $553 = Math_fround(HEAPF32[$552>>2]);
 $554 = (($descs) + 88|0);
 $555 = HEAP32[$554>>2]|0;
 $556 = (($555) + 16|0);
 $557 = Math_fround(HEAPF32[$556>>2]);
 $558 = (($555) + 20|0);
 $559 = Math_fround(HEAPF32[$558>>2]);
 $560 = (($555) + 24|0);
 $561 = Math_fround(HEAPF32[$560>>2]);
 $562 = (($descs) + 144|0);
 $563 = HEAP32[$562>>2]|0;
 $564 = (($563) + 16|0);
 $565 = Math_fround(HEAPF32[$564>>2]);
 $566 = (($563) + 20|0);
 $567 = Math_fround(HEAPF32[$566>>2]);
 $568 = (($563) + 24|0);
 $569 = Math_fround(HEAPF32[$568>>2]);
 $570 = (($descs) + 200|0);
 $571 = HEAP32[$570>>2]|0;
 $572 = (($571) + 16|0);
 $573 = Math_fround(HEAPF32[$572>>2]);
 $574 = (($571) + 20|0);
 $575 = Math_fround(HEAPF32[$574>>2]);
 $576 = (($571) + 24|0);
 $577 = Math_fround(HEAPF32[$576>>2]);
 $578 = (($c) + 1664|0);
 $579 = (($c) + 1792|0);
 $580 = (($descs) + 8|0);
 $581 = HEAP32[$580>>2]|0;
 $582 = (($descs) + 64|0);
 $583 = HEAP32[$582>>2]|0;
 $584 = (($descs) + 120|0);
 $585 = HEAP32[$584>>2]|0;
 $586 = (($descs) + 176|0);
 $587 = HEAP32[$586>>2]|0;
 $588 = ($585>>>0)<($587>>>0);
 $589 = $588 ? $587 : $585;
 $590 = ($583>>>0)<($589>>>0);
 $591 = $590 ? $589 : $583;
 $592 = ($581>>>0)<($591>>>0);
 $593 = $592 ? $591 : $581;
 $594 = ($593|0)==(0);
 if ($594) {
  STACKTOP = sp;return 1;
 }
 $595 = Math_imul($53, $numContactPoints4)|0;
 $596 = ($593*112)|0;
 $597 = (($596) + ($595))|0;
 $598 = (($workspace) + ($597)|0);
 $599 = $52 ? 7 : 8;
 $600 = $52 ? 13 : 14;
 $601 = ($numFrictionPerPoint|0)==(2);
 $602 = $601&1;
 $603 = (($1) + 4|0);
 $604 = (($1) + 8|0);
 $605 = (($1) + 12|0);
 $606 = (($4) + 4|0);
 $607 = (($4) + 8|0);
 $608 = (($4) + 12|0);
 $609 = (($3) + 4|0);
 $610 = (($3) + 8|0);
 $611 = (($3) + 12|0);
 $612 = (($6) + 4|0);
 $613 = (($6) + 8|0);
 $614 = (($6) + 12|0);
 $615 = (($8) + 4|0);
 $616 = (($8) + 8|0);
 $617 = (($8) + 12|0);
 $618 = (($7) + 4|0);
 $619 = (($7) + 8|0);
 $620 = (($7) + 12|0);
 $621 = (($10) + 4|0);
 $622 = (($10) + 8|0);
 $623 = (($10) + 12|0);
 $624 = (($9) + 4|0);
 $625 = (($9) + 8|0);
 $626 = (($9) + 12|0);
 $627 = (($12) + 4|0);
 $628 = (($12) + 8|0);
 $629 = (($12) + 12|0);
 $630 = (($11) + 4|0);
 $631 = (($11) + 8|0);
 $632 = (($11) + 12|0);
 $633 = (($tFallbackX) + 4|0);
 $634 = (($tFallbackX) + 8|0);
 $635 = (($tFallbackX) + 12|0);
 $636 = (($tFallbackX) + 16|0);
 $637 = (($tFallbackX) + 20|0);
 $638 = (($tFallbackX) + 24|0);
 $639 = (($tFallbackX) + 28|0);
 $640 = (($tFallbackY) + 4|0);
 $641 = (($tFallbackY) + 8|0);
 $642 = (($tFallbackY) + 12|0);
 $643 = (($tFallbackY) + 16|0);
 $644 = (($tFallbackY) + 20|0);
 $645 = (($tFallbackY) + 24|0);
 $646 = (($tFallbackY) + 28|0);
 $647 = (($tFallbackZ) + 4|0);
 $648 = (($tFallbackZ) + 8|0);
 $649 = (($tFallbackZ) + 12|0);
 $650 = (($tFallbackZ) + 16|0);
 $651 = (($tFallbackZ) + 20|0);
 $652 = (($tFallbackZ) + 24|0);
 $653 = (($tFallbackZ) + 28|0);
 $654 = (($14) + 4|0);
 $655 = (($14) + 8|0);
 $656 = (($14) + 12|0);
 $657 = (($15) + 4|0);
 $658 = (($15) + 8|0);
 $659 = (($15) + 12|0);
 $660 = (($18) + 4|0);
 $661 = (($18) + 8|0);
 $662 = (($18) + 12|0);
 $663 = ($numFrictionPerPoint|0)==(0);
 $664 = (($20) + 4|0);
 $665 = (($20) + 8|0);
 $666 = (($20) + 12|0);
 $667 = (($descs) + 172|0);
 $668 = (($descs) + 116|0);
 $669 = (($descs) + 60|0);
 $670 = (($descs) + 4|0);
 $671 = Math_imul($54, $numFrictionPerPoint)|0;
 $frictionIndex0$05748 = 0;$frictionIndex1$05747 = 0;$frictionIndex2$05746 = 0;$frictionIndex3$05745 = 0;$i$05743 = 0;$ptr$05749 = $workspace;$ptr2$05744 = $598;
 while(1) {
  $672 = HEAP32[$580>>2]|0;
  $673 = ($i$05743>>>0)>=($672>>>0);
  $674 = HEAP32[$582>>2]|0;
  $675 = ($i$05743>>>0)>=($674>>>0);
  $676 = HEAP32[$584>>2]|0;
  $677 = ($i$05743>>>0)>=($676>>>0);
  $678 = HEAP32[$586>>2]|0;
  $679 = ($i$05743>>>0)>=($678>>>0);
  if ($673) {
   $689 = $frictionIndex0$05748;
  } else {
   $680 = HEAP32[$670>>2]|0;
   $681 = (($680) + ($i$05743))|0;
   $689 = $681;
  }
  if ($675) {
   $692 = $frictionIndex1$05747;
  } else {
   $682 = HEAP32[$669>>2]|0;
   $683 = (($682) + ($i$05743))|0;
   $692 = $683;
  }
  if ($677) {
   $695 = $frictionIndex2$05746;
  } else {
   $684 = HEAP32[$668>>2]|0;
   $685 = (($684) + ($i$05743))|0;
   $695 = $685;
  }
  if ($679) {
   $698 = $frictionIndex3$05745;
  } else {
   $686 = HEAP32[$667>>2]|0;
   $687 = (($686) + ($i$05743))|0;
   $698 = $687;
  }
  if ($673) {
   $720 = 0;
  } else {
   $688 = ((($c) + ($689<<2)|0) + 1408|0);
   $690 = HEAP32[$688>>2]|0;
   $720 = $690;
  }
  if ($675) {
   $717 = 0;
  } else {
   $691 = ((($c) + ($692<<2)|0) + 1408|0);
   $693 = HEAP32[$691>>2]|0;
   $717 = $693;
  }
  if ($677) {
   $713 = 0;
  } else {
   $694 = ((($c) + ($695<<2)|0) + 1408|0);
   $696 = HEAP32[$694>>2]|0;
   $713 = $696;
  }
  if ($679) {
   $714 = 0;
  } else {
   $697 = ((($c) + ($698<<2)|0) + 1408|0);
   $699 = HEAP32[$697>>2]|0;
   $714 = $699;
  }
  if ($673) {
   $730 = 0;
  } else {
   $700 = ((($c) + (($689*20)|0)|0) + 784|0);
   $701 = HEAP16[$700>>1]|0;
   $702 = $701&65535;
   $730 = $702;
  }
  if ($675) {
   $727 = 0;
  } else {
   $703 = ((($c) + (($692*20)|0)|0) + 784|0);
   $704 = HEAP16[$703>>1]|0;
   $705 = $704&65535;
   $727 = $705;
  }
  if ($677) {
   $723 = 0;
  } else {
   $706 = ((($c) + (($695*20)|0)|0) + 784|0);
   $707 = HEAP16[$706>>1]|0;
   $708 = $707&65535;
   $723 = $708;
  }
  if ($679) {
   $724 = 0;
  } else {
   $709 = ((($c) + (($698*20)|0)|0) + 784|0);
   $710 = HEAP16[$709>>1]|0;
   $711 = $710&65535;
   $724 = $711;
  }
  $712 = ($713>>>0)<($714>>>0);
  $715 = $712 ? $714 : $713;
  $716 = ($717>>>0)<($715>>>0);
  $718 = $716 ? $715 : $717;
  $719 = ($720>>>0)<($718>>>0);
  $721 = $719 ? $718 : $720;
  $722 = ($723>>>0)<($724>>>0);
  $725 = $722 ? $724 : $723;
  $726 = ($727>>>0)<($725>>>0);
  $728 = $726 ? $725 : $727;
  $729 = ($730>>>0)<($728>>>0);
  $731 = $729 ? $728 : $730;
  $732 = ((($c) + ($689<<2)|0) + 1536|0);
  $733 = HEAP32[$732>>2]|0;
  $734 = ((($c) + ($692<<2)|0) + 1536|0);
  $735 = HEAP32[$734>>2]|0;
  $736 = ((($c) + ($695<<2)|0) + 1536|0);
  $737 = HEAP32[$736>>2]|0;
  $738 = ((($c) + ($698<<2)|0) + 1536|0);
  $739 = HEAP32[$738>>2]|0;
  $740 = (($c) + (($733*12)|0)|0);
  $741 = HEAP16[$740>>1]|0;
  $742 = $741&65535;
  $743 = (($c) + (($735*12)|0)|0);
  $744 = HEAP16[$743>>1]|0;
  $745 = $744&65535;
  $746 = (($c) + (($737*12)|0)|0);
  $747 = HEAP16[$746>>1]|0;
  $748 = $747&65535;
  $749 = (($c) + (($739*12)|0)|0);
  $750 = HEAP16[$749>>1]|0;
  $751 = $750&65535;
  $752 = ((($threadContext) + ($742<<6)|0) + 444|0);
  $753 = Math_fround(HEAPF32[$752>>2]);
  $754 = ((($threadContext) + ($745<<6)|0) + 444|0);
  $755 = Math_fround(HEAPF32[$754>>2]);
  $756 = ((($threadContext) + ($748<<6)|0) + 444|0);
  $757 = Math_fround(HEAPF32[$756>>2]);
  $758 = ((($threadContext) + ($751<<6)|0) + 444|0);
  $759 = Math_fround(HEAPF32[$758>>2]);
  $760 = ((($threadContext) + ($742<<6)|0) + 428|0);
  $761 = Math_fround(HEAPF32[$760>>2]);
  $762 = ((($threadContext) + ($745<<6)|0) + 428|0);
  $763 = Math_fround(HEAPF32[$762>>2]);
  $764 = ((($threadContext) + ($748<<6)|0) + 428|0);
  $765 = Math_fround(HEAPF32[$764>>2]);
  $766 = ((($threadContext) + ($751<<6)|0) + 428|0);
  $767 = Math_fround(HEAPF32[$766>>2]);
  $768 = $ptr2$05744;
  $769 = $ptr$05749;
  $770 = (($768) - ($769))|0;
  $771 = $770&65535;
  $772 = (($ptr$05749) + 2|0);
  HEAP16[$772>>1] = $771;
  $773 = (($ptr$05749) + 112|0);
  $774 = $721 << 4;
  $775 = (($774) + 64)|0;
  $776 = (($ptr2$05744) + ($775)|0);
  $777 = $720&255;
  $778 = (($ptr$05749) + 4|0);
  HEAP8[$778>>0] = $777;
  $779 = $717&255;
  $780 = (($ptr$05749) + 5|0);
  HEAP8[$780>>0] = $779;
  $781 = $713&255;
  $782 = (($ptr$05749) + 6|0);
  HEAP8[$782>>0] = $781;
  $783 = $714&255;
  $784 = (($ptr$05749) + 7|0);
  HEAP8[$784>>0] = $783;
  $785 = $721&255;
  $786 = (($ptr$05749) + 1|0);
  HEAP8[$786>>0] = $785;
  $787 = (($ptr$05749) + 80|0);
  HEAPF32[$787>>2] = $293;
  $788 = (($ptr$05749) + 84|0);
  HEAPF32[$788>>2] = $294;
  $789 = (($ptr$05749) + 88|0);
  HEAPF32[$789>>2] = $295;
  $790 = (($ptr$05749) + 92|0);
  HEAPF32[$790>>2] = $296;
  $791 = (($ptr$05749) + 96|0);
  HEAPF32[$791>>2] = $298;
  $792 = (($ptr$05749) + 100|0);
  HEAPF32[$792>>2] = $300;
  $793 = (($ptr$05749) + 104|0);
  HEAPF32[$793>>2] = $302;
  $794 = (($ptr$05749) + 108|0);
  HEAPF32[$794>>2] = $304;
  $795 = (($ptr$05749) + 16|0);
  HEAPF32[$795>>2] = $753;
  $796 = (($ptr$05749) + 20|0);
  HEAPF32[$796>>2] = $755;
  $797 = (($ptr$05749) + 24|0);
  HEAPF32[$797>>2] = $757;
  $798 = (($ptr$05749) + 28|0);
  HEAPF32[$798>>2] = $759;
  $799 = (($ptr$05749) + 8|0);
  HEAP8[$799>>0] = $26;
  $800 = (($ptr$05749) + 9|0);
  HEAP8[$800>>0] = $33;
  $801 = (($ptr$05749) + 10|0);
  HEAP8[$801>>0] = $40;
  $802 = (($ptr$05749) + 11|0);
  HEAP8[$802>>0] = $47;
  HEAP8[$ptr$05749>>0] = $599;
  $803 = (($ptr2$05744) + 32|0);
  HEAPF32[$803>>2] = $293;
  $804 = (($ptr2$05744) + 36|0);
  HEAPF32[$804>>2] = $294;
  $805 = (($ptr2$05744) + 40|0);
  HEAPF32[$805>>2] = $295;
  $806 = (($ptr2$05744) + 44|0);
  HEAPF32[$806>>2] = $296;
  $807 = (($ptr2$05744) + 48|0);
  HEAPF32[$807>>2] = $298;
  $808 = (($ptr2$05744) + 52|0);
  HEAPF32[$808>>2] = $300;
  $809 = (($ptr2$05744) + 56|0);
  HEAPF32[$809>>2] = $302;
  $810 = (($ptr2$05744) + 60|0);
  HEAPF32[$810>>2] = $304;
  $811 = $730&255;
  $812 = (($ptr2$05744) + 7|0);
  HEAP8[$812>>0] = $811;
  $813 = $727&255;
  $814 = (($ptr2$05744) + 8|0);
  HEAP8[$814>>0] = $813;
  $815 = $723&255;
  $816 = (($ptr2$05744) + 9|0);
  HEAP8[$816>>0] = $815;
  $817 = $724&255;
  $818 = (($ptr2$05744) + 10|0);
  HEAP8[$818>>0] = $817;
  $819 = (($ptr2$05744) + 1|0);
  HEAP8[$819>>0] = $785;
  $820 = (($ptr2$05744) + 3|0);
  HEAP8[$820>>0] = $777;
  $821 = (($ptr2$05744) + 4|0);
  HEAP8[$821>>0] = $779;
  $822 = (($ptr2$05744) + 5|0);
  HEAP8[$822>>0] = $781;
  $823 = (($ptr2$05744) + 6|0);
  HEAP8[$823>>0] = $783;
  HEAP8[$ptr2$05744>>0] = $600;
  $824 = (($ptr2$05744) + 16|0);
  HEAPF32[$824>>2] = $761;
  $825 = (($ptr2$05744) + 20|0);
  HEAPF32[$825>>2] = $763;
  $826 = (($ptr2$05744) + 24|0);
  HEAPF32[$826>>2] = $765;
  $827 = (($ptr2$05744) + 28|0);
  HEAPF32[$827>>2] = $767;
  $828 = (($ptr2$05744) + 12|0);
  HEAP32[$828>>2] = $602;
  $829 = $731&255;
  $830 = (($ptr2$05744) + 2|0);
  HEAP8[$830>>0] = $829;
  $831 = ((($threadContext) + ($742<<6)|0) + 384|0);
  $832 = Math_fround(HEAPF32[$831>>2]);
  $833 = (($831) + 4|0);
  $834 = Math_fround(HEAPF32[$833>>2]);
  $835 = (($831) + 8|0);
  $836 = Math_fround(HEAPF32[$835>>2]);
  $837 = ((($threadContext) + ($745<<6)|0) + 384|0);
  $838 = Math_fround(HEAPF32[$837>>2]);
  $839 = (($837) + 4|0);
  $840 = Math_fround(HEAPF32[$839>>2]);
  $841 = (($837) + 8|0);
  $842 = Math_fround(HEAPF32[$841>>2]);
  $843 = ((($threadContext) + ($748<<6)|0) + 384|0);
  $844 = Math_fround(HEAPF32[$843>>2]);
  $845 = (($843) + 4|0);
  $846 = Math_fround(HEAPF32[$845>>2]);
  $847 = (($843) + 8|0);
  $848 = Math_fround(HEAPF32[$847>>2]);
  $849 = ((($threadContext) + ($751<<6)|0) + 384|0);
  $850 = Math_fround(HEAPF32[$849>>2]);
  $851 = (($849) + 4|0);
  $852 = Math_fround(HEAPF32[$851>>2]);
  $853 = (($849) + 8|0);
  $854 = Math_fround(HEAPF32[$853>>2]);
  $855 = (($ptr$05749) + 32|0);
  HEAPF32[$855>>2] = $832;
  $856 = (($ptr$05749) + 36|0);
  HEAPF32[$856>>2] = $838;
  $857 = (($ptr$05749) + 40|0);
  HEAPF32[$857>>2] = $844;
  $858 = (($ptr$05749) + 44|0);
  HEAPF32[$858>>2] = $850;
  $859 = (($ptr$05749) + 48|0);
  HEAPF32[$859>>2] = $834;
  $860 = (($ptr$05749) + 52|0);
  HEAPF32[$860>>2] = $840;
  $861 = (($ptr$05749) + 56|0);
  HEAPF32[$861>>2] = $846;
  $862 = (($ptr$05749) + 60|0);
  HEAPF32[$862>>2] = $852;
  $863 = (($ptr$05749) + 64|0);
  HEAPF32[$863>>2] = $836;
  $864 = (($ptr$05749) + 68|0);
  HEAPF32[$864>>2] = $842;
  $865 = (($ptr$05749) + 72|0);
  HEAPF32[$865>>2] = $848;
  $866 = (($ptr$05749) + 76|0);
  HEAPF32[$866>>2] = $854;
  $867 = Math_fround($832 * $832);
  $868 = Math_fround($838 * $838);
  $869 = Math_fround($844 * $844);
  $870 = Math_fround($850 * $850);
  $871 = Math_fround($834 * $834);
  $872 = Math_fround($840 * $840);
  $873 = Math_fround($846 * $846);
  $874 = Math_fround($852 * $852);
  $875 = Math_fround($867 + $871);
  $876 = Math_fround($868 + $872);
  $877 = Math_fround($869 + $873);
  $878 = Math_fround($870 + $874);
  $879 = Math_fround($836 * $836);
  $880 = Math_fround($842 * $842);
  $881 = Math_fround($848 * $848);
  $882 = Math_fround($854 * $854);
  $883 = Math_fround($879 + $875);
  $884 = Math_fround($880 + $876);
  $885 = Math_fround($881 + $877);
  $886 = Math_fround($882 + $878);
  $887 = Math_fround($163 * $832);
  $888 = Math_fround($170 * $838);
  $889 = Math_fround($177 * $844);
  $890 = Math_fround($184 * $850);
  $891 = Math_fround($165 * $834);
  $892 = Math_fround($172 * $840);
  $893 = Math_fround($179 * $846);
  $894 = Math_fround($186 * $852);
  $895 = Math_fround($887 + $891);
  $896 = Math_fround($888 + $892);
  $897 = Math_fround($889 + $893);
  $898 = Math_fround($890 + $894);
  $899 = Math_fround($167 * $836);
  $900 = Math_fround($174 * $842);
  $901 = Math_fround($181 * $848);
  $902 = Math_fround($188 * $854);
  $903 = Math_fround($899 + $895);
  $904 = Math_fround($900 + $896);
  $905 = Math_fround($901 + $897);
  $906 = Math_fround($902 + $898);
  $907 = Math_fround($191 * $832);
  $908 = Math_fround($198 * $838);
  $909 = Math_fround($205 * $844);
  $910 = Math_fround($212 * $850);
  $911 = Math_fround($193 * $834);
  $912 = Math_fround($200 * $840);
  $913 = Math_fround($207 * $846);
  $914 = Math_fround($214 * $852);
  $915 = Math_fround($907 + $911);
  $916 = Math_fround($908 + $912);
  $917 = Math_fround($909 + $913);
  $918 = Math_fround($910 + $914);
  $919 = Math_fround($195 * $836);
  $920 = Math_fround($202 * $842);
  $921 = Math_fround($209 * $848);
  $922 = Math_fround($216 * $854);
  $923 = Math_fround($919 + $915);
  $924 = Math_fround($920 + $916);
  $925 = Math_fround($921 + $917);
  $926 = Math_fround($922 + $918);
  $927 = Math_fround($293 * $883);
  $928 = Math_fround($294 * $884);
  $929 = Math_fround($295 * $885);
  $930 = Math_fround($296 * $886);
  $931 = Math_fround($883 * $298);
  $932 = Math_fround($884 * $300);
  $933 = Math_fround($885 * $302);
  $934 = Math_fround($886 * $304);
  $935 = Math_fround(-$832);
  $936 = Math_fround(-$838);
  $937 = Math_fround(-$844);
  $938 = Math_fround(-$850);
  $939 = $832 > $935;
  $$$i$i = $939 ? $832 : $935;
  $940 = $838 > $936;
  $941 = $940 ? $838 : $936;
  $942 = $844 > $937;
  $$1$i$i = $942 ? $844 : $937;
  $943 = $850 > $938;
  $944 = $943 ? $850 : $938;
  $945 = $$$i$i < Math_fround(0.707106769084930419921);
  $946 = $941 < Math_fround(0.707106769084930419921);
  $947 = $$1$i$i < Math_fround(0.707106769084930419921);
  $948 = $944 < Math_fround(0.707106769084930419921);
  $949 = Math_fround(-$834);
  $950 = Math_fround(-$840);
  $951 = Math_fround(-$846);
  $952 = Math_fround(-$852);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
  HEAPF32[$1>>2] = $949;
  HEAPF32[$603>>2] = $950;
  HEAPF32[$604>>2] = $951;
  HEAPF32[$605>>2] = $952;
  $b$a$i883 = $945 ? $2 : $1;
  $953 = Math_fround(HEAPF32[$b$a$i883>>2]);
  $a$pn4$i885 = $946 ? $2 : $1;
  $$in1$i886 = (($a$pn4$i885) + 4|0);
  $954 = Math_fround(HEAPF32[$$in1$i886>>2]);
  $b$a7$i887 = $947 ? $2 : $1;
  $$in2$i888 = (($b$a7$i887) + 8|0);
  $955 = Math_fround(HEAPF32[$$in2$i888>>2]);
  $a$pn6$i889 = $948 ? $2 : $1;
  $$in3$i890 = (($a$pn6$i889) + 12|0);
  $956 = Math_fround(HEAPF32[$$in3$i890>>2]);
  $957 = Math_fround(-$836);
  $958 = Math_fround(-$842);
  $959 = Math_fround(-$848);
  $960 = Math_fround(-$854);
  HEAPF32[$4>>2] = $957;
  HEAPF32[$606>>2] = $958;
  HEAPF32[$607>>2] = $959;
  HEAPF32[$608>>2] = $960;
  HEAPF32[$3>>2] = $832;
  HEAPF32[$609>>2] = $838;
  HEAPF32[$610>>2] = $844;
  HEAPF32[$611>>2] = $850;
  $b$a$i867 = $945 ? $4 : $3;
  $961 = Math_fround(HEAPF32[$b$a$i867>>2]);
  $a$pn4$i869 = $946 ? $4 : $3;
  $$in1$i870 = (($a$pn4$i869) + 4|0);
  $962 = Math_fround(HEAPF32[$$in1$i870>>2]);
  $b$a7$i871 = $947 ? $4 : $3;
  $$in2$i872 = (($b$a7$i871) + 8|0);
  $963 = Math_fround(HEAPF32[$$in2$i872>>2]);
  $a$pn6$i873 = $948 ? $4 : $3;
  $$in3$i874 = (($a$pn6$i873) + 12|0);
  $964 = Math_fround(HEAPF32[$$in3$i874>>2]);
  HEAPF32[$6>>2] = $834;
  HEAPF32[$612>>2] = $840;
  HEAPF32[$613>>2] = $846;
  HEAPF32[$614>>2] = $852;
  $b$a$i853 = $945 ? $6 : $5;
  ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
  $965 = Math_fround(HEAPF32[$b$a$i853>>2]);
  $a$pn4$i855 = $946 ? $6 : $5;
  $$in1$i856 = (($a$pn4$i855) + 4|0);
  $966 = Math_fround(HEAPF32[$$in1$i856>>2]);
  $b$a7$i857 = $947 ? $6 : $5;
  $$in2$i858 = (($b$a7$i857) + 8|0);
  $967 = Math_fround(HEAPF32[$$in2$i858>>2]);
  $a$pn6$i859 = $948 ? $6 : $5;
  $$in3$i860 = (($a$pn6$i859) + 12|0);
  $968 = Math_fround(HEAPF32[$$in3$i860>>2]);
  $969 = Math_fround($265 * $832);
  $970 = Math_fround($266 * $838);
  $971 = Math_fround($267 * $844);
  $972 = Math_fround($268 * $850);
  $973 = Math_fround($269 * $834);
  $974 = Math_fround($270 * $840);
  $975 = Math_fround($271 * $846);
  $976 = Math_fround($272 * $852);
  $977 = Math_fround($969 + $973);
  $978 = Math_fround($970 + $974);
  $979 = Math_fround($971 + $975);
  $980 = Math_fround($972 + $976);
  $981 = Math_fround($273 * $836);
  $982 = Math_fround($274 * $842);
  $983 = Math_fround($275 * $848);
  $984 = Math_fround($276 * $854);
  $985 = Math_fround($981 + $977);
  $986 = Math_fround($982 + $978);
  $987 = Math_fround($983 + $979);
  $988 = Math_fround($984 + $980);
  $989 = Math_fround($832 * $985);
  $990 = Math_fround($838 * $986);
  $991 = Math_fround($844 * $987);
  $992 = Math_fround($850 * $988);
  $993 = Math_fround($265 - $989);
  $994 = Math_fround($266 - $990);
  $995 = Math_fround($267 - $991);
  $996 = Math_fround($268 - $992);
  $997 = Math_fround($834 * $985);
  $998 = Math_fround($840 * $986);
  $999 = Math_fround($846 * $987);
  $1000 = Math_fround($852 * $988);
  $1001 = Math_fround($269 - $997);
  $1002 = Math_fround($270 - $998);
  $1003 = Math_fround($271 - $999);
  $1004 = Math_fround($272 - $1000);
  $1005 = Math_fround($836 * $985);
  $1006 = Math_fround($842 * $986);
  $1007 = Math_fround($848 * $987);
  $1008 = Math_fround($854 * $988);
  $1009 = Math_fround($273 - $1005);
  $1010 = Math_fround($274 - $1006);
  $1011 = Math_fround($275 - $1007);
  $1012 = Math_fround($276 - $1008);
  $1013 = Math_fround($1009 * $1009);
  $1014 = Math_fround($1010 * $1010);
  $1015 = Math_fround($1011 * $1011);
  $1016 = Math_fround($1012 * $1012);
  $1017 = Math_fround($1001 * $1001);
  $1018 = Math_fround($1002 * $1002);
  $1019 = Math_fround($1003 * $1003);
  $1020 = Math_fround($1004 * $1004);
  $1021 = Math_fround($1017 + $1013);
  $1022 = Math_fround($1018 + $1014);
  $1023 = Math_fround($1019 + $1015);
  $1024 = Math_fround($1020 + $1016);
  $1025 = Math_fround($993 * $993);
  $1026 = Math_fround($994 * $994);
  $1027 = Math_fround($995 * $995);
  $1028 = Math_fround($996 * $996);
  $1029 = Math_fround($1025 + $1021);
  $1030 = Math_fround($1026 + $1022);
  $1031 = Math_fround($1027 + $1023);
  $1032 = Math_fround($1028 + $1024);
  $1033 = $1029 > Math_fround(0.100000001490116119385);
  $1034 = $1030 > Math_fround(0.100000001490116119385);
  $1035 = $1031 > Math_fround(0.100000001490116119385);
  $1036 = $1032 > Math_fround(0.100000001490116119385);
  HEAPF32[$8>>2] = $993;
  HEAPF32[$615>>2] = $994;
  HEAPF32[$616>>2] = $995;
  HEAPF32[$617>>2] = $996;
  HEAPF32[$7>>2] = $953;
  HEAPF32[$618>>2] = $954;
  HEAPF32[$619>>2] = $955;
  HEAPF32[$620>>2] = $956;
  $b$a$i785 = $1033 ? $8 : $7;
  $1037 = Math_fround(HEAPF32[$b$a$i785>>2]);
  $a$pn4$i787 = $1034 ? $8 : $7;
  $$in1$i788 = (($a$pn4$i787) + 4|0);
  $1038 = Math_fround(HEAPF32[$$in1$i788>>2]);
  $b$a7$i789 = $1035 ? $8 : $7;
  $$in2$i790 = (($b$a7$i789) + 8|0);
  $1039 = Math_fround(HEAPF32[$$in2$i790>>2]);
  $a$pn6$i791 = $1036 ? $8 : $7;
  $$in3$i792 = (($a$pn6$i791) + 12|0);
  $1040 = Math_fround(HEAPF32[$$in3$i792>>2]);
  HEAPF32[$10>>2] = $1001;
  HEAPF32[$621>>2] = $1002;
  HEAPF32[$622>>2] = $1003;
  HEAPF32[$623>>2] = $1004;
  HEAPF32[$9>>2] = $961;
  HEAPF32[$624>>2] = $962;
  HEAPF32[$625>>2] = $963;
  HEAPF32[$626>>2] = $964;
  $b$a$i771 = $1033 ? $10 : $9;
  $1041 = Math_fround(HEAPF32[$b$a$i771>>2]);
  $a$pn4$i773 = $1034 ? $10 : $9;
  $$in1$i774 = (($a$pn4$i773) + 4|0);
  $1042 = Math_fround(HEAPF32[$$in1$i774>>2]);
  $b$a7$i775 = $1035 ? $10 : $9;
  $$in2$i776 = (($b$a7$i775) + 8|0);
  $1043 = Math_fround(HEAPF32[$$in2$i776>>2]);
  $a$pn6$i777 = $1036 ? $10 : $9;
  $$in3$i778 = (($a$pn6$i777) + 12|0);
  $1044 = Math_fround(HEAPF32[$$in3$i778>>2]);
  HEAPF32[$12>>2] = $1009;
  HEAPF32[$627>>2] = $1010;
  HEAPF32[$628>>2] = $1011;
  HEAPF32[$629>>2] = $1012;
  HEAPF32[$11>>2] = $965;
  HEAPF32[$630>>2] = $966;
  HEAPF32[$631>>2] = $967;
  HEAPF32[$632>>2] = $968;
  $b$a$i757 = $1033 ? $12 : $11;
  $1045 = Math_fround(HEAPF32[$b$a$i757>>2]);
  $a$pn4$i759 = $1034 ? $12 : $11;
  $$in1$i760 = (($a$pn4$i759) + 4|0);
  $1046 = Math_fround(HEAPF32[$$in1$i760>>2]);
  $b$a7$i761 = $1035 ? $12 : $11;
  $$in2$i762 = (($b$a7$i761) + 8|0);
  $1047 = Math_fround(HEAPF32[$$in2$i762>>2]);
  $a$pn6$i763 = $1036 ? $12 : $11;
  $$in3$i764 = (($a$pn6$i763) + 12|0);
  $1048 = Math_fround(HEAPF32[$$in3$i764>>2]);
  $1049 = Math_fround($1045 * $1045);
  $1050 = Math_fround($1046 * $1046);
  $1051 = Math_fround($1047 * $1047);
  $1052 = Math_fround($1048 * $1048);
  $1053 = Math_fround($1041 * $1041);
  $1054 = Math_fround($1042 * $1042);
  $1055 = Math_fround($1043 * $1043);
  $1056 = Math_fround($1044 * $1044);
  $1057 = Math_fround($1053 + $1049);
  $1058 = Math_fround($1054 + $1050);
  $1059 = Math_fround($1055 + $1051);
  $1060 = Math_fround($1056 + $1052);
  $1061 = Math_fround($1037 * $1037);
  $1062 = Math_fround($1038 * $1038);
  $1063 = Math_fround($1039 * $1039);
  $1064 = Math_fround($1040 * $1040);
  $1065 = Math_fround($1061 + $1057);
  $1066 = Math_fround($1062 + $1058);
  $1067 = Math_fround($1063 + $1059);
  $1068 = Math_fround($1064 + $1060);
  $1069 = (Math_fround(Math_sqrt((Math_fround($1065)))));
  $1070 = Math_fround(Math_fround(1.0) / $1069);
  $1071 = (Math_fround(Math_sqrt((Math_fround($1066)))));
  $1072 = Math_fround(Math_fround(1.0) / $1071);
  $1073 = (Math_fround(Math_sqrt((Math_fround($1067)))));
  $1074 = Math_fround(Math_fround(1.0) / $1073);
  $1075 = (Math_fround(Math_sqrt((Math_fround($1068)))));
  $1076 = Math_fround(Math_fround(1.0) / $1075);
  $1077 = Math_fround($1037 * $1070);
  $1078 = Math_fround($1038 * $1072);
  $1079 = Math_fround($1039 * $1074);
  $1080 = Math_fround($1040 * $1076);
  $1081 = Math_fround($1041 * $1070);
  $1082 = Math_fround($1042 * $1072);
  $1083 = Math_fround($1043 * $1074);
  $1084 = Math_fround($1044 * $1076);
  $1085 = Math_fround($1045 * $1070);
  $1086 = Math_fround($1046 * $1072);
  $1087 = Math_fround($1047 * $1074);
  $1088 = Math_fround($1048 * $1076);
  $1089 = Math_fround($834 * $1085);
  $1090 = Math_fround($840 * $1086);
  $1091 = Math_fround($846 * $1087);
  $1092 = Math_fround($852 * $1088);
  $1093 = Math_fround($836 * $1081);
  $1094 = Math_fround($842 * $1082);
  $1095 = Math_fround($848 * $1083);
  $1096 = Math_fround($854 * $1084);
  $1097 = Math_fround($1089 - $1093);
  $1098 = Math_fround($1090 - $1094);
  $1099 = Math_fround($1091 - $1095);
  $1100 = Math_fround($1092 - $1096);
  $1101 = Math_fround($836 * $1077);
  $1102 = Math_fround($842 * $1078);
  $1103 = Math_fround($848 * $1079);
  $1104 = Math_fround($854 * $1080);
  $1105 = Math_fround($832 * $1085);
  $1106 = Math_fround($838 * $1086);
  $1107 = Math_fround($844 * $1087);
  $1108 = Math_fround($850 * $1088);
  $1109 = Math_fround($1101 - $1105);
  $1110 = Math_fround($1102 - $1106);
  $1111 = Math_fround($1103 - $1107);
  $1112 = Math_fround($1104 - $1108);
  $1113 = Math_fround($832 * $1081);
  $1114 = Math_fround($838 * $1082);
  $1115 = Math_fround($844 * $1083);
  $1116 = Math_fround($850 * $1084);
  $1117 = Math_fround($834 * $1077);
  $1118 = Math_fround($840 * $1078);
  $1119 = Math_fround($846 * $1079);
  $1120 = Math_fround($852 * $1080);
  $1121 = Math_fround($1113 - $1117);
  $1122 = Math_fround($1114 - $1118);
  $1123 = Math_fround($1115 - $1119);
  $1124 = Math_fround($1116 - $1120);
  HEAPF32[$tFallbackX>>2] = $1077;
  HEAPF32[$633>>2] = $1078;
  HEAPF32[$634>>2] = $1079;
  HEAPF32[$635>>2] = $1080;
  HEAPF32[$636>>2] = $1097;
  HEAPF32[$637>>2] = $1098;
  HEAPF32[$638>>2] = $1099;
  HEAPF32[$639>>2] = $1100;
  HEAPF32[$tFallbackY>>2] = $1081;
  HEAPF32[$640>>2] = $1082;
  HEAPF32[$641>>2] = $1083;
  HEAPF32[$642>>2] = $1084;
  HEAPF32[$643>>2] = $1109;
  HEAPF32[$644>>2] = $1110;
  HEAPF32[$645>>2] = $1111;
  HEAPF32[$646>>2] = $1112;
  HEAPF32[$tFallbackZ>>2] = $1085;
  HEAPF32[$647>>2] = $1086;
  HEAPF32[$648>>2] = $1087;
  HEAPF32[$649>>2] = $1088;
  HEAPF32[$650>>2] = $1121;
  HEAPF32[$651>>2] = $1122;
  HEAPF32[$652>>2] = $1123;
  HEAPF32[$653>>2] = $1124;
  $1125 = $673&1;
  $1126 = $675&1;
  $1127 = $1126 << 1;
  $1128 = $1127 | $1125;
  $1129 = $677&1;
  $1130 = $1129 << 2;
  $1131 = $1128 | $1130;
  $1132 = $679&1;
  $1133 = $1132 << 3;
  $1134 = $1131 | $1133;
  $1135 = ($733|0)==(65535);
  L42: do {
   if ($1135) {
    $newPatch$0$lcssa$i$i689 = 65535;
   } else {
    $newPatch$01$i$i687 = $733;
    while(1) {
     $1136 = ((($c) + (($newPatch$01$i$i687*12)|0)|0) + 2|0);
     $1137 = HEAP16[$1136>>1]|0;
     $1138 = ($1137<<16>>16)==(0);
     if (!($1138)) {
      $newPatch$0$lcssa$i$i689 = $newPatch$01$i$i687;
      break L42;
     }
     $1139 = ((($c) + (($newPatch$01$i$i687*12)|0)|0) + 4|0);
     $1140 = HEAP16[$1139>>1]|0;
     $1141 = $1140&65535;
     $1142 = ($1140<<16>>16)==(-1);
     if ($1142) {
      $newPatch$0$lcssa$i$i689 = $1141;
      break;
     } else {
      $newPatch$01$i$i687 = $1141;
     }
    }
   }
  } while(0);
  $1143 = ($735|0)==(65535);
  L47: do {
   if ($1143) {
    $newPatch$0$lcssa$i$i685 = 65535;
   } else {
    $newPatch$01$i$i683 = $735;
    while(1) {
     $1144 = ((($c) + (($newPatch$01$i$i683*12)|0)|0) + 2|0);
     $1145 = HEAP16[$1144>>1]|0;
     $1146 = ($1145<<16>>16)==(0);
     if (!($1146)) {
      $newPatch$0$lcssa$i$i685 = $newPatch$01$i$i683;
      break L47;
     }
     $1147 = ((($c) + (($newPatch$01$i$i683*12)|0)|0) + 4|0);
     $1148 = HEAP16[$1147>>1]|0;
     $1149 = $1148&65535;
     $1150 = ($1148<<16>>16)==(-1);
     if ($1150) {
      $newPatch$0$lcssa$i$i685 = $1149;
      break;
     } else {
      $newPatch$01$i$i683 = $1149;
     }
    }
   }
  } while(0);
  $1151 = ($737|0)==(65535);
  L52: do {
   if ($1151) {
    $newPatch$0$lcssa$i$i681 = 65535;
   } else {
    $newPatch$01$i$i679 = $737;
    while(1) {
     $1152 = ((($c) + (($newPatch$01$i$i679*12)|0)|0) + 2|0);
     $1153 = HEAP16[$1152>>1]|0;
     $1154 = ($1153<<16>>16)==(0);
     if (!($1154)) {
      $newPatch$0$lcssa$i$i681 = $newPatch$01$i$i679;
      break L52;
     }
     $1155 = ((($c) + (($newPatch$01$i$i679*12)|0)|0) + 4|0);
     $1156 = HEAP16[$1155>>1]|0;
     $1157 = $1156&65535;
     $1158 = ($1156<<16>>16)==(-1);
     if ($1158) {
      $newPatch$0$lcssa$i$i681 = $1157;
      break;
     } else {
      $newPatch$01$i$i679 = $1157;
     }
    }
   }
  } while(0);
  $1159 = ($739|0)==(65535);
  L57: do {
   if ($1159) {
    $newPatch$0$lcssa$i$i = 65535;
   } else {
    $newPatch$01$i$i = $739;
    while(1) {
     $1160 = ((($c) + (($newPatch$01$i$i*12)|0)|0) + 2|0);
     $1161 = HEAP16[$1160>>1]|0;
     $1162 = ($1161<<16>>16)==(0);
     if (!($1162)) {
      $newPatch$0$lcssa$i$i = $newPatch$01$i$i;
      break L57;
     }
     $1163 = ((($c) + (($newPatch$01$i$i*12)|0)|0) + 4|0);
     $1164 = HEAP16[$1163>>1]|0;
     $1165 = $1164&65535;
     $1166 = ($1164<<16>>16)==(-1);
     if ($1166) {
      $newPatch$0$lcssa$i$i = $1165;
      break;
     } else {
      $newPatch$01$i$i = $1165;
     }
    }
   }
  } while(0);
  $1167 = ($newPatch$0$lcssa$i$i689|0)==(65535);
  L62: do {
   if ($1167) {
    $newContact$0$lcssa$i676 = 1;$newPatch$0$lcssa$i677 = 65535;
   } else {
    $newContact$02$i674 = 1;$newPatch$01$i675 = $newPatch$0$lcssa$i$i689;
    while(1) {
     $1168 = ((($c) + (($newPatch$01$i675*12)|0)|0) + 2|0);
     $1169 = HEAP16[$1168>>1]|0;
     $1170 = $1169&65535;
     $1171 = ($newContact$02$i674|0)==($1170|0);
     if (!($1171)) {
      $newContact$0$lcssa$i676 = $newContact$02$i674;$newPatch$0$lcssa$i677 = $newPatch$01$i675;
      break L62;
     }
     $1172 = ((($c) + (($newPatch$01$i675*12)|0)|0) + 4|0);
     $1173 = HEAP16[$1172>>1]|0;
     $1174 = $1173&65535;
     $1175 = ($1173<<16>>16)==(-1);
     if ($1175) {
      $newContact$0$lcssa$i676 = 0;$newPatch$0$lcssa$i677 = $1174;
      break;
     } else {
      $newContact$02$i674 = 0;$newPatch$01$i675 = $1174;
     }
    }
   }
  } while(0);
  $1176 = ($newPatch$0$lcssa$i$i685|0)==(65535);
  L67: do {
   if ($1176) {
    $newContact$0$lcssa$i670 = 1;$newPatch$0$lcssa$i671 = 65535;
   } else {
    $newContact$02$i668 = 1;$newPatch$01$i669 = $newPatch$0$lcssa$i$i685;
    while(1) {
     $1177 = ((($c) + (($newPatch$01$i669*12)|0)|0) + 2|0);
     $1178 = HEAP16[$1177>>1]|0;
     $1179 = $1178&65535;
     $1180 = ($newContact$02$i668|0)==($1179|0);
     if (!($1180)) {
      $newContact$0$lcssa$i670 = $newContact$02$i668;$newPatch$0$lcssa$i671 = $newPatch$01$i669;
      break L67;
     }
     $1181 = ((($c) + (($newPatch$01$i669*12)|0)|0) + 4|0);
     $1182 = HEAP16[$1181>>1]|0;
     $1183 = $1182&65535;
     $1184 = ($1182<<16>>16)==(-1);
     if ($1184) {
      $newContact$0$lcssa$i670 = 0;$newPatch$0$lcssa$i671 = $1183;
      break;
     } else {
      $newContact$02$i668 = 0;$newPatch$01$i669 = $1183;
     }
    }
   }
  } while(0);
  $1185 = ($newPatch$0$lcssa$i$i681|0)==(65535);
  L72: do {
   if ($1185) {
    $newContact$0$lcssa$i664 = 1;$newPatch$0$lcssa$i665 = 65535;
   } else {
    $newContact$02$i662 = 1;$newPatch$01$i663 = $newPatch$0$lcssa$i$i681;
    while(1) {
     $1186 = ((($c) + (($newPatch$01$i663*12)|0)|0) + 2|0);
     $1187 = HEAP16[$1186>>1]|0;
     $1188 = $1187&65535;
     $1189 = ($newContact$02$i662|0)==($1188|0);
     if (!($1189)) {
      $newContact$0$lcssa$i664 = $newContact$02$i662;$newPatch$0$lcssa$i665 = $newPatch$01$i663;
      break L72;
     }
     $1190 = ((($c) + (($newPatch$01$i663*12)|0)|0) + 4|0);
     $1191 = HEAP16[$1190>>1]|0;
     $1192 = $1191&65535;
     $1193 = ($1191<<16>>16)==(-1);
     if ($1193) {
      $newContact$0$lcssa$i664 = 0;$newPatch$0$lcssa$i665 = $1192;
      break;
     } else {
      $newContact$02$i662 = 0;$newPatch$01$i663 = $1192;
     }
    }
   }
  } while(0);
  $1194 = ($newPatch$0$lcssa$i$i|0)==(65535);
  L77: do {
   if ($1194) {
    $newContact$0$lcssa$i658 = 1;$newPatch$0$lcssa$i659 = 65535;
   } else {
    $newContact$02$i656 = 1;$newPatch$01$i657 = $newPatch$0$lcssa$i$i;
    while(1) {
     $1195 = ((($c) + (($newPatch$01$i657*12)|0)|0) + 2|0);
     $1196 = HEAP16[$1195>>1]|0;
     $1197 = $1196&65535;
     $1198 = ($newContact$02$i656|0)==($1197|0);
     if (!($1198)) {
      $newContact$0$lcssa$i658 = $newContact$02$i656;$newPatch$0$lcssa$i659 = $newPatch$01$i657;
      break L77;
     }
     $1199 = ((($c) + (($newPatch$01$i657*12)|0)|0) + 4|0);
     $1200 = HEAP16[$1199>>1]|0;
     $1201 = $1200&65535;
     $1202 = ($1200<<16>>16)==(-1);
     if ($1202) {
      $newContact$0$lcssa$i658 = 0;$newPatch$0$lcssa$i659 = $1201;
      break;
     } else {
      $newContact$02$i656 = 0;$newPatch$01$i657 = $1201;
     }
    }
   }
  } while(0);
  $1203 = ($newPatch$0$lcssa$i677|0)==(65535);
  $or$cond = $673 | $1203;
  if ($or$cond) {
   $1208 = 1;
  } else {
   $1204 = ((($c) + (($newPatch$0$lcssa$i677*12)|0)|0) + 2|0);
   $1205 = HEAP16[$1204>>1]|0;
   $1206 = $1205&65535;
   $phitmp = ($newContact$0$lcssa$i676>>>0)>=($1206>>>0);
   $1208 = $phitmp;
  }
  $1207 = $1208&1;
  $1209 = ($newPatch$0$lcssa$i671|0)==(65535);
  $or$cond5712 = $675 | $1209;
  if ($or$cond5712) {
   $1214 = 1;
  } else {
   $1210 = ((($c) + (($newPatch$0$lcssa$i671*12)|0)|0) + 2|0);
   $1211 = HEAP16[$1210>>1]|0;
   $1212 = $1211&65535;
   $phitmp5695 = ($newContact$0$lcssa$i670>>>0)>=($1212>>>0);
   $1214 = $phitmp5695;
  }
  $1213 = $1214&1;
  $1215 = $1213 << 1;
  $1216 = $1215 | $1207;
  $1217 = ($newPatch$0$lcssa$i665|0)==(65535);
  $or$cond5713 = $677 | $1217;
  if ($or$cond5713) {
   $1222 = 1;
  } else {
   $1218 = ((($c) + (($newPatch$0$lcssa$i665*12)|0)|0) + 2|0);
   $1219 = HEAP16[$1218>>1]|0;
   $1220 = $1219&65535;
   $phitmp5696 = ($newContact$0$lcssa$i664>>>0)>=($1220>>>0);
   $1222 = $phitmp5696;
  }
  $1221 = $1222&1;
  $1223 = $1221 << 2;
  $1224 = $1216 | $1223;
  $1225 = ($newPatch$0$lcssa$i659|0)==(65535);
  $or$cond5714 = $679 | $1225;
  if ($or$cond5714) {
   $1230 = 1;
  } else {
   $1226 = ((($c) + (($newPatch$0$lcssa$i659*12)|0)|0) + 2|0);
   $1227 = HEAP16[$1226>>1]|0;
   $1228 = $1227&65535;
   $phitmp5697 = ($newContact$0$lcssa$i658>>>0)>=($1228>>>0);
   $1230 = $phitmp5697;
  }
  $1229 = $1230&1;
  $1231 = $1229 << 3;
  $1232 = $1224 | $1231;
  $notlhs5702 = $753 > Math_fround(0.0);
  $notlhs5704 = $755 > Math_fround(0.0);
  $notlhs5707 = $757 > Math_fround(0.0);
  $notlhs5710 = $759 > Math_fround(0.0);
  $$ph = $newContact$0$lcssa$i676;$$ph5719 = $newContact$0$lcssa$i670;$$ph5720 = $newContact$0$lcssa$i664;$$ph5721 = $newContact$0$lcssa$i658;$$ph5722 = 0;$$ph5723 = 0;$$ph5724 = 0;$$ph5725 = 0;$$ph5726 = $newPatch$0$lcssa$i$i689;$$ph5727 = $newPatch$0$lcssa$i$i685;$$ph5728 = $newPatch$0$lcssa$i$i681;$$ph5729 = $newPatch$0$lcssa$i$i;$finished$0$ph = $1134;$fricIndex$0$ph = 0;$newFinished$0$ph = $1232;$newPatch$0$lcssa$i$i5677$ph = $newPatch$0$lcssa$i659;$newPatch$0$lcssa$i$i6815678$ph = $newPatch$0$lcssa$i665;$newPatch$0$lcssa$i$i6855680$ph = $newPatch$0$lcssa$i671;$newPatch$0$lcssa$i$i6895682$ph = $newPatch$0$lcssa$i677;$p$0$ph = $773;$ptr2$1$ph = $776;
  L94: while(1) {
   $1233 = (($c) + (($$ph5729*12)|0)|0);
   $1240 = $$ph5726;$1244 = $$ph5722;$1246 = $$ph5727;$1250 = $$ph5723;$1252 = $$ph5728;$1256 = $$ph5724;$2437 = $$ph;$2459 = $$ph5719;$2482 = $$ph5720;$finished$0 = $finished$0$ph;$fricIndex$0 = $fricIndex$0$ph;$newFinished$0 = $newFinished$0$ph;$newPatch$0$lcssa$i$i6815678 = $newPatch$0$lcssa$i$i6815678$ph;$newPatch$0$lcssa$i$i6855680 = $newPatch$0$lcssa$i$i6855680$ph;$newPatch$0$lcssa$i$i6895682 = $newPatch$0$lcssa$i$i6895682$ph;$p$0 = $p$0$ph;$ptr2$1 = $ptr2$1$ph;
   while(1) {
    $1234 = ($finished$0|0)==(15);
    if ($1234) {
     break L94;
    }
    $1235 = (($p$0) + 384|0);
    $1236 = (($p$0) + 512|0);
    $1237 = (($p$0) + 640|0);
    $1238 = (($p$0) + ($53)|0);
    $1239 = (($c) + (($1240*12)|0)|0);
    $1241 = HEAP16[$1239>>1]|0;
    $1242 = $1241&65535;
    $1243 = (($1242) + ($1244))|0;
    $1245 = (($c) + (($1246*12)|0)|0);
    $1247 = HEAP16[$1245>>1]|0;
    $1248 = $1247&65535;
    $1249 = (($1248) + ($1250))|0;
    $1251 = (($c) + (($1252*12)|0)|0);
    $1253 = HEAP16[$1251>>1]|0;
    $1254 = $1253&65535;
    $1255 = (($1254) + ($1256))|0;
    $1257 = HEAP16[$1233>>1]|0;
    $1258 = $1257&65535;
    $1259 = (($1258) + ($$ph5725))|0;
    $1260 = ((($threadContext) + ($1243<<6)|0) + 400|0);
    $1261 = Math_fround(HEAPF32[$1260>>2]);
    $1262 = (($1260) + 4|0);
    $1263 = Math_fround(HEAPF32[$1262>>2]);
    $1264 = (($1260) + 8|0);
    $1265 = Math_fround(HEAPF32[$1264>>2]);
    $1266 = ((($threadContext) + ($1249<<6)|0) + 400|0);
    $1267 = Math_fround(HEAPF32[$1266>>2]);
    $1268 = (($1266) + 4|0);
    $1269 = Math_fround(HEAPF32[$1268>>2]);
    $1270 = (($1266) + 8|0);
    $1271 = Math_fround(HEAPF32[$1270>>2]);
    $1272 = ((($threadContext) + ($1255<<6)|0) + 400|0);
    $1273 = Math_fround(HEAPF32[$1272>>2]);
    $1274 = (($1272) + 4|0);
    $1275 = Math_fround(HEAPF32[$1274>>2]);
    $1276 = (($1272) + 8|0);
    $1277 = Math_fround(HEAPF32[$1276>>2]);
    $1278 = ((($threadContext) + ($1259<<6)|0) + 400|0);
    $1279 = Math_fround(HEAPF32[$1278>>2]);
    $1280 = (($1278) + 4|0);
    $1281 = Math_fround(HEAPF32[$1280>>2]);
    $1282 = (($1278) + 8|0);
    $1283 = Math_fround(HEAPF32[$1282>>2]);
    $1284 = ((($threadContext) + ($1243<<6)|0) + 416|0);
    $1285 = Math_fround(HEAPF32[$1284>>2]);
    $1286 = (($1284) + 4|0);
    $1287 = Math_fround(HEAPF32[$1286>>2]);
    $1288 = (($1284) + 8|0);
    $1289 = Math_fround(HEAPF32[$1288>>2]);
    $1290 = ((($threadContext) + ($1249<<6)|0) + 416|0);
    $1291 = Math_fround(HEAPF32[$1290>>2]);
    $1292 = (($1290) + 4|0);
    $1293 = Math_fround(HEAPF32[$1292>>2]);
    $1294 = (($1290) + 8|0);
    $1295 = Math_fround(HEAPF32[$1294>>2]);
    $1296 = ((($threadContext) + ($1255<<6)|0) + 416|0);
    $1297 = Math_fround(HEAPF32[$1296>>2]);
    $1298 = (($1296) + 4|0);
    $1299 = Math_fround(HEAPF32[$1298>>2]);
    $1300 = (($1296) + 8|0);
    $1301 = Math_fround(HEAPF32[$1300>>2]);
    $1302 = ((($threadContext) + ($1259<<6)|0) + 416|0);
    $1303 = Math_fround(HEAPF32[$1302>>2]);
    $1304 = (($1302) + 4|0);
    $1305 = Math_fround(HEAPF32[$1304>>2]);
    $1306 = (($1302) + 8|0);
    $1307 = Math_fround(HEAPF32[$1306>>2]);
    $1308 = ((($threadContext) + ($1243<<6)|0) + 396|0);
    $1309 = Math_fround(HEAPF32[$1308>>2]);
    $1310 = ((($threadContext) + ($1249<<6)|0) + 396|0);
    $1311 = Math_fround(HEAPF32[$1310>>2]);
    $1312 = ((($threadContext) + ($1255<<6)|0) + 396|0);
    $1313 = Math_fround(HEAPF32[$1312>>2]);
    $1314 = ((($threadContext) + ($1259<<6)|0) + 396|0);
    $1315 = Math_fround(HEAPF32[$1314>>2]);
    $1316 = ((($threadContext) + ($1243<<6)|0) + 412|0);
    $1317 = Math_fround(HEAPF32[$1316>>2]);
    $1318 = ((($threadContext) + ($1249<<6)|0) + 412|0);
    $1319 = Math_fround(HEAPF32[$1318>>2]);
    $1320 = ((($threadContext) + ($1255<<6)|0) + 412|0);
    $1321 = Math_fround(HEAPF32[$1320>>2]);
    $1322 = ((($threadContext) + ($1259<<6)|0) + 412|0);
    $1323 = Math_fround(HEAPF32[$1322>>2]);
    $1324 = Math_fround($836 * $1289);
    $1325 = Math_fround($842 * $1295);
    $1326 = Math_fround($848 * $1301);
    $1327 = Math_fround($854 * $1307);
    $1328 = Math_fround($834 * $1287);
    $1329 = Math_fround($840 * $1293);
    $1330 = Math_fround($846 * $1299);
    $1331 = Math_fround($852 * $1305);
    $1332 = Math_fround($1328 + $1324);
    $1333 = Math_fround($1329 + $1325);
    $1334 = Math_fround($1330 + $1326);
    $1335 = Math_fround($1331 + $1327);
    $1336 = Math_fround($832 * $1285);
    $1337 = Math_fround($838 * $1291);
    $1338 = Math_fround($844 * $1297);
    $1339 = Math_fround($850 * $1303);
    $1340 = Math_fround($1336 + $1332);
    $1341 = Math_fround($1337 + $1333);
    $1342 = Math_fround($1338 + $1334);
    $1343 = Math_fround($1339 + $1335);
    $1344 = Math_fround($1261 - $517);
    $1345 = Math_fround($1267 - $525);
    $1346 = Math_fround($1273 - $533);
    $1347 = Math_fround($1279 - $541);
    $1348 = Math_fround($1263 - $519);
    $1349 = Math_fround($1269 - $527);
    $1350 = Math_fround($1275 - $535);
    $1351 = Math_fround($1281 - $543);
    $1352 = Math_fround($1265 - $521);
    $1353 = Math_fround($1271 - $529);
    $1354 = Math_fround($1277 - $537);
    $1355 = Math_fround($1283 - $545);
    $1356 = Math_fround($1261 - $549);
    $1357 = Math_fround($1267 - $557);
    $1358 = Math_fround($1273 - $565);
    $1359 = Math_fround($1279 - $573);
    $1360 = Math_fround($1263 - $551);
    $1361 = Math_fround($1269 - $559);
    $1362 = Math_fround($1275 - $567);
    $1363 = Math_fround($1281 - $575);
    $1364 = Math_fround($1265 - $553);
    $1365 = Math_fround($1271 - $561);
    $1366 = Math_fround($1277 - $569);
    $1367 = Math_fround($1283 - $577);
    $1368 = Math_fround($836 * $1348);
    $1369 = Math_fround($842 * $1349);
    $1370 = Math_fround($848 * $1350);
    $1371 = Math_fround($854 * $1351);
    $1372 = Math_fround($834 * $1352);
    $1373 = Math_fround($840 * $1353);
    $1374 = Math_fround($846 * $1354);
    $1375 = Math_fround($852 * $1355);
    $1376 = Math_fround($1368 - $1372);
    $1377 = Math_fround($1369 - $1373);
    $1378 = Math_fround($1370 - $1374);
    $1379 = Math_fround($1371 - $1375);
    $1380 = Math_fround($832 * $1352);
    $1381 = Math_fround($838 * $1353);
    $1382 = Math_fround($844 * $1354);
    $1383 = Math_fround($850 * $1355);
    $1384 = Math_fround($836 * $1344);
    $1385 = Math_fround($842 * $1345);
    $1386 = Math_fround($848 * $1346);
    $1387 = Math_fround($854 * $1347);
    $1388 = Math_fround($1380 - $1384);
    $1389 = Math_fround($1381 - $1385);
    $1390 = Math_fround($1382 - $1386);
    $1391 = Math_fround($1383 - $1387);
    $1392 = Math_fround($834 * $1344);
    $1393 = Math_fround($840 * $1345);
    $1394 = Math_fround($846 * $1346);
    $1395 = Math_fround($852 * $1347);
    $1396 = Math_fround($832 * $1348);
    $1397 = Math_fround($838 * $1349);
    $1398 = Math_fround($844 * $1350);
    $1399 = Math_fround($850 * $1351);
    $1400 = Math_fround($1392 - $1396);
    $1401 = Math_fround($1393 - $1397);
    $1402 = Math_fround($1394 - $1398);
    $1403 = Math_fround($1395 - $1399);
    $1404 = Math_fround($441 * $1376);
    $1405 = Math_fround($442 * $1377);
    $1406 = Math_fround($443 * $1378);
    $1407 = Math_fround($444 * $1379);
    $1408 = Math_fround($453 * $1376);
    $1409 = Math_fround($454 * $1377);
    $1410 = Math_fround($455 * $1378);
    $1411 = Math_fround($456 * $1379);
    $1412 = Math_fround($465 * $1376);
    $1413 = Math_fround($466 * $1377);
    $1414 = Math_fround($467 * $1378);
    $1415 = Math_fround($468 * $1379);
    $1416 = Math_fround($445 * $1388);
    $1417 = Math_fround($446 * $1389);
    $1418 = Math_fround($447 * $1390);
    $1419 = Math_fround($448 * $1391);
    $1420 = Math_fround($1416 + $1404);
    $1421 = Math_fround($1417 + $1405);
    $1422 = Math_fround($1418 + $1406);
    $1423 = Math_fround($1419 + $1407);
    $1424 = Math_fround($457 * $1388);
    $1425 = Math_fround($458 * $1389);
    $1426 = Math_fround($459 * $1390);
    $1427 = Math_fround($460 * $1391);
    $1428 = Math_fround($1424 + $1408);
    $1429 = Math_fround($1425 + $1409);
    $1430 = Math_fround($1426 + $1410);
    $1431 = Math_fround($1427 + $1411);
    $1432 = Math_fround($469 * $1388);
    $1433 = Math_fround($470 * $1389);
    $1434 = Math_fround($471 * $1390);
    $1435 = Math_fround($472 * $1391);
    $1436 = Math_fround($1432 + $1412);
    $1437 = Math_fround($1433 + $1413);
    $1438 = Math_fround($1434 + $1414);
    $1439 = Math_fround($1435 + $1415);
    $1440 = Math_fround($449 * $1400);
    $1441 = Math_fround($450 * $1401);
    $1442 = Math_fround($451 * $1402);
    $1443 = Math_fround($452 * $1403);
    $1444 = Math_fround($1440 + $1420);
    $1445 = Math_fround($1441 + $1421);
    $1446 = Math_fround($1442 + $1422);
    $1447 = Math_fround($1443 + $1423);
    $1448 = Math_fround($461 * $1400);
    $1449 = Math_fround($462 * $1401);
    $1450 = Math_fround($463 * $1402);
    $1451 = Math_fround($464 * $1403);
    $1452 = Math_fround($1448 + $1428);
    $1453 = Math_fround($1449 + $1429);
    $1454 = Math_fround($1450 + $1430);
    $1455 = Math_fround($1451 + $1431);
    $1456 = Math_fround($473 * $1400);
    $1457 = Math_fround($474 * $1401);
    $1458 = Math_fround($475 * $1402);
    $1459 = Math_fround($476 * $1403);
    $1460 = Math_fround($1456 + $1436);
    $1461 = Math_fround($1457 + $1437);
    $1462 = Math_fround($1458 + $1438);
    $1463 = Math_fround($1459 + $1439);
    $1464 = Math_fround($1376 * $1444);
    $1465 = Math_fround($1377 * $1445);
    $1466 = Math_fround($1378 * $1446);
    $1467 = Math_fround($1379 * $1447);
    $1468 = Math_fround($1388 * $1452);
    $1469 = Math_fround($1389 * $1453);
    $1470 = Math_fround($1390 * $1454);
    $1471 = Math_fround($1391 * $1455);
    $1472 = Math_fround($1468 + $1464);
    $1473 = Math_fround($1469 + $1465);
    $1474 = Math_fround($1470 + $1466);
    $1475 = Math_fround($1471 + $1467);
    $1476 = Math_fround($1400 * $1460);
    $1477 = Math_fround($1401 * $1461);
    $1478 = Math_fround($1402 * $1462);
    $1479 = Math_fround($1403 * $1463);
    $1480 = Math_fround($1476 + $1472);
    $1481 = Math_fround($1477 + $1473);
    $1482 = Math_fround($1478 + $1474);
    $1483 = Math_fround($1479 + $1475);
    $1484 = Math_fround($218 * $1376);
    $1485 = Math_fround($224 * $1377);
    $1486 = Math_fround($230 * $1378);
    $1487 = Math_fround($236 * $1379);
    $1488 = Math_fround($220 * $1388);
    $1489 = Math_fround($226 * $1389);
    $1490 = Math_fround($232 * $1390);
    $1491 = Math_fround($238 * $1391);
    $1492 = Math_fround($1488 + $1484);
    $1493 = Math_fround($1489 + $1485);
    $1494 = Math_fround($1490 + $1486);
    $1495 = Math_fround($1491 + $1487);
    $1496 = Math_fround($222 * $1400);
    $1497 = Math_fround($228 * $1401);
    $1498 = Math_fround($234 * $1402);
    $1499 = Math_fround($240 * $1403);
    $1500 = Math_fround($1496 + $1492);
    $1501 = Math_fround($1497 + $1493);
    $1502 = Math_fround($1498 + $1494);
    $1503 = Math_fround($1499 + $1495);
    $1504 = Math_fround($927 + $1480);
    $1505 = Math_fround($928 + $1481);
    $1506 = Math_fround($929 + $1482);
    $1507 = Math_fround($930 + $1483);
    $1508 = Math_fround($903 + $1500);
    $1509 = Math_fround($904 + $1501);
    $1510 = Math_fround($905 + $1502);
    $1511 = Math_fround($906 + $1503);
    if ($52) {
     $1512 = Math_fround($836 * $1360);
     $1513 = Math_fround($842 * $1361);
     $1514 = Math_fround($848 * $1362);
     $1515 = Math_fround($854 * $1363);
     $1516 = Math_fround($834 * $1364);
     $1517 = Math_fround($840 * $1365);
     $1518 = Math_fround($846 * $1366);
     $1519 = Math_fround($852 * $1367);
     $1520 = Math_fround($1512 - $1516);
     $1521 = Math_fround($1513 - $1517);
     $1522 = Math_fround($1514 - $1518);
     $1523 = Math_fround($1515 - $1519);
     $1524 = Math_fround($832 * $1364);
     $1525 = Math_fround($838 * $1365);
     $1526 = Math_fround($844 * $1366);
     $1527 = Math_fround($850 * $1367);
     $1528 = Math_fround($836 * $1356);
     $1529 = Math_fround($842 * $1357);
     $1530 = Math_fround($848 * $1358);
     $1531 = Math_fround($854 * $1359);
     $1532 = Math_fround($1524 - $1528);
     $1533 = Math_fround($1525 - $1529);
     $1534 = Math_fround($1526 - $1530);
     $1535 = Math_fround($1527 - $1531);
     $1536 = Math_fround($834 * $1356);
     $1537 = Math_fround($840 * $1357);
     $1538 = Math_fround($846 * $1358);
     $1539 = Math_fround($852 * $1359);
     $1540 = Math_fround($832 * $1360);
     $1541 = Math_fround($838 * $1361);
     $1542 = Math_fround($844 * $1362);
     $1543 = Math_fround($850 * $1363);
     $1544 = Math_fround($1536 - $1540);
     $1545 = Math_fround($1537 - $1541);
     $1546 = Math_fround($1538 - $1542);
     $1547 = Math_fround($1539 - $1543);
     $1548 = Math_fround($477 * $1520);
     $1549 = Math_fround($478 * $1521);
     $1550 = Math_fround($479 * $1522);
     $1551 = Math_fround($480 * $1523);
     $1552 = Math_fround($489 * $1520);
     $1553 = Math_fround($490 * $1521);
     $1554 = Math_fround($491 * $1522);
     $1555 = Math_fround($492 * $1523);
     $1556 = Math_fround($501 * $1520);
     $1557 = Math_fround($502 * $1521);
     $1558 = Math_fround($503 * $1522);
     $1559 = Math_fround($504 * $1523);
     $1560 = Math_fround($481 * $1532);
     $1561 = Math_fround($482 * $1533);
     $1562 = Math_fround($483 * $1534);
     $1563 = Math_fround($484 * $1535);
     $1564 = Math_fround($1560 + $1548);
     $1565 = Math_fround($1561 + $1549);
     $1566 = Math_fround($1562 + $1550);
     $1567 = Math_fround($1563 + $1551);
     $1568 = Math_fround($493 * $1532);
     $1569 = Math_fround($494 * $1533);
     $1570 = Math_fround($495 * $1534);
     $1571 = Math_fround($496 * $1535);
     $1572 = Math_fround($1568 + $1552);
     $1573 = Math_fround($1569 + $1553);
     $1574 = Math_fround($1570 + $1554);
     $1575 = Math_fround($1571 + $1555);
     $1576 = Math_fround($505 * $1532);
     $1577 = Math_fround($506 * $1533);
     $1578 = Math_fround($507 * $1534);
     $1579 = Math_fround($508 * $1535);
     $1580 = Math_fround($1576 + $1556);
     $1581 = Math_fround($1577 + $1557);
     $1582 = Math_fround($1578 + $1558);
     $1583 = Math_fround($1579 + $1559);
     $1584 = Math_fround($485 * $1544);
     $1585 = Math_fround($486 * $1545);
     $1586 = Math_fround($487 * $1546);
     $1587 = Math_fround($488 * $1547);
     $1588 = Math_fround($1584 + $1564);
     $1589 = Math_fround($1585 + $1565);
     $1590 = Math_fround($1586 + $1566);
     $1591 = Math_fround($1587 + $1567);
     $1592 = Math_fround($497 * $1544);
     $1593 = Math_fround($498 * $1545);
     $1594 = Math_fround($499 * $1546);
     $1595 = Math_fround($500 * $1547);
     $1596 = Math_fround($1592 + $1572);
     $1597 = Math_fround($1593 + $1573);
     $1598 = Math_fround($1594 + $1574);
     $1599 = Math_fround($1595 + $1575);
     $1600 = Math_fround($509 * $1544);
     $1601 = Math_fround($510 * $1545);
     $1602 = Math_fround($511 * $1546);
     $1603 = Math_fround($512 * $1547);
     $1604 = Math_fround($1600 + $1580);
     $1605 = Math_fround($1601 + $1581);
     $1606 = Math_fround($1602 + $1582);
     $1607 = Math_fround($1603 + $1583);
     $1608 = Math_fround($1520 * $1588);
     $1609 = Math_fround($1521 * $1589);
     $1610 = Math_fround($1522 * $1590);
     $1611 = Math_fround($1523 * $1591);
     $1612 = Math_fround($1532 * $1596);
     $1613 = Math_fround($1533 * $1597);
     $1614 = Math_fround($1534 * $1598);
     $1615 = Math_fround($1535 * $1599);
     $1616 = Math_fround($1612 + $1608);
     $1617 = Math_fround($1613 + $1609);
     $1618 = Math_fround($1614 + $1610);
     $1619 = Math_fround($1615 + $1611);
     $1620 = Math_fround($1544 * $1604);
     $1621 = Math_fround($1545 * $1605);
     $1622 = Math_fround($1546 * $1606);
     $1623 = Math_fround($1547 * $1607);
     $1624 = Math_fround($1620 + $1616);
     $1625 = Math_fround($1621 + $1617);
     $1626 = Math_fround($1622 + $1618);
     $1627 = Math_fround($1623 + $1619);
     $1628 = Math_fround($242 * $1520);
     $1629 = Math_fround($248 * $1521);
     $1630 = Math_fround($254 * $1522);
     $1631 = Math_fround($260 * $1523);
     $1632 = Math_fround($244 * $1532);
     $1633 = Math_fround($250 * $1533);
     $1634 = Math_fround($256 * $1534);
     $1635 = Math_fround($262 * $1535);
     $1636 = Math_fround($1632 + $1628);
     $1637 = Math_fround($1633 + $1629);
     $1638 = Math_fround($1634 + $1630);
     $1639 = Math_fround($1635 + $1631);
     $1640 = Math_fround($246 * $1544);
     $1641 = Math_fround($252 * $1545);
     $1642 = Math_fround($258 * $1546);
     $1643 = Math_fround($264 * $1547);
     $1644 = Math_fround($1640 + $1636);
     $1645 = Math_fround($1641 + $1637);
     $1646 = Math_fround($1642 + $1638);
     $1647 = Math_fround($1643 + $1639);
     $1648 = Math_fround($1624 - $931);
     $1649 = Math_fround($1625 - $932);
     $1650 = Math_fround($1626 - $933);
     $1651 = Math_fround($1627 - $934);
     $1652 = Math_fround($1504 + $1648);
     $1653 = Math_fround($1505 + $1649);
     $1654 = Math_fround($1506 + $1650);
     $1655 = Math_fround($1507 + $1651);
     $1656 = Math_fround($923 + $1644);
     $1657 = Math_fround($924 + $1645);
     $1658 = Math_fround($925 + $1646);
     $1659 = Math_fround($926 + $1647);
     $1660 = Math_fround($1508 - $1656);
     $1661 = Math_fround($1509 - $1657);
     $1662 = Math_fround($1510 - $1658);
     $1663 = Math_fround($1511 - $1659);
     $1664 = (($p$0) + 176|0);
     HEAPF32[$1664>>2] = $1520;
     $1665 = (($p$0) + 180|0);
     HEAPF32[$1665>>2] = $1521;
     $1666 = (($p$0) + 184|0);
     HEAPF32[$1666>>2] = $1522;
     $1667 = (($p$0) + 188|0);
     HEAPF32[$1667>>2] = $1523;
     $1668 = (($p$0) + 192|0);
     HEAPF32[$1668>>2] = $1532;
     $1669 = (($p$0) + 196|0);
     HEAPF32[$1669>>2] = $1533;
     $1670 = (($p$0) + 200|0);
     HEAPF32[$1670>>2] = $1534;
     $1671 = (($p$0) + 204|0);
     HEAPF32[$1671>>2] = $1535;
     $1672 = (($p$0) + 208|0);
     HEAPF32[$1672>>2] = $1544;
     $1673 = (($p$0) + 212|0);
     HEAPF32[$1673>>2] = $1545;
     $1674 = (($p$0) + 216|0);
     HEAPF32[$1674>>2] = $1546;
     $1675 = (($p$0) + 220|0);
     HEAPF32[$1675>>2] = $1547;
     $1676 = Math_fround(-$1588);
     $1677 = Math_fround(-$1589);
     $1678 = Math_fround(-$1590);
     $1679 = Math_fround(-$1591);
     $1680 = (($p$0) + 224|0);
     HEAPF32[$1680>>2] = $1676;
     $1681 = (($p$0) + 228|0);
     HEAPF32[$1681>>2] = $1677;
     $1682 = (($p$0) + 232|0);
     HEAPF32[$1682>>2] = $1678;
     $1683 = (($p$0) + 236|0);
     HEAPF32[$1683>>2] = $1679;
     $1684 = Math_fround(-$1596);
     $1685 = Math_fround(-$1597);
     $1686 = Math_fround(-$1598);
     $1687 = Math_fround(-$1599);
     $1688 = (($p$0) + 240|0);
     HEAPF32[$1688>>2] = $1684;
     $1689 = (($p$0) + 244|0);
     HEAPF32[$1689>>2] = $1685;
     $1690 = (($p$0) + 248|0);
     HEAPF32[$1690>>2] = $1686;
     $1691 = (($p$0) + 252|0);
     HEAPF32[$1691>>2] = $1687;
     $1692 = Math_fround(-$1604);
     $1693 = Math_fround(-$1605);
     $1694 = Math_fround(-$1606);
     $1695 = Math_fround(-$1607);
     $1696 = (($p$0) + 256|0);
     HEAPF32[$1696>>2] = $1692;
     $1697 = (($p$0) + 260|0);
     HEAPF32[$1697>>2] = $1693;
     $1698 = (($p$0) + 264|0);
     HEAPF32[$1698>>2] = $1694;
     $1699 = (($p$0) + 268|0);
     HEAPF32[$1699>>2] = $1695;
     $1701 = $1652;$1703 = $1653;$1705 = $1654;$1707 = $1655;$1739 = $1660;$1741 = $1661;$1743 = $1662;$1745 = $1663;
    } else {
     $1701 = $1504;$1703 = $1505;$1705 = $1506;$1707 = $1507;$1739 = $1508;$1741 = $1509;$1743 = $1510;$1745 = $1511;
    }
    $1700 = $1701 > Math_fround(0.0);
    $1702 = $1703 > Math_fround(0.0);
    $1704 = $1705 > Math_fround(0.0);
    $1706 = $1707 > Math_fround(0.0);
    $1708 = Math_fround(Math_fround(1.0) / $1701);
    $1709 = Math_fround(Math_fround(1.0) / $1703);
    $1710 = Math_fround(Math_fround(1.0) / $1705);
    $1711 = Math_fround(Math_fround(1.0) / $1707);
    HEAPF32[$14>>2] = $1708;
    HEAPF32[$654>>2] = $1709;
    HEAPF32[$655>>2] = $1710;
    HEAPF32[$656>>2] = $1711;
    $b$a$i347 = $1700 ? $14 : $13;
    ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
    $1712 = Math_fround(HEAPF32[$b$a$i347>>2]);
    $a$pn4$i349 = $1702 ? $14 : $13;
    $$in1$i350 = (($a$pn4$i349) + 4|0);
    $1713 = Math_fround(HEAPF32[$$in1$i350>>2]);
    $b$a7$i351 = $1704 ? $14 : $13;
    $$in2$i352 = (($b$a7$i351) + 8|0);
    $1714 = Math_fround(HEAPF32[$$in2$i352>>2]);
    $a$pn6$i353 = $1706 ? $14 : $13;
    $$in3$i354 = (($a$pn6$i353) + 12|0);
    $1715 = Math_fround(HEAPF32[$$in3$i354>>2]);
    $1716 = Math_fround($1309 - $154);
    $1717 = Math_fround($1311 - $156);
    $1718 = Math_fround($1313 - $158);
    $1719 = Math_fround($1315 - $160);
    $1720 = Math_fround($513 * $1716);
    $1721 = Math_fround($513 * $1717);
    $1722 = Math_fround($513 * $1718);
    $1723 = Math_fround($513 * $1719);
    $1724 = $$$i1125 > $1720;
    $$$i = $1724 ? $$$i1125 : $1720;
    $1725 = $149 > $1721;
    $1726 = $1725 ? $149 : $1721;
    $1727 = $$1$i1126 > $1722;
    $$1$i = $1727 ? $$1$i1126 : $1722;
    $1728 = $152 > $1723;
    $1729 = $1728 ? $152 : $1723;
    $1730 = Math_fround($$$i * $1712);
    $1731 = Math_fround($1726 * $1713);
    $1732 = Math_fround($$1$i * $1714);
    $1733 = Math_fround($1729 * $1715);
    $1734 = Math_fround($1716 * $invDtF32);
    $1735 = Math_fround($1717 * $invDtF32);
    $1736 = Math_fround($1718 * $invDtF32);
    $1737 = Math_fround($1719 * $invDtF32);
    $1738 = Math_fround(-$1739);
    $1740 = Math_fround(-$1741);
    $1742 = Math_fround(-$1743);
    $1744 = Math_fround(-$1745);
    $1746 = $1734 < $1738;
    $1747 = $1735 < $1740;
    $1748 = $1736 < $1742;
    $1749 = $1737 < $1744;
    $notrhs5703 = $1739 < $bounceThresholdF32;
    $not$5701 = $notrhs5703 & $notlhs5702;
    $$5693 = $1746 & $not$5701;
    $notrhs5705 = $1741 < $bounceThresholdF32;
    $not$ = $notrhs5705 & $notlhs5704;
    $1750 = $1747 & $not$;
    $notrhs5708 = $1743 < $bounceThresholdF32;
    $not$5706 = $notrhs5708 & $notlhs5707;
    $$5694 = $1748 & $not$5706;
    $notrhs5711 = $1745 < $bounceThresholdF32;
    $not$5709 = $notrhs5711 & $notlhs5710;
    $1751 = $1749 & $not$5709;
    ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
    HEAPF32[$15>>2] = $1730;
    HEAPF32[$657>>2] = $1731;
    HEAPF32[$658>>2] = $1732;
    HEAPF32[$659>>2] = $1733;
    $b$a$i290 = $$5693 ? $16 : $15;
    $1752 = Math_fround(HEAPF32[$b$a$i290>>2]);
    $a$pn4$i292 = $1750 ? $16 : $15;
    $$in1$i293 = (($a$pn4$i292) + 4|0);
    $1753 = Math_fround(HEAPF32[$$in1$i293>>2]);
    $b$a7$i294 = $$5694 ? $16 : $15;
    $$in2$i295 = (($b$a7$i294) + 8|0);
    $1754 = Math_fround(HEAPF32[$$in2$i295>>2]);
    $a$pn6$i296 = $1751 ? $16 : $15;
    $$in3$i297 = (($a$pn6$i296) + 12|0);
    $1755 = Math_fround(HEAPF32[$$in3$i297>>2]);
    $1756 = Math_fround($753 * $1738);
    $1757 = Math_fround($755 * $1740);
    $1758 = Math_fround($757 * $1742);
    $1759 = Math_fround($759 * $1744);
    HEAPF32[$18>>2] = $1756;
    HEAPF32[$660>>2] = $1757;
    HEAPF32[$661>>2] = $1758;
    HEAPF32[$662>>2] = $1759;
    $b$a$i270 = $$5693 ? $18 : $17;
    ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;
    $1760 = Math_fround(HEAPF32[$b$a$i270>>2]);
    $a$pn4$i272 = $1750 ? $18 : $17;
    $$in1$i273 = (($a$pn4$i272) + 4|0);
    $1761 = Math_fround(HEAPF32[$$in1$i273>>2]);
    $b$a7$i274 = $$5694 ? $18 : $17;
    $$in2$i275 = (($b$a7$i274) + 8|0);
    $1762 = Math_fround(HEAPF32[$$in2$i275>>2]);
    $a$pn6$i276 = $1751 ? $18 : $17;
    $$in3$i277 = (($a$pn6$i276) + 12|0);
    $1763 = Math_fround(HEAPF32[$$in3$i277>>2]);
    $1764 = Math_fround($1340 + $1760);
    $1765 = Math_fround($1341 + $1761);
    $1766 = Math_fround($1342 + $1762);
    $1767 = Math_fround($1343 + $1763);
    HEAPF32[$p$0>>2] = $1376;
    $1768 = (($p$0) + 4|0);
    HEAPF32[$1768>>2] = $1377;
    $1769 = (($p$0) + 8|0);
    HEAPF32[$1769>>2] = $1378;
    $1770 = (($p$0) + 12|0);
    HEAPF32[$1770>>2] = $1379;
    $1771 = (($p$0) + 16|0);
    HEAPF32[$1771>>2] = $1388;
    $1772 = (($p$0) + 20|0);
    HEAPF32[$1772>>2] = $1389;
    $1773 = (($p$0) + 24|0);
    HEAPF32[$1773>>2] = $1390;
    $1774 = (($p$0) + 28|0);
    HEAPF32[$1774>>2] = $1391;
    $1775 = (($p$0) + 32|0);
    HEAPF32[$1775>>2] = $1400;
    $1776 = (($p$0) + 36|0);
    HEAPF32[$1776>>2] = $1401;
    $1777 = (($p$0) + 40|0);
    HEAPF32[$1777>>2] = $1402;
    $1778 = (($p$0) + 44|0);
    HEAPF32[$1778>>2] = $1403;
    $1779 = (($p$0) + 112|0);
    HEAPF32[$1779>>2] = $1712;
    $1780 = (($p$0) + 116|0);
    HEAPF32[$1780>>2] = $1713;
    $1781 = (($p$0) + 120|0);
    HEAPF32[$1781>>2] = $1714;
    $1782 = (($p$0) + 124|0);
    HEAPF32[$1782>>2] = $1715;
    $1783 = (($p$0) + 96|0);
    $1784 = (($p$0) + 144|0);
    ;HEAP32[$1783+0>>2]=0|0;HEAP32[$1783+4>>2]=0|0;HEAP32[$1783+8>>2]=0|0;HEAP32[$1783+12>>2]=0|0;
    HEAPF32[$1784>>2] = $1752;
    $1785 = (($p$0) + 148|0);
    HEAPF32[$1785>>2] = $1753;
    $1786 = (($p$0) + 152|0);
    HEAPF32[$1786>>2] = $1754;
    $1787 = (($p$0) + 156|0);
    HEAPF32[$1787>>2] = $1755;
    $1788 = (($p$0) + 128|0);
    HEAPF32[$1788>>2] = $1764;
    $1789 = (($p$0) + 132|0);
    HEAPF32[$1789>>2] = $1765;
    $1790 = (($p$0) + 136|0);
    HEAPF32[$1790>>2] = $1766;
    $1791 = (($p$0) + 140|0);
    HEAPF32[$1791>>2] = $1767;
    $1792 = (($p$0) + 160|0);
    HEAPF32[$1792>>2] = $1317;
    $1793 = (($p$0) + 164|0);
    HEAPF32[$1793>>2] = $1319;
    $1794 = (($p$0) + 168|0);
    HEAPF32[$1794>>2] = $1321;
    $1795 = (($p$0) + 172|0);
    HEAPF32[$1795>>2] = $1323;
    $1796 = (($p$0) + 48|0);
    HEAPF32[$1796>>2] = $1444;
    $1797 = (($p$0) + 52|0);
    HEAPF32[$1797>>2] = $1445;
    $1798 = (($p$0) + 56|0);
    HEAPF32[$1798>>2] = $1446;
    $1799 = (($p$0) + 60|0);
    HEAPF32[$1799>>2] = $1447;
    $1800 = (($p$0) + 64|0);
    HEAPF32[$1800>>2] = $1452;
    $1801 = (($p$0) + 68|0);
    HEAPF32[$1801>>2] = $1453;
    $1802 = (($p$0) + 72|0);
    HEAPF32[$1802>>2] = $1454;
    $1803 = (($p$0) + 76|0);
    HEAPF32[$1803>>2] = $1455;
    $1804 = (($p$0) + 80|0);
    HEAPF32[$1804>>2] = $1460;
    $1805 = (($p$0) + 84|0);
    HEAPF32[$1805>>2] = $1461;
    $1806 = (($p$0) + 88|0);
    HEAPF32[$1806>>2] = $1462;
    $1807 = (($p$0) + 92|0);
    HEAPF32[$1807>>2] = $1463;
    $1808 = Math_fround(HEAPF32[$1284>>2]);
    $1809 = Math_fround(HEAPF32[$1286>>2]);
    $1810 = Math_fround(HEAPF32[$1288>>2]);
    $1811 = Math_fround(HEAPF32[$1290>>2]);
    $1812 = Math_fround(HEAPF32[$1292>>2]);
    $1813 = Math_fround(HEAPF32[$1294>>2]);
    $1814 = Math_fround(HEAPF32[$1296>>2]);
    $1815 = Math_fround(HEAPF32[$1298>>2]);
    $1816 = Math_fround(HEAPF32[$1300>>2]);
    $1817 = Math_fround(HEAPF32[$1302>>2]);
    $1818 = Math_fround(HEAPF32[$1304>>2]);
    $1819 = Math_fround(HEAPF32[$1306>>2]);
    if ($663) {
     $fricIndex$1$lcssa = $fricIndex$0;$ptr2$2$lcssa = $ptr2$1;
    } else {
     if ($52) {
      $a$05717$us = 0;$fricIndex$15715$us = $fricIndex$0;$ptr2$25716$us = $ptr2$1;
      while(1) {
       $1820 = (($ptr2$25716$us) + ($54)|0);
       $1821 = (($tFallbackX) + ($fricIndex$15715$us<<4)|0);
       $1822 = Math_fround(HEAPF32[$1821>>2]);
       $1823 = ((($tFallbackX) + ($fricIndex$15715$us<<4)|0) + 4|0);
       $1824 = Math_fround(HEAPF32[$1823>>2]);
       $1825 = ((($tFallbackX) + ($fricIndex$15715$us<<4)|0) + 8|0);
       $1826 = Math_fround(HEAPF32[$1825>>2]);
       $1827 = ((($tFallbackX) + ($fricIndex$15715$us<<4)|0) + 12|0);
       $1828 = Math_fround(HEAPF32[$1827>>2]);
       $1829 = (($tFallbackY) + ($fricIndex$15715$us<<4)|0);
       $1830 = Math_fround(HEAPF32[$1829>>2]);
       $1831 = ((($tFallbackY) + ($fricIndex$15715$us<<4)|0) + 4|0);
       $1832 = Math_fround(HEAPF32[$1831>>2]);
       $1833 = ((($tFallbackY) + ($fricIndex$15715$us<<4)|0) + 8|0);
       $1834 = Math_fround(HEAPF32[$1833>>2]);
       $1835 = ((($tFallbackY) + ($fricIndex$15715$us<<4)|0) + 12|0);
       $1836 = Math_fround(HEAPF32[$1835>>2]);
       $1837 = (($tFallbackZ) + ($fricIndex$15715$us<<4)|0);
       $1838 = Math_fround(HEAPF32[$1837>>2]);
       $1839 = ((($tFallbackZ) + ($fricIndex$15715$us<<4)|0) + 4|0);
       $1840 = Math_fround(HEAPF32[$1839>>2]);
       $1841 = ((($tFallbackZ) + ($fricIndex$15715$us<<4)|0) + 8|0);
       $1842 = Math_fround(HEAPF32[$1841>>2]);
       $1843 = ((($tFallbackZ) + ($fricIndex$15715$us<<4)|0) + 12|0);
       $1844 = Math_fround(HEAPF32[$1843>>2]);
       $1845 = (1 - ($fricIndex$15715$us))|0;
       $1846 = Math_fround($1348 * $1838);
       $1847 = Math_fround($1349 * $1840);
       $1848 = Math_fround($1350 * $1842);
       $1849 = Math_fround($1351 * $1844);
       $1850 = Math_fround($1352 * $1830);
       $1851 = Math_fround($1353 * $1832);
       $1852 = Math_fround($1354 * $1834);
       $1853 = Math_fround($1355 * $1836);
       $1854 = Math_fround($1846 - $1850);
       $1855 = Math_fround($1847 - $1851);
       $1856 = Math_fround($1848 - $1852);
       $1857 = Math_fround($1849 - $1853);
       $1858 = Math_fround($1352 * $1822);
       $1859 = Math_fround($1353 * $1824);
       $1860 = Math_fround($1354 * $1826);
       $1861 = Math_fround($1355 * $1828);
       $1862 = Math_fround($1344 * $1838);
       $1863 = Math_fround($1345 * $1840);
       $1864 = Math_fround($1346 * $1842);
       $1865 = Math_fround($1347 * $1844);
       $1866 = Math_fround($1858 - $1862);
       $1867 = Math_fround($1859 - $1863);
       $1868 = Math_fround($1860 - $1864);
       $1869 = Math_fround($1861 - $1865);
       $1870 = Math_fround($1344 * $1830);
       $1871 = Math_fround($1345 * $1832);
       $1872 = Math_fround($1346 * $1834);
       $1873 = Math_fround($1347 * $1836);
       $1874 = Math_fround($1348 * $1822);
       $1875 = Math_fround($1349 * $1824);
       $1876 = Math_fround($1350 * $1826);
       $1877 = Math_fround($1351 * $1828);
       $1878 = Math_fround($1870 - $1874);
       $1879 = Math_fround($1871 - $1875);
       $1880 = Math_fround($1872 - $1876);
       $1881 = Math_fround($1873 - $1877);
       $1882 = Math_fround($441 * $1854);
       $1883 = Math_fround($442 * $1855);
       $1884 = Math_fround($443 * $1856);
       $1885 = Math_fround($444 * $1857);
       $1886 = Math_fround($453 * $1854);
       $1887 = Math_fround($454 * $1855);
       $1888 = Math_fround($455 * $1856);
       $1889 = Math_fround($456 * $1857);
       $1890 = Math_fround($465 * $1854);
       $1891 = Math_fround($466 * $1855);
       $1892 = Math_fround($467 * $1856);
       $1893 = Math_fround($468 * $1857);
       $1894 = Math_fround($445 * $1866);
       $1895 = Math_fround($446 * $1867);
       $1896 = Math_fround($447 * $1868);
       $1897 = Math_fround($448 * $1869);
       $1898 = Math_fround($1894 + $1882);
       $1899 = Math_fround($1895 + $1883);
       $1900 = Math_fround($1896 + $1884);
       $1901 = Math_fround($1897 + $1885);
       $1902 = Math_fround($457 * $1866);
       $1903 = Math_fround($458 * $1867);
       $1904 = Math_fround($459 * $1868);
       $1905 = Math_fround($460 * $1869);
       $1906 = Math_fround($1902 + $1886);
       $1907 = Math_fround($1903 + $1887);
       $1908 = Math_fround($1904 + $1888);
       $1909 = Math_fround($1905 + $1889);
       $1910 = Math_fround($469 * $1866);
       $1911 = Math_fround($470 * $1867);
       $1912 = Math_fround($471 * $1868);
       $1913 = Math_fround($472 * $1869);
       $1914 = Math_fround($1910 + $1890);
       $1915 = Math_fround($1911 + $1891);
       $1916 = Math_fround($1912 + $1892);
       $1917 = Math_fround($1913 + $1893);
       $1918 = Math_fround($449 * $1878);
       $1919 = Math_fround($450 * $1879);
       $1920 = Math_fround($451 * $1880);
       $1921 = Math_fround($452 * $1881);
       $1922 = Math_fround($1918 + $1898);
       $1923 = Math_fround($1919 + $1899);
       $1924 = Math_fround($1920 + $1900);
       $1925 = Math_fround($1921 + $1901);
       $1926 = Math_fround($461 * $1878);
       $1927 = Math_fround($462 * $1879);
       $1928 = Math_fround($463 * $1880);
       $1929 = Math_fround($464 * $1881);
       $1930 = Math_fround($1926 + $1906);
       $1931 = Math_fround($1927 + $1907);
       $1932 = Math_fround($1928 + $1908);
       $1933 = Math_fround($1929 + $1909);
       $1934 = Math_fround($473 * $1878);
       $1935 = Math_fround($474 * $1879);
       $1936 = Math_fround($475 * $1880);
       $1937 = Math_fround($476 * $1881);
       $1938 = Math_fround($1934 + $1914);
       $1939 = Math_fround($1935 + $1915);
       $1940 = Math_fround($1936 + $1916);
       $1941 = Math_fround($1937 + $1917);
       $1942 = Math_fround($1854 * $1922);
       $1943 = Math_fround($1855 * $1923);
       $1944 = Math_fround($1856 * $1924);
       $1945 = Math_fround($1857 * $1925);
       $1946 = Math_fround($1866 * $1930);
       $1947 = Math_fround($1867 * $1931);
       $1948 = Math_fround($1868 * $1932);
       $1949 = Math_fround($1869 * $1933);
       $1950 = Math_fround($1946 + $1942);
       $1951 = Math_fround($1947 + $1943);
       $1952 = Math_fround($1948 + $1944);
       $1953 = Math_fround($1949 + $1945);
       $1954 = Math_fround($1878 * $1938);
       $1955 = Math_fround($1879 * $1939);
       $1956 = Math_fround($1880 * $1940);
       $1957 = Math_fround($1881 * $1941);
       $1958 = Math_fround($1954 + $1950);
       $1959 = Math_fround($1955 + $1951);
       $1960 = Math_fround($1956 + $1952);
       $1961 = Math_fround($1957 + $1953);
       $1962 = Math_fround($293 + $1958);
       $1963 = Math_fround($294 + $1959);
       $1964 = Math_fround($295 + $1960);
       $1965 = Math_fround($296 + $1961);
       $1966 = Math_fround($1360 * $1838);
       $1967 = Math_fround($1361 * $1840);
       $1968 = Math_fround($1362 * $1842);
       $1969 = Math_fround($1363 * $1844);
       $1970 = Math_fround($1364 * $1830);
       $1971 = Math_fround($1365 * $1832);
       $1972 = Math_fround($1366 * $1834);
       $1973 = Math_fround($1367 * $1836);
       $1974 = Math_fround($1966 - $1970);
       $1975 = Math_fround($1967 - $1971);
       $1976 = Math_fround($1968 - $1972);
       $1977 = Math_fround($1969 - $1973);
       $1978 = Math_fround($1364 * $1822);
       $1979 = Math_fround($1365 * $1824);
       $1980 = Math_fround($1366 * $1826);
       $1981 = Math_fround($1367 * $1828);
       $1982 = Math_fround($1356 * $1838);
       $1983 = Math_fround($1357 * $1840);
       $1984 = Math_fround($1358 * $1842);
       $1985 = Math_fround($1359 * $1844);
       $1986 = Math_fround($1978 - $1982);
       $1987 = Math_fround($1979 - $1983);
       $1988 = Math_fround($1980 - $1984);
       $1989 = Math_fround($1981 - $1985);
       $1990 = Math_fround($1356 * $1830);
       $1991 = Math_fround($1357 * $1832);
       $1992 = Math_fround($1358 * $1834);
       $1993 = Math_fround($1359 * $1836);
       $1994 = Math_fround($1360 * $1822);
       $1995 = Math_fround($1361 * $1824);
       $1996 = Math_fround($1362 * $1826);
       $1997 = Math_fround($1363 * $1828);
       $1998 = Math_fround($1990 - $1994);
       $1999 = Math_fround($1991 - $1995);
       $2000 = Math_fround($1992 - $1996);
       $2001 = Math_fround($1993 - $1997);
       $2002 = Math_fround($477 * $1974);
       $2003 = Math_fround($478 * $1975);
       $2004 = Math_fround($479 * $1976);
       $2005 = Math_fround($480 * $1977);
       $2006 = Math_fround($489 * $1974);
       $2007 = Math_fround($490 * $1975);
       $2008 = Math_fround($491 * $1976);
       $2009 = Math_fround($492 * $1977);
       $2010 = Math_fround($501 * $1974);
       $2011 = Math_fround($502 * $1975);
       $2012 = Math_fround($503 * $1976);
       $2013 = Math_fround($504 * $1977);
       $2014 = Math_fround($481 * $1986);
       $2015 = Math_fround($482 * $1987);
       $2016 = Math_fround($483 * $1988);
       $2017 = Math_fround($484 * $1989);
       $2018 = Math_fround($2014 + $2002);
       $2019 = Math_fround($2015 + $2003);
       $2020 = Math_fround($2016 + $2004);
       $2021 = Math_fround($2017 + $2005);
       $2022 = Math_fround($493 * $1986);
       $2023 = Math_fround($494 * $1987);
       $2024 = Math_fround($495 * $1988);
       $2025 = Math_fround($496 * $1989);
       $2026 = Math_fround($2022 + $2006);
       $2027 = Math_fround($2023 + $2007);
       $2028 = Math_fround($2024 + $2008);
       $2029 = Math_fround($2025 + $2009);
       $2030 = Math_fround($505 * $1986);
       $2031 = Math_fround($506 * $1987);
       $2032 = Math_fround($507 * $1988);
       $2033 = Math_fround($508 * $1989);
       $2034 = Math_fround($2030 + $2010);
       $2035 = Math_fround($2031 + $2011);
       $2036 = Math_fround($2032 + $2012);
       $2037 = Math_fround($2033 + $2013);
       $2038 = Math_fround($485 * $1998);
       $2039 = Math_fround($486 * $1999);
       $2040 = Math_fround($487 * $2000);
       $2041 = Math_fround($488 * $2001);
       $2042 = Math_fround($2038 + $2018);
       $2043 = Math_fround($2039 + $2019);
       $2044 = Math_fround($2040 + $2020);
       $2045 = Math_fround($2041 + $2021);
       $2046 = Math_fround($497 * $1998);
       $2047 = Math_fround($498 * $1999);
       $2048 = Math_fround($499 * $2000);
       $2049 = Math_fround($500 * $2001);
       $2050 = Math_fround($2046 + $2026);
       $2051 = Math_fround($2047 + $2027);
       $2052 = Math_fround($2048 + $2028);
       $2053 = Math_fround($2049 + $2029);
       $2054 = Math_fround($509 * $1998);
       $2055 = Math_fround($510 * $1999);
       $2056 = Math_fround($511 * $2000);
       $2057 = Math_fround($512 * $2001);
       $2058 = Math_fround($2054 + $2034);
       $2059 = Math_fround($2055 + $2035);
       $2060 = Math_fround($2056 + $2036);
       $2061 = Math_fround($2057 + $2037);
       $2062 = Math_fround($1974 * $2042);
       $2063 = Math_fround($1975 * $2043);
       $2064 = Math_fround($1976 * $2044);
       $2065 = Math_fround($1977 * $2045);
       $2066 = Math_fround($1986 * $2050);
       $2067 = Math_fround($1987 * $2051);
       $2068 = Math_fround($1988 * $2052);
       $2069 = Math_fround($1989 * $2053);
       $2070 = Math_fround($2066 + $2062);
       $2071 = Math_fround($2067 + $2063);
       $2072 = Math_fround($2068 + $2064);
       $2073 = Math_fround($2069 + $2065);
       $2074 = Math_fround($1998 * $2058);
       $2075 = Math_fround($1999 * $2059);
       $2076 = Math_fround($2000 * $2060);
       $2077 = Math_fround($2001 * $2061);
       $2078 = Math_fround($2074 + $2070);
       $2079 = Math_fround($2075 + $2071);
       $2080 = Math_fround($2076 + $2072);
       $2081 = Math_fround($2077 + $2073);
       $2082 = Math_fround($2078 - $931);
       $2083 = Math_fround($2079 - $932);
       $2084 = Math_fround($2080 - $933);
       $2085 = Math_fround($2081 - $934);
       $2086 = Math_fround($1962 + $2082);
       $2087 = Math_fround($1963 + $2083);
       $2088 = Math_fround($1964 + $2084);
       $2089 = Math_fround($1965 + $2085);
       $2090 = (($ptr2$25716$us) + 192|0);
       HEAPF32[$2090>>2] = $1974;
       $2091 = (($ptr2$25716$us) + 196|0);
       HEAPF32[$2091>>2] = $1975;
       $2092 = (($ptr2$25716$us) + 200|0);
       HEAPF32[$2092>>2] = $1976;
       $2093 = (($ptr2$25716$us) + 204|0);
       HEAPF32[$2093>>2] = $1977;
       $2094 = (($ptr2$25716$us) + 208|0);
       HEAPF32[$2094>>2] = $1986;
       $2095 = (($ptr2$25716$us) + 212|0);
       HEAPF32[$2095>>2] = $1987;
       $2096 = (($ptr2$25716$us) + 216|0);
       HEAPF32[$2096>>2] = $1988;
       $2097 = (($ptr2$25716$us) + 220|0);
       HEAPF32[$2097>>2] = $1989;
       $2098 = (($ptr2$25716$us) + 224|0);
       HEAPF32[$2098>>2] = $1998;
       $2099 = (($ptr2$25716$us) + 228|0);
       HEAPF32[$2099>>2] = $1999;
       $2100 = (($ptr2$25716$us) + 232|0);
       HEAPF32[$2100>>2] = $2000;
       $2101 = (($ptr2$25716$us) + 236|0);
       HEAPF32[$2101>>2] = $2001;
       $2102 = Math_fround(-$2042);
       $2103 = Math_fround(-$2043);
       $2104 = Math_fround(-$2044);
       $2105 = Math_fround(-$2045);
       $2106 = (($ptr2$25716$us) + 240|0);
       HEAPF32[$2106>>2] = $2102;
       $2107 = (($ptr2$25716$us) + 244|0);
       HEAPF32[$2107>>2] = $2103;
       $2108 = (($ptr2$25716$us) + 248|0);
       HEAPF32[$2108>>2] = $2104;
       $2109 = (($ptr2$25716$us) + 252|0);
       HEAPF32[$2109>>2] = $2105;
       $2110 = Math_fround(-$2050);
       $2111 = Math_fround(-$2051);
       $2112 = Math_fround(-$2052);
       $2113 = Math_fround(-$2053);
       $2114 = (($ptr2$25716$us) + 256|0);
       HEAPF32[$2114>>2] = $2110;
       $2115 = (($ptr2$25716$us) + 260|0);
       HEAPF32[$2115>>2] = $2111;
       $2116 = (($ptr2$25716$us) + 264|0);
       HEAPF32[$2116>>2] = $2112;
       $2117 = (($ptr2$25716$us) + 268|0);
       HEAPF32[$2117>>2] = $2113;
       $2118 = Math_fround(-$2058);
       $2119 = Math_fround(-$2059);
       $2120 = Math_fround(-$2060);
       $2121 = Math_fround(-$2061);
       $2122 = (($ptr2$25716$us) + 272|0);
       HEAPF32[$2122>>2] = $2118;
       $2123 = (($ptr2$25716$us) + 276|0);
       HEAPF32[$2123>>2] = $2119;
       $2124 = (($ptr2$25716$us) + 280|0);
       HEAPF32[$2124>>2] = $2120;
       $2125 = (($ptr2$25716$us) + 284|0);
       HEAPF32[$2125>>2] = $2121;
       $2126 = $2086 > Math_fround(0.0);
       $2127 = $2087 > Math_fround(0.0);
       $2128 = $2088 > Math_fround(0.0);
       $2129 = $2089 > Math_fround(0.0);
       $2130 = Math_fround(Math_fround(1.0) / $2086);
       $2131 = Math_fround(Math_fround(1.0) / $2087);
       $2132 = Math_fround(Math_fround(1.0) / $2088);
       $2133 = Math_fround(Math_fround(1.0) / $2089);
       HEAPF32[$20>>2] = $2130;
       HEAPF32[$664>>2] = $2131;
       HEAPF32[$665>>2] = $2132;
       HEAPF32[$666>>2] = $2133;
       $b$a$i$us = $2126 ? $20 : $19;
       ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;
       $2134 = Math_fround(HEAPF32[$b$a$i$us>>2]);
       $a$pn4$i$us = $2127 ? $20 : $19;
       $$in1$i$us = (($a$pn4$i$us) + 4|0);
       $2135 = Math_fround(HEAPF32[$$in1$i$us>>2]);
       $b$a7$i$us = $2128 ? $20 : $19;
       $$in2$i$us = (($b$a7$i$us) + 8|0);
       $2136 = Math_fround(HEAPF32[$$in2$i$us>>2]);
       $a$pn6$i$us = $2129 ? $20 : $19;
       $$in3$i$us = (($a$pn6$i$us) + 12|0);
       $2137 = Math_fround(HEAPF32[$$in3$i$us>>2]);
       $2138 = Math_fround(-$2134);
       $2139 = Math_fround(-$2135);
       $2140 = Math_fround(-$2136);
       $2141 = Math_fround(-$2137);
       $2142 = (($ptr2$25716$us) + 144|0);
       $2143 = (($ptr2$25716$us) + 96|0);
       ;HEAP32[$2142+0>>2]=0|0;HEAP32[$2142+4>>2]=0|0;HEAP32[$2142+8>>2]=0|0;HEAP32[$2142+12>>2]=0|0;
       HEAPF32[$2143>>2] = $1922;
       $2144 = (($ptr2$25716$us) + 100|0);
       HEAPF32[$2144>>2] = $1923;
       $2145 = (($ptr2$25716$us) + 104|0);
       HEAPF32[$2145>>2] = $1924;
       $2146 = (($ptr2$25716$us) + 108|0);
       HEAPF32[$2146>>2] = $1925;
       $2147 = (($ptr2$25716$us) + 112|0);
       HEAPF32[$2147>>2] = $1930;
       $2148 = (($ptr2$25716$us) + 116|0);
       HEAPF32[$2148>>2] = $1931;
       $2149 = (($ptr2$25716$us) + 120|0);
       HEAPF32[$2149>>2] = $1932;
       $2150 = (($ptr2$25716$us) + 124|0);
       HEAPF32[$2150>>2] = $1933;
       $2151 = (($ptr2$25716$us) + 128|0);
       HEAPF32[$2151>>2] = $1938;
       $2152 = (($ptr2$25716$us) + 132|0);
       HEAPF32[$2152>>2] = $1939;
       $2153 = (($ptr2$25716$us) + 136|0);
       HEAPF32[$2153>>2] = $1940;
       $2154 = (($ptr2$25716$us) + 140|0);
       HEAPF32[$2154>>2] = $1941;
       $2155 = (($ptr2$25716$us) + 48|0);
       HEAPF32[$2155>>2] = $1854;
       $2156 = (($ptr2$25716$us) + 52|0);
       HEAPF32[$2156>>2] = $1855;
       $2157 = (($ptr2$25716$us) + 56|0);
       HEAPF32[$2157>>2] = $1856;
       $2158 = (($ptr2$25716$us) + 60|0);
       HEAPF32[$2158>>2] = $1857;
       $2159 = (($ptr2$25716$us) + 64|0);
       HEAPF32[$2159>>2] = $1866;
       $2160 = (($ptr2$25716$us) + 68|0);
       HEAPF32[$2160>>2] = $1867;
       $2161 = (($ptr2$25716$us) + 72|0);
       HEAPF32[$2161>>2] = $1868;
       $2162 = (($ptr2$25716$us) + 76|0);
       HEAPF32[$2162>>2] = $1869;
       $2163 = (($ptr2$25716$us) + 80|0);
       HEAPF32[$2163>>2] = $1878;
       $2164 = (($ptr2$25716$us) + 84|0);
       HEAPF32[$2164>>2] = $1879;
       $2165 = (($ptr2$25716$us) + 88|0);
       HEAPF32[$2165>>2] = $1880;
       $2166 = (($ptr2$25716$us) + 92|0);
       HEAPF32[$2166>>2] = $1881;
       $2167 = (($ptr2$25716$us) + 160|0);
       HEAPF32[$2167>>2] = $2138;
       $2168 = (($ptr2$25716$us) + 164|0);
       HEAPF32[$2168>>2] = $2139;
       $2169 = (($ptr2$25716$us) + 168|0);
       HEAPF32[$2169>>2] = $2140;
       $2170 = (($ptr2$25716$us) + 172|0);
       HEAPF32[$2170>>2] = $2141;
       $2171 = Math_fround($1808 * $1822);
       $2172 = Math_fround($1811 * $1824);
       $2173 = Math_fround($1814 * $1826);
       $2174 = Math_fround($1817 * $1828);
       $2175 = Math_fround($1809 * $1830);
       $2176 = Math_fround($1812 * $1832);
       $2177 = Math_fround($1815 * $1834);
       $2178 = Math_fround($1818 * $1836);
       $2179 = Math_fround($2171 + $2175);
       $2180 = Math_fround($2172 + $2176);
       $2181 = Math_fround($2173 + $2177);
       $2182 = Math_fround($2174 + $2178);
       $2183 = Math_fround($1810 * $1838);
       $2184 = Math_fround($1813 * $1840);
       $2185 = Math_fround($1816 * $1842);
       $2186 = Math_fround($1819 * $1844);
       $2187 = Math_fround($2179 + $2183);
       $2188 = Math_fround($2180 + $2184);
       $2189 = Math_fround($2181 + $2185);
       $2190 = Math_fround($2182 + $2186);
       $2191 = (($ptr2$25716$us) + 176|0);
       HEAPF32[$2191>>2] = $2187;
       $2192 = (($ptr2$25716$us) + 180|0);
       HEAPF32[$2192>>2] = $2188;
       $2193 = (($ptr2$25716$us) + 184|0);
       HEAPF32[$2193>>2] = $2189;
       $2194 = (($ptr2$25716$us) + 188|0);
       HEAPF32[$2194>>2] = $2190;
       HEAPF32[$ptr2$25716$us>>2] = $1822;
       $2195 = (($ptr2$25716$us) + 4|0);
       HEAPF32[$2195>>2] = $1824;
       $2196 = (($ptr2$25716$us) + 8|0);
       HEAPF32[$2196>>2] = $1826;
       $2197 = (($ptr2$25716$us) + 12|0);
       HEAPF32[$2197>>2] = $1828;
       $2198 = (($ptr2$25716$us) + 16|0);
       HEAPF32[$2198>>2] = $1830;
       $2199 = (($ptr2$25716$us) + 20|0);
       HEAPF32[$2199>>2] = $1832;
       $2200 = (($ptr2$25716$us) + 24|0);
       HEAPF32[$2200>>2] = $1834;
       $2201 = (($ptr2$25716$us) + 28|0);
       HEAPF32[$2201>>2] = $1836;
       $2202 = (($ptr2$25716$us) + 32|0);
       HEAPF32[$2202>>2] = $1838;
       $2203 = (($ptr2$25716$us) + 36|0);
       HEAPF32[$2203>>2] = $1840;
       $2204 = (($ptr2$25716$us) + 40|0);
       HEAPF32[$2204>>2] = $1842;
       $2205 = (($ptr2$25716$us) + 44|0);
       HEAPF32[$2205>>2] = $1844;
       $2206 = (($a$05717$us) + 1)|0;
       $exitcond5756 = ($2206|0)==($numFrictionPerPoint|0);
       if ($exitcond5756) {
        $split5718 = $1845;
        break;
       } else {
        $a$05717$us = $2206;$fricIndex$15715$us = $1845;$ptr2$25716$us = $1820;
       }
      }
     } else {
      $a$05717 = 0;$fricIndex$15715 = $fricIndex$0;$ptr2$25716 = $ptr2$1;
      while(1) {
       $2207 = (($ptr2$25716) + ($54)|0);
       $2208 = (($tFallbackX) + ($fricIndex$15715<<4)|0);
       $2209 = Math_fround(HEAPF32[$2208>>2]);
       $2210 = ((($tFallbackX) + ($fricIndex$15715<<4)|0) + 4|0);
       $2211 = Math_fround(HEAPF32[$2210>>2]);
       $2212 = ((($tFallbackX) + ($fricIndex$15715<<4)|0) + 8|0);
       $2213 = Math_fround(HEAPF32[$2212>>2]);
       $2214 = ((($tFallbackX) + ($fricIndex$15715<<4)|0) + 12|0);
       $2215 = Math_fround(HEAPF32[$2214>>2]);
       $2216 = (($tFallbackY) + ($fricIndex$15715<<4)|0);
       $2217 = Math_fround(HEAPF32[$2216>>2]);
       $2218 = ((($tFallbackY) + ($fricIndex$15715<<4)|0) + 4|0);
       $2219 = Math_fround(HEAPF32[$2218>>2]);
       $2220 = ((($tFallbackY) + ($fricIndex$15715<<4)|0) + 8|0);
       $2221 = Math_fround(HEAPF32[$2220>>2]);
       $2222 = ((($tFallbackY) + ($fricIndex$15715<<4)|0) + 12|0);
       $2223 = Math_fround(HEAPF32[$2222>>2]);
       $2224 = (($tFallbackZ) + ($fricIndex$15715<<4)|0);
       $2225 = Math_fround(HEAPF32[$2224>>2]);
       $2226 = ((($tFallbackZ) + ($fricIndex$15715<<4)|0) + 4|0);
       $2227 = Math_fround(HEAPF32[$2226>>2]);
       $2228 = ((($tFallbackZ) + ($fricIndex$15715<<4)|0) + 8|0);
       $2229 = Math_fround(HEAPF32[$2228>>2]);
       $2230 = ((($tFallbackZ) + ($fricIndex$15715<<4)|0) + 12|0);
       $2231 = Math_fround(HEAPF32[$2230>>2]);
       $2232 = (1 - ($fricIndex$15715))|0;
       $2233 = Math_fround($1348 * $2225);
       $2234 = Math_fround($1349 * $2227);
       $2235 = Math_fround($1350 * $2229);
       $2236 = Math_fround($1351 * $2231);
       $2237 = Math_fround($1352 * $2217);
       $2238 = Math_fround($1353 * $2219);
       $2239 = Math_fround($1354 * $2221);
       $2240 = Math_fround($1355 * $2223);
       $2241 = Math_fround($2233 - $2237);
       $2242 = Math_fround($2234 - $2238);
       $2243 = Math_fround($2235 - $2239);
       $2244 = Math_fround($2236 - $2240);
       $2245 = Math_fround($1352 * $2209);
       $2246 = Math_fround($1353 * $2211);
       $2247 = Math_fround($1354 * $2213);
       $2248 = Math_fround($1355 * $2215);
       $2249 = Math_fround($1344 * $2225);
       $2250 = Math_fround($1345 * $2227);
       $2251 = Math_fround($1346 * $2229);
       $2252 = Math_fround($1347 * $2231);
       $2253 = Math_fround($2245 - $2249);
       $2254 = Math_fround($2246 - $2250);
       $2255 = Math_fround($2247 - $2251);
       $2256 = Math_fround($2248 - $2252);
       $2257 = Math_fround($1344 * $2217);
       $2258 = Math_fround($1345 * $2219);
       $2259 = Math_fround($1346 * $2221);
       $2260 = Math_fround($1347 * $2223);
       $2261 = Math_fround($1348 * $2209);
       $2262 = Math_fround($1349 * $2211);
       $2263 = Math_fround($1350 * $2213);
       $2264 = Math_fround($1351 * $2215);
       $2265 = Math_fround($2257 - $2261);
       $2266 = Math_fround($2258 - $2262);
       $2267 = Math_fround($2259 - $2263);
       $2268 = Math_fround($2260 - $2264);
       $2269 = Math_fround($441 * $2241);
       $2270 = Math_fround($442 * $2242);
       $2271 = Math_fround($443 * $2243);
       $2272 = Math_fround($444 * $2244);
       $2273 = Math_fround($453 * $2241);
       $2274 = Math_fround($454 * $2242);
       $2275 = Math_fround($455 * $2243);
       $2276 = Math_fround($456 * $2244);
       $2277 = Math_fround($465 * $2241);
       $2278 = Math_fround($466 * $2242);
       $2279 = Math_fround($467 * $2243);
       $2280 = Math_fround($468 * $2244);
       $2281 = Math_fround($445 * $2253);
       $2282 = Math_fround($446 * $2254);
       $2283 = Math_fround($447 * $2255);
       $2284 = Math_fround($448 * $2256);
       $2285 = Math_fround($2281 + $2269);
       $2286 = Math_fround($2282 + $2270);
       $2287 = Math_fround($2283 + $2271);
       $2288 = Math_fround($2284 + $2272);
       $2289 = Math_fround($457 * $2253);
       $2290 = Math_fround($458 * $2254);
       $2291 = Math_fround($459 * $2255);
       $2292 = Math_fround($460 * $2256);
       $2293 = Math_fround($2289 + $2273);
       $2294 = Math_fround($2290 + $2274);
       $2295 = Math_fround($2291 + $2275);
       $2296 = Math_fround($2292 + $2276);
       $2297 = Math_fround($469 * $2253);
       $2298 = Math_fround($470 * $2254);
       $2299 = Math_fround($471 * $2255);
       $2300 = Math_fround($472 * $2256);
       $2301 = Math_fround($2297 + $2277);
       $2302 = Math_fround($2298 + $2278);
       $2303 = Math_fround($2299 + $2279);
       $2304 = Math_fround($2300 + $2280);
       $2305 = Math_fround($449 * $2265);
       $2306 = Math_fround($450 * $2266);
       $2307 = Math_fround($451 * $2267);
       $2308 = Math_fround($452 * $2268);
       $2309 = Math_fround($2305 + $2285);
       $2310 = Math_fround($2306 + $2286);
       $2311 = Math_fround($2307 + $2287);
       $2312 = Math_fround($2308 + $2288);
       $2313 = Math_fround($461 * $2265);
       $2314 = Math_fround($462 * $2266);
       $2315 = Math_fround($463 * $2267);
       $2316 = Math_fround($464 * $2268);
       $2317 = Math_fround($2313 + $2293);
       $2318 = Math_fround($2314 + $2294);
       $2319 = Math_fround($2315 + $2295);
       $2320 = Math_fround($2316 + $2296);
       $2321 = Math_fround($473 * $2265);
       $2322 = Math_fround($474 * $2266);
       $2323 = Math_fround($475 * $2267);
       $2324 = Math_fround($476 * $2268);
       $2325 = Math_fround($2321 + $2301);
       $2326 = Math_fround($2322 + $2302);
       $2327 = Math_fround($2323 + $2303);
       $2328 = Math_fround($2324 + $2304);
       $2329 = Math_fround($2241 * $2309);
       $2330 = Math_fround($2242 * $2310);
       $2331 = Math_fround($2243 * $2311);
       $2332 = Math_fround($2244 * $2312);
       $2333 = Math_fround($2253 * $2317);
       $2334 = Math_fround($2254 * $2318);
       $2335 = Math_fround($2255 * $2319);
       $2336 = Math_fround($2256 * $2320);
       $2337 = Math_fround($2333 + $2329);
       $2338 = Math_fround($2334 + $2330);
       $2339 = Math_fround($2335 + $2331);
       $2340 = Math_fround($2336 + $2332);
       $2341 = Math_fround($2265 * $2325);
       $2342 = Math_fround($2266 * $2326);
       $2343 = Math_fround($2267 * $2327);
       $2344 = Math_fround($2268 * $2328);
       $2345 = Math_fround($2341 + $2337);
       $2346 = Math_fround($2342 + $2338);
       $2347 = Math_fround($2343 + $2339);
       $2348 = Math_fround($2344 + $2340);
       $2349 = Math_fround($293 + $2345);
       $2350 = Math_fround($294 + $2346);
       $2351 = Math_fround($295 + $2347);
       $2352 = Math_fround($296 + $2348);
       $2353 = $2349 > Math_fround(0.0);
       $2354 = $2350 > Math_fround(0.0);
       $2355 = $2351 > Math_fround(0.0);
       $2356 = $2352 > Math_fround(0.0);
       $2357 = Math_fround(Math_fround(1.0) / $2349);
       $2358 = Math_fround(Math_fround(1.0) / $2350);
       $2359 = Math_fround(Math_fround(1.0) / $2351);
       $2360 = Math_fround(Math_fround(1.0) / $2352);
       HEAPF32[$20>>2] = $2357;
       HEAPF32[$664>>2] = $2358;
       HEAPF32[$665>>2] = $2359;
       HEAPF32[$666>>2] = $2360;
       $b$a$i = $2353 ? $20 : $19;
       ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;
       $2361 = Math_fround(HEAPF32[$b$a$i>>2]);
       $a$pn4$i = $2354 ? $20 : $19;
       $$in1$i = (($a$pn4$i) + 4|0);
       $2362 = Math_fround(HEAPF32[$$in1$i>>2]);
       $b$a7$i = $2355 ? $20 : $19;
       $$in2$i = (($b$a7$i) + 8|0);
       $2363 = Math_fround(HEAPF32[$$in2$i>>2]);
       $a$pn6$i = $2356 ? $20 : $19;
       $$in3$i = (($a$pn6$i) + 12|0);
       $2364 = Math_fround(HEAPF32[$$in3$i>>2]);
       $2365 = Math_fround(-$2361);
       $2366 = Math_fround(-$2362);
       $2367 = Math_fround(-$2363);
       $2368 = Math_fround(-$2364);
       $2369 = (($ptr2$25716) + 144|0);
       $2370 = (($ptr2$25716) + 96|0);
       ;HEAP32[$2369+0>>2]=0|0;HEAP32[$2369+4>>2]=0|0;HEAP32[$2369+8>>2]=0|0;HEAP32[$2369+12>>2]=0|0;
       HEAPF32[$2370>>2] = $2309;
       $2371 = (($ptr2$25716) + 100|0);
       HEAPF32[$2371>>2] = $2310;
       $2372 = (($ptr2$25716) + 104|0);
       HEAPF32[$2372>>2] = $2311;
       $2373 = (($ptr2$25716) + 108|0);
       HEAPF32[$2373>>2] = $2312;
       $2374 = (($ptr2$25716) + 112|0);
       HEAPF32[$2374>>2] = $2317;
       $2375 = (($ptr2$25716) + 116|0);
       HEAPF32[$2375>>2] = $2318;
       $2376 = (($ptr2$25716) + 120|0);
       HEAPF32[$2376>>2] = $2319;
       $2377 = (($ptr2$25716) + 124|0);
       HEAPF32[$2377>>2] = $2320;
       $2378 = (($ptr2$25716) + 128|0);
       HEAPF32[$2378>>2] = $2325;
       $2379 = (($ptr2$25716) + 132|0);
       HEAPF32[$2379>>2] = $2326;
       $2380 = (($ptr2$25716) + 136|0);
       HEAPF32[$2380>>2] = $2327;
       $2381 = (($ptr2$25716) + 140|0);
       HEAPF32[$2381>>2] = $2328;
       $2382 = (($ptr2$25716) + 48|0);
       HEAPF32[$2382>>2] = $2241;
       $2383 = (($ptr2$25716) + 52|0);
       HEAPF32[$2383>>2] = $2242;
       $2384 = (($ptr2$25716) + 56|0);
       HEAPF32[$2384>>2] = $2243;
       $2385 = (($ptr2$25716) + 60|0);
       HEAPF32[$2385>>2] = $2244;
       $2386 = (($ptr2$25716) + 64|0);
       HEAPF32[$2386>>2] = $2253;
       $2387 = (($ptr2$25716) + 68|0);
       HEAPF32[$2387>>2] = $2254;
       $2388 = (($ptr2$25716) + 72|0);
       HEAPF32[$2388>>2] = $2255;
       $2389 = (($ptr2$25716) + 76|0);
       HEAPF32[$2389>>2] = $2256;
       $2390 = (($ptr2$25716) + 80|0);
       HEAPF32[$2390>>2] = $2265;
       $2391 = (($ptr2$25716) + 84|0);
       HEAPF32[$2391>>2] = $2266;
       $2392 = (($ptr2$25716) + 88|0);
       HEAPF32[$2392>>2] = $2267;
       $2393 = (($ptr2$25716) + 92|0);
       HEAPF32[$2393>>2] = $2268;
       $2394 = (($ptr2$25716) + 160|0);
       HEAPF32[$2394>>2] = $2365;
       $2395 = (($ptr2$25716) + 164|0);
       HEAPF32[$2395>>2] = $2366;
       $2396 = (($ptr2$25716) + 168|0);
       HEAPF32[$2396>>2] = $2367;
       $2397 = (($ptr2$25716) + 172|0);
       HEAPF32[$2397>>2] = $2368;
       $2398 = Math_fround($1808 * $2209);
       $2399 = Math_fround($1811 * $2211);
       $2400 = Math_fround($1814 * $2213);
       $2401 = Math_fround($1817 * $2215);
       $2402 = Math_fround($1809 * $2217);
       $2403 = Math_fround($1812 * $2219);
       $2404 = Math_fround($1815 * $2221);
       $2405 = Math_fround($1818 * $2223);
       $2406 = Math_fround($2398 + $2402);
       $2407 = Math_fround($2399 + $2403);
       $2408 = Math_fround($2400 + $2404);
       $2409 = Math_fround($2401 + $2405);
       $2410 = Math_fround($1810 * $2225);
       $2411 = Math_fround($1813 * $2227);
       $2412 = Math_fround($1816 * $2229);
       $2413 = Math_fround($1819 * $2231);
       $2414 = Math_fround($2406 + $2410);
       $2415 = Math_fround($2407 + $2411);
       $2416 = Math_fround($2408 + $2412);
       $2417 = Math_fround($2409 + $2413);
       $2418 = (($ptr2$25716) + 176|0);
       HEAPF32[$2418>>2] = $2414;
       $2419 = (($ptr2$25716) + 180|0);
       HEAPF32[$2419>>2] = $2415;
       $2420 = (($ptr2$25716) + 184|0);
       HEAPF32[$2420>>2] = $2416;
       $2421 = (($ptr2$25716) + 188|0);
       HEAPF32[$2421>>2] = $2417;
       HEAPF32[$ptr2$25716>>2] = $2209;
       $2422 = (($ptr2$25716) + 4|0);
       HEAPF32[$2422>>2] = $2211;
       $2423 = (($ptr2$25716) + 8|0);
       HEAPF32[$2423>>2] = $2213;
       $2424 = (($ptr2$25716) + 12|0);
       HEAPF32[$2424>>2] = $2215;
       $2425 = (($ptr2$25716) + 16|0);
       HEAPF32[$2425>>2] = $2217;
       $2426 = (($ptr2$25716) + 20|0);
       HEAPF32[$2426>>2] = $2219;
       $2427 = (($ptr2$25716) + 24|0);
       HEAPF32[$2427>>2] = $2221;
       $2428 = (($ptr2$25716) + 28|0);
       HEAPF32[$2428>>2] = $2223;
       $2429 = (($ptr2$25716) + 32|0);
       HEAPF32[$2429>>2] = $2225;
       $2430 = (($ptr2$25716) + 36|0);
       HEAPF32[$2430>>2] = $2227;
       $2431 = (($ptr2$25716) + 40|0);
       HEAPF32[$2431>>2] = $2229;
       $2432 = (($ptr2$25716) + 44|0);
       HEAPF32[$2432>>2] = $2231;
       $2433 = (($a$05717) + 1)|0;
       $exitcond = ($2433|0)==($numFrictionPerPoint|0);
       if ($exitcond) {
        $split5718 = $2232;
        break;
       } else {
        $a$05717 = $2433;$fricIndex$15715 = $2232;$ptr2$25716 = $2207;
       }
      }
     }
     $split = (($ptr2$1) + ($671)|0);
     $fricIndex$1$lcssa = $split5718;$ptr2$2$lcssa = $split;
    }
    $2434 = $newFinished$0 & 1;
    $2435 = ($2434|0)==(0);
    if ($2435) {
     $2436 = (($2437) + 1)|0;
     $2438 = ($newPatch$0$lcssa$i$i6895682|0)==(65535);
     do {
      if ($2438) {
       $2453 = 0;$newContact$0$lcssa$i225684 = $2436;$newPatch$0$lcssa$i235685 = 65535;
      } else {
       $newContact$02$i20 = $2436;$newPatch$01$i21 = $newPatch$0$lcssa$i$i6895682;
       while(1) {
        $2439 = ((($c) + (($newPatch$01$i21*12)|0)|0) + 2|0);
        $2440 = HEAP16[$2439>>1]|0;
        $2441 = $2440&65535;
        $2442 = ($newContact$02$i20|0)==($2441|0);
        if (!($2442)) {
         $newContact$0$lcssa$i22 = $newContact$02$i20;$newPatch$0$lcssa$i23 = $newPatch$01$i21;
         break;
        }
        $2443 = ((($c) + (($newPatch$01$i21*12)|0)|0) + 4|0);
        $2444 = HEAP16[$2443>>1]|0;
        $2445 = $2444&65535;
        $2446 = ($2444<<16>>16)==(-1);
        if ($2446) {
         $newContact$0$lcssa$i22 = 0;$newPatch$0$lcssa$i23 = $2445;
         break;
        } else {
         $newContact$02$i20 = 0;$newPatch$01$i21 = $2445;
        }
       }
       $2447 = ($newPatch$0$lcssa$i23|0)==(65535);
       if ($2447) {
        $2453 = 0;$newContact$0$lcssa$i225684 = $newContact$0$lcssa$i22;$newPatch$0$lcssa$i235685 = 65535;
        break;
       }
       $2448 = ((($c) + (($newPatch$0$lcssa$i23*12)|0)|0) + 2|0);
       $2449 = HEAP16[$2448>>1]|0;
       $2450 = $2449&65535;
       $2451 = ($newContact$0$lcssa$i22>>>0)<($2450>>>0);
       $2453 = $2451;$newContact$0$lcssa$i225684 = $newContact$0$lcssa$i22;$newPatch$0$lcssa$i235685 = $newPatch$0$lcssa$i23;
      }
     } while(0);
     $2452 = $2453&1;
     $2454 = $2452 ^ 1;
     $2455 = $2454 | $newFinished$0;
     $2526 = $newContact$0$lcssa$i225684;$2527 = $2437;$2528 = $newPatch$0$lcssa$i$i6895682;$newFinished$1 = $2455;$newPatch$0$lcssa$i$i6895683 = $newPatch$0$lcssa$i235685;
    } else {
     $2526 = $2437;$2527 = $1244;$2528 = $1240;$newFinished$1 = $newFinished$0;$newPatch$0$lcssa$i$i6895683 = $newPatch$0$lcssa$i$i6895682;
    }
    $2456 = $newFinished$0 & 2;
    $2457 = ($2456|0)==(0);
    if ($2457) {
     $2458 = (($2459) + 1)|0;
     $2460 = ($newPatch$0$lcssa$i$i6855680|0)==(65535);
     do {
      if ($2460) {
       $2475 = 0;$newContact$0$lcssa$i155686 = $2458;$newPatch$0$lcssa$i165687 = 65535;
      } else {
       $newContact$02$i13 = $2458;$newPatch$01$i14 = $newPatch$0$lcssa$i$i6855680;
       while(1) {
        $2461 = ((($c) + (($newPatch$01$i14*12)|0)|0) + 2|0);
        $2462 = HEAP16[$2461>>1]|0;
        $2463 = $2462&65535;
        $2464 = ($newContact$02$i13|0)==($2463|0);
        if (!($2464)) {
         $newContact$0$lcssa$i15 = $newContact$02$i13;$newPatch$0$lcssa$i16 = $newPatch$01$i14;
         break;
        }
        $2465 = ((($c) + (($newPatch$01$i14*12)|0)|0) + 4|0);
        $2466 = HEAP16[$2465>>1]|0;
        $2467 = $2466&65535;
        $2468 = ($2466<<16>>16)==(-1);
        if ($2468) {
         $newContact$0$lcssa$i15 = 0;$newPatch$0$lcssa$i16 = $2467;
         break;
        } else {
         $newContact$02$i13 = 0;$newPatch$01$i14 = $2467;
        }
       }
       $2469 = ($newPatch$0$lcssa$i16|0)==(65535);
       if ($2469) {
        $2475 = 0;$newContact$0$lcssa$i155686 = $newContact$0$lcssa$i15;$newPatch$0$lcssa$i165687 = 65535;
        break;
       }
       $2470 = ((($c) + (($newPatch$0$lcssa$i16*12)|0)|0) + 2|0);
       $2471 = HEAP16[$2470>>1]|0;
       $2472 = $2471&65535;
       $2473 = ($newContact$0$lcssa$i15>>>0)<($2472>>>0);
       $2475 = $2473;$newContact$0$lcssa$i155686 = $newContact$0$lcssa$i15;$newPatch$0$lcssa$i165687 = $newPatch$0$lcssa$i16;
      }
     } while(0);
     $2474 = $2475&1;
     $2476 = $2474 << 1;
     $2477 = $2476 ^ 2;
     $2478 = $2477 | $newFinished$1;
     $2529 = $newContact$0$lcssa$i155686;$2530 = $2459;$2531 = $newPatch$0$lcssa$i$i6855680;$newFinished$2 = $2478;$newPatch$0$lcssa$i$i6855681 = $newPatch$0$lcssa$i165687;
    } else {
     $2529 = $2459;$2530 = $1250;$2531 = $1246;$newFinished$2 = $newFinished$1;$newPatch$0$lcssa$i$i6855681 = $newPatch$0$lcssa$i$i6855680;
    }
    $2479 = $newFinished$0 & 4;
    $2480 = ($2479|0)==(0);
    if ($2480) {
     $2481 = (($2482) + 1)|0;
     $2483 = ($newPatch$0$lcssa$i$i6815678|0)==(65535);
     do {
      if ($2483) {
       $2498 = 0;$newContact$0$lcssa$i85688 = $2481;$newPatch$0$lcssa$i95689 = 65535;
      } else {
       $newContact$02$i6 = $2481;$newPatch$01$i7 = $newPatch$0$lcssa$i$i6815678;
       while(1) {
        $2484 = ((($c) + (($newPatch$01$i7*12)|0)|0) + 2|0);
        $2485 = HEAP16[$2484>>1]|0;
        $2486 = $2485&65535;
        $2487 = ($newContact$02$i6|0)==($2486|0);
        if (!($2487)) {
         $newContact$0$lcssa$i8 = $newContact$02$i6;$newPatch$0$lcssa$i9 = $newPatch$01$i7;
         break;
        }
        $2488 = ((($c) + (($newPatch$01$i7*12)|0)|0) + 4|0);
        $2489 = HEAP16[$2488>>1]|0;
        $2490 = $2489&65535;
        $2491 = ($2489<<16>>16)==(-1);
        if ($2491) {
         $newContact$0$lcssa$i8 = 0;$newPatch$0$lcssa$i9 = $2490;
         break;
        } else {
         $newContact$02$i6 = 0;$newPatch$01$i7 = $2490;
        }
       }
       $2492 = ($newPatch$0$lcssa$i9|0)==(65535);
       if ($2492) {
        $2498 = 0;$newContact$0$lcssa$i85688 = $newContact$0$lcssa$i8;$newPatch$0$lcssa$i95689 = 65535;
        break;
       }
       $2493 = ((($c) + (($newPatch$0$lcssa$i9*12)|0)|0) + 2|0);
       $2494 = HEAP16[$2493>>1]|0;
       $2495 = $2494&65535;
       $2496 = ($newContact$0$lcssa$i8>>>0)<($2495>>>0);
       $2498 = $2496;$newContact$0$lcssa$i85688 = $newContact$0$lcssa$i8;$newPatch$0$lcssa$i95689 = $newPatch$0$lcssa$i9;
      }
     } while(0);
     $2497 = $2498&1;
     $2499 = $2497 << 2;
     $2500 = $2499 ^ 4;
     $2501 = $2500 | $newFinished$2;
     $2532 = $newContact$0$lcssa$i85688;$2533 = $2482;$2534 = $newPatch$0$lcssa$i$i6815678;$newFinished$3 = $2501;$newPatch$0$lcssa$i$i6815679 = $newPatch$0$lcssa$i95689;
    } else {
     $2532 = $2482;$2533 = $1256;$2534 = $1252;$newFinished$3 = $newFinished$2;$newPatch$0$lcssa$i$i6815679 = $newPatch$0$lcssa$i$i6815678;
    }
    $2502 = $newFinished$0 & 8;
    $2503 = ($2502|0)==(0);
    if ($2503) {
     break;
    } else {
     $finished$0$phi = $newFinished$0;$1240 = $2528;$1244 = $2527;$1246 = $2531;$1250 = $2530;$1252 = $2534;$1256 = $2533;$2437 = $2526;$2459 = $2529;$2482 = $2532;$fricIndex$0 = $fricIndex$1$lcssa;$newFinished$0 = $newFinished$3;$newPatch$0$lcssa$i$i6815678 = $newPatch$0$lcssa$i$i6815679;$newPatch$0$lcssa$i$i6855680 = $newPatch$0$lcssa$i$i6855681;$newPatch$0$lcssa$i$i6895682 = $newPatch$0$lcssa$i$i6895683;$p$0 = $1238;$ptr2$1 = $ptr2$2$lcssa;$finished$0 = $finished$0$phi;
    }
   }
   $2504 = (($$ph5721) + 1)|0;
   $2505 = ($newPatch$0$lcssa$i$i5677$ph|0)==(65535);
   do {
    if ($2505) {
     $2520 = 0;$newContact$0$lcssa$i5690 = $2504;$newPatch$0$lcssa$i5691 = 65535;
    } else {
     $newContact$02$i = $2504;$newPatch$01$i = $newPatch$0$lcssa$i$i5677$ph;
     while(1) {
      $2506 = ((($c) + (($newPatch$01$i*12)|0)|0) + 2|0);
      $2507 = HEAP16[$2506>>1]|0;
      $2508 = $2507&65535;
      $2509 = ($newContact$02$i|0)==($2508|0);
      if (!($2509)) {
       $newContact$0$lcssa$i = $newContact$02$i;$newPatch$0$lcssa$i = $newPatch$01$i;
       break;
      }
      $2510 = ((($c) + (($newPatch$01$i*12)|0)|0) + 4|0);
      $2511 = HEAP16[$2510>>1]|0;
      $2512 = $2511&65535;
      $2513 = ($2511<<16>>16)==(-1);
      if ($2513) {
       $newContact$0$lcssa$i = 0;$newPatch$0$lcssa$i = $2512;
       break;
      } else {
       $newContact$02$i = 0;$newPatch$01$i = $2512;
      }
     }
     $2514 = ($newPatch$0$lcssa$i|0)==(65535);
     if ($2514) {
      $2520 = 0;$newContact$0$lcssa$i5690 = $newContact$0$lcssa$i;$newPatch$0$lcssa$i5691 = 65535;
      break;
     }
     $2515 = ((($c) + (($newPatch$0$lcssa$i*12)|0)|0) + 2|0);
     $2516 = HEAP16[$2515>>1]|0;
     $2517 = $2516&65535;
     $2518 = ($newContact$0$lcssa$i>>>0)<($2517>>>0);
     $2520 = $2518;$newContact$0$lcssa$i5690 = $newContact$0$lcssa$i;$newPatch$0$lcssa$i5691 = $newPatch$0$lcssa$i;
    }
   } while(0);
   $2519 = $2520&1;
   $2521 = $2519 << 3;
   $2522 = $2521 ^ 8;
   $2523 = $2522 | $newFinished$3;
   $$ph5729$phi = $newPatch$0$lcssa$i$i5677$ph;$$ph5725$phi = $$ph5721;$$ph = $2526;$$ph5719 = $2529;$$ph5720 = $2532;$$ph5721 = $newContact$0$lcssa$i5690;$$ph5722 = $2527;$$ph5723 = $2530;$$ph5724 = $2533;$$ph5726 = $2528;$$ph5727 = $2531;$$ph5728 = $2534;$finished$0$ph = $newFinished$0;$fricIndex$0$ph = $fricIndex$1$lcssa;$newFinished$0$ph = $2523;$newPatch$0$lcssa$i$i5677$ph = $newPatch$0$lcssa$i5691;$newPatch$0$lcssa$i$i6815678$ph = $newPatch$0$lcssa$i$i6815679;$newPatch$0$lcssa$i$i6855680$ph = $newPatch$0$lcssa$i$i6855681;$newPatch$0$lcssa$i$i6895682$ph = $newPatch$0$lcssa$i$i6895683;$p$0$ph = $1238;$ptr2$1$ph = $ptr2$2$lcssa;$$ph5729 = $$ph5729$phi;$$ph5725 = $$ph5725$phi;
  }
  $2524 = (($i$05743) + 1)|0;
  $2525 = ($2524>>>0)<($593>>>0);
  if ($2525) {
   $frictionIndex0$05748 = $689;$frictionIndex1$05747 = $692;$frictionIndex2$05746 = $695;$frictionIndex3$05745 = $698;$i$05743 = $2524;$ptr$05749 = $p$0;$ptr2$05744 = $ptr2$1;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN5physx37setupFinalizeSolverConstraintsCoulombERNS_13PxcNpWorkUnitERKNS_2Gu13ContactBufferERKNS_27PxcCorrelationBufferCoulombERKNS_11PxTransformESB_bPhRKNS_13PxcSolverBodyESF_RKNS_17PxcSolverBodyDataESI_ffjffff($n,$buffer,$c,$bodyFrame0,$bodyFrame1,$0,$workspace,$b0,$b1,$data0,$data1,$invDtF32,$bounceThresholdF32,$frictionPerPointCount,$invMassScale0,$invInertiaScale0,$invMassScale1,$invInertiaScale1) {
 $n = $n|0;
 $buffer = $buffer|0;
 $c = $c|0;
 $bodyFrame0 = $bodyFrame0|0;
 $bodyFrame1 = $bodyFrame1|0;
 $0 = $0|0;
 $workspace = $workspace|0;
 $b0 = $b0|0;
 $b1 = $b1|0;
 $data0 = $data0|0;
 $data1 = $data1|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $frictionPerPointCount = $frictionPerPointCount|0;
 $invMassScale0 = Math_fround($invMassScale0);
 $invInertiaScale0 = Math_fround($invInertiaScale0);
 $invMassScale1 = Math_fround($invMassScale1);
 $invInertiaScale1 = Math_fround($invInertiaScale1);
 var $$$i = Math_fround(0), $$$i$us = Math_fround(0), $$$i407 = Math_fround(0), $$$us = 0, $$in1$i = 0, $$in1$i143 = 0, $$in2$i = 0, $$in2$i145 = 0, $$lcssa1647 = Math_fround(0), $$lcssa1648 = Math_fround(0), $$lcssa1649 = Math_fround(0), $$lcssa1650 = Math_fround(0), $$lcssa1651 = Math_fround(0), $$lcssa1652 = Math_fround(0), $$lobit = 0, $$pn = 0, $$pre$pre = 0, $$sum = 0, $$sum1629 = 0, $$sum1630 = 0;
 var $$sum1631 = 0, $$sum7$us = 0, $$sum8 = 0, $$sum8$us = 0, $$tr = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0);
 var $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0;
 var $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0;
 var $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0);
 var $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0);
 var $509 = 0, $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = 0, $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0);
 var $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0);
 var $545 = Math_fround(0), $546 = Math_fround(0), $547 = 0, $548 = Math_fround(0), $549 = 0, $55 = 0, $550 = Math_fround(0), $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0);
 var $563 = Math_fround(0), $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = Math_fround(0), $576 = Math_fround(0), $576$phi = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $579$phi = Math_fround(0);
 var $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $583$phi = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0);
 var $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0);
 var $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0);
 var $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = 0, $647 = Math_fround(0), $648 = Math_fround(0), $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = Math_fround(0), $679 = 0, $68 = Math_fround(0), $680 = Math_fround(0), $681 = 0, $682 = Math_fround(0), $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0);
 var $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $707$phi = Math_fround(0), $708 = Math_fround(0), $708$phi = Math_fround(0), $709 = Math_fround(0), $709$phi = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0);
 var $b$a$i108 = 0, $b$a$i140 = 0, $exitcond = 0, $exitcond1707 = 0, $exitcond1708 = 0, $exitcond1709 = 0, $exitcond1712 = 0, $exitcond1715 = 0, $exitcond1716 = 0, $fabsf$i$i$i = Math_fround(0), $hasFriction$0$off0$lcssa = 0, $hasFriction$0$off01677 = 0, $hasFriction$1$off01670 = 0, $hasFriction$2$off0$lcssa = 0, $hasFriction$3$off0 = 0, $i$01696 = 0, $i1$01676 = 0, $j$01684 = 0, $j$01684$us = 0, $j11$01654 = 0;
 var $j11$01654$us = 0, $k$01640$us = 0, $p$0$lcssa = 0, $p$01685 = 0, $p$01685$us = 0, $p10$0$lcssa = 0, $p10$01653$us = 0, $p10$11639$us = 0, $patch$01691 = 0, $patch7$01669 = 0, $phitmp = 0, $phitmp1628 = 0, $ptr$01697 = 0, $ptr$11692 = 0, $ptr$2 = 0, $ptr$3$lcssa = 0, $ptr$31679 = 0, $ptr$41671 = 0, $ptr$5 = 0, $ptr2$01678 = 0;
 var $ptr2$1 = 0, $scevgep = 0, $split1689 = 0, $totalPatchContactCount$01666 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $1 = sp + 48|0;
 $2 = sp;
 $3 = sp + 16|0;
 $4 = sp + 32|0;
 $5 = (($n) + 22|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = ($6&65535) >>> 8;
 $$tr = $7&255;
 $8 = $$tr & 1;
 $9 = (($n) + 92|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($bodyFrame0) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($bodyFrame0) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($bodyFrame0) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($bodyFrame1) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($bodyFrame1) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($bodyFrame1) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($c) + 1664|0);
 $24 = (($c) + 1792|0);
 $25 = HEAP16[$5>>1]|0;
 $26 = $25&65535;
 $27 = $26 & 24;
 $28 = ($27|0)!=(0);
 $29 = (($c) + 1796|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $26 >>> 6;
 $32 = $28 ? 112 : 80;
 $33 = $28 ? 128 : 96;
 if ($28) {
  $185 = 3;$552 = 12;
 } else {
  $$lobit = $31 << 2;
  $34 = $$lobit & 4;
  $35 = $34 ^ 5;
  $36 = $35&255;
  $37 = $31 & 1;
  $38 = $37 ^ 11;
  $phitmp = $38&255;
  $185 = $36;$552 = $phitmp;
 }
 $39 = Math_fround(HEAPF32[$b0>>2]);
 $40 = (($b0) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($b0) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(HEAPF32[$b1>>2]);
 $45 = (($b1) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($b1) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($b0) + 16|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($b0) + 20|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($b0) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($b1) + 16|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($b1) + 20|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($b1) + 24|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($data0) + 48|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($data1) + 48|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($data0) + 52|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($data1) + 52|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = $66 > $68;
 $$$i407 = $69 ? $66 : $68;
 $70 = Math_fround(HEAPF32[$data0>>2]);
 $71 = (($data0) + 4|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($data0) + 8|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($data0) + 12|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($data0) + 16|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($data0) + 20|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($data0) + 24|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($data0) + 28|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($data0) + 32|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround(HEAPF32[$data1>>2]);
 $88 = (($data1) + 4|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($data1) + 8|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($data1) + 12|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($data1) + 16|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($data1) + 20|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($data1) + 24|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($data1) + 28|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($data1) + 32|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($invDtF32 * Math_fround(0.800000011920928955078));
 $105 = (($n) + 84|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($n) + 88|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($106 * $invMassScale0);
 $110 = Math_fround($108 * $invMassScale1);
 $111 = Math_fround($106 * $invInertiaScale0);
 $112 = Math_fround($108 * $invInertiaScale1);
 $113 = Math_fround(-$112);
 $114 = Math_fround($62 * $109);
 $115 = Math_fround($64 * $110);
 $116 = Math_fround(-$115);
 $117 = Math_fround($70 * $111);
 $118 = Math_fround($72 * $111);
 $119 = Math_fround($74 * $111);
 $120 = Math_fround($76 * $111);
 $121 = Math_fround($78 * $111);
 $122 = Math_fround($80 * $111);
 $123 = Math_fround($82 * $111);
 $124 = Math_fround($84 * $111);
 $125 = Math_fround($86 * $111);
 $126 = Math_fround($87 * $113);
 $127 = Math_fround($89 * $113);
 $128 = Math_fround($91 * $113);
 $129 = Math_fround($93 * $113);
 $130 = Math_fround($95 * $113);
 $131 = Math_fround($97 * $113);
 $132 = Math_fround($99 * $113);
 $133 = Math_fround($101 * $113);
 $134 = Math_fround($103 * $113);
 $135 = ($30|0)==(0);
 if ($135) {
  $hasFriction$0$off0$lcssa = 0;$ptr$3$lcssa = $workspace;
  HEAP8[$ptr$3$lcssa>>0] = 0;
  STACKTOP = sp;return ($hasFriction$0$off0$lcssa|0);
 } else {
  $i$01696 = 0;$ptr$01697 = $workspace;
 }
 while(1) {
  $153 = ((($c) + ($i$01696<<2)|0) + 1408|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = ($154|0)==(0);
  if ($155) {
   $ptr$2 = $ptr$01697;
  } else {
   $156 = ((($c) + ($i$01696<<2)|0) + 1536|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($c) + (($157*12)|0)|0);
   $159 = HEAP16[$158>>1]|0;
   $160 = $159&65535;
   $161 = ((($c) + (($i$01696*20)|0)|0) + 768|0);
   $162 = Math_fround(HEAPF32[$161>>2]);
   $163 = ((($c) + (($i$01696*20)|0)|0) + 772|0);
   $164 = Math_fround(HEAPF32[$163>>2]);
   $165 = ((($c) + (($i$01696*20)|0)|0) + 776|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   $167 = ((($buffer) + ($160<<6)|0) + 60|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = Math_fround($39 * $162);
   $170 = Math_fround($41 * $164);
   $171 = Math_fround($169 + $170);
   $172 = Math_fround($43 * $166);
   $173 = Math_fround($171 + $172);
   $174 = Math_fround($44 * $162);
   $175 = Math_fround($46 * $164);
   $176 = Math_fround($174 + $175);
   $177 = Math_fround($48 * $166);
   $178 = Math_fround($176 + $177);
   $179 = (($ptr$01697) + 48|0);
   $180 = (($ptr$01697) + 176|0);
   $181 = (($ptr$01697) + 304|0);
   $182 = (($ptr$01697) + 432|0);
   $183 = $154&255;
   $184 = (($ptr$01697) + 1|0);
   HEAP8[$184>>0] = $183;
   HEAP8[$ptr$01697>>0] = $185;
   $186 = Math_fround(HEAPF32[$167>>2]);
   $187 = (($ptr$01697) + 4|0);
   HEAPF32[$187>>2] = $186;
   $188 = (($ptr$01697) + 8|0);
   HEAPF32[$188>>2] = $114;
   $189 = (($ptr$01697) + 12|0);
   HEAPF32[$189>>2] = $116;
   $190 = (($ptr$01697) + 16|0);
   HEAPF32[$190>>2] = $162;
   $191 = (($ptr$01697) + 20|0);
   HEAPF32[$191>>2] = $164;
   $192 = (($ptr$01697) + 24|0);
   HEAPF32[$192>>2] = $166;
   $193 = (($ptr$01697) + 36|0);
   HEAP8[$193>>0] = $8;
   $194 = HEAP32[$156>>2]|0;
   $195 = ($194|0)==(65535);
   if ($195) {
    $ptr$2 = $179;
   } else {
    $196 = $168 > Math_fround(0.0);
    $patch$01691 = $194;$ptr$11692 = $179;
    while(1) {
     $197 = ((($c) + (($patch$01691*12)|0)|0) + 2|0);
     $198 = HEAP16[$197>>1]|0;
     $199 = (($c) + (($patch$01691*12)|0)|0);
     $200 = HEAP16[$199>>1]|0;
     $201 = $200&65535;
     $202 = ($198<<16>>16)==(0);
     if ($202) {
      $p$0$lcssa = $ptr$11692;
     } else {
      $203 = $198&65535;
      if ($196) {
       $j$01684$us = 0;$p$01685$us = $ptr$11692;
       while(1) {
        $$sum8$us = (($j$01684$us) + ($201))|0;
        $204 = (($p$01685$us) + ($32)|0);
        $205 = ((($buffer) + ($$sum8$us<<6)|0) + 16|0);
        $206 = Math_fround(HEAPF32[$205>>2]);
        $207 = ((($buffer) + ($$sum8$us<<6)|0) + 20|0);
        $208 = Math_fround(HEAPF32[$207>>2]);
        $209 = ((($buffer) + ($$sum8$us<<6)|0) + 24|0);
        $210 = Math_fround(HEAPF32[$209>>2]);
        $211 = ((($buffer) + ($$sum8$us<<6)|0) + 12|0);
        $212 = Math_fround(HEAPF32[$211>>2]);
        $213 = ((($buffer) + ($$sum8$us<<6)|0) + 32|0);
        $214 = Math_fround(HEAPF32[$213>>2]);
        $215 = ((($buffer) + ($$sum8$us<<6)|0) + 36|0);
        $216 = Math_fround(HEAPF32[$215>>2]);
        $217 = ((($buffer) + ($$sum8$us<<6)|0) + 40|0);
        $218 = Math_fround(HEAPF32[$217>>2]);
        $219 = Math_fround($162 * $214);
        $220 = Math_fround($164 * $216);
        $221 = Math_fround($219 + $220);
        $222 = Math_fround($166 * $218);
        $223 = Math_fround($221 + $222);
        $224 = Math_fround($206 - $12);
        $225 = Math_fround($208 - $14);
        $226 = Math_fround($210 - $16);
        $227 = Math_fround($206 - $18);
        $228 = Math_fround($208 - $20);
        $229 = Math_fround($210 - $22);
        $230 = ((($buffer) + ($$sum8$us<<6)|0) + 28|0);
        $231 = Math_fround(HEAPF32[$230>>2]);
        $232 = Math_fround($166 * $225);
        $233 = Math_fround($164 * $226);
        $234 = Math_fround($232 - $233);
        $235 = Math_fround($162 * $226);
        $236 = Math_fround($166 * $224);
        $237 = Math_fround($235 - $236);
        $238 = Math_fround($164 * $224);
        $239 = Math_fround($162 * $225);
        $240 = Math_fround($238 - $239);
        $241 = Math_fround($166 * $228);
        $242 = Math_fround($164 * $229);
        $243 = Math_fround($241 - $242);
        $244 = Math_fround($162 * $229);
        $245 = Math_fround($166 * $227);
        $246 = Math_fround($244 - $245);
        $247 = Math_fround($164 * $227);
        $248 = Math_fround($162 * $228);
        $249 = Math_fround($247 - $248);
        $250 = Math_fround($117 * $234);
        $251 = Math_fround($120 * $237);
        $252 = Math_fround($250 + $251);
        $253 = Math_fround($123 * $240);
        $254 = Math_fround($253 + $252);
        $255 = Math_fround($118 * $234);
        $256 = Math_fround($121 * $237);
        $257 = Math_fround($255 + $256);
        $258 = Math_fround($124 * $240);
        $259 = Math_fround($258 + $257);
        $260 = Math_fround($119 * $234);
        $261 = Math_fround($122 * $237);
        $262 = Math_fround($260 + $261);
        $263 = Math_fround($125 * $240);
        $264 = Math_fround($263 + $262);
        $265 = Math_fround($126 * $243);
        $266 = Math_fround($129 * $246);
        $267 = Math_fround($265 + $266);
        $268 = Math_fround($132 * $249);
        $269 = Math_fround($268 + $267);
        $270 = Math_fround($127 * $243);
        $271 = Math_fround($130 * $246);
        $272 = Math_fround($270 + $271);
        $273 = Math_fround($133 * $249);
        $274 = Math_fround($273 + $272);
        $275 = Math_fround($128 * $243);
        $276 = Math_fround($131 * $246);
        $277 = Math_fround($275 + $276);
        $278 = Math_fround($134 * $249);
        $279 = Math_fround($278 + $277);
        $280 = Math_fround($234 * $254);
        $281 = Math_fround($237 * $259);
        $282 = Math_fround($280 + $281);
        $283 = Math_fround($240 * $264);
        $284 = Math_fround($283 + $282);
        $285 = Math_fround($114 + $284);
        $286 = Math_fround($243 * $269);
        $287 = Math_fround($246 * $274);
        $288 = Math_fround($286 + $287);
        $289 = Math_fround($249 * $279);
        $290 = Math_fround($289 + $288);
        $291 = Math_fround($290 - $115);
        $292 = Math_fround($285 - $291);
        $293 = Math_fround($50 * $234);
        $294 = Math_fround($52 * $237);
        $295 = Math_fround($293 + $294);
        $296 = Math_fround($54 * $240);
        $297 = Math_fround($296 + $295);
        $298 = Math_fround($173 + $297);
        $299 = Math_fround($56 * $243);
        $300 = Math_fround($58 * $246);
        $301 = Math_fround($299 + $300);
        $302 = Math_fround($60 * $249);
        $303 = Math_fround($302 + $301);
        $304 = Math_fround($178 + $303);
        $305 = Math_fround($298 - $304);
        $306 = Math_fround(Math_fround(1.0) / $292);
        $307 = !($292 > Math_fround(0.0));
        $308 = $307 ? Math_fround(0.0) : $306;
        $309 = Math_fround($212 - $10);
        $310 = Math_fround($104 * $309);
        $311 = $$$i407 > $310;
        $$$i$us = $311 ? $$$i407 : $310;
        $312 = Math_fround($$$i$us * $308);
        $313 = Math_fround($309 * $invDtF32);
        $314 = (($p$01685$us) + 48|0);
        HEAPF32[$314>>2] = $254;
        $315 = (($p$01685$us) + 52|0);
        HEAPF32[$315>>2] = $259;
        $316 = (($p$01685$us) + 56|0);
        HEAPF32[$316>>2] = $264;
        $317 = (($p$01685$us) + 60|0);
        HEAPF32[$317>>2] = $114;
        $318 = (($p$01685$us) + 64|0);
        HEAPF32[$318>>2] = $269;
        $319 = (($p$01685$us) + 68|0);
        HEAPF32[$319>>2] = $274;
        $320 = (($p$01685$us) + 72|0);
        HEAPF32[$320>>2] = $279;
        $321 = (($p$01685$us) + 76|0);
        HEAPF32[$321>>2] = $116;
        $322 = $305 < $bounceThresholdF32;
        $323 = Math_fround(-$305);
        $324 = $313 < $323;
        $$$us = $324 & $322;
        $325 = $$$us ? Math_fround(0.0) : $312;
        $326 = Math_fround($168 * $323);
        $327 = $$$us ? $326 : Math_fround(0.0);
        $328 = Math_fround($223 + $327);
        HEAPF32[$p$01685$us>>2] = $234;
        $329 = (($p$01685$us) + 4|0);
        HEAPF32[$329>>2] = $237;
        $330 = (($p$01685$us) + 8|0);
        HEAPF32[$330>>2] = $240;
        $331 = (($p$01685$us) + 12|0);
        HEAPF32[$331>>2] = Math_fround(0.0);
        $332 = (($p$01685$us) + 16|0);
        HEAPF32[$332>>2] = $243;
        $333 = (($p$01685$us) + 20|0);
        HEAPF32[$333>>2] = $246;
        $334 = (($p$01685$us) + 24|0);
        HEAPF32[$334>>2] = $249;
        $335 = (($p$01685$us) + 28|0);
        HEAPF32[$335>>2] = $308;
        $336 = (($p$01685$us) + 32|0);
        HEAPF32[$336>>2] = $325;
        $337 = (($p$01685$us) + 36|0);
        HEAPF32[$337>>2] = $328;
        $338 = (($p$01685$us) + 40|0);
        HEAPF32[$338>>2] = $231;
        $339 = (($p$01685$us) + 44|0);
        HEAPF32[$339>>2] = Math_fround(0.0);
        $340 = (($j$01684$us) + 1)|0;
        $exitcond1715 = ($340|0)==($203|0);
        if ($exitcond1715) {
         break;
        } else {
         $j$01684$us = $340;$p$01685$us = $204;
        }
       }
      } else {
       $j$01684 = 0;$p$01685 = $ptr$11692;
       while(1) {
        $$sum8 = (($j$01684) + ($201))|0;
        $341 = (($p$01685) + ($32)|0);
        $342 = ((($buffer) + ($$sum8<<6)|0) + 16|0);
        $343 = Math_fround(HEAPF32[$342>>2]);
        $344 = ((($buffer) + ($$sum8<<6)|0) + 20|0);
        $345 = Math_fround(HEAPF32[$344>>2]);
        $346 = ((($buffer) + ($$sum8<<6)|0) + 24|0);
        $347 = Math_fround(HEAPF32[$346>>2]);
        $348 = ((($buffer) + ($$sum8<<6)|0) + 12|0);
        $349 = Math_fround(HEAPF32[$348>>2]);
        $350 = ((($buffer) + ($$sum8<<6)|0) + 32|0);
        $351 = Math_fround(HEAPF32[$350>>2]);
        $352 = ((($buffer) + ($$sum8<<6)|0) + 36|0);
        $353 = Math_fround(HEAPF32[$352>>2]);
        $354 = ((($buffer) + ($$sum8<<6)|0) + 40|0);
        $355 = Math_fround(HEAPF32[$354>>2]);
        $356 = Math_fround($162 * $351);
        $357 = Math_fround($164 * $353);
        $358 = Math_fround($356 + $357);
        $359 = Math_fround($166 * $355);
        $360 = Math_fround($358 + $359);
        $361 = Math_fround($343 - $12);
        $362 = Math_fround($345 - $14);
        $363 = Math_fround($347 - $16);
        $364 = Math_fround($343 - $18);
        $365 = Math_fround($345 - $20);
        $366 = Math_fround($347 - $22);
        $367 = ((($buffer) + ($$sum8<<6)|0) + 28|0);
        $368 = Math_fround(HEAPF32[$367>>2]);
        $369 = Math_fround($166 * $362);
        $370 = Math_fround($164 * $363);
        $371 = Math_fround($369 - $370);
        $372 = Math_fround($162 * $363);
        $373 = Math_fround($166 * $361);
        $374 = Math_fround($372 - $373);
        $375 = Math_fround($164 * $361);
        $376 = Math_fround($162 * $362);
        $377 = Math_fround($375 - $376);
        $378 = Math_fround($166 * $365);
        $379 = Math_fround($164 * $366);
        $380 = Math_fround($378 - $379);
        $381 = Math_fround($162 * $366);
        $382 = Math_fround($166 * $364);
        $383 = Math_fround($381 - $382);
        $384 = Math_fround($164 * $364);
        $385 = Math_fround($162 * $365);
        $386 = Math_fround($384 - $385);
        $387 = Math_fround($117 * $371);
        $388 = Math_fround($120 * $374);
        $389 = Math_fround($387 + $388);
        $390 = Math_fround($123 * $377);
        $391 = Math_fround($390 + $389);
        $392 = Math_fround($118 * $371);
        $393 = Math_fround($121 * $374);
        $394 = Math_fround($392 + $393);
        $395 = Math_fround($124 * $377);
        $396 = Math_fround($395 + $394);
        $397 = Math_fround($119 * $371);
        $398 = Math_fround($122 * $374);
        $399 = Math_fround($397 + $398);
        $400 = Math_fround($125 * $377);
        $401 = Math_fround($400 + $399);
        $402 = Math_fround($126 * $380);
        $403 = Math_fround($129 * $383);
        $404 = Math_fround($402 + $403);
        $405 = Math_fround($132 * $386);
        $406 = Math_fround($405 + $404);
        $407 = Math_fround($127 * $380);
        $408 = Math_fround($130 * $383);
        $409 = Math_fround($407 + $408);
        $410 = Math_fround($133 * $386);
        $411 = Math_fround($410 + $409);
        $412 = Math_fround($128 * $380);
        $413 = Math_fround($131 * $383);
        $414 = Math_fround($412 + $413);
        $415 = Math_fround($134 * $386);
        $416 = Math_fround($415 + $414);
        $417 = Math_fround($371 * $391);
        $418 = Math_fround($374 * $396);
        $419 = Math_fround($417 + $418);
        $420 = Math_fround($377 * $401);
        $421 = Math_fround($420 + $419);
        $422 = Math_fround($114 + $421);
        $423 = Math_fround($380 * $406);
        $424 = Math_fround($383 * $411);
        $425 = Math_fround($423 + $424);
        $426 = Math_fround($386 * $416);
        $427 = Math_fround($426 + $425);
        $428 = Math_fround($427 - $115);
        $429 = Math_fround($422 - $428);
        $430 = Math_fround(Math_fround(1.0) / $429);
        $431 = !($429 > Math_fround(0.0));
        $432 = $431 ? Math_fround(0.0) : $430;
        $433 = Math_fround($349 - $10);
        $434 = Math_fround($104 * $433);
        $435 = $$$i407 > $434;
        $$$i = $435 ? $$$i407 : $434;
        $436 = Math_fround($$$i * $432);
        $437 = (($p$01685) + 48|0);
        HEAPF32[$437>>2] = $391;
        $438 = (($p$01685) + 52|0);
        HEAPF32[$438>>2] = $396;
        $439 = (($p$01685) + 56|0);
        HEAPF32[$439>>2] = $401;
        $440 = (($p$01685) + 60|0);
        HEAPF32[$440>>2] = $114;
        $441 = (($p$01685) + 64|0);
        HEAPF32[$441>>2] = $406;
        $442 = (($p$01685) + 68|0);
        HEAPF32[$442>>2] = $411;
        $443 = (($p$01685) + 72|0);
        HEAPF32[$443>>2] = $416;
        $444 = (($p$01685) + 76|0);
        HEAPF32[$444>>2] = $116;
        $445 = Math_fround($360 + Math_fround(0.0));
        HEAPF32[$p$01685>>2] = $371;
        $446 = (($p$01685) + 4|0);
        HEAPF32[$446>>2] = $374;
        $447 = (($p$01685) + 8|0);
        HEAPF32[$447>>2] = $377;
        $448 = (($p$01685) + 12|0);
        HEAPF32[$448>>2] = Math_fround(0.0);
        $449 = (($p$01685) + 16|0);
        HEAPF32[$449>>2] = $380;
        $450 = (($p$01685) + 20|0);
        HEAPF32[$450>>2] = $383;
        $451 = (($p$01685) + 24|0);
        HEAPF32[$451>>2] = $386;
        $452 = (($p$01685) + 28|0);
        HEAPF32[$452>>2] = $432;
        $453 = (($p$01685) + 32|0);
        HEAPF32[$453>>2] = $436;
        $454 = (($p$01685) + 36|0);
        HEAPF32[$454>>2] = $445;
        $455 = (($p$01685) + 40|0);
        HEAPF32[$455>>2] = $368;
        $456 = (($p$01685) + 44|0);
        HEAPF32[$456>>2] = Math_fround(0.0);
        $457 = (($j$01684) + 1)|0;
        $exitcond1712 = ($457|0)==($203|0);
        if ($exitcond1712) {
         break;
        } else {
         $j$01684 = $457;$p$01685 = $341;
        }
       }
      }
      $$pn = Math_imul($32, $203)|0;
      $split1689 = (($ptr$11692) + ($$pn)|0);
      $p$0$lcssa = $split1689;
     }
     $458 = ((($c) + (($patch$01691*12)|0)|0) + 4|0);
     $459 = HEAP16[$458>>1]|0;
     $460 = $459&65535;
     $461 = ($459<<16>>16)==(-1);
     if ($461) {
      $ptr$2 = $p$0$lcssa;
      break;
     } else {
      $patch$01691 = $460;$ptr$11692 = $p$0$lcssa;
     }
    }
   }
  }
  $462 = (($i$01696) + 1)|0;
  $exitcond1716 = ($462|0)==($30|0);
  if ($exitcond1716) {
   break;
  } else {
   $i$01696 = $462;$ptr$01697 = $ptr$2;
  }
 }
 if ($135) {
  $hasFriction$0$off0$lcssa = 0;$ptr$3$lcssa = $ptr$2;
  HEAP8[$ptr$3$lcssa>>0] = 0;
  STACKTOP = sp;return ($hasFriction$0$off0$lcssa|0);
 }
 $136 = (($2) + 4|0);
 $137 = (($2) + 8|0);
 $138 = (($2) + 12|0);
 $139 = (($1) + 4|0);
 $140 = (($1) + 8|0);
 $141 = (($1) + 12|0);
 $142 = Math_fround($39 - $44);
 $143 = Math_fround($41 - $46);
 $144 = Math_fround($43 - $48);
 $145 = (($4) + 4|0);
 $146 = (($4) + 8|0);
 $147 = (($4) + 12|0);
 $148 = (($3) + 4|0);
 $149 = (($3) + 8|0);
 $150 = (($3) + 12|0);
 $151 = ($frictionPerPointCount|0)==(0);
 $152 = Math_imul($33, $frictionPerPointCount)|0;
 $hasFriction$0$off01677 = 0;$i1$01676 = 0;$ptr$31679 = $ptr$2;$ptr2$01678 = $workspace;
 while(1) {
  $463 = ((($c) + ($i1$01676<<2)|0) + 1408|0);
  $464 = HEAP32[$463>>2]|0;
  $465 = ($464|0)==(0);
  if ($465) {
   $hasFriction$3$off0 = $hasFriction$0$off01677;$ptr$5 = $ptr$31679;$ptr2$1 = $ptr2$01678;
  } else {
   $466 = ((($c) + ($i1$01676<<2)|0) + 1536|0);
   $467 = HEAP32[$466>>2]|0;
   $468 = (($c) + (($467*12)|0)|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = $469&65535;
   $471 = $ptr$31679;
   $472 = $ptr2$01678;
   $473 = (($471) - ($472))|0;
   $474 = $473&65535;
   $475 = (($ptr2$01678) + 2|0);
   HEAP16[$475>>1] = $474;
   $476 = (($ptr2$01678) + 1|0);
   $477 = HEAP8[$476>>0]|0;
   $478 = $477&255;
   $479 = Math_imul($478, $32)|0;
   $480 = (($479) + 48)|0;
   $481 = (($ptr2$01678) + ($480)|0);
   $482 = ((($buffer) + ($470<<6)|0) + 44|0);
   $483 = Math_fround(HEAPF32[$482>>2]);
   $484 = ((($buffer) + ($470<<6)|0) + 52|0);
   $485 = HEAP32[$484>>2]|0;
   $486 = $485 & 1;
   $487 = ($486|0)==(0);
   $488 = $464&255;
   $489 = (($ptr$31679) + 1|0);
   HEAP8[$489>>0] = $488;
   if ($487) {
    $490 = ((($c) + (($i1$01676*20)|0)|0) + 784|0);
    $491 = HEAP16[$490>>1]|0;
    $phitmp1628 = $491&255;
    $493 = $phitmp1628;
   } else {
    $493 = 0;
   }
   $492 = (($ptr$31679) + 2|0);
   HEAP8[$492>>0] = $493;
   $494 = HEAP32[$463>>2]|0;
   $495 = $494 << 2;
   $496 = (($495) + 44)|0;
   $$sum = $496 & -16;
   $497 = (($ptr$31679) + ($$sum)|0);
   $$sum1629 = (($$sum) + 128)|0;
   $498 = (($ptr$31679) + ($$sum1629)|0);
   $$sum1630 = (($$sum) + 256)|0;
   $499 = (($ptr$31679) + ($$sum1630)|0);
   $$sum1631 = (($$sum) + 384)|0;
   $500 = (($ptr$31679) + ($$sum1631)|0);
   $501 = HEAP32[$466>>2]|0;
   $502 = (($c) + (($501*12)|0)|0);
   $503 = HEAP16[$502>>1]|0;
   $504 = $503&65535;
   $505 = (($buffer) + ($504<<6)|0);
   $506 = Math_fround(HEAPF32[$505>>2]);
   $507 = ((($buffer) + ($504<<6)|0) + 4|0);
   $508 = Math_fround(HEAPF32[$507>>2]);
   $509 = ((($buffer) + ($504<<6)|0) + 8|0);
   $510 = Math_fround(HEAPF32[$509>>2]);
   $511 = Math_fround(-$510);
   $512 = Math_fround(-$508);
   $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($506)))));
   $513 = $fabsf$i$i$i < Math_fround(0.707106769084930419921);
   HEAPF32[$2>>2] = Math_fround(0.0);
   HEAPF32[$136>>2] = $511;
   HEAPF32[$137>>2] = $508;
   HEAPF32[$138>>2] = Math_fround(0.0);
   HEAPF32[$1>>2] = $512;
   HEAPF32[$139>>2] = $506;
   HEAPF32[$140>>2] = Math_fround(0.0);
   HEAPF32[$141>>2] = Math_fround(0.0);
   $b$a$i140 = $513 ? $2 : $1;
   $514 = Math_fround(HEAPF32[$b$a$i140>>2]);
   $$in1$i143 = (($b$a$i140) + 4|0);
   $515 = Math_fround(HEAPF32[$$in1$i143>>2]);
   $$in2$i145 = (($b$a$i140) + 8|0);
   $516 = Math_fround(HEAPF32[$$in2$i145>>2]);
   $517 = Math_fround($142 * $506);
   $518 = Math_fround($143 * $508);
   $519 = Math_fround($517 + $518);
   $520 = Math_fround($144 * $510);
   $521 = Math_fround($519 + $520);
   $522 = Math_fround($506 * $521);
   $523 = Math_fround($508 * $521);
   $524 = Math_fround($510 * $521);
   $525 = Math_fround($142 - $522);
   $526 = Math_fround($143 - $523);
   $527 = Math_fround($144 - $524);
   $528 = Math_fround($525 * $525);
   $529 = Math_fround($526 * $526);
   $530 = Math_fround($528 + $529);
   $531 = Math_fround($527 * $527);
   $532 = Math_fround($531 + $530);
   $533 = $532 > Math_fround(9.99999974737875163555E-6);
   HEAPF32[$4>>2] = $525;
   HEAPF32[$145>>2] = $526;
   HEAPF32[$146>>2] = $527;
   HEAPF32[$147>>2] = Math_fround(0.0);
   HEAPF32[$3>>2] = $514;
   HEAPF32[$148>>2] = $515;
   HEAPF32[$149>>2] = $516;
   HEAPF32[$150>>2] = Math_fround(0.0);
   $b$a$i108 = $533 ? $4 : $3;
   $534 = Math_fround(HEAPF32[$b$a$i108>>2]);
   $$in1$i = (($b$a$i108) + 4|0);
   $535 = Math_fround(HEAPF32[$$in1$i>>2]);
   $$in2$i = (($b$a$i108) + 8|0);
   $536 = Math_fround(HEAPF32[$$in2$i>>2]);
   $537 = Math_fround($534 * $534);
   $538 = Math_fround($535 * $535);
   $539 = Math_fround($537 + $538);
   $540 = Math_fround($536 * $536);
   $541 = Math_fround($539 + $540);
   $542 = (Math_fround(Math_sqrt((Math_fround($541)))));
   $543 = Math_fround(Math_fround(1.0) / $542);
   $544 = Math_fround($534 * $543);
   $545 = Math_fround($535 * $543);
   $546 = Math_fround($536 * $543);
   if ($487) {
    $547 = (($ptr$31679) + 4|0);
    HEAPF32[$547>>2] = $483;
    $548 = Math_fround(HEAPF32[$105>>2]);
    $549 = (($ptr$31679) + 8|0);
    HEAPF32[$549>>2] = $548;
    $550 = Math_fround(HEAPF32[$107>>2]);
    $551 = (($ptr$31679) + 12|0);
    HEAPF32[$551>>2] = $550;
    HEAP8[$ptr$31679>>0] = $552;
    $553 = HEAP32[$466>>2]|0;
    $554 = ($553|0)==(65535);
    if ($554) {
     $hasFriction$3$off0 = $hasFriction$0$off01677;$ptr$5 = $497;$ptr2$1 = $481;
    } else {
     $555 = Math_fround($510 * $545);
     $556 = Math_fround($508 * $546);
     $557 = Math_fround($506 * $546);
     $558 = Math_fround($510 * $544);
     $559 = Math_fround($508 * $544);
     $560 = Math_fround($506 * $545);
     $561 = Math_fround($555 - $556);
     $562 = Math_fround($557 - $558);
     $563 = Math_fround($559 - $560);
     $695 = $561;$696 = $562;$697 = $563;$698 = $544;$699 = $545;$700 = $546;$hasFriction$1$off01670 = $hasFriction$0$off01677;$patch7$01669 = $553;$ptr$41671 = $497;$totalPatchContactCount$01666 = 0;
     while(1) {
      $564 = ((($c) + (($patch7$01669*12)|0)|0) + 2|0);
      $565 = HEAP16[$564>>1]|0;
      $566 = (($c) + (($patch7$01669*12)|0)|0);
      $567 = HEAP16[$566>>1]|0;
      $568 = $567&65535;
      $569 = ($565<<16>>16)==(0);
      L38: do {
       if ($569) {
        $$lcssa1647 = $700;$$lcssa1648 = $699;$$lcssa1649 = $698;$$lcssa1650 = $697;$$lcssa1651 = $696;$$lcssa1652 = $695;$688 = 0;$hasFriction$2$off0$lcssa = $hasFriction$1$off01670;$p10$0$lcssa = $ptr$41671;
       } else {
        $570 = $565&65535;
        if ($151) {
         $j11$01654 = 0;
         while(1) {
          $686 = (($j11$01654) + 1)|0;
          $exitcond = ($686|0)==($570|0);
          if ($exitcond) {
           $$lcssa1647 = $700;$$lcssa1648 = $699;$$lcssa1649 = $698;$$lcssa1650 = $697;$$lcssa1651 = $696;$$lcssa1652 = $695;$688 = $565;$hasFriction$2$off0$lcssa = 1;$p10$0$lcssa = $ptr$41671;
           break L38;
          } else {
           $j11$01654 = $686;
          }
         }
        } else {
         $701 = $695;$702 = $696;$703 = $697;$704 = $698;$705 = $699;$706 = $700;$j11$01654$us = 0;$p10$01653$us = $ptr$41671;
        }
        while(1) {
         $574 = (($j11$01654$us) + ($totalPatchContactCount$01666))|0;
         $$sum7$us = (($j11$01654$us) + ($568))|0;
         $677 = ((($buffer) + ($$sum7$us<<6)|0) + 16|0);
         $678 = Math_fround(HEAPF32[$677>>2]);
         $679 = ((($buffer) + ($$sum7$us<<6)|0) + 20|0);
         $680 = Math_fround(HEAPF32[$679>>2]);
         $681 = ((($buffer) + ($$sum7$us<<6)|0) + 24|0);
         $682 = Math_fround(HEAPF32[$681>>2]);
         $585 = Math_fround($678 - $12);
         $577 = Math_fround($680 - $14);
         $580 = Math_fround($682 - $16);
         $597 = Math_fround($678 - $18);
         $591 = Math_fround($680 - $20);
         $593 = Math_fround($682 - $22);
         $683 = ((($buffer) + ($$sum7$us<<6)|0) + 32|0);
         $657 = Math_fround(HEAPF32[$683>>2]);
         $684 = ((($buffer) + ($$sum7$us<<6)|0) + 36|0);
         $659 = Math_fround(HEAPF32[$684>>2]);
         $685 = ((($buffer) + ($$sum7$us<<6)|0) + 40|0);
         $662 = Math_fround(HEAPF32[$685>>2]);
         $576 = $706;$579 = $705;$583 = $704;$707 = $701;$708 = $702;$709 = $703;$k$01640$us = 0;$p10$11639$us = $p10$01653$us;
         while(1) {
          $572 = (($p10$11639$us) + ($33)|0);
          $573 = (($p10$11639$us) + 80|0);
          HEAP32[$573>>2] = $574;
          $575 = Math_fround($577 * $576);
          $578 = Math_fround($580 * $579);
          $581 = Math_fround($575 - $578);
          $582 = Math_fround($580 * $583);
          $584 = Math_fround($585 * $576);
          $586 = Math_fround($582 - $584);
          $587 = Math_fround($585 * $579);
          $588 = Math_fround($577 * $583);
          $589 = Math_fround($587 - $588);
          $590 = Math_fround($591 * $576);
          $592 = Math_fround($593 * $579);
          $594 = Math_fround($590 - $592);
          $595 = Math_fround($593 * $583);
          $596 = Math_fround($597 * $576);
          $598 = Math_fround($595 - $596);
          $599 = Math_fround($597 * $579);
          $600 = Math_fround($591 * $583);
          $601 = Math_fround($599 - $600);
          $602 = Math_fround($117 * $581);
          $603 = Math_fround($120 * $586);
          $604 = Math_fround($602 + $603);
          $605 = Math_fround($123 * $589);
          $606 = Math_fround($605 + $604);
          $607 = Math_fround($118 * $581);
          $608 = Math_fround($121 * $586);
          $609 = Math_fround($607 + $608);
          $610 = Math_fround($124 * $589);
          $611 = Math_fround($610 + $609);
          $612 = Math_fround($119 * $581);
          $613 = Math_fround($122 * $586);
          $614 = Math_fround($612 + $613);
          $615 = Math_fround($125 * $589);
          $616 = Math_fround($615 + $614);
          $617 = Math_fround($126 * $594);
          $618 = Math_fround($129 * $598);
          $619 = Math_fround($617 + $618);
          $620 = Math_fround($132 * $601);
          $621 = Math_fround($620 + $619);
          $622 = Math_fround($127 * $594);
          $623 = Math_fround($130 * $598);
          $624 = Math_fround($622 + $623);
          $625 = Math_fround($133 * $601);
          $626 = Math_fround($625 + $624);
          $627 = Math_fround($128 * $594);
          $628 = Math_fround($131 * $598);
          $629 = Math_fround($627 + $628);
          $630 = Math_fround($134 * $601);
          $631 = Math_fround($630 + $629);
          $632 = Math_fround($581 * $606);
          $633 = Math_fround($586 * $611);
          $634 = Math_fround($632 + $633);
          $635 = Math_fround($589 * $616);
          $636 = Math_fround($635 + $634);
          $637 = Math_fround($114 + $636);
          $638 = Math_fround($594 * $621);
          $639 = Math_fround($598 * $626);
          $640 = Math_fround($638 + $639);
          $641 = Math_fround($601 * $631);
          $642 = Math_fround($641 + $640);
          $643 = Math_fround($642 - $115);
          $644 = Math_fround($637 - $643);
          $645 = Math_fround(Math_fround(1.0) / $644);
          $646 = !($644 > Math_fround(0.0));
          $647 = $646 ? Math_fround(0.0) : $645;
          $648 = Math_fround(-$647);
          HEAPF32[$p10$11639$us>>2] = $583;
          $649 = (($p10$11639$us) + 4|0);
          HEAPF32[$649>>2] = $579;
          $650 = (($p10$11639$us) + 8|0);
          HEAPF32[$650>>2] = $576;
          $651 = (($p10$11639$us) + 12|0);
          HEAPF32[$651>>2] = Math_fround(0.0);
          $652 = (($p10$11639$us) + 16|0);
          HEAPF32[$652>>2] = $581;
          $653 = (($p10$11639$us) + 20|0);
          HEAPF32[$653>>2] = $586;
          $654 = (($p10$11639$us) + 24|0);
          HEAPF32[$654>>2] = $589;
          $655 = (($p10$11639$us) + 28|0);
          HEAPF32[$655>>2] = $648;
          $656 = Math_fround($657 * $583);
          $658 = Math_fround($659 * $579);
          $660 = Math_fround($658 + $656);
          $661 = Math_fround($662 * $576);
          $663 = Math_fround($661 + $660);
          $664 = (($p10$11639$us) + 32|0);
          HEAPF32[$664>>2] = $594;
          $665 = (($p10$11639$us) + 36|0);
          HEAPF32[$665>>2] = $598;
          $666 = (($p10$11639$us) + 40|0);
          HEAPF32[$666>>2] = $601;
          $667 = (($p10$11639$us) + 44|0);
          HEAPF32[$667>>2] = $663;
          $668 = (($p10$11639$us) + 48|0);
          HEAPF32[$668>>2] = $606;
          $669 = (($p10$11639$us) + 52|0);
          HEAPF32[$669>>2] = $611;
          $670 = (($p10$11639$us) + 56|0);
          HEAPF32[$670>>2] = $616;
          $671 = (($p10$11639$us) + 60|0);
          HEAPF32[$671>>2] = $114;
          $672 = (($p10$11639$us) + 64|0);
          HEAPF32[$672>>2] = $621;
          $673 = (($p10$11639$us) + 68|0);
          HEAPF32[$673>>2] = $626;
          $674 = (($p10$11639$us) + 72|0);
          HEAPF32[$674>>2] = $631;
          $675 = (($p10$11639$us) + 76|0);
          HEAPF32[$675>>2] = $116;
          $676 = (($k$01640$us) + 1)|0;
          $exitcond1707 = ($676|0)==($frictionPerPointCount|0);
          if ($exitcond1707) {
           break;
          } else {
           $709$phi = $576;$708$phi = $579;$707$phi = $583;$583$phi = $707;$579$phi = $708;$576$phi = $709;$k$01640$us = $676;$p10$11639$us = $572;$709 = $709$phi;$708 = $708$phi;$707 = $707$phi;$583 = $583$phi;$579 = $579$phi;$576 = $576$phi;
          }
         }
         $scevgep = (($p10$01653$us) + ($152)|0);
         $571 = (($j11$01654$us) + 1)|0;
         $exitcond1708 = ($571|0)==($570|0);
         if ($exitcond1708) {
          break;
         } else {
          $701 = $583;$702 = $579;$703 = $576;$704 = $707;$705 = $708;$706 = $709;$j11$01654$us = $571;$p10$01653$us = $scevgep;
         }
        }
        $$pre$pre = HEAP16[$564>>1]|0;
        $$lcssa1647 = $709;$$lcssa1648 = $708;$$lcssa1649 = $707;$$lcssa1650 = $576;$$lcssa1651 = $579;$$lcssa1652 = $583;$688 = $$pre$pre;$hasFriction$2$off0$lcssa = 1;$p10$0$lcssa = $scevgep;
       }
      } while(0);
      $687 = $688&65535;
      $689 = (($687) + ($totalPatchContactCount$01666))|0;
      $690 = ((($c) + (($patch7$01669*12)|0)|0) + 4|0);
      $691 = HEAP16[$690>>1]|0;
      $692 = $691&65535;
      $693 = ($691<<16>>16)==(-1);
      if ($693) {
       $hasFriction$3$off0 = $hasFriction$2$off0$lcssa;$ptr$5 = $p10$0$lcssa;$ptr2$1 = $481;
       break;
      } else {
       $695 = $$lcssa1652;$696 = $$lcssa1651;$697 = $$lcssa1650;$698 = $$lcssa1649;$699 = $$lcssa1648;$700 = $$lcssa1647;$hasFriction$1$off01670 = $hasFriction$2$off0$lcssa;$patch7$01669 = $692;$ptr$41671 = $p10$0$lcssa;$totalPatchContactCount$01666 = $689;
      }
     }
    }
   } else {
    $hasFriction$3$off0 = $hasFriction$0$off01677;$ptr$5 = $497;$ptr2$1 = $481;
   }
  }
  $694 = (($i1$01676) + 1)|0;
  $exitcond1709 = ($694|0)==($30|0);
  if ($exitcond1709) {
   $hasFriction$0$off0$lcssa = $hasFriction$3$off0;$ptr$3$lcssa = $ptr$5;
   break;
  } else {
   $hasFriction$0$off01677 = $hasFriction$3$off0;$i1$01676 = $694;$ptr$31679 = $ptr$5;$ptr2$01678 = $ptr2$1;
  }
 }
 HEAP8[$ptr$3$lcssa>>0] = 0;
 STACKTOP = sp;return ($hasFriction$0$off0$lcssa|0);
}
function __ZN5physx26solveVBlockDefaultFrictionEPNS_13PxsSolverCoreEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS9_jRNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENSA_19ReflectionAllocatorISC_EEEESG_PNS_2Cm13SpatialVectorEPNS_25PxcThresholdStreamElementEjRj($solverCore,$dt,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$contactConstraintList,$contactConstraintListSize,$frictionConstraintList,$frictionConstraintConstraintListSize,$contactConstraintBatchHeaders,$frictionConstraintBatchHeaders,$motionVelocityArray,$thresholdStream,$thresholdStreamLength,$outThresholdPairs) {
 $solverCore = $solverCore|0;
 $dt = Math_fround($dt);
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $solverBodyOffset = $solverBodyOffset|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $contactConstraintList = $contactConstraintList|0;
 $contactConstraintListSize = $contactConstraintListSize|0;
 $frictionConstraintList = $frictionConstraintList|0;
 $frictionConstraintConstraintListSize = $frictionConstraintConstraintListSize|0;
 $contactConstraintBatchHeaders = $contactConstraintBatchHeaders|0;
 $frictionConstraintBatchHeaders = $frictionConstraintBatchHeaders|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$solverCore>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiii[$2 & 7]($solverCore,$dt,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$contactConstraintList,$contactConstraintListSize,$frictionConstraintList,$frictionConstraintConstraintListSize,$contactConstraintBatchHeaders,$frictionConstraintBatchHeaders,$motionVelocityArray,$thresholdStream,$thresholdStreamLength,$outThresholdPairs);
 STACKTOP = sp;return;
}
function __ZN5physx26solveVBlockCoulombFrictionEPNS_13PxsSolverCoreEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS9_jRNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENSA_19ReflectionAllocatorISC_EEEESG_PNS_2Cm13SpatialVectorEPNS_25PxcThresholdStreamElementEjRj($solverCore,$dt,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$contactConstraintList,$contactConstraintListSize,$frictionConstraintList,$frictionConstraintConstraintListSize,$contactConstraintBatchHeaders,$frictionConstraintBatchHeaders,$motionVelocityArray,$thresholdStream,$thresholdStreamLength,$outThresholdPairs) {
 $solverCore = $solverCore|0;
 $dt = Math_fround($dt);
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $solverBodyOffset = $solverBodyOffset|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $contactConstraintList = $contactConstraintList|0;
 $contactConstraintListSize = $contactConstraintListSize|0;
 $frictionConstraintList = $frictionConstraintList|0;
 $frictionConstraintConstraintListSize = $frictionConstraintConstraintListSize|0;
 $contactConstraintBatchHeaders = $contactConstraintBatchHeaders|0;
 $frictionConstraintBatchHeaders = $frictionConstraintBatchHeaders|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$solverCore>>2]|0;
 $1 = (($0) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiii[$2 & 7]($solverCore,$dt,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$solverBodyOffset,$atomListSize,$articulationListStart,$articulationListSize,$contactConstraintList,$contactConstraintListSize,$frictionConstraintList,$frictionConstraintConstraintListSize,$contactConstraintBatchHeaders,$frictionConstraintBatchHeaders,$motionVelocityArray,$thresholdStream,$thresholdStreamLength,$outThresholdPairs);
 STACKTOP = sp;return;
}
function __ZN5physx36PxsSolverCoreRegisterArticulationFnsEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[((501768 + 12|0))>>2] = 2529;
 HEAP32[((501768 + 16|0))>>2] = 2530;
 HEAP32[((501800 + 12|0))>>2] = 2531;
 HEAP32[((501800 + 16|0))>>2] = 2532;
 HEAP32[((501832 + 12|0))>>2] = 1590;
 HEAP32[((501832 + 16|0))>>2] = 1591;
 HEAP32[((501872 + 12|0))>>2] = 90;
 HEAP32[((501872 + 16|0))>>2] = 91;
 HEAP32[((501912 + 12|0))>>2] = 1592;
 HEAP32[((501912 + 16|0))>>2] = 1593;
 HEAP32[((501952 + 12|0))>>2] = 2533;
 HEAP32[((501952 + 16|0))>>2] = 2530;
 HEAP32[((502008 + 12|0))>>2] = 2534;
 HEAP32[((502008 + 16|0))>>2] = 2532;
 HEAP32[((502064 + 12|0))>>2] = 1594;
 HEAP32[((502064 + 16|0))>>2] = 1591;
 HEAP32[((502128 + 12|0))>>2] = 92;
 HEAP32[((502128 + 16|0))>>2] = 91;
 HEAP32[((502192 + 12|0))>>2] = 1595;
 HEAP32[((502192 + 16|0))>>2] = 1593;
 HEAP32[((501952 + 48|0))>>2] = 2535;
 HEAP32[((502064 + 48|0))>>2] = 1596;
 HEAP32[((502128 + 48|0))>>2] = 93;
 HEAP32[((502192 + 48|0))>>2] = 1596;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsSolverCoreGeneral6createEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,4,502256,147)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return ($1|0);
 }
 HEAP32[$1>>2] = ((502416 + 8|0));
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx20PxsSolverCoreGeneral8destroyVEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsSolverCoreGeneral6solveVEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jPNS_2Cm13SpatialVectorE($this,$0,$positionIterations,$velocityIterations,$atomListStart,$1,$2,$atomListSize,$articulationListStart,$articulationListSize,$contactConstraintList,$contactConstraintListSize,$3,$4,$motionVelocityArray) {
 $this = $this|0;
 $0 = Math_fround($0);
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $1 = $1|0;
 $2 = $2|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $contactConstraintList = $contactConstraintList|0;
 $contactConstraintListSize = $contactConstraintListSize|0;
 $3 = $3|0;
 $4 = $4|0;
 $motionVelocityArray = $motionVelocityArray|0;
 var $$not = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0;
 var $29 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $baIdx$012 = 0, $brmerge = 0, $cache = 0, $exitcond = 0, $exitcond21 = 0, $exitcond22 = 0, $exitcond23 = 0, $exitcond24 = 0, $i$014$us = 0, $i1$09 = 0, $i2$05 = 0, $i4$01$us = 0, $iteration$018 = 0, $iteration$018$us = 0, $iteration3$02$us = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $cache = sp;
 $5 = (($cache) + 1|0);
 HEAP8[$5>>0] = 0;
 $6 = ($positionIterations|0)>(0);
 L1: do {
  if ($6) {
   $7 = ($contactConstraintListSize|0)==(0);
   if ($7) {
    $iteration$018 = $positionIterations;
    while(1) {
     $21 = ($iteration$018|0)<(4);
     $22 = $21&1;
     HEAP8[$cache>>0] = $22;
     $23 = (($iteration$018) + -1)|0;
     $24 = ($23|0)>(0);
     if ($24) {
      $iteration$018 = $23;
     } else {
      break L1;
     }
    }
   } else {
    $iteration$018$us = $positionIterations;
   }
   while(1) {
    $18 = ($iteration$018$us|0)<(4);
    $19 = $18&1;
    HEAP8[$cache>>0] = $19;
    $i$014$us = 0;
    while(1) {
     $10 = (($contactConstraintList) + ($i$014$us<<5)|0);
     $11 = ((($contactConstraintList) + ($i$014$us<<5)|0) + 16|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = HEAP8[$12>>0]|0;
     $14 = $13&255;
     $15 = (501768 + ($14<<2)|0);
     $16 = HEAP32[$15>>2]|0;
     FUNCTION_TABLE_vii[$16 & 4095]($10,$cache);
     $17 = (($i$014$us) + 1)|0;
     $exitcond24 = ($17|0)==($contactConstraintListSize|0);
     if ($exitcond24) {
      break;
     } else {
      $i$014$us = $17;
     }
    }
    $8 = (($iteration$018$us) + -1)|0;
    $9 = ($8|0)>(0);
    if ($9) {
     $iteration$018$us = $8;
    } else {
     break;
    }
   }
  }
 } while(0);
 $20 = ($atomListSize|0)==(0);
 if (!($20)) {
  $baIdx$012 = 0;
  while(1) {
   $26 = (($atomListStart) + ($baIdx$012<<5)|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = (($motionVelocityArray) + ($baIdx$012<<5)|0);
   HEAPF32[$28>>2] = $27;
   $29 = ((($atomListStart) + ($baIdx$012<<5)|0) + 4|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = ((($motionVelocityArray) + ($baIdx$012<<5)|0) + 4|0);
   HEAPF32[$31>>2] = $30;
   $32 = ((($atomListStart) + ($baIdx$012<<5)|0) + 8|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = ((($motionVelocityArray) + ($baIdx$012<<5)|0) + 8|0);
   HEAPF32[$34>>2] = $33;
   $35 = ((($atomListStart) + ($baIdx$012<<5)|0) + 16|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = ((($motionVelocityArray) + ($baIdx$012<<5)|0) + 16|0);
   HEAPF32[$37>>2] = $36;
   $38 = ((($atomListStart) + ($baIdx$012<<5)|0) + 20|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = ((($motionVelocityArray) + ($baIdx$012<<5)|0) + 20|0);
   HEAPF32[$40>>2] = $39;
   $41 = ((($atomListStart) + ($baIdx$012<<5)|0) + 24|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = ((($motionVelocityArray) + ($baIdx$012<<5)|0) + 24|0);
   HEAPF32[$43>>2] = $42;
   $44 = (($baIdx$012) + 1)|0;
   $exitcond22 = ($44|0)==($atomListSize|0);
   if ($exitcond22) {
    break;
   } else {
    $baIdx$012 = $44;
   }
  }
 }
 $25 = ($articulationListSize|0)==(0);
 if (!($25)) {
  $i1$09 = 0;
  while(1) {
   $46 = HEAP32[503528>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    $48 = (($articulationListStart) + (($i1$09*40)|0)|0);
    __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($48);
   }
   $49 = (($i1$09) + 1)|0;
   $exitcond21 = ($49|0)==($articulationListSize|0);
   if ($exitcond21) {
    break;
   } else {
    $i1$09 = $49;
   }
  }
 }
 $45 = ($contactConstraintListSize|0)==(0);
 if (!($45)) {
  $i2$05 = 0;
  while(1) {
   $50 = (($contactConstraintList) + ($i2$05<<5)|0);
   $51 = ((($contactConstraintList) + ($i2$05<<5)|0) + 16|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP8[$52>>0]|0;
   $54 = $53&255;
   $55 = (502352 + ($54<<2)|0);
   $56 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vii[$56 & 4095]($50,$cache);
   $57 = (($i2$05) + 1)|0;
   $exitcond = ($57|0)==($contactConstraintListSize|0);
   if ($exitcond) {
    break;
   } else {
    $i2$05 = $57;
   }
  }
 }
 $58 = (1 - ($velocityIterations))|0;
 $$not = ($58|0)>(0);
 $brmerge = $$not | $45;
 if ($brmerge) {
  STACKTOP = sp;return;
 } else {
  $iteration3$02$us = $58;
 }
 while(1) {
  $i4$01$us = 0;
  while(1) {
   $61 = (($contactConstraintList) + ($i4$01$us<<5)|0);
   $62 = ((($contactConstraintList) + ($i4$01$us<<5)|0) + 16|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP8[$63>>0]|0;
   $65 = $64&255;
   $66 = (501768 + ($65<<2)|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vii[$67 & 4095]($61,$cache);
   $68 = (($i4$01$us) + 1)|0;
   $exitcond23 = ($68|0)==($contactConstraintListSize|0);
   if ($exitcond23) {
    break;
   } else {
    $i4$01$us = $68;
   }
  }
  $59 = (($iteration3$02$us) + 1)|0;
  $60 = ($iteration3$02$us|0)<(0);
  if ($60) {
   $iteration3$02$us = $59;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsSolverCoreGeneral13solveVCoulombEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jPNS_2Cm13SpatialVectorE($this,$0,$positionIterations,$velocityIterations,$atomListStart,$1,$2,$atomListSize,$articulationListStart,$articulationListSize,$contactConstraintList,$contactConstraintListSize,$frictionConstraintList,$frictionConstraintListSize,$motionVelocityArray) {
 $this = $this|0;
 $0 = Math_fround($0);
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $1 = $1|0;
 $2 = $2|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $contactConstraintList = $contactConstraintList|0;
 $contactConstraintListSize = $contactConstraintListSize|0;
 $frictionConstraintList = $frictionConstraintList|0;
 $frictionConstraintListSize = $frictionConstraintListSize|0;
 $motionVelocityArray = $motionVelocityArray|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $baIdx$014 = 0, $cache = 0, $exitcond = 0, $exitcond27 = 0, $exitcond28 = 0, $exitcond29 = 0, $exitcond30 = 0, $exitcond31 = 0, $exitcond32 = 0, $exitcond33 = 0;
 var $i$022 = 0, $i2$017$us = 0, $i3$011 = 0, $i4$07 = 0, $i6$01$us = 0, $i7$02 = 0, $i7$02$us = 0, $iteration$025 = 0, $iteration1$020$us = 0, $iteration5$04 = 0, $iteration5$04$us = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $cache = sp;
 $3 = ($positionIterations|0)>(0);
 if ($3) {
  $4 = ($contactConstraintListSize|0)==(0);
  $iteration$025 = $positionIterations;
  while(1) {
   if (!($4)) {
    $i$022 = 0;
    while(1) {
     $5 = (($contactConstraintList) + ($i$022<<5)|0);
     $6 = ((($contactConstraintList) + ($i$022<<5)|0) + 16|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = HEAP8[$7>>0]|0;
     $9 = $8&255;
     $10 = (501952 + ($9<<2)|0);
     $11 = HEAP32[$10>>2]|0;
     FUNCTION_TABLE_vii[$11 & 4095]($5,$cache);
     $12 = (($i$022) + 1)|0;
     $exitcond30 = ($12|0)==($contactConstraintListSize|0);
     if ($exitcond30) {
      break;
     } else {
      $i$022 = $12;
     }
    }
   }
   $13 = (($iteration$025) + -1)|0;
   $14 = ($13|0)>(0);
   if ($14) {
    $iteration$025 = $13;
   } else {
    break;
   }
  }
 }
 $15 = $positionIterations << 1;
 $16 = ($15|0)<(1);
 $17 = ($frictionConstraintListSize|0)==(0);
 $or$cond = $16 | $17;
 if (!($or$cond)) {
  $iteration1$020$us = $15;
  while(1) {
   $i2$017$us = 0;
   while(1) {
    $20 = (($frictionConstraintList) + ($i2$017$us<<5)|0);
    $21 = ((($frictionConstraintList) + ($i2$017$us<<5)|0) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = (501952 + ($24<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    FUNCTION_TABLE_vii[$26 & 4095]($20,$cache);
    $27 = (($i2$017$us) + 1)|0;
    $exitcond33 = ($27|0)==($frictionConstraintListSize|0);
    if ($exitcond33) {
     break;
    } else {
     $i2$017$us = $27;
    }
   }
   $18 = (($iteration1$020$us) + -1)|0;
   $19 = ($18|0)>(0);
   if ($19) {
    $iteration1$020$us = $18;
   } else {
    break;
   }
  }
 }
 $28 = ($atomListSize|0)==(0);
 if (!($28)) {
  $baIdx$014 = 0;
  while(1) {
   $30 = (($atomListStart) + ($baIdx$014<<5)|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = (($motionVelocityArray) + ($baIdx$014<<5)|0);
   HEAPF32[$32>>2] = $31;
   $33 = ((($atomListStart) + ($baIdx$014<<5)|0) + 4|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = ((($motionVelocityArray) + ($baIdx$014<<5)|0) + 4|0);
   HEAPF32[$35>>2] = $34;
   $36 = ((($atomListStart) + ($baIdx$014<<5)|0) + 8|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = ((($motionVelocityArray) + ($baIdx$014<<5)|0) + 8|0);
   HEAPF32[$38>>2] = $37;
   $39 = ((($atomListStart) + ($baIdx$014<<5)|0) + 16|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = ((($motionVelocityArray) + ($baIdx$014<<5)|0) + 16|0);
   HEAPF32[$41>>2] = $40;
   $42 = ((($atomListStart) + ($baIdx$014<<5)|0) + 20|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = ((($motionVelocityArray) + ($baIdx$014<<5)|0) + 20|0);
   HEAPF32[$44>>2] = $43;
   $45 = ((($atomListStart) + ($baIdx$014<<5)|0) + 24|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = ((($motionVelocityArray) + ($baIdx$014<<5)|0) + 24|0);
   HEAPF32[$47>>2] = $46;
   $48 = (($baIdx$014) + 1)|0;
   $exitcond29 = ($48|0)==($atomListSize|0);
   if ($exitcond29) {
    break;
   } else {
    $baIdx$014 = $48;
   }
  }
 }
 $29 = ($articulationListSize|0)==(0);
 if (!($29)) {
  $i3$011 = 0;
  while(1) {
   $50 = HEAP32[503528>>2]|0;
   $51 = ($50|0)==(0|0);
   if (!($51)) {
    $52 = (($articulationListStart) + (($i3$011*40)|0)|0);
    __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($52);
   }
   $53 = (($i3$011) + 1)|0;
   $exitcond28 = ($53|0)==($articulationListSize|0);
   if ($exitcond28) {
    break;
   } else {
    $i3$011 = $53;
   }
  }
 }
 $49 = ($contactConstraintListSize|0)==(0);
 if (!($49)) {
  $i4$07 = 0;
  while(1) {
   $54 = (($contactConstraintList) + ($i4$07<<5)|0);
   $55 = ((($contactConstraintList) + ($i4$07<<5)|0) + 16|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = HEAP8[$56>>0]|0;
   $58 = $57&255;
   $59 = (502384 + ($58<<2)|0);
   $60 = HEAP32[$59>>2]|0;
   FUNCTION_TABLE_vii[$60 & 4095]($54,$cache);
   $61 = (($i4$07) + 1)|0;
   $exitcond27 = ($61|0)==($contactConstraintListSize|0);
   if ($exitcond27) {
    break;
   } else {
    $i4$07 = $61;
   }
  }
 }
 $62 = (1 - ($velocityIterations))|0;
 $63 = ($62|0)<(1);
 if (!($63)) {
  STACKTOP = sp;return;
 }
 $64 = ($frictionConstraintListSize|0)!=(0);
 if ($49) {
  $iteration5$04 = $62;
  while(1) {
   if ($64) {
    $i7$02 = 0;
    while(1) {
     $83 = (($frictionConstraintList) + ($i7$02<<5)|0);
     $84 = ((($frictionConstraintList) + ($i7$02<<5)|0) + 16|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = HEAP8[$85>>0]|0;
     $87 = $86&255;
     $88 = (501952 + ($87<<2)|0);
     $89 = HEAP32[$88>>2]|0;
     FUNCTION_TABLE_vii[$89 & 4095]($83,$cache);
     $90 = (($i7$02) + 1)|0;
     $exitcond = ($90|0)==($frictionConstraintListSize|0);
     if ($exitcond) {
      break;
     } else {
      $i7$02 = $90;
     }
    }
   }
   $91 = (($iteration5$04) + 1)|0;
   $92 = ($iteration5$04|0)<(0);
   if ($92) {
    $iteration5$04 = $91;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else {
  $iteration5$04$us = $62;
 }
 while(1) {
  $i6$01$us = 0;
  while(1) {
   $75 = (($contactConstraintList) + ($i6$01$us<<5)|0);
   $76 = ((($contactConstraintList) + ($i6$01$us<<5)|0) + 16|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = HEAP8[$77>>0]|0;
   $79 = $78&255;
   $80 = (501952 + ($79<<2)|0);
   $81 = HEAP32[$80>>2]|0;
   FUNCTION_TABLE_vii[$81 & 4095]($75,$cache);
   $82 = (($i6$01$us) + 1)|0;
   $exitcond31 = ($82|0)==($contactConstraintListSize|0);
   if ($exitcond31) {
    break;
   } else {
    $i6$01$us = $82;
   }
  }
  if ($64) {
   $i7$02$us = 0;
   while(1) {
    $67 = (($frictionConstraintList) + ($i7$02$us<<5)|0);
    $68 = ((($frictionConstraintList) + ($i7$02$us<<5)|0) + 16|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = HEAP8[$69>>0]|0;
    $71 = $70&255;
    $72 = (501952 + ($71<<2)|0);
    $73 = HEAP32[$72>>2]|0;
    FUNCTION_TABLE_vii[$73 & 4095]($67,$cache);
    $74 = (($i7$02$us) + 1)|0;
    $exitcond32 = ($74|0)==($frictionConstraintListSize|0);
    if ($exitcond32) {
     break;
    } else {
     $i7$02$us = $74;
    }
   }
  }
  $65 = (($iteration5$04$us) + 1)|0;
  $66 = ($iteration5$04$us|0)<(0);
  if ($66) {
   $iteration5$04$us = $65;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsSolverCoreGeneral13solveV_BlocksEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jRNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENS9_19ReflectionAllocatorISB_EEEESF_PNS_2Cm13SpatialVectorEPNS_25PxcThresholdStreamElementEjRj($this,$0,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$1,$atomListSize,$articulationListStart,$articulationListSize,$contactConstraintList,$contactConstraintListSize,$2,$3,$contactConstraintBatchHeaders,$frictionConstraintBatchHeaders,$motionVelocityArray,$thresholdStream,$thresholdStreamLength,$outThresholdPairs) {
 $this = $this|0;
 $0 = Math_fround($0);
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $1 = $1|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $contactConstraintList = $contactConstraintList|0;
 $contactConstraintListSize = $contactConstraintListSize|0;
 $2 = $2|0;
 $3 = $3|0;
 $contactConstraintBatchHeaders = $contactConstraintBatchHeaders|0;
 $frictionConstraintBatchHeaders = $frictionConstraintBatchHeaders|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $$sum$i = 0, $$sum$i13 = 0, $$sum$i4 = 0, $$sum1$i = 0, $$sum1$i14 = 0, $$sum1$i5 = 0, $$sum2$i = 0, $$sum2$i15 = 0, $$sum2$i6 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $18 = Math_fround(0), $19 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0;
 var $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_ZN5physxL25gVTableSolveConcludeBlockE$_ZN5physxL17gVTableSolveBlockE = 0, $b$03$i = 0, $b$03$i12 = 0, $b$03$i3 = 0;
 var $baIdx$021 = 0, $baIdx1$034 = 0, $cache = 0, $exitcond = 0, $exitcond39 = 0, $exitcond40 = 0, $exitcond41 = 0, $exitcond42 = 0, $exitcond43 = 0, $exitcond44 = 0, $exitcond45 = 0, $exitcond46 = 0, $i$019 = 0, $i$04$i = 0, $i$04$i1 = 0, $i$04$i10 = 0, $i4$030 = 0, $iteration$037 = 0, $iteration5$0$lcssa = 0, $iteration5$025 = 0;
 var $iteration5$123 = 0, $phitmp = 0, $threshPairOut = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $cache = sp + 4|0;
 $threshPairOut = sp;
 $4 = (($cache) + 16|0);
 HEAP32[$4>>2] = $atomDataList;
 $5 = (($cache) + 4|0);
 HEAP32[$5>>2] = $thresholdStream;
 $6 = (($thresholdStreamLength) + 4)|0;
 $7 = (($cache) + 12|0);
 HEAP32[$7>>2] = $6;
 $8 = (($cache) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($cache) + 1|0);
 HEAP8[$9>>0] = 0;
 $10 = (($contactConstraintBatchHeaders) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($contactConstraintListSize|0)==(0);
 if ($12) {
  $15 = ($atomListSize|0)==(0);
  if (!($15)) {
   $baIdx$021 = 0;
   while(1) {
    $17 = (($atomListStart) + ($baIdx$021<<5)|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = (($motionVelocityArray) + ($baIdx$021<<5)|0);
    HEAPF32[$19>>2] = $18;
    $20 = ((($atomListStart) + ($baIdx$021<<5)|0) + 4|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = ((($motionVelocityArray) + ($baIdx$021<<5)|0) + 4|0);
    HEAPF32[$22>>2] = $21;
    $23 = ((($atomListStart) + ($baIdx$021<<5)|0) + 8|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = ((($motionVelocityArray) + ($baIdx$021<<5)|0) + 8|0);
    HEAPF32[$25>>2] = $24;
    $26 = ((($atomListStart) + ($baIdx$021<<5)|0) + 16|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = ((($motionVelocityArray) + ($baIdx$021<<5)|0) + 16|0);
    HEAPF32[$28>>2] = $27;
    $29 = ((($atomListStart) + ($baIdx$021<<5)|0) + 20|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = ((($motionVelocityArray) + ($baIdx$021<<5)|0) + 20|0);
    HEAPF32[$31>>2] = $30;
    $32 = ((($atomListStart) + ($baIdx$021<<5)|0) + 24|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = ((($motionVelocityArray) + ($baIdx$021<<5)|0) + 24|0);
    HEAPF32[$34>>2] = $33;
    $35 = (($baIdx$021) + 1)|0;
    $exitcond39 = ($35|0)==($atomListSize|0);
    if ($exitcond39) {
     break;
    } else {
     $baIdx$021 = $35;
    }
   }
  }
  $16 = ($articulationListSize|0)==(0);
  if ($16) {
   STACKTOP = sp;return;
  } else {
   $i$019 = 0;
  }
  while(1) {
   $36 = HEAP32[503528>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = (($articulationListStart) + (($i$019*40)|0)|0);
    __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($38);
   }
   $39 = (($i$019) + 1)|0;
   $exitcond = ($39|0)==($articulationListSize|0);
   if ($exitcond) {
    break;
   } else {
    $i$019 = $39;
   }
  }
  STACKTOP = sp;return;
 }
 $13 = ($positionIterations|0)>(0);
 if ($13) {
  $14 = ($11|0)>(0);
  $iteration$037 = $positionIterations;
  while(1) {
   $41 = ($iteration$037|0)<(4);
   $42 = $41&1;
   HEAP8[$cache>>0] = $42;
   $43 = ($iteration$037|0)==(1);
   $_ZN5physxL25gVTableSolveConcludeBlockE$_ZN5physxL17gVTableSolveBlockE = $43 ? 501912 : 501832;
   $44 = HEAP32[$contactConstraintBatchHeaders>>2]|0;
   if ($14) {
    $i$04$i10 = 0;
    while(1) {
     $45 = ((($44) + ($i$04$i10<<3)|0) + 4|0);
     $46 = HEAP16[$45>>1]|0;
     $47 = $46&65535;
     $48 = (($47) + -1)|0;
     $49 = (($44) + ($i$04$i10<<3)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (($contactConstraintList) + ($50<<5)|0);
     $52 = ($46<<16>>16)==(0);
     if (!($52)) {
      $b$03$i12 = 0;
      while(1) {
       $53 = (($b$03$i12) + 2)|0;
       $54 = ($53|0)<($48|0);
       $55 = $54 ? $53 : $48;
       $$sum$i13 = (($b$03$i12) + ($50))|0;
       $56 = ((($contactConstraintList) + ($$sum$i13<<5)|0) + 16|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = HEAP32[$56>>2]|0;
       $59 = (($58) + 128|0);
       $60 = HEAP32[$56>>2]|0;
       $61 = (($60) + 256|0);
       $$sum1$i14 = (($55) + ($50))|0;
       $62 = (($contactConstraintList) + ($$sum1$i14<<5)|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = ((($contactConstraintList) + ($$sum1$i14<<5)|0) + 4|0);
       $65 = HEAP32[$64>>2]|0;
       $$sum2$i15 = (($$sum$i13) + 8)|0;
       $66 = (($contactConstraintList) + ($$sum2$i15<<5)|0);
       $67 = (($b$03$i12) + 1)|0;
       $68 = ($67|0)<($47|0);
       if ($68) {
        $b$03$i12 = $67;
       } else {
        break;
       }
      }
     }
     $69 = ((($44) + ($i$04$i10<<3)|0) + 6|0);
     $70 = HEAP16[$69>>1]|0;
     $71 = $70&65535;
     $72 = (($_ZN5physxL25gVTableSolveConcludeBlockE$_ZN5physxL17gVTableSolveBlockE) + ($71<<2)|0);
     $73 = HEAP32[$72>>2]|0;
     FUNCTION_TABLE_viii[$73 & 4095]($51,$47,$cache);
     $74 = (($i$04$i10) + 1)|0;
     $exitcond46 = ($74|0)==($11|0);
     if ($exitcond46) {
      break;
     } else {
      $i$04$i10 = $74;
     }
    }
   }
   $75 = (($iteration$037) + -1)|0;
   $76 = ($75|0)>(0);
   if ($76) {
    $iteration$037 = $75;
   } else {
    break;
   }
  }
 }
 $40 = ($atomListSize|0)==(0);
 if (!($40)) {
  $baIdx1$034 = 0;
  while(1) {
   $78 = (($atomListStart) + ($baIdx1$034<<5)|0);
   $79 = Math_fround(HEAPF32[$78>>2]);
   $80 = (($motionVelocityArray) + ($baIdx1$034<<5)|0);
   HEAPF32[$80>>2] = $79;
   $81 = ((($atomListStart) + ($baIdx1$034<<5)|0) + 4|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $83 = ((($motionVelocityArray) + ($baIdx1$034<<5)|0) + 4|0);
   HEAPF32[$83>>2] = $82;
   $84 = ((($atomListStart) + ($baIdx1$034<<5)|0) + 8|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = ((($motionVelocityArray) + ($baIdx1$034<<5)|0) + 8|0);
   HEAPF32[$86>>2] = $85;
   $87 = ((($atomListStart) + ($baIdx1$034<<5)|0) + 16|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = ((($motionVelocityArray) + ($baIdx1$034<<5)|0) + 16|0);
   HEAPF32[$89>>2] = $88;
   $90 = ((($atomListStart) + ($baIdx1$034<<5)|0) + 20|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = ((($motionVelocityArray) + ($baIdx1$034<<5)|0) + 20|0);
   HEAPF32[$92>>2] = $91;
   $93 = ((($atomListStart) + ($baIdx1$034<<5)|0) + 24|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = ((($motionVelocityArray) + ($baIdx1$034<<5)|0) + 24|0);
   HEAPF32[$95>>2] = $94;
   $96 = (($baIdx1$034) + 1)|0;
   $exitcond45 = ($96|0)==($atomListSize|0);
   if ($exitcond45) {
    break;
   } else {
    $baIdx1$034 = $96;
   }
  }
 }
 $77 = ($articulationListSize|0)==(0);
 if (!($77)) {
  $i4$030 = 0;
  while(1) {
   $97 = HEAP32[503528>>2]|0;
   $98 = ($97|0)==(0|0);
   if (!($98)) {
    $99 = (($articulationListStart) + (($i4$030*40)|0)|0);
    __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($99);
   }
   $100 = (($i4$030) + 1)|0;
   $exitcond44 = ($100|0)==($articulationListSize|0);
   if ($exitcond44) {
    break;
   } else {
    $i4$030 = $100;
   }
  }
 }
 $101 = (($velocityIterations) + -1)|0;
 $102 = ($101|0)>(0);
 L40: do {
  if ($102) {
   $103 = ($11|0)>(0);
   $iteration5$025 = 1;
   while(1) {
    $104 = HEAP32[$contactConstraintBatchHeaders>>2]|0;
    if ($103) {
     $i$04$i1 = 0;
     while(1) {
      $105 = ((($104) + ($i$04$i1<<3)|0) + 4|0);
      $106 = HEAP16[$105>>1]|0;
      $107 = $106&65535;
      $108 = (($107) + -1)|0;
      $109 = (($104) + ($i$04$i1<<3)|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = (($contactConstraintList) + ($110<<5)|0);
      $112 = ($106<<16>>16)==(0);
      if (!($112)) {
       $b$03$i3 = 0;
       while(1) {
        $113 = (($b$03$i3) + 2)|0;
        $114 = ($113|0)<($108|0);
        $115 = $114 ? $113 : $108;
        $$sum$i4 = (($b$03$i3) + ($110))|0;
        $116 = ((($contactConstraintList) + ($$sum$i4<<5)|0) + 16|0);
        $117 = HEAP32[$116>>2]|0;
        $118 = HEAP32[$116>>2]|0;
        $119 = (($118) + 128|0);
        $120 = HEAP32[$116>>2]|0;
        $121 = (($120) + 256|0);
        $$sum1$i5 = (($115) + ($110))|0;
        $122 = (($contactConstraintList) + ($$sum1$i5<<5)|0);
        $123 = HEAP32[$122>>2]|0;
        $124 = ((($contactConstraintList) + ($$sum1$i5<<5)|0) + 4|0);
        $125 = HEAP32[$124>>2]|0;
        $$sum2$i6 = (($$sum$i4) + 8)|0;
        $126 = (($contactConstraintList) + ($$sum2$i6<<5)|0);
        $127 = (($b$03$i3) + 1)|0;
        $128 = ($127|0)<($107|0);
        if ($128) {
         $b$03$i3 = $127;
        } else {
         break;
        }
       }
      }
      $129 = ((($104) + ($i$04$i1<<3)|0) + 6|0);
      $130 = HEAP16[$129>>1]|0;
      $131 = $130&65535;
      $132 = (501832 + ($131<<2)|0);
      $133 = HEAP32[$132>>2]|0;
      FUNCTION_TABLE_viii[$133 & 4095]($111,$107,$cache);
      $134 = (($i$04$i1) + 1)|0;
      $exitcond42 = ($134|0)==($11|0);
      if ($exitcond42) {
       break;
      } else {
       $i$04$i1 = $134;
      }
     }
    }
    $exitcond43 = ($iteration5$025|0)==($101|0);
    if ($exitcond43) {
     $iteration5$0$lcssa = $101;
     break L40;
    }
    $phitmp = (($iteration5$025) + 1)|0;
    $iteration5$025 = $phitmp;
   }
  } else {
   $iteration5$0$lcssa = 0;
  }
 } while(0);
 $135 = HEAP32[$outThresholdPairs>>2]|0;
 HEAP32[$threshPairOut>>2] = $135;
 HEAP8[$9>>0] = 1;
 $136 = ($iteration5$0$lcssa|0)<($velocityIterations|0);
 if ($136) {
  $137 = ($11|0)>(0);
  $iteration5$123 = $iteration5$0$lcssa;
  while(1) {
   $138 = HEAP32[$contactConstraintBatchHeaders>>2]|0;
   if ($137) {
    $i$04$i = 0;
    while(1) {
     $139 = ((($138) + ($i$04$i<<3)|0) + 4|0);
     $140 = HEAP16[$139>>1]|0;
     $141 = $140&65535;
     $142 = (($141) + -1)|0;
     $143 = (($138) + ($i$04$i<<3)|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = (($contactConstraintList) + ($144<<5)|0);
     $146 = ($140<<16>>16)==(0);
     if (!($146)) {
      $b$03$i = 0;
      while(1) {
       $147 = (($b$03$i) + 2)|0;
       $148 = ($147|0)<($142|0);
       $149 = $148 ? $147 : $142;
       $$sum$i = (($b$03$i) + ($144))|0;
       $150 = ((($contactConstraintList) + ($$sum$i<<5)|0) + 16|0);
       $151 = HEAP32[$150>>2]|0;
       $152 = HEAP32[$150>>2]|0;
       $153 = (($152) + 128|0);
       $154 = HEAP32[$150>>2]|0;
       $155 = (($154) + 256|0);
       $$sum1$i = (($149) + ($144))|0;
       $156 = (($contactConstraintList) + ($$sum1$i<<5)|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = ((($contactConstraintList) + ($$sum1$i<<5)|0) + 4|0);
       $159 = HEAP32[$158>>2]|0;
       $$sum2$i = (($$sum$i) + 8)|0;
       $160 = (($contactConstraintList) + ($$sum2$i<<5)|0);
       $161 = (($b$03$i) + 1)|0;
       $162 = ($161|0)<($141|0);
       if ($162) {
        $b$03$i = $161;
       } else {
        break;
       }
      }
     }
     $163 = ((($138) + ($i$04$i<<3)|0) + 6|0);
     $164 = HEAP16[$163>>1]|0;
     $165 = $164&65535;
     $166 = (501872 + ($165<<2)|0);
     $167 = HEAP32[$166>>2]|0;
     FUNCTION_TABLE_viiiiii[$167 & 255]($145,$141,$cache,$thresholdStream,$thresholdStreamLength,$threshPairOut);
     $168 = (($i$04$i) + 1)|0;
     $exitcond40 = ($168|0)==($11|0);
     if ($exitcond40) {
      break;
     } else {
      $i$04$i = $168;
     }
    }
   }
   $169 = (($iteration5$123) + 1)|0;
   $exitcond41 = ($169|0)==($velocityIterations|0);
   if ($exitcond41) {
    break;
   } else {
    $iteration5$123 = $169;
   }
  }
 }
 $170 = HEAP32[$8>>2]|0;
 HEAP32[$outThresholdPairs>>2] = $170;
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsSolverCoreGeneral20solveVCoulomb_BlocksEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jRNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENS9_19ReflectionAllocatorISB_EEEESF_PNS_2Cm13SpatialVectorEPNS_25PxcThresholdStreamElementEjRj($this,$0,$positionIterations,$velocityIterations,$atomListStart,$atomDataList,$1,$atomListSize,$articulationListStart,$articulationListSize,$contactConstraintList,$contactConstraintListSize,$frictionConstraintList,$frictionConstraintListSize,$contactConstraintBatchHeaders,$frictionConstraintBatchHeaders,$motionVelocityArray,$thresholdStream,$thresholdStreamLength,$outThresholdPairs) {
 $this = $this|0;
 $0 = Math_fround($0);
 $positionIterations = $positionIterations|0;
 $velocityIterations = $velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $1 = $1|0;
 $atomListSize = $atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $articulationListSize = $articulationListSize|0;
 $contactConstraintList = $contactConstraintList|0;
 $contactConstraintListSize = $contactConstraintListSize|0;
 $frictionConstraintList = $frictionConstraintList|0;
 $frictionConstraintListSize = $frictionConstraintListSize|0;
 $contactConstraintBatchHeaders = $contactConstraintBatchHeaders|0;
 $frictionConstraintBatchHeaders = $frictionConstraintBatchHeaders|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $$sum$i = 0, $$sum$i14 = 0, $$sum$i22 = 0, $$sum$i32 = 0, $$sum$i41 = 0, $$sum$i5 = 0, $$sum1$i = 0, $$sum1$i15 = 0, $$sum1$i23 = 0, $$sum1$i33 = 0, $$sum1$i42 = 0, $$sum1$i6 = 0, $$sum2$i = 0, $$sum2$i16 = 0, $$sum2$i24 = 0, $$sum2$i34 = 0, $$sum2$i43 = 0, $$sum2$i7 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0;
 var $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_ZN5physxL32gVTableSolveConcludeBlockCoulombE$_ZN5physxL24gVTableSolveBlockCoulombE = 0, $_ZN5physxL32gVTableSolveConcludeBlockCoulombE$_ZN5physxL24gVTableSolveBlockCoulombE1 = 0, $b$03$i = 0, $b$03$i13 = 0, $b$03$i21 = 0, $b$03$i31 = 0, $b$03$i4 = 0, $b$03$i40 = 0, $baIdx$049 = 0, $baIdx2$064 = 0, $cache = 0, $exitcond = 0, $exitcond77 = 0;
 var $exitcond78 = 0, $exitcond79 = 0, $exitcond80 = 0, $exitcond81 = 0, $exitcond82 = 0, $exitcond83 = 0, $exitcond84 = 0, $exitcond85 = 0, $exitcond86 = 0, $exitcond87 = 0, $exitcond88 = 0, $frictionIter$068 = 0, $i$04$i = 0, $i$04$i11 = 0, $i$04$i19 = 0, $i$04$i2 = 0, $i$04$i29 = 0, $i$04$i38 = 0, $i$047 = 0, $i5$061 = 0;
 var $iteration$073 = 0, $iteration1$069 = 0, $iteration6$0$lcssa = 0, $iteration6$055 = 0, $iteration6$152 = 0, $phitmp = 0, $phitmp92 = 0, $threshPairOut = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $cache = sp + 4|0;
 $threshPairOut = sp;
 $2 = (($cache) + 16|0);
 HEAP32[$2>>2] = $atomDataList;
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $thresholdStream;
 $4 = (($thresholdStreamLength) + 4)|0;
 $5 = (($cache) + 12|0);
 HEAP32[$5>>2] = $4;
 $6 = (($cache) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($cache) + 1|0);
 HEAP8[$7>>0] = 0;
 $8 = ($contactConstraintListSize|0)==(0);
 if ($8) {
  $9 = ($atomListSize|0)==(0);
  if (!($9)) {
   $baIdx$049 = 0;
   while(1) {
    $11 = (($atomListStart) + ($baIdx$049<<5)|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    $13 = (($motionVelocityArray) + ($baIdx$049<<5)|0);
    HEAPF32[$13>>2] = $12;
    $14 = ((($atomListStart) + ($baIdx$049<<5)|0) + 4|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = ((($motionVelocityArray) + ($baIdx$049<<5)|0) + 4|0);
    HEAPF32[$16>>2] = $15;
    $17 = ((($atomListStart) + ($baIdx$049<<5)|0) + 8|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = ((($motionVelocityArray) + ($baIdx$049<<5)|0) + 8|0);
    HEAPF32[$19>>2] = $18;
    $20 = ((($atomListStart) + ($baIdx$049<<5)|0) + 16|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = ((($motionVelocityArray) + ($baIdx$049<<5)|0) + 16|0);
    HEAPF32[$22>>2] = $21;
    $23 = ((($atomListStart) + ($baIdx$049<<5)|0) + 20|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = ((($motionVelocityArray) + ($baIdx$049<<5)|0) + 20|0);
    HEAPF32[$25>>2] = $24;
    $26 = ((($atomListStart) + ($baIdx$049<<5)|0) + 24|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = ((($motionVelocityArray) + ($baIdx$049<<5)|0) + 24|0);
    HEAPF32[$28>>2] = $27;
    $29 = (($baIdx$049) + 1)|0;
    $exitcond77 = ($29|0)==($atomListSize|0);
    if ($exitcond77) {
     break;
    } else {
     $baIdx$049 = $29;
    }
   }
  }
  $10 = ($articulationListSize|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $i$047 = 0;
  }
  while(1) {
   $30 = HEAP32[503528>>2]|0;
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    $32 = (($articulationListStart) + (($i$047*40)|0)|0);
    __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($32);
   }
   $33 = (($i$047) + 1)|0;
   $exitcond = ($33|0)==($articulationListSize|0);
   if ($exitcond) {
    break;
   } else {
    $i$047 = $33;
   }
  }
  STACKTOP = sp;return;
 }
 $34 = (($contactConstraintBatchHeaders) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($frictionConstraintBatchHeaders) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($positionIterations|0)>(0);
 if ($38) {
  $39 = ($35|0)>(0);
  $iteration$073 = $positionIterations;
  while(1) {
   $40 = ($iteration$073|0)==(1);
   $_ZN5physxL32gVTableSolveConcludeBlockCoulombE$_ZN5physxL24gVTableSolveBlockCoulombE = $40 ? 502192 : 502064;
   $41 = HEAP32[$contactConstraintBatchHeaders>>2]|0;
   if ($39) {
    $i$04$i38 = 0;
    while(1) {
     $42 = ((($41) + ($i$04$i38<<3)|0) + 4|0);
     $43 = HEAP16[$42>>1]|0;
     $44 = $43&65535;
     $45 = (($44) + -1)|0;
     $46 = (($41) + ($i$04$i38<<3)|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (($contactConstraintList) + ($47<<5)|0);
     $49 = ($43<<16>>16)==(0);
     if (!($49)) {
      $b$03$i40 = 0;
      while(1) {
       $50 = (($b$03$i40) + 2)|0;
       $51 = ($50|0)<($45|0);
       $52 = $51 ? $50 : $45;
       $$sum$i41 = (($b$03$i40) + ($47))|0;
       $53 = ((($contactConstraintList) + ($$sum$i41<<5)|0) + 16|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = HEAP32[$53>>2]|0;
       $56 = (($55) + 128|0);
       $57 = HEAP32[$53>>2]|0;
       $58 = (($57) + 256|0);
       $$sum1$i42 = (($52) + ($47))|0;
       $59 = (($contactConstraintList) + ($$sum1$i42<<5)|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ((($contactConstraintList) + ($$sum1$i42<<5)|0) + 4|0);
       $62 = HEAP32[$61>>2]|0;
       $$sum2$i43 = (($$sum$i41) + 8)|0;
       $63 = (($contactConstraintList) + ($$sum2$i43<<5)|0);
       $64 = (($b$03$i40) + 1)|0;
       $65 = ($64|0)<($44|0);
       if ($65) {
        $b$03$i40 = $64;
       } else {
        break;
       }
      }
     }
     $66 = ((($41) + ($i$04$i38<<3)|0) + 6|0);
     $67 = HEAP16[$66>>1]|0;
     $68 = $67&65535;
     $69 = (($_ZN5physxL32gVTableSolveConcludeBlockCoulombE$_ZN5physxL24gVTableSolveBlockCoulombE) + ($68<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     FUNCTION_TABLE_viii[$70 & 4095]($48,$44,$cache);
     $71 = (($i$04$i38) + 1)|0;
     $exitcond88 = ($71|0)==($35|0);
     if ($exitcond88) {
      break;
     } else {
      $i$04$i38 = $71;
     }
    }
   }
   $72 = (($iteration$073) + -1)|0;
   $73 = ($72|0)>(0);
   if ($73) {
    $iteration$073 = $72;
   } else {
    break;
   }
  }
 }
 $74 = ($frictionConstraintListSize|0)==(0);
 L29: do {
  if (!($74)) {
   $75 = $positionIterations << 1;
   $76 = ($75|0)>(0);
   if ($76) {
    $77 = ($37|0)>(0);
    $78 = $positionIterations << 1;
    $frictionIter$068 = 1;$iteration1$069 = $75;
    while(1) {
     $79 = ($iteration1$069|0)==(1);
     $_ZN5physxL32gVTableSolveConcludeBlockCoulombE$_ZN5physxL24gVTableSolveBlockCoulombE1 = $79 ? 502192 : 502064;
     $80 = HEAP32[$frictionConstraintBatchHeaders>>2]|0;
     if ($77) {
      $i$04$i29 = 0;
      while(1) {
       $81 = ((($80) + ($i$04$i29<<3)|0) + 4|0);
       $82 = HEAP16[$81>>1]|0;
       $83 = $82&65535;
       $84 = (($83) + -1)|0;
       $85 = (($80) + ($i$04$i29<<3)|0);
       $86 = HEAP32[$85>>2]|0;
       $87 = (($frictionConstraintList) + ($86<<5)|0);
       $88 = ($82<<16>>16)==(0);
       if (!($88)) {
        $b$03$i31 = 0;
        while(1) {
         $89 = (($b$03$i31) + 2)|0;
         $90 = ($89|0)<($84|0);
         $91 = $90 ? $89 : $84;
         $$sum$i32 = (($b$03$i31) + ($86))|0;
         $92 = ((($frictionConstraintList) + ($$sum$i32<<5)|0) + 16|0);
         $93 = HEAP32[$92>>2]|0;
         $94 = HEAP32[$92>>2]|0;
         $95 = (($94) + 128|0);
         $96 = HEAP32[$92>>2]|0;
         $97 = (($96) + 256|0);
         $$sum1$i33 = (($91) + ($86))|0;
         $98 = (($frictionConstraintList) + ($$sum1$i33<<5)|0);
         $99 = HEAP32[$98>>2]|0;
         $100 = ((($frictionConstraintList) + ($$sum1$i33<<5)|0) + 4|0);
         $101 = HEAP32[$100>>2]|0;
         $$sum2$i34 = (($$sum$i32) + 8)|0;
         $102 = (($frictionConstraintList) + ($$sum2$i34<<5)|0);
         $103 = (($b$03$i31) + 1)|0;
         $104 = ($103|0)<($83|0);
         if ($104) {
          $b$03$i31 = $103;
         } else {
          break;
         }
        }
       }
       $105 = ((($80) + ($i$04$i29<<3)|0) + 6|0);
       $106 = HEAP16[$105>>1]|0;
       $107 = $106&65535;
       $108 = (($_ZN5physxL32gVTableSolveConcludeBlockCoulombE$_ZN5physxL24gVTableSolveBlockCoulombE1) + ($107<<2)|0);
       $109 = HEAP32[$108>>2]|0;
       FUNCTION_TABLE_viii[$109 & 4095]($87,$83,$cache);
       $110 = (($i$04$i29) + 1)|0;
       $exitcond86 = ($110|0)==($37|0);
       if ($exitcond86) {
        break;
       } else {
        $i$04$i29 = $110;
       }
      }
     }
     $exitcond87 = ($frictionIter$068|0)==($78|0);
     if ($exitcond87) {
      break L29;
     }
     $111 = (($iteration1$069) + -1)|0;
     $phitmp92 = (($frictionIter$068) + 1)|0;
     $frictionIter$068 = $phitmp92;$iteration1$069 = $111;
    }
   }
  }
 } while(0);
 $112 = ($atomListSize|0)==(0);
 if (!($112)) {
  $baIdx2$064 = 0;
  while(1) {
   $114 = (($atomListStart) + ($baIdx2$064<<5)|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = (($motionVelocityArray) + ($baIdx2$064<<5)|0);
   HEAPF32[$116>>2] = $115;
   $117 = ((($atomListStart) + ($baIdx2$064<<5)|0) + 4|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = ((($motionVelocityArray) + ($baIdx2$064<<5)|0) + 4|0);
   HEAPF32[$119>>2] = $118;
   $120 = ((($atomListStart) + ($baIdx2$064<<5)|0) + 8|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = ((($motionVelocityArray) + ($baIdx2$064<<5)|0) + 8|0);
   HEAPF32[$122>>2] = $121;
   $123 = ((($atomListStart) + ($baIdx2$064<<5)|0) + 16|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = ((($motionVelocityArray) + ($baIdx2$064<<5)|0) + 16|0);
   HEAPF32[$125>>2] = $124;
   $126 = ((($atomListStart) + ($baIdx2$064<<5)|0) + 20|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = ((($motionVelocityArray) + ($baIdx2$064<<5)|0) + 20|0);
   HEAPF32[$128>>2] = $127;
   $129 = ((($atomListStart) + ($baIdx2$064<<5)|0) + 24|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = ((($motionVelocityArray) + ($baIdx2$064<<5)|0) + 24|0);
   HEAPF32[$131>>2] = $130;
   $132 = (($baIdx2$064) + 1)|0;
   $exitcond85 = ($132|0)==($atomListSize|0);
   if ($exitcond85) {
    break;
   } else {
    $baIdx2$064 = $132;
   }
  }
 }
 $113 = ($articulationListSize|0)==(0);
 if (!($113)) {
  $i5$061 = 0;
  while(1) {
   $133 = HEAP32[503528>>2]|0;
   $134 = ($133|0)==(0|0);
   if (!($134)) {
    $135 = (($articulationListStart) + (($i5$061*40)|0)|0);
    __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($135);
   }
   $136 = (($i5$061) + 1)|0;
   $exitcond84 = ($136|0)==($articulationListSize|0);
   if ($exitcond84) {
    break;
   } else {
    $i5$061 = $136;
   }
  }
 }
 $137 = (($velocityIterations) + -1)|0;
 $138 = ($137|0)>(0);
 L55: do {
  if ($138) {
   $139 = ($35|0)>(0);
   $140 = ($37|0)>(0);
   $iteration6$055 = 1;
   while(1) {
    $141 = HEAP32[$contactConstraintBatchHeaders>>2]|0;
    if ($139) {
     $i$04$i19 = 0;
     while(1) {
      $142 = ((($141) + ($i$04$i19<<3)|0) + 4|0);
      $143 = HEAP16[$142>>1]|0;
      $144 = $143&65535;
      $145 = (($144) + -1)|0;
      $146 = (($141) + ($i$04$i19<<3)|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = (($contactConstraintList) + ($147<<5)|0);
      $149 = ($143<<16>>16)==(0);
      if (!($149)) {
       $b$03$i21 = 0;
       while(1) {
        $150 = (($b$03$i21) + 2)|0;
        $151 = ($150|0)<($145|0);
        $152 = $151 ? $150 : $145;
        $$sum$i22 = (($b$03$i21) + ($147))|0;
        $153 = ((($contactConstraintList) + ($$sum$i22<<5)|0) + 16|0);
        $154 = HEAP32[$153>>2]|0;
        $155 = HEAP32[$153>>2]|0;
        $156 = (($155) + 128|0);
        $157 = HEAP32[$153>>2]|0;
        $158 = (($157) + 256|0);
        $$sum1$i23 = (($152) + ($147))|0;
        $159 = (($contactConstraintList) + ($$sum1$i23<<5)|0);
        $160 = HEAP32[$159>>2]|0;
        $161 = ((($contactConstraintList) + ($$sum1$i23<<5)|0) + 4|0);
        $162 = HEAP32[$161>>2]|0;
        $$sum2$i24 = (($$sum$i22) + 8)|0;
        $163 = (($contactConstraintList) + ($$sum2$i24<<5)|0);
        $164 = (($b$03$i21) + 1)|0;
        $165 = ($164|0)<($144|0);
        if ($165) {
         $b$03$i21 = $164;
        } else {
         break;
        }
       }
      }
      $166 = ((($141) + ($i$04$i19<<3)|0) + 6|0);
      $167 = HEAP16[$166>>1]|0;
      $168 = $167&65535;
      $169 = (502064 + ($168<<2)|0);
      $170 = HEAP32[$169>>2]|0;
      FUNCTION_TABLE_viii[$170 & 4095]($148,$144,$cache);
      $171 = (($i$04$i19) + 1)|0;
      $exitcond81 = ($171|0)==($35|0);
      if ($exitcond81) {
       break;
      } else {
       $i$04$i19 = $171;
      }
     }
    }
    if (!($74)) {
     $172 = HEAP32[$frictionConstraintBatchHeaders>>2]|0;
     if ($140) {
      $i$04$i11 = 0;
      while(1) {
       $173 = ((($172) + ($i$04$i11<<3)|0) + 4|0);
       $174 = HEAP16[$173>>1]|0;
       $175 = $174&65535;
       $176 = (($175) + -1)|0;
       $177 = (($172) + ($i$04$i11<<3)|0);
       $178 = HEAP32[$177>>2]|0;
       $179 = (($frictionConstraintList) + ($178<<5)|0);
       $180 = ($174<<16>>16)==(0);
       if (!($180)) {
        $b$03$i13 = 0;
        while(1) {
         $181 = (($b$03$i13) + 2)|0;
         $182 = ($181|0)<($176|0);
         $183 = $182 ? $181 : $176;
         $$sum$i14 = (($b$03$i13) + ($178))|0;
         $184 = ((($frictionConstraintList) + ($$sum$i14<<5)|0) + 16|0);
         $185 = HEAP32[$184>>2]|0;
         $186 = HEAP32[$184>>2]|0;
         $187 = (($186) + 128|0);
         $188 = HEAP32[$184>>2]|0;
         $189 = (($188) + 256|0);
         $$sum1$i15 = (($183) + ($178))|0;
         $190 = (($frictionConstraintList) + ($$sum1$i15<<5)|0);
         $191 = HEAP32[$190>>2]|0;
         $192 = ((($frictionConstraintList) + ($$sum1$i15<<5)|0) + 4|0);
         $193 = HEAP32[$192>>2]|0;
         $$sum2$i16 = (($$sum$i14) + 8)|0;
         $194 = (($frictionConstraintList) + ($$sum2$i16<<5)|0);
         $195 = (($b$03$i13) + 1)|0;
         $196 = ($195|0)<($175|0);
         if ($196) {
          $b$03$i13 = $195;
         } else {
          break;
         }
        }
       }
       $197 = ((($172) + ($i$04$i11<<3)|0) + 6|0);
       $198 = HEAP16[$197>>1]|0;
       $199 = $198&65535;
       $200 = (502064 + ($199<<2)|0);
       $201 = HEAP32[$200>>2]|0;
       FUNCTION_TABLE_viii[$201 & 4095]($179,$175,$cache);
       $202 = (($i$04$i11) + 1)|0;
       $exitcond82 = ($202|0)==($37|0);
       if ($exitcond82) {
        break;
       } else {
        $i$04$i11 = $202;
       }
      }
     }
    }
    $exitcond83 = ($iteration6$055|0)==($137|0);
    if ($exitcond83) {
     $iteration6$0$lcssa = $137;
     break L55;
    }
    $phitmp = (($iteration6$055) + 1)|0;
    $iteration6$055 = $phitmp;
   }
  } else {
   $iteration6$0$lcssa = 0;
  }
 } while(0);
 $203 = HEAP32[$outThresholdPairs>>2]|0;
 HEAP32[$threshPairOut>>2] = $203;
 HEAP8[$7>>0] = 1;
 $204 = ($iteration6$0$lcssa|0)<($velocityIterations|0);
 if ($204) {
  $205 = ($35|0)>(0);
  $206 = ($37|0)>(0);
  $iteration6$152 = $iteration6$0$lcssa;
  while(1) {
   $207 = HEAP32[$contactConstraintBatchHeaders>>2]|0;
   if ($205) {
    $i$04$i2 = 0;
    while(1) {
     $208 = ((($207) + ($i$04$i2<<3)|0) + 4|0);
     $209 = HEAP16[$208>>1]|0;
     $210 = $209&65535;
     $211 = (($210) + -1)|0;
     $212 = (($207) + ($i$04$i2<<3)|0);
     $213 = HEAP32[$212>>2]|0;
     $214 = (($contactConstraintList) + ($213<<5)|0);
     $215 = ($209<<16>>16)==(0);
     if (!($215)) {
      $b$03$i4 = 0;
      while(1) {
       $216 = (($b$03$i4) + 2)|0;
       $217 = ($216|0)<($211|0);
       $218 = $217 ? $216 : $211;
       $$sum$i5 = (($b$03$i4) + ($213))|0;
       $219 = ((($contactConstraintList) + ($$sum$i5<<5)|0) + 16|0);
       $220 = HEAP32[$219>>2]|0;
       $221 = HEAP32[$219>>2]|0;
       $222 = (($221) + 128|0);
       $223 = HEAP32[$219>>2]|0;
       $224 = (($223) + 256|0);
       $$sum1$i6 = (($218) + ($213))|0;
       $225 = (($contactConstraintList) + ($$sum1$i6<<5)|0);
       $226 = HEAP32[$225>>2]|0;
       $227 = ((($contactConstraintList) + ($$sum1$i6<<5)|0) + 4|0);
       $228 = HEAP32[$227>>2]|0;
       $$sum2$i7 = (($$sum$i5) + 8)|0;
       $229 = (($contactConstraintList) + ($$sum2$i7<<5)|0);
       $230 = (($b$03$i4) + 1)|0;
       $231 = ($230|0)<($210|0);
       if ($231) {
        $b$03$i4 = $230;
       } else {
        break;
       }
      }
     }
     $232 = ((($207) + ($i$04$i2<<3)|0) + 6|0);
     $233 = HEAP16[$232>>1]|0;
     $234 = $233&65535;
     $235 = (502128 + ($234<<2)|0);
     $236 = HEAP32[$235>>2]|0;
     FUNCTION_TABLE_viiiiii[$236 & 255]($214,$210,$cache,$thresholdStream,$thresholdStreamLength,$threshPairOut);
     $237 = (($i$04$i2) + 1)|0;
     $exitcond78 = ($237|0)==($35|0);
     if ($exitcond78) {
      break;
     } else {
      $i$04$i2 = $237;
     }
    }
   }
   if (!($74)) {
    $238 = HEAP32[$frictionConstraintBatchHeaders>>2]|0;
    if ($206) {
     $i$04$i = 0;
     while(1) {
      $239 = ((($238) + ($i$04$i<<3)|0) + 4|0);
      $240 = HEAP16[$239>>1]|0;
      $241 = $240&65535;
      $242 = (($241) + -1)|0;
      $243 = (($238) + ($i$04$i<<3)|0);
      $244 = HEAP32[$243>>2]|0;
      $245 = (($frictionConstraintList) + ($244<<5)|0);
      $246 = ($240<<16>>16)==(0);
      if (!($246)) {
       $b$03$i = 0;
       while(1) {
        $247 = (($b$03$i) + 2)|0;
        $248 = ($247|0)<($242|0);
        $249 = $248 ? $247 : $242;
        $$sum$i = (($b$03$i) + ($244))|0;
        $250 = ((($frictionConstraintList) + ($$sum$i<<5)|0) + 16|0);
        $251 = HEAP32[$250>>2]|0;
        $252 = HEAP32[$250>>2]|0;
        $253 = (($252) + 128|0);
        $254 = HEAP32[$250>>2]|0;
        $255 = (($254) + 256|0);
        $$sum1$i = (($249) + ($244))|0;
        $256 = (($frictionConstraintList) + ($$sum1$i<<5)|0);
        $257 = HEAP32[$256>>2]|0;
        $258 = ((($frictionConstraintList) + ($$sum1$i<<5)|0) + 4|0);
        $259 = HEAP32[$258>>2]|0;
        $$sum2$i = (($$sum$i) + 8)|0;
        $260 = (($frictionConstraintList) + ($$sum2$i<<5)|0);
        $261 = (($b$03$i) + 1)|0;
        $262 = ($261|0)<($241|0);
        if ($262) {
         $b$03$i = $261;
        } else {
         break;
        }
       }
      }
      $263 = ((($238) + ($i$04$i<<3)|0) + 6|0);
      $264 = HEAP16[$263>>1]|0;
      $265 = $264&65535;
      $266 = (502128 + ($265<<2)|0);
      $267 = HEAP32[$266>>2]|0;
      FUNCTION_TABLE_viiiiii[$267 & 255]($245,$241,$cache,$thresholdStream,$thresholdStreamLength,$threshPairOut);
      $268 = (($i$04$i) + 1)|0;
      $exitcond79 = ($268|0)==($37|0);
      if ($exitcond79) {
       break;
      } else {
       $i$04$i = $268;
      }
     }
    }
   }
   $269 = (($iteration6$152) + 1)|0;
   $exitcond80 = ($269|0)==($velocityIterations|0);
   if ($exitcond80) {
    break;
   } else {
    $iteration6$152 = $269;
   }
  }
 }
 $270 = HEAP32[$6>>2]|0;
 HEAP32[$outThresholdPairs>>2] = $270;
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsSolverCoreGeneral26solveVParallelAndWriteBackEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjPiS9_PNS_25PxcThresholdStreamElementEjS9_RNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENSC_19ReflectionAllocatorISE_EEEESI_PNS_2Cm13SpatialVectorERi($this,$0,$_positionIterations,$_velocityIterations,$atomListStart,$atomDataList,$1,$_atomListSize,$articulationListStart,$_articulationListSize,$contactConstraintList,$2,$pConstraintIndex,$pAtomListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$contactConstraintBatches,$3,$motionVelocityArray,$_normalIterations) {
 $this = $this|0;
 $0 = Math_fround($0);
 $_positionIterations = $_positionIterations|0;
 $_velocityIterations = $_velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $1 = $1|0;
 $_atomListSize = $_atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $_articulationListSize = $_articulationListSize|0;
 $contactConstraintList = $contactConstraintList|0;
 $2 = $2|0;
 $pConstraintIndex = $pConstraintIndex|0;
 $pAtomListIndex = $pAtomListIndex|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $contactConstraintBatches = $contactConstraintBatches|0;
 $3 = $3|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $_normalIterations = $_normalIterations|0;
 var $$pre = 0, $$pre83 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $a$035 = 0, $a3$026 = 0, $aa$156 = 0, $aa$156$1 = 0, $cache = 0, $contactIter = 0, $endIndexCount$1$lcssa = 0, $endIndexCount$1$lcssa$1 = 0, $endIndexCount$160 = 0, $endIndexCount$160$1 = 0, $endIndexCount$2$be = 0, $endIndexCount$2$be$1 = 0, $endIndexCount$2$lcssa = 0;
 var $endIndexCount$2$lcssa$1 = 0, $endIndexCount$250 = 0, $endIndexCount$250$1 = 0, $endIndexCount$3$lcssa = 0, $endIndexCount$316 = 0, $endIndexCount$4$be = 0, $endIndexCount$4$lcssa = 0, $endIndexCount$47 = 0, $endIndexCount$5$be = 0, $endIndexCount$54 = 0, $endIndexCount2$0$be = 0, $endIndexCount2$0$lcssa = 0, $endIndexCount2$043 = 0, $endIndexCount2$132 = 0, $exitcond = 0, $exitcond76 = 0, $exitcond78 = 0, $exitcond81 = 0, $exitcond81$1 = 0, $index$1$lcssa = 0;
 var $index$1$lcssa$1 = 0, $index$159 = 0, $index$159$1 = 0, $index$2$be = 0, $index$2$be$1 = 0, $index$2$lcssa = 0, $index$2$lcssa$1 = 0, $index$249 = 0, $index$249$1 = 0, $index$3$lcssa = 0, $index$315 = 0, $index$4$be = 0, $index$4$lcssa = 0, $index$46 = 0, $index$5$be = 0, $index$53 = 0, $index2$0$be = 0, $index2$0$lcssa = 0, $index2$042 = 0, $index2$1$lcssa = 0;
 var $index2$136 = 0, $index2$2 = 0, $index2$231 = 0, $index2$233 = 0, $index2$325 = 0, $maxNormalIndex$1$lcssa = 0, $maxNormalIndex$1$lcssa$1 = 0, $maxNormalIndex$158 = 0, $maxNormalIndex$158$1 = 0, $maxNormalIndex$2$lcssa = 0, $maxNormalIndex$214 = 0, $normalIteration$1$lcssa = 0, $normalIteration$1$lcssa$1 = 0, $normalIteration$157 = 0, $normalIteration$157$1 = 0, $normalIteration$2 = 0, $normalIteration$2$in$lcssa = 0, $normalIteration$2$lcssa = 0, $normalIteration$212 = 0, $normalIteration$217 = 0;
 var $smax = 0, $smax77 = 0, $tempThresholdStream = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $cache = sp + 520|0;
 $tempThresholdStream = sp;
 $contactIter = sp + 512|0;
 $4 = (($cache) + 16|0);
 HEAP32[$4>>2] = $atomDataList;
 $5 = (($contactConstraintBatches) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($cache) + 4|0);
 HEAP32[$7>>2] = $tempThresholdStream;
 $8 = (($cache) + 12|0);
 HEAP32[$8>>2] = 32;
 $9 = (($cache) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($cache) + 1|0);
 HEAP8[$10>>0] = 0;
 $11 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,4)|0);
 $12 = (($11) + -4)|0;
 HEAP32[$contactIter>>2] = $contactConstraintBatches;
 $13 = (($contactIter) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($_positionIterations) + -1)|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $endIndexCount$1$lcssa = 4;$index$1$lcssa = $12;$maxNormalIndex$1$lcssa = 0;$normalIteration$1$lcssa = 0;
 } else {
  $16 = Math_imul($6, $14)|0;
  $aa$156 = 0;$endIndexCount$160 = 4;$index$159 = $12;$maxNormalIndex$158 = 0;$normalIteration$157 = 0;
  while(1) {
   $17 = (($maxNormalIndex$158) + ($6))|0;
   $18 = (($_positionIterations) - ($aa$156))|0;
   $19 = ($18>>>0)<(4);
   $20 = $19&1;
   HEAP8[$cache>>0] = $20;
   $21 = ($index$159|0)<($17|0);
   if ($21) {
    $endIndexCount$250 = $endIndexCount$160;$index$249 = $index$159;
    while(1) {
     $22 = (($17) - ($index$249))|0;
     $23 = ($22|0)<($endIndexCount$250|0);
     $24 = $23 ? $22 : $endIndexCount$250;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($contactConstraintList,$24,$index$249,$6,$cache,$contactIter,501832,$normalIteration$157,0,$normalIteration$157);
     $25 = (($24) + ($index$249))|0;
     $26 = (($endIndexCount$250) - ($24))|0;
     $27 = ($endIndexCount$250|0)==($24|0);
     if ($27) {
      $28 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,4)|0);
      $29 = (($28) + -4)|0;
      $endIndexCount$2$be = 4;$index$2$be = $29;
     } else {
      $endIndexCount$2$be = $26;$index$2$be = $25;
     }
     $30 = ($index$2$be|0)<($17|0);
     if ($30) {
      $endIndexCount$250 = $endIndexCount$2$be;$index$249 = $index$2$be;
     } else {
      $endIndexCount$2$lcssa = $endIndexCount$2$be;$index$2$lcssa = $index$2$be;
      break;
     }
    }
   } else {
    $endIndexCount$2$lcssa = $endIndexCount$160;$index$2$lcssa = $index$159;
   }
   $31 = (($normalIteration$157) + 1)|0;
   $32 = (($aa$156) + 1)|0;
   $exitcond81 = ($32|0)==($14|0);
   if ($exitcond81) {
    $endIndexCount$1$lcssa = $endIndexCount$2$lcssa;$index$1$lcssa = $index$2$lcssa;$maxNormalIndex$1$lcssa = $16;$normalIteration$1$lcssa = $14;
    break;
   } else {
    $aa$156 = $32;$endIndexCount$160 = $endIndexCount$2$lcssa;$index$159 = $index$2$lcssa;$maxNormalIndex$158 = $17;$normalIteration$157 = $31;
   }
  }
 }
 $33 = ($normalIteration$1$lcssa>>>0)<($_positionIterations>>>0);
 if ($33) {
  $147 = (($_positionIterations) - ($normalIteration$1$lcssa))|0;
  $148 = Math_imul($6, $147)|0;
  $aa$156$1 = $normalIteration$1$lcssa;$endIndexCount$160$1 = $endIndexCount$1$lcssa;$index$159$1 = $index$1$lcssa;$maxNormalIndex$158$1 = $maxNormalIndex$1$lcssa;$normalIteration$157$1 = $normalIteration$1$lcssa;
  while(1) {
   $149 = (($maxNormalIndex$158$1) + ($6))|0;
   $150 = (($_positionIterations) - ($aa$156$1))|0;
   $151 = ($150>>>0)<(4);
   $152 = $151&1;
   HEAP8[$cache>>0] = $152;
   $153 = ($index$159$1|0)<($149|0);
   if ($153) {
    $endIndexCount$250$1 = $endIndexCount$160$1;$index$249$1 = $index$159$1;
    while(1) {
     $154 = (($149) - ($index$249$1))|0;
     $155 = ($154|0)<($endIndexCount$250$1|0);
     $156 = $155 ? $154 : $endIndexCount$250$1;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($contactConstraintList,$156,$index$249$1,$6,$cache,$contactIter,501912,$normalIteration$157$1,0,$normalIteration$157$1);
     $157 = (($156) + ($index$249$1))|0;
     $158 = (($endIndexCount$250$1) - ($156))|0;
     $159 = ($endIndexCount$250$1|0)==($156|0);
     if ($159) {
      $160 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,4)|0);
      $161 = (($160) + -4)|0;
      $endIndexCount$2$be$1 = 4;$index$2$be$1 = $161;
     } else {
      $endIndexCount$2$be$1 = $158;$index$2$be$1 = $157;
     }
     $162 = ($index$2$be$1|0)<($149|0);
     if ($162) {
      $endIndexCount$250$1 = $endIndexCount$2$be$1;$index$249$1 = $index$2$be$1;
     } else {
      $endIndexCount$2$lcssa$1 = $endIndexCount$2$be$1;$index$2$lcssa$1 = $index$2$be$1;
      break;
     }
    }
   } else {
    $endIndexCount$2$lcssa$1 = $endIndexCount$160$1;$index$2$lcssa$1 = $index$159$1;
   }
   $163 = (($normalIteration$157$1) + 1)|0;
   $164 = (($aa$156$1) + 1)|0;
   $exitcond81$1 = ($164|0)==($_positionIterations|0);
   if ($exitcond81$1) {
    break;
   } else {
    $aa$156$1 = $164;$endIndexCount$160$1 = $endIndexCount$2$lcssa$1;$index$159$1 = $index$2$lcssa$1;$maxNormalIndex$158$1 = $149;$normalIteration$157$1 = $163;
   }
  }
  $165 = (($maxNormalIndex$1$lcssa) + ($148))|0;
  $endIndexCount$1$lcssa$1 = $endIndexCount$2$lcssa$1;$index$1$lcssa$1 = $index$2$lcssa$1;$maxNormalIndex$1$lcssa$1 = $165;$normalIteration$1$lcssa$1 = $_positionIterations;
 } else {
  $endIndexCount$1$lcssa$1 = $endIndexCount$1$lcssa;$index$1$lcssa$1 = $index$1$lcssa;$maxNormalIndex$1$lcssa$1 = $maxNormalIndex$1$lcssa;$normalIteration$1$lcssa$1 = $normalIteration$1$lcssa;
 }
 $166 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomListIndex,64)|0);
 $167 = (($166) + -64)|0;
 $168 = ($167|0)<($_articulationListSize|0);
 if ($168) {
  $34 = $_articulationListSize ^ -1;
  $endIndexCount2$043 = 64;$index2$042 = $167;
  while(1) {
   $37 = (($_articulationListSize) - ($index2$042))|0;
   $38 = ($37|0)>(64);
   $39 = $38 ? 64 : $37;
   $40 = (($endIndexCount2$043) - ($39))|0;
   $41 = ($39|0)>(0);
   if ($41) {
    $42 = (($index2$042) + ($34))|0;
    $43 = ($42|0)>(-65);
    $smax77 = $43 ? $42 : -65;
    $44 = $smax77 ^ -1;
    $a$035 = 0;$index2$136 = $index2$042;
    while(1) {
     $45 = (($articulationListStart) + (($index2$136*40)|0)|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($46) + 12|0);
     $48 = HEAP16[$47>>1]|0;
     $49 = $48&65535;
     $50 = Math_imul($49, $normalIteration$1$lcssa$1)|0;
     $51 = (($46) + 28|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==($50|0);
     if (!($53)) {
      while(1) {
       $54 = HEAP32[$51>>2]|0;
       $55 = ($54|0)==($50|0);
       if ($55) {
        break;
       }
      }
     }
     $56 = HEAP32[503528>>2]|0;
     $57 = ($56|0)==(0|0);
     if ($57) {
      $61 = $50;
     } else {
      __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($45);
      $$pre = HEAP32[$51>>2]|0;
      $61 = $$pre;
     }
     $58 = HEAP16[$47>>1]|0;
     $59 = $58&65535;
     $60 = (($61) + ($59))|0;
     HEAP32[$51>>2] = $60;
     $62 = (($a$035) + 1)|0;
     $63 = (($index2$136) + 1)|0;
     $exitcond78 = ($62|0)==($44|0);
     if ($exitcond78) {
      break;
     } else {
      $a$035 = $62;$index2$136 = $63;
     }
    }
    $64 = (($index2$042) + -1)|0;
    $65 = (($64) - ($smax77))|0;
    $index2$1$lcssa = $65;
   } else {
    $index2$1$lcssa = $index2$042;
   }
   $66 = ($endIndexCount2$043|0)==($39|0);
   if ($66) {
    $67 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomListIndex,64)|0);
    $68 = (($67) + -64)|0;
    $endIndexCount2$0$be = 64;$index2$0$be = $68;
   } else {
    $endIndexCount2$0$be = $40;$index2$0$be = $index2$1$lcssa;
   }
   $69 = ($index2$0$be|0)<($_articulationListSize|0);
   if ($69) {
    $endIndexCount2$043 = $endIndexCount2$0$be;$index2$042 = $index2$0$be;
   } else {
    $endIndexCount2$0$lcssa = $endIndexCount2$0$be;$index2$0$lcssa = $index2$0$be;
    break;
   }
  }
 } else {
  $endIndexCount2$0$lcssa = 64;$index2$0$lcssa = $167;
 }
 $index2$231 = (($index2$0$lcssa) - ($_articulationListSize))|0;
 $35 = ($index2$231|0)<($_atomListSize|0);
 if ($35) {
  $36 = $_atomListSize ^ -1;
  $endIndexCount2$132 = $endIndexCount2$0$lcssa;$index2$233 = $index2$231;
  while(1) {
   $75 = (($_atomListSize) - ($index2$233))|0;
   $76 = ($endIndexCount2$132|0)<($75|0);
   $77 = $76 ? $endIndexCount2$132 : $75;
   $78 = ($77|0)>(0);
   if ($78) {
    $79 = $endIndexCount2$132 ^ -1;
    $80 = (($index2$233) + ($36))|0;
    $81 = ($80|0)<($79|0);
    $smax = $81 ? $79 : $80;
    $82 = $smax ^ -1;
    $a3$026 = 0;$index2$325 = $index2$233;
    while(1) {
     $83 = (($index2$325) + 8)|0;
     $84 = (($atomListStart) + ($83<<5)|0);
     $85 = (($motionVelocityArray) + ($83<<5)|0);
     $86 = ((($atomListStart) + ($index2$325<<5)|0) + 12|0);
     $87 = HEAP16[$86>>1]|0;
     $88 = $87&65535;
     $89 = Math_imul($88, $normalIteration$1$lcssa$1)|0;
     $90 = ((($atomListStart) + ($index2$325<<5)|0) + 28|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($91|0)==($89|0);
     if ($92) {
      $114 = $87;
     } else {
      while(1) {
       $93 = HEAP32[$90>>2]|0;
       $94 = ($93|0)==($89|0);
       if ($94) {
        break;
       }
      }
      $$pre83 = HEAP16[$86>>1]|0;
      $114 = $$pre83;
     }
     $95 = (($atomListStart) + ($index2$325<<5)|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $97 = (($motionVelocityArray) + ($index2$325<<5)|0);
     HEAPF32[$97>>2] = $96;
     $98 = ((($atomListStart) + ($index2$325<<5)|0) + 4|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     $100 = ((($motionVelocityArray) + ($index2$325<<5)|0) + 4|0);
     HEAPF32[$100>>2] = $99;
     $101 = ((($atomListStart) + ($index2$325<<5)|0) + 8|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = ((($motionVelocityArray) + ($index2$325<<5)|0) + 8|0);
     HEAPF32[$103>>2] = $102;
     $104 = ((($atomListStart) + ($index2$325<<5)|0) + 16|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = ((($motionVelocityArray) + ($index2$325<<5)|0) + 16|0);
     HEAPF32[$106>>2] = $105;
     $107 = ((($atomListStart) + ($index2$325<<5)|0) + 20|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     $109 = ((($motionVelocityArray) + ($index2$325<<5)|0) + 20|0);
     HEAPF32[$109>>2] = $108;
     $110 = ((($atomListStart) + ($index2$325<<5)|0) + 24|0);
     $111 = Math_fround(HEAPF32[$110>>2]);
     $112 = ((($motionVelocityArray) + ($index2$325<<5)|0) + 24|0);
     HEAPF32[$112>>2] = $111;
     $113 = $114&65535;
     $115 = (($89) + ($113))|0;
     HEAP32[$90>>2] = $115;
     $116 = (($a3$026) + 1)|0;
     $117 = (($index2$325) + 1)|0;
     $exitcond76 = ($116|0)==($82|0);
     if ($exitcond76) {
      break;
     } else {
      $a3$026 = $116;$index2$325 = $117;
     }
    }
   }
   $118 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomListIndex,64)|0);
   $119 = (($118) + -64)|0;
   $index2$2 = (($119) - ($_articulationListSize))|0;
   $120 = ($index2$2|0)<($_atomListSize|0);
   if ($120) {
    $endIndexCount2$132 = 64;$index2$233 = $index2$2;
   } else {
    break;
   }
  }
 }
 $normalIteration$212 = (($normalIteration$1$lcssa$1) + 1)|0;
 $70 = (($_velocityIterations) + -1)|0;
 $71 = ($70|0)==(0);
 if ($71) {
  $endIndexCount$3$lcssa = $endIndexCount$1$lcssa$1;$index$3$lcssa = $index$1$lcssa$1;$maxNormalIndex$2$lcssa = $maxNormalIndex$1$lcssa$1;$normalIteration$2$in$lcssa = $normalIteration$1$lcssa$1;$normalIteration$2$lcssa = $normalIteration$212;
 } else {
  $72 = (($normalIteration$1$lcssa$1) + ($_velocityIterations))|0;
  $73 = Math_imul($6, $70)|0;
  $74 = (($73) + ($maxNormalIndex$1$lcssa$1))|0;
  $endIndexCount$316 = $endIndexCount$1$lcssa$1;$index$315 = $index$1$lcssa$1;$maxNormalIndex$214 = $maxNormalIndex$1$lcssa$1;$normalIteration$217 = $normalIteration$212;
  while(1) {
   $121 = (($maxNormalIndex$214) + ($6))|0;
   $122 = ($index$315|0)<($121|0);
   if ($122) {
    $endIndexCount$47 = $endIndexCount$316;$index$46 = $index$315;
    while(1) {
     $123 = (($121) - ($index$46))|0;
     $124 = ($123|0)<($endIndexCount$47|0);
     $125 = $124 ? $123 : $endIndexCount$47;
     $126 = (($index$46) + ($6))|0;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($contactConstraintList,$125,$126,$6,$cache,$contactIter,501832,$normalIteration$217,0,$normalIteration$217);
     $127 = (($125) + ($index$46))|0;
     $128 = (($endIndexCount$47) - ($125))|0;
     $129 = ($endIndexCount$47|0)==($125|0);
     if ($129) {
      $130 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,4)|0);
      $131 = (($130) + -4)|0;
      $endIndexCount$4$be = 4;$index$4$be = $131;
     } else {
      $endIndexCount$4$be = $128;$index$4$be = $127;
     }
     $132 = ($index$4$be|0)<($121|0);
     if ($132) {
      $endIndexCount$47 = $endIndexCount$4$be;$index$46 = $index$4$be;
     } else {
      $endIndexCount$4$lcssa = $endIndexCount$4$be;$index$4$lcssa = $index$4$be;
      break;
     }
    }
   } else {
    $endIndexCount$4$lcssa = $endIndexCount$316;$index$4$lcssa = $index$315;
   }
   $normalIteration$2 = (($normalIteration$217) + 1)|0;
   $exitcond = ($normalIteration$2|0)==($72|0);
   if ($exitcond) {
    break;
   } else {
    $endIndexCount$316 = $endIndexCount$4$lcssa;$index$315 = $index$4$lcssa;$maxNormalIndex$214 = $121;$normalIteration$217 = $normalIteration$2;
   }
  }
  $133 = (($70) + ($normalIteration$1$lcssa$1))|0;
  $endIndexCount$3$lcssa = $endIndexCount$4$lcssa;$index$3$lcssa = $index$4$lcssa;$maxNormalIndex$2$lcssa = $74;$normalIteration$2$in$lcssa = $133;$normalIteration$2$lcssa = $72;
 }
 HEAP8[$10>>0] = 1;
 $134 = (($maxNormalIndex$2$lcssa) + ($6))|0;
 $135 = ($index$3$lcssa|0)<($134|0);
 if ($135) {
  $endIndexCount$54 = $endIndexCount$3$lcssa;$index$53 = $index$3$lcssa;
 } else {
  $146 = (($normalIteration$2$in$lcssa) + 2)|0;
  HEAP32[$_normalIterations>>2] = $146;
  STACKTOP = sp;return;
 }
 while(1) {
  $136 = (($134) - ($index$53))|0;
  $137 = ($136|0)<($endIndexCount$54|0);
  $138 = $137 ? $136 : $endIndexCount$54;
  $139 = (($index$53) + ($6))|0;
  __Z27SolveWriteBackBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextEPNS0_25PxcThresholdStreamElementEjPiR16PxsBatchIteratorjjjPPFvPKS1_jS4_S6_jS7_E($contactConstraintList,$138,$139,$6,$cache,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$contactIter,$normalIteration$2$lcssa,0,$normalIteration$2$lcssa,501872);
  $140 = (($138) + ($index$53))|0;
  $141 = (($endIndexCount$54) - ($138))|0;
  $142 = ($endIndexCount$54|0)==($138|0);
  if ($142) {
   $143 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,4)|0);
   $144 = (($143) + -4)|0;
   $endIndexCount$5$be = 4;$index$5$be = $144;
  } else {
   $endIndexCount$5$be = $141;$index$5$be = $140;
  }
  $145 = ($index$5$be|0)<($134|0);
  if ($145) {
   $endIndexCount$54 = $endIndexCount$5$be;$index$53 = $index$5$be;
  } else {
   break;
  }
 }
 $146 = (($normalIteration$2$in$lcssa) + 2)|0;
 HEAP32[$_normalIterations>>2] = $146;
 STACKTOP = sp;return;
}
function __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($constraintList,$batchCount,$index,$headerCount,$cache,$iterator,$solveTable,$normalIteration,$frictionIteration,$iteration) {
 $constraintList = $constraintList|0;
 $batchCount = $batchCount|0;
 $index = $index|0;
 $headerCount = $headerCount|0;
 $cache = $cache|0;
 $iterator = $iterator|0;
 $solveTable = $solveTable|0;
 $normalIteration = $normalIteration|0;
 $frictionIteration = $frictionIteration|0;
 $iteration = $iteration|0;
 var $$pre$i = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$04 = 0, $i$09 = 0, $j$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_imul($iteration, $headerCount)|0;
 $1 = (($index) - ($0))|0;
 $2 = HEAP32[$iterator>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($batchCount))|0;
 $5 = ($batchCount|0)>(0);
 if ($5) {
  $i$09 = $1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $6 = ((($3) + ($i$09<<3)|0) + 4|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = $7&65535;
  $9 = (($8) + -1)|0;
  $10 = (($3) + ($i$09<<3)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($constraintList) + ($11<<5)|0);
  $13 = ($7<<16>>16)==(0);
  if ($13) {
   $99 = ((($3) + ($i$09<<3)|0) + 6|0);
   $100 = HEAP16[$99>>1]|0;
   $101 = $100&65535;
   $102 = (($solveTable) + ($101<<2)|0);
   $103 = HEAP32[$102>>2]|0;
   FUNCTION_TABLE_viii[$103 & 4095]($12,$8,$cache);
  } else {
   $b$04 = 0;
   while(1) {
    $14 = (($b$04) + 2)|0;
    $15 = ($14|0)<($9|0);
    $16 = $15 ? $14 : $9;
    $$sum1 = (($b$04) + ($11))|0;
    $17 = ((($constraintList) + ($$sum1<<5)|0) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$17>>2]|0;
    $20 = (($19) + 128|0);
    $21 = HEAP32[$17>>2]|0;
    $22 = (($21) + 256|0);
    $$sum2 = (($16) + ($11))|0;
    $23 = (($constraintList) + ($$sum2<<5)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($constraintList) + ($$sum2<<5)|0) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $$sum3 = (($$sum1) + 8)|0;
    $27 = (($constraintList) + ($$sum3<<5)|0);
    $28 = (($constraintList) + ($$sum1<<5)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($constraintList) + ($$sum1<<5)|0) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($constraintList) + ($$sum1<<5)|0) + 28|0);
    $33 = HEAP16[$32>>1]|0;
    $34 = ($33<<16>>16)==(-1);
    if ($34) {
     $64 = 65535;
    } else {
     $35 = $33&65535;
     $36 = (($29) + 12|0);
     $37 = HEAP16[$36>>1]|0;
     $38 = $37&65535;
     $39 = Math_imul($38, $normalIteration)|0;
     $40 = (($39) + ($35))|0;
     $41 = (($29) + 14|0);
     $42 = HEAP16[$41>>1]|0;
     $43 = $42&65535;
     $44 = Math_imul($43, $frictionIteration)|0;
     $45 = (($40) + ($44))|0;
     $64 = $45;
    }
    $46 = ((($constraintList) + ($$sum1<<5)|0) + 30|0);
    $47 = HEAP16[$46>>1]|0;
    $48 = ($47<<16>>16)==(-1);
    if ($48) {
     $67 = 65535;
    } else {
     $49 = $47&65535;
     $50 = (($31) + 12|0);
     $51 = HEAP16[$50>>1]|0;
     $52 = $51&65535;
     $53 = Math_imul($52, $normalIteration)|0;
     $54 = (($53) + ($49))|0;
     $55 = (($31) + 14|0);
     $56 = HEAP16[$55>>1]|0;
     $57 = $56&65535;
     $58 = Math_imul($57, $frictionIteration)|0;
     $59 = (($54) + ($58))|0;
     $67 = $59;
    }
    $60 = (($29) + 28|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($31) + 28|0);
    $63 = ($61|0)==($64|0);
    if ($63) {
     $65 = HEAP32[$62>>2]|0;
     $66 = ($65|0)==($67|0);
     if (!($66)) {
      label = 9;
     }
    } else {
     label = 9;
    }
    if ((label|0) == 9) {
     while(1) {
      label = 0;
      $68 = HEAP32[$60>>2]|0;
      $69 = ($68|0)==($64|0);
      if ($69) {
       break;
      } else {
       label = 9;
      }
     }
     while(1) {
      $70 = HEAP32[$62>>2]|0;
      $71 = ($70|0)==($67|0);
      if ($71) {
       break;
      }
     }
    }
    $72 = (($b$04) + 1)|0;
    $73 = ($72|0)<($8|0);
    if ($73) {
     $b$04 = $72;
    } else {
     break;
    }
   }
   $74 = ((($3) + ($i$09<<3)|0) + 6|0);
   $75 = HEAP16[$74>>1]|0;
   $76 = $75&65535;
   $77 = (($solveTable) + ($76<<2)|0);
   $78 = HEAP32[$77>>2]|0;
   FUNCTION_TABLE_viii[$78 & 4095]($12,$8,$cache);
   if (!($13)) {
    $j$05 = 0;
    while(1) {
     $$sum = (($j$05) + ($11))|0;
     $79 = (($constraintList) + ($$sum<<5)|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ((($constraintList) + ($$sum<<5)|0) + 4|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = (($80) + 12|0);
     $84 = HEAP16[$83>>1]|0;
     $85 = (($82) + 12|0);
     $86 = HEAP16[$85>>1]|0;
     $87 = ($84<<16>>16)==(-1);
     if ($87) {
      $95 = 65535;
     } else {
      $88 = (($80) + 28|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = (($89) + 1)|0;
      $95 = $90;
     }
     $91 = ($86<<16>>16)==(-1);
     $$pre$i = (($82) + 28|0);
     if ($91) {
      $96 = 65535;
     } else {
      $92 = HEAP32[$$pre$i>>2]|0;
      $93 = (($92) + 1)|0;
      $96 = $93;
     }
     $94 = (($80) + 28|0);
     HEAP32[$94>>2] = $95;
     HEAP32[$$pre$i>>2] = $96;
     $97 = (($j$05) + 1)|0;
     $98 = ($97|0)<($8|0);
     if ($98) {
      $j$05 = $97;
     } else {
      break;
     }
    }
   }
  }
  $104 = (($i$09) + 1)|0;
  $105 = ($104|0)<($4|0);
  if ($105) {
   $i$09 = $104;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z27SolveWriteBackBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextEPNS0_25PxcThresholdStreamElementEjPiR16PxsBatchIteratorjjjPPFvPKS1_jS4_S6_jS7_E($constraintList,$batchCount,$index,$headerCount,$cache,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$iterator,$normalIteration,$frictionIteration,$iteration,$solveTable) {
 $constraintList = $constraintList|0;
 $batchCount = $batchCount|0;
 $index = $index|0;
 $headerCount = $headerCount|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $iterator = $iterator|0;
 $normalIteration = $normalIteration|0;
 $frictionIteration = $frictionIteration|0;
 $iteration = $iteration|0;
 $solveTable = $solveTable|0;
 var $$pre$i = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$04 = 0, $i$09 = 0, $j$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_imul($iteration, $headerCount)|0;
 $1 = (($index) - ($0))|0;
 $2 = HEAP32[$iterator>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($batchCount))|0;
 $5 = ($batchCount|0)>(0);
 if ($5) {
  $i$09 = $1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $6 = ((($3) + ($i$09<<3)|0) + 4|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = $7&65535;
  $9 = (($8) + -1)|0;
  $10 = (($3) + ($i$09<<3)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($constraintList) + ($11<<5)|0);
  $13 = ($7<<16>>16)==(0);
  if ($13) {
   $99 = ((($3) + ($i$09<<3)|0) + 6|0);
   $100 = HEAP16[$99>>1]|0;
   $101 = $100&65535;
   $102 = (($solveTable) + ($101<<2)|0);
   $103 = HEAP32[$102>>2]|0;
   FUNCTION_TABLE_viiiiii[$103 & 255]($12,$8,$cache,$thresholdStream,$thresholdStreamLength,$outThresholdPairs);
  } else {
   $b$04 = 0;
   while(1) {
    $14 = (($b$04) + 2)|0;
    $15 = ($14|0)<($9|0);
    $16 = $15 ? $14 : $9;
    $$sum1 = (($b$04) + ($11))|0;
    $17 = ((($constraintList) + ($$sum1<<5)|0) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$17>>2]|0;
    $20 = (($19) + 128|0);
    $21 = HEAP32[$17>>2]|0;
    $22 = (($21) + 256|0);
    $$sum2 = (($16) + ($11))|0;
    $23 = (($constraintList) + ($$sum2<<5)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($constraintList) + ($$sum2<<5)|0) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $$sum3 = (($$sum1) + 8)|0;
    $27 = (($constraintList) + ($$sum3<<5)|0);
    $28 = (($constraintList) + ($$sum1<<5)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($constraintList) + ($$sum1<<5)|0) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($constraintList) + ($$sum1<<5)|0) + 28|0);
    $33 = HEAP16[$32>>1]|0;
    $34 = ($33<<16>>16)==(-1);
    if ($34) {
     $64 = 65535;
    } else {
     $35 = $33&65535;
     $36 = (($29) + 12|0);
     $37 = HEAP16[$36>>1]|0;
     $38 = $37&65535;
     $39 = Math_imul($38, $normalIteration)|0;
     $40 = (($39) + ($35))|0;
     $41 = (($29) + 14|0);
     $42 = HEAP16[$41>>1]|0;
     $43 = $42&65535;
     $44 = Math_imul($43, $frictionIteration)|0;
     $45 = (($40) + ($44))|0;
     $64 = $45;
    }
    $46 = ((($constraintList) + ($$sum1<<5)|0) + 30|0);
    $47 = HEAP16[$46>>1]|0;
    $48 = ($47<<16>>16)==(-1);
    if ($48) {
     $67 = 65535;
    } else {
     $49 = $47&65535;
     $50 = (($31) + 12|0);
     $51 = HEAP16[$50>>1]|0;
     $52 = $51&65535;
     $53 = Math_imul($52, $normalIteration)|0;
     $54 = (($53) + ($49))|0;
     $55 = (($31) + 14|0);
     $56 = HEAP16[$55>>1]|0;
     $57 = $56&65535;
     $58 = Math_imul($57, $frictionIteration)|0;
     $59 = (($54) + ($58))|0;
     $67 = $59;
    }
    $60 = (($29) + 28|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($31) + 28|0);
    $63 = ($61|0)==($64|0);
    if ($63) {
     $65 = HEAP32[$62>>2]|0;
     $66 = ($65|0)==($67|0);
     if (!($66)) {
      label = 9;
     }
    } else {
     label = 9;
    }
    if ((label|0) == 9) {
     while(1) {
      label = 0;
      $68 = HEAP32[$60>>2]|0;
      $69 = ($68|0)==($64|0);
      if ($69) {
       break;
      } else {
       label = 9;
      }
     }
     while(1) {
      $70 = HEAP32[$62>>2]|0;
      $71 = ($70|0)==($67|0);
      if ($71) {
       break;
      }
     }
    }
    $72 = (($b$04) + 1)|0;
    $73 = ($72|0)<($8|0);
    if ($73) {
     $b$04 = $72;
    } else {
     break;
    }
   }
   $74 = ((($3) + ($i$09<<3)|0) + 6|0);
   $75 = HEAP16[$74>>1]|0;
   $76 = $75&65535;
   $77 = (($solveTable) + ($76<<2)|0);
   $78 = HEAP32[$77>>2]|0;
   FUNCTION_TABLE_viiiiii[$78 & 255]($12,$8,$cache,$thresholdStream,$thresholdStreamLength,$outThresholdPairs);
   if (!($13)) {
    $j$05 = 0;
    while(1) {
     $$sum = (($j$05) + ($11))|0;
     $79 = (($constraintList) + ($$sum<<5)|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ((($constraintList) + ($$sum<<5)|0) + 4|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = (($80) + 12|0);
     $84 = HEAP16[$83>>1]|0;
     $85 = (($82) + 12|0);
     $86 = HEAP16[$85>>1]|0;
     $87 = ($84<<16>>16)==(-1);
     if ($87) {
      $95 = 65535;
     } else {
      $88 = (($80) + 28|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = (($89) + 1)|0;
      $95 = $90;
     }
     $91 = ($86<<16>>16)==(-1);
     $$pre$i = (($82) + 28|0);
     if ($91) {
      $96 = 65535;
     } else {
      $92 = HEAP32[$$pre$i>>2]|0;
      $93 = (($92) + 1)|0;
      $96 = $93;
     }
     $94 = (($80) + 28|0);
     HEAP32[$94>>2] = $95;
     HEAP32[$$pre$i>>2] = $96;
     $97 = (($j$05) + 1)|0;
     $98 = ($97|0)<($8|0);
     if ($98) {
      $j$05 = $97;
     } else {
      break;
     }
    }
   }
  }
  $104 = (($i$09) + 1)|0;
  $105 = ($104|0)<($4|0);
  if ($105) {
   $i$09 = $104;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsSolverCoreGeneral33solveVCoulombParallelAndWriteBackEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jPiS9_S9_PNS_25PxcThresholdStreamElementEjS9_RNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENSC_19ReflectionAllocatorISE_EEEESI_PNS_2Cm13SpatialVectorERiSM_($this,$0,$_positionIterations,$_velocityIterations,$atomListStart,$atomDataList,$1,$_atomListSize,$articulationListStart,$_articulationListSize,$contactConstraintList,$2,$frictionConstraintList,$3,$pConstraintIndex,$pFrictionConstraintIndex,$pAtomListIndex,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$contactConstraintBatches,$frictionConstraintBatches,$motionVelocityArray,$_normalIterations,$_frictionIterations) {
 $this = $this|0;
 $0 = Math_fround($0);
 $_positionIterations = $_positionIterations|0;
 $_velocityIterations = $_velocityIterations|0;
 $atomListStart = $atomListStart|0;
 $atomDataList = $atomDataList|0;
 $1 = $1|0;
 $_atomListSize = $_atomListSize|0;
 $articulationListStart = $articulationListStart|0;
 $_articulationListSize = $_articulationListSize|0;
 $contactConstraintList = $contactConstraintList|0;
 $2 = $2|0;
 $frictionConstraintList = $frictionConstraintList|0;
 $3 = $3|0;
 $pConstraintIndex = $pConstraintIndex|0;
 $pFrictionConstraintIndex = $pFrictionConstraintIndex|0;
 $pAtomListIndex = $pAtomListIndex|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $contactConstraintBatches = $contactConstraintBatches|0;
 $frictionConstraintBatches = $frictionConstraintBatches|0;
 $motionVelocityArray = $motionVelocityArray|0;
 $_normalIterations = $_normalIterations|0;
 $_frictionIterations = $_frictionIterations|0;
 var $$lcssa = 0, $$pre = 0, $$pre141 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$1$lcssa$1 = 0, $a$1102 = 0, $a$1102$1 = 0, $a$3$lcssa = 0, $a$374 = 0, $a$374$1 = 0, $a1$043 = 0, $b$054 = 0, $cache = 0, $contactIter = 0, $endIndexCount$1$lcssa = 0, $endIndexCount$1$lcssa$1 = 0, $endIndexCount$1106 = 0, $endIndexCount$1106$1 = 0, $endIndexCount$2$be = 0, $endIndexCount$2$be$1 = 0;
 var $endIndexCount$2$lcssa = 0, $endIndexCount$2$lcssa$1 = 0, $endIndexCount$296 = 0, $endIndexCount$296$1 = 0, $endIndexCount$3$lcssa = 0, $endIndexCount$333 = 0, $endIndexCount$4$be = 0, $endIndexCount$4$lcssa = 0, $endIndexCount$414 = 0, $endIndexCount$5$be = 0, $endIndexCount$58 = 0, $endIndexCount2$0$be = 0, $endIndexCount2$0$lcssa = 0, $endIndexCount2$060 = 0, $endIndexCount2$149 = 0, $exitcond = 0, $exitcond126 = 0, $exitcond129 = 0, $exitcond133 = 0, $exitcond133$1 = 0;
 var $exitcond138 = 0, $exitcond138$1 = 0, $frictionEndIndexCount$1$lcssa = 0, $frictionEndIndexCount$1$lcssa$1 = 0, $frictionEndIndexCount$177 = 0, $frictionEndIndexCount$177$1 = 0, $frictionEndIndexCount$2$be = 0, $frictionEndIndexCount$2$be$1 = 0, $frictionEndIndexCount$2$lcssa = 0, $frictionEndIndexCount$2$lcssa$1 = 0, $frictionEndIndexCount$267 = 0, $frictionEndIndexCount$267$1 = 0, $frictionEndIndexCount$3$lcssa = 0, $frictionEndIndexCount$330 = 0, $frictionEndIndexCount$4$be = 0, $frictionEndIndexCount$4$lcssa = 0, $frictionEndIndexCount$419 = 0, $frictionEndIndexCount$5$be = 0, $frictionEndIndexCount$54 = 0, $frictionIndex$1$lcssa = 0;
 var $frictionIndex$1$lcssa$1 = 0, $frictionIndex$178 = 0, $frictionIndex$178$1 = 0, $frictionIndex$2$be = 0, $frictionIndex$2$be$1 = 0, $frictionIndex$2$lcssa = 0, $frictionIndex$2$lcssa$1 = 0, $frictionIndex$268 = 0, $frictionIndex$268$1 = 0, $frictionIndex$3$lcssa = 0, $frictionIndex$331 = 0, $frictionIndex$4$be = 0, $frictionIndex$4$lcssa = 0, $frictionIndex$420 = 0, $frictionIndex$5$be = 0, $frictionIndex$55 = 0, $frictionIter = 0, $frictionIteration$1$lcssa = 0, $frictionIteration$1$lcssa$1 = 0, $frictionIteration$175 = 0;
 var $frictionIteration$175$1 = 0, $frictionIteration$2$lcssa = 0, $frictionIteration$227 = 0, $index$1$lcssa = 0, $index$1$lcssa$1 = 0, $index$1105 = 0, $index$1105$1 = 0, $index$2$be = 0, $index$2$be$1 = 0, $index$2$lcssa = 0, $index$2$lcssa$1 = 0, $index$295 = 0, $index$295$1 = 0, $index$3$lcssa = 0, $index$332 = 0, $index$4$be = 0, $index$4$lcssa = 0, $index$413 = 0, $index$5$be = 0, $index$57 = 0;
 var $index2$0$be = 0, $index2$0$lcssa = 0, $index2$061 = 0, $index2$1$lcssa = 0, $index2$153 = 0, $index2$2 = 0, $index2$248 = 0, $index2$250 = 0, $index2$342 = 0, $maxFrictionIndex$1$lcssa = 0, $maxFrictionIndex$1$lcssa$1 = 0, $maxFrictionIndex$176 = 0, $maxFrictionIndex$176$1 = 0, $maxFrictionIndex$2$lcssa = 0, $maxFrictionIndex$229 = 0, $maxNormalIndex$1$lcssa = 0, $maxNormalIndex$1$lcssa$1 = 0, $maxNormalIndex$1104 = 0, $maxNormalIndex$1104$1 = 0, $normalIteration$1$lcssa = 0;
 var $normalIteration$1$lcssa$1 = 0, $normalIteration$1103 = 0, $normalIteration$1103$1 = 0, $normalIteration$2$lcssa = 0, $normalIteration$228 = 0, $smax = 0, $smax128 = 0, $tempThresholdStream = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $cache = sp + 528|0;
 $tempThresholdStream = sp;
 $contactIter = sp + 512|0;
 $frictionIter = sp + 520|0;
 $4 = (($cache) + 16|0);
 HEAP32[$4>>2] = $atomDataList;
 $5 = (($contactConstraintBatches) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($frictionConstraintBatches) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($cache) + 4|0);
 HEAP32[$9>>2] = $tempThresholdStream;
 $10 = (($cache) + 12|0);
 HEAP32[$10>>2] = 32;
 $11 = (($cache) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,32)|0);
 $13 = (($12) + -32)|0;
 $14 = (__ZN5physx6shdfnd9atomicAddEPVii($pFrictionConstraintIndex,32)|0);
 HEAP32[$contactIter>>2] = $contactConstraintBatches;
 $15 = (($contactIter) + 4|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$frictionIter>>2] = $frictionConstraintBatches;
 $16 = (($frictionIter) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($_positionIterations) + -1)|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $endIndexCount$1$lcssa = 32;$index$1$lcssa = $13;$maxNormalIndex$1$lcssa = 0;$normalIteration$1$lcssa = 0;
 } else {
  $19 = Math_imul($6, $17)|0;
  $a$1102 = 0;$endIndexCount$1106 = 32;$index$1105 = $13;$maxNormalIndex$1104 = 0;$normalIteration$1103 = 0;
  while(1) {
   $20 = (($maxNormalIndex$1104) + ($6))|0;
   $21 = ($index$1105|0)<($20|0);
   if ($21) {
    $endIndexCount$296 = $endIndexCount$1106;$index$295 = $index$1105;
    while(1) {
     $22 = (($20) - ($index$295))|0;
     $23 = ($22|0)<($endIndexCount$296|0);
     $24 = $23 ? $22 : $endIndexCount$296;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($contactConstraintList,$24,$index$295,$6,$cache,$contactIter,502064,$normalIteration$1103,0,$normalIteration$1103);
     $25 = (($24) + ($index$295))|0;
     $26 = (($endIndexCount$296) - ($24))|0;
     $27 = ($endIndexCount$296|0)==($24|0);
     if ($27) {
      $28 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,32)|0);
      $29 = (($28) + -32)|0;
      $endIndexCount$2$be = 32;$index$2$be = $29;
     } else {
      $endIndexCount$2$be = $26;$index$2$be = $25;
     }
     $30 = ($index$2$be|0)<($20|0);
     if ($30) {
      $endIndexCount$296 = $endIndexCount$2$be;$index$295 = $index$2$be;
     } else {
      $endIndexCount$2$lcssa = $endIndexCount$2$be;$index$2$lcssa = $index$2$be;
      break;
     }
    }
   } else {
    $endIndexCount$2$lcssa = $endIndexCount$1106;$index$2$lcssa = $index$1105;
   }
   $31 = (($normalIteration$1103) + 1)|0;
   $32 = (($a$1102) + 1)|0;
   $exitcond138 = ($32|0)==($17|0);
   if ($exitcond138) {
    $endIndexCount$1$lcssa = $endIndexCount$2$lcssa;$index$1$lcssa = $index$2$lcssa;$maxNormalIndex$1$lcssa = $19;$normalIteration$1$lcssa = $17;
    break;
   } else {
    $a$1102 = $32;$endIndexCount$1106 = $endIndexCount$2$lcssa;$index$1105 = $index$2$lcssa;$maxNormalIndex$1104 = $20;$normalIteration$1103 = $31;
   }
  }
 }
 $33 = ($normalIteration$1$lcssa>>>0)<($_positionIterations>>>0);
 if ($33) {
  $226 = (($_positionIterations) - ($normalIteration$1$lcssa))|0;
  $227 = Math_imul($6, $226)|0;
  $a$1102$1 = $normalIteration$1$lcssa;$endIndexCount$1106$1 = $endIndexCount$1$lcssa;$index$1105$1 = $index$1$lcssa;$maxNormalIndex$1104$1 = $maxNormalIndex$1$lcssa;$normalIteration$1103$1 = $normalIteration$1$lcssa;
  while(1) {
   $228 = (($maxNormalIndex$1104$1) + ($6))|0;
   $229 = ($index$1105$1|0)<($228|0);
   if ($229) {
    $endIndexCount$296$1 = $endIndexCount$1106$1;$index$295$1 = $index$1105$1;
    while(1) {
     $230 = (($228) - ($index$295$1))|0;
     $231 = ($230|0)<($endIndexCount$296$1|0);
     $232 = $231 ? $230 : $endIndexCount$296$1;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($contactConstraintList,$232,$index$295$1,$6,$cache,$contactIter,502192,$normalIteration$1103$1,0,$normalIteration$1103$1);
     $233 = (($232) + ($index$295$1))|0;
     $234 = (($endIndexCount$296$1) - ($232))|0;
     $235 = ($endIndexCount$296$1|0)==($232|0);
     if ($235) {
      $236 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,32)|0);
      $237 = (($236) + -32)|0;
      $endIndexCount$2$be$1 = 32;$index$2$be$1 = $237;
     } else {
      $endIndexCount$2$be$1 = $234;$index$2$be$1 = $233;
     }
     $238 = ($index$2$be$1|0)<($228|0);
     if ($238) {
      $endIndexCount$296$1 = $endIndexCount$2$be$1;$index$295$1 = $index$2$be$1;
     } else {
      $endIndexCount$2$lcssa$1 = $endIndexCount$2$be$1;$index$2$lcssa$1 = $index$2$be$1;
      break;
     }
    }
   } else {
    $endIndexCount$2$lcssa$1 = $endIndexCount$1106$1;$index$2$lcssa$1 = $index$1105$1;
   }
   $239 = (($normalIteration$1103$1) + 1)|0;
   $240 = (($a$1102$1) + 1)|0;
   $exitcond138$1 = ($240|0)==($_positionIterations|0);
   if ($exitcond138$1) {
    break;
   } else {
    $a$1102$1 = $240;$endIndexCount$1106$1 = $endIndexCount$2$lcssa$1;$index$1105$1 = $index$2$lcssa$1;$maxNormalIndex$1104$1 = $228;$normalIteration$1103$1 = $239;
   }
  }
  $241 = (($maxNormalIndex$1$lcssa) + ($227))|0;
  $a$1$lcssa$1 = $_positionIterations;$endIndexCount$1$lcssa$1 = $endIndexCount$2$lcssa$1;$index$1$lcssa$1 = $index$2$lcssa$1;$maxNormalIndex$1$lcssa$1 = $241;$normalIteration$1$lcssa$1 = $_positionIterations;
 } else {
  $a$1$lcssa$1 = $normalIteration$1$lcssa;$endIndexCount$1$lcssa$1 = $endIndexCount$1$lcssa;$index$1$lcssa$1 = $index$1$lcssa;$maxNormalIndex$1$lcssa$1 = $maxNormalIndex$1$lcssa;$normalIteration$1$lcssa$1 = $normalIteration$1$lcssa;
 }
 $242 = (($14) + -32)|0;
 $51 = $_positionIterations << 1;
 $243 = (($51) + -1)|0;
 $205 = $_positionIterations << 1;
 $35 = (($205) + -1)|0;
 $244 = ($a$1$lcssa$1>>>0)<($243>>>0);
 if ($244) {
  $34 = (($35) - ($a$1$lcssa$1))|0;
  $36 = Math_imul($8, $34)|0;
  $a$374 = $a$1$lcssa$1;$frictionEndIndexCount$177 = 32;$frictionIndex$178 = $242;$frictionIteration$175 = 0;$maxFrictionIndex$176 = 0;
  while(1) {
   $37 = (($maxFrictionIndex$176) + ($8))|0;
   $38 = ($frictionIndex$178|0)<($37|0);
   if ($38) {
    $frictionEndIndexCount$267 = $frictionEndIndexCount$177;$frictionIndex$268 = $frictionIndex$178;
    while(1) {
     $39 = (($37) - ($frictionIndex$268))|0;
     $40 = ($39|0)<($frictionEndIndexCount$267|0);
     $41 = $40 ? $39 : $frictionEndIndexCount$267;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($frictionConstraintList,$41,$frictionIndex$268,$8,$cache,$frictionIter,502064,$normalIteration$1$lcssa$1,$frictionIteration$175,$frictionIteration$175);
     $42 = (($41) + ($frictionIndex$268))|0;
     $43 = (($frictionEndIndexCount$267) - ($41))|0;
     $44 = ($frictionEndIndexCount$267|0)==($41|0);
     if ($44) {
      $45 = (__ZN5physx6shdfnd9atomicAddEPVii($pFrictionConstraintIndex,32)|0);
      $46 = (($45) + -32)|0;
      $frictionEndIndexCount$2$be = 32;$frictionIndex$2$be = $46;
     } else {
      $frictionEndIndexCount$2$be = $43;$frictionIndex$2$be = $42;
     }
     $47 = ($frictionIndex$2$be|0)<($37|0);
     if ($47) {
      $frictionEndIndexCount$267 = $frictionEndIndexCount$2$be;$frictionIndex$268 = $frictionIndex$2$be;
     } else {
      $frictionEndIndexCount$2$lcssa = $frictionEndIndexCount$2$be;$frictionIndex$2$lcssa = $frictionIndex$2$be;
      break;
     }
    }
   } else {
    $frictionEndIndexCount$2$lcssa = $frictionEndIndexCount$177;$frictionIndex$2$lcssa = $frictionIndex$178;
   }
   $48 = (($frictionIteration$175) + 1)|0;
   $49 = (($a$374) + 1)|0;
   $exitcond133 = ($49|0)==($35|0);
   if ($exitcond133) {
    $a$3$lcssa = $35;$frictionEndIndexCount$1$lcssa = $frictionEndIndexCount$2$lcssa;$frictionIndex$1$lcssa = $frictionIndex$2$lcssa;$frictionIteration$1$lcssa = $34;$maxFrictionIndex$1$lcssa = $36;
    break;
   } else {
    $a$374 = $49;$frictionEndIndexCount$177 = $frictionEndIndexCount$2$lcssa;$frictionIndex$178 = $frictionIndex$2$lcssa;$frictionIteration$175 = $48;$maxFrictionIndex$176 = $37;
   }
  }
 } else {
  $a$3$lcssa = $a$1$lcssa$1;$frictionEndIndexCount$1$lcssa = 32;$frictionIndex$1$lcssa = $242;$frictionIteration$1$lcssa = 0;$maxFrictionIndex$1$lcssa = 0;
 }
 $50 = ($a$3$lcssa>>>0)<($51>>>0);
 if ($50) {
  $204 = (($frictionIteration$1$lcssa) + ($205))|0;
  $206 = (($205) - ($a$3$lcssa))|0;
  $207 = Math_imul($8, $206)|0;
  $a$374$1 = $a$3$lcssa;$frictionEndIndexCount$177$1 = $frictionEndIndexCount$1$lcssa;$frictionIndex$178$1 = $frictionIndex$1$lcssa;$frictionIteration$175$1 = $frictionIteration$1$lcssa;$maxFrictionIndex$176$1 = $maxFrictionIndex$1$lcssa;
  while(1) {
   $208 = (($maxFrictionIndex$176$1) + ($8))|0;
   $209 = ($frictionIndex$178$1|0)<($208|0);
   if ($209) {
    $frictionEndIndexCount$267$1 = $frictionEndIndexCount$177$1;$frictionIndex$268$1 = $frictionIndex$178$1;
    while(1) {
     $210 = (($208) - ($frictionIndex$268$1))|0;
     $211 = ($210|0)<($frictionEndIndexCount$267$1|0);
     $212 = $211 ? $210 : $frictionEndIndexCount$267$1;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($frictionConstraintList,$212,$frictionIndex$268$1,$8,$cache,$frictionIter,502192,$normalIteration$1$lcssa$1,$frictionIteration$175$1,$frictionIteration$175$1);
     $213 = (($212) + ($frictionIndex$268$1))|0;
     $214 = (($frictionEndIndexCount$267$1) - ($212))|0;
     $215 = ($frictionEndIndexCount$267$1|0)==($212|0);
     if ($215) {
      $216 = (__ZN5physx6shdfnd9atomicAddEPVii($pFrictionConstraintIndex,32)|0);
      $217 = (($216) + -32)|0;
      $frictionEndIndexCount$2$be$1 = 32;$frictionIndex$2$be$1 = $217;
     } else {
      $frictionEndIndexCount$2$be$1 = $214;$frictionIndex$2$be$1 = $213;
     }
     $218 = ($frictionIndex$2$be$1|0)<($208|0);
     if ($218) {
      $frictionEndIndexCount$267$1 = $frictionEndIndexCount$2$be$1;$frictionIndex$268$1 = $frictionIndex$2$be$1;
     } else {
      $frictionEndIndexCount$2$lcssa$1 = $frictionEndIndexCount$2$be$1;$frictionIndex$2$lcssa$1 = $frictionIndex$2$be$1;
      break;
     }
    }
   } else {
    $frictionEndIndexCount$2$lcssa$1 = $frictionEndIndexCount$177$1;$frictionIndex$2$lcssa$1 = $frictionIndex$178$1;
   }
   $219 = (($frictionIteration$175$1) + 1)|0;
   $220 = (($a$374$1) + 1)|0;
   $exitcond133$1 = ($220|0)==($205|0);
   if ($exitcond133$1) {
    break;
   } else {
    $a$374$1 = $220;$frictionEndIndexCount$177$1 = $frictionEndIndexCount$2$lcssa$1;$frictionIndex$178$1 = $frictionIndex$2$lcssa$1;$frictionIteration$175$1 = $219;$maxFrictionIndex$176$1 = $208;
   }
  }
  $221 = (($204) - ($a$3$lcssa))|0;
  $222 = (($maxFrictionIndex$1$lcssa) + ($207))|0;
  $frictionEndIndexCount$1$lcssa$1 = $frictionEndIndexCount$2$lcssa$1;$frictionIndex$1$lcssa$1 = $frictionIndex$2$lcssa$1;$frictionIteration$1$lcssa$1 = $221;$maxFrictionIndex$1$lcssa$1 = $222;
 } else {
  $frictionEndIndexCount$1$lcssa$1 = $frictionEndIndexCount$1$lcssa;$frictionIndex$1$lcssa$1 = $frictionIndex$1$lcssa;$frictionIteration$1$lcssa$1 = $frictionIteration$1$lcssa;$maxFrictionIndex$1$lcssa$1 = $maxFrictionIndex$1$lcssa;
 }
 $223 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomListIndex,64)|0);
 $224 = (($223) + -64)|0;
 $225 = ($224|0)<($_articulationListSize|0);
 if ($225) {
  $52 = $_articulationListSize ^ -1;
  $endIndexCount2$060 = 64;$index2$061 = $224;
  while(1) {
   $55 = (($_articulationListSize) - ($index2$061))|0;
   $56 = ($55|0)>(64);
   $57 = $56 ? 64 : $55;
   $58 = (($endIndexCount2$060) - ($57))|0;
   $59 = ($57|0)>(0);
   if ($59) {
    $60 = (($index2$061) + ($52))|0;
    $61 = ($60|0)>(-65);
    $smax128 = $61 ? $60 : -65;
    $62 = $smax128 ^ -1;
    $b$054 = 0;$index2$153 = $index2$061;
    while(1) {
     $63 = (($articulationListStart) + (($index2$153*40)|0)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($64) + 12|0);
     $66 = HEAP16[$65>>1]|0;
     $67 = $66&65535;
     $68 = Math_imul($67, $normalIteration$1$lcssa$1)|0;
     $69 = (($64) + 14|0);
     $70 = HEAP16[$69>>1]|0;
     $71 = $70&65535;
     $72 = Math_imul($71, $frictionIteration$1$lcssa$1)|0;
     $73 = (($72) + ($68))|0;
     $74 = (($64) + 28|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = ($75|0)==($73|0);
     if (!($76)) {
      while(1) {
       $77 = HEAP32[$74>>2]|0;
       $78 = ($77|0)==($73|0);
       if ($78) {
        break;
       }
      }
     }
     $79 = HEAP32[503528>>2]|0;
     $80 = ($79|0)==(0|0);
     if ($80) {
      $84 = $73;
     } else {
      __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($63);
      $$pre = HEAP32[$74>>2]|0;
      $84 = $$pre;
     }
     $81 = HEAP16[$65>>1]|0;
     $82 = $81&65535;
     $83 = (($84) + ($82))|0;
     HEAP32[$74>>2] = $83;
     $85 = (($b$054) + 1)|0;
     $86 = (($index2$153) + 1)|0;
     $exitcond129 = ($85|0)==($62|0);
     if ($exitcond129) {
      break;
     } else {
      $b$054 = $85;$index2$153 = $86;
     }
    }
    $87 = (($index2$061) + -1)|0;
    $88 = (($87) - ($smax128))|0;
    $index2$1$lcssa = $88;
   } else {
    $index2$1$lcssa = $index2$061;
   }
   $89 = ($endIndexCount2$060|0)==($57|0);
   if ($89) {
    $90 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomListIndex,64)|0);
    $91 = (($90) + -64)|0;
    $endIndexCount2$0$be = 64;$index2$0$be = $91;
   } else {
    $endIndexCount2$0$be = $58;$index2$0$be = $index2$1$lcssa;
   }
   $92 = ($index2$0$be|0)<($_articulationListSize|0);
   if ($92) {
    $endIndexCount2$060 = $endIndexCount2$0$be;$index2$061 = $index2$0$be;
   } else {
    $endIndexCount2$0$lcssa = $endIndexCount2$0$be;$index2$0$lcssa = $index2$0$be;
    break;
   }
  }
 } else {
  $endIndexCount2$0$lcssa = 64;$index2$0$lcssa = $224;
 }
 $index2$248 = (($index2$0$lcssa) - ($_articulationListSize))|0;
 $53 = ($index2$248|0)<($_atomListSize|0);
 if ($53) {
  $54 = $_atomListSize ^ -1;
  $endIndexCount2$149 = $endIndexCount2$0$lcssa;$index2$250 = $index2$248;
  while(1) {
   $93 = (($_atomListSize) - ($index2$250))|0;
   $94 = ($endIndexCount2$149|0)<($93|0);
   $95 = $94 ? $endIndexCount2$149 : $93;
   $96 = ($95|0)>(0);
   if ($96) {
    $97 = $endIndexCount2$149 ^ -1;
    $98 = (($index2$250) + ($54))|0;
    $99 = ($98|0)<($97|0);
    $smax = $99 ? $97 : $98;
    $100 = $smax ^ -1;
    $a1$043 = 0;$index2$342 = $index2$250;
    while(1) {
     $101 = (($index2$342) + 8)|0;
     $102 = (($atomListStart) + ($101<<5)|0);
     $103 = (($motionVelocityArray) + ($101<<5)|0);
     $104 = ((($atomListStart) + ($index2$342<<5)|0) + 12|0);
     $105 = HEAP16[$104>>1]|0;
     $106 = $105&65535;
     $107 = Math_imul($106, $normalIteration$1$lcssa$1)|0;
     $108 = ((($atomListStart) + ($index2$342<<5)|0) + 14|0);
     $109 = HEAP16[$108>>1]|0;
     $110 = $109&65535;
     $111 = Math_imul($110, $frictionIteration$1$lcssa$1)|0;
     $112 = (($111) + ($107))|0;
     $113 = ((($atomListStart) + ($index2$342<<5)|0) + 28|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)==($112|0);
     if ($115) {
      $137 = $105;
     } else {
      while(1) {
       $116 = HEAP32[$113>>2]|0;
       $117 = ($116|0)==($112|0);
       if ($117) {
        break;
       }
      }
      $$pre141 = HEAP16[$104>>1]|0;
      $137 = $$pre141;
     }
     $118 = (($atomListStart) + ($index2$342<<5)|0);
     $119 = Math_fround(HEAPF32[$118>>2]);
     $120 = (($motionVelocityArray) + ($index2$342<<5)|0);
     HEAPF32[$120>>2] = $119;
     $121 = ((($atomListStart) + ($index2$342<<5)|0) + 4|0);
     $122 = Math_fround(HEAPF32[$121>>2]);
     $123 = ((($motionVelocityArray) + ($index2$342<<5)|0) + 4|0);
     HEAPF32[$123>>2] = $122;
     $124 = ((($atomListStart) + ($index2$342<<5)|0) + 8|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     $126 = ((($motionVelocityArray) + ($index2$342<<5)|0) + 8|0);
     HEAPF32[$126>>2] = $125;
     $127 = ((($atomListStart) + ($index2$342<<5)|0) + 16|0);
     $128 = Math_fround(HEAPF32[$127>>2]);
     $129 = ((($motionVelocityArray) + ($index2$342<<5)|0) + 16|0);
     HEAPF32[$129>>2] = $128;
     $130 = ((($atomListStart) + ($index2$342<<5)|0) + 20|0);
     $131 = Math_fround(HEAPF32[$130>>2]);
     $132 = ((($motionVelocityArray) + ($index2$342<<5)|0) + 20|0);
     HEAPF32[$132>>2] = $131;
     $133 = ((($atomListStart) + ($index2$342<<5)|0) + 24|0);
     $134 = Math_fround(HEAPF32[$133>>2]);
     $135 = ((($motionVelocityArray) + ($index2$342<<5)|0) + 24|0);
     HEAPF32[$135>>2] = $134;
     $136 = $137&65535;
     $138 = (($112) + ($136))|0;
     HEAP32[$113>>2] = $138;
     $139 = (($a1$043) + 1)|0;
     $140 = (($index2$342) + 1)|0;
     $exitcond126 = ($139|0)==($100|0);
     if ($exitcond126) {
      break;
     } else {
      $a1$043 = $139;$index2$342 = $140;
     }
    }
   }
   $141 = (__ZN5physx6shdfnd9atomicAddEPVii($pAtomListIndex,64)|0);
   $142 = (($141) + -64)|0;
   $index2$2 = (($142) - ($_articulationListSize))|0;
   $143 = ($index2$2|0)<($_atomListSize|0);
   if ($143) {
    $endIndexCount2$149 = 64;$index2$250 = $index2$2;
   } else {
    break;
   }
  }
 }
 $144 = (($normalIteration$1$lcssa$1) + 1)|0;
 $145 = (($_velocityIterations) + -1)|0;
 $146 = ($145|0)==(0);
 $147 = (($maxNormalIndex$1$lcssa$1) + ($6))|0;
 if ($146) {
  $$lcssa = $147;$endIndexCount$3$lcssa = $endIndexCount$1$lcssa$1;$frictionEndIndexCount$3$lcssa = $frictionEndIndexCount$1$lcssa$1;$frictionIndex$3$lcssa = $frictionIndex$1$lcssa$1;$frictionIteration$2$lcssa = $frictionIteration$1$lcssa$1;$index$3$lcssa = $index$1$lcssa$1;$maxFrictionIndex$2$lcssa = $maxFrictionIndex$1$lcssa$1;$normalIteration$2$lcssa = $144;
 } else {
  $148 = Math_imul($6, $_velocityIterations)|0;
  $149 = Math_imul($8, $145)|0;
  $150 = (($normalIteration$1$lcssa$1) + ($_velocityIterations))|0;
  $152 = $147;$endIndexCount$333 = $endIndexCount$1$lcssa$1;$frictionEndIndexCount$330 = $frictionEndIndexCount$1$lcssa$1;$frictionIndex$331 = $frictionIndex$1$lcssa$1;$frictionIteration$227 = $frictionIteration$1$lcssa$1;$index$332 = $index$1$lcssa$1;$maxFrictionIndex$229 = $maxFrictionIndex$1$lcssa$1;$normalIteration$228 = $144;
  while(1) {
   $151 = ($index$332|0)<($152|0);
   if ($151) {
    $endIndexCount$414 = $endIndexCount$333;$index$413 = $index$332;
    while(1) {
     $157 = (($152) - ($index$413))|0;
     $158 = ($157|0)<($endIndexCount$414|0);
     $159 = $158 ? $157 : $endIndexCount$414;
     $160 = (($index$413) + ($6))|0;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($contactConstraintList,$159,$160,$6,$cache,$contactIter,502064,$normalIteration$228,$frictionIteration$227,$normalIteration$228);
     $161 = (($159) + ($index$413))|0;
     $162 = (($endIndexCount$414) - ($159))|0;
     $163 = ($endIndexCount$414|0)==($159|0);
     if ($163) {
      $164 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,32)|0);
      $165 = (($164) + -32)|0;
      $endIndexCount$4$be = 32;$index$4$be = $165;
     } else {
      $endIndexCount$4$be = $162;$index$4$be = $161;
     }
     $166 = ($index$4$be|0)<($152|0);
     if ($166) {
      $endIndexCount$414 = $endIndexCount$4$be;$index$413 = $index$4$be;
     } else {
      $endIndexCount$4$lcssa = $endIndexCount$4$be;$index$4$lcssa = $index$4$be;
      break;
     }
    }
   } else {
    $endIndexCount$4$lcssa = $endIndexCount$333;$index$4$lcssa = $index$332;
   }
   $167 = (($normalIteration$228) + 1)|0;
   $168 = (($maxFrictionIndex$229) + ($8))|0;
   $169 = ($frictionIndex$331|0)<($168|0);
   if ($169) {
    $frictionEndIndexCount$419 = $frictionEndIndexCount$330;$frictionIndex$420 = $frictionIndex$331;
    while(1) {
     $170 = (($168) - ($frictionIndex$420))|0;
     $171 = ($170|0)<($frictionEndIndexCount$419|0);
     $172 = $171 ? $170 : $frictionEndIndexCount$419;
     __Z18SolveBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextER16PxsBatchIteratorPPFvPKS1_jS4_Eiij($frictionConstraintList,$172,$frictionIndex$420,$8,$cache,$frictionIter,502064,$167,$frictionIteration$227,$frictionIteration$227);
     $173 = (($172) + ($frictionIndex$420))|0;
     $174 = (($frictionEndIndexCount$419) - ($172))|0;
     $175 = ($frictionEndIndexCount$419|0)==($172|0);
     if ($175) {
      $176 = (__ZN5physx6shdfnd9atomicAddEPVii($pFrictionConstraintIndex,32)|0);
      $177 = (($176) + -32)|0;
      $frictionEndIndexCount$4$be = 32;$frictionIndex$4$be = $177;
     } else {
      $frictionEndIndexCount$4$be = $174;$frictionIndex$4$be = $173;
     }
     $178 = ($frictionIndex$4$be|0)<($168|0);
     if ($178) {
      $frictionEndIndexCount$419 = $frictionEndIndexCount$4$be;$frictionIndex$420 = $frictionIndex$4$be;
     } else {
      $frictionEndIndexCount$4$lcssa = $frictionEndIndexCount$4$be;$frictionIndex$4$lcssa = $frictionIndex$4$be;
      break;
     }
    }
   } else {
    $frictionEndIndexCount$4$lcssa = $frictionEndIndexCount$330;$frictionIndex$4$lcssa = $frictionIndex$331;
   }
   $179 = (($frictionIteration$227) + 1)|0;
   $180 = (($152) + ($6))|0;
   $exitcond = ($167|0)==($150|0);
   if ($exitcond) {
    break;
   } else {
    $152 = $180;$endIndexCount$333 = $endIndexCount$4$lcssa;$frictionEndIndexCount$330 = $frictionEndIndexCount$4$lcssa;$frictionIndex$331 = $frictionIndex$4$lcssa;$frictionIteration$227 = $179;$index$332 = $index$4$lcssa;$maxFrictionIndex$229 = $168;$normalIteration$228 = $167;
   }
  }
  $153 = (($148) + ($maxNormalIndex$1$lcssa$1))|0;
  $154 = (($145) + ($frictionIteration$1$lcssa$1))|0;
  $155 = (($149) + ($maxFrictionIndex$1$lcssa$1))|0;
  $$lcssa = $153;$endIndexCount$3$lcssa = $endIndexCount$4$lcssa;$frictionEndIndexCount$3$lcssa = $frictionEndIndexCount$4$lcssa;$frictionIndex$3$lcssa = $frictionIndex$4$lcssa;$frictionIteration$2$lcssa = $154;$index$3$lcssa = $index$4$lcssa;$maxFrictionIndex$2$lcssa = $155;$normalIteration$2$lcssa = $150;
 }
 $156 = ($index$3$lcssa|0)<($$lcssa|0);
 if ($156) {
  $endIndexCount$58 = $endIndexCount$3$lcssa;$index$57 = $index$3$lcssa;
  while(1) {
   $181 = (($$lcssa) - ($index$57))|0;
   $182 = ($181|0)<($endIndexCount$58|0);
   $183 = $182 ? $181 : $endIndexCount$58;
   $184 = (($index$57) + ($6))|0;
   __Z27SolveWriteBackBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextEPNS0_25PxcThresholdStreamElementEjPiR16PxsBatchIteratorjjjPPFvPKS1_jS4_S6_jS7_E($contactConstraintList,$183,$184,$6,$cache,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$contactIter,$normalIteration$2$lcssa,$frictionIteration$2$lcssa,$normalIteration$2$lcssa,502128);
   $185 = (($183) + ($index$57))|0;
   $186 = (($endIndexCount$58) - ($183))|0;
   $187 = ($endIndexCount$58|0)==($183|0);
   if ($187) {
    $188 = (__ZN5physx6shdfnd9atomicAddEPVii($pConstraintIndex,32)|0);
    $189 = (($188) + -32)|0;
    $endIndexCount$5$be = 32;$index$5$be = $189;
   } else {
    $endIndexCount$5$be = $186;$index$5$be = $185;
   }
   $190 = ($index$5$be|0)<($$lcssa|0);
   if ($190) {
    $endIndexCount$58 = $endIndexCount$5$be;$index$57 = $index$5$be;
   } else {
    break;
   }
  }
 }
 $191 = (($normalIteration$2$lcssa) + 1)|0;
 $192 = (($maxFrictionIndex$2$lcssa) + ($8))|0;
 $193 = ($frictionIndex$3$lcssa|0)<($192|0);
 if ($193) {
  $frictionEndIndexCount$54 = $frictionEndIndexCount$3$lcssa;$frictionIndex$55 = $frictionIndex$3$lcssa;
 } else {
  $203 = (($frictionIteration$2$lcssa) + 1)|0;
  HEAP32[$_normalIterations>>2] = $191;
  HEAP32[$_frictionIterations>>2] = $203;
  STACKTOP = sp;return;
 }
 while(1) {
  $194 = (($192) - ($frictionIndex$55))|0;
  $195 = ($194|0)<($frictionEndIndexCount$54|0);
  $196 = $195 ? $194 : $frictionEndIndexCount$54;
  __Z27SolveWriteBackBlockParallelILb1EEvPN5physx23PxcSolverConstraintDescEjiiRNS0_16PxcSolverContextEPNS0_25PxcThresholdStreamElementEjPiR16PxsBatchIteratorjjjPPFvPKS1_jS4_S6_jS7_E($frictionConstraintList,$196,$frictionIndex$55,$8,$cache,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$frictionIter,$191,$frictionIteration$2$lcssa,$frictionIteration$2$lcssa,502128);
  $197 = (($196) + ($frictionIndex$55))|0;
  $198 = (($frictionEndIndexCount$54) - ($196))|0;
  $199 = ($frictionEndIndexCount$54|0)==($196|0);
  if ($199) {
   $200 = (__ZN5physx6shdfnd9atomicAddEPVii($pFrictionConstraintIndex,32)|0);
   $201 = (($200) + -32)|0;
   $frictionEndIndexCount$5$be = 32;$frictionIndex$5$be = $201;
  } else {
   $frictionEndIndexCount$5$be = $198;$frictionIndex$5$be = $197;
  }
  $202 = ($frictionIndex$5$be|0)<($192|0);
  if ($202) {
   $frictionEndIndexCount$54 = $frictionEndIndexCount$5$be;$frictionIndex$55 = $frictionIndex$5$be;
  } else {
   break;
  }
 }
 $203 = (($frictionIteration$2$lcssa) + 1)|0;
 HEAP32[$_normalIterations>>2] = $191;
 HEAP32[$_frictionIterations>>2] = $203;
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsSolverCoreGeneral10writeBackVEPKNS_23PxcSolverConstraintDescEjPNS_25PxcThresholdStreamElementEjRjPNS_17PxcSolverBodyDataEPPFvRS2_RNS_16PxcSolverContextERS7_SC_E($this,$constraintList,$constraintListSize,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$atomListData,$writeBackTable) {
 $this = $this|0;
 $constraintList = $constraintList|0;
 $constraintListSize = $constraintListSize|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $atomListData = $atomListData|0;
 $writeBackTable = $writeBackTable|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cache = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $cache = sp;
 $0 = (($cache) + 16|0);
 HEAP32[$0>>2] = $atomListData;
 $1 = (($cache) + 4|0);
 HEAP32[$1>>2] = $thresholdStream;
 $2 = (($cache) + 12|0);
 HEAP32[$2>>2] = $thresholdStreamLength;
 $3 = (($cache) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ($constraintListSize|0)==(0);
 if ($4) {
  $29 = 0;
  HEAP32[$outThresholdPairs>>2] = $29;
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $5 = (($constraintList) + ($i$01<<5)|0);
  $6 = ((($constraintList) + ($i$01<<5)|0) + 8|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = ($7<<16>>16)==(-1);
  if ($8) {
   $9 = ((($constraintList) + ($i$01<<5)|0) + 10|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = $10&65535;
   $13 = $11;
  } else {
   $13 = 0;
  }
  $12 = (($atomListData) + ($13<<6)|0);
  $14 = ((($constraintList) + ($i$01<<5)|0) + 12|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = ($15<<16>>16)==(-1);
  if ($16) {
   $17 = ((($constraintList) + ($i$01<<5)|0) + 14|0);
   $18 = HEAP16[$17>>1]|0;
   $19 = $18&65535;
   $21 = $19;
  } else {
   $21 = 0;
  }
  $20 = (($atomListData) + ($21<<6)|0);
  $22 = ((($constraintList) + ($i$01<<5)|0) + 16|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = (($writeBackTable) + ($25<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_viiii[$27 & 511]($5,$cache,$12,$20);
  $28 = (($i$01) + 1)|0;
  $exitcond = ($28|0)==($constraintListSize|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $28;
  }
 }
 $$pre = HEAP32[$3>>2]|0;
 $29 = $$pre;
 HEAP32[$outThresholdPairs>>2] = $29;
 STACKTOP = sp;return;
}
function __ZNK5physx20PxsSolverCoreGeneral10writeBackVEPKNS_23PxcSolverConstraintDescEjPNS_24PxsConstraintBatchHeaderEjPNS_25PxcThresholdStreamElementEjRjPNS_17PxcSolverBodyDataEPPFvS3_jRNS_16PxcSolverContextES7_jPiE($this,$constraintList,$0,$batchHeaders,$numBatches,$thresholdStream,$thresholdStreamLength,$outThresholdPairs,$atomListData,$writeBackTable) {
 $this = $this|0;
 $constraintList = $constraintList|0;
 $0 = $0|0;
 $batchHeaders = $batchHeaders|0;
 $numBatches = $numBatches|0;
 $thresholdStream = $thresholdStream|0;
 $thresholdStreamLength = $thresholdStreamLength|0;
 $outThresholdPairs = $outThresholdPairs|0;
 $atomListData = $atomListData|0;
 $writeBackTable = $writeBackTable|0;
 var $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $cache = 0, $exitcond = 0, $j$01 = 0, $outThreshIndex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $cache = sp + 4|0;
 $outThreshIndex = sp;
 $1 = (($cache) + 16|0);
 HEAP32[$1>>2] = $atomListData;
 $2 = (($cache) + 4|0);
 HEAP32[$2>>2] = $thresholdStream;
 $3 = (($cache) + 12|0);
 HEAP32[$3>>2] = $thresholdStreamLength;
 $4 = (($cache) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$outThreshIndex>>2] = 0;
 $5 = ($numBatches|0)==(0);
 if ($5) {
  $19 = 0;
  HEAP32[$outThresholdPairs>>2] = $19;
  STACKTOP = sp;return;
 } else {
  $j$01 = 0;
 }
 while(1) {
  $6 = (($batchHeaders) + ($j$01<<3)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($constraintList) + ($7<<5)|0);
  $9 = ((($constraintList) + ($7<<5)|0) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = (($writeBackTable) + ($12<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($batchHeaders) + ($j$01<<3)|0) + 4|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = $16&65535;
  FUNCTION_TABLE_viiiiii[$14 & 255]($8,$17,$cache,$thresholdStream,$thresholdStreamLength,$outThreshIndex);
  $18 = (($j$01) + 1)|0;
  $exitcond = ($18|0)==($numBatches|0);
  if ($exitcond) {
   break;
  } else {
   $j$01 = $18;
  }
 }
 $$pre = HEAP32[$outThreshIndex>>2]|0;
 $19 = $$pre;
 HEAP32[$outThresholdPairs>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsSolverCoreGeneralD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx20PxsSolverCoreGeneralD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx7solve1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i = Math_fround(0), $$$i52 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa379 = Math_fround(0), $$lcssa380 = Math_fround(0), $$lcssa381 = Math_fround(0), $$lcssa382 = Math_fround(0), $$lcssa383 = Math_fround(0), $$lcssa384 = Math_fround(0), $$lcssa385 = Math_fround(0), $$lcssa386 = Math_fround(0), $$lcssa387 = Math_fround(0), $$lcssa388 = Math_fround(0), $$lcssa389 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0);
 var $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0;
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $base$0391 = 0, $i$0390 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($desc) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$0>>2]);
 $6 = (($0) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$2>>2]);
 $11 = (($2) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($2) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($0) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($0) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($0) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($2) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($2) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($2) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($4) + 1|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  $$lcssa = $9;$$lcssa379 = $7;$$lcssa380 = $5;$$lcssa381 = $14;$$lcssa382 = $12;$$lcssa383 = $10;$$lcssa384 = $20;$$lcssa385 = $18;$$lcssa386 = $16;$$lcssa387 = $26;$$lcssa388 = $24;$$lcssa389 = $22;
  HEAPF32[$0>>2] = $$lcssa380;
  HEAPF32[$6>>2] = $$lcssa379;
  HEAPF32[$8>>2] = $$lcssa;
  HEAPF32[$15>>2] = $$lcssa386;
  HEAPF32[$17>>2] = $$lcssa385;
  HEAPF32[$19>>2] = $$lcssa384;
  HEAPF32[$2>>2] = $$lcssa383;
  HEAPF32[$11>>2] = $$lcssa382;
  HEAPF32[$13>>2] = $$lcssa381;
  HEAPF32[$21>>2] = $$lcssa389;
  HEAPF32[$23>>2] = $$lcssa388;
  HEAPF32[$25>>2] = $$lcssa387;
  STACKTOP = sp;return;
 }
 $30 = (($4) + 48|0);
 $100 = $10;$102 = $12;$105 = $14;$108 = $22;$110 = $24;$113 = $26;$84 = $5;$86 = $7;$89 = $9;$92 = $16;$94 = $18;$97 = $20;$base$0391 = $30;$i$0390 = 0;
 while(1) {
  $31 = (($base$0391) + 112|0);
  $32 = Math_fround(HEAPF32[$base$0391>>2]);
  $33 = (($base$0391) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($base$0391) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($base$0391) + 16|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($base$0391) + 20|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($base$0391) + 24|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($base$0391) + 32|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($base$0391) + 36|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($base$0391) + 40|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($base$0391) + 48|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = (($base$0391) + 52|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (($base$0391) + 56|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($base$0391) + 64|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($base$0391) + 68|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($base$0391) + 72|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($base$0391) + 80|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = (($base$0391) + 84|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($base$0391) + 88|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = (($base$0391) + 76|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($base$0391) + 92|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = (($base$0391) + 12|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($base$0391) + 44|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($base$0391) + 60|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($base$0391) + 104|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($base$0391) + 100|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (($base$0391) + 96|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($84 * $32);
  $85 = Math_fround($86 * $34);
  $87 = Math_fround($83 + $85);
  $88 = Math_fround($89 * $36);
  $90 = Math_fround($87 + $88);
  $91 = Math_fround($92 * $44);
  $93 = Math_fround($94 * $46);
  $95 = Math_fround($91 + $93);
  $96 = Math_fround($97 * $48);
  $98 = Math_fround($95 + $96);
  $99 = Math_fround($100 * $38);
  $101 = Math_fround($102 * $40);
  $103 = Math_fround($99 + $101);
  $104 = Math_fround($105 * $42);
  $106 = Math_fround($103 + $104);
  $107 = Math_fround($108 * $50);
  $109 = Math_fround($110 * $52);
  $111 = Math_fround($107 + $109);
  $112 = Math_fround($113 * $54);
  $114 = Math_fround($111 + $112);
  $115 = Math_fround($90 + $98);
  $116 = Math_fround($106 + $114);
  $117 = Math_fround($115 - $116);
  $118 = Math_fround($117 * $74);
  $119 = Math_fround($72 + $118);
  $120 = Math_fround($76 * $78);
  $121 = Math_fround($119 + $120);
  $122 = $82 > $121;
  $$$i52 = $122 ? $82 : $121;
  $123 = $80 > $$$i52;
  $$$i = $123 ? $$$i52 : $80;
  $124 = Math_fround($$$i - $78);
  $125 = Math_fround($32 * $68);
  $126 = Math_fround($34 * $68);
  $127 = Math_fround($36 * $68);
  $128 = Math_fround($38 * $70);
  $129 = Math_fround($40 * $70);
  $130 = Math_fround($42 * $70);
  HEAPF32[$77>>2] = $$$i;
  $131 = Math_fround($125 * $124);
  $132 = Math_fround($126 * $124);
  $133 = Math_fround($127 * $124);
  $134 = Math_fround($84 + $131);
  $135 = Math_fround($86 + $132);
  $136 = Math_fround($89 + $133);
  $137 = Math_fround($128 * $124);
  $138 = Math_fround($129 * $124);
  $139 = Math_fround($130 * $124);
  $140 = Math_fround($100 + $137);
  $141 = Math_fround($102 + $138);
  $142 = Math_fround($105 + $139);
  $143 = Math_fround($56 * $124);
  $144 = Math_fround($58 * $124);
  $145 = Math_fround($60 * $124);
  $146 = Math_fround($92 + $143);
  $147 = Math_fround($94 + $144);
  $148 = Math_fround($97 + $145);
  $149 = Math_fround($62 * $124);
  $150 = Math_fround($64 * $124);
  $151 = Math_fround($66 * $124);
  $152 = Math_fround($108 + $149);
  $153 = Math_fround($110 + $150);
  $154 = Math_fround($113 + $151);
  $155 = (($i$0390) + 1)|0;
  $156 = HEAP8[$27>>0]|0;
  $157 = $156&255;
  $158 = ($155>>>0)<($157>>>0);
  if ($158) {
   $100 = $140;$102 = $141;$105 = $142;$108 = $152;$110 = $153;$113 = $154;$84 = $134;$86 = $135;$89 = $136;$92 = $146;$94 = $147;$97 = $148;$base$0391 = $31;$i$0390 = $155;
  } else {
   $$lcssa = $136;$$lcssa379 = $135;$$lcssa380 = $134;$$lcssa381 = $142;$$lcssa382 = $141;$$lcssa383 = $140;$$lcssa384 = $148;$$lcssa385 = $147;$$lcssa386 = $146;$$lcssa387 = $154;$$lcssa388 = $153;$$lcssa389 = $152;
   break;
  }
 }
 HEAPF32[$0>>2] = $$lcssa380;
 HEAPF32[$6>>2] = $$lcssa379;
 HEAPF32[$8>>2] = $$lcssa;
 HEAPF32[$15>>2] = $$lcssa386;
 HEAPF32[$17>>2] = $$lcssa385;
 HEAPF32[$19>>2] = $$lcssa384;
 HEAPF32[$2>>2] = $$lcssa383;
 HEAPF32[$11>>2] = $$lcssa382;
 HEAPF32[$13>>2] = $$lcssa381;
 HEAPF32[$21>>2] = $$lcssa389;
 HEAPF32[$23>>2] = $$lcssa388;
 HEAPF32[$25>>2] = $$lcssa387;
 STACKTOP = sp;return;
}
function __ZN5physx10conclude1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $base$02 = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = (($desc) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(4);
 $5 = $4 ? 176 : 112;
 $6 = (($2) + 1|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($2) + 48|0);
 $base$02 = $9;$i$01 = 0;
 while(1) {
  $10 = (($base$02) + 28|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($base$02) + 12|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($base$02) + ($5)|0);
  $14 = (($i$01) + 1)|0;
  $15 = HEAP8[$6>>0]|0;
  $16 = $15&255;
  $17 = ($14>>>0)<($16>>>0);
  if ($17) {
   $base$02 = $13;$i$01 = $14;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx12solveContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i = Math_fround(0), $$$i192 = Math_fround(0), $$$i201 = Math_fround(0), $$$i65 = Math_fround(0), $$be = Math_fround(0), $$be1094 = Math_fround(0), $$be1095 = Math_fround(0), $$be1096 = Math_fround(0), $$be1097 = Math_fround(0), $$be1098 = Math_fround(0), $$be1099 = Math_fround(0), $$be1100 = Math_fround(0), $$be1101 = Math_fround(0), $$be1102 = Math_fround(0), $$be1103 = Math_fround(0), $$be1104 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa1042 = Math_fround(0), $$lcssa1043 = Math_fround(0), $$lcssa1044 = Math_fround(0);
 var $$lcssa1045 = Math_fround(0), $$lcssa1046 = Math_fround(0), $$lcssa1047 = Math_fround(0), $$lcssa1048 = Math_fround(0), $$lcssa1049 = Math_fround(0), $$lcssa1050 = Math_fround(0), $$lcssa1051 = Math_fround(0), $$lcssa1052 = Math_fround(0), $$lcssa1053 = Math_fround(0), $$lcssa1105 = Math_fround(0), $$lcssa1106 = Math_fround(0), $$lcssa1107 = Math_fround(0), $$lcssa1108 = Math_fround(0), $$lcssa1109 = Math_fround(0), $$lcssa1110 = Math_fround(0), $$lcssa1111 = Math_fround(0), $$lcssa1112 = Math_fround(0), $$lcssa1113 = Math_fround(0), $$lcssa1114 = Math_fround(0), $$lcssa1115 = Math_fround(0);
 var $$lcssa1116 = Math_fround(0), $$sum = 0, $$sum1 = 0, $$sum1040 = 0, $$sum1041 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0;
 var $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = 0, $310 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0);
 var $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0);
 var $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $currPtr$01117 = 0, $exitcond = 0, $exitcond1158 = 0, $fabsf$i$i$i = Math_fround(0);
 var $i$01054 = 0, $i1$01079 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$0>>2]);
 $4 = (($0) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(HEAPF32[$2>>2]);
 $9 = (($2) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($2) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($0) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($0) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($0) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($2) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($2) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($2) + 24|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($desc) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($desc) + 26|0);
 $28 = HEAP16[$27>>1]|0;
 $29 = $28&65535;
 $30 = $29 << 4;
 $31 = (($26) + ($30)|0);
 $32 = ($28<<16>>16)==(0);
 if ($32) {
  $$lcssa1105 = $7;$$lcssa1106 = $5;$$lcssa1107 = $3;$$lcssa1108 = $12;$$lcssa1109 = $10;$$lcssa1110 = $8;$$lcssa1111 = $18;$$lcssa1112 = $16;$$lcssa1113 = $14;$$lcssa1114 = $24;$$lcssa1115 = $22;$$lcssa1116 = $20;
  HEAPF32[$0>>2] = $$lcssa1107;
  HEAPF32[$4>>2] = $$lcssa1106;
  HEAPF32[$6>>2] = $$lcssa1105;
  HEAPF32[$2>>2] = $$lcssa1110;
  HEAPF32[$9>>2] = $$lcssa1109;
  HEAPF32[$11>>2] = $$lcssa1108;
  HEAPF32[$13>>2] = $$lcssa1113;
  HEAPF32[$15>>2] = $$lcssa1112;
  HEAPF32[$17>>2] = $$lcssa1111;
  HEAPF32[$19>>2] = $$lcssa1116;
  HEAPF32[$21>>2] = $$lcssa1115;
  HEAPF32[$23>>2] = $$lcssa1114;
  STACKTOP = sp;return;
 }
 $33 = (($cache) + 1|0);
 $299 = $20;$300 = $22;$301 = $24;$302 = $14;$303 = $16;$304 = $18;$305 = $8;$306 = $10;$307 = $12;$308 = $3;$309 = $5;$310 = $7;$currPtr$01117 = $26;
 while(1) {
  $34 = (($currPtr$01117) + 32|0);
  $35 = (($currPtr$01117) + 5|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = (($currPtr$01117) + 6|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = ($37*96)|0;
  $$sum = (($41) + 32)|0;
  $42 = (($currPtr$01117) + ($$sum)|0);
  $43 = ($40*96)|0;
  $$sum1 = (($$sum) + ($43))|0;
  $44 = (($currPtr$01117) + ($$sum1)|0);
  $45 = (($currPtr$01117) + 108|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($currPtr$01117) + 124|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = ($36<<24>>24)==(0);
  if ($49) {
   $$lcssa = $310;$$lcssa1042 = $309;$$lcssa1043 = $308;$$lcssa1044 = $307;$$lcssa1045 = $306;$$lcssa1046 = $305;$$lcssa1047 = $304;$$lcssa1048 = $303;$$lcssa1049 = $302;$$lcssa1050 = $301;$$lcssa1051 = $300;$$lcssa1052 = $299;$$lcssa1053 = Math_fround(0.0);
  } else {
   $101 = $307;$104 = $299;$106 = $300;$109 = $301;$166 = Math_fround(0.0);$80 = $308;$82 = $309;$85 = $310;$88 = $302;$90 = $303;$93 = $304;$96 = $305;$98 = $306;$i$01054 = 0;
   while(1) {
    $$sum1041 = (($i$01054) + 1)|0;
    $50 = ((($34) + (($$sum1041*96)|0)|0) + 32|0);
    $51 = (($34) + (($i$01054*96)|0)|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = ((($34) + (($i$01054*96)|0)|0) + 4|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = ((($34) + (($i$01054*96)|0)|0) + 8|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = ((($34) + (($i$01054*96)|0)|0) + 12|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = ((($34) + (($i$01054*96)|0)|0) + 16|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = ((($34) + (($i$01054*96)|0)|0) + 20|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = ((($34) + (($i$01054*96)|0)|0) + 24|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = ((($34) + (($i$01054*96)|0)|0) + 28|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($34) + (($i$01054*96)|0)|0) + 32|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = ((($34) + (($i$01054*96)|0)|0) + 36|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = ((($34) + (($i$01054*96)|0)|0) + 40|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = ((($34) + (($i$01054*96)|0)|0) + 52|0);
    $74 = Math_fround(HEAPF32[$73>>2]);
    $75 = ((($34) + (($i$01054*96)|0)|0) + 48|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = ((($34) + (($i$01054*96)|0)|0) + 56|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = Math_fround($80 * $52);
    $81 = Math_fround($82 * $54);
    $83 = Math_fround($79 + $81);
    $84 = Math_fround($85 * $56);
    $86 = Math_fround($83 + $84);
    $87 = Math_fround($88 * $60);
    $89 = Math_fround($90 * $62);
    $91 = Math_fround($87 + $89);
    $92 = Math_fround($93 * $64);
    $94 = Math_fround($91 + $92);
    $95 = Math_fround($96 * $52);
    $97 = Math_fround($98 * $54);
    $99 = Math_fround($95 + $97);
    $100 = Math_fround($101 * $56);
    $102 = Math_fround($99 + $100);
    $103 = Math_fround($104 * $68);
    $105 = Math_fround($106 * $70);
    $107 = Math_fround($103 + $105);
    $108 = Math_fround($109 * $72);
    $110 = Math_fround($107 + $108);
    $111 = Math_fround($58 * $74);
    $112 = Math_fround($111 - $76);
    $113 = Math_fround($86 + $94);
    $114 = Math_fround($102 + $110);
    $115 = Math_fround($113 - $114);
    $116 = ((($34) + (($i$01054*96)|0)|0) + 64|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = ((($34) + (($i$01054*96)|0)|0) + 68|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = ((($34) + (($i$01054*96)|0)|0) + 72|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    $122 = ((($34) + (($i$01054*96)|0)|0) + 80|0);
    $123 = Math_fround(HEAPF32[$122>>2]);
    $124 = ((($34) + (($i$01054*96)|0)|0) + 84|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = ((($34) + (($i$01054*96)|0)|0) + 88|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = Math_fround($46 * $52);
    $129 = Math_fround($46 * $54);
    $130 = Math_fround($46 * $56);
    $131 = Math_fround($48 * $52);
    $132 = Math_fround($48 * $54);
    $133 = Math_fround($48 * $56);
    $134 = Math_fround($58 * $115);
    $135 = Math_fround($112 - $134);
    $136 = Math_fround(-$66);
    $137 = $135 > $136;
    $$$i201 = $137 ? $135 : $136;
    $138 = Math_fround($66 + $$$i201);
    $139 = $138 > $78;
    $$$i192 = $139 ? $78 : $138;
    $140 = Math_fround($$$i192 - $66);
    $141 = Math_fround($128 * $140);
    $142 = Math_fround($129 * $140);
    $143 = Math_fround($130 * $140);
    $144 = Math_fround($80 + $141);
    $145 = Math_fround($82 + $142);
    $146 = Math_fround($85 + $143);
    $147 = Math_fround($131 * $140);
    $148 = Math_fround($132 * $140);
    $149 = Math_fround($133 * $140);
    $150 = Math_fround($96 + $147);
    $151 = Math_fround($98 + $148);
    $152 = Math_fround($101 + $149);
    $153 = Math_fround($117 * $140);
    $154 = Math_fround($119 * $140);
    $155 = Math_fround($121 * $140);
    $156 = Math_fround($88 + $153);
    $157 = Math_fround($90 + $154);
    $158 = Math_fround($93 + $155);
    $159 = Math_fround($123 * $140);
    $160 = Math_fround($125 * $140);
    $161 = Math_fround($127 * $140);
    $162 = Math_fround($104 + $159);
    $163 = Math_fround($106 + $160);
    $164 = Math_fround($109 + $161);
    HEAPF32[$65>>2] = $$$i192;
    $165 = Math_fround($166 + $$$i192);
    $exitcond = ($$sum1041|0)==($37|0);
    if ($exitcond) {
     $$lcssa = $146;$$lcssa1042 = $145;$$lcssa1043 = $144;$$lcssa1044 = $152;$$lcssa1045 = $151;$$lcssa1046 = $150;$$lcssa1047 = $158;$$lcssa1048 = $157;$$lcssa1049 = $156;$$lcssa1050 = $164;$$lcssa1051 = $163;$$lcssa1052 = $162;$$lcssa1053 = $165;
     break;
    } else {
     $101 = $152;$104 = $162;$106 = $163;$109 = $164;$166 = $165;$80 = $144;$82 = $145;$85 = $146;$88 = $156;$90 = $157;$93 = $158;$96 = $150;$98 = $151;$i$01054 = $$sum1041;
    }
   }
  }
  $167 = HEAP8[$cache>>0]|0;
  $168 = ($167<<24>>24)==(0);
  $169 = ($39<<24>>24)==(0);
  $or$cond = $168 | $169;
  if ($or$cond) {
   $$be = $$lcssa;$$be1094 = $$lcssa1042;$$be1095 = $$lcssa1043;$$be1096 = $$lcssa1044;$$be1097 = $$lcssa1045;$$be1098 = $$lcssa1046;$$be1099 = $$lcssa1047;$$be1100 = $$lcssa1048;$$be1101 = $$lcssa1049;$$be1102 = $$lcssa1050;$$be1103 = $$lcssa1051;$$be1104 = $$lcssa1052;
  } else {
   $171 = (($currPtr$01117) + 16|0);
   $172 = Math_fround(HEAPF32[$171>>2]);
   $173 = (($currPtr$01117) + 20|0);
   $174 = Math_fround(HEAPF32[$173>>2]);
   $175 = Math_fround($$lcssa1053 * $172);
   $176 = Math_fround($$lcssa1053 * $174);
   $177 = Math_fround(-$176);
   $212 = $$lcssa1043;$214 = $$lcssa1042;$217 = $$lcssa;$220 = $$lcssa1049;$222 = $$lcssa1048;$225 = $$lcssa1047;$228 = $$lcssa1046;$230 = $$lcssa1045;$233 = $$lcssa1044;$236 = $$lcssa1052;$238 = $$lcssa1051;$241 = $$lcssa1050;$i1$01079 = 0;
   while(1) {
    $$sum1040 = (($i1$01079) + 1)|0;
    $178 = ((($42) + (($$sum1040*96)|0)|0) + 32|0);
    $179 = HEAP8[$33>>0]|0;
    $180 = ($179<<24>>24)==(0);
    if (!($180)) {
     $181 = ((($42) + (($i1$01079*96)|0)|0) + 80|0);
     $182 = HEAP32[$181>>2]|0;
    }
    $183 = (($42) + (($i1$01079*96)|0)|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    $185 = ((($42) + (($i1$01079*96)|0)|0) + 4|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = ((($42) + (($i1$01079*96)|0)|0) + 8|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = ((($42) + (($i1$01079*96)|0)|0) + 12|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = ((($42) + (($i1$01079*96)|0)|0) + 16|0);
    $192 = Math_fround(HEAPF32[$191>>2]);
    $193 = ((($42) + (($i1$01079*96)|0)|0) + 20|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = ((($42) + (($i1$01079*96)|0)|0) + 24|0);
    $196 = Math_fround(HEAPF32[$195>>2]);
    $197 = ((($42) + (($i1$01079*96)|0)|0) + 28|0);
    $198 = Math_fround(HEAPF32[$197>>2]);
    $199 = ((($42) + (($i1$01079*96)|0)|0) + 32|0);
    $200 = Math_fround(HEAPF32[$199>>2]);
    $201 = ((($42) + (($i1$01079*96)|0)|0) + 36|0);
    $202 = Math_fround(HEAPF32[$201>>2]);
    $203 = ((($42) + (($i1$01079*96)|0)|0) + 40|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = ((($42) + (($i1$01079*96)|0)|0) + 44|0);
    $206 = Math_fround(HEAPF32[$205>>2]);
    $207 = ((($42) + (($i1$01079*96)|0)|0) + 60|0);
    $208 = Math_fround(HEAPF32[$207>>2]);
    $209 = ((($42) + (($i1$01079*96)|0)|0) + 76|0);
    $210 = Math_fround(HEAPF32[$209>>2]);
    $211 = Math_fround($212 * $184);
    $213 = Math_fround($214 * $186);
    $215 = Math_fround($211 + $213);
    $216 = Math_fround($217 * $188);
    $218 = Math_fround($215 + $216);
    $219 = Math_fround($220 * $192);
    $221 = Math_fround($222 * $194);
    $223 = Math_fround($219 + $221);
    $224 = Math_fround($225 * $196);
    $226 = Math_fround($223 + $224);
    $227 = Math_fround($228 * $184);
    $229 = Math_fround($230 * $186);
    $231 = Math_fround($227 + $229);
    $232 = Math_fround($233 * $188);
    $234 = Math_fround($231 + $232);
    $235 = Math_fround($236 * $200);
    $237 = Math_fround($238 * $202);
    $239 = Math_fround($235 + $237);
    $240 = Math_fround($241 * $204);
    $242 = Math_fround($239 + $240);
    $243 = Math_fround($218 + $226);
    $244 = Math_fround($234 + $242);
    $245 = Math_fround($243 - $244);
    $246 = Math_fround($206 - $210);
    $247 = Math_fround($198 * $246);
    $248 = Math_fround($190 - $247);
    $249 = ((($42) + (($i1$01079*96)|0)|0) + 48|0);
    $250 = Math_fround(HEAPF32[$249>>2]);
    $251 = ((($42) + (($i1$01079*96)|0)|0) + 52|0);
    $252 = Math_fround(HEAPF32[$251>>2]);
    $253 = ((($42) + (($i1$01079*96)|0)|0) + 56|0);
    $254 = Math_fround(HEAPF32[$253>>2]);
    $255 = ((($42) + (($i1$01079*96)|0)|0) + 64|0);
    $256 = Math_fround(HEAPF32[$255>>2]);
    $257 = ((($42) + (($i1$01079*96)|0)|0) + 68|0);
    $258 = Math_fround(HEAPF32[$257>>2]);
    $259 = ((($42) + (($i1$01079*96)|0)|0) + 72|0);
    $260 = Math_fround(HEAPF32[$259>>2]);
    $261 = Math_fround($46 * $184);
    $262 = Math_fround($46 * $186);
    $263 = Math_fround($46 * $188);
    $264 = Math_fround($48 * $184);
    $265 = Math_fround($48 * $186);
    $266 = Math_fround($48 * $188);
    $267 = Math_fround($198 * $245);
    $268 = Math_fround($248 - $267);
    $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($268)))));
    $269 = $268 < $177;
    $$$i65 = $269 ? $177 : $268;
    $270 = $176 > $$$i65;
    $$$i = $270 ? $$$i65 : $176;
    $271 = !($fabsf$i$i$i > $175);
    $272 = $271 ? $268 : $$$i;
    $273 = Math_fround($272 - $190);
    $274 = $271 ? $208 : Math_fround(1.0);
    $275 = Math_fround($261 * $273);
    $276 = Math_fround($262 * $273);
    $277 = Math_fround($263 * $273);
    $278 = Math_fround($212 + $275);
    $279 = Math_fround($214 + $276);
    $280 = Math_fround($217 + $277);
    $281 = Math_fround($264 * $273);
    $282 = Math_fround($265 * $273);
    $283 = Math_fround($266 * $273);
    $284 = Math_fround($228 + $281);
    $285 = Math_fround($230 + $282);
    $286 = Math_fround($233 + $283);
    $287 = Math_fround($250 * $273);
    $288 = Math_fround($252 * $273);
    $289 = Math_fround($254 * $273);
    $290 = Math_fround($220 + $287);
    $291 = Math_fround($222 + $288);
    $292 = Math_fround($225 + $289);
    $293 = Math_fround($256 * $273);
    $294 = Math_fround($258 * $273);
    $295 = Math_fround($260 * $273);
    $296 = Math_fround($236 + $293);
    $297 = Math_fround($238 + $294);
    $298 = Math_fround($241 + $295);
    HEAPF32[$189>>2] = $272;
    HEAPF32[$207>>2] = $274;
    $exitcond1158 = ($$sum1040|0)==($40|0);
    if ($exitcond1158) {
     $$be = $280;$$be1094 = $279;$$be1095 = $278;$$be1096 = $286;$$be1097 = $285;$$be1098 = $284;$$be1099 = $292;$$be1100 = $291;$$be1101 = $290;$$be1102 = $298;$$be1103 = $297;$$be1104 = $296;
     break;
    } else {
     $212 = $278;$214 = $279;$217 = $280;$220 = $290;$222 = $291;$225 = $292;$228 = $284;$230 = $285;$233 = $286;$236 = $296;$238 = $297;$241 = $298;$i1$01079 = $$sum1040;
    }
   }
  }
  $170 = ($44>>>0)<($31>>>0);
  if ($170) {
   $299 = $$be1104;$300 = $$be1103;$301 = $$be1102;$302 = $$be1101;$303 = $$be1100;$304 = $$be1099;$305 = $$be1098;$306 = $$be1097;$307 = $$be1096;$308 = $$be1095;$309 = $$be1094;$310 = $$be;$currPtr$01117 = $44;
  } else {
   $$lcssa1105 = $$be;$$lcssa1106 = $$be1094;$$lcssa1107 = $$be1095;$$lcssa1108 = $$be1096;$$lcssa1109 = $$be1097;$$lcssa1110 = $$be1098;$$lcssa1111 = $$be1099;$$lcssa1112 = $$be1100;$$lcssa1113 = $$be1101;$$lcssa1114 = $$be1102;$$lcssa1115 = $$be1103;$$lcssa1116 = $$be1104;
   break;
  }
 }
 HEAPF32[$0>>2] = $$lcssa1107;
 HEAPF32[$4>>2] = $$lcssa1106;
 HEAPF32[$6>>2] = $$lcssa1105;
 HEAPF32[$2>>2] = $$lcssa1110;
 HEAPF32[$9>>2] = $$lcssa1109;
 HEAPF32[$11>>2] = $$lcssa1108;
 HEAPF32[$13>>2] = $$lcssa1113;
 HEAPF32[$15>>2] = $$lcssa1112;
 HEAPF32[$17>>2] = $$lcssa1111;
 HEAPF32[$19>>2] = $$lcssa1116;
 HEAPF32[$21>>2] = $$lcssa1115;
 HEAPF32[$23>>2] = $$lcssa1114;
 STACKTOP = sp;return;
}
function __ZN5physx20solveContact_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i = Math_fround(0), $$$i140 = Math_fround(0), $$$i149 = Math_fround(0), $$$i49 = Math_fround(0), $$be = Math_fround(0), $$be726 = Math_fround(0), $$be727 = Math_fround(0), $$be728 = Math_fround(0), $$be729 = Math_fround(0), $$be730 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa698 = Math_fround(0), $$lcssa699 = Math_fround(0), $$lcssa700 = Math_fround(0), $$lcssa701 = Math_fround(0), $$lcssa702 = Math_fround(0), $$lcssa703 = Math_fround(0), $$lcssa731 = Math_fround(0), $$lcssa732 = Math_fround(0), $$lcssa733 = Math_fround(0);
 var $$lcssa734 = Math_fround(0), $$lcssa735 = Math_fround(0), $$lcssa736 = Math_fround(0), $$sum = 0, $$sum1 = 0, $$sum696 = 0, $$sum697 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0;
 var $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0;
 var $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0;
 var $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0);
 var $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0;
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $currPtr$0737 = 0, $exitcond = 0, $exitcond760 = 0, $fabsf$i$i$i = Math_fround(0), $i$0704 = 0, $i1$0717 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$desc>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($0) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($0) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($0) + 20|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($0) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($desc) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($desc) + 26|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = $16 << 4;
 $18 = (($13) + ($17)|0);
 $19 = ($15<<16>>16)==(0);
 if ($19) {
  $$lcssa731 = $5;$$lcssa732 = $3;$$lcssa733 = $1;$$lcssa734 = $11;$$lcssa735 = $9;$$lcssa736 = $7;
  HEAPF32[$0>>2] = $$lcssa733;
  HEAPF32[$2>>2] = $$lcssa732;
  HEAPF32[$4>>2] = $$lcssa731;
  HEAPF32[$6>>2] = $$lcssa736;
  HEAPF32[$8>>2] = $$lcssa735;
  HEAPF32[$10>>2] = $$lcssa734;
  STACKTOP = sp;return;
 }
 $20 = (($cache) + 1|0);
 $194 = $7;$195 = $9;$196 = $11;$197 = $1;$198 = $3;$199 = $5;$currPtr$0737 = $13;
 while(1) {
  $21 = (($currPtr$0737) + 32|0);
  $22 = (($currPtr$0737) + 5|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = (($currPtr$0737) + 6|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = $26&255;
  $28 = ($24*96)|0;
  $$sum = (($28) + 32)|0;
  $29 = (($currPtr$0737) + ($$sum)|0);
  $30 = ($27*96)|0;
  $$sum1 = (($$sum) + ($30))|0;
  $31 = (($currPtr$0737) + ($$sum1)|0);
  $32 = (($currPtr$0737) + 108|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = ($23<<24>>24)==(0);
  if ($34) {
   $$lcssa = $199;$$lcssa698 = $198;$$lcssa699 = $197;$$lcssa700 = $196;$$lcssa701 = $195;$$lcssa702 = $194;$$lcssa703 = Math_fround(0.0);
  } else {
   $106 = Math_fround(0.0);$59 = $197;$61 = $198;$64 = $199;$67 = $194;$69 = $195;$72 = $196;$i$0704 = 0;
   while(1) {
    $$sum697 = (($i$0704) + 1)|0;
    $35 = ((($21) + (($$sum697*96)|0)|0) + 32|0);
    $36 = (($21) + (($i$0704*96)|0)|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = ((($21) + (($i$0704*96)|0)|0) + 4|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = ((($21) + (($i$0704*96)|0)|0) + 8|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = ((($21) + (($i$0704*96)|0)|0) + 12|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = ((($21) + (($i$0704*96)|0)|0) + 16|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = ((($21) + (($i$0704*96)|0)|0) + 20|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = ((($21) + (($i$0704*96)|0)|0) + 24|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = ((($21) + (($i$0704*96)|0)|0) + 28|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = ((($21) + (($i$0704*96)|0)|0) + 52|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = ((($21) + (($i$0704*96)|0)|0) + 48|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = ((($21) + (($i$0704*96)|0)|0) + 56|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = Math_fround($59 * $37);
    $60 = Math_fround($61 * $39);
    $62 = Math_fround($58 + $60);
    $63 = Math_fround($64 * $41);
    $65 = Math_fround($62 + $63);
    $66 = Math_fround($67 * $45);
    $68 = Math_fround($69 * $47);
    $70 = Math_fround($66 + $68);
    $71 = Math_fround($72 * $49);
    $73 = Math_fround($70 + $71);
    $74 = Math_fround($43 * $53);
    $75 = Math_fround($74 - $55);
    $76 = Math_fround($65 + $73);
    $77 = ((($21) + (($i$0704*96)|0)|0) + 64|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = ((($21) + (($i$0704*96)|0)|0) + 68|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = ((($21) + (($i$0704*96)|0)|0) + 72|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround($33 * $37);
    $84 = Math_fround($33 * $39);
    $85 = Math_fround($33 * $41);
    $86 = Math_fround($43 * $76);
    $87 = Math_fround($75 - $86);
    $88 = Math_fround(-$51);
    $89 = $87 > $88;
    $$$i149 = $89 ? $87 : $88;
    $90 = Math_fround($51 + $$$i149);
    $91 = $90 > $57;
    $$$i140 = $91 ? $57 : $90;
    $92 = Math_fround($$$i140 - $51);
    $93 = Math_fround($83 * $92);
    $94 = Math_fround($84 * $92);
    $95 = Math_fround($85 * $92);
    $96 = Math_fround($59 + $93);
    $97 = Math_fround($61 + $94);
    $98 = Math_fround($64 + $95);
    $99 = Math_fround($78 * $92);
    $100 = Math_fround($80 * $92);
    $101 = Math_fround($82 * $92);
    $102 = Math_fround($67 + $99);
    $103 = Math_fround($69 + $100);
    $104 = Math_fround($72 + $101);
    HEAPF32[$50>>2] = $$$i140;
    $105 = Math_fround($106 + $$$i140);
    $exitcond = ($$sum697|0)==($24|0);
    if ($exitcond) {
     $$lcssa = $98;$$lcssa698 = $97;$$lcssa699 = $96;$$lcssa700 = $104;$$lcssa701 = $103;$$lcssa702 = $102;$$lcssa703 = $105;
     break;
    } else {
     $106 = $105;$59 = $96;$61 = $97;$64 = $98;$67 = $102;$69 = $103;$72 = $104;$i$0704 = $$sum697;
    }
   }
  }
  $107 = HEAP8[$cache>>0]|0;
  $108 = ($107<<24>>24)==(0);
  $109 = ($26<<24>>24)==(0);
  $or$cond = $108 | $109;
  if ($or$cond) {
   $$be = $$lcssa;$$be726 = $$lcssa698;$$be727 = $$lcssa699;$$be728 = $$lcssa700;$$be729 = $$lcssa701;$$be730 = $$lcssa702;
  } else {
   $111 = (($currPtr$0737) + 16|0);
   $112 = Math_fround(HEAPF32[$111>>2]);
   $113 = Math_fround($$lcssa703 * $112);
   $114 = (($currPtr$0737) + 20|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = Math_fround($$lcssa703 * $115);
   $117 = Math_fround(-$116);
   $144 = $$lcssa699;$146 = $$lcssa698;$149 = $$lcssa;$152 = $$lcssa702;$154 = $$lcssa701;$157 = $$lcssa700;$i1$0717 = 0;
   while(1) {
    $$sum696 = (($i1$0717) + 1)|0;
    $118 = ((($29) + (($$sum696*96)|0)|0) + 32|0);
    $119 = HEAP8[$20>>0]|0;
    $120 = ($119<<24>>24)==(0);
    if (!($120)) {
     $121 = ((($29) + (($i1$0717*96)|0)|0) + 80|0);
     $122 = HEAP32[$121>>2]|0;
    }
    $123 = (($29) + (($i1$0717*96)|0)|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = ((($29) + (($i1$0717*96)|0)|0) + 4|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = ((($29) + (($i1$0717*96)|0)|0) + 8|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $129 = ((($29) + (($i1$0717*96)|0)|0) + 12|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $131 = ((($29) + (($i1$0717*96)|0)|0) + 16|0);
    $132 = Math_fround(HEAPF32[$131>>2]);
    $133 = ((($29) + (($i1$0717*96)|0)|0) + 20|0);
    $134 = Math_fround(HEAPF32[$133>>2]);
    $135 = ((($29) + (($i1$0717*96)|0)|0) + 24|0);
    $136 = Math_fround(HEAPF32[$135>>2]);
    $137 = ((($29) + (($i1$0717*96)|0)|0) + 28|0);
    $138 = Math_fround(HEAPF32[$137>>2]);
    $139 = ((($29) + (($i1$0717*96)|0)|0) + 44|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = ((($29) + (($i1$0717*96)|0)|0) + 76|0);
    $142 = Math_fround(HEAPF32[$141>>2]);
    $143 = Math_fround($144 * $124);
    $145 = Math_fround($146 * $126);
    $147 = Math_fround($143 + $145);
    $148 = Math_fround($149 * $128);
    $150 = Math_fround($147 + $148);
    $151 = Math_fround($152 * $132);
    $153 = Math_fround($154 * $134);
    $155 = Math_fround($151 + $153);
    $156 = Math_fround($157 * $136);
    $158 = Math_fround($155 + $156);
    $159 = Math_fround($150 + $158);
    $160 = Math_fround($140 - $142);
    $161 = Math_fround($138 * $160);
    $162 = Math_fround($130 - $161);
    $163 = ((($29) + (($i1$0717*96)|0)|0) + 48|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = ((($29) + (($i1$0717*96)|0)|0) + 52|0);
    $166 = Math_fround(HEAPF32[$165>>2]);
    $167 = ((($29) + (($i1$0717*96)|0)|0) + 56|0);
    $168 = Math_fround(HEAPF32[$167>>2]);
    $169 = ((($29) + (($i1$0717*96)|0)|0) + 60|0);
    $170 = Math_fround($33 * $124);
    $171 = Math_fround($33 * $126);
    $172 = Math_fround($33 * $128);
    $173 = Math_fround(HEAPF32[$169>>2]);
    $174 = Math_fround($138 * $159);
    $175 = Math_fround($162 - $174);
    $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($175)))));
    $176 = $175 < $117;
    $$$i49 = $176 ? $117 : $175;
    $177 = $116 > $$$i49;
    $$$i = $177 ? $$$i49 : $116;
    $178 = !($fabsf$i$i$i > $113);
    $179 = $178 ? $175 : $$$i;
    $180 = Math_fround($179 - $130);
    $181 = $178 ? $173 : Math_fround(1.0);
    $182 = Math_fround($170 * $180);
    $183 = Math_fround($171 * $180);
    $184 = Math_fround($172 * $180);
    $185 = Math_fround($144 + $182);
    $186 = Math_fround($146 + $183);
    $187 = Math_fround($149 + $184);
    $188 = Math_fround($164 * $180);
    $189 = Math_fround($166 * $180);
    $190 = Math_fround($168 * $180);
    $191 = Math_fround($152 + $188);
    $192 = Math_fround($154 + $189);
    $193 = Math_fround($157 + $190);
    HEAPF32[$129>>2] = $179;
    HEAPF32[$169>>2] = $181;
    $exitcond760 = ($$sum696|0)==($27|0);
    if ($exitcond760) {
     $$be = $187;$$be726 = $186;$$be727 = $185;$$be728 = $193;$$be729 = $192;$$be730 = $191;
     break;
    } else {
     $144 = $185;$146 = $186;$149 = $187;$152 = $191;$154 = $192;$157 = $193;$i1$0717 = $$sum696;
    }
   }
  }
  $110 = ($31>>>0)<($18>>>0);
  if ($110) {
   $194 = $$be730;$195 = $$be729;$196 = $$be728;$197 = $$be727;$198 = $$be726;$199 = $$be;$currPtr$0737 = $31;
  } else {
   $$lcssa731 = $$be;$$lcssa732 = $$be726;$$lcssa733 = $$be727;$$lcssa734 = $$be728;$$lcssa735 = $$be729;$$lcssa736 = $$be730;
   break;
  }
 }
 HEAPF32[$0>>2] = $$lcssa733;
 HEAPF32[$2>>2] = $$lcssa732;
 HEAPF32[$4>>2] = $$lcssa731;
 HEAPF32[$6>>2] = $$lcssa736;
 HEAPF32[$8>>2] = $$lcssa735;
 HEAPF32[$10>>2] = $$lcssa734;
 STACKTOP = sp;return;
}
function __ZN5physx15concludeContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i = Math_fround(0), $$pre = 0, $$sum = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $cPtr$029 = 0, $cPtr$1$lcssa = 0, $cPtr$123 = 0, $cPtr$2$lcssa = 0, $cPtr$225 = 0, $exitcond = 0, $exitcond35 = 0, $i$022 = 0, $i1$024 = 0, $scevgep33 = 0, $scevgep34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($desc) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($desc) + 26|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = $5 << 4;
 $7 = (($2) + ($6)|0);
 $8 = ($4<<16>>16)==(0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $cPtr$029 = $2;
 }
 while(1) {
  $11 = (($cPtr$029) + 32|0);
  $12 = (($cPtr$029) + 5|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = (($cPtr$029) + 6|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = (($cPtr$029) + 160|0);
  $17 = (($cPtr$029) + 288|0);
  $18 = (($cPtr$029) + 416|0);
  $19 = HEAP8[$cPtr$029>>0]|0;
  $20 = ($19<<24>>24)==(3);
  $21 = $20 ? 128 : 96;
  $22 = ($13<<24>>24)==(0);
  if ($22) {
   $32 = $19;$cPtr$1$lcssa = $11;
  } else {
   $23 = $13&255;
   $24 = Math_imul($21, $23)|0;
   $cPtr$123 = $11;$i$022 = 0;
   while(1) {
    $25 = (($cPtr$123) + ($21)|0);
    $26 = (($cPtr$123) + 48|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = $27 > Math_fround(0.0);
    $$$i = $28 ? $27 : Math_fround(0.0);
    $29 = (($cPtr$123) + 60|0);
    HEAPF32[$26>>2] = $$$i;
    HEAPF32[$29>>2] = Math_fround(0.0);
    $30 = (($i$022) + 1)|0;
    $exitcond = ($30|0)==($23|0);
    if ($exitcond) {
     break;
    } else {
     $cPtr$123 = $25;$i$022 = $30;
    }
   }
   $$sum = (($24) + 32)|0;
   $scevgep33 = (($cPtr$029) + ($$sum)|0);
   $$pre = HEAP8[$cPtr$029>>0]|0;
   $32 = $$pre;$cPtr$1$lcssa = $scevgep33;
  }
  $31 = ($32<<24>>24)==(3);
  $33 = $31 ? 128 : 96;
  $34 = ($15<<24>>24)==(0);
  if ($34) {
   $cPtr$2$lcssa = $cPtr$1$lcssa;
  } else {
   $35 = $15&255;
   $9 = Math_imul($33, $35)|0;
   $cPtr$225 = $cPtr$1$lcssa;$i1$024 = 0;
   while(1) {
    $36 = (($cPtr$225) + ($33)|0);
    $37 = (($cPtr$225) + 44|0);
    HEAPF32[$37>>2] = Math_fround(0.0);
    $38 = (($i1$024) + 1)|0;
    $exitcond35 = ($38|0)==($35|0);
    if ($exitcond35) {
     break;
    } else {
     $cPtr$225 = $36;$i1$024 = $38;
    }
   }
   $scevgep34 = (($cPtr$1$lcssa) + ($9)|0);
   $cPtr$2$lcssa = $scevgep34;
  }
  $10 = ($cPtr$2$lcssa>>>0)<($7>>>0);
  if ($10) {
   $cPtr$029 = $cPtr$2$lcssa;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16writeBackContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($desc,$cache,$bd0,$bd1) {
 $desc = $desc|0;
 $cache = $cache|0;
 $bd0 = $bd0|0;
 $bd1 = $bd1|0;
 var $$ = 0, $$1 = 0, $$phi$trans$insert = 0, $$pre$pre = 0, $$pre26 = Math_fround(0), $$sum = 0, $$sum27 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $cPtr$014 = 0, $cPtr$14 = 0, $cPtr$2 = 0, $cPtr$3$lcssa = 0, $cPtr$39 = 0, $exitcond = 0, $exitcond24 = 0, $i$02 = 0, $i1$010 = 0, $normalForce$015 = Math_fround(0), $normalForce$15 = Math_fround(0), $normalForce$2 = Math_fround(0), $or$cond = 0, $or$cond28 = 0, $scevgep = 0;
 var $scevgep22 = 0, $scevgep23 = 0, $vForceWriteback$013 = 0, $vForceWriteback$13 = 0, $vForceWriteback$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($desc) + 26|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 << 4;
 $6 = (($1) + ($5)|0);
 $7 = ($3<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($desc) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $cPtr$014 = $1;$normalForce$015 = Math_fround(0.0);$vForceWriteback$013 = $9;
 while(1) {
  $12 = (($cPtr$014) + 32|0);
  $13 = (($cPtr$014) + 4|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  $17 = (($cPtr$014) + 5|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = (($cPtr$014) + 6|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = (($cPtr$014) + 288|0);
  $23 = (($cPtr$014) + 416|0);
  $24 = HEAP8[$cPtr$014>>0]|0;
  $25 = ($24<<24>>24)==(3);
  $26 = $25 ? 128 : 96;
  $27 = ($vForceWriteback$013|0)==(0|0);
  if ($27) {
   $36 = Math_imul($26, $19)|0;
   $$sum = (($36) + 32)|0;
   $37 = (($cPtr$014) + ($$sum)|0);
   $39 = $24;$cPtr$2 = $37;$normalForce$2 = $normalForce$015;$vForceWriteback$2 = 0;
  } else {
   $28 = ($18<<24>>24)==(0);
   if ($28) {
    $39 = $24;$cPtr$2 = $12;$normalForce$2 = $normalForce$015;$vForceWriteback$2 = $vForceWriteback$013;
   } else {
    $scevgep = (($vForceWriteback$013) + ($19<<2)|0);
    $29 = Math_imul($26, $19)|0;
    $cPtr$14 = $12;$i$02 = 0;$normalForce$15 = $normalForce$015;$vForceWriteback$13 = $vForceWriteback$013;
    while(1) {
     $30 = (($cPtr$14) + ($26)|0);
     $31 = (($cPtr$14) + 28|0);
     $32 = Math_fround(HEAPF32[$31>>2]);
     $33 = (($vForceWriteback$13) + 4|0);
     HEAPF32[$vForceWriteback$13>>2] = $32;
     $34 = Math_fround($normalForce$15 + $32);
     $35 = (($i$02) + 1)|0;
     $exitcond = ($35|0)==($19|0);
     if ($exitcond) {
      break;
     } else {
      $cPtr$14 = $30;$i$02 = $35;$normalForce$15 = $34;$vForceWriteback$13 = $33;
     }
    }
    $$sum27 = (($29) + 32)|0;
    $scevgep22 = (($cPtr$014) + ($$sum27)|0);
    $$pre$pre = HEAP8[$cPtr$014>>0]|0;
    $39 = $$pre$pre;$cPtr$2 = $scevgep22;$normalForce$2 = $34;$vForceWriteback$2 = $scevgep;
   }
  }
  $38 = ($39<<24>>24)==(3);
  $40 = $38 ? 128 : 96;
  $41 = ($21<<24>>24)==(0);
  if ($41) {
   $cPtr$3$lcssa = $cPtr$2;
  } else {
   $42 = $21&255;
   $10 = Math_imul($40, $42)|0;
   $cPtr$39 = $cPtr$2;$i1$010 = 0;
   while(1) {
    $43 = (($cPtr$39) + ($40)|0);
    $44 = (($cPtr$39) + 80|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==(0|0);
    if (!($46)) {
     $47 = (($cPtr$39) + 60|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(0);
     if (!($49)) {
      HEAP8[$45>>0] = 1;
     }
    }
    $50 = (($i1$010) + 1)|0;
    $exitcond24 = ($50|0)==($42|0);
    if ($exitcond24) {
     break;
    } else {
     $cPtr$39 = $43;$i1$010 = $50;
    }
   }
   $scevgep23 = (($cPtr$2) + ($10)|0);
   $cPtr$3$lcssa = $scevgep23;
  }
  $11 = ($cPtr$3$lcssa>>>0)<($6>>>0);
  if ($11) {
   $cPtr$014 = $cPtr$3$lcssa;$normalForce$015 = $normalForce$2;$vForceWriteback$013 = $vForceWriteback$2;
  } else {
   break;
  }
 }
 if ($16) {
  STACKTOP = sp;return;
 }
 $51 = (($desc) + 8|0);
 $52 = HEAP16[$51>>1]|0;
 $53 = ($52<<16>>16)==(-1);
 if (!($53)) {
  STACKTOP = sp;return;
 }
 $54 = (($desc) + 12|0);
 $55 = HEAP16[$54>>1]|0;
 $56 = ($55<<16>>16)==(-1);
 $57 = $normalForce$2 != Math_fround(0.0);
 $or$cond = $56 & $57;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $58 = (($bd0) + 36|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = $59 < Math_fround(3.40282346638528859812E+38);
 $$phi$trans$insert = (($bd1) + 36|0);
 $$pre26 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
 $61 = $$pre26 < Math_fround(3.40282346638528859812E+38);
 $or$cond28 = $60 | $61;
 if (!($or$cond28)) {
  STACKTOP = sp;return;
 }
 $62 = $59 < $$pre26;
 $63 = $62 ? $59 : $$pre26;
 $64 = (($bd0) + 40|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($bd1) + 40|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67>>>0)<($65>>>0);
 $$ = $68 ? $65 : $67;
 $$1 = $68 ? $67 : $65;
 $69 = (($cache) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + 1)|0;
 HEAP32[$69>>2] = $71;
 $72 = (($cache) + 4|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73) + ($70<<4)|0);
 HEAP32[$74>>2] = $$1;
 $75 = ((($73) + ($70<<4)|0) + 4|0);
 HEAP32[$75>>2] = $$;
 $76 = ((($73) + ($70<<4)|0) + 8|0);
 HEAPF32[$76>>2] = $normalForce$2;
 $77 = ((($73) + ($70<<4)|0) + 12|0);
 HEAPF32[$77>>2] = $63;
 STACKTOP = sp;return;
}
function __ZN5physx11writeBack1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($desc,$0,$1,$2) {
 $desc = $desc|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$lcssa = Math_fround(0), $$lcssa10 = Math_fround(0), $$lcssa11 = Math_fround(0), $$lcssa7 = Math_fround(0), $$lcssa8 = Math_fround(0), $$lcssa9 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0;
 var $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $base$013 = 0, $i$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = (($desc) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($desc) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(4);
 $10 = $9 ? 176 : 112;
 $11 = (($7) + 1|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $$lcssa = Math_fround(0.0);$$lcssa10 = Math_fround(0.0);$$lcssa11 = Math_fround(0.0);$$lcssa7 = Math_fround(0.0);$$lcssa8 = Math_fround(0.0);$$lcssa9 = Math_fround(0.0);
 } else {
  $14 = (($7) + 48|0);
  $15 = $12&255;
  $31 = Math_fround(0.0);$33 = Math_fround(0.0);$35 = Math_fround(0.0);$46 = Math_fround(0.0);$48 = Math_fround(0.0);$50 = Math_fround(0.0);$base$013 = $14;$i$012 = 0;
  while(1) {
   $16 = (($base$013) + 108|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $17 & 2;
   $19 = ($18|0)==(0);
   if ($19) {
    $100 = $31;$101 = $50;$102 = $48;$103 = $46;$98 = $35;$99 = $33;
   } else {
    $20 = (($base$013) + 104|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = Math_fround(HEAPF32[$base$013>>2]);
    $23 = Math_fround($21 * $22);
    $24 = (($base$013) + 4|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = Math_fround($21 * $25);
    $27 = (($base$013) + 8|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = Math_fround($21 * $28);
    $30 = Math_fround($31 + $23);
    $32 = Math_fround($33 + $26);
    $34 = Math_fround($35 + $29);
    $36 = (($base$013) + 32|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = Math_fround($21 * $37);
    $39 = (($base$013) + 36|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = Math_fround($21 * $40);
    $42 = (($base$013) + 40|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = Math_fround($21 * $43);
    $45 = Math_fround($46 + $38);
    $47 = Math_fround($48 + $41);
    $49 = Math_fround($50 + $44);
    $100 = $30;$101 = $49;$102 = $47;$103 = $45;$98 = $34;$99 = $32;
   }
   $51 = (($base$013) + ($10)|0);
   $52 = (($i$012) + 1)|0;
   $53 = ($52>>>0)<($15>>>0);
   if ($53) {
    $31 = $100;$33 = $99;$35 = $98;$46 = $103;$48 = $102;$50 = $101;$base$013 = $51;$i$012 = $52;
   } else {
    $$lcssa = $98;$$lcssa10 = $102;$$lcssa11 = $103;$$lcssa7 = $99;$$lcssa8 = $100;$$lcssa9 = $101;
    break;
   }
  }
 }
 $54 = (($7) + 16|0);
 $55 = (($7) + 20|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($$lcssa * $56);
 $58 = (($7) + 24|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($$lcssa7 * $59);
 $61 = Math_fround($57 - $60);
 $62 = Math_fround($$lcssa8 * $59);
 $63 = Math_fround(HEAPF32[$54>>2]);
 $64 = Math_fround($$lcssa * $63);
 $65 = Math_fround($62 - $64);
 $66 = Math_fround($$lcssa7 * $63);
 $67 = Math_fround($$lcssa8 * $56);
 $68 = Math_fround($66 - $67);
 $69 = Math_fround($$lcssa11 - $61);
 $70 = Math_fround($$lcssa10 - $65);
 $71 = Math_fround($$lcssa9 - $68);
 HEAPF32[$4>>2] = $$lcssa8;
 $72 = (($4) + 4|0);
 HEAPF32[$72>>2] = $$lcssa7;
 $73 = (($4) + 8|0);
 HEAPF32[$73>>2] = $$lcssa;
 $74 = (($4) + 16|0);
 HEAPF32[$74>>2] = $69;
 $75 = (($4) + 20|0);
 HEAPF32[$75>>2] = $70;
 $76 = (($4) + 24|0);
 HEAPF32[$76>>2] = $71;
 $77 = Math_fround($$lcssa8 * $$lcssa8);
 $78 = Math_fround($$lcssa7 * $$lcssa7);
 $79 = Math_fround($78 + $77);
 $80 = Math_fround($$lcssa * $$lcssa);
 $81 = Math_fround($80 + $79);
 $82 = (Math_fround(Math_sqrt((Math_fround($81)))));
 $83 = (($7) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = $82 > $84;
 if ($85) {
  $96 = 1;
 } else {
  $86 = Math_fround($69 * $69);
  $87 = Math_fround($70 * $70);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround($71 * $71);
  $90 = Math_fround($89 + $88);
  $91 = (Math_fround(Math_sqrt((Math_fround($90)))));
  $92 = (($7) + 8|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = $91 > $93;
  $96 = $94;
 }
 $95 = $96&1;
 $97 = (($4) + 12|0);
 HEAP32[$97>>2] = $95;
 STACKTOP = sp;return;
}
function __ZN5physx12solve1DBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx7solve1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx20solve1DConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $a$01 = 0, $base$02$i = 0, $exitcond = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx7solve1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = ((($desc) + ($a$01<<5)|0) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(4);
  $6 = $5 ? 176 : 112;
  $7 = (($3) + 1|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if (!($9)) {
   $10 = (($3) + 48|0);
   $base$02$i = $10;$i$01$i = 0;
   while(1) {
    $11 = (($base$02$i) + 28|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    $13 = (($base$02$i) + 12|0);
    HEAPF32[$13>>2] = $12;
    $14 = (($base$02$i) + ($6)|0);
    $15 = (($i$01$i) + 1)|0;
    $16 = HEAP8[$7>>0]|0;
    $17 = $16&255;
    $18 = ($15>>>0)<($17>>>0);
    if ($18) {
     $base$02$i = $14;$i$01$i = $15;
    } else {
     break;
    }
   }
  }
  $19 = (($a$01) + 1)|0;
  $exitcond = ($19|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $19;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21solve1DBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$0,$1,$2) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($constraintCount|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $4 = (($desc) + ($a$01<<5)|0);
  __ZN5physx7solve1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($4,$cache);
  __ZN5physx11writeBack1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($4,0,0,0);
  $5 = (($a$01) + 1)|0;
  $exitcond = ($5|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx17solveContactBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx12solveContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx25solveContactConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$pre$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $cPtr$029$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$123$i = 0, $cPtr$2$lcssa$i = 0, $cPtr$225$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond35$i = 0, $i$022$i = 0, $i1$024$i = 0, $scevgep33$i = 0, $scevgep34$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx12solveContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = ((($desc) + ($a$01<<5)|0) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($desc) + ($a$01<<5)|0) + 26|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = $5&65535;
  $7 = $6 << 4;
  $8 = (($3) + ($7)|0);
  $9 = ($5<<16>>16)==(0);
  if (!($9)) {
   $cPtr$029$i = $3;
   while(1) {
    $14 = (($cPtr$029$i) + 32|0);
    $15 = (($cPtr$029$i) + 5|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = (($cPtr$029$i) + 6|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = (($cPtr$029$i) + 160|0);
    $20 = (($cPtr$029$i) + 288|0);
    $21 = (($cPtr$029$i) + 416|0);
    $22 = HEAP8[$cPtr$029$i>>0]|0;
    $23 = ($22<<24>>24)==(3);
    $24 = $23 ? 128 : 96;
    $25 = ($16<<24>>24)==(0);
    if ($25) {
     $35 = $22;$cPtr$1$lcssa$i = $14;
    } else {
     $26 = $16&255;
     $cPtr$123$i = $14;$i$022$i = 0;
     while(1) {
      $27 = (($cPtr$123$i) + ($24)|0);
      $28 = (($cPtr$123$i) + 48|0);
      $29 = Math_fround(HEAPF32[$28>>2]);
      $30 = $29 > Math_fround(0.0);
      $$$i$i = $30 ? $29 : Math_fround(0.0);
      $31 = (($cPtr$123$i) + 60|0);
      HEAPF32[$28>>2] = $$$i$i;
      HEAPF32[$31>>2] = Math_fround(0.0);
      $32 = (($i$022$i) + 1)|0;
      $exitcond$i = ($32|0)==($26|0);
      if ($exitcond$i) {
       break;
      } else {
       $cPtr$123$i = $27;$i$022$i = $32;
      }
     }
     $33 = Math_imul($24, $26)|0;
     $$sum$i = (($33) + 32)|0;
     $scevgep33$i = (($cPtr$029$i) + ($$sum$i)|0);
     $$pre$i = HEAP8[$cPtr$029$i>>0]|0;
     $35 = $$pre$i;$cPtr$1$lcssa$i = $scevgep33$i;
    }
    $34 = ($35<<24>>24)==(3);
    $11 = $34 ? 128 : 96;
    $36 = ($18<<24>>24)==(0);
    if ($36) {
     $cPtr$2$lcssa$i = $cPtr$1$lcssa$i;
    } else {
     $12 = $18&255;
     $cPtr$225$i = $cPtr$1$lcssa$i;$i1$024$i = 0;
     while(1) {
      $37 = (($cPtr$225$i) + ($11)|0);
      $38 = (($cPtr$225$i) + 44|0);
      HEAPF32[$38>>2] = Math_fround(0.0);
      $39 = (($i1$024$i) + 1)|0;
      $exitcond35$i = ($39|0)==($12|0);
      if ($exitcond35$i) {
       break;
      } else {
       $cPtr$225$i = $37;$i1$024$i = $39;
      }
     }
     $10 = Math_imul($11, $12)|0;
     $scevgep34$i = (($cPtr$1$lcssa$i) + ($10)|0);
     $cPtr$2$lcssa$i = $scevgep34$i;
    }
    $13 = ($cPtr$2$lcssa$i>>>0)<($8>>>0);
    if ($13) {
     $cPtr$029$i = $cPtr$2$lcssa$i;
    } else {
     break;
    }
   }
  }
  $40 = (($a$01) + 1)|0;
  $exitcond = ($40|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $40;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx26solveContactBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$thresholdStream,$0,$outThresholdPairs) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $0 = $0|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$02 = 0, $a1$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($constraintCount|0)==(0);
 if (!($1)) {
  $2 = (($cache) + 16|0);
  $a$02 = 0;
  while(1) {
   $3 = (($desc) + ($a$02<<5)|0);
   $4 = ((($desc) + ($a$02<<5)|0) + 10|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = $5&65535;
   $7 = HEAP32[$2>>2]|0;
   $8 = (($7) + ($6<<6)|0);
   $9 = ((($desc) + ($a$02<<5)|0) + 14|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = $10&65535;
   $12 = (($7) + ($11<<6)|0);
   __ZN5physx12solveContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($3,$cache);
   __ZN5physx16writeBackContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($3,$cache,$8,$12);
   $13 = (($a$02) + 1)|0;
   $exitcond = ($13|0)==($constraintCount|0);
   if ($exitcond) {
    break;
   } else {
    $a$02 = $13;
   }
  }
 }
 $14 = (($cache) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($cache) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + -4)|0;
 $19 = ($15>>>0)>($18>>>0);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$15)|0);
 $21 = HEAP32[$14>>2]|0;
 $22 = (($20) - ($21))|0;
 $23 = ($21|0)==(0);
 if (!($23)) {
  $24 = (($cache) + 4|0);
  $a1$01 = 0;
  while(1) {
   $25 = (($22) + ($a1$01))|0;
   $26 = (($thresholdStream) + ($25<<4)|0);
   $27 = HEAP32[$24>>2]|0;
   $28 = (($27) + ($a1$01<<4)|0);
   ;HEAP32[$26+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$28+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$28+12>>2]|0;
   $29 = (($a1$01) + 1)|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    $a1$01 = $29;
   } else {
    break;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx25solveContact_BStaticBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx20solveContact_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx33solveContact_BStaticConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$pre$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $cPtr$029$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$123$i = 0, $cPtr$2$lcssa$i = 0, $cPtr$225$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond35$i = 0, $i$022$i = 0, $i1$024$i = 0, $scevgep33$i = 0, $scevgep34$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx20solveContact_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = ((($desc) + ($a$01<<5)|0) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($desc) + ($a$01<<5)|0) + 26|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = $5&65535;
  $7 = $6 << 4;
  $8 = (($3) + ($7)|0);
  $9 = ($5<<16>>16)==(0);
  if (!($9)) {
   $cPtr$029$i = $3;
   while(1) {
    $14 = (($cPtr$029$i) + 32|0);
    $15 = (($cPtr$029$i) + 5|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = (($cPtr$029$i) + 6|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = (($cPtr$029$i) + 160|0);
    $20 = (($cPtr$029$i) + 288|0);
    $21 = (($cPtr$029$i) + 416|0);
    $22 = HEAP8[$cPtr$029$i>>0]|0;
    $23 = ($22<<24>>24)==(3);
    $24 = $23 ? 128 : 96;
    $25 = ($16<<24>>24)==(0);
    if ($25) {
     $35 = $22;$cPtr$1$lcssa$i = $14;
    } else {
     $26 = $16&255;
     $cPtr$123$i = $14;$i$022$i = 0;
     while(1) {
      $27 = (($cPtr$123$i) + ($24)|0);
      $28 = (($cPtr$123$i) + 48|0);
      $29 = Math_fround(HEAPF32[$28>>2]);
      $30 = $29 > Math_fround(0.0);
      $$$i$i = $30 ? $29 : Math_fround(0.0);
      $31 = (($cPtr$123$i) + 60|0);
      HEAPF32[$28>>2] = $$$i$i;
      HEAPF32[$31>>2] = Math_fround(0.0);
      $32 = (($i$022$i) + 1)|0;
      $exitcond$i = ($32|0)==($26|0);
      if ($exitcond$i) {
       break;
      } else {
       $cPtr$123$i = $27;$i$022$i = $32;
      }
     }
     $33 = Math_imul($24, $26)|0;
     $$sum$i = (($33) + 32)|0;
     $scevgep33$i = (($cPtr$029$i) + ($$sum$i)|0);
     $$pre$i = HEAP8[$cPtr$029$i>>0]|0;
     $35 = $$pre$i;$cPtr$1$lcssa$i = $scevgep33$i;
    }
    $34 = ($35<<24>>24)==(3);
    $11 = $34 ? 128 : 96;
    $36 = ($18<<24>>24)==(0);
    if ($36) {
     $cPtr$2$lcssa$i = $cPtr$1$lcssa$i;
    } else {
     $12 = $18&255;
     $cPtr$225$i = $cPtr$1$lcssa$i;$i1$024$i = 0;
     while(1) {
      $37 = (($cPtr$225$i) + ($11)|0);
      $38 = (($cPtr$225$i) + 44|0);
      HEAPF32[$38>>2] = Math_fround(0.0);
      $39 = (($i1$024$i) + 1)|0;
      $exitcond35$i = ($39|0)==($12|0);
      if ($exitcond35$i) {
       break;
      } else {
       $cPtr$225$i = $37;$i1$024$i = $39;
      }
     }
     $10 = Math_imul($11, $12)|0;
     $scevgep34$i = (($cPtr$1$lcssa$i) + ($10)|0);
     $cPtr$2$lcssa$i = $scevgep34$i;
    }
    $13 = ($cPtr$2$lcssa$i>>>0)<($8>>>0);
    if ($13) {
     $cPtr$029$i = $cPtr$2$lcssa$i;
    } else {
     break;
    }
   }
  }
  $40 = (($a$01) + 1)|0;
  $exitcond = ($40|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $40;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx34solveContact_BStaticBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$thresholdStream,$0,$outThresholdPairs) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $0 = $0|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$02 = 0, $a1$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($constraintCount|0)==(0);
 if (!($1)) {
  $2 = (($cache) + 16|0);
  $a$02 = 0;
  while(1) {
   $3 = (($desc) + ($a$02<<5)|0);
   $4 = ((($desc) + ($a$02<<5)|0) + 10|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = $5&65535;
   $7 = HEAP32[$2>>2]|0;
   $8 = (($7) + ($6<<6)|0);
   $9 = ((($desc) + ($a$02<<5)|0) + 14|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = $10&65535;
   $12 = (($7) + ($11<<6)|0);
   __ZN5physx20solveContact_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($3,$cache);
   __ZN5physx16writeBackContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($3,$cache,$8,$12);
   $13 = (($a$02) + 1)|0;
   $exitcond = ($13|0)==($constraintCount|0);
   if ($exitcond) {
    break;
   } else {
    $a$02 = $13;
   }
  }
 }
 $14 = (($cache) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($cache) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + -4)|0;
 $19 = ($15>>>0)>($18>>>0);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$15)|0);
 $21 = HEAP32[$14>>2]|0;
 $22 = (($20) - ($21))|0;
 $23 = ($21|0)==(0);
 if (!($23)) {
  $24 = (($cache) + 4|0);
  $a1$01 = 0;
  while(1) {
   $25 = (($22) + ($a1$01))|0;
   $26 = (($thresholdStream) + ($25<<4)|0);
   $27 = HEAP32[$24>>2]|0;
   $28 = (($27) + ($a1$01<<4)|0);
   ;HEAP32[$26+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$28+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$28+12>>2]|0;
   $29 = (($a1$01) + 1)|0;
   $30 = HEAP32[$14>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    $a1$01 = $29;
   } else {
    break;
   }
  }
 }
 HEAP32[$14>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx15solveConclude1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $base$02$i = 0, $i$01$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN5physx7solve1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(4);
 $4 = $3 ? 176 : 112;
 $5 = (($1) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($1) + 48|0);
 $base$02$i = $8;$i$01$i = 0;
 while(1) {
  $9 = (($base$02$i) + 28|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($base$02$i) + 12|0);
  HEAPF32[$11>>2] = $10;
  $12 = (($base$02$i) + ($4)|0);
  $13 = (($i$01$i) + 1)|0;
  $14 = HEAP8[$5>>0]|0;
  $15 = $14&255;
  $16 = ($13>>>0)<($15>>>0);
  if ($16) {
   $base$02$i = $12;$i$01$i = $13;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx20solveConcludeContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$pre$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $cPtr$029$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$123$i = 0, $cPtr$2$lcssa$i = 0, $cPtr$225$i = 0, $exitcond$i = 0, $exitcond35$i = 0, $i$022$i = 0, $i1$024$i = 0, $scevgep33$i = 0, $scevgep34$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx12solveContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($desc) + 26|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 << 4;
 $6 = (($1) + ($5)|0);
 $7 = ($3<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $cPtr$029$i = $1;
 }
 while(1) {
  $12 = (($cPtr$029$i) + 32|0);
  $13 = (($cPtr$029$i) + 5|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = (($cPtr$029$i) + 6|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = (($cPtr$029$i) + 160|0);
  $18 = (($cPtr$029$i) + 288|0);
  $19 = (($cPtr$029$i) + 416|0);
  $20 = HEAP8[$cPtr$029$i>>0]|0;
  $21 = ($20<<24>>24)==(3);
  $22 = $21 ? 128 : 96;
  $23 = ($14<<24>>24)==(0);
  if ($23) {
   $33 = $20;$cPtr$1$lcssa$i = $12;
  } else {
   $24 = $14&255;
   $cPtr$123$i = $12;$i$022$i = 0;
   while(1) {
    $25 = (($cPtr$123$i) + ($22)|0);
    $26 = (($cPtr$123$i) + 48|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = $27 > Math_fround(0.0);
    $$$i$i = $28 ? $27 : Math_fround(0.0);
    $29 = (($cPtr$123$i) + 60|0);
    HEAPF32[$26>>2] = $$$i$i;
    HEAPF32[$29>>2] = Math_fround(0.0);
    $30 = (($i$022$i) + 1)|0;
    $exitcond$i = ($30|0)==($24|0);
    if ($exitcond$i) {
     break;
    } else {
     $cPtr$123$i = $25;$i$022$i = $30;
    }
   }
   $31 = Math_imul($22, $24)|0;
   $$sum$i = (($31) + 32)|0;
   $scevgep33$i = (($cPtr$029$i) + ($$sum$i)|0);
   $$pre$i = HEAP8[$cPtr$029$i>>0]|0;
   $33 = $$pre$i;$cPtr$1$lcssa$i = $scevgep33$i;
  }
  $32 = ($33<<24>>24)==(3);
  $9 = $32 ? 128 : 96;
  $34 = ($16<<24>>24)==(0);
  if ($34) {
   $cPtr$2$lcssa$i = $cPtr$1$lcssa$i;
  } else {
   $10 = $16&255;
   $cPtr$225$i = $cPtr$1$lcssa$i;$i1$024$i = 0;
   while(1) {
    $35 = (($cPtr$225$i) + ($9)|0);
    $36 = (($cPtr$225$i) + 44|0);
    HEAPF32[$36>>2] = Math_fround(0.0);
    $37 = (($i1$024$i) + 1)|0;
    $exitcond35$i = ($37|0)==($10|0);
    if ($exitcond35$i) {
     break;
    } else {
     $cPtr$225$i = $35;$i1$024$i = $37;
    }
   }
   $8 = Math_imul($9, $10)|0;
   $scevgep34$i = (($cPtr$1$lcssa$i) + ($8)|0);
   $cPtr$2$lcssa$i = $scevgep34$i;
  }
  $11 = ($cPtr$2$lcssa$i>>>0)<($6>>>0);
  if ($11) {
   $cPtr$029$i = $cPtr$2$lcssa$i;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23solveConcludeExtContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$pre$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $cPtr$029$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$123$i = 0, $cPtr$2$lcssa$i = 0, $cPtr$225$i = 0, $exitcond$i = 0, $exitcond35$i = 0, $i$022$i = 0, $i1$024$i = 0, $scevgep33$i = 0, $scevgep34$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15solveExtContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($desc) + 26|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 << 4;
 $6 = (($1) + ($5)|0);
 $7 = ($3<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $cPtr$029$i = $1;
 }
 while(1) {
  $12 = (($cPtr$029$i) + 32|0);
  $13 = (($cPtr$029$i) + 5|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = (($cPtr$029$i) + 6|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = (($cPtr$029$i) + 160|0);
  $18 = (($cPtr$029$i) + 288|0);
  $19 = (($cPtr$029$i) + 416|0);
  $20 = HEAP8[$cPtr$029$i>>0]|0;
  $21 = ($20<<24>>24)==(3);
  $22 = $21 ? 128 : 96;
  $23 = ($14<<24>>24)==(0);
  if ($23) {
   $33 = $20;$cPtr$1$lcssa$i = $12;
  } else {
   $24 = $14&255;
   $cPtr$123$i = $12;$i$022$i = 0;
   while(1) {
    $25 = (($cPtr$123$i) + ($22)|0);
    $26 = (($cPtr$123$i) + 48|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = $27 > Math_fround(0.0);
    $$$i$i = $28 ? $27 : Math_fround(0.0);
    $29 = (($cPtr$123$i) + 60|0);
    HEAPF32[$26>>2] = $$$i$i;
    HEAPF32[$29>>2] = Math_fround(0.0);
    $30 = (($i$022$i) + 1)|0;
    $exitcond$i = ($30|0)==($24|0);
    if ($exitcond$i) {
     break;
    } else {
     $cPtr$123$i = $25;$i$022$i = $30;
    }
   }
   $31 = Math_imul($22, $24)|0;
   $$sum$i = (($31) + 32)|0;
   $scevgep33$i = (($cPtr$029$i) + ($$sum$i)|0);
   $$pre$i = HEAP8[$cPtr$029$i>>0]|0;
   $33 = $$pre$i;$cPtr$1$lcssa$i = $scevgep33$i;
  }
  $32 = ($33<<24>>24)==(3);
  $9 = $32 ? 128 : 96;
  $34 = ($16<<24>>24)==(0);
  if ($34) {
   $cPtr$2$lcssa$i = $cPtr$1$lcssa$i;
  } else {
   $10 = $16&255;
   $cPtr$225$i = $cPtr$1$lcssa$i;$i1$024$i = 0;
   while(1) {
    $35 = (($cPtr$225$i) + ($9)|0);
    $36 = (($cPtr$225$i) + 44|0);
    HEAPF32[$36>>2] = Math_fround(0.0);
    $37 = (($i1$024$i) + 1)|0;
    $exitcond35$i = ($37|0)==($10|0);
    if ($exitcond35$i) {
     break;
    } else {
     $cPtr$225$i = $35;$i1$024$i = $37;
    }
   }
   $8 = Math_imul($9, $10)|0;
   $scevgep34$i = (($cPtr$1$lcssa$i) + ($8)|0);
   $cPtr$2$lcssa$i = $scevgep34$i;
  }
  $11 = ($cPtr$2$lcssa$i>>>0)<($6>>>0);
  if ($11) {
   $cPtr$029$i = $cPtr$2$lcssa$i;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx18solveConcludeExt1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $base$02$i = 0, $i$01$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN5physx10solveExt1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(4);
 $4 = $3 ? 176 : 112;
 $5 = (($1) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($1) + 48|0);
 $base$02$i = $8;$i$01$i = 0;
 while(1) {
  $9 = (($base$02$i) + 28|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($base$02$i) + 12|0);
  HEAPF32[$11>>2] = $10;
  $12 = (($base$02$i) + ($4)|0);
  $13 = (($i$01$i) + 1)|0;
  $14 = HEAP8[$5>>0]|0;
  $15 = $14&255;
  $16 = ($13>>>0)<($15>>>0);
  if ($16) {
   $base$02$i = $12;$i$01$i = $13;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx28solveConcludeContact_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$pre$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $cPtr$029$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$123$i = 0, $cPtr$2$lcssa$i = 0, $cPtr$225$i = 0, $exitcond$i = 0, $exitcond35$i = 0, $i$022$i = 0, $i1$024$i = 0, $scevgep33$i = 0, $scevgep34$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx20solveContact_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($desc) + 26|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 << 4;
 $6 = (($1) + ($5)|0);
 $7 = ($3<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $cPtr$029$i = $1;
 }
 while(1) {
  $12 = (($cPtr$029$i) + 32|0);
  $13 = (($cPtr$029$i) + 5|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = (($cPtr$029$i) + 6|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = (($cPtr$029$i) + 160|0);
  $18 = (($cPtr$029$i) + 288|0);
  $19 = (($cPtr$029$i) + 416|0);
  $20 = HEAP8[$cPtr$029$i>>0]|0;
  $21 = ($20<<24>>24)==(3);
  $22 = $21 ? 128 : 96;
  $23 = ($14<<24>>24)==(0);
  if ($23) {
   $33 = $20;$cPtr$1$lcssa$i = $12;
  } else {
   $24 = $14&255;
   $cPtr$123$i = $12;$i$022$i = 0;
   while(1) {
    $25 = (($cPtr$123$i) + ($22)|0);
    $26 = (($cPtr$123$i) + 48|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = $27 > Math_fround(0.0);
    $$$i$i = $28 ? $27 : Math_fround(0.0);
    $29 = (($cPtr$123$i) + 60|0);
    HEAPF32[$26>>2] = $$$i$i;
    HEAPF32[$29>>2] = Math_fround(0.0);
    $30 = (($i$022$i) + 1)|0;
    $exitcond$i = ($30|0)==($24|0);
    if ($exitcond$i) {
     break;
    } else {
     $cPtr$123$i = $25;$i$022$i = $30;
    }
   }
   $31 = Math_imul($22, $24)|0;
   $$sum$i = (($31) + 32)|0;
   $scevgep33$i = (($cPtr$029$i) + ($$sum$i)|0);
   $$pre$i = HEAP8[$cPtr$029$i>>0]|0;
   $33 = $$pre$i;$cPtr$1$lcssa$i = $scevgep33$i;
  }
  $32 = ($33<<24>>24)==(3);
  $9 = $32 ? 128 : 96;
  $34 = ($16<<24>>24)==(0);
  if ($34) {
   $cPtr$2$lcssa$i = $cPtr$1$lcssa$i;
  } else {
   $10 = $16&255;
   $cPtr$225$i = $cPtr$1$lcssa$i;$i1$024$i = 0;
   while(1) {
    $35 = (($cPtr$225$i) + ($9)|0);
    $36 = (($cPtr$225$i) + 44|0);
    HEAPF32[$36>>2] = Math_fround(0.0);
    $37 = (($i1$024$i) + 1)|0;
    $exitcond35$i = ($37|0)==($10|0);
    if ($exitcond35$i) {
     break;
    } else {
     $cPtr$225$i = $35;$i1$024$i = $37;
    }
   }
   $8 = Math_imul($9, $10)|0;
   $scevgep34$i = (($cPtr$1$lcssa$i) + ($8)|0);
   $cPtr$2$lcssa$i = $scevgep34$i;
  }
  $11 = ($cPtr$2$lcssa$i>>>0)<($6>>>0);
  if ($11) {
   $cPtr$029$i = $cPtr$2$lcssa$i;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23writeBackContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEPPKNS_17PxcSolverBodyDataES8_($desc,$cache,$bd0,$bd1) {
 $desc = $desc|0;
 $cache = $cache|0;
 $bd0 = $bd0|0;
 $bd1 = $bd1|0;
 var $$ = 0, $$113 = 0, $$lcssa = Math_fround(0), $$lcssa115 = Math_fround(0), $$lcssa116 = Math_fround(0), $$lcssa117 = Math_fround(0), $$lcssa135 = Math_fround(0), $$lcssa136 = Math_fround(0), $$lcssa137 = Math_fround(0), $$lcssa138 = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert158 = 0, $$pre = 0, $$pre159 = Math_fround(0), $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $a2$0114 = 0, $brmerge = 0, $brmerge160 = 0, $brmerge161 = 0;
 var $contacts$0$in121 = 0, $currPtr$0143 = 0, $exitcond = 0, $exitcond155 = 0, $exitcond157 = 0, $frictions$0$in132 = 0, $i$0122 = 0, $i1$0133 = 0, $nf = 0, $or$cond = 0, $vForceWriteback0$0142 = 0, $vForceWriteback0$1$lcssa = 0, $vForceWriteback0$1123 = 0, $vForceWriteback0$2 = 0, $vForceWriteback1$0141 = 0, $vForceWriteback1$1$lcssa = 0, $vForceWriteback1$1120 = 0, $vForceWriteback1$2 = 0, $vForceWriteback2$0140 = 0, $vForceWriteback2$1$lcssa = 0;
 var $vForceWriteback2$1119 = 0, $vForceWriteback2$2 = 0, $vForceWriteback3$0139 = 0, $vForceWriteback3$1$lcssa = 0, $vForceWriteback3$1118 = 0, $vForceWriteback3$2 = 0, $writeBackThresholds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $writeBackThresholds = sp + 16|0;
 $nf = sp;
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($desc) + 26|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 << 4;
 $6 = (($1) + ($5)|0);
 $7 = (($desc) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($desc) + 52|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($desc) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($desc) + 116|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP8[$1>>0]|0;
 $16 = ($15<<24>>24)==(7);
 $17 = $16 ? 272 : 176;
 $18 = $16 ? 336 : 240;
 HEAP32[$writeBackThresholds>>2] = 0;
 $19 = ($3<<16>>16)==(0);
 if ($19) {
  $$lcssa135 = Math_fround(0.0);$$lcssa136 = Math_fround(0.0);$$lcssa137 = Math_fround(0.0);$$lcssa138 = Math_fround(0.0);
 } else {
  $20 = (($writeBackThresholds) + 1|0);
  $21 = (($writeBackThresholds) + 2|0);
  $22 = (($writeBackThresholds) + 3|0);
  $156 = Math_fround(0.0);$157 = Math_fround(0.0);$158 = Math_fround(0.0);$159 = Math_fround(0.0);$currPtr$0143 = $1;$vForceWriteback0$0142 = $8;$vForceWriteback1$0141 = $10;$vForceWriteback2$0140 = $12;$vForceWriteback3$0139 = $14;
  while(1) {
   $23 = (($currPtr$0143) + 1|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24&255;
   $26 = (($currPtr$0143) + 2|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   $29 = Math_imul($25, $17)|0;
   $$sum = (($29) + 144)|0;
   $30 = (($currPtr$0143) + ($$sum)|0);
   $31 = Math_imul($28, $18)|0;
   $$sum1 = (($$sum) + ($31))|0;
   $32 = (($currPtr$0143) + ($$sum1)|0);
   $33 = (($currPtr$0143) + 4|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34 & 1;
   HEAP8[$writeBackThresholds>>0] = $35;
   $36 = (($currPtr$0143) + 5|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37 & 1;
   HEAP8[$20>>0] = $38;
   $39 = (($currPtr$0143) + 6|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40 & 1;
   HEAP8[$21>>0] = $41;
   $42 = (($currPtr$0143) + 7|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = $43 & 1;
   HEAP8[$22>>0] = $44;
   $45 = ($24<<24>>24)==(0);
   if ($45) {
    $$lcssa = $159;$$lcssa115 = $158;$$lcssa116 = $157;$$lcssa117 = $156;$vForceWriteback0$1$lcssa = $vForceWriteback0$0142;$vForceWriteback1$1$lcssa = $vForceWriteback1$0141;$vForceWriteback2$1$lcssa = $vForceWriteback2$0140;$vForceWriteback3$1$lcssa = $vForceWriteback3$0139;
   } else {
    $46 = (($currPtr$0143) + 144|0);
    $47 = (($currPtr$0143) + 11|0);
    $48 = (($currPtr$0143) + 10|0);
    $49 = (($currPtr$0143) + 9|0);
    $50 = (($currPtr$0143) + 8|0);
    $61 = $156;$63 = $157;$65 = $158;$67 = $159;$contacts$0$in121 = $46;$i$0122 = 0;$vForceWriteback0$1123 = $vForceWriteback0$0142;$vForceWriteback1$1120 = $vForceWriteback1$0141;$vForceWriteback2$1119 = $vForceWriteback2$0140;$vForceWriteback3$1118 = $vForceWriteback3$0139;
    while(1) {
     $51 = (($contacts$0$in121) + ($17)|0);
     $52 = (($contacts$0$in121) + 112|0);
     $53 = Math_fround(HEAPF32[$52>>2]);
     $54 = (($contacts$0$in121) + 116|0);
     $55 = Math_fround(HEAPF32[$54>>2]);
     $56 = (($contacts$0$in121) + 120|0);
     $57 = Math_fround(HEAPF32[$56>>2]);
     $58 = (($contacts$0$in121) + 124|0);
     $59 = Math_fround(HEAPF32[$58>>2]);
     $60 = Math_fround($61 + $53);
     $62 = Math_fround($63 + $55);
     $64 = Math_fround($65 + $57);
     $66 = Math_fround($67 + $59);
     $68 = ($vForceWriteback0$1123|0)==(0|0);
     if ($68) {
      $vForceWriteback0$2 = 0;
     } else {
      $69 = HEAP8[$50>>0]|0;
      $70 = $69&255;
      $71 = ($i$0122>>>0)<($70>>>0);
      if ($71) {
       $72 = (($vForceWriteback0$1123) + 4|0);
       HEAPF32[$vForceWriteback0$1123>>2] = $53;
       $vForceWriteback0$2 = $72;
      } else {
       $vForceWriteback0$2 = $vForceWriteback0$1123;
      }
     }
     $73 = ($vForceWriteback1$1120|0)==(0|0);
     if ($73) {
      $vForceWriteback1$2 = 0;
     } else {
      $74 = HEAP8[$49>>0]|0;
      $75 = $74&255;
      $76 = ($i$0122>>>0)<($75>>>0);
      if ($76) {
       $77 = (($vForceWriteback1$1120) + 4|0);
       HEAPF32[$vForceWriteback1$1120>>2] = $55;
       $vForceWriteback1$2 = $77;
      } else {
       $vForceWriteback1$2 = $vForceWriteback1$1120;
      }
     }
     $78 = ($vForceWriteback2$1119|0)==(0|0);
     if ($78) {
      $vForceWriteback2$2 = 0;
     } else {
      $79 = HEAP8[$48>>0]|0;
      $80 = $79&255;
      $81 = ($i$0122>>>0)<($80>>>0);
      if ($81) {
       $82 = (($vForceWriteback2$1119) + 4|0);
       HEAPF32[$vForceWriteback2$1119>>2] = $57;
       $vForceWriteback2$2 = $82;
      } else {
       $vForceWriteback2$2 = $vForceWriteback2$1119;
      }
     }
     $83 = ($vForceWriteback3$1118|0)==(0|0);
     if ($83) {
      $vForceWriteback3$2 = 0;
     } else {
      $84 = HEAP8[$47>>0]|0;
      $85 = $84&255;
      $86 = ($i$0122>>>0)<($85>>>0);
      if ($86) {
       $87 = (($vForceWriteback3$1118) + 4|0);
       HEAPF32[$vForceWriteback3$1118>>2] = $59;
       $vForceWriteback3$2 = $87;
      } else {
       $vForceWriteback3$2 = $vForceWriteback3$1118;
      }
     }
     $88 = (($i$0122) + 1)|0;
     $exitcond155 = ($88|0)==($25|0);
     if ($exitcond155) {
      $$lcssa = $66;$$lcssa115 = $64;$$lcssa116 = $62;$$lcssa117 = $60;$vForceWriteback0$1$lcssa = $vForceWriteback0$2;$vForceWriteback1$1$lcssa = $vForceWriteback1$2;$vForceWriteback2$1$lcssa = $vForceWriteback2$2;$vForceWriteback3$1$lcssa = $vForceWriteback3$2;
      break;
     } else {
      $61 = $60;$63 = $62;$65 = $64;$67 = $66;$contacts$0$in121 = $51;$i$0122 = $88;$vForceWriteback0$1123 = $vForceWriteback0$2;$vForceWriteback1$1120 = $vForceWriteback1$2;$vForceWriteback2$1119 = $vForceWriteback2$2;$vForceWriteback3$1118 = $vForceWriteback3$2;
     }
    }
   }
   $89 = ($27<<24>>24)==(0);
   if (!($89)) {
    $frictions$0$in132 = $30;$i1$0133 = 0;
    while(1) {
     $91 = (($frictions$0$in132) + 180|0);
     $92 = Math_fround(HEAPF32[$91>>2]);
     $93 = (($frictions$0$in132) + 184|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = (($frictions$0$in132) + 188|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $97 = $92 == Math_fround(0.0);
     $98 = $94 == Math_fround(0.0);
     $99 = $96 == Math_fround(0.0);
     $100 = (($frictions$0$in132) + 224|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101|0)==(0|0);
     if (!($102)) {
      $103 = (($frictions$0$in132) + 176|0);
      $104 = Math_fround(HEAPF32[$103>>2]);
      $105 = $104 == Math_fround(0.0);
      if (!($105)) {
       HEAP8[$101>>0] = 1;
      }
     }
     $106 = (($frictions$0$in132) + 228|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ($107|0)==(0|0);
     $brmerge = $108 | $97;
     if (!($brmerge)) {
      HEAP8[$107>>0] = 1;
     }
     $148 = (($frictions$0$in132) + 232|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ($149|0)==(0|0);
     $brmerge160 = $150 | $98;
     if (!($brmerge160)) {
      HEAP8[$149>>0] = 1;
     }
     $151 = (($frictions$0$in132) + 236|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = ($152|0)==(0|0);
     $brmerge161 = $153 | $99;
     if (!($brmerge161)) {
      HEAP8[$152>>0] = 1;
     }
     $154 = (($frictions$0$in132) + ($18)|0);
     $155 = (($i1$0133) + 1)|0;
     $exitcond157 = ($155|0)==($28|0);
     if ($exitcond157) {
      break;
     } else {
      $frictions$0$in132 = $154;$i1$0133 = $155;
     }
    }
   }
   $90 = ($32>>>0)<($6>>>0);
   if ($90) {
    $156 = $$lcssa117;$157 = $$lcssa116;$158 = $$lcssa115;$159 = $$lcssa;$currPtr$0143 = $32;$vForceWriteback0$0142 = $vForceWriteback0$1$lcssa;$vForceWriteback1$0141 = $vForceWriteback1$1$lcssa;$vForceWriteback2$0140 = $vForceWriteback2$1$lcssa;$vForceWriteback3$0139 = $vForceWriteback3$1$lcssa;
   } else {
    $$lcssa135 = $$lcssa;$$lcssa136 = $$lcssa115;$$lcssa137 = $$lcssa116;$$lcssa138 = $$lcssa117;
    break;
   }
  }
 }
 HEAPF32[$nf>>2] = $$lcssa138;
 $109 = (($nf) + 4|0);
 HEAPF32[$109>>2] = $$lcssa137;
 $110 = (($nf) + 8|0);
 HEAPF32[$110>>2] = $$lcssa136;
 $111 = (($nf) + 12|0);
 HEAPF32[$111>>2] = $$lcssa135;
 $112 = (($cache) + 8|0);
 $113 = (($cache) + 4|0);
 $a2$0114 = 0;
 while(1) {
  $114 = (($writeBackThresholds) + ($a2$0114)|0);
  $115 = HEAP8[$114>>0]|0;
  $116 = ($115<<24>>24)==(0);
  if (!($116)) {
   $117 = ((($desc) + ($a2$0114<<5)|0) + 8|0);
   $118 = HEAP16[$117>>1]|0;
   $119 = ($118<<16>>16)==(-1);
   if ($119) {
    $120 = ((($desc) + ($a2$0114<<5)|0) + 12|0);
    $121 = HEAP16[$120>>1]|0;
    $122 = ($121<<16>>16)==(-1);
    if ($122) {
     $123 = (($nf) + ($a2$0114<<2)|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = ($124|0)==(0);
     $126 = (HEAP32[tempDoublePtr>>2]=$124,Math_fround(HEAPF32[tempDoublePtr>>2]));
     if (!($125)) {
      $127 = (($bd0) + ($a2$0114<<2)|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = (($128) + 36|0);
      $130 = Math_fround(HEAPF32[$129>>2]);
      $131 = $130 < Math_fround(3.40282346638528859812E+38);
      $$phi$trans$insert = (($bd1) + ($a2$0114<<2)|0);
      $$pre = HEAP32[$$phi$trans$insert>>2]|0;
      $$phi$trans$insert158 = (($$pre) + 36|0);
      $$pre159 = Math_fround(HEAPF32[$$phi$trans$insert158>>2]);
      $132 = $$pre159 < Math_fround(3.40282346638528859812E+38);
      $or$cond = $131 | $132;
      if ($or$cond) {
       $133 = $130 < $$pre159;
       $134 = $133 ? $130 : $$pre159;
       $135 = (($128) + 40|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = (($$pre) + 40|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = ($138>>>0)<($136>>>0);
       $$ = $139 ? $136 : $138;
       $$113 = $139 ? $138 : $136;
       $140 = HEAP32[$112>>2]|0;
       $141 = (($140) + 1)|0;
       HEAP32[$112>>2] = $141;
       $142 = HEAP32[$113>>2]|0;
       $143 = (($142) + ($140<<4)|0);
       HEAP32[$143>>2] = $$113;
       $144 = ((($142) + ($140<<4)|0) + 4|0);
       HEAP32[$144>>2] = $$;
       $145 = ((($142) + ($140<<4)|0) + 8|0);
       HEAPF32[$145>>2] = $126;
       $146 = ((($142) + ($140<<4)|0) + 12|0);
       HEAPF32[$146>>2] = $134;
      }
     }
    }
   }
  }
  $147 = (($a2$0114) + 1)|0;
  $exitcond = ($147|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $a2$0114 = $147;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx12writeBack1D4EPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEPPKNS_17PxcSolverBodyDataES8_($desc,$0,$1,$2) {
 $desc = $desc|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$916 = 0, $$in1$i = 0, $$in2$i = 0, $$in3$i = 0, $$lcssa = Math_fround(0), $$lcssa923 = Math_fround(0), $$lcssa924 = Math_fround(0), $$lcssa925 = Math_fround(0), $$lcssa926 = Math_fround(0), $$lcssa927 = Math_fround(0), $$lcssa928 = Math_fround(0), $$lcssa929 = Math_fround(0), $$lcssa930 = Math_fround(0), $$lcssa931 = Math_fround(0), $$lcssa932 = Math_fround(0), $$lcssa933 = Math_fround(0), $$lcssa934 = Math_fround(0), $$lcssa935 = Math_fround(0), $$lcssa936 = Math_fround(0);
 var $$lcssa937 = Math_fround(0), $$lcssa938 = Math_fround(0), $$lcssa939 = Math_fround(0), $$lcssa940 = Math_fround(0), $$lcssa941 = Math_fround(0), $$lcssa942 = Math_fround(0), $$lcssa943 = Math_fround(0), $$lcssa944 = Math_fround(0), $$lcssa945 = Math_fround(0), $$not = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0;
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0;
 var $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0;
 var $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0;
 var $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0);
 var $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0);
 var $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0);
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn4$i = 0, $a$pn6$i = 0, $b$a$i = 0, $b$a7$i = 0, $base$0947 = 0, $i$0946 = 0, $not$ = 0, $not$917 = 0, $not$918 = 0, $not$919 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $sext$mask = 0, $sext920$mask = 0, $sext921$mask = 0, $sext922$mask = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $3 = sp + 16|0;
 $4 = sp;
 $5 = (($desc) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($desc) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($desc) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($desc) + 116|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($6|0)!=(0|0);
 $$not = $13 ^ 1;
 $14 = ($8|0)==(0|0);
 $or$cond = $14 & $$not;
 $15 = ($10|0)==(0|0);
 $or$cond1 = $or$cond & $15;
 $16 = ($12|0)==(0|0);
 $or$cond2 = $or$cond1 & $16;
 if ($or$cond2) {
  STACKTOP = sp;return;
 }
 $17 = (($desc) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(9);
 $21 = $20 ? 416 : 272;
 $22 = (($18) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if ($24) {
  $$lcssa = Math_fround(0.0);$$lcssa923 = Math_fround(0.0);$$lcssa924 = Math_fround(0.0);$$lcssa925 = Math_fround(0.0);$$lcssa926 = Math_fround(0.0);$$lcssa927 = Math_fround(0.0);$$lcssa928 = Math_fround(0.0);$$lcssa929 = Math_fround(0.0);$$lcssa930 = Math_fround(0.0);$$lcssa931 = Math_fround(0.0);$$lcssa932 = Math_fround(0.0);$$lcssa933 = Math_fround(0.0);$$lcssa934 = Math_fround(0.0);$$lcssa935 = Math_fround(0.0);$$lcssa936 = Math_fround(0.0);$$lcssa937 = Math_fround(0.0);$$lcssa938 = Math_fround(0.0);$$lcssa939 = Math_fround(0.0);$$lcssa940 = Math_fround(0.0);$$lcssa941 = Math_fround(0.0);$$lcssa942 = Math_fround(0.0);$$lcssa943 = Math_fround(0.0);$$lcssa944 = Math_fround(0.0);$$lcssa945 = Math_fround(0.0);
 } else {
  $25 = (($18) + 128|0);
  $101 = Math_fround(0.0);$115 = Math_fround(0.0);$117 = Math_fround(0.0);$119 = Math_fround(0.0);$121 = Math_fround(0.0);$135 = Math_fround(0.0);$137 = Math_fround(0.0);$139 = Math_fround(0.0);$141 = Math_fround(0.0);$155 = Math_fround(0.0);$157 = Math_fround(0.0);$159 = Math_fround(0.0);$161 = Math_fround(0.0);$55 = Math_fround(0.0);$57 = Math_fround(0.0);$59 = Math_fround(0.0);$61 = Math_fround(0.0);$75 = Math_fround(0.0);$77 = Math_fround(0.0);$79 = Math_fround(0.0);$81 = Math_fround(0.0);$95 = Math_fround(0.0);$97 = Math_fround(0.0);$99 = Math_fround(0.0);$base$0947 = $25;$i$0946 = 0;
  while(1) {
   $26 = (($base$0947) + 256|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($base$0947) + 260|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($base$0947) + 264|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($base$0947) + 268|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($base$0947) + 240|0);
   _memmove(($4|0),($34|0),16)|0;
   $sext$mask = $27 & 2;
   $35 = ($sext$mask|0)==(0);
   $b$a$i = $35 ? $3 : $4;
   ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
   $36 = Math_fround(HEAPF32[$b$a$i>>2]);
   $sext920$mask = $29 & 2;
   $37 = ($sext920$mask|0)==(0);
   $a$pn4$i = $37 ? $3 : $4;
   $$in1$i = (($a$pn4$i) + 4|0);
   $38 = Math_fround(HEAPF32[$$in1$i>>2]);
   $sext921$mask = $31 & 2;
   $39 = ($sext921$mask|0)==(0);
   $b$a7$i = $39 ? $3 : $4;
   $$in2$i = (($b$a7$i) + 8|0);
   $40 = Math_fround(HEAPF32[$$in2$i>>2]);
   $sext922$mask = $33 & 2;
   $41 = ($sext922$mask|0)==(0);
   $a$pn6$i = $41 ? $3 : $4;
   $$in3$i = (($a$pn6$i) + 12|0);
   $42 = Math_fround(HEAPF32[$$in3$i>>2]);
   $43 = Math_fround(HEAPF32[$base$0947>>2]);
   $44 = (($base$0947) + 4|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = (($base$0947) + 8|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = (($base$0947) + 12|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = Math_fround($36 * $43);
   $51 = Math_fround($38 * $45);
   $52 = Math_fround($40 * $47);
   $53 = Math_fround($42 * $49);
   $54 = Math_fround($55 + $50);
   $56 = Math_fround($57 + $51);
   $58 = Math_fround($59 + $52);
   $60 = Math_fround($61 + $53);
   $62 = (($base$0947) + 16|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = (($base$0947) + 20|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = (($base$0947) + 24|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = (($base$0947) + 28|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($36 * $63);
   $71 = Math_fround($38 * $65);
   $72 = Math_fround($40 * $67);
   $73 = Math_fround($42 * $69);
   $74 = Math_fround($75 + $70);
   $76 = Math_fround($77 + $71);
   $78 = Math_fround($79 + $72);
   $80 = Math_fround($81 + $73);
   $82 = (($base$0947) + 32|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = (($base$0947) + 36|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = (($base$0947) + 40|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = (($base$0947) + 44|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = Math_fround($36 * $83);
   $91 = Math_fround($38 * $85);
   $92 = Math_fround($40 * $87);
   $93 = Math_fround($42 * $89);
   $94 = Math_fround($95 + $90);
   $96 = Math_fround($97 + $91);
   $98 = Math_fround($99 + $92);
   $100 = Math_fround($101 + $93);
   $102 = (($base$0947) + 48|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = (($base$0947) + 52|0);
   $105 = Math_fround(HEAPF32[$104>>2]);
   $106 = (($base$0947) + 56|0);
   $107 = Math_fround(HEAPF32[$106>>2]);
   $108 = (($base$0947) + 60|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = Math_fround($36 * $103);
   $111 = Math_fround($38 * $105);
   $112 = Math_fround($40 * $107);
   $113 = Math_fround($42 * $109);
   $114 = Math_fround($115 + $110);
   $116 = Math_fround($117 + $111);
   $118 = Math_fround($119 + $112);
   $120 = Math_fround($121 + $113);
   $122 = (($base$0947) + 64|0);
   $123 = Math_fround(HEAPF32[$122>>2]);
   $124 = (($base$0947) + 68|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = (($base$0947) + 72|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = (($base$0947) + 76|0);
   $129 = Math_fround(HEAPF32[$128>>2]);
   $130 = Math_fround($36 * $123);
   $131 = Math_fround($38 * $125);
   $132 = Math_fround($40 * $127);
   $133 = Math_fround($42 * $129);
   $134 = Math_fround($135 + $130);
   $136 = Math_fround($137 + $131);
   $138 = Math_fround($139 + $132);
   $140 = Math_fround($141 + $133);
   $142 = (($base$0947) + 80|0);
   $143 = Math_fround(HEAPF32[$142>>2]);
   $144 = (($base$0947) + 84|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = (($base$0947) + 88|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = (($base$0947) + 92|0);
   $149 = Math_fround(HEAPF32[$148>>2]);
   $150 = Math_fround($36 * $143);
   $151 = Math_fround($38 * $145);
   $152 = Math_fround($40 * $147);
   $153 = Math_fround($42 * $149);
   $154 = Math_fround($155 + $150);
   $156 = Math_fround($157 + $151);
   $158 = Math_fround($159 + $152);
   $160 = Math_fround($161 + $153);
   $162 = (($base$0947) + ($21)|0);
   $163 = (($i$0946) + 1)|0;
   $164 = HEAP32[$22>>2]|0;
   $165 = ($163>>>0)<($164>>>0);
   if ($165) {
    $101 = $100;$115 = $114;$117 = $116;$119 = $118;$121 = $120;$135 = $134;$137 = $136;$139 = $138;$141 = $140;$155 = $154;$157 = $156;$159 = $158;$161 = $160;$55 = $54;$57 = $56;$59 = $58;$61 = $60;$75 = $74;$77 = $76;$79 = $78;$81 = $80;$95 = $94;$97 = $96;$99 = $98;$base$0947 = $162;$i$0946 = $163;
   } else {
    $$lcssa = $60;$$lcssa923 = $58;$$lcssa924 = $56;$$lcssa925 = $54;$$lcssa926 = $80;$$lcssa927 = $78;$$lcssa928 = $76;$$lcssa929 = $74;$$lcssa930 = $100;$$lcssa931 = $98;$$lcssa932 = $96;$$lcssa933 = $94;$$lcssa934 = $120;$$lcssa935 = $118;$$lcssa936 = $116;$$lcssa937 = $114;$$lcssa938 = $140;$$lcssa939 = $138;$$lcssa940 = $136;$$lcssa941 = $134;$$lcssa942 = $160;$$lcssa943 = $158;$$lcssa944 = $156;$$lcssa945 = $154;
    break;
   }
  }
 }
 $166 = (($18) + 112|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = (($18) + 116|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($18) + 120|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($18) + 124|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = (($18) + 96|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = (($18) + 100|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = (($18) + 104|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = (($18) + 108|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = Math_fround($$lcssa933 * $175);
 $183 = Math_fround($$lcssa932 * $177);
 $184 = Math_fround($$lcssa931 * $179);
 $185 = Math_fround($$lcssa930 * $181);
 $186 = Math_fround($$lcssa929 * $167);
 $187 = Math_fround($$lcssa928 * $169);
 $188 = Math_fround($$lcssa927 * $171);
 $189 = Math_fround($$lcssa926 * $173);
 $190 = Math_fround($182 - $186);
 $191 = Math_fround($183 - $187);
 $192 = Math_fround($184 - $188);
 $193 = Math_fround($185 - $189);
 $194 = Math_fround($$lcssa937 - $190);
 $195 = Math_fround($$lcssa936 - $191);
 $196 = Math_fround($$lcssa935 - $192);
 $197 = Math_fround($$lcssa934 - $193);
 $198 = (($18) + 80|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($18) + 84|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = (($18) + 88|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = (($18) + 92|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = Math_fround($$lcssa925 * $167);
 $207 = Math_fround($$lcssa924 * $169);
 $208 = Math_fround($$lcssa923 * $171);
 $209 = Math_fround($$lcssa * $173);
 $210 = Math_fround($$lcssa933 * $199);
 $211 = Math_fround($$lcssa932 * $201);
 $212 = Math_fround($$lcssa931 * $203);
 $213 = Math_fround($$lcssa930 * $205);
 $214 = Math_fround($206 - $210);
 $215 = Math_fround($207 - $211);
 $216 = Math_fround($208 - $212);
 $217 = Math_fround($209 - $213);
 $218 = Math_fround($$lcssa941 - $214);
 $219 = Math_fround($$lcssa940 - $215);
 $220 = Math_fround($$lcssa939 - $216);
 $221 = Math_fround($$lcssa938 - $217);
 $222 = Math_fround($$lcssa929 * $199);
 $223 = Math_fround($$lcssa928 * $201);
 $224 = Math_fround($$lcssa927 * $203);
 $225 = Math_fround($$lcssa926 * $205);
 $226 = Math_fround($$lcssa925 * $175);
 $227 = Math_fround($$lcssa924 * $177);
 $228 = Math_fround($$lcssa923 * $179);
 $229 = Math_fround($$lcssa * $181);
 $230 = Math_fround($222 - $226);
 $231 = Math_fround($223 - $227);
 $232 = Math_fround($224 - $228);
 $233 = Math_fround($225 - $229);
 $234 = Math_fround($$lcssa945 - $230);
 $235 = Math_fround($$lcssa944 - $231);
 $236 = Math_fround($$lcssa943 - $232);
 $237 = Math_fround($$lcssa942 - $233);
 $238 = Math_fround($$lcssa924 * $$lcssa924);
 $239 = Math_fround($$lcssa923 * $$lcssa923);
 $240 = Math_fround($$lcssa * $$lcssa);
 $241 = Math_fround($$lcssa928 * $$lcssa928);
 $242 = Math_fround($$lcssa927 * $$lcssa927);
 $243 = Math_fround($$lcssa926 * $$lcssa926);
 $244 = Math_fround($238 + $241);
 $245 = Math_fround($239 + $242);
 $246 = Math_fround($240 + $243);
 $247 = Math_fround($$lcssa932 * $$lcssa932);
 $248 = Math_fround($$lcssa931 * $$lcssa931);
 $249 = Math_fround($$lcssa930 * $$lcssa930);
 $250 = Math_fround($244 + $247);
 $251 = Math_fround($245 + $248);
 $252 = Math_fround($246 + $249);
 $253 = Math_fround($195 * $195);
 $254 = Math_fround($196 * $196);
 $255 = Math_fround($197 * $197);
 $256 = Math_fround($219 * $219);
 $257 = Math_fround($220 * $220);
 $258 = Math_fround($221 * $221);
 $259 = Math_fround($253 + $256);
 $260 = Math_fround($254 + $257);
 $261 = Math_fround($255 + $258);
 $262 = Math_fround($235 * $235);
 $263 = Math_fround($236 * $236);
 $264 = Math_fround($237 * $237);
 $265 = Math_fround($262 + $259);
 $266 = Math_fround($263 + $260);
 $267 = Math_fround($264 + $261);
 $268 = (Math_fround(Math_sqrt((Math_fround($250)))));
 $269 = (Math_fround(Math_sqrt((Math_fround($251)))));
 $270 = (Math_fround(Math_sqrt((Math_fround($252)))));
 $271 = (Math_fround(Math_sqrt((Math_fround($265)))));
 $272 = (Math_fround(Math_sqrt((Math_fround($266)))));
 $273 = (Math_fround(Math_sqrt((Math_fround($267)))));
 $274 = (($18) + 20|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = (($18) + 24|0);
 $277 = Math_fround(HEAPF32[$276>>2]);
 $278 = (($18) + 28|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = (($18) + 36|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = (($18) + 40|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = (($18) + 44|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = $271 > $281;
 $287 = $272 > $283;
 $288 = $273 > $285;
 $not$917 = $268 > $275;
 $289 = $286 | $not$917;
 $not$918 = $269 > $277;
 $$916 = $287 | $not$918;
 $not$919 = $270 > $279;
 $290 = $288 | $not$919;
 if ($13) {
  $291 = Math_fround($218 * $218);
  $292 = Math_fround($194 * $194);
  $293 = (($18) + 32|0);
  $294 = Math_fround($234 * $234);
  $295 = Math_fround($292 + $291);
  $296 = Math_fround($$lcssa929 * $$lcssa929);
  $297 = Math_fround($$lcssa925 * $$lcssa925);
  $298 = (($18) + 16|0);
  $299 = Math_fround($294 + $295);
  $300 = Math_fround($$lcssa933 * $$lcssa933);
  $301 = Math_fround($297 + $296);
  $302 = Math_fround(HEAPF32[$293>>2]);
  $303 = (Math_fround(Math_sqrt((Math_fround($299)))));
  $304 = Math_fround($301 + $300);
  $305 = (Math_fround(Math_sqrt((Math_fround($304)))));
  $306 = Math_fround(HEAPF32[$298>>2]);
  $307 = $303 > $302;
  $not$ = $305 > $306;
  $$ = $307 | $not$;
  HEAPF32[$6>>2] = $$lcssa925;
  $308 = (($6) + 4|0);
  HEAPF32[$308>>2] = $$lcssa929;
  $309 = (($6) + 8|0);
  HEAPF32[$309>>2] = $$lcssa933;
  $310 = (($6) + 16|0);
  HEAPF32[$310>>2] = $194;
  $311 = (($6) + 20|0);
  HEAPF32[$311>>2] = $218;
  $312 = (($6) + 24|0);
  HEAPF32[$312>>2] = $234;
  $313 = $$&1;
  $314 = (($6) + 12|0);
  HEAP32[$314>>2] = $313;
 }
 if (!($14)) {
  HEAPF32[$8>>2] = $$lcssa924;
  $315 = (($8) + 4|0);
  HEAPF32[$315>>2] = $$lcssa928;
  $316 = (($8) + 8|0);
  HEAPF32[$316>>2] = $$lcssa932;
  $317 = (($8) + 16|0);
  HEAPF32[$317>>2] = $195;
  $318 = (($8) + 20|0);
  HEAPF32[$318>>2] = $219;
  $319 = (($8) + 24|0);
  HEAPF32[$319>>2] = $235;
  $320 = $289&1;
  $321 = (($8) + 12|0);
  HEAP32[$321>>2] = $320;
 }
 if (!($15)) {
  HEAPF32[$10>>2] = $$lcssa923;
  $322 = (($10) + 4|0);
  HEAPF32[$322>>2] = $$lcssa927;
  $323 = (($10) + 8|0);
  HEAPF32[$323>>2] = $$lcssa931;
  $324 = (($10) + 16|0);
  HEAPF32[$324>>2] = $196;
  $325 = (($10) + 20|0);
  HEAPF32[$325>>2] = $220;
  $326 = (($10) + 24|0);
  HEAPF32[$326>>2] = $236;
  $327 = $$916&1;
  $328 = (($10) + 12|0);
  HEAP32[$328>>2] = $327;
 }
 if ($16) {
  STACKTOP = sp;return;
 }
 HEAPF32[$12>>2] = $$lcssa;
 $329 = (($12) + 4|0);
 HEAPF32[$329>>2] = $$lcssa926;
 $330 = (($12) + 8|0);
 HEAPF32[$330>>2] = $$lcssa930;
 $331 = (($12) + 16|0);
 HEAPF32[$331>>2] = $197;
 $332 = (($12) + 20|0);
 HEAPF32[$332>>2] = $221;
 $333 = (($12) + 24|0);
 HEAPF32[$333>>2] = $237;
 $334 = $290&1;
 $335 = (($12) + 12|0);
 HEAP32[$335>>2] = $334;
 STACKTOP = sp;return;
}
function __ZN5physx20solveContactPreBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL19solveContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 STACKTOP = sp;return;
}
function __ZN5physxL19solveContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i177 = Math_fround(0), $$$i389 = Math_fround(0), $$$i399 = Math_fround(0), $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i178 = Math_fround(0), $$1$i390 = Math_fround(0), $$1$i400 = Math_fround(0), $$be = Math_fround(0), $$be2859 = Math_fround(0), $$be2860 = Math_fround(0), $$be2861 = Math_fround(0), $$be2862 = Math_fround(0), $$be2863 = Math_fround(0), $$be2864 = Math_fround(0), $$be2865 = Math_fround(0), $$be2866 = Math_fround(0), $$be2867 = Math_fround(0);
 var $$be2868 = Math_fround(0), $$be2869 = Math_fround(0), $$be2870 = Math_fround(0), $$be2871 = Math_fround(0), $$be2872 = Math_fround(0), $$be2873 = Math_fround(0), $$be2874 = Math_fround(0), $$be2875 = Math_fround(0), $$be2876 = Math_fround(0), $$be2877 = Math_fround(0), $$be2878 = Math_fround(0), $$be2879 = Math_fround(0), $$be2880 = Math_fround(0), $$be2881 = Math_fround(0), $$be2882 = Math_fround(0), $$be2883 = Math_fround(0), $$be2884 = Math_fround(0), $$be2885 = Math_fround(0), $$be2886 = Math_fround(0), $$be2887 = Math_fround(0);
 var $$be2888 = Math_fround(0), $$be2889 = Math_fround(0), $$be2890 = Math_fround(0), $$be2891 = Math_fround(0), $$be2892 = Math_fround(0), $$be2893 = Math_fround(0), $$be2894 = Math_fround(0), $$be2895 = Math_fround(0), $$be2896 = Math_fround(0), $$be2897 = Math_fround(0), $$be2898 = Math_fround(0), $$be2899 = Math_fround(0), $$be2900 = Math_fround(0), $$be2901 = Math_fround(0), $$be2902 = Math_fround(0), $$be2903 = Math_fround(0), $$be2904 = Math_fround(0), $$be2905 = Math_fround(0), $$in1$i = 0, $$in1$i164 = 0;
 var $$in2$i = 0, $$in2$i166 = 0, $$in3$i = 0, $$in3$i168 = 0, $$lcssa = Math_fround(0), $$lcssa2693 = Math_fround(0), $$lcssa2694 = Math_fround(0), $$lcssa2695 = Math_fround(0), $$lcssa2696 = Math_fround(0), $$lcssa2697 = Math_fround(0), $$lcssa2698 = Math_fround(0), $$lcssa2699 = Math_fround(0), $$lcssa2700 = Math_fround(0), $$lcssa2701 = Math_fround(0), $$lcssa2702 = Math_fround(0), $$lcssa2703 = Math_fround(0), $$lcssa2704 = Math_fround(0), $$lcssa2705 = Math_fround(0), $$lcssa2706 = Math_fround(0), $$lcssa2707 = Math_fround(0);
 var $$lcssa2708 = Math_fround(0), $$lcssa2709 = Math_fround(0), $$lcssa2710 = Math_fround(0), $$lcssa2711 = Math_fround(0), $$lcssa2712 = Math_fround(0), $$lcssa2713 = Math_fround(0), $$lcssa2714 = Math_fround(0), $$lcssa2715 = Math_fround(0), $$lcssa2716 = Math_fround(0), $$lcssa2717 = Math_fround(0), $$lcssa2718 = Math_fround(0), $$lcssa2719 = Math_fround(0), $$lcssa2720 = Math_fround(0), $$lcssa2721 = Math_fround(0), $$lcssa2722 = Math_fround(0), $$lcssa2723 = Math_fround(0), $$lcssa2906 = Math_fround(0), $$lcssa2907 = Math_fround(0), $$lcssa2908 = Math_fround(0), $$lcssa2909 = Math_fround(0);
 var $$lcssa2910 = Math_fround(0), $$lcssa2911 = Math_fround(0), $$lcssa2912 = Math_fround(0), $$lcssa2913 = Math_fround(0), $$lcssa2914 = Math_fround(0), $$lcssa2915 = Math_fround(0), $$lcssa2916 = Math_fround(0), $$lcssa2917 = Math_fround(0), $$lcssa2918 = Math_fround(0), $$lcssa2919 = Math_fround(0), $$lcssa2920 = Math_fround(0), $$lcssa2921 = Math_fround(0), $$lcssa2922 = Math_fround(0), $$lcssa2923 = Math_fround(0), $$lcssa2924 = Math_fround(0), $$lcssa2925 = Math_fround(0), $$lcssa2926 = Math_fround(0), $$lcssa2927 = Math_fround(0), $$lcssa2928 = Math_fround(0), $$lcssa2929 = Math_fround(0);
 var $$lcssa2930 = Math_fround(0), $$lcssa2931 = Math_fround(0), $$lcssa2932 = Math_fround(0), $$lcssa2933 = Math_fround(0), $$lcssa2934 = Math_fround(0), $$lcssa2935 = Math_fround(0), $$lcssa2936 = Math_fround(0), $$lcssa2937 = Math_fround(0), $$lcssa2938 = Math_fround(0), $$lcssa2939 = Math_fround(0), $$lcssa2940 = Math_fround(0), $$lcssa2941 = Math_fround(0), $$lcssa2942 = Math_fround(0), $$lcssa2943 = Math_fround(0), $$lcssa2944 = Math_fround(0), $$lcssa2945 = Math_fround(0), $$lcssa2946 = Math_fround(0), $$lcssa2947 = Math_fround(0), $$lcssa2948 = Math_fround(0), $$lcssa2949 = Math_fround(0);
 var $$lcssa2950 = Math_fround(0), $$lcssa2951 = Math_fround(0), $$lcssa2952 = Math_fround(0), $$lcssa2953 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = 0, $1006 = 0, $1007 = 0, $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = Math_fround(0);
 var $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = Math_fround(0), $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0);
 var $103 = 0, $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0);
 var $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = 0, $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0);
 var $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = 0, $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0), $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = 0, $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0);
 var $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = 0, $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = 0, $1100 = Math_fround(0);
 var $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0;
 var $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0;
 var $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = 0, $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0);
 var $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = Math_fround(0), $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0;
 var $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0);
 var $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0);
 var $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0);
 var $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0;
 var $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0;
 var $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0;
 var $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0);
 var $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0);
 var $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0;
 var $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0;
 var $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0);
 var $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0);
 var $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0);
 var $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0);
 var $429 = Math_fround(0), $43 = Math_fround(0), $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0);
 var $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = 0, $472 = Math_fround(0), $473 = 0, $474 = 0, $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = Math_fround(0);
 var $483 = 0, $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0);
 var $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0);
 var $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0);
 var $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = 0, $571 = Math_fround(0), $572 = Math_fround(0);
 var $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0);
 var $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0);
 var $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0);
 var $627 = 0, $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = 0, $636 = Math_fround(0), $637 = 0, $638 = Math_fround(0), $639 = 0, $64 = 0, $640 = Math_fround(0), $641 = 0, $642 = Math_fround(0), $643 = 0, $644 = Math_fround(0);
 var $645 = 0, $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0;
 var $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = Math_fround(0), $670 = 0, $671 = Math_fround(0), $672 = 0, $673 = Math_fround(0), $674 = 0, $675 = Math_fround(0), $676 = 0, $677 = Math_fround(0), $678 = 0, $679 = Math_fround(0), $68 = Math_fround(0), $680 = 0;
 var $681 = Math_fround(0), $682 = 0, $683 = Math_fround(0), $684 = 0, $685 = Math_fround(0), $686 = 0, $687 = Math_fround(0), $688 = 0, $689 = Math_fround(0), $69 = 0, $690 = 0, $691 = Math_fround(0), $692 = 0, $693 = Math_fround(0), $694 = 0, $695 = Math_fround(0), $696 = 0, $697 = Math_fround(0), $698 = 0, $699 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $700 = 0, $701 = Math_fround(0), $702 = 0, $703 = Math_fround(0), $704 = 0, $705 = Math_fround(0), $706 = 0, $707 = Math_fround(0), $708 = 0, $709 = Math_fround(0), $71 = 0, $710 = 0, $711 = Math_fround(0), $712 = 0, $713 = Math_fround(0), $714 = 0, $715 = Math_fround(0), $716 = 0;
 var $717 = Math_fround(0), $718 = 0, $719 = Math_fround(0), $72 = Math_fround(0), $720 = 0, $721 = Math_fround(0), $722 = 0, $723 = Math_fround(0), $724 = 0, $725 = Math_fround(0), $726 = 0, $727 = Math_fround(0), $728 = 0, $729 = Math_fround(0), $73 = 0, $730 = 0, $731 = Math_fround(0), $732 = 0, $733 = Math_fround(0), $734 = 0;
 var $735 = Math_fround(0), $736 = 0, $737 = Math_fround(0), $738 = 0, $739 = Math_fround(0), $74 = Math_fround(0), $740 = 0, $741 = Math_fround(0), $742 = 0, $743 = Math_fround(0), $744 = 0, $745 = Math_fround(0), $746 = 0, $747 = Math_fround(0), $748 = 0, $749 = Math_fround(0), $75 = 0, $750 = 0, $751 = Math_fround(0), $752 = 0;
 var $753 = Math_fround(0), $754 = 0, $755 = Math_fround(0), $756 = 0, $757 = Math_fround(0), $758 = 0, $759 = Math_fround(0), $76 = Math_fround(0), $760 = 0, $761 = Math_fround(0), $762 = 0, $763 = Math_fround(0), $764 = 0, $765 = Math_fround(0), $766 = 0, $767 = Math_fround(0), $768 = 0, $769 = Math_fround(0), $77 = 0, $770 = 0;
 var $771 = Math_fround(0), $772 = 0, $773 = Math_fround(0), $774 = 0, $775 = Math_fround(0), $776 = 0, $777 = Math_fround(0), $778 = 0, $779 = Math_fround(0), $78 = Math_fround(0), $780 = 0, $781 = Math_fround(0), $782 = 0, $783 = Math_fround(0), $784 = 0, $785 = Math_fround(0), $786 = 0, $787 = Math_fround(0), $788 = 0, $789 = Math_fround(0);
 var $79 = 0, $790 = 0, $791 = Math_fround(0), $792 = 0, $793 = Math_fround(0), $794 = 0, $795 = Math_fround(0), $796 = 0, $797 = Math_fround(0), $798 = 0, $799 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $800 = 0, $801 = Math_fround(0), $802 = 0, $803 = Math_fround(0), $804 = 0, $805 = Math_fround(0), $806 = 0;
 var $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = Math_fround(0), $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0);
 var $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0);
 var $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0);
 var $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0);
 var $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0);
 var $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0);
 var $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = Math_fround(0), $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0);
 var $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = Math_fround(0), $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = 0, $948 = Math_fround(0), $949 = 0, $95 = 0, $950 = Math_fround(0);
 var $951 = 0, $952 = Math_fround(0), $953 = 0, $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = Math_fround(0), $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0);
 var $97 = 0, $970 = Math_fround(0), $971 = 0, $972 = 0, $973 = Math_fround(0), $974 = 0, $975 = 0, $976 = Math_fround(0), $977 = 0, $978 = 0, $979 = 0, $98 = Math_fround(0), $980 = 0, $981 = 0, $982 = 0, $983 = Math_fround(0), $984 = 0, $985 = 0, $986 = Math_fround(0), $987 = 0;
 var $988 = 0, $989 = Math_fround(0), $99 = 0, $990 = 0, $991 = 0, $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $a$pn4$i = 0, $a$pn4$i163 = 0, $a$pn6$i = 0, $a$pn6$i167 = 0, $b$a$i = 0, $b$a$i161 = 0, $b$a7$i = 0;
 var $b$a7$i165 = 0, $currPtr$02955 = 0, $exitcond = 0, $exitcond3090 = 0, $i$02724 = 0, $i1$02807 = 0, $oldBroken = 0, $or$cond = 0, $prefetchAddress$0$be = 0, $prefetchAddress$02954 = 0, $prefetchAddress$1$lcssa = 0, $prefetchAddress$12725 = 0, $prefetchAddress$22806 = 0, $scevgep = 0, $scevgep3089 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $oldBroken = sp + 48|0;
 $4 = HEAP32[$desc>>2]|0;
 $5 = (($desc) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($desc) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($desc) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($desc) + 64|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($desc) + 68|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($desc) + 96|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($desc) + 100|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = Math_fround(HEAPF32[$4>>2]);
 $20 = (($4) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($4) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(HEAPF32[$6>>2]);
 $25 = (($6) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($6) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($4) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($29) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($29) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($6) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($35) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($35) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround(HEAPF32[$8>>2]);
 $42 = (($8) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($8) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround(HEAPF32[$10>>2]);
 $47 = (($10) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($10) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($8) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($51) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($51) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($10) + 16|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($57) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($57) + 8|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround(HEAPF32[$12>>2]);
 $64 = (($12) + 4|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($12) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround(HEAPF32[$14>>2]);
 $69 = (($14) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($14) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($12) + 16|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($73) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($73) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($14) + 16|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($79) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($79) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround(HEAPF32[$16>>2]);
 $86 = (($16) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($16) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround(HEAPF32[$18>>2]);
 $91 = (($18) + 4|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($18) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($16) + 16|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($95) + 4|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($95) + 8|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($18) + 16|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($101) + 4|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($101) + 8|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($desc) + 16|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($desc) + 26|0);
 $110 = HEAP16[$109>>1]|0;
 $111 = $110&65535;
 $112 = $111 << 4;
 $113 = (($108) + ($112)|0);
 $114 = ($110<<16>>16)==(0);
 if ($114) {
  $$lcssa2906 = $85;$$lcssa2907 = $63;$$lcssa2908 = $41;$$lcssa2909 = $19;$$lcssa2910 = $87;$$lcssa2911 = $65;$$lcssa2912 = $43;$$lcssa2913 = $21;$$lcssa2914 = $89;$$lcssa2915 = $67;$$lcssa2916 = $45;$$lcssa2917 = $23;$$lcssa2918 = $90;$$lcssa2919 = $68;$$lcssa2920 = $46;$$lcssa2921 = $24;$$lcssa2922 = $92;$$lcssa2923 = $70;$$lcssa2924 = $48;$$lcssa2925 = $26;$$lcssa2926 = $94;$$lcssa2927 = $72;$$lcssa2928 = $50;$$lcssa2929 = $28;$$lcssa2930 = $96;$$lcssa2931 = $74;$$lcssa2932 = $52;$$lcssa2933 = $30;$$lcssa2934 = $98;$$lcssa2935 = $76;$$lcssa2936 = $54;$$lcssa2937 = $32;$$lcssa2938 = $100;$$lcssa2939 = $78;$$lcssa2940 = $56;$$lcssa2941 = $34;$$lcssa2942 = $102;$$lcssa2943 = $80;$$lcssa2944 = $58;$$lcssa2945 = $36;$$lcssa2946 = $104;$$lcssa2947 = $82;$$lcssa2948 = $60;$$lcssa2949 = $38;$$lcssa2950 = $106;$$lcssa2951 = $84;$$lcssa2952 = $62;$$lcssa2953 = $40;
  HEAPF32[$4>>2] = $$lcssa2909;
  $1113 = (($4) + 4|0);
  HEAPF32[$1113>>2] = $$lcssa2913;
  $1114 = (($4) + 8|0);
  HEAPF32[$1114>>2] = $$lcssa2917;
  HEAPF32[$8>>2] = $$lcssa2908;
  $1115 = (($8) + 4|0);
  HEAPF32[$1115>>2] = $$lcssa2912;
  $1116 = (($8) + 8|0);
  HEAPF32[$1116>>2] = $$lcssa2916;
  HEAPF32[$12>>2] = $$lcssa2907;
  $1117 = (($12) + 4|0);
  HEAPF32[$1117>>2] = $$lcssa2911;
  $1118 = (($12) + 8|0);
  HEAPF32[$1118>>2] = $$lcssa2915;
  HEAPF32[$16>>2] = $$lcssa2906;
  $1119 = (($16) + 4|0);
  HEAPF32[$1119>>2] = $$lcssa2910;
  $1120 = (($16) + 8|0);
  HEAPF32[$1120>>2] = $$lcssa2914;
  HEAPF32[$6>>2] = $$lcssa2921;
  $1121 = (($6) + 4|0);
  HEAPF32[$1121>>2] = $$lcssa2925;
  $1122 = (($6) + 8|0);
  HEAPF32[$1122>>2] = $$lcssa2929;
  HEAPF32[$10>>2] = $$lcssa2920;
  $1123 = (($10) + 4|0);
  HEAPF32[$1123>>2] = $$lcssa2924;
  $1124 = (($10) + 8|0);
  HEAPF32[$1124>>2] = $$lcssa2928;
  HEAPF32[$14>>2] = $$lcssa2919;
  $1125 = (($14) + 4|0);
  HEAPF32[$1125>>2] = $$lcssa2923;
  $1126 = (($14) + 8|0);
  HEAPF32[$1126>>2] = $$lcssa2927;
  HEAPF32[$18>>2] = $$lcssa2918;
  $1127 = (($18) + 4|0);
  HEAPF32[$1127>>2] = $$lcssa2922;
  $1128 = (($18) + 8|0);
  HEAPF32[$1128>>2] = $$lcssa2926;
  HEAPF32[$29>>2] = $$lcssa2933;
  $1129 = (($4) + 20|0);
  HEAPF32[$1129>>2] = $$lcssa2937;
  $1130 = (($4) + 24|0);
  HEAPF32[$1130>>2] = $$lcssa2941;
  HEAPF32[$51>>2] = $$lcssa2932;
  $1131 = (($8) + 20|0);
  HEAPF32[$1131>>2] = $$lcssa2936;
  $1132 = (($8) + 24|0);
  HEAPF32[$1132>>2] = $$lcssa2940;
  HEAPF32[$73>>2] = $$lcssa2931;
  $1133 = (($12) + 20|0);
  HEAPF32[$1133>>2] = $$lcssa2935;
  $1134 = (($12) + 24|0);
  HEAPF32[$1134>>2] = $$lcssa2939;
  HEAPF32[$95>>2] = $$lcssa2930;
  $1135 = (($16) + 20|0);
  HEAPF32[$1135>>2] = $$lcssa2934;
  $1136 = (($16) + 24|0);
  HEAPF32[$1136>>2] = $$lcssa2938;
  HEAPF32[$35>>2] = $$lcssa2945;
  $1137 = (($6) + 20|0);
  HEAPF32[$1137>>2] = $$lcssa2949;
  $1138 = (($6) + 24|0);
  HEAPF32[$1138>>2] = $$lcssa2953;
  HEAPF32[$57>>2] = $$lcssa2944;
  $1139 = (($10) + 20|0);
  HEAPF32[$1139>>2] = $$lcssa2948;
  $1140 = (($10) + 24|0);
  HEAPF32[$1140>>2] = $$lcssa2952;
  HEAPF32[$79>>2] = $$lcssa2943;
  $1141 = (($14) + 20|0);
  HEAPF32[$1141>>2] = $$lcssa2947;
  $1142 = (($14) + 24|0);
  HEAPF32[$1142>>2] = $$lcssa2951;
  HEAPF32[$101>>2] = $$lcssa2942;
  $1143 = (($18) + 20|0);
  HEAPF32[$1143>>2] = $$lcssa2946;
  $1144 = (($18) + 24|0);
  HEAPF32[$1144>>2] = $$lcssa2950;
  STACKTOP = sp;return;
 }
 $115 = (($108) + 416|0);
 $116 = (($cache) + 1|0);
 $117 = (($1) + 4|0);
 $118 = (($1) + 8|0);
 $119 = (($1) + 12|0);
 $120 = (($0) + 4|0);
 $121 = (($0) + 8|0);
 $122 = (($0) + 12|0);
 $123 = (($3) + 4|0);
 $124 = (($3) + 8|0);
 $125 = (($3) + 12|0);
 $1145 = $40;$1146 = $62;$1147 = $84;$1148 = $106;$1149 = $38;$1150 = $60;$1151 = $82;$1152 = $104;$1153 = $36;$1154 = $58;$1155 = $80;$1156 = $102;$1157 = $34;$1158 = $56;$1159 = $78;$1160 = $100;$1161 = $32;$1162 = $54;$1163 = $76;$1164 = $98;$1165 = $30;$1166 = $52;$1167 = $74;$1168 = $96;$179 = $92;$181 = $70;$183 = $48;$185 = $26;$187 = $87;$189 = $65;$191 = $43;$193 = $21;$195 = $90;$197 = $68;$199 = $46;$201 = $24;$203 = $85;$205 = $63;$207 = $41;$209 = $19;$211 = $94;$213 = $72;$215 = $50;$217 = $28;$219 = $89;$221 = $67;$223 = $45;$225 = $23;$currPtr$02955 = $108;$prefetchAddress$02954 = $115;
 while(1) {
  $127 = (($currPtr$02955) + 144|0);
  $128 = (($currPtr$02955) + 1|0);
  $129 = HEAP8[$128>>0]|0;
  $130 = $129&255;
  $131 = (($currPtr$02955) + 2|0);
  $132 = HEAP8[$131>>0]|0;
  $133 = $132&255;
  $134 = (($127) + (($130*272)|0)|0);
  $135 = ($133*336)|0;
  $136 = (($134) + ($135)|0);
  $137 = (($currPtr$02955) + 64|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = (($currPtr$02955) + 68|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = (($currPtr$02955) + 72|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($currPtr$02955) + 76|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = (($currPtr$02955) + 80|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($currPtr$02955) + 84|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = (($currPtr$02955) + 88|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $151 = (($currPtr$02955) + 92|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = (($currPtr$02955) + 96|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = (($currPtr$02955) + 100|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = (($currPtr$02955) + 104|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = (($currPtr$02955) + 108|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = (($currPtr$02955) + 112|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = (($currPtr$02955) + 116|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = (($currPtr$02955) + 120|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($currPtr$02955) + 124|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($currPtr$02955) + 128|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = (($currPtr$02955) + 132|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = (($currPtr$02955) + 136|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = (($currPtr$02955) + 140|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = ($129<<24>>24)==(0);
  if ($177) {
   $$lcssa = $1168;$$lcssa2693 = $1167;$$lcssa2694 = $1166;$$lcssa2695 = $1165;$$lcssa2696 = $1164;$$lcssa2697 = $1163;$$lcssa2698 = $1162;$$lcssa2699 = $1161;$$lcssa2700 = $1160;$$lcssa2701 = $1159;$$lcssa2702 = $1158;$$lcssa2703 = $1157;$$lcssa2704 = $1156;$$lcssa2705 = $1155;$$lcssa2706 = $1154;$$lcssa2707 = $1153;$$lcssa2708 = $1152;$$lcssa2709 = $1151;$$lcssa2710 = $1150;$$lcssa2711 = $1149;$$lcssa2712 = $1148;$$lcssa2713 = $1147;$$lcssa2714 = $1146;$$lcssa2715 = $1145;$$lcssa2716 = Math_fround(0.0);$$lcssa2717 = Math_fround(0.0);$$lcssa2718 = Math_fround(0.0);$$lcssa2719 = Math_fround(0.0);$$lcssa2720 = Math_fround(0.0);$$lcssa2721 = Math_fround(0.0);$$lcssa2722 = Math_fround(0.0);$$lcssa2723 = Math_fround(0.0);$prefetchAddress$1$lcssa = $prefetchAddress$02954;
  } else {
   $178 = Math_fround($179 * $168);
   $180 = Math_fround($181 * $166);
   $182 = Math_fround($183 * $164);
   $184 = Math_fround($185 * $162);
   $186 = Math_fround($187 * $168);
   $188 = Math_fround($189 * $166);
   $190 = Math_fround($191 * $164);
   $192 = Math_fround($193 * $162);
   $194 = Math_fround($195 * $160);
   $196 = Math_fround($197 * $158);
   $198 = Math_fround($199 * $156);
   $200 = Math_fround($201 * $154);
   $202 = Math_fround($203 * $160);
   $204 = Math_fround($205 * $158);
   $206 = Math_fround($207 * $156);
   $208 = Math_fround($209 * $154);
   $210 = Math_fround($211 * $176);
   $212 = Math_fround($213 * $174);
   $214 = Math_fround($215 * $172);
   $216 = Math_fround($217 * $170);
   $218 = Math_fround($219 * $176);
   $220 = Math_fround($221 * $174);
   $222 = Math_fround($223 * $172);
   $224 = Math_fround($225 * $170);
   $226 = Math_fround($194 + $178);
   $227 = Math_fround($196 + $180);
   $228 = Math_fround($198 + $182);
   $229 = Math_fround($200 + $184);
   $230 = Math_fround($202 + $186);
   $231 = Math_fround($204 + $188);
   $232 = Math_fround($206 + $190);
   $233 = Math_fround($208 + $192);
   $234 = Math_fround($226 + $210);
   $235 = Math_fround($227 + $212);
   $236 = Math_fround($228 + $214);
   $237 = Math_fround($229 + $216);
   $238 = Math_fround($230 + $218);
   $239 = Math_fround($231 + $220);
   $240 = Math_fround($232 + $222);
   $241 = Math_fround($233 + $224);
   $242 = ($130*384)|0;
   $367 = $1165;$369 = $1166;$371 = $1167;$373 = $1168;$375 = $1153;$377 = $1154;$379 = $1155;$381 = $1156;$383 = $1161;$385 = $1162;$387 = $1163;$389 = $1164;$395 = $1149;$397 = $1150;$399 = $1151;$401 = $1152;$407 = $1157;$409 = $1158;$411 = $1159;$413 = $1160;$419 = $1145;$421 = $1146;$423 = $1147;$425 = $1148;$439 = $241;$441 = $240;$443 = $239;$445 = $238;$447 = $237;$449 = $236;$451 = $235;$453 = $234;$491 = Math_fround(0.0);$493 = Math_fround(0.0);$495 = Math_fround(0.0);$497 = Math_fround(0.0);$563 = Math_fround(0.0);$565 = Math_fround(0.0);$567 = Math_fround(0.0);$569 = Math_fround(0.0);$i$02724 = 0;$prefetchAddress$12725 = $prefetchAddress$02954;
   while(1) {
    $243 = (($prefetchAddress$12725) + 128|0);
    $244 = (($prefetchAddress$12725) + 256|0);
    $245 = (($prefetchAddress$12725) + 384|0);
    $246 = ((($127) + (($i$02724*272)|0)|0) + 48|0);
    $247 = Math_fround(HEAPF32[$246>>2]);
    $248 = ((($127) + (($i$02724*272)|0)|0) + 52|0);
    $249 = Math_fround(HEAPF32[$248>>2]);
    $250 = ((($127) + (($i$02724*272)|0)|0) + 56|0);
    $251 = Math_fround(HEAPF32[$250>>2]);
    $252 = ((($127) + (($i$02724*272)|0)|0) + 60|0);
    $253 = Math_fround(HEAPF32[$252>>2]);
    $254 = ((($127) + (($i$02724*272)|0)|0) + 64|0);
    $255 = Math_fround(HEAPF32[$254>>2]);
    $256 = ((($127) + (($i$02724*272)|0)|0) + 68|0);
    $257 = Math_fround(HEAPF32[$256>>2]);
    $258 = ((($127) + (($i$02724*272)|0)|0) + 72|0);
    $259 = Math_fround(HEAPF32[$258>>2]);
    $260 = ((($127) + (($i$02724*272)|0)|0) + 76|0);
    $261 = Math_fround(HEAPF32[$260>>2]);
    $262 = ((($127) + (($i$02724*272)|0)|0) + 80|0);
    $263 = Math_fround(HEAPF32[$262>>2]);
    $264 = ((($127) + (($i$02724*272)|0)|0) + 84|0);
    $265 = Math_fround(HEAPF32[$264>>2]);
    $266 = ((($127) + (($i$02724*272)|0)|0) + 88|0);
    $267 = Math_fround(HEAPF32[$266>>2]);
    $268 = ((($127) + (($i$02724*272)|0)|0) + 92|0);
    $269 = Math_fround(HEAPF32[$268>>2]);
    $270 = ((($127) + (($i$02724*272)|0)|0) + 224|0);
    $271 = Math_fround(HEAPF32[$270>>2]);
    $272 = ((($127) + (($i$02724*272)|0)|0) + 228|0);
    $273 = Math_fround(HEAPF32[$272>>2]);
    $274 = ((($127) + (($i$02724*272)|0)|0) + 232|0);
    $275 = Math_fround(HEAPF32[$274>>2]);
    $276 = ((($127) + (($i$02724*272)|0)|0) + 236|0);
    $277 = Math_fround(HEAPF32[$276>>2]);
    $278 = ((($127) + (($i$02724*272)|0)|0) + 240|0);
    $279 = Math_fround(HEAPF32[$278>>2]);
    $280 = ((($127) + (($i$02724*272)|0)|0) + 244|0);
    $281 = Math_fround(HEAPF32[$280>>2]);
    $282 = ((($127) + (($i$02724*272)|0)|0) + 248|0);
    $283 = Math_fround(HEAPF32[$282>>2]);
    $284 = ((($127) + (($i$02724*272)|0)|0) + 252|0);
    $285 = Math_fround(HEAPF32[$284>>2]);
    $286 = ((($127) + (($i$02724*272)|0)|0) + 256|0);
    $287 = Math_fround(HEAPF32[$286>>2]);
    $288 = ((($127) + (($i$02724*272)|0)|0) + 260|0);
    $289 = Math_fround(HEAPF32[$288>>2]);
    $290 = ((($127) + (($i$02724*272)|0)|0) + 264|0);
    $291 = Math_fround(HEAPF32[$290>>2]);
    $292 = ((($127) + (($i$02724*272)|0)|0) + 268|0);
    $293 = Math_fround(HEAPF32[$292>>2]);
    $294 = ((($127) + (($i$02724*272)|0)|0) + 112|0);
    $295 = Math_fround(HEAPF32[$294>>2]);
    $296 = ((($127) + (($i$02724*272)|0)|0) + 116|0);
    $297 = Math_fround(HEAPF32[$296>>2]);
    $298 = ((($127) + (($i$02724*272)|0)|0) + 120|0);
    $299 = Math_fround(HEAPF32[$298>>2]);
    $300 = ((($127) + (($i$02724*272)|0)|0) + 124|0);
    $301 = Math_fround(HEAPF32[$300>>2]);
    $302 = ((($127) + (($i$02724*272)|0)|0) + 96|0);
    $303 = Math_fround(HEAPF32[$302>>2]);
    $304 = ((($127) + (($i$02724*272)|0)|0) + 100|0);
    $305 = Math_fround(HEAPF32[$304>>2]);
    $306 = ((($127) + (($i$02724*272)|0)|0) + 104|0);
    $307 = Math_fround(HEAPF32[$306>>2]);
    $308 = ((($127) + (($i$02724*272)|0)|0) + 108|0);
    $309 = Math_fround(HEAPF32[$308>>2]);
    $310 = ((($127) + (($i$02724*272)|0)|0) + 160|0);
    $311 = Math_fround(HEAPF32[$310>>2]);
    $312 = ((($127) + (($i$02724*272)|0)|0) + 164|0);
    $313 = Math_fround(HEAPF32[$312>>2]);
    $314 = ((($127) + (($i$02724*272)|0)|0) + 168|0);
    $315 = Math_fround(HEAPF32[$314>>2]);
    $316 = ((($127) + (($i$02724*272)|0)|0) + 172|0);
    $317 = Math_fround(HEAPF32[$316>>2]);
    $318 = (($127) + (($i$02724*272)|0)|0);
    $319 = Math_fround(HEAPF32[$318>>2]);
    $320 = ((($127) + (($i$02724*272)|0)|0) + 4|0);
    $321 = Math_fround(HEAPF32[$320>>2]);
    $322 = ((($127) + (($i$02724*272)|0)|0) + 8|0);
    $323 = Math_fround(HEAPF32[$322>>2]);
    $324 = ((($127) + (($i$02724*272)|0)|0) + 12|0);
    $325 = Math_fround(HEAPF32[$324>>2]);
    $326 = ((($127) + (($i$02724*272)|0)|0) + 16|0);
    $327 = Math_fround(HEAPF32[$326>>2]);
    $328 = ((($127) + (($i$02724*272)|0)|0) + 20|0);
    $329 = Math_fround(HEAPF32[$328>>2]);
    $330 = ((($127) + (($i$02724*272)|0)|0) + 24|0);
    $331 = Math_fround(HEAPF32[$330>>2]);
    $332 = ((($127) + (($i$02724*272)|0)|0) + 28|0);
    $333 = Math_fround(HEAPF32[$332>>2]);
    $334 = ((($127) + (($i$02724*272)|0)|0) + 32|0);
    $335 = Math_fround(HEAPF32[$334>>2]);
    $336 = ((($127) + (($i$02724*272)|0)|0) + 36|0);
    $337 = Math_fround(HEAPF32[$336>>2]);
    $338 = ((($127) + (($i$02724*272)|0)|0) + 40|0);
    $339 = Math_fround(HEAPF32[$338>>2]);
    $340 = ((($127) + (($i$02724*272)|0)|0) + 44|0);
    $341 = Math_fround(HEAPF32[$340>>2]);
    $342 = ((($127) + (($i$02724*272)|0)|0) + 176|0);
    $343 = Math_fround(HEAPF32[$342>>2]);
    $344 = ((($127) + (($i$02724*272)|0)|0) + 180|0);
    $345 = Math_fround(HEAPF32[$344>>2]);
    $346 = ((($127) + (($i$02724*272)|0)|0) + 184|0);
    $347 = Math_fround(HEAPF32[$346>>2]);
    $348 = ((($127) + (($i$02724*272)|0)|0) + 188|0);
    $349 = Math_fround(HEAPF32[$348>>2]);
    $350 = ((($127) + (($i$02724*272)|0)|0) + 192|0);
    $351 = Math_fround(HEAPF32[$350>>2]);
    $352 = ((($127) + (($i$02724*272)|0)|0) + 196|0);
    $353 = Math_fround(HEAPF32[$352>>2]);
    $354 = ((($127) + (($i$02724*272)|0)|0) + 200|0);
    $355 = Math_fround(HEAPF32[$354>>2]);
    $356 = ((($127) + (($i$02724*272)|0)|0) + 204|0);
    $357 = Math_fround(HEAPF32[$356>>2]);
    $358 = ((($127) + (($i$02724*272)|0)|0) + 208|0);
    $359 = Math_fround(HEAPF32[$358>>2]);
    $360 = ((($127) + (($i$02724*272)|0)|0) + 212|0);
    $361 = Math_fround(HEAPF32[$360>>2]);
    $362 = ((($127) + (($i$02724*272)|0)|0) + 216|0);
    $363 = Math_fround(HEAPF32[$362>>2]);
    $364 = ((($127) + (($i$02724*272)|0)|0) + 220|0);
    $365 = Math_fround(HEAPF32[$364>>2]);
    $366 = Math_fround($367 * $319);
    $368 = Math_fround($369 * $321);
    $370 = Math_fround($371 * $323);
    $372 = Math_fround($373 * $325);
    $374 = Math_fround($375 * $343);
    $376 = Math_fround($377 * $345);
    $378 = Math_fround($379 * $347);
    $380 = Math_fround($381 * $349);
    $382 = Math_fround($383 * $327);
    $384 = Math_fround($385 * $329);
    $386 = Math_fround($387 * $331);
    $388 = Math_fround($389 * $333);
    $390 = Math_fround($366 + $382);
    $391 = Math_fround($368 + $384);
    $392 = Math_fround($370 + $386);
    $393 = Math_fround($372 + $388);
    $394 = Math_fround($395 * $351);
    $396 = Math_fround($397 * $353);
    $398 = Math_fround($399 * $355);
    $400 = Math_fround($401 * $357);
    $402 = Math_fround($374 + $394);
    $403 = Math_fround($376 + $396);
    $404 = Math_fround($378 + $398);
    $405 = Math_fround($380 + $400);
    $406 = Math_fround($407 * $335);
    $408 = Math_fround($409 * $337);
    $410 = Math_fround($411 * $339);
    $412 = Math_fround($413 * $341);
    $414 = Math_fround($390 + $406);
    $415 = Math_fround($391 + $408);
    $416 = Math_fround($392 + $410);
    $417 = Math_fround($393 + $412);
    $418 = Math_fround($419 * $359);
    $420 = Math_fround($421 * $361);
    $422 = Math_fround($423 * $363);
    $424 = Math_fround($425 * $365);
    $426 = Math_fround($402 + $418);
    $427 = Math_fround($403 + $420);
    $428 = Math_fround($404 + $422);
    $429 = Math_fround($405 + $424);
    $430 = ((($127) + (($i$02724*272)|0)|0) + 144|0);
    $431 = Math_fround(HEAPF32[$430>>2]);
    $432 = ((($127) + (($i$02724*272)|0)|0) + 148|0);
    $433 = Math_fround(HEAPF32[$432>>2]);
    $434 = ((($127) + (($i$02724*272)|0)|0) + 152|0);
    $435 = Math_fround(HEAPF32[$434>>2]);
    $436 = ((($127) + (($i$02724*272)|0)|0) + 156|0);
    $437 = Math_fround(HEAPF32[$436>>2]);
    $438 = Math_fround($439 + $414);
    $440 = Math_fround($441 + $415);
    $442 = Math_fround($443 + $416);
    $444 = Math_fround($445 + $417);
    $446 = Math_fround($447 + $426);
    $448 = Math_fround($449 + $427);
    $450 = Math_fround($451 + $428);
    $452 = Math_fround($453 + $429);
    $454 = Math_fround($438 - $446);
    $455 = Math_fround($440 - $448);
    $456 = Math_fround($442 - $450);
    $457 = Math_fround($444 - $452);
    $458 = Math_fround($303 * $454);
    $459 = Math_fround($305 * $455);
    $460 = Math_fround($307 * $456);
    $461 = Math_fround($309 * $457);
    $462 = Math_fround($431 - $458);
    $463 = Math_fround($433 - $459);
    $464 = Math_fround($435 - $460);
    $465 = Math_fround($437 - $461);
    $466 = Math_fround(-$295);
    $467 = Math_fround(-$297);
    $468 = Math_fround(-$299);
    $469 = Math_fround(-$301);
    $470 = $462 > $466;
    $$$i399 = $470 ? $462 : $466;
    $471 = $463 > $467;
    $472 = $471 ? $463 : $467;
    $473 = $464 > $468;
    $$1$i400 = $473 ? $464 : $468;
    $474 = $465 > $469;
    $475 = $474 ? $465 : $469;
    $476 = Math_fround($295 + $$$i399);
    $477 = Math_fround($297 + $472);
    $478 = Math_fround($299 + $$1$i400);
    $479 = Math_fround($301 + $475);
    $480 = $476 < $311;
    $$$i389 = $480 ? $476 : $311;
    $481 = $477 < $313;
    $482 = $481 ? $477 : $313;
    $483 = $478 < $315;
    $$1$i390 = $483 ? $478 : $315;
    $484 = $479 < $317;
    $485 = $484 ? $479 : $317;
    $486 = Math_fround($$$i389 - $295);
    $487 = Math_fround($482 - $297);
    $488 = Math_fround($$1$i390 - $299);
    $489 = Math_fround($485 - $301);
    $490 = Math_fround($491 + $486);
    $492 = Math_fround($493 + $487);
    $494 = Math_fround($495 + $488);
    $496 = Math_fround($497 + $489);
    $498 = Math_fround($138 * $486);
    $499 = Math_fround($140 * $487);
    $500 = Math_fround($142 * $488);
    $501 = Math_fround($144 * $489);
    $502 = Math_fround($439 + $498);
    $503 = Math_fround($441 + $499);
    $504 = Math_fround($443 + $500);
    $505 = Math_fround($445 + $501);
    $506 = Math_fround($146 * $486);
    $507 = Math_fround($148 * $487);
    $508 = Math_fround($150 * $488);
    $509 = Math_fround($152 * $489);
    $510 = Math_fround($447 + $506);
    $511 = Math_fround($449 + $507);
    $512 = Math_fround($451 + $508);
    $513 = Math_fround($453 + $509);
    $514 = Math_fround($247 * $486);
    $515 = Math_fround($249 * $487);
    $516 = Math_fround($251 * $488);
    $517 = Math_fround($253 * $489);
    $518 = Math_fround($367 + $514);
    $519 = Math_fround($369 + $515);
    $520 = Math_fround($371 + $516);
    $521 = Math_fround($373 + $517);
    $522 = Math_fround($271 * $486);
    $523 = Math_fround($273 * $487);
    $524 = Math_fround($275 * $488);
    $525 = Math_fround($277 * $489);
    $526 = Math_fround($375 + $522);
    $527 = Math_fround($377 + $523);
    $528 = Math_fround($379 + $524);
    $529 = Math_fround($381 + $525);
    $530 = Math_fround($255 * $486);
    $531 = Math_fround($257 * $487);
    $532 = Math_fround($259 * $488);
    $533 = Math_fround($261 * $489);
    $534 = Math_fround($383 + $530);
    $535 = Math_fround($385 + $531);
    $536 = Math_fround($387 + $532);
    $537 = Math_fround($389 + $533);
    $538 = Math_fround($279 * $486);
    $539 = Math_fround($281 * $487);
    $540 = Math_fround($283 * $488);
    $541 = Math_fround($285 * $489);
    $542 = Math_fround($395 + $538);
    $543 = Math_fround($397 + $539);
    $544 = Math_fround($399 + $540);
    $545 = Math_fround($401 + $541);
    $546 = Math_fround($263 * $486);
    $547 = Math_fround($265 * $487);
    $548 = Math_fround($267 * $488);
    $549 = Math_fround($269 * $489);
    $550 = Math_fround($407 + $546);
    $551 = Math_fround($409 + $547);
    $552 = Math_fround($411 + $548);
    $553 = Math_fround($413 + $549);
    $554 = Math_fround($287 * $486);
    $555 = Math_fround($289 * $487);
    $556 = Math_fround($291 * $488);
    $557 = Math_fround($293 * $489);
    $558 = Math_fround($419 + $554);
    $559 = Math_fround($421 + $555);
    $560 = Math_fround($423 + $556);
    $561 = Math_fround($425 + $557);
    HEAPF32[$294>>2] = $$$i389;
    HEAPF32[$296>>2] = $482;
    HEAPF32[$298>>2] = $$1$i390;
    HEAPF32[$300>>2] = $485;
    $562 = Math_fround($563 + $$$i389);
    $564 = Math_fround($565 + $482);
    $566 = Math_fround($567 + $$1$i390);
    $568 = Math_fround($569 + $485);
    $570 = (($i$02724) + 1)|0;
    $exitcond = ($570|0)==($130|0);
    if ($exitcond) {
     break;
    } else {
     $367 = $518;$369 = $519;$371 = $520;$373 = $521;$375 = $526;$377 = $527;$379 = $528;$381 = $529;$383 = $534;$385 = $535;$387 = $536;$389 = $537;$395 = $542;$397 = $543;$399 = $544;$401 = $545;$407 = $550;$409 = $551;$411 = $552;$413 = $553;$419 = $558;$421 = $559;$423 = $560;$425 = $561;$439 = $502;$441 = $503;$443 = $504;$445 = $505;$447 = $510;$449 = $511;$451 = $512;$453 = $513;$491 = $490;$493 = $492;$495 = $494;$497 = $496;$563 = $562;$565 = $564;$567 = $566;$569 = $568;$i$02724 = $570;$prefetchAddress$12725 = $245;
    }
   }
   $scevgep = (($prefetchAddress$02954) + ($242)|0);
   $$lcssa = $521;$$lcssa2693 = $520;$$lcssa2694 = $519;$$lcssa2695 = $518;$$lcssa2696 = $537;$$lcssa2697 = $536;$$lcssa2698 = $535;$$lcssa2699 = $534;$$lcssa2700 = $553;$$lcssa2701 = $552;$$lcssa2702 = $551;$$lcssa2703 = $550;$$lcssa2704 = $529;$$lcssa2705 = $528;$$lcssa2706 = $527;$$lcssa2707 = $526;$$lcssa2708 = $545;$$lcssa2709 = $544;$$lcssa2710 = $543;$$lcssa2711 = $542;$$lcssa2712 = $561;$$lcssa2713 = $560;$$lcssa2714 = $559;$$lcssa2715 = $558;$$lcssa2716 = $568;$$lcssa2717 = $566;$$lcssa2718 = $564;$$lcssa2719 = $562;$$lcssa2720 = $496;$$lcssa2721 = $494;$$lcssa2722 = $492;$$lcssa2723 = $490;$prefetchAddress$1$lcssa = $scevgep;
  }
  $571 = Math_fround($138 * $$lcssa2723);
  $572 = Math_fround($140 * $$lcssa2722);
  $573 = Math_fround($142 * $$lcssa2721);
  $574 = Math_fround($144 * $$lcssa2720);
  $575 = Math_fround($146 * $$lcssa2723);
  $576 = Math_fround($148 * $$lcssa2722);
  $577 = Math_fround($150 * $$lcssa2721);
  $578 = Math_fround($152 * $$lcssa2720);
  $579 = Math_fround($154 * $571);
  $580 = Math_fround($156 * $572);
  $581 = Math_fround($158 * $573);
  $582 = Math_fround($160 * $574);
  $583 = Math_fround($209 + $579);
  $584 = Math_fround($207 + $580);
  $585 = Math_fround($205 + $581);
  $586 = Math_fround($203 + $582);
  $587 = Math_fround($154 * $575);
  $588 = Math_fround($156 * $576);
  $589 = Math_fround($158 * $577);
  $590 = Math_fround($160 * $578);
  $591 = Math_fround($201 + $587);
  $592 = Math_fround($199 + $588);
  $593 = Math_fround($197 + $589);
  $594 = Math_fround($195 + $590);
  $595 = Math_fround($162 * $571);
  $596 = Math_fround($164 * $572);
  $597 = Math_fround($166 * $573);
  $598 = Math_fround($168 * $574);
  $599 = Math_fround($193 + $595);
  $600 = Math_fround($191 + $596);
  $601 = Math_fround($189 + $597);
  $602 = Math_fround($187 + $598);
  $603 = Math_fround($162 * $575);
  $604 = Math_fround($164 * $576);
  $605 = Math_fround($166 * $577);
  $606 = Math_fround($168 * $578);
  $607 = Math_fround($185 + $603);
  $608 = Math_fround($183 + $604);
  $609 = Math_fround($181 + $605);
  $610 = Math_fround($179 + $606);
  $611 = Math_fround($170 * $571);
  $612 = Math_fround($172 * $572);
  $613 = Math_fround($174 * $573);
  $614 = Math_fround($176 * $574);
  $615 = Math_fround($225 + $611);
  $616 = Math_fround($223 + $612);
  $617 = Math_fround($221 + $613);
  $618 = Math_fround($219 + $614);
  $619 = Math_fround($170 * $575);
  $620 = Math_fround($172 * $576);
  $621 = Math_fround($174 * $577);
  $622 = Math_fround($176 * $578);
  $623 = Math_fround($217 + $619);
  $624 = Math_fround($215 + $620);
  $625 = Math_fround($213 + $621);
  $626 = Math_fround($211 + $622);
  $627 = HEAP8[$cache>>0]|0;
  $628 = ($627<<24>>24)==(0);
  $629 = ($132<<24>>24)==(0);
  $or$cond = $628 | $629;
  if ($or$cond) {
   $$be = $586;$$be2859 = $585;$$be2860 = $584;$$be2861 = $583;$$be2862 = $602;$$be2863 = $601;$$be2864 = $600;$$be2865 = $599;$$be2866 = $618;$$be2867 = $617;$$be2868 = $616;$$be2869 = $615;$$be2870 = $594;$$be2871 = $593;$$be2872 = $592;$$be2873 = $591;$$be2874 = $610;$$be2875 = $609;$$be2876 = $608;$$be2877 = $607;$$be2878 = $626;$$be2879 = $625;$$be2880 = $624;$$be2881 = $623;$$be2882 = $$lcssa;$$be2883 = $$lcssa2693;$$be2884 = $$lcssa2694;$$be2885 = $$lcssa2695;$$be2886 = $$lcssa2696;$$be2887 = $$lcssa2697;$$be2888 = $$lcssa2698;$$be2889 = $$lcssa2699;$$be2890 = $$lcssa2700;$$be2891 = $$lcssa2701;$$be2892 = $$lcssa2702;$$be2893 = $$lcssa2703;$$be2894 = $$lcssa2704;$$be2895 = $$lcssa2705;$$be2896 = $$lcssa2706;$$be2897 = $$lcssa2707;$$be2898 = $$lcssa2708;$$be2899 = $$lcssa2709;$$be2900 = $$lcssa2710;$$be2901 = $$lcssa2711;$$be2902 = $$lcssa2712;$$be2903 = $$lcssa2713;$$be2904 = $$lcssa2714;$$be2905 = $$lcssa2715;$prefetchAddress$0$be = $prefetchAddress$1$lcssa;
  } else {
   $631 = (($currPtr$02955) + 32|0);
   $632 = Math_fround(HEAPF32[$631>>2]);
   $633 = (($currPtr$02955) + 36|0);
   $634 = Math_fround(HEAPF32[$633>>2]);
   $635 = (($currPtr$02955) + 40|0);
   $636 = Math_fround(HEAPF32[$635>>2]);
   $637 = (($currPtr$02955) + 44|0);
   $638 = Math_fround(HEAPF32[$637>>2]);
   $639 = (($currPtr$02955) + 48|0);
   $640 = Math_fround(HEAPF32[$639>>2]);
   $641 = (($currPtr$02955) + 52|0);
   $642 = Math_fround(HEAPF32[$641>>2]);
   $643 = (($currPtr$02955) + 56|0);
   $644 = Math_fround(HEAPF32[$643>>2]);
   $645 = (($currPtr$02955) + 60|0);
   $646 = Math_fround(HEAPF32[$645>>2]);
   $647 = Math_fround($$lcssa2719 * $632);
   $648 = Math_fround($$lcssa2718 * $634);
   $649 = Math_fround($$lcssa2717 * $636);
   $650 = Math_fround($$lcssa2716 * $638);
   $651 = Math_fround($$lcssa2719 * $640);
   $652 = Math_fround($$lcssa2718 * $642);
   $653 = Math_fround($$lcssa2717 * $644);
   $654 = Math_fround($$lcssa2716 * $646);
   $655 = Math_fround(-$651);
   $656 = Math_fround(-$652);
   $657 = Math_fround(-$653);
   $658 = Math_fround(-$654);
   $126 = ($133*384)|0;
   $808 = $583;$810 = $584;$812 = $585;$814 = $586;$816 = $$lcssa2695;$818 = $$lcssa2694;$820 = $$lcssa2693;$822 = $$lcssa;$824 = $591;$826 = $592;$828 = $593;$830 = $594;$832 = $$lcssa2707;$834 = $$lcssa2706;$836 = $$lcssa2705;$838 = $$lcssa2704;$840 = $599;$842 = $600;$844 = $601;$846 = $602;$852 = $$lcssa2699;$854 = $$lcssa2698;$856 = $$lcssa2697;$858 = $$lcssa2696;$864 = $607;$866 = $608;$868 = $609;$870 = $610;$876 = $$lcssa2711;$878 = $$lcssa2710;$880 = $$lcssa2709;$882 = $$lcssa2708;$888 = $615;$890 = $616;$892 = $617;$894 = $618;$900 = $$lcssa2703;$902 = $$lcssa2702;$904 = $$lcssa2701;$906 = $$lcssa2700;$912 = $623;$914 = $624;$916 = $625;$918 = $626;$924 = $$lcssa2715;$926 = $$lcssa2714;$928 = $$lcssa2713;$930 = $$lcssa2712;$i1$02807 = 0;$prefetchAddress$22806 = $prefetchAddress$1$lcssa;
   while(1) {
    $659 = (($prefetchAddress$22806) + 384|0);
    $660 = HEAP8[$116>>0]|0;
    $661 = ($660<<24>>24)==(0);
    if (!($661)) {
     $662 = ((($134) + (($i1$02807*336)|0)|0) + 224|0);
     $663 = HEAP32[$662>>2]|0;
     $664 = ((($134) + (($i1$02807*336)|0)|0) + 228|0);
     $665 = HEAP32[$664>>2]|0;
     $666 = ((($134) + (($i1$02807*336)|0)|0) + 232|0);
     $667 = HEAP32[$666>>2]|0;
     $668 = ((($134) + (($i1$02807*336)|0)|0) + 236|0);
     $669 = HEAP32[$668>>2]|0;
    }
    $670 = ((($134) + (($i1$02807*336)|0)|0) + 112|0);
    $671 = Math_fround(HEAPF32[$670>>2]);
    $672 = ((($134) + (($i1$02807*336)|0)|0) + 116|0);
    $673 = Math_fround(HEAPF32[$672>>2]);
    $674 = ((($134) + (($i1$02807*336)|0)|0) + 120|0);
    $675 = Math_fround(HEAPF32[$674>>2]);
    $676 = ((($134) + (($i1$02807*336)|0)|0) + 124|0);
    $677 = Math_fround(HEAPF32[$676>>2]);
    $678 = ((($134) + (($i1$02807*336)|0)|0) + 128|0);
    $679 = Math_fround(HEAPF32[$678>>2]);
    $680 = ((($134) + (($i1$02807*336)|0)|0) + 132|0);
    $681 = Math_fround(HEAPF32[$680>>2]);
    $682 = ((($134) + (($i1$02807*336)|0)|0) + 136|0);
    $683 = Math_fround(HEAPF32[$682>>2]);
    $684 = ((($134) + (($i1$02807*336)|0)|0) + 140|0);
    $685 = Math_fround(HEAPF32[$684>>2]);
    $686 = ((($134) + (($i1$02807*336)|0)|0) + 144|0);
    $687 = Math_fround(HEAPF32[$686>>2]);
    $688 = ((($134) + (($i1$02807*336)|0)|0) + 148|0);
    $689 = Math_fround(HEAPF32[$688>>2]);
    $690 = ((($134) + (($i1$02807*336)|0)|0) + 152|0);
    $691 = Math_fround(HEAPF32[$690>>2]);
    $692 = ((($134) + (($i1$02807*336)|0)|0) + 156|0);
    $693 = Math_fround(HEAPF32[$692>>2]);
    $694 = ((($134) + (($i1$02807*336)|0)|0) + 288|0);
    $695 = Math_fround(HEAPF32[$694>>2]);
    $696 = ((($134) + (($i1$02807*336)|0)|0) + 292|0);
    $697 = Math_fround(HEAPF32[$696>>2]);
    $698 = ((($134) + (($i1$02807*336)|0)|0) + 296|0);
    $699 = Math_fround(HEAPF32[$698>>2]);
    $700 = ((($134) + (($i1$02807*336)|0)|0) + 300|0);
    $701 = Math_fround(HEAPF32[$700>>2]);
    $702 = ((($134) + (($i1$02807*336)|0)|0) + 304|0);
    $703 = Math_fround(HEAPF32[$702>>2]);
    $704 = ((($134) + (($i1$02807*336)|0)|0) + 308|0);
    $705 = Math_fround(HEAPF32[$704>>2]);
    $706 = ((($134) + (($i1$02807*336)|0)|0) + 312|0);
    $707 = Math_fround(HEAPF32[$706>>2]);
    $708 = ((($134) + (($i1$02807*336)|0)|0) + 316|0);
    $709 = Math_fround(HEAPF32[$708>>2]);
    $710 = ((($134) + (($i1$02807*336)|0)|0) + 320|0);
    $711 = Math_fround(HEAPF32[$710>>2]);
    $712 = ((($134) + (($i1$02807*336)|0)|0) + 324|0);
    $713 = Math_fround(HEAPF32[$712>>2]);
    $714 = ((($134) + (($i1$02807*336)|0)|0) + 328|0);
    $715 = Math_fround(HEAPF32[$714>>2]);
    $716 = ((($134) + (($i1$02807*336)|0)|0) + 332|0);
    $717 = Math_fround(HEAPF32[$716>>2]);
    $718 = ((($134) + (($i1$02807*336)|0)|0) + 48|0);
    $719 = Math_fround(HEAPF32[$718>>2]);
    $720 = ((($134) + (($i1$02807*336)|0)|0) + 52|0);
    $721 = Math_fround(HEAPF32[$720>>2]);
    $722 = ((($134) + (($i1$02807*336)|0)|0) + 56|0);
    $723 = Math_fround(HEAPF32[$722>>2]);
    $724 = ((($134) + (($i1$02807*336)|0)|0) + 60|0);
    $725 = Math_fround(HEAPF32[$724>>2]);
    $726 = ((($134) + (($i1$02807*336)|0)|0) + 208|0);
    $727 = Math_fround(HEAPF32[$726>>2]);
    $728 = ((($134) + (($i1$02807*336)|0)|0) + 212|0);
    $729 = Math_fround(HEAPF32[$728>>2]);
    $730 = ((($134) + (($i1$02807*336)|0)|0) + 216|0);
    $731 = Math_fround(HEAPF32[$730>>2]);
    $732 = ((($134) + (($i1$02807*336)|0)|0) + 220|0);
    $733 = Math_fround(HEAPF32[$732>>2]);
    $734 = (($134) + (($i1$02807*336)|0)|0);
    $735 = Math_fround(HEAPF32[$734>>2]);
    $736 = ((($134) + (($i1$02807*336)|0)|0) + 4|0);
    $737 = Math_fround(HEAPF32[$736>>2]);
    $738 = ((($134) + (($i1$02807*336)|0)|0) + 8|0);
    $739 = Math_fround(HEAPF32[$738>>2]);
    $740 = ((($134) + (($i1$02807*336)|0)|0) + 12|0);
    $741 = Math_fround(HEAPF32[$740>>2]);
    $742 = ((($134) + (($i1$02807*336)|0)|0) + 16|0);
    $743 = Math_fround(HEAPF32[$742>>2]);
    $744 = ((($134) + (($i1$02807*336)|0)|0) + 20|0);
    $745 = Math_fround(HEAPF32[$744>>2]);
    $746 = ((($134) + (($i1$02807*336)|0)|0) + 24|0);
    $747 = Math_fround(HEAPF32[$746>>2]);
    $748 = ((($134) + (($i1$02807*336)|0)|0) + 28|0);
    $749 = Math_fround(HEAPF32[$748>>2]);
    $750 = ((($134) + (($i1$02807*336)|0)|0) + 32|0);
    $751 = Math_fround(HEAPF32[$750>>2]);
    $752 = ((($134) + (($i1$02807*336)|0)|0) + 36|0);
    $753 = Math_fround(HEAPF32[$752>>2]);
    $754 = ((($134) + (($i1$02807*336)|0)|0) + 40|0);
    $755 = Math_fround(HEAPF32[$754>>2]);
    $756 = ((($134) + (($i1$02807*336)|0)|0) + 44|0);
    $757 = Math_fround(HEAPF32[$756>>2]);
    $758 = ((($134) + (($i1$02807*336)|0)|0) + 64|0);
    $759 = Math_fround(HEAPF32[$758>>2]);
    $760 = ((($134) + (($i1$02807*336)|0)|0) + 68|0);
    $761 = Math_fround(HEAPF32[$760>>2]);
    $762 = ((($134) + (($i1$02807*336)|0)|0) + 72|0);
    $763 = Math_fround(HEAPF32[$762>>2]);
    $764 = ((($134) + (($i1$02807*336)|0)|0) + 76|0);
    $765 = Math_fround(HEAPF32[$764>>2]);
    $766 = ((($134) + (($i1$02807*336)|0)|0) + 80|0);
    $767 = Math_fround(HEAPF32[$766>>2]);
    $768 = ((($134) + (($i1$02807*336)|0)|0) + 84|0);
    $769 = Math_fround(HEAPF32[$768>>2]);
    $770 = ((($134) + (($i1$02807*336)|0)|0) + 88|0);
    $771 = Math_fround(HEAPF32[$770>>2]);
    $772 = ((($134) + (($i1$02807*336)|0)|0) + 92|0);
    $773 = Math_fround(HEAPF32[$772>>2]);
    $774 = ((($134) + (($i1$02807*336)|0)|0) + 96|0);
    $775 = Math_fround(HEAPF32[$774>>2]);
    $776 = ((($134) + (($i1$02807*336)|0)|0) + 100|0);
    $777 = Math_fround(HEAPF32[$776>>2]);
    $778 = ((($134) + (($i1$02807*336)|0)|0) + 104|0);
    $779 = Math_fround(HEAPF32[$778>>2]);
    $780 = ((($134) + (($i1$02807*336)|0)|0) + 108|0);
    $781 = Math_fround(HEAPF32[$780>>2]);
    $782 = ((($134) + (($i1$02807*336)|0)|0) + 240|0);
    $783 = Math_fround(HEAPF32[$782>>2]);
    $784 = ((($134) + (($i1$02807*336)|0)|0) + 244|0);
    $785 = Math_fround(HEAPF32[$784>>2]);
    $786 = ((($134) + (($i1$02807*336)|0)|0) + 248|0);
    $787 = Math_fround(HEAPF32[$786>>2]);
    $788 = ((($134) + (($i1$02807*336)|0)|0) + 252|0);
    $789 = Math_fround(HEAPF32[$788>>2]);
    $790 = ((($134) + (($i1$02807*336)|0)|0) + 256|0);
    $791 = Math_fround(HEAPF32[$790>>2]);
    $792 = ((($134) + (($i1$02807*336)|0)|0) + 260|0);
    $793 = Math_fround(HEAPF32[$792>>2]);
    $794 = ((($134) + (($i1$02807*336)|0)|0) + 264|0);
    $795 = Math_fround(HEAPF32[$794>>2]);
    $796 = ((($134) + (($i1$02807*336)|0)|0) + 268|0);
    $797 = Math_fround(HEAPF32[$796>>2]);
    $798 = ((($134) + (($i1$02807*336)|0)|0) + 272|0);
    $799 = Math_fround(HEAPF32[$798>>2]);
    $800 = ((($134) + (($i1$02807*336)|0)|0) + 276|0);
    $801 = Math_fround(HEAPF32[$800>>2]);
    $802 = ((($134) + (($i1$02807*336)|0)|0) + 280|0);
    $803 = Math_fround(HEAPF32[$802>>2]);
    $804 = ((($134) + (($i1$02807*336)|0)|0) + 284|0);
    $805 = Math_fround(HEAPF32[$804>>2]);
    $806 = ((($134) + (($i1$02807*336)|0)|0) + 176|0);
    ;HEAP32[$oldBroken+0>>2]=HEAP32[$806+0>>2]|0;HEAP32[$oldBroken+4>>2]=HEAP32[$806+4>>2]|0;HEAP32[$oldBroken+8>>2]=HEAP32[$806+8>>2]|0;HEAP32[$oldBroken+12>>2]=HEAP32[$806+12>>2]|0;
    $807 = Math_fround($808 * $735);
    $809 = Math_fround($810 * $737);
    $811 = Math_fround($812 * $739);
    $813 = Math_fround($814 * $741);
    $815 = Math_fround($816 * $759);
    $817 = Math_fround($818 * $761);
    $819 = Math_fround($820 * $763);
    $821 = Math_fround($822 * $765);
    $823 = Math_fround($824 * $735);
    $825 = Math_fround($826 * $737);
    $827 = Math_fround($828 * $739);
    $829 = Math_fround($830 * $741);
    $831 = Math_fround($832 * $783);
    $833 = Math_fround($834 * $785);
    $835 = Math_fround($836 * $787);
    $837 = Math_fround($838 * $789);
    $839 = Math_fround($840 * $743);
    $841 = Math_fround($842 * $745);
    $843 = Math_fround($844 * $747);
    $845 = Math_fround($846 * $749);
    $847 = Math_fround($807 + $839);
    $848 = Math_fround($809 + $841);
    $849 = Math_fround($811 + $843);
    $850 = Math_fround($813 + $845);
    $851 = Math_fround($852 * $767);
    $853 = Math_fround($854 * $769);
    $855 = Math_fround($856 * $771);
    $857 = Math_fround($858 * $773);
    $859 = Math_fround($815 + $851);
    $860 = Math_fround($817 + $853);
    $861 = Math_fround($819 + $855);
    $862 = Math_fround($821 + $857);
    $863 = Math_fround($864 * $743);
    $865 = Math_fround($866 * $745);
    $867 = Math_fround($868 * $747);
    $869 = Math_fround($870 * $749);
    $871 = Math_fround($823 + $863);
    $872 = Math_fround($825 + $865);
    $873 = Math_fround($827 + $867);
    $874 = Math_fround($829 + $869);
    $875 = Math_fround($876 * $791);
    $877 = Math_fround($878 * $793);
    $879 = Math_fround($880 * $795);
    $881 = Math_fround($882 * $797);
    $883 = Math_fround($831 + $875);
    $884 = Math_fround($833 + $877);
    $885 = Math_fround($835 + $879);
    $886 = Math_fround($837 + $881);
    $887 = Math_fround($888 * $751);
    $889 = Math_fround($890 * $753);
    $891 = Math_fround($892 * $755);
    $893 = Math_fround($894 * $757);
    $895 = Math_fround($847 + $887);
    $896 = Math_fround($848 + $889);
    $897 = Math_fround($849 + $891);
    $898 = Math_fround($850 + $893);
    $899 = Math_fround($900 * $775);
    $901 = Math_fround($902 * $777);
    $903 = Math_fround($904 * $779);
    $905 = Math_fround($906 * $781);
    $907 = Math_fround($859 + $899);
    $908 = Math_fround($860 + $901);
    $909 = Math_fround($861 + $903);
    $910 = Math_fround($862 + $905);
    $911 = Math_fround($912 * $751);
    $913 = Math_fround($914 * $753);
    $915 = Math_fround($916 * $755);
    $917 = Math_fround($918 * $757);
    $919 = Math_fround($871 + $911);
    $920 = Math_fround($872 + $913);
    $921 = Math_fround($873 + $915);
    $922 = Math_fround($874 + $917);
    $923 = Math_fround($924 * $799);
    $925 = Math_fround($926 * $801);
    $927 = Math_fround($928 * $803);
    $929 = Math_fround($930 * $805);
    $931 = Math_fround($883 + $923);
    $932 = Math_fround($884 + $925);
    $933 = Math_fround($885 + $927);
    $934 = Math_fround($886 + $929);
    $935 = Math_fround($895 + $907);
    $936 = Math_fround($896 + $908);
    $937 = Math_fround($897 + $909);
    $938 = Math_fround($898 + $910);
    $939 = Math_fround($919 + $931);
    $940 = Math_fround($920 + $932);
    $941 = Math_fround($921 + $933);
    $942 = Math_fround($922 + $934);
    $943 = Math_fround($935 - $939);
    $944 = Math_fround($936 - $940);
    $945 = Math_fround($937 - $941);
    $946 = Math_fround($938 - $942);
    $947 = ((($134) + (($i1$02807*336)|0)|0) + 160|0);
    $948 = Math_fround(HEAPF32[$947>>2]);
    $949 = ((($134) + (($i1$02807*336)|0)|0) + 164|0);
    $950 = Math_fround(HEAPF32[$949>>2]);
    $951 = ((($134) + (($i1$02807*336)|0)|0) + 168|0);
    $952 = Math_fround(HEAPF32[$951>>2]);
    $953 = ((($134) + (($i1$02807*336)|0)|0) + 172|0);
    $954 = Math_fround(HEAPF32[$953>>2]);
    $955 = Math_fround($719 - $948);
    $956 = Math_fround($721 - $950);
    $957 = Math_fround($723 - $952);
    $958 = Math_fround($725 - $954);
    $959 = Math_fround($727 * $943);
    $960 = Math_fround($729 * $944);
    $961 = Math_fround($731 * $945);
    $962 = Math_fround($733 * $946);
    $963 = Math_fround($955 - $959);
    $964 = Math_fround($956 - $960);
    $965 = Math_fround($957 - $961);
    $966 = Math_fround($958 - $962);
    $967 = Math_fround(-$963);
    $968 = Math_fround(-$964);
    $969 = Math_fround(-$965);
    $970 = Math_fround(-$966);
    $971 = $963 > $967;
    $$$i$i = $971 ? $963 : $967;
    $972 = $964 > $968;
    $973 = $972 ? $964 : $968;
    $974 = $965 > $969;
    $$1$i$i = $974 ? $965 : $969;
    $975 = $966 > $970;
    $976 = $975 ? $966 : $970;
    $977 = $$$i$i > $647;
    $978 = $973 > $648;
    $979 = $$1$i$i > $649;
    $980 = $976 > $650;
    $981 = $963 < $655;
    $$$i177 = $981 ? $655 : $963;
    $982 = $964 < $656;
    $983 = $982 ? $656 : $964;
    $984 = $965 < $657;
    $$1$i178 = $984 ? $657 : $965;
    $985 = $966 < $658;
    $986 = $985 ? $658 : $966;
    $987 = $651 < $$$i177;
    $$$i = $987 ? $651 : $$$i177;
    $988 = $652 < $983;
    $989 = $988 ? $652 : $983;
    $990 = $653 < $$1$i178;
    $$1$i = $990 ? $653 : $$1$i178;
    $991 = $654 < $986;
    $992 = $991 ? $654 : $986;
    HEAPF32[$1>>2] = $$$i;
    HEAPF32[$117>>2] = $989;
    HEAPF32[$118>>2] = $$1$i;
    HEAPF32[$119>>2] = $992;
    HEAPF32[$0>>2] = $963;
    HEAPF32[$120>>2] = $964;
    HEAPF32[$121>>2] = $965;
    HEAPF32[$122>>2] = $966;
    $b$a$i161 = $977 ? $1 : $0;
    $993 = Math_fround(HEAPF32[$b$a$i161>>2]);
    $a$pn4$i163 = $978 ? $1 : $0;
    $$in1$i164 = (($a$pn4$i163) + 4|0);
    $994 = Math_fround(HEAPF32[$$in1$i164>>2]);
    $b$a7$i165 = $979 ? $1 : $0;
    $$in2$i166 = (($b$a7$i165) + 8|0);
    $995 = Math_fround(HEAPF32[$$in2$i166>>2]);
    $a$pn6$i167 = $980 ? $1 : $0;
    $$in3$i168 = (($a$pn6$i167) + 12|0);
    $996 = Math_fround(HEAPF32[$$in3$i168>>2]);
    ;HEAP32[$2+0>>2]=HEAP32[$oldBroken+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$oldBroken+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$oldBroken+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$oldBroken+12>>2]|0;
    HEAPF32[$3>>2] = Math_fround(1.0);
    HEAPF32[$123>>2] = Math_fround(1.0);
    HEAPF32[$124>>2] = Math_fround(1.0);
    HEAPF32[$125>>2] = Math_fround(1.0);
    $b$a$i = $977 ? $3 : $2;
    $997 = Math_fround(HEAPF32[$b$a$i>>2]);
    $a$pn4$i = $978 ? $3 : $2;
    $$in1$i = (($a$pn4$i) + 4|0);
    $998 = Math_fround(HEAPF32[$$in1$i>>2]);
    $b$a7$i = $979 ? $3 : $2;
    $$in2$i = (($b$a7$i) + 8|0);
    $999 = Math_fround(HEAPF32[$$in2$i>>2]);
    $a$pn6$i = $980 ? $3 : $2;
    $$in3$i = (($a$pn6$i) + 12|0);
    $1000 = Math_fround(HEAPF32[$$in3$i>>2]);
    $1001 = Math_fround($993 - $719);
    $1002 = Math_fround($994 - $721);
    $1003 = Math_fround($995 - $723);
    $1004 = Math_fround($996 - $725);
    HEAPF32[$718>>2] = $993;
    HEAPF32[$720>>2] = $994;
    HEAPF32[$722>>2] = $995;
    HEAPF32[$724>>2] = $996;
    HEAPF32[$806>>2] = $997;
    $1005 = ((($134) + (($i1$02807*336)|0)|0) + 180|0);
    HEAPF32[$1005>>2] = $998;
    $1006 = ((($134) + (($i1$02807*336)|0)|0) + 184|0);
    HEAPF32[$1006>>2] = $999;
    $1007 = ((($134) + (($i1$02807*336)|0)|0) + 188|0);
    HEAPF32[$1007>>2] = $1000;
    $1008 = Math_fround($138 * $1001);
    $1009 = Math_fround($140 * $1002);
    $1010 = Math_fround($142 * $1003);
    $1011 = Math_fround($144 * $1004);
    $1012 = Math_fround($146 * $1001);
    $1013 = Math_fround($148 * $1002);
    $1014 = Math_fround($150 * $1003);
    $1015 = Math_fround($152 * $1004);
    $1016 = Math_fround($735 * $1008);
    $1017 = Math_fround($737 * $1009);
    $1018 = Math_fround($739 * $1010);
    $1019 = Math_fround($741 * $1011);
    $1020 = Math_fround($808 + $1016);
    $1021 = Math_fround($810 + $1017);
    $1022 = Math_fround($812 + $1018);
    $1023 = Math_fround($814 + $1019);
    $1024 = Math_fround($735 * $1012);
    $1025 = Math_fround($737 * $1013);
    $1026 = Math_fround($739 * $1014);
    $1027 = Math_fround($741 * $1015);
    $1028 = Math_fround($824 + $1024);
    $1029 = Math_fround($826 + $1025);
    $1030 = Math_fround($828 + $1026);
    $1031 = Math_fround($830 + $1027);
    $1032 = Math_fround($671 * $1001);
    $1033 = Math_fround($673 * $1002);
    $1034 = Math_fround($675 * $1003);
    $1035 = Math_fround($677 * $1004);
    $1036 = Math_fround($816 + $1032);
    $1037 = Math_fround($818 + $1033);
    $1038 = Math_fround($820 + $1034);
    $1039 = Math_fround($822 + $1035);
    $1040 = Math_fround($695 * $1001);
    $1041 = Math_fround($697 * $1002);
    $1042 = Math_fround($699 * $1003);
    $1043 = Math_fround($701 * $1004);
    $1044 = Math_fround($832 + $1040);
    $1045 = Math_fround($834 + $1041);
    $1046 = Math_fround($836 + $1042);
    $1047 = Math_fround($838 + $1043);
    $1048 = Math_fround($743 * $1008);
    $1049 = Math_fround($745 * $1009);
    $1050 = Math_fround($747 * $1010);
    $1051 = Math_fround($749 * $1011);
    $1052 = Math_fround($840 + $1048);
    $1053 = Math_fround($842 + $1049);
    $1054 = Math_fround($844 + $1050);
    $1055 = Math_fround($846 + $1051);
    $1056 = Math_fround($743 * $1012);
    $1057 = Math_fround($745 * $1013);
    $1058 = Math_fround($747 * $1014);
    $1059 = Math_fround($749 * $1015);
    $1060 = Math_fround($864 + $1056);
    $1061 = Math_fround($866 + $1057);
    $1062 = Math_fround($868 + $1058);
    $1063 = Math_fround($870 + $1059);
    $1064 = Math_fround($679 * $1001);
    $1065 = Math_fround($681 * $1002);
    $1066 = Math_fround($683 * $1003);
    $1067 = Math_fround($685 * $1004);
    $1068 = Math_fround($852 + $1064);
    $1069 = Math_fround($854 + $1065);
    $1070 = Math_fround($856 + $1066);
    $1071 = Math_fround($858 + $1067);
    $1072 = Math_fround($703 * $1001);
    $1073 = Math_fround($705 * $1002);
    $1074 = Math_fround($707 * $1003);
    $1075 = Math_fround($709 * $1004);
    $1076 = Math_fround($876 + $1072);
    $1077 = Math_fround($878 + $1073);
    $1078 = Math_fround($880 + $1074);
    $1079 = Math_fround($882 + $1075);
    $1080 = Math_fround($751 * $1008);
    $1081 = Math_fround($753 * $1009);
    $1082 = Math_fround($755 * $1010);
    $1083 = Math_fround($757 * $1011);
    $1084 = Math_fround($888 + $1080);
    $1085 = Math_fround($890 + $1081);
    $1086 = Math_fround($892 + $1082);
    $1087 = Math_fround($894 + $1083);
    $1088 = Math_fround($751 * $1012);
    $1089 = Math_fround($753 * $1013);
    $1090 = Math_fround($755 * $1014);
    $1091 = Math_fround($757 * $1015);
    $1092 = Math_fround($912 + $1088);
    $1093 = Math_fround($914 + $1089);
    $1094 = Math_fround($916 + $1090);
    $1095 = Math_fround($918 + $1091);
    $1096 = Math_fround($687 * $1001);
    $1097 = Math_fround($689 * $1002);
    $1098 = Math_fround($691 * $1003);
    $1099 = Math_fround($693 * $1004);
    $1100 = Math_fround($900 + $1096);
    $1101 = Math_fround($902 + $1097);
    $1102 = Math_fround($904 + $1098);
    $1103 = Math_fround($906 + $1099);
    $1104 = Math_fround($711 * $1001);
    $1105 = Math_fround($713 * $1002);
    $1106 = Math_fround($715 * $1003);
    $1107 = Math_fround($717 * $1004);
    $1108 = Math_fround($924 + $1104);
    $1109 = Math_fround($926 + $1105);
    $1110 = Math_fround($928 + $1106);
    $1111 = Math_fround($930 + $1107);
    $1112 = (($i1$02807) + 1)|0;
    $exitcond3090 = ($1112|0)==($133|0);
    if ($exitcond3090) {
     break;
    } else {
     $808 = $1020;$810 = $1021;$812 = $1022;$814 = $1023;$816 = $1036;$818 = $1037;$820 = $1038;$822 = $1039;$824 = $1028;$826 = $1029;$828 = $1030;$830 = $1031;$832 = $1044;$834 = $1045;$836 = $1046;$838 = $1047;$840 = $1052;$842 = $1053;$844 = $1054;$846 = $1055;$852 = $1068;$854 = $1069;$856 = $1070;$858 = $1071;$864 = $1060;$866 = $1061;$868 = $1062;$870 = $1063;$876 = $1076;$878 = $1077;$880 = $1078;$882 = $1079;$888 = $1084;$890 = $1085;$892 = $1086;$894 = $1087;$900 = $1100;$902 = $1101;$904 = $1102;$906 = $1103;$912 = $1092;$914 = $1093;$916 = $1094;$918 = $1095;$924 = $1108;$926 = $1109;$928 = $1110;$930 = $1111;$i1$02807 = $1112;$prefetchAddress$22806 = $659;
    }
   }
   $scevgep3089 = (($prefetchAddress$1$lcssa) + ($126)|0);
   $$be = $1023;$$be2859 = $1022;$$be2860 = $1021;$$be2861 = $1020;$$be2862 = $1055;$$be2863 = $1054;$$be2864 = $1053;$$be2865 = $1052;$$be2866 = $1087;$$be2867 = $1086;$$be2868 = $1085;$$be2869 = $1084;$$be2870 = $1031;$$be2871 = $1030;$$be2872 = $1029;$$be2873 = $1028;$$be2874 = $1063;$$be2875 = $1062;$$be2876 = $1061;$$be2877 = $1060;$$be2878 = $1095;$$be2879 = $1094;$$be2880 = $1093;$$be2881 = $1092;$$be2882 = $1039;$$be2883 = $1038;$$be2884 = $1037;$$be2885 = $1036;$$be2886 = $1071;$$be2887 = $1070;$$be2888 = $1069;$$be2889 = $1068;$$be2890 = $1103;$$be2891 = $1102;$$be2892 = $1101;$$be2893 = $1100;$$be2894 = $1047;$$be2895 = $1046;$$be2896 = $1045;$$be2897 = $1044;$$be2898 = $1079;$$be2899 = $1078;$$be2900 = $1077;$$be2901 = $1076;$$be2902 = $1111;$$be2903 = $1110;$$be2904 = $1109;$$be2905 = $1108;$prefetchAddress$0$be = $scevgep3089;
  }
  $630 = ($136>>>0)<($113>>>0);
  if ($630) {
   $1145 = $$be2905;$1146 = $$be2904;$1147 = $$be2903;$1148 = $$be2902;$1149 = $$be2901;$1150 = $$be2900;$1151 = $$be2899;$1152 = $$be2898;$1153 = $$be2897;$1154 = $$be2896;$1155 = $$be2895;$1156 = $$be2894;$1157 = $$be2893;$1158 = $$be2892;$1159 = $$be2891;$1160 = $$be2890;$1161 = $$be2889;$1162 = $$be2888;$1163 = $$be2887;$1164 = $$be2886;$1165 = $$be2885;$1166 = $$be2884;$1167 = $$be2883;$1168 = $$be2882;$179 = $$be2874;$181 = $$be2875;$183 = $$be2876;$185 = $$be2877;$187 = $$be2862;$189 = $$be2863;$191 = $$be2864;$193 = $$be2865;$195 = $$be2870;$197 = $$be2871;$199 = $$be2872;$201 = $$be2873;$203 = $$be;$205 = $$be2859;$207 = $$be2860;$209 = $$be2861;$211 = $$be2878;$213 = $$be2879;$215 = $$be2880;$217 = $$be2881;$219 = $$be2866;$221 = $$be2867;$223 = $$be2868;$225 = $$be2869;$currPtr$02955 = $136;$prefetchAddress$02954 = $prefetchAddress$0$be;
  } else {
   $$lcssa2906 = $$be;$$lcssa2907 = $$be2859;$$lcssa2908 = $$be2860;$$lcssa2909 = $$be2861;$$lcssa2910 = $$be2862;$$lcssa2911 = $$be2863;$$lcssa2912 = $$be2864;$$lcssa2913 = $$be2865;$$lcssa2914 = $$be2866;$$lcssa2915 = $$be2867;$$lcssa2916 = $$be2868;$$lcssa2917 = $$be2869;$$lcssa2918 = $$be2870;$$lcssa2919 = $$be2871;$$lcssa2920 = $$be2872;$$lcssa2921 = $$be2873;$$lcssa2922 = $$be2874;$$lcssa2923 = $$be2875;$$lcssa2924 = $$be2876;$$lcssa2925 = $$be2877;$$lcssa2926 = $$be2878;$$lcssa2927 = $$be2879;$$lcssa2928 = $$be2880;$$lcssa2929 = $$be2881;$$lcssa2930 = $$be2882;$$lcssa2931 = $$be2883;$$lcssa2932 = $$be2884;$$lcssa2933 = $$be2885;$$lcssa2934 = $$be2886;$$lcssa2935 = $$be2887;$$lcssa2936 = $$be2888;$$lcssa2937 = $$be2889;$$lcssa2938 = $$be2890;$$lcssa2939 = $$be2891;$$lcssa2940 = $$be2892;$$lcssa2941 = $$be2893;$$lcssa2942 = $$be2894;$$lcssa2943 = $$be2895;$$lcssa2944 = $$be2896;$$lcssa2945 = $$be2897;$$lcssa2946 = $$be2898;$$lcssa2947 = $$be2899;$$lcssa2948 = $$be2900;$$lcssa2949 = $$be2901;$$lcssa2950 = $$be2902;$$lcssa2951 = $$be2903;$$lcssa2952 = $$be2904;$$lcssa2953 = $$be2905;
   break;
  }
 }
 HEAPF32[$4>>2] = $$lcssa2909;
 $1113 = (($4) + 4|0);
 HEAPF32[$1113>>2] = $$lcssa2913;
 $1114 = (($4) + 8|0);
 HEAPF32[$1114>>2] = $$lcssa2917;
 HEAPF32[$8>>2] = $$lcssa2908;
 $1115 = (($8) + 4|0);
 HEAPF32[$1115>>2] = $$lcssa2912;
 $1116 = (($8) + 8|0);
 HEAPF32[$1116>>2] = $$lcssa2916;
 HEAPF32[$12>>2] = $$lcssa2907;
 $1117 = (($12) + 4|0);
 HEAPF32[$1117>>2] = $$lcssa2911;
 $1118 = (($12) + 8|0);
 HEAPF32[$1118>>2] = $$lcssa2915;
 HEAPF32[$16>>2] = $$lcssa2906;
 $1119 = (($16) + 4|0);
 HEAPF32[$1119>>2] = $$lcssa2910;
 $1120 = (($16) + 8|0);
 HEAPF32[$1120>>2] = $$lcssa2914;
 HEAPF32[$6>>2] = $$lcssa2921;
 $1121 = (($6) + 4|0);
 HEAPF32[$1121>>2] = $$lcssa2925;
 $1122 = (($6) + 8|0);
 HEAPF32[$1122>>2] = $$lcssa2929;
 HEAPF32[$10>>2] = $$lcssa2920;
 $1123 = (($10) + 4|0);
 HEAPF32[$1123>>2] = $$lcssa2924;
 $1124 = (($10) + 8|0);
 HEAPF32[$1124>>2] = $$lcssa2928;
 HEAPF32[$14>>2] = $$lcssa2919;
 $1125 = (($14) + 4|0);
 HEAPF32[$1125>>2] = $$lcssa2923;
 $1126 = (($14) + 8|0);
 HEAPF32[$1126>>2] = $$lcssa2927;
 HEAPF32[$18>>2] = $$lcssa2918;
 $1127 = (($18) + 4|0);
 HEAPF32[$1127>>2] = $$lcssa2922;
 $1128 = (($18) + 8|0);
 HEAPF32[$1128>>2] = $$lcssa2926;
 HEAPF32[$29>>2] = $$lcssa2933;
 $1129 = (($4) + 20|0);
 HEAPF32[$1129>>2] = $$lcssa2937;
 $1130 = (($4) + 24|0);
 HEAPF32[$1130>>2] = $$lcssa2941;
 HEAPF32[$51>>2] = $$lcssa2932;
 $1131 = (($8) + 20|0);
 HEAPF32[$1131>>2] = $$lcssa2936;
 $1132 = (($8) + 24|0);
 HEAPF32[$1132>>2] = $$lcssa2940;
 HEAPF32[$73>>2] = $$lcssa2931;
 $1133 = (($12) + 20|0);
 HEAPF32[$1133>>2] = $$lcssa2935;
 $1134 = (($12) + 24|0);
 HEAPF32[$1134>>2] = $$lcssa2939;
 HEAPF32[$95>>2] = $$lcssa2930;
 $1135 = (($16) + 20|0);
 HEAPF32[$1135>>2] = $$lcssa2934;
 $1136 = (($16) + 24|0);
 HEAPF32[$1136>>2] = $$lcssa2938;
 HEAPF32[$35>>2] = $$lcssa2945;
 $1137 = (($6) + 20|0);
 HEAPF32[$1137>>2] = $$lcssa2949;
 $1138 = (($6) + 24|0);
 HEAPF32[$1138>>2] = $$lcssa2953;
 HEAPF32[$57>>2] = $$lcssa2944;
 $1139 = (($10) + 20|0);
 HEAPF32[$1139>>2] = $$lcssa2948;
 $1140 = (($10) + 24|0);
 HEAPF32[$1140>>2] = $$lcssa2952;
 HEAPF32[$79>>2] = $$lcssa2943;
 $1141 = (($14) + 20|0);
 HEAPF32[$1141>>2] = $$lcssa2947;
 $1142 = (($14) + 24|0);
 HEAPF32[$1142>>2] = $$lcssa2951;
 HEAPF32[$101>>2] = $$lcssa2942;
 $1143 = (($18) + 20|0);
 HEAPF32[$1143>>2] = $$lcssa2946;
 $1144 = (($18) + 24|0);
 HEAPF32[$1144>>2] = $$lcssa2950;
 STACKTOP = sp;return;
}
function __ZN5physx27solveContactPreBlock_StaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL25solveContact4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 STACKTOP = sp;return;
}
function __ZN5physxL25solveContact4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i105 = Math_fround(0), $$$i231 = Math_fround(0), $$$i241 = Math_fround(0), $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i106 = Math_fround(0), $$1$i232 = Math_fround(0), $$1$i242 = Math_fround(0), $$be = Math_fround(0), $$be1625 = Math_fround(0), $$be1626 = Math_fround(0), $$be1627 = Math_fround(0), $$be1628 = Math_fround(0), $$be1629 = Math_fround(0), $$be1630 = Math_fround(0), $$be1631 = Math_fround(0), $$be1632 = Math_fround(0), $$be1633 = Math_fround(0);
 var $$be1634 = Math_fround(0), $$be1635 = Math_fround(0), $$be1636 = Math_fround(0), $$be1637 = Math_fround(0), $$be1638 = Math_fround(0), $$be1639 = Math_fround(0), $$be1640 = Math_fround(0), $$be1641 = Math_fround(0), $$be1642 = Math_fround(0), $$be1643 = Math_fround(0), $$be1644 = Math_fround(0), $$be1645 = Math_fround(0), $$be1646 = Math_fround(0), $$be1647 = Math_fround(0), $$in1$i = 0, $$in1$i92 = 0, $$in2$i = 0, $$in2$i94 = 0, $$in3$i = 0, $$in3$i96 = 0;
 var $$lcssa = Math_fround(0), $$lcssa1531 = Math_fround(0), $$lcssa1532 = Math_fround(0), $$lcssa1533 = Math_fround(0), $$lcssa1534 = Math_fround(0), $$lcssa1535 = Math_fround(0), $$lcssa1536 = Math_fround(0), $$lcssa1537 = Math_fround(0), $$lcssa1538 = Math_fround(0), $$lcssa1539 = Math_fround(0), $$lcssa1540 = Math_fround(0), $$lcssa1541 = Math_fround(0), $$lcssa1542 = Math_fround(0), $$lcssa1543 = Math_fround(0), $$lcssa1544 = Math_fround(0), $$lcssa1545 = Math_fround(0), $$lcssa1546 = Math_fround(0), $$lcssa1547 = Math_fround(0), $$lcssa1548 = Math_fround(0), $$lcssa1549 = Math_fround(0);
 var $$lcssa1648 = Math_fround(0), $$lcssa1649 = Math_fround(0), $$lcssa1650 = Math_fround(0), $$lcssa1651 = Math_fround(0), $$lcssa1652 = Math_fround(0), $$lcssa1653 = Math_fround(0), $$lcssa1654 = Math_fround(0), $$lcssa1655 = Math_fround(0), $$lcssa1656 = Math_fround(0), $$lcssa1657 = Math_fround(0), $$lcssa1658 = Math_fround(0), $$lcssa1659 = Math_fround(0), $$lcssa1660 = Math_fround(0), $$lcssa1661 = Math_fround(0), $$lcssa1662 = Math_fround(0), $$lcssa1663 = Math_fround(0), $$lcssa1664 = Math_fround(0), $$lcssa1665 = Math_fround(0), $$lcssa1666 = Math_fround(0), $$lcssa1667 = Math_fround(0);
 var $$lcssa1668 = Math_fround(0), $$lcssa1669 = Math_fround(0), $$lcssa1670 = Math_fround(0), $$lcssa1671 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0;
 var $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0);
 var $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0);
 var $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0;
 var $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0);
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0);
 var $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = 0, $444 = Math_fround(0), $445 = 0, $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = Math_fround(0);
 var $455 = 0, $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0), $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = 0, $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = Math_fround(0);
 var $473 = 0, $474 = Math_fround(0), $475 = 0, $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = Math_fround(0);
 var $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = Math_fround(0), $497 = 0, $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = 0, $502 = Math_fround(0), $503 = 0, $504 = Math_fround(0), $505 = 0, $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0);
 var $509 = 0, $51 = Math_fround(0), $510 = Math_fround(0), $511 = 0, $512 = Math_fround(0), $513 = 0, $514 = Math_fround(0), $515 = 0, $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0);
 var $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0);
 var $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0);
 var $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0);
 var $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = 0, $589 = Math_fround(0), $59 = Math_fround(0), $590 = 0, $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0);
 var $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = 0, $609 = 0, $61 = Math_fround(0), $610 = Math_fround(0), $611 = 0, $612 = 0, $613 = Math_fround(0), $614 = 0, $615 = 0, $616 = 0;
 var $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = Math_fround(0), $621 = 0, $622 = 0, $623 = Math_fround(0), $624 = 0, $625 = 0, $626 = Math_fround(0), $627 = 0, $628 = 0, $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0);
 var $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0);
 var $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0);
 var $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0);
 var $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0;
 var $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0);
 var $725 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $a$pn4$i = 0, $a$pn4$i91 = 0, $a$pn6$i = 0, $a$pn6$i95 = 0, $b$a$i = 0, $b$a$i89 = 0, $b$a7$i = 0, $b$a7$i93 = 0, $currPtr$01673 = 0, $exitcond = 0;
 var $exitcond1748 = 0, $i$01550 = 0, $i1$01597 = 0, $oldBroken = 0, $or$cond = 0, $prefetchAddress$0$be = 0, $prefetchAddress$01672 = 0, $prefetchAddress$1$lcssa = 0, $prefetchAddress$11551 = 0, $prefetchAddress$21596 = 0, $scevgep = 0, $scevgep1747 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $oldBroken = sp + 48|0;
 $4 = HEAP32[$desc>>2]|0;
 $5 = (($desc) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($desc) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($desc) + 96|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($desc) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($desc) + 26|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = $14&65535;
 $16 = $15 << 4;
 $17 = (($12) + ($16)|0);
 $18 = Math_fround(HEAPF32[$4>>2]);
 $19 = (($4) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($4) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($4) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($23) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($23) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$6>>2]);
 $30 = (($6) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($6) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($6) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($34) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($34) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround(HEAPF32[$8>>2]);
 $41 = (($8) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($8) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($8) + 16|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($45) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($45) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround(HEAPF32[$10>>2]);
 $52 = (($10) + 4|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($10) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($10) + 16|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($56) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($56) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = ($14<<16>>16)==(0);
 if ($62) {
  $$lcssa1648 = $51;$$lcssa1649 = $40;$$lcssa1650 = $29;$$lcssa1651 = $18;$$lcssa1652 = $53;$$lcssa1653 = $42;$$lcssa1654 = $31;$$lcssa1655 = $20;$$lcssa1656 = $55;$$lcssa1657 = $44;$$lcssa1658 = $33;$$lcssa1659 = $22;$$lcssa1660 = $57;$$lcssa1661 = $46;$$lcssa1662 = $35;$$lcssa1663 = $24;$$lcssa1664 = $59;$$lcssa1665 = $48;$$lcssa1666 = $37;$$lcssa1667 = $26;$$lcssa1668 = $61;$$lcssa1669 = $50;$$lcssa1670 = $39;$$lcssa1671 = $28;
  HEAPF32[$4>>2] = $$lcssa1651;
  $698 = (($4) + 4|0);
  HEAPF32[$698>>2] = $$lcssa1655;
  $699 = (($4) + 8|0);
  HEAPF32[$699>>2] = $$lcssa1659;
  HEAPF32[$6>>2] = $$lcssa1650;
  $700 = (($6) + 4|0);
  HEAPF32[$700>>2] = $$lcssa1654;
  $701 = (($6) + 8|0);
  HEAPF32[$701>>2] = $$lcssa1658;
  HEAPF32[$8>>2] = $$lcssa1649;
  $702 = (($8) + 4|0);
  HEAPF32[$702>>2] = $$lcssa1653;
  $703 = (($8) + 8|0);
  HEAPF32[$703>>2] = $$lcssa1657;
  HEAPF32[$10>>2] = $$lcssa1648;
  $704 = (($10) + 4|0);
  HEAPF32[$704>>2] = $$lcssa1652;
  $705 = (($10) + 8|0);
  HEAPF32[$705>>2] = $$lcssa1656;
  HEAPF32[$23>>2] = $$lcssa1663;
  $706 = (($4) + 20|0);
  HEAPF32[$706>>2] = $$lcssa1667;
  $707 = (($4) + 24|0);
  HEAPF32[$707>>2] = $$lcssa1671;
  HEAPF32[$34>>2] = $$lcssa1662;
  $708 = (($6) + 20|0);
  HEAPF32[$708>>2] = $$lcssa1666;
  $709 = (($6) + 24|0);
  HEAPF32[$709>>2] = $$lcssa1670;
  HEAPF32[$45>>2] = $$lcssa1661;
  $710 = (($8) + 20|0);
  HEAPF32[$710>>2] = $$lcssa1665;
  $711 = (($8) + 24|0);
  HEAPF32[$711>>2] = $$lcssa1669;
  HEAPF32[$56>>2] = $$lcssa1660;
  $712 = (($10) + 20|0);
  HEAPF32[$712>>2] = $$lcssa1664;
  $713 = (($10) + 24|0);
  HEAPF32[$713>>2] = $$lcssa1668;
  STACKTOP = sp;return;
 }
 $63 = (($12) + 320|0);
 $64 = (($cache) + 1|0);
 $65 = (($1) + 4|0);
 $66 = (($1) + 8|0);
 $67 = (($1) + 12|0);
 $68 = (($0) + 4|0);
 $69 = (($0) + 8|0);
 $70 = (($0) + 12|0);
 $71 = (($3) + 4|0);
 $72 = (($3) + 8|0);
 $73 = (($3) + 12|0);
 $119 = $53;$121 = $42;$123 = $31;$125 = $20;$127 = $51;$129 = $40;$131 = $29;$133 = $18;$135 = $55;$137 = $44;$139 = $33;$141 = $22;$714 = $28;$715 = $39;$716 = $50;$717 = $61;$718 = $26;$719 = $37;$720 = $48;$721 = $59;$722 = $24;$723 = $35;$724 = $46;$725 = $57;$currPtr$01673 = $12;$prefetchAddress$01672 = $63;
 while(1) {
  $75 = (($currPtr$01673) + 144|0);
  $76 = (($currPtr$01673) + 1|0);
  $77 = HEAP8[$76>>0]|0;
  $78 = $77&255;
  $79 = (($currPtr$01673) + 2|0);
  $80 = HEAP8[$79>>0]|0;
  $81 = $80&255;
  $82 = (($75) + (($78*176)|0)|0);
  $83 = ($81*240)|0;
  $84 = (($82) + ($83)|0);
  $85 = (($currPtr$01673) + 64|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = (($currPtr$01673) + 68|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (($currPtr$01673) + 72|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = (($currPtr$01673) + 76|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = (($currPtr$01673) + 96|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = (($currPtr$01673) + 100|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = (($currPtr$01673) + 104|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($currPtr$01673) + 108|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($currPtr$01673) + 112|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = (($currPtr$01673) + 116|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = (($currPtr$01673) + 120|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = (($currPtr$01673) + 124|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = (($currPtr$01673) + 128|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = (($currPtr$01673) + 132|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($currPtr$01673) + 136|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = (($currPtr$01673) + 140|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = ($77<<24>>24)==(0);
  if ($117) {
   $$lcssa = $725;$$lcssa1531 = $724;$$lcssa1532 = $723;$$lcssa1533 = $722;$$lcssa1534 = $721;$$lcssa1535 = $720;$$lcssa1536 = $719;$$lcssa1537 = $718;$$lcssa1538 = $717;$$lcssa1539 = $716;$$lcssa1540 = $715;$$lcssa1541 = $714;$$lcssa1542 = Math_fround(0.0);$$lcssa1543 = Math_fround(0.0);$$lcssa1544 = Math_fround(0.0);$$lcssa1545 = Math_fround(0.0);$$lcssa1546 = Math_fround(0.0);$$lcssa1547 = Math_fround(0.0);$$lcssa1548 = Math_fround(0.0);$$lcssa1549 = Math_fround(0.0);$prefetchAddress$1$lcssa = $prefetchAddress$01672;
  } else {
   $118 = Math_fround($119 * $108);
   $120 = Math_fround($121 * $106);
   $122 = Math_fround($123 * $104);
   $124 = Math_fround($125 * $102);
   $126 = Math_fround($127 * $100);
   $128 = Math_fround($129 * $98);
   $130 = Math_fround($131 * $96);
   $132 = Math_fround($133 * $94);
   $134 = Math_fround($135 * $116);
   $136 = Math_fround($137 * $114);
   $138 = Math_fround($139 * $112);
   $140 = Math_fround($141 * $110);
   $142 = Math_fround($126 + $118);
   $143 = Math_fround($128 + $120);
   $144 = Math_fround($130 + $122);
   $145 = Math_fround($132 + $124);
   $146 = Math_fround($142 + $134);
   $147 = Math_fround($143 + $136);
   $148 = Math_fround($144 + $138);
   $149 = Math_fround($145 + $140);
   $150 = $78 << 8;
   $226 = $722;$228 = $723;$230 = $724;$232 = $725;$234 = $718;$236 = $719;$238 = $720;$240 = $721;$246 = $714;$248 = $715;$250 = $716;$252 = $717;$266 = $149;$268 = $148;$270 = $147;$272 = $146;$306 = Math_fround(0.0);$308 = Math_fround(0.0);$310 = Math_fround(0.0);$312 = Math_fround(0.0);$346 = Math_fround(0.0);$348 = Math_fround(0.0);$350 = Math_fround(0.0);$352 = Math_fround(0.0);$i$01550 = 0;$prefetchAddress$11551 = $prefetchAddress$01672;
   while(1) {
    $151 = (($prefetchAddress$11551) + 128|0);
    $152 = (($prefetchAddress$11551) + 256|0);
    $153 = ((($75) + (($i$01550*176)|0)|0) + 48|0);
    $154 = Math_fround(HEAPF32[$153>>2]);
    $155 = ((($75) + (($i$01550*176)|0)|0) + 52|0);
    $156 = Math_fround(HEAPF32[$155>>2]);
    $157 = ((($75) + (($i$01550*176)|0)|0) + 56|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = ((($75) + (($i$01550*176)|0)|0) + 60|0);
    $160 = Math_fround(HEAPF32[$159>>2]);
    $161 = ((($75) + (($i$01550*176)|0)|0) + 64|0);
    $162 = Math_fround(HEAPF32[$161>>2]);
    $163 = ((($75) + (($i$01550*176)|0)|0) + 68|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = ((($75) + (($i$01550*176)|0)|0) + 72|0);
    $166 = Math_fround(HEAPF32[$165>>2]);
    $167 = ((($75) + (($i$01550*176)|0)|0) + 76|0);
    $168 = Math_fround(HEAPF32[$167>>2]);
    $169 = ((($75) + (($i$01550*176)|0)|0) + 80|0);
    $170 = Math_fround(HEAPF32[$169>>2]);
    $171 = ((($75) + (($i$01550*176)|0)|0) + 84|0);
    $172 = Math_fround(HEAPF32[$171>>2]);
    $173 = ((($75) + (($i$01550*176)|0)|0) + 88|0);
    $174 = Math_fround(HEAPF32[$173>>2]);
    $175 = ((($75) + (($i$01550*176)|0)|0) + 92|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = ((($75) + (($i$01550*176)|0)|0) + 112|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = ((($75) + (($i$01550*176)|0)|0) + 116|0);
    $180 = Math_fround(HEAPF32[$179>>2]);
    $181 = ((($75) + (($i$01550*176)|0)|0) + 120|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = ((($75) + (($i$01550*176)|0)|0) + 124|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    $185 = ((($75) + (($i$01550*176)|0)|0) + 96|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = ((($75) + (($i$01550*176)|0)|0) + 100|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = ((($75) + (($i$01550*176)|0)|0) + 104|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = ((($75) + (($i$01550*176)|0)|0) + 108|0);
    $192 = Math_fround(HEAPF32[$191>>2]);
    $193 = ((($75) + (($i$01550*176)|0)|0) + 160|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = ((($75) + (($i$01550*176)|0)|0) + 164|0);
    $196 = Math_fround(HEAPF32[$195>>2]);
    $197 = ((($75) + (($i$01550*176)|0)|0) + 168|0);
    $198 = Math_fround(HEAPF32[$197>>2]);
    $199 = ((($75) + (($i$01550*176)|0)|0) + 172|0);
    $200 = Math_fround(HEAPF32[$199>>2]);
    $201 = (($75) + (($i$01550*176)|0)|0);
    $202 = Math_fround(HEAPF32[$201>>2]);
    $203 = ((($75) + (($i$01550*176)|0)|0) + 4|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = ((($75) + (($i$01550*176)|0)|0) + 8|0);
    $206 = Math_fround(HEAPF32[$205>>2]);
    $207 = ((($75) + (($i$01550*176)|0)|0) + 12|0);
    $208 = Math_fround(HEAPF32[$207>>2]);
    $209 = ((($75) + (($i$01550*176)|0)|0) + 16|0);
    $210 = Math_fround(HEAPF32[$209>>2]);
    $211 = ((($75) + (($i$01550*176)|0)|0) + 20|0);
    $212 = Math_fround(HEAPF32[$211>>2]);
    $213 = ((($75) + (($i$01550*176)|0)|0) + 24|0);
    $214 = Math_fround(HEAPF32[$213>>2]);
    $215 = ((($75) + (($i$01550*176)|0)|0) + 28|0);
    $216 = Math_fround(HEAPF32[$215>>2]);
    $217 = ((($75) + (($i$01550*176)|0)|0) + 32|0);
    $218 = Math_fround(HEAPF32[$217>>2]);
    $219 = ((($75) + (($i$01550*176)|0)|0) + 36|0);
    $220 = Math_fround(HEAPF32[$219>>2]);
    $221 = ((($75) + (($i$01550*176)|0)|0) + 40|0);
    $222 = Math_fround(HEAPF32[$221>>2]);
    $223 = ((($75) + (($i$01550*176)|0)|0) + 44|0);
    $224 = Math_fround(HEAPF32[$223>>2]);
    $225 = Math_fround($226 * $202);
    $227 = Math_fround($228 * $204);
    $229 = Math_fround($230 * $206);
    $231 = Math_fround($232 * $208);
    $233 = Math_fround($234 * $210);
    $235 = Math_fround($236 * $212);
    $237 = Math_fround($238 * $214);
    $239 = Math_fround($240 * $216);
    $241 = Math_fround($225 + $233);
    $242 = Math_fround($227 + $235);
    $243 = Math_fround($229 + $237);
    $244 = Math_fround($231 + $239);
    $245 = Math_fround($246 * $218);
    $247 = Math_fround($248 * $220);
    $249 = Math_fround($250 * $222);
    $251 = Math_fround($252 * $224);
    $253 = Math_fround($241 + $245);
    $254 = Math_fround($242 + $247);
    $255 = Math_fround($243 + $249);
    $256 = Math_fround($244 + $251);
    $257 = ((($75) + (($i$01550*176)|0)|0) + 144|0);
    $258 = Math_fround(HEAPF32[$257>>2]);
    $259 = ((($75) + (($i$01550*176)|0)|0) + 148|0);
    $260 = Math_fround(HEAPF32[$259>>2]);
    $261 = ((($75) + (($i$01550*176)|0)|0) + 152|0);
    $262 = Math_fround(HEAPF32[$261>>2]);
    $263 = ((($75) + (($i$01550*176)|0)|0) + 156|0);
    $264 = Math_fround(HEAPF32[$263>>2]);
    $265 = Math_fround($266 + $253);
    $267 = Math_fround($268 + $254);
    $269 = Math_fround($270 + $255);
    $271 = Math_fround($272 + $256);
    $273 = Math_fround($186 * $265);
    $274 = Math_fround($188 * $267);
    $275 = Math_fround($190 * $269);
    $276 = Math_fround($192 * $271);
    $277 = Math_fround($258 - $273);
    $278 = Math_fround($260 - $274);
    $279 = Math_fround($262 - $275);
    $280 = Math_fround($264 - $276);
    $281 = Math_fround(-$178);
    $282 = Math_fround(-$180);
    $283 = Math_fround(-$182);
    $284 = Math_fround(-$184);
    $285 = $277 > $281;
    $$$i241 = $285 ? $277 : $281;
    $286 = $278 > $282;
    $287 = $286 ? $278 : $282;
    $288 = $279 > $283;
    $$1$i242 = $288 ? $279 : $283;
    $289 = $280 > $284;
    $290 = $289 ? $280 : $284;
    $291 = Math_fround($178 + $$$i241);
    $292 = Math_fround($180 + $287);
    $293 = Math_fround($182 + $$1$i242);
    $294 = Math_fround($184 + $290);
    $295 = $291 < $194;
    $$$i231 = $295 ? $291 : $194;
    $296 = $292 < $196;
    $297 = $296 ? $292 : $196;
    $298 = $293 < $198;
    $$1$i232 = $298 ? $293 : $198;
    $299 = $294 < $200;
    $300 = $299 ? $294 : $200;
    $301 = Math_fround($$$i231 - $178);
    $302 = Math_fround($297 - $180);
    $303 = Math_fround($$1$i232 - $182);
    $304 = Math_fround($300 - $184);
    $305 = Math_fround($306 + $301);
    $307 = Math_fround($308 + $302);
    $309 = Math_fround($310 + $303);
    $311 = Math_fround($312 + $304);
    $313 = Math_fround($86 * $301);
    $314 = Math_fround($88 * $302);
    $315 = Math_fround($90 * $303);
    $316 = Math_fround($92 * $304);
    $317 = Math_fround($266 + $313);
    $318 = Math_fround($268 + $314);
    $319 = Math_fround($270 + $315);
    $320 = Math_fround($272 + $316);
    $321 = Math_fround($154 * $301);
    $322 = Math_fround($156 * $302);
    $323 = Math_fround($158 * $303);
    $324 = Math_fround($160 * $304);
    $325 = Math_fround($226 + $321);
    $326 = Math_fround($228 + $322);
    $327 = Math_fround($230 + $323);
    $328 = Math_fround($232 + $324);
    $329 = Math_fround($162 * $301);
    $330 = Math_fround($164 * $302);
    $331 = Math_fround($166 * $303);
    $332 = Math_fround($168 * $304);
    $333 = Math_fround($234 + $329);
    $334 = Math_fround($236 + $330);
    $335 = Math_fround($238 + $331);
    $336 = Math_fround($240 + $332);
    $337 = Math_fround($170 * $301);
    $338 = Math_fround($172 * $302);
    $339 = Math_fround($174 * $303);
    $340 = Math_fround($176 * $304);
    $341 = Math_fround($246 + $337);
    $342 = Math_fround($248 + $338);
    $343 = Math_fround($250 + $339);
    $344 = Math_fround($252 + $340);
    HEAPF32[$177>>2] = $$$i231;
    HEAPF32[$179>>2] = $297;
    HEAPF32[$181>>2] = $$1$i232;
    HEAPF32[$183>>2] = $300;
    $345 = Math_fround($346 + $$$i231);
    $347 = Math_fround($348 + $297);
    $349 = Math_fround($350 + $$1$i232);
    $351 = Math_fround($352 + $300);
    $353 = (($i$01550) + 1)|0;
    $exitcond = ($353|0)==($78|0);
    if ($exitcond) {
     break;
    } else {
     $226 = $325;$228 = $326;$230 = $327;$232 = $328;$234 = $333;$236 = $334;$238 = $335;$240 = $336;$246 = $341;$248 = $342;$250 = $343;$252 = $344;$266 = $317;$268 = $318;$270 = $319;$272 = $320;$306 = $305;$308 = $307;$310 = $309;$312 = $311;$346 = $345;$348 = $347;$350 = $349;$352 = $351;$i$01550 = $353;$prefetchAddress$11551 = $152;
    }
   }
   $scevgep = (($prefetchAddress$01672) + ($150)|0);
   $$lcssa = $328;$$lcssa1531 = $327;$$lcssa1532 = $326;$$lcssa1533 = $325;$$lcssa1534 = $336;$$lcssa1535 = $335;$$lcssa1536 = $334;$$lcssa1537 = $333;$$lcssa1538 = $344;$$lcssa1539 = $343;$$lcssa1540 = $342;$$lcssa1541 = $341;$$lcssa1542 = $351;$$lcssa1543 = $349;$$lcssa1544 = $347;$$lcssa1545 = $345;$$lcssa1546 = $311;$$lcssa1547 = $309;$$lcssa1548 = $307;$$lcssa1549 = $305;$prefetchAddress$1$lcssa = $scevgep;
  }
  $354 = Math_fround($86 * $$lcssa1549);
  $355 = Math_fround($88 * $$lcssa1548);
  $356 = Math_fround($90 * $$lcssa1547);
  $357 = Math_fround($92 * $$lcssa1546);
  $358 = Math_fround($94 * $354);
  $359 = Math_fround($96 * $355);
  $360 = Math_fround($98 * $356);
  $361 = Math_fround($100 * $357);
  $362 = Math_fround($133 + $358);
  $363 = Math_fround($131 + $359);
  $364 = Math_fround($129 + $360);
  $365 = Math_fround($127 + $361);
  $366 = Math_fround($102 * $354);
  $367 = Math_fround($104 * $355);
  $368 = Math_fround($106 * $356);
  $369 = Math_fround($108 * $357);
  $370 = Math_fround($125 + $366);
  $371 = Math_fround($123 + $367);
  $372 = Math_fround($121 + $368);
  $373 = Math_fround($119 + $369);
  $374 = Math_fround($110 * $354);
  $375 = Math_fround($112 * $355);
  $376 = Math_fround($114 * $356);
  $377 = Math_fround($116 * $357);
  $378 = Math_fround($141 + $374);
  $379 = Math_fround($139 + $375);
  $380 = Math_fround($137 + $376);
  $381 = Math_fround($135 + $377);
  $382 = HEAP8[$cache>>0]|0;
  $383 = ($382<<24>>24)==(0);
  $384 = ($80<<24>>24)==(0);
  $or$cond = $383 | $384;
  if ($or$cond) {
   $$be = $365;$$be1625 = $364;$$be1626 = $363;$$be1627 = $362;$$be1628 = $373;$$be1629 = $372;$$be1630 = $371;$$be1631 = $370;$$be1632 = $381;$$be1633 = $380;$$be1634 = $379;$$be1635 = $378;$$be1636 = $$lcssa;$$be1637 = $$lcssa1531;$$be1638 = $$lcssa1532;$$be1639 = $$lcssa1533;$$be1640 = $$lcssa1534;$$be1641 = $$lcssa1535;$$be1642 = $$lcssa1536;$$be1643 = $$lcssa1537;$$be1644 = $$lcssa1538;$$be1645 = $$lcssa1539;$$be1646 = $$lcssa1540;$$be1647 = $$lcssa1541;$prefetchAddress$0$be = $prefetchAddress$1$lcssa;
  } else {
   $386 = (($currPtr$01673) + 32|0);
   $387 = Math_fround(HEAPF32[$386>>2]);
   $388 = (($currPtr$01673) + 36|0);
   $389 = Math_fround(HEAPF32[$388>>2]);
   $390 = (($currPtr$01673) + 40|0);
   $391 = Math_fround(HEAPF32[$390>>2]);
   $392 = (($currPtr$01673) + 44|0);
   $393 = Math_fround(HEAPF32[$392>>2]);
   $394 = (($currPtr$01673) + 48|0);
   $395 = Math_fround(HEAPF32[$394>>2]);
   $396 = (($currPtr$01673) + 52|0);
   $397 = Math_fround(HEAPF32[$396>>2]);
   $398 = (($currPtr$01673) + 56|0);
   $399 = Math_fround(HEAPF32[$398>>2]);
   $400 = (($currPtr$01673) + 60|0);
   $401 = Math_fround(HEAPF32[$400>>2]);
   $402 = Math_fround($$lcssa1545 * $387);
   $403 = Math_fround($$lcssa1544 * $389);
   $404 = Math_fround($$lcssa1543 * $391);
   $405 = Math_fround($$lcssa1542 * $393);
   $406 = Math_fround($$lcssa1545 * $395);
   $407 = Math_fround($$lcssa1544 * $397);
   $408 = Math_fround($$lcssa1543 * $399);
   $409 = Math_fround($$lcssa1542 * $401);
   $410 = Math_fround(-$406);
   $411 = Math_fround(-$407);
   $412 = Math_fround(-$408);
   $413 = Math_fround(-$409);
   $74 = ($81*384)|0;
   $517 = $362;$519 = $363;$521 = $364;$523 = $365;$525 = $$lcssa1533;$527 = $$lcssa1532;$529 = $$lcssa1531;$531 = $$lcssa;$533 = $370;$535 = $371;$537 = $372;$539 = $373;$545 = $$lcssa1537;$547 = $$lcssa1536;$549 = $$lcssa1535;$551 = $$lcssa1534;$557 = $378;$559 = $379;$561 = $380;$563 = $381;$569 = $$lcssa1541;$571 = $$lcssa1540;$573 = $$lcssa1539;$575 = $$lcssa1538;$i1$01597 = 0;$prefetchAddress$21596 = $prefetchAddress$1$lcssa;
   while(1) {
    $414 = (($prefetchAddress$21596) + 128|0);
    $415 = (($prefetchAddress$21596) + 256|0);
    $416 = (($prefetchAddress$21596) + 384|0);
    $417 = HEAP8[$64>>0]|0;
    $418 = ($417<<24>>24)==(0);
    if (!($418)) {
     $419 = ((($82) + (($i1$01597*240)|0)|0) + 224|0);
     $420 = HEAP32[$419>>2]|0;
     $421 = ((($82) + (($i1$01597*240)|0)|0) + 228|0);
     $422 = HEAP32[$421>>2]|0;
     $423 = ((($82) + (($i1$01597*240)|0)|0) + 232|0);
     $424 = HEAP32[$423>>2]|0;
     $425 = ((($82) + (($i1$01597*240)|0)|0) + 236|0);
     $426 = HEAP32[$425>>2]|0;
    }
    $427 = ((($82) + (($i1$01597*240)|0)|0) + 112|0);
    $428 = Math_fround(HEAPF32[$427>>2]);
    $429 = ((($82) + (($i1$01597*240)|0)|0) + 116|0);
    $430 = Math_fround(HEAPF32[$429>>2]);
    $431 = ((($82) + (($i1$01597*240)|0)|0) + 120|0);
    $432 = Math_fround(HEAPF32[$431>>2]);
    $433 = ((($82) + (($i1$01597*240)|0)|0) + 124|0);
    $434 = Math_fround(HEAPF32[$433>>2]);
    $435 = ((($82) + (($i1$01597*240)|0)|0) + 128|0);
    $436 = Math_fround(HEAPF32[$435>>2]);
    $437 = ((($82) + (($i1$01597*240)|0)|0) + 132|0);
    $438 = Math_fround(HEAPF32[$437>>2]);
    $439 = ((($82) + (($i1$01597*240)|0)|0) + 136|0);
    $440 = Math_fround(HEAPF32[$439>>2]);
    $441 = ((($82) + (($i1$01597*240)|0)|0) + 140|0);
    $442 = Math_fround(HEAPF32[$441>>2]);
    $443 = ((($82) + (($i1$01597*240)|0)|0) + 144|0);
    $444 = Math_fround(HEAPF32[$443>>2]);
    $445 = ((($82) + (($i1$01597*240)|0)|0) + 148|0);
    $446 = Math_fround(HEAPF32[$445>>2]);
    $447 = ((($82) + (($i1$01597*240)|0)|0) + 152|0);
    $448 = Math_fround(HEAPF32[$447>>2]);
    $449 = ((($82) + (($i1$01597*240)|0)|0) + 156|0);
    $450 = Math_fround(HEAPF32[$449>>2]);
    $451 = ((($82) + (($i1$01597*240)|0)|0) + 48|0);
    $452 = Math_fround(HEAPF32[$451>>2]);
    $453 = ((($82) + (($i1$01597*240)|0)|0) + 52|0);
    $454 = Math_fround(HEAPF32[$453>>2]);
    $455 = ((($82) + (($i1$01597*240)|0)|0) + 56|0);
    $456 = Math_fround(HEAPF32[$455>>2]);
    $457 = ((($82) + (($i1$01597*240)|0)|0) + 60|0);
    $458 = Math_fround(HEAPF32[$457>>2]);
    $459 = ((($82) + (($i1$01597*240)|0)|0) + 208|0);
    $460 = Math_fround(HEAPF32[$459>>2]);
    $461 = ((($82) + (($i1$01597*240)|0)|0) + 212|0);
    $462 = Math_fround(HEAPF32[$461>>2]);
    $463 = ((($82) + (($i1$01597*240)|0)|0) + 216|0);
    $464 = Math_fround(HEAPF32[$463>>2]);
    $465 = ((($82) + (($i1$01597*240)|0)|0) + 220|0);
    $466 = Math_fround(HEAPF32[$465>>2]);
    $467 = (($82) + (($i1$01597*240)|0)|0);
    $468 = Math_fround(HEAPF32[$467>>2]);
    $469 = ((($82) + (($i1$01597*240)|0)|0) + 4|0);
    $470 = Math_fround(HEAPF32[$469>>2]);
    $471 = ((($82) + (($i1$01597*240)|0)|0) + 8|0);
    $472 = Math_fround(HEAPF32[$471>>2]);
    $473 = ((($82) + (($i1$01597*240)|0)|0) + 12|0);
    $474 = Math_fround(HEAPF32[$473>>2]);
    $475 = ((($82) + (($i1$01597*240)|0)|0) + 16|0);
    $476 = Math_fround(HEAPF32[$475>>2]);
    $477 = ((($82) + (($i1$01597*240)|0)|0) + 20|0);
    $478 = Math_fround(HEAPF32[$477>>2]);
    $479 = ((($82) + (($i1$01597*240)|0)|0) + 24|0);
    $480 = Math_fround(HEAPF32[$479>>2]);
    $481 = ((($82) + (($i1$01597*240)|0)|0) + 28|0);
    $482 = Math_fround(HEAPF32[$481>>2]);
    $483 = ((($82) + (($i1$01597*240)|0)|0) + 32|0);
    $484 = Math_fround(HEAPF32[$483>>2]);
    $485 = ((($82) + (($i1$01597*240)|0)|0) + 36|0);
    $486 = Math_fround(HEAPF32[$485>>2]);
    $487 = ((($82) + (($i1$01597*240)|0)|0) + 40|0);
    $488 = Math_fround(HEAPF32[$487>>2]);
    $489 = ((($82) + (($i1$01597*240)|0)|0) + 44|0);
    $490 = Math_fround(HEAPF32[$489>>2]);
    $491 = ((($82) + (($i1$01597*240)|0)|0) + 64|0);
    $492 = Math_fround(HEAPF32[$491>>2]);
    $493 = ((($82) + (($i1$01597*240)|0)|0) + 68|0);
    $494 = Math_fround(HEAPF32[$493>>2]);
    $495 = ((($82) + (($i1$01597*240)|0)|0) + 72|0);
    $496 = Math_fround(HEAPF32[$495>>2]);
    $497 = ((($82) + (($i1$01597*240)|0)|0) + 76|0);
    $498 = Math_fround(HEAPF32[$497>>2]);
    $499 = ((($82) + (($i1$01597*240)|0)|0) + 80|0);
    $500 = Math_fround(HEAPF32[$499>>2]);
    $501 = ((($82) + (($i1$01597*240)|0)|0) + 84|0);
    $502 = Math_fround(HEAPF32[$501>>2]);
    $503 = ((($82) + (($i1$01597*240)|0)|0) + 88|0);
    $504 = Math_fround(HEAPF32[$503>>2]);
    $505 = ((($82) + (($i1$01597*240)|0)|0) + 92|0);
    $506 = Math_fround(HEAPF32[$505>>2]);
    $507 = ((($82) + (($i1$01597*240)|0)|0) + 96|0);
    $508 = Math_fround(HEAPF32[$507>>2]);
    $509 = ((($82) + (($i1$01597*240)|0)|0) + 100|0);
    $510 = Math_fround(HEAPF32[$509>>2]);
    $511 = ((($82) + (($i1$01597*240)|0)|0) + 104|0);
    $512 = Math_fround(HEAPF32[$511>>2]);
    $513 = ((($82) + (($i1$01597*240)|0)|0) + 108|0);
    $514 = Math_fround(HEAPF32[$513>>2]);
    $515 = ((($82) + (($i1$01597*240)|0)|0) + 176|0);
    ;HEAP32[$oldBroken+0>>2]=HEAP32[$515+0>>2]|0;HEAP32[$oldBroken+4>>2]=HEAP32[$515+4>>2]|0;HEAP32[$oldBroken+8>>2]=HEAP32[$515+8>>2]|0;HEAP32[$oldBroken+12>>2]=HEAP32[$515+12>>2]|0;
    $516 = Math_fround($517 * $468);
    $518 = Math_fround($519 * $470);
    $520 = Math_fround($521 * $472);
    $522 = Math_fround($523 * $474);
    $524 = Math_fround($525 * $492);
    $526 = Math_fround($527 * $494);
    $528 = Math_fround($529 * $496);
    $530 = Math_fround($531 * $498);
    $532 = Math_fround($533 * $476);
    $534 = Math_fround($535 * $478);
    $536 = Math_fround($537 * $480);
    $538 = Math_fround($539 * $482);
    $540 = Math_fround($516 + $532);
    $541 = Math_fround($518 + $534);
    $542 = Math_fround($520 + $536);
    $543 = Math_fround($522 + $538);
    $544 = Math_fround($545 * $500);
    $546 = Math_fround($547 * $502);
    $548 = Math_fround($549 * $504);
    $550 = Math_fround($551 * $506);
    $552 = Math_fround($524 + $544);
    $553 = Math_fround($526 + $546);
    $554 = Math_fround($528 + $548);
    $555 = Math_fround($530 + $550);
    $556 = Math_fround($557 * $484);
    $558 = Math_fround($559 * $486);
    $560 = Math_fround($561 * $488);
    $562 = Math_fround($563 * $490);
    $564 = Math_fround($540 + $556);
    $565 = Math_fround($541 + $558);
    $566 = Math_fround($542 + $560);
    $567 = Math_fround($543 + $562);
    $568 = Math_fround($569 * $508);
    $570 = Math_fround($571 * $510);
    $572 = Math_fround($573 * $512);
    $574 = Math_fround($575 * $514);
    $576 = Math_fround($552 + $568);
    $577 = Math_fround($553 + $570);
    $578 = Math_fround($554 + $572);
    $579 = Math_fround($555 + $574);
    $580 = Math_fround($564 + $576);
    $581 = Math_fround($565 + $577);
    $582 = Math_fround($566 + $578);
    $583 = Math_fround($567 + $579);
    $584 = ((($82) + (($i1$01597*240)|0)|0) + 160|0);
    $585 = Math_fround(HEAPF32[$584>>2]);
    $586 = ((($82) + (($i1$01597*240)|0)|0) + 164|0);
    $587 = Math_fround(HEAPF32[$586>>2]);
    $588 = ((($82) + (($i1$01597*240)|0)|0) + 168|0);
    $589 = Math_fround(HEAPF32[$588>>2]);
    $590 = ((($82) + (($i1$01597*240)|0)|0) + 172|0);
    $591 = Math_fround(HEAPF32[$590>>2]);
    $592 = Math_fround($452 - $585);
    $593 = Math_fround($454 - $587);
    $594 = Math_fround($456 - $589);
    $595 = Math_fround($458 - $591);
    $596 = Math_fround($460 * $580);
    $597 = Math_fround($462 * $581);
    $598 = Math_fround($464 * $582);
    $599 = Math_fround($466 * $583);
    $600 = Math_fround($592 - $596);
    $601 = Math_fround($593 - $597);
    $602 = Math_fround($594 - $598);
    $603 = Math_fround($595 - $599);
    $604 = Math_fround(-$600);
    $605 = Math_fround(-$601);
    $606 = Math_fround(-$602);
    $607 = Math_fround(-$603);
    $608 = $600 > $604;
    $$$i$i = $608 ? $600 : $604;
    $609 = $601 > $605;
    $610 = $609 ? $601 : $605;
    $611 = $602 > $606;
    $$1$i$i = $611 ? $602 : $606;
    $612 = $603 > $607;
    $613 = $612 ? $603 : $607;
    $614 = $$$i$i > $402;
    $615 = $610 > $403;
    $616 = $$1$i$i > $404;
    $617 = $613 > $405;
    $618 = $600 < $410;
    $$$i105 = $618 ? $410 : $600;
    $619 = $601 < $411;
    $620 = $619 ? $411 : $601;
    $621 = $602 < $412;
    $$1$i106 = $621 ? $412 : $602;
    $622 = $603 < $413;
    $623 = $622 ? $413 : $603;
    $624 = $406 < $$$i105;
    $$$i = $624 ? $406 : $$$i105;
    $625 = $407 < $620;
    $626 = $625 ? $407 : $620;
    $627 = $408 < $$1$i106;
    $$1$i = $627 ? $408 : $$1$i106;
    $628 = $409 < $623;
    $629 = $628 ? $409 : $623;
    HEAPF32[$1>>2] = $$$i;
    HEAPF32[$65>>2] = $626;
    HEAPF32[$66>>2] = $$1$i;
    HEAPF32[$67>>2] = $629;
    HEAPF32[$0>>2] = $600;
    HEAPF32[$68>>2] = $601;
    HEAPF32[$69>>2] = $602;
    HEAPF32[$70>>2] = $603;
    $b$a$i89 = $614 ? $1 : $0;
    $630 = Math_fround(HEAPF32[$b$a$i89>>2]);
    $a$pn4$i91 = $615 ? $1 : $0;
    $$in1$i92 = (($a$pn4$i91) + 4|0);
    $631 = Math_fround(HEAPF32[$$in1$i92>>2]);
    $b$a7$i93 = $616 ? $1 : $0;
    $$in2$i94 = (($b$a7$i93) + 8|0);
    $632 = Math_fround(HEAPF32[$$in2$i94>>2]);
    $a$pn6$i95 = $617 ? $1 : $0;
    $$in3$i96 = (($a$pn6$i95) + 12|0);
    $633 = Math_fround(HEAPF32[$$in3$i96>>2]);
    ;HEAP32[$2+0>>2]=HEAP32[$oldBroken+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$oldBroken+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$oldBroken+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$oldBroken+12>>2]|0;
    HEAPF32[$3>>2] = Math_fround(1.0);
    HEAPF32[$71>>2] = Math_fround(1.0);
    HEAPF32[$72>>2] = Math_fround(1.0);
    HEAPF32[$73>>2] = Math_fround(1.0);
    $b$a$i = $614 ? $3 : $2;
    $634 = Math_fround(HEAPF32[$b$a$i>>2]);
    $a$pn4$i = $615 ? $3 : $2;
    $$in1$i = (($a$pn4$i) + 4|0);
    $635 = Math_fround(HEAPF32[$$in1$i>>2]);
    $b$a7$i = $616 ? $3 : $2;
    $$in2$i = (($b$a7$i) + 8|0);
    $636 = Math_fround(HEAPF32[$$in2$i>>2]);
    $a$pn6$i = $617 ? $3 : $2;
    $$in3$i = (($a$pn6$i) + 12|0);
    $637 = Math_fround(HEAPF32[$$in3$i>>2]);
    $638 = Math_fround($630 - $452);
    $639 = Math_fround($631 - $454);
    $640 = Math_fround($632 - $456);
    $641 = Math_fround($633 - $458);
    $642 = Math_fround($86 * $638);
    $643 = Math_fround($88 * $639);
    $644 = Math_fround($90 * $640);
    $645 = Math_fround($92 * $641);
    $646 = Math_fround($468 * $642);
    $647 = Math_fround($470 * $643);
    $648 = Math_fround($472 * $644);
    $649 = Math_fround($474 * $645);
    $650 = Math_fround($517 + $646);
    $651 = Math_fround($519 + $647);
    $652 = Math_fround($521 + $648);
    $653 = Math_fround($523 + $649);
    $654 = Math_fround($428 * $638);
    $655 = Math_fround($430 * $639);
    $656 = Math_fround($432 * $640);
    $657 = Math_fround($434 * $641);
    $658 = Math_fround($525 + $654);
    $659 = Math_fround($527 + $655);
    $660 = Math_fround($529 + $656);
    $661 = Math_fround($531 + $657);
    $662 = Math_fround($476 * $642);
    $663 = Math_fround($478 * $643);
    $664 = Math_fround($480 * $644);
    $665 = Math_fround($482 * $645);
    $666 = Math_fround($533 + $662);
    $667 = Math_fround($535 + $663);
    $668 = Math_fround($537 + $664);
    $669 = Math_fround($539 + $665);
    $670 = Math_fround($436 * $638);
    $671 = Math_fround($438 * $639);
    $672 = Math_fround($440 * $640);
    $673 = Math_fround($442 * $641);
    $674 = Math_fround($545 + $670);
    $675 = Math_fround($547 + $671);
    $676 = Math_fround($549 + $672);
    $677 = Math_fround($551 + $673);
    $678 = Math_fround($484 * $642);
    $679 = Math_fround($486 * $643);
    $680 = Math_fround($488 * $644);
    $681 = Math_fround($490 * $645);
    $682 = Math_fround($557 + $678);
    $683 = Math_fround($559 + $679);
    $684 = Math_fround($561 + $680);
    $685 = Math_fround($563 + $681);
    $686 = Math_fround($444 * $638);
    $687 = Math_fround($446 * $639);
    $688 = Math_fround($448 * $640);
    $689 = Math_fround($450 * $641);
    $690 = Math_fround($569 + $686);
    $691 = Math_fround($571 + $687);
    $692 = Math_fround($573 + $688);
    $693 = Math_fround($575 + $689);
    HEAPF32[$451>>2] = $630;
    HEAPF32[$453>>2] = $631;
    HEAPF32[$455>>2] = $632;
    HEAPF32[$457>>2] = $633;
    HEAPF32[$515>>2] = $634;
    $694 = ((($82) + (($i1$01597*240)|0)|0) + 180|0);
    HEAPF32[$694>>2] = $635;
    $695 = ((($82) + (($i1$01597*240)|0)|0) + 184|0);
    HEAPF32[$695>>2] = $636;
    $696 = ((($82) + (($i1$01597*240)|0)|0) + 188|0);
    HEAPF32[$696>>2] = $637;
    $697 = (($i1$01597) + 1)|0;
    $exitcond1748 = ($697|0)==($81|0);
    if ($exitcond1748) {
     break;
    } else {
     $517 = $650;$519 = $651;$521 = $652;$523 = $653;$525 = $658;$527 = $659;$529 = $660;$531 = $661;$533 = $666;$535 = $667;$537 = $668;$539 = $669;$545 = $674;$547 = $675;$549 = $676;$551 = $677;$557 = $682;$559 = $683;$561 = $684;$563 = $685;$569 = $690;$571 = $691;$573 = $692;$575 = $693;$i1$01597 = $697;$prefetchAddress$21596 = $416;
    }
   }
   $scevgep1747 = (($prefetchAddress$1$lcssa) + ($74)|0);
   $$be = $653;$$be1625 = $652;$$be1626 = $651;$$be1627 = $650;$$be1628 = $669;$$be1629 = $668;$$be1630 = $667;$$be1631 = $666;$$be1632 = $685;$$be1633 = $684;$$be1634 = $683;$$be1635 = $682;$$be1636 = $661;$$be1637 = $660;$$be1638 = $659;$$be1639 = $658;$$be1640 = $677;$$be1641 = $676;$$be1642 = $675;$$be1643 = $674;$$be1644 = $693;$$be1645 = $692;$$be1646 = $691;$$be1647 = $690;$prefetchAddress$0$be = $scevgep1747;
  }
  $385 = ($84>>>0)<($17>>>0);
  if ($385) {
   $119 = $$be1628;$121 = $$be1629;$123 = $$be1630;$125 = $$be1631;$127 = $$be;$129 = $$be1625;$131 = $$be1626;$133 = $$be1627;$135 = $$be1632;$137 = $$be1633;$139 = $$be1634;$141 = $$be1635;$714 = $$be1647;$715 = $$be1646;$716 = $$be1645;$717 = $$be1644;$718 = $$be1643;$719 = $$be1642;$720 = $$be1641;$721 = $$be1640;$722 = $$be1639;$723 = $$be1638;$724 = $$be1637;$725 = $$be1636;$currPtr$01673 = $84;$prefetchAddress$01672 = $prefetchAddress$0$be;
  } else {
   $$lcssa1648 = $$be;$$lcssa1649 = $$be1625;$$lcssa1650 = $$be1626;$$lcssa1651 = $$be1627;$$lcssa1652 = $$be1628;$$lcssa1653 = $$be1629;$$lcssa1654 = $$be1630;$$lcssa1655 = $$be1631;$$lcssa1656 = $$be1632;$$lcssa1657 = $$be1633;$$lcssa1658 = $$be1634;$$lcssa1659 = $$be1635;$$lcssa1660 = $$be1636;$$lcssa1661 = $$be1637;$$lcssa1662 = $$be1638;$$lcssa1663 = $$be1639;$$lcssa1664 = $$be1640;$$lcssa1665 = $$be1641;$$lcssa1666 = $$be1642;$$lcssa1667 = $$be1643;$$lcssa1668 = $$be1644;$$lcssa1669 = $$be1645;$$lcssa1670 = $$be1646;$$lcssa1671 = $$be1647;
   break;
  }
 }
 HEAPF32[$4>>2] = $$lcssa1651;
 $698 = (($4) + 4|0);
 HEAPF32[$698>>2] = $$lcssa1655;
 $699 = (($4) + 8|0);
 HEAPF32[$699>>2] = $$lcssa1659;
 HEAPF32[$6>>2] = $$lcssa1650;
 $700 = (($6) + 4|0);
 HEAPF32[$700>>2] = $$lcssa1654;
 $701 = (($6) + 8|0);
 HEAPF32[$701>>2] = $$lcssa1658;
 HEAPF32[$8>>2] = $$lcssa1649;
 $702 = (($8) + 4|0);
 HEAPF32[$702>>2] = $$lcssa1653;
 $703 = (($8) + 8|0);
 HEAPF32[$703>>2] = $$lcssa1657;
 HEAPF32[$10>>2] = $$lcssa1648;
 $704 = (($10) + 4|0);
 HEAPF32[$704>>2] = $$lcssa1652;
 $705 = (($10) + 8|0);
 HEAPF32[$705>>2] = $$lcssa1656;
 HEAPF32[$23>>2] = $$lcssa1663;
 $706 = (($4) + 20|0);
 HEAPF32[$706>>2] = $$lcssa1667;
 $707 = (($4) + 24|0);
 HEAPF32[$707>>2] = $$lcssa1671;
 HEAPF32[$34>>2] = $$lcssa1662;
 $708 = (($6) + 20|0);
 HEAPF32[$708>>2] = $$lcssa1666;
 $709 = (($6) + 24|0);
 HEAPF32[$709>>2] = $$lcssa1670;
 HEAPF32[$45>>2] = $$lcssa1661;
 $710 = (($8) + 20|0);
 HEAPF32[$710>>2] = $$lcssa1665;
 $711 = (($8) + 24|0);
 HEAPF32[$711>>2] = $$lcssa1669;
 HEAPF32[$56>>2] = $$lcssa1660;
 $712 = (($10) + 20|0);
 HEAPF32[$712>>2] = $$lcssa1664;
 $713 = (($10) + 24|0);
 HEAPF32[$713>>2] = $$lcssa1668;
 STACKTOP = sp;return;
}
function __ZN5physx29solveContactPreBlock_ConcludeEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var $desc$idx = 0, $desc$idx$val = 0, $desc$idx1 = 0, $desc$idx1$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL19solveContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $desc$idx = (($desc) + 16|0);
 $desc$idx$val = HEAP32[$desc$idx>>2]|0;
 $desc$idx1 = (($desc) + 26|0);
 $desc$idx1$val = HEAP16[$desc$idx1>>1]|0;
 __ZN5physxL22concludeContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEjj($desc$idx$val,$desc$idx1$val,$cache,272,336);
 STACKTOP = sp;return;
}
function __ZN5physxL22concludeContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEjj($desc$0$6$val,$desc$0$9$val,$cache,$contactSize,$frictionSize) {
 $desc$0$6$val = $desc$0$6$val|0;
 $desc$0$9$val = $desc$0$9$val|0;
 $cache = $cache|0;
 $contactSize = $contactSize|0;
 $frictionSize = $frictionSize|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $7 = 0, $8 = 0, $9 = 0, $contacts$0$in38 = 0, $currPtr$042 = 0, $exitcond = 0, $exitcond46 = 0, $frictions$0$in39 = 0, $i$037 = 0, $i1$040 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $desc$0$9$val&65535;
 $1 = $0 << 4;
 $2 = (($desc$0$6$val) + ($1)|0);
 $3 = ($desc$0$9$val<<16>>16)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $currPtr$042 = $desc$0$6$val;
 while(1) {
  $4 = (($currPtr$042) + 1|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = (($currPtr$042) + 2|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = $8&255;
  $10 = Math_imul($6, $contactSize)|0;
  $$sum = (($10) + 144)|0;
  $11 = (($currPtr$042) + ($$sum)|0);
  $12 = Math_imul($9, $frictionSize)|0;
  $$sum1 = (($$sum) + ($12))|0;
  $13 = (($currPtr$042) + ($$sum1)|0);
  $14 = ($5<<24>>24)==(0);
  if (!($14)) {
   $15 = (($currPtr$042) + 144|0);
   $contacts$0$in38 = $15;$i$037 = 0;
   while(1) {
    $16 = (($contacts$0$in38) + ($contactSize)|0);
    $17 = (($contacts$0$in38) + 144|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = (($contacts$0$in38) + 148|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = (($contacts$0$in38) + 152|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = (($contacts$0$in38) + 156|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = (($contacts$0$in38) + 128|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = (($contacts$0$in38) + 132|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = (($contacts$0$in38) + 136|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = (($contacts$0$in38) + 140|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = Math_fround($18 - $26);
    $34 = Math_fround($20 - $28);
    $35 = Math_fround($22 - $30);
    $36 = Math_fround($24 - $32);
    HEAPF32[$17>>2] = $33;
    HEAPF32[$19>>2] = $34;
    HEAPF32[$21>>2] = $35;
    HEAPF32[$23>>2] = $36;
    $37 = (($i$037) + 1)|0;
    $exitcond = ($37|0)==($6|0);
    if ($exitcond) {
     break;
    } else {
     $contacts$0$in38 = $16;$i$037 = $37;
    }
   }
  }
  $38 = HEAP8[$cache>>0]|0;
  $39 = ($38<<24>>24)==(0);
  $40 = ($8<<24>>24)==(0);
  $or$cond = $39 | $40;
  if (!($or$cond)) {
   $frictions$0$in39 = $11;$i1$040 = 0;
   while(1) {
    $42 = (($frictions$0$in39) + ($frictionSize)|0);
    $43 = (($frictions$0$in39) + 160|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = (($frictions$0$in39) + 164|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = (($frictions$0$in39) + 168|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = (($frictions$0$in39) + 172|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = (($frictions$0$in39) + 192|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = (($frictions$0$in39) + 196|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = (($frictions$0$in39) + 200|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = (($frictions$0$in39) + 204|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($44 - $52);
    $60 = Math_fround($46 - $54);
    $61 = Math_fround($48 - $56);
    $62 = Math_fround($50 - $58);
    HEAPF32[$43>>2] = $59;
    HEAPF32[$45>>2] = $60;
    HEAPF32[$47>>2] = $61;
    HEAPF32[$49>>2] = $62;
    $63 = (($i1$040) + 1)|0;
    $exitcond46 = ($63|0)==($9|0);
    if ($exitcond46) {
     break;
    } else {
     $frictions$0$in39 = $42;$i1$040 = $63;
    }
   }
  }
  $41 = ($13>>>0)<($2>>>0);
  if ($41) {
   $currPtr$042 = $13;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx35solveContactPreBlock_ConcludeStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var $desc$idx = 0, $desc$idx$val = 0, $desc$idx1 = 0, $desc$idx1$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL25solveContact4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $desc$idx = (($desc) + 16|0);
 $desc$idx$val = HEAP32[$desc$idx>>2]|0;
 $desc$idx1 = (($desc) + 26|0);
 $desc$idx1$val = HEAP16[$desc$idx1>>1]|0;
 __ZN5physxL22concludeContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEjj($desc$idx$val,$desc$idx1$val,$cache,176,240);
 STACKTOP = sp;return;
}
function __ZN5physx30solveContactPreBlock_WriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$0,$cache,$thresholdStream,$1,$outThresholdPairs) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $1 = $1|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $bd0 = 0;
 var $bd1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bd0 = sp + 16|0;
 $bd1 = sp;
 __ZN5physxL19solveContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $2 = (($desc) + 10|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($cache) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<6)|0);
 HEAP32[$bd0>>2] = $7;
 $8 = (($bd0) + 4|0);
 $9 = (($desc) + 42|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 $12 = (($6) + ($11<<6)|0);
 HEAP32[$8>>2] = $12;
 $13 = (($bd0) + 8|0);
 $14 = (($desc) + 74|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = (($6) + ($16<<6)|0);
 HEAP32[$13>>2] = $17;
 $18 = (($bd0) + 12|0);
 $19 = (($desc) + 106|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = $20&65535;
 $22 = (($6) + ($21<<6)|0);
 HEAP32[$18>>2] = $22;
 $23 = (($desc) + 14|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = $24&65535;
 $26 = (($6) + ($25<<6)|0);
 HEAP32[$bd1>>2] = $26;
 $27 = (($bd1) + 4|0);
 $28 = (($desc) + 46|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = $29&65535;
 $31 = (($6) + ($30<<6)|0);
 HEAP32[$27>>2] = $31;
 $32 = (($bd1) + 8|0);
 $33 = (($desc) + 78|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = $34&65535;
 $36 = (($6) + ($35<<6)|0);
 HEAP32[$32>>2] = $36;
 $37 = (($bd1) + 12|0);
 $38 = (($desc) + 110|0);
 $39 = HEAP16[$38>>1]|0;
 $40 = $39&65535;
 $41 = (($6) + ($40<<6)|0);
 HEAP32[$37>>2] = $41;
 __ZN5physx23writeBackContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEPPKNS_17PxcSolverBodyDataES8_($desc,$cache,$bd0,$bd1);
 $42 = (($cache) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($cache) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + -4)|0;
 $47 = ($43>>>0)>($46>>>0);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$43)|0);
 $49 = HEAP32[$42>>2]|0;
 $50 = (($48) - ($49))|0;
 $51 = ($49|0)==(0);
 if (!($51)) {
  $52 = (($cache) + 4|0);
  $a$01 = 0;
  while(1) {
   $53 = (($50) + ($a$01))|0;
   $54 = (($thresholdStream) + ($53<<4)|0);
   $55 = HEAP32[$52>>2]|0;
   $56 = (($55) + ($a$01<<4)|0);
   ;HEAP32[$54+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$56+12>>2]|0;
   $57 = (($a$01) + 1)|0;
   $58 = HEAP32[$42>>2]|0;
   $59 = ($57>>>0)<($58>>>0);
   if ($59) {
    $a$01 = $57;
   } else {
    break;
   }
  }
 }
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx36solveContactPreBlock_WriteBackStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$0,$cache,$thresholdStream,$1,$outThresholdPairs) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $1 = $1|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $bd0 = 0;
 var $bd1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bd0 = sp + 16|0;
 $bd1 = sp;
 __ZN5physxL25solveContact4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 $2 = (($desc) + 10|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($cache) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<6)|0);
 HEAP32[$bd0>>2] = $7;
 $8 = (($bd0) + 4|0);
 $9 = (($desc) + 42|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 $12 = (($6) + ($11<<6)|0);
 HEAP32[$8>>2] = $12;
 $13 = (($bd0) + 8|0);
 $14 = (($desc) + 74|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = (($6) + ($16<<6)|0);
 HEAP32[$13>>2] = $17;
 $18 = (($bd0) + 12|0);
 $19 = (($desc) + 106|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = $20&65535;
 $22 = (($6) + ($21<<6)|0);
 HEAP32[$18>>2] = $22;
 $23 = (($desc) + 14|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = $24&65535;
 $26 = (($6) + ($25<<6)|0);
 HEAP32[$bd1>>2] = $26;
 $27 = (($bd1) + 4|0);
 $28 = (($desc) + 46|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = $29&65535;
 $31 = (($6) + ($30<<6)|0);
 HEAP32[$27>>2] = $31;
 $32 = (($bd1) + 8|0);
 $33 = (($desc) + 78|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = $34&65535;
 $36 = (($6) + ($35<<6)|0);
 HEAP32[$32>>2] = $36;
 $37 = (($bd1) + 12|0);
 $38 = (($desc) + 110|0);
 $39 = HEAP16[$38>>1]|0;
 $40 = $39&65535;
 $41 = (($6) + ($40<<6)|0);
 HEAP32[$37>>2] = $41;
 __ZN5physx23writeBackContact4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEPPKNS_17PxcSolverBodyDataES8_($desc,$cache,$bd0,$bd1);
 $42 = (($cache) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($cache) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + -4)|0;
 $47 = ($43>>>0)>($46>>>0);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$43)|0);
 $49 = HEAP32[$42>>2]|0;
 $50 = (($48) - ($49))|0;
 $51 = ($49|0)==(0);
 if (!($51)) {
  $52 = (($cache) + 4|0);
  $a$01 = 0;
  while(1) {
   $53 = (($50) + ($a$01))|0;
   $54 = (($thresholdStream) + ($53<<4)|0);
   $55 = HEAP32[$52>>2]|0;
   $56 = (($55) + ($a$01<<4)|0);
   ;HEAP32[$54+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$56+12>>2]|0;
   $57 = (($a$01) + 1)|0;
   $58 = HEAP32[$42>>2]|0;
   $59 = ($57>>>0)<($58>>>0);
   if ($59) {
    $a$01 = $57;
   } else {
    break;
   }
  }
 }
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx14solve1D4_BlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL14solve1D4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physxL14solve1D4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc) {
 $desc = $desc|0;
 var $$$i = Math_fround(0), $$$i156 = Math_fround(0), $$1$i = Math_fround(0), $$1$i157 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa1506 = Math_fround(0), $$lcssa1507 = Math_fround(0), $$lcssa1508 = Math_fround(0), $$lcssa1509 = Math_fround(0), $$lcssa1510 = Math_fround(0), $$lcssa1511 = Math_fround(0), $$lcssa1512 = Math_fround(0), $$lcssa1513 = Math_fround(0), $$lcssa1514 = Math_fround(0), $$lcssa1515 = Math_fround(0), $$lcssa1516 = Math_fround(0), $$lcssa1517 = Math_fround(0), $$lcssa1518 = Math_fround(0), $$lcssa1519 = Math_fround(0), $$lcssa1520 = Math_fround(0);
 var $$lcssa1521 = Math_fround(0), $$lcssa1522 = Math_fround(0), $$lcssa1523 = Math_fround(0), $$lcssa1524 = Math_fround(0), $$lcssa1525 = Math_fround(0), $$lcssa1526 = Math_fround(0), $$lcssa1527 = Math_fround(0), $$lcssa1528 = Math_fround(0), $$lcssa1529 = Math_fround(0), $$lcssa1530 = Math_fround(0), $$lcssa1531 = Math_fround(0), $$lcssa1532 = Math_fround(0), $$lcssa1533 = Math_fround(0), $$lcssa1534 = Math_fround(0), $$lcssa1535 = Math_fround(0), $$lcssa1536 = Math_fround(0), $$lcssa1537 = Math_fround(0), $$lcssa1538 = Math_fround(0), $$lcssa1539 = Math_fround(0), $$lcssa1540 = Math_fround(0);
 var $$lcssa1541 = Math_fround(0), $$lcssa1542 = Math_fround(0), $$lcssa1543 = Math_fround(0), $$lcssa1544 = Math_fround(0), $$lcssa1545 = Math_fround(0), $$lcssa1546 = Math_fround(0), $$lcssa1547 = Math_fround(0), $$lcssa1548 = Math_fround(0), $$lcssa1549 = Math_fround(0), $$lcssa1550 = Math_fround(0), $$lcssa1551 = Math_fround(0), $$lcssa1552 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0);
 var $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0);
 var $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0;
 var $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0);
 var $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0);
 var $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0;
 var $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0;
 var $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0);
 var $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0);
 var $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0);
 var $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = 0;
 var $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0);
 var $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0);
 var $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0);
 var $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0);
 var $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0);
 var $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0);
 var $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = Math_fround(0), $482 = 0, $483 = 0;
 var $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0);
 var $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0);
 var $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0);
 var $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0);
 var $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0);
 var $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0);
 var $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0;
 var $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0;
 var $628 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0);
 var $99 = 0, $a$01553 = 0, $base$01554 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($desc) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($desc) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($desc) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($desc) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($desc) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($desc) + 100|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($desc) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = Math_fround(HEAPF32[$0>>2]);
 $18 = (($0) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($0) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(HEAPF32[$2>>2]);
 $23 = (($2) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($2) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($0) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($27) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($27) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($2) + 16|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($33) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($33) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(HEAPF32[$4>>2]);
 $40 = (($4) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($4) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(HEAPF32[$6>>2]);
 $45 = (($6) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($6) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($4) + 16|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($49) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($49) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($6) + 16|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($55) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($55) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround(HEAPF32[$8>>2]);
 $62 = (($8) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($8) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround(HEAPF32[$10>>2]);
 $67 = (($10) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($10) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($8) + 16|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($71) + 4|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($71) + 8|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($10) + 16|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($77) + 4|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($77) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround(HEAPF32[$12>>2]);
 $84 = (($12) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($12) + 8|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround(HEAPF32[$14>>2]);
 $89 = (($14) + 4|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($14) + 8|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($12) + 16|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($93) + 4|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($93) + 8|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($14) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($99) + 4|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($99) + 8|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($16) + 48|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($16) + 52|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($16) + 56|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($16) + 60|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($16) + 64|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($16) + 68|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (($16) + 72|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($16) + 76|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($16) + 4|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($122|0)==(0);
 if ($123) {
  $$lcssa = $83;$$lcssa1506 = $61;$$lcssa1507 = $39;$$lcssa1508 = $17;$$lcssa1509 = $85;$$lcssa1510 = $63;$$lcssa1511 = $41;$$lcssa1512 = $19;$$lcssa1513 = $87;$$lcssa1514 = $65;$$lcssa1515 = $43;$$lcssa1516 = $21;$$lcssa1517 = $88;$$lcssa1518 = $66;$$lcssa1519 = $44;$$lcssa1520 = $22;$$lcssa1521 = $90;$$lcssa1522 = $68;$$lcssa1523 = $46;$$lcssa1524 = $24;$$lcssa1525 = $92;$$lcssa1526 = $70;$$lcssa1527 = $48;$$lcssa1528 = $26;$$lcssa1529 = $94;$$lcssa1530 = $72;$$lcssa1531 = $50;$$lcssa1532 = $28;$$lcssa1533 = $96;$$lcssa1534 = $74;$$lcssa1535 = $52;$$lcssa1536 = $30;$$lcssa1537 = $98;$$lcssa1538 = $76;$$lcssa1539 = $54;$$lcssa1540 = $32;$$lcssa1541 = $100;$$lcssa1542 = $78;$$lcssa1543 = $56;$$lcssa1544 = $34;$$lcssa1545 = $102;$$lcssa1546 = $80;$$lcssa1547 = $58;$$lcssa1548 = $36;$$lcssa1549 = $104;$$lcssa1550 = $82;$$lcssa1551 = $60;$$lcssa1552 = $38;
  HEAPF32[$0>>2] = $$lcssa1508;
  $597 = (($0) + 4|0);
  HEAPF32[$597>>2] = $$lcssa1512;
  $598 = (($0) + 8|0);
  HEAPF32[$598>>2] = $$lcssa1516;
  HEAPF32[$4>>2] = $$lcssa1507;
  $599 = (($4) + 4|0);
  HEAPF32[$599>>2] = $$lcssa1511;
  $600 = (($4) + 8|0);
  HEAPF32[$600>>2] = $$lcssa1515;
  HEAPF32[$8>>2] = $$lcssa1506;
  $601 = (($8) + 4|0);
  HEAPF32[$601>>2] = $$lcssa1510;
  $602 = (($8) + 8|0);
  HEAPF32[$602>>2] = $$lcssa1514;
  HEAPF32[$12>>2] = $$lcssa;
  $603 = (($12) + 4|0);
  HEAPF32[$603>>2] = $$lcssa1509;
  $604 = (($12) + 8|0);
  HEAPF32[$604>>2] = $$lcssa1513;
  HEAPF32[$2>>2] = $$lcssa1520;
  $605 = (($2) + 4|0);
  HEAPF32[$605>>2] = $$lcssa1524;
  $606 = (($2) + 8|0);
  HEAPF32[$606>>2] = $$lcssa1528;
  HEAPF32[$6>>2] = $$lcssa1519;
  $607 = (($6) + 4|0);
  HEAPF32[$607>>2] = $$lcssa1523;
  $608 = (($6) + 8|0);
  HEAPF32[$608>>2] = $$lcssa1527;
  HEAPF32[$10>>2] = $$lcssa1518;
  $609 = (($10) + 4|0);
  HEAPF32[$609>>2] = $$lcssa1522;
  $610 = (($10) + 8|0);
  HEAPF32[$610>>2] = $$lcssa1526;
  HEAPF32[$14>>2] = $$lcssa1517;
  $611 = (($14) + 4|0);
  HEAPF32[$611>>2] = $$lcssa1521;
  $612 = (($14) + 8|0);
  HEAPF32[$612>>2] = $$lcssa1525;
  HEAPF32[$27>>2] = $$lcssa1532;
  $613 = (($0) + 20|0);
  HEAPF32[$613>>2] = $$lcssa1536;
  $614 = (($0) + 24|0);
  HEAPF32[$614>>2] = $$lcssa1540;
  HEAPF32[$49>>2] = $$lcssa1531;
  $615 = (($4) + 20|0);
  HEAPF32[$615>>2] = $$lcssa1535;
  $616 = (($4) + 24|0);
  HEAPF32[$616>>2] = $$lcssa1539;
  HEAPF32[$71>>2] = $$lcssa1530;
  $617 = (($8) + 20|0);
  HEAPF32[$617>>2] = $$lcssa1534;
  $618 = (($8) + 24|0);
  HEAPF32[$618>>2] = $$lcssa1538;
  HEAPF32[$93>>2] = $$lcssa1529;
  $619 = (($12) + 20|0);
  HEAPF32[$619>>2] = $$lcssa1533;
  $620 = (($12) + 24|0);
  HEAPF32[$620>>2] = $$lcssa1537;
  HEAPF32[$33>>2] = $$lcssa1544;
  $621 = (($2) + 20|0);
  HEAPF32[$621>>2] = $$lcssa1548;
  $622 = (($2) + 24|0);
  HEAPF32[$622>>2] = $$lcssa1552;
  HEAPF32[$55>>2] = $$lcssa1543;
  $623 = (($6) + 20|0);
  HEAPF32[$623>>2] = $$lcssa1547;
  $624 = (($6) + 24|0);
  HEAPF32[$624>>2] = $$lcssa1551;
  HEAPF32[$77>>2] = $$lcssa1542;
  $625 = (($10) + 20|0);
  HEAPF32[$625>>2] = $$lcssa1546;
  $626 = (($10) + 24|0);
  HEAPF32[$626>>2] = $$lcssa1550;
  HEAPF32[$99>>2] = $$lcssa1541;
  $627 = (($14) + 20|0);
  HEAPF32[$627>>2] = $$lcssa1545;
  $628 = (($14) + 24|0);
  HEAPF32[$628>>2] = $$lcssa1549;
  STACKTOP = sp;return;
 }
 $124 = (($16) + 128|0);
 $321 = $17;$323 = $39;$325 = $61;$327 = $83;$329 = $22;$331 = $44;$333 = $66;$335 = $88;$337 = $28;$339 = $50;$341 = $72;$343 = $94;$345 = $34;$347 = $56;$349 = $78;$351 = $100;$353 = $19;$355 = $41;$357 = $63;$359 = $85;$365 = $24;$367 = $46;$369 = $68;$371 = $90;$377 = $30;$379 = $52;$381 = $74;$383 = $96;$389 = $36;$391 = $58;$393 = $80;$395 = $102;$401 = $21;$403 = $43;$405 = $65;$407 = $87;$413 = $26;$415 = $48;$417 = $70;$419 = $92;$425 = $32;$427 = $54;$429 = $76;$431 = $98;$437 = $38;$439 = $60;$441 = $82;$443 = $104;$a$01553 = 0;$base$01554 = $124;
 while(1) {
  $125 = (($base$01554) + 416|0);
  $126 = (($base$01554) + 544|0);
  $127 = (($base$01554) + 672|0);
  $128 = (($base$01554) + 800|0);
  $129 = (($base$01554) + 176|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = (($base$01554) + 180|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($base$01554) + 184|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($base$01554) + 188|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = (($base$01554) + 192|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = (($base$01554) + 196|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = (($base$01554) + 200|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($base$01554) + 204|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = (($base$01554) + 144|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($base$01554) + 148|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = (($base$01554) + 152|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $151 = (($base$01554) + 156|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = (($base$01554) + 208|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = (($base$01554) + 212|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = (($base$01554) + 216|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = (($base$01554) + 220|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = (($base$01554) + 224|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = (($base$01554) + 228|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = (($base$01554) + 232|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($base$01554) + 236|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($base$01554) + 240|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = (($base$01554) + 244|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = (($base$01554) + 248|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = (($base$01554) + 252|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = Math_fround(HEAPF32[$base$01554>>2]);
  $178 = (($base$01554) + 4|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = (($base$01554) + 8|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = (($base$01554) + 12|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = (($base$01554) + 16|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = (($base$01554) + 20|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = (($base$01554) + 24|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = (($base$01554) + 28|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = (($base$01554) + 32|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($base$01554) + 36|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($base$01554) + 40|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = (($base$01554) + 44|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = (($base$01554) + 272|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (($base$01554) + 276|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = (($base$01554) + 280|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = (($base$01554) + 284|0);
  $207 = Math_fround(HEAPF32[$206>>2]);
  $208 = (($base$01554) + 288|0);
  $209 = Math_fround(HEAPF32[$208>>2]);
  $210 = (($base$01554) + 292|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = (($base$01554) + 296|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = (($base$01554) + 300|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($base$01554) + 304|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($base$01554) + 308|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = (($base$01554) + 312|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = (($base$01554) + 316|0);
  $223 = Math_fround(HEAPF32[$222>>2]);
  $224 = (($base$01554) + 48|0);
  $225 = Math_fround(HEAPF32[$224>>2]);
  $226 = (($base$01554) + 52|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = (($base$01554) + 56|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = (($base$01554) + 60|0);
  $231 = Math_fround(HEAPF32[$230>>2]);
  $232 = (($base$01554) + 64|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = (($base$01554) + 68|0);
  $235 = Math_fround(HEAPF32[$234>>2]);
  $236 = (($base$01554) + 72|0);
  $237 = Math_fround(HEAPF32[$236>>2]);
  $238 = (($base$01554) + 76|0);
  $239 = Math_fround(HEAPF32[$238>>2]);
  $240 = (($base$01554) + 80|0);
  $241 = Math_fround(HEAPF32[$240>>2]);
  $242 = (($base$01554) + 84|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = (($base$01554) + 88|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = (($base$01554) + 92|0);
  $247 = Math_fround(HEAPF32[$246>>2]);
  $248 = (($base$01554) + 320|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = (($base$01554) + 324|0);
  $251 = Math_fround(HEAPF32[$250>>2]);
  $252 = (($base$01554) + 328|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = (($base$01554) + 332|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = (($base$01554) + 336|0);
  $257 = Math_fround(HEAPF32[$256>>2]);
  $258 = (($base$01554) + 340|0);
  $259 = Math_fround(HEAPF32[$258>>2]);
  $260 = (($base$01554) + 344|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = (($base$01554) + 348|0);
  $263 = Math_fround(HEAPF32[$262>>2]);
  $264 = (($base$01554) + 352|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = (($base$01554) + 356|0);
  $267 = Math_fround(HEAPF32[$266>>2]);
  $268 = (($base$01554) + 360|0);
  $269 = Math_fround(HEAPF32[$268>>2]);
  $270 = (($base$01554) + 364|0);
  $271 = Math_fround(HEAPF32[$270>>2]);
  $272 = (($base$01554) + 96|0);
  $273 = Math_fround(HEAPF32[$272>>2]);
  $274 = (($base$01554) + 100|0);
  $275 = Math_fround(HEAPF32[$274>>2]);
  $276 = (($base$01554) + 104|0);
  $277 = Math_fround(HEAPF32[$276>>2]);
  $278 = (($base$01554) + 108|0);
  $279 = Math_fround(HEAPF32[$278>>2]);
  $280 = (($base$01554) + 112|0);
  $281 = Math_fround(HEAPF32[$280>>2]);
  $282 = (($base$01554) + 116|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = (($base$01554) + 120|0);
  $285 = Math_fround(HEAPF32[$284>>2]);
  $286 = (($base$01554) + 124|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $288 = (($base$01554) + 128|0);
  $289 = Math_fround(HEAPF32[$288>>2]);
  $290 = (($base$01554) + 132|0);
  $291 = Math_fround(HEAPF32[$290>>2]);
  $292 = (($base$01554) + 136|0);
  $293 = Math_fround(HEAPF32[$292>>2]);
  $294 = (($base$01554) + 140|0);
  $295 = Math_fround(HEAPF32[$294>>2]);
  $296 = (($base$01554) + 368|0);
  $297 = Math_fround(HEAPF32[$296>>2]);
  $298 = (($base$01554) + 372|0);
  $299 = Math_fround(HEAPF32[$298>>2]);
  $300 = (($base$01554) + 376|0);
  $301 = Math_fround(HEAPF32[$300>>2]);
  $302 = (($base$01554) + 380|0);
  $303 = Math_fround(HEAPF32[$302>>2]);
  $304 = (($base$01554) + 384|0);
  $305 = Math_fround(HEAPF32[$304>>2]);
  $306 = (($base$01554) + 388|0);
  $307 = Math_fround(HEAPF32[$306>>2]);
  $308 = (($base$01554) + 392|0);
  $309 = Math_fround(HEAPF32[$308>>2]);
  $310 = (($base$01554) + 396|0);
  $311 = Math_fround(HEAPF32[$310>>2]);
  $312 = (($base$01554) + 400|0);
  $313 = Math_fround(HEAPF32[$312>>2]);
  $314 = (($base$01554) + 404|0);
  $315 = Math_fround(HEAPF32[$314>>2]);
  $316 = (($base$01554) + 408|0);
  $317 = Math_fround(HEAPF32[$316>>2]);
  $318 = (($base$01554) + 412|0);
  $319 = Math_fround(HEAPF32[$318>>2]);
  $320 = Math_fround($321 * $177);
  $322 = Math_fround($323 * $179);
  $324 = Math_fround($325 * $181);
  $326 = Math_fround($327 * $183);
  $328 = Math_fround($329 * $201);
  $330 = Math_fround($331 * $203);
  $332 = Math_fround($333 * $205);
  $334 = Math_fround($335 * $207);
  $336 = Math_fround($337 * $225);
  $338 = Math_fround($339 * $227);
  $340 = Math_fround($341 * $229);
  $342 = Math_fround($343 * $231);
  $344 = Math_fround($345 * $249);
  $346 = Math_fround($347 * $251);
  $348 = Math_fround($349 * $253);
  $350 = Math_fround($351 * $255);
  $352 = Math_fround($353 * $185);
  $354 = Math_fround($355 * $187);
  $356 = Math_fround($357 * $189);
  $358 = Math_fround($359 * $191);
  $360 = Math_fround($320 + $352);
  $361 = Math_fround($322 + $354);
  $362 = Math_fround($324 + $356);
  $363 = Math_fround($326 + $358);
  $364 = Math_fround($365 * $209);
  $366 = Math_fround($367 * $211);
  $368 = Math_fround($369 * $213);
  $370 = Math_fround($371 * $215);
  $372 = Math_fround($328 + $364);
  $373 = Math_fround($330 + $366);
  $374 = Math_fround($332 + $368);
  $375 = Math_fround($334 + $370);
  $376 = Math_fround($377 * $233);
  $378 = Math_fround($379 * $235);
  $380 = Math_fround($381 * $237);
  $382 = Math_fround($383 * $239);
  $384 = Math_fround($336 + $376);
  $385 = Math_fround($338 + $378);
  $386 = Math_fround($340 + $380);
  $387 = Math_fround($342 + $382);
  $388 = Math_fround($389 * $257);
  $390 = Math_fround($391 * $259);
  $392 = Math_fround($393 * $261);
  $394 = Math_fround($395 * $263);
  $396 = Math_fround($344 + $388);
  $397 = Math_fround($346 + $390);
  $398 = Math_fround($348 + $392);
  $399 = Math_fround($350 + $394);
  $400 = Math_fround($401 * $193);
  $402 = Math_fround($403 * $195);
  $404 = Math_fround($405 * $197);
  $406 = Math_fround($407 * $199);
  $408 = Math_fround($360 + $400);
  $409 = Math_fround($361 + $402);
  $410 = Math_fround($362 + $404);
  $411 = Math_fround($363 + $406);
  $412 = Math_fround($413 * $217);
  $414 = Math_fround($415 * $219);
  $416 = Math_fround($417 * $221);
  $418 = Math_fround($419 * $223);
  $420 = Math_fround($372 + $412);
  $421 = Math_fround($373 + $414);
  $422 = Math_fround($374 + $416);
  $423 = Math_fround($375 + $418);
  $424 = Math_fround($425 * $241);
  $426 = Math_fround($427 * $243);
  $428 = Math_fround($429 * $245);
  $430 = Math_fround($431 * $247);
  $432 = Math_fround($384 + $424);
  $433 = Math_fround($385 + $426);
  $434 = Math_fround($386 + $428);
  $435 = Math_fround($387 + $430);
  $436 = Math_fround($437 * $265);
  $438 = Math_fround($439 * $267);
  $440 = Math_fround($441 * $269);
  $442 = Math_fround($443 * $271);
  $444 = Math_fround($396 + $436);
  $445 = Math_fround($397 + $438);
  $446 = Math_fround($398 + $440);
  $447 = Math_fround($399 + $442);
  $448 = Math_fround($408 + $432);
  $449 = Math_fround($409 + $433);
  $450 = Math_fround($410 + $434);
  $451 = Math_fround($411 + $435);
  $452 = Math_fround($420 + $444);
  $453 = Math_fround($421 + $445);
  $454 = Math_fround($422 + $446);
  $455 = Math_fround($423 + $447);
  $456 = Math_fround($448 - $452);
  $457 = Math_fround($449 - $453);
  $458 = Math_fround($450 - $454);
  $459 = Math_fround($451 - $455);
  $460 = Math_fround($130 * $456);
  $461 = Math_fround($132 * $457);
  $462 = Math_fround($134 * $458);
  $463 = Math_fround($136 * $459);
  $464 = Math_fround($146 + $460);
  $465 = Math_fround($148 + $461);
  $466 = Math_fround($150 + $462);
  $467 = Math_fround($152 + $463);
  $468 = Math_fround($138 * $170);
  $469 = Math_fround($140 * $172);
  $470 = Math_fround($142 * $174);
  $471 = Math_fround($144 * $176);
  $472 = Math_fround($468 + $464);
  $473 = Math_fround($469 + $465);
  $474 = Math_fround($470 + $466);
  $475 = Math_fround($471 + $467);
  $476 = $162 < $472;
  $$$i156 = $476 ? $162 : $472;
  $477 = $164 < $473;
  $478 = $477 ? $164 : $473;
  $479 = $166 < $474;
  $$1$i157 = $479 ? $166 : $474;
  $480 = $168 < $475;
  $481 = $480 ? $168 : $475;
  $482 = $154 > $$$i156;
  $$$i = $482 ? $154 : $$$i156;
  $483 = $156 > $478;
  $484 = $483 ? $156 : $478;
  $485 = $158 > $$1$i157;
  $$1$i = $485 ? $158 : $$1$i157;
  $486 = $160 > $481;
  $487 = $486 ? $160 : $481;
  $488 = Math_fround($$$i - $170);
  $489 = Math_fround($484 - $172);
  $490 = Math_fround($$1$i - $174);
  $491 = Math_fround($487 - $176);
  HEAPF32[$169>>2] = $$$i;
  HEAPF32[$171>>2] = $484;
  HEAPF32[$173>>2] = $$1$i;
  HEAPF32[$175>>2] = $487;
  $492 = Math_fround($106 * $488);
  $493 = Math_fround($108 * $489);
  $494 = Math_fround($110 * $490);
  $495 = Math_fround($112 * $491);
  $496 = Math_fround($114 * $488);
  $497 = Math_fround($116 * $489);
  $498 = Math_fround($118 * $490);
  $499 = Math_fround($120 * $491);
  $500 = Math_fround($177 * $492);
  $501 = Math_fround($179 * $493);
  $502 = Math_fround($181 * $494);
  $503 = Math_fround($183 * $495);
  $504 = Math_fround($321 + $500);
  $505 = Math_fround($323 + $501);
  $506 = Math_fround($325 + $502);
  $507 = Math_fround($327 + $503);
  $508 = Math_fround($201 * $496);
  $509 = Math_fround($203 * $497);
  $510 = Math_fround($205 * $498);
  $511 = Math_fround($207 * $499);
  $512 = Math_fround($329 + $508);
  $513 = Math_fround($331 + $509);
  $514 = Math_fround($333 + $510);
  $515 = Math_fround($335 + $511);
  $516 = Math_fround($273 * $488);
  $517 = Math_fround($275 * $489);
  $518 = Math_fround($277 * $490);
  $519 = Math_fround($279 * $491);
  $520 = Math_fround($337 + $516);
  $521 = Math_fround($339 + $517);
  $522 = Math_fround($341 + $518);
  $523 = Math_fround($343 + $519);
  $524 = Math_fround($488 * $297);
  $525 = Math_fround($489 * $299);
  $526 = Math_fround($490 * $301);
  $527 = Math_fround($491 * $303);
  $528 = Math_fround($345 + $524);
  $529 = Math_fround($347 + $525);
  $530 = Math_fround($349 + $526);
  $531 = Math_fround($351 + $527);
  $532 = Math_fround($185 * $492);
  $533 = Math_fround($187 * $493);
  $534 = Math_fround($189 * $494);
  $535 = Math_fround($191 * $495);
  $536 = Math_fround($353 + $532);
  $537 = Math_fround($355 + $533);
  $538 = Math_fround($357 + $534);
  $539 = Math_fround($359 + $535);
  $540 = Math_fround($209 * $496);
  $541 = Math_fround($211 * $497);
  $542 = Math_fround($213 * $498);
  $543 = Math_fround($215 * $499);
  $544 = Math_fround($365 + $540);
  $545 = Math_fround($367 + $541);
  $546 = Math_fround($369 + $542);
  $547 = Math_fround($371 + $543);
  $548 = Math_fround($281 * $488);
  $549 = Math_fround($283 * $489);
  $550 = Math_fround($285 * $490);
  $551 = Math_fround($287 * $491);
  $552 = Math_fround($377 + $548);
  $553 = Math_fround($379 + $549);
  $554 = Math_fround($381 + $550);
  $555 = Math_fround($383 + $551);
  $556 = Math_fround($488 * $305);
  $557 = Math_fround($489 * $307);
  $558 = Math_fround($490 * $309);
  $559 = Math_fround($491 * $311);
  $560 = Math_fround($389 + $556);
  $561 = Math_fround($391 + $557);
  $562 = Math_fround($393 + $558);
  $563 = Math_fround($395 + $559);
  $564 = Math_fround($193 * $492);
  $565 = Math_fround($195 * $493);
  $566 = Math_fround($197 * $494);
  $567 = Math_fround($199 * $495);
  $568 = Math_fround($401 + $564);
  $569 = Math_fround($403 + $565);
  $570 = Math_fround($405 + $566);
  $571 = Math_fround($407 + $567);
  $572 = Math_fround($217 * $496);
  $573 = Math_fround($219 * $497);
  $574 = Math_fround($221 * $498);
  $575 = Math_fround($223 * $499);
  $576 = Math_fround($413 + $572);
  $577 = Math_fround($415 + $573);
  $578 = Math_fround($417 + $574);
  $579 = Math_fround($419 + $575);
  $580 = Math_fround($289 * $488);
  $581 = Math_fround($291 * $489);
  $582 = Math_fround($293 * $490);
  $583 = Math_fround($295 * $491);
  $584 = Math_fround($425 + $580);
  $585 = Math_fround($427 + $581);
  $586 = Math_fround($429 + $582);
  $587 = Math_fround($431 + $583);
  $588 = Math_fround($488 * $313);
  $589 = Math_fround($489 * $315);
  $590 = Math_fround($490 * $317);
  $591 = Math_fround($491 * $319);
  $592 = Math_fround($437 + $588);
  $593 = Math_fround($439 + $589);
  $594 = Math_fround($441 + $590);
  $595 = Math_fround($443 + $591);
  $596 = (($a$01553) + 1)|0;
  $exitcond = ($596|0)==($122|0);
  if ($exitcond) {
   $$lcssa = $507;$$lcssa1506 = $506;$$lcssa1507 = $505;$$lcssa1508 = $504;$$lcssa1509 = $539;$$lcssa1510 = $538;$$lcssa1511 = $537;$$lcssa1512 = $536;$$lcssa1513 = $571;$$lcssa1514 = $570;$$lcssa1515 = $569;$$lcssa1516 = $568;$$lcssa1517 = $515;$$lcssa1518 = $514;$$lcssa1519 = $513;$$lcssa1520 = $512;$$lcssa1521 = $547;$$lcssa1522 = $546;$$lcssa1523 = $545;$$lcssa1524 = $544;$$lcssa1525 = $579;$$lcssa1526 = $578;$$lcssa1527 = $577;$$lcssa1528 = $576;$$lcssa1529 = $523;$$lcssa1530 = $522;$$lcssa1531 = $521;$$lcssa1532 = $520;$$lcssa1533 = $555;$$lcssa1534 = $554;$$lcssa1535 = $553;$$lcssa1536 = $552;$$lcssa1537 = $587;$$lcssa1538 = $586;$$lcssa1539 = $585;$$lcssa1540 = $584;$$lcssa1541 = $531;$$lcssa1542 = $530;$$lcssa1543 = $529;$$lcssa1544 = $528;$$lcssa1545 = $563;$$lcssa1546 = $562;$$lcssa1547 = $561;$$lcssa1548 = $560;$$lcssa1549 = $595;$$lcssa1550 = $594;$$lcssa1551 = $593;$$lcssa1552 = $592;
   break;
  } else {
   $321 = $504;$323 = $505;$325 = $506;$327 = $507;$329 = $512;$331 = $513;$333 = $514;$335 = $515;$337 = $520;$339 = $521;$341 = $522;$343 = $523;$345 = $528;$347 = $529;$349 = $530;$351 = $531;$353 = $536;$355 = $537;$357 = $538;$359 = $539;$365 = $544;$367 = $545;$369 = $546;$371 = $547;$377 = $552;$379 = $553;$381 = $554;$383 = $555;$389 = $560;$391 = $561;$393 = $562;$395 = $563;$401 = $568;$403 = $569;$405 = $570;$407 = $571;$413 = $576;$415 = $577;$417 = $578;$419 = $579;$425 = $584;$427 = $585;$429 = $586;$431 = $587;$437 = $592;$439 = $593;$441 = $594;$443 = $595;$a$01553 = $596;$base$01554 = $125;
  }
 }
 HEAPF32[$0>>2] = $$lcssa1508;
 $597 = (($0) + 4|0);
 HEAPF32[$597>>2] = $$lcssa1512;
 $598 = (($0) + 8|0);
 HEAPF32[$598>>2] = $$lcssa1516;
 HEAPF32[$4>>2] = $$lcssa1507;
 $599 = (($4) + 4|0);
 HEAPF32[$599>>2] = $$lcssa1511;
 $600 = (($4) + 8|0);
 HEAPF32[$600>>2] = $$lcssa1515;
 HEAPF32[$8>>2] = $$lcssa1506;
 $601 = (($8) + 4|0);
 HEAPF32[$601>>2] = $$lcssa1510;
 $602 = (($8) + 8|0);
 HEAPF32[$602>>2] = $$lcssa1514;
 HEAPF32[$12>>2] = $$lcssa;
 $603 = (($12) + 4|0);
 HEAPF32[$603>>2] = $$lcssa1509;
 $604 = (($12) + 8|0);
 HEAPF32[$604>>2] = $$lcssa1513;
 HEAPF32[$2>>2] = $$lcssa1520;
 $605 = (($2) + 4|0);
 HEAPF32[$605>>2] = $$lcssa1524;
 $606 = (($2) + 8|0);
 HEAPF32[$606>>2] = $$lcssa1528;
 HEAPF32[$6>>2] = $$lcssa1519;
 $607 = (($6) + 4|0);
 HEAPF32[$607>>2] = $$lcssa1523;
 $608 = (($6) + 8|0);
 HEAPF32[$608>>2] = $$lcssa1527;
 HEAPF32[$10>>2] = $$lcssa1518;
 $609 = (($10) + 4|0);
 HEAPF32[$609>>2] = $$lcssa1522;
 $610 = (($10) + 8|0);
 HEAPF32[$610>>2] = $$lcssa1526;
 HEAPF32[$14>>2] = $$lcssa1517;
 $611 = (($14) + 4|0);
 HEAPF32[$611>>2] = $$lcssa1521;
 $612 = (($14) + 8|0);
 HEAPF32[$612>>2] = $$lcssa1525;
 HEAPF32[$27>>2] = $$lcssa1532;
 $613 = (($0) + 20|0);
 HEAPF32[$613>>2] = $$lcssa1536;
 $614 = (($0) + 24|0);
 HEAPF32[$614>>2] = $$lcssa1540;
 HEAPF32[$49>>2] = $$lcssa1531;
 $615 = (($4) + 20|0);
 HEAPF32[$615>>2] = $$lcssa1535;
 $616 = (($4) + 24|0);
 HEAPF32[$616>>2] = $$lcssa1539;
 HEAPF32[$71>>2] = $$lcssa1530;
 $617 = (($8) + 20|0);
 HEAPF32[$617>>2] = $$lcssa1534;
 $618 = (($8) + 24|0);
 HEAPF32[$618>>2] = $$lcssa1538;
 HEAPF32[$93>>2] = $$lcssa1529;
 $619 = (($12) + 20|0);
 HEAPF32[$619>>2] = $$lcssa1533;
 $620 = (($12) + 24|0);
 HEAPF32[$620>>2] = $$lcssa1537;
 HEAPF32[$33>>2] = $$lcssa1544;
 $621 = (($2) + 20|0);
 HEAPF32[$621>>2] = $$lcssa1548;
 $622 = (($2) + 24|0);
 HEAPF32[$622>>2] = $$lcssa1552;
 HEAPF32[$55>>2] = $$lcssa1543;
 $623 = (($6) + 20|0);
 HEAPF32[$623>>2] = $$lcssa1547;
 $624 = (($6) + 24|0);
 HEAPF32[$624>>2] = $$lcssa1551;
 HEAPF32[$77>>2] = $$lcssa1542;
 $625 = (($10) + 20|0);
 HEAPF32[$625>>2] = $$lcssa1546;
 $626 = (($10) + 24|0);
 HEAPF32[$626>>2] = $$lcssa1550;
 HEAPF32[$99>>2] = $$lcssa1541;
 $627 = (($14) + 20|0);
 HEAPF32[$627>>2] = $$lcssa1545;
 $628 = (($14) + 24|0);
 HEAPF32[$628>>2] = $$lcssa1549;
 STACKTOP = sp;return;
}
function __ZN5physx22solve1D4Block_ConcludeEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $base$02$i = 0, $desc$idx = 0, $desc$idx$val = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL14solve1D4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 $desc$idx = (($desc) + 16|0);
 $desc$idx$val = HEAP32[$desc$idx>>2]|0;
 $1 = HEAP8[$desc$idx$val>>0]|0;
 $2 = ($1<<24>>24)==(9);
 $3 = $2 ? 416 : 272;
 $4 = (($desc$idx$val) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($desc$idx$val) + 128|0);
 $base$02$i = $7;$i$01$i = 0;
 while(1) {
  $8 = (($base$02$i) + 144|0);
  $9 = (($base$02$i) + 160|0);
  ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
  $10 = (($base$02$i) + ($3)|0);
  $11 = (($i$01$i) + 1)|0;
  $12 = HEAP32[$4>>2]|0;
  $13 = ($11>>>0)<($12>>>0);
  if ($13) {
   $base$02$i = $10;$i$01$i = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23solve1D4Block_WriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$0,$cache,$1,$2,$3) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL14solve1D4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 __ZN5physx12writeBack1D4EPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEPPKNS_17PxcSolverBodyDataES8_($desc,0,0,0);
 STACKTOP = sp;return;
}
function __ZN5physx24writeBackContactCoulomb4EPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEPPKNS_17PxcSolverBodyDataES8_($desc,$cache,$bd0,$bd1) {
 $desc = $desc|0;
 $cache = $cache|0;
 $bd0 = $bd0|0;
 $bd1 = $bd1|0;
 var $$ = 0, $$94 = 0, $$lcssa = Math_fround(0), $$lcssa113 = Math_fround(0), $$lcssa114 = Math_fround(0), $$lcssa115 = Math_fround(0), $$lcssa116 = Math_fround(0), $$lcssa96 = Math_fround(0), $$lcssa97 = Math_fround(0), $$lcssa98 = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert134 = 0, $$pre = 0, $$pre135 = Math_fround(0), $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0);
 var $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $a$095 = 0, $cPtr$0121 = 0, $cPtr$1$lcssa = 0, $cPtr$1104 = 0, $exitcond = 0, $exitcond133 = 0, $i$0103 = 0, $nf = 0, $or$cond = 0, $scevgep132 = 0, $vForceWriteback0$0120 = 0, $vForceWriteback0$1$lcssa = 0, $vForceWriteback0$1102 = 0, $vForceWriteback0$2 = 0, $vForceWriteback1$0119 = 0, $vForceWriteback1$1$lcssa = 0, $vForceWriteback1$1101 = 0, $vForceWriteback1$2 = 0;
 var $vForceWriteback2$0118 = 0, $vForceWriteback2$1$lcssa = 0, $vForceWriteback2$1100 = 0, $vForceWriteback2$2 = 0, $vForceWriteback3$0117 = 0, $vForceWriteback3$1$lcssa = 0, $vForceWriteback3$199 = 0, $vForceWriteback3$2 = 0, $writeBackThresholds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $writeBackThresholds = sp + 16|0;
 $nf = sp;
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($desc) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($desc) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($desc) + 84|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($desc) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($1) + 2|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = $11&65535;
 $13 = (($1) + ($12)|0);
 $14 = HEAP8[$1>>0]|0;
 $15 = ($14<<24>>24)==(7);
 $16 = $15 ? 272 : 176;
 HEAP32[$writeBackThresholds>>2] = 0;
 $17 = ($11<<16>>16)==(0);
 if ($17) {
  $$lcssa113 = Math_fround(0.0);$$lcssa114 = Math_fround(0.0);$$lcssa115 = Math_fround(0.0);$$lcssa116 = Math_fround(0.0);
 } else {
  $18 = (($writeBackThresholds) + 1|0);
  $19 = (($writeBackThresholds) + 2|0);
  $20 = (($writeBackThresholds) + 3|0);
  $123 = Math_fround(0.0);$124 = Math_fround(0.0);$125 = Math_fround(0.0);$126 = Math_fround(0.0);$cPtr$0121 = $1;$vForceWriteback0$0120 = $3;$vForceWriteback1$0119 = $5;$vForceWriteback2$0118 = $7;$vForceWriteback3$0117 = $9;
  while(1) {
   $23 = (($cPtr$0121) + 112|0);
   $24 = (($cPtr$0121) + 8|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = $25 & 1;
   HEAP8[$writeBackThresholds>>0] = $26;
   $27 = (($cPtr$0121) + 9|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = $28 & 1;
   HEAP8[$18>>0] = $29;
   $30 = (($cPtr$0121) + 10|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = $31 & 1;
   HEAP8[$19>>0] = $32;
   $33 = (($cPtr$0121) + 11|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34 & 1;
   HEAP8[$20>>0] = $35;
   $36 = (($cPtr$0121) + 1|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = (($cPtr$0121) + 368|0);
   $39 = (($cPtr$0121) + 496|0);
   $40 = ($37<<24>>24)==(0);
   if ($40) {
    $$lcssa = $126;$$lcssa96 = $125;$$lcssa97 = $124;$$lcssa98 = $123;$cPtr$1$lcssa = $23;$vForceWriteback0$1$lcssa = $vForceWriteback0$0120;$vForceWriteback1$1$lcssa = $vForceWriteback1$0119;$vForceWriteback2$1$lcssa = $vForceWriteback2$0118;$vForceWriteback3$1$lcssa = $vForceWriteback3$0117;
   } else {
    $41 = (($cPtr$0121) + 7|0);
    $42 = (($cPtr$0121) + 6|0);
    $43 = (($cPtr$0121) + 5|0);
    $44 = (($cPtr$0121) + 4|0);
    $45 = $37&255;
    $21 = Math_imul($16, $45)|0;
    $76 = $123;$78 = $124;$80 = $125;$82 = $126;$cPtr$1104 = $23;$i$0103 = 0;$vForceWriteback0$1102 = $vForceWriteback0$0120;$vForceWriteback1$1101 = $vForceWriteback1$0119;$vForceWriteback2$1100 = $vForceWriteback2$0118;$vForceWriteback3$199 = $vForceWriteback3$0117;
    while(1) {
     $46 = (($cPtr$1104) + ($16)|0);
     $47 = (($cPtr$1104) + 96|0);
     $48 = Math_fround(HEAPF32[$47>>2]);
     $49 = (($cPtr$1104) + 100|0);
     $50 = Math_fround(HEAPF32[$49>>2]);
     $51 = (($cPtr$1104) + 104|0);
     $52 = Math_fround(HEAPF32[$51>>2]);
     $53 = (($cPtr$1104) + 108|0);
     $54 = Math_fround(HEAPF32[$53>>2]);
     $55 = ($vForceWriteback0$1102|0)==(0|0);
     if ($55) {
      $vForceWriteback0$2 = 0;
     } else {
      $56 = HEAP8[$44>>0]|0;
      $57 = $56&255;
      $58 = ($i$0103>>>0)<($57>>>0);
      if ($58) {
       $59 = (($vForceWriteback0$1102) + 4|0);
       HEAPF32[$vForceWriteback0$1102>>2] = $48;
       $vForceWriteback0$2 = $59;
      } else {
       $vForceWriteback0$2 = $vForceWriteback0$1102;
      }
     }
     $60 = ($vForceWriteback1$1101|0)==(0|0);
     if ($60) {
      $vForceWriteback1$2 = 0;
     } else {
      $61 = HEAP8[$43>>0]|0;
      $62 = $61&255;
      $63 = ($i$0103>>>0)<($62>>>0);
      if ($63) {
       $64 = (($vForceWriteback1$1101) + 4|0);
       HEAPF32[$vForceWriteback1$1101>>2] = $50;
       $vForceWriteback1$2 = $64;
      } else {
       $vForceWriteback1$2 = $vForceWriteback1$1101;
      }
     }
     $65 = ($vForceWriteback2$1100|0)==(0|0);
     if ($65) {
      $vForceWriteback2$2 = 0;
     } else {
      $66 = HEAP8[$42>>0]|0;
      $67 = $66&255;
      $68 = ($i$0103>>>0)<($67>>>0);
      if ($68) {
       $69 = (($vForceWriteback2$1100) + 4|0);
       HEAPF32[$vForceWriteback2$1100>>2] = $52;
       $vForceWriteback2$2 = $69;
      } else {
       $vForceWriteback2$2 = $vForceWriteback2$1100;
      }
     }
     $70 = ($vForceWriteback3$199|0)==(0|0);
     if ($70) {
      $vForceWriteback3$2 = 0;
     } else {
      $71 = HEAP8[$41>>0]|0;
      $72 = $71&255;
      $73 = ($i$0103>>>0)<($72>>>0);
      if ($73) {
       $74 = (($vForceWriteback3$199) + 4|0);
       HEAPF32[$vForceWriteback3$199>>2] = $54;
       $vForceWriteback3$2 = $74;
      } else {
       $vForceWriteback3$2 = $vForceWriteback3$199;
      }
     }
     $75 = Math_fround($76 + $48);
     $77 = Math_fround($78 + $50);
     $79 = Math_fround($80 + $52);
     $81 = Math_fround($82 + $54);
     $83 = (($i$0103) + 1)|0;
     $exitcond133 = ($83|0)==($45|0);
     if ($exitcond133) {
      break;
     } else {
      $76 = $75;$78 = $77;$80 = $79;$82 = $81;$cPtr$1104 = $46;$i$0103 = $83;$vForceWriteback0$1102 = $vForceWriteback0$2;$vForceWriteback1$1101 = $vForceWriteback1$2;$vForceWriteback2$1100 = $vForceWriteback2$2;$vForceWriteback3$199 = $vForceWriteback3$2;
     }
    }
    $$sum = (($21) + 112)|0;
    $scevgep132 = (($cPtr$0121) + ($$sum)|0);
    $$lcssa = $81;$$lcssa96 = $79;$$lcssa97 = $77;$$lcssa98 = $75;$cPtr$1$lcssa = $scevgep132;$vForceWriteback0$1$lcssa = $vForceWriteback0$2;$vForceWriteback1$1$lcssa = $vForceWriteback1$2;$vForceWriteback2$1$lcssa = $vForceWriteback2$2;$vForceWriteback3$1$lcssa = $vForceWriteback3$2;
   }
   $22 = ($cPtr$1$lcssa>>>0)<($13>>>0);
   if ($22) {
    $123 = $$lcssa98;$124 = $$lcssa97;$125 = $$lcssa96;$126 = $$lcssa;$cPtr$0121 = $cPtr$1$lcssa;$vForceWriteback0$0120 = $vForceWriteback0$1$lcssa;$vForceWriteback1$0119 = $vForceWriteback1$1$lcssa;$vForceWriteback2$0118 = $vForceWriteback2$1$lcssa;$vForceWriteback3$0117 = $vForceWriteback3$1$lcssa;
   } else {
    $$lcssa113 = $$lcssa;$$lcssa114 = $$lcssa96;$$lcssa115 = $$lcssa97;$$lcssa116 = $$lcssa98;
    break;
   }
  }
 }
 HEAPF32[$nf>>2] = $$lcssa116;
 $84 = (($nf) + 4|0);
 HEAPF32[$84>>2] = $$lcssa115;
 $85 = (($nf) + 8|0);
 HEAPF32[$85>>2] = $$lcssa114;
 $86 = (($nf) + 12|0);
 HEAPF32[$86>>2] = $$lcssa113;
 $87 = (($cache) + 8|0);
 $88 = (($cache) + 4|0);
 $a$095 = 0;
 while(1) {
  $89 = (($writeBackThresholds) + ($a$095)|0);
  $90 = HEAP8[$89>>0]|0;
  $91 = ($90<<24>>24)==(0);
  if (!($91)) {
   $92 = ((($desc) + ($a$095<<5)|0) + 8|0);
   $93 = HEAP16[$92>>1]|0;
   $94 = ($93<<16>>16)==(-1);
   if ($94) {
    $95 = ((($desc) + ($a$095<<5)|0) + 12|0);
    $96 = HEAP16[$95>>1]|0;
    $97 = ($96<<16>>16)==(-1);
    if ($97) {
     $98 = (($nf) + ($a$095<<2)|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ($99|0)==(0);
     $101 = (HEAP32[tempDoublePtr>>2]=$99,Math_fround(HEAPF32[tempDoublePtr>>2]));
     if (!($100)) {
      $102 = (($bd0) + ($a$095<<2)|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = (($103) + 36|0);
      $105 = Math_fround(HEAPF32[$104>>2]);
      $106 = $105 < Math_fround(3.40282346638528859812E+38);
      $$phi$trans$insert = (($bd1) + ($a$095<<2)|0);
      $$pre = HEAP32[$$phi$trans$insert>>2]|0;
      $$phi$trans$insert134 = (($$pre) + 36|0);
      $$pre135 = Math_fround(HEAPF32[$$phi$trans$insert134>>2]);
      $107 = $$pre135 < Math_fround(3.40282346638528859812E+38);
      $or$cond = $106 | $107;
      if ($or$cond) {
       $108 = $105 < $$pre135;
       $109 = $108 ? $105 : $$pre135;
       $110 = (($103) + 40|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = (($$pre) + 40|0);
       $113 = HEAP32[$112>>2]|0;
       $114 = ($113>>>0)<($111>>>0);
       $$ = $114 ? $111 : $113;
       $$94 = $114 ? $113 : $111;
       $115 = HEAP32[$87>>2]|0;
       $116 = (($115) + 1)|0;
       HEAP32[$87>>2] = $116;
       $117 = HEAP32[$88>>2]|0;
       $118 = (($117) + ($115<<4)|0);
       HEAP32[$118>>2] = $$94;
       $119 = ((($117) + ($115<<4)|0) + 4|0);
       HEAP32[$119>>2] = $$;
       $120 = ((($117) + ($115<<4)|0) + 8|0);
       HEAPF32[$120>>2] = $101;
       $121 = ((($117) + ($115<<4)|0) + 12|0);
       HEAPF32[$121>>2] = $109;
      }
     }
    }
   }
  }
  $122 = (($a$095) + 1)|0;
  $exitcond = ($122|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $a$095 = $122;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx27solveContactCoulombPreBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL26solveContactCoulomb4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physxL26solveContactCoulomb4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc) {
 $desc = $desc|0;
 var $$$i = Math_fround(0), $$$i168 = Math_fround(0), $$1$i = Math_fround(0), $$1$i169 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa1719 = Math_fround(0), $$lcssa1720 = Math_fround(0), $$lcssa1721 = Math_fround(0), $$lcssa1722 = Math_fround(0), $$lcssa1723 = Math_fround(0), $$lcssa1724 = Math_fround(0), $$lcssa1725 = Math_fround(0), $$lcssa1726 = Math_fround(0), $$lcssa1727 = Math_fround(0), $$lcssa1728 = Math_fround(0), $$lcssa1729 = Math_fround(0), $$lcssa1730 = Math_fround(0), $$lcssa1731 = Math_fround(0), $$lcssa1732 = Math_fround(0), $$lcssa1733 = Math_fround(0);
 var $$lcssa1734 = Math_fround(0), $$lcssa1735 = Math_fround(0), $$lcssa1736 = Math_fround(0), $$lcssa1737 = Math_fround(0), $$lcssa1738 = Math_fround(0), $$lcssa1739 = Math_fround(0), $$lcssa1740 = Math_fround(0), $$lcssa1741 = Math_fround(0), $$lcssa1742 = Math_fround(0), $$lcssa1743 = Math_fround(0), $$lcssa1744 = Math_fround(0), $$lcssa1745 = Math_fround(0), $$lcssa1774 = Math_fround(0), $$lcssa1775 = Math_fround(0), $$lcssa1776 = Math_fround(0), $$lcssa1777 = Math_fround(0), $$lcssa1778 = Math_fround(0), $$lcssa1779 = Math_fround(0), $$lcssa1780 = Math_fround(0), $$lcssa1781 = Math_fround(0);
 var $$lcssa1782 = Math_fround(0), $$lcssa1783 = Math_fround(0), $$lcssa1784 = Math_fround(0), $$lcssa1785 = Math_fround(0), $$lcssa1786 = Math_fround(0), $$lcssa1787 = Math_fround(0), $$lcssa1788 = Math_fround(0), $$lcssa1789 = Math_fround(0), $$lcssa1790 = Math_fround(0), $$lcssa1791 = Math_fround(0), $$lcssa1792 = Math_fround(0), $$lcssa1793 = Math_fround(0), $$lcssa1794 = Math_fround(0), $$lcssa1795 = Math_fround(0), $$lcssa1796 = Math_fround(0), $$lcssa1797 = Math_fround(0), $$lcssa1798 = Math_fround(0), $$lcssa1799 = Math_fround(0), $$lcssa1800 = Math_fround(0), $$lcssa1801 = Math_fround(0);
 var $$lcssa1802 = Math_fround(0), $$lcssa1803 = Math_fround(0), $$lcssa1804 = Math_fround(0), $$lcssa1805 = Math_fround(0), $$lcssa1806 = Math_fround(0), $$lcssa1807 = Math_fround(0), $$lcssa1808 = Math_fround(0), $$lcssa1809 = Math_fround(0), $$lcssa1810 = Math_fround(0), $$lcssa1811 = Math_fround(0), $$lcssa1812 = Math_fround(0), $$lcssa1813 = Math_fround(0), $$lcssa1814 = Math_fround(0), $$lcssa1815 = Math_fround(0), $$lcssa1816 = Math_fround(0), $$lcssa1817 = Math_fround(0), $$lcssa1818 = Math_fround(0), $$lcssa1819 = Math_fround(0), $$lcssa1820 = Math_fround(0), $$lcssa1821 = Math_fround(0);
 var $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1718 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0;
 var $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0;
 var $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0;
 var $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0;
 var $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0;
 var $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0;
 var $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0;
 var $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0;
 var $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = 0;
 var $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = Math_fround(0), $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0;
 var $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0;
 var $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0);
 var $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0);
 var $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0);
 var $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0);
 var $491 = Math_fround(0), $492 = 0, $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = 0, $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = Math_fround(0), $505 = 0, $506 = 0, $507 = Math_fround(0), $508 = Math_fround(0);
 var $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0);
 var $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0);
 var $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0);
 var $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0);
 var $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0);
 var $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0);
 var $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0);
 var $635 = Math_fround(0), $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0;
 var $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0);
 var $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0);
 var $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0);
 var $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $currPtr$01822 = 0, $exitcond = 0, $i$01746 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($desc) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($desc) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($desc) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($desc) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($desc) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($desc) + 100|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = Math_fround(HEAPF32[$0>>2]);
 $16 = (($0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$2>>2]);
 $21 = (($2) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($2) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($0) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($25) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($25) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($2) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($31) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($31) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$4>>2]);
 $38 = (($4) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($4) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround(HEAPF32[$6>>2]);
 $43 = (($6) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($6) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($4) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($47) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($47) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($6) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($53) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($53) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround(HEAPF32[$8>>2]);
 $60 = (($8) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($8) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(HEAPF32[$10>>2]);
 $65 = (($10) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($10) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($8) + 16|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($69) + 4|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($69) + 8|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($10) + 16|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($75) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($75) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround(HEAPF32[$12>>2]);
 $82 = (($12) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($12) + 8|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround(HEAPF32[$14>>2]);
 $87 = (($14) + 4|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($14) + 8|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($12) + 16|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($91) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($91) + 8|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($14) + 16|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($97) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($97) + 8|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($desc) + 16|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 2|0);
 $106 = HEAP16[$105>>1]|0;
 $107 = $106&65535;
 $108 = (($104) + ($107)|0);
 $109 = ($106<<16>>16)==(0);
 if ($109) {
  $$lcssa1774 = $81;$$lcssa1775 = $59;$$lcssa1776 = $37;$$lcssa1777 = $15;$$lcssa1778 = $83;$$lcssa1779 = $61;$$lcssa1780 = $39;$$lcssa1781 = $17;$$lcssa1782 = $85;$$lcssa1783 = $63;$$lcssa1784 = $41;$$lcssa1785 = $19;$$lcssa1786 = $86;$$lcssa1787 = $64;$$lcssa1788 = $42;$$lcssa1789 = $20;$$lcssa1790 = $88;$$lcssa1791 = $66;$$lcssa1792 = $44;$$lcssa1793 = $22;$$lcssa1794 = $90;$$lcssa1795 = $68;$$lcssa1796 = $46;$$lcssa1797 = $24;$$lcssa1798 = $92;$$lcssa1799 = $70;$$lcssa1800 = $48;$$lcssa1801 = $26;$$lcssa1802 = $94;$$lcssa1803 = $72;$$lcssa1804 = $50;$$lcssa1805 = $28;$$lcssa1806 = $96;$$lcssa1807 = $74;$$lcssa1808 = $52;$$lcssa1809 = $30;$$lcssa1810 = $98;$$lcssa1811 = $76;$$lcssa1812 = $54;$$lcssa1813 = $32;$$lcssa1814 = $100;$$lcssa1815 = $78;$$lcssa1816 = $56;$$lcssa1817 = $34;$$lcssa1818 = $102;$$lcssa1819 = $80;$$lcssa1820 = $58;$$lcssa1821 = $36;
  HEAPF32[$0>>2] = $$lcssa1777;
  $637 = (($0) + 4|0);
  HEAPF32[$637>>2] = $$lcssa1781;
  $638 = (($0) + 8|0);
  HEAPF32[$638>>2] = $$lcssa1785;
  HEAPF32[$4>>2] = $$lcssa1776;
  $639 = (($4) + 4|0);
  HEAPF32[$639>>2] = $$lcssa1780;
  $640 = (($4) + 8|0);
  HEAPF32[$640>>2] = $$lcssa1784;
  HEAPF32[$8>>2] = $$lcssa1775;
  $641 = (($8) + 4|0);
  HEAPF32[$641>>2] = $$lcssa1779;
  $642 = (($8) + 8|0);
  HEAPF32[$642>>2] = $$lcssa1783;
  HEAPF32[$12>>2] = $$lcssa1774;
  $643 = (($12) + 4|0);
  HEAPF32[$643>>2] = $$lcssa1778;
  $644 = (($12) + 8|0);
  HEAPF32[$644>>2] = $$lcssa1782;
  HEAPF32[$2>>2] = $$lcssa1789;
  $645 = (($2) + 4|0);
  HEAPF32[$645>>2] = $$lcssa1793;
  $646 = (($2) + 8|0);
  HEAPF32[$646>>2] = $$lcssa1797;
  HEAPF32[$6>>2] = $$lcssa1788;
  $647 = (($6) + 4|0);
  HEAPF32[$647>>2] = $$lcssa1792;
  $648 = (($6) + 8|0);
  HEAPF32[$648>>2] = $$lcssa1796;
  HEAPF32[$10>>2] = $$lcssa1787;
  $649 = (($10) + 4|0);
  HEAPF32[$649>>2] = $$lcssa1791;
  $650 = (($10) + 8|0);
  HEAPF32[$650>>2] = $$lcssa1795;
  HEAPF32[$14>>2] = $$lcssa1786;
  $651 = (($14) + 4|0);
  HEAPF32[$651>>2] = $$lcssa1790;
  $652 = (($14) + 8|0);
  HEAPF32[$652>>2] = $$lcssa1794;
  HEAPF32[$25>>2] = $$lcssa1801;
  $653 = (($0) + 20|0);
  HEAPF32[$653>>2] = $$lcssa1805;
  $654 = (($0) + 24|0);
  HEAPF32[$654>>2] = $$lcssa1809;
  HEAPF32[$47>>2] = $$lcssa1800;
  $655 = (($4) + 20|0);
  HEAPF32[$655>>2] = $$lcssa1804;
  $656 = (($4) + 24|0);
  HEAPF32[$656>>2] = $$lcssa1808;
  HEAPF32[$69>>2] = $$lcssa1799;
  $657 = (($8) + 20|0);
  HEAPF32[$657>>2] = $$lcssa1803;
  $658 = (($8) + 24|0);
  HEAPF32[$658>>2] = $$lcssa1807;
  HEAPF32[$91>>2] = $$lcssa1798;
  $659 = (($12) + 20|0);
  HEAPF32[$659>>2] = $$lcssa1802;
  $660 = (($12) + 24|0);
  HEAPF32[$660>>2] = $$lcssa1806;
  HEAPF32[$31>>2] = $$lcssa1813;
  $661 = (($2) + 20|0);
  HEAPF32[$661>>2] = $$lcssa1817;
  $662 = (($2) + 24|0);
  HEAPF32[$662>>2] = $$lcssa1821;
  HEAPF32[$53>>2] = $$lcssa1812;
  $663 = (($6) + 20|0);
  HEAPF32[$663>>2] = $$lcssa1816;
  $664 = (($6) + 24|0);
  HEAPF32[$664>>2] = $$lcssa1820;
  HEAPF32[$75>>2] = $$lcssa1811;
  $665 = (($10) + 20|0);
  HEAPF32[$665>>2] = $$lcssa1815;
  $666 = (($10) + 24|0);
  HEAPF32[$666>>2] = $$lcssa1819;
  HEAPF32[$97>>2] = $$lcssa1810;
  $667 = (($14) + 20|0);
  HEAPF32[$667>>2] = $$lcssa1814;
  $668 = (($14) + 24|0);
  HEAPF32[$668>>2] = $$lcssa1818;
  STACKTOP = sp;return;
 } else {
  $111 = $106;$184 = $88;$186 = $66;$188 = $44;$190 = $22;$192 = $83;$194 = $61;$196 = $39;$198 = $17;$200 = $86;$202 = $64;$204 = $42;$206 = $20;$208 = $81;$210 = $59;$212 = $37;$214 = $15;$216 = $90;$218 = $68;$220 = $46;$222 = $24;$224 = $85;$226 = $63;$228 = $41;$230 = $19;$669 = $36;$670 = $58;$671 = $80;$672 = $102;$673 = $34;$674 = $56;$675 = $78;$676 = $100;$677 = $32;$678 = $54;$679 = $76;$680 = $98;$681 = $30;$682 = $52;$683 = $74;$684 = $96;$685 = $28;$686 = $50;$687 = $72;$688 = $94;$689 = $26;$690 = $48;$691 = $70;$692 = $92;$currPtr$01822 = $104;
 }
 while(1) {
  $110 = $111&65535;
  $$sum = (($110) + 64)|0;
  $112 = (($currPtr$01822) + ($$sum)|0);
  $113 = (($currPtr$01822) + 112|0);
  $114 = (($currPtr$01822) + 1|0);
  $115 = HEAP8[$114>>0]|0;
  $116 = $115&255;
  $117 = (($113) + (($116*272)|0)|0);
  $118 = (($currPtr$01822) + 80|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = (($currPtr$01822) + 84|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = (($currPtr$01822) + 88|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = (($currPtr$01822) + 92|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = (($currPtr$01822) + 96|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = (($currPtr$01822) + 100|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = (($currPtr$01822) + 104|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  $132 = (($currPtr$01822) + 108|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = (($currPtr$01822) + 32|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = (($currPtr$01822) + 36|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = (($currPtr$01822) + 40|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = (($currPtr$01822) + 44|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = (($currPtr$01822) + 48|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = (($currPtr$01822) + 52|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = (($currPtr$01822) + 56|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  $148 = (($currPtr$01822) + 60|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = (($currPtr$01822) + 64|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = (($currPtr$01822) + 68|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  $154 = (($currPtr$01822) + 72|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = (($currPtr$01822) + 76|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = Math_fround($119 * $135);
  $159 = Math_fround($121 * $137);
  $160 = Math_fround($123 * $139);
  $161 = Math_fround($125 * $141);
  $162 = Math_fround($127 * $135);
  $163 = Math_fround($129 * $137);
  $164 = Math_fround($131 * $139);
  $165 = Math_fround($133 * $141);
  $166 = Math_fround($119 * $143);
  $167 = Math_fround($121 * $145);
  $168 = Math_fround($123 * $147);
  $169 = Math_fround($125 * $149);
  $170 = Math_fround($127 * $143);
  $171 = Math_fround($129 * $145);
  $172 = Math_fround($131 * $147);
  $173 = Math_fround($133 * $149);
  $174 = Math_fround($119 * $151);
  $175 = Math_fround($121 * $153);
  $176 = Math_fround($123 * $155);
  $177 = Math_fround($125 * $157);
  $178 = Math_fround($127 * $151);
  $179 = Math_fround($129 * $153);
  $180 = Math_fround($131 * $155);
  $181 = Math_fround($133 * $157);
  $182 = ($115<<24>>24)==(0);
  if ($182) {
   $$lcssa = $692;$$lcssa1719 = $691;$$lcssa1720 = $690;$$lcssa1721 = $689;$$lcssa1722 = $688;$$lcssa1723 = $687;$$lcssa1724 = $686;$$lcssa1725 = $685;$$lcssa1726 = $684;$$lcssa1727 = $683;$$lcssa1728 = $682;$$lcssa1729 = $681;$$lcssa1730 = $680;$$lcssa1731 = $679;$$lcssa1732 = $678;$$lcssa1733 = $677;$$lcssa1734 = $676;$$lcssa1735 = $675;$$lcssa1736 = $674;$$lcssa1737 = $673;$$lcssa1738 = $672;$$lcssa1739 = $671;$$lcssa1740 = $670;$$lcssa1741 = $669;$$lcssa1742 = Math_fround(0.0);$$lcssa1743 = Math_fround(0.0);$$lcssa1744 = Math_fround(0.0);$$lcssa1745 = Math_fround(0.0);
  } else {
   $183 = Math_fround($184 * $149);
   $185 = Math_fround($186 * $147);
   $187 = Math_fround($188 * $145);
   $189 = Math_fround($190 * $143);
   $191 = Math_fround($192 * $149);
   $193 = Math_fround($194 * $147);
   $195 = Math_fround($196 * $145);
   $197 = Math_fround($198 * $143);
   $199 = Math_fround($200 * $141);
   $201 = Math_fround($202 * $139);
   $203 = Math_fround($204 * $137);
   $205 = Math_fround($206 * $135);
   $207 = Math_fround($208 * $141);
   $209 = Math_fround($210 * $139);
   $211 = Math_fround($212 * $137);
   $213 = Math_fround($214 * $135);
   $215 = Math_fround($216 * $157);
   $217 = Math_fround($218 * $155);
   $219 = Math_fround($220 * $153);
   $221 = Math_fround($222 * $151);
   $223 = Math_fround($224 * $157);
   $225 = Math_fround($226 * $155);
   $227 = Math_fround($228 * $153);
   $229 = Math_fround($230 * $151);
   $231 = Math_fround($199 + $183);
   $232 = Math_fround($201 + $185);
   $233 = Math_fround($203 + $187);
   $234 = Math_fround($205 + $189);
   $235 = Math_fround($207 + $191);
   $236 = Math_fround($209 + $193);
   $237 = Math_fround($211 + $195);
   $238 = Math_fround($213 + $197);
   $239 = Math_fround($231 + $215);
   $240 = Math_fround($232 + $217);
   $241 = Math_fround($233 + $219);
   $242 = Math_fround($234 + $221);
   $243 = Math_fround($235 + $223);
   $244 = Math_fround($236 + $225);
   $245 = Math_fround($237 + $227);
   $246 = Math_fround($238 + $229);
   $389 = $689;$391 = $690;$393 = $691;$395 = $692;$397 = $677;$399 = $678;$401 = $679;$403 = $680;$405 = $685;$407 = $686;$409 = $687;$411 = $688;$417 = $673;$419 = $674;$421 = $675;$423 = $676;$429 = $681;$431 = $682;$433 = $683;$435 = $684;$441 = $669;$443 = $670;$445 = $671;$447 = $672;$461 = $246;$463 = $245;$465 = $244;$467 = $243;$469 = $242;$471 = $241;$473 = $240;$475 = $239;$529 = Math_fround(0.0);$531 = Math_fround(0.0);$533 = Math_fround(0.0);$535 = Math_fround(0.0);$i$01746 = 0;
   while(1) {
    $247 = (($i$01746) + 1)|0;
    $248 = (($113) + (($247*272)|0)|0);
    $249 = ((($113) + (($247*272)|0)|0) + 128|0);
    $250 = ((($113) + (($247*272)|0)|0) + 256|0);
    $$sum1718 = (($i$01746) + 2)|0;
    $251 = ((($113) + (($$sum1718*272)|0)|0) + 112|0);
    $252 = ((($113) + (($i$01746*272)|0)|0) + 48|0);
    $253 = Math_fround(HEAPF32[$252>>2]);
    $254 = ((($113) + (($i$01746*272)|0)|0) + 52|0);
    $255 = Math_fround(HEAPF32[$254>>2]);
    $256 = ((($113) + (($i$01746*272)|0)|0) + 56|0);
    $257 = Math_fround(HEAPF32[$256>>2]);
    $258 = ((($113) + (($i$01746*272)|0)|0) + 60|0);
    $259 = Math_fround(HEAPF32[$258>>2]);
    $260 = ((($113) + (($i$01746*272)|0)|0) + 64|0);
    $261 = Math_fround(HEAPF32[$260>>2]);
    $262 = ((($113) + (($i$01746*272)|0)|0) + 68|0);
    $263 = Math_fround(HEAPF32[$262>>2]);
    $264 = ((($113) + (($i$01746*272)|0)|0) + 72|0);
    $265 = Math_fround(HEAPF32[$264>>2]);
    $266 = ((($113) + (($i$01746*272)|0)|0) + 76|0);
    $267 = Math_fround(HEAPF32[$266>>2]);
    $268 = ((($113) + (($i$01746*272)|0)|0) + 80|0);
    $269 = Math_fround(HEAPF32[$268>>2]);
    $270 = ((($113) + (($i$01746*272)|0)|0) + 84|0);
    $271 = Math_fround(HEAPF32[$270>>2]);
    $272 = ((($113) + (($i$01746*272)|0)|0) + 88|0);
    $273 = Math_fround(HEAPF32[$272>>2]);
    $274 = ((($113) + (($i$01746*272)|0)|0) + 92|0);
    $275 = Math_fround(HEAPF32[$274>>2]);
    $276 = ((($113) + (($i$01746*272)|0)|0) + 224|0);
    $277 = Math_fround(HEAPF32[$276>>2]);
    $278 = ((($113) + (($i$01746*272)|0)|0) + 228|0);
    $279 = Math_fround(HEAPF32[$278>>2]);
    $280 = ((($113) + (($i$01746*272)|0)|0) + 232|0);
    $281 = Math_fround(HEAPF32[$280>>2]);
    $282 = ((($113) + (($i$01746*272)|0)|0) + 236|0);
    $283 = Math_fround(HEAPF32[$282>>2]);
    $284 = ((($113) + (($i$01746*272)|0)|0) + 240|0);
    $285 = Math_fround(HEAPF32[$284>>2]);
    $286 = ((($113) + (($i$01746*272)|0)|0) + 244|0);
    $287 = Math_fround(HEAPF32[$286>>2]);
    $288 = ((($113) + (($i$01746*272)|0)|0) + 248|0);
    $289 = Math_fround(HEAPF32[$288>>2]);
    $290 = ((($113) + (($i$01746*272)|0)|0) + 252|0);
    $291 = Math_fround(HEAPF32[$290>>2]);
    $292 = ((($113) + (($i$01746*272)|0)|0) + 256|0);
    $293 = Math_fround(HEAPF32[$292>>2]);
    $294 = ((($113) + (($i$01746*272)|0)|0) + 260|0);
    $295 = Math_fround(HEAPF32[$294>>2]);
    $296 = ((($113) + (($i$01746*272)|0)|0) + 264|0);
    $297 = Math_fround(HEAPF32[$296>>2]);
    $298 = ((($113) + (($i$01746*272)|0)|0) + 268|0);
    $299 = Math_fround(HEAPF32[$298>>2]);
    $300 = ((($113) + (($i$01746*272)|0)|0) + 96|0);
    $301 = Math_fround(HEAPF32[$300>>2]);
    $302 = ((($113) + (($i$01746*272)|0)|0) + 100|0);
    $303 = Math_fround(HEAPF32[$302>>2]);
    $304 = ((($113) + (($i$01746*272)|0)|0) + 104|0);
    $305 = Math_fround(HEAPF32[$304>>2]);
    $306 = ((($113) + (($i$01746*272)|0)|0) + 108|0);
    $307 = Math_fround(HEAPF32[$306>>2]);
    $308 = ((($113) + (($i$01746*272)|0)|0) + 112|0);
    $309 = Math_fround(HEAPF32[$308>>2]);
    $310 = ((($113) + (($i$01746*272)|0)|0) + 116|0);
    $311 = Math_fround(HEAPF32[$310>>2]);
    $312 = ((($113) + (($i$01746*272)|0)|0) + 120|0);
    $313 = Math_fround(HEAPF32[$312>>2]);
    $314 = ((($113) + (($i$01746*272)|0)|0) + 124|0);
    $315 = Math_fround(HEAPF32[$314>>2]);
    $316 = ((($113) + (($i$01746*272)|0)|0) + 128|0);
    $317 = Math_fround(HEAPF32[$316>>2]);
    $318 = ((($113) + (($i$01746*272)|0)|0) + 132|0);
    $319 = Math_fround(HEAPF32[$318>>2]);
    $320 = ((($113) + (($i$01746*272)|0)|0) + 136|0);
    $321 = Math_fround(HEAPF32[$320>>2]);
    $322 = ((($113) + (($i$01746*272)|0)|0) + 140|0);
    $323 = Math_fround(HEAPF32[$322>>2]);
    $324 = ((($113) + (($i$01746*272)|0)|0) + 144|0);
    $325 = Math_fround(HEAPF32[$324>>2]);
    $326 = ((($113) + (($i$01746*272)|0)|0) + 148|0);
    $327 = Math_fround(HEAPF32[$326>>2]);
    $328 = ((($113) + (($i$01746*272)|0)|0) + 152|0);
    $329 = Math_fround(HEAPF32[$328>>2]);
    $330 = ((($113) + (($i$01746*272)|0)|0) + 156|0);
    $331 = Math_fround(HEAPF32[$330>>2]);
    $332 = ((($113) + (($i$01746*272)|0)|0) + 160|0);
    $333 = Math_fround(HEAPF32[$332>>2]);
    $334 = ((($113) + (($i$01746*272)|0)|0) + 164|0);
    $335 = Math_fround(HEAPF32[$334>>2]);
    $336 = ((($113) + (($i$01746*272)|0)|0) + 168|0);
    $337 = Math_fround(HEAPF32[$336>>2]);
    $338 = ((($113) + (($i$01746*272)|0)|0) + 172|0);
    $339 = Math_fround(HEAPF32[$338>>2]);
    $340 = (($113) + (($i$01746*272)|0)|0);
    $341 = Math_fround(HEAPF32[$340>>2]);
    $342 = ((($113) + (($i$01746*272)|0)|0) + 4|0);
    $343 = Math_fround(HEAPF32[$342>>2]);
    $344 = ((($113) + (($i$01746*272)|0)|0) + 8|0);
    $345 = Math_fround(HEAPF32[$344>>2]);
    $346 = ((($113) + (($i$01746*272)|0)|0) + 12|0);
    $347 = Math_fround(HEAPF32[$346>>2]);
    $348 = ((($113) + (($i$01746*272)|0)|0) + 16|0);
    $349 = Math_fround(HEAPF32[$348>>2]);
    $350 = ((($113) + (($i$01746*272)|0)|0) + 20|0);
    $351 = Math_fround(HEAPF32[$350>>2]);
    $352 = ((($113) + (($i$01746*272)|0)|0) + 24|0);
    $353 = Math_fround(HEAPF32[$352>>2]);
    $354 = ((($113) + (($i$01746*272)|0)|0) + 28|0);
    $355 = Math_fround(HEAPF32[$354>>2]);
    $356 = ((($113) + (($i$01746*272)|0)|0) + 32|0);
    $357 = Math_fround(HEAPF32[$356>>2]);
    $358 = ((($113) + (($i$01746*272)|0)|0) + 36|0);
    $359 = Math_fround(HEAPF32[$358>>2]);
    $360 = ((($113) + (($i$01746*272)|0)|0) + 40|0);
    $361 = Math_fround(HEAPF32[$360>>2]);
    $362 = ((($113) + (($i$01746*272)|0)|0) + 44|0);
    $363 = Math_fround(HEAPF32[$362>>2]);
    $364 = ((($113) + (($i$01746*272)|0)|0) + 176|0);
    $365 = Math_fround(HEAPF32[$364>>2]);
    $366 = ((($113) + (($i$01746*272)|0)|0) + 180|0);
    $367 = Math_fround(HEAPF32[$366>>2]);
    $368 = ((($113) + (($i$01746*272)|0)|0) + 184|0);
    $369 = Math_fround(HEAPF32[$368>>2]);
    $370 = ((($113) + (($i$01746*272)|0)|0) + 188|0);
    $371 = Math_fround(HEAPF32[$370>>2]);
    $372 = ((($113) + (($i$01746*272)|0)|0) + 192|0);
    $373 = Math_fround(HEAPF32[$372>>2]);
    $374 = ((($113) + (($i$01746*272)|0)|0) + 196|0);
    $375 = Math_fround(HEAPF32[$374>>2]);
    $376 = ((($113) + (($i$01746*272)|0)|0) + 200|0);
    $377 = Math_fround(HEAPF32[$376>>2]);
    $378 = ((($113) + (($i$01746*272)|0)|0) + 204|0);
    $379 = Math_fround(HEAPF32[$378>>2]);
    $380 = ((($113) + (($i$01746*272)|0)|0) + 208|0);
    $381 = Math_fround(HEAPF32[$380>>2]);
    $382 = ((($113) + (($i$01746*272)|0)|0) + 212|0);
    $383 = Math_fround(HEAPF32[$382>>2]);
    $384 = ((($113) + (($i$01746*272)|0)|0) + 216|0);
    $385 = Math_fround(HEAPF32[$384>>2]);
    $386 = ((($113) + (($i$01746*272)|0)|0) + 220|0);
    $387 = Math_fround(HEAPF32[$386>>2]);
    $388 = Math_fround($389 * $341);
    $390 = Math_fround($391 * $343);
    $392 = Math_fround($393 * $345);
    $394 = Math_fround($395 * $347);
    $396 = Math_fround($397 * $365);
    $398 = Math_fround($399 * $367);
    $400 = Math_fround($401 * $369);
    $402 = Math_fround($403 * $371);
    $404 = Math_fround($405 * $349);
    $406 = Math_fround($407 * $351);
    $408 = Math_fround($409 * $353);
    $410 = Math_fround($411 * $355);
    $412 = Math_fround($388 + $404);
    $413 = Math_fround($390 + $406);
    $414 = Math_fround($392 + $408);
    $415 = Math_fround($394 + $410);
    $416 = Math_fround($417 * $373);
    $418 = Math_fround($419 * $375);
    $420 = Math_fround($421 * $377);
    $422 = Math_fround($423 * $379);
    $424 = Math_fround($396 + $416);
    $425 = Math_fround($398 + $418);
    $426 = Math_fround($400 + $420);
    $427 = Math_fround($402 + $422);
    $428 = Math_fround($429 * $357);
    $430 = Math_fround($431 * $359);
    $432 = Math_fround($433 * $361);
    $434 = Math_fround($435 * $363);
    $436 = Math_fround($412 + $428);
    $437 = Math_fround($413 + $430);
    $438 = Math_fround($414 + $432);
    $439 = Math_fround($415 + $434);
    $440 = Math_fround($441 * $381);
    $442 = Math_fround($443 * $383);
    $444 = Math_fround($445 * $385);
    $446 = Math_fround($447 * $387);
    $448 = Math_fround($424 + $440);
    $449 = Math_fround($425 + $442);
    $450 = Math_fround($426 + $444);
    $451 = Math_fround($427 + $446);
    $452 = Math_fround($309 * $317);
    $453 = Math_fround($311 * $319);
    $454 = Math_fround($313 * $321);
    $455 = Math_fround($315 * $323);
    $456 = Math_fround($452 - $325);
    $457 = Math_fround($453 - $327);
    $458 = Math_fround($454 - $329);
    $459 = Math_fround($455 - $331);
    $460 = Math_fround($461 + $436);
    $462 = Math_fround($463 + $437);
    $464 = Math_fround($465 + $438);
    $466 = Math_fround($467 + $439);
    $468 = Math_fround($469 + $448);
    $470 = Math_fround($471 + $449);
    $472 = Math_fround($473 + $450);
    $474 = Math_fround($475 + $451);
    $476 = Math_fround($460 - $468);
    $477 = Math_fround($462 - $470);
    $478 = Math_fround($464 - $472);
    $479 = Math_fround($466 - $474);
    $480 = Math_fround($309 * $476);
    $481 = Math_fround($311 * $477);
    $482 = Math_fround($313 * $478);
    $483 = Math_fround($315 * $479);
    $484 = Math_fround($456 - $480);
    $485 = Math_fround($457 - $481);
    $486 = Math_fround($458 - $482);
    $487 = Math_fround($459 - $483);
    $488 = Math_fround(-$301);
    $489 = Math_fround(-$303);
    $490 = Math_fround(-$305);
    $491 = Math_fround(-$307);
    $492 = $484 > $488;
    $$$i168 = $492 ? $484 : $488;
    $493 = $485 > $489;
    $494 = $493 ? $485 : $489;
    $495 = $486 > $490;
    $$1$i169 = $495 ? $486 : $490;
    $496 = $487 > $491;
    $497 = $496 ? $487 : $491;
    $498 = Math_fround($301 + $$$i168);
    $499 = Math_fround($303 + $494);
    $500 = Math_fround($305 + $$1$i169);
    $501 = Math_fround($307 + $497);
    $502 = $498 < $333;
    $$$i = $502 ? $498 : $333;
    $503 = $499 < $335;
    $504 = $503 ? $499 : $335;
    $505 = $500 < $337;
    $$1$i = $505 ? $500 : $337;
    $506 = $501 < $339;
    $507 = $506 ? $501 : $339;
    $508 = Math_fround($$$i - $301);
    $509 = Math_fround($504 - $303);
    $510 = Math_fround($$1$i - $305);
    $511 = Math_fround($507 - $307);
    $512 = Math_fround($119 * $508);
    $513 = Math_fround($121 * $509);
    $514 = Math_fround($123 * $510);
    $515 = Math_fround($125 * $511);
    $516 = Math_fround($461 + $512);
    $517 = Math_fround($463 + $513);
    $518 = Math_fround($465 + $514);
    $519 = Math_fround($467 + $515);
    $520 = Math_fround($127 * $508);
    $521 = Math_fround($129 * $509);
    $522 = Math_fround($131 * $510);
    $523 = Math_fround($133 * $511);
    $524 = Math_fround($469 + $520);
    $525 = Math_fround($471 + $521);
    $526 = Math_fround($473 + $522);
    $527 = Math_fround($475 + $523);
    $528 = Math_fround($529 + $508);
    $530 = Math_fround($531 + $509);
    $532 = Math_fround($533 + $510);
    $534 = Math_fround($535 + $511);
    $536 = Math_fround($253 * $508);
    $537 = Math_fround($255 * $509);
    $538 = Math_fround($257 * $510);
    $539 = Math_fround($259 * $511);
    $540 = Math_fround($389 + $536);
    $541 = Math_fround($391 + $537);
    $542 = Math_fround($393 + $538);
    $543 = Math_fround($395 + $539);
    $544 = Math_fround($277 * $508);
    $545 = Math_fround($279 * $509);
    $546 = Math_fround($281 * $510);
    $547 = Math_fround($283 * $511);
    $548 = Math_fround($397 + $544);
    $549 = Math_fround($399 + $545);
    $550 = Math_fround($401 + $546);
    $551 = Math_fround($403 + $547);
    $552 = Math_fround($261 * $508);
    $553 = Math_fround($263 * $509);
    $554 = Math_fround($265 * $510);
    $555 = Math_fround($267 * $511);
    $556 = Math_fround($405 + $552);
    $557 = Math_fround($407 + $553);
    $558 = Math_fround($409 + $554);
    $559 = Math_fround($411 + $555);
    $560 = Math_fround($285 * $508);
    $561 = Math_fround($287 * $509);
    $562 = Math_fround($289 * $510);
    $563 = Math_fround($291 * $511);
    $564 = Math_fround($417 + $560);
    $565 = Math_fround($419 + $561);
    $566 = Math_fround($421 + $562);
    $567 = Math_fround($423 + $563);
    $568 = Math_fround($269 * $508);
    $569 = Math_fround($271 * $509);
    $570 = Math_fround($273 * $510);
    $571 = Math_fround($275 * $511);
    $572 = Math_fround($429 + $568);
    $573 = Math_fround($431 + $569);
    $574 = Math_fround($433 + $570);
    $575 = Math_fround($435 + $571);
    $576 = Math_fround($293 * $508);
    $577 = Math_fround($295 * $509);
    $578 = Math_fround($297 * $510);
    $579 = Math_fround($299 * $511);
    $580 = Math_fround($441 + $576);
    $581 = Math_fround($443 + $577);
    $582 = Math_fround($445 + $578);
    $583 = Math_fround($447 + $579);
    HEAPF32[$300>>2] = $$$i;
    HEAPF32[$302>>2] = $504;
    HEAPF32[$304>>2] = $$1$i;
    HEAPF32[$306>>2] = $507;
    $584 = (($112) + ($i$01746<<4)|0);
    HEAPF32[$584>>2] = $$$i;
    $585 = ((($112) + ($i$01746<<4)|0) + 4|0);
    HEAPF32[$585>>2] = $504;
    $586 = ((($112) + ($i$01746<<4)|0) + 8|0);
    HEAPF32[$586>>2] = $$1$i;
    $587 = ((($112) + ($i$01746<<4)|0) + 12|0);
    HEAPF32[$587>>2] = $507;
    $exitcond = ($247|0)==($116|0);
    if ($exitcond) {
     $$lcssa = $543;$$lcssa1719 = $542;$$lcssa1720 = $541;$$lcssa1721 = $540;$$lcssa1722 = $559;$$lcssa1723 = $558;$$lcssa1724 = $557;$$lcssa1725 = $556;$$lcssa1726 = $575;$$lcssa1727 = $574;$$lcssa1728 = $573;$$lcssa1729 = $572;$$lcssa1730 = $551;$$lcssa1731 = $550;$$lcssa1732 = $549;$$lcssa1733 = $548;$$lcssa1734 = $567;$$lcssa1735 = $566;$$lcssa1736 = $565;$$lcssa1737 = $564;$$lcssa1738 = $583;$$lcssa1739 = $582;$$lcssa1740 = $581;$$lcssa1741 = $580;$$lcssa1742 = $534;$$lcssa1743 = $532;$$lcssa1744 = $530;$$lcssa1745 = $528;
     break;
    } else {
     $389 = $540;$391 = $541;$393 = $542;$395 = $543;$397 = $548;$399 = $549;$401 = $550;$403 = $551;$405 = $556;$407 = $557;$409 = $558;$411 = $559;$417 = $564;$419 = $565;$421 = $566;$423 = $567;$429 = $572;$431 = $573;$433 = $574;$435 = $575;$441 = $580;$443 = $581;$445 = $582;$447 = $583;$461 = $516;$463 = $517;$465 = $518;$467 = $519;$469 = $524;$471 = $525;$473 = $526;$475 = $527;$529 = $528;$531 = $530;$533 = $532;$535 = $534;$i$01746 = $247;
    }
   }
  }
  $588 = Math_fround($158 * $$lcssa1745);
  $589 = Math_fround($159 * $$lcssa1744);
  $590 = Math_fround($160 * $$lcssa1743);
  $591 = Math_fround($161 * $$lcssa1742);
  $592 = Math_fround($214 + $588);
  $593 = Math_fround($212 + $589);
  $594 = Math_fround($210 + $590);
  $595 = Math_fround($208 + $591);
  $596 = Math_fround($162 * $$lcssa1745);
  $597 = Math_fround($163 * $$lcssa1744);
  $598 = Math_fround($164 * $$lcssa1743);
  $599 = Math_fround($165 * $$lcssa1742);
  $600 = Math_fround($206 + $596);
  $601 = Math_fround($204 + $597);
  $602 = Math_fround($202 + $598);
  $603 = Math_fround($200 + $599);
  $604 = Math_fround($166 * $$lcssa1745);
  $605 = Math_fround($167 * $$lcssa1744);
  $606 = Math_fround($168 * $$lcssa1743);
  $607 = Math_fround($169 * $$lcssa1742);
  $608 = Math_fround($198 + $604);
  $609 = Math_fround($196 + $605);
  $610 = Math_fround($194 + $606);
  $611 = Math_fround($192 + $607);
  $612 = Math_fround($170 * $$lcssa1745);
  $613 = Math_fround($171 * $$lcssa1744);
  $614 = Math_fround($172 * $$lcssa1743);
  $615 = Math_fround($173 * $$lcssa1742);
  $616 = Math_fround($190 + $612);
  $617 = Math_fround($188 + $613);
  $618 = Math_fround($186 + $614);
  $619 = Math_fround($184 + $615);
  $620 = Math_fround($174 * $$lcssa1745);
  $621 = Math_fround($175 * $$lcssa1744);
  $622 = Math_fround($176 * $$lcssa1743);
  $623 = Math_fround($177 * $$lcssa1742);
  $624 = Math_fround($230 + $620);
  $625 = Math_fround($228 + $621);
  $626 = Math_fround($226 + $622);
  $627 = Math_fround($224 + $623);
  $628 = Math_fround($178 * $$lcssa1745);
  $629 = Math_fround($179 * $$lcssa1744);
  $630 = Math_fround($180 * $$lcssa1743);
  $631 = Math_fround($181 * $$lcssa1742);
  $632 = Math_fround($222 + $628);
  $633 = Math_fround($220 + $629);
  $634 = Math_fround($218 + $630);
  $635 = Math_fround($216 + $631);
  $636 = ($117>>>0)<($108>>>0);
  if (!($636)) {
   $$lcssa1774 = $595;$$lcssa1775 = $594;$$lcssa1776 = $593;$$lcssa1777 = $592;$$lcssa1778 = $611;$$lcssa1779 = $610;$$lcssa1780 = $609;$$lcssa1781 = $608;$$lcssa1782 = $627;$$lcssa1783 = $626;$$lcssa1784 = $625;$$lcssa1785 = $624;$$lcssa1786 = $603;$$lcssa1787 = $602;$$lcssa1788 = $601;$$lcssa1789 = $600;$$lcssa1790 = $619;$$lcssa1791 = $618;$$lcssa1792 = $617;$$lcssa1793 = $616;$$lcssa1794 = $635;$$lcssa1795 = $634;$$lcssa1796 = $633;$$lcssa1797 = $632;$$lcssa1798 = $$lcssa;$$lcssa1799 = $$lcssa1719;$$lcssa1800 = $$lcssa1720;$$lcssa1801 = $$lcssa1721;$$lcssa1802 = $$lcssa1722;$$lcssa1803 = $$lcssa1723;$$lcssa1804 = $$lcssa1724;$$lcssa1805 = $$lcssa1725;$$lcssa1806 = $$lcssa1726;$$lcssa1807 = $$lcssa1727;$$lcssa1808 = $$lcssa1728;$$lcssa1809 = $$lcssa1729;$$lcssa1810 = $$lcssa1730;$$lcssa1811 = $$lcssa1731;$$lcssa1812 = $$lcssa1732;$$lcssa1813 = $$lcssa1733;$$lcssa1814 = $$lcssa1734;$$lcssa1815 = $$lcssa1735;$$lcssa1816 = $$lcssa1736;$$lcssa1817 = $$lcssa1737;$$lcssa1818 = $$lcssa1738;$$lcssa1819 = $$lcssa1739;$$lcssa1820 = $$lcssa1740;$$lcssa1821 = $$lcssa1741;
   break;
  }
  $$phi$trans$insert = (($117) + 2|0);
  $$pre = HEAP16[$$phi$trans$insert>>1]|0;
  $111 = $$pre;$184 = $619;$186 = $618;$188 = $617;$190 = $616;$192 = $611;$194 = $610;$196 = $609;$198 = $608;$200 = $603;$202 = $602;$204 = $601;$206 = $600;$208 = $595;$210 = $594;$212 = $593;$214 = $592;$216 = $635;$218 = $634;$220 = $633;$222 = $632;$224 = $627;$226 = $626;$228 = $625;$230 = $624;$669 = $$lcssa1741;$670 = $$lcssa1740;$671 = $$lcssa1739;$672 = $$lcssa1738;$673 = $$lcssa1737;$674 = $$lcssa1736;$675 = $$lcssa1735;$676 = $$lcssa1734;$677 = $$lcssa1733;$678 = $$lcssa1732;$679 = $$lcssa1731;$680 = $$lcssa1730;$681 = $$lcssa1729;$682 = $$lcssa1728;$683 = $$lcssa1727;$684 = $$lcssa1726;$685 = $$lcssa1725;$686 = $$lcssa1724;$687 = $$lcssa1723;$688 = $$lcssa1722;$689 = $$lcssa1721;$690 = $$lcssa1720;$691 = $$lcssa1719;$692 = $$lcssa;$currPtr$01822 = $117;
 }
 HEAPF32[$0>>2] = $$lcssa1777;
 $637 = (($0) + 4|0);
 HEAPF32[$637>>2] = $$lcssa1781;
 $638 = (($0) + 8|0);
 HEAPF32[$638>>2] = $$lcssa1785;
 HEAPF32[$4>>2] = $$lcssa1776;
 $639 = (($4) + 4|0);
 HEAPF32[$639>>2] = $$lcssa1780;
 $640 = (($4) + 8|0);
 HEAPF32[$640>>2] = $$lcssa1784;
 HEAPF32[$8>>2] = $$lcssa1775;
 $641 = (($8) + 4|0);
 HEAPF32[$641>>2] = $$lcssa1779;
 $642 = (($8) + 8|0);
 HEAPF32[$642>>2] = $$lcssa1783;
 HEAPF32[$12>>2] = $$lcssa1774;
 $643 = (($12) + 4|0);
 HEAPF32[$643>>2] = $$lcssa1778;
 $644 = (($12) + 8|0);
 HEAPF32[$644>>2] = $$lcssa1782;
 HEAPF32[$2>>2] = $$lcssa1789;
 $645 = (($2) + 4|0);
 HEAPF32[$645>>2] = $$lcssa1793;
 $646 = (($2) + 8|0);
 HEAPF32[$646>>2] = $$lcssa1797;
 HEAPF32[$6>>2] = $$lcssa1788;
 $647 = (($6) + 4|0);
 HEAPF32[$647>>2] = $$lcssa1792;
 $648 = (($6) + 8|0);
 HEAPF32[$648>>2] = $$lcssa1796;
 HEAPF32[$10>>2] = $$lcssa1787;
 $649 = (($10) + 4|0);
 HEAPF32[$649>>2] = $$lcssa1791;
 $650 = (($10) + 8|0);
 HEAPF32[$650>>2] = $$lcssa1795;
 HEAPF32[$14>>2] = $$lcssa1786;
 $651 = (($14) + 4|0);
 HEAPF32[$651>>2] = $$lcssa1790;
 $652 = (($14) + 8|0);
 HEAPF32[$652>>2] = $$lcssa1794;
 HEAPF32[$25>>2] = $$lcssa1801;
 $653 = (($0) + 20|0);
 HEAPF32[$653>>2] = $$lcssa1805;
 $654 = (($0) + 24|0);
 HEAPF32[$654>>2] = $$lcssa1809;
 HEAPF32[$47>>2] = $$lcssa1800;
 $655 = (($4) + 20|0);
 HEAPF32[$655>>2] = $$lcssa1804;
 $656 = (($4) + 24|0);
 HEAPF32[$656>>2] = $$lcssa1808;
 HEAPF32[$69>>2] = $$lcssa1799;
 $657 = (($8) + 20|0);
 HEAPF32[$657>>2] = $$lcssa1803;
 $658 = (($8) + 24|0);
 HEAPF32[$658>>2] = $$lcssa1807;
 HEAPF32[$91>>2] = $$lcssa1798;
 $659 = (($12) + 20|0);
 HEAPF32[$659>>2] = $$lcssa1802;
 $660 = (($12) + 24|0);
 HEAPF32[$660>>2] = $$lcssa1806;
 HEAPF32[$31>>2] = $$lcssa1813;
 $661 = (($2) + 20|0);
 HEAPF32[$661>>2] = $$lcssa1817;
 $662 = (($2) + 24|0);
 HEAPF32[$662>>2] = $$lcssa1821;
 HEAPF32[$53>>2] = $$lcssa1812;
 $663 = (($6) + 20|0);
 HEAPF32[$663>>2] = $$lcssa1816;
 $664 = (($6) + 24|0);
 HEAPF32[$664>>2] = $$lcssa1820;
 HEAPF32[$75>>2] = $$lcssa1811;
 $665 = (($10) + 20|0);
 HEAPF32[$665>>2] = $$lcssa1815;
 $666 = (($10) + 24|0);
 HEAPF32[$666>>2] = $$lcssa1819;
 HEAPF32[$97>>2] = $$lcssa1810;
 $667 = (($14) + 20|0);
 HEAPF32[$667>>2] = $$lcssa1814;
 $668 = (($14) + 24|0);
 HEAPF32[$668>>2] = $$lcssa1818;
 STACKTOP = sp;return;
}
function __ZN5physx34solveContactCoulombPreBlock_StaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL32solveContactCoulomb4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physxL32solveContactCoulomb4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc) {
 $desc = $desc|0;
 var $$$i = Math_fround(0), $$$i94 = Math_fround(0), $$1$i = Math_fround(0), $$1$i95 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa941 = Math_fround(0), $$lcssa942 = Math_fround(0), $$lcssa943 = Math_fround(0), $$lcssa944 = Math_fround(0), $$lcssa945 = Math_fround(0), $$lcssa946 = Math_fround(0), $$lcssa947 = Math_fround(0), $$lcssa948 = Math_fround(0), $$lcssa949 = Math_fround(0), $$lcssa950 = Math_fround(0), $$lcssa951 = Math_fround(0), $$lcssa952 = Math_fround(0), $$lcssa953 = Math_fround(0), $$lcssa954 = Math_fround(0), $$lcssa955 = Math_fround(0);
 var $$lcssa972 = Math_fround(0), $$lcssa973 = Math_fround(0), $$lcssa974 = Math_fround(0), $$lcssa975 = Math_fround(0), $$lcssa976 = Math_fround(0), $$lcssa977 = Math_fround(0), $$lcssa978 = Math_fround(0), $$lcssa979 = Math_fround(0), $$lcssa980 = Math_fround(0), $$lcssa981 = Math_fround(0), $$lcssa982 = Math_fround(0), $$lcssa983 = Math_fround(0), $$lcssa984 = Math_fround(0), $$lcssa985 = Math_fround(0), $$lcssa986 = Math_fround(0), $$lcssa987 = Math_fround(0), $$lcssa988 = Math_fround(0), $$lcssa989 = Math_fround(0), $$lcssa990 = Math_fround(0), $$lcssa991 = Math_fround(0);
 var $$lcssa992 = Math_fround(0), $$lcssa993 = Math_fround(0), $$lcssa994 = Math_fround(0), $$lcssa995 = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum940 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0);
 var $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0);
 var $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0;
 var $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0);
 var $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0);
 var $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0);
 var $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0);
 var $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = 0;
 var $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0);
 var $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0);
 var $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0);
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0);
 var $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $currPtr$0996 = 0, $exitcond = 0, $i$0956 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($desc) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($desc) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$0>>2]);
 $8 = (($0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($0) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($12) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$2>>2]);
 $19 = (($2) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($2) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($2) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($23) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($23) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$4>>2]);
 $30 = (($4) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($4) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($4) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($34) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($34) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround(HEAPF32[$6>>2]);
 $41 = (($6) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($6) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($6) + 16|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($45) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($45) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($desc) + 16|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 2|0);
 $54 = HEAP16[$53>>1]|0;
 $55 = $54&65535;
 $56 = (($52) + ($55)|0);
 $57 = ($54<<16>>16)==(0);
 if ($57) {
  $$lcssa972 = $40;$$lcssa973 = $29;$$lcssa974 = $18;$$lcssa975 = $7;$$lcssa976 = $42;$$lcssa977 = $31;$$lcssa978 = $20;$$lcssa979 = $9;$$lcssa980 = $44;$$lcssa981 = $33;$$lcssa982 = $22;$$lcssa983 = $11;$$lcssa984 = $46;$$lcssa985 = $35;$$lcssa986 = $24;$$lcssa987 = $13;$$lcssa988 = $48;$$lcssa989 = $37;$$lcssa990 = $26;$$lcssa991 = $15;$$lcssa992 = $50;$$lcssa993 = $39;$$lcssa994 = $28;$$lcssa995 = $17;
  HEAPF32[$0>>2] = $$lcssa975;
  $384 = (($0) + 4|0);
  HEAPF32[$384>>2] = $$lcssa979;
  $385 = (($0) + 8|0);
  HEAPF32[$385>>2] = $$lcssa983;
  HEAPF32[$2>>2] = $$lcssa974;
  $386 = (($2) + 4|0);
  HEAPF32[$386>>2] = $$lcssa978;
  $387 = (($2) + 8|0);
  HEAPF32[$387>>2] = $$lcssa982;
  HEAPF32[$4>>2] = $$lcssa973;
  $388 = (($4) + 4|0);
  HEAPF32[$388>>2] = $$lcssa977;
  $389 = (($4) + 8|0);
  HEAPF32[$389>>2] = $$lcssa981;
  HEAPF32[$6>>2] = $$lcssa972;
  $390 = (($6) + 4|0);
  HEAPF32[$390>>2] = $$lcssa976;
  $391 = (($6) + 8|0);
  HEAPF32[$391>>2] = $$lcssa980;
  HEAPF32[$12>>2] = $$lcssa987;
  $392 = (($0) + 20|0);
  HEAPF32[$392>>2] = $$lcssa991;
  $393 = (($0) + 24|0);
  HEAPF32[$393>>2] = $$lcssa995;
  HEAPF32[$23>>2] = $$lcssa986;
  $394 = (($2) + 20|0);
  HEAPF32[$394>>2] = $$lcssa990;
  $395 = (($2) + 24|0);
  HEAPF32[$395>>2] = $$lcssa994;
  HEAPF32[$34>>2] = $$lcssa985;
  $396 = (($4) + 20|0);
  HEAPF32[$396>>2] = $$lcssa989;
  $397 = (($4) + 24|0);
  HEAPF32[$397>>2] = $$lcssa993;
  HEAPF32[$45>>2] = $$lcssa984;
  $398 = (($6) + 20|0);
  HEAPF32[$398>>2] = $$lcssa988;
  $399 = (($6) + 24|0);
  HEAPF32[$399>>2] = $$lcssa992;
  STACKTOP = sp;return;
 } else {
  $112 = $42;$114 = $31;$116 = $20;$118 = $9;$120 = $40;$122 = $29;$124 = $18;$126 = $7;$128 = $44;$130 = $33;$132 = $22;$134 = $11;$400 = $17;$401 = $28;$402 = $39;$403 = $50;$404 = $15;$405 = $26;$406 = $37;$407 = $48;$408 = $13;$409 = $24;$410 = $35;$411 = $46;$59 = $54;$currPtr$0996 = $52;
 }
 while(1) {
  $58 = $59&65535;
  $$sum = (($58) + 64)|0;
  $60 = (($currPtr$0996) + ($$sum)|0);
  $61 = (($currPtr$0996) + 112|0);
  $62 = (($currPtr$0996) + 1|0);
  $63 = HEAP8[$62>>0]|0;
  $64 = $63&255;
  $65 = (($61) + (($64*176)|0)|0);
  $66 = (($currPtr$0996) + 80|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = (($currPtr$0996) + 84|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($currPtr$0996) + 88|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = (($currPtr$0996) + 92|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = (($currPtr$0996) + 32|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = (($currPtr$0996) + 36|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = (($currPtr$0996) + 40|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = (($currPtr$0996) + 44|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($currPtr$0996) + 48|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($currPtr$0996) + 52|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = (($currPtr$0996) + 56|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = (($currPtr$0996) + 60|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = (($currPtr$0996) + 64|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = (($currPtr$0996) + 68|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = (($currPtr$0996) + 72|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = (($currPtr$0996) + 76|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = Math_fround($67 * $75);
  $99 = Math_fround($69 * $77);
  $100 = Math_fround($71 * $79);
  $101 = Math_fround($73 * $81);
  $102 = Math_fround($67 * $83);
  $103 = Math_fround($69 * $85);
  $104 = Math_fround($71 * $87);
  $105 = Math_fround($73 * $89);
  $106 = Math_fround($67 * $91);
  $107 = Math_fround($69 * $93);
  $108 = Math_fround($71 * $95);
  $109 = Math_fround($73 * $97);
  $110 = ($63<<24>>24)==(0);
  if ($110) {
   $$lcssa = $411;$$lcssa941 = $410;$$lcssa942 = $409;$$lcssa943 = $408;$$lcssa944 = $407;$$lcssa945 = $406;$$lcssa946 = $405;$$lcssa947 = $404;$$lcssa948 = $403;$$lcssa949 = $402;$$lcssa950 = $401;$$lcssa951 = $400;$$lcssa952 = Math_fround(0.0);$$lcssa953 = Math_fround(0.0);$$lcssa954 = Math_fround(0.0);$$lcssa955 = Math_fround(0.0);
  } else {
   $111 = Math_fround($112 * $89);
   $113 = Math_fround($114 * $87);
   $115 = Math_fround($116 * $85);
   $117 = Math_fround($118 * $83);
   $119 = Math_fround($120 * $81);
   $121 = Math_fround($122 * $79);
   $123 = Math_fround($124 * $77);
   $125 = Math_fround($126 * $75);
   $127 = Math_fround($128 * $97);
   $129 = Math_fround($130 * $95);
   $131 = Math_fround($132 * $93);
   $133 = Math_fround($134 * $91);
   $135 = Math_fround($119 + $111);
   $136 = Math_fround($121 + $113);
   $137 = Math_fround($123 + $115);
   $138 = Math_fround($125 + $117);
   $139 = Math_fround($135 + $127);
   $140 = Math_fround($136 + $129);
   $141 = Math_fround($137 + $131);
   $142 = Math_fround($138 + $133);
   $236 = $408;$238 = $409;$240 = $410;$242 = $411;$244 = $404;$246 = $405;$248 = $406;$250 = $407;$256 = $400;$258 = $401;$260 = $402;$262 = $403;$276 = $142;$278 = $141;$280 = $140;$282 = $139;$324 = Math_fround(0.0);$326 = Math_fround(0.0);$328 = Math_fround(0.0);$330 = Math_fround(0.0);$i$0956 = 0;
   while(1) {
    $143 = (($i$0956) + 1)|0;
    $144 = (($61) + (($143*176)|0)|0);
    $145 = ((($61) + (($143*176)|0)|0) + 128|0);
    $$sum940 = (($i$0956) + 2)|0;
    $146 = ((($61) + (($$sum940*176)|0)|0) + 80|0);
    $147 = ((($61) + (($i$0956*176)|0)|0) + 48|0);
    $148 = Math_fround(HEAPF32[$147>>2]);
    $149 = ((($61) + (($i$0956*176)|0)|0) + 52|0);
    $150 = Math_fround(HEAPF32[$149>>2]);
    $151 = ((($61) + (($i$0956*176)|0)|0) + 56|0);
    $152 = Math_fround(HEAPF32[$151>>2]);
    $153 = ((($61) + (($i$0956*176)|0)|0) + 60|0);
    $154 = Math_fround(HEAPF32[$153>>2]);
    $155 = ((($61) + (($i$0956*176)|0)|0) + 64|0);
    $156 = Math_fround(HEAPF32[$155>>2]);
    $157 = ((($61) + (($i$0956*176)|0)|0) + 68|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = ((($61) + (($i$0956*176)|0)|0) + 72|0);
    $160 = Math_fround(HEAPF32[$159>>2]);
    $161 = ((($61) + (($i$0956*176)|0)|0) + 76|0);
    $162 = Math_fround(HEAPF32[$161>>2]);
    $163 = ((($61) + (($i$0956*176)|0)|0) + 80|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = ((($61) + (($i$0956*176)|0)|0) + 84|0);
    $166 = Math_fround(HEAPF32[$165>>2]);
    $167 = ((($61) + (($i$0956*176)|0)|0) + 88|0);
    $168 = Math_fround(HEAPF32[$167>>2]);
    $169 = ((($61) + (($i$0956*176)|0)|0) + 92|0);
    $170 = Math_fround(HEAPF32[$169>>2]);
    $171 = ((($61) + (($i$0956*176)|0)|0) + 96|0);
    $172 = Math_fround(HEAPF32[$171>>2]);
    $173 = ((($61) + (($i$0956*176)|0)|0) + 100|0);
    $174 = Math_fround(HEAPF32[$173>>2]);
    $175 = ((($61) + (($i$0956*176)|0)|0) + 104|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = ((($61) + (($i$0956*176)|0)|0) + 108|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = ((($61) + (($i$0956*176)|0)|0) + 112|0);
    $180 = Math_fround(HEAPF32[$179>>2]);
    $181 = ((($61) + (($i$0956*176)|0)|0) + 116|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = ((($61) + (($i$0956*176)|0)|0) + 120|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    $185 = ((($61) + (($i$0956*176)|0)|0) + 124|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = ((($61) + (($i$0956*176)|0)|0) + 128|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = ((($61) + (($i$0956*176)|0)|0) + 132|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = ((($61) + (($i$0956*176)|0)|0) + 136|0);
    $192 = Math_fround(HEAPF32[$191>>2]);
    $193 = ((($61) + (($i$0956*176)|0)|0) + 140|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = ((($61) + (($i$0956*176)|0)|0) + 144|0);
    $196 = Math_fround(HEAPF32[$195>>2]);
    $197 = ((($61) + (($i$0956*176)|0)|0) + 148|0);
    $198 = Math_fround(HEAPF32[$197>>2]);
    $199 = ((($61) + (($i$0956*176)|0)|0) + 152|0);
    $200 = Math_fround(HEAPF32[$199>>2]);
    $201 = ((($61) + (($i$0956*176)|0)|0) + 156|0);
    $202 = Math_fround(HEAPF32[$201>>2]);
    $203 = ((($61) + (($i$0956*176)|0)|0) + 160|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = ((($61) + (($i$0956*176)|0)|0) + 164|0);
    $206 = Math_fround(HEAPF32[$205>>2]);
    $207 = ((($61) + (($i$0956*176)|0)|0) + 168|0);
    $208 = Math_fround(HEAPF32[$207>>2]);
    $209 = ((($61) + (($i$0956*176)|0)|0) + 172|0);
    $210 = Math_fround(HEAPF32[$209>>2]);
    $211 = (($61) + (($i$0956*176)|0)|0);
    $212 = Math_fround(HEAPF32[$211>>2]);
    $213 = ((($61) + (($i$0956*176)|0)|0) + 4|0);
    $214 = Math_fround(HEAPF32[$213>>2]);
    $215 = ((($61) + (($i$0956*176)|0)|0) + 8|0);
    $216 = Math_fround(HEAPF32[$215>>2]);
    $217 = ((($61) + (($i$0956*176)|0)|0) + 12|0);
    $218 = Math_fround(HEAPF32[$217>>2]);
    $219 = ((($61) + (($i$0956*176)|0)|0) + 16|0);
    $220 = Math_fround(HEAPF32[$219>>2]);
    $221 = ((($61) + (($i$0956*176)|0)|0) + 20|0);
    $222 = Math_fround(HEAPF32[$221>>2]);
    $223 = ((($61) + (($i$0956*176)|0)|0) + 24|0);
    $224 = Math_fround(HEAPF32[$223>>2]);
    $225 = ((($61) + (($i$0956*176)|0)|0) + 28|0);
    $226 = Math_fround(HEAPF32[$225>>2]);
    $227 = ((($61) + (($i$0956*176)|0)|0) + 32|0);
    $228 = Math_fround(HEAPF32[$227>>2]);
    $229 = ((($61) + (($i$0956*176)|0)|0) + 36|0);
    $230 = Math_fround(HEAPF32[$229>>2]);
    $231 = ((($61) + (($i$0956*176)|0)|0) + 40|0);
    $232 = Math_fround(HEAPF32[$231>>2]);
    $233 = ((($61) + (($i$0956*176)|0)|0) + 44|0);
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = Math_fround($236 * $212);
    $237 = Math_fround($238 * $214);
    $239 = Math_fround($240 * $216);
    $241 = Math_fround($242 * $218);
    $243 = Math_fround($244 * $220);
    $245 = Math_fround($246 * $222);
    $247 = Math_fround($248 * $224);
    $249 = Math_fround($250 * $226);
    $251 = Math_fround($235 + $243);
    $252 = Math_fround($237 + $245);
    $253 = Math_fround($239 + $247);
    $254 = Math_fround($241 + $249);
    $255 = Math_fround($256 * $228);
    $257 = Math_fround($258 * $230);
    $259 = Math_fround($260 * $232);
    $261 = Math_fround($262 * $234);
    $263 = Math_fround($251 + $255);
    $264 = Math_fround($252 + $257);
    $265 = Math_fround($253 + $259);
    $266 = Math_fround($254 + $261);
    $267 = Math_fround($180 * $188);
    $268 = Math_fround($182 * $190);
    $269 = Math_fround($184 * $192);
    $270 = Math_fround($186 * $194);
    $271 = Math_fround($267 - $196);
    $272 = Math_fround($268 - $198);
    $273 = Math_fround($269 - $200);
    $274 = Math_fround($270 - $202);
    $275 = Math_fround($276 + $263);
    $277 = Math_fround($278 + $264);
    $279 = Math_fround($280 + $265);
    $281 = Math_fround($282 + $266);
    $283 = Math_fround($180 * $275);
    $284 = Math_fround($182 * $277);
    $285 = Math_fround($184 * $279);
    $286 = Math_fround($186 * $281);
    $287 = Math_fround($271 - $283);
    $288 = Math_fround($272 - $284);
    $289 = Math_fround($273 - $285);
    $290 = Math_fround($274 - $286);
    $291 = Math_fround(-$172);
    $292 = Math_fround(-$174);
    $293 = Math_fround(-$176);
    $294 = Math_fround(-$178);
    $295 = $287 > $291;
    $$$i94 = $295 ? $287 : $291;
    $296 = $288 > $292;
    $297 = $296 ? $288 : $292;
    $298 = $289 > $293;
    $$1$i95 = $298 ? $289 : $293;
    $299 = $290 > $294;
    $300 = $299 ? $290 : $294;
    $301 = Math_fround($172 + $$$i94);
    $302 = Math_fround($174 + $297);
    $303 = Math_fround($176 + $$1$i95);
    $304 = Math_fround($178 + $300);
    $305 = $301 < $204;
    $$$i = $305 ? $301 : $204;
    $306 = $302 < $206;
    $307 = $306 ? $302 : $206;
    $308 = $303 < $208;
    $$1$i = $308 ? $303 : $208;
    $309 = $304 < $210;
    $310 = $309 ? $304 : $210;
    $311 = Math_fround($$$i - $172);
    $312 = Math_fround($307 - $174);
    $313 = Math_fround($$1$i - $176);
    $314 = Math_fround($310 - $178);
    $315 = Math_fround($67 * $311);
    $316 = Math_fround($69 * $312);
    $317 = Math_fround($71 * $313);
    $318 = Math_fround($73 * $314);
    $319 = Math_fround($276 + $315);
    $320 = Math_fround($278 + $316);
    $321 = Math_fround($280 + $317);
    $322 = Math_fround($282 + $318);
    $323 = Math_fround($324 + $311);
    $325 = Math_fround($326 + $312);
    $327 = Math_fround($328 + $313);
    $329 = Math_fround($330 + $314);
    $331 = Math_fround($148 * $311);
    $332 = Math_fround($150 * $312);
    $333 = Math_fround($152 * $313);
    $334 = Math_fround($154 * $314);
    $335 = Math_fround($236 + $331);
    $336 = Math_fround($238 + $332);
    $337 = Math_fround($240 + $333);
    $338 = Math_fround($242 + $334);
    $339 = Math_fround($156 * $311);
    $340 = Math_fround($158 * $312);
    $341 = Math_fround($160 * $313);
    $342 = Math_fround($162 * $314);
    $343 = Math_fround($244 + $339);
    $344 = Math_fround($246 + $340);
    $345 = Math_fround($248 + $341);
    $346 = Math_fround($250 + $342);
    $347 = Math_fround($164 * $311);
    $348 = Math_fround($166 * $312);
    $349 = Math_fround($168 * $313);
    $350 = Math_fround($170 * $314);
    $351 = Math_fround($256 + $347);
    $352 = Math_fround($258 + $348);
    $353 = Math_fround($260 + $349);
    $354 = Math_fround($262 + $350);
    HEAPF32[$171>>2] = $$$i;
    HEAPF32[$173>>2] = $307;
    HEAPF32[$175>>2] = $$1$i;
    HEAPF32[$177>>2] = $310;
    $355 = (($60) + ($i$0956<<4)|0);
    HEAPF32[$355>>2] = $$$i;
    $356 = ((($60) + ($i$0956<<4)|0) + 4|0);
    HEAPF32[$356>>2] = $307;
    $357 = ((($60) + ($i$0956<<4)|0) + 8|0);
    HEAPF32[$357>>2] = $$1$i;
    $358 = ((($60) + ($i$0956<<4)|0) + 12|0);
    HEAPF32[$358>>2] = $310;
    $exitcond = ($143|0)==($64|0);
    if ($exitcond) {
     $$lcssa = $338;$$lcssa941 = $337;$$lcssa942 = $336;$$lcssa943 = $335;$$lcssa944 = $346;$$lcssa945 = $345;$$lcssa946 = $344;$$lcssa947 = $343;$$lcssa948 = $354;$$lcssa949 = $353;$$lcssa950 = $352;$$lcssa951 = $351;$$lcssa952 = $329;$$lcssa953 = $327;$$lcssa954 = $325;$$lcssa955 = $323;
     break;
    } else {
     $236 = $335;$238 = $336;$240 = $337;$242 = $338;$244 = $343;$246 = $344;$248 = $345;$250 = $346;$256 = $351;$258 = $352;$260 = $353;$262 = $354;$276 = $319;$278 = $320;$280 = $321;$282 = $322;$324 = $323;$326 = $325;$328 = $327;$330 = $329;$i$0956 = $143;
    }
   }
  }
  $359 = Math_fround($98 * $$lcssa955);
  $360 = Math_fround($99 * $$lcssa954);
  $361 = Math_fround($100 * $$lcssa953);
  $362 = Math_fround($101 * $$lcssa952);
  $363 = Math_fround($126 + $359);
  $364 = Math_fround($124 + $360);
  $365 = Math_fround($122 + $361);
  $366 = Math_fround($120 + $362);
  $367 = Math_fround($102 * $$lcssa955);
  $368 = Math_fround($103 * $$lcssa954);
  $369 = Math_fround($104 * $$lcssa953);
  $370 = Math_fround($105 * $$lcssa952);
  $371 = Math_fround($118 + $367);
  $372 = Math_fround($116 + $368);
  $373 = Math_fround($114 + $369);
  $374 = Math_fround($112 + $370);
  $375 = Math_fround($106 * $$lcssa955);
  $376 = Math_fround($107 * $$lcssa954);
  $377 = Math_fround($108 * $$lcssa953);
  $378 = Math_fround($109 * $$lcssa952);
  $379 = Math_fround($134 + $375);
  $380 = Math_fround($132 + $376);
  $381 = Math_fround($130 + $377);
  $382 = Math_fround($128 + $378);
  $383 = ($65>>>0)<($56>>>0);
  if (!($383)) {
   $$lcssa972 = $366;$$lcssa973 = $365;$$lcssa974 = $364;$$lcssa975 = $363;$$lcssa976 = $374;$$lcssa977 = $373;$$lcssa978 = $372;$$lcssa979 = $371;$$lcssa980 = $382;$$lcssa981 = $381;$$lcssa982 = $380;$$lcssa983 = $379;$$lcssa984 = $$lcssa;$$lcssa985 = $$lcssa941;$$lcssa986 = $$lcssa942;$$lcssa987 = $$lcssa943;$$lcssa988 = $$lcssa944;$$lcssa989 = $$lcssa945;$$lcssa990 = $$lcssa946;$$lcssa991 = $$lcssa947;$$lcssa992 = $$lcssa948;$$lcssa993 = $$lcssa949;$$lcssa994 = $$lcssa950;$$lcssa995 = $$lcssa951;
   break;
  }
  $$phi$trans$insert = (($65) + 2|0);
  $$pre = HEAP16[$$phi$trans$insert>>1]|0;
  $112 = $374;$114 = $373;$116 = $372;$118 = $371;$120 = $366;$122 = $365;$124 = $364;$126 = $363;$128 = $382;$130 = $381;$132 = $380;$134 = $379;$400 = $$lcssa951;$401 = $$lcssa950;$402 = $$lcssa949;$403 = $$lcssa948;$404 = $$lcssa947;$405 = $$lcssa946;$406 = $$lcssa945;$407 = $$lcssa944;$408 = $$lcssa943;$409 = $$lcssa942;$410 = $$lcssa941;$411 = $$lcssa;$59 = $$pre;$currPtr$0996 = $65;
 }
 HEAPF32[$0>>2] = $$lcssa975;
 $384 = (($0) + 4|0);
 HEAPF32[$384>>2] = $$lcssa979;
 $385 = (($0) + 8|0);
 HEAPF32[$385>>2] = $$lcssa983;
 HEAPF32[$2>>2] = $$lcssa974;
 $386 = (($2) + 4|0);
 HEAPF32[$386>>2] = $$lcssa978;
 $387 = (($2) + 8|0);
 HEAPF32[$387>>2] = $$lcssa982;
 HEAPF32[$4>>2] = $$lcssa973;
 $388 = (($4) + 4|0);
 HEAPF32[$388>>2] = $$lcssa977;
 $389 = (($4) + 8|0);
 HEAPF32[$389>>2] = $$lcssa981;
 HEAPF32[$6>>2] = $$lcssa972;
 $390 = (($6) + 4|0);
 HEAPF32[$390>>2] = $$lcssa976;
 $391 = (($6) + 8|0);
 HEAPF32[$391>>2] = $$lcssa980;
 HEAPF32[$12>>2] = $$lcssa987;
 $392 = (($0) + 20|0);
 HEAPF32[$392>>2] = $$lcssa991;
 $393 = (($0) + 24|0);
 HEAPF32[$393>>2] = $$lcssa995;
 HEAPF32[$23>>2] = $$lcssa986;
 $394 = (($2) + 20|0);
 HEAPF32[$394>>2] = $$lcssa990;
 $395 = (($2) + 24|0);
 HEAPF32[$395>>2] = $$lcssa994;
 HEAPF32[$34>>2] = $$lcssa985;
 $396 = (($4) + 20|0);
 HEAPF32[$396>>2] = $$lcssa989;
 $397 = (($4) + 24|0);
 HEAPF32[$397>>2] = $$lcssa993;
 HEAPF32[$45>>2] = $$lcssa984;
 $398 = (($6) + 20|0);
 HEAPF32[$398>>2] = $$lcssa988;
 $399 = (($6) + 24|0);
 HEAPF32[$399>>2] = $$lcssa992;
 STACKTOP = sp;return;
}
function __ZN5physx36solveContactCoulombPreBlock_ConcludeEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$1$i$i = Math_fround(0), $$sum$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cPtr$019$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$118$i = 0;
 var $desc$idx = 0, $desc$idx$val = 0, $exitcond$i = 0, $i$017$i = 0, $scevgep21$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL26solveContactCoulomb4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 $desc$idx = (($desc) + 16|0);
 $desc$idx$val = HEAP32[$desc$idx>>2]|0;
 $1 = (($desc$idx$val) + 2|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = (($desc$idx$val) + ($3)|0);
 $5 = HEAP8[$desc$idx$val>>0]|0;
 $6 = ($5<<24>>24)==(7);
 $7 = $6 ? 272 : 176;
 $8 = ($2<<16>>16)==(0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $cPtr$019$i = $desc$idx$val;
 }
 while(1) {
  $12 = (($cPtr$019$i) + 112|0);
  $13 = (($cPtr$019$i) + 1|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = (($cPtr$019$i) + 240|0);
  $16 = (($cPtr$019$i) + 368|0);
  $17 = (($cPtr$019$i) + 496|0);
  $18 = ($14<<24>>24)==(0);
  if ($18) {
   $cPtr$1$lcssa$i = $12;
  } else {
   $10 = $14&255;
   $cPtr$118$i = $12;$i$017$i = 0;
   while(1) {
    $19 = (($cPtr$118$i) + ($7)|0);
    $20 = (($cPtr$118$i) + 144|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = (($cPtr$118$i) + 148|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = (($cPtr$118$i) + 152|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = (($cPtr$118$i) + 156|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = $21 > Math_fround(0.0);
    $$$i$i = $28 ? $21 : Math_fround(0.0);
    $29 = $23 > Math_fround(0.0);
    $30 = $29 ? $23 : Math_fround(0.0);
    $31 = $25 > Math_fround(0.0);
    $$1$i$i = $31 ? $25 : Math_fround(0.0);
    $32 = $27 > Math_fround(0.0);
    $33 = $32 ? $27 : Math_fround(0.0);
    HEAPF32[$20>>2] = $$$i$i;
    HEAPF32[$22>>2] = $30;
    HEAPF32[$24>>2] = $$1$i$i;
    HEAPF32[$26>>2] = $33;
    $34 = (($i$017$i) + 1)|0;
    $exitcond$i = ($34|0)==($10|0);
    if ($exitcond$i) {
     break;
    } else {
     $cPtr$118$i = $19;$i$017$i = $34;
    }
   }
   $9 = Math_imul($10, $7)|0;
   $$sum$i = (($9) + 112)|0;
   $scevgep21$i = (($cPtr$019$i) + ($$sum$i)|0);
   $cPtr$1$lcssa$i = $scevgep21$i;
  }
  $11 = ($cPtr$1$lcssa$i>>>0)<($4>>>0);
  if ($11) {
   $cPtr$019$i = $cPtr$1$lcssa$i;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx42solveContactCoulombPreBlock_ConcludeStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$1$i$i = Math_fround(0), $$sum$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cPtr$019$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$118$i = 0;
 var $desc$idx = 0, $desc$idx$val = 0, $exitcond$i = 0, $i$017$i = 0, $scevgep21$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL32solveContactCoulomb4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 $desc$idx = (($desc) + 16|0);
 $desc$idx$val = HEAP32[$desc$idx>>2]|0;
 $1 = (($desc$idx$val) + 2|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = (($desc$idx$val) + ($3)|0);
 $5 = HEAP8[$desc$idx$val>>0]|0;
 $6 = ($5<<24>>24)==(7);
 $7 = $6 ? 272 : 176;
 $8 = ($2<<16>>16)==(0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $cPtr$019$i = $desc$idx$val;
 }
 while(1) {
  $12 = (($cPtr$019$i) + 112|0);
  $13 = (($cPtr$019$i) + 1|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = (($cPtr$019$i) + 240|0);
  $16 = (($cPtr$019$i) + 368|0);
  $17 = (($cPtr$019$i) + 496|0);
  $18 = ($14<<24>>24)==(0);
  if ($18) {
   $cPtr$1$lcssa$i = $12;
  } else {
   $10 = $14&255;
   $cPtr$118$i = $12;$i$017$i = 0;
   while(1) {
    $19 = (($cPtr$118$i) + ($7)|0);
    $20 = (($cPtr$118$i) + 144|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = (($cPtr$118$i) + 148|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = (($cPtr$118$i) + 152|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = (($cPtr$118$i) + 156|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = $21 > Math_fround(0.0);
    $$$i$i = $28 ? $21 : Math_fround(0.0);
    $29 = $23 > Math_fround(0.0);
    $30 = $29 ? $23 : Math_fround(0.0);
    $31 = $25 > Math_fround(0.0);
    $$1$i$i = $31 ? $25 : Math_fround(0.0);
    $32 = $27 > Math_fround(0.0);
    $33 = $32 ? $27 : Math_fround(0.0);
    HEAPF32[$20>>2] = $$$i$i;
    HEAPF32[$22>>2] = $30;
    HEAPF32[$24>>2] = $$1$i$i;
    HEAPF32[$26>>2] = $33;
    $34 = (($i$017$i) + 1)|0;
    $exitcond$i = ($34|0)==($10|0);
    if ($exitcond$i) {
     break;
    } else {
     $cPtr$118$i = $19;$i$017$i = $34;
    }
   }
   $9 = Math_imul($10, $7)|0;
   $$sum$i = (($9) + 112)|0;
   $scevgep21$i = (($cPtr$019$i) + ($$sum$i)|0);
   $cPtr$1$lcssa$i = $scevgep21$i;
  }
  $11 = ($cPtr$1$lcssa$i>>>0)<($4>>>0);
  if ($11) {
   $cPtr$019$i = $cPtr$1$lcssa$i;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx37solveContactCoulombPreBlock_WriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$0,$cache,$thresholdStream,$1,$outThresholdPairs) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $1 = $1|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $bd0 = 0;
 var $bd1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bd0 = sp + 16|0;
 $bd1 = sp;
 __ZN5physxL26solveContactCoulomb4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 $2 = (($desc) + 10|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($cache) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<6)|0);
 HEAP32[$bd0>>2] = $7;
 $8 = (($bd0) + 4|0);
 $9 = (($desc) + 42|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 $12 = (($6) + ($11<<6)|0);
 HEAP32[$8>>2] = $12;
 $13 = (($bd0) + 8|0);
 $14 = (($desc) + 74|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = (($6) + ($16<<6)|0);
 HEAP32[$13>>2] = $17;
 $18 = (($bd0) + 12|0);
 $19 = (($desc) + 106|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = $20&65535;
 $22 = (($6) + ($21<<6)|0);
 HEAP32[$18>>2] = $22;
 $23 = (($desc) + 14|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = $24&65535;
 $26 = (($6) + ($25<<6)|0);
 HEAP32[$bd1>>2] = $26;
 $27 = (($bd1) + 4|0);
 $28 = (($desc) + 46|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = $29&65535;
 $31 = (($6) + ($30<<6)|0);
 HEAP32[$27>>2] = $31;
 $32 = (($bd1) + 8|0);
 $33 = (($desc) + 78|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = $34&65535;
 $36 = (($6) + ($35<<6)|0);
 HEAP32[$32>>2] = $36;
 $37 = (($bd1) + 12|0);
 $38 = (($desc) + 110|0);
 $39 = HEAP16[$38>>1]|0;
 $40 = $39&65535;
 $41 = (($6) + ($40<<6)|0);
 HEAP32[$37>>2] = $41;
 __ZN5physx24writeBackContactCoulomb4EPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEPPKNS_17PxcSolverBodyDataES8_($desc,$cache,$bd0,$bd1);
 $42 = (($cache) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($cache) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + -4)|0;
 $47 = ($43>>>0)>($46>>>0);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$43)|0);
 $49 = HEAP32[$42>>2]|0;
 $50 = (($48) - ($49))|0;
 $51 = ($49|0)==(0);
 if (!($51)) {
  $52 = (($cache) + 4|0);
  $a$01 = 0;
  while(1) {
   $53 = (($50) + ($a$01))|0;
   $54 = (($thresholdStream) + ($53<<4)|0);
   $55 = HEAP32[$52>>2]|0;
   $56 = (($55) + ($a$01<<4)|0);
   ;HEAP32[$54+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$56+12>>2]|0;
   $57 = (($a$01) + 1)|0;
   $58 = HEAP32[$42>>2]|0;
   $59 = ($57>>>0)<($58>>>0);
   if ($59) {
    $a$01 = $57;
   } else {
    break;
   }
  }
 }
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx43solveContactCoulombPreBlock_WriteBackStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$0,$cache,$thresholdStream,$1,$outThresholdPairs) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $1 = $1|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $bd0 = 0;
 var $bd1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bd0 = sp + 16|0;
 $bd1 = sp;
 __ZN5physxL32solveContactCoulomb4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 $2 = (($desc) + 10|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($cache) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<6)|0);
 HEAP32[$bd0>>2] = $7;
 $8 = (($bd0) + 4|0);
 $9 = (($desc) + 42|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 $12 = (($6) + ($11<<6)|0);
 HEAP32[$8>>2] = $12;
 $13 = (($bd0) + 8|0);
 $14 = (($desc) + 74|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = (($6) + ($16<<6)|0);
 HEAP32[$13>>2] = $17;
 $18 = (($bd0) + 12|0);
 $19 = (($desc) + 106|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = $20&65535;
 $22 = (($6) + ($21<<6)|0);
 HEAP32[$18>>2] = $22;
 $23 = (($desc) + 14|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = $24&65535;
 $26 = (($6) + ($25<<6)|0);
 HEAP32[$bd1>>2] = $26;
 $27 = (($bd1) + 4|0);
 $28 = (($desc) + 46|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = $29&65535;
 $31 = (($6) + ($30<<6)|0);
 HEAP32[$27>>2] = $31;
 $32 = (($bd1) + 8|0);
 $33 = (($desc) + 78|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = $34&65535;
 $36 = (($6) + ($35<<6)|0);
 HEAP32[$32>>2] = $36;
 $37 = (($bd1) + 12|0);
 $38 = (($desc) + 110|0);
 $39 = HEAP16[$38>>1]|0;
 $40 = $39&65535;
 $41 = (($6) + ($40<<6)|0);
 HEAP32[$37>>2] = $41;
 __ZN5physx24writeBackContactCoulomb4EPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextEPPKNS_17PxcSolverBodyDataES8_($desc,$cache,$bd0,$bd1);
 $42 = (($cache) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($cache) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + -4)|0;
 $47 = ($43>>>0)>($46>>>0);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$43)|0);
 $49 = HEAP32[$42>>2]|0;
 $50 = (($48) - ($49))|0;
 $51 = ($49|0)==(0);
 if (!($51)) {
  $52 = (($cache) + 4|0);
  $a$01 = 0;
  while(1) {
   $53 = (($50) + ($a$01))|0;
   $54 = (($thresholdStream) + ($53<<4)|0);
   $55 = HEAP32[$52>>2]|0;
   $56 = (($55) + ($a$01<<4)|0);
   ;HEAP32[$54+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$56+12>>2]|0;
   $57 = (($a$01) + 1)|0;
   $58 = HEAP32[$42>>2]|0;
   $59 = ($57>>>0)<($58>>>0);
   if ($59) {
    $a$01 = $57;
   } else {
    break;
   }
  }
 }
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx28solveFrictionCoulombPreBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL20solveFriction4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physxL20solveFriction4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc) {
 $desc = $desc|0;
 var $$$i$i = Math_fround(0), $$$i8$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i9$i = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa1614 = Math_fround(0), $$lcssa1615 = Math_fround(0), $$lcssa1616 = Math_fround(0), $$lcssa1617 = Math_fround(0), $$lcssa1618 = Math_fround(0), $$lcssa1619 = Math_fround(0), $$lcssa1620 = Math_fround(0), $$lcssa1621 = Math_fround(0), $$lcssa1622 = Math_fround(0), $$lcssa1623 = Math_fround(0), $$lcssa1624 = Math_fround(0), $$lcssa1625 = Math_fround(0), $$lcssa1626 = Math_fround(0), $$lcssa1627 = Math_fround(0), $$lcssa1628 = Math_fround(0);
 var $$lcssa1629 = Math_fround(0), $$lcssa1630 = Math_fround(0), $$lcssa1631 = Math_fround(0), $$lcssa1632 = Math_fround(0), $$lcssa1633 = Math_fround(0), $$lcssa1634 = Math_fround(0), $$lcssa1635 = Math_fround(0), $$lcssa1636 = Math_fround(0), $$lcssa1637 = Math_fround(0), $$lcssa1638 = Math_fround(0), $$lcssa1639 = Math_fround(0), $$lcssa1640 = Math_fround(0), $$lcssa1641 = Math_fround(0), $$lcssa1642 = Math_fround(0), $$lcssa1643 = Math_fround(0), $$lcssa1644 = Math_fround(0), $$lcssa1645 = Math_fround(0), $$lcssa1646 = Math_fround(0), $$lcssa1647 = Math_fround(0), $$lcssa1648 = Math_fround(0);
 var $$lcssa1649 = Math_fround(0), $$lcssa1650 = Math_fround(0), $$lcssa1651 = Math_fround(0), $$lcssa1652 = Math_fround(0), $$lcssa1653 = Math_fround(0), $$lcssa1654 = Math_fround(0), $$lcssa1655 = Math_fround(0), $$lcssa1656 = Math_fround(0), $$lcssa1657 = Math_fround(0), $$lcssa1658 = Math_fround(0), $$lcssa1659 = Math_fround(0), $$lcssa1660 = Math_fround(0), $$lcssa1709 = Math_fround(0), $$lcssa1710 = Math_fround(0), $$lcssa1711 = Math_fround(0), $$lcssa1712 = Math_fround(0), $$lcssa1713 = Math_fround(0), $$lcssa1714 = Math_fround(0), $$lcssa1715 = Math_fround(0), $$lcssa1716 = Math_fround(0);
 var $$lcssa1717 = Math_fround(0), $$lcssa1718 = Math_fround(0), $$lcssa1719 = Math_fround(0), $$lcssa1720 = Math_fround(0), $$lcssa1721 = Math_fround(0), $$lcssa1722 = Math_fround(0), $$lcssa1723 = Math_fround(0), $$lcssa1724 = Math_fround(0), $$lcssa1725 = Math_fround(0), $$lcssa1726 = Math_fround(0), $$lcssa1727 = Math_fround(0), $$lcssa1728 = Math_fround(0), $$lcssa1729 = Math_fround(0), $$lcssa1730 = Math_fround(0), $$lcssa1731 = Math_fround(0), $$lcssa1732 = Math_fround(0), $$lcssa1733 = Math_fround(0), $$lcssa1734 = Math_fround(0), $$lcssa1735 = Math_fround(0), $$lcssa1736 = Math_fround(0);
 var $$lcssa1737 = Math_fround(0), $$lcssa1738 = Math_fround(0), $$lcssa1739 = Math_fround(0), $$lcssa1740 = Math_fround(0), $$lcssa1741 = Math_fround(0), $$lcssa1742 = Math_fround(0), $$lcssa1743 = Math_fround(0), $$lcssa1744 = Math_fround(0), $$lcssa1745 = Math_fround(0), $$lcssa1746 = Math_fround(0), $$lcssa1747 = Math_fround(0), $$lcssa1748 = Math_fround(0), $$lcssa1749 = Math_fround(0), $$lcssa1750 = Math_fround(0), $$lcssa1751 = Math_fround(0), $$lcssa1752 = Math_fround(0), $$lcssa1753 = Math_fround(0), $$lcssa1754 = Math_fround(0), $$lcssa1755 = Math_fround(0), $$lcssa1756 = Math_fround(0);
 var $$sum = 0, $$sum1 = 0, $$sum1610 = 0, $$sum1611 = 0, $$sum1612 = 0, $$sum1613 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0);
 var $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0);
 var $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0);
 var $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0);
 var $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0);
 var $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0);
 var $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0);
 var $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0);
 var $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0);
 var $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0);
 var $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0);
 var $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0);
 var $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0);
 var $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0);
 var $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0);
 var $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0);
 var $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0);
 var $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0);
 var $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0);
 var $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = 0, $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = Math_fround(0), $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = 0;
 var $507 = 0, $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0);
 var $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0);
 var $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0);
 var $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0);
 var $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0);
 var $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = 0, $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0;
 var $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0);
 var $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0);
 var $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0);
 var $688 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $currPtr$01757 = 0, $exitcond = 0, $i$01661 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($desc) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($desc) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($desc) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($desc) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($desc) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($desc) + 100|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = Math_fround(HEAPF32[$0>>2]);
 $16 = (($0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$2>>2]);
 $21 = (($2) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($2) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($0) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($25) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($25) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($2) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($31) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($31) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$4>>2]);
 $38 = (($4) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($4) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround(HEAPF32[$6>>2]);
 $43 = (($6) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($6) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($4) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($47) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($47) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($6) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($53) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($53) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround(HEAPF32[$8>>2]);
 $60 = (($8) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($8) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(HEAPF32[$10>>2]);
 $65 = (($10) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($10) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($8) + 16|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($69) + 4|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($69) + 8|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($10) + 16|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($75) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($75) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround(HEAPF32[$12>>2]);
 $82 = (($12) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($12) + 8|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround(HEAPF32[$14>>2]);
 $87 = (($14) + 4|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($14) + 8|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($12) + 16|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($91) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($91) + 8|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($14) + 16|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($97) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($97) + 8|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($desc) + 16|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($desc) + 26|0);
 $106 = HEAP16[$105>>1]|0;
 $107 = $106&65535;
 $108 = $107 << 4;
 $109 = (($104) + ($108)|0);
 $110 = ($106<<16>>16)==(0);
 if ($110) {
  $$lcssa1709 = $81;$$lcssa1710 = $59;$$lcssa1711 = $37;$$lcssa1712 = $15;$$lcssa1713 = $83;$$lcssa1714 = $61;$$lcssa1715 = $39;$$lcssa1716 = $17;$$lcssa1717 = $85;$$lcssa1718 = $63;$$lcssa1719 = $41;$$lcssa1720 = $19;$$lcssa1721 = $86;$$lcssa1722 = $64;$$lcssa1723 = $42;$$lcssa1724 = $20;$$lcssa1725 = $88;$$lcssa1726 = $66;$$lcssa1727 = $44;$$lcssa1728 = $22;$$lcssa1729 = $90;$$lcssa1730 = $68;$$lcssa1731 = $46;$$lcssa1732 = $24;$$lcssa1733 = $92;$$lcssa1734 = $70;$$lcssa1735 = $48;$$lcssa1736 = $26;$$lcssa1737 = $94;$$lcssa1738 = $72;$$lcssa1739 = $50;$$lcssa1740 = $28;$$lcssa1741 = $96;$$lcssa1742 = $74;$$lcssa1743 = $52;$$lcssa1744 = $30;$$lcssa1745 = $98;$$lcssa1746 = $76;$$lcssa1747 = $54;$$lcssa1748 = $32;$$lcssa1749 = $100;$$lcssa1750 = $78;$$lcssa1751 = $56;$$lcssa1752 = $34;$$lcssa1753 = $102;$$lcssa1754 = $80;$$lcssa1755 = $58;$$lcssa1756 = $36;
  HEAPF32[$0>>2] = $$lcssa1712;
  $609 = (($0) + 4|0);
  HEAPF32[$609>>2] = $$lcssa1716;
  $610 = (($0) + 8|0);
  HEAPF32[$610>>2] = $$lcssa1720;
  HEAPF32[$4>>2] = $$lcssa1711;
  $611 = (($4) + 4|0);
  HEAPF32[$611>>2] = $$lcssa1715;
  $612 = (($4) + 8|0);
  HEAPF32[$612>>2] = $$lcssa1719;
  HEAPF32[$8>>2] = $$lcssa1710;
  $613 = (($8) + 4|0);
  HEAPF32[$613>>2] = $$lcssa1714;
  $614 = (($8) + 8|0);
  HEAPF32[$614>>2] = $$lcssa1718;
  HEAPF32[$12>>2] = $$lcssa1709;
  $615 = (($12) + 4|0);
  HEAPF32[$615>>2] = $$lcssa1713;
  $616 = (($12) + 8|0);
  HEAPF32[$616>>2] = $$lcssa1717;
  HEAPF32[$2>>2] = $$lcssa1724;
  $617 = (($2) + 4|0);
  HEAPF32[$617>>2] = $$lcssa1728;
  $618 = (($2) + 8|0);
  HEAPF32[$618>>2] = $$lcssa1732;
  HEAPF32[$6>>2] = $$lcssa1723;
  $619 = (($6) + 4|0);
  HEAPF32[$619>>2] = $$lcssa1727;
  $620 = (($6) + 8|0);
  HEAPF32[$620>>2] = $$lcssa1731;
  HEAPF32[$10>>2] = $$lcssa1722;
  $621 = (($10) + 4|0);
  HEAPF32[$621>>2] = $$lcssa1726;
  $622 = (($10) + 8|0);
  HEAPF32[$622>>2] = $$lcssa1730;
  HEAPF32[$14>>2] = $$lcssa1721;
  $623 = (($14) + 4|0);
  HEAPF32[$623>>2] = $$lcssa1725;
  $624 = (($14) + 8|0);
  HEAPF32[$624>>2] = $$lcssa1729;
  HEAPF32[$25>>2] = $$lcssa1736;
  $625 = (($0) + 20|0);
  HEAPF32[$625>>2] = $$lcssa1740;
  $626 = (($0) + 24|0);
  HEAPF32[$626>>2] = $$lcssa1744;
  HEAPF32[$47>>2] = $$lcssa1735;
  $627 = (($4) + 20|0);
  HEAPF32[$627>>2] = $$lcssa1739;
  $628 = (($4) + 24|0);
  HEAPF32[$628>>2] = $$lcssa1743;
  HEAPF32[$69>>2] = $$lcssa1734;
  $629 = (($8) + 20|0);
  HEAPF32[$629>>2] = $$lcssa1738;
  $630 = (($8) + 24|0);
  HEAPF32[$630>>2] = $$lcssa1742;
  HEAPF32[$91>>2] = $$lcssa1733;
  $631 = (($12) + 20|0);
  HEAPF32[$631>>2] = $$lcssa1737;
  $632 = (($12) + 24|0);
  HEAPF32[$632>>2] = $$lcssa1741;
  HEAPF32[$31>>2] = $$lcssa1748;
  $633 = (($2) + 20|0);
  HEAPF32[$633>>2] = $$lcssa1752;
  $634 = (($2) + 24|0);
  HEAPF32[$634>>2] = $$lcssa1756;
  HEAPF32[$53>>2] = $$lcssa1747;
  $635 = (($6) + 20|0);
  HEAPF32[$635>>2] = $$lcssa1751;
  $636 = (($6) + 24|0);
  HEAPF32[$636>>2] = $$lcssa1755;
  HEAPF32[$75>>2] = $$lcssa1746;
  $637 = (($10) + 20|0);
  HEAPF32[$637>>2] = $$lcssa1750;
  $638 = (($10) + 24|0);
  HEAPF32[$638>>2] = $$lcssa1754;
  HEAPF32[$97>>2] = $$lcssa1745;
  $639 = (($14) + 20|0);
  HEAPF32[$639>>2] = $$lcssa1749;
  $640 = (($14) + 24|0);
  HEAPF32[$640>>2] = $$lcssa1753;
  STACKTOP = sp;return;
 } else {
  $641 = $36;$642 = $58;$643 = $80;$644 = $102;$645 = $34;$646 = $56;$647 = $78;$648 = $100;$649 = $32;$650 = $54;$651 = $76;$652 = $98;$653 = $30;$654 = $52;$655 = $74;$656 = $96;$657 = $28;$658 = $50;$659 = $72;$660 = $94;$661 = $26;$662 = $48;$663 = $70;$664 = $92;$665 = $24;$666 = $46;$667 = $68;$668 = $90;$669 = $22;$670 = $44;$671 = $66;$672 = $88;$673 = $20;$674 = $42;$675 = $64;$676 = $86;$677 = $19;$678 = $41;$679 = $63;$680 = $85;$681 = $17;$682 = $39;$683 = $61;$684 = $83;$685 = $15;$686 = $37;$687 = $59;$688 = $81;$currPtr$01757 = $104;
 }
 while(1) {
  $113 = (($currPtr$01757) + 64|0);
  $114 = (($currPtr$01757) + 1|0);
  $115 = HEAP8[$114>>0]|0;
  $116 = $115&255;
  $117 = $116 << 4;
  $$sum = (($117) + 64)|0;
  $118 = (($currPtr$01757) + ($$sum)|0);
  $$sum1610 = (($117) + 192)|0;
  $119 = (($currPtr$01757) + ($$sum1610)|0);
  $$sum1611 = (($117) + 320)|0;
  $120 = (($currPtr$01757) + ($$sum1611)|0);
  $$sum1612 = (($117) + 448)|0;
  $121 = (($currPtr$01757) + ($$sum1612)|0);
  $122 = (($currPtr$01757) + 2|0);
  $123 = HEAP8[$122>>0]|0;
  $124 = $123&255;
  $112 = (($118) + (($124*288)|0)|0);
  $125 = (($currPtr$01757) + 16|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = (($currPtr$01757) + 20|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = (($currPtr$01757) + 24|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = (($currPtr$01757) + 28|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($currPtr$01757) + 32|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($currPtr$01757) + 36|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = (($currPtr$01757) + 40|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = (($currPtr$01757) + 44|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = (($currPtr$01757) + 48|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($currPtr$01757) + 52|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = (($currPtr$01757) + 56|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($currPtr$01757) + 60|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = ($123<<24>>24)==(0);
  if ($149) {
   $$lcssa = $688;$$lcssa1614 = $687;$$lcssa1615 = $686;$$lcssa1616 = $685;$$lcssa1617 = $684;$$lcssa1618 = $683;$$lcssa1619 = $682;$$lcssa1620 = $681;$$lcssa1621 = $680;$$lcssa1622 = $679;$$lcssa1623 = $678;$$lcssa1624 = $677;$$lcssa1625 = $676;$$lcssa1626 = $675;$$lcssa1627 = $674;$$lcssa1628 = $673;$$lcssa1629 = $672;$$lcssa1630 = $671;$$lcssa1631 = $670;$$lcssa1632 = $669;$$lcssa1633 = $668;$$lcssa1634 = $667;$$lcssa1635 = $666;$$lcssa1636 = $665;$$lcssa1637 = $664;$$lcssa1638 = $663;$$lcssa1639 = $662;$$lcssa1640 = $661;$$lcssa1641 = $660;$$lcssa1642 = $659;$$lcssa1643 = $658;$$lcssa1644 = $657;$$lcssa1645 = $656;$$lcssa1646 = $655;$$lcssa1647 = $654;$$lcssa1648 = $653;$$lcssa1649 = $652;$$lcssa1650 = $651;$$lcssa1651 = $650;$$lcssa1652 = $649;$$lcssa1653 = $648;$$lcssa1654 = $647;$$lcssa1655 = $646;$$lcssa1656 = $645;$$lcssa1657 = $644;$$lcssa1658 = $643;$$lcssa1659 = $642;$$lcssa1660 = $641;
  } else {
   $150 = (($currPtr$01757) + 12|0);
   $318 = $685;$320 = $686;$322 = $687;$324 = $688;$326 = $661;$328 = $662;$330 = $663;$332 = $664;$334 = $673;$336 = $674;$338 = $675;$340 = $676;$342 = $649;$344 = $650;$346 = $651;$348 = $652;$350 = $681;$352 = $682;$354 = $683;$356 = $684;$362 = $657;$364 = $658;$366 = $659;$368 = $660;$374 = $669;$376 = $670;$378 = $671;$380 = $672;$386 = $645;$388 = $646;$390 = $647;$392 = $648;$398 = $677;$400 = $678;$402 = $679;$404 = $680;$410 = $653;$412 = $654;$414 = $655;$416 = $656;$422 = $665;$424 = $666;$426 = $667;$428 = $668;$434 = $641;$436 = $642;$438 = $643;$440 = $644;$i$01661 = 0;
   while(1) {
    $$sum1 = (($i$01661) + 1)|0;
    $151 = (($118) + (($$sum1*288)|0)|0);
    $152 = ((($118) + (($$sum1*288)|0)|0) + 128|0);
    $153 = ((($118) + (($$sum1*288)|0)|0) + 256|0);
    $$sum1613 = (($i$01661) + 2)|0;
    $154 = ((($118) + (($$sum1613*288)|0)|0) + 96|0);
    $155 = HEAP32[$150>>2]|0;
    $156 = $i$01661 >>> $155;
    $157 = (($113) + ($156<<4)|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = ((($113) + ($156<<4)|0) + 4|0);
    $160 = Math_fround(HEAPF32[$159>>2]);
    $161 = ((($113) + ($156<<4)|0) + 8|0);
    $162 = Math_fround(HEAPF32[$161>>2]);
    $163 = ((($113) + ($156<<4)|0) + 12|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = Math_fround($126 * $158);
    $166 = Math_fround($128 * $160);
    $167 = Math_fround($130 * $162);
    $168 = Math_fround($132 * $164);
    $169 = Math_fround(-$165);
    $170 = Math_fround(-$166);
    $171 = Math_fround(-$167);
    $172 = Math_fround(-$168);
    $173 = ((($118) + (($i$01661*288)|0)|0) + 96|0);
    $174 = Math_fround(HEAPF32[$173>>2]);
    $175 = ((($118) + (($i$01661*288)|0)|0) + 100|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = ((($118) + (($i$01661*288)|0)|0) + 104|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = ((($118) + (($i$01661*288)|0)|0) + 108|0);
    $180 = Math_fround(HEAPF32[$179>>2]);
    $181 = ((($118) + (($i$01661*288)|0)|0) + 112|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = ((($118) + (($i$01661*288)|0)|0) + 116|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    $185 = ((($118) + (($i$01661*288)|0)|0) + 120|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = ((($118) + (($i$01661*288)|0)|0) + 124|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = ((($118) + (($i$01661*288)|0)|0) + 128|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = ((($118) + (($i$01661*288)|0)|0) + 132|0);
    $192 = Math_fround(HEAPF32[$191>>2]);
    $193 = ((($118) + (($i$01661*288)|0)|0) + 136|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = ((($118) + (($i$01661*288)|0)|0) + 140|0);
    $196 = Math_fround(HEAPF32[$195>>2]);
    $197 = ((($118) + (($i$01661*288)|0)|0) + 240|0);
    $198 = Math_fround(HEAPF32[$197>>2]);
    $199 = ((($118) + (($i$01661*288)|0)|0) + 244|0);
    $200 = Math_fround(HEAPF32[$199>>2]);
    $201 = ((($118) + (($i$01661*288)|0)|0) + 248|0);
    $202 = Math_fround(HEAPF32[$201>>2]);
    $203 = ((($118) + (($i$01661*288)|0)|0) + 252|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = ((($118) + (($i$01661*288)|0)|0) + 256|0);
    $206 = Math_fround(HEAPF32[$205>>2]);
    $207 = ((($118) + (($i$01661*288)|0)|0) + 260|0);
    $208 = Math_fround(HEAPF32[$207>>2]);
    $209 = ((($118) + (($i$01661*288)|0)|0) + 264|0);
    $210 = Math_fround(HEAPF32[$209>>2]);
    $211 = ((($118) + (($i$01661*288)|0)|0) + 268|0);
    $212 = Math_fround(HEAPF32[$211>>2]);
    $213 = ((($118) + (($i$01661*288)|0)|0) + 272|0);
    $214 = Math_fround(HEAPF32[$213>>2]);
    $215 = ((($118) + (($i$01661*288)|0)|0) + 276|0);
    $216 = Math_fround(HEAPF32[$215>>2]);
    $217 = ((($118) + (($i$01661*288)|0)|0) + 280|0);
    $218 = Math_fround(HEAPF32[$217>>2]);
    $219 = ((($118) + (($i$01661*288)|0)|0) + 284|0);
    $220 = Math_fround(HEAPF32[$219>>2]);
    $221 = (($118) + (($i$01661*288)|0)|0);
    $222 = Math_fround(HEAPF32[$221>>2]);
    $223 = ((($118) + (($i$01661*288)|0)|0) + 4|0);
    $224 = Math_fround(HEAPF32[$223>>2]);
    $225 = ((($118) + (($i$01661*288)|0)|0) + 8|0);
    $226 = Math_fround(HEAPF32[$225>>2]);
    $227 = ((($118) + (($i$01661*288)|0)|0) + 12|0);
    $228 = Math_fround(HEAPF32[$227>>2]);
    $229 = ((($118) + (($i$01661*288)|0)|0) + 16|0);
    $230 = Math_fround(HEAPF32[$229>>2]);
    $231 = ((($118) + (($i$01661*288)|0)|0) + 20|0);
    $232 = Math_fround(HEAPF32[$231>>2]);
    $233 = ((($118) + (($i$01661*288)|0)|0) + 24|0);
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = ((($118) + (($i$01661*288)|0)|0) + 28|0);
    $236 = Math_fround(HEAPF32[$235>>2]);
    $237 = ((($118) + (($i$01661*288)|0)|0) + 32|0);
    $238 = Math_fround(HEAPF32[$237>>2]);
    $239 = ((($118) + (($i$01661*288)|0)|0) + 36|0);
    $240 = Math_fround(HEAPF32[$239>>2]);
    $241 = ((($118) + (($i$01661*288)|0)|0) + 40|0);
    $242 = Math_fround(HEAPF32[$241>>2]);
    $243 = ((($118) + (($i$01661*288)|0)|0) + 44|0);
    $244 = Math_fround(HEAPF32[$243>>2]);
    $245 = ((($118) + (($i$01661*288)|0)|0) + 48|0);
    $246 = Math_fround(HEAPF32[$245>>2]);
    $247 = ((($118) + (($i$01661*288)|0)|0) + 52|0);
    $248 = Math_fround(HEAPF32[$247>>2]);
    $249 = ((($118) + (($i$01661*288)|0)|0) + 56|0);
    $250 = Math_fround(HEAPF32[$249>>2]);
    $251 = ((($118) + (($i$01661*288)|0)|0) + 60|0);
    $252 = Math_fround(HEAPF32[$251>>2]);
    $253 = ((($118) + (($i$01661*288)|0)|0) + 64|0);
    $254 = Math_fround(HEAPF32[$253>>2]);
    $255 = ((($118) + (($i$01661*288)|0)|0) + 68|0);
    $256 = Math_fround(HEAPF32[$255>>2]);
    $257 = ((($118) + (($i$01661*288)|0)|0) + 72|0);
    $258 = Math_fround(HEAPF32[$257>>2]);
    $259 = ((($118) + (($i$01661*288)|0)|0) + 76|0);
    $260 = Math_fround(HEAPF32[$259>>2]);
    $261 = ((($118) + (($i$01661*288)|0)|0) + 80|0);
    $262 = Math_fround(HEAPF32[$261>>2]);
    $263 = ((($118) + (($i$01661*288)|0)|0) + 84|0);
    $264 = Math_fround(HEAPF32[$263>>2]);
    $265 = ((($118) + (($i$01661*288)|0)|0) + 88|0);
    $266 = Math_fround(HEAPF32[$265>>2]);
    $267 = ((($118) + (($i$01661*288)|0)|0) + 92|0);
    $268 = Math_fround(HEAPF32[$267>>2]);
    $269 = ((($118) + (($i$01661*288)|0)|0) + 192|0);
    $270 = Math_fround(HEAPF32[$269>>2]);
    $271 = ((($118) + (($i$01661*288)|0)|0) + 196|0);
    $272 = Math_fround(HEAPF32[$271>>2]);
    $273 = ((($118) + (($i$01661*288)|0)|0) + 200|0);
    $274 = Math_fround(HEAPF32[$273>>2]);
    $275 = ((($118) + (($i$01661*288)|0)|0) + 204|0);
    $276 = Math_fround(HEAPF32[$275>>2]);
    $277 = ((($118) + (($i$01661*288)|0)|0) + 208|0);
    $278 = Math_fround(HEAPF32[$277>>2]);
    $279 = ((($118) + (($i$01661*288)|0)|0) + 212|0);
    $280 = Math_fround(HEAPF32[$279>>2]);
    $281 = ((($118) + (($i$01661*288)|0)|0) + 216|0);
    $282 = Math_fround(HEAPF32[$281>>2]);
    $283 = ((($118) + (($i$01661*288)|0)|0) + 220|0);
    $284 = Math_fround(HEAPF32[$283>>2]);
    $285 = ((($118) + (($i$01661*288)|0)|0) + 224|0);
    $286 = Math_fround(HEAPF32[$285>>2]);
    $287 = ((($118) + (($i$01661*288)|0)|0) + 228|0);
    $288 = Math_fround(HEAPF32[$287>>2]);
    $289 = ((($118) + (($i$01661*288)|0)|0) + 232|0);
    $290 = Math_fround(HEAPF32[$289>>2]);
    $291 = ((($118) + (($i$01661*288)|0)|0) + 236|0);
    $292 = Math_fround(HEAPF32[$291>>2]);
    $293 = ((($118) + (($i$01661*288)|0)|0) + 144|0);
    $294 = Math_fround(HEAPF32[$293>>2]);
    $295 = ((($118) + (($i$01661*288)|0)|0) + 148|0);
    $296 = Math_fround(HEAPF32[$295>>2]);
    $297 = ((($118) + (($i$01661*288)|0)|0) + 152|0);
    $298 = Math_fround(HEAPF32[$297>>2]);
    $299 = ((($118) + (($i$01661*288)|0)|0) + 156|0);
    $300 = Math_fround(HEAPF32[$299>>2]);
    $301 = ((($118) + (($i$01661*288)|0)|0) + 160|0);
    $302 = Math_fround(HEAPF32[$301>>2]);
    $303 = ((($118) + (($i$01661*288)|0)|0) + 164|0);
    $304 = Math_fround(HEAPF32[$303>>2]);
    $305 = ((($118) + (($i$01661*288)|0)|0) + 168|0);
    $306 = Math_fround(HEAPF32[$305>>2]);
    $307 = ((($118) + (($i$01661*288)|0)|0) + 172|0);
    $308 = Math_fround(HEAPF32[$307>>2]);
    $309 = ((($118) + (($i$01661*288)|0)|0) + 176|0);
    $310 = Math_fround(HEAPF32[$309>>2]);
    $311 = ((($118) + (($i$01661*288)|0)|0) + 180|0);
    $312 = Math_fround(HEAPF32[$311>>2]);
    $313 = ((($118) + (($i$01661*288)|0)|0) + 184|0);
    $314 = Math_fround(HEAPF32[$313>>2]);
    $315 = ((($118) + (($i$01661*288)|0)|0) + 188|0);
    $316 = Math_fround(HEAPF32[$315>>2]);
    $317 = Math_fround($318 * $222);
    $319 = Math_fround($320 * $224);
    $321 = Math_fround($322 * $226);
    $323 = Math_fround($324 * $228);
    $325 = Math_fround($326 * $246);
    $327 = Math_fround($328 * $248);
    $329 = Math_fround($330 * $250);
    $331 = Math_fround($332 * $252);
    $333 = Math_fround($334 * $222);
    $335 = Math_fround($336 * $224);
    $337 = Math_fround($338 * $226);
    $339 = Math_fround($340 * $228);
    $341 = Math_fround($342 * $270);
    $343 = Math_fround($344 * $272);
    $345 = Math_fround($346 * $274);
    $347 = Math_fround($348 * $276);
    $349 = Math_fround($350 * $230);
    $351 = Math_fround($352 * $232);
    $353 = Math_fround($354 * $234);
    $355 = Math_fround($356 * $236);
    $357 = Math_fround($317 + $349);
    $358 = Math_fround($319 + $351);
    $359 = Math_fround($321 + $353);
    $360 = Math_fround($323 + $355);
    $361 = Math_fround($362 * $254);
    $363 = Math_fround($364 * $256);
    $365 = Math_fround($366 * $258);
    $367 = Math_fround($368 * $260);
    $369 = Math_fround($325 + $361);
    $370 = Math_fround($327 + $363);
    $371 = Math_fround($329 + $365);
    $372 = Math_fround($331 + $367);
    $373 = Math_fround($374 * $230);
    $375 = Math_fround($376 * $232);
    $377 = Math_fround($378 * $234);
    $379 = Math_fround($380 * $236);
    $381 = Math_fround($333 + $373);
    $382 = Math_fround($335 + $375);
    $383 = Math_fround($337 + $377);
    $384 = Math_fround($339 + $379);
    $385 = Math_fround($386 * $278);
    $387 = Math_fround($388 * $280);
    $389 = Math_fround($390 * $282);
    $391 = Math_fround($392 * $284);
    $393 = Math_fround($341 + $385);
    $394 = Math_fround($343 + $387);
    $395 = Math_fround($345 + $389);
    $396 = Math_fround($347 + $391);
    $397 = Math_fround($398 * $238);
    $399 = Math_fround($400 * $240);
    $401 = Math_fround($402 * $242);
    $403 = Math_fround($404 * $244);
    $405 = Math_fround($357 + $397);
    $406 = Math_fround($358 + $399);
    $407 = Math_fround($359 + $401);
    $408 = Math_fround($360 + $403);
    $409 = Math_fround($410 * $262);
    $411 = Math_fround($412 * $264);
    $413 = Math_fround($414 * $266);
    $415 = Math_fround($416 * $268);
    $417 = Math_fround($369 + $409);
    $418 = Math_fround($370 + $411);
    $419 = Math_fround($371 + $413);
    $420 = Math_fround($372 + $415);
    $421 = Math_fround($422 * $238);
    $423 = Math_fround($424 * $240);
    $425 = Math_fround($426 * $242);
    $427 = Math_fround($428 * $244);
    $429 = Math_fround($381 + $421);
    $430 = Math_fround($382 + $423);
    $431 = Math_fround($383 + $425);
    $432 = Math_fround($384 + $427);
    $433 = Math_fround($434 * $286);
    $435 = Math_fround($436 * $288);
    $437 = Math_fround($438 * $290);
    $439 = Math_fround($440 * $292);
    $441 = Math_fround($393 + $433);
    $442 = Math_fround($394 + $435);
    $443 = Math_fround($395 + $437);
    $444 = Math_fround($396 + $439);
    $445 = Math_fround($134 * $222);
    $446 = Math_fround($136 * $224);
    $447 = Math_fround($138 * $226);
    $448 = Math_fround($140 * $228);
    $449 = Math_fround($142 * $222);
    $450 = Math_fround($144 * $224);
    $451 = Math_fround($146 * $226);
    $452 = Math_fround($148 * $228);
    $453 = Math_fround($134 * $230);
    $454 = Math_fround($136 * $232);
    $455 = Math_fround($138 * $234);
    $456 = Math_fround($140 * $236);
    $457 = Math_fround($142 * $230);
    $458 = Math_fround($144 * $232);
    $459 = Math_fround($146 * $234);
    $460 = Math_fround($148 * $236);
    $461 = Math_fround($405 + $417);
    $462 = Math_fround($406 + $418);
    $463 = Math_fround($407 + $419);
    $464 = Math_fround($408 + $420);
    $465 = Math_fround($429 + $441);
    $466 = Math_fround($430 + $442);
    $467 = Math_fround($431 + $443);
    $468 = Math_fround($432 + $444);
    $469 = Math_fround($134 * $238);
    $470 = Math_fround($136 * $240);
    $471 = Math_fround($138 * $242);
    $472 = Math_fround($140 * $244);
    $473 = Math_fround($142 * $238);
    $474 = Math_fround($144 * $240);
    $475 = Math_fround($146 * $242);
    $476 = Math_fround($148 * $244);
    $477 = Math_fround($461 - $465);
    $478 = Math_fround($462 - $466);
    $479 = Math_fround($463 - $467);
    $480 = Math_fround($464 - $468);
    $481 = Math_fround($302 * $310);
    $482 = Math_fround($304 * $312);
    $483 = Math_fround($306 * $314);
    $484 = Math_fround($308 * $316);
    $485 = Math_fround($294 - $481);
    $486 = Math_fround($296 - $482);
    $487 = Math_fround($298 - $483);
    $488 = Math_fround($300 - $484);
    $489 = Math_fround($477 * $302);
    $490 = Math_fround($478 * $304);
    $491 = Math_fround($479 * $306);
    $492 = Math_fround($480 * $308);
    $493 = Math_fround($489 + $485);
    $494 = Math_fround($490 + $486);
    $495 = Math_fround($491 + $487);
    $496 = Math_fround($492 + $488);
    $497 = $493 < $165;
    $$$i$i = $497 ? $493 : $165;
    $498 = $494 < $166;
    $499 = $498 ? $494 : $166;
    $500 = $495 < $167;
    $$1$i$i = $500 ? $495 : $167;
    $501 = $496 < $168;
    $502 = $501 ? $496 : $168;
    $503 = $$$i$i > $169;
    $$$i8$i = $503 ? $$$i$i : $169;
    $504 = $499 > $170;
    $505 = $504 ? $499 : $170;
    $506 = $$1$i$i > $171;
    $$1$i9$i = $506 ? $$1$i$i : $171;
    $507 = $502 > $172;
    $508 = $507 ? $502 : $172;
    $509 = Math_fround($$$i8$i - $294);
    $510 = Math_fround($505 - $296);
    $511 = Math_fround($$1$i9$i - $298);
    $512 = Math_fround($508 - $300);
    $513 = Math_fround($445 * $509);
    $514 = Math_fround($446 * $510);
    $515 = Math_fround($447 * $511);
    $516 = Math_fround($448 * $512);
    $517 = Math_fround($318 + $513);
    $518 = Math_fround($320 + $514);
    $519 = Math_fround($322 + $515);
    $520 = Math_fround($324 + $516);
    $521 = Math_fround($449 * $509);
    $522 = Math_fround($450 * $510);
    $523 = Math_fround($451 * $511);
    $524 = Math_fround($452 * $512);
    $525 = Math_fround($334 + $521);
    $526 = Math_fround($336 + $522);
    $527 = Math_fround($338 + $523);
    $528 = Math_fround($340 + $524);
    $529 = Math_fround($174 * $509);
    $530 = Math_fround($176 * $510);
    $531 = Math_fround($178 * $511);
    $532 = Math_fround($180 * $512);
    $533 = Math_fround($326 + $529);
    $534 = Math_fround($328 + $530);
    $535 = Math_fround($330 + $531);
    $536 = Math_fround($332 + $532);
    $537 = Math_fround($198 * $509);
    $538 = Math_fround($200 * $510);
    $539 = Math_fround($202 * $511);
    $540 = Math_fround($204 * $512);
    $541 = Math_fround($342 + $537);
    $542 = Math_fround($344 + $538);
    $543 = Math_fround($346 + $539);
    $544 = Math_fround($348 + $540);
    $545 = Math_fround($453 * $509);
    $546 = Math_fround($454 * $510);
    $547 = Math_fround($455 * $511);
    $548 = Math_fround($456 * $512);
    $549 = Math_fround($350 + $545);
    $550 = Math_fround($352 + $546);
    $551 = Math_fround($354 + $547);
    $552 = Math_fround($356 + $548);
    $553 = Math_fround($457 * $509);
    $554 = Math_fround($458 * $510);
    $555 = Math_fround($459 * $511);
    $556 = Math_fround($460 * $512);
    $557 = Math_fround($374 + $553);
    $558 = Math_fround($376 + $554);
    $559 = Math_fround($378 + $555);
    $560 = Math_fround($380 + $556);
    $561 = Math_fround($182 * $509);
    $562 = Math_fround($184 * $510);
    $563 = Math_fround($186 * $511);
    $564 = Math_fround($188 * $512);
    $565 = Math_fround($362 + $561);
    $566 = Math_fround($364 + $562);
    $567 = Math_fround($366 + $563);
    $568 = Math_fround($368 + $564);
    $569 = Math_fround($206 * $509);
    $570 = Math_fround($208 * $510);
    $571 = Math_fround($210 * $511);
    $572 = Math_fround($212 * $512);
    $573 = Math_fround($386 + $569);
    $574 = Math_fround($388 + $570);
    $575 = Math_fround($390 + $571);
    $576 = Math_fround($392 + $572);
    $577 = Math_fround($469 * $509);
    $578 = Math_fround($470 * $510);
    $579 = Math_fround($471 * $511);
    $580 = Math_fround($472 * $512);
    $581 = Math_fround($398 + $577);
    $582 = Math_fround($400 + $578);
    $583 = Math_fround($402 + $579);
    $584 = Math_fround($404 + $580);
    $585 = Math_fround($473 * $509);
    $586 = Math_fround($474 * $510);
    $587 = Math_fround($475 * $511);
    $588 = Math_fround($476 * $512);
    $589 = Math_fround($422 + $585);
    $590 = Math_fround($424 + $586);
    $591 = Math_fround($426 + $587);
    $592 = Math_fround($428 + $588);
    $593 = Math_fround($190 * $509);
    $594 = Math_fround($192 * $510);
    $595 = Math_fround($194 * $511);
    $596 = Math_fround($196 * $512);
    $597 = Math_fround($410 + $593);
    $598 = Math_fround($412 + $594);
    $599 = Math_fround($414 + $595);
    $600 = Math_fround($416 + $596);
    $601 = Math_fround($214 * $509);
    $602 = Math_fround($216 * $510);
    $603 = Math_fround($218 * $511);
    $604 = Math_fround($220 * $512);
    $605 = Math_fround($434 + $601);
    $606 = Math_fround($436 + $602);
    $607 = Math_fround($438 + $603);
    $608 = Math_fround($440 + $604);
    HEAPF32[$293>>2] = $$$i8$i;
    HEAPF32[$295>>2] = $505;
    HEAPF32[$297>>2] = $$1$i9$i;
    HEAPF32[$299>>2] = $508;
    $exitcond = ($$sum1|0)==($124|0);
    if ($exitcond) {
     $$lcssa = $520;$$lcssa1614 = $519;$$lcssa1615 = $518;$$lcssa1616 = $517;$$lcssa1617 = $552;$$lcssa1618 = $551;$$lcssa1619 = $550;$$lcssa1620 = $549;$$lcssa1621 = $584;$$lcssa1622 = $583;$$lcssa1623 = $582;$$lcssa1624 = $581;$$lcssa1625 = $528;$$lcssa1626 = $527;$$lcssa1627 = $526;$$lcssa1628 = $525;$$lcssa1629 = $560;$$lcssa1630 = $559;$$lcssa1631 = $558;$$lcssa1632 = $557;$$lcssa1633 = $592;$$lcssa1634 = $591;$$lcssa1635 = $590;$$lcssa1636 = $589;$$lcssa1637 = $536;$$lcssa1638 = $535;$$lcssa1639 = $534;$$lcssa1640 = $533;$$lcssa1641 = $568;$$lcssa1642 = $567;$$lcssa1643 = $566;$$lcssa1644 = $565;$$lcssa1645 = $600;$$lcssa1646 = $599;$$lcssa1647 = $598;$$lcssa1648 = $597;$$lcssa1649 = $544;$$lcssa1650 = $543;$$lcssa1651 = $542;$$lcssa1652 = $541;$$lcssa1653 = $576;$$lcssa1654 = $575;$$lcssa1655 = $574;$$lcssa1656 = $573;$$lcssa1657 = $608;$$lcssa1658 = $607;$$lcssa1659 = $606;$$lcssa1660 = $605;
     break;
    } else {
     $318 = $517;$320 = $518;$322 = $519;$324 = $520;$326 = $533;$328 = $534;$330 = $535;$332 = $536;$334 = $525;$336 = $526;$338 = $527;$340 = $528;$342 = $541;$344 = $542;$346 = $543;$348 = $544;$350 = $549;$352 = $550;$354 = $551;$356 = $552;$362 = $565;$364 = $566;$366 = $567;$368 = $568;$374 = $557;$376 = $558;$378 = $559;$380 = $560;$386 = $573;$388 = $574;$390 = $575;$392 = $576;$398 = $581;$400 = $582;$402 = $583;$404 = $584;$410 = $597;$412 = $598;$414 = $599;$416 = $600;$422 = $589;$424 = $590;$426 = $591;$428 = $592;$434 = $605;$436 = $606;$438 = $607;$440 = $608;$i$01661 = $$sum1;
    }
   }
  }
  $111 = ($112>>>0)<($109>>>0);
  if ($111) {
   $641 = $$lcssa1660;$642 = $$lcssa1659;$643 = $$lcssa1658;$644 = $$lcssa1657;$645 = $$lcssa1656;$646 = $$lcssa1655;$647 = $$lcssa1654;$648 = $$lcssa1653;$649 = $$lcssa1652;$650 = $$lcssa1651;$651 = $$lcssa1650;$652 = $$lcssa1649;$653 = $$lcssa1648;$654 = $$lcssa1647;$655 = $$lcssa1646;$656 = $$lcssa1645;$657 = $$lcssa1644;$658 = $$lcssa1643;$659 = $$lcssa1642;$660 = $$lcssa1641;$661 = $$lcssa1640;$662 = $$lcssa1639;$663 = $$lcssa1638;$664 = $$lcssa1637;$665 = $$lcssa1636;$666 = $$lcssa1635;$667 = $$lcssa1634;$668 = $$lcssa1633;$669 = $$lcssa1632;$670 = $$lcssa1631;$671 = $$lcssa1630;$672 = $$lcssa1629;$673 = $$lcssa1628;$674 = $$lcssa1627;$675 = $$lcssa1626;$676 = $$lcssa1625;$677 = $$lcssa1624;$678 = $$lcssa1623;$679 = $$lcssa1622;$680 = $$lcssa1621;$681 = $$lcssa1620;$682 = $$lcssa1619;$683 = $$lcssa1618;$684 = $$lcssa1617;$685 = $$lcssa1616;$686 = $$lcssa1615;$687 = $$lcssa1614;$688 = $$lcssa;$currPtr$01757 = $112;
  } else {
   $$lcssa1709 = $$lcssa;$$lcssa1710 = $$lcssa1614;$$lcssa1711 = $$lcssa1615;$$lcssa1712 = $$lcssa1616;$$lcssa1713 = $$lcssa1617;$$lcssa1714 = $$lcssa1618;$$lcssa1715 = $$lcssa1619;$$lcssa1716 = $$lcssa1620;$$lcssa1717 = $$lcssa1621;$$lcssa1718 = $$lcssa1622;$$lcssa1719 = $$lcssa1623;$$lcssa1720 = $$lcssa1624;$$lcssa1721 = $$lcssa1625;$$lcssa1722 = $$lcssa1626;$$lcssa1723 = $$lcssa1627;$$lcssa1724 = $$lcssa1628;$$lcssa1725 = $$lcssa1629;$$lcssa1726 = $$lcssa1630;$$lcssa1727 = $$lcssa1631;$$lcssa1728 = $$lcssa1632;$$lcssa1729 = $$lcssa1633;$$lcssa1730 = $$lcssa1634;$$lcssa1731 = $$lcssa1635;$$lcssa1732 = $$lcssa1636;$$lcssa1733 = $$lcssa1637;$$lcssa1734 = $$lcssa1638;$$lcssa1735 = $$lcssa1639;$$lcssa1736 = $$lcssa1640;$$lcssa1737 = $$lcssa1641;$$lcssa1738 = $$lcssa1642;$$lcssa1739 = $$lcssa1643;$$lcssa1740 = $$lcssa1644;$$lcssa1741 = $$lcssa1645;$$lcssa1742 = $$lcssa1646;$$lcssa1743 = $$lcssa1647;$$lcssa1744 = $$lcssa1648;$$lcssa1745 = $$lcssa1649;$$lcssa1746 = $$lcssa1650;$$lcssa1747 = $$lcssa1651;$$lcssa1748 = $$lcssa1652;$$lcssa1749 = $$lcssa1653;$$lcssa1750 = $$lcssa1654;$$lcssa1751 = $$lcssa1655;$$lcssa1752 = $$lcssa1656;$$lcssa1753 = $$lcssa1657;$$lcssa1754 = $$lcssa1658;$$lcssa1755 = $$lcssa1659;$$lcssa1756 = $$lcssa1660;
   break;
  }
 }
 HEAPF32[$0>>2] = $$lcssa1712;
 $609 = (($0) + 4|0);
 HEAPF32[$609>>2] = $$lcssa1716;
 $610 = (($0) + 8|0);
 HEAPF32[$610>>2] = $$lcssa1720;
 HEAPF32[$4>>2] = $$lcssa1711;
 $611 = (($4) + 4|0);
 HEAPF32[$611>>2] = $$lcssa1715;
 $612 = (($4) + 8|0);
 HEAPF32[$612>>2] = $$lcssa1719;
 HEAPF32[$8>>2] = $$lcssa1710;
 $613 = (($8) + 4|0);
 HEAPF32[$613>>2] = $$lcssa1714;
 $614 = (($8) + 8|0);
 HEAPF32[$614>>2] = $$lcssa1718;
 HEAPF32[$12>>2] = $$lcssa1709;
 $615 = (($12) + 4|0);
 HEAPF32[$615>>2] = $$lcssa1713;
 $616 = (($12) + 8|0);
 HEAPF32[$616>>2] = $$lcssa1717;
 HEAPF32[$2>>2] = $$lcssa1724;
 $617 = (($2) + 4|0);
 HEAPF32[$617>>2] = $$lcssa1728;
 $618 = (($2) + 8|0);
 HEAPF32[$618>>2] = $$lcssa1732;
 HEAPF32[$6>>2] = $$lcssa1723;
 $619 = (($6) + 4|0);
 HEAPF32[$619>>2] = $$lcssa1727;
 $620 = (($6) + 8|0);
 HEAPF32[$620>>2] = $$lcssa1731;
 HEAPF32[$10>>2] = $$lcssa1722;
 $621 = (($10) + 4|0);
 HEAPF32[$621>>2] = $$lcssa1726;
 $622 = (($10) + 8|0);
 HEAPF32[$622>>2] = $$lcssa1730;
 HEAPF32[$14>>2] = $$lcssa1721;
 $623 = (($14) + 4|0);
 HEAPF32[$623>>2] = $$lcssa1725;
 $624 = (($14) + 8|0);
 HEAPF32[$624>>2] = $$lcssa1729;
 HEAPF32[$25>>2] = $$lcssa1736;
 $625 = (($0) + 20|0);
 HEAPF32[$625>>2] = $$lcssa1740;
 $626 = (($0) + 24|0);
 HEAPF32[$626>>2] = $$lcssa1744;
 HEAPF32[$47>>2] = $$lcssa1735;
 $627 = (($4) + 20|0);
 HEAPF32[$627>>2] = $$lcssa1739;
 $628 = (($4) + 24|0);
 HEAPF32[$628>>2] = $$lcssa1743;
 HEAPF32[$69>>2] = $$lcssa1734;
 $629 = (($8) + 20|0);
 HEAPF32[$629>>2] = $$lcssa1738;
 $630 = (($8) + 24|0);
 HEAPF32[$630>>2] = $$lcssa1742;
 HEAPF32[$91>>2] = $$lcssa1733;
 $631 = (($12) + 20|0);
 HEAPF32[$631>>2] = $$lcssa1737;
 $632 = (($12) + 24|0);
 HEAPF32[$632>>2] = $$lcssa1741;
 HEAPF32[$31>>2] = $$lcssa1748;
 $633 = (($2) + 20|0);
 HEAPF32[$633>>2] = $$lcssa1752;
 $634 = (($2) + 24|0);
 HEAPF32[$634>>2] = $$lcssa1756;
 HEAPF32[$53>>2] = $$lcssa1747;
 $635 = (($6) + 20|0);
 HEAPF32[$635>>2] = $$lcssa1751;
 $636 = (($6) + 24|0);
 HEAPF32[$636>>2] = $$lcssa1755;
 HEAPF32[$75>>2] = $$lcssa1746;
 $637 = (($10) + 20|0);
 HEAPF32[$637>>2] = $$lcssa1750;
 $638 = (($10) + 24|0);
 HEAPF32[$638>>2] = $$lcssa1754;
 HEAPF32[$97>>2] = $$lcssa1745;
 $639 = (($14) + 20|0);
 HEAPF32[$639>>2] = $$lcssa1749;
 $640 = (($14) + 24|0);
 HEAPF32[$640>>2] = $$lcssa1753;
 STACKTOP = sp;return;
}
function __ZN5physx35solveFrictionCoulombPreBlock_StaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL26solveFriction4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physxL26solveFriction4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc) {
 $desc = $desc|0;
 var $$$i$i = Math_fround(0), $$$i8$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i9$i = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa870 = Math_fround(0), $$lcssa871 = Math_fround(0), $$lcssa872 = Math_fround(0), $$lcssa873 = Math_fround(0), $$lcssa874 = Math_fround(0), $$lcssa875 = Math_fround(0), $$lcssa876 = Math_fround(0), $$lcssa877 = Math_fround(0), $$lcssa878 = Math_fround(0), $$lcssa879 = Math_fround(0), $$lcssa880 = Math_fround(0), $$lcssa881 = Math_fround(0), $$lcssa882 = Math_fround(0), $$lcssa883 = Math_fround(0), $$lcssa884 = Math_fround(0);
 var $$lcssa885 = Math_fround(0), $$lcssa886 = Math_fround(0), $$lcssa887 = Math_fround(0), $$lcssa888 = Math_fround(0), $$lcssa889 = Math_fround(0), $$lcssa890 = Math_fround(0), $$lcssa891 = Math_fround(0), $$lcssa892 = Math_fround(0), $$lcssa917 = Math_fround(0), $$lcssa918 = Math_fround(0), $$lcssa919 = Math_fround(0), $$lcssa920 = Math_fround(0), $$lcssa921 = Math_fround(0), $$lcssa922 = Math_fround(0), $$lcssa923 = Math_fround(0), $$lcssa924 = Math_fround(0), $$lcssa925 = Math_fround(0), $$lcssa926 = Math_fround(0), $$lcssa927 = Math_fround(0), $$lcssa928 = Math_fround(0);
 var $$lcssa929 = Math_fround(0), $$lcssa930 = Math_fround(0), $$lcssa931 = Math_fround(0), $$lcssa932 = Math_fround(0), $$lcssa933 = Math_fround(0), $$lcssa934 = Math_fround(0), $$lcssa935 = Math_fround(0), $$lcssa936 = Math_fround(0), $$lcssa937 = Math_fround(0), $$lcssa938 = Math_fround(0), $$lcssa939 = Math_fround(0), $$lcssa940 = Math_fround(0), $$sum = 0, $$sum1 = 0, $$sum866 = 0, $$sum867 = 0, $$sum868 = 0, $$sum869 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0);
 var $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0);
 var $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0);
 var $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0);
 var $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0;
 var $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0);
 var $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0);
 var $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0);
 var $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0);
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0);
 var $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = Math_fround(0);
 var $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0);
 var $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0);
 var $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = Math_fround(0);
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0);
 var $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0);
 var $406 = Math_fround(0), $407 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0;
 var $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $currPtr$0941 = 0, $exitcond = 0, $i$0893 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($desc) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($desc) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$0>>2]);
 $8 = (($0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($0) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($12) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$2>>2]);
 $19 = (($2) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($2) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($2) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($23) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($23) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$4>>2]);
 $30 = (($4) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($4) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($4) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($34) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($34) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround(HEAPF32[$6>>2]);
 $41 = (($6) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($6) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($6) + 16|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($45) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($45) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($desc) + 16|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($desc) + 26|0);
 $54 = HEAP16[$53>>1]|0;
 $55 = $54&65535;
 $56 = $55 << 4;
 $57 = (($52) + ($56)|0);
 $58 = ($54<<16>>16)==(0);
 if ($58) {
  $$lcssa917 = $40;$$lcssa918 = $29;$$lcssa919 = $18;$$lcssa920 = $7;$$lcssa921 = $42;$$lcssa922 = $31;$$lcssa923 = $20;$$lcssa924 = $9;$$lcssa925 = $44;$$lcssa926 = $33;$$lcssa927 = $22;$$lcssa928 = $11;$$lcssa929 = $46;$$lcssa930 = $35;$$lcssa931 = $24;$$lcssa932 = $13;$$lcssa933 = $48;$$lcssa934 = $37;$$lcssa935 = $26;$$lcssa936 = $15;$$lcssa937 = $50;$$lcssa938 = $39;$$lcssa939 = $28;$$lcssa940 = $17;
  HEAPF32[$0>>2] = $$lcssa920;
  $368 = (($0) + 4|0);
  HEAPF32[$368>>2] = $$lcssa924;
  $369 = (($0) + 8|0);
  HEAPF32[$369>>2] = $$lcssa928;
  HEAPF32[$2>>2] = $$lcssa919;
  $370 = (($2) + 4|0);
  HEAPF32[$370>>2] = $$lcssa923;
  $371 = (($2) + 8|0);
  HEAPF32[$371>>2] = $$lcssa927;
  HEAPF32[$4>>2] = $$lcssa918;
  $372 = (($4) + 4|0);
  HEAPF32[$372>>2] = $$lcssa922;
  $373 = (($4) + 8|0);
  HEAPF32[$373>>2] = $$lcssa926;
  HEAPF32[$6>>2] = $$lcssa917;
  $374 = (($6) + 4|0);
  HEAPF32[$374>>2] = $$lcssa921;
  $375 = (($6) + 8|0);
  HEAPF32[$375>>2] = $$lcssa925;
  HEAPF32[$12>>2] = $$lcssa932;
  $376 = (($0) + 20|0);
  HEAPF32[$376>>2] = $$lcssa936;
  $377 = (($0) + 24|0);
  HEAPF32[$377>>2] = $$lcssa940;
  HEAPF32[$23>>2] = $$lcssa931;
  $378 = (($2) + 20|0);
  HEAPF32[$378>>2] = $$lcssa935;
  $379 = (($2) + 24|0);
  HEAPF32[$379>>2] = $$lcssa939;
  HEAPF32[$34>>2] = $$lcssa930;
  $380 = (($4) + 20|0);
  HEAPF32[$380>>2] = $$lcssa934;
  $381 = (($4) + 24|0);
  HEAPF32[$381>>2] = $$lcssa938;
  HEAPF32[$45>>2] = $$lcssa929;
  $382 = (($6) + 20|0);
  HEAPF32[$382>>2] = $$lcssa933;
  $383 = (($6) + 24|0);
  HEAPF32[$383>>2] = $$lcssa937;
  STACKTOP = sp;return;
 } else {
  $384 = $17;$385 = $28;$386 = $39;$387 = $50;$388 = $15;$389 = $26;$390 = $37;$391 = $48;$392 = $13;$393 = $24;$394 = $35;$395 = $46;$396 = $11;$397 = $22;$398 = $33;$399 = $44;$400 = $9;$401 = $20;$402 = $31;$403 = $42;$404 = $7;$405 = $18;$406 = $29;$407 = $40;$currPtr$0941 = $52;
 }
 while(1) {
  $61 = (($currPtr$0941) + 64|0);
  $62 = (($currPtr$0941) + 1|0);
  $63 = HEAP8[$62>>0]|0;
  $64 = $63&255;
  $65 = $64 << 4;
  $$sum = (($65) + 64)|0;
  $66 = (($currPtr$0941) + ($$sum)|0);
  $$sum866 = (($65) + 192)|0;
  $67 = (($currPtr$0941) + ($$sum866)|0);
  $$sum867 = (($65) + 320)|0;
  $68 = (($currPtr$0941) + ($$sum867)|0);
  $$sum868 = (($65) + 448)|0;
  $69 = (($currPtr$0941) + ($$sum868)|0);
  $70 = (($currPtr$0941) + 2|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71&255;
  $60 = (($66) + (($72*192)|0)|0);
  $73 = (($currPtr$0941) + 16|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($currPtr$0941) + 20|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($currPtr$0941) + 24|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($currPtr$0941) + 28|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (($currPtr$0941) + 32|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = (($currPtr$0941) + 36|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = (($currPtr$0941) + 40|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = (($currPtr$0941) + 44|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = ($71<<24>>24)==(0);
  if ($89) {
   $$lcssa = $407;$$lcssa870 = $406;$$lcssa871 = $405;$$lcssa872 = $404;$$lcssa873 = $403;$$lcssa874 = $402;$$lcssa875 = $401;$$lcssa876 = $400;$$lcssa877 = $399;$$lcssa878 = $398;$$lcssa879 = $397;$$lcssa880 = $396;$$lcssa881 = $395;$$lcssa882 = $394;$$lcssa883 = $393;$$lcssa884 = $392;$$lcssa885 = $391;$$lcssa886 = $390;$$lcssa887 = $389;$$lcssa888 = $388;$$lcssa889 = $387;$$lcssa890 = $386;$$lcssa891 = $385;$$lcssa892 = $384;
  } else {
   $90 = (($currPtr$0941) + 12|0);
   $209 = $404;$211 = $405;$213 = $406;$215 = $407;$217 = $392;$219 = $393;$221 = $394;$223 = $395;$225 = $400;$227 = $401;$229 = $402;$231 = $403;$237 = $388;$239 = $389;$241 = $390;$243 = $391;$249 = $396;$251 = $397;$253 = $398;$255 = $399;$261 = $384;$263 = $385;$265 = $386;$267 = $387;$i$0893 = 0;
   while(1) {
    $$sum1 = (($i$0893) + 1)|0;
    $91 = (($66) + (($$sum1*192)|0)|0);
    $92 = ((($66) + (($$sum1*192)|0)|0) + 128|0);
    $$sum869 = (($i$0893) + 2)|0;
    $93 = ((($66) + (($$sum869*192)|0)|0) + 64|0);
    $94 = HEAP32[$90>>2]|0;
    $95 = $i$0893 >>> $94;
    $96 = (($61) + ($95<<4)|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = ((($61) + ($95<<4)|0) + 4|0);
    $99 = Math_fround(HEAPF32[$98>>2]);
    $100 = ((($61) + ($95<<4)|0) + 8|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = ((($61) + ($95<<4)|0) + 12|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = Math_fround($74 * $97);
    $105 = Math_fround($76 * $99);
    $106 = Math_fround($78 * $101);
    $107 = Math_fround($80 * $103);
    $108 = Math_fround(-$104);
    $109 = Math_fround(-$105);
    $110 = Math_fround(-$106);
    $111 = Math_fround(-$107);
    $112 = ((($66) + (($i$0893*192)|0)|0) + 96|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = ((($66) + (($i$0893*192)|0)|0) + 100|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = ((($66) + (($i$0893*192)|0)|0) + 104|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = ((($66) + (($i$0893*192)|0)|0) + 108|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = ((($66) + (($i$0893*192)|0)|0) + 112|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    $122 = ((($66) + (($i$0893*192)|0)|0) + 116|0);
    $123 = Math_fround(HEAPF32[$122>>2]);
    $124 = ((($66) + (($i$0893*192)|0)|0) + 120|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = ((($66) + (($i$0893*192)|0)|0) + 124|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = ((($66) + (($i$0893*192)|0)|0) + 128|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = ((($66) + (($i$0893*192)|0)|0) + 132|0);
    $131 = Math_fround(HEAPF32[$130>>2]);
    $132 = ((($66) + (($i$0893*192)|0)|0) + 136|0);
    $133 = Math_fround(HEAPF32[$132>>2]);
    $134 = ((($66) + (($i$0893*192)|0)|0) + 140|0);
    $135 = Math_fround(HEAPF32[$134>>2]);
    $136 = (($66) + (($i$0893*192)|0)|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = ((($66) + (($i$0893*192)|0)|0) + 4|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = ((($66) + (($i$0893*192)|0)|0) + 8|0);
    $141 = Math_fround(HEAPF32[$140>>2]);
    $142 = ((($66) + (($i$0893*192)|0)|0) + 12|0);
    $143 = Math_fround(HEAPF32[$142>>2]);
    $144 = ((($66) + (($i$0893*192)|0)|0) + 16|0);
    $145 = Math_fround(HEAPF32[$144>>2]);
    $146 = ((($66) + (($i$0893*192)|0)|0) + 20|0);
    $147 = Math_fround(HEAPF32[$146>>2]);
    $148 = ((($66) + (($i$0893*192)|0)|0) + 24|0);
    $149 = Math_fround(HEAPF32[$148>>2]);
    $150 = ((($66) + (($i$0893*192)|0)|0) + 28|0);
    $151 = Math_fround(HEAPF32[$150>>2]);
    $152 = ((($66) + (($i$0893*192)|0)|0) + 32|0);
    $153 = Math_fround(HEAPF32[$152>>2]);
    $154 = ((($66) + (($i$0893*192)|0)|0) + 36|0);
    $155 = Math_fround(HEAPF32[$154>>2]);
    $156 = ((($66) + (($i$0893*192)|0)|0) + 40|0);
    $157 = Math_fround(HEAPF32[$156>>2]);
    $158 = ((($66) + (($i$0893*192)|0)|0) + 44|0);
    $159 = Math_fround(HEAPF32[$158>>2]);
    $160 = ((($66) + (($i$0893*192)|0)|0) + 48|0);
    $161 = Math_fround(HEAPF32[$160>>2]);
    $162 = ((($66) + (($i$0893*192)|0)|0) + 52|0);
    $163 = Math_fround(HEAPF32[$162>>2]);
    $164 = ((($66) + (($i$0893*192)|0)|0) + 56|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = ((($66) + (($i$0893*192)|0)|0) + 60|0);
    $167 = Math_fround(HEAPF32[$166>>2]);
    $168 = ((($66) + (($i$0893*192)|0)|0) + 64|0);
    $169 = Math_fround(HEAPF32[$168>>2]);
    $170 = ((($66) + (($i$0893*192)|0)|0) + 68|0);
    $171 = Math_fround(HEAPF32[$170>>2]);
    $172 = ((($66) + (($i$0893*192)|0)|0) + 72|0);
    $173 = Math_fround(HEAPF32[$172>>2]);
    $174 = ((($66) + (($i$0893*192)|0)|0) + 76|0);
    $175 = Math_fround(HEAPF32[$174>>2]);
    $176 = ((($66) + (($i$0893*192)|0)|0) + 80|0);
    $177 = Math_fround(HEAPF32[$176>>2]);
    $178 = ((($66) + (($i$0893*192)|0)|0) + 84|0);
    $179 = Math_fround(HEAPF32[$178>>2]);
    $180 = ((($66) + (($i$0893*192)|0)|0) + 88|0);
    $181 = Math_fround(HEAPF32[$180>>2]);
    $182 = ((($66) + (($i$0893*192)|0)|0) + 92|0);
    $183 = Math_fround(HEAPF32[$182>>2]);
    $184 = ((($66) + (($i$0893*192)|0)|0) + 144|0);
    $185 = Math_fround(HEAPF32[$184>>2]);
    $186 = ((($66) + (($i$0893*192)|0)|0) + 148|0);
    $187 = Math_fround(HEAPF32[$186>>2]);
    $188 = ((($66) + (($i$0893*192)|0)|0) + 152|0);
    $189 = Math_fround(HEAPF32[$188>>2]);
    $190 = ((($66) + (($i$0893*192)|0)|0) + 156|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = ((($66) + (($i$0893*192)|0)|0) + 160|0);
    $193 = Math_fround(HEAPF32[$192>>2]);
    $194 = ((($66) + (($i$0893*192)|0)|0) + 164|0);
    $195 = Math_fround(HEAPF32[$194>>2]);
    $196 = ((($66) + (($i$0893*192)|0)|0) + 168|0);
    $197 = Math_fround(HEAPF32[$196>>2]);
    $198 = ((($66) + (($i$0893*192)|0)|0) + 172|0);
    $199 = Math_fround(HEAPF32[$198>>2]);
    $200 = ((($66) + (($i$0893*192)|0)|0) + 176|0);
    $201 = Math_fround(HEAPF32[$200>>2]);
    $202 = ((($66) + (($i$0893*192)|0)|0) + 180|0);
    $203 = Math_fround(HEAPF32[$202>>2]);
    $204 = ((($66) + (($i$0893*192)|0)|0) + 184|0);
    $205 = Math_fround(HEAPF32[$204>>2]);
    $206 = ((($66) + (($i$0893*192)|0)|0) + 188|0);
    $207 = Math_fround(HEAPF32[$206>>2]);
    $208 = Math_fround($209 * $137);
    $210 = Math_fround($211 * $139);
    $212 = Math_fround($213 * $141);
    $214 = Math_fround($215 * $143);
    $216 = Math_fround($217 * $161);
    $218 = Math_fround($219 * $163);
    $220 = Math_fround($221 * $165);
    $222 = Math_fround($223 * $167);
    $224 = Math_fround($225 * $145);
    $226 = Math_fround($227 * $147);
    $228 = Math_fround($229 * $149);
    $230 = Math_fround($231 * $151);
    $232 = Math_fround($208 + $224);
    $233 = Math_fround($210 + $226);
    $234 = Math_fround($212 + $228);
    $235 = Math_fround($214 + $230);
    $236 = Math_fround($237 * $169);
    $238 = Math_fround($239 * $171);
    $240 = Math_fround($241 * $173);
    $242 = Math_fround($243 * $175);
    $244 = Math_fround($216 + $236);
    $245 = Math_fround($218 + $238);
    $246 = Math_fround($220 + $240);
    $247 = Math_fround($222 + $242);
    $248 = Math_fround($249 * $153);
    $250 = Math_fround($251 * $155);
    $252 = Math_fround($253 * $157);
    $254 = Math_fround($255 * $159);
    $256 = Math_fround($232 + $248);
    $257 = Math_fround($233 + $250);
    $258 = Math_fround($234 + $252);
    $259 = Math_fround($235 + $254);
    $260 = Math_fround($261 * $177);
    $262 = Math_fround($263 * $179);
    $264 = Math_fround($265 * $181);
    $266 = Math_fround($267 * $183);
    $268 = Math_fround($244 + $260);
    $269 = Math_fround($245 + $262);
    $270 = Math_fround($246 + $264);
    $271 = Math_fround($247 + $266);
    $272 = Math_fround($82 * $137);
    $273 = Math_fround($84 * $139);
    $274 = Math_fround($86 * $141);
    $275 = Math_fround($88 * $143);
    $276 = Math_fround($82 * $145);
    $277 = Math_fround($84 * $147);
    $278 = Math_fround($86 * $149);
    $279 = Math_fround($88 * $151);
    $280 = Math_fround($256 + $268);
    $281 = Math_fround($257 + $269);
    $282 = Math_fround($258 + $270);
    $283 = Math_fround($259 + $271);
    $284 = Math_fround($82 * $153);
    $285 = Math_fround($84 * $155);
    $286 = Math_fround($86 * $157);
    $287 = Math_fround($88 * $159);
    $288 = Math_fround($193 * $201);
    $289 = Math_fround($195 * $203);
    $290 = Math_fround($197 * $205);
    $291 = Math_fround($199 * $207);
    $292 = Math_fround($185 - $288);
    $293 = Math_fround($187 - $289);
    $294 = Math_fround($189 - $290);
    $295 = Math_fround($191 - $291);
    $296 = Math_fround($280 * $193);
    $297 = Math_fround($281 * $195);
    $298 = Math_fround($282 * $197);
    $299 = Math_fround($283 * $199);
    $300 = Math_fround($296 + $292);
    $301 = Math_fround($297 + $293);
    $302 = Math_fround($298 + $294);
    $303 = Math_fround($299 + $295);
    $304 = $300 < $104;
    $$$i$i = $304 ? $300 : $104;
    $305 = $301 < $105;
    $306 = $305 ? $301 : $105;
    $307 = $302 < $106;
    $$1$i$i = $307 ? $302 : $106;
    $308 = $303 < $107;
    $309 = $308 ? $303 : $107;
    $310 = $$$i$i > $108;
    $$$i8$i = $310 ? $$$i$i : $108;
    $311 = $306 > $109;
    $312 = $311 ? $306 : $109;
    $313 = $$1$i$i > $110;
    $$1$i9$i = $313 ? $$1$i$i : $110;
    $314 = $309 > $111;
    $315 = $314 ? $309 : $111;
    $316 = Math_fround($$$i8$i - $185);
    $317 = Math_fround($312 - $187);
    $318 = Math_fround($$1$i9$i - $189);
    $319 = Math_fround($315 - $191);
    $320 = Math_fround($272 * $316);
    $321 = Math_fround($273 * $317);
    $322 = Math_fround($274 * $318);
    $323 = Math_fround($275 * $319);
    $324 = Math_fround($209 + $320);
    $325 = Math_fround($211 + $321);
    $326 = Math_fround($213 + $322);
    $327 = Math_fround($215 + $323);
    $328 = Math_fround($113 * $316);
    $329 = Math_fround($115 * $317);
    $330 = Math_fround($117 * $318);
    $331 = Math_fround($119 * $319);
    $332 = Math_fround($217 + $328);
    $333 = Math_fround($219 + $329);
    $334 = Math_fround($221 + $330);
    $335 = Math_fround($223 + $331);
    $336 = Math_fround($276 * $316);
    $337 = Math_fround($277 * $317);
    $338 = Math_fround($278 * $318);
    $339 = Math_fround($279 * $319);
    $340 = Math_fround($225 + $336);
    $341 = Math_fround($227 + $337);
    $342 = Math_fround($229 + $338);
    $343 = Math_fround($231 + $339);
    $344 = Math_fround($121 * $316);
    $345 = Math_fround($123 * $317);
    $346 = Math_fround($125 * $318);
    $347 = Math_fround($127 * $319);
    $348 = Math_fround($237 + $344);
    $349 = Math_fround($239 + $345);
    $350 = Math_fround($241 + $346);
    $351 = Math_fround($243 + $347);
    $352 = Math_fround($284 * $316);
    $353 = Math_fround($285 * $317);
    $354 = Math_fround($286 * $318);
    $355 = Math_fround($287 * $319);
    $356 = Math_fround($249 + $352);
    $357 = Math_fround($251 + $353);
    $358 = Math_fround($253 + $354);
    $359 = Math_fround($255 + $355);
    $360 = Math_fround($129 * $316);
    $361 = Math_fround($131 * $317);
    $362 = Math_fround($133 * $318);
    $363 = Math_fround($135 * $319);
    $364 = Math_fround($261 + $360);
    $365 = Math_fround($263 + $361);
    $366 = Math_fround($265 + $362);
    $367 = Math_fround($267 + $363);
    HEAPF32[$184>>2] = $$$i8$i;
    HEAPF32[$186>>2] = $312;
    HEAPF32[$188>>2] = $$1$i9$i;
    HEAPF32[$190>>2] = $315;
    $exitcond = ($$sum1|0)==($72|0);
    if ($exitcond) {
     $$lcssa = $327;$$lcssa870 = $326;$$lcssa871 = $325;$$lcssa872 = $324;$$lcssa873 = $343;$$lcssa874 = $342;$$lcssa875 = $341;$$lcssa876 = $340;$$lcssa877 = $359;$$lcssa878 = $358;$$lcssa879 = $357;$$lcssa880 = $356;$$lcssa881 = $335;$$lcssa882 = $334;$$lcssa883 = $333;$$lcssa884 = $332;$$lcssa885 = $351;$$lcssa886 = $350;$$lcssa887 = $349;$$lcssa888 = $348;$$lcssa889 = $367;$$lcssa890 = $366;$$lcssa891 = $365;$$lcssa892 = $364;
     break;
    } else {
     $209 = $324;$211 = $325;$213 = $326;$215 = $327;$217 = $332;$219 = $333;$221 = $334;$223 = $335;$225 = $340;$227 = $341;$229 = $342;$231 = $343;$237 = $348;$239 = $349;$241 = $350;$243 = $351;$249 = $356;$251 = $357;$253 = $358;$255 = $359;$261 = $364;$263 = $365;$265 = $366;$267 = $367;$i$0893 = $$sum1;
    }
   }
  }
  $59 = ($60>>>0)<($57>>>0);
  if ($59) {
   $384 = $$lcssa892;$385 = $$lcssa891;$386 = $$lcssa890;$387 = $$lcssa889;$388 = $$lcssa888;$389 = $$lcssa887;$390 = $$lcssa886;$391 = $$lcssa885;$392 = $$lcssa884;$393 = $$lcssa883;$394 = $$lcssa882;$395 = $$lcssa881;$396 = $$lcssa880;$397 = $$lcssa879;$398 = $$lcssa878;$399 = $$lcssa877;$400 = $$lcssa876;$401 = $$lcssa875;$402 = $$lcssa874;$403 = $$lcssa873;$404 = $$lcssa872;$405 = $$lcssa871;$406 = $$lcssa870;$407 = $$lcssa;$currPtr$0941 = $60;
  } else {
   $$lcssa917 = $$lcssa;$$lcssa918 = $$lcssa870;$$lcssa919 = $$lcssa871;$$lcssa920 = $$lcssa872;$$lcssa921 = $$lcssa873;$$lcssa922 = $$lcssa874;$$lcssa923 = $$lcssa875;$$lcssa924 = $$lcssa876;$$lcssa925 = $$lcssa877;$$lcssa926 = $$lcssa878;$$lcssa927 = $$lcssa879;$$lcssa928 = $$lcssa880;$$lcssa929 = $$lcssa881;$$lcssa930 = $$lcssa882;$$lcssa931 = $$lcssa883;$$lcssa932 = $$lcssa884;$$lcssa933 = $$lcssa885;$$lcssa934 = $$lcssa886;$$lcssa935 = $$lcssa887;$$lcssa936 = $$lcssa888;$$lcssa937 = $$lcssa889;$$lcssa938 = $$lcssa890;$$lcssa939 = $$lcssa891;$$lcssa940 = $$lcssa892;
   break;
  }
 }
 HEAPF32[$0>>2] = $$lcssa920;
 $368 = (($0) + 4|0);
 HEAPF32[$368>>2] = $$lcssa924;
 $369 = (($0) + 8|0);
 HEAPF32[$369>>2] = $$lcssa928;
 HEAPF32[$2>>2] = $$lcssa919;
 $370 = (($2) + 4|0);
 HEAPF32[$370>>2] = $$lcssa923;
 $371 = (($2) + 8|0);
 HEAPF32[$371>>2] = $$lcssa927;
 HEAPF32[$4>>2] = $$lcssa918;
 $372 = (($4) + 4|0);
 HEAPF32[$372>>2] = $$lcssa922;
 $373 = (($4) + 8|0);
 HEAPF32[$373>>2] = $$lcssa926;
 HEAPF32[$6>>2] = $$lcssa917;
 $374 = (($6) + 4|0);
 HEAPF32[$374>>2] = $$lcssa921;
 $375 = (($6) + 8|0);
 HEAPF32[$375>>2] = $$lcssa925;
 HEAPF32[$12>>2] = $$lcssa932;
 $376 = (($0) + 20|0);
 HEAPF32[$376>>2] = $$lcssa936;
 $377 = (($0) + 24|0);
 HEAPF32[$377>>2] = $$lcssa940;
 HEAPF32[$23>>2] = $$lcssa931;
 $378 = (($2) + 20|0);
 HEAPF32[$378>>2] = $$lcssa935;
 $379 = (($2) + 24|0);
 HEAPF32[$379>>2] = $$lcssa939;
 HEAPF32[$34>>2] = $$lcssa930;
 $380 = (($4) + 20|0);
 HEAPF32[$380>>2] = $$lcssa934;
 $381 = (($4) + 24|0);
 HEAPF32[$381>>2] = $$lcssa938;
 HEAPF32[$45>>2] = $$lcssa929;
 $382 = (($6) + 20|0);
 HEAPF32[$382>>2] = $$lcssa933;
 $383 = (($6) + 24|0);
 HEAPF32[$383>>2] = $$lcssa937;
 STACKTOP = sp;return;
}
function __ZN5physx37solveFrictionCoulombPreBlock_ConcludeEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL20solveFriction4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physx43solveFrictionCoulombPreBlock_ConcludeStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$0,$cache) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL26solveFriction4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physx38solveFrictionCoulombPreBlock_WriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$0,$cache,$1,$2,$3) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL20solveFriction4_BlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physx44solveFrictionCoulombPreBlock_WriteBackStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$0,$cache,$1,$2,$3) {
 $desc = $desc|0;
 $0 = $0|0;
 $cache = $cache|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physxL26solveFriction4_StaticBlockEPKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc);
 STACKTOP = sp;return;
}
function __ZN5physx19solveContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i = Math_fround(0), $$$i69 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa518 = Math_fround(0), $$lcssa519 = Math_fround(0), $$lcssa520 = Math_fround(0), $$lcssa521 = Math_fround(0), $$lcssa522 = Math_fround(0), $$lcssa523 = Math_fround(0), $$lcssa531 = Math_fround(0), $$lcssa532 = Math_fround(0), $$lcssa533 = Math_fround(0), $$lcssa534 = Math_fround(0), $$lcssa535 = Math_fround(0), $$lcssa536 = Math_fround(0), $$lcssa537 = Math_fround(0), $$lcssa538 = Math_fround(0), $$lcssa539 = Math_fround(0), $$lcssa540 = Math_fround(0), $$lcssa541 = Math_fround(0);
 var $$lcssa542 = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $$sum516 = 0, $$sum517 = 0, $$sum574 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0;
 var $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0;
 var $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0;
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0;
 var $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0);
 var $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $currPtr$0543 = 0, $exitcond = 0, $i$0524 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$desc>>2]|0;
 $2 = (($desc) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$1>>2]);
 $5 = (($1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$3>>2]);
 $10 = (($3) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($3) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($1) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($1) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($3) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($3) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($3) + 24|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($desc) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 2|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = $29&65535;
 $31 = (($27) + ($30)|0);
 $32 = ($29<<16>>16)==(0);
 if ($32) {
  $$lcssa531 = $8;$$lcssa532 = $6;$$lcssa533 = $4;$$lcssa534 = $13;$$lcssa535 = $11;$$lcssa536 = $9;$$lcssa537 = $19;$$lcssa538 = $17;$$lcssa539 = $15;$$lcssa540 = $25;$$lcssa541 = $23;$$lcssa542 = $21;
  HEAPF32[$1>>2] = $$lcssa533;
  HEAPF32[$5>>2] = $$lcssa532;
  HEAPF32[$7>>2] = $$lcssa531;
  HEAPF32[$3>>2] = $$lcssa536;
  HEAPF32[$10>>2] = $$lcssa535;
  HEAPF32[$12>>2] = $$lcssa534;
  HEAPF32[$14>>2] = $$lcssa539;
  HEAPF32[$16>>2] = $$lcssa538;
  HEAPF32[$18>>2] = $$lcssa537;
  HEAPF32[$20>>2] = $$lcssa542;
  HEAPF32[$22>>2] = $$lcssa541;
  HEAPF32[$24>>2] = $$lcssa540;
  STACKTOP = sp;return;
 } else {
  $173 = $21;$174 = $23;$175 = $25;$176 = $15;$177 = $17;$178 = $19;$56 = $29;$60 = $11;$62 = $9;$64 = $6;$66 = $4;$68 = $13;$71 = $8;$currPtr$0543 = $27;
 }
 while(1) {
  $33 = (($currPtr$0543) + 48|0);
  $34 = (($currPtr$0543) + 1|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35&255;
  $37 = (($currPtr$0543) + 16|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($currPtr$0543) + 20|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($currPtr$0543) + 24|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($currPtr$0543) + 8|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($currPtr$0543) + 12|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($38 * $44);
  $48 = Math_fround($40 * $44);
  $49 = Math_fround($42 * $44);
  $50 = Math_fround($38 * $46);
  $51 = Math_fround($40 * $46);
  $52 = Math_fround($42 * $46);
  $53 = ($36*80)|0;
  $$sum = (($53) + 48)|0;
  $54 = (($currPtr$0543) + ($$sum)|0);
  $55 = $56&65535;
  $$sum1 = (($55) + 32)|0;
  $57 = (($currPtr$0543) + ($$sum1)|0);
  $58 = ($35<<24>>24)==(0);
  if ($58) {
   $$lcssa = $178;$$lcssa518 = $177;$$lcssa519 = $176;$$lcssa520 = $175;$$lcssa521 = $174;$$lcssa522 = $173;$$lcssa523 = Math_fround(0.0);
  } else {
   $59 = Math_fround($60 * $40);
   $61 = Math_fround($62 * $38);
   $63 = Math_fround($64 * $40);
   $65 = Math_fround($66 * $38);
   $67 = Math_fround($68 * $42);
   $69 = Math_fround($61 + $59);
   $70 = Math_fround($71 * $42);
   $72 = Math_fround($65 + $63);
   $73 = Math_fround($69 + $67);
   $74 = Math_fround($72 + $70);
   $101 = $177;$104 = $178;$107 = $173;$109 = $174;$112 = $175;$117 = $74;$119 = $73;$157 = Math_fround(0.0);$99 = $176;$i$0524 = 0;
   while(1) {
    $$sum516 = (($i$0524) + 1)|0;
    $75 = ((($33) + (($$sum516*80)|0)|0) + 48|0);
    $76 = (($33) + (($i$0524*80)|0)|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = ((($33) + (($i$0524*80)|0)|0) + 4|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = ((($33) + (($i$0524*80)|0)|0) + 8|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = ((($33) + (($i$0524*80)|0)|0) + 12|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = ((($33) + (($i$0524*80)|0)|0) + 16|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = ((($33) + (($i$0524*80)|0)|0) + 20|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = ((($33) + (($i$0524*80)|0)|0) + 24|0);
    $89 = Math_fround(HEAPF32[$88>>2]);
    $90 = ((($33) + (($i$0524*80)|0)|0) + 28|0);
    $91 = Math_fround(HEAPF32[$90>>2]);
    $92 = ((($33) + (($i$0524*80)|0)|0) + 36|0);
    $93 = Math_fround(HEAPF32[$92>>2]);
    $94 = ((($33) + (($i$0524*80)|0)|0) + 32|0);
    $95 = Math_fround(HEAPF32[$94>>2]);
    $96 = ((($33) + (($i$0524*80)|0)|0) + 40|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = Math_fround($99 * $77);
    $100 = Math_fround($101 * $79);
    $102 = Math_fround($98 + $100);
    $103 = Math_fround($104 * $81);
    $105 = Math_fround($102 + $103);
    $106 = Math_fround($107 * $85);
    $108 = Math_fround($109 * $87);
    $110 = Math_fround($106 + $108);
    $111 = Math_fround($112 * $89);
    $113 = Math_fround($110 + $111);
    $114 = Math_fround($91 * $93);
    $115 = Math_fround($114 - $95);
    $116 = Math_fround($117 + $105);
    $118 = Math_fround($119 + $113);
    $120 = Math_fround($116 - $118);
    $121 = ((($33) + (($i$0524*80)|0)|0) + 48|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = ((($33) + (($i$0524*80)|0)|0) + 52|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = ((($33) + (($i$0524*80)|0)|0) + 56|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = ((($33) + (($i$0524*80)|0)|0) + 64|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $129 = ((($33) + (($i$0524*80)|0)|0) + 68|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $131 = ((($33) + (($i$0524*80)|0)|0) + 72|0);
    $132 = Math_fround(HEAPF32[$131>>2]);
    $133 = Math_fround($91 * $120);
    $134 = Math_fround($115 - $133);
    $135 = Math_fround(-$83);
    $136 = $134 > $135;
    $$$i69 = $136 ? $134 : $135;
    $137 = Math_fround($83 + $$$i69);
    $138 = $137 > $97;
    $$$i = $138 ? $97 : $137;
    $139 = Math_fround($$$i - $83);
    $140 = Math_fround($122 * $139);
    $141 = Math_fround($124 * $139);
    $142 = Math_fround($126 * $139);
    $143 = Math_fround($99 + $140);
    $144 = Math_fround($101 + $141);
    $145 = Math_fround($104 + $142);
    $146 = Math_fround($128 * $139);
    $147 = Math_fround($130 * $139);
    $148 = Math_fround($132 * $139);
    $149 = Math_fround($107 + $146);
    $150 = Math_fround($109 + $147);
    $151 = Math_fround($112 + $148);
    $152 = Math_fround($44 * $139);
    $153 = Math_fround($117 + $152);
    $154 = Math_fround($46 * $139);
    $155 = Math_fround($119 + $154);
    $156 = Math_fround($157 + $139);
    HEAPF32[$82>>2] = $$$i;
    $158 = (($57) + ($i$0524<<2)|0);
    HEAPF32[$158>>2] = $$$i;
    $$sum517 = (($i$0524) + 32)|0;
    $159 = (($57) + ($$sum517<<2)|0);
    $exitcond = ($$sum516|0)==($36|0);
    if ($exitcond) {
     $$lcssa = $145;$$lcssa518 = $144;$$lcssa519 = $143;$$lcssa520 = $151;$$lcssa521 = $150;$$lcssa522 = $149;$$lcssa523 = $156;
     break;
    } else {
     $101 = $144;$104 = $145;$107 = $149;$109 = $150;$112 = $151;$117 = $153;$119 = $155;$157 = $156;$99 = $143;$i$0524 = $$sum516;
    }
   }
  }
  $160 = Math_fround($47 * $$lcssa523);
  $161 = Math_fround($48 * $$lcssa523);
  $162 = Math_fround($49 * $$lcssa523);
  $163 = Math_fround($66 + $160);
  $164 = Math_fround($64 + $161);
  $165 = Math_fround($71 + $162);
  $166 = Math_fround($50 * $$lcssa523);
  $167 = Math_fround($51 * $$lcssa523);
  $168 = Math_fround($52 * $$lcssa523);
  $169 = Math_fround($62 + $166);
  $170 = Math_fround($60 + $167);
  $171 = Math_fround($68 + $168);
  $172 = ($54>>>0)<($31>>>0);
  if (!($172)) {
   $$lcssa531 = $165;$$lcssa532 = $164;$$lcssa533 = $163;$$lcssa534 = $171;$$lcssa535 = $170;$$lcssa536 = $169;$$lcssa537 = $$lcssa;$$lcssa538 = $$lcssa518;$$lcssa539 = $$lcssa519;$$lcssa540 = $$lcssa520;$$lcssa541 = $$lcssa521;$$lcssa542 = $$lcssa522;
   break;
  }
  $$sum574 = (($53) + 50)|0;
  $$phi$trans$insert = (($currPtr$0543) + ($$sum574)|0);
  $$pre = HEAP16[$$phi$trans$insert>>1]|0;
  $173 = $$lcssa522;$174 = $$lcssa521;$175 = $$lcssa520;$176 = $$lcssa519;$177 = $$lcssa518;$178 = $$lcssa;$56 = $$pre;$60 = $170;$62 = $169;$64 = $164;$66 = $163;$68 = $171;$71 = $165;$currPtr$0543 = $54;
 }
 HEAPF32[$1>>2] = $$lcssa533;
 HEAPF32[$5>>2] = $$lcssa532;
 HEAPF32[$7>>2] = $$lcssa531;
 HEAPF32[$3>>2] = $$lcssa536;
 HEAPF32[$10>>2] = $$lcssa535;
 HEAPF32[$12>>2] = $$lcssa534;
 HEAPF32[$14>>2] = $$lcssa539;
 HEAPF32[$16>>2] = $$lcssa538;
 HEAPF32[$18>>2] = $$lcssa537;
 HEAPF32[$20>>2] = $$lcssa542;
 HEAPF32[$22>>2] = $$lcssa541;
 HEAPF32[$24>>2] = $$lcssa540;
 STACKTOP = sp;return;
}
function __ZN5physx13solveFrictionERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i$i = Math_fround(0), $$$i8$i = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa479 = Math_fround(0), $$lcssa480 = Math_fround(0), $$lcssa481 = Math_fround(0), $$lcssa482 = Math_fround(0), $$lcssa483 = Math_fround(0), $$lcssa484 = Math_fround(0), $$lcssa485 = Math_fround(0), $$lcssa486 = Math_fround(0), $$lcssa487 = Math_fround(0), $$lcssa488 = Math_fround(0), $$lcssa489 = Math_fround(0), $$lcssa502 = Math_fround(0), $$lcssa503 = Math_fround(0), $$lcssa504 = Math_fround(0), $$lcssa505 = Math_fround(0), $$lcssa506 = Math_fround(0), $$lcssa507 = Math_fround(0);
 var $$lcssa508 = Math_fround(0), $$lcssa509 = Math_fround(0), $$lcssa510 = Math_fround(0), $$lcssa511 = Math_fround(0), $$lcssa512 = Math_fround(0), $$lcssa513 = Math_fround(0), $$sum = 0, $$sum1 = 0, $$sum478 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0;
 var $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0;
 var $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0);
 var $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0);
 var $181 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0);
 var $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $currPtr$0514 = 0, $exitcond = 0, $i$0490 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$desc>>2]|0;
 $2 = (($desc) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$1>>2]);
 $5 = (($1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$3>>2]);
 $10 = (($3) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($3) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($1) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($1) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($3) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($3) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($3) + 24|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($desc) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($desc) + 26|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = $29&65535;
 $31 = $30 << 4;
 $32 = (($27) + ($31)|0);
 $33 = ($29<<16>>16)==(0);
 if ($33) {
  $$lcssa502 = $8;$$lcssa503 = $6;$$lcssa504 = $4;$$lcssa505 = $13;$$lcssa506 = $11;$$lcssa507 = $9;$$lcssa508 = $19;$$lcssa509 = $17;$$lcssa510 = $15;$$lcssa511 = $25;$$lcssa512 = $23;$$lcssa513 = $21;
  HEAPF32[$1>>2] = $$lcssa504;
  HEAPF32[$5>>2] = $$lcssa503;
  HEAPF32[$7>>2] = $$lcssa502;
  HEAPF32[$3>>2] = $$lcssa507;
  HEAPF32[$10>>2] = $$lcssa506;
  HEAPF32[$12>>2] = $$lcssa505;
  HEAPF32[$14>>2] = $$lcssa510;
  HEAPF32[$16>>2] = $$lcssa509;
  HEAPF32[$18>>2] = $$lcssa508;
  HEAPF32[$20>>2] = $$lcssa513;
  HEAPF32[$22>>2] = $$lcssa512;
  HEAPF32[$24>>2] = $$lcssa511;
  STACKTOP = sp;return;
 } else {
  $170 = $21;$171 = $23;$172 = $25;$173 = $15;$174 = $17;$175 = $19;$176 = $9;$177 = $11;$178 = $13;$179 = $4;$180 = $6;$181 = $8;$currPtr$0514 = $27;
 }
 while(1) {
  $36 = (($currPtr$0514) + 32|0);
  $37 = (($currPtr$0514) + 1|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = $38&255;
  $40 = $39 << 2;
  $41 = (($40) + 12)|0;
  $42 = $41 & 2032;
  $$sum = (($42) + 32)|0;
  $43 = (($currPtr$0514) + ($$sum)|0);
  $44 = (($currPtr$0514) + 2|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = ($46*96)|0;
  $$sum1 = (($$sum) + ($47))|0;
  $35 = (($currPtr$0514) + ($$sum1)|0);
  $48 = (($currPtr$0514) + 4|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = ($45<<24>>24)==(0);
  if ($50) {
   $$lcssa = $181;$$lcssa479 = $180;$$lcssa480 = $179;$$lcssa481 = $178;$$lcssa482 = $177;$$lcssa483 = $176;$$lcssa484 = $175;$$lcssa485 = $174;$$lcssa486 = $173;$$lcssa487 = $172;$$lcssa488 = $171;$$lcssa489 = $170;
  } else {
   $101 = $177;$104 = $178;$107 = $170;$109 = $171;$112 = $172;$83 = $179;$85 = $180;$88 = $181;$91 = $173;$93 = $174;$96 = $175;$99 = $176;$i$0490 = 0;
   while(1) {
    $$sum478 = (($i$0490) + 1)|0;
    $51 = ((($43) + (($$sum478*96)|0)|0) + 32|0);
    $52 = (($43) + (($i$0490*96)|0)|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = ((($43) + (($i$0490*96)|0)|0) + 4|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = ((($43) + (($i$0490*96)|0)|0) + 8|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = ((($43) + (($i$0490*96)|0)|0) + 12|0);
    $59 = ((($43) + (($i$0490*96)|0)|0) + 16|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = ((($43) + (($i$0490*96)|0)|0) + 20|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = ((($43) + (($i$0490*96)|0)|0) + 24|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = ((($43) + (($i$0490*96)|0)|0) + 28|0);
    $66 = ((($43) + (($i$0490*96)|0)|0) + 32|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = ((($43) + (($i$0490*96)|0)|0) + 36|0);
    $69 = Math_fround(HEAPF32[$68>>2]);
    $70 = ((($43) + (($i$0490*96)|0)|0) + 40|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = ((($43) + (($i$0490*96)|0)|0) + 44|0);
    $73 = Math_fround(HEAPF32[$58>>2]);
    $74 = Math_fround(HEAPF32[$65>>2]);
    $75 = Math_fround(HEAPF32[$72>>2]);
    $76 = ((($43) + (($i$0490*96)|0)|0) + 80|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($36) + ($77<<2)|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = Math_fround($49 * $79);
    $81 = Math_fround(-$80);
    $82 = Math_fround($83 * $53);
    $84 = Math_fround($85 * $55);
    $86 = Math_fround($82 + $84);
    $87 = Math_fround($88 * $57);
    $89 = Math_fround($86 + $87);
    $90 = Math_fround($91 * $60);
    $92 = Math_fround($93 * $62);
    $94 = Math_fround($90 + $92);
    $95 = Math_fround($96 * $64);
    $97 = Math_fround($94 + $95);
    $98 = Math_fround($99 * $53);
    $100 = Math_fround($101 * $55);
    $102 = Math_fround($98 + $100);
    $103 = Math_fround($104 * $57);
    $105 = Math_fround($102 + $103);
    $106 = Math_fround($107 * $67);
    $108 = Math_fround($109 * $69);
    $110 = Math_fround($106 + $108);
    $111 = Math_fround($112 * $71);
    $113 = Math_fround($110 + $111);
    $114 = Math_fround($89 + $97);
    $115 = Math_fround($105 + $113);
    $116 = Math_fround($114 - $115);
    $117 = ((($43) + (($i$0490*96)|0)|0) + 48|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = ((($43) + (($i$0490*96)|0)|0) + 52|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = ((($43) + (($i$0490*96)|0)|0) + 56|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = ((($43) + (($i$0490*96)|0)|0) + 60|0);
    $124 = ((($43) + (($i$0490*96)|0)|0) + 64|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = ((($43) + (($i$0490*96)|0)|0) + 68|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = ((($43) + (($i$0490*96)|0)|0) + 72|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = ((($43) + (($i$0490*96)|0)|0) + 76|0);
    $131 = Math_fround(HEAPF32[$123>>2]);
    $132 = Math_fround($53 * $131);
    $133 = Math_fround($55 * $131);
    $134 = Math_fround($57 * $131);
    $135 = Math_fround(HEAPF32[$130>>2]);
    $136 = Math_fround($53 * $135);
    $137 = Math_fround($55 * $135);
    $138 = Math_fround($57 * $135);
    $139 = Math_fround($74 * $75);
    $140 = Math_fround($73 - $139);
    $141 = Math_fround($74 * $116);
    $142 = Math_fround($141 + $140);
    $143 = $142 > $80;
    $$$i$i = $143 ? $80 : $142;
    $144 = $$$i$i > $81;
    $$$i8$i = $144 ? $$$i$i : $81;
    $145 = Math_fround($$$i8$i - $73);
    $146 = Math_fround($145 * $132);
    $147 = Math_fround($145 * $133);
    $148 = Math_fround($145 * $134);
    $149 = Math_fround($83 + $146);
    $150 = Math_fround($85 + $147);
    $151 = Math_fround($88 + $148);
    $152 = Math_fround($145 * $136);
    $153 = Math_fround($145 * $137);
    $154 = Math_fround($145 * $138);
    $155 = Math_fround($99 + $152);
    $156 = Math_fround($101 + $153);
    $157 = Math_fround($104 + $154);
    $158 = Math_fround($118 * $145);
    $159 = Math_fround($120 * $145);
    $160 = Math_fround($122 * $145);
    $161 = Math_fround($91 + $158);
    $162 = Math_fround($93 + $159);
    $163 = Math_fround($96 + $160);
    $164 = Math_fround($125 * $145);
    $165 = Math_fround($127 * $145);
    $166 = Math_fround($129 * $145);
    $167 = Math_fround($107 + $164);
    $168 = Math_fround($109 + $165);
    $169 = Math_fround($112 + $166);
    HEAPF32[$58>>2] = $$$i8$i;
    $exitcond = ($$sum478|0)==($46|0);
    if ($exitcond) {
     $$lcssa = $151;$$lcssa479 = $150;$$lcssa480 = $149;$$lcssa481 = $157;$$lcssa482 = $156;$$lcssa483 = $155;$$lcssa484 = $163;$$lcssa485 = $162;$$lcssa486 = $161;$$lcssa487 = $169;$$lcssa488 = $168;$$lcssa489 = $167;
     break;
    } else {
     $101 = $156;$104 = $157;$107 = $167;$109 = $168;$112 = $169;$83 = $149;$85 = $150;$88 = $151;$91 = $161;$93 = $162;$96 = $163;$99 = $155;$i$0490 = $$sum478;
    }
   }
  }
  $34 = ($35>>>0)<($32>>>0);
  if ($34) {
   $170 = $$lcssa489;$171 = $$lcssa488;$172 = $$lcssa487;$173 = $$lcssa486;$174 = $$lcssa485;$175 = $$lcssa484;$176 = $$lcssa483;$177 = $$lcssa482;$178 = $$lcssa481;$179 = $$lcssa480;$180 = $$lcssa479;$181 = $$lcssa;$currPtr$0514 = $35;
  } else {
   $$lcssa502 = $$lcssa;$$lcssa503 = $$lcssa479;$$lcssa504 = $$lcssa480;$$lcssa505 = $$lcssa481;$$lcssa506 = $$lcssa482;$$lcssa507 = $$lcssa483;$$lcssa508 = $$lcssa484;$$lcssa509 = $$lcssa485;$$lcssa510 = $$lcssa486;$$lcssa511 = $$lcssa487;$$lcssa512 = $$lcssa488;$$lcssa513 = $$lcssa489;
   break;
  }
 }
 HEAPF32[$1>>2] = $$lcssa504;
 HEAPF32[$5>>2] = $$lcssa503;
 HEAPF32[$7>>2] = $$lcssa502;
 HEAPF32[$3>>2] = $$lcssa507;
 HEAPF32[$10>>2] = $$lcssa506;
 HEAPF32[$12>>2] = $$lcssa505;
 HEAPF32[$14>>2] = $$lcssa510;
 HEAPF32[$16>>2] = $$lcssa509;
 HEAPF32[$18>>2] = $$lcssa508;
 HEAPF32[$20>>2] = $$lcssa513;
 HEAPF32[$22>>2] = $$lcssa512;
 HEAPF32[$24>>2] = $$lcssa511;
 STACKTOP = sp;return;
}
function __ZN5physx27solveContactCoulomb_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i = Math_fround(0), $$$i47 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa319 = Math_fround(0), $$lcssa320 = Math_fround(0), $$lcssa321 = Math_fround(0), $$lcssa326 = Math_fround(0), $$lcssa327 = Math_fround(0), $$lcssa328 = Math_fround(0), $$lcssa329 = Math_fround(0), $$lcssa330 = Math_fround(0), $$lcssa331 = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $$sum318 = 0, $$sum351 = 0, $1 = 0, $10 = Math_fround(0);
 var $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0);
 var $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0);
 var $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0);
 var $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $currPtr$0332 = 0, $exitcond = 0, $i$0322 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$desc>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($1) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($1) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($desc) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 2|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = (($14) + ($17)|0);
 $19 = ($16<<16>>16)==(0);
 if ($19) {
  $$lcssa326 = $6;$$lcssa327 = $4;$$lcssa328 = $2;$$lcssa329 = $12;$$lcssa330 = $10;$$lcssa331 = $8;
  HEAPF32[$1>>2] = $$lcssa328;
  HEAPF32[$3>>2] = $$lcssa327;
  HEAPF32[$5>>2] = $$lcssa326;
  HEAPF32[$7>>2] = $$lcssa331;
  HEAPF32[$9>>2] = $$lcssa330;
  HEAPF32[$11>>2] = $$lcssa329;
  STACKTOP = sp;return;
 } else {
  $111 = $8;$112 = $10;$113 = $12;$27 = $16;$42 = $4;$44 = $2;$46 = $6;$currPtr$0332 = $14;
 }
 while(1) {
  $20 = (($currPtr$0332) + 48|0);
  $21 = (($currPtr$0332) + 1|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = ($23*80)|0;
  $$sum = (($24) + 48)|0;
  $25 = (($currPtr$0332) + ($$sum)|0);
  $26 = $27&65535;
  $$sum1 = (($26) + 32)|0;
  $28 = (($currPtr$0332) + ($$sum1)|0);
  $29 = (($currPtr$0332) + 16|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($currPtr$0332) + 20|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($currPtr$0332) + 24|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($currPtr$0332) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($30 * $36);
  $38 = Math_fround($32 * $36);
  $39 = Math_fround($34 * $36);
  $40 = ($22<<24>>24)==(0);
  if ($40) {
   $$lcssa = $113;$$lcssa319 = $112;$$lcssa320 = $111;$$lcssa321 = Math_fround(0.0);
  } else {
   $41 = Math_fround($42 * $32);
   $43 = Math_fround($44 * $30);
   $45 = Math_fround($46 * $34);
   $47 = Math_fround($43 + $41);
   $48 = Math_fround($47 + $45);
   $101 = Math_fround(0.0);$74 = $111;$76 = $112;$79 = $113;$82 = $48;$i$0322 = 0;
   while(1) {
    $49 = (($i$0322) + 1)|0;
    $50 = (($20) + (($49*80)|0)|0);
    $51 = (($20) + (($i$0322*80)|0)|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = ((($20) + (($i$0322*80)|0)|0) + 4|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = ((($20) + (($i$0322*80)|0)|0) + 8|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = ((($20) + (($i$0322*80)|0)|0) + 12|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = ((($20) + (($i$0322*80)|0)|0) + 28|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = ((($20) + (($i$0322*80)|0)|0) + 48|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = ((($20) + (($i$0322*80)|0)|0) + 52|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = ((($20) + (($i$0322*80)|0)|0) + 56|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($20) + (($i$0322*80)|0)|0) + 36|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = ((($20) + (($i$0322*80)|0)|0) + 32|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = ((($20) + (($i$0322*80)|0)|0) + 40|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = Math_fround($74 * $52);
    $75 = Math_fround($76 * $54);
    $77 = Math_fround($73 + $75);
    $78 = Math_fround($79 * $56);
    $80 = Math_fround($77 + $78);
    $81 = Math_fround($82 + $80);
    $83 = Math_fround($60 * $68);
    $84 = Math_fround($83 - $70);
    $85 = Math_fround($60 * $81);
    $86 = Math_fround($84 - $85);
    $87 = Math_fround(-$58);
    $88 = $86 > $87;
    $$$i47 = $88 ? $86 : $87;
    $89 = Math_fround($58 + $$$i47);
    $90 = $89 > $72;
    $$$i = $90 ? $72 : $89;
    $91 = Math_fround($$$i - $58);
    $92 = Math_fround($36 * $91);
    $93 = Math_fround($82 + $92);
    $94 = Math_fround($62 * $91);
    $95 = Math_fround($64 * $91);
    $96 = Math_fround($66 * $91);
    $97 = Math_fround($74 + $94);
    $98 = Math_fround($76 + $95);
    $99 = Math_fround($79 + $96);
    $100 = Math_fround($101 + $91);
    HEAPF32[$57>>2] = $$$i;
    $102 = (($28) + ($i$0322<<2)|0);
    HEAPF32[$102>>2] = $$$i;
    $$sum318 = (($i$0322) + 32)|0;
    $103 = (($28) + ($$sum318<<2)|0);
    $exitcond = ($49|0)==($23|0);
    if ($exitcond) {
     $$lcssa = $99;$$lcssa319 = $98;$$lcssa320 = $97;$$lcssa321 = $100;
     break;
    } else {
     $101 = $100;$74 = $97;$76 = $98;$79 = $99;$82 = $93;$i$0322 = $49;
    }
   }
  }
  $104 = Math_fround($37 * $$lcssa321);
  $105 = Math_fround($38 * $$lcssa321);
  $106 = Math_fround($39 * $$lcssa321);
  $107 = Math_fround($44 + $104);
  $108 = Math_fround($42 + $105);
  $109 = Math_fround($46 + $106);
  $110 = ($25>>>0)<($18>>>0);
  if (!($110)) {
   $$lcssa326 = $109;$$lcssa327 = $108;$$lcssa328 = $107;$$lcssa329 = $$lcssa;$$lcssa330 = $$lcssa319;$$lcssa331 = $$lcssa320;
   break;
  }
  $$sum351 = (($24) + 50)|0;
  $$phi$trans$insert = (($currPtr$0332) + ($$sum351)|0);
  $$pre = HEAP16[$$phi$trans$insert>>1]|0;
  $111 = $$lcssa320;$112 = $$lcssa319;$113 = $$lcssa;$27 = $$pre;$42 = $108;$44 = $107;$46 = $109;$currPtr$0332 = $25;
 }
 HEAPF32[$1>>2] = $$lcssa328;
 HEAPF32[$3>>2] = $$lcssa327;
 HEAPF32[$5>>2] = $$lcssa326;
 HEAPF32[$7>>2] = $$lcssa331;
 HEAPF32[$9>>2] = $$lcssa330;
 HEAPF32[$11>>2] = $$lcssa329;
 STACKTOP = sp;return;
}
function __ZN5physx21solveFriction_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i$i = Math_fround(0), $$$i8$i = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa292 = Math_fround(0), $$lcssa293 = Math_fround(0), $$lcssa294 = Math_fround(0), $$lcssa295 = Math_fround(0), $$lcssa296 = Math_fround(0), $$lcssa303 = Math_fround(0), $$lcssa304 = Math_fround(0), $$lcssa305 = Math_fround(0), $$lcssa306 = Math_fround(0), $$lcssa307 = Math_fround(0), $$lcssa308 = Math_fround(0), $$sum = 0, $$sum1 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0);
 var $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $currPtr$0309 = 0, $exitcond = 0, $i$0297 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$desc>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($1) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($1) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($desc) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($desc) + 26|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = $17 << 4;
 $19 = (($14) + ($18)|0);
 $20 = ($16<<16>>16)==(0);
 if ($20) {
  $$lcssa303 = $6;$$lcssa304 = $4;$$lcssa305 = $2;$$lcssa306 = $12;$$lcssa307 = $10;$$lcssa308 = $8;
  HEAPF32[$1>>2] = $$lcssa305;
  HEAPF32[$3>>2] = $$lcssa304;
  HEAPF32[$5>>2] = $$lcssa303;
  HEAPF32[$7>>2] = $$lcssa308;
  HEAPF32[$9>>2] = $$lcssa307;
  HEAPF32[$11>>2] = $$lcssa306;
  STACKTOP = sp;return;
 } else {
  $111 = $8;$112 = $10;$113 = $12;$114 = $2;$115 = $4;$116 = $6;$currPtr$0309 = $14;
 }
 while(1) {
  $23 = (($currPtr$0309) + 2|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = (($currPtr$0309) + 32|0);
  $27 = (($currPtr$0309) + 1|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = $29 << 2;
  $31 = (($30) + 12)|0;
  $32 = $31 & 2032;
  $$sum = (($32) + 32)|0;
  $33 = (($currPtr$0309) + ($$sum)|0);
  $34 = ($25*96)|0;
  $$sum1 = (($$sum) + ($34))|0;
  $22 = (($currPtr$0309) + ($$sum1)|0);
  $35 = (($currPtr$0309) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = ($24<<24>>24)==(0);
  if ($37) {
   $$lcssa = $116;$$lcssa292 = $115;$$lcssa293 = $114;$$lcssa294 = $113;$$lcssa295 = $112;$$lcssa296 = $111;
  } else {
   $65 = $114;$67 = $115;$70 = $116;$73 = $111;$75 = $112;$78 = $113;$i$0297 = 0;
   while(1) {
    $38 = (($i$0297) + 1)|0;
    $39 = (($33) + (($38*96)|0)|0);
    $40 = (($33) + (($i$0297*96)|0)|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = ((($33) + (($i$0297*96)|0)|0) + 4|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = ((($33) + (($i$0297*96)|0)|0) + 8|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = ((($33) + (($i$0297*96)|0)|0) + 12|0);
    $47 = ((($33) + (($i$0297*96)|0)|0) + 16|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = ((($33) + (($i$0297*96)|0)|0) + 20|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = ((($33) + (($i$0297*96)|0)|0) + 24|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = ((($33) + (($i$0297*96)|0)|0) + 28|0);
    $54 = Math_fround(HEAPF32[$46>>2]);
    $55 = Math_fround(HEAPF32[$53>>2]);
    $56 = ((($33) + (($i$0297*96)|0)|0) + 44|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = ((($33) + (($i$0297*96)|0)|0) + 80|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($26) + ($59<<2)|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = Math_fround($36 * $61);
    $63 = Math_fround(-$62);
    $64 = Math_fround($65 * $41);
    $66 = Math_fround($67 * $43);
    $68 = Math_fround($64 + $66);
    $69 = Math_fround($70 * $45);
    $71 = Math_fround($68 + $69);
    $72 = Math_fround($73 * $48);
    $74 = Math_fround($75 * $50);
    $76 = Math_fround($72 + $74);
    $77 = Math_fround($78 * $52);
    $79 = Math_fround($76 + $77);
    $80 = Math_fround($71 + $79);
    $81 = ((($33) + (($i$0297*96)|0)|0) + 48|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = ((($33) + (($i$0297*96)|0)|0) + 52|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = ((($33) + (($i$0297*96)|0)|0) + 56|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $87 = ((($33) + (($i$0297*96)|0)|0) + 60|0);
    $88 = Math_fround(HEAPF32[$87>>2]);
    $89 = Math_fround($41 * $88);
    $90 = Math_fround($43 * $88);
    $91 = Math_fround($45 * $88);
    $92 = Math_fround($55 * $57);
    $93 = Math_fround($54 - $92);
    $94 = Math_fround($55 * $80);
    $95 = Math_fround($94 + $93);
    $96 = $95 > $62;
    $$$i$i = $96 ? $62 : $95;
    $97 = $$$i$i > $63;
    $$$i8$i = $97 ? $$$i$i : $63;
    $98 = Math_fround($$$i8$i - $54);
    $99 = Math_fround($89 * $98);
    $100 = Math_fround($90 * $98);
    $101 = Math_fround($91 * $98);
    $102 = Math_fround($65 + $99);
    $103 = Math_fround($67 + $100);
    $104 = Math_fround($70 + $101);
    $105 = Math_fround($82 * $98);
    $106 = Math_fround($84 * $98);
    $107 = Math_fround($86 * $98);
    $108 = Math_fround($73 + $105);
    $109 = Math_fround($75 + $106);
    $110 = Math_fround($78 + $107);
    HEAPF32[$46>>2] = $$$i8$i;
    $exitcond = ($38|0)==($25|0);
    if ($exitcond) {
     $$lcssa = $104;$$lcssa292 = $103;$$lcssa293 = $102;$$lcssa294 = $110;$$lcssa295 = $109;$$lcssa296 = $108;
     break;
    } else {
     $65 = $102;$67 = $103;$70 = $104;$73 = $108;$75 = $109;$78 = $110;$i$0297 = $38;
    }
   }
  }
  $21 = ($22>>>0)<($19>>>0);
  if ($21) {
   $111 = $$lcssa296;$112 = $$lcssa295;$113 = $$lcssa294;$114 = $$lcssa293;$115 = $$lcssa292;$116 = $$lcssa;$currPtr$0309 = $22;
  } else {
   $$lcssa303 = $$lcssa;$$lcssa304 = $$lcssa292;$$lcssa305 = $$lcssa293;$$lcssa306 = $$lcssa294;$$lcssa307 = $$lcssa295;$$lcssa308 = $$lcssa296;
   break;
  }
 }
 HEAPF32[$1>>2] = $$lcssa305;
 HEAPF32[$3>>2] = $$lcssa304;
 HEAPF32[$5>>2] = $$lcssa303;
 HEAPF32[$7>>2] = $$lcssa308;
 HEAPF32[$9>>2] = $$lcssa307;
 HEAPF32[$11>>2] = $$lcssa306;
 STACKTOP = sp;return;
}
function __ZN5physx22concludeContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i = Math_fround(0), $$sum = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cPtr$018 = 0, $cPtr$1$lcssa = 0, $cPtr$117 = 0, $exitcond = 0, $i$016 = 0, $scevgep20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($desc) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 2|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = (($2) + ($5)|0);
 $7 = ($4<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $cPtr$018 = $2;
 }
 while(1) {
  $10 = (($cPtr$018) + 48|0);
  $11 = (($cPtr$018) + 1|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = (($cPtr$018) + 176|0);
  $14 = (($cPtr$018) + 304|0);
  $15 = (($cPtr$018) + 432|0);
  $16 = HEAP8[$cPtr$018>>0]|0;
  $17 = ($16<<24>>24)==(3);
  $18 = $17 ? 112 : 80;
  $19 = ($12<<24>>24)==(0);
  if ($19) {
   $cPtr$1$lcssa = $10;
  } else {
   $20 = $12&255;
   $8 = Math_imul($18, $20)|0;
   $cPtr$117 = $10;$i$016 = 0;
   while(1) {
    $21 = (($cPtr$117) + ($18)|0);
    $22 = (($cPtr$117) + 32|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = $23 > Math_fround(0.0);
    $$$i = $24 ? $23 : Math_fround(0.0);
    $25 = (($cPtr$117) + 44|0);
    HEAPF32[$22>>2] = $$$i;
    HEAPF32[$25>>2] = Math_fround(0.0);
    $26 = (($i$016) + 1)|0;
    $exitcond = ($26|0)==($20|0);
    if ($exitcond) {
     break;
    } else {
     $cPtr$117 = $21;$i$016 = $26;
    }
   }
   $$sum = (($8) + 48)|0;
   $scevgep20 = (($cPtr$018) + ($$sum)|0);
   $cPtr$1$lcssa = $scevgep20;
  }
  $9 = ($cPtr$1$lcssa>>>0)<($6>>>0);
  if ($9) {
   $cPtr$018 = $cPtr$1$lcssa;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23writeBackContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($desc,$cache,$bd0,$bd1) {
 $desc = $desc|0;
 $cache = $cache|0;
 $bd0 = $bd0|0;
 $bd1 = $bd1|0;
 var $$sum = 0, $$sum45 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cPtr$028 = 0, $cPtr$1$lcssa = 0, $cPtr$121 = 0, $i$020 = 0, $scevgep = 0, $scevgep44 = 0;
 var $umax = 0, $vForceWriteback$027 = 0, $vForceWriteback$1$lcssa = 0, $vForceWriteback$119 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 2|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($1) + ($4)|0);
 $6 = HEAP8[$1>>0]|0;
 $7 = ($6<<24>>24)==(3);
 $8 = $7 ? 112 : 80;
 $9 = ($3<<16>>16)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($desc) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $cPtr$028 = $1;$vForceWriteback$027 = $11;
 while(1) {
  $14 = (($cPtr$028) + 48|0);
  $15 = (($cPtr$028) + 1|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16&255;
  $18 = (($cPtr$028) + 304|0);
  $19 = (($cPtr$028) + 432|0);
  $20 = ($vForceWriteback$027|0)==(0|0);
  if ($20) {
   $29 = Math_imul($17, $8)|0;
   $$sum = (($29) + 48)|0;
   $30 = (($cPtr$028) + ($$sum)|0);
   $31 = ($30>>>0)<($5>>>0);
   if ($31) {
    $cPtr$028 = $30;$vForceWriteback$027 = 0;
    continue;
   } else {
    label = 10;
    break;
   }
  }
  $21 = ($16<<24>>24)==(0);
  if ($21) {
   $cPtr$1$lcssa = $14;$vForceWriteback$1$lcssa = $vForceWriteback$027;
  } else {
   $22 = ($17>>>0)>(1);
   $umax = $22 ? $17 : 1;
   $12 = Math_imul($8, $umax)|0;
   $cPtr$121 = $14;$i$020 = 0;$vForceWriteback$119 = $vForceWriteback$027;
   while(1) {
    $23 = (($cPtr$121) + ($8)|0);
    $24 = (($cPtr$121) + 12|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    HEAPF32[$vForceWriteback$119>>2] = $25;
    $26 = (($vForceWriteback$119) + 4|0);
    $27 = (($i$020) + 1)|0;
    $28 = ($27>>>0)<($17>>>0);
    if ($28) {
     $cPtr$121 = $23;$i$020 = $27;$vForceWriteback$119 = $26;
    } else {
     break;
    }
   }
   $scevgep = (($vForceWriteback$027) + ($umax<<2)|0);
   $$sum45 = (($12) + 48)|0;
   $scevgep44 = (($cPtr$028) + ($$sum45)|0);
   $cPtr$1$lcssa = $scevgep44;$vForceWriteback$1$lcssa = $scevgep;
  }
  $13 = ($cPtr$1$lcssa>>>0)<($5>>>0);
  if ($13) {
   $cPtr$028 = $cPtr$1$lcssa;$vForceWriteback$027 = $vForceWriteback$1$lcssa;
  } else {
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx18solveFrictionBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx13solveFrictionERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx27solveFrictionBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$0,$1,$2) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($constraintCount|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $4 = (($desc) + ($a$01<<5)|0);
  __ZN5physx13solveFrictionERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($4,0);
  $5 = (($a$01) + 1)|0;
  $exitcond = ($5|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx26solveFriction_BStaticBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx21solveFriction_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx35solveFriction_BStaticBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$0,$1,$2) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($constraintCount|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $4 = (($desc) + ($a$01<<5)|0);
  __ZN5physx21solveFriction_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($4,0);
  $5 = (($a$01) + 1)|0;
  $exitcond = ($5|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx24solveContactCoulombBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx19solveContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx32solveContactCoulombConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $cPtr$018$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$117$i = 0, $exitcond = 0, $exitcond$i = 0, $i$016$i = 0, $scevgep20$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx19solveContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = ((($desc) + ($a$01<<5)|0) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 2|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = $5&65535;
  $7 = (($3) + ($6)|0);
  $8 = ($5<<16>>16)==(0);
  if (!($8)) {
   $cPtr$018$i = $3;
   while(1) {
    $13 = (($cPtr$018$i) + 48|0);
    $14 = (($cPtr$018$i) + 1|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = (($cPtr$018$i) + 176|0);
    $17 = (($cPtr$018$i) + 304|0);
    $18 = (($cPtr$018$i) + 432|0);
    $19 = HEAP8[$cPtr$018$i>>0]|0;
    $20 = ($19<<24>>24)==(3);
    $10 = $20 ? 112 : 80;
    $21 = ($15<<24>>24)==(0);
    if ($21) {
     $cPtr$1$lcssa$i = $13;
    } else {
     $11 = $15&255;
     $cPtr$117$i = $13;$i$016$i = 0;
     while(1) {
      $22 = (($cPtr$117$i) + ($10)|0);
      $23 = (($cPtr$117$i) + 32|0);
      $24 = Math_fround(HEAPF32[$23>>2]);
      $25 = $24 > Math_fround(0.0);
      $$$i$i = $25 ? $24 : Math_fround(0.0);
      $26 = (($cPtr$117$i) + 44|0);
      HEAPF32[$23>>2] = $$$i$i;
      HEAPF32[$26>>2] = Math_fround(0.0);
      $27 = (($i$016$i) + 1)|0;
      $exitcond$i = ($27|0)==($11|0);
      if ($exitcond$i) {
       break;
      } else {
       $cPtr$117$i = $22;$i$016$i = $27;
      }
     }
     $9 = Math_imul($10, $11)|0;
     $$sum$i = (($9) + 48)|0;
     $scevgep20$i = (($cPtr$018$i) + ($$sum$i)|0);
     $cPtr$1$lcssa$i = $scevgep20$i;
    }
    $12 = ($cPtr$1$lcssa$i>>>0)<($7>>>0);
    if ($12) {
     $cPtr$018$i = $cPtr$1$lcssa$i;
    } else {
     break;
    }
   }
  }
  $28 = (($a$01) + 1)|0;
  $exitcond = ($28|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $28;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx33solveContactCoulombBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$thresholdStream,$0,$outThresholdPairs) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $0 = $0|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $$sum$i = 0, $$sum45$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$02 = 0, $a1$01 = 0, $cPtr$028$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$121$i = 0, $exitcond = 0;
 var $exitcond6 = 0, $i$020$i = 0, $scevgep$i = 0, $scevgep44$i = 0, $umax$i = 0, $vForceWriteback$027$i = 0, $vForceWriteback$1$lcssa$i = 0, $vForceWriteback$119$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($constraintCount|0)==(0);
 if (!($1)) {
  $a$02 = 0;
  while(1) {
   $2 = (($desc) + ($a$02<<5)|0);
   __ZN5physx19solveContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($2,0);
   $3 = ((($desc) + ($a$02<<5)|0) + 16|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 2|0);
   $6 = HEAP16[$5>>1]|0;
   $7 = $6&65535;
   $8 = (($4) + ($7)|0);
   $9 = HEAP8[$4>>0]|0;
   $10 = ($9<<24>>24)==(3);
   $11 = $10 ? 112 : 80;
   $12 = ($6<<16>>16)==(0);
   if (!($12)) {
    $13 = ((($desc) + ($a$02<<5)|0) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $cPtr$028$i = $4;$vForceWriteback$027$i = $14;
    while(1) {
     $17 = (($cPtr$028$i) + 48|0);
     $18 = (($cPtr$028$i) + 1|0);
     $19 = HEAP8[$18>>0]|0;
     $20 = $19&255;
     $21 = (($cPtr$028$i) + 304|0);
     $22 = (($cPtr$028$i) + 432|0);
     $23 = ($vForceWriteback$027$i|0)==(0|0);
     if ($23) {
      $31 = Math_imul($20, $11)|0;
      $$sum$i = (($31) + 48)|0;
      $32 = (($cPtr$028$i) + ($$sum$i)|0);
      $33 = ($32>>>0)<($8>>>0);
      if ($33) {
       $cPtr$028$i = $32;$vForceWriteback$027$i = 0;
       continue;
      } else {
       break;
      }
     }
     $24 = ($19<<24>>24)==(0);
     if ($24) {
      $cPtr$1$lcssa$i = $17;$vForceWriteback$1$lcssa$i = $vForceWriteback$027$i;
     } else {
      $25 = ($20>>>0)>(1);
      $umax$i = $25 ? $20 : 1;
      $cPtr$121$i = $17;$i$020$i = 0;$vForceWriteback$119$i = $vForceWriteback$027$i;
      while(1) {
       $26 = (($cPtr$121$i) + ($11)|0);
       $27 = (($cPtr$121$i) + 12|0);
       $28 = Math_fround(HEAPF32[$27>>2]);
       HEAPF32[$vForceWriteback$119$i>>2] = $28;
       $29 = (($vForceWriteback$119$i) + 4|0);
       $30 = (($i$020$i) + 1)|0;
       $exitcond = ($30|0)==($20|0);
       if ($exitcond) {
        break;
       } else {
        $cPtr$121$i = $26;$i$020$i = $30;$vForceWriteback$119$i = $29;
       }
      }
      $15 = Math_imul($umax$i, $11)|0;
      $scevgep$i = (($vForceWriteback$027$i) + ($umax$i<<2)|0);
      $$sum45$i = (($15) + 48)|0;
      $scevgep44$i = (($cPtr$028$i) + ($$sum45$i)|0);
      $cPtr$1$lcssa$i = $scevgep44$i;$vForceWriteback$1$lcssa$i = $scevgep$i;
     }
     $16 = ($cPtr$1$lcssa$i>>>0)<($8>>>0);
     if ($16) {
      $cPtr$028$i = $cPtr$1$lcssa$i;$vForceWriteback$027$i = $vForceWriteback$1$lcssa$i;
     } else {
      break;
     }
    }
   }
   $34 = (($a$02) + 1)|0;
   $exitcond6 = ($34|0)==($constraintCount|0);
   if ($exitcond6) {
    break;
   } else {
    $a$02 = $34;
   }
  }
 }
 $35 = (($cache) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($cache) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + -4)|0;
 $40 = ($36>>>0)>($39>>>0);
 if (!($40)) {
  STACKTOP = sp;return;
 }
 $41 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$36)|0);
 $42 = HEAP32[$35>>2]|0;
 $43 = (($41) - ($42))|0;
 $44 = ($42|0)==(0);
 if (!($44)) {
  $45 = (($cache) + 4|0);
  $a1$01 = 0;
  while(1) {
   $46 = (($43) + ($a1$01))|0;
   $47 = (($thresholdStream) + ($46<<4)|0);
   $48 = HEAP32[$45>>2]|0;
   $49 = (($48) + ($a1$01<<4)|0);
   ;HEAP32[$47+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$47+12>>2]=HEAP32[$49+12>>2]|0;
   $50 = (($a1$01) + 1)|0;
   $51 = HEAP32[$35>>2]|0;
   $52 = ($50>>>0)<($51>>>0);
   if ($52) {
    $a1$01 = $50;
   } else {
    break;
   }
  }
 }
 HEAP32[$35>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx32solveContactCoulomb_BStaticBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx27solveContactCoulomb_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx40solveContactCoulomb_BStaticConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$01 = 0, $cPtr$018$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$117$i = 0, $exitcond = 0, $exitcond$i = 0, $i$016$i = 0, $scevgep20$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx27solveContactCoulomb_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = ((($desc) + ($a$01<<5)|0) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 2|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = $5&65535;
  $7 = (($3) + ($6)|0);
  $8 = ($5<<16>>16)==(0);
  if (!($8)) {
   $cPtr$018$i = $3;
   while(1) {
    $13 = (($cPtr$018$i) + 48|0);
    $14 = (($cPtr$018$i) + 1|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = (($cPtr$018$i) + 176|0);
    $17 = (($cPtr$018$i) + 304|0);
    $18 = (($cPtr$018$i) + 432|0);
    $19 = HEAP8[$cPtr$018$i>>0]|0;
    $20 = ($19<<24>>24)==(3);
    $10 = $20 ? 112 : 80;
    $21 = ($15<<24>>24)==(0);
    if ($21) {
     $cPtr$1$lcssa$i = $13;
    } else {
     $11 = $15&255;
     $cPtr$117$i = $13;$i$016$i = 0;
     while(1) {
      $22 = (($cPtr$117$i) + ($10)|0);
      $23 = (($cPtr$117$i) + 32|0);
      $24 = Math_fround(HEAPF32[$23>>2]);
      $25 = $24 > Math_fround(0.0);
      $$$i$i = $25 ? $24 : Math_fround(0.0);
      $26 = (($cPtr$117$i) + 44|0);
      HEAPF32[$23>>2] = $$$i$i;
      HEAPF32[$26>>2] = Math_fround(0.0);
      $27 = (($i$016$i) + 1)|0;
      $exitcond$i = ($27|0)==($11|0);
      if ($exitcond$i) {
       break;
      } else {
       $cPtr$117$i = $22;$i$016$i = $27;
      }
     }
     $9 = Math_imul($10, $11)|0;
     $$sum$i = (($9) + 48)|0;
     $scevgep20$i = (($cPtr$018$i) + ($$sum$i)|0);
     $cPtr$1$lcssa$i = $scevgep20$i;
    }
    $12 = ($cPtr$1$lcssa$i>>>0)<($7>>>0);
    if ($12) {
     $cPtr$018$i = $cPtr$1$lcssa$i;
    } else {
     break;
    }
   }
  }
  $28 = (($a$01) + 1)|0;
  $exitcond = ($28|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $28;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx41solveContactCoulomb_BStaticBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$thresholdStream,$0,$outThresholdPairs) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $0 = $0|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $$sum$i = 0, $$sum45$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$02 = 0, $a1$01 = 0, $cPtr$028$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$121$i = 0, $exitcond = 0;
 var $exitcond6 = 0, $i$020$i = 0, $scevgep$i = 0, $scevgep44$i = 0, $umax$i = 0, $vForceWriteback$027$i = 0, $vForceWriteback$1$lcssa$i = 0, $vForceWriteback$119$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($constraintCount|0)==(0);
 if (!($1)) {
  $a$02 = 0;
  while(1) {
   $2 = (($desc) + ($a$02<<5)|0);
   __ZN5physx27solveContactCoulomb_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($2,0);
   $3 = ((($desc) + ($a$02<<5)|0) + 16|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 2|0);
   $6 = HEAP16[$5>>1]|0;
   $7 = $6&65535;
   $8 = (($4) + ($7)|0);
   $9 = HEAP8[$4>>0]|0;
   $10 = ($9<<24>>24)==(3);
   $11 = $10 ? 112 : 80;
   $12 = ($6<<16>>16)==(0);
   if (!($12)) {
    $13 = ((($desc) + ($a$02<<5)|0) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $cPtr$028$i = $4;$vForceWriteback$027$i = $14;
    while(1) {
     $17 = (($cPtr$028$i) + 48|0);
     $18 = (($cPtr$028$i) + 1|0);
     $19 = HEAP8[$18>>0]|0;
     $20 = $19&255;
     $21 = (($cPtr$028$i) + 304|0);
     $22 = (($cPtr$028$i) + 432|0);
     $23 = ($vForceWriteback$027$i|0)==(0|0);
     if ($23) {
      $31 = Math_imul($20, $11)|0;
      $$sum$i = (($31) + 48)|0;
      $32 = (($cPtr$028$i) + ($$sum$i)|0);
      $33 = ($32>>>0)<($8>>>0);
      if ($33) {
       $cPtr$028$i = $32;$vForceWriteback$027$i = 0;
       continue;
      } else {
       break;
      }
     }
     $24 = ($19<<24>>24)==(0);
     if ($24) {
      $cPtr$1$lcssa$i = $17;$vForceWriteback$1$lcssa$i = $vForceWriteback$027$i;
     } else {
      $25 = ($20>>>0)>(1);
      $umax$i = $25 ? $20 : 1;
      $cPtr$121$i = $17;$i$020$i = 0;$vForceWriteback$119$i = $vForceWriteback$027$i;
      while(1) {
       $26 = (($cPtr$121$i) + ($11)|0);
       $27 = (($cPtr$121$i) + 12|0);
       $28 = Math_fround(HEAPF32[$27>>2]);
       HEAPF32[$vForceWriteback$119$i>>2] = $28;
       $29 = (($vForceWriteback$119$i) + 4|0);
       $30 = (($i$020$i) + 1)|0;
       $exitcond = ($30|0)==($20|0);
       if ($exitcond) {
        break;
       } else {
        $cPtr$121$i = $26;$i$020$i = $30;$vForceWriteback$119$i = $29;
       }
      }
      $15 = Math_imul($umax$i, $11)|0;
      $scevgep$i = (($vForceWriteback$027$i) + ($umax$i<<2)|0);
      $$sum45$i = (($15) + 48)|0;
      $scevgep44$i = (($cPtr$028$i) + ($$sum45$i)|0);
      $cPtr$1$lcssa$i = $scevgep44$i;$vForceWriteback$1$lcssa$i = $scevgep$i;
     }
     $16 = ($cPtr$1$lcssa$i>>>0)<($8>>>0);
     if ($16) {
      $cPtr$028$i = $cPtr$1$lcssa$i;$vForceWriteback$027$i = $vForceWriteback$1$lcssa$i;
     } else {
      break;
     }
    }
   }
   $34 = (($a$02) + 1)|0;
   $exitcond6 = ($34|0)==($constraintCount|0);
   if ($exitcond6) {
    break;
   } else {
    $a$02 = $34;
   }
  }
 }
 $35 = (($cache) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($cache) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + -4)|0;
 $40 = ($36>>>0)>($39>>>0);
 if (!($40)) {
  STACKTOP = sp;return;
 }
 $41 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$36)|0);
 $42 = HEAP32[$35>>2]|0;
 $43 = (($41) - ($42))|0;
 $44 = ($42|0)==(0);
 if (!($44)) {
  $45 = (($cache) + 4|0);
  $a1$01 = 0;
  while(1) {
   $46 = (($43) + ($a1$01))|0;
   $47 = (($thresholdStream) + ($46<<4)|0);
   $48 = HEAP32[$45>>2]|0;
   $49 = (($48) + ($a1$01<<4)|0);
   ;HEAP32[$47+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$47+12>>2]=HEAP32[$49+12>>2]|0;
   $50 = (($a1$01) + 1)|0;
   $51 = HEAP32[$35>>2]|0;
   $52 = ($50>>>0)<($51>>>0);
   if ($52) {
    $a1$01 = $50;
   } else {
    break;
   }
  }
 }
 HEAP32[$35>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx27solveConcludeContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cPtr$018$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$117$i = 0, $exitcond$i = 0, $i$016$i = 0, $scevgep20$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx19solveContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,0);
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 2|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($1) + ($4)|0);
 $6 = ($3<<16>>16)==(0);
 if ($6) {
  STACKTOP = sp;return;
 } else {
  $cPtr$018$i = $1;
 }
 while(1) {
  $11 = (($cPtr$018$i) + 48|0);
  $12 = (($cPtr$018$i) + 1|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = (($cPtr$018$i) + 176|0);
  $15 = (($cPtr$018$i) + 304|0);
  $16 = (($cPtr$018$i) + 432|0);
  $17 = HEAP8[$cPtr$018$i>>0]|0;
  $18 = ($17<<24>>24)==(3);
  $8 = $18 ? 112 : 80;
  $19 = ($13<<24>>24)==(0);
  if ($19) {
   $cPtr$1$lcssa$i = $11;
  } else {
   $9 = $13&255;
   $cPtr$117$i = $11;$i$016$i = 0;
   while(1) {
    $20 = (($cPtr$117$i) + ($8)|0);
    $21 = (($cPtr$117$i) + 32|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = $22 > Math_fround(0.0);
    $$$i$i = $23 ? $22 : Math_fround(0.0);
    $24 = (($cPtr$117$i) + 44|0);
    HEAPF32[$21>>2] = $$$i$i;
    HEAPF32[$24>>2] = Math_fround(0.0);
    $25 = (($i$016$i) + 1)|0;
    $exitcond$i = ($25|0)==($9|0);
    if ($exitcond$i) {
     break;
    } else {
     $cPtr$117$i = $20;$i$016$i = $25;
    }
   }
   $7 = Math_imul($8, $9)|0;
   $$sum$i = (($7) + 48)|0;
   $scevgep20$i = (($cPtr$018$i) + ($$sum$i)|0);
   $cPtr$1$lcssa$i = $scevgep20$i;
  }
  $10 = ($cPtr$1$lcssa$i>>>0)<($5>>>0);
  if ($10) {
   $cPtr$018$i = $cPtr$1$lcssa$i;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx35solveConcludeContactCoulomb_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cPtr$018$i = 0, $cPtr$1$lcssa$i = 0, $cPtr$117$i = 0, $exitcond$i = 0, $i$016$i = 0, $scevgep20$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx27solveContactCoulomb_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,0);
 $0 = (($desc) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 2|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($1) + ($4)|0);
 $6 = ($3<<16>>16)==(0);
 if ($6) {
  STACKTOP = sp;return;
 } else {
  $cPtr$018$i = $1;
 }
 while(1) {
  $11 = (($cPtr$018$i) + 48|0);
  $12 = (($cPtr$018$i) + 1|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = (($cPtr$018$i) + 176|0);
  $15 = (($cPtr$018$i) + 304|0);
  $16 = (($cPtr$018$i) + 432|0);
  $17 = HEAP8[$cPtr$018$i>>0]|0;
  $18 = ($17<<24>>24)==(3);
  $8 = $18 ? 112 : 80;
  $19 = ($13<<24>>24)==(0);
  if ($19) {
   $cPtr$1$lcssa$i = $11;
  } else {
   $9 = $13&255;
   $cPtr$117$i = $11;$i$016$i = 0;
   while(1) {
    $20 = (($cPtr$117$i) + ($8)|0);
    $21 = (($cPtr$117$i) + 32|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = $22 > Math_fround(0.0);
    $$$i$i = $23 ? $22 : Math_fround(0.0);
    $24 = (($cPtr$117$i) + 44|0);
    HEAPF32[$21>>2] = $$$i$i;
    HEAPF32[$24>>2] = Math_fround(0.0);
    $25 = (($i$016$i) + 1)|0;
    $exitcond$i = ($25|0)==($9|0);
    if ($exitcond$i) {
     break;
    } else {
     $cPtr$117$i = $20;$i$016$i = $25;
    }
   }
   $7 = Math_imul($8, $9)|0;
   $$sum$i = (($7) + 48)|0;
   $scevgep20$i = (($cPtr$018$i) + ($$sum$i)|0);
   $cPtr$1$lcssa$i = $scevgep20$i;
  }
  $10 = ($cPtr$1$lcssa$i>>>0)<($5>>>0);
  if ($10) {
   $cPtr$018$i = $cPtr$1$lcssa$i;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx10solveExt1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i = Math_fround(0), $$$i86 = Math_fround(0), $$byval_copy2 = 0, $$byval_copy3 = 0, $$lcssa = Math_fround(0), $$lcssa670 = Math_fround(0), $$lcssa671 = Math_fround(0), $$lcssa672 = Math_fround(0), $$lcssa673 = Math_fround(0), $$lcssa674 = Math_fround(0), $$lcssa675 = Math_fround(0), $$lcssa676 = Math_fround(0), $$lcssa677 = Math_fround(0), $$lcssa678 = Math_fround(0), $$lcssa679 = Math_fround(0), $$lcssa680 = Math_fround(0), $$lcssa681 = Math_fround(0), $$lcssa682 = Math_fround(0), $$lcssa683 = Math_fround(0), $$lcssa684 = Math_fround(0);
 var $$lcssa685 = Math_fround(0), $$lcssa686 = Math_fround(0), $$lcssa687 = Math_fround(0), $$lcssa688 = Math_fround(0), $$lcssa689 = Math_fround(0), $$lcssa690 = Math_fround(0), $$lcssa691 = Math_fround(0), $$lcssa692 = Math_fround(0), $$ph = Math_fround(0), $$ph665 = Math_fround(0), $$ph666 = Math_fround(0), $$ph667 = Math_fround(0), $$ph668 = Math_fround(0), $$ph669 = Math_fround(0), $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0);
 var $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0;
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0;
 var $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0;
 var $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0);
 var $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0);
 var $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $base$0693 = 0, $i$0694 = 0, $v = 0, $v1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy3 = sp + 144|0;
 $$byval_copy2 = sp;
 $v = sp + 16|0;
 $v1 = sp + 48|0;
 $1 = sp + 80|0;
 $2 = sp + 96|0;
 $3 = sp + 112|0;
 $4 = sp + 128|0;
 $5 = (($desc) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 48|0);
 $8 = (($desc) + 8|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = ($9<<16>>16)==(-1);
 if ($10) {
  $11 = HEAP32[$desc>>2]|0;
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($11) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($11) + 8|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($11) + 16|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($11) + 20|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($11) + 24|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $287 = $16;$288 = $14;$289 = $12;$290 = $22;$291 = $20;$292 = $18;
 } else {
  $23 = $9&65535;
  $24 = HEAP32[$desc>>2]|0;
  __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($v,$24,$23);
  $25 = Math_fround(HEAPF32[$v>>2]);
  $26 = (($v) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($v) + 8|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($v) + 16|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($v) + 20|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($v) + 24|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $287 = $29;$288 = $27;$289 = $25;$290 = $35;$291 = $33;$292 = $31;
 }
 $36 = (($desc) + 12|0);
 $37 = HEAP16[$36>>1]|0;
 $38 = ($37<<16>>16)==(-1);
 $39 = (($desc) + 4|0);
 if ($38) {
  $40 = HEAP32[$39>>2]|0;
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($40) + 4|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = (($40) + 8|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($40) + 16|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = (($40) + 20|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($40) + 24|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $$ph = $45;$$ph665 = $43;$$ph666 = $41;$$ph667 = $51;$$ph668 = $49;$$ph669 = $47;
 } else {
  $52 = $37&65535;
  $53 = HEAP32[$39>>2]|0;
  __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($v1,$53,$52);
  $54 = Math_fround(HEAPF32[$v1>>2]);
  $55 = (($v1) + 4|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($v1) + 8|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($v1) + 16|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($v1) + 20|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = (($v1) + 24|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $$ph = $58;$$ph665 = $56;$$ph666 = $54;$$ph667 = $64;$$ph668 = $62;$$ph669 = $60;
 }
 $65 = (($6) + 1|0);
 $66 = HEAP8[$65>>0]|0;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  $$lcssa = $287;$$lcssa670 = $288;$$lcssa671 = $289;$$lcssa672 = $290;$$lcssa673 = $291;$$lcssa674 = $292;$$lcssa675 = $$ph;$$lcssa676 = $$ph665;$$lcssa677 = $$ph666;$$lcssa678 = $$ph667;$$lcssa679 = $$ph668;$$lcssa680 = $$ph669;$$lcssa681 = Math_fround(0.0);$$lcssa682 = Math_fround(0.0);$$lcssa683 = Math_fround(0.0);$$lcssa684 = Math_fround(0.0);$$lcssa685 = Math_fround(0.0);$$lcssa686 = Math_fround(0.0);$$lcssa687 = Math_fround(0.0);$$lcssa688 = Math_fround(0.0);$$lcssa689 = Math_fround(0.0);$$lcssa690 = Math_fround(0.0);$$lcssa691 = Math_fround(0.0);$$lcssa692 = Math_fround(0.0);
 } else {
  $105 = $292;$107 = $291;$109 = $290;$111 = $289;$113 = $288;$115 = $287;$120 = $$ph669;$122 = $$ph668;$124 = $$ph667;$126 = $$ph666;$128 = $$ph665;$130 = $$ph;$151 = Math_fround(0.0);$153 = Math_fround(0.0);$155 = Math_fround(0.0);$160 = Math_fround(0.0);$162 = Math_fround(0.0);$164 = Math_fround(0.0);$169 = Math_fround(0.0);$171 = Math_fround(0.0);$173 = Math_fround(0.0);$178 = Math_fround(0.0);$180 = Math_fround(0.0);$182 = Math_fround(0.0);$base$0693 = $7;$i$0694 = 0;
  while(1) {
   $68 = (($base$0693) + 176|0);
   $69 = Math_fround(HEAPF32[$base$0693>>2]);
   $70 = (($base$0693) + 4|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = (($base$0693) + 8|0);
   $73 = Math_fround(HEAPF32[$72>>2]);
   $74 = (($base$0693) + 12|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = (($base$0693) + 16|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = (($76) + 4|0);
   $79 = Math_fround(HEAPF32[$78>>2]);
   $80 = (($76) + 8|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   $82 = (($base$0693) + 32|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = (($82) + 4|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = (($82) + 8|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = (($82) + 12|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = (($base$0693) + 48|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = (($90) + 4|0);
   $93 = Math_fround(HEAPF32[$92>>2]);
   $94 = (($90) + 8|0);
   $95 = Math_fround(HEAPF32[$94>>2]);
   $96 = (($90) + 12|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = (($base$0693) + 96|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $100 = (($98) + 4|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = (($98) + 8|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = Math_fround($105 * $83);
   $106 = Math_fround($107 * $85);
   $108 = Math_fround($109 * $87);
   $110 = Math_fround($111 * $69);
   $112 = Math_fround($113 * $71);
   $114 = Math_fround($115 * $73);
   $116 = Math_fround($110 + $104);
   $117 = Math_fround($112 + $106);
   $118 = Math_fround($114 + $108);
   $119 = Math_fround($120 * $91);
   $121 = Math_fround($122 * $93);
   $123 = Math_fround($124 * $95);
   $125 = Math_fround($126 * $77);
   $127 = Math_fround($128 * $79);
   $129 = Math_fround($130 * $81);
   $131 = Math_fround($125 + $119);
   $132 = Math_fround($127 + $121);
   $133 = Math_fround($129 + $123);
   $134 = Math_fround($116 - $131);
   $135 = Math_fround($117 - $132);
   $136 = Math_fround($118 - $133);
   $137 = Math_fround($134 + $135);
   $138 = Math_fround($137 + $136);
   $139 = Math_fround($89 * $138);
   $140 = Math_fround($75 + $139);
   $141 = Math_fround($97 * $103);
   $142 = Math_fround($141 + $140);
   $143 = $99 > $142;
   $$$i86 = $143 ? $99 : $142;
   $144 = $101 > $$$i86;
   $$$i = $144 ? $$$i86 : $101;
   $145 = Math_fround($$$i - $103);
   $146 = (($base$0693) + 104|0);
   HEAPF32[$146>>2] = $$$i;
   $147 = Math_fround($69 * $145);
   $148 = Math_fround($71 * $145);
   $149 = Math_fround($73 * $145);
   $150 = Math_fround($151 + $147);
   $152 = Math_fround($153 + $148);
   $154 = Math_fround($155 + $149);
   $156 = Math_fround($83 * $145);
   $157 = Math_fround($85 * $145);
   $158 = Math_fround($87 * $145);
   $159 = Math_fround($160 + $156);
   $161 = Math_fround($162 + $157);
   $163 = Math_fround($164 + $158);
   $165 = Math_fround($77 * $145);
   $166 = Math_fround($79 * $145);
   $167 = Math_fround($81 * $145);
   $168 = Math_fround($169 + $165);
   $170 = Math_fround($171 + $166);
   $172 = Math_fround($173 + $167);
   $174 = Math_fround($91 * $145);
   $175 = Math_fround($93 * $145);
   $176 = Math_fround($95 * $145);
   $177 = Math_fround($178 + $174);
   $179 = Math_fround($180 + $175);
   $181 = Math_fround($182 + $176);
   $183 = (($base$0693) + 112|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = (($base$0693) + 116|0);
   $186 = Math_fround(HEAPF32[$185>>2]);
   $187 = (($base$0693) + 120|0);
   $188 = Math_fround(HEAPF32[$187>>2]);
   $189 = Math_fround($184 * $145);
   $190 = Math_fround($186 * $145);
   $191 = Math_fround($188 * $145);
   $192 = Math_fround($111 + $189);
   $193 = Math_fround($113 + $190);
   $194 = Math_fround($115 + $191);
   $195 = (($base$0693) + 128|0);
   $196 = Math_fround(HEAPF32[$195>>2]);
   $197 = (($base$0693) + 132|0);
   $198 = Math_fround(HEAPF32[$197>>2]);
   $199 = (($base$0693) + 136|0);
   $200 = Math_fround(HEAPF32[$199>>2]);
   $201 = Math_fround($196 * $145);
   $202 = Math_fround($198 * $145);
   $203 = Math_fround($200 * $145);
   $204 = Math_fround($105 + $201);
   $205 = Math_fround($107 + $202);
   $206 = Math_fround($109 + $203);
   $207 = (($base$0693) + 144|0);
   $208 = Math_fround(HEAPF32[$207>>2]);
   $209 = (($base$0693) + 148|0);
   $210 = Math_fround(HEAPF32[$209>>2]);
   $211 = (($base$0693) + 152|0);
   $212 = Math_fround(HEAPF32[$211>>2]);
   $213 = Math_fround($208 * $145);
   $214 = Math_fround($210 * $145);
   $215 = Math_fround($145 * $212);
   $216 = Math_fround($126 + $213);
   $217 = Math_fround($128 + $214);
   $218 = Math_fround($130 + $215);
   $219 = (($base$0693) + 160|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = (($base$0693) + 164|0);
   $222 = Math_fround(HEAPF32[$221>>2]);
   $223 = (($base$0693) + 168|0);
   $224 = Math_fround(HEAPF32[$223>>2]);
   $225 = Math_fround($145 * $220);
   $226 = Math_fround($145 * $222);
   $227 = Math_fround($145 * $224);
   $228 = Math_fround($120 + $225);
   $229 = Math_fround($122 + $226);
   $230 = Math_fround($124 + $227);
   $231 = (($i$0694) + 1)|0;
   $232 = HEAP8[$65>>0]|0;
   $233 = $232&255;
   $234 = ($231>>>0)<($233>>>0);
   if ($234) {
    $105 = $204;$107 = $205;$109 = $206;$111 = $192;$113 = $193;$115 = $194;$120 = $228;$122 = $229;$124 = $230;$126 = $216;$128 = $217;$130 = $218;$151 = $150;$153 = $152;$155 = $154;$160 = $159;$162 = $161;$164 = $163;$169 = $168;$171 = $170;$173 = $172;$178 = $177;$180 = $179;$182 = $181;$base$0693 = $68;$i$0694 = $231;
   } else {
    $$lcssa = $194;$$lcssa670 = $193;$$lcssa671 = $192;$$lcssa672 = $206;$$lcssa673 = $205;$$lcssa674 = $204;$$lcssa675 = $218;$$lcssa676 = $217;$$lcssa677 = $216;$$lcssa678 = $230;$$lcssa679 = $229;$$lcssa680 = $228;$$lcssa681 = $154;$$lcssa682 = $152;$$lcssa683 = $150;$$lcssa684 = $172;$$lcssa685 = $170;$$lcssa686 = $168;$$lcssa687 = $163;$$lcssa688 = $161;$$lcssa689 = $159;$$lcssa690 = $181;$$lcssa691 = $179;$$lcssa692 = $177;
    break;
   }
  }
 }
 $235 = HEAP16[$8>>1]|0;
 $236 = ($235<<16>>16)==(-1);
 if ($236) {
  $237 = HEAP32[$desc>>2]|0;
  HEAPF32[$237>>2] = $$lcssa671;
  $238 = (($237) + 4|0);
  HEAPF32[$238>>2] = $$lcssa670;
  $239 = (($237) + 8|0);
  HEAPF32[$239>>2] = $$lcssa;
  $240 = (($237) + 16|0);
  HEAPF32[$240>>2] = $$lcssa674;
  $241 = (($237) + 20|0);
  HEAPF32[$241>>2] = $$lcssa673;
  $242 = (($237) + 24|0);
  HEAPF32[$242>>2] = $$lcssa672;
 } else {
  $243 = $235&65535;
  $244 = HEAP32[$desc>>2]|0;
  $245 = (($6) + 32|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround($$lcssa683 * $246);
  $248 = Math_fround($$lcssa682 * $246);
  $249 = Math_fround($$lcssa681 * $246);
  HEAPF32[$1>>2] = $247;
  $250 = (($1) + 4|0);
  HEAPF32[$250>>2] = $248;
  $251 = (($1) + 8|0);
  HEAPF32[$251>>2] = $249;
  $252 = (($1) + 12|0);
  HEAPF32[$252>>2] = Math_fround(0.0);
  $253 = (($6) + 36|0);
  $254 = Math_fround(HEAPF32[$253>>2]);
  $255 = Math_fround($$lcssa689 * $254);
  $256 = Math_fround($$lcssa688 * $254);
  $257 = Math_fround($$lcssa687 * $254);
  HEAPF32[$2>>2] = $255;
  $258 = (($2) + 4|0);
  HEAPF32[$258>>2] = $256;
  $259 = (($2) + 8|0);
  HEAPF32[$259>>2] = $257;
  $260 = (($2) + 12|0);
  HEAPF32[$260>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$2+12>>2]|0;
  __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($244,$243,$$byval_copy2,$$byval_copy3);
 }
 $261 = HEAP16[$36>>1]|0;
 $262 = ($261<<16>>16)==(-1);
 if ($262) {
  $263 = HEAP32[$39>>2]|0;
  HEAPF32[$263>>2] = $$lcssa677;
  $264 = (($263) + 4|0);
  HEAPF32[$264>>2] = $$lcssa676;
  $265 = (($263) + 8|0);
  HEAPF32[$265>>2] = $$lcssa675;
  $266 = (($263) + 16|0);
  HEAPF32[$266>>2] = $$lcssa680;
  $267 = (($263) + 20|0);
  HEAPF32[$267>>2] = $$lcssa679;
  $268 = (($263) + 24|0);
  HEAPF32[$268>>2] = $$lcssa678;
  STACKTOP = sp;return;
 } else {
  $269 = $261&65535;
  $270 = HEAP32[$39>>2]|0;
  $271 = (($6) + 40|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = Math_fround($$lcssa686 * $272);
  $274 = Math_fround($$lcssa685 * $272);
  $275 = Math_fround($$lcssa684 * $272);
  HEAPF32[$3>>2] = $273;
  $276 = (($3) + 4|0);
  HEAPF32[$276>>2] = $274;
  $277 = (($3) + 8|0);
  HEAPF32[$277>>2] = $275;
  $278 = (($3) + 12|0);
  HEAPF32[$278>>2] = Math_fround(0.0);
  $279 = (($6) + 44|0);
  $280 = Math_fround(HEAPF32[$279>>2]);
  $281 = Math_fround($$lcssa692 * $280);
  $282 = Math_fround($$lcssa691 * $280);
  $283 = Math_fround($$lcssa690 * $280);
  HEAPF32[$4>>2] = $281;
  $284 = (($4) + 4|0);
  HEAPF32[$284>>2] = $282;
  $285 = (($4) + 8|0);
  HEAPF32[$285>>2] = $283;
  $286 = (($4) + 12|0);
  HEAPF32[$286>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$3+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$4+12>>2]|0;
  __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($270,$269,$$byval_copy2,$$byval_copy3);
  STACKTOP = sp;return;
 }
}
function __ZN5physx15solveExtContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var $$$i = Math_fround(0), $$$i137 = Math_fround(0), $$$i290 = Math_fround(0), $$byval_copy2 = 0, $$byval_copy3 = 0, $$lcssa1455 = Math_fround(0), $$lcssa1456 = Math_fround(0), $$lcssa1457 = Math_fround(0), $$lcssa1459 = Math_fround(0), $$lcssa1460 = Math_fround(0), $$lcssa1461 = Math_fround(0), $$lcssa1463 = Math_fround(0), $$lcssa1464 = Math_fround(0), $$lcssa1465 = Math_fround(0), $$lcssa1467 = Math_fround(0), $$lcssa1468 = Math_fround(0), $$lcssa1469 = Math_fround(0), $$lcssa1470 = Math_fround(0), $$lcssa1471 = Math_fround(0), $$lcssa1472 = Math_fround(0);
 var $$lcssa1473 = Math_fround(0), $$lcssa1474 = Math_fround(0), $$lcssa1475 = Math_fround(0), $$lcssa1476 = Math_fround(0), $$lcssa1477 = Math_fround(0), $$lcssa1478 = Math_fround(0), $$lcssa1479 = Math_fround(0), $$lcssa1480 = Math_fround(0), $$lcssa1481 = Math_fround(0), $$lcssa1482 = Math_fround(0), $$lcssa1571 = Math_fround(0), $$lcssa1572 = Math_fround(0), $$lcssa1573 = Math_fround(0), $$lcssa1574 = Math_fround(0), $$lcssa1575 = Math_fround(0), $$lcssa1576 = Math_fround(0), $$lcssa1577 = Math_fround(0), $$lcssa1578 = Math_fround(0), $$lcssa1579 = Math_fround(0), $$lcssa1580 = Math_fround(0);
 var $$lcssa1581 = Math_fround(0), $$lcssa1582 = Math_fround(0), $$lcssa1583 = Math_fround(0), $$lcssa1584 = Math_fround(0), $$lcssa1585 = Math_fround(0), $$lcssa1586 = Math_fround(0), $$lcssa1587 = Math_fround(0), $$lcssa1588 = Math_fround(0), $$lcssa1589 = Math_fround(0), $$lcssa1590 = Math_fround(0), $$lcssa1591 = Math_fround(0), $$lcssa1592 = Math_fround(0), $$lcssa1593 = Math_fround(0), $$lcssa1594 = Math_fround(0), $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0);
 var $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0);
 var $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0);
 var $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0);
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0);
 var $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0);
 var $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0);
 var $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0);
 var $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0);
 var $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0;
 var $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0, $317 = 0;
 var $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0);
 var $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = 0;
 var $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0);
 var $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0);
 var $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0);
 var $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0);
 var $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0);
 var $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0);
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0);
 var $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0);
 var $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0);
 var $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $currPtr$01595 = 0, $exitcond = 0, $exitcond1672 = 0, $i$01483 = 0, $i3$01540 = 0, $or$cond = 0, $v = 0, $v1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy3 = sp + 144|0;
 $$byval_copy2 = sp;
 $v = sp + 16|0;
 $v1 = sp + 48|0;
 $0 = sp + 80|0;
 $1 = sp + 96|0;
 $2 = sp + 112|0;
 $3 = sp + 128|0;
 $4 = (($desc) + 8|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = ($5<<16>>16)==(-1);
 if ($6) {
  $7 = HEAP32[$desc>>2]|0;
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($7) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($7) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($7) + 16|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($7) + 20|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($7) + 24|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $495 = $12;$496 = $10;$497 = $8;$498 = $18;$499 = $16;$500 = $14;
 } else {
  $19 = $5&65535;
  $20 = HEAP32[$desc>>2]|0;
  __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($v,$20,$19);
  $21 = Math_fround(HEAPF32[$v>>2]);
  $22 = (($v) + 4|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($v) + 8|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($v) + 16|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($v) + 20|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($v) + 24|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $495 = $25;$496 = $23;$497 = $21;$498 = $31;$499 = $29;$500 = $27;
 }
 $32 = (($desc) + 12|0);
 $33 = HEAP16[$32>>1]|0;
 $34 = ($33<<16>>16)==(-1);
 $35 = (($desc) + 4|0);
 if ($34) {
  $36 = HEAP32[$35>>2]|0;
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($36) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($36) + 8|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($36) + 16|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = (($36) + 20|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($36) + 24|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $501 = $41;$502 = $39;$503 = $37;$504 = $47;$505 = $45;$506 = $43;
 } else {
  $48 = $33&65535;
  $49 = HEAP32[$35>>2]|0;
  __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($v1,$49,$48);
  $50 = Math_fround(HEAPF32[$v1>>2]);
  $51 = (($v1) + 4|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (($v1) + 8|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($v1) + 16|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($v1) + 20|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($v1) + 24|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $501 = $54;$502 = $52;$503 = $50;$504 = $60;$505 = $58;$506 = $56;
 }
 $61 = (($desc) + 16|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($desc) + 26|0);
 $64 = HEAP16[$63>>1]|0;
 $65 = $64&65535;
 $66 = $65 << 4;
 $67 = (($62) + ($66)|0);
 $68 = ($64<<16>>16)==(0);
 if ($68) {
  $$lcssa1571 = $495;$$lcssa1572 = $496;$$lcssa1573 = $497;$$lcssa1574 = $498;$$lcssa1575 = $499;$$lcssa1576 = $500;$$lcssa1577 = $501;$$lcssa1578 = $502;$$lcssa1579 = $503;$$lcssa1580 = $504;$$lcssa1581 = $505;$$lcssa1582 = $506;$$lcssa1583 = Math_fround(0.0);$$lcssa1584 = Math_fround(0.0);$$lcssa1585 = Math_fround(0.0);$$lcssa1586 = Math_fround(0.0);$$lcssa1587 = Math_fround(0.0);$$lcssa1588 = Math_fround(0.0);$$lcssa1589 = Math_fround(0.0);$$lcssa1590 = Math_fround(0.0);$$lcssa1591 = Math_fround(0.0);$$lcssa1592 = Math_fround(0.0);$$lcssa1593 = Math_fround(0.0);$$lcssa1594 = Math_fround(0.0);
 } else {
  $415 = Math_fround(0.0);$417 = Math_fround(0.0);$419 = Math_fround(0.0);$429 = Math_fround(0.0);$431 = Math_fround(0.0);$433 = Math_fround(0.0);$443 = Math_fround(0.0);$445 = Math_fround(0.0);$447 = Math_fround(0.0);$457 = Math_fround(0.0);$459 = Math_fround(0.0);$461 = Math_fround(0.0);$507 = $506;$508 = $505;$509 = $504;$510 = $503;$511 = $502;$512 = $501;$513 = $500;$514 = $499;$515 = $498;$516 = $497;$517 = $496;$518 = $495;$currPtr$01595 = $62;
  while(1) {
   $69 = (($currPtr$01595) + 32|0);
   $70 = (($currPtr$01595) + 5|0);
   $71 = HEAP8[$70>>0]|0;
   $72 = $71&255;
   $73 = (($currPtr$01595) + 6|0);
   $74 = HEAP8[$73>>0]|0;
   $75 = $74&255;
   $76 = $72 << 7;
   $$sum1 = $76 | 32;
   $77 = (($currPtr$01595) + ($$sum1)|0);
   $78 = $75 << 7;
   $$sum = (($$sum1) + ($78))|0;
   $79 = (($currPtr$01595) + ($$sum)|0);
   $80 = ($71<<24>>24)==(0);
   if ($80) {
    $$lcssa1455 = $518;$$lcssa1456 = $517;$$lcssa1457 = $516;$$lcssa1459 = $515;$$lcssa1460 = $514;$$lcssa1461 = $513;$$lcssa1463 = $512;$$lcssa1464 = $511;$$lcssa1465 = $510;$$lcssa1467 = $509;$$lcssa1468 = $508;$$lcssa1469 = $507;$$lcssa1470 = Math_fround(0.0);$$lcssa1471 = Math_fround(0.0);$$lcssa1472 = Math_fround(0.0);$$lcssa1473 = Math_fround(0.0);$$lcssa1474 = Math_fround(0.0);$$lcssa1475 = Math_fround(0.0);$$lcssa1476 = Math_fround(0.0);$$lcssa1477 = Math_fround(0.0);$$lcssa1478 = Math_fround(0.0);$$lcssa1479 = Math_fround(0.0);$$lcssa1480 = Math_fround(0.0);$$lcssa1481 = Math_fround(0.0);$$lcssa1482 = Math_fround(0.0);
   } else {
    $110 = $513;$112 = $514;$114 = $515;$116 = $516;$118 = $517;$120 = $518;$125 = $507;$127 = $508;$129 = $509;$131 = $510;$133 = $511;$135 = $512;$202 = Math_fround(0.0);$204 = Math_fround(0.0);$206 = Math_fround(0.0);$211 = Math_fround(0.0);$213 = Math_fround(0.0);$215 = Math_fround(0.0);$217 = Math_fround(0.0);$219 = Math_fround(0.0);$221 = Math_fround(0.0);$226 = Math_fround(0.0);$228 = Math_fround(0.0);$230 = Math_fround(0.0);$233 = Math_fround(0.0);$i$01483 = 0;
    while(1) {
     $81 = (($i$01483) + 1)|0;
     $82 = (($69) + ($81<<7)|0);
     $83 = (($69) + ($i$01483<<7)|0);
     $84 = Math_fround(HEAPF32[$83>>2]);
     $85 = ((($69) + ($i$01483<<7)|0) + 4|0);
     $86 = Math_fround(HEAPF32[$85>>2]);
     $87 = ((($69) + ($i$01483<<7)|0) + 8|0);
     $88 = Math_fround(HEAPF32[$87>>2]);
     $89 = ((($69) + ($i$01483<<7)|0) + 12|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     $91 = ((($69) + ($i$01483<<7)|0) + 16|0);
     $92 = Math_fround(HEAPF32[$91>>2]);
     $93 = ((($69) + ($i$01483<<7)|0) + 20|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = ((($69) + ($i$01483<<7)|0) + 24|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $97 = ((($69) + ($i$01483<<7)|0) + 28|0);
     $98 = Math_fround(HEAPF32[$97>>2]);
     $99 = ((($69) + ($i$01483<<7)|0) + 32|0);
     $100 = Math_fround(HEAPF32[$99>>2]);
     $101 = ((($69) + ($i$01483<<7)|0) + 36|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = ((($69) + ($i$01483<<7)|0) + 40|0);
     $104 = Math_fround(HEAPF32[$103>>2]);
     $105 = ((($69) + ($i$01483<<7)|0) + 52|0);
     $106 = Math_fround(HEAPF32[$105>>2]);
     $107 = ((($69) + ($i$01483<<7)|0) + 48|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     $109 = Math_fround($110 * $92);
     $111 = Math_fround($112 * $94);
     $113 = Math_fround($114 * $96);
     $115 = Math_fround($116 * $84);
     $117 = Math_fround($118 * $86);
     $119 = Math_fround($120 * $88);
     $121 = Math_fround($115 + $109);
     $122 = Math_fround($117 + $111);
     $123 = Math_fround($119 + $113);
     $124 = Math_fround($125 * $100);
     $126 = Math_fround($127 * $102);
     $128 = Math_fround($129 * $104);
     $130 = Math_fround($131 * $84);
     $132 = Math_fround($133 * $86);
     $134 = Math_fround($135 * $88);
     $136 = Math_fround($130 + $124);
     $137 = Math_fround($132 + $126);
     $138 = Math_fround($134 + $128);
     $139 = Math_fround($121 - $136);
     $140 = Math_fround($122 - $137);
     $141 = Math_fround($123 - $138);
     $142 = Math_fround($139 + $140);
     $143 = Math_fround($142 + $141);
     $144 = Math_fround($90 * $106);
     $145 = Math_fround($144 - $108);
     $146 = Math_fround($90 * $143);
     $147 = Math_fround($145 - $146);
     $148 = Math_fround(-$98);
     $149 = $147 > $148;
     $$$i290 = $149 ? $147 : $148;
     $150 = ((($69) + ($i$01483<<7)|0) + 96|0);
     $151 = Math_fround(HEAPF32[$150>>2]);
     $152 = ((($69) + ($i$01483<<7)|0) + 100|0);
     $153 = Math_fround(HEAPF32[$152>>2]);
     $154 = ((($69) + ($i$01483<<7)|0) + 104|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = Math_fround($151 * $$$i290);
     $157 = Math_fround($153 * $$$i290);
     $158 = Math_fround($155 * $$$i290);
     $159 = Math_fround($116 + $156);
     $160 = Math_fround($118 + $157);
     $161 = Math_fround($120 + $158);
     $162 = ((($69) + ($i$01483<<7)|0) + 64|0);
     $163 = Math_fround(HEAPF32[$162>>2]);
     $164 = ((($69) + ($i$01483<<7)|0) + 68|0);
     $165 = Math_fround(HEAPF32[$164>>2]);
     $166 = ((($69) + ($i$01483<<7)|0) + 72|0);
     $167 = Math_fround(HEAPF32[$166>>2]);
     $168 = Math_fround($163 * $$$i290);
     $169 = Math_fround($165 * $$$i290);
     $170 = Math_fround($167 * $$$i290);
     $171 = Math_fround($110 + $168);
     $172 = Math_fround($112 + $169);
     $173 = Math_fround($114 + $170);
     $174 = ((($69) + ($i$01483<<7)|0) + 112|0);
     $175 = Math_fround(HEAPF32[$174>>2]);
     $176 = ((($69) + ($i$01483<<7)|0) + 116|0);
     $177 = Math_fround(HEAPF32[$176>>2]);
     $178 = ((($69) + ($i$01483<<7)|0) + 120|0);
     $179 = Math_fround(HEAPF32[$178>>2]);
     $180 = Math_fround($$$i290 * $175);
     $181 = Math_fround($$$i290 * $177);
     $182 = Math_fround($$$i290 * $179);
     $183 = Math_fround($131 + $180);
     $184 = Math_fround($133 + $181);
     $185 = Math_fround($135 + $182);
     $186 = ((($69) + ($i$01483<<7)|0) + 80|0);
     $187 = Math_fround(HEAPF32[$186>>2]);
     $188 = ((($69) + ($i$01483<<7)|0) + 84|0);
     $189 = Math_fround(HEAPF32[$188>>2]);
     $190 = ((($69) + ($i$01483<<7)|0) + 88|0);
     $191 = Math_fround(HEAPF32[$190>>2]);
     $192 = Math_fround($$$i290 * $187);
     $193 = Math_fround($$$i290 * $189);
     $194 = Math_fround($$$i290 * $191);
     $195 = Math_fround($125 + $192);
     $196 = Math_fround($127 + $193);
     $197 = Math_fround($129 + $194);
     $198 = Math_fround($84 * $$$i290);
     $199 = Math_fround($86 * $$$i290);
     $200 = Math_fround($88 * $$$i290);
     $201 = Math_fround($202 + $198);
     $203 = Math_fround($204 + $199);
     $205 = Math_fround($206 + $200);
     $207 = Math_fround($92 * $$$i290);
     $208 = Math_fround($94 * $$$i290);
     $209 = Math_fround($96 * $$$i290);
     $210 = Math_fround($211 + $207);
     $212 = Math_fround($213 + $208);
     $214 = Math_fround($215 + $209);
     $216 = Math_fround($217 + $198);
     $218 = Math_fround($219 + $199);
     $220 = Math_fround($221 + $200);
     $222 = Math_fround($100 * $$$i290);
     $223 = Math_fround($102 * $$$i290);
     $224 = Math_fround($104 * $$$i290);
     $225 = Math_fround($226 + $222);
     $227 = Math_fround($228 + $223);
     $229 = Math_fround($230 + $224);
     $231 = Math_fround($98 + $$$i290);
     HEAPF32[$97>>2] = $231;
     $232 = Math_fround($233 + $98);
     $234 = Math_fround($232 + $$$i290);
     $exitcond = ($81|0)==($72|0);
     if ($exitcond) {
      $$lcssa1455 = $161;$$lcssa1456 = $160;$$lcssa1457 = $159;$$lcssa1459 = $173;$$lcssa1460 = $172;$$lcssa1461 = $171;$$lcssa1463 = $185;$$lcssa1464 = $184;$$lcssa1465 = $183;$$lcssa1467 = $197;$$lcssa1468 = $196;$$lcssa1469 = $195;$$lcssa1470 = $234;$$lcssa1471 = $205;$$lcssa1472 = $203;$$lcssa1473 = $201;$$lcssa1474 = $220;$$lcssa1475 = $218;$$lcssa1476 = $216;$$lcssa1477 = $214;$$lcssa1478 = $212;$$lcssa1479 = $210;$$lcssa1480 = $229;$$lcssa1481 = $227;$$lcssa1482 = $225;
      break;
     } else {
      $110 = $171;$112 = $172;$114 = $173;$116 = $159;$118 = $160;$120 = $161;$125 = $195;$127 = $196;$129 = $197;$131 = $183;$133 = $184;$135 = $185;$202 = $201;$204 = $203;$206 = $205;$211 = $210;$213 = $212;$215 = $214;$217 = $216;$219 = $218;$221 = $220;$226 = $225;$228 = $227;$230 = $229;$233 = $234;$i$01483 = $81;
     }
    }
   }
   $235 = HEAP8[$cache>>0]|0;
   $236 = ($235<<24>>24)==(0);
   $237 = ($74<<24>>24)==(0);
   $or$cond = $236 | $237;
   if ($or$cond) {
    $409 = $$lcssa1473;$411 = $$lcssa1472;$413 = $$lcssa1471;$423 = $$lcssa1479;$425 = $$lcssa1478;$427 = $$lcssa1477;$437 = $$lcssa1476;$439 = $$lcssa1475;$441 = $$lcssa1474;$451 = $$lcssa1482;$453 = $$lcssa1481;$455 = $$lcssa1480;$519 = $$lcssa1455;$520 = $$lcssa1456;$521 = $$lcssa1457;$522 = $$lcssa1459;$523 = $$lcssa1460;$524 = $$lcssa1461;$525 = $$lcssa1463;$526 = $$lcssa1464;$527 = $$lcssa1465;$528 = $$lcssa1467;$529 = $$lcssa1468;$530 = $$lcssa1469;
   } else {
    $238 = (($currPtr$01595) + 16|0);
    $239 = Math_fround(HEAPF32[$238>>2]);
    $240 = Math_fround($$lcssa1470 * $239);
    $241 = (($currPtr$01595) + 20|0);
    $242 = Math_fround(HEAPF32[$241>>2]);
    $243 = Math_fround($$lcssa1470 * $242);
    $244 = Math_fround(-$243);
    $245 = Math_fround(-$240);
    $275 = $$lcssa1461;$277 = $$lcssa1460;$279 = $$lcssa1459;$281 = $$lcssa1457;$283 = $$lcssa1456;$285 = $$lcssa1455;$290 = $$lcssa1469;$292 = $$lcssa1468;$294 = $$lcssa1467;$296 = $$lcssa1465;$298 = $$lcssa1464;$300 = $$lcssa1463;$377 = $$lcssa1473;$379 = $$lcssa1472;$381 = $$lcssa1471;$386 = $$lcssa1479;$388 = $$lcssa1478;$390 = $$lcssa1477;$392 = $$lcssa1476;$394 = $$lcssa1475;$396 = $$lcssa1474;$401 = $$lcssa1482;$403 = $$lcssa1481;$405 = $$lcssa1480;$i3$01540 = 0;
    while(1) {
     $246 = (($i3$01540) + 1)|0;
     $247 = (($77) + ($246<<7)|0);
     $248 = (($77) + ($i3$01540<<7)|0);
     $249 = Math_fround(HEAPF32[$248>>2]);
     $250 = ((($77) + ($i3$01540<<7)|0) + 4|0);
     $251 = Math_fround(HEAPF32[$250>>2]);
     $252 = ((($77) + ($i3$01540<<7)|0) + 8|0);
     $253 = Math_fround(HEAPF32[$252>>2]);
     $254 = ((($77) + ($i3$01540<<7)|0) + 12|0);
     $255 = Math_fround(HEAPF32[$254>>2]);
     $256 = ((($77) + ($i3$01540<<7)|0) + 16|0);
     $257 = Math_fround(HEAPF32[$256>>2]);
     $258 = ((($77) + ($i3$01540<<7)|0) + 20|0);
     $259 = Math_fround(HEAPF32[$258>>2]);
     $260 = ((($77) + ($i3$01540<<7)|0) + 24|0);
     $261 = Math_fround(HEAPF32[$260>>2]);
     $262 = ((($77) + ($i3$01540<<7)|0) + 28|0);
     $263 = Math_fround(HEAPF32[$262>>2]);
     $264 = ((($77) + ($i3$01540<<7)|0) + 32|0);
     $265 = Math_fround(HEAPF32[$264>>2]);
     $266 = ((($77) + ($i3$01540<<7)|0) + 36|0);
     $267 = Math_fround(HEAPF32[$266>>2]);
     $268 = ((($77) + ($i3$01540<<7)|0) + 40|0);
     $269 = Math_fround(HEAPF32[$268>>2]);
     $270 = ((($77) + ($i3$01540<<7)|0) + 44|0);
     $271 = Math_fround(HEAPF32[$270>>2]);
     $272 = ((($77) + ($i3$01540<<7)|0) + 76|0);
     $273 = Math_fround(HEAPF32[$272>>2]);
     $274 = Math_fround($275 * $257);
     $276 = Math_fround($277 * $259);
     $278 = Math_fround($279 * $261);
     $280 = Math_fround($281 * $249);
     $282 = Math_fround($283 * $251);
     $284 = Math_fround($285 * $253);
     $286 = Math_fround($280 + $274);
     $287 = Math_fround($282 + $276);
     $288 = Math_fround($284 + $278);
     $289 = Math_fround($290 * $265);
     $291 = Math_fround($292 * $267);
     $293 = Math_fround($294 * $269);
     $295 = Math_fround($296 * $249);
     $297 = Math_fround($298 * $251);
     $299 = Math_fround($300 * $253);
     $301 = Math_fround($295 + $289);
     $302 = Math_fround($297 + $291);
     $303 = Math_fround($299 + $293);
     $304 = Math_fround($286 - $301);
     $305 = Math_fround($287 - $302);
     $306 = Math_fround($288 - $303);
     $307 = Math_fround($304 + $305);
     $308 = Math_fround($307 + $306);
     $309 = Math_fround($271 - $273);
     $310 = Math_fround($263 * $309);
     $311 = Math_fround($255 - $310);
     $312 = ((($77) + ($i3$01540<<7)|0) + 60|0);
     $313 = Math_fround(HEAPF32[$312>>2]);
     $314 = Math_fround($263 * $308);
     $315 = Math_fround($311 - $314);
     $316 = $315 < $244;
     $$$i137 = $316 ? $244 : $315;
     $317 = $243 > $315;
     $$$i = $317 ? $315 : $243;
     $318 = !($315 > $240);
     $319 = $318 ? $315 : $$$i;
     $320 = !($315 < $245);
     $321 = $320 ? $319 : $$$i137;
     $322 = $318 ? $313 : Math_fround(1.0);
     $323 = $320 ? $322 : Math_fround(1.0);
     $324 = Math_fround($321 - $255);
     $325 = ((($77) + ($i3$01540<<7)|0) + 96|0);
     $326 = Math_fround(HEAPF32[$325>>2]);
     $327 = ((($77) + ($i3$01540<<7)|0) + 100|0);
     $328 = Math_fround(HEAPF32[$327>>2]);
     $329 = ((($77) + ($i3$01540<<7)|0) + 104|0);
     $330 = Math_fround(HEAPF32[$329>>2]);
     $331 = Math_fround($326 * $324);
     $332 = Math_fround($328 * $324);
     $333 = Math_fround($330 * $324);
     $334 = Math_fround($281 + $331);
     $335 = Math_fround($283 + $332);
     $336 = Math_fround($285 + $333);
     $337 = ((($77) + ($i3$01540<<7)|0) + 48|0);
     $338 = Math_fround(HEAPF32[$337>>2]);
     $339 = ((($77) + ($i3$01540<<7)|0) + 52|0);
     $340 = Math_fround(HEAPF32[$339>>2]);
     $341 = ((($77) + ($i3$01540<<7)|0) + 56|0);
     $342 = Math_fround(HEAPF32[$341>>2]);
     $343 = Math_fround($338 * $324);
     $344 = Math_fround($340 * $324);
     $345 = Math_fround($342 * $324);
     $346 = Math_fround($275 + $343);
     $347 = Math_fround($277 + $344);
     $348 = Math_fround($279 + $345);
     $349 = ((($77) + ($i3$01540<<7)|0) + 112|0);
     $350 = Math_fround(HEAPF32[$349>>2]);
     $351 = ((($77) + ($i3$01540<<7)|0) + 116|0);
     $352 = Math_fround(HEAPF32[$351>>2]);
     $353 = ((($77) + ($i3$01540<<7)|0) + 120|0);
     $354 = Math_fround(HEAPF32[$353>>2]);
     $355 = Math_fround($350 * $324);
     $356 = Math_fround($352 * $324);
     $357 = Math_fround($324 * $354);
     $358 = Math_fround($296 + $355);
     $359 = Math_fround($298 + $356);
     $360 = Math_fround($300 + $357);
     $361 = ((($77) + ($i3$01540<<7)|0) + 64|0);
     $362 = Math_fround(HEAPF32[$361>>2]);
     $363 = ((($77) + ($i3$01540<<7)|0) + 68|0);
     $364 = Math_fround(HEAPF32[$363>>2]);
     $365 = ((($77) + ($i3$01540<<7)|0) + 72|0);
     $366 = Math_fround(HEAPF32[$365>>2]);
     $367 = Math_fround($324 * $362);
     $368 = Math_fround($324 * $364);
     $369 = Math_fround($324 * $366);
     $370 = Math_fround($290 + $367);
     $371 = Math_fround($292 + $368);
     $372 = Math_fround($294 + $369);
     $373 = Math_fround($249 * $324);
     $374 = Math_fround($251 * $324);
     $375 = Math_fround($253 * $324);
     $376 = Math_fround($377 + $373);
     $378 = Math_fround($379 + $374);
     $380 = Math_fround($381 + $375);
     $382 = Math_fround($257 * $324);
     $383 = Math_fround($259 * $324);
     $384 = Math_fround($261 * $324);
     $385 = Math_fround($386 + $382);
     $387 = Math_fround($388 + $383);
     $389 = Math_fround($390 + $384);
     $391 = Math_fround($392 + $373);
     $393 = Math_fround($394 + $374);
     $395 = Math_fround($396 + $375);
     $397 = Math_fround($265 * $324);
     $398 = Math_fround($267 * $324);
     $399 = Math_fround($269 * $324);
     $400 = Math_fround($401 + $397);
     $402 = Math_fround($403 + $398);
     $404 = Math_fround($405 + $399);
     HEAPF32[$254>>2] = $321;
     HEAPF32[$312>>2] = $323;
     $exitcond1672 = ($246|0)==($75|0);
     if ($exitcond1672) {
      $409 = $376;$411 = $378;$413 = $380;$423 = $385;$425 = $387;$427 = $389;$437 = $391;$439 = $393;$441 = $395;$451 = $400;$453 = $402;$455 = $404;$519 = $336;$520 = $335;$521 = $334;$522 = $348;$523 = $347;$524 = $346;$525 = $360;$526 = $359;$527 = $358;$528 = $372;$529 = $371;$530 = $370;
      break;
     } else {
      $275 = $346;$277 = $347;$279 = $348;$281 = $334;$283 = $335;$285 = $336;$290 = $370;$292 = $371;$294 = $372;$296 = $358;$298 = $359;$300 = $360;$377 = $376;$379 = $378;$381 = $380;$386 = $385;$388 = $387;$390 = $389;$392 = $391;$394 = $393;$396 = $395;$401 = $400;$403 = $402;$405 = $404;$i3$01540 = $246;
     }
    }
   }
   $406 = (($currPtr$01595) + 24|0);
   $407 = Math_fround(HEAPF32[$406>>2]);
   $408 = Math_fround($409 * $407);
   $410 = Math_fround($411 * $407);
   $412 = Math_fround($413 * $407);
   $414 = Math_fround($415 + $408);
   $416 = Math_fround($417 + $410);
   $418 = Math_fround($419 + $412);
   $420 = (($currPtr$01595) + 8|0);
   $421 = Math_fround(HEAPF32[$420>>2]);
   $422 = Math_fround($423 * $421);
   $424 = Math_fround($425 * $421);
   $426 = Math_fround($427 * $421);
   $428 = Math_fround($429 + $422);
   $430 = Math_fround($431 + $424);
   $432 = Math_fround($433 + $426);
   $434 = (($currPtr$01595) + 28|0);
   $435 = Math_fround(HEAPF32[$434>>2]);
   $436 = Math_fround($437 * $435);
   $438 = Math_fround($439 * $435);
   $440 = Math_fround($441 * $435);
   $442 = Math_fround($443 - $436);
   $444 = Math_fround($445 - $438);
   $446 = Math_fround($447 - $440);
   $448 = (($currPtr$01595) + 12|0);
   $449 = Math_fround(HEAPF32[$448>>2]);
   $450 = Math_fround($451 * $449);
   $452 = Math_fround($453 * $449);
   $454 = Math_fround($455 * $449);
   $456 = Math_fround($457 - $450);
   $458 = Math_fround($459 - $452);
   $460 = Math_fround($461 - $454);
   $462 = ($79>>>0)<($67>>>0);
   if ($462) {
    $415 = $414;$417 = $416;$419 = $418;$429 = $428;$431 = $430;$433 = $432;$443 = $442;$445 = $444;$447 = $446;$457 = $456;$459 = $458;$461 = $460;$507 = $530;$508 = $529;$509 = $528;$510 = $527;$511 = $526;$512 = $525;$513 = $524;$514 = $523;$515 = $522;$516 = $521;$517 = $520;$518 = $519;$currPtr$01595 = $79;
   } else {
    $$lcssa1571 = $519;$$lcssa1572 = $520;$$lcssa1573 = $521;$$lcssa1574 = $522;$$lcssa1575 = $523;$$lcssa1576 = $524;$$lcssa1577 = $525;$$lcssa1578 = $526;$$lcssa1579 = $527;$$lcssa1580 = $528;$$lcssa1581 = $529;$$lcssa1582 = $530;$$lcssa1583 = $418;$$lcssa1584 = $416;$$lcssa1585 = $414;$$lcssa1586 = $446;$$lcssa1587 = $444;$$lcssa1588 = $442;$$lcssa1589 = $432;$$lcssa1590 = $430;$$lcssa1591 = $428;$$lcssa1592 = $460;$$lcssa1593 = $458;$$lcssa1594 = $456;
    break;
   }
  }
 }
 $463 = HEAP16[$4>>1]|0;
 $464 = ($463<<16>>16)==(-1);
 if ($464) {
  $465 = HEAP32[$desc>>2]|0;
  HEAPF32[$465>>2] = $$lcssa1573;
  $466 = (($465) + 4|0);
  HEAPF32[$466>>2] = $$lcssa1572;
  $467 = (($465) + 8|0);
  HEAPF32[$467>>2] = $$lcssa1571;
  $468 = (($465) + 16|0);
  HEAPF32[$468>>2] = $$lcssa1576;
  $469 = (($465) + 20|0);
  HEAPF32[$469>>2] = $$lcssa1575;
  $470 = (($465) + 24|0);
  HEAPF32[$470>>2] = $$lcssa1574;
 } else {
  $471 = $463&65535;
  $472 = HEAP32[$desc>>2]|0;
  HEAPF32[$0>>2] = $$lcssa1585;
  $473 = (($0) + 4|0);
  HEAPF32[$473>>2] = $$lcssa1584;
  $474 = (($0) + 8|0);
  HEAPF32[$474>>2] = $$lcssa1583;
  $475 = (($0) + 12|0);
  HEAPF32[$475>>2] = Math_fround(0.0);
  HEAPF32[$1>>2] = $$lcssa1591;
  $476 = (($1) + 4|0);
  HEAPF32[$476>>2] = $$lcssa1590;
  $477 = (($1) + 8|0);
  HEAPF32[$477>>2] = $$lcssa1589;
  $478 = (($1) + 12|0);
  HEAPF32[$478>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$0+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$1+12>>2]|0;
  __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($472,$471,$$byval_copy2,$$byval_copy3);
 }
 $479 = HEAP16[$32>>1]|0;
 $480 = ($479<<16>>16)==(-1);
 if ($480) {
  $481 = HEAP32[$35>>2]|0;
  HEAPF32[$481>>2] = $$lcssa1579;
  $482 = (($481) + 4|0);
  HEAPF32[$482>>2] = $$lcssa1578;
  $483 = (($481) + 8|0);
  HEAPF32[$483>>2] = $$lcssa1577;
  $484 = (($481) + 16|0);
  HEAPF32[$484>>2] = $$lcssa1582;
  $485 = (($481) + 20|0);
  HEAPF32[$485>>2] = $$lcssa1581;
  $486 = (($481) + 24|0);
  HEAPF32[$486>>2] = $$lcssa1580;
  STACKTOP = sp;return;
 } else {
  $487 = $479&65535;
  $488 = HEAP32[$35>>2]|0;
  HEAPF32[$2>>2] = $$lcssa1588;
  $489 = (($2) + 4|0);
  HEAPF32[$489>>2] = $$lcssa1587;
  $490 = (($2) + 8|0);
  HEAPF32[$490>>2] = $$lcssa1586;
  $491 = (($2) + 12|0);
  HEAPF32[$491>>2] = Math_fround(0.0);
  HEAPF32[$3>>2] = $$lcssa1594;
  $492 = (($3) + 4|0);
  HEAPF32[$492>>2] = $$lcssa1593;
  $493 = (($3) + 8|0);
  HEAPF32[$493>>2] = $$lcssa1592;
  $494 = (($3) + 12|0);
  HEAPF32[$494>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$2+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$3+12>>2]|0;
  __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($488,$487,$$byval_copy2,$$byval_copy3);
  STACKTOP = sp;return;
 }
}
function __ZN5physx20solveExtContactBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx15solveExtContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx28solveExtContactConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx15solveExtContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  __ZN5physx15concludeContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx29solveExtContactBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$thresholdStream,$0,$outThresholdPairs) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $0 = $0|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$02 = 0, $a1$01 = 0, $exitcond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ($constraintCount|0)==(0);
 if (!($1)) {
  $2 = (($cache) + 16|0);
  $a$02 = 0;
  while(1) {
   $3 = (($desc) + ($a$02<<5)|0);
   $4 = ((($desc) + ($a$02<<5)|0) + 8|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = ($5<<16>>16)==(-1);
   if ($6) {
    $7 = ((($desc) + ($a$02<<5)|0) + 10|0);
    $8 = HEAP16[$7>>1]|0;
    $9 = $8&65535;
    $12 = $9;
   } else {
    $12 = 0;
   }
   $10 = HEAP32[$2>>2]|0;
   $11 = (($10) + ($12<<6)|0);
   $13 = ((($desc) + ($a$02<<5)|0) + 12|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = ($14<<16>>16)==(-1);
   if ($15) {
    $16 = ((($desc) + ($a$02<<5)|0) + 14|0);
    $17 = HEAP16[$16>>1]|0;
    $18 = $17&65535;
    $20 = $18;
   } else {
    $20 = 0;
   }
   $19 = (($10) + ($20<<6)|0);
   __ZN5physx15solveExtContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($3,$cache);
   __ZN5physx16writeBackContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($3,$cache,$11,$19);
   $21 = (($a$02) + 1)|0;
   $exitcond = ($21|0)==($constraintCount|0);
   if ($exitcond) {
    break;
   } else {
    $a$02 = $21;
   }
  }
 }
 $22 = (($cache) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$23)|0);
 $26 = HEAP32[$22>>2]|0;
 $27 = (($25) - ($26))|0;
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($cache) + 4|0);
  $a1$01 = 0;
  while(1) {
   $30 = (($27) + ($a1$01))|0;
   $31 = (($thresholdStream) + ($30<<4)|0);
   $32 = HEAP32[$29>>2]|0;
   $33 = (($32) + ($a1$01<<4)|0);
   ;HEAP32[$31+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$33+12>>2]|0;
   $34 = (($a1$01) + 1)|0;
   $35 = HEAP32[$22>>2]|0;
   $36 = ($34>>>0)<($35>>>0);
   if ($36) {
    $a1$01 = $34;
   } else {
    break;
   }
  }
 }
 HEAP32[$22>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx15solveExt1DBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx10solveExt1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23solveExt1DConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx10solveExt1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  __ZN5physx10conclude1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx24solveExt1DBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$0,$1,$2) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($constraintCount|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($cache) + 16|0);
 $a$01 = 0;
 while(1) {
  $5 = (($desc) + ($a$01<<5)|0);
  $6 = ((($desc) + ($a$01<<5)|0) + 8|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = ($7<<16>>16)==(-1);
  if ($8) {
   $9 = ((($desc) + ($a$01<<5)|0) + 10|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = $10&65535;
   $14 = $11;
  } else {
   $14 = 0;
  }
  $12 = HEAP32[$4>>2]|0;
  $13 = (($12) + ($14<<6)|0);
  $15 = ((($desc) + ($a$01<<5)|0) + 12|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = ($16<<16>>16)==(-1);
  if ($17) {
   $18 = ((($desc) + ($a$01<<5)|0) + 14|0);
   $19 = HEAP16[$18>>1]|0;
   $20 = $19&65535;
   $22 = $20;
  } else {
   $22 = 0;
  }
  $21 = (($12) + ($22<<6)|0);
  __ZN5physx10solveExt1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($5,0);
  __ZN5physx11writeBack1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($5,$cache,$13,$21);
  $23 = (($a$01) + 1)|0;
  $exitcond = ($23|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $23;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx22solveExtContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i = Math_fround(0), $$byval_copy2 = 0, $$byval_copy3 = 0, $$lcssa = Math_fround(0), $$lcssa696 = Math_fround(0), $$lcssa697 = Math_fround(0), $$lcssa698 = Math_fround(0), $$lcssa699 = Math_fround(0), $$lcssa700 = Math_fround(0), $$lcssa701 = Math_fround(0), $$lcssa702 = Math_fround(0), $$lcssa703 = Math_fround(0), $$lcssa704 = Math_fround(0), $$lcssa705 = Math_fround(0), $$lcssa706 = Math_fround(0), $$lcssa707 = Math_fround(0), $$lcssa708 = Math_fround(0), $$lcssa709 = Math_fround(0), $$lcssa710 = Math_fround(0), $$lcssa711 = Math_fround(0);
 var $$lcssa712 = Math_fround(0), $$lcssa713 = Math_fround(0), $$lcssa714 = Math_fround(0), $$lcssa715 = Math_fround(0), $$lcssa716 = Math_fround(0), $$lcssa717 = Math_fround(0), $$lcssa718 = Math_fround(0), $$lcssa743 = Math_fround(0), $$lcssa744 = Math_fround(0), $$lcssa745 = Math_fround(0), $$lcssa746 = Math_fround(0), $$lcssa747 = Math_fround(0), $$lcssa748 = Math_fround(0), $$lcssa749 = Math_fround(0), $$lcssa750 = Math_fround(0), $$lcssa751 = Math_fround(0), $$lcssa752 = Math_fround(0), $$lcssa753 = Math_fround(0), $$lcssa754 = Math_fround(0), $$lcssa755 = Math_fround(0);
 var $$lcssa756 = Math_fround(0), $$lcssa757 = Math_fround(0), $$lcssa758 = Math_fround(0), $$lcssa759 = Math_fround(0), $$lcssa760 = Math_fround(0), $$lcssa761 = Math_fround(0), $$lcssa762 = Math_fround(0), $$lcssa763 = Math_fround(0), $$lcssa764 = Math_fround(0), $$lcssa765 = Math_fround(0), $$lcssa766 = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $$sum695 = 0, $$sum834 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0);
 var $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0);
 var $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0);
 var $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0);
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0);
 var $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0);
 var $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0);
 var $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0);
 var $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0);
 var $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $currPtr$0767 = 0, $exitcond = 0, $i$0719 = 0, $v = 0, $v1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy3 = sp + 144|0;
 $$byval_copy2 = sp;
 $v = sp + 16|0;
 $v1 = sp + 48|0;
 $1 = sp + 80|0;
 $2 = sp + 96|0;
 $3 = sp + 112|0;
 $4 = sp + 128|0;
 $5 = (($desc) + 8|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = ($6<<16>>16)==(-1);
 if ($7) {
  $8 = HEAP32[$desc>>2]|0;
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($8) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($8) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($8) + 16|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($8) + 20|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($8) + 24|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $309 = $13;$310 = $11;$311 = $9;$312 = $19;$313 = $17;$314 = $15;
 } else {
  $20 = $6&65535;
  $21 = HEAP32[$desc>>2]|0;
  __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($v,$21,$20);
  $22 = Math_fround(HEAPF32[$v>>2]);
  $23 = (($v) + 4|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($v) + 8|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($v) + 16|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($v) + 20|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($v) + 24|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $309 = $26;$310 = $24;$311 = $22;$312 = $32;$313 = $30;$314 = $28;
 }
 $33 = (($desc) + 12|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = ($34<<16>>16)==(-1);
 $36 = (($desc) + 4|0);
 if ($35) {
  $37 = HEAP32[$36>>2]|0;
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($37) + 4|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($37) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($37) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($37) + 20|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($37) + 24|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $315 = $42;$316 = $40;$317 = $38;$318 = $48;$319 = $46;$320 = $44;
 } else {
  $49 = $34&65535;
  $50 = HEAP32[$36>>2]|0;
  __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($v1,$50,$49);
  $51 = Math_fround(HEAPF32[$v1>>2]);
  $52 = (($v1) + 4|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($v1) + 8|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($v1) + 16|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($v1) + 20|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($v1) + 24|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $315 = $55;$316 = $53;$317 = $51;$318 = $61;$319 = $59;$320 = $57;
 }
 $62 = (($desc) + 16|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 2|0);
 $65 = HEAP16[$64>>1]|0;
 $66 = $65&65535;
 $67 = (($63) + ($66)|0);
 $68 = ($65<<16>>16)==(0);
 L9: do {
  if ($68) {
   $$lcssa743 = $309;$$lcssa744 = $310;$$lcssa745 = $311;$$lcssa746 = $312;$$lcssa747 = $313;$$lcssa748 = $314;$$lcssa749 = $315;$$lcssa750 = $316;$$lcssa751 = $317;$$lcssa752 = $318;$$lcssa753 = $319;$$lcssa754 = $320;$$lcssa755 = Math_fround(0.0);$$lcssa756 = Math_fround(0.0);$$lcssa757 = Math_fround(0.0);$$lcssa758 = Math_fround(0.0);$$lcssa759 = Math_fround(0.0);$$lcssa760 = Math_fround(0.0);$$lcssa761 = Math_fround(0.0);$$lcssa762 = Math_fround(0.0);$$lcssa763 = Math_fround(0.0);$$lcssa764 = Math_fround(0.0);$$lcssa765 = Math_fround(0.0);$$lcssa766 = Math_fround(0.0);
  } else {
   $238 = Math_fround(0.0);$240 = Math_fround(0.0);$242 = Math_fround(0.0);$249 = Math_fround(0.0);$251 = Math_fround(0.0);$253 = Math_fround(0.0);$260 = Math_fround(0.0);$262 = Math_fround(0.0);$264 = Math_fround(0.0);$271 = Math_fround(0.0);$273 = Math_fround(0.0);$275 = Math_fround(0.0);$321 = $320;$322 = $319;$323 = $318;$324 = $317;$325 = $316;$326 = $315;$327 = $314;$328 = $313;$329 = $312;$330 = $311;$331 = $310;$332 = $309;$74 = $65;$currPtr$0767 = $63;
   while(1) {
    $69 = (($currPtr$0767) + 48|0);
    $70 = (($currPtr$0767) + 1|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = $71&255;
    $73 = $74&65535;
    $$sum = (($73) + 32)|0;
    $75 = (($currPtr$0767) + ($$sum)|0);
    $76 = ($72*112)|0;
    $$sum1 = (($76) + 48)|0;
    $77 = (($currPtr$0767) + ($$sum1)|0);
    $78 = (($currPtr$0767) + 16|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = (($currPtr$0767) + 20|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = (($currPtr$0767) + 24|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = ($71<<24>>24)==(0);
    if ($84) {
     $$lcssa = $332;$$lcssa696 = $331;$$lcssa697 = $330;$$lcssa698 = $329;$$lcssa699 = $328;$$lcssa700 = $327;$$lcssa701 = $326;$$lcssa702 = $325;$$lcssa703 = $324;$$lcssa704 = $323;$$lcssa705 = $322;$$lcssa706 = $321;$$lcssa707 = Math_fround(0.0);$$lcssa708 = Math_fround(0.0);$$lcssa709 = Math_fround(0.0);$$lcssa710 = Math_fround(0.0);$$lcssa711 = Math_fround(0.0);$$lcssa712 = Math_fround(0.0);$$lcssa713 = Math_fround(0.0);$$lcssa714 = Math_fround(0.0);$$lcssa715 = Math_fround(0.0);$$lcssa716 = Math_fround(0.0);$$lcssa717 = Math_fround(0.0);$$lcssa718 = Math_fround(0.0);
    } else {
     $108 = $327;$110 = $328;$112 = $329;$114 = $330;$116 = $331;$118 = $332;$123 = $321;$125 = $322;$127 = $323;$129 = $324;$131 = $325;$133 = $326;$200 = Math_fround(0.0);$202 = Math_fround(0.0);$204 = Math_fround(0.0);$209 = Math_fround(0.0);$211 = Math_fround(0.0);$213 = Math_fround(0.0);$215 = Math_fround(0.0);$217 = Math_fround(0.0);$219 = Math_fround(0.0);$224 = Math_fround(0.0);$226 = Math_fround(0.0);$228 = Math_fround(0.0);$i$0719 = 0;
     while(1) {
      $85 = (($i$0719) + 1)|0;
      $86 = (($69) + (($85*112)|0)|0);
      $87 = ((($69) + (($i$0719*112)|0)|0) + 16|0);
      $88 = Math_fround(HEAPF32[$87>>2]);
      $89 = ((($69) + (($i$0719*112)|0)|0) + 20|0);
      $90 = Math_fround(HEAPF32[$89>>2]);
      $91 = ((($69) + (($i$0719*112)|0)|0) + 24|0);
      $92 = Math_fround(HEAPF32[$91>>2]);
      $93 = ((($69) + (($i$0719*112)|0)|0) + 28|0);
      $94 = Math_fround(HEAPF32[$93>>2]);
      $95 = (($69) + (($i$0719*112)|0)|0);
      $96 = Math_fround(HEAPF32[$95>>2]);
      $97 = ((($69) + (($i$0719*112)|0)|0) + 4|0);
      $98 = Math_fround(HEAPF32[$97>>2]);
      $99 = ((($69) + (($i$0719*112)|0)|0) + 8|0);
      $100 = Math_fround(HEAPF32[$99>>2]);
      $101 = ((($69) + (($i$0719*112)|0)|0) + 12|0);
      $102 = Math_fround(HEAPF32[$101>>2]);
      $103 = ((($69) + (($i$0719*112)|0)|0) + 36|0);
      $104 = Math_fround(HEAPF32[$103>>2]);
      $105 = ((($69) + (($i$0719*112)|0)|0) + 32|0);
      $106 = Math_fround(HEAPF32[$105>>2]);
      $107 = Math_fround($108 * $96);
      $109 = Math_fround($110 * $98);
      $111 = Math_fround($112 * $100);
      $113 = Math_fround($79 * $114);
      $115 = Math_fround($81 * $116);
      $117 = Math_fround($83 * $118);
      $119 = Math_fround($113 + $107);
      $120 = Math_fround($115 + $109);
      $121 = Math_fround($117 + $111);
      $122 = Math_fround($123 * $88);
      $124 = Math_fround($125 * $90);
      $126 = Math_fround($127 * $92);
      $128 = Math_fround($79 * $129);
      $130 = Math_fround($81 * $131);
      $132 = Math_fround($83 * $133);
      $134 = Math_fround($128 + $122);
      $135 = Math_fround($130 + $124);
      $136 = Math_fround($132 + $126);
      $137 = Math_fround($119 - $134);
      $138 = Math_fround($120 - $135);
      $139 = Math_fround($121 - $136);
      $140 = Math_fround($137 + $138);
      $141 = Math_fround($140 + $139);
      $142 = Math_fround($94 * $104);
      $143 = Math_fround($142 - $106);
      $144 = Math_fround($94 * $141);
      $145 = Math_fround($143 - $144);
      $146 = Math_fround(-$102);
      $147 = $145 > $146;
      $$$i = $147 ? $145 : $146;
      $148 = ((($69) + (($i$0719*112)|0)|0) + 80|0);
      $149 = Math_fround(HEAPF32[$148>>2]);
      $150 = ((($69) + (($i$0719*112)|0)|0) + 84|0);
      $151 = Math_fround(HEAPF32[$150>>2]);
      $152 = ((($69) + (($i$0719*112)|0)|0) + 88|0);
      $153 = Math_fround(HEAPF32[$152>>2]);
      $154 = Math_fround($149 * $$$i);
      $155 = Math_fround($151 * $$$i);
      $156 = Math_fround($153 * $$$i);
      $157 = Math_fround($114 + $154);
      $158 = Math_fround($116 + $155);
      $159 = Math_fround($118 + $156);
      $160 = ((($69) + (($i$0719*112)|0)|0) + 48|0);
      $161 = Math_fround(HEAPF32[$160>>2]);
      $162 = ((($69) + (($i$0719*112)|0)|0) + 52|0);
      $163 = Math_fround(HEAPF32[$162>>2]);
      $164 = ((($69) + (($i$0719*112)|0)|0) + 56|0);
      $165 = Math_fround(HEAPF32[$164>>2]);
      $166 = Math_fround($161 * $$$i);
      $167 = Math_fround($163 * $$$i);
      $168 = Math_fround($$$i * $165);
      $169 = Math_fround($108 + $166);
      $170 = Math_fround($110 + $167);
      $171 = Math_fround($112 + $168);
      $172 = ((($69) + (($i$0719*112)|0)|0) + 96|0);
      $173 = Math_fround(HEAPF32[$172>>2]);
      $174 = ((($69) + (($i$0719*112)|0)|0) + 100|0);
      $175 = Math_fround(HEAPF32[$174>>2]);
      $176 = ((($69) + (($i$0719*112)|0)|0) + 104|0);
      $177 = Math_fround(HEAPF32[$176>>2]);
      $178 = Math_fround($$$i * $173);
      $179 = Math_fround($$$i * $175);
      $180 = Math_fround($$$i * $177);
      $181 = Math_fround($129 + $178);
      $182 = Math_fround($131 + $179);
      $183 = Math_fround($133 + $180);
      $184 = ((($69) + (($i$0719*112)|0)|0) + 64|0);
      $185 = Math_fround(HEAPF32[$184>>2]);
      $186 = ((($69) + (($i$0719*112)|0)|0) + 68|0);
      $187 = Math_fround(HEAPF32[$186>>2]);
      $188 = ((($69) + (($i$0719*112)|0)|0) + 72|0);
      $189 = Math_fround(HEAPF32[$188>>2]);
      $190 = Math_fround($$$i * $185);
      $191 = Math_fround($$$i * $187);
      $192 = Math_fround($$$i * $189);
      $193 = Math_fround($123 + $190);
      $194 = Math_fround($125 + $191);
      $195 = Math_fround($127 + $192);
      $196 = Math_fround($79 * $$$i);
      $197 = Math_fround($81 * $$$i);
      $198 = Math_fround($83 * $$$i);
      $199 = Math_fround($200 + $196);
      $201 = Math_fround($202 + $197);
      $203 = Math_fround($204 + $198);
      $205 = Math_fround($96 * $$$i);
      $206 = Math_fround($98 * $$$i);
      $207 = Math_fround($100 * $$$i);
      $208 = Math_fround($209 + $205);
      $210 = Math_fround($211 + $206);
      $212 = Math_fround($213 + $207);
      $214 = Math_fround($215 + $196);
      $216 = Math_fround($217 + $197);
      $218 = Math_fround($219 + $198);
      $220 = Math_fround($88 * $$$i);
      $221 = Math_fround($90 * $$$i);
      $222 = Math_fround($92 * $$$i);
      $223 = Math_fround($224 + $220);
      $225 = Math_fround($226 + $221);
      $227 = Math_fround($228 + $222);
      $229 = Math_fround($102 + $$$i);
      HEAPF32[$101>>2] = $229;
      $230 = (($75) + ($i$0719<<2)|0);
      HEAPF32[$230>>2] = $229;
      $$sum695 = (($i$0719) + 32)|0;
      $231 = (($75) + ($$sum695<<2)|0);
      $exitcond = ($85|0)==($72|0);
      if ($exitcond) {
       $$lcssa = $159;$$lcssa696 = $158;$$lcssa697 = $157;$$lcssa698 = $171;$$lcssa699 = $170;$$lcssa700 = $169;$$lcssa701 = $183;$$lcssa702 = $182;$$lcssa703 = $181;$$lcssa704 = $195;$$lcssa705 = $194;$$lcssa706 = $193;$$lcssa707 = $203;$$lcssa708 = $201;$$lcssa709 = $199;$$lcssa710 = $218;$$lcssa711 = $216;$$lcssa712 = $214;$$lcssa713 = $212;$$lcssa714 = $210;$$lcssa715 = $208;$$lcssa716 = $227;$$lcssa717 = $225;$$lcssa718 = $223;
       break;
      } else {
       $108 = $169;$110 = $170;$112 = $171;$114 = $157;$116 = $158;$118 = $159;$123 = $193;$125 = $194;$127 = $195;$129 = $181;$131 = $182;$133 = $183;$200 = $199;$202 = $201;$204 = $203;$209 = $208;$211 = $210;$213 = $212;$215 = $214;$217 = $216;$219 = $218;$224 = $223;$226 = $225;$228 = $227;$i$0719 = $85;
      }
     }
    }
    $232 = (($currPtr$0767) + 8|0);
    $233 = Math_fround(HEAPF32[$232>>2]);
    $234 = Math_fround($$lcssa709 * $233);
    $235 = Math_fround($$lcssa708 * $233);
    $236 = Math_fround($$lcssa707 * $233);
    $237 = Math_fround($238 + $234);
    $239 = Math_fround($240 + $235);
    $241 = Math_fround($242 + $236);
    $243 = (($currPtr$0767) + 28|0);
    $244 = Math_fround(HEAPF32[$243>>2]);
    $245 = Math_fround($$lcssa715 * $244);
    $246 = Math_fround($$lcssa714 * $244);
    $247 = Math_fround($$lcssa713 * $244);
    $248 = Math_fround($249 + $245);
    $250 = Math_fround($251 + $246);
    $252 = Math_fround($253 + $247);
    $254 = (($currPtr$0767) + 12|0);
    $255 = Math_fround(HEAPF32[$254>>2]);
    $256 = Math_fround($$lcssa712 * $255);
    $257 = Math_fround($$lcssa711 * $255);
    $258 = Math_fround($$lcssa710 * $255);
    $259 = Math_fround($260 - $256);
    $261 = Math_fround($262 - $257);
    $263 = Math_fround($264 - $258);
    $265 = (($currPtr$0767) + 32|0);
    $266 = Math_fround(HEAPF32[$265>>2]);
    $267 = Math_fround($$lcssa718 * $266);
    $268 = Math_fround($$lcssa717 * $266);
    $269 = Math_fround($$lcssa716 * $266);
    $270 = Math_fround($271 - $267);
    $272 = Math_fround($273 - $268);
    $274 = Math_fround($275 - $269);
    $276 = ($77>>>0)<($67>>>0);
    if (!($276)) {
     $$lcssa743 = $$lcssa;$$lcssa744 = $$lcssa696;$$lcssa745 = $$lcssa697;$$lcssa746 = $$lcssa698;$$lcssa747 = $$lcssa699;$$lcssa748 = $$lcssa700;$$lcssa749 = $$lcssa701;$$lcssa750 = $$lcssa702;$$lcssa751 = $$lcssa703;$$lcssa752 = $$lcssa704;$$lcssa753 = $$lcssa705;$$lcssa754 = $$lcssa706;$$lcssa755 = $241;$$lcssa756 = $239;$$lcssa757 = $237;$$lcssa758 = $263;$$lcssa759 = $261;$$lcssa760 = $259;$$lcssa761 = $252;$$lcssa762 = $250;$$lcssa763 = $248;$$lcssa764 = $274;$$lcssa765 = $272;$$lcssa766 = $270;
     break L9;
    }
    $$sum834 = (($76) + 50)|0;
    $$phi$trans$insert = (($currPtr$0767) + ($$sum834)|0);
    $$pre = HEAP16[$$phi$trans$insert>>1]|0;
    $238 = $237;$240 = $239;$242 = $241;$249 = $248;$251 = $250;$253 = $252;$260 = $259;$262 = $261;$264 = $263;$271 = $270;$273 = $272;$275 = $274;$321 = $$lcssa706;$322 = $$lcssa705;$323 = $$lcssa704;$324 = $$lcssa703;$325 = $$lcssa702;$326 = $$lcssa701;$327 = $$lcssa700;$328 = $$lcssa699;$329 = $$lcssa698;$330 = $$lcssa697;$331 = $$lcssa696;$332 = $$lcssa;$74 = $$pre;$currPtr$0767 = $77;
   }
  }
 } while(0);
 $277 = HEAP16[$5>>1]|0;
 $278 = ($277<<16>>16)==(-1);
 if ($278) {
  $279 = HEAP32[$desc>>2]|0;
  HEAPF32[$279>>2] = $$lcssa745;
  $280 = (($279) + 4|0);
  HEAPF32[$280>>2] = $$lcssa744;
  $281 = (($279) + 8|0);
  HEAPF32[$281>>2] = $$lcssa743;
  $282 = (($279) + 16|0);
  HEAPF32[$282>>2] = $$lcssa748;
  $283 = (($279) + 20|0);
  HEAPF32[$283>>2] = $$lcssa747;
  $284 = (($279) + 24|0);
  HEAPF32[$284>>2] = $$lcssa746;
 } else {
  $285 = $277&65535;
  $286 = HEAP32[$desc>>2]|0;
  HEAPF32[$1>>2] = $$lcssa757;
  $287 = (($1) + 4|0);
  HEAPF32[$287>>2] = $$lcssa756;
  $288 = (($1) + 8|0);
  HEAPF32[$288>>2] = $$lcssa755;
  $289 = (($1) + 12|0);
  HEAPF32[$289>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = $$lcssa763;
  $290 = (($2) + 4|0);
  HEAPF32[$290>>2] = $$lcssa762;
  $291 = (($2) + 8|0);
  HEAPF32[$291>>2] = $$lcssa761;
  $292 = (($2) + 12|0);
  HEAPF32[$292>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$2+12>>2]|0;
  __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($286,$285,$$byval_copy2,$$byval_copy3);
 }
 $293 = HEAP16[$33>>1]|0;
 $294 = ($293<<16>>16)==(-1);
 if ($294) {
  $295 = HEAP32[$36>>2]|0;
  HEAPF32[$295>>2] = $$lcssa751;
  $296 = (($295) + 4|0);
  HEAPF32[$296>>2] = $$lcssa750;
  $297 = (($295) + 8|0);
  HEAPF32[$297>>2] = $$lcssa749;
  $298 = (($295) + 16|0);
  HEAPF32[$298>>2] = $$lcssa754;
  $299 = (($295) + 20|0);
  HEAPF32[$299>>2] = $$lcssa753;
  $300 = (($295) + 24|0);
  HEAPF32[$300>>2] = $$lcssa752;
  STACKTOP = sp;return;
 } else {
  $301 = $293&65535;
  $302 = HEAP32[$36>>2]|0;
  HEAPF32[$3>>2] = $$lcssa760;
  $303 = (($3) + 4|0);
  HEAPF32[$303>>2] = $$lcssa759;
  $304 = (($3) + 8|0);
  HEAPF32[$304>>2] = $$lcssa758;
  $305 = (($3) + 12|0);
  HEAPF32[$305>>2] = Math_fround(0.0);
  HEAPF32[$4>>2] = $$lcssa766;
  $306 = (($4) + 4|0);
  HEAPF32[$306>>2] = $$lcssa765;
  $307 = (($4) + 8|0);
  HEAPF32[$307>>2] = $$lcssa764;
  $308 = (($4) + 12|0);
  HEAPF32[$308>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$3+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$4+12>>2]|0;
  __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($302,$301,$$byval_copy2,$$byval_copy3);
  STACKTOP = sp;return;
 }
}
function __ZN5physx16solveExtFrictionERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$0) {
 $desc = $desc|0;
 $0 = $0|0;
 var $$$i$i = Math_fround(0), $$$i8$i = Math_fround(0), $$byval_copy2 = 0, $$byval_copy3 = 0, $$lcssa = Math_fround(0), $$lcssa699 = Math_fround(0), $$lcssa700 = Math_fround(0), $$lcssa701 = Math_fround(0), $$lcssa702 = Math_fround(0), $$lcssa703 = Math_fround(0), $$lcssa704 = Math_fround(0), $$lcssa705 = Math_fround(0), $$lcssa706 = Math_fround(0), $$lcssa707 = Math_fround(0), $$lcssa708 = Math_fround(0), $$lcssa709 = Math_fround(0), $$lcssa710 = Math_fround(0), $$lcssa711 = Math_fround(0), $$lcssa712 = Math_fround(0), $$lcssa713 = Math_fround(0);
 var $$lcssa714 = Math_fround(0), $$lcssa715 = Math_fround(0), $$lcssa716 = Math_fround(0), $$lcssa717 = Math_fround(0), $$lcssa718 = Math_fround(0), $$lcssa719 = Math_fround(0), $$lcssa720 = Math_fround(0), $$lcssa721 = Math_fround(0), $$lcssa746 = Math_fround(0), $$lcssa747 = Math_fround(0), $$lcssa748 = Math_fround(0), $$lcssa749 = Math_fround(0), $$lcssa750 = Math_fround(0), $$lcssa751 = Math_fround(0), $$lcssa752 = Math_fround(0), $$lcssa753 = Math_fround(0), $$lcssa754 = Math_fround(0), $$lcssa755 = Math_fround(0), $$lcssa756 = Math_fround(0), $$lcssa757 = Math_fround(0);
 var $$lcssa758 = Math_fround(0), $$lcssa759 = Math_fround(0), $$lcssa760 = Math_fround(0), $$lcssa761 = Math_fround(0), $$lcssa762 = Math_fround(0), $$lcssa763 = Math_fround(0), $$lcssa764 = Math_fround(0), $$lcssa765 = Math_fround(0), $$lcssa766 = Math_fround(0), $$lcssa767 = Math_fround(0), $$lcssa768 = Math_fround(0), $$lcssa769 = Math_fround(0), $$sum = 0, $$sum1 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0);
 var $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0;
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0;
 var $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0;
 var $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0;
 var $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0;
 var $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0);
 var $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0;
 var $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $currPtr$0770 = 0, $exitcond = 0, $i$0722 = 0, $v = 0, $v1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy3 = sp + 144|0;
 $$byval_copy2 = sp;
 $v = sp + 16|0;
 $v1 = sp + 48|0;
 $1 = sp + 80|0;
 $2 = sp + 96|0;
 $3 = sp + 112|0;
 $4 = sp + 128|0;
 $5 = (($desc) + 8|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = ($6<<16>>16)==(-1);
 if ($7) {
  $8 = HEAP32[$desc>>2]|0;
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($8) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($8) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($8) + 16|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($8) + 20|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($8) + 24|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $314 = $13;$315 = $11;$316 = $9;$317 = $19;$318 = $17;$319 = $15;
 } else {
  $20 = $6&65535;
  $21 = HEAP32[$desc>>2]|0;
  __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($v,$21,$20);
  $22 = Math_fround(HEAPF32[$v>>2]);
  $23 = (($v) + 4|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($v) + 8|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($v) + 16|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($v) + 20|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($v) + 24|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $314 = $26;$315 = $24;$316 = $22;$317 = $32;$318 = $30;$319 = $28;
 }
 $33 = (($desc) + 12|0);
 $34 = HEAP16[$33>>1]|0;
 $35 = ($34<<16>>16)==(-1);
 $36 = (($desc) + 4|0);
 if ($35) {
  $37 = HEAP32[$36>>2]|0;
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($37) + 4|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($37) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($37) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($37) + 20|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($37) + 24|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $320 = $42;$321 = $40;$322 = $38;$323 = $48;$324 = $46;$325 = $44;
 } else {
  $49 = $34&65535;
  $50 = HEAP32[$36>>2]|0;
  __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($v1,$50,$49);
  $51 = Math_fround(HEAPF32[$v1>>2]);
  $52 = (($v1) + 4|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($v1) + 8|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($v1) + 16|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($v1) + 20|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($v1) + 24|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $320 = $55;$321 = $53;$322 = $51;$323 = $61;$324 = $59;$325 = $57;
 }
 $62 = (($desc) + 16|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($desc) + 26|0);
 $65 = HEAP16[$64>>1]|0;
 $66 = $65&65535;
 $67 = $66 << 4;
 $68 = (($63) + ($67)|0);
 $69 = ($65<<16>>16)==(0);
 if ($69) {
  $$lcssa746 = $314;$$lcssa747 = $315;$$lcssa748 = $316;$$lcssa749 = $317;$$lcssa750 = $318;$$lcssa751 = $319;$$lcssa752 = $320;$$lcssa753 = $321;$$lcssa754 = $322;$$lcssa755 = $323;$$lcssa756 = $324;$$lcssa757 = $325;$$lcssa758 = Math_fround(0.0);$$lcssa759 = Math_fround(0.0);$$lcssa760 = Math_fround(0.0);$$lcssa761 = Math_fround(0.0);$$lcssa762 = Math_fround(0.0);$$lcssa763 = Math_fround(0.0);$$lcssa764 = Math_fround(0.0);$$lcssa765 = Math_fround(0.0);$$lcssa766 = Math_fround(0.0);$$lcssa767 = Math_fround(0.0);$$lcssa768 = Math_fround(0.0);$$lcssa769 = Math_fround(0.0);
 } else {
  $243 = Math_fround(0.0);$245 = Math_fround(0.0);$247 = Math_fround(0.0);$254 = Math_fround(0.0);$256 = Math_fround(0.0);$258 = Math_fround(0.0);$265 = Math_fround(0.0);$267 = Math_fround(0.0);$269 = Math_fround(0.0);$276 = Math_fround(0.0);$278 = Math_fround(0.0);$280 = Math_fround(0.0);$326 = $325;$327 = $324;$328 = $323;$329 = $322;$330 = $321;$331 = $320;$332 = $319;$333 = $318;$334 = $317;$335 = $316;$336 = $315;$337 = $314;$currPtr$0770 = $63;
  while(1) {
   $70 = (($currPtr$0770) + 32|0);
   $71 = (($currPtr$0770) + 1|0);
   $72 = HEAP8[$71>>0]|0;
   $73 = $72&255;
   $74 = $73 << 2;
   $75 = (($74) + 12)|0;
   $76 = $75 & 2032;
   $$sum = (($76) + 32)|0;
   $77 = (($currPtr$0770) + ($$sum)|0);
   $78 = (($currPtr$0770) + 2|0);
   $79 = HEAP8[$78>>0]|0;
   $80 = $79&255;
   $81 = $80 << 7;
   $$sum1 = (($$sum) + ($81))|0;
   $82 = (($currPtr$0770) + ($$sum1)|0);
   $83 = (($currPtr$0770) + 4|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   $85 = ($79<<24>>24)==(0);
   if ($85) {
    $$lcssa = $337;$$lcssa699 = $336;$$lcssa700 = $335;$$lcssa701 = $334;$$lcssa702 = $333;$$lcssa703 = $332;$$lcssa704 = $331;$$lcssa705 = $330;$$lcssa706 = $329;$$lcssa707 = $328;$$lcssa708 = $327;$$lcssa709 = $326;$$lcssa710 = Math_fround(0.0);$$lcssa711 = Math_fround(0.0);$$lcssa712 = Math_fround(0.0);$$lcssa713 = Math_fround(0.0);$$lcssa714 = Math_fround(0.0);$$lcssa715 = Math_fround(0.0);$$lcssa716 = Math_fround(0.0);$$lcssa717 = Math_fround(0.0);$$lcssa718 = Math_fround(0.0);$$lcssa719 = Math_fround(0.0);$$lcssa720 = Math_fround(0.0);$$lcssa721 = Math_fround(0.0);
   } else {
    $117 = $335;$119 = $336;$122 = $337;$125 = $332;$127 = $333;$130 = $334;$133 = $329;$135 = $330;$138 = $331;$141 = $326;$143 = $327;$146 = $328;$208 = Math_fround(0.0);$210 = Math_fround(0.0);$212 = Math_fround(0.0);$217 = Math_fround(0.0);$219 = Math_fround(0.0);$221 = Math_fround(0.0);$223 = Math_fround(0.0);$225 = Math_fround(0.0);$227 = Math_fround(0.0);$232 = Math_fround(0.0);$234 = Math_fround(0.0);$236 = Math_fround(0.0);$i$0722 = 0;
    while(1) {
     $86 = (($i$0722) + 1)|0;
     $87 = (($77) + ($86<<7)|0);
     $88 = (($77) + ($i$0722<<7)|0);
     $89 = Math_fround(HEAPF32[$88>>2]);
     $90 = ((($77) + ($i$0722<<7)|0) + 4|0);
     $91 = Math_fround(HEAPF32[$90>>2]);
     $92 = ((($77) + ($i$0722<<7)|0) + 8|0);
     $93 = Math_fround(HEAPF32[$92>>2]);
     $94 = ((($77) + ($i$0722<<7)|0) + 12|0);
     $95 = ((($77) + ($i$0722<<7)|0) + 16|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $97 = ((($77) + ($i$0722<<7)|0) + 20|0);
     $98 = Math_fround(HEAPF32[$97>>2]);
     $99 = ((($77) + ($i$0722<<7)|0) + 24|0);
     $100 = Math_fround(HEAPF32[$99>>2]);
     $101 = ((($77) + ($i$0722<<7)|0) + 28|0);
     $102 = ((($77) + ($i$0722<<7)|0) + 32|0);
     $103 = Math_fround(HEAPF32[$102>>2]);
     $104 = ((($77) + ($i$0722<<7)|0) + 36|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = ((($77) + ($i$0722<<7)|0) + 40|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = Math_fround(HEAPF32[$94>>2]);
     $109 = Math_fround(HEAPF32[$101>>2]);
     $110 = ((($77) + ($i$0722<<7)|0) + 80|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = (($70) + ($111<<2)|0);
     $113 = Math_fround(HEAPF32[$112>>2]);
     $114 = Math_fround($84 * $113);
     $115 = Math_fround(-$114);
     $116 = Math_fround($117 * $89);
     $118 = Math_fround($119 * $91);
     $120 = Math_fround($116 + $118);
     $121 = Math_fround($122 * $93);
     $123 = Math_fround($120 + $121);
     $124 = Math_fround($125 * $96);
     $126 = Math_fround($127 * $98);
     $128 = Math_fround($124 + $126);
     $129 = Math_fround($130 * $100);
     $131 = Math_fround($128 + $129);
     $132 = Math_fround($133 * $89);
     $134 = Math_fround($135 * $91);
     $136 = Math_fround($132 + $134);
     $137 = Math_fround($138 * $93);
     $139 = Math_fround($136 + $137);
     $140 = Math_fround($141 * $103);
     $142 = Math_fround($143 * $105);
     $144 = Math_fround($140 + $142);
     $145 = Math_fround($146 * $107);
     $147 = Math_fround($144 + $145);
     $148 = Math_fround($123 + $131);
     $149 = Math_fround($139 + $147);
     $150 = Math_fround($148 - $149);
     $151 = Math_fround($109 * $150);
     $152 = Math_fround($108 - $151);
     $153 = $152 > $114;
     $$$i$i = $153 ? $114 : $152;
     $154 = $$$i$i > $115;
     $$$i8$i = $154 ? $$$i$i : $115;
     $155 = Math_fround($$$i8$i - $108);
     $156 = ((($77) + ($i$0722<<7)|0) + 96|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = ((($77) + ($i$0722<<7)|0) + 100|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = ((($77) + ($i$0722<<7)|0) + 104|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = Math_fround($157 * $155);
     $163 = Math_fround($159 * $155);
     $164 = Math_fround($161 * $155);
     $165 = Math_fround($117 + $162);
     $166 = Math_fround($119 + $163);
     $167 = Math_fround($122 + $164);
     $168 = ((($77) + ($i$0722<<7)|0) + 48|0);
     $169 = Math_fround(HEAPF32[$168>>2]);
     $170 = ((($77) + ($i$0722<<7)|0) + 52|0);
     $171 = Math_fround(HEAPF32[$170>>2]);
     $172 = ((($77) + ($i$0722<<7)|0) + 56|0);
     $173 = Math_fround(HEAPF32[$172>>2]);
     $174 = Math_fround($169 * $155);
     $175 = Math_fround($171 * $155);
     $176 = Math_fround($173 * $155);
     $177 = Math_fround($125 + $174);
     $178 = Math_fround($127 + $175);
     $179 = Math_fround($130 + $176);
     $180 = ((($77) + ($i$0722<<7)|0) + 112|0);
     $181 = Math_fround(HEAPF32[$180>>2]);
     $182 = ((($77) + ($i$0722<<7)|0) + 116|0);
     $183 = Math_fround(HEAPF32[$182>>2]);
     $184 = ((($77) + ($i$0722<<7)|0) + 120|0);
     $185 = Math_fround(HEAPF32[$184>>2]);
     $186 = Math_fround($181 * $155);
     $187 = Math_fround($155 * $183);
     $188 = Math_fround($155 * $185);
     $189 = Math_fround($133 + $186);
     $190 = Math_fround($135 + $187);
     $191 = Math_fround($138 + $188);
     $192 = ((($77) + ($i$0722<<7)|0) + 64|0);
     $193 = Math_fround(HEAPF32[$192>>2]);
     $194 = ((($77) + ($i$0722<<7)|0) + 68|0);
     $195 = Math_fround(HEAPF32[$194>>2]);
     $196 = ((($77) + ($i$0722<<7)|0) + 72|0);
     $197 = Math_fround(HEAPF32[$196>>2]);
     $198 = Math_fround($155 * $193);
     $199 = Math_fround($155 * $195);
     $200 = Math_fround($155 * $197);
     $201 = Math_fround($141 + $198);
     $202 = Math_fround($143 + $199);
     $203 = Math_fround($146 + $200);
     $204 = Math_fround($89 * $155);
     $205 = Math_fround($91 * $155);
     $206 = Math_fround($93 * $155);
     $207 = Math_fround($208 + $204);
     $209 = Math_fround($210 + $205);
     $211 = Math_fround($212 + $206);
     $213 = Math_fround($96 * $155);
     $214 = Math_fround($98 * $155);
     $215 = Math_fround($100 * $155);
     $216 = Math_fround($217 + $213);
     $218 = Math_fround($219 + $214);
     $220 = Math_fround($221 + $215);
     $222 = Math_fround($223 + $204);
     $224 = Math_fround($225 + $205);
     $226 = Math_fround($227 + $206);
     $228 = Math_fround($103 * $155);
     $229 = Math_fround($105 * $155);
     $230 = Math_fround($107 * $155);
     $231 = Math_fround($232 + $228);
     $233 = Math_fround($234 + $229);
     $235 = Math_fround($236 + $230);
     HEAPF32[$94>>2] = $$$i8$i;
     $exitcond = ($86|0)==($80|0);
     if ($exitcond) {
      $$lcssa = $167;$$lcssa699 = $166;$$lcssa700 = $165;$$lcssa701 = $179;$$lcssa702 = $178;$$lcssa703 = $177;$$lcssa704 = $191;$$lcssa705 = $190;$$lcssa706 = $189;$$lcssa707 = $203;$$lcssa708 = $202;$$lcssa709 = $201;$$lcssa710 = $211;$$lcssa711 = $209;$$lcssa712 = $207;$$lcssa713 = $226;$$lcssa714 = $224;$$lcssa715 = $222;$$lcssa716 = $220;$$lcssa717 = $218;$$lcssa718 = $216;$$lcssa719 = $235;$$lcssa720 = $233;$$lcssa721 = $231;
      break;
     } else {
      $117 = $165;$119 = $166;$122 = $167;$125 = $177;$127 = $178;$130 = $179;$133 = $189;$135 = $190;$138 = $191;$141 = $201;$143 = $202;$146 = $203;$208 = $207;$210 = $209;$212 = $211;$217 = $216;$219 = $218;$221 = $220;$223 = $222;$225 = $224;$227 = $226;$232 = $231;$234 = $233;$236 = $235;$i$0722 = $86;
     }
    }
   }
   $237 = (($currPtr$0770) + 8|0);
   $238 = Math_fround(HEAPF32[$237>>2]);
   $239 = Math_fround($$lcssa712 * $238);
   $240 = Math_fround($$lcssa711 * $238);
   $241 = Math_fround($$lcssa710 * $238);
   $242 = Math_fround($243 + $239);
   $244 = Math_fround($245 + $240);
   $246 = Math_fround($247 + $241);
   $248 = (($currPtr$0770) + 16|0);
   $249 = Math_fround(HEAPF32[$248>>2]);
   $250 = Math_fround($$lcssa718 * $249);
   $251 = Math_fround($$lcssa717 * $249);
   $252 = Math_fround($$lcssa716 * $249);
   $253 = Math_fround($254 + $250);
   $255 = Math_fround($256 + $251);
   $257 = Math_fround($258 + $252);
   $259 = (($currPtr$0770) + 12|0);
   $260 = Math_fround(HEAPF32[$259>>2]);
   $261 = Math_fround($$lcssa715 * $260);
   $262 = Math_fround($$lcssa714 * $260);
   $263 = Math_fround($$lcssa713 * $260);
   $264 = Math_fround($265 - $261);
   $266 = Math_fround($267 - $262);
   $268 = Math_fround($269 - $263);
   $270 = (($currPtr$0770) + 20|0);
   $271 = Math_fround(HEAPF32[$270>>2]);
   $272 = Math_fround($$lcssa721 * $271);
   $273 = Math_fround($$lcssa720 * $271);
   $274 = Math_fround($$lcssa719 * $271);
   $275 = Math_fround($276 - $272);
   $277 = Math_fround($278 - $273);
   $279 = Math_fround($280 - $274);
   $281 = ($82>>>0)<($68>>>0);
   if ($281) {
    $243 = $242;$245 = $244;$247 = $246;$254 = $253;$256 = $255;$258 = $257;$265 = $264;$267 = $266;$269 = $268;$276 = $275;$278 = $277;$280 = $279;$326 = $$lcssa709;$327 = $$lcssa708;$328 = $$lcssa707;$329 = $$lcssa706;$330 = $$lcssa705;$331 = $$lcssa704;$332 = $$lcssa703;$333 = $$lcssa702;$334 = $$lcssa701;$335 = $$lcssa700;$336 = $$lcssa699;$337 = $$lcssa;$currPtr$0770 = $82;
   } else {
    $$lcssa746 = $$lcssa;$$lcssa747 = $$lcssa699;$$lcssa748 = $$lcssa700;$$lcssa749 = $$lcssa701;$$lcssa750 = $$lcssa702;$$lcssa751 = $$lcssa703;$$lcssa752 = $$lcssa704;$$lcssa753 = $$lcssa705;$$lcssa754 = $$lcssa706;$$lcssa755 = $$lcssa707;$$lcssa756 = $$lcssa708;$$lcssa757 = $$lcssa709;$$lcssa758 = $246;$$lcssa759 = $244;$$lcssa760 = $242;$$lcssa761 = $268;$$lcssa762 = $266;$$lcssa763 = $264;$$lcssa764 = $257;$$lcssa765 = $255;$$lcssa766 = $253;$$lcssa767 = $279;$$lcssa768 = $277;$$lcssa769 = $275;
    break;
   }
  }
 }
 $282 = HEAP16[$5>>1]|0;
 $283 = ($282<<16>>16)==(-1);
 if ($283) {
  $284 = HEAP32[$desc>>2]|0;
  HEAPF32[$284>>2] = $$lcssa748;
  $285 = (($284) + 4|0);
  HEAPF32[$285>>2] = $$lcssa747;
  $286 = (($284) + 8|0);
  HEAPF32[$286>>2] = $$lcssa746;
  $287 = (($284) + 16|0);
  HEAPF32[$287>>2] = $$lcssa751;
  $288 = (($284) + 20|0);
  HEAPF32[$288>>2] = $$lcssa750;
  $289 = (($284) + 24|0);
  HEAPF32[$289>>2] = $$lcssa749;
 } else {
  $290 = $282&65535;
  $291 = HEAP32[$desc>>2]|0;
  HEAPF32[$1>>2] = $$lcssa760;
  $292 = (($1) + 4|0);
  HEAPF32[$292>>2] = $$lcssa759;
  $293 = (($1) + 8|0);
  HEAPF32[$293>>2] = $$lcssa758;
  $294 = (($1) + 12|0);
  HEAPF32[$294>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = $$lcssa766;
  $295 = (($2) + 4|0);
  HEAPF32[$295>>2] = $$lcssa765;
  $296 = (($2) + 8|0);
  HEAPF32[$296>>2] = $$lcssa764;
  $297 = (($2) + 12|0);
  HEAPF32[$297>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$2+12>>2]|0;
  __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($291,$290,$$byval_copy2,$$byval_copy3);
 }
 $298 = HEAP16[$33>>1]|0;
 $299 = ($298<<16>>16)==(-1);
 if ($299) {
  $300 = HEAP32[$36>>2]|0;
  HEAPF32[$300>>2] = $$lcssa754;
  $301 = (($300) + 4|0);
  HEAPF32[$301>>2] = $$lcssa753;
  $302 = (($300) + 8|0);
  HEAPF32[$302>>2] = $$lcssa752;
  $303 = (($300) + 16|0);
  HEAPF32[$303>>2] = $$lcssa757;
  $304 = (($300) + 20|0);
  HEAPF32[$304>>2] = $$lcssa756;
  $305 = (($300) + 24|0);
  HEAPF32[$305>>2] = $$lcssa755;
  STACKTOP = sp;return;
 } else {
  $306 = $298&65535;
  $307 = HEAP32[$36>>2]|0;
  HEAPF32[$3>>2] = $$lcssa763;
  $308 = (($3) + 4|0);
  HEAPF32[$308>>2] = $$lcssa762;
  $309 = (($3) + 8|0);
  HEAPF32[$309>>2] = $$lcssa761;
  $310 = (($3) + 12|0);
  HEAPF32[$310>>2] = Math_fround(0.0);
  HEAPF32[$4>>2] = $$lcssa769;
  $311 = (($4) + 4|0);
  HEAPF32[$311>>2] = $$lcssa768;
  $312 = (($4) + 8|0);
  HEAPF32[$312>>2] = $$lcssa767;
  $313 = (($4) + 12|0);
  HEAPF32[$313>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$3+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$4+12>>2]|0;
  __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($307,$306,$$byval_copy2,$$byval_copy3);
  STACKTOP = sp;return;
 }
}
function __ZN5physx21solveExtFrictionBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx16solveExtFrictionERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx30solveExtFrictionBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$0,$1,$2) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var $3 = 0, $4 = 0, $5 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $3 = ($constraintCount|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $4 = (($desc) + ($a$01<<5)|0);
  __ZN5physx16solveExtFrictionERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($4,0);
  $5 = (($a$01) + 1)|0;
  $exitcond = ($5|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx30solveConcludeExtContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache) {
 $desc = $desc|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22solveExtContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,0);
 __ZN5physx22concludeContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($desc,$cache);
 STACKTOP = sp;return;
}
function __ZN5physx27solveExtContactCoulombBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx22solveExtContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx35solveExtContactCoulombConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE($desc,$constraintCount,$cache) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $a$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constraintCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $a$01 = 0;
 }
 while(1) {
  $1 = (($desc) + ($a$01<<5)|0);
  __ZN5physx22solveExtContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,0);
  __ZN5physx22concludeContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($1,$cache);
  $2 = (($a$01) + 1)|0;
  $exitcond = ($2|0)==($constraintCount|0);
  if ($exitcond) {
   break;
  } else {
   $a$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx36solveExtContactCoulombBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi($desc,$constraintCount,$cache,$thresholdStream,$0,$outThresholdPairs) {
 $desc = $desc|0;
 $constraintCount = $constraintCount|0;
 $cache = $cache|0;
 $thresholdStream = $thresholdStream|0;
 $0 = $0|0;
 $outThresholdPairs = $outThresholdPairs|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$02 = 0, $a1$01 = 0, $exitcond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = ($constraintCount|0)==(0);
 if (!($1)) {
  $2 = (($cache) + 16|0);
  $a$02 = 0;
  while(1) {
   $3 = (($desc) + ($a$02<<5)|0);
   $4 = ((($desc) + ($a$02<<5)|0) + 8|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = ($5<<16>>16)==(-1);
   if ($6) {
    $7 = ((($desc) + ($a$02<<5)|0) + 10|0);
    $8 = HEAP16[$7>>1]|0;
    $9 = $8&65535;
    $12 = $9;
   } else {
    $12 = 0;
   }
   $10 = HEAP32[$2>>2]|0;
   $11 = (($10) + ($12<<6)|0);
   $13 = ((($desc) + ($a$02<<5)|0) + 12|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = ($14<<16>>16)==(-1);
   if ($15) {
    $16 = ((($desc) + ($a$02<<5)|0) + 14|0);
    $17 = HEAP16[$16>>1]|0;
    $18 = $17&65535;
    $20 = $18;
   } else {
    $20 = 0;
   }
   $19 = (($10) + ($20<<6)|0);
   __ZN5physx22solveExtContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE($3,0);
   __ZN5physx23writeBackContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextERNS_17PxcSolverBodyDataES6_($3,$cache,$11,$19);
   $21 = (($a$02) + 1)|0;
   $exitcond = ($21|0)==($constraintCount|0);
   if ($exitcond) {
    break;
   } else {
    $a$02 = $21;
   }
  }
 }
 $22 = (($cache) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (__ZN5physx6shdfnd9atomicAddEPVii($outThresholdPairs,$23)|0);
 $26 = HEAP32[$22>>2]|0;
 $27 = (($25) - ($26))|0;
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($cache) + 4|0);
  $a1$01 = 0;
  while(1) {
   $30 = (($27) + ($a1$01))|0;
   $31 = (($thresholdStream) + ($30<<4)|0);
   $32 = HEAP32[$29>>2]|0;
   $33 = (($32) + ($a1$01<<4)|0);
   ;HEAP32[$31+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$33+12>>2]|0;
   $34 = (($a1$01) + 1)|0;
   $35 = HEAP32[$22>>2]|0;
   $36 = ($34>>>0)<($35>>>0);
   if ($36) {
    $a1$01 = $34;
   } else {
    break;
   }
  }
 }
 HEAP32[$22>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsThreadContextC2EPNS_10PxsContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp;
 HEAP32[$this>>2] = 0;
 $1 = (($this) + 16|0);
 $2 = (($context) + 6164|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($context) + 6168|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($context) + 6172|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($context) + 5928|0);
 $9 = (($0) + 36|0);
 dest=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($0) + 40|0);
 $11 = (($0) + 56|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($0) + 60|0);
 $13 = (($0) + 76|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($0) + 80|0);
 $15 = (($0) + 96|0);
 ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($0) + 100|0);
 HEAP32[$16>>2] = $8;
 $17 = (($context) + 44|0);
 $18 = (($context) + 1444|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)!=(0);
 __ZN5physx18PxcNpThreadContextC2EfffRKNS_2Cm12RenderOutputERNS_17PxcNpMemBlockPoolEb($1,$3,$5,$7,$0,$17,$20);
 $21 = (($this) + 8952|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 9092|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 9100|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 9108|0);
 $25 = (($this) + 9268|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 9272|0);
 HEAP8[$26>>0] = 0;
 $27 = (($this) + 9276|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 9284|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 9292|0);
 $30 = (($this) + 9316|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 9344|0);
 $32 = (($this) + 9392|0);
 $33 = (($this) + 9412|0);
 ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;
 _memset(($24|0),0,144)|0;
 ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;HEAP32[$29+16>>2]=0|0;
 dest=$31+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsThreadContext12resizeArraysEjjjjj($this,$bodyCount,$cmCount,$contactConstraintDescCount,$frictionConstraintDescCount,$articulationCount) {
 $this = $this|0;
 $bodyCount = $bodyCount|0;
 $cmCount = $cmCount|0;
 $contactConstraintDescCount = $contactConstraintDescCount|0;
 $frictionConstraintDescCount = $frictionConstraintDescCount|0;
 $articulationCount = $articulationCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 9112|0);
 HEAP32[$0>>2] = 0;
 $1 = $bodyCount >>> 1;
 $2 = $1 | $bodyCount;
 $3 = $2 >>> 2;
 $4 = $3 | $2;
 $5 = $4 >>> 4;
 $6 = $5 | $4;
 $7 = $6 >>> 8;
 $8 = $7 | $6;
 $9 = $8 >>> 16;
 $10 = $9 | $8;
 $11 = (($10) + 1)|0;
 $12 = ($11>>>0)<(64);
 $13 = $12 ? 64 : $11;
 $14 = (($this) + 9116|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($13>>>0);
 if ($17) {
  $18 = (($this) + 9108|0);
  __ZN5physx6shdfnd5ArrayIPNS_11PxsBodyCoreENS0_19ReflectionAllocatorIS3_EEE8recreateEj($18,$13);
 }
 HEAP32[$0>>2] = $bodyCount;
 $19 = (($this) + 9124|0);
 HEAP32[$19>>2] = 0;
 $20 = (($bodyCount) + 63)|0;
 $21 = $20 & -64;
 $22 = (($this) + 9128|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($24>>>0)<($21>>>0);
 if ($25) {
  $26 = (($this) + 9120|0);
  __ZN5physx6shdfnd5ArrayINS_2Cm13SpatialVectorENS0_19ReflectionAllocatorIS3_EEE8recreateEj($26,$21);
 }
 HEAP32[$19>>2] = $bodyCount;
 $27 = (($this) + 9136|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 9140|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = $29 & 2147483647;
 $31 = ($30>>>0)<($21>>>0);
 if ($31) {
  $32 = (($this) + 9132|0);
  __ZN5physx6shdfnd5ArrayINS_2Cm13SpatialVectorENS0_19ReflectionAllocatorIS3_EEE8recreateEj($32,$21);
 }
 HEAP32[$27>>2] = $bodyCount;
 $33 = (($this) + 9144|0);
 $34 = (($this) + 9148|0);
 HEAP32[$34>>2] = 0;
 $35 = (($contactConstraintDescCount) + 63)|0;
 $36 = $35 & -64;
 $37 = (($this) + 9152|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 2147483647;
 $40 = ($39>>>0)<($36>>>0);
 if ($40) {
  __ZN5physx6shdfnd5ArrayINS_23PxcSolverConstraintDescENS0_19ReflectionAllocatorIS2_EEE8recreateEj($33,$36);
 }
 $41 = (($this) + 9172|0);
 HEAP32[$41>>2] = 0;
 $42 = (($contactConstraintDescCount) + 66)|0;
 $43 = $42 & -64;
 $44 = (($this) + 9176|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45 & 2147483647;
 $47 = ($46>>>0)<($43>>>0);
 if ($47) {
  $48 = (($this) + 9168|0);
  __ZN5physx6shdfnd5ArrayINS_23PxcSolverConstraintDescENS0_19ReflectionAllocatorIS2_EEE8recreateEj($48,$43);
 }
 $49 = (($this) + 9156|0);
 $50 = (($this) + 9160|0);
 HEAP32[$50>>2] = 0;
 $51 = (($frictionConstraintDescCount) + 63)|0;
 $52 = $51 & -64;
 $53 = (($this) + 9164|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 & 2147483647;
 $56 = ($55>>>0)<($52>>>0);
 if ($56) {
  __ZN5physx6shdfnd5ArrayINS_23PxcSolverConstraintDescENS0_19ReflectionAllocatorIS2_EEE8recreateEj($49,$52);
 }
 $57 = (($this) + 9348|0);
 HEAP32[$57>>2] = 0;
 $58 = $cmCount >>> 1;
 $59 = $58 | $cmCount;
 $60 = $59 >>> 2;
 $61 = $60 | $59;
 $62 = $61 >>> 4;
 $63 = $62 | $61;
 $64 = $63 >>> 8;
 $65 = $64 | $63;
 $66 = $65 >>> 16;
 $67 = $66 | $65;
 $68 = (($67) + 1)|0;
 $69 = ($68>>>0)<(64);
 $70 = $69 ? 64 : $68;
 $71 = (($this) + 9352|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $72 & 2147483647;
 $74 = ($73>>>0)<($70>>>0);
 if ($74) {
  $75 = (($this) + 9344|0);
  __ZN5physx6shdfnd5ArrayINS_25PxcThresholdStreamElementENS0_19ReflectionAllocatorIS2_EEE8recreateEj($75,$70);
 }
 HEAP32[$57>>2] = $cmCount;
 $76 = (($this) + 9372|0);
 HEAP32[$76>>2] = 0;
 $77 = $articulationCount >>> 1;
 $78 = $77 | $articulationCount;
 $79 = $78 >>> 2;
 $80 = $79 | $78;
 $81 = $80 >>> 4;
 $82 = $81 | $80;
 $83 = $82 >>> 8;
 $84 = $83 | $82;
 $85 = $84 >>> 16;
 $86 = $85 | $84;
 $87 = (($86) + 1)|0;
 $88 = ($87>>>0)<(16);
 $89 = $88 ? 16 : $87;
 $90 = (($this) + 9376|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = $91 & 2147483647;
 $93 = ($92>>>0)<($89>>>0);
 if (!($93)) {
  HEAP32[$76>>2] = $articulationCount;
  $95 = HEAP32[$33>>2]|0;
  $96 = (($this) + 9308|0);
  HEAP32[$96>>2] = $95;
  $97 = HEAP32[$49>>2]|0;
  $98 = (($this) + 9316|0);
  HEAP32[$98>>2] = $97;
  STACKTOP = sp;return;
 }
 $94 = (($this) + 9368|0);
 __ZN5physx6shdfnd5ArrayINS_25PxcArticulationSolverDescENS0_19ReflectionAllocatorIS2_EEE8recreateEj($94,$89);
 HEAP32[$76>>2] = $articulationCount;
 $95 = HEAP32[$33>>2]|0;
 $96 = (($this) + 9308|0);
 HEAP32[$96>>2] = $95;
 $97 = HEAP32[$49>>2]|0;
 $98 = (($this) + 9316|0);
 HEAP32[$98>>2] = $97;
 STACKTOP = sp;return;
}
function __ZN5physx16PxsThreadContext5resetEjj($this,$shapeCount,$cmCount) {
 $this = $this|0;
 $shapeCount = $shapeCount|0;
 $cmCount = $cmCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 360|0);
 __ZN5physx26PxcFrictionPatchStreamPair5resetEv($0);
 $1 = (($this) + 336|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 340|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 352|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 356|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 372|0);
 __ZN5physx20PxcNpCacheStreamPair5resetEv($5);
 $6 = (($this) + 9384|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 9380|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7 << 2;
 _memset(($9|0),0,($10|0))|0;
 $11 = (($cmCount) + 31)|0;
 $12 = $11 >>> 5;
 $13 = HEAP32[$6>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($12>>>0)>($14>>>0);
 if ($15) {
  $16 = (($this) + 9388|0);
  $17 = $12 << 2;
  $18 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($16,$17,502472,339)|0);
  $19 = HEAP32[$8>>2]|0;
  $20 = ($19|0)==(0|0);
  if (!($20)) {
   $21 = HEAP32[$6>>2]|0;
   $22 = $21 << 2;
   _memcpy(($18|0),($19|0),($22|0))|0;
   $23 = HEAP32[$6>>2]|0;
   $24 = ($23|0)>(-1);
   if ($24) {
    $25 = HEAP32[$8>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($16,$25);
   }
  }
  $26 = HEAP32[$6>>2]|0;
  $27 = $26 & 2147483647;
  $28 = (($18) + ($27<<2)|0);
  $29 = (($12) - ($26))|0;
  $30 = $29 << 2;
  _memset(($28|0),0,($30|0))|0;
  HEAP32[$8>>2] = $18;
  HEAP32[$6>>2] = $12;
 }
 $31 = (($this) + 9392|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 9396|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 9404|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 9400|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $34 << 2;
 _memset(($36|0),0,($37|0))|0;
 $38 = (($shapeCount) + 31)|0;
 $39 = $38 >>> 5;
 $40 = HEAP32[$33>>2]|0;
 $41 = $40 & 2147483647;
 $42 = ($39>>>0)>($41>>>0);
 if ($42) {
  $43 = (($this) + 9408|0);
  $44 = $39 << 2;
  $45 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($43,$44,502472,339)|0);
  $46 = HEAP32[$35>>2]|0;
  $47 = ($46|0)==(0|0);
  if (!($47)) {
   $48 = HEAP32[$33>>2]|0;
   $49 = $48 << 2;
   _memcpy(($45|0),($46|0),($49|0))|0;
   $50 = HEAP32[$33>>2]|0;
   $51 = ($50|0)>(-1);
   if ($51) {
    $52 = HEAP32[$35>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($43,$52);
   }
  }
  $53 = HEAP32[$33>>2]|0;
  $54 = $53 & 2147483647;
  $55 = (($45) + ($54<<2)|0);
  $56 = (($39) - ($53))|0;
  $57 = $56 << 2;
  _memset(($55|0),0,($57|0))|0;
  HEAP32[$35>>2] = $45;
  HEAP32[$33>>2] = $39;
 }
 $58 = (($this) + 9360|0);
 HEAP32[$58>>2] = 0;
 $59 = (($this) + 9144|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($this) + 9308|0);
 HEAP32[$61>>2] = $60;
 $62 = (($this) + 9156|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($this) + 9316|0);
 HEAP32[$64>>2] = $63;
 $65 = (($this) + 9300|0);
 HEAP32[$65>>2] = 0;
 $66 = (($this) + 9268|0);
 HEAP32[$66>>2] = 0;
 $67 = (($this) + 9292|0);
 HEAP32[$67>>2] = 0;
 $68 = (($this) + 9296|0);
 HEAP32[$68>>2] = 0;
 $69 = (($this) + 9272|0);
 HEAP8[$69>>0] = 0;
 $70 = (($this) + 8952|0);
 HEAP32[$70>>2] = 0;
 $71 = (($this) + 9092|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 9276|0);
 HEAP32[$72>>2] = 0;
 $73 = (($this) + 9100|0);
 HEAP32[$73>>2] = 0;
 $74 = (($this) + 9172|0);
 HEAP32[$74>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Cm13SpatialVectorENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 502656 : 502624;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,502544,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<5)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
    $30 = (($$012$i) + 16|0);
    $31 = (($$03$i) + 16|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    HEAPF32[$30>>2] = $32;
    $33 = (($$012$i) + 20|0);
    $34 = (($$03$i) + 20|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    HEAPF32[$33>>2] = $35;
    $36 = (($$012$i) + 24|0);
    $37 = (($$03$i) + 24|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    HEAPF32[$36>>2] = $38;
    $39 = (($$012$i) + 28|0);
    $40 = (($$03$i) + 28|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    HEAPF32[$39>>2] = $41;
   }
   $42 = (($$012$i) + 32|0);
   $43 = (($$03$i) + 32|0);
   $44 = ($42>>>0)<($15>>>0);
   if ($44) {
    $$012$i = $42;$$03$i = $43;
   } else {
    break;
   }
  }
 }
 $45 = (($this) + 8|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)>(-1);
 if (!($47)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$45>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$this>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  HEAP32[$this>>2] = $16;
  HEAP32[$45>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $50 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vii[$53 & 4095]($50,$48);
 HEAP32[$this>>2] = $16;
 HEAP32[$45>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_11PxsBodyCoreENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 502784 : 502624;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,502544,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx16PxcContactBoxBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$ = 0, $$1$i = 0, $$pre$i = Math_fround(0), $$pre185$i = Math_fround(0), $$pre186$i = Math_fround(0), $$pre187$i = Math_fround(0), $$pre188$i = Math_fround(0), $$pre189$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0;
 var $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0);
 var $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0);
 var $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0);
 var $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0);
 var $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0);
 var $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = 0;
 var $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0);
 var $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0);
 var $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0);
 var $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0);
 var $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0);
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0;
 var $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = 0, $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = Math_fround(0);
 var $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0);
 var $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0);
 var $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = Math_fround(0), $504 = Math_fround(0);
 var $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = 0;
 var $523 = 0, $524 = 0, $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = 0;
 var $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = 0, $558 = 0, $559 = 0;
 var $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = 0, $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0);
 var $578 = Math_fround(0), $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = 0, $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0);
 var $596 = 0, $597 = 0, $598 = 0, $599 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = 0, $606 = 0, $607 = 0, $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0;
 var $631 = 0, $632 = 0, $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = 0, $637 = 0, $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = 0, $642 = 0, $643 = 0, $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0);
 var $65 = Math_fround(0), $650 = 0, $651 = 0, $652 = 0, $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0);
 var $668 = Math_fround(0), $669 = 0, $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0;
 var $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $ctcNrm$i = 0, $d1$i = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i36$i = Math_fround(0), $fabsf$i$i37$i = Math_fround(0), $fabsf$i$i38$i = Math_fround(0), $fabsf$i$i39$i = Math_fround(0), $fabsf$i$i40$i = Math_fround(0), $fabsf$i$i41$i = Math_fround(0), $fabsf$i$i42$i = Math_fround(0), $fabsf$i$i43$i = Math_fround(0), $fabsf$i$i44$i = Math_fround(0), $fabsf$i$i45$i = Math_fround(0), $fabsf$i$i46$i = Math_fround(0), $fabsf$i$i47$i = Math_fround(0), $fabsf$i$i48$i = Math_fround(0), $fabsf$i$i49$i = Math_fround(0);
 var $fabsf$i$i50$i = Math_fround(0), $fabsf$i$i51$i = Math_fround(0), $fabsf$i$i52$i = Math_fround(0), $fabsf$i$i53$i = Math_fround(0), $fabsf$i$i54$i = Math_fround(0), $fabsf$i$i55$i = Math_fround(0), $fabsf$i$i56$i = Math_fround(0), $fabsf$i$i57$i = Math_fround(0), $fabsf$i$i58$i = Math_fround(0), $minIndex$1$1$i = 0, $minIndex$1$2$i = 0, $minIndex$1$3$i = 0, $minIndex$1$4$i = 0, $minIndex$1$5$i = 0, $minimum$1$1$i = Math_fround(0), $minimum$1$2$i = Math_fround(0), $minimum$1$3$i = Math_fround(0), $minimum$1$4$i = Math_fround(0), $minimum$1$i = Math_fround(0), $not$ = 0;
 var $or$cond$1$i = 0, $or$cond$2$i = 0, $or$cond$3$i = 0, $or$cond$4$i = 0, $or$cond$5$i = 0, $or$cond$i = 0, $overlap$i = 0, $trs$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $d1$i = sp + 184|0;
 $overlap$i = sp;
 $trs$i = sp + 24|0;
 $ctcNrm$i = sp + 72|0;
 $0 = sp + 88|0;
 $1 = sp + 136|0;
 $2 = (($npCache) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($shape0) + 4|0);
 $5 = (($shape1) + 4|0);
 $6 = Math_fround(HEAPF32[$transform0>>2]);
 $7 = Math_fround($6 + $6);
 $8 = (($transform0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 + $9);
 $11 = (($transform0) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 + $12);
 $14 = (($transform0) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($7 * $15);
 $17 = Math_fround($10 * $15);
 $18 = Math_fround($15 * $13);
 $19 = Math_fround($6 * $7);
 $20 = Math_fround($6 * $10);
 $21 = Math_fround($6 * $13);
 $22 = Math_fround($9 * $10);
 $23 = Math_fround($9 * $13);
 $24 = Math_fround($12 * $13);
 $25 = Math_fround(Math_fround(1.0) - $22);
 $26 = Math_fround($25 - $24);
 HEAPF32[$0>>2] = $26;
 $27 = Math_fround($20 + $18);
 $28 = (($0) + 4|0);
 HEAPF32[$28>>2] = $27;
 $29 = Math_fround($21 - $17);
 $30 = (($0) + 8|0);
 HEAPF32[$30>>2] = $29;
 $31 = Math_fround($20 - $18);
 $32 = (($0) + 12|0);
 HEAPF32[$32>>2] = $31;
 $33 = Math_fround(Math_fround(1.0) - $19);
 $34 = Math_fround($33 - $24);
 $35 = (($0) + 16|0);
 HEAPF32[$35>>2] = $34;
 $36 = Math_fround($23 + $16);
 $37 = (($0) + 20|0);
 HEAPF32[$37>>2] = $36;
 $38 = Math_fround($21 + $17);
 $39 = (($0) + 24|0);
 HEAPF32[$39>>2] = $38;
 $40 = Math_fround($23 - $16);
 $41 = (($0) + 28|0);
 HEAPF32[$41>>2] = $40;
 $42 = Math_fround($33 - $22);
 $43 = (($0) + 32|0);
 HEAPF32[$43>>2] = $42;
 $44 = (($0) + 36|0);
 $45 = (($0) + 40|0);
 $46 = (($0) + 44|0);
 $47 = (($transform0) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$44>>2] = $48;
 $49 = (($transform0) + 20|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 HEAPF32[$45>>2] = $50;
 $51 = (($transform0) + 24|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 HEAPF32[$46>>2] = $52;
 $53 = Math_fround(HEAPF32[$transform1>>2]);
 $54 = Math_fround($53 + $53);
 $55 = (($transform1) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 + $56);
 $58 = (($transform1) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 + $59);
 $61 = (($transform1) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($54 * $62);
 $64 = Math_fround($57 * $62);
 $65 = Math_fround($62 * $60);
 $66 = Math_fround($53 * $54);
 $67 = Math_fround($53 * $57);
 $68 = Math_fround($53 * $60);
 $69 = Math_fround($56 * $57);
 $70 = Math_fround($56 * $60);
 $71 = Math_fround($59 * $60);
 $72 = Math_fround(Math_fround(1.0) - $69);
 $73 = Math_fround($72 - $71);
 HEAPF32[$1>>2] = $73;
 $74 = Math_fround($67 + $65);
 $75 = (($1) + 4|0);
 HEAPF32[$75>>2] = $74;
 $76 = Math_fround($68 - $64);
 $77 = (($1) + 8|0);
 HEAPF32[$77>>2] = $76;
 $78 = Math_fround($67 - $65);
 $79 = (($1) + 12|0);
 HEAPF32[$79>>2] = $78;
 $80 = Math_fround(Math_fround(1.0) - $66);
 $81 = Math_fround($80 - $71);
 $82 = (($1) + 16|0);
 HEAPF32[$82>>2] = $81;
 $83 = Math_fround($70 + $63);
 $84 = (($1) + 20|0);
 HEAPF32[$84>>2] = $83;
 $85 = Math_fround($68 + $64);
 $86 = (($1) + 24|0);
 HEAPF32[$86>>2] = $85;
 $87 = Math_fround($70 - $63);
 $88 = (($1) + 28|0);
 HEAPF32[$88>>2] = $87;
 $89 = Math_fround($80 - $69);
 $90 = (($1) + 32|0);
 HEAPF32[$90>>2] = $89;
 $91 = (($1) + 36|0);
 $92 = (($1) + 40|0);
 $93 = (($1) + 44|0);
 $94 = (($transform1) + 16|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 HEAPF32[$91>>2] = $95;
 $96 = (($transform1) + 20|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 HEAPF32[$92>>2] = $97;
 $98 = (($transform1) + 24|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 HEAPF32[$93>>2] = $99;
 $100 = Math_fround(HEAPF32[$contactDistance>>2]);
 $101 = Math_fround($95 - $48);
 $102 = Math_fround($97 - $50);
 $103 = Math_fround($99 - $52);
 $104 = Math_fround(HEAPF32[$0>>2]);
 $105 = Math_fround($104 * $73);
 $106 = Math_fround(HEAPF32[$28>>2]);
 $107 = Math_fround($106 * $74);
 $108 = Math_fround($105 + $107);
 $109 = Math_fround(HEAPF32[$30>>2]);
 $110 = Math_fround($109 * $76);
 $111 = Math_fround($108 + $110);
 $112 = Math_fround($104 * $78);
 $113 = Math_fround($106 * $81);
 $114 = Math_fround($112 + $113);
 $115 = Math_fround($109 * $83);
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($104 * $85);
 $118 = Math_fround($106 * $87);
 $119 = Math_fround($117 + $118);
 $120 = Math_fround($109 * $89);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($101 * $104);
 $123 = Math_fround($102 * $106);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($103 * $109);
 $126 = Math_fround($124 + $125);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($111)))));
 $127 = Math_fround($fabsf$i$i$i + Math_fround(9.99999997475242707878E-7));
 $fabsf$i$i36$i = (Math_fround(Math_abs((Math_fround($116)))));
 $128 = Math_fround($fabsf$i$i36$i + Math_fround(9.99999997475242707878E-7));
 $fabsf$i$i37$i = (Math_fround(Math_abs((Math_fround($121)))));
 $129 = Math_fround($fabsf$i$i37$i + Math_fround(9.99999997475242707878E-7));
 HEAPF32[$d1$i>>2] = $126;
 $130 = Math_fround(HEAPF32[$4>>2]);
 $131 = Math_fround(HEAPF32[$5>>2]);
 $132 = Math_fround($127 * $131);
 $133 = Math_fround($130 + $132);
 $134 = (($shape1) + 8|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($128 * $135);
 $137 = Math_fround($133 + $136);
 $138 = (($shape1) + 12|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($129 * $139);
 $141 = Math_fround($137 + $140);
 $fabsf$i$i38$i = (Math_fround(Math_abs((Math_fround($126)))));
 $142 = Math_fround($141 - $fabsf$i$i38$i);
 $143 = Math_fround($100 + $142);
 HEAPF32[$overlap$i>>2] = $143;
 $144 = $143 < Math_fround(0.0);
 if ($144) {
  $$1$i = 0;$674 = $3;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
 }
 $145 = Math_fround(HEAPF32[$32>>2]);
 $146 = Math_fround($73 * $145);
 $147 = Math_fround(HEAPF32[$35>>2]);
 $148 = Math_fround($74 * $147);
 $149 = Math_fround($146 + $148);
 $150 = Math_fround(HEAPF32[$37>>2]);
 $151 = Math_fround($76 * $150);
 $152 = Math_fround($149 + $151);
 $153 = Math_fround($78 * $145);
 $154 = Math_fround($81 * $147);
 $155 = Math_fround($153 + $154);
 $156 = Math_fround($83 * $150);
 $157 = Math_fround($155 + $156);
 $158 = Math_fround($85 * $145);
 $159 = Math_fround($87 * $147);
 $160 = Math_fround($158 + $159);
 $161 = Math_fround($89 * $150);
 $162 = Math_fround($160 + $161);
 $163 = Math_fround($101 * $145);
 $164 = Math_fround($102 * $147);
 $165 = Math_fround($163 + $164);
 $166 = Math_fround($103 * $150);
 $167 = Math_fround($165 + $166);
 $fabsf$i$i42$i = (Math_fround(Math_abs((Math_fround($152)))));
 $168 = Math_fround($fabsf$i$i42$i + Math_fround(9.99999997475242707878E-7));
 $fabsf$i$i43$i = (Math_fround(Math_abs((Math_fround($157)))));
 $169 = Math_fround($fabsf$i$i43$i + Math_fround(9.99999997475242707878E-7));
 $fabsf$i$i44$i = (Math_fround(Math_abs((Math_fround($162)))));
 $170 = Math_fround($fabsf$i$i44$i + Math_fround(9.99999997475242707878E-7));
 $171 = (($d1$i) + 4|0);
 HEAPF32[$171>>2] = $167;
 $172 = (($shape0) + 8|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround($131 * $168);
 $175 = Math_fround($174 + $173);
 $176 = Math_fround($135 * $169);
 $177 = Math_fround($176 + $175);
 $178 = Math_fround($139 * $170);
 $179 = Math_fround($178 + $177);
 $fabsf$i$i45$i = (Math_fround(Math_abs((Math_fround($167)))));
 $180 = Math_fround($179 - $fabsf$i$i45$i);
 $181 = Math_fround($100 + $180);
 $182 = (($overlap$i) + 4|0);
 HEAPF32[$182>>2] = $181;
 $183 = $181 < Math_fround(0.0);
 if ($183) {
  $$1$i = 0;$674 = $3;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
 }
 $184 = Math_fround(HEAPF32[$39>>2]);
 $185 = Math_fround($73 * $184);
 $186 = Math_fround(HEAPF32[$41>>2]);
 $187 = Math_fround($74 * $186);
 $188 = Math_fround($185 + $187);
 $189 = Math_fround(HEAPF32[$43>>2]);
 $190 = Math_fround($76 * $189);
 $191 = Math_fround($188 + $190);
 $192 = Math_fround($78 * $184);
 $193 = Math_fround($81 * $186);
 $194 = Math_fround($192 + $193);
 $195 = Math_fround($83 * $189);
 $196 = Math_fround($194 + $195);
 $197 = Math_fround($85 * $184);
 $198 = Math_fround($87 * $186);
 $199 = Math_fround($197 + $198);
 $200 = Math_fround($89 * $189);
 $201 = Math_fround($199 + $200);
 $202 = Math_fround($101 * $184);
 $203 = Math_fround($102 * $186);
 $204 = Math_fround($202 + $203);
 $205 = Math_fround($103 * $189);
 $206 = Math_fround($204 + $205);
 $fabsf$i$i50$i = (Math_fround(Math_abs((Math_fround($191)))));
 $207 = Math_fround($fabsf$i$i50$i + Math_fround(9.99999997475242707878E-7));
 $fabsf$i$i51$i = (Math_fround(Math_abs((Math_fround($196)))));
 $208 = Math_fround($fabsf$i$i51$i + Math_fround(9.99999997475242707878E-7));
 $fabsf$i$i52$i = (Math_fround(Math_abs((Math_fround($201)))));
 $209 = Math_fround($fabsf$i$i52$i + Math_fround(9.99999997475242707878E-7));
 $210 = (($d1$i) + 8|0);
 HEAPF32[$210>>2] = $206;
 $211 = (($shape0) + 12|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = Math_fround($131 * $207);
 $214 = Math_fround($213 + $212);
 $215 = Math_fround($135 * $208);
 $216 = Math_fround($215 + $214);
 $217 = Math_fround($139 * $209);
 $218 = Math_fround($217 + $216);
 $fabsf$i$i53$i = (Math_fround(Math_abs((Math_fround($206)))));
 $219 = Math_fround($218 - $fabsf$i$i53$i);
 $220 = Math_fround($100 + $219);
 $221 = (($overlap$i) + 8|0);
 HEAPF32[$221>>2] = $220;
 $222 = $220 < Math_fround(0.0);
 if ($222) {
  $$1$i = 0;$674 = $3;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
 }
 $223 = Math_fround($101 * $73);
 $224 = Math_fround($102 * $74);
 $225 = Math_fround($223 + $224);
 $226 = Math_fround($103 * $76);
 $227 = Math_fround($225 + $226);
 $228 = (($d1$i) + 12|0);
 HEAPF32[$228>>2] = $227;
 $229 = Math_fround($127 * $130);
 $230 = Math_fround($131 + $229);
 $231 = Math_fround($168 * $173);
 $232 = Math_fround($230 + $231);
 $233 = Math_fround($207 * $212);
 $234 = Math_fround($232 + $233);
 $fabsf$i$i55$i = (Math_fround(Math_abs((Math_fround($227)))));
 $235 = Math_fround($234 - $fabsf$i$i55$i);
 $236 = Math_fround($100 + $235);
 $237 = (($overlap$i) + 12|0);
 HEAPF32[$237>>2] = $236;
 $238 = $236 < Math_fround(0.0);
 if ($238) {
  $$1$i = 0;$674 = $3;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
 }
 $239 = Math_fround($101 * $78);
 $240 = Math_fround($102 * $81);
 $241 = Math_fround($239 + $240);
 $242 = Math_fround($103 * $83);
 $243 = Math_fround($241 + $242);
 $244 = (($d1$i) + 16|0);
 HEAPF32[$244>>2] = $243;
 $245 = Math_fround($128 * $130);
 $246 = Math_fround($245 + $135);
 $247 = Math_fround($169 * $173);
 $248 = Math_fround($246 + $247);
 $249 = Math_fround($208 * $212);
 $250 = Math_fround($248 + $249);
 $fabsf$i$i57$i = (Math_fround(Math_abs((Math_fround($243)))));
 $251 = Math_fround($250 - $fabsf$i$i57$i);
 $252 = Math_fround($100 + $251);
 $253 = (($overlap$i) + 16|0);
 HEAPF32[$253>>2] = $252;
 $254 = $252 < Math_fround(0.0);
 if ($254) {
  $$1$i = 0;$674 = $3;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
 }
 $255 = Math_fround($101 * $85);
 $256 = Math_fround($102 * $87);
 $257 = Math_fround($255 + $256);
 $258 = Math_fround($103 * $89);
 $259 = Math_fround($257 + $258);
 $260 = (($d1$i) + 20|0);
 HEAPF32[$260>>2] = $259;
 $261 = Math_fround($129 * $130);
 $262 = Math_fround($261 + $139);
 $263 = Math_fround($170 * $173);
 $264 = Math_fround($262 + $263);
 $265 = Math_fround($209 * $212);
 $266 = Math_fround($264 + $265);
 $fabsf$i$i58$i = (Math_fround(Math_abs((Math_fround($259)))));
 $267 = Math_fround($266 - $fabsf$i$i58$i);
 $268 = Math_fround($100 + $267);
 $269 = (($overlap$i) + 20|0);
 HEAPF32[$269>>2] = $268;
 $270 = $268 < Math_fround(0.0);
 if ($270) {
  $$1$i = 0;$674 = $3;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
 }
 $271 = ($3|0)==(0);
 if ($271) {
  $272 = Math_fround($152 * $206);
  $273 = Math_fround($167 * $191);
  $274 = Math_fround($272 - $273);
  $275 = Math_fround($173 * $207);
  $276 = Math_fround($100 + $275);
  $277 = Math_fround($168 * $212);
  $278 = Math_fround($276 + $277);
  $279 = Math_fround($129 * $135);
  $280 = Math_fround($279 + $278);
  $281 = Math_fround($128 * $139);
  $282 = Math_fround($281 + $280);
  $fabsf$i$i56$i = (Math_fround(Math_abs((Math_fround($274)))));
  $283 = $fabsf$i$i56$i > $282;
  if ($283) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  }
  $284 = Math_fround($157 * $206);
  $285 = Math_fround($167 * $196);
  $286 = Math_fround($284 - $285);
  $287 = Math_fround($173 * $208);
  $288 = Math_fround($100 + $287);
  $289 = Math_fround($169 * $212);
  $290 = Math_fround($288 + $289);
  $291 = Math_fround($129 * $131);
  $292 = Math_fround($291 + $290);
  $293 = Math_fround($127 * $139);
  $294 = Math_fround($293 + $292);
  $fabsf$i$i54$i = (Math_fround(Math_abs((Math_fround($286)))));
  $295 = $fabsf$i$i54$i > $294;
  if ($295) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  }
  $296 = Math_fround($162 * $206);
  $297 = Math_fround($167 * $201);
  $298 = Math_fround($296 - $297);
  $299 = Math_fround($173 * $209);
  $300 = Math_fround($100 + $299);
  $301 = Math_fround($170 * $212);
  $302 = Math_fround($301 + $300);
  $303 = Math_fround($128 * $131);
  $304 = Math_fround($303 + $302);
  $305 = Math_fround($127 * $135);
  $306 = Math_fround($305 + $304);
  $fabsf$i$i49$i = (Math_fround(Math_abs((Math_fround($298)))));
  $307 = $fabsf$i$i49$i > $306;
  if ($307) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  }
  $308 = Math_fround($126 * $191);
  $309 = Math_fround($111 * $206);
  $310 = Math_fround($308 - $309);
  $311 = Math_fround($130 * $207);
  $312 = Math_fround($100 + $311);
  $313 = Math_fround($127 * $212);
  $314 = Math_fround($312 + $313);
  $315 = Math_fround($135 * $170);
  $316 = Math_fround($315 + $314);
  $317 = Math_fround($139 * $169);
  $318 = Math_fround($317 + $316);
  $fabsf$i$i48$i = (Math_fround(Math_abs((Math_fround($310)))));
  $319 = $fabsf$i$i48$i > $318;
  if ($319) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  }
  $320 = Math_fround($126 * $196);
  $321 = Math_fround($116 * $206);
  $322 = Math_fround($320 - $321);
  $323 = Math_fround($130 * $208);
  $324 = Math_fround($100 + $323);
  $325 = Math_fround($128 * $212);
  $326 = Math_fround($325 + $324);
  $327 = Math_fround($131 * $170);
  $328 = Math_fround($327 + $326);
  $329 = Math_fround($139 * $168);
  $330 = Math_fround($329 + $328);
  $fabsf$i$i47$i = (Math_fround(Math_abs((Math_fround($322)))));
  $331 = $fabsf$i$i47$i > $330;
  if ($331) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  }
  $332 = Math_fround($126 * $201);
  $333 = Math_fround($121 * $206);
  $334 = Math_fround($332 - $333);
  $335 = Math_fround($130 * $209);
  $336 = Math_fround($100 + $335);
  $337 = Math_fround($129 * $212);
  $338 = Math_fround($337 + $336);
  $339 = Math_fround($131 * $169);
  $340 = Math_fround($339 + $338);
  $341 = Math_fround($135 * $168);
  $342 = Math_fround($341 + $340);
  $fabsf$i$i46$i = (Math_fround(Math_abs((Math_fround($334)))));
  $343 = $fabsf$i$i46$i > $342;
  if ($343) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  }
  $344 = Math_fround($111 * $167);
  $345 = Math_fround($126 * $152);
  $346 = Math_fround($344 - $345);
  $347 = Math_fround($130 * $168);
  $348 = Math_fround($100 + $347);
  $349 = Math_fround($127 * $173);
  $350 = Math_fround($348 + $349);
  $351 = Math_fround($135 * $209);
  $352 = Math_fround($350 + $351);
  $353 = Math_fround($139 * $208);
  $354 = Math_fround($353 + $352);
  $fabsf$i$i41$i = (Math_fround(Math_abs((Math_fround($346)))));
  $355 = $fabsf$i$i41$i > $354;
  if ($355) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  }
  $356 = Math_fround($116 * $167);
  $357 = Math_fround($126 * $157);
  $358 = Math_fround($356 - $357);
  $359 = Math_fround($130 * $169);
  $360 = Math_fround($100 + $359);
  $361 = Math_fround($128 * $173);
  $362 = Math_fround($361 + $360);
  $363 = Math_fround($131 * $209);
  $364 = Math_fround($362 + $363);
  $365 = Math_fround($139 * $207);
  $366 = Math_fround($365 + $364);
  $fabsf$i$i40$i = (Math_fround(Math_abs((Math_fround($358)))));
  $367 = $fabsf$i$i40$i > $366;
  if ($367) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  }
  $368 = Math_fround($121 * $167);
  $369 = Math_fround($126 * $162);
  $370 = Math_fround($368 - $369);
  $371 = Math_fround($130 * $170);
  $372 = Math_fround($100 + $371);
  $373 = Math_fround($129 * $173);
  $374 = Math_fround($373 + $372);
  $375 = Math_fround($131 * $208);
  $376 = Math_fround($374 + $375);
  $377 = Math_fround($135 * $207);
  $378 = Math_fround($377 + $376);
  $fabsf$i$i39$i = (Math_fround(Math_abs((Math_fround($370)))));
  $379 = $fabsf$i$i39$i > $378;
  if ($379) {
   $$1$i = 0;$674 = 0;
   $673 = ($$1$i|0)==(0);
   $$ = $673 ? 0 : $674;
   HEAP32[$2>>2] = $$;
   $not$ = $673 ^ 1;
   STACKTOP = sp;return ($not$|0);
  } else {
   $385 = $143;$388 = $181;$391 = $220;$394 = $236;$397 = $252;$400 = $268;
  }
 } else {
  $380 = (($3) + -1)|0;
  $381 = (($overlap$i) + ($380<<2)|0);
  $382 = Math_fround(HEAPF32[$381>>2]);
  $383 = Math_fround($382 * Math_fround(0.999000012874603271484));
  HEAPF32[$381>>2] = $383;
  $$pre$i = Math_fround(HEAPF32[$overlap$i>>2]);
  $$pre185$i = Math_fround(HEAPF32[$182>>2]);
  $$pre186$i = Math_fround(HEAPF32[$221>>2]);
  $$pre187$i = Math_fround(HEAPF32[$237>>2]);
  $$pre188$i = Math_fround(HEAPF32[$253>>2]);
  $$pre189$i = Math_fround(HEAPF32[$269>>2]);
  $385 = $$pre$i;$388 = $$pre185$i;$391 = $$pre186$i;$394 = $$pre187$i;$397 = $$pre188$i;$400 = $$pre189$i;
 }
 $384 = $385 >= Math_fround(0.0);
 $386 = $385 < Math_fround(3.40282346638528859812E+38);
 $or$cond$i = $384 & $386;
 $minimum$1$i = $or$cond$i ? $385 : Math_fround(3.40282346638528859812E+38);
 $387 = $388 >= Math_fround(0.0);
 $389 = $388 < $minimum$1$i;
 $or$cond$1$i = $387 & $389;
 $minimum$1$1$i = $or$cond$1$i ? $388 : $minimum$1$i;
 $minIndex$1$1$i = $or$cond$1$i&1;
 $390 = $391 >= Math_fround(0.0);
 $392 = $391 < $minimum$1$1$i;
 $or$cond$2$i = $390 & $392;
 $minimum$1$2$i = $or$cond$2$i ? $391 : $minimum$1$1$i;
 $minIndex$1$2$i = $or$cond$2$i ? 2 : $minIndex$1$1$i;
 $393 = $394 >= Math_fround(0.0);
 $395 = $394 < $minimum$1$2$i;
 $or$cond$3$i = $393 & $395;
 $minimum$1$3$i = $or$cond$3$i ? $394 : $minimum$1$2$i;
 $minIndex$1$3$i = $or$cond$3$i ? 3 : $minIndex$1$2$i;
 $396 = $397 >= Math_fround(0.0);
 $398 = $397 < $minimum$1$3$i;
 $or$cond$4$i = $396 & $398;
 $minimum$1$4$i = $or$cond$4$i ? $397 : $minimum$1$3$i;
 $minIndex$1$4$i = $or$cond$4$i ? 4 : $minIndex$1$3$i;
 $399 = $400 >= Math_fround(0.0);
 $401 = $400 < $minimum$1$4$i;
 $or$cond$5$i = $399 & $401;
 $minIndex$1$5$i = $or$cond$5$i ? 5 : $minIndex$1$4$i;
 $402 = (($minIndex$1$5$i) + 1)|0;
 $403 = (($d1$i) + ($minIndex$1$5$i<<2)|0);
 $404 = Math_fround(HEAPF32[$403>>2]);
 $405 = $404 < Math_fround(0.0);
 switch ($minIndex$1$5$i|0) {
 case 3:  {
  if ($405) {
   HEAPF32[$ctcNrm$i>>2] = $73;
   $535 = (($ctcNrm$i) + 4|0);
   HEAPF32[$535>>2] = $74;
   $536 = (($ctcNrm$i) + 8|0);
   HEAPF32[$536>>2] = $76;
   $537 = Math_fround(-$73);
   $538 = Math_fround(-$74);
   $539 = Math_fround(-$76);
   HEAPF32[$trs$i>>2] = $537;
   $540 = (($trs$i) + 4|0);
   HEAPF32[$540>>2] = $538;
   $541 = (($trs$i) + 8|0);
   HEAPF32[$541>>2] = $539;
   $542 = Math_fround(-$78);
   $543 = Math_fround(-$81);
   $544 = Math_fround(-$83);
   $545 = (($trs$i) + 12|0);
   HEAPF32[$545>>2] = $542;
   $546 = (($trs$i) + 16|0);
   HEAPF32[$546>>2] = $543;
   $547 = (($trs$i) + 20|0);
   HEAPF32[$547>>2] = $544;
   $548 = (($trs$i) + 24|0);
   HEAPF32[$548>>2] = $85;
   $549 = (($trs$i) + 28|0);
   HEAPF32[$549>>2] = $87;
   $550 = (($trs$i) + 32|0);
   HEAPF32[$550>>2] = $89;
   $551 = Math_fround($73 * $131);
   $552 = Math_fround($74 * $131);
   $553 = Math_fround($76 * $131);
   $554 = Math_fround($95 + $551);
   $555 = Math_fround($97 + $552);
   $556 = Math_fround($99 + $553);
   $557 = (($trs$i) + 36|0);
   HEAPF32[$557>>2] = $554;
   $558 = (($trs$i) + 40|0);
   HEAPF32[$558>>2] = $555;
   $559 = (($trs$i) + 44|0);
   HEAPF32[$559>>2] = $556;
  } else {
   $560 = Math_fround(-$73);
   $561 = Math_fround(-$74);
   $562 = Math_fround(-$76);
   HEAPF32[$ctcNrm$i>>2] = $560;
   $563 = (($ctcNrm$i) + 4|0);
   HEAPF32[$563>>2] = $561;
   $564 = (($ctcNrm$i) + 8|0);
   HEAPF32[$564>>2] = $562;
   HEAPF32[$trs$i>>2] = $73;
   $565 = (($trs$i) + 4|0);
   HEAPF32[$565>>2] = $74;
   $566 = (($trs$i) + 8|0);
   HEAPF32[$566>>2] = $76;
   $567 = (($trs$i) + 12|0);
   HEAPF32[$567>>2] = $78;
   $568 = (($trs$i) + 16|0);
   HEAPF32[$568>>2] = $81;
   $569 = (($trs$i) + 20|0);
   HEAPF32[$569>>2] = $83;
   $570 = (($trs$i) + 24|0);
   HEAPF32[$570>>2] = $85;
   $571 = (($trs$i) + 28|0);
   HEAPF32[$571>>2] = $87;
   $572 = (($trs$i) + 32|0);
   HEAPF32[$572>>2] = $89;
   $573 = Math_fround($73 * $131);
   $574 = Math_fround($74 * $131);
   $575 = Math_fround($76 * $131);
   $576 = Math_fround($95 - $573);
   $577 = Math_fround($97 - $574);
   $578 = Math_fround($99 - $575);
   $579 = (($trs$i) + 36|0);
   HEAPF32[$579>>2] = $576;
   $580 = (($trs$i) + 40|0);
   HEAPF32[$580>>2] = $577;
   $581 = (($trs$i) + 44|0);
   HEAPF32[$581>>2] = $578;
  }
  $582 = (__ZL16generateContactsRN5physx2Gu13ContactBufferERKNS_6PxVec3EffS5_RKNS_2Cm8Matrix34ES9_f($contactBuffer,$ctcNrm$i,$135,$139,$4,$trs$i,$0,$100)|0);
  $$1$i = $582;$674 = $402;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
  break;
 }
 case 4:  {
  $583 = (($trs$i) + 24|0);
  HEAPF32[$583>>2] = $73;
  $584 = (($trs$i) + 28|0);
  HEAPF32[$584>>2] = $74;
  $585 = (($trs$i) + 32|0);
  HEAPF32[$585>>2] = $76;
  if ($405) {
   HEAPF32[$ctcNrm$i>>2] = $78;
   $586 = (($ctcNrm$i) + 4|0);
   HEAPF32[$586>>2] = $81;
   $587 = (($ctcNrm$i) + 8|0);
   HEAPF32[$587>>2] = $83;
   $588 = Math_fround(-$78);
   $589 = Math_fround(-$81);
   $590 = Math_fround(-$83);
   HEAPF32[$trs$i>>2] = $588;
   $591 = (($trs$i) + 4|0);
   HEAPF32[$591>>2] = $589;
   $592 = (($trs$i) + 8|0);
   HEAPF32[$592>>2] = $590;
   $593 = Math_fround(-$85);
   $594 = Math_fround(-$87);
   $595 = Math_fround(-$89);
   $596 = (($trs$i) + 12|0);
   HEAPF32[$596>>2] = $593;
   $597 = (($trs$i) + 16|0);
   HEAPF32[$597>>2] = $594;
   $598 = (($trs$i) + 20|0);
   HEAPF32[$598>>2] = $595;
   $599 = Math_fround($78 * $135);
   $600 = Math_fround($81 * $135);
   $601 = Math_fround($83 * $135);
   $602 = Math_fround($95 + $599);
   $603 = Math_fround($97 + $600);
   $604 = Math_fround($99 + $601);
   $605 = (($trs$i) + 36|0);
   HEAPF32[$605>>2] = $602;
   $606 = (($trs$i) + 40|0);
   HEAPF32[$606>>2] = $603;
   $607 = (($trs$i) + 44|0);
   HEAPF32[$607>>2] = $604;
  } else {
   $608 = Math_fround(-$78);
   $609 = Math_fround(-$81);
   $610 = Math_fround(-$83);
   HEAPF32[$ctcNrm$i>>2] = $608;
   $611 = (($ctcNrm$i) + 4|0);
   HEAPF32[$611>>2] = $609;
   $612 = (($ctcNrm$i) + 8|0);
   HEAPF32[$612>>2] = $610;
   HEAPF32[$trs$i>>2] = $78;
   $613 = (($trs$i) + 4|0);
   HEAPF32[$613>>2] = $81;
   $614 = (($trs$i) + 8|0);
   HEAPF32[$614>>2] = $83;
   $615 = (($trs$i) + 12|0);
   HEAPF32[$615>>2] = $85;
   $616 = (($trs$i) + 16|0);
   HEAPF32[$616>>2] = $87;
   $617 = (($trs$i) + 20|0);
   HEAPF32[$617>>2] = $89;
   HEAPF32[$583>>2] = $73;
   HEAPF32[$584>>2] = $74;
   HEAPF32[$585>>2] = $76;
   $618 = Math_fround($78 * $135);
   $619 = Math_fround($81 * $135);
   $620 = Math_fround($83 * $135);
   $621 = Math_fround($95 - $618);
   $622 = Math_fround($97 - $619);
   $623 = Math_fround($99 - $620);
   $624 = (($trs$i) + 36|0);
   HEAPF32[$624>>2] = $621;
   $625 = (($trs$i) + 40|0);
   HEAPF32[$625>>2] = $622;
   $626 = (($trs$i) + 44|0);
   HEAPF32[$626>>2] = $623;
  }
  $627 = (__ZL16generateContactsRN5physx2Gu13ContactBufferERKNS_6PxVec3EffS5_RKNS_2Cm8Matrix34ES9_f($contactBuffer,$ctcNrm$i,$139,$131,$4,$trs$i,$0,$100)|0);
  $$1$i = $627;$674 = $402;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
  break;
 }
 case 1:  {
  $451 = (($trs$i) + 24|0);
  HEAPF32[$451>>2] = $104;
  $452 = (($trs$i) + 28|0);
  HEAPF32[$452>>2] = $106;
  $453 = (($trs$i) + 32|0);
  HEAPF32[$453>>2] = $109;
  if ($405) {
   HEAPF32[$ctcNrm$i>>2] = $145;
   $454 = (($ctcNrm$i) + 4|0);
   HEAPF32[$454>>2] = $147;
   $455 = (($ctcNrm$i) + 8|0);
   HEAPF32[$455>>2] = $150;
   HEAPF32[$trs$i>>2] = $145;
   $456 = (($trs$i) + 4|0);
   HEAPF32[$456>>2] = $147;
   $457 = (($trs$i) + 8|0);
   HEAPF32[$457>>2] = $150;
   $458 = (($trs$i) + 12|0);
   HEAPF32[$458>>2] = $184;
   $459 = (($trs$i) + 16|0);
   HEAPF32[$459>>2] = $186;
   $460 = (($trs$i) + 20|0);
   HEAPF32[$460>>2] = $189;
   $461 = Math_fround($145 * $173);
   $462 = Math_fround($147 * $173);
   $463 = Math_fround($150 * $173);
   $464 = Math_fround($48 - $461);
   $465 = Math_fround($50 - $462);
   $466 = Math_fround($52 - $463);
   $467 = (($trs$i) + 36|0);
   HEAPF32[$467>>2] = $464;
   $468 = (($trs$i) + 40|0);
   HEAPF32[$468>>2] = $465;
   $469 = (($trs$i) + 44|0);
   HEAPF32[$469>>2] = $466;
  } else {
   $470 = Math_fround(-$145);
   $471 = Math_fround(-$147);
   $472 = Math_fround(-$150);
   HEAPF32[$ctcNrm$i>>2] = $470;
   $473 = (($ctcNrm$i) + 4|0);
   HEAPF32[$473>>2] = $471;
   $474 = (($ctcNrm$i) + 8|0);
   HEAPF32[$474>>2] = $472;
   HEAPF32[$trs$i>>2] = $470;
   $475 = (($trs$i) + 4|0);
   HEAPF32[$475>>2] = $471;
   $476 = (($trs$i) + 8|0);
   HEAPF32[$476>>2] = $472;
   $477 = Math_fround(-$184);
   $478 = Math_fround(-$186);
   $479 = Math_fround(-$189);
   $480 = (($trs$i) + 12|0);
   HEAPF32[$480>>2] = $477;
   $481 = (($trs$i) + 16|0);
   HEAPF32[$481>>2] = $478;
   $482 = (($trs$i) + 20|0);
   HEAPF32[$482>>2] = $479;
   $483 = Math_fround($145 * $173);
   $484 = Math_fround($147 * $173);
   $485 = Math_fround($150 * $173);
   $486 = Math_fround($48 + $483);
   $487 = Math_fround($50 + $484);
   $488 = Math_fround($52 + $485);
   $489 = (($trs$i) + 36|0);
   HEAPF32[$489>>2] = $486;
   $490 = (($trs$i) + 40|0);
   HEAPF32[$490>>2] = $487;
   $491 = (($trs$i) + 44|0);
   HEAPF32[$491>>2] = $488;
  }
  $492 = (__ZL16generateContactsRN5physx2Gu13ContactBufferERKNS_6PxVec3EffS5_RKNS_2Cm8Matrix34ES9_f($contactBuffer,$ctcNrm$i,$212,$130,$5,$trs$i,$1,$100)|0);
  $$1$i = $492;$674 = $402;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
  break;
 }
 case 2:  {
  $493 = (($trs$i) + 24|0);
  HEAPF32[$493>>2] = $145;
  $494 = (($trs$i) + 28|0);
  HEAPF32[$494>>2] = $147;
  $495 = (($trs$i) + 32|0);
  HEAPF32[$495>>2] = $150;
  if ($405) {
   HEAPF32[$ctcNrm$i>>2] = $184;
   $496 = (($ctcNrm$i) + 4|0);
   HEAPF32[$496>>2] = $186;
   $497 = (($ctcNrm$i) + 8|0);
   HEAPF32[$497>>2] = $189;
   HEAPF32[$trs$i>>2] = $184;
   $498 = (($trs$i) + 4|0);
   HEAPF32[$498>>2] = $186;
   $499 = (($trs$i) + 8|0);
   HEAPF32[$499>>2] = $189;
   $500 = (($trs$i) + 12|0);
   HEAPF32[$500>>2] = $104;
   $501 = (($trs$i) + 16|0);
   HEAPF32[$501>>2] = $106;
   $502 = (($trs$i) + 20|0);
   HEAPF32[$502>>2] = $109;
   $503 = Math_fround($184 * $212);
   $504 = Math_fround($186 * $212);
   $505 = Math_fround($189 * $212);
   $506 = Math_fround($48 - $503);
   $507 = Math_fround($50 - $504);
   $508 = Math_fround($52 - $505);
   $509 = (($trs$i) + 36|0);
   HEAPF32[$509>>2] = $506;
   $510 = (($trs$i) + 40|0);
   HEAPF32[$510>>2] = $507;
   $511 = (($trs$i) + 44|0);
   HEAPF32[$511>>2] = $508;
  } else {
   $512 = Math_fround(-$184);
   $513 = Math_fround(-$186);
   $514 = Math_fround(-$189);
   HEAPF32[$ctcNrm$i>>2] = $512;
   $515 = (($ctcNrm$i) + 4|0);
   HEAPF32[$515>>2] = $513;
   $516 = (($ctcNrm$i) + 8|0);
   HEAPF32[$516>>2] = $514;
   HEAPF32[$trs$i>>2] = $512;
   $517 = (($trs$i) + 4|0);
   HEAPF32[$517>>2] = $513;
   $518 = (($trs$i) + 8|0);
   HEAPF32[$518>>2] = $514;
   $519 = Math_fround(-$104);
   $520 = Math_fround(-$106);
   $521 = Math_fround(-$109);
   $522 = (($trs$i) + 12|0);
   HEAPF32[$522>>2] = $519;
   $523 = (($trs$i) + 16|0);
   HEAPF32[$523>>2] = $520;
   $524 = (($trs$i) + 20|0);
   HEAPF32[$524>>2] = $521;
   $525 = Math_fround($184 * $212);
   $526 = Math_fround($186 * $212);
   $527 = Math_fround($189 * $212);
   $528 = Math_fround($48 + $525);
   $529 = Math_fround($50 + $526);
   $530 = Math_fround($52 + $527);
   $531 = (($trs$i) + 36|0);
   HEAPF32[$531>>2] = $528;
   $532 = (($trs$i) + 40|0);
   HEAPF32[$532>>2] = $529;
   $533 = (($trs$i) + 44|0);
   HEAPF32[$533>>2] = $530;
  }
  $534 = (__ZL16generateContactsRN5physx2Gu13ContactBufferERKNS_6PxVec3EffS5_RKNS_2Cm8Matrix34ES9_f($contactBuffer,$ctcNrm$i,$130,$173,$5,$trs$i,$1,$100)|0);
  $$1$i = $534;$674 = $402;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
  break;
 }
 case 5:  {
  $628 = (($trs$i) + 24|0);
  HEAPF32[$628>>2] = $78;
  $629 = (($trs$i) + 28|0);
  HEAPF32[$629>>2] = $81;
  $630 = (($trs$i) + 32|0);
  HEAPF32[$630>>2] = $83;
  if ($405) {
   HEAPF32[$ctcNrm$i>>2] = $85;
   $631 = (($ctcNrm$i) + 4|0);
   HEAPF32[$631>>2] = $87;
   $632 = (($ctcNrm$i) + 8|0);
   HEAPF32[$632>>2] = $89;
   $633 = Math_fround(-$85);
   $634 = Math_fround(-$87);
   $635 = Math_fround(-$89);
   HEAPF32[$trs$i>>2] = $633;
   $636 = (($trs$i) + 4|0);
   HEAPF32[$636>>2] = $634;
   $637 = (($trs$i) + 8|0);
   HEAPF32[$637>>2] = $635;
   $638 = Math_fround(-$73);
   $639 = Math_fround(-$74);
   $640 = Math_fround(-$76);
   $641 = (($trs$i) + 12|0);
   HEAPF32[$641>>2] = $638;
   $642 = (($trs$i) + 16|0);
   HEAPF32[$642>>2] = $639;
   $643 = (($trs$i) + 20|0);
   HEAPF32[$643>>2] = $640;
   $644 = Math_fround($85 * $139);
   $645 = Math_fround($87 * $139);
   $646 = Math_fround($89 * $139);
   $647 = Math_fround($95 + $644);
   $648 = Math_fround($97 + $645);
   $649 = Math_fround($99 + $646);
   $650 = (($trs$i) + 36|0);
   HEAPF32[$650>>2] = $647;
   $651 = (($trs$i) + 40|0);
   HEAPF32[$651>>2] = $648;
   $652 = (($trs$i) + 44|0);
   HEAPF32[$652>>2] = $649;
  } else {
   $653 = Math_fround(-$85);
   $654 = Math_fround(-$87);
   $655 = Math_fround(-$89);
   HEAPF32[$ctcNrm$i>>2] = $653;
   $656 = (($ctcNrm$i) + 4|0);
   HEAPF32[$656>>2] = $654;
   $657 = (($ctcNrm$i) + 8|0);
   HEAPF32[$657>>2] = $655;
   HEAPF32[$trs$i>>2] = $85;
   $658 = (($trs$i) + 4|0);
   HEAPF32[$658>>2] = $87;
   $659 = (($trs$i) + 8|0);
   HEAPF32[$659>>2] = $89;
   $660 = (($trs$i) + 12|0);
   HEAPF32[$660>>2] = $73;
   $661 = (($trs$i) + 16|0);
   HEAPF32[$661>>2] = $74;
   $662 = (($trs$i) + 20|0);
   HEAPF32[$662>>2] = $76;
   $663 = Math_fround($85 * $139);
   $664 = Math_fround($87 * $139);
   $665 = Math_fround($89 * $139);
   $666 = Math_fround($95 - $663);
   $667 = Math_fround($97 - $664);
   $668 = Math_fround($99 - $665);
   $669 = (($trs$i) + 36|0);
   HEAPF32[$669>>2] = $666;
   $670 = (($trs$i) + 40|0);
   HEAPF32[$670>>2] = $667;
   $671 = (($trs$i) + 44|0);
   HEAPF32[$671>>2] = $668;
  }
  $672 = (__ZL16generateContactsRN5physx2Gu13ContactBufferERKNS_6PxVec3EffS5_RKNS_2Cm8Matrix34ES9_f($contactBuffer,$ctcNrm$i,$131,$135,$4,$trs$i,$0,$100)|0);
  $$1$i = $672;$674 = $402;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
  break;
 }
 case 0:  {
  if ($405) {
   HEAPF32[$ctcNrm$i>>2] = $104;
   $406 = (($ctcNrm$i) + 4|0);
   HEAPF32[$406>>2] = $106;
   $407 = (($ctcNrm$i) + 8|0);
   HEAPF32[$407>>2] = $109;
   HEAPF32[$trs$i>>2] = $104;
   $408 = (($trs$i) + 4|0);
   HEAPF32[$408>>2] = $106;
   $409 = (($trs$i) + 8|0);
   HEAPF32[$409>>2] = $109;
   $410 = (($trs$i) + 12|0);
   HEAPF32[$410>>2] = $145;
   $411 = (($trs$i) + 16|0);
   HEAPF32[$411>>2] = $147;
   $412 = (($trs$i) + 20|0);
   HEAPF32[$412>>2] = $150;
   $413 = (($trs$i) + 24|0);
   HEAPF32[$413>>2] = $184;
   $414 = (($trs$i) + 28|0);
   HEAPF32[$414>>2] = $186;
   $415 = (($trs$i) + 32|0);
   HEAPF32[$415>>2] = $189;
   $416 = Math_fround($104 * $130);
   $417 = Math_fround($106 * $130);
   $418 = Math_fround($109 * $130);
   $419 = Math_fround($48 - $416);
   $420 = Math_fround($50 - $417);
   $421 = Math_fround($52 - $418);
   $422 = (($trs$i) + 36|0);
   HEAPF32[$422>>2] = $419;
   $423 = (($trs$i) + 40|0);
   HEAPF32[$423>>2] = $420;
   $424 = (($trs$i) + 44|0);
   HEAPF32[$424>>2] = $421;
  } else {
   $425 = Math_fround(-$104);
   $426 = Math_fround(-$106);
   $427 = Math_fround(-$109);
   HEAPF32[$ctcNrm$i>>2] = $425;
   $428 = (($ctcNrm$i) + 4|0);
   HEAPF32[$428>>2] = $426;
   $429 = (($ctcNrm$i) + 8|0);
   HEAPF32[$429>>2] = $427;
   HEAPF32[$trs$i>>2] = $425;
   $430 = (($trs$i) + 4|0);
   HEAPF32[$430>>2] = $426;
   $431 = (($trs$i) + 8|0);
   HEAPF32[$431>>2] = $427;
   $432 = Math_fround(-$145);
   $433 = Math_fround(-$147);
   $434 = Math_fround(-$150);
   $435 = (($trs$i) + 12|0);
   HEAPF32[$435>>2] = $432;
   $436 = (($trs$i) + 16|0);
   HEAPF32[$436>>2] = $433;
   $437 = (($trs$i) + 20|0);
   HEAPF32[$437>>2] = $434;
   $438 = (($trs$i) + 24|0);
   HEAPF32[$438>>2] = $184;
   $439 = (($trs$i) + 28|0);
   HEAPF32[$439>>2] = $186;
   $440 = (($trs$i) + 32|0);
   HEAPF32[$440>>2] = $189;
   $441 = Math_fround($104 * $130);
   $442 = Math_fround($106 * $130);
   $443 = Math_fround($109 * $130);
   $444 = Math_fround($48 + $441);
   $445 = Math_fround($50 + $442);
   $446 = Math_fround($52 + $443);
   $447 = (($trs$i) + 36|0);
   HEAPF32[$447>>2] = $444;
   $448 = (($trs$i) + 40|0);
   HEAPF32[$448>>2] = $445;
   $449 = (($trs$i) + 44|0);
   HEAPF32[$449>>2] = $446;
  }
  $450 = (__ZL16generateContactsRN5physx2Gu13ContactBufferERKNS_6PxVec3EffS5_RKNS_2Cm8Matrix34ES9_f($contactBuffer,$ctcNrm$i,$173,$212,$5,$trs$i,$1,$100)|0);
  $$1$i = $450;$674 = $402;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
  break;
 }
 default: {
  $$1$i = 0;$674 = $402;
  $673 = ($$1$i|0)==(0);
  $$ = $673 ? 0 : $674;
  HEAP32[$2>>2] = $$;
  $not$ = $673 ^ 1;
  STACKTOP = sp;return ($not$|0);
 }
 }
 return 0|0;
}
function __ZL16generateContactsRN5physx2Gu13ContactBufferERKNS_6PxVec3EffS5_RKNS_2Cm8Matrix34ES9_f($contactBuffer,$contactNormal,$y1,$z1,$box2,$transform0,$transform1,$contactDistance) {
 $contactBuffer = $contactBuffer|0;
 $contactNormal = $contactNormal|0;
 $y1 = Math_fround($y1);
 $z1 = Math_fround($z1);
 $box2 = $box2|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = Math_fround($contactDistance);
 var $$lcssa = 0, $$phi$trans$insert = 0, $$phi$trans$insert82 = 0, $$phi$trans$insert84 = 0, $$phi$trans$insert86 = 0, $$pre = 0, $$pre83 = 0, $$pre85 = 0, $$pre87 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0);
 var $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0);
 var $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0);
 var $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = Math_fround(0);
 var $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0);
 var $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0);
 var $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0;
 var $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0;
 var $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = 0, $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0);
 var $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0);
 var $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0;
 var $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = Math_fround(0), $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = Math_fround(0), $534 = 0, $535 = Math_fround(0), $536 = Math_fround(0), $537 = 0, $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0);
 var $540 = Math_fround(0), $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = Math_fround(0), $545 = 0, $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0);
 var $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = 0, $575 = 0, $576 = 0;
 var $577 = 0, $578 = Math_fround(0), $579 = 0, $58 = Math_fround(0), $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = 0, $584 = Math_fround(0), $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0;
 var $595 = Math_fround(0), $596 = 0, $597 = Math_fround(0), $598 = 0, $599 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $600 = 0, $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = 0;
 var $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = Math_fround(0), $616 = 0, $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = 0, $622 = Math_fround(0), $623 = Math_fround(0), $624 = 0, $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0);
 var $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0);
 var $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = Math_fround(0), $658 = 0, $659 = Math_fround(0), $66 = Math_fround(0), $660 = 0, $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0), $664 = 0, $665 = 0, $666 = 0;
 var $667 = 0, $668 = 0, $669 = 0, $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = Math_fround(0), $675 = 0, $676 = Math_fround(0), $677 = 0, $678 = 0, $679 = 0, $68 = Math_fround(0), $680 = Math_fround(0), $681 = 0, $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0);
 var $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = 0, $691 = Math_fround(0), $692 = 0, $693 = Math_fround(0), $694 = Math_fround(0), $695 = 0, $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = 0, $701 = Math_fround(0);
 var $702 = Math_fround(0), $703 = 0, $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = Math_fround(0);
 var $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = Math_fround(0), $737 = 0, $738 = Math_fround(0);
 var $739 = 0, $74 = Math_fround(0), $740 = Math_fround(0), $741 = 0, $742 = Math_fround(0), $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = Math_fround(0), $754 = 0, $755 = Math_fround(0), $756 = 0;
 var $757 = 0, $758 = 0, $759 = Math_fround(0), $76 = Math_fround(0), $760 = 0, $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = 0, $77 = Math_fround(0), $770 = Math_fround(0), $771 = 0, $772 = Math_fround(0), $773 = Math_fround(0), $774 = 0;
 var $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = 0, $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0), $782 = 0, $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0);
 var $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = Math_fround(0);
 var $810 = Math_fround(0), $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = Math_fround(0), $816 = 0, $817 = Math_fround(0), $818 = 0, $819 = Math_fround(0), $82 = Math_fround(0), $820 = 0, $821 = Math_fround(0), $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0;
 var $829 = 0, $83 = Math_fround(0), $830 = 0, $831 = 0, $832 = 0, $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = 0, $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0);
 var $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0, $850 = Math_fround(0), $851 = 0, $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0);
 var $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = 0, $869 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $PreviousY$03$i = Math_fround(0);
 var $PreviousY$03$i14 = Math_fround(0), $PreviousY$03$i2 = Math_fround(0), $PreviousY$03$i8 = Math_fround(0), $PreviousZ$02$i = Math_fround(0), $PreviousZ$02$i15 = Math_fround(0), $PreviousZ$02$i3 = Math_fround(0), $PreviousZ$02$i9 = Math_fround(0), $addflg$072 = 0, $addflg$1 = 0, $addflg$2 = 0, $addflg$3 = 0, $addflg$4 = 0, $exitcond = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i20 = Math_fround(0), $fabsf$i$i22 = Math_fround(0), $fabsf$i$i24 = Math_fround(0), $fabsf$i$i26 = Math_fround(0), $fabsf$i$i28 = Math_fround(0), $fabsf$i$i30 = Math_fround(0);
 var $fabsf$i$i31 = Math_fround(0), $i$01$i = 0, $i$01$i10 = 0, $i$01$i16 = 0, $i$01$i4 = 0, $i$075 = 0, $i13$073 = 0, $i19$071 = 0, $or$cond = 0, $p1$0 = 0, $p1$1 = 0, $p1$2 = 0, $p2$0 = 0, $p2$1 = 0, $p2$2 = 0, $phitmp = 0, $phitmp88 = 0, $phitmp89 = 0, $phitmp90 = 0, $q = 0;
 var $runningLine$074 = 0, $vtx = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vtx = sp + 16|0;
 $q = sp;
 $0 = (($contactBuffer) + 4096|0);
 HEAP32[$0>>2] = 0;
 $1 = Math_fround($y1 + $contactDistance);
 $2 = Math_fround(HEAPF32[$transform0>>2]);
 $3 = (($transform0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($transform0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform0) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($transform0) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transform0) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transform0) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transform0) + 28|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transform0) + 32|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transform0) + 36|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(-$20);
 $22 = (($transform0) + 40|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(-$23);
 $25 = (($transform0) + 44|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(-$26);
 $28 = Math_fround($4 * $24);
 $29 = Math_fround($6 * $27);
 $30 = Math_fround($8 * $21);
 $31 = Math_fround($10 * $24);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($12 * $27);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($16 * $24);
 $36 = Math_fround($18 * $27);
 $37 = Math_fround(HEAPF32[$transform1>>2]);
 $38 = Math_fround($8 * $37);
 $39 = (($transform1) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($10 * $40);
 $42 = Math_fround($16 * $40);
 $43 = Math_fround($38 + $41);
 $44 = (($transform1) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($12 * $45);
 $47 = Math_fround($18 * $45);
 $48 = Math_fround($43 + $46);
 $49 = (($transform1) + 12|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($8 * $50);
 $52 = (($transform1) + 16|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($10 * $53);
 $55 = Math_fround($16 * $53);
 $56 = Math_fround($51 + $54);
 $57 = (($transform1) + 20|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($12 * $58);
 $60 = Math_fround($18 * $58);
 $61 = Math_fround($56 + $59);
 $62 = (($transform1) + 24|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($8 * $63);
 $65 = (($transform1) + 28|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($10 * $66);
 $68 = Math_fround($16 * $66);
 $69 = Math_fround($64 + $67);
 $70 = (($transform1) + 32|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($12 * $71);
 $73 = Math_fround($18 * $71);
 $74 = Math_fround($69 + $72);
 $75 = (($transform1) + 36|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($8 * $76);
 $78 = Math_fround($14 * $76);
 $79 = (($transform1) + 40|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($10 * $80);
 $82 = Math_fround($16 * $80);
 $83 = Math_fround($77 + $81);
 $84 = Math_fround($78 + $82);
 $85 = (($transform1) + 44|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($12 * $86);
 $88 = Math_fround($18 * $86);
 $89 = Math_fround($83 + $87);
 $90 = Math_fround($84 + $88);
 $91 = Math_fround($34 + $89);
 $92 = Math_fround($z1 + $contactDistance);
 $93 = Math_fround($2 * $21);
 $94 = Math_fround($93 + $28);
 $95 = Math_fround($94 + $29);
 $96 = Math_fround($14 * $21);
 $97 = Math_fround($96 + $35);
 $98 = Math_fround($97 + $36);
 $99 = Math_fround($2 * $37);
 $100 = Math_fround($14 * $37);
 $101 = Math_fround($4 * $40);
 $102 = Math_fround($99 + $101);
 $103 = Math_fround($100 + $42);
 $104 = Math_fround($6 * $45);
 $105 = Math_fround($102 + $104);
 $106 = Math_fround($103 + $47);
 $107 = Math_fround($2 * $50);
 $108 = Math_fround($14 * $50);
 $109 = Math_fround($4 * $53);
 $110 = Math_fround($107 + $109);
 $111 = Math_fround($108 + $55);
 $112 = Math_fround($6 * $58);
 $113 = Math_fround($110 + $112);
 $114 = Math_fround($111 + $60);
 $115 = Math_fround($2 * $63);
 $116 = Math_fround($14 * $63);
 $117 = Math_fround($4 * $66);
 $118 = Math_fround($115 + $117);
 $119 = Math_fround($116 + $68);
 $120 = Math_fround($6 * $71);
 $121 = Math_fround($118 + $120);
 $122 = Math_fround($119 + $73);
 $123 = Math_fround($2 * $76);
 $124 = Math_fround($4 * $80);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($6 * $86);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround($95 + $127);
 $129 = Math_fround($98 + $90);
 $130 = Math_fround(HEAPF32[$box2>>2]);
 $131 = Math_fround($105 * $130);
 $132 = Math_fround($48 * $130);
 $133 = Math_fround($106 * $130);
 $134 = (($box2) + 4|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($113 * $135);
 $137 = Math_fround($61 * $135);
 $138 = Math_fround($114 * $135);
 $139 = (($box2) + 8|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($121 * $140);
 $142 = Math_fround($74 * $140);
 $143 = Math_fround($122 * $140);
 $144 = Math_fround($128 - $131);
 $145 = Math_fround($91 - $132);
 $146 = Math_fround($129 - $133);
 $147 = (($vtx) + 96|0);
 $148 = (($vtx) + 100|0);
 $149 = (($vtx) + 104|0);
 $150 = (($vtx) + 64|0);
 $151 = (($vtx) + 68|0);
 $152 = (($vtx) + 72|0);
 $153 = (($vtx) + 32|0);
 $154 = (($vtx) + 36|0);
 $155 = (($vtx) + 40|0);
 $156 = (($vtx) + 4|0);
 $157 = (($vtx) + 8|0);
 $158 = Math_fround($128 + $131);
 $159 = Math_fround($91 + $132);
 $160 = Math_fround($129 + $133);
 $161 = (($vtx) + 112|0);
 $162 = (($vtx) + 116|0);
 $163 = (($vtx) + 120|0);
 $164 = (($vtx) + 80|0);
 $165 = (($vtx) + 84|0);
 $166 = (($vtx) + 88|0);
 $167 = (($vtx) + 48|0);
 $168 = (($vtx) + 52|0);
 $169 = (($vtx) + 56|0);
 $170 = (($vtx) + 16|0);
 $171 = (($vtx) + 20|0);
 $172 = (($vtx) + 24|0);
 $173 = Math_fround($136 + $141);
 $174 = Math_fround($137 + $142);
 $175 = Math_fround($138 + $143);
 $176 = Math_fround($144 - $173);
 HEAPF32[$vtx>>2] = $176;
 $177 = Math_fround($145 - $174);
 HEAPF32[$156>>2] = $177;
 $178 = Math_fround($146 - $175);
 HEAPF32[$157>>2] = $178;
 $179 = Math_fround($158 - $173);
 HEAPF32[$170>>2] = $179;
 $180 = Math_fround($159 - $174);
 HEAPF32[$171>>2] = $180;
 $181 = Math_fround($160 - $175);
 HEAPF32[$172>>2] = $181;
 $182 = Math_fround($173 + $144);
 HEAPF32[$147>>2] = $182;
 $183 = Math_fround($174 + $145);
 HEAPF32[$148>>2] = $183;
 $184 = Math_fround($175 + $146);
 HEAPF32[$149>>2] = $184;
 $185 = Math_fround($173 + $158);
 HEAPF32[$161>>2] = $185;
 $186 = Math_fround($174 + $159);
 HEAPF32[$162>>2] = $186;
 $187 = Math_fround($175 + $160);
 HEAPF32[$163>>2] = $187;
 $188 = Math_fround($136 - $141);
 $189 = Math_fround($137 - $142);
 $190 = Math_fround($138 - $143);
 $191 = Math_fround($188 + $144);
 HEAPF32[$153>>2] = $191;
 $192 = Math_fround($189 + $145);
 HEAPF32[$154>>2] = $192;
 $193 = Math_fround($190 + $146);
 HEAPF32[$155>>2] = $193;
 $194 = Math_fround($188 + $158);
 HEAPF32[$167>>2] = $194;
 $195 = Math_fround($189 + $159);
 HEAPF32[$168>>2] = $195;
 $196 = Math_fround($190 + $160);
 HEAPF32[$169>>2] = $196;
 $197 = Math_fround($144 - $188);
 HEAPF32[$150>>2] = $197;
 $198 = Math_fround($145 - $189);
 HEAPF32[$151>>2] = $198;
 $199 = Math_fround($146 - $190);
 HEAPF32[$152>>2] = $199;
 $200 = Math_fround($158 - $188);
 HEAPF32[$164>>2] = $200;
 $201 = Math_fround($159 - $189);
 HEAPF32[$165>>2] = $201;
 $202 = Math_fround($160 - $190);
 HEAPF32[$166>>2] = $202;
 $203 = Math_fround(-$contactDistance);
 $204 = (($contactNormal) + 4|0);
 $205 = (($contactNormal) + 8|0);
 $i$075 = 0;
 while(1) {
  $208 = (($vtx) + ($i$075<<4)|0);
  $209 = Math_fround(HEAPF32[$208>>2]);
  $210 = $209 < $203;
  do {
   if ($210) {
    $211 = ((($vtx) + ($i$075<<4)|0) + 13|0);
    HEAP8[$211>>0] = 0;
    $212 = ((($vtx) + ($i$075<<4)|0) + 12|0);
    HEAP8[$212>>0] = 0;
   } else {
    $213 = ((($vtx) + ($i$075<<4)|0) + 12|0);
    HEAP8[$213>>0] = 1;
    $214 = ((($vtx) + ($i$075<<4)|0) + 4|0);
    $215 = Math_fround(HEAPF32[$214>>2]);
    $fabsf$i$i31 = (Math_fround(Math_abs((Math_fround($215)))));
    $216 = !($fabsf$i$i31 <= $1);
    if (!($216)) {
     $217 = ((($vtx) + ($i$075<<4)|0) + 8|0);
     $218 = Math_fround(HEAPF32[$217>>2]);
     $fabsf$i$i30 = (Math_fround(Math_abs((Math_fround($218)))));
     $219 = !($fabsf$i$i30 <= $92);
     if (!($219)) {
      $220 = ((($vtx) + ($i$075<<4)|0) + 13|0);
      HEAP8[$220>>0] = 1;
      $221 = HEAP32[$0>>2]|0;
      $222 = ($221>>>0)>(63);
      if ($222) {
       break;
      }
      $223 = Math_fround(-$209);
      $224 = (($221) + 1)|0;
      HEAP32[$0>>2] = $224;
      $225 = Math_fround(HEAPF32[$contactNormal>>2]);
      $226 = (($contactBuffer) + ($221<<6)|0);
      HEAPF32[$226>>2] = $225;
      $227 = Math_fround(HEAPF32[$204>>2]);
      $228 = ((($contactBuffer) + ($221<<6)|0) + 4|0);
      HEAPF32[$228>>2] = $227;
      $229 = Math_fround(HEAPF32[$205>>2]);
      $230 = ((($contactBuffer) + ($221<<6)|0) + 8|0);
      HEAPF32[$230>>2] = $229;
      $231 = ((($contactBuffer) + ($221<<6)|0) + 16|0);
      HEAPF32[$231>>2] = $209;
      $232 = ((($contactBuffer) + ($221<<6)|0) + 20|0);
      HEAPF32[$232>>2] = $215;
      $233 = ((($contactBuffer) + ($221<<6)|0) + 24|0);
      HEAPF32[$233>>2] = $218;
      $234 = ((($contactBuffer) + ($221<<6)|0) + 12|0);
      HEAPF32[$234>>2] = $223;
      $235 = ((($contactBuffer) + ($221<<6)|0) + 48|0);
      HEAP32[$235>>2] = -1;
      $236 = ((($contactBuffer) + ($221<<6)|0) + 52|0);
      HEAP32[$236>>2] = -1;
      break;
     }
    }
    $237 = ((($vtx) + ($i$075<<4)|0) + 13|0);
    HEAP8[$237>>0] = 0;
   }
  } while(0);
  $238 = (($i$075) + 1)|0;
  $exitcond = ($238|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i$075 = $238;
  }
 }
 $206 = Math_fround(-$1);
 $207 = Math_fround(-$92);
 $runningLine$074 = 502904;
 while(1) {
  $242 = (($runningLine$074) + 4|0);
  $243 = HEAP32[$runningLine$074>>2]|0;
  $244 = (($vtx) + ($243<<4)|0);
  $245 = (($runningLine$074) + 8|0);
  $246 = HEAP32[$242>>2]|0;
  $247 = (($vtx) + ($246<<4)|0);
  $248 = ((($vtx) + ($243<<4)|0) + 12|0);
  $249 = HEAP8[$248>>0]|0;
  $250 = ($249<<24>>24)==(0);
  if ($250) {
   $251 = ((($vtx) + ($246<<4)|0) + 12|0);
   $252 = HEAP8[$251>>0]|0;
   $253 = ($252<<24>>24)==(0);
   if (!($253)) {
    label = 15;
   }
  } else {
   label = 15;
  }
  do {
   if ((label|0) == 15) {
    label = 0;
    $255 = ((($vtx) + ($243<<4)|0) + 13|0);
    $256 = HEAP8[$255>>0]|0;
    $257 = ($256<<24>>24)==(0);
    if ($257) {
     label = 17;
    } else {
     $258 = ((($vtx) + ($246<<4)|0) + 13|0);
     $259 = HEAP8[$258>>0]|0;
     $260 = ($259<<24>>24)==(0);
     if ($260) {
      label = 17;
     } else {
      $p1$2 = $244;$p2$2 = $247;
     }
    }
    if ((label|0) == 17) {
     label = 0;
     $261 = ((($vtx) + ($243<<4)|0) + 4|0);
     $262 = Math_fround(HEAPF32[$261>>2]);
     $263 = ((($vtx) + ($246<<4)|0) + 4|0);
     $264 = Math_fround(HEAPF32[$263>>2]);
     $265 = $262 > $264;
     $p2$0 = $265 ? $244 : $247;
     $p1$0 = $265 ? $247 : $244;
     $266 = (($p1$0) + 4|0);
     $267 = Math_fround(HEAPF32[$266>>2]);
     $268 = $267 < $1;
     if ($268) {
      $269 = (($p2$0) + 4|0);
      $270 = Math_fround(HEAPF32[$269>>2]);
      $271 = !($270 >= $1);
      if (!($271)) {
       $272 = Math_fround($1 - $267);
       $273 = Math_fround($270 - $267);
       $274 = Math_fround($272 / $273);
       $275 = (($p1$0) + 8|0);
       $276 = Math_fround(HEAPF32[$275>>2]);
       $277 = (($p2$0) + 8|0);
       $278 = Math_fround(HEAPF32[$277>>2]);
       $279 = Math_fround($278 - $276);
       $280 = Math_fround($274 * $279);
       $281 = Math_fround($276 + $280);
       $fabsf$i$i28 = (Math_fround(Math_abs((Math_fround($281)))));
       $282 = !($fabsf$i$i28 <= $92);
       if (!($282)) {
        $283 = Math_fround(HEAPF32[$p1$0>>2]);
        $284 = Math_fround(HEAPF32[$p2$0>>2]);
        $285 = Math_fround($284 - $283);
        $286 = Math_fround($274 * $285);
        $287 = Math_fround($283 + $286);
        $288 = Math_fround($287 + $contactDistance);
        $289 = !($288 >= Math_fround(0.0));
        if (!($289)) {
         $290 = HEAP32[$0>>2]|0;
         $291 = ($290>>>0)>(63);
         if (!($291)) {
          $292 = Math_fround(-$287);
          $293 = (($290) + 1)|0;
          HEAP32[$0>>2] = $293;
          $294 = Math_fround(HEAPF32[$contactNormal>>2]);
          $295 = (($contactBuffer) + ($290<<6)|0);
          HEAPF32[$295>>2] = $294;
          $296 = Math_fround(HEAPF32[$204>>2]);
          $297 = ((($contactBuffer) + ($290<<6)|0) + 4|0);
          HEAPF32[$297>>2] = $296;
          $298 = Math_fround(HEAPF32[$205>>2]);
          $299 = ((($contactBuffer) + ($290<<6)|0) + 8|0);
          HEAPF32[$299>>2] = $298;
          $300 = ((($contactBuffer) + ($290<<6)|0) + 16|0);
          HEAPF32[$300>>2] = $287;
          $301 = ((($contactBuffer) + ($290<<6)|0) + 20|0);
          HEAPF32[$301>>2] = $1;
          $302 = ((($contactBuffer) + ($290<<6)|0) + 24|0);
          HEAPF32[$302>>2] = $281;
          $303 = ((($contactBuffer) + ($290<<6)|0) + 12|0);
          HEAPF32[$303>>2] = $292;
          $304 = ((($contactBuffer) + ($290<<6)|0) + 48|0);
          HEAP32[$304>>2] = -1;
          $305 = ((($contactBuffer) + ($290<<6)|0) + 52|0);
          HEAP32[$305>>2] = -1;
         }
        }
       }
      }
     }
     $306 = $267 < $206;
     if ($306) {
      $307 = (($p2$0) + 4|0);
      $308 = Math_fround(HEAPF32[$307>>2]);
      $309 = !($308 >= $206);
      if (!($309)) {
       $310 = Math_fround($206 - $267);
       $311 = Math_fround($308 - $267);
       $312 = Math_fround($310 / $311);
       $313 = (($p1$0) + 8|0);
       $314 = Math_fround(HEAPF32[$313>>2]);
       $315 = (($p2$0) + 8|0);
       $316 = Math_fround(HEAPF32[$315>>2]);
       $317 = Math_fround($316 - $314);
       $318 = Math_fround($312 * $317);
       $319 = Math_fround($314 + $318);
       $fabsf$i$i26 = (Math_fround(Math_abs((Math_fround($319)))));
       $320 = !($fabsf$i$i26 <= $92);
       if (!($320)) {
        $321 = Math_fround(HEAPF32[$p1$0>>2]);
        $322 = Math_fround(HEAPF32[$p2$0>>2]);
        $323 = Math_fround($322 - $321);
        $324 = Math_fround($312 * $323);
        $325 = Math_fround($321 + $324);
        $326 = Math_fround($325 + $contactDistance);
        $327 = !($326 >= Math_fround(0.0));
        if (!($327)) {
         $328 = HEAP32[$0>>2]|0;
         $329 = ($328>>>0)>(63);
         if (!($329)) {
          $330 = Math_fround(-$325);
          $331 = (($328) + 1)|0;
          HEAP32[$0>>2] = $331;
          $332 = Math_fround(HEAPF32[$contactNormal>>2]);
          $333 = (($contactBuffer) + ($328<<6)|0);
          HEAPF32[$333>>2] = $332;
          $334 = Math_fround(HEAPF32[$204>>2]);
          $335 = ((($contactBuffer) + ($328<<6)|0) + 4|0);
          HEAPF32[$335>>2] = $334;
          $336 = Math_fround(HEAPF32[$205>>2]);
          $337 = ((($contactBuffer) + ($328<<6)|0) + 8|0);
          HEAPF32[$337>>2] = $336;
          $338 = ((($contactBuffer) + ($328<<6)|0) + 16|0);
          HEAPF32[$338>>2] = $325;
          $339 = ((($contactBuffer) + ($328<<6)|0) + 20|0);
          HEAPF32[$339>>2] = $206;
          $340 = ((($contactBuffer) + ($328<<6)|0) + 24|0);
          HEAPF32[$340>>2] = $319;
          $341 = ((($contactBuffer) + ($328<<6)|0) + 12|0);
          HEAPF32[$341>>2] = $330;
          $342 = ((($contactBuffer) + ($328<<6)|0) + 48|0);
          HEAP32[$342>>2] = -1;
          $343 = ((($contactBuffer) + ($328<<6)|0) + 52|0);
          HEAP32[$343>>2] = -1;
         }
        }
       }
      }
     }
     $344 = (($p1$0) + 8|0);
     $345 = Math_fround(HEAPF32[$344>>2]);
     $346 = (($p2$0) + 8|0);
     $347 = Math_fround(HEAPF32[$346>>2]);
     $348 = $345 > $347;
     $p2$1 = $348 ? $p1$0 : $p2$0;
     $p1$1 = $348 ? $p2$0 : $p1$0;
     $349 = (($p1$1) + 8|0);
     $350 = Math_fround(HEAPF32[$349>>2]);
     $351 = $350 < $92;
     if ($351) {
      $352 = (($p2$1) + 8|0);
      $353 = Math_fround(HEAPF32[$352>>2]);
      $354 = !($353 >= $92);
      if (!($354)) {
       $355 = Math_fround($92 - $350);
       $356 = Math_fround($353 - $350);
       $357 = Math_fround($355 / $356);
       $358 = (($p1$1) + 4|0);
       $359 = Math_fround(HEAPF32[$358>>2]);
       $360 = (($p2$1) + 4|0);
       $361 = Math_fround(HEAPF32[$360>>2]);
       $362 = Math_fround($361 - $359);
       $363 = Math_fround($357 * $362);
       $364 = Math_fround($359 + $363);
       $fabsf$i$i24 = (Math_fround(Math_abs((Math_fround($364)))));
       $365 = !($fabsf$i$i24 <= $1);
       if (!($365)) {
        $366 = Math_fround(HEAPF32[$p1$1>>2]);
        $367 = Math_fround(HEAPF32[$p2$1>>2]);
        $368 = Math_fround($367 - $366);
        $369 = Math_fround($357 * $368);
        $370 = Math_fround($366 + $369);
        $371 = Math_fround($370 + $contactDistance);
        $372 = !($371 >= Math_fround(0.0));
        if (!($372)) {
         $373 = HEAP32[$0>>2]|0;
         $374 = ($373>>>0)>(63);
         if (!($374)) {
          $375 = Math_fround(-$370);
          $376 = (($373) + 1)|0;
          HEAP32[$0>>2] = $376;
          $377 = Math_fround(HEAPF32[$contactNormal>>2]);
          $378 = (($contactBuffer) + ($373<<6)|0);
          HEAPF32[$378>>2] = $377;
          $379 = Math_fround(HEAPF32[$204>>2]);
          $380 = ((($contactBuffer) + ($373<<6)|0) + 4|0);
          HEAPF32[$380>>2] = $379;
          $381 = Math_fround(HEAPF32[$205>>2]);
          $382 = ((($contactBuffer) + ($373<<6)|0) + 8|0);
          HEAPF32[$382>>2] = $381;
          $383 = ((($contactBuffer) + ($373<<6)|0) + 16|0);
          HEAPF32[$383>>2] = $370;
          $384 = ((($contactBuffer) + ($373<<6)|0) + 20|0);
          HEAPF32[$384>>2] = $364;
          $385 = ((($contactBuffer) + ($373<<6)|0) + 24|0);
          HEAPF32[$385>>2] = $92;
          $386 = ((($contactBuffer) + ($373<<6)|0) + 12|0);
          HEAPF32[$386>>2] = $375;
          $387 = ((($contactBuffer) + ($373<<6)|0) + 48|0);
          HEAP32[$387>>2] = -1;
          $388 = ((($contactBuffer) + ($373<<6)|0) + 52|0);
          HEAP32[$388>>2] = -1;
         }
        }
       }
      }
     }
     $389 = $350 < $207;
     if ($389) {
      $390 = (($p2$1) + 8|0);
      $391 = Math_fround(HEAPF32[$390>>2]);
      $392 = !($391 >= $207);
      if ($392) {
       $p1$2 = $p1$1;$p2$2 = $p2$1;
      } else {
       $393 = Math_fround($207 - $350);
       $394 = Math_fround($391 - $350);
       $395 = Math_fround($393 / $394);
       $396 = (($p1$1) + 4|0);
       $397 = Math_fround(HEAPF32[$396>>2]);
       $398 = (($p2$1) + 4|0);
       $399 = Math_fround(HEAPF32[$398>>2]);
       $400 = Math_fround($399 - $397);
       $401 = Math_fround($395 * $400);
       $402 = Math_fround($397 + $401);
       $fabsf$i$i22 = (Math_fround(Math_abs((Math_fround($402)))));
       $403 = !($fabsf$i$i22 <= $1);
       if ($403) {
        $p1$2 = $p1$1;$p2$2 = $p2$1;
       } else {
        $404 = Math_fround(HEAPF32[$p1$1>>2]);
        $405 = Math_fround(HEAPF32[$p2$1>>2]);
        $406 = Math_fround($405 - $404);
        $407 = Math_fround($395 * $406);
        $408 = Math_fround($404 + $407);
        $409 = Math_fround($408 + $contactDistance);
        $410 = !($409 >= Math_fround(0.0));
        if ($410) {
         $p1$2 = $p1$1;$p2$2 = $p2$1;
        } else {
         $411 = HEAP32[$0>>2]|0;
         $412 = ($411>>>0)>(63);
         if ($412) {
          $p1$2 = $p1$1;$p2$2 = $p2$1;
         } else {
          $413 = Math_fround(-$408);
          $414 = (($411) + 1)|0;
          HEAP32[$0>>2] = $414;
          $415 = Math_fround(HEAPF32[$contactNormal>>2]);
          $416 = (($contactBuffer) + ($411<<6)|0);
          HEAPF32[$416>>2] = $415;
          $417 = Math_fround(HEAPF32[$204>>2]);
          $418 = ((($contactBuffer) + ($411<<6)|0) + 4|0);
          HEAPF32[$418>>2] = $417;
          $419 = Math_fround(HEAPF32[$205>>2]);
          $420 = ((($contactBuffer) + ($411<<6)|0) + 8|0);
          HEAPF32[$420>>2] = $419;
          $421 = ((($contactBuffer) + ($411<<6)|0) + 16|0);
          HEAPF32[$421>>2] = $408;
          $422 = ((($contactBuffer) + ($411<<6)|0) + 20|0);
          HEAPF32[$422>>2] = $402;
          $423 = ((($contactBuffer) + ($411<<6)|0) + 24|0);
          HEAPF32[$423>>2] = $207;
          $424 = ((($contactBuffer) + ($411<<6)|0) + 12|0);
          HEAPF32[$424>>2] = $413;
          $425 = ((($contactBuffer) + ($411<<6)|0) + 48|0);
          HEAP32[$425>>2] = -1;
          $426 = ((($contactBuffer) + ($411<<6)|0) + 52|0);
          HEAP32[$426>>2] = -1;
          $p1$2 = $p1$1;$p2$2 = $p2$1;
         }
        }
       }
      }
     } else {
      $p1$2 = $p1$1;$p2$2 = $p2$1;
     }
    }
    $427 = (($p1$2) + 12|0);
    $428 = HEAP8[$427>>0]|0;
    $429 = ($428<<24>>24)==(0);
    if ($429) {
     $430 = (($p2$2) + 13|0);
     $431 = HEAP8[$430>>0]|0;
     $432 = ($431<<24>>24)==(0);
     if (!($432)) {
      label = 43;
     }
    } else {
     label = 43;
    }
    if ((label|0) == 43) {
     label = 0;
     $433 = (($p2$2) + 12|0);
     $434 = HEAP8[$433>>0]|0;
     $435 = ($434<<24>>24)==(0);
     if (!($435)) {
      break;
     }
     $436 = (($p1$2) + 13|0);
     $437 = HEAP8[$436>>0]|0;
     $438 = ($437<<24>>24)==(0);
     if (!($438)) {
      break;
     }
    }
    $439 = Math_fround(HEAPF32[$p1$2>>2]);
    $440 = Math_fround(-$439);
    $441 = Math_fround(HEAPF32[$p2$2>>2]);
    $442 = Math_fround($441 - $439);
    $443 = Math_fround($440 / $442);
    $444 = (($p1$2) + 4|0);
    $445 = Math_fround(HEAPF32[$444>>2]);
    $446 = (($p2$2) + 4|0);
    $447 = Math_fround(HEAPF32[$446>>2]);
    $448 = Math_fround($447 - $445);
    $449 = Math_fround($443 * $448);
    $450 = Math_fround($445 + $449);
    $fabsf$i$i20 = (Math_fround(Math_abs((Math_fround($450)))));
    $451 = !($fabsf$i$i20 <= $1);
    if (!($451)) {
     $452 = (($p1$2) + 8|0);
     $453 = Math_fround(HEAPF32[$452>>2]);
     $454 = (($p2$2) + 8|0);
     $455 = Math_fround(HEAPF32[$454>>2]);
     $456 = Math_fround($455 - $453);
     $457 = Math_fround($443 * $456);
     $458 = Math_fround($453 + $457);
     $fabsf$i$i = (Math_fround(Math_abs((Math_fround($458)))));
     $459 = !($fabsf$i$i <= $92);
     if (!($459)) {
      $460 = HEAP32[$0>>2]|0;
      $461 = ($460>>>0)>(63);
      if (!($461)) {
       $462 = (($460) + 1)|0;
       HEAP32[$0>>2] = $462;
       $463 = Math_fround(HEAPF32[$contactNormal>>2]);
       $464 = (($contactBuffer) + ($460<<6)|0);
       HEAPF32[$464>>2] = $463;
       $465 = Math_fround(HEAPF32[$204>>2]);
       $466 = ((($contactBuffer) + ($460<<6)|0) + 4|0);
       HEAPF32[$466>>2] = $465;
       $467 = Math_fround(HEAPF32[$205>>2]);
       $468 = ((($contactBuffer) + ($460<<6)|0) + 8|0);
       HEAPF32[$468>>2] = $467;
       $469 = ((($contactBuffer) + ($460<<6)|0) + 16|0);
       HEAPF32[$469>>2] = Math_fround(0.0);
       $470 = ((($contactBuffer) + ($460<<6)|0) + 20|0);
       HEAPF32[$470>>2] = $450;
       $471 = ((($contactBuffer) + ($460<<6)|0) + 24|0);
       HEAPF32[$471>>2] = $458;
       $472 = ((($contactBuffer) + ($460<<6)|0) + 12|0);
       HEAPF32[$472>>2] = Math_fround(0.0);
       $473 = ((($contactBuffer) + ($460<<6)|0) + 48|0);
       HEAP32[$473>>2] = -1;
       $474 = ((($contactBuffer) + ($460<<6)|0) + 52|0);
       HEAP32[$474>>2] = -1;
      }
     }
    }
   }
  } while(0);
  $254 = ($245|0)==(((502904 + 96|0))|0);
  if ($254) {
   break;
  } else {
   $runningLine$074 = $245;
  }
 }
 $239 = (($q) + 4|0);
 $240 = (($q) + 8|0);
 $241 = (($q) + 12|0);
 $addflg$072 = 0;$i13$073 = 0;
 while(1) {
  $477 = (503000 + ($i13$073<<4)|0);
  $478 = HEAP32[$477>>2]|0;
  $479 = (($vtx) + ($478<<4)|0);
  HEAP32[$q>>2] = $479;
  $480 = ((($vtx) + ($478<<4)|0) + 12|0);
  $481 = HEAP8[$480>>0]|0;
  $482 = ($481<<24>>24)==(0);
  L63: do {
   if ($482) {
    $addflg$4 = $addflg$072;
   } else {
    $483 = ((503000 + ($i13$073<<4)|0) + 4|0);
    $484 = HEAP32[$483>>2]|0;
    $485 = (($vtx) + ($484<<4)|0);
    HEAP32[$239>>2] = $485;
    $486 = ((($vtx) + ($484<<4)|0) + 12|0);
    $487 = HEAP8[$486>>0]|0;
    $488 = ($487<<24>>24)==(0);
    if ($488) {
     $addflg$4 = $addflg$072;
    } else {
     $489 = ((503000 + ($i13$073<<4)|0) + 8|0);
     $490 = HEAP32[$489>>2]|0;
     $491 = (($vtx) + ($490<<4)|0);
     HEAP32[$240>>2] = $491;
     $492 = ((($vtx) + ($490<<4)|0) + 12|0);
     $493 = HEAP8[$492>>0]|0;
     $494 = ($493<<24>>24)==(0);
     if ($494) {
      $addflg$4 = $addflg$072;
     } else {
      $495 = ((503000 + ($i13$073<<4)|0) + 12|0);
      $496 = HEAP32[$495>>2]|0;
      $497 = (($vtx) + ($496<<4)|0);
      HEAP32[$241>>2] = $497;
      $498 = ((($vtx) + ($496<<4)|0) + 12|0);
      $499 = HEAP8[$498>>0]|0;
      $500 = ($499<<24>>24)==(0);
      if ($500) {
       $addflg$4 = $addflg$072;
      } else {
       $501 = ((($vtx) + ($478<<4)|0) + 13|0);
       $502 = HEAP8[$501>>0]|0;
       $503 = ($502<<24>>24)==(0);
       if (!($503)) {
        $504 = ((($vtx) + ($484<<4)|0) + 13|0);
        $505 = HEAP8[$504>>0]|0;
        $506 = ($505<<24>>24)==(0);
        if (!($506)) {
         $507 = ((($vtx) + ($490<<4)|0) + 13|0);
         $508 = HEAP8[$507>>0]|0;
         $509 = ($508<<24>>24)==(0);
         if (!($509)) {
          $510 = ((($vtx) + ($496<<4)|0) + 13|0);
          $511 = HEAP8[$510>>0]|0;
          $512 = ($511<<24>>24)==(0);
          if (!($512)) {
           $addflg$4 = $addflg$072;
           break;
          }
         }
        }
       }
       $513 = $addflg$072 & 1;
       $514 = ($513|0)==(0);
       L73: do {
        if ($514) {
         $515 = ((($vtx) + ($496<<4)|0) + 4|0);
         $516 = Math_fround(HEAPF32[$515>>2]);
         $517 = ((($vtx) + ($496<<4)|0) + 8|0);
         $518 = Math_fround(HEAPF32[$517>>2]);
         $521 = $479;$PreviousY$03$i14 = $516;$PreviousZ$02$i15 = $518;$i$01$i16 = 1;
         while(1) {
          $520 = (($521) + 4|0);
          $522 = Math_fround(HEAPF32[$520>>2]);
          $523 = (($521) + 8|0);
          $524 = Math_fround(HEAPF32[$523>>2]);
          $525 = Math_fround($522 - $PreviousY$03$i14);
          $526 = Math_fround($207 - $PreviousZ$02$i15);
          $527 = Math_fround($526 * $525);
          $528 = Math_fround($524 - $PreviousZ$02$i15);
          $529 = Math_fround($206 - $PreviousY$03$i14);
          $530 = Math_fround($529 * $528);
          $531 = Math_fround($527 - $530);
          $532 = !($531 >= Math_fround(0.0));
          if (!($532)) {
           $addflg$1 = $addflg$072;
           break L73;
          }
          $519 = ($i$01$i16|0)<(4);
          if (!($519)) {
           break;
          }
          $$phi$trans$insert = (($q) + ($i$01$i16<<2)|0);
          $$pre = HEAP32[$$phi$trans$insert>>2]|0;
          $phitmp90 = (($i$01$i16) + 1)|0;
          $521 = $$pre;$PreviousY$03$i14 = $522;$PreviousZ$02$i15 = $524;$i$01$i16 = $phitmp90;
         }
         $533 = Math_fround(HEAPF32[$479>>2]);
         $534 = ((($vtx) + ($478<<4)|0) + 4|0);
         $535 = Math_fround(HEAPF32[$534>>2]);
         $536 = Math_fround($206 - $535);
         $537 = ((($vtx) + ($478<<4)|0) + 8|0);
         $538 = Math_fround(HEAPF32[$537>>2]);
         $539 = Math_fround($207 - $538);
         $540 = Math_fround(HEAPF32[$485>>2]);
         $541 = Math_fround($540 - $533);
         $542 = ((($vtx) + ($484<<4)|0) + 4|0);
         $543 = Math_fround(HEAPF32[$542>>2]);
         $544 = Math_fround($543 - $535);
         $545 = ((($vtx) + ($484<<4)|0) + 8|0);
         $546 = Math_fround(HEAPF32[$545>>2]);
         $547 = Math_fround($546 - $538);
         $548 = Math_fround($536 * $544);
         $549 = Math_fround($539 * $547);
         $550 = Math_fround($548 + $549);
         $551 = Math_fround($541 * $550);
         $552 = Math_fround($541 * $541);
         $553 = Math_fround($544 * $544);
         $554 = Math_fround($552 + $553);
         $555 = Math_fround($547 * $547);
         $556 = Math_fround($554 + $555);
         $557 = Math_fround($551 / $556);
         $558 = Math_fround($533 + $557);
         $559 = Math_fround(HEAPF32[$497>>2]);
         $560 = Math_fround($559 - $533);
         $561 = Math_fround($516 - $535);
         $562 = Math_fround($518 - $538);
         $563 = Math_fround($536 * $561);
         $564 = Math_fround($539 * $562);
         $565 = Math_fround($563 + $564);
         $566 = Math_fround($565 * $560);
         $567 = Math_fround($560 * $560);
         $568 = Math_fround($561 * $561);
         $569 = Math_fround($568 + $567);
         $570 = Math_fround($562 * $562);
         $571 = Math_fround($570 + $569);
         $572 = Math_fround($566 / $571);
         $573 = Math_fround($558 + $572);
         $574 = !($573 >= Math_fround(0.0));
         if ($574) {
          $addflg$1 = $addflg$072;
         } else {
          $575 = $addflg$072 | 1;
          $576 = HEAP32[$0>>2]|0;
          $577 = ($576>>>0)>(63);
          if ($577) {
           $addflg$1 = $575;
          } else {
           $578 = Math_fround(-$573);
           $579 = (($576) + 1)|0;
           HEAP32[$0>>2] = $579;
           $580 = Math_fround(HEAPF32[$contactNormal>>2]);
           $581 = (($contactBuffer) + ($576<<6)|0);
           HEAPF32[$581>>2] = $580;
           $582 = Math_fround(HEAPF32[$204>>2]);
           $583 = ((($contactBuffer) + ($576<<6)|0) + 4|0);
           HEAPF32[$583>>2] = $582;
           $584 = Math_fround(HEAPF32[$205>>2]);
           $585 = ((($contactBuffer) + ($576<<6)|0) + 8|0);
           HEAPF32[$585>>2] = $584;
           $586 = ((($contactBuffer) + ($576<<6)|0) + 16|0);
           HEAPF32[$586>>2] = $573;
           $587 = ((($contactBuffer) + ($576<<6)|0) + 20|0);
           HEAPF32[$587>>2] = $206;
           $588 = ((($contactBuffer) + ($576<<6)|0) + 24|0);
           HEAPF32[$588>>2] = $207;
           $589 = ((($contactBuffer) + ($576<<6)|0) + 12|0);
           HEAPF32[$589>>2] = $578;
           $590 = ((($contactBuffer) + ($576<<6)|0) + 48|0);
           HEAP32[$590>>2] = -1;
           $591 = ((($contactBuffer) + ($576<<6)|0) + 52|0);
           HEAP32[$591>>2] = -1;
           $addflg$1 = $575;
          }
         }
        } else {
         $addflg$1 = $addflg$072;
        }
       } while(0);
       $592 = $addflg$1 & 2;
       $593 = ($592|0)==(0);
       L83: do {
        if ($593) {
         $594 = ((($vtx) + ($496<<4)|0) + 4|0);
         $595 = Math_fround(HEAPF32[$594>>2]);
         $596 = ((($vtx) + ($496<<4)|0) + 8|0);
         $597 = Math_fround(HEAPF32[$596>>2]);
         $600 = $479;$PreviousY$03$i8 = $595;$PreviousZ$02$i9 = $597;$i$01$i10 = 1;
         while(1) {
          $599 = (($600) + 4|0);
          $601 = Math_fround(HEAPF32[$599>>2]);
          $602 = (($600) + 8|0);
          $603 = Math_fround(HEAPF32[$602>>2]);
          $604 = Math_fround($601 - $PreviousY$03$i8);
          $605 = Math_fround($207 - $PreviousZ$02$i9);
          $606 = Math_fround($605 * $604);
          $607 = Math_fround($603 - $PreviousZ$02$i9);
          $608 = Math_fround($1 - $PreviousY$03$i8);
          $609 = Math_fround($608 * $607);
          $610 = Math_fround($606 - $609);
          $611 = !($610 >= Math_fround(0.0));
          if (!($611)) {
           $addflg$2 = $addflg$1;
           break L83;
          }
          $598 = ($i$01$i10|0)<(4);
          if (!($598)) {
           break;
          }
          $$phi$trans$insert82 = (($q) + ($i$01$i10<<2)|0);
          $$pre83 = HEAP32[$$phi$trans$insert82>>2]|0;
          $phitmp89 = (($i$01$i10) + 1)|0;
          $600 = $$pre83;$PreviousY$03$i8 = $601;$PreviousZ$02$i9 = $603;$i$01$i10 = $phitmp89;
         }
         $612 = Math_fround(HEAPF32[$479>>2]);
         $613 = ((($vtx) + ($478<<4)|0) + 4|0);
         $614 = Math_fround(HEAPF32[$613>>2]);
         $615 = Math_fround($1 - $614);
         $616 = ((($vtx) + ($478<<4)|0) + 8|0);
         $617 = Math_fround(HEAPF32[$616>>2]);
         $618 = Math_fround($207 - $617);
         $619 = Math_fround(HEAPF32[$485>>2]);
         $620 = Math_fround($619 - $612);
         $621 = ((($vtx) + ($484<<4)|0) + 4|0);
         $622 = Math_fround(HEAPF32[$621>>2]);
         $623 = Math_fround($622 - $614);
         $624 = ((($vtx) + ($484<<4)|0) + 8|0);
         $625 = Math_fround(HEAPF32[$624>>2]);
         $626 = Math_fround($625 - $617);
         $627 = Math_fround($615 * $623);
         $628 = Math_fround($618 * $626);
         $629 = Math_fround($627 + $628);
         $630 = Math_fround($620 * $629);
         $631 = Math_fround($620 * $620);
         $632 = Math_fround($623 * $623);
         $633 = Math_fround($631 + $632);
         $634 = Math_fround($626 * $626);
         $635 = Math_fround($633 + $634);
         $636 = Math_fround($630 / $635);
         $637 = Math_fround($612 + $636);
         $638 = Math_fround(HEAPF32[$497>>2]);
         $639 = Math_fround($638 - $612);
         $640 = Math_fround($595 - $614);
         $641 = Math_fround($597 - $617);
         $642 = Math_fround($615 * $640);
         $643 = Math_fround($618 * $641);
         $644 = Math_fround($642 + $643);
         $645 = Math_fround($644 * $639);
         $646 = Math_fround($639 * $639);
         $647 = Math_fround($640 * $640);
         $648 = Math_fround($647 + $646);
         $649 = Math_fround($641 * $641);
         $650 = Math_fround($649 + $648);
         $651 = Math_fround($645 / $650);
         $652 = Math_fround($637 + $651);
         $653 = !($652 >= Math_fround(0.0));
         if ($653) {
          $addflg$2 = $addflg$1;
         } else {
          $654 = $addflg$1 | 2;
          $655 = HEAP32[$0>>2]|0;
          $656 = ($655>>>0)>(63);
          if ($656) {
           $addflg$2 = $654;
          } else {
           $657 = Math_fround(-$652);
           $658 = (($655) + 1)|0;
           HEAP32[$0>>2] = $658;
           $659 = Math_fround(HEAPF32[$contactNormal>>2]);
           $660 = (($contactBuffer) + ($655<<6)|0);
           HEAPF32[$660>>2] = $659;
           $661 = Math_fround(HEAPF32[$204>>2]);
           $662 = ((($contactBuffer) + ($655<<6)|0) + 4|0);
           HEAPF32[$662>>2] = $661;
           $663 = Math_fround(HEAPF32[$205>>2]);
           $664 = ((($contactBuffer) + ($655<<6)|0) + 8|0);
           HEAPF32[$664>>2] = $663;
           $665 = ((($contactBuffer) + ($655<<6)|0) + 16|0);
           HEAPF32[$665>>2] = $652;
           $666 = ((($contactBuffer) + ($655<<6)|0) + 20|0);
           HEAPF32[$666>>2] = $1;
           $667 = ((($contactBuffer) + ($655<<6)|0) + 24|0);
           HEAPF32[$667>>2] = $207;
           $668 = ((($contactBuffer) + ($655<<6)|0) + 12|0);
           HEAPF32[$668>>2] = $657;
           $669 = ((($contactBuffer) + ($655<<6)|0) + 48|0);
           HEAP32[$669>>2] = -1;
           $670 = ((($contactBuffer) + ($655<<6)|0) + 52|0);
           HEAP32[$670>>2] = -1;
           $addflg$2 = $654;
          }
         }
        } else {
         $addflg$2 = $addflg$1;
        }
       } while(0);
       $671 = $addflg$2 & 4;
       $672 = ($671|0)==(0);
       L93: do {
        if ($672) {
         $673 = ((($vtx) + ($496<<4)|0) + 4|0);
         $674 = Math_fround(HEAPF32[$673>>2]);
         $675 = ((($vtx) + ($496<<4)|0) + 8|0);
         $676 = Math_fround(HEAPF32[$675>>2]);
         $679 = $479;$PreviousY$03$i2 = $674;$PreviousZ$02$i3 = $676;$i$01$i4 = 1;
         while(1) {
          $678 = (($679) + 4|0);
          $680 = Math_fround(HEAPF32[$678>>2]);
          $681 = (($679) + 8|0);
          $682 = Math_fround(HEAPF32[$681>>2]);
          $683 = Math_fround($680 - $PreviousY$03$i2);
          $684 = Math_fround($92 - $PreviousZ$02$i3);
          $685 = Math_fround($684 * $683);
          $686 = Math_fround($682 - $PreviousZ$02$i3);
          $687 = Math_fround($206 - $PreviousY$03$i2);
          $688 = Math_fround($687 * $686);
          $689 = Math_fround($685 - $688);
          $690 = !($689 >= Math_fround(0.0));
          if (!($690)) {
           $addflg$3 = $addflg$2;
           break L93;
          }
          $677 = ($i$01$i4|0)<(4);
          if (!($677)) {
           break;
          }
          $$phi$trans$insert84 = (($q) + ($i$01$i4<<2)|0);
          $$pre85 = HEAP32[$$phi$trans$insert84>>2]|0;
          $phitmp88 = (($i$01$i4) + 1)|0;
          $679 = $$pre85;$PreviousY$03$i2 = $680;$PreviousZ$02$i3 = $682;$i$01$i4 = $phitmp88;
         }
         $691 = Math_fround(HEAPF32[$479>>2]);
         $692 = ((($vtx) + ($478<<4)|0) + 4|0);
         $693 = Math_fround(HEAPF32[$692>>2]);
         $694 = Math_fround($206 - $693);
         $695 = ((($vtx) + ($478<<4)|0) + 8|0);
         $696 = Math_fround(HEAPF32[$695>>2]);
         $697 = Math_fround($92 - $696);
         $698 = Math_fround(HEAPF32[$485>>2]);
         $699 = Math_fround($698 - $691);
         $700 = ((($vtx) + ($484<<4)|0) + 4|0);
         $701 = Math_fround(HEAPF32[$700>>2]);
         $702 = Math_fround($701 - $693);
         $703 = ((($vtx) + ($484<<4)|0) + 8|0);
         $704 = Math_fround(HEAPF32[$703>>2]);
         $705 = Math_fround($704 - $696);
         $706 = Math_fround($694 * $702);
         $707 = Math_fround($697 * $705);
         $708 = Math_fround($706 + $707);
         $709 = Math_fround($699 * $708);
         $710 = Math_fround($699 * $699);
         $711 = Math_fround($702 * $702);
         $712 = Math_fround($710 + $711);
         $713 = Math_fround($705 * $705);
         $714 = Math_fround($712 + $713);
         $715 = Math_fround($709 / $714);
         $716 = Math_fround($691 + $715);
         $717 = Math_fround(HEAPF32[$497>>2]);
         $718 = Math_fround($717 - $691);
         $719 = Math_fround($674 - $693);
         $720 = Math_fround($676 - $696);
         $721 = Math_fround($694 * $719);
         $722 = Math_fround($697 * $720);
         $723 = Math_fround($721 + $722);
         $724 = Math_fround($723 * $718);
         $725 = Math_fround($718 * $718);
         $726 = Math_fround($719 * $719);
         $727 = Math_fround($726 + $725);
         $728 = Math_fround($720 * $720);
         $729 = Math_fround($728 + $727);
         $730 = Math_fround($724 / $729);
         $731 = Math_fround($716 + $730);
         $732 = !($731 >= Math_fround(0.0));
         if ($732) {
          $addflg$3 = $addflg$2;
         } else {
          $733 = $addflg$2 | 4;
          $734 = HEAP32[$0>>2]|0;
          $735 = ($734>>>0)>(63);
          if ($735) {
           $addflg$3 = $733;
          } else {
           $736 = Math_fround(-$731);
           $737 = (($734) + 1)|0;
           HEAP32[$0>>2] = $737;
           $738 = Math_fround(HEAPF32[$contactNormal>>2]);
           $739 = (($contactBuffer) + ($734<<6)|0);
           HEAPF32[$739>>2] = $738;
           $740 = Math_fround(HEAPF32[$204>>2]);
           $741 = ((($contactBuffer) + ($734<<6)|0) + 4|0);
           HEAPF32[$741>>2] = $740;
           $742 = Math_fround(HEAPF32[$205>>2]);
           $743 = ((($contactBuffer) + ($734<<6)|0) + 8|0);
           HEAPF32[$743>>2] = $742;
           $744 = ((($contactBuffer) + ($734<<6)|0) + 16|0);
           HEAPF32[$744>>2] = $731;
           $745 = ((($contactBuffer) + ($734<<6)|0) + 20|0);
           HEAPF32[$745>>2] = $206;
           $746 = ((($contactBuffer) + ($734<<6)|0) + 24|0);
           HEAPF32[$746>>2] = $92;
           $747 = ((($contactBuffer) + ($734<<6)|0) + 12|0);
           HEAPF32[$747>>2] = $736;
           $748 = ((($contactBuffer) + ($734<<6)|0) + 48|0);
           HEAP32[$748>>2] = -1;
           $749 = ((($contactBuffer) + ($734<<6)|0) + 52|0);
           HEAP32[$749>>2] = -1;
           $addflg$3 = $733;
          }
         }
        } else {
         $addflg$3 = $addflg$2;
        }
       } while(0);
       $750 = $addflg$3 & 8;
       $751 = ($750|0)==(0);
       if ($751) {
        $752 = ((($vtx) + ($496<<4)|0) + 4|0);
        $753 = Math_fround(HEAPF32[$752>>2]);
        $754 = ((($vtx) + ($496<<4)|0) + 8|0);
        $755 = Math_fround(HEAPF32[$754>>2]);
        $758 = $479;$PreviousY$03$i = $753;$PreviousZ$02$i = $755;$i$01$i = 1;
        while(1) {
         $757 = (($758) + 4|0);
         $759 = Math_fround(HEAPF32[$757>>2]);
         $760 = (($758) + 8|0);
         $761 = Math_fround(HEAPF32[$760>>2]);
         $762 = Math_fround($759 - $PreviousY$03$i);
         $763 = Math_fround($92 - $PreviousZ$02$i);
         $764 = Math_fround($763 * $762);
         $765 = Math_fround($761 - $PreviousZ$02$i);
         $766 = Math_fround($1 - $PreviousY$03$i);
         $767 = Math_fround($766 * $765);
         $768 = Math_fround($764 - $767);
         $769 = !($768 >= Math_fround(0.0));
         if (!($769)) {
          $addflg$4 = $addflg$3;
          break L63;
         }
         $756 = ($i$01$i|0)<(4);
         if (!($756)) {
          break;
         }
         $$phi$trans$insert86 = (($q) + ($i$01$i<<2)|0);
         $$pre87 = HEAP32[$$phi$trans$insert86>>2]|0;
         $phitmp = (($i$01$i) + 1)|0;
         $758 = $$pre87;$PreviousY$03$i = $759;$PreviousZ$02$i = $761;$i$01$i = $phitmp;
        }
        $770 = Math_fround(HEAPF32[$479>>2]);
        $771 = ((($vtx) + ($478<<4)|0) + 4|0);
        $772 = Math_fround(HEAPF32[$771>>2]);
        $773 = Math_fround($1 - $772);
        $774 = ((($vtx) + ($478<<4)|0) + 8|0);
        $775 = Math_fround(HEAPF32[$774>>2]);
        $776 = Math_fround($92 - $775);
        $777 = Math_fround(HEAPF32[$485>>2]);
        $778 = Math_fround($777 - $770);
        $779 = ((($vtx) + ($484<<4)|0) + 4|0);
        $780 = Math_fround(HEAPF32[$779>>2]);
        $781 = Math_fround($780 - $772);
        $782 = ((($vtx) + ($484<<4)|0) + 8|0);
        $783 = Math_fround(HEAPF32[$782>>2]);
        $784 = Math_fround($783 - $775);
        $785 = Math_fround($773 * $781);
        $786 = Math_fround($776 * $784);
        $787 = Math_fround($785 + $786);
        $788 = Math_fround($778 * $787);
        $789 = Math_fround($778 * $778);
        $790 = Math_fround($781 * $781);
        $791 = Math_fround($789 + $790);
        $792 = Math_fround($784 * $784);
        $793 = Math_fround($791 + $792);
        $794 = Math_fround($788 / $793);
        $795 = Math_fround($770 + $794);
        $796 = Math_fround(HEAPF32[$497>>2]);
        $797 = Math_fround($796 - $770);
        $798 = Math_fround($753 - $772);
        $799 = Math_fround($755 - $775);
        $800 = Math_fround($773 * $798);
        $801 = Math_fround($776 * $799);
        $802 = Math_fround($800 + $801);
        $803 = Math_fround($802 * $797);
        $804 = Math_fround($797 * $797);
        $805 = Math_fround($798 * $798);
        $806 = Math_fround($805 + $804);
        $807 = Math_fround($799 * $799);
        $808 = Math_fround($807 + $806);
        $809 = Math_fround($803 / $808);
        $810 = Math_fround($795 + $809);
        $811 = !($810 >= Math_fround(0.0));
        if ($811) {
         $addflg$4 = $addflg$3;
        } else {
         $812 = $addflg$3 | 8;
         $813 = HEAP32[$0>>2]|0;
         $814 = ($813>>>0)>(63);
         if ($814) {
          $addflg$4 = $812;
         } else {
          $815 = Math_fround(-$810);
          $816 = (($813) + 1)|0;
          HEAP32[$0>>2] = $816;
          $817 = Math_fround(HEAPF32[$contactNormal>>2]);
          $818 = (($contactBuffer) + ($813<<6)|0);
          HEAPF32[$818>>2] = $817;
          $819 = Math_fround(HEAPF32[$204>>2]);
          $820 = ((($contactBuffer) + ($813<<6)|0) + 4|0);
          HEAPF32[$820>>2] = $819;
          $821 = Math_fround(HEAPF32[$205>>2]);
          $822 = ((($contactBuffer) + ($813<<6)|0) + 8|0);
          HEAPF32[$822>>2] = $821;
          $823 = ((($contactBuffer) + ($813<<6)|0) + 16|0);
          HEAPF32[$823>>2] = $810;
          $824 = ((($contactBuffer) + ($813<<6)|0) + 20|0);
          HEAPF32[$824>>2] = $1;
          $825 = ((($contactBuffer) + ($813<<6)|0) + 24|0);
          HEAPF32[$825>>2] = $92;
          $826 = ((($contactBuffer) + ($813<<6)|0) + 12|0);
          HEAPF32[$826>>2] = $815;
          $827 = ((($contactBuffer) + ($813<<6)|0) + 48|0);
          HEAP32[$827>>2] = -1;
          $828 = ((($contactBuffer) + ($813<<6)|0) + 52|0);
          HEAP32[$828>>2] = -1;
          $addflg$4 = $812;
         }
        }
       } else {
        $addflg$4 = $addflg$3;
       }
      }
     }
    }
   }
  } while(0);
  $829 = (($i13$073) + 1)|0;
  $830 = ($829>>>0)>(5);
  $831 = ($addflg$4|0)==(15);
  $or$cond = $830 | $831;
  if ($or$cond) {
   break;
  } else {
   $addflg$072 = $addflg$4;$i13$073 = $829;
  }
 }
 $475 = HEAP32[$0>>2]|0;
 $476 = ($475|0)==(0);
 if ($476) {
  $$lcssa = 0;
  STACKTOP = sp;return ($$lcssa|0);
 } else {
  $i19$071 = 0;
 }
 while(1) {
  $832 = ((($contactBuffer) + ($i19$071<<6)|0) + 16|0);
  $833 = Math_fround(HEAPF32[$832>>2]);
  $834 = Math_fround(HEAPF32[$transform0>>2]);
  $835 = Math_fround($833 * $834);
  $836 = Math_fround(HEAPF32[$3>>2]);
  $837 = Math_fround($833 * $836);
  $838 = Math_fround(HEAPF32[$5>>2]);
  $839 = Math_fround($833 * $838);
  $840 = ((($contactBuffer) + ($i19$071<<6)|0) + 20|0);
  $841 = Math_fround(HEAPF32[$840>>2]);
  $842 = Math_fround(HEAPF32[$7>>2]);
  $843 = Math_fround($841 * $842);
  $844 = Math_fround(HEAPF32[$9>>2]);
  $845 = Math_fround($841 * $844);
  $846 = Math_fround(HEAPF32[$11>>2]);
  $847 = Math_fround($841 * $846);
  $848 = Math_fround($835 + $843);
  $849 = Math_fround($837 + $845);
  $850 = Math_fround($839 + $847);
  $851 = ((($contactBuffer) + ($i19$071<<6)|0) + 24|0);
  $852 = Math_fround(HEAPF32[$851>>2]);
  $853 = Math_fround(HEAPF32[$13>>2]);
  $854 = Math_fround($852 * $853);
  $855 = Math_fround(HEAPF32[$15>>2]);
  $856 = Math_fround($852 * $855);
  $857 = Math_fround(HEAPF32[$17>>2]);
  $858 = Math_fround($852 * $857);
  $859 = Math_fround($848 + $854);
  $860 = Math_fround($849 + $856);
  $861 = Math_fround($850 + $858);
  $862 = Math_fround(HEAPF32[$19>>2]);
  $863 = Math_fround($859 + $862);
  $864 = Math_fround(HEAPF32[$22>>2]);
  $865 = Math_fround($860 + $864);
  $866 = Math_fround(HEAPF32[$25>>2]);
  $867 = Math_fround($861 + $866);
  HEAPF32[$832>>2] = $863;
  HEAPF32[$840>>2] = $865;
  HEAPF32[$851>>2] = $867;
  $868 = (($i19$071) + 1)|0;
  $869 = ($868>>>0)<($475>>>0);
  if ($869) {
   $i19$071 = $868;
  } else {
   $$lcssa = $475;
   break;
  }
 }
 STACKTOP = sp;return ($$lcssa|0);
}
function __ZN5physx24PxcContactBoxHeightFieldERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$ = Math_fround(0), $$0 = 0, $$115 = Math_fround(0), $$116 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0);
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0);
 var $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0);
 var $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0);
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0);
 var $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0);
 var $473 = 0, $474 = Math_fround(0), $475 = 0, $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0);
 var $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0);
 var $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = 0;
 var $563 = 0, $564 = 0, $565 = 0, $566 = Math_fround(0), $567 = Math_fround(0), $568 = 0, $569 = 0, $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = Math_fround(0);
 var $581 = 0, $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = Math_fround(0), $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0);
 var $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = 0, $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = 0, $616 = Math_fround(0);
 var $617 = 0, $618 = Math_fround(0), $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0);
 var $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0);
 var $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = Math_fround(0), $670 = 0;
 var $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = Math_fround(0), $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = Math_fround(0), $689 = 0;
 var $69 = Math_fround(0), $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = Math_fround(0), $695 = Math_fround(0), $696 = 0, $697 = 0, $698 = 0, $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = 0, $701 = 0, $702 = Math_fround(0), $703 = 0, $704 = 0, $705 = Math_fround(0), $706 = 0;
 var $707 = 0, $708 = 0, $709 = Math_fround(0), $71 = Math_fround(0), $710 = 0, $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = 0, $715 = Math_fround(0), $716 = Math_fround(0), $717 = 0, $718 = Math_fround(0), $719 = 0, $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = 0, $724 = Math_fround(0);
 var $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = Math_fround(0), $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = 0, $738 = 0, $739 = 0, $74 = Math_fround(0), $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0);
 var $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = Math_fround(0), $760 = Math_fround(0);
 var $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = 0, $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = 0, $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = 0, $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0);
 var $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = 0, $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0);
 var $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0);
 var $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = 0, $82 = Math_fround(0), $820 = 0, $821 = Math_fround(0), $822 = 0, $823 = 0, $824 = Math_fround(0), $825 = Math_fround(0), $826 = 0, $827 = Math_fround(0), $828 = 0, $829 = Math_fround(0), $83 = Math_fround(0), $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0);
 var $833 = 0, $834 = 0, $835 = 0, $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0, $850 = Math_fround(0);
 var $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0);
 var $87 = 0, $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = 0, $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = 0, $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0);
 var $888 = 0, $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = Math_fround(0), $892 = 0, $893 = 0, $894 = 0, $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0);
 var $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0);
 var $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0;
 var $941 = 0, $942 = 0, $943 = 0, $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $boxVertexNormals = 0, $boxVertexNormalsInHfShape = 0, $boxVertices = 0, $boxVerticesInHfShape = 0, $column$073 = 0, $distance1$014$i = Math_fround(0);
 var $distance1$1$i = Math_fround(0), $distance1$2$i = Math_fround(0), $distance1$2$i$distance2$1$i = Math_fround(0), $distance2$013$i = Math_fround(0), $distance2$1$i = Math_fround(0), $exitcond = 0, $exitcond100 = 0, $exitcond102 = 0, $exitcond103 = 0, $exitcond104 = 0, $exitcond105 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i2 = Math_fround(0), $fabsf$i$i3 = Math_fround(0), $fracX = 0, $fracZ = 0, $hfUtil = 0, $hfVertexInBoxShape = 0, $i$094 = 0, $i1$092 = 0;
 var $i2$090 = 0, $i3$086 = 0, $i3$086$us = 0, $i4$084 = 0, $left = 0, $maxColumn$0 = 0, $maxRow$0 = 0, $minColumn$0 = 0, $minRow$0 = 0, $n$i = 0, $normalInHfShape = 0, $nrm = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$us = 0, $or$cond$i6 = 0, $or$cond$i6$us = 0, $or$cond$us = 0, $or$cond1$i = 0, $or$cond1$i$us = 0;
 var $poly$010$i = 0, $poly1$012$i = 0, $poly1$1$i = 0, $poly1$2$i = 0, $poly2$011$i = 0, $poly2$1$i = 0, $row$080 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 656|0;
 $n$i = sp + 584|0;
 $hfUtil = sp + 564|0;
 $left = sp + 528|0;
 $0 = sp + 492|0;
 $1 = sp + 456|0;
 $boxVertices = sp + 360|0;
 $boxVertexNormals = sp + 264|0;
 $boxVerticesInHfShape = sp + 168|0;
 $boxVertexNormalsInHfShape = sp + 72|0;
 $fracX = sp + 52|0;
 $fracZ = sp + 48|0;
 $2 = sp + 36|0;
 $hfVertexInBoxShape = sp + 24|0;
 $nrm = sp + 12|0;
 $3 = sp;
 $normalInHfShape = sp + 56|0;
 $4 = (($shape1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($hfUtil) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (($hfUtil) + 16|0);
 HEAP32[$7>>2] = $shape1;
 $8 = (($shape1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(Math_fround(1.0) / $9);
 $11 = (($hfUtil) + 4|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($shape1) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(Math_fround(1.0) / $13);
 HEAPF32[$hfUtil>>2] = $14;
 $15 = (($shape1) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(Math_fround(1.0) / $16);
 $18 = (($hfUtil) + 8|0);
 HEAPF32[$18>>2] = $17;
 $19 = Math_fround(HEAPF32[$transform0>>2]);
 $20 = Math_fround($19 + $19);
 $21 = (($transform0) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 + $22);
 $24 = (($transform0) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $25);
 $27 = (($transform0) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($20 * $28);
 $30 = Math_fround($23 * $28);
 $31 = Math_fround($28 * $26);
 $32 = Math_fround($19 * $20);
 $33 = Math_fround($19 * $23);
 $34 = Math_fround($19 * $26);
 $35 = Math_fround($22 * $23);
 $36 = Math_fround($22 * $26);
 $37 = Math_fround($25 * $26);
 $38 = Math_fround(Math_fround(1.0) - $35);
 $39 = Math_fround($38 - $37);
 $40 = Math_fround($33 + $31);
 $41 = Math_fround($34 - $30);
 $42 = Math_fround($33 - $31);
 $43 = Math_fround(Math_fround(1.0) - $32);
 $44 = Math_fround($43 - $37);
 $45 = Math_fround($36 + $29);
 $46 = Math_fround($34 + $30);
 $47 = Math_fround($36 - $29);
 $48 = Math_fround($43 - $35);
 $49 = (($transform0) + 16|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($transform0) + 20|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($transform0) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround(HEAPF32[$transform1>>2]);
 $56 = Math_fround($55 + $55);
 $57 = (($transform1) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 + $58);
 $60 = (($transform1) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 + $61);
 $63 = (($transform1) + 12|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($56 * $64);
 $66 = Math_fround($59 * $64);
 $67 = Math_fround($64 * $62);
 $68 = Math_fround($55 * $56);
 $69 = Math_fround($55 * $59);
 $70 = Math_fround($55 * $62);
 $71 = Math_fround($58 * $59);
 $72 = Math_fround($58 * $62);
 $73 = Math_fround($61 * $62);
 $74 = Math_fround(Math_fround(1.0) - $71);
 $75 = Math_fround($74 - $73);
 $76 = Math_fround($69 + $67);
 $77 = Math_fround($70 - $66);
 $78 = Math_fround($69 - $67);
 $79 = Math_fround(Math_fround(1.0) - $68);
 $80 = Math_fround($79 - $73);
 $81 = Math_fround($72 + $65);
 $82 = Math_fround($70 + $66);
 $83 = Math_fround($72 - $65);
 $84 = Math_fround($79 - $71);
 $85 = (($transform1) + 16|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($transform1) + 20|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($transform1) + 24|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 HEAPF32[$left>>2] = $75;
 $91 = (($left) + 4|0);
 HEAPF32[$91>>2] = $76;
 $92 = (($left) + 8|0);
 HEAPF32[$92>>2] = $77;
 $93 = (($left) + 12|0);
 HEAPF32[$93>>2] = $78;
 $94 = (($left) + 16|0);
 HEAPF32[$94>>2] = $80;
 $95 = (($left) + 20|0);
 HEAPF32[$95>>2] = $81;
 $96 = (($left) + 24|0);
 HEAPF32[$96>>2] = $82;
 $97 = (($left) + 28|0);
 HEAPF32[$97>>2] = $83;
 $98 = (($left) + 32|0);
 HEAPF32[$98>>2] = $84;
 __ZNK5physx7PxMat3310getInverseEv($0,$left);
 $99 = Math_fround(HEAPF32[$0>>2]);
 $100 = (($0) + 4|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($39 * $101);
 $103 = (($0) + 8|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($0) + 12|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($0) + 16|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($40 * $108);
 $110 = (($0) + 20|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($40 * $111);
 $113 = Math_fround($102 + $109);
 $114 = (($0) + 24|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($0) + 28|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($41 * $117);
 $119 = (($0) + 32|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($41 * $120);
 $122 = Math_fround($113 + $118);
 $123 = Math_fround($42 * $99);
 $124 = Math_fround($42 * $104);
 $125 = Math_fround($44 * $106);
 $126 = Math_fround($44 * $111);
 $127 = Math_fround($123 + $125);
 $128 = Math_fround($124 + $126);
 $129 = Math_fround($45 * $115);
 $130 = Math_fround($45 * $120);
 $131 = Math_fround($127 + $129);
 $132 = Math_fround($128 + $130);
 $133 = Math_fround($46 * $101);
 $134 = Math_fround($46 * $104);
 $135 = Math_fround($47 * $108);
 $136 = Math_fround($47 * $111);
 $137 = Math_fround($133 + $135);
 $138 = Math_fround($134 + $136);
 $139 = Math_fround($48 * $117);
 $140 = Math_fround($48 * $120);
 $141 = Math_fround($137 + $139);
 __ZNK5physx7PxMat3310getInverseEv($1,$left);
 $142 = Math_fround($50 - $86);
 $143 = Math_fround($52 - $88);
 $144 = Math_fround($54 - $90);
 $145 = Math_fround(HEAPF32[$1>>2]);
 $146 = (($1) + 4|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = Math_fround($142 * $147);
 $149 = (($1) + 8|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = (($1) + 12|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($1) + 16|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = Math_fround($143 * $154);
 $156 = (($1) + 20|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = Math_fround($143 * $157);
 $159 = Math_fround($148 + $155);
 $160 = (($1) + 24|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($1) + 28|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = Math_fround($144 * $163);
 $165 = (($1) + 32|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = Math_fround($144 * $166);
 $168 = Math_fround($159 + $164);
 $169 = Math_fround($39 * $99);
 $170 = Math_fround($39 * $104);
 $171 = Math_fround($40 * $106);
 $172 = Math_fround($169 + $171);
 $173 = Math_fround($170 + $112);
 $174 = Math_fround($41 * $115);
 $175 = Math_fround($172 + $174);
 $176 = Math_fround($173 + $121);
 $177 = Math_fround($42 * $101);
 $178 = Math_fround($44 * $108);
 $179 = Math_fround($177 + $178);
 $180 = Math_fround($45 * $117);
 $181 = Math_fround($179 + $180);
 $182 = Math_fround($46 * $99);
 $183 = Math_fround($47 * $106);
 $184 = Math_fround($182 + $183);
 $185 = Math_fround($48 * $115);
 $186 = Math_fround($184 + $185);
 $187 = Math_fround($138 + $140);
 $188 = Math_fround($142 * $145);
 $189 = Math_fround($142 * $150);
 $190 = Math_fround($143 * $152);
 $191 = Math_fround($188 + $190);
 $192 = Math_fround($189 + $158);
 $193 = Math_fround($144 * $161);
 $194 = Math_fround($191 + $193);
 $195 = Math_fround($192 + $167);
 $196 = (($shape0) + 4|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = (($shape0) + 8|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($shape0) + 12|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $i$094 = 0;
 while(1) {
  $202 = ($i$094*3)|0;
  $203 = (503096 + ($202<<2)|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = Math_fround($197 * $204);
  $206 = (($202) + 1)|0;
  $207 = (503096 + ($206<<2)|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = Math_fround($199 * $208);
  $210 = (($202) + 2)|0;
  $211 = (503096 + ($210<<2)|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $213 = Math_fround($201 * $212);
  $214 = (($boxVertices) + (($i$094*12)|0)|0);
  HEAPF32[$214>>2] = $205;
  $215 = ((($boxVertices) + (($i$094*12)|0)|0) + 4|0);
  HEAPF32[$215>>2] = $209;
  $216 = ((($boxVertices) + (($i$094*12)|0)|0) + 8|0);
  HEAPF32[$216>>2] = $213;
  $217 = (($boxVertexNormals) + (($i$094*12)|0)|0);
  HEAPF32[$217>>2] = $204;
  $218 = ((($boxVertexNormals) + (($i$094*12)|0)|0) + 4|0);
  HEAPF32[$218>>2] = $208;
  $219 = ((($boxVertexNormals) + (($i$094*12)|0)|0) + 8|0);
  HEAPF32[$219>>2] = $212;
  $220 = Math_fround($204 * $204);
  $221 = Math_fround($208 * $208);
  $222 = Math_fround($220 + $221);
  $223 = Math_fround($212 * $212);
  $224 = Math_fround($223 + $222);
  $225 = (Math_fround(Math_sqrt((Math_fround($224)))));
  $226 = $225 > Math_fround(0.0);
  if ($226) {
   $227 = Math_fround(Math_fround(1.0) / $225);
   $228 = Math_fround($204 * $227);
   HEAPF32[$217>>2] = $228;
   $229 = Math_fround($208 * $227);
   HEAPF32[$218>>2] = $229;
   $230 = Math_fround($212 * $227);
   HEAPF32[$219>>2] = $230;
  }
  $231 = (($i$094) + 1)|0;
  $exitcond104 = ($231|0)==(8);
  if ($exitcond104) {
   break;
  } else {
   $i$094 = $231;
  }
 }
 $i1$092 = 0;
 while(1) {
  $232 = (($boxVertices) + (($i1$092*12)|0)|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = Math_fround($175 * $233);
  $235 = Math_fround($122 * $233);
  $236 = Math_fround($176 * $233);
  $237 = ((($boxVertices) + (($i1$092*12)|0)|0) + 4|0);
  $238 = Math_fround(HEAPF32[$237>>2]);
  $239 = Math_fround($131 * $238);
  $240 = Math_fround($181 * $238);
  $241 = Math_fround($132 * $238);
  $242 = Math_fround($234 + $239);
  $243 = Math_fround($235 + $240);
  $244 = Math_fround($236 + $241);
  $245 = ((($boxVertices) + (($i1$092*12)|0)|0) + 8|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround($186 * $246);
  $248 = Math_fround($141 * $246);
  $249 = Math_fround($187 * $246);
  $250 = Math_fround($242 + $247);
  $251 = Math_fround($243 + $248);
  $252 = Math_fround($244 + $249);
  $253 = Math_fround($194 + $250);
  $254 = Math_fround($168 + $251);
  $255 = Math_fround($195 + $252);
  $256 = (($boxVerticesInHfShape) + (($i1$092*12)|0)|0);
  HEAPF32[$256>>2] = $253;
  $257 = ((($boxVerticesInHfShape) + (($i1$092*12)|0)|0) + 4|0);
  HEAPF32[$257>>2] = $254;
  $258 = ((($boxVerticesInHfShape) + (($i1$092*12)|0)|0) + 8|0);
  HEAPF32[$258>>2] = $255;
  $259 = (($boxVertexNormals) + (($i1$092*12)|0)|0);
  $260 = Math_fround(HEAPF32[$259>>2]);
  $261 = Math_fround($175 * $260);
  $262 = Math_fround($122 * $260);
  $263 = Math_fround($176 * $260);
  $264 = ((($boxVertexNormals) + (($i1$092*12)|0)|0) + 4|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = Math_fround($131 * $265);
  $267 = Math_fround($181 * $265);
  $268 = Math_fround($132 * $265);
  $269 = Math_fround($261 + $266);
  $270 = Math_fround($262 + $267);
  $271 = Math_fround($263 + $268);
  $272 = ((($boxVertexNormals) + (($i1$092*12)|0)|0) + 8|0);
  $273 = Math_fround(HEAPF32[$272>>2]);
  $274 = Math_fround($186 * $273);
  $275 = Math_fround($141 * $273);
  $276 = Math_fround($187 * $273);
  $277 = Math_fround($269 + $274);
  $278 = Math_fround($270 + $275);
  $279 = Math_fround($271 + $276);
  $280 = (($boxVertexNormalsInHfShape) + (($i1$092*12)|0)|0);
  HEAPF32[$280>>2] = $277;
  $281 = ((($boxVertexNormalsInHfShape) + (($i1$092*12)|0)|0) + 4|0);
  HEAPF32[$281>>2] = $278;
  $282 = ((($boxVertexNormalsInHfShape) + (($i1$092*12)|0)|0) + 8|0);
  HEAPF32[$282>>2] = $279;
  $283 = (($i1$092) + 1)|0;
  $exitcond103 = ($283|0)==(8);
  if ($exitcond103) {
   break;
  } else {
   $i1$092 = $283;
  }
 }
 $284 = Math_fround(HEAPF32[$boxVerticesInHfShape>>2]);
 $285 = (($boxVerticesInHfShape) + 4|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = (($boxVerticesInHfShape) + 8|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $292 = $284;$295 = $284;$300 = $286;$303 = $286;$308 = $288;$311 = $288;$i2$090 = 1;
 while(1) {
  $289 = (($boxVerticesInHfShape) + (($i2$090*12)|0)|0);
  $290 = Math_fround(HEAPF32[$289>>2]);
  $291 = $292 < $290;
  $293 = $291 ? $292 : $290;
  $294 = $295 > $290;
  $296 = $294 ? $295 : $290;
  $297 = (($289) + 4|0);
  $298 = Math_fround(HEAPF32[$297>>2]);
  $299 = $300 < $298;
  $301 = $299 ? $300 : $298;
  $302 = $303 > $298;
  $304 = $302 ? $303 : $298;
  $305 = (($289) + 8|0);
  $306 = Math_fround(HEAPF32[$305>>2]);
  $307 = $308 < $306;
  $309 = $307 ? $308 : $306;
  $310 = $311 > $306;
  $312 = $310 ? $311 : $306;
  $313 = (($i2$090) + 1)|0;
  $exitcond102 = ($313|0)==(8);
  if ($exitcond102) {
   break;
  } else {
   $292 = $293;$295 = $296;$300 = $301;$303 = $304;$308 = $309;$311 = $312;$i2$090 = $313;
  }
 }
 $314 = (($5) + 40|0);
 $315 = Math_fround(HEAPF32[$314>>2]);
 $316 = $315 <= Math_fround(0.0);
 $317 = Math_fround(HEAPF32[$hfUtil>>2]);
 $318 = Math_fround(HEAPF32[$18>>2]);
 $319 = Math_fround(HEAPF32[$12>>2]);
 $320 = $319 < Math_fround(0.0);
 if ($320) {
  $321 = Math_fround($317 * $296);
  $322 = (Math_fround(Math_floor((Math_fround($321)))));
  $323 = (~~(($322)));
  $324 = (($5) + 16|0);
  $325 = HEAP32[$324>>2]|0;
  $326 = (($325) + -2)|0;
  $327 = ($323|0)>(0);
  $328 = $327 ? $323 : 0;
  $329 = ($328|0)>($326|0);
  $330 = $329 ? $326 : $328;
  $331 = Math_fround($317 * $293);
  $332 = (Math_fround(Math_ceil((Math_fround($331)))));
  $333 = (~~(($332)));
  $334 = (($325) + -1)|0;
  $335 = ($333|0)>(0);
  $336 = $335 ? $333 : 0;
  $337 = ($336|0)>($334|0);
  $338 = $337 ? $334 : $336;
  $maxRow$0 = $338;$minRow$0 = $330;
 } else {
  $339 = Math_fround($317 * $293);
  $340 = (Math_fround(Math_floor((Math_fround($339)))));
  $341 = (~~(($340)));
  $342 = (($5) + 16|0);
  $343 = HEAP32[$342>>2]|0;
  $344 = (($343) + -2)|0;
  $345 = ($341|0)>(0);
  $346 = $345 ? $341 : 0;
  $347 = ($346|0)>($344|0);
  $348 = $347 ? $344 : $346;
  $349 = Math_fround($317 * $296);
  $350 = (Math_fround(Math_ceil((Math_fround($349)))));
  $351 = (~~(($350)));
  $352 = (($343) + -1)|0;
  $353 = ($351|0)>(0);
  $354 = $353 ? $351 : 0;
  $355 = ($354|0)>($352|0);
  $356 = $355 ? $352 : $354;
  $maxRow$0 = $356;$minRow$0 = $348;
 }
 $357 = Math_fround(HEAPF32[$15>>2]);
 $358 = $357 < Math_fround(0.0);
 if ($358) {
  $359 = Math_fround($318 * $312);
  $360 = (Math_fround(Math_floor((Math_fround($359)))));
  $361 = (~~(($360)));
  $362 = (($5) + 20|0);
  $363 = HEAP32[$362>>2]|0;
  $364 = (($363) + -2)|0;
  $365 = ($361|0)>(0);
  $366 = $365 ? $361 : 0;
  $367 = ($366|0)>($364|0);
  $368 = $367 ? $364 : $366;
  $369 = Math_fround($318 * $309);
  $370 = (Math_fround(Math_ceil((Math_fround($369)))));
  $371 = (~~(($370)));
  $372 = (($363) + -1)|0;
  $373 = ($371|0)>(0);
  $374 = $373 ? $371 : 0;
  $375 = ($374|0)>($372|0);
  $376 = $375 ? $372 : $374;
  $maxColumn$0 = $376;$minColumn$0 = $368;
 } else {
  $377 = Math_fround($318 * $309);
  $378 = (Math_fround(Math_floor((Math_fround($377)))));
  $379 = (~~(($378)));
  $380 = (($5) + 20|0);
  $381 = HEAP32[$380>>2]|0;
  $382 = (($381) + -2)|0;
  $383 = ($379|0)>(0);
  $384 = $383 ? $379 : 0;
  $385 = ($384|0)>($382|0);
  $386 = $385 ? $382 : $384;
  $387 = Math_fround($318 * $312);
  $388 = (Math_fround(Math_ceil((Math_fround($387)))));
  $389 = (~~(($388)));
  $390 = (($381) + -1)|0;
  $391 = ($389|0)>(0);
  $392 = $391 ? $389 : 0;
  $393 = ($392|0)>($390|0);
  $394 = $393 ? $390 : $392;
  $maxColumn$0 = $394;$minColumn$0 = $386;
 }
 $395 = (Math_fround(__ZNK5physx2Gu11HeightField14computeExtremeEjjjj($5,$minRow$0,$maxRow$0,$minColumn$0,$maxColumn$0)));
 $396 = Math_fround(HEAPF32[$8>>2]);
 $397 = Math_fround($395 * $396);
 if ($316) {
  $398 = $301 > $397;
  if ($398) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $403 = (($2) + 4|0);
  $404 = (($2) + 8|0);
  $405 = (($contactBuffer) + 4096|0);
  $i3$086$us = 0;
  while(1) {
   $406 = ((($boxVertexNormalsInHfShape) + (($i3$086$us*12)|0)|0) + 4|0);
   $407 = HEAP32[$406>>2]|0;
   $408 = ($407|0)>(0);
   do {
    if (!($408)) {
     $409 = ((($boxVerticesInHfShape) + (($i3$086$us*12)|0)|0) + 4|0);
     $410 = Math_fround(HEAPF32[$contactDistance>>2]);
     $411 = Math_fround(HEAPF32[$409>>2]);
     $412 = Math_fround($397 + $410);
     $413 = $411 < $412;
     if ($413) {
      $414 = (($boxVerticesInHfShape) + (($i3$086$us*12)|0)|0);
      $415 = Math_fround(HEAPF32[$414>>2]);
      $416 = ((($boxVerticesInHfShape) + (($i3$086$us*12)|0)|0) + 8|0);
      $417 = Math_fround(HEAPF32[$416>>2]);
      $418 = Math_fround(HEAPF32[$hfUtil>>2]);
      $419 = Math_fround($415 * $418);
      $420 = Math_fround(HEAPF32[$18>>2]);
      $421 = Math_fround($417 * $420);
      $422 = !($419 >= Math_fround(0.0));
      $423 = !($421 >= Math_fround(0.0));
      $or$cond$i6$us = $422 | $423;
      if (!($or$cond$i6$us)) {
       $424 = HEAP32[$6>>2]|0;
       $425 = (($424) + 24|0);
       $426 = Math_fround(HEAPF32[$425>>2]);
       $427 = Math_fround($426 + Math_fround(1.0));
       $428 = $419 < $427;
       if ($428) {
        $429 = (($424) + 28|0);
        $430 = Math_fround(HEAPF32[$429>>2]);
        $431 = Math_fround($430 + Math_fround(1.0));
        $432 = $421 < $431;
        if ($432) {
         $433 = Math_fround($317 * $415);
         $434 = Math_fround($318 * $417);
         $435 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($424,$433,$434,$fracX,$fracZ)|0);
         $436 = Math_fround(HEAPF32[$fracX>>2]);
         $437 = Math_fround(HEAPF32[$fracZ>>2]);
         $438 = HEAP32[$7>>2]|0;
         $439 = (($438) + 8|0);
         $440 = Math_fround(HEAPF32[$439>>2]);
         $441 = HEAP32[$6>>2]|0;
         $442 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($441,$435,$436,$437)));
         $443 = Math_fround($440 * $442);
         $444 = Math_fround(HEAPF32[$409>>2]);
         $445 = Math_fround($444 - $443);
         $446 = Math_fround(HEAPF32[$contactDistance>>2]);
         $447 = Math_fround(HEAPF32[$314>>2]);
         $448 = !($447 <= Math_fround(0.0));
         $449 = !($445 <= $446);
         $or$cond$i$us = $448 | $449;
         $450 = !($447 <= $445);
         $or$cond1$i$us = $or$cond$i$us | $450;
         if ($or$cond1$i$us) {
          $451 = $447 > Math_fround(0.0);
          if (!($451)) {
           break;
          }
          $452 = Math_fround(-$446);
          $453 = $445 > $452;
          $454 = $447 > $445;
          $or$cond$us = $453 & $454;
          if (!($or$cond$us)) {
           break;
          }
         }
         $455 = (__ZNK5physx2Gu15HeightFieldUtil31getFaceIndexAtShapePointNoTest2Ejff($hfUtil,$435,$436,$437)|0);
         $456 = ($455|0)==(-1);
         if (!($456)) {
          $457 = Math_fround(HEAPF32[$fracX>>2]);
          $458 = Math_fround(HEAPF32[$fracZ>>2]);
          __ZNK5physx2Gu15HeightFieldUtil22getNormalAtShapePoint2Ejff($2,$hfUtil,$435,$457,$458);
          $459 = Math_fround(HEAPF32[$2>>2]);
          $460 = Math_fround(HEAPF32[$403>>2]);
          $461 = Math_fround(HEAPF32[$404>>2]);
          $462 = Math_fround($459 * $459);
          $463 = Math_fround($460 * $460);
          $464 = Math_fround($462 + $463);
          $465 = Math_fround($461 * $461);
          $466 = Math_fround($464 + $465);
          $467 = $466 > Math_fround(0.0);
          if ($467) {
           $468 = (Math_fround(Math_sqrt((Math_fround($466)))));
           $469 = Math_fround(Math_fround(1.0) / $468);
           $470 = Math_fround($459 * $469);
           $471 = Math_fround($460 * $469);
           $472 = Math_fround($461 * $469);
           $488 = $471;$492 = $470;$502 = $472;
          } else {
           $488 = Math_fround(0.0);$492 = Math_fround(0.0);$502 = Math_fround(0.0);
          }
          $473 = (($boxVertices) + (($i3$086$us*12)|0)|0);
          $474 = Math_fround(HEAPF32[$473>>2]);
          $475 = ((($boxVertices) + (($i3$086$us*12)|0)|0) + 4|0);
          $476 = Math_fround(HEAPF32[$475>>2]);
          $477 = ((($boxVertices) + (($i3$086$us*12)|0)|0) + 8|0);
          $478 = Math_fround(HEAPF32[$477>>2]);
          $479 = HEAP32[$405>>2]|0;
          $480 = ($479>>>0)>(63);
          if (!($480)) {
           $481 = Math_fround($45 * $476);
           $482 = Math_fround($44 * $476);
           $483 = Math_fround($42 * $476);
           $484 = Math_fround($41 * $474);
           $485 = Math_fround($40 * $474);
           $486 = Math_fround($39 * $474);
           $487 = Math_fround($81 * $488);
           $489 = Math_fround($80 * $488);
           $490 = Math_fround($78 * $488);
           $491 = Math_fround($77 * $492);
           $493 = Math_fround($76 * $492);
           $494 = Math_fround($75 * $492);
           $495 = Math_fround($48 * $478);
           $496 = Math_fround($47 * $478);
           $497 = Math_fround($46 * $478);
           $498 = Math_fround($484 + $481);
           $499 = Math_fround($485 + $482);
           $500 = Math_fround($486 + $483);
           $501 = Math_fround($84 * $502);
           $503 = Math_fround($83 * $502);
           $504 = Math_fround($82 * $502);
           $505 = Math_fround($487 + $491);
           $506 = Math_fround($489 + $493);
           $507 = Math_fround($490 + $494);
           $508 = Math_fround($498 + $495);
           $509 = Math_fround($499 + $496);
           $510 = Math_fround($500 + $497);
           $511 = Math_fround($445 * $488);
           $512 = Math_fround($501 + $505);
           $513 = Math_fround($503 + $506);
           $514 = Math_fround($504 + $507);
           $515 = Math_fround($54 + $508);
           $516 = Math_fround($52 + $509);
           $517 = Math_fround($50 + $510);
           $518 = (($479) + 1)|0;
           HEAP32[$405>>2] = $518;
           $519 = (($contactBuffer) + ($479<<6)|0);
           HEAPF32[$519>>2] = $514;
           $520 = ((($contactBuffer) + ($479<<6)|0) + 4|0);
           HEAPF32[$520>>2] = $513;
           $521 = ((($contactBuffer) + ($479<<6)|0) + 8|0);
           HEAPF32[$521>>2] = $512;
           $522 = ((($contactBuffer) + ($479<<6)|0) + 16|0);
           HEAPF32[$522>>2] = $517;
           $523 = ((($contactBuffer) + ($479<<6)|0) + 20|0);
           HEAPF32[$523>>2] = $516;
           $524 = ((($contactBuffer) + ($479<<6)|0) + 24|0);
           HEAPF32[$524>>2] = $515;
           $525 = ((($contactBuffer) + ($479<<6)|0) + 12|0);
           HEAPF32[$525>>2] = $511;
           $526 = ((($contactBuffer) + ($479<<6)|0) + 48|0);
           HEAP32[$526>>2] = -1;
           $527 = ((($contactBuffer) + ($479<<6)|0) + 52|0);
           HEAP32[$527>>2] = $455;
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   $528 = (($i3$086$us) + 1)|0;
   $exitcond105 = ($528|0)==(8);
   if ($exitcond105) {
    $893 = $405;
    break;
   } else {
    $i3$086$us = $528;
   }
  }
 } else {
  $399 = $304 < $397;
  if ($399) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $400 = (($2) + 4|0);
  $401 = (($2) + 8|0);
  $402 = (($contactBuffer) + 4096|0);
  $i3$086 = 0;
  while(1) {
   $546 = ((($boxVertexNormalsInHfShape) + (($i3$086*12)|0)|0) + 4|0);
   $547 = HEAP32[$546>>2]|0;
   $548 = ($547|0)>(0);
   do {
    if (!($548)) {
     $549 = ((($boxVerticesInHfShape) + (($i3$086*12)|0)|0) + 4|0);
     $550 = Math_fround(HEAPF32[$contactDistance>>2]);
     $551 = Math_fround(HEAPF32[$549>>2]);
     $552 = Math_fround($397 - $550);
     $553 = $551 > $552;
     if ($553) {
      $554 = (($boxVerticesInHfShape) + (($i3$086*12)|0)|0);
      $555 = Math_fround(HEAPF32[$554>>2]);
      $556 = ((($boxVerticesInHfShape) + (($i3$086*12)|0)|0) + 8|0);
      $557 = Math_fround(HEAPF32[$556>>2]);
      $558 = Math_fround(HEAPF32[$hfUtil>>2]);
      $559 = Math_fround($555 * $558);
      $560 = Math_fround(HEAPF32[$18>>2]);
      $561 = Math_fround($557 * $560);
      $562 = !($559 >= Math_fround(0.0));
      $563 = !($561 >= Math_fround(0.0));
      $or$cond$i6 = $562 | $563;
      if (!($or$cond$i6)) {
       $564 = HEAP32[$6>>2]|0;
       $565 = (($564) + 24|0);
       $566 = Math_fround(HEAPF32[$565>>2]);
       $567 = Math_fround($566 + Math_fround(1.0));
       $568 = $559 < $567;
       if ($568) {
        $569 = (($564) + 28|0);
        $570 = Math_fround(HEAPF32[$569>>2]);
        $571 = Math_fround($570 + Math_fround(1.0));
        $572 = $561 < $571;
        if ($572) {
         $573 = Math_fround($317 * $555);
         $574 = Math_fround($318 * $557);
         $575 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($564,$573,$574,$fracX,$fracZ)|0);
         $576 = Math_fround(HEAPF32[$fracX>>2]);
         $577 = Math_fround(HEAPF32[$fracZ>>2]);
         $578 = HEAP32[$7>>2]|0;
         $579 = (($578) + 8|0);
         $580 = Math_fround(HEAPF32[$579>>2]);
         $581 = HEAP32[$6>>2]|0;
         $582 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($581,$575,$576,$577)));
         $583 = Math_fround($580 * $582);
         $584 = Math_fround(HEAPF32[$549>>2]);
         $585 = Math_fround($584 - $583);
         $586 = Math_fround(HEAPF32[$contactDistance>>2]);
         $587 = Math_fround(HEAPF32[$314>>2]);
         $588 = !($587 <= Math_fround(0.0));
         $589 = !($585 <= $586);
         $or$cond$i = $588 | $589;
         $590 = !($587 <= $585);
         $or$cond1$i = $or$cond$i | $590;
         if ($or$cond1$i) {
          $591 = $587 > Math_fround(0.0);
          if (!($591)) {
           break;
          }
          $592 = Math_fround(-$586);
          $593 = $585 > $592;
          $594 = $587 > $585;
          $or$cond = $593 & $594;
          if (!($or$cond)) {
           break;
          }
         }
         $595 = (__ZNK5physx2Gu15HeightFieldUtil31getFaceIndexAtShapePointNoTest2Ejff($hfUtil,$575,$576,$577)|0);
         $596 = ($595|0)==(-1);
         if (!($596)) {
          $597 = Math_fround(HEAPF32[$fracX>>2]);
          $598 = Math_fround(HEAPF32[$fracZ>>2]);
          __ZNK5physx2Gu15HeightFieldUtil22getNormalAtShapePoint2Ejff($2,$hfUtil,$575,$597,$598);
          $599 = Math_fround(HEAPF32[$2>>2]);
          $600 = Math_fround(HEAPF32[$400>>2]);
          $601 = Math_fround(HEAPF32[$401>>2]);
          $602 = Math_fround($599 * $599);
          $603 = Math_fround($600 * $600);
          $604 = Math_fround($602 + $603);
          $605 = Math_fround($601 * $601);
          $606 = Math_fround($604 + $605);
          $607 = $606 > Math_fround(0.0);
          if ($607) {
           $608 = (Math_fround(Math_sqrt((Math_fround($606)))));
           $609 = Math_fround(Math_fround(1.0) / $608);
           $610 = Math_fround($599 * $609);
           $611 = Math_fround($600 * $609);
           $612 = Math_fround($601 * $609);
           $628 = $611;$632 = $610;$642 = $612;
          } else {
           $628 = Math_fround(0.0);$632 = Math_fround(0.0);$642 = Math_fround(0.0);
          }
          $613 = (($boxVertices) + (($i3$086*12)|0)|0);
          $614 = Math_fround(HEAPF32[$613>>2]);
          $615 = ((($boxVertices) + (($i3$086*12)|0)|0) + 4|0);
          $616 = Math_fround(HEAPF32[$615>>2]);
          $617 = ((($boxVertices) + (($i3$086*12)|0)|0) + 8|0);
          $618 = Math_fround(HEAPF32[$617>>2]);
          $619 = HEAP32[$402>>2]|0;
          $620 = ($619>>>0)>(63);
          if (!($620)) {
           $621 = Math_fround($45 * $616);
           $622 = Math_fround($44 * $616);
           $623 = Math_fround($42 * $616);
           $624 = Math_fround($41 * $614);
           $625 = Math_fround($40 * $614);
           $626 = Math_fround($39 * $614);
           $627 = Math_fround($81 * $628);
           $629 = Math_fround($80 * $628);
           $630 = Math_fround($78 * $628);
           $631 = Math_fround($77 * $632);
           $633 = Math_fround($76 * $632);
           $634 = Math_fround($75 * $632);
           $635 = Math_fround($48 * $618);
           $636 = Math_fround($47 * $618);
           $637 = Math_fround($46 * $618);
           $638 = Math_fround($624 + $621);
           $639 = Math_fround($625 + $622);
           $640 = Math_fround($626 + $623);
           $641 = Math_fround($84 * $642);
           $643 = Math_fround($83 * $642);
           $644 = Math_fround($82 * $642);
           $645 = Math_fround($627 + $631);
           $646 = Math_fround($629 + $633);
           $647 = Math_fround($630 + $634);
           $648 = Math_fround($638 + $635);
           $649 = Math_fround($639 + $636);
           $650 = Math_fround($640 + $637);
           $651 = Math_fround($585 * $628);
           $652 = Math_fround($641 + $645);
           $653 = Math_fround($643 + $646);
           $654 = Math_fround($644 + $647);
           $655 = Math_fround($54 + $648);
           $656 = Math_fround($52 + $649);
           $657 = Math_fround($50 + $650);
           $658 = (($619) + 1)|0;
           HEAP32[$402>>2] = $658;
           $659 = (($contactBuffer) + ($619<<6)|0);
           HEAPF32[$659>>2] = $654;
           $660 = ((($contactBuffer) + ($619<<6)|0) + 4|0);
           HEAPF32[$660>>2] = $653;
           $661 = ((($contactBuffer) + ($619<<6)|0) + 8|0);
           HEAPF32[$661>>2] = $652;
           $662 = ((($contactBuffer) + ($619<<6)|0) + 16|0);
           HEAPF32[$662>>2] = $657;
           $663 = ((($contactBuffer) + ($619<<6)|0) + 20|0);
           HEAPF32[$663>>2] = $656;
           $664 = ((($contactBuffer) + ($619<<6)|0) + 24|0);
           HEAPF32[$664>>2] = $655;
           $665 = ((($contactBuffer) + ($619<<6)|0) + 12|0);
           HEAPF32[$665>>2] = $651;
           $666 = ((($contactBuffer) + ($619<<6)|0) + 48|0);
           HEAP32[$666>>2] = -1;
           $667 = ((($contactBuffer) + ($619<<6)|0) + 52|0);
           HEAP32[$667>>2] = $595;
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   $668 = (($i3$086) + 1)|0;
   $exitcond100 = ($668|0)==(8);
   if ($exitcond100) {
    $893 = $402;
    break;
   } else {
    $i3$086 = $668;
   }
  }
 }
 $529 = (($n$i) + 4|0);
 $530 = (($n$i) + 8|0);
 $531 = (($n$i) + 12|0);
 $532 = (($n$i) + 16|0);
 $533 = (($n$i) + 20|0);
 $534 = (($n$i) + 24|0);
 $535 = (($n$i) + 28|0);
 $536 = (($n$i) + 32|0);
 $537 = (($n$i) + 36|0);
 $538 = (($n$i) + 40|0);
 $539 = (($n$i) + 44|0);
 $540 = (($n$i) + 48|0);
 $541 = (($n$i) + 52|0);
 $542 = (($n$i) + 56|0);
 $543 = (($n$i) + 60|0);
 $544 = (($n$i) + 64|0);
 $545 = (($n$i) + 68|0);
 $i4$084 = 0;
 while(1) {
  $683 = $i4$084 << 1;
  $684 = (503192 + ($683)|0);
  $685 = HEAP8[$684>>0]|0;
  $686 = $685&255;
  $687 = ((($boxVertexNormalsInHfShape) + (($686*12)|0)|0) + 4|0);
  $688 = Math_fround(HEAPF32[$687>>2]);
  $689 = $683 | 1;
  $690 = (503192 + ($689)|0);
  $691 = HEAP8[$690>>0]|0;
  $692 = $691&255;
  $693 = ((($boxVertexNormalsInHfShape) + (($692*12)|0)|0) + 4|0);
  $694 = Math_fround(HEAPF32[$693>>2]);
  $695 = Math_fround($688 + $694);
  $696 = $695 > Math_fround(0.0);
  do {
   if (!($696)) {
    $697 = (($boxVerticesInHfShape) + (($686*12)|0)|0);
    $698 = (($boxVerticesInHfShape) + (($692*12)|0)|0);
    $699 = Math_fround(HEAPF32[$314>>2]);
    $700 = $699 != Math_fround(0.0);
    $701 = ((($boxVerticesInHfShape) + (($686*12)|0)|0) + 4|0);
    $702 = Math_fround(HEAPF32[$701>>2]);
    if ($700) {
     $703 = $702 > $397;
     if ($703) {
      $704 = ((($boxVerticesInHfShape) + (($692*12)|0)|0) + 4|0);
      $705 = Math_fround(HEAPF32[$704>>2]);
      $706 = $705 > $397;
      if ($706) {
       break;
      }
     }
    } else {
     $707 = $702 < $397;
     if ($707) {
      $708 = ((($boxVerticesInHfShape) + (($692*12)|0)|0) + 4|0);
      $709 = Math_fround(HEAPF32[$708>>2]);
      $710 = $709 < $397;
      if ($710) {
       break;
      }
     }
    }
    $711 = Math_fround(HEAPF32[$698>>2]);
    $712 = Math_fround(HEAPF32[$697>>2]);
    $713 = Math_fround($711 - $712);
    $714 = ((($boxVerticesInHfShape) + (($692*12)|0)|0) + 4|0);
    $715 = Math_fround(HEAPF32[$714>>2]);
    $716 = Math_fround($715 - $702);
    $717 = ((($boxVerticesInHfShape) + (($692*12)|0)|0) + 8|0);
    $718 = Math_fround(HEAPF32[$717>>2]);
    $719 = ((($boxVerticesInHfShape) + (($686*12)|0)|0) + 8|0);
    $720 = Math_fround(HEAPF32[$719>>2]);
    $721 = Math_fround($718 - $720);
    $722 = Math_fround(HEAPF32[$contactDistance>>2]);
    HEAPF32[$n$i>>2] = $713;
    HEAPF32[$529>>2] = $716;
    HEAPF32[$530>>2] = $721;
    HEAP32[$531>>2] = $contactBuffer;
    HEAPF32[$532>>2] = $75;
    HEAPF32[$533>>2] = $76;
    HEAPF32[$534>>2] = $77;
    HEAPF32[$535>>2] = $78;
    HEAPF32[$536>>2] = $80;
    HEAPF32[$537>>2] = $81;
    HEAPF32[$538>>2] = $82;
    HEAPF32[$539>>2] = $83;
    HEAPF32[$540>>2] = $84;
    HEAPF32[$541>>2] = $86;
    HEAPF32[$542>>2] = $88;
    HEAPF32[$543>>2] = $90;
    HEAPF32[$544>>2] = $722;
    HEAP32[$545>>2] = -1;
    __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS_30PxcContactTraceSegmentCallbackELb1ELb1ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$697,$698,$n$i,0);
   }
  } while(0);
  $723 = (($i4$084) + 1)|0;
  $exitcond = ($723|0)==(12);
  if ($exitcond) {
   break;
  } else {
   $i4$084 = $723;
  }
 }
 $669 = ($minRow$0>>>0)>($maxRow$0>>>0);
 if (!($669)) {
  $670 = ($minColumn$0>>>0)>($maxColumn$0>>>0);
  $671 = (($5) + 20|0);
  $672 = (($5) + 36|0);
  $673 = (($hfVertexInBoxShape) + 4|0);
  $674 = (($hfVertexInBoxShape) + 8|0);
  $675 = (($nrm) + 4|0);
  $676 = (($nrm) + 8|0);
  $677 = (($3) + 4|0);
  $678 = (($3) + 8|0);
  $679 = (($n$i) + 4|0);
  $680 = (($n$i) + 8|0);
  $681 = (($normalInHfShape) + 4|0);
  $682 = (($normalInHfShape) + 8|0);
  $row$080 = $minRow$0;
  while(1) {
   if (!($670)) {
    $724 = (Math_fround(($row$080>>>0)));
    $column$073 = $minColumn$0;
    while(1) {
     $725 = HEAP32[$671>>2]|0;
     $726 = Math_imul($725, $row$080)|0;
     $727 = (($726) + ($column$073))|0;
     $728 = HEAP32[$6>>2]|0;
     $729 = (($728) + 36|0);
     $730 = HEAP32[$729>>2]|0;
     $731 = ((($730) + ($727<<2)|0) + 3|0);
     $732 = HEAP8[$731>>0]|0;
     $733 = ($732<<24>>24)<(0);
     L87: do {
      if ($733) {
       $734 = Math_fround(HEAPF32[$12>>2]);
       $735 = Math_fround($724 * $734);
       $736 = Math_fround(HEAPF32[$8>>2]);
       $737 = HEAP32[$672>>2]|0;
       $738 = (($737) + ($727<<2)|0);
       $739 = HEAP16[$738>>1]|0;
       $740 = (Math_fround(($739<<16>>16)));
       $741 = Math_fround($736 * $740);
       $742 = Math_fround(HEAPF32[$15>>2]);
       $743 = (Math_fround(($column$073>>>0)));
       $744 = Math_fround($743 * $742);
       $745 = Math_fround($735 - $194);
       $746 = Math_fround($741 - $168);
       $747 = Math_fround($744 - $195);
       $748 = Math_fround($175 * $745);
       $749 = Math_fround($122 * $746);
       $750 = Math_fround($748 + $749);
       $751 = Math_fround($176 * $747);
       $752 = Math_fround($751 + $750);
       $753 = Math_fround($131 * $745);
       $754 = Math_fround($181 * $746);
       $755 = Math_fround($753 + $754);
       $756 = Math_fround($132 * $747);
       $757 = Math_fround($756 + $755);
       $758 = Math_fround($186 * $745);
       $759 = Math_fround($141 * $746);
       $760 = Math_fround($758 + $759);
       $761 = Math_fround($187 * $747);
       $762 = Math_fround($761 + $760);
       HEAPF32[$hfVertexInBoxShape>>2] = $752;
       HEAPF32[$673>>2] = $757;
       HEAPF32[$674>>2] = $762;
       $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($752)))));
       $763 = Math_fround(HEAPF32[$196>>2]);
       $764 = Math_fround($fabsf$i$i3 - $763);
       $765 = Math_fround(HEAPF32[$contactDistance>>2]);
       $766 = Math_fround($764 - $765);
       $767 = $766 < Math_fround(0.0);
       if ($767) {
        $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($757)))));
        $768 = Math_fround(HEAPF32[$198>>2]);
        $769 = Math_fround($fabsf$i$i2 - $768);
        $770 = Math_fround($769 - $765);
        $771 = $770 < Math_fround(0.0);
        if ($771) {
         $fabsf$i$i = (Math_fround(Math_abs((Math_fround($762)))));
         $772 = Math_fround(HEAPF32[$200>>2]);
         $773 = Math_fround($fabsf$i$i - $772);
         $774 = Math_fround($773 - $765);
         $775 = $774 < Math_fround(0.0);
         if ($775) {
          __ZNK5physx2Gu15HeightFieldUtil15getVertexNormalEjjj($nrm,$hfUtil,$727,$row$080,$column$073);
          $776 = Math_fround(HEAPF32[$nrm>>2]);
          if ($316) {
           $777 = Math_fround(HEAPF32[$675>>2]);
           $778 = Math_fround(HEAPF32[$676>>2]);
           $785 = $776;$787 = $777;$790 = $778;
          } else {
           $779 = Math_fround(-$776);
           $780 = Math_fround(HEAPF32[$675>>2]);
           $781 = Math_fround(-$780);
           $782 = Math_fround(HEAPF32[$676>>2]);
           $783 = Math_fround(-$782);
           $785 = $779;$787 = $781;$790 = $783;
          }
          $784 = Math_fround($785 * $785);
          $786 = Math_fround($787 * $787);
          $788 = Math_fround($786 + $784);
          $789 = Math_fround($790 * $790);
          $791 = Math_fround($789 + $788);
          $792 = $791 > Math_fround(0.0);
          if ($792) {
           $793 = (Math_fround(Math_sqrt((Math_fround($791)))));
           $794 = Math_fround(Math_fround(1.0) / $793);
           $795 = Math_fround($785 * $794);
           $796 = Math_fround($787 * $794);
           $797 = Math_fround($790 * $794);
           $799 = $795;$801 = $796;$804 = $797;
          } else {
           $799 = Math_fround(0.0);$801 = Math_fround(0.0);$804 = Math_fround(0.0);
          }
          $798 = Math_fround($175 * $799);
          $800 = Math_fround($122 * $801);
          $802 = Math_fround($800 + $798);
          $803 = Math_fround($176 * $804);
          $805 = Math_fround($803 + $802);
          $806 = Math_fround($131 * $799);
          $807 = Math_fround($181 * $801);
          $808 = Math_fround($807 + $806);
          $809 = Math_fround($132 * $804);
          $810 = Math_fround($809 + $808);
          $811 = Math_fround($186 * $799);
          $812 = Math_fround($141 * $801);
          $813 = Math_fround($812 + $811);
          $814 = Math_fround($187 * $804);
          $815 = Math_fround($814 + $813);
          $816 = Math_fround(-$805);
          $817 = Math_fround(-$810);
          $818 = Math_fround(-$815);
          HEAPF32[$3>>2] = $816;
          HEAPF32[$677>>2] = $817;
          HEAPF32[$678>>2] = $818;
          $944 = Math_fround(0.0);$945 = Math_fround(0.0);$946 = Math_fround(0.0);$distance1$014$i = Math_fround(-3.40282346638528859812E+38);$distance2$013$i = Math_fround(-3.40282346638528859812E+38);$poly$010$i = 0;$poly1$012$i = -1;$poly2$011$i = -2;
          while(1) {
           $819 = (($poly$010$i>>>0) % 3)&-1;
           $820 = ($poly$010$i>>>0)>(2);
           $821 = $820 ? Math_fround(-1.0) : Math_fround(1.0);
           HEAPF32[$n$i>>2] = Math_fround(0.0);
           HEAPF32[$679>>2] = Math_fround(0.0);
           HEAPF32[$680>>2] = Math_fround(0.0);
           $822 = (($n$i) + ($819<<2)|0);
           HEAPF32[$822>>2] = $821;
           $823 = (($3) + ($819<<2)|0);
           $824 = Math_fround(HEAPF32[$823>>2]);
           $825 = Math_fround($821 * $824);
           $826 = (($hfVertexInBoxShape) + ($819<<2)|0);
           $827 = Math_fround(HEAPF32[$826>>2]);
           $828 = (($196) + ($819<<2)|0);
           $829 = Math_fround(HEAPF32[$828>>2]);
           $830 = Math_fround($821 * $829);
           $831 = Math_fround($827 - $830);
           $832 = Math_fround($821 * $831);
           $833 = !($832 >= Math_fround(0.0));
           if (!($833)) {
            break L87;
           }
           $834 = $825 > Math_fround(0.0);
           do {
            if ($834) {
             $835 = $832 > $distance1$014$i;
             if ($835) {
              $836 = Math_fround(HEAPF32[$n$i>>2]);
              $837 = Math_fround(HEAPF32[$679>>2]);
              $838 = Math_fround(HEAPF32[$680>>2]);
              $947 = $838;$948 = $837;$949 = $836;$distance1$1$i = $832;$poly1$1$i = $poly$010$i;
             } else {
              $947 = $946;$948 = $945;$949 = $944;$distance1$1$i = $distance1$014$i;$poly1$1$i = $poly1$012$i;
             }
             $839 = Math_fround($832 / $825);
             $840 = $839 > $distance2$013$i;
             if (!($840)) {
              $844 = $947;$845 = $948;$846 = $949;$distance1$2$i = $distance1$1$i;$distance2$1$i = $distance2$013$i;$poly1$2$i = $poly1$1$i;$poly2$1$i = $poly2$011$i;
              break;
             }
             $844 = $947;$845 = $948;$846 = $949;$distance1$2$i = $distance1$1$i;$distance2$1$i = $839;$poly1$2$i = $poly1$1$i;$poly2$1$i = $poly$010$i;
            } else {
             $844 = $946;$845 = $945;$846 = $944;$distance1$2$i = $distance1$014$i;$distance2$1$i = $distance2$013$i;$poly1$2$i = $poly1$012$i;$poly2$1$i = $poly2$011$i;
            }
           } while(0);
           $841 = (($poly$010$i) + 1)|0;
           $842 = ($841>>>0)<(6);
           if ($842) {
            $944 = $846;$945 = $845;$946 = $844;$distance1$014$i = $distance1$2$i;$distance2$013$i = $distance2$1$i;$poly$010$i = $841;$poly1$012$i = $poly1$2$i;$poly2$011$i = $poly2$1$i;
           } else {
            break;
           }
          }
          $843 = ($poly1$2$i|0)==($poly2$1$i|0);
          $$ = $843 ? $844 : $818;
          $$115 = $843 ? $845 : $817;
          $$116 = $843 ? $846 : $816;
          $distance1$2$i$distance2$1$i = $843 ? $distance1$2$i : $distance2$1$i;
          $847 = Math_fround(-$$116);
          $848 = Math_fround(-$$115);
          $849 = Math_fround(-$$);
          $850 = Math_fround($175 * $847);
          $851 = Math_fround($122 * $847);
          $852 = Math_fround($176 * $847);
          $853 = Math_fround($131 * $848);
          $854 = Math_fround($181 * $848);
          $855 = Math_fround($132 * $848);
          $856 = Math_fround($853 + $850);
          $857 = Math_fround($854 + $851);
          $858 = Math_fround($855 + $852);
          $859 = Math_fround($186 * $849);
          $860 = Math_fround($141 * $849);
          $861 = Math_fround($187 * $849);
          $862 = Math_fround($859 + $856);
          $863 = Math_fround($860 + $857);
          $864 = Math_fround($861 + $858);
          HEAPF32[$normalInHfShape>>2] = $862;
          HEAPF32[$681>>2] = $863;
          HEAPF32[$682>>2] = $864;
          (__ZNK5physx2Gu15HeightFieldUtil30clipShapeNormalToVertexVoronoiERNS_6PxVec3Ejjj($hfUtil,$normalInHfShape,$727,$row$080,$column$073)|0);
          $865 = Math_fround(HEAPF32[$normalInHfShape>>2]);
          $866 = Math_fround($799 * $865);
          $867 = Math_fround(HEAPF32[$681>>2]);
          $868 = Math_fround($801 * $867);
          $869 = Math_fround($866 + $868);
          $870 = Math_fround(HEAPF32[$682>>2]);
          $871 = Math_fround($804 * $870);
          $872 = Math_fround($869 + $871);
          $873 = $872 < Math_fround(1.1920928955078125E-7);
          if (!($873)) {
           $874 = Math_fround($865 * $865);
           $875 = Math_fround($867 * $867);
           $876 = Math_fround($874 + $875);
           $877 = Math_fround($870 * $870);
           $878 = Math_fround($876 + $877);
           $879 = $878 > Math_fround(0.0);
           if ($879) {
            $880 = (Math_fround(Math_sqrt((Math_fround($878)))));
            $881 = Math_fround(Math_fround(1.0) / $880);
            $882 = Math_fround($865 * $881);
            $883 = Math_fround($867 * $881);
            $884 = Math_fround($870 * $881);
            $885 = $882;$886 = $883;$887 = $884;
           } else {
            $885 = Math_fround(0.0);$886 = Math_fround(0.0);$887 = Math_fround(0.0);
           }
           HEAPF32[$normalInHfShape>>2] = $885;
           HEAPF32[$681>>2] = $886;
           HEAPF32[$682>>2] = $887;
           $888 = (__ZNK5physx2Gu15HeightFieldUtil18getVertexFaceIndexEjjj($hfUtil,$727,$row$080,$column$073)|0);
           $889 = Math_fround(HEAPF32[$normalInHfShape>>2]);
           $890 = Math_fround(HEAPF32[$681>>2]);
           $891 = Math_fround(HEAPF32[$682>>2]);
           $892 = HEAP32[$893>>2]|0;
           $894 = ($892>>>0)>(63);
           if (!($894)) {
            $895 = Math_fround($81 * $741);
            $896 = Math_fround($80 * $741);
            $897 = Math_fround($78 * $741);
            $898 = Math_fround($77 * $735);
            $899 = Math_fround($76 * $735);
            $900 = Math_fround($75 * $735);
            $901 = Math_fround($81 * $890);
            $902 = Math_fround($80 * $890);
            $903 = Math_fround($78 * $890);
            $904 = Math_fround($77 * $889);
            $905 = Math_fround($76 * $889);
            $906 = Math_fround($75 * $889);
            $907 = Math_fround($84 * $744);
            $908 = Math_fround($83 * $744);
            $909 = Math_fround($82 * $744);
            $910 = Math_fround($898 + $895);
            $911 = Math_fround($899 + $896);
            $912 = Math_fround($900 + $897);
            $913 = Math_fround($84 * $891);
            $914 = Math_fround($83 * $891);
            $915 = Math_fround($82 * $891);
            $916 = Math_fround($904 + $901);
            $917 = Math_fround($905 + $902);
            $918 = Math_fround($906 + $903);
            $919 = Math_fround($907 + $910);
            $920 = Math_fround($908 + $911);
            $921 = Math_fround($909 + $912);
            $922 = Math_fround($916 + $913);
            $923 = Math_fround($917 + $914);
            $924 = Math_fround($918 + $915);
            $925 = Math_fround($90 + $919);
            $926 = Math_fround($88 + $920);
            $927 = Math_fround($86 + $921);
            $928 = (($892) + 1)|0;
            HEAP32[$893>>2] = $928;
            $929 = (($contactBuffer) + ($892<<6)|0);
            HEAPF32[$929>>2] = $924;
            $930 = ((($contactBuffer) + ($892<<6)|0) + 4|0);
            HEAPF32[$930>>2] = $923;
            $931 = ((($contactBuffer) + ($892<<6)|0) + 8|0);
            HEAPF32[$931>>2] = $922;
            $932 = ((($contactBuffer) + ($892<<6)|0) + 16|0);
            HEAPF32[$932>>2] = $927;
            $933 = ((($contactBuffer) + ($892<<6)|0) + 20|0);
            HEAPF32[$933>>2] = $926;
            $934 = ((($contactBuffer) + ($892<<6)|0) + 24|0);
            HEAPF32[$934>>2] = $925;
            $935 = ((($contactBuffer) + ($892<<6)|0) + 12|0);
            HEAPF32[$935>>2] = $distance1$2$i$distance2$1$i;
            $936 = ((($contactBuffer) + ($892<<6)|0) + 48|0);
            HEAP32[$936>>2] = -1;
            $937 = ((($contactBuffer) + ($892<<6)|0) + 52|0);
            HEAP32[$937>>2] = $888;
           }
          }
         }
        }
       }
      }
     } while(0);
     $938 = (($column$073) + 1)|0;
     $939 = ($938>>>0)>($maxColumn$0>>>0);
     if ($939) {
      break;
     } else {
      $column$073 = $938;
     }
    }
   }
   $940 = (($row$080) + 1)|0;
   $941 = ($940>>>0)>($maxRow$0>>>0);
   if ($941) {
    break;
   } else {
    $row$080 = $940;
   }
  }
 }
 $942 = HEAP32[$893>>2]|0;
 $943 = ($942|0)!=(0);
 $$0 = $943;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Gu15HeightFieldUtil22getNormalAtShapePoint2Ejff($agg$result,$this,$vertexIndex,$fracX,$fracZ) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $vertexIndex = $vertexIndex|0;
 $fracX = Math_fround($fracX);
 $fracZ = Math_fround($fracZ);
 var $$pn$i = Math_fround(0), $$pn$in$i = 0, $$pn11$i = Math_fround(0), $$pn11$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0;
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$this>>2]);
 $3 = (($this) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8) + ($vertexIndex<<2)|0) + 2|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)<(0);
 do {
  if ($11) {
   $12 = (($8) + ($vertexIndex<<2)|0);
   $13 = HEAP16[$12>>1]|0;
   $14 = $13 << 16 >> 16;
   $15 = (($1) + 20|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($vertexIndex))|0;
   $18 = (($17) + 1)|0;
   $19 = (($8) + ($18<<2)|0);
   $20 = HEAP16[$19>>1]|0;
   $21 = $20 << 16 >> 16;
   $22 = !($fracZ >= $fracX);
   if ($22) {
    $29 = (($8) + ($17<<2)|0);
    $30 = HEAP16[$29>>1]|0;
    $31 = $30 << 16 >> 16;
    $32 = (($14) - ($31))|0;
    $33 = (($31) - ($21))|0;
    $$pn$in$i = $33;$$pn11$in$i = $32;
    break;
   } else {
    $23 = (($vertexIndex) + 1)|0;
    $24 = (($8) + ($23<<2)|0);
    $25 = HEAP16[$24>>1]|0;
    $26 = $25 << 16 >> 16;
    $27 = (($26) - ($21))|0;
    $28 = (($14) - ($26))|0;
    $$pn$in$i = $28;$$pn11$in$i = $27;
    break;
   }
  } else {
   $34 = (($vertexIndex) + 1)|0;
   $35 = (($8) + ($34<<2)|0);
   $36 = HEAP16[$35>>1]|0;
   $37 = $36 << 16 >> 16;
   $38 = (($1) + 20|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + ($vertexIndex))|0;
   $41 = (($8) + ($40<<2)|0);
   $42 = HEAP16[$41>>1]|0;
   $43 = $42 << 16 >> 16;
   $44 = Math_fround($fracX + $fracZ);
   $45 = !($44 <= Math_fround(1.0));
   if ($45) {
    $51 = (($40) + 1)|0;
    $52 = (($8) + ($51<<2)|0);
    $53 = HEAP16[$52>>1]|0;
    $54 = $53 << 16 >> 16;
    $55 = (($37) - ($54))|0;
    $56 = (($43) - ($54))|0;
    $$pn$in$i = $56;$$pn11$in$i = $55;
    break;
   } else {
    $46 = (($8) + ($vertexIndex<<2)|0);
    $47 = HEAP16[$46>>1]|0;
    $48 = $47 << 16 >> 16;
    $49 = (($48) - ($43))|0;
    $50 = (($48) - ($37))|0;
    $$pn$in$i = $50;$$pn11$in$i = $49;
    break;
   }
  }
 } while(0);
 $$pn11$i = (Math_fround(($$pn11$in$i|0)));
 $$pn$i = (Math_fround(($$pn$in$i|0)));
 $57 = Math_fround($2 * $$pn11$i);
 $58 = Math_fround($6 * $$pn$i);
 $59 = (($1) + 40|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = !($60 <= Math_fround(0.0));
 if ($61) {
  $64 = Math_fround(-$57);
  $65 = Math_fround(-$4);
  $66 = Math_fround(-$58);
  HEAPF32[$agg$result>>2] = $64;
  $67 = (($agg$result) + 4|0);
  HEAPF32[$67>>2] = $65;
  $68 = (($agg$result) + 8|0);
  HEAPF32[$68>>2] = $66;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$agg$result>>2] = $57;
  $62 = (($agg$result) + 4|0);
  HEAPF32[$62>>2] = $4;
  $63 = (($agg$result) + 8|0);
  HEAPF32[$63>>2] = $58;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS_30PxcContactTraceSegmentCallbackELb1ELb1ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($this,$aP0,$aP1,$aCallback,$overlapObjectExtent) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $aCallback = $aCallback|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 var $$ = 0, $$29 = 0, $$old = 0, $$sink = Math_fround(0), $$sink1 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0;
 var $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0;
 var $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $crossedEdge = 0, $du$0 = Math_fround(0), $dv$0 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i2 = Math_fround(0);
 var $fabsf$i$i3 = Math_fround(0), $fabsf$i$i6 = Math_fround(0), $fabsf$i$i7 = Math_fround(0), $h = 0, $hLinePrev$0 = Math_fround(0), $last_tu$0 = Math_fround(0), $last_tu$1 = Math_fround(0), $last_tv$0 = Math_fround(0), $last_tv$1 = Math_fround(0), $localBounds = 0, $or$cond = 0, $or$cond31 = 0, $or$cond34 = 0, $or$cond36 = 0, $p00 = 0, $p00$p01 = 0, $p01 = 0, $p01$p11 = 0, $p10 = 0, $p10$p00 = 0;
 var $p11 = 0, $p11$p10 = 0, $rayDir = 0, $storemerge = Math_fround(0), $storemerge37 = Math_fround(0), $storemerge38 = Math_fround(0), $tfar = 0, $tnear = 0, $triNormals = 0, $tu$0 = Math_fround(0), $tu$1 = Math_fround(0), $tv$0 = Math_fround(0), $tv$1 = Math_fround(0), $ui$0 = 0, $ui$1 = 0, $uif$0 = Math_fround(0), $uif$1 = Math_fround(0), $vi$0 = 0, $vi$1 = 0, $vif$0 = Math_fround(0);
 var $vif$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $localBounds = sp + 144|0;
 $rayDir = sp + 128|0;
 $tnear = sp + 124|0;
 $tfar = sp + 120|0;
 $h = sp + 104|0;
 $p00 = sp + 88|0;
 $p01 = sp + 76|0;
 $p10 = sp + 52|0;
 $p11 = sp + 40|0;
 $triNormals = sp + 16|0;
 $crossedEdge = sp;
 $0 = sp + 64|0;
 __ZNK5physx2Gu15HeightFieldUtil18computeLocalBoundsERNS_9PxBounds3E($this,$localBounds);
 $1 = Math_fround(HEAPF32[$aP1>>2]);
 $2 = Math_fround(HEAPF32[$aP0>>2]);
 $3 = Math_fround($1 - $2);
 $4 = (($aP1) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($aP0) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($aP1) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($aP0) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 HEAPF32[$rayDir>>2] = $3;
 $14 = (($rayDir) + 4|0);
 HEAPF32[$14>>2] = $8;
 $15 = (($rayDir) + 8|0);
 HEAPF32[$15>>2] = $13;
 $16 = (($localBounds) + 12|0);
 $17 = (__ZN5physx2Gu17intersectRayAABB2ERKNS_6PxVec3ES3_S3_S3_fRfS4_($localBounds,$16,$aP0,$rayDir,Math_fround(1.0),$tnear,$tfar)|0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($this) + 12|0);
 $19 = Math_fround(HEAPF32[$tnear>>2]);
 $20 = Math_fround(HEAPF32[$rayDir>>2]);
 $21 = Math_fround($19 * $20);
 $22 = Math_fround(HEAPF32[$14>>2]);
 $23 = Math_fround($19 * $22);
 $24 = Math_fround(HEAPF32[$15>>2]);
 $25 = Math_fround($19 * $24);
 $26 = Math_fround(HEAPF32[$aP0>>2]);
 $27 = Math_fround($21 + $26);
 $28 = Math_fround(HEAPF32[$6>>2]);
 $29 = Math_fround($23 + $28);
 $30 = Math_fround(HEAPF32[$11>>2]);
 $31 = Math_fround($25 + $30);
 $32 = Math_fround(HEAPF32[$tfar>>2]);
 $33 = Math_fround($20 * $32);
 $34 = Math_fround($22 * $32);
 $35 = Math_fround($24 * $32);
 $36 = Math_fround($26 + $33);
 $37 = Math_fround($28 + $34);
 $38 = Math_fround($30 + $35);
 $39 = (($this) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 12|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($40) + 16|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($40) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = HEAP32[$18>>2]|0;
 $48 = (($47) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($47) + 16|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = Math_fround(HEAPF32[$this>>2]);
 $53 = (($this) + 8|0);
 $54 = (($51) + -1)|0;
 $55 = (Math_fround(($54|0)));
 $56 = Math_fround($55 * Math_fround(0.999999880790710449218));
 $57 = (($49) + -1)|0;
 $58 = (Math_fround(($57|0)));
 $59 = Math_fround($58 * Math_fround(0.999999880790710449218));
 $60 = Math_fround($27 * $52);
 $61 = $60 > Math_fround(1.00000001168609742308E-7);
 $62 = $61 ? $60 : Math_fround(1.00000001168609742308E-7);
 $63 = Math_fround($56 + Math_fround(0.0));
 $64 = $62 < $63;
 $65 = $64 ? $62 : $63;
 $66 = Math_fround(HEAPF32[$53>>2]);
 $67 = Math_fround($31 * $66);
 $68 = $67 > Math_fround(1.00000001168609742308E-7);
 $69 = $68 ? $67 : Math_fround(1.00000001168609742308E-7);
 $70 = Math_fround($59 + Math_fround(0.0));
 $71 = $69 < $70;
 $72 = $71 ? $69 : $70;
 $73 = Math_fround($36 * $52);
 $74 = $73 > Math_fround(1.00000001168609742308E-7);
 $75 = $74 ? $73 : Math_fround(1.00000001168609742308E-7);
 $76 = $75 < $63;
 $77 = $76 ? $75 : $63;
 $78 = Math_fround($38 * $66);
 $79 = $78 > Math_fround(1.00000001168609742308E-7);
 $80 = $79 ? $78 : Math_fround(1.00000001168609742308E-7);
 $81 = $80 < $70;
 $82 = $81 ? $80 : $70;
 $83 = Math_fround($77 - $65);
 $84 = Math_fround($82 - $72);
 $85 = Math_fround($37 - $29);
 $86 = $83 >= Math_fround(0.0);
 $87 = $86 ? Math_fround(1.0) : Math_fround(-1.0);
 $88 = $84 >= Math_fround(0.0);
 $89 = $88 ? Math_fround(1.0) : Math_fround(-1.0);
 $90 = (~~(($87)));
 $91 = (~~(($89)));
 $fabsf$i$i7 = (Math_fround(Math_abs((Math_fround($83)))));
 $92 = $fabsf$i$i7 < Math_fround(1.00000001335143196002E-10);
 if ($92) {
  $93 = Math_fround($87 * Math_fround(1.00000001335143196002E-10));
  $du$0 = $93;
 } else {
  $du$0 = $83;
 }
 $fabsf$i$i6 = (Math_fround(Math_abs((Math_fround($84)))));
 $94 = $fabsf$i$i6 < Math_fround(1.00000001335143196002E-10);
 if ($94) {
  $95 = Math_fround($89 * Math_fround(1.00000001335143196002E-10));
  $dv$0 = $95;
 } else {
  $dv$0 = $84;
 }
 $96 = $du$0 > Math_fround(0.0);
 if ($96) {
  $97 = (Math_fround(Math_floor((Math_fround($65)))));
  $$sink = $97;
 } else {
  $98 = (Math_fround(Math_ceil((Math_fround($65)))));
  $$sink = $98;
 }
 $99 = (~~(($$sink)));
 $100 = $dv$0 > Math_fround(0.0);
 if ($100) {
  $101 = (Math_fround(Math_floor((Math_fround($72)))));
  $$sink1 = $101;
 } else {
  $102 = (Math_fround(Math_ceil((Math_fround($72)))));
  $$sink1 = $102;
 }
 $103 = (~~(($$sink1)));
 if ($96) {
  $104 = (Math_fround(Math_ceil((Math_fround($65)))));
  $105 = $104 == $65;
  if ($105) {
   $106 = Math_fround($104 + Math_fround(1.0));
   $117 = $106;
  } else {
   $117 = $104;
  }
 } else {
  $107 = (Math_fround(Math_floor((Math_fround($65)))));
  $108 = $107 == $65;
  if ($108) {
   $109 = Math_fround($107 + Math_fround(-1.0));
   $117 = $109;
  } else {
   $117 = $107;
  }
 }
 if ($100) {
  $110 = (Math_fround(Math_ceil((Math_fround($72)))));
  $111 = $110 == $72;
  if ($111) {
   $112 = Math_fround($110 + Math_fround(1.0));
   $120 = $112;
  } else {
   $120 = $110;
  }
 } else {
  $113 = (Math_fround(Math_floor((Math_fround($72)))));
  $114 = $113 == $72;
  if ($114) {
   $115 = Math_fround($113 + Math_fround(-1.0));
   $120 = $115;
  } else {
   $120 = $113;
  }
 }
 $116 = Math_fround($117 - $65);
 $118 = Math_fround($116 / $du$0);
 $119 = Math_fround($120 - $72);
 $121 = Math_fround($119 / $dv$0);
 $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($du$0)))));
 $122 = Math_fround(Math_fround(1.0) / $fabsf$i$i3);
 $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($dv$0)))));
 $123 = Math_fround(Math_fround(1.0) / $fabsf$i$i2);
 $124 = (Math_fround(($99|0)));
 $125 = (Math_fround(($103|0)));
 $126 = (1 - ($90))|0;
 $127 = (1 - ($91))|0;
 $128 = (($127|0) / 2)&-1;
 $129 = Math_fround($85 * Math_fround(0.0));
 $130 = Math_fround($29 + $129);
 $131 = (Math_fround(($49|0)));
 $132 = (Math_fround(($51|0)));
 $133 = (($47) + 36|0);
 $134 = (($h) + 4|0);
 $135 = (($h) + 8|0);
 $136 = (($h) + 12|0);
 $137 = (($128) + ($126))|0;
 $138 = (($h) + ($137<<2)|0);
 $139 = (($126) + 1)|0;
 $140 = (($139) - ($128))|0;
 $141 = (($h) + ($140<<2)|0);
 $142 = (2 - ($126))|0;
 $143 = (($142) + ($128))|0;
 $144 = (($h) + ($143<<2)|0);
 $145 = (3 - ($126))|0;
 $146 = (($145) - ($128))|0;
 $147 = (($h) + ($146<<2)|0);
 $148 = (($p00) + 4|0);
 $149 = (($p00) + 8|0);
 $150 = (($p01) + 4|0);
 $151 = (($p01) + 8|0);
 $152 = (($p10) + 4|0);
 $153 = (($p10) + 8|0);
 $154 = (($p11) + 4|0);
 $155 = (($p11) + 8|0);
 $156 = (($triNormals) + 4|0);
 $157 = (($triNormals) + 8|0);
 $158 = (($triNormals) + 12|0);
 $159 = (($triNormals) + 16|0);
 $160 = (($triNormals) + 20|0);
 $161 = Math_fround($87 * Math_fround(0.5));
 $162 = Math_fround($89 * Math_fround(0.5));
 $163 = Math_fround($44 * $89);
 $164 = (($crossedEdge) + 4|0);
 $165 = (($crossedEdge) + 8|0);
 $166 = (($0) + 4|0);
 $167 = (($0) + 8|0);
 $168 = Math_fround($42 * $87);
 $hLinePrev$0 = $130;$last_tu$0 = Math_fround(0.0);$last_tv$0 = Math_fround(0.0);$tu$0 = $118;$tv$0 = $121;$ui$0 = $99;$uif$0 = $124;$vi$0 = $103;$vif$0 = $125;
 while(1) {
  $169 = $tu$0 < $tv$0;
  $170 = $169 ? $tu$0 : $tv$0;
  $171 = Math_fround($85 * $170);
  $172 = Math_fround($29 + $171);
  $173 = Math_imul($ui$0, $49)|0;
  $174 = (($173) + ($vi$0))|0;
  $175 = (($ui$0) + ($90))|0;
  $176 = Math_imul($175, $49)|0;
  $177 = (($176) + ($vi$0))|0;
  $178 = HEAP32[$133>>2]|0;
  $179 = (($178) + ($174<<2)|0);
  $180 = HEAP16[$179>>1]|0;
  $181 = (Math_fround(($180<<16>>16)));
  $182 = Math_fround($46 * $181);
  HEAPF32[$h>>2] = $182;
  $183 = (($174) + ($91))|0;
  $184 = (($178) + ($183<<2)|0);
  $185 = HEAP16[$184>>1]|0;
  $186 = (Math_fround(($185<<16>>16)));
  $187 = Math_fround($46 * $186);
  HEAPF32[$134>>2] = $187;
  $188 = (($178) + ($177<<2)|0);
  $189 = HEAP16[$188>>1]|0;
  $190 = (Math_fround(($189<<16>>16)));
  $191 = Math_fround($46 * $190);
  HEAPF32[$135>>2] = $191;
  $192 = (($177) + ($91))|0;
  $193 = (($178) + ($192<<2)|0);
  $194 = HEAP16[$193>>1]|0;
  $195 = (Math_fround(($194<<16>>16)));
  $196 = Math_fround($46 * $195);
  HEAPF32[$136>>2] = $196;
  $197 = $182 < $187;
  $198 = $197 ? $182 : $187;
  $199 = $191 < $196;
  $200 = $199 ? $191 : $196;
  $201 = $182 > $187;
  $202 = $201 ? $182 : $187;
  $203 = $191 > $196;
  $204 = $203 ? $191 : $196;
  $205 = $202 > $204;
  $206 = $205 ? $202 : $204;
  $207 = $hLinePrev$0 < $172;
  $208 = $207 ? $hLinePrev$0 : $172;
  $209 = $hLinePrev$0 > $172;
  $210 = $209 ? $hLinePrev$0 : $172;
  $211 = Math_fround($208 + Math_fround(-9.99999974737875163555E-5));
  $212 = $211 > $206;
  if ($212) {
   $$old = $210 < $206;
   if ($$old) {
    label = 26;
   }
  } else {
   $213 = $198 < $200;
   $214 = $213 ? $198 : $200;
   $215 = Math_fround($210 + Math_fround(9.99999974737875163555E-5));
   $216 = !($215 < $214);
   $217 = $210 < $206;
   $or$cond = $216 | $217;
   if ($or$cond) {
    label = 26;
   }
  }
  if ((label|0) == 26) {
   label = 0;
   $218 = Math_fround(HEAPF32[$138>>2]);
   $219 = Math_fround(HEAPF32[$141>>2]);
   $220 = Math_fround(HEAPF32[$144>>2]);
   $221 = Math_fround(HEAPF32[$147>>2]);
   $222 = Math_fround($87 + $uif$0);
   $223 = $uif$0 < $222;
   $224 = $223 ? $uif$0 : $222;
   $225 = $uif$0 > $222;
   $226 = $225 ? $uif$0 : $222;
   $227 = Math_fround($89 + $vif$0);
   $228 = $vif$0 < $227;
   $229 = $228 ? $vif$0 : $227;
   $230 = $vif$0 > $227;
   $231 = $230 ? $vif$0 : $227;
   HEAPF32[$p00>>2] = $224;
   HEAPF32[$148>>2] = $218;
   HEAPF32[$149>>2] = $229;
   HEAPF32[$p01>>2] = $224;
   HEAPF32[$150>>2] = $219;
   HEAPF32[$151>>2] = $231;
   HEAPF32[$p10>>2] = $226;
   HEAPF32[$152>>2] = $220;
   HEAPF32[$153>>2] = $229;
   HEAPF32[$p11>>2] = $226;
   HEAPF32[$154>>2] = $221;
   HEAPF32[$155>>2] = $231;
   $232 = ($175|0)<($ui$0|0);
   $233 = $232 ? $175 : $ui$0;
   $234 = (($vi$0) + ($91))|0;
   $235 = ($234|0)<($vi$0|0);
   $236 = $235 ? $234 : $vi$0;
   $237 = Math_imul($233, $49)|0;
   $238 = (($237) + ($236))|0;
   $239 = ((($178) + ($238<<2)|0) + 2|0);
   $240 = HEAP8[$239>>0]|0;
   $241 = ($240<<24>>24)<(0);
   $p11$p10 = $241 ? $p11 : $p10;
   $p10$p00 = $241 ? $p10 : $p00;
   $p01$p11 = $241 ? $p01 : $p11;
   $p00$p01 = $241 ? $p00 : $p01;
   $242 = Math_fround(HEAPF32[$p00$p01>>2]);
   $243 = Math_fround($42 * $242);
   $244 = (($p00$p01) + 4|0);
   $245 = Math_fround(HEAPF32[$244>>2]);
   $246 = (($p00$p01) + 8|0);
   $247 = Math_fround(HEAPF32[$246>>2]);
   $248 = Math_fround($44 * $247);
   $249 = Math_fround(HEAPF32[$p01$p11>>2]);
   $250 = Math_fround($42 * $249);
   $251 = (($p01$p11) + 4|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = (($p01$p11) + 8|0);
   $254 = Math_fround(HEAPF32[$253>>2]);
   $255 = Math_fround($44 * $254);
   $256 = Math_fround(HEAPF32[$p10$p00>>2]);
   $257 = Math_fround($42 * $256);
   $258 = (($p10$p00) + 4|0);
   $259 = Math_fround(HEAPF32[$258>>2]);
   $260 = (($p10$p00) + 8|0);
   $261 = Math_fround(HEAPF32[$260>>2]);
   $262 = Math_fround($44 * $261);
   $263 = Math_fround(HEAPF32[$p11$p10>>2]);
   $264 = Math_fround($42 * $263);
   $265 = (($p11$p10) + 4|0);
   $266 = Math_fround(HEAPF32[$265>>2]);
   $267 = (($p11$p10) + 8|0);
   $268 = Math_fround(HEAPF32[$267>>2]);
   $269 = Math_fround($44 * $268);
   $270 = Math_fround($243 - $257);
   $271 = Math_fround($245 - $259);
   $272 = Math_fround($248 - $262);
   $273 = Math_fround($264 - $257);
   $274 = Math_fround($266 - $259);
   $275 = Math_fround($269 - $262);
   $276 = Math_fround($271 * $275);
   $277 = Math_fround($272 * $274);
   $278 = Math_fround($276 - $277);
   $279 = Math_fround($272 * $273);
   $280 = Math_fround($270 * $275);
   $281 = Math_fround($279 - $280);
   $282 = Math_fround($270 * $274);
   $283 = Math_fround($271 * $273);
   $284 = Math_fround($282 - $283);
   $285 = Math_fround($264 - $250);
   $286 = Math_fround($266 - $252);
   $287 = Math_fround($269 - $255);
   $288 = Math_fround($243 - $250);
   $289 = Math_fround($245 - $252);
   $290 = Math_fround($248 - $255);
   $291 = Math_fround($290 * $286);
   $292 = Math_fround($289 * $287);
   $293 = Math_fround($291 - $292);
   $294 = Math_fround($288 * $287);
   $295 = Math_fround($290 * $285);
   $296 = Math_fround($294 - $295);
   $297 = Math_fround($289 * $285);
   $298 = Math_fround($288 * $286);
   $299 = Math_fround($297 - $298);
   $300 = Math_fround($278 * $278);
   $301 = Math_fround($281 * $281);
   $302 = Math_fround($300 + $301);
   $303 = Math_fround($284 * $284);
   $304 = Math_fround($302 + $303);
   $305 = (Math_fround(Math_sqrt((Math_fround($304)))));
   $306 = Math_fround(Math_fround(1.0) / $305);
   $307 = Math_fround($278 * $306);
   HEAPF32[$triNormals>>2] = $307;
   $308 = Math_fround($306 * $281);
   HEAPF32[$156>>2] = $308;
   $309 = Math_fround($306 * $284);
   HEAPF32[$157>>2] = $309;
   $310 = Math_fround($293 * $293);
   $311 = Math_fround($296 * $296);
   $312 = Math_fround($310 + $311);
   $313 = Math_fround($299 * $299);
   $314 = Math_fround($312 + $313);
   $315 = (Math_fround(Math_sqrt((Math_fround($314)))));
   $316 = Math_fround(Math_fround(1.0) / $315);
   $317 = Math_fround($293 * $316);
   HEAPF32[$158>>2] = $317;
   $318 = Math_fround($316 * $296);
   HEAPF32[$159>>2] = $318;
   $319 = Math_fround($316 * $299);
   HEAPF32[$160>>2] = $319;
   $320 = $241 ? Math_fround(-1.0) : Math_fround(1.0);
   $321 = Math_fround($161 + $uif$0);
   $322 = Math_fround($162 + $vif$0);
   $323 = $170 < Math_fround(1.0);
   $324 = $323 ? $170 : Math_fround(1.0);
   $325 = $last_tu$0 > $last_tv$0;
   $326 = $325 ? $last_tu$0 : $last_tv$0;
   $327 = Math_fround($du$0 * $324);
   $328 = Math_fround($65 + $327);
   $329 = Math_fround($dv$0 * $324);
   $330 = Math_fround($72 + $329);
   $331 = Math_fround($du$0 * $326);
   $332 = Math_fround($65 + $331);
   $333 = Math_fround($dv$0 * $326);
   $334 = Math_fround($72 + $333);
   $335 = Math_fround($332 - $321);
   $336 = Math_fround($335 * $320);
   $337 = Math_fround($334 - $322);
   $338 = Math_fround($337 + $336);
   $339 = $338 > Math_fround(0.0);
   $340 = $339&1;
   $341 = Math_fround($328 - $321);
   $342 = Math_fround($341 * $320);
   $343 = Math_fround($330 - $322);
   $344 = Math_fround($343 + $342);
   $345 = $344 > Math_fround(0.0);
   $346 = $345&1;
   $347 = $238 << 1;
   $348 = $340 | $347;
   $349 = $346 | $347;
   $350 = HEAP32[$133>>2]|0;
   $351 = ((($350) + ($238<<2)|0) + 2|0);
   $352 = HEAP8[$351>>0]|0;
   $353 = $352 & 127;
   $354 = ($353<<24>>24)==(127);
   $355 = $354&1;
   $356 = ((($350) + ($238<<2)|0) + 3|0);
   $357 = HEAP8[$356>>0]|0;
   $358 = $357 & 127;
   $359 = ($358<<24>>24)==(127);
   $360 = $359&1;
   $361 = ($348>>>0)>($349>>>0);
   $$ = $361 ? $360 : $355;
   $$29 = $361 ? $355 : $360;
   if ($325) {
    $362 = Math_fround(HEAPF32[$134>>2]);
    $363 = Math_fround(HEAPF32[$h>>2]);
    $364 = Math_fround($362 - $363);
    $storemerge = $163;$storemerge37 = $364;$storemerge38 = Math_fround(0.0);
   } else {
    $365 = Math_fround(HEAPF32[$135>>2]);
    $366 = Math_fround(HEAPF32[$h>>2]);
    $367 = Math_fround($365 - $366);
    $storemerge = Math_fround(0.0);$storemerge37 = $367;$storemerge38 = $168;
   }
   HEAPF32[$crossedEdge>>2] = $storemerge38;
   HEAPF32[$164>>2] = $storemerge37;
   HEAPF32[$165>>2] = $storemerge;
   $368 = ($$|0)==(0);
   if ($368) {
    $369 = (($triNormals) + (($340*12)|0)|0);
    $370 = Math_fround($42 * $332);
    $371 = Math_fround($44 * $334);
    $372 = Math_fround($85 * $326);
    $373 = Math_fround($29 + $372);
    (__ZN5physx30PxcContactTraceSegmentCallback12underFaceHitERKNS_2Gu15HeightFieldUtilERKNS_6PxVec3ES7_fffj($aCallback,$this,$369,$crossedEdge,$370,$371,$373,$348)|0);
   }
   $374 = ($349|0)!=($348|0);
   $375 = ($$29|0)==(0);
   $or$cond31 = $374 & $375;
   if ($or$cond31) {
    $376 = Math_fround($du$0 * $320);
    $377 = Math_fround($dv$0 + $376);
    $fabsf$i$i = (Math_fround(Math_abs((Math_fround($377)))));
    $378 = $fabsf$i$i > Math_fround(9.99999997475242707878E-7);
    if ($378) {
     $379 = Math_fround($321 - $65);
     $380 = Math_fround($379 * $320);
     $381 = Math_fround($322 - $72);
     $382 = Math_fround($381 + $380);
     $383 = Math_fround($382 / $377);
     $384 = (($triNormals) + (($346*12)|0)|0);
     $385 = Math_fround($257 - $250);
     $386 = Math_fround($259 - $252);
     $387 = Math_fround($262 - $255);
     HEAPF32[$0>>2] = $385;
     HEAPF32[$166>>2] = $386;
     HEAPF32[$167>>2] = $387;
     $388 = Math_fround($du$0 * $383);
     $389 = Math_fround($65 + $388);
     $390 = Math_fround($42 * $389);
     $391 = Math_fround($dv$0 * $383);
     $392 = Math_fround($72 + $391);
     $393 = Math_fround($44 * $392);
     $394 = Math_fround($85 * $383);
     $395 = Math_fround($29 + $394);
     (__ZN5physx30PxcContactTraceSegmentCallback12underFaceHitERKNS_2Gu15HeightFieldUtilERKNS_6PxVec3ES7_fffj($aCallback,$this,$384,$0,$390,$393,$395,$349)|0);
    }
   }
  }
  if ($169) {
   $396 = (($175) + ($90))|0;
   $397 = (Math_fround(($396|0)));
   $398 = !($397 < Math_fround(0.0));
   $399 = !($397 >= $132);
   $or$cond36 = $398 & $399;
   if (!($or$cond36)) {
    label = 40;
    break;
   }
   $400 = Math_fround($87 + $uif$0);
   $401 = Math_fround($122 + $tu$0);
   $last_tu$1 = $tu$0;$last_tv$1 = $last_tv$0;$tu$1 = $401;$tv$1 = $tv$0;$ui$1 = $175;$uif$1 = $400;$vi$1 = $vi$0;$vif$1 = $vif$0;
  } else {
   $402 = (($vi$0) + ($91))|0;
   $403 = (($402) + ($91))|0;
   $404 = (Math_fround(($403|0)));
   $405 = !($404 < Math_fround(0.0));
   $406 = !($404 >= $131);
   $or$cond34 = $405 & $406;
   if (!($or$cond34)) {
    label = 40;
    break;
   }
   $407 = Math_fround($89 + $vif$0);
   $408 = Math_fround($123 + $tv$0);
   $last_tu$1 = $last_tu$0;$last_tv$1 = $tv$0;$tu$1 = $tu$0;$tv$1 = $408;$ui$1 = $ui$0;$uif$1 = $uif$0;$vi$1 = $402;$vif$1 = $407;
  }
  $409 = $170 < Math_fround(0.999899983406066894531);
  if ($409) {
   $hLinePrev$0 = $172;$last_tu$0 = $last_tu$1;$last_tv$0 = $last_tv$1;$tu$0 = $tu$1;$tv$0 = $tv$1;$ui$0 = $ui$1;$uif$0 = $uif$1;$vi$0 = $vi$1;$vif$0 = $vif$1;
  } else {
   label = 40;
   break;
  }
 }
 if ((label|0) == 40) {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu15HeightFieldUtil30clipShapeNormalToVertexVoronoiERNS_6PxVec3Ejjj($this,$normal,$vertexIndex,$row,$column) {
 $this = $this|0;
 $normal = $normal|0;
 $vertexIndex = $vertexIndex|0;
 $row = $row|0;
 $column = $column|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $result$0$off0 = 0, $result$1$off0 = 0, $result$2$off0 = 0, $result$3$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($vertexIndex<<2)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = (Math_fround(($5<<16>>16)));
 $7 = ($row|0)==(0);
 if ($7) {
  $result$0$off0 = 0;
 } else {
  $8 = (($this) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 12|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround(-$11);
  $13 = (($9) + 8|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($1) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($vertexIndex) - ($16))|0;
  $18 = (($3) + ($17<<2)|0);
  $19 = HEAP16[$18>>1]|0;
  $20 = (Math_fround(($19<<16>>16)));
  $21 = Math_fround($20 - $6);
  $22 = Math_fround($14 * $21);
  $23 = Math_fround(HEAPF32[$normal>>2]);
  $24 = Math_fround($23 * $12);
  $25 = (($normal) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($26 * $22);
  $28 = Math_fround($24 + $27);
  $29 = (($normal) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($30 * Math_fround(0.0));
  $32 = Math_fround($31 + $28);
  $33 = $32 > Math_fround(0.0);
  if ($33) {
   $34 = Math_fround($32 * $12);
   $35 = Math_fround($22 * $32);
   $36 = Math_fround($32 * Math_fround(0.0));
   $37 = Math_fround($11 * $11);
   $38 = Math_fround($22 * $22);
   $39 = Math_fround($37 + $38);
   $40 = Math_fround($39 + Math_fround(0.0));
   $41 = Math_fround(Math_fround(1.0) / $40);
   $42 = Math_fround($34 * $41);
   $43 = Math_fround($35 * $41);
   $44 = Math_fround($36 * $41);
   $45 = Math_fround($23 - $42);
   HEAPF32[$normal>>2] = $45;
   $46 = Math_fround($26 - $43);
   HEAPF32[$25>>2] = $46;
   $47 = Math_fround($30 - $44);
   HEAPF32[$29>>2] = $47;
   $result$0$off0 = 1;
  } else {
   $result$0$off0 = 0;
  }
 }
 $48 = (($1) + 16|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + -1)|0;
 $51 = ($50>>>0)>($row>>>0);
 if ($51) {
  $52 = (($this) + 16|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 12|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($53) + 8|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($1) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + ($vertexIndex))|0;
  $61 = (($3) + ($60<<2)|0);
  $62 = HEAP16[$61>>1]|0;
  $63 = (Math_fround(($62<<16>>16)));
  $64 = Math_fround($63 - $6);
  $65 = Math_fround($57 * $64);
  $66 = Math_fround(HEAPF32[$normal>>2]);
  $67 = Math_fround($55 * $66);
  $68 = (($normal) + 4|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($69 * $65);
  $71 = Math_fround($67 + $70);
  $72 = (($normal) + 8|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($73 * Math_fround(0.0));
  $75 = Math_fround($74 + $71);
  $76 = $75 > Math_fround(0.0);
  if ($76) {
   $77 = Math_fround($55 * $75);
   $78 = Math_fround($65 * $75);
   $79 = Math_fround($75 * Math_fround(0.0));
   $80 = Math_fround($55 * $55);
   $81 = Math_fround($65 * $65);
   $82 = Math_fround($80 + $81);
   $83 = Math_fround($82 + Math_fround(0.0));
   $84 = Math_fround(Math_fround(1.0) / $83);
   $85 = Math_fround($77 * $84);
   $86 = Math_fround($78 * $84);
   $87 = Math_fround($79 * $84);
   $88 = Math_fround($66 - $85);
   HEAPF32[$normal>>2] = $88;
   $89 = Math_fround($69 - $86);
   HEAPF32[$68>>2] = $89;
   $90 = Math_fround($73 - $87);
   HEAPF32[$72>>2] = $90;
   $result$1$off0 = 1;
  } else {
   $result$1$off0 = $result$0$off0;
  }
 } else {
  $result$1$off0 = $result$0$off0;
 }
 $91 = ($column|0)==(0);
 if ($91) {
  $result$2$off0 = $result$1$off0;
 } else {
  $92 = (($this) + 16|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (($93) + 8|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = (($vertexIndex) + -1)|0;
  $97 = (($3) + ($96<<2)|0);
  $98 = HEAP16[$97>>1]|0;
  $99 = (Math_fround(($98<<16>>16)));
  $100 = Math_fround($99 - $6);
  $101 = Math_fround($95 * $100);
  $102 = (($93) + 16|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = Math_fround(-$103);
  $105 = Math_fround(HEAPF32[$normal>>2]);
  $106 = Math_fround($105 * Math_fround(0.0));
  $107 = (($normal) + 4|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($101 * $108);
  $110 = Math_fround($106 + $109);
  $111 = (($normal) + 8|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = Math_fround($112 * $104);
  $114 = Math_fround($110 + $113);
  $115 = $114 > Math_fround(0.0);
  if ($115) {
   $116 = Math_fround($114 * Math_fround(0.0));
   $117 = Math_fround($101 * $114);
   $118 = Math_fround($114 * $104);
   $119 = Math_fround($101 * $101);
   $120 = Math_fround($119 + Math_fround(0.0));
   $121 = Math_fround($103 * $103);
   $122 = Math_fround($121 + $120);
   $123 = Math_fround(Math_fround(1.0) / $122);
   $124 = Math_fround($116 * $123);
   $125 = Math_fround($117 * $123);
   $126 = Math_fround($118 * $123);
   $127 = Math_fround($105 - $124);
   HEAPF32[$normal>>2] = $127;
   $128 = Math_fround($108 - $125);
   HEAPF32[$107>>2] = $128;
   $129 = Math_fround($112 - $126);
   HEAPF32[$111>>2] = $129;
   $result$2$off0 = 1;
  } else {
   $result$2$off0 = $result$1$off0;
  }
 }
 $130 = (($1) + 20|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = (($131) + -1)|0;
 $133 = ($132>>>0)>($column>>>0);
 if (!($133)) {
  $result$3$off0 = $result$2$off0;
  STACKTOP = sp;return ($result$3$off0|0);
 }
 $134 = (($this) + 16|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($135) + 8|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($vertexIndex) + 1)|0;
 $139 = (($3) + ($138<<2)|0);
 $140 = HEAP16[$139>>1]|0;
 $141 = (Math_fround(($140<<16>>16)));
 $142 = Math_fround($141 - $6);
 $143 = Math_fround($137 * $142);
 $144 = (($135) + 16|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround(HEAPF32[$normal>>2]);
 $147 = Math_fround($146 * Math_fround(0.0));
 $148 = (($normal) + 4|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = Math_fround($143 * $149);
 $151 = Math_fround($147 + $150);
 $152 = (($normal) + 8|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = Math_fround($145 * $153);
 $155 = Math_fround($151 + $154);
 $156 = $155 > Math_fround(0.0);
 if (!($156)) {
  $result$3$off0 = $result$2$off0;
  STACKTOP = sp;return ($result$3$off0|0);
 }
 $157 = Math_fround($155 * Math_fround(0.0));
 $158 = Math_fround($143 * $155);
 $159 = Math_fround($145 * $155);
 $160 = Math_fround($143 * $143);
 $161 = Math_fround($160 + Math_fround(0.0));
 $162 = Math_fround($145 * $145);
 $163 = Math_fround($162 + $161);
 $164 = Math_fround(Math_fround(1.0) / $163);
 $165 = Math_fround($157 * $164);
 $166 = Math_fround($158 * $164);
 $167 = Math_fround($159 * $164);
 $168 = Math_fround($146 - $165);
 HEAPF32[$normal>>2] = $168;
 $169 = Math_fround($149 - $166);
 HEAPF32[$148>>2] = $169;
 $170 = Math_fround($153 - $167);
 HEAPF32[$152>>2] = $170;
 $result$3$off0 = 1;
 STACKTOP = sp;return ($result$3$off0|0);
}
function __ZN5physx30PxcContactTraceSegmentCallback12underFaceHitERKNS_2Gu15HeightFieldUtilERKNS_6PxVec3ES7_fffj($this,$hfUtil,$triangleNormal,$crossedEdge,$x,$z,$rayHeight,$triangleIndex) {
 $this = $this|0;
 $hfUtil = $hfUtil|0;
 $triangleNormal = $triangleNormal|0;
 $crossedEdge = $crossedEdge|0;
 $x = Math_fround($x);
 $z = Math_fround($z);
 $rayHeight = Math_fround($rayHeight);
 $triangleIndex = $triangleIndex|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0;
 var $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $dy$0 = Math_fround(0), $fracX$i$i = 0, $fracZ$i$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fracX$i$i = sp + 4|0;
 $fracZ$i$i = sp;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  HEAP32[$0>>2] = $triangleIndex;
  STACKTOP = sp;return 1;
 }
 $3 = (($hfUtil) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($hfUtil) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$hfUtil>>2]);
 $10 = Math_fround($9 * $x);
 $11 = (($hfUtil) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $z);
 $14 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($4,$10,$13,$fracX$i$i,$fracZ$i$i)|0);
 $15 = Math_fround(HEAPF32[$fracX$i$i>>2]);
 $16 = Math_fround(HEAPF32[$fracZ$i$i>>2]);
 $17 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($4,$14,$15,$16)));
 $18 = Math_fround($8 * $17);
 $19 = Math_fround($rayHeight - $18);
 $20 = (($this) + 64|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($4) + 40|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = !($23 <= Math_fround(0.0));
 $25 = !($19 <= $21);
 $or$cond$i = $24 | $25;
 $26 = !($23 <= $19);
 $or$cond1$i = $or$cond$i | $26;
 if ($or$cond1$i) {
  $27 = $23 > Math_fround(0.0);
  if (!($27)) {
   STACKTOP = sp;return 1;
  }
  $28 = Math_fround(-$21);
  $29 = $19 > $28;
  $30 = $23 > $19;
  $or$cond = $29 & $30;
  if (!($or$cond)) {
   STACKTOP = sp;return 1;
  }
 }
 $31 = (($crossedEdge) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($32 * $34);
 $36 = (($crossedEdge) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($this) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($37 * $39);
 $41 = Math_fround($35 - $40);
 $42 = Math_fround(HEAPF32[$this>>2]);
 $43 = Math_fround($37 * $42);
 $44 = Math_fround(HEAPF32[$crossedEdge>>2]);
 $45 = Math_fround($34 * $44);
 $46 = Math_fround($43 - $45);
 $47 = Math_fround($39 * $44);
 $48 = Math_fround($32 * $42);
 $49 = Math_fround($47 - $48);
 $50 = $46 < Math_fround(0.0);
 if ($50) {
  $51 = Math_fround(-$41);
  $52 = Math_fround(-$46);
  $53 = Math_fround(-$49);
  $55 = $52;$57 = $51;$61 = $53;
 } else {
  $55 = $46;$57 = $41;$61 = $49;
 }
 $54 = $55 < Math_fround(0.0);
 if ($54) {
  STACKTOP = sp;return 1;
 }
 $56 = Math_fround($57 * $57);
 $58 = Math_fround($55 * $55);
 $59 = Math_fround($58 + $56);
 $60 = Math_fround($61 * $61);
 $62 = Math_fround($60 + $59);
 $63 = $62 > Math_fround(0.0);
 if (!($63)) {
  STACKTOP = sp;return 1;
 }
 $64 = (Math_fround(Math_sqrt((Math_fround($62)))));
 $65 = Math_fround(Math_fround(1.0) / $64);
 $66 = Math_fround($55 * $65);
 $67 = Math_fround($19 * $66);
 $68 = $23 > Math_fround(0.0);
 if ($68) {
  $69 = Math_fround(-$67);
  $dy$0 = $69;
 } else {
  $dy$0 = $67;
 }
 $70 = (($this) + 12|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($this) + 16|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($this) + 20|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($this) + 24|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($this) + 28|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($this) + 32|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($this) + 36|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($this) + 40|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($this) + 44|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($this) + 48|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround(HEAPF32[$triangleNormal>>2]);
 $91 = (($triangleNormal) + 4|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($triangleNormal) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($71) + 4096|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96>>>0)>(63);
 if (!($97)) {
  $98 = Math_fround($83 * $rayHeight);
  $99 = Math_fround($81 * $rayHeight);
  $100 = Math_fround($79 * $rayHeight);
  $101 = Math_fround($77 * $x);
  $102 = Math_fround($75 * $x);
  $103 = Math_fround($73 * $x);
  $104 = Math_fround($83 * $92);
  $105 = Math_fround($81 * $92);
  $106 = Math_fround($79 * $92);
  $107 = Math_fround($77 * $90);
  $108 = Math_fround($75 * $90);
  $109 = Math_fround($73 * $90);
  $110 = (($this) + 60|0);
  $111 = (($this) + 56|0);
  $112 = (($this) + 52|0);
  $113 = Math_fround($89 * $z);
  $114 = Math_fround($87 * $z);
  $115 = Math_fround($85 * $z);
  $116 = Math_fround($101 + $98);
  $117 = Math_fround($102 + $99);
  $118 = Math_fround($103 + $100);
  $119 = Math_fround($89 * $94);
  $120 = Math_fround($87 * $94);
  $121 = Math_fround($85 * $94);
  $122 = Math_fround($107 + $104);
  $123 = Math_fround($108 + $105);
  $124 = Math_fround($109 + $106);
  $125 = Math_fround(HEAPF32[$110>>2]);
  $126 = Math_fround(HEAPF32[$111>>2]);
  $127 = Math_fround(HEAPF32[$112>>2]);
  $128 = Math_fround($116 + $113);
  $129 = Math_fround($117 + $114);
  $130 = Math_fround($118 + $115);
  $131 = Math_fround($122 + $119);
  $132 = Math_fround($123 + $120);
  $133 = Math_fround($124 + $121);
  $134 = Math_fround($128 + $125);
  $135 = Math_fround($129 + $126);
  $136 = Math_fround($130 + $127);
  $137 = (($96) + 1)|0;
  HEAP32[$95>>2] = $137;
  $138 = (($71) + ($96<<6)|0);
  HEAPF32[$138>>2] = $133;
  $139 = ((($71) + ($96<<6)|0) + 4|0);
  HEAPF32[$139>>2] = $132;
  $140 = ((($71) + ($96<<6)|0) + 8|0);
  HEAPF32[$140>>2] = $131;
  $141 = ((($71) + ($96<<6)|0) + 16|0);
  HEAPF32[$141>>2] = $136;
  $142 = ((($71) + ($96<<6)|0) + 20|0);
  HEAPF32[$142>>2] = $135;
  $143 = ((($71) + ($96<<6)|0) + 24|0);
  HEAPF32[$143>>2] = $134;
  $144 = ((($71) + ($96<<6)|0) + 12|0);
  HEAPF32[$144>>2] = $dy$0;
  $145 = ((($71) + ($96<<6)|0) + 48|0);
  HEAP32[$145>>2] = -1;
  $146 = ((($71) + ($96<<6)|0) + 52|0);
  HEAP32[$146>>2] = $triangleIndex;
 }
 HEAP32[$0>>2] = $triangleIndex;
 STACKTOP = sp;return 1;
}
function __ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($this,$vertexIndex,$fracX,$fracZ) {
 $this = $this|0;
 $vertexIndex = $vertexIndex|0;
 $fracX = Math_fround($fracX);
 $fracZ = Math_fround($fracZ);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + ($vertexIndex<<2)|0) + 2|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)<(0);
 if ($4) {
  $5 = (($1) + ($vertexIndex<<2)|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = (Math_fround(($6<<16>>16)));
  $8 = (($this) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($vertexIndex))|0;
  $11 = (($10) + 1)|0;
  $12 = (($1) + ($11<<2)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = (Math_fround(($13<<16>>16)));
  $15 = $fracZ > $fracX;
  if ($15) {
   $16 = (($vertexIndex) + 1)|0;
   $17 = (($1) + ($16<<2)|0);
   $18 = HEAP16[$17>>1]|0;
   $19 = (Math_fround(($18<<16>>16)));
   $20 = Math_fround($19 - $7);
   $21 = Math_fround($20 * $fracZ);
   $22 = Math_fround($7 + $21);
   $23 = Math_fround($14 - $19);
   $24 = Math_fround($23 * $fracX);
   $25 = Math_fround($24 + $22);
   $$0 = $25;
   STACKTOP = sp;return (Math_fround($$0));
  } else {
   $26 = (($1) + ($10<<2)|0);
   $27 = HEAP16[$26>>1]|0;
   $28 = (Math_fround(($27<<16>>16)));
   $29 = Math_fround($28 - $7);
   $30 = Math_fround($29 * $fracX);
   $31 = Math_fround($7 + $30);
   $32 = Math_fround($14 - $28);
   $33 = Math_fround($32 * $fracZ);
   $34 = Math_fround($33 + $31);
   $$0 = $34;
   STACKTOP = sp;return (Math_fround($$0));
  }
 } else {
  $35 = (($this) + 20|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($vertexIndex))|0;
  $38 = (($1) + ($37<<2)|0);
  $39 = HEAP16[$38>>1]|0;
  $40 = (Math_fround(($39<<16>>16)));
  $41 = (($vertexIndex) + 1)|0;
  $42 = (($1) + ($41<<2)|0);
  $43 = HEAP16[$42>>1]|0;
  $44 = (Math_fround(($43<<16>>16)));
  $45 = Math_fround($fracX + $fracZ);
  $46 = $45 < Math_fround(1.0);
  if ($46) {
   $47 = (($1) + ($vertexIndex<<2)|0);
   $48 = HEAP16[$47>>1]|0;
   $49 = (Math_fround(($48<<16>>16)));
   $50 = Math_fround($44 - $49);
   $51 = Math_fround($50 * $fracZ);
   $52 = Math_fround($49 + $51);
   $53 = Math_fround($40 - $49);
   $54 = Math_fround($53 * $fracX);
   $55 = Math_fround($54 + $52);
   $$0 = $55;
   STACKTOP = sp;return (Math_fround($$0));
  } else {
   $56 = (($37) + 1)|0;
   $57 = (($1) + ($56<<2)|0);
   $58 = HEAP16[$57>>1]|0;
   $59 = (Math_fround(($58<<16>>16)));
   $60 = Math_fround(Math_fround(1.0) - $fracZ);
   $61 = Math_fround($40 - $59);
   $62 = Math_fround($60 * $61);
   $63 = Math_fround($59 + $62);
   $64 = Math_fround(Math_fround(1.0) - $fracX);
   $65 = Math_fround($44 - $59);
   $66 = Math_fround($64 * $65);
   $67 = Math_fround($66 + $63);
   $$0 = $67;
   STACKTOP = sp;return (Math_fround($$0));
  }
 }
 return Math_fround(0);
}
function __ZN5physx17PxcContactBoxMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu14contactBoxMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx20PxcContactCapsuleBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $$idx$i = 0, $$idx$i1 = 0, $$idx$i24 = 0, $$idx$val$i = Math_fround(0), $$idx$val$i2 = Math_fround(0), $$idx$val$i25 = Math_fround(0), $$idx1$i = 0, $$idx1$i26 = 0, $$idx1$val$i = Math_fround(0), $$idx1$val$i27 = Math_fround(0), $$idx2$i = 0, $$idx2$i28 = 0, $$idx2$val$i = Math_fround(0), $$idx2$val$i29 = Math_fround(0), $$idx3$i = 0, $$idx3$i3 = 0, $$idx3$i30 = 0, $$idx3$val$i = Math_fround(0), $$idx3$val$i31 = Math_fround(0);
 var $$idx3$val$i4 = Math_fround(0), $$idx4$i = 0, $$idx4$i32 = 0, $$idx4$i5 = 0, $$idx4$val$i = Math_fround(0), $$idx4$val$i33 = Math_fround(0), $$idx4$val$i6 = Math_fround(0), $$idx5$i = 0, $$idx5$i34 = 0, $$idx5$val$i = Math_fround(0), $$idx5$val$i35 = Math_fround(0), $$pre = Math_fround(0), $$pre66 = Math_fround(0), $$pre67 = Math_fround(0), $$pre68 = Math_fround(0), $$pre69 = Math_fround(0), $$pre70 = Math_fround(0), $$pre71 = Math_fround(0), $$pre72 = Math_fround(0), $$pre73 = Math_fround(0);
 var $$pre74 = Math_fround(0), $$pre75 = Math_fround(0), $$pre76 = Math_fround(0), $$pre77 = Math_fround(0), $$pre78 = Math_fround(0), $$pre79 = Math_fround(0), $$pre80 = Math_fround(0), $$pre81 = Math_fround(0), $$pre82 = Math_fround(0), $$pre83 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0);
 var $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0);
 var $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0;
 var $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0);
 var $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = 0;
 var $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0;
 var $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0);
 var $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0);
 var $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = 0, $394 = 0, $395 = 0;
 var $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0);
 var $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0.0, $429 = 0, $43 = Math_fround(0), $430 = 0.0;
 var $431 = 0, $432 = 0.0, $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0);
 var $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0);
 var $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0);
 var $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = 0, $497 = 0, $498 = 0, $499 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0);
 var $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0);
 var $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = 0, $527 = 0, $528 = 0, $529 = Math_fround(0), $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = 0, $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0;
 var $54 = Math_fround(0), $540 = Math_fround(0), $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0);
 var $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = Math_fround(0);
 var $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = 0, $587 = 0, $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0);
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $600 = Math_fround(0), $601 = 0, $602 = 0, $603 = Math_fround(0), $604 = Math_fround(0), $605 = 0, $606 = Math_fround(0), $607 = 0, $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0);
 var $611 = Math_fround(0), $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = Math_fround(0), $622 = 0, $623 = 0, $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0);
 var $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0, $649 = 0, $65 = Math_fround(0), $650 = 0, $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0);
 var $666 = Math_fround(0), $667 = Math_fround(0), $668 = 0, $669 = Math_fround(0), $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0);
 var $684 = Math_fround(0), $685 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $Indices$013$i = 0, $Indices$016$i = 0, $PenDepth$031$i = Math_fround(0), $PenDepth$1$i = Math_fround(0);
 var $PenDepth$221$i = Math_fround(0), $PenDepth$3$i = Math_fround(0), $Pts$i = 0, $dist$i16 = 0, $exitcond$i = 0, $exitcond$i36 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i$i$i18 = Math_fround(0), $fabsf$i$i$i$i7 = Math_fround(0), $fabsf$i$i$i41 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i1$i$i19 = Math_fround(0), $fabsf$i$i1$i$i8 = Math_fround(0), $fabsf$i$i1$i40 = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i2$i$i20 = Math_fround(0), $fabsf$i$i2$i$i9 = Math_fround(0);
 var $fabsf$i$i2$i39 = Math_fround(0), $i$012$i = 0, $i$015$i = 0, $i$032$i = 0, $i1$022$i = 0, $ip$i17 = 0, $normal = 0, $onBox = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i$i21 = 0, $or$cond$i42 = 0, $phitmp$i = 0, $plane$i15 = 0, $s0$i12 = 0, $s1$i13 = 0, $sepAxis = 0, $t = 0, $v1$i14 = 0, $worldBox = 0;
 var $worldSegment = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $s0$i12 = sp + 296|0;
 $s1$i13 = sp + 284|0;
 $v1$i14 = sp + 272|0;
 $plane$i15 = sp + 256|0;
 $dist$i16 = sp + 248|0;
 $ip$i17 = sp + 236|0;
 $0 = sp + 224|0;
 $Pts$i = sp + 128|0;
 $worldSegment = sp + 88|0;
 $worldBox = sp + 28|0;
 $t = sp + 24|0;
 $onBox = sp + 12|0;
 $normal = sp;
 $sepAxis = sp + 112|0;
 $1 = Math_fround(HEAPF32[$transform0>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($transform0) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = Math_fround($4 * $5);
 $7 = Math_fround($6 + Math_fround(-1.0));
 $8 = Math_fround($1 * $2);
 $9 = Math_fround($8 + $7);
 $10 = (($transform0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $5);
 $13 = (($transform0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($2 * $14);
 $16 = Math_fround($12 + $15);
 $17 = Math_fround($5 * $14);
 $18 = Math_fround($2 * $11);
 $19 = Math_fround($18 - $17);
 $20 = (($shape0) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $9);
 $23 = Math_fround($21 * $16);
 $24 = Math_fround($21 * $19);
 $25 = (($transform0) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + $22);
 $28 = (($transform0) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 + $23);
 $31 = (($transform0) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 + $32);
 HEAPF32[$worldSegment>>2] = $27;
 $34 = (($worldSegment) + 4|0);
 HEAPF32[$34>>2] = $30;
 $35 = (($worldSegment) + 8|0);
 HEAPF32[$35>>2] = $33;
 $36 = Math_fround($26 - $22);
 $37 = Math_fround($29 - $23);
 $38 = Math_fround($32 - $24);
 $39 = (($worldSegment) + 12|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($worldSegment) + 16|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($worldSegment) + 20|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($shape0) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(HEAPF32[$contactDistance>>2]);
 $45 = Math_fround($43 + $44);
 $46 = (($shape1) + 4|0);
 $47 = Math_fround(HEAPF32[$transform1>>2]);
 $48 = (($transform1) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($transform1) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($transform1) + 12|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($47 + $47);
 $55 = Math_fround($49 + $49);
 $56 = Math_fround($51 + $51);
 $57 = Math_fround($47 * $54);
 $58 = Math_fround($49 * $55);
 $59 = Math_fround($51 * $56);
 $60 = Math_fround($54 * $49);
 $61 = Math_fround($54 * $51);
 $62 = Math_fround($54 * $53);
 $63 = Math_fround($55 * $51);
 $64 = Math_fround($55 * $53);
 $65 = Math_fround($56 * $53);
 $66 = Math_fround(Math_fround(1.0) - $58);
 $67 = Math_fround($66 - $59);
 $68 = Math_fround($60 + $65);
 $69 = Math_fround($61 - $64);
 $70 = Math_fround($60 - $65);
 $71 = Math_fround(Math_fround(1.0) - $57);
 $72 = Math_fround($71 - $59);
 $73 = Math_fround($63 + $62);
 $74 = Math_fround($61 + $64);
 $75 = Math_fround($63 - $62);
 $76 = Math_fround($71 - $58);
 HEAPF32[$worldBox>>2] = $67;
 $77 = (($worldBox) + 4|0);
 HEAPF32[$77>>2] = $68;
 $78 = (($worldBox) + 8|0);
 HEAPF32[$78>>2] = $69;
 $79 = (($worldBox) + 12|0);
 HEAPF32[$79>>2] = $70;
 $80 = (($worldBox) + 16|0);
 HEAPF32[$80>>2] = $72;
 $81 = (($worldBox) + 20|0);
 HEAPF32[$81>>2] = $73;
 $82 = (($worldBox) + 24|0);
 HEAPF32[$82>>2] = $74;
 $83 = (($worldBox) + 28|0);
 HEAPF32[$83>>2] = $75;
 $84 = (($worldBox) + 32|0);
 HEAPF32[$84>>2] = $76;
 $85 = (($worldBox) + 36|0);
 $86 = (($transform1) + 16|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 HEAPF32[$85>>2] = $87;
 $88 = (($worldBox) + 40|0);
 $89 = (($transform1) + 20|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 HEAPF32[$88>>2] = $90;
 $91 = (($worldBox) + 44|0);
 $92 = (($transform1) + 24|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 HEAPF32[$91>>2] = $93;
 $94 = (($worldBox) + 48|0);
 $95 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$94>>2] = $95;
 $96 = (($worldBox) + 52|0);
 $97 = (($shape1) + 8|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 HEAPF32[$96>>2] = $98;
 $99 = (($worldBox) + 56|0);
 $100 = (($shape1) + 12|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 HEAPF32[$99>>2] = $101;
 $102 = (($worldSegment) + 12|0);
 $103 = (($worldBox) + 36|0);
 $104 = (($worldBox) + 48|0);
 $105 = (Math_fround(__ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($worldSegment,$102,$103,$104,$worldBox,$t,$onBox)));
 $106 = Math_fround($45 * $45);
 $107 = !($105 >= $106);
 if (!($107)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $108 = $105 != Math_fround(0.0);
 if ($108) {
  $109 = Math_fround(HEAPF32[$t>>2]);
  $110 = Math_fround(HEAPF32[$39>>2]);
  $111 = Math_fround(HEAPF32[$worldSegment>>2]);
  $112 = Math_fround($110 - $111);
  $113 = Math_fround(HEAPF32[$40>>2]);
  $114 = Math_fround(HEAPF32[$34>>2]);
  $115 = Math_fround($113 - $114);
  $116 = Math_fround(HEAPF32[$41>>2]);
  $117 = Math_fround(HEAPF32[$35>>2]);
  $118 = Math_fround($116 - $117);
  $119 = Math_fround($109 * $112);
  $120 = Math_fround($109 * $115);
  $121 = Math_fround($109 * $118);
  $122 = Math_fround($111 + $119);
  $123 = Math_fround($114 + $120);
  $124 = Math_fround($117 + $121);
  $125 = Math_fround(HEAPF32[$onBox>>2]);
  $126 = Math_fround(HEAPF32[$worldBox>>2]);
  $127 = Math_fround($125 * $126);
  $128 = Math_fround(HEAPF32[$77>>2]);
  $129 = Math_fround($125 * $128);
  $130 = Math_fround(HEAPF32[$78>>2]);
  $131 = Math_fround($125 * $130);
  $132 = (($onBox) + 4|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = Math_fround(HEAPF32[$79>>2]);
  $135 = Math_fround($133 * $134);
  $136 = Math_fround(HEAPF32[$80>>2]);
  $137 = Math_fround($133 * $136);
  $138 = Math_fround(HEAPF32[$81>>2]);
  $139 = Math_fround($133 * $138);
  $140 = Math_fround($127 + $135);
  $141 = Math_fround($129 + $137);
  $142 = Math_fround($131 + $139);
  $143 = (($onBox) + 8|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = Math_fround(HEAPF32[$82>>2]);
  $146 = Math_fround($144 * $145);
  $147 = Math_fround(HEAPF32[$83>>2]);
  $148 = Math_fround($144 * $147);
  $149 = Math_fround(HEAPF32[$84>>2]);
  $150 = Math_fround($144 * $149);
  $151 = Math_fround($140 + $146);
  $152 = Math_fround($141 + $148);
  $153 = Math_fround($142 + $150);
  $154 = Math_fround(HEAPF32[$103>>2]);
  $155 = Math_fround($151 + $154);
  $156 = Math_fround(HEAPF32[$88>>2]);
  $157 = Math_fround($152 + $156);
  $158 = Math_fround(HEAPF32[$91>>2]);
  $159 = Math_fround($153 + $158);
  HEAPF32[$onBox>>2] = $155;
  HEAPF32[$132>>2] = $157;
  HEAPF32[$143>>2] = $159;
  $160 = Math_fround($122 - $155);
  $161 = Math_fround($123 - $157);
  $162 = Math_fround($124 - $159);
  HEAPF32[$normal>>2] = $160;
  $163 = (($normal) + 4|0);
  HEAPF32[$163>>2] = $161;
  $164 = (($normal) + 8|0);
  HEAPF32[$164>>2] = $162;
  $165 = Math_fround($160 * $160);
  $166 = Math_fround($161 * $161);
  $167 = Math_fround($165 + $166);
  $168 = Math_fround($162 * $162);
  $169 = Math_fround($168 + $167);
  $170 = (Math_fround(Math_sqrt((Math_fround($169)))));
  $171 = $170 > Math_fround(0.0);
  if ($171) {
   $172 = Math_fround(Math_fround(1.0) / $170);
   $173 = Math_fround($160 * $172);
   HEAPF32[$normal>>2] = $173;
   $174 = Math_fround($172 * $161);
   HEAPF32[$163>>2] = $174;
   $175 = Math_fround($172 * $162);
   HEAPF32[$164>>2] = $175;
   $176 = Math_fround(HEAPF32[$42>>2]);
   $177 = Math_fround(HEAPF32[$contactDistance>>2]);
   __ZL21PxcGenerateVFContactsRN5physx2Gu13ContactBufferERKNS0_7SegmentEfRKNS0_3BoxERKNS_6PxVec3Ef($contactBuffer,$worldSegment,$176,$worldBox,$normal,$177);
   $178 = (($contactBuffer) + 4096|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = ($179|0)==(2);
   if ($180) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $181 = Math_fround(HEAPF32[$42>>2]);
   $182 = Math_fround(HEAPF32[$contactDistance>>2]);
   $183 = (__ZN5physx2Gu11getBoxEdgesEv()|0);
   $184 = (($worldBox) + 12|0);
   $185 = (($worldBox) + 24|0);
   __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($Pts$i,$103,$104,$worldBox,$184,$185);
   $186 = Math_fround(HEAPF32[$worldSegment>>2]);
   HEAPF32[$s0$i12>>2] = $186;
   $187 = (($s0$i12) + 4|0);
   $188 = Math_fround(HEAPF32[$34>>2]);
   HEAPF32[$187>>2] = $188;
   $189 = (($s0$i12) + 8|0);
   $190 = Math_fround(HEAPF32[$35>>2]);
   HEAPF32[$189>>2] = $190;
   $191 = Math_fround(HEAPF32[$39>>2]);
   HEAPF32[$s1$i13>>2] = $191;
   $192 = (($s1$i13) + 4|0);
   $193 = Math_fround(HEAPF32[$40>>2]);
   HEAPF32[$192>>2] = $193;
   $194 = (($s1$i13) + 8|0);
   $195 = Math_fround(HEAPF32[$41>>2]);
   HEAPF32[$194>>2] = $195;
   $196 = Math_fround($191 - $186);
   $197 = Math_fround($193 - $188);
   $198 = Math_fround($195 - $190);
   $199 = Math_fround($196 * $196);
   $200 = Math_fround($197 * $197);
   $201 = Math_fround($199 + $200);
   $202 = Math_fround($198 * $198);
   $203 = Math_fround($201 + $202);
   $204 = (Math_fround(Math_sqrt((Math_fround($203)))));
   $205 = $204 > Math_fround(0.0);
   if ($205) {
    $206 = Math_fround(Math_fround(0.00999999977648258209228) / $204);
    $207 = Math_fround($196 * $206);
    $208 = Math_fround($197 * $206);
    $209 = Math_fround($198 * $206);
    $210 = Math_fround($186 - $207);
    HEAPF32[$s0$i12>>2] = $210;
    $211 = Math_fround($188 - $208);
    HEAPF32[$187>>2] = $211;
    $212 = Math_fround($190 - $209);
    HEAPF32[$189>>2] = $212;
    $213 = Math_fround($191 + $207);
    HEAPF32[$s1$i13>>2] = $213;
    $214 = Math_fround($193 + $208);
    HEAPF32[$192>>2] = $214;
    $215 = Math_fround($195 + $209);
    HEAPF32[$194>>2] = $215;
    $217 = $210;$218 = $213;$220 = $211;$221 = $214;$223 = $212;$224 = $215;
   } else {
    $217 = $186;$218 = $191;$220 = $188;$221 = $193;$223 = $190;$224 = $195;
   }
   $216 = Math_fround($218 - $217);
   $219 = Math_fround($221 - $220);
   $222 = Math_fround($224 - $223);
   HEAPF32[$v1$i14>>2] = $216;
   $225 = (($v1$i14) + 4|0);
   HEAPF32[$225>>2] = $219;
   $226 = (($v1$i14) + 8|0);
   HEAPF32[$226>>2] = $222;
   $227 = Math_fround(HEAPF32[$164>>2]);
   $228 = Math_fround($219 * $227);
   $229 = Math_fround(HEAPF32[$163>>2]);
   $230 = Math_fround($222 * $229);
   $231 = Math_fround($228 - $230);
   $232 = Math_fround(HEAPF32[$normal>>2]);
   $233 = Math_fround($222 * $232);
   $234 = Math_fround($227 * $216);
   $235 = Math_fround($233 - $234);
   $236 = Math_fround($216 * $229);
   $237 = Math_fround($219 * $232);
   $238 = Math_fround($236 - $237);
   $239 = Math_fround(-$231);
   $240 = Math_fround(-$235);
   $241 = Math_fround(-$238);
   HEAPF32[$plane$i15>>2] = $239;
   $242 = (($plane$i15) + 4|0);
   HEAPF32[$242>>2] = $240;
   $243 = (($plane$i15) + 8|0);
   HEAPF32[$243>>2] = $241;
   $244 = Math_fround($217 * $239);
   $245 = Math_fround($220 * $240);
   $246 = Math_fround($244 + $245);
   $247 = Math_fround($223 * $241);
   $248 = Math_fround($247 + $246);
   $249 = Math_fround(-$248);
   $250 = (($plane$i15) + 12|0);
   HEAPF32[$250>>2] = $249;
   $fabsf$i$i$i$i18 = (Math_fround(Math_abs((Math_fround($239)))));
   $fabsf$i$i1$i$i19 = (Math_fround(Math_abs((Math_fround($240)))));
   $fabsf$i$i2$i$i20 = (Math_fround(Math_abs((Math_fround($241)))));
   $251 = $fabsf$i$i1$i$i19 > $fabsf$i$i$i$i18;
   $252 = $fabsf$i$i1$i$i19 > $fabsf$i$i2$i$i20;
   $or$cond$i$i21 = $251 & $252;
   if ($or$cond$i$i21) {
    $255 = 0;$258 = 2;
   } else {
    $253 = $fabsf$i$i2$i$i20 > $fabsf$i$i$i$i18;
    if ($253) {
     $255 = 1;$258 = 0;
    } else {
     $255 = 2;$258 = 1;
    }
   }
   $254 = (($v1$i14) + ($255<<2)|0);
   $256 = Math_fround(HEAPF32[$254>>2]);
   $257 = (($normal) + ($258<<2)|0);
   $259 = Math_fround(HEAPF32[$257>>2]);
   $260 = Math_fround($256 * $259);
   $261 = (($v1$i14) + ($258<<2)|0);
   $262 = Math_fround(HEAPF32[$261>>2]);
   $263 = (($normal) + ($255<<2)|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = Math_fround($262 * $264);
   $266 = Math_fround($260 - $265);
   $267 = Math_fround(Math_fround(1.0) / $266);
   $268 = (($0) + 4|0);
   $269 = (($0) + 8|0);
   $270 = Math_fround($181 + $182);
   $271 = (($ip$i17) + 8|0);
   $272 = (($ip$i17) + 4|0);
   $$pre = Math_fround(HEAPF32[$normal>>2]);
   $Indices$016$i = $183;$i$015$i = 1;
   while(1) {
    $273 = (($Indices$016$i) + 1|0);
    $274 = HEAP8[$Indices$016$i>>0]|0;
    $275 = $274&255;
    $276 = (($Indices$016$i) + 2|0);
    $277 = HEAP8[$273>>0]|0;
    $278 = $277&255;
    $279 = Math_fround(-$$pre);
    $280 = Math_fround(-$229);
    $281 = Math_fround(-$227);
    HEAPF32[$0>>2] = $279;
    HEAPF32[$268>>2] = $280;
    HEAPF32[$269>>2] = $281;
    $$idx$i24 = (($Pts$i) + (($275*12)|0)|0);
    $$idx$val$i25 = Math_fround(HEAPF32[$$idx$i24>>2]);
    $$idx1$i26 = ((($Pts$i) + (($275*12)|0)|0) + 4|0);
    $$idx1$val$i27 = Math_fround(HEAPF32[$$idx1$i26>>2]);
    $$idx2$i28 = ((($Pts$i) + (($275*12)|0)|0) + 8|0);
    $$idx2$val$i29 = Math_fround(HEAPF32[$$idx2$i28>>2]);
    $$idx3$i30 = (($Pts$i) + (($278*12)|0)|0);
    $$idx3$val$i31 = Math_fround(HEAPF32[$$idx3$i30>>2]);
    $$idx4$i32 = ((($Pts$i) + (($278*12)|0)|0) + 4|0);
    $$idx4$val$i33 = Math_fround(HEAPF32[$$idx4$i32>>2]);
    $$idx5$i34 = ((($Pts$i) + (($278*12)|0)|0) + 8|0);
    $$idx5$val$i35 = Math_fround(HEAPF32[$$idx5$i34>>2]);
    $282 = (__ZL22intersectEdgeEdgePrecaRKN5physx6PxVec3ES2_S2_RKNS_7PxPlaneEjjfS2_S2_S2_RfRS0_($s0$i12,$s1$i13,$v1$i14,$plane$i15,$258,$255,$267,$0,$$idx$val$i25,$$idx1$val$i27,$$idx2$val$i29,$$idx3$val$i31,$$idx4$val$i33,$$idx5$val$i35,$dist$i16,$ip$i17)|0);
    if ($282) {
     $283 = Math_fround(HEAPF32[$dist$i16>>2]);
     $284 = $283 < $270;
     if ($284) {
      $285 = HEAP32[$178>>2]|0;
      $286 = ($285>>>0)>(63);
      if (!($286)) {
       $287 = Math_fround(HEAPF32[$271>>2]);
       $288 = Math_fround(HEAPF32[$272>>2]);
       $289 = Math_fround(HEAPF32[$ip$i17>>2]);
       $290 = Math_fround($283 * $227);
       $291 = Math_fround($283 * $229);
       $292 = Math_fround($283 * $$pre);
       $293 = Math_fround($283 - $181);
       $294 = Math_fround($287 - $290);
       $295 = Math_fround($288 - $291);
       $296 = Math_fround($289 - $292);
       $297 = (($285) + 1)|0;
       HEAP32[$178>>2] = $297;
       $298 = (($contactBuffer) + ($285<<6)|0);
       HEAPF32[$298>>2] = $$pre;
       $299 = ((($contactBuffer) + ($285<<6)|0) + 4|0);
       HEAPF32[$299>>2] = $229;
       $300 = ((($contactBuffer) + ($285<<6)|0) + 8|0);
       HEAPF32[$300>>2] = $227;
       $301 = ((($contactBuffer) + ($285<<6)|0) + 16|0);
       HEAPF32[$301>>2] = $296;
       $302 = ((($contactBuffer) + ($285<<6)|0) + 20|0);
       HEAPF32[$302>>2] = $295;
       $303 = ((($contactBuffer) + ($285<<6)|0) + 24|0);
       HEAPF32[$303>>2] = $294;
       $304 = ((($contactBuffer) + ($285<<6)|0) + 12|0);
       HEAPF32[$304>>2] = $293;
       $305 = ((($contactBuffer) + ($285<<6)|0) + 48|0);
       HEAP32[$305>>2] = -1;
       $306 = ((($contactBuffer) + ($285<<6)|0) + 52|0);
       HEAP32[$306>>2] = -1;
      }
     }
    }
    $exitcond$i36 = ($i$015$i|0)==(12);
    if ($exitcond$i36) {
     break;
    }
    $phitmp$i = (($i$015$i) + 1)|0;
    $Indices$016$i = $276;$i$015$i = $phitmp$i;
   }
   $307 = HEAP32[$178>>2]|0;
   $308 = ($307|0)==(0);
   if (!($308)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $309 = (Math_fround(Math_sqrt((Math_fround($105)))));
   $310 = Math_fround(HEAPF32[$42>>2]);
   $311 = Math_fround($309 - $310);
   HEAP32[$178>>2] = 1;
   HEAPF32[$contactBuffer>>2] = $$pre;
   $312 = (($contactBuffer) + 4|0);
   HEAPF32[$312>>2] = $229;
   $313 = (($contactBuffer) + 8|0);
   HEAPF32[$313>>2] = $227;
   $314 = Math_fround(HEAPF32[$onBox>>2]);
   $315 = (($contactBuffer) + 16|0);
   HEAPF32[$315>>2] = $314;
   $316 = Math_fround(HEAPF32[$132>>2]);
   $317 = (($contactBuffer) + 20|0);
   HEAPF32[$317>>2] = $316;
   $318 = Math_fround(HEAPF32[$143>>2]);
   $319 = (($contactBuffer) + 24|0);
   HEAPF32[$319>>2] = $318;
   $320 = (($contactBuffer) + 12|0);
   HEAPF32[$320>>2] = $311;
   $321 = (($contactBuffer) + 48|0);
   HEAP32[$321>>2] = -1;
   $322 = (($contactBuffer) + 52|0);
   HEAP32[$322>>2] = -1;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $328 = $111;$330 = $114;$333 = $117;$336 = $110;$338 = $113;$341 = $116;$349 = $154;$351 = $156;$354 = $158;$357 = $126;$359 = $128;$362 = $130;$366 = $134;$368 = $136;$371 = $138;$376 = $145;$378 = $147;$381 = $149;
  }
 } else {
  $$pre66 = Math_fround(HEAPF32[$worldSegment>>2]);
  $$pre67 = Math_fround(HEAPF32[$34>>2]);
  $$pre68 = Math_fround(HEAPF32[$35>>2]);
  $$pre69 = Math_fround(HEAPF32[$39>>2]);
  $$pre70 = Math_fround(HEAPF32[$40>>2]);
  $$pre71 = Math_fround(HEAPF32[$41>>2]);
  $$pre72 = Math_fround(HEAPF32[$85>>2]);
  $$pre73 = Math_fround(HEAPF32[$88>>2]);
  $$pre74 = Math_fround(HEAPF32[$91>>2]);
  $$pre75 = Math_fround(HEAPF32[$worldBox>>2]);
  $$pre76 = Math_fround(HEAPF32[$77>>2]);
  $$pre77 = Math_fround(HEAPF32[$78>>2]);
  $$pre78 = Math_fround(HEAPF32[$79>>2]);
  $$pre79 = Math_fround(HEAPF32[$80>>2]);
  $$pre80 = Math_fround(HEAPF32[$81>>2]);
  $$pre81 = Math_fround(HEAPF32[$82>>2]);
  $$pre82 = Math_fround(HEAPF32[$83>>2]);
  $$pre83 = Math_fround(HEAPF32[$84>>2]);
  $328 = $$pre66;$330 = $$pre67;$333 = $$pre68;$336 = $$pre69;$338 = $$pre70;$341 = $$pre71;$349 = $$pre72;$351 = $$pre73;$354 = $$pre74;$357 = $$pre75;$359 = $$pre76;$362 = $$pre77;$366 = $$pre78;$368 = $$pre79;$371 = $$pre80;$376 = $$pre81;$378 = $$pre82;$381 = $$pre83;
 }
 $323 = Math_fround(HEAPF32[$42>>2]);
 $324 = Math_fround(HEAPF32[$94>>2]);
 $325 = Math_fround(HEAPF32[$96>>2]);
 $326 = Math_fround(HEAPF32[$99>>2]);
 $677 = Math_fround(0.0);$678 = Math_fround(0.0);$679 = Math_fround(0.0);$PenDepth$031$i = Math_fround(3.40282346638528859812E+38);$i$032$i = 0;
 while(1) {
  $$idx$i1 = (($worldBox) + (($i$032$i*12)|0)|0);
  $$idx$val$i2 = Math_fround(HEAPF32[$$idx$i1>>2]);
  $$idx3$i3 = ((($worldBox) + (($i$032$i*12)|0)|0) + 4|0);
  $$idx3$val$i4 = Math_fround(HEAPF32[$$idx3$i3>>2]);
  $$idx4$i5 = ((($worldBox) + (($i$032$i*12)|0)|0) + 8|0);
  $$idx4$val$i6 = Math_fround(HEAPF32[$$idx4$i5>>2]);
  $327 = Math_fround($$idx$val$i2 * $328);
  $329 = Math_fround($$idx3$val$i4 * $330);
  $331 = Math_fround($327 + $329);
  $332 = Math_fround($$idx4$val$i6 * $333);
  $334 = Math_fround($331 + $332);
  $335 = Math_fround($$idx$val$i2 * $336);
  $337 = Math_fround($$idx3$val$i4 * $338);
  $339 = Math_fround($335 + $337);
  $340 = Math_fround($$idx4$val$i6 * $341);
  $342 = Math_fround($339 + $340);
  $343 = $334 > $342;
  $344 = $343 ? $342 : $334;
  $345 = $343 ? $334 : $342;
  $346 = Math_fround($344 - $323);
  $347 = Math_fround($323 + $345);
  $348 = Math_fround($$idx$val$i2 * $349);
  $350 = Math_fround($$idx3$val$i4 * $351);
  $352 = Math_fround($348 + $350);
  $353 = Math_fround($$idx4$val$i6 * $354);
  $355 = Math_fround($352 + $353);
  $356 = Math_fround($$idx$val$i2 * $357);
  $358 = Math_fround($$idx3$val$i4 * $359);
  $360 = Math_fround($356 + $358);
  $361 = Math_fround($$idx4$val$i6 * $362);
  $363 = Math_fround($360 + $361);
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($363)))));
  $364 = Math_fround($fabsf$i$i2$i * $324);
  $365 = Math_fround($$idx$val$i2 * $366);
  $367 = Math_fround($$idx3$val$i4 * $368);
  $369 = Math_fround($365 + $367);
  $370 = Math_fround($$idx4$val$i6 * $371);
  $372 = Math_fround($369 + $370);
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($372)))));
  $373 = Math_fround($fabsf$i$i1$i * $325);
  $374 = Math_fround($364 + $373);
  $375 = Math_fround($$idx$val$i2 * $376);
  $377 = Math_fround($$idx3$val$i4 * $378);
  $379 = Math_fround($375 + $377);
  $380 = Math_fround($$idx4$val$i6 * $381);
  $382 = Math_fround($379 + $380);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($382)))));
  $383 = Math_fround($fabsf$i$i$i * $326);
  $384 = Math_fround($374 + $383);
  $385 = Math_fround($355 - $384);
  $386 = Math_fround($355 + $384);
  $387 = $347 < $385;
  $388 = $386 < $346;
  $or$cond$i = $387 | $388;
  if ($or$cond$i) {
   $$0 = 0;
   label = 52;
   break;
  }
  $389 = Math_fround($347 - $385);
  $390 = Math_fround($386 - $346);
  $391 = $389 < $390;
  $392 = $391 ? $389 : $390;
  $393 = $392 < $PenDepth$031$i;
  if ($393) {
   $680 = $$idx4$val$i6;$681 = $$idx3$val$i4;$682 = $$idx$val$i2;$PenDepth$1$i = $392;
  } else {
   $680 = $679;$681 = $678;$682 = $677;$PenDepth$1$i = $PenDepth$031$i;
  }
  $394 = (($i$032$i) + 1)|0;
  $395 = ($394>>>0)<(3);
  if ($395) {
   $677 = $682;$678 = $681;$679 = $680;$PenDepth$031$i = $PenDepth$1$i;$i$032$i = $394;
  } else {
   break;
  }
 }
 if ((label|0) == 52) {
  STACKTOP = sp;return ($$0|0);
 }
 $396 = Math_fround($336 - $328);
 $397 = Math_fround($338 - $330);
 $398 = Math_fround($341 - $333);
 $399 = Math_fround($396 * $396);
 $400 = Math_fround($397 * $397);
 $401 = Math_fround($399 + $400);
 $402 = Math_fround($398 * $398);
 $403 = Math_fround($401 + $402);
 $404 = $403 > Math_fround(0.0);
 if ($404) {
  $405 = (Math_fround(Math_sqrt((Math_fround($403)))));
  $406 = Math_fround(Math_fround(1.0) / $405);
  $407 = Math_fround($396 * $406);
  $408 = Math_fround($397 * $406);
  $409 = Math_fround($398 * $406);
  $413 = $408;$417 = $409;$423 = $407;
 } else {
  $413 = Math_fround(0.0);$417 = Math_fround(0.0);$423 = Math_fround(0.0);
 }
 $683 = $682;$684 = $681;$685 = $680;$PenDepth$221$i = $PenDepth$1$i;$i1$022$i = 0;
 while(1) {
  $410 = ((($worldBox) + (($i1$022$i*12)|0)|0) + 8|0);
  $411 = Math_fround(HEAPF32[$410>>2]);
  $412 = Math_fround($413 * $411);
  $414 = ((($worldBox) + (($i1$022$i*12)|0)|0) + 4|0);
  $415 = Math_fround(HEAPF32[$414>>2]);
  $416 = Math_fround($417 * $415);
  $418 = Math_fround($412 - $416);
  $419 = (($worldBox) + (($i1$022$i*12)|0)|0);
  $420 = Math_fround(HEAPF32[$419>>2]);
  $421 = Math_fround($417 * $420);
  $422 = Math_fround($423 * $411);
  $424 = Math_fround($421 - $422);
  $425 = Math_fround($423 * $415);
  $426 = Math_fround($413 * $420);
  $427 = Math_fround($425 - $426);
  $fabsf$i$i$i$i7 = (Math_fround(Math_abs((Math_fround($418)))));
  $428 = +$fabsf$i$i$i$i7;
  $429 = $428 > 9.99999999999999954748E-7;
  if ($429) {
   label = 31;
  } else {
   $fabsf$i$i1$i$i8 = (Math_fround(Math_abs((Math_fround($424)))));
   $430 = +$fabsf$i$i1$i$i8;
   $431 = $430 > 9.99999999999999954748E-7;
   if ($431) {
    label = 31;
   } else {
    $fabsf$i$i2$i$i9 = (Math_fround(Math_abs((Math_fround($427)))));
    $432 = +$fabsf$i$i2$i$i9;
    $433 = $432 > 9.99999999999999954748E-7;
    if ($433) {
     label = 31;
    } else {
     $509 = $683;$511 = $684;$514 = $685;$PenDepth$3$i = $PenDepth$221$i;
    }
   }
  }
  if ((label|0) == 31) {
   label = 0;
   $434 = Math_fround($418 * $418);
   $435 = Math_fround($424 * $424);
   $436 = Math_fround($434 + $435);
   $437 = Math_fround($427 * $427);
   $438 = Math_fround($437 + $436);
   $439 = $438 > Math_fround(0.0);
   if ($439) {
    $440 = (Math_fround(Math_sqrt((Math_fround($438)))));
    $441 = Math_fround(Math_fround(1.0) / $440);
    $442 = Math_fround($418 * $441);
    $443 = Math_fround($424 * $441);
    $444 = Math_fround($427 * $441);
    $446 = $442;$448 = $443;$451 = $444;
   } else {
    $446 = Math_fround(0.0);$448 = Math_fround(0.0);$451 = Math_fround(0.0);
   }
   $445 = Math_fround($446 * $328);
   $447 = Math_fround($448 * $330);
   $449 = Math_fround($445 + $447);
   $450 = Math_fround($451 * $333);
   $452 = Math_fround($449 + $450);
   $453 = Math_fround($446 * $336);
   $454 = Math_fround($448 * $338);
   $455 = Math_fround($453 + $454);
   $456 = Math_fround($451 * $341);
   $457 = Math_fround($455 + $456);
   $458 = $452 > $457;
   $459 = $458 ? $457 : $452;
   $460 = $458 ? $452 : $457;
   $461 = Math_fround($459 - $323);
   $462 = Math_fround($323 + $460);
   $463 = Math_fround($446 * $349);
   $464 = Math_fround($448 * $351);
   $465 = Math_fround($463 + $464);
   $466 = Math_fround($451 * $354);
   $467 = Math_fround($465 + $466);
   $468 = Math_fround($446 * $357);
   $469 = Math_fround($448 * $359);
   $470 = Math_fround($468 + $469);
   $471 = Math_fround($451 * $362);
   $472 = Math_fround($470 + $471);
   $fabsf$i$i2$i39 = (Math_fround(Math_abs((Math_fround($472)))));
   $473 = Math_fround($fabsf$i$i2$i39 * $324);
   $474 = Math_fround($446 * $366);
   $475 = Math_fround($448 * $368);
   $476 = Math_fround($474 + $475);
   $477 = Math_fround($451 * $371);
   $478 = Math_fround($476 + $477);
   $fabsf$i$i1$i40 = (Math_fround(Math_abs((Math_fround($478)))));
   $479 = Math_fround($fabsf$i$i1$i40 * $325);
   $480 = Math_fround($473 + $479);
   $481 = Math_fround($446 * $376);
   $482 = Math_fround($448 * $378);
   $483 = Math_fround($481 + $482);
   $484 = Math_fround($451 * $381);
   $485 = Math_fround($483 + $484);
   $fabsf$i$i$i41 = (Math_fround(Math_abs((Math_fround($485)))));
   $486 = Math_fround($fabsf$i$i$i41 * $326);
   $487 = Math_fround($480 + $486);
   $488 = Math_fround($467 - $487);
   $489 = Math_fround($467 + $487);
   $490 = $462 < $488;
   $491 = $489 < $461;
   $or$cond$i42 = $490 | $491;
   if ($or$cond$i42) {
    $$0 = 0;
    label = 52;
    break;
   }
   $492 = Math_fround($462 - $488);
   $493 = Math_fround($489 - $461);
   $494 = $492 < $493;
   $495 = $494 ? $492 : $493;
   $496 = $495 < $PenDepth$221$i;
   if ($496) {
    $509 = $446;$511 = $448;$514 = $451;$PenDepth$3$i = $495;
   } else {
    $509 = $683;$511 = $684;$514 = $685;$PenDepth$3$i = $PenDepth$221$i;
   }
  }
  $497 = (($i1$022$i) + 1)|0;
  $498 = ($497>>>0)<(3);
  if ($498) {
   $683 = $509;$684 = $511;$685 = $514;$PenDepth$221$i = $PenDepth$3$i;$i1$022$i = $497;
  } else {
   break;
  }
 }
 if ((label|0) == 52) {
  STACKTOP = sp;return ($$0|0);
 }
 $499 = Math_fround($328 + $336);
 $500 = Math_fround($330 + $338);
 $501 = Math_fround($333 + $341);
 $502 = Math_fround($499 * Math_fround(0.5));
 $503 = Math_fround($500 * Math_fround(0.5));
 $504 = Math_fround($501 * Math_fround(0.5));
 $505 = Math_fround($502 - $349);
 $506 = Math_fround($503 - $351);
 $507 = Math_fround($504 - $354);
 $508 = Math_fround($509 * $505);
 $510 = Math_fround($511 * $506);
 $512 = Math_fround($508 + $510);
 $513 = Math_fround($514 * $507);
 $515 = Math_fround($512 + $513);
 $516 = $515 < Math_fround(0.0);
 if ($516) {
  $517 = Math_fround(-$509);
  $518 = Math_fround(-$511);
  $519 = Math_fround(-$514);
  $520 = $517;$522 = $518;$524 = $519;
 } else {
  $520 = $509;$522 = $511;$524 = $514;
 }
 HEAPF32[$sepAxis>>2] = $520;
 $521 = (($sepAxis) + 4|0);
 HEAPF32[$521>>2] = $522;
 $523 = (($sepAxis) + 8|0);
 HEAPF32[$523>>2] = $524;
 $525 = Math_fround(HEAPF32[$contactDistance>>2]);
 __ZL21PxcGenerateVFContactsRN5physx2Gu13ContactBufferERKNS0_7SegmentEfRKNS0_3BoxERKNS_6PxVec3Ef($contactBuffer,$worldSegment,$323,$worldBox,$sepAxis,$525);
 $526 = (($contactBuffer) + 4096|0);
 $527 = HEAP32[$526>>2]|0;
 $528 = ($527|0)==(2);
 if ($528) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $529 = Math_fround(HEAPF32[$42>>2]);
 $530 = (__ZN5physx2Gu11getBoxEdgesEv()|0);
 $531 = (($worldBox) + 12|0);
 $532 = (($worldBox) + 24|0);
 __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($Pts$i,$103,$104,$worldBox,$531,$532);
 $533 = Math_fround(HEAPF32[$worldSegment>>2]);
 HEAPF32[$s0$i12>>2] = $533;
 $534 = (($s0$i12) + 4|0);
 $535 = Math_fround(HEAPF32[$34>>2]);
 HEAPF32[$534>>2] = $535;
 $536 = (($s0$i12) + 8|0);
 $537 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$536>>2] = $537;
 $538 = Math_fround(HEAPF32[$39>>2]);
 HEAPF32[$s1$i13>>2] = $538;
 $539 = (($s1$i13) + 4|0);
 $540 = Math_fround(HEAPF32[$40>>2]);
 HEAPF32[$539>>2] = $540;
 $541 = (($s1$i13) + 8|0);
 $542 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$541>>2] = $542;
 $543 = Math_fround($538 - $533);
 $544 = Math_fround($540 - $535);
 $545 = Math_fround($542 - $537);
 $546 = Math_fround($543 * $543);
 $547 = Math_fround($544 * $544);
 $548 = Math_fround($546 + $547);
 $549 = Math_fround($545 * $545);
 $550 = Math_fround($548 + $549);
 $551 = (Math_fround(Math_sqrt((Math_fround($550)))));
 $552 = $551 > Math_fround(0.0);
 if ($552) {
  $553 = Math_fround(Math_fround(0.00999999977648258209228) / $551);
  $554 = Math_fround($543 * $553);
  $555 = Math_fround($544 * $553);
  $556 = Math_fround($545 * $553);
  $557 = Math_fround($533 - $554);
  HEAPF32[$s0$i12>>2] = $557;
  $558 = Math_fround($535 - $555);
  HEAPF32[$534>>2] = $558;
  $559 = Math_fround($537 - $556);
  HEAPF32[$536>>2] = $559;
  $560 = Math_fround($538 + $554);
  HEAPF32[$s1$i13>>2] = $560;
  $561 = Math_fround($540 + $555);
  HEAPF32[$539>>2] = $561;
  $562 = Math_fround($542 + $556);
  HEAPF32[$541>>2] = $562;
  $564 = $557;$565 = $560;$567 = $558;$568 = $561;$570 = $559;$571 = $562;
 } else {
  $564 = $533;$565 = $538;$567 = $535;$568 = $540;$570 = $537;$571 = $542;
 }
 $563 = Math_fround($565 - $564);
 $566 = Math_fround($568 - $567);
 $569 = Math_fround($571 - $570);
 HEAPF32[$v1$i14>>2] = $563;
 $572 = (($v1$i14) + 4|0);
 HEAPF32[$572>>2] = $566;
 $573 = (($v1$i14) + 8|0);
 HEAPF32[$573>>2] = $569;
 $574 = Math_fround(HEAPF32[$523>>2]);
 $575 = Math_fround($566 * $574);
 $576 = Math_fround(HEAPF32[$521>>2]);
 $577 = Math_fround($569 * $576);
 $578 = Math_fround($575 - $577);
 $579 = Math_fround(HEAPF32[$sepAxis>>2]);
 $580 = Math_fround($569 * $579);
 $581 = Math_fround($574 * $563);
 $582 = Math_fround($580 - $581);
 $583 = Math_fround($563 * $576);
 $584 = Math_fround($566 * $579);
 $585 = Math_fround($583 - $584);
 HEAPF32[$plane$i15>>2] = $578;
 $586 = (($plane$i15) + 4|0);
 HEAPF32[$586>>2] = $582;
 $587 = (($plane$i15) + 8|0);
 HEAPF32[$587>>2] = $585;
 $588 = Math_fround($564 * $578);
 $589 = Math_fround($567 * $582);
 $590 = Math_fround($588 + $589);
 $591 = Math_fround($570 * $585);
 $592 = Math_fround($591 + $590);
 $593 = Math_fround(-$592);
 $594 = (($plane$i15) + 12|0);
 HEAPF32[$594>>2] = $593;
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($578)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($582)))));
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($585)))));
 $595 = $fabsf$i$i1$i$i > $fabsf$i$i$i$i;
 $596 = $fabsf$i$i1$i$i > $fabsf$i$i2$i$i;
 $or$cond$i$i = $595 & $596;
 if ($or$cond$i$i) {
  $599 = 2;$602 = 0;
 } else {
  $597 = $fabsf$i$i2$i$i > $fabsf$i$i$i$i;
  if ($597) {
   $599 = 0;$602 = 1;
  } else {
   $599 = 1;$602 = 2;
  }
 }
 $598 = (($v1$i14) + ($599<<2)|0);
 $600 = Math_fround(HEAPF32[$598>>2]);
 $601 = (($sepAxis) + ($602<<2)|0);
 $603 = Math_fround(HEAPF32[$601>>2]);
 $604 = Math_fround($600 * $603);
 $605 = (($v1$i14) + ($602<<2)|0);
 $606 = Math_fround(HEAPF32[$605>>2]);
 $607 = (($sepAxis) + ($599<<2)|0);
 $608 = Math_fround(HEAPF32[$607>>2]);
 $609 = Math_fround($606 * $608);
 $610 = Math_fround($604 - $609);
 $611 = Math_fround(Math_fround(1.0) / $610);
 $612 = (($ip$i17) + 8|0);
 $613 = (($ip$i17) + 4|0);
 $Indices$013$i = $530;$i$012$i = 0;
 while(1) {
  $614 = (($Indices$013$i) + 1|0);
  $615 = HEAP8[$Indices$013$i>>0]|0;
  $616 = $615&255;
  $617 = (($Indices$013$i) + 2|0);
  $618 = HEAP8[$614>>0]|0;
  $619 = $618&255;
  $$idx$i = (($Pts$i) + (($616*12)|0)|0);
  $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
  $$idx1$i = ((($Pts$i) + (($616*12)|0)|0) + 4|0);
  $$idx1$val$i = Math_fround(HEAPF32[$$idx1$i>>2]);
  $$idx2$i = ((($Pts$i) + (($616*12)|0)|0) + 8|0);
  $$idx2$val$i = Math_fround(HEAPF32[$$idx2$i>>2]);
  $$idx3$i = (($Pts$i) + (($619*12)|0)|0);
  $$idx3$val$i = Math_fround(HEAPF32[$$idx3$i>>2]);
  $$idx4$i = ((($Pts$i) + (($619*12)|0)|0) + 4|0);
  $$idx4$val$i = Math_fround(HEAPF32[$$idx4$i>>2]);
  $$idx5$i = ((($Pts$i) + (($619*12)|0)|0) + 8|0);
  $$idx5$val$i = Math_fround(HEAPF32[$$idx5$i>>2]);
  $620 = (__ZL22intersectEdgeEdgePrecaRKN5physx6PxVec3ES2_S2_RKNS_7PxPlaneEjjfS2_S2_S2_RfRS0_($s0$i12,$s1$i13,$v1$i14,$plane$i15,$599,$602,$611,$sepAxis,$$idx$val$i,$$idx1$val$i,$$idx2$val$i,$$idx3$val$i,$$idx4$val$i,$$idx5$val$i,$dist$i16,$ip$i17)|0);
  if ($620) {
   $621 = Math_fround(HEAPF32[$dist$i16>>2]);
   $622 = HEAP32[$526>>2]|0;
   $623 = ($622>>>0)>(63);
   if (!($623)) {
    $624 = Math_fround(HEAPF32[$523>>2]);
    $625 = Math_fround(HEAPF32[$521>>2]);
    $626 = Math_fround(HEAPF32[$sepAxis>>2]);
    $627 = Math_fround($529 + $621);
    $628 = Math_fround(HEAPF32[$612>>2]);
    $629 = Math_fround(HEAPF32[$613>>2]);
    $630 = Math_fround(HEAPF32[$ip$i17>>2]);
    $631 = Math_fround($621 * $624);
    $632 = Math_fround($621 * $625);
    $633 = Math_fround($621 * $626);
    $634 = Math_fround(-$627);
    $635 = Math_fround($628 - $631);
    $636 = Math_fround($629 - $632);
    $637 = Math_fround($630 - $633);
    $638 = (($622) + 1)|0;
    HEAP32[$526>>2] = $638;
    $639 = (($contactBuffer) + ($622<<6)|0);
    HEAPF32[$639>>2] = $626;
    $640 = ((($contactBuffer) + ($622<<6)|0) + 4|0);
    HEAPF32[$640>>2] = $625;
    $641 = ((($contactBuffer) + ($622<<6)|0) + 8|0);
    HEAPF32[$641>>2] = $624;
    $642 = ((($contactBuffer) + ($622<<6)|0) + 16|0);
    HEAPF32[$642>>2] = $637;
    $643 = ((($contactBuffer) + ($622<<6)|0) + 20|0);
    HEAPF32[$643>>2] = $636;
    $644 = ((($contactBuffer) + ($622<<6)|0) + 24|0);
    HEAPF32[$644>>2] = $635;
    $645 = ((($contactBuffer) + ($622<<6)|0) + 12|0);
    HEAPF32[$645>>2] = $634;
    $646 = ((($contactBuffer) + ($622<<6)|0) + 48|0);
    HEAP32[$646>>2] = -1;
    $647 = ((($contactBuffer) + ($622<<6)|0) + 52|0);
    HEAP32[$647>>2] = -1;
   }
  }
  $648 = (($i$012$i) + 1)|0;
  $exitcond$i = ($648|0)==(12);
  if ($exitcond$i) {
   break;
  } else {
   $Indices$013$i = $617;$i$012$i = $648;
  }
 }
 $649 = HEAP32[$526>>2]|0;
 $650 = ($649|0)==(0);
 if (!($650)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $651 = Math_fround(HEAPF32[$worldSegment>>2]);
 $652 = Math_fround(HEAPF32[$39>>2]);
 $653 = Math_fround($651 + $652);
 $654 = Math_fround(HEAPF32[$34>>2]);
 $655 = Math_fround(HEAPF32[$40>>2]);
 $656 = Math_fround($654 + $655);
 $657 = Math_fround(HEAPF32[$35>>2]);
 $658 = Math_fround(HEAPF32[$41>>2]);
 $659 = Math_fround($657 + $658);
 $660 = Math_fround($653 * Math_fround(0.5));
 $661 = Math_fround($656 * Math_fround(0.5));
 $662 = Math_fround($659 * Math_fround(0.5));
 $663 = Math_fround(HEAPF32[$42>>2]);
 $664 = Math_fround($PenDepth$3$i + $663);
 $665 = Math_fround(-$664);
 HEAP32[$526>>2] = 1;
 $666 = Math_fround(HEAPF32[$sepAxis>>2]);
 HEAPF32[$contactBuffer>>2] = $666;
 $667 = Math_fround(HEAPF32[$521>>2]);
 $668 = (($contactBuffer) + 4|0);
 HEAPF32[$668>>2] = $667;
 $669 = Math_fround(HEAPF32[$523>>2]);
 $670 = (($contactBuffer) + 8|0);
 HEAPF32[$670>>2] = $669;
 $671 = (($contactBuffer) + 16|0);
 HEAPF32[$671>>2] = $660;
 $672 = (($contactBuffer) + 20|0);
 HEAPF32[$672>>2] = $661;
 $673 = (($contactBuffer) + 24|0);
 HEAPF32[$673>>2] = $662;
 $674 = (($contactBuffer) + 12|0);
 HEAPF32[$674>>2] = $665;
 $675 = (($contactBuffer) + 48|0);
 HEAP32[$675>>2] = -1;
 $676 = (($contactBuffer) + 52|0);
 HEAP32[$676>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL21PxcGenerateVFContactsRN5physx2Gu13ContactBufferERKNS0_7SegmentEfRKNS0_3BoxERKNS_6PxVec3Ef($contactBuffer,$segment,$radius,$worldBox,$normal,$contactDistance) {
 $contactBuffer = $contactBuffer|0;
 $segment = $segment|0;
 $radius = Math_fround($radius);
 $worldBox = $worldBox|0;
 $normal = $normal|0;
 $contactDistance = Math_fround($contactDistance);
 var $$pre = Math_fround(0), $$pre13 = Math_fround(0), $$pre14 = Math_fround(0), $$pre15 = Math_fround(0), $$pre16 = Math_fround(0), $$pre17 = Math_fround(0), $$pre18 = Math_fround(0), $$pre19 = Math_fround(0), $$pre20 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0;
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $Max = 0, $Min = 0, $exitcond = 0, $i$012 = 0;
 var $normal$idx$val = Math_fround(0), $normal$idx1$val = Math_fround(0), $normal$idx2$val = Math_fround(0), $tfar = 0, $tmp = 0, $tmp2 = 0, $tnear = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $Max = sp + 44|0;
 $Min = sp;
 $tmp2 = sp + 12|0;
 $tmp = sp + 24|0;
 $tnear = sp + 36|0;
 $tfar = sp + 40|0;
 $0 = (($worldBox) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$Max>>2] = $1;
 $2 = (($Max) + 4|0);
 $3 = (($worldBox) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($Max) + 8|0);
 $6 = (($worldBox) + 56|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 $8 = Math_fround(-$1);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$7);
 HEAPF32[$Min>>2] = $8;
 $11 = (($Min) + 4|0);
 HEAPF32[$11>>2] = $9;
 $12 = (($Min) + 8|0);
 HEAPF32[$12>>2] = $10;
 $13 = Math_fround(HEAPF32[$worldBox>>2]);
 $14 = Math_fround(HEAPF32[$normal>>2]);
 $15 = Math_fround($13 * $14);
 $16 = (($worldBox) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($normal) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = Math_fround($15 + $20);
 $22 = (($worldBox) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($normal) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 * $25);
 $27 = Math_fround($21 + $26);
 $28 = (($worldBox) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($14 * $29);
 $31 = (($worldBox) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($19 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($worldBox) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($25 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($worldBox) + 24|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($14 * $40);
 $42 = (($worldBox) + 28|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($19 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($worldBox) + 32|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($25 * $47);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround(-$27);
 $51 = Math_fround(-$38);
 $52 = Math_fround(-$49);
 HEAPF32[$tmp2>>2] = $50;
 $53 = (($tmp2) + 4|0);
 HEAPF32[$53>>2] = $51;
 $54 = (($tmp2) + 8|0);
 HEAPF32[$54>>2] = $52;
 $55 = (($worldBox) + 36|0);
 $56 = (($worldBox) + 40|0);
 $57 = (($worldBox) + 44|0);
 $58 = (($tmp) + 4|0);
 $59 = (($tmp) + 8|0);
 $60 = Math_fround($radius + $contactDistance);
 $61 = (($contactBuffer) + 4096|0);
 $75 = $13;$77 = $17;$80 = $23;$83 = $29;$85 = $32;$88 = $36;$91 = $40;$93 = $43;$96 = $47;$i$012 = 0;
 while(1) {
  $62 = (($segment) + (($i$012*12)|0)|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround(HEAPF32[$55>>2]);
  $65 = Math_fround($63 - $64);
  $66 = ((($segment) + (($i$012*12)|0)|0) + 4|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround(HEAPF32[$56>>2]);
  $69 = Math_fround($67 - $68);
  $70 = ((($segment) + (($i$012*12)|0)|0) + 8|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = Math_fround(HEAPF32[$57>>2]);
  $73 = Math_fround($71 - $72);
  $74 = Math_fround($65 * $75);
  $76 = Math_fround($69 * $77);
  $78 = Math_fround($74 + $76);
  $79 = Math_fround($73 * $80);
  $81 = Math_fround($78 + $79);
  $82 = Math_fround($65 * $83);
  $84 = Math_fround($69 * $85);
  $86 = Math_fround($82 + $84);
  $87 = Math_fround($73 * $88);
  $89 = Math_fround($86 + $87);
  $90 = Math_fround($65 * $91);
  $92 = Math_fround($69 * $93);
  $94 = Math_fround($90 + $92);
  $95 = Math_fround($73 * $96);
  $97 = Math_fround($94 + $95);
  HEAPF32[$tmp>>2] = $81;
  HEAPF32[$58>>2] = $89;
  HEAPF32[$59>>2] = $97;
  $98 = (__ZN5physx2Gu16intersectRayAABBERKNS_6PxVec3ES3_S3_S3_RfS4_($Min,$Max,$tmp,$tmp2,$tnear,$tfar)|0);
  $99 = ($98|0)==(-1);
  if (!($99)) {
   $100 = Math_fround(HEAPF32[$tnear>>2]);
   $101 = $100 < $60;
   if ($101) {
    $102 = HEAP32[$61>>2]|0;
    $103 = ($102>>>0)>(63);
    if (!($103)) {
     $normal$idx2$val = Math_fround(HEAPF32[$24>>2]);
     $normal$idx1$val = Math_fround(HEAPF32[$18>>2]);
     $normal$idx$val = Math_fround(HEAPF32[$normal>>2]);
     $104 = Math_fround(HEAPF32[$70>>2]);
     $105 = Math_fround(HEAPF32[$66>>2]);
     $106 = Math_fround(HEAPF32[$62>>2]);
     $107 = Math_fround($100 * $normal$idx2$val);
     $108 = Math_fround($100 * $normal$idx1$val);
     $109 = Math_fround($100 * $normal$idx$val);
     $110 = Math_fround($100 - $radius);
     $111 = Math_fround($104 - $107);
     $112 = Math_fround($105 - $108);
     $113 = Math_fround($106 - $109);
     $114 = (($102) + 1)|0;
     HEAP32[$61>>2] = $114;
     $115 = (($contactBuffer) + ($102<<6)|0);
     HEAPF32[$115>>2] = $normal$idx$val;
     $116 = Math_fround(HEAPF32[$18>>2]);
     $117 = ((($contactBuffer) + ($102<<6)|0) + 4|0);
     HEAPF32[$117>>2] = $116;
     $118 = Math_fround(HEAPF32[$24>>2]);
     $119 = ((($contactBuffer) + ($102<<6)|0) + 8|0);
     HEAPF32[$119>>2] = $118;
     $120 = ((($contactBuffer) + ($102<<6)|0) + 16|0);
     HEAPF32[$120>>2] = $113;
     $121 = ((($contactBuffer) + ($102<<6)|0) + 20|0);
     HEAPF32[$121>>2] = $112;
     $122 = ((($contactBuffer) + ($102<<6)|0) + 24|0);
     HEAPF32[$122>>2] = $111;
     $123 = ((($contactBuffer) + ($102<<6)|0) + 12|0);
     HEAPF32[$123>>2] = $110;
     $124 = ((($contactBuffer) + ($102<<6)|0) + 48|0);
     HEAP32[$124>>2] = -1;
     $125 = ((($contactBuffer) + ($102<<6)|0) + 52|0);
     HEAP32[$125>>2] = -1;
    }
   }
  }
  $126 = (($i$012) + 1)|0;
  $exitcond = ($126|0)==(2);
  if ($exitcond) {
   break;
  }
  $$pre = Math_fround(HEAPF32[$worldBox>>2]);
  $$pre13 = Math_fround(HEAPF32[$16>>2]);
  $$pre14 = Math_fround(HEAPF32[$22>>2]);
  $$pre15 = Math_fround(HEAPF32[$28>>2]);
  $$pre16 = Math_fround(HEAPF32[$31>>2]);
  $$pre17 = Math_fround(HEAPF32[$35>>2]);
  $$pre18 = Math_fround(HEAPF32[$39>>2]);
  $$pre19 = Math_fround(HEAPF32[$42>>2]);
  $$pre20 = Math_fround(HEAPF32[$46>>2]);
  $75 = $$pre;$77 = $$pre13;$80 = $$pre14;$83 = $$pre15;$85 = $$pre16;$88 = $$pre17;$91 = $$pre18;$93 = $$pre19;$96 = $$pre20;$i$012 = $126;
 }
 STACKTOP = sp;return;
}
function __ZL22intersectEdgeEdgePrecaRKN5physx6PxVec3ES2_S2_RKNS_7PxPlaneEjjfS2_S2_S2_RfRS0_($p1,$p2,$v1,$plane,$i,$j,$coeff,$dir,$p3$0$0$val,$p3$0$1$val,$p3$0$2$val,$p4$0$0$val,$p4$0$1$val,$p4$0$2$val,$dist,$ip) {
 $p1 = $p1|0;
 $p2 = $p2|0;
 $v1 = $v1|0;
 $plane = $plane|0;
 $i = $i|0;
 $j = $j|0;
 $coeff = Math_fround($coeff);
 $dir = $dir|0;
 $p3$0$0$val = Math_fround($p3$0$0$val);
 $p3$0$1$val = Math_fround($p3$0$1$val);
 $p3$0$2$val = Math_fround($p3$0$2$val);
 $p4$0$0$val = Math_fround($p4$0$0$val);
 $p4$0$1$val = Math_fround($p4$0$1$val);
 $p4$0$2$val = Math_fround($p4$0$2$val);
 $dist = $dist|0;
 $ip = $ip|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $9 = Math_fround(0), $dir$idx$val = Math_fround(0), $dir$idx1 = 0, $dir$idx1$val = Math_fround(0), $dir$idx2 = 0, $dir$idx2$val = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$plane>>2]);
 $1 = Math_fround($0 * $p3$0$0$val);
 $2 = (($plane) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $p3$0$1$val);
 $5 = Math_fround($1 + $4);
 $6 = (($plane) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $p3$0$2$val);
 $9 = Math_fround($5 + $8);
 $10 = (($plane) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 + $9);
 $13 = Math_fround($0 * $p4$0$0$val);
 $14 = Math_fround($3 * $p4$0$1$val);
 $15 = Math_fround($13 + $14);
 $16 = Math_fround($7 * $p4$0$2$val);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($11 + $17);
 $19 = Math_fround($12 * $18);
 $20 = $19 > Math_fround(0.0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = Math_fround($p4$0$0$val - $p3$0$0$val);
 $22 = Math_fround($p4$0$1$val - $p3$0$1$val);
 $23 = Math_fround($p4$0$2$val - $p3$0$2$val);
 $24 = Math_fround($21 * $0);
 $25 = Math_fround($22 * $3);
 $26 = Math_fround($24 + $25);
 $27 = Math_fround($23 * $7);
 $28 = Math_fround($26 + $27);
 $29 = $28 == Math_fround(0.0);
 if ($29) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = Math_fround($12 / $28);
 $31 = Math_fround($21 * $30);
 $32 = Math_fround($22 * $30);
 $33 = Math_fround($23 * $30);
 $34 = Math_fround($p3$0$0$val - $31);
 $35 = Math_fround($p3$0$1$val - $32);
 $36 = Math_fround($p3$0$2$val - $33);
 HEAPF32[$ip>>2] = $34;
 $37 = (($ip) + 4|0);
 HEAPF32[$37>>2] = $35;
 $38 = (($ip) + 8|0);
 HEAPF32[$38>>2] = $36;
 $39 = (($v1) + ($i<<2)|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($ip) + ($j<<2)|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($p1) + ($j<<2)|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($42 - $44);
 $46 = Math_fround($40 * $45);
 $47 = (($v1) + ($j<<2)|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($ip) + ($i<<2)|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($p1) + ($i<<2)|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($50 - $52);
 $54 = Math_fround($48 * $53);
 $55 = Math_fround($46 - $54);
 $56 = Math_fround($55 * $coeff);
 HEAPF32[$dist>>2] = $56;
 $57 = $56 < Math_fround(0.0);
 if ($57) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $dir$idx$val = Math_fround(HEAPF32[$dir>>2]);
 $dir$idx1 = (($dir) + 4|0);
 $dir$idx1$val = Math_fround(HEAPF32[$dir$idx1>>2]);
 $dir$idx2 = (($dir) + 8|0);
 $dir$idx2$val = Math_fround(HEAPF32[$dir$idx2>>2]);
 $58 = Math_fround($56 * $dir$idx$val);
 $59 = Math_fround($56 * $dir$idx1$val);
 $60 = Math_fround($56 * $dir$idx2$val);
 $61 = Math_fround(HEAPF32[$ip>>2]);
 $62 = Math_fround($61 - $58);
 HEAPF32[$ip>>2] = $62;
 $63 = Math_fround(HEAPF32[$37>>2]);
 $64 = Math_fround($63 - $59);
 HEAPF32[$37>>2] = $64;
 $65 = Math_fround(HEAPF32[$38>>2]);
 $66 = Math_fround($65 - $60);
 HEAPF32[$38>>2] = $66;
 $67 = Math_fround(HEAPF32[$p1>>2]);
 $68 = Math_fround($67 - $62);
 $69 = Math_fround(HEAPF32[$p2>>2]);
 $70 = Math_fround($69 - $62);
 $71 = Math_fround($68 * $70);
 $72 = (($p1) + 4|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 - $64);
 $75 = (($p2) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($76 - $64);
 $78 = Math_fround($74 * $77);
 $79 = Math_fround($71 + $78);
 $80 = (($p1) + 8|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 - $66);
 $83 = (($p2) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 - $66);
 $86 = Math_fround($82 * $85);
 $87 = Math_fround($79 + $86);
 $88 = $87 < Math_fround(0.0);
 $$0 = $88;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx24PxcContactCapsuleCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert57 = 0, $$phi$trans$insert59 = 0, $$phi$trans$insert61 = 0, $$phi$trans$insert63 = 0, $$phi$trans$insert65 = 0, $$pre = Math_fround(0), $$pre58 = Math_fround(0), $$pre60 = Math_fround(0), $$pre62 = Math_fround(0), $$pre64 = Math_fround(0), $$pre66 = Math_fround(0), $$v = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0;
 var $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0);
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0);
 var $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0.0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0;
 var $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0.0, $281 = 0, $282 = 0.0, $283 = 0;
 var $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0);
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0);
 var $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0;
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $destShapeIndex$048 = 0, $dir = 0, $exitcond = 0, $exitcond50 = 0, $fabsf$i$i = Math_fround(0), $numCons$049 = 0;
 var $numCons$147 = 0, $numCons$2 = 0, $or$cond = 0, $pos = 0, $s = 0, $segLen = 0, $segLenEps = 0, $segment = 0, $startEnd$046 = 0, $t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $segment = sp + 72|0;
 $s = sp;
 $t = sp + 4|0;
 $dir = sp + 8|0;
 $segLen = sp + 32|0;
 $segLenEps = sp + 40|0;
 $pos = sp + 48|0;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($transform0) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($transform0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($shape0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = Math_fround($20 * $15);
 $23 = Math_fround($20 * $18);
 HEAPF32[$segment>>2] = $21;
 $24 = (($segment) + 4|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($segment) + 8|0);
 HEAPF32[$25>>2] = $23;
 $26 = Math_fround(-$21);
 $27 = Math_fround(-$22);
 $28 = Math_fround(-$23);
 $29 = (($segment) + 12|0);
 HEAPF32[$29>>2] = $26;
 $30 = (($segment) + 16|0);
 HEAPF32[$30>>2] = $27;
 $31 = (($segment) + 20|0);
 HEAPF32[$31>>2] = $28;
 $32 = (($segment) + 24|0);
 $33 = Math_fround(HEAPF32[$transform1>>2]);
 $34 = Math_fround($33 * Math_fround(2.0));
 $35 = (($transform1) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * Math_fround(2.0));
 $38 = Math_fround($36 * $37);
 $39 = Math_fround($38 + Math_fround(-1.0));
 $40 = Math_fround($33 * $34);
 $41 = Math_fround($40 + $39);
 $42 = (($transform1) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $37);
 $45 = (($transform1) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($34 * $46);
 $48 = Math_fround($44 + $47);
 $49 = Math_fround($37 * $46);
 $50 = Math_fround($34 * $43);
 $51 = Math_fround($50 - $49);
 $52 = (($shape1) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 * $41);
 $55 = Math_fround($53 * $48);
 $56 = Math_fround($53 * $51);
 $57 = (($segment) + 28|0);
 $58 = (($segment) + 32|0);
 $59 = (($segment) + 36|0);
 $60 = (($segment) + 40|0);
 $61 = (($segment) + 44|0);
 $62 = (($transform1) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($transform0) + 16|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($63 - $65);
 $67 = (($transform1) + 20|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($transform0) + 20|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($68 - $70);
 $72 = (($transform1) + 24|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($transform0) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($73 - $75);
 $77 = Math_fround($66 - $54);
 HEAPF32[$59>>2] = $77;
 $78 = Math_fround($71 - $55);
 HEAPF32[$60>>2] = $78;
 $79 = Math_fround($76 - $56);
 HEAPF32[$61>>2] = $79;
 $80 = Math_fround($66 + $54);
 HEAPF32[$32>>2] = $80;
 $81 = Math_fround($71 + $55);
 HEAPF32[$57>>2] = $81;
 $82 = Math_fround($76 + $56);
 HEAPF32[$58>>2] = $82;
 $83 = (Math_fround(__ZN5physx2Gu30distanceSegmentSegmentSquared2ERKNS0_7SegmentES3_PfS4_($segment,$32,$s,$t)));
 $84 = (($shape0) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($shape1) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($85 + $87);
 $89 = Math_fround(HEAPF32[$contactDistance>>2]);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround($90 * $90);
 $92 = $83 < $91;
 if (!($92)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $93 = Math_fround(HEAPF32[$29>>2]);
 $94 = Math_fround(HEAPF32[$segment>>2]);
 $95 = Math_fround($93 - $94);
 $96 = Math_fround(HEAPF32[$30>>2]);
 $97 = Math_fround(HEAPF32[$24>>2]);
 $98 = Math_fround($96 - $97);
 $99 = Math_fround(HEAPF32[$31>>2]);
 $100 = Math_fround(HEAPF32[$25>>2]);
 $101 = Math_fround($99 - $100);
 HEAPF32[$dir>>2] = $95;
 $102 = (($dir) + 4|0);
 HEAPF32[$102>>2] = $98;
 $103 = (($dir) + 8|0);
 HEAPF32[$103>>2] = $101;
 $104 = Math_fround(HEAPF32[$59>>2]);
 $105 = Math_fround(HEAPF32[$32>>2]);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround(HEAPF32[$60>>2]);
 $108 = Math_fround(HEAPF32[$57>>2]);
 $109 = Math_fround($107 - $108);
 $110 = Math_fround(HEAPF32[$61>>2]);
 $111 = Math_fround(HEAPF32[$58>>2]);
 $112 = Math_fround($110 - $111);
 $113 = (($dir) + 12|0);
 HEAPF32[$113>>2] = $106;
 $114 = (($dir) + 16|0);
 HEAPF32[$114>>2] = $109;
 $115 = (($dir) + 20|0);
 HEAPF32[$115>>2] = $112;
 $116 = Math_fround($95 * $95);
 $117 = Math_fround($98 * $98);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($101 * $101);
 $120 = Math_fround($118 + $119);
 $121 = (Math_fround(Math_sqrt((Math_fround($120)))));
 HEAPF32[$segLen>>2] = $121;
 $122 = Math_fround($106 * $106);
 $123 = Math_fround($109 * $109);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($112 * $112);
 $126 = Math_fround($124 + $125);
 $127 = (Math_fround(Math_sqrt((Math_fround($126)))));
 $128 = (($segLen) + 4|0);
 HEAPF32[$128>>2] = $127;
 $129 = $121 != Math_fround(0.0);
 if ($129) {
  $130 = Math_fround(Math_fround(1.0) / $121);
  $131 = Math_fround($130 * $95);
  HEAPF32[$dir>>2] = $131;
  $132 = Math_fround($130 * $98);
  HEAPF32[$102>>2] = $132;
  $133 = Math_fround($130 * $101);
  HEAPF32[$103>>2] = $133;
  $141 = $131;$144 = $132;$148 = $133;
 } else {
  $141 = $95;$144 = $98;$148 = $101;
 }
 $134 = $127 != Math_fround(0.0);
 if ($134) {
  $135 = Math_fround(Math_fround(1.0) / $127);
  $136 = Math_fround($135 * $106);
  HEAPF32[$113>>2] = $136;
  $137 = Math_fround($135 * $109);
  HEAPF32[$114>>2] = $137;
  $138 = Math_fround($135 * $112);
  HEAPF32[$115>>2] = $138;
  $140 = $136;$143 = $137;$147 = $138;
 } else {
  $140 = $106;$143 = $109;$147 = $112;
 }
 $139 = Math_fround($141 * $140);
 $142 = Math_fround($144 * $143);
 $145 = Math_fround($139 + $142);
 $146 = Math_fround($148 * $147);
 $149 = Math_fround($145 + $146);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($149)))));
 $150 = $fabsf$i$i > Math_fround(0.999800026416778564453);
 if ($150) {
  $151 = Math_fround($121 * Math_fround(0.00100000004749745130539));
  HEAPF32[$segLenEps>>2] = $151;
  $152 = Math_fround($127 * Math_fround(0.00100000004749745130539));
  $153 = (($segLenEps) + 4|0);
  HEAPF32[$153>>2] = $152;
  $154 = (($pos) + 12|0);
  $155 = (($pos) + 16|0);
  $156 = (($pos) + 4|0);
  $157 = (($pos) + 20|0);
  $158 = (($pos) + 8|0);
  $159 = (($contactBuffer) + 4096|0);
  $169 = $151;$184 = $94;$186 = $97;$188 = $100;$191 = $144;$194 = $148;$destShapeIndex$048 = 0;$numCons$049 = 0;
  while(1) {
   $160 = (1 - ($destShapeIndex$048))|0;
   $161 = ((($segment) + (($160*24)|0)|0) + 12|0);
   $162 = (($segment) + (($160*24)|0)|0);
   $163 = (($pos) + (($destShapeIndex$048*12)|0)|0);
   $164 = ((($pos) + (($destShapeIndex$048*12)|0)|0) + 4|0);
   $165 = ((($pos) + (($destShapeIndex$048*12)|0)|0) + 8|0);
   $166 = (($dir) + (($destShapeIndex$048*12)|0)|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = Math_fround(-$169);
   $170 = (($segLen) + ($destShapeIndex$048<<2)|0);
   $171 = (($pos) + (($160*12)|0)|0);
   $172 = ((($pos) + (($160*12)|0)|0) + 4|0);
   $173 = ((($pos) + (($160*12)|0)|0) + 8|0);
   $174 = ($destShapeIndex$048|0)!=(1);
   $$v = $174 ? $shape1 : $shape0;
   $175 = (($$v) + 4|0);
   $numCons$147 = $numCons$049;$startEnd$046 = 0;
   while(1) {
    $176 = ($startEnd$046|0)!=(0);
    $177 = $176 ? $161 : $162;
    $178 = Math_fround(HEAPF32[$177>>2]);
    HEAPF32[$163>>2] = $178;
    $179 = (($177) + 4|0);
    $180 = Math_fround(HEAPF32[$179>>2]);
    HEAPF32[$164>>2] = $180;
    $181 = (($177) + 8|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    HEAPF32[$165>>2] = $182;
    $183 = Math_fround($178 - $184);
    $185 = Math_fround($180 - $186);
    $187 = Math_fround($182 - $188);
    $189 = Math_fround($183 * $167);
    $190 = Math_fround($185 * $191);
    $192 = Math_fround($189 + $190);
    $193 = Math_fround($187 * $194);
    $195 = Math_fround($192 + $193);
    $196 = !($195 >= $168);
    if ($196) {
     $numCons$2 = $numCons$147;
    } else {
     $197 = Math_fround(HEAPF32[$170>>2]);
     $198 = Math_fround($169 + $197);
     $199 = !($195 <= $198);
     if ($199) {
      $numCons$2 = $numCons$147;
     } else {
      $200 = Math_fround($195 * $167);
      $201 = Math_fround($195 * $191);
      $202 = Math_fround($195 * $194);
      $203 = Math_fround($184 + $200);
      $204 = Math_fround($186 + $201);
      $205 = Math_fround($188 + $202);
      HEAPF32[$171>>2] = $203;
      HEAPF32[$172>>2] = $204;
      HEAPF32[$173>>2] = $205;
      $206 = Math_fround(HEAPF32[$154>>2]);
      $207 = Math_fround(HEAPF32[$pos>>2]);
      $208 = Math_fround($206 - $207);
      $209 = Math_fround(HEAPF32[$155>>2]);
      $210 = Math_fround(HEAPF32[$156>>2]);
      $211 = Math_fround($209 - $210);
      $212 = Math_fround(HEAPF32[$157>>2]);
      $213 = Math_fround(HEAPF32[$158>>2]);
      $214 = Math_fround($212 - $213);
      $215 = Math_fround($208 * $208);
      $216 = Math_fround($211 * $211);
      $217 = Math_fround($215 + $216);
      $218 = Math_fround($214 * $214);
      $219 = Math_fround($217 + $218);
      $220 = +$219;
      $221 = $220 > 9.99999999999999954748E-7;
      $222 = $219 < $91;
      $or$cond = $221 & $222;
      if ($or$cond) {
       $223 = (Math_fround(Math_sqrt((Math_fround($219)))));
       $224 = Math_fround(Math_fround(1.0) / $223);
       $225 = Math_fround($208 * $224);
       $226 = Math_fround($211 * $224);
       $227 = Math_fround($214 * $224);
       $228 = Math_fround(HEAPF32[$175>>2]);
       $229 = HEAP32[$159>>2]|0;
       $230 = ($229>>>0)>(63);
       if (!($230)) {
        $231 = Math_fround($227 * $228);
        $232 = Math_fround($226 * $228);
        $233 = Math_fround($225 * $228);
        $234 = Math_fround(HEAPF32[$74>>2]);
        $235 = Math_fround(HEAPF32[$69>>2]);
        $236 = Math_fround(HEAPF32[$64>>2]);
        $237 = Math_fround($212 - $231);
        $238 = Math_fround($209 - $232);
        $239 = Math_fround($206 - $233);
        $240 = Math_fround($223 - $88);
        $241 = Math_fround($237 + $234);
        $242 = Math_fround($238 + $235);
        $243 = Math_fround($239 + $236);
        $244 = (($229) + 1)|0;
        HEAP32[$159>>2] = $244;
        $245 = (($contactBuffer) + ($229<<6)|0);
        HEAPF32[$245>>2] = $225;
        $246 = ((($contactBuffer) + ($229<<6)|0) + 4|0);
        HEAPF32[$246>>2] = $226;
        $247 = ((($contactBuffer) + ($229<<6)|0) + 8|0);
        HEAPF32[$247>>2] = $227;
        $248 = ((($contactBuffer) + ($229<<6)|0) + 16|0);
        HEAPF32[$248>>2] = $243;
        $249 = ((($contactBuffer) + ($229<<6)|0) + 20|0);
        HEAPF32[$249>>2] = $242;
        $250 = ((($contactBuffer) + ($229<<6)|0) + 24|0);
        HEAPF32[$250>>2] = $241;
        $251 = ((($contactBuffer) + ($229<<6)|0) + 12|0);
        HEAPF32[$251>>2] = $240;
        $252 = ((($contactBuffer) + ($229<<6)|0) + 48|0);
        HEAP32[$252>>2] = -1;
        $253 = ((($contactBuffer) + ($229<<6)|0) + 52|0);
        HEAP32[$253>>2] = -1;
       }
       $254 = (($numCons$147) + 1)|0;
       $numCons$2 = $254;
      } else {
       $numCons$2 = $numCons$147;
      }
     }
    }
    $255 = (($startEnd$046) + 1)|0;
    $exitcond = ($255|0)==(2);
    if ($exitcond) {
     break;
    } else {
     $numCons$147 = $numCons$2;$startEnd$046 = $255;
    }
   }
   $256 = (($destShapeIndex$048) + 1)|0;
   $exitcond50 = ($256|0)==(2);
   if ($exitcond50) {
    break;
   }
   $$phi$trans$insert = (($segment) + (($256*24)|0)|0);
   $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
   $$phi$trans$insert57 = ((($segment) + (($256*24)|0)|0) + 4|0);
   $$pre58 = Math_fround(HEAPF32[$$phi$trans$insert57>>2]);
   $$phi$trans$insert59 = ((($segment) + (($256*24)|0)|0) + 8|0);
   $$pre60 = Math_fround(HEAPF32[$$phi$trans$insert59>>2]);
   $$phi$trans$insert61 = ((($dir) + (($256*12)|0)|0) + 4|0);
   $$pre62 = Math_fround(HEAPF32[$$phi$trans$insert61>>2]);
   $$phi$trans$insert63 = ((($dir) + (($256*12)|0)|0) + 8|0);
   $$pre64 = Math_fround(HEAPF32[$$phi$trans$insert63>>2]);
   $$phi$trans$insert65 = (($segLenEps) + ($256<<2)|0);
   $$pre66 = Math_fround(HEAPF32[$$phi$trans$insert65>>2]);
   $169 = $$pre66;$184 = $$pre;$186 = $$pre58;$188 = $$pre60;$191 = $$pre62;$194 = $$pre64;$destShapeIndex$048 = $256;$numCons$049 = $numCons$2;
  }
  $257 = ($numCons$2|0)==(0);
  if (!($257)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $258 = Math_fround(HEAPF32[$s>>2]);
 $259 = Math_fround($258 * $95);
 $260 = Math_fround($258 * $98);
 $261 = Math_fround($258 * $101);
 $262 = Math_fround($94 + $259);
 $263 = Math_fround($97 + $260);
 $264 = Math_fround($100 + $261);
 $265 = Math_fround(HEAPF32[$t>>2]);
 $266 = Math_fround($265 * $106);
 $267 = Math_fround($265 * $109);
 $268 = Math_fround($265 * $112);
 $269 = Math_fround($105 + $266);
 $270 = Math_fround($108 + $267);
 $271 = Math_fround($111 + $268);
 $272 = Math_fround($262 - $269);
 $273 = Math_fround($263 - $270);
 $274 = Math_fround($264 - $271);
 $275 = Math_fround($272 * $272);
 $276 = Math_fround($273 * $273);
 $277 = Math_fround($275 + $276);
 $278 = Math_fround($274 * $274);
 $279 = Math_fround($277 + $278);
 $280 = +$279;
 $281 = $280 < 9.99999999999999954748E-7;
 if ($281) {
  $282 = +$121;
  $283 = $282 > 9.99999999999999954748E-7;
  if ($283) {
   $298 = $148;$300 = $144;$302 = $141;
  } else {
   $298 = Math_fround(0.0);$300 = Math_fround(0.0);$302 = Math_fround(1.0);
  }
 } else {
  $284 = (Math_fround(Math_sqrt((Math_fround($279)))));
  $285 = Math_fround(Math_fround(1.0) / $284);
  $286 = Math_fround($272 * $285);
  $287 = Math_fround($273 * $285);
  $288 = Math_fround($274 * $285);
  $298 = $288;$300 = $287;$302 = $286;
 }
 $289 = Math_fround(HEAPF32[$84>>2]);
 $290 = (($contactBuffer) + 4096|0);
 $291 = HEAP32[$290>>2]|0;
 $292 = ($291>>>0)>(63);
 if ($292) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $293 = Math_fround(HEAPF32[$74>>2]);
 $294 = Math_fround(HEAPF32[$69>>2]);
 $295 = Math_fround(HEAPF32[$64>>2]);
 $296 = (Math_fround(Math_sqrt((Math_fround($83)))));
 $297 = Math_fround($298 * $289);
 $299 = Math_fround($300 * $289);
 $301 = Math_fround($302 * $289);
 $303 = Math_fround($264 + $293);
 $304 = Math_fround($263 + $294);
 $305 = Math_fround($262 + $295);
 $306 = Math_fround($296 - $88);
 $307 = Math_fround($303 - $297);
 $308 = Math_fround($304 - $299);
 $309 = Math_fround($305 - $301);
 $310 = (($291) + 1)|0;
 HEAP32[$290>>2] = $310;
 $311 = (($contactBuffer) + ($291<<6)|0);
 HEAPF32[$311>>2] = $302;
 $312 = ((($contactBuffer) + ($291<<6)|0) + 4|0);
 HEAPF32[$312>>2] = $300;
 $313 = ((($contactBuffer) + ($291<<6)|0) + 8|0);
 HEAPF32[$313>>2] = $298;
 $314 = ((($contactBuffer) + ($291<<6)|0) + 16|0);
 HEAPF32[$314>>2] = $309;
 $315 = ((($contactBuffer) + ($291<<6)|0) + 20|0);
 HEAPF32[$315>>2] = $308;
 $316 = ((($contactBuffer) + ($291<<6)|0) + 24|0);
 HEAPF32[$316>>2] = $307;
 $317 = ((($contactBuffer) + ($291<<6)|0) + 12|0);
 HEAPF32[$317>>2] = $306;
 $318 = ((($contactBuffer) + ($291<<6)|0) + 48|0);
 HEAP32[$318>>2] = -1;
 $319 = ((($contactBuffer) + ($291<<6)|0) + 52|0);
 HEAP32[$319>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx23PxcContactCapsuleConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$1 = 0, $$in$i = 0, $$lcssa29$i = Math_fround(0), $$lcssa31$i = Math_fround(0), $$lcssa33$i = Math_fround(0), $$pre$i = Math_fround(0), $$pre51$i = Math_fround(0), $$pre52$i = Math_fround(0), $$pre53$i = Math_fround(0), $$pre54$i = Math_fround(0), $$pre55$i = Math_fround(0), $$pre56$i = Math_fround(0), $$pre57$i = Math_fround(0), $$pre58$i = Math_fround(0), $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0);
 var $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = 0, $1007 = 0, $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0);
 var $1019 = Math_fround(0), $102 = Math_fround(0), $1020 = 0, $1021 = 0, $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = 0, $1029 = 0, $103 = Math_fround(0), $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = Math_fround(0), $1035 = 0, $1036 = 0;
 var $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = 0, $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = 0, $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = 0, $1047 = 0, $1048 = 0, $1049 = Math_fround(0), $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0;
 var $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = 0, $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0);
 var $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = 0, $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = Math_fround(0), $1090 = Math_fround(0);
 var $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0);
 var $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0);
 var $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0), $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = 0, $1133 = 0, $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = 0, $1139 = Math_fround(0), $114 = Math_fround(0), $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0);
 var $1145 = Math_fround(0), $1146 = 0, $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = Math_fround(0), $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = Math_fround(0);
 var $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0), $1169 = Math_fround(0), $117 = Math_fround(0), $1170 = Math_fround(0), $1171 = Math_fround(0), $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = Math_fround(0), $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = Math_fround(0), $1180 = Math_fround(0);
 var $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0), $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = Math_fround(0), $1188 = Math_fround(0), $1189 = 0, $119 = Math_fround(0), $1190 = Math_fround(0), $1191 = 0, $1192 = 0, $1193 = Math_fround(0), $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = Math_fround(0), $1197 = Math_fround(0), $1198 = Math_fround(0), $1199 = Math_fround(0);
 var $12 = Math_fround(0), $120 = Math_fround(0), $1200 = Math_fround(0), $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = Math_fround(0), $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = 0, $1208 = 0, $1209 = 0, $121 = Math_fround(0), $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0;
 var $1217 = 0, $1218 = Math_fround(0), $1219 = Math_fround(0), $122 = Math_fround(0), $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = Math_fround(0), $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = Math_fround(0), $1229 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0);
 var $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0);
 var $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0);
 var $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = 0, $362 = 0;
 var $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0);
 var $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0);
 var $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0);
 var $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0);
 var $471 = Math_fround(0), $472 = 0, $473 = 0, $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = 0, $489 = Math_fround(0);
 var $49 = 0, $490 = Math_fround(0), $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0;
 var $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = Math_fround(0), $515 = 0, $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = 0, $522 = 0, $523 = 0, $524 = 0;
 var $525 = 0, $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0);
 var $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0);
 var $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0);
 var $58 = Math_fround(0), $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = 0, $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0);
 var $598 = Math_fround(0), $599 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0);
 var $615 = 0, $616 = Math_fround(0), $617 = 0, $618 = 0, $619 = 0, $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = 0, $65 = Math_fround(0), $650 = Math_fround(0);
 var $651 = 0, $652 = 0, $653 = Math_fround(0), $654 = 0, $655 = Math_fround(0), $656 = 0, $657 = Math_fround(0), $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = Math_fround(0), $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0);
 var $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = 0, $686 = Math_fround(0), $687 = 0;
 var $688 = Math_fround(0), $689 = 0, $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = 0, $693 = Math_fround(0), $694 = 0, $695 = Math_fround(0), $696 = 0, $697 = Math_fround(0), $698 = 0, $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = Math_fround(0);
 var $705 = Math_fround(0), $706 = Math_fround(0), $707 = 0, $708 = 0, $709 = 0, $71 = Math_fround(0), $710 = 0, $711 = 0, $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = 0, $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0);
 var $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = 0, $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = Math_fround(0), $740 = Math_fround(0);
 var $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = 0, $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = 0, $757 = Math_fround(0), $758 = 0, $759 = Math_fround(0);
 var $76 = Math_fround(0), $760 = 0, $761 = Math_fround(0), $762 = Math_fround(0), $763 = 0, $764 = Math_fround(0), $765 = 0, $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = 0, $77 = Math_fround(0), $770 = 0, $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0);
 var $778 = Math_fround(0), $779 = 0, $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0);
 var $796 = 0, $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = 0, $808 = Math_fround(0), $809 = Math_fround(0), $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0);
 var $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = Math_fround(0), $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = 0.0;
 var $831 = 0, $832 = 0.0, $833 = 0, $834 = 0.0, $835 = 0, $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = Math_fround(0), $841 = 0, $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0);
 var $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = 0, $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = 0, $866 = Math_fround(0), $867 = 0;
 var $868 = Math_fround(0), $869 = 0, $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = 0, $873 = Math_fround(0), $874 = 0, $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = 0, $879 = 0, $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0);
 var $886 = Math_fround(0), $887 = Math_fround(0), $888 = 0, $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = 0, $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0);
 var $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = Math_fround(0), $920 = Math_fround(0);
 var $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = Math_fround(0), $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0);
 var $94 = 0, $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = 0, $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = Math_fround(0), $950 = Math_fround(0), $951 = 0, $952 = Math_fround(0), $953 = 0, $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = 0;
 var $958 = 0, $959 = 0, $96 = Math_fround(0), $960 = Math_fround(0), $961 = Math_fround(0), $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = Math_fround(0), $968 = 0, $969 = Math_fround(0), $97 = Math_fround(0), $970 = 0, $971 = Math_fround(0), $972 = Math_fround(0), $973 = 0, $974 = Math_fround(0), $975 = 0;
 var $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = 0, $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = Math_fround(0), $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0);
 var $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $Cross$i = 0, $Max1$i$i = 0, $Max1$i3$i = 0, $Min1$i$i = 0, $Min1$i2$i = 0, $PenDepth$0$lcssa$i = Math_fround(0), $PenDepth$037$i = Math_fround(0), $PenDepth$1$i = Math_fround(0), $PenDepth$225$i = Math_fround(0), $PenDepth$3$i = Math_fround(0), $SepAxis = 0, $a$021$i = 0, $a$021$i$phi = 0, $b$022$i = 0;
 var $brmerge = 0, $capsuleRadius$sroa$1 = 0, $closA = 0, $closB = 0, $convexScaling = 0, $dist$i = 0, $dist$i9 = 0, $edges$i = 0, $exitcond$i = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i$i$i11 = Math_fround(0), $fabsf$i$i$i$i2 = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i1$i$i12 = Math_fround(0), $fabsf$i$i1$i$i3 = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i2$i$i13 = Math_fround(0), $fabsf$i$i2$i$i4 = Math_fround(0), $i$017$i = 0, $i$036$i = 0;
 var $i1$024$i = 0, $ip$i = 0, $ip$i10 = 0, $normal = 0, $normalV = 0, $or$cond = 0, $or$cond$i$i = 0, $or$cond$i$i14 = 0, $plane$i = 0, $plane$i8 = 0, $polyData = 0, $s0$i = 0, $s1$i = 0, $s1$i6 = 0, $sqDist = 0, $v1$i = 0, $v1$i7 = 0, $vQuat = 0, $vScale = 0, $worldNormal$i = 0;
 var $worldSegment = 0, $worldTM$i = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 9152|0;
 $zero$sroa$1$i$i$i = sp + 9132|0;
 $0 = sp + 512|0;
 $s1$i6 = sp + 448|0;
 $v1$i7 = sp + 240|0;
 $plane$i8 = sp + 96|0;
 $dist$i9 = sp + 9128|0;
 $ip$i10 = sp + 9116|0;
 $1 = sp + 9104|0;
 $Min1$i2$i = sp + 9100|0;
 $Max1$i3$i = sp + 9096|0;
 $Min1$i$i = sp + 9092|0;
 $Max1$i$i = sp + 9088|0;
 $worldTM$i = sp + 9040|0;
 $worldNormal$i = sp + 9028|0;
 $Cross$i = sp + 9016|0;
 $edges$i = sp + 824|0;
 $s0$i = sp + 808|0;
 $s1$i = sp + 556|0;
 $v1$i = sp + 568|0;
 $plane$i = sp + 584|0;
 $dist$i = sp + 600|0;
 $ip$i = sp + 604|0;
 $closA = sp + 528|0;
 $closB = sp + 64|0;
 $normalV = sp + 48|0;
 $sqDist = sp + 32|0;
 $zeroV = sp + 80|0;
 $capsuleRadius$sroa$1 = sp + 544|0;
 $vScale = sp;
 $vQuat = sp + 16|0;
 $worldSegment = sp + 616|0;
 $convexScaling = sp + 640|0;
 $polyData = sp + 712|0;
 $normal = sp + 784|0;
 $SepAxis = sp + 796|0;
 $2 = (($shape1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $4 = (($3) + 16|0);
 $5 = (($shape0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($shape0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($shape1) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($shape1) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($shape1) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$vScale>>2] = $10;
 $15 = (($vScale) + 4|0);
 HEAPF32[$15>>2] = $12;
 $16 = (($vScale) + 8|0);
 HEAPF32[$16>>2] = $14;
 $17 = (($vScale) + 12|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($shape1) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($shape1) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($shape1) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($shape1) + 28|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$vQuat>>2] = $19;
 $26 = (($vQuat) + 4|0);
 HEAPF32[$26>>2] = $21;
 $27 = (($vQuat) + 8|0);
 HEAPF32[$27>>2] = $23;
 $28 = (($vQuat) + 12|0);
 HEAPF32[$28>>2] = $25;
 $29 = Math_fround(HEAPF32[$transform1>>2]);
 $30 = Math_fround(-$29);
 $31 = (($transform1) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(-$32);
 $34 = (($transform1) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround(-$35);
 $37 = (($transform1) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($transform0) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($transform1) + 16|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 - $42);
 $44 = (($transform0) + 20|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($transform1) + 20|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 - $47);
 $49 = (($transform0) + 24|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($transform1) + 24|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($50 - $52);
 $54 = Math_fround($43 * Math_fround(2.0));
 $55 = Math_fround($48 * Math_fround(2.0));
 $56 = Math_fround($53 * Math_fround(2.0));
 $57 = Math_fround($38 * $38);
 $58 = Math_fround($57 + Math_fround(-0.5));
 $59 = Math_fround($54 * $30);
 $60 = Math_fround($55 * $33);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($56 * $36);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($58 * $54);
 $65 = Math_fround($56 * $33);
 $66 = Math_fround($55 * $36);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($38 * $67);
 $69 = Math_fround($64 + $68);
 $70 = Math_fround($63 * $30);
 $71 = Math_fround($70 + $69);
 $72 = Math_fround($58 * $55);
 $73 = Math_fround($54 * $36);
 $74 = Math_fround($56 * $30);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($38 * $75);
 $77 = Math_fround($72 + $76);
 $78 = Math_fround($63 * $33);
 $79 = Math_fround($78 + $77);
 $80 = Math_fround($58 * $56);
 $81 = Math_fround($55 * $30);
 $82 = Math_fround($54 * $33);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($38 * $83);
 $85 = Math_fround($80 + $84);
 $86 = Math_fround($63 * $36);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround(HEAPF32[$transform0>>2]);
 $89 = Math_fround($38 * $88);
 $90 = (($transform0) + 12|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 * $30);
 $93 = Math_fround($89 + $92);
 $94 = (($transform0) + 8|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($95 * $33);
 $97 = Math_fround($93 + $96);
 $98 = (($transform0) + 4|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($99 * $36);
 $101 = Math_fround($97 - $100);
 $102 = Math_fround($38 * $99);
 $103 = Math_fround($91 * $33);
 $104 = Math_fround($103 + $102);
 $105 = Math_fround($88 * $36);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($95 * $30);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($38 * $95);
 $110 = Math_fround($91 * $36);
 $111 = Math_fround($110 + $109);
 $112 = Math_fround($99 * $30);
 $113 = Math_fround($112 + $111);
 $114 = Math_fround($88 * $33);
 $115 = Math_fround($113 - $114);
 $116 = Math_fround($38 * $91);
 $117 = Math_fround($88 * $30);
 $118 = Math_fround($116 - $117);
 $119 = Math_fround($99 * $33);
 $120 = Math_fround($118 - $119);
 $121 = Math_fround($95 * $36);
 $122 = Math_fround($120 - $121);
 $123 = (($s1$i6) + 48|0);
 HEAPF32[$123>>2] = $71;
 $124 = (($s1$i6) + 52|0);
 HEAPF32[$124>>2] = $79;
 $125 = (($s1$i6) + 56|0);
 HEAPF32[$125>>2] = $87;
 $126 = (($s1$i6) + 60|0);
 HEAPF32[$126>>2] = Math_fround(0.0);
 $127 = Math_fround($101 + $101);
 $128 = Math_fround($108 + $108);
 $129 = Math_fround($115 + $115);
 $130 = Math_fround($101 * $127);
 $131 = Math_fround($108 * $128);
 $132 = Math_fround($115 * $129);
 $133 = Math_fround($127 * $108);
 $134 = Math_fround($127 * $115);
 $135 = Math_fround($127 * $122);
 $136 = Math_fround($115 * $128);
 $137 = Math_fround($122 * $128);
 $138 = Math_fround($122 * $129);
 $139 = Math_fround(Math_fround(1.0) - $130);
 $140 = Math_fround(Math_fround(1.0) - $131);
 $141 = Math_fround($140 - $132);
 $142 = Math_fround($133 + $138);
 $143 = Math_fround($134 - $137);
 $144 = Math_fround($133 - $138);
 $145 = Math_fround($139 - $132);
 $146 = Math_fround($135 + $136);
 $147 = Math_fround($134 + $137);
 $148 = Math_fround($136 - $135);
 $149 = Math_fround($139 - $131);
 HEAPF32[$s1$i6>>2] = $141;
 $150 = (($s1$i6) + 4|0);
 HEAPF32[$150>>2] = $142;
 $151 = (($s1$i6) + 8|0);
 HEAPF32[$151>>2] = $143;
 $152 = (($s1$i6) + 12|0);
 HEAPF32[$152>>2] = Math_fround(0.0);
 $153 = (($s1$i6) + 16|0);
 HEAPF32[$153>>2] = $144;
 $154 = (($s1$i6) + 20|0);
 HEAPF32[$154>>2] = $145;
 $155 = (($s1$i6) + 24|0);
 HEAPF32[$155>>2] = $146;
 $156 = (($s1$i6) + 28|0);
 HEAPF32[$156>>2] = Math_fround(0.0);
 $157 = (($s1$i6) + 32|0);
 HEAPF32[$157>>2] = $147;
 $158 = (($s1$i6) + 36|0);
 HEAPF32[$158>>2] = $148;
 $159 = (($s1$i6) + 40|0);
 HEAPF32[$159>>2] = $149;
 $160 = (($s1$i6) + 44|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($v1$i7,$4,$zeroV,$vScale,$vQuat);
 $161 = Math_fround($6 * Math_fround(0.0));
 $162 = (($plane$i8) + 64|0);
 ;HEAP32[$plane$i8+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$plane$i8+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$plane$i8+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$plane$i8+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $163 = (($plane$i8) + 80|0);
 HEAP32[$163>>2] = 4;
 $164 = (($plane$i8) + 16|0);
 $165 = (($plane$i8) + 20|0);
 $166 = (($plane$i8) + 32|0);
 $167 = (($plane$i8) + 36|0);
 $168 = (($plane$i8) + 48|0);
 HEAPF32[$168>>2] = Math_fround(0.0);
 $169 = (($plane$i8) + 52|0);
 ;HEAP32[$169+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$169+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$169+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $170 = (($plane$i8) + 128|0);
 HEAPF32[$170>>2] = $8;
 $171 = (($plane$i8) + 132|0);
 ;HEAP32[$171+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$171+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$171+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $172 = Math_fround(HEAPF32[$zeroV>>2]);
 $173 = (($zeroV) + 4|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($zeroV) + 8|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = Math_fround($6 + $172);
 $178 = Math_fround($161 + $174);
 $179 = Math_fround($161 + $176);
 $180 = (($plane$i8) + 96|0);
 HEAPF32[$180>>2] = $177;
 $181 = (($plane$i8) + 100|0);
 HEAPF32[$181>>2] = $178;
 $182 = (($plane$i8) + 104|0);
 HEAPF32[$182>>2] = $179;
 $183 = (($plane$i8) + 108|0);
 HEAPF32[$183>>2] = Math_fround(0.0);
 $184 = Math_fround($172 - $6);
 $185 = Math_fround($174 - $161);
 $186 = Math_fround($176 - $161);
 $187 = (($plane$i8) + 112|0);
 HEAPF32[$187>>2] = $184;
 $188 = (($plane$i8) + 116|0);
 HEAPF32[$188>>2] = $185;
 $189 = (($plane$i8) + 120|0);
 HEAPF32[$189>>2] = $186;
 $190 = (($plane$i8) + 124|0);
 HEAPF32[$190>>2] = Math_fround(0.0);
 HEAPF32[$164>>2] = $8;
 ;HEAP32[$165+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$166>>2] = $8;
 ;HEAP32[$167+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$162+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$0+12>>2]|0;
 $191 = (__ZN5physx2Gu11GJKRelativeERKNS0_8CapsuleVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERNS8_5Vec3VESD_SD_RNS8_6FloatVE($plane$i8,$v1$i7,$s1$i6,$closA,$closB,$normalV,$sqDist)|0);
 $192 = ($191|0)==(1);
 if ($192) {
  $285 = Math_fround(0.0);$352 = Math_fround(0.0);$354 = Math_fround(0.0);$356 = Math_fround(0.0);$653 = Math_fround(0.0);$655 = Math_fround(0.0);$657 = Math_fround(0.0);
 } else {
  $193 = Math_fround(HEAPF32[$closB>>2]);
  $194 = (($closB) + 4|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($closB) + 8|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = Math_fround(HEAPF32[$sqDist>>2]);
  $199 = Math_fround(HEAPF32[$normalV>>2]);
  $200 = (($normalV) + 4|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (($normalV) + 8|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = Math_fround($193 * Math_fround(2.0));
  $205 = Math_fround($195 * Math_fround(2.0));
  $206 = Math_fround($197 * Math_fround(2.0));
  $207 = Math_fround(HEAPF32[$37>>2]);
  $208 = Math_fround($207 * $207);
  $209 = Math_fround($208 + Math_fround(-0.5));
  $210 = Math_fround(HEAPF32[$transform1>>2]);
  $211 = Math_fround($204 * $210);
  $212 = Math_fround(HEAPF32[$31>>2]);
  $213 = Math_fround($205 * $212);
  $214 = Math_fround($211 + $213);
  $215 = Math_fround(HEAPF32[$34>>2]);
  $216 = Math_fround($206 * $215);
  $217 = Math_fround($214 + $216);
  $218 = Math_fround($204 * $209);
  $219 = Math_fround($206 * $212);
  $220 = Math_fround($205 * $215);
  $221 = Math_fround($219 - $220);
  $222 = Math_fround($207 * $221);
  $223 = Math_fround($218 + $222);
  $224 = Math_fround($210 * $217);
  $225 = Math_fround($224 + $223);
  $226 = Math_fround($205 * $209);
  $227 = Math_fround($204 * $215);
  $228 = Math_fround($206 * $210);
  $229 = Math_fround($227 - $228);
  $230 = Math_fround($207 * $229);
  $231 = Math_fround($226 + $230);
  $232 = Math_fround($212 * $217);
  $233 = Math_fround($232 + $231);
  $234 = Math_fround($206 * $209);
  $235 = Math_fround($205 * $210);
  $236 = Math_fround($204 * $212);
  $237 = Math_fround($235 - $236);
  $238 = Math_fround($207 * $237);
  $239 = Math_fround($234 + $238);
  $240 = Math_fround($215 * $217);
  $241 = Math_fround($239 + $240);
  $242 = Math_fround(HEAPF32[$41>>2]);
  $243 = Math_fround($242 + $225);
  $244 = Math_fround(HEAPF32[$46>>2]);
  $245 = Math_fround($244 + $233);
  $246 = Math_fround(HEAPF32[$51>>2]);
  $247 = Math_fround($246 + $241);
  $248 = Math_fround($199 * Math_fround(2.0));
  $249 = Math_fround($201 * Math_fround(2.0));
  $250 = Math_fround($203 * Math_fround(2.0));
  $251 = Math_fround($248 * $210);
  $252 = Math_fround($249 * $212);
  $253 = Math_fround($251 + $252);
  $254 = Math_fround($250 * $215);
  $255 = Math_fround($253 + $254);
  $256 = Math_fround($248 * $209);
  $257 = Math_fround($250 * $212);
  $258 = Math_fround($249 * $215);
  $259 = Math_fround($257 - $258);
  $260 = Math_fround($207 * $259);
  $261 = Math_fround($256 + $260);
  $262 = Math_fround($210 * $255);
  $263 = Math_fround($262 + $261);
  $264 = Math_fround($249 * $209);
  $265 = Math_fround($248 * $215);
  $266 = Math_fround($250 * $210);
  $267 = Math_fround($265 - $266);
  $268 = Math_fround($207 * $267);
  $269 = Math_fround($264 + $268);
  $270 = Math_fround($212 * $255);
  $271 = Math_fround($270 + $269);
  $272 = Math_fround($250 * $209);
  $273 = Math_fround($249 * $210);
  $274 = Math_fround($248 * $212);
  $275 = Math_fround($273 - $274);
  $276 = Math_fround($207 * $275);
  $277 = Math_fround($272 + $276);
  $278 = Math_fround($215 * $255);
  $279 = Math_fround($277 + $278);
  $285 = $198;$352 = $263;$354 = $271;$356 = $279;$653 = $243;$655 = $245;$657 = $247;
 }
 $280 = Math_fround(HEAPF32[$7>>2]);
 $281 = Math_fround(HEAPF32[$contactDistance>>2]);
 $282 = Math_fround($280 + $281);
 $283 = Math_fround($282 * $282);
 $284 = !($285 >= $283);
 if (!($284)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $286 = Math_fround(HEAPF32[$transform0>>2]);
 $287 = Math_fround($286 * Math_fround(2.0));
 $288 = Math_fround(HEAPF32[$90>>2]);
 $289 = Math_fround($288 * Math_fround(2.0));
 $290 = Math_fround($288 * $289);
 $291 = Math_fround($290 + Math_fround(-1.0));
 $292 = Math_fround($286 * $287);
 $293 = Math_fround($292 + $291);
 $294 = Math_fround(HEAPF32[$94>>2]);
 $295 = Math_fround($294 * $289);
 $296 = Math_fround(HEAPF32[$98>>2]);
 $297 = Math_fround($287 * $296);
 $298 = Math_fround($295 + $297);
 $299 = Math_fround($289 * $296);
 $300 = Math_fround($287 * $294);
 $301 = Math_fround($300 - $299);
 $302 = Math_fround(HEAPF32[$5>>2]);
 $303 = Math_fround($302 * $293);
 $304 = Math_fround($302 * $298);
 $305 = Math_fround($302 * $301);
 $306 = Math_fround(HEAPF32[$39>>2]);
 $307 = Math_fround($306 + $303);
 $308 = Math_fround(HEAPF32[$44>>2]);
 $309 = Math_fround($308 + $304);
 $310 = Math_fround(HEAPF32[$49>>2]);
 $311 = Math_fround($305 + $310);
 HEAPF32[$worldSegment>>2] = $307;
 $312 = (($worldSegment) + 4|0);
 HEAPF32[$312>>2] = $309;
 $313 = (($worldSegment) + 8|0);
 HEAPF32[$313>>2] = $311;
 $314 = Math_fround($306 - $303);
 $315 = Math_fround($308 - $304);
 $316 = Math_fround($310 - $305);
 $317 = (($worldSegment) + 12|0);
 HEAPF32[$317>>2] = $314;
 $318 = (($worldSegment) + 16|0);
 HEAPF32[$318>>2] = $315;
 $319 = (($worldSegment) + 20|0);
 HEAPF32[$319>>2] = $316;
 $320 = $307 == $314;
 $321 = $309 == $315;
 $or$cond = $320 & $321;
 if ($or$cond) {
  $322 = $311 == $316;
  $324 = $322;
 } else {
  $324 = 0;
 }
 $323 = $324 ? 1 : 2;
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $325 = (($convexScaling) + 4|0);
 HEAPF32[$325>>2] = Math_fround(0.0);
 $326 = (($convexScaling) + 8|0);
 HEAPF32[$326>>2] = Math_fround(0.0);
 $327 = (($convexScaling) + 12|0);
 HEAPF32[$327>>2] = Math_fround(0.0);
 $328 = (($convexScaling) + 16|0);
 HEAPF32[$328>>2] = Math_fround(1.0);
 $329 = (($convexScaling) + 20|0);
 HEAPF32[$329>>2] = Math_fround(0.0);
 $330 = (($convexScaling) + 24|0);
 HEAPF32[$330>>2] = Math_fround(0.0);
 $331 = (($convexScaling) + 28|0);
 HEAPF32[$331>>2] = Math_fround(0.0);
 $332 = (($convexScaling) + 32|0);
 HEAPF32[$332>>2] = Math_fround(1.0);
 $333 = (($convexScaling) + 36|0);
 HEAPF32[$333>>2] = Math_fround(1.0);
 $334 = (($convexScaling) + 40|0);
 HEAPF32[$334>>2] = Math_fround(0.0);
 $335 = (($convexScaling) + 44|0);
 HEAPF32[$335>>2] = Math_fround(0.0);
 $336 = (($convexScaling) + 48|0);
 HEAPF32[$336>>2] = Math_fround(0.0);
 $337 = (($convexScaling) + 52|0);
 HEAPF32[$337>>2] = Math_fround(1.0);
 $338 = (($convexScaling) + 56|0);
 HEAPF32[$338>>2] = Math_fround(0.0);
 $339 = (($convexScaling) + 60|0);
 HEAPF32[$339>>2] = Math_fround(0.0);
 $340 = (($convexScaling) + 64|0);
 HEAPF32[$340>>2] = Math_fround(0.0);
 $341 = (($convexScaling) + 68|0);
 HEAPF32[$341>>2] = Math_fround(1.0);
 $342 = Math_fround(HEAPF32[$9>>2]);
 $343 = $342 == Math_fround(1.0);
 if ($343) {
  $344 = Math_fround(HEAPF32[$11>>2]);
  $345 = $344 == Math_fround(1.0);
  if ($345) {
   $346 = Math_fround(HEAPF32[$13>>2]);
   $347 = $346 == Math_fround(1.0);
   if (!($347)) {
    label = 9;
   }
  } else {
   label = 9;
  }
 } else {
  label = 9;
 }
 if ((label|0) == 9) {
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$9,$18);
 }
 $348 = (($shape1) + 36|0);
 $349 = HEAP32[$348>>2]|0;
 __ZN5physx2Gu23getPolygonalData_ConvexEPNS0_13PolygonalDataEPKNS0_14ConvexHullDataERKNS_2Cm23FastVertex2ShapeScalingE($polyData,$349,$convexScaling);
 $350 = $285 > Math_fround(0.0);
 if ($350) {
  $351 = Math_fround(-$352);
  $353 = Math_fround(-$354);
  $355 = Math_fround(-$356);
  HEAPF32[$normal>>2] = $351;
  $357 = (($normal) + 4|0);
  HEAPF32[$357>>2] = $353;
  $358 = (($normal) + 8|0);
  HEAPF32[$358>>2] = $355;
  $359 = Math_fround(HEAPF32[$7>>2]);
  $360 = Math_fround(HEAPF32[$contactDistance>>2]);
  __ZL22PxcGenerateVFContacts2RN5physx2Gu13ContactBufferERKNS_11PxTransformERKNS0_13PolygonalDataERKNS_11PxMeshScaleEjPKNS_6PxVec3EfRSD_f($contactBuffer,$transform1,$polyData,$9,$323,$worldSegment,$359,$normal,$360);
  $361 = (($contactBuffer) + 4096|0);
  $362 = HEAP32[$361>>2]|0;
  $363 = ($362|0)==(2);
  if ($363) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
  if (!($324)) {
   $364 = Math_fround(HEAPF32[$transform1>>2]);
   $365 = Math_fround($364 + $364);
   $366 = Math_fround(HEAPF32[$31>>2]);
   $367 = Math_fround($366 + $366);
   $368 = Math_fround(HEAPF32[$34>>2]);
   $369 = Math_fround($368 + $368);
   $370 = Math_fround(HEAPF32[$37>>2]);
   $371 = Math_fround($365 * $370);
   $372 = Math_fround($367 * $370);
   $373 = Math_fround($370 * $369);
   $374 = Math_fround($364 * $365);
   $375 = Math_fround($364 * $367);
   $376 = Math_fround($364 * $369);
   $377 = Math_fround($366 * $367);
   $378 = Math_fround($366 * $369);
   $379 = Math_fround($368 * $369);
   $380 = Math_fround(Math_fround(1.0) - $377);
   $381 = Math_fround($380 - $379);
   $382 = Math_fround($375 + $373);
   $383 = Math_fround($376 - $372);
   $384 = Math_fround($375 - $373);
   $385 = Math_fround(Math_fround(1.0) - $374);
   $386 = Math_fround($385 - $379);
   $387 = Math_fround($378 + $371);
   $388 = Math_fround($376 + $372);
   $389 = Math_fround($378 - $371);
   $390 = Math_fround($385 - $377);
   $391 = Math_fround(HEAPF32[$41>>2]);
   $392 = Math_fround(HEAPF32[$46>>2]);
   $393 = Math_fround(HEAPF32[$51>>2]);
   $394 = Math_fround(HEAPF32[$7>>2]);
   $395 = Math_fround(HEAPF32[$contactDistance>>2]);
   $396 = Math_fround(HEAPF32[$normal>>2]);
   $397 = Math_fround($381 * $396);
   $398 = Math_fround(HEAPF32[$357>>2]);
   $399 = Math_fround($382 * $398);
   $400 = Math_fround($397 + $399);
   $401 = Math_fround(HEAPF32[$358>>2]);
   $402 = Math_fround($383 * $401);
   $403 = Math_fround($400 + $402);
   $404 = Math_fround($384 * $396);
   $405 = Math_fround($386 * $398);
   $406 = Math_fround($404 + $405);
   $407 = Math_fround($387 * $401);
   $408 = Math_fround($406 + $407);
   $409 = Math_fround($388 * $396);
   $410 = Math_fround($389 * $398);
   $411 = Math_fround($409 + $410);
   $412 = Math_fround($390 * $401);
   $413 = Math_fround($411 + $412);
   HEAPF32[$zero$sroa$1$i$i$i>>2] = $403;
   $414 = (($zero$sroa$1$i$i$i) + 4|0);
   HEAPF32[$414>>2] = $408;
   $415 = (($zero$sroa$1$i$i$i) + 8|0);
   HEAPF32[$415>>2] = $413;
   $416 = (($polyData) + 68|0);
   $417 = HEAP32[$416>>2]|0;
   $418 = (FUNCTION_TABLE_iiii[$417 & 2047]($polyData,$convexScaling,$zero$sroa$1$i$i$i)|0);
   $419 = Math_fround(HEAPF32[$worldSegment>>2]);
   HEAPF32[$0>>2] = $419;
   $420 = (($0) + 4|0);
   $421 = Math_fround(HEAPF32[$312>>2]);
   HEAPF32[$420>>2] = $421;
   $422 = (($0) + 8|0);
   $423 = Math_fround(HEAPF32[$313>>2]);
   HEAPF32[$422>>2] = $423;
   $424 = Math_fround(HEAPF32[$317>>2]);
   HEAPF32[$s1$i6>>2] = $424;
   $425 = (($s1$i6) + 4|0);
   $426 = Math_fround(HEAPF32[$318>>2]);
   HEAPF32[$425>>2] = $426;
   $427 = (($s1$i6) + 8|0);
   $428 = Math_fround(HEAPF32[$319>>2]);
   HEAPF32[$427>>2] = $428;
   $429 = Math_fround($424 - $419);
   $430 = Math_fround($426 - $421);
   $431 = Math_fround($428 - $423);
   $432 = Math_fround($429 * $429);
   $433 = Math_fround($430 * $430);
   $434 = Math_fround($432 + $433);
   $435 = Math_fround($431 * $431);
   $436 = Math_fround($434 + $435);
   $437 = (Math_fround(Math_sqrt((Math_fround($436)))));
   $438 = $437 > Math_fround(0.0);
   if ($438) {
    $439 = Math_fround(Math_fround(0.00999999977648258209228) / $437);
    $440 = Math_fround($429 * $439);
    $441 = Math_fround($430 * $439);
    $442 = Math_fround($431 * $439);
    $443 = Math_fround($419 - $440);
    HEAPF32[$0>>2] = $443;
    $444 = Math_fround($421 - $441);
    HEAPF32[$420>>2] = $444;
    $445 = Math_fround($423 - $442);
    HEAPF32[$422>>2] = $445;
    $446 = Math_fround($424 + $440);
    HEAPF32[$s1$i6>>2] = $446;
    $447 = Math_fround($426 + $441);
    HEAPF32[$425>>2] = $447;
    $448 = Math_fround($428 + $442);
    HEAPF32[$427>>2] = $448;
    $450 = $443;$451 = $446;$453 = $444;$454 = $447;$456 = $445;$457 = $448;
   } else {
    $450 = $419;$451 = $424;$453 = $421;$454 = $426;$456 = $423;$457 = $428;
   }
   $449 = Math_fround($451 - $450);
   $452 = Math_fround($454 - $453);
   $455 = Math_fround($457 - $456);
   HEAPF32[$v1$i7>>2] = $449;
   $458 = (($v1$i7) + 4|0);
   HEAPF32[$458>>2] = $452;
   $459 = (($v1$i7) + 8|0);
   HEAPF32[$459>>2] = $455;
   $460 = Math_fround($452 * $401);
   $461 = Math_fround($455 * $398);
   $462 = Math_fround($460 - $461);
   $463 = Math_fround($455 * $396);
   $464 = Math_fround($401 * $449);
   $465 = Math_fround($463 - $464);
   $466 = Math_fround($449 * $398);
   $467 = Math_fround($452 * $396);
   $468 = Math_fround($466 - $467);
   $469 = Math_fround(-$462);
   $470 = Math_fround(-$465);
   $471 = Math_fround(-$468);
   HEAPF32[$plane$i8>>2] = $469;
   $472 = (($plane$i8) + 4|0);
   HEAPF32[$472>>2] = $470;
   $473 = (($plane$i8) + 8|0);
   HEAPF32[$473>>2] = $471;
   $474 = Math_fround($450 * $469);
   $475 = Math_fround($453 * $470);
   $476 = Math_fround($474 + $475);
   $477 = Math_fround($456 * $471);
   $478 = Math_fround($477 + $476);
   $479 = Math_fround(-$478);
   $480 = (($plane$i8) + 12|0);
   HEAPF32[$480>>2] = $479;
   $fabsf$i$i$i$i11 = (Math_fround(Math_abs((Math_fround($469)))));
   $fabsf$i$i1$i$i12 = (Math_fround(Math_abs((Math_fround($470)))));
   $fabsf$i$i2$i$i13 = (Math_fround(Math_abs((Math_fround($471)))));
   $481 = $fabsf$i$i1$i$i12 > $fabsf$i$i$i$i11;
   $482 = $fabsf$i$i1$i$i12 > $fabsf$i$i2$i$i13;
   $or$cond$i$i14 = $481 & $482;
   if ($or$cond$i$i14) {
    $485 = 0;$488 = 2;
   } else {
    $483 = $fabsf$i$i2$i$i13 > $fabsf$i$i$i$i11;
    if ($483) {
     $485 = 1;$488 = 0;
    } else {
     $485 = 2;$488 = 1;
    }
   }
   $484 = (($v1$i7) + ($485<<2)|0);
   $486 = Math_fround(HEAPF32[$484>>2]);
   $487 = (($normal) + ($488<<2)|0);
   $489 = Math_fround(HEAPF32[$487>>2]);
   $490 = Math_fround($486 * $489);
   $491 = (($v1$i7) + ($488<<2)|0);
   $492 = Math_fround(HEAPF32[$491>>2]);
   $493 = (($normal) + ($485<<2)|0);
   $494 = Math_fround(HEAPF32[$493>>2]);
   $495 = Math_fround($492 * $494);
   $496 = Math_fround($490 - $495);
   $497 = Math_fround(Math_fround(1.0) / $496);
   $498 = (($polyData) + 28|0);
   $499 = HEAP32[$498>>2]|0;
   $500 = (($polyData) + 24|0);
   $501 = HEAP32[$500>>2]|0;
   $502 = (($polyData) + 32|0);
   $503 = HEAP32[$502>>2]|0;
   $504 = ((($501) + (($418*20)|0)|0) + 16|0);
   $505 = HEAP16[$504>>1]|0;
   $506 = $505&65535;
   $507 = ((($501) + (($418*20)|0)|0) + 18|0);
   $508 = HEAP8[$507>>0]|0;
   $509 = $508&255;
   $510 = ($508<<24>>24)==(0);
   if (!($510)) {
    $511 = (($509) + -1)|0;
    $512 = (($1) + 4|0);
    $513 = (($1) + 8|0);
    $514 = Math_fround($394 + $395);
    $515 = (($ip$i10) + 8|0);
    $516 = (($ip$i10) + 4|0);
    $517 = Math_fround(HEAPF32[$normal>>2]);
    $518 = Math_fround(-$517);
    $519 = Math_fround(-$398);
    $520 = Math_fround(-$401);
    $$in$i = $509;$a$021$i = $511;$b$022$i = 0;
    while(1) {
     $521 = (($$in$i) + -1)|0;
     $$sum$i = (($a$021$i) + ($506))|0;
     $522 = (($503) + ($$sum$i)|0);
     $523 = HEAP8[$522>>0]|0;
     $524 = $523&255;
     $525 = (($499) + (($524*12)|0)|0);
     $526 = Math_fround(HEAPF32[$525>>2]);
     $527 = Math_fround(HEAPF32[$convexScaling>>2]);
     $528 = Math_fround($526 * $527);
     $529 = Math_fround(HEAPF32[$325>>2]);
     $530 = Math_fround($526 * $529);
     $531 = Math_fround(HEAPF32[$326>>2]);
     $532 = Math_fround($526 * $531);
     $533 = ((($499) + (($524*12)|0)|0) + 4|0);
     $534 = Math_fround(HEAPF32[$533>>2]);
     $535 = Math_fround(HEAPF32[$327>>2]);
     $536 = Math_fround($534 * $535);
     $537 = Math_fround(HEAPF32[$328>>2]);
     $538 = Math_fround($534 * $537);
     $539 = Math_fround(HEAPF32[$329>>2]);
     $540 = Math_fround($534 * $539);
     $541 = Math_fround($528 + $536);
     $542 = Math_fround($530 + $538);
     $543 = Math_fround($532 + $540);
     $544 = ((($499) + (($524*12)|0)|0) + 8|0);
     $545 = Math_fround(HEAPF32[$544>>2]);
     $546 = Math_fround(HEAPF32[$330>>2]);
     $547 = Math_fround($545 * $546);
     $548 = Math_fround(HEAPF32[$331>>2]);
     $549 = Math_fround($545 * $548);
     $550 = Math_fround(HEAPF32[$332>>2]);
     $551 = Math_fround($545 * $550);
     $552 = Math_fround($541 + $547);
     $553 = Math_fround($542 + $549);
     $554 = Math_fround($543 + $551);
     $555 = Math_fround($381 * $552);
     $556 = Math_fround($382 * $552);
     $557 = Math_fround($383 * $552);
     $558 = Math_fround($384 * $553);
     $559 = Math_fround($386 * $553);
     $560 = Math_fround($387 * $553);
     $561 = Math_fround($555 + $558);
     $562 = Math_fround($556 + $559);
     $563 = Math_fround($557 + $560);
     $564 = Math_fround($388 * $554);
     $565 = Math_fround($389 * $554);
     $566 = Math_fround($390 * $554);
     $567 = Math_fround($561 + $564);
     $568 = Math_fround($562 + $565);
     $569 = Math_fround($563 + $566);
     $570 = Math_fround($391 + $567);
     $571 = Math_fround($392 + $568);
     $572 = Math_fround($393 + $569);
     $$sum1$i = (($b$022$i) + ($506))|0;
     $573 = (($503) + ($$sum1$i)|0);
     $574 = HEAP8[$573>>0]|0;
     $575 = $574&255;
     $576 = (($499) + (($575*12)|0)|0);
     $577 = Math_fround(HEAPF32[$576>>2]);
     $578 = Math_fround($527 * $577);
     $579 = Math_fround($529 * $577);
     $580 = Math_fround($531 * $577);
     $581 = ((($499) + (($575*12)|0)|0) + 4|0);
     $582 = Math_fround(HEAPF32[$581>>2]);
     $583 = Math_fround($535 * $582);
     $584 = Math_fround($537 * $582);
     $585 = Math_fround($539 * $582);
     $586 = Math_fround($578 + $583);
     $587 = Math_fround($579 + $584);
     $588 = Math_fround($580 + $585);
     $589 = ((($499) + (($575*12)|0)|0) + 8|0);
     $590 = Math_fround(HEAPF32[$589>>2]);
     $591 = Math_fround($546 * $590);
     $592 = Math_fround($548 * $590);
     $593 = Math_fround($550 * $590);
     $594 = Math_fround($586 + $591);
     $595 = Math_fround($587 + $592);
     $596 = Math_fround($588 + $593);
     $597 = Math_fround($381 * $594);
     $598 = Math_fround($382 * $594);
     $599 = Math_fround($383 * $594);
     $600 = Math_fround($384 * $595);
     $601 = Math_fround($386 * $595);
     $602 = Math_fround($387 * $595);
     $603 = Math_fround($597 + $600);
     $604 = Math_fround($598 + $601);
     $605 = Math_fround($599 + $602);
     $606 = Math_fround($388 * $596);
     $607 = Math_fround($389 * $596);
     $608 = Math_fround($390 * $596);
     $609 = Math_fround($606 + $603);
     $610 = Math_fround($607 + $604);
     $611 = Math_fround($608 + $605);
     $612 = Math_fround($391 + $609);
     $613 = Math_fround($392 + $610);
     $614 = Math_fround($393 + $611);
     HEAPF32[$1>>2] = $518;
     HEAPF32[$512>>2] = $519;
     HEAPF32[$513>>2] = $520;
     $615 = (__ZL22intersectEdgeEdgePrecaRKN5physx6PxVec3ES2_S2_RKNS_7PxPlaneEjjfS2_S2_S2_RfRS0_f($0,$s1$i6,$v1$i7,$plane$i8,$488,$485,$497,$1,$570,$571,$572,$612,$613,$614,$dist$i9,$ip$i10,Math_fround(0.0))|0);
     if ($615) {
      $616 = Math_fround(HEAPF32[$dist$i9>>2]);
      $617 = $616 < $514;
      if ($617) {
       $618 = HEAP32[$361>>2]|0;
       $619 = ($618>>>0)>(63);
       if (!($619)) {
        $620 = Math_fround(HEAPF32[$515>>2]);
        $621 = Math_fround(HEAPF32[$516>>2]);
        $622 = Math_fround(HEAPF32[$ip$i10>>2]);
        $623 = Math_fround($616 * $401);
        $624 = Math_fround($616 * $398);
        $625 = Math_fround($616 * $517);
        $626 = Math_fround($616 - $394);
        $627 = Math_fround($620 - $623);
        $628 = Math_fround($621 - $624);
        $629 = Math_fround($622 - $625);
        $630 = (($618) + 1)|0;
        HEAP32[$361>>2] = $630;
        $631 = (($contactBuffer) + ($618<<6)|0);
        HEAPF32[$631>>2] = $517;
        $632 = ((($contactBuffer) + ($618<<6)|0) + 4|0);
        HEAPF32[$632>>2] = $398;
        $633 = ((($contactBuffer) + ($618<<6)|0) + 8|0);
        HEAPF32[$633>>2] = $401;
        $634 = ((($contactBuffer) + ($618<<6)|0) + 16|0);
        HEAPF32[$634>>2] = $629;
        $635 = ((($contactBuffer) + ($618<<6)|0) + 20|0);
        HEAPF32[$635>>2] = $628;
        $636 = ((($contactBuffer) + ($618<<6)|0) + 24|0);
        HEAPF32[$636>>2] = $627;
        $637 = ((($contactBuffer) + ($618<<6)|0) + 12|0);
        HEAPF32[$637>>2] = $626;
        $638 = ((($contactBuffer) + ($618<<6)|0) + 48|0);
        HEAP32[$638>>2] = -1;
        $639 = ((($contactBuffer) + ($618<<6)|0) + 52|0);
        HEAP32[$639>>2] = -1;
       }
      }
     }
     $640 = (($b$022$i) + 1)|0;
     $641 = ($521|0)==(0);
     if ($641) {
      break;
     } else {
      $a$021$i$phi = $b$022$i;$$in$i = $521;$b$022$i = $640;$a$021$i = $a$021$i$phi;
     }
    }
   }
  }
  $642 = HEAP32[$361>>2]|0;
  $643 = ($642|0)==(0);
  if (!($643)) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
  $644 = (Math_fround(Math_sqrt((Math_fround($285)))));
  $645 = Math_fround(HEAPF32[$7>>2]);
  $646 = Math_fround($644 - $645);
  HEAP32[$361>>2] = 1;
  $647 = Math_fround(HEAPF32[$normal>>2]);
  HEAPF32[$contactBuffer>>2] = $647;
  $648 = Math_fround(HEAPF32[$357>>2]);
  $649 = (($contactBuffer) + 4|0);
  HEAPF32[$649>>2] = $648;
  $650 = Math_fround(HEAPF32[$358>>2]);
  $651 = (($contactBuffer) + 8|0);
  HEAPF32[$651>>2] = $650;
  $652 = (($contactBuffer) + 16|0);
  HEAPF32[$652>>2] = $653;
  $654 = (($contactBuffer) + 20|0);
  HEAPF32[$654>>2] = $655;
  $656 = (($contactBuffer) + 24|0);
  HEAPF32[$656>>2] = $657;
  $658 = (($contactBuffer) + 12|0);
  HEAPF32[$658>>2] = $646;
  $659 = (($contactBuffer) + 48|0);
  HEAP32[$659>>2] = -1;
  $660 = (($contactBuffer) + 52|0);
  HEAP32[$660>>2] = -1;
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $661 = Math_fround(HEAPF32[$7>>2]);
 $662 = (($polyData) + 16|0);
 $663 = HEAP32[$662>>2]|0;
 $664 = (($polyData) + 24|0);
 $665 = HEAP32[$664>>2]|0;
 $666 = Math_fround(HEAPF32[$transform1>>2]);
 $667 = Math_fround($666 + $666);
 $668 = Math_fround(HEAPF32[$31>>2]);
 $669 = Math_fround($668 + $668);
 $670 = Math_fround(HEAPF32[$34>>2]);
 $671 = Math_fround($670 + $670);
 $672 = Math_fround(HEAPF32[$37>>2]);
 $673 = Math_fround($667 * $672);
 $674 = Math_fround($669 * $672);
 $675 = Math_fround($672 * $671);
 $676 = Math_fround($666 * $667);
 $677 = Math_fround($666 * $669);
 $678 = Math_fround($666 * $671);
 $679 = Math_fround($668 * $669);
 $680 = Math_fround($668 * $671);
 $681 = Math_fround($670 * $671);
 $682 = Math_fround(Math_fround(1.0) - $679);
 $683 = Math_fround($682 - $681);
 HEAPF32[$worldTM$i>>2] = $683;
 $684 = Math_fround($677 + $675);
 $685 = (($worldTM$i) + 4|0);
 HEAPF32[$685>>2] = $684;
 $686 = Math_fround($678 - $674);
 $687 = (($worldTM$i) + 8|0);
 HEAPF32[$687>>2] = $686;
 $688 = Math_fround($677 - $675);
 $689 = (($worldTM$i) + 12|0);
 HEAPF32[$689>>2] = $688;
 $690 = Math_fround(Math_fround(1.0) - $676);
 $691 = Math_fround($690 - $681);
 $692 = (($worldTM$i) + 16|0);
 HEAPF32[$692>>2] = $691;
 $693 = Math_fround($680 + $673);
 $694 = (($worldTM$i) + 20|0);
 HEAPF32[$694>>2] = $693;
 $695 = Math_fround($678 + $674);
 $696 = (($worldTM$i) + 24|0);
 HEAPF32[$696>>2] = $695;
 $697 = Math_fround($680 - $673);
 $698 = (($worldTM$i) + 28|0);
 HEAPF32[$698>>2] = $697;
 $699 = Math_fround($690 - $679);
 $700 = (($worldTM$i) + 32|0);
 HEAPF32[$700>>2] = $699;
 $701 = (($worldTM$i) + 36|0);
 $702 = (($worldTM$i) + 40|0);
 $703 = (($worldTM$i) + 44|0);
 $704 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$701>>2] = $704;
 $705 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$702>>2] = $705;
 $706 = Math_fround(HEAPF32[$51>>2]);
 HEAPF32[$703>>2] = $706;
 $707 = ($663|0)==(0);
 L44: do {
  if ($707) {
   $$lcssa29$i = Math_fround(0.0);$$lcssa31$i = Math_fround(0.0);$$lcssa33$i = Math_fround(0.0);$PenDepth$0$lcssa$i = Math_fround(3.40282346638528859812E+38);
  } else {
   $708 = (($worldNormal$i) + 4|0);
   $709 = (($worldNormal$i) + 8|0);
   $710 = (($polyData) + 64|0);
   $1218 = Math_fround(0.0);$1219 = Math_fround(0.0);$1220 = Math_fround(0.0);$714 = $683;$716 = $684;$718 = $686;$722 = $688;$724 = $691;$726 = $693;$733 = $695;$735 = $697;$737 = $699;$PenDepth$037$i = Math_fround(3.40282346638528859812E+38);$i$036$i = 0;
   while(1) {
    $711 = (($665) + (($i$036$i*20)|0)|0);
    $712 = Math_fround(HEAPF32[$711>>2]);
    $713 = Math_fround($714 * $712);
    $715 = Math_fround($716 * $712);
    $717 = Math_fround($718 * $712);
    $719 = ((($665) + (($i$036$i*20)|0)|0) + 4|0);
    $720 = Math_fround(HEAPF32[$719>>2]);
    $721 = Math_fround($722 * $720);
    $723 = Math_fround($724 * $720);
    $725 = Math_fround($726 * $720);
    $727 = Math_fround($713 + $721);
    $728 = Math_fround($715 + $723);
    $729 = Math_fround($717 + $725);
    $730 = ((($665) + (($i$036$i*20)|0)|0) + 8|0);
    $731 = Math_fround(HEAPF32[$730>>2]);
    $732 = Math_fround($733 * $731);
    $734 = Math_fround($735 * $731);
    $736 = Math_fround($737 * $731);
    $738 = Math_fround($727 + $732);
    $739 = Math_fround($728 + $734);
    $740 = Math_fround($729 + $736);
    HEAPF32[$worldNormal$i>>2] = $738;
    HEAPF32[$708>>2] = $739;
    HEAPF32[$709>>2] = $740;
    $741 = Math_fround($738 * $307);
    $742 = Math_fround($739 * $309);
    $743 = Math_fround($741 + $742);
    $744 = Math_fround($740 * $311);
    $745 = Math_fround($743 + $744);
    $746 = Math_fround($738 * $314);
    $747 = Math_fround($739 * $315);
    $748 = Math_fround($746 + $747);
    $749 = Math_fround($740 * $316);
    $750 = Math_fround($748 + $749);
    $751 = $745 > $750;
    $752 = $751 ? $750 : $745;
    $753 = $751 ? $745 : $750;
    $754 = Math_fround($752 - $661);
    $755 = Math_fround($661 + $753);
    $756 = HEAP32[$710>>2]|0;
    FUNCTION_TABLE_viiiiii[$756 & 255]($polyData,$worldNormal$i,$worldTM$i,$convexScaling,$Min1$i2$i,$Max1$i3$i);
    $757 = Math_fround(HEAPF32[$Min1$i2$i>>2]);
    $758 = $755 < $757;
    if ($758) {
     $$1 = 0;
     label = 64;
     break;
    }
    $759 = Math_fround(HEAPF32[$Max1$i3$i>>2]);
    $760 = $759 < $754;
    if ($760) {
     $$1 = 0;
     label = 64;
     break;
    }
    $761 = Math_fround($755 - $757);
    $762 = Math_fround($759 - $754);
    $763 = $761 < $762;
    $764 = $763 ? $761 : $762;
    $765 = $764 < $PenDepth$037$i;
    if ($765) {
     $766 = Math_fround(HEAPF32[$worldNormal$i>>2]);
     $767 = Math_fround(HEAPF32[$708>>2]);
     $768 = Math_fround(HEAPF32[$709>>2]);
     $1221 = $768;$1222 = $767;$1223 = $766;$PenDepth$1$i = $764;
    } else {
     $1221 = $1220;$1222 = $1219;$1223 = $1218;$PenDepth$1$i = $PenDepth$037$i;
    }
    $769 = (($i$036$i) + 1)|0;
    $770 = ($769>>>0)<($663>>>0);
    if (!($770)) {
     $$lcssa29$i = $1221;$$lcssa31$i = $1222;$$lcssa33$i = $1223;$PenDepth$0$lcssa$i = $PenDepth$1$i;
     break L44;
    }
    $$pre$i = Math_fround(HEAPF32[$worldTM$i>>2]);
    $$pre51$i = Math_fround(HEAPF32[$685>>2]);
    $$pre52$i = Math_fround(HEAPF32[$687>>2]);
    $$pre53$i = Math_fround(HEAPF32[$689>>2]);
    $$pre54$i = Math_fround(HEAPF32[$692>>2]);
    $$pre55$i = Math_fround(HEAPF32[$694>>2]);
    $$pre56$i = Math_fround(HEAPF32[$696>>2]);
    $$pre57$i = Math_fround(HEAPF32[$698>>2]);
    $$pre58$i = Math_fround(HEAPF32[$700>>2]);
    $1218 = $1223;$1219 = $1222;$1220 = $1221;$714 = $$pre$i;$716 = $$pre51$i;$718 = $$pre52$i;$722 = $$pre53$i;$724 = $$pre54$i;$726 = $$pre55$i;$733 = $$pre56$i;$735 = $$pre57$i;$737 = $$pre58$i;$PenDepth$037$i = $PenDepth$1$i;$i$036$i = $769;
   }
   if ((label|0) == 64) {
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 L58: do {
  if ($324) {
   $939 = $$lcssa33$i;$941 = $$lcssa31$i;$944 = $$lcssa29$i;
  } else {
   $771 = Math_fround($314 - $307);
   $772 = Math_fround($315 - $309);
   $773 = Math_fround($316 - $311);
   $774 = Math_fround($771 * $771);
   $775 = Math_fround($772 * $772);
   $776 = Math_fround($774 + $775);
   $777 = Math_fround($773 * $773);
   $778 = Math_fround($776 + $777);
   $779 = $778 > Math_fround(0.0);
   if ($779) {
    $780 = (Math_fround(Math_sqrt((Math_fround($778)))));
    $781 = Math_fround(Math_fround(1.0) / $780);
    $782 = Math_fround($771 * $781);
    $783 = Math_fround($772 * $781);
    $784 = Math_fround($773 * $781);
    $819 = $783;$821 = $784;$825 = $782;
   } else {
    $819 = Math_fround(0.0);$821 = Math_fround(0.0);$825 = Math_fround(0.0);
   }
   if ($707) {
    $939 = $$lcssa33$i;$941 = $$lcssa31$i;$944 = $$lcssa29$i;
   } else {
    $785 = (($Cross$i) + 4|0);
    $786 = (($Cross$i) + 8|0);
    $787 = (($polyData) + 64|0);
    $1224 = $$lcssa33$i;$1225 = $$lcssa31$i;$1226 = $$lcssa29$i;$PenDepth$225$i = $PenDepth$0$lcssa$i;$i1$024$i = 0;
    while(1) {
     $788 = (($665) + (($i1$024$i*20)|0)|0);
     $789 = Math_fround(HEAPF32[$788>>2]);
     $790 = Math_fround(HEAPF32[$worldTM$i>>2]);
     $791 = Math_fround($789 * $790);
     $792 = Math_fround(HEAPF32[$685>>2]);
     $793 = Math_fround($789 * $792);
     $794 = Math_fround(HEAPF32[$687>>2]);
     $795 = Math_fround($789 * $794);
     $796 = ((($665) + (($i1$024$i*20)|0)|0) + 4|0);
     $797 = Math_fround(HEAPF32[$796>>2]);
     $798 = Math_fround(HEAPF32[$689>>2]);
     $799 = Math_fround($797 * $798);
     $800 = Math_fround(HEAPF32[$692>>2]);
     $801 = Math_fround($797 * $800);
     $802 = Math_fround(HEAPF32[$694>>2]);
     $803 = Math_fround($797 * $802);
     $804 = Math_fround($791 + $799);
     $805 = Math_fround($793 + $801);
     $806 = Math_fround($795 + $803);
     $807 = ((($665) + (($i1$024$i*20)|0)|0) + 8|0);
     $808 = Math_fround(HEAPF32[$807>>2]);
     $809 = Math_fround(HEAPF32[$696>>2]);
     $810 = Math_fround($808 * $809);
     $811 = Math_fround(HEAPF32[$698>>2]);
     $812 = Math_fround($808 * $811);
     $813 = Math_fround(HEAPF32[$700>>2]);
     $814 = Math_fround($808 * $813);
     $815 = Math_fround($804 + $810);
     $816 = Math_fround($805 + $812);
     $817 = Math_fround($806 + $814);
     $818 = Math_fround($819 * $817);
     $820 = Math_fround($821 * $816);
     $822 = Math_fround($818 - $820);
     $823 = Math_fround($821 * $815);
     $824 = Math_fround($825 * $817);
     $826 = Math_fround($823 - $824);
     $827 = Math_fround($825 * $816);
     $828 = Math_fround($819 * $815);
     $829 = Math_fround($827 - $828);
     HEAPF32[$Cross$i>>2] = $822;
     HEAPF32[$785>>2] = $826;
     HEAPF32[$786>>2] = $829;
     $fabsf$i$i$i$i2 = (Math_fround(Math_abs((Math_fround($822)))));
     $830 = +$fabsf$i$i$i$i2;
     $831 = $830 > 9.99999999999999954748E-7;
     if ($831) {
      label = 43;
     } else {
      $fabsf$i$i1$i$i3 = (Math_fround(Math_abs((Math_fround($826)))));
      $832 = +$fabsf$i$i1$i$i3;
      $833 = $832 > 9.99999999999999954748E-7;
      if ($833) {
       label = 43;
      } else {
       $fabsf$i$i2$i$i4 = (Math_fround(Math_abs((Math_fround($829)))));
       $834 = +$fabsf$i$i2$i$i4;
       $835 = $834 > 9.99999999999999954748E-7;
       if ($835) {
        label = 43;
       } else {
        $1227 = $1226;$1228 = $1225;$1229 = $1224;$PenDepth$3$i = $PenDepth$225$i;
       }
      }
     }
     if ((label|0) == 43) {
      label = 0;
      $836 = Math_fround($822 * $822);
      $837 = Math_fround($826 * $826);
      $838 = Math_fround($836 + $837);
      $839 = Math_fround($829 * $829);
      $840 = Math_fround($839 + $838);
      $841 = $840 > Math_fround(0.0);
      if ($841) {
       $842 = (Math_fround(Math_sqrt((Math_fround($840)))));
       $843 = Math_fround(Math_fround(1.0) / $842);
       $844 = Math_fround($822 * $843);
       $845 = Math_fround($826 * $843);
       $846 = Math_fround($829 * $843);
       $847 = $844;$848 = $845;$849 = $846;
      } else {
       $847 = Math_fround(0.0);$848 = Math_fround(0.0);$849 = Math_fround(0.0);
      }
      HEAPF32[$Cross$i>>2] = $847;
      HEAPF32[$785>>2] = $848;
      HEAPF32[$786>>2] = $849;
      $850 = Math_fround($847 * $307);
      $851 = Math_fround($848 * $309);
      $852 = Math_fround($850 + $851);
      $853 = Math_fround($849 * $311);
      $854 = Math_fround($852 + $853);
      $855 = Math_fround($847 * $314);
      $856 = Math_fround($848 * $315);
      $857 = Math_fround($855 + $856);
      $858 = Math_fround($849 * $316);
      $859 = Math_fround($857 + $858);
      $860 = $854 > $859;
      $861 = $860 ? $859 : $854;
      $862 = $860 ? $854 : $859;
      $863 = Math_fround($861 - $661);
      $864 = Math_fround($661 + $862);
      $865 = HEAP32[$787>>2]|0;
      FUNCTION_TABLE_viiiiii[$865 & 255]($polyData,$Cross$i,$worldTM$i,$convexScaling,$Min1$i$i,$Max1$i$i);
      $866 = Math_fround(HEAPF32[$Min1$i$i>>2]);
      $867 = $864 < $866;
      if ($867) {
       $$1 = 0;
       label = 64;
       break;
      }
      $868 = Math_fround(HEAPF32[$Max1$i$i>>2]);
      $869 = $868 < $863;
      if ($869) {
       $$1 = 0;
       label = 64;
       break;
      }
      $870 = Math_fround($864 - $866);
      $871 = Math_fround($868 - $863);
      $872 = $870 < $871;
      $873 = $872 ? $870 : $871;
      $874 = $873 < $PenDepth$225$i;
      if ($874) {
       $875 = Math_fround(HEAPF32[$Cross$i>>2]);
       $876 = Math_fround(HEAPF32[$785>>2]);
       $877 = Math_fround(HEAPF32[$786>>2]);
       $1227 = $877;$1228 = $876;$1229 = $875;$PenDepth$3$i = $873;
      } else {
       $1227 = $1226;$1228 = $1225;$1229 = $1224;$PenDepth$3$i = $PenDepth$225$i;
      }
     }
     $878 = (($i1$024$i) + 1)|0;
     $879 = ($878>>>0)<($663>>>0);
     if ($879) {
      $1224 = $1229;$1225 = $1228;$1226 = $1227;$PenDepth$225$i = $PenDepth$3$i;$i1$024$i = $878;
     } else {
      $939 = $1229;$941 = $1228;$944 = $1227;
      break L58;
     }
    }
    if ((label|0) == 64) {
     STACKTOP = sp;return ($$1|0);
    }
   }
  }
 } while(0);
 $880 = Math_fround($307 + $314);
 $881 = Math_fround($309 + $315);
 $882 = Math_fround($311 + $316);
 $883 = Math_fround($880 * Math_fround(0.5));
 $884 = Math_fround($881 * Math_fround(0.5));
 $885 = Math_fround($882 * Math_fround(0.5));
 $886 = Math_fround(HEAPF32[$polyData>>2]);
 $887 = Math_fround($886 * Math_fround(2.0));
 $888 = (($polyData) + 4|0);
 $889 = Math_fround(HEAPF32[$888>>2]);
 $890 = Math_fround($889 * Math_fround(2.0));
 $891 = (($polyData) + 8|0);
 $892 = Math_fround(HEAPF32[$891>>2]);
 $893 = Math_fround($892 * Math_fround(2.0));
 $894 = Math_fround(HEAPF32[$37>>2]);
 $895 = Math_fround($894 * $894);
 $896 = Math_fround($895 + Math_fround(-0.5));
 $897 = Math_fround(HEAPF32[$transform1>>2]);
 $898 = Math_fround($887 * $897);
 $899 = Math_fround(HEAPF32[$31>>2]);
 $900 = Math_fround($890 * $899);
 $901 = Math_fround($898 + $900);
 $902 = Math_fround(HEAPF32[$34>>2]);
 $903 = Math_fround($893 * $902);
 $904 = Math_fround($901 + $903);
 $905 = Math_fround($887 * $896);
 $906 = Math_fround($893 * $899);
 $907 = Math_fround($890 * $902);
 $908 = Math_fround($906 - $907);
 $909 = Math_fround($894 * $908);
 $910 = Math_fround($905 + $909);
 $911 = Math_fround($897 * $904);
 $912 = Math_fround($911 + $910);
 $913 = Math_fround($890 * $896);
 $914 = Math_fround($887 * $902);
 $915 = Math_fround($893 * $897);
 $916 = Math_fround($914 - $915);
 $917 = Math_fround($894 * $916);
 $918 = Math_fround($913 + $917);
 $919 = Math_fround($899 * $904);
 $920 = Math_fround($919 + $918);
 $921 = Math_fround($893 * $896);
 $922 = Math_fround($890 * $897);
 $923 = Math_fround($887 * $899);
 $924 = Math_fround($922 - $923);
 $925 = Math_fround($894 * $924);
 $926 = Math_fround($921 + $925);
 $927 = Math_fround($902 * $904);
 $928 = Math_fround($926 + $927);
 $929 = Math_fround(HEAPF32[$41>>2]);
 $930 = Math_fround($929 + $912);
 $931 = Math_fround(HEAPF32[$46>>2]);
 $932 = Math_fround($931 + $920);
 $933 = Math_fround(HEAPF32[$51>>2]);
 $934 = Math_fround($933 + $928);
 $935 = Math_fround($883 - $930);
 $936 = Math_fround($884 - $932);
 $937 = Math_fround($885 - $934);
 $938 = Math_fround($939 * $935);
 $940 = Math_fround($941 * $936);
 $942 = Math_fround($938 + $940);
 $943 = Math_fround($944 * $937);
 $945 = Math_fround($943 + $942);
 $946 = $945 < Math_fround(0.0);
 if ($946) {
  $947 = Math_fround(-$939);
  $948 = Math_fround(-$941);
  $949 = Math_fround(-$944);
  $950 = $947;$952 = $948;$954 = $949;
 } else {
  $950 = $939;$952 = $941;$954 = $944;
 }
 HEAPF32[$SepAxis>>2] = $950;
 $951 = (($SepAxis) + 4|0);
 HEAPF32[$951>>2] = $952;
 $953 = (($SepAxis) + 8|0);
 HEAPF32[$953>>2] = $954;
 $955 = Math_fround(HEAPF32[$7>>2]);
 $956 = Math_fround(HEAPF32[$contactDistance>>2]);
 __ZL22PxcGenerateVFContacts2RN5physx2Gu13ContactBufferERKNS_11PxTransformERKNS0_13PolygonalDataERKNS_11PxMeshScaleEjPKNS_6PxVec3EfRSD_f($contactBuffer,$transform1,$polyData,$9,$323,$worldSegment,$955,$SepAxis,$956);
 $957 = (($contactBuffer) + 4096|0);
 $958 = HEAP32[$957>>2]|0;
 $959 = ($958|0)==(2);
 $brmerge = $959 | $324;
 if ($brmerge) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $960 = Math_fround(HEAPF32[$7>>2]);
 $961 = Math_fround(HEAPF32[$contactDistance>>2]);
 $962 = HEAP32[$662>>2]|0;
 $963 = HEAP32[$664>>2]|0;
 $964 = (($polyData) + 32|0);
 $965 = HEAP32[$964>>2]|0;
 $966 = (__ZN5physx2Gu21findUniqueConvexEdgesEjPNS0_10ConvexEdgeEjPKNS0_15HullPolygonDataEPKh(512,$edges$i,$962,$963,$965)|0);
 $967 = Math_fround(HEAPF32[$worldSegment>>2]);
 HEAPF32[$s0$i>>2] = $967;
 $968 = (($s0$i) + 4|0);
 $969 = Math_fround(HEAPF32[$312>>2]);
 HEAPF32[$968>>2] = $969;
 $970 = (($s0$i) + 8|0);
 $971 = Math_fround(HEAPF32[$313>>2]);
 HEAPF32[$970>>2] = $971;
 $972 = Math_fround(HEAPF32[$317>>2]);
 HEAPF32[$s1$i>>2] = $972;
 $973 = (($s1$i) + 4|0);
 $974 = Math_fround(HEAPF32[$318>>2]);
 HEAPF32[$973>>2] = $974;
 $975 = (($s1$i) + 8|0);
 $976 = Math_fround(HEAPF32[$319>>2]);
 HEAPF32[$975>>2] = $976;
 $977 = Math_fround($972 - $967);
 $978 = Math_fround($974 - $969);
 $979 = Math_fround($976 - $971);
 $980 = Math_fround($977 * $977);
 $981 = Math_fround($978 * $978);
 $982 = Math_fround($980 + $981);
 $983 = Math_fround($979 * $979);
 $984 = Math_fround($982 + $983);
 $985 = (Math_fround(Math_sqrt((Math_fround($984)))));
 $986 = $985 > Math_fround(0.0);
 if ($986) {
  $987 = Math_fround(Math_fround(0.00999999977648258209228) / $985);
  $988 = Math_fround($977 * $987);
  $989 = Math_fround($978 * $987);
  $990 = Math_fround($979 * $987);
  $991 = Math_fround($967 - $988);
  HEAPF32[$s0$i>>2] = $991;
  $992 = Math_fround($969 - $989);
  HEAPF32[$968>>2] = $992;
  $993 = Math_fround($971 - $990);
  HEAPF32[$970>>2] = $993;
  $994 = Math_fround($972 + $988);
  HEAPF32[$s1$i>>2] = $994;
  $995 = Math_fround($974 + $989);
  HEAPF32[$973>>2] = $995;
  $996 = Math_fround($976 + $990);
  HEAPF32[$975>>2] = $996;
  $1001 = $992;$1002 = $995;$1004 = $993;$1005 = $996;$998 = $991;$999 = $994;
 } else {
  $1001 = $969;$1002 = $974;$1004 = $971;$1005 = $976;$998 = $967;$999 = $972;
 }
 $997 = Math_fround($999 - $998);
 $1000 = Math_fround($1002 - $1001);
 $1003 = Math_fround($1005 - $1004);
 HEAPF32[$v1$i>>2] = $997;
 $1006 = (($v1$i) + 4|0);
 HEAPF32[$1006>>2] = $1000;
 $1007 = (($v1$i) + 8|0);
 HEAPF32[$1007>>2] = $1003;
 $1008 = Math_fround(HEAPF32[$953>>2]);
 $1009 = Math_fround($1000 * $1008);
 $1010 = Math_fround(HEAPF32[$951>>2]);
 $1011 = Math_fround($1003 * $1010);
 $1012 = Math_fround($1009 - $1011);
 $1013 = Math_fround(HEAPF32[$SepAxis>>2]);
 $1014 = Math_fround($1003 * $1013);
 $1015 = Math_fround($1008 * $997);
 $1016 = Math_fround($1014 - $1015);
 $1017 = Math_fround($997 * $1010);
 $1018 = Math_fround($1000 * $1013);
 $1019 = Math_fround($1017 - $1018);
 HEAPF32[$plane$i>>2] = $1012;
 $1020 = (($plane$i) + 4|0);
 HEAPF32[$1020>>2] = $1016;
 $1021 = (($plane$i) + 8|0);
 HEAPF32[$1021>>2] = $1019;
 $1022 = Math_fround($998 * $1012);
 $1023 = Math_fround($1001 * $1016);
 $1024 = Math_fround($1022 + $1023);
 $1025 = Math_fround($1004 * $1019);
 $1026 = Math_fround($1025 + $1024);
 $1027 = Math_fround(-$1026);
 $1028 = (($plane$i) + 12|0);
 HEAPF32[$1028>>2] = $1027;
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($1012)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($1016)))));
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($1019)))));
 $1029 = $fabsf$i$i1$i$i > $fabsf$i$i$i$i;
 $1030 = $fabsf$i$i1$i$i > $fabsf$i$i2$i$i;
 $or$cond$i$i = $1029 & $1030;
 if ($or$cond$i$i) {
  $1033 = 2;$1036 = 0;
 } else {
  $1031 = $fabsf$i$i2$i$i > $fabsf$i$i$i$i;
  if ($1031) {
   $1033 = 0;$1036 = 1;
  } else {
   $1033 = 1;$1036 = 2;
  }
 }
 $1032 = (($v1$i) + ($1033<<2)|0);
 $1034 = Math_fround(HEAPF32[$1032>>2]);
 $1035 = (($SepAxis) + ($1036<<2)|0);
 $1037 = Math_fround(HEAPF32[$1035>>2]);
 $1038 = Math_fround($1034 * $1037);
 $1039 = (($v1$i) + ($1036<<2)|0);
 $1040 = Math_fround(HEAPF32[$1039>>2]);
 $1041 = (($SepAxis) + ($1033<<2)|0);
 $1042 = Math_fround(HEAPF32[$1041>>2]);
 $1043 = Math_fround($1040 * $1042);
 $1044 = Math_fround($1038 - $1043);
 $1045 = Math_fround(Math_fround(1.0) / $1044);
 $1046 = (($polyData) + 28|0);
 $1047 = HEAP32[$1046>>2]|0;
 $1048 = ($966|0)==(0);
 if ($1048) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $1049 = Math_fround(-$960);
 $1050 = Math_fround($1049 - $961);
 $1051 = (($ip$i) + 8|0);
 $1052 = (($ip$i) + 4|0);
 $i$017$i = 0;
 while(1) {
  $1053 = (($edges$i) + ($i$017$i<<4)|0);
  $1054 = HEAP8[$1053>>0]|0;
  $1055 = ((($edges$i) + ($i$017$i<<4)|0) + 1|0);
  $1056 = HEAP8[$1055>>0]|0;
  $1057 = $1054&255;
  $1058 = (($1047) + (($1057*12)|0)|0);
  $1059 = Math_fround(HEAPF32[$1058>>2]);
  $1060 = Math_fround(HEAPF32[$convexScaling>>2]);
  $1061 = Math_fround($1059 * $1060);
  $1062 = Math_fround(HEAPF32[$325>>2]);
  $1063 = Math_fround($1059 * $1062);
  $1064 = Math_fround(HEAPF32[$326>>2]);
  $1065 = Math_fround($1059 * $1064);
  $1066 = ((($1047) + (($1057*12)|0)|0) + 4|0);
  $1067 = Math_fround(HEAPF32[$1066>>2]);
  $1068 = Math_fround(HEAPF32[$327>>2]);
  $1069 = Math_fround($1067 * $1068);
  $1070 = Math_fround(HEAPF32[$328>>2]);
  $1071 = Math_fround($1067 * $1070);
  $1072 = Math_fround(HEAPF32[$329>>2]);
  $1073 = Math_fround($1067 * $1072);
  $1074 = Math_fround($1061 + $1069);
  $1075 = Math_fround($1063 + $1071);
  $1076 = Math_fround($1065 + $1073);
  $1077 = ((($1047) + (($1057*12)|0)|0) + 8|0);
  $1078 = Math_fround(HEAPF32[$1077>>2]);
  $1079 = Math_fround(HEAPF32[$330>>2]);
  $1080 = Math_fround($1078 * $1079);
  $1081 = Math_fround(HEAPF32[$331>>2]);
  $1082 = Math_fround($1078 * $1081);
  $1083 = Math_fround(HEAPF32[$332>>2]);
  $1084 = Math_fround($1078 * $1083);
  $1085 = Math_fround($1074 + $1080);
  $1086 = Math_fround($1075 + $1082);
  $1087 = Math_fround($1076 + $1084);
  $1088 = Math_fround($1085 * Math_fround(2.0));
  $1089 = Math_fround($1086 * Math_fround(2.0));
  $1090 = Math_fround($1087 * Math_fround(2.0));
  $1091 = Math_fround(HEAPF32[$37>>2]);
  $1092 = Math_fround($1091 * $1091);
  $1093 = Math_fround($1092 + Math_fround(-0.5));
  $1094 = Math_fround(HEAPF32[$transform1>>2]);
  $1095 = Math_fround($1088 * $1094);
  $1096 = Math_fround(HEAPF32[$31>>2]);
  $1097 = Math_fround($1089 * $1096);
  $1098 = Math_fround($1095 + $1097);
  $1099 = Math_fround(HEAPF32[$34>>2]);
  $1100 = Math_fround($1090 * $1099);
  $1101 = Math_fround($1098 + $1100);
  $1102 = Math_fround($1088 * $1093);
  $1103 = Math_fround($1090 * $1096);
  $1104 = Math_fround($1089 * $1099);
  $1105 = Math_fround($1103 - $1104);
  $1106 = Math_fround($1091 * $1105);
  $1107 = Math_fround($1102 + $1106);
  $1108 = Math_fround($1094 * $1101);
  $1109 = Math_fround($1108 + $1107);
  $1110 = Math_fround($1089 * $1093);
  $1111 = Math_fround($1088 * $1099);
  $1112 = Math_fround($1094 * $1090);
  $1113 = Math_fround($1111 - $1112);
  $1114 = Math_fround($1091 * $1113);
  $1115 = Math_fround($1110 + $1114);
  $1116 = Math_fround($1096 * $1101);
  $1117 = Math_fround($1116 + $1115);
  $1118 = Math_fround($1090 * $1093);
  $1119 = Math_fround($1089 * $1094);
  $1120 = Math_fround($1088 * $1096);
  $1121 = Math_fround($1119 - $1120);
  $1122 = Math_fround($1091 * $1121);
  $1123 = Math_fround($1118 + $1122);
  $1124 = Math_fround($1099 * $1101);
  $1125 = Math_fround($1123 + $1124);
  $1126 = Math_fround(HEAPF32[$41>>2]);
  $1127 = Math_fround($1126 + $1109);
  $1128 = Math_fround(HEAPF32[$46>>2]);
  $1129 = Math_fround($1128 + $1117);
  $1130 = Math_fround(HEAPF32[$51>>2]);
  $1131 = Math_fround($1130 + $1125);
  $1132 = $1056&255;
  $1133 = (($1047) + (($1132*12)|0)|0);
  $1134 = Math_fround(HEAPF32[$1133>>2]);
  $1135 = Math_fround($1060 * $1134);
  $1136 = Math_fround($1062 * $1134);
  $1137 = Math_fround($1064 * $1134);
  $1138 = ((($1047) + (($1132*12)|0)|0) + 4|0);
  $1139 = Math_fround(HEAPF32[$1138>>2]);
  $1140 = Math_fround($1068 * $1139);
  $1141 = Math_fround($1070 * $1139);
  $1142 = Math_fround($1072 * $1139);
  $1143 = Math_fround($1135 + $1140);
  $1144 = Math_fround($1136 + $1141);
  $1145 = Math_fround($1137 + $1142);
  $1146 = ((($1047) + (($1132*12)|0)|0) + 8|0);
  $1147 = Math_fround(HEAPF32[$1146>>2]);
  $1148 = Math_fround($1079 * $1147);
  $1149 = Math_fround($1081 * $1147);
  $1150 = Math_fround($1083 * $1147);
  $1151 = Math_fround($1143 + $1148);
  $1152 = Math_fround($1144 + $1149);
  $1153 = Math_fround($1145 + $1150);
  $1154 = Math_fround($1151 * Math_fround(2.0));
  $1155 = Math_fround($1152 * Math_fround(2.0));
  $1156 = Math_fround($1153 * Math_fround(2.0));
  $1157 = Math_fround($1094 * $1154);
  $1158 = Math_fround($1096 * $1155);
  $1159 = Math_fround($1157 + $1158);
  $1160 = Math_fround($1099 * $1156);
  $1161 = Math_fround($1160 + $1159);
  $1162 = Math_fround($1093 * $1154);
  $1163 = Math_fround($1096 * $1156);
  $1164 = Math_fround($1099 * $1155);
  $1165 = Math_fround($1163 - $1164);
  $1166 = Math_fround($1091 * $1165);
  $1167 = Math_fround($1162 + $1166);
  $1168 = Math_fround($1094 * $1161);
  $1169 = Math_fround($1168 + $1167);
  $1170 = Math_fround($1093 * $1155);
  $1171 = Math_fround($1099 * $1154);
  $1172 = Math_fround($1094 * $1156);
  $1173 = Math_fround($1171 - $1172);
  $1174 = Math_fround($1091 * $1173);
  $1175 = Math_fround($1170 + $1174);
  $1176 = Math_fround($1096 * $1161);
  $1177 = Math_fround($1176 + $1175);
  $1178 = Math_fround($1093 * $1156);
  $1179 = Math_fround($1094 * $1155);
  $1180 = Math_fround($1096 * $1154);
  $1181 = Math_fround($1179 - $1180);
  $1182 = Math_fround($1091 * $1181);
  $1183 = Math_fround($1178 + $1182);
  $1184 = Math_fround($1099 * $1161);
  $1185 = Math_fround($1183 + $1184);
  $1186 = Math_fround($1126 + $1169);
  $1187 = Math_fround($1128 + $1177);
  $1188 = Math_fround($1130 + $1185);
  $1189 = (__ZL22intersectEdgeEdgePrecaRKN5physx6PxVec3ES2_S2_RKNS_7PxPlaneEjjfS2_S2_S2_RfRS0_f($s0$i,$s1$i,$v1$i,$plane$i,$1033,$1036,$1045,$SepAxis,$1127,$1129,$1131,$1186,$1187,$1188,$dist$i,$ip$i,$1050)|0);
  if ($1189) {
   $1190 = Math_fround(HEAPF32[$dist$i>>2]);
   $1191 = HEAP32[$957>>2]|0;
   $1192 = ($1191>>>0)>(63);
   if (!($1192)) {
    $1193 = Math_fround(HEAPF32[$953>>2]);
    $1194 = Math_fround(HEAPF32[$951>>2]);
    $1195 = Math_fround(HEAPF32[$SepAxis>>2]);
    $1196 = Math_fround($960 + $1190);
    $1197 = Math_fround(HEAPF32[$1051>>2]);
    $1198 = Math_fround(HEAPF32[$1052>>2]);
    $1199 = Math_fround(HEAPF32[$ip$i>>2]);
    $1200 = Math_fround($1190 * $1193);
    $1201 = Math_fround($1190 * $1194);
    $1202 = Math_fround($1190 * $1195);
    $1203 = Math_fround(-$1196);
    $1204 = Math_fround($1197 - $1200);
    $1205 = Math_fround($1198 - $1201);
    $1206 = Math_fround($1199 - $1202);
    $1207 = (($1191) + 1)|0;
    HEAP32[$957>>2] = $1207;
    $1208 = (($contactBuffer) + ($1191<<6)|0);
    HEAPF32[$1208>>2] = $1195;
    $1209 = ((($contactBuffer) + ($1191<<6)|0) + 4|0);
    HEAPF32[$1209>>2] = $1194;
    $1210 = ((($contactBuffer) + ($1191<<6)|0) + 8|0);
    HEAPF32[$1210>>2] = $1193;
    $1211 = ((($contactBuffer) + ($1191<<6)|0) + 16|0);
    HEAPF32[$1211>>2] = $1206;
    $1212 = ((($contactBuffer) + ($1191<<6)|0) + 20|0);
    HEAPF32[$1212>>2] = $1205;
    $1213 = ((($contactBuffer) + ($1191<<6)|0) + 24|0);
    HEAPF32[$1213>>2] = $1204;
    $1214 = ((($contactBuffer) + ($1191<<6)|0) + 12|0);
    HEAPF32[$1214>>2] = $1203;
    $1215 = ((($contactBuffer) + ($1191<<6)|0) + 48|0);
    HEAP32[$1215>>2] = -1;
    $1216 = ((($contactBuffer) + ($1191<<6)|0) + 52|0);
    HEAP32[$1216>>2] = -1;
   }
  }
  $1217 = (($i$017$i) + 1)|0;
  $exitcond$i = ($1217|0)==($966|0);
  if ($exitcond$i) {
   $$1 = 1;
   break;
  } else {
   $i$017$i = $1217;
  }
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZL22PxcGenerateVFContacts2RN5physx2Gu13ContactBufferERKNS_11PxTransformERKNS0_13PolygonalDataERKNS_11PxMeshScaleEjPKNS_6PxVec3EfRSD_f($contactBuffer,$convexPose,$polyData,$scale,$nbPts,$points,$radius,$normal,$contactDistance) {
 $contactBuffer = $contactBuffer|0;
 $convexPose = $convexPose|0;
 $polyData = $polyData|0;
 $scale = $scale|0;
 $nbPts = $nbPts|0;
 $points = $points|0;
 $radius = Math_fround($radius);
 $normal = $normal|0;
 $contactDistance = Math_fround($contactDistance);
 var $$pre = Math_fround(0), $$pre41 = Math_fround(0), $$pre42 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $earlyestExit$0$ph$i = Math_fround(0), $exitcond = 0, $i$029 = 0, $latestEntry$0$ph$i = Math_fround(0), $latestEntry$0$ph2$i = Math_fround(0), $nPolys$0$i = 0, $nPolys$0$ph$i = 0, $nPolys$0$ph4$i = 0, $normal$idx$val = Math_fround(0), $normal$idx6$val = Math_fround(0), $normal$idx7$val = Math_fround(0), $or$cond$i = 0, $polyData$idx = 0;
 var $polyData$idx$val = 0, $polyData$idx1 = 0, $polyData$idx1$val = 0, $polys$0$i = 0, $polys$0$ph$i = 0, $polys$0$ph3$i = 0, $world2vertexSkew = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $world2vertexSkew = sp + 56|0;
 $0 = sp;
 $1 = sp + 28|0;
 $2 = Math_fround(HEAPF32[$scale>>2]);
 $3 = Math_fround(Math_fround(1.0) / $2);
 $4 = (($scale) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(Math_fround(1.0) / $5);
 $7 = (($scale) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(Math_fround(1.0) / $8);
 HEAPF32[$0>>2] = $3;
 $10 = (($0) + 4|0);
 HEAPF32[$10>>2] = $6;
 $11 = (($0) + 8|0);
 HEAPF32[$11>>2] = $9;
 $12 = (($scale) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($0) + 12|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($scale) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($0) + 16|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($scale) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($0) + 20|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($scale) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($0) + 24|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($convexPose) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($convexPose) + 20|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($convexPose) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($25 * Math_fround(-2.0));
 $31 = Math_fround($27 * Math_fround(-2.0));
 $32 = Math_fround($29 * Math_fround(-2.0));
 $33 = (($convexPose) + 12|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $34);
 $36 = Math_fround($35 + Math_fround(-0.5));
 $37 = Math_fround(HEAPF32[$convexPose>>2]);
 $38 = Math_fround($30 * $37);
 $39 = (($convexPose) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($31 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($convexPose) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($32 * $44);
 $46 = Math_fround($42 + $45);
 $47 = Math_fround($30 * $36);
 $48 = Math_fround($32 * $40);
 $49 = Math_fround($31 * $44);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($34 * $50);
 $52 = Math_fround($47 - $51);
 $53 = Math_fround($37 * $46);
 $54 = Math_fround($53 + $52);
 $55 = Math_fround($31 * $36);
 $56 = Math_fround($30 * $44);
 $57 = Math_fround($32 * $37);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($34 * $58);
 $60 = Math_fround($55 - $59);
 $61 = Math_fround($40 * $46);
 $62 = Math_fround($61 + $60);
 $63 = Math_fround($32 * $36);
 $64 = Math_fround($31 * $37);
 $65 = Math_fround($30 * $40);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround($34 * $66);
 $68 = Math_fround($63 - $67);
 $69 = Math_fround($44 * $46);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround(-$37);
 $72 = Math_fround(-$40);
 $73 = Math_fround(-$44);
 HEAPF32[$1>>2] = $71;
 $74 = (($1) + 4|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($1) + 8|0);
 HEAPF32[$75>>2] = $73;
 $76 = (($1) + 12|0);
 HEAPF32[$76>>2] = $34;
 $77 = (($1) + 16|0);
 HEAPF32[$77>>2] = $54;
 $78 = (($1) + 20|0);
 HEAPF32[$78>>2] = $62;
 $79 = (($1) + 24|0);
 HEAPF32[$79>>2] = $70;
 __ZN5physxmlERKNS_11PxMeshScaleERKNS_11PxTransformE($world2vertexSkew,$0,$1);
 $80 = Math_fround(HEAPF32[$normal>>2]);
 $81 = Math_fround(-$80);
 $82 = (($normal) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround(-$83);
 $85 = (($normal) + 8|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround(-$86);
 $88 = Math_fround(HEAPF32[$world2vertexSkew>>2]);
 $89 = Math_fround($88 * $81);
 $90 = (($world2vertexSkew) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 * $81);
 $93 = (($world2vertexSkew) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 * $81);
 $96 = (($world2vertexSkew) + 12|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 * $84);
 $99 = (($world2vertexSkew) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 * $84);
 $102 = (($world2vertexSkew) + 20|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($103 * $84);
 $105 = Math_fround($89 + $98);
 $106 = Math_fround($92 + $101);
 $107 = Math_fround($95 + $104);
 $108 = (($world2vertexSkew) + 24|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($109 * $87);
 $111 = (($world2vertexSkew) + 28|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($112 * $87);
 $114 = (($world2vertexSkew) + 32|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($115 * $87);
 $117 = Math_fround($105 + $110);
 $118 = Math_fround($106 + $113);
 $119 = Math_fround($107 + $116);
 $120 = Math_fround($radius + $contactDistance);
 $121 = ($nbPts|0)==(0);
 if ($121) {
  STACKTOP = sp;return;
 }
 $122 = (($world2vertexSkew) + 36|0);
 $123 = (($world2vertexSkew) + 40|0);
 $124 = (($world2vertexSkew) + 44|0);
 $polyData$idx = (($polyData) + 16|0);
 $polyData$idx1 = (($polyData) + 24|0);
 $polyData$idx1$val = HEAP32[$polyData$idx1>>2]|0;
 $125 = (($contactBuffer) + 4096|0);
 $$pre = Math_fround(HEAPF32[$122>>2]);
 $$pre41 = Math_fround(HEAPF32[$123>>2]);
 $$pre42 = Math_fround(HEAPF32[$124>>2]);
 $i$029 = 0;
 while(1) {
  $126 = (($points) + (($i$029*12)|0)|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = Math_fround($127 * $88);
  $129 = Math_fround($127 * $91);
  $130 = Math_fround($127 * $94);
  $131 = ((($points) + (($i$029*12)|0)|0) + 4|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = Math_fround($132 * $97);
  $134 = Math_fround($132 * $100);
  $135 = Math_fround($132 * $103);
  $136 = Math_fround($128 + $133);
  $137 = Math_fround($129 + $134);
  $138 = Math_fround($130 + $135);
  $139 = ((($points) + (($i$029*12)|0)|0) + 8|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = Math_fround($140 * $109);
  $142 = Math_fround($140 * $112);
  $143 = Math_fround($140 * $115);
  $144 = Math_fround($136 + $141);
  $145 = Math_fround($137 + $142);
  $146 = Math_fround($138 + $143);
  $147 = Math_fround($144 + $$pre);
  $148 = Math_fround($145 + $$pre41);
  $149 = Math_fround($146 + $$pre42);
  $polyData$idx$val = HEAP32[$polyData$idx>>2]|0;
  $earlyestExit$0$ph$i = Math_fround(3.40282346638528859812E+38);$latestEntry$0$ph$i = Math_fround(-3.40282346638528859812E+38);$nPolys$0$ph$i = $polyData$idx$val;$polys$0$ph$i = $polyData$idx1$val;
  L6: while(1) {
   $latestEntry$0$ph2$i = $latestEntry$0$ph$i;$nPolys$0$ph4$i = $nPolys$0$ph$i;$polys$0$ph3$i = $polys$0$ph$i;
   L8: while(1) {
    $nPolys$0$i = $nPolys$0$ph4$i;$polys$0$i = $polys$0$ph3$i;
    while(1) {
     $150 = (($nPolys$0$i) + -1)|0;
     $151 = ($nPolys$0$i|0)==(0);
     if ($151) {
      label = 12;
      break L6;
     }
     $152 = (($polys$0$i) + 20|0);
     $153 = Math_fround(HEAPF32[$polys$0$i>>2]);
     $154 = Math_fround($147 * $153);
     $155 = (($polys$0$i) + 4|0);
     $156 = Math_fround(HEAPF32[$155>>2]);
     $157 = Math_fround($148 * $156);
     $158 = Math_fround($154 + $157);
     $159 = (($polys$0$i) + 8|0);
     $160 = Math_fround(HEAPF32[$159>>2]);
     $161 = Math_fround($149 * $160);
     $162 = Math_fround($158 + $161);
     $163 = (($polys$0$i) + 12|0);
     $164 = Math_fround(HEAPF32[$163>>2]);
     $165 = Math_fround($164 + $162);
     $166 = Math_fround($117 * $153);
     $167 = Math_fround($118 * $156);
     $168 = Math_fround($166 + $167);
     $169 = Math_fround($119 * $160);
     $170 = Math_fround($168 + $169);
     $171 = Math_fround(-$165);
     $172 = Math_fround($171 / $170);
     $173 = $170 > Math_fround(1.00000001168609742308E-7);
     if ($173) {
      break L8;
     }
     $176 = $170 < Math_fround(-1.00000001168609742308E-7);
     if ($176) {
      break;
     }
     $179 = $165 > Math_fround(0.0);
     if ($179) {
      break L6;
     } else {
      $nPolys$0$i = $150;$polys$0$i = $152;
     }
    }
    $177 = $latestEntry$0$ph2$i > $172;
    $178 = $177 ? $latestEntry$0$ph2$i : $172;
    $latestEntry$0$ph2$i = $178;$nPolys$0$ph4$i = $150;$polys$0$ph3$i = $152;
   }
   $174 = $earlyestExit$0$ph$i < $172;
   $175 = $174 ? $earlyestExit$0$ph$i : $172;
   $earlyestExit$0$ph$i = $175;$latestEntry$0$ph$i = $latestEntry$0$ph2$i;$nPolys$0$ph$i = $150;$polys$0$ph$i = $152;
  }
  if ((label|0) == 12) {
   label = 0;
   $180 = $latestEntry$0$ph2$i < $earlyestExit$0$ph$i;
   $181 = $latestEntry$0$ph2$i < $120;
   $or$cond$i = $180 & $181;
   if ($or$cond$i) {
    $182 = HEAP32[$125>>2]|0;
    $183 = ($182>>>0)>(63);
    if (!($183)) {
     $normal$idx7$val = Math_fround(HEAPF32[$85>>2]);
     $normal$idx6$val = Math_fround(HEAPF32[$82>>2]);
     $normal$idx$val = Math_fround(HEAPF32[$normal>>2]);
     $184 = Math_fround($latestEntry$0$ph2$i * $normal$idx7$val);
     $185 = Math_fround($latestEntry$0$ph2$i * $normal$idx6$val);
     $186 = Math_fround($latestEntry$0$ph2$i * $normal$idx$val);
     $187 = Math_fround($latestEntry$0$ph2$i - $radius);
     $188 = Math_fround($140 - $184);
     $189 = Math_fround($132 - $185);
     $190 = Math_fround($127 - $186);
     $191 = (($182) + 1)|0;
     HEAP32[$125>>2] = $191;
     $192 = (($contactBuffer) + ($182<<6)|0);
     HEAPF32[$192>>2] = $normal$idx$val;
     $193 = Math_fround(HEAPF32[$82>>2]);
     $194 = ((($contactBuffer) + ($182<<6)|0) + 4|0);
     HEAPF32[$194>>2] = $193;
     $195 = Math_fround(HEAPF32[$85>>2]);
     $196 = ((($contactBuffer) + ($182<<6)|0) + 8|0);
     HEAPF32[$196>>2] = $195;
     $197 = ((($contactBuffer) + ($182<<6)|0) + 16|0);
     HEAPF32[$197>>2] = $190;
     $198 = ((($contactBuffer) + ($182<<6)|0) + 20|0);
     HEAPF32[$198>>2] = $189;
     $199 = ((($contactBuffer) + ($182<<6)|0) + 24|0);
     HEAPF32[$199>>2] = $188;
     $200 = ((($contactBuffer) + ($182<<6)|0) + 12|0);
     HEAPF32[$200>>2] = $187;
     $201 = ((($contactBuffer) + ($182<<6)|0) + 48|0);
     HEAP32[$201>>2] = -1;
     $202 = ((($contactBuffer) + ($182<<6)|0) + 52|0);
     HEAP32[$202>>2] = -1;
    }
   }
  }
  $203 = (($i$029) + 1)|0;
  $exitcond = ($203|0)==($nbPts|0);
  if ($exitcond) {
   break;
  } else {
   $i$029 = $203;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx22PxcContactSphereConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx23PxcContactCapsuleConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL22intersectEdgeEdgePrecaRKN5physx6PxVec3ES2_S2_RKNS_7PxPlaneEjjfS2_S2_S2_RfRS0_f($p1,$p2,$v1,$plane,$i,$j,$coeff,$dir,$p3$0$0$val,$p3$0$1$val,$p3$0$2$val,$p4$0$0$val,$p4$0$1$val,$p4$0$2$val,$dist,$ip,$limit) {
 $p1 = $p1|0;
 $p2 = $p2|0;
 $v1 = $v1|0;
 $plane = $plane|0;
 $i = $i|0;
 $j = $j|0;
 $coeff = Math_fround($coeff);
 $dir = $dir|0;
 $p3$0$0$val = Math_fround($p3$0$0$val);
 $p3$0$1$val = Math_fround($p3$0$1$val);
 $p3$0$2$val = Math_fround($p3$0$2$val);
 $p4$0$0$val = Math_fround($p4$0$0$val);
 $p4$0$1$val = Math_fround($p4$0$1$val);
 $p4$0$2$val = Math_fround($p4$0$2$val);
 $dist = $dist|0;
 $ip = $ip|0;
 $limit = Math_fround($limit);
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $9 = Math_fround(0), $dir$idx$val = Math_fround(0), $dir$idx1 = 0, $dir$idx1$val = Math_fround(0), $dir$idx2 = 0, $dir$idx2$val = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$plane>>2]);
 $1 = Math_fround($0 * $p3$0$0$val);
 $2 = (($plane) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $p3$0$1$val);
 $5 = Math_fround($1 + $4);
 $6 = (($plane) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $p3$0$2$val);
 $9 = Math_fround($5 + $8);
 $10 = (($plane) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 + $9);
 $13 = Math_fround($0 * $p4$0$0$val);
 $14 = Math_fround($3 * $p4$0$1$val);
 $15 = Math_fround($13 + $14);
 $16 = Math_fround($7 * $p4$0$2$val);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($11 + $17);
 $19 = Math_fround($12 * $18);
 $20 = $19 > Math_fround(0.0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = Math_fround($p4$0$0$val - $p3$0$0$val);
 $22 = Math_fround($p4$0$1$val - $p3$0$1$val);
 $23 = Math_fround($p4$0$2$val - $p3$0$2$val);
 $24 = Math_fround($21 * $0);
 $25 = Math_fround($22 * $3);
 $26 = Math_fround($24 + $25);
 $27 = Math_fround($23 * $7);
 $28 = Math_fround($26 + $27);
 $29 = $28 == Math_fround(0.0);
 if ($29) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = Math_fround($12 / $28);
 $31 = Math_fround($21 * $30);
 $32 = Math_fround($22 * $30);
 $33 = Math_fround($23 * $30);
 $34 = Math_fround($p3$0$0$val - $31);
 $35 = Math_fround($p3$0$1$val - $32);
 $36 = Math_fround($p3$0$2$val - $33);
 HEAPF32[$ip>>2] = $34;
 $37 = (($ip) + 4|0);
 HEAPF32[$37>>2] = $35;
 $38 = (($ip) + 8|0);
 HEAPF32[$38>>2] = $36;
 $39 = (($v1) + ($i<<2)|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($ip) + ($j<<2)|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($p1) + ($j<<2)|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($42 - $44);
 $46 = Math_fround($40 * $45);
 $47 = (($v1) + ($j<<2)|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($ip) + ($i<<2)|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($p1) + ($i<<2)|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($50 - $52);
 $54 = Math_fround($48 * $53);
 $55 = Math_fround($46 - $54);
 $56 = Math_fround($55 * $coeff);
 HEAPF32[$dist>>2] = $56;
 $57 = $56 < $limit;
 if ($57) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $dir$idx$val = Math_fround(HEAPF32[$dir>>2]);
 $dir$idx1 = (($dir) + 4|0);
 $dir$idx1$val = Math_fround(HEAPF32[$dir$idx1>>2]);
 $dir$idx2 = (($dir) + 8|0);
 $dir$idx2$val = Math_fround(HEAPF32[$dir$idx2>>2]);
 $58 = Math_fround($56 * $dir$idx$val);
 $59 = Math_fround($56 * $dir$idx1$val);
 $60 = Math_fround($56 * $dir$idx2$val);
 $61 = Math_fround(HEAPF32[$ip>>2]);
 $62 = Math_fround($61 - $58);
 HEAPF32[$ip>>2] = $62;
 $63 = Math_fround(HEAPF32[$37>>2]);
 $64 = Math_fround($63 - $59);
 HEAPF32[$37>>2] = $64;
 $65 = Math_fround(HEAPF32[$38>>2]);
 $66 = Math_fround($65 - $60);
 HEAPF32[$38>>2] = $66;
 $67 = Math_fround(HEAPF32[$p1>>2]);
 $68 = Math_fround($67 - $62);
 $69 = Math_fround(HEAPF32[$p2>>2]);
 $70 = Math_fround($69 - $62);
 $71 = Math_fround($68 * $70);
 $72 = (($p1) + 4|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 - $64);
 $75 = (($p2) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($76 - $64);
 $78 = Math_fround($74 * $77);
 $79 = Math_fround($71 + $78);
 $80 = (($p1) + 8|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 - $66);
 $83 = (($p2) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 - $66);
 $86 = Math_fround($82 * $85);
 $87 = Math_fround($79 + $86);
 $88 = $87 < Math_fround(0.0);
 $$0 = $88;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physxmlERKNS_11PxMeshScaleERKNS_11PxTransformE($agg$result,$scale,$transform) {
 $agg$result = $agg$result|0;
 $scale = $scale|0;
 $transform = $transform|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0);
 var $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($scale) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($scale) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($scale) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($scale) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($1 + $1);
 $9 = Math_fround($3 + $3);
 $10 = Math_fround($5 + $5);
 $11 = Math_fround($1 * $8);
 $12 = Math_fround($3 * $9);
 $13 = Math_fround($5 * $10);
 $14 = Math_fround($8 * $3);
 $15 = Math_fround($8 * $5);
 $16 = Math_fround($8 * $7);
 $17 = Math_fround($9 * $5);
 $18 = Math_fround($9 * $7);
 $19 = Math_fround($10 * $7);
 $20 = Math_fround(Math_fround(1.0) - $12);
 $21 = Math_fround($20 - $13);
 $22 = Math_fround($14 + $19);
 $23 = Math_fround($15 - $18);
 $24 = Math_fround($14 - $19);
 $25 = Math_fround(Math_fround(1.0) - $11);
 $26 = Math_fround($25 - $13);
 $27 = Math_fround($17 + $16);
 $28 = Math_fround($15 + $18);
 $29 = Math_fround($17 - $16);
 $30 = Math_fround($25 - $12);
 $31 = Math_fround(HEAPF32[$scale>>2]);
 $32 = Math_fround($31 * $21);
 $33 = Math_fround($31 * $24);
 $34 = Math_fround($31 * $28);
 $35 = (($scale) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($22 * $36);
 $38 = Math_fround($26 * $36);
 $39 = Math_fround($29 * $36);
 $40 = (($scale) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($23 * $41);
 $43 = Math_fround($27 * $41);
 $44 = Math_fround($30 * $41);
 $45 = Math_fround($21 * $32);
 $46 = Math_fround($21 * $33);
 $47 = Math_fround($21 * $34);
 $48 = Math_fround($22 * $37);
 $49 = Math_fround($22 * $38);
 $50 = Math_fround($22 * $39);
 $51 = Math_fround($45 + $48);
 $52 = Math_fround($46 + $49);
 $53 = Math_fround($47 + $50);
 $54 = Math_fround($23 * $42);
 $55 = Math_fround($23 * $43);
 $56 = Math_fround($23 * $44);
 $57 = Math_fround($51 + $54);
 $58 = Math_fround($52 + $55);
 $59 = Math_fround($53 + $56);
 $60 = Math_fround($24 * $32);
 $61 = Math_fround($24 * $33);
 $62 = Math_fround($24 * $34);
 $63 = Math_fround($26 * $37);
 $64 = Math_fround($26 * $38);
 $65 = Math_fround($26 * $39);
 $66 = Math_fround($60 + $63);
 $67 = Math_fround($61 + $64);
 $68 = Math_fround($62 + $65);
 $69 = Math_fround($27 * $42);
 $70 = Math_fround($27 * $43);
 $71 = Math_fround($27 * $44);
 $72 = Math_fround($66 + $69);
 $73 = Math_fround($67 + $70);
 $74 = Math_fround($68 + $71);
 $75 = Math_fround($28 * $32);
 $76 = Math_fround($28 * $33);
 $77 = Math_fround($28 * $34);
 $78 = Math_fround($29 * $37);
 $79 = Math_fround($29 * $38);
 $80 = Math_fround($29 * $39);
 $81 = Math_fround($75 + $78);
 $82 = Math_fround($76 + $79);
 $83 = Math_fround($77 + $80);
 $84 = Math_fround($30 * $42);
 $85 = Math_fround($30 * $43);
 $86 = Math_fround($30 * $44);
 $87 = Math_fround($81 + $84);
 $88 = Math_fround($82 + $85);
 $89 = Math_fround($83 + $86);
 $90 = Math_fround(HEAPF32[$transform>>2]);
 $91 = (($transform) + 4|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($transform) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($transform) + 12|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($90 + $90);
 $98 = Math_fround($92 + $92);
 $99 = Math_fround($94 + $94);
 $100 = Math_fround($90 * $97);
 $101 = Math_fround($92 * $98);
 $102 = Math_fround($94 * $99);
 $103 = Math_fround($97 * $92);
 $104 = Math_fround($97 * $94);
 $105 = Math_fround($97 * $96);
 $106 = Math_fround($98 * $94);
 $107 = Math_fround($98 * $96);
 $108 = Math_fround($99 * $96);
 $109 = Math_fround(Math_fround(1.0) - $101);
 $110 = Math_fround($109 - $102);
 $111 = Math_fround($103 + $108);
 $112 = Math_fround($104 - $107);
 $113 = Math_fround($103 - $108);
 $114 = Math_fround(Math_fround(1.0) - $100);
 $115 = Math_fround($114 - $102);
 $116 = Math_fround($106 + $105);
 $117 = Math_fround($104 + $107);
 $118 = Math_fround($106 - $105);
 $119 = Math_fround($114 - $101);
 $120 = Math_fround($57 * $110);
 $121 = Math_fround($58 * $110);
 $122 = Math_fround($59 * $110);
 $123 = Math_fround($72 * $111);
 $124 = Math_fround($73 * $111);
 $125 = Math_fround($74 * $111);
 $126 = Math_fround($120 + $123);
 $127 = Math_fround($121 + $124);
 $128 = Math_fround($122 + $125);
 $129 = Math_fround($87 * $112);
 $130 = Math_fround($88 * $112);
 $131 = Math_fround($89 * $112);
 $132 = Math_fround($129 + $126);
 $133 = Math_fround($130 + $127);
 $134 = Math_fround($131 + $128);
 $135 = Math_fround($57 * $113);
 $136 = Math_fround($58 * $113);
 $137 = Math_fround($59 * $113);
 $138 = Math_fround($72 * $115);
 $139 = Math_fround($73 * $115);
 $140 = Math_fround($74 * $115);
 $141 = Math_fround($135 + $138);
 $142 = Math_fround($136 + $139);
 $143 = Math_fround($137 + $140);
 $144 = Math_fround($87 * $116);
 $145 = Math_fround($88 * $116);
 $146 = Math_fround($89 * $116);
 $147 = Math_fround($144 + $141);
 $148 = Math_fround($145 + $142);
 $149 = Math_fround($146 + $143);
 $150 = Math_fround($57 * $117);
 $151 = Math_fround($58 * $117);
 $152 = Math_fround($59 * $117);
 $153 = Math_fround($72 * $118);
 $154 = Math_fround($73 * $118);
 $155 = Math_fround($74 * $118);
 $156 = Math_fround($150 + $153);
 $157 = Math_fround($151 + $154);
 $158 = Math_fround($152 + $155);
 $159 = Math_fround($87 * $119);
 $160 = Math_fround($88 * $119);
 $161 = Math_fround($89 * $119);
 $162 = Math_fround($159 + $156);
 $163 = Math_fround($160 + $157);
 $164 = Math_fround($161 + $158);
 $165 = (($transform) + 16|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = Math_fround($57 * $166);
 $168 = Math_fround($58 * $166);
 $169 = Math_fround($59 * $166);
 $170 = (($transform) + 20|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = Math_fround($72 * $171);
 $173 = Math_fround($73 * $171);
 $174 = Math_fround($74 * $171);
 $175 = Math_fround($167 + $172);
 $176 = Math_fround($168 + $173);
 $177 = Math_fround($169 + $174);
 $178 = (($transform) + 24|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround($87 * $179);
 $181 = Math_fround($88 * $179);
 $182 = Math_fround($89 * $179);
 $183 = Math_fround($175 + $180);
 $184 = Math_fround($176 + $181);
 $185 = Math_fround($177 + $182);
 HEAPF32[$agg$result>>2] = $132;
 $186 = (($agg$result) + 4|0);
 HEAPF32[$186>>2] = $133;
 $187 = (($agg$result) + 8|0);
 HEAPF32[$187>>2] = $134;
 $188 = (($agg$result) + 12|0);
 HEAPF32[$188>>2] = $147;
 $189 = (($agg$result) + 16|0);
 HEAPF32[$189>>2] = $148;
 $190 = (($agg$result) + 20|0);
 HEAPF32[$190>>2] = $149;
 $191 = (($agg$result) + 24|0);
 HEAPF32[$191>>2] = $162;
 $192 = (($agg$result) + 28|0);
 HEAPF32[$192>>2] = $163;
 $193 = (($agg$result) + 32|0);
 HEAPF32[$193>>2] = $164;
 $194 = (($agg$result) + 36|0);
 HEAPF32[$194>>2] = $183;
 $195 = (($agg$result) + 40|0);
 HEAPF32[$195>>2] = $184;
 $196 = (($agg$result) + 44|0);
 HEAPF32[$196>>2] = $185;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($this,$_hullData,$_center,$scale,$scaleRot) {
 $this = $this|0;
 $_hullData = $_hullData|0;
 $_center = $_center|0;
 $scale = $scale|0;
 $scaleRot = $scaleRot|0;
 var $$$i$i = Math_fround(0), $$$i12$i = Math_fround(0), $$$i23$i = Math_fround(0), $$$i26$i = Math_fround(0), $$pre = 0, $$sroa$1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $startAddress$04 = 0, $startAddress$12 = 0, $tmp1 = 0, $totalPrefetchBytes$05 = 0, $totalSize$03 = 0, $zero$sroa$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$sroa$1$i = sp;
 $zero$sroa$1$i = sp + 16|0;
 $0 = (($this) + 64|0);
 ;HEAP32[$this+0>>2]=HEAP32[$_center+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$_center+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$_center+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$_center+12>>2]|0;
 $1 = (($this) + 80|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 20|0);
 ;HEAP32[$3+0>>2]=HEAP32[$zero$sroa$1$i+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$zero$sroa$1$i+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$zero$sroa$1$i+8>>2]|0;
 $4 = (($this) + 32|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 36|0);
 ;HEAP32[$5+0>>2]=HEAP32[$zero$sroa$1$i+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$zero$sroa$1$i+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$zero$sroa$1$i+8>>2]|0;
 $6 = (($this) + 48|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 52|0);
 ;HEAP32[$7+0>>2]=HEAP32[$zero$sroa$1$i+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$zero$sroa$1$i+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$zero$sroa$1$i+8>>2]|0;
 ;HEAP32[$$sroa$1$i+0>>2]=0|0;HEAP32[$$sroa$1$i+4>>2]=0|0;HEAP32[$$sroa$1$i+8>>2]=0|0;HEAP32[$$sroa$1$i+12>>2]=0|0;
 ;HEAP32[$0+0>>2]=HEAP32[$$sroa$1$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$$sroa$1$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$$sroa$1$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$$sroa$1$i+12>>2]|0;
 $8 = (($this) + 96|0);
 $9 = (($this) + 144|0);
 $10 = (($this) + 192|0);
 HEAP32[$10>>2] = $_hullData;
 $11 = (($_hullData) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($_hullData) + 39|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = (($12) + (($15*20)|0)|0);
 $17 = (($this) + 200|0);
 HEAP32[$17>>2] = $16;
 $18 = (($_hullData) + 38|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = (($this) + 204|0);
 HEAP8[$20>>0] = $19;
 $21 = (($_hullData) + 52|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($_hullData) + 56|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($_hullData) + 60|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(HEAPF32[$scale>>2]);
 $28 = (($scale) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($scale) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($22 * $27);
 $33 = Math_fround($24 * $29);
 $34 = Math_fround($26 * $31);
 $35 = !($32 <= $33);
 $$$i26$i = $35 ? $33 : $32;
 $36 = !($$$i26$i <= $34);
 $37 = $36 ? $34 : $$$i26$i;
 $38 = !($32 >= $33);
 $$$i23$i = $38 ? $33 : $32;
 $39 = !($$$i23$i >= $34);
 $40 = $39 ? $34 : $$$i23$i;
 $41 = Math_fround($37 * Math_fround(0.20000000298023223877));
 $42 = Math_fround($40 * Math_fround(0.0500000007450580596924));
 $43 = $41 > $42;
 $$$i12$i = $43 ? $41 : $42;
 $44 = $37 > $$$i12$i;
 $$$i$i = $44 ? $$$i12$i : $37;
 HEAPF32[$2>>2] = $$$i$i;
 ;HEAP32[$3+0>>2]=HEAP32[$zero$sroa$1$i+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$zero$sroa$1$i+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$zero$sroa$1$i+8>>2]|0;
 $45 = Math_fround($37 * Math_fround(0.100000001490116119385));
 HEAPF32[$4>>2] = $45;
 ;HEAP32[$5+0>>2]=HEAP32[$$sroa$1$i+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$$sroa$1$i+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$$sroa$1$i+8>>2]|0;
 __ZN5physx2Gu19ConstructSkewMatrixERKNS_6shdfnd3aos5Vec3VERKNS2_5Vec4VERNS2_6Mat33VESA_($scale,$scaleRot,$8,$9);
 $46 = (($_hullData) + 44|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($this) + 196|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$11>>2]|0;
 $50 = HEAP8[$13>>0]|0;
 $51 = $50&255;
 $52 = (($49) + (($51*20)|0)|0);
 $53 = HEAP8[$18>>0]|0;
 $54 = $53&255;
 $55 = (($_hullData) + 36|0);
 $56 = HEAP16[$55>>1]|0;
 $57 = $56&65535;
 $58 = $57 << 1;
 $tmp1 = ($54*15)|0;
 $$sum = (($tmp1) + ($58))|0;
 $59 = (($52) + ($$sum)|0);
 $60 = $59;
 $61 = $49;
 $62 = (($60) - ($61))|0;
 $63 = ($62|0)>(0);
 if ($63) {
  $startAddress$04 = $49;$totalPrefetchBytes$05 = $62;
  while(1) {
   $64 = (($totalPrefetchBytes$05) + -128)|0;
   $65 = (($startAddress$04) + 128|0);
   $66 = ($64|0)>(0);
   if ($66) {
    $startAddress$04 = $65;$totalPrefetchBytes$05 = $64;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$48>>2]|0;
  $68 = $$pre;
 } else {
  $68 = $47;
 }
 $67 = ($68|0)==(0|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $69 = (($68) + 2|0);
 $70 = HEAP16[$69>>1]|0;
 $71 = $70&65535;
 $72 = (($68) + 8|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73 << 2;
 $75 = (($74) + ($71))|0;
 $76 = (($68) + 12|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($75) + ($77))|0;
 $79 = ($78|0)>(0);
 if (!($79)) {
  STACKTOP = sp;return;
 }
 $80 = (($68) + 4|0);
 $81 = HEAP32[$80>>2]|0;
 $startAddress$12 = $81;$totalSize$03 = $78;
 while(1) {
  $82 = (($totalSize$03) + -128)|0;
  $83 = (($startAddress$12) + 128|0);
  $84 = ($82|0)>(0);
  if ($84) {
   $startAddress$12 = $83;$totalSize$03 = $82;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19ConstructSkewMatrixERKNS_6shdfnd3aos5Vec3VERKNS2_5Vec4VERNS2_6Mat33VESA_($scale,$rotation,$vertex2Shape,$shape2Vertex) {
 $scale = $scale|0;
 $rotation = $rotation|0;
 $vertex2Shape = $vertex2Shape|0;
 $shape2Vertex = $shape2Vertex|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0;
 var $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$rotation>>2]);
 $1 = (($rotation) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($rotation) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($rotation) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 + $0);
 $8 = Math_fround($2 + $2);
 $9 = Math_fround($4 + $4);
 $10 = Math_fround($0 * $7);
 $11 = Math_fround($2 * $8);
 $12 = Math_fround($4 * $9);
 $13 = Math_fround($7 * $2);
 $14 = Math_fround($7 * $4);
 $15 = Math_fround($7 * $6);
 $16 = Math_fround($8 * $4);
 $17 = Math_fround($8 * $6);
 $18 = Math_fround($9 * $6);
 $19 = Math_fround(Math_fround(1.0) - $10);
 $20 = Math_fround(Math_fround(1.0) - $11);
 $21 = Math_fround($20 - $12);
 $22 = Math_fround($13 + $18);
 $23 = Math_fround($14 - $17);
 $24 = Math_fround($13 - $18);
 $25 = Math_fround($19 - $12);
 $26 = Math_fround($16 + $15);
 $27 = Math_fround($14 + $17);
 $28 = Math_fround($16 - $15);
 $29 = Math_fround($19 - $11);
 $30 = Math_fround(HEAPF32[$scale>>2]);
 $31 = (($scale) + 4|0);
 $32 = Math_fround($30 * $21);
 $33 = Math_fround($30 * $24);
 $34 = Math_fround($30 * $27);
 $35 = Math_fround(HEAPF32[$31>>2]);
 $36 = (($scale) + 8|0);
 $37 = Math_fround($22 * $35);
 $38 = Math_fround($35 * $25);
 $39 = Math_fround($35 * $28);
 $40 = Math_fround(HEAPF32[$36>>2]);
 $41 = Math_fround($23 * $40);
 $42 = Math_fround($26 * $40);
 $43 = Math_fround($29 * $40);
 $44 = Math_fround($21 * $32);
 $45 = Math_fround($22 * $37);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($23 * $41);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($21 * $33);
 $50 = Math_fround($22 * $38);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($23 * $42);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($21 * $34);
 $55 = Math_fround($22 * $39);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($23 * $43);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($24 * $32);
 $60 = Math_fround($25 * $37);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($26 * $41);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($24 * $33);
 $65 = Math_fround($25 * $38);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($26 * $42);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($24 * $34);
 $70 = Math_fround($25 * $39);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($26 * $43);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($27 * $32);
 $75 = Math_fround($28 * $37);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($29 * $41);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($27 * $33);
 $80 = Math_fround($28 * $38);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($29 * $42);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($27 * $34);
 $85 = Math_fround($28 * $39);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($29 * $43);
 $88 = Math_fround($86 + $87);
 HEAPF32[$vertex2Shape>>2] = $48;
 $89 = (($vertex2Shape) + 4|0);
 HEAPF32[$89>>2] = $53;
 $90 = (($vertex2Shape) + 8|0);
 HEAPF32[$90>>2] = $58;
 $91 = (($vertex2Shape) + 12|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($vertex2Shape) + 16|0);
 HEAPF32[$92>>2] = $63;
 $93 = (($vertex2Shape) + 20|0);
 HEAPF32[$93>>2] = $68;
 $94 = (($vertex2Shape) + 24|0);
 HEAPF32[$94>>2] = $73;
 $95 = (($vertex2Shape) + 28|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($vertex2Shape) + 32|0);
 HEAPF32[$96>>2] = $78;
 $97 = (($vertex2Shape) + 36|0);
 HEAPF32[$97>>2] = $83;
 $98 = (($vertex2Shape) + 40|0);
 HEAPF32[$98>>2] = $88;
 $99 = (($vertex2Shape) + 44|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = Math_fround(HEAPF32[$scale>>2]);
 $101 = Math_fround(HEAPF32[$31>>2]);
 $102 = Math_fround(HEAPF32[$36>>2]);
 $103 = Math_fround(Math_fround(1.0) / $100);
 $104 = Math_fround(Math_fround(1.0) / $101);
 $105 = Math_fround(Math_fround(1.0) / $102);
 $106 = Math_fround($21 * $103);
 $107 = Math_fround($24 * $103);
 $108 = Math_fround($27 * $103);
 $109 = (($shape2Vertex) + 4|0);
 $110 = (($shape2Vertex) + 8|0);
 $111 = (($shape2Vertex) + 12|0);
 $112 = Math_fround($22 * $104);
 $113 = Math_fround($25 * $104);
 $114 = Math_fround($28 * $104);
 $115 = (($shape2Vertex) + 16|0);
 $116 = (($shape2Vertex) + 20|0);
 $117 = (($shape2Vertex) + 24|0);
 $118 = (($shape2Vertex) + 28|0);
 $119 = Math_fround($23 * $105);
 $120 = Math_fround($26 * $105);
 $121 = Math_fround($29 * $105);
 $122 = (($shape2Vertex) + 32|0);
 $123 = (($shape2Vertex) + 36|0);
 $124 = (($shape2Vertex) + 40|0);
 $125 = (($shape2Vertex) + 44|0);
 $126 = Math_fround($21 * $106);
 $127 = Math_fround($22 * $112);
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($23 * $119);
 $130 = Math_fround($128 + $129);
 $131 = Math_fround($21 * $107);
 $132 = Math_fround($22 * $113);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround($23 * $120);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround($21 * $108);
 $137 = Math_fround($22 * $114);
 $138 = Math_fround($136 + $137);
 $139 = Math_fround($23 * $121);
 $140 = Math_fround($138 + $139);
 $141 = Math_fround($24 * $106);
 $142 = Math_fround($25 * $112);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround($26 * $119);
 $145 = Math_fround($143 + $144);
 $146 = Math_fround($24 * $107);
 $147 = Math_fround($25 * $113);
 $148 = Math_fround($146 + $147);
 $149 = Math_fround($26 * $120);
 $150 = Math_fround($148 + $149);
 $151 = Math_fround($24 * $108);
 $152 = Math_fround($25 * $114);
 $153 = Math_fround($151 + $152);
 $154 = Math_fround($26 * $121);
 $155 = Math_fround($153 + $154);
 $156 = Math_fround($27 * $106);
 $157 = Math_fround($28 * $112);
 $158 = Math_fround($156 + $157);
 $159 = Math_fround($29 * $119);
 $160 = Math_fround($158 + $159);
 $161 = Math_fround($27 * $107);
 $162 = Math_fround($28 * $113);
 $163 = Math_fround($161 + $162);
 $164 = Math_fround($29 * $120);
 $165 = Math_fround($163 + $164);
 $166 = Math_fround($27 * $108);
 $167 = Math_fround($28 * $114);
 $168 = Math_fround($166 + $167);
 $169 = Math_fround($29 * $121);
 $170 = Math_fround($168 + $169);
 HEAPF32[$shape2Vertex>>2] = $130;
 HEAPF32[$109>>2] = $135;
 HEAPF32[$110>>2] = $140;
 HEAPF32[$111>>2] = Math_fround(0.0);
 HEAPF32[$115>>2] = $145;
 HEAPF32[$116>>2] = $150;
 HEAPF32[$117>>2] = $155;
 HEAPF32[$118>>2] = Math_fround(0.0);
 HEAPF32[$122>>2] = $160;
 HEAPF32[$123>>2] = $165;
 HEAPF32[$124>>2] = $170;
 HEAPF32[$125>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx28PxcContactCapsuleHeightFieldERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$phi$trans$insert = 0, $$pre = Math_fround(0), $$pre109 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0);
 var $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0);
 var $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = Math_fround(0);
 var $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0);
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0);
 var $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0);
 var $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0);
 var $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = 0, $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0);
 var $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0);
 var $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = Math_fround(0), $563 = Math_fround(0);
 var $564 = 0, $565 = Math_fround(0), $566 = Math_fround(0), $567 = 0, $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0);
 var $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = 0, $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = 0, $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0);
 var $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = 0, $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0);
 var $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0);
 var $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = 0, $663 = 0, $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0);
 var $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = Math_fround(0);
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = 0, $702 = 0, $703 = 0, $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0);
 var $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = 0, $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0);
 var $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = Math_fround(0), $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = Math_fround(0), $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = Math_fround(0), $760 = 0, $761 = 0;
 var $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = Math_fround(0), $770 = 0, $771 = Math_fround(0), $772 = 0, $773 = Math_fround(0), $774 = 0, $775 = Math_fround(0), $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = Math_fround(0);
 var $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = 0, $784 = 0, $785 = 0, $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0);
 var $799 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0;
 var $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = Math_fround(0), $820 = 0, $821 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $adjFaceIndices = 0, $capsuleSegmentInHfShape = 0, $column$097 = 0, $d = 0, $d4 = 0, $direction = 0, $direction$idx$val = Math_fround(0), $direction$idx8 = 0, $direction$idx8$val = Math_fround(0), $direction$idx9 = 0, $direction$idx9$val = Math_fround(0), $ei$089 = 0, $exitcond = 0, $exitcond105 = 0, $fabsf$i$i = Math_fround(0);
 var $fabsf$i$i12 = Math_fround(0), $hfUtil = 0, $iVertexContact$094 = 0, $iVertexContact9$084 = 0, $j$087 = 0, $l = 0, $l6 = 0, $n = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i13 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond80 = 0, $or$cond81 = 0, $or$cond82 = 0, $or$cond83 = 0, $origin = 0, $phitmp = 0;
 var $row$0100 = 0, $s = 0, $s1 = 0, $sphere = 0, $t = 0, $ts0 = 0, $ts1 = 0, $tv0 = 0, $tv1 = 0, $tv2 = 0, $vertex = 0, $verticesInHfShape = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $hfUtil = sp + 288|0;
 $verticesInHfShape = sp + 264|0;
 $sphere = sp + 256|0;
 $ts0 = sp + 228|0;
 $ts1 = sp + 200|0;
 $capsuleSegmentInHfShape = sp + 176|0;
 $adjFaceIndices = sp + 168|0;
 $origin = sp + 152|0;
 $direction = sp + 140|0;
 $s = sp + 136|0;
 $t = sp + 132|0;
 $0 = sp + 120|0;
 $d = sp + 108|0;
 $l = sp + 48|0;
 $n = sp;
 $1 = sp + 12|0;
 $tv0 = sp + 24|0;
 $tv1 = sp + 36|0;
 $tv2 = sp + 52|0;
 $vertex = sp + 64|0;
 $s1 = sp + 76|0;
 $d4 = sp + 80|0;
 $l6 = sp + 92|0;
 $2 = sp + 96|0;
 $3 = (($shape1) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($hfUtil) + 12|0);
 HEAP32[$5>>2] = $4;
 $6 = (($hfUtil) + 16|0);
 HEAP32[$6>>2] = $shape1;
 $7 = (($shape1) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(Math_fround(1.0) / $8);
 $10 = (($hfUtil) + 4|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($shape1) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(Math_fround(1.0) / $12);
 HEAPF32[$hfUtil>>2] = $13;
 $14 = (($shape1) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(Math_fround(1.0) / $15);
 $17 = (($hfUtil) + 8|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($shape0) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$contactDistance>>2]);
 $21 = Math_fround($19 + $20);
 $22 = (($shape0) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($19 * Math_fround(0.100000001490116119385));
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($13)))));
 $fabsf$i$i12 = (Math_fround(Math_abs((Math_fround($16)))));
 $25 = Math_fround(HEAPF32[$transform1>>2]);
 $26 = Math_fround(-$25);
 $27 = (($transform1) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(-$28);
 $30 = (($transform1) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(-$31);
 $33 = (($transform1) + 12|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($transform0) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($transform1) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 - $38);
 $40 = (($transform0) + 20|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($transform1) + 20|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($41 - $43);
 $45 = (($transform0) + 24|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($transform1) + 24|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($46 - $48);
 $50 = Math_fround($39 * Math_fround(2.0));
 $51 = Math_fround($44 * Math_fround(2.0));
 $52 = Math_fround($49 * Math_fround(2.0));
 $53 = Math_fround($34 * $34);
 $54 = Math_fround($53 + Math_fround(-0.5));
 $55 = Math_fround($50 * $26);
 $56 = Math_fround($51 * $29);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($52 * $32);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($52 * $29);
 $61 = Math_fround($51 * $32);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($34 * $62);
 $64 = Math_fround($59 * $26);
 $65 = Math_fround($54 * $51);
 $66 = Math_fround($50 * $32);
 $67 = Math_fround($52 * $26);
 $68 = Math_fround($66 - $67);
 $69 = Math_fround($34 * $68);
 $70 = Math_fround($65 + $69);
 $71 = Math_fround($59 * $29);
 $72 = Math_fround($71 + $70);
 $73 = Math_fround($51 * $26);
 $74 = Math_fround($50 * $29);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($34 * $75);
 $77 = Math_fround($59 * $32);
 $78 = Math_fround(HEAPF32[$transform0>>2]);
 $79 = Math_fround($34 * $78);
 $80 = (($transform0) + 12|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 * $26);
 $83 = Math_fround($79 + $82);
 $84 = (($transform0) + 8|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($85 * $29);
 $87 = Math_fround($83 + $86);
 $88 = (($transform0) + 4|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($89 * $32);
 $91 = Math_fround($87 - $90);
 $92 = Math_fround($81 * $29);
 $93 = Math_fround($78 * $32);
 $94 = Math_fround($85 * $26);
 $95 = Math_fround($34 * $85);
 $96 = Math_fround($81 * $32);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($89 * $26);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($78 * $29);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($78 * $26);
 $103 = Math_fround($89 * $29);
 $104 = Math_fround($85 * $32);
 $105 = Math_fround($21 * $21);
 $106 = Math_fround($24 * $24);
 $107 = Math_fround($21 * $fabsf$i$i);
 $108 = Math_fround($21 * $fabsf$i$i12);
 $109 = Math_fround($54 * $50);
 $110 = Math_fround($109 + $63);
 $111 = Math_fround($64 + $110);
 $112 = Math_fround($54 * $52);
 $113 = Math_fround($112 + $76);
 $114 = Math_fround($113 + $77);
 $115 = Math_fround($34 * $89);
 $116 = Math_fround($92 + $115);
 $117 = Math_fround($93 + $116);
 $118 = Math_fround($117 - $94);
 $119 = Math_fround($34 * $81);
 $120 = Math_fround($119 - $102);
 $121 = Math_fround($120 - $103);
 $122 = Math_fround($121 - $104);
 $123 = Math_fround($23 * Math_fround(-2.0));
 $124 = Math_fround($122 * $122);
 $125 = Math_fround($124 + Math_fround(-0.5));
 $126 = Math_fround($123 * $91);
 $127 = Math_fround($118 * Math_fround(0.0));
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($101 * Math_fround(0.0));
 $130 = Math_fround($129 + $128);
 $131 = Math_fround($123 * $125);
 $132 = Math_fround($127 - $129);
 $133 = Math_fround($122 * $132);
 $134 = Math_fround($131 + $133);
 $135 = Math_fround($91 * $130);
 $136 = Math_fround($135 + $134);
 $137 = Math_fround($125 * Math_fround(0.0));
 $138 = Math_fround($123 * $101);
 $139 = Math_fround($91 * Math_fround(0.0));
 $140 = Math_fround($138 - $139);
 $141 = Math_fround($122 * $140);
 $142 = Math_fround($137 + $141);
 $143 = Math_fround($118 * $130);
 $144 = Math_fround($142 + $143);
 $145 = Math_fround($123 * $118);
 $146 = Math_fround($139 - $145);
 $147 = Math_fround($122 * $146);
 $148 = Math_fround($137 + $147);
 $149 = Math_fround($101 * $130);
 $150 = Math_fround($148 + $149);
 $151 = Math_fround($111 + $136);
 $152 = Math_fround($72 + $144);
 $153 = Math_fround($114 + $150);
 HEAPF32[$verticesInHfShape>>2] = $151;
 $154 = (($verticesInHfShape) + 4|0);
 HEAPF32[$154>>2] = $152;
 $155 = (($verticesInHfShape) + 8|0);
 HEAPF32[$155>>2] = $153;
 $156 = Math_fround($23 * Math_fround(2.0));
 $157 = Math_fround($156 * $91);
 $158 = Math_fround($157 + $127);
 $159 = Math_fround($129 + $158);
 $160 = Math_fround($156 * $125);
 $161 = Math_fround($160 + $133);
 $162 = Math_fround($91 * $159);
 $163 = Math_fround($162 + $161);
 $164 = Math_fround($156 * $101);
 $165 = Math_fround($164 - $139);
 $166 = Math_fround($122 * $165);
 $167 = Math_fround($137 + $166);
 $168 = Math_fround($118 * $159);
 $169 = Math_fround($167 + $168);
 $170 = Math_fround($156 * $118);
 $171 = Math_fround($139 - $170);
 $172 = Math_fround($122 * $171);
 $173 = Math_fround($137 + $172);
 $174 = Math_fround($101 * $159);
 $175 = Math_fround($173 + $174);
 $176 = Math_fround($111 + $163);
 $177 = Math_fround($72 + $169);
 $178 = Math_fround($114 + $175);
 $179 = (($verticesInHfShape) + 12|0);
 HEAPF32[$179>>2] = $176;
 $180 = (($verticesInHfShape) + 16|0);
 HEAPF32[$180>>2] = $177;
 $181 = (($verticesInHfShape) + 20|0);
 HEAPF32[$181>>2] = $178;
 HEAP32[$sphere>>2] = 0;
 $182 = (($sphere) + 4|0);
 HEAPF32[$182>>2] = $19;
 $183 = Math_fround($151 * Math_fround(2.0));
 $184 = Math_fround($152 * Math_fround(2.0));
 $185 = Math_fround($153 * Math_fround(2.0));
 $186 = Math_fround(HEAPF32[$33>>2]);
 $187 = Math_fround($186 * $186);
 $188 = Math_fround($187 + Math_fround(-0.5));
 $189 = Math_fround(HEAPF32[$transform1>>2]);
 $190 = Math_fround($183 * $189);
 $191 = Math_fround(HEAPF32[$27>>2]);
 $192 = Math_fround($184 * $191);
 $193 = Math_fround($190 + $192);
 $194 = Math_fround(HEAPF32[$30>>2]);
 $195 = Math_fround($185 * $194);
 $196 = Math_fround($193 + $195);
 $197 = Math_fround($183 * $188);
 $198 = Math_fround($185 * $191);
 $199 = Math_fround($184 * $194);
 $200 = Math_fround($198 - $199);
 $201 = Math_fround($186 * $200);
 $202 = Math_fround($197 + $201);
 $203 = Math_fround($189 * $196);
 $204 = Math_fround($203 + $202);
 $205 = Math_fround($184 * $188);
 $206 = Math_fround($183 * $194);
 $207 = Math_fround($185 * $189);
 $208 = Math_fround($206 - $207);
 $209 = Math_fround($186 * $208);
 $210 = Math_fround($205 + $209);
 $211 = Math_fround($191 * $196);
 $212 = Math_fround($211 + $210);
 $213 = Math_fround($185 * $188);
 $214 = Math_fround($184 * $189);
 $215 = Math_fround($183 * $191);
 $216 = Math_fround($214 - $215);
 $217 = Math_fround($186 * $216);
 $218 = Math_fround($213 + $217);
 $219 = Math_fround($194 * $196);
 $220 = Math_fround($218 + $219);
 $221 = Math_fround(HEAPF32[$37>>2]);
 $222 = Math_fround($221 + $204);
 $223 = Math_fround(HEAPF32[$42>>2]);
 $224 = Math_fround($223 + $212);
 $225 = Math_fround(HEAPF32[$47>>2]);
 $226 = Math_fround($225 + $220);
 HEAPF32[$ts0>>2] = Math_fround(0.0);
 $227 = (($ts0) + 4|0);
 HEAPF32[$227>>2] = Math_fround(0.0);
 $228 = (($ts0) + 8|0);
 HEAPF32[$228>>2] = Math_fround(0.0);
 $229 = (($ts0) + 12|0);
 HEAPF32[$229>>2] = Math_fround(1.0);
 $230 = (($ts0) + 16|0);
 HEAPF32[$230>>2] = $222;
 $231 = (($ts0) + 20|0);
 HEAPF32[$231>>2] = $224;
 $232 = (($ts0) + 24|0);
 HEAPF32[$232>>2] = $226;
 $233 = Math_fround($176 * Math_fround(2.0));
 $234 = Math_fround($177 * Math_fround(2.0));
 $235 = Math_fround($178 * Math_fround(2.0));
 $236 = Math_fround($233 * $189);
 $237 = Math_fround($234 * $191);
 $238 = Math_fround($236 + $237);
 $239 = Math_fround($235 * $194);
 $240 = Math_fround($238 + $239);
 $241 = Math_fround($233 * $188);
 $242 = Math_fround($235 * $191);
 $243 = Math_fround($234 * $194);
 $244 = Math_fround($242 - $243);
 $245 = Math_fround($186 * $244);
 $246 = Math_fround($241 + $245);
 $247 = Math_fround($189 * $240);
 $248 = Math_fround($247 + $246);
 $249 = Math_fround($234 * $188);
 $250 = Math_fround($233 * $194);
 $251 = Math_fround($235 * $189);
 $252 = Math_fround($250 - $251);
 $253 = Math_fround($186 * $252);
 $254 = Math_fround($249 + $253);
 $255 = Math_fround($191 * $240);
 $256 = Math_fround($255 + $254);
 $257 = Math_fround($235 * $188);
 $258 = Math_fround($234 * $189);
 $259 = Math_fround($233 * $191);
 $260 = Math_fround($258 - $259);
 $261 = Math_fround($186 * $260);
 $262 = Math_fround($257 + $261);
 $263 = Math_fround($194 * $240);
 $264 = Math_fround($262 + $263);
 $265 = Math_fround($221 + $248);
 $266 = Math_fround($223 + $256);
 $267 = Math_fround($225 + $264);
 HEAPF32[$ts1>>2] = Math_fround(0.0);
 $268 = (($ts1) + 4|0);
 HEAPF32[$268>>2] = Math_fround(0.0);
 $269 = (($ts1) + 8|0);
 HEAPF32[$269>>2] = Math_fround(0.0);
 $270 = (($ts1) + 12|0);
 HEAPF32[$270>>2] = Math_fround(1.0);
 $271 = (($ts1) + 16|0);
 HEAPF32[$271>>2] = $265;
 $272 = (($ts1) + 20|0);
 HEAPF32[$272>>2] = $266;
 $273 = (($ts1) + 24|0);
 HEAPF32[$273>>2] = $267;
 (__ZN5physx33PxcContactSphereHeightFieldSharedERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferEb($sphere,$shape1,$ts0,$transform1,$contactDistance,$npCache,$contactBuffer,1)|0);
 (__ZN5physx33PxcContactSphereHeightFieldSharedERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferEb($sphere,$shape1,$ts1,$transform1,$contactDistance,$npCache,$contactBuffer,1)|0);
 $274 = Math_fround(HEAPF32[$transform0>>2]);
 $275 = Math_fround($274 * Math_fround(2.0));
 $276 = Math_fround(HEAPF32[$80>>2]);
 $277 = Math_fround($276 * Math_fround(2.0));
 $278 = Math_fround($276 * $277);
 $279 = Math_fround($278 + Math_fround(-1.0));
 $280 = Math_fround($274 * $275);
 $281 = Math_fround($280 + $279);
 $282 = Math_fround(HEAPF32[$84>>2]);
 $283 = Math_fround($282 * $277);
 $284 = Math_fround(HEAPF32[$88>>2]);
 $285 = Math_fround($275 * $284);
 $286 = Math_fround($283 + $285);
 $287 = Math_fround($277 * $284);
 $288 = Math_fround($275 * $282);
 $289 = Math_fround($288 - $287);
 $290 = Math_fround(HEAPF32[$22>>2]);
 $291 = Math_fround($290 * $281);
 $292 = Math_fround($290 * $286);
 $293 = Math_fround($290 * $289);
 $294 = Math_fround(HEAPF32[$35>>2]);
 $295 = Math_fround($294 - $291);
 $296 = Math_fround(HEAPF32[$40>>2]);
 $297 = Math_fround($296 - $292);
 $298 = Math_fround(HEAPF32[$45>>2]);
 $299 = Math_fround($298 - $293);
 $300 = Math_fround(HEAPF32[$verticesInHfShape>>2]);
 HEAPF32[$capsuleSegmentInHfShape>>2] = $300;
 $301 = (($capsuleSegmentInHfShape) + 4|0);
 $302 = Math_fround(HEAPF32[$154>>2]);
 HEAPF32[$301>>2] = $302;
 $303 = (($capsuleSegmentInHfShape) + 8|0);
 $304 = Math_fround(HEAPF32[$155>>2]);
 HEAPF32[$303>>2] = $304;
 $305 = (($capsuleSegmentInHfShape) + 12|0);
 $306 = Math_fround(HEAPF32[$179>>2]);
 HEAPF32[$305>>2] = $306;
 $307 = (($capsuleSegmentInHfShape) + 16|0);
 $308 = Math_fround(HEAPF32[$180>>2]);
 HEAPF32[$307>>2] = $308;
 $309 = (($capsuleSegmentInHfShape) + 20|0);
 $310 = Math_fround(HEAPF32[$181>>2]);
 HEAPF32[$309>>2] = $310;
 $311 = (($contactBuffer) + 4096|0);
 $312 = HEAP32[$311>>2]|0;
 $313 = Math_fround(HEAPF32[$hfUtil>>2]);
 $314 = Math_fround($300 * $313);
 $315 = Math_fround(HEAPF32[$17>>2]);
 $316 = Math_fround($304 * $315);
 $317 = Math_fround($313 * $306);
 $318 = Math_fround($315 * $310);
 $319 = Math_fround($314 - $107);
 $320 = Math_fround($317 - $107);
 $321 = $319 < $320;
 $322 = $321 ? $319 : $320;
 $323 = (Math_fround(Math_floor((Math_fround($322)))));
 $324 = (~~(($323)));
 $325 = (($4) + 16|0);
 $326 = HEAP32[$325>>2]|0;
 $327 = (($326) + -2)|0;
 $328 = ($324|0)>(0);
 $329 = $328 ? $324 : 0;
 $330 = ($329|0)>($327|0);
 $331 = $330 ? $327 : $329;
 $332 = Math_fround($107 + $314);
 $333 = Math_fround($107 + $317);
 $334 = $332 > $333;
 $335 = $334 ? $332 : $333;
 $336 = (Math_fround(Math_ceil((Math_fround($335)))));
 $337 = (~~(($336)));
 $338 = (($326) + -1)|0;
 $339 = ($337|0)>(0);
 $340 = $339 ? $337 : 0;
 $341 = ($340|0)>($338|0);
 $342 = $341 ? $338 : $340;
 $343 = Math_fround($316 - $108);
 $344 = Math_fround($318 - $108);
 $345 = $343 < $344;
 $346 = $345 ? $343 : $344;
 $347 = (Math_fround(Math_floor((Math_fround($346)))));
 $348 = (~~(($347)));
 $349 = (($4) + 20|0);
 $350 = HEAP32[$349>>2]|0;
 $351 = (($350) + -2)|0;
 $352 = ($348|0)>(0);
 $353 = $352 ? $348 : 0;
 $354 = ($353|0)>($351|0);
 $355 = $354 ? $351 : $353;
 $356 = Math_fround($108 + $316);
 $357 = Math_fround($108 + $318);
 $358 = $356 > $357;
 $359 = $358 ? $356 : $357;
 $360 = (Math_fround(Math_ceil((Math_fround($359)))));
 $361 = (~~(($360)));
 $362 = (($350) + -1)|0;
 $363 = ($361|0)>(0);
 $364 = $363 ? $361 : 0;
 $365 = ($364|0)>($362|0);
 $366 = $365 ? $362 : $364;
 $367 = ($331>>>0)>($342>>>0);
 if (!($367)) {
  $368 = Math_fround($293 + $298);
  $369 = Math_fround($296 + $292);
  $370 = Math_fround($294 + $291);
  $371 = ($355>>>0)>($366>>>0);
  $372 = (($4) + 36|0);
  $373 = (($vertex) + 4|0);
  $374 = (($vertex) + 8|0);
  $375 = (($capsuleSegmentInHfShape) + 12|0);
  $376 = (($d4) + 4|0);
  $377 = (($d4) + 8|0);
  $378 = (($4) + 40|0);
  $379 = ($312|0)==(0);
  $380 = Math_fround($368 - $299);
  $381 = Math_fround($369 - $297);
  $382 = Math_fround($370 - $295);
  $383 = (($shape1) + 20|0);
  $384 = (($2) + 4|0);
  $385 = (($2) + 8|0);
  $386 = (($0) + 4|0);
  $387 = (($0) + 8|0);
  $direction$idx8 = (($direction) + 4|0);
  $direction$idx9 = (($direction) + 8|0);
  $388 = (($origin) + 4|0);
  $389 = (($origin) + 8|0);
  $390 = (($d) + 4|0);
  $391 = (($d) + 8|0);
  $392 = (($n) + 4|0);
  $393 = (($n) + 8|0);
  $394 = (($1) + 4|0);
  $395 = (($1) + 8|0);
  $396 = (($tv0) + 4|0);
  $397 = (($tv1) + 4|0);
  $398 = (($tv0) + 8|0);
  $399 = (($tv1) + 8|0);
  $400 = (($tv2) + 4|0);
  $401 = (($tv2) + 8|0);
  $402 = (($adjFaceIndices) + 4|0);
  $row$0100 = $331;
  while(1) {
   if (!($371)) {
    $403 = ($row$0100|0)==($342|0);
    $404 = $403 ? 1 : 3;
    $405 = (Math_fround(($row$0100>>>0)));
    $column$097 = $355;
    while(1) {
     $407 = HEAP32[$349>>2]|0;
     $408 = Math_imul($407, $row$0100)|0;
     $409 = (($408) + ($column$097))|0;
     $410 = ($409*3)|0;
     $411 = ($column$097|0)==($366|0);
     $412 = $411 ? 2 : 0;
     $413 = ($412>>>0)<($404>>>0);
     if ($413) {
      $ei$089 = $412;
      while(1) {
       $414 = (($ei$089) + ($410))|0;
       $415 = (__ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($4,$414,$adjFaceIndices)|0);
       $416 = ($415|0)!=(2);
       $417 = HEAP32[$adjFaceIndices>>2]|0;
       $418 = ($417|0)==(-1);
       $or$cond5 = $416 | $418;
       if ($or$cond5) {
        label = 9;
       } else {
        $419 = HEAP32[$402>>2]|0;
        $420 = ($419|0)==(-1);
        if ($420) {
         label = 9;
        } else {
         label = 10;
        }
       }
       if ((label|0) == 9) {
        label = 0;
        $421 = ($415|0)!=(1);
        $or$cond7 = $421 | $418;
        if (!($or$cond7)) {
         label = 10;
        }
       }
       do {
        if ((label|0) == 10) {
         label = 0;
         __ZNK5physx2Gu15HeightFieldUtil7getEdgeEjjjjRNS_6PxVec3ES3_($hfUtil,$414,$409,$row$0100,$column$097,$origin,$direction);
         $422 = Math_fround(HEAPF32[$305>>2]);
         $423 = Math_fround(HEAPF32[$capsuleSegmentInHfShape>>2]);
         $424 = Math_fround($422 - $423);
         $425 = Math_fround(HEAPF32[$307>>2]);
         $426 = Math_fround(HEAPF32[$301>>2]);
         $427 = Math_fround($425 - $426);
         $428 = Math_fround(HEAPF32[$309>>2]);
         $429 = Math_fround(HEAPF32[$303>>2]);
         $430 = Math_fround($428 - $429);
         HEAPF32[$0>>2] = $424;
         HEAPF32[$386>>2] = $427;
         HEAPF32[$387>>2] = $430;
         $431 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($capsuleSegmentInHfShape,$0,$origin,$direction,$s,$t)));
         $432 = $431 < $105;
         if ($432) {
          $433 = Math_fround(HEAPF32[$t>>2]);
          $434 = $433 >= Math_fround(0.0);
          $435 = $433 <= Math_fround(1.0);
          $or$cond = $434 & $435;
          if ($or$cond) {
           $436 = ($ei$089|0)==(0);
           if (!($436)) {
            $437 = $433 == Math_fround(0.0);
            $438 = $433 == Math_fround(1.0);
            $or$cond3 = $437 | $438;
            if ($or$cond3) {
             break;
            }
           }
           $439 = Math_fround(HEAPF32[$s>>2]);
           $440 = Math_fround(HEAPF32[$305>>2]);
           $441 = Math_fround(HEAPF32[$capsuleSegmentInHfShape>>2]);
           $442 = Math_fround($440 - $441);
           $443 = Math_fround(HEAPF32[$307>>2]);
           $444 = Math_fround(HEAPF32[$301>>2]);
           $445 = Math_fround($443 - $444);
           $446 = Math_fround(HEAPF32[$309>>2]);
           $447 = Math_fround(HEAPF32[$303>>2]);
           $448 = Math_fround($446 - $447);
           $449 = Math_fround($439 * $442);
           $450 = Math_fround($439 * $445);
           $451 = Math_fround($439 * $448);
           $452 = Math_fround($441 + $449);
           $453 = Math_fround($444 + $450);
           $454 = Math_fround($447 + $451);
           $direction$idx$val = Math_fround(HEAPF32[$direction>>2]);
           $direction$idx8$val = Math_fround(HEAPF32[$direction$idx8>>2]);
           $direction$idx9$val = Math_fround(HEAPF32[$direction$idx9>>2]);
           $455 = Math_fround($433 * $direction$idx$val);
           $456 = Math_fround($433 * $direction$idx8$val);
           $457 = Math_fround($433 * $direction$idx9$val);
           $458 = Math_fround(HEAPF32[$origin>>2]);
           $459 = Math_fround($455 + $458);
           $460 = Math_fround(HEAPF32[$388>>2]);
           $461 = Math_fround($456 + $460);
           $462 = Math_fround(HEAPF32[$389>>2]);
           $463 = Math_fround($457 + $462);
           $464 = Math_fround($452 - $459);
           $465 = Math_fround($453 - $461);
           $466 = Math_fround($454 - $463);
           HEAPF32[$d>>2] = $464;
           HEAPF32[$390>>2] = $465;
           HEAPF32[$391>>2] = $466;
           $467 = Math_fround(HEAPF32[$378>>2]);
           $468 = $467 <= Math_fround(0.0);
           $469 = $465 > Math_fround(0.0);
           $or$cond$i13 = $468 & $469;
           if (!($or$cond$i13)) {
            $470 = $467 > Math_fround(0.0);
            $471 = $465 < Math_fround(0.0);
            $or$cond80 = $470 & $471;
            if (!($or$cond80)) {
             break;
            }
           }
           $472 = HEAP8[$383>>0]|0;
           $473 = $472&255;
           __ZNK5physx2Gu15HeightFieldUtil18computePointNormalEjRKNS_6PxVec3ERKNS_11PxTransformEffffRf($n,$hfUtil,$473,$d,$transform1,$431,$459,$463,$106,$l);
           $474 = Math_fround(HEAPF32[$n>>2]);
           $475 = Math_fround($474 * Math_fround(2.0));
           $476 = Math_fround(HEAPF32[$392>>2]);
           $477 = Math_fround($476 * Math_fround(2.0));
           $478 = Math_fround(HEAPF32[$393>>2]);
           $479 = Math_fround($478 * Math_fround(2.0));
           $480 = Math_fround(HEAPF32[$33>>2]);
           $481 = Math_fround($480 * $480);
           $482 = Math_fround($481 + Math_fround(-0.5));
           $483 = Math_fround(HEAPF32[$transform1>>2]);
           $484 = Math_fround($475 * $483);
           $485 = Math_fround(HEAPF32[$27>>2]);
           $486 = Math_fround($477 * $485);
           $487 = Math_fround($484 + $486);
           $488 = Math_fround(HEAPF32[$30>>2]);
           $489 = Math_fround($479 * $488);
           $490 = Math_fround($487 + $489);
           $491 = Math_fround($475 * $482);
           $492 = Math_fround($479 * $485);
           $493 = Math_fround($477 * $488);
           $494 = Math_fround($492 - $493);
           $495 = Math_fround($480 * $494);
           $496 = Math_fround($491 - $495);
           $497 = Math_fround($483 * $490);
           $498 = Math_fround($497 + $496);
           $499 = Math_fround($477 * $482);
           $500 = Math_fround($475 * $488);
           $501 = Math_fround($479 * $483);
           $502 = Math_fround($500 - $501);
           $503 = Math_fround($480 * $502);
           $504 = Math_fround($499 - $503);
           $505 = Math_fround($485 * $490);
           $506 = Math_fround($505 + $504);
           $507 = Math_fround($479 * $482);
           $508 = Math_fround($477 * $483);
           $509 = Math_fround($475 * $485);
           $510 = Math_fround($508 - $509);
           $511 = Math_fround($480 * $510);
           $512 = Math_fround($507 - $511);
           $513 = Math_fround($488 * $490);
           $514 = Math_fround($512 + $513);
           $515 = ($415|0)==(0);
           L26: do {
            if ($515) {
             $669 = $478;$671 = $476;$673 = $474;
            } else {
             $517 = $417;$j$087 = 1;
             while(1) {
              __ZNK5physx2Gu11HeightField25getTriangleNormalInternalEj($1,$4,$517);
              $518 = Math_fround(HEAPF32[$1>>2]);
              $519 = Math_fround(HEAPF32[$hfUtil>>2]);
              $520 = Math_fround($518 * $519);
              $521 = Math_fround(HEAPF32[$394>>2]);
              $522 = Math_fround(HEAPF32[$10>>2]);
              $523 = Math_fround($521 * $522);
              $524 = Math_fround(HEAPF32[$395>>2]);
              $525 = Math_fround(HEAPF32[$17>>2]);
              $526 = Math_fround($524 * $525);
              $527 = Math_fround($520 * $520);
              $528 = Math_fround($523 * $523);
              $529 = Math_fround($527 + $528);
              $530 = Math_fround($526 * $526);
              $531 = Math_fround($529 + $530);
              $532 = $531 > Math_fround(0.0);
              if ($532) {
               $533 = (Math_fround(Math_sqrt((Math_fround($531)))));
               $534 = Math_fround(Math_fround(1.0) / $533);
               $535 = Math_fround($520 * $534);
               $536 = Math_fround($523 * $534);
               $537 = Math_fround($526 * $534);
               $572 = $536;$575 = $537;$580 = $535;
              } else {
               $572 = Math_fround(0.0);$575 = Math_fround(0.0);$580 = Math_fround(0.0);
              }
              $538 = $517 >>> 1;
              $539 = HEAP32[$349>>2]|0;
              $540 = (($538>>>0) / ($539>>>0))&-1;
              $541 = (($538>>>0) % ($539>>>0))&-1;
              __ZNK5physx2Gu11HeightField19getTriangleVerticesEjjjRNS_6PxVec3ES3_S3_($4,$517,$540,$541,$tv0,$tv1,$tv2);
              $542 = Math_fround(HEAPF32[$tv0>>2]);
              $543 = Math_fround(HEAPF32[$tv1>>2]);
              $544 = Math_fround($542 + $543);
              $545 = Math_fround(HEAPF32[$396>>2]);
              $546 = Math_fround(HEAPF32[$397>>2]);
              $547 = Math_fround($545 + $546);
              $548 = Math_fround(HEAPF32[$398>>2]);
              $549 = Math_fround(HEAPF32[$399>>2]);
              $550 = Math_fround($548 + $549);
              $551 = Math_fround(HEAPF32[$tv2>>2]);
              $552 = Math_fround($544 + $551);
              $553 = Math_fround(HEAPF32[$400>>2]);
              $554 = Math_fround($547 + $553);
              $555 = Math_fround(HEAPF32[$401>>2]);
              $556 = Math_fround($550 + $555);
              $557 = Math_fround($552 * Math_fround(0.333333343267440795898));
              $558 = Math_fround($554 * Math_fround(0.333333343267440795898));
              $559 = Math_fround($556 * Math_fround(0.333333343267440795898));
              $560 = HEAP32[$6>>2]|0;
              $561 = (($560) + 12|0);
              $562 = Math_fround(HEAPF32[$561>>2]);
              $563 = Math_fround($557 * $562);
              $564 = (($560) + 8|0);
              $565 = Math_fround(HEAPF32[$564>>2]);
              $566 = Math_fround($558 * $565);
              $567 = (($560) + 16|0);
              $568 = Math_fround(HEAPF32[$567>>2]);
              $569 = Math_fround($559 * $568);
              $570 = Math_fround(HEAPF32[$direction$idx9>>2]);
              $571 = Math_fround($572 * $570);
              $573 = Math_fround(HEAPF32[$direction$idx8>>2]);
              $574 = Math_fround($575 * $573);
              $576 = Math_fround($571 - $574);
              $577 = Math_fround(HEAPF32[$direction>>2]);
              $578 = Math_fround($575 * $577);
              $579 = Math_fround($580 * $570);
              $581 = Math_fround($578 - $579);
              $582 = Math_fround($580 * $573);
              $583 = Math_fround($572 * $577);
              $584 = Math_fround($582 - $583);
              $585 = Math_fround($576 * $576);
              $586 = Math_fround($581 * $581);
              $587 = Math_fround($585 + $586);
              $588 = Math_fround($584 * $584);
              $589 = Math_fround($588 + $587);
              $590 = $589 > Math_fround(0.0);
              if ($590) {
               $591 = (Math_fround(Math_sqrt((Math_fround($589)))));
               $592 = Math_fround(Math_fround(1.0) / $591);
               $593 = Math_fround($576 * $592);
               $594 = Math_fround($581 * $592);
               $595 = Math_fround($584 * $592);
               $603 = $593;$605 = $594;$608 = $595;
              } else {
               $603 = Math_fround(0.0);$605 = Math_fround(0.0);$608 = Math_fround(0.0);
              }
              $596 = Math_fround(HEAPF32[$origin>>2]);
              $597 = Math_fround($563 - $596);
              $598 = Math_fround(HEAPF32[$388>>2]);
              $599 = Math_fround($566 - $598);
              $600 = Math_fround(HEAPF32[$389>>2]);
              $601 = Math_fround($569 - $600);
              $602 = Math_fround($603 * $597);
              $604 = Math_fround($605 * $599);
              $606 = Math_fround($602 + $604);
              $607 = Math_fround($608 * $601);
              $609 = Math_fround($606 + $607);
              $610 = $609 < Math_fround(0.0);
              if ($610) {
               $611 = Math_fround(-$603);
               $612 = Math_fround(-$605);
               $613 = Math_fround(-$608);
               $615 = $611;$617 = $612;$620 = $613;
              } else {
               $615 = $603;$617 = $605;$620 = $608;
              }
              $614 = Math_fround($498 * $615);
              $616 = Math_fround($506 * $617);
              $618 = Math_fround($616 + $614);
              $619 = Math_fround($514 * $620);
              $621 = Math_fround($619 + $618);
              $622 = $621 > Math_fround(0.0);
              if ($622) {
               break;
              }
              $516 = ($j$087>>>0)<($415>>>0);
              if (!($516)) {
               $669 = $478;$671 = $476;$673 = $474;
               break L26;
              }
              $$phi$trans$insert = (($adjFaceIndices) + ($j$087<<2)|0);
              $$pre109 = HEAP32[$$phi$trans$insert>>2]|0;
              $phitmp = (($j$087) + 1)|0;
              $517 = $$pre109;$j$087 = $phitmp;
             }
             $623 = Math_fround($580 * Math_fround(2.0));
             $624 = Math_fround($572 * Math_fround(2.0));
             $625 = Math_fround($575 * Math_fround(2.0));
             $626 = Math_fround(HEAPF32[$33>>2]);
             $627 = Math_fround($626 * $626);
             $628 = Math_fround($627 + Math_fround(-0.5));
             $629 = Math_fround(HEAPF32[$transform1>>2]);
             $630 = Math_fround($623 * $629);
             $631 = Math_fround(HEAPF32[$27>>2]);
             $632 = Math_fround($624 * $631);
             $633 = Math_fround($630 + $632);
             $634 = Math_fround(HEAPF32[$30>>2]);
             $635 = Math_fround($625 * $634);
             $636 = Math_fround($633 + $635);
             $637 = Math_fround($623 * $628);
             $638 = Math_fround($625 * $631);
             $639 = Math_fround($624 * $634);
             $640 = Math_fround($638 - $639);
             $641 = Math_fround($626 * $640);
             $642 = Math_fround($637 + $641);
             $643 = Math_fround($629 * $636);
             $644 = Math_fround($643 + $642);
             $645 = Math_fround($624 * $628);
             $646 = Math_fround($623 * $634);
             $647 = Math_fround($625 * $629);
             $648 = Math_fround($646 - $647);
             $649 = Math_fround($626 * $648);
             $650 = Math_fround($645 + $649);
             $651 = Math_fround($631 * $636);
             $652 = Math_fround($651 + $650);
             $653 = Math_fround($625 * $628);
             $654 = Math_fround($624 * $629);
             $655 = Math_fround($623 * $631);
             $656 = Math_fround($654 - $655);
             $657 = Math_fround($626 * $656);
             $658 = Math_fround($653 + $657);
             $659 = Math_fround($634 * $636);
             $660 = Math_fround($658 + $659);
             HEAPF32[$n>>2] = $644;
             HEAPF32[$392>>2] = $652;
             HEAPF32[$393>>2] = $660;
             $669 = $660;$671 = $652;$673 = $644;
            }
           } while(0);
           $661 = Math_fround(HEAPF32[$s>>2]);
           $662 = HEAP32[$311>>2]|0;
           $663 = ($662>>>0)>(63);
           if (!($663)) {
            $664 = Math_fround($380 * $661);
            $665 = Math_fround($381 * $661);
            $666 = Math_fround($382 * $661);
            $667 = Math_fround(HEAPF32[$l>>2]);
            $668 = Math_fround($19 * $669);
            $670 = Math_fround($19 * $671);
            $672 = Math_fround($19 * $673);
            $674 = Math_fround($299 + $664);
            $675 = Math_fround($297 + $665);
            $676 = Math_fround($295 + $666);
            $677 = Math_fround($667 - $19);
            $678 = Math_fround($674 - $668);
            $679 = Math_fround($675 - $670);
            $680 = Math_fround($676 - $672);
            $681 = (($662) + 1)|0;
            HEAP32[$311>>2] = $681;
            $682 = (($contactBuffer) + ($662<<6)|0);
            HEAPF32[$682>>2] = $673;
            $683 = ((($contactBuffer) + ($662<<6)|0) + 4|0);
            HEAPF32[$683>>2] = $671;
            $684 = ((($contactBuffer) + ($662<<6)|0) + 8|0);
            HEAPF32[$684>>2] = $669;
            $685 = ((($contactBuffer) + ($662<<6)|0) + 16|0);
            HEAPF32[$685>>2] = $680;
            $686 = ((($contactBuffer) + ($662<<6)|0) + 20|0);
            HEAPF32[$686>>2] = $679;
            $687 = ((($contactBuffer) + ($662<<6)|0) + 24|0);
            HEAPF32[$687>>2] = $678;
            $688 = ((($contactBuffer) + ($662<<6)|0) + 12|0);
            HEAPF32[$688>>2] = $677;
            $689 = ((($contactBuffer) + ($662<<6)|0) + 48|0);
            HEAP32[$689>>2] = -1;
            $690 = ((($contactBuffer) + ($662<<6)|0) + 52|0);
            HEAP32[$690>>2] = $417;
           }
          }
         }
        }
       } while(0);
       $691 = (($ei$089) + 1)|0;
       $exitcond105 = ($691|0)==($404|0);
       if ($exitcond105) {
        break;
       } else {
        $ei$089 = $691;
       }
      }
     }
     $692 = HEAP32[$5>>2]|0;
     $693 = (($692) + 36|0);
     $694 = HEAP32[$693>>2]|0;
     $695 = ((($694) + ($409<<2)|0) + 3|0);
     $696 = HEAP8[$695>>0]|0;
     $697 = ($696<<24>>24)<(0);
     do {
      if ($697) {
       $698 = Math_fround(HEAPF32[$11>>2]);
       $699 = Math_fround($405 * $698);
       $700 = Math_fround(HEAPF32[$7>>2]);
       $701 = HEAP32[$372>>2]|0;
       $702 = (($701) + ($409<<2)|0);
       $703 = HEAP16[$702>>1]|0;
       $704 = (Math_fround(($703<<16>>16)));
       $705 = Math_fround($700 * $704);
       $706 = (Math_fround(($column$097>>>0)));
       $707 = Math_fround(HEAPF32[$14>>2]);
       $708 = Math_fround($706 * $707);
       HEAPF32[$vertex>>2] = $699;
       HEAPF32[$373>>2] = $705;
       HEAPF32[$374>>2] = $708;
       $709 = (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($capsuleSegmentInHfShape,$375,$vertex,$s1)));
       $710 = $709 < $105;
       if ($710) {
        $711 = Math_fround(HEAPF32[$s1>>2]);
        $712 = Math_fround(HEAPF32[$305>>2]);
        $713 = Math_fround(HEAPF32[$capsuleSegmentInHfShape>>2]);
        $714 = Math_fround($712 - $713);
        $715 = Math_fround(HEAPF32[$307>>2]);
        $716 = Math_fround(HEAPF32[$301>>2]);
        $717 = Math_fround($715 - $716);
        $718 = Math_fround(HEAPF32[$309>>2]);
        $719 = Math_fround(HEAPF32[$303>>2]);
        $720 = Math_fround($718 - $719);
        $721 = Math_fround($711 * $714);
        $722 = Math_fround($711 * $717);
        $723 = Math_fround($711 * $720);
        $724 = Math_fround($713 + $721);
        $725 = Math_fround($716 + $722);
        $726 = Math_fround($719 + $723);
        $727 = Math_fround(HEAPF32[$vertex>>2]);
        $728 = Math_fround($724 - $727);
        $729 = Math_fround(HEAPF32[$373>>2]);
        $730 = Math_fround($725 - $729);
        $731 = Math_fround(HEAPF32[$374>>2]);
        $732 = Math_fround($726 - $731);
        HEAPF32[$d4>>2] = $728;
        HEAPF32[$376>>2] = $730;
        HEAPF32[$377>>2] = $732;
        $733 = Math_fround(HEAPF32[$378>>2]);
        $734 = $733 <= Math_fround(0.0);
        $735 = $730 > Math_fround(0.0);
        $or$cond$i = $734 & $735;
        if (!($or$cond$i)) {
         $736 = $733 > Math_fround(0.0);
         $737 = $730 < Math_fround(0.0);
         $or$cond81 = $736 & $737;
         if (!($or$cond81)) {
          break;
         }
        }
        L51: do {
         if ($379) {
          label = 47;
         } else {
          $738 = HEAP32[$372>>2]|0;
          $iVertexContact$094 = 0;
          while(1) {
           $739 = ((($contactBuffer) + ($iVertexContact$094<<6)|0) + 52|0);
           $740 = HEAP32[$739>>2]|0;
           $741 = $740 >>> 1;
           $742 = ((($738) + ($741<<2)|0) + 2|0);
           $743 = HEAP8[$742>>0]|0;
           $744 = ($743<<24>>24)<(0);
           $745 = $740 & 1;
           $746 = ($745|0)==(0);
           do {
            if ($744) {
             if ($746) {
              $747 = HEAP32[$349>>2]|0;
              $748 = (($747) + ($741))|0;
              $749 = (($741) + 1)|0;
              $750 = (($749) + ($747))|0;
              $765 = $748;$767 = $741;$769 = $750;
              break;
             } else {
              $751 = (($741) + 1)|0;
              $752 = HEAP32[$349>>2]|0;
              $753 = (($752) + ($751))|0;
              $765 = $751;$767 = $753;$769 = $741;
              break;
             }
            } else {
             if ($746) {
              $754 = (($741) + 1)|0;
              $755 = HEAP32[$349>>2]|0;
              $756 = (($755) + ($741))|0;
              $765 = $741;$767 = $754;$769 = $756;
              break;
             } else {
              $757 = HEAP32[$349>>2]|0;
              $758 = (($741) + 1)|0;
              $759 = (($757) + ($758))|0;
              $760 = (($757) + ($741))|0;
              $765 = $759;$767 = $760;$769 = $758;
              break;
             }
            }
           } while(0);
           $761 = ((($contactBuffer) + ($iVertexContact$094<<6)|0) + 48|0);
           $762 = HEAP32[$761>>2]|0;
           $763 = ($762|0)==(0);
           if ($763) {
            $764 = ($409|0)==($765|0);
            $766 = ($409|0)==($767|0);
            $or$cond82 = $764 | $766;
            $768 = ($409|0)==($769|0);
            $or$cond83 = $or$cond82 | $768;
            if ($or$cond83) {
             break;
            }
           }
           $776 = (($iVertexContact$094) + 1)|0;
           $777 = ($776>>>0)<($312>>>0);
           if ($777) {
            $iVertexContact$094 = $776;
           } else {
            label = 47;
            break L51;
           }
          }
          $770 = (($contactBuffer) + ($iVertexContact$094<<6)|0);
          $771 = Math_fround(HEAPF32[$770>>2]);
          $772 = ((($contactBuffer) + ($iVertexContact$094<<6)|0) + 4|0);
          $773 = Math_fround(HEAPF32[$772>>2]);
          $774 = ((($contactBuffer) + ($iVertexContact$094<<6)|0) + 8|0);
          $775 = Math_fround(HEAPF32[$774>>2]);
          HEAPF32[$l6>>2] = Math_fround(1.0);
          $787 = $711;$792 = $775;$794 = $773;$796 = $771;
         }
        } while(0);
        if ((label|0) == 47) {
         label = 0;
         HEAPF32[$l6>>2] = Math_fround(1.0);
         $778 = HEAP8[$383>>0]|0;
         $779 = $778&255;
         __ZNK5physx2Gu15HeightFieldUtil18computePointNormalEjRKNS_6PxVec3ERKNS_11PxTransformEffffRf($2,$hfUtil,$779,$d4,$transform1,$709,$727,$731,$106,$l6);
         $780 = Math_fround(HEAPF32[$2>>2]);
         $781 = Math_fround(HEAPF32[$384>>2]);
         $782 = Math_fround(HEAPF32[$385>>2]);
         $$pre = Math_fround(HEAPF32[$s1>>2]);
         $787 = $$pre;$792 = $782;$794 = $781;$796 = $780;
        }
        $783 = (__ZNK5physx2Gu15HeightFieldUtil18getVertexFaceIndexEjjj($hfUtil,$409,$row$0100,$column$097)|0);
        $784 = HEAP32[$311>>2]|0;
        $785 = ($784>>>0)>(63);
        if (!($785)) {
         $786 = Math_fround($380 * $787);
         $788 = Math_fround($381 * $787);
         $789 = Math_fround($382 * $787);
         $790 = Math_fround(HEAPF32[$l6>>2]);
         $791 = Math_fround($19 * $792);
         $793 = Math_fround($19 * $794);
         $795 = Math_fround($19 * $796);
         $797 = Math_fround($299 + $786);
         $798 = Math_fround($297 + $788);
         $799 = Math_fround($295 + $789);
         $800 = Math_fround($790 - $19);
         $801 = Math_fround($797 - $791);
         $802 = Math_fround($798 - $793);
         $803 = Math_fround($799 - $795);
         $804 = (($784) + 1)|0;
         HEAP32[$311>>2] = $804;
         $805 = (($contactBuffer) + ($784<<6)|0);
         HEAPF32[$805>>2] = $796;
         $806 = ((($contactBuffer) + ($784<<6)|0) + 4|0);
         HEAPF32[$806>>2] = $794;
         $807 = ((($contactBuffer) + ($784<<6)|0) + 8|0);
         HEAPF32[$807>>2] = $792;
         $808 = ((($contactBuffer) + ($784<<6)|0) + 16|0);
         HEAPF32[$808>>2] = $803;
         $809 = ((($contactBuffer) + ($784<<6)|0) + 20|0);
         HEAPF32[$809>>2] = $802;
         $810 = ((($contactBuffer) + ($784<<6)|0) + 24|0);
         HEAPF32[$810>>2] = $801;
         $811 = ((($contactBuffer) + ($784<<6)|0) + 12|0);
         HEAPF32[$811>>2] = $800;
         $812 = ((($contactBuffer) + ($784<<6)|0) + 48|0);
         HEAP32[$812>>2] = -1;
         $813 = ((($contactBuffer) + ($784<<6)|0) + 52|0);
         HEAP32[$813>>2] = $783;
        }
       }
      }
     } while(0);
     $814 = (($column$097) + 1)|0;
     $815 = ($814>>>0)>($366>>>0);
     if ($815) {
      break;
     } else {
      $column$097 = $814;
     }
    }
   }
   $816 = (($row$0100) + 1)|0;
   $817 = ($816>>>0)>($342>>>0);
   if ($817) {
    break;
   } else {
    $row$0100 = $816;
   }
  }
 }
 $406 = ($312|0)==(0);
 if ($406) {
  $820 = HEAP32[$311>>2]|0;
  $821 = ($820|0)!=(0);
  STACKTOP = sp;return ($821|0);
 } else {
  $iVertexContact9$084 = 0;
 }
 while(1) {
  $818 = ((($contactBuffer) + ($iVertexContact9$084<<6)|0) + 48|0);
  HEAP32[$818>>2] = -1;
  $819 = (($iVertexContact9$084) + 1)|0;
  $exitcond = ($819|0)==($312|0);
  if ($exitcond) {
   break;
  } else {
   $iVertexContact9$084 = $819;
  }
 }
 $820 = HEAP32[$311>>2]|0;
 $821 = ($820|0)!=(0);
 STACKTOP = sp;return ($821|0);
}
function __ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($this,$edgeIndex,$triangleIndices) {
 $this = $this|0;
 $edgeIndex = $edgeIndex|0;
 $triangleIndices = $triangleIndices|0;
 var $$lobit = 0, $$lobit2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0 = 0, $count$1 = 0, $count$2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($edgeIndex>>>0) / 3)&-1;
 $1 = (($this) + 16|0);
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0>>>0) / ($3>>>0))&-1;
 $5 = (($0>>>0) % ($3>>>0))&-1;
 $6 = Math_imul($0, -3)|0;
 $7 = (($6) + ($edgeIndex))|0;
 if ((($7|0) == 0)) {
  $8 = (($3) + -1)|0;
  $9 = ($5>>>0)<($8>>>0);
  if (!($9)) {
   $count$2 = 0;
   STACKTOP = sp;return ($count$2|0);
  }
  $10 = ($4|0)==(0);
  if ($10) {
   $count$0 = 0;
  } else {
   $11 = (($0) - ($3))|0;
   $12 = $11 << 1;
   $13 = (($this) + 36|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($14) + ($11<<2)|0) + 2|0);
   $16 = HEAP8[$15>>0]|0;
   $$lobit = ($16&255) >>> 7;
   $17 = $$lobit&255;
   $18 = $17 | $12;
   HEAP32[$triangleIndices>>2] = $18;
   $count$0 = 1;
  }
  $19 = HEAP32[$1>>2]|0;
  $20 = (($19) + -1)|0;
  $21 = ($4>>>0)<($20>>>0);
  if (!($21)) {
   $count$2 = $count$0;
   STACKTOP = sp;return ($count$2|0);
  }
  $22 = $0 << 1;
  $23 = (($this) + 36|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($24) + ($0<<2)|0) + 2|0);
  $26 = HEAP8[$25>>0]|0;
  $$lobit2 = ($26&255) >>> 7;
  $27 = $$lobit2&255;
  $28 = $27 | $22;
  $29 = (($count$0) + 1)|0;
  $30 = (($triangleIndices) + ($count$0<<2)|0);
  HEAP32[$30>>2] = $28;
  $count$2 = $29;
  STACKTOP = sp;return ($count$2|0);
 } else if ((($7|0) == 2)) {
  $39 = HEAP32[$1>>2]|0;
  $40 = (($39) + -1)|0;
  $41 = ($4>>>0)<($40>>>0);
  if (!($41)) {
   $count$2 = 0;
   STACKTOP = sp;return ($count$2|0);
  }
  $42 = ($5|0)==(0);
  if ($42) {
   $46 = $3;$count$1 = 0;
  } else {
   $43 = $0 << 1;
   $44 = (($43) + -1)|0;
   HEAP32[$triangleIndices>>2] = $44;
   $$pre = HEAP32[$2>>2]|0;
   $46 = $$pre;$count$1 = 1;
  }
  $45 = (($46) + -1)|0;
  $47 = ($5>>>0)<($45>>>0);
  if (!($47)) {
   $count$2 = $count$1;
   STACKTOP = sp;return ($count$2|0);
  }
  $48 = $0 << 1;
  $49 = (($count$1) + 1)|0;
  $50 = (($triangleIndices) + ($count$1<<2)|0);
  HEAP32[$50>>2] = $48;
  $count$2 = $49;
  STACKTOP = sp;return ($count$2|0);
 } else if ((($7|0) == 1)) {
  $31 = HEAP32[$1>>2]|0;
  $32 = (($31) + -1)|0;
  $33 = ($4>>>0)<($32>>>0);
  $34 = (($3) + -1)|0;
  $35 = ($5>>>0)<($34>>>0);
  $or$cond = $33 & $35;
  if (!($or$cond)) {
   $count$2 = 0;
   STACKTOP = sp;return ($count$2|0);
  }
  $36 = $0 << 1;
  HEAP32[$triangleIndices>>2] = $36;
  $37 = $36 | 1;
  $38 = (($triangleIndices) + 4|0);
  HEAP32[$38>>2] = $37;
  $count$2 = 2;
  STACKTOP = sp;return ($count$2|0);
 } else {
  $count$2 = 0;
  STACKTOP = sp;return ($count$2|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu15HeightFieldUtil18computePointNormalEjRKNS_6PxVec3ERKNS_11PxTransformEffffRf($agg$result,$this,$meshFlags,$d,$transform,$l_sqr,$x,$z,$epsilon,$l) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $meshFlags = $meshFlags|0;
 $d = $d|0;
 $transform = $transform|0;
 $l_sqr = Math_fround($l_sqr);
 $x = Math_fround($x);
 $z = Math_fround($z);
 $epsilon = Math_fround($epsilon);
 $l = $l|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $14 = Math_fround(0);
 var $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $storemerge = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $l_sqr > $epsilon;
 if ($1) {
  $2 = Math_fround(HEAPF32[$d>>2]);
  $3 = Math_fround($2 * Math_fround(2.0));
  $4 = (($d) + 4|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = Math_fround($5 * Math_fround(2.0));
  $7 = (($d) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround($8 * Math_fround(2.0));
  $10 = (($transform) + 12|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($11 * $11);
  $13 = Math_fround($12 + Math_fround(-0.5));
  $14 = Math_fround(HEAPF32[$transform>>2]);
  $15 = Math_fround($3 * $14);
  $16 = (($transform) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($6 * $17);
  $19 = Math_fround($15 + $18);
  $20 = (($transform) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($9 * $21);
  $23 = Math_fround($19 + $22);
  $24 = Math_fround($3 * $13);
  $25 = Math_fround($9 * $17);
  $26 = Math_fround($6 * $21);
  $27 = Math_fround($25 - $26);
  $28 = Math_fround($11 * $27);
  $29 = Math_fround($24 + $28);
  $30 = Math_fround($14 * $23);
  $31 = Math_fround($30 + $29);
  $32 = Math_fround($6 * $13);
  $33 = Math_fround($3 * $21);
  $34 = Math_fround($9 * $14);
  $35 = Math_fround($33 - $34);
  $36 = Math_fround($11 * $35);
  $37 = Math_fround($32 + $36);
  $38 = Math_fround($17 * $23);
  $39 = Math_fround($38 + $37);
  $40 = Math_fround($9 * $13);
  $41 = Math_fround($6 * $14);
  $42 = Math_fround($3 * $17);
  $43 = Math_fround($41 - $42);
  $44 = Math_fround($11 * $43);
  $45 = Math_fround($40 + $44);
  $46 = Math_fround($21 * $23);
  $47 = Math_fround($45 + $46);
  HEAPF32[$agg$result>>2] = $31;
  $48 = (($agg$result) + 4|0);
  HEAPF32[$48>>2] = $39;
  $49 = (($agg$result) + 8|0);
  HEAPF32[$49>>2] = $47;
  $50 = Math_fround($31 * $31);
  $51 = Math_fround($39 * $39);
  $52 = Math_fround($50 + $51);
  $53 = Math_fround($47 * $47);
  $54 = Math_fround($52 + $53);
  $55 = (Math_fround(Math_sqrt((Math_fround($54)))));
  $56 = $55 > Math_fround(0.0);
  if (!($56)) {
   $storemerge = $55;
   HEAPF32[$l>>2] = $storemerge;
   STACKTOP = sp;return;
  }
  $57 = Math_fround(Math_fround(1.0) / $55);
  $58 = Math_fround($31 * $57);
  HEAPF32[$agg$result>>2] = $58;
  $59 = Math_fround($39 * $57);
  HEAPF32[$48>>2] = $59;
  $60 = Math_fround($47 * $57);
  HEAPF32[$49>>2] = $60;
  $storemerge = $55;
  HEAPF32[$l>>2] = $storemerge;
  STACKTOP = sp;return;
 } else {
  $61 = (($this) + 12|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = Math_fround(HEAPF32[$this>>2]);
  $64 = Math_fround($63 * $x);
  $65 = (($this) + 8|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($66 * $z);
  $68 = (($this) + 4|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  __ZNK5physx2Gu11HeightField10getNormal_Efffff($0,$62,$64,$67,$63,$69,$66);
  $70 = Math_fround(HEAPF32[$0>>2]);
  $71 = Math_fround($70 * Math_fround(2.0));
  $72 = (($0) + 4|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($73 * Math_fround(2.0));
  $75 = (($0) + 8|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($76 * Math_fround(2.0));
  $78 = (($transform) + 12|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($79 * $79);
  $81 = Math_fround($80 + Math_fround(-0.5));
  $82 = Math_fround(HEAPF32[$transform>>2]);
  $83 = Math_fround($71 * $82);
  $84 = (($transform) + 4|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($74 * $85);
  $87 = Math_fround($83 + $86);
  $88 = (($transform) + 8|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = Math_fround($77 * $89);
  $91 = Math_fround($87 + $90);
  $92 = Math_fround($71 * $81);
  $93 = Math_fround($77 * $85);
  $94 = Math_fround($74 * $89);
  $95 = Math_fround($93 - $94);
  $96 = Math_fround($79 * $95);
  $97 = Math_fround($92 + $96);
  $98 = Math_fround($82 * $91);
  $99 = Math_fround($98 + $97);
  $100 = Math_fround($74 * $81);
  $101 = Math_fround($71 * $89);
  $102 = Math_fround($77 * $82);
  $103 = Math_fround($101 - $102);
  $104 = Math_fround($79 * $103);
  $105 = Math_fround($100 + $104);
  $106 = Math_fround($85 * $91);
  $107 = Math_fround($106 + $105);
  $108 = Math_fround($77 * $81);
  $109 = Math_fround($74 * $82);
  $110 = Math_fround($71 * $85);
  $111 = Math_fround($109 - $110);
  $112 = Math_fround($79 * $111);
  $113 = Math_fround($108 + $112);
  $114 = Math_fround($89 * $91);
  $115 = Math_fround($113 + $114);
  HEAPF32[$agg$result>>2] = $99;
  $116 = (($agg$result) + 4|0);
  HEAPF32[$116>>2] = $107;
  $117 = (($agg$result) + 8|0);
  HEAPF32[$117>>2] = $115;
  $118 = Math_fround($99 * $99);
  $119 = Math_fround($107 * $107);
  $120 = Math_fround($118 + $119);
  $121 = Math_fround($115 * $115);
  $122 = Math_fround($120 + $121);
  $123 = $122 > Math_fround(0.0);
  if ($123) {
   $124 = (Math_fround(Math_sqrt((Math_fround($122)))));
   $125 = Math_fround(Math_fround(1.0) / $124);
   $126 = Math_fround($99 * $125);
   $127 = Math_fround($107 * $125);
   $128 = Math_fround($115 * $125);
   $129 = $126;$130 = $127;$131 = $128;
  } else {
   $129 = Math_fround(0.0);$130 = Math_fround(0.0);$131 = Math_fround(0.0);
  }
  HEAPF32[$agg$result>>2] = $129;
  HEAPF32[$116>>2] = $130;
  HEAPF32[$117>>2] = $131;
  $132 = (Math_fround(Math_sqrt((Math_fround($l_sqr)))));
  $storemerge = $132;
  HEAPF32[$l>>2] = $storemerge;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu11HeightField25getTriangleNormalInternalEj($agg$result,$this,$triangleIndex) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $triangleIndex = $triangleIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $triangleIndex >>> 1;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2) + ($0<<2)|0) + 2|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = $triangleIndex & 1;
 $7 = ($6|0)==(0);
 do {
  if ($5) {
   if ($7) {
    $8 = (($this) + 20|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + ($0))|0;
    $11 = (($0) + 1)|0;
    $12 = (($11) + ($9))|0;
    $27 = $10;$31 = $0;$35 = $12;
    break;
   } else {
    $13 = (($0) + 1)|0;
    $14 = (($this) + 20|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($15) + ($13))|0;
    $27 = $13;$31 = $16;$35 = $0;
    break;
   }
  } else {
   if ($7) {
    $17 = (($0) + 1)|0;
    $18 = (($this) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + ($0))|0;
    $27 = $0;$31 = $17;$35 = $20;
    break;
   } else {
    $21 = (($this) + 20|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($0) + 1)|0;
    $24 = (($22) + ($23))|0;
    $25 = (($22) + ($0))|0;
    $27 = $24;$31 = $25;$35 = $23;
    break;
   }
  }
 } while(0);
 $26 = (($2) + ($27<<2)|0);
 $28 = HEAP16[$26>>1]|0;
 $29 = $28 << 16 >> 16;
 $30 = (($2) + ($31<<2)|0);
 $32 = HEAP16[$30>>1]|0;
 $33 = $32 << 16 >> 16;
 $34 = (($2) + ($35<<2)|0);
 $36 = HEAP16[$34>>1]|0;
 $37 = $36 << 16 >> 16;
 $38 = (($this) + 40|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = $39 >= Math_fround(0.0);
 $41 = $40 ? Math_fround(-1.0) : Math_fround(1.0);
 if ($5) {
  if ($7) {
   $42 = (($33) - ($29))|0;
   $43 = (Math_fround(($42|0)));
   $44 = Math_fround($43 * $41);
   $45 = (($29) - ($37))|0;
   $46 = (Math_fround(($45|0)));
   $47 = Math_fround($41 * $46);
   HEAPF32[$agg$result>>2] = $44;
   $48 = (($agg$result) + 4|0);
   HEAPF32[$48>>2] = $41;
   $49 = (($agg$result) + 8|0);
   HEAPF32[$49>>2] = $47;
   STACKTOP = sp;return;
  } else {
   $50 = (($29) - ($33))|0;
   $51 = (Math_fround(($50|0)));
   $52 = Math_fround($51 * $41);
   $53 = (($37) - ($29))|0;
   $54 = (Math_fround(($53|0)));
   $55 = Math_fround($41 * $54);
   HEAPF32[$agg$result>>2] = $52;
   $56 = (($agg$result) + 4|0);
   HEAPF32[$56>>2] = $41;
   $57 = (($agg$result) + 8|0);
   HEAPF32[$57>>2] = $55;
   STACKTOP = sp;return;
  }
 } else {
  if ($7) {
   $58 = (($29) - ($37))|0;
   $59 = (Math_fround(($58|0)));
   $60 = Math_fround($41 * $59);
   $61 = (($29) - ($33))|0;
   $62 = (Math_fround(($61|0)));
   $63 = Math_fround($62 * $41);
   HEAPF32[$agg$result>>2] = $60;
   $64 = (($agg$result) + 4|0);
   HEAPF32[$64>>2] = $41;
   $65 = (($agg$result) + 8|0);
   HEAPF32[$65>>2] = $63;
   STACKTOP = sp;return;
  } else {
   $66 = (($37) - ($29))|0;
   $67 = (Math_fround(($66|0)));
   $68 = Math_fround($41 * $67);
   $69 = (($33) - ($29))|0;
   $70 = (Math_fround(($69|0)));
   $71 = Math_fround($70 * $41);
   HEAPF32[$agg$result>>2] = $68;
   $72 = (($agg$result) + 4|0);
   HEAPF32[$72>>2] = $41;
   $73 = (($agg$result) + 8|0);
   HEAPF32[$73>>2] = $71;
   STACKTOP = sp;return;
  }
 }
}
function __ZNK5physx2Gu11HeightField10getNormal_Efffff($agg$result,$this,$x,$z,$xcoeff,$ycoeff,$zcoeff) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $x = Math_fround($x);
 $z = Math_fround($z);
 $xcoeff = Math_fround($xcoeff);
 $ycoeff = Math_fround($ycoeff);
 $zcoeff = Math_fround($zcoeff);
 var $$pn$i = Math_fround(0), $$pn$in$i = 0, $$pn11$i = Math_fround(0), $$pn11$in$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0);
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $fracX = 0, $fracZ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fracX = sp + 4|0;
 $fracZ = sp;
 $0 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($this,$x,$z,$fracX,$fracZ)|0);
 $1 = Math_fround(HEAPF32[$fracX>>2]);
 $2 = Math_fround(HEAPF32[$fracZ>>2]);
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + ($0<<2)|0) + 2|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)<(0);
 do {
  if ($7) {
   $8 = (($4) + ($0<<2)|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = $9 << 16 >> 16;
   $11 = (($this) + 20|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($0))|0;
   $14 = (($13) + 1)|0;
   $15 = (($4) + ($14<<2)|0);
   $16 = HEAP16[$15>>1]|0;
   $17 = $16 << 16 >> 16;
   $18 = !($2 >= $1);
   if ($18) {
    $25 = (($4) + ($13<<2)|0);
    $26 = HEAP16[$25>>1]|0;
    $27 = $26 << 16 >> 16;
    $28 = (($10) - ($27))|0;
    $29 = (($27) - ($17))|0;
    $$pn$in$i = $29;$$pn11$in$i = $28;
    break;
   } else {
    $19 = (($0) + 1)|0;
    $20 = (($4) + ($19<<2)|0);
    $21 = HEAP16[$20>>1]|0;
    $22 = $21 << 16 >> 16;
    $23 = (($22) - ($17))|0;
    $24 = (($10) - ($22))|0;
    $$pn$in$i = $24;$$pn11$in$i = $23;
    break;
   }
  } else {
   $30 = (($0) + 1)|0;
   $31 = (($4) + ($30<<2)|0);
   $32 = HEAP16[$31>>1]|0;
   $33 = $32 << 16 >> 16;
   $34 = (($this) + 20|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + ($0))|0;
   $37 = (($4) + ($36<<2)|0);
   $38 = HEAP16[$37>>1]|0;
   $39 = $38 << 16 >> 16;
   $40 = Math_fround($1 + $2);
   $41 = !($40 <= Math_fround(1.0));
   if ($41) {
    $47 = (($36) + 1)|0;
    $48 = (($4) + ($47<<2)|0);
    $49 = HEAP16[$48>>1]|0;
    $50 = $49 << 16 >> 16;
    $51 = (($33) - ($50))|0;
    $52 = (($39) - ($50))|0;
    $$pn$in$i = $52;$$pn11$in$i = $51;
    break;
   } else {
    $42 = (($4) + ($0<<2)|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = $43 << 16 >> 16;
    $45 = (($44) - ($39))|0;
    $46 = (($44) - ($33))|0;
    $$pn$in$i = $46;$$pn11$in$i = $45;
    break;
   }
  }
 } while(0);
 $$pn11$i = (Math_fround(($$pn11$in$i|0)));
 $$pn$i = (Math_fround(($$pn$in$i|0)));
 $53 = Math_fround($$pn11$i * $xcoeff);
 $54 = Math_fround($$pn$i * $zcoeff);
 $55 = (($this) + 40|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = !($56 <= Math_fround(0.0));
 if ($57) {
  $60 = Math_fround(-$53);
  $61 = Math_fround(-$ycoeff);
  $62 = Math_fround(-$54);
  HEAPF32[$agg$result>>2] = $60;
  $63 = (($agg$result) + 4|0);
  HEAPF32[$63>>2] = $61;
  $64 = (($agg$result) + 8|0);
  HEAPF32[$64>>2] = $62;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$agg$result>>2] = $53;
  $58 = (($agg$result) + 4|0);
  HEAPF32[$58>>2] = $ycoeff;
  $59 = (($agg$result) + 8|0);
  HEAPF32[$59>>2] = $54;
  STACKTOP = sp;return;
 }
}
function __ZN5physx21PxcContactCapsuleMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18contactCapsuleMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx19PxcContactBoxConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $boxBounds = 0, $convexBounds = 0, $convexScaling = 0, $idtScaling = 0, $polyBox = 0, $polyData0 = 0, $polyData1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $idtScaling = sp + 488|0;
 $boxBounds = sp;
 $polyData0 = sp + 24|0;
 $polyBox = sp + 96|0;
 $convexScaling = sp + 320|0;
 $convexBounds = sp + 392|0;
 $polyData1 = sp + 416|0;
 HEAPF32[$idtScaling>>2] = Math_fround(1.0);
 $0 = (($idtScaling) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($idtScaling) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($idtScaling) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($idtScaling) + 16|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($idtScaling) + 20|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($idtScaling) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($idtScaling) + 28|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($idtScaling) + 32|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($idtScaling) + 36|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($idtScaling) + 40|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($idtScaling) + 44|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($idtScaling) + 48|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($idtScaling) + 52|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($idtScaling) + 56|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($idtScaling) + 60|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($idtScaling) + 64|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($idtScaling) + 68|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($shape0) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(-$18);
 $20 = (($shape0) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(-$21);
 $23 = (($shape0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(-$24);
 HEAPF32[$boxBounds>>2] = $19;
 $26 = (($boxBounds) + 4|0);
 HEAPF32[$26>>2] = $22;
 $27 = (($boxBounds) + 8|0);
 HEAPF32[$27>>2] = $25;
 $28 = (($boxBounds) + 12|0);
 HEAPF32[$28>>2] = $18;
 $29 = (($boxBounds) + 16|0);
 HEAPF32[$29>>2] = $21;
 $30 = (($boxBounds) + 20|0);
 HEAPF32[$30>>2] = $24;
 __ZN5physx2Gu12PolygonalBoxC2ERKNS_6PxVec3E($polyBox,$17);
 __ZNK5physx2Gu12PolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($polyBox,$polyData0);
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $31 = (($convexScaling) + 4|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($convexScaling) + 8|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($convexScaling) + 12|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($convexScaling) + 16|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (($convexScaling) + 20|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($convexScaling) + 24|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($convexScaling) + 28|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($convexScaling) + 32|0);
 HEAPF32[$38>>2] = Math_fround(1.0);
 $39 = (($convexScaling) + 36|0);
 HEAPF32[$39>>2] = Math_fround(1.0);
 $40 = (($convexScaling) + 40|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($convexScaling) + 44|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($convexScaling) + 48|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($convexScaling) + 52|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 $44 = (($convexScaling) + 56|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($convexScaling) + 60|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($convexScaling) + 64|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($convexScaling) + 68|0);
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (__ZN5physx2Gu13getConvexDataERKNS0_13GeometryUnionERNS_2Cm23FastVertex2ShapeScalingERNS_9PxBounds3ERNS0_13PolygonalDataE($shape1,$convexScaling,$convexBounds,$polyData1)|0);
 $49 = Math_fround(HEAPF32[$contactDistance>>2]);
 $50 = (__ZL18PxcContactHullHullRKN5physx2Gu13PolygonalDataES3_RKNS_9PxBounds3ES6_RKNS_11PxTransformES9_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESF_bb($polyData0,$polyData1,$boxBounds,$convexBounds,$transform0,$transform1,$49,$contactBuffer,$idtScaling,$convexScaling,1,$48)|0);
 STACKTOP = sp;return ($50|0);
}
function __ZL18PxcContactHullHullRKN5physx2Gu13PolygonalDataES3_RKNS_9PxBounds3ES6_RKNS_11PxTransformES9_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESF_bb($polyData0,$polyData1,$hullBounds0,$hullBounds1,$transform0,$transform1,$contactDistance,$contactBuffer,$scaling0,$scaling1,$idtScale0,$idtScale1) {
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $hullBounds0 = $hullBounds0|0;
 $hullBounds1 = $hullBounds1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = Math_fround($contactDistance);
 $contactBuffer = $contactBuffer|0;
 $scaling0 = $scaling0|0;
 $scaling1 = $scaling1|0;
 $idtScale0 = $idtScale0|0;
 $idtScale1 = $idtScale1|0;
 var $$0 = 0, $$0$ = 0, $$01 = 0, $$1 = 0, $$3 = 0, $$pre = Math_fround(0), $$pre40 = Math_fround(0), $$pre41 = Math_fround(0), $$pre42 = 0, $$pre43 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0);
 var $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = Math_fround(0), $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0);
 var $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = Math_fround(0), $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = Math_fround(0);
 var $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = 0;
 var $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0), $1078 = Math_fround(0);
 var $1079 = Math_fround(0), $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = Math_fround(0), $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0);
 var $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0);
 var $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0), $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0);
 var $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = Math_fround(0), $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = Math_fround(0);
 var $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = Math_fround(0), $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0;
 var $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = Math_fround(0), $1180 = 0, $1181 = 0, $1182 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0);
 var $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0);
 var $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0);
 var $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0);
 var $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0);
 var $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0;
 var $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = 0;
 var $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0), $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0);
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = 0;
 var $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0);
 var $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0);
 var $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0);
 var $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = 0, $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = 0, $572 = Math_fround(0);
 var $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = 0, $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = Math_fround(0);
 var $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0);
 var $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0);
 var $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0);
 var $645 = Math_fround(0), $646 = 0, $647 = 0, $648 = 0, $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0);
 var $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = 0, $674 = 0, $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0);
 var $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = Math_fround(0), $708 = Math_fround(0), $709 = 0, $71 = Math_fround(0), $710 = Math_fround(0), $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0;
 var $717 = 0, $718 = Math_fround(0), $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0);
 var $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = 0, $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = 0, $752 = Math_fround(0);
 var $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = 0, $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0);
 var $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0);
 var $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0);
 var $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = Math_fround(0), $819 = Math_fround(0), $82 = Math_fround(0), $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0);
 var $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0);
 var $843 = Math_fround(0), $844 = Math_fround(0), $845 = 0, $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0, $850 = Math_fround(0), $851 = 0, $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = 0, $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0);
 var $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = 0, $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0);
 var $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0);
 var $898 = Math_fround(0), $899 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0);
 var $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = 0, $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0);
 var $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = Math_fround(0), $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = 0, $950 = Math_fround(0);
 var $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = Math_fround(0), $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0);
 var $97 = 0, $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = Math_fround(0), $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0);
 var $988 = Math_fround(0), $989 = Math_fround(0), $99 = Math_fround(0), $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $TryRoughPass$0$off0 = 0, $TryRoughPass$1$off0 = 0, $c0$0 = 0, $c0$1 = 0, $c1$0 = 0, $c1$1 = 0, $code = 0;
 var $contactGenPositionShiftVec = 0, $deltaC = 0, $depth = 0, $dmin$0$i = Math_fround(0), $dmin0$i = 0, $dmin1$i = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i5 = Math_fround(0), $id0 = 0, $id1 = 0, $m0to1 = 0, $m1to0 = 0, $max0$i = 0, $max1$i$i = 0, $min0$i = 0, $min1$i$i = 0, $scaledVertices0 = 0, $scaledVertices1 = 0, $shapeSpacePlane0 = 0, $shapeSpacePlane1 = 0;
 var $stackIndices0 = 0, $stackIndices1 = 0, $storemerge = Math_fround(0), $storemerge45 = Math_fround(0), $storemerge46 = Math_fround(0), $storemerge47 = Math_fround(0), $storemerge48 = Math_fround(0), $storemerge49 = Math_fround(0), $vec0$i = 0, $vec1$i = 0, $world0 = 0, $world1 = 0, $worldNormal = 0, $worldNormal0 = 0, $worldNormal1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $dmin0$i = sp + 560|0;
 $dmin1$i = sp + 512|0;
 $vec0$i = sp + 464|0;
 $vec1$i = sp + 428|0;
 $0 = sp + 392|0;
 $min1$i$i = sp + 388|0;
 $max1$i$i = sp + 384|0;
 $min0$i = sp + 380|0;
 $max0$i = sp + 376|0;
 $world0 = sp + 328|0;
 $world1 = sp + 280|0;
 $deltaC = sp + 264|0;
 $depth = sp + 260|0;
 $worldNormal = sp + 248|0;
 $m0to1 = sp + 200|0;
 $m1to0 = sp + 152|0;
 $code = sp + 148|0;
 $id0 = sp + 64|0;
 $id1 = sp;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 40|0;
 $worldNormal0 = sp + 52|0;
 $shapeSpacePlane0 = sp + 72|0;
 $worldNormal1 = sp + 88|0;
 $shapeSpacePlane1 = sp + 104|0;
 $contactGenPositionShiftVec = sp + 120|0;
 $scaledVertices0 = sp + 132|0;
 $stackIndices0 = sp + 136|0;
 $scaledVertices1 = sp + 140|0;
 $stackIndices1 = sp + 144|0;
 $5 = Math_fround(HEAPF32[$transform0>>2]);
 $6 = Math_fround($5 + $5);
 $7 = (($transform0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 + $8);
 $10 = (($transform0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 + $11);
 $13 = (($transform0) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($6 * $14);
 $16 = Math_fround($9 * $14);
 $17 = Math_fround($14 * $12);
 $18 = Math_fround($5 * $6);
 $19 = Math_fround($5 * $9);
 $20 = Math_fround($5 * $12);
 $21 = Math_fround($8 * $9);
 $22 = Math_fround($8 * $12);
 $23 = Math_fround($11 * $12);
 $24 = Math_fround(Math_fround(1.0) - $21);
 $25 = Math_fround($24 - $23);
 HEAPF32[$world0>>2] = $25;
 $26 = Math_fround($19 + $17);
 $27 = (($world0) + 4|0);
 HEAPF32[$27>>2] = $26;
 $28 = Math_fround($20 - $16);
 $29 = (($world0) + 8|0);
 HEAPF32[$29>>2] = $28;
 $30 = Math_fround($19 - $17);
 $31 = (($world0) + 12|0);
 HEAPF32[$31>>2] = $30;
 $32 = Math_fround(Math_fround(1.0) - $18);
 $33 = Math_fround($32 - $23);
 $34 = (($world0) + 16|0);
 HEAPF32[$34>>2] = $33;
 $35 = Math_fround($22 + $15);
 $36 = (($world0) + 20|0);
 HEAPF32[$36>>2] = $35;
 $37 = Math_fround($20 + $16);
 $38 = (($world0) + 24|0);
 HEAPF32[$38>>2] = $37;
 $39 = Math_fround($22 - $15);
 $40 = (($world0) + 28|0);
 HEAPF32[$40>>2] = $39;
 $41 = Math_fround($32 - $21);
 $42 = (($world0) + 32|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($world0) + 36|0);
 $44 = (($world0) + 40|0);
 $45 = (($world0) + 44|0);
 $46 = (($transform0) + 16|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$43>>2] = $47;
 $48 = (($transform0) + 20|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$44>>2] = $49;
 $50 = (($transform0) + 24|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$45>>2] = $51;
 $52 = Math_fround(HEAPF32[$transform1>>2]);
 $53 = Math_fround($52 + $52);
 $54 = (($transform1) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 + $55);
 $57 = (($transform1) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 + $58);
 $60 = (($transform1) + 12|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($53 * $61);
 $63 = Math_fround($56 * $61);
 $64 = Math_fround($61 * $59);
 $65 = Math_fround($52 * $53);
 $66 = Math_fround($52 * $56);
 $67 = Math_fround($52 * $59);
 $68 = Math_fround($55 * $56);
 $69 = Math_fround($55 * $59);
 $70 = Math_fround($58 * $59);
 $71 = Math_fround(Math_fround(1.0) - $68);
 $72 = Math_fround($71 - $70);
 HEAPF32[$world1>>2] = $72;
 $73 = Math_fround($66 + $64);
 $74 = (($world1) + 4|0);
 HEAPF32[$74>>2] = $73;
 $75 = Math_fround($67 - $63);
 $76 = (($world1) + 8|0);
 HEAPF32[$76>>2] = $75;
 $77 = Math_fround($66 - $64);
 $78 = (($world1) + 12|0);
 HEAPF32[$78>>2] = $77;
 $79 = Math_fround(Math_fround(1.0) - $65);
 $80 = Math_fround($79 - $70);
 $81 = (($world1) + 16|0);
 HEAPF32[$81>>2] = $80;
 $82 = Math_fround($69 + $62);
 $83 = (($world1) + 20|0);
 HEAPF32[$83>>2] = $82;
 $84 = Math_fround($67 + $63);
 $85 = (($world1) + 24|0);
 HEAPF32[$85>>2] = $84;
 $86 = Math_fround($69 - $62);
 $87 = (($world1) + 28|0);
 HEAPF32[$87>>2] = $86;
 $88 = Math_fround($79 - $68);
 $89 = (($world1) + 32|0);
 HEAPF32[$89>>2] = $88;
 $90 = (($world1) + 36|0);
 $91 = (($world1) + 40|0);
 $92 = (($world1) + 44|0);
 $93 = (($transform1) + 16|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 HEAPF32[$90>>2] = $94;
 $95 = (($transform1) + 20|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 HEAPF32[$91>>2] = $96;
 $97 = (($transform1) + 24|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 HEAPF32[$92>>2] = $98;
 $99 = Math_fround(HEAPF32[$polyData0>>2]);
 $100 = Math_fround(HEAPF32[$world0>>2]);
 $101 = Math_fround($99 * $100);
 $102 = Math_fround(HEAPF32[$27>>2]);
 $103 = Math_fround($99 * $102);
 $104 = Math_fround(HEAPF32[$29>>2]);
 $105 = Math_fround($99 * $104);
 $106 = (($polyData0) + 4|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround(HEAPF32[$31>>2]);
 $109 = Math_fround($107 * $108);
 $110 = Math_fround(HEAPF32[$34>>2]);
 $111 = Math_fround($107 * $110);
 $112 = Math_fround(HEAPF32[$36>>2]);
 $113 = Math_fround($107 * $112);
 $114 = Math_fround($101 + $109);
 $115 = Math_fround($103 + $111);
 $116 = Math_fround($105 + $113);
 $117 = (($polyData0) + 8|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = Math_fround(HEAPF32[$38>>2]);
 $120 = Math_fround($118 * $119);
 $121 = Math_fround(HEAPF32[$40>>2]);
 $122 = Math_fround($118 * $121);
 $123 = Math_fround(HEAPF32[$42>>2]);
 $124 = Math_fround($118 * $123);
 $125 = Math_fround($114 + $120);
 $126 = Math_fround($115 + $122);
 $127 = Math_fround($116 + $124);
 $128 = Math_fround(HEAPF32[$43>>2]);
 $129 = Math_fround($125 + $128);
 $130 = Math_fround(HEAPF32[$44>>2]);
 $131 = Math_fround($126 + $130);
 $132 = Math_fround(HEAPF32[$45>>2]);
 $133 = Math_fround($127 + $132);
 $134 = Math_fround(HEAPF32[$polyData1>>2]);
 $135 = Math_fround($134 * $72);
 $136 = Math_fround($134 * $73);
 $137 = Math_fround($134 * $75);
 $138 = (($polyData1) + 4|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($139 * $77);
 $141 = Math_fround($139 * $80);
 $142 = Math_fround($139 * $82);
 $143 = Math_fround($135 + $140);
 $144 = Math_fround($136 + $141);
 $145 = Math_fround($137 + $142);
 $146 = (($polyData1) + 8|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = Math_fround($147 * $84);
 $149 = Math_fround($147 * $86);
 $150 = Math_fround($147 * $88);
 $151 = Math_fround($143 + $148);
 $152 = Math_fround($144 + $149);
 $153 = Math_fround($145 + $150);
 $154 = Math_fround($151 + $94);
 $155 = Math_fround($152 + $96);
 $156 = Math_fround($98 + $153);
 $157 = Math_fround($154 - $129);
 $158 = Math_fround($155 - $131);
 $159 = Math_fround($156 - $133);
 HEAPF32[$deltaC>>2] = $157;
 $160 = (($deltaC) + 4|0);
 HEAPF32[$160>>2] = $158;
 $161 = (($deltaC) + 8|0);
 HEAPF32[$161>>2] = $159;
 $162 = (($polyData0) + 60|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = ($163|0)==(0|0);
 if (!($164)) {
  $165 = (($polyData0) + 12|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = (($polyData0) + 28|0);
  $168 = HEAP32[$167>>2]|0;
  FUNCTION_TABLE_vii[$163 & 4095]($166,$168);
 }
 $169 = (($polyData1) + 60|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = ($170|0)==(0|0);
 if (!($171)) {
  $172 = (($polyData1) + 12|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = (($polyData1) + 28|0);
  $175 = HEAP32[$174>>2]|0;
  FUNCTION_TABLE_vii[$170 & 4095]($173,$175);
 }
 $176 = (($polyData0) + 64|0);
 $177 = HEAP32[$176>>2]|0;
 FUNCTION_TABLE_viiiiii[$177 & 255]($polyData0,$deltaC,$world0,$scaling0,$min0$i,$max0$i);
 $178 = Math_fround(HEAPF32[$min0$i>>2]);
 $179 = Math_fround(HEAPF32[$max0$i>>2]);
 $180 = (($polyData1) + 64|0);
 $181 = HEAP32[$180>>2]|0;
 FUNCTION_TABLE_viiiiii[$181 & 255]($polyData1,$deltaC,$world1,$scaling1,$min1$i$i,$max1$i$i);
 $182 = Math_fround($179 + $contactDistance);
 $183 = Math_fround(HEAPF32[$min1$i$i>>2]);
 $184 = $182 < $183;
 if ($184) {
  $$3 = 0;
  STACKTOP = sp;return ($$3|0);
 }
 $185 = Math_fround(HEAPF32[$max1$i$i>>2]);
 $186 = Math_fround($185 + $contactDistance);
 $187 = $186 < $178;
 if ($187) {
  $$3 = 0;
  STACKTOP = sp;return ($$3|0);
 }
 $188 = Math_fround($179 - $183);
 $189 = Math_fround($185 - $178);
 $190 = $188 < $189;
 $191 = $190 ? $188 : $189;
 HEAPF32[$depth>>2] = $191;
 $192 = Math_fround(HEAPF32[$transform1>>2]);
 $193 = Math_fround(-$192);
 $194 = Math_fround(HEAPF32[$54>>2]);
 $195 = Math_fround(-$194);
 $196 = Math_fround(HEAPF32[$57>>2]);
 $197 = Math_fround(-$196);
 $198 = Math_fround(HEAPF32[$60>>2]);
 $199 = Math_fround(HEAPF32[$46>>2]);
 $200 = Math_fround(HEAPF32[$93>>2]);
 $201 = Math_fround($199 - $200);
 $202 = Math_fround(HEAPF32[$48>>2]);
 $203 = Math_fround(HEAPF32[$95>>2]);
 $204 = Math_fround($202 - $203);
 $205 = Math_fround(HEAPF32[$50>>2]);
 $206 = Math_fround(HEAPF32[$97>>2]);
 $207 = Math_fround($205 - $206);
 $208 = Math_fround($201 * Math_fround(2.0));
 $209 = Math_fround($204 * Math_fround(2.0));
 $210 = Math_fround($207 * Math_fround(2.0));
 $211 = Math_fround($198 * $198);
 $212 = Math_fround($211 + Math_fround(-0.5));
 $213 = Math_fround($208 * $193);
 $214 = Math_fround($209 * $195);
 $215 = Math_fround($213 + $214);
 $216 = Math_fround($210 * $197);
 $217 = Math_fround($215 + $216);
 $218 = Math_fround($212 * $208);
 $219 = Math_fround($210 * $195);
 $220 = Math_fround($209 * $197);
 $221 = Math_fround($219 - $220);
 $222 = Math_fround($198 * $221);
 $223 = Math_fround($218 + $222);
 $224 = Math_fround($217 * $193);
 $225 = Math_fround($224 + $223);
 $226 = Math_fround($212 * $209);
 $227 = Math_fround($208 * $197);
 $228 = Math_fround($210 * $193);
 $229 = Math_fround($227 - $228);
 $230 = Math_fround($198 * $229);
 $231 = Math_fround($226 + $230);
 $232 = Math_fround($217 * $195);
 $233 = Math_fround($232 + $231);
 $234 = Math_fround($212 * $210);
 $235 = Math_fround($209 * $193);
 $236 = Math_fround($208 * $195);
 $237 = Math_fround($235 - $236);
 $238 = Math_fround($198 * $237);
 $239 = Math_fround($234 + $238);
 $240 = Math_fround($217 * $197);
 $241 = Math_fround($239 + $240);
 $242 = Math_fround(HEAPF32[$transform0>>2]);
 $243 = Math_fround($198 * $242);
 $244 = Math_fround(HEAPF32[$13>>2]);
 $245 = Math_fround($244 * $193);
 $246 = Math_fround($243 + $245);
 $247 = Math_fround(HEAPF32[$10>>2]);
 $248 = Math_fround($247 * $195);
 $249 = Math_fround($246 + $248);
 $250 = Math_fround(HEAPF32[$7>>2]);
 $251 = Math_fround($250 * $197);
 $252 = Math_fround($249 - $251);
 $253 = Math_fround($198 * $250);
 $254 = Math_fround($244 * $195);
 $255 = Math_fround($254 + $253);
 $256 = Math_fround($242 * $197);
 $257 = Math_fround($256 + $255);
 $258 = Math_fround($247 * $193);
 $259 = Math_fround($257 - $258);
 $260 = Math_fround($198 * $247);
 $261 = Math_fround($244 * $197);
 $262 = Math_fround($261 + $260);
 $263 = Math_fround($250 * $193);
 $264 = Math_fround($263 + $262);
 $265 = Math_fround($242 * $195);
 $266 = Math_fround($264 - $265);
 $267 = Math_fround($198 * $244);
 $268 = Math_fround($242 * $193);
 $269 = Math_fround($267 - $268);
 $270 = Math_fround($250 * $195);
 $271 = Math_fround($269 - $270);
 $272 = Math_fround($247 * $197);
 $273 = Math_fround($271 - $272);
 $274 = Math_fround(-$242);
 $275 = Math_fround(-$250);
 $276 = Math_fround(-$247);
 $277 = Math_fround($200 - $199);
 $278 = Math_fround($203 - $202);
 $279 = Math_fround($206 - $205);
 $280 = Math_fround($277 * Math_fround(2.0));
 $281 = Math_fround($278 * Math_fround(2.0));
 $282 = Math_fround($279 * Math_fround(2.0));
 $283 = Math_fround($244 * $244);
 $284 = Math_fround($283 + Math_fround(-0.5));
 $285 = Math_fround($280 * $274);
 $286 = Math_fround($281 * $275);
 $287 = Math_fround($285 + $286);
 $288 = Math_fround($282 * $276);
 $289 = Math_fround($288 + $287);
 $290 = Math_fround($280 * $284);
 $291 = Math_fround($282 * $275);
 $292 = Math_fround($281 * $276);
 $293 = Math_fround($291 - $292);
 $294 = Math_fround($244 * $293);
 $295 = Math_fround($290 + $294);
 $296 = Math_fround($289 * $274);
 $297 = Math_fround($296 + $295);
 $298 = Math_fround($281 * $284);
 $299 = Math_fround($280 * $276);
 $300 = Math_fround($282 * $274);
 $301 = Math_fround($299 - $300);
 $302 = Math_fround($244 * $301);
 $303 = Math_fround($298 + $302);
 $304 = Math_fround($289 * $275);
 $305 = Math_fround($303 + $304);
 $306 = Math_fround($282 * $284);
 $307 = Math_fround($281 * $274);
 $308 = Math_fround($280 * $275);
 $309 = Math_fround($307 - $308);
 $310 = Math_fround($244 * $309);
 $311 = Math_fround($306 + $310);
 $312 = Math_fround($289 * $276);
 $313 = Math_fround($311 + $312);
 $314 = Math_fround($192 * $244);
 $315 = Math_fround($198 * $274);
 $316 = Math_fround($314 + $315);
 $317 = Math_fround($196 * $275);
 $318 = Math_fround($316 + $317);
 $319 = Math_fround($194 * $276);
 $320 = Math_fround($318 - $319);
 $321 = Math_fround($194 * $244);
 $322 = Math_fround($198 * $275);
 $323 = Math_fround($321 + $322);
 $324 = Math_fround($192 * $276);
 $325 = Math_fround($324 + $323);
 $326 = Math_fround($196 * $274);
 $327 = Math_fround($325 - $326);
 $328 = Math_fround($196 * $244);
 $329 = Math_fround($198 * $276);
 $330 = Math_fround($328 + $329);
 $331 = Math_fround($194 * $274);
 $332 = Math_fround($331 + $330);
 $333 = Math_fround($192 * $275);
 $334 = Math_fround($332 - $333);
 $335 = Math_fround($192 * $274);
 $336 = Math_fround($267 - $335);
 $337 = Math_fround($194 * $275);
 $338 = Math_fround($336 - $337);
 $339 = Math_fround($196 * $276);
 $340 = Math_fround($338 - $339);
 $341 = Math_fround($252 + $252);
 $342 = Math_fround($259 + $259);
 $343 = Math_fround($266 + $266);
 $344 = Math_fround($341 * $273);
 $345 = Math_fround($273 * $342);
 $346 = Math_fround($273 * $343);
 $347 = Math_fround($252 * $341);
 $348 = Math_fround($252 * $342);
 $349 = Math_fround($252 * $343);
 $350 = Math_fround($259 * $342);
 $351 = Math_fround($259 * $343);
 $352 = Math_fround($266 * $343);
 $353 = Math_fround(Math_fround(1.0) - $350);
 $354 = Math_fround($353 - $352);
 HEAPF32[$m0to1>>2] = $354;
 $355 = Math_fround($346 + $348);
 $356 = (($m0to1) + 4|0);
 HEAPF32[$356>>2] = $355;
 $357 = Math_fround($349 - $345);
 $358 = (($m0to1) + 8|0);
 HEAPF32[$358>>2] = $357;
 $359 = Math_fround($348 - $346);
 $360 = (($m0to1) + 12|0);
 HEAPF32[$360>>2] = $359;
 $361 = Math_fround(Math_fround(1.0) - $347);
 $362 = Math_fround($361 - $352);
 $363 = (($m0to1) + 16|0);
 HEAPF32[$363>>2] = $362;
 $364 = Math_fround($344 + $351);
 $365 = (($m0to1) + 20|0);
 HEAPF32[$365>>2] = $364;
 $366 = Math_fround($349 + $345);
 $367 = (($m0to1) + 24|0);
 HEAPF32[$367>>2] = $366;
 $368 = Math_fround($351 - $344);
 $369 = (($m0to1) + 28|0);
 HEAPF32[$369>>2] = $368;
 $370 = Math_fround($361 - $350);
 $371 = (($m0to1) + 32|0);
 HEAPF32[$371>>2] = $370;
 $372 = (($m0to1) + 36|0);
 $373 = (($m0to1) + 40|0);
 $374 = (($m0to1) + 44|0);
 HEAPF32[$372>>2] = $225;
 HEAPF32[$373>>2] = $233;
 HEAPF32[$374>>2] = $241;
 $375 = Math_fround($320 + $320);
 $376 = Math_fround($327 + $327);
 $377 = Math_fround($334 + $334);
 $378 = Math_fround($340 * $375);
 $379 = Math_fround($340 * $376);
 $380 = Math_fround($340 * $377);
 $381 = Math_fround($320 * $375);
 $382 = Math_fround($320 * $376);
 $383 = Math_fround($320 * $377);
 $384 = Math_fround($327 * $376);
 $385 = Math_fround($327 * $377);
 $386 = Math_fround($334 * $377);
 $387 = Math_fround(Math_fround(1.0) - $384);
 $388 = Math_fround($387 - $386);
 HEAPF32[$m1to0>>2] = $388;
 $389 = Math_fround($380 + $382);
 $390 = (($m1to0) + 4|0);
 HEAPF32[$390>>2] = $389;
 $391 = Math_fround($383 - $379);
 $392 = (($m1to0) + 8|0);
 HEAPF32[$392>>2] = $391;
 $393 = Math_fround($382 - $380);
 $394 = (($m1to0) + 12|0);
 HEAPF32[$394>>2] = $393;
 $395 = Math_fround(Math_fround(1.0) - $381);
 $396 = Math_fround($395 - $386);
 $397 = (($m1to0) + 16|0);
 HEAPF32[$397>>2] = $396;
 $398 = Math_fround($385 + $378);
 $399 = (($m1to0) + 20|0);
 HEAPF32[$399>>2] = $398;
 $400 = Math_fround($383 + $379);
 $401 = (($m1to0) + 24|0);
 HEAPF32[$401>>2] = $400;
 $402 = Math_fround($385 - $378);
 $403 = (($m1to0) + 28|0);
 HEAPF32[$403>>2] = $402;
 $404 = Math_fround($395 - $384);
 $405 = (($m1to0) + 32|0);
 HEAPF32[$405>>2] = $404;
 $406 = (($m1to0) + 36|0);
 $407 = (($m1to0) + 40|0);
 $408 = (($m1to0) + 44|0);
 HEAPF32[$406>>2] = $297;
 HEAPF32[$407>>2] = $305;
 HEAPF32[$408>>2] = $313;
 $409 = (($0) + 4|0);
 $410 = (($0) + 8|0);
 $411 = (($vec0$i) + 4|0);
 $412 = (($vec0$i) + 8|0);
 $413 = (($vec1$i) + 4|0);
 $414 = (($vec1$i) + 8|0);
 $415 = (($worldNormal) + 4|0);
 $416 = (($worldNormal) + 8|0);
 $417 = (($polyData0) + 24|0);
 $418 = (($polyData1) + 24|0);
 $419 = (($shapeSpacePlane0) + 4|0);
 $420 = (($shapeSpacePlane0) + 8|0);
 $421 = (($shapeSpacePlane0) + 12|0);
 $422 = (($worldNormal0) + 4|0);
 $423 = (($worldNormal0) + 8|0);
 $424 = (($shapeSpacePlane1) + 4|0);
 $425 = (($shapeSpacePlane1) + 8|0);
 $426 = (($shapeSpacePlane1) + 12|0);
 $427 = (($worldNormal1) + 4|0);
 $428 = (($worldNormal1) + 8|0);
 $429 = (($contactBuffer) + 4100|0);
 $430 = (($contactGenPositionShiftVec) + 4|0);
 $431 = (($contactGenPositionShiftVec) + 8|0);
 $432 = (($dmin0$i) + 4|0);
 $433 = (($dmin0$i) + 8|0);
 $434 = (($dmin0$i) + 12|0);
 $435 = (($dmin0$i) + 16|0);
 $436 = (($dmin0$i) + 20|0);
 $437 = (($dmin0$i) + 24|0);
 $438 = (($dmin0$i) + 28|0);
 $439 = (($dmin0$i) + 32|0);
 $440 = (($dmin0$i) + 36|0);
 $441 = (($dmin0$i) + 40|0);
 $442 = (($dmin0$i) + 44|0);
 $443 = (($dmin1$i) + 4|0);
 $444 = (($dmin1$i) + 8|0);
 $445 = (($dmin1$i) + 12|0);
 $446 = (($dmin1$i) + 16|0);
 $447 = (($dmin1$i) + 20|0);
 $448 = (($dmin1$i) + 24|0);
 $449 = (($dmin1$i) + 28|0);
 $450 = (($dmin1$i) + 32|0);
 $451 = (($dmin1$i) + 36|0);
 $452 = (($dmin1$i) + 40|0);
 $453 = (($dmin1$i) + 44|0);
 $454 = (($vec0$i) + 4|0);
 $455 = (($vec0$i) + 8|0);
 $456 = (($vec0$i) + 12|0);
 $457 = (($vec0$i) + 16|0);
 $458 = (($vec0$i) + 20|0);
 $459 = (($vec0$i) + 24|0);
 $460 = (($vec0$i) + 28|0);
 $461 = (($vec0$i) + 32|0);
 $462 = (($vec0$i) + 36|0);
 $463 = (($vec0$i) + 40|0);
 $464 = (($vec0$i) + 44|0);
 $465 = (($polyData0) + 28|0);
 $466 = (($polyData0) + 32|0);
 $467 = (($polyData1) + 28|0);
 $468 = (($polyData1) + 32|0);
 $469 = (($scaling1) + 36|0);
 $470 = (($scaling1) + 40|0);
 $471 = (($scaling1) + 44|0);
 $472 = (($scaling1) + 48|0);
 $473 = (($scaling1) + 52|0);
 $474 = (($scaling1) + 56|0);
 $475 = (($scaling1) + 60|0);
 $476 = (($scaling1) + 64|0);
 $477 = (($scaling1) + 68|0);
 $478 = (($scaling0) + 36|0);
 $479 = (($scaling0) + 40|0);
 $480 = (($scaling0) + 44|0);
 $481 = (($scaling0) + 48|0);
 $482 = (($scaling0) + 52|0);
 $483 = (($scaling0) + 56|0);
 $484 = (($scaling0) + 60|0);
 $485 = (($scaling0) + 64|0);
 $486 = (($scaling0) + 68|0);
 $487 = (($polyData1) + 68|0);
 $488 = (($1) + 4|0);
 $489 = (($1) + 8|0);
 $490 = (($polyData0) + 68|0);
 $491 = (($2) + 4|0);
 $492 = (($2) + 8|0);
 $493 = (($3) + 4|0);
 $494 = (($3) + 8|0);
 $495 = (($4) + 4|0);
 $496 = (($4) + 8|0);
 $$0 = 0;$TryRoughPass$0$off0 = 1;$c0$0 = 32767;$c1$0 = 32767;
 while(1) {
  if ($TryRoughPass$0$off0) {
   HEAPF32[$dmin0$i>>2] = Math_fround(3.40282346638528859812E+38);
   HEAPF32[$dmin1$i>>2] = Math_fround(3.40282346638528859812E+38);
   $497 = Math_fround(HEAPF32[$world0>>2]);
   $498 = Math_fround(HEAPF32[$deltaC>>2]);
   $499 = Math_fround($497 * $498);
   $500 = Math_fround(HEAPF32[$27>>2]);
   $501 = Math_fround(HEAPF32[$160>>2]);
   $502 = Math_fround($500 * $501);
   $503 = Math_fround($499 + $502);
   $504 = Math_fround(HEAPF32[$29>>2]);
   $505 = Math_fround(HEAPF32[$161>>2]);
   $506 = Math_fround($504 * $505);
   $507 = Math_fround($503 + $506);
   $508 = Math_fround(HEAPF32[$31>>2]);
   $509 = Math_fround($498 * $508);
   $510 = Math_fround(HEAPF32[$34>>2]);
   $511 = Math_fround($501 * $510);
   $512 = Math_fround($509 + $511);
   $513 = Math_fround(HEAPF32[$36>>2]);
   $514 = Math_fround($505 * $513);
   $515 = Math_fround($512 + $514);
   $516 = Math_fround(HEAPF32[$38>>2]);
   $517 = Math_fround($498 * $516);
   $518 = Math_fround(HEAPF32[$40>>2]);
   $519 = Math_fround($501 * $518);
   $520 = Math_fround($517 + $519);
   $521 = Math_fround(HEAPF32[$42>>2]);
   $522 = Math_fround($505 * $521);
   $523 = Math_fround($520 + $522);
   $524 = Math_fround(-$498);
   $525 = Math_fround(-$501);
   $526 = Math_fround(-$505);
   HEAPF32[$0>>2] = $524;
   HEAPF32[$409>>2] = $525;
   HEAPF32[$410>>2] = $526;
   $527 = (__ZL36PxcTestFacesSepAxesBackfaceRoughPassRKN5physx2Gu13PolygonalDataES3_RKNS_2Cm8Matrix34ES7_RKNS4_23FastVertex2ShapeScalingESA_S7_RKNS_6PxVec3ESD_RfRSB_RjfSD_($polyData0,$polyData1,$world0,$world1,$scaling0,$scaling1,$m1to0,$507,$515,$523,$dmin0$i,$vec0$i,$id0,$contactDistance,$0)|0);
   if (!($527)) {
    $$3 = 0;
    label = 37;
    break;
   }
   $528 = Math_fround(HEAPF32[$world1>>2]);
   $529 = Math_fround(HEAPF32[$deltaC>>2]);
   $530 = Math_fround($528 * $529);
   $531 = Math_fround(HEAPF32[$74>>2]);
   $532 = Math_fround(HEAPF32[$160>>2]);
   $533 = Math_fround($531 * $532);
   $534 = Math_fround($530 + $533);
   $535 = Math_fround(HEAPF32[$76>>2]);
   $536 = Math_fround(HEAPF32[$161>>2]);
   $537 = Math_fround($535 * $536);
   $538 = Math_fround($534 + $537);
   $539 = Math_fround(HEAPF32[$78>>2]);
   $540 = Math_fround($529 * $539);
   $541 = Math_fround(HEAPF32[$81>>2]);
   $542 = Math_fround($532 * $541);
   $543 = Math_fround($540 + $542);
   $544 = Math_fround(HEAPF32[$83>>2]);
   $545 = Math_fround($536 * $544);
   $546 = Math_fround($543 + $545);
   $547 = Math_fround(HEAPF32[$85>>2]);
   $548 = Math_fround($529 * $547);
   $549 = Math_fround(HEAPF32[$87>>2]);
   $550 = Math_fround($532 * $549);
   $551 = Math_fround($548 + $550);
   $552 = Math_fround(HEAPF32[$89>>2]);
   $553 = Math_fround($536 * $552);
   $554 = Math_fround($551 + $553);
   $555 = Math_fround(-$538);
   $556 = Math_fround(-$546);
   $557 = Math_fround(-$554);
   $558 = (__ZL36PxcTestFacesSepAxesBackfaceRoughPassRKN5physx2Gu13PolygonalDataES3_RKNS_2Cm8Matrix34ES7_RKNS4_23FastVertex2ShapeScalingESA_S7_RKNS_6PxVec3ESD_RfRSB_RjfSD_($polyData1,$polyData0,$world1,$world0,$scaling1,$scaling0,$m0to1,$555,$556,$557,$dmin1$i,$vec1$i,$id1,$contactDistance,$deltaC)|0);
   if (!($558)) {
    $$3 = 0;
    label = 37;
    break;
   }
   $559 = Math_fround(HEAPF32[$dmin0$i>>2]);
   $560 = Math_fround(HEAPF32[$vec0$i>>2]);
   $561 = Math_fround(HEAPF32[$411>>2]);
   $562 = Math_fround(HEAPF32[$412>>2]);
   HEAP32[$code>>2] = 0;
   $563 = Math_fround(HEAPF32[$dmin1$i>>2]);
   $564 = $563 < $559;
   if ($564) {
    $565 = Math_fround(HEAPF32[$vec1$i>>2]);
    $566 = Math_fround(HEAPF32[$413>>2]);
    $567 = Math_fround(HEAPF32[$414>>2]);
    HEAP32[$code>>2] = 1;
    $568 = $565;$569 = $566;$570 = $567;$dmin$0$i = $563;
   } else {
    $568 = $560;$569 = $561;$570 = $562;$dmin$0$i = $559;
   }
   HEAPF32[$depth>>2] = $dmin$0$i;
   HEAPF32[$worldNormal>>2] = $568;
   HEAPF32[$415>>2] = $569;
   HEAPF32[$416>>2] = $570;
   $574 = $568;$577 = $569;$581 = $570;
  } else {
   $571 = (__ZL28PxcBruteForceOverlapBackfaceRKN5physx9PxBounds3ES2_RKNS_2Gu13PolygonalDataES6_RKNS_2Cm8Matrix34ESA_RKNS7_23FastVertex2ShapeScalingESD_SA_SA_RKNS_6PxVec3ERjSH_RfRSE_RNS3_14PxcSepAxisTypeEf($hullBounds0,$hullBounds1,$polyData0,$polyData1,$world0,$world1,$scaling0,$scaling1,$m0to1,$m1to0,$deltaC,$id0,$id1,$depth,$worldNormal,$code,$contactDistance)|0);
   if (!($571)) {
    $$3 = 0;
    label = 37;
    break;
   }
   $$pre = Math_fround(HEAPF32[$worldNormal>>2]);
   $$pre40 = Math_fround(HEAPF32[$415>>2]);
   $$pre41 = Math_fround(HEAPF32[$416>>2]);
   $574 = $$pre;$577 = $$pre40;$581 = $$pre41;
  }
  $572 = Math_fround(HEAPF32[$deltaC>>2]);
  $573 = Math_fround($572 * $574);
  $575 = Math_fround(HEAPF32[$160>>2]);
  $576 = Math_fround($575 * $577);
  $578 = Math_fround($573 + $576);
  $579 = Math_fround(HEAPF32[$161>>2]);
  $580 = Math_fround($579 * $581);
  $582 = Math_fround($578 + $580);
  $583 = $582 < Math_fround(0.0);
  if ($583) {
   $584 = Math_fround(-$574);
   $585 = Math_fround(-$577);
   $586 = Math_fround(-$581);
   HEAPF32[$worldNormal>>2] = $584;
   HEAPF32[$415>>2] = $585;
   HEAPF32[$416>>2] = $586;
   $591 = $584;$593 = $585;$595 = $586;
  } else {
   $591 = $574;$593 = $577;$595 = $581;
  }
  $587 = HEAP32[$code>>2]|0;
  if ((($587|0) == 0)) {
   $588 = HEAP32[$id0>>2]|0;
   $589 = HEAP32[$487>>2]|0;
   $590 = Math_fround(-$591);
   $592 = Math_fround(-$593);
   $594 = Math_fround(-$595);
   $596 = Math_fround(HEAPF32[$world1>>2]);
   $597 = Math_fround($596 * $590);
   $598 = Math_fround(HEAPF32[$74>>2]);
   $599 = Math_fround($598 * $592);
   $600 = Math_fround($597 + $599);
   $601 = Math_fround(HEAPF32[$76>>2]);
   $602 = Math_fround($601 * $594);
   $603 = Math_fround($600 + $602);
   $604 = Math_fround(HEAPF32[$78>>2]);
   $605 = Math_fround($604 * $590);
   $606 = Math_fround(HEAPF32[$81>>2]);
   $607 = Math_fround($606 * $592);
   $608 = Math_fround($605 + $607);
   $609 = Math_fround(HEAPF32[$83>>2]);
   $610 = Math_fround($609 * $594);
   $611 = Math_fround($608 + $610);
   $612 = Math_fround(HEAPF32[$85>>2]);
   $613 = Math_fround($612 * $590);
   $614 = Math_fround(HEAPF32[$87>>2]);
   $615 = Math_fround($614 * $592);
   $616 = Math_fround($613 + $615);
   $617 = Math_fround(HEAPF32[$89>>2]);
   $618 = Math_fround($617 * $594);
   $619 = Math_fround($616 + $618);
   HEAPF32[$1>>2] = $603;
   HEAPF32[$488>>2] = $611;
   HEAPF32[$489>>2] = $619;
   $620 = (FUNCTION_TABLE_iiii[$589 & 2047]($polyData1,$scaling1,$1)|0);
   $c0$1 = $588;$c1$1 = $620;
  } else if ((($587|0) == 1)) {
   $621 = HEAP32[$490>>2]|0;
   $622 = Math_fround(HEAPF32[$world0>>2]);
   $623 = Math_fround($622 * $591);
   $624 = Math_fround(HEAPF32[$27>>2]);
   $625 = Math_fround($624 * $593);
   $626 = Math_fround($623 + $625);
   $627 = Math_fround(HEAPF32[$29>>2]);
   $628 = Math_fround($627 * $595);
   $629 = Math_fround($626 + $628);
   $630 = Math_fround(HEAPF32[$31>>2]);
   $631 = Math_fround($591 * $630);
   $632 = Math_fround(HEAPF32[$34>>2]);
   $633 = Math_fround($593 * $632);
   $634 = Math_fround($631 + $633);
   $635 = Math_fround(HEAPF32[$36>>2]);
   $636 = Math_fround($595 * $635);
   $637 = Math_fround($634 + $636);
   $638 = Math_fround(HEAPF32[$38>>2]);
   $639 = Math_fround($591 * $638);
   $640 = Math_fround(HEAPF32[$40>>2]);
   $641 = Math_fround($593 * $640);
   $642 = Math_fround($639 + $641);
   $643 = Math_fround(HEAPF32[$42>>2]);
   $644 = Math_fround($595 * $643);
   $645 = Math_fround($642 + $644);
   HEAPF32[$2>>2] = $629;
   HEAPF32[$491>>2] = $637;
   HEAPF32[$492>>2] = $645;
   $646 = (FUNCTION_TABLE_iiii[$621 & 2047]($polyData0,$scaling0,$2)|0);
   $647 = HEAP32[$id1>>2]|0;
   $c0$1 = $646;$c1$1 = $647;
  } else if ((($587|0) == 2)) {
   $648 = HEAP32[$490>>2]|0;
   $649 = Math_fround(HEAPF32[$world0>>2]);
   $650 = Math_fround($649 * $591);
   $651 = Math_fround(HEAPF32[$27>>2]);
   $652 = Math_fround($651 * $593);
   $653 = Math_fround($650 + $652);
   $654 = Math_fround(HEAPF32[$29>>2]);
   $655 = Math_fround($654 * $595);
   $656 = Math_fround($653 + $655);
   $657 = Math_fround(HEAPF32[$31>>2]);
   $658 = Math_fround($591 * $657);
   $659 = Math_fround(HEAPF32[$34>>2]);
   $660 = Math_fround($593 * $659);
   $661 = Math_fround($658 + $660);
   $662 = Math_fround(HEAPF32[$36>>2]);
   $663 = Math_fround($595 * $662);
   $664 = Math_fround($661 + $663);
   $665 = Math_fround(HEAPF32[$38>>2]);
   $666 = Math_fround($591 * $665);
   $667 = Math_fround(HEAPF32[$40>>2]);
   $668 = Math_fround($593 * $667);
   $669 = Math_fround($666 + $668);
   $670 = Math_fround(HEAPF32[$42>>2]);
   $671 = Math_fround($595 * $670);
   $672 = Math_fround($669 + $671);
   HEAPF32[$3>>2] = $656;
   HEAPF32[$493>>2] = $664;
   HEAPF32[$494>>2] = $672;
   $673 = (FUNCTION_TABLE_iiii[$648 & 2047]($polyData0,$scaling0,$3)|0);
   $674 = HEAP32[$487>>2]|0;
   $675 = Math_fround(-$591);
   $676 = Math_fround(-$593);
   $677 = Math_fround(-$595);
   $678 = Math_fround(HEAPF32[$world1>>2]);
   $679 = Math_fround($678 * $675);
   $680 = Math_fround(HEAPF32[$74>>2]);
   $681 = Math_fround($680 * $676);
   $682 = Math_fround($679 + $681);
   $683 = Math_fround(HEAPF32[$76>>2]);
   $684 = Math_fround($683 * $677);
   $685 = Math_fround($682 + $684);
   $686 = Math_fround(HEAPF32[$78>>2]);
   $687 = Math_fround($686 * $675);
   $688 = Math_fround(HEAPF32[$81>>2]);
   $689 = Math_fround($688 * $676);
   $690 = Math_fround($687 + $689);
   $691 = Math_fround(HEAPF32[$83>>2]);
   $692 = Math_fround($691 * $677);
   $693 = Math_fround($690 + $692);
   $694 = Math_fround(HEAPF32[$85>>2]);
   $695 = Math_fround($694 * $675);
   $696 = Math_fround(HEAPF32[$87>>2]);
   $697 = Math_fround($696 * $676);
   $698 = Math_fround($695 + $697);
   $699 = Math_fround(HEAPF32[$89>>2]);
   $700 = Math_fround($699 * $677);
   $701 = Math_fround($698 + $700);
   HEAPF32[$4>>2] = $685;
   HEAPF32[$495>>2] = $693;
   HEAPF32[$496>>2] = $701;
   $702 = (FUNCTION_TABLE_iiii[$674 & 2047]($polyData1,$scaling1,$4)|0);
   $c0$1 = $673;$c1$1 = $702;
  } else {
   $c0$1 = $c0$0;$c1$1 = $c1$0;
  }
  $703 = HEAP32[$417>>2]|0;
  $704 = (($703) + (($c0$1*20)|0)|0);
  $705 = HEAP32[$418>>2]|0;
  $706 = (($705) + (($c1$1*20)|0)|0);
  $707 = Math_fround(HEAPF32[$depth>>2]);
  $708 = Math_fround(-$707);
  $709 = $707 >= Math_fround(0.0);
  $710 = $709 ? Math_fround(0.0) : $708;
  if ($idtScale0) {
   $711 = HEAP32[$704>>2]|0;
   HEAP32[$shapeSpacePlane0>>2] = $711;
   $712 = ((($703) + (($c0$1*20)|0)|0) + 4|0);
   $713 = HEAP32[$712>>2]|0;
   HEAP32[$419>>2] = $713;
   $714 = ((($703) + (($c0$1*20)|0)|0) + 8|0);
   $715 = HEAP32[$714>>2]|0;
   HEAP32[$420>>2] = $715;
   $716 = ((($703) + (($c0$1*20)|0)|0) + 12|0);
   $717 = HEAP32[$716>>2]|0;
   HEAP32[$421>>2] = $717;
   $718 = (HEAP32[tempDoublePtr>>2]=$711,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $719 = Math_fround(HEAPF32[$world0>>2]);
   $720 = Math_fround($718 * $719);
   $721 = Math_fround(HEAPF32[$27>>2]);
   $722 = Math_fround($718 * $721);
   $723 = Math_fround(HEAPF32[$29>>2]);
   $724 = Math_fround($718 * $723);
   $725 = (HEAP32[tempDoublePtr>>2]=$713,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $726 = Math_fround(HEAPF32[$31>>2]);
   $727 = Math_fround($725 * $726);
   $728 = Math_fround(HEAPF32[$34>>2]);
   $729 = Math_fround($725 * $728);
   $730 = Math_fround(HEAPF32[$36>>2]);
   $731 = Math_fround($725 * $730);
   $732 = Math_fround($720 + $727);
   $733 = Math_fround($722 + $729);
   $734 = Math_fround($724 + $731);
   $735 = (HEAP32[tempDoublePtr>>2]=$715,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $736 = Math_fround(HEAPF32[$38>>2]);
   $737 = Math_fround($735 * $736);
   $738 = Math_fround(HEAPF32[$40>>2]);
   $739 = Math_fround($735 * $738);
   $740 = Math_fround(HEAPF32[$42>>2]);
   $741 = Math_fround($735 * $740);
   $742 = Math_fround($732 + $737);
   $743 = Math_fround($733 + $739);
   $744 = Math_fround($734 + $741);
   $934 = $719;$935 = $721;$936 = $723;$937 = $726;$938 = $728;$939 = $730;$940 = $736;$941 = $738;$942 = $740;$storemerge = $744;$storemerge47 = $743;$storemerge48 = $742;
  } else {
   $745 = ((($703) + (($c0$1*20)|0)|0) + 12|0);
   $746 = Math_fround(HEAPF32[$745>>2]);
   $747 = Math_fround(HEAPF32[$478>>2]);
   $748 = Math_fround(HEAPF32[$704>>2]);
   $749 = Math_fround($747 * $748);
   $750 = Math_fround(HEAPF32[$479>>2]);
   $751 = ((($703) + (($c0$1*20)|0)|0) + 4|0);
   $752 = Math_fround(HEAPF32[$751>>2]);
   $753 = Math_fround($750 * $752);
   $754 = Math_fround($749 + $753);
   $755 = Math_fround(HEAPF32[$480>>2]);
   $756 = ((($703) + (($c0$1*20)|0)|0) + 8|0);
   $757 = Math_fround(HEAPF32[$756>>2]);
   $758 = Math_fround($755 * $757);
   $759 = Math_fround($754 + $758);
   $760 = Math_fround(HEAPF32[$481>>2]);
   $761 = Math_fround($748 * $760);
   $762 = Math_fround(HEAPF32[$482>>2]);
   $763 = Math_fround($752 * $762);
   $764 = Math_fround($761 + $763);
   $765 = Math_fround(HEAPF32[$483>>2]);
   $766 = Math_fround($757 * $765);
   $767 = Math_fround($764 + $766);
   $768 = Math_fround(HEAPF32[$484>>2]);
   $769 = Math_fround($748 * $768);
   $770 = Math_fround(HEAPF32[$485>>2]);
   $771 = Math_fround($752 * $770);
   $772 = Math_fround($769 + $771);
   $773 = Math_fround(HEAPF32[$486>>2]);
   $774 = Math_fround($757 * $773);
   $775 = Math_fround($772 + $774);
   $776 = Math_fround($759 * $759);
   $777 = Math_fround($767 * $767);
   $778 = Math_fround($776 + $777);
   $779 = Math_fround($775 * $775);
   $780 = Math_fround($778 + $779);
   $781 = (Math_fround(Math_sqrt((Math_fround($780)))));
   $782 = Math_fround(Math_fround(1.0) / $781);
   $783 = Math_fround($759 * $782);
   $784 = Math_fround($767 * $782);
   $785 = Math_fround($775 * $782);
   HEAPF32[$shapeSpacePlane0>>2] = $783;
   HEAPF32[$419>>2] = $784;
   HEAPF32[$420>>2] = $785;
   $786 = Math_fround($746 * $782);
   HEAPF32[$421>>2] = $786;
   $787 = Math_fround(HEAPF32[$world0>>2]);
   $788 = Math_fround($783 * $787);
   $789 = Math_fround(HEAPF32[$27>>2]);
   $790 = Math_fround($783 * $789);
   $791 = Math_fround(HEAPF32[$29>>2]);
   $792 = Math_fround($783 * $791);
   $793 = Math_fround(HEAPF32[$31>>2]);
   $794 = Math_fround($784 * $793);
   $795 = Math_fround(HEAPF32[$34>>2]);
   $796 = Math_fround($784 * $795);
   $797 = Math_fround(HEAPF32[$36>>2]);
   $798 = Math_fround($784 * $797);
   $799 = Math_fround($788 + $794);
   $800 = Math_fround($790 + $796);
   $801 = Math_fround($792 + $798);
   $802 = Math_fround(HEAPF32[$38>>2]);
   $803 = Math_fround($785 * $802);
   $804 = Math_fround(HEAPF32[$40>>2]);
   $805 = Math_fround($785 * $804);
   $806 = Math_fround(HEAPF32[$42>>2]);
   $807 = Math_fround($785 * $806);
   $808 = Math_fround($799 + $803);
   $809 = Math_fround($800 + $805);
   $810 = Math_fround($801 + $807);
   $934 = $787;$935 = $789;$936 = $791;$937 = $793;$938 = $795;$939 = $797;$940 = $802;$941 = $804;$942 = $806;$storemerge = $810;$storemerge47 = $809;$storemerge48 = $808;
  }
  HEAPF32[$worldNormal0>>2] = $storemerge48;
  HEAPF32[$422>>2] = $storemerge47;
  HEAPF32[$423>>2] = $storemerge;
  if ($idtScale1) {
   $811 = HEAP32[$706>>2]|0;
   HEAP32[$shapeSpacePlane1>>2] = $811;
   $812 = ((($705) + (($c1$1*20)|0)|0) + 4|0);
   $813 = HEAP32[$812>>2]|0;
   HEAP32[$424>>2] = $813;
   $814 = ((($705) + (($c1$1*20)|0)|0) + 8|0);
   $815 = HEAP32[$814>>2]|0;
   HEAP32[$425>>2] = $815;
   $816 = ((($705) + (($c1$1*20)|0)|0) + 12|0);
   $817 = HEAP32[$816>>2]|0;
   HEAP32[$426>>2] = $817;
   $818 = (HEAP32[tempDoublePtr>>2]=$811,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $819 = Math_fround(HEAPF32[$world1>>2]);
   $820 = Math_fround($818 * $819);
   $821 = Math_fround(HEAPF32[$74>>2]);
   $822 = Math_fround($818 * $821);
   $823 = Math_fround(HEAPF32[$76>>2]);
   $824 = Math_fround($818 * $823);
   $825 = (HEAP32[tempDoublePtr>>2]=$813,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $826 = Math_fround(HEAPF32[$78>>2]);
   $827 = Math_fround($825 * $826);
   $828 = Math_fround(HEAPF32[$81>>2]);
   $829 = Math_fround($825 * $828);
   $830 = Math_fround(HEAPF32[$83>>2]);
   $831 = Math_fround($825 * $830);
   $832 = Math_fround($820 + $827);
   $833 = Math_fround($822 + $829);
   $834 = Math_fround($824 + $831);
   $835 = (HEAP32[tempDoublePtr>>2]=$815,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $836 = Math_fround(HEAPF32[$85>>2]);
   $837 = Math_fround($835 * $836);
   $838 = Math_fround(HEAPF32[$87>>2]);
   $839 = Math_fround($835 * $838);
   $840 = Math_fround(HEAPF32[$89>>2]);
   $841 = Math_fround($835 * $840);
   $842 = Math_fround($832 + $837);
   $843 = Math_fround($833 + $839);
   $844 = Math_fround($834 + $841);
   $storemerge45 = $844;$storemerge46 = $843;$storemerge49 = $842;
  } else {
   $845 = ((($705) + (($c1$1*20)|0)|0) + 12|0);
   $846 = Math_fround(HEAPF32[$845>>2]);
   $847 = Math_fround(HEAPF32[$469>>2]);
   $848 = Math_fround(HEAPF32[$706>>2]);
   $849 = Math_fround($847 * $848);
   $850 = Math_fround(HEAPF32[$470>>2]);
   $851 = ((($705) + (($c1$1*20)|0)|0) + 4|0);
   $852 = Math_fround(HEAPF32[$851>>2]);
   $853 = Math_fround($850 * $852);
   $854 = Math_fround($849 + $853);
   $855 = Math_fround(HEAPF32[$471>>2]);
   $856 = ((($705) + (($c1$1*20)|0)|0) + 8|0);
   $857 = Math_fround(HEAPF32[$856>>2]);
   $858 = Math_fround($855 * $857);
   $859 = Math_fround($854 + $858);
   $860 = Math_fround(HEAPF32[$472>>2]);
   $861 = Math_fround($848 * $860);
   $862 = Math_fround(HEAPF32[$473>>2]);
   $863 = Math_fround($852 * $862);
   $864 = Math_fround($861 + $863);
   $865 = Math_fround(HEAPF32[$474>>2]);
   $866 = Math_fround($857 * $865);
   $867 = Math_fround($864 + $866);
   $868 = Math_fround(HEAPF32[$475>>2]);
   $869 = Math_fround($848 * $868);
   $870 = Math_fround(HEAPF32[$476>>2]);
   $871 = Math_fround($852 * $870);
   $872 = Math_fround($869 + $871);
   $873 = Math_fround(HEAPF32[$477>>2]);
   $874 = Math_fround($857 * $873);
   $875 = Math_fround($872 + $874);
   $876 = Math_fround($859 * $859);
   $877 = Math_fround($867 * $867);
   $878 = Math_fround($876 + $877);
   $879 = Math_fround($875 * $875);
   $880 = Math_fround($878 + $879);
   $881 = (Math_fround(Math_sqrt((Math_fround($880)))));
   $882 = Math_fround(Math_fround(1.0) / $881);
   $883 = Math_fround($859 * $882);
   $884 = Math_fround($867 * $882);
   $885 = Math_fround($875 * $882);
   HEAPF32[$shapeSpacePlane1>>2] = $883;
   HEAPF32[$424>>2] = $884;
   HEAPF32[$425>>2] = $885;
   $886 = Math_fround($846 * $882);
   HEAPF32[$426>>2] = $886;
   $887 = Math_fround(HEAPF32[$world1>>2]);
   $888 = Math_fround($883 * $887);
   $889 = Math_fround(HEAPF32[$74>>2]);
   $890 = Math_fround($883 * $889);
   $891 = Math_fround(HEAPF32[$76>>2]);
   $892 = Math_fround($883 * $891);
   $893 = Math_fround(HEAPF32[$78>>2]);
   $894 = Math_fround($884 * $893);
   $895 = Math_fround(HEAPF32[$81>>2]);
   $896 = Math_fround($884 * $895);
   $897 = Math_fround(HEAPF32[$83>>2]);
   $898 = Math_fround($884 * $897);
   $899 = Math_fround($888 + $894);
   $900 = Math_fround($890 + $896);
   $901 = Math_fround($892 + $898);
   $902 = Math_fround(HEAPF32[$85>>2]);
   $903 = Math_fround($885 * $902);
   $904 = Math_fround(HEAPF32[$87>>2]);
   $905 = Math_fround($885 * $904);
   $906 = Math_fround(HEAPF32[$89>>2]);
   $907 = Math_fround($885 * $906);
   $908 = Math_fround($899 + $903);
   $909 = Math_fround($900 + $905);
   $910 = Math_fround($901 + $907);
   $storemerge45 = $910;$storemerge46 = $909;$storemerge49 = $908;
  }
  HEAPF32[$worldNormal1>>2] = $storemerge49;
  HEAPF32[$427>>2] = $storemerge46;
  HEAPF32[$428>>2] = $storemerge45;
  $911 = Math_fround($storemerge48 * $591);
  $912 = Math_fround($storemerge47 * $593);
  $913 = Math_fround($911 + $912);
  $914 = Math_fround($storemerge * $595);
  $915 = Math_fround($913 + $914);
  $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($915)))));
  $916 = Math_fround($591 * $storemerge49);
  $917 = Math_fround($593 * $storemerge46);
  $918 = Math_fround($916 + $917);
  $919 = Math_fround($595 * $storemerge45);
  $920 = Math_fround($918 + $919);
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($920)))));
  $921 = $fabsf$i$i5 > $fabsf$i$i;
  $922 = Math_fround(HEAPF32[$429>>2]);
  $923 = Math_fround($710 + $922);
  $924 = Math_fround(-$923);
  $925 = Math_fround($591 * $924);
  $926 = Math_fround($593 * $924);
  $927 = Math_fround($595 * $924);
  HEAPF32[$contactGenPositionShiftVec>>2] = $925;
  HEAPF32[$430>>2] = $926;
  HEAPF32[$431>>2] = $927;
  $928 = Math_fround(HEAPF32[$43>>2]);
  $929 = Math_fround($928 - $925);
  $930 = Math_fround(HEAPF32[$44>>2]);
  $931 = Math_fround($930 - $926);
  $932 = Math_fround(HEAPF32[$45>>2]);
  $933 = Math_fround($932 - $927);
  HEAPF32[$dmin0$i>>2] = $934;
  HEAPF32[$432>>2] = $935;
  HEAPF32[$433>>2] = $936;
  HEAPF32[$434>>2] = $937;
  HEAPF32[$435>>2] = $938;
  HEAPF32[$436>>2] = $939;
  HEAPF32[$437>>2] = $940;
  HEAPF32[$438>>2] = $941;
  HEAPF32[$439>>2] = $942;
  HEAPF32[$440>>2] = $929;
  HEAPF32[$441>>2] = $931;
  HEAPF32[$442>>2] = $933;
  $943 = Math_fround(HEAPF32[$transform0>>2]);
  $944 = Math_fround(HEAPF32[$7>>2]);
  $945 = Math_fround(HEAPF32[$10>>2]);
  $946 = Math_fround(HEAPF32[$13>>2]);
  $947 = Math_fround(HEAPF32[$transform1>>2]);
  $948 = Math_fround(-$947);
  $949 = Math_fround(HEAPF32[$54>>2]);
  $950 = Math_fround(-$949);
  $951 = Math_fround(HEAPF32[$57>>2]);
  $952 = Math_fround(-$951);
  $953 = Math_fround(HEAPF32[$60>>2]);
  $954 = Math_fround(HEAPF32[$93>>2]);
  $955 = Math_fround($929 - $954);
  $956 = Math_fround(HEAPF32[$95>>2]);
  $957 = Math_fround($931 - $956);
  $958 = Math_fround(HEAPF32[$97>>2]);
  $959 = Math_fround($933 - $958);
  $960 = Math_fround($955 * Math_fround(2.0));
  $961 = Math_fround($957 * Math_fround(2.0));
  $962 = Math_fround($959 * Math_fround(2.0));
  $963 = Math_fround($953 * $953);
  $964 = Math_fround($963 + Math_fround(-0.5));
  $965 = Math_fround($960 * $948);
  $966 = Math_fround($961 * $950);
  $967 = Math_fround($965 + $966);
  $968 = Math_fround($962 * $952);
  $969 = Math_fround($967 + $968);
  $970 = Math_fround($964 * $960);
  $971 = Math_fround($962 * $950);
  $972 = Math_fround($961 * $952);
  $973 = Math_fround($971 - $972);
  $974 = Math_fround($953 * $973);
  $975 = Math_fround($970 + $974);
  $976 = Math_fround($969 * $948);
  $977 = Math_fround($976 + $975);
  $978 = Math_fround($964 * $961);
  $979 = Math_fround($960 * $952);
  $980 = Math_fround($962 * $948);
  $981 = Math_fround($979 - $980);
  $982 = Math_fround($953 * $981);
  $983 = Math_fround($978 + $982);
  $984 = Math_fround($969 * $950);
  $985 = Math_fround($984 + $983);
  $986 = Math_fround($964 * $962);
  $987 = Math_fround($961 * $948);
  $988 = Math_fround($960 * $950);
  $989 = Math_fround($987 - $988);
  $990 = Math_fround($953 * $989);
  $991 = Math_fround($986 + $990);
  $992 = Math_fround($969 * $952);
  $993 = Math_fround($991 + $992);
  $994 = Math_fround($943 * $953);
  $995 = Math_fround($946 * $948);
  $996 = Math_fround($995 + $994);
  $997 = Math_fround($945 * $950);
  $998 = Math_fround($997 + $996);
  $999 = Math_fround($944 * $952);
  $1000 = Math_fround($998 - $999);
  $1001 = Math_fround($944 * $953);
  $1002 = Math_fround($946 * $950);
  $1003 = Math_fround($1002 + $1001);
  $1004 = Math_fround($943 * $952);
  $1005 = Math_fround($1004 + $1003);
  $1006 = Math_fround($945 * $948);
  $1007 = Math_fround($1005 - $1006);
  $1008 = Math_fround($945 * $953);
  $1009 = Math_fround($946 * $952);
  $1010 = Math_fround($1009 + $1008);
  $1011 = Math_fround($944 * $948);
  $1012 = Math_fround($1011 + $1010);
  $1013 = Math_fround($943 * $950);
  $1014 = Math_fround($1012 - $1013);
  $1015 = Math_fround($946 * $953);
  $1016 = Math_fround($943 * $948);
  $1017 = Math_fround($1015 - $1016);
  $1018 = Math_fround($944 * $950);
  $1019 = Math_fround($1017 - $1018);
  $1020 = Math_fround($945 * $952);
  $1021 = Math_fround($1019 - $1020);
  $1022 = Math_fround(-$943);
  $1023 = Math_fround(-$944);
  $1024 = Math_fround(-$945);
  $1025 = Math_fround($954 - $929);
  $1026 = Math_fround($956 - $931);
  $1027 = Math_fround($958 - $933);
  $1028 = Math_fround($1025 * Math_fround(2.0));
  $1029 = Math_fround($1026 * Math_fround(2.0));
  $1030 = Math_fround($1027 * Math_fround(2.0));
  $1031 = Math_fround($946 * $946);
  $1032 = Math_fround($1031 + Math_fround(-0.5));
  $1033 = Math_fround($1028 * $1022);
  $1034 = Math_fround($1029 * $1023);
  $1035 = Math_fround($1033 + $1034);
  $1036 = Math_fround($1030 * $1024);
  $1037 = Math_fround($1035 + $1036);
  $1038 = Math_fround($1032 * $1028);
  $1039 = Math_fround($1030 * $1023);
  $1040 = Math_fround($1029 * $1024);
  $1041 = Math_fround($1039 - $1040);
  $1042 = Math_fround($946 * $1041);
  $1043 = Math_fround($1038 + $1042);
  $1044 = Math_fround($1037 * $1022);
  $1045 = Math_fround($1044 + $1043);
  $1046 = Math_fround($1032 * $1029);
  $1047 = Math_fround($1028 * $1024);
  $1048 = Math_fround($1030 * $1022);
  $1049 = Math_fround($1047 - $1048);
  $1050 = Math_fround($946 * $1049);
  $1051 = Math_fround($1046 + $1050);
  $1052 = Math_fround($1037 * $1023);
  $1053 = Math_fround($1052 + $1051);
  $1054 = Math_fround($1032 * $1030);
  $1055 = Math_fround($1029 * $1022);
  $1056 = Math_fround($1028 * $1023);
  $1057 = Math_fround($1055 - $1056);
  $1058 = Math_fround($946 * $1057);
  $1059 = Math_fround($1054 + $1058);
  $1060 = Math_fround($1037 * $1024);
  $1061 = Math_fround($1059 + $1060);
  $1062 = Math_fround($946 * $947);
  $1063 = Math_fround($953 * $1022);
  $1064 = Math_fround($1062 + $1063);
  $1065 = Math_fround($951 * $1023);
  $1066 = Math_fround($1065 + $1064);
  $1067 = Math_fround($949 * $1024);
  $1068 = Math_fround($1066 - $1067);
  $1069 = Math_fround($946 * $949);
  $1070 = Math_fround($953 * $1023);
  $1071 = Math_fround($1069 + $1070);
  $1072 = Math_fround($947 * $1024);
  $1073 = Math_fround($1072 + $1071);
  $1074 = Math_fround($951 * $1022);
  $1075 = Math_fround($1073 - $1074);
  $1076 = Math_fround($946 * $951);
  $1077 = Math_fround($953 * $1024);
  $1078 = Math_fround($1076 + $1077);
  $1079 = Math_fround($949 * $1022);
  $1080 = Math_fround($1079 + $1078);
  $1081 = Math_fround($947 * $1023);
  $1082 = Math_fround($1080 - $1081);
  $1083 = Math_fround($947 * $1022);
  $1084 = Math_fround($1015 - $1083);
  $1085 = Math_fround($949 * $1023);
  $1086 = Math_fround($1084 - $1085);
  $1087 = Math_fround($951 * $1024);
  $1088 = Math_fround($1086 - $1087);
  $1089 = Math_fround($1000 + $1000);
  $1090 = Math_fround($1007 + $1007);
  $1091 = Math_fround($1014 + $1014);
  $1092 = Math_fround($1021 * $1089);
  $1093 = Math_fround($1021 * $1090);
  $1094 = Math_fround($1021 * $1091);
  $1095 = Math_fround($1000 * $1089);
  $1096 = Math_fround($1000 * $1090);
  $1097 = Math_fround($1000 * $1091);
  $1098 = Math_fround($1007 * $1090);
  $1099 = Math_fround($1007 * $1091);
  $1100 = Math_fround($1014 * $1091);
  $1101 = Math_fround(Math_fround(1.0) - $1098);
  $1102 = Math_fround($1101 - $1100);
  HEAPF32[$dmin1$i>>2] = $1102;
  $1103 = Math_fround($1096 + $1094);
  HEAPF32[$443>>2] = $1103;
  $1104 = Math_fround($1097 - $1093);
  HEAPF32[$444>>2] = $1104;
  $1105 = Math_fround($1096 - $1094);
  HEAPF32[$445>>2] = $1105;
  $1106 = Math_fround(Math_fround(1.0) - $1095);
  $1107 = Math_fround($1106 - $1100);
  HEAPF32[$446>>2] = $1107;
  $1108 = Math_fround($1099 + $1092);
  HEAPF32[$447>>2] = $1108;
  $1109 = Math_fround($1097 + $1093);
  HEAPF32[$448>>2] = $1109;
  $1110 = Math_fround($1099 - $1092);
  HEAPF32[$449>>2] = $1110;
  $1111 = Math_fround($1106 - $1098);
  HEAPF32[$450>>2] = $1111;
  HEAPF32[$451>>2] = $977;
  HEAPF32[$452>>2] = $985;
  HEAPF32[$453>>2] = $993;
  $1112 = Math_fround($1068 + $1068);
  $1113 = Math_fround($1075 + $1075);
  $1114 = Math_fround($1082 + $1082);
  $1115 = Math_fround($1088 * $1112);
  $1116 = Math_fround($1088 * $1113);
  $1117 = Math_fround($1088 * $1114);
  $1118 = Math_fround($1068 * $1112);
  $1119 = Math_fround($1068 * $1113);
  $1120 = Math_fround($1068 * $1114);
  $1121 = Math_fround($1075 * $1113);
  $1122 = Math_fround($1075 * $1114);
  $1123 = Math_fround($1082 * $1114);
  $1124 = Math_fround(Math_fround(1.0) - $1121);
  $1125 = Math_fround($1124 - $1123);
  HEAPF32[$vec0$i>>2] = $1125;
  $1126 = Math_fround($1119 + $1117);
  HEAPF32[$454>>2] = $1126;
  $1127 = Math_fround($1120 - $1116);
  HEAPF32[$455>>2] = $1127;
  $1128 = Math_fround($1119 - $1117);
  HEAPF32[$456>>2] = $1128;
  $1129 = Math_fround(Math_fround(1.0) - $1118);
  $1130 = Math_fround($1129 - $1123);
  HEAPF32[$457>>2] = $1130;
  $1131 = Math_fround($1122 + $1115);
  HEAPF32[$458>>2] = $1131;
  $1132 = Math_fround($1120 + $1116);
  HEAPF32[$459>>2] = $1132;
  $1133 = Math_fround($1122 - $1115);
  HEAPF32[$460>>2] = $1133;
  $1134 = Math_fround($1129 - $1121);
  HEAPF32[$461>>2] = $1134;
  HEAPF32[$462>>2] = $1045;
  HEAPF32[$463>>2] = $1053;
  HEAPF32[$464>>2] = $1061;
  $$pre42 = ((($703) + (($c0$1*20)|0)|0) + 18|0);
  if ($idtScale0) {
   $1148 = 0;$1149 = 0;
  } else {
   $1135 = HEAP8[$$pre42>>0]|0;
   $1136 = $1135&255;
   $1137 = ($1136*12)|0;
   $1138 = STACKTOP; STACKTOP = STACKTOP + ((((1*$1137)|0)+15)&-16)|0;;
   $1139 = STACKTOP; STACKTOP = STACKTOP + ((((1*$1136)|0)+15)&-16)|0;;
   $1148 = $1138;$1149 = $1139;
  }
  $1140 = HEAP32[$465>>2]|0;
  $1141 = HEAP32[$466>>2]|0;
  $1142 = ((($703) + (($c0$1*20)|0)|0) + 16|0);
  $1143 = HEAP16[$1142>>1]|0;
  $1144 = $1143&65535;
  $1145 = (($1141) + ($1144)|0);
  $1146 = HEAP8[$$pre42>>0]|0;
  $1147 = $1146&255;
  __ZN5physx2Gu15getScaledConvexERPNS_6PxVec3ERPhS2_S4_bPKS1_PKhjRKNS_2Cm23FastVertex2ShapeScalingE($scaledVertices0,$stackIndices0,$1148,$1149,$idtScale0,$1140,$1145,$1147,$scaling0);
  $$pre43 = ((($705) + (($c1$1*20)|0)|0) + 18|0);
  if ($idtScale1) {
   $1163 = 0;$1164 = 0;
  } else {
   $1150 = HEAP8[$$pre43>>0]|0;
   $1151 = $1150&255;
   $1152 = ($1151*12)|0;
   $1153 = STACKTOP; STACKTOP = STACKTOP + ((((1*$1152)|0)+15)&-16)|0;;
   $1154 = STACKTOP; STACKTOP = STACKTOP + ((((1*$1151)|0)+15)&-16)|0;;
   $1163 = $1153;$1164 = $1154;
  }
  $1155 = HEAP32[$467>>2]|0;
  $1156 = HEAP32[$468>>2]|0;
  $1157 = ((($705) + (($c1$1*20)|0)|0) + 16|0);
  $1158 = HEAP16[$1157>>1]|0;
  $1159 = $1158&65535;
  $1160 = (($1156) + ($1159)|0);
  $1161 = HEAP8[$$pre43>>0]|0;
  $1162 = $1161&255;
  __ZN5physx2Gu15getScaledConvexERPNS_6PxVec3ERPhS2_S4_bPKS1_PKhjRKNS_2Cm23FastVertex2ShapeScalingE($scaledVertices1,$stackIndices1,$1163,$1164,$idtScale1,$1155,$1160,$1162,$scaling1);
  __ZN5physx2Gu23findRotationMatrixFromZERKNS_6PxVec3E($vec1$i,$shapeSpacePlane0);
  __ZN5physx2Gu23findRotationMatrixFromZERKNS_6PxVec3E($0,$shapeSpacePlane1);
  if ($921) {
   $1165 = HEAP8[$$pre42>>0]|0;
   $1166 = $1165&255;
   $1167 = HEAP32[$scaledVertices0>>2]|0;
   $1168 = HEAP32[$stackIndices0>>2]|0;
   $1169 = HEAP8[$$pre43>>0]|0;
   $1170 = $1169&255;
   $1171 = HEAP32[$scaledVertices1>>2]|0;
   $1172 = HEAP32[$stackIndices1>>2]|0;
   $1173 = (__ZN5physx2Gu24contactPolygonPolygonExtEjPKNS_6PxVec3EPKhRKNS_2Cm8Matrix34ERKNS_7PxPlaneERKNS_7PxMat33EjS3_S5_S9_SC_SF_RS2_S9_S9_jjRNS0_13ContactBufferEbSG_f($1166,$1167,$1168,$dmin0$i,$shapeSpacePlane0,$vec1$i,$1170,$1171,$1172,$world1,$shapeSpacePlane1,$0,$worldNormal0,$dmin1$i,$vec0$i,-1,-1,$contactBuffer,1,$contactGenPositionShiftVec,$923)|0);
   if ($1173) {
    $$01 = 0;$$1 = 1;$TryRoughPass$1$off0 = $TryRoughPass$0$off0;
   } else {
    label = 35;
   }
  } else {
   $1174 = HEAP8[$$pre43>>0]|0;
   $1175 = $1174&255;
   $1176 = HEAP32[$scaledVertices1>>2]|0;
   $1177 = HEAP32[$stackIndices1>>2]|0;
   $1178 = HEAP8[$$pre42>>0]|0;
   $1179 = $1178&255;
   $1180 = HEAP32[$scaledVertices0>>2]|0;
   $1181 = HEAP32[$stackIndices0>>2]|0;
   $1182 = (__ZN5physx2Gu24contactPolygonPolygonExtEjPKNS_6PxVec3EPKhRKNS_2Cm8Matrix34ERKNS_7PxPlaneERKNS_7PxMat33EjS3_S5_S9_SC_SF_RS2_S9_S9_jjRNS0_13ContactBufferEbSG_f($1175,$1176,$1177,$world1,$shapeSpacePlane1,$0,$1179,$1180,$1181,$dmin0$i,$shapeSpacePlane0,$vec1$i,$worldNormal1,$vec0$i,$dmin1$i,-1,-1,$contactBuffer,0,$contactGenPositionShiftVec,$923)|0);
   if ($1182) {
    $$01 = 0;$$1 = 1;$TryRoughPass$1$off0 = $TryRoughPass$0$off0;
   } else {
    label = 35;
   }
  }
  if ((label|0) == 35) {
   label = 0;
   $$0$ = $TryRoughPass$0$off0 & $$0;
   $$01 = $TryRoughPass$0$off0;$$1 = $$0$;$TryRoughPass$1$off0 = 0;
  }
  if ($$01) {
   $$0 = $$1;$TryRoughPass$0$off0 = $TryRoughPass$1$off0;$c0$0 = $c0$1;$c1$0 = $c1$1;
  } else {
   $$3 = $$1;
   label = 37;
   break;
  }
 }
 if ((label|0) == 37) {
  STACKTOP = sp;return ($$3|0);
 }
 return 0|0;
}
function __ZN5physx22PxcContactConvexConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $convexBounds0 = 0, $convexBounds1 = 0;
 var $polyData0 = 0, $polyData1 = 0, $scaling0 = 0, $scaling1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $scaling0 = sp + 264|0;
 $scaling1 = sp;
 $convexBounds0 = sp + 72|0;
 $convexBounds1 = sp + 96|0;
 $polyData0 = sp + 120|0;
 $polyData1 = sp + 192|0;
 HEAPF32[$scaling0>>2] = Math_fround(1.0);
 $0 = (($scaling0) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($scaling0) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($scaling0) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($scaling0) + 16|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($scaling0) + 20|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($scaling0) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($scaling0) + 28|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($scaling0) + 32|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($scaling0) + 36|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($scaling0) + 40|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($scaling0) + 44|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($scaling0) + 48|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($scaling0) + 52|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($scaling0) + 56|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($scaling0) + 60|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($scaling0) + 64|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($scaling0) + 68|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 HEAPF32[$scaling1>>2] = Math_fround(1.0);
 $17 = (($scaling1) + 4|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($scaling1) + 8|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($scaling1) + 12|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($scaling1) + 16|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($scaling1) + 20|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($scaling1) + 24|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($scaling1) + 28|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($scaling1) + 32|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($scaling1) + 36|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($scaling1) + 40|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($scaling1) + 44|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($scaling1) + 48|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($scaling1) + 52|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = (($scaling1) + 56|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($scaling1) + 60|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($scaling1) + 64|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($scaling1) + 68|0);
 HEAPF32[$33>>2] = Math_fround(1.0);
 $34 = (__ZN5physx2Gu13getConvexDataERKNS0_13GeometryUnionERNS_2Cm23FastVertex2ShapeScalingERNS_9PxBounds3ERNS0_13PolygonalDataE($shape0,$scaling0,$convexBounds0,$polyData0)|0);
 $35 = (__ZN5physx2Gu13getConvexDataERKNS0_13GeometryUnionERNS_2Cm23FastVertex2ShapeScalingERNS_9PxBounds3ERNS0_13PolygonalDataE($shape1,$scaling1,$convexBounds1,$polyData1)|0);
 $36 = Math_fround(HEAPF32[$contactDistance>>2]);
 $37 = (__ZL18PxcContactHullHullRKN5physx2Gu13PolygonalDataES3_RKNS_9PxBounds3ES6_RKNS_11PxTransformES9_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESF_bb($polyData0,$polyData1,$convexBounds0,$convexBounds1,$transform0,$transform1,$36,$contactBuffer,$scaling0,$scaling1,$34,$35)|0);
 STACKTOP = sp;return ($37|0);
}
function __ZL28PxcBruteForceOverlapBackfaceRKN5physx9PxBounds3ES2_RKNS_2Gu13PolygonalDataES6_RKNS_2Cm8Matrix34ESA_RKNS7_23FastVertex2ShapeScalingESD_SA_SA_RKNS_6PxVec3ERjSH_RfRSE_RNS3_14PxcSepAxisTypeEf($hullBounds0,$hullBounds1,$polyData0,$polyData1,$world0,$world1,$scaling0,$scaling1,$m0to1,$m1to0,$delta,$id0,$id1,$depth,$sep,$code,$contactDistance) {
 $hullBounds0 = $hullBounds0|0;
 $hullBounds1 = $hullBounds1|0;
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $world0 = $world0|0;
 $world1 = $world1|0;
 $scaling0 = $scaling0|0;
 $scaling1 = $scaling1|0;
 $m0to1 = $m0to1|0;
 $m1to0 = $m1to0|0;
 $delta = $delta|0;
 $id0 = $id0|0;
 $id1 = $id1|0;
 $depth = $depth|0;
 $sep = $sep|0;
 $code = $code|0;
 $contactDistance = Math_fround($contactDistance);
 var $$0$i$i$us = 0, $$1 = 0, $$lcssa29 = Math_fround(0), $$lcssa31 = Math_fround(0), $$lcssa33 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0;
 var $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0;
 var $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0;
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0;
 var $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0;
 var $328 = 0, $329 = Math_fround(0), $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = 0, $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0.0, $394 = 0, $395 = 0.0, $396 = 0, $397 = 0.0, $398 = 0, $399 = Math_fround(0), $4 = 0;
 var $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0);
 var $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0);
 var $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0);
 var $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0);
 var $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0);
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0);
 var $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0);
 var $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = 0, $531 = Math_fround(0), $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = 0, $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0;
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0;
 var $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $aabb0 = 0, $aabb1 = 0, $dmin$0 = Math_fround(0), $dmin$1$lcssa = Math_fround(0), $dmin$137$us = Math_fround(0), $dmin$223$us = Math_fround(0), $dmin$3$us = Math_fround(0), $dmin0 = 0, $dmin1 = 0, $fabsf$i$i$i$us = Math_fround(0), $fabsf$i$i1$i$us = Math_fround(0), $fabsf$i$i2$i$us = Math_fround(0), $i$036 = 0, $i$036$us = 0;
 var $j$024$us = 0, $mSA0 = 0, $mSA1 = 0, $max0$i = 0, $max1$i$i = 0, $min0$i = 0, $min1$i$i = 0, $not$$i$us = 0, $numIndices0 = 0, $numIndices1 = 0, $polyData0$idx$val = 0, $polyData0$idx7 = 0, $polyData0$idx7$val = 0, $polyData0$idx8 = 0, $polyData0$idx8$val = 0, $polyData1$idx$val = 0, $polyData1$idx5 = 0, $polyData1$idx5$val = 0, $polyData1$idx6 = 0, $polyData1$idx6$val = 0;
 var $sepAxis = 0, $vec0 = 0, $vec1 = 0, $witnessPlane0 = 0, $witnessPlane1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6320|0;
 $min1$i$i = sp + 6308|0;
 $max1$i$i = sp + 6304|0;
 $min0$i = sp + 6300|0;
 $max0$i = sp + 6296|0;
 $numIndices0 = sp + 6292|0;
 $dmin0 = sp + 6288|0;
 $vec0 = sp + 6276|0;
 $0 = sp + 6264|0;
 $numIndices1 = sp + 6260|0;
 $dmin1 = sp + 6256|0;
 $vec1 = sp + 6232|0;
 $mSA0 = sp + 3156|0;
 $mSA1 = sp + 80|0;
 $witnessPlane0 = sp + 64|0;
 $witnessPlane1 = sp + 48|0;
 $aabb0 = sp + 24|0;
 $aabb1 = sp;
 $sepAxis = sp + 6244|0;
 $1 = Math_fround(HEAPF32[$world0>>2]);
 $2 = Math_fround(HEAPF32[$delta>>2]);
 $3 = Math_fround($1 * $2);
 $4 = (($world0) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($delta) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = Math_fround($3 + $8);
 $10 = (($world0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($delta) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 * $13);
 $15 = Math_fround($9 + $14);
 $16 = (($world0) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($2 * $17);
 $19 = (($world0) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($7 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($world0) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($13 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($world0) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($2 * $28);
 $30 = (($world0) + 28|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($7 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($world0) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($13 * $35);
 $37 = Math_fround($33 + $36);
 $38 = (($polyData0) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39 << 2;
 $41 = STACKTOP; STACKTOP = STACKTOP + ((((1*$40)|0)+15)&-16)|0;;
 HEAPF32[$dmin0>>2] = Math_fround(3.40282346638528859812E+38);
 $42 = Math_fround(-$2);
 $43 = Math_fround(-$7);
 $44 = Math_fround(-$13);
 HEAPF32[$0>>2] = $42;
 $45 = (($0) + 4|0);
 HEAPF32[$45>>2] = $43;
 $46 = (($0) + 8|0);
 HEAPF32[$46>>2] = $44;
 $47 = (__ZL27PxcTestFacesSepAxesBackfaceRKN5physx2Gu13PolygonalDataES3_RKNS_2Cm8Matrix34ES7_RKNS4_23FastVertex2ShapeScalingESA_S7_RKNS_6PxVec3ERfRSB_RjPjSG_fSD_($polyData0,$polyData1,$world0,$world1,$scaling0,$scaling1,$m1to0,$15,$26,$37,$dmin0,$vec0,$id0,$41,$numIndices0,$contactDistance,$0)|0);
 if (!($47)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $48 = Math_fround(HEAPF32[$world1>>2]);
 $49 = Math_fround(HEAPF32[$delta>>2]);
 $50 = Math_fround($48 * $49);
 $51 = (($world1) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(HEAPF32[$6>>2]);
 $54 = Math_fround($52 * $53);
 $55 = Math_fround($50 + $54);
 $56 = (($world1) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround(HEAPF32[$12>>2]);
 $59 = Math_fround($57 * $58);
 $60 = Math_fround($55 + $59);
 $61 = (($world1) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($49 * $62);
 $64 = (($world1) + 16|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($53 * $65);
 $67 = Math_fround($63 + $66);
 $68 = (($world1) + 20|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($58 * $69);
 $71 = Math_fround($67 + $70);
 $72 = (($world1) + 24|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($49 * $73);
 $75 = (($world1) + 28|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($53 * $76);
 $78 = Math_fround($74 + $77);
 $79 = (($world1) + 32|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($58 * $80);
 $82 = Math_fround($78 + $81);
 $83 = (($polyData1) + 16|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = $84 << 2;
 $86 = STACKTOP; STACKTOP = STACKTOP + ((((1*$85)|0)+15)&-16)|0;;
 HEAPF32[$dmin1>>2] = Math_fround(3.40282346638528859812E+38);
 $87 = Math_fround(-$60);
 $88 = Math_fround(-$71);
 $89 = Math_fround(-$82);
 $90 = (__ZL27PxcTestFacesSepAxesBackfaceRKN5physx2Gu13PolygonalDataES3_RKNS_2Cm8Matrix34ES7_RKNS4_23FastVertex2ShapeScalingESA_S7_RKNS_6PxVec3ERfRSB_RjPjSG_fSD_($polyData1,$polyData0,$world1,$world0,$scaling1,$scaling0,$m0to1,$87,$88,$89,$dmin1,$vec1,$id1,$86,$numIndices1,$contactDistance,$delta)|0);
 if (!($90)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $91 = Math_fround(HEAPF32[$dmin0>>2]);
 $92 = Math_fround(HEAPF32[$vec0>>2]);
 $93 = (($vec0) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($vec0) + 8|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 HEAP32[$code>>2] = 0;
 $97 = Math_fround(HEAPF32[$dmin1>>2]);
 $98 = $97 < $91;
 if ($98) {
  $99 = Math_fround(HEAPF32[$vec1>>2]);
  $100 = (($vec1) + 4|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $102 = (($vec1) + 8|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  HEAP32[$code>>2] = 1;
  $546 = $103;$547 = $101;$548 = $99;$dmin$0 = $97;
 } else {
  $546 = $96;$547 = $94;$548 = $92;$dmin$0 = $91;
 }
 HEAP32[$mSA0>>2] = 0;
 HEAP32[$mSA1>>2] = 0;
 $104 = HEAP32[$id0>>2]|0;
 $105 = (($polyData0) + 24|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = HEAP32[$id1>>2]|0;
 $108 = (($polyData1) + 24|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ((($106) + (($104*20)|0)|0) + 12|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($witnessPlane0) + 12|0);
 $113 = (($scaling0) + 36|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($106) + (($104*20)|0)|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($114 * $116);
 $118 = (($scaling0) + 40|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = ((($106) + (($104*20)|0)|0) + 4|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround($119 * $121);
 $123 = Math_fround($117 + $122);
 $124 = (($scaling0) + 44|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = ((($106) + (($104*20)|0)|0) + 8|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = Math_fround($125 * $127);
 $129 = Math_fround($123 + $128);
 $130 = (($scaling0) + 48|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($116 * $131);
 $133 = (($scaling0) + 52|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($121 * $134);
 $136 = Math_fround($132 + $135);
 $137 = (($scaling0) + 56|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($127 * $138);
 $140 = Math_fround($136 + $139);
 $141 = (($scaling0) + 60|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround($116 * $142);
 $144 = (($scaling0) + 64|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround($121 * $145);
 $147 = Math_fround($143 + $146);
 $148 = (($scaling0) + 68|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = Math_fround($127 * $149);
 $151 = Math_fround($147 + $150);
 $152 = Math_fround($129 * $129);
 $153 = Math_fround($140 * $140);
 $154 = Math_fround($152 + $153);
 $155 = Math_fround($151 * $151);
 $156 = Math_fround($154 + $155);
 $157 = (Math_fround(Math_sqrt((Math_fround($156)))));
 $158 = Math_fround(Math_fround(1.0) / $157);
 $159 = Math_fround($129 * $158);
 $160 = Math_fround($140 * $158);
 $161 = Math_fround($151 * $158);
 HEAPF32[$witnessPlane0>>2] = $159;
 $162 = (($witnessPlane0) + 4|0);
 HEAPF32[$162>>2] = $160;
 $163 = (($witnessPlane0) + 8|0);
 HEAPF32[$163>>2] = $161;
 $164 = Math_fround($111 * $158);
 HEAPF32[$112>>2] = $164;
 $165 = ((($109) + (($107*20)|0)|0) + 12|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = (($witnessPlane1) + 12|0);
 $168 = (($scaling1) + 36|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($109) + (($107*20)|0)|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = Math_fround($169 * $171);
 $173 = (($scaling1) + 40|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = ((($109) + (($107*20)|0)|0) + 4|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = Math_fround($174 * $176);
 $178 = Math_fround($172 + $177);
 $179 = (($scaling1) + 44|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = ((($109) + (($107*20)|0)|0) + 8|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = Math_fround($180 * $182);
 $184 = Math_fround($178 + $183);
 $185 = (($scaling1) + 48|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = Math_fround($171 * $186);
 $188 = (($scaling1) + 52|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = Math_fround($176 * $189);
 $191 = Math_fround($187 + $190);
 $192 = (($scaling1) + 56|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = Math_fround($182 * $193);
 $195 = Math_fround($191 + $194);
 $196 = (($scaling1) + 60|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = Math_fround($171 * $197);
 $199 = (($scaling1) + 64|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = Math_fround($176 * $200);
 $202 = Math_fround($198 + $201);
 $203 = (($scaling1) + 68|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = Math_fround($182 * $204);
 $206 = Math_fround($202 + $205);
 $207 = Math_fround($184 * $184);
 $208 = Math_fround($195 * $195);
 $209 = Math_fround($207 + $208);
 $210 = Math_fround($206 * $206);
 $211 = Math_fround($209 + $210);
 $212 = (Math_fround(Math_sqrt((Math_fround($211)))));
 $213 = Math_fround(Math_fround(1.0) / $212);
 $214 = Math_fround($184 * $213);
 $215 = Math_fround($195 * $213);
 $216 = Math_fround($206 * $213);
 HEAPF32[$witnessPlane1>>2] = $214;
 $217 = (($witnessPlane1) + 4|0);
 HEAPF32[$217>>2] = $215;
 $218 = (($witnessPlane1) + 8|0);
 $219 = Math_fround($166 * $213);
 $220 = Math_fround(HEAPF32[$m0to1>>2]);
 $221 = Math_fround($159 * $220);
 $222 = (($m0to1) + 4|0);
 $223 = Math_fround(HEAPF32[$222>>2]);
 $224 = Math_fround($159 * $223);
 $225 = (($m0to1) + 8|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = Math_fround($159 * $226);
 $228 = (($m0to1) + 12|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = Math_fround($160 * $229);
 $231 = (($m0to1) + 16|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = Math_fround($160 * $232);
 $234 = (($m0to1) + 20|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = Math_fround($160 * $235);
 $237 = Math_fround($221 + $230);
 $238 = Math_fround($224 + $233);
 $239 = Math_fround($227 + $236);
 $240 = (($m0to1) + 24|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = Math_fround($161 * $241);
 $243 = (($m0to1) + 28|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = Math_fround($161 * $244);
 $246 = (($m0to1) + 32|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = Math_fround($161 * $247);
 $249 = Math_fround($237 + $242);
 $250 = Math_fround($238 + $245);
 $251 = Math_fround($239 + $248);
 $252 = (($m0to1) + 36|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = Math_fround($249 * $253);
 $255 = (($m0to1) + 40|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 $257 = Math_fround($250 * $256);
 $258 = Math_fround($254 + $257);
 $259 = (($m0to1) + 44|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = Math_fround($251 * $260);
 $262 = Math_fround($258 + $261);
 $263 = Math_fround($164 - $262);
 HEAPF32[$witnessPlane0>>2] = $249;
 HEAPF32[$162>>2] = $250;
 HEAPF32[$163>>2] = $251;
 HEAPF32[$112>>2] = $263;
 $264 = Math_fround(HEAPF32[$m1to0>>2]);
 $265 = Math_fround($214 * $264);
 $266 = (($m1to0) + 4|0);
 $267 = Math_fround(HEAPF32[$266>>2]);
 $268 = Math_fround($214 * $267);
 $269 = (($m1to0) + 8|0);
 $270 = Math_fround(HEAPF32[$269>>2]);
 $271 = Math_fround($214 * $270);
 $272 = (($m1to0) + 12|0);
 $273 = Math_fround(HEAPF32[$272>>2]);
 $274 = Math_fround($215 * $273);
 $275 = (($m1to0) + 16|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 $277 = Math_fround($215 * $276);
 $278 = (($m1to0) + 20|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = Math_fround($215 * $279);
 $281 = Math_fround($265 + $274);
 $282 = Math_fround($268 + $277);
 $283 = Math_fround($271 + $280);
 $284 = (($m1to0) + 24|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = Math_fround($216 * $285);
 $287 = (($m1to0) + 28|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $289 = Math_fround($216 * $288);
 $290 = (($m1to0) + 32|0);
 $291 = Math_fround(HEAPF32[$290>>2]);
 $292 = Math_fround($216 * $291);
 $293 = Math_fround($281 + $286);
 $294 = Math_fround($282 + $289);
 $295 = Math_fround($283 + $292);
 $296 = (($m1to0) + 36|0);
 $297 = Math_fround(HEAPF32[$296>>2]);
 $298 = Math_fround($293 * $297);
 $299 = (($m1to0) + 40|0);
 $300 = Math_fround(HEAPF32[$299>>2]);
 $301 = Math_fround($294 * $300);
 $302 = Math_fround($298 + $301);
 $303 = (($m1to0) + 44|0);
 $304 = Math_fround(HEAPF32[$303>>2]);
 $305 = Math_fround($295 * $304);
 $306 = Math_fround($302 + $305);
 $307 = Math_fround($219 - $306);
 HEAPF32[$witnessPlane1>>2] = $293;
 HEAPF32[$217>>2] = $294;
 HEAPF32[$218>>2] = $295;
 HEAPF32[$167>>2] = $307;
 $308 = Math_fround(HEAPF32[$hullBounds0>>2]);
 $309 = (($hullBounds0) + 4|0);
 $310 = Math_fround(HEAPF32[$309>>2]);
 $311 = (($aabb0) + 4|0);
 $312 = (($hullBounds0) + 8|0);
 $313 = Math_fround(HEAPF32[$312>>2]);
 $314 = (($aabb0) + 8|0);
 $315 = (($hullBounds0) + 12|0);
 $316 = Math_fround(HEAPF32[$315>>2]);
 $317 = (($aabb0) + 12|0);
 $318 = (($hullBounds0) + 16|0);
 $319 = Math_fround(HEAPF32[$318>>2]);
 $320 = (($aabb0) + 16|0);
 $321 = (($hullBounds0) + 20|0);
 $322 = Math_fround(HEAPF32[$321>>2]);
 $323 = (($aabb0) + 20|0);
 $324 = Math_fround(HEAPF32[$hullBounds1>>2]);
 $325 = (($hullBounds1) + 4|0);
 $326 = Math_fround(HEAPF32[$325>>2]);
 $327 = (($aabb1) + 4|0);
 $328 = (($hullBounds1) + 8|0);
 $329 = Math_fround(HEAPF32[$328>>2]);
 $330 = (($aabb1) + 8|0);
 $331 = (($hullBounds1) + 12|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = (($aabb1) + 12|0);
 $334 = (($hullBounds1) + 16|0);
 $335 = Math_fround(HEAPF32[$334>>2]);
 $336 = (($aabb1) + 16|0);
 $337 = (($hullBounds1) + 20|0);
 $338 = Math_fround(HEAPF32[$337>>2]);
 $339 = (($aabb1) + 20|0);
 $340 = Math_fround($308 - $contactDistance);
 HEAPF32[$aabb0>>2] = $340;
 $341 = Math_fround($310 - $contactDistance);
 HEAPF32[$311>>2] = $341;
 $342 = Math_fround($313 - $contactDistance);
 HEAPF32[$314>>2] = $342;
 $343 = Math_fround($324 - $contactDistance);
 HEAPF32[$aabb1>>2] = $343;
 $344 = Math_fround($326 - $contactDistance);
 HEAPF32[$327>>2] = $344;
 $345 = Math_fround($329 - $contactDistance);
 HEAPF32[$330>>2] = $345;
 $346 = Math_fround($316 + $contactDistance);
 HEAPF32[$317>>2] = $346;
 $347 = Math_fround($319 + $contactDistance);
 HEAPF32[$320>>2] = $347;
 $348 = Math_fround($322 + $contactDistance);
 HEAPF32[$323>>2] = $348;
 $349 = Math_fround($332 + $contactDistance);
 HEAPF32[$333>>2] = $349;
 $350 = Math_fround($335 + $contactDistance);
 HEAPF32[$336>>2] = $350;
 $351 = Math_fround($338 + $contactDistance);
 HEAPF32[$339>>2] = $351;
 $352 = HEAP32[$numIndices0>>2]|0;
 $polyData0$idx$val = HEAP32[$105>>2]|0;
 $polyData0$idx7 = (($polyData0) + 28|0);
 $polyData0$idx7$val = HEAP32[$polyData0$idx7>>2]|0;
 $polyData0$idx8 = (($polyData0) + 32|0);
 $polyData0$idx8$val = HEAP32[$polyData0$idx8>>2]|0;
 __ZL21PxcFindSeparatingAxesRN5physx2Gu14SeparatingAxesEPKjjRKNS0_13PolygonalDataERKNS_2Cm8Matrix34ERKNS_7PxPlaneESB_RKNS_9PxBounds3EfRKNS8_23FastVertex2ShapeScalingE($mSA0,$41,$352,$polyData0$idx$val,$polyData0$idx7$val,$polyData0$idx8$val,$world0,$witnessPlane1,$m0to1,$aabb1,$contactDistance,$scaling0);
 $353 = HEAP32[$numIndices1>>2]|0;
 $polyData1$idx$val = HEAP32[$108>>2]|0;
 $polyData1$idx5 = (($polyData1) + 28|0);
 $polyData1$idx5$val = HEAP32[$polyData1$idx5>>2]|0;
 $polyData1$idx6 = (($polyData1) + 32|0);
 $polyData1$idx6$val = HEAP32[$polyData1$idx6>>2]|0;
 __ZL21PxcFindSeparatingAxesRN5physx2Gu14SeparatingAxesEPKjjRKNS0_13PolygonalDataERKNS_2Cm8Matrix34ERKNS_7PxPlaneESB_RKNS_9PxBounds3EfRKNS8_23FastVertex2ShapeScalingE($mSA1,$86,$353,$polyData1$idx$val,$polyData1$idx5$val,$polyData1$idx6$val,$world1,$witnessPlane0,$m1to0,$aabb0,$contactDistance,$scaling1);
 $354 = HEAP32[$mSA0>>2]|0;
 $355 = HEAP32[$mSA1>>2]|0;
 $356 = ($354|0)==(0);
 L10: do {
  if ($356) {
   $$lcssa29 = $546;$$lcssa31 = $547;$$lcssa33 = $548;$dmin$1$lcssa = $dmin$0;
  } else {
   $357 = ($355|0)==(0);
   $358 = (($sepAxis) + 4|0);
   $359 = (($sepAxis) + 8|0);
   $360 = (($polyData0) + 44|0);
   $361 = (($polyData0) + 48|0);
   $362 = (($polyData0) + 52|0);
   $363 = (($polyData1) + 44|0);
   $364 = (($polyData1) + 48|0);
   $365 = (($polyData1) + 52|0);
   $366 = (($polyData0) + 40|0);
   $367 = (($polyData1) + 40|0);
   $368 = (($polyData0) + 64|0);
   $369 = (($polyData1) + 64|0);
   if ($357) {
    $i$036 = 0;
    while(1) {
     $542 = (($i$036) + 1)|0;
     $543 = ($542>>>0)<($354>>>0);
     if ($543) {
      $i$036 = $542;
     } else {
      $$lcssa29 = $546;$$lcssa31 = $547;$$lcssa33 = $548;$dmin$1$lcssa = $dmin$0;
      break L10;
     }
    }
   } else {
    $549 = Math_fround(0.0);$550 = $548;$551 = $547;$552 = $546;$dmin$137$us = $dmin$0;$i$036$us = 0;
   }
   L15: while(1) {
    $373 = ((($mSA0) + (($i$036$us*12)|0)|0) + 8|0);
    $378 = ((($mSA0) + (($i$036$us*12)|0)|0) + 12|0);
    $387 = ((($mSA0) + (($i$036$us*12)|0)|0) + 4|0);
    $557 = $552;$558 = $551;$559 = $550;$560 = $549;$dmin$223$us = $dmin$137$us;$j$024$us = 0;
    while(1) {
     $372 = Math_fround(HEAPF32[$373>>2]);
     $374 = ((($mSA1) + (($j$024$us*12)|0)|0) + 12|0);
     $375 = Math_fround(HEAPF32[$374>>2]);
     $376 = Math_fround($372 * $375);
     $377 = Math_fround(HEAPF32[$378>>2]);
     $379 = ((($mSA1) + (($j$024$us*12)|0)|0) + 8|0);
     $380 = Math_fround(HEAPF32[$379>>2]);
     $381 = Math_fround($377 * $380);
     $382 = Math_fround($376 - $381);
     $383 = ((($mSA1) + (($j$024$us*12)|0)|0) + 4|0);
     $384 = Math_fround(HEAPF32[$383>>2]);
     $385 = Math_fround($377 * $384);
     $386 = Math_fround(HEAPF32[$387>>2]);
     $388 = Math_fround($375 * $386);
     $389 = Math_fround($385 - $388);
     $390 = Math_fround($380 * $386);
     $391 = Math_fround($372 * $384);
     $392 = Math_fround($390 - $391);
     HEAPF32[$sepAxis>>2] = $382;
     HEAPF32[$358>>2] = $389;
     HEAPF32[$359>>2] = $392;
     $fabsf$i$i$i$us = (Math_fround(Math_abs((Math_fround($382)))));
     $393 = +$fabsf$i$i$i$us;
     $394 = $393 > 9.99999999999999954748E-7;
     if ($394) {
      label = 11;
     } else {
      $fabsf$i$i1$i$us = (Math_fround(Math_abs((Math_fround($389)))));
      $395 = +$fabsf$i$i1$i$us;
      $396 = $395 > 9.99999999999999954748E-7;
      if ($396) {
       label = 11;
      } else {
       $fabsf$i$i2$i$us = (Math_fround(Math_abs((Math_fround($392)))));
       $397 = +$fabsf$i$i2$i$us;
       $398 = $397 > 9.99999999999999954748E-7;
       if ($398) {
        label = 11;
       } else {
        $553 = $560;$554 = $559;$555 = $558;$556 = $557;$dmin$3$us = $dmin$223$us;
       }
      }
     }
     if ((label|0) == 11) {
      label = 0;
      $399 = Math_fround($382 * $382);
      $400 = Math_fround($389 * $389);
      $401 = Math_fround($399 + $400);
      $402 = Math_fround($392 * $392);
      $403 = Math_fround($401 + $402);
      $404 = $403 > Math_fround(0.0);
      if ($404) {
       $405 = (Math_fround(Math_sqrt((Math_fround($403)))));
       $406 = Math_fround(Math_fround(1.0) / $405);
       $407 = Math_fround($382 * $406);
       $408 = Math_fround($389 * $406);
       $409 = Math_fround($392 * $406);
       $410 = $407;$411 = $408;$412 = $409;
      } else {
       $410 = Math_fround(0.0);$411 = Math_fround(0.0);$412 = Math_fround(0.0);
      }
      HEAPF32[$sepAxis>>2] = $410;
      HEAPF32[$358>>2] = $411;
      HEAPF32[$359>>2] = $412;
      $413 = Math_fround(HEAPF32[$delta>>2]);
      $414 = Math_fround(HEAPF32[$6>>2]);
      $415 = Math_fround(HEAPF32[$12>>2]);
      $416 = Math_fround(HEAPF32[$world0>>2]);
      $417 = Math_fround($416 * $410);
      $418 = Math_fround(HEAPF32[$4>>2]);
      $419 = Math_fround($418 * $411);
      $420 = Math_fround($417 + $419);
      $421 = Math_fround(HEAPF32[$10>>2]);
      $422 = Math_fround($412 * $421);
      $423 = Math_fround($420 + $422);
      $424 = Math_fround(HEAPF32[$16>>2]);
      $425 = Math_fround($410 * $424);
      $426 = Math_fround(HEAPF32[$19>>2]);
      $427 = Math_fround($411 * $426);
      $428 = Math_fround($425 + $427);
      $429 = Math_fround(HEAPF32[$23>>2]);
      $430 = Math_fround($412 * $429);
      $431 = Math_fround($428 + $430);
      $432 = Math_fround(HEAPF32[$27>>2]);
      $433 = Math_fround($410 * $432);
      $434 = Math_fround(HEAPF32[$30>>2]);
      $435 = Math_fround($411 * $434);
      $436 = Math_fround($433 + $435);
      $437 = Math_fround(HEAPF32[$34>>2]);
      $438 = Math_fround($412 * $437);
      $439 = Math_fround($436 + $438);
      $440 = (HEAPF32[tempDoublePtr>>2]=$423,HEAP32[tempDoublePtr>>2]|0);
      $441 = (HEAPF32[tempDoublePtr>>2]=$431,HEAP32[tempDoublePtr>>2]|0);
      $442 = (HEAPF32[tempDoublePtr>>2]=$439,HEAP32[tempDoublePtr>>2]|0);
      $443 = Math_fround(HEAPF32[$world1>>2]);
      $444 = Math_fround($410 * $443);
      $445 = Math_fround(HEAPF32[$51>>2]);
      $446 = Math_fround($411 * $445);
      $447 = Math_fround($444 + $446);
      $448 = Math_fround(HEAPF32[$56>>2]);
      $449 = Math_fround($412 * $448);
      $450 = Math_fround($447 + $449);
      $451 = Math_fround(HEAPF32[$61>>2]);
      $452 = Math_fround($410 * $451);
      $453 = Math_fround(HEAPF32[$64>>2]);
      $454 = Math_fround($411 * $453);
      $455 = Math_fround($452 + $454);
      $456 = Math_fround(HEAPF32[$68>>2]);
      $457 = Math_fround($412 * $456);
      $458 = Math_fround($455 + $457);
      $459 = Math_fround(HEAPF32[$72>>2]);
      $460 = Math_fround($410 * $459);
      $461 = Math_fround(HEAPF32[$75>>2]);
      $462 = Math_fround($411 * $461);
      $463 = Math_fround($460 + $462);
      $464 = Math_fround(HEAPF32[$79>>2]);
      $465 = Math_fround($412 * $464);
      $466 = Math_fround($463 + $465);
      $467 = (HEAPF32[tempDoublePtr>>2]=$450,HEAP32[tempDoublePtr>>2]|0);
      $468 = (HEAPF32[tempDoublePtr>>2]=$458,HEAP32[tempDoublePtr>>2]|0);
      $469 = (HEAPF32[tempDoublePtr>>2]=$466,HEAP32[tempDoublePtr>>2]|0);
      $470 = Math_fround($413 * $410);
      $471 = Math_fround($414 * $411);
      $472 = Math_fround(-$471);
      $473 = Math_fround($472 - $470);
      $474 = Math_fround($412 * $415);
      $475 = Math_fround($473 - $474);
      $476 = HEAP32[$360>>2]|0;
      $477 = $440 & -2147483648;
      $478 = $476 | $477;
      $479 = HEAP32[$361>>2]|0;
      $480 = $441 & -2147483648;
      $481 = $479 | $480;
      $482 = HEAP32[$362>>2]|0;
      $483 = $442 & -2147483648;
      $484 = $482 | $483;
      $485 = HEAP32[$363>>2]|0;
      $486 = $467 & -2147483648;
      $487 = $485 | $486;
      $488 = HEAP32[$364>>2]|0;
      $489 = $468 & -2147483648;
      $490 = $488 | $489;
      $491 = HEAP32[$365>>2]|0;
      $492 = $469 & -2147483648;
      $493 = $491 | $492;
      $494 = (HEAP32[tempDoublePtr>>2]=$478,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $495 = Math_fround($423 * $494);
      $496 = (HEAP32[tempDoublePtr>>2]=$481,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $497 = Math_fround($431 * $496);
      $498 = Math_fround($495 + $497);
      $499 = (HEAP32[tempDoublePtr>>2]=$484,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $500 = Math_fround($439 * $499);
      $501 = Math_fround($498 + $500);
      $502 = (HEAP32[tempDoublePtr>>2]=$487,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $503 = Math_fround($450 * $502);
      $504 = (HEAP32[tempDoublePtr>>2]=$490,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $505 = Math_fround($458 * $504);
      $506 = Math_fround($503 + $505);
      $507 = (HEAP32[tempDoublePtr>>2]=$493,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $508 = Math_fround($466 * $507);
      $509 = Math_fround($506 + $508);
      $510 = Math_fround(HEAPF32[$366>>2]);
      $511 = $501 > $510;
      $512 = $511 ? $501 : $510;
      $513 = Math_fround(HEAPF32[$367>>2]);
      $514 = $509 > $513;
      $515 = $514 ? $509 : $513;
      $516 = Math_fround($512 + $515);
      $517 = Math_fround($475 + $516);
      $518 = Math_fround($516 - $475);
      $519 = $517 < $518;
      $520 = $519 ? $517 : $518;
      $not$$i$us = !($520 > $dmin$223$us);
      if ($not$$i$us) {
       $521 = HEAP32[$368>>2]|0;
       FUNCTION_TABLE_viiiiii[$521 & 255]($polyData0,$sepAxis,$world0,$scaling0,$min0$i,$max0$i);
       $522 = Math_fround(HEAPF32[$min0$i>>2]);
       $523 = Math_fround(HEAPF32[$max0$i>>2]);
       $524 = HEAP32[$369>>2]|0;
       FUNCTION_TABLE_viiiiii[$524 & 255]($polyData1,$sepAxis,$world1,$scaling1,$min1$i$i,$max1$i$i);
       $525 = Math_fround($523 + $contactDistance);
       $526 = Math_fround(HEAPF32[$min1$i$i>>2]);
       $527 = $525 < $526;
       if ($527) {
        $$0$i$i$us = 0;$536 = $560;
       } else {
        $528 = Math_fround(HEAPF32[$max1$i$i>>2]);
        $529 = Math_fround($528 + $contactDistance);
        $530 = $529 < $522;
        if ($530) {
         $$0$i$i$us = 0;$536 = $560;
        } else {
         $531 = Math_fround($523 - $526);
         $532 = Math_fround($528 - $522);
         $533 = $531 < $532;
         $534 = $533 ? $531 : $532;
         $$0$i$i$us = 1;$536 = $534;
        }
       }
       if (!($$0$i$i$us)) {
        $$1 = 0;
        break L15;
       }
       $535 = $536 < $dmin$223$us;
       if ($535) {
        $537 = Math_fround(HEAPF32[$sepAxis>>2]);
        $538 = Math_fround(HEAPF32[$358>>2]);
        $539 = Math_fround(HEAPF32[$359>>2]);
        HEAP32[$code>>2] = 2;
        $553 = $536;$554 = $537;$555 = $538;$556 = $539;$dmin$3$us = $536;
       } else {
        $553 = $536;$554 = $559;$555 = $558;$556 = $557;$dmin$3$us = $dmin$223$us;
       }
      } else {
       $553 = $560;$554 = $559;$555 = $558;$556 = $557;$dmin$3$us = $dmin$223$us;
      }
     }
     $540 = (($j$024$us) + 1)|0;
     $541 = ($540>>>0)<($355>>>0);
     if ($541) {
      $557 = $556;$558 = $555;$559 = $554;$560 = $553;$dmin$223$us = $dmin$3$us;$j$024$us = $540;
     } else {
      break;
     }
    }
    $370 = (($i$036$us) + 1)|0;
    $371 = ($370>>>0)<($354>>>0);
    if ($371) {
     $549 = $553;$550 = $554;$551 = $555;$552 = $556;$dmin$137$us = $dmin$3$us;$i$036$us = $370;
    } else {
     $$lcssa29 = $556;$$lcssa31 = $555;$$lcssa33 = $554;$dmin$1$lcssa = $dmin$3$us;
     break L10;
    }
   }
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 HEAPF32[$depth>>2] = $dmin$1$lcssa;
 HEAPF32[$sep>>2] = $$lcssa33;
 $544 = (($sep) + 4|0);
 HEAPF32[$544>>2] = $$lcssa31;
 $545 = (($sep) + 8|0);
 HEAPF32[$545>>2] = $$lcssa29;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZL27PxcTestFacesSepAxesBackfaceRKN5physx2Gu13PolygonalDataES3_RKNS_2Cm8Matrix34ES7_RKNS4_23FastVertex2ShapeScalingESA_S7_RKNS_6PxVec3ERfRSB_RjPjSG_fSD_($polyData0,$polyData1,$world0,$world1,$scaling0,$scaling1,$m1to0,$delta$0$0$val,$delta$0$1$val,$delta$0$2$val,$dmin,$sep,$id,$indices_,$numIndices,$contactDistance,$worldDelta) {
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $world0 = $world0|0;
 $world1 = $world1|0;
 $scaling0 = $scaling0|0;
 $scaling1 = $scaling1|0;
 $m1to0 = $m1to0|0;
 $delta$0$0$val = Math_fround($delta$0$0$val);
 $delta$0$1$val = Math_fround($delta$0$1$val);
 $delta$0$2$val = Math_fround($delta$0$2$val);
 $dmin = $dmin|0;
 $sep = $sep|0;
 $id = $id|0;
 $indices_ = $indices_|0;
 $numIndices = $numIndices|0;
 $contactDistance = Math_fround($contactDistance);
 $worldDelta = $worldDelta|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0;
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0;
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$02 = 0, $indices$0$lcssa = 0, $indices$04 = 0, $indices$1 = 0, $max1$i = 0, $min1$i = 0, $not$$i = 0;
 var $offset$05 = 0, $shapeSpaceNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $min1$i = sp + 16|0;
 $max1$i = sp;
 $shapeSpaceNormal = sp + 4|0;
 HEAP32[$id>>2] = -1;
 $0 = (($polyData0) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($polyData0) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($polyData0) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($scaling0) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $delta$0$0$val);
 $9 = (($scaling0) + 40|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $delta$0$0$val);
 $12 = (($scaling0) + 44|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $delta$0$0$val);
 $15 = (($scaling0) + 48|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $delta$0$1$val);
 $18 = (($scaling0) + 52|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $delta$0$1$val);
 $21 = (($scaling0) + 56|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $delta$0$1$val);
 $24 = Math_fround($8 + $17);
 $25 = Math_fround($11 + $20);
 $26 = Math_fround($14 + $23);
 $27 = (($scaling0) + 60|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $delta$0$2$val);
 $30 = (($scaling0) + 64|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $delta$0$2$val);
 $33 = (($scaling0) + 68|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $delta$0$2$val);
 $36 = Math_fround($24 + $29);
 $37 = Math_fround($25 + $32);
 $38 = Math_fround($26 + $35);
 $39 = ($1*20)|0;
 $40 = ($39|0)==(0);
 if (!($40)) {
  $offset$05 = 0;
  while(1) {
   $73 = (($5) + ($offset$05)|0);
   $74 = (($offset$05) + 128)|0;
   $75 = ($74>>>0)<($39>>>0);
   if ($75) {
    $offset$05 = $74;
   } else {
    break;
   }
  }
 }
 $41 = ($1|0)==(0);
 L6: do {
  if ($41) {
   $indices$0$lcssa = $indices_;
  } else {
   $42 = (($shapeSpaceNormal) + 4|0);
   $43 = (($shapeSpaceNormal) + 8|0);
   $44 = (($world0) + 4|0);
   $45 = (($world0) + 8|0);
   $46 = (($world0) + 12|0);
   $47 = (($world0) + 16|0);
   $48 = (($world0) + 20|0);
   $49 = (($world0) + 24|0);
   $50 = (($world0) + 28|0);
   $51 = (($world0) + 32|0);
   $52 = (($world1) + 4|0);
   $53 = (($world1) + 8|0);
   $54 = (($world1) + 12|0);
   $55 = (($world1) + 16|0);
   $56 = (($world1) + 20|0);
   $57 = (($world1) + 24|0);
   $58 = (($world1) + 28|0);
   $59 = (($world1) + 32|0);
   $60 = (($worldDelta) + 4|0);
   $61 = (($worldDelta) + 8|0);
   $62 = (($polyData0) + 44|0);
   $63 = (($polyData0) + 48|0);
   $64 = (($polyData0) + 52|0);
   $65 = (($polyData1) + 44|0);
   $66 = (($polyData1) + 48|0);
   $67 = (($polyData1) + 52|0);
   $68 = (($polyData0) + 40|0);
   $69 = (($polyData1) + 40|0);
   $70 = (($polyData1) + 64|0);
   $71 = (($sep) + 4|0);
   $72 = (($sep) + 8|0);
   $i$02 = 0;$indices$04 = $indices_;
   while(1) {
    $76 = (($5) + (($i$02*20)|0)|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = Math_fround($36 * $77);
    $79 = ((($5) + (($i$02*20)|0)|0) + 4|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = Math_fround($37 * $80);
    $82 = Math_fround($78 + $81);
    $83 = ((($5) + (($i$02*20)|0)|0) + 8|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = Math_fround($38 * $84);
    $86 = Math_fround($82 + $85);
    $87 = $86 < Math_fround(0.0);
    if ($87) {
     $indices$1 = $indices$04;
    } else {
     $88 = Math_fround(HEAPF32[$6>>2]);
     $89 = Math_fround($77 * $88);
     $90 = Math_fround(HEAPF32[$9>>2]);
     $91 = Math_fround($77 * $90);
     $92 = Math_fround(HEAPF32[$12>>2]);
     $93 = Math_fround($77 * $92);
     $94 = Math_fround(HEAPF32[$15>>2]);
     $95 = Math_fround($80 * $94);
     $96 = Math_fround(HEAPF32[$18>>2]);
     $97 = Math_fround($80 * $96);
     $98 = Math_fround(HEAPF32[$21>>2]);
     $99 = Math_fround($80 * $98);
     $100 = Math_fround($89 + $95);
     $101 = Math_fround($91 + $97);
     $102 = Math_fround($93 + $99);
     $103 = Math_fround(HEAPF32[$27>>2]);
     $104 = Math_fround($84 * $103);
     $105 = Math_fround(HEAPF32[$30>>2]);
     $106 = Math_fround($84 * $105);
     $107 = Math_fround(HEAPF32[$33>>2]);
     $108 = Math_fround($84 * $107);
     $109 = Math_fround($100 + $104);
     $110 = Math_fround($101 + $106);
     $111 = Math_fround($102 + $108);
     HEAPF32[$shapeSpaceNormal>>2] = $109;
     HEAPF32[$42>>2] = $110;
     HEAPF32[$43>>2] = $111;
     $112 = Math_fround($109 * $109);
     $113 = Math_fround($110 * $110);
     $114 = Math_fround($112 + $113);
     $115 = Math_fround($111 * $111);
     $116 = Math_fround($115 + $114);
     $117 = (Math_fround(Math_sqrt((Math_fround($116)))));
     $118 = $117 > Math_fround(0.0);
     if ($118) {
      $119 = Math_fround(Math_fround(1.0) / $117);
      $120 = Math_fround($109 * $119);
      HEAPF32[$shapeSpaceNormal>>2] = $120;
      $121 = Math_fround($110 * $119);
      HEAPF32[$42>>2] = $121;
      $122 = Math_fround($111 * $119);
      HEAPF32[$43>>2] = $122;
      $125 = $120;$132 = $121;$142 = $122;
     } else {
      $125 = $109;$132 = $110;$142 = $111;
     }
     $123 = Math_fround(HEAPF32[$world0>>2]);
     $124 = Math_fround($125 * $123);
     $126 = Math_fround(HEAPF32[$44>>2]);
     $127 = Math_fround($125 * $126);
     $128 = Math_fround(HEAPF32[$45>>2]);
     $129 = Math_fround($125 * $128);
     $130 = Math_fround(HEAPF32[$46>>2]);
     $131 = Math_fround($132 * $130);
     $133 = Math_fround(HEAPF32[$47>>2]);
     $134 = Math_fround($132 * $133);
     $135 = Math_fround(HEAPF32[$48>>2]);
     $136 = Math_fround($132 * $135);
     $137 = Math_fround($124 + $131);
     $138 = Math_fround($127 + $134);
     $139 = Math_fround($129 + $136);
     $140 = Math_fround(HEAPF32[$49>>2]);
     $141 = Math_fround($142 * $140);
     $143 = Math_fround(HEAPF32[$50>>2]);
     $144 = Math_fround($142 * $143);
     $145 = Math_fround(HEAPF32[$51>>2]);
     $146 = Math_fround($142 * $145);
     $147 = Math_fround($137 + $141);
     $148 = Math_fround($138 + $144);
     $149 = Math_fround($139 + $146);
     $150 = Math_fround(HEAPF32[$dmin>>2]);
     $151 = Math_fround($123 * $147);
     $152 = Math_fround($126 * $148);
     $153 = Math_fround($151 + $152);
     $154 = Math_fround($128 * $149);
     $155 = Math_fround($153 + $154);
     $156 = Math_fround($130 * $147);
     $157 = Math_fround($133 * $148);
     $158 = Math_fround($156 + $157);
     $159 = Math_fround($135 * $149);
     $160 = Math_fround($158 + $159);
     $161 = Math_fround($140 * $147);
     $162 = Math_fround($143 * $148);
     $163 = Math_fround($161 + $162);
     $164 = Math_fround($145 * $149);
     $165 = Math_fround($163 + $164);
     $166 = (HEAPF32[tempDoublePtr>>2]=$155,HEAP32[tempDoublePtr>>2]|0);
     $167 = (HEAPF32[tempDoublePtr>>2]=$160,HEAP32[tempDoublePtr>>2]|0);
     $168 = (HEAPF32[tempDoublePtr>>2]=$165,HEAP32[tempDoublePtr>>2]|0);
     $169 = Math_fround(HEAPF32[$world1>>2]);
     $170 = Math_fround($147 * $169);
     $171 = Math_fround(HEAPF32[$52>>2]);
     $172 = Math_fround($148 * $171);
     $173 = Math_fround($170 + $172);
     $174 = Math_fround(HEAPF32[$53>>2]);
     $175 = Math_fround($149 * $174);
     $176 = Math_fround($173 + $175);
     $177 = Math_fround(HEAPF32[$54>>2]);
     $178 = Math_fround($147 * $177);
     $179 = Math_fround(HEAPF32[$55>>2]);
     $180 = Math_fround($148 * $179);
     $181 = Math_fround($178 + $180);
     $182 = Math_fround(HEAPF32[$56>>2]);
     $183 = Math_fround($149 * $182);
     $184 = Math_fround($181 + $183);
     $185 = Math_fround(HEAPF32[$57>>2]);
     $186 = Math_fround($147 * $185);
     $187 = Math_fround(HEAPF32[$58>>2]);
     $188 = Math_fround($148 * $187);
     $189 = Math_fround($186 + $188);
     $190 = Math_fround(HEAPF32[$59>>2]);
     $191 = Math_fround($149 * $190);
     $192 = Math_fround($189 + $191);
     $193 = (HEAPF32[tempDoublePtr>>2]=$176,HEAP32[tempDoublePtr>>2]|0);
     $194 = (HEAPF32[tempDoublePtr>>2]=$184,HEAP32[tempDoublePtr>>2]|0);
     $195 = (HEAPF32[tempDoublePtr>>2]=$192,HEAP32[tempDoublePtr>>2]|0);
     $196 = Math_fround(HEAPF32[$worldDelta>>2]);
     $197 = Math_fround($147 * $196);
     $198 = Math_fround(HEAPF32[$60>>2]);
     $199 = Math_fround($148 * $198);
     $200 = Math_fround($197 + $199);
     $201 = Math_fround(HEAPF32[$61>>2]);
     $202 = Math_fround($149 * $201);
     $203 = Math_fround($200 + $202);
     $204 = HEAP32[$62>>2]|0;
     $205 = $166 & -2147483648;
     $206 = $204 | $205;
     $207 = HEAP32[$63>>2]|0;
     $208 = $167 & -2147483648;
     $209 = $207 | $208;
     $210 = HEAP32[$64>>2]|0;
     $211 = $168 & -2147483648;
     $212 = $210 | $211;
     $213 = HEAP32[$65>>2]|0;
     $214 = $193 & -2147483648;
     $215 = $213 | $214;
     $216 = HEAP32[$66>>2]|0;
     $217 = $194 & -2147483648;
     $218 = $216 | $217;
     $219 = HEAP32[$67>>2]|0;
     $220 = $195 & -2147483648;
     $221 = $219 | $220;
     $222 = (HEAP32[tempDoublePtr>>2]=$206,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $223 = Math_fround($155 * $222);
     $224 = (HEAP32[tempDoublePtr>>2]=$209,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $225 = Math_fround($160 * $224);
     $226 = Math_fround($223 + $225);
     $227 = (HEAP32[tempDoublePtr>>2]=$212,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $228 = Math_fround($165 * $227);
     $229 = Math_fround($226 + $228);
     $230 = (HEAP32[tempDoublePtr>>2]=$215,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $231 = Math_fround($176 * $230);
     $232 = (HEAP32[tempDoublePtr>>2]=$218,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $233 = Math_fround($184 * $232);
     $234 = Math_fround($231 + $233);
     $235 = (HEAP32[tempDoublePtr>>2]=$221,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $236 = Math_fround($192 * $235);
     $237 = Math_fround($234 + $236);
     $238 = Math_fround(HEAPF32[$68>>2]);
     $239 = $229 > $238;
     $240 = $239 ? $229 : $238;
     $241 = Math_fround(HEAPF32[$69>>2]);
     $242 = $237 > $241;
     $243 = $242 ? $237 : $241;
     $244 = Math_fround($240 + $243);
     $245 = Math_fround($203 + $244);
     $246 = Math_fround($244 - $203);
     $247 = $245 < $246;
     $248 = $247 ? $245 : $246;
     $not$$i = !($248 > $150);
     if ($not$$i) {
      $249 = (($indices$04) + 4|0);
      HEAP32[$indices$04>>2] = $i$02;
      $250 = Math_fround(Math_fround(1.0) / $117);
      $251 = ((($5) + (($i$02*20)|0)|0) + 19|0);
      $252 = HEAP8[$251>>0]|0;
      $253 = $252&255;
      $254 = Math_fround(HEAPF32[$76>>2]);
      $255 = (($3) + (($253*12)|0)|0);
      $256 = Math_fround(HEAPF32[$255>>2]);
      $257 = Math_fround($254 * $256);
      $258 = Math_fround(HEAPF32[$79>>2]);
      $259 = ((($3) + (($253*12)|0)|0) + 4|0);
      $260 = Math_fround(HEAPF32[$259>>2]);
      $261 = Math_fround($258 * $260);
      $262 = Math_fround($257 + $261);
      $263 = Math_fround(HEAPF32[$83>>2]);
      $264 = ((($3) + (($253*12)|0)|0) + 8|0);
      $265 = Math_fround(HEAPF32[$264>>2]);
      $266 = Math_fround($263 * $265);
      $267 = Math_fround($262 + $266);
      $268 = Math_fround($250 * $267);
      $269 = ((($5) + (($i$02*20)|0)|0) + 12|0);
      $270 = Math_fround(HEAPF32[$269>>2]);
      $271 = Math_fround($250 * $270);
      $272 = Math_fround(-$271);
      $273 = HEAP32[$70>>2]|0;
      FUNCTION_TABLE_viiiiii[$273 & 255]($polyData1,$shapeSpaceNormal,$m1to0,$scaling1,$min1$i,$max1$i);
      $274 = Math_fround($contactDistance - $271);
      $275 = Math_fround(HEAPF32[$min1$i>>2]);
      $276 = $274 < $275;
      if ($276) {
       $$0 = 0;
       label = 16;
       break;
      }
      $277 = Math_fround(HEAPF32[$max1$i>>2]);
      $278 = Math_fround($277 + $contactDistance);
      $279 = $278 < $268;
      if ($279) {
       $$0 = 0;
       label = 16;
       break;
      }
      $280 = Math_fround($272 - $275);
      $281 = Math_fround($277 - $268);
      $282 = $280 < $281;
      $283 = $282 ? $280 : $281;
      $284 = Math_fround(HEAPF32[$dmin>>2]);
      $285 = $283 < $284;
      if ($285) {
       HEAPF32[$sep>>2] = $147;
       HEAPF32[$71>>2] = $148;
       HEAPF32[$72>>2] = $149;
       HEAPF32[$dmin>>2] = $283;
       HEAP32[$id>>2] = $i$02;
       $indices$1 = $249;
      } else {
       $indices$1 = $249;
      }
     } else {
      $indices$1 = $indices$04;
     }
    }
    $286 = (($i$02) + 1)|0;
    $287 = ($286>>>0)<($1>>>0);
    if ($287) {
     $i$02 = $286;$indices$04 = $indices$1;
    } else {
     $indices$0$lcssa = $indices$1;
     break L6;
    }
   }
   if ((label|0) == 16) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $288 = $indices$0$lcssa;
 $289 = $indices_;
 $290 = (($288) - ($289))|0;
 $291 = $290 >> 2;
 HEAP32[$numIndices>>2] = $291;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL21PxcFindSeparatingAxesRN5physx2Gu14SeparatingAxesEPKjjRKNS0_13PolygonalDataERKNS_2Cm8Matrix34ERKNS_7PxPlaneESB_RKNS_9PxBounds3EfRKNS8_23FastVertex2ShapeScalingE($sa,$indices,$numPolygons,$polyData$0$4$val,$polyData$0$5$val,$polyData$0$6$val,$world0,$plane,$m0to1,$aabb,$contactDistance,$scaling) {
 $sa = $sa|0;
 $indices = $indices|0;
 $numPolygons = $numPolygons|0;
 $polyData$0$4$val = $polyData$0$4$val|0;
 $polyData$0$5$val = $polyData$0$5$val|0;
 $polyData$0$6$val = $polyData$0$6$val|0;
 $world0 = $world0|0;
 $plane = $plane|0;
 $m0to1 = $m0to1|0;
 $aabb = $aabb|0;
 $contactDistance = Math_fround($contactDistance);
 $scaling = $scaling|0;
 var $$ = 0, $$012 = 0, $$in = 0, $$pre = Math_fround(0), $$pre14 = Math_fround(0), $$pre15 = Math_fround(0), $$pre16 = Math_fround(0), $$pre17 = Math_fround(0), $$pre18 = Math_fround(0), $$pre19 = Math_fround(0), $$pre20 = Math_fround(0), $$pre21 = Math_fround(0), $$pre22 = Math_fround(0), $$pre23 = Math_fround(0), $$pre24 = Math_fround(0), $$pre25 = Math_fround(0), $$sum = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0);
 var $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0);
 var $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0);
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0);
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0);
 var $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0);
 var $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0);
 var $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0);
 var $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0);
 var $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0;
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $b0$0$in10 = 0, $brmerge = 0, $currentEdge = 0, $exitcond = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0);
 var $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $j$011 = 0, $not$$i = 0, $phitmp = 0, $storemerge = Math_fround(0), $storemerge26 = Math_fround(0), $storemerge27 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $currentEdge = sp;
 $0 = ($numPolygons|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($scaling) + 4|0);
 $2 = (($scaling) + 8|0);
 $3 = (($scaling) + 12|0);
 $4 = (($scaling) + 16|0);
 $5 = (($scaling) + 20|0);
 $6 = (($scaling) + 24|0);
 $7 = (($scaling) + 28|0);
 $8 = (($scaling) + 32|0);
 $9 = (($plane) + 4|0);
 $10 = (($plane) + 8|0);
 $11 = (($plane) + 12|0);
 $12 = (($m0to1) + 12|0);
 $13 = (($m0to1) + 24|0);
 $14 = (($aabb) + 12|0);
 $15 = (($m0to1) + 36|0);
 $16 = (($m0to1) + 4|0);
 $17 = (($12) + 4|0);
 $18 = (($13) + 4|0);
 $19 = (($aabb) + 16|0);
 $20 = (($aabb) + 4|0);
 $21 = (($15) + 4|0);
 $22 = (($m0to1) + 8|0);
 $23 = (($12) + 8|0);
 $24 = (($13) + 8|0);
 $25 = (($aabb) + 20|0);
 $26 = (($aabb) + 8|0);
 $27 = (($15) + 8|0);
 $28 = (($world0) + 4|0);
 $29 = (($world0) + 8|0);
 $30 = (($world0) + 12|0);
 $31 = (($world0) + 16|0);
 $32 = (($world0) + 20|0);
 $33 = (($world0) + 24|0);
 $34 = (($world0) + 28|0);
 $35 = (($world0) + 32|0);
 $36 = (($currentEdge) + 4|0);
 $37 = (($currentEdge) + 8|0);
 $$012 = $indices;$$in = $numPolygons;
 while(1) {
  $39 = (($$in) + -1)|0;
  $40 = (($$012) + 4|0);
  $41 = HEAP32[$$012>>2]|0;
  $42 = ((($polyData$0$4$val) + (($41*20)|0)|0) + 16|0);
  $43 = HEAP16[$42>>1]|0;
  $44 = $43&65535;
  $45 = (($polyData$0$6$val) + ($44)|0);
  $46 = ((($polyData$0$4$val) + (($41*20)|0)|0) + 18|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = $47&255;
  $49 = HEAP8[$45>>0]|0;
  $50 = $49&255;
  $51 = (($polyData$0$5$val) + (($50*12)|0)|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = Math_fround(HEAPF32[$scaling>>2]);
  $54 = Math_fround($52 * $53);
  $55 = Math_fround(HEAPF32[$1>>2]);
  $56 = Math_fround($52 * $55);
  $57 = Math_fround(HEAPF32[$2>>2]);
  $58 = Math_fround($52 * $57);
  $59 = ((($polyData$0$5$val) + (($50*12)|0)|0) + 4|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround(HEAPF32[$3>>2]);
  $62 = Math_fround($60 * $61);
  $63 = Math_fround(HEAPF32[$4>>2]);
  $64 = Math_fround($60 * $63);
  $65 = Math_fround(HEAPF32[$5>>2]);
  $66 = Math_fround($60 * $65);
  $67 = Math_fround($54 + $62);
  $68 = Math_fround($56 + $64);
  $69 = Math_fround($58 + $66);
  $70 = ((($polyData$0$5$val) + (($50*12)|0)|0) + 8|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = Math_fround(HEAPF32[$6>>2]);
  $73 = Math_fround($71 * $72);
  $74 = Math_fround(HEAPF32[$7>>2]);
  $75 = Math_fround($71 * $74);
  $76 = Math_fround(HEAPF32[$8>>2]);
  $77 = Math_fround($71 * $76);
  $78 = Math_fround($67 + $73);
  $79 = Math_fround($68 + $75);
  $80 = Math_fround($69 + $77);
  $81 = ($47<<24>>24)==(0);
  L6: do {
   if (!($81)) {
    $82 = Math_fround(HEAPF32[$9>>2]);
    $83 = Math_fround(HEAPF32[$plane>>2]);
    $84 = Math_fround(HEAPF32[$10>>2]);
    $85 = Math_fround($79 * $82);
    $86 = Math_fround($78 * $83);
    $87 = Math_fround($80 * $84);
    $88 = Math_fround($86 + $85);
    $89 = Math_fround(HEAPF32[$11>>2]);
    $90 = Math_fround($88 + $87);
    $91 = Math_fround($89 + $90);
    $92 = $91 <= $contactDistance;
    $100 = $53;$102 = $55;$104 = $57;$108 = $61;$110 = $63;$112 = $65;$119 = $72;$121 = $74;$123 = $76;$128 = $83;$130 = $82;$133 = $84;$136 = $89;$139 = $78;$143 = $79;$148 = $80;$b0$0$in10 = $92;$j$011 = 1;
    while(1) {
     $93 = ($j$011>>>0)>=($48>>>0);
     $$ = $93 ? 0 : $j$011;
     $$sum = (($$) + ($44))|0;
     $94 = (($polyData$0$6$val) + ($$sum)|0);
     $95 = HEAP8[$94>>0]|0;
     $96 = $95&255;
     $97 = (($polyData$0$5$val) + (($96*12)|0)|0);
     $98 = Math_fround(HEAPF32[$97>>2]);
     $99 = Math_fround($98 * $100);
     $101 = Math_fround($98 * $102);
     $103 = Math_fround($98 * $104);
     $105 = ((($polyData$0$5$val) + (($96*12)|0)|0) + 4|0);
     $106 = Math_fround(HEAPF32[$105>>2]);
     $107 = Math_fround($106 * $108);
     $109 = Math_fround($106 * $110);
     $111 = Math_fround($106 * $112);
     $113 = Math_fround($99 + $107);
     $114 = Math_fround($101 + $109);
     $115 = Math_fround($103 + $111);
     $116 = ((($polyData$0$5$val) + (($96*12)|0)|0) + 8|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = Math_fround($117 * $119);
     $120 = Math_fround($117 * $121);
     $122 = Math_fround($117 * $123);
     $124 = Math_fround($113 + $118);
     $125 = Math_fround($114 + $120);
     $126 = Math_fround($115 + $122);
     $127 = Math_fround($124 * $128);
     $129 = Math_fround($125 * $130);
     $131 = Math_fround($127 + $129);
     $132 = Math_fround($126 * $133);
     $134 = Math_fround($131 + $132);
     $135 = Math_fround($136 + $134);
     $137 = $135 <= $contactDistance;
     $brmerge = $b0$0$in10 | $137;
     if ($brmerge) {
      $138 = Math_fround($124 - $139);
      $140 = Math_fround(HEAPF32[$m0to1>>2]);
      $141 = Math_fround($138 * $140);
      $142 = Math_fround($125 - $143);
      $144 = Math_fround(HEAPF32[$12>>2]);
      $145 = Math_fround($142 * $144);
      $146 = Math_fround($141 + $145);
      $147 = Math_fround($126 - $148);
      $149 = Math_fround(HEAPF32[$13>>2]);
      $150 = Math_fround($147 * $149);
      $151 = Math_fround($146 + $150);
      $152 = Math_fround(HEAPF32[$14>>2]);
      $153 = Math_fround(HEAPF32[$aabb>>2]);
      $154 = Math_fround($152 - $153);
      $155 = Math_fround($139 + $124);
      $156 = Math_fround($155 * $140);
      $157 = Math_fround($143 + $125);
      $158 = Math_fround($157 * $144);
      $159 = Math_fround($156 + $158);
      $160 = Math_fround($148 + $126);
      $161 = Math_fround($160 * $149);
      $162 = Math_fround($159 + $161);
      $163 = Math_fround(HEAPF32[$15>>2]);
      $164 = Math_fround($163 * Math_fround(2.0));
      $165 = Math_fround($162 + $164);
      $166 = Math_fround($152 + $153);
      $167 = Math_fround($165 - $166);
      $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($151)))));
      $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($167)))));
      $168 = Math_fround($154 + $fabsf$i$i5$i);
      $169 = $fabsf$i$i6$i > $168;
      if (!($169)) {
       $170 = Math_fround(HEAPF32[$16>>2]);
       $171 = Math_fround($138 * $170);
       $172 = Math_fround(HEAPF32[$17>>2]);
       $173 = Math_fround($142 * $172);
       $174 = Math_fround($171 + $173);
       $175 = Math_fround(HEAPF32[$18>>2]);
       $176 = Math_fround($147 * $175);
       $177 = Math_fround($174 + $176);
       $178 = Math_fround(HEAPF32[$19>>2]);
       $179 = Math_fround(HEAPF32[$20>>2]);
       $180 = Math_fround($178 - $179);
       $181 = Math_fround($155 * $170);
       $182 = Math_fround($157 * $172);
       $183 = Math_fround($181 + $182);
       $184 = Math_fround($160 * $175);
       $185 = Math_fround($183 + $184);
       $186 = Math_fround(HEAPF32[$21>>2]);
       $187 = Math_fround($186 * Math_fround(2.0));
       $188 = Math_fround($185 + $187);
       $189 = Math_fround($178 + $179);
       $190 = Math_fround($188 - $189);
       $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($177)))));
       $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($190)))));
       $191 = Math_fround($180 + $fabsf$i$i8$i);
       $192 = $fabsf$i$i7$i > $191;
       if (!($192)) {
        $193 = Math_fround(HEAPF32[$22>>2]);
        $194 = Math_fround($138 * $193);
        $195 = Math_fround(HEAPF32[$23>>2]);
        $196 = Math_fround($142 * $195);
        $197 = Math_fround($194 + $196);
        $198 = Math_fround(HEAPF32[$24>>2]);
        $199 = Math_fround($147 * $198);
        $200 = Math_fround($197 + $199);
        $201 = Math_fround(HEAPF32[$25>>2]);
        $202 = Math_fround(HEAPF32[$26>>2]);
        $203 = Math_fround($201 - $202);
        $204 = Math_fround($155 * $193);
        $205 = Math_fround($157 * $195);
        $206 = Math_fround($204 + $205);
        $207 = Math_fround($160 * $198);
        $208 = Math_fround($206 + $207);
        $209 = Math_fround(HEAPF32[$27>>2]);
        $210 = Math_fround($209 * Math_fround(2.0));
        $211 = Math_fround($208 + $210);
        $212 = Math_fround($201 + $202);
        $213 = Math_fround($211 - $212);
        $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($200)))));
        $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($213)))));
        $214 = Math_fround($203 + $fabsf$i$i4$i);
        $215 = $fabsf$i$i3$i > $214;
        if (!($215)) {
         $216 = Math_fround($177 * $213);
         $217 = Math_fround($190 * $200);
         $218 = Math_fround($216 - $217);
         $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($218)))));
         $219 = Math_fround($180 * $fabsf$i$i4$i);
         $220 = Math_fround($fabsf$i$i8$i * $203);
         $221 = Math_fround($220 + $219);
         $222 = $fabsf$i$i2$i > $221;
         if (!($222)) {
          $223 = Math_fround($167 * $200);
          $224 = Math_fround($151 * $213);
          $225 = Math_fround($223 - $224);
          $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($225)))));
          $226 = Math_fround($154 * $fabsf$i$i4$i);
          $227 = Math_fround($fabsf$i$i5$i * $203);
          $228 = Math_fround($227 + $226);
          $229 = $fabsf$i$i1$i > $228;
          if (!($229)) {
           $230 = Math_fround($151 * $190);
           $231 = Math_fround($167 * $177);
           $232 = Math_fround($230 - $231);
           $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($232)))));
           $233 = Math_fround($154 * $fabsf$i$i8$i);
           $234 = Math_fround($fabsf$i$i5$i * $180);
           $235 = Math_fround($234 + $233);
           $not$$i = !($fabsf$i$i$i > $235);
           if ($not$$i) {
            $236 = Math_fround($139 - $124);
            $237 = Math_fround($143 - $125);
            $238 = Math_fround($148 - $126);
            $239 = Math_fround(HEAPF32[$world0>>2]);
            $240 = Math_fround($236 * $239);
            $241 = Math_fround(HEAPF32[$28>>2]);
            $242 = Math_fround($236 * $241);
            $243 = Math_fround(HEAPF32[$29>>2]);
            $244 = Math_fround($236 * $243);
            $245 = Math_fround(HEAPF32[$30>>2]);
            $246 = Math_fround($237 * $245);
            $247 = Math_fround(HEAPF32[$31>>2]);
            $248 = Math_fround($237 * $247);
            $249 = Math_fround(HEAPF32[$32>>2]);
            $250 = Math_fround($237 * $249);
            $251 = Math_fround($240 + $246);
            $252 = Math_fround($242 + $248);
            $253 = Math_fround($244 + $250);
            $254 = Math_fround(HEAPF32[$33>>2]);
            $255 = Math_fround($238 * $254);
            $256 = Math_fround(HEAPF32[$34>>2]);
            $257 = Math_fround($238 * $256);
            $258 = Math_fround(HEAPF32[$35>>2]);
            $259 = Math_fround($238 * $258);
            $260 = Math_fround($251 + $255);
            $261 = Math_fround($252 + $257);
            $262 = Math_fround($253 + $259);
            $263 = Math_fround($260 * $260);
            $264 = Math_fround($261 * $261);
            $265 = Math_fround($263 + $264);
            $266 = Math_fround($262 * $262);
            $267 = Math_fround($265 + $266);
            $268 = $267 > Math_fround(0.0);
            if ($268) {
             $269 = (Math_fround(Math_sqrt((Math_fround($267)))));
             $270 = Math_fround(Math_fround(1.0) / $269);
             $271 = Math_fround($260 * $270);
             $272 = Math_fround($261 * $270);
             $273 = Math_fround($262 * $270);
             $storemerge = $273;$storemerge26 = $272;$storemerge27 = $271;
            } else {
             $storemerge = Math_fround(0.0);$storemerge26 = Math_fround(0.0);$storemerge27 = Math_fround(0.0);
            }
            HEAPF32[$currentEdge>>2] = $storemerge27;
            HEAPF32[$36>>2] = $storemerge26;
            HEAPF32[$37>>2] = $storemerge;
            (__ZN5physx2Gu14SeparatingAxes7addAxisERKNS_6PxVec3E($sa,$currentEdge)|0);
           }
          }
         }
        }
       }
      }
     }
     $exitcond = ($j$011|0)==($48|0);
     if ($exitcond) {
      break L6;
     }
     $$pre = Math_fround(HEAPF32[$scaling>>2]);
     $$pre14 = Math_fround(HEAPF32[$1>>2]);
     $$pre15 = Math_fround(HEAPF32[$2>>2]);
     $$pre16 = Math_fround(HEAPF32[$3>>2]);
     $$pre17 = Math_fround(HEAPF32[$4>>2]);
     $$pre18 = Math_fround(HEAPF32[$5>>2]);
     $$pre19 = Math_fround(HEAPF32[$6>>2]);
     $$pre20 = Math_fround(HEAPF32[$7>>2]);
     $$pre21 = Math_fround(HEAPF32[$8>>2]);
     $$pre22 = Math_fround(HEAPF32[$plane>>2]);
     $$pre23 = Math_fround(HEAPF32[$9>>2]);
     $$pre24 = Math_fround(HEAPF32[$10>>2]);
     $$pre25 = Math_fround(HEAPF32[$11>>2]);
     $phitmp = (($j$011) + 1)|0;
     $100 = $$pre;$102 = $$pre14;$104 = $$pre15;$108 = $$pre16;$110 = $$pre17;$112 = $$pre18;$119 = $$pre19;$121 = $$pre20;$123 = $$pre21;$128 = $$pre22;$130 = $$pre23;$133 = $$pre24;$136 = $$pre25;$139 = $124;$143 = $125;$148 = $126;$b0$0$in10 = $137;$j$011 = $phitmp;
    }
   }
  } while(0);
  $38 = ($39|0)==(0);
  if ($38) {
   break;
  } else {
   $$012 = $40;$$in = $39;
  }
 }
 STACKTOP = sp;return;
}
function __ZL36PxcTestFacesSepAxesBackfaceRoughPassRKN5physx2Gu13PolygonalDataES3_RKNS_2Cm8Matrix34ES7_RKNS4_23FastVertex2ShapeScalingESA_S7_RKNS_6PxVec3ESD_RfRSB_RjfSD_($polyData0,$polyData1,$world0,$world1,$scaling0,$scaling1,$m1to0,$delta$0$0$val,$delta$0$1$val,$delta$0$2$val,$dmin,$sep,$id,$contactDistance,$worldDelta) {
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $world0 = $world0|0;
 $world1 = $world1|0;
 $scaling0 = $scaling0|0;
 $scaling1 = $scaling1|0;
 $m1to0 = $m1to0|0;
 $delta$0$0$val = Math_fround($delta$0$0$val);
 $delta$0$1$val = Math_fround($delta$0$1$val);
 $delta$0$2$val = Math_fround($delta$0$2$val);
 $dmin = $dmin|0;
 $sep = $sep|0;
 $id = $id|0;
 $contactDistance = Math_fround($contactDistance);
 $worldDelta = $worldDelta|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0;
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$01 = 0, $max1$i = 0, $min1$i = 0, $not$$i = 0, $shapeSpaceNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $min1$i = sp + 16|0;
 $max1$i = sp;
 $shapeSpaceNormal = sp + 4|0;
 HEAP32[$id>>2] = -1;
 $0 = (($polyData0) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($polyData0) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($polyData0) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($scaling0) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $delta$0$0$val);
 $9 = (($scaling0) + 40|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $delta$0$0$val);
 $12 = (($scaling0) + 44|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $delta$0$0$val);
 $15 = (($scaling0) + 48|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $delta$0$1$val);
 $18 = (($scaling0) + 52|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $delta$0$1$val);
 $21 = (($scaling0) + 56|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $delta$0$1$val);
 $24 = Math_fround($8 + $17);
 $25 = Math_fround($11 + $20);
 $26 = Math_fround($14 + $23);
 $27 = (($scaling0) + 60|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $delta$0$2$val);
 $30 = (($scaling0) + 64|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $delta$0$2$val);
 $33 = (($scaling0) + 68|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $delta$0$2$val);
 $36 = Math_fround($24 + $29);
 $37 = Math_fround($25 + $32);
 $38 = Math_fround($26 + $35);
 $39 = ($1|0)==(0);
 if ($39) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = (($shapeSpaceNormal) + 4|0);
 $41 = (($shapeSpaceNormal) + 8|0);
 $42 = (($world0) + 4|0);
 $43 = (($world0) + 8|0);
 $44 = (($world0) + 12|0);
 $45 = (($world0) + 16|0);
 $46 = (($world0) + 20|0);
 $47 = (($world0) + 24|0);
 $48 = (($world0) + 28|0);
 $49 = (($world0) + 32|0);
 $50 = (($world1) + 4|0);
 $51 = (($world1) + 8|0);
 $52 = (($world1) + 12|0);
 $53 = (($world1) + 16|0);
 $54 = (($world1) + 20|0);
 $55 = (($world1) + 24|0);
 $56 = (($world1) + 28|0);
 $57 = (($world1) + 32|0);
 $58 = (($worldDelta) + 4|0);
 $59 = (($worldDelta) + 8|0);
 $60 = (($polyData0) + 44|0);
 $61 = (($polyData0) + 48|0);
 $62 = (($polyData0) + 52|0);
 $63 = (($polyData1) + 44|0);
 $64 = (($polyData1) + 48|0);
 $65 = (($polyData1) + 52|0);
 $66 = (($polyData0) + 40|0);
 $67 = (($polyData1) + 40|0);
 $68 = (($polyData1) + 64|0);
 $69 = (($sep) + 4|0);
 $70 = (($sep) + 8|0);
 $i$01 = 0;
 while(1) {
  $71 = (($3) + (($i$01*20)|0)|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($36 * $72);
  $74 = ((($3) + (($i$01*20)|0)|0) + 4|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($37 * $75);
  $77 = Math_fround($73 + $76);
  $78 = ((($3) + (($i$01*20)|0)|0) + 8|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($38 * $79);
  $81 = Math_fround($77 + $80);
  $82 = $81 < Math_fround(0.0);
  if (!($82)) {
   $83 = Math_fround(HEAPF32[$6>>2]);
   $84 = Math_fround($72 * $83);
   $85 = Math_fround(HEAPF32[$9>>2]);
   $86 = Math_fround($72 * $85);
   $87 = Math_fround(HEAPF32[$12>>2]);
   $88 = Math_fround($72 * $87);
   $89 = Math_fround(HEAPF32[$15>>2]);
   $90 = Math_fround($75 * $89);
   $91 = Math_fround(HEAPF32[$18>>2]);
   $92 = Math_fround($75 * $91);
   $93 = Math_fround(HEAPF32[$21>>2]);
   $94 = Math_fround($75 * $93);
   $95 = Math_fround($84 + $90);
   $96 = Math_fround($86 + $92);
   $97 = Math_fround($88 + $94);
   $98 = Math_fround(HEAPF32[$27>>2]);
   $99 = Math_fround($79 * $98);
   $100 = Math_fround(HEAPF32[$30>>2]);
   $101 = Math_fround($79 * $100);
   $102 = Math_fround(HEAPF32[$33>>2]);
   $103 = Math_fround($79 * $102);
   $104 = Math_fround($95 + $99);
   $105 = Math_fround($96 + $101);
   $106 = Math_fround($97 + $103);
   HEAPF32[$shapeSpaceNormal>>2] = $104;
   HEAPF32[$40>>2] = $105;
   HEAPF32[$41>>2] = $106;
   $107 = Math_fround($104 * $104);
   $108 = Math_fround($105 * $105);
   $109 = Math_fround($107 + $108);
   $110 = Math_fround($106 * $106);
   $111 = Math_fround($110 + $109);
   $112 = (Math_fround(Math_sqrt((Math_fround($111)))));
   $113 = $112 > Math_fround(0.0);
   if ($113) {
    $114 = Math_fround(Math_fround(1.0) / $112);
    $115 = Math_fround($104 * $114);
    HEAPF32[$shapeSpaceNormal>>2] = $115;
    $116 = Math_fround($105 * $114);
    HEAPF32[$40>>2] = $116;
    $117 = Math_fround($106 * $114);
    HEAPF32[$41>>2] = $117;
    $120 = $115;$127 = $116;$137 = $117;
   } else {
    $120 = $104;$127 = $105;$137 = $106;
   }
   $118 = Math_fround(HEAPF32[$world0>>2]);
   $119 = Math_fround($120 * $118);
   $121 = Math_fround(HEAPF32[$42>>2]);
   $122 = Math_fround($120 * $121);
   $123 = Math_fround(HEAPF32[$43>>2]);
   $124 = Math_fround($120 * $123);
   $125 = Math_fround(HEAPF32[$44>>2]);
   $126 = Math_fround($127 * $125);
   $128 = Math_fround(HEAPF32[$45>>2]);
   $129 = Math_fround($127 * $128);
   $130 = Math_fround(HEAPF32[$46>>2]);
   $131 = Math_fround($127 * $130);
   $132 = Math_fround($119 + $126);
   $133 = Math_fround($122 + $129);
   $134 = Math_fround($124 + $131);
   $135 = Math_fround(HEAPF32[$47>>2]);
   $136 = Math_fround($137 * $135);
   $138 = Math_fround(HEAPF32[$48>>2]);
   $139 = Math_fround($137 * $138);
   $140 = Math_fround(HEAPF32[$49>>2]);
   $141 = Math_fround($137 * $140);
   $142 = Math_fround($132 + $136);
   $143 = Math_fround($133 + $139);
   $144 = Math_fround($134 + $141);
   $145 = Math_fround(HEAPF32[$dmin>>2]);
   $146 = Math_fround($118 * $142);
   $147 = Math_fround($121 * $143);
   $148 = Math_fround($146 + $147);
   $149 = Math_fround($123 * $144);
   $150 = Math_fround($148 + $149);
   $151 = Math_fround($125 * $142);
   $152 = Math_fround($128 * $143);
   $153 = Math_fround($151 + $152);
   $154 = Math_fround($130 * $144);
   $155 = Math_fround($153 + $154);
   $156 = Math_fround($135 * $142);
   $157 = Math_fround($138 * $143);
   $158 = Math_fround($156 + $157);
   $159 = Math_fround($140 * $144);
   $160 = Math_fround($158 + $159);
   $161 = (HEAPF32[tempDoublePtr>>2]=$150,HEAP32[tempDoublePtr>>2]|0);
   $162 = (HEAPF32[tempDoublePtr>>2]=$155,HEAP32[tempDoublePtr>>2]|0);
   $163 = (HEAPF32[tempDoublePtr>>2]=$160,HEAP32[tempDoublePtr>>2]|0);
   $164 = Math_fround(HEAPF32[$world1>>2]);
   $165 = Math_fround($142 * $164);
   $166 = Math_fround(HEAPF32[$50>>2]);
   $167 = Math_fround($143 * $166);
   $168 = Math_fround($165 + $167);
   $169 = Math_fround(HEAPF32[$51>>2]);
   $170 = Math_fround($144 * $169);
   $171 = Math_fround($168 + $170);
   $172 = Math_fround(HEAPF32[$52>>2]);
   $173 = Math_fround($142 * $172);
   $174 = Math_fround(HEAPF32[$53>>2]);
   $175 = Math_fround($143 * $174);
   $176 = Math_fround($173 + $175);
   $177 = Math_fround(HEAPF32[$54>>2]);
   $178 = Math_fround($144 * $177);
   $179 = Math_fround($176 + $178);
   $180 = Math_fround(HEAPF32[$55>>2]);
   $181 = Math_fround($142 * $180);
   $182 = Math_fround(HEAPF32[$56>>2]);
   $183 = Math_fround($143 * $182);
   $184 = Math_fround($181 + $183);
   $185 = Math_fround(HEAPF32[$57>>2]);
   $186 = Math_fround($144 * $185);
   $187 = Math_fround($184 + $186);
   $188 = (HEAPF32[tempDoublePtr>>2]=$171,HEAP32[tempDoublePtr>>2]|0);
   $189 = (HEAPF32[tempDoublePtr>>2]=$179,HEAP32[tempDoublePtr>>2]|0);
   $190 = (HEAPF32[tempDoublePtr>>2]=$187,HEAP32[tempDoublePtr>>2]|0);
   $191 = Math_fround(HEAPF32[$worldDelta>>2]);
   $192 = Math_fround($142 * $191);
   $193 = Math_fround(HEAPF32[$58>>2]);
   $194 = Math_fround($143 * $193);
   $195 = Math_fround($192 + $194);
   $196 = Math_fround(HEAPF32[$59>>2]);
   $197 = Math_fround($144 * $196);
   $198 = Math_fround($195 + $197);
   $199 = HEAP32[$60>>2]|0;
   $200 = $161 & -2147483648;
   $201 = $199 | $200;
   $202 = HEAP32[$61>>2]|0;
   $203 = $162 & -2147483648;
   $204 = $202 | $203;
   $205 = HEAP32[$62>>2]|0;
   $206 = $163 & -2147483648;
   $207 = $205 | $206;
   $208 = HEAP32[$63>>2]|0;
   $209 = $188 & -2147483648;
   $210 = $208 | $209;
   $211 = HEAP32[$64>>2]|0;
   $212 = $189 & -2147483648;
   $213 = $211 | $212;
   $214 = HEAP32[$65>>2]|0;
   $215 = $190 & -2147483648;
   $216 = $214 | $215;
   $217 = (HEAP32[tempDoublePtr>>2]=$201,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $218 = Math_fround($150 * $217);
   $219 = (HEAP32[tempDoublePtr>>2]=$204,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $220 = Math_fround($155 * $219);
   $221 = Math_fround($218 + $220);
   $222 = (HEAP32[tempDoublePtr>>2]=$207,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $223 = Math_fround($160 * $222);
   $224 = Math_fround($221 + $223);
   $225 = (HEAP32[tempDoublePtr>>2]=$210,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $226 = Math_fround($171 * $225);
   $227 = (HEAP32[tempDoublePtr>>2]=$213,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $228 = Math_fround($179 * $227);
   $229 = Math_fround($226 + $228);
   $230 = (HEAP32[tempDoublePtr>>2]=$216,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $231 = Math_fround($187 * $230);
   $232 = Math_fround($229 + $231);
   $233 = Math_fround(HEAPF32[$66>>2]);
   $234 = $224 > $233;
   $235 = $234 ? $224 : $233;
   $236 = Math_fround(HEAPF32[$67>>2]);
   $237 = $232 > $236;
   $238 = $237 ? $232 : $236;
   $239 = Math_fround($235 + $238);
   $240 = Math_fround($198 + $239);
   $241 = Math_fround($239 - $198);
   $242 = $240 < $241;
   $243 = $242 ? $240 : $241;
   $not$$i = !($243 > $145);
   if ($not$$i) {
    $244 = Math_fround(Math_fround(1.0) / $112);
    $245 = ((($3) + (($i$01*20)|0)|0) + 19|0);
    $246 = HEAP8[$245>>0]|0;
    $247 = $246&255;
    $248 = Math_fround(HEAPF32[$71>>2]);
    $249 = (($5) + (($247*12)|0)|0);
    $250 = Math_fround(HEAPF32[$249>>2]);
    $251 = Math_fround($248 * $250);
    $252 = Math_fround(HEAPF32[$74>>2]);
    $253 = ((($5) + (($247*12)|0)|0) + 4|0);
    $254 = Math_fround(HEAPF32[$253>>2]);
    $255 = Math_fround($252 * $254);
    $256 = Math_fround($251 + $255);
    $257 = Math_fround(HEAPF32[$78>>2]);
    $258 = ((($5) + (($247*12)|0)|0) + 8|0);
    $259 = Math_fround(HEAPF32[$258>>2]);
    $260 = Math_fround($257 * $259);
    $261 = Math_fround($256 + $260);
    $262 = Math_fround($244 * $261);
    $263 = ((($3) + (($i$01*20)|0)|0) + 12|0);
    $264 = Math_fround(HEAPF32[$263>>2]);
    $265 = Math_fround($244 * $264);
    $266 = Math_fround(-$265);
    $267 = HEAP32[$68>>2]|0;
    FUNCTION_TABLE_viiiiii[$267 & 255]($polyData1,$shapeSpaceNormal,$m1to0,$scaling1,$min1$i,$max1$i);
    $268 = Math_fround($contactDistance - $265);
    $269 = Math_fround(HEAPF32[$min1$i>>2]);
    $270 = $268 < $269;
    if ($270) {
     $$0 = 0;
     label = 12;
     break;
    }
    $271 = Math_fround(HEAPF32[$max1$i>>2]);
    $272 = Math_fround($271 + $contactDistance);
    $273 = $272 < $262;
    if ($273) {
     $$0 = 0;
     label = 12;
     break;
    }
    $274 = Math_fround($266 - $269);
    $275 = Math_fround($271 - $262);
    $276 = $274 < $275;
    $277 = $276 ? $274 : $275;
    $278 = Math_fround(HEAPF32[$dmin>>2]);
    $279 = $277 < $278;
    if ($279) {
     HEAPF32[$sep>>2] = $142;
     HEAPF32[$69>>2] = $143;
     HEAPF32[$70>>2] = $144;
     HEAPF32[$dmin>>2] = $277;
     HEAP32[$id>>2] = $i$01;
    }
   }
  }
  $280 = (($i$01) + 1)|0;
  $281 = ($280>>>0)<($1>>>0);
  if ($281) {
   $i$01 = $280;
  } else {
   $$0 = 1;
   label = 12;
   break;
  }
 }
 if ((label|0) == 12) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx27PxcContactConvexHeightFieldERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $$lcssa$i = Math_fround(0), $$lcssa$i87 = Math_fround(0), $$lcssa123 = 0, $$lcssa130 = Math_fround(0), $$lcssa131 = Math_fround(0), $$lcssa132 = Math_fround(0), $$lcssa133 = Math_fround(0), $$lcssa134 = Math_fround(0), $$lcssa135 = Math_fround(0), $$lcssa2$i = Math_fround(0), $$lcssa2$i82 = Math_fround(0), $$lcssa4$i = Math_fround(0), $$lcssa4$i77 = Math_fround(0), $$pre = 0, $$pre$phiZ2D = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0);
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0;
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0);
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0);
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0);
 var $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0);
 var $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0);
 var $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0);
 var $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0);
 var $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0;
 var $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0);
 var $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0);
 var $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0;
 var $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = Math_fround(0);
 var $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0);
 var $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = 0, $46 = Math_fround(0), $460 = 0;
 var $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = Math_fround(0), $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $476 = 0, $477 = Math_fround(0), $478 = 0, $479 = Math_fround(0);
 var $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0);
 var $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = 0, $511 = Math_fround(0), $512 = 0, $513 = Math_fround(0), $514 = 0;
 var $515 = Math_fround(0), $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0);
 var $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0);
 var $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0;
 var $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = Math_fround(0), $599 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $600 = 0, $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = 0;
 var $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = 0, $609 = 0, $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = Math_fround(0), $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = Math_fround(0), $622 = 0;
 var $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = 0, $627 = Math_fround(0), $628 = 0, $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = 0, $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = 0, $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0;
 var $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = Math_fround(0), $648 = Math_fround(0), $649 = 0, $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = 0, $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = 0, $658 = 0, $659 = 0;
 var $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = Math_fround(0), $668 = 0, $669 = 0, $67 = Math_fround(0), $670 = Math_fround(0), $671 = 0, $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = 0, $676 = Math_fround(0), $677 = 0;
 var $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = 0, $681 = Math_fround(0), $682 = 0, $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = 0, $687 = Math_fround(0), $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0;
 var $696 = 0, $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $700 = 0, $701 = 0, $702 = 0, $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0);
 var $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = 0, $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0);
 var $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = Math_fround(0), $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0);
 var $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0);
 var $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = 0, $784 = 0, $785 = 0;
 var $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = 0, $8 = 0, $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0);
 var $803 = Math_fround(0), $804 = Math_fround(0), $805 = 0, $806 = 0, $807 = Math_fround(0), $808 = 0, $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0, $812 = Math_fround(0), $813 = 0, $814 = Math_fround(0), $815 = Math_fround(0), $816 = 0, $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = 0;
 var $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0);
 var $84 = Math_fround(0), $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = 0, $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0);
 var $858 = 0, $859 = 0, $86 = 0, $860 = Math_fround(0), $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0);
 var $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = 0, $892 = Math_fround(0), $893 = Math_fround(0);
 var $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = 0, $898 = Math_fround(0), $899 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = 0, $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = 0;
 var $911 = 0, $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0);
 var $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = Math_fround(0), $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = 0, $946 = 0, $947 = 0;
 var $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0);
 var $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $99 = 0, $cb = 0, $column$0106 = 0, $convexScaling = 0;
 var $distance1$0$lcssa$i = Math_fround(0), $distance1$014$i = Math_fround(0), $distance1$014$us$i = Math_fround(0), $distance1$1$i = Math_fround(0), $distance1$1$us$i = Math_fround(0), $distance1$2$i = Math_fround(0), $distance1$2$us$i = Math_fround(0), $distance2$0$lcssa$i = Math_fround(0), $distance2$0$lcssa30$i = Math_fround(0), $distance2$0$pn$i = Math_fround(0), $distance2$013$i = Math_fround(0), $distance2$013$us$i = Math_fround(0), $distance2$1$i = Math_fround(0), $distance2$1$us$i = Math_fround(0), $edges = 0, $exitcond = 0, $exitcond160 = 0, $fracX = 0, $fracZ = 0, $hfUtil = 0;
 var $i$0145 = 0, $i1$0136 = 0, $i2$0124 = 0, $i3$0119 = 0, $i3$0119$us = 0, $left = 0, $normalInHfShape = 0, $nrm = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i6 = 0, $or$cond1$i = 0, $phitmp$i = Math_fround(0), $phitmp21$i = Math_fround(0), $phitmp22$i = Math_fround(0), $phitmp23$i = Math_fround(0), $poly$011$i = 0, $poly$011$us$i = 0, $poly1$0$lcssa$i = 0, $poly1$012$i = 0;
 var $poly1$012$us$i = 0, $poly1$1$i = 0, $poly1$1$us$i = 0, $poly1$2$i = 0, $poly1$2$us$i = 0, $poly2$0$lcssa$i = 0, $poly2$010$i = 0, $poly2$010$us$i = 0, $poly2$1$i = 0, $poly2$1$us$i = 0, $row$0116 = 0, $tmp2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 8528|0;
 $hfUtil = sp + 8496|0;
 $convexScaling = sp + 8424|0;
 $left = sp + 8384|0;
 $0 = sp + 8348|0;
 $1 = sp + 8312|0;
 $fracX = sp + 8308|0;
 $fracZ = sp + 8304|0;
 $2 = sp + 8280|0;
 $edges = sp + 88|0;
 $cb = sp + 16|0;
 $nrm = sp;
 $normalInHfShape = sp + 8292|0;
 $3 = Math_fround(HEAPF32[$transform0>>2]);
 $4 = Math_fround($3 + $3);
 $5 = (($transform0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 + $6);
 $8 = (($transform0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 + $9);
 $11 = (($transform0) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($4 * $12);
 $14 = Math_fround($7 * $12);
 $15 = Math_fround($12 * $10);
 $16 = Math_fround($3 * $4);
 $17 = Math_fround($3 * $7);
 $18 = Math_fround($3 * $10);
 $19 = Math_fround($6 * $7);
 $20 = Math_fround($6 * $10);
 $21 = Math_fround($9 * $10);
 $22 = Math_fround(Math_fround(1.0) - $19);
 $23 = Math_fround($22 - $21);
 $24 = Math_fround($17 + $15);
 $25 = Math_fround($18 - $14);
 $26 = Math_fround($17 - $15);
 $27 = Math_fround(Math_fround(1.0) - $16);
 $28 = Math_fround($27 - $21);
 $29 = Math_fround($20 + $13);
 $30 = Math_fround($18 + $14);
 $31 = Math_fround($20 - $13);
 $32 = Math_fround($27 - $19);
 $33 = (($transform0) + 16|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($transform0) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($transform0) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(HEAPF32[$transform1>>2]);
 $40 = Math_fround($39 + $39);
 $41 = (($transform1) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($42 + $42);
 $44 = (($transform1) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 + $45);
 $47 = (($transform1) + 12|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($40 * $48);
 $50 = Math_fround($43 * $48);
 $51 = Math_fround($48 * $46);
 $52 = Math_fround($39 * $40);
 $53 = Math_fround($39 * $43);
 $54 = Math_fround($39 * $46);
 $55 = Math_fround($42 * $43);
 $56 = Math_fround($42 * $46);
 $57 = Math_fround($45 * $46);
 $58 = Math_fround(Math_fround(1.0) - $55);
 $59 = Math_fround($58 - $57);
 $60 = Math_fround($53 + $51);
 $61 = Math_fround($54 - $50);
 $62 = Math_fround($53 - $51);
 $63 = Math_fround(Math_fround(1.0) - $52);
 $64 = Math_fround($63 - $57);
 $65 = Math_fround($56 + $49);
 $66 = Math_fround($54 + $50);
 $67 = Math_fround($56 - $49);
 $68 = Math_fround($63 - $55);
 $69 = (($transform1) + 16|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($transform1) + 20|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($transform1) + 24|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($shape1) + 4|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($hfUtil) + 12|0);
 HEAP32[$77>>2] = $76;
 $78 = (($hfUtil) + 16|0);
 HEAP32[$78>>2] = $shape1;
 $79 = (($shape1) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround(Math_fround(1.0) / $80);
 $82 = (($hfUtil) + 4|0);
 HEAPF32[$82>>2] = $81;
 $83 = (($shape1) + 12|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround(Math_fround(1.0) / $84);
 HEAPF32[$hfUtil>>2] = $85;
 $86 = (($shape1) + 16|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround(Math_fround(1.0) / $87);
 $89 = (($hfUtil) + 8|0);
 HEAPF32[$89>>2] = $88;
 $90 = (($shape0) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = $91 == Math_fround(1.0);
 if ($92) {
  $93 = (($shape0) + 8|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = $94 == Math_fround(1.0);
  if ($95) {
   $96 = (($shape0) + 12|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = $97 == Math_fround(1.0);
   $961 = $98;
  } else {
   $961 = 0;
  }
 } else {
  $961 = 0;
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $99 = (($convexScaling) + 4|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = (($convexScaling) + 8|0);
 HEAPF32[$100>>2] = Math_fround(0.0);
 $101 = (($convexScaling) + 12|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = (($convexScaling) + 16|0);
 HEAPF32[$102>>2] = Math_fround(1.0);
 $103 = (($convexScaling) + 20|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($convexScaling) + 24|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($convexScaling) + 28|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = (($convexScaling) + 32|0);
 HEAPF32[$106>>2] = Math_fround(1.0);
 $107 = (($convexScaling) + 36|0);
 HEAPF32[$107>>2] = Math_fround(1.0);
 $108 = (($convexScaling) + 40|0);
 HEAPF32[$108>>2] = Math_fround(0.0);
 $109 = (($convexScaling) + 44|0);
 HEAPF32[$109>>2] = Math_fround(0.0);
 $110 = (($convexScaling) + 48|0);
 HEAPF32[$110>>2] = Math_fround(0.0);
 $111 = (($convexScaling) + 52|0);
 HEAPF32[$111>>2] = Math_fround(1.0);
 $112 = (($convexScaling) + 56|0);
 HEAPF32[$112>>2] = Math_fround(0.0);
 $113 = (($convexScaling) + 60|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = (($convexScaling) + 64|0);
 HEAPF32[$114>>2] = Math_fround(0.0);
 $115 = (($convexScaling) + 68|0);
 HEAPF32[$115>>2] = Math_fround(1.0);
 if (!($961)) {
  $116 = (($shape0) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$90,$116);
 }
 HEAPF32[$left>>2] = $59;
 $117 = (($left) + 4|0);
 HEAPF32[$117>>2] = $60;
 $118 = (($left) + 8|0);
 HEAPF32[$118>>2] = $61;
 $119 = (($left) + 12|0);
 HEAPF32[$119>>2] = $62;
 $120 = (($left) + 16|0);
 HEAPF32[$120>>2] = $64;
 $121 = (($left) + 20|0);
 HEAPF32[$121>>2] = $65;
 $122 = (($left) + 24|0);
 HEAPF32[$122>>2] = $66;
 $123 = (($left) + 28|0);
 HEAPF32[$123>>2] = $67;
 $124 = (($left) + 32|0);
 HEAPF32[$124>>2] = $68;
 __ZNK5physx7PxMat3310getInverseEv($0,$left);
 $125 = Math_fround(HEAPF32[$0>>2]);
 $126 = Math_fround($23 * $125);
 $127 = (($0) + 4|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($23 * $128);
 $130 = (($0) + 8|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($23 * $131);
 $133 = (($0) + 12|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($24 * $134);
 $136 = (($0) + 16|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($24 * $137);
 $139 = (($0) + 20|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($24 * $140);
 $142 = Math_fround($126 + $135);
 $143 = Math_fround($129 + $138);
 $144 = Math_fround($132 + $141);
 $145 = (($0) + 24|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = Math_fround($25 * $146);
 $148 = (($0) + 28|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = Math_fround($25 * $149);
 $151 = (($0) + 32|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = Math_fround($25 * $152);
 $154 = Math_fround($142 + $147);
 $155 = Math_fround($143 + $150);
 $156 = Math_fround($144 + $153);
 $157 = Math_fround($26 * $125);
 $158 = Math_fround($26 * $128);
 $159 = Math_fround($26 * $131);
 $160 = Math_fround($28 * $134);
 $161 = Math_fround($28 * $137);
 $162 = Math_fround($28 * $140);
 $163 = Math_fround($157 + $160);
 $164 = Math_fround($158 + $161);
 $165 = Math_fround($159 + $162);
 $166 = Math_fround($29 * $146);
 $167 = Math_fround($29 * $149);
 $168 = Math_fround($29 * $152);
 $169 = Math_fround($163 + $166);
 $170 = Math_fround($164 + $167);
 $171 = Math_fround($165 + $168);
 $172 = Math_fround($30 * $125);
 $173 = Math_fround($30 * $128);
 $174 = Math_fround($30 * $131);
 $175 = Math_fround($31 * $134);
 $176 = Math_fround($31 * $137);
 $177 = Math_fround($31 * $140);
 $178 = Math_fround($172 + $175);
 $179 = Math_fround($173 + $176);
 $180 = Math_fround($174 + $177);
 $181 = Math_fround($32 * $146);
 $182 = Math_fround($32 * $149);
 $183 = Math_fround($32 * $152);
 $184 = Math_fround($178 + $181);
 $185 = Math_fround($179 + $182);
 $186 = Math_fround($180 + $183);
 __ZNK5physx7PxMat3310getInverseEv($1,$left);
 $187 = Math_fround($34 - $70);
 $188 = Math_fround($36 - $72);
 $189 = Math_fround($38 - $74);
 $190 = Math_fround(HEAPF32[$1>>2]);
 $191 = Math_fround($187 * $190);
 $192 = (($1) + 4|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = Math_fround($187 * $193);
 $195 = (($1) + 8|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = Math_fround($187 * $196);
 $198 = (($1) + 12|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = Math_fround($188 * $199);
 $201 = (($1) + 16|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = Math_fround($188 * $202);
 $204 = (($1) + 20|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = Math_fround($188 * $205);
 $207 = Math_fround($191 + $200);
 $208 = Math_fround($194 + $203);
 $209 = Math_fround($197 + $206);
 $210 = (($1) + 24|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = Math_fround($189 * $211);
 $213 = (($1) + 28|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = Math_fround($189 * $214);
 $216 = (($1) + 32|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = Math_fround($189 * $217);
 $219 = Math_fround($207 + $212);
 $220 = Math_fround($208 + $215);
 $221 = Math_fround($209 + $218);
 $222 = Math_fround(HEAPF32[$convexScaling>>2]);
 $223 = Math_fround($23 * $222);
 $224 = Math_fround($24 * $222);
 $225 = Math_fround($25 * $222);
 $226 = Math_fround(HEAPF32[$99>>2]);
 $227 = Math_fround($26 * $226);
 $228 = Math_fround($28 * $226);
 $229 = Math_fround($29 * $226);
 $230 = Math_fround($223 + $227);
 $231 = Math_fround($224 + $228);
 $232 = Math_fround($225 + $229);
 $233 = Math_fround(HEAPF32[$100>>2]);
 $234 = Math_fround($30 * $233);
 $235 = Math_fround($31 * $233);
 $236 = Math_fround($32 * $233);
 $237 = Math_fround($230 + $234);
 $238 = Math_fround($231 + $235);
 $239 = Math_fround($232 + $236);
 $240 = Math_fround(HEAPF32[$101>>2]);
 $241 = Math_fround($23 * $240);
 $242 = Math_fround($24 * $240);
 $243 = Math_fround($25 * $240);
 $244 = Math_fround(HEAPF32[$102>>2]);
 $245 = Math_fround($26 * $244);
 $246 = Math_fround($28 * $244);
 $247 = Math_fround($29 * $244);
 $248 = Math_fround($241 + $245);
 $249 = Math_fround($242 + $246);
 $250 = Math_fround($243 + $247);
 $251 = Math_fround(HEAPF32[$103>>2]);
 $252 = Math_fround($30 * $251);
 $253 = Math_fround($31 * $251);
 $254 = Math_fround($32 * $251);
 $255 = Math_fround($248 + $252);
 $256 = Math_fround($249 + $253);
 $257 = Math_fround($250 + $254);
 $258 = Math_fround(HEAPF32[$104>>2]);
 $259 = Math_fround($23 * $258);
 $260 = Math_fround($24 * $258);
 $261 = Math_fround($25 * $258);
 $262 = Math_fround(HEAPF32[$105>>2]);
 $263 = Math_fround($26 * $262);
 $264 = Math_fround($28 * $262);
 $265 = Math_fround($29 * $262);
 $266 = Math_fround($259 + $263);
 $267 = Math_fround($260 + $264);
 $268 = Math_fround($261 + $265);
 $269 = Math_fround(HEAPF32[$106>>2]);
 $270 = Math_fround($30 * $269);
 $271 = Math_fround($31 * $269);
 $272 = Math_fround($32 * $269);
 $273 = Math_fround($266 + $270);
 $274 = Math_fround($267 + $271);
 $275 = Math_fround($268 + $272);
 $276 = (($shape0) + 36|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = (($277) + 38|0);
 $279 = HEAP8[$278>>0]|0;
 $280 = $279&255;
 $281 = ($280*12)|0;
 $282 = STACKTOP; STACKTOP = STACKTOP + ((((1*$281)|0)+15)&-16)|0;;
 $283 = Math_fround($154 * $222);
 $284 = Math_fround($155 * $222);
 $285 = Math_fround($156 * $222);
 $286 = Math_fround($169 * $226);
 $287 = Math_fround($170 * $226);
 $288 = Math_fround($171 * $226);
 $289 = Math_fround($283 + $286);
 $290 = Math_fround($284 + $287);
 $291 = Math_fround($285 + $288);
 $292 = Math_fround($184 * $233);
 $293 = Math_fround($185 * $233);
 $294 = Math_fround($186 * $233);
 $295 = Math_fround($289 + $292);
 $296 = Math_fround($290 + $293);
 $297 = Math_fround($291 + $294);
 $298 = Math_fround($154 * $240);
 $299 = Math_fround($155 * $240);
 $300 = Math_fround($156 * $240);
 $301 = Math_fround($169 * $244);
 $302 = Math_fround($170 * $244);
 $303 = Math_fround($171 * $244);
 $304 = Math_fround($298 + $301);
 $305 = Math_fround($299 + $302);
 $306 = Math_fround($300 + $303);
 $307 = Math_fround($184 * $251);
 $308 = Math_fround($185 * $251);
 $309 = Math_fround($186 * $251);
 $310 = Math_fround($304 + $307);
 $311 = Math_fround($305 + $308);
 $312 = Math_fround($306 + $309);
 $313 = Math_fround($154 * $258);
 $314 = Math_fround($155 * $258);
 $315 = Math_fround($156 * $258);
 $316 = Math_fround($169 * $262);
 $317 = Math_fround($170 * $262);
 $318 = Math_fround($171 * $262);
 $319 = Math_fround($313 + $316);
 $320 = Math_fround($314 + $317);
 $321 = Math_fround($315 + $318);
 $322 = Math_fround($184 * $269);
 $323 = Math_fround($185 * $269);
 $324 = Math_fround($186 * $269);
 $325 = Math_fround($319 + $322);
 $326 = Math_fround($320 + $323);
 $327 = Math_fround($321 + $324);
 $328 = (($277) + 40|0);
 $329 = HEAP32[$328>>2]|0;
 $330 = (($277) + 39|0);
 $331 = HEAP8[$330>>0]|0;
 $332 = $331&255;
 $333 = (($329) + (($332*20)|0)|0);
 $334 = HEAP8[$278>>0]|0;
 $335 = ($334<<24>>24)==(0);
 if ($335) {
  $$lcssa130 = Math_fround(3.40282346638528859812E+38);$$lcssa131 = Math_fround(3.40282346638528859812E+38);$$lcssa132 = Math_fround(3.40282346638528859812E+38);$$lcssa133 = Math_fround(-3.40282346638528859812E+38);$$lcssa134 = Math_fround(-3.40282346638528859812E+38);$$lcssa135 = Math_fround(-3.40282346638528859812E+38);
 } else {
  $i$0145 = 0;
  while(1) {
   $339 = (($333) + (($i$0145*12)|0)|0);
   $340 = Math_fround(HEAPF32[$339>>2]);
   $341 = Math_fround($295 * $340);
   $342 = Math_fround($296 * $340);
   $343 = Math_fround($297 * $340);
   $344 = ((($333) + (($i$0145*12)|0)|0) + 4|0);
   $345 = Math_fround(HEAPF32[$344>>2]);
   $346 = Math_fround($310 * $345);
   $347 = Math_fround($311 * $345);
   $348 = Math_fround($312 * $345);
   $349 = Math_fround($341 + $346);
   $350 = Math_fround($342 + $347);
   $351 = Math_fround($343 + $348);
   $352 = ((($333) + (($i$0145*12)|0)|0) + 8|0);
   $353 = Math_fround(HEAPF32[$352>>2]);
   $354 = Math_fround($325 * $353);
   $355 = Math_fround($326 * $353);
   $356 = Math_fround($327 * $353);
   $357 = Math_fround($349 + $354);
   $358 = Math_fround($350 + $355);
   $359 = Math_fround($351 + $356);
   $360 = Math_fround($219 + $357);
   $361 = Math_fround($220 + $358);
   $362 = Math_fround($221 + $359);
   $363 = (($282) + (($i$0145*12)|0)|0);
   HEAPF32[$363>>2] = $360;
   $364 = ((($282) + (($i$0145*12)|0)|0) + 4|0);
   HEAPF32[$364>>2] = $361;
   $365 = ((($282) + (($i$0145*12)|0)|0) + 8|0);
   HEAPF32[$365>>2] = $362;
   $366 = (($i$0145) + 1)|0;
   $337 = HEAP8[$278>>0]|0;
   $367 = $337&255;
   $368 = ($366>>>0)<($367>>>0);
   if ($368) {
    $i$0145 = $366;
   } else {
    break;
   }
  }
  $336 = ($337<<24>>24)==(0);
  if ($336) {
   $$lcssa130 = Math_fround(3.40282346638528859812E+38);$$lcssa131 = Math_fround(3.40282346638528859812E+38);$$lcssa132 = Math_fround(3.40282346638528859812E+38);$$lcssa133 = Math_fround(-3.40282346638528859812E+38);$$lcssa134 = Math_fround(-3.40282346638528859812E+38);$$lcssa135 = Math_fround(-3.40282346638528859812E+38);
  } else {
   $338 = $337&255;
   $372 = Math_fround(3.40282346638528859812E+38);$377 = Math_fround(3.40282346638528859812E+38);$382 = Math_fround(3.40282346638528859812E+38);$385 = Math_fround(-3.40282346638528859812E+38);$388 = Math_fround(-3.40282346638528859812E+38);$391 = Math_fround(-3.40282346638528859812E+38);$i1$0136 = 0;
   while(1) {
    $369 = (($282) + (($i1$0136*12)|0)|0);
    $370 = Math_fround(HEAPF32[$369>>2]);
    $371 = $372 < $370;
    $373 = $371 ? $372 : $370;
    $374 = ((($282) + (($i1$0136*12)|0)|0) + 4|0);
    $375 = Math_fround(HEAPF32[$374>>2]);
    $376 = $377 < $375;
    $378 = $376 ? $377 : $375;
    $379 = ((($282) + (($i1$0136*12)|0)|0) + 8|0);
    $380 = Math_fround(HEAPF32[$379>>2]);
    $381 = $382 < $380;
    $383 = $381 ? $382 : $380;
    $384 = $385 > $370;
    $386 = $384 ? $385 : $370;
    $387 = $388 > $375;
    $389 = $387 ? $388 : $375;
    $390 = $391 > $380;
    $392 = $390 ? $391 : $380;
    $393 = (($i1$0136) + 1)|0;
    $394 = ($393>>>0)<($338>>>0);
    if ($394) {
     $372 = $373;$377 = $378;$382 = $383;$385 = $386;$388 = $389;$391 = $392;$i1$0136 = $393;
    } else {
     $$lcssa130 = $383;$$lcssa131 = $378;$$lcssa132 = $373;$$lcssa133 = $392;$$lcssa134 = $389;$$lcssa135 = $386;
     break;
    }
   }
  }
 }
 $395 = (($76) + 40|0);
 $396 = Math_fround(HEAPF32[$395>>2]);
 $397 = $396 <= Math_fround(0.0);
 $398 = Math_fround(HEAPF32[$hfUtil>>2]);
 $399 = Math_fround(HEAPF32[$89>>2]);
 $400 = Math_fround($$lcssa132 * $398);
 $401 = (Math_fround(Math_floor((Math_fround($400)))));
 $402 = (~~(($401)));
 $403 = (($76) + 16|0);
 $404 = HEAP32[$403>>2]|0;
 $405 = (($404) + -2)|0;
 $406 = ($402|0)>(0);
 $407 = $406 ? $402 : 0;
 $408 = ($407|0)>($405|0);
 $409 = $408 ? $405 : $407;
 $410 = Math_fround($$lcssa135 * $398);
 $411 = (Math_fround(Math_ceil((Math_fround($410)))));
 $412 = (~~(($411)));
 $413 = (($404) + -1)|0;
 $414 = ($412|0)>(0);
 $415 = $414 ? $412 : 0;
 $416 = ($415|0)>($413|0);
 $417 = $416 ? $413 : $415;
 $418 = Math_fround($$lcssa130 * $399);
 $419 = (Math_fround(Math_floor((Math_fround($418)))));
 $420 = (~~(($419)));
 $421 = (($76) + 20|0);
 $422 = HEAP32[$421>>2]|0;
 $423 = (($422) + -2)|0;
 $424 = ($420|0)>(0);
 $425 = $424 ? $420 : 0;
 $426 = ($425|0)>($423|0);
 $427 = $426 ? $423 : $425;
 $428 = Math_fround($$lcssa133 * $399);
 $429 = (Math_fround(Math_ceil((Math_fround($428)))));
 $430 = (~~(($429)));
 $431 = (($422) + -1)|0;
 $432 = ($430|0)>(0);
 $433 = $432 ? $430 : 0;
 $434 = ($433|0)>($431|0);
 $435 = $434 ? $431 : $433;
 $436 = (Math_fround(__ZNK5physx2Gu11HeightField14computeExtremeEjjjj($76,$409,$417,$427,$435)));
 $437 = Math_fround(HEAPF32[$79>>2]);
 $438 = Math_fround($436 * $437);
 if ($397) {
  $439 = $$lcssa131 > $438;
  if ($439) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $440 = $$lcssa134 < $438;
  if ($440) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $441 = HEAP8[$278>>0]|0;
 $442 = $441&255;
 $443 = ($441<<24>>24)==(0);
 if ($443) {
  $$lcssa123 = $442;
 } else {
  $444 = (($2) + 4|0);
  $445 = (($2) + 8|0);
  $446 = (($contactBuffer) + 4096|0);
  $i2$0124 = 0;
  while(1) {
   $447 = ((($282) + (($i2$0124*12)|0)|0) + 4|0);
   $448 = Math_fround(HEAPF32[$447>>2]);
   if ($397) {
    $449 = $448 < $438;
    if ($449) {
     label = 19;
    }
   } else {
    $450 = $448 > $438;
    if ($450) {
     label = 19;
    }
   }
   do {
    if ((label|0) == 19) {
     label = 0;
     $451 = (($282) + (($i2$0124*12)|0)|0);
     $452 = Math_fround(HEAPF32[$451>>2]);
     $453 = ((($282) + (($i2$0124*12)|0)|0) + 8|0);
     $454 = Math_fround(HEAPF32[$453>>2]);
     $455 = Math_fround(HEAPF32[$hfUtil>>2]);
     $456 = Math_fround($452 * $455);
     $457 = Math_fround(HEAPF32[$89>>2]);
     $458 = Math_fround($454 * $457);
     $459 = !($456 >= Math_fround(0.0));
     $460 = !($458 >= Math_fround(0.0));
     $or$cond$i6 = $459 | $460;
     if (!($or$cond$i6)) {
      $461 = HEAP32[$77>>2]|0;
      $462 = (($461) + 24|0);
      $463 = Math_fround(HEAPF32[$462>>2]);
      $464 = Math_fround($463 + Math_fround(1.0));
      $465 = $456 < $464;
      if ($465) {
       $466 = (($461) + 28|0);
       $467 = Math_fround(HEAPF32[$466>>2]);
       $468 = Math_fround($467 + Math_fround(1.0));
       $469 = $458 < $468;
       if ($469) {
        $470 = Math_fround($398 * $452);
        $471 = Math_fround($399 * $454);
        $472 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($461,$470,$471,$fracX,$fracZ)|0);
        $473 = Math_fround(HEAPF32[$fracX>>2]);
        $474 = Math_fround(HEAPF32[$fracZ>>2]);
        $475 = HEAP32[$78>>2]|0;
        $476 = (($475) + 8|0);
        $477 = Math_fround(HEAPF32[$476>>2]);
        $478 = HEAP32[$77>>2]|0;
        $479 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($478,$472,$473,$474)));
        $480 = Math_fround($477 * $479);
        $481 = Math_fround(HEAPF32[$447>>2]);
        $482 = Math_fround($481 - $480);
        $483 = Math_fround(HEAPF32[$contactDistance>>2]);
        $484 = Math_fround(HEAPF32[$395>>2]);
        $485 = !($484 <= Math_fround(0.0));
        $486 = !($482 <= $483);
        $or$cond$i = $485 | $486;
        $487 = !($484 <= $482);
        $or$cond1$i = $or$cond$i | $487;
        if ($or$cond1$i) {
         $488 = $484 > Math_fround(0.0);
         if (!($488)) {
          break;
         }
         $489 = Math_fround(-$483);
         $490 = $482 > $489;
         $491 = $484 > $482;
         $or$cond = $490 & $491;
         if (!($or$cond)) {
          break;
         }
        }
        $492 = (__ZNK5physx2Gu15HeightFieldUtil31getFaceIndexAtShapePointNoTest2Ejff($hfUtil,$472,$473,$474)|0);
        $493 = ($492|0)==(-1);
        if (!($493)) {
         $494 = Math_fround(HEAPF32[$fracX>>2]);
         $495 = Math_fround(HEAPF32[$fracZ>>2]);
         __ZNK5physx2Gu15HeightFieldUtil22getNormalAtShapePoint2Ejff($2,$hfUtil,$472,$494,$495);
         $496 = Math_fround(HEAPF32[$2>>2]);
         $497 = Math_fround(HEAPF32[$444>>2]);
         $498 = Math_fround(HEAPF32[$445>>2]);
         $499 = Math_fround($496 * $496);
         $500 = Math_fround($497 * $497);
         $501 = Math_fround($499 + $500);
         $502 = Math_fround($498 * $498);
         $503 = Math_fround($501 + $502);
         $504 = $503 > Math_fround(0.0);
         if ($504) {
          $505 = (Math_fround(Math_sqrt((Math_fround($503)))));
          $506 = Math_fround(Math_fround(1.0) / $505);
          $507 = Math_fround($496 * $506);
          $508 = Math_fround($497 * $506);
          $509 = Math_fround($498 * $506);
          $525 = $508;$529 = $507;$539 = $509;
         } else {
          $525 = Math_fround(0.0);$529 = Math_fround(0.0);$539 = Math_fround(0.0);
         }
         $510 = (($333) + (($i2$0124*12)|0)|0);
         $511 = Math_fround(HEAPF32[$510>>2]);
         $512 = ((($333) + (($i2$0124*12)|0)|0) + 4|0);
         $513 = Math_fround(HEAPF32[$512>>2]);
         $514 = ((($333) + (($i2$0124*12)|0)|0) + 8|0);
         $515 = Math_fround(HEAPF32[$514>>2]);
         $516 = HEAP32[$446>>2]|0;
         $517 = ($516>>>0)>(63);
         if (!($517)) {
          $518 = Math_fround($257 * $513);
          $519 = Math_fround($256 * $513);
          $520 = Math_fround($255 * $513);
          $521 = Math_fround($239 * $511);
          $522 = Math_fround($238 * $511);
          $523 = Math_fround($237 * $511);
          $524 = Math_fround($65 * $525);
          $526 = Math_fround($64 * $525);
          $527 = Math_fround($62 * $525);
          $528 = Math_fround($61 * $529);
          $530 = Math_fround($60 * $529);
          $531 = Math_fround($59 * $529);
          $532 = Math_fround($275 * $515);
          $533 = Math_fround($274 * $515);
          $534 = Math_fround($273 * $515);
          $535 = Math_fround($521 + $518);
          $536 = Math_fround($522 + $519);
          $537 = Math_fround($523 + $520);
          $538 = Math_fround($68 * $539);
          $540 = Math_fround($67 * $539);
          $541 = Math_fround($66 * $539);
          $542 = Math_fround($524 + $528);
          $543 = Math_fround($526 + $530);
          $544 = Math_fround($527 + $531);
          $545 = Math_fround($535 + $532);
          $546 = Math_fround($536 + $533);
          $547 = Math_fround($537 + $534);
          $548 = Math_fround($482 * $525);
          $549 = Math_fround($538 + $542);
          $550 = Math_fround($540 + $543);
          $551 = Math_fround($541 + $544);
          $552 = Math_fround($38 + $545);
          $553 = Math_fround($36 + $546);
          $554 = Math_fround($34 + $547);
          $555 = (($516) + 1)|0;
          HEAP32[$446>>2] = $555;
          $556 = (($contactBuffer) + ($516<<6)|0);
          HEAPF32[$556>>2] = $551;
          $557 = ((($contactBuffer) + ($516<<6)|0) + 4|0);
          HEAPF32[$557>>2] = $550;
          $558 = ((($contactBuffer) + ($516<<6)|0) + 8|0);
          HEAPF32[$558>>2] = $549;
          $559 = ((($contactBuffer) + ($516<<6)|0) + 16|0);
          HEAPF32[$559>>2] = $554;
          $560 = ((($contactBuffer) + ($516<<6)|0) + 20|0);
          HEAPF32[$560>>2] = $553;
          $561 = ((($contactBuffer) + ($516<<6)|0) + 24|0);
          HEAPF32[$561>>2] = $552;
          $562 = ((($contactBuffer) + ($516<<6)|0) + 12|0);
          HEAPF32[$562>>2] = $548;
          $563 = ((($contactBuffer) + ($516<<6)|0) + 48|0);
          HEAP32[$563>>2] = -1;
          $564 = ((($contactBuffer) + ($516<<6)|0) + 52|0);
          HEAP32[$564>>2] = $492;
         }
        }
       }
      }
     }
    }
   } while(0);
   $565 = (($i2$0124) + 1)|0;
   $566 = HEAP8[$278>>0]|0;
   $567 = $566&255;
   $568 = ($565>>>0)<($567>>>0);
   if ($568) {
    $i2$0124 = $565;
   } else {
    $$lcssa123 = $567;
    break;
   }
  }
 }
 $569 = HEAP8[$330>>0]|0;
 $570 = $569&255;
 $571 = HEAP32[$328>>2]|0;
 $572 = (($571) + (($570*20)|0)|0);
 $573 = (($277) + 36|0);
 $574 = HEAP16[$573>>1]|0;
 $575 = $574&65535;
 $576 = $575 << 1;
 $tmp2$i = ($$lcssa123*15)|0;
 $$sum1$i = (($576) + ($tmp2$i))|0;
 $577 = (($572) + ($$sum1$i)|0);
 $578 = (__ZN5physx2Gu21findUniqueConvexEdgesEjPNS0_10ConvexEdgeEjPKNS0_15HullPolygonDataEPKh(512,$edges,$570,$571,$577)|0);
 $579 = ($578|0)==(0);
 if (!($579)) {
  $580 = (($cb) + 4|0);
  $581 = (($cb) + 8|0);
  $582 = (($cb) + 12|0);
  $583 = (($cb) + 16|0);
  $584 = (($cb) + 20|0);
  $585 = (($cb) + 24|0);
  $586 = (($cb) + 28|0);
  $587 = (($cb) + 32|0);
  $588 = (($cb) + 36|0);
  $589 = (($cb) + 40|0);
  $590 = (($cb) + 44|0);
  $591 = (($cb) + 48|0);
  $592 = (($cb) + 52|0);
  $593 = (($cb) + 56|0);
  $594 = (($cb) + 60|0);
  $595 = (($cb) + 64|0);
  $596 = (($cb) + 68|0);
  if ($397) {
   $i3$0119$us = 0;
   while(1) {
    $597 = ((($edges) + ($i3$0119$us<<4)|0) + 4|0);
    $598 = Math_fround(HEAPF32[$597>>2]);
    $599 = Math_fround($296 * $598);
    $600 = ((($edges) + ($i3$0119$us<<4)|0) + 8|0);
    $601 = Math_fround(HEAPF32[$600>>2]);
    $602 = Math_fround($311 * $601);
    $603 = Math_fround($599 + $602);
    $604 = ((($edges) + ($i3$0119$us<<4)|0) + 12|0);
    $605 = Math_fround(HEAPF32[$604>>2]);
    $606 = Math_fround($326 * $605);
    $607 = Math_fround($603 + $606);
    $608 = $607 > Math_fround(0.0);
    do {
     if (!($608)) {
      $609 = (($edges) + ($i3$0119$us<<4)|0);
      $610 = HEAP8[$609>>0]|0;
      $611 = ((($edges) + ($i3$0119$us<<4)|0) + 1|0);
      $612 = HEAP8[$611>>0]|0;
      $613 = $610&255;
      $614 = (($282) + (($613*12)|0)|0);
      $615 = $612&255;
      $616 = (($282) + (($615*12)|0)|0);
      $617 = ((($282) + (($613*12)|0)|0) + 4|0);
      $618 = Math_fround(HEAPF32[$617>>2]);
      $619 = $618 > $438;
      if ($619) {
       $620 = ((($282) + (($615*12)|0)|0) + 4|0);
       $621 = Math_fround(HEAPF32[$620>>2]);
       $622 = $621 > $438;
       if ($622) {
        break;
       }
      }
      $623 = Math_fround(HEAPF32[$616>>2]);
      $624 = Math_fround(HEAPF32[$614>>2]);
      $625 = Math_fround($623 - $624);
      $626 = ((($282) + (($615*12)|0)|0) + 4|0);
      $627 = Math_fround(HEAPF32[$626>>2]);
      $628 = ((($282) + (($613*12)|0)|0) + 4|0);
      $629 = Math_fround(HEAPF32[$628>>2]);
      $630 = Math_fround($627 - $629);
      $631 = ((($282) + (($615*12)|0)|0) + 8|0);
      $632 = Math_fround(HEAPF32[$631>>2]);
      $633 = ((($282) + (($613*12)|0)|0) + 8|0);
      $634 = Math_fround(HEAPF32[$633>>2]);
      $635 = Math_fround($632 - $634);
      $636 = Math_fround(HEAPF32[$contactDistance>>2]);
      HEAPF32[$cb>>2] = $625;
      HEAPF32[$580>>2] = $630;
      HEAPF32[$581>>2] = $635;
      HEAP32[$582>>2] = $contactBuffer;
      HEAPF32[$583>>2] = $59;
      HEAPF32[$584>>2] = $60;
      HEAPF32[$585>>2] = $61;
      HEAPF32[$586>>2] = $62;
      HEAPF32[$587>>2] = $64;
      HEAPF32[$588>>2] = $65;
      HEAPF32[$589>>2] = $66;
      HEAPF32[$590>>2] = $67;
      HEAPF32[$591>>2] = $68;
      HEAPF32[$592>>2] = $70;
      HEAPF32[$593>>2] = $72;
      HEAPF32[$594>>2] = $74;
      HEAPF32[$595>>2] = $636;
      HEAP32[$596>>2] = -1;
      __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS_30PxcContactTraceSegmentCallbackELb1ELb1ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$614,$616,$cb,0);
     }
    } while(0);
    $637 = (($i3$0119$us) + 1)|0;
    $exitcond160 = ($637|0)==($578|0);
    if ($exitcond160) {
     break;
    } else {
     $i3$0119$us = $637;
    }
   }
  } else {
   $i3$0119 = 0;
   while(1) {
    $646 = ((($edges) + ($i3$0119<<4)|0) + 4|0);
    $647 = Math_fround(HEAPF32[$646>>2]);
    $648 = Math_fround($296 * $647);
    $649 = ((($edges) + ($i3$0119<<4)|0) + 8|0);
    $650 = Math_fround(HEAPF32[$649>>2]);
    $651 = Math_fround($311 * $650);
    $652 = Math_fround($648 + $651);
    $653 = ((($edges) + ($i3$0119<<4)|0) + 12|0);
    $654 = Math_fround(HEAPF32[$653>>2]);
    $655 = Math_fround($326 * $654);
    $656 = Math_fround($652 + $655);
    $657 = $656 > Math_fround(0.0);
    do {
     if (!($657)) {
      $658 = (($edges) + ($i3$0119<<4)|0);
      $659 = HEAP8[$658>>0]|0;
      $660 = ((($edges) + ($i3$0119<<4)|0) + 1|0);
      $661 = HEAP8[$660>>0]|0;
      $662 = $659&255;
      $663 = (($282) + (($662*12)|0)|0);
      $664 = $661&255;
      $665 = (($282) + (($664*12)|0)|0);
      $666 = ((($282) + (($662*12)|0)|0) + 4|0);
      $667 = Math_fround(HEAPF32[$666>>2]);
      $668 = $667 < $438;
      if ($668) {
       $669 = ((($282) + (($664*12)|0)|0) + 4|0);
       $670 = Math_fround(HEAPF32[$669>>2]);
       $671 = $670 < $438;
       if ($671) {
        break;
       }
      }
      $672 = Math_fround(HEAPF32[$665>>2]);
      $673 = Math_fround(HEAPF32[$663>>2]);
      $674 = Math_fround($672 - $673);
      $675 = ((($282) + (($664*12)|0)|0) + 4|0);
      $676 = Math_fround(HEAPF32[$675>>2]);
      $677 = ((($282) + (($662*12)|0)|0) + 4|0);
      $678 = Math_fround(HEAPF32[$677>>2]);
      $679 = Math_fround($676 - $678);
      $680 = ((($282) + (($664*12)|0)|0) + 8|0);
      $681 = Math_fround(HEAPF32[$680>>2]);
      $682 = ((($282) + (($662*12)|0)|0) + 8|0);
      $683 = Math_fround(HEAPF32[$682>>2]);
      $684 = Math_fround($681 - $683);
      $685 = Math_fround(HEAPF32[$contactDistance>>2]);
      HEAPF32[$cb>>2] = $674;
      HEAPF32[$580>>2] = $679;
      HEAPF32[$581>>2] = $684;
      HEAP32[$582>>2] = $contactBuffer;
      HEAPF32[$583>>2] = $59;
      HEAPF32[$584>>2] = $60;
      HEAPF32[$585>>2] = $61;
      HEAPF32[$586>>2] = $62;
      HEAPF32[$587>>2] = $64;
      HEAPF32[$588>>2] = $65;
      HEAPF32[$589>>2] = $66;
      HEAPF32[$590>>2] = $67;
      HEAPF32[$591>>2] = $68;
      HEAPF32[$592>>2] = $70;
      HEAPF32[$593>>2] = $72;
      HEAPF32[$594>>2] = $74;
      HEAPF32[$595>>2] = $685;
      HEAP32[$596>>2] = -1;
      __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS_30PxcContactTraceSegmentCallbackELb1ELb1ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$663,$665,$cb,0);
     }
    } while(0);
    $686 = (($i3$0119) + 1)|0;
    $exitcond = ($686|0)==($578|0);
    if ($exitcond) {
     break;
    } else {
     $i3$0119 = $686;
    }
   }
  }
 }
 $638 = ($409>>>0)>($417>>>0);
 if ($638) {
  $$pre = (($contactBuffer) + 4096|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $639 = ($427>>>0)>($435>>>0);
  $640 = (($76) + 36|0);
  $641 = (($nrm) + 4|0);
  $642 = (($nrm) + 8|0);
  $643 = (($normalInHfShape) + 4|0);
  $644 = (($normalInHfShape) + 8|0);
  $645 = (($contactBuffer) + 4096|0);
  $row$0116 = $409;
  while(1) {
   if (!($639)) {
    $687 = (Math_fround(($row$0116>>>0)));
    $column$0106 = $427;
    while(1) {
     $688 = HEAP32[$421>>2]|0;
     $689 = Math_imul($688, $row$0116)|0;
     $690 = (($689) + ($column$0106))|0;
     $691 = HEAP32[$77>>2]|0;
     $692 = (($691) + 36|0);
     $693 = HEAP32[$692>>2]|0;
     $694 = ((($693) + ($690<<2)|0) + 3|0);
     $695 = HEAP8[$694>>0]|0;
     $696 = ($695<<24>>24)<(0);
     L74: do {
      if ($696) {
       $697 = Math_fround(HEAPF32[$83>>2]);
       $698 = Math_fround($687 * $697);
       $699 = Math_fround(HEAPF32[$79>>2]);
       $700 = HEAP32[$640>>2]|0;
       $701 = (($700) + ($690<<2)|0);
       $702 = HEAP16[$701>>1]|0;
       $703 = (Math_fround(($702<<16>>16)));
       $704 = Math_fround($699 * $703);
       $705 = Math_fround(HEAPF32[$86>>2]);
       $706 = (Math_fround(($column$0106>>>0)));
       $707 = Math_fround($706 * $705);
       __ZNK5physx2Gu15HeightFieldUtil15getVertexNormalEjjj($nrm,$hfUtil,$690,$row$0116,$column$0106);
       $708 = Math_fround(HEAPF32[$nrm>>2]);
       if ($397) {
        $709 = Math_fround(HEAPF32[$641>>2]);
        $710 = Math_fround(HEAPF32[$642>>2]);
        $717 = $708;$719 = $709;$722 = $710;
       } else {
        $711 = Math_fround(-$708);
        $712 = Math_fround(HEAPF32[$641>>2]);
        $713 = Math_fround(-$712);
        $714 = Math_fround(HEAPF32[$642>>2]);
        $715 = Math_fround(-$714);
        $717 = $711;$719 = $713;$722 = $715;
       }
       $716 = Math_fround($717 * $717);
       $718 = Math_fround($719 * $719);
       $720 = Math_fround($718 + $716);
       $721 = Math_fround($722 * $722);
       $723 = Math_fround($721 + $720);
       $724 = $723 > Math_fround(0.0);
       if ($724) {
        $725 = (Math_fround(Math_sqrt((Math_fround($723)))));
        $726 = Math_fround(Math_fround(1.0) / $725);
        $727 = Math_fround($717 * $726);
        $728 = Math_fround($719 * $726);
        $729 = Math_fround($722 * $726);
        $731 = $727;$733 = $728;$736 = $729;
       } else {
        $731 = Math_fround(0.0);$733 = Math_fround(0.0);$736 = Math_fround(0.0);
       }
       $730 = Math_fround($154 * $731);
       $732 = Math_fround($155 * $733);
       $734 = Math_fround($732 + $730);
       $735 = Math_fround($156 * $736);
       $737 = Math_fround($735 + $734);
       $738 = Math_fround($169 * $731);
       $739 = Math_fround($170 * $733);
       $740 = Math_fround($739 + $738);
       $741 = Math_fround($171 * $736);
       $742 = Math_fround($741 + $740);
       $743 = Math_fround($184 * $731);
       $744 = Math_fround($185 * $733);
       $745 = Math_fround($744 + $743);
       $746 = Math_fround($186 * $736);
       $747 = Math_fround($746 + $745);
       $748 = Math_fround($698 - $219);
       $749 = Math_fround($704 - $220);
       $750 = Math_fround($707 - $221);
       $751 = Math_fround($154 * $748);
       $752 = Math_fround($155 * $749);
       $753 = Math_fround($751 + $752);
       $754 = Math_fround($156 * $750);
       $755 = Math_fround($754 + $753);
       $756 = Math_fround($169 * $748);
       $757 = Math_fround($170 * $749);
       $758 = Math_fround($756 + $757);
       $759 = Math_fround($171 * $750);
       $760 = Math_fround($759 + $758);
       $761 = Math_fround($184 * $748);
       $762 = Math_fround($185 * $749);
       $763 = Math_fround($761 + $762);
       $764 = Math_fround($186 * $750);
       $765 = Math_fround($764 + $763);
       $766 = Math_fround(-$737);
       $767 = Math_fround(-$742);
       $768 = Math_fround(-$747);
       $769 = Math_fround(HEAPF32[$contactDistance>>2]);
       $770 = HEAP8[$330>>0]|0;
       $771 = ($770<<24>>24)==(0);
       if ($771) {
        $distance2$0$lcssa30$i = Math_fround(-3.40282346638528859812E+38);
        label = 73;
       } else {
        $772 = HEAP32[$328>>2]|0;
        if ($961) {
         $773 = $770&255;
         $962 = Math_fround(0.0);$963 = Math_fround(0.0);$964 = Math_fround(0.0);$distance1$014$us$i = Math_fround(-3.40282346638528859812E+38);$distance2$013$us$i = Math_fround(-3.40282346638528859812E+38);$poly$011$us$i = 0;$poly1$012$us$i = -1;$poly2$010$us$i = -2;
         while(1) {
          $784 = (($772) + (($poly$011$us$i*20)|0)|0);
          $785 = HEAP32[$784>>2]|0;
          $786 = ((($772) + (($poly$011$us$i*20)|0)|0) + 4|0);
          $787 = HEAP32[$786>>2]|0;
          $788 = ((($772) + (($poly$011$us$i*20)|0)|0) + 8|0);
          $789 = HEAP32[$788>>2]|0;
          $790 = ((($772) + (($poly$011$us$i*20)|0)|0) + 12|0);
          $791 = HEAP32[$790>>2]|0;
          $phitmp$i = (HEAP32[tempDoublePtr>>2]=$785,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $phitmp21$i = (HEAP32[tempDoublePtr>>2]=$787,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $phitmp22$i = (HEAP32[tempDoublePtr>>2]=$789,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $phitmp23$i = (HEAP32[tempDoublePtr>>2]=$791,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $792 = Math_fround($755 * $phitmp$i);
          $793 = Math_fround($760 * $phitmp21$i);
          $794 = Math_fround($792 + $793);
          $795 = Math_fround($765 * $phitmp22$i);
          $796 = Math_fround($795 + $794);
          $797 = Math_fround($phitmp23$i + $796);
          $798 = Math_fround($797 - $769);
          $799 = !($798 >= Math_fround(0.0));
          if (!($799)) {
           break L74;
          }
          $800 = Math_fround($phitmp$i * $766);
          $801 = Math_fround($phitmp21$i * $767);
          $802 = Math_fround($800 + $801);
          $803 = Math_fround($phitmp22$i * $768);
          $804 = Math_fround($802 + $803);
          $805 = $804 > Math_fround(0.0);
          do {
           if ($805) {
            $806 = $798 > $distance1$014$us$i;
            if ($806) {
             $971 = $phitmp22$i;$972 = $phitmp21$i;$973 = $phitmp$i;$distance1$1$us$i = $798;$poly1$1$us$i = $poly$011$us$i;
            } else {
             $971 = $964;$972 = $963;$973 = $962;$distance1$1$us$i = $distance1$014$us$i;$poly1$1$us$i = $poly1$012$us$i;
            }
            $807 = Math_fround($798 / $804);
            $808 = $807 > $distance2$013$us$i;
            if (!($808)) {
             $968 = $971;$969 = $972;$970 = $973;$distance1$2$us$i = $distance1$1$us$i;$distance2$1$us$i = $distance2$013$us$i;$poly1$2$us$i = $poly1$1$us$i;$poly2$1$us$i = $poly2$010$us$i;
             break;
            }
            $968 = $971;$969 = $972;$970 = $973;$distance1$2$us$i = $distance1$1$us$i;$distance2$1$us$i = $807;$poly1$2$us$i = $poly1$1$us$i;$poly2$1$us$i = $poly$011$us$i;
           } else {
            $968 = $964;$969 = $963;$970 = $962;$distance1$2$us$i = $distance1$014$us$i;$distance2$1$us$i = $distance2$013$us$i;$poly1$2$us$i = $poly1$012$us$i;$poly2$1$us$i = $poly2$010$us$i;
           }
          } while(0);
          $809 = (($poly$011$us$i) + 1)|0;
          $810 = ($809>>>0)<($773>>>0);
          if ($810) {
           $962 = $970;$963 = $969;$964 = $968;$distance1$014$us$i = $distance1$2$us$i;$distance2$013$us$i = $distance2$1$us$i;$poly$011$us$i = $809;$poly1$012$us$i = $poly1$2$us$i;$poly2$010$us$i = $poly2$1$us$i;
          } else {
           $$lcssa$i = $968;$$lcssa2$i = $969;$$lcssa4$i = $970;$distance1$0$lcssa$i = $distance1$2$us$i;$distance2$0$lcssa$i = $distance2$1$us$i;$poly1$0$lcssa$i = $poly1$2$us$i;$poly2$0$lcssa$i = $poly2$1$us$i;
           break;
          }
         }
        } else {
         $774 = Math_fround(HEAPF32[$107>>2]);
         $775 = Math_fround(HEAPF32[$108>>2]);
         $776 = Math_fround(HEAPF32[$109>>2]);
         $777 = Math_fround(HEAPF32[$110>>2]);
         $778 = Math_fround(HEAPF32[$111>>2]);
         $779 = Math_fround(HEAPF32[$112>>2]);
         $780 = Math_fround(HEAPF32[$113>>2]);
         $781 = Math_fround(HEAPF32[$114>>2]);
         $782 = Math_fround(HEAPF32[$115>>2]);
         $783 = $770&255;
         $965 = Math_fround(0.0);$966 = Math_fround(0.0);$967 = Math_fround(0.0);$distance1$014$i = Math_fround(-3.40282346638528859812E+38);$distance2$013$i = Math_fround(-3.40282346638528859812E+38);$poly$011$i = 0;$poly1$012$i = -1;$poly2$010$i = -2;
         while(1) {
          $811 = ((($772) + (($poly$011$i*20)|0)|0) + 12|0);
          $812 = Math_fround(HEAPF32[$811>>2]);
          $813 = (($772) + (($poly$011$i*20)|0)|0);
          $814 = Math_fround(HEAPF32[$813>>2]);
          $815 = Math_fround($774 * $814);
          $816 = ((($772) + (($poly$011$i*20)|0)|0) + 4|0);
          $817 = Math_fround(HEAPF32[$816>>2]);
          $818 = Math_fround($775 * $817);
          $819 = Math_fround($815 + $818);
          $820 = ((($772) + (($poly$011$i*20)|0)|0) + 8|0);
          $821 = Math_fround(HEAPF32[$820>>2]);
          $822 = Math_fround($776 * $821);
          $823 = Math_fround($819 + $822);
          $824 = Math_fround($814 * $777);
          $825 = Math_fround($817 * $778);
          $826 = Math_fround($824 + $825);
          $827 = Math_fround($821 * $779);
          $828 = Math_fround($826 + $827);
          $829 = Math_fround($814 * $780);
          $830 = Math_fround($817 * $781);
          $831 = Math_fround($829 + $830);
          $832 = Math_fround($821 * $782);
          $833 = Math_fround($831 + $832);
          $834 = Math_fround($823 * $823);
          $835 = Math_fround($828 * $828);
          $836 = Math_fround($834 + $835);
          $837 = Math_fround($833 * $833);
          $838 = Math_fround($836 + $837);
          $839 = (Math_fround(Math_sqrt((Math_fround($838)))));
          $840 = Math_fround(Math_fround(1.0) / $839);
          $841 = Math_fround($823 * $840);
          $842 = Math_fround($828 * $840);
          $843 = Math_fround($833 * $840);
          $844 = Math_fround($812 * $840);
          $845 = Math_fround($755 * $841);
          $846 = Math_fround($760 * $842);
          $847 = Math_fround($846 + $845);
          $848 = Math_fround($765 * $843);
          $849 = Math_fround($848 + $847);
          $850 = Math_fround($844 + $849);
          $851 = Math_fround($850 - $769);
          $852 = !($851 >= Math_fround(0.0));
          if (!($852)) {
           break L74;
          }
          $853 = Math_fround($841 * $766);
          $854 = Math_fround($842 * $767);
          $855 = Math_fround($853 + $854);
          $856 = Math_fround($843 * $768);
          $857 = Math_fround($856 + $855);
          $858 = $857 > Math_fround(0.0);
          do {
           if ($858) {
            $859 = $851 > $distance1$014$i;
            if ($859) {
             $977 = $843;$978 = $842;$979 = $841;$distance1$1$i = $851;$poly1$1$i = $poly$011$i;
            } else {
             $977 = $967;$978 = $966;$979 = $965;$distance1$1$i = $distance1$014$i;$poly1$1$i = $poly1$012$i;
            }
            $860 = Math_fround($851 / $857);
            $861 = $860 > $distance2$013$i;
            if (!($861)) {
             $974 = $977;$975 = $978;$976 = $979;$distance1$2$i = $distance1$1$i;$distance2$1$i = $distance2$013$i;$poly1$2$i = $poly1$1$i;$poly2$1$i = $poly2$010$i;
             break;
            }
            $974 = $977;$975 = $978;$976 = $979;$distance1$2$i = $distance1$1$i;$distance2$1$i = $860;$poly1$2$i = $poly1$1$i;$poly2$1$i = $poly$011$i;
           } else {
            $974 = $967;$975 = $966;$976 = $965;$distance1$2$i = $distance1$014$i;$distance2$1$i = $distance2$013$i;$poly1$2$i = $poly1$012$i;$poly2$1$i = $poly2$010$i;
           }
          } while(0);
          $862 = (($poly$011$i) + 1)|0;
          $863 = ($862>>>0)<($783>>>0);
          if ($863) {
           $965 = $976;$966 = $975;$967 = $974;$distance1$014$i = $distance1$2$i;$distance2$013$i = $distance2$1$i;$poly$011$i = $862;$poly1$012$i = $poly1$2$i;$poly2$010$i = $poly2$1$i;
          } else {
           $$lcssa$i = $974;$$lcssa2$i = $975;$$lcssa4$i = $976;$distance1$0$lcssa$i = $distance1$2$i;$distance2$0$lcssa$i = $distance2$1$i;$poly1$0$lcssa$i = $poly1$2$i;$poly2$0$lcssa$i = $poly2$1$i;
           break;
          }
         }
        }
        $864 = ($poly1$0$lcssa$i|0)==($poly2$0$lcssa$i|0);
        if ($864) {
         $$lcssa$i87 = $$lcssa$i;$$lcssa2$i82 = $$lcssa2$i;$$lcssa4$i77 = $$lcssa4$i;$distance2$0$pn$i = $distance1$0$lcssa$i;
        } else {
         $distance2$0$lcssa30$i = $distance2$0$lcssa$i;
         label = 73;
        }
       }
       if ((label|0) == 73) {
        label = 0;
        $$lcssa$i87 = $768;$$lcssa2$i82 = $767;$$lcssa4$i77 = $766;$distance2$0$pn$i = $distance2$0$lcssa30$i;
       }
       $865 = Math_fround(-$$lcssa4$i77);
       $866 = Math_fround(-$$lcssa2$i82);
       $867 = Math_fround(-$$lcssa$i87);
       $868 = Math_fround($154 * $865);
       $869 = Math_fround($155 * $865);
       $870 = Math_fround($156 * $865);
       $871 = Math_fround($169 * $866);
       $872 = Math_fround($170 * $866);
       $873 = Math_fround($171 * $866);
       $874 = Math_fround($871 + $868);
       $875 = Math_fround($872 + $869);
       $876 = Math_fround($873 + $870);
       $877 = Math_fround($184 * $867);
       $878 = Math_fround($185 * $867);
       $879 = Math_fround($186 * $867);
       $880 = Math_fround($877 + $874);
       $881 = Math_fround($878 + $875);
       $882 = Math_fround($879 + $876);
       HEAPF32[$normalInHfShape>>2] = $880;
       HEAPF32[$643>>2] = $881;
       HEAPF32[$644>>2] = $882;
       (__ZNK5physx2Gu15HeightFieldUtil30clipShapeNormalToVertexVoronoiERNS_6PxVec3Ejjj($hfUtil,$normalInHfShape,$690,$row$0116,$column$0106)|0);
       $883 = Math_fround(HEAPF32[$normalInHfShape>>2]);
       $884 = Math_fround($731 * $883);
       $885 = Math_fround(HEAPF32[$643>>2]);
       $886 = Math_fround($733 * $885);
       $887 = Math_fround($884 + $886);
       $888 = Math_fround(HEAPF32[$644>>2]);
       $889 = Math_fround($736 * $888);
       $890 = Math_fround($887 + $889);
       $891 = $890 < Math_fround(1.1920928955078125E-7);
       if (!($891)) {
        $892 = Math_fround($883 * $883);
        $893 = Math_fround($885 * $885);
        $894 = Math_fround($892 + $893);
        $895 = Math_fround($888 * $888);
        $896 = Math_fround($894 + $895);
        $897 = $896 > Math_fround(0.0);
        if ($897) {
         $898 = (Math_fround(Math_sqrt((Math_fround($896)))));
         $899 = Math_fround(Math_fround(1.0) / $898);
         $900 = Math_fround($883 * $899);
         $901 = Math_fround($885 * $899);
         $902 = Math_fround($888 * $899);
         $903 = $900;$904 = $901;$905 = $902;
        } else {
         $903 = Math_fround(0.0);$904 = Math_fround(0.0);$905 = Math_fround(0.0);
        }
        HEAPF32[$normalInHfShape>>2] = $903;
        HEAPF32[$643>>2] = $904;
        HEAPF32[$644>>2] = $905;
        $906 = (__ZNK5physx2Gu15HeightFieldUtil18getVertexFaceIndexEjjj($hfUtil,$690,$row$0116,$column$0106)|0);
        $907 = Math_fround(HEAPF32[$normalInHfShape>>2]);
        $908 = Math_fround(HEAPF32[$643>>2]);
        $909 = Math_fround(HEAPF32[$644>>2]);
        $910 = HEAP32[$645>>2]|0;
        $911 = ($910>>>0)>(63);
        if (!($911)) {
         $912 = Math_fround($65 * $704);
         $913 = Math_fround($64 * $704);
         $914 = Math_fround($62 * $704);
         $915 = Math_fround($61 * $698);
         $916 = Math_fround($60 * $698);
         $917 = Math_fround($59 * $698);
         $918 = Math_fround($65 * $908);
         $919 = Math_fround($64 * $908);
         $920 = Math_fround($62 * $908);
         $921 = Math_fround($61 * $907);
         $922 = Math_fround($60 * $907);
         $923 = Math_fround($59 * $907);
         $924 = Math_fround($68 * $707);
         $925 = Math_fround($67 * $707);
         $926 = Math_fround($66 * $707);
         $927 = Math_fround($915 + $912);
         $928 = Math_fround($916 + $913);
         $929 = Math_fround($917 + $914);
         $930 = Math_fround($68 * $909);
         $931 = Math_fround($67 * $909);
         $932 = Math_fround($66 * $909);
         $933 = Math_fround($921 + $918);
         $934 = Math_fround($922 + $919);
         $935 = Math_fround($923 + $920);
         $936 = Math_fround($924 + $927);
         $937 = Math_fround($925 + $928);
         $938 = Math_fround($926 + $929);
         $939 = Math_fround($933 + $930);
         $940 = Math_fround($934 + $931);
         $941 = Math_fround($935 + $932);
         $942 = Math_fround($74 + $936);
         $943 = Math_fround($72 + $937);
         $944 = Math_fround($70 + $938);
         $945 = (($910) + 1)|0;
         HEAP32[$645>>2] = $945;
         $946 = (($contactBuffer) + ($910<<6)|0);
         HEAPF32[$946>>2] = $941;
         $947 = ((($contactBuffer) + ($910<<6)|0) + 4|0);
         HEAPF32[$947>>2] = $940;
         $948 = ((($contactBuffer) + ($910<<6)|0) + 8|0);
         HEAPF32[$948>>2] = $939;
         $949 = ((($contactBuffer) + ($910<<6)|0) + 16|0);
         HEAPF32[$949>>2] = $944;
         $950 = ((($contactBuffer) + ($910<<6)|0) + 20|0);
         HEAPF32[$950>>2] = $943;
         $951 = ((($contactBuffer) + ($910<<6)|0) + 24|0);
         HEAPF32[$951>>2] = $942;
         $952 = ((($contactBuffer) + ($910<<6)|0) + 12|0);
         HEAPF32[$952>>2] = $distance2$0$pn$i;
         $953 = ((($contactBuffer) + ($910<<6)|0) + 48|0);
         HEAP32[$953>>2] = -1;
         $954 = ((($contactBuffer) + ($910<<6)|0) + 52|0);
         HEAP32[$954>>2] = $906;
        }
       }
      }
     } while(0);
     $955 = (($column$0106) + 1)|0;
     $956 = ($955>>>0)>($435>>>0);
     if ($956) {
      break;
     } else {
      $column$0106 = $955;
     }
    }
   }
   $957 = (($row$0116) + 1)|0;
   $958 = ($957>>>0)>($417>>>0);
   if ($958) {
    $$pre$phiZ2D = $645;
    break;
   } else {
    $row$0116 = $957;
   }
  }
 }
 $959 = HEAP32[$$pre$phiZ2D>>2]|0;
 $960 = ($959|0)!=(0);
 $$0 = $960;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx21PxcContactConvexMesh2ERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu17contactConvexMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx18PxcContactPlaneBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0);
 var $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0;
 var $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0;
 var $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = 0;
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = Math_fround(0), $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0;
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = 0, $383 = 0, $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = Math_fround(0);
 var $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0);
 var $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0;
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($transform0) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($transform0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = Math_fround(-$8);
 $20 = Math_fround(-$15);
 $21 = Math_fround(-$18);
 $22 = Math_fround(HEAPF32[$transform1>>2]);
 $23 = Math_fround($22 + $22);
 $24 = (($transform1) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $25);
 $27 = (($transform1) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + $28);
 $30 = (($transform1) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($23 * $31);
 $33 = Math_fround($26 * $31);
 $34 = Math_fround($31 * $29);
 $35 = Math_fround($22 * $23);
 $36 = Math_fround($22 * $26);
 $37 = Math_fround($22 * $29);
 $38 = Math_fround($25 * $26);
 $39 = Math_fround($25 * $29);
 $40 = Math_fround($28 * $29);
 $41 = Math_fround(Math_fround(1.0) - $38);
 $42 = Math_fround($41 - $40);
 $43 = Math_fround($36 + $34);
 $44 = Math_fround($37 - $33);
 $45 = Math_fround($36 - $34);
 $46 = Math_fround(Math_fround(1.0) - $35);
 $47 = Math_fround($46 - $40);
 $48 = Math_fround($39 + $32);
 $49 = Math_fround($37 + $33);
 $50 = Math_fround($39 - $32);
 $51 = Math_fround($46 - $38);
 $52 = (($transform1) + 16|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($transform1) + 20|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($transform1) + 24|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround(-$0);
 $59 = Math_fround(-$13);
 $60 = Math_fround(-$10);
 $61 = (($transform0) + 16|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($53 - $62);
 $64 = (($transform0) + 20|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($55 - $65);
 $67 = (($transform0) + 24|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($57 - $68);
 $70 = Math_fround($63 * Math_fround(2.0));
 $71 = Math_fround($66 * Math_fround(2.0));
 $72 = Math_fround($69 * Math_fround(2.0));
 $73 = Math_fround($3 * $3);
 $74 = Math_fround($73 + Math_fround(-0.5));
 $75 = Math_fround($70 * $58);
 $76 = Math_fround($71 * $59);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($72 * $60);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($74 * $70);
 $81 = Math_fround($72 * $59);
 $82 = Math_fround($71 * $60);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($3 * $83);
 $85 = Math_fround($80 + $84);
 $86 = Math_fround($79 * $58);
 $87 = Math_fround($86 + $85);
 $88 = Math_fround($22 * $3);
 $89 = Math_fround($31 * $58);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($28 * $59);
 $92 = Math_fround($91 + $90);
 $93 = Math_fround($25 * $60);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($25 * $3);
 $96 = Math_fround($31 * $59);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($22 * $60);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($28 * $58);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($28 * $3);
 $103 = Math_fround($31 * $60);
 $104 = Math_fround($103 + $102);
 $105 = Math_fround($25 * $58);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($22 * $59);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($31 * $3);
 $110 = Math_fround($22 * $58);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($25 * $59);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($28 * $60);
 $115 = Math_fround($113 - $114);
 $116 = Math_fround($101 + $101);
 $117 = Math_fround($108 + $108);
 $118 = Math_fround($115 * $116);
 $119 = Math_fround($115 * $117);
 $120 = Math_fround($94 * $116);
 $121 = Math_fround($94 * $117);
 $122 = Math_fround($101 * $116);
 $123 = Math_fround($108 * $117);
 $124 = Math_fround(Math_fround(1.0) - $122);
 $125 = Math_fround($124 - $123);
 $126 = Math_fround($120 - $119);
 $127 = Math_fround($121 + $118);
 $128 = Math_fround(HEAPF32[$contactDistance>>2]);
 $129 = Math_fround($128 - $87);
 $130 = (($shape1) + 4|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($shape1) + 8|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($shape1) + 12|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($131 * $125);
 $137 = Math_fround($133 * $126);
 $138 = Math_fround($127 * $135);
 $139 = Math_fround($137 + $136);
 $140 = Math_fround($138 + $139);
 $141 = Math_fround($140 - $129);
 $142 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
 $143 = Math_fround($139 - $138);
 $144 = Math_fround($143 - $129);
 $145 = (HEAPF32[tempDoublePtr>>2]=$144,HEAP32[tempDoublePtr>>2]|0);
 $146 = Math_fround($136 - $137);
 $147 = Math_fround($138 + $146);
 $148 = Math_fround($147 - $129);
 $149 = (HEAPF32[tempDoublePtr>>2]=$148,HEAP32[tempDoublePtr>>2]|0);
 $150 = Math_fround($146 - $138);
 $151 = Math_fround($150 - $129);
 $152 = (HEAPF32[tempDoublePtr>>2]=$151,HEAP32[tempDoublePtr>>2]|0);
 $153 = Math_fround(-$136);
 $154 = Math_fround($137 - $136);
 $155 = Math_fround($138 + $154);
 $156 = Math_fround($155 - $129);
 $157 = (HEAPF32[tempDoublePtr>>2]=$156,HEAP32[tempDoublePtr>>2]|0);
 $158 = Math_fround($154 - $138);
 $159 = Math_fround($158 - $129);
 $160 = (HEAPF32[tempDoublePtr>>2]=$159,HEAP32[tempDoublePtr>>2]|0);
 $161 = Math_fround($153 - $137);
 $162 = Math_fround($138 + $161);
 $163 = Math_fround($162 - $129);
 $164 = (HEAPF32[tempDoublePtr>>2]=$163,HEAP32[tempDoublePtr>>2]|0);
 $165 = Math_fround($161 - $138);
 $166 = Math_fround($165 - $129);
 $167 = (HEAPF32[tempDoublePtr>>2]=$166,HEAP32[tempDoublePtr>>2]|0);
 $168 = ($142|0)<(0);
 if ($168) {
  $169 = (($contactBuffer) + 4096|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = ($170>>>0)>(63);
  if (!($171)) {
   $172 = Math_fround($48 * $133);
   $173 = Math_fround($47 * $133);
   $174 = Math_fround($45 * $133);
   $175 = Math_fround($44 * $131);
   $176 = Math_fround($43 * $131);
   $177 = Math_fround($42 * $131);
   $178 = Math_fround($51 * $135);
   $179 = Math_fround($50 * $135);
   $180 = Math_fround($49 * $135);
   $181 = Math_fround($175 + $172);
   $182 = Math_fround($176 + $173);
   $183 = Math_fround($177 + $174);
   $184 = Math_fround($181 + $178);
   $185 = Math_fround($182 + $179);
   $186 = Math_fround($183 + $180);
   $187 = Math_fround($128 + $141);
   $188 = Math_fround($57 + $184);
   $189 = Math_fround($55 + $185);
   $190 = Math_fround($53 + $186);
   $191 = (($170) + 1)|0;
   HEAP32[$169>>2] = $191;
   $192 = (($contactBuffer) + ($170<<6)|0);
   HEAPF32[$192>>2] = $19;
   $193 = ((($contactBuffer) + ($170<<6)|0) + 4|0);
   HEAPF32[$193>>2] = $20;
   $194 = ((($contactBuffer) + ($170<<6)|0) + 8|0);
   HEAPF32[$194>>2] = $21;
   $195 = ((($contactBuffer) + ($170<<6)|0) + 16|0);
   HEAPF32[$195>>2] = $190;
   $196 = ((($contactBuffer) + ($170<<6)|0) + 20|0);
   HEAPF32[$196>>2] = $189;
   $197 = ((($contactBuffer) + ($170<<6)|0) + 24|0);
   HEAPF32[$197>>2] = $188;
   $198 = ((($contactBuffer) + ($170<<6)|0) + 12|0);
   HEAPF32[$198>>2] = $187;
   $199 = ((($contactBuffer) + ($170<<6)|0) + 48|0);
   HEAP32[$199>>2] = -1;
   $200 = ((($contactBuffer) + ($170<<6)|0) + 52|0);
   HEAP32[$200>>2] = -1;
  }
 }
 $201 = ($145|0)<(0);
 if ($201) {
  $202 = Math_fround(-$135);
  $203 = (($contactBuffer) + 4096|0);
  $204 = HEAP32[$203>>2]|0;
  $205 = ($204>>>0)>(63);
  if (!($205)) {
   $206 = Math_fround($48 * $133);
   $207 = Math_fround($47 * $133);
   $208 = Math_fround($45 * $133);
   $209 = Math_fround($44 * $131);
   $210 = Math_fround($43 * $131);
   $211 = Math_fround($42 * $131);
   $212 = Math_fround($51 * $202);
   $213 = Math_fround($50 * $202);
   $214 = Math_fround($49 * $202);
   $215 = Math_fround($209 + $206);
   $216 = Math_fround($210 + $207);
   $217 = Math_fround($211 + $208);
   $218 = Math_fround(HEAPF32[$contactDistance>>2]);
   $219 = Math_fround($215 + $212);
   $220 = Math_fround($216 + $213);
   $221 = Math_fround($217 + $214);
   $222 = Math_fround($144 + $218);
   $223 = Math_fround($57 + $219);
   $224 = Math_fround($55 + $220);
   $225 = Math_fround($53 + $221);
   $226 = (($204) + 1)|0;
   HEAP32[$203>>2] = $226;
   $227 = (($contactBuffer) + ($204<<6)|0);
   HEAPF32[$227>>2] = $19;
   $228 = ((($contactBuffer) + ($204<<6)|0) + 4|0);
   HEAPF32[$228>>2] = $20;
   $229 = ((($contactBuffer) + ($204<<6)|0) + 8|0);
   HEAPF32[$229>>2] = $21;
   $230 = ((($contactBuffer) + ($204<<6)|0) + 16|0);
   HEAPF32[$230>>2] = $225;
   $231 = ((($contactBuffer) + ($204<<6)|0) + 20|0);
   HEAPF32[$231>>2] = $224;
   $232 = ((($contactBuffer) + ($204<<6)|0) + 24|0);
   HEAPF32[$232>>2] = $223;
   $233 = ((($contactBuffer) + ($204<<6)|0) + 12|0);
   HEAPF32[$233>>2] = $222;
   $234 = ((($contactBuffer) + ($204<<6)|0) + 48|0);
   HEAP32[$234>>2] = -1;
   $235 = ((($contactBuffer) + ($204<<6)|0) + 52|0);
   HEAP32[$235>>2] = -1;
  }
 }
 $236 = ($149|0)<(0);
 if ($236) {
  $237 = Math_fround(-$133);
  $238 = (($contactBuffer) + 4096|0);
  $239 = HEAP32[$238>>2]|0;
  $240 = ($239>>>0)>(63);
  if (!($240)) {
   $241 = Math_fround($48 * $237);
   $242 = Math_fround($47 * $237);
   $243 = Math_fround($45 * $237);
   $244 = Math_fround($44 * $131);
   $245 = Math_fround($43 * $131);
   $246 = Math_fround($42 * $131);
   $247 = Math_fround($51 * $135);
   $248 = Math_fround($50 * $135);
   $249 = Math_fround($49 * $135);
   $250 = Math_fround($244 + $241);
   $251 = Math_fround($245 + $242);
   $252 = Math_fround($246 + $243);
   $253 = Math_fround(HEAPF32[$contactDistance>>2]);
   $254 = Math_fround($247 + $250);
   $255 = Math_fround($248 + $251);
   $256 = Math_fround($249 + $252);
   $257 = Math_fround($148 + $253);
   $258 = Math_fround($57 + $254);
   $259 = Math_fround($55 + $255);
   $260 = Math_fround($53 + $256);
   $261 = (($239) + 1)|0;
   HEAP32[$238>>2] = $261;
   $262 = (($contactBuffer) + ($239<<6)|0);
   HEAPF32[$262>>2] = $19;
   $263 = ((($contactBuffer) + ($239<<6)|0) + 4|0);
   HEAPF32[$263>>2] = $20;
   $264 = ((($contactBuffer) + ($239<<6)|0) + 8|0);
   HEAPF32[$264>>2] = $21;
   $265 = ((($contactBuffer) + ($239<<6)|0) + 16|0);
   HEAPF32[$265>>2] = $260;
   $266 = ((($contactBuffer) + ($239<<6)|0) + 20|0);
   HEAPF32[$266>>2] = $259;
   $267 = ((($contactBuffer) + ($239<<6)|0) + 24|0);
   HEAPF32[$267>>2] = $258;
   $268 = ((($contactBuffer) + ($239<<6)|0) + 12|0);
   HEAPF32[$268>>2] = $257;
   $269 = ((($contactBuffer) + ($239<<6)|0) + 48|0);
   HEAP32[$269>>2] = -1;
   $270 = ((($contactBuffer) + ($239<<6)|0) + 52|0);
   HEAP32[$270>>2] = -1;
  }
 }
 $271 = ($152|0)<(0);
 if ($271) {
  $272 = Math_fround(-$133);
  $273 = Math_fround(-$135);
  $274 = (($contactBuffer) + 4096|0);
  $275 = HEAP32[$274>>2]|0;
  $276 = ($275>>>0)>(63);
  if (!($276)) {
   $277 = Math_fround($48 * $272);
   $278 = Math_fround($47 * $272);
   $279 = Math_fround($45 * $272);
   $280 = Math_fround($44 * $131);
   $281 = Math_fround($43 * $131);
   $282 = Math_fround($42 * $131);
   $283 = Math_fround($51 * $273);
   $284 = Math_fround($50 * $273);
   $285 = Math_fround($49 * $273);
   $286 = Math_fround($280 + $277);
   $287 = Math_fround($281 + $278);
   $288 = Math_fround($282 + $279);
   $289 = Math_fround(HEAPF32[$contactDistance>>2]);
   $290 = Math_fround($286 + $283);
   $291 = Math_fround($287 + $284);
   $292 = Math_fround($288 + $285);
   $293 = Math_fround($151 + $289);
   $294 = Math_fround($57 + $290);
   $295 = Math_fround($55 + $291);
   $296 = Math_fround($53 + $292);
   $297 = (($275) + 1)|0;
   HEAP32[$274>>2] = $297;
   $298 = (($contactBuffer) + ($275<<6)|0);
   HEAPF32[$298>>2] = $19;
   $299 = ((($contactBuffer) + ($275<<6)|0) + 4|0);
   HEAPF32[$299>>2] = $20;
   $300 = ((($contactBuffer) + ($275<<6)|0) + 8|0);
   HEAPF32[$300>>2] = $21;
   $301 = ((($contactBuffer) + ($275<<6)|0) + 16|0);
   HEAPF32[$301>>2] = $296;
   $302 = ((($contactBuffer) + ($275<<6)|0) + 20|0);
   HEAPF32[$302>>2] = $295;
   $303 = ((($contactBuffer) + ($275<<6)|0) + 24|0);
   HEAPF32[$303>>2] = $294;
   $304 = ((($contactBuffer) + ($275<<6)|0) + 12|0);
   HEAPF32[$304>>2] = $293;
   $305 = ((($contactBuffer) + ($275<<6)|0) + 48|0);
   HEAP32[$305>>2] = -1;
   $306 = ((($contactBuffer) + ($275<<6)|0) + 52|0);
   HEAP32[$306>>2] = -1;
  }
 }
 $307 = ($157|0)<(0);
 if ($307) {
  $308 = Math_fround(-$131);
  $309 = (($contactBuffer) + 4096|0);
  $310 = HEAP32[$309>>2]|0;
  $311 = ($310>>>0)>(63);
  if (!($311)) {
   $312 = Math_fround($48 * $133);
   $313 = Math_fround($47 * $133);
   $314 = Math_fround($45 * $133);
   $315 = Math_fround($44 * $308);
   $316 = Math_fround($43 * $308);
   $317 = Math_fround($42 * $308);
   $318 = Math_fround($51 * $135);
   $319 = Math_fround($50 * $135);
   $320 = Math_fround($49 * $135);
   $321 = Math_fround($315 + $312);
   $322 = Math_fround($316 + $313);
   $323 = Math_fround($317 + $314);
   $324 = Math_fround(HEAPF32[$contactDistance>>2]);
   $325 = Math_fround($321 + $318);
   $326 = Math_fround($322 + $319);
   $327 = Math_fround($323 + $320);
   $328 = Math_fround($156 + $324);
   $329 = Math_fround($57 + $325);
   $330 = Math_fround($55 + $326);
   $331 = Math_fround($53 + $327);
   $332 = (($310) + 1)|0;
   HEAP32[$309>>2] = $332;
   $333 = (($contactBuffer) + ($310<<6)|0);
   HEAPF32[$333>>2] = $19;
   $334 = ((($contactBuffer) + ($310<<6)|0) + 4|0);
   HEAPF32[$334>>2] = $20;
   $335 = ((($contactBuffer) + ($310<<6)|0) + 8|0);
   HEAPF32[$335>>2] = $21;
   $336 = ((($contactBuffer) + ($310<<6)|0) + 16|0);
   HEAPF32[$336>>2] = $331;
   $337 = ((($contactBuffer) + ($310<<6)|0) + 20|0);
   HEAPF32[$337>>2] = $330;
   $338 = ((($contactBuffer) + ($310<<6)|0) + 24|0);
   HEAPF32[$338>>2] = $329;
   $339 = ((($contactBuffer) + ($310<<6)|0) + 12|0);
   HEAPF32[$339>>2] = $328;
   $340 = ((($contactBuffer) + ($310<<6)|0) + 48|0);
   HEAP32[$340>>2] = -1;
   $341 = ((($contactBuffer) + ($310<<6)|0) + 52|0);
   HEAP32[$341>>2] = -1;
  }
 }
 $342 = ($160|0)<(0);
 if ($342) {
  $343 = Math_fround(-$131);
  $344 = Math_fround(-$135);
  $345 = (($contactBuffer) + 4096|0);
  $346 = HEAP32[$345>>2]|0;
  $347 = ($346>>>0)>(63);
  if (!($347)) {
   $348 = Math_fround($48 * $133);
   $349 = Math_fround($47 * $133);
   $350 = Math_fround($45 * $133);
   $351 = Math_fround($44 * $343);
   $352 = Math_fround($43 * $343);
   $353 = Math_fround($42 * $343);
   $354 = Math_fround($51 * $344);
   $355 = Math_fround($50 * $344);
   $356 = Math_fround($49 * $344);
   $357 = Math_fround($351 + $348);
   $358 = Math_fround($352 + $349);
   $359 = Math_fround($353 + $350);
   $360 = Math_fround(HEAPF32[$contactDistance>>2]);
   $361 = Math_fround($357 + $354);
   $362 = Math_fround($358 + $355);
   $363 = Math_fround($359 + $356);
   $364 = Math_fround($159 + $360);
   $365 = Math_fround($57 + $361);
   $366 = Math_fround($55 + $362);
   $367 = Math_fround($53 + $363);
   $368 = (($346) + 1)|0;
   HEAP32[$345>>2] = $368;
   $369 = (($contactBuffer) + ($346<<6)|0);
   HEAPF32[$369>>2] = $19;
   $370 = ((($contactBuffer) + ($346<<6)|0) + 4|0);
   HEAPF32[$370>>2] = $20;
   $371 = ((($contactBuffer) + ($346<<6)|0) + 8|0);
   HEAPF32[$371>>2] = $21;
   $372 = ((($contactBuffer) + ($346<<6)|0) + 16|0);
   HEAPF32[$372>>2] = $367;
   $373 = ((($contactBuffer) + ($346<<6)|0) + 20|0);
   HEAPF32[$373>>2] = $366;
   $374 = ((($contactBuffer) + ($346<<6)|0) + 24|0);
   HEAPF32[$374>>2] = $365;
   $375 = ((($contactBuffer) + ($346<<6)|0) + 12|0);
   HEAPF32[$375>>2] = $364;
   $376 = ((($contactBuffer) + ($346<<6)|0) + 48|0);
   HEAP32[$376>>2] = -1;
   $377 = ((($contactBuffer) + ($346<<6)|0) + 52|0);
   HEAP32[$377>>2] = -1;
  }
 }
 $378 = ($164|0)<(0);
 if ($378) {
  $379 = Math_fround(-$131);
  $380 = Math_fround(-$133);
  $381 = (($contactBuffer) + 4096|0);
  $382 = HEAP32[$381>>2]|0;
  $383 = ($382>>>0)>(63);
  if (!($383)) {
   $384 = Math_fround($48 * $380);
   $385 = Math_fround($47 * $380);
   $386 = Math_fround($45 * $380);
   $387 = Math_fround($44 * $379);
   $388 = Math_fround($43 * $379);
   $389 = Math_fround($42 * $379);
   $390 = Math_fround($51 * $135);
   $391 = Math_fround($50 * $135);
   $392 = Math_fround($49 * $135);
   $393 = Math_fround($387 + $384);
   $394 = Math_fround($388 + $385);
   $395 = Math_fround($389 + $386);
   $396 = Math_fround(HEAPF32[$contactDistance>>2]);
   $397 = Math_fround($390 + $393);
   $398 = Math_fround($391 + $394);
   $399 = Math_fround($392 + $395);
   $400 = Math_fround($163 + $396);
   $401 = Math_fround($57 + $397);
   $402 = Math_fround($55 + $398);
   $403 = Math_fround($53 + $399);
   $404 = (($382) + 1)|0;
   HEAP32[$381>>2] = $404;
   $405 = (($contactBuffer) + ($382<<6)|0);
   HEAPF32[$405>>2] = $19;
   $406 = ((($contactBuffer) + ($382<<6)|0) + 4|0);
   HEAPF32[$406>>2] = $20;
   $407 = ((($contactBuffer) + ($382<<6)|0) + 8|0);
   HEAPF32[$407>>2] = $21;
   $408 = ((($contactBuffer) + ($382<<6)|0) + 16|0);
   HEAPF32[$408>>2] = $403;
   $409 = ((($contactBuffer) + ($382<<6)|0) + 20|0);
   HEAPF32[$409>>2] = $402;
   $410 = ((($contactBuffer) + ($382<<6)|0) + 24|0);
   HEAPF32[$410>>2] = $401;
   $411 = ((($contactBuffer) + ($382<<6)|0) + 12|0);
   HEAPF32[$411>>2] = $400;
   $412 = ((($contactBuffer) + ($382<<6)|0) + 48|0);
   HEAP32[$412>>2] = -1;
   $413 = ((($contactBuffer) + ($382<<6)|0) + 52|0);
   HEAP32[$413>>2] = -1;
  }
 }
 $414 = ($167|0)<(0);
 if (!($414)) {
  $$pre = (($contactBuffer) + 4096|0);
  $$pre$phiZ2D = $$pre;
  $451 = HEAP32[$$pre$phiZ2D>>2]|0;
  $452 = ($451|0)!=(0);
  STACKTOP = sp;return ($452|0);
 }
 $415 = Math_fround(-$131);
 $416 = Math_fround(-$133);
 $417 = Math_fround(-$135);
 $418 = (($contactBuffer) + 4096|0);
 $419 = HEAP32[$418>>2]|0;
 $420 = ($419>>>0)>(63);
 if ($420) {
  $$pre$phiZ2D = $418;
  $451 = HEAP32[$$pre$phiZ2D>>2]|0;
  $452 = ($451|0)!=(0);
  STACKTOP = sp;return ($452|0);
 }
 $421 = Math_fround($48 * $416);
 $422 = Math_fround($47 * $416);
 $423 = Math_fround($45 * $416);
 $424 = Math_fround($44 * $415);
 $425 = Math_fround($43 * $415);
 $426 = Math_fround($42 * $415);
 $427 = Math_fround($51 * $417);
 $428 = Math_fround($50 * $417);
 $429 = Math_fround($49 * $417);
 $430 = Math_fround($424 + $421);
 $431 = Math_fround($425 + $422);
 $432 = Math_fround($426 + $423);
 $433 = Math_fround(HEAPF32[$contactDistance>>2]);
 $434 = Math_fround($430 + $427);
 $435 = Math_fround($431 + $428);
 $436 = Math_fround($432 + $429);
 $437 = Math_fround($166 + $433);
 $438 = Math_fround($57 + $434);
 $439 = Math_fround($55 + $435);
 $440 = Math_fround($53 + $436);
 $441 = (($419) + 1)|0;
 HEAP32[$418>>2] = $441;
 $442 = (($contactBuffer) + ($419<<6)|0);
 HEAPF32[$442>>2] = $19;
 $443 = ((($contactBuffer) + ($419<<6)|0) + 4|0);
 HEAPF32[$443>>2] = $20;
 $444 = ((($contactBuffer) + ($419<<6)|0) + 8|0);
 HEAPF32[$444>>2] = $21;
 $445 = ((($contactBuffer) + ($419<<6)|0) + 16|0);
 HEAPF32[$445>>2] = $440;
 $446 = ((($contactBuffer) + ($419<<6)|0) + 20|0);
 HEAPF32[$446>>2] = $439;
 $447 = ((($contactBuffer) + ($419<<6)|0) + 24|0);
 HEAPF32[$447>>2] = $438;
 $448 = ((($contactBuffer) + ($419<<6)|0) + 12|0);
 HEAPF32[$448>>2] = $437;
 $449 = ((($contactBuffer) + ($419<<6)|0) + 48|0);
 HEAP32[$449>>2] = -1;
 $450 = ((($contactBuffer) + ($419<<6)|0) + 52|0);
 HEAP32[$450>>2] = -1;
 $$pre$phiZ2D = $418;
 $451 = HEAP32[$$pre$phiZ2D>>2]|0;
 $452 = ($451|0)!=(0);
 STACKTOP = sp;return ($452|0);
}
function __ZN5physx22PxcContactPlaneCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$pre = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $contact$0$off0 = 0, $contact$1$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround(-$0);
 $2 = (($transform0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(-$3);
 $5 = (($transform0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 $8 = (($transform0) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($transform1) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform0) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($transform1) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transform0) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = (($transform1) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transform0) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 $25 = Math_fround($14 * Math_fround(2.0));
 $26 = Math_fround($19 * Math_fround(2.0));
 $27 = Math_fround($24 * Math_fround(2.0));
 $28 = Math_fround($9 * $9);
 $29 = Math_fround($28 + Math_fround(-0.5));
 $30 = Math_fround($25 * $1);
 $31 = Math_fround($26 * $4);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($27 * $7);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($29 * $25);
 $36 = Math_fround($27 * $4);
 $37 = Math_fround($26 * $7);
 $38 = Math_fround($36 - $37);
 $39 = Math_fround($9 * $38);
 $40 = Math_fround($35 + $39);
 $41 = Math_fround($34 * $1);
 $42 = Math_fround($41 + $40);
 $43 = Math_fround($29 * $26);
 $44 = Math_fround($25 * $7);
 $45 = Math_fround($27 * $1);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($9 * $46);
 $48 = Math_fround($43 + $47);
 $49 = Math_fround($34 * $4);
 $50 = Math_fround($49 + $48);
 $51 = Math_fround($29 * $27);
 $52 = Math_fround($26 * $1);
 $53 = Math_fround($25 * $4);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($9 * $54);
 $56 = Math_fround($51 + $55);
 $57 = Math_fround($34 * $7);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround(HEAPF32[$transform1>>2]);
 $60 = Math_fround($9 * $59);
 $61 = (($transform1) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * $1);
 $64 = Math_fround($60 + $63);
 $65 = (($transform1) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $4);
 $68 = Math_fround($64 + $67);
 $69 = (($transform1) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $7);
 $72 = Math_fround($68 - $71);
 $73 = Math_fround($9 * $70);
 $74 = Math_fround($62 * $4);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($59 * $7);
 $77 = Math_fround($76 + $75);
 $78 = Math_fround($66 * $1);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($9 * $66);
 $81 = Math_fround($62 * $7);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($70 * $1);
 $84 = Math_fround($83 + $82);
 $85 = Math_fround($59 * $4);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($9 * $62);
 $88 = Math_fround($59 * $1);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($70 * $4);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($66 * $7);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($72 * Math_fround(2.0));
 $95 = Math_fround($93 * Math_fround(2.0));
 $96 = Math_fround($93 * $95);
 $97 = Math_fround($96 + Math_fround(-1.0));
 $98 = Math_fround($72 * $94);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($86 * $95);
 $101 = Math_fround($94 * $79);
 $102 = Math_fround($100 + $101);
 $103 = Math_fround($95 * $79);
 $104 = Math_fround($94 * $86);
 $105 = Math_fround($104 - $103);
 $106 = (($shape1) + 8|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($107 * $99);
 $109 = Math_fround($107 * $102);
 $110 = Math_fround($107 * $105);
 $111 = Math_fround($42 + $108);
 $112 = Math_fround($42 - $108);
 $113 = Math_fround($50 - $109);
 $114 = Math_fround($58 - $110);
 $115 = Math_fround(HEAPF32[$transform0>>2]);
 $116 = Math_fround($115 * Math_fround(2.0));
 $117 = Math_fround(HEAPF32[$8>>2]);
 $118 = Math_fround($117 * Math_fround(2.0));
 $119 = Math_fround($117 * $118);
 $120 = Math_fround($119 + Math_fround(-1.0));
 $121 = Math_fround($115 * $116);
 $122 = Math_fround($121 + $120);
 $123 = Math_fround(HEAPF32[$5>>2]);
 $124 = Math_fround($123 * $118);
 $125 = Math_fround(HEAPF32[$2>>2]);
 $126 = Math_fround($116 * $125);
 $127 = Math_fround($124 + $126);
 $128 = Math_fround($118 * $125);
 $129 = Math_fround($116 * $123);
 $130 = Math_fround($129 - $128);
 $131 = (($shape1) + 4|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($111 - $132);
 $134 = Math_fround($112 - $132);
 $135 = Math_fround(HEAPF32[$contactDistance>>2]);
 $136 = !($133 <= $135);
 if ($136) {
  $191 = $135;$contact$0$off0 = 0;
 } else {
  $137 = Math_fround($58 + $110);
  $138 = Math_fround($50 + $109);
  $139 = Math_fround($133 * Math_fround(2.0));
  $140 = Math_fround($138 * Math_fround(2.0));
  $141 = Math_fround($137 * Math_fround(2.0));
  $142 = Math_fround($0 * $139);
  $143 = Math_fround($3 * $140);
  $144 = Math_fround($143 + $142);
  $145 = Math_fround($6 * $141);
  $146 = Math_fround($145 + $144);
  $147 = (($contactBuffer) + 4096|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = ($148>>>0)>(63);
  if ($149) {
   $191 = $135;$contact$0$off0 = 1;
  } else {
   $150 = Math_fround($3 * $139);
   $151 = Math_fround($0 * $140);
   $152 = Math_fround($0 * $141);
   $153 = Math_fround($6 * $139);
   $154 = Math_fround($6 * $140);
   $155 = Math_fround($3 * $141);
   $156 = Math_fround($151 - $150);
   $157 = Math_fround($153 - $152);
   $158 = Math_fround($155 - $154);
   $159 = Math_fround($9 * $156);
   $160 = Math_fround($29 * $141);
   $161 = Math_fround($9 * $157);
   $162 = Math_fround($29 * $140);
   $163 = Math_fround($9 * $158);
   $164 = Math_fround($29 * $139);
   $165 = Math_fround($6 * $146);
   $166 = Math_fround($160 + $159);
   $167 = Math_fround($3 * $146);
   $168 = Math_fround($162 + $161);
   $169 = Math_fround($0 * $146);
   $170 = Math_fround($164 + $163);
   $171 = Math_fround($166 + $165);
   $172 = Math_fround($167 + $168);
   $173 = Math_fround($170 + $169);
   $174 = Math_fround(-$130);
   $175 = Math_fround(-$127);
   $176 = Math_fround(-$122);
   $177 = Math_fround($23 + $171);
   $178 = Math_fround($18 + $172);
   $179 = Math_fround($13 + $173);
   $180 = (($148) + 1)|0;
   HEAP32[$147>>2] = $180;
   $181 = (($contactBuffer) + ($148<<6)|0);
   HEAPF32[$181>>2] = $176;
   $182 = ((($contactBuffer) + ($148<<6)|0) + 4|0);
   HEAPF32[$182>>2] = $175;
   $183 = ((($contactBuffer) + ($148<<6)|0) + 8|0);
   HEAPF32[$183>>2] = $174;
   $184 = ((($contactBuffer) + ($148<<6)|0) + 16|0);
   HEAPF32[$184>>2] = $179;
   $185 = ((($contactBuffer) + ($148<<6)|0) + 20|0);
   HEAPF32[$185>>2] = $178;
   $186 = ((($contactBuffer) + ($148<<6)|0) + 24|0);
   HEAPF32[$186>>2] = $177;
   $187 = ((($contactBuffer) + ($148<<6)|0) + 12|0);
   HEAPF32[$187>>2] = $133;
   $188 = ((($contactBuffer) + ($148<<6)|0) + 48|0);
   HEAP32[$188>>2] = -1;
   $189 = ((($contactBuffer) + ($148<<6)|0) + 52|0);
   HEAP32[$189>>2] = -1;
   $$pre = Math_fround(HEAPF32[$contactDistance>>2]);
   $191 = $$pre;$contact$0$off0 = 1;
  }
 }
 $190 = !($134 <= $191);
 if ($190) {
  $contact$1$off0 = $contact$0$off0;
  STACKTOP = sp;return ($contact$1$off0|0);
 }
 $192 = Math_fround(HEAPF32[$131>>2]);
 $193 = Math_fround($112 - $192);
 $194 = Math_fround($193 * Math_fround(2.0));
 $195 = Math_fround($113 * Math_fround(2.0));
 $196 = Math_fround($114 * Math_fround(2.0));
 $197 = Math_fround(HEAPF32[$8>>2]);
 $198 = Math_fround($197 * $197);
 $199 = Math_fround($198 + Math_fround(-0.5));
 $200 = Math_fround(HEAPF32[$transform0>>2]);
 $201 = Math_fround($194 * $200);
 $202 = Math_fround(HEAPF32[$2>>2]);
 $203 = Math_fround($195 * $202);
 $204 = Math_fround($201 + $203);
 $205 = Math_fround(HEAPF32[$5>>2]);
 $206 = Math_fround($196 * $205);
 $207 = Math_fround($204 + $206);
 $208 = (($contactBuffer) + 4096|0);
 $209 = HEAP32[$208>>2]|0;
 $210 = ($209>>>0)>(63);
 if ($210) {
  $contact$1$off0 = 1;
  STACKTOP = sp;return ($contact$1$off0|0);
 }
 $211 = Math_fround($194 * $202);
 $212 = Math_fround($195 * $200);
 $213 = Math_fround($196 * $200);
 $214 = Math_fround($194 * $205);
 $215 = Math_fround($195 * $205);
 $216 = Math_fround($196 * $202);
 $217 = Math_fround($212 - $211);
 $218 = Math_fround($214 - $213);
 $219 = Math_fround($216 - $215);
 $220 = Math_fround($197 * $217);
 $221 = Math_fround($196 * $199);
 $222 = Math_fround($197 * $218);
 $223 = Math_fround($195 * $199);
 $224 = Math_fround($197 * $219);
 $225 = Math_fround($194 * $199);
 $226 = Math_fround($205 * $207);
 $227 = Math_fround($221 + $220);
 $228 = Math_fround($202 * $207);
 $229 = Math_fround($223 + $222);
 $230 = Math_fround($200 * $207);
 $231 = Math_fround($225 + $224);
 $232 = Math_fround(HEAPF32[$22>>2]);
 $233 = Math_fround(HEAPF32[$17>>2]);
 $234 = Math_fround(HEAPF32[$12>>2]);
 $235 = Math_fround($227 + $226);
 $236 = Math_fround($228 + $229);
 $237 = Math_fround($230 + $231);
 $238 = Math_fround(-$130);
 $239 = Math_fround(-$127);
 $240 = Math_fround(-$122);
 $241 = Math_fround($235 + $232);
 $242 = Math_fround($236 + $233);
 $243 = Math_fround($237 + $234);
 $244 = (($209) + 1)|0;
 HEAP32[$208>>2] = $244;
 $245 = (($contactBuffer) + ($209<<6)|0);
 HEAPF32[$245>>2] = $240;
 $246 = ((($contactBuffer) + ($209<<6)|0) + 4|0);
 HEAPF32[$246>>2] = $239;
 $247 = ((($contactBuffer) + ($209<<6)|0) + 8|0);
 HEAPF32[$247>>2] = $238;
 $248 = ((($contactBuffer) + ($209<<6)|0) + 16|0);
 HEAPF32[$248>>2] = $243;
 $249 = ((($contactBuffer) + ($209<<6)|0) + 20|0);
 HEAPF32[$249>>2] = $242;
 $250 = ((($contactBuffer) + ($209<<6)|0) + 24|0);
 HEAPF32[$250>>2] = $241;
 $251 = ((($contactBuffer) + ($209<<6)|0) + 12|0);
 HEAPF32[$251>>2] = $134;
 $252 = ((($contactBuffer) + ($209<<6)|0) + 48|0);
 HEAP32[$252>>2] = -1;
 $253 = ((($contactBuffer) + ($209<<6)|0) + 52|0);
 HEAP32[$253>>2] = -1;
 $contact$1$off0 = 1;
 STACKTOP = sp;return ($contact$1$off0|0);
}
function __ZN5physx21PxcContactPlaneConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$pre = Math_fround(0), $$pre28 = Math_fround(0), $$pre29 = Math_fround(0), $$pre30 = Math_fround(0), $$pre31 = Math_fround(0), $$pre32 = Math_fround(0), $$pre33 = Math_fround(0), $$pre34 = Math_fround(0), $$pre35 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0);
 var $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0);
 var $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0);
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0);
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0;
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $convexScaling = 0, $hullVertices$0 = 0, $hullVertices$0$ph = 0, $numHullVertices$0 = 0, $numHullVertices$0$ph = 0, $status$0$off0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $convexScaling = sp;
 $0 = (($shape1) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 39|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = (($3) + (($6*20)|0)|0);
 $8 = (($1) + 38|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = Math_fround(HEAPF32[$transform0>>2]);
 $12 = Math_fround(-$11);
 $13 = (($transform0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(-$14);
 $16 = (($transform0) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(-$17);
 $19 = (($transform0) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform1) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 - $24);
 $26 = (($transform1) + 20|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($transform0) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($27 - $29);
 $31 = (($transform1) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($transform0) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($32 - $34);
 $36 = Math_fround($25 * Math_fround(2.0));
 $37 = Math_fround($30 * Math_fround(2.0));
 $38 = Math_fround($35 * Math_fround(2.0));
 $39 = Math_fround($20 * $20);
 $40 = Math_fround($39 + Math_fround(-0.5));
 $41 = Math_fround($36 * $12);
 $42 = Math_fround($37 * $15);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($38 * $18);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($40 * $36);
 $47 = Math_fround($38 * $15);
 $48 = Math_fround($37 * $18);
 $49 = Math_fround($47 - $48);
 $50 = Math_fround($20 * $49);
 $51 = Math_fround($46 + $50);
 $52 = Math_fround($45 * $12);
 $53 = Math_fround($52 + $51);
 $54 = Math_fround($40 * $37);
 $55 = Math_fround($36 * $18);
 $56 = Math_fround($38 * $12);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($20 * $57);
 $59 = Math_fround($54 + $58);
 $60 = Math_fround($45 * $15);
 $61 = Math_fround($60 + $59);
 $62 = Math_fround($40 * $38);
 $63 = Math_fround($37 * $12);
 $64 = Math_fround($36 * $15);
 $65 = Math_fround($63 - $64);
 $66 = Math_fround($20 * $65);
 $67 = Math_fround($62 + $66);
 $68 = Math_fround($45 * $18);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround(HEAPF32[$transform1>>2]);
 $71 = Math_fround($20 * $70);
 $72 = (($transform1) + 12|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 * $12);
 $75 = Math_fround($71 + $74);
 $76 = (($transform1) + 8|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 * $15);
 $79 = Math_fround($75 + $78);
 $80 = (($transform1) + 4|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 * $18);
 $83 = Math_fround($79 - $82);
 $84 = Math_fround($20 * $81);
 $85 = Math_fround($73 * $15);
 $86 = Math_fround($85 + $84);
 $87 = Math_fround($70 * $18);
 $88 = Math_fround($87 + $86);
 $89 = Math_fround($77 * $12);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($20 * $77);
 $92 = Math_fround($73 * $18);
 $93 = Math_fround($92 + $91);
 $94 = Math_fround($81 * $12);
 $95 = Math_fround($94 + $93);
 $96 = Math_fround($70 * $15);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($20 * $73);
 $99 = Math_fround($70 * $12);
 $100 = Math_fround($98 - $99);
 $101 = Math_fround($81 * $15);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($77 * $18);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($83 + $83);
 $106 = Math_fround($90 + $90);
 $107 = Math_fround($97 + $97);
 $108 = Math_fround($105 * $104);
 $109 = Math_fround($104 * $106);
 $110 = Math_fround($104 * $107);
 $111 = Math_fround($83 * $105);
 $112 = Math_fround($83 * $106);
 $113 = Math_fround($83 * $107);
 $114 = Math_fround($90 * $106);
 $115 = Math_fround($90 * $107);
 $116 = Math_fround($97 * $107);
 $117 = Math_fround(Math_fround(1.0) - $114);
 $118 = Math_fround($117 - $116);
 $119 = Math_fround($110 + $112);
 $120 = Math_fround($113 - $109);
 $121 = Math_fround($112 - $110);
 $122 = Math_fround(Math_fround(1.0) - $111);
 $123 = Math_fround($122 - $116);
 $124 = Math_fround($108 + $115);
 $125 = Math_fround($113 + $109);
 $126 = Math_fround($115 - $108);
 $127 = Math_fround($122 - $114);
 $128 = (($shape1) + 4|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = $129 == Math_fround(1.0);
 if ($130) {
  $131 = (($shape1) + 8|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = $132 == Math_fround(1.0);
  if ($133) {
   $134 = (($shape1) + 12|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = $135 == Math_fround(1.0);
   $302 = $136;
  } else {
   $302 = 0;
  }
 } else {
  $302 = 0;
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $137 = (($convexScaling) + 4|0);
 HEAPF32[$137>>2] = Math_fround(0.0);
 $138 = (($convexScaling) + 8|0);
 HEAPF32[$138>>2] = Math_fround(0.0);
 $139 = (($convexScaling) + 12|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($convexScaling) + 16|0);
 HEAPF32[$140>>2] = Math_fround(1.0);
 $141 = (($convexScaling) + 20|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 $142 = (($convexScaling) + 24|0);
 HEAPF32[$142>>2] = Math_fround(0.0);
 $143 = (($convexScaling) + 28|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = (($convexScaling) + 32|0);
 HEAPF32[$144>>2] = Math_fround(1.0);
 $145 = (($convexScaling) + 36|0);
 HEAPF32[$145>>2] = Math_fround(1.0);
 $146 = (($convexScaling) + 40|0);
 HEAPF32[$146>>2] = Math_fround(0.0);
 $147 = (($convexScaling) + 44|0);
 HEAPF32[$147>>2] = Math_fround(0.0);
 $148 = (($convexScaling) + 48|0);
 HEAPF32[$148>>2] = Math_fround(0.0);
 $149 = (($convexScaling) + 52|0);
 HEAPF32[$149>>2] = Math_fround(1.0);
 $150 = (($convexScaling) + 56|0);
 HEAPF32[$150>>2] = Math_fround(0.0);
 $151 = (($convexScaling) + 60|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = (($convexScaling) + 64|0);
 HEAPF32[$152>>2] = Math_fround(0.0);
 $153 = (($convexScaling) + 68|0);
 HEAPF32[$153>>2] = Math_fround(1.0);
 if ($302) {
  $156 = Math_fround(1.0);$160 = Math_fround(0.0);$167 = Math_fround(0.0);$174 = Math_fround(0.0);$178 = Math_fround(1.0);$185 = Math_fround(0.0);$192 = Math_fround(0.0);$196 = Math_fround(0.0);$203 = Math_fround(1.0);
 } else {
  $154 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$128,$154);
  $$pre = Math_fround(HEAPF32[$convexScaling>>2]);
  $$pre28 = Math_fround(HEAPF32[$137>>2]);
  $$pre29 = Math_fround(HEAPF32[$138>>2]);
  $$pre30 = Math_fround(HEAPF32[$139>>2]);
  $$pre31 = Math_fround(HEAPF32[$140>>2]);
  $$pre32 = Math_fround(HEAPF32[$141>>2]);
  $$pre33 = Math_fround(HEAPF32[$142>>2]);
  $$pre34 = Math_fround(HEAPF32[$143>>2]);
  $$pre35 = Math_fround(HEAPF32[$144>>2]);
  $156 = $$pre;$160 = $$pre28;$167 = $$pre29;$174 = $$pre30;$178 = $$pre31;$185 = $$pre32;$192 = $$pre33;$196 = $$pre34;$203 = $$pre35;
 }
 $155 = Math_fround($118 * $156);
 $157 = Math_fround($119 * $156);
 $158 = Math_fround($120 * $156);
 $159 = Math_fround($121 * $160);
 $161 = Math_fround($123 * $160);
 $162 = Math_fround($124 * $160);
 $163 = Math_fround($155 + $159);
 $164 = Math_fround($157 + $161);
 $165 = Math_fround($158 + $162);
 $166 = Math_fround($125 * $167);
 $168 = Math_fround($126 * $167);
 $169 = Math_fround($127 * $167);
 $170 = Math_fround($163 + $166);
 $171 = Math_fround($164 + $168);
 $172 = Math_fround($165 + $169);
 $173 = Math_fround($118 * $174);
 $175 = Math_fround($119 * $174);
 $176 = Math_fround($120 * $174);
 $177 = Math_fround($121 * $178);
 $179 = Math_fround($123 * $178);
 $180 = Math_fround($124 * $178);
 $181 = Math_fround($173 + $177);
 $182 = Math_fround($175 + $179);
 $183 = Math_fround($176 + $180);
 $184 = Math_fround($125 * $185);
 $186 = Math_fround($126 * $185);
 $187 = Math_fround($127 * $185);
 $188 = Math_fround($181 + $184);
 $189 = Math_fround($182 + $186);
 $190 = Math_fround($183 + $187);
 $191 = Math_fround($118 * $192);
 $193 = Math_fround($119 * $192);
 $194 = Math_fround($120 * $192);
 $195 = Math_fround($121 * $196);
 $197 = Math_fround($123 * $196);
 $198 = Math_fround($124 * $196);
 $199 = Math_fround($191 + $195);
 $200 = Math_fround($193 + $197);
 $201 = Math_fround($194 + $198);
 $202 = Math_fround($125 * $203);
 $204 = Math_fround($126 * $203);
 $205 = Math_fround($127 * $203);
 $206 = Math_fround($199 + $202);
 $207 = Math_fround($200 + $204);
 $208 = Math_fround($201 + $205);
 $209 = Math_fround(HEAPF32[$transform0>>2]);
 $210 = Math_fround($209 + $209);
 $211 = Math_fround(HEAPF32[$13>>2]);
 $212 = Math_fround($211 + $211);
 $213 = Math_fround(HEAPF32[$16>>2]);
 $214 = Math_fround($213 + $213);
 $215 = Math_fround(HEAPF32[$19>>2]);
 $216 = Math_fround($210 * $215);
 $217 = Math_fround($212 * $215);
 $218 = Math_fround($215 * $214);
 $219 = Math_fround($209 * $210);
 $220 = Math_fround($209 * $212);
 $221 = Math_fround($209 * $214);
 $222 = Math_fround($211 * $212);
 $223 = Math_fround($211 * $214);
 $224 = Math_fround($213 * $214);
 $225 = Math_fround(Math_fround(1.0) - $222);
 $226 = Math_fround($225 - $224);
 $227 = Math_fround($220 + $218);
 $228 = Math_fround($221 - $217);
 $229 = Math_fround($220 - $218);
 $230 = Math_fround(Math_fround(1.0) - $219);
 $231 = Math_fround($230 - $224);
 $232 = Math_fround($223 + $216);
 $233 = Math_fround($221 + $217);
 $234 = Math_fround($223 - $216);
 $235 = Math_fround($230 - $222);
 $236 = Math_fround(HEAPF32[$23>>2]);
 $237 = Math_fround(HEAPF32[$28>>2]);
 $238 = Math_fround(HEAPF32[$33>>2]);
 $239 = Math_fround(-$226);
 $240 = Math_fround(-$227);
 $241 = Math_fround(-$228);
 $242 = (($contactBuffer) + 4096|0);
 $hullVertices$0$ph = $7;$numHullVertices$0$ph = $10;$status$0$off0$ph = 0;
 L8: while(1) {
  $hullVertices$0 = $hullVertices$0$ph;$numHullVertices$0 = $numHullVertices$0$ph;
  while(1) {
   $243 = (($numHullVertices$0) + -1)|0;
   $244 = ($numHullVertices$0|0)==(0);
   if ($244) {
    break L8;
   }
   $245 = (($hullVertices$0) + 12|0);
   $246 = Math_fround(HEAPF32[$hullVertices$0>>2]);
   $247 = Math_fround($170 * $246);
   $248 = Math_fround($171 * $246);
   $249 = Math_fround($172 * $246);
   $250 = (($hullVertices$0) + 4|0);
   $251 = Math_fround(HEAPF32[$250>>2]);
   $252 = Math_fround($188 * $251);
   $253 = Math_fround($189 * $251);
   $254 = Math_fround($190 * $251);
   $255 = Math_fround($247 + $252);
   $256 = Math_fround($248 + $253);
   $257 = Math_fround($249 + $254);
   $258 = (($hullVertices$0) + 8|0);
   $259 = Math_fround(HEAPF32[$258>>2]);
   $260 = Math_fround($206 * $259);
   $261 = Math_fround($207 * $259);
   $262 = Math_fround($208 * $259);
   $263 = Math_fround($255 + $260);
   $264 = Math_fround($256 + $261);
   $265 = Math_fround($257 + $262);
   $266 = Math_fround($53 + $263);
   $267 = Math_fround($61 + $264);
   $268 = Math_fround($69 + $265);
   $269 = Math_fround(HEAPF32[$contactDistance>>2]);
   $270 = !($266 <= $269);
   if ($270) {
    $hullVertices$0 = $245;$numHullVertices$0 = $243;
   } else {
    break;
   }
  }
  $271 = HEAP32[$242>>2]|0;
  $272 = ($271>>>0)>(63);
  if ($272) {
   $hullVertices$0$ph = $245;$numHullVertices$0$ph = $243;$status$0$off0$ph = 1;
   continue;
  }
  $273 = (($271) + 1)|0;
  HEAP32[$242>>2] = $273;
  $274 = (($contactBuffer) + ($271<<6)|0);
  $275 = ($274|0)==(0|0);
  if ($275) {
   $hullVertices$0$ph = $245;$numHullVertices$0$ph = $243;$status$0$off0$ph = 1;
   continue;
  }
  HEAPF32[$274>>2] = $239;
  $276 = ((($contactBuffer) + ($271<<6)|0) + 4|0);
  HEAPF32[$276>>2] = $240;
  $277 = ((($contactBuffer) + ($271<<6)|0) + 8|0);
  HEAPF32[$277>>2] = $241;
  $278 = Math_fround($226 * $266);
  $279 = Math_fround($227 * $266);
  $280 = Math_fround($228 * $266);
  $281 = Math_fround($229 * $267);
  $282 = Math_fround($231 * $267);
  $283 = Math_fround($232 * $267);
  $284 = Math_fround($278 + $281);
  $285 = Math_fround($279 + $282);
  $286 = Math_fround($280 + $283);
  $287 = Math_fround($233 * $268);
  $288 = Math_fround($234 * $268);
  $289 = Math_fround($235 * $268);
  $290 = Math_fround($287 + $284);
  $291 = Math_fround($288 + $285);
  $292 = Math_fround($289 + $286);
  $293 = Math_fround($236 + $290);
  $294 = Math_fround($237 + $291);
  $295 = Math_fround($238 + $292);
  $296 = ((($contactBuffer) + ($271<<6)|0) + 16|0);
  HEAPF32[$296>>2] = $293;
  $297 = ((($contactBuffer) + ($271<<6)|0) + 20|0);
  HEAPF32[$297>>2] = $294;
  $298 = ((($contactBuffer) + ($271<<6)|0) + 24|0);
  HEAPF32[$298>>2] = $295;
  $299 = ((($contactBuffer) + ($271<<6)|0) + 12|0);
  HEAPF32[$299>>2] = $266;
  $300 = ((($contactBuffer) + ($271<<6)|0) + 48|0);
  HEAP32[$300>>2] = -1;
  $301 = ((($contactBuffer) + ($271<<6)|0) + 52|0);
  HEAP32[$301>>2] = -1;
  $hullVertices$0$ph = $245;$numHullVertices$0$ph = $243;$status$0$off0$ph = 1;
 }
 STACKTOP = sp;return ($status$0$off0$ph|0);
}
function __ZN5physx19PxcContactSphereBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $$mux$i = Math_fround(0), $$ph = Math_fround(0), $$ph1 = Math_fround(0), $$ph2 = Math_fround(0), $$ph3 = Math_fround(0), $$ph4 = Math_fround(0), $$ph5 = Math_fround(0), $$pn = Math_fround(0), $$sink = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0);
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0);
 var $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0;
 var $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0;
 var $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge$i = 0;
 var $fabsf$i$i$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $outside$0$off0$i = 0, $outside$1$off0$i = 0, $phitmp$i = Math_fround(0), $phitmp26$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape0) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($shape1) + 4|0);
 $3 = Math_fround(HEAPF32[$contactDistance>>2]);
 $4 = (($transform0) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($transform1) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($transform0) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transform1) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = (($transform0) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($transform1) + 24|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = Math_fround($8 * Math_fround(2.0));
 $20 = Math_fround($13 * Math_fround(2.0));
 $21 = Math_fround($18 * Math_fround(2.0));
 $22 = (($transform1) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $23);
 $25 = Math_fround($24 + Math_fround(-0.5));
 $26 = Math_fround(HEAPF32[$transform1>>2]);
 $27 = Math_fround($19 * $26);
 $28 = (($transform1) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($20 * $29);
 $31 = Math_fround($27 + $30);
 $32 = (($transform1) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($21 * $33);
 $35 = Math_fround($31 + $34);
 $36 = Math_fround($19 * $25);
 $37 = Math_fround($21 * $29);
 $38 = Math_fround($20 * $33);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($23 * $39);
 $41 = Math_fround($36 - $40);
 $42 = Math_fround($26 * $35);
 $43 = Math_fround($42 + $41);
 $44 = Math_fround($20 * $25);
 $45 = Math_fround($19 * $33);
 $46 = Math_fround($21 * $26);
 $47 = Math_fround($45 - $46);
 $48 = Math_fround($23 * $47);
 $49 = Math_fround($44 - $48);
 $50 = Math_fround($29 * $35);
 $51 = Math_fround($50 + $49);
 $52 = Math_fround($21 * $25);
 $53 = Math_fround($20 * $26);
 $54 = Math_fround($19 * $29);
 $55 = Math_fround($53 - $54);
 $56 = Math_fround($23 * $55);
 $57 = Math_fround($52 - $56);
 $58 = Math_fround($33 * $35);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround(HEAPF32[$2>>2]);
 $61 = Math_fround(-$60);
 $62 = $43 < $61;
 if ($62) {
  $75 = $61;$outside$0$off0$i = 1;
 } else {
  $63 = $43 > $60;
  if ($63) {
   $75 = $60;$outside$0$off0$i = 1;
  } else {
   $75 = $43;$outside$0$off0$i = 0;
  }
 }
 $64 = (($shape1) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround(-$65);
 $67 = $51 < $66;
 if ($67) {
  $77 = $66;$outside$1$off0$i = 1;
 } else {
  $68 = $51 > $65;
  if ($68) {
   $77 = $65;$outside$1$off0$i = 1;
  } else {
   $77 = $51;$outside$1$off0$i = $outside$0$off0$i;
  }
 }
 $69 = (($shape1) + 12|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround(-$70);
 $72 = $59 < $71;
 if ($72) {
  $79 = $71;
  label = 9;
 } else {
  $73 = $59 > $70;
  $brmerge$i = $73 | $outside$1$off0$i;
  $$mux$i = $73 ? $70 : $59;
  if ($brmerge$i) {
   $79 = $$mux$i;
   label = 9;
  } else {
   $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($75)))));
   $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($77)))));
   $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($59)))));
   $129 = Math_fround($60 - $fabsf$i$i4$i);
   $130 = Math_fround($65 - $fabsf$i$i3$i);
   $131 = Math_fround($70 - $fabsf$i$i$i);
   $132 = $130 < $129;
   do {
    if ($132) {
     $133 = $130 < $131;
     if ($133) {
      $134 = $77 > Math_fround(0.0);
      $phitmp26$i = $134 ? Math_fround(2.0) : Math_fround(-2.0);
      $$pn = $130;$143 = Math_fround(0.0);$145 = Math_fround(0.0);$147 = $phitmp26$i;
      break;
     } else {
      $135 = $59 > Math_fround(0.0);
      $136 = $135 ? Math_fround(1.0) : Math_fround(-1.0);
      $$pn = $131;$143 = $136;$145 = Math_fround(0.0);$147 = Math_fround(0.0);
      break;
     }
    } else {
     $137 = $129 < $131;
     if ($137) {
      $138 = $75 > Math_fround(0.0);
      $phitmp$i = $138 ? Math_fround(2.0) : Math_fround(-2.0);
      $$pn = $129;$143 = Math_fround(0.0);$145 = $phitmp$i;$147 = Math_fround(0.0);
      break;
     } else {
      $139 = $59 > Math_fround(0.0);
      $140 = $139 ? Math_fround(1.0) : Math_fround(-1.0);
      $$pn = $131;$143 = $140;$145 = Math_fround(0.0);$147 = Math_fround(0.0);
      break;
     }
    }
   } while(0);
   $141 = Math_fround(-$$pn);
   $142 = Math_fround($143 * Math_fround(2.0));
   $144 = Math_fround($145 * $26);
   $146 = Math_fround($147 * $29);
   $148 = Math_fround($144 + $146);
   $149 = Math_fround($142 * $33);
   $150 = Math_fround($148 + $149);
   $151 = Math_fround($145 * $25);
   $152 = Math_fround($142 * $29);
   $153 = Math_fround($147 * $33);
   $154 = Math_fround($152 - $153);
   $155 = Math_fround($23 * $154);
   $156 = Math_fround($151 + $155);
   $157 = Math_fround($26 * $150);
   $158 = Math_fround($157 + $156);
   $159 = Math_fround($147 * $25);
   $160 = Math_fround($145 * $33);
   $161 = Math_fround($142 * $26);
   $162 = Math_fround($160 - $161);
   $163 = Math_fround($23 * $162);
   $164 = Math_fround($159 + $163);
   $165 = Math_fround($29 * $150);
   $166 = Math_fround($165 + $164);
   $167 = Math_fround($142 * $25);
   $168 = Math_fround($147 * $26);
   $169 = Math_fround($145 * $29);
   $170 = Math_fround($168 - $169);
   $171 = Math_fround($23 * $170);
   $172 = Math_fround($167 + $171);
   $173 = Math_fround($33 * $150);
   $174 = Math_fround($172 + $173);
   $$ph = $174;$$ph1 = $166;$$ph2 = $158;$$ph3 = $15;$$ph4 = $10;$$ph5 = $5;$$sink = $141;
  }
 }
 do {
  if ((label|0) == 9) {
   $74 = Math_fround($75 * Math_fround(2.0));
   $76 = Math_fround($77 * Math_fround(2.0));
   $78 = Math_fround($79 * Math_fround(2.0));
   $80 = Math_fround($26 * $74);
   $81 = Math_fround($29 * $76);
   $82 = Math_fround($80 + $81);
   $83 = Math_fround($33 * $78);
   $84 = Math_fround($82 + $83);
   $85 = Math_fround($25 * $74);
   $86 = Math_fround($29 * $78);
   $87 = Math_fround($33 * $76);
   $88 = Math_fround($86 - $87);
   $89 = Math_fround($23 * $88);
   $90 = Math_fround($85 + $89);
   $91 = Math_fround($26 * $84);
   $92 = Math_fround($91 + $90);
   $93 = Math_fround($25 * $76);
   $94 = Math_fround($33 * $74);
   $95 = Math_fround($26 * $78);
   $96 = Math_fround($94 - $95);
   $97 = Math_fround($23 * $96);
   $98 = Math_fround($93 + $97);
   $99 = Math_fround($29 * $84);
   $100 = Math_fround($99 + $98);
   $101 = Math_fround($25 * $78);
   $102 = Math_fround($26 * $76);
   $103 = Math_fround($29 * $74);
   $104 = Math_fround($102 - $103);
   $105 = Math_fround($23 * $104);
   $106 = Math_fround($105 + $101);
   $107 = Math_fround($33 * $84);
   $108 = Math_fround($106 + $107);
   $109 = Math_fround($8 - $92);
   $110 = Math_fround($13 - $100);
   $111 = Math_fround($18 - $108);
   $112 = Math_fround($109 * $109);
   $113 = Math_fround($110 * $110);
   $114 = Math_fround($112 + $113);
   $115 = Math_fround($111 * $111);
   $116 = Math_fround($115 + $114);
   $117 = Math_fround($1 + $3);
   $118 = Math_fround($117 * $117);
   $119 = $116 > $118;
   if ($119) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $120 = (Math_fround(Math_sqrt((Math_fround($116)))));
    $121 = Math_fround(Math_fround(1.0) / $120);
    $122 = Math_fround($109 * $121);
    $123 = Math_fround($110 * $121);
    $124 = Math_fround($111 * $121);
    $125 = Math_fround($116 * $121);
    $126 = Math_fround($92 + $7);
    $127 = Math_fround($100 + $12);
    $128 = Math_fround($108 + $17);
    $$ph = $124;$$ph1 = $123;$$ph2 = $122;$$ph3 = $128;$$ph4 = $127;$$ph5 = $126;$$sink = $125;
    break;
   }
  }
 } while(0);
 $175 = (($contactBuffer) + 4096|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = ($176>>>0)>(63);
 if ($177) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $178 = Math_fround($$sink - $1);
 $179 = (($176) + 1)|0;
 HEAP32[$175>>2] = $179;
 $180 = (($contactBuffer) + ($176<<6)|0);
 HEAPF32[$180>>2] = $$ph2;
 $181 = ((($contactBuffer) + ($176<<6)|0) + 4|0);
 HEAPF32[$181>>2] = $$ph1;
 $182 = ((($contactBuffer) + ($176<<6)|0) + 8|0);
 HEAPF32[$182>>2] = $$ph;
 $183 = ((($contactBuffer) + ($176<<6)|0) + 16|0);
 HEAPF32[$183>>2] = $$ph5;
 $184 = ((($contactBuffer) + ($176<<6)|0) + 20|0);
 HEAPF32[$184>>2] = $$ph4;
 $185 = ((($contactBuffer) + ($176<<6)|0) + 24|0);
 HEAPF32[$185>>2] = $$ph3;
 $186 = ((($contactBuffer) + ($176<<6)|0) + 12|0);
 HEAPF32[$186>>2] = $178;
 $187 = ((($contactBuffer) + ($176<<6)|0) + 48|0);
 HEAP32[$187>>2] = -1;
 $188 = ((($contactBuffer) + ($176<<6)|0) + 52|0);
 HEAP32[$188>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx23PxcContactSphereCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $12 = Math_fround(0), $13 = 0;
 var $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0);
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $segment = 0, $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $segment = sp + 8|0;
 $u = sp;
 $0 = (($transform0) + 16|0);
 $1 = Math_fround(HEAPF32[$transform1>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($transform1) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = Math_fround($4 * $5);
 $7 = Math_fround($6 + Math_fround(-1.0));
 $8 = Math_fround($1 * $2);
 $9 = Math_fround($8 + $7);
 $10 = (($transform1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $5);
 $13 = (($transform1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($2 * $14);
 $16 = Math_fround($12 + $15);
 $17 = Math_fround($5 * $14);
 $18 = Math_fround($2 * $11);
 $19 = Math_fround($18 - $17);
 $20 = (($shape1) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $9);
 $23 = Math_fround($21 * $16);
 $24 = Math_fround($21 * $19);
 $25 = (($transform1) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + $22);
 $28 = (($transform1) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 + $23);
 $31 = (($transform1) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 + $32);
 HEAPF32[$segment>>2] = $27;
 $34 = (($segment) + 4|0);
 HEAPF32[$34>>2] = $30;
 $35 = (($segment) + 8|0);
 HEAPF32[$35>>2] = $33;
 $36 = Math_fround($26 - $22);
 $37 = Math_fround($29 - $23);
 $38 = Math_fround($32 - $24);
 $39 = (($segment) + 12|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($segment) + 16|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($segment) + 20|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($shape0) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($shape1) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 + $45);
 $47 = Math_fround(HEAPF32[$contactDistance>>2]);
 $48 = Math_fround($46 + $47);
 $49 = (($segment) + 12|0);
 $50 = (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($segment,$49,$0,$u)));
 $51 = Math_fround($48 * $48);
 $52 = $50 < $51;
 if (!($52)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $53 = Math_fround(HEAPF32[$u>>2]);
 $54 = Math_fround(HEAPF32[$39>>2]);
 $55 = Math_fround(HEAPF32[$segment>>2]);
 $56 = Math_fround($54 - $55);
 $57 = Math_fround(HEAPF32[$40>>2]);
 $58 = Math_fround(HEAPF32[$34>>2]);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround(HEAPF32[$41>>2]);
 $61 = Math_fround(HEAPF32[$35>>2]);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($53 * $56);
 $64 = Math_fround($53 * $59);
 $65 = Math_fround($53 * $62);
 $66 = Math_fround($55 + $63);
 $67 = Math_fround($58 + $64);
 $68 = Math_fround($61 + $65);
 $69 = Math_fround(HEAPF32[$0>>2]);
 $70 = Math_fround($69 - $66);
 $71 = (($transform0) + 20|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 - $67);
 $74 = (($transform0) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 - $68);
 $77 = Math_fround($70 * $70);
 $78 = Math_fround($73 * $73);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($76 * $76);
 $81 = Math_fround($79 + $80);
 $82 = $81 == Math_fround(0.0);
 if ($82) {
  $94 = Math_fround(0.0);$96 = Math_fround(0.0);$98 = Math_fround(1.0);
 } else {
  $83 = (Math_fround(Math_sqrt((Math_fround($81)))));
  $84 = Math_fround(Math_fround(1.0) / $83);
  $85 = Math_fround($70 * $84);
  $86 = Math_fround($73 * $84);
  $87 = Math_fround($76 * $84);
  $94 = $87;$96 = $86;$98 = $85;
 }
 $88 = Math_fround(HEAPF32[$42>>2]);
 $89 = (($contactBuffer) + 4096|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($90>>>0)>(63);
 if ($91) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $92 = (Math_fround(Math_sqrt((Math_fround($50)))));
 $93 = Math_fround($94 * $88);
 $95 = Math_fround($96 * $88);
 $97 = Math_fround($98 * $88);
 $99 = Math_fround($92 - $46);
 $100 = Math_fround($75 - $93);
 $101 = Math_fround($72 - $95);
 $102 = Math_fround($69 - $97);
 $103 = (($90) + 1)|0;
 HEAP32[$89>>2] = $103;
 $104 = (($contactBuffer) + ($90<<6)|0);
 HEAPF32[$104>>2] = $98;
 $105 = ((($contactBuffer) + ($90<<6)|0) + 4|0);
 HEAPF32[$105>>2] = $96;
 $106 = ((($contactBuffer) + ($90<<6)|0) + 8|0);
 HEAPF32[$106>>2] = $94;
 $107 = ((($contactBuffer) + ($90<<6)|0) + 16|0);
 HEAPF32[$107>>2] = $102;
 $108 = ((($contactBuffer) + ($90<<6)|0) + 20|0);
 HEAPF32[$108>>2] = $101;
 $109 = ((($contactBuffer) + ($90<<6)|0) + 24|0);
 HEAPF32[$109>>2] = $100;
 $110 = ((($contactBuffer) + ($90<<6)|0) + 12|0);
 HEAPF32[$110>>2] = $99;
 $111 = ((($contactBuffer) + ($90<<6)|0) + 48|0);
 HEAP32[$111>>2] = -1;
 $112 = ((($contactBuffer) + ($90<<6)|0) + 52|0);
 HEAP32[$112>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx33PxcContactSphereHeightFieldSharedERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferEb($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer,$isCapsule) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 $isCapsule = $isCapsule|0;
 var $$0 = 0, $$lcssa = 0, $$lcssa68 = Math_fround(0), $$lcssa69 = Math_fround(0), $$lcssa70 = Math_fround(0), $$lcssa81 = Math_fround(0), $$lcssa82 = Math_fround(0), $$lcssa83 = Math_fround(0), $$lcssa90 = Math_fround(0), $$lcssa91 = Math_fround(0), $$lcssa92 = Math_fround(0), $$ph = Math_fround(0), $$ph39 = Math_fround(0), $$ph40 = Math_fround(0), $$pr = Math_fround(0), $$pre = Math_fround(0), $$pre124 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0);
 var $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0);
 var $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0);
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0);
 var $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0);
 var $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0);
 var $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0);
 var $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0);
 var $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0;
 var $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0);
 var $407 = Math_fround(0), $408 = Math_fround(0), $409 = 0, $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0);
 var $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0);
 var $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = Math_fround(0), $478 = 0, $479 = Math_fround(0);
 var $48 = Math_fround(0), $480 = 0, $481 = Math_fround(0), $482 = Math_fround(0), $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = 0, $496 = 0, $497 = Math_fround(0);
 var $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0);
 var $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0;
 var $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $adjEdges = 0, $adjFaceIndices = 0, $c$084 = 0, $closestFeatures = 0, $closestPoints = 0, $d = 0, $dMag = 0, $direction = 0, $exitcond = 0, $exitcond105 = 0, $exitcond115 = 0, $exitcond119 = 0, $exitcond122 = 0, $fabsf$i$i = Math_fround(0);
 var $fabsf$i$i5 = Math_fround(0), $fracX = 0, $fracZ = 0, $hfUtil = 0, $i$098 = 0, $iAdjEdge$047$us = 0, $iPrevEdgeContact$053 = 0, $iPrevEdgeContact$053$us = 0, $j$065 = 0, $k$044 = 0, $k4$042 = 0, $numFaceContacts$099 = 0, $numFaceContacts$099$phi = 0, $numFaceContacts$1121 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i2 = 0, $or$cond$i3 = 0, $or$cond1$i = 0, $or$cond41 = 0;
 var $origin = 0, $pi$071 = 0, $r$093 = 0, $tv0 = 0, $tv1 = 0, $tv2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0;
 $hfUtil = sp + 444|0;
 $fracX = sp + 440|0;
 $fracZ = sp + 436|0;
 $closestPoints = sp + 304|0;
 $closestFeatures = sp + 260|0;
 $0 = sp + 248|0;
 $d = sp + 236|0;
 $dMag = sp + 232|0;
 $adjFaceIndices = sp + 224|0;
 $origin = sp + 212|0;
 $direction = sp + 188|0;
 $1 = sp + 176|0;
 $2 = sp + 164|0;
 $tv0 = sp + 152|0;
 $tv1 = sp + 140|0;
 $tv2 = sp + 128|0;
 $adjEdges = sp;
 $3 = sp + 200|0;
 $4 = (($shape1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($hfUtil) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (($hfUtil) + 16|0);
 HEAP32[$7>>2] = $shape1;
 $8 = (($shape1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(Math_fround(1.0) / $9);
 $11 = (($hfUtil) + 4|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($shape1) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(Math_fround(1.0) / $13);
 HEAPF32[$hfUtil>>2] = $14;
 $15 = (($shape1) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(Math_fround(1.0) / $16);
 $18 = (($hfUtil) + 8|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($shape0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * Math_fround(0.100000001490116119385));
 $22 = (($transform0) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($transform1) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 - $25);
 $27 = (($transform0) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($transform1) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 - $30);
 $32 = (($transform0) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($transform1) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 - $35);
 $37 = Math_fround($26 * Math_fround(2.0));
 $38 = Math_fround($31 * Math_fround(2.0));
 $39 = Math_fround($36 * Math_fround(2.0));
 $40 = (($transform1) + 12|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 * $41);
 $43 = Math_fround($42 + Math_fround(-0.5));
 $44 = Math_fround(HEAPF32[$transform1>>2]);
 $45 = Math_fround($37 * $44);
 $46 = (($transform1) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($38 * $47);
 $49 = Math_fround($45 + $48);
 $50 = (($transform1) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($39 * $51);
 $53 = Math_fround($49 + $52);
 $54 = Math_fround($37 * $43);
 $55 = Math_fround($39 * $47);
 $56 = Math_fround($38 * $51);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($41 * $57);
 $59 = Math_fround($54 - $58);
 $60 = Math_fround($44 * $53);
 $61 = Math_fround($60 + $59);
 $62 = Math_fround($38 * $43);
 $63 = Math_fround($37 * $51);
 $64 = Math_fround($39 * $44);
 $65 = Math_fround($63 - $64);
 $66 = Math_fround($41 * $65);
 $67 = Math_fround($62 - $66);
 $68 = Math_fround($47 * $53);
 $69 = Math_fround($68 + $67);
 $70 = Math_fround($39 * $43);
 $71 = Math_fround($38 * $44);
 $72 = Math_fround($37 * $47);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($41 * $73);
 $75 = Math_fround($70 - $74);
 $76 = Math_fround($51 * $53);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($14 * $61);
 $79 = Math_fround($17 * $77);
 $80 = !($78 >= Math_fround(0.0));
 $81 = !($79 >= Math_fround(0.0));
 $or$cond$i = $80 | $81;
 do {
  if (!($or$cond$i)) {
   $82 = (($5) + 24|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = Math_fround($83 + Math_fround(1.0));
   $85 = $78 < $84;
   if ($85) {
    $86 = (($5) + 28|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = Math_fround($87 + Math_fround(1.0));
    $89 = $79 < $88;
    if ($89) {
     $90 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($5,$78,$79,$fracX,$fracZ)|0);
     $91 = Math_fround(HEAPF32[$fracX>>2]);
     $92 = Math_fround(HEAPF32[$fracZ>>2]);
     $93 = HEAP32[$7>>2]|0;
     $94 = (($93) + 8|0);
     $95 = Math_fround(HEAPF32[$94>>2]);
     $96 = HEAP32[$6>>2]|0;
     $97 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($96,$90,$91,$92)));
     $98 = Math_fround($95 * $97);
     $99 = Math_fround($69 - $98);
     $100 = (($5) + 40|0);
     $101 = Math_fround(HEAPF32[$100>>2]);
     $102 = !($101 <= Math_fround(0.0));
     $103 = !($99 <= $21);
     $or$cond$i3 = $102 | $103;
     $104 = !($101 <= $99);
     $or$cond1$i = $or$cond$i3 | $104;
     if ($or$cond1$i) {
      $105 = $101 > Math_fround(0.0);
      if (!($105)) {
       break;
      }
      $106 = Math_fround(-$21);
      $107 = $99 > $106;
      $108 = $101 > $99;
      $or$cond = $107 & $108;
      if (!($or$cond)) {
       break;
      }
     }
     $109 = (__ZNK5physx2Gu15HeightFieldUtil31getFaceIndexAtShapePointNoTest2Ejff($hfUtil,$90,$91,$92)|0);
     $110 = ($109|0)==(-1);
     if ($110) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $111 = Math_fround(HEAPF32[$46>>2]);
     $112 = Math_fround($111 * Math_fround(2.0));
     $113 = Math_fround(HEAPF32[$40>>2]);
     $114 = Math_fround($113 * Math_fround(2.0));
     $115 = Math_fround(HEAPF32[$50>>2]);
     $116 = Math_fround($115 * $114);
     $117 = Math_fround(HEAPF32[$transform1>>2]);
     $118 = Math_fround($112 * $117);
     $119 = Math_fround($118 - $116);
     $120 = Math_fround($113 * $114);
     $121 = Math_fround($120 + Math_fround(-1.0));
     $122 = Math_fround($111 * $112);
     $123 = Math_fround($122 + $121);
     $124 = Math_fround($114 * $117);
     $125 = Math_fround($112 * $115);
     $126 = Math_fround($125 + $124);
     $127 = Math_fround(HEAPF32[$100>>2]);
     $128 = !($127 <= Math_fround(0.0));
     $129 = (($contactBuffer) + 4096|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($130>>>0)>(63);
     if ($128) {
      if ($131) {
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
      $146 = Math_fround(-$99);
      $147 = Math_fround($146 - $20);
      $148 = Math_fround(-$126);
      $149 = Math_fround(-$123);
      $150 = Math_fround(-$119);
      $151 = (($130) + 1)|0;
      HEAP32[$129>>2] = $151;
      $152 = (($contactBuffer) + ($130<<6)|0);
      HEAPF32[$152>>2] = $150;
      $153 = ((($contactBuffer) + ($130<<6)|0) + 4|0);
      HEAPF32[$153>>2] = $149;
      $154 = ((($contactBuffer) + ($130<<6)|0) + 8|0);
      HEAPF32[$154>>2] = $148;
      $155 = Math_fround(HEAPF32[$22>>2]);
      $156 = ((($contactBuffer) + ($130<<6)|0) + 16|0);
      HEAPF32[$156>>2] = $155;
      $157 = Math_fround(HEAPF32[$27>>2]);
      $158 = ((($contactBuffer) + ($130<<6)|0) + 20|0);
      HEAPF32[$158>>2] = $157;
      $159 = Math_fround(HEAPF32[$32>>2]);
      $160 = ((($contactBuffer) + ($130<<6)|0) + 24|0);
      HEAPF32[$160>>2] = $159;
      $161 = ((($contactBuffer) + ($130<<6)|0) + 12|0);
      HEAPF32[$161>>2] = $147;
      $162 = ((($contactBuffer) + ($130<<6)|0) + 48|0);
      HEAP32[$162>>2] = -1;
      $163 = ((($contactBuffer) + ($130<<6)|0) + 52|0);
      HEAP32[$163>>2] = $109;
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     } else {
      if ($131) {
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
      $132 = Math_fround($99 - $20);
      $133 = (($130) + 1)|0;
      HEAP32[$129>>2] = $133;
      $134 = (($contactBuffer) + ($130<<6)|0);
      HEAPF32[$134>>2] = $119;
      $135 = ((($contactBuffer) + ($130<<6)|0) + 4|0);
      HEAPF32[$135>>2] = $123;
      $136 = ((($contactBuffer) + ($130<<6)|0) + 8|0);
      HEAPF32[$136>>2] = $126;
      $137 = Math_fround(HEAPF32[$22>>2]);
      $138 = ((($contactBuffer) + ($130<<6)|0) + 16|0);
      HEAPF32[$138>>2] = $137;
      $139 = Math_fround(HEAPF32[$27>>2]);
      $140 = ((($contactBuffer) + ($130<<6)|0) + 20|0);
      HEAPF32[$140>>2] = $139;
      $141 = Math_fround(HEAPF32[$32>>2]);
      $142 = ((($contactBuffer) + ($130<<6)|0) + 24|0);
      HEAPF32[$142>>2] = $141;
      $143 = ((($contactBuffer) + ($130<<6)|0) + 12|0);
      HEAPF32[$143>>2] = $132;
      $144 = ((($contactBuffer) + ($130<<6)|0) + 48|0);
      HEAP32[$144>>2] = -1;
      $145 = ((($contactBuffer) + ($130<<6)|0) + 52|0);
      HEAP32[$145>>2] = $109;
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $164 = Math_fround($21 * $21);
 $165 = Math_fround(HEAPF32[$contactDistance>>2]);
 $166 = Math_fround($20 + $165);
 $167 = Math_fround($166 * $166);
 $168 = Math_fround(HEAPF32[$hfUtil>>2]);
 $169 = Math_fround($61 * $168);
 $170 = Math_fround(HEAPF32[$18>>2]);
 $171 = Math_fround($77 * $170);
 $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($14)))));
 $172 = Math_fround($166 * $fabsf$i$i5);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($17)))));
 $173 = Math_fround($166 * $fabsf$i$i);
 $174 = Math_fround($169 - $172);
 $175 = (Math_fround(Math_floor((Math_fround($174)))));
 $176 = (~~(($175)));
 $177 = (($5) + 16|0);
 $178 = HEAP32[$177>>2]|0;
 $179 = (($178) + -2)|0;
 $180 = ($176|0)>(0);
 $181 = $180 ? $176 : 0;
 $182 = ($181|0)>($179|0);
 $183 = $182 ? $179 : $181;
 $184 = Math_fround($169 + $172);
 $185 = (Math_fround(Math_ceil((Math_fround($184)))));
 $186 = (~~(($185)));
 $187 = (($178) + -1)|0;
 $188 = ($186|0)>(0);
 $189 = $188 ? $186 : 0;
 $190 = ($189|0)>($187|0);
 $191 = $190 ? $187 : $189;
 $192 = Math_fround($171 - $173);
 $193 = (Math_fround(Math_floor((Math_fround($192)))));
 $194 = (~~(($193)));
 $195 = (($5) + 20|0);
 $196 = HEAP32[$195>>2]|0;
 $197 = (($196) + -2)|0;
 $198 = ($194|0)>(0);
 $199 = $198 ? $194 : 0;
 $200 = ($199|0)>($197|0);
 $201 = $200 ? $197 : $199;
 $202 = Math_fround($171 + $173);
 $203 = (Math_fround(Math_ceil((Math_fround($202)))));
 $204 = (~~(($203)));
 $205 = (($196) + -1)|0;
 $206 = ($204|0)>(0);
 $207 = $206 ? $204 : 0;
 $208 = ($207|0)>($205|0);
 $209 = $208 ? $205 : $207;
 $210 = ($183>>>0)<($191>>>0);
 $211 = (($contactBuffer) + 4096|0);
 $212 = ($201>>>0)<($209>>>0);
 $213 = (($0) + 4|0);
 $214 = (($0) + 8|0);
 $215 = (($d) + 4|0);
 $216 = (($d) + 8|0);
 $217 = (($5) + 40|0);
 $218 = (($shape1) + 20|0);
 $219 = (($3) + 4|0);
 $220 = (($3) + 8|0);
 $221 = (($1) + 4|0);
 $222 = (($1) + 8|0);
 $223 = (($2) + 4|0);
 $224 = (($2) + 8|0);
 $225 = (($tv0) + 4|0);
 $226 = (($tv1) + 4|0);
 $227 = (($tv0) + 8|0);
 $228 = (($tv1) + 8|0);
 $229 = (($tv2) + 4|0);
 $230 = (($tv2) + 8|0);
 $231 = (($direction) + 8|0);
 $232 = (($direction) + 4|0);
 $233 = (($origin) + 4|0);
 $234 = (($origin) + 8|0);
 $548 = Math_fround(0.0);$549 = Math_fround(0.0);$550 = Math_fround(0.0);$i$098 = 0;$numFaceContacts$099 = 0;
 while(1) {
  $235 = ($i$098|0)==(0);
  if ($210) {
   $236 = $235 ^ 1;
   $551 = $548;$552 = $549;$553 = $550;$r$093 = $183;
   while(1) {
    if ($212) {
     $554 = $551;$555 = $552;$556 = $553;$c$084 = $201;
     while(1) {
      HEAPF32[$0>>2] = $61;
      HEAPF32[$213>>2] = $69;
      HEAPF32[$214>>2] = $77;
      $237 = (__ZNK5physx2Gu15HeightFieldUtil23findClosestPointsOnCellEjjNS_6PxVec3EPS2_Pjbbb($hfUtil,$r$093,$c$084,$0,$closestPoints,$closestFeatures,$235,$236,1)|0);
      $238 = ($237|0)==(0);
      if ($238) {
       $$lcssa68 = $556;$$lcssa69 = $555;$$lcssa70 = $554;
      } else {
       $557 = $554;$558 = $555;$559 = $556;$pi$071 = 0;
       while(1) {
        $239 = (($closestPoints) + (($pi$071*12)|0)|0);
        $240 = Math_fround(HEAPF32[$239>>2]);
        $241 = Math_fround($61 - $240);
        $242 = ((($closestPoints) + (($pi$071*12)|0)|0) + 4|0);
        $243 = Math_fround(HEAPF32[$242>>2]);
        $244 = Math_fround($69 - $243);
        $245 = ((($closestPoints) + (($pi$071*12)|0)|0) + 8|0);
        $246 = Math_fround(HEAPF32[$245>>2]);
        $247 = Math_fround($77 - $246);
        HEAPF32[$d>>2] = $241;
        HEAPF32[$215>>2] = $244;
        HEAPF32[$216>>2] = $247;
        $248 = Math_fround(HEAPF32[$217>>2]);
        $249 = $248 <= Math_fround(0.0);
        $250 = $244 > Math_fround(0.0);
        $or$cond$i2 = $249 & $250;
        if ($or$cond$i2) {
         label = 20;
        } else {
         $251 = $248 > Math_fround(0.0);
         $252 = $244 < Math_fround(0.0);
         $or$cond41 = $251 & $252;
         if ($or$cond41) {
          label = 20;
         } else {
          $560 = $559;$561 = $558;$562 = $557;
         }
        }
        if ((label|0) == 20) {
         label = 0;
         $253 = Math_fround($241 * $241);
         $254 = Math_fround($244 * $244);
         $255 = Math_fround($253 + $254);
         $256 = Math_fround($247 * $247);
         $257 = Math_fround($255 + $256);
         $258 = $257 > $167;
         if ($258) {
          $560 = $559;$561 = $558;$562 = $557;
         } else {
          HEAPF32[$dMag>>2] = Math_fround(-1.0);
          $259 = (($closestFeatures) + ($pi$071<<2)|0);
          $260 = HEAP32[$259>>2]|0;
          $261 = $260 >>> 30;
          L41: do {
           if ((($261|0) == 2)) {
            $460 = HEAP32[$211>>2]|0;
            $461 = $260 & 1073741823;
            $462 = (($461>>>0) / ($196>>>0))&-1;
            $463 = (($461>>>0) % ($196>>>0))&-1;
            $464 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($5,$461,$462,$463,$adjEdges)|0);
            $465 = ($numFaceContacts$099>>>0)<($460>>>0);
            if ($465) {
             $466 = ($464|0)==(0);
             if ($466) {
              $iPrevEdgeContact$053 = $numFaceContacts$099;
              while(1) {
               $485 = (($iPrevEdgeContact$053) + 1)|0;
               $exitcond105 = ($485|0)==($460|0);
               if ($exitcond105) {
                $$ph = $559;$$ph39 = $558;$$ph40 = $557;
                label = 41;
                break L41;
               } else {
                $iPrevEdgeContact$053 = $485;
               }
              }
             } else {
              $563 = $557;$564 = $558;$565 = $559;$iPrevEdgeContact$053$us = $numFaceContacts$099;
             }
             while(1) {
              $467 = ((($contactBuffer) + ($iPrevEdgeContact$053$us<<6)|0) + 48|0);
              $468 = HEAP32[$467>>2]|0;
              $469 = ($468|0)==(1);
              L49: do {
               if ($469) {
                $484 = ((($contactBuffer) + ($iPrevEdgeContact$053$us<<6)|0) + 52|0);
                $475 = HEAP32[$484>>2]|0;
                $iAdjEdge$047$us = 0;
                while(1) {
                 $472 = (($adjEdges) + ($iAdjEdge$047$us<<4)|0);
                 $473 = HEAP32[$472>>2]|0;
                 $474 = ($473|0)==($475|0);
                 $471 = (($iAdjEdge$047$us) + 1)|0;
                 if ($474) {
                  break;
                 }
                 $470 = ($471>>>0)<($464>>>0);
                 if ($470) {
                  $iAdjEdge$047$us = $471;
                 } else {
                  $566 = $565;$567 = $564;$568 = $563;
                  break L49;
                 }
                }
                $476 = (($contactBuffer) + ($iPrevEdgeContact$053$us<<6)|0);
                $477 = Math_fround(HEAPF32[$476>>2]);
                $478 = ((($contactBuffer) + ($iPrevEdgeContact$053$us<<6)|0) + 4|0);
                $479 = Math_fround(HEAPF32[$478>>2]);
                $480 = ((($contactBuffer) + ($iPrevEdgeContact$053$us<<6)|0) + 8|0);
                $481 = Math_fround(HEAPF32[$480>>2]);
                $482 = (Math_fround(Math_sqrt((Math_fround($257)))));
                HEAPF32[$dMag>>2] = $482;
                $566 = $481;$567 = $479;$568 = $477;
               } else {
                $566 = $565;$567 = $564;$568 = $563;
               }
              } while(0);
              $483 = (($iPrevEdgeContact$053$us) + 1)|0;
              $exitcond115 = ($483|0)==($460|0);
              if ($exitcond115) {
               $$ph = $566;$$ph39 = $567;$$ph40 = $568;
               label = 41;
               break;
              } else {
               $563 = $568;$564 = $567;$565 = $566;$iPrevEdgeContact$053$us = $483;
              }
             }
            } else {
             $$ph = $559;$$ph39 = $558;$$ph40 = $557;
             label = 41;
            }
           } else if ((($261|0) == 1)) {
            $262 = $260 & 1073741823;
            $263 = (__ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($5,$262,$adjFaceIndices)|0);
            $264 = (($262>>>0) / 3)&-1;
            $265 = (($264>>>0) / ($196>>>0))&-1;
            $266 = (($264>>>0) % ($196>>>0))&-1;
            __ZNK5physx2Gu15HeightFieldUtil7getEdgeEjjjjRNS_6PxVec3ES3_($hfUtil,$262,$264,$265,$266,$origin,$direction);
            $267 = HEAP8[$218>>0]|0;
            $268 = $267&255;
            $269 = Math_fround(HEAPF32[$239>>2]);
            $270 = Math_fround(HEAPF32[$245>>2]);
            __ZNK5physx2Gu15HeightFieldUtil18computePointNormalEjRKNS_6PxVec3ERKNS_11PxTransformEffffRf($1,$hfUtil,$268,$d,$transform1,$257,$269,$270,$164,$dMag);
            $271 = Math_fround(HEAPF32[$1>>2]);
            $272 = Math_fround(HEAPF32[$221>>2]);
            $273 = Math_fround(HEAPF32[$222>>2]);
            $274 = Math_fround($271 * Math_fround(2.0));
            $275 = Math_fround($272 * Math_fround(2.0));
            $276 = Math_fround($273 * Math_fround(2.0));
            $277 = Math_fround(HEAPF32[$40>>2]);
            $278 = Math_fround($277 * $277);
            $279 = Math_fround($278 + Math_fround(-0.5));
            $280 = Math_fround(HEAPF32[$transform1>>2]);
            $281 = Math_fround($274 * $280);
            $282 = Math_fround(HEAPF32[$46>>2]);
            $283 = Math_fround($275 * $282);
            $284 = Math_fround($281 + $283);
            $285 = Math_fround(HEAPF32[$50>>2]);
            $286 = Math_fround($276 * $285);
            $287 = Math_fround($284 + $286);
            $288 = Math_fround($274 * $279);
            $289 = Math_fround($276 * $282);
            $290 = Math_fround($275 * $285);
            $291 = Math_fround($289 - $290);
            $292 = Math_fround($277 * $291);
            $293 = Math_fround($288 - $292);
            $294 = Math_fround($280 * $287);
            $295 = Math_fround($294 + $293);
            $296 = Math_fround($275 * $279);
            $297 = Math_fround($274 * $285);
            $298 = Math_fround($276 * $280);
            $299 = Math_fround($297 - $298);
            $300 = Math_fround($277 * $299);
            $301 = Math_fround($296 - $300);
            $302 = Math_fround($282 * $287);
            $303 = Math_fround($302 + $301);
            $304 = Math_fround($276 * $279);
            $305 = Math_fround($275 * $280);
            $306 = Math_fround($274 * $282);
            $307 = Math_fround($305 - $306);
            $308 = Math_fround($277 * $307);
            $309 = Math_fround($304 - $308);
            $310 = Math_fround($285 * $287);
            $311 = Math_fround($309 + $310);
            $312 = ($263|0)==(0);
            if ($312) {
             $$ph = $273;$$ph39 = $272;$$ph40 = $271;
             label = 41;
            } else {
             $j$065 = 0;
             while(1) {
              $315 = (($adjFaceIndices) + ($j$065<<2)|0);
              $316 = HEAP32[$315>>2]|0;
              __ZNK5physx2Gu11HeightField25getTriangleNormalInternalEj($2,$5,$316);
              $317 = Math_fround(HEAPF32[$2>>2]);
              $318 = Math_fround(HEAPF32[$hfUtil>>2]);
              $319 = Math_fround($317 * $318);
              $320 = Math_fround(HEAPF32[$223>>2]);
              $321 = Math_fround(HEAPF32[$11>>2]);
              $322 = Math_fround($320 * $321);
              $323 = Math_fround(HEAPF32[$224>>2]);
              $324 = Math_fround(HEAPF32[$18>>2]);
              $325 = Math_fround($323 * $324);
              $326 = Math_fround($319 * $319);
              $327 = Math_fround($322 * $322);
              $328 = Math_fround($326 + $327);
              $329 = Math_fround($325 * $325);
              $330 = Math_fround($328 + $329);
              $331 = $330 > Math_fround(0.0);
              if ($331) {
               $332 = (Math_fround(Math_sqrt((Math_fround($330)))));
               $333 = Math_fround(Math_fround(1.0) / $332);
               $334 = Math_fround($319 * $333);
               $335 = Math_fround($322 * $333);
               $336 = Math_fround($325 * $333);
               $371 = $335;$374 = $336;$379 = $334;
              } else {
               $371 = Math_fround(0.0);$374 = Math_fround(0.0);$379 = Math_fround(0.0);
              }
              $337 = $316 >>> 1;
              $338 = HEAP32[$195>>2]|0;
              $339 = (($337>>>0) / ($338>>>0))&-1;
              $340 = (($337>>>0) % ($338>>>0))&-1;
              __ZNK5physx2Gu11HeightField19getTriangleVerticesEjjjRNS_6PxVec3ES3_S3_($5,$316,$339,$340,$tv0,$tv1,$tv2);
              $341 = Math_fround(HEAPF32[$tv0>>2]);
              $342 = Math_fround(HEAPF32[$tv1>>2]);
              $343 = Math_fround($341 + $342);
              $344 = Math_fround(HEAPF32[$225>>2]);
              $345 = Math_fround(HEAPF32[$226>>2]);
              $346 = Math_fround($344 + $345);
              $347 = Math_fround(HEAPF32[$227>>2]);
              $348 = Math_fround(HEAPF32[$228>>2]);
              $349 = Math_fround($347 + $348);
              $350 = Math_fround(HEAPF32[$tv2>>2]);
              $351 = Math_fround($343 + $350);
              $352 = Math_fround(HEAPF32[$229>>2]);
              $353 = Math_fround($346 + $352);
              $354 = Math_fround(HEAPF32[$230>>2]);
              $355 = Math_fround($349 + $354);
              $356 = Math_fround($351 * Math_fround(0.333333343267440795898));
              $357 = Math_fround($353 * Math_fround(0.333333343267440795898));
              $358 = Math_fround($355 * Math_fround(0.333333343267440795898));
              $359 = HEAP32[$7>>2]|0;
              $360 = (($359) + 12|0);
              $361 = Math_fround(HEAPF32[$360>>2]);
              $362 = Math_fround($356 * $361);
              $363 = (($359) + 8|0);
              $364 = Math_fround(HEAPF32[$363>>2]);
              $365 = Math_fround($357 * $364);
              $366 = (($359) + 16|0);
              $367 = Math_fround(HEAPF32[$366>>2]);
              $368 = Math_fround($358 * $367);
              $369 = Math_fround(HEAPF32[$231>>2]);
              $370 = Math_fround($371 * $369);
              $372 = Math_fround(HEAPF32[$232>>2]);
              $373 = Math_fround($374 * $372);
              $375 = Math_fround($370 - $373);
              $376 = Math_fround(HEAPF32[$direction>>2]);
              $377 = Math_fround($374 * $376);
              $378 = Math_fround($379 * $369);
              $380 = Math_fround($377 - $378);
              $381 = Math_fround($379 * $372);
              $382 = Math_fround($371 * $376);
              $383 = Math_fround($381 - $382);
              $384 = Math_fround($375 * $375);
              $385 = Math_fround($380 * $380);
              $386 = Math_fround($384 + $385);
              $387 = Math_fround($383 * $383);
              $388 = Math_fround($387 + $386);
              $389 = $388 > Math_fround(0.0);
              if ($389) {
               $390 = (Math_fround(Math_sqrt((Math_fround($388)))));
               $391 = Math_fround(Math_fround(1.0) / $390);
               $392 = Math_fround($375 * $391);
               $393 = Math_fround($380 * $391);
               $394 = Math_fround($383 * $391);
               $402 = $392;$404 = $393;$407 = $394;
              } else {
               $402 = Math_fround(0.0);$404 = Math_fround(0.0);$407 = Math_fround(0.0);
              }
              $395 = Math_fround(HEAPF32[$origin>>2]);
              $396 = Math_fround($362 - $395);
              $397 = Math_fround(HEAPF32[$233>>2]);
              $398 = Math_fround($365 - $397);
              $399 = Math_fround(HEAPF32[$234>>2]);
              $400 = Math_fround($368 - $399);
              $401 = Math_fround($402 * $396);
              $403 = Math_fround($404 * $398);
              $405 = Math_fround($401 + $403);
              $406 = Math_fround($407 * $400);
              $408 = Math_fround($405 + $406);
              $409 = $408 < Math_fround(0.0);
              if ($409) {
               $410 = Math_fround(-$402);
               $411 = Math_fround(-$404);
               $412 = Math_fround(-$407);
               $414 = $410;$416 = $411;$419 = $412;
              } else {
               $414 = $402;$416 = $404;$419 = $407;
              }
              $413 = Math_fround($295 * $414);
              $415 = Math_fround($303 * $416);
              $417 = Math_fround($415 + $413);
              $418 = Math_fround($311 * $419);
              $420 = Math_fround($418 + $417);
              $421 = $420 > Math_fround(0.0);
              $314 = (($j$065) + 1)|0;
              if ($421) {
               break;
              }
              $313 = ($314>>>0)<($263>>>0);
              if ($313) {
               $j$065 = $314;
              } else {
               $$ph = $273;$$ph39 = $272;$$ph40 = $271;
               label = 41;
               break L41;
              }
             }
             $422 = Math_fround($379 * Math_fround(2.0));
             $423 = Math_fround($371 * Math_fround(2.0));
             $424 = Math_fround($374 * Math_fround(2.0));
             $425 = Math_fround(HEAPF32[$40>>2]);
             $426 = Math_fround($425 * $425);
             $427 = Math_fround($426 + Math_fround(-0.5));
             $428 = Math_fround(HEAPF32[$transform1>>2]);
             $429 = Math_fround($422 * $428);
             $430 = Math_fround(HEAPF32[$46>>2]);
             $431 = Math_fround($423 * $430);
             $432 = Math_fround($429 + $431);
             $433 = Math_fround(HEAPF32[$50>>2]);
             $434 = Math_fround($424 * $433);
             $435 = Math_fround($432 + $434);
             $436 = Math_fround($422 * $427);
             $437 = Math_fround($424 * $430);
             $438 = Math_fround($423 * $433);
             $439 = Math_fround($437 - $438);
             $440 = Math_fround($425 * $439);
             $441 = Math_fround($436 + $440);
             $442 = Math_fround($428 * $435);
             $443 = Math_fround($442 + $441);
             $444 = Math_fround($423 * $427);
             $445 = Math_fround($422 * $433);
             $446 = Math_fround($424 * $428);
             $447 = Math_fround($445 - $446);
             $448 = Math_fround($425 * $447);
             $449 = Math_fround($444 + $448);
             $450 = Math_fround($430 * $435);
             $451 = Math_fround($450 + $449);
             $452 = Math_fround($424 * $427);
             $453 = Math_fround($423 * $428);
             $454 = Math_fround($422 * $430);
             $455 = Math_fround($453 - $454);
             $456 = Math_fround($425 * $455);
             $457 = Math_fround($452 + $456);
             $458 = Math_fround($433 * $435);
             $459 = Math_fround($457 + $458);
             $$ph = $459;$$ph39 = $451;$$ph40 = $443;
             label = 41;
            }
           } else {
            $489 = $240;$490 = $246;
            label = 43;
           }
          } while(0);
          if ((label|0) == 41) {
           label = 0;
           $$pr = Math_fround(HEAPF32[$dMag>>2]);
           $486 = $$pr == Math_fround(-1.0);
           if ($486) {
            $$pre = Math_fround(HEAPF32[$239>>2]);
            $$pre124 = Math_fround(HEAPF32[$245>>2]);
            $489 = $$pre;$490 = $$pre124;
            label = 43;
           } else {
            $502 = $$ph;$504 = $$ph39;$506 = $$ph40;
           }
          }
          if ((label|0) == 43) {
           label = 0;
           $487 = HEAP8[$218>>0]|0;
           $488 = $487&255;
           __ZNK5physx2Gu15HeightFieldUtil18computePointNormalEjRKNS_6PxVec3ERKNS_11PxTransformEffffRf($3,$hfUtil,$488,$d,$transform1,$257,$489,$490,$164,$dMag);
           $491 = Math_fround(HEAPF32[$3>>2]);
           $492 = Math_fround(HEAPF32[$219>>2]);
           $493 = Math_fround(HEAPF32[$220>>2]);
           $502 = $493;$504 = $492;$506 = $491;
          }
          $494 = HEAP32[$211>>2]|0;
          $495 = ($494>>>0)>(63);
          if ($495) {
           $560 = $502;$561 = $504;$562 = $506;
          } else {
           $496 = HEAP32[$259>>2]|0;
           $497 = Math_fround(HEAPF32[$dMag>>2]);
           $498 = Math_fround(HEAPF32[$32>>2]);
           $499 = Math_fround(HEAPF32[$27>>2]);
           $500 = Math_fround(HEAPF32[$22>>2]);
           $501 = Math_fround($20 * $502);
           $503 = Math_fround($20 * $504);
           $505 = Math_fround($20 * $506);
           $507 = $496 & 1073741823;
           $508 = Math_fround($497 - $20);
           $509 = Math_fround($498 - $501);
           $510 = Math_fround($499 - $503);
           $511 = Math_fround($500 - $505);
           $512 = (($494) + 1)|0;
           HEAP32[$211>>2] = $512;
           $513 = (($contactBuffer) + ($494<<6)|0);
           HEAPF32[$513>>2] = $506;
           $514 = ((($contactBuffer) + ($494<<6)|0) + 4|0);
           HEAPF32[$514>>2] = $504;
           $515 = ((($contactBuffer) + ($494<<6)|0) + 8|0);
           HEAPF32[$515>>2] = $502;
           $516 = ((($contactBuffer) + ($494<<6)|0) + 16|0);
           HEAPF32[$516>>2] = $511;
           $517 = ((($contactBuffer) + ($494<<6)|0) + 20|0);
           HEAPF32[$517>>2] = $510;
           $518 = ((($contactBuffer) + ($494<<6)|0) + 24|0);
           HEAPF32[$518>>2] = $509;
           $519 = ((($contactBuffer) + ($494<<6)|0) + 12|0);
           HEAPF32[$519>>2] = $508;
           $520 = ((($contactBuffer) + ($494<<6)|0) + 48|0);
           HEAP32[$520>>2] = $261;
           $521 = ((($contactBuffer) + ($494<<6)|0) + 52|0);
           HEAP32[$521>>2] = $507;
           $560 = $502;$561 = $504;$562 = $506;
          }
         }
        }
        $522 = (($pi$071) + 1)|0;
        $exitcond119 = ($522|0)==($237|0);
        if ($exitcond119) {
         $$lcssa68 = $560;$$lcssa69 = $561;$$lcssa70 = $562;
         break;
        } else {
         $557 = $562;$558 = $561;$559 = $560;$pi$071 = $522;
        }
       }
      }
      $523 = (($c$084) + 1)|0;
      $524 = ($523>>>0)<($209>>>0);
      if ($524) {
       $554 = $$lcssa70;$555 = $$lcssa69;$556 = $$lcssa68;$c$084 = $523;
      } else {
       $$lcssa81 = $$lcssa68;$$lcssa82 = $$lcssa69;$$lcssa83 = $$lcssa70;
       break;
      }
     }
    } else {
     $$lcssa81 = $553;$$lcssa82 = $552;$$lcssa83 = $551;
    }
    $525 = (($r$093) + 1)|0;
    $526 = ($525>>>0)<($191>>>0);
    if ($526) {
     $551 = $$lcssa83;$552 = $$lcssa82;$553 = $$lcssa81;$r$093 = $525;
    } else {
     $$lcssa90 = $$lcssa81;$$lcssa91 = $$lcssa82;$$lcssa92 = $$lcssa83;
     break;
    }
   }
  } else {
   $$lcssa90 = $550;$$lcssa91 = $549;$$lcssa92 = $548;
  }
  if ($235) {
   $527 = HEAP32[$211>>2]|0;
   $528 = (($i$098) + 1)|0;
   $548 = $$lcssa92;$549 = $$lcssa91;$550 = $$lcssa90;$i$098 = $528;$numFaceContacts$099 = $527;
   continue;
  } else {
   $529 = (($i$098) + 1)|0;
   $exitcond122 = ($529|0)==(2);
   if ($exitcond122) {
    break;
   } else {
    $numFaceContacts$099$phi = $numFaceContacts$099;$548 = $$lcssa92;$549 = $$lcssa91;$550 = $$lcssa90;$i$098 = $529;$numFaceContacts$099 = $numFaceContacts$099$phi;
    continue;
   }
  }
 }
 if ($isCapsule) {
  $numFaceContacts$1121 = $numFaceContacts$099;
 } else {
  $530 = ($numFaceContacts$099|0)==(0);
  if ($530) {
   $numFaceContacts$1121 = 0;
  } else {
   $k$044 = 0;
   while(1) {
    $533 = ((($contactBuffer) + ($k$044<<6)|0) + 48|0);
    HEAP32[$533>>2] = -1;
    $534 = (($k$044) + 1)|0;
    $exitcond = ($534|0)==($numFaceContacts$099|0);
    if ($exitcond) {
     $numFaceContacts$1121 = $numFaceContacts$099;
     break;
    } else {
     $k$044 = $534;
    }
   }
  }
 }
 $531 = HEAP32[$211>>2]|0;
 $532 = ($numFaceContacts$1121>>>0)<($531>>>0);
 if ($532) {
  $k4$042 = $numFaceContacts$1121;
  while(1) {
   $535 = ((($contactBuffer) + ($k4$042<<6)|0) + 52|0);
   $536 = HEAP32[$535>>2]|0;
   $537 = ((($contactBuffer) + ($k4$042<<6)|0) + 48|0);
   $538 = HEAP32[$537>>2]|0;
   if ((($538|0) == 1)) {
    $539 = (__ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEj($hfUtil,$536)|0);
    HEAP32[$535>>2] = $539;
   } else if ((($538|0) == 2)) {
    $540 = HEAP32[$195>>2]|0;
    $541 = (($536>>>0) / ($540>>>0))&-1;
    $542 = (($536>>>0) % ($540>>>0))&-1;
    $543 = (__ZNK5physx2Gu15HeightFieldUtil18getVertexFaceIndexEjjj($hfUtil,$536,$541,$542)|0);
    HEAP32[$535>>2] = $543;
   }
   HEAP32[$537>>2] = -1;
   $544 = (($k4$042) + 1)|0;
   $545 = HEAP32[$211>>2]|0;
   $546 = ($544>>>0)<($545>>>0);
   if ($546) {
    $k4$042 = $544;
   } else {
    $$lcssa = $545;
    break;
   }
  }
 } else {
  $$lcssa = $531;
 }
 $547 = ($$lcssa|0)!=(0);
 $$0 = $547;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx27PxcContactSphereHeightFieldERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx33PxcContactSphereHeightFieldSharedERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferEb($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx20PxcContactSphereMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu17contactSphereMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx21PxcContactSpherePlaneERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transform0) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($transform1) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($transform0) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform1) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($transform0) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * Math_fround(2.0));
 $16 = Math_fround($9 * Math_fround(2.0));
 $17 = Math_fround($14 * Math_fround(2.0));
 $18 = (($transform1) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $19);
 $21 = Math_fround($20 + Math_fround(-0.5));
 $22 = Math_fround(HEAPF32[$transform1>>2]);
 $23 = Math_fround($15 * $22);
 $24 = (($transform1) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($16 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($transform1) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($17 * $29);
 $31 = Math_fround($27 + $30);
 $32 = Math_fround($15 * $21);
 $33 = Math_fround($17 * $25);
 $34 = Math_fround($16 * $29);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($19 * $35);
 $37 = Math_fround($32 - $36);
 $38 = Math_fround($22 * $31);
 $39 = Math_fround($38 + $37);
 $40 = (($shape0) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($39 - $41);
 $43 = Math_fround(HEAPF32[$contactDistance>>2]);
 $44 = !($42 <= $43);
 if ($44) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = Math_fround($22 * Math_fround(2.0));
 $46 = Math_fround($19 * Math_fround(2.0));
 $47 = Math_fround($19 * $46);
 $48 = Math_fround($47 + Math_fround(-1.0));
 $49 = Math_fround($22 * $45);
 $50 = Math_fround($49 + $48);
 $51 = Math_fround($29 * $46);
 $52 = Math_fround($45 * $25);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($46 * $25);
 $55 = Math_fround($45 * $29);
 $56 = Math_fround($55 - $54);
 $57 = (($contactBuffer) + 4096|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58>>>0)>(63);
 if ($59) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $60 = Math_fround($41 * $56);
 $61 = Math_fround($41 * $53);
 $62 = Math_fround($41 * $50);
 $63 = Math_fround($11 - $60);
 $64 = Math_fround($6 - $61);
 $65 = Math_fround($1 - $62);
 $66 = (($58) + 1)|0;
 HEAP32[$57>>2] = $66;
 $67 = (($contactBuffer) + ($58<<6)|0);
 HEAPF32[$67>>2] = $50;
 $68 = ((($contactBuffer) + ($58<<6)|0) + 4|0);
 HEAPF32[$68>>2] = $53;
 $69 = ((($contactBuffer) + ($58<<6)|0) + 8|0);
 HEAPF32[$69>>2] = $56;
 $70 = ((($contactBuffer) + ($58<<6)|0) + 16|0);
 HEAPF32[$70>>2] = $65;
 $71 = ((($contactBuffer) + ($58<<6)|0) + 20|0);
 HEAPF32[$71>>2] = $64;
 $72 = ((($contactBuffer) + ($58<<6)|0) + 24|0);
 HEAPF32[$72>>2] = $63;
 $73 = ((($contactBuffer) + ($58<<6)|0) + 12|0);
 HEAPF32[$73>>2] = $42;
 $74 = ((($contactBuffer) + ($58<<6)|0) + 48|0);
 HEAP32[$74>>2] = -1;
 $75 = ((($contactBuffer) + ($58<<6)|0) + 52|0);
 HEAP32[$75>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx22PxcContactSphereSphereERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $7 = 0;
 var $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transform0) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($transform1) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($transform0) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform1) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($transform0) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * $4);
 $16 = Math_fround($9 * $9);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($14 * $14);
 $19 = Math_fround($17 + $18);
 $20 = (($shape0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($shape1) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 + $23);
 $25 = Math_fround(HEAPF32[$contactDistance>>2]);
 $26 = Math_fround($24 + $25);
 $27 = Math_fround($26 * $26);
 $28 = $19 < $27;
 if (!($28)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (Math_fround(Math_sqrt((Math_fround($19)))));
 $30 = !($29 <= Math_fround(9.99999974737875163555E-6));
 if ($30) {
  $31 = Math_fround(Math_fround(1.0) / $29);
  $32 = Math_fround($4 * $31);
  $33 = Math_fround($9 * $31);
  $34 = Math_fround($14 * $31);
  $42 = $34;$44 = $33;$46 = $32;
 } else {
  $42 = Math_fround(0.0);$44 = Math_fround(0.0);$46 = Math_fround(1.0);
 }
 $35 = Math_fround($29 + $21);
 $36 = Math_fround($35 - $23);
 $37 = Math_fround($36 * Math_fround(-0.5));
 $38 = (($contactBuffer) + 4096|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39>>>0)>(63);
 if ($40) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = Math_fround($42 * $37);
 $43 = Math_fround($44 * $37);
 $45 = Math_fround($46 * $37);
 $47 = Math_fround($29 - $24);
 $48 = Math_fround($41 + $11);
 $49 = Math_fround($43 + $6);
 $50 = Math_fround($45 + $1);
 $51 = (($39) + 1)|0;
 HEAP32[$38>>2] = $51;
 $52 = (($contactBuffer) + ($39<<6)|0);
 HEAPF32[$52>>2] = $46;
 $53 = ((($contactBuffer) + ($39<<6)|0) + 4|0);
 HEAPF32[$53>>2] = $44;
 $54 = ((($contactBuffer) + ($39<<6)|0) + 8|0);
 HEAPF32[$54>>2] = $42;
 $55 = ((($contactBuffer) + ($39<<6)|0) + 16|0);
 HEAPF32[$55>>2] = $50;
 $56 = ((($contactBuffer) + ($39<<6)|0) + 20|0);
 HEAPF32[$56>>2] = $49;
 $57 = ((($contactBuffer) + ($39<<6)|0) + 24|0);
 HEAPF32[$57>>2] = $48;
 $58 = ((($contactBuffer) + ($39<<6)|0) + 12|0);
 HEAPF32[$58>>2] = $47;
 $59 = ((($contactBuffer) + ($39<<6)|0) + 48|0);
 HEAP32[$59>>2] = -1;
 $60 = ((($contactBuffer) + ($39<<6)|0) + 52|0);
 HEAP32[$60>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx19PxcPCMContactBoxBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu16pcmContactBoxBoxERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx22PxcPCMContactBoxConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu19pcmContactBoxConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx20PxcPCMContactBoxMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu17pcmContactBoxMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx23PxcPCMContactCapsuleBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu20pcmContactCapsuleBoxERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx32pcmDistanceSegmentSegmentSquaredERKNS_6shdfnd3aos5Vec3VES4_S4_S4_RNS1_6FloatVES6_($agg$result,$p1,$d1,$p2,$d2,$s,$t) {
 $agg$result = $agg$result|0;
 $p1 = $p1|0;
 $d1 = $d1|0;
 $p2 = $p2|0;
 $d2 = $d2|0;
 $s = $s|0;
 $t = $t|0;
 var $$$i$i = Math_fround(0), $$$i$i44 = Math_fround(0), $$$i$i72 = Math_fround(0), $$$i8$i = Math_fround(0), $$$i8$i45 = Math_fround(0), $$$i8$i73 = Math_fround(0), $$in1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn4$i = 0, $b$a$i124 = 0, $s2$sroa$1 = 0, $t2$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 16|0;
 $1 = sp;
 $t2$sroa$1 = sp + 44|0;
 $s2$sroa$1 = sp + 32|0;
 $2 = Math_fround(HEAPF32[$p1>>2]);
 $3 = (($p1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($p1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$p2>>2]);
 $8 = (($p2) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($p2) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($2 - $7);
 $13 = Math_fround($4 - $9);
 $14 = Math_fround($6 - $11);
 $15 = Math_fround(HEAPF32[$d1>>2]);
 $16 = (($d1) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($d1) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($15 * $15);
 $21 = Math_fround($17 * $17);
 $22 = Math_fround($19 * $19);
 $23 = Math_fround(HEAPF32[$d2>>2]);
 $24 = (($d2) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($d2) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($23 * $23);
 $29 = Math_fround($25 * $25);
 $30 = Math_fround($27 * $27);
 $31 = Math_fround($15 * $23);
 $32 = Math_fround($17 * $25);
 $33 = Math_fround($19 * $27);
 $34 = Math_fround($12 * $15);
 $35 = Math_fround($13 * $17);
 $36 = Math_fround($14 * $19);
 $37 = Math_fround($20 + $21);
 $38 = Math_fround($28 + $29);
 $39 = Math_fround($31 + $32);
 $40 = Math_fround($34 + $35);
 $41 = Math_fround($37 + $22);
 $42 = Math_fround($38 + $30);
 $43 = Math_fround($39 + $33);
 $44 = Math_fround($40 + $36);
 $45 = $41 > Math_fround(1.1920928955078125E-7);
 $46 = $42 > Math_fround(1.1920928955078125E-7);
 $47 = Math_fround(Math_fround(1.0) / $41);
 $48 = Math_fround(Math_fround(1.0) / $42);
 $49 = Math_fround(Math_fround(1.0) / $43);
 $50 = Math_fround(Math_fround(1.0) / $44);
 HEAPF32[$1>>2] = $47;
 $51 = (($1) + 4|0);
 HEAPF32[$51>>2] = $48;
 $52 = (($1) + 8|0);
 HEAPF32[$52>>2] = $49;
 $53 = (($1) + 12|0);
 HEAPF32[$53>>2] = $50;
 $b$a$i124 = $45 ? $1 : $0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $54 = Math_fround(HEAPF32[$b$a$i124>>2]);
 $a$pn4$i = $46 ? $1 : $0;
 $$in1$i = (($a$pn4$i) + 4|0);
 $55 = Math_fround(HEAPF32[$$in1$i>>2]);
 $56 = Math_fround($12 * $23);
 $57 = Math_fround($13 * $25);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($14 * $27);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($41 * $42);
 $62 = Math_fround($43 * $43);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($43 * $60);
 $65 = Math_fround($44 * $42);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround($66 / $63);
 $68 = $67 > Math_fround(1.0);
 $$$i$i72 = $68 ? Math_fround(1.0) : $67;
 $69 = $$$i$i72 > Math_fround(0.0);
 $$$i8$i73 = $69 ? $$$i$i72 : Math_fround(0.0);
 $70 = !($63 < Math_fround(1.1920928955078125E-7));
 $71 = $70 ? $$$i8$i73 : Math_fround(0.5);
 $72 = Math_fround($43 * $71);
 $73 = Math_fround($60 + $72);
 $74 = Math_fround($55 * $73);
 $75 = $74 > Math_fround(1.0);
 $$$i$i44 = $75 ? Math_fround(1.0) : $74;
 $76 = $$$i$i44 > Math_fround(0.0);
 $$$i8$i45 = $76 ? $$$i$i44 : Math_fround(0.0);
 $77 = Math_fround($43 * $$$i8$i45);
 $78 = Math_fround($77 - $44);
 $79 = Math_fround($54 * $78);
 $80 = $79 > Math_fround(1.0);
 $$$i$i = $80 ? Math_fround(1.0) : $79;
 $81 = $$$i$i > Math_fround(0.0);
 $$$i8$i = $81 ? $$$i$i : Math_fround(0.0);
 HEAPF32[$s>>2] = $$$i8$i;
 $82 = (($s) + 4|0);
 ;HEAP32[$82+0>>2]=HEAP32[$s2$sroa$1+0>>2]|0;HEAP32[$82+4>>2]=HEAP32[$s2$sroa$1+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$s2$sroa$1+8>>2]|0;
 HEAPF32[$t>>2] = $$$i8$i45;
 $83 = (($t) + 4|0);
 ;HEAP32[$83+0>>2]=HEAP32[$t2$sroa$1+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$t2$sroa$1+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$t2$sroa$1+8>>2]|0;
 $84 = Math_fround(HEAPF32[$d1>>2]);
 $85 = Math_fround(HEAPF32[$16>>2]);
 $86 = Math_fround(HEAPF32[$18>>2]);
 $87 = Math_fround(HEAPF32[$p1>>2]);
 $88 = Math_fround(HEAPF32[$3>>2]);
 $89 = Math_fround(HEAPF32[$5>>2]);
 $90 = Math_fround($84 * $$$i8$i);
 $91 = Math_fround($85 * $$$i8$i);
 $92 = Math_fround($86 * $$$i8$i);
 $93 = Math_fround($87 + $90);
 $94 = Math_fround($88 + $91);
 $95 = Math_fround($89 + $92);
 $96 = Math_fround(HEAPF32[$d2>>2]);
 $97 = Math_fround(HEAPF32[$24>>2]);
 $98 = Math_fround(HEAPF32[$26>>2]);
 $99 = Math_fround(HEAPF32[$p2>>2]);
 $100 = Math_fround(HEAPF32[$8>>2]);
 $101 = Math_fround(HEAPF32[$10>>2]);
 $102 = Math_fround($96 * $$$i8$i45);
 $103 = Math_fround($97 * $$$i8$i45);
 $104 = Math_fround($98 * $$$i8$i45);
 $105 = Math_fround($99 + $102);
 $106 = Math_fround($103 + $100);
 $107 = Math_fround($104 + $101);
 $108 = Math_fround($93 - $105);
 $109 = Math_fround($94 - $106);
 $110 = Math_fround($95 - $107);
 $111 = Math_fround($108 * $108);
 $112 = Math_fround($109 * $109);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($110 * $110);
 $115 = Math_fround($114 + $113);
 HEAPF32[$agg$result>>2] = $115;
 STACKTOP = sp;return;
}
function __ZN5physx27PxcPCMContactCapsuleCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $$demorgan = 0, $$demorgan1753 = 0, $$demorgan1754 = 0, $$demorgan1755 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i321 = 0, $$in1$i339 = 0, $$in1$i48 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i323 = 0, $$in2$i341 = 0, $$in2$i50 = 0, $$in3$i$i = 0, $$pre = Math_fround(0), $$pre1762 = Math_fround(0), $$pre1763 = Math_fround(0), $$pre1764 = Math_fround(0);
 var $$pre1765 = Math_fround(0), $$pre1766 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0;
 var $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0);
 var $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0);
 var $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0);
 var $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0);
 var $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0;
 var $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $b$a$i$i = 0, $b$a$i318 = 0, $b$a$i33 = 0, $b$a$i336 = 0, $b$a$i45 = 0, $b$a7$i$i = 0, $d0 = 0, $d1 = 0, $fabsf$i$i$i = Math_fround(0), $not$ = 0, $not$1750 = 0, $not$1751 = 0, $not$1752 = 0, $numContact$0 = 0;
 var $numContact$1 = 0, $numContact$2 = 0, $numContact$3 = 0, $or$cond = 0, $or$cond1756 = 0, $or$cond1758 = 0, $or$cond1760 = 0, $s0 = 0, $s1 = 0, $sqDist0 = 0, $t0 = 0, $t1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $0 = sp + 272|0;
 $1 = sp + 256|0;
 $2 = sp + 240|0;
 $3 = sp + 224|0;
 $4 = sp + 208|0;
 $5 = sp + 192|0;
 $6 = sp + 176|0;
 $7 = sp + 160|0;
 $8 = sp + 144|0;
 $9 = sp + 128|0;
 $zeroV = sp + 96|0;
 $s0 = sp + 80|0;
 $d0 = sp + 64|0;
 $s1 = sp + 48|0;
 $d1 = sp + 32|0;
 $t0 = sp + 16|0;
 $t1 = sp;
 $sqDist0 = sp + 112|0;
 $10 = (($transform0) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($10) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($10) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$transform0>>2]);
 $17 = (($transform0) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transform0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 12|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform1) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($23) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($23) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$transform1>>2]);
 $30 = (($transform1) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($transform1) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($transform1) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($shape0) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($shape0) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($shape1) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($shape1) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(HEAPF32[$contactDistance>>2]);
 $45 = Math_fround($11 + $24);
 $46 = Math_fround($13 + $26);
 $47 = Math_fround($15 + $28);
 $48 = Math_fround($45 * Math_fround(0.5));
 $49 = Math_fround($46 * Math_fround(0.5));
 $50 = Math_fround($47 * Math_fround(0.5));
 $51 = Math_fround($11 - $48);
 $52 = Math_fround($13 - $49);
 $53 = Math_fround($15 - $50);
 $54 = Math_fround($24 - $48);
 $55 = Math_fround($26 - $49);
 $56 = Math_fround($28 - $50);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $57 = Math_fround($16 * Math_fround(2.0));
 $58 = Math_fround($22 * Math_fround(2.0));
 $59 = Math_fround($16 * $57);
 $60 = Math_fround($57 * $18);
 $61 = Math_fround($57 * $20);
 $62 = Math_fround($22 * $58);
 $63 = Math_fround($20 * $58);
 $64 = Math_fround($18 * $58);
 $65 = Math_fround($59 + $62);
 $66 = Math_fround($60 + $63);
 $67 = Math_fround($61 - $64);
 $68 = Math_fround($65 + Math_fround(-1.0));
 $69 = Math_fround($68 * $39);
 $70 = Math_fround($66 * $39);
 $71 = Math_fround($67 * $39);
 $72 = Math_fround($51 + $69);
 $73 = Math_fround($52 + $70);
 $74 = Math_fround($53 + $71);
 HEAPF32[$s0>>2] = $72;
 $75 = (($s0) + 4|0);
 HEAPF32[$75>>2] = $73;
 $76 = (($s0) + 8|0);
 HEAPF32[$76>>2] = $74;
 $77 = (($s0) + 12|0);
 HEAPF32[$77>>2] = Math_fround(0.0);
 $78 = Math_fround($51 - $69);
 $79 = Math_fround($52 - $70);
 $80 = Math_fround($53 - $71);
 $81 = Math_fround($78 - $72);
 $82 = Math_fround($79 - $73);
 $83 = Math_fround($80 - $74);
 HEAPF32[$d0>>2] = $81;
 $84 = (($d0) + 4|0);
 HEAPF32[$84>>2] = $82;
 $85 = (($d0) + 8|0);
 HEAPF32[$85>>2] = $83;
 $86 = (($d0) + 12|0);
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = Math_fround($29 * Math_fround(2.0));
 $88 = Math_fround($35 * Math_fround(2.0));
 $89 = Math_fround($29 * $87);
 $90 = Math_fround($87 * $31);
 $91 = Math_fround($87 * $33);
 $92 = Math_fround($35 * $88);
 $93 = Math_fround($33 * $88);
 $94 = Math_fround($31 * $88);
 $95 = Math_fround($89 + $92);
 $96 = Math_fround($90 + $93);
 $97 = Math_fround($91 - $94);
 $98 = Math_fround($95 + Math_fround(-1.0));
 $99 = Math_fround($98 * $43);
 $100 = Math_fround($96 * $43);
 $101 = Math_fround($97 * $43);
 $102 = Math_fround($54 + $99);
 $103 = Math_fround($55 + $100);
 $104 = Math_fround($56 + $101);
 HEAPF32[$s1>>2] = $102;
 $105 = (($s1) + 4|0);
 HEAPF32[$105>>2] = $103;
 $106 = (($s1) + 8|0);
 HEAPF32[$106>>2] = $104;
 $107 = (($s1) + 12|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = Math_fround($54 - $99);
 $109 = Math_fround($55 - $100);
 $110 = Math_fround($56 - $101);
 $111 = Math_fround($108 - $102);
 $112 = Math_fround($109 - $103);
 $113 = Math_fround($110 - $104);
 HEAPF32[$d1>>2] = $111;
 $114 = (($d1) + 4|0);
 HEAPF32[$114>>2] = $112;
 $115 = (($d1) + 8|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($d1) + 12|0);
 HEAPF32[$116>>2] = Math_fround(0.0);
 $117 = Math_fround($37 + $41);
 $118 = Math_fround($117 + $44);
 $119 = Math_fround($118 * $118);
 $120 = Math_fround($81 * $81);
 $121 = Math_fround($82 * $82);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($83 * $83);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($111 * $111);
 $126 = Math_fround($112 * $112);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround($113 * $113);
 $129 = Math_fround($127 + $128);
 __ZN5physx32pcmDistanceSegmentSegmentSquaredERKNS_6shdfnd3aos5Vec3VES4_S4_S4_RNS1_6FloatVES6_($sqDist0,$s0,$d0,$s1,$d1,$t0,$t1);
 $130 = Math_fround(HEAPF32[$sqDist0>>2]);
 $131 = !($119 >= $130);
 if ($131) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $132 = $124 < Math_fround(9.99999997475242707878E-7);
 $133 = $129 < Math_fround(9.99999997475242707878E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $134 = Math_fround(HEAPF32[$d0>>2]);
 $135 = Math_fround(HEAPF32[$84>>2]);
 $136 = Math_fround(HEAPF32[$85>>2]);
 $137 = (Math_fround(Math_sqrt((Math_fround($124)))));
 $138 = Math_fround(Math_fround(1.0) / $137);
 $139 = Math_fround($134 * $138);
 $140 = Math_fround($135 * $138);
 $141 = Math_fround($136 * $138);
 HEAPF32[$0>>2] = $139;
 $142 = (($0) + 4|0);
 HEAPF32[$142>>2] = $140;
 $143 = (($0) + 8|0);
 HEAPF32[$143>>2] = $141;
 $144 = (($0) + 12|0);
 HEAPF32[$144>>2] = Math_fround(0.0);
 $b$a$i336 = $132 ? $1 : $0;
 $145 = Math_fround(HEAPF32[$b$a$i336>>2]);
 $$in1$i339 = (($b$a$i336) + 4|0);
 $146 = Math_fround(HEAPF32[$$in1$i339>>2]);
 $$in2$i341 = (($b$a$i336) + 8|0);
 $147 = Math_fround(HEAPF32[$$in2$i341>>2]);
 ;HEAP32[$3+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $148 = Math_fround(HEAPF32[$d1>>2]);
 $149 = Math_fround(HEAPF32[$114>>2]);
 $150 = Math_fround(HEAPF32[$115>>2]);
 $151 = (Math_fround(Math_sqrt((Math_fround($129)))));
 $152 = Math_fround(Math_fround(1.0) / $151);
 $153 = Math_fround($148 * $152);
 $154 = Math_fround($149 * $152);
 $155 = Math_fround($150 * $152);
 HEAPF32[$2>>2] = $153;
 $156 = (($2) + 4|0);
 HEAPF32[$156>>2] = $154;
 $157 = (($2) + 8|0);
 HEAPF32[$157>>2] = $155;
 $158 = (($2) + 12|0);
 HEAPF32[$158>>2] = Math_fround(0.0);
 $b$a$i318 = $133 ? $3 : $2;
 $159 = Math_fround(HEAPF32[$b$a$i318>>2]);
 $$in1$i321 = (($b$a$i318) + 4|0);
 $160 = Math_fround(HEAPF32[$$in1$i321>>2]);
 $$in2$i323 = (($b$a$i318) + 8|0);
 $161 = Math_fround(HEAPF32[$$in2$i323>>2]);
 $162 = Math_fround($145 * $159);
 $163 = Math_fround($146 * $160);
 $164 = Math_fround($162 + $163);
 $165 = Math_fround($147 * $161);
 $166 = Math_fround($164 + $165);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($166)))));
 $167 = $fabsf$i$i$i > Math_fround(0.999800026416778564453);
 if ($167) {
  $168 = Math_fround(HEAPF32[$s1>>2]);
  $169 = Math_fround(HEAPF32[$105>>2]);
  $170 = Math_fround(HEAPF32[$106>>2]);
  $171 = Math_fround(HEAPF32[$s0>>2]);
  $172 = Math_fround(HEAPF32[$75>>2]);
  $173 = Math_fround(HEAPF32[$76>>2]);
  $174 = Math_fround($168 - $171);
  $175 = Math_fround($169 - $172);
  $176 = Math_fround($170 - $173);
  $177 = Math_fround($108 - $171);
  $178 = Math_fround($109 - $172);
  $179 = Math_fround($110 - $173);
  $180 = Math_fround($171 - $168);
  $181 = Math_fround($172 - $169);
  $182 = Math_fround($173 - $170);
  $183 = Math_fround($78 - $168);
  $184 = Math_fround($79 - $169);
  $185 = Math_fround($80 - $170);
  $186 = Math_fround($78 - $171);
  $187 = Math_fround($79 - $172);
  $188 = Math_fround($80 - $173);
  $189 = Math_fround($108 - $168);
  $190 = Math_fround($109 - $169);
  $191 = Math_fround($110 - $170);
  $192 = Math_fround($174 * $186);
  $193 = Math_fround($175 * $187);
  $194 = Math_fround($176 * $188);
  $195 = Math_fround($177 * $186);
  $196 = Math_fround($178 * $187);
  $197 = Math_fround($179 * $188);
  $198 = Math_fround($189 * $180);
  $199 = Math_fround($190 * $181);
  $200 = Math_fround($191 * $182);
  $201 = Math_fround($183 * $189);
  $202 = Math_fround($184 * $190);
  $203 = Math_fround($185 * $191);
  $204 = Math_fround($192 + $193);
  $205 = Math_fround($195 + $196);
  $206 = Math_fround($198 + $199);
  $207 = Math_fround($201 + $202);
  $208 = Math_fround($204 + $194);
  $209 = Math_fround($205 + $197);
  $210 = Math_fround($206 + $200);
  $211 = Math_fround($207 + $203);
  $212 = Math_fround($186 * $186);
  $213 = Math_fround($187 * $187);
  $214 = Math_fround($212 + $213);
  $215 = Math_fround($188 * $188);
  $216 = Math_fround($214 + $215);
  $217 = Math_fround($189 * $189);
  $218 = Math_fround($190 * $190);
  $219 = Math_fround($217 + $218);
  $220 = Math_fround($191 * $191);
  $221 = Math_fround($219 + $220);
  $222 = Math_fround($208 / $216);
  $223 = Math_fround($209 / $216);
  $224 = Math_fround($210 / $221);
  $225 = Math_fround($211 / $221);
  $226 = $216 == Math_fround(0.0);
  $227 = $221 == Math_fround(0.0);
  ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
  HEAPF32[$4>>2] = $222;
  $228 = (($4) + 4|0);
  HEAPF32[$228>>2] = $223;
  $229 = (($4) + 8|0);
  HEAPF32[$229>>2] = $224;
  $230 = (($4) + 12|0);
  HEAPF32[$230>>2] = $225;
  $b$a$i$i = $226 ? $5 : $4;
  $231 = Math_fround(HEAPF32[$b$a$i$i>>2]);
  $$in1$i$i = (($b$a$i$i) + 4|0);
  $232 = Math_fround(HEAPF32[$$in1$i$i>>2]);
  $b$a7$i$i = $227 ? $5 : $4;
  $$in2$i$i = (($b$a7$i$i) + 8|0);
  $233 = Math_fround(HEAPF32[$$in2$i$i>>2]);
  $$in3$i$i = (($b$a7$i$i) + 12|0);
  $234 = Math_fround(HEAPF32[$$in3$i$i>>2]);
  $235 = $231 <= Math_fround(1.0);
  $236 = $232 <= Math_fround(1.0);
  $237 = $233 <= Math_fround(1.0);
  $238 = $234 <= Math_fround(1.0);
  $not$ = $231 >= Math_fround(0.0);
  $not$1750 = $232 >= Math_fround(0.0);
  $not$1751 = $233 >= Math_fround(0.0);
  $not$1752 = $234 >= Math_fround(0.0);
  $$demorgan = $235 & $not$;
  if ($$demorgan) {
   $239 = Math_fround($231 * $134);
   $240 = Math_fround($231 * $135);
   $241 = Math_fround($231 * $136);
   $242 = Math_fround($239 + $171);
   $243 = Math_fround($240 + $172);
   $244 = Math_fround($241 + $173);
   $245 = Math_fround($242 - $168);
   $246 = Math_fround($243 - $169);
   $247 = Math_fround($244 - $170);
   $248 = Math_fround($245 * $245);
   $249 = Math_fround($246 * $246);
   $250 = Math_fround($248 + $249);
   $251 = Math_fround($247 * $247);
   $252 = Math_fround($250 + $251);
   $253 = $252 > Math_fround(9.99999997475242707878E-7);
   $254 = $119 > $252;
   $or$cond = $253 & $254;
   if ($or$cond) {
    $255 = (Math_fround(Math_sqrt((Math_fround($252)))));
    $256 = Math_fround(Math_fround(1.0) / $255);
    $257 = Math_fround($245 * $256);
    $258 = Math_fround($246 * $256);
    $259 = Math_fround($247 * $256);
    $260 = (($contactBuffer) + 4096|0);
    $261 = HEAP32[$260>>2]|0;
    $262 = ($261>>>0)>(63);
    if ($262) {
     $numContact$0 = 1;
    } else {
     $263 = Math_fround($37 * $259);
     $264 = Math_fround($37 * $258);
     $265 = Math_fround($37 * $257);
     $266 = Math_fround($244 - $263);
     $267 = Math_fround($243 - $264);
     $268 = Math_fround($242 - $265);
     $269 = Math_fround($50 + $266);
     $270 = Math_fround($49 + $267);
     $271 = Math_fround($48 + $268);
     $272 = Math_fround($255 - $117);
     $273 = (($261) + 1)|0;
     HEAP32[$260>>2] = $273;
     $274 = (($contactBuffer) + ($261<<6)|0);
     HEAPF32[$274>>2] = $257;
     $275 = (($274) + 4|0);
     HEAPF32[$275>>2] = $258;
     $276 = (($274) + 8|0);
     HEAPF32[$276>>2] = $259;
     $277 = (($274) + 12|0);
     HEAPF32[$277>>2] = Math_fround(0.0);
     $278 = ((($contactBuffer) + ($261<<6)|0) + 16|0);
     HEAPF32[$278>>2] = $271;
     $279 = (($278) + 4|0);
     HEAPF32[$279>>2] = $270;
     $280 = (($278) + 8|0);
     HEAPF32[$280>>2] = $269;
     $281 = (($278) + 12|0);
     HEAPF32[$281>>2] = Math_fround(0.0);
     $282 = ((($contactBuffer) + ($261<<6)|0) + 12|0);
     HEAPF32[$282>>2] = $272;
     $283 = ((($contactBuffer) + ($261<<6)|0) + 48|0);
     HEAP32[$283>>2] = -1;
     $284 = ((($contactBuffer) + ($261<<6)|0) + 52|0);
     HEAP32[$284>>2] = -1;
     $numContact$0 = 1;
    }
   } else {
    $numContact$0 = 0;
   }
  } else {
   $numContact$0 = 0;
  }
  $$demorgan1753 = $236 & $not$1750;
  if ($$demorgan1753) {
   $285 = Math_fround($232 * $134);
   $286 = Math_fround($232 * $135);
   $287 = Math_fround($232 * $136);
   $288 = Math_fround($285 + $171);
   $289 = Math_fround($286 + $172);
   $290 = Math_fround($287 + $173);
   $291 = Math_fround($288 - $108);
   $292 = Math_fround($289 - $109);
   $293 = Math_fround($290 - $110);
   $294 = Math_fround($291 * $291);
   $295 = Math_fround($292 * $292);
   $296 = Math_fround($294 + $295);
   $297 = Math_fround($293 * $293);
   $298 = Math_fround($296 + $297);
   $299 = $298 > Math_fround(9.99999997475242707878E-7);
   $300 = $119 > $298;
   $or$cond1756 = $299 & $300;
   if ($or$cond1756) {
    $301 = (Math_fround(Math_sqrt((Math_fround($298)))));
    $302 = Math_fround(Math_fround(1.0) / $301);
    $303 = Math_fround($291 * $302);
    $304 = Math_fround($292 * $302);
    $305 = Math_fround($293 * $302);
    $306 = (($contactBuffer) + 4096|0);
    $307 = HEAP32[$306>>2]|0;
    $308 = ($307>>>0)>(63);
    if (!($308)) {
     $309 = Math_fround($37 * $305);
     $310 = Math_fround($37 * $304);
     $311 = Math_fround($37 * $303);
     $312 = Math_fround($290 - $309);
     $313 = Math_fround($289 - $310);
     $314 = Math_fround($288 - $311);
     $315 = Math_fround($50 + $312);
     $316 = Math_fround($49 + $313);
     $317 = Math_fround($48 + $314);
     $318 = Math_fround($301 - $117);
     $319 = (($307) + 1)|0;
     HEAP32[$306>>2] = $319;
     $320 = (($contactBuffer) + ($307<<6)|0);
     HEAPF32[$320>>2] = $303;
     $321 = (($320) + 4|0);
     HEAPF32[$321>>2] = $304;
     $322 = (($320) + 8|0);
     HEAPF32[$322>>2] = $305;
     $323 = (($320) + 12|0);
     HEAPF32[$323>>2] = Math_fround(0.0);
     $324 = ((($contactBuffer) + ($307<<6)|0) + 16|0);
     HEAPF32[$324>>2] = $317;
     $325 = (($324) + 4|0);
     HEAPF32[$325>>2] = $316;
     $326 = (($324) + 8|0);
     HEAPF32[$326>>2] = $315;
     $327 = (($324) + 12|0);
     HEAPF32[$327>>2] = Math_fround(0.0);
     $328 = ((($contactBuffer) + ($307<<6)|0) + 12|0);
     HEAPF32[$328>>2] = $318;
     $329 = ((($contactBuffer) + ($307<<6)|0) + 48|0);
     HEAP32[$329>>2] = -1;
     $330 = ((($contactBuffer) + ($307<<6)|0) + 52|0);
     HEAP32[$330>>2] = -1;
    }
    $331 = (($numContact$0) + 1)|0;
    $numContact$1 = $331;
   } else {
    $numContact$1 = $numContact$0;
   }
  } else {
   $numContact$1 = $numContact$0;
  }
  $$demorgan1754 = $237 & $not$1751;
  if ($$demorgan1754) {
   $332 = Math_fround($233 * $148);
   $333 = Math_fround($233 * $149);
   $334 = Math_fround($233 * $150);
   $335 = Math_fround($332 + $168);
   $336 = Math_fround($333 + $169);
   $337 = Math_fround($334 + $170);
   $338 = Math_fround($171 - $335);
   $339 = Math_fround($172 - $336);
   $340 = Math_fround($173 - $337);
   $341 = Math_fround($338 * $338);
   $342 = Math_fround($339 * $339);
   $343 = Math_fround($341 + $342);
   $344 = Math_fround($340 * $340);
   $345 = Math_fround($343 + $344);
   $346 = $345 > Math_fround(9.99999997475242707878E-7);
   $347 = $119 > $345;
   $or$cond1758 = $346 & $347;
   if ($or$cond1758) {
    $348 = (Math_fround(Math_sqrt((Math_fround($345)))));
    $349 = Math_fround(Math_fround(1.0) / $348);
    $350 = Math_fround($338 * $349);
    $351 = Math_fround($339 * $349);
    $352 = Math_fround($340 * $349);
    $353 = (($contactBuffer) + 4096|0);
    $354 = HEAP32[$353>>2]|0;
    $355 = ($354>>>0)>(63);
    if (!($355)) {
     $356 = Math_fround($37 * $352);
     $357 = Math_fround($37 * $351);
     $358 = Math_fround($37 * $350);
     $359 = Math_fround($173 - $356);
     $360 = Math_fround($172 - $357);
     $361 = Math_fround($171 - $358);
     $362 = Math_fround($50 + $359);
     $363 = Math_fround($49 + $360);
     $364 = Math_fround($48 + $361);
     $365 = Math_fround($348 - $117);
     $366 = (($354) + 1)|0;
     HEAP32[$353>>2] = $366;
     $367 = (($contactBuffer) + ($354<<6)|0);
     HEAPF32[$367>>2] = $350;
     $368 = (($367) + 4|0);
     HEAPF32[$368>>2] = $351;
     $369 = (($367) + 8|0);
     HEAPF32[$369>>2] = $352;
     $370 = (($367) + 12|0);
     HEAPF32[$370>>2] = Math_fround(0.0);
     $371 = ((($contactBuffer) + ($354<<6)|0) + 16|0);
     HEAPF32[$371>>2] = $364;
     $372 = (($371) + 4|0);
     HEAPF32[$372>>2] = $363;
     $373 = (($371) + 8|0);
     HEAPF32[$373>>2] = $362;
     $374 = (($371) + 12|0);
     HEAPF32[$374>>2] = Math_fround(0.0);
     $375 = ((($contactBuffer) + ($354<<6)|0) + 12|0);
     HEAPF32[$375>>2] = $365;
     $376 = ((($contactBuffer) + ($354<<6)|0) + 48|0);
     HEAP32[$376>>2] = -1;
     $377 = ((($contactBuffer) + ($354<<6)|0) + 52|0);
     HEAP32[$377>>2] = -1;
    }
    $378 = (($numContact$1) + 1)|0;
    $numContact$2 = $378;
   } else {
    $numContact$2 = $numContact$1;
   }
  } else {
   $numContact$2 = $numContact$1;
  }
  $$demorgan1755 = $238 & $not$1752;
  if ($$demorgan1755) {
   $379 = Math_fround($234 * $148);
   $380 = Math_fround($234 * $149);
   $381 = Math_fround($234 * $150);
   $382 = Math_fround($379 + $168);
   $383 = Math_fround($380 + $169);
   $384 = Math_fround($381 + $170);
   $385 = Math_fround($78 - $382);
   $386 = Math_fround($79 - $383);
   $387 = Math_fround($80 - $384);
   $388 = Math_fround($385 * $385);
   $389 = Math_fround($386 * $386);
   $390 = Math_fround($388 + $389);
   $391 = Math_fround($387 * $387);
   $392 = Math_fround($390 + $391);
   $393 = $392 > Math_fround(9.99999997475242707878E-7);
   $394 = $119 > $392;
   $or$cond1760 = $393 & $394;
   if ($or$cond1760) {
    $395 = (Math_fround(Math_sqrt((Math_fround($392)))));
    $396 = Math_fround(Math_fround(1.0) / $395);
    $397 = Math_fround($385 * $396);
    $398 = Math_fround($386 * $396);
    $399 = Math_fround($387 * $396);
    $400 = (($contactBuffer) + 4096|0);
    $401 = HEAP32[$400>>2]|0;
    $402 = ($401>>>0)>(63);
    if (!($402)) {
     $403 = Math_fround($37 * $399);
     $404 = Math_fround($37 * $398);
     $405 = Math_fround($37 * $397);
     $406 = Math_fround($80 - $403);
     $407 = Math_fround($79 - $404);
     $408 = Math_fround($78 - $405);
     $409 = Math_fround($50 + $406);
     $410 = Math_fround($49 + $407);
     $411 = Math_fround($48 + $408);
     $412 = Math_fround($395 - $117);
     $413 = (($401) + 1)|0;
     HEAP32[$400>>2] = $413;
     $414 = (($contactBuffer) + ($401<<6)|0);
     HEAPF32[$414>>2] = $397;
     $415 = (($414) + 4|0);
     HEAPF32[$415>>2] = $398;
     $416 = (($414) + 8|0);
     HEAPF32[$416>>2] = $399;
     $417 = (($414) + 12|0);
     HEAPF32[$417>>2] = Math_fround(0.0);
     $418 = ((($contactBuffer) + ($401<<6)|0) + 16|0);
     HEAPF32[$418>>2] = $411;
     $419 = (($418) + 4|0);
     HEAPF32[$419>>2] = $410;
     $420 = (($418) + 8|0);
     HEAPF32[$420>>2] = $409;
     $421 = (($418) + 12|0);
     HEAPF32[$421>>2] = Math_fround(0.0);
     $422 = ((($contactBuffer) + ($401<<6)|0) + 12|0);
     HEAPF32[$422>>2] = $412;
     $423 = ((($contactBuffer) + ($401<<6)|0) + 48|0);
     HEAP32[$423>>2] = -1;
     $424 = ((($contactBuffer) + ($401<<6)|0) + 52|0);
     HEAP32[$424>>2] = -1;
    }
    $425 = (($numContact$2) + 1)|0;
    $numContact$3 = $425;
   } else {
    $numContact$3 = $numContact$2;
   }
  } else {
   $numContact$3 = $numContact$2;
  }
  $426 = ($numContact$3|0)==(0);
  if ($426) {
   $432 = $171;$434 = $172;$436 = $173;$442 = $168;$444 = $169;$446 = $170;
  } else {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$pre = Math_fround(HEAPF32[$s0>>2]);
  $$pre1762 = Math_fround(HEAPF32[$75>>2]);
  $$pre1763 = Math_fround(HEAPF32[$76>>2]);
  $$pre1764 = Math_fround(HEAPF32[$s1>>2]);
  $$pre1765 = Math_fround(HEAPF32[$105>>2]);
  $$pre1766 = Math_fround(HEAPF32[$106>>2]);
  $432 = $$pre;$434 = $$pre1762;$436 = $$pre1763;$442 = $$pre1764;$444 = $$pre1765;$446 = $$pre1766;
 }
 $427 = Math_fround(HEAPF32[$t0>>2]);
 $428 = Math_fround($134 * $427);
 $429 = Math_fround($135 * $427);
 $430 = Math_fround($136 * $427);
 $431 = Math_fround($428 + $432);
 $433 = Math_fround($429 + $434);
 $435 = Math_fround($430 + $436);
 $437 = Math_fround(HEAPF32[$t1>>2]);
 $438 = Math_fround($148 * $437);
 $439 = Math_fround($149 * $437);
 $440 = Math_fround($150 * $437);
 $441 = Math_fround($438 + $442);
 $443 = Math_fround($439 + $444);
 $445 = Math_fround($440 + $446);
 $447 = $130 < Math_fround(9.99999997475242707878E-7);
 $448 = $124 > Math_fround(9.99999997475242707878E-7);
 ;HEAP32[$7+0>>2]=HEAP32[$d0+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$d0+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$d0+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$d0+12>>2]|0;
 HEAPF32[$6>>2] = Math_fround(1.0);
 $449 = (($6) + 4|0);
 HEAPF32[$449>>2] = Math_fround(0.0);
 $450 = (($6) + 8|0);
 HEAPF32[$450>>2] = Math_fround(0.0);
 $451 = (($6) + 12|0);
 HEAPF32[$451>>2] = Math_fround(0.0);
 $b$a$i45 = $448 ? $7 : $6;
 $452 = Math_fround(HEAPF32[$b$a$i45>>2]);
 $$in1$i48 = (($b$a$i45) + 4|0);
 $453 = Math_fround(HEAPF32[$$in1$i48>>2]);
 $$in2$i50 = (($b$a$i45) + 8|0);
 $454 = Math_fround(HEAPF32[$$in2$i50>>2]);
 $455 = Math_fround($431 - $441);
 $456 = Math_fround($433 - $443);
 $457 = Math_fround($435 - $445);
 HEAPF32[$9>>2] = $452;
 $458 = (($9) + 4|0);
 HEAPF32[$458>>2] = $453;
 $459 = (($9) + 8|0);
 HEAPF32[$459>>2] = $454;
 $460 = (($9) + 12|0);
 HEAPF32[$460>>2] = Math_fround(0.0);
 HEAPF32[$8>>2] = $455;
 $461 = (($8) + 4|0);
 HEAPF32[$461>>2] = $456;
 $462 = (($8) + 8|0);
 HEAPF32[$462>>2] = $457;
 $463 = (($8) + 12|0);
 HEAPF32[$463>>2] = Math_fround(0.0);
 $b$a$i33 = $447 ? $9 : $8;
 $464 = Math_fround(HEAPF32[$b$a$i33>>2]);
 $$in1$i = (($b$a$i33) + 4|0);
 $465 = Math_fround(HEAPF32[$$in1$i>>2]);
 $$in2$i = (($b$a$i33) + 8|0);
 $466 = Math_fround(HEAPF32[$$in2$i>>2]);
 $467 = Math_fround($464 * $464);
 $468 = Math_fround($465 * $465);
 $469 = Math_fround($467 + $468);
 $470 = Math_fround($466 * $466);
 $471 = Math_fround($469 + $470);
 $472 = (Math_fround(Math_sqrt((Math_fround($471)))));
 $473 = Math_fround(Math_fround(1.0) / $472);
 $474 = Math_fround($464 * $473);
 $475 = Math_fround($465 * $473);
 $476 = Math_fround($466 * $473);
 $477 = (($contactBuffer) + 4096|0);
 $478 = HEAP32[$477>>2]|0;
 $479 = ($478>>>0)>(63);
 if ($479) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $480 = (Math_fround(Math_sqrt((Math_fround($130)))));
 $481 = Math_fround($37 * $476);
 $482 = Math_fround($37 * $475);
 $483 = Math_fround($37 * $474);
 $484 = $447 ? Math_fround(0.0) : $480;
 $485 = Math_fround($435 - $481);
 $486 = Math_fround($433 - $482);
 $487 = Math_fround($431 - $483);
 $488 = Math_fround($484 - $117);
 $489 = Math_fround($50 + $485);
 $490 = Math_fround($49 + $486);
 $491 = Math_fround($48 + $487);
 $492 = (($478) + 1)|0;
 HEAP32[$477>>2] = $492;
 $493 = (($contactBuffer) + ($478<<6)|0);
 HEAPF32[$493>>2] = $474;
 $494 = (($493) + 4|0);
 HEAPF32[$494>>2] = $475;
 $495 = (($493) + 8|0);
 HEAPF32[$495>>2] = $476;
 $496 = (($493) + 12|0);
 HEAPF32[$496>>2] = Math_fround(0.0);
 $497 = ((($contactBuffer) + ($478<<6)|0) + 16|0);
 HEAPF32[$497>>2] = $491;
 $498 = (($497) + 4|0);
 HEAPF32[$498>>2] = $490;
 $499 = (($497) + 8|0);
 HEAPF32[$499>>2] = $489;
 $500 = (($497) + 12|0);
 HEAPF32[$500>>2] = Math_fround(0.0);
 $501 = ((($contactBuffer) + ($478<<6)|0) + 12|0);
 HEAPF32[$501>>2] = $488;
 $502 = ((($contactBuffer) + ($478<<6)|0) + 48|0);
 HEAP32[$502>>2] = -1;
 $503 = ((($contactBuffer) + ($478<<6)|0) + 52|0);
 HEAP32[$503>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx26PxcPCMContactCapsuleConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu23pcmContactCapsuleConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx24PxcPCMContactCapsuleMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu21pcmContactCapsuleMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx25PxcPCMContactConvexConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu22pcmContactConvexConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx23PxcPCMContactConvexMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu20pcmContactConvexMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx21PxcPCMContactPlaneBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18pcmContactPlaneBoxERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx25PxcPCMContactPlaneCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu22pcmContactPlaneCapsuleERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx24PxcPCMContactPlaneConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu21pcmContactPlaneConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx22PxcPCMContactSphereBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i = Math_fround(0), $$$i$i124 = Math_fround(0), $$$i$i140 = Math_fround(0), $$$i8$i = Math_fround(0), $$0 = 0, $$1$i$i = Math_fround(0), $$1$i$i125 = Math_fround(0), $$1$i$i141 = Math_fround(0), $$1$i9$i = Math_fround(0), $$in1$i = 0, $$in1$i69 = 0, $$in2$i = 0, $$in2$i71 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0);
 var $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0;
 var $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0;
 var $99 = 0, $b$a$i58 = 0, $b$a$i66 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = (($transform0) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($4) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($4) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$transform1>>2]);
 $11 = (($transform1) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transform1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transform1) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transform1) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($17) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($17) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($shape0) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(HEAPF32[$contactDistance>>2]);
 $26 = (($shape1) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($shape1) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($shape1) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($5 - $18);
 $33 = Math_fround($7 - $20);
 $34 = Math_fround($9 - $22);
 $35 = Math_fround($16 * $16);
 $36 = Math_fround($35 + Math_fround(-0.5));
 $37 = Math_fround($36 * $32);
 $38 = Math_fround($36 * $33);
 $39 = Math_fround($36 * $34);
 $40 = Math_fround($12 * $34);
 $41 = Math_fround($14 * $33);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($14 * $32);
 $44 = Math_fround($10 * $34);
 $45 = Math_fround($43 - $44);
 $46 = Math_fround($10 * $33);
 $47 = Math_fround($12 * $32);
 $48 = Math_fround($46 - $47);
 $49 = Math_fround($16 * $42);
 $50 = Math_fround($16 * $45);
 $51 = Math_fround($16 * $48);
 $52 = Math_fround($37 - $49);
 $53 = Math_fround($38 - $50);
 $54 = Math_fround($39 - $51);
 $55 = Math_fround($10 * $32);
 $56 = Math_fround($12 * $33);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($14 * $34);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($10 * $59);
 $61 = Math_fround($12 * $59);
 $62 = Math_fround($14 * $59);
 $63 = Math_fround($60 + $52);
 $64 = Math_fround($61 + $53);
 $65 = Math_fround($54 + $62);
 $66 = Math_fround($63 * Math_fround(2.0));
 $67 = Math_fround($64 * Math_fround(2.0));
 $68 = Math_fround($65 * Math_fround(2.0));
 $69 = Math_fround(-$27);
 $70 = Math_fround(-$29);
 $71 = Math_fround(-$31);
 $72 = Math_fround($24 + $25);
 $73 = Math_fround($72 * $72);
 $74 = $66 < $27;
 $$$i$i140 = $74 ? $66 : $27;
 $75 = $67 < $29;
 $76 = $75 ? $67 : $29;
 $77 = $68 < $31;
 $$1$i$i141 = $77 ? $68 : $31;
 $78 = $$$i$i140 > $69;
 $$$i8$i = $78 ? $$$i$i140 : $69;
 $79 = $76 > $70;
 $80 = $79 ? $76 : $70;
 $81 = $$1$i$i141 > $71;
 $$1$i9$i = $81 ? $$1$i$i141 : $71;
 $82 = Math_fround($66 - $$$i8$i);
 $83 = Math_fround($67 - $80);
 $84 = Math_fround($68 - $$1$i9$i);
 $85 = Math_fround($82 * $82);
 $86 = Math_fround($83 * $83);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($84 * $84);
 $89 = Math_fround($88 + $87);
 $90 = $73 > $89;
 if (!($90)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $91 = Math_fround(-$66);
 $92 = Math_fround(-$67);
 $93 = Math_fround(-$68);
 $94 = $66 > $91;
 $$$i$i124 = $94 ? $66 : $91;
 $95 = $67 > $92;
 $96 = $95 ? $67 : $92;
 $97 = $68 > $93;
 $$1$i$i125 = $97 ? $68 : $93;
 $98 = $27 >= $$$i$i124;
 $99 = $29 >= $96;
 $100 = $31 >= $$1$i$i125;
 $101 = $99 & $98;
 $102 = $101 & $100;
 if ($102) {
  $103 = Math_fround(-$$$i8$i);
  $104 = Math_fround(-$80);
  $105 = Math_fround(-$$1$i9$i);
  $106 = $$$i8$i > $103;
  $$$i$i = $106 ? $$$i8$i : $103;
  $107 = $80 > $104;
  $108 = $107 ? $80 : $104;
  $109 = $$1$i9$i > $105;
  $$1$i$i = $109 ? $$1$i9$i : $105;
  $110 = Math_fround($27 - $$$i$i);
  $111 = Math_fround($29 - $108);
  $112 = Math_fround($31 - $$1$i$i);
  $113 = $110 >= $112;
  $114 = $111 >= $112;
  $115 = ($112 == $112) & (Math_fround(0.0) == Math_fround(0.0));
  $116 = $114 & $113;
  $117 = $116 & $115;
  $118 = ($110 == $110) & (Math_fround(0.0) == Math_fround(0.0));
  $119 = $111 >= $110;
  $120 = $112 >= $110;
  $121 = $119 & $118;
  $122 = $121 & $120;
  $123 = $$$i8$i >= Math_fround(0.0);
  $124 = $123 ? Math_fround(1.0) : Math_fround(-1.0);
  $125 = $80 >= Math_fround(0.0);
  $126 = $125 ? Math_fround(1.0) : Math_fround(-1.0);
  $127 = $$1$i9$i >= Math_fround(0.0);
  $128 = $127 ? Math_fround(1.0) : Math_fround(-1.0);
  $129 = Math_fround($126 * Math_fround(0.0));
  $130 = Math_fround($128 * Math_fround(0.0));
  $131 = Math_fround($124 * Math_fround(0.0));
  HEAPF32[$1>>2] = $124;
  $132 = (($1) + 4|0);
  HEAPF32[$132>>2] = $129;
  $133 = (($1) + 8|0);
  HEAPF32[$133>>2] = $130;
  $134 = (($1) + 12|0);
  HEAPF32[$134>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = $131;
  $135 = (($0) + 4|0);
  HEAPF32[$135>>2] = $126;
  $136 = (($0) + 8|0);
  HEAPF32[$136>>2] = $130;
  $137 = (($0) + 12|0);
  HEAPF32[$137>>2] = Math_fround(0.0);
  $b$a$i66 = $122 ? $1 : $0;
  $138 = Math_fround(HEAPF32[$b$a$i66>>2]);
  $$in1$i69 = (($b$a$i66) + 4|0);
  $139 = Math_fround(HEAPF32[$$in1$i69>>2]);
  $$in2$i71 = (($b$a$i66) + 8|0);
  $140 = Math_fround(HEAPF32[$$in2$i71>>2]);
  HEAPF32[$3>>2] = $131;
  $141 = (($3) + 4|0);
  HEAPF32[$141>>2] = $129;
  $142 = (($3) + 8|0);
  HEAPF32[$142>>2] = $128;
  $143 = (($3) + 12|0);
  HEAPF32[$143>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = $138;
  $144 = (($2) + 4|0);
  HEAPF32[$144>>2] = $139;
  $145 = (($2) + 8|0);
  HEAPF32[$145>>2] = $140;
  $146 = (($2) + 12|0);
  HEAPF32[$146>>2] = Math_fround(0.0);
  $b$a$i58 = $117 ? $3 : $2;
  $147 = Math_fround(HEAPF32[$b$a$i58>>2]);
  $$in1$i = (($b$a$i58) + 4|0);
  $148 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i58) + 8|0);
  $149 = Math_fround(HEAPF32[$$in2$i>>2]);
  $150 = $122 ? $110 : $111;
  $151 = $117 ? $112 : $150;
  $152 = Math_fround(-$151);
  $153 = Math_fround($36 * $147);
  $154 = Math_fround($36 * $148);
  $155 = Math_fround($36 * $149);
  $156 = Math_fround($12 * $149);
  $157 = Math_fround($14 * $148);
  $158 = Math_fround($156 - $157);
  $159 = Math_fround($14 * $147);
  $160 = Math_fround($10 * $149);
  $161 = Math_fround($159 - $160);
  $162 = Math_fround($10 * $148);
  $163 = Math_fround($12 * $147);
  $164 = Math_fround($162 - $163);
  $165 = Math_fround($16 * $158);
  $166 = Math_fround($16 * $161);
  $167 = Math_fround($16 * $164);
  $168 = Math_fround($153 + $165);
  $169 = Math_fround($154 + $166);
  $170 = Math_fround($155 + $167);
  $171 = Math_fround($10 * $147);
  $172 = Math_fround($12 * $148);
  $173 = Math_fround($171 + $172);
  $174 = Math_fround($14 * $149);
  $175 = Math_fround($173 + $174);
  $176 = Math_fround($10 * $175);
  $177 = Math_fround($12 * $175);
  $178 = Math_fround($14 * $175);
  $179 = Math_fround($176 + $168);
  $180 = Math_fround($177 + $169);
  $181 = Math_fround($170 + $178);
  $182 = Math_fround($179 * Math_fround(2.0));
  $183 = Math_fround($180 * Math_fround(2.0));
  $184 = Math_fround($181 * Math_fround(2.0));
  $185 = Math_fround($152 - $24);
  $186 = (($contactBuffer) + 4096|0);
  $187 = HEAP32[$186>>2]|0;
  $188 = (($187) + 1)|0;
  HEAP32[$186>>2] = $188;
  $189 = (($contactBuffer) + ($187<<6)|0);
  HEAPF32[$189>>2] = $182;
  $190 = (($189) + 4|0);
  HEAPF32[$190>>2] = $183;
  $191 = (($189) + 8|0);
  HEAPF32[$191>>2] = $184;
  $192 = (($189) + 12|0);
  HEAPF32[$192>>2] = Math_fround(0.0);
  $193 = ((($contactBuffer) + ($187<<6)|0) + 16|0);
  HEAPF32[$193>>2] = $5;
  $194 = (($193) + 4|0);
  HEAPF32[$194>>2] = $7;
  $195 = (($193) + 8|0);
  HEAPF32[$195>>2] = $9;
  $196 = (($193) + 12|0);
  HEAPF32[$196>>2] = Math_fround(0.0);
  $197 = ((($contactBuffer) + ($187<<6)|0) + 12|0);
  HEAPF32[$197>>2] = $185;
  $198 = ((($contactBuffer) + ($187<<6)|0) + 48|0);
  HEAP32[$198>>2] = -1;
  $199 = ((($contactBuffer) + ($187<<6)|0) + 52|0);
  HEAP32[$199>>2] = -1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $200 = (Math_fround(Math_sqrt((Math_fround($89)))));
  $201 = Math_fround(Math_fround(1.0) / $200);
  $202 = Math_fround(Math_fround(1.0) / $201);
  $203 = Math_fround($82 * $201);
  $204 = Math_fround($83 * $201);
  $205 = Math_fround($84 * $201);
  $206 = Math_fround($202 - $24);
  $207 = Math_fround($36 * $203);
  $208 = Math_fround($36 * $204);
  $209 = Math_fround($36 * $205);
  $210 = Math_fround($12 * $205);
  $211 = Math_fround($14 * $204);
  $212 = Math_fround($210 - $211);
  $213 = Math_fround($14 * $203);
  $214 = Math_fround($10 * $205);
  $215 = Math_fround($213 - $214);
  $216 = Math_fround($10 * $204);
  $217 = Math_fround($12 * $203);
  $218 = Math_fround($216 - $217);
  $219 = Math_fround($16 * $212);
  $220 = Math_fround($16 * $215);
  $221 = Math_fround($16 * $218);
  $222 = Math_fround($207 + $219);
  $223 = Math_fround($208 + $220);
  $224 = Math_fround($209 + $221);
  $225 = Math_fround($10 * $203);
  $226 = Math_fround($12 * $204);
  $227 = Math_fround($225 + $226);
  $228 = Math_fround($14 * $205);
  $229 = Math_fround($228 + $227);
  $230 = Math_fround($10 * $229);
  $231 = Math_fround($12 * $229);
  $232 = Math_fround($14 * $229);
  $233 = Math_fround($230 + $222);
  $234 = Math_fround($231 + $223);
  $235 = Math_fround($224 + $232);
  $236 = Math_fround($233 * Math_fround(2.0));
  $237 = Math_fround($234 * Math_fround(2.0));
  $238 = Math_fround($235 * Math_fround(2.0));
  $239 = Math_fround($36 * $$$i8$i);
  $240 = Math_fround($36 * $80);
  $241 = Math_fround($36 * $$1$i9$i);
  $242 = Math_fround($12 * $$1$i9$i);
  $243 = Math_fround($14 * $80);
  $244 = Math_fround($242 - $243);
  $245 = Math_fround($14 * $$$i8$i);
  $246 = Math_fround($10 * $$1$i9$i);
  $247 = Math_fround($245 - $246);
  $248 = Math_fround($10 * $80);
  $249 = Math_fround($12 * $$$i8$i);
  $250 = Math_fround($248 - $249);
  $251 = Math_fround($16 * $244);
  $252 = Math_fround($16 * $247);
  $253 = Math_fround($16 * $250);
  $254 = Math_fround($239 + $251);
  $255 = Math_fround($240 + $252);
  $256 = Math_fround($241 + $253);
  $257 = Math_fround($10 * $$$i8$i);
  $258 = Math_fround($12 * $80);
  $259 = Math_fround($257 + $258);
  $260 = Math_fround($14 * $$1$i9$i);
  $261 = Math_fround($260 + $259);
  $262 = Math_fround($10 * $261);
  $263 = Math_fround($12 * $261);
  $264 = Math_fround($14 * $261);
  $265 = Math_fround($262 + $254);
  $266 = Math_fround($263 + $255);
  $267 = Math_fround($256 + $264);
  $268 = Math_fround($265 * Math_fround(2.0));
  $269 = Math_fround($266 * Math_fround(2.0));
  $270 = Math_fround($267 * Math_fround(2.0));
  $271 = Math_fround($18 + $268);
  $272 = Math_fround($20 + $269);
  $273 = Math_fround($22 + $270);
  $274 = (($contactBuffer) + 4096|0);
  $275 = HEAP32[$274>>2]|0;
  $276 = (($275) + 1)|0;
  HEAP32[$274>>2] = $276;
  $277 = (($contactBuffer) + ($275<<6)|0);
  HEAPF32[$277>>2] = $236;
  $278 = (($277) + 4|0);
  HEAPF32[$278>>2] = $237;
  $279 = (($277) + 8|0);
  HEAPF32[$279>>2] = $238;
  $280 = (($277) + 12|0);
  HEAPF32[$280>>2] = Math_fround(0.0);
  $281 = ((($contactBuffer) + ($275<<6)|0) + 16|0);
  HEAPF32[$281>>2] = $271;
  $282 = (($281) + 4|0);
  HEAPF32[$282>>2] = $272;
  $283 = (($281) + 8|0);
  HEAPF32[$283>>2] = $273;
  $284 = (($281) + 12|0);
  HEAPF32[$284>>2] = Math_fround(0.0);
  $285 = ((($contactBuffer) + ($275<<6)|0) + 12|0);
  HEAPF32[$285>>2] = $206;
  $286 = ((($contactBuffer) + ($275<<6)|0) + 48|0);
  HEAP32[$286>>2] = -1;
  $287 = ((($contactBuffer) + ($275<<6)|0) + 52|0);
  HEAP32[$287>>2] = -1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx26PxcPCMContactSphereCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in2$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $b$a$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($transform0) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($2) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($2) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(HEAPF32[$transform1>>2]);
 $9 = (($transform1) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transform1) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transform1) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transform1) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($15) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($15) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($shape0) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($shape1) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(HEAPF32[$contactDistance>>2]);
 $26 = (($shape1) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($8 * Math_fround(2.0));
 $29 = Math_fround($14 * Math_fround(2.0));
 $30 = Math_fround($8 * $28);
 $31 = Math_fround($28 * $10);
 $32 = Math_fround($28 * $12);
 $33 = Math_fround($14 * $29);
 $34 = Math_fround($12 * $29);
 $35 = Math_fround($10 * $29);
 $36 = Math_fround($30 + $33);
 $37 = Math_fround($31 + $34);
 $38 = Math_fround($32 - $35);
 $39 = Math_fround($36 + Math_fround(-1.0));
 $40 = Math_fround($39 * $27);
 $41 = Math_fround($37 * $27);
 $42 = Math_fround($38 * $27);
 $43 = Math_fround($16 + $40);
 $44 = Math_fround($18 + $41);
 $45 = Math_fround($20 + $42);
 $46 = Math_fround($16 - $40);
 $47 = Math_fround($18 - $41);
 $48 = Math_fround($20 - $42);
 $49 = Math_fround($22 + $24);
 $50 = Math_fround($49 + $25);
 $51 = Math_fround($3 - $43);
 $52 = Math_fround($5 - $44);
 $53 = Math_fround($7 - $45);
 $54 = Math_fround($46 - $43);
 $55 = Math_fround($47 - $44);
 $56 = Math_fround($48 - $45);
 $57 = Math_fround($51 * $54);
 $58 = Math_fround($52 * $55);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($53 * $56);
 $61 = Math_fround($60 + $59);
 $62 = Math_fround($54 * $54);
 $63 = Math_fround($55 * $55);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($56 * $56);
 $66 = Math_fround($65 + $64);
 $67 = Math_fround(Math_fround(1.0) / $66);
 $68 = Math_fround($67 * $61);
 $69 = $68 > Math_fround(1.0);
 $$$i$i$i = $69 ? Math_fround(1.0) : $68;
 $70 = $$$i$i$i > Math_fround(0.0);
 $$$i8$i$i = $70 ? $$$i$i$i : Math_fround(0.0);
 $71 = $66 != Math_fround(0.0);
 $72 = $71 ? $$$i8$i$i : Math_fround(0.0);
 $73 = Math_fround($54 * $72);
 $74 = Math_fround($55 * $72);
 $75 = Math_fround($56 * $72);
 $76 = Math_fround($51 - $73);
 $77 = Math_fround($52 - $74);
 $78 = Math_fround($53 - $75);
 $79 = Math_fround($76 * $76);
 $80 = Math_fround($77 * $77);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($78 * $78);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($50 * $50);
 $85 = $84 > $83;
 if (!($85)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $86 = Math_fround($43 + $73);
 $87 = Math_fround($44 + $74);
 $88 = Math_fround($45 + $75);
 $89 = Math_fround($3 - $86);
 $90 = Math_fround($5 - $87);
 $91 = Math_fround($7 - $88);
 $92 = Math_fround($89 * $89);
 $93 = Math_fround($90 * $90);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($91 * $91);
 $96 = Math_fround($95 + $94);
 $97 = $96 == Math_fround(0.0);
 $98 = (Math_fround(Math_sqrt((Math_fround($96)))));
 $99 = Math_fround(Math_fround(1.0) / $98);
 $100 = Math_fround($89 * $99);
 $101 = Math_fround($90 * $99);
 $102 = Math_fround($91 * $99);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $103 = (($1) + 4|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($1) + 8|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($1) + 12|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = $100;
 $106 = (($0) + 4|0);
 HEAPF32[$106>>2] = $101;
 $107 = (($0) + 8|0);
 HEAPF32[$107>>2] = $102;
 $108 = (($0) + 12|0);
 HEAPF32[$108>>2] = Math_fround(0.0);
 $b$a$i = $97 ? $1 : $0;
 $109 = Math_fround(HEAPF32[$b$a$i>>2]);
 $$in1$i = (($b$a$i) + 4|0);
 $110 = Math_fround(HEAPF32[$$in1$i>>2]);
 $$in2$i = (($b$a$i) + 8|0);
 $111 = Math_fround(HEAPF32[$$in2$i>>2]);
 $112 = Math_fround($22 * $109);
 $113 = Math_fround($22 * $110);
 $114 = Math_fround($22 * $111);
 $115 = Math_fround($3 - $112);
 $116 = Math_fround($5 - $113);
 $117 = Math_fround($7 - $114);
 $118 = (Math_fround(Math_sqrt((Math_fround($83)))));
 $119 = Math_fround($118 - $49);
 $120 = (($contactBuffer) + 4096|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = (($121) + 1)|0;
 HEAP32[$120>>2] = $122;
 $123 = (($contactBuffer) + ($121<<6)|0);
 HEAPF32[$123>>2] = $109;
 $124 = (($123) + 4|0);
 HEAPF32[$124>>2] = $110;
 $125 = (($123) + 8|0);
 HEAPF32[$125>>2] = $111;
 $126 = (($123) + 12|0);
 HEAPF32[$126>>2] = Math_fround(0.0);
 $127 = ((($contactBuffer) + ($121<<6)|0) + 16|0);
 HEAPF32[$127>>2] = $115;
 $128 = (($127) + 4|0);
 HEAPF32[$128>>2] = $116;
 $129 = (($127) + 8|0);
 HEAPF32[$129>>2] = $117;
 $130 = (($127) + 12|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = ((($contactBuffer) + ($121<<6)|0) + 12|0);
 HEAPF32[$131>>2] = $119;
 $132 = ((($contactBuffer) + ($121<<6)|0) + 48|0);
 HEAP32[$132>>2] = -1;
 $133 = ((($contactBuffer) + ($121<<6)|0) + 52|0);
 HEAP32[$133>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx25PxcPCMContactSphereConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu22pcmContactSphereConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx23PxcPCMContactSphereMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu20pcmContactSphereMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx24PxcPCMContactSpherePlaneERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transform0) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($0) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($transform1) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($6) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($6) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(HEAPF32[$transform1>>2]);
 $13 = (($transform1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transform1) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transform1) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($shape0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$contactDistance>>2]);
 $22 = Math_fround($1 - $7);
 $23 = Math_fround($3 - $9);
 $24 = Math_fround($5 - $11);
 $25 = Math_fround($18 * $18);
 $26 = Math_fround($25 + Math_fround(-0.5));
 $27 = Math_fround($22 * $26);
 $28 = Math_fround($24 * $14);
 $29 = Math_fround($23 * $16);
 $30 = Math_fround($28 - $29);
 $31 = Math_fround($18 * $30);
 $32 = Math_fround($27 - $31);
 $33 = Math_fround($22 * $12);
 $34 = Math_fround($23 * $14);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($24 * $16);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($12 * $37);
 $39 = Math_fround($38 + $32);
 $40 = Math_fround($39 * Math_fround(2.0));
 $41 = Math_fround($40 - $20);
 $42 = !($21 >= $41);
 if ($42) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = Math_fround($12 * Math_fround(2.0));
 $44 = Math_fround($18 * Math_fround(2.0));
 $45 = Math_fround($12 * $43);
 $46 = Math_fround($43 * $14);
 $47 = Math_fround($43 * $16);
 $48 = Math_fround($18 * $44);
 $49 = Math_fround($16 * $44);
 $50 = Math_fround($14 * $44);
 $51 = Math_fround($45 + $48);
 $52 = Math_fround($46 + $49);
 $53 = Math_fround($47 - $50);
 $54 = Math_fround($51 + Math_fround(-1.0));
 $55 = Math_fround($20 * $54);
 $56 = Math_fround($20 * $52);
 $57 = Math_fround($20 * $53);
 $58 = Math_fround($1 - $55);
 $59 = Math_fround($3 - $56);
 $60 = Math_fround($5 - $57);
 $61 = (($contactBuffer) + 4096|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + 1)|0;
 HEAP32[$61>>2] = $63;
 $64 = (($contactBuffer) + ($62<<6)|0);
 HEAPF32[$64>>2] = $54;
 $65 = (($64) + 4|0);
 HEAPF32[$65>>2] = $52;
 $66 = (($64) + 8|0);
 HEAPF32[$66>>2] = $53;
 $67 = (($64) + 12|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = ((($contactBuffer) + ($62<<6)|0) + 16|0);
 HEAPF32[$68>>2] = $58;
 $69 = (($68) + 4|0);
 HEAPF32[$69>>2] = $59;
 $70 = (($68) + 8|0);
 HEAPF32[$70>>2] = $60;
 $71 = (($68) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = ((($contactBuffer) + ($62<<6)|0) + 12|0);
 HEAPF32[$72>>2] = $41;
 $73 = ((($contactBuffer) + ($62<<6)|0) + 48|0);
 HEAP32[$73>>2] = -1;
 $74 = ((($contactBuffer) + ($62<<6)|0) + 52|0);
 HEAP32[$74>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx25PxcPCMContactSphereSphereERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$npCache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $npCache = $npCache|0;
 $contactBuffer = $contactBuffer|0;
 var $$0 = 0, $$in1$i = 0, $$in2$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0);
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $b$a$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = Math_fround(HEAPF32[$contactDistance>>2]);
 $3 = (($transform0) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($3) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($3) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($transform1) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($9) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($9) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($shape0) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($shape1) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($4 - $10);
 $20 = Math_fround($6 - $12);
 $21 = Math_fround($8 - $14);
 $22 = Math_fround($19 * $19);
 $23 = Math_fround($20 * $20);
 $24 = Math_fround($22 + $23);
 $25 = Math_fround($21 * $21);
 $26 = Math_fround($24 + $25);
 $27 = Math_fround($16 + $18);
 $28 = Math_fround($2 + $27);
 $29 = Math_fround($28 * $28);
 $30 = $29 > $26;
 if (!($30)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (Math_fround(Math_sqrt((Math_fround($26)))));
 $32 = $31 <= Math_fround(9.99999974737875163555E-6);
 $33 = Math_fround(Math_fround(1.0) / $31);
 $34 = Math_fround($19 * $33);
 $35 = Math_fround($20 * $33);
 $36 = Math_fround($21 * $33);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $37 = (($1) + 4|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($1) + 8|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($1) + 12|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = $34;
 $40 = (($0) + 4|0);
 HEAPF32[$40>>2] = $35;
 $41 = (($0) + 8|0);
 HEAPF32[$41>>2] = $36;
 $42 = (($0) + 12|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $b$a$i = $32 ? $1 : $0;
 $43 = Math_fround(HEAPF32[$b$a$i>>2]);
 $$in1$i = (($b$a$i) + 4|0);
 $44 = Math_fround(HEAPF32[$$in1$i>>2]);
 $$in2$i = (($b$a$i) + 8|0);
 $45 = Math_fround(HEAPF32[$$in2$i>>2]);
 $46 = Math_fround($16 + $31);
 $47 = Math_fround($46 - $18);
 $48 = Math_fround($47 * Math_fround(-0.5));
 $49 = Math_fround($43 * $48);
 $50 = Math_fround($44 * $48);
 $51 = Math_fround($48 * $45);
 $52 = Math_fround($4 + $49);
 $53 = Math_fround($6 + $50);
 $54 = Math_fround($8 + $51);
 $55 = Math_fround($31 - $27);
 $56 = (($contactBuffer) + 4096|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 1)|0;
 HEAP32[$56>>2] = $58;
 $59 = (($contactBuffer) + ($57<<6)|0);
 HEAPF32[$59>>2] = $43;
 $60 = (($59) + 4|0);
 HEAPF32[$60>>2] = $44;
 $61 = (($59) + 8|0);
 HEAPF32[$61>>2] = $45;
 $62 = (($59) + 12|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = ((($contactBuffer) + ($57<<6)|0) + 16|0);
 HEAPF32[$63>>2] = $52;
 $64 = (($63) + 4|0);
 HEAPF32[$64>>2] = $53;
 $65 = (($63) + 8|0);
 HEAPF32[$65>>2] = $54;
 $66 = (($63) + 12|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = ((($contactBuffer) + ($57<<6)|0) + 12|0);
 HEAPF32[$67>>2] = $55;
 $68 = ((($contactBuffer) + ($57<<6)|0) + 48|0);
 HEAP32[$68>>2] = -1;
 $69 = ((($contactBuffer) + ($57<<6)|0) + 52|0);
 HEAP32[$69>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx18PxcConvexTriangles19calcCenterAndBoundsERKNS_11PxTransformE($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $$lcssa = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert10 = 0, $$phi$trans$insert12 = 0, $$pre = Math_fround(0), $$pre11 = Math_fround(0), $$pre13 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0);
 var $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0);
 var $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0);
 var $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0;
 var $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0;
 var $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0);
 var $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0);
 var $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0);
 var $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = 0;
 var $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$07 = 0;
 var $phitmp = 0, $phitmp14 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$phi$trans$insert = (($this) + 64|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$phi$trans$insert10 = (($this) + 68|0);
  $$pre11 = Math_fround(HEAPF32[$$phi$trans$insert10>>2]);
  $$phi$trans$insert12 = (($this) + 72|0);
  $$pre13 = Math_fround(HEAPF32[$$phi$trans$insert12>>2]);
  $$lcssa = Math_fround(0.0);$384 = $$pre;$387 = $$pre11;$390 = $$pre13;
  $381 = Math_fround(Math_fround(1.0) / $$lcssa);
  $382 = (($this) + 64|0);
  $383 = Math_fround($381 * $384);
  HEAPF32[$382>>2] = $383;
  $385 = (($this) + 68|0);
  $386 = Math_fround($381 * $387);
  HEAPF32[$385>>2] = $386;
  $388 = (($this) + 72|0);
  $389 = Math_fround($381 * $390);
  HEAPF32[$388>>2] = $389;
  $391 = (($this) + 76|0);
  HEAP8[$391>>0] = 1;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 $4 = (($this) + 4|0);
 $5 = (($transform) + 12|0);
 $6 = (($transform) + 4|0);
 $7 = (($transform) + 8|0);
 $8 = (($transform) + 16|0);
 $9 = (($transform) + 20|0);
 $10 = (($transform) + 24|0);
 $11 = (($this) + 64|0);
 $12 = (($this) + 68|0);
 $13 = (($this) + 72|0);
 $14 = (($this) + 40|0);
 $15 = (($this) + 44|0);
 $16 = (($this) + 48|0);
 $17 = (($this) + 52|0);
 $18 = (($this) + 56|0);
 $19 = (($this) + 60|0);
 $i$07 = 0;
 while(1) {
  $20 = HEAP32[$3>>2]|0;
  $21 = (($20) + ($i$07<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$this>>2]|0;
  $24 = (($23) + 40|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 156|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27 & 2;
  $29 = ($28<<24>>24)==(0);
  $30 = (($25) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  if ($29) {
   $46 = (($31) + (($22*12)|0)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($25) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + (($47*12)|0)|0);
   $51 = ((($31) + (($22*12)|0)|0) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($49) + (($52*12)|0)|0);
   $54 = ((($31) + (($22*12)|0)|0) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($49) + (($55*12)|0)|0);
   $166 = $53;$273 = $56;$59 = $50;
  } else {
   $32 = (($31) + (($22*6)|0)|0);
   $33 = HEAP16[$32>>1]|0;
   $34 = $33&65535;
   $35 = (($25) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + (($34*12)|0)|0);
   $38 = ((($31) + (($22*6)|0)|0) + 2|0);
   $39 = HEAP16[$38>>1]|0;
   $40 = $39&65535;
   $41 = (($36) + (($40*12)|0)|0);
   $42 = ((($31) + (($22*6)|0)|0) + 4|0);
   $43 = HEAP16[$42>>1]|0;
   $44 = $43&65535;
   $45 = (($36) + (($44*12)|0)|0);
   $166 = $41;$273 = $45;$59 = $37;
  }
  $57 = HEAP32[$4>>2]|0;
  $58 = Math_fround(HEAPF32[$59>>2]);
  $60 = Math_fround(HEAPF32[$57>>2]);
  $61 = Math_fround($58 * $60);
  $62 = (($57) + 4|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($58 * $63);
  $65 = (($57) + 8|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($58 * $66);
  $68 = (($59) + 4|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($57) + 12|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = Math_fround($69 * $71);
  $73 = (($57) + 16|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($69 * $74);
  $76 = (($57) + 20|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = Math_fround($69 * $77);
  $79 = Math_fround($61 + $72);
  $80 = Math_fround($64 + $75);
  $81 = Math_fround($67 + $78);
  $82 = (($59) + 8|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($57) + 24|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($83 * $85);
  $87 = (($57) + 28|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($83 * $88);
  $90 = (($57) + 32|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($83 * $91);
  $93 = Math_fround($79 + $86);
  $94 = Math_fround($80 + $89);
  $95 = Math_fround($81 + $92);
  $96 = Math_fround($93 * Math_fround(2.0));
  $97 = Math_fround($94 * Math_fround(2.0));
  $98 = Math_fround($95 * Math_fround(2.0));
  $99 = Math_fround(HEAPF32[$5>>2]);
  $100 = Math_fround($99 * $99);
  $101 = Math_fround($100 + Math_fround(-0.5));
  $102 = Math_fround(HEAPF32[$transform>>2]);
  $103 = Math_fround($96 * $102);
  $104 = Math_fround(HEAPF32[$6>>2]);
  $105 = Math_fround($97 * $104);
  $106 = Math_fround($103 + $105);
  $107 = Math_fround(HEAPF32[$7>>2]);
  $108 = Math_fround($98 * $107);
  $109 = Math_fround($106 + $108);
  $110 = Math_fround($96 * $101);
  $111 = Math_fround($98 * $104);
  $112 = Math_fround($97 * $107);
  $113 = Math_fround($111 - $112);
  $114 = Math_fround($99 * $113);
  $115 = Math_fround($110 + $114);
  $116 = Math_fround($102 * $109);
  $117 = Math_fround($116 + $115);
  $118 = Math_fround($97 * $101);
  $119 = Math_fround($96 * $107);
  $120 = Math_fround($102 * $98);
  $121 = Math_fround($119 - $120);
  $122 = Math_fround($99 * $121);
  $123 = Math_fround($118 + $122);
  $124 = Math_fround($104 * $109);
  $125 = Math_fround($124 + $123);
  $126 = Math_fround($98 * $101);
  $127 = Math_fround($97 * $102);
  $128 = Math_fround($96 * $104);
  $129 = Math_fround($127 - $128);
  $130 = Math_fround($99 * $129);
  $131 = Math_fround($126 + $130);
  $132 = Math_fround($107 * $109);
  $133 = Math_fround($131 + $132);
  $134 = Math_fround(HEAPF32[$8>>2]);
  $135 = Math_fround($134 + $117);
  $136 = Math_fround(HEAPF32[$9>>2]);
  $137 = Math_fround($136 + $125);
  $138 = Math_fround(HEAPF32[$10>>2]);
  $139 = Math_fround($138 + $133);
  $140 = Math_fround(HEAPF32[$11>>2]);
  $141 = Math_fround($140 + $135);
  HEAPF32[$11>>2] = $141;
  $142 = Math_fround(HEAPF32[$12>>2]);
  $143 = Math_fround($142 + $137);
  HEAPF32[$12>>2] = $143;
  $144 = Math_fround(HEAPF32[$13>>2]);
  $145 = Math_fround($139 + $144);
  HEAPF32[$13>>2] = $145;
  $146 = Math_fround(HEAPF32[$14>>2]);
  $147 = $146 < $135;
  $148 = $147 ? $146 : $135;
  $149 = Math_fround(HEAPF32[$15>>2]);
  $150 = $149 < $137;
  $151 = $150 ? $149 : $137;
  $152 = Math_fround(HEAPF32[$16>>2]);
  $153 = $152 < $139;
  $154 = $153 ? $152 : $139;
  HEAPF32[$14>>2] = $148;
  HEAPF32[$15>>2] = $151;
  HEAPF32[$16>>2] = $154;
  $155 = Math_fround(HEAPF32[$17>>2]);
  $156 = $155 > $135;
  $157 = $156 ? $155 : $135;
  $158 = Math_fround(HEAPF32[$18>>2]);
  $159 = $158 > $137;
  $160 = $159 ? $158 : $137;
  $161 = Math_fround(HEAPF32[$19>>2]);
  $162 = $161 > $139;
  $163 = $162 ? $161 : $139;
  HEAPF32[$17>>2] = $157;
  HEAPF32[$18>>2] = $160;
  HEAPF32[$19>>2] = $163;
  $164 = HEAP32[$4>>2]|0;
  $165 = Math_fround(HEAPF32[$166>>2]);
  $167 = Math_fround(HEAPF32[$164>>2]);
  $168 = Math_fround($165 * $167);
  $169 = (($164) + 4|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround($165 * $170);
  $172 = (($164) + 8|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($165 * $173);
  $175 = (($166) + 4|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = (($164) + 12|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = Math_fround($176 * $178);
  $180 = (($164) + 16|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = Math_fround($176 * $181);
  $183 = (($164) + 20|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = Math_fround($176 * $184);
  $186 = Math_fround($168 + $179);
  $187 = Math_fround($171 + $182);
  $188 = Math_fround($174 + $185);
  $189 = (($166) + 8|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($164) + 24|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = Math_fround($190 * $192);
  $194 = (($164) + 28|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($190 * $195);
  $197 = (($164) + 32|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = Math_fround($190 * $198);
  $200 = Math_fround($186 + $193);
  $201 = Math_fround($187 + $196);
  $202 = Math_fround($188 + $199);
  $203 = Math_fround($200 * Math_fround(2.0));
  $204 = Math_fround($201 * Math_fround(2.0));
  $205 = Math_fround($202 * Math_fround(2.0));
  $206 = Math_fround(HEAPF32[$5>>2]);
  $207 = Math_fround($206 * $206);
  $208 = Math_fround($207 + Math_fround(-0.5));
  $209 = Math_fround(HEAPF32[$transform>>2]);
  $210 = Math_fround($203 * $209);
  $211 = Math_fround(HEAPF32[$6>>2]);
  $212 = Math_fround($204 * $211);
  $213 = Math_fround($210 + $212);
  $214 = Math_fround(HEAPF32[$7>>2]);
  $215 = Math_fround($205 * $214);
  $216 = Math_fround($213 + $215);
  $217 = Math_fround($203 * $208);
  $218 = Math_fround($205 * $211);
  $219 = Math_fround($204 * $214);
  $220 = Math_fround($218 - $219);
  $221 = Math_fround($206 * $220);
  $222 = Math_fround($217 + $221);
  $223 = Math_fround($209 * $216);
  $224 = Math_fround($223 + $222);
  $225 = Math_fround($204 * $208);
  $226 = Math_fround($203 * $214);
  $227 = Math_fround($209 * $205);
  $228 = Math_fround($226 - $227);
  $229 = Math_fround($206 * $228);
  $230 = Math_fround($225 + $229);
  $231 = Math_fround($211 * $216);
  $232 = Math_fround($231 + $230);
  $233 = Math_fround($205 * $208);
  $234 = Math_fround($204 * $209);
  $235 = Math_fround($203 * $211);
  $236 = Math_fround($234 - $235);
  $237 = Math_fround($206 * $236);
  $238 = Math_fround($233 + $237);
  $239 = Math_fround($214 * $216);
  $240 = Math_fround($238 + $239);
  $241 = Math_fround(HEAPF32[$8>>2]);
  $242 = Math_fround($241 + $224);
  $243 = Math_fround(HEAPF32[$9>>2]);
  $244 = Math_fround($243 + $232);
  $245 = Math_fround(HEAPF32[$10>>2]);
  $246 = Math_fround($245 + $240);
  $247 = Math_fround(HEAPF32[$11>>2]);
  $248 = Math_fround($247 + $242);
  HEAPF32[$11>>2] = $248;
  $249 = Math_fround(HEAPF32[$12>>2]);
  $250 = Math_fround($249 + $244);
  HEAPF32[$12>>2] = $250;
  $251 = Math_fround(HEAPF32[$13>>2]);
  $252 = Math_fround($246 + $251);
  HEAPF32[$13>>2] = $252;
  $253 = Math_fround(HEAPF32[$14>>2]);
  $254 = $253 < $242;
  $255 = $254 ? $253 : $242;
  $256 = Math_fround(HEAPF32[$15>>2]);
  $257 = $256 < $244;
  $258 = $257 ? $256 : $244;
  $259 = Math_fround(HEAPF32[$16>>2]);
  $260 = $259 < $246;
  $261 = $260 ? $259 : $246;
  HEAPF32[$14>>2] = $255;
  HEAPF32[$15>>2] = $258;
  HEAPF32[$16>>2] = $261;
  $262 = Math_fround(HEAPF32[$17>>2]);
  $263 = $262 > $242;
  $264 = $263 ? $262 : $242;
  $265 = Math_fround(HEAPF32[$18>>2]);
  $266 = $265 > $244;
  $267 = $266 ? $265 : $244;
  $268 = Math_fround(HEAPF32[$19>>2]);
  $269 = $268 > $246;
  $270 = $269 ? $268 : $246;
  HEAPF32[$17>>2] = $264;
  HEAPF32[$18>>2] = $267;
  HEAPF32[$19>>2] = $270;
  $271 = HEAP32[$4>>2]|0;
  $272 = Math_fround(HEAPF32[$273>>2]);
  $274 = Math_fround(HEAPF32[$271>>2]);
  $275 = Math_fround($272 * $274);
  $276 = (($271) + 4|0);
  $277 = Math_fround(HEAPF32[$276>>2]);
  $278 = Math_fround($272 * $277);
  $279 = (($271) + 8|0);
  $280 = Math_fround(HEAPF32[$279>>2]);
  $281 = Math_fround($272 * $280);
  $282 = (($273) + 4|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = (($271) + 12|0);
  $285 = Math_fround(HEAPF32[$284>>2]);
  $286 = Math_fround($283 * $285);
  $287 = (($271) + 16|0);
  $288 = Math_fround(HEAPF32[$287>>2]);
  $289 = Math_fround($283 * $288);
  $290 = (($271) + 20|0);
  $291 = Math_fround(HEAPF32[$290>>2]);
  $292 = Math_fround($283 * $291);
  $293 = Math_fround($275 + $286);
  $294 = Math_fround($278 + $289);
  $295 = Math_fround($281 + $292);
  $296 = (($273) + 8|0);
  $297 = Math_fround(HEAPF32[$296>>2]);
  $298 = (($271) + 24|0);
  $299 = Math_fround(HEAPF32[$298>>2]);
  $300 = Math_fround($297 * $299);
  $301 = (($271) + 28|0);
  $302 = Math_fround(HEAPF32[$301>>2]);
  $303 = Math_fround($297 * $302);
  $304 = (($271) + 32|0);
  $305 = Math_fround(HEAPF32[$304>>2]);
  $306 = Math_fround($297 * $305);
  $307 = Math_fround($293 + $300);
  $308 = Math_fround($294 + $303);
  $309 = Math_fround($295 + $306);
  $310 = Math_fround($307 * Math_fround(2.0));
  $311 = Math_fround($308 * Math_fround(2.0));
  $312 = Math_fround($309 * Math_fround(2.0));
  $313 = Math_fround(HEAPF32[$5>>2]);
  $314 = Math_fround($313 * $313);
  $315 = Math_fround($314 + Math_fround(-0.5));
  $316 = Math_fround(HEAPF32[$transform>>2]);
  $317 = Math_fround($310 * $316);
  $318 = Math_fround(HEAPF32[$6>>2]);
  $319 = Math_fround($311 * $318);
  $320 = Math_fround($317 + $319);
  $321 = Math_fround(HEAPF32[$7>>2]);
  $322 = Math_fround($312 * $321);
  $323 = Math_fround($320 + $322);
  $324 = Math_fround($310 * $315);
  $325 = Math_fround($312 * $318);
  $326 = Math_fround($311 * $321);
  $327 = Math_fround($325 - $326);
  $328 = Math_fround($313 * $327);
  $329 = Math_fround($324 + $328);
  $330 = Math_fround($316 * $323);
  $331 = Math_fround($330 + $329);
  $332 = Math_fround($311 * $315);
  $333 = Math_fround($310 * $321);
  $334 = Math_fround($316 * $312);
  $335 = Math_fround($333 - $334);
  $336 = Math_fround($313 * $335);
  $337 = Math_fround($332 + $336);
  $338 = Math_fround($318 * $323);
  $339 = Math_fround($338 + $337);
  $340 = Math_fround($312 * $315);
  $341 = Math_fround($311 * $316);
  $342 = Math_fround($310 * $318);
  $343 = Math_fround($341 - $342);
  $344 = Math_fround($313 * $343);
  $345 = Math_fround($340 + $344);
  $346 = Math_fround($321 * $323);
  $347 = Math_fround($345 + $346);
  $348 = Math_fround(HEAPF32[$8>>2]);
  $349 = Math_fround($348 + $331);
  $350 = Math_fround(HEAPF32[$9>>2]);
  $351 = Math_fround($350 + $339);
  $352 = Math_fround(HEAPF32[$10>>2]);
  $353 = Math_fround($352 + $347);
  $354 = Math_fround(HEAPF32[$11>>2]);
  $355 = Math_fround($354 + $349);
  HEAPF32[$11>>2] = $355;
  $356 = Math_fround(HEAPF32[$12>>2]);
  $357 = Math_fround($356 + $351);
  HEAPF32[$12>>2] = $357;
  $358 = Math_fround(HEAPF32[$13>>2]);
  $359 = Math_fround($353 + $358);
  HEAPF32[$13>>2] = $359;
  $360 = Math_fround(HEAPF32[$14>>2]);
  $361 = $360 < $349;
  $362 = $361 ? $360 : $349;
  $363 = Math_fround(HEAPF32[$15>>2]);
  $364 = $363 < $351;
  $365 = $364 ? $363 : $351;
  $366 = Math_fround(HEAPF32[$16>>2]);
  $367 = $366 < $353;
  $368 = $367 ? $366 : $353;
  HEAPF32[$14>>2] = $362;
  HEAPF32[$15>>2] = $365;
  HEAPF32[$16>>2] = $368;
  $369 = Math_fround(HEAPF32[$17>>2]);
  $370 = $369 > $349;
  $371 = $370 ? $369 : $349;
  $372 = Math_fround(HEAPF32[$18>>2]);
  $373 = $372 > $351;
  $374 = $373 ? $372 : $351;
  $375 = Math_fround(HEAPF32[$19>>2]);
  $376 = $375 > $353;
  $377 = $376 ? $375 : $353;
  HEAPF32[$17>>2] = $371;
  HEAPF32[$18>>2] = $374;
  HEAPF32[$19>>2] = $377;
  $378 = (($i$07) + 1)|0;
  $379 = HEAP32[$0>>2]|0;
  $380 = ($378>>>0)<($379>>>0);
  if ($380) {
   $i$07 = $378;
  } else {
   break;
  }
 }
 $phitmp = ($379*3)|0;
 $phitmp14 = (Math_fround(($phitmp>>>0)));
 $$lcssa = $phitmp14;$384 = $355;$387 = $357;$390 = $359;
 $381 = Math_fround(Math_fround(1.0) / $$lcssa);
 $382 = (($this) + 64|0);
 $383 = Math_fround($381 * $384);
 HEAPF32[$382>>2] = $383;
 $385 = (($this) + 68|0);
 $386 = Math_fround($381 * $387);
 HEAPF32[$385>>2] = $386;
 $388 = (($this) + 72|0);
 $389 = Math_fround($381 * $390);
 HEAPF32[$388>>2] = $389;
 $391 = (($this) + 76|0);
 HEAP8[$391>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK5physx18PxcConvexTriangles16getPolygonNormalEj($agg$result,$this,$index) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 156|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 2;
 $10 = ($9<<24>>24)==(0);
 $11 = (($6) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 if ($10) {
  $27 = (($12) + (($3*12)|0)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($6) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + (($28*12)|0)|0);
  $32 = ((($12) + (($3*12)|0)|0) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($30) + (($33*12)|0)|0);
  $35 = ((($12) + (($3*12)|0)|0) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($30) + (($36*12)|0)|0);
  $100 = $37;$41 = $31;$79 = $34;
 } else {
  $13 = (($12) + (($3*6)|0)|0);
  $14 = HEAP16[$13>>1]|0;
  $15 = $14&65535;
  $16 = (($6) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + (($15*12)|0)|0);
  $19 = ((($12) + (($3*6)|0)|0) + 2|0);
  $20 = HEAP16[$19>>1]|0;
  $21 = $20&65535;
  $22 = (($17) + (($21*12)|0)|0);
  $23 = ((($12) + (($3*6)|0)|0) + 4|0);
  $24 = HEAP16[$23>>1]|0;
  $25 = $24&65535;
  $26 = (($17) + (($25*12)|0)|0);
  $100 = $26;$41 = $18;$79 = $22;
 }
 $38 = (($this) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = Math_fround(HEAPF32[$41>>2]);
 $42 = Math_fround(HEAPF32[$39>>2]);
 $43 = Math_fround($40 * $42);
 $44 = (($39) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($40 * $45);
 $47 = (($39) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($40 * $48);
 $50 = (($41) + 4|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($39) + 12|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($51 * $53);
 $55 = (($39) + 16|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($51 * $56);
 $58 = (($39) + 20|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($51 * $59);
 $61 = Math_fround($43 + $54);
 $62 = Math_fround($46 + $57);
 $63 = Math_fround($49 + $60);
 $64 = (($41) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($39) + 24|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($65 * $67);
 $69 = (($39) + 28|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($65 * $70);
 $72 = (($39) + 32|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($65 * $73);
 $75 = Math_fround($61 + $68);
 $76 = Math_fround($62 + $71);
 $77 = Math_fround($63 + $74);
 $78 = Math_fround(HEAPF32[$79>>2]);
 $80 = Math_fround($42 * $78);
 $81 = Math_fround($45 * $78);
 $82 = Math_fround($48 * $78);
 $83 = (($79) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($53 * $84);
 $86 = Math_fround($56 * $84);
 $87 = Math_fround($59 * $84);
 $88 = Math_fround($80 + $85);
 $89 = Math_fround($81 + $86);
 $90 = Math_fround($82 + $87);
 $91 = (($79) + 8|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($67 * $92);
 $94 = Math_fround($70 * $92);
 $95 = Math_fround($73 * $92);
 $96 = Math_fround($88 + $93);
 $97 = Math_fround($89 + $94);
 $98 = Math_fround($90 + $95);
 $99 = Math_fround(HEAPF32[$100>>2]);
 $101 = Math_fround($42 * $99);
 $102 = Math_fround($45 * $99);
 $103 = Math_fround($48 * $99);
 $104 = (($100) + 4|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($53 * $105);
 $107 = Math_fround($56 * $105);
 $108 = Math_fround($59 * $105);
 $109 = Math_fround($101 + $106);
 $110 = Math_fround($102 + $107);
 $111 = Math_fround($103 + $108);
 $112 = (($100) + 8|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($67 * $113);
 $115 = Math_fround($70 * $113);
 $116 = Math_fround($73 * $113);
 $117 = Math_fround($109 + $114);
 $118 = Math_fround($110 + $115);
 $119 = Math_fround($111 + $116);
 $120 = Math_fround($75 - $96);
 $121 = Math_fround($76 - $97);
 $122 = Math_fround($77 - $98);
 $123 = Math_fround($75 - $117);
 $124 = Math_fround($76 - $118);
 $125 = Math_fround($77 - $119);
 $126 = Math_fround($121 * $125);
 $127 = Math_fround($122 * $124);
 $128 = Math_fround($126 - $127);
 $129 = Math_fround($122 * $123);
 $130 = Math_fround($120 * $125);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($120 * $124);
 $133 = Math_fround($121 * $123);
 $134 = Math_fround($132 - $133);
 $135 = Math_fround($128 * $128);
 $136 = Math_fround($131 * $131);
 $137 = Math_fround($135 + $136);
 $138 = Math_fround($134 * $134);
 $139 = Math_fround($138 + $137);
 $140 = $139 > Math_fround(0.0);
 if ($140) {
  $141 = (Math_fround(Math_sqrt((Math_fround($139)))));
  $142 = Math_fround(Math_fround(1.0) / $141);
  $143 = Math_fround($128 * $142);
  $144 = Math_fround($131 * $142);
  $145 = Math_fround($134 * $142);
  HEAPF32[$agg$result>>2] = $143;
  $146 = (($agg$result) + 4|0);
  HEAPF32[$146>>2] = $144;
  $147 = (($agg$result) + 8|0);
  HEAPF32[$147>>2] = $145;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $148 = (($agg$result) + 4|0);
  HEAPF32[$148>>2] = Math_fround(0.0);
  $149 = (($agg$result) + 8|0);
  HEAPF32[$149>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx28PxcSweepEstimateAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_f($shape0,$shape1,$atom0,$atom1,$0,$transform1,$restDistance) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $0 = $0|0;
 $transform1 = $transform1|0;
 $restDistance = Math_fround($restDistance);
 var $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0);
 var $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0);
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $callback = 0, $extent = 0, $hmd = 0, $matRot = 0, $meshScaling = 0, $origin = 0, $relTr = 0, $sweptBox = 0, $trA = 0, $trB = 0, $unitDir = 0, $vertexSpaceBox = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $meshScaling = sp + 288|0;
 $trA = sp + 276|0;
 $trB = sp + 264|0;
 $relTr = sp + 252|0;
 $unitDir = sp + 240|0;
 $matRot = sp + 204|0;
 $sweptBox = sp + 144|0;
 $vertexSpaceBox = sp + 72|0;
 $origin = sp + 60|0;
 $extent = sp + 48|0;
 $callback = sp;
 $hmd = sp + 132|0;
 $1 = HEAP32[$shape1>>2]|0;
 $2 = (($1) + 36|0);
 $3 = (($1) + 40|0);
 $4 = (($1) + 52|0);
 __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$3,$4);
 $5 = (($shape0) + 56|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($shape0) + 28|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($shape0) + 60|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($shape0) + 32|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($shape0) + 64|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($shape0) + 36|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 HEAPF32[$trA>>2] = $9;
 $20 = (($trA) + 4|0);
 HEAPF32[$20>>2] = $14;
 $21 = (($trA) + 8|0);
 HEAPF32[$21>>2] = $19;
 $22 = (($shape1) + 40|0);
 $23 = (($shape1) + 56|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($shape1) + 28|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($24 - $26);
 $28 = (($shape1) + 60|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($shape1) + 32|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($29 - $31);
 $33 = (($shape1) + 64|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($shape1) + 36|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 - $36);
 HEAPF32[$trB>>2] = $27;
 $38 = (($trB) + 4|0);
 HEAPF32[$38>>2] = $32;
 $39 = (($trB) + 8|0);
 HEAPF32[$39>>2] = $37;
 $40 = Math_fround($9 - $27);
 $41 = Math_fround($14 - $32);
 $42 = Math_fround($19 - $37);
 HEAPF32[$relTr>>2] = $40;
 $43 = (($relTr) + 4|0);
 HEAPF32[$43>>2] = $41;
 $44 = (($relTr) + 8|0);
 HEAPF32[$44>>2] = $42;
 HEAPF32[$unitDir>>2] = $40;
 $45 = (($unitDir) + 4|0);
 HEAPF32[$45>>2] = $41;
 $46 = (($unitDir) + 8|0);
 HEAPF32[$46>>2] = $42;
 $47 = Math_fround($40 * $40);
 $48 = Math_fround($41 * $41);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($42 * $42);
 $51 = Math_fround($50 + $49);
 $52 = (Math_fround(Math_sqrt((Math_fround($51)))));
 $53 = $52 > Math_fround(0.0);
 if ($53) {
  $54 = Math_fround(Math_fround(1.0) / $52);
  $55 = Math_fround($40 * $54);
  HEAPF32[$unitDir>>2] = $55;
  $56 = Math_fround($41 * $54);
  HEAPF32[$45>>2] = $56;
  $57 = Math_fround($42 * $54);
  HEAPF32[$46>>2] = $57;
 }
 $58 = (($shape0) + 12|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($shape0) + 16|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($shape0) + 20|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($shape0) + 24|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($59 + $59);
 $67 = Math_fround($61 + $61);
 $68 = Math_fround($63 + $63);
 $69 = Math_fround($59 * $66);
 $70 = Math_fround($61 * $67);
 $71 = Math_fround($63 * $68);
 $72 = Math_fround($66 * $61);
 $73 = Math_fround($66 * $63);
 $74 = Math_fround($66 * $65);
 $75 = Math_fround($67 * $63);
 $76 = Math_fround($67 * $65);
 $77 = Math_fround($68 * $65);
 $78 = Math_fround(Math_fround(1.0) - $70);
 $79 = Math_fround($78 - $71);
 $80 = Math_fround($72 + $77);
 $81 = Math_fround($73 - $76);
 HEAPF32[$matRot>>2] = $79;
 $82 = (($matRot) + 4|0);
 HEAPF32[$82>>2] = $80;
 $83 = (($matRot) + 8|0);
 HEAPF32[$83>>2] = $81;
 $84 = Math_fround($72 - $77);
 $85 = Math_fround(Math_fround(1.0) - $69);
 $86 = Math_fround($85 - $71);
 $87 = Math_fround($75 + $74);
 $88 = (($matRot) + 12|0);
 HEAPF32[$88>>2] = $84;
 $89 = (($matRot) + 16|0);
 HEAPF32[$89>>2] = $86;
 $90 = (($matRot) + 20|0);
 HEAPF32[$90>>2] = $87;
 $91 = Math_fround($73 + $76);
 $92 = Math_fround($75 - $74);
 $93 = Math_fround($85 - $70);
 $94 = (($matRot) + 24|0);
 HEAPF32[$94>>2] = $91;
 $95 = (($matRot) + 28|0);
 HEAPF32[$95>>2] = $92;
 $96 = (($matRot) + 32|0);
 HEAPF32[$96>>2] = $93;
 $97 = (($shape0) + 68|0);
 $98 = (($shape0) + 80|0);
 __ZN5physx2Gu15computeSweptBoxERNS0_3BoxERKNS_6PxVec3ES5_RKNS_7PxMat33ES5_f($sweptBox,$97,$98,$matRot,$unitDir,$52);
 __ZN5physx2Gu21computeVertexSpaceOBBERNS0_3BoxERKS1_RKNS_11PxTransformERKNS_11PxMeshScaleE($vertexSpaceBox,$sweptBox,$22,$3);
 $99 = (($vertexSpaceBox) + 48|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 + $restDistance);
 HEAPF32[$99>>2] = $101;
 $102 = (($vertexSpaceBox) + 52|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($103 + $restDistance);
 HEAPF32[$102>>2] = $104;
 $105 = (($vertexSpaceBox) + 56|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($106 + $restDistance);
 HEAPF32[$105>>2] = $107;
 $108 = Math_fround(HEAPF32[$98>>2]);
 HEAPF32[$origin>>2] = $108;
 $109 = (($origin) + 4|0);
 $110 = (($shape0) + 84|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 HEAPF32[$109>>2] = $111;
 $112 = (($origin) + 8|0);
 $113 = (($shape0) + 88|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 HEAPF32[$112>>2] = $114;
 $115 = Math_fround(HEAPF32[$97>>2]);
 $116 = Math_fround($115 + $restDistance);
 $117 = (($shape0) + 72|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = Math_fround($118 + $restDistance);
 $120 = (($shape0) + 76|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround($121 + $restDistance);
 HEAPF32[$extent>>2] = $116;
 $123 = (($extent) + 4|0);
 HEAPF32[$123>>2] = $119;
 $124 = (($extent) + 8|0);
 HEAPF32[$124>>2] = $122;
 $125 = ($atom0|0)!=(0|0);
 if ($125) {
  $126 = (($shape0) + 8|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $132 = $127;
 } else {
  $132 = Math_fround(0.0);
 }
 $128 = ($atom1|0)!=(0|0);
 if ($128) {
  $129 = (($shape1) + 8|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $133 = $130;
 } else {
  $133 = Math_fround(0.0);
 }
 $131 = $132 > $133;
 $134 = $131 ? $132 : $133;
 if ($125) {
  $135 = (($atom0) + 60|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = (($136) + 4|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $144 = $138;
 } else {
  $144 = Math_fround(1.0);
 }
 if (!($128)) {
  $145 = Math_fround(1.0);
  $143 = $144 < $145;
  $146 = $143 ? $144 : $145;
  $147 = Math_fround($134 * $146);
  $148 = (($callback) + 4|0);
  HEAP32[$148>>2] = 2;
  HEAP32[$callback>>2] = ((503296 + 8|0));
  $149 = (($callback) + 12|0);
  HEAPF32[$149>>2] = $147;
  $150 = (($callback) + 16|0);
  HEAP32[$150>>2] = $2;
  $151 = (($callback) + 20|0);
  HEAP32[$151>>2] = $meshScaling;
  $152 = (($callback) + 24|0);
  HEAP32[$152>>2] = $relTr;
  $153 = (($callback) + 28|0);
  HEAP32[$153>>2] = $trA;
  $154 = (($callback) + 32|0);
  HEAP32[$154>>2] = $trB;
  $155 = (($callback) + 36|0);
  HEAP32[$155>>2] = $transform1;
  $156 = (($callback) + 40|0);
  HEAP32[$156>>2] = $origin;
  $157 = (($callback) + 44|0);
  HEAP32[$157>>2] = $extent;
  $158 = (($callback) + 8|0);
  HEAPF32[$158>>2] = Math_fround(3.40282346638528859812E+38);
  $159 = (($1) + 76|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = (($160) + 16|0);
  $162 = HEAP32[$161>>2]|0;
  HEAP32[$hmd>>2] = $162;
  $163 = (($160) + 32|0);
  $164 = (($hmd) + 4|0);
  HEAP32[$164>>2] = $163;
  $165 = (($160) + 20|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($hmd) + 8|0);
  HEAPF32[$167>>2] = $166;
  __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($vertexSpaceBox,1,$hmd,$callback,1);
  $168 = Math_fround(HEAPF32[$158>>2]);
  STACKTOP = sp;return (Math_fround($168));
 }
 $139 = (($atom1) + 60|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = (($140) + 4|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $145 = $142;
 $143 = $144 < $145;
 $146 = $143 ? $144 : $145;
 $147 = Math_fround($134 * $146);
 $148 = (($callback) + 4|0);
 HEAP32[$148>>2] = 2;
 HEAP32[$callback>>2] = ((503296 + 8|0));
 $149 = (($callback) + 12|0);
 HEAPF32[$149>>2] = $147;
 $150 = (($callback) + 16|0);
 HEAP32[$150>>2] = $2;
 $151 = (($callback) + 20|0);
 HEAP32[$151>>2] = $meshScaling;
 $152 = (($callback) + 24|0);
 HEAP32[$152>>2] = $relTr;
 $153 = (($callback) + 28|0);
 HEAP32[$153>>2] = $trA;
 $154 = (($callback) + 32|0);
 HEAP32[$154>>2] = $trB;
 $155 = (($callback) + 36|0);
 HEAP32[$155>>2] = $transform1;
 $156 = (($callback) + 40|0);
 HEAP32[$156>>2] = $origin;
 $157 = (($callback) + 44|0);
 HEAP32[$157>>2] = $extent;
 $158 = (($callback) + 8|0);
 HEAPF32[$158>>2] = Math_fround(3.40282346638528859812E+38);
 $159 = (($1) + 76|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = (($160) + 16|0);
 $162 = HEAP32[$161>>2]|0;
 HEAP32[$hmd>>2] = $162;
 $163 = (($160) + 32|0);
 $164 = (($hmd) + 4|0);
 HEAP32[$164>>2] = $163;
 $165 = (($160) + 20|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = (($hmd) + 8|0);
 HEAPF32[$167>>2] = $166;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($vertexSpaceBox,1,$hmd,$callback,1);
 $168 = Math_fround(HEAPF32[$158>>2]);
 STACKTOP = sp;return (Math_fround($168));
}
function __ZN5physx35PxcSweepEstimateAnyShapeHeightfieldERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_f($shape0,$shape1,$atom0,$atom1,$0,$transform1,$restDistance) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $0 = $0|0;
 $transform1 = $transform1|0;
 $restDistance = Math_fround($restDistance);
 var $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0;
 var $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0);
 var $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0);
 var $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0;
 var $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0;
 var $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0);
 var $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $a$031 = 0, $bounds0 = 0, $callback = 0;
 var $exitcond = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $hfUtil = 0, $minTOI$0$lcssa = Math_fround(0), $minTOI$032 = Math_fround(0), $minTOI$1 = Math_fround(0), $origin = 0, $tempContainer = 0, $trA = 0, $trB = 0, $tri = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $hfUtil = sp + 416|0;
 $tempContainer = sp + 400|0;
 $callback = sp + 392|0;
 $trA = sp + 380|0;
 $trB = sp + 368|0;
 $bounds0 = sp + 344|0;
 $origin = sp + 328|0;
 $tri = sp + 36|0;
 $1 = sp + 24|0;
 $2 = sp + 12|0;
 $3 = sp;
 $4 = HEAP32[$shape1>>2]|0;
 $5 = (($4) + 36|0);
 $6 = (($hfUtil) + 12|0);
 $7 = (($4) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = (($hfUtil) + 16|0);
 HEAP32[$9>>2] = $5;
 $10 = (($4) + 44|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(Math_fround(1.0) / $11);
 $13 = (($hfUtil) + 4|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($4) + 48|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(Math_fround(1.0) / $15);
 HEAPF32[$hfUtil>>2] = $16;
 $17 = (($4) + 52|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(Math_fround(1.0) / $18);
 $20 = (($hfUtil) + 8|0);
 HEAPF32[$20>>2] = $19;
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $21 = sp + 72|0;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,64,$21,1);
 HEAP32[$callback>>2] = ((503272 + 8|0));
 $22 = (($callback) + 4|0);
 HEAP32[$22>>2] = $tempContainer;
 $23 = (($tempContainer) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 if (!($25)) {
  HEAP32[$23>>2] = 0;
 }
 $26 = (($shape0) + 56|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($shape0) + 28|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($27 - $29);
 $31 = (($shape0) + 60|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($shape0) + 32|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($32 - $34);
 $36 = (($shape0) + 64|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($shape0) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($37 - $39);
 HEAPF32[$trA>>2] = $30;
 $41 = (($trA) + 4|0);
 HEAPF32[$41>>2] = $35;
 $42 = (($trA) + 8|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($shape1) + 12|0);
 $44 = (($shape1) + 56|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($shape1) + 28|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 - $47);
 $49 = (($shape1) + 60|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($shape1) + 32|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($50 - $52);
 $54 = (($shape1) + 64|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($shape1) + 36|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($55 - $57);
 HEAPF32[$trB>>2] = $48;
 $59 = (($trB) + 4|0);
 HEAPF32[$59>>2] = $53;
 $60 = (($trB) + 8|0);
 HEAPF32[$60>>2] = $58;
 $61 = Math_fround($30 - $48);
 $62 = Math_fround($35 - $53);
 $63 = Math_fround($40 - $58);
 $64 = Math_fround($61 * Math_fround(0.5));
 $65 = Math_fround($62 * Math_fround(0.5));
 $66 = Math_fround($63 * Math_fround(0.5));
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($64)))));
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($65)))));
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($66)))));
 $67 = (($shape0) + 68|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($fabsf$i$i$i + $68);
 $70 = (($shape0) + 72|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($fabsf$i$i1$i + $71);
 $73 = (($shape0) + 76|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($fabsf$i$i2$i + $74);
 $76 = Math_fround($69 + $restDistance);
 $77 = Math_fround($72 + $restDistance);
 $78 = Math_fround($75 + $restDistance);
 $79 = (($shape0) + 80|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($64 + $80);
 $82 = (($shape0) + 84|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($65 + $83);
 $85 = (($shape0) + 88|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($66 + $86);
 $88 = Math_fround($81 - $76);
 $89 = Math_fround($84 - $77);
 $90 = Math_fround($87 - $78);
 $91 = Math_fround($76 + $81);
 $92 = Math_fround($77 + $84);
 $93 = Math_fround($78 + $87);
 HEAPF32[$bounds0>>2] = $88;
 $94 = (($bounds0) + 4|0);
 HEAPF32[$94>>2] = $89;
 $95 = (($bounds0) + 8|0);
 HEAPF32[$95>>2] = $90;
 $96 = (($bounds0) + 12|0);
 HEAPF32[$96>>2] = $91;
 $97 = (($bounds0) + 16|0);
 HEAPF32[$97>>2] = $92;
 $98 = (($bounds0) + 20|0);
 HEAPF32[$98>>2] = $93;
 (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$transform1,$bounds0,1,$callback)|0);
 $99 = Math_fround(HEAPF32[$79>>2]);
 HEAPF32[$origin>>2] = $99;
 $100 = (($origin) + 4|0);
 $101 = Math_fround(HEAPF32[$82>>2]);
 HEAPF32[$100>>2] = $101;
 $102 = (($origin) + 8|0);
 $103 = Math_fround(HEAPF32[$85>>2]);
 HEAPF32[$102>>2] = $103;
 $104 = Math_fround(HEAPF32[$67>>2]);
 $105 = Math_fround(HEAPF32[$70>>2]);
 $106 = Math_fround(HEAPF32[$73>>2]);
 $107 = ($atom0|0)!=(0|0);
 if ($107) {
  $108 = (($shape0) + 8|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $114 = $109;
 } else {
  $114 = Math_fround(0.0);
 }
 $110 = ($atom1|0)!=(0|0);
 if ($110) {
  $111 = (($shape1) + 8|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $115 = $112;
 } else {
  $115 = Math_fround(0.0);
 }
 $113 = $114 > $115;
 $116 = $113 ? $114 : $115;
 if ($107) {
  $117 = (($atom0) + 60|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($118) + 4|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $126 = $120;
 } else {
  $126 = Math_fround(1.0);
 }
 if ($110) {
  $121 = (($atom1) + 60|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = (($122) + 4|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $127 = $124;
 } else {
  $127 = Math_fround(1.0);
 }
 $125 = $126 < $127;
 $128 = $125 ? $126 : $127;
 $129 = Math_fround($116 * $128);
 $130 = HEAP32[$23>>2]|0;
 $131 = (($tempContainer) + 8|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($130|0)==(0);
 if ($133) {
  $minTOI$0$lcssa = Math_fround(3.40282346638528859812E+38);
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return (Math_fround($minTOI$0$lcssa));
 }
 $134 = (($tri) + 12|0);
 $135 = (($tri) + 16|0);
 $136 = (($tri) + 4|0);
 $137 = (($tri) + 20|0);
 $138 = (($tri) + 8|0);
 $139 = (($tri) + 24|0);
 $140 = (($tri) + 28|0);
 $141 = (($tri) + 32|0);
 $142 = Math_fround($104 * Math_fround(1.10000002384185791016));
 $143 = Math_fround($105 * Math_fround(1.10000002384185791016));
 $144 = Math_fround($106 * Math_fround(1.10000002384185791016));
 $145 = (($1) + 4|0);
 $146 = (($1) + 8|0);
 $147 = (($2) + 4|0);
 $148 = (($2) + 8|0);
 $149 = (($3) + 4|0);
 $150 = (($3) + 8|0);
 $a$031 = 0;$minTOI$032 = Math_fround(3.40282346638528859812E+38);
 while(1) {
  $151 = (($132) + ($a$031<<2)|0);
  $152 = HEAP32[$151>>2]|0;
  (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($hfUtil,$43,$tri,0,0,$152,1,1)|0);
  $153 = Math_fround(HEAPF32[$134>>2]);
  $154 = Math_fround(HEAPF32[$tri>>2]);
  $155 = Math_fround($153 - $154);
  $156 = Math_fround(HEAPF32[$135>>2]);
  $157 = Math_fround(HEAPF32[$136>>2]);
  $158 = Math_fround($156 - $157);
  $159 = Math_fround(HEAPF32[$137>>2]);
  $160 = Math_fround(HEAPF32[$138>>2]);
  $161 = Math_fround($159 - $160);
  $162 = Math_fround(HEAPF32[$139>>2]);
  $163 = Math_fround($162 - $154);
  $164 = Math_fround(HEAPF32[$140>>2]);
  $165 = Math_fround($164 - $157);
  $166 = Math_fround(HEAPF32[$141>>2]);
  $167 = Math_fround($166 - $160);
  $168 = Math_fround($158 * $167);
  $169 = Math_fround($161 * $165);
  $170 = Math_fround($168 - $169);
  $171 = Math_fround($161 * $163);
  $172 = Math_fround($155 * $167);
  $173 = Math_fround($171 - $172);
  $174 = Math_fround($155 * $165);
  $175 = Math_fround($158 * $163);
  $176 = Math_fround($174 - $175);
  $177 = Math_fround(-$170);
  $178 = Math_fround(-$173);
  $179 = Math_fround(-$176);
  $180 = Math_fround($170 * $170);
  $181 = Math_fround($173 * $173);
  $182 = Math_fround($180 + $181);
  $183 = Math_fround($176 * $176);
  $184 = Math_fround($183 + $182);
  $185 = (Math_fround(Math_sqrt((Math_fround($184)))));
  $186 = $185 > Math_fround(0.0);
  if ($186) {
   $187 = Math_fround(Math_fround(1.0) / $185);
   $188 = Math_fround($187 * $177);
   $189 = Math_fround($187 * $178);
   $190 = Math_fround($187 * $179);
   $192 = $188;$194 = $189;$197 = $190;
  } else {
   $192 = $177;$194 = $178;$197 = $179;
  }
  $191 = Math_fround($61 * $192);
  $193 = Math_fround($62 * $194);
  $195 = Math_fround($193 + $191);
  $196 = Math_fround($63 * $197);
  $198 = Math_fround($196 + $195);
  $199 = !($198 >= $129);
  if ($199) {
   $minTOI$1 = $minTOI$032;
  } else {
   $200 = $154 > Math_fround(8.50705866596322149529E+37);
   $201 = $200 ? Math_fround(8.50705866596322149529E+37) : $154;
   $202 = $157 > Math_fround(8.50705866596322149529E+37);
   $203 = $202 ? Math_fround(8.50705866596322149529E+37) : $157;
   $204 = $160 > Math_fround(8.50705866596322149529E+37);
   $205 = $204 ? Math_fround(8.50705866596322149529E+37) : $160;
   $206 = $154 < Math_fround(-8.50705866596322149529E+37);
   $207 = $206 ? Math_fround(-8.50705866596322149529E+37) : $154;
   $208 = $157 < Math_fround(-8.50705866596322149529E+37);
   $209 = $208 ? Math_fround(-8.50705866596322149529E+37) : $157;
   $210 = $160 < Math_fround(-8.50705866596322149529E+37);
   $211 = $210 ? Math_fround(-8.50705866596322149529E+37) : $160;
   $212 = $201 < $153;
   $213 = $212 ? $201 : $153;
   $214 = $203 < $156;
   $215 = $214 ? $203 : $156;
   $216 = $205 < $159;
   $217 = $216 ? $205 : $159;
   $218 = $207 > $153;
   $219 = $218 ? $207 : $153;
   $220 = $209 > $156;
   $221 = $220 ? $209 : $156;
   $222 = $211 > $159;
   $223 = $222 ? $211 : $159;
   $224 = $213 < $162;
   $225 = $224 ? $213 : $162;
   $226 = $215 < $164;
   $227 = $226 ? $215 : $164;
   $228 = $217 < $166;
   $229 = $228 ? $217 : $166;
   $230 = $219 > $162;
   $231 = $230 ? $219 : $162;
   $232 = $221 > $164;
   $233 = $232 ? $221 : $164;
   $234 = $223 > $166;
   $235 = $234 ? $223 : $166;
   HEAPF32[$1>>2] = $142;
   HEAPF32[$145>>2] = $143;
   HEAPF32[$146>>2] = $144;
   $236 = Math_fround($225 + $231);
   $237 = Math_fround($227 + $233);
   $238 = Math_fround($229 + $235);
   $239 = Math_fround($236 * Math_fround(0.5));
   $240 = Math_fround($237 * Math_fround(0.5));
   $241 = Math_fround($238 * Math_fround(0.5));
   HEAPF32[$2>>2] = $239;
   HEAPF32[$147>>2] = $240;
   HEAPF32[$148>>2] = $241;
   $242 = Math_fround($231 - $225);
   $243 = Math_fround($233 - $227);
   $244 = Math_fround($235 - $229);
   $245 = Math_fround($242 * Math_fround(0.5));
   $246 = Math_fround($243 * Math_fround(0.5));
   $247 = Math_fround($244 * Math_fround(0.5));
   $248 = Math_fround($245 + Math_fround(0.00999999977648258209228));
   $249 = Math_fround($246 + Math_fround(0.00999999977648258209228));
   $250 = Math_fround($247 + Math_fround(0.00999999977648258209228));
   $251 = Math_fround($248 * Math_fround(1.10000002384185791016));
   $252 = Math_fround($249 * Math_fround(1.10000002384185791016));
   $253 = Math_fround($250 * Math_fround(1.10000002384185791016));
   HEAPF32[$3>>2] = $251;
   HEAPF32[$149>>2] = $252;
   HEAPF32[$150>>2] = $253;
   $254 = (Math_fround(__Z13sweepAABBAABBRKN5physx6PxVec3ES2_S2_S2_S2_S2_($origin,$1,$2,$3,$trA,$trB)));
   $255 = $minTOI$032 < $254;
   $256 = $255 ? $minTOI$032 : $254;
   $minTOI$1 = $256;
  }
  $257 = (($a$031) + 1)|0;
  $exitcond = ($257|0)==($130|0);
  if ($exitcond) {
   $minTOI$0$lcssa = $minTOI$1;
   break;
  } else {
   $a$031 = $257;$minTOI$032 = $minTOI$1;
  }
 }
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return (Math_fround($minTOI$0$lcssa));
}
function __ZN5physx29EntityReportContainerCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx20PxcSweepSphereSphereERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$0 = Math_fround(0), $$sroa$144 = 0, $$sroa$146 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0;
 var $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0;
 var $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0);
 var $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $capTrans1 = 0, $capsule0 = 0;
 var $capsule1 = 0, $closestA = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trA = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 432|0;
 $zero$sroa$1$i$i$i = sp + 496|0;
 $zeroV = sp + 272|0;
 $capsule0 = sp + 288|0;
 $$sroa$146 = sp + 508|0;
 $capsule1 = sp + 128|0;
 $$sroa$144 = sp + 520|0;
 $capTrans1 = sp + 96|0;
 $toi = sp + 64|0;
 $trA = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 80|0;
 $1 = HEAP32[$shape0>>2]|0;
 $2 = HEAP32[$shape1>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $3 = (($1) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($capsule0) + 64|0);
 $6 = (($capsule0) + 80|0);
 HEAP32[$6>>2] = 4;
 $7 = (($capsule0) + 16|0);
 $8 = (($capsule0) + 20|0);
 $9 = (($capsule0) + 32|0);
 $10 = (($capsule0) + 36|0);
 $11 = (($capsule0) + 48|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($capsule0) + 52|0);
 ;HEAP32[$12+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $13 = (($capsule0) + 96|0);
 $14 = (($capsule0) + 112|0);
 ;HEAP32[$capsule0+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule0+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule0+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule0+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $15 = (($capsule0) + 128|0);
 HEAPF32[$15>>2] = $4;
 $16 = (($capsule0) + 132|0);
 ;HEAP32[$16+0>>2]=HEAP32[$$sroa$146+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$$sroa$146+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$$sroa$146+8>>2]|0;
 ;HEAP32[$13+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$14+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$7>>2] = $4;
 ;HEAP32[$8+0>>2]=HEAP32[$$sroa$146+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$$sroa$146+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$$sroa$146+8>>2]|0;
 HEAPF32[$9>>2] = $4;
 ;HEAP32[$10+0>>2]=HEAP32[$$sroa$146+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$$sroa$146+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$$sroa$146+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$5+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$0+12>>2]|0;
 $17 = (($2) + 40|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($capsule1) + 64|0);
 $20 = (($capsule1) + 80|0);
 HEAP32[$20>>2] = 4;
 $21 = (($capsule1) + 16|0);
 $22 = (($capsule1) + 20|0);
 $23 = (($capsule1) + 32|0);
 $24 = (($capsule1) + 36|0);
 $25 = (($capsule1) + 48|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($capsule1) + 52|0);
 ;HEAP32[$26+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $27 = (($capsule1) + 96|0);
 $28 = (($capsule1) + 112|0);
 ;HEAP32[$capsule1+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule1+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule1+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule1+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $29 = (($capsule1) + 128|0);
 HEAPF32[$29>>2] = $18;
 $30 = (($capsule1) + 132|0);
 ;HEAP32[$30+0>>2]=HEAP32[$$sroa$144+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$$sroa$144+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$$sroa$144+8>>2]|0;
 ;HEAP32[$27+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$28+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$21>>2] = $18;
 ;HEAP32[$22+0>>2]=HEAP32[$$sroa$144+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$$sroa$144+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$$sroa$144+8>>2]|0;
 HEAPF32[$23>>2] = $18;
 ;HEAP32[$24+0>>2]=HEAP32[$$sroa$144+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$$sroa$144+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$$sroa$144+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$19+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$0+12>>2]|0;
 $31 = Math_fround(HEAPF32[$transform0>>2]);
 $32 = (($transform0) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($transform0) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($transform0) + 12|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($lastTm0) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($38) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($38) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(HEAPF32[$transform1>>2]);
 $45 = (($transform1) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($transform1) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($transform1) + 12|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($lastTm1) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($51) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($51) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 HEAPF32[$capTrans1>>2] = $44;
 $57 = (($capTrans1) + 4|0);
 HEAPF32[$57>>2] = $46;
 $58 = (($capTrans1) + 8|0);
 HEAPF32[$58>>2] = $48;
 $59 = (($capTrans1) + 12|0);
 HEAPF32[$59>>2] = $50;
 $60 = (($capTrans1) + 16|0);
 HEAPF32[$60>>2] = $52;
 $61 = (($capTrans1) + 20|0);
 HEAPF32[$61>>2] = $54;
 $62 = (($capTrans1) + 24|0);
 HEAPF32[$62>>2] = $56;
 $63 = (($capTrans1) + 28|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = Math_fround(-$44);
 $65 = Math_fround(-$46);
 $66 = Math_fround(-$48);
 $67 = Math_fround($39 - $52);
 $68 = Math_fround($41 - $54);
 $69 = Math_fround($43 - $56);
 $70 = Math_fround($50 * $50);
 $71 = Math_fround($70 + Math_fround(-0.5));
 $72 = Math_fround($71 * $67);
 $73 = Math_fround($71 * $68);
 $74 = Math_fround($71 * $69);
 $75 = Math_fround($69 * $65);
 $76 = Math_fround($68 * $66);
 $77 = Math_fround($75 - $76);
 $78 = Math_fround($67 * $66);
 $79 = Math_fround($69 * $64);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($68 * $64);
 $82 = Math_fround($67 * $65);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($50 * $77);
 $85 = Math_fround($50 * $80);
 $86 = Math_fround($50 * $83);
 $87 = Math_fround($72 + $84);
 $88 = Math_fround($73 + $85);
 $89 = Math_fround($74 + $86);
 $90 = Math_fround($67 * $64);
 $91 = Math_fround($68 * $65);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($69 * $66);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($94 * $64);
 $96 = Math_fround($94 * $65);
 $97 = Math_fround($94 * $66);
 $98 = Math_fround($95 + $87);
 $99 = Math_fround($96 + $88);
 $100 = Math_fround($89 + $97);
 $101 = Math_fround($98 * Math_fround(2.0));
 $102 = Math_fround($99 * Math_fround(2.0));
 $103 = Math_fround($100 * Math_fround(2.0));
 $104 = Math_fround($37 * $50);
 $105 = Math_fround($31 * $64);
 $106 = Math_fround($33 * $65);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($35 * $66);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($104 - $109);
 $111 = Math_fround($37 * $64);
 $112 = Math_fround($37 * $65);
 $113 = Math_fround($37 * $66);
 $114 = Math_fround($31 * $50);
 $115 = Math_fround($33 * $50);
 $116 = Math_fround($35 * $50);
 $117 = Math_fround($35 * $65);
 $118 = Math_fround($33 * $66);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($31 * $66);
 $121 = Math_fround($35 * $64);
 $122 = Math_fround($120 - $121);
 $123 = Math_fround($33 * $64);
 $124 = Math_fround($31 * $65);
 $125 = Math_fround($123 - $124);
 $126 = Math_fround($111 + $114);
 $127 = Math_fround($112 + $115);
 $128 = Math_fround($116 + $113);
 $129 = Math_fround($119 + $126);
 $130 = Math_fround($122 + $127);
 $131 = Math_fround($125 + $128);
 $132 = (($0) + 48|0);
 HEAPF32[$132>>2] = $101;
 $133 = (($0) + 52|0);
 HEAPF32[$133>>2] = $102;
 $134 = (($0) + 56|0);
 HEAPF32[$134>>2] = $103;
 $135 = (($0) + 60|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = Math_fround($129 + $129);
 $137 = Math_fround($130 + $130);
 $138 = Math_fround($131 + $131);
 $139 = Math_fround($129 * $136);
 $140 = Math_fround($130 * $137);
 $141 = Math_fround($131 * $138);
 $142 = Math_fround($130 * $136);
 $143 = Math_fround($131 * $136);
 $144 = Math_fround($110 * $136);
 $145 = Math_fround($131 * $137);
 $146 = Math_fround($110 * $137);
 $147 = Math_fround($110 * $138);
 $148 = Math_fround(Math_fround(1.0) - $139);
 $149 = Math_fround(Math_fround(1.0) - $140);
 $150 = Math_fround($149 - $141);
 $151 = Math_fround($142 + $147);
 $152 = Math_fround($143 - $146);
 $153 = Math_fround($142 - $147);
 $154 = Math_fround($148 - $141);
 $155 = Math_fround($145 + $144);
 $156 = Math_fround($143 + $146);
 $157 = Math_fround($145 - $144);
 $158 = Math_fround($148 - $140);
 HEAPF32[$0>>2] = $150;
 $159 = (($0) + 4|0);
 HEAPF32[$159>>2] = $151;
 $160 = (($0) + 8|0);
 HEAPF32[$160>>2] = $152;
 $161 = (($0) + 12|0);
 HEAPF32[$161>>2] = Math_fround(0.0);
 $162 = (($0) + 16|0);
 HEAPF32[$162>>2] = $153;
 $163 = (($0) + 20|0);
 HEAPF32[$163>>2] = $154;
 $164 = (($0) + 24|0);
 HEAPF32[$164>>2] = $155;
 $165 = (($0) + 28|0);
 HEAPF32[$165>>2] = Math_fround(0.0);
 $166 = (($0) + 32|0);
 HEAPF32[$166>>2] = $156;
 $167 = (($0) + 36|0);
 HEAPF32[$167>>2] = $157;
 $168 = (($0) + 40|0);
 HEAPF32[$168>>2] = $158;
 $169 = (($0) + 44|0);
 HEAPF32[$169>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $170 = (($transform0) + 16|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($transform0) + 20|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = (($transform0) + 24|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = (($transform1) + 16|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = (($transform1) + 20|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = (($transform1) + 24|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = Math_fround($171 - $39);
 $183 = Math_fround($173 - $41);
 $184 = Math_fround($175 - $43);
 HEAPF32[$trA>>2] = $182;
 $185 = (($trA) + 4|0);
 HEAPF32[$185>>2] = $183;
 $186 = (($trA) + 8|0);
 HEAPF32[$186>>2] = $184;
 $187 = (($trA) + 12|0);
 HEAPF32[$187>>2] = Math_fround(0.0);
 $188 = Math_fround($177 - $52);
 $189 = Math_fround($179 - $54);
 $190 = Math_fround($181 - $56);
 $191 = Math_fround($188 - $182);
 $192 = Math_fround($189 - $183);
 $193 = Math_fround($190 - $184);
 $194 = Math_fround(HEAPF32[$capTrans1>>2]);
 $195 = Math_fround(HEAPF32[$57>>2]);
 $196 = Math_fround(HEAPF32[$58>>2]);
 $197 = Math_fround(HEAPF32[$59>>2]);
 $198 = Math_fround($197 * $197);
 $199 = Math_fround($198 + Math_fround(-0.5));
 $200 = Math_fround($191 * $199);
 $201 = Math_fround($192 * $199);
 $202 = Math_fround($193 * $199);
 $203 = Math_fround($193 * $195);
 $204 = Math_fround($192 * $196);
 $205 = Math_fround($203 - $204);
 $206 = Math_fround($191 * $196);
 $207 = Math_fround($194 * $193);
 $208 = Math_fround($206 - $207);
 $209 = Math_fround($192 * $194);
 $210 = Math_fround($191 * $195);
 $211 = Math_fround($209 - $210);
 $212 = Math_fround($197 * $205);
 $213 = Math_fround($197 * $208);
 $214 = Math_fround($197 * $211);
 $215 = Math_fround($200 - $212);
 $216 = Math_fround($201 - $213);
 $217 = Math_fround($202 - $214);
 $218 = Math_fround($191 * $194);
 $219 = Math_fround($192 * $195);
 $220 = Math_fround($218 + $219);
 $221 = Math_fround($193 * $196);
 $222 = Math_fround($220 + $221);
 $223 = Math_fround($194 * $222);
 $224 = Math_fround($195 * $222);
 $225 = Math_fround($196 * $222);
 $226 = Math_fround($223 + $215);
 $227 = Math_fround($224 + $216);
 $228 = Math_fround($225 + $217);
 $229 = Math_fround($226 * Math_fround(2.0));
 $230 = Math_fround($227 * Math_fround(2.0));
 $231 = Math_fround($228 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $229;
 $232 = (($relTr) + 4|0);
 HEAPF32[$232>>2] = $230;
 $233 = (($relTr) + 8|0);
 HEAPF32[$233>>2] = $231;
 $234 = (($relTr) + 12|0);
 HEAPF32[$234>>2] = Math_fround(0.0);
 $235 = Math_fround(HEAPF32[$3>>2]);
 $236 = Math_fround(HEAPF32[$17>>2]);
 $237 = Math_fround($235 + $236);
 $238 = Math_fround($237 + $restDistance);
 $239 = (__ZN5physx8CCDSweepINS_2Gu8CapsuleVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVERKNS8_5Vec3VERKNS8_6FloatVESH_SH_RSI_RSF_SM_f($capsule0,$capsule1,$0,$capTrans1,$trA,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$238)|0);
 if (!($239)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $240 = Math_fround(HEAPF32[$lambda>>2]);
 $241 = Math_fround(HEAPF32[$normal>>2]);
 $242 = (($normal) + 4|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($normal) + 8|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 HEAPF32[$worldNormal>>2] = $241;
 $246 = (($worldNormal) + 4|0);
 HEAPF32[$246>>2] = $243;
 $247 = (($worldNormal) + 8|0);
 HEAPF32[$247>>2] = $245;
 $248 = Math_fround(HEAPF32[$closestA>>2]);
 $249 = (($closestA) + 4|0);
 $250 = Math_fround(HEAPF32[$249>>2]);
 $251 = (($closestA) + 8|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 HEAPF32[$worldPoint>>2] = $248;
 $253 = (($worldPoint) + 4|0);
 HEAPF32[$253>>2] = $250;
 $254 = (($worldPoint) + 8|0);
 HEAPF32[$254>>2] = $252;
 $$0 = $240;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx8CCDSweepINS_2Gu8CapsuleVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVERKNS8_5Vec3VERKNS8_6FloatVESH_SH_RSI_RSF_SM_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_8CapsuleVES2_RKNS_6shdfnd3aos15PsMatTransformVERKNS4_6FloatVERKNS4_5Vec3VESD_RS8_RSB_SF_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17PxcSweepSphereBoxERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = Math_fround(0), $$sroa$1$i$i$i = 0, $$sroa$132 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0);
 var $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0);
 var $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0);
 var $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0);
 var $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $box = 0, $boxTrans = 0, $capsule = 0, $closestA = 0;
 var $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trA = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 528|0;
 $$sroa$1$i$i$i = sp + 512|0;
 $zeroV = sp + 496|0;
 $boxTrans = sp + 464|0;
 $aToB = sp + 400|0;
 $capsule = sp + 256|0;
 $$sroa$132 = sp + 544|0;
 $box = sp + 96|0;
 $toi = sp + 64|0;
 $trA = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 80|0;
 $1 = HEAP32[$shape0>>2]|0;
 $2 = HEAP32[$shape1>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $3 = (($2) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($2) + 44|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($2) + 48|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$transform0>>2]);
 $10 = (($transform0) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($transform0) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($lastTm0) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($16) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($16) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(HEAPF32[$transform1>>2]);
 $23 = (($transform1) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($transform1) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($transform1) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($lastTm1) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($29) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($29) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$boxTrans>>2] = $22;
 $35 = (($boxTrans) + 4|0);
 HEAPF32[$35>>2] = $24;
 $36 = (($boxTrans) + 8|0);
 HEAPF32[$36>>2] = $26;
 $37 = (($boxTrans) + 12|0);
 HEAPF32[$37>>2] = $28;
 $38 = (($boxTrans) + 16|0);
 HEAPF32[$38>>2] = $30;
 $39 = (($boxTrans) + 20|0);
 HEAPF32[$39>>2] = $32;
 $40 = (($boxTrans) + 24|0);
 HEAPF32[$40>>2] = $34;
 $41 = (($boxTrans) + 28|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = Math_fround(-$22);
 $43 = Math_fround(-$24);
 $44 = Math_fround(-$26);
 $45 = Math_fround($17 - $30);
 $46 = Math_fround($19 - $32);
 $47 = Math_fround($21 - $34);
 $48 = Math_fround($28 * $28);
 $49 = Math_fround($48 + Math_fround(-0.5));
 $50 = Math_fround($49 * $45);
 $51 = Math_fround($49 * $46);
 $52 = Math_fround($49 * $47);
 $53 = Math_fround($47 * $43);
 $54 = Math_fround($46 * $44);
 $55 = Math_fround($53 - $54);
 $56 = Math_fround($45 * $44);
 $57 = Math_fround($47 * $42);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($46 * $42);
 $60 = Math_fround($45 * $43);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($28 * $55);
 $63 = Math_fround($28 * $58);
 $64 = Math_fround($28 * $61);
 $65 = Math_fround($50 + $62);
 $66 = Math_fround($51 + $63);
 $67 = Math_fround($52 + $64);
 $68 = Math_fround($45 * $42);
 $69 = Math_fround($46 * $43);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($47 * $44);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($72 * $42);
 $74 = Math_fround($72 * $43);
 $75 = Math_fround($72 * $44);
 $76 = Math_fround($73 + $65);
 $77 = Math_fround($74 + $66);
 $78 = Math_fround($67 + $75);
 $79 = Math_fround($76 * Math_fround(2.0));
 $80 = Math_fround($77 * Math_fround(2.0));
 $81 = Math_fround($78 * Math_fround(2.0));
 $82 = Math_fround($15 * $28);
 $83 = Math_fround($9 * $42);
 $84 = Math_fround($11 * $43);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($13 * $44);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($82 - $87);
 $89 = Math_fround($15 * $42);
 $90 = Math_fround($15 * $43);
 $91 = Math_fround($15 * $44);
 $92 = Math_fround($9 * $28);
 $93 = Math_fround($11 * $28);
 $94 = Math_fround($13 * $28);
 $95 = Math_fround($13 * $43);
 $96 = Math_fround($11 * $44);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($9 * $44);
 $99 = Math_fround($13 * $42);
 $100 = Math_fround($98 - $99);
 $101 = Math_fround($11 * $42);
 $102 = Math_fround($9 * $43);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($89 + $92);
 $105 = Math_fround($90 + $93);
 $106 = Math_fround($94 + $91);
 $107 = Math_fround($97 + $104);
 $108 = Math_fround($100 + $105);
 $109 = Math_fround($103 + $106);
 $110 = (($aToB) + 48|0);
 HEAPF32[$110>>2] = $79;
 $111 = (($aToB) + 52|0);
 HEAPF32[$111>>2] = $80;
 $112 = (($aToB) + 56|0);
 HEAPF32[$112>>2] = $81;
 $113 = (($aToB) + 60|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = Math_fround($107 + $107);
 $115 = Math_fround($108 + $108);
 $116 = Math_fround($109 + $109);
 $117 = Math_fround($107 * $114);
 $118 = Math_fround($108 * $115);
 $119 = Math_fround($109 * $116);
 $120 = Math_fround($108 * $114);
 $121 = Math_fround($109 * $114);
 $122 = Math_fround($88 * $114);
 $123 = Math_fround($109 * $115);
 $124 = Math_fround($88 * $115);
 $125 = Math_fround($88 * $116);
 $126 = Math_fround(Math_fround(1.0) - $117);
 $127 = Math_fround(Math_fround(1.0) - $118);
 $128 = Math_fround($127 - $119);
 $129 = Math_fround($120 + $125);
 $130 = Math_fround($121 - $124);
 $131 = Math_fround($120 - $125);
 $132 = Math_fround($126 - $119);
 $133 = Math_fround($123 + $122);
 $134 = Math_fround($121 + $124);
 $135 = Math_fround($123 - $122);
 $136 = Math_fround($126 - $118);
 HEAPF32[$aToB>>2] = $128;
 $137 = (($aToB) + 4|0);
 HEAPF32[$137>>2] = $129;
 $138 = (($aToB) + 8|0);
 HEAPF32[$138>>2] = $130;
 $139 = (($aToB) + 12|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($aToB) + 16|0);
 HEAPF32[$140>>2] = $131;
 $141 = (($aToB) + 20|0);
 HEAPF32[$141>>2] = $132;
 $142 = (($aToB) + 24|0);
 HEAPF32[$142>>2] = $133;
 $143 = (($aToB) + 28|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = (($aToB) + 32|0);
 HEAPF32[$144>>2] = $134;
 $145 = (($aToB) + 36|0);
 HEAPF32[$145>>2] = $135;
 $146 = (($aToB) + 40|0);
 HEAPF32[$146>>2] = $136;
 $147 = (($aToB) + 44|0);
 HEAPF32[$147>>2] = Math_fround(0.0);
 $148 = (($1) + 40|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($capsule) + 64|0);
 $151 = (($capsule) + 80|0);
 HEAP32[$151>>2] = 4;
 $152 = (($capsule) + 16|0);
 $153 = (($capsule) + 20|0);
 $154 = (($capsule) + 32|0);
 $155 = (($capsule) + 36|0);
 $156 = (($capsule) + 48|0);
 HEAPF32[$156>>2] = Math_fround(0.0);
 $157 = (($capsule) + 52|0);
 ;HEAP32[$157+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $158 = (($capsule) + 96|0);
 $159 = (($capsule) + 112|0);
 ;HEAP32[$capsule+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $160 = (($capsule) + 128|0);
 HEAPF32[$160>>2] = $149;
 $161 = (($capsule) + 132|0);
 ;HEAP32[$161+0>>2]=HEAP32[$$sroa$132+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$$sroa$132+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$$sroa$132+8>>2]|0;
 ;HEAP32[$158+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$158+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$159+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$159+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$152>>2] = $149;
 ;HEAP32[$153+0>>2]=HEAP32[$$sroa$132+0>>2]|0;HEAP32[$153+4>>2]=HEAP32[$$sroa$132+4>>2]|0;HEAP32[$153+8>>2]=HEAP32[$$sroa$132+8>>2]|0;
 HEAPF32[$154>>2] = $149;
 ;HEAP32[$155+0>>2]=HEAP32[$$sroa$132+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$$sroa$132+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$$sroa$132+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$150+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$150+12>>2]=HEAP32[$0+12>>2]|0;
 $162 = (($box) + 64|0);
 ;HEAP32[$box+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $163 = (($box) + 80|0);
 HEAP32[$163>>2] = 3;
 $164 = (($box) + 16|0);
 $165 = (($box) + 20|0);
 ;HEAP32[$165+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$0+8>>2]|0;
 $166 = (($box) + 32|0);
 $167 = (($box) + 36|0);
 $168 = (($box) + 48|0);
 HEAPF32[$168>>2] = Math_fround(0.0);
 $169 = (($box) + 52|0);
 ;HEAP32[$169+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$169+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$169+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$162+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $170 = (($box) + 144|0);
 HEAPF32[$170>>2] = $4;
 $171 = (($box) + 148|0);
 HEAPF32[$171>>2] = $6;
 $172 = (($box) + 152|0);
 HEAPF32[$172>>2] = $8;
 $173 = (($box) + 156|0);
 HEAPF32[$173>>2] = Math_fround(0.0);
 $174 = !($4 <= $6);
 $$$i26$i$i$i = $174 ? $6 : $4;
 $175 = !($$$i26$i$i$i <= $8);
 $176 = $175 ? $8 : $$$i26$i$i$i;
 $177 = !($4 >= $6);
 $$$i23$i$i$i = $177 ? $6 : $4;
 $178 = !($$$i23$i$i$i >= $8);
 $179 = $178 ? $8 : $$$i23$i$i$i;
 $180 = Math_fround($176 * Math_fround(0.150000005960464477539));
 $181 = Math_fround($179 * Math_fround(0.0299999993294477462769));
 $182 = $180 > $181;
 $$$i12$i$i$i = $182 ? $180 : $181;
 $183 = $176 > $$$i12$i$i$i;
 $$$i$i$i$i = $183 ? $$$i12$i$i$i : $176;
 HEAPF32[$164>>2] = $$$i$i$i$i;
 ;HEAP32[$165+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$0+8>>2]|0;
 $184 = Math_fround($176 * Math_fround(0.0500000007450580596924));
 HEAPF32[$166>>2] = $184;
 ;HEAP32[$167+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 HEAPF32[$toi>>2] = $toiEstimate;
 $185 = (($transform0) + 16|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($transform0) + 20|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($transform0) + 24|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($transform1) + 16|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($transform1) + 20|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($transform1) + 24|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = Math_fround($186 - $17);
 $198 = Math_fround($188 - $19);
 $199 = Math_fround($190 - $21);
 HEAPF32[$trA>>2] = $197;
 $200 = (($trA) + 4|0);
 HEAPF32[$200>>2] = $198;
 $201 = (($trA) + 8|0);
 HEAPF32[$201>>2] = $199;
 $202 = (($trA) + 12|0);
 HEAPF32[$202>>2] = Math_fround(0.0);
 $203 = Math_fround($192 - $30);
 $204 = Math_fround($194 - $32);
 $205 = Math_fround($196 - $34);
 $206 = Math_fround($203 - $197);
 $207 = Math_fround($204 - $198);
 $208 = Math_fround($205 - $199);
 $209 = Math_fround(HEAPF32[$boxTrans>>2]);
 $210 = Math_fround(HEAPF32[$35>>2]);
 $211 = Math_fround(HEAPF32[$36>>2]);
 $212 = Math_fround(HEAPF32[$37>>2]);
 $213 = Math_fround($212 * $212);
 $214 = Math_fround($213 + Math_fround(-0.5));
 $215 = Math_fround($206 * $214);
 $216 = Math_fround($207 * $214);
 $217 = Math_fround($208 * $214);
 $218 = Math_fround($208 * $210);
 $219 = Math_fround($207 * $211);
 $220 = Math_fround($218 - $219);
 $221 = Math_fround($206 * $211);
 $222 = Math_fround($209 * $208);
 $223 = Math_fround($221 - $222);
 $224 = Math_fround($207 * $209);
 $225 = Math_fround($206 * $210);
 $226 = Math_fround($224 - $225);
 $227 = Math_fround($212 * $220);
 $228 = Math_fround($212 * $223);
 $229 = Math_fround($212 * $226);
 $230 = Math_fround($215 - $227);
 $231 = Math_fround($216 - $228);
 $232 = Math_fround($217 - $229);
 $233 = Math_fround($206 * $209);
 $234 = Math_fround($207 * $210);
 $235 = Math_fround($233 + $234);
 $236 = Math_fround($208 * $211);
 $237 = Math_fround($235 + $236);
 $238 = Math_fround($209 * $237);
 $239 = Math_fround($210 * $237);
 $240 = Math_fround($211 * $237);
 $241 = Math_fround($238 + $230);
 $242 = Math_fround($239 + $231);
 $243 = Math_fround($240 + $232);
 $244 = Math_fround($241 * Math_fround(2.0));
 $245 = Math_fround($242 * Math_fround(2.0));
 $246 = Math_fround($243 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $244;
 $247 = (($relTr) + 4|0);
 HEAPF32[$247>>2] = $245;
 $248 = (($relTr) + 8|0);
 HEAPF32[$248>>2] = $246;
 $249 = (($relTr) + 12|0);
 HEAPF32[$249>>2] = Math_fround(0.0);
 $250 = Math_fround(HEAPF32[$148>>2]);
 $251 = Math_fround($250 + $restDistance);
 $252 = (__ZN5physx8CCDSweepINS_2Gu8CapsuleVENS1_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($capsule,$box,$aToB,$boxTrans,$trA,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$251)|0);
 if (!($252)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $253 = Math_fround(HEAPF32[$lambda>>2]);
 $254 = Math_fround(HEAPF32[$normal>>2]);
 $255 = (($normal) + 4|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 $257 = (($normal) + 8|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 HEAPF32[$worldNormal>>2] = $254;
 $259 = (($worldNormal) + 4|0);
 HEAPF32[$259>>2] = $256;
 $260 = (($worldNormal) + 8|0);
 HEAPF32[$260>>2] = $258;
 $261 = Math_fround(HEAPF32[$closestA>>2]);
 $262 = (($closestA) + 4|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 $264 = (($closestA) + 8|0);
 $265 = Math_fround(HEAPF32[$264>>2]);
 HEAPF32[$worldPoint>>2] = $261;
 $266 = (($worldPoint) + 4|0);
 HEAPF32[$266>>2] = $263;
 $267 = (($worldPoint) + 8|0);
 HEAPF32[$267>>2] = $265;
 $$0 = $253;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx8CCDSweepINS_2Gu8CapsuleVENS1_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_8CapsuleVERNS0_4BoxVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx22PxcSweepCapsuleCapsuleERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0;
 var $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0;
 var $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0);
 var $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $capTrans1 = 0, $capsule0 = 0, $capsule1 = 0, $capsuleRadius0$sroa$1 = 0, $capsuleRadius1$sroa$1 = 0, $closestA = 0, $lambda = 0, $normal = 0;
 var $relTr = 0, $toi = 0, $trA = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 496|0;
 $zero$sroa$1$i$i$i = sp + 512|0;
 $zeroV = sp + 480|0;
 $capsuleRadius0$sroa$1 = sp + 524|0;
 $capsuleRadius1$sroa$1 = sp + 536|0;
 $capTrans1 = sp + 448|0;
 $aToB = sp + 384|0;
 $capsule0 = sp + 240|0;
 $capsule1 = sp + 80|0;
 $toi = sp + 64|0;
 $trA = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 224|0;
 $1 = HEAP32[$shape0>>2]|0;
 $2 = HEAP32[$shape1>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $3 = (($1) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 44|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($2) + 40|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($2) + 44|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$transform0>>2]);
 $12 = (($transform0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($transform0) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($transform0) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($lastTm0) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($18) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($18) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(HEAPF32[$transform1>>2]);
 $25 = (($transform1) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($transform1) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($transform1) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($lastTm1) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($31) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($31) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$capTrans1>>2] = $24;
 $37 = (($capTrans1) + 4|0);
 HEAPF32[$37>>2] = $26;
 $38 = (($capTrans1) + 8|0);
 HEAPF32[$38>>2] = $28;
 $39 = (($capTrans1) + 12|0);
 HEAPF32[$39>>2] = $30;
 $40 = (($capTrans1) + 16|0);
 HEAPF32[$40>>2] = $32;
 $41 = (($capTrans1) + 20|0);
 HEAPF32[$41>>2] = $34;
 $42 = (($capTrans1) + 24|0);
 HEAPF32[$42>>2] = $36;
 $43 = (($capTrans1) + 28|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = Math_fround(-$24);
 $45 = Math_fround(-$26);
 $46 = Math_fround(-$28);
 $47 = Math_fround($19 - $32);
 $48 = Math_fround($21 - $34);
 $49 = Math_fround($23 - $36);
 $50 = Math_fround($30 * $30);
 $51 = Math_fround($50 + Math_fround(-0.5));
 $52 = Math_fround($51 * $47);
 $53 = Math_fround($51 * $48);
 $54 = Math_fround($51 * $49);
 $55 = Math_fround($49 * $45);
 $56 = Math_fround($48 * $46);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($47 * $46);
 $59 = Math_fround($49 * $44);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($48 * $44);
 $62 = Math_fround($47 * $45);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($30 * $57);
 $65 = Math_fround($30 * $60);
 $66 = Math_fround($30 * $63);
 $67 = Math_fround($52 + $64);
 $68 = Math_fround($53 + $65);
 $69 = Math_fround($54 + $66);
 $70 = Math_fround($47 * $44);
 $71 = Math_fround($48 * $45);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($49 * $46);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($74 * $44);
 $76 = Math_fround($74 * $45);
 $77 = Math_fround($74 * $46);
 $78 = Math_fround($75 + $67);
 $79 = Math_fround($76 + $68);
 $80 = Math_fround($69 + $77);
 $81 = Math_fround($78 * Math_fround(2.0));
 $82 = Math_fround($79 * Math_fround(2.0));
 $83 = Math_fround($80 * Math_fround(2.0));
 $84 = Math_fround($17 * $30);
 $85 = Math_fround($11 * $44);
 $86 = Math_fround($13 * $45);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($15 * $46);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($84 - $89);
 $91 = Math_fround($17 * $44);
 $92 = Math_fround($17 * $45);
 $93 = Math_fround($17 * $46);
 $94 = Math_fround($11 * $30);
 $95 = Math_fround($13 * $30);
 $96 = Math_fround($15 * $30);
 $97 = Math_fround($15 * $45);
 $98 = Math_fround($13 * $46);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($11 * $46);
 $101 = Math_fround($15 * $44);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($13 * $44);
 $104 = Math_fround($11 * $45);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($91 + $94);
 $107 = Math_fround($92 + $95);
 $108 = Math_fround($96 + $93);
 $109 = Math_fround($99 + $106);
 $110 = Math_fround($102 + $107);
 $111 = Math_fround($105 + $108);
 $112 = (($aToB) + 48|0);
 HEAPF32[$112>>2] = $81;
 $113 = (($aToB) + 52|0);
 HEAPF32[$113>>2] = $82;
 $114 = (($aToB) + 56|0);
 HEAPF32[$114>>2] = $83;
 $115 = (($aToB) + 60|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = Math_fround($109 + $109);
 $117 = Math_fround($110 + $110);
 $118 = Math_fround($111 + $111);
 $119 = Math_fround($109 * $116);
 $120 = Math_fround($110 * $117);
 $121 = Math_fround($111 * $118);
 $122 = Math_fround($110 * $116);
 $123 = Math_fround($111 * $116);
 $124 = Math_fround($90 * $116);
 $125 = Math_fround($111 * $117);
 $126 = Math_fround($90 * $117);
 $127 = Math_fround($90 * $118);
 $128 = Math_fround(Math_fround(1.0) - $119);
 $129 = Math_fround(Math_fround(1.0) - $120);
 $130 = Math_fround($129 - $121);
 $131 = Math_fround($122 + $127);
 $132 = Math_fround($123 - $126);
 $133 = Math_fround($122 - $127);
 $134 = Math_fround($128 - $121);
 $135 = Math_fround($125 + $124);
 $136 = Math_fround($123 + $126);
 $137 = Math_fround($125 - $124);
 $138 = Math_fround($128 - $120);
 HEAPF32[$aToB>>2] = $130;
 $139 = (($aToB) + 4|0);
 HEAPF32[$139>>2] = $131;
 $140 = (($aToB) + 8|0);
 HEAPF32[$140>>2] = $132;
 $141 = (($aToB) + 12|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 $142 = (($aToB) + 16|0);
 HEAPF32[$142>>2] = $133;
 $143 = (($aToB) + 20|0);
 HEAPF32[$143>>2] = $134;
 $144 = (($aToB) + 24|0);
 HEAPF32[$144>>2] = $135;
 $145 = (($aToB) + 28|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = (($aToB) + 32|0);
 HEAPF32[$146>>2] = $136;
 $147 = (($aToB) + 36|0);
 HEAPF32[$147>>2] = $137;
 $148 = (($aToB) + 40|0);
 HEAPF32[$148>>2] = $138;
 $149 = (($aToB) + 44|0);
 HEAPF32[$149>>2] = Math_fround(0.0);
 $150 = Math_fround($6 * Math_fround(0.0));
 $151 = (($capsule0) + 64|0);
 ;HEAP32[$capsule0+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule0+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule0+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule0+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $152 = (($capsule0) + 80|0);
 HEAP32[$152>>2] = 4;
 $153 = (($capsule0) + 16|0);
 $154 = (($capsule0) + 20|0);
 $155 = (($capsule0) + 32|0);
 $156 = (($capsule0) + 36|0);
 $157 = (($capsule0) + 48|0);
 HEAPF32[$157>>2] = Math_fround(0.0);
 $158 = (($capsule0) + 52|0);
 ;HEAP32[$158+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $159 = (($capsule0) + 128|0);
 HEAPF32[$159>>2] = $4;
 $160 = (($capsule0) + 132|0);
 ;HEAP32[$160+0>>2]=HEAP32[$capsuleRadius0$sroa$1+0>>2]|0;HEAP32[$160+4>>2]=HEAP32[$capsuleRadius0$sroa$1+4>>2]|0;HEAP32[$160+8>>2]=HEAP32[$capsuleRadius0$sroa$1+8>>2]|0;
 $161 = Math_fround(HEAPF32[$zeroV>>2]);
 $162 = (($zeroV) + 4|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($zeroV) + 8|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = Math_fround($6 + $161);
 $167 = Math_fround($150 + $163);
 $168 = Math_fround($150 + $165);
 $169 = (($capsule0) + 96|0);
 HEAPF32[$169>>2] = $166;
 $170 = (($capsule0) + 100|0);
 HEAPF32[$170>>2] = $167;
 $171 = (($capsule0) + 104|0);
 HEAPF32[$171>>2] = $168;
 $172 = (($capsule0) + 108|0);
 HEAPF32[$172>>2] = Math_fround(0.0);
 $173 = Math_fround($161 - $6);
 $174 = Math_fround($163 - $150);
 $175 = Math_fround($165 - $150);
 $176 = (($capsule0) + 112|0);
 HEAPF32[$176>>2] = $173;
 $177 = (($capsule0) + 116|0);
 HEAPF32[$177>>2] = $174;
 $178 = (($capsule0) + 120|0);
 HEAPF32[$178>>2] = $175;
 $179 = (($capsule0) + 124|0);
 HEAPF32[$179>>2] = Math_fround(0.0);
 HEAPF32[$153>>2] = $4;
 ;HEAP32[$154+0>>2]=HEAP32[$capsuleRadius0$sroa$1+0>>2]|0;HEAP32[$154+4>>2]=HEAP32[$capsuleRadius0$sroa$1+4>>2]|0;HEAP32[$154+8>>2]=HEAP32[$capsuleRadius0$sroa$1+8>>2]|0;
 HEAPF32[$155>>2] = $4;
 ;HEAP32[$156+0>>2]=HEAP32[$capsuleRadius0$sroa$1+0>>2]|0;HEAP32[$156+4>>2]=HEAP32[$capsuleRadius0$sroa$1+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$capsuleRadius0$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$151+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$151+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$151+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$151+12>>2]=HEAP32[$0+12>>2]|0;
 $180 = Math_fround($10 * Math_fround(0.0));
 $181 = (($capsule1) + 64|0);
 ;HEAP32[$capsule1+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule1+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule1+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule1+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $182 = (($capsule1) + 80|0);
 HEAP32[$182>>2] = 4;
 $183 = (($capsule1) + 16|0);
 $184 = (($capsule1) + 20|0);
 $185 = (($capsule1) + 32|0);
 $186 = (($capsule1) + 36|0);
 $187 = (($capsule1) + 48|0);
 HEAPF32[$187>>2] = Math_fround(0.0);
 $188 = (($capsule1) + 52|0);
 ;HEAP32[$188+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$188+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$188+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $189 = (($capsule1) + 128|0);
 HEAPF32[$189>>2] = $8;
 $190 = (($capsule1) + 132|0);
 ;HEAP32[$190+0>>2]=HEAP32[$capsuleRadius1$sroa$1+0>>2]|0;HEAP32[$190+4>>2]=HEAP32[$capsuleRadius1$sroa$1+4>>2]|0;HEAP32[$190+8>>2]=HEAP32[$capsuleRadius1$sroa$1+8>>2]|0;
 $191 = Math_fround($10 + $161);
 $192 = Math_fround($180 + $163);
 $193 = Math_fround($180 + $165);
 $194 = (($capsule1) + 96|0);
 HEAPF32[$194>>2] = $191;
 $195 = (($capsule1) + 100|0);
 HEAPF32[$195>>2] = $192;
 $196 = (($capsule1) + 104|0);
 HEAPF32[$196>>2] = $193;
 $197 = (($capsule1) + 108|0);
 HEAPF32[$197>>2] = Math_fround(0.0);
 $198 = Math_fround($161 - $10);
 $199 = Math_fround($163 - $180);
 $200 = Math_fround($165 - $180);
 $201 = (($capsule1) + 112|0);
 HEAPF32[$201>>2] = $198;
 $202 = (($capsule1) + 116|0);
 HEAPF32[$202>>2] = $199;
 $203 = (($capsule1) + 120|0);
 HEAPF32[$203>>2] = $200;
 $204 = (($capsule1) + 124|0);
 HEAPF32[$204>>2] = Math_fround(0.0);
 HEAPF32[$183>>2] = $8;
 ;HEAP32[$184+0>>2]=HEAP32[$capsuleRadius1$sroa$1+0>>2]|0;HEAP32[$184+4>>2]=HEAP32[$capsuleRadius1$sroa$1+4>>2]|0;HEAP32[$184+8>>2]=HEAP32[$capsuleRadius1$sroa$1+8>>2]|0;
 HEAPF32[$185>>2] = $8;
 ;HEAP32[$186+0>>2]=HEAP32[$capsuleRadius1$sroa$1+0>>2]|0;HEAP32[$186+4>>2]=HEAP32[$capsuleRadius1$sroa$1+4>>2]|0;HEAP32[$186+8>>2]=HEAP32[$capsuleRadius1$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$181+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$181+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$181+12>>2]=HEAP32[$0+12>>2]|0;
 HEAPF32[$toi>>2] = $toiEstimate;
 $205 = (($transform0) + 16|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = (($transform0) + 20|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($transform0) + 24|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($transform1) + 16|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($transform1) + 20|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = (($transform1) + 24|0);
 $216 = Math_fround(HEAPF32[$215>>2]);
 $217 = Math_fround($206 - $19);
 $218 = Math_fround($208 - $21);
 $219 = Math_fround($210 - $23);
 HEAPF32[$trA>>2] = $217;
 $220 = (($trA) + 4|0);
 HEAPF32[$220>>2] = $218;
 $221 = (($trA) + 8|0);
 HEAPF32[$221>>2] = $219;
 $222 = (($trA) + 12|0);
 HEAPF32[$222>>2] = Math_fround(0.0);
 $223 = Math_fround($212 - $32);
 $224 = Math_fround($214 - $34);
 $225 = Math_fround($216 - $36);
 $226 = Math_fround($223 - $217);
 $227 = Math_fround($224 - $218);
 $228 = Math_fround($225 - $219);
 $229 = Math_fround(HEAPF32[$capTrans1>>2]);
 $230 = Math_fround(HEAPF32[$37>>2]);
 $231 = Math_fround(HEAPF32[$38>>2]);
 $232 = Math_fround(HEAPF32[$39>>2]);
 $233 = Math_fround($232 * $232);
 $234 = Math_fround($233 + Math_fround(-0.5));
 $235 = Math_fround($226 * $234);
 $236 = Math_fround($227 * $234);
 $237 = Math_fround($228 * $234);
 $238 = Math_fround($228 * $230);
 $239 = Math_fround($227 * $231);
 $240 = Math_fround($238 - $239);
 $241 = Math_fround($226 * $231);
 $242 = Math_fround($229 * $228);
 $243 = Math_fround($241 - $242);
 $244 = Math_fround($227 * $229);
 $245 = Math_fround($226 * $230);
 $246 = Math_fround($244 - $245);
 $247 = Math_fround($232 * $240);
 $248 = Math_fround($232 * $243);
 $249 = Math_fround($232 * $246);
 $250 = Math_fround($235 - $247);
 $251 = Math_fround($236 - $248);
 $252 = Math_fround($237 - $249);
 $253 = Math_fround($226 * $229);
 $254 = Math_fround($227 * $230);
 $255 = Math_fround($253 + $254);
 $256 = Math_fround($228 * $231);
 $257 = Math_fround($255 + $256);
 $258 = Math_fround($229 * $257);
 $259 = Math_fround($230 * $257);
 $260 = Math_fround($231 * $257);
 $261 = Math_fround($258 + $250);
 $262 = Math_fround($259 + $251);
 $263 = Math_fround($260 + $252);
 $264 = Math_fround($261 * Math_fround(2.0));
 $265 = Math_fround($262 * Math_fround(2.0));
 $266 = Math_fround($263 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $264;
 $267 = (($relTr) + 4|0);
 HEAPF32[$267>>2] = $265;
 $268 = (($relTr) + 8|0);
 HEAPF32[$268>>2] = $266;
 $269 = (($relTr) + 12|0);
 HEAPF32[$269>>2] = Math_fround(0.0);
 $270 = Math_fround(HEAPF32[$3>>2]);
 $271 = Math_fround(HEAPF32[$7>>2]);
 $272 = Math_fround($270 + $271);
 $273 = Math_fround($272 + $restDistance);
 $274 = (__ZN5physx8CCDSweepINS_2Gu8CapsuleVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVERKNS8_5Vec3VERKNS8_6FloatVESH_SH_RSI_RSF_SM_f($capsule0,$capsule1,$aToB,$capTrans1,$trA,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$273)|0);
 if (!($274)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $275 = Math_fround(HEAPF32[$lambda>>2]);
 $276 = Math_fround(HEAPF32[$normal>>2]);
 $277 = (($normal) + 4|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = (($normal) + 8|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 HEAPF32[$worldNormal>>2] = $276;
 $281 = (($worldNormal) + 4|0);
 HEAPF32[$281>>2] = $278;
 $282 = (($worldNormal) + 8|0);
 HEAPF32[$282>>2] = $280;
 $283 = Math_fround(HEAPF32[$closestA>>2]);
 $284 = (($closestA) + 4|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = (($closestA) + 8|0);
 $287 = Math_fround(HEAPF32[$286>>2]);
 HEAPF32[$worldPoint>>2] = $283;
 $288 = (($worldPoint) + 4|0);
 HEAPF32[$288>>2] = $285;
 $289 = (($worldPoint) + 8|0);
 HEAPF32[$289>>2] = $287;
 $$0 = $275;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx18PxcSweepCapsuleBoxERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = Math_fround(0), $$sroa$1$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0;
 var $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0;
 var $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0);
 var $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $box = 0, $boxTrans = 0, $capsule = 0, $capsuleRadius$sroa$1 = 0, $closestA = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trA = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 464|0;
 $$sroa$1$i$i$i = sp + 448|0;
 $zeroV = sp + 432|0;
 $capsuleRadius$sroa$1 = sp + 528|0;
 $capsule = sp + 288|0;
 $box = sp + 128|0;
 $boxTrans = sp + 96|0;
 $toi = sp + 64|0;
 $trA = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 80|0;
 $1 = HEAP32[$shape0>>2]|0;
 $2 = HEAP32[$shape1>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $3 = (($1) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 44|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($2) + 40|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($2) + 44|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($2) + 48|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($6 * Math_fround(0.0));
 $14 = (($capsule) + 64|0);
 ;HEAP32[$capsule+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $15 = (($capsule) + 80|0);
 HEAP32[$15>>2] = 4;
 $16 = (($capsule) + 16|0);
 $17 = (($capsule) + 20|0);
 $18 = (($capsule) + 32|0);
 $19 = (($capsule) + 36|0);
 $20 = (($capsule) + 48|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($capsule) + 52|0);
 ;HEAP32[$21+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $22 = (($capsule) + 128|0);
 HEAPF32[$22>>2] = $4;
 $23 = (($capsule) + 132|0);
 ;HEAP32[$23+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $24 = Math_fround($6 + Math_fround(0.0));
 $25 = Math_fround($13 + Math_fround(0.0));
 $26 = (($capsule) + 96|0);
 HEAPF32[$26>>2] = $24;
 $27 = (($capsule) + 100|0);
 HEAPF32[$27>>2] = $25;
 $28 = (($capsule) + 104|0);
 HEAPF32[$28>>2] = $25;
 $29 = (($capsule) + 108|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = Math_fround(Math_fround(0.0) - $6);
 $31 = Math_fround(Math_fround(0.0) - $13);
 $32 = (($capsule) + 112|0);
 HEAPF32[$32>>2] = $30;
 $33 = (($capsule) + 116|0);
 HEAPF32[$33>>2] = $31;
 $34 = (($capsule) + 120|0);
 HEAPF32[$34>>2] = $31;
 $35 = (($capsule) + 124|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 HEAPF32[$16>>2] = $4;
 ;HEAP32[$17+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$18>>2] = $4;
 ;HEAP32[$19+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$14+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$0+12>>2]|0;
 $36 = (($box) + 64|0);
 ;HEAP32[$box+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $37 = (($box) + 80|0);
 HEAP32[$37>>2] = 3;
 $38 = (($box) + 16|0);
 $39 = (($box) + 20|0);
 ;HEAP32[$39+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$0+8>>2]|0;
 $40 = (($box) + 32|0);
 $41 = (($box) + 36|0);
 $42 = (($box) + 48|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($box) + 52|0);
 ;HEAP32[$43+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$36+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $44 = (($box) + 144|0);
 HEAPF32[$44>>2] = $8;
 $45 = (($box) + 148|0);
 HEAPF32[$45>>2] = $10;
 $46 = (($box) + 152|0);
 HEAPF32[$46>>2] = $12;
 $47 = (($box) + 156|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = !($8 <= $10);
 $$$i26$i$i$i = $48 ? $10 : $8;
 $49 = !($$$i26$i$i$i <= $12);
 $50 = $49 ? $12 : $$$i26$i$i$i;
 $51 = !($8 >= $10);
 $$$i23$i$i$i = $51 ? $10 : $8;
 $52 = !($$$i23$i$i$i >= $12);
 $53 = $52 ? $12 : $$$i23$i$i$i;
 $54 = Math_fround($50 * Math_fround(0.150000005960464477539));
 $55 = Math_fround($53 * Math_fround(0.0299999993294477462769));
 $56 = $54 > $55;
 $$$i12$i$i$i = $56 ? $54 : $55;
 $57 = $50 > $$$i12$i$i$i;
 $$$i$i$i$i = $57 ? $$$i12$i$i$i : $50;
 HEAPF32[$38>>2] = $$$i$i$i$i;
 ;HEAP32[$39+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$0+8>>2]|0;
 $58 = Math_fround($50 * Math_fround(0.0500000007450580596924));
 HEAPF32[$40>>2] = $58;
 ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $59 = Math_fround(HEAPF32[$transform0>>2]);
 $60 = (($transform0) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($transform0) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($transform0) + 12|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($lastTm0) + 16|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($66) + 4|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($66) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround(HEAPF32[$transform1>>2]);
 $73 = (($transform1) + 4|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($transform1) + 8|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($transform1) + 12|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($lastTm1) + 16|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($79) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($79) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 HEAPF32[$boxTrans>>2] = $72;
 $85 = (($boxTrans) + 4|0);
 HEAPF32[$85>>2] = $74;
 $86 = (($boxTrans) + 8|0);
 HEAPF32[$86>>2] = $76;
 $87 = (($boxTrans) + 12|0);
 HEAPF32[$87>>2] = $78;
 $88 = (($boxTrans) + 16|0);
 HEAPF32[$88>>2] = $80;
 $89 = (($boxTrans) + 20|0);
 HEAPF32[$89>>2] = $82;
 $90 = (($boxTrans) + 24|0);
 HEAPF32[$90>>2] = $84;
 $91 = (($boxTrans) + 28|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = Math_fround(-$72);
 $93 = Math_fround(-$74);
 $94 = Math_fround(-$76);
 $95 = Math_fround($67 - $80);
 $96 = Math_fround($69 - $82);
 $97 = Math_fround($71 - $84);
 $98 = Math_fround($78 * $78);
 $99 = Math_fround($98 + Math_fround(-0.5));
 $100 = Math_fround($99 * $95);
 $101 = Math_fround($99 * $96);
 $102 = Math_fround($99 * $97);
 $103 = Math_fround($97 * $93);
 $104 = Math_fround($96 * $94);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($95 * $94);
 $107 = Math_fround($97 * $92);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($96 * $92);
 $110 = Math_fround($95 * $93);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($78 * $105);
 $113 = Math_fround($78 * $108);
 $114 = Math_fround($78 * $111);
 $115 = Math_fround($100 + $112);
 $116 = Math_fround($101 + $113);
 $117 = Math_fround($102 + $114);
 $118 = Math_fround($95 * $92);
 $119 = Math_fround($96 * $93);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($97 * $94);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($122 * $92);
 $124 = Math_fround($122 * $93);
 $125 = Math_fround($122 * $94);
 $126 = Math_fround($123 + $115);
 $127 = Math_fround($124 + $116);
 $128 = Math_fround($117 + $125);
 $129 = Math_fround($126 * Math_fround(2.0));
 $130 = Math_fround($127 * Math_fround(2.0));
 $131 = Math_fround($128 * Math_fround(2.0));
 $132 = Math_fround($65 * $78);
 $133 = Math_fround($59 * $92);
 $134 = Math_fround($61 * $93);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround($63 * $94);
 $137 = Math_fround($135 + $136);
 $138 = Math_fround($132 - $137);
 $139 = Math_fround($65 * $92);
 $140 = Math_fround($65 * $93);
 $141 = Math_fround($65 * $94);
 $142 = Math_fround($59 * $78);
 $143 = Math_fround($61 * $78);
 $144 = Math_fround($63 * $78);
 $145 = Math_fround($63 * $93);
 $146 = Math_fround($61 * $94);
 $147 = Math_fround($145 - $146);
 $148 = Math_fround($59 * $94);
 $149 = Math_fround($63 * $92);
 $150 = Math_fround($148 - $149);
 $151 = Math_fround($61 * $92);
 $152 = Math_fround($59 * $93);
 $153 = Math_fround($151 - $152);
 $154 = Math_fround($139 + $142);
 $155 = Math_fround($140 + $143);
 $156 = Math_fround($144 + $141);
 $157 = Math_fround($147 + $154);
 $158 = Math_fround($150 + $155);
 $159 = Math_fround($153 + $156);
 $160 = (($0) + 48|0);
 HEAPF32[$160>>2] = $129;
 $161 = (($0) + 52|0);
 HEAPF32[$161>>2] = $130;
 $162 = (($0) + 56|0);
 HEAPF32[$162>>2] = $131;
 $163 = (($0) + 60|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = Math_fround($157 + $157);
 $165 = Math_fround($158 + $158);
 $166 = Math_fround($159 + $159);
 $167 = Math_fround($157 * $164);
 $168 = Math_fround($158 * $165);
 $169 = Math_fround($159 * $166);
 $170 = Math_fround($158 * $164);
 $171 = Math_fround($159 * $164);
 $172 = Math_fround($138 * $164);
 $173 = Math_fround($159 * $165);
 $174 = Math_fround($138 * $165);
 $175 = Math_fround($138 * $166);
 $176 = Math_fround(Math_fround(1.0) - $167);
 $177 = Math_fround(Math_fround(1.0) - $168);
 $178 = Math_fround($177 - $169);
 $179 = Math_fround($170 + $175);
 $180 = Math_fround($171 - $174);
 $181 = Math_fround($170 - $175);
 $182 = Math_fround($176 - $169);
 $183 = Math_fround($173 + $172);
 $184 = Math_fround($171 + $174);
 $185 = Math_fround($173 - $172);
 $186 = Math_fround($176 - $168);
 HEAPF32[$0>>2] = $178;
 $187 = (($0) + 4|0);
 HEAPF32[$187>>2] = $179;
 $188 = (($0) + 8|0);
 HEAPF32[$188>>2] = $180;
 $189 = (($0) + 12|0);
 HEAPF32[$189>>2] = Math_fround(0.0);
 $190 = (($0) + 16|0);
 HEAPF32[$190>>2] = $181;
 $191 = (($0) + 20|0);
 HEAPF32[$191>>2] = $182;
 $192 = (($0) + 24|0);
 HEAPF32[$192>>2] = $183;
 $193 = (($0) + 28|0);
 HEAPF32[$193>>2] = Math_fround(0.0);
 $194 = (($0) + 32|0);
 HEAPF32[$194>>2] = $184;
 $195 = (($0) + 36|0);
 HEAPF32[$195>>2] = $185;
 $196 = (($0) + 40|0);
 HEAPF32[$196>>2] = $186;
 $197 = (($0) + 44|0);
 HEAPF32[$197>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $198 = (($transform0) + 16|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($transform0) + 20|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = (($transform0) + 24|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = (($transform1) + 16|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($transform1) + 20|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = (($transform1) + 24|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = Math_fround($199 - $67);
 $211 = Math_fround($201 - $69);
 $212 = Math_fround($203 - $71);
 HEAPF32[$trA>>2] = $210;
 $213 = (($trA) + 4|0);
 HEAPF32[$213>>2] = $211;
 $214 = (($trA) + 8|0);
 HEAPF32[$214>>2] = $212;
 $215 = (($trA) + 12|0);
 HEAPF32[$215>>2] = Math_fround(0.0);
 $216 = Math_fround($205 - $80);
 $217 = Math_fround($207 - $82);
 $218 = Math_fround($209 - $84);
 $219 = Math_fround($216 - $210);
 $220 = Math_fround($217 - $211);
 $221 = Math_fround($218 - $212);
 $222 = Math_fround(HEAPF32[$boxTrans>>2]);
 $223 = Math_fround(HEAPF32[$85>>2]);
 $224 = Math_fround(HEAPF32[$86>>2]);
 $225 = Math_fround(HEAPF32[$87>>2]);
 $226 = Math_fround($225 * $225);
 $227 = Math_fround($226 + Math_fround(-0.5));
 $228 = Math_fround($219 * $227);
 $229 = Math_fround($220 * $227);
 $230 = Math_fround($221 * $227);
 $231 = Math_fround($221 * $223);
 $232 = Math_fround($220 * $224);
 $233 = Math_fround($231 - $232);
 $234 = Math_fround($219 * $224);
 $235 = Math_fround($222 * $221);
 $236 = Math_fround($234 - $235);
 $237 = Math_fround($220 * $222);
 $238 = Math_fround($219 * $223);
 $239 = Math_fround($237 - $238);
 $240 = Math_fround($225 * $233);
 $241 = Math_fround($225 * $236);
 $242 = Math_fround($225 * $239);
 $243 = Math_fround($228 - $240);
 $244 = Math_fround($229 - $241);
 $245 = Math_fround($230 - $242);
 $246 = Math_fround($219 * $222);
 $247 = Math_fround($220 * $223);
 $248 = Math_fround($246 + $247);
 $249 = Math_fround($221 * $224);
 $250 = Math_fround($248 + $249);
 $251 = Math_fround($222 * $250);
 $252 = Math_fround($223 * $250);
 $253 = Math_fround($224 * $250);
 $254 = Math_fround($251 + $243);
 $255 = Math_fround($252 + $244);
 $256 = Math_fround($253 + $245);
 $257 = Math_fround($254 * Math_fround(2.0));
 $258 = Math_fround($255 * Math_fround(2.0));
 $259 = Math_fround($256 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $257;
 $260 = (($relTr) + 4|0);
 HEAPF32[$260>>2] = $258;
 $261 = (($relTr) + 8|0);
 HEAPF32[$261>>2] = $259;
 $262 = (($relTr) + 12|0);
 HEAPF32[$262>>2] = Math_fround(0.0);
 $263 = Math_fround(HEAPF32[$3>>2]);
 $264 = Math_fround($263 + $restDistance);
 $265 = (__ZN5physx8CCDSweepINS_2Gu8CapsuleVENS1_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($capsule,$box,$0,$boxTrans,$trA,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$264)|0);
 if (!($265)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $266 = Math_fround(HEAPF32[$lambda>>2]);
 $267 = Math_fround(HEAPF32[$normal>>2]);
 $268 = (($normal) + 4|0);
 $269 = Math_fround(HEAPF32[$268>>2]);
 $270 = (($normal) + 8|0);
 $271 = Math_fround(HEAPF32[$270>>2]);
 HEAPF32[$worldNormal>>2] = $267;
 $272 = (($worldNormal) + 4|0);
 HEAPF32[$272>>2] = $269;
 $273 = (($worldNormal) + 8|0);
 HEAPF32[$273>>2] = $271;
 $274 = Math_fround(HEAPF32[$closestA>>2]);
 $275 = (($closestA) + 4|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 $277 = (($closestA) + 8|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 HEAPF32[$worldPoint>>2] = $274;
 $279 = (($worldPoint) + 4|0);
 HEAPF32[$279>>2] = $276;
 $280 = (($worldPoint) + 8|0);
 HEAPF32[$280>>2] = $278;
 $$0 = $266;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx21PxcSweepCapsuleConvexERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0);
 var $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0);
 var $278 = 0, $279 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $capsule = 0, $capsuleRadius$sroa$1 = 0, $closestA = 0, $convexTrans = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trA = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $zero$sroa$1$i$i$i = sp + 384|0;
 $0 = sp + 320|0;
 $zeroV = sp + 304|0;
 $capsuleRadius$sroa$1 = sp + 592|0;
 $vScale = sp + 288|0;
 $vQuat = sp + 272|0;
 $capsule = sp + 128|0;
 $convexTrans = sp + 96|0;
 $toi = sp + 64|0;
 $trA = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 80|0;
 $1 = HEAP32[$shape0>>2]|0;
 $2 = HEAP32[$shape1>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $3 = (($1) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 44|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($2) + 40|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($2) + 44|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($2) + 48|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$vScale>>2] = $8;
 $13 = (($vScale) + 4|0);
 HEAPF32[$13>>2] = $10;
 $14 = (($vScale) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($vScale) + 12|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($2) + 52|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($2) + 56|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($2) + 60|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($2) + 64|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 HEAPF32[$vQuat>>2] = $17;
 $24 = (($vQuat) + 4|0);
 HEAPF32[$24>>2] = $19;
 $25 = (($vQuat) + 8|0);
 HEAPF32[$25>>2] = $21;
 $26 = (($vQuat) + 12|0);
 HEAPF32[$26>>2] = $23;
 $27 = (($2) + 72|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = Math_fround($6 * Math_fround(0.0));
 $30 = (($capsule) + 64|0);
 ;HEAP32[$capsule+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $31 = (($capsule) + 80|0);
 HEAP32[$31>>2] = 4;
 $32 = (($capsule) + 16|0);
 $33 = (($capsule) + 20|0);
 $34 = (($capsule) + 32|0);
 $35 = (($capsule) + 36|0);
 $36 = (($capsule) + 48|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($capsule) + 52|0);
 ;HEAP32[$37+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $38 = (($capsule) + 128|0);
 HEAPF32[$38>>2] = $4;
 $39 = (($capsule) + 132|0);
 ;HEAP32[$39+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $40 = (($zeroV) + 4|0);
 $41 = (($zeroV) + 8|0);
 $42 = Math_fround($6 + Math_fround(0.0));
 $43 = Math_fround($29 + Math_fround(0.0));
 $44 = (($capsule) + 96|0);
 HEAPF32[$44>>2] = $42;
 $45 = (($capsule) + 100|0);
 HEAPF32[$45>>2] = $43;
 $46 = (($capsule) + 104|0);
 HEAPF32[$46>>2] = $43;
 $47 = (($capsule) + 108|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = Math_fround(HEAPF32[$zeroV>>2]);
 $49 = Math_fround(HEAPF32[$40>>2]);
 $50 = Math_fround(HEAPF32[$41>>2]);
 $51 = Math_fround($48 - $6);
 $52 = Math_fround($49 - $29);
 $53 = Math_fround($50 - $29);
 $54 = (($capsule) + 112|0);
 HEAPF32[$54>>2] = $51;
 $55 = (($capsule) + 116|0);
 HEAPF32[$55>>2] = $52;
 $56 = (($capsule) + 120|0);
 HEAPF32[$56>>2] = $53;
 $57 = (($capsule) + 124|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 HEAPF32[$32>>2] = $4;
 ;HEAP32[$33+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$34>>2] = $4;
 ;HEAP32[$35+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$30+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$0+12>>2]|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($zero$sroa$1$i$i$i,$28,$zeroV,$vScale,$vQuat);
 $58 = Math_fround(HEAPF32[$transform0>>2]);
 $59 = (($transform0) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($transform0) + 8|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($transform0) + 12|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($lastTm0) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($65) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($65) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround(HEAPF32[$transform1>>2]);
 $72 = (($transform1) + 4|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($transform1) + 8|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($transform1) + 12|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($lastTm1) + 16|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($78) + 4|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($78) + 8|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 HEAPF32[$convexTrans>>2] = $71;
 $84 = (($convexTrans) + 4|0);
 HEAPF32[$84>>2] = $73;
 $85 = (($convexTrans) + 8|0);
 HEAPF32[$85>>2] = $75;
 $86 = (($convexTrans) + 12|0);
 HEAPF32[$86>>2] = $77;
 $87 = (($convexTrans) + 16|0);
 HEAPF32[$87>>2] = $79;
 $88 = (($convexTrans) + 20|0);
 HEAPF32[$88>>2] = $81;
 $89 = (($convexTrans) + 24|0);
 HEAPF32[$89>>2] = $83;
 $90 = (($convexTrans) + 28|0);
 HEAPF32[$90>>2] = Math_fround(0.0);
 $91 = Math_fround(-$71);
 $92 = Math_fround(-$73);
 $93 = Math_fround(-$75);
 $94 = Math_fround($66 - $79);
 $95 = Math_fround($68 - $81);
 $96 = Math_fround($70 - $83);
 $97 = Math_fround($77 * $77);
 $98 = Math_fround($97 + Math_fround(-0.5));
 $99 = Math_fround($98 * $94);
 $100 = Math_fround($98 * $95);
 $101 = Math_fround($98 * $96);
 $102 = Math_fround($96 * $92);
 $103 = Math_fround($95 * $93);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($94 * $93);
 $106 = Math_fround($96 * $91);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($95 * $91);
 $109 = Math_fround($94 * $92);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($77 * $104);
 $112 = Math_fround($77 * $107);
 $113 = Math_fround($77 * $110);
 $114 = Math_fround($99 + $111);
 $115 = Math_fround($100 + $112);
 $116 = Math_fround($101 + $113);
 $117 = Math_fround($94 * $91);
 $118 = Math_fround($95 * $92);
 $119 = Math_fround($117 + $118);
 $120 = Math_fround($96 * $93);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($121 * $91);
 $123 = Math_fround($121 * $92);
 $124 = Math_fround($121 * $93);
 $125 = Math_fround($122 + $114);
 $126 = Math_fround($123 + $115);
 $127 = Math_fround($116 + $124);
 $128 = Math_fround($125 * Math_fround(2.0));
 $129 = Math_fround($126 * Math_fround(2.0));
 $130 = Math_fround($127 * Math_fround(2.0));
 $131 = Math_fround($64 * $77);
 $132 = Math_fround($58 * $91);
 $133 = Math_fround($60 * $92);
 $134 = Math_fround($132 + $133);
 $135 = Math_fround($62 * $93);
 $136 = Math_fround($134 + $135);
 $137 = Math_fround($131 - $136);
 $138 = Math_fround($64 * $91);
 $139 = Math_fround($64 * $92);
 $140 = Math_fround($64 * $93);
 $141 = Math_fround($58 * $77);
 $142 = Math_fround($60 * $77);
 $143 = Math_fround($62 * $77);
 $144 = Math_fround($62 * $92);
 $145 = Math_fround($60 * $93);
 $146 = Math_fround($144 - $145);
 $147 = Math_fround($58 * $93);
 $148 = Math_fround($62 * $91);
 $149 = Math_fround($147 - $148);
 $150 = Math_fround($60 * $91);
 $151 = Math_fround($58 * $92);
 $152 = Math_fround($150 - $151);
 $153 = Math_fround($138 + $141);
 $154 = Math_fround($139 + $142);
 $155 = Math_fround($143 + $140);
 $156 = Math_fround($146 + $153);
 $157 = Math_fround($149 + $154);
 $158 = Math_fround($152 + $155);
 $159 = (($0) + 48|0);
 HEAPF32[$159>>2] = $128;
 $160 = (($0) + 52|0);
 HEAPF32[$160>>2] = $129;
 $161 = (($0) + 56|0);
 HEAPF32[$161>>2] = $130;
 $162 = (($0) + 60|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 $163 = Math_fround($156 + $156);
 $164 = Math_fround($157 + $157);
 $165 = Math_fround($158 + $158);
 $166 = Math_fround($156 * $163);
 $167 = Math_fround($157 * $164);
 $168 = Math_fround($158 * $165);
 $169 = Math_fround($157 * $163);
 $170 = Math_fround($158 * $163);
 $171 = Math_fround($137 * $163);
 $172 = Math_fround($158 * $164);
 $173 = Math_fround($137 * $164);
 $174 = Math_fround($137 * $165);
 $175 = Math_fround(Math_fround(1.0) - $166);
 $176 = Math_fround(Math_fround(1.0) - $167);
 $177 = Math_fround($176 - $168);
 $178 = Math_fround($169 + $174);
 $179 = Math_fround($170 - $173);
 $180 = Math_fround($169 - $174);
 $181 = Math_fround($175 - $168);
 $182 = Math_fround($172 + $171);
 $183 = Math_fround($170 + $173);
 $184 = Math_fround($172 - $171);
 $185 = Math_fround($175 - $167);
 HEAPF32[$0>>2] = $177;
 $186 = (($0) + 4|0);
 HEAPF32[$186>>2] = $178;
 $187 = (($0) + 8|0);
 HEAPF32[$187>>2] = $179;
 $188 = (($0) + 12|0);
 HEAPF32[$188>>2] = Math_fround(0.0);
 $189 = (($0) + 16|0);
 HEAPF32[$189>>2] = $180;
 $190 = (($0) + 20|0);
 HEAPF32[$190>>2] = $181;
 $191 = (($0) + 24|0);
 HEAPF32[$191>>2] = $182;
 $192 = (($0) + 28|0);
 HEAPF32[$192>>2] = Math_fround(0.0);
 $193 = (($0) + 32|0);
 HEAPF32[$193>>2] = $183;
 $194 = (($0) + 36|0);
 HEAPF32[$194>>2] = $184;
 $195 = (($0) + 40|0);
 HEAPF32[$195>>2] = $185;
 $196 = (($0) + 44|0);
 HEAPF32[$196>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $197 = (($transform0) + 16|0);
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = (($transform0) + 20|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = (($transform0) + 24|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($transform1) + 16|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = (($transform1) + 20|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = (($transform1) + 24|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = Math_fround($198 - $66);
 $210 = Math_fround($200 - $68);
 $211 = Math_fround($202 - $70);
 HEAPF32[$trA>>2] = $209;
 $212 = (($trA) + 4|0);
 HEAPF32[$212>>2] = $210;
 $213 = (($trA) + 8|0);
 HEAPF32[$213>>2] = $211;
 $214 = (($trA) + 12|0);
 HEAPF32[$214>>2] = Math_fround(0.0);
 $215 = Math_fround($204 - $79);
 $216 = Math_fround($206 - $81);
 $217 = Math_fround($208 - $83);
 $218 = Math_fround($215 - $209);
 $219 = Math_fround($216 - $210);
 $220 = Math_fround($217 - $211);
 $221 = Math_fround(HEAPF32[$convexTrans>>2]);
 $222 = Math_fround(HEAPF32[$84>>2]);
 $223 = Math_fround(HEAPF32[$85>>2]);
 $224 = Math_fround(HEAPF32[$86>>2]);
 $225 = Math_fround($224 * $224);
 $226 = Math_fround($225 + Math_fround(-0.5));
 $227 = Math_fround($218 * $226);
 $228 = Math_fround($219 * $226);
 $229 = Math_fround($220 * $226);
 $230 = Math_fround($220 * $222);
 $231 = Math_fround($219 * $223);
 $232 = Math_fround($230 - $231);
 $233 = Math_fround($218 * $223);
 $234 = Math_fround($221 * $220);
 $235 = Math_fround($233 - $234);
 $236 = Math_fround($219 * $221);
 $237 = Math_fround($218 * $222);
 $238 = Math_fround($236 - $237);
 $239 = Math_fround($224 * $232);
 $240 = Math_fround($224 * $235);
 $241 = Math_fround($224 * $238);
 $242 = Math_fround($227 - $239);
 $243 = Math_fround($228 - $240);
 $244 = Math_fround($229 - $241);
 $245 = Math_fround($218 * $221);
 $246 = Math_fround($219 * $222);
 $247 = Math_fround($245 + $246);
 $248 = Math_fround($220 * $223);
 $249 = Math_fround($247 + $248);
 $250 = Math_fround($221 * $249);
 $251 = Math_fround($222 * $249);
 $252 = Math_fround($223 * $249);
 $253 = Math_fround($250 + $242);
 $254 = Math_fround($251 + $243);
 $255 = Math_fround($252 + $244);
 $256 = Math_fround($253 * Math_fround(2.0));
 $257 = Math_fround($254 * Math_fround(2.0));
 $258 = Math_fround($255 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $256;
 $259 = (($relTr) + 4|0);
 HEAPF32[$259>>2] = $257;
 $260 = (($relTr) + 8|0);
 HEAPF32[$260>>2] = $258;
 $261 = (($relTr) + 12|0);
 HEAPF32[$261>>2] = Math_fround(0.0);
 $262 = Math_fround(HEAPF32[$3>>2]);
 $263 = Math_fround($262 + $restDistance);
 $264 = (__ZN5physx8CCDSweepINS_2Gu8CapsuleVENS1_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($capsule,$zero$sroa$1$i$i$i,$0,$convexTrans,$trA,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$263)|0);
 if (!($264)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $265 = Math_fround(HEAPF32[$lambda>>2]);
 $266 = Math_fround(HEAPF32[$normal>>2]);
 $267 = (($normal) + 4|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = (($normal) + 8|0);
 $270 = Math_fround(HEAPF32[$269>>2]);
 HEAPF32[$worldNormal>>2] = $266;
 $271 = (($worldNormal) + 4|0);
 HEAPF32[$271>>2] = $268;
 $272 = (($worldNormal) + 8|0);
 HEAPF32[$272>>2] = $270;
 $273 = Math_fround(HEAPF32[$closestA>>2]);
 $274 = (($closestA) + 4|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = (($closestA) + 8|0);
 $277 = Math_fround(HEAPF32[$276>>2]);
 HEAPF32[$worldPoint>>2] = $273;
 $278 = (($worldPoint) + 4|0);
 HEAPF32[$278>>2] = $275;
 $279 = (($worldPoint) + 8|0);
 HEAPF32[$279>>2] = $277;
 $$0 = $265;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx8CCDSweepINS_2Gu8CapsuleVENS1_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_8CapsuleVERNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx14PxcSweepBoxBoxERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$$i$i$i$i = Math_fround(0), $$$i$i$i$i23 = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i12$i$i$i22 = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i23$i$i$i21 = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$$i26$i$i$i20 = Math_fround(0), $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0;
 var $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0;
 var $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0;
 var $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0;
 var $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0;
 var $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $box0 = 0, $box1 = 0, $boxTrans1 = 0, $closestA = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trA = 0, $zero$sroa$1$i$i$i = 0;
 var $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 464|0;
 $zero$sroa$1$i$i$i = sp + 528|0;
 $zeroV = sp + 448|0;
 $box0 = sp + 288|0;
 $box1 = sp + 128|0;
 $boxTrans1 = sp + 96|0;
 $toi = sp + 80|0;
 $trA = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 64|0;
 $1 = HEAP32[$shape0>>2]|0;
 $2 = HEAP32[$shape1>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $3 = (($1) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 44|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 48|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($2) + 40|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($2) + 44|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($2) + 48|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($box0) + 64|0);
 ;HEAP32[$box0+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box0+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box0+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box0+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $16 = (($box0) + 80|0);
 HEAP32[$16>>2] = 3;
 $17 = (($box0) + 16|0);
 $18 = (($box0) + 20|0);
 ;HEAP32[$18+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $19 = (($box0) + 32|0);
 $20 = (($box0) + 36|0);
 $21 = (($box0) + 48|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($box0) + 52|0);
 ;HEAP32[$22+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$15+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$0+12>>2]|0;
 $23 = (($box0) + 144|0);
 HEAPF32[$23>>2] = $4;
 $24 = (($box0) + 148|0);
 HEAPF32[$24>>2] = $6;
 $25 = (($box0) + 152|0);
 HEAPF32[$25>>2] = $8;
 $26 = (($box0) + 156|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = !($4 <= $6);
 $$$i26$i$i$i20 = $27 ? $6 : $4;
 $28 = !($$$i26$i$i$i20 <= $8);
 $29 = $28 ? $8 : $$$i26$i$i$i20;
 $30 = !($4 >= $6);
 $$$i23$i$i$i21 = $30 ? $6 : $4;
 $31 = !($$$i23$i$i$i21 >= $8);
 $32 = $31 ? $8 : $$$i23$i$i$i21;
 $33 = Math_fround($29 * Math_fround(0.150000005960464477539));
 $34 = Math_fround($32 * Math_fround(0.0299999993294477462769));
 $35 = $33 > $34;
 $$$i12$i$i$i22 = $35 ? $33 : $34;
 $36 = $29 > $$$i12$i$i$i22;
 $$$i$i$i$i23 = $36 ? $$$i12$i$i$i22 : $29;
 HEAPF32[$17>>2] = $$$i$i$i$i23;
 ;HEAP32[$18+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $37 = Math_fround($29 * Math_fround(0.0500000007450580596924));
 HEAPF32[$19>>2] = $37;
 ;HEAP32[$20+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$0+8>>2]|0;
 $38 = (($box1) + 64|0);
 ;HEAP32[$box1+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box1+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box1+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box1+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $39 = (($box1) + 80|0);
 HEAP32[$39>>2] = 3;
 $40 = (($box1) + 16|0);
 $41 = (($box1) + 20|0);
 ;HEAP32[$41+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $42 = (($box1) + 32|0);
 $43 = (($box1) + 36|0);
 $44 = (($box1) + 48|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($box1) + 52|0);
 ;HEAP32[$45+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$38+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$0+12>>2]|0;
 $46 = (($box1) + 144|0);
 HEAPF32[$46>>2] = $10;
 $47 = (($box1) + 148|0);
 HEAPF32[$47>>2] = $12;
 $48 = (($box1) + 152|0);
 HEAPF32[$48>>2] = $14;
 $49 = (($box1) + 156|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = !($10 <= $12);
 $$$i26$i$i$i = $50 ? $12 : $10;
 $51 = !($$$i26$i$i$i <= $14);
 $52 = $51 ? $14 : $$$i26$i$i$i;
 $53 = !($10 >= $12);
 $$$i23$i$i$i = $53 ? $12 : $10;
 $54 = !($$$i23$i$i$i >= $14);
 $55 = $54 ? $14 : $$$i23$i$i$i;
 $56 = Math_fround($52 * Math_fround(0.150000005960464477539));
 $57 = Math_fround($55 * Math_fround(0.0299999993294477462769));
 $58 = $56 > $57;
 $$$i12$i$i$i = $58 ? $56 : $57;
 $59 = $52 > $$$i12$i$i$i;
 $$$i$i$i$i = $59 ? $$$i12$i$i$i : $52;
 HEAPF32[$40>>2] = $$$i$i$i$i;
 ;HEAP32[$41+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $60 = Math_fround($52 * Math_fround(0.0500000007450580596924));
 HEAPF32[$42>>2] = $60;
 ;HEAP32[$43+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$0+8>>2]|0;
 $61 = Math_fround(HEAPF32[$transform0>>2]);
 $62 = (($transform0) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($transform0) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($transform0) + 12|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($lastTm0) + 16|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($68) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($68) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround(HEAPF32[$transform1>>2]);
 $75 = (($transform1) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($transform1) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($transform1) + 12|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($lastTm1) + 16|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($81) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($81) + 8|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 HEAPF32[$boxTrans1>>2] = $74;
 $87 = (($boxTrans1) + 4|0);
 HEAPF32[$87>>2] = $76;
 $88 = (($boxTrans1) + 8|0);
 HEAPF32[$88>>2] = $78;
 $89 = (($boxTrans1) + 12|0);
 HEAPF32[$89>>2] = $80;
 $90 = (($boxTrans1) + 16|0);
 HEAPF32[$90>>2] = $82;
 $91 = (($boxTrans1) + 20|0);
 HEAPF32[$91>>2] = $84;
 $92 = (($boxTrans1) + 24|0);
 HEAPF32[$92>>2] = $86;
 $93 = (($boxTrans1) + 28|0);
 HEAPF32[$93>>2] = Math_fround(0.0);
 $94 = Math_fround(-$74);
 $95 = Math_fround(-$76);
 $96 = Math_fround(-$78);
 $97 = Math_fround($69 - $82);
 $98 = Math_fround($71 - $84);
 $99 = Math_fround($73 - $86);
 $100 = Math_fround($80 * $80);
 $101 = Math_fround($100 + Math_fround(-0.5));
 $102 = Math_fround($101 * $97);
 $103 = Math_fround($101 * $98);
 $104 = Math_fround($101 * $99);
 $105 = Math_fround($99 * $95);
 $106 = Math_fround($98 * $96);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($97 * $96);
 $109 = Math_fround($99 * $94);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($98 * $94);
 $112 = Math_fround($97 * $95);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($80 * $107);
 $115 = Math_fround($80 * $110);
 $116 = Math_fround($80 * $113);
 $117 = Math_fround($102 + $114);
 $118 = Math_fround($103 + $115);
 $119 = Math_fround($104 + $116);
 $120 = Math_fround($97 * $94);
 $121 = Math_fround($98 * $95);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($99 * $96);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($124 * $94);
 $126 = Math_fround($124 * $95);
 $127 = Math_fround($124 * $96);
 $128 = Math_fround($125 + $117);
 $129 = Math_fround($126 + $118);
 $130 = Math_fround($119 + $127);
 $131 = Math_fround($128 * Math_fround(2.0));
 $132 = Math_fround($129 * Math_fround(2.0));
 $133 = Math_fround($130 * Math_fround(2.0));
 $134 = Math_fround($67 * $80);
 $135 = Math_fround($61 * $94);
 $136 = Math_fround($63 * $95);
 $137 = Math_fround($135 + $136);
 $138 = Math_fround($65 * $96);
 $139 = Math_fround($137 + $138);
 $140 = Math_fround($134 - $139);
 $141 = Math_fround($67 * $94);
 $142 = Math_fround($67 * $95);
 $143 = Math_fround($67 * $96);
 $144 = Math_fround($61 * $80);
 $145 = Math_fround($63 * $80);
 $146 = Math_fround($65 * $80);
 $147 = Math_fround($65 * $95);
 $148 = Math_fround($63 * $96);
 $149 = Math_fround($147 - $148);
 $150 = Math_fround($61 * $96);
 $151 = Math_fround($65 * $94);
 $152 = Math_fround($150 - $151);
 $153 = Math_fround($63 * $94);
 $154 = Math_fround($61 * $95);
 $155 = Math_fround($153 - $154);
 $156 = Math_fround($141 + $144);
 $157 = Math_fround($142 + $145);
 $158 = Math_fround($146 + $143);
 $159 = Math_fround($149 + $156);
 $160 = Math_fround($152 + $157);
 $161 = Math_fround($155 + $158);
 $162 = (($0) + 48|0);
 HEAPF32[$162>>2] = $131;
 $163 = (($0) + 52|0);
 HEAPF32[$163>>2] = $132;
 $164 = (($0) + 56|0);
 HEAPF32[$164>>2] = $133;
 $165 = (($0) + 60|0);
 HEAPF32[$165>>2] = Math_fround(0.0);
 $166 = Math_fround($159 + $159);
 $167 = Math_fround($160 + $160);
 $168 = Math_fround($161 + $161);
 $169 = Math_fround($159 * $166);
 $170 = Math_fround($160 * $167);
 $171 = Math_fround($161 * $168);
 $172 = Math_fround($160 * $166);
 $173 = Math_fround($161 * $166);
 $174 = Math_fround($140 * $166);
 $175 = Math_fround($161 * $167);
 $176 = Math_fround($140 * $167);
 $177 = Math_fround($140 * $168);
 $178 = Math_fround(Math_fround(1.0) - $169);
 $179 = Math_fround(Math_fround(1.0) - $170);
 $180 = Math_fround($179 - $171);
 $181 = Math_fround($172 + $177);
 $182 = Math_fround($173 - $176);
 $183 = Math_fround($172 - $177);
 $184 = Math_fround($178 - $171);
 $185 = Math_fround($175 + $174);
 $186 = Math_fround($173 + $176);
 $187 = Math_fround($175 - $174);
 $188 = Math_fround($178 - $170);
 HEAPF32[$0>>2] = $180;
 $189 = (($0) + 4|0);
 HEAPF32[$189>>2] = $181;
 $190 = (($0) + 8|0);
 HEAPF32[$190>>2] = $182;
 $191 = (($0) + 12|0);
 HEAPF32[$191>>2] = Math_fround(0.0);
 $192 = (($0) + 16|0);
 HEAPF32[$192>>2] = $183;
 $193 = (($0) + 20|0);
 HEAPF32[$193>>2] = $184;
 $194 = (($0) + 24|0);
 HEAPF32[$194>>2] = $185;
 $195 = (($0) + 28|0);
 HEAPF32[$195>>2] = Math_fround(0.0);
 $196 = (($0) + 32|0);
 HEAPF32[$196>>2] = $186;
 $197 = (($0) + 36|0);
 HEAPF32[$197>>2] = $187;
 $198 = (($0) + 40|0);
 HEAPF32[$198>>2] = $188;
 $199 = (($0) + 44|0);
 HEAPF32[$199>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $200 = (($transform0) + 16|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = (($transform0) + 20|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = (($transform0) + 24|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($transform1) + 16|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = (($transform1) + 20|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = (($transform1) + 24|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = Math_fround($201 - $69);
 $213 = Math_fround($203 - $71);
 $214 = Math_fround($205 - $73);
 HEAPF32[$trA>>2] = $212;
 $215 = (($trA) + 4|0);
 HEAPF32[$215>>2] = $213;
 $216 = (($trA) + 8|0);
 HEAPF32[$216>>2] = $214;
 $217 = (($trA) + 12|0);
 HEAPF32[$217>>2] = Math_fround(0.0);
 $218 = Math_fround($207 - $82);
 $219 = Math_fround($209 - $84);
 $220 = Math_fround($211 - $86);
 $221 = Math_fround($218 - $212);
 $222 = Math_fround($219 - $213);
 $223 = Math_fround($220 - $214);
 $224 = Math_fround(HEAPF32[$boxTrans1>>2]);
 $225 = Math_fround(HEAPF32[$87>>2]);
 $226 = Math_fround(HEAPF32[$88>>2]);
 $227 = Math_fround(HEAPF32[$89>>2]);
 $228 = Math_fround($227 * $227);
 $229 = Math_fround($228 + Math_fround(-0.5));
 $230 = Math_fround($221 * $229);
 $231 = Math_fround($222 * $229);
 $232 = Math_fround($223 * $229);
 $233 = Math_fround($223 * $225);
 $234 = Math_fround($222 * $226);
 $235 = Math_fround($233 - $234);
 $236 = Math_fround($221 * $226);
 $237 = Math_fround($224 * $223);
 $238 = Math_fround($236 - $237);
 $239 = Math_fround($222 * $224);
 $240 = Math_fround($221 * $225);
 $241 = Math_fround($239 - $240);
 $242 = Math_fround($227 * $235);
 $243 = Math_fround($227 * $238);
 $244 = Math_fround($227 * $241);
 $245 = Math_fround($230 - $242);
 $246 = Math_fround($231 - $243);
 $247 = Math_fround($232 - $244);
 $248 = Math_fround($221 * $224);
 $249 = Math_fround($222 * $225);
 $250 = Math_fround($248 + $249);
 $251 = Math_fround($223 * $226);
 $252 = Math_fround($250 + $251);
 $253 = Math_fround($224 * $252);
 $254 = Math_fround($225 * $252);
 $255 = Math_fround($226 * $252);
 $256 = Math_fround($253 + $245);
 $257 = Math_fround($254 + $246);
 $258 = Math_fround($255 + $247);
 $259 = Math_fround($256 * Math_fround(2.0));
 $260 = Math_fround($257 * Math_fround(2.0));
 $261 = Math_fround($258 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $259;
 $262 = (($relTr) + 4|0);
 HEAPF32[$262>>2] = $260;
 $263 = (($relTr) + 8|0);
 HEAPF32[$263>>2] = $261;
 $264 = (($relTr) + 12|0);
 HEAPF32[$264>>2] = Math_fround(0.0);
 $265 = (__ZN5physx8CCDSweepINS_2Gu4BoxVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVERKNS8_5Vec3VERKNS8_6FloatVESH_SH_RSI_RSF_SM_f($box0,$box1,$0,$boxTrans1,$trA,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$restDistance)|0);
 if (!($265)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $266 = Math_fround(HEAPF32[$lambda>>2]);
 $267 = Math_fround(HEAPF32[$normal>>2]);
 $268 = (($normal) + 4|0);
 $269 = Math_fround(HEAPF32[$268>>2]);
 $270 = (($normal) + 8|0);
 $271 = Math_fround(HEAPF32[$270>>2]);
 HEAPF32[$worldNormal>>2] = $267;
 $272 = (($worldNormal) + 4|0);
 HEAPF32[$272>>2] = $269;
 $273 = (($worldNormal) + 8|0);
 HEAPF32[$273>>2] = $271;
 $274 = Math_fround(HEAPF32[$closestA>>2]);
 $275 = (($closestA) + 4|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 $277 = (($closestA) + 8|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 HEAPF32[$worldPoint>>2] = $274;
 $279 = (($worldPoint) + 4|0);
 HEAPF32[$279>>2] = $276;
 $280 = (($worldPoint) + 8|0);
 HEAPF32[$280>>2] = $278;
 $$0 = $266;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx8CCDSweepINS_2Gu4BoxVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVERKNS8_5Vec3VERKNS8_6FloatVESH_SH_RSI_RSF_SM_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_4BoxVES2_RKNS_6shdfnd3aos15PsMatTransformVERKNS4_6FloatVERKNS4_5Vec3VESD_RS8_RSB_SF_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17PxcSweepBoxConvexERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = Math_fround(0), $$sroa$1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = 0;
 var $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0;
 var $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $box = 0;
 var $closestA = 0, $convexTrans = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trA = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $$sroa$1$i$i$i = sp + 400|0;
 $zero$sroa$1$i$i$i = sp + 336|0;
 $zeroV = sp + 320|0;
 $vScale = sp + 304|0;
 $vQuat = sp + 288|0;
 $box = sp + 128|0;
 $convexTrans = sp + 96|0;
 $toi = sp + 64|0;
 $trA = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 80|0;
 $0 = HEAP32[$shape0>>2]|0;
 $1 = HEAP32[$shape1>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $2 = (($1) + 40|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 44|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 48|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$vScale>>2] = $3;
 $8 = (($vScale) + 4|0);
 HEAPF32[$8>>2] = $5;
 $9 = (($vScale) + 8|0);
 HEAPF32[$9>>2] = $7;
 $10 = (($vScale) + 12|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($1) + 52|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($1) + 56|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($1) + 60|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($1) + 64|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$vQuat>>2] = $12;
 $19 = (($vQuat) + 4|0);
 HEAPF32[$19>>2] = $14;
 $20 = (($vQuat) + 8|0);
 HEAPF32[$20>>2] = $16;
 $21 = (($vQuat) + 12|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($0) + 40|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($0) + 44|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($0) + 48|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($1) + 72|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($box) + 64|0);
 ;HEAP32[$box+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $31 = (($box) + 80|0);
 HEAP32[$31>>2] = 3;
 $32 = (($box) + 16|0);
 $33 = (($box) + 20|0);
 ;HEAP32[$33+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $34 = (($box) + 32|0);
 $35 = (($box) + 36|0);
 $36 = (($box) + 48|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($box) + 52|0);
 ;HEAP32[$37+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$30+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $38 = (($box) + 144|0);
 HEAPF32[$38>>2] = $23;
 $39 = (($box) + 148|0);
 HEAPF32[$39>>2] = $25;
 $40 = (($box) + 152|0);
 HEAPF32[$40>>2] = $27;
 $41 = (($box) + 156|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = !($23 <= $25);
 $$$i26$i$i$i = $42 ? $25 : $23;
 $43 = !($$$i26$i$i$i <= $27);
 $44 = $43 ? $27 : $$$i26$i$i$i;
 $45 = !($23 >= $25);
 $$$i23$i$i$i = $45 ? $25 : $23;
 $46 = !($$$i23$i$i$i >= $27);
 $47 = $46 ? $27 : $$$i23$i$i$i;
 $48 = Math_fround($44 * Math_fround(0.150000005960464477539));
 $49 = Math_fround($47 * Math_fround(0.0299999993294477462769));
 $50 = $48 > $49;
 $$$i12$i$i$i = $50 ? $48 : $49;
 $51 = $44 > $$$i12$i$i$i;
 $$$i$i$i$i = $51 ? $$$i12$i$i$i : $44;
 HEAPF32[$32>>2] = $$$i$i$i$i;
 ;HEAP32[$33+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $52 = Math_fround($44 * Math_fround(0.0500000007450580596924));
 HEAPF32[$34>>2] = $52;
 ;HEAP32[$35+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($$sroa$1$i$i$i,$29,$zeroV,$vScale,$vQuat);
 $53 = Math_fround(HEAPF32[$transform0>>2]);
 $54 = (($transform0) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($transform0) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($transform0) + 12|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($lastTm0) + 16|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($60) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($60) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround(HEAPF32[$transform1>>2]);
 $67 = (($transform1) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($transform1) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($transform1) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($lastTm1) + 16|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($73) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($73) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 HEAPF32[$convexTrans>>2] = $66;
 $79 = (($convexTrans) + 4|0);
 HEAPF32[$79>>2] = $68;
 $80 = (($convexTrans) + 8|0);
 HEAPF32[$80>>2] = $70;
 $81 = (($convexTrans) + 12|0);
 HEAPF32[$81>>2] = $72;
 $82 = (($convexTrans) + 16|0);
 HEAPF32[$82>>2] = $74;
 $83 = (($convexTrans) + 20|0);
 HEAPF32[$83>>2] = $76;
 $84 = (($convexTrans) + 24|0);
 HEAPF32[$84>>2] = $78;
 $85 = (($convexTrans) + 28|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 $86 = Math_fround(-$66);
 $87 = Math_fround(-$68);
 $88 = Math_fround(-$70);
 $89 = Math_fround($61 - $74);
 $90 = Math_fround($63 - $76);
 $91 = Math_fround($65 - $78);
 $92 = Math_fround($72 * $72);
 $93 = Math_fround($92 + Math_fround(-0.5));
 $94 = Math_fround($93 * $89);
 $95 = Math_fround($93 * $90);
 $96 = Math_fround($93 * $91);
 $97 = Math_fround($91 * $87);
 $98 = Math_fround($90 * $88);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($89 * $88);
 $101 = Math_fround($91 * $86);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($90 * $86);
 $104 = Math_fround($89 * $87);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($72 * $99);
 $107 = Math_fround($72 * $102);
 $108 = Math_fround($72 * $105);
 $109 = Math_fround($94 + $106);
 $110 = Math_fround($95 + $107);
 $111 = Math_fround($96 + $108);
 $112 = Math_fround($89 * $86);
 $113 = Math_fround($90 * $87);
 $114 = Math_fround($112 + $113);
 $115 = Math_fround($91 * $88);
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($116 * $86);
 $118 = Math_fround($116 * $87);
 $119 = Math_fround($116 * $88);
 $120 = Math_fround($117 + $109);
 $121 = Math_fround($118 + $110);
 $122 = Math_fround($111 + $119);
 $123 = Math_fround($120 * Math_fround(2.0));
 $124 = Math_fround($121 * Math_fround(2.0));
 $125 = Math_fround($122 * Math_fround(2.0));
 $126 = Math_fround($59 * $72);
 $127 = Math_fround($53 * $86);
 $128 = Math_fround($55 * $87);
 $129 = Math_fround($127 + $128);
 $130 = Math_fround($57 * $88);
 $131 = Math_fround($129 + $130);
 $132 = Math_fround($126 - $131);
 $133 = Math_fround($59 * $86);
 $134 = Math_fround($59 * $87);
 $135 = Math_fround($59 * $88);
 $136 = Math_fround($53 * $72);
 $137 = Math_fround($55 * $72);
 $138 = Math_fround($57 * $72);
 $139 = Math_fround($57 * $87);
 $140 = Math_fround($55 * $88);
 $141 = Math_fround($139 - $140);
 $142 = Math_fround($53 * $88);
 $143 = Math_fround($57 * $86);
 $144 = Math_fround($142 - $143);
 $145 = Math_fround($55 * $86);
 $146 = Math_fround($53 * $87);
 $147 = Math_fround($145 - $146);
 $148 = Math_fround($133 + $136);
 $149 = Math_fround($134 + $137);
 $150 = Math_fround($138 + $135);
 $151 = Math_fround($141 + $148);
 $152 = Math_fround($144 + $149);
 $153 = Math_fround($147 + $150);
 $154 = (($zero$sroa$1$i$i$i) + 48|0);
 HEAPF32[$154>>2] = $123;
 $155 = (($zero$sroa$1$i$i$i) + 52|0);
 HEAPF32[$155>>2] = $124;
 $156 = (($zero$sroa$1$i$i$i) + 56|0);
 HEAPF32[$156>>2] = $125;
 $157 = (($zero$sroa$1$i$i$i) + 60|0);
 HEAPF32[$157>>2] = Math_fround(0.0);
 $158 = Math_fround($151 + $151);
 $159 = Math_fround($152 + $152);
 $160 = Math_fround($153 + $153);
 $161 = Math_fround($151 * $158);
 $162 = Math_fround($152 * $159);
 $163 = Math_fround($153 * $160);
 $164 = Math_fround($152 * $158);
 $165 = Math_fround($153 * $158);
 $166 = Math_fround($132 * $158);
 $167 = Math_fround($153 * $159);
 $168 = Math_fround($132 * $159);
 $169 = Math_fround($132 * $160);
 $170 = Math_fround(Math_fround(1.0) - $161);
 $171 = Math_fround(Math_fround(1.0) - $162);
 $172 = Math_fround($171 - $163);
 $173 = Math_fround($164 + $169);
 $174 = Math_fround($165 - $168);
 $175 = Math_fround($164 - $169);
 $176 = Math_fround($170 - $163);
 $177 = Math_fround($167 + $166);
 $178 = Math_fround($165 + $168);
 $179 = Math_fround($167 - $166);
 $180 = Math_fround($170 - $162);
 HEAPF32[$zero$sroa$1$i$i$i>>2] = $172;
 $181 = (($zero$sroa$1$i$i$i) + 4|0);
 HEAPF32[$181>>2] = $173;
 $182 = (($zero$sroa$1$i$i$i) + 8|0);
 HEAPF32[$182>>2] = $174;
 $183 = (($zero$sroa$1$i$i$i) + 12|0);
 HEAPF32[$183>>2] = Math_fround(0.0);
 $184 = (($zero$sroa$1$i$i$i) + 16|0);
 HEAPF32[$184>>2] = $175;
 $185 = (($zero$sroa$1$i$i$i) + 20|0);
 HEAPF32[$185>>2] = $176;
 $186 = (($zero$sroa$1$i$i$i) + 24|0);
 HEAPF32[$186>>2] = $177;
 $187 = (($zero$sroa$1$i$i$i) + 28|0);
 HEAPF32[$187>>2] = Math_fround(0.0);
 $188 = (($zero$sroa$1$i$i$i) + 32|0);
 HEAPF32[$188>>2] = $178;
 $189 = (($zero$sroa$1$i$i$i) + 36|0);
 HEAPF32[$189>>2] = $179;
 $190 = (($zero$sroa$1$i$i$i) + 40|0);
 HEAPF32[$190>>2] = $180;
 $191 = (($zero$sroa$1$i$i$i) + 44|0);
 HEAPF32[$191>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $192 = (($transform0) + 16|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($transform0) + 20|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = (($transform0) + 24|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = (($transform1) + 16|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($transform1) + 20|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = (($transform1) + 24|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = Math_fround($193 - $61);
 $205 = Math_fround($195 - $63);
 $206 = Math_fround($197 - $65);
 HEAPF32[$trA>>2] = $204;
 $207 = (($trA) + 4|0);
 HEAPF32[$207>>2] = $205;
 $208 = (($trA) + 8|0);
 HEAPF32[$208>>2] = $206;
 $209 = (($trA) + 12|0);
 HEAPF32[$209>>2] = Math_fround(0.0);
 $210 = Math_fround($199 - $74);
 $211 = Math_fround($201 - $76);
 $212 = Math_fround($203 - $78);
 $213 = Math_fround($210 - $204);
 $214 = Math_fround($211 - $205);
 $215 = Math_fround($212 - $206);
 $216 = Math_fround(HEAPF32[$convexTrans>>2]);
 $217 = Math_fround(HEAPF32[$79>>2]);
 $218 = Math_fround(HEAPF32[$80>>2]);
 $219 = Math_fround(HEAPF32[$81>>2]);
 $220 = Math_fround($219 * $219);
 $221 = Math_fround($220 + Math_fround(-0.5));
 $222 = Math_fround($213 * $221);
 $223 = Math_fround($214 * $221);
 $224 = Math_fround($215 * $221);
 $225 = Math_fround($215 * $217);
 $226 = Math_fround($214 * $218);
 $227 = Math_fround($225 - $226);
 $228 = Math_fround($213 * $218);
 $229 = Math_fround($216 * $215);
 $230 = Math_fround($228 - $229);
 $231 = Math_fround($214 * $216);
 $232 = Math_fround($213 * $217);
 $233 = Math_fround($231 - $232);
 $234 = Math_fround($219 * $227);
 $235 = Math_fround($219 * $230);
 $236 = Math_fround($219 * $233);
 $237 = Math_fround($222 - $234);
 $238 = Math_fround($223 - $235);
 $239 = Math_fround($224 - $236);
 $240 = Math_fround($213 * $216);
 $241 = Math_fround($214 * $217);
 $242 = Math_fround($240 + $241);
 $243 = Math_fround($215 * $218);
 $244 = Math_fround($242 + $243);
 $245 = Math_fround($216 * $244);
 $246 = Math_fround($217 * $244);
 $247 = Math_fround($218 * $244);
 $248 = Math_fround($245 + $237);
 $249 = Math_fround($246 + $238);
 $250 = Math_fround($247 + $239);
 $251 = Math_fround($248 * Math_fround(2.0));
 $252 = Math_fround($249 * Math_fround(2.0));
 $253 = Math_fround($250 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $251;
 $254 = (($relTr) + 4|0);
 HEAPF32[$254>>2] = $252;
 $255 = (($relTr) + 8|0);
 HEAPF32[$255>>2] = $253;
 $256 = (($relTr) + 12|0);
 HEAPF32[$256>>2] = Math_fround(0.0);
 $257 = (__ZN5physx8CCDSweepINS_2Gu4BoxVENS1_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($box,$$sroa$1$i$i$i,$zero$sroa$1$i$i$i,$convexTrans,$trA,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$restDistance)|0);
 if (!($257)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $258 = Math_fround(HEAPF32[$lambda>>2]);
 $259 = Math_fround(HEAPF32[$normal>>2]);
 $260 = (($normal) + 4|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = (($normal) + 8|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 HEAPF32[$worldNormal>>2] = $259;
 $264 = (($worldNormal) + 4|0);
 HEAPF32[$264>>2] = $261;
 $265 = (($worldNormal) + 8|0);
 HEAPF32[$265>>2] = $263;
 $266 = Math_fround(HEAPF32[$closestA>>2]);
 $267 = (($closestA) + 4|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = (($closestA) + 8|0);
 $270 = Math_fround(HEAPF32[$269>>2]);
 HEAPF32[$worldPoint>>2] = $266;
 $271 = (($worldPoint) + 4|0);
 HEAPF32[$271>>2] = $268;
 $272 = (($worldPoint) + 8|0);
 HEAPF32[$272>>2] = $270;
 $$0 = $258;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx8CCDSweepINS_2Gu4BoxVENS1_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_4BoxVERNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx20PxcSweepConvexConvexERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0;
 var $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = Math_fround(0);
 var $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0);
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0);
 var $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $closestA = 0, $convexHull0 = 0, $convexHull1 = 0, $convexTrans1 = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trA = 0, $vQuat0 = 0, $vQuat1 = 0, $vScale0 = 0;
 var $vScale1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 688|0;
 $zeroV = sp + 672|0;
 $vScale0 = sp + 656|0;
 $vQuat0 = sp + 640|0;
 $vScale1 = sp + 624|0;
 $vQuat1 = sp + 608|0;
 $convexHull0 = sp + 400|0;
 $convexHull1 = sp + 192|0;
 $convexTrans1 = sp + 160|0;
 $aToB = sp + 80|0;
 $toi = sp + 64|0;
 $trA = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 144|0;
 $0 = HEAP32[$shape0>>2]|0;
 $1 = HEAP32[$shape1>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $2 = (($0) + 40|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($0) + 44|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($0) + 48|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$vScale0>>2] = $3;
 $8 = (($vScale0) + 4|0);
 HEAPF32[$8>>2] = $5;
 $9 = (($vScale0) + 8|0);
 HEAPF32[$9>>2] = $7;
 $10 = (($vScale0) + 12|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($0) + 52|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($0) + 56|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($0) + 60|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($0) + 64|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$vQuat0>>2] = $12;
 $19 = (($vQuat0) + 4|0);
 HEAPF32[$19>>2] = $14;
 $20 = (($vQuat0) + 8|0);
 HEAPF32[$20>>2] = $16;
 $21 = (($vQuat0) + 12|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($1) + 40|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($1) + 44|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($1) + 48|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$vScale1>>2] = $23;
 $28 = (($vScale1) + 4|0);
 HEAPF32[$28>>2] = $25;
 $29 = (($vScale1) + 8|0);
 HEAPF32[$29>>2] = $27;
 $30 = (($vScale1) + 12|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($1) + 52|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($1) + 56|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($1) + 60|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($1) + 64|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 HEAPF32[$vQuat1>>2] = $32;
 $39 = (($vQuat1) + 4|0);
 HEAPF32[$39>>2] = $34;
 $40 = (($vQuat1) + 8|0);
 HEAPF32[$40>>2] = $36;
 $41 = (($vQuat1) + 12|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($0) + 72|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($1) + 72|0);
 $45 = HEAP32[$44>>2]|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull0,$43,$zeroV,$vScale0,$vQuat0);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull1,$45,$zeroV,$vScale1,$vQuat1);
 $46 = Math_fround(HEAPF32[$transform0>>2]);
 $47 = (($transform0) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($transform0) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($transform0) + 12|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($lastTm0) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($53) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($53) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround(HEAPF32[$transform1>>2]);
 $60 = (($transform1) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($transform1) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($transform1) + 12|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($lastTm1) + 16|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($66) + 4|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($66) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 HEAPF32[$convexTrans1>>2] = $59;
 $72 = (($convexTrans1) + 4|0);
 HEAPF32[$72>>2] = $61;
 $73 = (($convexTrans1) + 8|0);
 HEAPF32[$73>>2] = $63;
 $74 = (($convexTrans1) + 12|0);
 HEAPF32[$74>>2] = $65;
 $75 = (($convexTrans1) + 16|0);
 HEAPF32[$75>>2] = $67;
 $76 = (($convexTrans1) + 20|0);
 HEAPF32[$76>>2] = $69;
 $77 = (($convexTrans1) + 24|0);
 HEAPF32[$77>>2] = $71;
 $78 = (($convexTrans1) + 28|0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = Math_fround(-$59);
 $80 = Math_fround(-$61);
 $81 = Math_fround(-$63);
 $82 = Math_fround($54 - $67);
 $83 = Math_fround($56 - $69);
 $84 = Math_fround($58 - $71);
 $85 = Math_fround($65 * $65);
 $86 = Math_fround($85 + Math_fround(-0.5));
 $87 = Math_fround($86 * $82);
 $88 = Math_fround($86 * $83);
 $89 = Math_fround($86 * $84);
 $90 = Math_fround($84 * $80);
 $91 = Math_fround($83 * $81);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($82 * $81);
 $94 = Math_fround($84 * $79);
 $95 = Math_fround($93 - $94);
 $96 = Math_fround($83 * $79);
 $97 = Math_fround($82 * $80);
 $98 = Math_fround($96 - $97);
 $99 = Math_fround($65 * $92);
 $100 = Math_fround($65 * $95);
 $101 = Math_fround($65 * $98);
 $102 = Math_fround($87 + $99);
 $103 = Math_fround($88 + $100);
 $104 = Math_fround($89 + $101);
 $105 = Math_fround($82 * $79);
 $106 = Math_fround($83 * $80);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($84 * $81);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($109 * $79);
 $111 = Math_fround($109 * $80);
 $112 = Math_fround($109 * $81);
 $113 = Math_fround($110 + $102);
 $114 = Math_fround($111 + $103);
 $115 = Math_fround($104 + $112);
 $116 = Math_fround($113 * Math_fround(2.0));
 $117 = Math_fround($114 * Math_fround(2.0));
 $118 = Math_fround($115 * Math_fround(2.0));
 $119 = Math_fround($52 * $65);
 $120 = Math_fround($46 * $79);
 $121 = Math_fround($48 * $80);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($50 * $81);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($119 - $124);
 $126 = Math_fround($52 * $79);
 $127 = Math_fround($52 * $80);
 $128 = Math_fround($52 * $81);
 $129 = Math_fround($46 * $65);
 $130 = Math_fround($48 * $65);
 $131 = Math_fround($50 * $65);
 $132 = Math_fround($50 * $80);
 $133 = Math_fround($48 * $81);
 $134 = Math_fround($132 - $133);
 $135 = Math_fround($46 * $81);
 $136 = Math_fround($50 * $79);
 $137 = Math_fround($135 - $136);
 $138 = Math_fround($48 * $79);
 $139 = Math_fround($46 * $80);
 $140 = Math_fround($138 - $139);
 $141 = Math_fround($126 + $129);
 $142 = Math_fround($127 + $130);
 $143 = Math_fround($131 + $128);
 $144 = Math_fround($134 + $141);
 $145 = Math_fround($137 + $142);
 $146 = Math_fround($140 + $143);
 $147 = (($aToB) + 48|0);
 HEAPF32[$147>>2] = $116;
 $148 = (($aToB) + 52|0);
 HEAPF32[$148>>2] = $117;
 $149 = (($aToB) + 56|0);
 HEAPF32[$149>>2] = $118;
 $150 = (($aToB) + 60|0);
 HEAPF32[$150>>2] = Math_fround(0.0);
 $151 = Math_fround($144 + $144);
 $152 = Math_fround($145 + $145);
 $153 = Math_fround($146 + $146);
 $154 = Math_fround($144 * $151);
 $155 = Math_fround($145 * $152);
 $156 = Math_fround($146 * $153);
 $157 = Math_fround($145 * $151);
 $158 = Math_fround($146 * $151);
 $159 = Math_fround($125 * $151);
 $160 = Math_fround($146 * $152);
 $161 = Math_fround($125 * $152);
 $162 = Math_fround($125 * $153);
 $163 = Math_fround(Math_fround(1.0) - $154);
 $164 = Math_fround(Math_fround(1.0) - $155);
 $165 = Math_fround($164 - $156);
 $166 = Math_fround($157 + $162);
 $167 = Math_fround($158 - $161);
 $168 = Math_fround($157 - $162);
 $169 = Math_fround($163 - $156);
 $170 = Math_fround($160 + $159);
 $171 = Math_fround($158 + $161);
 $172 = Math_fround($160 - $159);
 $173 = Math_fround($163 - $155);
 HEAPF32[$aToB>>2] = $165;
 $174 = (($aToB) + 4|0);
 HEAPF32[$174>>2] = $166;
 $175 = (($aToB) + 8|0);
 HEAPF32[$175>>2] = $167;
 $176 = (($aToB) + 12|0);
 HEAPF32[$176>>2] = Math_fround(0.0);
 $177 = (($aToB) + 16|0);
 HEAPF32[$177>>2] = $168;
 $178 = (($aToB) + 20|0);
 HEAPF32[$178>>2] = $169;
 $179 = (($aToB) + 24|0);
 HEAPF32[$179>>2] = $170;
 $180 = (($aToB) + 28|0);
 HEAPF32[$180>>2] = Math_fround(0.0);
 $181 = (($aToB) + 32|0);
 HEAPF32[$181>>2] = $171;
 $182 = (($aToB) + 36|0);
 HEAPF32[$182>>2] = $172;
 $183 = (($aToB) + 40|0);
 HEAPF32[$183>>2] = $173;
 $184 = (($aToB) + 44|0);
 HEAPF32[$184>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $185 = (($transform0) + 16|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($transform0) + 20|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($transform0) + 24|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($transform1) + 16|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($transform1) + 20|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($transform1) + 24|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = Math_fround($186 - $54);
 $198 = Math_fround($188 - $56);
 $199 = Math_fround($190 - $58);
 HEAPF32[$trA>>2] = $197;
 $200 = (($trA) + 4|0);
 HEAPF32[$200>>2] = $198;
 $201 = (($trA) + 8|0);
 HEAPF32[$201>>2] = $199;
 $202 = (($trA) + 12|0);
 HEAPF32[$202>>2] = Math_fround(0.0);
 $203 = Math_fround($192 - $67);
 $204 = Math_fround($194 - $69);
 $205 = Math_fround($196 - $71);
 $206 = Math_fround($203 - $197);
 $207 = Math_fround($204 - $198);
 $208 = Math_fround($205 - $199);
 $209 = Math_fround(HEAPF32[$convexTrans1>>2]);
 $210 = Math_fround(HEAPF32[$72>>2]);
 $211 = Math_fround(HEAPF32[$73>>2]);
 $212 = Math_fround(HEAPF32[$74>>2]);
 $213 = Math_fround($212 * $212);
 $214 = Math_fround($213 + Math_fround(-0.5));
 $215 = Math_fround($206 * $214);
 $216 = Math_fround($207 * $214);
 $217 = Math_fround($208 * $214);
 $218 = Math_fround($208 * $210);
 $219 = Math_fround($207 * $211);
 $220 = Math_fround($218 - $219);
 $221 = Math_fround($206 * $211);
 $222 = Math_fround($209 * $208);
 $223 = Math_fround($221 - $222);
 $224 = Math_fround($207 * $209);
 $225 = Math_fround($206 * $210);
 $226 = Math_fround($224 - $225);
 $227 = Math_fround($212 * $220);
 $228 = Math_fround($212 * $223);
 $229 = Math_fround($212 * $226);
 $230 = Math_fround($215 - $227);
 $231 = Math_fround($216 - $228);
 $232 = Math_fround($217 - $229);
 $233 = Math_fround($206 * $209);
 $234 = Math_fround($207 * $210);
 $235 = Math_fround($233 + $234);
 $236 = Math_fround($208 * $211);
 $237 = Math_fround($235 + $236);
 $238 = Math_fround($209 * $237);
 $239 = Math_fround($210 * $237);
 $240 = Math_fround($211 * $237);
 $241 = Math_fround($238 + $230);
 $242 = Math_fround($239 + $231);
 $243 = Math_fround($240 + $232);
 $244 = Math_fround($241 * Math_fround(2.0));
 $245 = Math_fround($242 * Math_fround(2.0));
 $246 = Math_fround($243 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $244;
 $247 = (($relTr) + 4|0);
 HEAPF32[$247>>2] = $245;
 $248 = (($relTr) + 8|0);
 HEAPF32[$248>>2] = $246;
 $249 = (($relTr) + 12|0);
 HEAPF32[$249>>2] = Math_fround(0.0);
 $250 = (__ZN5physx8CCDSweepINS_2Gu11ConvexHullVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVERKNS8_5Vec3VERKNS8_6FloatVESH_SH_RSI_RSF_SM_f($convexHull0,$convexHull1,$aToB,$convexTrans1,$trA,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$restDistance)|0);
 if (!($250)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $251 = Math_fround(HEAPF32[$lambda>>2]);
 $252 = Math_fround(HEAPF32[$normal>>2]);
 $253 = (($normal) + 4|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = (($normal) + 8|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 HEAPF32[$worldNormal>>2] = $252;
 $257 = (($worldNormal) + 4|0);
 HEAPF32[$257>>2] = $254;
 $258 = (($worldNormal) + 8|0);
 HEAPF32[$258>>2] = $256;
 $259 = Math_fround(HEAPF32[$closestA>>2]);
 $260 = (($closestA) + 4|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = (($closestA) + 8|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 HEAPF32[$worldPoint>>2] = $259;
 $264 = (($worldPoint) + 4|0);
 HEAPF32[$264>>2] = $261;
 $265 = (($worldPoint) + 8|0);
 HEAPF32[$265>>2] = $263;
 $$0 = $251;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx8CCDSweepINS_2Gu11ConvexHullVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVERKNS8_5Vec3VERKNS8_6FloatVESH_SH_RSI_RSF_SM_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_11ConvexHullVES2_RKNS_6shdfnd3aos15PsMatTransformVERKNS4_6FloatVERKNS4_5Vec3VESD_RS8_RSB_SF_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx18PxcSweepConvexMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZN5physxL20PxcSweepAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextE($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$restDistance,$worldNormal,$worldPoint,$cache,$context)));
 STACKTOP = sp;return (Math_fround($0));
}
function __ZN5physxL20PxcSweepAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextE($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$restDistance,$worldNormal,$worldPoint,$cache,$context) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 var $$0 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa31 = Math_fround(0), $$lcssa32 = Math_fround(0), $$lcssa33 = Math_fround(0), $$lcssa34 = Math_fround(0), $$lcssa35 = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert63 = 0, $$phi$trans$insert65 = 0, $$pre = Math_fround(0), $$pre$i = 0, $$pre$i3 = 0, $$pre64 = Math_fround(0), $$pre66 = Math_fround(0), $$pre67 = Math_fround(0), $$pre68 = Math_fround(0), $$pre69 = Math_fround(0), $$pre70 = Math_fround(0), $$sroa$1$i$i = 0;
 var $$sroa$113$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = 0;
 var $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = 0;
 var $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0);
 var $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = 0;
 var $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = 0;
 var $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0;
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = Math_fround(0), $330 = 0;
 var $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0);
 var $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = 0, $456 = Math_fround(0), $457 = Math_fround(0);
 var $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0);
 var $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0);
 var $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0);
 var $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = Math_fround(0), $617 = 0, $618 = 0, $619 = 0;
 var $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0;
 var $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = Math_fround(0), $652 = 0, $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0);
 var $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = 0, $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = 0, $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0);
 var $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = 0, $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = 0, $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0);
 var $692 = Math_fround(0), $693 = Math_fround(0), $694 = 0, $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = 0, $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = 0, $708 = Math_fround(0), $709 = Math_fround(0);
 var $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = 0, $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0);
 var $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = 0, $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = Math_fround(0), $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0);
 var $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = Math_fround(0), $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0);
 var $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = 0, $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0);
 var $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = 0, $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = 0, $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = 0, $8 = 0;
 var $80 = Math_fround(0), $800 = 0, $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0);
 var $818 = Math_fround(0), $819 = Math_fround(0), $82 = Math_fround(0), $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0);
 var $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = 0, $84 = Math_fround(0), $840 = 0, $841 = 0, $842 = 0, $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0);
 var $854 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $a$049 = 0, $b$044 = 0, $callback = 0, $convexPartOfMesh12 = 0;
 var $count$050 = 0, $count$1 = 0, $cp$i = 0, $distanceEntries = 0, $exitcond = 0, $exitcond62 = 0, $extent = 0, $hmd = 0, $index$0 = 0, $lastTransform0 = 0, $lastTransform1 = 0, $matRot = 0, $meshScaling = 0, $minTOI$0$lcssa = Math_fround(0), $minTOI$037 = Math_fround(0), $minTOI$1 = Math_fround(0), $orderedContainer = 0, $origin = 0, $res$0 = Math_fround(0), $resultNormal3 = 0;
 var $resultPoint = 0, $sphereCenterInTransform1 = 0, $sweptBox = 0, $tempContainer = 0, $ti$036 = 0, $trA = 0, $trB = 0, $triangle = 0, $unitDir = 0, $unused = 0, $unused1 = 0, $v0 = 0, $vertexSpaceBox = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $zero$sroa$1$i$i$i = sp + 976|0;
 $0 = sp + 208|0;
 $$sroa$113$i$i = sp + 960|0;
 $$sroa$1$i$i = sp + 948|0;
 $cp$i = sp + 936|0;
 $meshScaling = sp + 864|0;
 $trA = sp + 848|0;
 $trB = sp + 836|0;
 $unitDir = sp + 824|0;
 $matRot = sp + 788|0;
 $sweptBox = sp + 728|0;
 $vertexSpaceBox = sp + 668|0;
 $1 = sp + 608|0;
 $2 = sp + 580|0;
 $hmd = sp + 568|0;
 $tempContainer = sp + 552|0;
 $callback = sp + 540|0;
 $lastTransform0 = sp + 176|0;
 $lastTransform1 = sp;
 $origin = sp + 268|0;
 $extent = sp + 280|0;
 $orderedContainer = sp + 304|0;
 $distanceEntries = sp + 248|0;
 $unused = sp + 264|0;
 $3 = sp + 224|0;
 $4 = sp + 236|0;
 $5 = sp + 528|0;
 $sphereCenterInTransform1 = sp + 320|0;
 $unused1 = sp + 332|0;
 $convexPartOfMesh12 = sp + 336|0;
 $resultNormal3 = sp + 416|0;
 $resultPoint = sp + 428|0;
 $v0 = sp + 440|0;
 $triangle = sp + 32|0;
 $6 = sp + 456|0;
 $7 = sp + 292|0;
 $8 = HEAP32[$shape1>>2]|0;
 $9 = (($8) + 36|0);
 $10 = (($8) + 40|0);
 $11 = (($8) + 52|0);
 __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$10,$11);
 $12 = (($shape0) + 56|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($shape0) + 28|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = (($shape0) + 60|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($shape0) + 32|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 - $20);
 $22 = (($shape0) + 64|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($shape0) + 36|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 - $25);
 HEAPF32[$trA>>2] = $16;
 $27 = (($trA) + 4|0);
 HEAPF32[$27>>2] = $21;
 $28 = (($trA) + 8|0);
 HEAPF32[$28>>2] = $26;
 $29 = (($shape1) + 40|0);
 $30 = (($shape1) + 56|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($shape1) + 28|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($31 - $33);
 $35 = (($shape1) + 60|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($shape1) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 - $38);
 $40 = (($shape1) + 64|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($shape1) + 36|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($41 - $43);
 HEAPF32[$trB>>2] = $34;
 $45 = (($trB) + 4|0);
 HEAPF32[$45>>2] = $39;
 $46 = (($trB) + 8|0);
 HEAPF32[$46>>2] = $44;
 $47 = Math_fround($16 - $34);
 $48 = Math_fround($21 - $39);
 $49 = Math_fround($26 - $44);
 HEAPF32[$unitDir>>2] = $47;
 $50 = (($unitDir) + 4|0);
 HEAPF32[$50>>2] = $48;
 $51 = (($unitDir) + 8|0);
 HEAPF32[$51>>2] = $49;
 $52 = Math_fround($47 * $47);
 $53 = Math_fround($48 * $48);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($49 * $49);
 $56 = Math_fround($55 + $54);
 $57 = (Math_fround(Math_sqrt((Math_fround($56)))));
 $58 = $57 > Math_fround(0.0);
 if ($58) {
  $59 = Math_fround(Math_fround(1.0) / $57);
  $60 = Math_fround($47 * $59);
  HEAPF32[$unitDir>>2] = $60;
  $61 = Math_fround($48 * $59);
  HEAPF32[$50>>2] = $61;
  $62 = Math_fround($49 * $59);
  HEAPF32[$51>>2] = $62;
 }
 $63 = (($shape0) + 12|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($shape0) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($shape0) + 20|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($shape0) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($64 + $64);
 $72 = Math_fround($66 + $66);
 $73 = Math_fround($68 + $68);
 $74 = Math_fround($64 * $71);
 $75 = Math_fround($66 * $72);
 $76 = Math_fround($68 * $73);
 $77 = Math_fround($71 * $66);
 $78 = Math_fround($71 * $68);
 $79 = Math_fround($71 * $70);
 $80 = Math_fround($72 * $68);
 $81 = Math_fround($72 * $70);
 $82 = Math_fround($73 * $70);
 $83 = Math_fround(Math_fround(1.0) - $75);
 $84 = Math_fround($83 - $76);
 $85 = Math_fround($77 + $82);
 $86 = Math_fround($78 - $81);
 HEAPF32[$matRot>>2] = $84;
 $87 = (($matRot) + 4|0);
 HEAPF32[$87>>2] = $85;
 $88 = (($matRot) + 8|0);
 HEAPF32[$88>>2] = $86;
 $89 = Math_fround($77 - $82);
 $90 = Math_fround(Math_fround(1.0) - $74);
 $91 = Math_fround($90 - $76);
 $92 = Math_fround($80 + $79);
 $93 = (($matRot) + 12|0);
 HEAPF32[$93>>2] = $89;
 $94 = (($matRot) + 16|0);
 HEAPF32[$94>>2] = $91;
 $95 = (($matRot) + 20|0);
 HEAPF32[$95>>2] = $92;
 $96 = Math_fround($78 + $81);
 $97 = Math_fround($80 - $79);
 $98 = Math_fround($90 - $75);
 $99 = (($matRot) + 24|0);
 HEAPF32[$99>>2] = $96;
 $100 = (($matRot) + 28|0);
 HEAPF32[$100>>2] = $97;
 $101 = (($matRot) + 32|0);
 HEAPF32[$101>>2] = $98;
 $102 = (($shape0) + 68|0);
 $103 = (($shape0) + 80|0);
 __ZN5physx2Gu15computeSweptBoxERNS0_3BoxERKNS_6PxVec3ES5_RKNS_7PxMat33ES5_f($sweptBox,$102,$103,$matRot,$unitDir,$57);
 $104 = Math_fround(HEAPF32[$10>>2]);
 $105 = $104 == Math_fround(1.0);
 if ($105) {
  $106 = (($8) + 44|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = $107 == Math_fround(1.0);
  if ($108) {
   $109 = (($8) + 48|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = $110 == Math_fround(1.0);
   if ($111) {
    $112 = Math_fround(HEAPF32[$30>>2]);
    $113 = Math_fround(HEAPF32[$35>>2]);
    $114 = Math_fround(HEAPF32[$40>>2]);
    $115 = Math_fround($112 * Math_fround(-2.0));
    $116 = Math_fround($113 * Math_fround(-2.0));
    $117 = Math_fround($114 * Math_fround(-2.0));
    $118 = (($shape1) + 52|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = Math_fround($119 * $119);
    $121 = Math_fround($120 + Math_fround(-0.5));
    $122 = Math_fround(HEAPF32[$29>>2]);
    $123 = Math_fround($115 * $122);
    $124 = (($shape1) + 44|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = Math_fround($116 * $125);
    $127 = Math_fround($123 + $126);
    $128 = (($shape1) + 48|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = Math_fround($117 * $129);
    $131 = Math_fround($127 + $130);
    $132 = Math_fround($115 * $121);
    $133 = Math_fround($117 * $125);
    $134 = Math_fround($116 * $129);
    $135 = Math_fround($133 - $134);
    $136 = Math_fround($119 * $135);
    $137 = Math_fround($132 - $136);
    $138 = Math_fround($122 * $131);
    $139 = Math_fround($138 + $137);
    $140 = Math_fround($116 * $121);
    $141 = Math_fround($115 * $129);
    $142 = Math_fround($117 * $122);
    $143 = Math_fround($141 - $142);
    $144 = Math_fround($119 * $143);
    $145 = Math_fround($140 - $144);
    $146 = Math_fround($125 * $131);
    $147 = Math_fround($146 + $145);
    $148 = Math_fround($117 * $121);
    $149 = Math_fround($116 * $122);
    $150 = Math_fround($115 * $125);
    $151 = Math_fround($149 - $150);
    $152 = Math_fround($119 * $151);
    $153 = Math_fround($148 - $152);
    $154 = Math_fround($129 * $131);
    $155 = Math_fround($153 + $154);
    $156 = Math_fround(-$122);
    $157 = Math_fround(-$125);
    $158 = Math_fround(-$129);
    HEAPF32[$2>>2] = $156;
    $159 = (($2) + 4|0);
    HEAPF32[$159>>2] = $157;
    $160 = (($2) + 8|0);
    HEAPF32[$160>>2] = $158;
    $161 = (($2) + 12|0);
    HEAPF32[$161>>2] = $119;
    $162 = (($2) + 16|0);
    HEAPF32[$162>>2] = $139;
    $163 = (($2) + 20|0);
    HEAPF32[$163>>2] = $147;
    $164 = (($2) + 24|0);
    HEAPF32[$164>>2] = $155;
    __ZN5physx23transformBoxOrthonormalERKNS_2Gu3BoxERKNS_11PxTransformE($1,$sweptBox,$2);
    $165 = Math_fround(HEAPF32[$1>>2]);
    HEAPF32[$vertexSpaceBox>>2] = $165;
    $166 = (($1) + 4|0);
    $167 = Math_fround(HEAPF32[$166>>2]);
    $168 = (($vertexSpaceBox) + 4|0);
    HEAPF32[$168>>2] = $167;
    $169 = (($1) + 8|0);
    $170 = Math_fround(HEAPF32[$169>>2]);
    $171 = (($vertexSpaceBox) + 8|0);
    HEAPF32[$171>>2] = $170;
    $172 = (($1) + 12|0);
    $173 = Math_fround(HEAPF32[$172>>2]);
    $174 = (($vertexSpaceBox) + 12|0);
    HEAPF32[$174>>2] = $173;
    $175 = (($1) + 16|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = (($vertexSpaceBox) + 16|0);
    HEAPF32[$177>>2] = $176;
    $178 = (($1) + 20|0);
    $179 = Math_fround(HEAPF32[$178>>2]);
    $180 = (($vertexSpaceBox) + 20|0);
    HEAPF32[$180>>2] = $179;
    $181 = (($1) + 24|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = (($vertexSpaceBox) + 24|0);
    HEAPF32[$183>>2] = $182;
    $184 = (($1) + 28|0);
    $185 = Math_fround(HEAPF32[$184>>2]);
    $186 = (($vertexSpaceBox) + 28|0);
    HEAPF32[$186>>2] = $185;
    $187 = (($1) + 32|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = (($vertexSpaceBox) + 32|0);
    HEAPF32[$189>>2] = $188;
    $190 = (($1) + 36|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = (($vertexSpaceBox) + 36|0);
    HEAPF32[$192>>2] = $191;
    $193 = (($1) + 40|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = (($vertexSpaceBox) + 40|0);
    HEAPF32[$195>>2] = $194;
    $196 = (($1) + 44|0);
    $197 = Math_fround(HEAPF32[$196>>2]);
    $198 = (($vertexSpaceBox) + 44|0);
    HEAPF32[$198>>2] = $197;
    $199 = (($1) + 48|0);
    $200 = Math_fround(HEAPF32[$199>>2]);
    $201 = (($vertexSpaceBox) + 48|0);
    HEAPF32[$201>>2] = $200;
    $202 = (($1) + 52|0);
    $203 = Math_fround(HEAPF32[$202>>2]);
    $204 = (($vertexSpaceBox) + 52|0);
    HEAPF32[$204>>2] = $203;
    $205 = (($1) + 56|0);
    $206 = Math_fround(HEAPF32[$205>>2]);
    $207 = (($vertexSpaceBox) + 56|0);
    HEAPF32[$207>>2] = $206;
    $210 = $200;$213 = $203;$216 = $206;
   } else {
    label = 7;
   }
  } else {
   label = 7;
  }
 } else {
  label = 7;
 }
 if ((label|0) == 7) {
  __ZN5physx2Gu21computeVertexSpaceOBBERNS0_3BoxERKS1_RKNS_11PxTransformERKNS_11PxMeshScaleE($vertexSpaceBox,$sweptBox,$29,$10);
  $$phi$trans$insert = (($vertexSpaceBox) + 48|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$phi$trans$insert63 = (($vertexSpaceBox) + 52|0);
  $$pre64 = Math_fround(HEAPF32[$$phi$trans$insert63>>2]);
  $$phi$trans$insert65 = (($vertexSpaceBox) + 56|0);
  $$pre66 = Math_fround(HEAPF32[$$phi$trans$insert65>>2]);
  $210 = $$pre;$213 = $$pre64;$216 = $$pre66;
 }
 $208 = (($vertexSpaceBox) + 48|0);
 $209 = Math_fround($210 + $restDistance);
 HEAPF32[$208>>2] = $209;
 $211 = (($vertexSpaceBox) + 52|0);
 $212 = Math_fround($213 + $restDistance);
 HEAPF32[$211>>2] = $212;
 $214 = (($vertexSpaceBox) + 56|0);
 $215 = Math_fround($216 + $restDistance);
 HEAPF32[$214>>2] = $215;
 $217 = (($8) + 76|0);
 $218 = HEAP32[$217>>2]|0;
 $219 = (($218) + 16|0);
 $220 = HEAP32[$219>>2]|0;
 HEAP32[$hmd>>2] = $220;
 $221 = (($218) + 32|0);
 $222 = (($hmd) + 4|0);
 HEAP32[$222>>2] = $221;
 $223 = (($218) + 20|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = (($hmd) + 8|0);
 HEAPF32[$225>>2] = $224;
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $226 = STACKTOP; STACKTOP = STACKTOP + 256|0;;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,64,$226,1);
 $227 = (($callback) + 4|0);
 HEAP32[$227>>2] = 2;
 HEAP32[$callback>>2] = ((503248 + 8|0));
 $228 = (($callback) + 8|0);
 HEAP32[$228>>2] = $tempContainer;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($vertexSpaceBox,1,$hmd,$callback,1);
 $229 = (($tempContainer) + 4|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = ($230|0)==(0);
 if ($231) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $232 = (($tempContainer) + 8|0);
 $233 = HEAP32[$232>>2]|0;
 $234 = HEAP32[$shape0>>2]|0;
 $235 = (($234) + 36|0);
 $236 = HEAP32[$235>>2]|0;
 $237 = Math_fround(HEAPF32[$63>>2]);
 HEAPF32[$lastTransform0>>2] = $237;
 $238 = Math_fround(HEAPF32[$65>>2]);
 $239 = (($lastTransform0) + 4|0);
 HEAPF32[$239>>2] = $238;
 $240 = Math_fround(HEAPF32[$67>>2]);
 $241 = (($lastTransform0) + 8|0);
 HEAPF32[$241>>2] = $240;
 $242 = Math_fround(HEAPF32[$69>>2]);
 $243 = (($lastTransform0) + 12|0);
 HEAPF32[$243>>2] = $242;
 $244 = Math_fround(HEAPF32[$14>>2]);
 $245 = (($lastTransform0) + 16|0);
 HEAPF32[$245>>2] = $244;
 $246 = Math_fround(HEAPF32[$19>>2]);
 $247 = (($lastTransform0) + 20|0);
 HEAPF32[$247>>2] = $246;
 $248 = Math_fround(HEAPF32[$24>>2]);
 $249 = (($lastTransform0) + 24|0);
 HEAPF32[$249>>2] = $248;
 $250 = Math_fround(HEAPF32[$transform1>>2]);
 HEAPF32[$lastTransform1>>2] = $250;
 $251 = (($transform1) + 4|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 $253 = (($lastTransform1) + 4|0);
 HEAPF32[$253>>2] = $252;
 $254 = (($transform1) + 8|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = (($lastTransform1) + 8|0);
 HEAPF32[$256>>2] = $255;
 $257 = (($transform1) + 12|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 $259 = (($lastTransform1) + 12|0);
 HEAPF32[$259>>2] = $258;
 $260 = (($transform1) + 16|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = (($lastTransform1) + 16|0);
 HEAPF32[$262>>2] = $261;
 $263 = (($transform1) + 20|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = (($lastTransform1) + 20|0);
 HEAPF32[$265>>2] = $264;
 $266 = (($transform1) + 24|0);
 $267 = Math_fround(HEAPF32[$266>>2]);
 $268 = (($lastTransform1) + 24|0);
 HEAPF32[$268>>2] = $267;
 $269 = ($atom1|0)!=(0|0);
 if ($269) {
  $270 = (($atom1) + 64|0);
  $271 = HEAP32[$270>>2]|0;
  $272 = (($271) + 124|0);
  $273 = Math_fround(HEAPF32[$272>>2]);
  $274 = $273 == Math_fround(0.0);
  if (!($274)) {
   $275 = (($shape1) + 12|0);
   $276 = Math_fround(HEAPF32[$275>>2]);
   HEAPF32[$lastTransform1>>2] = $276;
   $277 = (($shape1) + 16|0);
   $278 = Math_fround(HEAPF32[$277>>2]);
   HEAPF32[$253>>2] = $278;
   $279 = (($shape1) + 20|0);
   $280 = Math_fround(HEAPF32[$279>>2]);
   HEAPF32[$256>>2] = $280;
   $281 = (($shape1) + 24|0);
   $282 = Math_fround(HEAPF32[$281>>2]);
   HEAPF32[$259>>2] = $282;
   $283 = Math_fround(HEAPF32[$32>>2]);
   HEAPF32[$262>>2] = $283;
   $284 = Math_fround(HEAPF32[$37>>2]);
   HEAPF32[$265>>2] = $284;
   $285 = Math_fround(HEAPF32[$42>>2]);
   HEAPF32[$268>>2] = $285;
  }
 }
 $286 = Math_fround(HEAPF32[$103>>2]);
 HEAPF32[$origin>>2] = $286;
 $287 = (($origin) + 4|0);
 $288 = (($shape0) + 84|0);
 $289 = Math_fround(HEAPF32[$288>>2]);
 HEAPF32[$287>>2] = $289;
 $290 = (($origin) + 8|0);
 $291 = (($shape0) + 88|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 HEAPF32[$290>>2] = $292;
 $293 = Math_fround(HEAPF32[$102>>2]);
 $294 = Math_fround($293 + $restDistance);
 $295 = (($shape0) + 72|0);
 $296 = Math_fround(HEAPF32[$295>>2]);
 $297 = Math_fround($296 + $restDistance);
 $298 = (($shape0) + 76|0);
 $299 = Math_fround(HEAPF32[$298>>2]);
 $300 = Math_fround($299 + $restDistance);
 HEAPF32[$extent>>2] = $294;
 $301 = (($extent) + 4|0);
 HEAPF32[$301>>2] = $297;
 $302 = (($extent) + 8|0);
 HEAPF32[$302>>2] = $300;
 __ZN5physx2Gu9ContainerC2Ev($orderedContainer);
 $303 = STACKTOP; STACKTOP = STACKTOP + 256|0;;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($orderedContainer,64,$303,1);
 $304 = HEAP32[$229>>2]|0;
 $305 = (($orderedContainer) + 4|0);
 $306 = HEAP32[$305>>2]|0;
 $307 = (($306) + ($304))|0;
 $308 = HEAP32[$orderedContainer>>2]|0;
 $309 = ($307>>>0)>($308>>>0);
 if ($309) {
  (__ZN5physx2Gu9Container6ResizeEj($orderedContainer,$304)|0);
  $$pre$i3 = HEAP32[$305>>2]|0;
  $312 = $$pre$i3;
 } else {
  $312 = $306;
 }
 $310 = (($orderedContainer) + 8|0);
 $311 = (($312) + ($304))|0;
 HEAP32[$305>>2] = $311;
 __ZN5physx2Gu9ContainerC2Ev($distanceEntries);
 $313 = STACKTOP; STACKTOP = STACKTOP + 256|0;;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($distanceEntries,64,$313,1);
 $314 = HEAP32[$229>>2]|0;
 $315 = (($distanceEntries) + 4|0);
 $316 = HEAP32[$315>>2]|0;
 $317 = (($316) + ($314))|0;
 $318 = HEAP32[$distanceEntries>>2]|0;
 $319 = ($317>>>0)>($318>>>0);
 if ($319) {
  (__ZN5physx2Gu9Container6ResizeEj($distanceEntries,$314)|0);
  $$pre$i = HEAP32[$315>>2]|0;
  $322 = $$pre$i;
 } else {
  $322 = $316;
 }
 $320 = (($distanceEntries) + 8|0);
 $321 = (($322) + ($314))|0;
 HEAP32[$315>>2] = $321;
 $323 = HEAP32[$310>>2]|0;
 $324 = HEAP32[$320>>2]|0;
 $325 = ($atom0|0)!=(0|0);
 if ($325) {
  $326 = (($shape0) + 8|0);
  $327 = Math_fround(HEAPF32[$326>>2]);
  $343 = $327;
 } else {
  $343 = Math_fround(0.0);
 }
 if ($269) {
  $328 = (($shape1) + 8|0);
  $329 = Math_fround(HEAPF32[$328>>2]);
  $344 = $329;
 } else {
  $344 = Math_fround(0.0);
 }
 if ($325) {
  $330 = (($atom0) + 60|0);
  $331 = HEAP32[$330>>2]|0;
  $332 = (($331) + 4|0);
  $333 = Math_fround(HEAPF32[$332>>2]);
  $339 = $333;
 } else {
  $339 = Math_fround(1.0);
 }
 if ($269) {
  $334 = (($atom1) + 60|0);
  $335 = HEAP32[$334>>2]|0;
  $336 = (($335) + 4|0);
  $337 = Math_fround(HEAPF32[$336>>2]);
  $340 = $337;
 } else {
  $340 = Math_fround(1.0);
 }
 $338 = $339 < $340;
 $341 = $338 ? $339 : $340;
 $342 = $343 > $344;
 $345 = $342 ? $343 : $344;
 $346 = Math_fround($345 * $341);
 $347 = (($zero$sroa$1$i$i$i) + 4|0);
 $348 = (($zero$sroa$1$i$i$i) + 8|0);
 $349 = (($zero$sroa$1$i$i$i) + 12|0);
 $350 = (($zero$sroa$1$i$i$i) + 16|0);
 $351 = (($zero$sroa$1$i$i$i) + 40|0);
 $352 = (($zero$sroa$1$i$i$i) + 44|0);
 $353 = (($zero$sroa$1$i$i$i) + 48|0);
 $354 = (($zero$sroa$1$i$i$i) + 52|0);
 $355 = (($zero$sroa$1$i$i$i) + 56|0);
 $356 = (($zero$sroa$1$i$i$i) + 60|0);
 $357 = (($zero$sroa$1$i$i$i) + 64|0);
 $358 = (($3) + 4|0);
 $359 = (($3) + 8|0);
 $360 = (($4) + 4|0);
 $361 = (($4) + 8|0);
 $362 = (($5) + 4|0);
 $363 = (($5) + 8|0);
 $a$049 = 0;$count$050 = 0;
 while(1) {
  $364 = (($233) + ($a$049<<2)|0);
  HEAP32[$zero$sroa$1$i$i$i>>2] = $9;
  HEAP32[$347>>2] = $meshScaling;
  HEAP32[$348>>2] = $364;
  HEAP32[$349>>2] = 1;
  HEAP32[$350>>2] = $unused;
  HEAPF32[$351>>2] = Math_fround(8.50705866596322149529E+37);
  HEAPF32[$352>>2] = Math_fround(8.50705866596322149529E+37);
  HEAPF32[$353>>2] = Math_fround(8.50705866596322149529E+37);
  HEAPF32[$354>>2] = Math_fround(-8.50705866596322149529E+37);
  HEAPF32[$355>>2] = Math_fround(-8.50705866596322149529E+37);
  HEAPF32[$356>>2] = Math_fround(-8.50705866596322149529E+37);
  ;HEAP32[$357+0>>2]=0|0;HEAP32[$357+4>>2]=0|0;HEAP32[$357+8>>2]=0|0;HEAP8[$357+12>>0]=0|0;
  __ZNK5physx18PxcConvexTriangles16getPolygonNormalEj($3,$zero$sroa$1$i$i$i,0);
  $365 = Math_fround(HEAPF32[$3>>2]);
  $366 = Math_fround($365 * Math_fround(2.0));
  $367 = Math_fround(HEAPF32[$358>>2]);
  $368 = Math_fround($367 * Math_fround(2.0));
  $369 = Math_fround(HEAPF32[$359>>2]);
  $370 = Math_fround($369 * Math_fround(2.0));
  $371 = Math_fround(HEAPF32[$257>>2]);
  $372 = Math_fround($371 * $371);
  $373 = Math_fround($372 + Math_fround(-0.5));
  $374 = Math_fround(HEAPF32[$transform1>>2]);
  $375 = Math_fround($366 * $374);
  $376 = Math_fround(HEAPF32[$251>>2]);
  $377 = Math_fround($368 * $376);
  $378 = Math_fround($375 + $377);
  $379 = Math_fround(HEAPF32[$254>>2]);
  $380 = Math_fround($370 * $379);
  $381 = Math_fround($378 + $380);
  $382 = Math_fround($366 * $373);
  $383 = Math_fround($370 * $376);
  $384 = Math_fround($368 * $379);
  $385 = Math_fround($383 - $384);
  $386 = Math_fround($371 * $385);
  $387 = Math_fround($382 + $386);
  $388 = Math_fround($374 * $381);
  $389 = Math_fround($388 + $387);
  $390 = Math_fround($368 * $373);
  $391 = Math_fround($366 * $379);
  $392 = Math_fround($370 * $374);
  $393 = Math_fround($391 - $392);
  $394 = Math_fround($371 * $393);
  $395 = Math_fround($390 + $394);
  $396 = Math_fround($376 * $381);
  $397 = Math_fround($396 + $395);
  $398 = Math_fround($370 * $373);
  $399 = Math_fround($368 * $374);
  $400 = Math_fround($366 * $376);
  $401 = Math_fround($399 - $400);
  $402 = Math_fround($371 * $401);
  $403 = Math_fround($398 + $402);
  $404 = Math_fround($379 * $381);
  $405 = Math_fround($403 + $404);
  $406 = Math_fround($47 * $389);
  $407 = Math_fround($48 * $397);
  $408 = Math_fround(-$407);
  $409 = Math_fround($408 - $406);
  $410 = Math_fround($49 * $405);
  $411 = Math_fround($409 - $410);
  $412 = !($411 >= $346);
  if ($412) {
   $count$1 = $count$050;
  } else {
   __ZNK5physx18PxcConvexTriangles19calcCenterAndBoundsERKNS_11PxTransformE($zero$sroa$1$i$i$i,$lastTransform1);
   $413 = Math_fround(HEAPF32[$351>>2]);
   $414 = Math_fround(HEAPF32[$352>>2]);
   $415 = Math_fround(HEAPF32[$353>>2]);
   $416 = Math_fround(HEAPF32[$354>>2]);
   $417 = Math_fround(HEAPF32[$355>>2]);
   $418 = Math_fround(HEAPF32[$356>>2]);
   $419 = Math_fround($413 + $416);
   $420 = Math_fround($414 + $417);
   $421 = Math_fround($415 + $418);
   $422 = Math_fround($419 * Math_fround(0.5));
   $423 = Math_fround($420 * Math_fround(0.5));
   $424 = Math_fround($421 * Math_fround(0.5));
   HEAPF32[$4>>2] = $422;
   HEAPF32[$360>>2] = $423;
   HEAPF32[$361>>2] = $424;
   $425 = Math_fround($416 - $413);
   $426 = Math_fround($417 - $414);
   $427 = Math_fround($418 - $415);
   $428 = Math_fround($425 * Math_fround(0.5));
   $429 = Math_fround($426 * Math_fround(0.5));
   $430 = Math_fround($427 * Math_fround(0.5));
   $431 = Math_fround($428 + Math_fround(0.0199999995529651641846));
   $432 = Math_fround($429 + Math_fround(0.0199999995529651641846));
   $433 = Math_fround($430 + Math_fround(0.0199999995529651641846));
   HEAPF32[$5>>2] = $431;
   HEAPF32[$362>>2] = $432;
   HEAPF32[$363>>2] = $433;
   $434 = (Math_fround(__Z13sweepAABBAABBRKN5physx6PxVec3ES2_S2_S2_S2_S2_($origin,$extent,$4,$5,$trA,$trB)));
   $435 = !($434 <= Math_fround(1.0));
   if ($435) {
    $count$1 = $count$050;
   } else {
    $436 = ($count$050|0)==(0);
    L41: do {
     if ($436) {
      $index$0 = 0;
     } else {
      $b$044 = $count$050;
      while(1) {
       $437 = (($b$044) + -1)|0;
       $438 = (($324) + ($437<<2)|0);
       $439 = Math_fround(HEAPF32[$438>>2]);
       $440 = !($439 <= $434);
       if (!($440)) {
        $index$0 = $b$044;
        break L41;
       }
       $441 = (($324) + ($b$044<<2)|0);
       HEAPF32[$441>>2] = $439;
       $442 = (($323) + ($437<<2)|0);
       $443 = HEAP32[$442>>2]|0;
       $444 = (($323) + ($b$044<<2)|0);
       HEAP32[$444>>2] = $443;
       $445 = ($437|0)==(0);
       if ($445) {
        $index$0 = 0;
        break;
       } else {
        $b$044 = $437;
       }
      }
     }
    } while(0);
    $446 = HEAP32[$364>>2]|0;
    $447 = (($323) + ($index$0<<2)|0);
    HEAP32[$447>>2] = $446;
    $448 = (($324) + ($index$0<<2)|0);
    HEAPF32[$448>>2] = $434;
    $449 = (($count$050) + 1)|0;
    $count$1 = $449;
   }
  }
  $450 = (($a$049) + 1)|0;
  $exitcond62 = ($450|0)==($230|0);
  if ($exitcond62) {
   break;
  } else {
   $a$049 = $450;$count$050 = $count$1;
  }
 }
 $451 = (($context) + 8756|0);
 HEAP32[$451>>2] = -1;
 $452 = Math_fround(HEAPF32[$14>>2]);
 $453 = Math_fround(HEAPF32[$19>>2]);
 $454 = Math_fround(HEAPF32[$24>>2]);
 $455 = (($shape0) + 8|0);
 $456 = Math_fround(HEAPF32[$455>>2]);
 $457 = Math_fround($456 * $456);
 $458 = Math_fround(HEAPF32[$260>>2]);
 $459 = Math_fround($452 - $458);
 $460 = Math_fround(HEAPF32[$263>>2]);
 $461 = Math_fround($453 - $460);
 $462 = Math_fround(HEAPF32[$266>>2]);
 $463 = Math_fround($454 - $462);
 $464 = Math_fround($459 * Math_fround(2.0));
 $465 = Math_fround($461 * Math_fround(2.0));
 $466 = Math_fround($463 * Math_fround(2.0));
 $467 = Math_fround(HEAPF32[$257>>2]);
 $468 = Math_fround($467 * $467);
 $469 = Math_fround($468 + Math_fround(-0.5));
 $470 = Math_fround(HEAPF32[$transform1>>2]);
 $471 = Math_fround($464 * $470);
 $472 = Math_fround(HEAPF32[$251>>2]);
 $473 = Math_fround($465 * $472);
 $474 = Math_fround($471 + $473);
 $475 = Math_fround(HEAPF32[$254>>2]);
 $476 = Math_fround($466 * $475);
 $477 = Math_fround($474 + $476);
 $478 = Math_fround($464 * $469);
 $479 = Math_fround($466 * $472);
 $480 = Math_fround($465 * $475);
 $481 = Math_fround($479 - $480);
 $482 = Math_fround($467 * $481);
 $483 = Math_fround($478 - $482);
 $484 = Math_fround($470 * $477);
 $485 = Math_fround($484 + $483);
 $486 = Math_fround($465 * $469);
 $487 = Math_fround($464 * $475);
 $488 = Math_fround($466 * $470);
 $489 = Math_fround($487 - $488);
 $490 = Math_fround($467 * $489);
 $491 = Math_fround($486 - $490);
 $492 = Math_fround($472 * $477);
 $493 = Math_fround($492 + $491);
 $494 = Math_fround($466 * $469);
 $495 = Math_fround($465 * $470);
 $496 = Math_fround($464 * $472);
 $497 = Math_fround($495 - $496);
 $498 = Math_fround($467 * $497);
 $499 = Math_fround($494 - $498);
 $500 = Math_fround($475 * $477);
 $501 = Math_fround($499 + $500);
 HEAPF32[$sphereCenterInTransform1>>2] = $485;
 $502 = (($sphereCenterInTransform1) + 4|0);
 HEAPF32[$502>>2] = $493;
 $503 = (($sphereCenterInTransform1) + 8|0);
 HEAPF32[$503>>2] = $501;
 $504 = Math_fround(HEAPF32[$245>>2]);
 $505 = Math_fround($504 - $458);
 $506 = Math_fround(HEAPF32[$247>>2]);
 $507 = Math_fround($506 - $460);
 $508 = Math_fround(HEAPF32[$249>>2]);
 $509 = Math_fround($508 - $462);
 $510 = Math_fround($505 * Math_fround(2.0));
 $511 = Math_fround($507 * Math_fround(2.0));
 $512 = Math_fround($509 * Math_fround(2.0));
 $513 = Math_fround($510 * $470);
 $514 = Math_fround($511 * $472);
 $515 = Math_fround($513 + $514);
 $516 = Math_fround($512 * $475);
 $517 = Math_fround($515 + $516);
 $518 = Math_fround($510 * $469);
 $519 = Math_fround($512 * $472);
 $520 = Math_fround($511 * $475);
 $521 = Math_fround($519 - $520);
 $522 = Math_fround($467 * $521);
 $523 = Math_fround($518 - $522);
 $524 = Math_fround($470 * $517);
 $525 = Math_fround($524 + $523);
 $526 = Math_fround($511 * $469);
 $527 = Math_fround($510 * $475);
 $528 = Math_fround($512 * $470);
 $529 = Math_fround($527 - $528);
 $530 = Math_fround($467 * $529);
 $531 = Math_fround($526 - $530);
 $532 = Math_fround($472 * $517);
 $533 = Math_fround($532 + $531);
 $534 = Math_fround($512 * $469);
 $535 = Math_fround($511 * $470);
 $536 = Math_fround($510 * $472);
 $537 = Math_fround($535 - $536);
 $538 = Math_fround($467 * $537);
 $539 = Math_fround($534 - $538);
 $540 = Math_fround($475 * $517);
 $541 = Math_fround($539 + $540);
 $542 = ($count$1|0)==(0);
 if ($542) {
  $$lcssa = Math_fround(0.0);$$lcssa31 = Math_fround(0.0);$$lcssa32 = Math_fround(0.0);$$lcssa33 = Math_fround(0.0);$$lcssa34 = Math_fround(0.0);$$lcssa35 = Math_fround(0.0);$805 = $467;$808 = $470;$810 = $472;$813 = $475;$minTOI$0$lcssa = Math_fround(3.40282346638528859812E+38);
 } else {
  $543 = (($convexPartOfMesh12) + 4|0);
  $544 = (($convexPartOfMesh12) + 8|0);
  $545 = (($convexPartOfMesh12) + 12|0);
  $546 = (($convexPartOfMesh12) + 16|0);
  $547 = (($convexPartOfMesh12) + 40|0);
  $548 = (($convexPartOfMesh12) + 44|0);
  $549 = (($convexPartOfMesh12) + 48|0);
  $550 = (($convexPartOfMesh12) + 52|0);
  $551 = (($convexPartOfMesh12) + 56|0);
  $552 = (($convexPartOfMesh12) + 60|0);
  $553 = (($convexPartOfMesh12) + 64|0);
  $554 = (($meshScaling) + 4|0);
  $555 = (($meshScaling) + 8|0);
  $556 = (($meshScaling) + 12|0);
  $557 = (($meshScaling) + 16|0);
  $558 = (($meshScaling) + 20|0);
  $559 = (($meshScaling) + 24|0);
  $560 = (($meshScaling) + 28|0);
  $561 = (($meshScaling) + 32|0);
  $562 = (($v0) + 4|0);
  $563 = (($v0) + 8|0);
  $564 = (($triangle) + 64|0);
  $565 = (($triangle) + 80|0);
  $566 = (($triangle) + 16|0);
  $567 = (($triangle) + 20|0);
  $568 = (($triangle) + 32|0);
  $569 = (($triangle) + 36|0);
  $570 = (($triangle) + 48|0);
  $571 = (($triangle) + 52|0);
  $572 = (($triangle) + 4|0);
  $573 = (($triangle) + 8|0);
  $574 = (($triangle) + 12|0);
  $575 = (($triangle) + 96|0);
  $576 = (($triangle) + 100|0);
  $577 = (($triangle) + 104|0);
  $578 = (($triangle) + 108|0);
  $579 = (($triangle) + 112|0);
  $580 = (($triangle) + 116|0);
  $581 = (($triangle) + 120|0);
  $582 = (($triangle) + 124|0);
  $583 = (($triangle) + 128|0);
  $584 = (($triangle) + 132|0);
  $585 = (($triangle) + 136|0);
  $586 = (($triangle) + 140|0);
  $587 = (503216 + ($236<<2)|0);
  $588 = HEAP32[$587>>2]|0;
  $589 = (($6) + 4|0);
  $590 = (($6) + 8|0);
  $591 = (($6) + 12|0);
  $592 = (($6) + 16|0);
  $593 = (($6) + 20|0);
  $594 = (($6) + 24|0);
  $595 = (($6) + 28|0);
  $596 = (($6) + 32|0);
  $597 = (($6) + 36|0);
  $598 = (($6) + 40|0);
  $599 = (($6) + 44|0);
  $600 = (($6) + 48|0);
  $601 = (($6) + 52|0);
  $602 = (($6) + 56|0);
  $603 = (($6) + 60|0);
  $604 = (($6) + 64|0);
  $605 = (($6) + 68|0);
  $606 = (($7) + 4|0);
  $607 = (($7) + 8|0);
  $608 = (($resultPoint) + 4|0);
  $609 = (($resultPoint) + 8|0);
  $610 = (($zero$sroa$1$i$i$i) + 4|0);
  $611 = (($zero$sroa$1$i$i$i) + 8|0);
  $612 = (($0) + 4|0);
  $613 = (($0) + 8|0);
  $614 = (($cp$i) + 4|0);
  $615 = (($cp$i) + 8|0);
  $616 = Math_fround($456 * Math_fround(2.0));
  $843 = Math_fround(0.0);$844 = Math_fround(0.0);$845 = Math_fround(0.0);$846 = Math_fround(0.0);$847 = Math_fround(0.0);$848 = Math_fround(0.0);$minTOI$037 = Math_fround(3.40282346638528859812E+38);$ti$036 = 0;
  while(1) {
   $617 = (($323) + ($ti$036<<2)|0);
   HEAP32[$convexPartOfMesh12>>2] = $9;
   HEAP32[$543>>2] = $meshScaling;
   HEAP32[$544>>2] = $617;
   HEAP32[$545>>2] = 1;
   HEAP32[$546>>2] = $unused1;
   HEAPF32[$547>>2] = Math_fround(8.50705866596322149529E+37);
   HEAPF32[$548>>2] = Math_fround(8.50705866596322149529E+37);
   HEAPF32[$549>>2] = Math_fround(8.50705866596322149529E+37);
   HEAPF32[$550>>2] = Math_fround(-8.50705866596322149529E+37);
   HEAPF32[$551>>2] = Math_fround(-8.50705866596322149529E+37);
   HEAPF32[$552>>2] = Math_fround(-8.50705866596322149529E+37);
   ;HEAP32[$553+0>>2]=0|0;HEAP32[$553+4>>2]=0|0;HEAP32[$553+8>>2]=0|0;HEAP8[$553+12>>0]=0|0;
   $618 = HEAP32[$217>>2]|0;
   $619 = HEAP32[$617>>2]|0;
   $620 = (($618) + 156|0);
   $621 = HEAP8[$620>>0]|0;
   $622 = $621 & 2;
   $623 = ($622<<24>>24)==(0);
   $624 = (($618) + 12|0);
   $625 = HEAP32[$624>>2]|0;
   if ($623) {
    $640 = (($625) + (($619*12)|0)|0);
    $641 = HEAP32[$640>>2]|0;
    $642 = (($618) + 8|0);
    $643 = HEAP32[$642>>2]|0;
    $644 = (($643) + (($641*12)|0)|0);
    $645 = ((($625) + (($619*12)|0)|0) + 4|0);
    $646 = HEAP32[$645>>2]|0;
    $647 = (($643) + (($646*12)|0)|0);
    $648 = ((($625) + (($619*12)|0)|0) + 8|0);
    $649 = HEAP32[$648>>2]|0;
    $650 = (($643) + (($649*12)|0)|0);
    $652 = $644;$682 = $647;$703 = $650;
   } else {
    $626 = (($625) + (($619*6)|0)|0);
    $627 = HEAP16[$626>>1]|0;
    $628 = $627&65535;
    $629 = (($618) + 8|0);
    $630 = HEAP32[$629>>2]|0;
    $631 = (($630) + (($628*12)|0)|0);
    $632 = ((($625) + (($619*6)|0)|0) + 2|0);
    $633 = HEAP16[$632>>1]|0;
    $634 = $633&65535;
    $635 = (($630) + (($634*12)|0)|0);
    $636 = ((($625) + (($619*6)|0)|0) + 4|0);
    $637 = HEAP16[$636>>1]|0;
    $638 = $637&65535;
    $639 = (($630) + (($638*12)|0)|0);
    $652 = $631;$682 = $635;$703 = $639;
   }
   $651 = Math_fround(HEAPF32[$652>>2]);
   $653 = Math_fround(HEAPF32[$meshScaling>>2]);
   $654 = Math_fround($651 * $653);
   $655 = Math_fround(HEAPF32[$554>>2]);
   $656 = Math_fround($651 * $655);
   $657 = Math_fround(HEAPF32[$555>>2]);
   $658 = Math_fround($651 * $657);
   $659 = (($652) + 4|0);
   $660 = Math_fround(HEAPF32[$659>>2]);
   $661 = Math_fround(HEAPF32[$556>>2]);
   $662 = Math_fround($660 * $661);
   $663 = Math_fround(HEAPF32[$557>>2]);
   $664 = Math_fround($660 * $663);
   $665 = Math_fround(HEAPF32[$558>>2]);
   $666 = Math_fround($660 * $665);
   $667 = Math_fround($654 + $662);
   $668 = Math_fround($656 + $664);
   $669 = Math_fround($658 + $666);
   $670 = (($652) + 8|0);
   $671 = Math_fround(HEAPF32[$670>>2]);
   $672 = Math_fround(HEAPF32[$559>>2]);
   $673 = Math_fround($671 * $672);
   $674 = Math_fround(HEAPF32[$560>>2]);
   $675 = Math_fround($671 * $674);
   $676 = Math_fround(HEAPF32[$561>>2]);
   $677 = Math_fround($671 * $676);
   $678 = Math_fround($667 + $673);
   $679 = Math_fround($668 + $675);
   $680 = Math_fround($669 + $677);
   HEAPF32[$v0>>2] = $678;
   HEAPF32[$562>>2] = $679;
   HEAPF32[$563>>2] = $680;
   $681 = Math_fround(HEAPF32[$682>>2]);
   $683 = Math_fround($681 * $653);
   $684 = Math_fround($681 * $655);
   $685 = Math_fround($681 * $657);
   $686 = (($682) + 4|0);
   $687 = Math_fround(HEAPF32[$686>>2]);
   $688 = Math_fround($687 * $661);
   $689 = Math_fround($687 * $663);
   $690 = Math_fround($687 * $665);
   $691 = Math_fround($683 + $688);
   $692 = Math_fround($684 + $689);
   $693 = Math_fround($685 + $690);
   $694 = (($682) + 8|0);
   $695 = Math_fround(HEAPF32[$694>>2]);
   $696 = Math_fround($695 * $672);
   $697 = Math_fround($695 * $674);
   $698 = Math_fround($695 * $676);
   $699 = Math_fround($691 + $696);
   $700 = Math_fround($692 + $697);
   $701 = Math_fround($693 + $698);
   $702 = Math_fround(HEAPF32[$703>>2]);
   $704 = Math_fround($653 * $702);
   $705 = Math_fround($655 * $702);
   $706 = Math_fround($657 * $702);
   $707 = (($703) + 4|0);
   $708 = Math_fround(HEAPF32[$707>>2]);
   $709 = Math_fround($661 * $708);
   $710 = Math_fround($663 * $708);
   $711 = Math_fround($665 * $708);
   $712 = Math_fround($704 + $709);
   $713 = Math_fround($705 + $710);
   $714 = Math_fround($706 + $711);
   $715 = (($703) + 8|0);
   $716 = Math_fround(HEAPF32[$715>>2]);
   $717 = Math_fround($672 * $716);
   $718 = Math_fround($674 * $716);
   $719 = Math_fround($676 * $716);
   $720 = Math_fround($712 + $717);
   $721 = Math_fround($713 + $718);
   $722 = Math_fround($714 + $719);
   HEAP32[$565>>2] = 7;
   HEAPF32[$570>>2] = Math_fround(0.0);
   ;HEAP32[$571+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$571+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$571+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   ;HEAP32[$564+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$564+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$564+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$564+12>>2]=HEAP32[$0+12>>2]|0;
   $723 = Math_fround($699 + $678);
   $724 = Math_fround($700 + $679);
   $725 = Math_fround($701 + $680);
   $726 = Math_fround($720 + $723);
   $727 = Math_fround($721 + $724);
   $728 = Math_fround($722 + $725);
   $729 = Math_fround($726 * Math_fround(0.333332985639572143555));
   $730 = Math_fround($727 * Math_fround(0.333332985639572143555));
   $731 = Math_fround($728 * Math_fround(0.333332985639572143555));
   HEAPF32[$triangle>>2] = $729;
   HEAPF32[$572>>2] = $730;
   HEAPF32[$573>>2] = $731;
   HEAPF32[$574>>2] = Math_fround(0.0);
   HEAPF32[$575>>2] = $678;
   HEAPF32[$576>>2] = $679;
   HEAPF32[$577>>2] = $680;
   HEAPF32[$578>>2] = Math_fround(0.0);
   HEAPF32[$579>>2] = $699;
   HEAPF32[$580>>2] = $700;
   HEAPF32[$581>>2] = $701;
   HEAPF32[$582>>2] = Math_fround(0.0);
   HEAPF32[$583>>2] = $720;
   HEAPF32[$584>>2] = $721;
   HEAPF32[$585>>2] = $722;
   HEAPF32[$586>>2] = Math_fround(0.0);
   HEAPF32[$566>>2] = Math_fround(0.0);
   ;HEAP32[$567+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$567+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$567+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
   HEAPF32[$568>>2] = Math_fround(3.40282346638528859812E+38);
   ;HEAP32[$569+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$569+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$569+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
   HEAPF32[$6>>2] = Math_fround(1.0);
   HEAPF32[$589>>2] = Math_fround(0.0);
   HEAPF32[$590>>2] = Math_fround(0.0);
   HEAPF32[$591>>2] = Math_fround(0.0);
   HEAPF32[$592>>2] = Math_fround(1.0);
   HEAPF32[$593>>2] = Math_fround(0.0);
   HEAPF32[$594>>2] = Math_fround(0.0);
   HEAPF32[$595>>2] = Math_fround(0.0);
   HEAPF32[$596>>2] = Math_fround(1.0);
   HEAPF32[$597>>2] = Math_fround(1.0);
   HEAPF32[$598>>2] = Math_fround(0.0);
   HEAPF32[$599>>2] = Math_fround(0.0);
   HEAPF32[$600>>2] = Math_fround(0.0);
   HEAPF32[$601>>2] = Math_fround(1.0);
   HEAPF32[$602>>2] = Math_fround(0.0);
   HEAPF32[$603>>2] = Math_fround(0.0);
   HEAPF32[$604>>2] = Math_fround(0.0);
   HEAPF32[$605>>2] = Math_fround(1.0);
   $732 = (Math_fround(FUNCTION_TABLE_fiiiiiifiiiiiif[$588 & 7]($shape0,$shape1,$transform0,$transform1,$lastTransform0,$lastTransform1,$restDistance,$resultNormal3,$resultPoint,$cache,$context,$6,$triangle,Math_fround(0.0))));
   $733 = !($732 <= Math_fround(0.0));
   if ($733) {
    $res$0 = $732;
   } else {
    $734 = Math_fround(HEAPF32[$v0>>2]);
    $735 = Math_fround($699 - $734);
    $736 = Math_fround(HEAPF32[$562>>2]);
    $737 = Math_fround($700 - $736);
    $738 = Math_fround(HEAPF32[$563>>2]);
    $739 = Math_fround($701 - $738);
    $740 = Math_fround($720 - $734);
    $741 = Math_fround($721 - $736);
    $742 = Math_fround($722 - $738);
    $743 = Math_fround($737 * $742);
    $744 = Math_fround($741 * $739);
    $745 = Math_fround($743 - $744);
    $746 = Math_fround($740 * $739);
    $747 = Math_fround($735 * $742);
    $748 = Math_fround($746 - $747);
    $749 = Math_fround($735 * $741);
    $750 = Math_fround($740 * $737);
    $751 = Math_fround($749 - $750);
    $752 = Math_fround($735 + $734);
    $753 = Math_fround($737 + $736);
    $754 = Math_fround($739 + $738);
    HEAPF32[$zero$sroa$1$i$i$i>>2] = $752;
    HEAPF32[$610>>2] = $753;
    HEAPF32[$611>>2] = $754;
    $755 = Math_fround($740 + $734);
    $756 = Math_fround($741 + $736);
    $757 = Math_fround($742 + $738);
    HEAPF32[$0>>2] = $755;
    HEAPF32[$612>>2] = $756;
    HEAPF32[$613>>2] = $757;
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i,$sphereCenterInTransform1,$v0,$zero$sroa$1$i$i$i,$0,$$sroa$113$i$i,$$sroa$1$i$i);
    $758 = Math_fround(HEAPF32[$cp$i>>2]);
    $759 = Math_fround(HEAPF32[$sphereCenterInTransform1>>2]);
    $760 = Math_fround($758 - $759);
    $761 = Math_fround(HEAPF32[$614>>2]);
    $762 = Math_fround(HEAPF32[$502>>2]);
    $763 = Math_fround($761 - $762);
    $764 = Math_fround(HEAPF32[$615>>2]);
    $765 = Math_fround(HEAPF32[$503>>2]);
    $766 = Math_fround($764 - $765);
    $767 = Math_fround($760 * $760);
    $768 = Math_fround($763 * $763);
    $769 = Math_fround($767 + $768);
    $770 = Math_fround($766 * $766);
    $771 = Math_fround($769 + $770);
    $772 = $771 < $457;
    if ($772) {
     $773 = (Math_fround(Math_sqrt((Math_fround($771)))));
     $774 = Math_fround($773 - $456);
     $775 = Math_fround(HEAPF32[$v0>>2]);
     $776 = Math_fround($745 * $775);
     $777 = Math_fround(HEAPF32[$562>>2]);
     $778 = Math_fround($748 * $777);
     $779 = Math_fround($776 + $778);
     $780 = Math_fround(HEAPF32[$563>>2]);
     $781 = Math_fround($751 * $780);
     $782 = Math_fround($779 + $781);
     $783 = Math_fround($525 * $745);
     $784 = Math_fround($533 * $748);
     $785 = Math_fround($783 + $784);
     $786 = Math_fround($541 * $751);
     $787 = Math_fround($786 + $785);
     $788 = Math_fround($787 - $782);
     $789 = $788 > Math_fround(0.0);
     if ($789) {
      $790 = Math_fround($616 - $773);
      $791 = Math_fround(-$790);
      $res$0 = $791;
     } else {
      $res$0 = $774;
     }
    } else {
     $res$0 = Math_fround(0.0);
    }
   }
   $792 = $res$0 < $minTOI$037;
   if ($792) {
    __ZNK5physx18PxcConvexTriangles16getPolygonNormalEj($7,$convexPartOfMesh12,0);
    $793 = Math_fround(HEAPF32[$7>>2]);
    $794 = Math_fround(HEAPF32[$606>>2]);
    $795 = Math_fround(HEAPF32[$607>>2]);
    $796 = Math_fround(HEAPF32[$resultPoint>>2]);
    $797 = Math_fround(HEAPF32[$608>>2]);
    $798 = Math_fround(HEAPF32[$609>>2]);
    $799 = HEAP32[$617>>2]|0;
    HEAP32[$451>>2] = $799;
    $849 = $795;$850 = $794;$851 = $793;$852 = $798;$853 = $797;$854 = $796;$minTOI$1 = $res$0;
   } else {
    $849 = $848;$850 = $847;$851 = $846;$852 = $845;$853 = $844;$854 = $843;$minTOI$1 = $minTOI$037;
   }
   $800 = (($ti$036) + 1)|0;
   $exitcond = ($800|0)==($count$1|0);
   if ($exitcond) {
    break;
   } else {
    $843 = $854;$844 = $853;$845 = $852;$846 = $851;$847 = $850;$848 = $849;$minTOI$037 = $minTOI$1;$ti$036 = $800;
   }
  }
  $$pre67 = Math_fround(HEAPF32[$257>>2]);
  $$pre68 = Math_fround(HEAPF32[$transform1>>2]);
  $$pre69 = Math_fround(HEAPF32[$251>>2]);
  $$pre70 = Math_fround(HEAPF32[$254>>2]);
  $$lcssa = $849;$$lcssa31 = $850;$$lcssa32 = $851;$$lcssa33 = $852;$$lcssa34 = $853;$$lcssa35 = $854;$805 = $$pre67;$808 = $$pre68;$810 = $$pre69;$813 = $$pre70;$minTOI$0$lcssa = $minTOI$1;
 }
 $801 = Math_fround($$lcssa32 * Math_fround(2.0));
 $802 = Math_fround($$lcssa31 * Math_fround(2.0));
 $803 = Math_fround($$lcssa * Math_fround(2.0));
 $804 = Math_fround($805 * $805);
 $806 = Math_fround($804 + Math_fround(-0.5));
 $807 = Math_fround($801 * $808);
 $809 = Math_fround($802 * $810);
 $811 = Math_fround($807 + $809);
 $812 = Math_fround($803 * $813);
 $814 = Math_fround($811 + $812);
 $815 = Math_fround($801 * $806);
 $816 = Math_fround($803 * $810);
 $817 = Math_fround($802 * $813);
 $818 = Math_fround($816 - $817);
 $819 = Math_fround($805 * $818);
 $820 = Math_fround($815 + $819);
 $821 = Math_fround($808 * $814);
 $822 = Math_fround($821 + $820);
 $823 = Math_fround($802 * $806);
 $824 = Math_fround($801 * $813);
 $825 = Math_fround($803 * $808);
 $826 = Math_fround($824 - $825);
 $827 = Math_fround($805 * $826);
 $828 = Math_fround($823 + $827);
 $829 = Math_fround($810 * $814);
 $830 = Math_fround($829 + $828);
 $831 = Math_fround($803 * $806);
 $832 = Math_fround($802 * $808);
 $833 = Math_fround($801 * $810);
 $834 = Math_fround($832 - $833);
 $835 = Math_fround($805 * $834);
 $836 = Math_fround($831 + $835);
 $837 = Math_fround($813 * $814);
 $838 = Math_fround($836 + $837);
 HEAPF32[$worldNormal>>2] = $822;
 $839 = (($worldNormal) + 4|0);
 HEAPF32[$839>>2] = $830;
 $840 = (($worldNormal) + 8|0);
 HEAPF32[$840>>2] = $838;
 HEAPF32[$worldPoint>>2] = $$lcssa35;
 $841 = (($worldPoint) + 4|0);
 HEAPF32[$841>>2] = $$lcssa34;
 $842 = (($worldPoint) + 8|0);
 HEAPF32[$842>>2] = $$lcssa33;
 __ZN5physx2Gu9ContainerD2Ev($distanceEntries);
 __ZN5physx2Gu9ContainerD2Ev($orderedContainer);
 $$0 = $minTOI$0$lcssa;
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx25PxcSweepConvexHeightfieldERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZN5physxL27PxcSweepAnyShapeHeightfieldERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextE($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$restDistance,$worldNormal,$worldPoint,$cache,$context)));
 STACKTOP = sp;return (Math_fround($0));
}
function __ZN5physxL27PxcSweepAnyShapeHeightfieldERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextE($shape0,$shape1,$atom0,$atom1,$transform0,$transform1,$restDistance,$worldNormal,$worldPoint,$cache,$context) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $atom0 = $atom0|0;
 $atom1 = $atom1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 var $$lcssa = Math_fround(0), $$lcssa59 = Math_fround(0), $$lcssa60 = Math_fround(0), $$lcssa61 = Math_fround(0), $$lcssa62 = Math_fround(0), $$lcssa63 = Math_fround(0), $$pre = Math_fround(0), $$pre$i = 0, $$pre$i4 = 0, $$pre91 = Math_fround(0), $$pre92 = Math_fround(0), $$pre93 = Math_fround(0), $$sroa$1$i$i = 0, $$sroa$113$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0;
 var $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0;
 var $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0);
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0);
 var $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0);
 var $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0);
 var $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0;
 var $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = 0;
 var $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = 0;
 var $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0);
 var $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0);
 var $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0);
 var $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0);
 var $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0);
 var $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0;
 var $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = 0, $516 = Math_fround(0), $517 = Math_fround(0);
 var $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0);
 var $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0);
 var $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0);
 var $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = 0, $584 = 0, $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0);
 var $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0);
 var $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0);
 var $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$077 = 0, $b$072 = 0, $bounds0 = 0, $callback = 0, $count$0$lcssa = 0, $count$078 = 0, $count$1 = 0, $cp$i = 0;
 var $distanceEntries = 0, $exitcond = 0, $exitcond90 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $hfUtil = 0, $index$0 = 0, $lastTransform0 = 0, $lastTransform1 = 0, $minTOI$0$lcssa = Math_fround(0), $minTOI$065 = Math_fround(0), $minTOI$1 = Math_fround(0), $orderedContainer = 0, $origin = 0, $res$0 = Math_fround(0), $resultNormal2 = 0, $resultPoint = 0, $sphereCenterInTr1 = 0, $tempContainer = 0;
 var $ti$064 = 0, $trA = 0, $trB = 0, $tri1 = 0, $triangle = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 880|0;
 $zero$sroa$1$i$i$i = sp + 832|0;
 $0 = sp;
 $$sroa$113$i$i = sp + 820|0;
 $$sroa$1$i$i = sp + 808|0;
 $cp$i = sp + 796|0;
 $hfUtil = sp + 776|0;
 $tempContainer = sp + 760|0;
 $callback = sp + 752|0;
 $trA = sp + 740|0;
 $trB = sp + 728|0;
 $bounds0 = sp + 704|0;
 $orderedContainer = sp + 688|0;
 $distanceEntries = sp + 672|0;
 $origin = sp + 656|0;
 $1 = sp + 292|0;
 $2 = sp + 280|0;
 $3 = sp + 220|0;
 $lastTransform0 = sp + 16|0;
 $lastTransform1 = sp + 192|0;
 $sphereCenterInTr1 = sp + 268|0;
 $tri1 = sp + 232|0;
 $resultNormal2 = sp + 304|0;
 $resultPoint = sp + 316|0;
 $triangle = sp + 48|0;
 $4 = sp + 328|0;
 $5 = HEAP32[$shape1>>2]|0;
 $6 = (($5) + 36|0);
 $7 = (($hfUtil) + 12|0);
 $8 = (($5) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$7>>2] = $9;
 $10 = (($hfUtil) + 16|0);
 HEAP32[$10>>2] = $6;
 $11 = (($5) + 44|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(Math_fround(1.0) / $12);
 $14 = (($hfUtil) + 4|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($5) + 48|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(Math_fround(1.0) / $16);
 HEAPF32[$hfUtil>>2] = $17;
 $18 = (($5) + 52|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(Math_fround(1.0) / $19);
 $21 = (($hfUtil) + 8|0);
 HEAPF32[$21>>2] = $20;
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $22 = sp + 400|0;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,64,$22,1);
 HEAP32[$callback>>2] = ((503272 + 8|0));
 $23 = (($callback) + 4|0);
 HEAP32[$23>>2] = $tempContainer;
 $24 = (($tempContainer) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if (!($26)) {
  HEAP32[$24>>2] = 0;
 }
 $27 = (($shape0) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($shape0) + 28|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 - $30);
 $32 = (($shape0) + 60|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($shape0) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 - $35);
 $37 = (($shape0) + 64|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($shape0) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 - $40);
 HEAPF32[$trA>>2] = $31;
 $42 = (($trA) + 4|0);
 HEAPF32[$42>>2] = $36;
 $43 = (($trA) + 8|0);
 HEAPF32[$43>>2] = $41;
 $44 = (($shape1) + 12|0);
 $45 = (($shape1) + 56|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($shape1) + 28|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($46 - $48);
 $50 = (($shape1) + 60|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($shape1) + 32|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($51 - $53);
 $55 = (($shape1) + 64|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($shape1) + 36|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($56 - $58);
 HEAPF32[$trB>>2] = $49;
 $60 = (($trB) + 4|0);
 HEAPF32[$60>>2] = $54;
 $61 = (($trB) + 8|0);
 HEAPF32[$61>>2] = $59;
 $62 = Math_fround($31 - $49);
 $63 = Math_fround($36 - $54);
 $64 = Math_fround($41 - $59);
 $65 = Math_fround($62 * Math_fround(0.5));
 $66 = Math_fround($63 * Math_fround(0.5));
 $67 = Math_fround($64 * Math_fround(0.5));
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($65)))));
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($66)))));
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($67)))));
 $68 = (($shape0) + 68|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($fabsf$i$i$i + $69);
 $71 = (($shape0) + 72|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($fabsf$i$i1$i + $72);
 $74 = (($shape0) + 76|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($fabsf$i$i2$i + $75);
 $77 = Math_fround($70 + $restDistance);
 $78 = Math_fround($73 + $restDistance);
 $79 = Math_fround($76 + $restDistance);
 $80 = (($shape0) + 80|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($65 + $81);
 $83 = (($shape0) + 84|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($66 + $84);
 $86 = (($shape0) + 88|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($67 + $87);
 $89 = Math_fround($82 - $77);
 $90 = Math_fround($85 - $78);
 $91 = Math_fround($88 - $79);
 $92 = Math_fround($77 + $82);
 $93 = Math_fround($78 + $85);
 $94 = Math_fround($79 + $88);
 HEAPF32[$bounds0>>2] = $89;
 $95 = (($bounds0) + 4|0);
 HEAPF32[$95>>2] = $90;
 $96 = (($bounds0) + 8|0);
 HEAPF32[$96>>2] = $91;
 $97 = (($bounds0) + 12|0);
 HEAPF32[$97>>2] = $92;
 $98 = (($bounds0) + 16|0);
 HEAPF32[$98>>2] = $93;
 $99 = (($bounds0) + 20|0);
 HEAPF32[$99>>2] = $94;
 (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$transform1,$bounds0,1,$callback)|0);
 __ZN5physx2Gu9ContainerC2Ev($orderedContainer);
 $100 = STACKTOP; STACKTOP = STACKTOP + 256|0;;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($orderedContainer,64,$100,1);
 $101 = HEAP32[$24>>2]|0;
 $102 = (($orderedContainer) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + ($101))|0;
 $105 = HEAP32[$orderedContainer>>2]|0;
 $106 = ($104>>>0)>($105>>>0);
 if ($106) {
  (__ZN5physx2Gu9Container6ResizeEj($orderedContainer,$101)|0);
  $$pre$i4 = HEAP32[$102>>2]|0;
  $109 = $$pre$i4;
 } else {
  $109 = $103;
 }
 $107 = (($orderedContainer) + 8|0);
 $108 = (($109) + ($101))|0;
 HEAP32[$102>>2] = $108;
 __ZN5physx2Gu9ContainerC2Ev($distanceEntries);
 $110 = STACKTOP; STACKTOP = STACKTOP + 256|0;;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($distanceEntries,64,$110,1);
 $111 = HEAP32[$24>>2]|0;
 $112 = (($distanceEntries) + 4|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($113) + ($111))|0;
 $115 = HEAP32[$distanceEntries>>2]|0;
 $116 = ($114>>>0)>($115>>>0);
 if ($116) {
  (__ZN5physx2Gu9Container6ResizeEj($distanceEntries,$111)|0);
  $$pre$i = HEAP32[$112>>2]|0;
  $119 = $$pre$i;
 } else {
  $119 = $113;
 }
 $117 = (($distanceEntries) + 8|0);
 $118 = (($119) + ($111))|0;
 HEAP32[$112>>2] = $118;
 $120 = HEAP32[$107>>2]|0;
 $121 = HEAP32[$117>>2]|0;
 $122 = Math_fround(HEAPF32[$80>>2]);
 HEAPF32[$origin>>2] = $122;
 $123 = (($origin) + 4|0);
 $124 = Math_fround(HEAPF32[$83>>2]);
 HEAPF32[$123>>2] = $124;
 $125 = (($origin) + 8|0);
 $126 = Math_fround(HEAPF32[$86>>2]);
 HEAPF32[$125>>2] = $126;
 $127 = Math_fround(HEAPF32[$68>>2]);
 $128 = Math_fround($127 + $restDistance);
 $129 = Math_fround(HEAPF32[$71>>2]);
 $130 = Math_fround($129 + $restDistance);
 $131 = Math_fround(HEAPF32[$74>>2]);
 $132 = Math_fround($131 + $restDistance);
 $133 = ($atom0|0)!=(0|0);
 if ($133) {
  $134 = (($shape0) + 8|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $140 = $135;
 } else {
  $140 = Math_fround(0.0);
 }
 $136 = ($atom1|0)!=(0|0);
 if ($136) {
  $137 = (($shape1) + 8|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $141 = $138;
 } else {
  $141 = Math_fround(0.0);
 }
 $139 = $140 > $141;
 $142 = $139 ? $140 : $141;
 if ($133) {
  $143 = (($atom0) + 60|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = (($144) + 4|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $152 = $146;
 } else {
  $152 = Math_fround(1.0);
 }
 if ($136) {
  $147 = (($atom1) + 60|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = (($148) + 4|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $153 = $150;
 } else {
  $153 = Math_fround(1.0);
 }
 $151 = $152 < $153;
 $154 = $151 ? $152 : $153;
 $155 = Math_fround($142 * $154);
 $156 = HEAP32[$24>>2]|0;
 $157 = (($tempContainer) + 8|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = ($156|0)==(0);
 if ($159) {
  $count$0$lcssa = 0;
 } else {
  $160 = (($zero$sroa$1$i$i$i) + 12|0);
  $161 = (($zero$sroa$1$i$i$i) + 16|0);
  $162 = (($zero$sroa$1$i$i$i) + 4|0);
  $163 = (($zero$sroa$1$i$i$i) + 20|0);
  $164 = (($zero$sroa$1$i$i$i) + 8|0);
  $165 = (($zero$sroa$1$i$i$i) + 24|0);
  $166 = (($zero$sroa$1$i$i$i) + 28|0);
  $167 = (($zero$sroa$1$i$i$i) + 32|0);
  $168 = Math_fround($128 * Math_fround(1.10000002384185791016));
  $169 = Math_fround($130 * Math_fround(1.10000002384185791016));
  $170 = Math_fround($132 * Math_fround(1.10000002384185791016));
  $171 = (($1) + 4|0);
  $172 = (($1) + 8|0);
  $173 = (($2) + 4|0);
  $174 = (($2) + 8|0);
  $175 = (($3) + 4|0);
  $176 = (($3) + 8|0);
  $a$077 = 0;$count$078 = 0;
  while(1) {
   $177 = (($158) + ($a$077<<2)|0);
   $178 = HEAP32[$177>>2]|0;
   (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($hfUtil,$44,$zero$sroa$1$i$i$i,0,0,$178,1,1)|0);
   $179 = Math_fround(HEAPF32[$160>>2]);
   $180 = Math_fround(HEAPF32[$zero$sroa$1$i$i$i>>2]);
   $181 = Math_fround($179 - $180);
   $182 = Math_fround(HEAPF32[$161>>2]);
   $183 = Math_fround(HEAPF32[$162>>2]);
   $184 = Math_fround($182 - $183);
   $185 = Math_fround(HEAPF32[$163>>2]);
   $186 = Math_fround(HEAPF32[$164>>2]);
   $187 = Math_fround($185 - $186);
   $188 = Math_fround(HEAPF32[$165>>2]);
   $189 = Math_fround($188 - $180);
   $190 = Math_fround(HEAPF32[$166>>2]);
   $191 = Math_fround($190 - $183);
   $192 = Math_fround(HEAPF32[$167>>2]);
   $193 = Math_fround($192 - $186);
   $194 = Math_fround($184 * $193);
   $195 = Math_fround($187 * $191);
   $196 = Math_fround($194 - $195);
   $197 = Math_fround($187 * $189);
   $198 = Math_fround($181 * $193);
   $199 = Math_fround($197 - $198);
   $200 = Math_fround($181 * $191);
   $201 = Math_fround($184 * $189);
   $202 = Math_fround($200 - $201);
   $203 = Math_fround(-$196);
   $204 = Math_fround(-$199);
   $205 = Math_fround(-$202);
   $206 = Math_fround($196 * $196);
   $207 = Math_fround($199 * $199);
   $208 = Math_fround($206 + $207);
   $209 = Math_fround($202 * $202);
   $210 = Math_fround($209 + $208);
   $211 = (Math_fround(Math_sqrt((Math_fround($210)))));
   $212 = $211 > Math_fround(0.0);
   if ($212) {
    $213 = Math_fround(Math_fround(1.0) / $211);
    $214 = Math_fround($213 * $203);
    $215 = Math_fround($213 * $204);
    $216 = Math_fround($213 * $205);
    $218 = $214;$220 = $215;$223 = $216;
   } else {
    $218 = $203;$220 = $204;$223 = $205;
   }
   $217 = Math_fround($62 * $218);
   $219 = Math_fround($63 * $220);
   $221 = Math_fround($219 + $217);
   $222 = Math_fround($64 * $223);
   $224 = Math_fround($222 + $221);
   $225 = !($224 >= $155);
   if ($225) {
    $count$1 = $count$078;
   } else {
    $226 = $180 > Math_fround(8.50705866596322149529E+37);
    $227 = $226 ? Math_fround(8.50705866596322149529E+37) : $180;
    $228 = $183 > Math_fround(8.50705866596322149529E+37);
    $229 = $228 ? Math_fround(8.50705866596322149529E+37) : $183;
    $230 = $186 > Math_fround(8.50705866596322149529E+37);
    $231 = $230 ? Math_fround(8.50705866596322149529E+37) : $186;
    $232 = $180 < Math_fround(-8.50705866596322149529E+37);
    $233 = $232 ? Math_fround(-8.50705866596322149529E+37) : $180;
    $234 = $183 < Math_fround(-8.50705866596322149529E+37);
    $235 = $234 ? Math_fround(-8.50705866596322149529E+37) : $183;
    $236 = $186 < Math_fround(-8.50705866596322149529E+37);
    $237 = $236 ? Math_fround(-8.50705866596322149529E+37) : $186;
    $238 = $227 < $179;
    $239 = $238 ? $227 : $179;
    $240 = $229 < $182;
    $241 = $240 ? $229 : $182;
    $242 = $231 < $185;
    $243 = $242 ? $231 : $185;
    $244 = $233 > $179;
    $245 = $244 ? $233 : $179;
    $246 = $235 > $182;
    $247 = $246 ? $235 : $182;
    $248 = $237 > $185;
    $249 = $248 ? $237 : $185;
    $250 = $239 < $188;
    $251 = $250 ? $239 : $188;
    $252 = $241 < $190;
    $253 = $252 ? $241 : $190;
    $254 = $243 < $192;
    $255 = $254 ? $243 : $192;
    $256 = $245 > $188;
    $257 = $256 ? $245 : $188;
    $258 = $247 > $190;
    $259 = $258 ? $247 : $190;
    $260 = $249 > $192;
    $261 = $260 ? $249 : $192;
    HEAPF32[$1>>2] = $168;
    HEAPF32[$171>>2] = $169;
    HEAPF32[$172>>2] = $170;
    $262 = Math_fround($251 + $257);
    $263 = Math_fround($253 + $259);
    $264 = Math_fround($255 + $261);
    $265 = Math_fround($262 * Math_fround(0.5));
    $266 = Math_fround($263 * Math_fround(0.5));
    $267 = Math_fround($264 * Math_fround(0.5));
    HEAPF32[$2>>2] = $265;
    HEAPF32[$173>>2] = $266;
    HEAPF32[$174>>2] = $267;
    $268 = Math_fround($257 - $251);
    $269 = Math_fround($259 - $253);
    $270 = Math_fround($261 - $255);
    $271 = Math_fround($268 * Math_fround(0.5));
    $272 = Math_fround($269 * Math_fround(0.5));
    $273 = Math_fround($270 * Math_fround(0.5));
    $274 = Math_fround($271 + Math_fround(0.00999999977648258209228));
    $275 = Math_fround($272 + Math_fround(0.00999999977648258209228));
    $276 = Math_fround($273 + Math_fround(0.00999999977648258209228));
    $277 = Math_fround($274 * Math_fround(1.10000002384185791016));
    $278 = Math_fround($275 * Math_fround(1.10000002384185791016));
    $279 = Math_fround($276 * Math_fround(1.10000002384185791016));
    HEAPF32[$3>>2] = $277;
    HEAPF32[$175>>2] = $278;
    HEAPF32[$176>>2] = $279;
    $280 = (Math_fround(__Z13sweepAABBAABBRKN5physx6PxVec3ES2_S2_S2_S2_S2_($origin,$1,$2,$3,$trA,$trB)));
    $281 = !($280 <= Math_fround(1.0));
    if ($281) {
     $count$1 = $count$078;
    } else {
     $282 = ($count$078|0)==(0);
     L32: do {
      if ($282) {
       $index$0 = 0;
      } else {
       $b$072 = $count$078;
       while(1) {
        $283 = (($b$072) + -1)|0;
        $284 = (($121) + ($283<<2)|0);
        $285 = Math_fround(HEAPF32[$284>>2]);
        $286 = !($285 <= $280);
        if (!($286)) {
         $index$0 = $b$072;
         break L32;
        }
        $287 = (($121) + ($b$072<<2)|0);
        HEAPF32[$287>>2] = $285;
        $288 = (($120) + ($283<<2)|0);
        $289 = HEAP32[$288>>2]|0;
        $290 = (($120) + ($b$072<<2)|0);
        HEAP32[$290>>2] = $289;
        $291 = ($283|0)==(0);
        if ($291) {
         $index$0 = 0;
         break;
        } else {
         $b$072 = $283;
        }
       }
      }
     } while(0);
     $292 = HEAP32[$177>>2]|0;
     $293 = (($120) + ($index$0<<2)|0);
     HEAP32[$293>>2] = $292;
     $294 = (($121) + ($index$0<<2)|0);
     HEAPF32[$294>>2] = $280;
     $295 = (($count$078) + 1)|0;
     $count$1 = $295;
    }
   }
   $296 = (($a$077) + 1)|0;
   $exitcond90 = ($296|0)==($156|0);
   if ($exitcond90) {
    $count$0$lcssa = $count$1;
    break;
   } else {
    $a$077 = $296;$count$078 = $count$1;
   }
  }
 }
 HEAPF32[$worldNormal>>2] = Math_fround(0.0);
 $297 = (($worldNormal) + 4|0);
 HEAPF32[$297>>2] = Math_fround(0.0);
 $298 = (($worldNormal) + 8|0);
 HEAPF32[$298>>2] = Math_fround(0.0);
 HEAPF32[$worldPoint>>2] = Math_fround(0.0);
 $299 = (($worldPoint) + 4|0);
 HEAPF32[$299>>2] = Math_fround(0.0);
 $300 = (($worldPoint) + 8|0);
 HEAPF32[$300>>2] = Math_fround(0.0);
 $301 = (($context) + 8756|0);
 HEAP32[$301>>2] = -1;
 $302 = Math_fround(HEAPF32[$29>>2]);
 $303 = Math_fround(HEAPF32[$34>>2]);
 $304 = Math_fround(HEAPF32[$39>>2]);
 $305 = (($shape0) + 8|0);
 $306 = Math_fround(HEAPF32[$305>>2]);
 $307 = Math_fround($306 * $306);
 $308 = HEAP32[$shape0>>2]|0;
 $309 = (($308) + 36|0);
 $310 = HEAP32[$309>>2]|0;
 $311 = (($shape0) + 12|0);
 $312 = Math_fround(HEAPF32[$311>>2]);
 HEAPF32[$lastTransform0>>2] = $312;
 $313 = (($shape0) + 16|0);
 $314 = Math_fround(HEAPF32[$313>>2]);
 $315 = (($lastTransform0) + 4|0);
 HEAPF32[$315>>2] = $314;
 $316 = (($shape0) + 20|0);
 $317 = Math_fround(HEAPF32[$316>>2]);
 $318 = (($lastTransform0) + 8|0);
 HEAPF32[$318>>2] = $317;
 $319 = (($shape0) + 24|0);
 $320 = Math_fround(HEAPF32[$319>>2]);
 $321 = (($lastTransform0) + 12|0);
 HEAPF32[$321>>2] = $320;
 $322 = (($lastTransform0) + 16|0);
 HEAPF32[$322>>2] = $302;
 $323 = (($lastTransform0) + 20|0);
 HEAPF32[$323>>2] = $303;
 $324 = (($lastTransform0) + 24|0);
 HEAPF32[$324>>2] = $304;
 $325 = Math_fround(HEAPF32[$transform1>>2]);
 HEAPF32[$lastTransform1>>2] = $325;
 $326 = (($transform1) + 4|0);
 $327 = Math_fround(HEAPF32[$326>>2]);
 $328 = (($lastTransform1) + 4|0);
 HEAPF32[$328>>2] = $327;
 $329 = (($transform1) + 8|0);
 $330 = Math_fround(HEAPF32[$329>>2]);
 $331 = (($lastTransform1) + 8|0);
 HEAPF32[$331>>2] = $330;
 $332 = (($transform1) + 12|0);
 $333 = Math_fround(HEAPF32[$332>>2]);
 $334 = (($lastTransform1) + 12|0);
 HEAPF32[$334>>2] = $333;
 $335 = (($transform1) + 16|0);
 $336 = Math_fround(HEAPF32[$335>>2]);
 $337 = (($lastTransform1) + 16|0);
 HEAPF32[$337>>2] = $336;
 $338 = (($transform1) + 20|0);
 $339 = Math_fround(HEAPF32[$338>>2]);
 $340 = (($lastTransform1) + 20|0);
 HEAPF32[$340>>2] = $339;
 $341 = (($transform1) + 24|0);
 $342 = Math_fround(HEAPF32[$341>>2]);
 $343 = (($lastTransform1) + 24|0);
 HEAPF32[$343>>2] = $342;
 if ($136) {
  $344 = (($atom1) + 64|0);
  $345 = HEAP32[$344>>2]|0;
  $346 = (($345) + 124|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  $348 = $347 == Math_fround(0.0);
  if (!($348)) {
   $349 = Math_fround(HEAPF32[$44>>2]);
   HEAPF32[$lastTransform1>>2] = $349;
   $350 = (($shape1) + 16|0);
   $351 = Math_fround(HEAPF32[$350>>2]);
   HEAPF32[$328>>2] = $351;
   $352 = (($shape1) + 20|0);
   $353 = Math_fround(HEAPF32[$352>>2]);
   HEAPF32[$331>>2] = $353;
   $354 = (($shape1) + 24|0);
   $355 = Math_fround(HEAPF32[$354>>2]);
   HEAPF32[$334>>2] = $355;
   $356 = Math_fround(HEAPF32[$47>>2]);
   HEAPF32[$337>>2] = $356;
   $357 = Math_fround(HEAPF32[$52>>2]);
   HEAPF32[$340>>2] = $357;
   $358 = Math_fround(HEAPF32[$57>>2]);
   HEAPF32[$343>>2] = $358;
  }
 }
 $359 = Math_fround($302 - $336);
 $360 = Math_fround($303 - $339);
 $361 = Math_fround($304 - $342);
 $362 = Math_fround($359 * Math_fround(2.0));
 $363 = Math_fround($360 * Math_fround(2.0));
 $364 = Math_fround($361 * Math_fround(2.0));
 $365 = Math_fround($333 * $333);
 $366 = Math_fround($365 + Math_fround(-0.5));
 $367 = Math_fround($362 * $325);
 $368 = Math_fround($363 * $327);
 $369 = Math_fround($367 + $368);
 $370 = Math_fround($364 * $330);
 $371 = Math_fround($369 + $370);
 $372 = Math_fround($362 * $366);
 $373 = Math_fround($364 * $327);
 $374 = Math_fround($363 * $330);
 $375 = Math_fround($373 - $374);
 $376 = Math_fround($333 * $375);
 $377 = Math_fround($372 - $376);
 $378 = Math_fround($325 * $371);
 $379 = Math_fround($378 + $377);
 $380 = Math_fround($363 * $366);
 $381 = Math_fround($362 * $330);
 $382 = Math_fround($364 * $325);
 $383 = Math_fround($381 - $382);
 $384 = Math_fround($333 * $383);
 $385 = Math_fround($380 - $384);
 $386 = Math_fround($327 * $371);
 $387 = Math_fround($386 + $385);
 $388 = Math_fround($364 * $366);
 $389 = Math_fround($363 * $325);
 $390 = Math_fround($362 * $327);
 $391 = Math_fround($389 - $390);
 $392 = Math_fround($333 * $391);
 $393 = Math_fround($388 - $392);
 $394 = Math_fround($330 * $371);
 $395 = Math_fround($393 + $394);
 HEAPF32[$sphereCenterInTr1>>2] = $379;
 $396 = (($sphereCenterInTr1) + 4|0);
 HEAPF32[$396>>2] = $387;
 $397 = (($sphereCenterInTr1) + 8|0);
 HEAPF32[$397>>2] = $395;
 $398 = ($count$0$lcssa|0)==(0);
 if ($398) {
  $$lcssa = Math_fround(0.0);$$lcssa59 = Math_fround(0.0);$$lcssa60 = Math_fround(0.0);$$lcssa61 = Math_fround(0.0);$$lcssa62 = Math_fround(0.0);$$lcssa63 = Math_fround(0.0);$589 = $333;$592 = $325;$594 = $327;$597 = $330;$minTOI$0$lcssa = Math_fround(3.40282346638528859812E+38);
  $585 = Math_fround($$lcssa60 * Math_fround(2.0));
  $586 = Math_fround($$lcssa59 * Math_fround(2.0));
  $587 = Math_fround($$lcssa * Math_fround(2.0));
  $588 = Math_fround($589 * $589);
  $590 = Math_fround($588 + Math_fround(-0.5));
  $591 = Math_fround($585 * $592);
  $593 = Math_fround($586 * $594);
  $595 = Math_fround($591 + $593);
  $596 = Math_fround($587 * $597);
  $598 = Math_fround($595 + $596);
  $599 = Math_fround($585 * $590);
  $600 = Math_fround($587 * $594);
  $601 = Math_fround($586 * $597);
  $602 = Math_fround($600 - $601);
  $603 = Math_fround($589 * $602);
  $604 = Math_fround($599 + $603);
  $605 = Math_fround($592 * $598);
  $606 = Math_fround($605 + $604);
  $607 = Math_fround($586 * $590);
  $608 = Math_fround($585 * $597);
  $609 = Math_fround($587 * $592);
  $610 = Math_fround($608 - $609);
  $611 = Math_fround($589 * $610);
  $612 = Math_fround($607 + $611);
  $613 = Math_fround($594 * $598);
  $614 = Math_fround($613 + $612);
  $615 = Math_fround($587 * $590);
  $616 = Math_fround($586 * $592);
  $617 = Math_fround($585 * $594);
  $618 = Math_fround($616 - $617);
  $619 = Math_fround($589 * $618);
  $620 = Math_fround($615 + $619);
  $621 = Math_fround($597 * $598);
  $622 = Math_fround($620 + $621);
  HEAPF32[$worldNormal>>2] = $606;
  HEAPF32[$297>>2] = $614;
  HEAPF32[$298>>2] = $622;
  HEAPF32[$worldPoint>>2] = $$lcssa63;
  HEAPF32[$299>>2] = $$lcssa62;
  HEAPF32[$300>>2] = $$lcssa61;
  __ZN5physx2Gu9ContainerD2Ev($distanceEntries);
  __ZN5physx2Gu9ContainerD2Ev($orderedContainer);
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return (Math_fround($minTOI$0$lcssa));
 }
 $399 = (($tri1) + 4|0);
 $400 = (($tri1) + 8|0);
 $401 = (($tri1) + 12|0);
 $402 = (($tri1) + 16|0);
 $403 = (($tri1) + 20|0);
 $404 = (($tri1) + 24|0);
 $405 = (($tri1) + 28|0);
 $406 = (($tri1) + 32|0);
 $407 = (($triangle) + 64|0);
 $408 = (($triangle) + 80|0);
 $409 = (($triangle) + 16|0);
 $410 = (($triangle) + 20|0);
 $411 = (($triangle) + 32|0);
 $412 = (($triangle) + 36|0);
 $413 = (($triangle) + 48|0);
 $414 = (($triangle) + 52|0);
 $415 = (($triangle) + 4|0);
 $416 = (($triangle) + 8|0);
 $417 = (($triangle) + 12|0);
 $418 = (($triangle) + 96|0);
 $419 = (($triangle) + 100|0);
 $420 = (($triangle) + 104|0);
 $421 = (($triangle) + 108|0);
 $422 = (($triangle) + 112|0);
 $423 = (($triangle) + 116|0);
 $424 = (($triangle) + 120|0);
 $425 = (($triangle) + 124|0);
 $426 = (($triangle) + 128|0);
 $427 = (($triangle) + 132|0);
 $428 = (($triangle) + 136|0);
 $429 = (($triangle) + 140|0);
 $430 = (503216 + ($310<<2)|0);
 $431 = HEAP32[$430>>2]|0;
 $432 = (($4) + 4|0);
 $433 = (($4) + 8|0);
 $434 = (($4) + 12|0);
 $435 = (($4) + 16|0);
 $436 = (($4) + 20|0);
 $437 = (($4) + 24|0);
 $438 = (($4) + 28|0);
 $439 = (($4) + 32|0);
 $440 = (($4) + 36|0);
 $441 = (($4) + 40|0);
 $442 = (($4) + 44|0);
 $443 = (($4) + 48|0);
 $444 = (($4) + 52|0);
 $445 = (($4) + 56|0);
 $446 = (($4) + 60|0);
 $447 = (($4) + 64|0);
 $448 = (($4) + 68|0);
 $449 = (($resultPoint) + 4|0);
 $450 = (($resultPoint) + 8|0);
 $451 = (($zero$sroa$1$i$i$i) + 4|0);
 $452 = (($zero$sroa$1$i$i$i) + 8|0);
 $453 = (($0) + 4|0);
 $454 = (($0) + 8|0);
 $455 = (($cp$i) + 4|0);
 $456 = (($cp$i) + 8|0);
 $457 = Math_fround($306 * Math_fround(2.0));
 $623 = Math_fround(0.0);$624 = Math_fround(0.0);$625 = Math_fround(0.0);$626 = Math_fround(0.0);$627 = Math_fround(0.0);$628 = Math_fround(0.0);$minTOI$065 = Math_fround(3.40282346638528859812E+38);$ti$064 = 0;
 while(1) {
  $458 = (($120) + ($ti$064<<2)|0);
  $459 = HEAP32[$458>>2]|0;
  (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($hfUtil,$44,$tri1,0,0,$459,0,0)|0);
  $460 = Math_fround(HEAPF32[$tri1>>2]);
  $461 = Math_fround(HEAPF32[$399>>2]);
  $462 = Math_fround(HEAPF32[$400>>2]);
  $463 = Math_fround(HEAPF32[$401>>2]);
  $464 = Math_fround(HEAPF32[$402>>2]);
  $465 = Math_fround(HEAPF32[$403>>2]);
  $466 = Math_fround(HEAPF32[$404>>2]);
  $467 = Math_fround(HEAPF32[$405>>2]);
  $468 = Math_fround(HEAPF32[$406>>2]);
  HEAP32[$408>>2] = 7;
  HEAPF32[$413>>2] = Math_fround(0.0);
  ;HEAP32[$414+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$414+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$414+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  ;HEAP32[$407+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$407+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$407+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$407+12>>2]=HEAP32[$0+12>>2]|0;
  $469 = Math_fround($460 + $463);
  $470 = Math_fround($461 + $464);
  $471 = Math_fround($462 + $465);
  $472 = Math_fround($469 + $466);
  $473 = Math_fround($470 + $467);
  $474 = Math_fround($471 + $468);
  $475 = Math_fround($472 * Math_fround(0.333332985639572143555));
  $476 = Math_fround($473 * Math_fround(0.333332985639572143555));
  $477 = Math_fround($474 * Math_fround(0.333332985639572143555));
  HEAPF32[$triangle>>2] = $475;
  HEAPF32[$415>>2] = $476;
  HEAPF32[$416>>2] = $477;
  HEAPF32[$417>>2] = Math_fround(0.0);
  HEAPF32[$418>>2] = $460;
  HEAPF32[$419>>2] = $461;
  HEAPF32[$420>>2] = $462;
  HEAPF32[$421>>2] = Math_fround(0.0);
  HEAPF32[$422>>2] = $463;
  HEAPF32[$423>>2] = $464;
  HEAPF32[$424>>2] = $465;
  HEAPF32[$425>>2] = Math_fround(0.0);
  HEAPF32[$426>>2] = $466;
  HEAPF32[$427>>2] = $467;
  HEAPF32[$428>>2] = $468;
  HEAPF32[$429>>2] = Math_fround(0.0);
  HEAPF32[$409>>2] = Math_fround(0.0);
  ;HEAP32[$410+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$410+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$410+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
  HEAPF32[$411>>2] = Math_fround(3.40282346638528859812E+38);
  ;HEAP32[$412+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$412+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$412+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
  HEAPF32[$4>>2] = Math_fround(1.0);
  HEAPF32[$432>>2] = Math_fround(0.0);
  HEAPF32[$433>>2] = Math_fround(0.0);
  HEAPF32[$434>>2] = Math_fround(0.0);
  HEAPF32[$435>>2] = Math_fround(1.0);
  HEAPF32[$436>>2] = Math_fround(0.0);
  HEAPF32[$437>>2] = Math_fround(0.0);
  HEAPF32[$438>>2] = Math_fround(0.0);
  HEAPF32[$439>>2] = Math_fround(1.0);
  HEAPF32[$440>>2] = Math_fround(1.0);
  HEAPF32[$441>>2] = Math_fround(0.0);
  HEAPF32[$442>>2] = Math_fround(0.0);
  HEAPF32[$443>>2] = Math_fround(0.0);
  HEAPF32[$444>>2] = Math_fround(1.0);
  HEAPF32[$445>>2] = Math_fround(0.0);
  HEAPF32[$446>>2] = Math_fround(0.0);
  HEAPF32[$447>>2] = Math_fround(0.0);
  HEAPF32[$448>>2] = Math_fround(1.0);
  $478 = (Math_fround(FUNCTION_TABLE_fiiiiiifiiiiiif[$431 & 7]($shape0,$shape1,$transform0,$transform1,$lastTransform0,$lastTransform1,$restDistance,$resultNormal2,$resultPoint,$cache,$context,$4,$triangle,Math_fround(0.0))));
  $479 = !($478 <= Math_fround(0.0));
  if ($479) {
   $res$0 = $478;
  } else {
   $480 = Math_fround(HEAPF32[$401>>2]);
   $481 = Math_fround(HEAPF32[$tri1>>2]);
   $482 = Math_fround($480 - $481);
   $483 = Math_fround(HEAPF32[$402>>2]);
   $484 = Math_fround(HEAPF32[$399>>2]);
   $485 = Math_fround($483 - $484);
   $486 = Math_fround(HEAPF32[$403>>2]);
   $487 = Math_fround(HEAPF32[$400>>2]);
   $488 = Math_fround($486 - $487);
   $489 = Math_fround(HEAPF32[$404>>2]);
   $490 = Math_fround($489 - $481);
   $491 = Math_fround(HEAPF32[$405>>2]);
   $492 = Math_fround($491 - $484);
   $493 = Math_fround(HEAPF32[$406>>2]);
   $494 = Math_fround($493 - $487);
   $495 = Math_fround($482 + $481);
   $496 = Math_fround($485 + $484);
   $497 = Math_fround($488 + $487);
   HEAPF32[$zero$sroa$1$i$i$i>>2] = $495;
   HEAPF32[$451>>2] = $496;
   HEAPF32[$452>>2] = $497;
   $498 = Math_fround($490 + $481);
   $499 = Math_fround($492 + $484);
   $500 = Math_fround($494 + $487);
   HEAPF32[$0>>2] = $498;
   HEAPF32[$453>>2] = $499;
   HEAPF32[$454>>2] = $500;
   __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i,$sphereCenterInTr1,$tri1,$zero$sroa$1$i$i$i,$0,$$sroa$113$i$i,$$sroa$1$i$i);
   $501 = Math_fround(HEAPF32[$cp$i>>2]);
   $502 = Math_fround(HEAPF32[$sphereCenterInTr1>>2]);
   $503 = Math_fround($501 - $502);
   $504 = Math_fround(HEAPF32[$455>>2]);
   $505 = Math_fround(HEAPF32[$396>>2]);
   $506 = Math_fround($504 - $505);
   $507 = Math_fround(HEAPF32[$456>>2]);
   $508 = Math_fround(HEAPF32[$397>>2]);
   $509 = Math_fround($507 - $508);
   $510 = Math_fround($503 * $503);
   $511 = Math_fround($506 * $506);
   $512 = Math_fround($510 + $511);
   $513 = Math_fround($509 * $509);
   $514 = Math_fround($512 + $513);
   $515 = $514 < $307;
   if ($515) {
    $516 = Math_fround($485 * $494);
    $517 = Math_fround($488 * $492);
    $518 = Math_fround($516 - $517);
    $519 = Math_fround($488 * $490);
    $520 = Math_fround($482 * $494);
    $521 = Math_fround($519 - $520);
    $522 = Math_fround($482 * $492);
    $523 = Math_fround($485 * $490);
    $524 = Math_fround($522 - $523);
    $525 = (Math_fround(Math_sqrt((Math_fround($514)))));
    $526 = Math_fround($525 - $306);
    $527 = Math_fround(HEAPF32[$tri1>>2]);
    $528 = Math_fround($518 * $527);
    $529 = Math_fround(HEAPF32[$399>>2]);
    $530 = Math_fround($521 * $529);
    $531 = Math_fround($528 + $530);
    $532 = Math_fround(HEAPF32[$400>>2]);
    $533 = Math_fround($524 * $532);
    $534 = Math_fround($531 + $533);
    $535 = Math_fround($379 * $518);
    $536 = Math_fround($387 * $521);
    $537 = Math_fround($535 + $536);
    $538 = Math_fround($395 * $524);
    $539 = Math_fround($538 + $537);
    $540 = Math_fround($539 - $534);
    $541 = $540 > Math_fround(0.0);
    if ($541) {
     $542 = Math_fround($457 - $525);
     $543 = Math_fround(-$542);
     $res$0 = $543;
    } else {
     $res$0 = $526;
    }
   } else {
    $res$0 = Math_fround(0.0);
   }
  }
  $544 = $res$0 < $minTOI$065;
  if ($544) {
   $545 = Math_fround(HEAPF32[$401>>2]);
   $546 = Math_fround(HEAPF32[$tri1>>2]);
   $547 = Math_fround($545 - $546);
   $548 = Math_fround(HEAPF32[$402>>2]);
   $549 = Math_fround(HEAPF32[$399>>2]);
   $550 = Math_fround($548 - $549);
   $551 = Math_fround(HEAPF32[$403>>2]);
   $552 = Math_fround(HEAPF32[$400>>2]);
   $553 = Math_fround($551 - $552);
   $554 = Math_fround(HEAPF32[$404>>2]);
   $555 = Math_fround($554 - $546);
   $556 = Math_fround(HEAPF32[$405>>2]);
   $557 = Math_fround($556 - $549);
   $558 = Math_fround(HEAPF32[$406>>2]);
   $559 = Math_fround($558 - $552);
   $560 = Math_fround($550 * $559);
   $561 = Math_fround($553 * $557);
   $562 = Math_fround($560 - $561);
   $563 = Math_fround($553 * $555);
   $564 = Math_fround($547 * $559);
   $565 = Math_fround($563 - $564);
   $566 = Math_fround($547 * $557);
   $567 = Math_fround($550 * $555);
   $568 = Math_fround($566 - $567);
   $569 = Math_fround($562 * $562);
   $570 = Math_fround($565 * $565);
   $571 = Math_fround($569 + $570);
   $572 = Math_fround($568 * $568);
   $573 = Math_fround($572 + $571);
   $574 = (Math_fround(Math_sqrt((Math_fround($573)))));
   $575 = $574 > Math_fround(0.0);
   if ($575) {
    $576 = Math_fround(Math_fround(1.0) / $574);
    $577 = Math_fround($562 * $576);
    $578 = Math_fround($565 * $576);
    $579 = Math_fround($568 * $576);
    $635 = $579;$636 = $578;$637 = $577;
   } else {
    $635 = $568;$636 = $565;$637 = $562;
   }
   $580 = Math_fround(HEAPF32[$resultPoint>>2]);
   $581 = Math_fround(HEAPF32[$449>>2]);
   $582 = Math_fround(HEAPF32[$450>>2]);
   $583 = HEAP32[$458>>2]|0;
   HEAP32[$301>>2] = $583;
   $629 = $635;$630 = $636;$631 = $637;$632 = $582;$633 = $581;$634 = $580;$minTOI$1 = $res$0;
  } else {
   $629 = $628;$630 = $627;$631 = $626;$632 = $625;$633 = $624;$634 = $623;$minTOI$1 = $minTOI$065;
  }
  $584 = (($ti$064) + 1)|0;
  $exitcond = ($584|0)==($count$0$lcssa|0);
  if ($exitcond) {
   break;
  } else {
   $623 = $634;$624 = $633;$625 = $632;$626 = $631;$627 = $630;$628 = $629;$minTOI$065 = $minTOI$1;$ti$064 = $584;
  }
 }
 $$pre = Math_fround(HEAPF32[$332>>2]);
 $$pre91 = Math_fround(HEAPF32[$transform1>>2]);
 $$pre92 = Math_fround(HEAPF32[$326>>2]);
 $$pre93 = Math_fround(HEAPF32[$329>>2]);
 $$lcssa = $629;$$lcssa59 = $630;$$lcssa60 = $631;$$lcssa61 = $632;$$lcssa62 = $633;$$lcssa63 = $634;$589 = $$pre;$592 = $$pre91;$594 = $$pre92;$597 = $$pre93;$minTOI$0$lcssa = $minTOI$1;
 $585 = Math_fround($$lcssa60 * Math_fround(2.0));
 $586 = Math_fround($$lcssa59 * Math_fround(2.0));
 $587 = Math_fround($$lcssa * Math_fround(2.0));
 $588 = Math_fround($589 * $589);
 $590 = Math_fround($588 + Math_fround(-0.5));
 $591 = Math_fround($585 * $592);
 $593 = Math_fround($586 * $594);
 $595 = Math_fround($591 + $593);
 $596 = Math_fround($587 * $597);
 $598 = Math_fround($595 + $596);
 $599 = Math_fround($585 * $590);
 $600 = Math_fround($587 * $594);
 $601 = Math_fround($586 * $597);
 $602 = Math_fround($600 - $601);
 $603 = Math_fround($589 * $602);
 $604 = Math_fround($599 + $603);
 $605 = Math_fround($592 * $598);
 $606 = Math_fround($605 + $604);
 $607 = Math_fround($586 * $590);
 $608 = Math_fround($585 * $597);
 $609 = Math_fround($587 * $592);
 $610 = Math_fround($608 - $609);
 $611 = Math_fround($589 * $610);
 $612 = Math_fround($607 + $611);
 $613 = Math_fround($594 * $598);
 $614 = Math_fround($613 + $612);
 $615 = Math_fround($587 * $590);
 $616 = Math_fround($586 * $592);
 $617 = Math_fround($585 * $594);
 $618 = Math_fround($616 - $617);
 $619 = Math_fround($589 * $618);
 $620 = Math_fround($615 + $619);
 $621 = Math_fround($597 * $598);
 $622 = Math_fround($620 + $621);
 HEAPF32[$worldNormal>>2] = $606;
 HEAPF32[$297>>2] = $614;
 HEAPF32[$298>>2] = $622;
 HEAPF32[$worldPoint>>2] = $$lcssa63;
 HEAPF32[$299>>2] = $$lcssa62;
 HEAPF32[$300>>2] = $$lcssa61;
 __ZN5physx2Gu9ContainerD2Ev($distanceEntries);
 __ZN5physx2Gu9ContainerD2Ev($orderedContainer);
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return (Math_fround($minTOI$0$lcssa));
}
function __ZN5physxL23PxcSweepSphereTrianglesERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf($shape0,$shape1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$meshScaling,$triangle,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $meshScaling = $meshScaling|0;
 $triangle = $triangle|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$0 = Math_fround(0), $$sroa$143 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $capsule = 0, $capsuleTrans = 0, $closestA = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trB = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $zero$sroa$1$i$i$i = sp + 304|0;
 $0 = sp + 288|0;
 $zeroV = sp + 272|0;
 $capsule = sp + 128|0;
 $$sroa$143 = sp + 368|0;
 $capsuleTrans = sp + 96|0;
 $toi = sp + 80|0;
 $trB = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 64|0;
 $1 = HEAP32[$shape0>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $2 = (($1) + 40|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($capsule) + 64|0);
 $5 = (($capsule) + 80|0);
 HEAP32[$5>>2] = 4;
 $6 = (($capsule) + 16|0);
 $7 = (($capsule) + 20|0);
 $8 = (($capsule) + 32|0);
 $9 = (($capsule) + 36|0);
 $10 = (($capsule) + 48|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($capsule) + 52|0);
 ;HEAP32[$11+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $12 = (($capsule) + 96|0);
 $13 = (($capsule) + 112|0);
 ;HEAP32[$capsule+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $14 = (($capsule) + 128|0);
 HEAPF32[$14>>2] = $3;
 $15 = (($capsule) + 132|0);
 ;HEAP32[$15+0>>2]=HEAP32[$$sroa$143+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$$sroa$143+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$$sroa$143+8>>2]|0;
 ;HEAP32[$12+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$13+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$6>>2] = $3;
 ;HEAP32[$7+0>>2]=HEAP32[$$sroa$143+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$$sroa$143+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$$sroa$143+8>>2]|0;
 HEAPF32[$8>>2] = $3;
 ;HEAP32[$9+0>>2]=HEAP32[$$sroa$143+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$$sroa$143+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$$sroa$143+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$0+12>>2]|0;
 $16 = Math_fround(HEAPF32[$transform0>>2]);
 $17 = (($transform0) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transform0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 12|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($lastTm0) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($23) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($23) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$transform1>>2]);
 $30 = (($transform1) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($transform1) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($transform1) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($lastTm1) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($36) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($36) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 HEAPF32[$capsuleTrans>>2] = $16;
 $42 = (($capsuleTrans) + 4|0);
 HEAPF32[$42>>2] = $18;
 $43 = (($capsuleTrans) + 8|0);
 HEAPF32[$43>>2] = $20;
 $44 = (($capsuleTrans) + 12|0);
 HEAPF32[$44>>2] = $22;
 $45 = (($capsuleTrans) + 16|0);
 HEAPF32[$45>>2] = $24;
 $46 = (($capsuleTrans) + 20|0);
 HEAPF32[$46>>2] = $26;
 $47 = (($capsuleTrans) + 24|0);
 HEAPF32[$47>>2] = $28;
 $48 = (($capsuleTrans) + 28|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = Math_fround(-$16);
 $50 = Math_fround(-$18);
 $51 = Math_fround(-$20);
 $52 = Math_fround($37 - $24);
 $53 = Math_fround($39 - $26);
 $54 = Math_fround($41 - $28);
 $55 = Math_fround($22 * $22);
 $56 = Math_fround($55 + Math_fround(-0.5));
 $57 = Math_fround($56 * $52);
 $58 = Math_fround($56 * $53);
 $59 = Math_fround($56 * $54);
 $60 = Math_fround($54 * $50);
 $61 = Math_fround($53 * $51);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($52 * $51);
 $64 = Math_fround($54 * $49);
 $65 = Math_fround($63 - $64);
 $66 = Math_fround($53 * $49);
 $67 = Math_fround($52 * $50);
 $68 = Math_fround($66 - $67);
 $69 = Math_fround($22 * $62);
 $70 = Math_fround($22 * $65);
 $71 = Math_fround($22 * $68);
 $72 = Math_fround($57 + $69);
 $73 = Math_fround($58 + $70);
 $74 = Math_fround($59 + $71);
 $75 = Math_fround($52 * $49);
 $76 = Math_fround($53 * $50);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($54 * $51);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($79 * $49);
 $81 = Math_fround($79 * $50);
 $82 = Math_fround($79 * $51);
 $83 = Math_fround($80 + $72);
 $84 = Math_fround($81 + $73);
 $85 = Math_fround($74 + $82);
 $86 = Math_fround($83 * Math_fround(2.0));
 $87 = Math_fround($84 * Math_fround(2.0));
 $88 = Math_fround($85 * Math_fround(2.0));
 $89 = Math_fround($35 * $22);
 $90 = Math_fround($29 * $49);
 $91 = Math_fround($31 * $50);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($33 * $51);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($89 - $94);
 $96 = Math_fround($35 * $49);
 $97 = Math_fround($35 * $50);
 $98 = Math_fround($35 * $51);
 $99 = Math_fround($29 * $22);
 $100 = Math_fround($31 * $22);
 $101 = Math_fround($33 * $22);
 $102 = Math_fround($33 * $50);
 $103 = Math_fround($31 * $51);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($29 * $51);
 $106 = Math_fround($33 * $49);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($31 * $49);
 $109 = Math_fround($29 * $50);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($96 + $99);
 $112 = Math_fround($97 + $100);
 $113 = Math_fround($101 + $98);
 $114 = Math_fround($104 + $111);
 $115 = Math_fround($107 + $112);
 $116 = Math_fround($110 + $113);
 $117 = (($zero$sroa$1$i$i$i) + 48|0);
 HEAPF32[$117>>2] = $86;
 $118 = (($zero$sroa$1$i$i$i) + 52|0);
 HEAPF32[$118>>2] = $87;
 $119 = (($zero$sroa$1$i$i$i) + 56|0);
 HEAPF32[$119>>2] = $88;
 $120 = (($zero$sroa$1$i$i$i) + 60|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = Math_fround($114 + $114);
 $122 = Math_fround($115 + $115);
 $123 = Math_fround($116 + $116);
 $124 = Math_fround($114 * $121);
 $125 = Math_fround($115 * $122);
 $126 = Math_fround($116 * $123);
 $127 = Math_fround($115 * $121);
 $128 = Math_fround($116 * $121);
 $129 = Math_fround($95 * $121);
 $130 = Math_fround($116 * $122);
 $131 = Math_fround($95 * $122);
 $132 = Math_fround($95 * $123);
 $133 = Math_fround(Math_fround(1.0) - $124);
 $134 = Math_fround(Math_fround(1.0) - $125);
 $135 = Math_fround($134 - $126);
 $136 = Math_fround($127 + $132);
 $137 = Math_fround($128 - $131);
 $138 = Math_fround($127 - $132);
 $139 = Math_fround($133 - $126);
 $140 = Math_fround($130 + $129);
 $141 = Math_fround($128 + $131);
 $142 = Math_fround($130 - $129);
 $143 = Math_fround($133 - $125);
 HEAPF32[$zero$sroa$1$i$i$i>>2] = $135;
 $144 = (($zero$sroa$1$i$i$i) + 4|0);
 HEAPF32[$144>>2] = $136;
 $145 = (($zero$sroa$1$i$i$i) + 8|0);
 HEAPF32[$145>>2] = $137;
 $146 = (($zero$sroa$1$i$i$i) + 12|0);
 HEAPF32[$146>>2] = Math_fround(0.0);
 $147 = (($zero$sroa$1$i$i$i) + 16|0);
 HEAPF32[$147>>2] = $138;
 $148 = (($zero$sroa$1$i$i$i) + 20|0);
 HEAPF32[$148>>2] = $139;
 $149 = (($zero$sroa$1$i$i$i) + 24|0);
 HEAPF32[$149>>2] = $140;
 $150 = (($zero$sroa$1$i$i$i) + 28|0);
 HEAPF32[$150>>2] = Math_fround(0.0);
 $151 = (($zero$sroa$1$i$i$i) + 32|0);
 HEAPF32[$151>>2] = $141;
 $152 = (($zero$sroa$1$i$i$i) + 36|0);
 HEAPF32[$152>>2] = $142;
 $153 = (($zero$sroa$1$i$i$i) + 40|0);
 HEAPF32[$153>>2] = $143;
 $154 = (($zero$sroa$1$i$i$i) + 44|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $155 = (($transform0) + 16|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($transform0) + 20|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($transform0) + 24|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($transform1) + 16|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = (($transform1) + 20|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = (($transform1) + 24|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = Math_fround($156 - $24);
 $168 = Math_fround($158 - $26);
 $169 = Math_fround($160 - $28);
 $170 = Math_fround($162 - $37);
 $171 = Math_fround($164 - $39);
 $172 = Math_fround($166 - $41);
 HEAPF32[$trB>>2] = $170;
 $173 = (($trB) + 4|0);
 HEAPF32[$173>>2] = $171;
 $174 = (($trB) + 8|0);
 HEAPF32[$174>>2] = $172;
 $175 = (($trB) + 12|0);
 HEAPF32[$175>>2] = Math_fround(0.0);
 $176 = Math_fround($167 - $170);
 $177 = Math_fround($168 - $171);
 $178 = Math_fround($169 - $172);
 $179 = Math_fround(HEAPF32[$capsuleTrans>>2]);
 $180 = Math_fround(HEAPF32[$42>>2]);
 $181 = Math_fround(HEAPF32[$43>>2]);
 $182 = Math_fround(HEAPF32[$44>>2]);
 $183 = Math_fround($182 * $182);
 $184 = Math_fround($183 + Math_fround(-0.5));
 $185 = Math_fround($176 * $184);
 $186 = Math_fround($177 * $184);
 $187 = Math_fround($178 * $184);
 $188 = Math_fround($178 * $180);
 $189 = Math_fround($177 * $181);
 $190 = Math_fround($188 - $189);
 $191 = Math_fround($176 * $181);
 $192 = Math_fround($179 * $178);
 $193 = Math_fround($191 - $192);
 $194 = Math_fround($177 * $179);
 $195 = Math_fround($176 * $180);
 $196 = Math_fround($194 - $195);
 $197 = Math_fround($182 * $190);
 $198 = Math_fround($182 * $193);
 $199 = Math_fround($182 * $196);
 $200 = Math_fround($185 - $197);
 $201 = Math_fround($186 - $198);
 $202 = Math_fround($187 - $199);
 $203 = Math_fround($176 * $179);
 $204 = Math_fround($177 * $180);
 $205 = Math_fround($203 + $204);
 $206 = Math_fround($178 * $181);
 $207 = Math_fround($205 + $206);
 $208 = Math_fround($179 * $207);
 $209 = Math_fround($180 * $207);
 $210 = Math_fround($181 * $207);
 $211 = Math_fround($208 + $200);
 $212 = Math_fround($209 + $201);
 $213 = Math_fround($210 + $202);
 $214 = Math_fround($211 * Math_fround(2.0));
 $215 = Math_fround($212 * Math_fround(2.0));
 $216 = Math_fround($213 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $214;
 $217 = (($relTr) + 4|0);
 HEAPF32[$217>>2] = $215;
 $218 = (($relTr) + 8|0);
 HEAPF32[$218>>2] = $216;
 $219 = (($relTr) + 12|0);
 HEAPF32[$219>>2] = Math_fround(0.0);
 $220 = Math_fround(HEAPF32[$2>>2]);
 $221 = Math_fround($220 + $restDistance);
 $222 = (__ZN5physx8CCDSweepINS_2Gu9TriangleVENS1_8CapsuleVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($triangle,$capsule,$zero$sroa$1$i$i$i,$capsuleTrans,$trB,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$221)|0);
 if (!($222)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $223 = Math_fround(HEAPF32[$lambda>>2]);
 $224 = Math_fround(HEAPF32[$normal>>2]);
 $225 = (($normal) + 4|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = (($normal) + 8|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 HEAPF32[$worldNormal>>2] = $224;
 $229 = (($worldNormal) + 4|0);
 HEAPF32[$229>>2] = $226;
 $230 = (($worldNormal) + 8|0);
 HEAPF32[$230>>2] = $228;
 $231 = Math_fround(HEAPF32[$closestA>>2]);
 $232 = (($closestA) + 4|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = (($closestA) + 8|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 HEAPF32[$worldPoint>>2] = $231;
 $236 = (($worldPoint) + 4|0);
 HEAPF32[$236>>2] = $233;
 $237 = (($worldPoint) + 8|0);
 HEAPF32[$237>>2] = $235;
 $$0 = $223;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physxL29PxcUnimplementedTriangleSweepERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf($shape0,$shape1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$meshScaling,$triangle,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $meshScaling = $meshScaling|0;
 $triangle = $triangle|0;
 $toiEstimate = Math_fround($toiEstimate);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return Math_fround(1.0E+10);
}
function __ZN5physxL24PxcSweepCapsuleTrianglesERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf($shape0,$shape1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$meshScaling,$triangle,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $meshScaling = $meshScaling|0;
 $triangle = $triangle|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0;
 var $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0;
 var $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0);
 var $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0;
 var $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $capsule0 = 0, $capsuleRadius$sroa$1 = 0, $capsuleTrans = 0, $closestA = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0;
 var $trB = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $zero$sroa$1$i$i$i = sp + 304|0;
 $0 = sp + 288|0;
 $zeroV = sp + 272|0;
 $capsuleRadius$sroa$1 = sp + 368|0;
 $capsule0 = sp + 128|0;
 $capsuleTrans = sp + 96|0;
 $toi = sp + 80|0;
 $trB = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 64|0;
 $1 = HEAP32[$shape0>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $2 = (($1) + 40|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 44|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(0.0));
 $7 = (($capsule0) + 64|0);
 ;HEAP32[$capsule0+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule0+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule0+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule0+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $8 = (($capsule0) + 80|0);
 HEAP32[$8>>2] = 4;
 $9 = (($capsule0) + 16|0);
 $10 = (($capsule0) + 20|0);
 $11 = (($capsule0) + 32|0);
 $12 = (($capsule0) + 36|0);
 $13 = (($capsule0) + 48|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($capsule0) + 52|0);
 ;HEAP32[$14+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $15 = (($capsule0) + 128|0);
 HEAPF32[$15>>2] = $3;
 $16 = (($capsule0) + 132|0);
 ;HEAP32[$16+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $17 = Math_fround($5 + Math_fround(0.0));
 $18 = Math_fround($6 + Math_fround(0.0));
 $19 = (($capsule0) + 96|0);
 HEAPF32[$19>>2] = $17;
 $20 = (($capsule0) + 100|0);
 HEAPF32[$20>>2] = $18;
 $21 = (($capsule0) + 104|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($capsule0) + 108|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = Math_fround(Math_fround(0.0) - $5);
 $24 = Math_fround(Math_fround(0.0) - $6);
 $25 = (($capsule0) + 112|0);
 HEAPF32[$25>>2] = $23;
 $26 = (($capsule0) + 116|0);
 HEAPF32[$26>>2] = $24;
 $27 = (($capsule0) + 120|0);
 HEAPF32[$27>>2] = $24;
 $28 = (($capsule0) + 124|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 HEAPF32[$9>>2] = $3;
 ;HEAP32[$10+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$11>>2] = $3;
 ;HEAP32[$12+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$7+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$0+12>>2]|0;
 $29 = Math_fround(HEAPF32[$transform0>>2]);
 $30 = (($transform0) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($transform0) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($transform0) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($lastTm0) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($36) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($36) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround(HEAPF32[$transform1>>2]);
 $43 = (($transform1) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($transform1) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($transform1) + 12|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($lastTm1) + 16|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($49) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($49) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 HEAPF32[$capsuleTrans>>2] = $29;
 $55 = (($capsuleTrans) + 4|0);
 HEAPF32[$55>>2] = $31;
 $56 = (($capsuleTrans) + 8|0);
 HEAPF32[$56>>2] = $33;
 $57 = (($capsuleTrans) + 12|0);
 HEAPF32[$57>>2] = $35;
 $58 = (($capsuleTrans) + 16|0);
 HEAPF32[$58>>2] = $37;
 $59 = (($capsuleTrans) + 20|0);
 HEAPF32[$59>>2] = $39;
 $60 = (($capsuleTrans) + 24|0);
 HEAPF32[$60>>2] = $41;
 $61 = (($capsuleTrans) + 28|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = Math_fround(-$29);
 $63 = Math_fround(-$31);
 $64 = Math_fround(-$33);
 $65 = Math_fround($50 - $37);
 $66 = Math_fround($52 - $39);
 $67 = Math_fround($54 - $41);
 $68 = Math_fround($35 * $35);
 $69 = Math_fround($68 + Math_fround(-0.5));
 $70 = Math_fround($69 * $65);
 $71 = Math_fround($69 * $66);
 $72 = Math_fround($69 * $67);
 $73 = Math_fround($67 * $63);
 $74 = Math_fround($66 * $64);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($65 * $64);
 $77 = Math_fround($67 * $62);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($66 * $62);
 $80 = Math_fround($65 * $63);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($35 * $75);
 $83 = Math_fround($35 * $78);
 $84 = Math_fround($35 * $81);
 $85 = Math_fround($70 + $82);
 $86 = Math_fround($71 + $83);
 $87 = Math_fround($72 + $84);
 $88 = Math_fround($65 * $62);
 $89 = Math_fround($66 * $63);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround($67 * $64);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($92 * $62);
 $94 = Math_fround($92 * $63);
 $95 = Math_fround($92 * $64);
 $96 = Math_fround($93 + $85);
 $97 = Math_fround($94 + $86);
 $98 = Math_fround($87 + $95);
 $99 = Math_fround($96 * Math_fround(2.0));
 $100 = Math_fround($97 * Math_fround(2.0));
 $101 = Math_fround($98 * Math_fround(2.0));
 $102 = Math_fround($48 * $35);
 $103 = Math_fround($42 * $62);
 $104 = Math_fround($44 * $63);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($46 * $64);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($102 - $107);
 $109 = Math_fround($48 * $62);
 $110 = Math_fround($48 * $63);
 $111 = Math_fround($48 * $64);
 $112 = Math_fround($42 * $35);
 $113 = Math_fround($44 * $35);
 $114 = Math_fround($46 * $35);
 $115 = Math_fround($46 * $63);
 $116 = Math_fround($44 * $64);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($42 * $64);
 $119 = Math_fround($46 * $62);
 $120 = Math_fround($118 - $119);
 $121 = Math_fround($44 * $62);
 $122 = Math_fround($42 * $63);
 $123 = Math_fround($121 - $122);
 $124 = Math_fround($109 + $112);
 $125 = Math_fround($110 + $113);
 $126 = Math_fround($114 + $111);
 $127 = Math_fround($117 + $124);
 $128 = Math_fround($120 + $125);
 $129 = Math_fround($123 + $126);
 $130 = (($zero$sroa$1$i$i$i) + 48|0);
 HEAPF32[$130>>2] = $99;
 $131 = (($zero$sroa$1$i$i$i) + 52|0);
 HEAPF32[$131>>2] = $100;
 $132 = (($zero$sroa$1$i$i$i) + 56|0);
 HEAPF32[$132>>2] = $101;
 $133 = (($zero$sroa$1$i$i$i) + 60|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = Math_fround($127 + $127);
 $135 = Math_fround($128 + $128);
 $136 = Math_fround($129 + $129);
 $137 = Math_fround($127 * $134);
 $138 = Math_fround($128 * $135);
 $139 = Math_fround($129 * $136);
 $140 = Math_fround($128 * $134);
 $141 = Math_fround($129 * $134);
 $142 = Math_fround($108 * $134);
 $143 = Math_fround($129 * $135);
 $144 = Math_fround($108 * $135);
 $145 = Math_fround($108 * $136);
 $146 = Math_fround(Math_fround(1.0) - $137);
 $147 = Math_fround(Math_fround(1.0) - $138);
 $148 = Math_fround($147 - $139);
 $149 = Math_fround($140 + $145);
 $150 = Math_fround($141 - $144);
 $151 = Math_fround($140 - $145);
 $152 = Math_fround($146 - $139);
 $153 = Math_fround($143 + $142);
 $154 = Math_fround($141 + $144);
 $155 = Math_fround($143 - $142);
 $156 = Math_fround($146 - $138);
 HEAPF32[$zero$sroa$1$i$i$i>>2] = $148;
 $157 = (($zero$sroa$1$i$i$i) + 4|0);
 HEAPF32[$157>>2] = $149;
 $158 = (($zero$sroa$1$i$i$i) + 8|0);
 HEAPF32[$158>>2] = $150;
 $159 = (($zero$sroa$1$i$i$i) + 12|0);
 HEAPF32[$159>>2] = Math_fround(0.0);
 $160 = (($zero$sroa$1$i$i$i) + 16|0);
 HEAPF32[$160>>2] = $151;
 $161 = (($zero$sroa$1$i$i$i) + 20|0);
 HEAPF32[$161>>2] = $152;
 $162 = (($zero$sroa$1$i$i$i) + 24|0);
 HEAPF32[$162>>2] = $153;
 $163 = (($zero$sroa$1$i$i$i) + 28|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = (($zero$sroa$1$i$i$i) + 32|0);
 HEAPF32[$164>>2] = $154;
 $165 = (($zero$sroa$1$i$i$i) + 36|0);
 HEAPF32[$165>>2] = $155;
 $166 = (($zero$sroa$1$i$i$i) + 40|0);
 HEAPF32[$166>>2] = $156;
 $167 = (($zero$sroa$1$i$i$i) + 44|0);
 HEAPF32[$167>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $168 = (($transform0) + 16|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($transform0) + 20|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($transform0) + 24|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = (($transform1) + 16|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = (($transform1) + 20|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = (($transform1) + 24|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround($169 - $37);
 $181 = Math_fround($171 - $39);
 $182 = Math_fround($173 - $41);
 $183 = Math_fround($175 - $50);
 $184 = Math_fround($177 - $52);
 $185 = Math_fround($179 - $54);
 HEAPF32[$trB>>2] = $183;
 $186 = (($trB) + 4|0);
 HEAPF32[$186>>2] = $184;
 $187 = (($trB) + 8|0);
 HEAPF32[$187>>2] = $185;
 $188 = (($trB) + 12|0);
 HEAPF32[$188>>2] = Math_fround(0.0);
 $189 = Math_fround($180 - $183);
 $190 = Math_fround($181 - $184);
 $191 = Math_fround($182 - $185);
 $192 = Math_fround(HEAPF32[$capsuleTrans>>2]);
 $193 = Math_fround(HEAPF32[$55>>2]);
 $194 = Math_fround(HEAPF32[$56>>2]);
 $195 = Math_fround(HEAPF32[$57>>2]);
 $196 = Math_fround($195 * $195);
 $197 = Math_fround($196 + Math_fround(-0.5));
 $198 = Math_fround($189 * $197);
 $199 = Math_fround($190 * $197);
 $200 = Math_fround($191 * $197);
 $201 = Math_fround($191 * $193);
 $202 = Math_fround($190 * $194);
 $203 = Math_fround($201 - $202);
 $204 = Math_fround($189 * $194);
 $205 = Math_fround($192 * $191);
 $206 = Math_fround($204 - $205);
 $207 = Math_fround($190 * $192);
 $208 = Math_fround($189 * $193);
 $209 = Math_fround($207 - $208);
 $210 = Math_fround($195 * $203);
 $211 = Math_fround($195 * $206);
 $212 = Math_fround($195 * $209);
 $213 = Math_fround($198 - $210);
 $214 = Math_fround($199 - $211);
 $215 = Math_fround($200 - $212);
 $216 = Math_fround($189 * $192);
 $217 = Math_fround($190 * $193);
 $218 = Math_fround($216 + $217);
 $219 = Math_fround($191 * $194);
 $220 = Math_fround($218 + $219);
 $221 = Math_fround($192 * $220);
 $222 = Math_fround($193 * $220);
 $223 = Math_fround($194 * $220);
 $224 = Math_fround($221 + $213);
 $225 = Math_fround($222 + $214);
 $226 = Math_fround($223 + $215);
 $227 = Math_fround($224 * Math_fround(2.0));
 $228 = Math_fround($225 * Math_fround(2.0));
 $229 = Math_fround($226 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $227;
 $230 = (($relTr) + 4|0);
 HEAPF32[$230>>2] = $228;
 $231 = (($relTr) + 8|0);
 HEAPF32[$231>>2] = $229;
 $232 = (($relTr) + 12|0);
 HEAPF32[$232>>2] = Math_fround(0.0);
 $233 = Math_fround(HEAPF32[$2>>2]);
 $234 = Math_fround($233 + $restDistance);
 $235 = (__ZN5physx8CCDSweepINS_2Gu9TriangleVENS1_8CapsuleVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($triangle,$capsule0,$zero$sroa$1$i$i$i,$capsuleTrans,$trB,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$234)|0);
 if (!($235)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $236 = Math_fround(HEAPF32[$lambda>>2]);
 $237 = Math_fround(HEAPF32[$normal>>2]);
 $238 = (($normal) + 4|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($normal) + 8|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 HEAPF32[$worldNormal>>2] = $237;
 $242 = (($worldNormal) + 4|0);
 HEAPF32[$242>>2] = $239;
 $243 = (($worldNormal) + 8|0);
 HEAPF32[$243>>2] = $241;
 $244 = Math_fround(HEAPF32[$closestA>>2]);
 $245 = (($closestA) + 4|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = (($closestA) + 8|0);
 $248 = Math_fround(HEAPF32[$247>>2]);
 HEAPF32[$worldPoint>>2] = $244;
 $249 = (($worldPoint) + 4|0);
 HEAPF32[$249>>2] = $246;
 $250 = (($worldPoint) + 8|0);
 HEAPF32[$250>>2] = $248;
 $$0 = $236;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physxL20PxcSweepBoxTrianglesERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf($shape0,$shape1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$meshScaling,$triangle,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $meshScaling = $meshScaling|0;
 $triangle = $triangle|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = Math_fround(0), $$sroa$1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0;
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $box0 = 0, $boxTrans = 0, $closestA = 0, $lambda = 0;
 var $normal = 0, $relTr = 0, $toi = 0, $trB = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $$sroa$1$i$i$i = sp + 304|0;
 $zero$sroa$1$i$i$i = sp + 368|0;
 $zeroV = sp + 288|0;
 $box0 = sp + 128|0;
 $boxTrans = sp + 96|0;
 $toi = sp + 80|0;
 $trB = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 64|0;
 $0 = HEAP32[$shape0>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $1 = (($0) + 40|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($0) + 44|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($0) + 48|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($box0) + 64|0);
 ;HEAP32[$box0+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box0+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box0+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box0+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $8 = (($box0) + 80|0);
 HEAP32[$8>>2] = 3;
 $9 = (($box0) + 16|0);
 $10 = (($box0) + 20|0);
 ;HEAP32[$10+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $11 = (($box0) + 32|0);
 $12 = (($box0) + 36|0);
 $13 = (($box0) + 48|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($box0) + 52|0);
 ;HEAP32[$14+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$7+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $15 = (($box0) + 144|0);
 HEAPF32[$15>>2] = $2;
 $16 = (($box0) + 148|0);
 HEAPF32[$16>>2] = $4;
 $17 = (($box0) + 152|0);
 HEAPF32[$17>>2] = $6;
 $18 = (($box0) + 156|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = !($2 <= $4);
 $$$i26$i$i$i = $19 ? $4 : $2;
 $20 = !($$$i26$i$i$i <= $6);
 $21 = $20 ? $6 : $$$i26$i$i$i;
 $22 = !($2 >= $4);
 $$$i23$i$i$i = $22 ? $4 : $2;
 $23 = !($$$i23$i$i$i >= $6);
 $24 = $23 ? $6 : $$$i23$i$i$i;
 $25 = Math_fround($21 * Math_fround(0.150000005960464477539));
 $26 = Math_fround($24 * Math_fround(0.0299999993294477462769));
 $27 = $25 > $26;
 $$$i12$i$i$i = $27 ? $25 : $26;
 $28 = $21 > $$$i12$i$i$i;
 $$$i$i$i$i = $28 ? $$$i12$i$i$i : $21;
 HEAPF32[$9>>2] = $$$i$i$i$i;
 ;HEAP32[$10+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $29 = Math_fround($21 * Math_fround(0.0500000007450580596924));
 HEAPF32[$11>>2] = $29;
 ;HEAP32[$12+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $30 = Math_fround(HEAPF32[$transform0>>2]);
 $31 = (($transform0) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($transform0) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($transform0) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($lastTm0) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($37) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($37) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround(HEAPF32[$transform1>>2]);
 $44 = (($transform1) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($transform1) + 8|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($transform1) + 12|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($lastTm1) + 16|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($50) + 4|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($50) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 HEAPF32[$boxTrans>>2] = $30;
 $56 = (($boxTrans) + 4|0);
 HEAPF32[$56>>2] = $32;
 $57 = (($boxTrans) + 8|0);
 HEAPF32[$57>>2] = $34;
 $58 = (($boxTrans) + 12|0);
 HEAPF32[$58>>2] = $36;
 $59 = (($boxTrans) + 16|0);
 HEAPF32[$59>>2] = $38;
 $60 = (($boxTrans) + 20|0);
 HEAPF32[$60>>2] = $40;
 $61 = (($boxTrans) + 24|0);
 HEAPF32[$61>>2] = $42;
 $62 = (($boxTrans) + 28|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = Math_fround(-$30);
 $64 = Math_fround(-$32);
 $65 = Math_fround(-$34);
 $66 = Math_fround($51 - $38);
 $67 = Math_fround($53 - $40);
 $68 = Math_fround($55 - $42);
 $69 = Math_fround($36 * $36);
 $70 = Math_fround($69 + Math_fround(-0.5));
 $71 = Math_fround($70 * $66);
 $72 = Math_fround($70 * $67);
 $73 = Math_fround($70 * $68);
 $74 = Math_fround($68 * $64);
 $75 = Math_fround($67 * $65);
 $76 = Math_fround($74 - $75);
 $77 = Math_fround($66 * $65);
 $78 = Math_fround($68 * $63);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($67 * $63);
 $81 = Math_fround($66 * $64);
 $82 = Math_fround($80 - $81);
 $83 = Math_fround($36 * $76);
 $84 = Math_fround($36 * $79);
 $85 = Math_fround($36 * $82);
 $86 = Math_fround($71 + $83);
 $87 = Math_fround($72 + $84);
 $88 = Math_fround($73 + $85);
 $89 = Math_fround($66 * $63);
 $90 = Math_fround($67 * $64);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($68 * $65);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($93 * $63);
 $95 = Math_fround($93 * $64);
 $96 = Math_fround($93 * $65);
 $97 = Math_fround($94 + $86);
 $98 = Math_fround($95 + $87);
 $99 = Math_fround($88 + $96);
 $100 = Math_fround($97 * Math_fround(2.0));
 $101 = Math_fround($98 * Math_fround(2.0));
 $102 = Math_fround($99 * Math_fround(2.0));
 $103 = Math_fround($49 * $36);
 $104 = Math_fround($43 * $63);
 $105 = Math_fround($45 * $64);
 $106 = Math_fround($104 + $105);
 $107 = Math_fround($47 * $65);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($103 - $108);
 $110 = Math_fround($49 * $63);
 $111 = Math_fround($49 * $64);
 $112 = Math_fround($49 * $65);
 $113 = Math_fround($43 * $36);
 $114 = Math_fround($45 * $36);
 $115 = Math_fround($47 * $36);
 $116 = Math_fround($47 * $64);
 $117 = Math_fround($45 * $65);
 $118 = Math_fround($116 - $117);
 $119 = Math_fround($43 * $65);
 $120 = Math_fround($47 * $63);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($45 * $63);
 $123 = Math_fround($43 * $64);
 $124 = Math_fround($122 - $123);
 $125 = Math_fround($110 + $113);
 $126 = Math_fround($111 + $114);
 $127 = Math_fround($115 + $112);
 $128 = Math_fround($118 + $125);
 $129 = Math_fround($121 + $126);
 $130 = Math_fround($124 + $127);
 $131 = (($$sroa$1$i$i$i) + 48|0);
 HEAPF32[$131>>2] = $100;
 $132 = (($$sroa$1$i$i$i) + 52|0);
 HEAPF32[$132>>2] = $101;
 $133 = (($$sroa$1$i$i$i) + 56|0);
 HEAPF32[$133>>2] = $102;
 $134 = (($$sroa$1$i$i$i) + 60|0);
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = Math_fround($128 + $128);
 $136 = Math_fround($129 + $129);
 $137 = Math_fround($130 + $130);
 $138 = Math_fround($128 * $135);
 $139 = Math_fround($129 * $136);
 $140 = Math_fround($130 * $137);
 $141 = Math_fround($129 * $135);
 $142 = Math_fround($130 * $135);
 $143 = Math_fround($109 * $135);
 $144 = Math_fround($130 * $136);
 $145 = Math_fround($109 * $136);
 $146 = Math_fround($109 * $137);
 $147 = Math_fround(Math_fround(1.0) - $138);
 $148 = Math_fround(Math_fround(1.0) - $139);
 $149 = Math_fround($148 - $140);
 $150 = Math_fround($141 + $146);
 $151 = Math_fround($142 - $145);
 $152 = Math_fround($141 - $146);
 $153 = Math_fround($147 - $140);
 $154 = Math_fround($144 + $143);
 $155 = Math_fround($142 + $145);
 $156 = Math_fround($144 - $143);
 $157 = Math_fround($147 - $139);
 HEAPF32[$$sroa$1$i$i$i>>2] = $149;
 $158 = (($$sroa$1$i$i$i) + 4|0);
 HEAPF32[$158>>2] = $150;
 $159 = (($$sroa$1$i$i$i) + 8|0);
 HEAPF32[$159>>2] = $151;
 $160 = (($$sroa$1$i$i$i) + 12|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 $161 = (($$sroa$1$i$i$i) + 16|0);
 HEAPF32[$161>>2] = $152;
 $162 = (($$sroa$1$i$i$i) + 20|0);
 HEAPF32[$162>>2] = $153;
 $163 = (($$sroa$1$i$i$i) + 24|0);
 HEAPF32[$163>>2] = $154;
 $164 = (($$sroa$1$i$i$i) + 28|0);
 HEAPF32[$164>>2] = Math_fround(0.0);
 $165 = (($$sroa$1$i$i$i) + 32|0);
 HEAPF32[$165>>2] = $155;
 $166 = (($$sroa$1$i$i$i) + 36|0);
 HEAPF32[$166>>2] = $156;
 $167 = (($$sroa$1$i$i$i) + 40|0);
 HEAPF32[$167>>2] = $157;
 $168 = (($$sroa$1$i$i$i) + 44|0);
 HEAPF32[$168>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $169 = (($transform0) + 16|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = (($transform0) + 20|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = (($transform0) + 24|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($transform1) + 16|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = (($transform1) + 20|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = (($transform1) + 24|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = Math_fround($170 - $38);
 $182 = Math_fround($172 - $40);
 $183 = Math_fround($174 - $42);
 $184 = Math_fround($176 - $51);
 $185 = Math_fround($178 - $53);
 $186 = Math_fround($180 - $55);
 HEAPF32[$trB>>2] = $184;
 $187 = (($trB) + 4|0);
 HEAPF32[$187>>2] = $185;
 $188 = (($trB) + 8|0);
 HEAPF32[$188>>2] = $186;
 $189 = (($trB) + 12|0);
 HEAPF32[$189>>2] = Math_fround(0.0);
 $190 = Math_fround($181 - $184);
 $191 = Math_fround($182 - $185);
 $192 = Math_fround($183 - $186);
 $193 = Math_fround(HEAPF32[$boxTrans>>2]);
 $194 = Math_fround(HEAPF32[$56>>2]);
 $195 = Math_fround(HEAPF32[$57>>2]);
 $196 = Math_fround(HEAPF32[$58>>2]);
 $197 = Math_fround($196 * $196);
 $198 = Math_fround($197 + Math_fround(-0.5));
 $199 = Math_fround($190 * $198);
 $200 = Math_fround($191 * $198);
 $201 = Math_fround($192 * $198);
 $202 = Math_fround($192 * $194);
 $203 = Math_fround($191 * $195);
 $204 = Math_fround($202 - $203);
 $205 = Math_fround($190 * $195);
 $206 = Math_fround($193 * $192);
 $207 = Math_fround($205 - $206);
 $208 = Math_fround($191 * $193);
 $209 = Math_fround($190 * $194);
 $210 = Math_fround($208 - $209);
 $211 = Math_fround($196 * $204);
 $212 = Math_fround($196 * $207);
 $213 = Math_fround($196 * $210);
 $214 = Math_fround($199 - $211);
 $215 = Math_fround($200 - $212);
 $216 = Math_fround($201 - $213);
 $217 = Math_fround($190 * $193);
 $218 = Math_fround($191 * $194);
 $219 = Math_fround($217 + $218);
 $220 = Math_fround($192 * $195);
 $221 = Math_fround($219 + $220);
 $222 = Math_fround($193 * $221);
 $223 = Math_fround($194 * $221);
 $224 = Math_fround($195 * $221);
 $225 = Math_fround($222 + $214);
 $226 = Math_fround($223 + $215);
 $227 = Math_fround($224 + $216);
 $228 = Math_fround($225 * Math_fround(2.0));
 $229 = Math_fround($226 * Math_fround(2.0));
 $230 = Math_fround($227 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $228;
 $231 = (($relTr) + 4|0);
 HEAPF32[$231>>2] = $229;
 $232 = (($relTr) + 8|0);
 HEAPF32[$232>>2] = $230;
 $233 = (($relTr) + 12|0);
 HEAPF32[$233>>2] = Math_fround(0.0);
 $234 = (__ZN5physx8CCDSweepINS_2Gu9TriangleVENS1_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($triangle,$box0,$$sroa$1$i$i$i,$boxTrans,$trB,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$restDistance)|0);
 if (!($234)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $235 = Math_fround(HEAPF32[$lambda>>2]);
 $236 = Math_fround(HEAPF32[$normal>>2]);
 $237 = (($normal) + 4|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = (($normal) + 8|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 HEAPF32[$worldNormal>>2] = $236;
 $241 = (($worldNormal) + 4|0);
 HEAPF32[$241>>2] = $238;
 $242 = (($worldNormal) + 8|0);
 HEAPF32[$242>>2] = $240;
 $243 = Math_fround(HEAPF32[$closestA>>2]);
 $244 = (($closestA) + 4|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = (($closestA) + 8|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 HEAPF32[$worldPoint>>2] = $243;
 $248 = (($worldPoint) + 4|0);
 HEAPF32[$248>>2] = $245;
 $249 = (($worldPoint) + 8|0);
 HEAPF32[$249>>2] = $247;
 $$0 = $235;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physxL23PxcSweepConvexTrianglesERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf($shape0,$shape1,$transform0,$transform1,$lastTm0,$lastTm1,$restDistance,$worldNormal,$worldPoint,$cache,$context,$meshScaling,$triangle,$toiEstimate) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $lastTm0 = $lastTm0|0;
 $lastTm1 = $lastTm1|0;
 $restDistance = Math_fround($restDistance);
 $worldNormal = $worldNormal|0;
 $worldPoint = $worldPoint|0;
 $cache = $cache|0;
 $context = $context|0;
 $meshScaling = $meshScaling|0;
 $triangle = $triangle|0;
 $toiEstimate = Math_fround($toiEstimate);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0);
 var $241 = 0, $242 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0);
 var $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $closestA = 0, $convexHull0 = 0, $convexTrans = 0, $lambda = 0, $normal = 0, $relTr = 0, $toi = 0, $trB = 0, $vQuat0 = 0, $vScale0 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $zeroV = sp + 432|0;
 $vScale0 = sp + 416|0;
 $vQuat0 = sp + 400|0;
 $convexHull0 = sp + 192|0;
 $convexTrans = sp + 160|0;
 $aToB = sp + 96|0;
 $toi = sp + 80|0;
 $trB = sp + 48|0;
 $relTr = sp + 32|0;
 $lambda = sp + 16|0;
 $normal = sp;
 $closestA = sp + 64|0;
 $0 = HEAP32[$shape0>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $1 = (($0) + 40|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($0) + 44|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($0) + 48|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$vScale0>>2] = $2;
 $7 = (($vScale0) + 4|0);
 HEAPF32[$7>>2] = $4;
 $8 = (($vScale0) + 8|0);
 HEAPF32[$8>>2] = $6;
 $9 = (($vScale0) + 12|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($0) + 52|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($0) + 56|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($0) + 60|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($0) + 64|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$vQuat0>>2] = $11;
 $18 = (($vQuat0) + 4|0);
 HEAPF32[$18>>2] = $13;
 $19 = (($vQuat0) + 8|0);
 HEAPF32[$19>>2] = $15;
 $20 = (($vQuat0) + 12|0);
 HEAPF32[$20>>2] = $17;
 $21 = (($0) + 72|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull0,$22,$zeroV,$vScale0,$vQuat0);
 $23 = Math_fround(HEAPF32[$transform0>>2]);
 $24 = (($transform0) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($transform0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($transform0) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($lastTm0) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($30) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($30) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround(HEAPF32[$transform1>>2]);
 $37 = (($transform1) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($transform1) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($transform1) + 12|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($lastTm1) + 16|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($43) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($43) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$convexTrans>>2] = $23;
 $49 = (($convexTrans) + 4|0);
 HEAPF32[$49>>2] = $25;
 $50 = (($convexTrans) + 8|0);
 HEAPF32[$50>>2] = $27;
 $51 = (($convexTrans) + 12|0);
 HEAPF32[$51>>2] = $29;
 $52 = (($convexTrans) + 16|0);
 HEAPF32[$52>>2] = $31;
 $53 = (($convexTrans) + 20|0);
 HEAPF32[$53>>2] = $33;
 $54 = (($convexTrans) + 24|0);
 HEAPF32[$54>>2] = $35;
 $55 = (($convexTrans) + 28|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = Math_fround(-$23);
 $57 = Math_fround(-$25);
 $58 = Math_fround(-$27);
 $59 = Math_fround($44 - $31);
 $60 = Math_fround($46 - $33);
 $61 = Math_fround($48 - $35);
 $62 = Math_fround($29 * $29);
 $63 = Math_fround($62 + Math_fround(-0.5));
 $64 = Math_fround($63 * $59);
 $65 = Math_fround($63 * $60);
 $66 = Math_fround($63 * $61);
 $67 = Math_fround($61 * $57);
 $68 = Math_fround($60 * $58);
 $69 = Math_fround($67 - $68);
 $70 = Math_fround($59 * $58);
 $71 = Math_fround($61 * $56);
 $72 = Math_fround($70 - $71);
 $73 = Math_fround($60 * $56);
 $74 = Math_fround($59 * $57);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($29 * $69);
 $77 = Math_fround($29 * $72);
 $78 = Math_fround($29 * $75);
 $79 = Math_fround($64 + $76);
 $80 = Math_fround($65 + $77);
 $81 = Math_fround($66 + $78);
 $82 = Math_fround($59 * $56);
 $83 = Math_fround($60 * $57);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($61 * $58);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($86 * $56);
 $88 = Math_fround($86 * $57);
 $89 = Math_fround($86 * $58);
 $90 = Math_fround($87 + $79);
 $91 = Math_fround($88 + $80);
 $92 = Math_fround($81 + $89);
 $93 = Math_fround($90 * Math_fround(2.0));
 $94 = Math_fround($91 * Math_fround(2.0));
 $95 = Math_fround($92 * Math_fround(2.0));
 $96 = Math_fround($42 * $29);
 $97 = Math_fround($36 * $56);
 $98 = Math_fround($38 * $57);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($40 * $58);
 $101 = Math_fround($99 + $100);
 $102 = Math_fround($96 - $101);
 $103 = Math_fround($42 * $56);
 $104 = Math_fround($42 * $57);
 $105 = Math_fround($42 * $58);
 $106 = Math_fround($36 * $29);
 $107 = Math_fround($38 * $29);
 $108 = Math_fround($40 * $29);
 $109 = Math_fround($40 * $57);
 $110 = Math_fround($38 * $58);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($36 * $58);
 $113 = Math_fround($40 * $56);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($38 * $56);
 $116 = Math_fround($36 * $57);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($103 + $106);
 $119 = Math_fround($104 + $107);
 $120 = Math_fround($108 + $105);
 $121 = Math_fround($111 + $118);
 $122 = Math_fround($114 + $119);
 $123 = Math_fround($117 + $120);
 $124 = (($aToB) + 48|0);
 HEAPF32[$124>>2] = $93;
 $125 = (($aToB) + 52|0);
 HEAPF32[$125>>2] = $94;
 $126 = (($aToB) + 56|0);
 HEAPF32[$126>>2] = $95;
 $127 = (($aToB) + 60|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = Math_fround($121 + $121);
 $129 = Math_fround($122 + $122);
 $130 = Math_fround($123 + $123);
 $131 = Math_fround($121 * $128);
 $132 = Math_fround($122 * $129);
 $133 = Math_fround($123 * $130);
 $134 = Math_fround($122 * $128);
 $135 = Math_fround($123 * $128);
 $136 = Math_fround($102 * $128);
 $137 = Math_fround($123 * $129);
 $138 = Math_fround($102 * $129);
 $139 = Math_fround($102 * $130);
 $140 = Math_fround(Math_fround(1.0) - $131);
 $141 = Math_fround(Math_fround(1.0) - $132);
 $142 = Math_fround($141 - $133);
 $143 = Math_fround($134 + $139);
 $144 = Math_fround($135 - $138);
 $145 = Math_fround($134 - $139);
 $146 = Math_fround($140 - $133);
 $147 = Math_fround($137 + $136);
 $148 = Math_fround($135 + $138);
 $149 = Math_fround($137 - $136);
 $150 = Math_fround($140 - $132);
 HEAPF32[$aToB>>2] = $142;
 $151 = (($aToB) + 4|0);
 HEAPF32[$151>>2] = $143;
 $152 = (($aToB) + 8|0);
 HEAPF32[$152>>2] = $144;
 $153 = (($aToB) + 12|0);
 HEAPF32[$153>>2] = Math_fround(0.0);
 $154 = (($aToB) + 16|0);
 HEAPF32[$154>>2] = $145;
 $155 = (($aToB) + 20|0);
 HEAPF32[$155>>2] = $146;
 $156 = (($aToB) + 24|0);
 HEAPF32[$156>>2] = $147;
 $157 = (($aToB) + 28|0);
 HEAPF32[$157>>2] = Math_fround(0.0);
 $158 = (($aToB) + 32|0);
 HEAPF32[$158>>2] = $148;
 $159 = (($aToB) + 36|0);
 HEAPF32[$159>>2] = $149;
 $160 = (($aToB) + 40|0);
 HEAPF32[$160>>2] = $150;
 $161 = (($aToB) + 44|0);
 HEAPF32[$161>>2] = Math_fround(0.0);
 HEAPF32[$toi>>2] = $toiEstimate;
 $162 = (($transform0) + 16|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($transform0) + 20|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = (($transform0) + 24|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = (($transform1) + 16|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($transform1) + 20|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($transform1) + 24|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround($163 - $31);
 $175 = Math_fround($165 - $33);
 $176 = Math_fround($167 - $35);
 $177 = Math_fround($169 - $44);
 $178 = Math_fround($171 - $46);
 $179 = Math_fround($173 - $48);
 HEAPF32[$trB>>2] = $177;
 $180 = (($trB) + 4|0);
 HEAPF32[$180>>2] = $178;
 $181 = (($trB) + 8|0);
 HEAPF32[$181>>2] = $179;
 $182 = (($trB) + 12|0);
 HEAPF32[$182>>2] = Math_fround(0.0);
 $183 = Math_fround($174 - $177);
 $184 = Math_fround($175 - $178);
 $185 = Math_fround($176 - $179);
 $186 = Math_fround(HEAPF32[$convexTrans>>2]);
 $187 = Math_fround(HEAPF32[$49>>2]);
 $188 = Math_fround(HEAPF32[$50>>2]);
 $189 = Math_fround(HEAPF32[$51>>2]);
 $190 = Math_fround($189 * $189);
 $191 = Math_fround($190 + Math_fround(-0.5));
 $192 = Math_fround($183 * $191);
 $193 = Math_fround($184 * $191);
 $194 = Math_fround($185 * $191);
 $195 = Math_fround($185 * $187);
 $196 = Math_fround($184 * $188);
 $197 = Math_fround($195 - $196);
 $198 = Math_fround($183 * $188);
 $199 = Math_fround($186 * $185);
 $200 = Math_fround($198 - $199);
 $201 = Math_fround($184 * $186);
 $202 = Math_fround($183 * $187);
 $203 = Math_fround($201 - $202);
 $204 = Math_fround($189 * $197);
 $205 = Math_fround($189 * $200);
 $206 = Math_fround($189 * $203);
 $207 = Math_fround($192 - $204);
 $208 = Math_fround($193 - $205);
 $209 = Math_fround($194 - $206);
 $210 = Math_fround($183 * $186);
 $211 = Math_fround($184 * $187);
 $212 = Math_fround($210 + $211);
 $213 = Math_fround($185 * $188);
 $214 = Math_fround($212 + $213);
 $215 = Math_fround($186 * $214);
 $216 = Math_fround($187 * $214);
 $217 = Math_fround($188 * $214);
 $218 = Math_fround($215 + $207);
 $219 = Math_fround($216 + $208);
 $220 = Math_fround($217 + $209);
 $221 = Math_fround($218 * Math_fround(2.0));
 $222 = Math_fround($219 * Math_fround(2.0));
 $223 = Math_fround($220 * Math_fround(2.0));
 HEAPF32[$relTr>>2] = $221;
 $224 = (($relTr) + 4|0);
 HEAPF32[$224>>2] = $222;
 $225 = (($relTr) + 8|0);
 HEAPF32[$225>>2] = $223;
 $226 = (($relTr) + 12|0);
 HEAPF32[$226>>2] = Math_fround(0.0);
 $227 = (__ZN5physx8CCDSweepINS_2Gu9TriangleVENS1_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($triangle,$convexHull0,$aToB,$convexTrans,$trB,$toi,$zeroV,$relTr,$lambda,$normal,$closestA,$restDistance)|0);
 if (!($227)) {
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $228 = Math_fround(HEAPF32[$lambda>>2]);
 $229 = Math_fround(HEAPF32[$normal>>2]);
 $230 = (($normal) + 4|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($normal) + 8|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 HEAPF32[$worldNormal>>2] = $229;
 $234 = (($worldNormal) + 4|0);
 HEAPF32[$234>>2] = $231;
 $235 = (($worldNormal) + 8|0);
 HEAPF32[$235>>2] = $233;
 $236 = Math_fround(HEAPF32[$closestA>>2]);
 $237 = (($closestA) + 4|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = (($closestA) + 8|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 HEAPF32[$worldPoint>>2] = $236;
 $241 = (($worldPoint) + 4|0);
 HEAPF32[$241>>2] = $238;
 $242 = (($worldPoint) + 8|0);
 HEAPF32[$242>>2] = $240;
 $$0 = $228;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx8CCDSweepINS_2Gu9TriangleVENS1_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_9TriangleVERNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx8CCDSweepINS_2Gu9TriangleVENS1_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_9TriangleVERNS0_4BoxVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx8CCDSweepINS_2Gu9TriangleVENS1_8CapsuleVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVERKNS9_5Vec3VERKNS9_6FloatVESI_SI_RSJ_RSG_SN_f($a,$b,$aToB,$transB,$translationA,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $transB = $transB|0;
 $translationA = $translationA|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 var $$$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $_closestA = 0, $_lambda = 0, $_normal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_lambda = sp + 32|0;
 $_closestA = sp;
 $_normal = sp + 16|0;
 $0 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_9TriangleVERNS0_8CapsuleVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$_normal,$_closestA,$inflation,1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$translationA>>2]);
 $2 = (($translationA) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($translationA) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$_lambda>>2]);
 $7 = $6 > Math_fround(0.0);
 $$$i = $7 ? $6 : Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$transB>>2]);
 $9 = (($transB) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transB) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transB) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transB) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transB) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transB) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$_closestA>>2]);
 $22 = (($_closestA) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_closestA) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $14);
 $27 = Math_fround($26 + Math_fround(-0.5));
 $28 = Math_fround($27 * $21);
 $29 = Math_fround($27 * $23);
 $30 = Math_fround($27 * $25);
 $31 = Math_fround($10 * $25);
 $32 = Math_fround($12 * $23);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($12 * $21);
 $35 = Math_fround($8 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($8 * $23);
 $38 = Math_fround($10 * $21);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($14 * $33);
 $41 = Math_fround($14 * $36);
 $42 = Math_fround($14 * $39);
 $43 = Math_fround($28 + $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($30 + $42);
 $46 = Math_fround($8 * $21);
 $47 = Math_fround($10 * $23);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($12 * $25);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($10 * $50);
 $53 = Math_fround($12 * $50);
 $54 = Math_fround($51 + $43);
 $55 = Math_fround($52 + $44);
 $56 = Math_fround($45 + $53);
 $57 = Math_fround($54 * Math_fround(2.0));
 $58 = Math_fround($55 * Math_fround(2.0));
 $59 = Math_fround($56 * Math_fround(2.0));
 $60 = Math_fround($16 + $57);
 $61 = Math_fround($18 + $58);
 $62 = Math_fround($20 + $59);
 $63 = Math_fround($1 * $$$i);
 $64 = Math_fround($3 * $$$i);
 $65 = Math_fround($5 * $$$i);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($64 + $61);
 $68 = Math_fround($65 + $62);
 HEAPF32[$closestA>>2] = $66;
 $69 = (($closestA) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($closestA) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($closestA) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround(HEAPF32[$transB>>2]);
 $73 = Math_fround(HEAPF32[$9>>2]);
 $74 = Math_fround(HEAPF32[$11>>2]);
 $75 = Math_fround(HEAPF32[$13>>2]);
 $76 = Math_fround(HEAPF32[$_normal>>2]);
 $77 = (($_normal) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($_normal) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($75 * $75);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround($76 * $82);
 $84 = Math_fround($82 * $78);
 $85 = Math_fround($82 * $80);
 $86 = Math_fround($73 * $80);
 $87 = Math_fround($74 * $78);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($74 * $76);
 $90 = Math_fround($72 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($72 * $78);
 $93 = Math_fround($73 * $76);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($75 * $88);
 $96 = Math_fround($75 * $91);
 $97 = Math_fround($75 * $94);
 $98 = Math_fround($83 + $95);
 $99 = Math_fround($84 + $96);
 $100 = Math_fround($85 + $97);
 $101 = Math_fround($72 * $76);
 $102 = Math_fround($73 * $78);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($74 * $80);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($72 * $105);
 $107 = Math_fround($73 * $105);
 $108 = Math_fround($74 * $105);
 $109 = Math_fround($106 + $98);
 $110 = Math_fround($107 + $99);
 $111 = Math_fround($100 + $108);
 $112 = Math_fround($109 * Math_fround(2.0));
 $113 = Math_fround($110 * Math_fround(2.0));
 $114 = Math_fround($111 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $112;
 $115 = (($normal) + 4|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($normal) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($normal) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx23transformBoxOrthonormalERKNS_2Gu3BoxERKNS_11PxTransformE($agg$result,$box,$t) {
 $agg$result = $agg$result|0;
 $box = $box|0;
 $t = $t|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$box>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($box) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = (($box) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * Math_fround(2.0));
 $8 = (($t) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = Math_fround($10 + Math_fround(-0.5));
 $12 = Math_fround(HEAPF32[$t>>2]);
 $13 = Math_fround($1 * $12);
 $14 = (($t) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($4 * $15);
 $17 = Math_fround($13 + $16);
 $18 = (($t) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($7 * $19);
 $21 = Math_fround($17 + $20);
 $22 = Math_fround($1 * $11);
 $23 = Math_fround($7 * $15);
 $24 = Math_fround($4 * $19);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($9 * $25);
 $27 = Math_fround($22 + $26);
 $28 = Math_fround($12 * $21);
 $29 = Math_fround($28 + $27);
 $30 = Math_fround($4 * $11);
 $31 = Math_fround($1 * $19);
 $32 = Math_fround($7 * $12);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($9 * $33);
 $35 = Math_fround($30 + $34);
 $36 = Math_fround($15 * $21);
 $37 = Math_fround($36 + $35);
 $38 = Math_fround($7 * $11);
 $39 = Math_fround($4 * $12);
 $40 = Math_fround($1 * $15);
 $41 = Math_fround($39 - $40);
 $42 = Math_fround($9 * $41);
 $43 = Math_fround($38 + $42);
 $44 = Math_fround($19 * $21);
 $45 = Math_fround($43 + $44);
 HEAPF32[$agg$result>>2] = $29;
 $46 = (($agg$result) + 4|0);
 HEAPF32[$46>>2] = $37;
 $47 = (($agg$result) + 8|0);
 HEAPF32[$47>>2] = $45;
 $48 = (($box) + 12|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * Math_fround(2.0));
 $51 = (($box) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 * Math_fround(2.0));
 $54 = (($box) + 20|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * Math_fround(2.0));
 $57 = Math_fround($50 * $12);
 $58 = Math_fround($53 * $15);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($56 * $19);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($50 * $11);
 $63 = Math_fround($56 * $15);
 $64 = Math_fround($53 * $19);
 $65 = Math_fround($63 - $64);
 $66 = Math_fround($9 * $65);
 $67 = Math_fround($62 + $66);
 $68 = Math_fround($12 * $61);
 $69 = Math_fround($68 + $67);
 $70 = Math_fround($53 * $11);
 $71 = Math_fround($50 * $19);
 $72 = Math_fround($56 * $12);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($9 * $73);
 $75 = Math_fround($70 + $74);
 $76 = Math_fround($15 * $61);
 $77 = Math_fround($76 + $75);
 $78 = Math_fround($56 * $11);
 $79 = Math_fround($53 * $12);
 $80 = Math_fround($50 * $15);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($9 * $81);
 $83 = Math_fround($78 + $82);
 $84 = Math_fround($19 * $61);
 $85 = Math_fround($83 + $84);
 $86 = (($agg$result) + 12|0);
 HEAPF32[$86>>2] = $69;
 $87 = (($agg$result) + 16|0);
 HEAPF32[$87>>2] = $77;
 $88 = (($agg$result) + 20|0);
 HEAPF32[$88>>2] = $85;
 $89 = (($box) + 24|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($90 * Math_fround(2.0));
 $92 = (($box) + 28|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($93 * Math_fround(2.0));
 $95 = (($box) + 32|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($96 * Math_fround(2.0));
 $98 = Math_fround($91 * $12);
 $99 = Math_fround($94 * $15);
 $100 = Math_fround($98 + $99);
 $101 = Math_fround($97 * $19);
 $102 = Math_fround($100 + $101);
 $103 = Math_fround($91 * $11);
 $104 = Math_fround($97 * $15);
 $105 = Math_fround($94 * $19);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($9 * $106);
 $108 = Math_fround($103 + $107);
 $109 = Math_fround($12 * $102);
 $110 = Math_fround($109 + $108);
 $111 = Math_fround($94 * $11);
 $112 = Math_fround($91 * $19);
 $113 = Math_fround($97 * $12);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($9 * $114);
 $116 = Math_fround($111 + $115);
 $117 = Math_fround($15 * $102);
 $118 = Math_fround($117 + $116);
 $119 = Math_fround($97 * $11);
 $120 = Math_fround($94 * $12);
 $121 = Math_fround($91 * $15);
 $122 = Math_fround($120 - $121);
 $123 = Math_fround($9 * $122);
 $124 = Math_fround($119 + $123);
 $125 = Math_fround($19 * $102);
 $126 = Math_fround($124 + $125);
 $127 = (($agg$result) + 24|0);
 HEAPF32[$127>>2] = $110;
 $128 = (($agg$result) + 28|0);
 HEAPF32[$128>>2] = $118;
 $129 = (($agg$result) + 32|0);
 HEAPF32[$129>>2] = $126;
 $130 = (($box) + 36|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($131 * Math_fround(2.0));
 $133 = (($box) + 40|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($134 * Math_fround(2.0));
 $136 = (($box) + 44|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($137 * Math_fround(2.0));
 $139 = Math_fround(HEAPF32[$8>>2]);
 $140 = Math_fround($139 * $139);
 $141 = Math_fround($140 + Math_fround(-0.5));
 $142 = Math_fround(HEAPF32[$t>>2]);
 $143 = Math_fround($132 * $142);
 $144 = Math_fround(HEAPF32[$14>>2]);
 $145 = Math_fround($135 * $144);
 $146 = Math_fround($143 + $145);
 $147 = Math_fround(HEAPF32[$18>>2]);
 $148 = Math_fround($138 * $147);
 $149 = Math_fround($146 + $148);
 $150 = Math_fround($132 * $141);
 $151 = Math_fround($138 * $144);
 $152 = Math_fround($135 * $147);
 $153 = Math_fround($151 - $152);
 $154 = Math_fround($139 * $153);
 $155 = Math_fround($150 + $154);
 $156 = Math_fround($142 * $149);
 $157 = Math_fround($156 + $155);
 $158 = Math_fround($135 * $141);
 $159 = Math_fround($132 * $147);
 $160 = Math_fround($138 * $142);
 $161 = Math_fround($159 - $160);
 $162 = Math_fround($139 * $161);
 $163 = Math_fround($158 + $162);
 $164 = Math_fround($144 * $149);
 $165 = Math_fround($164 + $163);
 $166 = Math_fround($138 * $141);
 $167 = Math_fround($135 * $142);
 $168 = Math_fround($132 * $144);
 $169 = Math_fround($167 - $168);
 $170 = Math_fround($139 * $169);
 $171 = Math_fround($166 + $170);
 $172 = Math_fround($147 * $149);
 $173 = Math_fround($171 + $172);
 $174 = (($t) + 16|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = Math_fround($175 + $157);
 $177 = (($t) + 20|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = Math_fround($178 + $165);
 $180 = (($t) + 24|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = Math_fround($181 + $173);
 $183 = (($agg$result) + 36|0);
 HEAPF32[$183>>2] = $176;
 $184 = (($agg$result) + 40|0);
 HEAPF32[$184>>2] = $179;
 $185 = (($agg$result) + 44|0);
 HEAPF32[$185>>2] = $182;
 $186 = (($box) + 48|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = (($agg$result) + 48|0);
 HEAPF32[$188>>2] = $187;
 $189 = (($box) + 52|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($agg$result) + 52|0);
 HEAPF32[$191>>2] = $190;
 $192 = (($box) + 56|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($agg$result) + 56|0);
 HEAPF32[$194>>2] = $193;
 STACKTOP = sp;return;
}
function __ZZN5physxL20PxcSweepAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEEN13AccumCallbackD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZN5physxL20PxcSweepAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEEN13AccumCallback10processHitERKNS_12PxRaycastHitERKS9_SK_SK_RfPKj($this,$hit,$0,$1,$2,$3,$4) {
 $this = $this|0;
 $hit = $hit|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($hit) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$6>>2]|0;
 $12 = ($10|0)==($11|0);
 if ($12) {
  (__ZN5physx2Gu9Container6ResizeEj($6,1)|0);
  $$pre$i = HEAP32[$9>>2]|0;
  $14 = $$pre$i;
 } else {
  $14 = $10;
 }
 $13 = (($14) + 1)|0;
 HEAP32[$9>>2] = $13;
 $15 = (($6) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14<<2)|0);
 HEAP32[$17>>2] = $8;
 STACKTOP = sp;return 1;
}
function __ZZN5physxL20PxcSweepAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEEN13AccumCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx29EntityReportContainerCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx29EntityReportContainerCallback7onEventEjPj($this,$nb,$indices) {
 $this = $this|0;
 $nb = $nb|0;
 $indices = $indices|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($indices|0)==(0|0);
 $3 = ($nb|0)==(0);
 $or$cond$i = $2 | $3;
 if ($or$cond$i) {
  STACKTOP = sp;return 1;
 }
 $4 = (($1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($nb))|0;
 $7 = HEAP32[$1>>2]|0;
 $8 = ($6>>>0)>($7>>>0);
 if ($8) {
  (__ZN5physx2Gu9Container6ResizeEj($1,$nb)|0);
  $$pre$i = HEAP32[$4>>2]|0;
  $12 = $$pre$i;
 } else {
  $12 = $5;
 }
 $9 = (($1) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($12<<2)|0);
 $13 = $nb << 2;
 _memcpy(($11|0),($indices|0),($13|0))|0;
 $14 = HEAP32[$4>>2]|0;
 $15 = (($14) + ($nb))|0;
 HEAP32[$4>>2] = $15;
 STACKTOP = sp;return 1;
}
function __ZZN5physx28PxcSweepEstimateAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fEN2CBD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZN5physx28PxcSweepEstimateAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fEN2CB10processHitERKNS_12PxRaycastHitERKNS_6PxVec3ESF_SF_RfPKj($this,$hit,$0,$1,$2,$shrunkMaxT,$3) {
 $this = $this|0;
 $hit = $hit|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $shrunkMaxT = $shrunkMaxT|0;
 $3 = $3|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0);
 var $convexPartOfMesh1 = 0, $unused = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $unused = sp + 128|0;
 $convexPartOfMesh1 = sp;
 $4 = sp + 80|0;
 $5 = sp + 92|0;
 $6 = sp + 104|0;
 $7 = sp + 116|0;
 $8 = (($this) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($hit) + 8|0);
 HEAP32[$convexPartOfMesh1>>2] = $9;
 $13 = (($convexPartOfMesh1) + 4|0);
 HEAP32[$13>>2] = $11;
 $14 = (($convexPartOfMesh1) + 8|0);
 HEAP32[$14>>2] = $12;
 $15 = (($convexPartOfMesh1) + 12|0);
 HEAP32[$15>>2] = 1;
 $16 = (($convexPartOfMesh1) + 16|0);
 HEAP32[$16>>2] = $unused;
 $17 = (($convexPartOfMesh1) + 40|0);
 HEAPF32[$17>>2] = Math_fround(8.50705866596322149529E+37);
 $18 = (($convexPartOfMesh1) + 44|0);
 HEAPF32[$18>>2] = Math_fround(8.50705866596322149529E+37);
 $19 = (($convexPartOfMesh1) + 48|0);
 HEAPF32[$19>>2] = Math_fround(8.50705866596322149529E+37);
 $20 = (($convexPartOfMesh1) + 52|0);
 HEAPF32[$20>>2] = Math_fround(-8.50705866596322149529E+37);
 $21 = (($convexPartOfMesh1) + 56|0);
 HEAPF32[$21>>2] = Math_fround(-8.50705866596322149529E+37);
 $22 = (($convexPartOfMesh1) + 60|0);
 HEAPF32[$22>>2] = Math_fround(-8.50705866596322149529E+37);
 $23 = (($convexPartOfMesh1) + 64|0);
 ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP8[$23+12>>0]=0|0;
 $24 = (($this) + 36|0);
 $25 = HEAP32[$24>>2]|0;
 __ZNK5physx18PxcConvexTriangles16getPolygonNormalEj($4,$convexPartOfMesh1,0);
 $26 = Math_fround(HEAPF32[$4>>2]);
 $27 = Math_fround($26 * Math_fround(2.0));
 $28 = (($4) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * Math_fround(2.0));
 $31 = (($4) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(2.0));
 $34 = (($25) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * $35);
 $37 = Math_fround($36 + Math_fround(-0.5));
 $38 = Math_fround(HEAPF32[$25>>2]);
 $39 = Math_fround($27 * $38);
 $40 = (($25) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($30 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (($25) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($33 * $45);
 $47 = Math_fround($43 + $46);
 $48 = Math_fround($27 * $37);
 $49 = Math_fround($33 * $41);
 $50 = Math_fround($30 * $45);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($35 * $51);
 $53 = Math_fround($48 + $52);
 $54 = Math_fround($38 * $47);
 $55 = Math_fround($54 + $53);
 $56 = Math_fround($30 * $37);
 $57 = Math_fround($27 * $45);
 $58 = Math_fround($33 * $38);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($35 * $59);
 $61 = Math_fround($56 + $60);
 $62 = Math_fround($41 * $47);
 $63 = Math_fround($62 + $61);
 $64 = Math_fround($33 * $37);
 $65 = Math_fround($30 * $38);
 $66 = Math_fround($27 * $41);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($35 * $67);
 $69 = Math_fround($64 + $68);
 $70 = Math_fround($45 * $47);
 $71 = Math_fround($69 + $70);
 $72 = (($this) + 24|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($74 * $55);
 $76 = (($73) + 4|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 * $63);
 $79 = Math_fround(-$78);
 $80 = Math_fround($79 - $75);
 $81 = (($73) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($71 * $82);
 $84 = Math_fround($80 - $83);
 $85 = (($this) + 12|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = !($84 >= $86);
 if ($87) {
  $$pre = (($this) + 8|0);
  $$pre$phiZ2D = $$pre;
  $140 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
  $141 = $140 > Math_fround(0.0);
  STACKTOP = sp;return ($141|0);
 } else {
  $88 = HEAP32[$24>>2]|0;
  __ZNK5physx18PxcConvexTriangles19calcCenterAndBoundsERKNS_11PxTransformE($convexPartOfMesh1,$88);
  $89 = Math_fround(HEAPF32[$17>>2]);
  $90 = Math_fround(HEAPF32[$18>>2]);
  $91 = Math_fround(HEAPF32[$19>>2]);
  $92 = Math_fround(HEAPF32[$20>>2]);
  $93 = Math_fround(HEAPF32[$21>>2]);
  $94 = Math_fround(HEAPF32[$22>>2]);
  $95 = (($this) + 40|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (($this) + 44|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = Math_fround($99 * Math_fround(1.10000002384185791016));
  $101 = (($98) + 4|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($102 * Math_fround(1.10000002384185791016));
  $104 = (($98) + 8|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($105 * Math_fround(1.10000002384185791016));
  HEAPF32[$5>>2] = $100;
  $107 = (($5) + 4|0);
  HEAPF32[$107>>2] = $103;
  $108 = (($5) + 8|0);
  HEAPF32[$108>>2] = $106;
  $109 = Math_fround($89 + $92);
  $110 = Math_fround($90 + $93);
  $111 = Math_fround($91 + $94);
  $112 = Math_fround($109 * Math_fround(0.5));
  $113 = Math_fround($110 * Math_fround(0.5));
  $114 = Math_fround($111 * Math_fround(0.5));
  HEAPF32[$6>>2] = $112;
  $115 = (($6) + 4|0);
  HEAPF32[$115>>2] = $113;
  $116 = (($6) + 8|0);
  HEAPF32[$116>>2] = $114;
  $117 = Math_fround($92 - $89);
  $118 = Math_fround($93 - $90);
  $119 = Math_fround($94 - $91);
  $120 = Math_fround($117 * Math_fround(0.5));
  $121 = Math_fround($118 * Math_fround(0.5));
  $122 = Math_fround($119 * Math_fround(0.5));
  $123 = Math_fround($120 + Math_fround(0.00999999977648258209228));
  $124 = Math_fround($121 + Math_fround(0.00999999977648258209228));
  $125 = Math_fround($122 + Math_fround(0.00999999977648258209228));
  $126 = Math_fround($123 * Math_fround(1.10000002384185791016));
  $127 = Math_fround($124 * Math_fround(1.10000002384185791016));
  $128 = Math_fround($125 * Math_fround(1.10000002384185791016));
  HEAPF32[$7>>2] = $126;
  $129 = (($7) + 4|0);
  HEAPF32[$129>>2] = $127;
  $130 = (($7) + 8|0);
  HEAPF32[$130>>2] = $128;
  $131 = (($this) + 28|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = (($this) + 32|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = (Math_fround(__Z13sweepAABBAABBRKN5physx6PxVec3ES2_S2_S2_S2_S2_($96,$5,$6,$7,$132,$134)));
  $136 = (($this) + 8|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = $137 < $135;
  $139 = $138 ? $137 : $135;
  HEAPF32[$136>>2] = $139;
  HEAPF32[$shrunkMaxT>>2] = $139;
  $$pre$phiZ2D = $136;
  $140 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
  $141 = $140 > Math_fround(0.0);
  STACKTOP = sp;return ($141|0);
 }
 return 0|0;
}
function __ZZN5physx28PxcSweepEstimateAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fEN2CBD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx12PxcLtbFactorERNS_9PxcFsDataE($m) {
 $m = $m|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $inertia = 0, $jResponse = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $inertia = sp + 384|0;
 $jResponse = sp;
 $0 = sp + 48|0;
 $1 = sp + 96|0;
 $2 = sp + 240|0;
 $3 = (($m) + 24|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = (($m) + ($5)|0);
 $7 = (($m) + 8|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $10 = (($9) + -1)|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = (($0) + 4|0);
  $13 = (($0) + 8|0);
  $14 = (($0) + 16|0);
  $15 = (($0) + 20|0);
  $16 = (($0) + 24|0);
  $17 = (($0) + 32|0);
  $18 = (($0) + 36|0);
  $19 = (($0) + 40|0);
  $20 = (($jResponse) + 4|0);
  $21 = (($jResponse) + 8|0);
  $22 = (($jResponse) + 12|0);
  $23 = (($jResponse) + 16|0);
  $24 = (($jResponse) + 20|0);
  $25 = (($jResponse) + 24|0);
  $26 = (($jResponse) + 28|0);
  $27 = (($jResponse) + 32|0);
  $28 = (($jResponse) + 36|0);
  $29 = (($jResponse) + 40|0);
  $30 = (($jResponse) + 44|0);
  $31 = (($inertia) + 16|0);
  $32 = (($inertia) + 32|0);
  $33 = (($inertia) + 48|0);
  $34 = (($inertia) + 64|0);
  $35 = (($inertia) + 80|0);
  $36 = (($inertia) + 96|0);
  $37 = (($inertia) + 112|0);
  $38 = (($inertia) + 128|0);
  $39 = (($1) + 16|0);
  $40 = (($1) + 32|0);
  $41 = (($1) + 48|0);
  $42 = (($1) + 64|0);
  $43 = (($1) + 80|0);
  $44 = (($1) + 96|0);
  $45 = (($1) + 112|0);
  $46 = (($1) + 128|0);
  $48 = $10;
  while(1) {
   $47 = ((($m) + ($48)|0) + 64|0);
   $49 = HEAP8[$47>>0]|0;
   $50 = $49&255;
   $51 = (($6) + (($48*400)|0)|0);
   __ZN5physx26PxcArticulationFnsSimdBase13invertInertiaERKNS_12PxcFsInertiaE($inertia,$51);
   $52 = ((($6) + (($48*400)|0)|0) + 240|0);
   __ZN5physx26PxcArticulationFnsSimdBase10computeSISERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialEPS4_($0,$inertia,$52,$52);
   $53 = Math_fround(HEAPF32[$0>>2]);
   $54 = Math_fround(HEAPF32[$12>>2]);
   $55 = Math_fround(HEAPF32[$13>>2]);
   $56 = Math_fround(HEAPF32[$14>>2]);
   $57 = Math_fround(HEAPF32[$15>>2]);
   $58 = Math_fround(HEAPF32[$16>>2]);
   $59 = Math_fround(HEAPF32[$17>>2]);
   $60 = Math_fround(HEAPF32[$18>>2]);
   $61 = Math_fround(HEAPF32[$19>>2]);
   $62 = Math_fround($57 * $61);
   $63 = Math_fround($58 * $60);
   $64 = Math_fround($62 - $63);
   $65 = Math_fround($58 * $59);
   $66 = Math_fround($56 * $61);
   $67 = Math_fround($65 - $66);
   $68 = Math_fround($56 * $60);
   $69 = Math_fround($57 * $59);
   $70 = Math_fround($68 - $69);
   $71 = Math_fround($53 * $61);
   $72 = Math_fround($55 * $59);
   $73 = Math_fround($71 - $72);
   $74 = Math_fround($54 * $59);
   $75 = Math_fround($53 * $60);
   $76 = Math_fround($74 - $75);
   $77 = Math_fround($53 * $57);
   $78 = Math_fround($54 * $56);
   $79 = Math_fround($77 - $78);
   $80 = Math_fround($53 * $64);
   $81 = Math_fround($54 * $67);
   $82 = Math_fround(-$81);
   $83 = Math_fround($82 - $80);
   $84 = Math_fround($55 * $70);
   $85 = Math_fround($83 - $84);
   $86 = Math_fround(Math_fround(1.0) / $85);
   $87 = Math_fround($86 * $64);
   $88 = Math_fround($86 * $67);
   $89 = Math_fround($70 * $86);
   $90 = Math_fround($86 * $73);
   $91 = Math_fround($86 * $76);
   $92 = Math_fround($79 * $86);
   HEAPF32[$jResponse>>2] = $87;
   HEAPF32[$20>>2] = $88;
   HEAPF32[$21>>2] = $89;
   HEAPF32[$22>>2] = Math_fround(0.0);
   HEAPF32[$23>>2] = $88;
   HEAPF32[$24>>2] = $90;
   HEAPF32[$25>>2] = $91;
   HEAPF32[$26>>2] = Math_fround(0.0);
   HEAPF32[$27>>2] = $89;
   HEAPF32[$28>>2] = $91;
   HEAPF32[$29>>2] = $92;
   HEAPF32[$30>>2] = Math_fround(0.0);
   ;HEAP32[$51+0>>2]=HEAP32[$inertia+0>>2]|0;HEAP32[$51+4>>2]=HEAP32[$inertia+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$inertia+8>>2]|0;HEAP32[$51+12>>2]=HEAP32[$inertia+12>>2]|0;
   $93 = ((($6) + (($48*400)|0)|0) + 16|0);
   ;HEAP32[$93+0>>2]=HEAP32[$31+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$31+8>>2]|0;HEAP32[$93+12>>2]=HEAP32[$31+12>>2]|0;
   $94 = ((($6) + (($48*400)|0)|0) + 32|0);
   ;HEAP32[$94+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$94+12>>2]=HEAP32[$32+12>>2]|0;
   $95 = ((($6) + (($48*400)|0)|0) + 48|0);
   ;HEAP32[$95+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$95+12>>2]=HEAP32[$33+12>>2]|0;
   $96 = ((($6) + (($48*400)|0)|0) + 64|0);
   ;HEAP32[$96+0>>2]=HEAP32[$34+0>>2]|0;HEAP32[$96+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$96+8>>2]=HEAP32[$34+8>>2]|0;HEAP32[$96+12>>2]=HEAP32[$34+12>>2]|0;
   $97 = ((($6) + (($48*400)|0)|0) + 80|0);
   ;HEAP32[$97+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$97+12>>2]=HEAP32[$35+12>>2]|0;
   $98 = ((($6) + (($48*400)|0)|0) + 96|0);
   ;HEAP32[$98+0>>2]=HEAP32[$36+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$36+8>>2]|0;HEAP32[$98+12>>2]=HEAP32[$36+12>>2]|0;
   $99 = ((($6) + (($48*400)|0)|0) + 112|0);
   ;HEAP32[$99+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$37+12>>2]|0;
   $100 = ((($6) + (($48*400)|0)|0) + 128|0);
   ;HEAP32[$100+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$100+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$100+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$100+12>>2]=HEAP32[$38+12>>2]|0;
   $101 = (($6) + (($50*400)|0)|0);
   $102 = ((($6) + (($48*400)|0)|0) + 144|0);
   __ZN5physx26PxcArticulationFnsSimdBase16multiplySubtractERKNS_12PxcFsInertiaERKNS_6shdfnd3aos6Mat33VEPKNS_14PxcSIMDSpatialEPS9_($1,$101,$jResponse,$102,$102);
   ;HEAP32[$101+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$101+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$101+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$101+12>>2]=HEAP32[$1+12>>2]|0;
   $103 = ((($6) + (($50*400)|0)|0) + 16|0);
   ;HEAP32[$103+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$39+12>>2]|0;
   $104 = ((($6) + (($50*400)|0)|0) + 32|0);
   ;HEAP32[$104+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$104+12>>2]=HEAP32[$40+12>>2]|0;
   $105 = ((($6) + (($50*400)|0)|0) + 48|0);
   ;HEAP32[$105+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$105+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$105+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$105+12>>2]=HEAP32[$41+12>>2]|0;
   $106 = ((($6) + (($50*400)|0)|0) + 64|0);
   ;HEAP32[$106+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$42+12>>2]|0;
   $107 = ((($6) + (($50*400)|0)|0) + 80|0);
   ;HEAP32[$107+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$107+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$107+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$107+12>>2]=HEAP32[$43+12>>2]|0;
   $108 = ((($6) + (($50*400)|0)|0) + 96|0);
   ;HEAP32[$108+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$108+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$108+8>>2]=HEAP32[$44+8>>2]|0;HEAP32[$108+12>>2]=HEAP32[$44+12>>2]|0;
   $109 = ((($6) + (($50*400)|0)|0) + 112|0);
   ;HEAP32[$109+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$109+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$45+8>>2]|0;HEAP32[$109+12>>2]=HEAP32[$45+12>>2]|0;
   $110 = ((($6) + (($50*400)|0)|0) + 128|0);
   ;HEAP32[$110+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$110+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$110+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$110+12>>2]=HEAP32[$46+12>>2]|0;
   $111 = ((($6) + (($48*400)|0)|0) + 336|0);
   dest=$111+0|0; src=$jResponse+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $112 = (($48) + -1)|0;
   $113 = ($112|0)==(0);
   if ($113) {
    break;
   } else {
    $48 = $112;
   }
  }
 }
 __ZN5physx26PxcArticulationFnsSimdBase13invertInertiaERKNS_12PxcFsInertiaE($2,$6);
 ;HEAP32[$6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$2+12>>2]|0;
 $$sum = (($5) + 16)|0;
 $114 = (($m) + ($$sum)|0);
 $115 = (($2) + 16|0);
 ;HEAP32[$114+0>>2]=HEAP32[$115+0>>2]|0;HEAP32[$114+4>>2]=HEAP32[$115+4>>2]|0;HEAP32[$114+8>>2]=HEAP32[$115+8>>2]|0;HEAP32[$114+12>>2]=HEAP32[$115+12>>2]|0;
 $$sum1 = (($5) + 32)|0;
 $116 = (($m) + ($$sum1)|0);
 $117 = (($2) + 32|0);
 ;HEAP32[$116+0>>2]=HEAP32[$117+0>>2]|0;HEAP32[$116+4>>2]=HEAP32[$117+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[$117+8>>2]|0;HEAP32[$116+12>>2]=HEAP32[$117+12>>2]|0;
 $$sum2 = (($5) + 48)|0;
 $118 = (($m) + ($$sum2)|0);
 $119 = (($2) + 48|0);
 ;HEAP32[$118+0>>2]=HEAP32[$119+0>>2]|0;HEAP32[$118+4>>2]=HEAP32[$119+4>>2]|0;HEAP32[$118+8>>2]=HEAP32[$119+8>>2]|0;HEAP32[$118+12>>2]=HEAP32[$119+12>>2]|0;
 $$sum3 = (($5) + 64)|0;
 $120 = (($m) + ($$sum3)|0);
 $121 = (($2) + 64|0);
 ;HEAP32[$120+0>>2]=HEAP32[$121+0>>2]|0;HEAP32[$120+4>>2]=HEAP32[$121+4>>2]|0;HEAP32[$120+8>>2]=HEAP32[$121+8>>2]|0;HEAP32[$120+12>>2]=HEAP32[$121+12>>2]|0;
 $$sum4 = (($5) + 80)|0;
 $122 = (($m) + ($$sum4)|0);
 $123 = (($2) + 80|0);
 ;HEAP32[$122+0>>2]=HEAP32[$123+0>>2]|0;HEAP32[$122+4>>2]=HEAP32[$123+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$123+8>>2]|0;HEAP32[$122+12>>2]=HEAP32[$123+12>>2]|0;
 $$sum5 = (($5) + 96)|0;
 $124 = (($m) + ($$sum5)|0);
 $125 = (($2) + 96|0);
 ;HEAP32[$124+0>>2]=HEAP32[$125+0>>2]|0;HEAP32[$124+4>>2]=HEAP32[$125+4>>2]|0;HEAP32[$124+8>>2]=HEAP32[$125+8>>2]|0;HEAP32[$124+12>>2]=HEAP32[$125+12>>2]|0;
 $$sum6 = (($5) + 112)|0;
 $126 = (($m) + ($$sum6)|0);
 $127 = (($2) + 112|0);
 ;HEAP32[$126+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$126+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$126+8>>2]=HEAP32[$127+8>>2]|0;HEAP32[$126+12>>2]=HEAP32[$127+12>>2]|0;
 $$sum7 = (($5) + 128)|0;
 $128 = (($m) + ($$sum7)|0);
 $129 = (($2) + 128|0);
 ;HEAP32[$128+0>>2]=HEAP32[$129+0>>2]|0;HEAP32[$128+4>>2]=HEAP32[$129+4>>2]|0;HEAP32[$128+8>>2]=HEAP32[$129+8>>2]|0;HEAP32[$128+12>>2]=HEAP32[$129+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx26PxcArticulationFnsSimdBase13invertInertiaERKNS_12PxcFsInertiaE($agg$result,$I) {
 $agg$result = $agg$result|0;
 $I = $I|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0;
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($I) + 96|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($I) + 112|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($I) + 128|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($I) + 100|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($I) + 116|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($I) + 132|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($I) + 104|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($I) + 120|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($I) + 136|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($1 + $1);
 $19 = Math_fround($3 + $7);
 $20 = Math_fround($5 + $13);
 $21 = Math_fround($9 + $9);
 $22 = Math_fround($11 + $15);
 $23 = Math_fround($17 + $17);
 $24 = Math_fround($18 * Math_fround(0.5));
 $25 = Math_fround($19 * Math_fround(0.5));
 $26 = Math_fround($20 * Math_fround(0.5));
 $27 = Math_fround($21 * Math_fround(0.5));
 $28 = Math_fround($22 * Math_fround(0.5));
 $29 = Math_fround($23 * Math_fround(0.5));
 $30 = Math_fround(HEAPF32[$I>>2]);
 $31 = (($I) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($I) + 32|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($I) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($I) + 20|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($I) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($I) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($I) + 24|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($I) + 40|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($30 + $30);
 $48 = Math_fround($32 + $36);
 $49 = Math_fround($34 + $42);
 $50 = Math_fround($38 + $38);
 $51 = Math_fround($40 + $44);
 $52 = Math_fround($46 + $46);
 $53 = Math_fround($47 * Math_fround(0.5));
 $54 = Math_fround($48 * Math_fround(0.5));
 $55 = Math_fround($49 * Math_fround(0.5));
 $56 = Math_fround($50 * Math_fround(0.5));
 $57 = Math_fround($51 * Math_fround(0.5));
 $58 = Math_fround($52 * Math_fround(0.5));
 $59 = Math_fround($27 * $29);
 $60 = Math_fround($28 * $28);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($26 * $28);
 $63 = Math_fround($25 * $29);
 $64 = Math_fround($62 - $63);
 $65 = Math_fround($25 * $28);
 $66 = Math_fround($27 * $26);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($24 * $29);
 $69 = Math_fround($26 * $26);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($25 * $26);
 $72 = Math_fround($24 * $28);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($24 * $27);
 $75 = Math_fround($25 * $25);
 $76 = Math_fround($74 - $75);
 $77 = Math_fround($24 * $61);
 $78 = Math_fround($25 * $64);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($26 * $67);
 $81 = Math_fround($80 + $79);
 $82 = Math_fround(Math_fround(1.0) / $81);
 $83 = Math_fround($61 * $82);
 $84 = Math_fround($64 * $82);
 $85 = Math_fround($67 * $82);
 $86 = Math_fround($70 * $82);
 $87 = Math_fround($73 * $82);
 $88 = Math_fround($76 * $82);
 $89 = (($I) + 48|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($I) + 52|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($I) + 56|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround(-$90);
 $96 = Math_fround(-$92);
 $97 = Math_fround(-$94);
 $98 = (($I) + 64|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($I) + 68|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($I) + 72|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround(-$99);
 $105 = Math_fround(-$101);
 $106 = Math_fround(-$103);
 $107 = (($I) + 80|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($I) + 84|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($I) + 88|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround(-$108);
 $114 = Math_fround(-$110);
 $115 = Math_fround(-$112);
 $116 = Math_fround($83 * $95);
 $117 = Math_fround($84 * $104);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($85 * $113);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($83 * $96);
 $122 = Math_fround($84 * $105);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($85 * $114);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($83 * $97);
 $127 = Math_fround($84 * $106);
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($85 * $115);
 $130 = Math_fround($128 + $129);
 $131 = Math_fround($84 * $95);
 $132 = Math_fround($86 * $104);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround($87 * $113);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround($84 * $96);
 $137 = Math_fround($86 * $105);
 $138 = Math_fround($136 + $137);
 $139 = Math_fround($87 * $114);
 $140 = Math_fround($138 + $139);
 $141 = Math_fround($84 * $97);
 $142 = Math_fround($86 * $106);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround($87 * $115);
 $145 = Math_fround($143 + $144);
 $146 = Math_fround($85 * $95);
 $147 = Math_fround($87 * $104);
 $148 = Math_fround($146 + $147);
 $149 = Math_fround($88 * $113);
 $150 = Math_fround($148 + $149);
 $151 = Math_fround($85 * $96);
 $152 = Math_fround($87 * $105);
 $153 = Math_fround($151 + $152);
 $154 = Math_fround($88 * $114);
 $155 = Math_fround($153 + $154);
 $156 = Math_fround($85 * $97);
 $157 = Math_fround($87 * $106);
 $158 = Math_fround($156 + $157);
 $159 = Math_fround($88 * $115);
 $160 = Math_fround($158 + $159);
 $161 = Math_fround($90 * $120);
 $162 = Math_fround($99 * $135);
 $163 = Math_fround($161 + $162);
 $164 = Math_fround($108 * $150);
 $165 = Math_fround($164 + $163);
 $166 = Math_fround($90 * $125);
 $167 = Math_fround($99 * $140);
 $168 = Math_fround($166 + $167);
 $169 = Math_fround($108 * $155);
 $170 = Math_fround($169 + $168);
 $171 = Math_fround($90 * $130);
 $172 = Math_fround($99 * $145);
 $173 = Math_fround($171 + $172);
 $174 = Math_fround($108 * $160);
 $175 = Math_fround($174 + $173);
 $176 = Math_fround($92 * $120);
 $177 = Math_fround($101 * $135);
 $178 = Math_fround($176 + $177);
 $179 = Math_fround($110 * $150);
 $180 = Math_fround($179 + $178);
 $181 = Math_fround($92 * $125);
 $182 = Math_fround($101 * $140);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround($110 * $155);
 $185 = Math_fround($184 + $183);
 $186 = Math_fround($92 * $130);
 $187 = Math_fround($101 * $145);
 $188 = Math_fround($186 + $187);
 $189 = Math_fround($110 * $160);
 $190 = Math_fround($189 + $188);
 $191 = Math_fround($94 * $120);
 $192 = Math_fround($103 * $135);
 $193 = Math_fround($191 + $192);
 $194 = Math_fround($112 * $150);
 $195 = Math_fround($194 + $193);
 $196 = Math_fround($94 * $125);
 $197 = Math_fround($103 * $140);
 $198 = Math_fround($196 + $197);
 $199 = Math_fround($112 * $155);
 $200 = Math_fround($199 + $198);
 $201 = Math_fround($94 * $130);
 $202 = Math_fround($103 * $145);
 $203 = Math_fround($201 + $202);
 $204 = Math_fround($112 * $160);
 $205 = Math_fround($204 + $203);
 $206 = Math_fround($53 + $165);
 $207 = Math_fround($54 + $170);
 $208 = Math_fround($55 + $175);
 $209 = Math_fround($54 + $180);
 $210 = Math_fround($56 + $185);
 $211 = Math_fround($57 + $190);
 $212 = Math_fround($55 + $195);
 $213 = Math_fround($57 + $200);
 $214 = Math_fround($58 + $205);
 $215 = Math_fround($210 * $214);
 $216 = Math_fround($213 * $211);
 $217 = Math_fround($215 - $216);
 $218 = Math_fround($212 * $211);
 $219 = Math_fround($209 * $214);
 $220 = Math_fround($218 - $219);
 $221 = Math_fround($209 * $213);
 $222 = Math_fround($212 * $210);
 $223 = Math_fround($221 - $222);
 $224 = Math_fround($206 * $214);
 $225 = Math_fround($212 * $208);
 $226 = Math_fround($224 - $225);
 $227 = Math_fround($212 * $207);
 $228 = Math_fround($206 * $213);
 $229 = Math_fround($227 - $228);
 $230 = Math_fround($206 * $210);
 $231 = Math_fround($209 * $207);
 $232 = Math_fround($230 - $231);
 $233 = Math_fround($206 * $217);
 $234 = Math_fround($207 * $220);
 $235 = Math_fround($233 + $234);
 $236 = Math_fround($208 * $223);
 $237 = Math_fround($236 + $235);
 $238 = Math_fround(Math_fround(1.0) / $237);
 $239 = Math_fround($238 * $217);
 $240 = Math_fround($238 * $220);
 $241 = Math_fround($238 * $223);
 $242 = Math_fround($238 * $226);
 $243 = Math_fround($238 * $229);
 $244 = Math_fround($238 * $232);
 $245 = Math_fround($120 * $239);
 $246 = Math_fround($125 * $240);
 $247 = Math_fround($245 + $246);
 $248 = Math_fround($130 * $241);
 $249 = Math_fround($248 + $247);
 $250 = Math_fround($120 * $240);
 $251 = Math_fround($125 * $242);
 $252 = Math_fround($250 + $251);
 $253 = Math_fround($130 * $243);
 $254 = Math_fround($253 + $252);
 $255 = Math_fround($120 * $241);
 $256 = Math_fround($125 * $243);
 $257 = Math_fround($255 + $256);
 $258 = Math_fround($130 * $244);
 $259 = Math_fround($258 + $257);
 $260 = Math_fround($135 * $239);
 $261 = Math_fround($140 * $240);
 $262 = Math_fround($260 + $261);
 $263 = Math_fround($145 * $241);
 $264 = Math_fround($263 + $262);
 $265 = Math_fround($135 * $240);
 $266 = Math_fround($140 * $242);
 $267 = Math_fround($265 + $266);
 $268 = Math_fround($145 * $243);
 $269 = Math_fround($268 + $267);
 $270 = Math_fround($135 * $241);
 $271 = Math_fround($140 * $243);
 $272 = Math_fround($270 + $271);
 $273 = Math_fround($145 * $244);
 $274 = Math_fround($273 + $272);
 $275 = Math_fround($150 * $239);
 $276 = Math_fround($155 * $240);
 $277 = Math_fround($275 + $276);
 $278 = Math_fround($160 * $241);
 $279 = Math_fround($278 + $277);
 $280 = Math_fround($150 * $240);
 $281 = Math_fround($155 * $242);
 $282 = Math_fround($280 + $281);
 $283 = Math_fround($160 * $243);
 $284 = Math_fround($283 + $282);
 $285 = Math_fround($150 * $241);
 $286 = Math_fround($155 * $243);
 $287 = Math_fround($285 + $286);
 $288 = Math_fround($160 * $244);
 $289 = Math_fround($288 + $287);
 $290 = Math_fround($120 * $249);
 $291 = Math_fround($125 * $254);
 $292 = Math_fround($290 + $291);
 $293 = Math_fround($130 * $259);
 $294 = Math_fround($293 + $292);
 $295 = Math_fround($135 * $249);
 $296 = Math_fround($140 * $254);
 $297 = Math_fround($295 + $296);
 $298 = Math_fround($145 * $259);
 $299 = Math_fround($298 + $297);
 $300 = Math_fround($150 * $249);
 $301 = Math_fround($155 * $254);
 $302 = Math_fround($300 + $301);
 $303 = Math_fround($160 * $259);
 $304 = Math_fround($303 + $302);
 $305 = Math_fround($120 * $264);
 $306 = Math_fround($125 * $269);
 $307 = Math_fround($305 + $306);
 $308 = Math_fround($130 * $274);
 $309 = Math_fround($308 + $307);
 $310 = Math_fround($135 * $264);
 $311 = Math_fround($140 * $269);
 $312 = Math_fround($310 + $311);
 $313 = Math_fround($145 * $274);
 $314 = Math_fround($313 + $312);
 $315 = Math_fround($150 * $264);
 $316 = Math_fround($155 * $269);
 $317 = Math_fround($315 + $316);
 $318 = Math_fround($160 * $274);
 $319 = Math_fround($318 + $317);
 $320 = Math_fround($120 * $279);
 $321 = Math_fround($125 * $284);
 $322 = Math_fround($320 + $321);
 $323 = Math_fround($130 * $289);
 $324 = Math_fround($323 + $322);
 $325 = Math_fround($135 * $279);
 $326 = Math_fround($140 * $284);
 $327 = Math_fround($325 + $326);
 $328 = Math_fround($145 * $289);
 $329 = Math_fround($328 + $327);
 $330 = Math_fround($150 * $279);
 $331 = Math_fround($155 * $284);
 $332 = Math_fround($330 + $331);
 $333 = Math_fround($160 * $289);
 $334 = Math_fround($333 + $332);
 $335 = Math_fround($83 + $294);
 $336 = Math_fround($84 + $299);
 $337 = Math_fround($85 + $304);
 $338 = Math_fround($84 + $309);
 $339 = Math_fround($86 + $314);
 $340 = Math_fround($87 + $319);
 $341 = Math_fround($85 + $324);
 $342 = Math_fround($87 + $329);
 $343 = Math_fround($88 + $334);
 HEAPF32[$agg$result>>2] = $239;
 $344 = (($agg$result) + 4|0);
 HEAPF32[$344>>2] = $240;
 $345 = (($agg$result) + 8|0);
 HEAPF32[$345>>2] = $241;
 $346 = (($agg$result) + 12|0);
 HEAPF32[$346>>2] = Math_fround(0.0);
 $347 = (($agg$result) + 16|0);
 HEAPF32[$347>>2] = $240;
 $348 = (($agg$result) + 20|0);
 HEAPF32[$348>>2] = $242;
 $349 = (($agg$result) + 24|0);
 HEAPF32[$349>>2] = $243;
 $350 = (($agg$result) + 28|0);
 HEAPF32[$350>>2] = Math_fround(0.0);
 $351 = (($agg$result) + 32|0);
 HEAPF32[$351>>2] = $241;
 $352 = (($agg$result) + 36|0);
 HEAPF32[$352>>2] = $243;
 $353 = (($agg$result) + 40|0);
 HEAPF32[$353>>2] = $244;
 $354 = (($agg$result) + 44|0);
 HEAPF32[$354>>2] = Math_fround(0.0);
 $355 = (($agg$result) + 48|0);
 HEAPF32[$355>>2] = $249;
 $356 = (($agg$result) + 52|0);
 HEAPF32[$356>>2] = $254;
 $357 = (($agg$result) + 56|0);
 HEAPF32[$357>>2] = $259;
 $358 = (($agg$result) + 60|0);
 HEAPF32[$358>>2] = Math_fround(0.0);
 $359 = (($agg$result) + 64|0);
 HEAPF32[$359>>2] = $264;
 $360 = (($agg$result) + 68|0);
 HEAPF32[$360>>2] = $269;
 $361 = (($agg$result) + 72|0);
 HEAPF32[$361>>2] = $274;
 $362 = (($agg$result) + 76|0);
 HEAPF32[$362>>2] = Math_fround(0.0);
 $363 = (($agg$result) + 80|0);
 HEAPF32[$363>>2] = $279;
 $364 = (($agg$result) + 84|0);
 HEAPF32[$364>>2] = $284;
 $365 = (($agg$result) + 88|0);
 HEAPF32[$365>>2] = $289;
 $366 = (($agg$result) + 92|0);
 HEAPF32[$366>>2] = Math_fround(0.0);
 $367 = (($agg$result) + 96|0);
 HEAPF32[$367>>2] = $335;
 $368 = (($agg$result) + 100|0);
 HEAPF32[$368>>2] = $336;
 $369 = (($agg$result) + 104|0);
 HEAPF32[$369>>2] = $337;
 $370 = (($agg$result) + 108|0);
 HEAPF32[$370>>2] = Math_fround(0.0);
 $371 = (($agg$result) + 112|0);
 HEAPF32[$371>>2] = $338;
 $372 = (($agg$result) + 116|0);
 HEAPF32[$372>>2] = $339;
 $373 = (($agg$result) + 120|0);
 HEAPF32[$373>>2] = $340;
 $374 = (($agg$result) + 124|0);
 HEAPF32[$374>>2] = Math_fround(0.0);
 $375 = (($agg$result) + 128|0);
 HEAPF32[$375>>2] = $341;
 $376 = (($agg$result) + 132|0);
 HEAPF32[$376>>2] = $342;
 $377 = (($agg$result) + 136|0);
 HEAPF32[$377>>2] = $343;
 $378 = (($agg$result) + 140|0);
 HEAPF32[$378>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx26PxcArticulationFnsSimdBase10computeSISERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialEPS4_($agg$result,$I,$S,$IS) {
 $agg$result = $agg$result|0;
 $I = $I|0;
 $S = $S|0;
 $IS = $IS|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$S>>2]);
 $1 = (($S) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($S) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($S) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($S) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($S) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($S) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($S) + 36|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($S) + 40|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($S) + 48|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($S) + 52|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($S) + 56|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($S) + 64|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($S) + 68|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($S) + 72|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($S) + 80|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($S) + 84|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($S) + 88|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround(HEAPF32[$I>>2]);
 $36 = Math_fround($0 * $35);
 $37 = (($I) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($2 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($I) + 32|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($4 * $42);
 $44 = Math_fround($40 + $43);
 $45 = (($I) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($0 * $46);
 $48 = (($I) + 20|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($2 * $49);
 $51 = Math_fround($47 + $50);
 $52 = (($I) + 36|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($4 * $53);
 $55 = Math_fround($51 + $54);
 $56 = (($I) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($0 * $57);
 $59 = (($I) + 24|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($2 * $60);
 $62 = Math_fround($58 + $61);
 $63 = (($I) + 40|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($4 * $64);
 $66 = Math_fround($62 + $65);
 $67 = (($I) + 48|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($6 * $68);
 $70 = (($I) + 64|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($8 * $71);
 $73 = Math_fround($69 + $72);
 $74 = (($I) + 80|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($10 * $75);
 $77 = Math_fround($73 + $76);
 $78 = (($I) + 52|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($6 * $79);
 $81 = (($I) + 68|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($8 * $82);
 $84 = Math_fround($80 + $83);
 $85 = (($I) + 84|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($10 * $86);
 $88 = Math_fround($84 + $87);
 $89 = (($I) + 56|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($6 * $90);
 $92 = (($I) + 72|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($8 * $93);
 $95 = Math_fround($91 + $94);
 $96 = (($I) + 88|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($10 * $97);
 $99 = Math_fround($95 + $98);
 $100 = Math_fround($44 + $77);
 $101 = Math_fround($55 + $88);
 $102 = Math_fround($66 + $99);
 $103 = Math_fround($0 * $68);
 $104 = Math_fround($2 * $79);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($4 * $90);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($0 * $71);
 $109 = Math_fround($2 * $82);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($4 * $93);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround($0 * $75);
 $114 = Math_fround($2 * $86);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($4 * $97);
 $117 = Math_fround($115 + $116);
 $118 = (($I) + 96|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($6 * $119);
 $121 = (($I) + 112|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround($8 * $122);
 $124 = Math_fround($120 + $123);
 $125 = (($I) + 128|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($10 * $126);
 $128 = Math_fround($124 + $127);
 $129 = (($I) + 100|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = Math_fround($6 * $130);
 $132 = (($I) + 116|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($8 * $133);
 $135 = Math_fround($131 + $134);
 $136 = (($I) + 132|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($10 * $137);
 $139 = Math_fround($135 + $138);
 $140 = (($I) + 104|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = Math_fround($6 * $141);
 $143 = (($I) + 120|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround($8 * $144);
 $146 = Math_fround($142 + $145);
 $147 = (($I) + 136|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = Math_fround($10 * $148);
 $150 = Math_fround($146 + $149);
 $151 = Math_fround($107 + $128);
 $152 = Math_fround($112 + $139);
 $153 = Math_fround($117 + $150);
 $154 = Math_fround($12 * $35);
 $155 = Math_fround($14 * $38);
 $156 = Math_fround($154 + $155);
 $157 = Math_fround($16 * $42);
 $158 = Math_fround($156 + $157);
 $159 = Math_fround($12 * $46);
 $160 = Math_fround($14 * $49);
 $161 = Math_fround($159 + $160);
 $162 = Math_fround($16 * $53);
 $163 = Math_fround($161 + $162);
 $164 = Math_fround($12 * $57);
 $165 = Math_fround($14 * $60);
 $166 = Math_fround($164 + $165);
 $167 = Math_fround($16 * $64);
 $168 = Math_fround($166 + $167);
 $169 = Math_fround($18 * $68);
 $170 = Math_fround($20 * $71);
 $171 = Math_fround($169 + $170);
 $172 = Math_fround($22 * $75);
 $173 = Math_fround($171 + $172);
 $174 = Math_fround($18 * $79);
 $175 = Math_fround($20 * $82);
 $176 = Math_fround($174 + $175);
 $177 = Math_fround($22 * $86);
 $178 = Math_fround($176 + $177);
 $179 = Math_fround($18 * $90);
 $180 = Math_fround($20 * $93);
 $181 = Math_fround($179 + $180);
 $182 = Math_fround($22 * $97);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround($158 + $173);
 $185 = Math_fround($163 + $178);
 $186 = Math_fround($168 + $183);
 $187 = Math_fround($12 * $68);
 $188 = Math_fround($14 * $79);
 $189 = Math_fround($187 + $188);
 $190 = Math_fround($16 * $90);
 $191 = Math_fround($189 + $190);
 $192 = Math_fround($12 * $71);
 $193 = Math_fround($14 * $82);
 $194 = Math_fround($192 + $193);
 $195 = Math_fround($16 * $93);
 $196 = Math_fround($194 + $195);
 $197 = Math_fround($12 * $75);
 $198 = Math_fround($14 * $86);
 $199 = Math_fround($197 + $198);
 $200 = Math_fround($16 * $97);
 $201 = Math_fround($199 + $200);
 $202 = Math_fround($18 * $119);
 $203 = Math_fround($20 * $122);
 $204 = Math_fround($202 + $203);
 $205 = Math_fround($22 * $126);
 $206 = Math_fround($204 + $205);
 $207 = Math_fround($18 * $130);
 $208 = Math_fround($20 * $133);
 $209 = Math_fround($207 + $208);
 $210 = Math_fround($22 * $137);
 $211 = Math_fround($209 + $210);
 $212 = Math_fround($18 * $141);
 $213 = Math_fround($20 * $144);
 $214 = Math_fround($212 + $213);
 $215 = Math_fround($22 * $148);
 $216 = Math_fround($214 + $215);
 $217 = Math_fround($191 + $206);
 $218 = Math_fround($196 + $211);
 $219 = Math_fround($201 + $216);
 $220 = Math_fround($24 * $35);
 $221 = Math_fround($26 * $38);
 $222 = Math_fround($220 + $221);
 $223 = Math_fround($28 * $42);
 $224 = Math_fround($222 + $223);
 $225 = Math_fround($24 * $46);
 $226 = Math_fround($26 * $49);
 $227 = Math_fround($225 + $226);
 $228 = Math_fround($28 * $53);
 $229 = Math_fround($227 + $228);
 $230 = Math_fround($24 * $57);
 $231 = Math_fround($26 * $60);
 $232 = Math_fround($230 + $231);
 $233 = Math_fround($28 * $64);
 $234 = Math_fround($232 + $233);
 $235 = Math_fround($30 * $68);
 $236 = Math_fround($32 * $71);
 $237 = Math_fround($235 + $236);
 $238 = Math_fround($34 * $75);
 $239 = Math_fround($237 + $238);
 $240 = Math_fround($30 * $79);
 $241 = Math_fround($32 * $82);
 $242 = Math_fround($240 + $241);
 $243 = Math_fround($34 * $86);
 $244 = Math_fround($242 + $243);
 $245 = Math_fround($30 * $90);
 $246 = Math_fround($32 * $93);
 $247 = Math_fround($245 + $246);
 $248 = Math_fround($34 * $97);
 $249 = Math_fround($247 + $248);
 $250 = Math_fround($224 + $239);
 $251 = Math_fround($229 + $244);
 $252 = Math_fround($234 + $249);
 $253 = Math_fround($24 * $68);
 $254 = Math_fround($26 * $79);
 $255 = Math_fround($253 + $254);
 $256 = Math_fround($28 * $90);
 $257 = Math_fround($255 + $256);
 $258 = Math_fround($24 * $71);
 $259 = Math_fround($26 * $82);
 $260 = Math_fround($258 + $259);
 $261 = Math_fround($28 * $93);
 $262 = Math_fround($260 + $261);
 $263 = Math_fround($24 * $75);
 $264 = Math_fround($26 * $86);
 $265 = Math_fround($263 + $264);
 $266 = Math_fround($28 * $97);
 $267 = Math_fround($265 + $266);
 $268 = Math_fround($30 * $119);
 $269 = Math_fround($32 * $122);
 $270 = Math_fround($268 + $269);
 $271 = Math_fround($34 * $126);
 $272 = Math_fround($270 + $271);
 $273 = Math_fround($30 * $130);
 $274 = Math_fround($32 * $133);
 $275 = Math_fround($273 + $274);
 $276 = Math_fround($34 * $137);
 $277 = Math_fround($275 + $276);
 $278 = Math_fround($30 * $141);
 $279 = Math_fround($32 * $144);
 $280 = Math_fround($278 + $279);
 $281 = Math_fround($34 * $148);
 $282 = Math_fround($280 + $281);
 $283 = Math_fround($257 + $272);
 $284 = Math_fround($262 + $277);
 $285 = Math_fround($267 + $282);
 $286 = Math_fround($0 * $100);
 $287 = Math_fround($2 * $101);
 $288 = Math_fround($286 + $287);
 $289 = Math_fround($4 * $102);
 $290 = Math_fround($288 + $289);
 $291 = Math_fround($6 * $151);
 $292 = Math_fround($8 * $152);
 $293 = Math_fround($291 + $292);
 $294 = Math_fround($10 * $153);
 $295 = Math_fround($293 + $294);
 $296 = Math_fround($290 + $295);
 $297 = Math_fround($0 * $184);
 $298 = Math_fround($2 * $185);
 $299 = Math_fround($297 + $298);
 $300 = Math_fround($4 * $186);
 $301 = Math_fround($299 + $300);
 $302 = Math_fround($6 * $217);
 $303 = Math_fround($8 * $218);
 $304 = Math_fround($302 + $303);
 $305 = Math_fround($10 * $219);
 $306 = Math_fround($304 + $305);
 $307 = Math_fround($301 + $306);
 $308 = Math_fround($0 * $250);
 $309 = Math_fround($2 * $251);
 $310 = Math_fround($308 + $309);
 $311 = Math_fround($4 * $252);
 $312 = Math_fround($310 + $311);
 $313 = Math_fround($6 * $283);
 $314 = Math_fround($8 * $284);
 $315 = Math_fround($313 + $314);
 $316 = Math_fround($10 * $285);
 $317 = Math_fround($315 + $316);
 $318 = Math_fround($312 + $317);
 $319 = Math_fround($12 * $184);
 $320 = Math_fround($14 * $185);
 $321 = Math_fround($319 + $320);
 $322 = Math_fround($16 * $186);
 $323 = Math_fround($321 + $322);
 $324 = Math_fround($18 * $217);
 $325 = Math_fround($20 * $218);
 $326 = Math_fround($324 + $325);
 $327 = Math_fround($22 * $219);
 $328 = Math_fround($326 + $327);
 $329 = Math_fround($323 + $328);
 $330 = Math_fround($12 * $250);
 $331 = Math_fround($14 * $251);
 $332 = Math_fround($330 + $331);
 $333 = Math_fround($16 * $252);
 $334 = Math_fround($332 + $333);
 $335 = Math_fround($18 * $283);
 $336 = Math_fround($20 * $284);
 $337 = Math_fround($335 + $336);
 $338 = Math_fround($22 * $285);
 $339 = Math_fround($337 + $338);
 $340 = Math_fround($334 + $339);
 $341 = Math_fround($24 * $250);
 $342 = Math_fround($26 * $251);
 $343 = Math_fround($341 + $342);
 $344 = Math_fround($28 * $252);
 $345 = Math_fround($343 + $344);
 $346 = Math_fround($30 * $283);
 $347 = Math_fround($32 * $284);
 $348 = Math_fround($346 + $347);
 $349 = Math_fround($34 * $285);
 $350 = Math_fround($348 + $349);
 $351 = Math_fround($345 + $350);
 HEAPF32[$IS>>2] = $100;
 $352 = (($IS) + 4|0);
 HEAPF32[$352>>2] = $101;
 $353 = (($IS) + 8|0);
 HEAPF32[$353>>2] = $102;
 $354 = (($IS) + 12|0);
 HEAPF32[$354>>2] = Math_fround(0.0);
 $355 = (($IS) + 16|0);
 HEAPF32[$355>>2] = $151;
 $356 = (($IS) + 20|0);
 HEAPF32[$356>>2] = $152;
 $357 = (($IS) + 24|0);
 HEAPF32[$357>>2] = $153;
 $358 = (($IS) + 28|0);
 HEAPF32[$358>>2] = Math_fround(0.0);
 $359 = (($IS) + 32|0);
 HEAPF32[$359>>2] = $184;
 $360 = (($IS) + 36|0);
 HEAPF32[$360>>2] = $185;
 $361 = (($IS) + 40|0);
 HEAPF32[$361>>2] = $186;
 $362 = (($IS) + 44|0);
 HEAPF32[$362>>2] = Math_fround(0.0);
 $363 = (($IS) + 48|0);
 HEAPF32[$363>>2] = $217;
 $364 = (($IS) + 52|0);
 HEAPF32[$364>>2] = $218;
 $365 = (($IS) + 56|0);
 HEAPF32[$365>>2] = $219;
 $366 = (($IS) + 60|0);
 HEAPF32[$366>>2] = Math_fround(0.0);
 $367 = (($IS) + 64|0);
 HEAPF32[$367>>2] = $250;
 $368 = (($IS) + 68|0);
 HEAPF32[$368>>2] = $251;
 $369 = (($IS) + 72|0);
 HEAPF32[$369>>2] = $252;
 $370 = (($IS) + 76|0);
 HEAPF32[$370>>2] = Math_fround(0.0);
 $371 = (($IS) + 80|0);
 HEAPF32[$371>>2] = $283;
 $372 = (($IS) + 84|0);
 HEAPF32[$372>>2] = $284;
 $373 = (($IS) + 88|0);
 HEAPF32[$373>>2] = $285;
 $374 = (($IS) + 92|0);
 HEAPF32[$374>>2] = Math_fround(0.0);
 HEAPF32[$agg$result>>2] = $296;
 $375 = (($agg$result) + 4|0);
 HEAPF32[$375>>2] = $307;
 $376 = (($agg$result) + 8|0);
 HEAPF32[$376>>2] = $318;
 $377 = (($agg$result) + 12|0);
 HEAPF32[$377>>2] = Math_fround(0.0);
 $378 = (($agg$result) + 16|0);
 HEAPF32[$378>>2] = $307;
 $379 = (($agg$result) + 20|0);
 HEAPF32[$379>>2] = $329;
 $380 = (($agg$result) + 24|0);
 HEAPF32[$380>>2] = $340;
 $381 = (($agg$result) + 28|0);
 HEAPF32[$381>>2] = Math_fround(0.0);
 $382 = (($agg$result) + 32|0);
 HEAPF32[$382>>2] = $318;
 $383 = (($agg$result) + 36|0);
 HEAPF32[$383>>2] = $340;
 $384 = (($agg$result) + 40|0);
 HEAPF32[$384>>2] = $351;
 $385 = (($agg$result) + 44|0);
 HEAPF32[$385>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx26PxcArticulationFnsSimdBase16multiplySubtractERKNS_12PxcFsInertiaERKNS_6shdfnd3aos6Mat33VEPKNS_14PxcSIMDSpatialEPS9_($agg$result,$I,$D,$IS,$DSI) {
 $agg$result = $agg$result|0;
 $I = $I|0;
 $D = $D|0;
 $IS = $IS|0;
 $DSI = $DSI|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = Math_fround(0), $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$IS>>2]);
 $1 = (($IS) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($IS) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($IS) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($IS) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($IS) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($IS) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($IS) + 36|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($IS) + 40|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($IS) + 48|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($IS) + 52|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($IS) + 56|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($IS) + 64|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($IS) + 68|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($IS) + 72|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($IS) + 80|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($IS) + 84|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($IS) + 88|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround(HEAPF32[$D>>2]);
 $36 = (($D) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($D) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($D) + 16|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($D) + 20|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($D) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($D) + 32|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($D) + 36|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($D) + 40|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($24 * $39);
 $53 = Math_fround($26 * $39);
 $54 = Math_fround($28 * $39);
 $55 = Math_fround($12 * $37);
 $56 = Math_fround($14 * $37);
 $57 = Math_fround($16 * $37);
 $58 = Math_fround($55 + $52);
 $59 = Math_fround($56 + $53);
 $60 = Math_fround($57 + $54);
 $61 = Math_fround($0 * $35);
 $62 = Math_fround($2 * $35);
 $63 = Math_fround($4 * $35);
 $64 = Math_fround($61 + $58);
 $65 = Math_fround($62 + $59);
 $66 = Math_fround($63 + $60);
 $67 = Math_fround($24 * $45);
 $68 = Math_fround($26 * $45);
 $69 = Math_fround($28 * $45);
 $70 = Math_fround($12 * $43);
 $71 = Math_fround($14 * $43);
 $72 = Math_fround($16 * $43);
 $73 = Math_fround($70 + $67);
 $74 = Math_fround($71 + $68);
 $75 = Math_fround($72 + $69);
 $76 = Math_fround($0 * $41);
 $77 = Math_fround($2 * $41);
 $78 = Math_fround($4 * $41);
 $79 = Math_fround($76 + $73);
 $80 = Math_fround($77 + $74);
 $81 = Math_fround($78 + $75);
 $82 = Math_fround($24 * $51);
 $83 = Math_fround($26 * $51);
 $84 = Math_fround($28 * $51);
 $85 = Math_fround($12 * $49);
 $86 = Math_fround($14 * $49);
 $87 = Math_fround($16 * $49);
 $88 = Math_fround($85 + $82);
 $89 = Math_fround($86 + $83);
 $90 = Math_fround($87 + $84);
 $91 = Math_fround($0 * $47);
 $92 = Math_fround($2 * $47);
 $93 = Math_fround($4 * $47);
 $94 = Math_fround($91 + $88);
 $95 = Math_fround($92 + $89);
 $96 = Math_fround($93 + $90);
 $97 = Math_fround($30 * $39);
 $98 = Math_fround($32 * $39);
 $99 = Math_fround($34 * $39);
 $100 = Math_fround($18 * $37);
 $101 = Math_fround($20 * $37);
 $102 = Math_fround($22 * $37);
 $103 = Math_fround($100 + $97);
 $104 = Math_fround($101 + $98);
 $105 = Math_fround($102 + $99);
 $106 = Math_fround($6 * $35);
 $107 = Math_fround($8 * $35);
 $108 = Math_fround($10 * $35);
 $109 = Math_fround($106 + $103);
 $110 = Math_fround($107 + $104);
 $111 = Math_fround($108 + $105);
 $112 = Math_fround($30 * $45);
 $113 = Math_fround($32 * $45);
 $114 = Math_fround($34 * $45);
 $115 = Math_fround($18 * $43);
 $116 = Math_fround($20 * $43);
 $117 = Math_fround($22 * $43);
 $118 = Math_fround($115 + $112);
 $119 = Math_fround($116 + $113);
 $120 = Math_fround($117 + $114);
 $121 = Math_fround($6 * $41);
 $122 = Math_fround($8 * $41);
 $123 = Math_fround($10 * $41);
 $124 = Math_fround($121 + $118);
 $125 = Math_fround($122 + $119);
 $126 = Math_fround($123 + $120);
 $127 = Math_fround($30 * $51);
 $128 = Math_fround($32 * $51);
 $129 = Math_fround($34 * $51);
 $130 = Math_fround($18 * $49);
 $131 = Math_fround($20 * $49);
 $132 = Math_fround($22 * $49);
 $133 = Math_fround($130 + $127);
 $134 = Math_fround($131 + $128);
 $135 = Math_fround($132 + $129);
 $136 = Math_fround($6 * $47);
 $137 = Math_fround($8 * $47);
 $138 = Math_fround($10 * $47);
 $139 = Math_fround($136 + $133);
 $140 = Math_fround($137 + $134);
 $141 = Math_fround($138 + $135);
 $142 = Math_fround(HEAPF32[$I>>2]);
 $143 = (($I) + 4|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = (($I) + 8|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($I) + 16|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = (($I) + 20|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = (($I) + 24|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($I) + 32|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($I) + 36|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($I) + 40|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($I) + 48|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($I) + 52|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = (($I) + 56|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = (($I) + 64|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = (($I) + 68|0);
 $168 = Math_fround(HEAPF32[$167>>2]);
 $169 = (($I) + 72|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = (($I) + 80|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = (($I) + 84|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($I) + 88|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = (($I) + 96|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = (($I) + 100|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = (($I) + 104|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = (($I) + 112|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = (($I) + 116|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($I) + 120|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($I) + 128|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($I) + 132|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($I) + 136|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround($0 * $64);
 $196 = Math_fround($0 * $65);
 $197 = Math_fround($0 * $66);
 $198 = Math_fround($142 - $195);
 $199 = Math_fround($144 - $196);
 $200 = Math_fround($146 - $197);
 $201 = Math_fround($6 * $64);
 $202 = Math_fround($6 * $65);
 $203 = Math_fround($6 * $66);
 $204 = Math_fround($160 - $201);
 $205 = Math_fround($162 - $202);
 $206 = Math_fround($164 - $203);
 $207 = Math_fround($6 * $109);
 $208 = Math_fround($6 * $110);
 $209 = Math_fround($6 * $111);
 $210 = Math_fround($178 - $207);
 $211 = Math_fround($180 - $208);
 $212 = Math_fround($182 - $209);
 $213 = Math_fround($2 * $64);
 $214 = Math_fround($2 * $65);
 $215 = Math_fround($2 * $66);
 $216 = Math_fround($148 - $213);
 $217 = Math_fround($150 - $214);
 $218 = Math_fround($152 - $215);
 $219 = Math_fround($8 * $64);
 $220 = Math_fround($8 * $65);
 $221 = Math_fround($8 * $66);
 $222 = Math_fround($166 - $219);
 $223 = Math_fround($168 - $220);
 $224 = Math_fround($170 - $221);
 $225 = Math_fround($8 * $109);
 $226 = Math_fround($8 * $110);
 $227 = Math_fround($8 * $111);
 $228 = Math_fround($184 - $225);
 $229 = Math_fround($186 - $226);
 $230 = Math_fround($188 - $227);
 $231 = Math_fround($4 * $64);
 $232 = Math_fround($4 * $65);
 $233 = Math_fround($4 * $66);
 $234 = Math_fround($154 - $231);
 $235 = Math_fround($156 - $232);
 $236 = Math_fround($158 - $233);
 $237 = Math_fround($10 * $64);
 $238 = Math_fround($10 * $65);
 $239 = Math_fround($10 * $66);
 $240 = Math_fround($172 - $237);
 $241 = Math_fround($174 - $238);
 $242 = Math_fround($176 - $239);
 $243 = Math_fround($10 * $109);
 $244 = Math_fround($10 * $110);
 $245 = Math_fround($10 * $111);
 $246 = Math_fround($190 - $243);
 $247 = Math_fround($192 - $244);
 $248 = Math_fround($194 - $245);
 $249 = Math_fround($12 * $79);
 $250 = Math_fround($12 * $80);
 $251 = Math_fround($12 * $81);
 $252 = Math_fround($198 - $249);
 $253 = Math_fround($199 - $250);
 $254 = Math_fround($200 - $251);
 $255 = Math_fround($18 * $79);
 $256 = Math_fround($18 * $80);
 $257 = Math_fround($18 * $81);
 $258 = Math_fround($204 - $255);
 $259 = Math_fround($205 - $256);
 $260 = Math_fround($206 - $257);
 $261 = Math_fround($18 * $124);
 $262 = Math_fround($18 * $125);
 $263 = Math_fround($18 * $126);
 $264 = Math_fround($210 - $261);
 $265 = Math_fround($211 - $262);
 $266 = Math_fround($212 - $263);
 $267 = Math_fround($14 * $79);
 $268 = Math_fround($14 * $80);
 $269 = Math_fround($14 * $81);
 $270 = Math_fround($216 - $267);
 $271 = Math_fround($217 - $268);
 $272 = Math_fround($218 - $269);
 $273 = Math_fround($20 * $79);
 $274 = Math_fround($20 * $80);
 $275 = Math_fround($20 * $81);
 $276 = Math_fround($222 - $273);
 $277 = Math_fround($223 - $274);
 $278 = Math_fround($224 - $275);
 $279 = Math_fround($20 * $124);
 $280 = Math_fround($20 * $125);
 $281 = Math_fround($20 * $126);
 $282 = Math_fround($228 - $279);
 $283 = Math_fround($229 - $280);
 $284 = Math_fround($230 - $281);
 $285 = Math_fround($16 * $79);
 $286 = Math_fround($16 * $80);
 $287 = Math_fround($16 * $81);
 $288 = Math_fround($234 - $285);
 $289 = Math_fround($235 - $286);
 $290 = Math_fround($236 - $287);
 $291 = Math_fround($22 * $79);
 $292 = Math_fround($22 * $80);
 $293 = Math_fround($22 * $81);
 $294 = Math_fround($240 - $291);
 $295 = Math_fround($241 - $292);
 $296 = Math_fround($242 - $293);
 $297 = Math_fround($22 * $124);
 $298 = Math_fround($22 * $125);
 $299 = Math_fround($22 * $126);
 $300 = Math_fround($246 - $297);
 $301 = Math_fround($247 - $298);
 $302 = Math_fround($248 - $299);
 $303 = Math_fround($24 * $94);
 $304 = Math_fround($24 * $95);
 $305 = Math_fround($24 * $96);
 $306 = Math_fround($252 - $303);
 $307 = Math_fround($253 - $304);
 $308 = Math_fround($254 - $305);
 $309 = Math_fround($30 * $94);
 $310 = Math_fround($30 * $95);
 $311 = Math_fround($30 * $96);
 $312 = Math_fround($258 - $309);
 $313 = Math_fround($259 - $310);
 $314 = Math_fround($260 - $311);
 $315 = Math_fround($30 * $139);
 $316 = Math_fround($30 * $140);
 $317 = Math_fround($30 * $141);
 $318 = Math_fround($264 - $315);
 $319 = Math_fround($265 - $316);
 $320 = Math_fround($266 - $317);
 $321 = Math_fround($26 * $94);
 $322 = Math_fround($26 * $95);
 $323 = Math_fround($26 * $96);
 $324 = Math_fround($270 - $321);
 $325 = Math_fround($271 - $322);
 $326 = Math_fround($272 - $323);
 $327 = Math_fround($32 * $94);
 $328 = Math_fround($32 * $95);
 $329 = Math_fround($32 * $96);
 $330 = Math_fround($276 - $327);
 $331 = Math_fround($277 - $328);
 $332 = Math_fround($278 - $329);
 $333 = Math_fround($32 * $139);
 $334 = Math_fround($32 * $140);
 $335 = Math_fround($32 * $141);
 $336 = Math_fround($282 - $333);
 $337 = Math_fround($283 - $334);
 $338 = Math_fround($284 - $335);
 $339 = Math_fround($28 * $94);
 $340 = Math_fround($28 * $95);
 $341 = Math_fround($28 * $96);
 $342 = Math_fround($288 - $339);
 $343 = Math_fround($289 - $340);
 $344 = Math_fround($290 - $341);
 $345 = Math_fround($34 * $94);
 $346 = Math_fround($34 * $95);
 $347 = Math_fround($34 * $96);
 $348 = Math_fround($294 - $345);
 $349 = Math_fround($295 - $346);
 $350 = Math_fround($296 - $347);
 $351 = Math_fround($34 * $139);
 $352 = Math_fround($34 * $140);
 $353 = Math_fround($34 * $141);
 $354 = Math_fround($300 - $351);
 $355 = Math_fround($301 - $352);
 $356 = Math_fround($302 - $353);
 HEAPF32[$DSI>>2] = $64;
 $357 = (($DSI) + 4|0);
 HEAPF32[$357>>2] = $65;
 $358 = (($DSI) + 8|0);
 HEAPF32[$358>>2] = $66;
 $359 = (($DSI) + 12|0);
 HEAPF32[$359>>2] = Math_fround(0.0);
 $360 = (($DSI) + 16|0);
 HEAPF32[$360>>2] = $109;
 $361 = (($DSI) + 20|0);
 HEAPF32[$361>>2] = $110;
 $362 = (($DSI) + 24|0);
 HEAPF32[$362>>2] = $111;
 $363 = (($DSI) + 28|0);
 HEAPF32[$363>>2] = Math_fround(0.0);
 $364 = (($DSI) + 32|0);
 HEAPF32[$364>>2] = $79;
 $365 = (($DSI) + 36|0);
 HEAPF32[$365>>2] = $80;
 $366 = (($DSI) + 40|0);
 HEAPF32[$366>>2] = $81;
 $367 = (($DSI) + 44|0);
 HEAPF32[$367>>2] = Math_fround(0.0);
 $368 = (($DSI) + 48|0);
 HEAPF32[$368>>2] = $124;
 $369 = (($DSI) + 52|0);
 HEAPF32[$369>>2] = $125;
 $370 = (($DSI) + 56|0);
 HEAPF32[$370>>2] = $126;
 $371 = (($DSI) + 60|0);
 HEAPF32[$371>>2] = Math_fround(0.0);
 $372 = (($DSI) + 64|0);
 HEAPF32[$372>>2] = $94;
 $373 = (($DSI) + 68|0);
 HEAPF32[$373>>2] = $95;
 $374 = (($DSI) + 72|0);
 HEAPF32[$374>>2] = $96;
 $375 = (($DSI) + 76|0);
 HEAPF32[$375>>2] = Math_fround(0.0);
 $376 = (($DSI) + 80|0);
 HEAPF32[$376>>2] = $139;
 $377 = (($DSI) + 84|0);
 HEAPF32[$377>>2] = $140;
 $378 = (($DSI) + 88|0);
 HEAPF32[$378>>2] = $141;
 $379 = (($DSI) + 92|0);
 HEAPF32[$379>>2] = Math_fround(0.0);
 HEAPF32[$agg$result>>2] = $306;
 $380 = (($agg$result) + 4|0);
 HEAPF32[$380>>2] = $307;
 $381 = (($agg$result) + 8|0);
 HEAPF32[$381>>2] = $308;
 $382 = (($agg$result) + 12|0);
 HEAPF32[$382>>2] = Math_fround(0.0);
 $383 = (($agg$result) + 16|0);
 HEAPF32[$383>>2] = $324;
 $384 = (($agg$result) + 20|0);
 HEAPF32[$384>>2] = $325;
 $385 = (($agg$result) + 24|0);
 HEAPF32[$385>>2] = $326;
 $386 = (($agg$result) + 28|0);
 HEAPF32[$386>>2] = Math_fround(0.0);
 $387 = (($agg$result) + 32|0);
 HEAPF32[$387>>2] = $342;
 $388 = (($agg$result) + 36|0);
 HEAPF32[$388>>2] = $343;
 $389 = (($agg$result) + 40|0);
 HEAPF32[$389>>2] = $344;
 $390 = (($agg$result) + 44|0);
 HEAPF32[$390>>2] = Math_fround(0.0);
 $391 = (($agg$result) + 48|0);
 HEAPF32[$391>>2] = $312;
 $392 = (($agg$result) + 52|0);
 HEAPF32[$392>>2] = $313;
 $393 = (($agg$result) + 56|0);
 HEAPF32[$393>>2] = $314;
 $394 = (($agg$result) + 60|0);
 HEAPF32[$394>>2] = Math_fround(0.0);
 $395 = (($agg$result) + 64|0);
 HEAPF32[$395>>2] = $330;
 $396 = (($agg$result) + 68|0);
 HEAPF32[$396>>2] = $331;
 $397 = (($agg$result) + 72|0);
 HEAPF32[$397>>2] = $332;
 $398 = (($agg$result) + 76|0);
 HEAPF32[$398>>2] = Math_fround(0.0);
 $399 = (($agg$result) + 80|0);
 HEAPF32[$399>>2] = $348;
 $400 = (($agg$result) + 84|0);
 HEAPF32[$400>>2] = $349;
 $401 = (($agg$result) + 88|0);
 HEAPF32[$401>>2] = $350;
 $402 = (($agg$result) + 92|0);
 HEAPF32[$402>>2] = Math_fround(0.0);
 $403 = (($agg$result) + 96|0);
 HEAPF32[$403>>2] = $318;
 $404 = (($agg$result) + 100|0);
 HEAPF32[$404>>2] = $319;
 $405 = (($agg$result) + 104|0);
 HEAPF32[$405>>2] = $320;
 $406 = (($agg$result) + 108|0);
 HEAPF32[$406>>2] = Math_fround(0.0);
 $407 = (($agg$result) + 112|0);
 HEAPF32[$407>>2] = $336;
 $408 = (($agg$result) + 116|0);
 HEAPF32[$408>>2] = $337;
 $409 = (($agg$result) + 120|0);
 HEAPF32[$409>>2] = $338;
 $410 = (($agg$result) + 124|0);
 HEAPF32[$410>>2] = Math_fround(0.0);
 $411 = (($agg$result) + 128|0);
 HEAPF32[$411>>2] = $354;
 $412 = (($agg$result) + 132|0);
 HEAPF32[$412>>2] = $355;
 $413 = (($agg$result) + 136|0);
 HEAPF32[$413>>2] = $356;
 $414 = (($agg$result) + 140|0);
 HEAPF32[$414>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx11PxcLtbSolveERKNS_9PxcFsDataEPNS_6shdfnd3aos5Vec3VEPNS_14PxcSIMDSpatialE($m,$b,$y) {
 $m = $m|0;
 $b = $b|0;
 $y = $y|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0;
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0);
 var $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = 0;
 var $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0);
 var $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0;
 var $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0;
 var $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $i1$094 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = (($m) + 24|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($m) + ($4)|0);
 $6 = (($m) + 8|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7&65535;
 $9 = $8 << 5;
 _memset(($y|0),0,($9|0))|0;
 $10 = HEAP16[$6>>1]|0;
 $11 = ($10&65535)>(1);
 if ($11) {
  $12 = $10&65535;
  $$in = $12;
  while(1) {
   $13 = (($$in) + -1)|0;
   $14 = ((($m) + ($13)|0) + 64|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = $15&255;
   $17 = (($b) + ($13<<4)|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = ((($b) + ($13<<4)|0) + 4|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = ((($b) + ($13<<4)|0) + 8|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = ((($b) + ($13<<4)|0) + 12|0);
   $24 = ((($5) + (($13*400)|0)|0) + 240|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = ((($5) + (($13*400)|0)|0) + 244|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = ((($5) + (($13*400)|0)|0) + 248|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = (($y) + ($13<<5)|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = ((($y) + ($13<<5)|0) + 4|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = ((($y) + ($13<<5)|0) + 8|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = Math_fround($25 * $31);
   $37 = Math_fround($27 * $33);
   $38 = Math_fround($36 + $37);
   $39 = Math_fround($29 * $35);
   $40 = Math_fround($38 + $39);
   $41 = ((($5) + (($13*400)|0)|0) + 256|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = ((($5) + (($13*400)|0)|0) + 260|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = ((($5) + (($13*400)|0)|0) + 264|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = ((($y) + ($13<<5)|0) + 16|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = ((($y) + ($13<<5)|0) + 20|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = ((($y) + ($13<<5)|0) + 24|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $53 = Math_fround($42 * $48);
   $54 = Math_fround($44 * $50);
   $55 = Math_fround($53 + $54);
   $56 = Math_fround($46 * $52);
   $57 = Math_fround($55 + $56);
   $58 = Math_fround($40 + $57);
   $59 = ((($5) + (($13*400)|0)|0) + 272|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = ((($5) + (($13*400)|0)|0) + 276|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = ((($5) + (($13*400)|0)|0) + 280|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = Math_fround($31 * $60);
   $66 = Math_fround($33 * $62);
   $67 = Math_fround($65 + $66);
   $68 = Math_fround($35 * $64);
   $69 = Math_fround($67 + $68);
   $70 = ((($5) + (($13*400)|0)|0) + 288|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = ((($5) + (($13*400)|0)|0) + 292|0);
   $73 = Math_fround(HEAPF32[$72>>2]);
   $74 = ((($5) + (($13*400)|0)|0) + 296|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = Math_fround($48 * $71);
   $77 = Math_fround($50 * $73);
   $78 = Math_fround($76 + $77);
   $79 = Math_fround($52 * $75);
   $80 = Math_fround($78 + $79);
   $81 = Math_fround($69 + $80);
   $82 = ((($5) + (($13*400)|0)|0) + 304|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = ((($5) + (($13*400)|0)|0) + 308|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = ((($5) + (($13*400)|0)|0) + 312|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = Math_fround($31 * $83);
   $89 = Math_fround($33 * $85);
   $90 = Math_fround($88 + $89);
   $91 = Math_fround($35 * $87);
   $92 = Math_fround($90 + $91);
   $93 = ((($5) + (($13*400)|0)|0) + 320|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = ((($5) + (($13*400)|0)|0) + 324|0);
   $96 = Math_fround(HEAPF32[$95>>2]);
   $97 = ((($5) + (($13*400)|0)|0) + 328|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = Math_fround($48 * $94);
   $100 = Math_fround($50 * $96);
   $101 = Math_fround($99 + $100);
   $102 = Math_fround($52 * $98);
   $103 = Math_fround($101 + $102);
   $104 = Math_fround($92 + $103);
   $105 = Math_fround($18 - $58);
   $106 = Math_fround($20 - $81);
   $107 = Math_fround($22 - $104);
   HEAPF32[$17>>2] = $105;
   HEAPF32[$19>>2] = $106;
   HEAPF32[$21>>2] = $107;
   HEAPF32[$23>>2] = Math_fround(0.0);
   $108 = ((($5) + (($13*400)|0)|0) + 144|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = ((($5) + (($13*400)|0)|0) + 148|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = ((($5) + (($13*400)|0)|0) + 152|0);
   $113 = Math_fround(HEAPF32[$112>>2]);
   $114 = ((($5) + (($13*400)|0)|0) + 176|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = ((($5) + (($13*400)|0)|0) + 180|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = ((($5) + (($13*400)|0)|0) + 184|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = ((($5) + (($13*400)|0)|0) + 208|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = ((($5) + (($13*400)|0)|0) + 212|0);
   $123 = Math_fround(HEAPF32[$122>>2]);
   $124 = ((($5) + (($13*400)|0)|0) + 216|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = Math_fround($107 * $121);
   $127 = Math_fround($107 * $123);
   $128 = Math_fround($107 * $125);
   $129 = Math_fround($106 * $115);
   $130 = Math_fround($106 * $117);
   $131 = Math_fround($106 * $119);
   $132 = Math_fround($129 + $126);
   $133 = Math_fround($130 + $127);
   $134 = Math_fround($131 + $128);
   $135 = Math_fround($105 * $109);
   $136 = Math_fround($105 * $111);
   $137 = Math_fround($105 * $113);
   $138 = Math_fround($135 + $132);
   $139 = Math_fround($136 + $133);
   $140 = Math_fround($137 + $134);
   $141 = ((($5) + (($13*400)|0)|0) + 160|0);
   $142 = Math_fround(HEAPF32[$141>>2]);
   $143 = ((($5) + (($13*400)|0)|0) + 164|0);
   $144 = Math_fround(HEAPF32[$143>>2]);
   $145 = ((($5) + (($13*400)|0)|0) + 168|0);
   $146 = Math_fround(HEAPF32[$145>>2]);
   $147 = ((($5) + (($13*400)|0)|0) + 192|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = ((($5) + (($13*400)|0)|0) + 196|0);
   $150 = Math_fround(HEAPF32[$149>>2]);
   $151 = ((($5) + (($13*400)|0)|0) + 200|0);
   $152 = Math_fround(HEAPF32[$151>>2]);
   $153 = ((($5) + (($13*400)|0)|0) + 224|0);
   $154 = Math_fround(HEAPF32[$153>>2]);
   $155 = ((($5) + (($13*400)|0)|0) + 228|0);
   $156 = Math_fround(HEAPF32[$155>>2]);
   $157 = ((($5) + (($13*400)|0)|0) + 232|0);
   $158 = Math_fround(HEAPF32[$157>>2]);
   $159 = Math_fround($107 * $154);
   $160 = Math_fround($107 * $156);
   $161 = Math_fround($107 * $158);
   $162 = Math_fround($106 * $148);
   $163 = Math_fround($106 * $150);
   $164 = Math_fround($106 * $152);
   $165 = Math_fround($162 + $159);
   $166 = Math_fround($163 + $160);
   $167 = Math_fround($164 + $161);
   $168 = Math_fround($105 * $142);
   $169 = Math_fround($105 * $144);
   $170 = Math_fround($105 * $146);
   $171 = Math_fround($168 + $165);
   $172 = Math_fround($169 + $166);
   $173 = Math_fround($170 + $167);
   $174 = (($y) + ($16<<5)|0);
   $175 = Math_fround(HEAPF32[$174>>2]);
   $176 = ((($y) + ($16<<5)|0) + 4|0);
   $177 = Math_fround(HEAPF32[$176>>2]);
   $178 = ((($y) + ($16<<5)|0) + 8|0);
   $179 = Math_fround(HEAPF32[$178>>2]);
   $180 = Math_fround($175 - $138);
   $181 = Math_fround($177 - $139);
   $182 = Math_fround($179 - $140);
   $183 = ((($y) + ($16<<5)|0) + 16|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = ((($y) + ($16<<5)|0) + 20|0);
   $186 = Math_fround(HEAPF32[$185>>2]);
   $187 = ((($y) + ($16<<5)|0) + 24|0);
   $188 = Math_fround(HEAPF32[$187>>2]);
   $189 = Math_fround($184 - $171);
   $190 = Math_fround($186 - $172);
   $191 = Math_fround($188 - $173);
   HEAPF32[$174>>2] = $180;
   HEAPF32[$176>>2] = $181;
   HEAPF32[$178>>2] = $182;
   $192 = ((($y) + ($16<<5)|0) + 12|0);
   HEAPF32[$192>>2] = Math_fround(0.0);
   HEAPF32[$183>>2] = $189;
   HEAPF32[$185>>2] = $190;
   HEAPF32[$187>>2] = $191;
   $193 = ((($y) + ($16<<5)|0) + 28|0);
   HEAPF32[$193>>2] = Math_fround(0.0);
   $194 = ($13>>>0)>(1);
   if ($194) {
    $$in = $13;
   } else {
    break;
   }
  }
 }
 __ZN5physx26PxcArticulationFnsSimdBase8multiplyERKNS_12PxcFsInertiaERKNS_14PxcSIMDSpatialE($0,$5,$y);
 ;HEAP32[$y+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$y+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$y+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$y+12>>2]=HEAP32[$0+12>>2]|0;
 $195 = (($y) + 16|0);
 $196 = (($0) + 16|0);
 ;HEAP32[$195+0>>2]=HEAP32[$196+0>>2]|0;HEAP32[$195+4>>2]=HEAP32[$196+4>>2]|0;HEAP32[$195+8>>2]=HEAP32[$196+8>>2]|0;HEAP32[$195+12>>2]=HEAP32[$196+12>>2]|0;
 $197 = HEAP16[$6>>1]|0;
 $198 = ($197&65535)>(1);
 if (!($198)) {
  STACKTOP = sp;return;
 }
 $199 = (($1) + 4|0);
 $200 = (($1) + 8|0);
 $201 = (($1) + 16|0);
 $202 = (($1) + 20|0);
 $203 = (($1) + 24|0);
 $i1$094 = 1;
 while(1) {
  $204 = ((($m) + ($i1$094)|0) + 64|0);
  $205 = HEAP8[$204>>0]|0;
  $206 = $205&255;
  $207 = (($b) + ($i1$094<<4)|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = ((($b) + ($i1$094<<4)|0) + 4|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $211 = ((($b) + ($i1$094<<4)|0) + 8|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $213 = ((($5) + (($i1$094*400)|0)|0) + 336|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = Math_fround($208 * $214);
  $216 = ((($5) + (($i1$094*400)|0)|0) + 352|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = Math_fround($210 * $217);
  $219 = Math_fround($215 + $218);
  $220 = ((($5) + (($i1$094*400)|0)|0) + 368|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = Math_fround($212 * $221);
  $223 = Math_fround($219 + $222);
  $224 = ((($5) + (($i1$094*400)|0)|0) + 340|0);
  $225 = Math_fround(HEAPF32[$224>>2]);
  $226 = Math_fround($208 * $225);
  $227 = ((($5) + (($i1$094*400)|0)|0) + 356|0);
  $228 = Math_fround(HEAPF32[$227>>2]);
  $229 = Math_fround($210 * $228);
  $230 = Math_fround($226 + $229);
  $231 = ((($5) + (($i1$094*400)|0)|0) + 372|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = Math_fround($212 * $232);
  $234 = Math_fround($230 + $233);
  $235 = ((($5) + (($i1$094*400)|0)|0) + 344|0);
  $236 = Math_fround(HEAPF32[$235>>2]);
  $237 = Math_fround($208 * $236);
  $238 = ((($5) + (($i1$094*400)|0)|0) + 360|0);
  $239 = Math_fround(HEAPF32[$238>>2]);
  $240 = Math_fround($210 * $239);
  $241 = Math_fround($237 + $240);
  $242 = ((($5) + (($i1$094*400)|0)|0) + 376|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = Math_fround($212 * $243);
  $245 = Math_fround($241 + $244);
  $246 = ((($5) + (($i1$094*400)|0)|0) + 144|0);
  $247 = Math_fround(HEAPF32[$246>>2]);
  $248 = ((($5) + (($i1$094*400)|0)|0) + 148|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = ((($5) + (($i1$094*400)|0)|0) + 152|0);
  $251 = Math_fround(HEAPF32[$250>>2]);
  $252 = (($y) + ($206<<5)|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = ((($y) + ($206<<5)|0) + 4|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = ((($y) + ($206<<5)|0) + 8|0);
  $257 = Math_fround(HEAPF32[$256>>2]);
  $258 = Math_fround($247 * $253);
  $259 = Math_fround($249 * $255);
  $260 = Math_fround($258 + $259);
  $261 = Math_fround($251 * $257);
  $262 = Math_fround($260 + $261);
  $263 = ((($5) + (($i1$094*400)|0)|0) + 160|0);
  $264 = Math_fround(HEAPF32[$263>>2]);
  $265 = ((($5) + (($i1$094*400)|0)|0) + 164|0);
  $266 = Math_fround(HEAPF32[$265>>2]);
  $267 = ((($5) + (($i1$094*400)|0)|0) + 168|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = ((($y) + ($206<<5)|0) + 16|0);
  $270 = Math_fround(HEAPF32[$269>>2]);
  $271 = ((($y) + ($206<<5)|0) + 20|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = ((($y) + ($206<<5)|0) + 24|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = Math_fround($264 * $270);
  $276 = Math_fround($266 * $272);
  $277 = Math_fround($275 + $276);
  $278 = Math_fround($268 * $274);
  $279 = Math_fround($277 + $278);
  $280 = Math_fround($262 + $279);
  $281 = ((($5) + (($i1$094*400)|0)|0) + 176|0);
  $282 = Math_fround(HEAPF32[$281>>2]);
  $283 = ((($5) + (($i1$094*400)|0)|0) + 180|0);
  $284 = Math_fround(HEAPF32[$283>>2]);
  $285 = ((($5) + (($i1$094*400)|0)|0) + 184|0);
  $286 = Math_fround(HEAPF32[$285>>2]);
  $287 = Math_fround($253 * $282);
  $288 = Math_fround($255 * $284);
  $289 = Math_fround($287 + $288);
  $290 = Math_fround($257 * $286);
  $291 = Math_fround($289 + $290);
  $292 = ((($5) + (($i1$094*400)|0)|0) + 192|0);
  $293 = Math_fround(HEAPF32[$292>>2]);
  $294 = ((($5) + (($i1$094*400)|0)|0) + 196|0);
  $295 = Math_fround(HEAPF32[$294>>2]);
  $296 = ((($5) + (($i1$094*400)|0)|0) + 200|0);
  $297 = Math_fround(HEAPF32[$296>>2]);
  $298 = Math_fround($270 * $293);
  $299 = Math_fround($272 * $295);
  $300 = Math_fround($298 + $299);
  $301 = Math_fround($274 * $297);
  $302 = Math_fround($300 + $301);
  $303 = Math_fround($291 + $302);
  $304 = ((($5) + (($i1$094*400)|0)|0) + 208|0);
  $305 = Math_fround(HEAPF32[$304>>2]);
  $306 = ((($5) + (($i1$094*400)|0)|0) + 212|0);
  $307 = Math_fround(HEAPF32[$306>>2]);
  $308 = ((($5) + (($i1$094*400)|0)|0) + 216|0);
  $309 = Math_fround(HEAPF32[$308>>2]);
  $310 = Math_fround($253 * $305);
  $311 = Math_fround($255 * $307);
  $312 = Math_fround($310 + $311);
  $313 = Math_fround($257 * $309);
  $314 = Math_fround($312 + $313);
  $315 = ((($5) + (($i1$094*400)|0)|0) + 224|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = ((($5) + (($i1$094*400)|0)|0) + 228|0);
  $318 = Math_fround(HEAPF32[$317>>2]);
  $319 = ((($5) + (($i1$094*400)|0)|0) + 232|0);
  $320 = Math_fround(HEAPF32[$319>>2]);
  $321 = Math_fround($270 * $316);
  $322 = Math_fround($272 * $318);
  $323 = Math_fround($321 + $322);
  $324 = Math_fround($274 * $320);
  $325 = Math_fround($323 + $324);
  $326 = Math_fround($314 + $325);
  $327 = Math_fround($223 - $280);
  $328 = Math_fround($234 - $303);
  $329 = Math_fround($245 - $326);
  $330 = (($y) + ($i1$094<<5)|0);
  $331 = (($5) + (($i1$094*400)|0)|0);
  __ZN5physx26PxcArticulationFnsSimdBase8multiplyERKNS_12PxcFsInertiaERKNS_14PxcSIMDSpatialE($1,$331,$330);
  $332 = ((($5) + (($i1$094*400)|0)|0) + 240|0);
  $333 = Math_fround(HEAPF32[$332>>2]);
  $334 = ((($5) + (($i1$094*400)|0)|0) + 244|0);
  $335 = Math_fround(HEAPF32[$334>>2]);
  $336 = ((($5) + (($i1$094*400)|0)|0) + 248|0);
  $337 = Math_fround(HEAPF32[$336>>2]);
  $338 = ((($5) + (($i1$094*400)|0)|0) + 272|0);
  $339 = Math_fround(HEAPF32[$338>>2]);
  $340 = ((($5) + (($i1$094*400)|0)|0) + 276|0);
  $341 = Math_fround(HEAPF32[$340>>2]);
  $342 = ((($5) + (($i1$094*400)|0)|0) + 280|0);
  $343 = Math_fround(HEAPF32[$342>>2]);
  $344 = ((($5) + (($i1$094*400)|0)|0) + 304|0);
  $345 = Math_fround(HEAPF32[$344>>2]);
  $346 = ((($5) + (($i1$094*400)|0)|0) + 308|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  $348 = ((($5) + (($i1$094*400)|0)|0) + 312|0);
  $349 = Math_fround(HEAPF32[$348>>2]);
  $350 = Math_fround($329 * $345);
  $351 = Math_fround($329 * $347);
  $352 = Math_fround($329 * $349);
  $353 = Math_fround($328 * $339);
  $354 = Math_fround($328 * $341);
  $355 = Math_fround($328 * $343);
  $356 = Math_fround($353 + $350);
  $357 = Math_fround($354 + $351);
  $358 = Math_fround($355 + $352);
  $359 = Math_fround($327 * $333);
  $360 = Math_fround($327 * $335);
  $361 = Math_fround($327 * $337);
  $362 = Math_fround($359 + $356);
  $363 = Math_fround($360 + $357);
  $364 = Math_fround($361 + $358);
  $365 = ((($5) + (($i1$094*400)|0)|0) + 256|0);
  $366 = Math_fround(HEAPF32[$365>>2]);
  $367 = ((($5) + (($i1$094*400)|0)|0) + 260|0);
  $368 = Math_fround(HEAPF32[$367>>2]);
  $369 = ((($5) + (($i1$094*400)|0)|0) + 264|0);
  $370 = Math_fround(HEAPF32[$369>>2]);
  $371 = ((($5) + (($i1$094*400)|0)|0) + 288|0);
  $372 = Math_fround(HEAPF32[$371>>2]);
  $373 = ((($5) + (($i1$094*400)|0)|0) + 292|0);
  $374 = Math_fround(HEAPF32[$373>>2]);
  $375 = ((($5) + (($i1$094*400)|0)|0) + 296|0);
  $376 = Math_fround(HEAPF32[$375>>2]);
  $377 = ((($5) + (($i1$094*400)|0)|0) + 320|0);
  $378 = Math_fround(HEAPF32[$377>>2]);
  $379 = ((($5) + (($i1$094*400)|0)|0) + 324|0);
  $380 = Math_fround(HEAPF32[$379>>2]);
  $381 = ((($5) + (($i1$094*400)|0)|0) + 328|0);
  $382 = Math_fround(HEAPF32[$381>>2]);
  $383 = Math_fround($329 * $378);
  $384 = Math_fround($329 * $380);
  $385 = Math_fround($329 * $382);
  $386 = Math_fround($328 * $372);
  $387 = Math_fround($328 * $374);
  $388 = Math_fround($328 * $376);
  $389 = Math_fround($386 + $383);
  $390 = Math_fround($387 + $384);
  $391 = Math_fround($388 + $385);
  $392 = Math_fround($327 * $366);
  $393 = Math_fround($327 * $368);
  $394 = Math_fround($327 * $370);
  $395 = Math_fround($392 + $389);
  $396 = Math_fround($393 + $390);
  $397 = Math_fround($394 + $391);
  $398 = Math_fround(HEAPF32[$1>>2]);
  $399 = Math_fround(HEAPF32[$199>>2]);
  $400 = Math_fround(HEAPF32[$200>>2]);
  $401 = Math_fround($398 - $362);
  $402 = Math_fround($399 - $363);
  $403 = Math_fround($400 - $364);
  $404 = Math_fround(HEAPF32[$201>>2]);
  $405 = Math_fround(HEAPF32[$202>>2]);
  $406 = Math_fround(HEAPF32[$203>>2]);
  $407 = Math_fround($404 - $395);
  $408 = Math_fround($405 - $396);
  $409 = Math_fround($406 - $397);
  HEAPF32[$330>>2] = $401;
  $410 = ((($y) + ($i1$094<<5)|0) + 4|0);
  HEAPF32[$410>>2] = $402;
  $411 = ((($y) + ($i1$094<<5)|0) + 8|0);
  HEAPF32[$411>>2] = $403;
  $412 = ((($y) + ($i1$094<<5)|0) + 12|0);
  HEAPF32[$412>>2] = Math_fround(0.0);
  $413 = ((($y) + ($i1$094<<5)|0) + 16|0);
  HEAPF32[$413>>2] = $407;
  $414 = ((($y) + ($i1$094<<5)|0) + 20|0);
  HEAPF32[$414>>2] = $408;
  $415 = ((($y) + ($i1$094<<5)|0) + 24|0);
  HEAPF32[$415>>2] = $409;
  $416 = ((($y) + ($i1$094<<5)|0) + 28|0);
  HEAPF32[$416>>2] = Math_fround(0.0);
  $417 = (($i1$094) + 1)|0;
  $418 = HEAP16[$6>>1]|0;
  $419 = $418&65535;
  $420 = ($417>>>0)<($419>>>0);
  if ($420) {
   $i1$094 = $417;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx26PxcArticulationFnsSimdBase8multiplyERKNS_12PxcFsInertiaERKNS_14PxcSIMDSpatialE($agg$result,$I,$S) {
 $agg$result = $agg$result|0;
 $I = $I|0;
 $S = $S|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0;
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$S>>2]);
 $1 = (($S) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($S) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$I>>2]);
 $6 = Math_fround($0 * $5);
 $7 = (($I) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($2 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($I) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($4 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($I) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($0 * $16);
 $18 = (($I) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($2 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (($I) + 36|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($4 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($I) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($0 * $27);
 $29 = (($I) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($2 * $30);
 $32 = Math_fround($28 + $31);
 $33 = (($I) + 40|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($4 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($S) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($S) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($S) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($I) + 48|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($38 * $44);
 $46 = (($I) + 64|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($40 * $47);
 $49 = Math_fround($45 + $48);
 $50 = (($I) + 80|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($42 * $51);
 $53 = Math_fround($49 + $52);
 $54 = (($I) + 52|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($38 * $55);
 $57 = (($I) + 68|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($40 * $58);
 $60 = Math_fround($56 + $59);
 $61 = (($I) + 84|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($42 * $62);
 $64 = Math_fround($60 + $63);
 $65 = (($I) + 56|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($38 * $66);
 $68 = (($I) + 72|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($40 * $69);
 $71 = Math_fround($67 + $70);
 $72 = (($I) + 88|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($42 * $73);
 $75 = Math_fround($71 + $74);
 $76 = Math_fround($14 + $53);
 $77 = Math_fround($25 + $64);
 $78 = Math_fround($36 + $75);
 $79 = Math_fround($0 * $44);
 $80 = Math_fround($2 * $55);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($4 * $66);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($0 * $47);
 $85 = Math_fround($2 * $58);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($4 * $69);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($0 * $51);
 $90 = Math_fround($2 * $62);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($4 * $73);
 $93 = Math_fround($91 + $92);
 $94 = (($I) + 96|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($38 * $95);
 $97 = (($I) + 112|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($40 * $98);
 $100 = Math_fround($96 + $99);
 $101 = (($I) + 128|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($42 * $102);
 $104 = Math_fround($100 + $103);
 $105 = (($I) + 100|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($38 * $106);
 $108 = (($I) + 116|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($40 * $109);
 $111 = Math_fround($107 + $110);
 $112 = (($I) + 132|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($42 * $113);
 $115 = Math_fround($111 + $114);
 $116 = (($I) + 104|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($38 * $117);
 $119 = (($I) + 120|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($40 * $120);
 $122 = Math_fround($118 + $121);
 $123 = (($I) + 136|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = Math_fround($42 * $124);
 $126 = Math_fround($122 + $125);
 $127 = Math_fround($83 + $104);
 $128 = Math_fround($88 + $115);
 $129 = Math_fround($93 + $126);
 HEAPF32[$agg$result>>2] = $76;
 $130 = (($agg$result) + 4|0);
 HEAPF32[$130>>2] = $77;
 $131 = (($agg$result) + 8|0);
 HEAPF32[$131>>2] = $78;
 $132 = (($agg$result) + 12|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = (($agg$result) + 16|0);
 HEAPF32[$133>>2] = $127;
 $134 = (($agg$result) + 20|0);
 HEAPF32[$134>>2] = $128;
 $135 = (($agg$result) + 24|0);
 HEAPF32[$135>>2] = $129;
 $136 = (($agg$result) + 28|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx13PxcLtbProjectERKNS_9PxcFsDataEPNS_14PxcSIMDSpatialEPNS_6shdfnd3aos5Vec3VE($m,$velocity,$b) {
 $m = $m|0;
 $velocity = $velocity|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $i$01 = 0;
 var $y = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2048|0;
 $y = sp;
 __ZN5physx11PxcLtbSolveERKNS_9PxcFsDataEPNS_6shdfnd3aos5Vec3VEPNS_14PxcSIMDSpatialE($m,$b,$y);
 $0 = (($m) + 8|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $3 = (($velocity) + ($i$01<<5)|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = ((($velocity) + ($i$01<<5)|0) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = ((($velocity) + ($i$01<<5)|0) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = ((($velocity) + ($i$01<<5)|0) + 12|0);
  $10 = (($y) + ($i$01<<5)|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = ((($y) + ($i$01<<5)|0) + 4|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = ((($y) + ($i$01<<5)|0) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($4 - $11);
  $17 = Math_fround($6 - $13);
  $18 = Math_fround($8 - $15);
  HEAPF32[$3>>2] = $16;
  HEAPF32[$5>>2] = $17;
  HEAPF32[$7>>2] = $18;
  HEAPF32[$9>>2] = Math_fround(0.0);
  $19 = ((($velocity) + ($i$01<<5)|0) + 16|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = ((($velocity) + ($i$01<<5)|0) + 20|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = ((($velocity) + ($i$01<<5)|0) + 24|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = ((($velocity) + ($i$01<<5)|0) + 28|0);
  $26 = ((($y) + ($i$01<<5)|0) + 16|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = ((($y) + ($i$01<<5)|0) + 20|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = ((($y) + ($i$01<<5)|0) + 24|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($20 - $27);
  $33 = Math_fround($22 - $29);
  $34 = Math_fround($24 - $31);
  HEAPF32[$19>>2] = $32;
  HEAPF32[$21>>2] = $33;
  HEAPF32[$23>>2] = $34;
  HEAPF32[$25>>2] = Math_fround(0.0);
  $35 = (($i$01) + 1)|0;
  $36 = HEAP16[$0>>1]|0;
  $37 = $36&65535;
  $38 = ($35>>>0)<($37>>>0);
  if ($38) {
   $i$01 = $35;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx31PxcFsPropagateDrivenInertiaSimdERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKfPKNS_6shdfnd3aos6Mat33VENS_21PxcFsScratchAllocatorE($matrix,$baseInertia,$isf,$load,$allocator) {
 $matrix = $matrix|0;
 $baseInertia = $baseInertia|0;
 $isf = $isf|0;
 $load = $load|0;
 $allocator = $allocator|0;
 var $$byval_copy = 0, $$sum = 0, $$sum$i = 0, $$sum$i1 = 0, $$sum103 = 0, $$sum104 = 0, $$sum105 = 0, $$sum106 = 0, $$sum107 = 0, $$sum108 = 0, $$sum109 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0);
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0);
 var $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0;
 var $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0);
 var $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0);
 var $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0;
 var $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $D = 0, $IS = 0, $m = 0, $tmp1$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 656|0;
 $$byval_copy = sp + 640|0;
 $IS = sp;
 $m = sp + 96|0;
 $D = sp + 144|0;
 $0 = sp + 192|0;
 $1 = sp + 336|0;
 $2 = sp + 352|0;
 $3 = sp + 496|0;
 $4 = (($matrix) + 26|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $$sum$i = (($6) + 144)|0;
 $7 = (($matrix) + ($$sum$i)|0);
 $8 = (($matrix) + 24|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9&65535;
 $11 = (($matrix) + 8|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12&65535;
 $tmp1$i = ($13*432)|0;
 $$sum$i1 = (($tmp1$i) + ($10))|0;
 $14 = (($matrix) + ($$sum$i1)|0);
 $15 = (($matrix) + 10|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = (($matrix) + ($17)|0);
 $19 = HEAP32[$allocator>>2]|0;
 $20 = (($allocator) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + ($21)|0);
 $23 = ($13*144)|0;
 $24 = (($21) + ($23))|0;
 HEAP32[$20>>2] = $24;
 _memcpy(($22|0),($baseInertia|0),($23|0))|0;
 $25 = HEAP16[$11>>1]|0;
 $26 = $25&65535;
 $27 = (($26) + -1)|0;
 $28 = ($27|0)==(0);
 if ($28) {
  $279 = HEAP16[$4>>1]|0;
  $280 = $279&65535;
  $281 = (($matrix) + ($280)|0);
  __ZN5physx26PxcArticulationFnsSimdBase13invertInertiaERKNS_12PxcFsInertiaE($3,$22);
  ;HEAP32[$281+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$281+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$281+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$281+12>>2]=HEAP32[$3+12>>2]|0;
  $$sum = (($280) + 16)|0;
  $282 = (($matrix) + ($$sum)|0);
  $283 = (($3) + 16|0);
  ;HEAP32[$282+0>>2]=HEAP32[$283+0>>2]|0;HEAP32[$282+4>>2]=HEAP32[$283+4>>2]|0;HEAP32[$282+8>>2]=HEAP32[$283+8>>2]|0;HEAP32[$282+12>>2]=HEAP32[$283+12>>2]|0;
  $$sum103 = (($280) + 32)|0;
  $284 = (($matrix) + ($$sum103)|0);
  $285 = (($3) + 32|0);
  ;HEAP32[$284+0>>2]=HEAP32[$285+0>>2]|0;HEAP32[$284+4>>2]=HEAP32[$285+4>>2]|0;HEAP32[$284+8>>2]=HEAP32[$285+8>>2]|0;HEAP32[$284+12>>2]=HEAP32[$285+12>>2]|0;
  $$sum104 = (($280) + 48)|0;
  $286 = (($matrix) + ($$sum104)|0);
  $287 = (($3) + 48|0);
  ;HEAP32[$286+0>>2]=HEAP32[$287+0>>2]|0;HEAP32[$286+4>>2]=HEAP32[$287+4>>2]|0;HEAP32[$286+8>>2]=HEAP32[$287+8>>2]|0;HEAP32[$286+12>>2]=HEAP32[$287+12>>2]|0;
  $$sum105 = (($280) + 64)|0;
  $288 = (($matrix) + ($$sum105)|0);
  $289 = (($3) + 64|0);
  ;HEAP32[$288+0>>2]=HEAP32[$289+0>>2]|0;HEAP32[$288+4>>2]=HEAP32[$289+4>>2]|0;HEAP32[$288+8>>2]=HEAP32[$289+8>>2]|0;HEAP32[$288+12>>2]=HEAP32[$289+12>>2]|0;
  $$sum106 = (($280) + 80)|0;
  $290 = (($matrix) + ($$sum106)|0);
  $291 = (($3) + 80|0);
  ;HEAP32[$290+0>>2]=HEAP32[$291+0>>2]|0;HEAP32[$290+4>>2]=HEAP32[$291+4>>2]|0;HEAP32[$290+8>>2]=HEAP32[$291+8>>2]|0;HEAP32[$290+12>>2]=HEAP32[$291+12>>2]|0;
  $$sum107 = (($280) + 96)|0;
  $292 = (($matrix) + ($$sum107)|0);
  $293 = (($3) + 96|0);
  ;HEAP32[$292+0>>2]=HEAP32[$293+0>>2]|0;HEAP32[$292+4>>2]=HEAP32[$293+4>>2]|0;HEAP32[$292+8>>2]=HEAP32[$293+8>>2]|0;HEAP32[$292+12>>2]=HEAP32[$293+12>>2]|0;
  $$sum108 = (($280) + 112)|0;
  $294 = (($matrix) + ($$sum108)|0);
  $295 = (($3) + 112|0);
  ;HEAP32[$294+0>>2]=HEAP32[$295+0>>2]|0;HEAP32[$294+4>>2]=HEAP32[$295+4>>2]|0;HEAP32[$294+8>>2]=HEAP32[$295+8>>2]|0;HEAP32[$294+12>>2]=HEAP32[$295+12>>2]|0;
  $$sum109 = (($280) + 128)|0;
  $296 = (($matrix) + ($$sum109)|0);
  $297 = (($3) + 128|0);
  ;HEAP32[$296+0>>2]=HEAP32[$297+0>>2]|0;HEAP32[$296+4>>2]=HEAP32[$297+4>>2]|0;HEAP32[$296+8>>2]=HEAP32[$297+8>>2]|0;HEAP32[$296+12>>2]=HEAP32[$297+12>>2]|0;
  STACKTOP = sp;return;
 }
 $29 = (($m) + 4|0);
 $30 = (($m) + 8|0);
 $31 = (($m) + 16|0);
 $32 = (($m) + 20|0);
 $33 = (($m) + 24|0);
 $34 = (($m) + 32|0);
 $35 = (($m) + 36|0);
 $36 = (($m) + 40|0);
 $37 = (($D) + 4|0);
 $38 = (($D) + 8|0);
 $39 = (($D) + 12|0);
 $40 = (($D) + 16|0);
 $41 = (($D) + 20|0);
 $42 = (($D) + 24|0);
 $43 = (($D) + 28|0);
 $44 = (($D) + 32|0);
 $45 = (($D) + 36|0);
 $46 = (($D) + 40|0);
 $47 = (($D) + 44|0);
 $48 = (($0) + 4|0);
 $49 = (($0) + 8|0);
 $50 = (($0) + 16|0);
 $51 = (($0) + 20|0);
 $52 = (($0) + 24|0);
 $53 = (($0) + 32|0);
 $54 = (($0) + 36|0);
 $55 = (($0) + 40|0);
 $56 = (($0) + 48|0);
 $57 = (($0) + 52|0);
 $58 = (($0) + 56|0);
 $59 = (($0) + 64|0);
 $60 = (($0) + 68|0);
 $61 = (($0) + 72|0);
 $62 = (($0) + 80|0);
 $63 = (($0) + 84|0);
 $64 = (($0) + 88|0);
 $65 = (($0) + 96|0);
 $66 = (($0) + 100|0);
 $67 = (($0) + 104|0);
 $68 = (($0) + 112|0);
 $69 = (($0) + 116|0);
 $70 = (($0) + 120|0);
 $71 = (($0) + 128|0);
 $72 = (($0) + 132|0);
 $73 = (($0) + 136|0);
 $75 = $27;
 while(1) {
  $74 = (($22) + (($75*144)|0)|0);
  $76 = (($14) + (($75*96)|0)|0);
  __ZN5physx26PxcArticulationFnsSimdBase10computeSISERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialEPS4_($m,$74,$76,$IS);
  $77 = (($isf) + ($75<<2)|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($load) + (($75*48)|0)|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = ((($load) + (($75*48)|0)|0) + 4|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = ((($load) + (($75*48)|0)|0) + 8|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = Math_fround(HEAPF32[$m>>2]);
  $86 = Math_fround(HEAPF32[$29>>2]);
  $87 = Math_fround(HEAPF32[$30>>2]);
  $88 = Math_fround($78 * $80);
  $89 = Math_fround($78 * $82);
  $90 = Math_fround($78 * $84);
  $91 = Math_fround($88 + $85);
  $92 = Math_fround($89 + $86);
  $93 = Math_fround($90 + $87);
  $94 = ((($load) + (($75*48)|0)|0) + 16|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = ((($load) + (($75*48)|0)|0) + 20|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = ((($load) + (($75*48)|0)|0) + 24|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = Math_fround(HEAPF32[$31>>2]);
  $101 = Math_fround(HEAPF32[$32>>2]);
  $102 = Math_fround(HEAPF32[$33>>2]);
  $103 = Math_fround($78 * $95);
  $104 = Math_fround($78 * $97);
  $105 = Math_fround($78 * $99);
  $106 = Math_fround($103 + $100);
  $107 = Math_fround($104 + $101);
  $108 = Math_fround($105 + $102);
  $109 = ((($load) + (($75*48)|0)|0) + 32|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = ((($load) + (($75*48)|0)|0) + 36|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = ((($load) + (($75*48)|0)|0) + 40|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = Math_fround(HEAPF32[$34>>2]);
  $116 = Math_fround(HEAPF32[$35>>2]);
  $117 = Math_fround(HEAPF32[$36>>2]);
  $118 = Math_fround($78 * $110);
  $119 = Math_fround($78 * $112);
  $120 = Math_fround($78 * $114);
  $121 = Math_fround($118 + $115);
  $122 = Math_fround($119 + $116);
  $123 = Math_fround($120 + $117);
  $124 = Math_fround($107 * $123);
  $125 = Math_fround($108 * $122);
  $126 = Math_fround($124 - $125);
  $127 = Math_fround($108 * $121);
  $128 = Math_fround($106 * $123);
  $129 = Math_fround($127 - $128);
  $130 = Math_fround($106 * $122);
  $131 = Math_fround($107 * $121);
  $132 = Math_fround($130 - $131);
  $133 = Math_fround($91 * $123);
  $134 = Math_fround($93 * $121);
  $135 = Math_fround($133 - $134);
  $136 = Math_fround($92 * $121);
  $137 = Math_fround($91 * $122);
  $138 = Math_fround($136 - $137);
  $139 = Math_fround($91 * $107);
  $140 = Math_fround($92 * $106);
  $141 = Math_fround($139 - $140);
  $142 = Math_fround($91 * $126);
  $143 = Math_fround($92 * $129);
  $144 = Math_fround($142 + $143);
  $145 = Math_fround($93 * $132);
  $146 = Math_fround($145 + $144);
  $147 = Math_fround(Math_fround(1.0) / $146);
  $148 = Math_fround($147 * $126);
  $149 = Math_fround($147 * $129);
  $150 = Math_fround($147 * $132);
  $151 = Math_fround($147 * $135);
  $152 = Math_fround($147 * $138);
  $153 = Math_fround($141 * $147);
  HEAPF32[$D>>2] = $148;
  HEAPF32[$37>>2] = $149;
  HEAPF32[$38>>2] = $150;
  HEAPF32[$39>>2] = Math_fround(0.0);
  HEAPF32[$40>>2] = $149;
  HEAPF32[$41>>2] = $151;
  HEAPF32[$42>>2] = $152;
  HEAPF32[$43>>2] = Math_fround(0.0);
  HEAPF32[$44>>2] = $150;
  HEAPF32[$45>>2] = $152;
  HEAPF32[$46>>2] = $153;
  HEAPF32[$47>>2] = Math_fround(0.0);
  $154 = ((($7) + (($75*160)|0)|0) + 96|0);
  dest=$154+0|0; src=$D+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $155 = ((($matrix) + ($75)|0) + 64|0);
  $156 = HEAP8[$155>>0]|0;
  $157 = $156&255;
  $158 = (($18) + ($75<<5)|0);
  ;HEAP32[$1+0>>2]=HEAP32[$158+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$158+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$158+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$158+12>>2]|0;
  $159 = (($7) + (($75*160)|0)|0);
  __ZN5physx26PxcArticulationFnsSimdBase16multiplySubtractERKNS_12PxcFsInertiaERKNS_6shdfnd3aos6Mat33VEPKNS_14PxcSIMDSpatialEPS9_($2,$74,$D,$IS,$159);
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
  __ZN5physx26PxcArticulationFnsSimdBase16translateInertiaENS_6shdfnd3aos5Vec3VERKNS_12PxcFsInertiaE($0,$$byval_copy,$2);
  $160 = (($22) + (($157*144)|0)|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = ((($22) + (($157*144)|0)|0) + 4|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = ((($22) + (($157*144)|0)|0) + 8|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  $166 = Math_fround(HEAPF32[$0>>2]);
  $167 = Math_fround(HEAPF32[$48>>2]);
  $168 = Math_fround(HEAPF32[$49>>2]);
  $169 = Math_fround($161 + $166);
  $170 = Math_fround($163 + $167);
  $171 = Math_fround($165 + $168);
  $172 = ((($22) + (($157*144)|0)|0) + 16|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = ((($22) + (($157*144)|0)|0) + 20|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = ((($22) + (($157*144)|0)|0) + 24|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround(HEAPF32[$50>>2]);
  $179 = Math_fround(HEAPF32[$51>>2]);
  $180 = Math_fround(HEAPF32[$52>>2]);
  $181 = Math_fround($173 + $178);
  $182 = Math_fround($175 + $179);
  $183 = Math_fround($177 + $180);
  $184 = ((($22) + (($157*144)|0)|0) + 32|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = ((($22) + (($157*144)|0)|0) + 36|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = ((($22) + (($157*144)|0)|0) + 40|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = Math_fround(HEAPF32[$53>>2]);
  $191 = Math_fround(HEAPF32[$54>>2]);
  $192 = Math_fround(HEAPF32[$55>>2]);
  $193 = Math_fround($185 + $190);
  $194 = Math_fround($187 + $191);
  $195 = Math_fround($189 + $192);
  $196 = ((($22) + (($157*144)|0)|0) + 48|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = ((($22) + (($157*144)|0)|0) + 52|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = ((($22) + (($157*144)|0)|0) + 56|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = Math_fround(HEAPF32[$56>>2]);
  $203 = Math_fround(HEAPF32[$57>>2]);
  $204 = Math_fround(HEAPF32[$58>>2]);
  $205 = Math_fround($197 + $202);
  $206 = Math_fround($199 + $203);
  $207 = Math_fround($201 + $204);
  $208 = ((($22) + (($157*144)|0)|0) + 64|0);
  $209 = Math_fround(HEAPF32[$208>>2]);
  $210 = ((($22) + (($157*144)|0)|0) + 68|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = ((($22) + (($157*144)|0)|0) + 72|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = Math_fround(HEAPF32[$59>>2]);
  $215 = Math_fround(HEAPF32[$60>>2]);
  $216 = Math_fround(HEAPF32[$61>>2]);
  $217 = Math_fround($209 + $214);
  $218 = Math_fround($211 + $215);
  $219 = Math_fround($213 + $216);
  $220 = ((($22) + (($157*144)|0)|0) + 80|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = ((($22) + (($157*144)|0)|0) + 84|0);
  $223 = Math_fround(HEAPF32[$222>>2]);
  $224 = ((($22) + (($157*144)|0)|0) + 88|0);
  $225 = Math_fround(HEAPF32[$224>>2]);
  $226 = Math_fround(HEAPF32[$62>>2]);
  $227 = Math_fround(HEAPF32[$63>>2]);
  $228 = Math_fround(HEAPF32[$64>>2]);
  $229 = Math_fround($221 + $226);
  $230 = Math_fround($223 + $227);
  $231 = Math_fround($225 + $228);
  $232 = ((($22) + (($157*144)|0)|0) + 96|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = ((($22) + (($157*144)|0)|0) + 100|0);
  $235 = Math_fround(HEAPF32[$234>>2]);
  $236 = ((($22) + (($157*144)|0)|0) + 104|0);
  $237 = Math_fround(HEAPF32[$236>>2]);
  $238 = Math_fround(HEAPF32[$65>>2]);
  $239 = Math_fround(HEAPF32[$66>>2]);
  $240 = Math_fround(HEAPF32[$67>>2]);
  $241 = Math_fround($233 + $238);
  $242 = Math_fround($235 + $239);
  $243 = Math_fround($237 + $240);
  $244 = ((($22) + (($157*144)|0)|0) + 112|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = ((($22) + (($157*144)|0)|0) + 116|0);
  $247 = Math_fround(HEAPF32[$246>>2]);
  $248 = ((($22) + (($157*144)|0)|0) + 120|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = Math_fround(HEAPF32[$68>>2]);
  $251 = Math_fround(HEAPF32[$69>>2]);
  $252 = Math_fround(HEAPF32[$70>>2]);
  $253 = Math_fround($245 + $250);
  $254 = Math_fround($247 + $251);
  $255 = Math_fround($249 + $252);
  $256 = ((($22) + (($157*144)|0)|0) + 128|0);
  $257 = Math_fround(HEAPF32[$256>>2]);
  $258 = ((($22) + (($157*144)|0)|0) + 132|0);
  $259 = Math_fround(HEAPF32[$258>>2]);
  $260 = ((($22) + (($157*144)|0)|0) + 136|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = Math_fround(HEAPF32[$71>>2]);
  $263 = Math_fround(HEAPF32[$72>>2]);
  $264 = Math_fround(HEAPF32[$73>>2]);
  $265 = Math_fround($257 + $262);
  $266 = Math_fround($259 + $263);
  $267 = Math_fround($261 + $264);
  HEAPF32[$160>>2] = $169;
  HEAPF32[$162>>2] = $170;
  HEAPF32[$164>>2] = $171;
  $268 = ((($22) + (($157*144)|0)|0) + 12|0);
  HEAPF32[$268>>2] = Math_fround(0.0);
  HEAPF32[$172>>2] = $181;
  HEAPF32[$174>>2] = $182;
  HEAPF32[$176>>2] = $183;
  $269 = ((($22) + (($157*144)|0)|0) + 28|0);
  HEAPF32[$269>>2] = Math_fround(0.0);
  HEAPF32[$184>>2] = $193;
  HEAPF32[$186>>2] = $194;
  HEAPF32[$188>>2] = $195;
  $270 = ((($22) + (($157*144)|0)|0) + 44|0);
  HEAPF32[$270>>2] = Math_fround(0.0);
  HEAPF32[$196>>2] = $205;
  HEAPF32[$198>>2] = $206;
  HEAPF32[$200>>2] = $207;
  $271 = ((($22) + (($157*144)|0)|0) + 60|0);
  HEAPF32[$271>>2] = Math_fround(0.0);
  HEAPF32[$208>>2] = $217;
  HEAPF32[$210>>2] = $218;
  HEAPF32[$212>>2] = $219;
  $272 = ((($22) + (($157*144)|0)|0) + 76|0);
  HEAPF32[$272>>2] = Math_fround(0.0);
  HEAPF32[$220>>2] = $229;
  HEAPF32[$222>>2] = $230;
  HEAPF32[$224>>2] = $231;
  $273 = ((($22) + (($157*144)|0)|0) + 92|0);
  HEAPF32[$273>>2] = Math_fround(0.0);
  HEAPF32[$232>>2] = $241;
  HEAPF32[$234>>2] = $242;
  HEAPF32[$236>>2] = $243;
  $274 = ((($22) + (($157*144)|0)|0) + 108|0);
  HEAPF32[$274>>2] = Math_fround(0.0);
  HEAPF32[$244>>2] = $253;
  HEAPF32[$246>>2] = $254;
  HEAPF32[$248>>2] = $255;
  $275 = ((($22) + (($157*144)|0)|0) + 124|0);
  HEAPF32[$275>>2] = Math_fround(0.0);
  HEAPF32[$256>>2] = $265;
  HEAPF32[$258>>2] = $266;
  HEAPF32[$260>>2] = $267;
  $276 = ((($22) + (($157*144)|0)|0) + 140|0);
  HEAPF32[$276>>2] = Math_fround(0.0);
  $277 = (($75) + -1)|0;
  $278 = ($277|0)==(0);
  if ($278) {
   break;
  } else {
   $75 = $277;
  }
 }
 $279 = HEAP16[$4>>1]|0;
 $280 = $279&65535;
 $281 = (($matrix) + ($280)|0);
 __ZN5physx26PxcArticulationFnsSimdBase13invertInertiaERKNS_12PxcFsInertiaE($3,$22);
 ;HEAP32[$281+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$281+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$281+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$281+12>>2]=HEAP32[$3+12>>2]|0;
 $$sum = (($280) + 16)|0;
 $282 = (($matrix) + ($$sum)|0);
 $283 = (($3) + 16|0);
 ;HEAP32[$282+0>>2]=HEAP32[$283+0>>2]|0;HEAP32[$282+4>>2]=HEAP32[$283+4>>2]|0;HEAP32[$282+8>>2]=HEAP32[$283+8>>2]|0;HEAP32[$282+12>>2]=HEAP32[$283+12>>2]|0;
 $$sum103 = (($280) + 32)|0;
 $284 = (($matrix) + ($$sum103)|0);
 $285 = (($3) + 32|0);
 ;HEAP32[$284+0>>2]=HEAP32[$285+0>>2]|0;HEAP32[$284+4>>2]=HEAP32[$285+4>>2]|0;HEAP32[$284+8>>2]=HEAP32[$285+8>>2]|0;HEAP32[$284+12>>2]=HEAP32[$285+12>>2]|0;
 $$sum104 = (($280) + 48)|0;
 $286 = (($matrix) + ($$sum104)|0);
 $287 = (($3) + 48|0);
 ;HEAP32[$286+0>>2]=HEAP32[$287+0>>2]|0;HEAP32[$286+4>>2]=HEAP32[$287+4>>2]|0;HEAP32[$286+8>>2]=HEAP32[$287+8>>2]|0;HEAP32[$286+12>>2]=HEAP32[$287+12>>2]|0;
 $$sum105 = (($280) + 64)|0;
 $288 = (($matrix) + ($$sum105)|0);
 $289 = (($3) + 64|0);
 ;HEAP32[$288+0>>2]=HEAP32[$289+0>>2]|0;HEAP32[$288+4>>2]=HEAP32[$289+4>>2]|0;HEAP32[$288+8>>2]=HEAP32[$289+8>>2]|0;HEAP32[$288+12>>2]=HEAP32[$289+12>>2]|0;
 $$sum106 = (($280) + 80)|0;
 $290 = (($matrix) + ($$sum106)|0);
 $291 = (($3) + 80|0);
 ;HEAP32[$290+0>>2]=HEAP32[$291+0>>2]|0;HEAP32[$290+4>>2]=HEAP32[$291+4>>2]|0;HEAP32[$290+8>>2]=HEAP32[$291+8>>2]|0;HEAP32[$290+12>>2]=HEAP32[$291+12>>2]|0;
 $$sum107 = (($280) + 96)|0;
 $292 = (($matrix) + ($$sum107)|0);
 $293 = (($3) + 96|0);
 ;HEAP32[$292+0>>2]=HEAP32[$293+0>>2]|0;HEAP32[$292+4>>2]=HEAP32[$293+4>>2]|0;HEAP32[$292+8>>2]=HEAP32[$293+8>>2]|0;HEAP32[$292+12>>2]=HEAP32[$293+12>>2]|0;
 $$sum108 = (($280) + 112)|0;
 $294 = (($matrix) + ($$sum108)|0);
 $295 = (($3) + 112|0);
 ;HEAP32[$294+0>>2]=HEAP32[$295+0>>2]|0;HEAP32[$294+4>>2]=HEAP32[$295+4>>2]|0;HEAP32[$294+8>>2]=HEAP32[$295+8>>2]|0;HEAP32[$294+12>>2]=HEAP32[$295+12>>2]|0;
 $$sum109 = (($280) + 128)|0;
 $296 = (($matrix) + ($$sum109)|0);
 $297 = (($3) + 128|0);
 ;HEAP32[$296+0>>2]=HEAP32[$297+0>>2]|0;HEAP32[$296+4>>2]=HEAP32[$297+4>>2]|0;HEAP32[$296+8>>2]=HEAP32[$297+8>>2]|0;HEAP32[$296+12>>2]=HEAP32[$297+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx26PxcArticulationFnsSimdBase10addInertiaERKNS_12PxcFsInertiaES3_($agg$result,$in1,$in2) {
 $agg$result = $agg$result|0;
 $in1 = $in1|0;
 $in2 = $in2|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0;
 var $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0);
 var $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0;
 var $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0);
 var $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$in1>>2]);
 $1 = (($in1) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($in1) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$in2>>2]);
 $6 = (($in2) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($in2) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($0 + $5);
 $11 = Math_fround($2 + $7);
 $12 = Math_fround($4 + $9);
 $13 = (($in1) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($in1) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($in1) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($in2) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($in2) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($in2) + 24|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($14 + $20);
 $26 = Math_fround($16 + $22);
 $27 = Math_fround($18 + $24);
 $28 = (($in1) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($in1) + 36|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($in1) + 40|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($in2) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($in2) + 36|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($in2) + 40|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($29 + $35);
 $41 = Math_fround($31 + $37);
 $42 = Math_fround($33 + $39);
 $43 = (($in1) + 48|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($in1) + 52|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($in1) + 56|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($in2) + 48|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($in2) + 52|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($in2) + 56|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($44 + $50);
 $56 = Math_fround($46 + $52);
 $57 = Math_fround($48 + $54);
 $58 = (($in1) + 64|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($in1) + 68|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($in1) + 72|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($in2) + 64|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($in2) + 68|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($in2) + 72|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($59 + $65);
 $71 = Math_fround($61 + $67);
 $72 = Math_fround($63 + $69);
 $73 = (($in1) + 80|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($in1) + 84|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($in1) + 88|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($in2) + 80|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($in2) + 84|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($in2) + 88|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($74 + $80);
 $86 = Math_fround($76 + $82);
 $87 = Math_fround($78 + $84);
 $88 = (($in1) + 96|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($in1) + 100|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($in1) + 104|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($in2) + 96|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($in2) + 100|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($in2) + 104|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($89 + $95);
 $101 = Math_fround($91 + $97);
 $102 = Math_fround($93 + $99);
 $103 = (($in1) + 112|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($in1) + 116|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($in1) + 120|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($in2) + 112|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($in2) + 116|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($in2) + 120|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($104 + $110);
 $116 = Math_fround($106 + $112);
 $117 = Math_fround($108 + $114);
 $118 = (($in1) + 128|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($in1) + 132|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($in1) + 136|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($in2) + 128|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($in2) + 132|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($in2) + 136|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($119 + $125);
 $131 = Math_fround($121 + $127);
 $132 = Math_fround($123 + $129);
 HEAPF32[$agg$result>>2] = $10;
 $133 = (($agg$result) + 4|0);
 HEAPF32[$133>>2] = $11;
 $134 = (($agg$result) + 8|0);
 HEAPF32[$134>>2] = $12;
 $135 = (($agg$result) + 12|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = (($agg$result) + 16|0);
 HEAPF32[$136>>2] = $25;
 $137 = (($agg$result) + 20|0);
 HEAPF32[$137>>2] = $26;
 $138 = (($agg$result) + 24|0);
 HEAPF32[$138>>2] = $27;
 $139 = (($agg$result) + 28|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($agg$result) + 32|0);
 HEAPF32[$140>>2] = $40;
 $141 = (($agg$result) + 36|0);
 HEAPF32[$141>>2] = $41;
 $142 = (($agg$result) + 40|0);
 HEAPF32[$142>>2] = $42;
 $143 = (($agg$result) + 44|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = (($agg$result) + 48|0);
 HEAPF32[$144>>2] = $55;
 $145 = (($agg$result) + 52|0);
 HEAPF32[$145>>2] = $56;
 $146 = (($agg$result) + 56|0);
 HEAPF32[$146>>2] = $57;
 $147 = (($agg$result) + 60|0);
 HEAPF32[$147>>2] = Math_fround(0.0);
 $148 = (($agg$result) + 64|0);
 HEAPF32[$148>>2] = $70;
 $149 = (($agg$result) + 68|0);
 HEAPF32[$149>>2] = $71;
 $150 = (($agg$result) + 72|0);
 HEAPF32[$150>>2] = $72;
 $151 = (($agg$result) + 76|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = (($agg$result) + 80|0);
 HEAPF32[$152>>2] = $85;
 $153 = (($agg$result) + 84|0);
 HEAPF32[$153>>2] = $86;
 $154 = (($agg$result) + 88|0);
 HEAPF32[$154>>2] = $87;
 $155 = (($agg$result) + 92|0);
 HEAPF32[$155>>2] = Math_fround(0.0);
 $156 = (($agg$result) + 96|0);
 HEAPF32[$156>>2] = $100;
 $157 = (($agg$result) + 100|0);
 HEAPF32[$157>>2] = $101;
 $158 = (($agg$result) + 104|0);
 HEAPF32[$158>>2] = $102;
 $159 = (($agg$result) + 108|0);
 HEAPF32[$159>>2] = Math_fround(0.0);
 $160 = (($agg$result) + 112|0);
 HEAPF32[$160>>2] = $115;
 $161 = (($agg$result) + 116|0);
 HEAPF32[$161>>2] = $116;
 $162 = (($agg$result) + 120|0);
 HEAPF32[$162>>2] = $117;
 $163 = (($agg$result) + 124|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = (($agg$result) + 128|0);
 HEAPF32[$164>>2] = $130;
 $165 = (($agg$result) + 132|0);
 HEAPF32[$165>>2] = $131;
 $166 = (($agg$result) + 136|0);
 HEAPF32[$166>>2] = $132;
 $167 = (($agg$result) + 140|0);
 HEAPF32[$167>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx26PxcArticulationFnsSimdBase16translateInertiaENS_6shdfnd3aos5Vec3VERKNS_12PxcFsInertiaE($agg$result,$a,$input) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $input = $input|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0);
 var $260 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = (($a) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($a) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$0);
 $6 = Math_fround(-$2);
 $7 = Math_fround(-$4);
 $8 = (($input) + 48|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($input) + 52|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($input) + 56|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($input) + 64|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($input) + 68|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($input) + 72|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($input) + 80|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($input) + 84|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($input) + 88|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround(HEAPF32[$input>>2]);
 $27 = (($input) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($input) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($input) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($input) + 16|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($input) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($input) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($input) + 28|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($input) + 32|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($input) + 36|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($input) + 40|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($input) + 44|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($input) + 96|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($input) + 100|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($input) + 104|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($input) + 112|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($input) + 116|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($input) + 120|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($input) + 128|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($input) + 132|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($input) + 136|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($13 * $2);
 $68 = Math_fround($13 * $5);
 $69 = Math_fround($13 * Math_fround(0.0));
 $70 = Math_fround($11 * $7);
 $71 = Math_fround($11 * Math_fround(0.0));
 $72 = Math_fround($0 * $11);
 $73 = Math_fround($70 + $67);
 $74 = Math_fround($71 + $68);
 $75 = Math_fround($72 + $69);
 $76 = Math_fround($9 * Math_fround(0.0));
 $77 = Math_fround($9 * $4);
 $78 = Math_fround($9 * $6);
 $79 = Math_fround($76 + $73);
 $80 = Math_fround($74 + $77);
 $81 = Math_fround($78 + $75);
 $82 = Math_fround($19 * $2);
 $83 = Math_fround($19 * $5);
 $84 = Math_fround($19 * Math_fround(0.0));
 $85 = Math_fround($17 * $7);
 $86 = Math_fround($17 * Math_fround(0.0));
 $87 = Math_fround($0 * $17);
 $88 = Math_fround($85 + $82);
 $89 = Math_fround($86 + $83);
 $90 = Math_fround($87 + $84);
 $91 = Math_fround($15 * Math_fround(0.0));
 $92 = Math_fround($15 * $4);
 $93 = Math_fround($15 * $6);
 $94 = Math_fround($91 + $88);
 $95 = Math_fround($89 + $92);
 $96 = Math_fround($93 + $90);
 $97 = Math_fround($25 * $2);
 $98 = Math_fround($25 * $5);
 $99 = Math_fround($25 * Math_fround(0.0));
 $100 = Math_fround($23 * $7);
 $101 = Math_fround($23 * Math_fround(0.0));
 $102 = Math_fround($0 * $23);
 $103 = Math_fround($100 + $97);
 $104 = Math_fround($101 + $98);
 $105 = Math_fround($102 + $99);
 $106 = Math_fround($21 * Math_fround(0.0));
 $107 = Math_fround($21 * $4);
 $108 = Math_fround($21 * $6);
 $109 = Math_fround($106 + $103);
 $110 = Math_fround($104 + $107);
 $111 = Math_fround($108 + $105);
 $112 = Math_fround($34 * $7);
 $113 = Math_fround($36 * $7);
 $114 = Math_fround($38 * $7);
 $115 = Math_fround($42 * $2);
 $116 = Math_fround($44 * $2);
 $117 = Math_fround($46 * $2);
 $118 = Math_fround($112 + $115);
 $119 = Math_fround($113 + $116);
 $120 = Math_fround($114 + $117);
 $121 = Math_fround($42 * $5);
 $122 = Math_fround($44 * $5);
 $123 = Math_fround($46 * $5);
 $124 = Math_fround($26 * $4);
 $125 = Math_fround($28 * $4);
 $126 = Math_fround($30 * $4);
 $127 = Math_fround($121 + $124);
 $128 = Math_fround($122 + $125);
 $129 = Math_fround($123 + $126);
 $130 = Math_fround($26 * $6);
 $131 = Math_fround($28 * $6);
 $132 = Math_fround($30 * $6);
 $133 = Math_fround($0 * $34);
 $134 = Math_fround($0 * $36);
 $135 = Math_fround($0 * $38);
 $136 = Math_fround($130 + $133);
 $137 = Math_fround($131 + $134);
 $138 = Math_fround($132 + $135);
 $139 = Math_fround($118 * Math_fround(0.0));
 $140 = Math_fround($4 * $118);
 $141 = Math_fround($118 * $6);
 $142 = Math_fround($119 * $7);
 $143 = Math_fround($119 * Math_fround(0.0));
 $144 = Math_fround($0 * $119);
 $145 = Math_fround($142 + $139);
 $146 = Math_fround($143 + $140);
 $147 = Math_fround($144 + $141);
 $148 = Math_fround($2 * $120);
 $149 = Math_fround($120 * $5);
 $150 = Math_fround($120 * Math_fround(0.0));
 $151 = Math_fround($148 + $145);
 $152 = Math_fround($149 + $146);
 $153 = Math_fround($150 + $147);
 $154 = Math_fround($127 * Math_fround(0.0));
 $155 = Math_fround($4 * $127);
 $156 = Math_fround($127 * $6);
 $157 = Math_fround($128 * $7);
 $158 = Math_fround($128 * Math_fround(0.0));
 $159 = Math_fround($0 * $128);
 $160 = Math_fround($157 + $154);
 $161 = Math_fround($158 + $155);
 $162 = Math_fround($159 + $156);
 $163 = Math_fround($2 * $129);
 $164 = Math_fround($129 * $5);
 $165 = Math_fround($129 * Math_fround(0.0));
 $166 = Math_fround($163 + $160);
 $167 = Math_fround($164 + $161);
 $168 = Math_fround($165 + $162);
 $169 = Math_fround($136 * Math_fround(0.0));
 $170 = Math_fround($136 * $4);
 $171 = Math_fround($136 * $6);
 $172 = Math_fround($137 * $7);
 $173 = Math_fround($137 * Math_fround(0.0));
 $174 = Math_fround($0 * $137);
 $175 = Math_fround($169 + $172);
 $176 = Math_fround($173 + $170);
 $177 = Math_fround($171 + $174);
 $178 = Math_fround($138 * $2);
 $179 = Math_fround($138 * $5);
 $180 = Math_fround($138 * Math_fround(0.0));
 $181 = Math_fround($175 + $178);
 $182 = Math_fround($179 + $176);
 $183 = Math_fround($180 + $177);
 $184 = Math_fround($151 * Math_fround(0.5));
 $185 = Math_fround($152 * Math_fround(0.5));
 $186 = Math_fround($153 * Math_fround(0.5));
 $187 = Math_fround($79 + $184);
 $188 = Math_fround($80 + $185);
 $189 = Math_fround($81 + $186);
 $190 = Math_fround($166 * Math_fround(0.5));
 $191 = Math_fround($167 * Math_fround(0.5));
 $192 = Math_fround($168 * Math_fround(0.5));
 $193 = Math_fround($94 + $190);
 $194 = Math_fround($95 + $191);
 $195 = Math_fround($96 + $192);
 $196 = Math_fround($181 * Math_fround(0.5));
 $197 = Math_fround($182 * Math_fround(0.5));
 $198 = Math_fround($183 * Math_fround(0.5));
 $199 = Math_fround($196 + $109);
 $200 = Math_fround($110 + $197);
 $201 = Math_fround($111 + $198);
 $202 = Math_fround($187 + $187);
 $203 = Math_fround($188 + $193);
 $204 = Math_fround($199 + $189);
 $205 = Math_fround($194 + $194);
 $206 = Math_fround($200 + $195);
 $207 = Math_fround($201 + $201);
 $208 = Math_fround($9 + $118);
 $209 = Math_fround($11 + $119);
 $210 = Math_fround($13 + $120);
 $211 = Math_fround($15 + $127);
 $212 = Math_fround($17 + $128);
 $213 = Math_fround($19 + $129);
 $214 = Math_fround($21 + $136);
 $215 = Math_fround($23 + $137);
 $216 = Math_fround($25 + $138);
 $217 = Math_fround($50 + $202);
 $218 = Math_fround($52 + $203);
 $219 = Math_fround($54 + $204);
 $220 = Math_fround($56 + $203);
 $221 = Math_fround($58 + $205);
 $222 = Math_fround($60 + $206);
 $223 = Math_fround($62 + $204);
 $224 = Math_fround($64 + $206);
 $225 = Math_fround($207 + $66);
 HEAPF32[$agg$result>>2] = $26;
 $226 = (($agg$result) + 4|0);
 HEAPF32[$226>>2] = $28;
 $227 = (($agg$result) + 8|0);
 HEAPF32[$227>>2] = $30;
 $228 = (($agg$result) + 12|0);
 HEAPF32[$228>>2] = $32;
 $229 = (($agg$result) + 16|0);
 HEAPF32[$229>>2] = $34;
 $230 = (($agg$result) + 20|0);
 HEAPF32[$230>>2] = $36;
 $231 = (($agg$result) + 24|0);
 HEAPF32[$231>>2] = $38;
 $232 = (($agg$result) + 28|0);
 HEAPF32[$232>>2] = $40;
 $233 = (($agg$result) + 32|0);
 HEAPF32[$233>>2] = $42;
 $234 = (($agg$result) + 36|0);
 HEAPF32[$234>>2] = $44;
 $235 = (($agg$result) + 40|0);
 HEAPF32[$235>>2] = $46;
 $236 = (($agg$result) + 44|0);
 HEAPF32[$236>>2] = $48;
 $237 = (($agg$result) + 48|0);
 HEAPF32[$237>>2] = $208;
 $238 = (($agg$result) + 52|0);
 HEAPF32[$238>>2] = $209;
 $239 = (($agg$result) + 56|0);
 HEAPF32[$239>>2] = $210;
 $240 = (($agg$result) + 60|0);
 HEAPF32[$240>>2] = Math_fround(0.0);
 $241 = (($agg$result) + 64|0);
 HEAPF32[$241>>2] = $211;
 $242 = (($agg$result) + 68|0);
 HEAPF32[$242>>2] = $212;
 $243 = (($agg$result) + 72|0);
 HEAPF32[$243>>2] = $213;
 $244 = (($agg$result) + 76|0);
 HEAPF32[$244>>2] = Math_fround(0.0);
 $245 = (($agg$result) + 80|0);
 HEAPF32[$245>>2] = $214;
 $246 = (($agg$result) + 84|0);
 HEAPF32[$246>>2] = $215;
 $247 = (($agg$result) + 88|0);
 HEAPF32[$247>>2] = $216;
 $248 = (($agg$result) + 92|0);
 HEAPF32[$248>>2] = Math_fround(0.0);
 $249 = (($agg$result) + 96|0);
 HEAPF32[$249>>2] = $217;
 $250 = (($agg$result) + 100|0);
 HEAPF32[$250>>2] = $218;
 $251 = (($agg$result) + 104|0);
 HEAPF32[$251>>2] = $219;
 $252 = (($agg$result) + 108|0);
 HEAPF32[$252>>2] = Math_fround(0.0);
 $253 = (($agg$result) + 112|0);
 HEAPF32[$253>>2] = $220;
 $254 = (($agg$result) + 116|0);
 HEAPF32[$254>>2] = $221;
 $255 = (($agg$result) + 120|0);
 HEAPF32[$255>>2] = $222;
 $256 = (($agg$result) + 124|0);
 HEAPF32[$256>>2] = Math_fround(0.0);
 $257 = (($agg$result) + 128|0);
 HEAPF32[$257>>2] = $223;
 $258 = (($agg$result) + 132|0);
 HEAPF32[$258>>2] = $224;
 $259 = (($agg$result) + 136|0);
 HEAPF32[$259>>2] = $225;
 $260 = (($agg$result) + 140|0);
 HEAPF32[$260>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx21PxcFsApplyJointDrivesERNS_9PxcFsDataEPKNS_6shdfnd3aos5Vec3VE($matrix,$Q) {
 $matrix = $matrix|0;
 $Q = $Q|0;
 var $$in = 0, $$pre = 0, $$sum$i = 0, $$sum$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0;
 var $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0;
 var $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $SZminusQ = 0, $Z = 0, $dV = 0, $i1$03 = 0, $i2$02 = 0, $tmp1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5248|0;
 $Z = sp + 3200|0;
 $dV = sp;
 $SZminusQ = sp + 2048|0;
 $0 = sp + 3072|0;
 $1 = sp + 3104|0;
 $2 = sp + 3136|0;
 $3 = sp + 3168|0;
 $4 = (($matrix) + 26|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $$sum$i = (($6) + 144)|0;
 $7 = (($matrix) + ($$sum$i)|0);
 $8 = (($matrix) + 24|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9&65535;
 $11 = (($matrix) + 8|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12&65535;
 $tmp1$i = ($13*432)|0;
 $$sum$i1 = (($tmp1$i) + ($10))|0;
 $14 = (($matrix) + ($$sum$i1)|0);
 $15 = (($matrix) + 10|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = (($matrix) + ($17)|0);
 $19 = $13 << 5;
 _memset(($Z|0),0,($19|0))|0;
 $20 = ($12&65535)>(1);
 if ($20) {
  $21 = (($0) + 4|0);
  $22 = (($0) + 8|0);
  $23 = (($0) + 16|0);
  $24 = (($0) + 20|0);
  $25 = (($0) + 24|0);
  $$in = $13;
  while(1) {
   $26 = (($$in) + -1)|0;
   $27 = ((($matrix) + ($26)|0) + 64|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = $28&255;
   $30 = (($7) + (($26*160)|0)|0);
   $31 = (($18) + ($26<<5)|0);
   $32 = (($SZminusQ) + ($26<<4)|0);
   $33 = (($Z) + ($26<<5)|0);
   $34 = (($Q) + ($26<<4)|0);
   __ZN5physx22propagateDrivenImpulseERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKS8_($0,$30,$31,$32,$33,$34);
   $35 = (($Z) + ($29<<5)|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = ((($Z) + ($29<<5)|0) + 4|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = ((($Z) + ($29<<5)|0) + 8|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = ((($Z) + ($29<<5)|0) + 12|0);
   $42 = Math_fround(HEAPF32[$0>>2]);
   $43 = Math_fround(HEAPF32[$21>>2]);
   $44 = Math_fround(HEAPF32[$22>>2]);
   $45 = Math_fround($36 + $42);
   $46 = Math_fround($38 + $43);
   $47 = Math_fround($40 + $44);
   HEAPF32[$35>>2] = $45;
   HEAPF32[$37>>2] = $46;
   HEAPF32[$39>>2] = $47;
   HEAPF32[$41>>2] = Math_fround(0.0);
   $48 = ((($Z) + ($29<<5)|0) + 16|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = ((($Z) + ($29<<5)|0) + 20|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = ((($Z) + ($29<<5)|0) + 24|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = ((($Z) + ($29<<5)|0) + 28|0);
   $55 = Math_fround(HEAPF32[$23>>2]);
   $56 = Math_fround(HEAPF32[$24>>2]);
   $57 = Math_fround(HEAPF32[$25>>2]);
   $58 = Math_fround($49 + $55);
   $59 = Math_fround($51 + $56);
   $60 = Math_fround($53 + $57);
   HEAPF32[$48>>2] = $58;
   HEAPF32[$50>>2] = $59;
   HEAPF32[$52>>2] = $60;
   HEAPF32[$54>>2] = Math_fround(0.0);
   $61 = ($26>>>0)>(1);
   if ($61) {
    $$in = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP16[$4>>1]|0;
  $63 = $$pre;
 } else {
  $63 = $5;
 }
 $62 = $63&65535;
 $64 = (($matrix) + ($62)|0);
 $65 = Math_fround(HEAPF32[$Z>>2]);
 $66 = (($Z) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($Z) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround(-$65);
 $71 = Math_fround(-$67);
 $72 = Math_fround(-$69);
 $73 = (($Z) + 16|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($Z) + 20|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($Z) + 24|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround(-$74);
 $80 = Math_fround(-$76);
 $81 = Math_fround(-$78);
 HEAPF32[$2>>2] = $70;
 $82 = (($2) + 4|0);
 HEAPF32[$82>>2] = $71;
 $83 = (($2) + 8|0);
 HEAPF32[$83>>2] = $72;
 $84 = (($2) + 12|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 $85 = (($2) + 16|0);
 HEAPF32[$85>>2] = $79;
 $86 = (($2) + 20|0);
 HEAPF32[$86>>2] = $80;
 $87 = (($2) + 24|0);
 HEAPF32[$87>>2] = $81;
 $88 = (($2) + 28|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 __ZN5physx26PxcArticulationFnsSimdBase8multiplyERKNS_12PxcFsInertiaERKNS_14PxcSIMDSpatialE($1,$64,$2);
 ;HEAP32[$dV+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$dV+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$dV+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$dV+12>>2]=HEAP32[$1+12>>2]|0;
 $89 = (($dV) + 16|0);
 $90 = (($1) + 16|0);
 ;HEAP32[$89+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$90+12>>2]|0;
 $91 = HEAP16[$11>>1]|0;
 $92 = ($91&65535)>(1);
 if ($92) {
  $93 = (($3) + 16|0);
  $i1$03 = 1;
  while(1) {
   $94 = (($dV) + ($i1$03<<5)|0);
   $95 = (($7) + (($i1$03*160)|0)|0);
   $96 = (($18) + ($i1$03<<5)|0);
   $97 = (($SZminusQ) + ($i1$03<<4)|0);
   $98 = ((($matrix) + ($i1$03)|0) + 64|0);
   $99 = HEAP8[$98>>0]|0;
   $100 = $99&255;
   $101 = (($dV) + ($100<<5)|0);
   $102 = (($14) + (($i1$03*96)|0)|0);
   __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE17propagateVelocityERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERKNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($3,$95,$96,$97,$101,$102);
   ;HEAP32[$94+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$94+12>>2]=HEAP32[$3+12>>2]|0;
   $103 = ((($dV) + ($i1$03<<5)|0) + 16|0);
   ;HEAP32[$103+0>>2]=HEAP32[$93+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$93+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$93+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$93+12>>2]|0;
   $104 = (($i1$03) + 1)|0;
   $105 = HEAP16[$11>>1]|0;
   $106 = $105&65535;
   $107 = ($104>>>0)<($106>>>0);
   if ($107) {
    $i1$03 = $104;
   } else {
    $110 = $105;
    break;
   }
  }
 } else {
  $110 = $91;
 }
 $108 = (($matrix) + 128|0);
 $109 = ($110<<16>>16)==(0);
 if ($109) {
  STACKTOP = sp;return;
 } else {
  $i2$02 = 0;
 }
 while(1) {
  $111 = (($108) + ($i2$02<<5)|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = ((($108) + ($i2$02<<5)|0) + 4|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = ((($108) + ($i2$02<<5)|0) + 8|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = ((($108) + ($i2$02<<5)|0) + 12|0);
  $118 = (($dV) + ($i2$02<<5)|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = ((($dV) + ($i2$02<<5)|0) + 4|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = ((($dV) + ($i2$02<<5)|0) + 8|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = Math_fround($112 + $119);
  $125 = Math_fround($114 + $121);
  $126 = Math_fround($116 + $123);
  HEAPF32[$111>>2] = $124;
  HEAPF32[$113>>2] = $125;
  HEAPF32[$115>>2] = $126;
  HEAPF32[$117>>2] = Math_fround(0.0);
  $127 = ((($108) + ($i2$02<<5)|0) + 16|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = ((($108) + ($i2$02<<5)|0) + 20|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = ((($108) + ($i2$02<<5)|0) + 24|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = ((($108) + ($i2$02<<5)|0) + 28|0);
  $134 = ((($dV) + ($i2$02<<5)|0) + 16|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = ((($dV) + ($i2$02<<5)|0) + 20|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = ((($dV) + ($i2$02<<5)|0) + 24|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($128 + $135);
  $141 = Math_fround($130 + $137);
  $142 = Math_fround($132 + $139);
  HEAPF32[$127>>2] = $140;
  HEAPF32[$129>>2] = $141;
  HEAPF32[$131>>2] = $142;
  HEAPF32[$133>>2] = Math_fround(0.0);
  $143 = (($i2$02) + 1)|0;
  $144 = HEAP16[$11>>1]|0;
  $145 = $144&65535;
  $146 = ($143>>>0)<($145>>>0);
  if ($146) {
   $i2$02 = $143;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx22propagateDrivenImpulseERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKS8_($agg$result,$row,$jv,$SZMinusQ,$Z,$Q) {
 $agg$result = $agg$result|0;
 $row = $row|0;
 $jv = $jv|0;
 $SZMinusQ = $SZMinusQ|0;
 $Z = $Z|0;
 $Q = $Q|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($Z) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($Z) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($Z) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$Z>>2]);
 $7 = (($Z) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($Z) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($jv) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($jv) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($jv) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($8 * $16);
 $18 = Math_fround($10 * $14);
 $19 = Math_fround($17 - $18);
 $20 = Math_fround($10 * $12);
 $21 = Math_fround($6 * $16);
 $22 = Math_fround($20 - $21);
 $23 = Math_fround($6 * $14);
 $24 = Math_fround($8 * $12);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($1 + $19);
 $27 = Math_fround($3 + $22);
 $28 = Math_fround($5 + $25);
 $29 = Math_fround(HEAPF32[$Q>>2]);
 $30 = (($Q) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($Q) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($26 - $29);
 $35 = Math_fround($27 - $31);
 $36 = Math_fround($28 - $33);
 HEAPF32[$SZMinusQ>>2] = $34;
 $37 = (($SZMinusQ) + 4|0);
 HEAPF32[$37>>2] = $35;
 $38 = (($SZMinusQ) + 8|0);
 HEAPF32[$38>>2] = $36;
 $39 = (($SZMinusQ) + 12|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = Math_fround(HEAPF32[$row>>2]);
 $41 = (($row) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($row) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($row) + 32|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($row) + 36|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($row) + 40|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($row) + 64|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($row) + 68|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($row) + 72|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($36 * $52);
 $58 = Math_fround($36 * $54);
 $59 = Math_fround($36 * $56);
 $60 = Math_fround($35 * $46);
 $61 = Math_fround($35 * $48);
 $62 = Math_fround($35 * $50);
 $63 = Math_fround($60 + $57);
 $64 = Math_fround($61 + $58);
 $65 = Math_fround($62 + $59);
 $66 = Math_fround($34 * $40);
 $67 = Math_fround($34 * $42);
 $68 = Math_fround($34 * $44);
 $69 = Math_fround($66 + $63);
 $70 = Math_fround($67 + $64);
 $71 = Math_fround($68 + $65);
 $72 = (($row) + 16|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($row) + 20|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($row) + 24|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($row) + 48|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($row) + 52|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($row) + 56|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($row) + 80|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($row) + 84|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($row) + 88|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($36 * $85);
 $91 = Math_fround($36 * $87);
 $92 = Math_fround($36 * $89);
 $93 = Math_fround($35 * $79);
 $94 = Math_fround($35 * $81);
 $95 = Math_fround($35 * $83);
 $96 = Math_fround($93 + $90);
 $97 = Math_fround($94 + $91);
 $98 = Math_fround($95 + $92);
 $99 = Math_fround($34 * $73);
 $100 = Math_fround($34 * $75);
 $101 = Math_fround($34 * $77);
 $102 = Math_fround($99 + $96);
 $103 = Math_fround($100 + $97);
 $104 = Math_fround($101 + $98);
 $105 = Math_fround(HEAPF32[$Z>>2]);
 $106 = Math_fround(HEAPF32[$7>>2]);
 $107 = Math_fround(HEAPF32[$9>>2]);
 $108 = Math_fround($105 - $69);
 $109 = Math_fround($106 - $70);
 $110 = Math_fround($107 - $71);
 $111 = Math_fround(HEAPF32[$0>>2]);
 $112 = Math_fround(HEAPF32[$2>>2]);
 $113 = Math_fround(HEAPF32[$4>>2]);
 $114 = Math_fround($111 - $102);
 $115 = Math_fround($112 - $103);
 $116 = Math_fround($113 - $104);
 $117 = Math_fround(HEAPF32[$jv>>2]);
 $118 = (($jv) + 4|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($jv) + 8|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround($110 * $119);
 $123 = Math_fround($109 * $121);
 $124 = Math_fround($122 - $123);
 $125 = Math_fround($108 * $121);
 $126 = Math_fround($110 * $117);
 $127 = Math_fround($125 - $126);
 $128 = Math_fround($109 * $117);
 $129 = Math_fround($108 * $119);
 $130 = Math_fround($128 - $129);
 $131 = Math_fround($114 + $124);
 $132 = Math_fround($115 + $127);
 $133 = Math_fround($116 + $130);
 HEAPF32[$agg$result>>2] = $108;
 $134 = (($agg$result) + 4|0);
 HEAPF32[$134>>2] = $109;
 $135 = (($agg$result) + 8|0);
 HEAPF32[$135>>2] = $110;
 $136 = (($agg$result) + 12|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 $137 = (($agg$result) + 16|0);
 HEAPF32[$137>>2] = $131;
 $138 = (($agg$result) + 20|0);
 HEAPF32[$138>>2] = $132;
 $139 = (($agg$result) + 24|0);
 HEAPF32[$139>>2] = $133;
 $140 = (($agg$result) + 28|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE17propagateVelocityERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERKNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($agg$result,$row,$jv,$SZ,$v,$aux) {
 $agg$result = $agg$result|0;
 $row = $row|0;
 $jv = $jv|0;
 $SZ = $SZ|0;
 $v = $v|0;
 $aux = $aux|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0);
 var $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0;
 var $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$jv>>2]);
 $1 = (($jv) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($jv) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$0);
 $6 = Math_fround(-$2);
 $7 = Math_fround(-$4);
 $8 = Math_fround(HEAPF32[$v>>2]);
 $9 = (($v) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($v) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($v) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($v) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($v) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * $6);
 $20 = Math_fround($16 * $7);
 $21 = Math_fround($19 - $20);
 $22 = Math_fround($14 * $7);
 $23 = Math_fround($18 * $5);
 $24 = Math_fround($22 - $23);
 $25 = Math_fround($16 * $5);
 $26 = Math_fround($14 * $6);
 $27 = Math_fround($25 - $26);
 $28 = Math_fround($8 + $21);
 $29 = Math_fround($10 + $24);
 $30 = Math_fround($12 + $27);
 $31 = Math_fround(HEAPF32[$SZ>>2]);
 $32 = (($SZ) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($SZ) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($row) + 96|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($31 * $37);
 $39 = (($row) + 112|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($33 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($row) + 128|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($35 * $44);
 $46 = Math_fround($42 + $45);
 $47 = (($row) + 100|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($31 * $48);
 $50 = (($row) + 116|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($33 * $51);
 $53 = Math_fround($49 + $52);
 $54 = (($row) + 132|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($35 * $55);
 $57 = Math_fround($53 + $56);
 $58 = (($row) + 104|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($31 * $59);
 $61 = (($row) + 120|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($33 * $62);
 $64 = Math_fround($60 + $63);
 $65 = (($row) + 136|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($35 * $66);
 $68 = Math_fround($64 + $67);
 $69 = Math_fround(HEAPF32[$row>>2]);
 $70 = (($row) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($row) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($28 * $69);
 $75 = Math_fround($29 * $71);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($30 * $73);
 $78 = Math_fround($76 + $77);
 $79 = (($row) + 16|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($row) + 20|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($row) + 24|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($14 * $80);
 $86 = Math_fround($16 * $82);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($18 * $84);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($78 + $89);
 $91 = (($row) + 32|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($row) + 36|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($row) + 40|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($28 * $92);
 $98 = Math_fround($29 * $94);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($30 * $96);
 $101 = Math_fround($99 + $100);
 $102 = (($row) + 48|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($row) + 52|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($row) + 56|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($14 * $103);
 $109 = Math_fround($16 * $105);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($18 * $107);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround($101 + $112);
 $114 = (($row) + 64|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($row) + 68|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($row) + 72|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($28 * $115);
 $121 = Math_fround($29 * $117);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($30 * $119);
 $124 = Math_fround($122 + $123);
 $125 = (($row) + 80|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($row) + 84|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($row) + 88|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = Math_fround($14 * $126);
 $132 = Math_fround($16 * $128);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround($18 * $130);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround($124 + $135);
 $137 = Math_fround($46 + $90);
 $138 = Math_fround($57 + $113);
 $139 = Math_fround($68 + $136);
 $140 = (($jv) + 16|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($jv) + 20|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($jv) + 24|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround($143 * $139);
 $147 = Math_fround($138 * $145);
 $148 = Math_fround($146 - $147);
 $149 = Math_fround($137 * $145);
 $150 = Math_fround($141 * $139);
 $151 = Math_fround($149 - $150);
 $152 = Math_fround($138 * $141);
 $153 = Math_fround($137 * $143);
 $154 = Math_fround($152 - $153);
 $155 = Math_fround($28 - $148);
 $156 = Math_fround($29 - $151);
 $157 = Math_fround($30 - $154);
 $158 = Math_fround($14 - $137);
 $159 = Math_fround($16 - $138);
 $160 = Math_fround($18 - $139);
 HEAPF32[$agg$result>>2] = $155;
 $161 = (($agg$result) + 4|0);
 HEAPF32[$161>>2] = $156;
 $162 = (($agg$result) + 8|0);
 HEAPF32[$162>>2] = $157;
 $163 = (($agg$result) + 12|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = (($agg$result) + 16|0);
 HEAPF32[$164>>2] = $158;
 $165 = (($agg$result) + 20|0);
 HEAPF32[$165>>2] = $159;
 $166 = (($agg$result) + 24|0);
 HEAPF32[$166>>2] = $160;
 $167 = (($agg$result) + 28|0);
 HEAPF32[$167>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper13applyImpulsesERKNS_9PxcFsDataEPNS_14PxcSIMDSpatialES5_($matrix,$Z,$V) {
 $matrix = $matrix|0;
 $Z = $Z|0;
 $V = $V|0;
 var $$in = 0, $$pre = 0, $$sum$i = 0, $$sum$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0;
 var $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0;
 var $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0;
 var $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0;
 var $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $SZ = 0, $dV = 0, $i1$03 = 0, $i2$02 = 0, $tmp1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3200|0;
 $dV = sp + 1152|0;
 $SZ = sp;
 $0 = sp + 1024|0;
 $1 = sp + 1056|0;
 $2 = sp + 1088|0;
 $3 = sp + 1120|0;
 $4 = (($matrix) + 26|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $$sum$i = (($6) + 144)|0;
 $7 = (($matrix) + ($$sum$i)|0);
 $8 = (($matrix) + 24|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9&65535;
 $11 = (($matrix) + 8|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12&65535;
 $tmp1$i = ($13*432)|0;
 $$sum$i1 = (($tmp1$i) + ($10))|0;
 $14 = (($matrix) + ($$sum$i1)|0);
 $15 = (($matrix) + 10|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = (($matrix) + ($17)|0);
 $19 = ($12&65535)>(1);
 if ($19) {
  $20 = (($0) + 4|0);
  $21 = (($0) + 8|0);
  $22 = (($0) + 16|0);
  $23 = (($0) + 20|0);
  $24 = (($0) + 24|0);
  $$in = $13;
  while(1) {
   $25 = (($$in) + -1)|0;
   $26 = ((($matrix) + ($25)|0) + 64|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   $29 = (($7) + (($25*160)|0)|0);
   $30 = (($18) + ($25<<5)|0);
   $31 = (($SZ) + ($25<<4)|0);
   $32 = (($Z) + ($25<<5)|0);
   $33 = (($14) + (($25*96)|0)|0);
   __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE16propagateImpulseERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($0,$29,$30,$31,$32,$33);
   $34 = (($Z) + ($28<<5)|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = ((($Z) + ($28<<5)|0) + 4|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = ((($Z) + ($28<<5)|0) + 8|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = ((($Z) + ($28<<5)|0) + 12|0);
   $41 = Math_fround(HEAPF32[$0>>2]);
   $42 = Math_fround(HEAPF32[$20>>2]);
   $43 = Math_fround(HEAPF32[$21>>2]);
   $44 = Math_fround($35 + $41);
   $45 = Math_fround($37 + $42);
   $46 = Math_fround($39 + $43);
   HEAPF32[$34>>2] = $44;
   HEAPF32[$36>>2] = $45;
   HEAPF32[$38>>2] = $46;
   HEAPF32[$40>>2] = Math_fround(0.0);
   $47 = ((($Z) + ($28<<5)|0) + 16|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = ((($Z) + ($28<<5)|0) + 20|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = ((($Z) + ($28<<5)|0) + 24|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $53 = ((($Z) + ($28<<5)|0) + 28|0);
   $54 = Math_fround(HEAPF32[$22>>2]);
   $55 = Math_fround(HEAPF32[$23>>2]);
   $56 = Math_fround(HEAPF32[$24>>2]);
   $57 = Math_fround($48 + $54);
   $58 = Math_fround($50 + $55);
   $59 = Math_fround($52 + $56);
   HEAPF32[$47>>2] = $57;
   HEAPF32[$49>>2] = $58;
   HEAPF32[$51>>2] = $59;
   HEAPF32[$53>>2] = Math_fround(0.0);
   $60 = ($25>>>0)>(1);
   if ($60) {
    $$in = $25;
   } else {
    break;
   }
  }
  $$pre = HEAP16[$4>>1]|0;
  $62 = $$pre;
 } else {
  $62 = $5;
 }
 $61 = $62&65535;
 $63 = (($matrix) + ($61)|0);
 $64 = Math_fround(HEAPF32[$Z>>2]);
 $65 = (($Z) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($Z) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround(-$64);
 $70 = Math_fround(-$66);
 $71 = Math_fround(-$68);
 $72 = (($Z) + 16|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($Z) + 20|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($Z) + 24|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround(-$73);
 $79 = Math_fround(-$75);
 $80 = Math_fround(-$77);
 HEAPF32[$2>>2] = $69;
 $81 = (($2) + 4|0);
 HEAPF32[$81>>2] = $70;
 $82 = (($2) + 8|0);
 HEAPF32[$82>>2] = $71;
 $83 = (($2) + 12|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($2) + 16|0);
 HEAPF32[$84>>2] = $78;
 $85 = (($2) + 20|0);
 HEAPF32[$85>>2] = $79;
 $86 = (($2) + 24|0);
 HEAPF32[$86>>2] = $80;
 $87 = (($2) + 28|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 __ZN5physx26PxcArticulationFnsSimdBase8multiplyERKNS_12PxcFsInertiaERKNS_14PxcSIMDSpatialE($1,$63,$2);
 ;HEAP32[$dV+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$dV+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$dV+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$dV+12>>2]=HEAP32[$1+12>>2]|0;
 $88 = (($dV) + 16|0);
 $89 = (($1) + 16|0);
 ;HEAP32[$88+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$89+12>>2]|0;
 $90 = HEAP16[$11>>1]|0;
 $91 = ($90&65535)>(1);
 if ($91) {
  $92 = (($3) + 16|0);
  $i1$03 = 1;
  while(1) {
   $95 = (($dV) + ($i1$03<<5)|0);
   $96 = (($7) + (($i1$03*160)|0)|0);
   $97 = (($18) + ($i1$03<<5)|0);
   $98 = (($SZ) + ($i1$03<<4)|0);
   $99 = ((($matrix) + ($i1$03)|0) + 64|0);
   $100 = HEAP8[$99>>0]|0;
   $101 = $100&255;
   $102 = (($dV) + ($101<<5)|0);
   $103 = (($14) + (($i1$03*96)|0)|0);
   __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE17propagateVelocityERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERKNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($3,$96,$97,$98,$102,$103);
   ;HEAP32[$95+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$95+12>>2]=HEAP32[$3+12>>2]|0;
   $104 = ((($dV) + ($i1$03<<5)|0) + 16|0);
   ;HEAP32[$104+0>>2]=HEAP32[$92+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$92+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$92+8>>2]|0;HEAP32[$104+12>>2]=HEAP32[$92+12>>2]|0;
   $105 = (($i1$03) + 1)|0;
   $106 = HEAP16[$11>>1]|0;
   $107 = $106&65535;
   $108 = ($105>>>0)<($107>>>0);
   if ($108) {
    $i1$03 = $105;
   } else {
    $94 = $106;
    break;
   }
  }
 } else {
  $94 = $90;
 }
 $93 = ($94<<16>>16)==(0);
 if ($93) {
  STACKTOP = sp;return;
 } else {
  $i2$02 = 0;
 }
 while(1) {
  $109 = (($V) + ($i2$02<<5)|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = ((($V) + ($i2$02<<5)|0) + 4|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = ((($V) + ($i2$02<<5)|0) + 8|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = ((($V) + ($i2$02<<5)|0) + 12|0);
  $116 = (($dV) + ($i2$02<<5)|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = ((($dV) + ($i2$02<<5)|0) + 4|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = ((($dV) + ($i2$02<<5)|0) + 8|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = Math_fround($110 + $117);
  $123 = Math_fround($112 + $119);
  $124 = Math_fround($114 + $121);
  HEAPF32[$109>>2] = $122;
  HEAPF32[$111>>2] = $123;
  HEAPF32[$113>>2] = $124;
  HEAPF32[$115>>2] = Math_fround(0.0);
  $125 = ((($V) + ($i2$02<<5)|0) + 16|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = ((($V) + ($i2$02<<5)|0) + 20|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = ((($V) + ($i2$02<<5)|0) + 24|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = ((($V) + ($i2$02<<5)|0) + 28|0);
  $132 = ((($dV) + ($i2$02<<5)|0) + 16|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = ((($dV) + ($i2$02<<5)|0) + 20|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = ((($dV) + ($i2$02<<5)|0) + 24|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = Math_fround($126 + $133);
  $139 = Math_fround($128 + $135);
  $140 = Math_fround($130 + $137);
  HEAPF32[$125>>2] = $138;
  HEAPF32[$127>>2] = $139;
  HEAPF32[$129>>2] = $140;
  HEAPF32[$131>>2] = Math_fround(0.0);
  $141 = (($i2$02) + 1)|0;
  $142 = HEAP16[$11>>1]|0;
  $143 = $142&65535;
  $144 = ($141>>>0)<($143>>>0);
  if ($144) {
   $i2$02 = $141;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE16propagateImpulseERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($agg$result,$row,$jv,$SZ,$Z,$aux) {
 $agg$result = $agg$result|0;
 $row = $row|0;
 $jv = $jv|0;
 $SZ = $SZ|0;
 $Z = $Z|0;
 $aux = $aux|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = Math_fround(0);
 var $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($Z) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($Z) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($Z) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$Z>>2]);
 $7 = (($Z) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($Z) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($jv) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($jv) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($jv) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($8 * $16);
 $18 = Math_fround($10 * $14);
 $19 = Math_fround($17 - $18);
 $20 = Math_fround($10 * $12);
 $21 = Math_fround($6 * $16);
 $22 = Math_fround($20 - $21);
 $23 = Math_fround($6 * $14);
 $24 = Math_fround($8 * $12);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($1 + $19);
 $27 = Math_fround($3 + $22);
 $28 = Math_fround($5 + $25);
 HEAPF32[$SZ>>2] = $26;
 $29 = (($SZ) + 4|0);
 HEAPF32[$29>>2] = $27;
 $30 = (($SZ) + 8|0);
 HEAPF32[$30>>2] = $28;
 $31 = (($SZ) + 12|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = Math_fround(HEAPF32[$row>>2]);
 $33 = (($row) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($row) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($row) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($row) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($row) + 40|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($row) + 64|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($row) + 68|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($row) + 72|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($28 * $44);
 $50 = Math_fround($28 * $46);
 $51 = Math_fround($28 * $48);
 $52 = Math_fround($27 * $38);
 $53 = Math_fround($27 * $40);
 $54 = Math_fround($27 * $42);
 $55 = Math_fround($52 + $49);
 $56 = Math_fround($53 + $50);
 $57 = Math_fround($54 + $51);
 $58 = Math_fround($26 * $32);
 $59 = Math_fround($26 * $34);
 $60 = Math_fround($26 * $36);
 $61 = Math_fround($58 + $55);
 $62 = Math_fround($59 + $56);
 $63 = Math_fround($60 + $57);
 $64 = (($row) + 16|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($row) + 20|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($row) + 24|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($row) + 48|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($row) + 52|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($row) + 56|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($row) + 80|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($row) + 84|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($row) + 88|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($28 * $77);
 $83 = Math_fround($28 * $79);
 $84 = Math_fround($28 * $81);
 $85 = Math_fround($27 * $71);
 $86 = Math_fround($27 * $73);
 $87 = Math_fround($27 * $75);
 $88 = Math_fround($85 + $82);
 $89 = Math_fround($86 + $83);
 $90 = Math_fround($87 + $84);
 $91 = Math_fround($26 * $65);
 $92 = Math_fround($26 * $67);
 $93 = Math_fround($26 * $69);
 $94 = Math_fround($91 + $88);
 $95 = Math_fround($92 + $89);
 $96 = Math_fround($93 + $90);
 $97 = Math_fround(HEAPF32[$Z>>2]);
 $98 = Math_fround(HEAPF32[$7>>2]);
 $99 = Math_fround(HEAPF32[$9>>2]);
 $100 = Math_fround($97 - $61);
 $101 = Math_fround($98 - $62);
 $102 = Math_fround($99 - $63);
 $103 = Math_fround(HEAPF32[$0>>2]);
 $104 = Math_fround(HEAPF32[$2>>2]);
 $105 = Math_fround(HEAPF32[$4>>2]);
 $106 = Math_fround($103 - $94);
 $107 = Math_fround($104 - $95);
 $108 = Math_fround($105 - $96);
 $109 = Math_fround(HEAPF32[$jv>>2]);
 $110 = (($jv) + 4|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($jv) + 8|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($102 * $111);
 $115 = Math_fround($101 * $113);
 $116 = Math_fround($114 - $115);
 $117 = Math_fround($100 * $113);
 $118 = Math_fround($102 * $109);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($101 * $109);
 $121 = Math_fround($100 * $111);
 $122 = Math_fround($120 - $121);
 $123 = Math_fround($106 + $116);
 $124 = Math_fround($107 + $119);
 $125 = Math_fround($108 + $122);
 HEAPF32[$agg$result>>2] = $100;
 $126 = (($agg$result) + 4|0);
 HEAPF32[$126>>2] = $101;
 $127 = (($agg$result) + 8|0);
 HEAPF32[$127>>2] = $102;
 $128 = (($agg$result) + 12|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 $129 = (($agg$result) + 16|0);
 HEAPF32[$129>>2] = $123;
 $130 = (($agg$result) + 20|0);
 HEAPF32[$130>>2] = $124;
 $131 = (($agg$result) + 24|0);
 HEAPF32[$131>>2] = $125;
 $132 = (($agg$result) + 28|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx22getImpulseResponseSlowERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS3_jS5_S6_($matrix,$linkID0,$impulse0,$deltaV0,$linkID1,$impulse1,$deltaV1) {
 $matrix = $matrix|0;
 $linkID0 = $linkID0|0;
 $impulse0 = $impulse0|0;
 $deltaV0 = $deltaV0|0;
 $linkID1 = $linkID1|0;
 $impulse1 = $impulse1|0;
 $deltaV1 = $deltaV1|0;
 var $$0147 = 0, $$064 = 0, $$in = 0, $$in87 = 0, $$in88 = 0, $$lcssa = Math_fround(0), $$lcssa25 = Math_fround(0), $$lcssa26 = Math_fround(0), $$lcssa27 = Math_fround(0), $$lcssa28 = Math_fround(0), $$lcssa29 = Math_fround(0), $$lcssa41 = Math_fround(0), $$lcssa42 = Math_fround(0), $$lcssa43 = Math_fround(0), $$lcssa44 = Math_fround(0), $$lcssa45 = Math_fround(0), $$lcssa46 = Math_fround(0), $$lcssa58 = Math_fround(0), $$lcssa59 = Math_fround(0), $$lcssa60 = Math_fround(0);
 var $$lcssa61 = Math_fround(0), $$lcssa62 = Math_fround(0), $$lcssa63 = Math_fround(0), $$pre$phi118Z2D = 0, $$pre115 = 0, $$sum$i = 0, $$sum$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0;
 var $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0);
 var $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0);
 var $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0);
 var $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0);
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0);
 var $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0;
 var $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0);
 var $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0);
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0);
 var $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0);
 var $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0);
 var $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0);
 var $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = 0, $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0);
 var $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0);
 var $452 = Math_fround(0), $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0;
 var $SZ = 0, $common$031 = 0, $i0$0$ph81 = 0, $i0$0$ph84 = 0, $i0$1$lcssa = 0, $i0$165 = 0, $i1$0$ph85 = 0, $i1$077 = 0, $i1$1$lcssa = 0, $i1$148 = 0, $ic$0$lcssa = 0, $ic$030 = 0, $stack = 0, $tmp1$i = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1440|0;
 $stack = sp + 1184|0;
 $SZ = sp;
 $v = sp + 1024|0;
 $0 = sp + 1056|0;
 $1 = sp + 1088|0;
 $2 = sp + 1120|0;
 $3 = sp + 1152|0;
 $4 = (($matrix) + 26|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $$sum$i = (($6) + 144)|0;
 $7 = (($matrix) + ($$sum$i)|0);
 $8 = (($matrix) + 24|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9&65535;
 $11 = (($matrix) + 8|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12&65535;
 $tmp1$i = ($13*432)|0;
 $$sum$i2 = (($tmp1$i) + ($10))|0;
 $14 = (($matrix) + ($$sum$i2)|0);
 $15 = (($matrix) + 10|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = (($matrix) + ($17)|0);
 $19 = ($linkID0|0)==($linkID1|0);
 L1: do {
  if ($19) {
   $i0$0$ph81 = $linkID0;
  } else {
   $i0$0$ph84 = $linkID0;$i1$0$ph85 = $linkID1;
   while(1) {
    $i1$077 = $i1$0$ph85;
    while(1) {
     $20 = ($i0$0$ph84>>>0)<($i1$077>>>0);
     if (!($20)) {
      break;
     }
     $21 = ((($matrix) + ($i1$077)|0) + 64|0);
     $22 = HEAP8[$21>>0]|0;
     $23 = $22&255;
     $24 = ($i0$0$ph84|0)==($23|0);
     if ($24) {
      $i0$0$ph81 = $i0$0$ph84;
      break L1;
     } else {
      $i1$077 = $23;
     }
    }
    $25 = ((($matrix) + ($i0$0$ph84)|0) + 64|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26&255;
    $28 = ($27|0)==($i1$077|0);
    if ($28) {
     $i0$0$ph81 = $i1$077;
     break;
    } else {
     $i0$0$ph84 = $27;$i1$0$ph85 = $i1$077;
    }
   }
  }
 } while(0);
 $29 = Math_fround(HEAPF32[$impulse0>>2]);
 $30 = (($impulse0) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($impulse0) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround(-$29);
 $35 = Math_fround(-$31);
 $36 = Math_fround(-$33);
 $37 = (($impulse0) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($impulse0) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($impulse0) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround(-$38);
 $44 = Math_fround(-$40);
 $45 = Math_fround(-$42);
 $46 = Math_fround(HEAPF32[$impulse1>>2]);
 $47 = (($impulse1) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($impulse1) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround(-$46);
 $52 = Math_fround(-$48);
 $53 = Math_fround(-$50);
 $54 = (($impulse1) + 16|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($impulse1) + 20|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($impulse1) + 24|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround(-$55);
 $61 = Math_fround(-$57);
 $62 = Math_fround(-$59);
 $63 = ($i0$0$ph81|0)==($linkID0|0);
 if ($63) {
  $$lcssa58 = $45;$$lcssa59 = $44;$$lcssa60 = $43;$$lcssa61 = $36;$$lcssa62 = $35;$$lcssa63 = $34;$i0$1$lcssa = 0;
 } else {
  $$064 = $linkID0;$72 = $35;$74 = $36;$78 = $34;$84 = $43;$86 = $44;$88 = $45;$i0$165 = 0;
  while(1) {
   $65 = ((($18) + ($$064<<5)|0) + 16|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = ((($18) + ($$064<<5)|0) + 20|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = ((($18) + ($$064<<5)|0) + 24|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = Math_fround($72 * $70);
   $73 = Math_fround($74 * $68);
   $75 = Math_fround($71 - $73);
   $76 = Math_fround($74 * $66);
   $77 = Math_fround($78 * $70);
   $79 = Math_fround($76 - $77);
   $80 = Math_fround($78 * $68);
   $81 = Math_fround($72 * $66);
   $82 = Math_fround($80 - $81);
   $83 = Math_fround($84 + $75);
   $85 = Math_fround($86 + $79);
   $87 = Math_fround($88 + $82);
   $89 = (($SZ) + ($$064<<4)|0);
   HEAPF32[$89>>2] = $83;
   $90 = ((($SZ) + ($$064<<4)|0) + 4|0);
   HEAPF32[$90>>2] = $85;
   $91 = ((($SZ) + ($$064<<4)|0) + 8|0);
   HEAPF32[$91>>2] = $87;
   $92 = ((($SZ) + ($$064<<4)|0) + 12|0);
   HEAPF32[$92>>2] = Math_fround(0.0);
   $93 = (($7) + (($$064*160)|0)|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = ((($7) + (($$064*160)|0)|0) + 4|0);
   $96 = Math_fround(HEAPF32[$95>>2]);
   $97 = ((($7) + (($$064*160)|0)|0) + 8|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = ((($7) + (($$064*160)|0)|0) + 32|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = ((($7) + (($$064*160)|0)|0) + 36|0);
   $102 = Math_fround(HEAPF32[$101>>2]);
   $103 = ((($7) + (($$064*160)|0)|0) + 40|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = ((($7) + (($$064*160)|0)|0) + 64|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = ((($7) + (($$064*160)|0)|0) + 68|0);
   $108 = Math_fround(HEAPF32[$107>>2]);
   $109 = ((($7) + (($$064*160)|0)|0) + 72|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = Math_fround($87 * $106);
   $112 = Math_fround($87 * $108);
   $113 = Math_fround($87 * $110);
   $114 = Math_fround($85 * $100);
   $115 = Math_fround($85 * $102);
   $116 = Math_fround($85 * $104);
   $117 = Math_fround($114 + $111);
   $118 = Math_fround($115 + $112);
   $119 = Math_fround($116 + $113);
   $120 = Math_fround($94 * $83);
   $121 = Math_fround($96 * $83);
   $122 = Math_fround($83 * $98);
   $123 = Math_fround($120 + $117);
   $124 = Math_fround($121 + $118);
   $125 = Math_fround($122 + $119);
   $126 = ((($7) + (($$064*160)|0)|0) + 16|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = ((($7) + (($$064*160)|0)|0) + 20|0);
   $129 = Math_fround(HEAPF32[$128>>2]);
   $130 = ((($7) + (($$064*160)|0)|0) + 24|0);
   $131 = Math_fround(HEAPF32[$130>>2]);
   $132 = ((($7) + (($$064*160)|0)|0) + 48|0);
   $133 = Math_fround(HEAPF32[$132>>2]);
   $134 = ((($7) + (($$064*160)|0)|0) + 52|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = ((($7) + (($$064*160)|0)|0) + 56|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = ((($7) + (($$064*160)|0)|0) + 80|0);
   $139 = Math_fround(HEAPF32[$138>>2]);
   $140 = ((($7) + (($$064*160)|0)|0) + 84|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = ((($7) + (($$064*160)|0)|0) + 88|0);
   $143 = Math_fround(HEAPF32[$142>>2]);
   $144 = Math_fround($87 * $139);
   $145 = Math_fround($87 * $141);
   $146 = Math_fround($87 * $143);
   $147 = Math_fround($85 * $133);
   $148 = Math_fround($85 * $135);
   $149 = Math_fround($85 * $137);
   $150 = Math_fround($147 + $144);
   $151 = Math_fround($148 + $145);
   $152 = Math_fround($149 + $146);
   $153 = Math_fround($83 * $127);
   $154 = Math_fround($83 * $129);
   $155 = Math_fround($83 * $131);
   $156 = Math_fround($153 + $150);
   $157 = Math_fround($154 + $151);
   $158 = Math_fround($155 + $152);
   $159 = Math_fround($78 - $123);
   $160 = Math_fround($72 - $124);
   $161 = Math_fround($74 - $125);
   $162 = Math_fround($84 - $156);
   $163 = Math_fround($86 - $157);
   $164 = Math_fround($88 - $158);
   $165 = (($18) + ($$064<<5)|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   $167 = ((($18) + ($$064<<5)|0) + 4|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = ((($18) + ($$064<<5)|0) + 8|0);
   $170 = Math_fround(HEAPF32[$169>>2]);
   $171 = Math_fround($161 * $168);
   $172 = Math_fround($160 * $170);
   $173 = Math_fround($171 - $172);
   $174 = Math_fround($159 * $170);
   $175 = Math_fround($161 * $166);
   $176 = Math_fround($174 - $175);
   $177 = Math_fround($160 * $166);
   $178 = Math_fround($159 * $168);
   $179 = Math_fround($177 - $178);
   $180 = Math_fround($162 + $173);
   $181 = Math_fround($163 + $176);
   $182 = Math_fround($164 + $179);
   $183 = (($i0$165) + 1)|0;
   $184 = (($stack) + ($i0$165<<2)|0);
   HEAP32[$184>>2] = $$064;
   $185 = ((($matrix) + ($$064)|0) + 64|0);
   $186 = HEAP8[$185>>0]|0;
   $187 = $186&255;
   $188 = ($187|0)==($i0$0$ph81|0);
   if ($188) {
    $$lcssa58 = $182;$$lcssa59 = $181;$$lcssa60 = $180;$$lcssa61 = $161;$$lcssa62 = $160;$$lcssa63 = $159;$i0$1$lcssa = $183;
    break;
   } else {
    $$064 = $187;$72 = $160;$74 = $161;$78 = $159;$84 = $180;$86 = $181;$88 = $182;$i0$165 = $183;
   }
  }
 }
 $64 = ($i0$0$ph81|0)==($linkID1|0);
 if ($64) {
  $$lcssa41 = $62;$$lcssa42 = $61;$$lcssa43 = $60;$$lcssa44 = $53;$$lcssa45 = $52;$$lcssa46 = $51;$i1$1$lcssa = $i0$1$lcssa;
 } else {
  $$0147 = $linkID1;$196 = $52;$198 = $53;$202 = $51;$208 = $60;$210 = $61;$212 = $62;$i1$148 = $i0$1$lcssa;
  while(1) {
   $189 = ((($18) + ($$0147<<5)|0) + 16|0);
   $190 = Math_fround(HEAPF32[$189>>2]);
   $191 = ((($18) + ($$0147<<5)|0) + 20|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = ((($18) + ($$0147<<5)|0) + 24|0);
   $194 = Math_fround(HEAPF32[$193>>2]);
   $195 = Math_fround($196 * $194);
   $197 = Math_fround($198 * $192);
   $199 = Math_fround($195 - $197);
   $200 = Math_fround($198 * $190);
   $201 = Math_fround($202 * $194);
   $203 = Math_fround($200 - $201);
   $204 = Math_fround($202 * $192);
   $205 = Math_fround($196 * $190);
   $206 = Math_fround($204 - $205);
   $207 = Math_fround($208 + $199);
   $209 = Math_fround($210 + $203);
   $211 = Math_fround($212 + $206);
   $213 = (($SZ) + ($$0147<<4)|0);
   HEAPF32[$213>>2] = $207;
   $214 = ((($SZ) + ($$0147<<4)|0) + 4|0);
   HEAPF32[$214>>2] = $209;
   $215 = ((($SZ) + ($$0147<<4)|0) + 8|0);
   HEAPF32[$215>>2] = $211;
   $216 = ((($SZ) + ($$0147<<4)|0) + 12|0);
   HEAPF32[$216>>2] = Math_fround(0.0);
   $217 = (($7) + (($$0147*160)|0)|0);
   $218 = Math_fround(HEAPF32[$217>>2]);
   $219 = ((($7) + (($$0147*160)|0)|0) + 4|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = ((($7) + (($$0147*160)|0)|0) + 8|0);
   $222 = Math_fround(HEAPF32[$221>>2]);
   $223 = ((($7) + (($$0147*160)|0)|0) + 32|0);
   $224 = Math_fround(HEAPF32[$223>>2]);
   $225 = ((($7) + (($$0147*160)|0)|0) + 36|0);
   $226 = Math_fround(HEAPF32[$225>>2]);
   $227 = ((($7) + (($$0147*160)|0)|0) + 40|0);
   $228 = Math_fround(HEAPF32[$227>>2]);
   $229 = ((($7) + (($$0147*160)|0)|0) + 64|0);
   $230 = Math_fround(HEAPF32[$229>>2]);
   $231 = ((($7) + (($$0147*160)|0)|0) + 68|0);
   $232 = Math_fround(HEAPF32[$231>>2]);
   $233 = ((($7) + (($$0147*160)|0)|0) + 72|0);
   $234 = Math_fround(HEAPF32[$233>>2]);
   $235 = Math_fround($211 * $230);
   $236 = Math_fround($211 * $232);
   $237 = Math_fround($211 * $234);
   $238 = Math_fround($209 * $224);
   $239 = Math_fround($209 * $226);
   $240 = Math_fround($209 * $228);
   $241 = Math_fround($238 + $235);
   $242 = Math_fround($239 + $236);
   $243 = Math_fround($240 + $237);
   $244 = Math_fround($218 * $207);
   $245 = Math_fround($220 * $207);
   $246 = Math_fround($207 * $222);
   $247 = Math_fround($244 + $241);
   $248 = Math_fround($245 + $242);
   $249 = Math_fround($246 + $243);
   $250 = ((($7) + (($$0147*160)|0)|0) + 16|0);
   $251 = Math_fround(HEAPF32[$250>>2]);
   $252 = ((($7) + (($$0147*160)|0)|0) + 20|0);
   $253 = Math_fround(HEAPF32[$252>>2]);
   $254 = ((($7) + (($$0147*160)|0)|0) + 24|0);
   $255 = Math_fround(HEAPF32[$254>>2]);
   $256 = ((($7) + (($$0147*160)|0)|0) + 48|0);
   $257 = Math_fround(HEAPF32[$256>>2]);
   $258 = ((($7) + (($$0147*160)|0)|0) + 52|0);
   $259 = Math_fround(HEAPF32[$258>>2]);
   $260 = ((($7) + (($$0147*160)|0)|0) + 56|0);
   $261 = Math_fround(HEAPF32[$260>>2]);
   $262 = ((($7) + (($$0147*160)|0)|0) + 80|0);
   $263 = Math_fround(HEAPF32[$262>>2]);
   $264 = ((($7) + (($$0147*160)|0)|0) + 84|0);
   $265 = Math_fround(HEAPF32[$264>>2]);
   $266 = ((($7) + (($$0147*160)|0)|0) + 88|0);
   $267 = Math_fround(HEAPF32[$266>>2]);
   $268 = Math_fround($211 * $263);
   $269 = Math_fround($211 * $265);
   $270 = Math_fround($211 * $267);
   $271 = Math_fround($209 * $257);
   $272 = Math_fround($209 * $259);
   $273 = Math_fround($209 * $261);
   $274 = Math_fround($271 + $268);
   $275 = Math_fround($272 + $269);
   $276 = Math_fround($273 + $270);
   $277 = Math_fround($207 * $251);
   $278 = Math_fround($207 * $253);
   $279 = Math_fround($207 * $255);
   $280 = Math_fround($277 + $274);
   $281 = Math_fround($278 + $275);
   $282 = Math_fround($279 + $276);
   $283 = Math_fround($202 - $247);
   $284 = Math_fround($196 - $248);
   $285 = Math_fround($198 - $249);
   $286 = Math_fround($208 - $280);
   $287 = Math_fround($210 - $281);
   $288 = Math_fround($212 - $282);
   $289 = (($18) + ($$0147<<5)|0);
   $290 = Math_fround(HEAPF32[$289>>2]);
   $291 = ((($18) + ($$0147<<5)|0) + 4|0);
   $292 = Math_fround(HEAPF32[$291>>2]);
   $293 = ((($18) + ($$0147<<5)|0) + 8|0);
   $294 = Math_fround(HEAPF32[$293>>2]);
   $295 = Math_fround($285 * $292);
   $296 = Math_fround($284 * $294);
   $297 = Math_fround($295 - $296);
   $298 = Math_fround($283 * $294);
   $299 = Math_fround($285 * $290);
   $300 = Math_fround($298 - $299);
   $301 = Math_fround($284 * $290);
   $302 = Math_fround($283 * $292);
   $303 = Math_fround($301 - $302);
   $304 = Math_fround($286 + $297);
   $305 = Math_fround($287 + $300);
   $306 = Math_fround($288 + $303);
   $307 = (($i1$148) + 1)|0;
   $308 = (($stack) + ($i1$148<<2)|0);
   HEAP32[$308>>2] = $$0147;
   $309 = ((($matrix) + ($$0147)|0) + 64|0);
   $310 = HEAP8[$309>>0]|0;
   $311 = $310&255;
   $312 = ($311|0)==($i0$0$ph81|0);
   if ($312) {
    $$lcssa41 = $306;$$lcssa42 = $305;$$lcssa43 = $304;$$lcssa44 = $285;$$lcssa45 = $284;$$lcssa46 = $283;$i1$1$lcssa = $307;
    break;
   } else {
    $$0147 = $311;$196 = $284;$198 = $285;$202 = $283;$208 = $304;$210 = $305;$212 = $306;$i1$148 = $307;
   }
  }
 }
 $313 = Math_fround($$lcssa63 + $$lcssa46);
 $314 = Math_fround($$lcssa62 + $$lcssa45);
 $315 = Math_fround($$lcssa61 + $$lcssa44);
 $316 = Math_fround($$lcssa60 + $$lcssa43);
 $317 = Math_fround($$lcssa59 + $$lcssa42);
 $318 = Math_fround($$lcssa58 + $$lcssa41);
 $319 = ($i0$0$ph81|0)==(0);
 if ($319) {
  $$lcssa = $318;$$lcssa25 = $317;$$lcssa26 = $316;$$lcssa27 = $315;$$lcssa28 = $314;$$lcssa29 = $313;$ic$0$lcssa = $i1$1$lcssa;
 } else {
  $327 = $314;$329 = $315;$333 = $313;$339 = $316;$341 = $317;$343 = $318;$common$031 = $i0$0$ph81;$ic$030 = $i1$1$lcssa;
  while(1) {
   $320 = ((($18) + ($common$031<<5)|0) + 16|0);
   $321 = Math_fround(HEAPF32[$320>>2]);
   $322 = ((($18) + ($common$031<<5)|0) + 20|0);
   $323 = Math_fround(HEAPF32[$322>>2]);
   $324 = ((($18) + ($common$031<<5)|0) + 24|0);
   $325 = Math_fround(HEAPF32[$324>>2]);
   $326 = Math_fround($327 * $325);
   $328 = Math_fround($329 * $323);
   $330 = Math_fround($326 - $328);
   $331 = Math_fround($329 * $321);
   $332 = Math_fround($333 * $325);
   $334 = Math_fround($331 - $332);
   $335 = Math_fround($333 * $323);
   $336 = Math_fround($327 * $321);
   $337 = Math_fround($335 - $336);
   $338 = Math_fround($339 + $330);
   $340 = Math_fround($341 + $334);
   $342 = Math_fround($343 + $337);
   $344 = (($SZ) + ($common$031<<4)|0);
   HEAPF32[$344>>2] = $338;
   $345 = ((($SZ) + ($common$031<<4)|0) + 4|0);
   HEAPF32[$345>>2] = $340;
   $346 = ((($SZ) + ($common$031<<4)|0) + 8|0);
   HEAPF32[$346>>2] = $342;
   $347 = ((($SZ) + ($common$031<<4)|0) + 12|0);
   HEAPF32[$347>>2] = Math_fround(0.0);
   $348 = (($7) + (($common$031*160)|0)|0);
   $349 = Math_fround(HEAPF32[$348>>2]);
   $350 = ((($7) + (($common$031*160)|0)|0) + 4|0);
   $351 = Math_fround(HEAPF32[$350>>2]);
   $352 = ((($7) + (($common$031*160)|0)|0) + 8|0);
   $353 = Math_fround(HEAPF32[$352>>2]);
   $354 = ((($7) + (($common$031*160)|0)|0) + 32|0);
   $355 = Math_fround(HEAPF32[$354>>2]);
   $356 = ((($7) + (($common$031*160)|0)|0) + 36|0);
   $357 = Math_fround(HEAPF32[$356>>2]);
   $358 = ((($7) + (($common$031*160)|0)|0) + 40|0);
   $359 = Math_fround(HEAPF32[$358>>2]);
   $360 = ((($7) + (($common$031*160)|0)|0) + 64|0);
   $361 = Math_fround(HEAPF32[$360>>2]);
   $362 = ((($7) + (($common$031*160)|0)|0) + 68|0);
   $363 = Math_fround(HEAPF32[$362>>2]);
   $364 = ((($7) + (($common$031*160)|0)|0) + 72|0);
   $365 = Math_fround(HEAPF32[$364>>2]);
   $366 = Math_fround($342 * $361);
   $367 = Math_fround($342 * $363);
   $368 = Math_fround($342 * $365);
   $369 = Math_fround($340 * $355);
   $370 = Math_fround($340 * $357);
   $371 = Math_fround($340 * $359);
   $372 = Math_fround($369 + $366);
   $373 = Math_fround($370 + $367);
   $374 = Math_fround($371 + $368);
   $375 = Math_fround($349 * $338);
   $376 = Math_fround($351 * $338);
   $377 = Math_fround($338 * $353);
   $378 = Math_fround($375 + $372);
   $379 = Math_fround($376 + $373);
   $380 = Math_fround($377 + $374);
   $381 = ((($7) + (($common$031*160)|0)|0) + 16|0);
   $382 = Math_fround(HEAPF32[$381>>2]);
   $383 = ((($7) + (($common$031*160)|0)|0) + 20|0);
   $384 = Math_fround(HEAPF32[$383>>2]);
   $385 = ((($7) + (($common$031*160)|0)|0) + 24|0);
   $386 = Math_fround(HEAPF32[$385>>2]);
   $387 = ((($7) + (($common$031*160)|0)|0) + 48|0);
   $388 = Math_fround(HEAPF32[$387>>2]);
   $389 = ((($7) + (($common$031*160)|0)|0) + 52|0);
   $390 = Math_fround(HEAPF32[$389>>2]);
   $391 = ((($7) + (($common$031*160)|0)|0) + 56|0);
   $392 = Math_fround(HEAPF32[$391>>2]);
   $393 = ((($7) + (($common$031*160)|0)|0) + 80|0);
   $394 = Math_fround(HEAPF32[$393>>2]);
   $395 = ((($7) + (($common$031*160)|0)|0) + 84|0);
   $396 = Math_fround(HEAPF32[$395>>2]);
   $397 = ((($7) + (($common$031*160)|0)|0) + 88|0);
   $398 = Math_fround(HEAPF32[$397>>2]);
   $399 = Math_fround($342 * $394);
   $400 = Math_fround($342 * $396);
   $401 = Math_fround($342 * $398);
   $402 = Math_fround($340 * $388);
   $403 = Math_fround($340 * $390);
   $404 = Math_fround($340 * $392);
   $405 = Math_fround($402 + $399);
   $406 = Math_fround($403 + $400);
   $407 = Math_fround($404 + $401);
   $408 = Math_fround($338 * $382);
   $409 = Math_fround($338 * $384);
   $410 = Math_fround($338 * $386);
   $411 = Math_fround($408 + $405);
   $412 = Math_fround($409 + $406);
   $413 = Math_fround($410 + $407);
   $414 = Math_fround($333 - $378);
   $415 = Math_fround($327 - $379);
   $416 = Math_fround($329 - $380);
   $417 = Math_fround($339 - $411);
   $418 = Math_fround($341 - $412);
   $419 = Math_fround($343 - $413);
   $420 = (($18) + ($common$031<<5)|0);
   $421 = Math_fround(HEAPF32[$420>>2]);
   $422 = ((($18) + ($common$031<<5)|0) + 4|0);
   $423 = Math_fround(HEAPF32[$422>>2]);
   $424 = ((($18) + ($common$031<<5)|0) + 8|0);
   $425 = Math_fround(HEAPF32[$424>>2]);
   $426 = Math_fround($416 * $423);
   $427 = Math_fround($415 * $425);
   $428 = Math_fround($426 - $427);
   $429 = Math_fround($414 * $425);
   $430 = Math_fround($416 * $421);
   $431 = Math_fround($429 - $430);
   $432 = Math_fround($415 * $421);
   $433 = Math_fround($414 * $423);
   $434 = Math_fround($432 - $433);
   $435 = Math_fround($417 + $428);
   $436 = Math_fround($418 + $431);
   $437 = Math_fround($419 + $434);
   $438 = (($ic$030) + 1)|0;
   $439 = (($stack) + ($ic$030<<2)|0);
   HEAP32[$439>>2] = $common$031;
   $440 = ((($matrix) + ($common$031)|0) + 64|0);
   $441 = HEAP8[$440>>0]|0;
   $442 = $441&255;
   $443 = ($441<<24>>24)==(0);
   if ($443) {
    $$lcssa = $437;$$lcssa25 = $436;$$lcssa26 = $435;$$lcssa27 = $416;$$lcssa28 = $415;$$lcssa29 = $414;$ic$0$lcssa = $438;
    break;
   } else {
    $327 = $415;$329 = $416;$333 = $414;$339 = $435;$341 = $436;$343 = $437;$common$031 = $442;$ic$030 = $438;
   }
  }
 }
 $444 = HEAP16[$4>>1]|0;
 $445 = $444&65535;
 $446 = (($matrix) + ($445)|0);
 $447 = Math_fround(-$$lcssa29);
 $448 = Math_fround(-$$lcssa28);
 $449 = Math_fround(-$$lcssa27);
 $450 = Math_fround(-$$lcssa26);
 $451 = Math_fround(-$$lcssa25);
 $452 = Math_fround(-$$lcssa);
 HEAPF32[$0>>2] = $447;
 $453 = (($0) + 4|0);
 HEAPF32[$453>>2] = $448;
 $454 = (($0) + 8|0);
 HEAPF32[$454>>2] = $449;
 $455 = (($0) + 12|0);
 HEAPF32[$455>>2] = Math_fround(0.0);
 $456 = (($0) + 16|0);
 HEAPF32[$456>>2] = $450;
 $457 = (($0) + 20|0);
 HEAPF32[$457>>2] = $451;
 $458 = (($0) + 24|0);
 HEAPF32[$458>>2] = $452;
 $459 = (($0) + 28|0);
 HEAPF32[$459>>2] = Math_fround(0.0);
 __ZN5physx26PxcArticulationFnsSimdBase8multiplyERKNS_12PxcFsInertiaERKNS_14PxcSIMDSpatialE($v,$446,$0);
 $460 = ($ic$0$lcssa>>>0)>($i1$1$lcssa>>>0);
 if ($460) {
  $461 = (($v) + 16|0);
  $462 = (($1) + 16|0);
  $$in88 = $ic$0$lcssa;
  while(1) {
   $463 = (($$in88) + -1)|0;
   $464 = (($stack) + ($463<<2)|0);
   $465 = HEAP32[$464>>2]|0;
   $466 = (($7) + (($465*160)|0)|0);
   $467 = (($18) + ($465<<5)|0);
   $468 = (($SZ) + ($465<<4)|0);
   $469 = (($14) + (($465*96)|0)|0);
   __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE17propagateVelocityERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERKNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($1,$466,$467,$468,$v,$469);
   ;HEAP32[$v+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$461+0>>2]=HEAP32[$462+0>>2]|0;HEAP32[$461+4>>2]=HEAP32[$462+4>>2]|0;HEAP32[$461+8>>2]=HEAP32[$462+8>>2]|0;HEAP32[$461+12>>2]=HEAP32[$462+12>>2]|0;
   $470 = ($463>>>0)>($i1$1$lcssa>>>0);
   if ($470) {
    $$in88 = $463;
   } else {
    $$pre$phi118Z2D = $461;
    break;
   }
  }
 } else {
  $$pre115 = (($v) + 16|0);
  $$pre$phi118Z2D = $$pre115;
 }
 ;HEAP32[$deltaV1+0>>2]=HEAP32[$v+0>>2]|0;HEAP32[$deltaV1+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$deltaV1+8>>2]=HEAP32[$v+8>>2]|0;HEAP32[$deltaV1+12>>2]=HEAP32[$v+12>>2]|0;
 $471 = (($deltaV1) + 16|0);
 ;HEAP32[$471+0>>2]=HEAP32[$$pre$phi118Z2D+0>>2]|0;HEAP32[$471+4>>2]=HEAP32[$$pre$phi118Z2D+4>>2]|0;HEAP32[$471+8>>2]=HEAP32[$$pre$phi118Z2D+8>>2]|0;HEAP32[$471+12>>2]=HEAP32[$$pre$phi118Z2D+12>>2]|0;
 $472 = ($i1$1$lcssa>>>0)>($i0$1$lcssa>>>0);
 if ($472) {
  $473 = (($2) + 16|0);
  $$in87 = $i1$1$lcssa;
  while(1) {
   $474 = (($$in87) + -1)|0;
   $475 = (($stack) + ($474<<2)|0);
   $476 = HEAP32[$475>>2]|0;
   $477 = (($7) + (($476*160)|0)|0);
   $478 = (($18) + ($476<<5)|0);
   $479 = (($SZ) + ($476<<4)|0);
   $480 = (($14) + (($476*96)|0)|0);
   __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE17propagateVelocityERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERKNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($2,$477,$478,$479,$deltaV1,$480);
   ;HEAP32[$deltaV1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$deltaV1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$deltaV1+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$deltaV1+12>>2]=HEAP32[$2+12>>2]|0;
   ;HEAP32[$471+0>>2]=HEAP32[$473+0>>2]|0;HEAP32[$471+4>>2]=HEAP32[$473+4>>2]|0;HEAP32[$471+8>>2]=HEAP32[$473+8>>2]|0;HEAP32[$471+12>>2]=HEAP32[$473+12>>2]|0;
   $481 = ($474>>>0)>($i0$1$lcssa>>>0);
   if ($481) {
    $$in87 = $474;
   } else {
    break;
   }
  }
 }
 ;HEAP32[$deltaV0+0>>2]=HEAP32[$v+0>>2]|0;HEAP32[$deltaV0+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$deltaV0+8>>2]=HEAP32[$v+8>>2]|0;HEAP32[$deltaV0+12>>2]=HEAP32[$v+12>>2]|0;
 $482 = (($deltaV0) + 16|0);
 ;HEAP32[$482+0>>2]=HEAP32[$$pre$phi118Z2D+0>>2]|0;HEAP32[$482+4>>2]=HEAP32[$$pre$phi118Z2D+4>>2]|0;HEAP32[$482+8>>2]=HEAP32[$$pre$phi118Z2D+8>>2]|0;HEAP32[$482+12>>2]=HEAP32[$$pre$phi118Z2D+12>>2]|0;
 $483 = ($i0$1$lcssa|0)==(0);
 if ($483) {
  STACKTOP = sp;return;
 }
 $484 = (($3) + 16|0);
 $$in = $i0$1$lcssa;
 while(1) {
  $485 = (($$in) + -1)|0;
  $486 = (($stack) + ($485<<2)|0);
  $487 = HEAP32[$486>>2]|0;
  $488 = (($7) + (($487*160)|0)|0);
  $489 = (($18) + ($487<<5)|0);
  $490 = (($SZ) + ($487<<4)|0);
  $491 = (($14) + (($487*96)|0)|0);
  __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE17propagateVelocityERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERKNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($3,$488,$489,$490,$deltaV0,$491);
  ;HEAP32[$deltaV0+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$deltaV0+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$deltaV0+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$deltaV0+12>>2]=HEAP32[$3+12>>2]|0;
  ;HEAP32[$482+0>>2]=HEAP32[$484+0>>2]|0;HEAP32[$482+4>>2]=HEAP32[$484+4>>2]|0;HEAP32[$482+8>>2]=HEAP32[$484+8>>2]|0;HEAP32[$482+12>>2]=HEAP32[$484+12>>2]|0;
  $492 = ($485|0)==(0);
  if ($492) {
   break;
  } else {
   $$in = $485;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper18getImpulseResponseERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS4_($matrix,$linkID,$impulse,$deltaV) {
 $matrix = $matrix|0;
 $linkID = $linkID|0;
 $impulse = $impulse|0;
 $deltaV = $deltaV|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 48|0;
 $tmpcast$byval_copy = sp;
 $0 = sp + 16|0;
 $1 = (($impulse) + 16|0);
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$impulse+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$impulse+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$impulse+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$impulse+12>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
 __ZN5physx12_GLOBAL__N_122getImpulseResponseSimdERKNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES6_($0,$matrix,$linkID,$tmpcast$byval_copy,$$byval_copy);
 ;HEAP32[$deltaV+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$deltaV+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$deltaV+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$deltaV+12>>2]=HEAP32[$0+12>>2]|0;
 $2 = (($deltaV) + 16|0);
 $3 = (($0) + 16|0);
 ;HEAP32[$2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$3+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx12_GLOBAL__N_122getImpulseResponseSimdERKNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES6_($agg$result,$matrix,$linkID,$lZ,$aZ) {
 $agg$result = $agg$result|0;
 $matrix = $matrix|0;
 $linkID = $linkID|0;
 $lZ = $lZ|0;
 $aZ = $aZ|0;
 var $$lcssa = Math_fround(0), $$lcssa749 = Math_fround(0), $$lcssa750 = Math_fround(0), $$lcssa751 = Math_fround(0), $$lcssa752 = Math_fround(0), $$lcssa753 = Math_fround(0), $$pre = 0, $$sum = 0, $$sum$i = 0, $$sum724 = 0, $$sum725 = 0, $$sum726 = 0, $$sum727 = 0, $$sum728 = 0, $$sum729 = 0, $$sum730 = 0, $$sum731 = 0, $$sum732 = 0, $$sum733 = 0, $$sum734 = 0;
 var $$sum735 = 0, $$sum736 = 0, $$sum737 = 0, $$sum738 = 0, $$sum739 = 0, $$sum740 = 0, $$sum741 = 0, $$sum742 = 0, $$sum743 = 0, $$sum744 = 0, $$sum745 = 0, $$sum746 = 0, $$sum747 = 0, $$sum748 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0);
 var $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0;
 var $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0);
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0;
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0;
 var $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0);
 var $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0);
 var $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0);
 var $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0);
 var $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0;
 var $338 = Math_fround(0), $339 = 0, $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0);
 var $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = Math_fround(0), $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = Math_fround(0), $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0);
 var $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0;
 var $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0);
 var $41 = Math_fround(0), $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = 0, $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0);
 var $428 = 0, $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0);
 var $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $SZ = 0, $i$0760 = 0, $iCount$0$lcssa = 0, $iCount$0761 = 0, $iCount$1754 = 0, $indices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1280|0;
 $SZ = sp;
 $indices = sp + 1024|0;
 $0 = (($matrix) + 26|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $$sum$i = (($2) + 144)|0;
 $3 = (($matrix) + ($$sum$i)|0);
 $4 = (($matrix) + 10|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = (($matrix) + ($6)|0);
 $8 = Math_fround(HEAPF32[$lZ>>2]);
 $9 = (($lZ) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($lZ) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($lZ) + 12|0);
 $14 = Math_fround(-$8);
 $15 = Math_fround(-$10);
 $16 = Math_fround(-$12);
 HEAPF32[$lZ>>2] = $14;
 HEAPF32[$9>>2] = $15;
 HEAPF32[$11>>2] = $16;
 HEAPF32[$13>>2] = Math_fround(0.0);
 $17 = Math_fround(HEAPF32[$aZ>>2]);
 $18 = (($aZ) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($aZ) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($aZ) + 12|0);
 $23 = Math_fround(-$17);
 $24 = Math_fround(-$19);
 $25 = Math_fround(-$21);
 HEAPF32[$aZ>>2] = $23;
 HEAPF32[$18>>2] = $24;
 HEAPF32[$20>>2] = $25;
 HEAPF32[$22>>2] = Math_fround(0.0);
 $26 = ($linkID|0)==(0);
 if ($26) {
  $152 = $1;$156 = $14;$160 = $15;$165 = $16;$192 = $23;$196 = $24;$201 = $25;$iCount$0$lcssa = 0;
 } else {
  $34 = $15;$36 = $16;$40 = $14;$46 = $23;$48 = $24;$50 = $25;$i$0760 = $linkID;$iCount$0761 = 0;
  while(1) {
   $27 = ((($7) + ($i$0760<<5)|0) + 16|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = ((($7) + ($i$0760<<5)|0) + 20|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = ((($7) + ($i$0760<<5)|0) + 24|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = Math_fround($34 * $32);
   $35 = Math_fround($36 * $30);
   $37 = Math_fround($33 - $35);
   $38 = Math_fround($36 * $28);
   $39 = Math_fround($40 * $32);
   $41 = Math_fround($38 - $39);
   $42 = Math_fround($40 * $30);
   $43 = Math_fround($34 * $28);
   $44 = Math_fround($42 - $43);
   $45 = Math_fround($46 + $37);
   $47 = Math_fround($48 + $41);
   $49 = Math_fround($50 + $44);
   $51 = (($SZ) + ($iCount$0761<<4)|0);
   HEAPF32[$51>>2] = $45;
   $52 = ((($SZ) + ($iCount$0761<<4)|0) + 4|0);
   HEAPF32[$52>>2] = $47;
   $53 = ((($SZ) + ($iCount$0761<<4)|0) + 8|0);
   HEAPF32[$53>>2] = $49;
   $54 = ((($SZ) + ($iCount$0761<<4)|0) + 12|0);
   HEAPF32[$54>>2] = Math_fround(0.0);
   $55 = (($3) + (($i$0760*160)|0)|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = ((($3) + (($i$0760*160)|0)|0) + 4|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = ((($3) + (($i$0760*160)|0)|0) + 8|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = ((($3) + (($i$0760*160)|0)|0) + 32|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = ((($3) + (($i$0760*160)|0)|0) + 36|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = ((($3) + (($i$0760*160)|0)|0) + 40|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = ((($3) + (($i$0760*160)|0)|0) + 64|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = ((($3) + (($i$0760*160)|0)|0) + 68|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = ((($3) + (($i$0760*160)|0)|0) + 72|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = Math_fround($49 * $68);
   $74 = Math_fround($49 * $70);
   $75 = Math_fround($49 * $72);
   $76 = Math_fround($40 - $73);
   $77 = Math_fround($34 - $74);
   $78 = Math_fround($36 - $75);
   $79 = Math_fround($47 * $62);
   $80 = Math_fround($47 * $64);
   $81 = Math_fround($47 * $66);
   $82 = Math_fround($76 - $79);
   $83 = Math_fround($77 - $80);
   $84 = Math_fround($78 - $81);
   $85 = Math_fround($56 * $45);
   $86 = Math_fround($58 * $45);
   $87 = Math_fround($60 * $45);
   $88 = Math_fround($82 - $85);
   $89 = Math_fround($83 - $86);
   $90 = Math_fround($84 - $87);
   $91 = ((($3) + (($i$0760*160)|0)|0) + 16|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = ((($3) + (($i$0760*160)|0)|0) + 20|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = ((($3) + (($i$0760*160)|0)|0) + 24|0);
   $96 = Math_fround(HEAPF32[$95>>2]);
   $97 = ((($3) + (($i$0760*160)|0)|0) + 48|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = ((($3) + (($i$0760*160)|0)|0) + 52|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = ((($3) + (($i$0760*160)|0)|0) + 56|0);
   $102 = Math_fround(HEAPF32[$101>>2]);
   $103 = ((($3) + (($i$0760*160)|0)|0) + 80|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = ((($3) + (($i$0760*160)|0)|0) + 84|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = ((($3) + (($i$0760*160)|0)|0) + 88|0);
   $108 = Math_fround(HEAPF32[$107>>2]);
   $109 = Math_fround($49 * $104);
   $110 = Math_fround($49 * $106);
   $111 = Math_fround($49 * $108);
   $112 = Math_fround($46 - $109);
   $113 = Math_fround($48 - $110);
   $114 = Math_fround($50 - $111);
   $115 = Math_fround($47 * $98);
   $116 = Math_fround($47 * $100);
   $117 = Math_fround($47 * $102);
   $118 = Math_fround($112 - $115);
   $119 = Math_fround($113 - $116);
   $120 = Math_fround($114 - $117);
   $121 = Math_fround($45 * $92);
   $122 = Math_fround($45 * $94);
   $123 = Math_fround($45 * $96);
   $124 = Math_fround($118 - $121);
   $125 = Math_fround($119 - $122);
   $126 = Math_fround($120 - $123);
   $127 = (($7) + ($i$0760<<5)|0);
   $128 = Math_fround(HEAPF32[$127>>2]);
   $129 = ((($7) + ($i$0760<<5)|0) + 4|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = ((($7) + ($i$0760<<5)|0) + 8|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = Math_fround($130 * $90);
   $134 = Math_fround($132 * $89);
   $135 = Math_fround($133 - $134);
   $136 = Math_fround($132 * $88);
   $137 = Math_fround($128 * $90);
   $138 = Math_fround($136 - $137);
   $139 = Math_fround($128 * $89);
   $140 = Math_fround($130 * $88);
   $141 = Math_fround($139 - $140);
   $142 = Math_fround($124 + $135);
   $143 = Math_fround($125 + $138);
   $144 = Math_fround($126 + $141);
   $145 = (($iCount$0761) + 1)|0;
   $146 = (($indices) + ($iCount$0761<<2)|0);
   HEAP32[$146>>2] = $i$0760;
   $147 = ((($matrix) + ($i$0760)|0) + 64|0);
   $148 = HEAP8[$147>>0]|0;
   $149 = $148&255;
   $150 = ($148<<24>>24)==(0);
   if ($150) {
    break;
   } else {
    $34 = $89;$36 = $90;$40 = $88;$46 = $142;$48 = $143;$50 = $144;$i$0760 = $149;$iCount$0761 = $145;
   }
  }
  HEAPF32[$aZ>>2] = $142;
  HEAPF32[$18>>2] = $143;
  HEAPF32[$20>>2] = $144;
  HEAPF32[$lZ>>2] = $88;
  HEAPF32[$9>>2] = $89;
  HEAPF32[$11>>2] = $90;
  HEAPF32[$13>>2] = Math_fround(0.0);
  HEAPF32[$22>>2] = Math_fround(0.0);
  $$pre = HEAP16[$0>>1]|0;
  $152 = $$pre;$156 = $88;$160 = $89;$165 = $90;$192 = $142;$196 = $143;$201 = $144;$iCount$0$lcssa = $145;
 }
 $151 = $152&65535;
 $153 = (($matrix) + ($151)|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = Math_fround($156 * $154);
 $$sum = (($151) + 16)|0;
 $157 = (($matrix) + ($$sum)|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround($160 * $158);
 $161 = Math_fround($155 + $159);
 $$sum724 = (($151) + 32)|0;
 $162 = (($matrix) + ($$sum724)|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = Math_fround($165 * $163);
 $166 = Math_fround($161 + $164);
 $$sum725 = (($151) + 4)|0;
 $167 = (($matrix) + ($$sum725)|0);
 $168 = Math_fround(HEAPF32[$167>>2]);
 $169 = Math_fround($156 * $168);
 $$sum726 = (($151) + 20)|0;
 $170 = (($matrix) + ($$sum726)|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = Math_fround($160 * $171);
 $173 = Math_fround($169 + $172);
 $$sum727 = (($151) + 36)|0;
 $174 = (($matrix) + ($$sum727)|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = Math_fround($165 * $175);
 $177 = Math_fround($173 + $176);
 $$sum728 = (($151) + 8)|0;
 $178 = (($matrix) + ($$sum728)|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround($156 * $179);
 $$sum729 = (($151) + 24)|0;
 $181 = (($matrix) + ($$sum729)|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = Math_fround($160 * $182);
 $184 = Math_fround($180 + $183);
 $$sum730 = (($151) + 40)|0;
 $185 = (($matrix) + ($$sum730)|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = Math_fround($165 * $186);
 $188 = Math_fround($184 + $187);
 $$sum731 = (($151) + 48)|0;
 $189 = (($matrix) + ($$sum731)|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = Math_fround($192 * $190);
 $$sum732 = (($151) + 64)|0;
 $193 = (($matrix) + ($$sum732)|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround($196 * $194);
 $197 = Math_fround($191 + $195);
 $$sum733 = (($151) + 80)|0;
 $198 = (($matrix) + ($$sum733)|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = Math_fround($201 * $199);
 $202 = Math_fround($197 + $200);
 $$sum734 = (($151) + 52)|0;
 $203 = (($matrix) + ($$sum734)|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = Math_fround($192 * $204);
 $$sum735 = (($151) + 68)|0;
 $206 = (($matrix) + ($$sum735)|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = Math_fround($196 * $207);
 $209 = Math_fround($205 + $208);
 $$sum736 = (($151) + 84)|0;
 $210 = (($matrix) + ($$sum736)|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = Math_fround($201 * $211);
 $213 = Math_fround($209 + $212);
 $$sum737 = (($151) + 56)|0;
 $214 = (($matrix) + ($$sum737)|0);
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = Math_fround($192 * $215);
 $$sum738 = (($151) + 72)|0;
 $217 = (($matrix) + ($$sum738)|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 $219 = Math_fround($196 * $218);
 $220 = Math_fround($216 + $219);
 $$sum739 = (($151) + 88)|0;
 $221 = (($matrix) + ($$sum739)|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = Math_fround($201 * $222);
 $224 = Math_fround($220 + $223);
 $225 = Math_fround($166 + $202);
 $226 = Math_fround($177 + $213);
 $227 = Math_fround($188 + $224);
 $228 = Math_fround(-$225);
 $229 = Math_fround(-$226);
 $230 = Math_fround(-$227);
 $231 = Math_fround($156 * $190);
 $232 = Math_fround($160 * $204);
 $233 = Math_fround($231 + $232);
 $234 = Math_fround($165 * $215);
 $235 = Math_fround($233 + $234);
 $236 = Math_fround($156 * $194);
 $237 = Math_fround($160 * $207);
 $238 = Math_fround($236 + $237);
 $239 = Math_fround($165 * $218);
 $240 = Math_fround($238 + $239);
 $241 = Math_fround($156 * $199);
 $242 = Math_fround($160 * $211);
 $243 = Math_fround($241 + $242);
 $244 = Math_fround($165 * $222);
 $245 = Math_fround($243 + $244);
 $$sum740 = (($151) + 96)|0;
 $246 = (($matrix) + ($$sum740)|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = Math_fround($192 * $247);
 $$sum741 = (($151) + 112)|0;
 $249 = (($matrix) + ($$sum741)|0);
 $250 = Math_fround(HEAPF32[$249>>2]);
 $251 = Math_fround($196 * $250);
 $252 = Math_fround($248 + $251);
 $$sum742 = (($151) + 128)|0;
 $253 = (($matrix) + ($$sum742)|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = Math_fround($201 * $254);
 $256 = Math_fround($252 + $255);
 $$sum743 = (($151) + 100)|0;
 $257 = (($matrix) + ($$sum743)|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 $259 = Math_fround($192 * $258);
 $$sum744 = (($151) + 116)|0;
 $260 = (($matrix) + ($$sum744)|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = Math_fround($196 * $261);
 $263 = Math_fround($259 + $262);
 $$sum745 = (($151) + 132)|0;
 $264 = (($matrix) + ($$sum745)|0);
 $265 = Math_fround(HEAPF32[$264>>2]);
 $266 = Math_fround($201 * $265);
 $267 = Math_fround($263 + $266);
 $$sum746 = (($151) + 104)|0;
 $268 = (($matrix) + ($$sum746)|0);
 $269 = Math_fround(HEAPF32[$268>>2]);
 $270 = Math_fround($192 * $269);
 $$sum747 = (($151) + 120)|0;
 $271 = (($matrix) + ($$sum747)|0);
 $272 = Math_fround(HEAPF32[$271>>2]);
 $273 = Math_fround($196 * $272);
 $274 = Math_fround($270 + $273);
 $$sum748 = (($151) + 136)|0;
 $275 = (($matrix) + ($$sum748)|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 $277 = Math_fround($201 * $276);
 $278 = Math_fround($274 + $277);
 $279 = Math_fround($235 + $256);
 $280 = Math_fround($240 + $267);
 $281 = Math_fround($245 + $278);
 $282 = Math_fround(-$279);
 $283 = Math_fround(-$280);
 $284 = Math_fround(-$281);
 $285 = ($iCount$0$lcssa|0)==(0);
 if ($285) {
  $$lcssa = $230;$$lcssa749 = $229;$$lcssa750 = $228;$$lcssa751 = $284;$$lcssa752 = $283;$$lcssa753 = $282;
  HEAPF32[$agg$result>>2] = $$lcssa750;
  $446 = (($agg$result) + 4|0);
  HEAPF32[$446>>2] = $$lcssa749;
  $447 = (($agg$result) + 8|0);
  HEAPF32[$447>>2] = $$lcssa;
  $448 = (($agg$result) + 12|0);
  HEAPF32[$448>>2] = Math_fround(0.0);
  $449 = (($agg$result) + 16|0);
  HEAPF32[$449>>2] = $$lcssa753;
  $450 = (($agg$result) + 20|0);
  HEAPF32[$450>>2] = $$lcssa752;
  $451 = (($agg$result) + 24|0);
  HEAPF32[$451>>2] = $$lcssa751;
  $452 = (($agg$result) + 28|0);
  HEAPF32[$452>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 } else {
  $296 = $284;$298 = $283;$301 = $282;$308 = $228;$310 = $229;$312 = $230;$iCount$1754 = $iCount$0$lcssa;
 }
 while(1) {
  $286 = (($iCount$1754) + -1)|0;
  $287 = (($indices) + ($286<<2)|0);
  $288 = HEAP32[$287>>2]|0;
  $289 = (($7) + ($288<<5)|0);
  $290 = Math_fround(HEAPF32[$289>>2]);
  $291 = ((($7) + ($288<<5)|0) + 4|0);
  $292 = Math_fround(HEAPF32[$291>>2]);
  $293 = ((($7) + ($288<<5)|0) + 8|0);
  $294 = Math_fround(HEAPF32[$293>>2]);
  $295 = Math_fround($296 * $292);
  $297 = Math_fround($298 * $294);
  $299 = Math_fround($295 - $297);
  $300 = Math_fround($301 * $294);
  $302 = Math_fround($296 * $290);
  $303 = Math_fround($300 - $302);
  $304 = Math_fround($298 * $290);
  $305 = Math_fround($301 * $292);
  $306 = Math_fround($304 - $305);
  $307 = Math_fround($308 - $299);
  $309 = Math_fround($310 - $303);
  $311 = Math_fround($312 - $306);
  $313 = (($3) + (($288*160)|0)|0);
  $314 = Math_fround(HEAPF32[$313>>2]);
  $315 = ((($3) + (($288*160)|0)|0) + 4|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = ((($3) + (($288*160)|0)|0) + 8|0);
  $318 = Math_fround(HEAPF32[$317>>2]);
  $319 = Math_fround($314 * $307);
  $320 = Math_fround($316 * $309);
  $321 = Math_fround($319 + $320);
  $322 = Math_fround($311 * $318);
  $323 = Math_fround($322 + $321);
  $324 = ((($3) + (($288*160)|0)|0) + 32|0);
  $325 = Math_fround(HEAPF32[$324>>2]);
  $326 = ((($3) + (($288*160)|0)|0) + 36|0);
  $327 = Math_fround(HEAPF32[$326>>2]);
  $328 = ((($3) + (($288*160)|0)|0) + 40|0);
  $329 = Math_fround(HEAPF32[$328>>2]);
  $330 = Math_fround($307 * $325);
  $331 = Math_fround($309 * $327);
  $332 = Math_fround($330 + $331);
  $333 = Math_fround($311 * $329);
  $334 = Math_fround($332 + $333);
  $335 = ((($3) + (($288*160)|0)|0) + 64|0);
  $336 = Math_fround(HEAPF32[$335>>2]);
  $337 = ((($3) + (($288*160)|0)|0) + 68|0);
  $338 = Math_fround(HEAPF32[$337>>2]);
  $339 = ((($3) + (($288*160)|0)|0) + 72|0);
  $340 = Math_fround(HEAPF32[$339>>2]);
  $341 = Math_fround($307 * $336);
  $342 = Math_fround($309 * $338);
  $343 = Math_fround($341 + $342);
  $344 = Math_fround($311 * $340);
  $345 = Math_fround($343 + $344);
  $346 = ((($3) + (($288*160)|0)|0) + 16|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  $348 = ((($3) + (($288*160)|0)|0) + 20|0);
  $349 = Math_fround(HEAPF32[$348>>2]);
  $350 = ((($3) + (($288*160)|0)|0) + 24|0);
  $351 = Math_fround(HEAPF32[$350>>2]);
  $352 = Math_fround($301 * $347);
  $353 = Math_fround($298 * $349);
  $354 = Math_fround($352 + $353);
  $355 = Math_fround($296 * $351);
  $356 = Math_fround($354 + $355);
  $357 = ((($3) + (($288*160)|0)|0) + 48|0);
  $358 = Math_fround(HEAPF32[$357>>2]);
  $359 = ((($3) + (($288*160)|0)|0) + 52|0);
  $360 = Math_fround(HEAPF32[$359>>2]);
  $361 = ((($3) + (($288*160)|0)|0) + 56|0);
  $362 = Math_fround(HEAPF32[$361>>2]);
  $363 = Math_fround($301 * $358);
  $364 = Math_fround($298 * $360);
  $365 = Math_fround($363 + $364);
  $366 = Math_fround($296 * $362);
  $367 = Math_fround($365 + $366);
  $368 = ((($3) + (($288*160)|0)|0) + 80|0);
  $369 = Math_fround(HEAPF32[$368>>2]);
  $370 = ((($3) + (($288*160)|0)|0) + 84|0);
  $371 = Math_fround(HEAPF32[$370>>2]);
  $372 = ((($3) + (($288*160)|0)|0) + 88|0);
  $373 = Math_fround(HEAPF32[$372>>2]);
  $374 = Math_fround($301 * $369);
  $375 = Math_fround($298 * $371);
  $376 = Math_fround($374 + $375);
  $377 = Math_fround($296 * $373);
  $378 = Math_fround($376 + $377);
  $379 = Math_fround($323 + $356);
  $380 = Math_fround($334 + $367);
  $381 = Math_fround($345 + $378);
  $382 = (($SZ) + ($286<<4)|0);
  $383 = Math_fround(HEAPF32[$382>>2]);
  $384 = ((($SZ) + ($286<<4)|0) + 4|0);
  $385 = Math_fround(HEAPF32[$384>>2]);
  $386 = ((($SZ) + ($286<<4)|0) + 8|0);
  $387 = Math_fround(HEAPF32[$386>>2]);
  $388 = ((($3) + (($288*160)|0)|0) + 96|0);
  $389 = Math_fround(HEAPF32[$388>>2]);
  $390 = Math_fround($383 * $389);
  $391 = ((($3) + (($288*160)|0)|0) + 112|0);
  $392 = Math_fround(HEAPF32[$391>>2]);
  $393 = Math_fround($385 * $392);
  $394 = Math_fround($390 + $393);
  $395 = ((($3) + (($288*160)|0)|0) + 128|0);
  $396 = Math_fround(HEAPF32[$395>>2]);
  $397 = Math_fround($387 * $396);
  $398 = Math_fround($394 + $397);
  $399 = ((($3) + (($288*160)|0)|0) + 100|0);
  $400 = Math_fround(HEAPF32[$399>>2]);
  $401 = Math_fround($383 * $400);
  $402 = ((($3) + (($288*160)|0)|0) + 116|0);
  $403 = Math_fround(HEAPF32[$402>>2]);
  $404 = Math_fround($385 * $403);
  $405 = Math_fround($401 + $404);
  $406 = ((($3) + (($288*160)|0)|0) + 132|0);
  $407 = Math_fround(HEAPF32[$406>>2]);
  $408 = Math_fround($387 * $407);
  $409 = Math_fround($405 + $408);
  $410 = ((($3) + (($288*160)|0)|0) + 104|0);
  $411 = Math_fround(HEAPF32[$410>>2]);
  $412 = Math_fround($383 * $411);
  $413 = ((($3) + (($288*160)|0)|0) + 120|0);
  $414 = Math_fround(HEAPF32[$413>>2]);
  $415 = Math_fround($385 * $414);
  $416 = Math_fround($412 + $415);
  $417 = ((($3) + (($288*160)|0)|0) + 136|0);
  $418 = Math_fround(HEAPF32[$417>>2]);
  $419 = Math_fround($387 * $418);
  $420 = Math_fround($416 + $419);
  $421 = Math_fround($379 + $398);
  $422 = Math_fround($380 + $409);
  $423 = Math_fround($381 + $420);
  $424 = ((($7) + ($288<<5)|0) + 16|0);
  $425 = Math_fround(HEAPF32[$424>>2]);
  $426 = ((($7) + ($288<<5)|0) + 20|0);
  $427 = Math_fround(HEAPF32[$426>>2]);
  $428 = ((($7) + ($288<<5)|0) + 24|0);
  $429 = Math_fround(HEAPF32[$428>>2]);
  $430 = Math_fround($427 * $423);
  $431 = Math_fround($422 * $429);
  $432 = Math_fround($430 - $431);
  $433 = Math_fround($421 * $429);
  $434 = Math_fround($425 * $423);
  $435 = Math_fround($433 - $434);
  $436 = Math_fround($422 * $425);
  $437 = Math_fround($421 * $427);
  $438 = Math_fround($436 - $437);
  $439 = Math_fround($307 - $432);
  $440 = Math_fround($309 - $435);
  $441 = Math_fround($311 - $438);
  $442 = Math_fround($301 - $421);
  $443 = Math_fround($298 - $422);
  $444 = Math_fround($296 - $423);
  $445 = ($286|0)==(0);
  if ($445) {
   $$lcssa = $441;$$lcssa749 = $440;$$lcssa750 = $439;$$lcssa751 = $444;$$lcssa752 = $443;$$lcssa753 = $442;
   break;
  } else {
   $296 = $444;$298 = $443;$301 = $442;$308 = $439;$310 = $440;$312 = $441;$iCount$1754 = $286;
  }
 }
 HEAPF32[$agg$result>>2] = $$lcssa750;
 $446 = (($agg$result) + 4|0);
 HEAPF32[$446>>2] = $$lcssa749;
 $447 = (($agg$result) + 8|0);
 HEAPF32[$447>>2] = $$lcssa;
 $448 = (($agg$result) + 12|0);
 HEAPF32[$448>>2] = Math_fround(0.0);
 $449 = (($agg$result) + 16|0);
 HEAPF32[$449>>2] = $$lcssa753;
 $450 = (($agg$result) + 20|0);
 HEAPF32[$450>>2] = $$lcssa752;
 $451 = (($agg$result) + 24|0);
 HEAPF32[$451>>2] = $$lcssa751;
 $452 = (($agg$result) + 28|0);
 HEAPF32[$452>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper22getImpulseSelfResponseERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS4_jS6_S7_($matrix,$linkID0,$impulse0,$deltaV0,$linkID1,$impulse1,$deltaV1) {
 $matrix = $matrix|0;
 $linkID0 = $linkID0|0;
 $impulse0 = $impulse0|0;
 $deltaV0 = $deltaV0|0;
 $linkID1 = $linkID1|0;
 $impulse1 = $impulse1|0;
 $deltaV1 = $deltaV1|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0;
 var $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0);
 var $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0);
 var $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0);
 var $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0);
 var $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 80|0;
 $$byval_copy = sp;
 $0 = sp + 16|0;
 $1 = sp + 48|0;
 $2 = sp + 64|0;
 $3 = (($matrix) + 26|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $$sum$i = (($5) + 144)|0;
 $6 = (($matrix) + ($$sum$i)|0);
 $7 = (($matrix) + 10|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $10 = (($matrix) + ($9)|0);
 $11 = ((($matrix) + ($linkID1)|0) + 64|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ($13|0)==($linkID0|0);
 if ($14) {
  $15 = Math_fround(HEAPF32[$impulse1>>2]);
  $16 = (($impulse1) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($impulse1) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround(-$15);
  $21 = Math_fround(-$17);
  $22 = Math_fround(-$19);
  $23 = (($impulse1) + 16|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($impulse1) + 20|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($impulse1) + 24|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround(-$24);
  $30 = Math_fround(-$26);
  $31 = Math_fround(-$28);
  $32 = ((($10) + ($linkID1<<5)|0) + 16|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = ((($10) + ($linkID1<<5)|0) + 20|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = ((($10) + ($linkID1<<5)|0) + 24|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($37 * $21);
  $39 = Math_fround($35 * $22);
  $40 = Math_fround($38 - $39);
  $41 = Math_fround($33 * $22);
  $42 = Math_fround($37 * $20);
  $43 = Math_fround($41 - $42);
  $44 = Math_fround($35 * $20);
  $45 = Math_fround($33 * $21);
  $46 = Math_fround($44 - $45);
  $47 = Math_fround($40 - $24);
  $48 = Math_fround($43 - $26);
  $49 = Math_fround($46 - $28);
  $50 = (($6) + (($linkID1*160)|0)|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = ((($6) + (($linkID1*160)|0)|0) + 4|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = ((($6) + (($linkID1*160)|0)|0) + 8|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = ((($6) + (($linkID1*160)|0)|0) + 32|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = ((($6) + (($linkID1*160)|0)|0) + 36|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($6) + (($linkID1*160)|0)|0) + 40|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = ((($6) + (($linkID1*160)|0)|0) + 64|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = ((($6) + (($linkID1*160)|0)|0) + 68|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($6) + (($linkID1*160)|0)|0) + 72|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($49 * $63);
  $69 = Math_fround($49 * $65);
  $70 = Math_fround($49 * $67);
  $71 = Math_fround($48 * $57);
  $72 = Math_fround($48 * $59);
  $73 = Math_fround($48 * $61);
  $74 = Math_fround($71 + $68);
  $75 = Math_fround($72 + $69);
  $76 = Math_fround($73 + $70);
  $77 = Math_fround($51 * $47);
  $78 = Math_fround($53 * $47);
  $79 = Math_fround($55 * $47);
  $80 = Math_fround($77 + $74);
  $81 = Math_fround($78 + $75);
  $82 = Math_fround($79 + $76);
  $83 = Math_fround($20 - $80);
  $84 = Math_fround($21 - $81);
  $85 = Math_fround($22 - $82);
  $86 = ((($6) + (($linkID1*160)|0)|0) + 16|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = ((($6) + (($linkID1*160)|0)|0) + 20|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = ((($6) + (($linkID1*160)|0)|0) + 24|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = ((($6) + (($linkID1*160)|0)|0) + 48|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = ((($6) + (($linkID1*160)|0)|0) + 52|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = ((($6) + (($linkID1*160)|0)|0) + 56|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = ((($6) + (($linkID1*160)|0)|0) + 80|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = ((($6) + (($linkID1*160)|0)|0) + 84|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $102 = ((($6) + (($linkID1*160)|0)|0) + 88|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = Math_fround($49 * $99);
  $105 = Math_fround($49 * $101);
  $106 = Math_fround($49 * $103);
  $107 = Math_fround($48 * $93);
  $108 = Math_fround($48 * $95);
  $109 = Math_fround($48 * $97);
  $110 = Math_fround($107 + $104);
  $111 = Math_fround($108 + $105);
  $112 = Math_fround($109 + $106);
  $113 = Math_fround($47 * $87);
  $114 = Math_fround($47 * $89);
  $115 = Math_fround($47 * $91);
  $116 = Math_fround($113 + $110);
  $117 = Math_fround($114 + $111);
  $118 = Math_fround($115 + $112);
  $119 = Math_fround($29 - $116);
  $120 = Math_fround($30 - $117);
  $121 = Math_fround($31 - $118);
  $122 = (($10) + ($linkID1<<5)|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = ((($10) + ($linkID1<<5)|0) + 4|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = ((($10) + ($linkID1<<5)|0) + 8|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = Math_fround($85 * $125);
  $129 = Math_fround($84 * $127);
  $130 = Math_fround($128 - $129);
  $131 = Math_fround($83 * $127);
  $132 = Math_fround($85 * $123);
  $133 = Math_fround($131 - $132);
  $134 = Math_fround($84 * $123);
  $135 = Math_fround($83 * $125);
  $136 = Math_fround($134 - $135);
  $137 = Math_fround($119 + $130);
  $138 = Math_fround($120 + $133);
  $139 = Math_fround($121 + $136);
  $140 = Math_fround(HEAPF32[$impulse0>>2]);
  $141 = (($impulse0) + 4|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($impulse0) + 8|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = Math_fround($140 - $83);
  $146 = Math_fround($142 - $84);
  $147 = Math_fround($144 - $85);
  $148 = (($impulse0) + 16|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = (($impulse0) + 20|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = (($impulse0) + 24|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  $154 = Math_fround($149 - $137);
  $155 = Math_fround($151 - $138);
  $156 = Math_fround($153 - $139);
  HEAPF32[$1>>2] = $145;
  $157 = (($1) + 4|0);
  HEAPF32[$157>>2] = $146;
  $158 = (($1) + 8|0);
  HEAPF32[$158>>2] = $147;
  $159 = (($1) + 12|0);
  HEAPF32[$159>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = $154;
  $160 = (($2) + 4|0);
  HEAPF32[$160>>2] = $155;
  $161 = (($2) + 8|0);
  HEAPF32[$161>>2] = $156;
  $162 = (($2) + 12|0);
  HEAPF32[$162>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$2+12>>2]|0;
  __ZN5physx12_GLOBAL__N_122getImpulseResponseSimdERKNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES6_($0,$matrix,$linkID0,$$byval_copy,$$byval_copy1);
  ;HEAP32[$deltaV0+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$deltaV0+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$deltaV0+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$deltaV0+12>>2]=HEAP32[$0+12>>2]|0;
  $163 = (($deltaV0) + 16|0);
  $164 = (($0) + 16|0);
  ;HEAP32[$163+0>>2]=HEAP32[$164+0>>2]|0;HEAP32[$163+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$164+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$164+12>>2]|0;
  $165 = (($deltaV0) + 16|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($deltaV0) + 20|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($deltaV0) + 24|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround(HEAPF32[$deltaV0>>2]);
  $172 = (($deltaV0) + 4|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = (($deltaV0) + 8|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = Math_fround(HEAPF32[$122>>2]);
  $177 = Math_fround(HEAPF32[$124>>2]);
  $178 = Math_fround(HEAPF32[$126>>2]);
  $179 = Math_fround($170 * $177);
  $180 = Math_fround($168 * $178);
  $181 = Math_fround($179 - $180);
  $182 = Math_fround($166 * $178);
  $183 = Math_fround($170 * $176);
  $184 = Math_fround($182 - $183);
  $185 = Math_fround($168 * $176);
  $186 = Math_fround($166 * $177);
  $187 = Math_fround($185 - $186);
  $188 = Math_fround($171 - $181);
  $189 = Math_fround($173 - $184);
  $190 = Math_fround($175 - $187);
  $191 = Math_fround(HEAPF32[$50>>2]);
  $192 = Math_fround(HEAPF32[$52>>2]);
  $193 = Math_fround(HEAPF32[$54>>2]);
  $194 = Math_fround($191 * $188);
  $195 = Math_fround($192 * $189);
  $196 = Math_fround($194 + $195);
  $197 = Math_fround($190 * $193);
  $198 = Math_fround($197 + $196);
  $199 = Math_fround(HEAPF32[$56>>2]);
  $200 = Math_fround(HEAPF32[$58>>2]);
  $201 = Math_fround(HEAPF32[$60>>2]);
  $202 = Math_fround($188 * $199);
  $203 = Math_fround($189 * $200);
  $204 = Math_fround($202 + $203);
  $205 = Math_fround($190 * $201);
  $206 = Math_fround($204 + $205);
  $207 = Math_fround(HEAPF32[$62>>2]);
  $208 = Math_fround(HEAPF32[$64>>2]);
  $209 = Math_fround(HEAPF32[$66>>2]);
  $210 = Math_fround($188 * $207);
  $211 = Math_fround($189 * $208);
  $212 = Math_fround($210 + $211);
  $213 = Math_fround($190 * $209);
  $214 = Math_fround($212 + $213);
  $215 = Math_fround(HEAPF32[$86>>2]);
  $216 = Math_fround(HEAPF32[$88>>2]);
  $217 = Math_fround(HEAPF32[$90>>2]);
  $218 = Math_fround($166 * $215);
  $219 = Math_fround($168 * $216);
  $220 = Math_fround($218 + $219);
  $221 = Math_fround($170 * $217);
  $222 = Math_fround($220 + $221);
  $223 = Math_fround(HEAPF32[$92>>2]);
  $224 = Math_fround(HEAPF32[$94>>2]);
  $225 = Math_fround(HEAPF32[$96>>2]);
  $226 = Math_fround($166 * $223);
  $227 = Math_fround($168 * $224);
  $228 = Math_fround($226 + $227);
  $229 = Math_fround($170 * $225);
  $230 = Math_fround($228 + $229);
  $231 = Math_fround(HEAPF32[$98>>2]);
  $232 = Math_fround(HEAPF32[$100>>2]);
  $233 = Math_fround(HEAPF32[$102>>2]);
  $234 = Math_fround($166 * $231);
  $235 = Math_fround($168 * $232);
  $236 = Math_fround($234 + $235);
  $237 = Math_fround($170 * $233);
  $238 = Math_fround($236 + $237);
  $239 = Math_fround($198 + $222);
  $240 = Math_fround($206 + $230);
  $241 = Math_fround($214 + $238);
  $242 = ((($6) + (($linkID1*160)|0)|0) + 96|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = Math_fround($47 * $243);
  $245 = ((($6) + (($linkID1*160)|0)|0) + 112|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround($48 * $246);
  $248 = Math_fround($244 + $247);
  $249 = ((($6) + (($linkID1*160)|0)|0) + 128|0);
  $250 = Math_fround(HEAPF32[$249>>2]);
  $251 = Math_fround($49 * $250);
  $252 = Math_fround($248 + $251);
  $253 = ((($6) + (($linkID1*160)|0)|0) + 100|0);
  $254 = Math_fround(HEAPF32[$253>>2]);
  $255 = Math_fround($47 * $254);
  $256 = ((($6) + (($linkID1*160)|0)|0) + 116|0);
  $257 = Math_fround(HEAPF32[$256>>2]);
  $258 = Math_fround($48 * $257);
  $259 = Math_fround($255 + $258);
  $260 = ((($6) + (($linkID1*160)|0)|0) + 132|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = Math_fround($49 * $261);
  $263 = Math_fround($259 + $262);
  $264 = ((($6) + (($linkID1*160)|0)|0) + 104|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = Math_fround($47 * $265);
  $267 = ((($6) + (($linkID1*160)|0)|0) + 120|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = Math_fround($48 * $268);
  $270 = Math_fround($266 + $269);
  $271 = ((($6) + (($linkID1*160)|0)|0) + 136|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = Math_fround($49 * $272);
  $274 = Math_fround($270 + $273);
  $275 = Math_fround($239 + $252);
  $276 = Math_fround($240 + $263);
  $277 = Math_fround($241 + $274);
  $278 = Math_fround(HEAPF32[$32>>2]);
  $279 = Math_fround(HEAPF32[$34>>2]);
  $280 = Math_fround(HEAPF32[$36>>2]);
  $281 = Math_fround($279 * $277);
  $282 = Math_fround($276 * $280);
  $283 = Math_fround($281 - $282);
  $284 = Math_fround($275 * $280);
  $285 = Math_fround($278 * $277);
  $286 = Math_fround($284 - $285);
  $287 = Math_fround($276 * $278);
  $288 = Math_fround($275 * $279);
  $289 = Math_fround($287 - $288);
  $290 = Math_fround($188 - $283);
  $291 = Math_fround($189 - $286);
  $292 = Math_fround($190 - $289);
  $293 = Math_fround($166 - $275);
  $294 = Math_fround($168 - $276);
  $295 = Math_fround($170 - $277);
  HEAPF32[$deltaV1>>2] = $290;
  $296 = (($deltaV1) + 4|0);
  HEAPF32[$296>>2] = $291;
  $297 = (($deltaV1) + 8|0);
  HEAPF32[$297>>2] = $292;
  $298 = (($deltaV1) + 12|0);
  HEAPF32[$298>>2] = Math_fround(0.0);
  $299 = (($deltaV1) + 16|0);
  HEAPF32[$299>>2] = $293;
  $300 = (($deltaV1) + 20|0);
  HEAPF32[$300>>2] = $294;
  $301 = (($deltaV1) + 24|0);
  HEAPF32[$301>>2] = $295;
  $302 = (($deltaV1) + 28|0);
  HEAPF32[$302>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 } else {
  __ZN5physx22getImpulseResponseSlowERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS3_jS5_S6_($matrix,$linkID0,$impulse0,$deltaV0,$linkID1,$impulse1,$deltaV1);
  STACKTOP = sp;return;
 }
}
function __ZN5physx15PxcLtbComputeJvEPNS_6shdfnd3aos5Vec3VERKNS_9PxcFsDataEPKNS_14PxcSIMDSpatialE($jv,$m,$velocity) {
 $jv = $jv|0;
 $m = $m|0;
 $velocity = $velocity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, $i$0120 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($m) + 10|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = (($m) + ($2)|0);
 $4 = (($m) + 8|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = ($5&65535)>(1);
 if ($6) {
  $i$0120 = 1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $7 = ((($m) + ($i$0120)|0) + 64|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = $8&255;
  $10 = (($velocity) + ($9<<5)|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = ((($velocity) + ($9<<5)|0) + 4|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = ((($velocity) + ($9<<5)|0) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = ((($velocity) + ($9<<5)|0) + 16|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = ((($velocity) + ($9<<5)|0) + 20|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = ((($velocity) + ($9<<5)|0) + 24|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($velocity) + ($i$0120<<5)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = ((($velocity) + ($i$0120<<5)|0) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($velocity) + ($i$0120<<5)|0) + 8|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = ((($velocity) + ($i$0120<<5)|0) + 16|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = ((($velocity) + ($i$0120<<5)|0) + 20|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = ((($velocity) + ($i$0120<<5)|0) + 24|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = ((($3) + ($i$0120<<5)|0) + 16|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = ((($3) + ($i$0120<<5)|0) + 20|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = ((($3) + ($i$0120<<5)|0) + 24|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($3) + ($i$0120<<5)|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = ((($3) + ($i$0120<<5)|0) + 4|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = ((($3) + ($i$0120<<5)|0) + 8|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($35 + $41);
  $47 = Math_fround($37 + $43);
  $48 = Math_fround($39 + $45);
  $49 = Math_fround($19 * $48);
  $50 = Math_fround($21 * $47);
  $51 = Math_fround($49 - $50);
  $52 = Math_fround($21 * $46);
  $53 = Math_fround($17 * $48);
  $54 = Math_fround($52 - $53);
  $55 = Math_fround($17 * $47);
  $56 = Math_fround($19 * $46);
  $57 = Math_fround($55 - $56);
  $58 = Math_fround($11 + $51);
  $59 = Math_fround($13 + $54);
  $60 = Math_fround($15 + $57);
  $61 = Math_fround($31 * $39);
  $62 = Math_fround($33 * $37);
  $63 = Math_fround($61 - $62);
  $64 = Math_fround($33 * $35);
  $65 = Math_fround($29 * $39);
  $66 = Math_fround($64 - $65);
  $67 = Math_fround($29 * $37);
  $68 = Math_fround($31 * $35);
  $69 = Math_fround($67 - $68);
  $70 = Math_fround($23 + $63);
  $71 = Math_fround($25 + $66);
  $72 = Math_fround($27 + $69);
  $73 = Math_fround($58 - $70);
  $74 = Math_fround($59 - $71);
  $75 = Math_fround($60 - $72);
  $76 = (($jv) + ($i$0120<<4)|0);
  HEAPF32[$76>>2] = $73;
  $77 = ((($jv) + ($i$0120<<4)|0) + 4|0);
  HEAPF32[$77>>2] = $74;
  $78 = ((($jv) + ($i$0120<<4)|0) + 8|0);
  HEAPF32[$78>>2] = $75;
  $79 = ((($jv) + ($i$0120<<4)|0) + 12|0);
  HEAPF32[$79>>2] = Math_fround(0.0);
  $80 = (($i$0120) + 1)|0;
  $81 = HEAP16[$4>>1]|0;
  $82 = $81&65535;
  $83 = ($80>>>0)<($82>>>0);
  if ($83) {
   $i$0120 = $80;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE($d) {
 $d = $d|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1024|0;
 $b = sp;
 $0 = HEAP32[$d>>2]|0;
 $1 = (($0) + 128|0);
 __ZN5physx18PxcFsFlushVelocityERNS_9PxcFsDataE($0);
 $2 = (($0) + 8|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(0);
 if (!($4)) {
  $5 = (($d) + 8|0);
  $i$01 = 0;
  while(1) {
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + ($i$01<<5)|0);
   $8 = (($1) + ($i$01<<5)|0);
   ;HEAP32[$7+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$8+12>>2]|0;
   $9 = ((($6) + ($i$01<<5)|0) + 16|0);
   $10 = ((($1) + ($i$01<<5)|0) + 16|0);
   ;HEAP32[$9+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$10+12>>2]|0;
   $11 = (($i$01) + 1)|0;
   $12 = HEAP16[$2>>1]|0;
   $13 = $12&65535;
   $14 = ($11>>>0)<($13>>>0);
   if ($14) {
    $i$01 = $11;
   } else {
    break;
   }
  }
 }
 __ZN5physx15PxcLtbComputeJvEPNS_6shdfnd3aos5Vec3VERKNS_9PxcFsDataEPKNS_14PxcSIMDSpatialE($b,$0,$1);
 __ZN5physx13PxcLtbProjectERKNS_9PxcFsDataEPNS_14PxcSIMDSpatialEPNS_6shdfnd3aos5Vec3VE($0,$1,$b);
 STACKTOP = sp;return;
}
function __ZN5physx26PxcFsComputeJointLoadsSimdERKNS_9PxcFsDataEPKNS_12PxcFsInertiaEPNS_6shdfnd3aos6Mat33VEPKfjjNS_21PxcFsScratchAllocatorE($matrix,$baseInertia,$load,$isf_,$linkCount,$maxIterations,$allocator) {
 $matrix = $matrix|0;
 $baseInertia = $baseInertia|0;
 $load = $load|0;
 $isf_ = $isf_|0;
 $linkCount = $linkCount|0;
 $maxIterations = $maxIterations|0;
 $allocator = $allocator|0;
 var $$byval_copy3 = 0, $$in = 0, $$sroa$146 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0;
 var $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0);
 var $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0);
 var $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0;
 var $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0;
 var $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0;
 var $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = Math_fround(0);
 var $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = 0;
 var $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = Math_fround(0);
 var $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = Math_fround(0), $482 = 0, $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = 0;
 var $491 = Math_fround(0), $492 = 0, $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0), $504 = 0, $505 = Math_fround(0), $506 = 0, $507 = Math_fround(0), $508 = Math_fround(0);
 var $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = 0, $517 = Math_fround(0), $518 = 0, $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond66 = 0, $exitcond67 = 0, $exitcond68 = 0, $i$064 = 0, $i1$061 = 0, $i3$057$us = 0, $isf = 0, $parent = 0, $tmp = 0, $tmp1$i = 0, $tmp5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2208|0;
 $$byval_copy3 = sp + 640|0;
 $isf = sp + 656|0;
 $$sroa$146 = sp + 2192|0;
 $parent = sp + 1680|0;
 $tmp = sp + 496|0;
 $0 = sp + 352|0;
 $1 = sp + 160|0;
 $2 = sp + 144|0;
 $tmp5 = sp;
 $3 = sp + 304|0;
 $4 = ($maxIterations|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = ($linkCount>>>0)>(1);
 if ($5) {
  $i$064 = 1;
  while(1) {
   $6 = (($isf_) + ($i$064<<2)|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = (($isf) + ($i$064<<4)|0);
   HEAPF32[$8>>2] = $7;
   $9 = ((($isf) + ($i$064<<4)|0) + 4|0);
   ;HEAP32[$9+0>>2]=HEAP32[$$sroa$146+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$$sroa$146+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$$sroa$146+8>>2]|0;
   $10 = (($i$064) + 1)|0;
   $exitcond67 = ($10|0)==($linkCount|0);
   if ($exitcond67) {
    break;
   } else {
    $i$064 = $10;
   }
  }
 }
 $11 = HEAP32[$allocator>>2]|0;
 $12 = (($allocator) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + ($13)|0);
 $15 = ($linkCount*144)|0;
 $16 = (($13) + ($15))|0;
 $17 = (($11) + ($16)|0);
 $18 = (($16) + ($15))|0;
 HEAP32[$12>>2] = $18;
 $19 = (($matrix) + 24|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = $20&65535;
 $22 = (($matrix) + 8|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = $23&65535;
 $tmp1$i = ($24*432)|0;
 $$sum$i = (($tmp1$i) + ($21))|0;
 $25 = (($matrix) + ($$sum$i)|0);
 $26 = (($matrix) + 10|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = $27&65535;
 $29 = (($matrix) + ($28)|0);
 $30 = ($linkCount|0)==(0);
 if (!($30)) {
  $i1$061 = 0;
  while(1) {
   $548 = ((($matrix) + ($i1$061)|0) + 64|0);
   $549 = HEAP8[$548>>0]|0;
   $550 = $549&255;
   $551 = (($parent) + ($i1$061<<3)|0);
   $552 = $551;
   $553 = $552;
   HEAP32[$553>>2] = $550;
   $554 = (($552) + 4)|0;
   $555 = $554;
   HEAP32[$555>>2] = 0;
   $556 = (($i1$061) + 1)|0;
   $exitcond66 = ($556|0)==($linkCount|0);
   if ($exitcond66) {
    break;
   } else {
    $i1$061 = $556;
   }
  }
 }
 $31 = (($maxIterations) + -1)|0;
 $32 = (($2) + 4|0);
 $33 = (($2) + 8|0);
 $34 = (($2) + 12|0);
 $35 = (($1) + 4|0);
 $36 = (($1) + 8|0);
 $37 = (($1) + 16|0);
 $38 = (($1) + 20|0);
 $39 = (($1) + 24|0);
 $40 = (($1) + 32|0);
 $41 = (($1) + 36|0);
 $42 = (($1) + 40|0);
 $43 = (($1) + 48|0);
 $44 = (($1) + 52|0);
 $45 = (($1) + 56|0);
 $46 = (($1) + 64|0);
 $47 = (($1) + 68|0);
 $48 = (($1) + 72|0);
 $49 = (($1) + 80|0);
 $50 = (($1) + 84|0);
 $51 = (($1) + 88|0);
 $52 = (($1) + 96|0);
 $53 = (($1) + 100|0);
 $54 = (($1) + 104|0);
 $55 = (($1) + 112|0);
 $56 = (($1) + 116|0);
 $57 = (($1) + 120|0);
 $58 = (($1) + 128|0);
 $59 = (($1) + 132|0);
 $60 = (($1) + 136|0);
 $61 = (($tmp) + 4|0);
 $62 = (($tmp) + 8|0);
 $63 = (($tmp) + 12|0);
 $64 = (($tmp) + 16|0);
 $65 = (($tmp) + 20|0);
 $66 = (($tmp) + 24|0);
 $67 = (($tmp) + 28|0);
 $68 = (($tmp) + 32|0);
 $69 = (($tmp) + 36|0);
 $70 = (($tmp) + 40|0);
 $71 = (($tmp) + 44|0);
 $72 = (($tmp) + 48|0);
 $73 = (($tmp) + 52|0);
 $74 = (($tmp) + 56|0);
 $75 = (($tmp) + 60|0);
 $76 = (($tmp) + 64|0);
 $77 = (($tmp) + 68|0);
 $78 = (($tmp) + 72|0);
 $79 = (($tmp) + 76|0);
 $80 = (($tmp) + 80|0);
 $81 = (($tmp) + 84|0);
 $82 = (($tmp) + 88|0);
 $83 = (($tmp) + 92|0);
 $84 = (($tmp) + 96|0);
 $85 = (($tmp) + 100|0);
 $86 = (($tmp) + 104|0);
 $87 = (($tmp) + 108|0);
 $88 = (($tmp) + 112|0);
 $89 = (($tmp) + 116|0);
 $90 = (($tmp) + 120|0);
 $91 = (($tmp) + 124|0);
 $92 = (($tmp) + 128|0);
 $93 = (($tmp) + 132|0);
 $94 = (($tmp) + 136|0);
 $95 = (($tmp) + 140|0);
 $96 = (($tmp5) + 4|0);
 $97 = (($tmp5) + 8|0);
 $98 = (($tmp5) + 16|0);
 $99 = (($tmp5) + 20|0);
 $100 = (($tmp5) + 24|0);
 $101 = (($tmp5) + 32|0);
 $102 = (($tmp5) + 36|0);
 $103 = (($tmp5) + 40|0);
 $104 = (($tmp5) + 48|0);
 $105 = (($tmp5) + 52|0);
 $106 = (($tmp5) + 56|0);
 $107 = (($tmp5) + 64|0);
 $108 = (($tmp5) + 68|0);
 $109 = (($tmp5) + 72|0);
 $110 = (($tmp5) + 80|0);
 $111 = (($tmp5) + 84|0);
 $112 = (($tmp5) + 88|0);
 $113 = (($tmp5) + 96|0);
 $114 = (($tmp5) + 100|0);
 $115 = (($tmp5) + 104|0);
 $116 = (($tmp5) + 112|0);
 $117 = (($tmp5) + 116|0);
 $118 = (($tmp5) + 120|0);
 $119 = (($tmp5) + 128|0);
 $120 = (($tmp5) + 132|0);
 $121 = (($tmp5) + 136|0);
 $122 = (($0) + 4|0);
 $123 = (($0) + 8|0);
 $124 = (($0) + 16|0);
 $125 = (($0) + 20|0);
 $126 = (($0) + 24|0);
 $127 = (($0) + 32|0);
 $128 = (($0) + 36|0);
 $129 = (($0) + 40|0);
 $130 = (($0) + 48|0);
 $131 = (($0) + 52|0);
 $132 = (($0) + 56|0);
 $133 = (($0) + 64|0);
 $134 = (($0) + 68|0);
 $135 = (($0) + 72|0);
 $136 = (($0) + 80|0);
 $137 = (($0) + 84|0);
 $138 = (($0) + 88|0);
 $139 = (($0) + 96|0);
 $140 = (($0) + 100|0);
 $141 = (($0) + 104|0);
 $142 = (($0) + 112|0);
 $143 = (($0) + 116|0);
 $144 = (($0) + 120|0);
 $145 = (($0) + 128|0);
 $146 = (($0) + 132|0);
 $147 = (($0) + 136|0);
 $148 = (($tmp) + 16|0);
 $149 = (($tmp) + 32|0);
 $150 = (($tmp) + 48|0);
 $151 = (($tmp) + 64|0);
 $152 = (($tmp) + 80|0);
 $153 = (($tmp) + 96|0);
 $154 = (($tmp) + 112|0);
 $155 = (($tmp) + 128|0);
 if ($5) {
  $546 = $31;
 } else {
  $558 = $31;
  while(1) {
   _memcpy(($14|0),($baseInertia|0),($15|0))|0;
   $557 = (($558) + -1)|0;
   $559 = ($558|0)==(0);
   if ($559) {
    break;
   } else {
    $558 = $557;
   }
  }
  STACKTOP = sp;return;
 }
 while(1) {
  _memcpy(($14|0),($baseInertia|0),($15|0))|0;
  $$in = $linkCount;
  while(1) {
   $402 = (($$in) + -1)|0;
   $403 = (($$in) + -2)|0;
   $404 = (($load) + (($403*48)|0)|0);
   $405 = (($29) + ($403<<5)|0);
   $406 = (($25) + (($402*96)|0)|0);
   $407 = (($14) + (($402*144)|0)|0);
   $408 = (($load) + (($402*48)|0)|0);
   $409 = (($isf) + ($402<<4)|0);
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$409+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$409+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$409+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$409+12>>2]|0;
   __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE9propagateERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialERKNS_6shdfnd3aos6Mat33VENSA_6FloatVE($tmp,$407,$406,$408,$$byval_copy3);
   $410 = (($parent) + ($402<<3)|0);
   $411 = $410;
   $412 = $411;
   $413 = HEAP32[$412>>2]|0;
   $414 = (($411) + 4)|0;
   $415 = $414;
   $416 = HEAP32[$415>>2]|0;
   $417 = (($29) + ($402<<5)|0);
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$417+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$417+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$417+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$417+12>>2]|0;
   __ZN5physx26PxcArticulationFnsSimdBase16translateInertiaENS_6shdfnd3aos5Vec3VERKNS_12PxcFsInertiaE($0,$$byval_copy3,$tmp);
   $418 = (($14) + (($413*144)|0)|0);
   $419 = Math_fround(HEAPF32[$418>>2]);
   $420 = ((($14) + (($413*144)|0)|0) + 4|0);
   $421 = Math_fround(HEAPF32[$420>>2]);
   $422 = ((($14) + (($413*144)|0)|0) + 8|0);
   $423 = Math_fround(HEAPF32[$422>>2]);
   $424 = Math_fround(HEAPF32[$0>>2]);
   $425 = Math_fround(HEAPF32[$122>>2]);
   $426 = Math_fround(HEAPF32[$123>>2]);
   $427 = Math_fround($419 + $424);
   $428 = Math_fround($421 + $425);
   $429 = Math_fround($423 + $426);
   $430 = ((($14) + (($413*144)|0)|0) + 16|0);
   $431 = Math_fround(HEAPF32[$430>>2]);
   $432 = ((($14) + (($413*144)|0)|0) + 20|0);
   $433 = Math_fround(HEAPF32[$432>>2]);
   $434 = ((($14) + (($413*144)|0)|0) + 24|0);
   $435 = Math_fround(HEAPF32[$434>>2]);
   $436 = Math_fround(HEAPF32[$124>>2]);
   $437 = Math_fround(HEAPF32[$125>>2]);
   $438 = Math_fround(HEAPF32[$126>>2]);
   $439 = Math_fround($431 + $436);
   $440 = Math_fround($433 + $437);
   $441 = Math_fround($435 + $438);
   $442 = ((($14) + (($413*144)|0)|0) + 32|0);
   $443 = Math_fround(HEAPF32[$442>>2]);
   $444 = ((($14) + (($413*144)|0)|0) + 36|0);
   $445 = Math_fround(HEAPF32[$444>>2]);
   $446 = ((($14) + (($413*144)|0)|0) + 40|0);
   $447 = Math_fround(HEAPF32[$446>>2]);
   $448 = Math_fround(HEAPF32[$127>>2]);
   $449 = Math_fround(HEAPF32[$128>>2]);
   $450 = Math_fround(HEAPF32[$129>>2]);
   $451 = Math_fround($443 + $448);
   $452 = Math_fround($445 + $449);
   $453 = Math_fround($447 + $450);
   $454 = ((($14) + (($413*144)|0)|0) + 48|0);
   $455 = Math_fround(HEAPF32[$454>>2]);
   $456 = ((($14) + (($413*144)|0)|0) + 52|0);
   $457 = Math_fround(HEAPF32[$456>>2]);
   $458 = ((($14) + (($413*144)|0)|0) + 56|0);
   $459 = Math_fround(HEAPF32[$458>>2]);
   $460 = Math_fround(HEAPF32[$130>>2]);
   $461 = Math_fround(HEAPF32[$131>>2]);
   $462 = Math_fround(HEAPF32[$132>>2]);
   $463 = Math_fround($455 + $460);
   $464 = Math_fround($457 + $461);
   $465 = Math_fround($459 + $462);
   $466 = ((($14) + (($413*144)|0)|0) + 64|0);
   $467 = Math_fround(HEAPF32[$466>>2]);
   $468 = ((($14) + (($413*144)|0)|0) + 68|0);
   $469 = Math_fround(HEAPF32[$468>>2]);
   $470 = ((($14) + (($413*144)|0)|0) + 72|0);
   $471 = Math_fround(HEAPF32[$470>>2]);
   $472 = Math_fround(HEAPF32[$133>>2]);
   $473 = Math_fround(HEAPF32[$134>>2]);
   $474 = Math_fround(HEAPF32[$135>>2]);
   $475 = Math_fround($467 + $472);
   $476 = Math_fround($469 + $473);
   $477 = Math_fround($471 + $474);
   $478 = ((($14) + (($413*144)|0)|0) + 80|0);
   $479 = Math_fround(HEAPF32[$478>>2]);
   $480 = ((($14) + (($413*144)|0)|0) + 84|0);
   $481 = Math_fround(HEAPF32[$480>>2]);
   $482 = ((($14) + (($413*144)|0)|0) + 88|0);
   $483 = Math_fround(HEAPF32[$482>>2]);
   $484 = Math_fround(HEAPF32[$136>>2]);
   $485 = Math_fround(HEAPF32[$137>>2]);
   $486 = Math_fround(HEAPF32[$138>>2]);
   $487 = Math_fround($479 + $484);
   $488 = Math_fround($481 + $485);
   $489 = Math_fround($483 + $486);
   $490 = ((($14) + (($413*144)|0)|0) + 96|0);
   $491 = Math_fround(HEAPF32[$490>>2]);
   $492 = ((($14) + (($413*144)|0)|0) + 100|0);
   $493 = Math_fround(HEAPF32[$492>>2]);
   $494 = ((($14) + (($413*144)|0)|0) + 104|0);
   $495 = Math_fround(HEAPF32[$494>>2]);
   $496 = Math_fround(HEAPF32[$139>>2]);
   $497 = Math_fround(HEAPF32[$140>>2]);
   $498 = Math_fround(HEAPF32[$141>>2]);
   $499 = Math_fround($491 + $496);
   $500 = Math_fround($493 + $497);
   $501 = Math_fround($495 + $498);
   $502 = ((($14) + (($413*144)|0)|0) + 112|0);
   $503 = Math_fround(HEAPF32[$502>>2]);
   $504 = ((($14) + (($413*144)|0)|0) + 116|0);
   $505 = Math_fround(HEAPF32[$504>>2]);
   $506 = ((($14) + (($413*144)|0)|0) + 120|0);
   $507 = Math_fround(HEAPF32[$506>>2]);
   $508 = Math_fround(HEAPF32[$142>>2]);
   $509 = Math_fround(HEAPF32[$143>>2]);
   $510 = Math_fround(HEAPF32[$144>>2]);
   $511 = Math_fround($503 + $508);
   $512 = Math_fround($505 + $509);
   $513 = Math_fround($507 + $510);
   $514 = ((($14) + (($413*144)|0)|0) + 128|0);
   $515 = Math_fround(HEAPF32[$514>>2]);
   $516 = ((($14) + (($413*144)|0)|0) + 132|0);
   $517 = Math_fround(HEAPF32[$516>>2]);
   $518 = ((($14) + (($413*144)|0)|0) + 136|0);
   $519 = Math_fround(HEAPF32[$518>>2]);
   $520 = Math_fround(HEAPF32[$145>>2]);
   $521 = Math_fround(HEAPF32[$146>>2]);
   $522 = Math_fround(HEAPF32[$147>>2]);
   $523 = Math_fround($515 + $520);
   $524 = Math_fround($517 + $521);
   $525 = Math_fround($519 + $522);
   HEAPF32[$418>>2] = $427;
   HEAPF32[$420>>2] = $428;
   HEAPF32[$422>>2] = $429;
   $526 = ((($14) + (($413*144)|0)|0) + 12|0);
   HEAPF32[$526>>2] = Math_fround(0.0);
   HEAPF32[$430>>2] = $439;
   HEAPF32[$432>>2] = $440;
   HEAPF32[$434>>2] = $441;
   $527 = ((($14) + (($413*144)|0)|0) + 28|0);
   HEAPF32[$527>>2] = Math_fround(0.0);
   HEAPF32[$442>>2] = $451;
   HEAPF32[$444>>2] = $452;
   HEAPF32[$446>>2] = $453;
   $528 = ((($14) + (($413*144)|0)|0) + 44|0);
   HEAPF32[$528>>2] = Math_fround(0.0);
   HEAPF32[$454>>2] = $463;
   HEAPF32[$456>>2] = $464;
   HEAPF32[$458>>2] = $465;
   $529 = ((($14) + (($413*144)|0)|0) + 60|0);
   HEAPF32[$529>>2] = Math_fround(0.0);
   HEAPF32[$466>>2] = $475;
   HEAPF32[$468>>2] = $476;
   HEAPF32[$470>>2] = $477;
   $530 = ((($14) + (($413*144)|0)|0) + 76|0);
   HEAPF32[$530>>2] = Math_fround(0.0);
   HEAPF32[$478>>2] = $487;
   HEAPF32[$480>>2] = $488;
   HEAPF32[$482>>2] = $489;
   $531 = ((($14) + (($413*144)|0)|0) + 92|0);
   HEAPF32[$531>>2] = Math_fround(0.0);
   HEAPF32[$490>>2] = $499;
   HEAPF32[$492>>2] = $500;
   HEAPF32[$494>>2] = $501;
   $532 = ((($14) + (($413*144)|0)|0) + 108|0);
   HEAPF32[$532>>2] = Math_fround(0.0);
   HEAPF32[$502>>2] = $511;
   HEAPF32[$504>>2] = $512;
   HEAPF32[$506>>2] = $513;
   $533 = ((($14) + (($413*144)|0)|0) + 124|0);
   HEAPF32[$533>>2] = Math_fround(0.0);
   HEAPF32[$514>>2] = $523;
   HEAPF32[$516>>2] = $524;
   HEAPF32[$518>>2] = $525;
   $534 = ((($14) + (($413*144)|0)|0) + 140|0);
   HEAPF32[$534>>2] = Math_fround(0.0);
   $535 = (($17) + (($402*144)|0)|0);
   ;HEAP32[$535+0>>2]=HEAP32[$tmp+0>>2]|0;HEAP32[$535+4>>2]=HEAP32[$tmp+4>>2]|0;HEAP32[$535+8>>2]=HEAP32[$tmp+8>>2]|0;HEAP32[$535+12>>2]=HEAP32[$tmp+12>>2]|0;
   $536 = ((($17) + (($402*144)|0)|0) + 16|0);
   ;HEAP32[$536+0>>2]=HEAP32[$148+0>>2]|0;HEAP32[$536+4>>2]=HEAP32[$148+4>>2]|0;HEAP32[$536+8>>2]=HEAP32[$148+8>>2]|0;HEAP32[$536+12>>2]=HEAP32[$148+12>>2]|0;
   $537 = ((($17) + (($402*144)|0)|0) + 32|0);
   ;HEAP32[$537+0>>2]=HEAP32[$149+0>>2]|0;HEAP32[$537+4>>2]=HEAP32[$149+4>>2]|0;HEAP32[$537+8>>2]=HEAP32[$149+8>>2]|0;HEAP32[$537+12>>2]=HEAP32[$149+12>>2]|0;
   $538 = ((($17) + (($402*144)|0)|0) + 48|0);
   ;HEAP32[$538+0>>2]=HEAP32[$150+0>>2]|0;HEAP32[$538+4>>2]=HEAP32[$150+4>>2]|0;HEAP32[$538+8>>2]=HEAP32[$150+8>>2]|0;HEAP32[$538+12>>2]=HEAP32[$150+12>>2]|0;
   $539 = ((($17) + (($402*144)|0)|0) + 64|0);
   ;HEAP32[$539+0>>2]=HEAP32[$151+0>>2]|0;HEAP32[$539+4>>2]=HEAP32[$151+4>>2]|0;HEAP32[$539+8>>2]=HEAP32[$151+8>>2]|0;HEAP32[$539+12>>2]=HEAP32[$151+12>>2]|0;
   $540 = ((($17) + (($402*144)|0)|0) + 80|0);
   ;HEAP32[$540+0>>2]=HEAP32[$152+0>>2]|0;HEAP32[$540+4>>2]=HEAP32[$152+4>>2]|0;HEAP32[$540+8>>2]=HEAP32[$152+8>>2]|0;HEAP32[$540+12>>2]=HEAP32[$152+12>>2]|0;
   $541 = ((($17) + (($402*144)|0)|0) + 96|0);
   ;HEAP32[$541+0>>2]=HEAP32[$153+0>>2]|0;HEAP32[$541+4>>2]=HEAP32[$153+4>>2]|0;HEAP32[$541+8>>2]=HEAP32[$153+8>>2]|0;HEAP32[$541+12>>2]=HEAP32[$153+12>>2]|0;
   $542 = ((($17) + (($402*144)|0)|0) + 112|0);
   ;HEAP32[$542+0>>2]=HEAP32[$154+0>>2]|0;HEAP32[$542+4>>2]=HEAP32[$154+4>>2]|0;HEAP32[$542+8>>2]=HEAP32[$154+8>>2]|0;HEAP32[$542+12>>2]=HEAP32[$154+12>>2]|0;
   $543 = ((($17) + (($402*144)|0)|0) + 128|0);
   ;HEAP32[$543+0>>2]=HEAP32[$155+0>>2]|0;HEAP32[$543+4>>2]=HEAP32[$155+4>>2]|0;HEAP32[$543+8>>2]=HEAP32[$155+8>>2]|0;HEAP32[$543+12>>2]=HEAP32[$155+12>>2]|0;
   $544 = ($402>>>0)>(1);
   if ($544) {
    $$in = $402;
   } else {
    $i3$057$us = 1;
    break;
   }
  }
  while(1) {
   $156 = (($25) + (($i3$057$us*96)|0)|0);
   $157 = (($29) + ($i3$057$us<<5)|0);
   $158 = Math_fround(HEAPF32[$157>>2]);
   $159 = ((($29) + ($i3$057$us<<5)|0) + 4|0);
   $160 = Math_fround(HEAPF32[$159>>2]);
   $161 = ((($29) + ($i3$057$us<<5)|0) + 8|0);
   $162 = Math_fround(HEAPF32[$161>>2]);
   $163 = Math_fround(-$158);
   $164 = Math_fround(-$160);
   $165 = Math_fround(-$162);
   HEAPF32[$2>>2] = $163;
   HEAPF32[$32>>2] = $164;
   HEAPF32[$33>>2] = $165;
   HEAPF32[$34>>2] = Math_fround(0.0);
   $166 = (($parent) + ($i3$057$us<<3)|0);
   $167 = $166;
   $168 = $167;
   $169 = HEAP32[$168>>2]|0;
   $170 = (($167) + 4)|0;
   $171 = $170;
   $172 = HEAP32[$171>>2]|0;
   $173 = (($14) + (($169*144)|0)|0);
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$2+12>>2]|0;
   __ZN5physx26PxcArticulationFnsSimdBase16translateInertiaENS_6shdfnd3aos5Vec3VERKNS_12PxcFsInertiaE($1,$$byval_copy3,$173);
   $174 = Math_fround(HEAPF32[$1>>2]);
   $175 = Math_fround(HEAPF32[$35>>2]);
   $176 = Math_fround(HEAPF32[$36>>2]);
   $177 = (($17) + (($i3$057$us*144)|0)|0);
   $178 = Math_fround(HEAPF32[$177>>2]);
   $179 = ((($17) + (($i3$057$us*144)|0)|0) + 4|0);
   $180 = Math_fround(HEAPF32[$179>>2]);
   $181 = ((($17) + (($i3$057$us*144)|0)|0) + 8|0);
   $182 = Math_fround(HEAPF32[$181>>2]);
   $183 = Math_fround($174 - $178);
   $184 = Math_fround($175 - $180);
   $185 = Math_fround($176 - $182);
   $186 = Math_fround(HEAPF32[$37>>2]);
   $187 = Math_fround(HEAPF32[$38>>2]);
   $188 = Math_fround(HEAPF32[$39>>2]);
   $189 = ((($17) + (($i3$057$us*144)|0)|0) + 16|0);
   $190 = Math_fround(HEAPF32[$189>>2]);
   $191 = ((($17) + (($i3$057$us*144)|0)|0) + 20|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = ((($17) + (($i3$057$us*144)|0)|0) + 24|0);
   $194 = Math_fround(HEAPF32[$193>>2]);
   $195 = Math_fround($186 - $190);
   $196 = Math_fround($187 - $192);
   $197 = Math_fround($188 - $194);
   $198 = Math_fround(HEAPF32[$40>>2]);
   $199 = Math_fround(HEAPF32[$41>>2]);
   $200 = Math_fround(HEAPF32[$42>>2]);
   $201 = ((($17) + (($i3$057$us*144)|0)|0) + 32|0);
   $202 = Math_fround(HEAPF32[$201>>2]);
   $203 = ((($17) + (($i3$057$us*144)|0)|0) + 36|0);
   $204 = Math_fround(HEAPF32[$203>>2]);
   $205 = ((($17) + (($i3$057$us*144)|0)|0) + 40|0);
   $206 = Math_fround(HEAPF32[$205>>2]);
   $207 = Math_fround($198 - $202);
   $208 = Math_fround($199 - $204);
   $209 = Math_fround($200 - $206);
   $210 = Math_fround(HEAPF32[$43>>2]);
   $211 = Math_fround(HEAPF32[$44>>2]);
   $212 = Math_fround(HEAPF32[$45>>2]);
   $213 = ((($17) + (($i3$057$us*144)|0)|0) + 48|0);
   $214 = Math_fround(HEAPF32[$213>>2]);
   $215 = ((($17) + (($i3$057$us*144)|0)|0) + 52|0);
   $216 = Math_fround(HEAPF32[$215>>2]);
   $217 = ((($17) + (($i3$057$us*144)|0)|0) + 56|0);
   $218 = Math_fround(HEAPF32[$217>>2]);
   $219 = Math_fround($210 - $214);
   $220 = Math_fround($211 - $216);
   $221 = Math_fround($212 - $218);
   $222 = Math_fround(HEAPF32[$46>>2]);
   $223 = Math_fround(HEAPF32[$47>>2]);
   $224 = Math_fround(HEAPF32[$48>>2]);
   $225 = ((($17) + (($i3$057$us*144)|0)|0) + 64|0);
   $226 = Math_fround(HEAPF32[$225>>2]);
   $227 = ((($17) + (($i3$057$us*144)|0)|0) + 68|0);
   $228 = Math_fround(HEAPF32[$227>>2]);
   $229 = ((($17) + (($i3$057$us*144)|0)|0) + 72|0);
   $230 = Math_fround(HEAPF32[$229>>2]);
   $231 = Math_fround($222 - $226);
   $232 = Math_fround($223 - $228);
   $233 = Math_fround($224 - $230);
   $234 = Math_fround(HEAPF32[$49>>2]);
   $235 = Math_fround(HEAPF32[$50>>2]);
   $236 = Math_fround(HEAPF32[$51>>2]);
   $237 = ((($17) + (($i3$057$us*144)|0)|0) + 80|0);
   $238 = Math_fround(HEAPF32[$237>>2]);
   $239 = ((($17) + (($i3$057$us*144)|0)|0) + 84|0);
   $240 = Math_fround(HEAPF32[$239>>2]);
   $241 = ((($17) + (($i3$057$us*144)|0)|0) + 88|0);
   $242 = Math_fround(HEAPF32[$241>>2]);
   $243 = Math_fround($234 - $238);
   $244 = Math_fround($235 - $240);
   $245 = Math_fround($236 - $242);
   $246 = Math_fround(HEAPF32[$52>>2]);
   $247 = Math_fround(HEAPF32[$53>>2]);
   $248 = Math_fround(HEAPF32[$54>>2]);
   $249 = ((($17) + (($i3$057$us*144)|0)|0) + 96|0);
   $250 = Math_fround(HEAPF32[$249>>2]);
   $251 = ((($17) + (($i3$057$us*144)|0)|0) + 100|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = ((($17) + (($i3$057$us*144)|0)|0) + 104|0);
   $254 = Math_fround(HEAPF32[$253>>2]);
   $255 = Math_fround($246 - $250);
   $256 = Math_fround($247 - $252);
   $257 = Math_fround($248 - $254);
   $258 = Math_fround(HEAPF32[$55>>2]);
   $259 = Math_fround(HEAPF32[$56>>2]);
   $260 = Math_fround(HEAPF32[$57>>2]);
   $261 = ((($17) + (($i3$057$us*144)|0)|0) + 112|0);
   $262 = Math_fround(HEAPF32[$261>>2]);
   $263 = ((($17) + (($i3$057$us*144)|0)|0) + 116|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = ((($17) + (($i3$057$us*144)|0)|0) + 120|0);
   $266 = Math_fround(HEAPF32[$265>>2]);
   $267 = Math_fround($258 - $262);
   $268 = Math_fround($259 - $264);
   $269 = Math_fround($260 - $266);
   $270 = Math_fround(HEAPF32[$58>>2]);
   $271 = Math_fround(HEAPF32[$59>>2]);
   $272 = Math_fround(HEAPF32[$60>>2]);
   $273 = ((($17) + (($i3$057$us*144)|0)|0) + 128|0);
   $274 = Math_fround(HEAPF32[$273>>2]);
   $275 = ((($17) + (($i3$057$us*144)|0)|0) + 132|0);
   $276 = Math_fround(HEAPF32[$275>>2]);
   $277 = ((($17) + (($i3$057$us*144)|0)|0) + 136|0);
   $278 = Math_fround(HEAPF32[$277>>2]);
   $279 = Math_fround($270 - $274);
   $280 = Math_fround($271 - $276);
   $281 = Math_fround($272 - $278);
   HEAPF32[$tmp>>2] = $183;
   HEAPF32[$61>>2] = $184;
   HEAPF32[$62>>2] = $185;
   HEAPF32[$63>>2] = Math_fround(0.0);
   HEAPF32[$64>>2] = $195;
   HEAPF32[$65>>2] = $196;
   HEAPF32[$66>>2] = $197;
   HEAPF32[$67>>2] = Math_fround(0.0);
   HEAPF32[$68>>2] = $207;
   HEAPF32[$69>>2] = $208;
   HEAPF32[$70>>2] = $209;
   HEAPF32[$71>>2] = Math_fround(0.0);
   HEAPF32[$72>>2] = $219;
   HEAPF32[$73>>2] = $220;
   HEAPF32[$74>>2] = $221;
   HEAPF32[$75>>2] = Math_fround(0.0);
   HEAPF32[$76>>2] = $231;
   HEAPF32[$77>>2] = $232;
   HEAPF32[$78>>2] = $233;
   HEAPF32[$79>>2] = Math_fround(0.0);
   HEAPF32[$80>>2] = $243;
   HEAPF32[$81>>2] = $244;
   HEAPF32[$82>>2] = $245;
   HEAPF32[$83>>2] = Math_fround(0.0);
   HEAPF32[$84>>2] = $255;
   HEAPF32[$85>>2] = $256;
   HEAPF32[$86>>2] = $257;
   HEAPF32[$87>>2] = Math_fround(0.0);
   HEAPF32[$88>>2] = $267;
   HEAPF32[$89>>2] = $268;
   HEAPF32[$90>>2] = $269;
   HEAPF32[$91>>2] = Math_fround(0.0);
   HEAPF32[$92>>2] = $279;
   HEAPF32[$93>>2] = $280;
   HEAPF32[$94>>2] = $281;
   HEAPF32[$95>>2] = Math_fround(0.0);
   $282 = (($load) + (($i3$057$us*48)|0)|0);
   $283 = (($isf) + ($i3$057$us<<4)|0);
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$283+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$283+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$283+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$283+12>>2]|0;
   __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE9propagateERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialERKNS_6shdfnd3aos6Mat33VENSA_6FloatVE($tmp5,$tmp,$156,$282,$$byval_copy3);
   $284 = (($14) + (($i3$057$us*144)|0)|0);
   __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE19computeDriveInertiaERKNS_12PxcFsInertiaES5_PKNS_14PxcSIMDSpatialE($3,$284,$tmp,$156);
   dest=$282+0|0; src=$3+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $285 = Math_fround(HEAPF32[$284>>2]);
   $286 = ((($14) + (($i3$057$us*144)|0)|0) + 4|0);
   $287 = Math_fround(HEAPF32[$286>>2]);
   $288 = ((($14) + (($i3$057$us*144)|0)|0) + 8|0);
   $289 = Math_fround(HEAPF32[$288>>2]);
   $290 = Math_fround(HEAPF32[$tmp5>>2]);
   $291 = Math_fround(HEAPF32[$96>>2]);
   $292 = Math_fround(HEAPF32[$97>>2]);
   $293 = Math_fround($285 + $290);
   $294 = Math_fround($287 + $291);
   $295 = Math_fround($289 + $292);
   $296 = ((($14) + (($i3$057$us*144)|0)|0) + 16|0);
   $297 = Math_fround(HEAPF32[$296>>2]);
   $298 = ((($14) + (($i3$057$us*144)|0)|0) + 20|0);
   $299 = Math_fround(HEAPF32[$298>>2]);
   $300 = ((($14) + (($i3$057$us*144)|0)|0) + 24|0);
   $301 = Math_fround(HEAPF32[$300>>2]);
   $302 = Math_fround(HEAPF32[$98>>2]);
   $303 = Math_fround(HEAPF32[$99>>2]);
   $304 = Math_fround(HEAPF32[$100>>2]);
   $305 = Math_fround($297 + $302);
   $306 = Math_fround($299 + $303);
   $307 = Math_fround($301 + $304);
   $308 = ((($14) + (($i3$057$us*144)|0)|0) + 32|0);
   $309 = Math_fround(HEAPF32[$308>>2]);
   $310 = ((($14) + (($i3$057$us*144)|0)|0) + 36|0);
   $311 = Math_fround(HEAPF32[$310>>2]);
   $312 = ((($14) + (($i3$057$us*144)|0)|0) + 40|0);
   $313 = Math_fround(HEAPF32[$312>>2]);
   $314 = Math_fround(HEAPF32[$101>>2]);
   $315 = Math_fround(HEAPF32[$102>>2]);
   $316 = Math_fround(HEAPF32[$103>>2]);
   $317 = Math_fround($309 + $314);
   $318 = Math_fround($311 + $315);
   $319 = Math_fround($313 + $316);
   $320 = ((($14) + (($i3$057$us*144)|0)|0) + 48|0);
   $321 = Math_fround(HEAPF32[$320>>2]);
   $322 = ((($14) + (($i3$057$us*144)|0)|0) + 52|0);
   $323 = Math_fround(HEAPF32[$322>>2]);
   $324 = ((($14) + (($i3$057$us*144)|0)|0) + 56|0);
   $325 = Math_fround(HEAPF32[$324>>2]);
   $326 = Math_fround(HEAPF32[$104>>2]);
   $327 = Math_fround(HEAPF32[$105>>2]);
   $328 = Math_fround(HEAPF32[$106>>2]);
   $329 = Math_fround($321 + $326);
   $330 = Math_fround($323 + $327);
   $331 = Math_fround($325 + $328);
   $332 = ((($14) + (($i3$057$us*144)|0)|0) + 64|0);
   $333 = Math_fround(HEAPF32[$332>>2]);
   $334 = ((($14) + (($i3$057$us*144)|0)|0) + 68|0);
   $335 = Math_fround(HEAPF32[$334>>2]);
   $336 = ((($14) + (($i3$057$us*144)|0)|0) + 72|0);
   $337 = Math_fround(HEAPF32[$336>>2]);
   $338 = Math_fround(HEAPF32[$107>>2]);
   $339 = Math_fround(HEAPF32[$108>>2]);
   $340 = Math_fround(HEAPF32[$109>>2]);
   $341 = Math_fround($333 + $338);
   $342 = Math_fround($335 + $339);
   $343 = Math_fround($337 + $340);
   $344 = ((($14) + (($i3$057$us*144)|0)|0) + 80|0);
   $345 = Math_fround(HEAPF32[$344>>2]);
   $346 = ((($14) + (($i3$057$us*144)|0)|0) + 84|0);
   $347 = Math_fround(HEAPF32[$346>>2]);
   $348 = ((($14) + (($i3$057$us*144)|0)|0) + 88|0);
   $349 = Math_fround(HEAPF32[$348>>2]);
   $350 = Math_fround(HEAPF32[$110>>2]);
   $351 = Math_fround(HEAPF32[$111>>2]);
   $352 = Math_fround(HEAPF32[$112>>2]);
   $353 = Math_fround($345 + $350);
   $354 = Math_fround($347 + $351);
   $355 = Math_fround($349 + $352);
   $356 = ((($14) + (($i3$057$us*144)|0)|0) + 96|0);
   $357 = Math_fround(HEAPF32[$356>>2]);
   $358 = ((($14) + (($i3$057$us*144)|0)|0) + 100|0);
   $359 = Math_fround(HEAPF32[$358>>2]);
   $360 = ((($14) + (($i3$057$us*144)|0)|0) + 104|0);
   $361 = Math_fround(HEAPF32[$360>>2]);
   $362 = Math_fround(HEAPF32[$113>>2]);
   $363 = Math_fround(HEAPF32[$114>>2]);
   $364 = Math_fround(HEAPF32[$115>>2]);
   $365 = Math_fround($357 + $362);
   $366 = Math_fround($359 + $363);
   $367 = Math_fround($361 + $364);
   $368 = ((($14) + (($i3$057$us*144)|0)|0) + 112|0);
   $369 = Math_fround(HEAPF32[$368>>2]);
   $370 = ((($14) + (($i3$057$us*144)|0)|0) + 116|0);
   $371 = Math_fround(HEAPF32[$370>>2]);
   $372 = ((($14) + (($i3$057$us*144)|0)|0) + 120|0);
   $373 = Math_fround(HEAPF32[$372>>2]);
   $374 = Math_fround(HEAPF32[$116>>2]);
   $375 = Math_fround(HEAPF32[$117>>2]);
   $376 = Math_fround(HEAPF32[$118>>2]);
   $377 = Math_fround($369 + $374);
   $378 = Math_fround($371 + $375);
   $379 = Math_fround($373 + $376);
   $380 = ((($14) + (($i3$057$us*144)|0)|0) + 128|0);
   $381 = Math_fround(HEAPF32[$380>>2]);
   $382 = ((($14) + (($i3$057$us*144)|0)|0) + 132|0);
   $383 = Math_fround(HEAPF32[$382>>2]);
   $384 = ((($14) + (($i3$057$us*144)|0)|0) + 136|0);
   $385 = Math_fround(HEAPF32[$384>>2]);
   $386 = Math_fround(HEAPF32[$119>>2]);
   $387 = Math_fround(HEAPF32[$120>>2]);
   $388 = Math_fround(HEAPF32[$121>>2]);
   $389 = Math_fround($381 + $386);
   $390 = Math_fround($383 + $387);
   $391 = Math_fround($385 + $388);
   HEAPF32[$284>>2] = $293;
   HEAPF32[$286>>2] = $294;
   HEAPF32[$288>>2] = $295;
   $392 = ((($14) + (($i3$057$us*144)|0)|0) + 12|0);
   HEAPF32[$392>>2] = Math_fround(0.0);
   HEAPF32[$296>>2] = $305;
   HEAPF32[$298>>2] = $306;
   HEAPF32[$300>>2] = $307;
   $393 = ((($14) + (($i3$057$us*144)|0)|0) + 28|0);
   HEAPF32[$393>>2] = Math_fround(0.0);
   HEAPF32[$308>>2] = $317;
   HEAPF32[$310>>2] = $318;
   HEAPF32[$312>>2] = $319;
   $394 = ((($14) + (($i3$057$us*144)|0)|0) + 44|0);
   HEAPF32[$394>>2] = Math_fround(0.0);
   HEAPF32[$320>>2] = $329;
   HEAPF32[$322>>2] = $330;
   HEAPF32[$324>>2] = $331;
   $395 = ((($14) + (($i3$057$us*144)|0)|0) + 60|0);
   HEAPF32[$395>>2] = Math_fround(0.0);
   HEAPF32[$332>>2] = $341;
   HEAPF32[$334>>2] = $342;
   HEAPF32[$336>>2] = $343;
   $396 = ((($14) + (($i3$057$us*144)|0)|0) + 76|0);
   HEAPF32[$396>>2] = Math_fround(0.0);
   HEAPF32[$344>>2] = $353;
   HEAPF32[$346>>2] = $354;
   HEAPF32[$348>>2] = $355;
   $397 = ((($14) + (($i3$057$us*144)|0)|0) + 92|0);
   HEAPF32[$397>>2] = Math_fround(0.0);
   HEAPF32[$356>>2] = $365;
   HEAPF32[$358>>2] = $366;
   HEAPF32[$360>>2] = $367;
   $398 = ((($14) + (($i3$057$us*144)|0)|0) + 108|0);
   HEAPF32[$398>>2] = Math_fround(0.0);
   HEAPF32[$368>>2] = $377;
   HEAPF32[$370>>2] = $378;
   HEAPF32[$372>>2] = $379;
   $399 = ((($14) + (($i3$057$us*144)|0)|0) + 124|0);
   HEAPF32[$399>>2] = Math_fround(0.0);
   HEAPF32[$380>>2] = $389;
   HEAPF32[$382>>2] = $390;
   HEAPF32[$384>>2] = $391;
   $400 = ((($14) + (($i3$057$us*144)|0)|0) + 140|0);
   HEAPF32[$400>>2] = Math_fround(0.0);
   $401 = (($i3$057$us) + 1)|0;
   $exitcond68 = ($401|0)==($linkCount|0);
   if ($exitcond68) {
    break;
   } else {
    $i3$057$us = $401;
   }
  }
  $545 = (($546) + -1)|0;
  $547 = ($546|0)==(0);
  if ($547) {
   break;
  } else {
   $546 = $545;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE9propagateERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialERKNS_6shdfnd3aos6Mat33VENSA_6FloatVE($agg$result,$I,$S,$load,$isf) {
 $agg$result = $agg$result|0;
 $I = $I|0;
 $S = $S|0;
 $load = $load|0;
 $isf = $isf|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0;
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0;
 var $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0);
 var $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $D = 0, $IS = 0, $ISE = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $IS = sp + 144|0;
 $ISE = sp;
 $D = sp + 96|0;
 __ZN5physx26PxcArticulationFnsSimdBase10computeSISERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialEPS4_($D,$I,$S,$IS);
 $0 = Math_fround(HEAPF32[$load>>2]);
 $1 = (($load) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($load) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$isf>>2]);
 $6 = Math_fround(HEAPF32[$D>>2]);
 $7 = (($D) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($D) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($D) + 12|0);
 $12 = Math_fround($0 * $5);
 $13 = Math_fround($2 * $5);
 $14 = Math_fround($4 * $5);
 $15 = Math_fround($12 + $6);
 $16 = Math_fround($13 + $8);
 $17 = Math_fround($14 + $10);
 HEAPF32[$D>>2] = $15;
 HEAPF32[$7>>2] = $16;
 HEAPF32[$9>>2] = $17;
 HEAPF32[$11>>2] = Math_fround(0.0);
 $18 = (($load) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($load) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($load) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($D) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($D) + 20|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($D) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($D) + 28|0);
 $31 = Math_fround($19 * $5);
 $32 = Math_fround($21 * $5);
 $33 = Math_fround($23 * $5);
 $34 = Math_fround($31 + $25);
 $35 = Math_fround($32 + $27);
 $36 = Math_fround($33 + $29);
 HEAPF32[$24>>2] = $34;
 HEAPF32[$26>>2] = $35;
 HEAPF32[$28>>2] = $36;
 HEAPF32[$30>>2] = Math_fround(0.0);
 $37 = (($load) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($load) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($load) + 40|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($D) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($D) + 36|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($D) + 40|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($D) + 44|0);
 $50 = Math_fround($38 * $5);
 $51 = Math_fround($40 * $5);
 $52 = Math_fround($42 * $5);
 $53 = Math_fround($50 + $44);
 $54 = Math_fround($51 + $46);
 $55 = Math_fround($52 + $48);
 HEAPF32[$43>>2] = $53;
 HEAPF32[$45>>2] = $54;
 HEAPF32[$47>>2] = $55;
 HEAPF32[$49>>2] = Math_fround(0.0);
 $56 = (Math_fround(Math_sqrt((Math_fround($15)))));
 $57 = Math_fround(Math_fround(1.0) / $56);
 $58 = Math_fround($16 * $57);
 $59 = Math_fround($17 * $57);
 $60 = Math_fround($58 * $58);
 $61 = Math_fround($35 - $60);
 $62 = (Math_fround(Math_sqrt((Math_fround($61)))));
 $63 = Math_fround(Math_fround(1.0) / $62);
 $64 = Math_fround($58 * $59);
 $65 = Math_fround($36 - $64);
 $66 = Math_fround($63 * $65);
 $67 = Math_fround($66 * $66);
 $68 = Math_fround($55 - $67);
 $69 = Math_fround($59 * $59);
 $70 = Math_fround($68 - $69);
 $71 = (Math_fround(Math_sqrt((Math_fround($70)))));
 $72 = Math_fround(Math_fround(1.0) / $71);
 $73 = Math_fround($57 * $58);
 $74 = Math_fround($73 * $63);
 $75 = Math_fround($74 * $66);
 $76 = Math_fround($57 * $59);
 $77 = Math_fround($75 - $76);
 $78 = Math_fround($72 * $77);
 $79 = Math_fround($63 * $72);
 $80 = Math_fround($66 * $79);
 $81 = Math_fround(-$74);
 $82 = Math_fround(-$80);
 $83 = Math_fround(HEAPF32[$IS>>2]);
 $84 = (($IS) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($IS) + 8|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($IS) + 32|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($IS) + 36|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($IS) + 40|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($IS) + 64|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($IS) + 68|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($IS) + 72|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($IS) + 16|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($IS) + 20|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($IS) + 24|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($IS) + 48|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($IS) + 52|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($IS) + 56|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($IS) + 80|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($IS) + 84|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($IS) + 88|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($57 * $83);
 $119 = Math_fround($57 * $85);
 $120 = Math_fround($57 * $87);
 $121 = Math_fround($57 * $101);
 $122 = Math_fround($57 * $103);
 $123 = Math_fround($57 * $105);
 HEAPF32[$ISE>>2] = $118;
 $124 = (($ISE) + 4|0);
 HEAPF32[$124>>2] = $119;
 $125 = (($ISE) + 8|0);
 HEAPF32[$125>>2] = $120;
 $126 = (($ISE) + 12|0);
 HEAPF32[$126>>2] = Math_fround(0.0);
 $127 = (($ISE) + 16|0);
 HEAPF32[$127>>2] = $121;
 $128 = (($ISE) + 20|0);
 HEAPF32[$128>>2] = $122;
 $129 = (($ISE) + 24|0);
 HEAPF32[$129>>2] = $123;
 $130 = (($ISE) + 28|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = Math_fround($63 * $89);
 $132 = Math_fround($63 * $91);
 $133 = Math_fround($63 * $93);
 $134 = Math_fround($83 * $81);
 $135 = Math_fround($85 * $81);
 $136 = Math_fround($87 * $81);
 $137 = Math_fround($134 + $131);
 $138 = Math_fround($135 + $132);
 $139 = Math_fround($136 + $133);
 $140 = Math_fround($63 * $107);
 $141 = Math_fround($63 * $109);
 $142 = Math_fround($63 * $111);
 $143 = Math_fround($101 * $81);
 $144 = Math_fround($103 * $81);
 $145 = Math_fround($105 * $81);
 $146 = Math_fround($143 + $140);
 $147 = Math_fround($144 + $141);
 $148 = Math_fround($145 + $142);
 $149 = (($ISE) + 32|0);
 HEAPF32[$149>>2] = $137;
 $150 = (($ISE) + 36|0);
 HEAPF32[$150>>2] = $138;
 $151 = (($ISE) + 40|0);
 HEAPF32[$151>>2] = $139;
 $152 = (($ISE) + 44|0);
 HEAPF32[$152>>2] = Math_fround(0.0);
 $153 = (($ISE) + 48|0);
 HEAPF32[$153>>2] = $146;
 $154 = (($ISE) + 52|0);
 HEAPF32[$154>>2] = $147;
 $155 = (($ISE) + 56|0);
 HEAPF32[$155>>2] = $148;
 $156 = (($ISE) + 60|0);
 HEAPF32[$156>>2] = Math_fround(0.0);
 $157 = Math_fround($72 * $95);
 $158 = Math_fround($72 * $97);
 $159 = Math_fround($72 * $99);
 $160 = Math_fround($89 * $82);
 $161 = Math_fround($91 * $82);
 $162 = Math_fround($93 * $82);
 $163 = Math_fround($160 + $157);
 $164 = Math_fround($161 + $158);
 $165 = Math_fround($162 + $159);
 $166 = Math_fround($83 * $78);
 $167 = Math_fround($85 * $78);
 $168 = Math_fround($87 * $78);
 $169 = Math_fround($166 + $163);
 $170 = Math_fround($167 + $164);
 $171 = Math_fround($168 + $165);
 $172 = Math_fround($72 * $113);
 $173 = Math_fround($72 * $115);
 $174 = Math_fround($72 * $117);
 $175 = Math_fround($107 * $82);
 $176 = Math_fround($109 * $82);
 $177 = Math_fround($111 * $82);
 $178 = Math_fround($175 + $172);
 $179 = Math_fround($176 + $173);
 $180 = Math_fround($177 + $174);
 $181 = Math_fround($78 * $101);
 $182 = Math_fround($78 * $103);
 $183 = Math_fround($78 * $105);
 $184 = Math_fround($181 + $178);
 $185 = Math_fround($182 + $179);
 $186 = Math_fround($183 + $180);
 $187 = (($ISE) + 64|0);
 HEAPF32[$187>>2] = $169;
 $188 = (($ISE) + 68|0);
 HEAPF32[$188>>2] = $170;
 $189 = (($ISE) + 72|0);
 HEAPF32[$189>>2] = $171;
 $190 = (($ISE) + 76|0);
 HEAPF32[$190>>2] = Math_fround(0.0);
 $191 = (($ISE) + 80|0);
 HEAPF32[$191>>2] = $184;
 $192 = (($ISE) + 84|0);
 HEAPF32[$192>>2] = $185;
 $193 = (($ISE) + 88|0);
 HEAPF32[$193>>2] = $186;
 $194 = (($ISE) + 92|0);
 HEAPF32[$194>>2] = Math_fround(0.0);
 __ZN5physx26PxcArticulationFnsSimdBase16multiplySubtractERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialE($agg$result,$I,$ISE);
 STACKTOP = sp;return;
}
function __ZN5physx22PxcArticulationFnsSimdINS_26PxcArticulationFnsSimdBaseEE19computeDriveInertiaERKNS_12PxcFsInertiaES5_PKNS_14PxcSIMDSpatialE($agg$result,$I0,$I1,$S) {
 $agg$result = $agg$result|0;
 $I0 = $I0|0;
 $I1 = $I1|0;
 $S = $S|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $16 = Math_fround(0);
 var $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0;
 var $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $D = 0, $DInv = 0, $E = 0, $IS = 0, $ISD = 0, $J = 0, $dummy = 0, $tmp = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 864|0;
 $IS = sp + 768|0;
 $ISD = sp + 672|0;
 $dummy = sp + 576|0;
 $D = sp + 528|0;
 $DInv = sp + 480|0;
 $tmp = sp + 288|0;
 $0 = sp + 144|0;
 $J = sp;
 $E = sp + 432|0;
 dest=$IS+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$ISD+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$dummy+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx26PxcArticulationFnsSimdBase10computeSISERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialEPS4_($D,$I0,$S,$IS);
 $1 = (($D) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($D) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($D) + 24|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($D) + 32|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($D) + 36|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($D) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($4 * $12);
 $14 = Math_fround($6 * $10);
 $15 = Math_fround($13 - $14);
 $16 = Math_fround($6 * $8);
 $17 = Math_fround($2 * $12);
 $18 = Math_fround($16 - $17);
 $19 = Math_fround($2 * $10);
 $20 = Math_fround($4 * $8);
 $21 = Math_fround($19 - $20);
 $22 = Math_fround(HEAPF32[$D>>2]);
 $23 = (($D) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($D) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($12 * $22);
 $28 = Math_fround($8 * $26);
 $29 = Math_fround($27 - $28);
 $30 = Math_fround($8 * $24);
 $31 = Math_fround($10 * $22);
 $32 = Math_fround($30 - $31);
 $33 = Math_fround($4 * $22);
 $34 = Math_fround($2 * $24);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($22 * $15);
 $37 = Math_fround($18 * $24);
 $38 = Math_fround($36 + $37);
 $39 = Math_fround($21 * $26);
 $40 = Math_fround($38 + $39);
 $41 = Math_fround(Math_fround(1.0) / $40);
 $42 = Math_fround($15 * $41);
 $43 = Math_fround($18 * $41);
 $44 = Math_fround($21 * $41);
 $45 = Math_fround($41 * $29);
 $46 = Math_fround($41 * $32);
 $47 = Math_fround($41 * $35);
 HEAPF32[$DInv>>2] = $42;
 $48 = (($DInv) + 4|0);
 HEAPF32[$48>>2] = $43;
 $49 = (($DInv) + 8|0);
 HEAPF32[$49>>2] = $44;
 $50 = (($DInv) + 12|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($DInv) + 16|0);
 HEAPF32[$51>>2] = $43;
 $52 = (($DInv) + 20|0);
 HEAPF32[$52>>2] = $45;
 $53 = (($DInv) + 24|0);
 HEAPF32[$53>>2] = $46;
 $54 = (($DInv) + 28|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($DInv) + 32|0);
 HEAPF32[$55>>2] = $44;
 $56 = (($DInv) + 36|0);
 HEAPF32[$56>>2] = $46;
 $57 = (($DInv) + 40|0);
 HEAPF32[$57>>2] = $47;
 $58 = (($DInv) + 44|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 __ZN5physx26PxcArticulationFnsSimdBase10addInertiaERKNS_12PxcFsInertiaES3_($tmp,$I0,$I1);
 __ZN5physx26PxcArticulationFnsSimdBase16multiplySubtractERKNS_12PxcFsInertiaERKNS_6shdfnd3aos6Mat33VEPKNS_14PxcSIMDSpatialEPS9_($0,$tmp,$DInv,$IS,$ISD);
 ;HEAP32[$tmp+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[$0+12>>2]|0;
 $59 = (($tmp) + 16|0);
 $60 = (($0) + 16|0);
 ;HEAP32[$59+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$59+12>>2]=HEAP32[$60+12>>2]|0;
 $61 = (($tmp) + 32|0);
 $62 = (($0) + 32|0);
 ;HEAP32[$61+0>>2]=HEAP32[$62+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$62+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$62+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$62+12>>2]|0;
 $63 = (($tmp) + 48|0);
 $64 = (($0) + 48|0);
 ;HEAP32[$63+0>>2]=HEAP32[$64+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$64+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$64+8>>2]|0;HEAP32[$63+12>>2]=HEAP32[$64+12>>2]|0;
 $65 = (($tmp) + 64|0);
 $66 = (($0) + 64|0);
 ;HEAP32[$65+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$66+12>>2]|0;
 $67 = (($tmp) + 80|0);
 $68 = (($0) + 80|0);
 ;HEAP32[$67+0>>2]=HEAP32[$68+0>>2]|0;HEAP32[$67+4>>2]=HEAP32[$68+4>>2]|0;HEAP32[$67+8>>2]=HEAP32[$68+8>>2]|0;HEAP32[$67+12>>2]=HEAP32[$68+12>>2]|0;
 $69 = (($tmp) + 96|0);
 $70 = (($0) + 96|0);
 ;HEAP32[$69+0>>2]=HEAP32[$70+0>>2]|0;HEAP32[$69+4>>2]=HEAP32[$70+4>>2]|0;HEAP32[$69+8>>2]=HEAP32[$70+8>>2]|0;HEAP32[$69+12>>2]=HEAP32[$70+12>>2]|0;
 $71 = (($tmp) + 112|0);
 $72 = (($0) + 112|0);
 ;HEAP32[$71+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$71+12>>2]=HEAP32[$72+12>>2]|0;
 $73 = (($tmp) + 128|0);
 $74 = (($0) + 128|0);
 ;HEAP32[$73+0>>2]=HEAP32[$74+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$74+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$74+12>>2]|0;
 __ZN5physx26PxcArticulationFnsSimdBase13invertInertiaERKNS_12PxcFsInertiaE($J,$tmp);
 __ZN5physx26PxcArticulationFnsSimdBase10computeSISERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialEPS4_($E,$J,$ISD,$dummy);
 $75 = Math_fround(HEAPF32[$DInv>>2]);
 $76 = Math_fround(HEAPF32[$48>>2]);
 $77 = Math_fround(HEAPF32[$49>>2]);
 $78 = Math_fround(HEAPF32[$E>>2]);
 $79 = (($E) + 4|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($E) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($75 + $78);
 $84 = Math_fround($76 + $80);
 $85 = Math_fround($77 + $82);
 $86 = Math_fround(HEAPF32[$51>>2]);
 $87 = Math_fround(HEAPF32[$52>>2]);
 $88 = Math_fround(HEAPF32[$53>>2]);
 $89 = (($E) + 16|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($E) + 20|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($E) + 24|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($86 + $90);
 $96 = Math_fround($87 + $92);
 $97 = Math_fround($88 + $94);
 $98 = Math_fround(HEAPF32[$55>>2]);
 $99 = Math_fround(HEAPF32[$56>>2]);
 $100 = Math_fround(HEAPF32[$57>>2]);
 $101 = (($E) + 32|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($E) + 36|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($E) + 40|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($98 + $102);
 $108 = Math_fround($99 + $104);
 $109 = Math_fround($100 + $106);
 $110 = Math_fround($96 * $109);
 $111 = Math_fround($97 * $108);
 $112 = Math_fround($110 - $111);
 $113 = Math_fround($97 * $107);
 $114 = Math_fround($95 * $109);
 $115 = Math_fround($113 - $114);
 $116 = Math_fround($95 * $108);
 $117 = Math_fround($96 * $107);
 $118 = Math_fround($116 - $117);
 $119 = Math_fround($83 * $109);
 $120 = Math_fround($85 * $107);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($84 * $107);
 $123 = Math_fround($83 * $108);
 $124 = Math_fround($122 - $123);
 $125 = Math_fround($83 * $96);
 $126 = Math_fround($84 * $95);
 $127 = Math_fround($125 - $126);
 $128 = Math_fround($83 * $112);
 $129 = Math_fround($84 * $115);
 $130 = Math_fround($128 + $129);
 $131 = Math_fround($85 * $118);
 $132 = Math_fround($131 + $130);
 $133 = Math_fround(Math_fround(1.0) / $132);
 $134 = Math_fround($133 * $112);
 $135 = Math_fround($133 * $115);
 $136 = Math_fround($133 * $118);
 $137 = Math_fround($133 * $121);
 $138 = Math_fround($133 * $124);
 $139 = Math_fround($127 * $133);
 HEAPF32[$agg$result>>2] = $134;
 $140 = (($agg$result) + 4|0);
 HEAPF32[$140>>2] = $135;
 $141 = (($agg$result) + 8|0);
 HEAPF32[$141>>2] = $136;
 $142 = (($agg$result) + 12|0);
 HEAPF32[$142>>2] = Math_fround(0.0);
 $143 = (($agg$result) + 16|0);
 HEAPF32[$143>>2] = $135;
 $144 = (($agg$result) + 20|0);
 HEAPF32[$144>>2] = $137;
 $145 = (($agg$result) + 24|0);
 HEAPF32[$145>>2] = $138;
 $146 = (($agg$result) + 28|0);
 HEAPF32[$146>>2] = Math_fround(0.0);
 $147 = (($agg$result) + 32|0);
 HEAPF32[$147>>2] = $136;
 $148 = (($agg$result) + 36|0);
 HEAPF32[$148>>2] = $138;
 $149 = (($agg$result) + 40|0);
 HEAPF32[$149>>2] = $139;
 $150 = (($agg$result) + 44|0);
 HEAPF32[$150>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper12getDataSizesEjRjS1_S1_($linkCount,$solverDataSize,$totalSize,$scratchSize) {
 $linkCount = $linkCount|0;
 $solverDataSize = $solverDataSize|0;
 $totalSize = $totalSize|0;
 $scratchSize = $scratchSize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $factor = 0, $tmp1 = 0, $tmp3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $linkCount << 5;
 $1 = $linkCount << 2;
 $2 = (($1) + 60)|0;
 $3 = $2 & -64;
 $factor = ($linkCount*96)|0;
 $tmp1 = ($linkCount*176)|0;
 $4 = (($tmp1) + 272)|0;
 $5 = (($4) + ($factor))|0;
 $6 = (($5) + ($3))|0;
 HEAP32[$solverDataSize>>2] = $6;
 $tmp3 = ($linkCount*496)|0;
 $7 = (($6) + ($0))|0;
 $8 = (($7) + ($tmp3))|0;
 HEAP32[$totalSize>>2] = $8;
 $9 = ($linkCount*608)|0;
 HEAP32[$scratchSize>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper16prepareDataBlockERNS_9PxcFsDataEPKNS_19PxsArticulationLinkEtPNS_11PxTransformEPNS_12PxcFsInertiaEPNS_30PxcArticulationJointTransformsEj($fsData,$links,$linkCount,$poses,$baseInertia,$jointTransforms,$expectedSize) {
 $fsData = $fsData|0;
 $links = $links|0;
 $linkCount = $linkCount|0;
 $poses = $poses|0;
 $baseInertia = $baseInertia|0;
 $jointTransforms = $jointTransforms|0;
 $expectedSize = $expectedSize|0;
 var $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0);
 var $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0);
 var $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond19 = 0, $exitcond20 = 0;
 var $factor = 0, $i$015 = 0, $i1$011 = 0, $i2$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = $linkCount&65535;
 $2 = $1 << 5;
 $3 = $1 << 4;
 $4 = $1 << 2;
 $5 = (($4) + 60)|0;
 $6 = $5 & 524224;
 $factor = $1 << 6;
 $7 = (($3) + 128)|0;
 $8 = (($7) + ($6))|0;
 $9 = (($8) + ($factor))|0;
 $10 = ($1*160)|0;
 $11 = (($10) + 144)|0;
 $12 = (($9) + ($2))|0;
 $13 = (($11) + ($12))|0;
 _memset(($fsData|0),0,($9|0))|0;
 $14 = $9&65535;
 $15 = (($fsData) + 10|0);
 HEAP16[$15>>1] = $14;
 $16 = $12&65535;
 $17 = (($fsData) + 26|0);
 HEAP16[$17>>1] = $16;
 $18 = $13&65535;
 $19 = (($fsData) + 24|0);
 HEAP16[$19>>1] = $18;
 $20 = (($fsData) + 8|0);
 HEAP16[$20>>1] = $linkCount;
 $21 = ($linkCount&65535)>(1);
 if ($21) {
  $i$015 = 1;
  while(1) {
   $22 = ((($links) + ($i$015<<5)|0) + 28|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23&255;
   $25 = ((($fsData) + ($i$015)|0) + 64|0);
   HEAP8[$25>>0] = $24;
   $26 = (($i$015) + 1)|0;
   $exitcond20 = ($26|0)==($1|0);
   if ($exitcond20) {
    break;
   } else {
    $i$015 = $26;
   }
  }
 }
 $27 = (($fsData) + 32|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
 ;HEAP32[$27+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$0+12>>2]|0;
 $28 = (($fsData) + 48|0);
 $29 = (($0) + 16|0);
 ;HEAP32[$28+0>>2]=HEAP32[$29+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$29+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$29+12>>2]|0;
 $30 = (($fsData) + 128|0);
 $31 = ($1*144)|0;
 _memset(($baseInertia|0),0,($31|0))|0;
 $32 = HEAP16[$20>>1]|0;
 $33 = $32&65535;
 $$sum$i = ($33*80)|0;
 $34 = (($30) + ($$sum$i)|0);
 $35 = ($linkCount<<16>>16)==(0);
 if (!($35)) {
  $i1$011 = 0;
  while(1) {
   $36 = (($i1$011) + 2)|0;
   $37 = ($36>>>0)<($1>>>0);
   if ($37) {
    $38 = ((($links) + ($36<<5)|0) + 20|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ((($links) + ($36<<5)|0) + 24|0);
    $41 = HEAP32[$40>>2]|0;
   }
   $42 = ((($links) + ($i1$011<<5)|0) + 20|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($poses) + (($i1$011*28)|0)|0);
   HEAPF32[$45>>2] = $44;
   $46 = (($43) + 4|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = ((($poses) + (($i1$011*28)|0)|0) + 4|0);
   HEAPF32[$48>>2] = $47;
   $49 = (($43) + 8|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = ((($poses) + (($i1$011*28)|0)|0) + 8|0);
   HEAPF32[$51>>2] = $50;
   $52 = (($43) + 12|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = ((($poses) + (($i1$011*28)|0)|0) + 12|0);
   HEAPF32[$54>>2] = $53;
   $55 = (($43) + 16|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = ((($poses) + (($i1$011*28)|0)|0) + 16|0);
   HEAPF32[$57>>2] = $56;
   $58 = (($43) + 20|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = ((($poses) + (($i1$011*28)|0)|0) + 20|0);
   HEAPF32[$60>>2] = $59;
   $61 = (($43) + 24|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = ((($poses) + (($i1$011*28)|0)|0) + 24|0);
   HEAPF32[$63>>2] = $62;
   $64 = (($43) + 64|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = (($43) + 68|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = (($43) + 72|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = (($43) + 80|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = (($43) + 84|0);
   $73 = Math_fround(HEAPF32[$72>>2]);
   $74 = (($43) + 88|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = (($30) + ($i1$011<<5)|0);
   HEAPF32[$76>>2] = $65;
   $77 = ((($30) + ($i1$011<<5)|0) + 4|0);
   HEAPF32[$77>>2] = $67;
   $78 = ((($30) + ($i1$011<<5)|0) + 8|0);
   HEAPF32[$78>>2] = $69;
   $79 = ((($30) + ($i1$011<<5)|0) + 12|0);
   HEAPF32[$79>>2] = Math_fround(0.0);
   $80 = ((($30) + ($i1$011<<5)|0) + 16|0);
   HEAPF32[$80>>2] = $71;
   $81 = ((($30) + ($i1$011<<5)|0) + 20|0);
   HEAPF32[$81>>2] = $73;
   $82 = ((($30) + ($i1$011<<5)|0) + 24|0);
   HEAPF32[$82>>2] = $75;
   $83 = ((($30) + ($i1$011<<5)|0) + 28|0);
   HEAPF32[$83>>2] = Math_fround(0.0);
   $84 = (($baseInertia) + (($i1$011*144)|0)|0);
   __ZN5physx21PxcArticulationHelper10setInertiaERNS_12PxcFsInertiaERKNS_11PxsBodyCoreERKNS_11PxTransformE($84,$43,$43);
   $85 = (($43) + 76|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   $87 = (($34) + ($i1$011<<2)|0);
   HEAPF32[$87>>2] = $86;
   $88 = ($i1$011|0)==(0);
   if (!($88)) {
    $89 = (($jointTransforms) + (($i1$011*84)|0)|0);
    $90 = ((($links) + ($i1$011<<5)|0) + 28|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($poses) + (($91*28)|0)|0);
    $93 = ((($links) + ($i1$011<<5)|0) + 24|0);
    $94 = HEAP32[$93>>2]|0;
    __ZN5physx21PxcArticulationHelper18setJointTransformsERNS_30PxcArticulationJointTransformsERKNS_11PxTransformES5_RKNS_24PxsArticulationJointCoreE($89,$92,$43,$94);
   }
   $95 = (($i1$011) + 1)|0;
   $exitcond19 = ($95|0)==($1|0);
   if ($exitcond19) {
    break;
   } else {
    $i1$011 = $95;
   }
  }
 }
 $96 = HEAP16[$15>>1]|0;
 $97 = $96&65535;
 $98 = (($fsData) + ($97)|0);
 if ($21) {
  $i2$010 = 1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $99 = ((($fsData) + ($i2$010)|0) + 64|0);
  $100 = HEAP8[$99>>0]|0;
  $101 = $100&255;
  $102 = ((($poses) + (($i2$010*28)|0)|0) + 16|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = ((($poses) + (($101*28)|0)|0) + 16|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($103 - $105);
  $107 = ((($poses) + (($i2$010*28)|0)|0) + 20|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = ((($poses) + (($101*28)|0)|0) + 20|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = Math_fround($108 - $110);
  $112 = ((($poses) + (($i2$010*28)|0)|0) + 24|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = ((($poses) + (($101*28)|0)|0) + 24|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($113 - $115);
  $117 = (($98) + ($i2$010<<5)|0);
  HEAPF32[$117>>2] = $106;
  $118 = ((($98) + ($i2$010<<5)|0) + 4|0);
  HEAPF32[$118>>2] = $111;
  $119 = ((($98) + ($i2$010<<5)|0) + 8|0);
  HEAPF32[$119>>2] = $116;
  $120 = ((($jointTransforms) + (($i2$010*84)|0)|0) + 44|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = Math_fround(HEAPF32[$102>>2]);
  $123 = Math_fround($121 - $122);
  $124 = ((($jointTransforms) + (($i2$010*84)|0)|0) + 48|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = Math_fround(HEAPF32[$107>>2]);
  $127 = Math_fround($125 - $126);
  $128 = ((($jointTransforms) + (($i2$010*84)|0)|0) + 52|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = Math_fround(HEAPF32[$112>>2]);
  $131 = Math_fround($129 - $130);
  $132 = ((($98) + ($i2$010<<5)|0) + 16|0);
  HEAPF32[$132>>2] = $123;
  $133 = ((($98) + ($i2$010<<5)|0) + 20|0);
  HEAPF32[$133>>2] = $127;
  $134 = ((($98) + ($i2$010<<5)|0) + 24|0);
  HEAPF32[$134>>2] = $131;
  $135 = (($i2$010) + 1)|0;
  $exitcond = ($135|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i2$010 = $135;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper10setInertiaERNS_12PxcFsInertiaERKNS_11PxsBodyCoreERKNS_11PxTransformE($inertia,$body,$pose) {
 $inertia = $inertia|0;
 $body = $body|0;
 $pose = $pose|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0);
 var $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$pose>>2]);
 $1 = (($pose) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($pose) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pose) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 + $0);
 $8 = Math_fround($2 + $2);
 $9 = Math_fround($4 + $4);
 $10 = Math_fround($0 * $7);
 $11 = Math_fround($2 * $8);
 $12 = Math_fround($4 * $9);
 $13 = Math_fround($7 * $2);
 $14 = Math_fround($7 * $4);
 $15 = Math_fround($7 * $6);
 $16 = Math_fround($8 * $4);
 $17 = Math_fround($8 * $6);
 $18 = Math_fround($9 * $6);
 $19 = Math_fround(Math_fround(1.0) - $11);
 $20 = Math_fround($19 - $12);
 $21 = Math_fround($13 + $18);
 $22 = Math_fround($14 - $17);
 $23 = Math_fround($13 - $18);
 $24 = Math_fround(Math_fround(1.0) - $10);
 $25 = Math_fround($24 - $12);
 $26 = Math_fround($16 + $15);
 $27 = Math_fround($14 + $17);
 $28 = Math_fround($16 - $15);
 $29 = Math_fround($24 - $11);
 $30 = (($body) + 124|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(Math_fround(1.0) / $31);
 HEAPF32[$inertia>>2] = $32;
 $33 = (($inertia) + 20|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($inertia) + 40|0);
 HEAPF32[$34>>2] = $32;
 $35 = (($body) + 112|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(Math_fround(1.0) / $36);
 $38 = (($body) + 116|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround(Math_fround(1.0) / $39);
 $41 = (($body) + 120|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround(Math_fround(1.0) / $42);
 $44 = Math_fround($20 * $37);
 $45 = Math_fround($21 * $37);
 $46 = Math_fround($22 * $37);
 $47 = Math_fround($23 * Math_fround(0.0));
 $48 = Math_fround($25 * Math_fround(0.0));
 $49 = Math_fround($26 * Math_fround(0.0));
 $50 = Math_fround($47 + $44);
 $51 = Math_fround($48 + $45);
 $52 = Math_fround($49 + $46);
 $53 = Math_fround($27 * Math_fround(0.0));
 $54 = Math_fround($28 * Math_fround(0.0));
 $55 = Math_fround($29 * Math_fround(0.0));
 $56 = Math_fround($53 + $50);
 $57 = Math_fround($54 + $51);
 $58 = Math_fround($55 + $52);
 $59 = Math_fround($20 * Math_fround(0.0));
 $60 = Math_fround($21 * Math_fround(0.0));
 $61 = Math_fround($22 * Math_fround(0.0));
 $62 = Math_fround($23 * $40);
 $63 = Math_fround($25 * $40);
 $64 = Math_fround($26 * $40);
 $65 = Math_fround($59 + $62);
 $66 = Math_fround($60 + $63);
 $67 = Math_fround($61 + $64);
 $68 = Math_fround($53 + $65);
 $69 = Math_fround($54 + $66);
 $70 = Math_fround($55 + $67);
 $71 = Math_fround($59 + $47);
 $72 = Math_fround($60 + $48);
 $73 = Math_fround($61 + $49);
 $74 = Math_fround($27 * $43);
 $75 = Math_fround($28 * $43);
 $76 = Math_fround($29 * $43);
 $77 = Math_fround($71 + $74);
 $78 = Math_fround($72 + $75);
 $79 = Math_fround($73 + $76);
 $80 = Math_fround($20 * $56);
 $81 = Math_fround($20 * $57);
 $82 = Math_fround($20 * $58);
 $83 = Math_fround($23 * $68);
 $84 = Math_fround($23 * $69);
 $85 = Math_fround($23 * $70);
 $86 = Math_fround($80 + $83);
 $87 = Math_fround($81 + $84);
 $88 = Math_fround($82 + $85);
 $89 = Math_fround($27 * $77);
 $90 = Math_fround($27 * $78);
 $91 = Math_fround($27 * $79);
 $92 = Math_fround($86 + $89);
 $93 = Math_fround($87 + $90);
 $94 = Math_fround($88 + $91);
 $95 = Math_fround($21 * $56);
 $96 = Math_fround($21 * $57);
 $97 = Math_fround($21 * $58);
 $98 = Math_fround($25 * $68);
 $99 = Math_fround($25 * $69);
 $100 = Math_fround($25 * $70);
 $101 = Math_fround($95 + $98);
 $102 = Math_fround($96 + $99);
 $103 = Math_fround($97 + $100);
 $104 = Math_fround($28 * $77);
 $105 = Math_fround($28 * $78);
 $106 = Math_fround($28 * $79);
 $107 = Math_fround($101 + $104);
 $108 = Math_fround($102 + $105);
 $109 = Math_fround($103 + $106);
 $110 = Math_fround($22 * $56);
 $111 = Math_fround($22 * $57);
 $112 = Math_fround($22 * $58);
 $113 = Math_fround($26 * $68);
 $114 = Math_fround($26 * $69);
 $115 = Math_fround($26 * $70);
 $116 = Math_fround($110 + $113);
 $117 = Math_fround($111 + $114);
 $118 = Math_fround($112 + $115);
 $119 = Math_fround($29 * $77);
 $120 = Math_fround($29 * $78);
 $121 = Math_fround($29 * $79);
 $122 = Math_fround($116 + $119);
 $123 = Math_fround($117 + $120);
 $124 = Math_fround($118 + $121);
 $125 = Math_fround($92 + $92);
 $126 = Math_fround($93 + $107);
 $127 = Math_fround($94 + $122);
 $128 = Math_fround($108 + $108);
 $129 = Math_fround($109 + $123);
 $130 = Math_fround($124 + $124);
 $131 = Math_fround($125 * Math_fround(0.5));
 $132 = Math_fround($126 * Math_fround(0.5));
 $133 = Math_fround($127 * Math_fround(0.5));
 $134 = Math_fround($128 * Math_fround(0.5));
 $135 = Math_fround($129 * Math_fround(0.5));
 $136 = Math_fround($130 * Math_fround(0.5));
 $137 = (($inertia) + 96|0);
 HEAPF32[$137>>2] = $131;
 $138 = (($inertia) + 100|0);
 HEAPF32[$138>>2] = $132;
 $139 = (($inertia) + 104|0);
 HEAPF32[$139>>2] = $133;
 $140 = (($inertia) + 108|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $141 = (($inertia) + 112|0);
 HEAPF32[$141>>2] = $132;
 $142 = (($inertia) + 116|0);
 HEAPF32[$142>>2] = $134;
 $143 = (($inertia) + 120|0);
 HEAPF32[$143>>2] = $135;
 $144 = (($inertia) + 124|0);
 HEAPF32[$144>>2] = Math_fround(0.0);
 $145 = (($inertia) + 128|0);
 HEAPF32[$145>>2] = $133;
 $146 = (($inertia) + 132|0);
 HEAPF32[$146>>2] = $135;
 $147 = (($inertia) + 136|0);
 HEAPF32[$147>>2] = $136;
 $148 = (($inertia) + 140|0);
 HEAPF32[$148>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper18setJointTransformsERNS_30PxcArticulationJointTransformsERKNS_11PxTransformES5_RKNS_24PxsArticulationJointCoreE($transforms,$parentPose,$childPose,$joint) {
 $transforms = $transforms|0;
 $parentPose = $parentPose|0;
 $childPose = $childPose|0;
 $joint = $joint|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0;
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($joint) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($joint) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = (($joint) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(2.0));
 $9 = (($parentPose) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $10);
 $12 = Math_fround($11 + Math_fround(-0.5));
 $13 = Math_fround(HEAPF32[$parentPose>>2]);
 $14 = Math_fround($2 * $13);
 $15 = (($parentPose) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($5 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($parentPose) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($8 * $20);
 $22 = Math_fround($18 + $21);
 $23 = Math_fround($2 * $12);
 $24 = Math_fround($8 * $16);
 $25 = Math_fround($5 * $20);
 $26 = Math_fround($24 - $25);
 $27 = Math_fround($10 * $26);
 $28 = Math_fround($23 + $27);
 $29 = Math_fround($13 * $22);
 $30 = Math_fround($29 + $28);
 $31 = Math_fround($5 * $12);
 $32 = Math_fround($2 * $20);
 $33 = Math_fround($8 * $13);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($10 * $34);
 $36 = Math_fround($31 + $35);
 $37 = Math_fround($16 * $22);
 $38 = Math_fround($37 + $36);
 $39 = Math_fround($8 * $12);
 $40 = Math_fround($5 * $13);
 $41 = Math_fround($2 * $16);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($10 * $42);
 $44 = Math_fround($39 + $43);
 $45 = Math_fround($20 * $22);
 $46 = Math_fround($44 + $45);
 $47 = (($parentPose) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($48 + $30);
 $50 = (($parentPose) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 + $38);
 $53 = (($parentPose) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 + $46);
 $56 = Math_fround(HEAPF32[$joint>>2]);
 $57 = Math_fround($10 * $56);
 $58 = (($joint) + 12|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($13 * $59);
 $61 = Math_fround($57 + $60);
 $62 = (($joint) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($16 * $63);
 $65 = Math_fround($61 + $64);
 $66 = (($joint) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($20 * $67);
 $69 = Math_fround($65 - $68);
 $70 = Math_fround($10 * $67);
 $71 = Math_fround($16 * $59);
 $72 = Math_fround($71 + $70);
 $73 = Math_fround($20 * $56);
 $74 = Math_fround($73 + $72);
 $75 = Math_fround($13 * $63);
 $76 = Math_fround($74 - $75);
 $77 = Math_fround($10 * $63);
 $78 = Math_fround($20 * $59);
 $79 = Math_fround($78 + $77);
 $80 = Math_fround($13 * $67);
 $81 = Math_fround($80 + $79);
 $82 = Math_fround($16 * $56);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($10 * $59);
 $85 = Math_fround($13 * $56);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($16 * $67);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($20 * $63);
 $90 = Math_fround($88 - $89);
 HEAPF32[$transforms>>2] = $69;
 $91 = (($transforms) + 4|0);
 HEAPF32[$91>>2] = $76;
 $92 = (($transforms) + 8|0);
 HEAPF32[$92>>2] = $83;
 $93 = (($transforms) + 12|0);
 HEAPF32[$93>>2] = $90;
 $94 = (($transforms) + 16|0);
 HEAPF32[$94>>2] = $49;
 $95 = (($transforms) + 20|0);
 HEAPF32[$95>>2] = $52;
 $96 = (($transforms) + 24|0);
 HEAPF32[$96>>2] = $55;
 $97 = (($joint) + 44|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($98 * Math_fround(2.0));
 $100 = (($joint) + 48|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($101 * Math_fround(2.0));
 $103 = (($joint) + 52|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($104 * Math_fround(2.0));
 $106 = (($childPose) + 12|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($107 * $107);
 $109 = Math_fround($108 + Math_fround(-0.5));
 $110 = Math_fround(HEAPF32[$childPose>>2]);
 $111 = Math_fround($99 * $110);
 $112 = (($childPose) + 4|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($102 * $113);
 $115 = Math_fround($111 + $114);
 $116 = (($childPose) + 8|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($105 * $117);
 $119 = Math_fround($115 + $118);
 $120 = Math_fround($99 * $109);
 $121 = Math_fround($105 * $113);
 $122 = Math_fround($102 * $117);
 $123 = Math_fround($121 - $122);
 $124 = Math_fround($107 * $123);
 $125 = Math_fround($120 + $124);
 $126 = Math_fround($110 * $119);
 $127 = Math_fround($126 + $125);
 $128 = Math_fround($102 * $109);
 $129 = Math_fround($99 * $117);
 $130 = Math_fround($105 * $110);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($107 * $131);
 $133 = Math_fround($128 + $132);
 $134 = Math_fround($113 * $119);
 $135 = Math_fround($134 + $133);
 $136 = Math_fround($105 * $109);
 $137 = Math_fround($102 * $110);
 $138 = Math_fround($99 * $113);
 $139 = Math_fround($137 - $138);
 $140 = Math_fround($107 * $139);
 $141 = Math_fround($136 + $140);
 $142 = Math_fround($117 * $119);
 $143 = Math_fround($141 + $142);
 $144 = (($childPose) + 16|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround($145 + $127);
 $147 = (($childPose) + 20|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = Math_fround($148 + $135);
 $150 = (($childPose) + 24|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = Math_fround($151 + $143);
 $153 = (($joint) + 28|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = Math_fround($107 * $154);
 $156 = (($joint) + 40|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = Math_fround($110 * $157);
 $159 = Math_fround($155 + $158);
 $160 = (($joint) + 36|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = Math_fround($113 * $161);
 $163 = Math_fround($159 + $162);
 $164 = (($joint) + 32|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = Math_fround($117 * $165);
 $167 = Math_fround($163 - $166);
 $168 = Math_fround($107 * $165);
 $169 = Math_fround($113 * $157);
 $170 = Math_fround($169 + $168);
 $171 = Math_fround($117 * $154);
 $172 = Math_fround($171 + $170);
 $173 = Math_fround($110 * $161);
 $174 = Math_fround($172 - $173);
 $175 = Math_fround($107 * $161);
 $176 = Math_fround($117 * $157);
 $177 = Math_fround($176 + $175);
 $178 = Math_fround($110 * $165);
 $179 = Math_fround($178 + $177);
 $180 = Math_fround($113 * $154);
 $181 = Math_fround($179 - $180);
 $182 = Math_fround($107 * $157);
 $183 = Math_fround($110 * $154);
 $184 = Math_fround($182 - $183);
 $185 = Math_fround($113 * $165);
 $186 = Math_fround($184 - $185);
 $187 = Math_fround($117 * $161);
 $188 = Math_fround($186 - $187);
 $189 = (($transforms) + 28|0);
 HEAPF32[$189>>2] = $167;
 $190 = (($transforms) + 32|0);
 HEAPF32[$190>>2] = $174;
 $191 = (($transforms) + 36|0);
 HEAPF32[$191>>2] = $181;
 $192 = (($transforms) + 40|0);
 HEAPF32[$192>>2] = $188;
 $193 = (($transforms) + 44|0);
 HEAPF32[$193>>2] = $146;
 $194 = (($transforms) + 48|0);
 HEAPF32[$194>>2] = $149;
 $195 = (($transforms) + 52|0);
 HEAPF32[$195>>2] = $152;
 $196 = Math_fround(HEAPF32[$transforms>>2]);
 $197 = Math_fround(-$196);
 $198 = Math_fround(HEAPF32[$91>>2]);
 $199 = Math_fround(-$198);
 $200 = Math_fround(HEAPF32[$92>>2]);
 $201 = Math_fround(-$200);
 $202 = Math_fround(HEAPF32[$93>>2]);
 $203 = Math_fround(HEAPF32[$94>>2]);
 $204 = Math_fround($146 - $203);
 $205 = Math_fround(HEAPF32[$95>>2]);
 $206 = Math_fround($149 - $205);
 $207 = Math_fround(HEAPF32[$96>>2]);
 $208 = Math_fround($152 - $207);
 $209 = Math_fround($204 * Math_fround(2.0));
 $210 = Math_fround($206 * Math_fround(2.0));
 $211 = Math_fround($208 * Math_fround(2.0));
 $212 = Math_fround($202 * $202);
 $213 = Math_fround($212 + Math_fround(-0.5));
 $214 = Math_fround($209 * $197);
 $215 = Math_fround($210 * $199);
 $216 = Math_fround($214 + $215);
 $217 = Math_fround($211 * $201);
 $218 = Math_fround($216 + $217);
 $219 = Math_fround($213 * $209);
 $220 = Math_fround($211 * $199);
 $221 = Math_fround($210 * $201);
 $222 = Math_fround($220 - $221);
 $223 = Math_fround($202 * $222);
 $224 = Math_fround($219 + $223);
 $225 = Math_fround($218 * $197);
 $226 = Math_fround($225 + $224);
 $227 = Math_fround($213 * $210);
 $228 = Math_fround($209 * $201);
 $229 = Math_fround($211 * $197);
 $230 = Math_fround($228 - $229);
 $231 = Math_fround($202 * $230);
 $232 = Math_fround($227 + $231);
 $233 = Math_fround($218 * $199);
 $234 = Math_fround($233 + $232);
 $235 = Math_fround($213 * $211);
 $236 = Math_fround($210 * $197);
 $237 = Math_fround($209 * $199);
 $238 = Math_fround($236 - $237);
 $239 = Math_fround($202 * $238);
 $240 = Math_fround($235 + $239);
 $241 = Math_fround($218 * $201);
 $242 = Math_fround($240 + $241);
 $243 = Math_fround($202 * $167);
 $244 = Math_fround($188 * $197);
 $245 = Math_fround($243 + $244);
 $246 = Math_fround($181 * $199);
 $247 = Math_fround($245 + $246);
 $248 = Math_fround($174 * $201);
 $249 = Math_fround($247 - $248);
 $250 = Math_fround($202 * $174);
 $251 = Math_fround($188 * $199);
 $252 = Math_fround($251 + $250);
 $253 = Math_fround($167 * $201);
 $254 = Math_fround($253 + $252);
 $255 = Math_fround($181 * $197);
 $256 = Math_fround($254 - $255);
 $257 = Math_fround($202 * $181);
 $258 = Math_fround($188 * $201);
 $259 = Math_fround($258 + $257);
 $260 = Math_fround($174 * $197);
 $261 = Math_fround($260 + $259);
 $262 = Math_fround($167 * $199);
 $263 = Math_fround($261 - $262);
 $264 = Math_fround($202 * $188);
 $265 = Math_fround($167 * $197);
 $266 = Math_fround($264 - $265);
 $267 = Math_fround($174 * $199);
 $268 = Math_fround($266 - $267);
 $269 = Math_fround($181 * $201);
 $270 = Math_fround($268 - $269);
 $271 = (($transforms) + 56|0);
 HEAPF32[$271>>2] = $249;
 $272 = (($transforms) + 60|0);
 HEAPF32[$272>>2] = $256;
 $273 = (($transforms) + 64|0);
 HEAPF32[$273>>2] = $263;
 $274 = (($transforms) + 68|0);
 HEAPF32[$274>>2] = $270;
 $275 = (($transforms) + 72|0);
 HEAPF32[$275>>2] = $226;
 $276 = (($transforms) + 76|0);
 HEAPF32[$276>>2] = $234;
 $277 = (($transforms) + 80|0);
 HEAPF32[$277>>2] = $242;
 $278 = $270 < Math_fround(0.0);
 if (!($278)) {
  STACKTOP = sp;return;
 }
 $279 = Math_fround(-$249);
 $280 = Math_fround(-$256);
 $281 = Math_fround(-$263);
 $282 = Math_fround(-$270);
 HEAPF32[$271>>2] = $279;
 HEAPF32[$272>>2] = $280;
 HEAPF32[$273>>2] = $281;
 HEAPF32[$274>>2] = $282;
 $283 = Math_fround(HEAPF32[$189>>2]);
 $284 = Math_fround(-$283);
 $285 = Math_fround(HEAPF32[$190>>2]);
 $286 = Math_fround(-$285);
 $287 = Math_fround(HEAPF32[$191>>2]);
 $288 = Math_fround(-$287);
 $289 = Math_fround(-$188);
 HEAPF32[$189>>2] = $284;
 HEAPF32[$190>>2] = $286;
 HEAPF32[$191>>2] = $288;
 HEAPF32[$192>>2] = $289;
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper30computeUnconstrainedVelocitiesERKNS_25PxcArticulationSolverDescEfRNS_24PxcConstraintBlockStreamEPNS_23PxcSolverConstraintDescERjRNS_2Cm13EventProfilerERNS_25PxsConstraintBlockManagerE($desc,$dt,$stream,$constraintDesc,$acCount,$profiler,$constraintBlockManager) {
 $desc = $desc|0;
 $dt = Math_fround($dt);
 $stream = $stream|0;
 $constraintDesc = $constraintDesc|0;
 $acCount = $acCount|0;
 $profiler = $profiler|0;
 $constraintBlockManager = $constraintBlockManager|0;
 var $$byval_copy5 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0;
 var $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $a = 0, $drive = 0, $esf = 0, $exitcond = 0, $exitcond111 = 0, $exitcond112 = 0, $i$0107 = 0, $i1$0104 = 0, $i2$0102 = 0, $inEnabled$not$i$i$i1 = 0, $inEnabled$not$i$i$i12 = 0, $inEnabled$not$i$i$i21 = 0, $inEnabled$not$i$i$i24 = 0, $inEnabled$not$i$i$i30 = 0, $inEnabled$not$i$i$i42 = 0, $inEnabled$not$i$i$i48 = 0, $inEnabled$not$i$i$i51 = 0, $inEnabled$not$i$i$i6 = 0;
 var $inEnabled$not$i$i$i60 = 0, $inEnabled$not$i$i$i63 = 0, $isf = 0, $or$cond$i$i$i13 = 0, $or$cond$i$i$i2 = 0, $or$cond$i$i$i22 = 0, $or$cond$i$i$i25 = 0, $or$cond$i$i$i31 = 0, $or$cond$i$i$i43 = 0, $or$cond$i$i$i49 = 0, $or$cond$i$i$i52 = 0, $or$cond$i$i$i61 = 0, $or$cond$i$i$i64 = 0, $or$cond$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3696|0;
 $$byval_copy5 = sp + 32|0;
 $isf = sp + 3416|0;
 $esf = sp + 3136|0;
 $drive = sp + 2080|0;
 $0 = sp + 3684|0;
 $1 = sp + 3672|0;
 $2 = sp + 3392|0;
 $3 = sp + 3404|0;
 $a = sp;
 $4 = sp + 3104|0;
 $5 = (($desc) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($desc) + 36|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = HEAP32[$desc>>2]|0;
 $10 = (($desc) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($desc) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($desc) + 38|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15&65535;
 $17 = $8&65535;
 $18 = ($17*144)|0;
 $19 = (($13) + ($18)|0);
 $20 = ($17*240)|0;
 $21 = (($profiler) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $profiler;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAPU16[545784>>1]|(HEAPU16[545784+2>>1]<<16);
 $30 = $29 & 16711680;
 $inEnabled$not$i$i$i6 = ($30|0)==(0);
 $31 = ($22|0)==(0|0);
 $or$cond$i$i$i7 = $31 | $inEnabled$not$i$i$i6;
 if ($or$cond$i$i$i7) {
  $43 = (($desc) + 32|0);
  $44 = HEAP16[$43>>1]|0;
  $45 = $44&65535;
  __ZN5physx21PxcArticulationHelper16prepareDataBlockERNS_9PxcFsDataEPKNS_19PxsArticulationLinkEtPNS_11PxTransformEPNS_12PxcFsInertiaEPNS_30PxcArticulationJointTransformsEj($9,$6,$8,$11,$13,$19,$45);
 } else {
  $32 = $29&65535;
  $33 = HEAP32[$22>>2]|0;
  $34 = (($33) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_viiii[$35 & 511]($22,$32,$25,$28);
  $36 = (($desc) + 32|0);
  $37 = HEAP16[$36>>1]|0;
  $38 = $37&65535;
  __ZN5physx21PxcArticulationHelper16prepareDataBlockERNS_9PxcFsDataEPKNS_19PxsArticulationLinkEtPNS_11PxTransformEPNS_12PxcFsInertiaEPNS_30PxcArticulationJointTransformsEj($9,$6,$8,$11,$13,$19,$38);
  $39 = HEAP32[$22>>2]|0;
  $40 = (($39) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = $29&65535;
  FUNCTION_TABLE_viiii[$41 & 511]($22,$42,$25,$28);
 }
 $46 = Math_fround(Math_fround(1.0) / $dt);
 $47 = (($9) + 128|0);
 $48 = HEAP32[$21>>2]|0;
 $49 = $profiler;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAPU16[545792>>1]|(HEAPU16[545792+2>>1]<<16);
 $56 = $55 & 16711680;
 $inEnabled$not$i$i$i21 = ($56|0)==(0);
 $57 = ($48|0)==(0|0);
 $or$cond$i$i$i22 = $57 | $inEnabled$not$i$i$i21;
 if (!($or$cond$i$i$i22)) {
  $58 = $55&65535;
  $59 = HEAP32[$48>>2]|0;
  $60 = (($59) + 8|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_viiii[$61 & 511]($48,$58,$51,$54);
 }
 $62 = (($9) + 24|0);
 $63 = HEAP16[$62>>1]|0;
 $64 = $63&65535;
 $65 = (($9) + ($64)|0);
 $66 = ($17*400)|0;
 _memset(($65|0),0,($66|0))|0;
 __ZN5physx21PxcArticulationHelper16prepareLtbMatrixERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKNS_11PxTransformEPKNS_30PxcArticulationJointTransformsEf($9,$13,$11,$19,$46);
 __ZN5physx12PxcLtbFactorERNS_9PxcFsDataE($9);
 __ZN5physx15PxcLtbComputeJvEPNS_6shdfnd3aos5Vec3VERKNS_9PxcFsDataEPKNS_14PxcSIMDSpatialE($$byval_copy5,$9,$47);
 $67 = HEAP16[$62>>1]|0;
 $68 = $67&65535;
 $69 = (($9) + ($68)|0);
 $70 = ($8&65535)>(1);
 if ($70) {
  $i$0107 = 1;
  while(1) {
   $71 = (($$byval_copy5) + ($i$0107<<4)|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = ((($$byval_copy5) + ($i$0107<<4)|0) + 4|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = ((($$byval_copy5) + ($i$0107<<4)|0) + 8|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = ((($$byval_copy5) + ($i$0107<<4)|0) + 12|0);
   $78 = ((($69) + (($i$0107*400)|0)|0) + 384|0);
   $79 = Math_fround(HEAPF32[$78>>2]);
   $80 = ((($69) + (($i$0107*400)|0)|0) + 388|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   $82 = ((($69) + (($i$0107*400)|0)|0) + 392|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = Math_fround($72 + $79);
   $85 = Math_fround($74 + $81);
   $86 = Math_fround($76 + $83);
   HEAPF32[$71>>2] = $84;
   HEAPF32[$73>>2] = $85;
   HEAPF32[$75>>2] = $86;
   HEAPF32[$77>>2] = Math_fround(0.0);
   $87 = (($i$0107) + 1)|0;
   $exitcond112 = ($87|0)==($17|0);
   if ($exitcond112) {
    break;
   } else {
    $i$0107 = $87;
   }
  }
 }
 __ZN5physx13PxcLtbProjectERKNS_9PxcFsDataEPNS_14PxcSIMDSpatialEPNS_6shdfnd3aos5Vec3VE($9,$47,$$byval_copy5);
 if (!($or$cond$i$i$i22)) {
  $88 = HEAP32[$48>>2]|0;
  $89 = (($88) + 12|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = $55&65535;
  FUNCTION_TABLE_viiii[$90 & 511]($48,$91,$51,$54);
 }
 $92 = HEAP32[$21>>2]|0;
 $93 = $profiler;
 $94 = $93;
 $95 = HEAP32[$94>>2]|0;
 $96 = (($93) + 4)|0;
 $97 = $96;
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAPU16[545800>>1]|(HEAPU16[545800+2>>1]<<16);
 $100 = $99 & 16711680;
 $inEnabled$not$i$i$i48 = ($100|0)==(0);
 $101 = ($92|0)==(0|0);
 $or$cond$i$i$i49 = $101 | $inEnabled$not$i$i$i48;
 if ($or$cond$i$i$i49) {
  $116 = (($9) + 26|0);
  $117 = HEAP16[$116>>1]|0;
  $118 = $117&65535;
  $119 = (($9) + ($118)|0);
  $120 = ($17*160)|0;
  $121 = (($120) + 144)|0;
  _memset(($119|0),0,($121|0))|0;
  __ZN5physx21PxcArticulationHelper13prepareFsDataERNS_9PxcFsDataEPKNS_19PxsArticulationLinkE($9,$6);
 } else {
  $102 = $99&65535;
  $103 = HEAP32[$92>>2]|0;
  $104 = (($103) + 8|0);
  $105 = HEAP32[$104>>2]|0;
  FUNCTION_TABLE_viiii[$105 & 511]($92,$102,$95,$98);
  $106 = (($9) + 26|0);
  $107 = HEAP16[$106>>1]|0;
  $108 = $107&65535;
  $109 = (($9) + ($108)|0);
  $110 = ($17*160)|0;
  $111 = (($110) + 144)|0;
  _memset(($109|0),0,($111|0))|0;
  __ZN5physx21PxcArticulationHelper13prepareFsDataERNS_9PxcFsDataEPKNS_19PxsArticulationLinkE($9,$6);
  $112 = HEAP32[$92>>2]|0;
  $113 = (($112) + 12|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = $99&65535;
  FUNCTION_TABLE_viiii[$114 & 511]($92,$115,$95,$98);
 }
 $122 = HEAP32[$21>>2]|0;
 $123 = $profiler;
 $124 = $123;
 $125 = HEAP32[$124>>2]|0;
 $126 = (($123) + 4)|0;
 $127 = $126;
 $128 = HEAP32[$127>>2]|0;
 $129 = HEAPU16[545808>>1]|(HEAPU16[545808+2>>1]<<16);
 $130 = $129 & 16711680;
 $inEnabled$not$i$i$i63 = ($130|0)==(0);
 $131 = ($122|0)==(0|0);
 $or$cond$i$i$i64 = $131 | $inEnabled$not$i$i$i63;
 if (!($or$cond$i$i$i64)) {
  $132 = $129&65535;
  $133 = HEAP32[$122>>2]|0;
  $134 = (($133) + 8|0);
  $135 = HEAP32[$134>>2]|0;
  FUNCTION_TABLE_viiii[$135 & 511]($122,$132,$125,$128);
 }
 $136 = (($desc) + 24|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (($137) + 4|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = ($139|0)<(0);
 if ($140) {
  $145 = $137;
 } else {
  $141 = (($desc) + 16|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = ($17*48)|0;
  _memset(($142|0),0,($143|0))|0;
  $$pre = HEAP32[$136>>2]|0;
  $145 = $$pre;
 }
 $144 = HEAP32[$145>>2]|0;
 $146 = ($144|0)<(0);
 if (!($146)) {
  $147 = (($desc) + 20|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = ($17*48)|0;
  _memset(($148|0),0,($149|0))|0;
 }
 if ($70) {
  $i1$0104 = 1;
  while(1) {
   $150 = ((($6) + ($i1$0104<<5)|0) + 24|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (($151) + 88|0);
   $153 = Math_fround(HEAPF32[$152>>2]);
   $154 = Math_fround($153 * $dt);
   $155 = Math_fround($154 + Math_fround(1.0));
   $156 = (($151) + 84|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $158 = Math_fround($157 * $dt);
   $159 = Math_fround($158 * $dt);
   $160 = Math_fround($155 + $159);
   $161 = (($151) + 100|0);
   $162 = Math_fround(HEAPF32[$161>>2]);
   $163 = Math_fround(Math_fround(1.0) / $162);
   $164 = Math_fround($163 * $160);
   $165 = (($isf) + ($i1$0104<<2)|0);
   HEAPF32[$165>>2] = $164;
   $166 = (($151) + 104|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = Math_fround(Math_fround(1.0) / $167);
   $169 = Math_fround($168 * $160);
   $170 = (($esf) + ($i1$0104<<2)|0);
   HEAPF32[$170>>2] = $169;
   $171 = (($i1$0104) + 1)|0;
   $exitcond111 = ($171|0)==($17|0);
   if ($exitcond111) {
    break;
   } else {
    $i1$0104 = $171;
   }
  }
 }
 $172 = HEAP32[$21>>2]|0;
 $173 = $profiler;
 $174 = $173;
 $175 = HEAP32[$174>>2]|0;
 $176 = (($173) + 4)|0;
 $177 = $176;
 $178 = HEAP32[$177>>2]|0;
 $179 = HEAPU16[545816>>1]|(HEAPU16[545816+2>>1]<<16);
 $180 = $179 & 16711680;
 $inEnabled$not$i$i$i60 = ($180|0)==(0);
 $181 = ($172|0)==(0|0);
 $or$cond$i$i$i61 = $181 | $inEnabled$not$i$i$i60;
 if (!($or$cond$i$i$i61)) {
  $182 = $179&65535;
  $183 = HEAP32[$172>>2]|0;
  $184 = (($183) + 8|0);
  $185 = HEAP32[$184>>2]|0;
  FUNCTION_TABLE_viiii[$185 & 511]($172,$182,$175,$178);
 }
 $186 = (($desc) + 20|0);
 $187 = HEAP32[$186>>2]|0;
 $188 = HEAP32[$136>>2]|0;
 $189 = HEAP32[$188>>2]|0;
 $190 = $189 & 65535;
 HEAP32[$0>>2] = $13;
 $191 = (($0) + 4|0);
 HEAP32[$191>>2] = $16;
 $192 = (($0) + 8|0);
 HEAP32[$192>>2] = $20;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN5physx26PxcFsComputeJointLoadsSimdERKNS_9PxcFsDataEPKNS_12PxcFsInertiaEPNS_6shdfnd3aos6Mat33VEPKfjjNS_21PxcFsScratchAllocatorE($9,$13,$187,$isf,$17,$190,$$byval_copy5);
 $193 = (($desc) + 16|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = HEAP32[$136>>2]|0;
 $196 = (($195) + 4|0);
 $197 = HEAP32[$196>>2]|0;
 $198 = $197 & 65535;
 HEAP32[$1>>2] = $13;
 $199 = (($1) + 4|0);
 HEAP32[$199>>2] = $16;
 $200 = (($1) + 8|0);
 HEAP32[$200>>2] = $20;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$1+8>>2]|0;
 __ZN5physx26PxcFsComputeJointLoadsSimdERKNS_9PxcFsDataEPKNS_12PxcFsInertiaEPNS_6shdfnd3aos6Mat33VEPKfjjNS_21PxcFsScratchAllocatorE($9,$13,$194,$esf,$17,$198,$$byval_copy5);
 if (!($or$cond$i$i$i61)) {
  $201 = HEAP32[$172>>2]|0;
  $202 = (($201) + 12|0);
  $203 = HEAP32[$202>>2]|0;
  $204 = $179&65535;
  FUNCTION_TABLE_viiii[$203 & 511]($172,$204,$175,$178);
 }
 $205 = HEAP32[$21>>2]|0;
 $206 = $profiler;
 $207 = $206;
 $208 = HEAP32[$207>>2]|0;
 $209 = (($206) + 4)|0;
 $210 = $209;
 $211 = HEAP32[$210>>2]|0;
 $212 = HEAPU16[545824>>1]|(HEAPU16[545824+2>>1]<<16);
 $213 = $212 & 16711680;
 $inEnabled$not$i$i$i51 = ($213|0)==(0);
 $214 = ($205|0)==(0|0);
 $or$cond$i$i$i52 = $214 | $inEnabled$not$i$i$i51;
 if ($or$cond$i$i$i52) {
  $226 = HEAP32[$186>>2]|0;
  HEAP32[$2>>2] = $13;
  $227 = (($2) + 4|0);
  HEAP32[$227>>2] = $16;
  $228 = (($2) + 8|0);
  HEAP32[$228>>2] = $20;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$2+8>>2]|0;
  __ZN5physx31PxcFsPropagateDrivenInertiaSimdERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKfPKNS_6shdfnd3aos6Mat33VENS_21PxcFsScratchAllocatorE($9,$13,$isf,$226,$$byval_copy5);
 } else {
  $215 = $212&65535;
  $216 = HEAP32[$205>>2]|0;
  $217 = (($216) + 8|0);
  $218 = HEAP32[$217>>2]|0;
  FUNCTION_TABLE_viiii[$218 & 511]($205,$215,$208,$211);
  $219 = HEAP32[$186>>2]|0;
  HEAP32[$2>>2] = $13;
  $220 = (($2) + 4|0);
  HEAP32[$220>>2] = $16;
  $221 = (($2) + 8|0);
  HEAP32[$221>>2] = $20;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$2+8>>2]|0;
  __ZN5physx31PxcFsPropagateDrivenInertiaSimdERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKfPKNS_6shdfnd3aos6Mat33VENS_21PxcFsScratchAllocatorE($9,$13,$isf,$219,$$byval_copy5);
  $222 = HEAP32[$205>>2]|0;
  $223 = (($222) + 12|0);
  $224 = HEAP32[$223>>2]|0;
  $225 = $212&65535;
  FUNCTION_TABLE_viiii[$224 & 511]($205,$225,$208,$211);
 }
 $229 = HEAP32[$21>>2]|0;
 $230 = $profiler;
 $231 = $230;
 $232 = HEAP32[$231>>2]|0;
 $233 = (($230) + 4)|0;
 $234 = $233;
 $235 = HEAP32[$234>>2]|0;
 $236 = HEAPU16[545832>>1]|(HEAPU16[545832+2>>1]<<16);
 $237 = $236 & 16711680;
 $inEnabled$not$i$i$i42 = ($237|0)==(0);
 $238 = ($229|0)==(0|0);
 $or$cond$i$i$i43 = $238 | $inEnabled$not$i$i$i42;
 if ($or$cond$i$i$i43) {
  $239 = HEAP32[$186>>2]|0;
  __ZN5physx21PxcArticulationHelper18computeJointDrivesERNS_9PxcFsDataEPNS_6shdfnd3aos5Vec3VEPKNS_19PxsArticulationLinkEPKNS_11PxTransformEPKNS_30PxcArticulationJointTransformsEPKNS4_6Mat33VEf($9,$drive,$6,$11,$19,$239,$dt);
 } else {
  $240 = $236&65535;
  $241 = HEAP32[$229>>2]|0;
  $242 = (($241) + 8|0);
  $243 = HEAP32[$242>>2]|0;
  FUNCTION_TABLE_viiii[$243 & 511]($229,$240,$232,$235);
  $244 = HEAP32[$186>>2]|0;
  __ZN5physx21PxcArticulationHelper18computeJointDrivesERNS_9PxcFsDataEPNS_6shdfnd3aos5Vec3VEPKNS_19PxsArticulationLinkEPKNS_11PxTransformEPKNS_30PxcArticulationJointTransformsEPKNS4_6Mat33VEf($9,$drive,$6,$11,$19,$244,$dt);
  $245 = HEAP32[$229>>2]|0;
  $246 = (($245) + 12|0);
  $247 = HEAP32[$246>>2]|0;
  $248 = $236&65535;
  FUNCTION_TABLE_viiii[$247 & 511]($229,$248,$232,$235);
 }
 $249 = HEAP32[$21>>2]|0;
 $250 = $profiler;
 $251 = $250;
 $252 = HEAP32[$251>>2]|0;
 $253 = (($250) + 4)|0;
 $254 = $253;
 $255 = HEAP32[$254>>2]|0;
 $256 = HEAPU16[545840>>1]|(HEAPU16[545840+2>>1]<<16);
 $257 = $256 & 16711680;
 $inEnabled$not$i$i$i30 = ($257|0)==(0);
 $258 = ($249|0)==(0|0);
 $or$cond$i$i$i31 = $258 | $inEnabled$not$i$i$i30;
 if ($or$cond$i$i$i31) {
  __ZN5physx21PxcFsApplyJointDrivesERNS_9PxcFsDataEPKNS_6shdfnd3aos5Vec3VE($9,$drive);
 } else {
  $259 = $256&65535;
  $260 = HEAP32[$249>>2]|0;
  $261 = (($260) + 8|0);
  $262 = HEAP32[$261>>2]|0;
  FUNCTION_TABLE_viiii[$262 & 511]($249,$259,$252,$255);
  __ZN5physx21PxcFsApplyJointDrivesERNS_9PxcFsDataEPKNS_6shdfnd3aos5Vec3VE($9,$drive);
  $263 = HEAP32[$249>>2]|0;
  $264 = (($263) + 12|0);
  $265 = HEAP32[$264>>2]|0;
  $266 = $256&65535;
  FUNCTION_TABLE_viiii[$265 & 511]($249,$266,$252,$255);
 }
 $267 = HEAP32[$21>>2]|0;
 $268 = $profiler;
 $269 = $268;
 $270 = HEAP32[$269>>2]|0;
 $271 = (($268) + 4)|0;
 $272 = $271;
 $273 = HEAP32[$272>>2]|0;
 $274 = HEAPU16[545824>>1]|(HEAPU16[545824+2>>1]<<16);
 $275 = $274 & 16711680;
 $inEnabled$not$i$i$i24 = ($275|0)==(0);
 $276 = ($267|0)==(0|0);
 $or$cond$i$i$i25 = $276 | $inEnabled$not$i$i$i24;
 if ($or$cond$i$i$i25) {
  $288 = HEAP32[$193>>2]|0;
  HEAP32[$3>>2] = $13;
  $289 = (($3) + 4|0);
  HEAP32[$289>>2] = $16;
  $290 = (($3) + 8|0);
  HEAP32[$290>>2] = $20;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$3+8>>2]|0;
  __ZN5physx31PxcFsPropagateDrivenInertiaSimdERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKfPKNS_6shdfnd3aos6Mat33VENS_21PxcFsScratchAllocatorE($9,$13,$esf,$288,$$byval_copy5);
 } else {
  $277 = $274&65535;
  $278 = HEAP32[$267>>2]|0;
  $279 = (($278) + 8|0);
  $280 = HEAP32[$279>>2]|0;
  FUNCTION_TABLE_viiii[$280 & 511]($267,$277,$270,$273);
  $281 = HEAP32[$193>>2]|0;
  HEAP32[$3>>2] = $13;
  $282 = (($3) + 4|0);
  HEAP32[$282>>2] = $16;
  $283 = (($3) + 8|0);
  HEAP32[$283>>2] = $20;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$3+8>>2]|0;
  __ZN5physx31PxcFsPropagateDrivenInertiaSimdERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKfPKNS_6shdfnd3aos6Mat33VENS_21PxcFsScratchAllocatorE($9,$13,$esf,$281,$$byval_copy5);
  $284 = HEAP32[$267>>2]|0;
  $285 = (($284) + 12|0);
  $286 = HEAP32[$285>>2]|0;
  $287 = $274&65535;
  FUNCTION_TABLE_viiii[$286 & 511]($267,$287,$270,$273);
 }
 if (!($or$cond$i$i$i64)) {
  $291 = HEAP32[$122>>2]|0;
  $292 = (($291) + 12|0);
  $293 = HEAP32[$292>>2]|0;
  $294 = $129&65535;
  FUNCTION_TABLE_viiii[$293 & 511]($122,$294,$125,$128);
 }
 $295 = HEAP32[$21>>2]|0;
 $296 = $profiler;
 $297 = $296;
 $298 = HEAP32[$297>>2]|0;
 $299 = (($296) + 4)|0;
 $300 = $299;
 $301 = HEAP32[$300>>2]|0;
 $302 = HEAPU16[545848>>1]|(HEAPU16[545848+2>>1]<<16);
 $303 = $302 & 16711680;
 $inEnabled$not$i$i$i12 = ($303|0)==(0);
 $304 = ($295|0)==(0|0);
 $or$cond$i$i$i13 = $304 | $inEnabled$not$i$i$i12;
 if (!($or$cond$i$i$i13)) {
  $305 = $302&65535;
  $306 = HEAP32[$295>>2]|0;
  $307 = (($306) + 8|0);
  $308 = HEAP32[$307>>2]|0;
  FUNCTION_TABLE_viiii[$308 & 511]($295,$305,$298,$301);
 }
 $309 = ($8<<16>>16)==(0);
 if (!($309)) {
  $310 = (($a) + 4|0);
  $311 = (($a) + 8|0);
  $312 = (($a) + 12|0);
  $313 = (($a) + 16|0);
  $314 = (($a) + 20|0);
  $315 = (($a) + 24|0);
  $316 = (($a) + 28|0);
  $317 = (($4) + 4|0);
  $318 = (($4) + 8|0);
  $319 = (($4) + 16|0);
  $320 = (($4) + 20|0);
  $321 = (($4) + 24|0);
  $i2$0102 = 0;
  while(1) {
   $322 = ((($6) + ($i2$0102<<5)|0) + 16|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = Math_fround(HEAPF32[$323>>2]);
   $325 = (($323) + 4|0);
   $326 = Math_fround(HEAPF32[$325>>2]);
   $327 = (($323) + 8|0);
   $328 = Math_fround(HEAPF32[$327>>2]);
   $329 = (($323) + 16|0);
   $330 = Math_fround(HEAPF32[$329>>2]);
   $331 = (($323) + 20|0);
   $332 = Math_fround(HEAPF32[$331>>2]);
   $333 = (($323) + 24|0);
   $334 = Math_fround(HEAPF32[$333>>2]);
   HEAPF32[$a>>2] = $324;
   HEAPF32[$310>>2] = $326;
   HEAPF32[$311>>2] = $328;
   HEAPF32[$312>>2] = Math_fround(0.0);
   HEAPF32[$313>>2] = $330;
   HEAPF32[$314>>2] = $332;
   HEAPF32[$315>>2] = $334;
   HEAPF32[$316>>2] = Math_fround(0.0);
   $335 = (($13) + (($i2$0102*144)|0)|0);
   __ZN5physx26PxcArticulationFnsSimdBase8multiplyERKNS_12PxcFsInertiaERKNS_14PxcSIMDSpatialE($4,$335,$a);
   $336 = Math_fround(HEAPF32[$4>>2]);
   $337 = Math_fround(HEAPF32[$317>>2]);
   $338 = Math_fround(HEAPF32[$318>>2]);
   $339 = Math_fround(HEAPF32[$319>>2]);
   $340 = Math_fround(HEAPF32[$320>>2]);
   $341 = Math_fround(HEAPF32[$321>>2]);
   $342 = Math_fround($336 * $dt);
   $343 = Math_fround(-$342);
   $344 = Math_fround($337 * $dt);
   $345 = Math_fround(-$344);
   $346 = Math_fround($338 * $dt);
   $347 = Math_fround(-$346);
   $348 = Math_fround($339 * $dt);
   $349 = Math_fround(-$348);
   $350 = Math_fround($340 * $dt);
   $351 = Math_fround(-$350);
   $352 = Math_fround($341 * $dt);
   $353 = Math_fround(-$352);
   $354 = (($$byval_copy5) + ($i2$0102<<5)|0);
   HEAPF32[$354>>2] = $343;
   $355 = ((($$byval_copy5) + ($i2$0102<<5)|0) + 4|0);
   HEAPF32[$355>>2] = $345;
   $356 = ((($$byval_copy5) + ($i2$0102<<5)|0) + 8|0);
   HEAPF32[$356>>2] = $347;
   $357 = ((($$byval_copy5) + ($i2$0102<<5)|0) + 12|0);
   HEAPF32[$357>>2] = Math_fround(0.0);
   $358 = ((($$byval_copy5) + ($i2$0102<<5)|0) + 16|0);
   HEAPF32[$358>>2] = $349;
   $359 = ((($$byval_copy5) + ($i2$0102<<5)|0) + 20|0);
   HEAPF32[$359>>2] = $351;
   $360 = ((($$byval_copy5) + ($i2$0102<<5)|0) + 24|0);
   HEAPF32[$360>>2] = $353;
   $361 = ((($$byval_copy5) + ($i2$0102<<5)|0) + 28|0);
   HEAPF32[$361>>2] = Math_fround(0.0);
   $362 = (($i2$0102) + 1)|0;
   $exitcond = ($362|0)==($17|0);
   if ($exitcond) {
    break;
   } else {
    $i2$0102 = $362;
   }
  }
 }
 __ZN5physx21PxcArticulationHelper13applyImpulsesERKNS_9PxcFsDataEPNS_14PxcSIMDSpatialES5_($9,$$byval_copy5,$47);
 if (!($or$cond$i$i$i13)) {
  $363 = HEAP32[$295>>2]|0;
  $364 = (($363) + 12|0);
  $365 = HEAP32[$364>>2]|0;
  $366 = $302&65535;
  FUNCTION_TABLE_viiii[$365 & 511]($295,$366,$298,$301);
 }
 $367 = (($desc) + 8|0);
 $368 = HEAP32[$367>>2]|0;
 $369 = $17 << 5;
 _memcpy(($368|0),($47|0),($369|0))|0;
 $370 = (($9) + 16|0);
 $371 = $370;
 $372 = $371;
 HEAP32[$372>>2] = 0;
 $373 = (($371) + 4)|0;
 $374 = $373;
 HEAP32[$374>>2] = 0;
 $375 = (($9) + 12|0);
 HEAP16[$375>>1] = 0;
 $376 = (($9) + 14|0);
 HEAP16[$376>>1] = 0;
 $377 = (($9) + 28|0);
 HEAP32[$377>>2] = 0;
 $378 = HEAP32[$21>>2]|0;
 $379 = $profiler;
 $380 = $379;
 $381 = HEAP32[$380>>2]|0;
 $382 = (($379) + 4)|0;
 $383 = $382;
 $384 = HEAP32[$383>>2]|0;
 $385 = HEAPU16[545856>>1]|(HEAPU16[545856+2>>1]<<16);
 $386 = $385 & 16711680;
 $inEnabled$not$i$i$i1 = ($386|0)==(0);
 $387 = ($378|0)==(0|0);
 $or$cond$i$i$i2 = $387 | $inEnabled$not$i$i$i1;
 if (!($or$cond$i$i$i2)) {
  $388 = $385&65535;
  $389 = HEAP32[$378>>2]|0;
  $390 = (($389) + 8|0);
  $391 = HEAP32[$390>>2]|0;
  FUNCTION_TABLE_viiii[$391 & 511]($378,$388,$381,$384);
 }
 $392 = (($desc) + 34|0);
 $393 = HEAP16[$392>>1]|0;
 $394 = $393&65535;
 $395 = (__ZN5physx21PxcArticulationHelper22setupSolverConstraintsERNS_9PxcFsDataEjRNS_24PxcConstraintBlockStreamEPNS_23PxcSolverConstraintDescEPKNS_19PxsArticulationLinkEPKNS_30PxcArticulationJointTransformsEfRjRNS_25PxsConstraintBlockManagerE($9,$394,$stream,$constraintDesc,$6,$19,$dt,$acCount,$constraintBlockManager)|0);
 if ($or$cond$i$i$i2) {
  STACKTOP = sp;return ($395|0);
 }
 $396 = HEAP32[$378>>2]|0;
 $397 = (($396) + 12|0);
 $398 = HEAP32[$397>>2]|0;
 $399 = $385&65535;
 FUNCTION_TABLE_viiii[$398 & 511]($378,$399,$381,$384);
 STACKTOP = sp;return ($395|0);
}
function __ZN5physx21PxcArticulationHelper16prepareLtbMatrixERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKNS_11PxTransformEPKNS_30PxcArticulationJointTransformsEf($fsData,$baseInertia,$poses,$jointTransforms,$recipDt) {
 $fsData = $fsData|0;
 $baseInertia = $baseInertia|0;
 $poses = $poses|0;
 $jointTransforms = $jointTransforms|0;
 $recipDt = Math_fround($recipDt);
 var $$sum = 0, $$sum47 = 0, $$sum48 = 0, $$sum49 = 0, $$sum50 = 0, $$sum51 = 0, $$sum52 = 0, $$sum53 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0;
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $axis = 0, $exitcond = 0, $exitcond56 = 0, $i$055 = 0, $j$054 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $axis = sp;
 $0 = (($fsData) + 8|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($fsData) + 24|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($fsData) + ($4)|0);
 ;HEAP32[$5+0>>2]=HEAP32[$baseInertia+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$baseInertia+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$baseInertia+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$baseInertia+12>>2]|0;
 $$sum = (($4) + 16)|0;
 $6 = (($fsData) + ($$sum)|0);
 $7 = (($baseInertia) + 16|0);
 ;HEAP32[$6+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$7+12>>2]|0;
 $$sum47 = (($4) + 32)|0;
 $8 = (($fsData) + ($$sum47)|0);
 $9 = (($baseInertia) + 32|0);
 ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
 $$sum48 = (($4) + 48)|0;
 $10 = (($fsData) + ($$sum48)|0);
 $11 = (($baseInertia) + 48|0);
 ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
 $$sum49 = (($4) + 64)|0;
 $12 = (($fsData) + ($$sum49)|0);
 $13 = (($baseInertia) + 64|0);
 ;HEAP32[$12+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$13+12>>2]|0;
 $$sum50 = (($4) + 80)|0;
 $14 = (($fsData) + ($$sum50)|0);
 $15 = (($baseInertia) + 80|0);
 ;HEAP32[$14+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$15+12>>2]|0;
 $$sum51 = (($4) + 96)|0;
 $16 = (($fsData) + ($$sum51)|0);
 $17 = (($baseInertia) + 96|0);
 ;HEAP32[$16+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$17+12>>2]|0;
 $$sum52 = (($4) + 112)|0;
 $18 = (($fsData) + ($$sum52)|0);
 $19 = (($baseInertia) + 112|0);
 ;HEAP32[$18+0>>2]=HEAP32[$19+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$19+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$19+12>>2]|0;
 $$sum53 = (($4) + 128)|0;
 $20 = (($fsData) + ($$sum53)|0);
 $21 = (($baseInertia) + 128|0);
 ;HEAP32[$20+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$21+12>>2]|0;
 HEAPF32[$axis>>2] = Math_fround(1.0);
 $22 = (($axis) + 4|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($axis) + 8|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($axis) + 12|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($axis) + 16|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($axis) + 20|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($axis) + 24|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($axis) + 28|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($axis) + 32|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = ($1&65535)>(1);
 if (!($30)) {
  STACKTOP = sp;return;
 }
 $31 = $1&65535;
 $i$055 = 1;
 while(1) {
  $32 = (($5) + (($i$055*400)|0)|0);
  $33 = (($baseInertia) + (($i$055*144)|0)|0);
  ;HEAP32[$32+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$33+12>>2]|0;
  $34 = ((($5) + (($i$055*400)|0)|0) + 16|0);
  $35 = ((($baseInertia) + (($i$055*144)|0)|0) + 16|0);
  ;HEAP32[$34+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$35+12>>2]|0;
  $36 = ((($5) + (($i$055*400)|0)|0) + 32|0);
  $37 = ((($baseInertia) + (($i$055*144)|0)|0) + 32|0);
  ;HEAP32[$36+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$37+12>>2]|0;
  $38 = ((($5) + (($i$055*400)|0)|0) + 48|0);
  $39 = ((($baseInertia) + (($i$055*144)|0)|0) + 48|0);
  ;HEAP32[$38+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$39+12>>2]|0;
  $40 = ((($5) + (($i$055*400)|0)|0) + 64|0);
  $41 = ((($baseInertia) + (($i$055*144)|0)|0) + 64|0);
  ;HEAP32[$40+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$41+12>>2]|0;
  $42 = ((($5) + (($i$055*400)|0)|0) + 80|0);
  $43 = ((($baseInertia) + (($i$055*144)|0)|0) + 80|0);
  ;HEAP32[$42+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$43+12>>2]|0;
  $44 = ((($5) + (($i$055*400)|0)|0) + 96|0);
  $45 = ((($baseInertia) + (($i$055*144)|0)|0) + 96|0);
  ;HEAP32[$44+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$45+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$45+12>>2]|0;
  $46 = ((($5) + (($i$055*400)|0)|0) + 112|0);
  $47 = ((($baseInertia) + (($i$055*144)|0)|0) + 112|0);
  ;HEAP32[$46+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$46+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[$47+8>>2]|0;HEAP32[$46+12>>2]=HEAP32[$47+12>>2]|0;
  $48 = ((($5) + (($i$055*400)|0)|0) + 128|0);
  $49 = ((($baseInertia) + (($i$055*144)|0)|0) + 128|0);
  ;HEAP32[$48+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$48+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$48+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$48+12>>2]=HEAP32[$49+12>>2]|0;
  $50 = ((($fsData) + ($i$055)|0) + 64|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51&255;
  $53 = ((($jointTransforms) + (($i$055*84)|0)|0) + 44|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = ((($poses) + (($52*28)|0)|0) + 16|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($54 - $56);
  $58 = ((($jointTransforms) + (($i$055*84)|0)|0) + 48|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($poses) + (($52*28)|0)|0) + 20|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($59 - $61);
  $63 = ((($jointTransforms) + (($i$055*84)|0)|0) + 52|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = ((($poses) + (($52*28)|0)|0) + 24|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($64 - $66);
  $68 = ((($poses) + (($i$055*28)|0)|0) + 16|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($54 - $69);
  $71 = ((($poses) + (($i$055*28)|0)|0) + 20|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($59 - $72);
  $74 = ((($poses) + (($i$055*28)|0)|0) + 24|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($64 - $75);
  $77 = ((($jointTransforms) + (($i$055*84)|0)|0) + 16|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = ((($jointTransforms) + (($i$055*84)|0)|0) + 20|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = Math_fround($80 - $59);
  $82 = ((($jointTransforms) + (($i$055*84)|0)|0) + 24|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($83 - $64);
  $85 = Math_fround($81 * Math_fround(0.990000009536743164062));
  $j$054 = 0;
  while(1) {
   $86 = (($axis) + (($j$054*12)|0)|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = ((($axis) + (($j$054*12)|0)|0) + 4|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = ((($axis) + (($j$054*12)|0)|0) + 8|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = Math_fround($62 * $91);
   $93 = Math_fround($67 * $89);
   $94 = Math_fround($92 - $93);
   $95 = Math_fround($67 * $87);
   $96 = Math_fround($57 * $91);
   $97 = Math_fround($95 - $96);
   $98 = Math_fround($57 * $89);
   $99 = Math_fround($62 * $87);
   $100 = Math_fround($98 - $99);
   $101 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 144|0);
   HEAPF32[$101>>2] = $87;
   $102 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 148|0);
   HEAPF32[$102>>2] = $89;
   $103 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 152|0);
   HEAPF32[$103>>2] = $91;
   $104 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 156|0);
   HEAPF32[$104>>2] = Math_fround(0.0);
   $105 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 160|0);
   HEAPF32[$105>>2] = $94;
   $106 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 164|0);
   HEAPF32[$106>>2] = $97;
   $107 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 168|0);
   HEAPF32[$107>>2] = $100;
   $108 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 172|0);
   HEAPF32[$108>>2] = Math_fround(0.0);
   $109 = Math_fround(-$87);
   $110 = Math_fround(-$89);
   $111 = Math_fround(-$91);
   $112 = Math_fround($73 * $91);
   $113 = Math_fround($76 * $89);
   $114 = Math_fround($112 - $113);
   $115 = Math_fround($76 * $87);
   $116 = Math_fround($70 * $91);
   $117 = Math_fround($115 - $116);
   $118 = Math_fround($70 * $89);
   $119 = Math_fround($73 * $87);
   $120 = Math_fround($118 - $119);
   $121 = Math_fround(-$114);
   $122 = Math_fround(-$117);
   $123 = Math_fround(-$120);
   $124 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 240|0);
   HEAPF32[$124>>2] = $109;
   $125 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 244|0);
   HEAPF32[$125>>2] = $110;
   $126 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 248|0);
   HEAPF32[$126>>2] = $111;
   $127 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 252|0);
   HEAPF32[$127>>2] = Math_fround(0.0);
   $128 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 256|0);
   HEAPF32[$128>>2] = $121;
   $129 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 260|0);
   HEAPF32[$129>>2] = $122;
   $130 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 264|0);
   HEAPF32[$130>>2] = $123;
   $131 = (((($5) + (($i$055*400)|0)|0) + ($j$054<<5)|0) + 268|0);
   HEAPF32[$131>>2] = Math_fround(0.0);
   $132 = (($j$054) + 1)|0;
   $exitcond = ($132|0)==(3);
   if ($exitcond) {
    break;
   } else {
    $j$054 = $132;
   }
  }
  $133 = Math_fround($78 - $54);
  $134 = Math_fround($133 * Math_fround(0.990000009536743164062));
  $135 = Math_fround($84 * Math_fround(0.990000009536743164062));
  $136 = Math_fround($134 * $recipDt);
  $137 = Math_fround($85 * $recipDt);
  $138 = Math_fround($135 * $recipDt);
  $139 = ((($5) + (($i$055*400)|0)|0) + 384|0);
  HEAPF32[$139>>2] = $136;
  $140 = ((($5) + (($i$055*400)|0)|0) + 388|0);
  HEAPF32[$140>>2] = $137;
  $141 = ((($5) + (($i$055*400)|0)|0) + 392|0);
  HEAPF32[$141>>2] = $138;
  $142 = ((($5) + (($i$055*400)|0)|0) + 396|0);
  HEAPF32[$142>>2] = Math_fround(0.0);
  $143 = (($i$055) + 1)|0;
  $exitcond56 = ($143|0)==($31|0);
  if ($exitcond56) {
   break;
  } else {
   $i$055 = $143;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper13prepareFsDataERNS_9PxcFsDataEPKNS_19PxsArticulationLinkE($fsData,$links) {
 $fsData = $fsData|0;
 $links = $links|0;
 var $$sum = 0, $$sum$i = 0, $$sum$i1 = 0, $$sum54 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond = 0, $i$055 = 0, $tmp1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($fsData) + 8|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = (($fsData) + 26|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $$sum$i = (($5) + 144)|0;
 $6 = (($fsData) + ($$sum$i)|0);
 $7 = (($fsData) + 24|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $tmp1$i = ($2*432)|0;
 $$sum$i1 = (($9) + ($tmp1$i))|0;
 $10 = (($fsData) + ($$sum$i1)|0);
 $11 = (($fsData) + 10|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12&65535;
 $14 = (($fsData) + ($13)|0);
 $15 = $links;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $$sum = (($5) + 288)|0;
 $21 = (($fsData) + ($$sum)|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = $17;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $$sum54 = (($5) + 296)|0;
 $26 = (($fsData) + ($$sum54)|0);
 $27 = $26;
 $28 = $27;
 HEAP32[$28>>2] = 1;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = 0;
 $31 = ($1&65535)>(1);
 if ($31) {
  $i$055 = 1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $32 = (($links) + ($i$055<<5)|0);
  $33 = $32;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + 4)|0;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = ((($6) + (($i$055*160)|0)|0) + 144|0);
  $40 = $39;
  $41 = $40;
  HEAP32[$41>>2] = $35;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = $38;
  $44 = ((($links) + ($i$055<<5)|0) + 8|0);
  $45 = $44;
  $46 = $45;
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + 4)|0;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = ((($6) + (($i$055*160)|0)|0) + 152|0);
  $52 = $51;
  $53 = $52;
  HEAP32[$53>>2] = $47;
  $54 = (($52) + 4)|0;
  $55 = $54;
  HEAP32[$55>>2] = $50;
  $56 = ((($14) + ($i$055<<5)|0) + 16|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = ((($14) + ($i$055<<5)|0) + 20|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($14) + ($i$055<<5)|0) + 24|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($59 * Math_fround(0.0));
  $63 = Math_fround($61 * Math_fround(0.0));
  $64 = Math_fround($62 - $63);
  $65 = Math_fround($57 * Math_fround(0.0));
  $66 = Math_fround($61 - $65);
  $67 = Math_fround($65 - $59);
  $68 = Math_fround($64 + Math_fround(0.0));
  $69 = Math_fround($66 + Math_fround(0.0));
  $70 = Math_fround($67 + Math_fround(0.0));
  $71 = (($10) + (($i$055*96)|0)|0);
  HEAPF32[$71>>2] = $68;
  $72 = ((($10) + (($i$055*96)|0)|0) + 4|0);
  HEAPF32[$72>>2] = $69;
  $73 = ((($10) + (($i$055*96)|0)|0) + 8|0);
  HEAPF32[$73>>2] = $70;
  $74 = ((($10) + (($i$055*96)|0)|0) + 12|0);
  HEAPF32[$74>>2] = Math_fround(0.0);
  $75 = ((($10) + (($i$055*96)|0)|0) + 16|0);
  HEAPF32[$75>>2] = Math_fround(1.0);
  $76 = ((($10) + (($i$055*96)|0)|0) + 20|0);
  HEAPF32[$76>>2] = Math_fround(0.0);
  $77 = ((($10) + (($i$055*96)|0)|0) + 24|0);
  HEAPF32[$77>>2] = Math_fround(0.0);
  $78 = ((($10) + (($i$055*96)|0)|0) + 28|0);
  HEAPF32[$78>>2] = Math_fround(0.0);
  $79 = Math_fround($62 - $61);
  $80 = Math_fround($63 - $65);
  $81 = Math_fround($57 - $62);
  $82 = Math_fround($79 + Math_fround(0.0));
  $83 = Math_fround($80 + Math_fround(0.0));
  $84 = Math_fround($81 + Math_fround(0.0));
  $85 = ((($10) + (($i$055*96)|0)|0) + 32|0);
  HEAPF32[$85>>2] = $82;
  $86 = ((($10) + (($i$055*96)|0)|0) + 36|0);
  HEAPF32[$86>>2] = $83;
  $87 = ((($10) + (($i$055*96)|0)|0) + 40|0);
  HEAPF32[$87>>2] = $84;
  $88 = ((($10) + (($i$055*96)|0)|0) + 44|0);
  HEAPF32[$88>>2] = Math_fround(0.0);
  $89 = ((($10) + (($i$055*96)|0)|0) + 48|0);
  HEAPF32[$89>>2] = Math_fround(0.0);
  $90 = ((($10) + (($i$055*96)|0)|0) + 52|0);
  HEAPF32[$90>>2] = Math_fround(1.0);
  $91 = ((($10) + (($i$055*96)|0)|0) + 56|0);
  HEAPF32[$91>>2] = Math_fround(0.0);
  $92 = ((($10) + (($i$055*96)|0)|0) + 60|0);
  HEAPF32[$92>>2] = Math_fround(0.0);
  $93 = Math_fround($59 - $63);
  $94 = Math_fround($63 - $57);
  $95 = Math_fround($65 - $62);
  $96 = Math_fround($93 + Math_fround(0.0));
  $97 = Math_fround($94 + Math_fround(0.0));
  $98 = Math_fround($95 + Math_fround(0.0));
  $99 = ((($10) + (($i$055*96)|0)|0) + 64|0);
  HEAPF32[$99>>2] = $96;
  $100 = ((($10) + (($i$055*96)|0)|0) + 68|0);
  HEAPF32[$100>>2] = $97;
  $101 = ((($10) + (($i$055*96)|0)|0) + 72|0);
  HEAPF32[$101>>2] = $98;
  $102 = ((($10) + (($i$055*96)|0)|0) + 76|0);
  HEAPF32[$102>>2] = Math_fround(0.0);
  $103 = ((($10) + (($i$055*96)|0)|0) + 80|0);
  HEAPF32[$103>>2] = Math_fround(0.0);
  $104 = ((($10) + (($i$055*96)|0)|0) + 84|0);
  HEAPF32[$104>>2] = Math_fround(0.0);
  $105 = ((($10) + (($i$055*96)|0)|0) + 88|0);
  HEAPF32[$105>>2] = Math_fround(1.0);
  $106 = ((($10) + (($i$055*96)|0)|0) + 92|0);
  HEAPF32[$106>>2] = Math_fround(0.0);
  $107 = (($i$055) + 1)|0;
  $exitcond = ($107|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $i$055 = $107;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper18computeJointDrivesERNS_9PxcFsDataEPNS_6shdfnd3aos5Vec3VEPKNS_19PxsArticulationLinkEPKNS_11PxTransformEPKNS_30PxcArticulationJointTransformsEPKNS4_6Mat33VEf($fsData,$drives,$links,$poses,$transforms,$loads,$dt) {
 $fsData = $fsData|0;
 $drives = $drives|0;
 $links = $links|0;
 $poses = $poses|0;
 $transforms = $transforms|0;
 $loads = $loads|0;
 $dt = Math_fround($dt);
 var $$sink$i = 0.0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0;
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0;
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0;
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0.0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond = 0, $i$060 = 0, $phitmp = Math_fround(0), $phitmp$i = Math_fround(0), $phitmp10$i = Math_fround(0), $phitmp11$i = Math_fround(0), $phitmp58 = Math_fround(0), $phitmp59 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($fsData) + 8|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($fsData) + 128|0);
 $3 = ($1&65535)>(1);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = $1&65535;
 $i$060 = 1;
 while(1) {
  $5 = ((($links) + ($i$060<<5)|0) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($links) + ($i$060<<5)|0) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($2) + ($i$060<<5)|0) + 24|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = ((($2) + ($i$060<<5)|0) + 20|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = ((($2) + ($i$060<<5)|0) + 16|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = ((($2) + ($6<<5)|0) + 24|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = ((($2) + ($6<<5)|0) + 20|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = ((($2) + ($6<<5)|0) + 16|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($14 - $20);
  $22 = Math_fround($12 - $18);
  $23 = Math_fround($10 - $16);
  $24 = ((($transforms) + (($i$060*84)|0)|0) + 56|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround(-$25);
  $27 = ((($transforms) + (($i$060*84)|0)|0) + 60|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround(-$28);
  $30 = ((($transforms) + (($i$060*84)|0)|0) + 64|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround(-$31);
  $33 = ((($transforms) + (($i$060*84)|0)|0) + 68|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($8) + 68|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($36 * $26);
  $38 = (($8) + 56|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($34 * $39);
  $41 = Math_fround($37 + $40);
  $42 = (($8) + 60|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($43 * $32);
  $45 = Math_fround($41 + $44);
  $46 = (($8) + 64|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($47 * $29);
  $49 = Math_fround($45 - $48);
  $50 = Math_fround($36 * $29);
  $51 = Math_fround($34 * $43);
  $52 = Math_fround($50 + $51);
  $53 = Math_fround($47 * $26);
  $54 = Math_fround($52 + $53);
  $55 = Math_fround($39 * $32);
  $56 = Math_fround($54 - $55);
  $57 = Math_fround($36 * $32);
  $58 = Math_fround($34 * $47);
  $59 = Math_fround($57 + $58);
  $60 = Math_fround($39 * $29);
  $61 = Math_fround($60 + $59);
  $62 = Math_fround($43 * $26);
  $63 = Math_fround($61 - $62);
  $64 = Math_fround($34 * $36);
  $65 = Math_fround($39 * $26);
  $66 = Math_fround($64 - $65);
  $67 = Math_fround($43 * $29);
  $68 = Math_fround($66 - $67);
  $69 = Math_fround($47 * $32);
  $70 = Math_fround($68 - $69);
  $71 = Math_fround($49 * $49);
  $72 = Math_fround($56 * $56);
  $73 = Math_fround($71 + $72);
  $74 = Math_fround($63 * $63);
  $75 = Math_fround($73 + $74);
  $76 = (Math_fround(Math_sqrt((Math_fround($75)))));
  $77 = +$76;
  $78 = $77 < 9.99999999999999979886E-13;
  if ($78) {
   $106 = Math_fround(0.0);$110 = Math_fround(0.0);$115 = Math_fround(0.0);
  } else {
   $79 = $70 < Math_fround(0.0);
   if ($79) {
    $80 = Math_fround(-$76);
    $81 = Math_fround(-$70);
    $82 = +$80;
    $83 = +$81;
    $84 = (+Math_atan2((+$82),(+$83)));
    $$sink$i = $84;
   } else {
    $85 = +$70;
    $86 = (+Math_atan2((+$77),(+$85)));
    $$sink$i = $86;
   }
   $87 = Math_fround($$sink$i);
   $88 = $75 > Math_fround(0.0);
   if ($88) {
    $89 = Math_fround(Math_fround(1.0) / $76);
    $90 = Math_fround($49 * $89);
    $91 = Math_fround($56 * $89);
    $92 = Math_fround($63 * $89);
    $phitmp$i = Math_fround($90 * Math_fround(2.0));
    $phitmp10$i = Math_fround($91 * Math_fround(2.0));
    $phitmp11$i = Math_fround($92 * Math_fround(2.0));
    $94 = $phitmp$i;$96 = $phitmp10$i;$98 = $phitmp11$i;
   } else {
    $94 = Math_fround(0.0);$96 = Math_fround(0.0);$98 = Math_fround(0.0);
   }
   $93 = Math_fround($87 * $94);
   $95 = Math_fround($87 * $96);
   $97 = Math_fround($87 * $98);
   $phitmp = Math_fround($93 * Math_fround(2.0));
   $phitmp58 = Math_fround($95 * Math_fround(2.0));
   $phitmp59 = Math_fround($97 * Math_fround(2.0));
   $106 = $phitmp;$110 = $phitmp58;$115 = $phitmp59;
  }
  $99 = ((($transforms) + (($i$060*84)|0)|0) + 12|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($100 * $100);
  $102 = Math_fround($101 + Math_fround(-0.5));
  $103 = (($transforms) + (($i$060*84)|0)|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = Math_fround($106 * $104);
  $107 = ((($transforms) + (($i$060*84)|0)|0) + 4|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($110 * $108);
  $111 = Math_fround($105 + $109);
  $112 = ((($transforms) + (($i$060*84)|0)|0) + 8|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($115 * $113);
  $116 = Math_fround($111 + $114);
  $117 = Math_fround($106 * $102);
  $118 = Math_fround($115 * $108);
  $119 = Math_fround($110 * $113);
  $120 = Math_fround($118 - $119);
  $121 = Math_fround($100 * $120);
  $122 = Math_fround($117 + $121);
  $123 = Math_fround($104 * $116);
  $124 = Math_fround($123 + $122);
  $125 = Math_fround($110 * $102);
  $126 = Math_fround($106 * $113);
  $127 = Math_fround($115 * $104);
  $128 = Math_fround($126 - $127);
  $129 = Math_fround($100 * $128);
  $130 = Math_fround($125 + $129);
  $131 = Math_fround($108 * $116);
  $132 = Math_fround($131 + $130);
  $133 = Math_fround($115 * $102);
  $134 = Math_fround($110 * $104);
  $135 = Math_fround($106 * $108);
  $136 = Math_fround($134 - $135);
  $137 = Math_fround($100 * $136);
  $138 = Math_fround($133 + $137);
  $139 = Math_fround($113 * $116);
  $140 = Math_fround($138 + $139);
  $141 = (($8) + 72|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = Math_fround($142 * Math_fround(2.0));
  $144 = (($8) + 76|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = Math_fround($145 * Math_fround(2.0));
  $147 = (($8) + 80|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = Math_fround($148 * Math_fround(2.0));
  $150 = Math_fround($104 * $143);
  $151 = Math_fround($108 * $146);
  $152 = Math_fround($150 + $151);
  $153 = Math_fround($113 * $149);
  $154 = Math_fround($152 + $153);
  $155 = Math_fround($102 * $143);
  $156 = Math_fround($108 * $149);
  $157 = Math_fround($113 * $146);
  $158 = Math_fround($156 - $157);
  $159 = Math_fround($100 * $158);
  $160 = Math_fround($155 + $159);
  $161 = Math_fround($104 * $154);
  $162 = Math_fround($161 + $160);
  $163 = Math_fround($102 * $146);
  $164 = Math_fround($113 * $143);
  $165 = Math_fround($104 * $149);
  $166 = Math_fround($164 - $165);
  $167 = Math_fround($100 * $166);
  $168 = Math_fround($163 + $167);
  $169 = Math_fround($108 * $154);
  $170 = Math_fround($169 + $168);
  $171 = Math_fround($102 * $149);
  $172 = Math_fround($104 * $146);
  $173 = Math_fround($108 * $143);
  $174 = Math_fround($172 - $173);
  $175 = Math_fround($100 * $174);
  $176 = Math_fround($171 + $175);
  $177 = Math_fround($113 * $154);
  $178 = Math_fround($176 + $177);
  $179 = Math_fround($162 - $21);
  $180 = Math_fround($170 - $22);
  $181 = Math_fround($178 - $23);
  $182 = (($8) + 84|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = Math_fround($183 * $124);
  $185 = Math_fround($183 * $132);
  $186 = Math_fround($183 * $140);
  $187 = (($8) + 88|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = Math_fround($188 * $179);
  $190 = Math_fround($188 * $180);
  $191 = Math_fround($188 * $181);
  $192 = Math_fround($184 + $189);
  $193 = Math_fround($185 + $190);
  $194 = Math_fround($186 + $191);
  $195 = Math_fround($192 * $dt);
  $196 = Math_fround($193 * $dt);
  $197 = Math_fround($194 * $dt);
  $198 = (($8) + 100|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = Math_fround(Math_fround(1.0) / $199);
  $201 = Math_fround($200 * $195);
  $202 = Math_fround($200 * $196);
  $203 = Math_fround($200 * $197);
  $204 = (($loads) + (($i$060*48)|0)|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = Math_fround($205 * $201);
  $207 = ((($loads) + (($i$060*48)|0)|0) + 16|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = Math_fround($208 * $202);
  $210 = Math_fround($206 + $209);
  $211 = ((($loads) + (($i$060*48)|0)|0) + 32|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $213 = Math_fround($212 * $203);
  $214 = Math_fround($213 + $210);
  $215 = ((($loads) + (($i$060*48)|0)|0) + 4|0);
  $216 = Math_fround(HEAPF32[$215>>2]);
  $217 = Math_fround($216 * $201);
  $218 = ((($loads) + (($i$060*48)|0)|0) + 20|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = Math_fround($219 * $202);
  $221 = Math_fround($217 + $220);
  $222 = ((($loads) + (($i$060*48)|0)|0) + 36|0);
  $223 = Math_fround(HEAPF32[$222>>2]);
  $224 = Math_fround($203 * $223);
  $225 = Math_fround($224 + $221);
  $226 = ((($loads) + (($i$060*48)|0)|0) + 8|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = Math_fround($201 * $227);
  $229 = ((($loads) + (($i$060*48)|0)|0) + 24|0);
  $230 = Math_fround(HEAPF32[$229>>2]);
  $231 = Math_fround($202 * $230);
  $232 = Math_fround($228 + $231);
  $233 = ((($loads) + (($i$060*48)|0)|0) + 40|0);
  $234 = Math_fround(HEAPF32[$233>>2]);
  $235 = Math_fround($203 * $234);
  $236 = Math_fround($232 + $235);
  $237 = (($drives) + ($i$060<<4)|0);
  HEAPF32[$237>>2] = $214;
  $238 = ((($drives) + ($i$060<<4)|0) + 4|0);
  HEAPF32[$238>>2] = $225;
  $239 = ((($drives) + ($i$060<<4)|0) + 8|0);
  HEAPF32[$239>>2] = $236;
  $240 = ((($drives) + ($i$060<<4)|0) + 12|0);
  HEAPF32[$240>>2] = Math_fround(0.0);
  $241 = (($i$060) + 1)|0;
  $exitcond = ($241|0)==($4|0);
  if ($exitcond) {
   break;
  } else {
   $i$060 = $241;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper22setupSolverConstraintsERNS_9PxcFsDataEjRNS_24PxcConstraintBlockStreamEPNS_23PxcSolverConstraintDescEPKNS_19PxsArticulationLinkEPKNS_30PxcArticulationJointTransformsEfRjRNS_25PxsConstraintBlockManagerE($fsData,$solverDataSize,$stream,$constraintDesc,$links,$jointTransforms,$dt,$acCount,$constraintBlockManager) {
 $fsData = $fsData|0;
 $solverDataSize = $solverDataSize|0;
 $stream = $stream|0;
 $constraintDesc = $constraintDesc|0;
 $links = $links|0;
 $jointTransforms = $jointTransforms|0;
 $dt = Math_fround($dt);
 $acCount = $acCount|0;
 $constraintBlockManager = $constraintBlockManager|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0;
 var $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0;
 var $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $cIndex$0 = 0, $cIndex$1 = 0, $cp$0$i = 0, $cp$0$i2 = 0, $descCount$0$lcssa = 0, $descCount$011 = 0, $descCount$1 = 0, $eh = 0, $exitcond = 0, $indvars$iv = 0, $lftr$wideiv = 0, $normal = 0, $swing = 0, $swingLimitAxis = 0, $swingLimitError = 0, $twistAxis = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 32|0;
 $1 = sp;
 $swing = sp + 120|0;
 $eh = sp + 104|0;
 $swingLimitAxis = sp + 136|0;
 $swingLimitError = sp + 88|0;
 $twistAxis = sp + 64|0;
 $normal = sp + 92|0;
 $2 = sp + 76|0;
 HEAP32[$acCount>>2] = 0;
 $3 = (($fsData) + 8|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = Math_fround(Math_fround(1.0) / $dt);
 $6 = ($4&65535)>(1);
 if (!($6)) {
  $descCount$0$lcssa = 0;
  STACKTOP = sp;return ($descCount$0$lcssa|0);
 }
 $7 = $4&65535;
 $8 = (($swing) + 4|0);
 $9 = (($swing) + 8|0);
 $10 = (($swing) + 12|0);
 $11 = (($eh) + 4|0);
 $12 = (($eh) + 8|0);
 $13 = (($twistAxis) + 4|0);
 $14 = (($twistAxis) + 8|0);
 $15 = $solverDataSize&65535;
 $16 = (($swingLimitAxis) + 4|0);
 $17 = (($swingLimitAxis) + 8|0);
 $18 = (($normal) + 4|0);
 $19 = (($normal) + 8|0);
 $20 = (($0) + 16|0);
 $21 = (($0) + 20|0);
 $22 = (($0) + 24|0);
 $23 = (($0) + 28|0);
 $24 = (($1) + 4|0);
 $25 = (($1) + 8|0);
 $26 = (($1) + 12|0);
 $27 = (($1) + 16|0);
 $28 = (($1) + 20|0);
 $29 = (($1) + 24|0);
 $30 = (($1) + 28|0);
 $31 = Math_fround($dt * $dt);
 $32 = (($2) + 4|0);
 $33 = (($2) + 8|0);
 $34 = (($stream) + 4|0);
 $$pre$i = (($stream) + 8|0);
 $descCount$011 = 0;$indvars$iv = 1;
 while(1) {
  $35 = ((($links) + ($indvars$iv<<5)|0) + 24|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($indvars$iv) + 1)|0;
  $38 = ($37>>>0)<($7>>>0);
  if ($38) {
   $39 = ((($links) + ($37<<5)|0) + 24|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $40;
   $42 = (_bitshift64Lshr(($41|0),0,6)|0);
   $43 = tempRet0;
   $44 = (_i64Add(($41|0),0,171,0)|0);
   $45 = tempRet0;
   $46 = (_bitshift64Lshr(($44|0),($45|0),6)|0);
   $47 = tempRet0;
   $48 = (_i64Subtract(1,0,($42|0),($43|0))|0);
   $49 = tempRet0;
   $50 = (_i64Add(($48|0),($49|0),($46|0),($47|0))|0);
   $51 = tempRet0;
   $53 = $50;$54 = $51;$cp$0$i = $40;
   while(1) {
    $52 = (($cp$0$i) + 64|0);
    $55 = (_i64Add(($53|0),($54|0),-1,-1)|0);
    $56 = tempRet0;
    $57 = ($55|0)==(0);
    $58 = ($56|0)==(0);
    $59 = $57 & $58;
    if ($59) {
     break;
    } else {
     $53 = $55;$54 = $56;$cp$0$i = $52;
    }
   }
   $60 = (($jointTransforms) + (($37*84)|0)|0);
   $61 = $60;
   $62 = (_bitshift64Lshr(($61|0),0,6)|0);
   $63 = tempRet0;
   $64 = (_i64Add(($61|0),0,83,0)|0);
   $65 = tempRet0;
   $66 = (_bitshift64Lshr(($64|0),($65|0),6)|0);
   $67 = tempRet0;
   $68 = (_i64Subtract(1,0,($62|0),($63|0))|0);
   $69 = tempRet0;
   $70 = (_i64Add(($68|0),($69|0),($66|0),($67|0))|0);
   $71 = tempRet0;
   $73 = $70;$74 = $71;$cp$0$i2 = $60;
   while(1) {
    $72 = (($cp$0$i2) + 64|0);
    $75 = (_i64Add(($73|0),($74|0),-1,-1)|0);
    $76 = tempRet0;
    $77 = ($75|0)==(0);
    $78 = ($76|0)==(0);
    $79 = $77 & $78;
    if ($79) {
     break;
    } else {
     $73 = $75;$74 = $76;$cp$0$i2 = $72;
    }
   }
  }
  $80 = (($36) + 144|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = ($81<<24>>24)==(0);
  if ($82) {
   $83 = (($36) + 120|0);
   $84 = HEAP8[$83>>0]|0;
   $85 = ($84<<24>>24)==(0);
   if ($85) {
    $descCount$1 = $descCount$011;
   } else {
    label = 10;
   }
  } else {
   label = 10;
  }
  if ((label|0) == 10) {
   label = 0;
   $86 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 56|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = $87 != Math_fround(0.0);
   $89 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 68|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   if ($88) {
    $91 = Math_fround($87 * $87);
    $92 = Math_fround($91 + Math_fround(0.0));
    $93 = Math_fround($90 * $90);
    $94 = Math_fround($92 + $93);
    $95 = (Math_fround(Math_sqrt((Math_fround($94)))));
    $96 = Math_fround(Math_fround(1.0) / $95);
    $97 = Math_fround($87 * $96);
    $98 = Math_fround($96 * Math_fround(0.0));
    $99 = Math_fround($90 * $96);
    $101 = $97;$103 = $98;$106 = $99;
   } else {
    $101 = Math_fround(0.0);$103 = Math_fround(0.0);$106 = Math_fround(1.0);
   }
   $100 = Math_fround(-$101);
   $102 = Math_fround(-$103);
   $104 = Math_fround($90 * $100);
   $105 = Math_fround($106 * $87);
   $107 = Math_fround($104 + $105);
   $108 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 60|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = Math_fround($109 * $102);
   $111 = Math_fround($107 + $110);
   $112 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 64|0);
   $113 = Math_fround(HEAPF32[$112>>2]);
   $114 = Math_fround($113 * $102);
   $115 = Math_fround($111 - $114);
   $116 = Math_fround($90 * $102);
   $117 = Math_fround($106 * $109);
   $118 = Math_fround($116 + $117);
   $119 = Math_fround($113 * $100);
   $120 = Math_fround($118 + $119);
   $121 = Math_fround($87 * $102);
   $122 = Math_fround($120 - $121);
   $123 = Math_fround($106 * $113);
   $124 = Math_fround($116 + $123);
   $125 = Math_fround($121 + $124);
   $126 = Math_fround($109 * $100);
   $127 = Math_fround($125 - $126);
   $128 = Math_fround($106 * $90);
   $129 = Math_fround($87 * $100);
   $130 = Math_fround($128 - $129);
   $131 = Math_fround($130 - $110);
   $132 = Math_fround($131 - $114);
   HEAPF32[$swing>>2] = $115;
   HEAPF32[$8>>2] = $122;
   HEAPF32[$9>>2] = $127;
   HEAPF32[$10>>2] = $132;
   $133 = (($36) + 148|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = (($36) + 152|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = (($36) + 156|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   HEAPF32[$eh>>2] = $134;
   HEAPF32[$11>>2] = $136;
   HEAPF32[$12>>2] = $138;
   HEAPF32[$swingLimitError>>2] = Math_fround(0.0);
   $139 = (($36) + 120|0);
   $140 = HEAP8[$139>>0]|0;
   $141 = ($140<<24>>24)==(0);
   if ($141) {
    $205 = 0;$207 = 0;
   } else {
    $142 = (__ZN5physx2Cm15ConeLimitHelper8getLimitERKNS_6PxQuatERNS_6PxVec3ERf($eh,$swing,$swingLimitAxis,$swingLimitError)|0);
    if ($142) {
     $143 = (($36) + 124|0);
     $144 = Math_fround(HEAPF32[$143>>2]);
     $145 = $144 > Math_fround(0.0);
     if ($145) {
      $205 = 1;$207 = 1;
     } else {
      $146 = (($36) + 128|0);
      $147 = Math_fround(HEAPF32[$146>>2]);
      $148 = $147 > Math_fround(0.0);
      $205 = 1;$207 = $148;
     }
    } else {
     $205 = 0;$207 = 0;
    }
   }
   $149 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 40|0);
   $150 = Math_fround(HEAPF32[$149>>2]);
   $151 = Math_fround($150 * $150);
   $152 = Math_fround($151 + Math_fround(-0.5));
   $153 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 28|0);
   $154 = Math_fround(HEAPF32[$153>>2]);
   $155 = Math_fround($154 * Math_fround(2.0));
   $156 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 32|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $158 = Math_fround($157 * Math_fround(0.0));
   $159 = Math_fround($155 + $158);
   $160 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 36|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = Math_fround($161 * Math_fround(0.0));
   $163 = Math_fround($159 + $162);
   $164 = Math_fround($152 * Math_fround(2.0));
   $165 = Math_fround($158 - $162);
   $166 = Math_fround($150 * $165);
   $167 = Math_fround($164 + $166);
   $168 = Math_fround($154 * $163);
   $169 = Math_fround($168 + $167);
   $170 = Math_fround($152 * Math_fround(0.0));
   $171 = Math_fround($161 * Math_fround(2.0));
   $172 = Math_fround($154 * Math_fround(0.0));
   $173 = Math_fround($171 - $172);
   $174 = Math_fround($150 * $173);
   $175 = Math_fround($170 + $174);
   $176 = Math_fround($157 * $163);
   $177 = Math_fround($176 + $175);
   $178 = Math_fround($157 * Math_fround(2.0));
   $179 = Math_fround($172 - $178);
   $180 = Math_fround($150 * $179);
   $181 = Math_fround($170 + $180);
   $182 = Math_fround($161 * $163);
   $183 = Math_fround($181 + $182);
   HEAPF32[$twistAxis>>2] = $169;
   HEAPF32[$13>>2] = $177;
   HEAPF32[$14>>2] = $183;
   $184 = Math_fround($106 + Math_fround(1.0));
   $185 = Math_fround($101 / $184);
   $186 = HEAP8[$80>>0]|0;
   $187 = ($186<<24>>24)==(0);
   if ($187) {
    $210 = 0;$212 = 0;
   } else {
    $188 = (($36) + 164|0);
    $189 = Math_fround(HEAPF32[$188>>2]);
    $190 = (($36) + 168|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = Math_fround($189 + $191);
    $193 = Math_fround($189 * $191);
    $194 = Math_fround(Math_fround(1.0) - $193);
    $195 = Math_fround($192 / $194);
    $196 = $185 < $195;
    $197 = (($36) + 160|0);
    $198 = Math_fround(HEAPF32[$197>>2]);
    $199 = Math_fround($198 - $191);
    $200 = Math_fround($198 * $191);
    $201 = Math_fround($200 + Math_fround(1.0));
    $202 = Math_fround($199 / $201);
    $203 = $185 > $202;
    $210 = $203;$212 = $196;
   }
   $204 = $205&1;
   $206 = $207&1;
   $208 = (($206) + ($204))|0;
   $209 = $210&1;
   $211 = $212&1;
   $213 = (($208) + ($211))|0;
   $214 = (($213) + ($209))|0;
   $215 = $214&255;
   $216 = ($215<<24>>24)==(0);
   if ($216) {
    $descCount$1 = $descCount$011;
   } else {
    $217 = (($descCount$011) + 1)|0;
    $218 = (($constraintDesc) + ($descCount$011<<5)|0);
    HEAP32[$218>>2] = $fsData;
    $219 = ((($links) + ($indvars$iv<<5)|0) + 28|0);
    $220 = HEAP32[$219>>2]|0;
    $221 = $220&65535;
    $222 = ((($constraintDesc) + ($descCount$011<<5)|0) + 8|0);
    HEAP16[$222>>1] = $221;
    $223 = ((($constraintDesc) + ($descCount$011<<5)|0) + 10|0);
    HEAP16[$223>>1] = $15;
    $224 = ((($constraintDesc) + ($descCount$011<<5)|0) + 4|0);
    HEAP32[$224>>2] = $fsData;
    $225 = ((($constraintDesc) + ($descCount$011<<5)|0) + 12|0);
    $226 = $indvars$iv&65535;
    HEAP16[$225>>1] = $226;
    $227 = ((($constraintDesc) + ($descCount$011<<5)|0) + 14|0);
    HEAP16[$227>>1] = $15;
    $228 = $214 & 255;
    $229 = ($228*176)|0;
    $230 = (($229) + 48)|0;
    $231 = $230 >>> 4;
    $232 = $231&65535;
    $233 = ((($constraintDesc) + ($descCount$011<<5)|0) + 26|0);
    HEAP16[$233>>1] = $232;
    $234 = (($229) + 79)|0;
    $235 = $234 & 131056;
    $236 = ($235>>>0)>(16384);
    do {
     if ($236) {
      $237 = HEAP32[$stream>>2]|0;
      $238 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($237,$235)|0);
      $$0$i = $238;
     } else {
      $239 = HEAP32[$34>>2]|0;
      $240 = ($239|0)==(0|0);
      if (!($240)) {
       $241 = HEAP32[$$pre$i>>2]|0;
       $242 = (($241) + ($235))|0;
       $243 = ($242>>>0)>(16384);
       if (!($243)) {
        $246 = (($239) + ($241)|0);
        HEAP32[$$pre$i>>2] = $242;
        $$0$i = $246;
        break;
       }
      }
      $244 = HEAP32[$stream>>2]|0;
      $245 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($244,$constraintBlockManager)|0);
      HEAP32[$34>>2] = $245;
      HEAP32[$$pre$i>>2] = $235;
      $$0$i = $245;
     }
    } while(0);
    $247 = ((($constraintDesc) + ($descCount$011<<5)|0) + 16|0);
    HEAP32[$247>>2] = $$0$i;
    $248 = ((($constraintDesc) + ($descCount$011<<5)|0) + 20|0);
    HEAP32[$248>>2] = 0;
    $249 = (($$0$i) + 48|0);
    HEAP8[$$0$i>>0] = 4;
    $250 = (($$0$i) + 1|0);
    HEAP8[$250>>0] = $215;
    $251 = (($$0$i) + 2|0);
    HEAP8[$251>>0] = 0;
    $252 = (($$0$i) + 32|0);
    HEAPF32[$252>>2] = Math_fround(1.0);
    $253 = (($$0$i) + 36|0);
    HEAPF32[$253>>2] = Math_fround(1.0);
    $254 = (($$0$i) + 40|0);
    HEAPF32[$254>>2] = Math_fround(-1.0);
    $255 = (($$0$i) + 44|0);
    HEAPF32[$255>>2] = Math_fround(-1.0);
    if ($205) {
     $256 = Math_fround(HEAPF32[$swingLimitAxis>>2]);
     $257 = Math_fround($256 * Math_fround(2.0));
     $258 = Math_fround(HEAPF32[$16>>2]);
     $259 = Math_fround($258 * Math_fround(2.0));
     $260 = Math_fround(HEAPF32[$17>>2]);
     $261 = Math_fround($260 * Math_fround(2.0));
     $262 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 12|0);
     $263 = Math_fround(HEAPF32[$262>>2]);
     $264 = Math_fround($263 * $263);
     $265 = Math_fround($264 + Math_fround(-0.5));
     $266 = (($jointTransforms) + (($indvars$iv*84)|0)|0);
     $267 = Math_fround(HEAPF32[$266>>2]);
     $268 = Math_fround($257 * $267);
     $269 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 4|0);
     $270 = Math_fround(HEAPF32[$269>>2]);
     $271 = Math_fround($259 * $270);
     $272 = Math_fround($268 + $271);
     $273 = ((($jointTransforms) + (($indvars$iv*84)|0)|0) + 8|0);
     $274 = Math_fround(HEAPF32[$273>>2]);
     $275 = Math_fround($261 * $274);
     $276 = Math_fround($272 + $275);
     $277 = Math_fround($257 * $265);
     $278 = Math_fround($261 * $270);
     $279 = Math_fround($259 * $274);
     $280 = Math_fround($278 - $279);
     $281 = Math_fround($263 * $280);
     $282 = Math_fround($277 + $281);
     $283 = Math_fround($267 * $276);
     $284 = Math_fround($283 + $282);
     $285 = Math_fround($259 * $265);
     $286 = Math_fround($257 * $274);
     $287 = Math_fround($261 * $267);
     $288 = Math_fround($286 - $287);
     $289 = Math_fround($263 * $288);
     $290 = Math_fround($285 + $289);
     $291 = Math_fround($270 * $276);
     $292 = Math_fround($291 + $290);
     $293 = Math_fround($261 * $265);
     $294 = Math_fround($259 * $267);
     $295 = Math_fround($257 * $270);
     $296 = Math_fround($294 - $295);
     $297 = Math_fround($263 * $296);
     $298 = Math_fround($293 + $297);
     $299 = Math_fround($274 * $276);
     $300 = Math_fround($298 + $299);
     HEAPF32[$normal>>2] = $284;
     HEAPF32[$18>>2] = $292;
     HEAPF32[$19>>2] = $300;
     $301 = Math_fround(HEAPF32[$swingLimitError>>2]);
     __ZN5physx21PxcArticulationHelper15createHardLimitERKNS_9PxcFsDataEPKNS_19PxsArticulationLinkEjRNS_24PxcSolverConstraint1DExtERKNS_6PxVec3Eff($fsData,$links,$indvars$iv,$249,$normal,$301,$5);
     if ($207) {
      $302 = Math_fround(HEAPF32[$13>>2]);
      $303 = Math_fround(HEAPF32[$19>>2]);
      $304 = Math_fround($302 * $303);
      $305 = Math_fround(HEAPF32[$14>>2]);
      $306 = Math_fround(HEAPF32[$18>>2]);
      $307 = Math_fround($305 * $306);
      $308 = Math_fround($304 - $307);
      $309 = Math_fround(HEAPF32[$normal>>2]);
      $310 = Math_fround($305 * $309);
      $311 = Math_fround(HEAPF32[$twistAxis>>2]);
      $312 = Math_fround($303 * $311);
      $313 = Math_fround($310 - $312);
      $314 = Math_fround($306 * $311);
      $315 = Math_fround($302 * $309);
      $316 = Math_fround($314 - $315);
      $317 = Math_fround($308 * $308);
      $318 = Math_fround($313 * $313);
      $319 = Math_fround($317 + $318);
      $320 = Math_fround($316 * $316);
      $321 = Math_fround($320 + $319);
      $322 = $321 > Math_fround(0.0);
      if ($322) {
       $323 = (Math_fround(Math_sqrt((Math_fround($321)))));
       $324 = Math_fround(Math_fround(1.0) / $323);
       $325 = Math_fround($308 * $324);
       $326 = Math_fround($313 * $324);
       $327 = Math_fround($316 * $324);
       $339 = $325;$341 = $326;$343 = $327;
      } else {
       $339 = Math_fround(0.0);$341 = Math_fround(0.0);$343 = Math_fround(0.0);
      }
      $328 = (($$0$i) + 224|0);
      $329 = (($36) + 124|0);
      $330 = Math_fround(HEAPF32[$329>>2]);
      $331 = (($36) + 128|0);
      $332 = Math_fround(HEAPF32[$331>>2]);
      HEAPF32[$328>>2] = Math_fround(0.0);
      $333 = (($$0$i) + 228|0);
      HEAPF32[$333>>2] = Math_fround(0.0);
      $334 = (($$0$i) + 232|0);
      HEAPF32[$334>>2] = Math_fround(0.0);
      $335 = (($$0$i) + 240|0);
      HEAPF32[$335>>2] = Math_fround(0.0);
      $336 = (($$0$i) + 244|0);
      HEAPF32[$336>>2] = Math_fround(0.0);
      $337 = (($$0$i) + 248|0);
      HEAPF32[$337>>2] = Math_fround(0.0);
      $338 = (($$0$i) + 256|0);
      HEAPF32[$338>>2] = $339;
      $340 = (($$0$i) + 260|0);
      HEAPF32[$340>>2] = $341;
      $342 = (($$0$i) + 264|0);
      HEAPF32[$342>>2] = $343;
      $344 = (($$0$i) + 272|0);
      HEAPF32[$344>>2] = $339;
      $345 = (($$0$i) + 276|0);
      HEAPF32[$345>>2] = $341;
      $346 = (($$0$i) + 280|0);
      HEAPF32[$346>>2] = $343;
      $347 = (($$0$i) + 320|0);
      HEAPF32[$347>>2] = Math_fround(-3.40282346638528859812E+38);
      $348 = (($$0$i) + 324|0);
      HEAPF32[$348>>2] = Math_fround(3.40282346638528859812E+38);
      $349 = (($$0$i) + 332|0);
      HEAP32[$349>>2] = 0;
      $350 = (($$0$i) + 328|0);
      HEAPF32[$350>>2] = Math_fround(0.0);
      $351 = HEAP32[$219>>2]|0;
      ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
      HEAPF32[$20>>2] = $339;
      HEAPF32[$21>>2] = $341;
      HEAPF32[$22>>2] = $343;
      HEAPF32[$23>>2] = Math_fround(0.0);
      $352 = (($$0$i) + 336|0);
      $353 = Math_fround(-$339);
      $354 = Math_fround(-$341);
      $355 = Math_fround(-$343);
      HEAPF32[$1>>2] = Math_fround(-0.0);
      HEAPF32[$24>>2] = Math_fround(-0.0);
      HEAPF32[$25>>2] = Math_fround(-0.0);
      HEAPF32[$26>>2] = Math_fround(0.0);
      HEAPF32[$27>>2] = $353;
      HEAPF32[$28>>2] = $354;
      HEAPF32[$29>>2] = $355;
      HEAPF32[$30>>2] = Math_fround(0.0);
      $356 = (($$0$i) + 368|0);
      __ZN5physx21PxcArticulationHelper22getImpulseSelfResponseERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS4_jS6_S7_($fsData,$351,$0,$352,$indvars$iv,$1,$356);
      $357 = (($$0$i) + 352|0);
      $358 = Math_fround(HEAPF32[$357>>2]);
      $359 = Math_fround($339 * $358);
      $360 = (($$0$i) + 356|0);
      $361 = Math_fround(HEAPF32[$360>>2]);
      $362 = Math_fround($341 * $361);
      $363 = Math_fround($359 + $362);
      $364 = (($$0$i) + 360|0);
      $365 = Math_fround(HEAPF32[$364>>2]);
      $366 = Math_fround($343 * $365);
      $367 = Math_fround($363 + $366);
      $368 = (($$0$i) + 384|0);
      $369 = Math_fround(HEAPF32[$368>>2]);
      $370 = Math_fround($339 * $369);
      $371 = (($$0$i) + 388|0);
      $372 = Math_fround(HEAPF32[$371>>2]);
      $373 = Math_fround($341 * $372);
      $374 = Math_fround($370 + $373);
      $375 = (($$0$i) + 392|0);
      $376 = Math_fround(HEAPF32[$375>>2]);
      $377 = Math_fround($343 * $376);
      $378 = Math_fround($374 + $377);
      $379 = Math_fround($367 - $378);
      $380 = Math_fround(Math_fround(1.0) / $379);
      $381 = Math_fround($31 * $330);
      $382 = Math_fround($332 * $dt);
      $383 = Math_fround($381 + $382);
      $384 = Math_fround($383 + Math_fround(1.0));
      $385 = Math_fround(Math_fround(1.0) / $384);
      $386 = (($$0$i) + 252|0);
      HEAPF32[$386>>2] = Math_fround(0.0);
      $387 = (($$0$i) + 236|0);
      HEAPF32[$387>>2] = Math_fround(0.0);
      $388 = Math_fround($380 * $385);
      $389 = Math_fround($383 * $388);
      $390 = Math_fround(-$389);
      $391 = (($$0$i) + 268|0);
      HEAPF32[$391>>2] = $390;
      $392 = Math_fround(Math_fround(1.0) - $385);
      $393 = (($$0$i) + 284|0);
      HEAPF32[$393>>2] = $392;
      $cIndex$0 = 2;
     } else {
      $cIndex$0 = 1;
     }
    } else {
     $cIndex$0 = 0;
    }
    if ($210) {
     $394 = (($cIndex$0) + 1)|0;
     $395 = (($249) + (($cIndex$0*176)|0)|0);
     $396 = (($36) + 160|0);
     $397 = Math_fround(HEAPF32[$396>>2]);
     $398 = Math_fround($397 - $185);
     $399 = Math_fround($398 * Math_fround(4.0));
     __ZN5physx21PxcArticulationHelper15createHardLimitERKNS_9PxcFsDataEPKNS_19PxsArticulationLinkEjRNS_24PxcSolverConstraint1DExtERKNS_6PxVec3Eff($fsData,$links,$indvars$iv,$395,$twistAxis,$399,$5);
     $cIndex$1 = $394;
    } else {
     $cIndex$1 = $cIndex$0;
    }
    if ($212) {
     $400 = (($249) + (($cIndex$1*176)|0)|0);
     $401 = Math_fround(HEAPF32[$twistAxis>>2]);
     $402 = Math_fround(-$401);
     $403 = Math_fround(HEAPF32[$13>>2]);
     $404 = Math_fround(-$403);
     $405 = Math_fround(HEAPF32[$14>>2]);
     $406 = Math_fround(-$405);
     HEAPF32[$2>>2] = $402;
     HEAPF32[$32>>2] = $404;
     HEAPF32[$33>>2] = $406;
     $407 = (($36) + 164|0);
     $408 = Math_fround(HEAPF32[$407>>2]);
     $409 = Math_fround($408 - $185);
     $410 = Math_fround($409 * Math_fround(-4.0));
     __ZN5physx21PxcArticulationHelper15createHardLimitERKNS_9PxcFsDataEPKNS_19PxsArticulationLinkEjRNS_24PxcSolverConstraint1DExtERKNS_6PxVec3Eff($fsData,$links,$indvars$iv,$400,$2,$410,$5);
    }
    $411 = HEAP32[$247>>2]|0;
    $412 = HEAP16[$233>>1]|0;
    $413 = $412&65535;
    $414 = $413 << 4;
    $415 = (($411) + ($414)|0);
    HEAP8[$415>>0] = 0;
    $416 = HEAP32[$acCount>>2]|0;
    $417 = (($416) + ($228))|0;
    HEAP32[$acCount>>2] = $417;
    $descCount$1 = $217;
   }
  }
  $lftr$wideiv = $37&65535;
  $exitcond = ($lftr$wideiv<<16>>16)==($4<<16>>16);
  if ($exitcond) {
   $descCount$0$lcssa = $descCount$1;
   break;
  } else {
   $descCount$011 = $descCount$1;$indvars$iv = $37;
  }
 }
 STACKTOP = sp;return ($descCount$0$lcssa|0);
}
function __ZN5physx21PxcArticulationHelper20initializeDriveCacheERNS_9PxcFsDataEtPKNS_19PxsArticulationLinkEfjPcj($fsData,$linkCount,$links,$compliance,$iterations,$scratchMemory,$scratchMemorySize) {
 $fsData = $fsData|0;
 $linkCount = $linkCount|0;
 $links = $links|0;
 $compliance = Math_fround($compliance);
 $iterations = $iterations|0;
 $scratchMemory = $scratchMemory|0;
 $scratchMemorySize = $scratchMemorySize|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $springFactor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy1 = sp + 280|0;
 $springFactor = sp;
 $0 = sp + 256|0;
 $1 = sp + 268|0;
 $2 = $linkCount&65535;
 $3 = ($2*144)|0;
 $4 = (($scratchMemory) + ($3)|0);
 $5 = ($2*240)|0;
 $6 = (($scratchMemory) + ($5)|0);
 $7 = $2 << 5;
 $8 = (($5) + ($7))|0;
 $9 = (($scratchMemory) + ($8)|0);
 $10 = ($2*48)|0;
 $11 = (($8) + ($10))|0;
 __ZN5physx21PxcArticulationHelper16prepareDataBlockERNS_9PxcFsDataEPKNS_19PxsArticulationLinkEtPNS_11PxTransformEPNS_12PxcFsInertiaEPNS_30PxcArticulationJointTransformsEj($fsData,$links,$linkCount,$6,$scratchMemory,$4,0);
 $12 = (($fsData) + 26|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13&65535;
 $15 = (($fsData) + ($14)|0);
 $16 = ($2*160)|0;
 $17 = (($16) + 144)|0;
 _memset(($15|0),0,($17|0))|0;
 __ZN5physx21PxcArticulationHelper13prepareFsDataERNS_9PxcFsDataEPKNS_19PxsArticulationLinkE($fsData,$links);
 HEAPF32[$springFactor>>2] = Math_fround(0.0);
 $18 = ($linkCount&65535)>(1);
 if ($18) {
  $19 = Math_fround(Math_fround(1.0) / $compliance);
  $i$01 = 1;
  while(1) {
   $20 = (($springFactor) + ($i$01<<2)|0);
   HEAPF32[$20>>2] = $19;
   $21 = (($i$01) + 1)|0;
   $exitcond = ($21|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $21;
   }
  }
 }
 _memset(($9|0),0,($10|0))|0;
 $22 = $iterations & 65535;
 HEAP32[$0>>2] = $scratchMemory;
 $23 = (($0) + 4|0);
 HEAP32[$23>>2] = $scratchMemorySize;
 $24 = (($0) + 8|0);
 HEAP32[$24>>2] = $11;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN5physx26PxcFsComputeJointLoadsSimdERKNS_9PxcFsDataEPKNS_12PxcFsInertiaEPNS_6shdfnd3aos6Mat33VEPKfjjNS_21PxcFsScratchAllocatorE($fsData,$scratchMemory,$9,$springFactor,$2,$22,$$byval_copy1);
 HEAP32[$1>>2] = $scratchMemory;
 $25 = (($1) + 4|0);
 HEAP32[$25>>2] = $scratchMemorySize;
 $26 = (($1) + 8|0);
 HEAP32[$26>>2] = $11;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;
 __ZN5physx31PxcFsPropagateDrivenInertiaSimdERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKfPKNS_6shdfnd3aos6Mat33VENS_21PxcFsScratchAllocatorE($fsData,$scratchMemory,$springFactor,$9,$$byval_copy1);
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper12updateBodiesERKNS_25PxcArticulationSolverDescEf($desc,$dt) {
 $desc = $desc|0;
 $dt = Math_fround($dt);
 var $$sink$i = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0;
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0.0, $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = Math_fround(0), $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = 0;
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0);
 var $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = 0.0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = Math_fround(0), $452 = Math_fround(0), $453 = 0.0, $454 = 0.0, $455 = 0.0, $456 = 0.0, $457 = 0.0;
 var $458 = Math_fround(0), $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = Math_fround(0), $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = 0, $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = 0;
 var $494 = 0, $495 = Math_fround(0), $496 = 0, $497 = 0, $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = Math_fround(0), $505 = 0, $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0), $509 = 0, $51 = Math_fround(0), $510 = 0;
 var $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = 0, $517 = Math_fround(0), $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = 0, $529 = 0;
 var $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = 0, $536 = Math_fround(0), $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0.0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $b = 0, $exitcond = 0, $exitcond157 = 0, $exitcond158 = 0, $exitcond159 = 0, $exitcond160 = 0, $exitcond161 = 0, $exitcond163 = 0, $i$0153 = 0, $i1$0132 = 0, $i2$0136 = 0, $i3$0140 = 0, $i4$0144 = 0, $i7$0129 = 0, $i8$0127 = 0, $iterations$0148 = 0, $maxSeparation$0$lcssa = Math_fround(0), $maxSeparation$0133 = Math_fround(0);
 var $phitmp$i = Math_fround(0), $phitmp10$i = Math_fround(0), $phitmp11$i = Math_fround(0), $projected$0$off0149 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1024|0;
 $b = sp;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($desc) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($desc) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($desc) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($desc) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 8|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 __ZN5physx18PxcFsFlushVelocityERNS_9PxcFsDataE($0);
 $12 = (($0) + 128|0);
 __ZN5physx15PxcLtbComputeJvEPNS_6shdfnd3aos5Vec3VERKNS_9PxcFsDataEPKNS_14PxcSIMDSpatialE($b,$0,$12);
 __ZN5physx13PxcLtbProjectERKNS_9PxcFsDataEPNS_14PxcSIMDSpatialEPNS_6shdfnd3aos5Vec3VE($0,$12,$b);
 $13 = (($desc) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($desc) + 36|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = $17 << 5;
 $19 = ($10<<16>>16)==(0);
 if (!($19)) {
  $i$0153 = 0;
  while(1) {
   $20 = (($6) + (($i$0153*28)|0)|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = (($14) + (($i$0153*28)|0)|0);
   HEAPF32[$22>>2] = $21;
   $23 = ((($6) + (($i$0153*28)|0)|0) + 4|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = ((($14) + (($i$0153*28)|0)|0) + 4|0);
   HEAPF32[$25>>2] = $24;
   $26 = ((($6) + (($i$0153*28)|0)|0) + 8|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = ((($14) + (($i$0153*28)|0)|0) + 8|0);
   HEAPF32[$28>>2] = $27;
   $29 = ((($6) + (($i$0153*28)|0)|0) + 12|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = ((($14) + (($i$0153*28)|0)|0) + 12|0);
   HEAPF32[$31>>2] = $30;
   $32 = ((($6) + (($i$0153*28)|0)|0) + 16|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = ((($14) + (($i$0153*28)|0)|0) + 16|0);
   HEAPF32[$34>>2] = $33;
   $35 = ((($6) + (($i$0153*28)|0)|0) + 20|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = ((($14) + (($i$0153*28)|0)|0) + 20|0);
   HEAPF32[$37>>2] = $36;
   $38 = ((($6) + (($i$0153*28)|0)|0) + 24|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = ((($14) + (($i$0153*28)|0)|0) + 24|0);
   HEAPF32[$40>>2] = $39;
   $41 = (($8) + ($i$0153<<5)|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = Math_fround($42 * $dt);
   $44 = ((($8) + ($i$0153<<5)|0) + 4|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = Math_fround($45 * $dt);
   $47 = ((($8) + ($i$0153<<5)|0) + 8|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = Math_fround($48 * $dt);
   $50 = Math_fround(HEAPF32[$32>>2]);
   $51 = Math_fround($43 + $50);
   $52 = Math_fround(HEAPF32[$35>>2]);
   $53 = Math_fround($46 + $52);
   $54 = Math_fround(HEAPF32[$38>>2]);
   $55 = Math_fround($49 + $54);
   $56 = ((($8) + ($i$0153<<5)|0) + 16|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround($57 * $dt);
   $59 = ((($8) + ($i$0153<<5)|0) + 20|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround($60 * $dt);
   $62 = ((($8) + ($i$0153<<5)|0) + 24|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = Math_fround($63 * $dt);
   $65 = Math_fround($58 * $58);
   $66 = Math_fround($61 * $61);
   $67 = Math_fround($65 + $66);
   $68 = Math_fround($64 * $64);
   $69 = Math_fround($67 + $68);
   $70 = +$69;
   $71 = $70 < 9.999999999999999237E-25;
   if ($71) {
    $85 = Math_fround(1.0);$88 = Math_fround(0.0);$92 = Math_fround(0.0);$96 = Math_fround(0.0);
   } else {
    $72 = (Math_fround(Math_sqrt((Math_fround($69)))));
    $73 = Math_fround(Math_fround(1.0) / $72);
    $74 = Math_fround($58 * $73);
    $75 = Math_fround($61 * $73);
    $76 = Math_fround($64 * $73);
    $77 = Math_fround($72 * Math_fround(0.5));
    $78 = (Math_fround(+(Math_sin((+$77)))));
    $79 = (Math_fround(+(Math_cos((+$77)))));
    $80 = Math_fround($78 * $74);
    $81 = Math_fround($78 * $75);
    $82 = Math_fround($78 * $76);
    $85 = $79;$88 = $80;$92 = $81;$96 = $82;
   }
   $83 = Math_fround(HEAPF32[$20>>2]);
   $84 = Math_fround($85 * $83);
   $86 = Math_fround(HEAPF32[$29>>2]);
   $87 = Math_fround($88 * $86);
   $89 = Math_fround($84 + $87);
   $90 = Math_fround(HEAPF32[$26>>2]);
   $91 = Math_fround($92 * $90);
   $93 = Math_fround($89 + $91);
   $94 = Math_fround(HEAPF32[$23>>2]);
   $95 = Math_fround($96 * $94);
   $97 = Math_fround($93 - $95);
   $98 = Math_fround($85 * $94);
   $99 = Math_fround($92 * $86);
   $100 = Math_fround($99 + $98);
   $101 = Math_fround($96 * $83);
   $102 = Math_fround($101 + $100);
   $103 = Math_fround($88 * $90);
   $104 = Math_fround($102 - $103);
   $105 = Math_fround($85 * $90);
   $106 = Math_fround($96 * $86);
   $107 = Math_fround($106 + $105);
   $108 = Math_fround($88 * $94);
   $109 = Math_fround($108 + $107);
   $110 = Math_fround($92 * $83);
   $111 = Math_fround($109 - $110);
   $112 = Math_fround($85 * $86);
   $113 = Math_fround($88 * $83);
   $114 = Math_fround($112 - $113);
   $115 = Math_fround($92 * $94);
   $116 = Math_fround($114 - $115);
   $117 = Math_fround($96 * $90);
   $118 = Math_fround($116 - $117);
   HEAPF32[$20>>2] = $97;
   HEAPF32[$23>>2] = $104;
   HEAPF32[$26>>2] = $111;
   HEAPF32[$29>>2] = $118;
   HEAPF32[$32>>2] = $51;
   HEAPF32[$35>>2] = $53;
   HEAPF32[$38>>2] = $55;
   $119 = (($i$0153) + 1)|0;
   $exitcond163 = ($119|0)==($11|0);
   if ($exitcond163) {
    break;
   } else {
    $i$0153 = $119;
   }
  }
 }
 $120 = Math_fround(Math_fround(1.0) / $dt);
 $121 = (($14) + ($18)|0);
 $122 = ($17*144)|0;
 $123 = (($122) + ($18))|0;
 $124 = (($14) + ($123)|0);
 $125 = (($2) + 8|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($126|0)==(0);
 do {
  if (!($127)) {
   $128 = ($10&65535)>(1);
   $129 = (($2) + 16|0);
   $130 = ($11*144)|0;
   $131 = (($4) + 20|0);
   $132 = (($0) + 24|0);
   $133 = $11 << 5;
   $iterations$0148 = 0;$projected$0$off0149 = 0;
   while(1) {
    if ($128) {
     $i1$0132 = 1;$maxSeparation$0133 = Math_fround(-3.40282346638528859812E+38);
     while(1) {
      $134 = ((($4) + ($i1$0132<<5)|0) + 24|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ((($4) + ($i1$0132<<5)|0) + 28|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = (($135) + 16|0);
      $139 = Math_fround(HEAPF32[$138>>2]);
      $140 = Math_fround($139 * Math_fround(2.0));
      $141 = (($135) + 20|0);
      $142 = Math_fround(HEAPF32[$141>>2]);
      $143 = Math_fround($142 * Math_fround(2.0));
      $144 = (($135) + 24|0);
      $145 = Math_fround(HEAPF32[$144>>2]);
      $146 = Math_fround($145 * Math_fround(2.0));
      $147 = ((($6) + (($137*28)|0)|0) + 12|0);
      $148 = Math_fround(HEAPF32[$147>>2]);
      $149 = Math_fround($148 * $148);
      $150 = Math_fround($149 + Math_fround(-0.5));
      $151 = (($6) + (($137*28)|0)|0);
      $152 = Math_fround(HEAPF32[$151>>2]);
      $153 = Math_fround($140 * $152);
      $154 = ((($6) + (($137*28)|0)|0) + 4|0);
      $155 = Math_fround(HEAPF32[$154>>2]);
      $156 = Math_fround($143 * $155);
      $157 = Math_fround($153 + $156);
      $158 = ((($6) + (($137*28)|0)|0) + 8|0);
      $159 = Math_fround(HEAPF32[$158>>2]);
      $160 = Math_fround($146 * $159);
      $161 = Math_fround($157 + $160);
      $162 = Math_fround($140 * $150);
      $163 = Math_fround($146 * $155);
      $164 = Math_fround($143 * $159);
      $165 = Math_fround($163 - $164);
      $166 = Math_fround($148 * $165);
      $167 = Math_fround($162 + $166);
      $168 = Math_fround($152 * $161);
      $169 = Math_fround($168 + $167);
      $170 = Math_fround($143 * $150);
      $171 = Math_fround($140 * $159);
      $172 = Math_fround($146 * $152);
      $173 = Math_fround($171 - $172);
      $174 = Math_fround($148 * $173);
      $175 = Math_fround($170 + $174);
      $176 = Math_fround($155 * $161);
      $177 = Math_fround($176 + $175);
      $178 = Math_fround($146 * $150);
      $179 = Math_fround($143 * $152);
      $180 = Math_fround($140 * $155);
      $181 = Math_fround($179 - $180);
      $182 = Math_fround($148 * $181);
      $183 = Math_fround($178 + $182);
      $184 = Math_fround($159 * $161);
      $185 = Math_fround($183 + $184);
      $186 = ((($6) + (($137*28)|0)|0) + 16|0);
      $187 = Math_fround(HEAPF32[$186>>2]);
      $188 = Math_fround($187 + $169);
      $189 = ((($6) + (($137*28)|0)|0) + 20|0);
      $190 = Math_fround(HEAPF32[$189>>2]);
      $191 = Math_fround($190 + $177);
      $192 = ((($6) + (($137*28)|0)|0) + 24|0);
      $193 = Math_fround(HEAPF32[$192>>2]);
      $194 = Math_fround($193 + $185);
      $195 = (($135) + 44|0);
      $196 = Math_fround(HEAPF32[$195>>2]);
      $197 = Math_fround($196 * Math_fround(2.0));
      $198 = (($135) + 48|0);
      $199 = Math_fround(HEAPF32[$198>>2]);
      $200 = Math_fround($199 * Math_fround(2.0));
      $201 = (($135) + 52|0);
      $202 = Math_fround(HEAPF32[$201>>2]);
      $203 = Math_fround($202 * Math_fround(2.0));
      $204 = ((($6) + (($i1$0132*28)|0)|0) + 12|0);
      $205 = Math_fround(HEAPF32[$204>>2]);
      $206 = Math_fround($205 * $205);
      $207 = Math_fround($206 + Math_fround(-0.5));
      $208 = (($6) + (($i1$0132*28)|0)|0);
      $209 = Math_fround(HEAPF32[$208>>2]);
      $210 = Math_fround($197 * $209);
      $211 = ((($6) + (($i1$0132*28)|0)|0) + 4|0);
      $212 = Math_fround(HEAPF32[$211>>2]);
      $213 = Math_fround($200 * $212);
      $214 = Math_fround($210 + $213);
      $215 = ((($6) + (($i1$0132*28)|0)|0) + 8|0);
      $216 = Math_fround(HEAPF32[$215>>2]);
      $217 = Math_fround($203 * $216);
      $218 = Math_fround($214 + $217);
      $219 = Math_fround($197 * $207);
      $220 = Math_fround($203 * $212);
      $221 = Math_fround($200 * $216);
      $222 = Math_fround($220 - $221);
      $223 = Math_fround($205 * $222);
      $224 = Math_fround($219 + $223);
      $225 = Math_fround($209 * $218);
      $226 = Math_fround($225 + $224);
      $227 = Math_fround($200 * $207);
      $228 = Math_fround($197 * $216);
      $229 = Math_fround($203 * $209);
      $230 = Math_fround($228 - $229);
      $231 = Math_fround($205 * $230);
      $232 = Math_fround($227 + $231);
      $233 = Math_fround($212 * $218);
      $234 = Math_fround($233 + $232);
      $235 = Math_fround($203 * $207);
      $236 = Math_fround($200 * $209);
      $237 = Math_fround($197 * $212);
      $238 = Math_fround($236 - $237);
      $239 = Math_fround($205 * $238);
      $240 = Math_fround($235 + $239);
      $241 = Math_fround($216 * $218);
      $242 = Math_fround($240 + $241);
      $243 = ((($6) + (($i1$0132*28)|0)|0) + 16|0);
      $244 = Math_fround(HEAPF32[$243>>2]);
      $245 = Math_fround($244 + $226);
      $246 = ((($6) + (($i1$0132*28)|0)|0) + 20|0);
      $247 = Math_fround(HEAPF32[$246>>2]);
      $248 = Math_fround($247 + $234);
      $249 = ((($6) + (($i1$0132*28)|0)|0) + 24|0);
      $250 = Math_fround(HEAPF32[$249>>2]);
      $251 = Math_fround($250 + $242);
      $252 = Math_fround($188 - $245);
      $253 = Math_fround($191 - $248);
      $254 = Math_fround($194 - $251);
      $255 = Math_fround($252 * $252);
      $256 = Math_fround($253 * $253);
      $257 = Math_fround($255 + $256);
      $258 = Math_fround($254 * $254);
      $259 = Math_fround($258 + $257);
      $260 = (Math_fround(Math_sqrt((Math_fround($259)))));
      $261 = $maxSeparation$0133 > $260;
      $262 = $261 ? $maxSeparation$0133 : $260;
      $263 = (($i1$0132) + 1)|0;
      $exitcond158 = ($263|0)==($11|0);
      if ($exitcond158) {
       $maxSeparation$0$lcssa = $262;
       break;
      } else {
       $i1$0132 = $263;$maxSeparation$0133 = $262;
      }
     }
    } else {
     $maxSeparation$0$lcssa = Math_fround(-3.40282346638528859812E+38);
    }
    $264 = Math_fround(HEAPF32[$129>>2]);
    $265 = !($maxSeparation$0$lcssa <= $264);
    if (!($265)) {
     label = 19;
     break;
    }
    _memset(($121|0),0,($130|0))|0;
    $266 = HEAP32[$131>>2]|0;
    __ZN5physx21PxcArticulationHelper10setInertiaERNS_12PxcFsInertiaERKNS_11PxsBodyCoreERKNS_11PxTransformE($121,$266,$6);
    if ($128) {
     $i2$0136 = 1;
     while(1) {
      $267 = (($121) + (($i2$0136*144)|0)|0);
      $268 = ((($4) + ($i2$0136<<5)|0) + 20|0);
      $269 = HEAP32[$268>>2]|0;
      $270 = (($6) + (($i2$0136*28)|0)|0);
      __ZN5physx21PxcArticulationHelper10setInertiaERNS_12PxcFsInertiaERKNS_11PxsBodyCoreERKNS_11PxTransformE($267,$269,$270);
      $271 = (($124) + (($i2$0136*84)|0)|0);
      $272 = ((($4) + ($i2$0136<<5)|0) + 28|0);
      $273 = HEAP32[$272>>2]|0;
      $274 = (($6) + (($273*28)|0)|0);
      $275 = ((($4) + ($i2$0136<<5)|0) + 24|0);
      $276 = HEAP32[$275>>2]|0;
      __ZN5physx21PxcArticulationHelper18setJointTransformsERNS_30PxcArticulationJointTransformsERKNS_11PxTransformES5_RKNS_24PxsArticulationJointCoreE($271,$274,$270,$276);
      $277 = (($i2$0136) + 1)|0;
      $exitcond159 = ($277|0)==($11|0);
      if ($exitcond159) {
       break;
      } else {
       $i2$0136 = $277;
      }
     }
    }
    __ZN5physx21PxcArticulationHelper16prepareLtbMatrixERNS_9PxcFsDataEPKNS_12PxcFsInertiaEPKNS_11PxTransformEPKNS_30PxcArticulationJointTransformsEf($0,$121,$6,$124,$120);
    __ZN5physx12PxcLtbFactorERNS_9PxcFsDataE($0);
    $278 = HEAP16[$132>>1]|0;
    $279 = $278&65535;
    $280 = (($0) + ($279)|0);
    if ($128) {
     $i3$0140 = 1;
     while(1) {
      $281 = (($b) + ($i3$0140<<4)|0);
      $282 = ((($280) + (($i3$0140*400)|0)|0) + 384|0);
      ;HEAP32[$281+0>>2]=HEAP32[$282+0>>2]|0;HEAP32[$281+4>>2]=HEAP32[$282+4>>2]|0;HEAP32[$281+8>>2]=HEAP32[$282+8>>2]|0;HEAP32[$281+12>>2]=HEAP32[$282+12>>2]|0;
      $283 = (($i3$0140) + 1)|0;
      $exitcond160 = ($283|0)==($11|0);
      if ($exitcond160) {
       break;
      } else {
       $i3$0140 = $283;
      }
     }
    }
    _memset(($8|0),0,($133|0))|0;
    __ZN5physx13PxcLtbProjectERKNS_9PxcFsDataEPNS_14PxcSIMDSpatialEPNS_6shdfnd3aos5Vec3VE($0,$8,$b);
    if (!($19)) {
     $i4$0144 = 0;
     while(1) {
      $284 = (($8) + ($i4$0144<<5)|0);
      $285 = Math_fround(HEAPF32[$284>>2]);
      $286 = Math_fround($285 * $dt);
      $287 = ((($8) + ($i4$0144<<5)|0) + 4|0);
      $288 = Math_fround(HEAPF32[$287>>2]);
      $289 = Math_fround($288 * $dt);
      $290 = ((($8) + ($i4$0144<<5)|0) + 8|0);
      $291 = Math_fround(HEAPF32[$290>>2]);
      $292 = Math_fround($291 * $dt);
      $293 = ((($6) + (($i4$0144*28)|0)|0) + 16|0);
      $294 = Math_fround(HEAPF32[$293>>2]);
      $295 = Math_fround($286 + $294);
      $296 = ((($6) + (($i4$0144*28)|0)|0) + 20|0);
      $297 = Math_fround(HEAPF32[$296>>2]);
      $298 = Math_fround($289 + $297);
      $299 = ((($6) + (($i4$0144*28)|0)|0) + 24|0);
      $300 = Math_fround(HEAPF32[$299>>2]);
      $301 = Math_fround($292 + $300);
      $302 = ((($8) + ($i4$0144<<5)|0) + 16|0);
      $303 = Math_fround(HEAPF32[$302>>2]);
      $304 = Math_fround($303 * $dt);
      $305 = ((($8) + ($i4$0144<<5)|0) + 20|0);
      $306 = Math_fround(HEAPF32[$305>>2]);
      $307 = Math_fround($306 * $dt);
      $308 = ((($8) + ($i4$0144<<5)|0) + 24|0);
      $309 = Math_fround(HEAPF32[$308>>2]);
      $310 = Math_fround($309 * $dt);
      $311 = Math_fround($304 * $304);
      $312 = Math_fround($307 * $307);
      $313 = Math_fround($311 + $312);
      $314 = Math_fround($310 * $310);
      $315 = Math_fround($313 + $314);
      $316 = +$315;
      $317 = $316 < 9.999999999999999237E-25;
      if ($317) {
       $332 = Math_fround(1.0);$336 = Math_fround(0.0);$341 = Math_fround(0.0);$346 = Math_fround(0.0);
      } else {
       $318 = (Math_fround(Math_sqrt((Math_fround($315)))));
       $319 = Math_fround(Math_fround(1.0) / $318);
       $320 = Math_fround($304 * $319);
       $321 = Math_fround($307 * $319);
       $322 = Math_fround($310 * $319);
       $323 = Math_fround($318 * Math_fround(0.5));
       $324 = (Math_fround(+(Math_sin((+$323)))));
       $325 = (Math_fround(+(Math_cos((+$323)))));
       $326 = Math_fround($324 * $320);
       $327 = Math_fround($324 * $321);
       $328 = Math_fround($324 * $322);
       $332 = $325;$336 = $326;$341 = $327;$346 = $328;
      }
      $329 = (($6) + (($i4$0144*28)|0)|0);
      $330 = Math_fround(HEAPF32[$329>>2]);
      $331 = Math_fround($332 * $330);
      $333 = ((($6) + (($i4$0144*28)|0)|0) + 12|0);
      $334 = Math_fround(HEAPF32[$333>>2]);
      $335 = Math_fround($336 * $334);
      $337 = Math_fround($331 + $335);
      $338 = ((($6) + (($i4$0144*28)|0)|0) + 8|0);
      $339 = Math_fround(HEAPF32[$338>>2]);
      $340 = Math_fround($341 * $339);
      $342 = Math_fround($337 + $340);
      $343 = ((($6) + (($i4$0144*28)|0)|0) + 4|0);
      $344 = Math_fround(HEAPF32[$343>>2]);
      $345 = Math_fround($346 * $344);
      $347 = Math_fround($342 - $345);
      $348 = Math_fround($332 * $344);
      $349 = Math_fround($341 * $334);
      $350 = Math_fround($349 + $348);
      $351 = Math_fround($346 * $330);
      $352 = Math_fround($351 + $350);
      $353 = Math_fround($336 * $339);
      $354 = Math_fround($352 - $353);
      $355 = Math_fround($332 * $339);
      $356 = Math_fround($346 * $334);
      $357 = Math_fround($356 + $355);
      $358 = Math_fround($336 * $344);
      $359 = Math_fround($358 + $357);
      $360 = Math_fround($341 * $330);
      $361 = Math_fround($359 - $360);
      $362 = Math_fround($332 * $334);
      $363 = Math_fround($336 * $330);
      $364 = Math_fround($362 - $363);
      $365 = Math_fround($341 * $344);
      $366 = Math_fround($364 - $365);
      $367 = Math_fround($346 * $339);
      $368 = Math_fround($366 - $367);
      HEAPF32[$329>>2] = $347;
      HEAPF32[$343>>2] = $354;
      HEAPF32[$338>>2] = $361;
      HEAPF32[$333>>2] = $368;
      HEAPF32[$293>>2] = $295;
      HEAPF32[$296>>2] = $298;
      HEAPF32[$299>>2] = $301;
      $369 = (($i4$0144) + 1)|0;
      $exitcond161 = ($369|0)==($11|0);
      if ($exitcond161) {
       break;
      } else {
       $i4$0144 = $369;
      }
     }
    }
    $370 = (($iterations$0148) + 1)|0;
    $371 = HEAP32[$125>>2]|0;
    $372 = ($370>>>0)<($371>>>0);
    if ($372) {
     $iterations$0148 = $370;$projected$0$off0149 = 1;
    } else {
     break;
    }
   }
   if ((label|0) == 19) {
    if (!($projected$0$off0149)) {
     break;
    }
   }
   if ($19) {
    STACKTOP = sp;return;
   } else {
    $i7$0129 = 0;
   }
   while(1) {
    $373 = ((($6) + (($i7$0129*28)|0)|0) + 16|0);
    $374 = Math_fround(HEAPF32[$373>>2]);
    $375 = ((($14) + (($i7$0129*28)|0)|0) + 16|0);
    $376 = Math_fround(HEAPF32[$375>>2]);
    $377 = Math_fround($374 - $376);
    $378 = ((($6) + (($i7$0129*28)|0)|0) + 20|0);
    $379 = Math_fround(HEAPF32[$378>>2]);
    $380 = ((($14) + (($i7$0129*28)|0)|0) + 20|0);
    $381 = Math_fround(HEAPF32[$380>>2]);
    $382 = Math_fround($379 - $381);
    $383 = ((($6) + (($i7$0129*28)|0)|0) + 24|0);
    $384 = Math_fround(HEAPF32[$383>>2]);
    $385 = ((($14) + (($i7$0129*28)|0)|0) + 24|0);
    $386 = Math_fround(HEAPF32[$385>>2]);
    $387 = Math_fround($384 - $386);
    $388 = Math_fround($120 * $377);
    $389 = Math_fround($120 * $382);
    $390 = Math_fround($120 * $387);
    $391 = (($8) + ($i7$0129<<5)|0);
    HEAPF32[$391>>2] = $388;
    $392 = ((($8) + ($i7$0129<<5)|0) + 4|0);
    HEAPF32[$392>>2] = $389;
    $393 = ((($8) + ($i7$0129<<5)|0) + 8|0);
    HEAPF32[$393>>2] = $390;
    $394 = ((($8) + ($i7$0129<<5)|0) + 12|0);
    HEAPF32[$394>>2] = Math_fround(0.0);
    $395 = (($14) + (($i7$0129*28)|0)|0);
    $396 = Math_fround(HEAPF32[$395>>2]);
    $397 = Math_fround(-$396);
    $398 = ((($14) + (($i7$0129*28)|0)|0) + 4|0);
    $399 = Math_fround(HEAPF32[$398>>2]);
    $400 = Math_fround(-$399);
    $401 = ((($14) + (($i7$0129*28)|0)|0) + 8|0);
    $402 = Math_fround(HEAPF32[$401>>2]);
    $403 = Math_fround(-$402);
    $404 = ((($14) + (($i7$0129*28)|0)|0) + 12|0);
    $405 = Math_fround(HEAPF32[$404>>2]);
    $406 = ((($6) + (($i7$0129*28)|0)|0) + 12|0);
    $407 = Math_fround(HEAPF32[$406>>2]);
    $408 = Math_fround($407 * $397);
    $409 = (($6) + (($i7$0129*28)|0)|0);
    $410 = Math_fround(HEAPF32[$409>>2]);
    $411 = Math_fround($405 * $410);
    $412 = Math_fround($408 + $411);
    $413 = ((($6) + (($i7$0129*28)|0)|0) + 4|0);
    $414 = Math_fround(HEAPF32[$413>>2]);
    $415 = Math_fround($414 * $403);
    $416 = Math_fround($412 + $415);
    $417 = ((($6) + (($i7$0129*28)|0)|0) + 8|0);
    $418 = Math_fround(HEAPF32[$417>>2]);
    $419 = Math_fround($418 * $400);
    $420 = Math_fround($416 - $419);
    $421 = Math_fround($407 * $400);
    $422 = Math_fround($405 * $414);
    $423 = Math_fround($421 + $422);
    $424 = Math_fround($418 * $397);
    $425 = Math_fround($423 + $424);
    $426 = Math_fround($410 * $403);
    $427 = Math_fround($425 - $426);
    $428 = Math_fround($407 * $403);
    $429 = Math_fround($405 * $418);
    $430 = Math_fround($428 + $429);
    $431 = Math_fround($410 * $400);
    $432 = Math_fround($431 + $430);
    $433 = Math_fround($414 * $397);
    $434 = Math_fround($432 - $433);
    $435 = Math_fround($405 * $407);
    $436 = Math_fround($410 * $397);
    $437 = Math_fround($435 - $436);
    $438 = Math_fround($414 * $400);
    $439 = Math_fround($437 - $438);
    $440 = Math_fround($418 * $403);
    $441 = Math_fround($439 - $440);
    $442 = Math_fround($420 * $420);
    $443 = Math_fround($427 * $427);
    $444 = Math_fround($442 + $443);
    $445 = Math_fround($434 * $434);
    $446 = Math_fround($444 + $445);
    $447 = (Math_fround(Math_sqrt((Math_fround($446)))));
    $448 = +$447;
    $449 = $448 < 9.99999999999999979886E-13;
    if ($449) {
     $471 = Math_fround(0.0);$473 = Math_fround(0.0);$475 = Math_fround(0.0);
    } else {
     $450 = $441 < Math_fround(0.0);
     if ($450) {
      $451 = Math_fround(-$447);
      $452 = Math_fround(-$441);
      $453 = +$451;
      $454 = +$452;
      $455 = (+Math_atan2((+$453),(+$454)));
      $$sink$i = $455;
     } else {
      $456 = +$441;
      $457 = (+Math_atan2((+$448),(+$456)));
      $$sink$i = $457;
     }
     $458 = Math_fround($$sink$i);
     $459 = $446 > Math_fround(0.0);
     if ($459) {
      $460 = Math_fround(Math_fround(1.0) / $447);
      $461 = Math_fround($420 * $460);
      $462 = Math_fround($427 * $460);
      $463 = Math_fround($434 * $460);
      $phitmp$i = Math_fround($461 * Math_fround(2.0));
      $phitmp10$i = Math_fround($462 * Math_fround(2.0));
      $phitmp11$i = Math_fround($463 * Math_fround(2.0));
      $465 = $phitmp$i;$467 = $phitmp10$i;$469 = $phitmp11$i;
     } else {
      $465 = Math_fround(0.0);$467 = Math_fround(0.0);$469 = Math_fround(0.0);
     }
     $464 = Math_fround($458 * $465);
     $466 = Math_fround($458 * $467);
     $468 = Math_fround($458 * $469);
     $471 = $464;$473 = $466;$475 = $468;
    }
    $470 = Math_fround($120 * $471);
    $472 = Math_fround($120 * $473);
    $474 = Math_fround($120 * $475);
    $476 = ((($8) + ($i7$0129<<5)|0) + 16|0);
    HEAPF32[$476>>2] = $470;
    $477 = ((($8) + ($i7$0129<<5)|0) + 20|0);
    HEAPF32[$477>>2] = $472;
    $478 = ((($8) + ($i7$0129<<5)|0) + 24|0);
    HEAPF32[$478>>2] = $474;
    $479 = ((($8) + ($i7$0129<<5)|0) + 28|0);
    HEAPF32[$479>>2] = Math_fround(0.0);
    $480 = (($i7$0129) + 1)|0;
    $exitcond157 = ($480|0)==($11|0);
    if ($exitcond157) {
     break;
    } else {
     $i7$0129 = $480;
    }
   }
  }
 } while(0);
 if ($19) {
  STACKTOP = sp;return;
 } else {
  $i8$0127 = 0;
 }
 while(1) {
  $481 = ((($4) + ($i8$0127<<5)|0) + 20|0);
  $482 = HEAP32[$481>>2]|0;
  $483 = (($6) + (($i8$0127*28)|0)|0);
  $484 = Math_fround(HEAPF32[$483>>2]);
  HEAPF32[$482>>2] = $484;
  $485 = ((($6) + (($i8$0127*28)|0)|0) + 4|0);
  $486 = Math_fround(HEAPF32[$485>>2]);
  $487 = (($482) + 4|0);
  HEAPF32[$487>>2] = $486;
  $488 = ((($6) + (($i8$0127*28)|0)|0) + 8|0);
  $489 = Math_fround(HEAPF32[$488>>2]);
  $490 = (($482) + 8|0);
  HEAPF32[$490>>2] = $489;
  $491 = ((($6) + (($i8$0127*28)|0)|0) + 12|0);
  $492 = Math_fround(HEAPF32[$491>>2]);
  $493 = (($482) + 12|0);
  HEAPF32[$493>>2] = $492;
  $494 = ((($6) + (($i8$0127*28)|0)|0) + 16|0);
  $495 = Math_fround(HEAPF32[$494>>2]);
  $496 = (($482) + 16|0);
  HEAPF32[$496>>2] = $495;
  $497 = ((($6) + (($i8$0127*28)|0)|0) + 20|0);
  $498 = Math_fround(HEAPF32[$497>>2]);
  $499 = (($482) + 20|0);
  HEAPF32[$499>>2] = $498;
  $500 = ((($6) + (($i8$0127*28)|0)|0) + 24|0);
  $501 = Math_fround(HEAPF32[$500>>2]);
  $502 = (($482) + 24|0);
  HEAPF32[$502>>2] = $501;
  $503 = (($12) + ($i8$0127<<5)|0);
  $504 = Math_fround(HEAPF32[$503>>2]);
  $505 = ((($12) + ($i8$0127<<5)|0) + 4|0);
  $506 = Math_fround(HEAPF32[$505>>2]);
  $507 = ((($12) + ($i8$0127<<5)|0) + 8|0);
  $508 = Math_fround(HEAPF32[$507>>2]);
  $509 = (($482) + 64|0);
  HEAPF32[$509>>2] = $504;
  $510 = (($482) + 68|0);
  HEAPF32[$510>>2] = $506;
  $511 = (($482) + 72|0);
  HEAPF32[$511>>2] = $508;
  $512 = ((($12) + ($i8$0127<<5)|0) + 16|0);
  $513 = Math_fround(HEAPF32[$512>>2]);
  $514 = ((($12) + ($i8$0127<<5)|0) + 20|0);
  $515 = Math_fround(HEAPF32[$514>>2]);
  $516 = ((($12) + ($i8$0127<<5)|0) + 24|0);
  $517 = Math_fround(HEAPF32[$516>>2]);
  $518 = (($482) + 80|0);
  HEAPF32[$518>>2] = $513;
  $519 = (($482) + 84|0);
  HEAPF32[$519>>2] = $515;
  $520 = (($482) + 88|0);
  HEAPF32[$520>>2] = $517;
  $521 = (($8) + ($i8$0127<<5)|0);
  $522 = Math_fround(HEAPF32[$521>>2]);
  $523 = ((($8) + ($i8$0127<<5)|0) + 4|0);
  $524 = Math_fround(HEAPF32[$523>>2]);
  $525 = ((($8) + ($i8$0127<<5)|0) + 8|0);
  $526 = Math_fround(HEAPF32[$525>>2]);
  $527 = ((($4) + ($i8$0127<<5)|0) + 16|0);
  $528 = HEAP32[$527>>2]|0;
  HEAPF32[$528>>2] = $522;
  $529 = (($528) + 4|0);
  HEAPF32[$529>>2] = $524;
  $530 = (($528) + 8|0);
  HEAPF32[$530>>2] = $526;
  $531 = ((($8) + ($i8$0127<<5)|0) + 16|0);
  $532 = Math_fround(HEAPF32[$531>>2]);
  $533 = ((($8) + ($i8$0127<<5)|0) + 20|0);
  $534 = Math_fround(HEAPF32[$533>>2]);
  $535 = ((($8) + ($i8$0127<<5)|0) + 24|0);
  $536 = Math_fround(HEAPF32[$535>>2]);
  $537 = (($528) + 16|0);
  HEAPF32[$537>>2] = $532;
  $538 = (($528) + 20|0);
  HEAPF32[$538>>2] = $534;
  $539 = (($528) + 24|0);
  HEAPF32[$539>>2] = $536;
  $540 = (($i8$0127) + 1)|0;
  $exitcond = ($540|0)==($11|0);
  if ($exitcond) {
   break;
  } else {
   $i8$0127 = $540;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21PxcArticulationHelper15createHardLimitERKNS_9PxcFsDataEPKNS_19PxsArticulationLinkEjRNS_24PxcSolverConstraint1DExtERKNS_6PxVec3Eff($fsData,$links,$linkIndex,$s,$axis,$err,$recipDt) {
 $fsData = $fsData|0;
 $links = $links|0;
 $linkIndex = $linkIndex|0;
 $s = $s|0;
 $axis = $axis|0;
 $err = Math_fround($err);
 $recipDt = Math_fround($recipDt);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer = sp + 64|0;
 $0 = sp;
 $1 = sp + 32|0;
 HEAPF32[$s>>2] = Math_fround(0.0);
 $2 = (($s) + 4|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($s) + 8|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($s) + 16|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($s) + 20|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($s) + 24|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = Math_fround(HEAPF32[$axis>>2]);
 $8 = (($s) + 32|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($axis) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($s) + 36|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($axis) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($s) + 40|0);
 HEAPF32[$14>>2] = $13;
 $15 = Math_fround(HEAPF32[$axis>>2]);
 $16 = (($s) + 48|0);
 HEAPF32[$16>>2] = $15;
 $17 = Math_fround(HEAPF32[$9>>2]);
 $18 = (($s) + 52|0);
 HEAPF32[$18>>2] = $17;
 $19 = Math_fround(HEAPF32[$12>>2]);
 $20 = (($s) + 56|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($s) + 96|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($s) + 100|0);
 HEAPF32[$22>>2] = Math_fround(3.40282346638528859812E+38);
 $23 = (($s) + 108|0);
 HEAP32[$23>>2] = 0;
 $24 = (($s) + 104|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = ((($links) + ($linkIndex<<5)|0) + 28|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = Math_fround(HEAPF32[$axis>>2]);
 $28 = Math_fround(HEAPF32[$9>>2]);
 $29 = Math_fround(HEAPF32[$12>>2]);
 $30 = (($0) + 16|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 HEAPF32[$30>>2] = $27;
 $31 = (($0) + 20|0);
 HEAPF32[$31>>2] = $28;
 $32 = (($0) + 24|0);
 HEAPF32[$32>>2] = $29;
 $33 = (($0) + 28|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($s) + 112|0);
 $35 = Math_fround(-$27);
 $36 = Math_fround(-$28);
 $37 = Math_fround(-$29);
 $38 = (($1) + 16|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAPF32[$38>>2] = $35;
 $39 = (($1) + 20|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($1) + 24|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($1) + 28|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($s) + 144|0);
 __ZN5physx21PxcArticulationHelper22getImpulseSelfResponseERKNS_9PxcFsDataEjRKNS_14PxcSIMDSpatialERS4_jS6_S7_($fsData,$26,$0,$34,$linkIndex,$1,$42);
 $43 = Math_fround(HEAPF32[$axis>>2]);
 $44 = (($s) + 128|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 * $45);
 $47 = Math_fround(HEAPF32[$9>>2]);
 $48 = (($s) + 132|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($47 * $49);
 $51 = Math_fround($46 + $50);
 $52 = Math_fround(HEAPF32[$12>>2]);
 $53 = (($s) + 136|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($52 * $54);
 $56 = Math_fround($51 + $55);
 $57 = (($s) + 160|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($43 * $58);
 $60 = (($s) + 164|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($47 * $61);
 $63 = Math_fround($59 + $62);
 $64 = (($s) + 168|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($52 * $65);
 $67 = Math_fround($63 + $66);
 $68 = Math_fround($56 - $67);
 $69 = $68 < Math_fround(0.0);
 if (!($69)) {
  $71 = Math_fround(Math_fround(1.0) / $68);
  $72 = Math_fround($71 * $err);
  $73 = Math_fround($72 * $recipDt);
  $74 = Math_fround(-$73);
  $75 = (($s) + 12|0);
  HEAPF32[$75>>2] = $74;
  $76 = $err > Math_fround(0.0);
  $77 = $76 ? $74 : Math_fround(0.0);
  $78 = (($s) + 28|0);
  HEAPF32[$78>>2] = $77;
  $79 = Math_fround(-$71);
  $80 = (($s) + 44|0);
  HEAPF32[$80>>2] = $79;
  $81 = (($s) + 60|0);
  HEAPF32[$81>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
 $70 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($70,2,503320,1198,503424,$vararg_buffer);
 $71 = Math_fround(Math_fround(1.0) / $68);
 $72 = Math_fround($71 * $err);
 $73 = Math_fround($72 * $recipDt);
 $74 = Math_fround(-$73);
 $75 = (($s) + 12|0);
 HEAPF32[$75>>2] = $74;
 $76 = $err > Math_fround(0.0);
 $77 = $76 ? $74 : Math_fround(0.0);
 $78 = (($s) + 28|0);
 HEAPF32[$78>>2] = $77;
 $79 = Math_fround(-$71);
 $80 = (($s) + 44|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($s) + 60|0);
 HEAPF32[$81>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN5physx26PxcArticulationFnsSimdBase16multiplySubtractERKNS_12PxcFsInertiaEPKNS_14PxcSIMDSpatialE($agg$result,$I,$S) {
 $agg$result = $agg$result|0;
 $I = $I|0;
 $S = $S|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0);
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0;
 var $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0;
 var $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$S>>2]);
 $1 = (($S) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($S) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($S) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($S) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($S) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($S) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($S) + 36|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($S) + 40|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($S) + 48|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($S) + 52|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($S) + 56|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($S) + 64|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($S) + 68|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($S) + 72|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($S) + 80|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($S) + 84|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($S) + 88|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround(HEAPF32[$I>>2]);
 $36 = (($I) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($I) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($I) + 16|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($I) + 20|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($I) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($I) + 32|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($I) + 36|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($I) + 40|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($I) + 48|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($I) + 52|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($I) + 56|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($I) + 64|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($I) + 68|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($I) + 72|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($I) + 80|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($I) + 84|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($I) + 88|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($I) + 96|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($I) + 100|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($I) + 104|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($I) + 112|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($I) + 116|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($I) + 120|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($I) + 128|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($I) + 132|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($I) + 136|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($0 * $0);
 $89 = Math_fround($0 * $2);
 $90 = Math_fround($0 * $4);
 $91 = Math_fround($35 - $88);
 $92 = Math_fround($37 - $89);
 $93 = Math_fround($39 - $90);
 $94 = Math_fround($0 * $6);
 $95 = Math_fround($2 * $6);
 $96 = Math_fround($4 * $6);
 $97 = Math_fround($53 - $94);
 $98 = Math_fround($55 - $95);
 $99 = Math_fround($57 - $96);
 $100 = Math_fround($6 * $6);
 $101 = Math_fround($6 * $8);
 $102 = Math_fround($6 * $10);
 $103 = Math_fround($71 - $100);
 $104 = Math_fround($73 - $101);
 $105 = Math_fround($75 - $102);
 $106 = Math_fround($2 * $2);
 $107 = Math_fround($2 * $4);
 $108 = Math_fround($41 - $89);
 $109 = Math_fround($43 - $106);
 $110 = Math_fround($45 - $107);
 $111 = Math_fround($0 * $8);
 $112 = Math_fround($2 * $8);
 $113 = Math_fround($4 * $8);
 $114 = Math_fround($59 - $111);
 $115 = Math_fround($61 - $112);
 $116 = Math_fround($63 - $113);
 $117 = Math_fround($8 * $8);
 $118 = Math_fround($8 * $10);
 $119 = Math_fround($77 - $101);
 $120 = Math_fround($79 - $117);
 $121 = Math_fround($81 - $118);
 $122 = Math_fround($4 * $4);
 $123 = Math_fround($47 - $90);
 $124 = Math_fround($49 - $107);
 $125 = Math_fround($51 - $122);
 $126 = Math_fround($0 * $10);
 $127 = Math_fround($2 * $10);
 $128 = Math_fround($4 * $10);
 $129 = Math_fround($65 - $126);
 $130 = Math_fround($67 - $127);
 $131 = Math_fround($69 - $128);
 $132 = Math_fround($10 * $10);
 $133 = Math_fround($83 - $102);
 $134 = Math_fround($85 - $118);
 $135 = Math_fround($87 - $132);
 $136 = Math_fround($12 * $12);
 $137 = Math_fround($12 * $14);
 $138 = Math_fround($12 * $16);
 $139 = Math_fround($91 - $136);
 $140 = Math_fround($92 - $137);
 $141 = Math_fround($93 - $138);
 $142 = Math_fround($12 * $18);
 $143 = Math_fround($14 * $18);
 $144 = Math_fround($16 * $18);
 $145 = Math_fround($97 - $142);
 $146 = Math_fround($98 - $143);
 $147 = Math_fround($99 - $144);
 $148 = Math_fround($18 * $18);
 $149 = Math_fround($18 * $20);
 $150 = Math_fround($18 * $22);
 $151 = Math_fround($103 - $148);
 $152 = Math_fround($104 - $149);
 $153 = Math_fround($105 - $150);
 $154 = Math_fround($14 * $14);
 $155 = Math_fround($14 * $16);
 $156 = Math_fround($108 - $137);
 $157 = Math_fround($109 - $154);
 $158 = Math_fround($110 - $155);
 $159 = Math_fround($12 * $20);
 $160 = Math_fround($14 * $20);
 $161 = Math_fround($16 * $20);
 $162 = Math_fround($114 - $159);
 $163 = Math_fround($115 - $160);
 $164 = Math_fround($116 - $161);
 $165 = Math_fround($20 * $20);
 $166 = Math_fround($20 * $22);
 $167 = Math_fround($119 - $149);
 $168 = Math_fround($120 - $165);
 $169 = Math_fround($121 - $166);
 $170 = Math_fround($16 * $16);
 $171 = Math_fround($123 - $138);
 $172 = Math_fround($124 - $155);
 $173 = Math_fround($125 - $170);
 $174 = Math_fround($12 * $22);
 $175 = Math_fround($14 * $22);
 $176 = Math_fround($16 * $22);
 $177 = Math_fround($129 - $174);
 $178 = Math_fround($130 - $175);
 $179 = Math_fround($131 - $176);
 $180 = Math_fround($22 * $22);
 $181 = Math_fround($133 - $150);
 $182 = Math_fround($134 - $166);
 $183 = Math_fround($135 - $180);
 $184 = Math_fround($24 * $24);
 $185 = Math_fround($24 * $26);
 $186 = Math_fround($24 * $28);
 $187 = Math_fround($139 - $184);
 $188 = Math_fround($140 - $185);
 $189 = Math_fround($141 - $186);
 $190 = Math_fround($24 * $30);
 $191 = Math_fround($26 * $30);
 $192 = Math_fround($28 * $30);
 $193 = Math_fround($145 - $190);
 $194 = Math_fround($146 - $191);
 $195 = Math_fround($147 - $192);
 $196 = Math_fround($30 * $30);
 $197 = Math_fround($30 * $32);
 $198 = Math_fround($30 * $34);
 $199 = Math_fround($151 - $196);
 $200 = Math_fround($152 - $197);
 $201 = Math_fround($153 - $198);
 $202 = Math_fround($26 * $26);
 $203 = Math_fround($26 * $28);
 $204 = Math_fround($156 - $185);
 $205 = Math_fround($157 - $202);
 $206 = Math_fround($158 - $203);
 $207 = Math_fround($24 * $32);
 $208 = Math_fround($26 * $32);
 $209 = Math_fround($28 * $32);
 $210 = Math_fround($162 - $207);
 $211 = Math_fround($163 - $208);
 $212 = Math_fround($164 - $209);
 $213 = Math_fround($32 * $32);
 $214 = Math_fround($32 * $34);
 $215 = Math_fround($167 - $197);
 $216 = Math_fround($168 - $213);
 $217 = Math_fround($169 - $214);
 $218 = Math_fround($28 * $28);
 $219 = Math_fround($171 - $186);
 $220 = Math_fround($172 - $203);
 $221 = Math_fround($173 - $218);
 $222 = Math_fround($24 * $34);
 $223 = Math_fround($26 * $34);
 $224 = Math_fround($28 * $34);
 $225 = Math_fround($177 - $222);
 $226 = Math_fround($178 - $223);
 $227 = Math_fround($179 - $224);
 $228 = Math_fround($34 * $34);
 $229 = Math_fround($181 - $198);
 $230 = Math_fround($182 - $214);
 $231 = Math_fround($183 - $228);
 HEAPF32[$agg$result>>2] = $187;
 $232 = (($agg$result) + 4|0);
 HEAPF32[$232>>2] = $188;
 $233 = (($agg$result) + 8|0);
 HEAPF32[$233>>2] = $189;
 $234 = (($agg$result) + 12|0);
 HEAPF32[$234>>2] = Math_fround(0.0);
 $235 = (($agg$result) + 16|0);
 HEAPF32[$235>>2] = $204;
 $236 = (($agg$result) + 20|0);
 HEAPF32[$236>>2] = $205;
 $237 = (($agg$result) + 24|0);
 HEAPF32[$237>>2] = $206;
 $238 = (($agg$result) + 28|0);
 HEAPF32[$238>>2] = Math_fround(0.0);
 $239 = (($agg$result) + 32|0);
 HEAPF32[$239>>2] = $219;
 $240 = (($agg$result) + 36|0);
 HEAPF32[$240>>2] = $220;
 $241 = (($agg$result) + 40|0);
 HEAPF32[$241>>2] = $221;
 $242 = (($agg$result) + 44|0);
 HEAPF32[$242>>2] = Math_fround(0.0);
 $243 = (($agg$result) + 48|0);
 HEAPF32[$243>>2] = $193;
 $244 = (($agg$result) + 52|0);
 HEAPF32[$244>>2] = $194;
 $245 = (($agg$result) + 56|0);
 HEAPF32[$245>>2] = $195;
 $246 = (($agg$result) + 60|0);
 HEAPF32[$246>>2] = Math_fround(0.0);
 $247 = (($agg$result) + 64|0);
 HEAPF32[$247>>2] = $210;
 $248 = (($agg$result) + 68|0);
 HEAPF32[$248>>2] = $211;
 $249 = (($agg$result) + 72|0);
 HEAPF32[$249>>2] = $212;
 $250 = (($agg$result) + 76|0);
 HEAPF32[$250>>2] = Math_fround(0.0);
 $251 = (($agg$result) + 80|0);
 HEAPF32[$251>>2] = $225;
 $252 = (($agg$result) + 84|0);
 HEAPF32[$252>>2] = $226;
 $253 = (($agg$result) + 88|0);
 HEAPF32[$253>>2] = $227;
 $254 = (($agg$result) + 92|0);
 HEAPF32[$254>>2] = Math_fround(0.0);
 $255 = (($agg$result) + 96|0);
 HEAPF32[$255>>2] = $199;
 $256 = (($agg$result) + 100|0);
 HEAPF32[$256>>2] = $200;
 $257 = (($agg$result) + 104|0);
 HEAPF32[$257>>2] = $201;
 $258 = (($agg$result) + 108|0);
 HEAPF32[$258>>2] = Math_fround(0.0);
 $259 = (($agg$result) + 112|0);
 HEAPF32[$259>>2] = $215;
 $260 = (($agg$result) + 116|0);
 HEAPF32[$260>>2] = $216;
 $261 = (($agg$result) + 120|0);
 HEAPF32[$261>>2] = $217;
 $262 = (($agg$result) + 124|0);
 HEAPF32[$262>>2] = Math_fround(0.0);
 $263 = (($agg$result) + 128|0);
 HEAPF32[$263>>2] = $229;
 $264 = (($agg$result) + 132|0);
 HEAPF32[$264>>2] = $230;
 $265 = (($agg$result) + 136|0);
 HEAPF32[$265>>2] = $231;
 $266 = (($agg$result) + 140|0);
 HEAPF32[$266>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx17PxcFsApplyImpulseERNS_9PxcFsDataEjNS_6shdfnd3aos5Vec3VES4_($matrix,$linkID,$linear,$angular) {
 $matrix = $matrix|0;
 $linkID = $linkID|0;
 $linear = $linear|0;
 $angular = $angular|0;
 var $$lcssa = Math_fround(0), $$lcssa409 = Math_fround(0), $$lcssa410 = Math_fround(0), $$lcssa411 = Math_fround(0), $$lcssa412 = Math_fround(0), $$lcssa413 = Math_fround(0), $$sum$i = 0, $$sum$i82 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0;
 var $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0;
 var $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0;
 var $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = Math_fround(0), $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0);
 var $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0);
 var $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $i$0414 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$linear>>2]);
 $1 = (($linear) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($linear) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$0);
 $6 = Math_fround(-$2);
 $7 = Math_fround(-$4);
 $8 = Math_fround(HEAPF32[$angular>>2]);
 $9 = (($angular) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($angular) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(-$8);
 $14 = Math_fround(-$10);
 $15 = Math_fround(-$12);
 $16 = (($matrix) + 26|0);
 $17 = HEAP16[$16>>1]|0;
 $18 = $17&65535;
 $$sum$i82 = (($18) + 144)|0;
 $19 = (($matrix) + ($$sum$i82)|0);
 $20 = (($matrix) + 10|0);
 $21 = HEAP16[$20>>1]|0;
 $22 = $21&65535;
 $23 = (($matrix) + ($22)|0);
 $24 = (($matrix) + 128|0);
 $25 = (($matrix) + 8|0);
 $26 = HEAP16[$25>>1]|0;
 $27 = $26&65535;
 $$sum$i = $27 << 6;
 $28 = (($24) + ($$sum$i)|0);
 $29 = ($linkID|0)==(0);
 if ($29) {
  $$lcssa = $7;$$lcssa409 = $6;$$lcssa410 = $5;$$lcssa411 = $15;$$lcssa412 = $14;$$lcssa413 = $13;
 } else {
  $37 = $6;$39 = $7;$43 = $5;$49 = $13;$51 = $14;$53 = $15;$i$0414 = $linkID;
  while(1) {
   $30 = ((($23) + ($i$0414<<5)|0) + 16|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = ((($23) + ($i$0414<<5)|0) + 20|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = ((($23) + ($i$0414<<5)|0) + 24|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = Math_fround($37 * $35);
   $38 = Math_fround($39 * $33);
   $40 = Math_fround($36 - $38);
   $41 = Math_fround($39 * $31);
   $42 = Math_fround($43 * $35);
   $44 = Math_fround($41 - $42);
   $45 = Math_fround($43 * $33);
   $46 = Math_fround($37 * $31);
   $47 = Math_fround($45 - $46);
   $48 = Math_fround($49 + $40);
   $50 = Math_fround($51 + $44);
   $52 = Math_fround($53 + $47);
   $54 = (($19) + (($i$0414*160)|0)|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = ((($19) + (($i$0414*160)|0)|0) + 4|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = ((($19) + (($i$0414*160)|0)|0) + 8|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = ((($19) + (($i$0414*160)|0)|0) + 32|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = ((($19) + (($i$0414*160)|0)|0) + 36|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = ((($19) + (($i$0414*160)|0)|0) + 40|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = ((($19) + (($i$0414*160)|0)|0) + 64|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = ((($19) + (($i$0414*160)|0)|0) + 68|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = ((($19) + (($i$0414*160)|0)|0) + 72|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = Math_fround($52 * $67);
   $73 = Math_fround($52 * $69);
   $74 = Math_fround($52 * $71);
   $75 = Math_fround($50 * $61);
   $76 = Math_fround($50 * $63);
   $77 = Math_fround($50 * $65);
   $78 = Math_fround($75 + $72);
   $79 = Math_fround($76 + $73);
   $80 = Math_fround($77 + $74);
   $81 = Math_fround($55 * $48);
   $82 = Math_fround($57 * $48);
   $83 = Math_fround($59 * $48);
   $84 = Math_fround($81 + $78);
   $85 = Math_fround($82 + $79);
   $86 = Math_fround($83 + $80);
   $87 = Math_fround($43 - $84);
   $88 = Math_fround($37 - $85);
   $89 = Math_fround($39 - $86);
   $90 = ((($19) + (($i$0414*160)|0)|0) + 16|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = ((($19) + (($i$0414*160)|0)|0) + 20|0);
   $93 = Math_fround(HEAPF32[$92>>2]);
   $94 = ((($19) + (($i$0414*160)|0)|0) + 24|0);
   $95 = Math_fround(HEAPF32[$94>>2]);
   $96 = ((($19) + (($i$0414*160)|0)|0) + 48|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = ((($19) + (($i$0414*160)|0)|0) + 52|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $100 = ((($19) + (($i$0414*160)|0)|0) + 56|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = ((($19) + (($i$0414*160)|0)|0) + 80|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = ((($19) + (($i$0414*160)|0)|0) + 84|0);
   $105 = Math_fround(HEAPF32[$104>>2]);
   $106 = ((($19) + (($i$0414*160)|0)|0) + 88|0);
   $107 = Math_fround(HEAPF32[$106>>2]);
   $108 = Math_fround($52 * $103);
   $109 = Math_fround($52 * $105);
   $110 = Math_fround($52 * $107);
   $111 = Math_fround($50 * $97);
   $112 = Math_fround($50 * $99);
   $113 = Math_fround($50 * $101);
   $114 = Math_fround($111 + $108);
   $115 = Math_fround($112 + $109);
   $116 = Math_fround($113 + $110);
   $117 = Math_fround($48 * $91);
   $118 = Math_fround($48 * $93);
   $119 = Math_fround($48 * $95);
   $120 = Math_fround($117 + $114);
   $121 = Math_fround($118 + $115);
   $122 = Math_fround($119 + $116);
   $123 = Math_fround($49 - $120);
   $124 = Math_fround($51 - $121);
   $125 = Math_fround($53 - $122);
   $126 = (($23) + ($i$0414<<5)|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = ((($23) + ($i$0414<<5)|0) + 4|0);
   $129 = Math_fround(HEAPF32[$128>>2]);
   $130 = ((($23) + ($i$0414<<5)|0) + 8|0);
   $131 = Math_fround(HEAPF32[$130>>2]);
   $132 = Math_fround($89 * $129);
   $133 = Math_fround($88 * $131);
   $134 = Math_fround($132 - $133);
   $135 = Math_fround($87 * $131);
   $136 = Math_fround($89 * $127);
   $137 = Math_fround($135 - $136);
   $138 = Math_fround($88 * $127);
   $139 = Math_fround($87 * $129);
   $140 = Math_fround($138 - $139);
   $141 = Math_fround($123 + $134);
   $142 = Math_fround($124 + $137);
   $143 = Math_fround($125 + $140);
   $144 = (($28) + ($i$0414<<4)|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = ((($28) + ($i$0414<<4)|0) + 4|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = ((($28) + ($i$0414<<4)|0) + 8|0);
   $149 = Math_fround(HEAPF32[$148>>2]);
   $150 = ((($28) + ($i$0414<<4)|0) + 12|0);
   $151 = Math_fround($48 + $145);
   $152 = Math_fround($50 + $147);
   $153 = Math_fround($52 + $149);
   HEAPF32[$144>>2] = $151;
   HEAPF32[$146>>2] = $152;
   HEAPF32[$148>>2] = $153;
   HEAPF32[$150>>2] = Math_fround(0.0);
   $154 = ((($matrix) + ($i$0414)|0) + 64|0);
   $155 = HEAP8[$154>>0]|0;
   $156 = $155&255;
   $157 = ($155<<24>>24)==(0);
   if ($157) {
    $$lcssa = $89;$$lcssa409 = $88;$$lcssa410 = $87;$$lcssa411 = $143;$$lcssa412 = $142;$$lcssa413 = $141;
    break;
   } else {
    $37 = $88;$39 = $89;$43 = $87;$49 = $141;$51 = $142;$53 = $143;$i$0414 = $156;
   }
  }
 }
 $158 = (($matrix) + 32|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($matrix) + 36|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($matrix) + 40|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($matrix) + 44|0);
 $165 = Math_fround($$lcssa410 + $159);
 $166 = Math_fround($$lcssa409 + $161);
 $167 = Math_fround($$lcssa + $163);
 HEAPF32[$158>>2] = $165;
 HEAPF32[$160>>2] = $166;
 HEAPF32[$162>>2] = $167;
 HEAPF32[$164>>2] = Math_fround(0.0);
 $168 = (($matrix) + 48|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($matrix) + 52|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($matrix) + 56|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = (($matrix) + 60|0);
 $175 = Math_fround($$lcssa413 + $169);
 $176 = Math_fround($$lcssa412 + $171);
 $177 = Math_fround($$lcssa411 + $173);
 HEAPF32[$168>>2] = $175;
 HEAPF32[$170>>2] = $176;
 HEAPF32[$172>>2] = $177;
 HEAPF32[$174>>2] = Math_fround(0.0);
 $178 = ((($19) + (($linkID*160)|0)|0) + 152|0);
 $179 = $178;
 $180 = $179;
 $181 = HEAP32[$180>>2]|0;
 $182 = (($179) + 4)|0;
 $183 = $182;
 $184 = HEAP32[$183>>2]|0;
 $185 = (($matrix) + 16|0);
 $186 = $185;
 $187 = $186;
 $188 = HEAP32[$187>>2]|0;
 $189 = (($186) + 4)|0;
 $190 = $189;
 $191 = HEAP32[$190>>2]|0;
 $192 = $188 | $181;
 $193 = $191 | $184;
 $194 = $185;
 $195 = $194;
 HEAP32[$195>>2] = $192;
 $196 = (($194) + 4)|0;
 $197 = $196;
 HEAP32[$197>>2] = $193;
 STACKTOP = sp;return;
}
function __ZN5physx16PxcFsGetVelocityERNS_9PxcFsDataEj($agg$result,$matrix,$linkID) {
 $agg$result = $agg$result|0;
 $matrix = $matrix|0;
 $linkID = $linkID|0;
 var $$ph = Math_fround(0), $$ph609 = Math_fround(0), $$ph610 = Math_fround(0), $$ph611 = Math_fround(0), $$ph612 = Math_fround(0), $$ph613 = Math_fround(0), $$sum = 0, $$sum$i = 0, $$sum$i107 = 0, $$sum582 = 0, $$sum583 = 0, $$sum584 = 0, $$sum585 = 0, $$sum586 = 0, $$sum587 = 0, $$sum588 = 0, $$sum589 = 0, $$sum590 = 0, $$sum591 = 0, $$sum592 = 0;
 var $$sum593 = 0, $$sum594 = 0, $$sum595 = 0, $$sum596 = 0, $$sum597 = 0, $$sum598 = 0, $$sum599 = 0, $$sum600 = 0, $$sum601 = 0, $$sum602 = 0, $$sum603 = 0, $$sum604 = 0, $$sum605 = 0, $$sum606 = 0, $$sum607 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0);
 var $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0;
 var $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0);
 var $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0);
 var $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0);
 var $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0;
 var $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0);
 var $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0);
 var $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0;
 var $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0;
 var $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0;
 var $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0;
 var $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0);
 var $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = Math_fround(0);
 var $391 = 0, $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = 0;
 var $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0);
 var $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0);
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = Math_fround(0), $503 = 0, $504 = Math_fround(0), $505 = 0, $506 = 0, $507 = Math_fround(0), $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = 0, $516 = Math_fround(0);
 var $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = 0, $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $count$0$ph = 0, $count$0616 = 0, $dVStack = 0, $indexToStackLoc = 0, $not$$i = 0, $not$$i78 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2384|0;
 $indexToStackLoc = sp + 2128|0;
 $dVStack = sp;
 $0 = sp + 2048|0;
 $1 = sp + 2064|0;
 $2 = sp + 2080|0;
 $3 = sp + 2096|0;
 $4 = sp + 2112|0;
 $5 = (($matrix) + 26|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6&65535;
 $$sum$i = (($7) + 144)|0;
 $8 = (($matrix) + ($$sum$i)|0);
 $9 = (($matrix) + 10|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 $12 = (($matrix) + ($11)|0);
 $13 = (($matrix) + 128|0);
 $14 = ((($8) + (($linkID*160)|0)|0) + 152|0);
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($matrix) + 16|0);
 $22 = $21;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 4)|0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = $24 & $17;
 $29 = $27 & $20;
 $30 = ($28|0)==(0);
 $31 = ($29|0)==(0);
 $32 = $30 & $31;
 if ($32) {
  $552 = (($13) + ($linkID<<5)|0);
  ;HEAP32[$agg$result+0>>2]=HEAP32[$552+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$552+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$552+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$552+12>>2]|0;
  $553 = (($agg$result) + 16|0);
  $554 = ((($13) + ($linkID<<5)|0) + 16|0);
  ;HEAP32[$553+0>>2]=HEAP32[$554+0>>2]|0;HEAP32[$553+4>>2]=HEAP32[$554+4>>2]|0;HEAP32[$553+8>>2]=HEAP32[$554+8>>2]|0;HEAP32[$553+12>>2]=HEAP32[$554+12>>2]|0;
  STACKTOP = sp;return;
 }
 $33 = (_i64Subtract(0,0,($28|0),($29|0))|0);
 $34 = tempRet0;
 $35 = $28 & $33;
 $36 = $29 & $34;
 $37 = (_i64Subtract(0,0,($35|0),($36|0))|0);
 $38 = tempRet0;
 $39 = $17 & $37;
 $40 = $20 & $38;
 $41 = (($matrix) + 8|0);
 $42 = HEAP16[$41>>1]|0;
 $43 = $42&65535;
 $44 = $43 << 5;
 $45 = (($13) + ($44)|0);
 $$sum$i107 = $43 << 6;
 $46 = (($13) + ($$sum$i107)|0);
 $47 = $39 & 1;
 $48 = ($47|0)==(0);
 $49 = (0)==(0);
 $50 = $48 & $49;
 if ($50) {
  $$ph = Math_fround(0.0);$$ph609 = Math_fround(0.0);$$ph610 = Math_fround(0.0);$$ph611 = Math_fround(0.0);$$ph612 = Math_fround(0.0);$$ph613 = Math_fround(0.0);$227 = $39;$229 = $40;$555 = 0;$556 = 0;$count$0$ph = 0;
 } else {
  $51 = (($matrix) + ($7)|0);
  $52 = (($matrix) + 32|0);
  $53 = (($matrix) + 32|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($matrix) + 36|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($matrix) + 40|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround(-$54);
  $60 = Math_fround(-$56);
  $61 = Math_fround(-$58);
  $62 = (($matrix) + 48|0);
  $63 = (($matrix) + 48|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($matrix) + 52|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = (($matrix) + 56|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround(-$64);
  $70 = Math_fround(-$66);
  $71 = Math_fround(-$68);
  $72 = Math_fround(HEAPF32[$51>>2]);
  $73 = Math_fround($72 * $59);
  $$sum = (($7) + 16)|0;
  $74 = (($matrix) + ($$sum)|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($75 * $60);
  $77 = Math_fround($73 + $76);
  $$sum582 = (($7) + 32)|0;
  $78 = (($matrix) + ($$sum582)|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($79 * $61);
  $81 = Math_fround($77 + $80);
  $$sum583 = (($7) + 4)|0;
  $82 = (($matrix) + ($$sum583)|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($83 * $59);
  $$sum584 = (($7) + 20)|0;
  $85 = (($matrix) + ($$sum584)|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround($86 * $60);
  $88 = Math_fround($84 + $87);
  $$sum585 = (($7) + 36)|0;
  $89 = (($matrix) + ($$sum585)|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = Math_fround($90 * $61);
  $92 = Math_fround($88 + $91);
  $$sum586 = (($7) + 8)|0;
  $93 = (($matrix) + ($$sum586)|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = Math_fround($94 * $59);
  $$sum587 = (($7) + 24)|0;
  $96 = (($matrix) + ($$sum587)|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = Math_fround($97 * $60);
  $99 = Math_fround($95 + $98);
  $$sum588 = (($7) + 40)|0;
  $100 = (($matrix) + ($$sum588)|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $102 = Math_fround($101 * $61);
  $103 = Math_fround($99 + $102);
  $$sum589 = (($7) + 48)|0;
  $104 = (($matrix) + ($$sum589)|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($105 * $69);
  $$sum590 = (($7) + 64)|0;
  $107 = (($matrix) + ($$sum590)|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($108 * $70);
  $110 = Math_fround($106 + $109);
  $$sum591 = (($7) + 80)|0;
  $111 = (($matrix) + ($$sum591)|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = Math_fround($112 * $71);
  $114 = Math_fround($110 + $113);
  $$sum592 = (($7) + 52)|0;
  $115 = (($matrix) + ($$sum592)|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = Math_fround($116 * $69);
  $$sum593 = (($7) + 68)|0;
  $118 = (($matrix) + ($$sum593)|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround($119 * $70);
  $121 = Math_fround($117 + $120);
  $$sum594 = (($7) + 84)|0;
  $122 = (($matrix) + ($$sum594)|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = Math_fround($123 * $71);
  $125 = Math_fround($121 + $124);
  $$sum595 = (($7) + 56)|0;
  $126 = (($matrix) + ($$sum595)|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = Math_fround($127 * $69);
  $$sum596 = (($7) + 72)|0;
  $129 = (($matrix) + ($$sum596)|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($130 * $70);
  $132 = Math_fround($128 + $131);
  $$sum597 = (($7) + 88)|0;
  $133 = (($matrix) + ($$sum597)|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($134 * $71);
  $136 = Math_fround($132 + $135);
  $137 = Math_fround($81 + $114);
  $138 = Math_fround($92 + $125);
  $139 = Math_fround($103 + $136);
  $140 = Math_fround($105 * $59);
  $141 = Math_fround($116 * $60);
  $142 = Math_fround($140 + $141);
  $143 = Math_fround($127 * $61);
  $144 = Math_fround($142 + $143);
  $145 = Math_fround($108 * $59);
  $146 = Math_fround($119 * $60);
  $147 = Math_fround($145 + $146);
  $148 = Math_fround($130 * $61);
  $149 = Math_fround($147 + $148);
  $150 = Math_fround($112 * $59);
  $151 = Math_fround($123 * $60);
  $152 = Math_fround($150 + $151);
  $153 = Math_fround($134 * $61);
  $154 = Math_fround($152 + $153);
  $$sum598 = (($7) + 96)|0;
  $155 = (($matrix) + ($$sum598)|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = Math_fround($156 * $69);
  $$sum599 = (($7) + 112)|0;
  $158 = (($matrix) + ($$sum599)|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = Math_fround($159 * $70);
  $161 = Math_fround($157 + $160);
  $$sum600 = (($7) + 128)|0;
  $162 = (($matrix) + ($$sum600)|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = Math_fround($163 * $71);
  $165 = Math_fround($161 + $164);
  $$sum601 = (($7) + 100)|0;
  $166 = (($matrix) + ($$sum601)|0);
  $167 = Math_fround(HEAPF32[$166>>2]);
  $168 = Math_fround($167 * $69);
  $$sum602 = (($7) + 116)|0;
  $169 = (($matrix) + ($$sum602)|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround($170 * $70);
  $172 = Math_fround($168 + $171);
  $$sum603 = (($7) + 132)|0;
  $173 = (($matrix) + ($$sum603)|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = Math_fround($174 * $71);
  $176 = Math_fround($172 + $175);
  $$sum604 = (($7) + 104)|0;
  $177 = (($matrix) + ($$sum604)|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = Math_fround($178 * $69);
  $$sum605 = (($7) + 120)|0;
  $180 = (($matrix) + ($$sum605)|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = Math_fround($181 * $70);
  $183 = Math_fround($179 + $182);
  $$sum606 = (($7) + 136)|0;
  $184 = (($matrix) + ($$sum606)|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = Math_fround($185 * $71);
  $187 = Math_fround($183 + $186);
  $188 = Math_fround($144 + $165);
  $189 = Math_fround($149 + $176);
  $190 = Math_fround($154 + $187);
  $191 = Math_fround(HEAPF32[$13>>2]);
  $192 = (($matrix) + 132|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($matrix) + 136|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($matrix) + 140|0);
  $197 = Math_fround($137 + $191);
  $198 = Math_fround($138 + $193);
  $199 = Math_fround($139 + $195);
  HEAPF32[$13>>2] = $197;
  HEAPF32[$192>>2] = $198;
  HEAPF32[$194>>2] = $199;
  HEAPF32[$196>>2] = Math_fround(0.0);
  $200 = (($matrix) + 144|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (($13) + 20|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = (($matrix) + 152|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = (($matrix) + 156|0);
  $207 = Math_fround($188 + $201);
  $208 = Math_fround($189 + $203);
  $209 = Math_fround($190 + $205);
  HEAPF32[$200>>2] = $207;
  HEAPF32[$202>>2] = $208;
  HEAPF32[$204>>2] = $209;
  HEAPF32[$206>>2] = Math_fround(0.0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  ;HEAP32[$52+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$52+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$52+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$52+12>>2]=HEAP32[$0+12>>2]|0;
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
  ;HEAP32[$62+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$62+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$62+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$62+12>>2]=HEAP32[$1+12>>2]|0;
  HEAP32[$indexToStackLoc>>2] = 0;
  HEAPF32[$dVStack>>2] = $137;
  $210 = (($dVStack) + 4|0);
  HEAPF32[$210>>2] = $138;
  $211 = (($dVStack) + 8|0);
  HEAPF32[$211>>2] = $139;
  $212 = (($dVStack) + 12|0);
  HEAPF32[$212>>2] = Math_fround(0.0);
  $213 = (($dVStack) + 16|0);
  HEAPF32[$213>>2] = $188;
  $214 = (($dVStack) + 20|0);
  HEAPF32[$214>>2] = $189;
  $215 = (($dVStack) + 24|0);
  HEAPF32[$215>>2] = $190;
  $216 = (($dVStack) + 28|0);
  HEAPF32[$216>>2] = Math_fround(0.0);
  $$sum607 = (($7) + 288)|0;
  $217 = (($matrix) + ($$sum607)|0);
  $218 = $217;
  $219 = $218;
  $220 = HEAP32[$219>>2]|0;
  $221 = (($218) + 4)|0;
  $222 = $221;
  $223 = HEAP32[$222>>2]|0;
  $224 = (_i64Add(($39|0),($40|0),-1,-1)|0);
  $225 = tempRet0;
  $$ph = $139;$$ph609 = $138;$$ph610 = $137;$$ph611 = $190;$$ph612 = $189;$$ph613 = $188;$227 = $224;$229 = $225;$555 = $220;$556 = $223;$count$0$ph = 1;
 }
 $226 = ($227|0)==(0);
 $228 = ($229|0)==(0);
 $230 = $226 & $228;
 if ($230) {
  $472 = $555;$474 = $556;
 } else {
  $231 = $227;$239 = $229;$258 = $$ph610;$260 = $$ph609;$262 = $$ph;$270 = $$ph613;$272 = $$ph612;$274 = $$ph611;$455 = $555;$457 = $556;$count$0616 = $count$0$ph;
  while(1) {
   $not$$i78 = ($231|0)!=(0);
   $232 = (0 - ($231))|0;
   $233 = $231 & $232;
   $234 = Math_imul($233, 125613361)|0;
   $235 = $234 >>> 27;
   $236 = (412480 + ($235<<2)|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = (0 - ($239))|0;
   $240 = $239 & $238;
   $241 = Math_imul($240, 125613361)|0;
   $242 = $241 >>> 27;
   $243 = (412480 + ($242<<2)|0);
   $244 = HEAP32[$243>>2]|0;
   $245 = (($244) + 32)|0;
   $246 = $not$$i78 ? $237 : $245;
   $247 = (_i64Add(($231|0),($239|0),-1,-1)|0);
   $248 = tempRet0;
   $249 = $247 & $231;
   $250 = $248 & $239;
   $251 = (($45) + ($246<<5)|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = ((($45) + ($246<<5)|0) + 4|0);
   $254 = Math_fround(HEAPF32[$253>>2]);
   $255 = ((($45) + ($246<<5)|0) + 8|0);
   $256 = Math_fround(HEAPF32[$255>>2]);
   $257 = Math_fround($258 + $252);
   $259 = Math_fround($260 + $254);
   $261 = Math_fround($262 + $256);
   $263 = ((($45) + ($246<<5)|0) + 16|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = ((($45) + ($246<<5)|0) + 20|0);
   $266 = Math_fround(HEAPF32[$265>>2]);
   $267 = ((($45) + ($246<<5)|0) + 24|0);
   $268 = Math_fround(HEAPF32[$267>>2]);
   $269 = Math_fround($270 + $264);
   $271 = Math_fround($272 + $266);
   $273 = Math_fround($274 + $268);
   $275 = (($46) + ($246<<4)|0);
   $276 = Math_fround(HEAPF32[$275>>2]);
   $277 = ((($46) + ($246<<4)|0) + 4|0);
   $278 = Math_fround(HEAPF32[$277>>2]);
   $279 = ((($46) + ($246<<4)|0) + 8|0);
   $280 = Math_fround(HEAPF32[$279>>2]);
   $281 = ((($8) + (($246*160)|0)|0) + 96|0);
   $282 = Math_fround(HEAPF32[$281>>2]);
   $283 = Math_fround($276 * $282);
   $284 = ((($8) + (($246*160)|0)|0) + 112|0);
   $285 = Math_fround(HEAPF32[$284>>2]);
   $286 = Math_fround($278 * $285);
   $287 = Math_fround($283 + $286);
   $288 = ((($8) + (($246*160)|0)|0) + 128|0);
   $289 = Math_fround(HEAPF32[$288>>2]);
   $290 = Math_fround($280 * $289);
   $291 = Math_fround($287 + $290);
   $292 = ((($8) + (($246*160)|0)|0) + 100|0);
   $293 = Math_fround(HEAPF32[$292>>2]);
   $294 = Math_fround($276 * $293);
   $295 = ((($8) + (($246*160)|0)|0) + 116|0);
   $296 = Math_fround(HEAPF32[$295>>2]);
   $297 = Math_fround($278 * $296);
   $298 = Math_fround($294 + $297);
   $299 = ((($8) + (($246*160)|0)|0) + 132|0);
   $300 = Math_fround(HEAPF32[$299>>2]);
   $301 = Math_fround($280 * $300);
   $302 = Math_fround($298 + $301);
   $303 = ((($8) + (($246*160)|0)|0) + 104|0);
   $304 = Math_fround(HEAPF32[$303>>2]);
   $305 = Math_fround($276 * $304);
   $306 = ((($8) + (($246*160)|0)|0) + 120|0);
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = Math_fround($278 * $307);
   $309 = Math_fround($305 + $308);
   $310 = ((($8) + (($246*160)|0)|0) + 136|0);
   $311 = Math_fround(HEAPF32[$310>>2]);
   $312 = Math_fround($280 * $311);
   $313 = Math_fround($309 + $312);
   $314 = (($12) + ($246<<5)|0);
   $315 = Math_fround(HEAPF32[$314>>2]);
   $316 = ((($12) + ($246<<5)|0) + 4|0);
   $317 = Math_fround(HEAPF32[$316>>2]);
   $318 = ((($12) + ($246<<5)|0) + 8|0);
   $319 = Math_fround(HEAPF32[$318>>2]);
   $320 = Math_fround($271 * $319);
   $321 = Math_fround($273 * $317);
   $322 = Math_fround($320 - $321);
   $323 = Math_fround($273 * $315);
   $324 = Math_fround($269 * $319);
   $325 = Math_fround($323 - $324);
   $326 = Math_fround($269 * $317);
   $327 = Math_fround($271 * $315);
   $328 = Math_fround($326 - $327);
   $329 = Math_fround($257 + $322);
   $330 = Math_fround($259 + $325);
   $331 = Math_fround($261 + $328);
   $332 = (($8) + (($246*160)|0)|0);
   $333 = Math_fround(HEAPF32[$332>>2]);
   $334 = ((($8) + (($246*160)|0)|0) + 4|0);
   $335 = Math_fround(HEAPF32[$334>>2]);
   $336 = ((($8) + (($246*160)|0)|0) + 8|0);
   $337 = Math_fround(HEAPF32[$336>>2]);
   $338 = Math_fround($333 * $329);
   $339 = Math_fround($335 * $330);
   $340 = Math_fround($338 + $339);
   $341 = Math_fround($331 * $337);
   $342 = Math_fround($341 + $340);
   $343 = ((($8) + (($246*160)|0)|0) + 32|0);
   $344 = Math_fround(HEAPF32[$343>>2]);
   $345 = ((($8) + (($246*160)|0)|0) + 36|0);
   $346 = Math_fround(HEAPF32[$345>>2]);
   $347 = ((($8) + (($246*160)|0)|0) + 40|0);
   $348 = Math_fround(HEAPF32[$347>>2]);
   $349 = Math_fround($329 * $344);
   $350 = Math_fround($330 * $346);
   $351 = Math_fround($349 + $350);
   $352 = Math_fround($331 * $348);
   $353 = Math_fround($351 + $352);
   $354 = ((($8) + (($246*160)|0)|0) + 64|0);
   $355 = Math_fround(HEAPF32[$354>>2]);
   $356 = ((($8) + (($246*160)|0)|0) + 68|0);
   $357 = Math_fround(HEAPF32[$356>>2]);
   $358 = ((($8) + (($246*160)|0)|0) + 72|0);
   $359 = Math_fround(HEAPF32[$358>>2]);
   $360 = Math_fround($329 * $355);
   $361 = Math_fround($330 * $357);
   $362 = Math_fround($360 + $361);
   $363 = Math_fround($331 * $359);
   $364 = Math_fround($362 + $363);
   $365 = ((($8) + (($246*160)|0)|0) + 16|0);
   $366 = Math_fround(HEAPF32[$365>>2]);
   $367 = ((($8) + (($246*160)|0)|0) + 20|0);
   $368 = Math_fround(HEAPF32[$367>>2]);
   $369 = ((($8) + (($246*160)|0)|0) + 24|0);
   $370 = Math_fround(HEAPF32[$369>>2]);
   $371 = Math_fround($269 * $366);
   $372 = Math_fround($271 * $368);
   $373 = Math_fround($371 + $372);
   $374 = Math_fround($273 * $370);
   $375 = Math_fround($373 + $374);
   $376 = ((($8) + (($246*160)|0)|0) + 48|0);
   $377 = Math_fround(HEAPF32[$376>>2]);
   $378 = ((($8) + (($246*160)|0)|0) + 52|0);
   $379 = Math_fround(HEAPF32[$378>>2]);
   $380 = ((($8) + (($246*160)|0)|0) + 56|0);
   $381 = Math_fround(HEAPF32[$380>>2]);
   $382 = Math_fround($269 * $377);
   $383 = Math_fround($271 * $379);
   $384 = Math_fround($382 + $383);
   $385 = Math_fround($273 * $381);
   $386 = Math_fround($384 + $385);
   $387 = ((($8) + (($246*160)|0)|0) + 80|0);
   $388 = Math_fround(HEAPF32[$387>>2]);
   $389 = ((($8) + (($246*160)|0)|0) + 84|0);
   $390 = Math_fround(HEAPF32[$389>>2]);
   $391 = ((($8) + (($246*160)|0)|0) + 88|0);
   $392 = Math_fround(HEAPF32[$391>>2]);
   $393 = Math_fround($269 * $388);
   $394 = Math_fround($271 * $390);
   $395 = Math_fround($393 + $394);
   $396 = Math_fround($273 * $392);
   $397 = Math_fround($395 + $396);
   $398 = Math_fround($342 + $375);
   $399 = Math_fround($353 + $386);
   $400 = Math_fround($364 + $397);
   $401 = Math_fround($291 + $398);
   $402 = Math_fround($302 + $399);
   $403 = Math_fround($313 + $400);
   $404 = ((($12) + ($246<<5)|0) + 16|0);
   $405 = Math_fround(HEAPF32[$404>>2]);
   $406 = ((($12) + ($246<<5)|0) + 20|0);
   $407 = Math_fround(HEAPF32[$406>>2]);
   $408 = ((($12) + ($246<<5)|0) + 24|0);
   $409 = Math_fround(HEAPF32[$408>>2]);
   $410 = Math_fround($407 * $403);
   $411 = Math_fround($402 * $409);
   $412 = Math_fround($410 - $411);
   $413 = Math_fround($401 * $409);
   $414 = Math_fround($405 * $403);
   $415 = Math_fround($413 - $414);
   $416 = Math_fround($402 * $405);
   $417 = Math_fround($401 * $407);
   $418 = Math_fround($416 - $417);
   $419 = Math_fround($329 - $412);
   $420 = Math_fround($330 - $415);
   $421 = Math_fround($331 - $418);
   $422 = Math_fround($269 - $401);
   $423 = Math_fround($271 - $402);
   $424 = Math_fround($273 - $403);
   $425 = (($13) + ($246<<5)|0);
   $426 = Math_fround(HEAPF32[$425>>2]);
   $427 = ((($13) + ($246<<5)|0) + 4|0);
   $428 = Math_fround(HEAPF32[$427>>2]);
   $429 = ((($13) + ($246<<5)|0) + 8|0);
   $430 = Math_fround(HEAPF32[$429>>2]);
   $431 = ((($13) + ($246<<5)|0) + 12|0);
   $432 = Math_fround($426 + $419);
   $433 = Math_fround($428 + $420);
   $434 = Math_fround($421 + $430);
   HEAPF32[$425>>2] = $432;
   HEAPF32[$427>>2] = $433;
   HEAPF32[$429>>2] = $434;
   HEAPF32[$431>>2] = Math_fround(0.0);
   $435 = ((($13) + ($246<<5)|0) + 16|0);
   $436 = Math_fround(HEAPF32[$435>>2]);
   $437 = ((($13) + ($246<<5)|0) + 20|0);
   $438 = Math_fround(HEAPF32[$437>>2]);
   $439 = ((($13) + ($246<<5)|0) + 24|0);
   $440 = Math_fround(HEAPF32[$439>>2]);
   $441 = ((($13) + ($246<<5)|0) + 28|0);
   $442 = Math_fround($422 + $436);
   $443 = Math_fround($423 + $438);
   $444 = Math_fround($424 + $440);
   HEAPF32[$435>>2] = $442;
   HEAPF32[$437>>2] = $443;
   HEAPF32[$439>>2] = $444;
   HEAPF32[$441>>2] = Math_fround(0.0);
   ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
   ;HEAP32[$251+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$251+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$251+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$251+12>>2]=HEAP32[$2+12>>2]|0;
   ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
   ;HEAP32[$263+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$263+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$263+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$263+12>>2]=HEAP32[$3+12>>2]|0;
   ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
   ;HEAP32[$275+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$275+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$275+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$275+12>>2]=HEAP32[$4+12>>2]|0;
   $445 = (($indexToStackLoc) + ($246<<2)|0);
   HEAP32[$445>>2] = $count$0616;
   $446 = (($count$0616) + 1)|0;
   $447 = ((($8) + (($246*160)|0)|0) + 144|0);
   $448 = $447;
   $449 = $448;
   $450 = HEAP32[$449>>2]|0;
   $451 = (($448) + 4)|0;
   $452 = $451;
   $453 = HEAP32[$452>>2]|0;
   $454 = $450 | $455;
   $456 = $453 | $457;
   $458 = (($dVStack) + ($count$0616<<5)|0);
   HEAPF32[$458>>2] = $419;
   $459 = ((($dVStack) + ($count$0616<<5)|0) + 4|0);
   HEAPF32[$459>>2] = $420;
   $460 = ((($dVStack) + ($count$0616<<5)|0) + 8|0);
   HEAPF32[$460>>2] = $421;
   $461 = ((($dVStack) + ($count$0616<<5)|0) + 12|0);
   HEAPF32[$461>>2] = Math_fround(0.0);
   $462 = ((($dVStack) + ($count$0616<<5)|0) + 16|0);
   HEAPF32[$462>>2] = $422;
   $463 = ((($dVStack) + ($count$0616<<5)|0) + 20|0);
   HEAPF32[$463>>2] = $423;
   $464 = ((($dVStack) + ($count$0616<<5)|0) + 24|0);
   HEAPF32[$464>>2] = $424;
   $465 = ((($dVStack) + ($count$0616<<5)|0) + 28|0);
   HEAPF32[$465>>2] = Math_fround(0.0);
   $466 = ($249|0)==(0);
   $467 = ($250|0)==(0);
   $468 = $466 & $467;
   if ($468) {
    $472 = $454;$474 = $456;
    break;
   } else {
    $231 = $249;$239 = $250;$258 = $419;$260 = $420;$262 = $421;$270 = $422;$272 = $423;$274 = $424;$455 = $454;$457 = $456;$count$0616 = $446;
   }
  }
 }
 $469 = $39 ^ -1;
 $470 = $40 ^ -1;
 $471 = $472 & $469;
 $473 = $474 & $470;
 $475 = ($471|0)==(0);
 $476 = ($473|0)==(0);
 $477 = $475 & $476;
 if (!($477)) {
  $478 = $471;$486 = $473;
  while(1) {
   $not$$i = ($478|0)!=(0);
   $479 = (0 - ($478))|0;
   $480 = $478 & $479;
   $481 = Math_imul($480, 125613361)|0;
   $482 = $481 >>> 27;
   $483 = (412480 + ($482<<2)|0);
   $484 = HEAP32[$483>>2]|0;
   $485 = (0 - ($486))|0;
   $487 = $486 & $485;
   $488 = Math_imul($487, 125613361)|0;
   $489 = $488 >>> 27;
   $490 = (412480 + ($489<<2)|0);
   $491 = HEAP32[$490>>2]|0;
   $492 = (($491) + 32)|0;
   $493 = $not$$i ? $484 : $492;
   $494 = ((($matrix) + ($493)|0) + 64|0);
   $495 = HEAP8[$494>>0]|0;
   $496 = $495&255;
   $497 = (($indexToStackLoc) + ($496<<2)|0);
   $498 = HEAP32[$497>>2]|0;
   $499 = (($45) + ($493<<5)|0);
   $500 = Math_fround(HEAPF32[$499>>2]);
   $501 = ((($45) + ($493<<5)|0) + 4|0);
   $502 = Math_fround(HEAPF32[$501>>2]);
   $503 = ((($45) + ($493<<5)|0) + 8|0);
   $504 = Math_fround(HEAPF32[$503>>2]);
   $505 = ((($45) + ($493<<5)|0) + 12|0);
   $506 = (($dVStack) + ($498<<5)|0);
   $507 = Math_fround(HEAPF32[$506>>2]);
   $508 = ((($dVStack) + ($498<<5)|0) + 4|0);
   $509 = Math_fround(HEAPF32[$508>>2]);
   $510 = ((($dVStack) + ($498<<5)|0) + 8|0);
   $511 = Math_fround(HEAPF32[$510>>2]);
   $512 = Math_fround($500 + $507);
   $513 = Math_fround($502 + $509);
   $514 = Math_fround($504 + $511);
   HEAPF32[$499>>2] = $512;
   HEAPF32[$501>>2] = $513;
   HEAPF32[$503>>2] = $514;
   HEAPF32[$505>>2] = Math_fround(0.0);
   $515 = ((($45) + ($493<<5)|0) + 16|0);
   $516 = Math_fround(HEAPF32[$515>>2]);
   $517 = ((($45) + ($493<<5)|0) + 20|0);
   $518 = Math_fround(HEAPF32[$517>>2]);
   $519 = ((($45) + ($493<<5)|0) + 24|0);
   $520 = Math_fround(HEAPF32[$519>>2]);
   $521 = ((($45) + ($493<<5)|0) + 28|0);
   $522 = ((($dVStack) + ($498<<5)|0) + 16|0);
   $523 = Math_fround(HEAPF32[$522>>2]);
   $524 = ((($dVStack) + ($498<<5)|0) + 20|0);
   $525 = Math_fround(HEAPF32[$524>>2]);
   $526 = ((($dVStack) + ($498<<5)|0) + 24|0);
   $527 = Math_fround(HEAPF32[$526>>2]);
   $528 = Math_fround($516 + $523);
   $529 = Math_fround($518 + $525);
   $530 = Math_fround($520 + $527);
   HEAPF32[$515>>2] = $528;
   HEAPF32[$517>>2] = $529;
   HEAPF32[$519>>2] = $530;
   HEAPF32[$521>>2] = Math_fround(0.0);
   $531 = (_i64Add(($478|0),($486|0),-1,-1)|0);
   $532 = tempRet0;
   $533 = $531 & $478;
   $534 = $532 & $486;
   $535 = ($533|0)==(0);
   $536 = ($534|0)==(0);
   $537 = $535 & $536;
   if ($537) {
    break;
   } else {
    $478 = $533;$486 = $534;
   }
  }
 }
 $538 = $21;
 $539 = $538;
 $540 = HEAP32[$539>>2]|0;
 $541 = (($538) + 4)|0;
 $542 = $541;
 $543 = HEAP32[$542>>2]|0;
 $544 = $540 | $472;
 $545 = $543 | $474;
 $546 = $544 & $469;
 $547 = $545 & $470;
 $548 = $21;
 $549 = $548;
 HEAP32[$549>>2] = $546;
 $550 = (($548) + 4)|0;
 $551 = $550;
 HEAP32[$551>>2] = $547;
 $552 = (($13) + ($linkID<<5)|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$552+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$552+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$552+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$552+12>>2]|0;
 $553 = (($agg$result) + 16|0);
 $554 = ((($13) + ($linkID<<5)|0) + 16|0);
 ;HEAP32[$553+0>>2]=HEAP32[$554+0>>2]|0;HEAP32[$553+4>>2]=HEAP32[$554+4>>2]|0;HEAP32[$553+8>>2]=HEAP32[$554+8>>2]|0;HEAP32[$553+12>>2]=HEAP32[$554+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx18PxcFsFlushVelocityERNS_9PxcFsDataE($matrix) {
 $matrix = $matrix|0;
 var $$sum = 0, $$sum$i = 0, $$sum$i1 = 0, $$sum$i2 = 0, $$sum$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0;
 var $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0;
 var $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $V = 0, $V0 = 0, $i$06 = 0, $not$$i = 0, $not$$i4 = 0, $tmp1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $V0 = sp + 144|0;
 $0 = sp;
 $1 = sp + 32|0;
 $V = sp + 64|0;
 $2 = sp + 96|0;
 $3 = sp + 128|0;
 $4 = (($matrix) + 26|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $$sum$i = (($6) + 144)|0;
 $7 = (($matrix) + ($$sum$i)|0);
 $8 = (($matrix) + 24|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9&65535;
 $11 = (($matrix) + 8|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = $12&65535;
 $tmp1$i = ($13*432)|0;
 $$sum$i2 = (($tmp1$i) + ($10))|0;
 $14 = (($matrix) + ($$sum$i2)|0);
 $15 = (($matrix) + 10|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = (($matrix) + ($17)|0);
 $19 = (($matrix) + ($6)|0);
 $20 = (($matrix) + 32|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($matrix) + 36|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($matrix) + 40|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround(-$21);
 $27 = Math_fround(-$23);
 $28 = Math_fround(-$25);
 $29 = (($matrix) + 48|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($matrix) + 52|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($matrix) + 56|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround(-$30);
 $36 = Math_fround(-$32);
 $37 = Math_fround(-$34);
 HEAPF32[$0>>2] = $26;
 $38 = (($0) + 4|0);
 HEAPF32[$38>>2] = $27;
 $39 = (($0) + 8|0);
 HEAPF32[$39>>2] = $28;
 $40 = (($0) + 12|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($0) + 16|0);
 HEAPF32[$41>>2] = $35;
 $42 = (($0) + 20|0);
 HEAPF32[$42>>2] = $36;
 $43 = (($0) + 24|0);
 HEAPF32[$43>>2] = $37;
 $44 = (($0) + 28|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 __ZN5physx26PxcArticulationFnsSimdBase8multiplyERKNS_12PxcFsInertiaERKNS_14PxcSIMDSpatialE($V0,$19,$0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;HEAP32[$1+28>>2]=0|0;
 ;HEAP32[$20+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$1+12>>2]|0;
 $45 = (($matrix) + 48|0);
 $46 = (($1) + 16|0);
 ;HEAP32[$45+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$46+12>>2]|0;
 $47 = (($matrix) + 128|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($matrix) + 132|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($matrix) + 136|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($matrix) + 140|0);
 $54 = Math_fround(HEAPF32[$V0>>2]);
 $55 = (($V0) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($V0) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($48 + $54);
 $60 = Math_fround($50 + $56);
 $61 = Math_fround($52 + $58);
 HEAPF32[$47>>2] = $59;
 HEAPF32[$49>>2] = $60;
 HEAPF32[$51>>2] = $61;
 HEAPF32[$53>>2] = Math_fround(0.0);
 $62 = (($matrix) + 144|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($47) + 20|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($matrix) + 152|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($matrix) + 156|0);
 $69 = (($V0) + 16|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($V0) + 20|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($V0) + 24|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($63 + $70);
 $76 = Math_fround($65 + $72);
 $77 = Math_fround($67 + $74);
 HEAPF32[$62>>2] = $75;
 HEAPF32[$64>>2] = $76;
 HEAPF32[$66>>2] = $77;
 HEAPF32[$68>>2] = Math_fround(0.0);
 $$sum = (($6) + 288)|0;
 $78 = (($matrix) + ($$sum)|0);
 $79 = $78;
 $80 = $79;
 $81 = HEAP32[$80>>2]|0;
 $82 = (($79) + 4)|0;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = ($81|0)==(0);
 $86 = ($84|0)==(0);
 $87 = $85 & $86;
 if (!($87)) {
  $105 = $84;$97 = $81;
  while(1) {
   $not$$i4 = ($97|0)!=(0);
   $98 = (0 - ($97))|0;
   $99 = $97 & $98;
   $100 = Math_imul($99, 125613361)|0;
   $101 = $100 >>> 27;
   $102 = (412480 + ($101<<2)|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (0 - ($105))|0;
   $106 = $105 & $104;
   $107 = Math_imul($106, 125613361)|0;
   $108 = $107 >>> 27;
   $109 = (412480 + ($108<<2)|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = (($110) + 32)|0;
   $112 = $not$$i4 ? $103 : $111;
   $113 = HEAP16[$11>>1]|0;
   $114 = $113&65535;
   $115 = $114 << 5;
   $116 = (($47) + ($115)|0);
   $117 = (($116) + ($112<<5)|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = ((($116) + ($112<<5)|0) + 4|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = ((($116) + ($112<<5)|0) + 8|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = ((($116) + ($112<<5)|0) + 12|0);
   $124 = Math_fround($118 + $54);
   $125 = Math_fround($120 + $56);
   $126 = Math_fround($122 + $58);
   HEAPF32[$117>>2] = $124;
   HEAPF32[$119>>2] = $125;
   HEAPF32[$121>>2] = $126;
   HEAPF32[$123>>2] = Math_fround(0.0);
   $127 = ((($116) + ($112<<5)|0) + 16|0);
   $128 = Math_fround(HEAPF32[$127>>2]);
   $129 = ((($116) + ($112<<5)|0) + 20|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = ((($116) + ($112<<5)|0) + 24|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = ((($116) + ($112<<5)|0) + 28|0);
   $134 = Math_fround($128 + $70);
   $135 = Math_fround($130 + $72);
   $136 = Math_fround($132 + $74);
   HEAPF32[$127>>2] = $134;
   HEAPF32[$129>>2] = $135;
   HEAPF32[$131>>2] = $136;
   HEAPF32[$133>>2] = Math_fround(0.0);
   $137 = (_i64Add(($97|0),($105|0),-1,-1)|0);
   $138 = tempRet0;
   $139 = $137 & $97;
   $140 = $138 & $105;
   $141 = ($139|0)==(0);
   $142 = ($140|0)==(0);
   $143 = $141 & $142;
   if ($143) {
    break;
   } else {
    $105 = $140;$97 = $139;
   }
  }
 }
 $88 = HEAP16[$11>>1]|0;
 $89 = ($88&65535)>(1);
 if (!($89)) {
  $250 = (($matrix) + 16|0);
  $251 = $250;
  $252 = $251;
  HEAP32[$252>>2] = 0;
  $253 = (($251) + 4)|0;
  $254 = $253;
  HEAP32[$254>>2] = 0;
  STACKTOP = sp;return;
 }
 $90 = $88&65535;
 $91 = (($2) + 16|0);
 $92 = (($V) + 4|0);
 $93 = (($V) + 8|0);
 $94 = (($V) + 16|0);
 $95 = (($V) + 20|0);
 $96 = (($V) + 24|0);
 $146 = $90;$i$06 = 1;
 while(1) {
  $144 = (($7) + (($i$06*160)|0)|0);
  $145 = (($18) + ($i$06<<5)|0);
  $$sum$i3 = $146 << 6;
  $147 = (($47) + ($$sum$i3)|0);
  $148 = (($147) + ($i$06<<4)|0);
  $149 = $146 << 5;
  $150 = (($47) + ($149)|0);
  $151 = (($150) + ($i$06<<5)|0);
  $152 = (($14) + (($i$06*96)|0)|0);
  __ZN5physx21propagateVelocitySIMDERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERKNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($V,$144,$145,$148,$151,$152);
  $153 = HEAP16[$11>>1]|0;
  $154 = $153&65535;
  $155 = $154 << 5;
  $156 = (($47) + ($155)|0);
  $157 = (($156) + ($i$06<<5)|0);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
  ;HEAP32[$157+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$157+12>>2]=HEAP32[$2+12>>2]|0;
  $158 = ((($156) + ($i$06<<5)|0) + 16|0);
  ;HEAP32[$158+0>>2]=HEAP32[$91+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$91+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$91+8>>2]|0;HEAP32[$158+12>>2]=HEAP32[$91+12>>2]|0;
  $159 = HEAP16[$11>>1]|0;
  $160 = $159&65535;
  $$sum$i1 = $160 << 6;
  $161 = (($47) + ($$sum$i1)|0);
  $162 = (($161) + ($i$06<<4)|0);
  ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
  ;HEAP32[$162+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$3+12>>2]|0;
  $163 = (($47) + ($i$06<<5)|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = ((($47) + ($i$06<<5)|0) + 4|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = ((($47) + ($i$06<<5)|0) + 8|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = ((($47) + ($i$06<<5)|0) + 12|0);
  $170 = Math_fround(HEAPF32[$V>>2]);
  $171 = Math_fround(HEAPF32[$92>>2]);
  $172 = Math_fround(HEAPF32[$93>>2]);
  $173 = Math_fround($164 + $170);
  $174 = Math_fround($166 + $171);
  $175 = Math_fround($168 + $172);
  HEAPF32[$163>>2] = $173;
  HEAPF32[$165>>2] = $174;
  HEAPF32[$167>>2] = $175;
  HEAPF32[$169>>2] = Math_fround(0.0);
  $176 = ((($47) + ($i$06<<5)|0) + 16|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = ((($47) + ($i$06<<5)|0) + 20|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = ((($47) + ($i$06<<5)|0) + 24|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = ((($47) + ($i$06<<5)|0) + 28|0);
  $183 = Math_fround(HEAPF32[$94>>2]);
  $184 = Math_fround(HEAPF32[$95>>2]);
  $185 = Math_fround(HEAPF32[$96>>2]);
  $186 = Math_fround($177 + $183);
  $187 = Math_fround($179 + $184);
  $188 = Math_fround($181 + $185);
  HEAPF32[$176>>2] = $186;
  HEAPF32[$178>>2] = $187;
  HEAPF32[$180>>2] = $188;
  HEAPF32[$182>>2] = Math_fround(0.0);
  $189 = ((($7) + (($i$06*160)|0)|0) + 144|0);
  $190 = $189;
  $191 = $190;
  $192 = HEAP32[$191>>2]|0;
  $193 = (($190) + 4)|0;
  $194 = $193;
  $195 = HEAP32[$194>>2]|0;
  $196 = ($192|0)==(0);
  $197 = ($195|0)==(0);
  $198 = $196 & $197;
  if (!($198)) {
   $199 = $192;$207 = $195;
   while(1) {
    $not$$i = ($199|0)!=(0);
    $200 = (0 - ($199))|0;
    $201 = $199 & $200;
    $202 = Math_imul($201, 125613361)|0;
    $203 = $202 >>> 27;
    $204 = (412480 + ($203<<2)|0);
    $205 = HEAP32[$204>>2]|0;
    $206 = (0 - ($207))|0;
    $208 = $207 & $206;
    $209 = Math_imul($208, 125613361)|0;
    $210 = $209 >>> 27;
    $211 = (412480 + ($210<<2)|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = (($212) + 32)|0;
    $214 = $not$$i ? $205 : $213;
    $215 = HEAP16[$11>>1]|0;
    $216 = $215&65535;
    $217 = $216 << 5;
    $218 = (($47) + ($217)|0);
    $219 = (($218) + ($214<<5)|0);
    $220 = Math_fround(HEAPF32[$219>>2]);
    $221 = ((($218) + ($214<<5)|0) + 4|0);
    $222 = Math_fround(HEAPF32[$221>>2]);
    $223 = ((($218) + ($214<<5)|0) + 8|0);
    $224 = Math_fround(HEAPF32[$223>>2]);
    $225 = ((($218) + ($214<<5)|0) + 12|0);
    $226 = Math_fround($220 + $170);
    $227 = Math_fround($222 + $171);
    $228 = Math_fround($224 + $172);
    HEAPF32[$219>>2] = $226;
    HEAPF32[$221>>2] = $227;
    HEAPF32[$223>>2] = $228;
    HEAPF32[$225>>2] = Math_fround(0.0);
    $229 = ((($218) + ($214<<5)|0) + 16|0);
    $230 = Math_fround(HEAPF32[$229>>2]);
    $231 = ((($218) + ($214<<5)|0) + 20|0);
    $232 = Math_fround(HEAPF32[$231>>2]);
    $233 = ((($218) + ($214<<5)|0) + 24|0);
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = ((($218) + ($214<<5)|0) + 28|0);
    $236 = Math_fround($230 + $183);
    $237 = Math_fround($232 + $184);
    $238 = Math_fround($234 + $185);
    HEAPF32[$229>>2] = $236;
    HEAPF32[$231>>2] = $237;
    HEAPF32[$233>>2] = $238;
    HEAPF32[$235>>2] = Math_fround(0.0);
    $239 = (_i64Add(($199|0),($207|0),-1,-1)|0);
    $240 = tempRet0;
    $241 = $239 & $199;
    $242 = $240 & $207;
    $243 = ($241|0)==(0);
    $244 = ($242|0)==(0);
    $245 = $243 & $244;
    if ($245) {
     break;
    } else {
     $199 = $241;$207 = $242;
    }
   }
  }
  $246 = (($i$06) + 1)|0;
  $247 = HEAP16[$11>>1]|0;
  $248 = $247&65535;
  $249 = ($246>>>0)<($248>>>0);
  if ($249) {
   $146 = $248;$i$06 = $246;
  } else {
   break;
  }
 }
 $250 = (($matrix) + 16|0);
 $251 = $250;
 $252 = $251;
 HEAP32[$252>>2] = 0;
 $253 = (($251) + 4)|0;
 $254 = $253;
 HEAP32[$254>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx21propagateVelocitySIMDERKNS_8PxcFsRowERKNS_17PxcFsJointVectorsERKNS_6shdfnd3aos5Vec3VERKNS_14PxcSIMDSpatialERKNS_11PxcFsRowAuxE($agg$result,$row,$jv,$SZ,$v,$aux) {
 $agg$result = $agg$result|0;
 $row = $row|0;
 $jv = $jv|0;
 $SZ = $SZ|0;
 $v = $v|0;
 $aux = $aux|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0);
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0;
 var $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$v>>2]);
 $1 = (($v) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($v) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($v) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($v) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($v) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$jv>>2]);
 $12 = (($jv) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($jv) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($8 * $15);
 $17 = Math_fround($10 * $13);
 $18 = Math_fround($16 - $17);
 $19 = Math_fround($10 * $11);
 $20 = Math_fround($6 * $15);
 $21 = Math_fround($19 - $20);
 $22 = Math_fround($6 * $13);
 $23 = Math_fround($8 * $11);
 $24 = Math_fround($22 - $23);
 $25 = Math_fround($0 + $18);
 $26 = Math_fround($2 + $21);
 $27 = Math_fround($4 + $24);
 $28 = Math_fround(HEAPF32[$SZ>>2]);
 $29 = (($SZ) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($SZ) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($row) + 96|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($28 * $34);
 $36 = (($row) + 112|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($30 * $37);
 $39 = Math_fround($35 + $38);
 $40 = (($row) + 128|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($32 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (($row) + 100|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($28 * $45);
 $47 = (($row) + 116|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($30 * $48);
 $50 = Math_fround($46 + $49);
 $51 = (($row) + 132|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($32 * $52);
 $54 = Math_fround($50 + $53);
 $55 = (($row) + 104|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($28 * $56);
 $58 = (($row) + 120|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($30 * $59);
 $61 = Math_fround($57 + $60);
 $62 = (($row) + 136|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($32 * $63);
 $65 = Math_fround($61 + $64);
 $66 = Math_fround(HEAPF32[$row>>2]);
 $67 = (($row) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($row) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($25 * $66);
 $72 = Math_fround($26 * $68);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($27 * $70);
 $75 = Math_fround($73 + $74);
 $76 = (($row) + 16|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($row) + 20|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($row) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($6 * $77);
 $83 = Math_fround($8 * $79);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($10 * $81);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($75 + $86);
 $88 = (($row) + 32|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($row) + 36|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($row) + 40|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($25 * $89);
 $95 = Math_fround($26 * $91);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($27 * $93);
 $98 = Math_fround($96 + $97);
 $99 = (($row) + 48|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($row) + 52|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($row) + 56|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($6 * $100);
 $106 = Math_fround($8 * $102);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($10 * $104);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($98 + $109);
 $111 = (($row) + 64|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($row) + 68|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($row) + 72|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($25 * $112);
 $118 = Math_fround($26 * $114);
 $119 = Math_fround($117 + $118);
 $120 = Math_fround($27 * $116);
 $121 = Math_fround($119 + $120);
 $122 = (($row) + 80|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($row) + 84|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($row) + 88|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = Math_fround($6 * $123);
 $129 = Math_fround($8 * $125);
 $130 = Math_fround($128 + $129);
 $131 = Math_fround($10 * $127);
 $132 = Math_fround($130 + $131);
 $133 = Math_fround($121 + $132);
 $134 = Math_fround($43 + $87);
 $135 = Math_fround($54 + $110);
 $136 = Math_fround($65 + $133);
 $137 = (($jv) + 16|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($jv) + 20|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($jv) + 24|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround($140 * $136);
 $144 = Math_fround($135 * $142);
 $145 = Math_fround($143 - $144);
 $146 = Math_fround($134 * $142);
 $147 = Math_fround($138 * $136);
 $148 = Math_fround($146 - $147);
 $149 = Math_fround($135 * $138);
 $150 = Math_fround($134 * $140);
 $151 = Math_fround($149 - $150);
 $152 = Math_fround($25 - $145);
 $153 = Math_fround($26 - $148);
 $154 = Math_fround($27 - $151);
 $155 = Math_fround($6 - $134);
 $156 = Math_fround($8 - $135);
 $157 = Math_fround($10 - $136);
 HEAPF32[$agg$result>>2] = $152;
 $158 = (($agg$result) + 4|0);
 HEAPF32[$158>>2] = $153;
 $159 = (($agg$result) + 8|0);
 HEAPF32[$159>>2] = $154;
 $160 = (($agg$result) + 12|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 $161 = (($agg$result) + 16|0);
 HEAPF32[$161>>2] = $155;
 $162 = (($agg$result) + 20|0);
 HEAPF32[$162>>2] = $156;
 $163 = (($agg$result) + 24|0);
 HEAPF32[$163>>2] = $157;
 $164 = (($agg$result) + 28|0);
 HEAPF32[$164>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __Z25PxcClearContactCacheStatsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z27PxcDisplayContactCacheStatsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx21PxcCacheLocalContactsENS_14PxGeometryType4EnumES1_RNS_18PxcNpThreadContextERNS_10PxcNpCacheERKNS_11PxTransformES8_fPFbRKNS_2Gu13GeometryUnionESC_S8_S8_RKfS5_RNS9_13ContactBufferEESC_SC_($type0,$type1,$context,$pairContactCache,$tm0,$tm1,$contactDistance,$conMethod,$shape0,$shape1) {
 $type0 = $type0|0;
 $type1 = $type1|0;
 $context = $context|0;
 $pairContactCache = $pairContactCache|0;
 $tm0 = $tm0|0;
 $tm1 = $tm1|0;
 $contactDistance = Math_fround($contactDistance);
 $conMethod = $conMethod|0;
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 var $$$i = 0, $$$i13 = 0, $$idx$val = Math_fround(0), $$idx6 = 0, $$idx6$val = Math_fround(0), $$idx7 = 0, $$idx7$val = Math_fround(0), $$not$i = 0, $$not$i11 = 0, $$pre$phi38Z2D = 0, $$pre$phi40Z2D = 0, $$pre$phi42Z2D = 0, $$pre$phi44Z2D = 0, $$pre$phi46Z2D = 0, $$pre$phi48Z2D = 0, $$pre$phi50Z2D = 0, $$pre$phi52Z2D = 0, $$pre$phi54Z2D = 0, $$pre$phi56Z2D = 0, $$pre$phi58Z2D = 0;
 var $$pre$phi60Z2D = 0, $$pre$phi62Z2D = 0, $$pre$phiZ2D = 0, $$pre37 = 0, $$pre39 = 0, $$pre41 = 0, $$pre43 = 0, $$pre45 = 0, $$pre47 = 0, $$pre51 = 0, $$pre53 = 0, $$pre55 = 0, $$pre57 = 0, $$pre59 = 0, $$pre61 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0);
 var $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0;
 var $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0);
 var $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0);
 var $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0);
 var $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0);
 var $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0);
 var $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0);
 var $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0);
 var $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0);
 var $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0;
 var $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0);
 var $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0);
 var $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0);
 var $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0);
 var $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0);
 var $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0);
 var $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0);
 var $445 = Math_fround(0), $446 = 0, $447 = 0, $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0);
 var $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = 0;
 var $517 = Math_fround(0), $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = 0, $528 = Math_fround(0), $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = Math_fround(0), $566 = 0, $567 = 0, $568 = Math_fround(0), $569 = 0, $57 = Math_fround(0), $570 = 0;
 var $571 = 0, $572 = Math_fround(0), $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = Math_fround(0), $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = Math_fround(0), $592 = 0, $593 = Math_fround(0), $594 = 0, $595 = 0, $596 = Math_fround(0), $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = 0, $602 = Math_fround(0), $603 = 0, $604 = 0, $605 = Math_fround(0), $606 = 0;
 var $607 = 0, $608 = 0, $609 = Math_fround(0), $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = Math_fround(0), $615 = Math_fround(0), $616 = 0, $617 = Math_fround(0), $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = Math_fround(0), $622 = 0, $623 = Math_fround(0), $624 = 0;
 var $625 = 0, $626 = Math_fround(0), $627 = 0, $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = Math_fround(0), $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = Math_fround(0), $642 = Math_fround(0);
 var $643 = 0, $644 = Math_fround(0), $645 = 0, $646 = 0, $647 = 0, $648 = Math_fround(0), $649 = 0, $65 = Math_fround(0), $650 = Math_fround(0), $651 = 0, $652 = 0, $653 = Math_fround(0), $654 = 0, $655 = 0, $656 = 0, $657 = Math_fround(0), $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = Math_fround(0), $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge = 0, $cachedNormal$0 = 0, $contacts$029 = 0, $contacts$1 = 0, $contacts$2 = 0, $dest$019 = 0, $dest$019$us = 0;
 var $dest$019$us$us = 0, $dest$019$us22 = 0, $dest$1 = 0, $dest$1$us23 = 0, $dst$030 = 0, $exitcond = 0, $exitcond33 = 0, $exitcond34 = 0, $exitcond35 = 0, $exitcond36 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i14 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i15 = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i2$i16 = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $i$027 = 0, $i3$025 = 0, $i8$020 = 0;
 var $i8$020$us = 0, $i8$020$us$us = 0, $i8$020$us21 = 0, $magicptr2$i = 0, $magicptr2$i8 = 0, $nbBytes$0 = 0, $normal0$028 = 0, $or$cond3$i = 0, $or$cond3$i12 = 0, $sameNormal1$0$off017 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAPF32[$0>>2] = $contactDistance;
 $1 = (($pairContactCache) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($pairContactCache) + 12|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = $5&65535;
  $7 = $2;
  $8 = $7 & 127;
  $9 = (($6) + ($8))|0;
  $10 = ($9>>>0)>(128);
  if ($10) {
   $11 = (($2) + 128|0);
  }
 }
 $12 = (($context) + 384|0);
 $13 = (($context) + 4480|0);
 HEAP32[$13>>2] = 0;
 $14 = HEAP32[$1>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  HEAP32[$1>>2] = 0;
  $16 = (($pairContactCache) + 12|0);
  HEAP16[$16>>1] = 0;
  $$pre37 = (($tm0) + 4|0);
  $$pre39 = (($tm0) + 8|0);
  $$pre41 = (($tm0) + 12|0);
  $$pre43 = (($tm0) + 16|0);
  $$pre45 = (($tm0) + 20|0);
  $$pre47 = (($tm0) + 24|0);
  $$pre51 = (($tm1) + 4|0);
  $$pre53 = (($tm1) + 8|0);
  $$pre55 = (($tm1) + 12|0);
  $$pre57 = (($tm1) + 16|0);
  $$pre59 = (($tm1) + 20|0);
  $$pre61 = (($tm1) + 24|0);
  $$pre$phi38Z2D = $$pre37;$$pre$phi40Z2D = $$pre39;$$pre$phi42Z2D = $$pre41;$$pre$phi44Z2D = $$pre43;$$pre$phi46Z2D = $$pre45;$$pre$phi48Z2D = $$pre47;$$pre$phi50Z2D = $tm1;$$pre$phi52Z2D = $$pre51;$$pre$phi54Z2D = $$pre53;$$pre$phi56Z2D = $$pre55;$$pre$phi58Z2D = $$pre57;$$pre$phi60Z2D = $$pre59;$$pre$phi62Z2D = $$pre61;$$pre$phiZ2D = $tm0;$539 = $16;$696 = 0;
 } else {
  $17 = Math_fround(HEAPF32[$14>>2]);
  $18 = (($14) + 4|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($14) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($14) + 12|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($14) + 16|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($14) + 20|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($14) + 24|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($14) + 28|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($14) + 32|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($14) + 36|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = (($14) + 40|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($14) + 44|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($14) + 48|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($14) + 52|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = (($14) + 56|0);
  $45 = HEAP16[$44>>1]|0;
  $46 = (($14) + 58|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = (($14) + 59|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = (($14) + 60|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($14) + 64|0);
  HEAP32[$1>>2] = 0;
  $53 = (($pairContactCache) + 12|0);
  HEAP16[$53>>1] = 0;
  $54 = Math_fround(HEAPF32[$tm1>>2]);
  $55 = Math_fround(-$54);
  $56 = (($tm1) + 4|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround(-$57);
  $59 = (($tm1) + 8|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround(-$60);
  $62 = (($tm1) + 12|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($tm0) + 16|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = (($tm1) + 16|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($65 - $67);
  $69 = (($tm0) + 20|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = (($tm1) + 20|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($70 - $72);
  $74 = (($tm0) + 24|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = (($tm1) + 24|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = Math_fround($75 - $77);
  $79 = Math_fround($68 * Math_fround(2.0));
  $80 = Math_fround($73 * Math_fround(2.0));
  $81 = Math_fround($78 * Math_fround(2.0));
  $82 = Math_fround($63 * $63);
  $83 = Math_fround($82 + Math_fround(-0.5));
  $84 = Math_fround($79 * $55);
  $85 = Math_fround($80 * $58);
  $86 = Math_fround($84 + $85);
  $87 = Math_fround($81 * $61);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround($83 * $79);
  $90 = Math_fround($81 * $58);
  $91 = Math_fround($80 * $61);
  $92 = Math_fround($90 - $91);
  $93 = Math_fround($63 * $92);
  $94 = Math_fround($89 + $93);
  $95 = Math_fround($88 * $55);
  $96 = Math_fround($95 + $94);
  $97 = Math_fround($83 * $80);
  $98 = Math_fround($79 * $61);
  $99 = Math_fround($81 * $55);
  $100 = Math_fround($98 - $99);
  $101 = Math_fround($63 * $100);
  $102 = Math_fround($97 + $101);
  $103 = Math_fround($88 * $58);
  $104 = Math_fround($103 + $102);
  $105 = Math_fround($83 * $81);
  $106 = Math_fround($80 * $55);
  $107 = Math_fround($79 * $58);
  $108 = Math_fround($106 - $107);
  $109 = Math_fround($63 * $108);
  $110 = Math_fround($105 + $109);
  $111 = Math_fround($88 * $61);
  $112 = Math_fround($110 + $111);
  $113 = Math_fround(HEAPF32[$tm0>>2]);
  $114 = (($tm0) + 12|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($tm0) + 8|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = (($tm0) + 4|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround(-$31);
  $121 = Math_fround(-$33);
  $122 = Math_fround(-$35);
  $123 = Math_fround($25 - $39);
  $124 = Math_fround($27 - $41);
  $125 = Math_fround($29 - $43);
  $126 = Math_fround($123 * Math_fround(2.0));
  $127 = Math_fround($124 * Math_fround(2.0));
  $128 = Math_fround($125 * Math_fround(2.0));
  $129 = Math_fround($37 * $37);
  $130 = Math_fround($129 + Math_fround(-0.5));
  $131 = Math_fround($126 * $120);
  $132 = Math_fround($127 * $121);
  $133 = Math_fround($131 + $132);
  $134 = Math_fround($128 * $122);
  $135 = Math_fround($133 + $134);
  $136 = Math_fround($130 * $126);
  $137 = Math_fround($128 * $121);
  $138 = Math_fround($127 * $122);
  $139 = Math_fround($137 - $138);
  $140 = Math_fround($37 * $139);
  $141 = Math_fround($136 + $140);
  $142 = Math_fround($135 * $120);
  $143 = Math_fround($142 + $141);
  $144 = Math_fround($130 * $127);
  $145 = Math_fround($126 * $122);
  $146 = Math_fround($128 * $120);
  $147 = Math_fround($145 - $146);
  $148 = Math_fround($37 * $147);
  $149 = Math_fround($144 + $148);
  $150 = Math_fround($135 * $121);
  $151 = Math_fround($150 + $149);
  $152 = Math_fround($130 * $128);
  $153 = Math_fround($127 * $120);
  $154 = Math_fround($126 * $121);
  $155 = Math_fround($153 - $154);
  $156 = Math_fround($37 * $155);
  $157 = Math_fround($152 + $156);
  $158 = Math_fround($135 * $122);
  $159 = Math_fround($157 + $158);
  $160 = Math_fround($96 - $143);
  $fabsf$i$i$i14 = (Math_fround(Math_abs((Math_fround($160)))));
  $161 = Math_fround($104 - $151);
  $fabsf$i$i1$i15 = (Math_fround(Math_abs((Math_fround($161)))));
  $162 = $fabsf$i$i$i14 > $fabsf$i$i1$i15;
  $163 = $162 ? $fabsf$i$i$i14 : $fabsf$i$i1$i15;
  $164 = Math_fround($112 - $159);
  $fabsf$i$i2$i16 = (Math_fround(Math_abs((Math_fround($164)))));
  $165 = $163 > $fabsf$i$i2$i16;
  $166 = $165 ? $163 : $fabsf$i$i2$i16;
  $167 = (($context) + 8780|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = Math_fround($168 * Math_fround(0.00999999977648258209228));
  $170 = $166 < $169;
  if ($170) {
   $171 = Math_fround($17 * $120);
   $172 = Math_fround($23 * $37);
   $173 = Math_fround($23 * $122);
   $174 = Math_fround($21 * $37);
   $175 = Math_fround($23 * $121);
   $176 = Math_fround($19 * $37);
   $177 = Math_fround($23 * $120);
   $178 = Math_fround($17 * $37);
   $179 = Math_fround($113 * $55);
   $180 = Math_fround($63 * $115);
   $181 = Math_fround($115 * $61);
   $182 = Math_fround($63 * $117);
   $183 = Math_fround($115 * $58);
   $184 = Math_fround($63 * $119);
   $185 = Math_fround($115 * $55);
   $186 = Math_fround($63 * $113);
   $187 = Math_fround($19 * $121);
   $188 = Math_fround($172 - $171);
   $189 = Math_fround($19 * $120);
   $190 = Math_fround($173 + $174);
   $191 = Math_fround($17 * $122);
   $192 = Math_fround($175 + $176);
   $193 = Math_fround($21 * $121);
   $194 = Math_fround($177 + $178);
   $195 = Math_fround($119 * $58);
   $196 = Math_fround($180 - $179);
   $197 = Math_fround($119 * $55);
   $198 = Math_fround($181 + $182);
   $199 = Math_fround($113 * $61);
   $200 = Math_fround($183 + $184);
   $201 = Math_fround($117 * $58);
   $202 = Math_fround($186 + $185);
   $203 = Math_fround($21 * $122);
   $204 = Math_fround($188 - $187);
   $205 = Math_fround($17 * $121);
   $206 = Math_fround($189 + $190);
   $207 = Math_fround($21 * $120);
   $208 = Math_fround($191 + $192);
   $209 = Math_fround($19 * $122);
   $210 = Math_fround($193 + $194);
   $211 = Math_fround($117 * $61);
   $212 = Math_fround($196 - $195);
   $213 = Math_fround($113 * $58);
   $214 = Math_fround($197 + $198);
   $215 = Math_fround($117 * $55);
   $216 = Math_fround($199 + $200);
   $217 = Math_fround($119 * $61);
   $218 = Math_fround($202 + $201);
   $219 = Math_fround($204 - $203);
   $220 = Math_fround($206 - $205);
   $221 = Math_fround($208 - $207);
   $222 = Math_fround($210 - $209);
   $223 = Math_fround($212 - $211);
   $224 = Math_fround($214 - $213);
   $225 = Math_fround($216 - $215);
   $226 = Math_fround($218 - $217);
   $227 = Math_fround($226 - $222);
   $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($227)))));
   $228 = Math_fround($225 - $221);
   $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($228)))));
   $229 = $fabsf$i$i$i > $fabsf$i$i1$i;
   $230 = $229 ? $fabsf$i$i$i : $fabsf$i$i1$i;
   $231 = Math_fround($224 - $220);
   $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($231)))));
   $232 = $230 > $fabsf$i$i3$i;
   $233 = $232 ? $230 : $fabsf$i$i3$i;
   $234 = Math_fround($223 - $219);
   $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($234)))));
   $235 = $233 > $fabsf$i$i2$i;
   $236 = $235 ? $233 : $fabsf$i$i2$i;
   $237 = $236 < Math_fround(0.00999999977648258209228);
   if ($237) {
    $238 = $45&65535;
    $239 = (($context) + 356|0);
    $240 = (($51) + 79)|0;
    $241 = $240 & 65520;
    $242 = $241&65535;
    HEAP16[$53>>1] = $242;
    $243 = (__ZN5physx20PxcNpCacheStreamPair7reserveEj($239,$241)|0);
    $244 = ($243|0)==(0|0);
    $$not$i11 = ($243|0)!=((-1)|0);
    $or$cond3$i12 = $244 | $$not$i11;
    $$$i13 = $or$cond3$i12 ? $243 : 0;
    HEAP32[$1>>2] = $$$i13;
    $245 = $240 & -16;
    $246 = $$$i13;
    $247 = $246 & 127;
    $248 = (($247) + ($245))|0;
    $249 = ($248>>>0)>(128);
    if ($249) {
     $250 = (($$$i13) + 128|0);
    }
    HEAP32[$13>>2] = $238;
    $251 = ($45<<16>>16)==(0);
    if (!($251)) {
     $252 = Math_fround(HEAPF32[$tm1>>2]);
     $253 = Math_fround($252 + $252);
     $254 = Math_fround(HEAPF32[$56>>2]);
     $255 = Math_fround($254 + $254);
     $256 = Math_fround(HEAPF32[$59>>2]);
     $257 = Math_fround($256 + $256);
     $258 = Math_fround(HEAPF32[$62>>2]);
     $259 = Math_fround($253 * $258);
     $260 = Math_fround($255 * $258);
     $261 = Math_fround($258 * $257);
     $262 = Math_fround($252 * $253);
     $263 = Math_fround($252 * $255);
     $264 = Math_fround($252 * $257);
     $265 = Math_fround($254 * $255);
     $266 = Math_fround($254 * $257);
     $267 = Math_fround($256 * $257);
     $268 = Math_fround(Math_fround(1.0) - $265);
     $269 = Math_fround($268 - $267);
     $270 = Math_fround($263 + $261);
     $271 = Math_fround($264 - $260);
     $272 = Math_fround($263 - $261);
     $273 = Math_fround(Math_fround(1.0) - $262);
     $274 = Math_fround($273 - $267);
     $275 = Math_fround($266 + $259);
     $276 = Math_fround($264 + $260);
     $277 = Math_fround($266 - $259);
     $278 = Math_fround($273 - $265);
     $279 = Math_fround(HEAPF32[$66>>2]);
     $280 = Math_fround(HEAPF32[$71>>2]);
     $281 = Math_fround(HEAPF32[$76>>2]);
     $282 = Math_fround(HEAPF32[$tm0>>2]);
     $283 = Math_fround($282 + $282);
     $284 = Math_fround(HEAPF32[$118>>2]);
     $285 = Math_fround($284 + $284);
     $286 = Math_fround(HEAPF32[$116>>2]);
     $287 = Math_fround($286 + $286);
     $288 = Math_fround(HEAPF32[$114>>2]);
     $289 = Math_fround($283 * $288);
     $290 = Math_fround($285 * $288);
     $291 = Math_fround($288 * $287);
     $292 = Math_fround($282 * $283);
     $293 = Math_fround($282 * $285);
     $294 = Math_fround($282 * $287);
     $295 = Math_fround($284 * $285);
     $296 = Math_fround($284 * $287);
     $297 = Math_fround($286 * $287);
     $298 = Math_fround(Math_fround(1.0) - $295);
     $299 = Math_fround($298 - $297);
     $300 = Math_fround($293 + $291);
     $301 = Math_fround($294 - $290);
     $302 = Math_fround($293 - $291);
     $303 = Math_fround(Math_fround(1.0) - $292);
     $304 = Math_fround($303 - $297);
     $305 = Math_fround($296 + $289);
     $306 = Math_fround($294 + $290);
     $307 = Math_fround($296 - $289);
     $308 = Math_fround($303 - $295);
     $309 = Math_fround(HEAPF32[$64>>2]);
     $310 = Math_fround(HEAPF32[$69>>2]);
     $311 = Math_fround(HEAPF32[$74>>2]);
     $312 = ($49<<24>>24)==(0);
     $313 = (($238) + -1)|0;
     $314 = Math_fround($23 * $23);
     $315 = Math_fround($314 + Math_fround(-0.5));
     $316 = ($47<<24>>24)==(0);
     $contacts$029 = $52;$dst$030 = $12;$i$027 = 0;$normal0$028 = 0;
     while(1) {
      $317 = ($i$027|0)==($313|0);
      if (!($317)) {
       $318 = (($contacts$029) + 128|0);
      }
      $319 = ($i$027|0)==(0);
      $brmerge = $319 | $312;
      if ($brmerge) {
       $320 = (($contacts$029) + 12|0);
       $cachedNormal$0 = $contacts$029;$contacts$1 = $320;
      } else {
       $cachedNormal$0 = $normal0$028;$contacts$1 = $contacts$029;
      }
      $321 = (($contacts$1) + 12|0);
      $322 = (($contacts$1) + 16|0);
      $323 = Math_fround(HEAPF32[$321>>2]);
      $$idx$val = Math_fround(HEAPF32[$contacts$1>>2]);
      $$idx6 = (($contacts$1) + 4|0);
      $$idx6$val = Math_fround(HEAPF32[$$idx6>>2]);
      $$idx7 = (($contacts$1) + 8|0);
      $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
      $324 = Math_fround($$idx$val - $25);
      $325 = Math_fround($$idx6$val - $27);
      $326 = Math_fround($$idx7$val - $29);
      $327 = Math_fround($324 * Math_fround(2.0));
      $328 = Math_fround($325 * Math_fround(2.0));
      $329 = Math_fround($326 * Math_fround(2.0));
      $330 = Math_fround($17 * $327);
      $331 = Math_fround($19 * $328);
      $332 = Math_fround($330 + $331);
      $333 = Math_fround($21 * $329);
      $334 = Math_fround($332 + $333);
      $335 = Math_fround($315 * $327);
      $336 = Math_fround($19 * $329);
      $337 = Math_fround($21 * $328);
      $338 = Math_fround($336 - $337);
      $339 = Math_fround($23 * $338);
      $340 = Math_fround($335 - $339);
      $341 = Math_fround($17 * $334);
      $342 = Math_fround($341 + $340);
      $343 = Math_fround($315 * $328);
      $344 = Math_fround($21 * $327);
      $345 = Math_fround($17 * $329);
      $346 = Math_fround($344 - $345);
      $347 = Math_fround($23 * $346);
      $348 = Math_fround($343 - $347);
      $349 = Math_fround($19 * $334);
      $350 = Math_fround($349 + $348);
      $351 = Math_fround($315 * $329);
      $352 = Math_fround($17 * $328);
      $353 = Math_fround($19 * $327);
      $354 = Math_fround($352 - $353);
      $355 = Math_fround($23 * $354);
      $356 = Math_fround($351 - $355);
      $357 = Math_fround($21 * $334);
      $358 = Math_fround($356 + $357);
      $359 = Math_fround($299 * $342);
      $360 = Math_fround($300 * $342);
      $361 = Math_fround($301 * $342);
      $362 = Math_fround($302 * $350);
      $363 = Math_fround($304 * $350);
      $364 = Math_fround($305 * $350);
      $365 = Math_fround($359 + $362);
      $366 = Math_fround($360 + $363);
      $367 = Math_fround($361 + $364);
      $368 = Math_fround($306 * $358);
      $369 = Math_fround($307 * $358);
      $370 = Math_fround($308 * $358);
      $371 = Math_fround($368 + $365);
      $372 = Math_fround($369 + $366);
      $373 = Math_fround($370 + $367);
      $374 = Math_fround($309 + $371);
      $375 = Math_fround($310 + $372);
      $376 = Math_fround($311 + $373);
      $377 = Math_fround($$idx$val - $39);
      $378 = Math_fround($$idx6$val - $41);
      $379 = Math_fround($$idx7$val - $43);
      $380 = Math_fround($377 * Math_fround(2.0));
      $381 = Math_fround($378 * Math_fround(2.0));
      $382 = Math_fround($379 * Math_fround(2.0));
      $383 = Math_fround($31 * $380);
      $384 = Math_fround($33 * $381);
      $385 = Math_fround($383 + $384);
      $386 = Math_fround($35 * $382);
      $387 = Math_fround($385 + $386);
      $388 = Math_fround($130 * $380);
      $389 = Math_fround($33 * $382);
      $390 = Math_fround($35 * $381);
      $391 = Math_fround($389 - $390);
      $392 = Math_fround($37 * $391);
      $393 = Math_fround($388 - $392);
      $394 = Math_fround($31 * $387);
      $395 = Math_fround($394 + $393);
      $396 = Math_fround($130 * $381);
      $397 = Math_fround($35 * $380);
      $398 = Math_fround($31 * $382);
      $399 = Math_fround($397 - $398);
      $400 = Math_fround($37 * $399);
      $401 = Math_fround($396 - $400);
      $402 = Math_fround($33 * $387);
      $403 = Math_fround($402 + $401);
      $404 = Math_fround($130 * $382);
      $405 = Math_fround($31 * $381);
      $406 = Math_fround($33 * $380);
      $407 = Math_fround($405 - $406);
      $408 = Math_fround($37 * $407);
      $409 = Math_fround($404 - $408);
      $410 = Math_fround($35 * $387);
      $411 = Math_fround($409 + $410);
      $412 = Math_fround($269 * $395);
      $413 = Math_fround($270 * $395);
      $414 = Math_fround($271 * $395);
      $415 = Math_fround($272 * $403);
      $416 = Math_fround($274 * $403);
      $417 = Math_fround($275 * $403);
      $418 = Math_fround($412 + $415);
      $419 = Math_fround($413 + $416);
      $420 = Math_fround($414 + $417);
      $421 = Math_fround($276 * $411);
      $422 = Math_fround($277 * $411);
      $423 = Math_fround($278 * $411);
      $424 = Math_fround($421 + $418);
      $425 = Math_fround($422 + $419);
      $426 = Math_fround($423 + $420);
      $427 = Math_fround($279 + $424);
      $428 = Math_fround($280 + $425);
      $429 = Math_fround($281 + $426);
      $430 = Math_fround($374 - $427);
      $431 = Math_fround($375 - $428);
      $432 = Math_fround($376 - $429);
      $433 = Math_fround(HEAPF32[$cachedNormal$0>>2]);
      HEAPF32[$dst$030>>2] = $433;
      $434 = (($cachedNormal$0) + 4|0);
      $435 = Math_fround(HEAPF32[$434>>2]);
      $436 = (($dst$030) + 4|0);
      HEAPF32[$436>>2] = $435;
      $437 = (($cachedNormal$0) + 8|0);
      $438 = Math_fround(HEAPF32[$437>>2]);
      $439 = (($dst$030) + 8|0);
      HEAPF32[$439>>2] = $438;
      $440 = Math_fround($374 + $427);
      $441 = Math_fround($375 + $428);
      $442 = Math_fround($376 + $429);
      $443 = Math_fround($440 * Math_fround(0.5));
      $444 = Math_fround($441 * Math_fround(0.5));
      $445 = Math_fround($442 * Math_fround(0.5));
      $446 = (($dst$030) + 16|0);
      HEAPF32[$446>>2] = $443;
      $447 = (($dst$030) + 20|0);
      HEAPF32[$447>>2] = $444;
      $448 = (($dst$030) + 24|0);
      HEAPF32[$448>>2] = $445;
      $449 = Math_fround(HEAPF32[$cachedNormal$0>>2]);
      $450 = Math_fround($449 * $430);
      $451 = Math_fround(HEAPF32[$434>>2]);
      $452 = Math_fround($451 * $431);
      $453 = Math_fround($450 + $452);
      $454 = Math_fround(HEAPF32[$437>>2]);
      $455 = Math_fround($454 * $432);
      $456 = Math_fround($455 + $453);
      $457 = Math_fround($323 + $456);
      $458 = (($dst$030) + 12|0);
      HEAPF32[$458>>2] = $457;
      if ($316) {
       $465 = (($dst$030) + 48|0);
       HEAP32[$465>>2] = -1;
       $466 = (($dst$030) + 52|0);
       HEAP32[$466>>2] = -1;
       $contacts$2 = $322;
      } else {
       $459 = (($contacts$1) + 20|0);
       $460 = (($contacts$1) + 24|0);
       $461 = HEAP32[$322>>2]|0;
       $462 = (($dst$030) + 48|0);
       HEAP32[$462>>2] = $461;
       $463 = HEAP32[$459>>2]|0;
       $464 = (($dst$030) + 52|0);
       HEAP32[$464>>2] = $463;
       $contacts$2 = $460;
      }
      $467 = (($dst$030) + 64|0);
      $468 = (($i$027) + 1)|0;
      $exitcond33 = ($468|0)==($238|0);
      if ($exitcond33) {
       break;
      } else {
       $contacts$029 = $contacts$2;$dst$030 = $467;$i$027 = $468;$normal0$028 = $cachedNormal$0;
      }
     }
    }
    $469 = ($$$i13|0)==(0|0);
    if ($469) {
     STACKTOP = sp;return;
    }
    HEAPF32[$$$i13>>2] = $17;
    $470 = (($$$i13) + 4|0);
    HEAPF32[$470>>2] = $19;
    $471 = (($$$i13) + 8|0);
    HEAPF32[$471>>2] = $21;
    $472 = (($$$i13) + 12|0);
    HEAPF32[$472>>2] = $23;
    $473 = (($$$i13) + 16|0);
    HEAPF32[$473>>2] = $25;
    $474 = (($$$i13) + 20|0);
    HEAPF32[$474>>2] = $27;
    $475 = (($$$i13) + 24|0);
    HEAPF32[$475>>2] = $29;
    $476 = (($$$i13) + 28|0);
    HEAPF32[$476>>2] = $31;
    $477 = (($$$i13) + 32|0);
    HEAPF32[$477>>2] = $33;
    $478 = (($$$i13) + 36|0);
    HEAPF32[$478>>2] = $35;
    $479 = (($$$i13) + 40|0);
    HEAPF32[$479>>2] = $37;
    $480 = (($$$i13) + 44|0);
    HEAPF32[$480>>2] = $39;
    $481 = (($$$i13) + 48|0);
    HEAPF32[$481>>2] = $41;
    $482 = (($$$i13) + 52|0);
    HEAPF32[$482>>2] = $43;
    $483 = (($$$i13) + 56|0);
    HEAP16[$483>>1] = $45;
    $484 = (($$$i13) + 58|0);
    HEAP8[$484>>0] = $47;
    $485 = (($$$i13) + 59|0);
    HEAP8[$485>>0] = $49;
    $486 = (($$$i13) + 60|0);
    HEAP32[$486>>2] = $51;
    $487 = (($$$i13) + 64|0);
    _memcpy(($487|0),($52|0),($51|0))|0;
    STACKTOP = sp;return;
   } else {
    $$pre$phi38Z2D = $118;$$pre$phi40Z2D = $116;$$pre$phi42Z2D = $114;$$pre$phi44Z2D = $64;$$pre$phi46Z2D = $69;$$pre$phi48Z2D = $74;$$pre$phi50Z2D = $tm1;$$pre$phi52Z2D = $56;$$pre$phi54Z2D = $59;$$pre$phi56Z2D = $62;$$pre$phi58Z2D = $66;$$pre$phi60Z2D = $71;$$pre$phi62Z2D = $76;$$pre$phiZ2D = $tm0;$539 = $53;$696 = $49;
   }
  } else {
   $$pre$phi38Z2D = $118;$$pre$phi40Z2D = $116;$$pre$phi42Z2D = $114;$$pre$phi44Z2D = $64;$$pre$phi46Z2D = $69;$$pre$phi48Z2D = $74;$$pre$phi50Z2D = $tm1;$$pre$phi52Z2D = $56;$$pre$phi54Z2D = $59;$$pre$phi56Z2D = $62;$$pre$phi58Z2D = $66;$$pre$phi60Z2D = $71;$$pre$phi62Z2D = $76;$$pre$phiZ2D = $tm0;$539 = $53;$696 = $49;
  }
 }
 (FUNCTION_TABLE_iiiiiiii[$conMethod & 127]($shape0,$shape1,$tm0,$tm1,$0,$pairContactCache,$12)|0);
 $488 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $489 = Math_fround(HEAPF32[$$pre$phi38Z2D>>2]);
 $490 = Math_fround(HEAPF32[$$pre$phi40Z2D>>2]);
 $491 = Math_fround(HEAPF32[$$pre$phi42Z2D>>2]);
 $492 = Math_fround(HEAPF32[$$pre$phi44Z2D>>2]);
 $493 = Math_fround(HEAPF32[$$pre$phi46Z2D>>2]);
 $494 = Math_fround(HEAPF32[$$pre$phi48Z2D>>2]);
 $495 = Math_fround(HEAPF32[$$pre$phi50Z2D>>2]);
 $496 = Math_fround(HEAPF32[$$pre$phi52Z2D>>2]);
 $497 = Math_fround(HEAPF32[$$pre$phi54Z2D>>2]);
 $498 = Math_fround(HEAPF32[$$pre$phi56Z2D>>2]);
 $499 = Math_fround(HEAPF32[$$pre$phi58Z2D>>2]);
 $500 = Math_fround(HEAPF32[$$pre$phi60Z2D>>2]);
 $501 = Math_fround(HEAPF32[$$pre$phi62Z2D>>2]);
 $502 = HEAP32[$13>>2]|0;
 $503 = ($502|0)==(0);
 if ($503) {
  $678 = (($context) + 356|0);
  HEAP16[$539>>1] = 64;
  $679 = (__ZN5physx20PxcNpCacheStreamPair7reserveEj($678,64)|0);
  HEAP32[$1>>2] = $679;
  $magicptr2$i = $679;
  if ((($magicptr2$i|0) == 0)) {
   STACKTOP = sp;return;
  } else if ((($magicptr2$i|0) == -1)) {
   HEAP32[$1>>2] = 0;
   STACKTOP = sp;return;
  } else {
   HEAPF32[$679>>2] = $488;
   $680 = (($679) + 4|0);
   HEAPF32[$680>>2] = $489;
   $681 = (($679) + 8|0);
   HEAPF32[$681>>2] = $490;
   $682 = (($679) + 12|0);
   HEAPF32[$682>>2] = $491;
   $683 = (($679) + 16|0);
   HEAPF32[$683>>2] = $492;
   $684 = (($679) + 20|0);
   HEAPF32[$684>>2] = $493;
   $685 = (($679) + 24|0);
   HEAPF32[$685>>2] = $494;
   $686 = (($679) + 28|0);
   HEAPF32[$686>>2] = $495;
   $687 = (($679) + 32|0);
   HEAPF32[$687>>2] = $496;
   $688 = (($679) + 36|0);
   HEAPF32[$688>>2] = $497;
   $689 = (($679) + 40|0);
   HEAPF32[$689>>2] = $498;
   $690 = (($679) + 44|0);
   HEAPF32[$690>>2] = $499;
   $691 = (($679) + 48|0);
   HEAPF32[$691>>2] = $500;
   $692 = (($679) + 52|0);
   HEAPF32[$692>>2] = $501;
   $693 = (($679) + 56|0);
   HEAP16[$693>>1] = 0;
   $694 = (($679) + 58|0);
   HEAP8[$694>>0] = 0;
   $695 = (($679) + 59|0);
   HEAP8[$695>>0] = $696;
   $697 = (($679) + 60|0);
   HEAP32[$697>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $504 = (($context) + 432|0);
 $505 = HEAP32[$504>>2]|0;
 $506 = ($505|0)==(-1);
 if ($506) {
  $507 = (($context) + 436|0);
  $508 = HEAP32[$507>>2]|0;
  $509 = ($508|0)!=(-1);
  $512 = $509;
 } else {
  $512 = 1;
 }
 $510 = $502&65535;
 $511 = $512&1;
 $513 = Math_fround(HEAPF32[$12>>2]);
 $514 = (($context) + 388|0);
 $515 = Math_fround(HEAPF32[$514>>2]);
 $516 = (($context) + 392|0);
 $517 = Math_fround(HEAPF32[$516>>2]);
 $518 = ($502>>>0)>(1);
 L45: do {
  if ($518) {
   $i3$025 = 1;
   while(1) {
    $521 = ((($context) + ($i3$025<<6)|0) + 384|0);
    $522 = Math_fround(HEAPF32[$521>>2]);
    $523 = $522 != $513;
    if ($523) {
     break;
    }
    $524 = ((($context) + ($i3$025<<6)|0) + 388|0);
    $525 = Math_fround(HEAPF32[$524>>2]);
    $526 = $525 != $515;
    if ($526) {
     break;
    }
    $527 = ((($context) + ($i3$025<<6)|0) + 392|0);
    $528 = Math_fround(HEAPF32[$527>>2]);
    $529 = $528 != $517;
    $520 = (($i3$025) + 1)|0;
    if ($529) {
     break;
    }
    $519 = ($520>>>0)<($502>>>0);
    if ($519) {
     $i3$025 = $520;
    } else {
     label = 31;
     break L45;
    }
   }
   $530 = $512 ? 36 : 28;
   $531 = Math_imul($530, $502)|0;
   $559 = 0;$nbBytes$0 = $531;$sameNormal1$0$off017 = 1;
  } else {
   label = 31;
  }
 } while(0);
 if ((label|0) == 31) {
  $532 = $512 ? 24 : 16;
  $533 = Math_imul($532, $502)|0;
  $534 = (($533) + 12)|0;
  $559 = 1;$nbBytes$0 = $534;$sameNormal1$0$off017 = 0;
 }
 $535 = (($context) + 356|0);
 $536 = (($nbBytes$0) + 79)|0;
 $537 = $536 & 65520;
 $538 = $537&65535;
 HEAP16[$539>>1] = $538;
 $540 = (__ZN5physx20PxcNpCacheStreamPair7reserveEj($535,$537)|0);
 $541 = ($540|0)==(0|0);
 $$not$i = ($540|0)!=((-1)|0);
 $or$cond3$i = $541 | $$not$i;
 $$$i = $or$cond3$i ? $540 : 0;
 HEAP32[$1>>2] = $$$i;
 $542 = ($$$i|0)==(0|0);
 if ($542) {
  HEAP16[$539>>1] = 64;
  $660 = (__ZN5physx20PxcNpCacheStreamPair7reserveEj($535,64)|0);
  HEAP32[$1>>2] = $660;
  $magicptr2$i8 = $660;
  if ((($magicptr2$i8|0) == 0)) {
   STACKTOP = sp;return;
  } else if ((($magicptr2$i8|0) == -1)) {
   HEAP32[$1>>2] = 0;
   STACKTOP = sp;return;
  } else {
   HEAPF32[$660>>2] = $488;
   $661 = (($660) + 4|0);
   HEAPF32[$661>>2] = $489;
   $662 = (($660) + 8|0);
   HEAPF32[$662>>2] = $490;
   $663 = (($660) + 12|0);
   HEAPF32[$663>>2] = $491;
   $664 = (($660) + 16|0);
   HEAPF32[$664>>2] = $492;
   $665 = (($660) + 20|0);
   HEAPF32[$665>>2] = $493;
   $666 = (($660) + 24|0);
   HEAPF32[$666>>2] = $494;
   $667 = (($660) + 28|0);
   HEAPF32[$667>>2] = $495;
   $668 = (($660) + 32|0);
   HEAPF32[$668>>2] = $496;
   $669 = (($660) + 36|0);
   HEAPF32[$669>>2] = $497;
   $670 = (($660) + 40|0);
   HEAPF32[$670>>2] = $498;
   $671 = (($660) + 44|0);
   HEAPF32[$671>>2] = $499;
   $672 = (($660) + 48|0);
   HEAPF32[$672>>2] = $500;
   $673 = (($660) + 52|0);
   HEAPF32[$673>>2] = $501;
   $674 = (($660) + 56|0);
   HEAP16[$674>>1] = 0;
   $675 = (($660) + 58|0);
   HEAP8[$675>>0] = $511;
   $676 = (($660) + 59|0);
   HEAP8[$676>>0] = $559;
   $677 = (($660) + 60|0);
   HEAP32[$677>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 HEAPF32[$$$i>>2] = $488;
 $543 = (($$$i) + 4|0);
 HEAPF32[$543>>2] = $489;
 $544 = (($$$i) + 8|0);
 HEAPF32[$544>>2] = $490;
 $545 = (($$$i) + 12|0);
 HEAPF32[$545>>2] = $491;
 $546 = (($$$i) + 16|0);
 HEAPF32[$546>>2] = $492;
 $547 = (($$$i) + 20|0);
 HEAPF32[$547>>2] = $493;
 $548 = (($$$i) + 24|0);
 HEAPF32[$548>>2] = $494;
 $549 = (($$$i) + 28|0);
 HEAPF32[$549>>2] = $495;
 $550 = (($$$i) + 32|0);
 HEAPF32[$550>>2] = $496;
 $551 = (($$$i) + 36|0);
 HEAPF32[$551>>2] = $497;
 $552 = (($$$i) + 40|0);
 HEAPF32[$552>>2] = $498;
 $553 = (($$$i) + 44|0);
 HEAPF32[$553>>2] = $499;
 $554 = (($$$i) + 48|0);
 HEAPF32[$554>>2] = $500;
 $555 = (($$$i) + 52|0);
 HEAPF32[$555>>2] = $501;
 $556 = (($$$i) + 56|0);
 HEAP16[$556>>1] = $510;
 $557 = (($$$i) + 58|0);
 HEAP8[$557>>0] = $511;
 $558 = (($$$i) + 59|0);
 HEAP8[$558>>0] = $559;
 $560 = (($$$i) + 60|0);
 HEAP32[$560>>2] = $nbBytes$0;
 $561 = (($$$i) + 64|0);
 if ($sameNormal1$0$off017) {
  if ($512) {
   $dest$019$us$us = $561;$i8$020$us$us = 0;
   while(1) {
    $562 = ((($context) + ($i8$020$us$us<<6)|0) + 384|0);
    $563 = Math_fround(HEAPF32[$562>>2]);
    HEAPF32[$dest$019$us$us>>2] = $563;
    $564 = ((($context) + ($i8$020$us$us<<6)|0) + 388|0);
    $565 = Math_fround(HEAPF32[$564>>2]);
    $566 = (($dest$019$us$us) + 4|0);
    HEAPF32[$566>>2] = $565;
    $567 = ((($context) + ($i8$020$us$us<<6)|0) + 392|0);
    $568 = Math_fround(HEAPF32[$567>>2]);
    $569 = (($dest$019$us$us) + 8|0);
    HEAPF32[$569>>2] = $568;
    $570 = (($dest$019$us$us) + 12|0);
    $571 = ((($context) + ($i8$020$us$us<<6)|0) + 400|0);
    $572 = Math_fround(HEAPF32[$571>>2]);
    HEAPF32[$570>>2] = $572;
    $573 = ((($context) + ($i8$020$us$us<<6)|0) + 404|0);
    $574 = Math_fround(HEAPF32[$573>>2]);
    $575 = (($dest$019$us$us) + 16|0);
    HEAPF32[$575>>2] = $574;
    $576 = ((($context) + ($i8$020$us$us<<6)|0) + 408|0);
    $577 = Math_fround(HEAPF32[$576>>2]);
    $578 = (($dest$019$us$us) + 20|0);
    HEAPF32[$578>>2] = $577;
    $579 = (($dest$019$us$us) + 24|0);
    $580 = ((($context) + ($i8$020$us$us<<6)|0) + 396|0);
    $581 = Math_fround(HEAPF32[$580>>2]);
    HEAPF32[$579>>2] = $581;
    $582 = (($dest$019$us$us) + 28|0);
    $583 = ((($context) + ($i8$020$us$us<<6)|0) + 432|0);
    $584 = HEAP32[$583>>2]|0;
    HEAP32[$582>>2] = $584;
    $585 = (($dest$019$us$us) + 32|0);
    $586 = ((($context) + ($i8$020$us$us<<6)|0) + 436|0);
    $587 = HEAP32[$586>>2]|0;
    HEAP32[$585>>2] = $587;
    $588 = (($dest$019$us$us) + 36|0);
    $589 = (($i8$020$us$us) + 1)|0;
    $exitcond36 = ($589|0)==($502|0);
    if ($exitcond36) {
     break;
    } else {
     $dest$019$us$us = $588;$i8$020$us$us = $589;
    }
   }
   STACKTOP = sp;return;
  } else {
   $dest$019$us = $561;$i8$020$us = 0;
   while(1) {
    $590 = ((($context) + ($i8$020$us<<6)|0) + 384|0);
    $591 = Math_fround(HEAPF32[$590>>2]);
    HEAPF32[$dest$019$us>>2] = $591;
    $592 = ((($context) + ($i8$020$us<<6)|0) + 388|0);
    $593 = Math_fround(HEAPF32[$592>>2]);
    $594 = (($dest$019$us) + 4|0);
    HEAPF32[$594>>2] = $593;
    $595 = ((($context) + ($i8$020$us<<6)|0) + 392|0);
    $596 = Math_fround(HEAPF32[$595>>2]);
    $597 = (($dest$019$us) + 8|0);
    HEAPF32[$597>>2] = $596;
    $598 = (($dest$019$us) + 12|0);
    $599 = ((($context) + ($i8$020$us<<6)|0) + 400|0);
    $600 = Math_fround(HEAPF32[$599>>2]);
    HEAPF32[$598>>2] = $600;
    $601 = ((($context) + ($i8$020$us<<6)|0) + 404|0);
    $602 = Math_fround(HEAPF32[$601>>2]);
    $603 = (($dest$019$us) + 16|0);
    HEAPF32[$603>>2] = $602;
    $604 = ((($context) + ($i8$020$us<<6)|0) + 408|0);
    $605 = Math_fround(HEAPF32[$604>>2]);
    $606 = (($dest$019$us) + 20|0);
    HEAPF32[$606>>2] = $605;
    $607 = (($dest$019$us) + 24|0);
    $608 = ((($context) + ($i8$020$us<<6)|0) + 396|0);
    $609 = Math_fround(HEAPF32[$608>>2]);
    HEAPF32[$607>>2] = $609;
    $610 = (($dest$019$us) + 28|0);
    $611 = (($i8$020$us) + 1)|0;
    $exitcond34 = ($611|0)==($502|0);
    if ($exitcond34) {
     break;
    } else {
     $dest$019$us = $610;$i8$020$us = $611;
    }
   }
   STACKTOP = sp;return;
  }
 }
 if ($512) {
  $dest$019$us22 = $561;$i8$020$us21 = 0;
  while(1) {
   $612 = ($i8$020$us21|0)==(0);
   if ($612) {
    $613 = (($context) + 384|0);
    $614 = Math_fround(HEAPF32[$613>>2]);
    HEAPF32[$dest$019$us22>>2] = $614;
    $615 = Math_fround(HEAPF32[$514>>2]);
    $616 = (($dest$019$us22) + 4|0);
    HEAPF32[$616>>2] = $615;
    $617 = Math_fround(HEAPF32[$516>>2]);
    $618 = (($dest$019$us22) + 8|0);
    HEAPF32[$618>>2] = $617;
    $619 = (($dest$019$us22) + 12|0);
    $dest$1$us23 = $619;
   } else {
    $dest$1$us23 = $dest$019$us22;
   }
   $620 = ((($context) + ($i8$020$us21<<6)|0) + 400|0);
   $621 = Math_fround(HEAPF32[$620>>2]);
   HEAPF32[$dest$1$us23>>2] = $621;
   $622 = ((($context) + ($i8$020$us21<<6)|0) + 404|0);
   $623 = Math_fround(HEAPF32[$622>>2]);
   $624 = (($dest$1$us23) + 4|0);
   HEAPF32[$624>>2] = $623;
   $625 = ((($context) + ($i8$020$us21<<6)|0) + 408|0);
   $626 = Math_fround(HEAPF32[$625>>2]);
   $627 = (($dest$1$us23) + 8|0);
   HEAPF32[$627>>2] = $626;
   $628 = (($dest$1$us23) + 12|0);
   $629 = ((($context) + ($i8$020$us21<<6)|0) + 396|0);
   $630 = Math_fround(HEAPF32[$629>>2]);
   HEAPF32[$628>>2] = $630;
   $631 = (($dest$1$us23) + 16|0);
   $632 = ((($context) + ($i8$020$us21<<6)|0) + 432|0);
   $633 = HEAP32[$632>>2]|0;
   HEAP32[$631>>2] = $633;
   $634 = (($dest$1$us23) + 20|0);
   $635 = ((($context) + ($i8$020$us21<<6)|0) + 436|0);
   $636 = HEAP32[$635>>2]|0;
   HEAP32[$634>>2] = $636;
   $637 = (($dest$1$us23) + 24|0);
   $638 = (($i8$020$us21) + 1)|0;
   $exitcond35 = ($638|0)==($502|0);
   if ($exitcond35) {
    break;
   } else {
    $dest$019$us22 = $637;$i8$020$us21 = $638;
   }
  }
  STACKTOP = sp;return;
 } else {
  $dest$019 = $561;$i8$020 = 0;
  while(1) {
   $639 = ($i8$020|0)==(0);
   if ($639) {
    $640 = (($context) + 384|0);
    $641 = Math_fround(HEAPF32[$640>>2]);
    HEAPF32[$dest$019>>2] = $641;
    $642 = Math_fround(HEAPF32[$514>>2]);
    $643 = (($dest$019) + 4|0);
    HEAPF32[$643>>2] = $642;
    $644 = Math_fround(HEAPF32[$516>>2]);
    $645 = (($dest$019) + 8|0);
    HEAPF32[$645>>2] = $644;
    $646 = (($dest$019) + 12|0);
    $dest$1 = $646;
   } else {
    $dest$1 = $dest$019;
   }
   $647 = ((($context) + ($i8$020<<6)|0) + 400|0);
   $648 = Math_fround(HEAPF32[$647>>2]);
   HEAPF32[$dest$1>>2] = $648;
   $649 = ((($context) + ($i8$020<<6)|0) + 404|0);
   $650 = Math_fround(HEAPF32[$649>>2]);
   $651 = (($dest$1) + 4|0);
   HEAPF32[$651>>2] = $650;
   $652 = ((($context) + ($i8$020<<6)|0) + 408|0);
   $653 = Math_fround(HEAPF32[$652>>2]);
   $654 = (($dest$1) + 8|0);
   HEAPF32[$654>>2] = $653;
   $655 = (($dest$1) + 12|0);
   $656 = ((($context) + ($i8$020<<6)|0) + 396|0);
   $657 = Math_fround(HEAPF32[$656>>2]);
   HEAPF32[$655>>2] = $657;
   $658 = (($dest$1) + 16|0);
   $659 = (($i8$020) + 1)|0;
   $exitcond = ($659|0)==($502|0);
   if ($exitcond) {
    break;
   } else {
    $dest$019 = $658;$i8$020 = $659;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN5physxL21PxcInvalidContactPairERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE($0,$1,$2,$3,$4,$5,$6) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx21PxcUnimplementedSweepERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf($0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = Math_fround($8);
 $9 = $9|0;
 $10 = $10|0;
 $11 = $11|0;
 $12 = $12|0;
 $13 = Math_fround($13);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return Math_fround(3.40282346638528859812E+38);
}
function __ZN5physx20createContactPatchesERNS_18PxcNpThreadContextEjf($threadContext,$startIndex,$normalTolerance) {
 $threadContext = $threadContext|0;
 $startIndex = $startIndex|0;
 $normalTolerance = Math_fround($normalTolerance);
 var $$0 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $contactPatchCount$010 = 0, $contactPatchCount$1 = 0, $contactPatchCount$2 = 0, $count$06 = 0;
 var $count$1 = 0, $currentPatchData$05 = 0, $currentPatchData$1 = 0, $i$08 = 0, $patchIndex$07 = 0, $patchIndex$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($threadContext) + 8724|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($threadContext) + 4480|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) - ($startIndex))|0;
 $5 = ($1|0)==(32);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ($3|0)==($startIndex|0);
 if ($6) {
  $contactPatchCount$2 = $1;
 } else {
  $7 = ((($threadContext) + (($1*12)|0)|0) + 4496|0);
  $8 = (($1) + 1)|0;
  $9 = $startIndex&65535;
  $10 = ((($threadContext) + ($startIndex<<6)|0) + 432|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11&65535;
  $13 = $11 >>> 16;
  $14 = $13&65535;
  $15 = ((($threadContext) + ($startIndex<<6)|0) + 436|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16&65535;
  HEAP16[$7>>1] = $9;
  $18 = ((($threadContext) + (($1*12)|0)|0) + 4498|0);
  HEAP16[$18>>1] = 1;
  $19 = ((($threadContext) + (($1*12)|0)|0) + 4500|0);
  HEAP16[$19>>1] = 0;
  $20 = ((($threadContext) + (($1*12)|0)|0) + 4504|0);
  HEAP16[$20>>1] = $12;
  $21 = ((($threadContext) + (($1*12)|0)|0) + 4506|0);
  HEAP16[$21>>1] = $14;
  $22 = ((($threadContext) + (($1*12)|0)|0) + 4502|0);
  HEAP16[$22>>1] = $17;
  $23 = ($4>>>0)>(1);
  if ($23) {
   $contactPatchCount$010 = $8;$count$06 = 1;$currentPatchData$05 = $7;$i$08 = 1;$patchIndex$07 = 0;
   while(1) {
    $$sum = (($i$08) + ($startIndex))|0;
    $$sum1 = (($patchIndex$07) + ($startIndex))|0;
    $24 = ((($threadContext) + ($$sum<<6)|0) + 432|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($threadContext) + ($$sum1<<6)|0) + 432|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($25|0)==($27|0);
    if ($28) {
     $29 = ((($threadContext) + ($$sum<<6)|0) + 436|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ((($threadContext) + ($$sum1<<6)|0) + 436|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($30|0)==($32|0);
     if ($33) {
      $34 = ((($threadContext) + ($$sum<<6)|0) + 384|0);
      $35 = Math_fround(HEAPF32[$34>>2]);
      $36 = ((($threadContext) + ($$sum1<<6)|0) + 384|0);
      $37 = Math_fround(HEAPF32[$36>>2]);
      $38 = Math_fround($35 * $37);
      $39 = ((($threadContext) + ($$sum<<6)|0) + 388|0);
      $40 = Math_fround(HEAPF32[$39>>2]);
      $41 = ((($threadContext) + ($$sum1<<6)|0) + 388|0);
      $42 = Math_fround(HEAPF32[$41>>2]);
      $43 = Math_fround($40 * $42);
      $44 = Math_fround($38 + $43);
      $45 = ((($threadContext) + ($$sum<<6)|0) + 392|0);
      $46 = Math_fround(HEAPF32[$45>>2]);
      $47 = ((($threadContext) + ($$sum1<<6)|0) + 392|0);
      $48 = Math_fround(HEAPF32[$47>>2]);
      $49 = Math_fround($46 * $48);
      $50 = Math_fround($44 + $49);
      $51 = !($50 >= $normalTolerance);
      if ($51) {
       label = 8;
      } else {
       $52 = (($count$06) + 1)<<16>>16;
       $contactPatchCount$1 = $contactPatchCount$010;$count$1 = $52;$currentPatchData$1 = $currentPatchData$05;$patchIndex$1 = $patchIndex$07;
      }
     } else {
      label = 8;
     }
    } else {
     label = 8;
    }
    if ((label|0) == 8) {
     label = 0;
     $53 = ($contactPatchCount$010|0)==(64);
     if ($53) {
      $$0 = 0;
      label = 14;
      break;
     }
     $54 = (($currentPatchData$05) + 2|0);
     HEAP16[$54>>1] = $count$06;
     $55 = ((($threadContext) + (($contactPatchCount$010*12)|0)|0) + 4496|0);
     $56 = (($contactPatchCount$010) + 1)|0;
     $57 = $$sum&65535;
     $58 = $25&65535;
     $59 = $25 >>> 16;
     $60 = $59&65535;
     $61 = ((($threadContext) + ($$sum<<6)|0) + 436|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = $62&65535;
     HEAP16[$55>>1] = $57;
     $64 = ((($threadContext) + (($contactPatchCount$010*12)|0)|0) + 4498|0);
     HEAP16[$64>>1] = 1;
     $65 = ((($threadContext) + (($contactPatchCount$010*12)|0)|0) + 4500|0);
     HEAP16[$65>>1] = 0;
     $66 = ((($threadContext) + (($contactPatchCount$010*12)|0)|0) + 4504|0);
     HEAP16[$66>>1] = $58;
     $67 = ((($threadContext) + (($contactPatchCount$010*12)|0)|0) + 4506|0);
     HEAP16[$67>>1] = $60;
     $68 = ((($threadContext) + (($contactPatchCount$010*12)|0)|0) + 4502|0);
     HEAP16[$68>>1] = $63;
     $contactPatchCount$1 = $56;$count$1 = 1;$currentPatchData$1 = $55;$patchIndex$1 = $i$08;
    }
    $69 = (($i$08) + 1)|0;
    $70 = ($69>>>0)<($4>>>0);
    if ($70) {
     $contactPatchCount$010 = $contactPatchCount$1;$count$06 = $count$1;$currentPatchData$05 = $currentPatchData$1;$i$08 = $69;$patchIndex$07 = $patchIndex$1;
    } else {
     break;
    }
   }
   if ((label|0) == 14) {
    STACKTOP = sp;return ($$0|0);
   }
   $71 = ($count$1<<16>>16)==(1);
   if ($71) {
    $contactPatchCount$2 = $contactPatchCount$1;
   } else {
    $72 = (($currentPatchData$1) + 2|0);
    HEAP16[$72>>1] = $count$1;
    $contactPatchCount$2 = $contactPatchCount$1;
   }
  } else {
   $contactPatchCount$2 = $8;
  }
 }
 HEAP32[$0>>2] = $contactPatchCount$2;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx27createContactPatchesCoulombERNS_27PxcCorrelationBufferCoulombERNS_2Gu13ContactBufferEfj($fb,$cb,$normalTolerance,$startContactIndex) {
 $fb = $fb|0;
 $cb = $cb|0;
 $normalTolerance = Math_fround($normalTolerance);
 $startContactIndex = $startContactIndex|0;
 var $$0 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $contactPatchCount$08 = 0;
 var $contactPatchCount$1 = 0, $contactPatchCount$2 = 0, $count$06 = 0, $count$1 = 0, $currentPatchData$05 = 0, $currentPatchData$1 = 0, $i$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($fb) + 1792|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cb) + 4096|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) - ($startContactIndex))|0;
 $5 = ($1|0)==(32);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ($3|0)==($startContactIndex|0);
 if ($6) {
  $contactPatchCount$2 = $1;
 } else {
  $7 = (($fb) + (($1*12)|0)|0);
  $8 = (($1) + 1)|0;
  $9 = $startContactIndex&65535;
  $10 = ((($cb) + ($startContactIndex<<6)|0) + 48|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11&65535;
  $13 = $11 >>> 16;
  $14 = $13&65535;
  $15 = ((($cb) + ($startContactIndex<<6)|0) + 52|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16&65535;
  HEAP16[$7>>1] = $9;
  $18 = ((($fb) + (($1*12)|0)|0) + 2|0);
  HEAP16[$18>>1] = 1;
  $19 = ((($fb) + (($1*12)|0)|0) + 4|0);
  HEAP16[$19>>1] = 0;
  $20 = ((($fb) + (($1*12)|0)|0) + 8|0);
  HEAP16[$20>>1] = $12;
  $21 = ((($fb) + (($1*12)|0)|0) + 10|0);
  HEAP16[$21>>1] = $14;
  $22 = ((($fb) + (($1*12)|0)|0) + 6|0);
  HEAP16[$22>>1] = $17;
  $23 = ($4>>>0)>(1);
  if ($23) {
   $24 = (($startContactIndex) + -1)|0;
   $contactPatchCount$08 = $8;$count$06 = 1;$currentPatchData$05 = $7;$i$07 = 1;
   while(1) {
    $$sum = (($i$07) + ($startContactIndex))|0;
    $$sum1 = (($24) + ($i$07))|0;
    $25 = (($cb) + ($$sum<<6)|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = (($cb) + ($$sum1<<6)|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = Math_fround($26 * $28);
    $30 = ((($cb) + ($$sum<<6)|0) + 4|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = ((($cb) + ($$sum1<<6)|0) + 4|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = Math_fround($31 * $33);
    $35 = Math_fround($29 + $34);
    $36 = ((($cb) + ($$sum<<6)|0) + 8|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = ((($cb) + ($$sum1<<6)|0) + 8|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = Math_fround($37 * $39);
    $41 = Math_fround($35 + $40);
    $42 = !($41 >= $normalTolerance);
    if ($42) {
     label = 9;
    } else {
     $43 = ((($cb) + ($$sum<<6)|0) + 48|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ((($cb) + ($$sum1<<6)|0) + 48|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($44|0)==($46|0);
     if ($47) {
      $48 = ((($cb) + ($$sum<<6)|0) + 52|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ((($cb) + ($$sum1<<6)|0) + 52|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($49|0)==($51|0);
      if ($52) {
       $53 = (($count$06) + 1)<<16>>16;
       $contactPatchCount$1 = $contactPatchCount$08;$count$1 = $53;$currentPatchData$1 = $currentPatchData$05;
      } else {
       label = 9;
      }
     } else {
      label = 9;
     }
    }
    if ((label|0) == 9) {
     label = 0;
     $54 = ($contactPatchCount$08|0)==(64);
     if ($54) {
      $$0 = 0;
      label = 15;
      break;
     }
     $55 = (($currentPatchData$05) + 2|0);
     HEAP16[$55>>1] = $count$06;
     $56 = (($fb) + (($contactPatchCount$08*12)|0)|0);
     $57 = (($contactPatchCount$08) + 1)|0;
     $58 = $$sum&65535;
     $59 = ((($cb) + ($$sum<<6)|0) + 48|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = $60&65535;
     $62 = $60 >>> 16;
     $63 = $62&65535;
     $64 = ((($cb) + ($$sum<<6)|0) + 52|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = $65&65535;
     HEAP16[$56>>1] = $58;
     $67 = ((($fb) + (($contactPatchCount$08*12)|0)|0) + 2|0);
     HEAP16[$67>>1] = 1;
     $68 = ((($fb) + (($contactPatchCount$08*12)|0)|0) + 4|0);
     HEAP16[$68>>1] = 0;
     $69 = ((($fb) + (($contactPatchCount$08*12)|0)|0) + 8|0);
     HEAP16[$69>>1] = $61;
     $70 = ((($fb) + (($contactPatchCount$08*12)|0)|0) + 10|0);
     HEAP16[$70>>1] = $63;
     $71 = ((($fb) + (($contactPatchCount$08*12)|0)|0) + 6|0);
     HEAP16[$71>>1] = $66;
     $contactPatchCount$1 = $57;$count$1 = 1;$currentPatchData$1 = $56;
    }
    $72 = (($i$07) + 1)|0;
    $73 = ($72>>>0)<($4>>>0);
    if ($73) {
     $contactPatchCount$08 = $contactPatchCount$1;$count$06 = $count$1;$currentPatchData$05 = $currentPatchData$1;$i$07 = $72;
    } else {
     break;
    }
   }
   if ((label|0) == 15) {
    STACKTOP = sp;return ($$0|0);
   }
   $74 = ($count$1<<16>>16)==(1);
   if ($74) {
    $contactPatchCount$2 = $contactPatchCount$1;
   } else {
    $75 = (($currentPatchData$1) + 2|0);
    HEAP16[$75>>1] = $count$1;
    $contactPatchCount$2 = $contactPatchCount$1;
   }
  } else {
   $contactPatchCount$2 = $8;
  }
 }
 HEAP32[$0>>2] = $contactPatchCount$2;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx16correlatePatchesERNS_20PxcCorrelationBufferERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjj($fb,$cb,$bodyFrame0,$bodyFrame1,$normalTolerance,$startContactPatchIndex,$startFrictionPatchIndex) {
 $fb = $fb|0;
 $cb = $cb|0;
 $bodyFrame0 = $bodyFrame0|0;
 $bodyFrame1 = $bodyFrame1|0;
 $normalTolerance = Math_fround($normalTolerance);
 $startContactPatchIndex = $startContactPatchIndex|0;
 $startFrictionPatchIndex = $startFrictionPatchIndex|0;
 var $$pre = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$014 = 0, $i1$09 = 0, $j$0$lcssa = 0, $j$08 = 0, $overflow$0$off0$lcssa = 0, $overflow$0$off011 = 0, $overflow$1$off0 = 0;
 var $overflow$2$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($fb) + 4232|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 $3 = ($2>>>0)>($startFrictionPatchIndex>>>0);
 if ($3) {
  $i$014 = $startFrictionPatchIndex;
  while(1) {
   $13 = ((($fb) + ($i$014<<2)|0) + 3968|0);
   HEAP32[$13>>2] = 65535;
   $14 = ((($fb) + ($i$014<<2)|0) + 3840|0);
   HEAP32[$14>>2] = 0;
   $15 = (($i$014) + 1)|0;
   $16 = HEAP32[$0>>2]|0;
   $17 = (($16) + 1)|0;
   $18 = ($15>>>0)<($17>>>0);
   if ($18) {
    $i$014 = $15;
   } else {
    $169 = $16;
    break;
   }
  }
 } else {
  $169 = $1;
 }
 $4 = (($fb) + 4228|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)>($startContactPatchIndex>>>0);
 if (!($6)) {
  $overflow$0$off0$lcssa = 0;
  STACKTOP = sp;return ($overflow$0$off0$lcssa|0);
 }
 $7 = (($bodyFrame0) + 12|0);
 $8 = (($bodyFrame0) + 4|0);
 $9 = (($bodyFrame0) + 8|0);
 $10 = (($bodyFrame1) + 12|0);
 $11 = (($bodyFrame1) + 4|0);
 $12 = (($bodyFrame1) + 8|0);
 $170 = $5;$67 = $169;$i1$09 = $startContactPatchIndex;$overflow$0$off011 = 0;
 while(1) {
  $19 = (($fb) + (($i1$09*12)|0)|0);
  $20 = HEAP16[$19>>1]|0;
  $21 = $20&65535;
  $22 = (($cb) + ($21<<6)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = ((($cb) + ($21<<6)|0) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($cb) + ($21<<6)|0) + 8|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($23 * Math_fround(2.0));
  $29 = Math_fround($25 * Math_fround(2.0));
  $30 = Math_fround($27 * Math_fround(2.0));
  $31 = Math_fround(HEAPF32[$7>>2]);
  $32 = Math_fround($31 * $31);
  $33 = Math_fround($32 + Math_fround(-0.5));
  $34 = Math_fround(HEAPF32[$bodyFrame0>>2]);
  $35 = Math_fround($28 * $34);
  $36 = Math_fround(HEAPF32[$8>>2]);
  $37 = Math_fround($29 * $36);
  $38 = Math_fround($35 + $37);
  $39 = Math_fround(HEAPF32[$9>>2]);
  $40 = Math_fround($30 * $39);
  $41 = Math_fround($38 + $40);
  $42 = Math_fround($28 * $33);
  $43 = Math_fround($30 * $36);
  $44 = Math_fround($29 * $39);
  $45 = Math_fround($43 - $44);
  $46 = Math_fround($31 * $45);
  $47 = Math_fround($42 - $46);
  $48 = Math_fround($34 * $41);
  $49 = Math_fround($48 + $47);
  $50 = Math_fround($29 * $33);
  $51 = Math_fround($28 * $39);
  $52 = Math_fround($30 * $34);
  $53 = Math_fround($51 - $52);
  $54 = Math_fround($31 * $53);
  $55 = Math_fround($50 - $54);
  $56 = Math_fround($36 * $41);
  $57 = Math_fround($56 + $55);
  $58 = Math_fround($30 * $33);
  $59 = Math_fround($29 * $34);
  $60 = Math_fround($28 * $36);
  $61 = Math_fround($59 - $60);
  $62 = Math_fround($31 * $61);
  $63 = Math_fround($58 - $62);
  $64 = Math_fround($39 * $41);
  $65 = Math_fround($63 + $64);
  $66 = ($67>>>0)>($startFrictionPatchIndex>>>0);
  L10: do {
   if ($66) {
    $68 = ((($fb) + (($i1$09*12)|0)|0) + 8|0);
    $69 = ((($fb) + (($i1$09*12)|0)|0) + 10|0);
    $j$08 = $startFrictionPatchIndex;
    while(1) {
     $70 = ((($fb) + (($j$08*96)|0)|0) + 792|0);
     $71 = Math_fround(HEAPF32[$70>>2]);
     $72 = Math_fround($49 * $71);
     $73 = ((($fb) + (($j$08*96)|0)|0) + 796|0);
     $74 = Math_fround(HEAPF32[$73>>2]);
     $75 = Math_fround($57 * $74);
     $76 = Math_fround($72 + $75);
     $77 = ((($fb) + (($j$08*96)|0)|0) + 800|0);
     $78 = Math_fround(HEAPF32[$77>>2]);
     $79 = Math_fround($65 * $78);
     $80 = Math_fround($76 + $79);
     $81 = $80 < $normalTolerance;
     if (!($81)) {
      $82 = ((($fb) + (($j$08*96)|0)|0) + 788|0);
      $83 = HEAP16[$82>>1]|0;
      $84 = HEAP16[$68>>1]|0;
      $85 = ($83<<16>>16)==($84<<16>>16);
      if ($85) {
       $86 = ((($fb) + (($j$08*96)|0)|0) + 786|0);
       $87 = HEAP16[$86>>1]|0;
       $88 = HEAP16[$69>>1]|0;
       $89 = ($87<<16>>16)==($88<<16>>16);
       if ($89) {
        $j$0$lcssa = $j$08;
        break L10;
       }
      }
     }
     $90 = (($j$08) + 1)|0;
     $91 = ($90>>>0)<($67>>>0);
     if ($91) {
      $j$08 = $90;
     } else {
      $j$0$lcssa = $90;
      break;
     }
    }
   } else {
    $j$0$lcssa = $startFrictionPatchIndex;
   }
  } while(0);
  $92 = ($j$0$lcssa|0)==($67|0);
  if ($92) {
   $93 = ($67|0)==(32);
   $94 = $overflow$0$off011 | $93;
   if ($94) {
    $168 = $170;$overflow$2$off0 = 1;
   } else {
    $95 = ((($fb) + ($67<<2)|0) + 4100|0);
    HEAP16[$95>>1] = -1;
    $96 = HEAP32[$0>>2]|0;
    $97 = ((($fb) + ($96<<2)|0) + 4102|0);
    HEAP16[$97>>1] = -1;
    $98 = HEAP32[$0>>2]|0;
    $99 = (($98) + 1)|0;
    HEAP32[$0>>2] = $99;
    $100 = Math_fround(HEAPF32[$10>>2]);
    $101 = Math_fround($100 * $100);
    $102 = Math_fround($101 + Math_fround(-0.5));
    $103 = Math_fround(HEAPF32[$bodyFrame1>>2]);
    $104 = Math_fround($28 * $103);
    $105 = Math_fround(HEAPF32[$11>>2]);
    $106 = Math_fround($29 * $105);
    $107 = Math_fround($104 + $106);
    $108 = Math_fround(HEAPF32[$12>>2]);
    $109 = Math_fround($30 * $108);
    $110 = Math_fround($107 + $109);
    $111 = Math_fround($28 * $102);
    $112 = Math_fround($30 * $105);
    $113 = Math_fround($29 * $108);
    $114 = Math_fround($112 - $113);
    $115 = Math_fround($100 * $114);
    $116 = Math_fround($111 - $115);
    $117 = Math_fround($103 * $110);
    $118 = Math_fround($117 + $116);
    $119 = Math_fround($29 * $102);
    $120 = Math_fround($28 * $108);
    $121 = Math_fround($30 * $103);
    $122 = Math_fround($120 - $121);
    $123 = Math_fround($100 * $122);
    $124 = Math_fround($119 - $123);
    $125 = Math_fround($105 * $110);
    $126 = Math_fround($125 + $124);
    $127 = Math_fround($30 * $102);
    $128 = Math_fround($29 * $103);
    $129 = Math_fround($28 * $105);
    $130 = Math_fround($128 - $129);
    $131 = Math_fround($100 * $130);
    $132 = Math_fround($127 - $131);
    $133 = Math_fround($108 * $110);
    $134 = Math_fround($132 + $133);
    $135 = ((($fb) + (($i1$09*12)|0)|0) + 8|0);
    $136 = HEAP16[$135>>1]|0;
    $137 = ((($fb) + (($i1$09*12)|0)|0) + 10|0);
    $138 = HEAP16[$137>>1]|0;
    $139 = ((($fb) + (($i1$09*12)|0)|0) + 6|0);
    $140 = HEAP16[$139>>1]|0;
    $141 = ((($fb) + (($98*96)|0)|0) + 792|0);
    HEAPF32[$141>>2] = $49;
    $142 = ((($fb) + (($98*96)|0)|0) + 796|0);
    HEAPF32[$142>>2] = $57;
    $143 = ((($fb) + (($98*96)|0)|0) + 800|0);
    HEAPF32[$143>>2] = $65;
    $144 = ((($fb) + (($98*96)|0)|0) + 804|0);
    HEAPF32[$144>>2] = $118;
    $145 = ((($fb) + (($98*96)|0)|0) + 808|0);
    HEAPF32[$145>>2] = $126;
    $146 = ((($fb) + (($98*96)|0)|0) + 812|0);
    HEAPF32[$146>>2] = $134;
    $147 = ((($fb) + (($98*96)|0)|0) + 784|0);
    HEAP16[$147>>1] = 0;
    $148 = ((($fb) + (($98*96)|0)|0) + 768|0);
    HEAP8[$148>>0] = 0;
    $149 = ((($fb) + (($98*96)|0)|0) + 788|0);
    HEAP16[$149>>1] = $136;
    $150 = ((($fb) + (($98*96)|0)|0) + 786|0);
    HEAP16[$150>>1] = $138;
    $151 = ((($fb) + (($98*96)|0)|0) + 790|0);
    HEAP16[$151>>1] = $140;
    $152 = (($67) + 1)|0;
    $153 = ($152>>>0)<(32);
    if ($153) {
     $154 = ((($fb) + ($152<<2)|0) + 3840|0);
     HEAP32[$154>>2] = 0;
     $155 = ((($fb) + ($152<<2)|0) + 3968|0);
     HEAP32[$155>>2] = 65535;
     $overflow$1$off0 = 0;
     label = 15;
    } else {
     $overflow$1$off0 = 0;
     label = 15;
    }
   }
  } else {
   $overflow$1$off0 = $overflow$0$off011;
   label = 15;
  }
  if ((label|0) == 15) {
   label = 0;
   $156 = ((($fb) + ($j$0$lcssa<<2)|0) + 3968|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = $157&65535;
   $159 = ((($fb) + (($i1$09*12)|0)|0) + 4|0);
   HEAP16[$159>>1] = $158;
   HEAP32[$156>>2] = $i1$09;
   $160 = ((($fb) + (($i1$09*12)|0)|0) + 2|0);
   $161 = HEAP16[$160>>1]|0;
   $162 = $161&65535;
   $163 = ((($fb) + ($j$0$lcssa<<2)|0) + 3840|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($164) + ($162))|0;
   HEAP32[$163>>2] = $165;
   $$pre = HEAP32[$4>>2]|0;
   $168 = $$pre;$overflow$2$off0 = $overflow$1$off0;
  }
  $166 = (($i1$09) + 1)|0;
  $167 = ($166>>>0)<($168>>>0);
  if (!($167)) {
   $overflow$0$off0$lcssa = $overflow$2$off0;
   break;
  }
  $$pre20 = HEAP32[$0>>2]|0;
  $170 = $168;$67 = $$pre20;$i1$09 = $166;$overflow$0$off011 = $overflow$2$off0;
 }
 STACKTOP = sp;return ($overflow$0$off0$lcssa|0);
}
function __ZN5physx23correlatePatchesCoulombERNS_27PxcCorrelationBufferCoulombERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjjj($fb,$cb,$bodyFrame0,$bodyFrame1,$normalTolerance,$numFrictionPerPoint,$startContactPatchIndex,$startFrictionPatchIndex) {
 $fb = $fb|0;
 $cb = $cb|0;
 $bodyFrame0 = $bodyFrame0|0;
 $bodyFrame1 = $bodyFrame1|0;
 $normalTolerance = Math_fround($normalTolerance);
 $numFrictionPerPoint = $numFrictionPerPoint|0;
 $startContactPatchIndex = $startContactPatchIndex|0;
 $startFrictionPatchIndex = $startFrictionPatchIndex|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = Math_fround(0), $frictionPatchCount$0$lcssa = 0, $frictionPatchCount$010 = 0, $frictionPatchCount$1 = 0, $frictionPatchCount$2 = 0, $i$08 = 0, $j$0$lcssa = 0, $j$07 = 0, $overflow$0$off0$lcssa = 0, $overflow$0$off011 = 0, $overflow$1$off0 = 0, $overflow$2$off0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($fb) + 1796|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($fb) + 1792|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)>($startContactPatchIndex>>>0);
 if ($4) {
  $84 = $3;$frictionPatchCount$010 = $1;$i$08 = $startContactPatchIndex;$overflow$0$off011 = 0;
 } else {
  $frictionPatchCount$0$lcssa = $1;$overflow$0$off0$lcssa = 0;
  HEAP32[$0>>2] = $frictionPatchCount$0$lcssa;
  STACKTOP = sp;return ($overflow$0$off0$lcssa|0);
 }
 while(1) {
  $5 = (($fb) + (($i$08*12)|0)|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = $6&65535;
  $8 = (($cb) + ($7<<6)|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = ((($cb) + ($7<<6)|0) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = ((($cb) + ($7<<6)|0) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = ((($fb) + (($i$08*12)|0)|0) + 2|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = $15&65535;
  $17 = Math_imul($16, $numFrictionPerPoint)|0;
  $18 = ($frictionPatchCount$010>>>0)>($startFrictionPatchIndex>>>0);
  L5: do {
   if ($18) {
    $19 = ((($fb) + (($i$08*12)|0)|0) + 8|0);
    $20 = ((($fb) + (($i$08*12)|0)|0) + 10|0);
    $j$07 = $startFrictionPatchIndex;
    while(1) {
     $21 = ((($fb) + (($j$07*20)|0)|0) + 768|0);
     $22 = Math_fround(HEAPF32[$21>>2]);
     $23 = Math_fround($9 * $22);
     $24 = ((($fb) + (($j$07*20)|0)|0) + 772|0);
     $25 = Math_fround(HEAPF32[$24>>2]);
     $26 = Math_fround($11 * $25);
     $27 = Math_fround($23 + $26);
     $28 = ((($fb) + (($j$07*20)|0)|0) + 776|0);
     $29 = Math_fround(HEAPF32[$28>>2]);
     $30 = Math_fround($13 * $29);
     $31 = Math_fround($27 + $30);
     $32 = $31 < $normalTolerance;
     if (!($32)) {
      $33 = ((($fb) + (($j$07*20)|0)|0) + 780|0);
      $34 = HEAP16[$33>>1]|0;
      $35 = HEAP16[$19>>1]|0;
      $36 = ($34<<16>>16)==($35<<16>>16);
      if ($36) {
       $37 = ((($fb) + (($j$07*20)|0)|0) + 782|0);
       $38 = HEAP16[$37>>1]|0;
       $39 = HEAP16[$20>>1]|0;
       $40 = ($38<<16>>16)==($39<<16>>16);
       if ($40) {
        $j$0$lcssa = $j$07;
        break L5;
       }
      }
     }
     $41 = (($j$07) + 1)|0;
     $42 = ($41>>>0)<($frictionPatchCount$010>>>0);
     if ($42) {
      $j$07 = $41;
     } else {
      $j$0$lcssa = $41;
      break;
     }
    }
   } else {
    $j$0$lcssa = $startFrictionPatchIndex;
   }
  } while(0);
  $43 = ($j$0$lcssa|0)==($frictionPatchCount$010|0);
  if ($43) {
   $44 = ($frictionPatchCount$010|0)==(32);
   $45 = $overflow$0$off011 | $44;
   if ($45) {
    $83 = $84;$frictionPatchCount$2 = $frictionPatchCount$010;$overflow$2$off0 = 1;
   } else {
    $46 = $17&65535;
    $47 = $46 & 255;
    $48 = ((($fb) + (($frictionPatchCount$010*20)|0)|0) + 784|0);
    HEAP16[$48>>1] = $47;
    $49 = ((($fb) + (($frictionPatchCount$010*20)|0)|0) + 768|0);
    HEAPF32[$49>>2] = $9;
    $50 = ((($fb) + (($frictionPatchCount$010*20)|0)|0) + 772|0);
    HEAPF32[$50>>2] = $11;
    $51 = ((($fb) + (($frictionPatchCount$010*20)|0)|0) + 776|0);
    HEAPF32[$51>>2] = $13;
    $52 = HEAP16[$14>>1]|0;
    $53 = $52&65535;
    $54 = ((($fb) + ($frictionPatchCount$010<<2)|0) + 1408|0);
    HEAP32[$54>>2] = $53;
    $55 = ((($fb) + (($i$08*12)|0)|0) + 8|0);
    $56 = HEAP16[$55>>1]|0;
    $57 = ((($fb) + (($frictionPatchCount$010*20)|0)|0) + 780|0);
    HEAP16[$57>>1] = $56;
    $58 = ((($fb) + (($i$08*12)|0)|0) + 10|0);
    $59 = HEAP16[$58>>1]|0;
    $60 = ((($fb) + (($frictionPatchCount$010*20)|0)|0) + 782|0);
    HEAP16[$60>>1] = $59;
    $61 = ((($fb) + (($i$08*12)|0)|0) + 6|0);
    $62 = HEAP16[$61>>1]|0;
    $63 = ((($fb) + (($frictionPatchCount$010*20)|0)|0) + 786|0);
    HEAP16[$63>>1] = $62;
    $64 = ((($fb) + ($frictionPatchCount$010<<2)|0) + 1664|0);
    HEAP16[$64>>1] = -1;
    $65 = (($frictionPatchCount$010) + 1)|0;
    $66 = ((($fb) + ($frictionPatchCount$010<<2)|0) + 1666|0);
    HEAP16[$66>>1] = -1;
    $67 = ((($fb) + (($i$08*12)|0)|0) + 4|0);
    HEAP16[$67>>1] = -1;
    $$pre16 = ((($fb) + ($j$0$lcssa<<2)|0) + 1536|0);
    $$pre$phiZ2D = $$pre16;$frictionPatchCount$1 = $65;$overflow$1$off0 = 0;
    label = 12;
   }
  } else {
   $68 = $17 & 255;
   $69 = ((($fb) + (($j$0$lcssa*20)|0)|0) + 784|0);
   $70 = HEAP16[$69>>1]|0;
   $71 = $70&65535;
   $72 = (($71) + ($68))|0;
   $73 = $72&65535;
   HEAP16[$69>>1] = $73;
   $74 = ((($fb) + ($j$0$lcssa<<2)|0) + 1408|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($75) + ($16))|0;
   HEAP32[$74>>2] = $76;
   $77 = ((($fb) + ($j$0$lcssa<<2)|0) + 1536|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = $78&65535;
   $80 = ((($fb) + (($i$08*12)|0)|0) + 4|0);
   HEAP16[$80>>1] = $79;
   $$pre$phiZ2D = $77;$frictionPatchCount$1 = $frictionPatchCount$010;$overflow$1$off0 = $overflow$0$off011;
   label = 12;
  }
  if ((label|0) == 12) {
   label = 0;
   HEAP32[$$pre$phiZ2D>>2] = $i$08;
   $$pre = HEAP32[$2>>2]|0;
   $83 = $$pre;$frictionPatchCount$2 = $frictionPatchCount$1;$overflow$2$off0 = $overflow$1$off0;
  }
  $81 = (($i$08) + 1)|0;
  $82 = ($81>>>0)<($83>>>0);
  if ($82) {
   $84 = $83;$frictionPatchCount$010 = $frictionPatchCount$2;$i$08 = $81;$overflow$0$off011 = $overflow$2$off0;
  } else {
   $frictionPatchCount$0$lcssa = $frictionPatchCount$2;$overflow$0$off0$lcssa = $overflow$2$off0;
   break;
  }
 }
 HEAP32[$0>>2] = $frictionPatchCount$0$lcssa;
 STACKTOP = sp;return ($overflow$0$off0$lcssa|0);
}
function __ZN5physx11growPatchesERNS_20PxcCorrelationBufferERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjf($fb,$cb,$bodyFrame0,$bodyFrame1,$0,$frictionPatchStartIndex,$frictionOffsetThreshold) {
 $fb = $fb|0;
 $cb = $cb|0;
 $bodyFrame0 = $bodyFrame0|0;
 $bodyFrame1 = $bodyFrame1|0;
 $0 = Math_fround($0);
 $frictionPatchStartIndex = $frictionPatchStartIndex|0;
 $frictionOffsetThreshold = Math_fround($frictionOffsetThreshold);
 var $$pre = 0, $$pre38 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $anchorCount$0 = 0, $anchorCount$125 = 0, $anchorCount$2$lcssa = 0, $anchorCount$220 = 0, $anchorCount$3 = 0, $exitcond = 0;
 var $i$032 = 0, $j$021 = 0, $j1$028 = 0, $patch$024 = 0, $pointDistSq$023 = Math_fround(0), $pointDistSq$1$lcssa = Math_fround(0), $pointDistSq$119 = Math_fround(0), $pointDistSq$2 = Math_fround(0), $worldAnchors = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $worldAnchors = sp;
 $1 = (($fb) + 4232|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>($frictionPatchStartIndex>>>0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($bodyFrame0) + 12|0);
 $5 = (($bodyFrame0) + 4|0);
 $6 = (($bodyFrame0) + 8|0);
 $7 = (($bodyFrame0) + 16|0);
 $8 = (($bodyFrame0) + 20|0);
 $9 = (($bodyFrame0) + 24|0);
 $10 = (($worldAnchors) + 4|0);
 $11 = (($worldAnchors) + 8|0);
 $12 = (($bodyFrame1) + 16|0);
 $13 = (($bodyFrame1) + 20|0);
 $14 = (($bodyFrame1) + 24|0);
 $15 = (($bodyFrame1) + 12|0);
 $16 = (($bodyFrame1) + 4|0);
 $17 = (($bodyFrame1) + 8|0);
 $18 = (($worldAnchors) + 12|0);
 $19 = (($worldAnchors) + 16|0);
 $20 = (($worldAnchors) + 20|0);
 $272 = $2;$i$032 = $frictionPatchStartIndex;
 while(1) {
  $21 = ((($fb) + (($i$032*96)|0)|0) + 784|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = ($22<<16>>16)==(2);
  if ($23) {
   $271 = $272;
  } else {
   $24 = ((($fb) + ($i$032<<2)|0) + 3968|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(65535);
   if ($26) {
    $271 = $272;
   } else {
    $27 = ($22<<16>>16)==(1);
    if ($27) {
     $28 = ((($fb) + (($i$032*96)|0)|0) + 816|0);
     $29 = Math_fround(HEAPF32[$28>>2]);
     $30 = Math_fround($29 * Math_fround(2.0));
     $31 = ((($fb) + (($i$032*96)|0)|0) + 820|0);
     $32 = Math_fround(HEAPF32[$31>>2]);
     $33 = Math_fround($32 * Math_fround(2.0));
     $34 = ((($fb) + (($i$032*96)|0)|0) + 824|0);
     $35 = Math_fround(HEAPF32[$34>>2]);
     $36 = Math_fround($35 * Math_fround(2.0));
     $37 = Math_fround(HEAPF32[$4>>2]);
     $38 = Math_fround($37 * $37);
     $39 = Math_fround($38 + Math_fround(-0.5));
     $40 = Math_fround(HEAPF32[$bodyFrame0>>2]);
     $41 = Math_fround($30 * $40);
     $42 = Math_fround(HEAPF32[$5>>2]);
     $43 = Math_fround($33 * $42);
     $44 = Math_fround($41 + $43);
     $45 = Math_fround(HEAPF32[$6>>2]);
     $46 = Math_fround($36 * $45);
     $47 = Math_fround($44 + $46);
     $48 = Math_fround($30 * $39);
     $49 = Math_fround($36 * $42);
     $50 = Math_fround($33 * $45);
     $51 = Math_fround($49 - $50);
     $52 = Math_fround($37 * $51);
     $53 = Math_fround($48 + $52);
     $54 = Math_fround($40 * $47);
     $55 = Math_fround($54 + $53);
     $56 = Math_fround($33 * $39);
     $57 = Math_fround($30 * $45);
     $58 = Math_fround($36 * $40);
     $59 = Math_fround($57 - $58);
     $60 = Math_fround($37 * $59);
     $61 = Math_fround($56 + $60);
     $62 = Math_fround($42 * $47);
     $63 = Math_fround($62 + $61);
     $64 = Math_fround($36 * $39);
     $65 = Math_fround($33 * $40);
     $66 = Math_fround($30 * $42);
     $67 = Math_fround($65 - $66);
     $68 = Math_fround($37 * $67);
     $69 = Math_fround($64 + $68);
     $70 = Math_fround($45 * $47);
     $71 = Math_fround($69 + $70);
     $72 = Math_fround(HEAPF32[$7>>2]);
     $73 = Math_fround($72 + $55);
     $74 = Math_fround(HEAPF32[$8>>2]);
     $75 = Math_fround($74 + $63);
     $76 = Math_fround(HEAPF32[$9>>2]);
     $77 = Math_fround($76 + $71);
     HEAPF32[$worldAnchors>>2] = $73;
     HEAPF32[$10>>2] = $75;
     HEAPF32[$11>>2] = $77;
     $anchorCount$0 = 1;
    } else {
     $anchorCount$0 = 0;
    }
    $78 = ((($fb) + ($i$032<<2)|0) + 4102|0);
    $79 = ((($fb) + ($i$032<<2)|0) + 4100|0);
    $anchorCount$125 = $anchorCount$0;$patch$024 = $25;$pointDistSq$023 = Math_fround(0.0);
    while(1) {
     $80 = ((($fb) + (($patch$024*12)|0)|0) + 2|0);
     $81 = HEAP16[$80>>1]|0;
     $82 = ($81<<16>>16)==(0);
     if ($82) {
      $anchorCount$2$lcssa = $anchorCount$125;$pointDistSq$1$lcssa = $pointDistSq$023;
     } else {
      $83 = (($fb) + (($patch$024*12)|0)|0);
      $anchorCount$220 = $anchorCount$125;$j$021 = 0;$pointDistSq$119 = $pointDistSq$023;
      while(1) {
       $84 = $j$021&65535;
       $85 = HEAP16[$83>>1]|0;
       $86 = $85&65535;
       $87 = (($86) + ($84))|0;
       $88 = ((($cb) + ($87<<6)|0) + 16|0);
       $89 = ((($cb) + ($87<<6)|0) + 12|0);
       $90 = Math_fround(HEAPF32[$89>>2]);
       $91 = $90 < $frictionOffsetThreshold;
       do {
        if ($91) {
         $92 = $anchorCount$220&65535;
         if ((($92|0) == 0)) {
          $93 = $87&65535;
          HEAP16[$79>>1] = $93;
          $94 = Math_fround(HEAPF32[$88>>2]);
          HEAPF32[$worldAnchors>>2] = $94;
          $95 = ((($cb) + ($87<<6)|0) + 20|0);
          $96 = Math_fround(HEAPF32[$95>>2]);
          HEAPF32[$10>>2] = $96;
          $97 = ((($cb) + ($87<<6)|0) + 24|0);
          $98 = Math_fround(HEAPF32[$97>>2]);
          HEAPF32[$11>>2] = $98;
          $99 = (($anchorCount$220) + 1)<<16>>16;
          $anchorCount$3 = $99;$pointDistSq$2 = $pointDistSq$119;
          break;
         } else if ((($92|0) == 1)) {
          $100 = Math_fround(HEAPF32[$88>>2]);
          $101 = Math_fround(HEAPF32[$worldAnchors>>2]);
          $102 = Math_fround($100 - $101);
          $103 = ((($cb) + ($87<<6)|0) + 20|0);
          $104 = Math_fround(HEAPF32[$103>>2]);
          $105 = Math_fround(HEAPF32[$10>>2]);
          $106 = Math_fround($104 - $105);
          $107 = ((($cb) + ($87<<6)|0) + 24|0);
          $108 = Math_fround(HEAPF32[$107>>2]);
          $109 = Math_fround(HEAPF32[$11>>2]);
          $110 = Math_fround($108 - $109);
          $111 = Math_fround($102 * $102);
          $112 = Math_fround($106 * $106);
          $113 = Math_fround($111 + $112);
          $114 = Math_fround($110 * $110);
          $115 = Math_fround($113 + $114);
          $116 = $115 > Math_fround(6.25000044237822294235E-4);
          if (!($116)) {
           $anchorCount$3 = $anchorCount$220;$pointDistSq$2 = $115;
           break;
          }
          $117 = $87&65535;
          HEAP16[$78>>1] = $117;
          HEAPF32[$18>>2] = $100;
          HEAPF32[$19>>2] = $104;
          HEAPF32[$20>>2] = $108;
          $118 = (($anchorCount$220) + 1)<<16>>16;
          $anchorCount$3 = $118;$pointDistSq$2 = $115;
          break;
         } else {
          $119 = Math_fround(HEAPF32[$88>>2]);
          $120 = Math_fround(HEAPF32[$worldAnchors>>2]);
          $121 = Math_fround($119 - $120);
          $122 = ((($cb) + ($87<<6)|0) + 20|0);
          $123 = Math_fround(HEAPF32[$122>>2]);
          $124 = Math_fround(HEAPF32[$10>>2]);
          $125 = Math_fround($123 - $124);
          $126 = ((($cb) + ($87<<6)|0) + 24|0);
          $127 = Math_fround(HEAPF32[$126>>2]);
          $128 = Math_fround(HEAPF32[$11>>2]);
          $129 = Math_fround($127 - $128);
          $130 = Math_fround($121 * $121);
          $131 = Math_fround($125 * $125);
          $132 = Math_fround($130 + $131);
          $133 = Math_fround($129 * $129);
          $134 = Math_fround($132 + $133);
          $135 = Math_fround(HEAPF32[$18>>2]);
          $136 = Math_fround($119 - $135);
          $137 = Math_fround(HEAPF32[$19>>2]);
          $138 = Math_fround($123 - $137);
          $139 = Math_fround(HEAPF32[$20>>2]);
          $140 = Math_fround($127 - $139);
          $141 = Math_fround($136 * $136);
          $142 = Math_fround($138 * $138);
          $143 = Math_fround($141 + $142);
          $144 = Math_fround($140 * $140);
          $145 = Math_fround($143 + $144);
          $146 = $134 > $145;
          if ($146) {
           $147 = $134 > $pointDistSq$119;
           if (!($147)) {
            $anchorCount$3 = $anchorCount$220;$pointDistSq$2 = $pointDistSq$119;
            break;
           }
           $148 = $87&65535;
           HEAP16[$78>>1] = $148;
           HEAPF32[$18>>2] = $119;
           HEAPF32[$19>>2] = $123;
           HEAPF32[$20>>2] = $127;
           $anchorCount$3 = $anchorCount$220;$pointDistSq$2 = $134;
           break;
          } else {
           $149 = $145 > $pointDistSq$119;
           if (!($149)) {
            $anchorCount$3 = $anchorCount$220;$pointDistSq$2 = $pointDistSq$119;
            break;
           }
           $150 = $87&65535;
           HEAP16[$79>>1] = $150;
           HEAPF32[$worldAnchors>>2] = $119;
           HEAPF32[$10>>2] = $123;
           HEAPF32[$11>>2] = $127;
           $anchorCount$3 = $anchorCount$220;$pointDistSq$2 = $145;
           break;
          }
         }
        } else {
         $anchorCount$3 = $anchorCount$220;$pointDistSq$2 = $pointDistSq$119;
        }
       } while(0);
       $151 = (($j$021) + 1)<<16>>16;
       $152 = HEAP16[$80>>1]|0;
       $153 = ($151&65535)<($152&65535);
       if ($153) {
        $anchorCount$220 = $anchorCount$3;$j$021 = $151;$pointDistSq$119 = $pointDistSq$2;
       } else {
        $anchorCount$2$lcssa = $anchorCount$3;$pointDistSq$1$lcssa = $pointDistSq$2;
        break;
       }
      }
     }
     $154 = ((($fb) + (($patch$024*12)|0)|0) + 4|0);
     $155 = HEAP16[$154>>1]|0;
     $156 = $155&65535;
     $157 = ($155<<16>>16)==(-1);
     if ($157) {
      break;
     } else {
      $anchorCount$125 = $anchorCount$2$lcssa;$patch$024 = $156;$pointDistSq$023 = $pointDistSq$1$lcssa;
     }
    }
    $$pre38 = HEAP16[$21>>1]|0;
    $158 = ($$pre38&65535)<($anchorCount$2$lcssa&65535);
    if ($158) {
     $159 = $$pre38&65535;
     $160 = $anchorCount$2$lcssa&65535;
     $j1$028 = $159;
     while(1) {
      $161 = (($worldAnchors) + (($j1$028*12)|0)|0);
      $162 = Math_fround(HEAPF32[$161>>2]);
      $163 = Math_fround(HEAPF32[$7>>2]);
      $164 = Math_fround($162 - $163);
      $165 = ((($worldAnchors) + (($j1$028*12)|0)|0) + 4|0);
      $166 = Math_fround(HEAPF32[$165>>2]);
      $167 = Math_fround(HEAPF32[$8>>2]);
      $168 = Math_fround($166 - $167);
      $169 = ((($worldAnchors) + (($j1$028*12)|0)|0) + 8|0);
      $170 = Math_fround(HEAPF32[$169>>2]);
      $171 = Math_fround(HEAPF32[$9>>2]);
      $172 = Math_fround($170 - $171);
      $173 = Math_fround($164 * Math_fround(2.0));
      $174 = Math_fround($168 * Math_fround(2.0));
      $175 = Math_fround($172 * Math_fround(2.0));
      $176 = Math_fround(HEAPF32[$4>>2]);
      $177 = Math_fround($176 * $176);
      $178 = Math_fround($177 + Math_fround(-0.5));
      $179 = Math_fround(HEAPF32[$bodyFrame0>>2]);
      $180 = Math_fround($173 * $179);
      $181 = Math_fround(HEAPF32[$5>>2]);
      $182 = Math_fround($174 * $181);
      $183 = Math_fround($180 + $182);
      $184 = Math_fround(HEAPF32[$6>>2]);
      $185 = Math_fround($175 * $184);
      $186 = Math_fround($183 + $185);
      $187 = Math_fround($173 * $178);
      $188 = Math_fround($175 * $181);
      $189 = Math_fround($174 * $184);
      $190 = Math_fround($188 - $189);
      $191 = Math_fround($176 * $190);
      $192 = Math_fround($187 - $191);
      $193 = Math_fround($179 * $186);
      $194 = Math_fround($193 + $192);
      $195 = Math_fround($174 * $178);
      $196 = Math_fround($173 * $184);
      $197 = Math_fround($175 * $179);
      $198 = Math_fround($196 - $197);
      $199 = Math_fround($176 * $198);
      $200 = Math_fround($195 - $199);
      $201 = Math_fround($181 * $186);
      $202 = Math_fround($201 + $200);
      $203 = Math_fround($175 * $178);
      $204 = Math_fround($174 * $179);
      $205 = Math_fround($173 * $181);
      $206 = Math_fround($204 - $205);
      $207 = Math_fround($176 * $206);
      $208 = Math_fround($203 - $207);
      $209 = Math_fround($184 * $186);
      $210 = Math_fround($208 + $209);
      $211 = (((($fb) + (($i$032*96)|0)|0) + (($j1$028*12)|0)|0) + 816|0);
      HEAPF32[$211>>2] = $194;
      $212 = (((($fb) + (($i$032*96)|0)|0) + (($j1$028*12)|0)|0) + 820|0);
      HEAPF32[$212>>2] = $202;
      $213 = (((($fb) + (($i$032*96)|0)|0) + (($j1$028*12)|0)|0) + 824|0);
      HEAPF32[$213>>2] = $210;
      $214 = Math_fround(HEAPF32[$12>>2]);
      $215 = Math_fround($162 - $214);
      $216 = Math_fround(HEAPF32[$13>>2]);
      $217 = Math_fround($166 - $216);
      $218 = Math_fround(HEAPF32[$14>>2]);
      $219 = Math_fround($170 - $218);
      $220 = Math_fround($215 * Math_fround(2.0));
      $221 = Math_fround($217 * Math_fround(2.0));
      $222 = Math_fround($219 * Math_fround(2.0));
      $223 = Math_fround(HEAPF32[$15>>2]);
      $224 = Math_fround($223 * $223);
      $225 = Math_fround($224 + Math_fround(-0.5));
      $226 = Math_fround(HEAPF32[$bodyFrame1>>2]);
      $227 = Math_fround($220 * $226);
      $228 = Math_fround(HEAPF32[$16>>2]);
      $229 = Math_fround($221 * $228);
      $230 = Math_fround($227 + $229);
      $231 = Math_fround(HEAPF32[$17>>2]);
      $232 = Math_fround($222 * $231);
      $233 = Math_fround($230 + $232);
      $234 = Math_fround($220 * $225);
      $235 = Math_fround($222 * $228);
      $236 = Math_fround($221 * $231);
      $237 = Math_fround($235 - $236);
      $238 = Math_fround($223 * $237);
      $239 = Math_fround($234 - $238);
      $240 = Math_fround($226 * $233);
      $241 = Math_fround($240 + $239);
      $242 = Math_fround($221 * $225);
      $243 = Math_fround($220 * $231);
      $244 = Math_fround($222 * $226);
      $245 = Math_fround($243 - $244);
      $246 = Math_fround($223 * $245);
      $247 = Math_fround($242 - $246);
      $248 = Math_fround($228 * $233);
      $249 = Math_fround($248 + $247);
      $250 = Math_fround($222 * $225);
      $251 = Math_fround($221 * $226);
      $252 = Math_fround($220 * $228);
      $253 = Math_fround($251 - $252);
      $254 = Math_fround($223 * $253);
      $255 = Math_fround($250 - $254);
      $256 = Math_fround($231 * $233);
      $257 = Math_fround($255 + $256);
      $258 = (((($fb) + (($i$032*96)|0)|0) + (($j1$028*12)|0)|0) + 840|0);
      HEAPF32[$258>>2] = $241;
      $259 = (((($fb) + (($i$032*96)|0)|0) + (($j1$028*12)|0)|0) + 844|0);
      HEAPF32[$259>>2] = $249;
      $260 = (((($fb) + (($i$032*96)|0)|0) + (($j1$028*12)|0)|0) + 848|0);
      HEAPF32[$260>>2] = $257;
      $261 = (($j1$028) + 1)|0;
      $exitcond = ($261|0)==($160|0);
      if ($exitcond) {
       break;
      } else {
       $j1$028 = $261;
      }
     }
    }
    $262 = ($anchorCount$2$lcssa<<16>>16)==(0);
    if ($262) {
     $263 = ((($fb) + (($i$032*96)|0)|0) + 840|0);
     HEAPF32[$263>>2] = Math_fround(0.0);
     $264 = ((($fb) + (($i$032*96)|0)|0) + 844|0);
     HEAPF32[$264>>2] = Math_fround(0.0);
     $265 = ((($fb) + (($i$032*96)|0)|0) + 848|0);
     HEAPF32[$265>>2] = Math_fround(0.0);
     $266 = ((($fb) + (($i$032*96)|0)|0) + 816|0);
     HEAPF32[$266>>2] = Math_fround(0.0);
     $267 = ((($fb) + (($i$032*96)|0)|0) + 820|0);
     HEAPF32[$267>>2] = Math_fround(0.0);
     $268 = ((($fb) + (($i$032*96)|0)|0) + 824|0);
     HEAPF32[$268>>2] = Math_fround(0.0);
    }
    HEAP16[$21>>1] = $anchorCount$2$lcssa;
    $$pre = HEAP32[$1>>2]|0;
    $271 = $$pre;
   }
  }
  $269 = (($i$032) + 1)|0;
  $270 = ($269>>>0)<($271>>>0);
  if ($270) {
   $272 = $271;$i$032 = $269;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx26PxcFrictionPatchStreamPair5resetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx26PxcFrictionPatchStreamPairC2ERNS_17PxcNpMemBlockPoolE($this,$blockPool) {
 $this = $this|0;
 $blockPool = $blockPool|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $blockPool;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx25PxcGetMaterialHeightFieldEPKNS_12PxsShapeCoreEjRNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($shape,$index,$context,$materialInfo) {
 $shape = $shape|0;
 $index = $index|0;
 $context = $context|0;
 $materialInfo = $materialInfo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var $i1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + 68|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1&65535)<(2);
 if ($2) {
  $3 = (($context) + 4480|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   STACKTOP = sp;return 1;
  }
  $6 = (($shape) + 34|0);
  $i$01 = 0;
  while(1) {
   $7 = HEAP16[$6>>1]|0;
   $8 = (($materialInfo) + ($i$01<<2)|0);
   $9 = (($8) + ($index<<1)|0);
   HEAP16[$9>>1] = $7;
   $10 = (($i$01) + 1)|0;
   $11 = ($10>>>0)<($4>>>0);
   if ($11) {
    $i$01 = $10;
   } else {
    break;
   }
  }
  STACKTOP = sp;return 1;
 } else {
  $12 = (($shape) + 64|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($context) + 4480|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0);
  if ($16) {
   STACKTOP = sp;return 1;
  }
  $17 = (($shape) + 60|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 20|0);
  $$pre = HEAP32[$19>>2]|0;
  $i1$03 = 0;
  while(1) {
   $20 = ((($context) + ($i1$03<<6)|0) + 432|0);
   $21 = (($20) + ($index<<2)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = $22 >>> 1;
   $24 = $22 & 1;
   $25 = ($24|0)==(0);
   $26 = ((($$pre) + ($23<<2)|0) + 2|0);
   $27 = ((($$pre) + ($23<<2)|0) + 3|0);
   $28 = $25 ? $26 : $27;
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = $30 & 127;
   $32 = (($13) + ($31<<1)|0);
   $33 = HEAP16[$32>>1]|0;
   $34 = (($materialInfo) + ($i1$03<<2)|0);
   $35 = (($34) + ($index<<1)|0);
   HEAP16[$35>>1] = $33;
   $36 = (($i1$03) + 1)|0;
   $37 = ($36>>>0)<($15>>>0);
   if ($37) {
    $i1$03 = $36;
   } else {
    break;
   }
  }
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5physx30PxcGetMaterialShapeHeightFieldEPKNS_12PxsShapeCoreES2_RNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($shape0,$shape1,$context,$materialInfo) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $context = $context|0;
 $materialInfo = $materialInfo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape1) + 68|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1&65535)<(2);
 if ($2) {
  $3 = (($context) + 4480|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   STACKTOP = sp;return 1;
  }
  $6 = (($shape0) + 34|0);
  $7 = (($shape1) + 34|0);
  $i$01 = 0;
  while(1) {
   $8 = HEAP16[$6>>1]|0;
   $9 = (($materialInfo) + ($i$01<<2)|0);
   HEAP16[$9>>1] = $8;
   $10 = HEAP16[$7>>1]|0;
   $11 = ((($materialInfo) + ($i$01<<2)|0) + 2|0);
   HEAP16[$11>>1] = $10;
   $12 = (($i$01) + 1)|0;
   $13 = ($12>>>0)<($4>>>0);
   if ($13) {
    $i$01 = $12;
   } else {
    break;
   }
  }
  STACKTOP = sp;return 1;
 } else {
  $14 = (($shape1) + 64|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($context) + 4480|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if ($18) {
   STACKTOP = sp;return 1;
  }
  $19 = (($shape1) + 60|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($shape0) + 34|0);
  $22 = (($20) + 20|0);
  $$pre = HEAP32[$22>>2]|0;
  $i1$03 = 0;
  while(1) {
   $23 = HEAP16[$21>>1]|0;
   $24 = (($materialInfo) + ($i1$03<<2)|0);
   HEAP16[$24>>1] = $23;
   $25 = ((($context) + ($i1$03<<6)|0) + 436|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = $26 >>> 1;
   $28 = $26 & 1;
   $29 = ($28|0)==(0);
   $30 = ((($$pre) + ($27<<2)|0) + 2|0);
   $31 = ((($$pre) + ($27<<2)|0) + 3|0);
   $32 = $29 ? $30 : $31;
   $33 = HEAP8[$32>>0]|0;
   $34 = $33&255;
   $35 = $34 & 127;
   $36 = (($15) + ($35<<1)|0);
   $37 = HEAP16[$36>>1]|0;
   $38 = ((($materialInfo) + ($i1$03<<2)|0) + 2|0);
   HEAP16[$38>>1] = $37;
   $39 = (($i1$03) + 1)|0;
   $40 = ($39>>>0)<($17>>>0);
   if ($40) {
    $i1$03 = $39;
   } else {
    break;
   }
  }
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5physx18PxcGetMaterialMeshEPKNS_12PxsShapeCoreEjRNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($shape,$index,$context,$materialInfo) {
 $shape = $shape|0;
 $index = $index|0;
 $context = $context|0;
 $materialInfo = $materialInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i1$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + 88|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1&65535)<(2);
 $3 = (($context) + 4480|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($2) {
  if ($5) {
   STACKTOP = sp;return 1;
  }
  $10 = (($shape) + 34|0);
  $i$01 = 0;
  while(1) {
   $11 = HEAP16[$10>>1]|0;
   $12 = (($materialInfo) + ($i$01<<2)|0);
   $13 = (($12) + ($index<<1)|0);
   HEAP16[$13>>1] = $11;
   $14 = (($i$01) + 1)|0;
   $15 = ($14>>>0)<($4>>>0);
   if ($15) {
    $i$01 = $14;
   } else {
    break;
   }
  }
  STACKTOP = sp;return 1;
 } else {
  if ($5) {
   STACKTOP = sp;return 1;
  }
  $6 = (($shape) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($shape) + 84|0);
  $9 = HEAP32[$8>>2]|0;
  $i1$04 = 0;
  while(1) {
   $16 = ((($context) + ($i1$04<<6)|0) + 432|0);
   $17 = (($16) + ($index<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($7) + ($18<<1)|0);
   $20 = HEAP16[$19>>1]|0;
   $21 = $20&65535;
   $22 = (($9) + ($21<<1)|0);
   $23 = HEAP16[$22>>1]|0;
   $24 = (($materialInfo) + ($i1$04<<2)|0);
   $25 = (($24) + ($index<<1)|0);
   HEAP16[$25>>1] = $23;
   $26 = (($i1$04) + 1)|0;
   $27 = ($26>>>0)<($4>>>0);
   if ($27) {
    $i1$04 = $26;
   } else {
    break;
   }
  }
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5physx23PxcGetMaterialShapeMeshEPKNS_12PxsShapeCoreES2_RNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($shape0,$shape1,$context,$materialInfo) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $context = $context|0;
 $materialInfo = $materialInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i1$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape1) + 88|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1&65535)<(2);
 $3 = (($context) + 4480|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($2) {
  if ($5) {
   STACKTOP = sp;return 1;
  }
  $11 = (($shape0) + 34|0);
  $12 = (($shape1) + 34|0);
  $i$01 = 0;
  while(1) {
   $13 = HEAP16[$11>>1]|0;
   $14 = (($materialInfo) + ($i$01<<2)|0);
   HEAP16[$14>>1] = $13;
   $15 = HEAP16[$12>>1]|0;
   $16 = ((($materialInfo) + ($i$01<<2)|0) + 2|0);
   HEAP16[$16>>1] = $15;
   $17 = (($i$01) + 1)|0;
   $18 = ($17>>>0)<($4>>>0);
   if ($18) {
    $i$01 = $17;
   } else {
    break;
   }
  }
  STACKTOP = sp;return 1;
 } else {
  if ($5) {
   STACKTOP = sp;return 1;
  }
  $6 = (($shape0) + 34|0);
  $7 = (($shape1) + 80|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($shape1) + 84|0);
  $10 = HEAP32[$9>>2]|0;
  $i1$04 = 0;
  while(1) {
   $19 = HEAP16[$6>>1]|0;
   $20 = (($materialInfo) + ($i1$04<<2)|0);
   HEAP16[$20>>1] = $19;
   $21 = ((($context) + ($i1$04<<6)|0) + 436|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($8) + ($22<<1)|0);
   $24 = HEAP16[$23>>1]|0;
   $25 = $24&65535;
   $26 = (($10) + ($25<<1)|0);
   $27 = HEAP16[$26>>1]|0;
   $28 = ((($materialInfo) + ($i1$04<<2)|0) + 2|0);
   HEAP16[$28>>1] = $27;
   $29 = (($i1$04) + 1)|0;
   $30 = ($29>>>0)<($4>>>0);
   if ($30) {
    $i1$04 = $29;
   } else {
    break;
   }
  }
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5physx19PxcGetMaterialShapeEPKNS_12PxsShapeCoreEjRNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($shape,$index,$context,$materialInfo) {
 $shape = $shape|0;
 $index = $index|0;
 $context = $context|0;
 $materialInfo = $materialInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($context) + 4480|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return 1;
 }
 $3 = (($shape) + 34|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP16[$3>>1]|0;
  $5 = (($materialInfo) + ($i$01<<2)|0);
  $6 = (($5) + ($index<<1)|0);
  HEAP16[$6>>1] = $4;
  $7 = (($i$01) + 1)|0;
  $8 = ($7>>>0)<($1>>>0);
  if ($8) {
   $i$01 = $7;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN5physx24PxcGetMaterialShapeShapeEPKNS_12PxsShapeCoreES2_RNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($shape0,$shape1,$context,$materialInfo) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $context = $context|0;
 $materialInfo = $materialInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($context) + 4480|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return 1;
 }
 $3 = (($shape0) + 34|0);
 $4 = (($shape1) + 34|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP16[$3>>1]|0;
  $6 = (($materialInfo) + ($i$01<<2)|0);
  HEAP16[$6>>1] = $5;
  $7 = HEAP16[$4>>1]|0;
  $8 = ((($materialInfo) + ($i$01<<2)|0) + 2|0);
  HEAP16[$8>>1] = $7;
  $9 = (($i$01) + 1)|0;
  $10 = ($9>>>0)<($1>>>0);
  if ($10) {
   $i$01 = $9;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function __Z13runNpBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($context,$entries,$numEntriesStart,$numEntriesEnd,$changeBitmapBase,$changeBitmapWordCount,$_touchLost,$_touchFound) {
 $context = $context|0;
 $entries = $entries|0;
 $numEntriesStart = $numEntriesStart|0;
 $numEntriesEnd = $numEntriesEnd|0;
 $changeBitmapBase = $changeBitmapBase|0;
 $changeBitmapWordCount = $changeBitmapWordCount|0;
 $_touchLost = $_touchLost|0;
 $_touchFound = $_touchFound|0;
 var $$ = 0, $$23 = 0, $$24 = 0, $$25 = 0, $$26 = 0, $$27 = 0, $$28 = 0, $$29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0);
 var $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0);
 var $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0);
 var $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0);
 var $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0);
 var $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0);
 var $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0);
 var $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0;
 var $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0);
 var $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0;
 var $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0;
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0);
 var $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0);
 var $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0);
 var $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0;
 var $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0);
 var $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = 0;
 var $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0);
 var $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0);
 var $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = 0, $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = 0;
 var $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0);
 var $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = 0, $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = 0, $551 = Math_fround(0), $552 = Math_fround(0), $553 = 0, $554 = Math_fround(0), $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0);
 var $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = 0, $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0);
 var $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = 0, $595 = Math_fround(0);
 var $596 = Math_fround(0), $597 = 0, $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = 0, $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = 0, $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0);
 var $613 = 0, $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0);
 var $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0;
 var $65 = Math_fround(0), $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = Math_fround(0), $658 = 0, $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = Math_fround(0), $667 = 0;
 var $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = Math_fround(0), $677 = Math_fround(0), $678 = 0, $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = 0, $682 = Math_fround(0), $683 = Math_fround(0), $684 = 0, $685 = 0;
 var $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = Math_fround(0), $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = Math_fround(0), $700 = 0, $701 = 0, $702 = 0;
 var $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = Math_fround(0), $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $i$01$i = 0, $i$030 = 0, $materialInfo = 0, $storemerge = Math_fround(0), $storemerge34 = Math_fround(0), $storemerge35 = Math_fround(0), $storemerge36 = Math_fround(0), $storemerge37 = Math_fround(0), $storemerge38 = Math_fround(0), $storemerge39 = Math_fround(0), $storemerge40 = Math_fround(0), $storemerge41 = Math_fround(0), $storemerge42 = Math_fround(0), $storemerge43 = Math_fround(0), $storemerge44 = Math_fround(0), $storemerge45 = Math_fround(0);
 var $storemerge46 = Math_fround(0), $tm0 = 0, $tm1 = 0, $touchFound$0$lcssa = 0, $touchFound$031 = 0, $touchFound$1 = 0, $touchLost$0$lcssa = 0, $touchLost$032 = 0, $touchLost$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $tm0 = sp + 32|0;
 $tm1 = sp;
 $0 = sp + 60|0;
 $materialInfo = sp + 64|0;
 $1 = ($numEntriesStart>>>0)<($numEntriesEnd>>>0);
 if (!($1)) {
  $touchFound$0$lcssa = 0;$touchLost$0$lcssa = 0;
  $711 = HEAP32[$_touchLost>>2]|0;
  $712 = (($711) + ($touchLost$0$lcssa))|0;
  HEAP32[$_touchLost>>2] = $712;
  $713 = HEAP32[$_touchFound>>2]|0;
  $714 = (($713) + ($touchFound$0$lcssa))|0;
  HEAP32[$_touchFound>>2] = $714;
  STACKTOP = sp;return;
 }
 $2 = (($tm0) + 4|0);
 $3 = (($tm0) + 8|0);
 $4 = (($tm0) + 12|0);
 $5 = (($tm0) + 16|0);
 $6 = (($tm0) + 20|0);
 $7 = (($tm0) + 24|0);
 $8 = (($tm1) + 4|0);
 $9 = (($tm1) + 8|0);
 $10 = (($tm1) + 12|0);
 $11 = (($tm1) + 16|0);
 $12 = (($tm1) + 20|0);
 $13 = (($tm1) + 24|0);
 $14 = (($context) + 4480|0);
 $15 = (($context) + 8769|0);
 $16 = (($context) + 384|0);
 $i$030 = $numEntriesStart;$touchFound$031 = 0;$touchLost$032 = 0;
 while(1) {
  $17 = (($entries) + (($i$030*12)|0)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 72|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($18) + 76|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + 36|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($22) + 36|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($18) + 64|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($18) + 68|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($18) + 22|0);
  $32 = HEAP16[$31>>1]|0;
  $33 = $32&65535;
  $34 = $33 & 32;
  $35 = $33 & 64;
  $36 = ($26|0)<($24|0);
  $$ = $36 ? $22 : $20;
  $$23 = $36 ? $20 : $22;
  $$24 = $36 ? $26 : $24;
  $$25 = $36 ? $24 : $26;
  $$26 = $36 ? $30 : $28;
  $$27 = $36 ? $28 : $30;
  $$28 = $36 ? $35 : $34;
  $$29 = $36 ? $34 : $35;
  $37 = (((($context) + (($$24*28)|0)|0) + ($$25<<2)|0) + 104|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + 1)|0;
  HEAP32[$37>>2] = $39;
  $40 = ($$28|0)==(0);
  if ($40) {
   $248 = (($$) + 16|0);
   $249 = Math_fround(HEAPF32[$248>>2]);
   $250 = Math_fround($249 * Math_fround(2.0));
   $251 = (($$) + 20|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = Math_fround($252 * Math_fround(2.0));
   $254 = (($$) + 24|0);
   $255 = Math_fround(HEAPF32[$254>>2]);
   $256 = Math_fround($255 * Math_fround(2.0));
   $257 = (($$26) + 12|0);
   $258 = Math_fround(HEAPF32[$257>>2]);
   $259 = Math_fround($258 * $258);
   $260 = Math_fround($259 + Math_fround(-0.5));
   $261 = Math_fround(HEAPF32[$$26>>2]);
   $262 = Math_fround($250 * $261);
   $263 = (($$26) + 4|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = Math_fround($253 * $264);
   $266 = Math_fround($262 + $265);
   $267 = (($$26) + 8|0);
   $268 = Math_fround(HEAPF32[$267>>2]);
   $269 = Math_fround($256 * $268);
   $270 = Math_fround($266 + $269);
   $271 = Math_fround($250 * $260);
   $272 = Math_fround($256 * $264);
   $273 = Math_fround($253 * $268);
   $274 = Math_fround($272 - $273);
   $275 = Math_fround($258 * $274);
   $276 = Math_fround($271 + $275);
   $277 = Math_fround($261 * $270);
   $278 = Math_fround($277 + $276);
   $279 = Math_fround($253 * $260);
   $280 = Math_fround($250 * $268);
   $281 = Math_fround($256 * $261);
   $282 = Math_fround($280 - $281);
   $283 = Math_fround($258 * $282);
   $284 = Math_fround($279 + $283);
   $285 = Math_fround($264 * $270);
   $286 = Math_fround($285 + $284);
   $287 = Math_fround($256 * $260);
   $288 = Math_fround($253 * $261);
   $289 = Math_fround($250 * $264);
   $290 = Math_fround($288 - $289);
   $291 = Math_fround($258 * $290);
   $292 = Math_fround($287 + $291);
   $293 = Math_fround($268 * $270);
   $294 = Math_fround($292 + $293);
   $295 = (($$26) + 16|0);
   $296 = Math_fround(HEAPF32[$295>>2]);
   $297 = Math_fround($296 + $278);
   $298 = (($$26) + 20|0);
   $299 = Math_fround(HEAPF32[$298>>2]);
   $300 = Math_fround($299 + $286);
   $301 = (($$26) + 24|0);
   $302 = Math_fround(HEAPF32[$301>>2]);
   $303 = Math_fround($302 + $294);
   $304 = Math_fround(HEAPF32[$$>>2]);
   $305 = Math_fround($258 * $304);
   $306 = (($$) + 12|0);
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = Math_fround($261 * $307);
   $309 = Math_fround($305 + $308);
   $310 = (($$) + 8|0);
   $311 = Math_fround(HEAPF32[$310>>2]);
   $312 = Math_fround($264 * $311);
   $313 = Math_fround($309 + $312);
   $314 = (($$) + 4|0);
   $315 = Math_fround(HEAPF32[$314>>2]);
   $316 = Math_fround($268 * $315);
   $317 = Math_fround($313 - $316);
   $318 = Math_fround($258 * $315);
   $319 = Math_fround($264 * $307);
   $320 = Math_fround($319 + $318);
   $321 = Math_fround($268 * $304);
   $322 = Math_fround($321 + $320);
   $323 = Math_fround($261 * $311);
   $324 = Math_fround($322 - $323);
   $325 = Math_fround($258 * $311);
   $326 = Math_fround($268 * $307);
   $327 = Math_fround($326 + $325);
   $328 = Math_fround($261 * $315);
   $329 = Math_fround($328 + $327);
   $330 = Math_fround($264 * $304);
   $331 = Math_fround($329 - $330);
   $332 = Math_fround($258 * $307);
   $333 = Math_fround($261 * $304);
   $334 = Math_fround($332 - $333);
   $335 = Math_fround($264 * $315);
   $336 = Math_fround($334 - $335);
   $337 = Math_fround($268 * $311);
   $338 = Math_fround($336 - $337);
   $storemerge = $303;$storemerge36 = $300;$storemerge37 = $297;$storemerge40 = $338;$storemerge41 = $331;$storemerge44 = $324;$storemerge45 = $317;
  } else {
   $41 = (($$26) + 48|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = (($$26) + 52|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($$26) + 56|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = Math_fround($42 * Math_fround(-2.0));
   $48 = Math_fround($44 * Math_fround(-2.0));
   $49 = Math_fround($46 * Math_fround(-2.0));
   $50 = (($$26) + 44|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = Math_fround($51 * $51);
   $53 = Math_fround($52 + Math_fround(-0.5));
   $54 = (($$26) + 32|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = Math_fround($47 * $55);
   $57 = (($$26) + 36|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = Math_fround($48 * $58);
   $60 = Math_fround($56 + $59);
   $61 = (($$26) + 40|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = Math_fround($49 * $62);
   $64 = Math_fround($60 + $63);
   $65 = Math_fround($47 * $53);
   $66 = Math_fround($49 * $58);
   $67 = Math_fround($48 * $62);
   $68 = Math_fround($66 - $67);
   $69 = Math_fround($51 * $68);
   $70 = Math_fround($65 - $69);
   $71 = Math_fround($55 * $64);
   $72 = Math_fround($71 + $70);
   $73 = Math_fround($48 * $53);
   $74 = Math_fround($47 * $62);
   $75 = Math_fround($49 * $55);
   $76 = Math_fround($74 - $75);
   $77 = Math_fround($51 * $76);
   $78 = Math_fround($73 - $77);
   $79 = Math_fround($58 * $64);
   $80 = Math_fround($79 + $78);
   $81 = Math_fround($49 * $53);
   $82 = Math_fround($48 * $55);
   $83 = Math_fround($47 * $58);
   $84 = Math_fround($82 - $83);
   $85 = Math_fround($51 * $84);
   $86 = Math_fround($81 - $85);
   $87 = Math_fround($62 * $64);
   $88 = Math_fround($86 + $87);
   $89 = Math_fround(-$55);
   $90 = Math_fround(-$58);
   $91 = Math_fround(-$62);
   $92 = Math_fround($72 * Math_fround(2.0));
   $93 = Math_fround($80 * Math_fround(2.0));
   $94 = Math_fround($88 * Math_fround(2.0));
   $95 = (($$26) + 12|0);
   $96 = Math_fround(HEAPF32[$95>>2]);
   $97 = Math_fround($96 * $96);
   $98 = Math_fround($97 + Math_fround(-0.5));
   $99 = Math_fround(HEAPF32[$$26>>2]);
   $100 = Math_fround($99 * $92);
   $101 = (($$26) + 4|0);
   $102 = Math_fround(HEAPF32[$101>>2]);
   $103 = Math_fround($102 * $93);
   $104 = Math_fround($100 + $103);
   $105 = (($$26) + 8|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = Math_fround($106 * $94);
   $108 = Math_fround($107 + $104);
   $109 = Math_fround($98 * $92);
   $110 = Math_fround($102 * $94);
   $111 = Math_fround($106 * $93);
   $112 = Math_fround($110 - $111);
   $113 = Math_fround($96 * $112);
   $114 = Math_fround($109 + $113);
   $115 = Math_fround($99 * $108);
   $116 = Math_fround($115 + $114);
   $117 = Math_fround($98 * $93);
   $118 = Math_fround($106 * $92);
   $119 = Math_fround($99 * $94);
   $120 = Math_fround($118 - $119);
   $121 = Math_fround($96 * $120);
   $122 = Math_fround($117 + $121);
   $123 = Math_fround($102 * $108);
   $124 = Math_fround($123 + $122);
   $125 = Math_fround($98 * $94);
   $126 = Math_fround($99 * $93);
   $127 = Math_fround($102 * $92);
   $128 = Math_fround($126 - $127);
   $129 = Math_fround($96 * $128);
   $130 = Math_fround($125 + $129);
   $131 = Math_fround($106 * $108);
   $132 = Math_fround($130 + $131);
   $133 = (($$26) + 16|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = Math_fround($134 + $116);
   $136 = (($$26) + 20|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = Math_fround($137 + $124);
   $139 = (($$26) + 24|0);
   $140 = Math_fround(HEAPF32[$139>>2]);
   $141 = Math_fround($140 + $132);
   $142 = Math_fround($96 * $89);
   $143 = Math_fround($51 * $99);
   $144 = Math_fround($142 + $143);
   $145 = Math_fround($102 * $91);
   $146 = Math_fround($144 + $145);
   $147 = Math_fround($106 * $90);
   $148 = Math_fround($146 - $147);
   $149 = Math_fround($96 * $90);
   $150 = Math_fround($51 * $102);
   $151 = Math_fround($149 + $150);
   $152 = Math_fround($106 * $89);
   $153 = Math_fround($152 + $151);
   $154 = Math_fround($99 * $91);
   $155 = Math_fround($153 - $154);
   $156 = Math_fround($96 * $91);
   $157 = Math_fround($51 * $106);
   $158 = Math_fround($156 + $157);
   $159 = Math_fround($99 * $90);
   $160 = Math_fround($159 + $158);
   $161 = Math_fround($102 * $89);
   $162 = Math_fround($160 - $161);
   $163 = Math_fround($51 * $96);
   $164 = Math_fround($99 * $89);
   $165 = Math_fround($163 - $164);
   $166 = Math_fround($102 * $90);
   $167 = Math_fround($165 - $166);
   $168 = Math_fround($106 * $91);
   $169 = Math_fround($167 - $168);
   $170 = (($$) + 16|0);
   $171 = Math_fround(HEAPF32[$170>>2]);
   $172 = Math_fround($171 * Math_fround(2.0));
   $173 = (($$) + 20|0);
   $174 = Math_fround(HEAPF32[$173>>2]);
   $175 = Math_fround($174 * Math_fround(2.0));
   $176 = (($$) + 24|0);
   $177 = Math_fround(HEAPF32[$176>>2]);
   $178 = Math_fround($177 * Math_fround(2.0));
   $179 = Math_fround($169 * $169);
   $180 = Math_fround($179 + Math_fround(-0.5));
   $181 = Math_fround($148 * $172);
   $182 = Math_fround($155 * $175);
   $183 = Math_fround($181 + $182);
   $184 = Math_fround($162 * $178);
   $185 = Math_fround($183 + $184);
   $186 = Math_fround($180 * $172);
   $187 = Math_fround($155 * $178);
   $188 = Math_fround($162 * $175);
   $189 = Math_fround($187 - $188);
   $190 = Math_fround($169 * $189);
   $191 = Math_fround($186 + $190);
   $192 = Math_fround($148 * $185);
   $193 = Math_fround($192 + $191);
   $194 = Math_fround($180 * $175);
   $195 = Math_fround($162 * $172);
   $196 = Math_fround($148 * $178);
   $197 = Math_fround($195 - $196);
   $198 = Math_fround($169 * $197);
   $199 = Math_fround($194 + $198);
   $200 = Math_fround($155 * $185);
   $201 = Math_fround($200 + $199);
   $202 = Math_fround($180 * $178);
   $203 = Math_fround($148 * $175);
   $204 = Math_fround($155 * $172);
   $205 = Math_fround($203 - $204);
   $206 = Math_fround($169 * $205);
   $207 = Math_fround($202 + $206);
   $208 = Math_fround($162 * $185);
   $209 = Math_fround($207 + $208);
   $210 = Math_fround($135 + $193);
   $211 = Math_fround($138 + $201);
   $212 = Math_fround($141 + $209);
   $213 = Math_fround(HEAPF32[$$>>2]);
   $214 = Math_fround($169 * $213);
   $215 = (($$) + 12|0);
   $216 = Math_fround(HEAPF32[$215>>2]);
   $217 = Math_fround($148 * $216);
   $218 = Math_fround($214 + $217);
   $219 = (($$) + 8|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = Math_fround($155 * $220);
   $222 = Math_fround($218 + $221);
   $223 = (($$) + 4|0);
   $224 = Math_fround(HEAPF32[$223>>2]);
   $225 = Math_fround($162 * $224);
   $226 = Math_fround($222 - $225);
   $227 = Math_fround($169 * $224);
   $228 = Math_fround($155 * $216);
   $229 = Math_fround($228 + $227);
   $230 = Math_fround($162 * $213);
   $231 = Math_fround($230 + $229);
   $232 = Math_fround($148 * $220);
   $233 = Math_fround($231 - $232);
   $234 = Math_fround($169 * $220);
   $235 = Math_fround($162 * $216);
   $236 = Math_fround($235 + $234);
   $237 = Math_fround($148 * $224);
   $238 = Math_fround($237 + $236);
   $239 = Math_fround($155 * $213);
   $240 = Math_fround($238 - $239);
   $241 = Math_fround($169 * $216);
   $242 = Math_fround($148 * $213);
   $243 = Math_fround($241 - $242);
   $244 = Math_fround($155 * $224);
   $245 = Math_fround($243 - $244);
   $246 = Math_fround($162 * $220);
   $247 = Math_fround($245 - $246);
   $storemerge = $212;$storemerge36 = $211;$storemerge37 = $210;$storemerge40 = $247;$storemerge41 = $240;$storemerge44 = $233;$storemerge45 = $226;
  }
  HEAPF32[$tm0>>2] = $storemerge45;
  HEAPF32[$2>>2] = $storemerge44;
  HEAPF32[$3>>2] = $storemerge41;
  HEAPF32[$4>>2] = $storemerge40;
  HEAPF32[$5>>2] = $storemerge37;
  HEAPF32[$6>>2] = $storemerge36;
  HEAPF32[$7>>2] = $storemerge;
  $339 = ($$29|0)==(0);
  if ($339) {
   $547 = (($$23) + 16|0);
   $548 = Math_fround(HEAPF32[$547>>2]);
   $549 = Math_fround($548 * Math_fround(2.0));
   $550 = (($$23) + 20|0);
   $551 = Math_fround(HEAPF32[$550>>2]);
   $552 = Math_fround($551 * Math_fround(2.0));
   $553 = (($$23) + 24|0);
   $554 = Math_fround(HEAPF32[$553>>2]);
   $555 = Math_fround($554 * Math_fround(2.0));
   $556 = (($$27) + 12|0);
   $557 = Math_fround(HEAPF32[$556>>2]);
   $558 = Math_fround($557 * $557);
   $559 = Math_fround($558 + Math_fround(-0.5));
   $560 = Math_fround(HEAPF32[$$27>>2]);
   $561 = Math_fround($549 * $560);
   $562 = (($$27) + 4|0);
   $563 = Math_fround(HEAPF32[$562>>2]);
   $564 = Math_fround($552 * $563);
   $565 = Math_fround($561 + $564);
   $566 = (($$27) + 8|0);
   $567 = Math_fround(HEAPF32[$566>>2]);
   $568 = Math_fround($555 * $567);
   $569 = Math_fround($565 + $568);
   $570 = Math_fround($549 * $559);
   $571 = Math_fround($555 * $563);
   $572 = Math_fround($552 * $567);
   $573 = Math_fround($571 - $572);
   $574 = Math_fround($557 * $573);
   $575 = Math_fround($570 + $574);
   $576 = Math_fround($560 * $569);
   $577 = Math_fround($576 + $575);
   $578 = Math_fround($552 * $559);
   $579 = Math_fround($549 * $567);
   $580 = Math_fround($555 * $560);
   $581 = Math_fround($579 - $580);
   $582 = Math_fround($557 * $581);
   $583 = Math_fround($578 + $582);
   $584 = Math_fround($563 * $569);
   $585 = Math_fround($584 + $583);
   $586 = Math_fround($555 * $559);
   $587 = Math_fround($552 * $560);
   $588 = Math_fround($549 * $563);
   $589 = Math_fround($587 - $588);
   $590 = Math_fround($557 * $589);
   $591 = Math_fround($586 + $590);
   $592 = Math_fround($567 * $569);
   $593 = Math_fround($591 + $592);
   $594 = (($$27) + 16|0);
   $595 = Math_fround(HEAPF32[$594>>2]);
   $596 = Math_fround($595 + $577);
   $597 = (($$27) + 20|0);
   $598 = Math_fround(HEAPF32[$597>>2]);
   $599 = Math_fround($598 + $585);
   $600 = (($$27) + 24|0);
   $601 = Math_fround(HEAPF32[$600>>2]);
   $602 = Math_fround($601 + $593);
   $603 = Math_fround(HEAPF32[$$23>>2]);
   $604 = Math_fround($557 * $603);
   $605 = (($$23) + 12|0);
   $606 = Math_fround(HEAPF32[$605>>2]);
   $607 = Math_fround($560 * $606);
   $608 = Math_fround($604 + $607);
   $609 = (($$23) + 8|0);
   $610 = Math_fround(HEAPF32[$609>>2]);
   $611 = Math_fround($563 * $610);
   $612 = Math_fround($608 + $611);
   $613 = (($$23) + 4|0);
   $614 = Math_fround(HEAPF32[$613>>2]);
   $615 = Math_fround($567 * $614);
   $616 = Math_fround($612 - $615);
   $617 = Math_fround($557 * $614);
   $618 = Math_fround($563 * $606);
   $619 = Math_fround($618 + $617);
   $620 = Math_fround($567 * $603);
   $621 = Math_fround($620 + $619);
   $622 = Math_fround($560 * $610);
   $623 = Math_fround($621 - $622);
   $624 = Math_fround($557 * $610);
   $625 = Math_fround($567 * $606);
   $626 = Math_fround($625 + $624);
   $627 = Math_fround($560 * $614);
   $628 = Math_fround($627 + $626);
   $629 = Math_fround($563 * $603);
   $630 = Math_fround($628 - $629);
   $631 = Math_fround($557 * $606);
   $632 = Math_fround($560 * $603);
   $633 = Math_fround($631 - $632);
   $634 = Math_fround($563 * $614);
   $635 = Math_fround($633 - $634);
   $636 = Math_fround($567 * $610);
   $637 = Math_fround($635 - $636);
   $storemerge34 = $602;$storemerge35 = $599;$storemerge38 = $596;$storemerge39 = $637;$storemerge42 = $630;$storemerge43 = $623;$storemerge46 = $616;
  } else {
   $340 = (($$27) + 48|0);
   $341 = Math_fround(HEAPF32[$340>>2]);
   $342 = (($$27) + 52|0);
   $343 = Math_fround(HEAPF32[$342>>2]);
   $344 = (($$27) + 56|0);
   $345 = Math_fround(HEAPF32[$344>>2]);
   $346 = Math_fround($341 * Math_fround(-2.0));
   $347 = Math_fround($343 * Math_fround(-2.0));
   $348 = Math_fround($345 * Math_fround(-2.0));
   $349 = (($$27) + 44|0);
   $350 = Math_fround(HEAPF32[$349>>2]);
   $351 = Math_fround($350 * $350);
   $352 = Math_fround($351 + Math_fround(-0.5));
   $353 = (($$27) + 32|0);
   $354 = Math_fround(HEAPF32[$353>>2]);
   $355 = Math_fround($346 * $354);
   $356 = (($$27) + 36|0);
   $357 = Math_fround(HEAPF32[$356>>2]);
   $358 = Math_fround($347 * $357);
   $359 = Math_fround($355 + $358);
   $360 = (($$27) + 40|0);
   $361 = Math_fround(HEAPF32[$360>>2]);
   $362 = Math_fround($348 * $361);
   $363 = Math_fround($359 + $362);
   $364 = Math_fround($346 * $352);
   $365 = Math_fround($348 * $357);
   $366 = Math_fround($347 * $361);
   $367 = Math_fround($365 - $366);
   $368 = Math_fround($350 * $367);
   $369 = Math_fround($364 - $368);
   $370 = Math_fround($354 * $363);
   $371 = Math_fround($370 + $369);
   $372 = Math_fround($347 * $352);
   $373 = Math_fround($346 * $361);
   $374 = Math_fround($348 * $354);
   $375 = Math_fround($373 - $374);
   $376 = Math_fround($350 * $375);
   $377 = Math_fround($372 - $376);
   $378 = Math_fround($357 * $363);
   $379 = Math_fround($378 + $377);
   $380 = Math_fround($348 * $352);
   $381 = Math_fround($347 * $354);
   $382 = Math_fround($346 * $357);
   $383 = Math_fround($381 - $382);
   $384 = Math_fround($350 * $383);
   $385 = Math_fround($380 - $384);
   $386 = Math_fround($361 * $363);
   $387 = Math_fround($385 + $386);
   $388 = Math_fround(-$354);
   $389 = Math_fround(-$357);
   $390 = Math_fround(-$361);
   $391 = Math_fround($371 * Math_fround(2.0));
   $392 = Math_fround($379 * Math_fround(2.0));
   $393 = Math_fround($387 * Math_fround(2.0));
   $394 = (($$27) + 12|0);
   $395 = Math_fround(HEAPF32[$394>>2]);
   $396 = Math_fround($395 * $395);
   $397 = Math_fround($396 + Math_fround(-0.5));
   $398 = Math_fround(HEAPF32[$$27>>2]);
   $399 = Math_fround($398 * $391);
   $400 = (($$27) + 4|0);
   $401 = Math_fround(HEAPF32[$400>>2]);
   $402 = Math_fround($401 * $392);
   $403 = Math_fround($399 + $402);
   $404 = (($$27) + 8|0);
   $405 = Math_fround(HEAPF32[$404>>2]);
   $406 = Math_fround($405 * $393);
   $407 = Math_fround($406 + $403);
   $408 = Math_fround($397 * $391);
   $409 = Math_fround($401 * $393);
   $410 = Math_fround($405 * $392);
   $411 = Math_fround($409 - $410);
   $412 = Math_fround($395 * $411);
   $413 = Math_fround($408 + $412);
   $414 = Math_fround($398 * $407);
   $415 = Math_fround($414 + $413);
   $416 = Math_fround($397 * $392);
   $417 = Math_fround($405 * $391);
   $418 = Math_fround($398 * $393);
   $419 = Math_fround($417 - $418);
   $420 = Math_fround($395 * $419);
   $421 = Math_fround($416 + $420);
   $422 = Math_fround($401 * $407);
   $423 = Math_fround($422 + $421);
   $424 = Math_fround($397 * $393);
   $425 = Math_fround($398 * $392);
   $426 = Math_fround($401 * $391);
   $427 = Math_fround($425 - $426);
   $428 = Math_fround($395 * $427);
   $429 = Math_fround($424 + $428);
   $430 = Math_fround($405 * $407);
   $431 = Math_fround($429 + $430);
   $432 = (($$27) + 16|0);
   $433 = Math_fround(HEAPF32[$432>>2]);
   $434 = Math_fround($433 + $415);
   $435 = (($$27) + 20|0);
   $436 = Math_fround(HEAPF32[$435>>2]);
   $437 = Math_fround($436 + $423);
   $438 = (($$27) + 24|0);
   $439 = Math_fround(HEAPF32[$438>>2]);
   $440 = Math_fround($439 + $431);
   $441 = Math_fround($395 * $388);
   $442 = Math_fround($350 * $398);
   $443 = Math_fround($441 + $442);
   $444 = Math_fround($401 * $390);
   $445 = Math_fround($443 + $444);
   $446 = Math_fround($405 * $389);
   $447 = Math_fround($445 - $446);
   $448 = Math_fround($395 * $389);
   $449 = Math_fround($350 * $401);
   $450 = Math_fround($448 + $449);
   $451 = Math_fround($405 * $388);
   $452 = Math_fround($451 + $450);
   $453 = Math_fround($398 * $390);
   $454 = Math_fround($452 - $453);
   $455 = Math_fround($395 * $390);
   $456 = Math_fround($350 * $405);
   $457 = Math_fround($455 + $456);
   $458 = Math_fround($398 * $389);
   $459 = Math_fround($458 + $457);
   $460 = Math_fround($401 * $388);
   $461 = Math_fround($459 - $460);
   $462 = Math_fround($350 * $395);
   $463 = Math_fround($398 * $388);
   $464 = Math_fround($462 - $463);
   $465 = Math_fround($401 * $389);
   $466 = Math_fround($464 - $465);
   $467 = Math_fround($405 * $390);
   $468 = Math_fround($466 - $467);
   $469 = (($$23) + 16|0);
   $470 = Math_fround(HEAPF32[$469>>2]);
   $471 = Math_fround($470 * Math_fround(2.0));
   $472 = (($$23) + 20|0);
   $473 = Math_fround(HEAPF32[$472>>2]);
   $474 = Math_fround($473 * Math_fround(2.0));
   $475 = (($$23) + 24|0);
   $476 = Math_fround(HEAPF32[$475>>2]);
   $477 = Math_fround($476 * Math_fround(2.0));
   $478 = Math_fround($468 * $468);
   $479 = Math_fround($478 + Math_fround(-0.5));
   $480 = Math_fround($447 * $471);
   $481 = Math_fround($454 * $474);
   $482 = Math_fround($480 + $481);
   $483 = Math_fround($461 * $477);
   $484 = Math_fround($482 + $483);
   $485 = Math_fround($479 * $471);
   $486 = Math_fround($454 * $477);
   $487 = Math_fround($461 * $474);
   $488 = Math_fround($486 - $487);
   $489 = Math_fround($468 * $488);
   $490 = Math_fround($485 + $489);
   $491 = Math_fround($447 * $484);
   $492 = Math_fround($491 + $490);
   $493 = Math_fround($479 * $474);
   $494 = Math_fround($461 * $471);
   $495 = Math_fround($447 * $477);
   $496 = Math_fround($494 - $495);
   $497 = Math_fround($468 * $496);
   $498 = Math_fround($493 + $497);
   $499 = Math_fround($454 * $484);
   $500 = Math_fround($499 + $498);
   $501 = Math_fround($479 * $477);
   $502 = Math_fround($447 * $474);
   $503 = Math_fround($454 * $471);
   $504 = Math_fround($502 - $503);
   $505 = Math_fround($468 * $504);
   $506 = Math_fround($501 + $505);
   $507 = Math_fround($461 * $484);
   $508 = Math_fround($506 + $507);
   $509 = Math_fround($434 + $492);
   $510 = Math_fround($437 + $500);
   $511 = Math_fround($440 + $508);
   $512 = Math_fround(HEAPF32[$$23>>2]);
   $513 = Math_fround($468 * $512);
   $514 = (($$23) + 12|0);
   $515 = Math_fround(HEAPF32[$514>>2]);
   $516 = Math_fround($447 * $515);
   $517 = Math_fround($513 + $516);
   $518 = (($$23) + 8|0);
   $519 = Math_fround(HEAPF32[$518>>2]);
   $520 = Math_fround($454 * $519);
   $521 = Math_fround($517 + $520);
   $522 = (($$23) + 4|0);
   $523 = Math_fround(HEAPF32[$522>>2]);
   $524 = Math_fround($461 * $523);
   $525 = Math_fround($521 - $524);
   $526 = Math_fround($468 * $523);
   $527 = Math_fround($454 * $515);
   $528 = Math_fround($527 + $526);
   $529 = Math_fround($461 * $512);
   $530 = Math_fround($529 + $528);
   $531 = Math_fround($447 * $519);
   $532 = Math_fround($530 - $531);
   $533 = Math_fround($468 * $519);
   $534 = Math_fround($461 * $515);
   $535 = Math_fround($534 + $533);
   $536 = Math_fround($447 * $523);
   $537 = Math_fround($536 + $535);
   $538 = Math_fround($454 * $512);
   $539 = Math_fround($537 - $538);
   $540 = Math_fround($468 * $515);
   $541 = Math_fround($447 * $512);
   $542 = Math_fround($540 - $541);
   $543 = Math_fround($454 * $523);
   $544 = Math_fround($542 - $543);
   $545 = Math_fround($461 * $519);
   $546 = Math_fround($544 - $545);
   $storemerge34 = $511;$storemerge35 = $510;$storemerge38 = $509;$storemerge39 = $546;$storemerge42 = $539;$storemerge43 = $532;$storemerge46 = $525;
  }
  HEAPF32[$tm1>>2] = $storemerge46;
  HEAPF32[$8>>2] = $storemerge43;
  HEAPF32[$9>>2] = $storemerge42;
  HEAPF32[$10>>2] = $storemerge39;
  HEAPF32[$11>>2] = $storemerge38;
  HEAPF32[$12>>2] = $storemerge35;
  HEAPF32[$13>>2] = $storemerge34;
  $638 = (($18) + 98|0);
  $639 = HEAP16[$638>>1]|0;
  $640 = $639&65535;
  $641 = $640 & 2;
  HEAP32[$14>>2] = 0;
  HEAP16[$638>>1] = 0;
  $642 = (($18) + 20|0);
  HEAP16[$642>>1] = 0;
  $643 = (($18) + 24|0);
  HEAP32[$643>>2] = 0;
  HEAP32[$18>>2] = 0;
  $644 = (($18) + 16|0);
  HEAP16[$644>>1] = 0;
  $645 = (($18) + 4|0);
  HEAP32[$645>>2] = 0;
  $646 = (($18) + 28|0);
  HEAP32[$646>>2] = 0;
  $647 = (($18) + 32|0);
  HEAP32[$647>>2] = 0;
  $648 = ((503592 + (($$24*28)|0)|0) + ($$25<<2)|0);
  $649 = HEAP32[$648>>2]|0;
  $650 = HEAP8[$15>>0]|0;
  $651 = ($650<<24>>24)==(0);
  if ($651) {
   label = 12;
  } else {
   $652 = ((503536 + (($$24*7)|0)|0) + ($$25)|0);
   $653 = HEAP8[$652>>0]|0;
   $654 = ($653<<24>>24)==(0);
   if ($654) {
    label = 12;
   } else {
    $655 = (($18) + 44|0);
    $656 = (($$) + 28|0);
    $657 = Math_fround(HEAPF32[$656>>2]);
    $658 = (($$23) + 28|0);
    $659 = Math_fround(HEAPF32[$658>>2]);
    $660 = Math_fround($657 + $659);
    $661 = (($$) + 36|0);
    $662 = (($$23) + 36|0);
    __ZN5physx21PxcCacheLocalContactsENS_14PxGeometryType4EnumES1_RNS_18PxcNpThreadContextERNS_10PxcNpCacheERKNS_11PxTransformES8_fPFbRKNS_2Gu13GeometryUnionESC_S8_S8_RKfS5_RNS9_13ContactBufferEESC_SC_($$24,$$25,$context,$655,$tm0,$tm1,$660,$649,$661,$662);
   }
  }
  if ((label|0) == 12) {
   label = 0;
   $663 = (($$) + 36|0);
   $664 = (($$23) + 36|0);
   $665 = (($$) + 28|0);
   $666 = Math_fround(HEAPF32[$665>>2]);
   $667 = (($$23) + 28|0);
   $668 = Math_fround(HEAPF32[$667>>2]);
   $669 = Math_fround($666 + $668);
   HEAPF32[$0>>2] = $669;
   $670 = (($18) + 44|0);
   (FUNCTION_TABLE_iiiiiiii[$649 & 127]($663,$664,$tm0,$tm1,$0,$670,$16)|0);
  }
  $671 = ((504224 + (($$24*28)|0)|0) + ($$25<<2)|0);
  $672 = HEAP32[$671>>2]|0;
  (FUNCTION_TABLE_iiiii[$672 & 511]($$,$$23,$context,$materialInfo)|0);
  if ($36) {
   $673 = HEAP32[$14>>2]|0;
   $674 = ($673|0)==(0);
   if (!($674)) {
    $i$01$i = 0;
    while(1) {
     $675 = ((($context) + ($i$01$i<<6)|0) + 384|0);
     $676 = Math_fround(HEAPF32[$675>>2]);
     $677 = Math_fround(-$676);
     $678 = ((($context) + ($i$01$i<<6)|0) + 388|0);
     $679 = Math_fround(HEAPF32[$678>>2]);
     $680 = Math_fround(-$679);
     $681 = ((($context) + ($i$01$i<<6)|0) + 392|0);
     $682 = Math_fround(HEAPF32[$681>>2]);
     $683 = Math_fround(-$682);
     HEAPF32[$675>>2] = $677;
     HEAPF32[$678>>2] = $680;
     HEAPF32[$681>>2] = $683;
     $684 = ((($context) + ($i$01$i<<6)|0) + 432|0);
     $685 = ((($context) + ($i$01$i<<6)|0) + 436|0);
     $686 = HEAP32[$684>>2]|0;
     $687 = HEAP32[$685>>2]|0;
     HEAP32[$684>>2] = $687;
     HEAP32[$685>>2] = $686;
     $688 = (($materialInfo) + ($i$01$i<<2)|0);
     $689 = ((($materialInfo) + ($i$01$i<<2)|0) + 2|0);
     $690 = HEAP16[$688>>1]|0;
     $691 = HEAP16[$689>>1]|0;
     HEAP16[$688>>1] = $691;
     HEAP16[$689>>1] = $690;
     $692 = (($i$01$i) + 1)|0;
     $693 = HEAP32[$14>>2]|0;
     $694 = ($692>>>0)<($693>>>0);
     if ($694) {
      $i$01$i = $692;
     } else {
      break;
     }
    }
   }
  }
  (__ZN5physx14finishContactsERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($18,$context,$materialInfo)|0);
  $695 = HEAP16[$638>>1]|0;
  $696 = $695&65535;
  $697 = $696 & 2;
  $698 = ($641|0)==($697|0);
  do {
   if ($698) {
    $touchFound$1 = $touchFound$031;$touchLost$1 = $touchLost$032;
   } else {
    $699 = ((($entries) + (($i$030*12)|0)|0) + 4|0);
    $700 = HEAP32[$699>>2]|0;
    $701 = $700 & 31;
    $702 = 1 << $701;
    $703 = $700 >>> 5;
    $704 = (($changeBitmapBase) + ($703<<2)|0);
    $705 = HEAP32[$704>>2]|0;
    $706 = $702 | $705;
    HEAP32[$704>>2] = $706;
    $707 = ($641|0)==(0);
    if ($707) {
     $709 = (($touchFound$031) + 1)|0;
     $touchFound$1 = $709;$touchLost$1 = $touchLost$032;
     break;
    } else {
     $708 = (($touchLost$032) + 1)|0;
     $touchFound$1 = $touchFound$031;$touchLost$1 = $708;
     break;
    }
   }
  } while(0);
  $710 = (($i$030) + 1)|0;
  $exitcond = ($710|0)==($numEntriesEnd|0);
  if ($exitcond) {
   $touchFound$0$lcssa = $touchFound$1;$touchLost$0$lcssa = $touchLost$1;
   break;
  } else {
   $i$030 = $710;$touchFound$031 = $touchFound$1;$touchLost$032 = $touchLost$1;
  }
 }
 $711 = HEAP32[$_touchLost>>2]|0;
 $712 = (($711) + ($touchLost$0$lcssa))|0;
 HEAP32[$_touchLost>>2] = $712;
 $713 = HEAP32[$_touchFound>>2]|0;
 $714 = (($713) + ($touchFound$0$lcssa))|0;
 HEAP32[$_touchFound>>2] = $714;
 STACKTOP = sp;return;
}
function __Z16runNpPCMBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($context,$entries,$numEntriesStart,$numEntriesEnd,$changeBitmapBase,$changeBitmapWordCount,$_touchLost,$_touchFound) {
 $context = $context|0;
 $entries = $entries|0;
 $numEntriesStart = $numEntriesStart|0;
 $numEntriesEnd = $numEntriesEnd|0;
 $changeBitmapBase = $changeBitmapBase|0;
 $changeBitmapWordCount = $changeBitmapWordCount|0;
 $_touchLost = $_touchLost|0;
 $_touchFound = $_touchFound|0;
 var $$ = 0, $$31 = 0, $$32 = 0, $$33 = 0, $$34 = 0, $$35 = 0, $$36 = 0, $$37 = 0, $$lcssa$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0;
 var $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0);
 var $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0);
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0;
 var $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0);
 var $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0);
 var $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0);
 var $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0;
 var $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0);
 var $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = 0;
 var $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = Math_fround(0);
 var $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0);
 var $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0;
 var $450 = Math_fround(0), $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0);
 var $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0);
 var $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = 0, $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0);
 var $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = 0;
 var $522 = Math_fround(0), $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0;
 var $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0);
 var $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = 0, $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = 0, $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = 0, $575 = Math_fround(0), $576 = Math_fround(0);
 var $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0);
 var $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = Math_fround(0), $605 = 0, $606 = Math_fround(0), $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0);
 var $612 = Math_fround(0), $613 = Math_fround(0), $614 = 0, $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = 0, $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0;
 var $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = 0, $647 = Math_fround(0), $648 = Math_fround(0);
 var $649 = 0, $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = 0, $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = 0, $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = 0, $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = 0, $666 = Math_fround(0);
 var $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0);
 var $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0;
 var $702 = 0, $703 = 0, $704 = 0, $705 = Math_fround(0), $706 = 0, $707 = Math_fround(0), $708 = Math_fround(0), $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0, $717 = Math_fround(0), $718 = Math_fround(0), $719 = 0, $72 = 0;
 var $720 = Math_fround(0), $721 = Math_fround(0), $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0;
 var $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0;
 var $757 = Math_fround(0), $758 = 0, $759 = Math_fround(0), $76 = 0, $760 = 0, $761 = Math_fround(0), $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = Math_fround(0), $768 = 0, $769 = Math_fround(0), $77 = 0, $770 = 0, $771 = Math_fround(0), $772 = 0, $773 = 0, $774 = 0;
 var $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0;
 var $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0;
 var $810 = 0, $811 = 0, $812 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $a$039$i = 0, $b$038$i = 0, $buff$040$i = 0, $cp$0$i = 0, $cp$0$i4 = 0, $exitcond = 0, $i$01$i = 0, $i$039 = 0, $isMultiManifold$0$off0 = 0, $materialInfo = 0, $phitmp$i = 0, $phitmp45$i = 0, $storemerge = Math_fround(0), $storemerge43 = Math_fround(0), $storemerge44 = Math_fround(0), $storemerge45 = Math_fround(0), $storemerge46 = Math_fround(0), $storemerge47 = Math_fround(0);
 var $storemerge48 = Math_fround(0), $storemerge49 = Math_fround(0), $storemerge50 = Math_fround(0), $storemerge51 = Math_fround(0), $storemerge52 = Math_fround(0), $storemerge53 = Math_fround(0), $storemerge54 = Math_fround(0), $storemerge55 = Math_fround(0), $tm0 = 0, $tm1 = 0, $touchFound$0$lcssa = 0, $touchFound$040 = 0, $touchFound$1 = 0, $touchLost$0$lcssa = 0, $touchLost$041 = 0, $touchLost$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $tm0 = sp + 32|0;
 $tm1 = sp;
 $0 = sp + 60|0;
 $materialInfo = sp + 64|0;
 $1 = ($numEntriesStart>>>0)<($numEntriesEnd>>>0);
 if (!($1)) {
  $touchFound$0$lcssa = 0;$touchLost$0$lcssa = 0;
  $809 = HEAP32[$_touchLost>>2]|0;
  $810 = (($809) + ($touchLost$0$lcssa))|0;
  HEAP32[$_touchLost>>2] = $810;
  $811 = HEAP32[$_touchFound>>2]|0;
  $812 = (($811) + ($touchFound$0$lcssa))|0;
  HEAP32[$_touchFound>>2] = $812;
  STACKTOP = sp;return;
 }
 $2 = (($context) + 4496|0);
 $3 = (($tm0) + 4|0);
 $4 = (($tm0) + 8|0);
 $5 = (($tm0) + 12|0);
 $6 = (($tm0) + 16|0);
 $7 = (($tm0) + 20|0);
 $8 = (($tm0) + 24|0);
 $9 = (($tm1) + 4|0);
 $10 = (($tm1) + 8|0);
 $11 = (($tm1) + 12|0);
 $12 = (($tm1) + 16|0);
 $13 = (($tm1) + 20|0);
 $14 = (($tm1) + 24|0);
 $15 = (($context) + 4480|0);
 $16 = (($context) + 384|0);
 $17 = (($context) + 4548|0);
 $18 = (($2) + 53|0);
 $19 = (($context) + 356|0);
 $20 = $2;
 $21 = $20 | 1;
 $i$039 = $numEntriesStart;$touchFound$040 = 0;$touchLost$041 = 0;
 while(1) {
  $22 = (($entries) + (($i$039*12)|0)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 72|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 76|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 36|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 36|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($23) + 64|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($23) + 68|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($23) + 22|0);
  $37 = HEAP16[$36>>1]|0;
  $38 = $37&65535;
  $39 = $38 & 32;
  $40 = $38 & 64;
  $41 = (($23) + 44|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 & 1;
  $44 = ($43|0)==(0);
  if ($44) {
   $47 = $42;
   $48 = HEAP32[$41>>2]|0;
   $49 = $48;
   $50 = (_bitshift64Lshr(($48|0),0,6)|0);
   $51 = tempRet0;
   $52 = (_i64Add(($48|0),0,127,0)|0);
   $53 = tempRet0;
   $54 = (_bitshift64Lshr(($52|0),($53|0),6)|0);
   $55 = tempRet0;
   $56 = (_i64Subtract(1,0,($50|0),($51|0))|0);
   $57 = tempRet0;
   $58 = (_i64Add(($56|0),($57|0),($54|0),($55|0))|0);
   $59 = tempRet0;
   $61 = $58;$62 = $59;$cp$0$i4 = $49;
   while(1) {
    $60 = (($cp$0$i4) + 64|0);
    $63 = (_i64Add(($61|0),($62|0),-1,-1)|0);
    $64 = tempRet0;
    $65 = ($63|0)==(0);
    $66 = ($64|0)==(0);
    $67 = $65 & $66;
    if ($67) {
     break;
    } else {
     $61 = $63;$62 = $64;$cp$0$i4 = $60;
    }
   }
   $68 = HEAP32[$41>>2]|0;
   $69 = $68;
   $70 = (_bitshift64Lshr(($68|0),0,6)|0);
   $71 = tempRet0;
   $72 = (_i64Add(($68|0),0,255,0)|0);
   $73 = tempRet0;
   $74 = (_bitshift64Lshr(($72|0),($73|0),6)|0);
   $75 = tempRet0;
   $76 = (_i64Subtract(1,0,($70|0),($71|0))|0);
   $77 = tempRet0;
   $78 = (_i64Add(($76|0),($77|0),($74|0),($75|0))|0);
   $79 = tempRet0;
   $81 = $78;$82 = $79;$cp$0$i = $69;
   while(1) {
    $80 = (($cp$0$i) + 64|0);
    $83 = (_i64Add(($81|0),($82|0),-1,-1)|0);
    $84 = tempRet0;
    $85 = ($83|0)==(0);
    $86 = ($84|0)==(0);
    $87 = $85 & $86;
    if ($87) {
     $isMultiManifold$0$off0 = 0;
     break;
    } else {
     $81 = $83;$82 = $84;$cp$0$i = $80;
    }
   }
  } else {
   $45 = $42 & -2;
   $46 = $45;
   __ZN5physx2Gu33MultiplePersistentContactManifold10fromBufferEPh($2,$46);
   HEAP32[$41>>2] = $21;
   $isMultiManifold$0$off0 = 1;
  }
  $88 = ($31|0)<($29|0);
  $$ = $88 ? $27 : $25;
  $$31 = $88 ? $25 : $27;
  $$32 = $88 ? $31 : $29;
  $$33 = $88 ? $29 : $31;
  $$34 = $88 ? $35 : $33;
  $$35 = $88 ? $33 : $35;
  $$36 = $88 ? $40 : $39;
  $$37 = $88 ? $39 : $40;
  $89 = (((($context) + (($$32*28)|0)|0) + ($$33<<2)|0) + 104|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($90) + 1)|0;
  HEAP32[$89>>2] = $91;
  $92 = ($$36|0)==(0);
  if ($92) {
   $300 = (($$) + 16|0);
   $301 = Math_fround(HEAPF32[$300>>2]);
   $302 = Math_fround($301 * Math_fround(2.0));
   $303 = (($$) + 20|0);
   $304 = Math_fround(HEAPF32[$303>>2]);
   $305 = Math_fround($304 * Math_fround(2.0));
   $306 = (($$) + 24|0);
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = Math_fround($307 * Math_fround(2.0));
   $309 = (($$34) + 12|0);
   $310 = Math_fround(HEAPF32[$309>>2]);
   $311 = Math_fround($310 * $310);
   $312 = Math_fround($311 + Math_fround(-0.5));
   $313 = Math_fround(HEAPF32[$$34>>2]);
   $314 = Math_fround($302 * $313);
   $315 = (($$34) + 4|0);
   $316 = Math_fround(HEAPF32[$315>>2]);
   $317 = Math_fround($305 * $316);
   $318 = Math_fround($314 + $317);
   $319 = (($$34) + 8|0);
   $320 = Math_fround(HEAPF32[$319>>2]);
   $321 = Math_fround($308 * $320);
   $322 = Math_fround($318 + $321);
   $323 = Math_fround($302 * $312);
   $324 = Math_fround($308 * $316);
   $325 = Math_fround($305 * $320);
   $326 = Math_fround($324 - $325);
   $327 = Math_fround($310 * $326);
   $328 = Math_fround($323 + $327);
   $329 = Math_fround($313 * $322);
   $330 = Math_fround($329 + $328);
   $331 = Math_fround($305 * $312);
   $332 = Math_fround($302 * $320);
   $333 = Math_fround($308 * $313);
   $334 = Math_fround($332 - $333);
   $335 = Math_fround($310 * $334);
   $336 = Math_fround($331 + $335);
   $337 = Math_fround($316 * $322);
   $338 = Math_fround($337 + $336);
   $339 = Math_fround($308 * $312);
   $340 = Math_fround($305 * $313);
   $341 = Math_fround($302 * $316);
   $342 = Math_fround($340 - $341);
   $343 = Math_fround($310 * $342);
   $344 = Math_fround($339 + $343);
   $345 = Math_fround($320 * $322);
   $346 = Math_fround($344 + $345);
   $347 = (($$34) + 16|0);
   $348 = Math_fround(HEAPF32[$347>>2]);
   $349 = Math_fround($348 + $330);
   $350 = (($$34) + 20|0);
   $351 = Math_fround(HEAPF32[$350>>2]);
   $352 = Math_fround($351 + $338);
   $353 = (($$34) + 24|0);
   $354 = Math_fround(HEAPF32[$353>>2]);
   $355 = Math_fround($354 + $346);
   $356 = Math_fround(HEAPF32[$$>>2]);
   $357 = Math_fround($310 * $356);
   $358 = (($$) + 12|0);
   $359 = Math_fround(HEAPF32[$358>>2]);
   $360 = Math_fround($313 * $359);
   $361 = Math_fround($357 + $360);
   $362 = (($$) + 8|0);
   $363 = Math_fround(HEAPF32[$362>>2]);
   $364 = Math_fround($316 * $363);
   $365 = Math_fround($361 + $364);
   $366 = (($$) + 4|0);
   $367 = Math_fround(HEAPF32[$366>>2]);
   $368 = Math_fround($320 * $367);
   $369 = Math_fround($365 - $368);
   $370 = Math_fround($310 * $367);
   $371 = Math_fround($316 * $359);
   $372 = Math_fround($371 + $370);
   $373 = Math_fround($320 * $356);
   $374 = Math_fround($373 + $372);
   $375 = Math_fround($313 * $363);
   $376 = Math_fround($374 - $375);
   $377 = Math_fround($310 * $363);
   $378 = Math_fround($320 * $359);
   $379 = Math_fround($378 + $377);
   $380 = Math_fround($313 * $367);
   $381 = Math_fround($380 + $379);
   $382 = Math_fround($316 * $356);
   $383 = Math_fround($381 - $382);
   $384 = Math_fround($310 * $359);
   $385 = Math_fround($313 * $356);
   $386 = Math_fround($384 - $385);
   $387 = Math_fround($316 * $367);
   $388 = Math_fround($386 - $387);
   $389 = Math_fround($320 * $363);
   $390 = Math_fround($388 - $389);
   $storemerge = $355;$storemerge45 = $352;$storemerge46 = $349;$storemerge49 = $390;$storemerge50 = $383;$storemerge53 = $376;$storemerge54 = $369;
  } else {
   $93 = (($$34) + 48|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = (($$34) + 52|0);
   $96 = Math_fround(HEAPF32[$95>>2]);
   $97 = (($$34) + 56|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = Math_fround($94 * Math_fround(-2.0));
   $100 = Math_fround($96 * Math_fround(-2.0));
   $101 = Math_fround($98 * Math_fround(-2.0));
   $102 = (($$34) + 44|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = Math_fround($103 * $103);
   $105 = Math_fround($104 + Math_fround(-0.5));
   $106 = (($$34) + 32|0);
   $107 = Math_fround(HEAPF32[$106>>2]);
   $108 = Math_fround($99 * $107);
   $109 = (($$34) + 36|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = Math_fround($100 * $110);
   $112 = Math_fround($108 + $111);
   $113 = (($$34) + 40|0);
   $114 = Math_fround(HEAPF32[$113>>2]);
   $115 = Math_fround($101 * $114);
   $116 = Math_fround($112 + $115);
   $117 = Math_fround($99 * $105);
   $118 = Math_fround($101 * $110);
   $119 = Math_fround($100 * $114);
   $120 = Math_fround($118 - $119);
   $121 = Math_fround($103 * $120);
   $122 = Math_fround($117 - $121);
   $123 = Math_fround($107 * $116);
   $124 = Math_fround($123 + $122);
   $125 = Math_fround($100 * $105);
   $126 = Math_fround($99 * $114);
   $127 = Math_fround($101 * $107);
   $128 = Math_fround($126 - $127);
   $129 = Math_fround($103 * $128);
   $130 = Math_fround($125 - $129);
   $131 = Math_fround($110 * $116);
   $132 = Math_fround($131 + $130);
   $133 = Math_fround($101 * $105);
   $134 = Math_fround($100 * $107);
   $135 = Math_fround($99 * $110);
   $136 = Math_fround($134 - $135);
   $137 = Math_fround($103 * $136);
   $138 = Math_fround($133 - $137);
   $139 = Math_fround($114 * $116);
   $140 = Math_fround($138 + $139);
   $141 = Math_fround(-$107);
   $142 = Math_fround(-$110);
   $143 = Math_fround(-$114);
   $144 = Math_fround($124 * Math_fround(2.0));
   $145 = Math_fround($132 * Math_fround(2.0));
   $146 = Math_fround($140 * Math_fround(2.0));
   $147 = (($$34) + 12|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = Math_fround($148 * $148);
   $150 = Math_fround($149 + Math_fround(-0.5));
   $151 = Math_fround(HEAPF32[$$34>>2]);
   $152 = Math_fround($151 * $144);
   $153 = (($$34) + 4|0);
   $154 = Math_fround(HEAPF32[$153>>2]);
   $155 = Math_fround($154 * $145);
   $156 = Math_fround($152 + $155);
   $157 = (($$34) + 8|0);
   $158 = Math_fround(HEAPF32[$157>>2]);
   $159 = Math_fround($158 * $146);
   $160 = Math_fround($159 + $156);
   $161 = Math_fround($150 * $144);
   $162 = Math_fround($154 * $146);
   $163 = Math_fround($158 * $145);
   $164 = Math_fround($162 - $163);
   $165 = Math_fround($148 * $164);
   $166 = Math_fround($161 + $165);
   $167 = Math_fround($151 * $160);
   $168 = Math_fround($167 + $166);
   $169 = Math_fround($150 * $145);
   $170 = Math_fround($158 * $144);
   $171 = Math_fround($151 * $146);
   $172 = Math_fround($170 - $171);
   $173 = Math_fround($148 * $172);
   $174 = Math_fround($169 + $173);
   $175 = Math_fround($154 * $160);
   $176 = Math_fround($175 + $174);
   $177 = Math_fround($150 * $146);
   $178 = Math_fround($151 * $145);
   $179 = Math_fround($154 * $144);
   $180 = Math_fround($178 - $179);
   $181 = Math_fround($148 * $180);
   $182 = Math_fround($177 + $181);
   $183 = Math_fround($158 * $160);
   $184 = Math_fround($182 + $183);
   $185 = (($$34) + 16|0);
   $186 = Math_fround(HEAPF32[$185>>2]);
   $187 = Math_fround($186 + $168);
   $188 = (($$34) + 20|0);
   $189 = Math_fround(HEAPF32[$188>>2]);
   $190 = Math_fround($189 + $176);
   $191 = (($$34) + 24|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = Math_fround($192 + $184);
   $194 = Math_fround($148 * $141);
   $195 = Math_fround($103 * $151);
   $196 = Math_fround($194 + $195);
   $197 = Math_fround($154 * $143);
   $198 = Math_fround($196 + $197);
   $199 = Math_fround($158 * $142);
   $200 = Math_fround($198 - $199);
   $201 = Math_fround($148 * $142);
   $202 = Math_fround($103 * $154);
   $203 = Math_fround($201 + $202);
   $204 = Math_fround($158 * $141);
   $205 = Math_fround($204 + $203);
   $206 = Math_fround($151 * $143);
   $207 = Math_fround($205 - $206);
   $208 = Math_fround($148 * $143);
   $209 = Math_fround($103 * $158);
   $210 = Math_fround($208 + $209);
   $211 = Math_fround($151 * $142);
   $212 = Math_fround($211 + $210);
   $213 = Math_fround($154 * $141);
   $214 = Math_fround($212 - $213);
   $215 = Math_fround($103 * $148);
   $216 = Math_fround($151 * $141);
   $217 = Math_fround($215 - $216);
   $218 = Math_fround($154 * $142);
   $219 = Math_fround($217 - $218);
   $220 = Math_fround($158 * $143);
   $221 = Math_fround($219 - $220);
   $222 = (($$) + 16|0);
   $223 = Math_fround(HEAPF32[$222>>2]);
   $224 = Math_fround($223 * Math_fround(2.0));
   $225 = (($$) + 20|0);
   $226 = Math_fround(HEAPF32[$225>>2]);
   $227 = Math_fround($226 * Math_fround(2.0));
   $228 = (($$) + 24|0);
   $229 = Math_fround(HEAPF32[$228>>2]);
   $230 = Math_fround($229 * Math_fround(2.0));
   $231 = Math_fround($221 * $221);
   $232 = Math_fround($231 + Math_fround(-0.5));
   $233 = Math_fround($200 * $224);
   $234 = Math_fround($207 * $227);
   $235 = Math_fround($233 + $234);
   $236 = Math_fround($214 * $230);
   $237 = Math_fround($235 + $236);
   $238 = Math_fround($232 * $224);
   $239 = Math_fround($207 * $230);
   $240 = Math_fround($214 * $227);
   $241 = Math_fround($239 - $240);
   $242 = Math_fround($221 * $241);
   $243 = Math_fround($238 + $242);
   $244 = Math_fround($200 * $237);
   $245 = Math_fround($244 + $243);
   $246 = Math_fround($232 * $227);
   $247 = Math_fround($214 * $224);
   $248 = Math_fround($200 * $230);
   $249 = Math_fround($247 - $248);
   $250 = Math_fround($221 * $249);
   $251 = Math_fround($246 + $250);
   $252 = Math_fround($207 * $237);
   $253 = Math_fround($252 + $251);
   $254 = Math_fround($232 * $230);
   $255 = Math_fround($200 * $227);
   $256 = Math_fround($207 * $224);
   $257 = Math_fround($255 - $256);
   $258 = Math_fround($221 * $257);
   $259 = Math_fround($254 + $258);
   $260 = Math_fround($214 * $237);
   $261 = Math_fround($259 + $260);
   $262 = Math_fround($187 + $245);
   $263 = Math_fround($190 + $253);
   $264 = Math_fround($193 + $261);
   $265 = Math_fround(HEAPF32[$$>>2]);
   $266 = Math_fround($221 * $265);
   $267 = (($$) + 12|0);
   $268 = Math_fround(HEAPF32[$267>>2]);
   $269 = Math_fround($200 * $268);
   $270 = Math_fround($266 + $269);
   $271 = (($$) + 8|0);
   $272 = Math_fround(HEAPF32[$271>>2]);
   $273 = Math_fround($207 * $272);
   $274 = Math_fround($270 + $273);
   $275 = (($$) + 4|0);
   $276 = Math_fround(HEAPF32[$275>>2]);
   $277 = Math_fround($214 * $276);
   $278 = Math_fround($274 - $277);
   $279 = Math_fround($221 * $276);
   $280 = Math_fround($207 * $268);
   $281 = Math_fround($280 + $279);
   $282 = Math_fround($214 * $265);
   $283 = Math_fround($282 + $281);
   $284 = Math_fround($200 * $272);
   $285 = Math_fround($283 - $284);
   $286 = Math_fround($221 * $272);
   $287 = Math_fround($214 * $268);
   $288 = Math_fround($287 + $286);
   $289 = Math_fround($200 * $276);
   $290 = Math_fround($289 + $288);
   $291 = Math_fround($207 * $265);
   $292 = Math_fround($290 - $291);
   $293 = Math_fround($221 * $268);
   $294 = Math_fround($200 * $265);
   $295 = Math_fround($293 - $294);
   $296 = Math_fround($207 * $276);
   $297 = Math_fround($295 - $296);
   $298 = Math_fround($214 * $272);
   $299 = Math_fround($297 - $298);
   $storemerge = $264;$storemerge45 = $263;$storemerge46 = $262;$storemerge49 = $299;$storemerge50 = $292;$storemerge53 = $285;$storemerge54 = $278;
  }
  HEAPF32[$tm0>>2] = $storemerge54;
  HEAPF32[$3>>2] = $storemerge53;
  HEAPF32[$4>>2] = $storemerge50;
  HEAPF32[$5>>2] = $storemerge49;
  HEAPF32[$6>>2] = $storemerge46;
  HEAPF32[$7>>2] = $storemerge45;
  HEAPF32[$8>>2] = $storemerge;
  $391 = ($$37|0)==(0);
  if ($391) {
   $599 = (($$31) + 16|0);
   $600 = Math_fround(HEAPF32[$599>>2]);
   $601 = Math_fround($600 * Math_fround(2.0));
   $602 = (($$31) + 20|0);
   $603 = Math_fround(HEAPF32[$602>>2]);
   $604 = Math_fround($603 * Math_fround(2.0));
   $605 = (($$31) + 24|0);
   $606 = Math_fround(HEAPF32[$605>>2]);
   $607 = Math_fround($606 * Math_fround(2.0));
   $608 = (($$35) + 12|0);
   $609 = Math_fround(HEAPF32[$608>>2]);
   $610 = Math_fround($609 * $609);
   $611 = Math_fround($610 + Math_fround(-0.5));
   $612 = Math_fround(HEAPF32[$$35>>2]);
   $613 = Math_fround($601 * $612);
   $614 = (($$35) + 4|0);
   $615 = Math_fround(HEAPF32[$614>>2]);
   $616 = Math_fround($604 * $615);
   $617 = Math_fround($613 + $616);
   $618 = (($$35) + 8|0);
   $619 = Math_fround(HEAPF32[$618>>2]);
   $620 = Math_fround($607 * $619);
   $621 = Math_fround($617 + $620);
   $622 = Math_fround($601 * $611);
   $623 = Math_fround($607 * $615);
   $624 = Math_fround($604 * $619);
   $625 = Math_fround($623 - $624);
   $626 = Math_fround($609 * $625);
   $627 = Math_fround($622 + $626);
   $628 = Math_fround($612 * $621);
   $629 = Math_fround($628 + $627);
   $630 = Math_fround($604 * $611);
   $631 = Math_fround($601 * $619);
   $632 = Math_fround($607 * $612);
   $633 = Math_fround($631 - $632);
   $634 = Math_fround($609 * $633);
   $635 = Math_fround($630 + $634);
   $636 = Math_fround($615 * $621);
   $637 = Math_fround($636 + $635);
   $638 = Math_fround($607 * $611);
   $639 = Math_fround($604 * $612);
   $640 = Math_fround($601 * $615);
   $641 = Math_fround($639 - $640);
   $642 = Math_fround($609 * $641);
   $643 = Math_fround($638 + $642);
   $644 = Math_fround($619 * $621);
   $645 = Math_fround($643 + $644);
   $646 = (($$35) + 16|0);
   $647 = Math_fround(HEAPF32[$646>>2]);
   $648 = Math_fround($647 + $629);
   $649 = (($$35) + 20|0);
   $650 = Math_fround(HEAPF32[$649>>2]);
   $651 = Math_fround($650 + $637);
   $652 = (($$35) + 24|0);
   $653 = Math_fround(HEAPF32[$652>>2]);
   $654 = Math_fround($653 + $645);
   $655 = Math_fround(HEAPF32[$$31>>2]);
   $656 = Math_fround($609 * $655);
   $657 = (($$31) + 12|0);
   $658 = Math_fround(HEAPF32[$657>>2]);
   $659 = Math_fround($612 * $658);
   $660 = Math_fround($656 + $659);
   $661 = (($$31) + 8|0);
   $662 = Math_fround(HEAPF32[$661>>2]);
   $663 = Math_fround($615 * $662);
   $664 = Math_fround($660 + $663);
   $665 = (($$31) + 4|0);
   $666 = Math_fround(HEAPF32[$665>>2]);
   $667 = Math_fround($619 * $666);
   $668 = Math_fround($664 - $667);
   $669 = Math_fround($609 * $666);
   $670 = Math_fround($615 * $658);
   $671 = Math_fround($670 + $669);
   $672 = Math_fround($619 * $655);
   $673 = Math_fround($672 + $671);
   $674 = Math_fround($612 * $662);
   $675 = Math_fround($673 - $674);
   $676 = Math_fround($609 * $662);
   $677 = Math_fround($619 * $658);
   $678 = Math_fround($677 + $676);
   $679 = Math_fround($612 * $666);
   $680 = Math_fround($679 + $678);
   $681 = Math_fround($615 * $655);
   $682 = Math_fround($680 - $681);
   $683 = Math_fround($609 * $658);
   $684 = Math_fround($612 * $655);
   $685 = Math_fround($683 - $684);
   $686 = Math_fround($615 * $666);
   $687 = Math_fround($685 - $686);
   $688 = Math_fround($619 * $662);
   $689 = Math_fround($687 - $688);
   $storemerge43 = $654;$storemerge44 = $651;$storemerge47 = $648;$storemerge48 = $689;$storemerge51 = $682;$storemerge52 = $675;$storemerge55 = $668;
  } else {
   $392 = (($$35) + 48|0);
   $393 = Math_fround(HEAPF32[$392>>2]);
   $394 = (($$35) + 52|0);
   $395 = Math_fround(HEAPF32[$394>>2]);
   $396 = (($$35) + 56|0);
   $397 = Math_fround(HEAPF32[$396>>2]);
   $398 = Math_fround($393 * Math_fround(-2.0));
   $399 = Math_fround($395 * Math_fround(-2.0));
   $400 = Math_fround($397 * Math_fround(-2.0));
   $401 = (($$35) + 44|0);
   $402 = Math_fround(HEAPF32[$401>>2]);
   $403 = Math_fround($402 * $402);
   $404 = Math_fround($403 + Math_fround(-0.5));
   $405 = (($$35) + 32|0);
   $406 = Math_fround(HEAPF32[$405>>2]);
   $407 = Math_fround($398 * $406);
   $408 = (($$35) + 36|0);
   $409 = Math_fround(HEAPF32[$408>>2]);
   $410 = Math_fround($399 * $409);
   $411 = Math_fround($407 + $410);
   $412 = (($$35) + 40|0);
   $413 = Math_fround(HEAPF32[$412>>2]);
   $414 = Math_fround($400 * $413);
   $415 = Math_fround($411 + $414);
   $416 = Math_fround($398 * $404);
   $417 = Math_fround($400 * $409);
   $418 = Math_fround($399 * $413);
   $419 = Math_fround($417 - $418);
   $420 = Math_fround($402 * $419);
   $421 = Math_fround($416 - $420);
   $422 = Math_fround($406 * $415);
   $423 = Math_fround($422 + $421);
   $424 = Math_fround($399 * $404);
   $425 = Math_fround($398 * $413);
   $426 = Math_fround($400 * $406);
   $427 = Math_fround($425 - $426);
   $428 = Math_fround($402 * $427);
   $429 = Math_fround($424 - $428);
   $430 = Math_fround($409 * $415);
   $431 = Math_fround($430 + $429);
   $432 = Math_fround($400 * $404);
   $433 = Math_fround($399 * $406);
   $434 = Math_fround($398 * $409);
   $435 = Math_fround($433 - $434);
   $436 = Math_fround($402 * $435);
   $437 = Math_fround($432 - $436);
   $438 = Math_fround($413 * $415);
   $439 = Math_fround($437 + $438);
   $440 = Math_fround(-$406);
   $441 = Math_fround(-$409);
   $442 = Math_fround(-$413);
   $443 = Math_fround($423 * Math_fround(2.0));
   $444 = Math_fround($431 * Math_fround(2.0));
   $445 = Math_fround($439 * Math_fround(2.0));
   $446 = (($$35) + 12|0);
   $447 = Math_fround(HEAPF32[$446>>2]);
   $448 = Math_fround($447 * $447);
   $449 = Math_fround($448 + Math_fround(-0.5));
   $450 = Math_fround(HEAPF32[$$35>>2]);
   $451 = Math_fround($450 * $443);
   $452 = (($$35) + 4|0);
   $453 = Math_fround(HEAPF32[$452>>2]);
   $454 = Math_fround($453 * $444);
   $455 = Math_fround($451 + $454);
   $456 = (($$35) + 8|0);
   $457 = Math_fround(HEAPF32[$456>>2]);
   $458 = Math_fround($457 * $445);
   $459 = Math_fround($458 + $455);
   $460 = Math_fround($449 * $443);
   $461 = Math_fround($453 * $445);
   $462 = Math_fround($457 * $444);
   $463 = Math_fround($461 - $462);
   $464 = Math_fround($447 * $463);
   $465 = Math_fround($460 + $464);
   $466 = Math_fround($450 * $459);
   $467 = Math_fround($466 + $465);
   $468 = Math_fround($449 * $444);
   $469 = Math_fround($457 * $443);
   $470 = Math_fround($450 * $445);
   $471 = Math_fround($469 - $470);
   $472 = Math_fround($447 * $471);
   $473 = Math_fround($468 + $472);
   $474 = Math_fround($453 * $459);
   $475 = Math_fround($474 + $473);
   $476 = Math_fround($449 * $445);
   $477 = Math_fround($450 * $444);
   $478 = Math_fround($453 * $443);
   $479 = Math_fround($477 - $478);
   $480 = Math_fround($447 * $479);
   $481 = Math_fround($476 + $480);
   $482 = Math_fround($457 * $459);
   $483 = Math_fround($481 + $482);
   $484 = (($$35) + 16|0);
   $485 = Math_fround(HEAPF32[$484>>2]);
   $486 = Math_fround($485 + $467);
   $487 = (($$35) + 20|0);
   $488 = Math_fround(HEAPF32[$487>>2]);
   $489 = Math_fround($488 + $475);
   $490 = (($$35) + 24|0);
   $491 = Math_fround(HEAPF32[$490>>2]);
   $492 = Math_fround($491 + $483);
   $493 = Math_fround($447 * $440);
   $494 = Math_fround($402 * $450);
   $495 = Math_fround($493 + $494);
   $496 = Math_fround($453 * $442);
   $497 = Math_fround($495 + $496);
   $498 = Math_fround($457 * $441);
   $499 = Math_fround($497 - $498);
   $500 = Math_fround($447 * $441);
   $501 = Math_fround($402 * $453);
   $502 = Math_fround($500 + $501);
   $503 = Math_fround($457 * $440);
   $504 = Math_fround($503 + $502);
   $505 = Math_fround($450 * $442);
   $506 = Math_fround($504 - $505);
   $507 = Math_fround($447 * $442);
   $508 = Math_fround($402 * $457);
   $509 = Math_fround($507 + $508);
   $510 = Math_fround($450 * $441);
   $511 = Math_fround($510 + $509);
   $512 = Math_fround($453 * $440);
   $513 = Math_fround($511 - $512);
   $514 = Math_fround($402 * $447);
   $515 = Math_fround($450 * $440);
   $516 = Math_fround($514 - $515);
   $517 = Math_fround($453 * $441);
   $518 = Math_fround($516 - $517);
   $519 = Math_fround($457 * $442);
   $520 = Math_fround($518 - $519);
   $521 = (($$31) + 16|0);
   $522 = Math_fround(HEAPF32[$521>>2]);
   $523 = Math_fround($522 * Math_fround(2.0));
   $524 = (($$31) + 20|0);
   $525 = Math_fround(HEAPF32[$524>>2]);
   $526 = Math_fround($525 * Math_fround(2.0));
   $527 = (($$31) + 24|0);
   $528 = Math_fround(HEAPF32[$527>>2]);
   $529 = Math_fround($528 * Math_fround(2.0));
   $530 = Math_fround($520 * $520);
   $531 = Math_fround($530 + Math_fround(-0.5));
   $532 = Math_fround($499 * $523);
   $533 = Math_fround($506 * $526);
   $534 = Math_fround($532 + $533);
   $535 = Math_fround($513 * $529);
   $536 = Math_fround($534 + $535);
   $537 = Math_fround($531 * $523);
   $538 = Math_fround($506 * $529);
   $539 = Math_fround($513 * $526);
   $540 = Math_fround($538 - $539);
   $541 = Math_fround($520 * $540);
   $542 = Math_fround($537 + $541);
   $543 = Math_fround($499 * $536);
   $544 = Math_fround($543 + $542);
   $545 = Math_fround($531 * $526);
   $546 = Math_fround($513 * $523);
   $547 = Math_fround($499 * $529);
   $548 = Math_fround($546 - $547);
   $549 = Math_fround($520 * $548);
   $550 = Math_fround($545 + $549);
   $551 = Math_fround($506 * $536);
   $552 = Math_fround($551 + $550);
   $553 = Math_fround($531 * $529);
   $554 = Math_fround($499 * $526);
   $555 = Math_fround($506 * $523);
   $556 = Math_fround($554 - $555);
   $557 = Math_fround($520 * $556);
   $558 = Math_fround($553 + $557);
   $559 = Math_fround($513 * $536);
   $560 = Math_fround($558 + $559);
   $561 = Math_fround($486 + $544);
   $562 = Math_fround($489 + $552);
   $563 = Math_fround($492 + $560);
   $564 = Math_fround(HEAPF32[$$31>>2]);
   $565 = Math_fround($520 * $564);
   $566 = (($$31) + 12|0);
   $567 = Math_fround(HEAPF32[$566>>2]);
   $568 = Math_fround($499 * $567);
   $569 = Math_fround($565 + $568);
   $570 = (($$31) + 8|0);
   $571 = Math_fround(HEAPF32[$570>>2]);
   $572 = Math_fround($506 * $571);
   $573 = Math_fround($569 + $572);
   $574 = (($$31) + 4|0);
   $575 = Math_fround(HEAPF32[$574>>2]);
   $576 = Math_fround($513 * $575);
   $577 = Math_fround($573 - $576);
   $578 = Math_fround($520 * $575);
   $579 = Math_fround($506 * $567);
   $580 = Math_fround($579 + $578);
   $581 = Math_fround($513 * $564);
   $582 = Math_fround($581 + $580);
   $583 = Math_fround($499 * $571);
   $584 = Math_fround($582 - $583);
   $585 = Math_fround($520 * $571);
   $586 = Math_fround($513 * $567);
   $587 = Math_fround($586 + $585);
   $588 = Math_fround($499 * $575);
   $589 = Math_fround($588 + $587);
   $590 = Math_fround($506 * $564);
   $591 = Math_fround($589 - $590);
   $592 = Math_fround($520 * $567);
   $593 = Math_fround($499 * $564);
   $594 = Math_fround($592 - $593);
   $595 = Math_fround($506 * $575);
   $596 = Math_fround($594 - $595);
   $597 = Math_fround($513 * $571);
   $598 = Math_fround($596 - $597);
   $storemerge43 = $563;$storemerge44 = $562;$storemerge47 = $561;$storemerge48 = $598;$storemerge51 = $591;$storemerge52 = $584;$storemerge55 = $577;
  }
  HEAPF32[$tm1>>2] = $storemerge55;
  HEAPF32[$9>>2] = $storemerge52;
  HEAPF32[$10>>2] = $storemerge51;
  HEAPF32[$11>>2] = $storemerge48;
  HEAPF32[$12>>2] = $storemerge47;
  HEAPF32[$13>>2] = $storemerge44;
  HEAPF32[$14>>2] = $storemerge43;
  $690 = (($23) + 98|0);
  $691 = HEAP16[$690>>1]|0;
  $692 = $691&65535;
  $693 = $692 & 2;
  HEAP32[$15>>2] = 0;
  HEAP16[$690>>1] = 0;
  $694 = (($23) + 20|0);
  HEAP16[$694>>1] = 0;
  $695 = (($23) + 24|0);
  HEAP32[$695>>2] = 0;
  HEAP32[$23>>2] = 0;
  $696 = (($23) + 16|0);
  HEAP16[$696>>1] = 0;
  $697 = (($23) + 4|0);
  HEAP32[$697>>2] = 0;
  $698 = (($23) + 28|0);
  HEAP32[$698>>2] = 0;
  $699 = (($23) + 32|0);
  HEAP32[$699>>2] = 0;
  $700 = ((503792 + (($$32*28)|0)|0) + ($$33<<2)|0);
  $701 = HEAP32[$700>>2]|0;
  $702 = (($$) + 36|0);
  $703 = (($$31) + 36|0);
  $704 = (($$) + 28|0);
  $705 = Math_fround(HEAPF32[$704>>2]);
  $706 = (($$31) + 28|0);
  $707 = Math_fround(HEAPF32[$706>>2]);
  $708 = Math_fround($705 + $707);
  HEAPF32[$0>>2] = $708;
  (FUNCTION_TABLE_iiiiiiii[$701 & 127]($702,$703,$tm0,$tm1,$0,$41,$16)|0);
  $709 = ((504224 + (($$32*28)|0)|0) + ($$33<<2)|0);
  $710 = HEAP32[$709>>2]|0;
  (FUNCTION_TABLE_iiiii[$710 & 511]($$,$$31,$context,$materialInfo)|0);
  if ($88) {
   $711 = HEAP32[$15>>2]|0;
   $712 = ($711|0)==(0);
   if (!($712)) {
    $i$01$i = 0;
    while(1) {
     $713 = ((($context) + ($i$01$i<<6)|0) + 384|0);
     $714 = Math_fround(HEAPF32[$713>>2]);
     $715 = Math_fround(-$714);
     $716 = ((($context) + ($i$01$i<<6)|0) + 388|0);
     $717 = Math_fround(HEAPF32[$716>>2]);
     $718 = Math_fround(-$717);
     $719 = ((($context) + ($i$01$i<<6)|0) + 392|0);
     $720 = Math_fround(HEAPF32[$719>>2]);
     $721 = Math_fround(-$720);
     HEAPF32[$713>>2] = $715;
     HEAPF32[$716>>2] = $718;
     HEAPF32[$719>>2] = $721;
     $722 = ((($context) + ($i$01$i<<6)|0) + 432|0);
     $723 = ((($context) + ($i$01$i<<6)|0) + 436|0);
     $724 = HEAP32[$722>>2]|0;
     $725 = HEAP32[$723>>2]|0;
     HEAP32[$722>>2] = $725;
     HEAP32[$723>>2] = $724;
     $726 = (($materialInfo) + ($i$01$i<<2)|0);
     $727 = ((($materialInfo) + ($i$01$i<<2)|0) + 2|0);
     $728 = HEAP16[$726>>1]|0;
     $729 = HEAP16[$727>>1]|0;
     HEAP16[$726>>1] = $729;
     HEAP16[$727>>1] = $728;
     $730 = (($i$01$i) + 1)|0;
     $731 = HEAP32[$15>>2]|0;
     $732 = ($730>>>0)<($731>>>0);
     if ($732) {
      $i$01$i = $730;
     } else {
      break;
     }
    }
   }
  }
  (__ZN5physx14finishContactsERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($23,$context,$materialInfo)|0);
  if ($isMultiManifold$0$off0) {
   $733 = HEAP8[$17>>0]|0;
   $734 = $733&255;
   $735 = $734 << 4;
   $736 = (($735) + 48)|0;
   $737 = HEAP8[$18>>0]|0;
   $738 = $737&255;
   $739 = ($738*48)|0;
   $740 = (($736) + ($739))|0;
   $741 = (__ZN5physx20PxcNpCacheStreamPair7reserveEj($19,$740)|0);
   $742 = HEAP8[$17>>0]|0;
   $743 = $742&255;
   $744 = (($741) + 32|0);
   HEAP32[$744>>2] = $743;
   ;HEAP32[$741+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$741+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$741+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$741+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$741+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$741+20>>2]=HEAP32[$2+20>>2]|0;HEAP32[$741+24>>2]=HEAP32[$2+24>>2]|0;HEAP32[$741+28>>2]=HEAP32[$2+28>>2]|0;
   $745 = HEAP8[$17>>0]|0;
   $746 = ($745<<24>>24)==(0);
   if (!($746)) {
    $747 = (($741) + 48|0);
    $a$039$i = 0;$buff$040$i = $747;
    while(1) {
     $748 = (($buff$040$i) + 16|0);
     $749 = ((($2) + ($a$039$i)|0) + 48|0);
     $750 = HEAP8[$749>>0]|0;
     $751 = $750&255;
     $752 = ((($2) + (($751*400)|0)|0) + 448|0);
     $753 = HEAP32[$752>>2]|0;
     HEAP32[$buff$040$i>>2] = $753;
     $754 = HEAP32[$752>>2]|0;
     $755 = ($754|0)==(0);
     if ($755) {
      $$lcssa$i = 16;
     } else {
      $b$038$i = 0;
      while(1) {
       $756 = (((($2) + (($751*400)|0)|0) + ($b$038$i<<6)|0) + 64|0);
       $757 = Math_fround(HEAPF32[$756>>2]);
       $758 = (((($2) + (($751*400)|0)|0) + ($b$038$i<<6)|0) + 68|0);
       $759 = Math_fround(HEAPF32[$758>>2]);
       $760 = (((($2) + (($751*400)|0)|0) + ($b$038$i<<6)|0) + 72|0);
       $761 = Math_fround(HEAPF32[$760>>2]);
       $762 = (($748) + (($b$038$i*48)|0)|0);
       HEAPF32[$762>>2] = $757;
       $763 = (($762) + 4|0);
       HEAPF32[$763>>2] = $759;
       $764 = (($762) + 8|0);
       HEAPF32[$764>>2] = $761;
       $765 = (($762) + 12|0);
       HEAPF32[$765>>2] = Math_fround(0.0);
       $766 = (((($2) + (($751*400)|0)|0) + ($b$038$i<<6)|0) + 80|0);
       $767 = Math_fround(HEAPF32[$766>>2]);
       $768 = (((($2) + (($751*400)|0)|0) + ($b$038$i<<6)|0) + 84|0);
       $769 = Math_fround(HEAPF32[$768>>2]);
       $770 = (((($2) + (($751*400)|0)|0) + ($b$038$i<<6)|0) + 88|0);
       $771 = Math_fround(HEAPF32[$770>>2]);
       $772 = ((($748) + (($b$038$i*48)|0)|0) + 16|0);
       HEAPF32[$772>>2] = $767;
       $773 = (($772) + 4|0);
       HEAPF32[$773>>2] = $769;
       $774 = (($772) + 8|0);
       HEAPF32[$774>>2] = $771;
       $775 = (($772) + 12|0);
       HEAPF32[$775>>2] = Math_fround(0.0);
       $776 = (((($2) + (($751*400)|0)|0) + ($b$038$i<<6)|0) + 96|0);
       $777 = ((($748) + (($b$038$i*48)|0)|0) + 32|0);
       _memmove(($777|0),($776|0),16)|0;
       $778 = (((($2) + (($751*400)|0)|0) + ($b$038$i<<6)|0) + 112|0);
       $779 = HEAP32[$778>>2]|0;
       $780 = ((($748) + (($b$038$i*48)|0)|0) + 12|0);
       HEAP32[$780>>2] = $779;
       $781 = (($b$038$i) + 1)|0;
       $782 = HEAP32[$752>>2]|0;
       $783 = ($781>>>0)<($782>>>0);
       if ($783) {
        $b$038$i = $781;
       } else {
        break;
       }
      }
      $phitmp$i = ($782*48)|0;
      $phitmp45$i = (($phitmp$i) + 16)|0;
      $$lcssa$i = $phitmp45$i;
     }
     $784 = (($buff$040$i) + ($$lcssa$i)|0);
     $785 = (($a$039$i) + 1)|0;
     $786 = HEAP8[$17>>0]|0;
     $787 = $786&255;
     $788 = ($785>>>0)<($787>>>0);
     if ($788) {
      $a$039$i = $785;$buff$040$i = $784;
     } else {
      break;
     }
    }
   }
   $789 = $741;
   $790 = $789 | 1;
   HEAP32[$41>>2] = $790;
   $791 = $740&65535;
   $792 = (($23) + 56|0);
   HEAP16[$792>>1] = $791;
  }
  $793 = HEAP16[$690>>1]|0;
  $794 = $793&65535;
  $795 = $794 & 2;
  $796 = ($693|0)==($795|0);
  do {
   if ($796) {
    $touchFound$1 = $touchFound$040;$touchLost$1 = $touchLost$041;
   } else {
    $797 = ((($entries) + (($i$039*12)|0)|0) + 4|0);
    $798 = HEAP32[$797>>2]|0;
    $799 = $798 & 31;
    $800 = 1 << $799;
    $801 = $798 >>> 5;
    $802 = (($changeBitmapBase) + ($801<<2)|0);
    $803 = HEAP32[$802>>2]|0;
    $804 = $800 | $803;
    HEAP32[$802>>2] = $804;
    $805 = ($693|0)==(0);
    if ($805) {
     $807 = (($touchFound$040) + 1)|0;
     $touchFound$1 = $807;$touchLost$1 = $touchLost$041;
     break;
    } else {
     $806 = (($touchLost$041) + 1)|0;
     $touchFound$1 = $touchFound$040;$touchLost$1 = $806;
     break;
    }
   }
  } while(0);
  $808 = (($i$039) + 1)|0;
  $exitcond = ($808|0)==($numEntriesEnd|0);
  if ($exitcond) {
   $touchFound$0$lcssa = $touchFound$1;$touchLost$0$lcssa = $touchLost$1;
   break;
  } else {
   $i$039 = $808;$touchFound$040 = $touchFound$1;$touchLost$041 = $touchLost$1;
  }
 }
 $809 = HEAP32[$_touchLost>>2]|0;
 $810 = (($809) + ($touchLost$0$lcssa))|0;
 HEAP32[$_touchLost>>2] = $810;
 $811 = HEAP32[$_touchFound>>2]|0;
 $812 = (($811) + ($touchFound$0$lcssa))|0;
 HEAP32[$_touchFound>>2] = $812;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu33MultiplePersistentContactManifold10fromBufferEPh($this,$buffer) {
 $this = $this|0;
 $buffer = $buffer|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $a$033 = 0, $a1$028 = 0, $b$029 = 0, $buff$035 = 0, $exitcond = 0, $exitcond38 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buffer|0)==(0|0);
 if ($0) {
  $52 = (($this) + 16|0);
  HEAPF32[$52>>2] = Math_fround(3.40282346638528859812E+38);
  $53 = (($this) + 20|0);
  HEAPF32[$53>>2] = Math_fround(3.40282346638528859812E+38);
  $54 = (($this) + 24|0);
  HEAPF32[$54>>2] = Math_fround(3.40282346638528859812E+38);
  $55 = (($this) + 28|0);
  HEAPF32[$55>>2] = Math_fround(0.0);
  HEAPF32[$this>>2] = Math_fround(0.0);
  $56 = (($this) + 4|0);
  HEAPF32[$56>>2] = Math_fround(0.0);
  $57 = (($this) + 8|0);
  HEAPF32[$57>>2] = Math_fround(0.0);
  $58 = (($this) + 12|0);
  HEAPF32[$58>>2] = Math_fround(1.0);
  label = 8;
 } else {
  $1 = (($buffer) + 32|0);
  $2 = HEAP32[$1>>2]|0;
  ;HEAP32[$this+0>>2]=HEAP32[$buffer+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$buffer+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$buffer+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$buffer+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$buffer+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$buffer+20>>2]|0;HEAP32[$this+24>>2]=HEAP32[$buffer+24>>2]|0;HEAP32[$this+28>>2]=HEAP32[$buffer+28>>2]|0;
  $3 = ($2|0)==(0);
  if ($3) {
   label = 8;
  } else {
   $4 = (($buffer) + 48|0);
   $a$033 = 0;$buff$035 = $4;
   while(1) {
    $5 = $a$033&255;
    $6 = ((($this) + ($a$033)|0) + 48|0);
    HEAP8[$6>>0] = $5;
    $7 = (($buff$035) + 16|0);
    $8 = HEAP32[$buff$035>>2]|0;
    $9 = ((($this) + (($a$033*400)|0)|0) + 448|0);
    HEAP32[$9>>2] = $8;
    $10 = ($8|0)==(0);
    if (!($10)) {
     $b$029 = 0;
     while(1) {
      $11 = (($7) + (($b$029*48)|0)|0);
      $12 = Math_fround(HEAPF32[$11>>2]);
      $13 = (($11) + 4|0);
      $14 = Math_fround(HEAPF32[$13>>2]);
      $15 = (($11) + 8|0);
      $16 = Math_fround(HEAPF32[$15>>2]);
      $17 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 64|0);
      HEAPF32[$17>>2] = $12;
      $18 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 68|0);
      HEAPF32[$18>>2] = $14;
      $19 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 72|0);
      HEAPF32[$19>>2] = $16;
      $20 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 76|0);
      HEAPF32[$20>>2] = Math_fround(0.0);
      $21 = ((($7) + (($b$029*48)|0)|0) + 16|0);
      $22 = Math_fround(HEAPF32[$21>>2]);
      $23 = (($21) + 4|0);
      $24 = Math_fround(HEAPF32[$23>>2]);
      $25 = (($21) + 8|0);
      $26 = Math_fround(HEAPF32[$25>>2]);
      $27 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 80|0);
      HEAPF32[$27>>2] = $22;
      $28 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 84|0);
      HEAPF32[$28>>2] = $24;
      $29 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 88|0);
      HEAPF32[$29>>2] = $26;
      $30 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 92|0);
      HEAPF32[$30>>2] = Math_fround(0.0);
      $31 = ((($7) + (($b$029*48)|0)|0) + 32|0);
      $32 = Math_fround(HEAPF32[$31>>2]);
      $33 = (($31) + 4|0);
      $34 = Math_fround(HEAPF32[$33>>2]);
      $35 = (($31) + 8|0);
      $36 = Math_fround(HEAPF32[$35>>2]);
      $37 = (($31) + 12|0);
      $38 = Math_fround(HEAPF32[$37>>2]);
      $39 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 96|0);
      HEAPF32[$39>>2] = $32;
      $40 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 100|0);
      HEAPF32[$40>>2] = $34;
      $41 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 104|0);
      HEAPF32[$41>>2] = $36;
      $42 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 108|0);
      HEAPF32[$42>>2] = $38;
      $43 = ((($7) + (($b$029*48)|0)|0) + 12|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = (((($this) + (($a$033*400)|0)|0) + ($b$029<<6)|0) + 112|0);
      HEAP32[$45>>2] = $44;
      $46 = (($b$029) + 1)|0;
      $47 = HEAP32[$9>>2]|0;
      $48 = ($46>>>0)<($47>>>0);
      if ($48) {
       $b$029 = $46;
      } else {
       break;
      }
     }
    }
    $49 = ($8*48)|0;
    $$sum = (($49) + 16)|0;
    $50 = (($buff$035) + ($$sum)|0);
    $51 = (($a$033) + 1)|0;
    $exitcond38 = ($51|0)==($2|0);
    if ($exitcond38) {
     break;
    } else {
     $a$033 = $51;$buff$035 = $50;
    }
   }
   $60 = $2&255;
   $61 = (($this) + 52|0);
   HEAP8[$61>>0] = $60;
   $62 = ($2>>>0)<(4);
   if ($62) {
    $a1$028 = $2;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 8) {
  $59 = (($this) + 52|0);
  HEAP8[$59>>0] = 0;
  $a1$028 = 0;
 }
 while(1) {
  $63 = $a1$028&255;
  $64 = ((($this) + ($a1$028)|0) + 48|0);
  HEAP8[$64>>0] = $63;
  $65 = (($a1$028) + 1)|0;
  $exitcond = ($65|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $a1$028 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __Z11CopyBuffersRN5physx13PxcNpWorkUnitERNS_18PxcNpThreadContextEb($n,$context,$useContactCache) {
 $n = $n|0;
 $context = $context|0;
 $useContactCache = $useContactCache|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($n) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($n) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($n) + 22|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = $6&65535;
  $8 = $7 & 1;
  $9 = ($8|0)==(0);
  do {
   if ($9) {
    $10 = (($context) + 8770|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = ($11<<24>>24)==(0);
    if ($12) {
     $13 = $7 & 32;
     $14 = ($13|0)==(0);
     if (!($14)) {
      $15 = (($n) + 64|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($16) + 92|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)==(2139095039);
      if (!($19)) {
       label = 8;
       break;
      }
     }
     $20 = $6 & 64;
     $21 = ($20<<16>>16)==(0);
     if ($21) {
      $36 = 0;
     } else {
      $22 = (($n) + 68|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = (($23) + 92|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25|0)==(2139095039);
      if ($26) {
       $36 = 0;
      } else {
       label = 8;
      }
     }
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } while(0);
  if ((label|0) == 8) {
   $27 = (($n) + 20|0);
   $28 = HEAP16[$27>>1]|0;
   $29 = $28&65535;
   $30 = $29 << 2;
   $36 = $30;
  }
  $31 = (($1) + 15)|0;
  $32 = $31 & -16;
  $33 = (($context) + 332|0);
  $34 = $31 | 15;
  $35 = (($34) + ($36))|0;
  $37 = $35 & -16;
  $38 = ($37>>>0)>(16384);
  do {
   if ($38) {
    $39 = HEAP32[$33>>2]|0;
    $40 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($39,$37)|0);
    $$0$i = $40;
   } else {
    $41 = (($context) + 336|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    $$pre$i = (($context) + 340|0);
    if (!($43)) {
     $44 = HEAP32[$$pre$i>>2]|0;
     $45 = (($44) + ($37))|0;
     $46 = ($45>>>0)>(16384);
     if (!($46)) {
      $49 = (($42) + ($44)|0);
      HEAP32[$$pre$i>>2] = $45;
      $$0$i = $49;
      break;
     }
    }
    $47 = HEAP32[$33>>2]|0;
    $48 = (__ZN5physx17PxcNpMemBlockPool19acquireContactBlockEv($47)|0);
    HEAP32[$41>>2] = $48;
    HEAP32[$$pre$i>>2] = $37;
    $$0$i = $48;
   }
  } while(0);
  _memcpy(($$0$i|0),($4|0),($1|0))|0;
  $50 = ($36|0)==(0);
  if ($50) {
   $52 = (($n) + 98|0);
   $53 = HEAP16[$52>>1]|0;
   $54 = $53&65535;
   $55 = $54 & 65519;
   $56 = $55&65535;
   HEAP16[$52>>1] = $56;
  } else {
   $51 = (($$0$i) + ($32)|0);
   _memset(($51|0),0,($36|0))|0;
  }
  HEAP32[$3>>2] = $$0$i;
 }
 $57 = (($n) + 44|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58 & 1;
 $60 = ($59|0)==(0);
 if (!($60)) {
  $61 = (($n) + 56|0);
  $62 = HEAP16[$61>>1]|0;
  $63 = ($62<<16>>16)==(0);
  if ($63) {
   STACKTOP = sp;return;
  }
  $64 = (($context) + 356|0);
  $65 = $62&65535;
  $66 = (__ZN5physx20PxcNpCacheStreamPair7reserveEj($64,$65)|0);
  $67 = HEAP32[$57>>2]|0;
  $68 = $67 & -16;
  $69 = $68;
  $70 = HEAP16[$61>>1]|0;
  $71 = $70&65535;
  _memcpy(($66|0),($69|0),($71|0))|0;
  $72 = $66;
  $73 = $72 | 1;
  HEAP32[$57>>2] = $73;
  STACKTOP = sp;return;
 }
 if (!($useContactCache)) {
  STACKTOP = sp;return;
 }
 $74 = (($n) + 56|0);
 $75 = HEAP16[$74>>1]|0;
 $76 = ($75<<16>>16)==(0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (($n) + 52|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($context) + 356|0);
 $80 = $75&65535;
 $81 = (($80) + 15)|0;
 $82 = $81 & 65520;
 $83 = (__ZN5physx20PxcNpCacheStreamPair7reserveEj($79,$82)|0);
 $84 = HEAP16[$74>>1]|0;
 $85 = $84&65535;
 _memcpy(($83|0),($78|0),($85|0))|0;
 HEAP32[$77>>2] = $83;
 STACKTOP = sp;return;
}
function __ZN5physx22PxcDiscreteNarrowPhaseERNS_18PxcNpThreadContextERNS_13PxcNpWorkUnitE($context,$n) {
 $context = $context|0;
 $n = $n|0;
 var $$ = 0, $$1 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$5 = 0, $$6 = 0, $$7 = 0, $$8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0;
 var $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $brmerge = 0, $contactDistance = 0, $i$01$i = 0, $materialInfo = 0, $tm0memory = 0, $tm1memory = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $tm0memory = sp + 32|0;
 $tm1memory = sp;
 $contactDistance = sp + 60|0;
 $materialInfo = sp + 64|0;
 $0 = (($n) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($n) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($n) + 22|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = $6 & 32;
 $8 = $6 & 64;
 $9 = ($7|0)==(0);
 if ($9) {
  $25 = 0;
 } else {
  $10 = (($1) + 29|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  $25 = $13;
 }
 $14 = ($8|0)==(0);
 if ($14) {
  $26 = 0;
 } else {
  $15 = (($3) + 29|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  $26 = $18;
 }
 $19 = (($n) + 96|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = (($n) + 97|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $brmerge = $25 | $26;
 if (!($brmerge)) {
  $27 = ($23&255)<($20&255);
  $28 = (($context) + 8769|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $34 = 0;
  } else {
   $$1 = $27 ? $21 : $24;
   $$ = $27 ? $24 : $21;
   $31 = ((503536 + (($$*7)|0)|0) + ($$1)|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)!=(0);
   $34 = $33;
  }
  __Z11CopyBuffersRN5physx13PxcNpWorkUnitERNS_18PxcNpThreadContextEb($n,$context,$34);
  STACKTOP = sp;return;
 }
 $35 = (($n) + 72|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($n) + 76|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($n) + 100|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($n) + 104|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($23&255)<($20&255);
 $$2 = $43 ? $1 : $3;
 $$3 = $43 ? $24 : $21;
 $$4 = $43 ? $21 : $24;
 $$5 = $43 ? $38 : $36;
 $$6 = $43 ? $36 : $38;
 $$7 = $43 ? $42 : $40;
 $$8 = $43 ? $40 : $42;
 $44 = (((($context) + (($$3*28)|0)|0) + ($$4<<2)|0) + 104|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 1)|0;
 HEAP32[$44>>2] = $46;
 $47 = ((503592 + (($$3*28)|0)|0) + ($$4<<2)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($context) + 4480|0);
 HEAP32[$49>>2] = 0;
 $50 = (($n) + 98|0);
 HEAP16[$50>>1] = 0;
 $51 = (($n) + 20|0);
 HEAP16[$51>>1] = 0;
 $52 = (($n) + 24|0);
 HEAP32[$52>>2] = 0;
 HEAP32[$n>>2] = 0;
 $53 = (($n) + 16|0);
 HEAP16[$53>>1] = 0;
 $54 = (($n) + 4|0);
 HEAP32[$54>>2] = 0;
 $55 = (($n) + 28|0);
 HEAP32[$55>>2] = 0;
 $56 = (($n) + 32|0);
 HEAP32[$56>>2] = 0;
 $57 = (($context) + 8764|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + 16|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + (($$7*28)|0)|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 HEAPF32[$tm0memory>>2] = $62;
 $63 = ((($60) + (($$7*28)|0)|0) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($tm0memory) + 4|0);
 HEAPF32[$65>>2] = $64;
 $66 = ((($60) + (($$7*28)|0)|0) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($tm0memory) + 8|0);
 HEAPF32[$68>>2] = $67;
 $69 = ((($60) + (($$7*28)|0)|0) + 12|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($tm0memory) + 12|0);
 HEAPF32[$71>>2] = $70;
 $72 = ((($60) + (($$7*28)|0)|0) + 16|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($tm0memory) + 16|0);
 HEAPF32[$74>>2] = $73;
 $75 = ((($60) + (($$7*28)|0)|0) + 20|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($tm0memory) + 20|0);
 HEAPF32[$77>>2] = $76;
 $78 = ((($60) + (($$7*28)|0)|0) + 24|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($tm0memory) + 24|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($60) + (($$8*28)|0)|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 HEAPF32[$tm1memory>>2] = $82;
 $83 = ((($60) + (($$8*28)|0)|0) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($tm1memory) + 4|0);
 HEAPF32[$85>>2] = $84;
 $86 = ((($60) + (($$8*28)|0)|0) + 8|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($tm1memory) + 8|0);
 HEAPF32[$88>>2] = $87;
 $89 = ((($60) + (($$8*28)|0)|0) + 12|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($tm1memory) + 12|0);
 HEAPF32[$91>>2] = $90;
 $92 = ((($60) + (($$8*28)|0)|0) + 16|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($tm1memory) + 16|0);
 HEAPF32[$94>>2] = $93;
 $95 = ((($60) + (($$8*28)|0)|0) + 20|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($tm1memory) + 20|0);
 HEAPF32[$97>>2] = $96;
 $98 = ((($60) + (($$8*28)|0)|0) + 24|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($tm1memory) + 24|0);
 HEAPF32[$100>>2] = $99;
 $101 = (($$5) + 28|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($$6) + 28|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($102 + $104);
 HEAPF32[$contactDistance>>2] = $105;
 $106 = (($context) + 8769|0);
 $107 = HEAP8[$106>>0]|0;
 $108 = ($107<<24>>24)==(0);
 if ($108) {
  label = 12;
 } else {
  $109 = ((503536 + (($$3*7)|0)|0) + ($$4)|0);
  $110 = HEAP8[$109>>0]|0;
  $111 = ($110<<24>>24)==(0);
  if ($111) {
   label = 12;
  } else {
   $112 = (($n) + 44|0);
   $113 = (($$5) + 36|0);
   $114 = (($$6) + 36|0);
   __ZN5physx21PxcCacheLocalContactsENS_14PxGeometryType4EnumES1_RNS_18PxcNpThreadContextERNS_10PxcNpCacheERKNS_11PxTransformES8_fPFbRKNS_2Gu13GeometryUnionESC_S8_S8_RKfS5_RNS9_13ContactBufferEESC_SC_($$3,$$4,$context,$112,$tm0memory,$tm1memory,$105,$48,$113,$114);
  }
 }
 if ((label|0) == 12) {
  $115 = (($$5) + 36|0);
  $116 = (($$6) + 36|0);
  $117 = (($n) + 44|0);
  $118 = (($context) + 384|0);
  (FUNCTION_TABLE_iiiiiiii[$48 & 127]($115,$116,$tm0memory,$tm1memory,$contactDistance,$117,$118)|0);
 }
 $119 = ((504224 + (($$3*28)|0)|0) + ($$4<<2)|0);
 $120 = HEAP32[$119>>2]|0;
 (FUNCTION_TABLE_iiiii[$120 & 511]($$5,$$6,$context,$materialInfo)|0);
 if ($43) {
  $121 = HEAP32[$49>>2]|0;
  $122 = ($121|0)==(0);
  if (!($122)) {
   $i$01$i = 0;
   while(1) {
    $123 = ((($context) + ($i$01$i<<6)|0) + 384|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = Math_fround(-$124);
    $126 = ((($context) + ($i$01$i<<6)|0) + 388|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = Math_fround(-$127);
    $129 = ((($context) + ($i$01$i<<6)|0) + 392|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $131 = Math_fround(-$130);
    HEAPF32[$123>>2] = $125;
    HEAPF32[$126>>2] = $128;
    HEAPF32[$129>>2] = $131;
    $132 = ((($context) + ($i$01$i<<6)|0) + 432|0);
    $133 = ((($context) + ($i$01$i<<6)|0) + 436|0);
    $134 = HEAP32[$132>>2]|0;
    $135 = HEAP32[$133>>2]|0;
    HEAP32[$132>>2] = $135;
    HEAP32[$133>>2] = $134;
    $136 = (($materialInfo) + ($i$01$i<<2)|0);
    $137 = ((($materialInfo) + ($i$01$i<<2)|0) + 2|0);
    $138 = HEAP16[$136>>1]|0;
    $139 = HEAP16[$137>>1]|0;
    HEAP16[$136>>1] = $139;
    HEAP16[$137>>1] = $138;
    $140 = (($i$01$i) + 1)|0;
    $141 = HEAP32[$49>>2]|0;
    $142 = ($140>>>0)<($141>>>0);
    if ($142) {
     $i$01$i = $140;
    } else {
     break;
    }
   }
  }
 }
 (__ZN5physx14finishContactsERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($n,$context,$materialInfo)|0);
 STACKTOP = sp;return;
}
function __ZN5physx25PxcDiscreteNarrowPhasePCMERNS_18PxcNpThreadContextERNS_13PxcNpWorkUnitE($context,$n) {
 $context = $context|0;
 $n = $n|0;
 var $$ = 0, $$10 = 0, $$11 = 0, $$9 = 0, $$lcssa$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0);
 var $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0;
 var $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0);
 var $97 = 0, $98 = 0, $99 = Math_fround(0), $a$039$i = 0, $b$038$i = 0, $brmerge = 0, $buff$040$i = 0, $contactDistance = 0, $cp$0$i3 = 0, $cp$0$i6 = 0, $i$01$i = 0, $isMultiManifold$0$off0 = 0, $materialInfo = 0, $phitmp$i = 0, $phitmp45$i = 0, $tm0memory = 0, $tm0memory$tm1memory = 0, $tm1memory = 0, $tm1memory$tm0memory = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $tm0memory = sp + 32|0;
 $tm1memory = sp;
 $contactDistance = sp + 60|0;
 $materialInfo = sp + 64|0;
 $0 = (($n) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($n) + 22|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 & 32;
 $6 = $4 & 64;
 $7 = ($5|0)==(0);
 if ($7) {
  $25 = 0;
 } else {
  $8 = (($n) + 64|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 29|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  $25 = $13;
 }
 $14 = ($6|0)==(0);
 if ($14) {
  $26 = 0;
 } else {
  $15 = (($1) + 29|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  $26 = $18;
 }
 $19 = (($n) + 96|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = (($n) + 97|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $brmerge = $25 | $26;
 if (!($brmerge)) {
  __Z11CopyBuffersRN5physx13PxcNpWorkUnitERNS_18PxcNpThreadContextEb($n,$context,0);
  STACKTOP = sp;return;
 }
 $27 = (($context) + 4496|0);
 $28 = (($n) + 72|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($n) + 76|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($n) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 & 1;
 $35 = ($34|0)==(0);
 if ($35) {
  $40 = $33;
  $41 = HEAP32[$32>>2]|0;
  $42 = $41;
  $43 = (_bitshift64Lshr(($41|0),0,6)|0);
  $44 = tempRet0;
  $45 = (_i64Add(($41|0),0,127,0)|0);
  $46 = tempRet0;
  $47 = (_bitshift64Lshr(($45|0),($46|0),6)|0);
  $48 = tempRet0;
  $49 = (_i64Subtract(1,0,($43|0),($44|0))|0);
  $50 = tempRet0;
  $51 = (_i64Add(($49|0),($50|0),($47|0),($48|0))|0);
  $52 = tempRet0;
  $54 = $51;$55 = $52;$cp$0$i3 = $42;
  while(1) {
   $53 = (($cp$0$i3) + 64|0);
   $56 = (_i64Add(($54|0),($55|0),-1,-1)|0);
   $57 = tempRet0;
   $58 = ($56|0)==(0);
   $59 = ($57|0)==(0);
   $60 = $58 & $59;
   if ($60) {
    break;
   } else {
    $54 = $56;$55 = $57;$cp$0$i3 = $53;
   }
  }
  $61 = HEAP32[$32>>2]|0;
  $62 = $61;
  $63 = (_bitshift64Lshr(($61|0),0,6)|0);
  $64 = tempRet0;
  $65 = (_i64Add(($61|0),0,255,0)|0);
  $66 = tempRet0;
  $67 = (_bitshift64Lshr(($65|0),($66|0),6)|0);
  $68 = tempRet0;
  $69 = (_i64Subtract(1,0,($63|0),($64|0))|0);
  $70 = tempRet0;
  $71 = (_i64Add(($69|0),($70|0),($67|0),($68|0))|0);
  $72 = tempRet0;
  $74 = $71;$75 = $72;$cp$0$i6 = $62;
  while(1) {
   $73 = (($cp$0$i6) + 64|0);
   $76 = (_i64Add(($74|0),($75|0),-1,-1)|0);
   $77 = tempRet0;
   $78 = ($76|0)==(0);
   $79 = ($77|0)==(0);
   $80 = $78 & $79;
   if ($80) {
    $isMultiManifold$0$off0 = 0;
    break;
   } else {
    $74 = $76;$75 = $77;$cp$0$i6 = $73;
   }
  }
 } else {
  $36 = $33 & -2;
  $37 = $36;
  __ZN5physx2Gu33MultiplePersistentContactManifold10fromBufferEPh($27,$37);
  $38 = $27;
  $39 = $38 | 1;
  HEAP32[$32>>2] = $39;
  $isMultiManifold$0$off0 = 1;
 }
 $81 = (($context) + 8764|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($n) + 100|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 16|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + (($84*28)|0)|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 HEAPF32[$tm0memory>>2] = $88;
 $89 = ((($86) + (($84*28)|0)|0) + 4|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($tm0memory) + 4|0);
 HEAPF32[$91>>2] = $90;
 $92 = ((($86) + (($84*28)|0)|0) + 8|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($tm0memory) + 8|0);
 HEAPF32[$94>>2] = $93;
 $95 = ((($86) + (($84*28)|0)|0) + 12|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($tm0memory) + 12|0);
 HEAPF32[$97>>2] = $96;
 $98 = ((($86) + (($84*28)|0)|0) + 16|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($tm0memory) + 16|0);
 HEAPF32[$100>>2] = $99;
 $101 = ((($86) + (($84*28)|0)|0) + 20|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($tm0memory) + 20|0);
 HEAPF32[$103>>2] = $102;
 $104 = ((($86) + (($84*28)|0)|0) + 24|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($tm0memory) + 24|0);
 HEAPF32[$106>>2] = $105;
 $107 = (($n) + 104|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($86) + (($108*28)|0)|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 HEAPF32[$tm1memory>>2] = $110;
 $111 = ((($86) + (($108*28)|0)|0) + 4|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($tm1memory) + 4|0);
 HEAPF32[$113>>2] = $112;
 $114 = ((($86) + (($108*28)|0)|0) + 8|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($tm1memory) + 8|0);
 HEAPF32[$116>>2] = $115;
 $117 = ((($86) + (($108*28)|0)|0) + 12|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($tm1memory) + 12|0);
 HEAPF32[$119>>2] = $118;
 $120 = ((($86) + (($108*28)|0)|0) + 16|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($tm1memory) + 16|0);
 HEAPF32[$122>>2] = $121;
 $123 = ((($86) + (($108*28)|0)|0) + 20|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($tm1memory) + 20|0);
 HEAPF32[$125>>2] = $124;
 $126 = ((($86) + (($108*28)|0)|0) + 24|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($tm1memory) + 24|0);
 HEAPF32[$128>>2] = $127;
 $129 = (($29) + 28|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($31) + 28|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($130 + $132);
 HEAPF32[$contactDistance>>2] = $133;
 $134 = ($23&255)<($20&255);
 $$ = $134 ? $24 : $21;
 $$9 = $134 ? $21 : $24;
 $$10 = $134 ? $31 : $29;
 $$11 = $134 ? $29 : $31;
 $tm0memory$tm1memory = $134 ? $tm0memory : $tm1memory;
 $tm1memory$tm0memory = $134 ? $tm1memory : $tm0memory;
 $135 = (((($context) + (($$*28)|0)|0) + ($$9<<2)|0) + 104|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = (($136) + 1)|0;
 HEAP32[$135>>2] = $137;
 $138 = ((503792 + (($$*28)|0)|0) + ($$9<<2)|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = (($context) + 4480|0);
 HEAP32[$140>>2] = 0;
 $141 = (($n) + 98|0);
 HEAP16[$141>>1] = 0;
 $142 = (($n) + 20|0);
 HEAP16[$142>>1] = 0;
 $143 = (($n) + 24|0);
 HEAP32[$143>>2] = 0;
 HEAP32[$n>>2] = 0;
 $144 = (($n) + 16|0);
 HEAP16[$144>>1] = 0;
 $145 = (($n) + 4|0);
 HEAP32[$145>>2] = 0;
 $146 = (($n) + 28|0);
 HEAP32[$146>>2] = 0;
 $147 = (($n) + 32|0);
 HEAP32[$147>>2] = 0;
 $148 = (($$10) + 36|0);
 $149 = (($$11) + 36|0);
 $150 = (($context) + 384|0);
 (FUNCTION_TABLE_iiiiiiii[$139 & 127]($148,$149,$tm1memory$tm0memory,$tm0memory$tm1memory,$contactDistance,$32,$150)|0);
 $151 = ((504224 + (($$*28)|0)|0) + ($$9<<2)|0);
 $152 = HEAP32[$151>>2]|0;
 (FUNCTION_TABLE_iiiii[$152 & 511]($$10,$$11,$context,$materialInfo)|0);
 if ($134) {
  $153 = HEAP32[$140>>2]|0;
  $154 = ($153|0)==(0);
  if (!($154)) {
   $i$01$i = 0;
   while(1) {
    $155 = ((($context) + ($i$01$i<<6)|0) + 384|0);
    $156 = Math_fround(HEAPF32[$155>>2]);
    $157 = Math_fround(-$156);
    $158 = ((($context) + ($i$01$i<<6)|0) + 388|0);
    $159 = Math_fround(HEAPF32[$158>>2]);
    $160 = Math_fround(-$159);
    $161 = ((($context) + ($i$01$i<<6)|0) + 392|0);
    $162 = Math_fround(HEAPF32[$161>>2]);
    $163 = Math_fround(-$162);
    HEAPF32[$155>>2] = $157;
    HEAPF32[$158>>2] = $160;
    HEAPF32[$161>>2] = $163;
    $164 = ((($context) + ($i$01$i<<6)|0) + 432|0);
    $165 = ((($context) + ($i$01$i<<6)|0) + 436|0);
    $166 = HEAP32[$164>>2]|0;
    $167 = HEAP32[$165>>2]|0;
    HEAP32[$164>>2] = $167;
    HEAP32[$165>>2] = $166;
    $168 = (($materialInfo) + ($i$01$i<<2)|0);
    $169 = ((($materialInfo) + ($i$01$i<<2)|0) + 2|0);
    $170 = HEAP16[$168>>1]|0;
    $171 = HEAP16[$169>>1]|0;
    HEAP16[$168>>1] = $171;
    HEAP16[$169>>1] = $170;
    $172 = (($i$01$i) + 1)|0;
    $173 = HEAP32[$140>>2]|0;
    $174 = ($172>>>0)<($173>>>0);
    if ($174) {
     $i$01$i = $172;
    } else {
     break;
    }
   }
  }
 }
 if ($isMultiManifold$0$off0) {
  $175 = (($context) + 4548|0);
  $176 = HEAP8[$175>>0]|0;
  $177 = $176&255;
  $178 = $177 << 4;
  $179 = (($178) + 48)|0;
  $180 = (($27) + 53|0);
  $181 = HEAP8[$180>>0]|0;
  $182 = $181&255;
  $183 = ($182*48)|0;
  $184 = (($179) + ($183))|0;
  $185 = (($context) + 356|0);
  $186 = (__ZN5physx20PxcNpCacheStreamPair7reserveEj($185,$184)|0);
  $187 = HEAP8[$175>>0]|0;
  $188 = $187&255;
  $189 = (($186) + 32|0);
  HEAP32[$189>>2] = $188;
  ;HEAP32[$186+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$186+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$186+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$186+12>>2]=HEAP32[$27+12>>2]|0;HEAP32[$186+16>>2]=HEAP32[$27+16>>2]|0;HEAP32[$186+20>>2]=HEAP32[$27+20>>2]|0;HEAP32[$186+24>>2]=HEAP32[$27+24>>2]|0;HEAP32[$186+28>>2]=HEAP32[$27+28>>2]|0;
  $190 = HEAP8[$175>>0]|0;
  $191 = ($190<<24>>24)==(0);
  if (!($191)) {
   $192 = (($186) + 48|0);
   $a$039$i = 0;$buff$040$i = $192;
   while(1) {
    $193 = (($buff$040$i) + 16|0);
    $194 = ((($27) + ($a$039$i)|0) + 48|0);
    $195 = HEAP8[$194>>0]|0;
    $196 = $195&255;
    $197 = ((($27) + (($196*400)|0)|0) + 448|0);
    $198 = HEAP32[$197>>2]|0;
    HEAP32[$buff$040$i>>2] = $198;
    $199 = HEAP32[$197>>2]|0;
    $200 = ($199|0)==(0);
    if ($200) {
     $$lcssa$i = 16;
    } else {
     $b$038$i = 0;
     while(1) {
      $201 = (((($27) + (($196*400)|0)|0) + ($b$038$i<<6)|0) + 64|0);
      $202 = Math_fround(HEAPF32[$201>>2]);
      $203 = (((($27) + (($196*400)|0)|0) + ($b$038$i<<6)|0) + 68|0);
      $204 = Math_fround(HEAPF32[$203>>2]);
      $205 = (((($27) + (($196*400)|0)|0) + ($b$038$i<<6)|0) + 72|0);
      $206 = Math_fround(HEAPF32[$205>>2]);
      $207 = (($193) + (($b$038$i*48)|0)|0);
      HEAPF32[$207>>2] = $202;
      $208 = (($207) + 4|0);
      HEAPF32[$208>>2] = $204;
      $209 = (($207) + 8|0);
      HEAPF32[$209>>2] = $206;
      $210 = (($207) + 12|0);
      HEAPF32[$210>>2] = Math_fround(0.0);
      $211 = (((($27) + (($196*400)|0)|0) + ($b$038$i<<6)|0) + 80|0);
      $212 = Math_fround(HEAPF32[$211>>2]);
      $213 = (((($27) + (($196*400)|0)|0) + ($b$038$i<<6)|0) + 84|0);
      $214 = Math_fround(HEAPF32[$213>>2]);
      $215 = (((($27) + (($196*400)|0)|0) + ($b$038$i<<6)|0) + 88|0);
      $216 = Math_fround(HEAPF32[$215>>2]);
      $217 = ((($193) + (($b$038$i*48)|0)|0) + 16|0);
      HEAPF32[$217>>2] = $212;
      $218 = (($217) + 4|0);
      HEAPF32[$218>>2] = $214;
      $219 = (($217) + 8|0);
      HEAPF32[$219>>2] = $216;
      $220 = (($217) + 12|0);
      HEAPF32[$220>>2] = Math_fround(0.0);
      $221 = (((($27) + (($196*400)|0)|0) + ($b$038$i<<6)|0) + 96|0);
      $222 = ((($193) + (($b$038$i*48)|0)|0) + 32|0);
      _memmove(($222|0),($221|0),16)|0;
      $223 = (((($27) + (($196*400)|0)|0) + ($b$038$i<<6)|0) + 112|0);
      $224 = HEAP32[$223>>2]|0;
      $225 = ((($193) + (($b$038$i*48)|0)|0) + 12|0);
      HEAP32[$225>>2] = $224;
      $226 = (($b$038$i) + 1)|0;
      $227 = HEAP32[$197>>2]|0;
      $228 = ($226>>>0)<($227>>>0);
      if ($228) {
       $b$038$i = $226;
      } else {
       break;
      }
     }
     $phitmp$i = ($227*48)|0;
     $phitmp45$i = (($phitmp$i) + 16)|0;
     $$lcssa$i = $phitmp45$i;
    }
    $229 = (($buff$040$i) + ($$lcssa$i)|0);
    $230 = (($a$039$i) + 1)|0;
    $231 = HEAP8[$175>>0]|0;
    $232 = $231&255;
    $233 = ($230>>>0)<($232>>>0);
    if ($233) {
     $a$039$i = $230;$buff$040$i = $229;
    } else {
     break;
    }
   }
  }
  $234 = $186;
  $235 = $234 | 1;
  HEAP32[$32>>2] = $235;
  $236 = $184&65535;
  $237 = (($n) + 56|0);
  HEAP16[$237>>1] = $236;
 }
 (__ZN5physx14finishContactsERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($n,$context,$materialInfo)|0);
 STACKTOP = sp;return;
}
function __ZN5physx13PxcRunNpBatchEjjjjjPNS_16PxsThreadContextERNS_17PxcNpMemBlockPoolEjjPNS_15PxcNpBatchEntryEjS5_jS5_jS5_jS5_jS5_jPjjRjS7_PNS_14PxLightCpuTaskERNS_2Cm9FlushPoolE($numSpusPrim,$numSpusCnvx,$numSpusHF,$numSpusMesh,$numSpusCnvxMesh,$context,$memBlockPool,$numContactBlocks,$numNpCacheBlocksBlocks,$entriesPrimVsPrim,$numEntriesPrimVsPrim,$entriesPrimOrCnvxVsCnvx,$numEntriesPrimOrCnvxVsCnvx,$entriesPrimOrCnvxVsHF,$numEntriesPrimOrCnvxVsHF,$entriesPrimVsTrimesh,$numEntriesPrimVsTrimesh,$entriesCvxBoxVsTrimesh,$numEntriesCvxBoxVsTrimesh,$entriesOther,$numEntriesOther,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound,$continuation,$taskPool) {
 $numSpusPrim = $numSpusPrim|0;
 $numSpusCnvx = $numSpusCnvx|0;
 $numSpusHF = $numSpusHF|0;
 $numSpusMesh = $numSpusMesh|0;
 $numSpusCnvxMesh = $numSpusCnvxMesh|0;
 $context = $context|0;
 $memBlockPool = $memBlockPool|0;
 $numContactBlocks = $numContactBlocks|0;
 $numNpCacheBlocksBlocks = $numNpCacheBlocksBlocks|0;
 $entriesPrimVsPrim = $entriesPrimVsPrim|0;
 $numEntriesPrimVsPrim = $numEntriesPrimVsPrim|0;
 $entriesPrimOrCnvxVsCnvx = $entriesPrimOrCnvxVsCnvx|0;
 $numEntriesPrimOrCnvxVsCnvx = $numEntriesPrimOrCnvxVsCnvx|0;
 $entriesPrimOrCnvxVsHF = $entriesPrimOrCnvxVsHF|0;
 $numEntriesPrimOrCnvxVsHF = $numEntriesPrimOrCnvxVsHF|0;
 $entriesPrimVsTrimesh = $entriesPrimVsTrimesh|0;
 $numEntriesPrimVsTrimesh = $numEntriesPrimVsTrimesh|0;
 $entriesCvxBoxVsTrimesh = $entriesCvxBoxVsTrimesh|0;
 $numEntriesCvxBoxVsTrimesh = $numEntriesCvxBoxVsTrimesh|0;
 $entriesOther = $entriesOther|0;
 $numEntriesOther = $numEntriesOther|0;
 $changeBitmapBase = $changeBitmapBase|0;
 $changeBitmapWordCount = $changeBitmapWordCount|0;
 $touchLost = $touchLost|0;
 $touchFound = $touchFound|0;
 $continuation = $continuation|0;
 $taskPool = $taskPool|0;
 var $$ = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$touchLost>>2] = 0;
 HEAP32[$touchFound>>2] = 0;
 $0 = ($context|0)==(0|0);
 $1 = (($context) + 16|0);
 $$ = $0 ? 0 : $1;
 __Z13runNpBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesPrimVsPrim,0,$numEntriesPrimVsPrim,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 __Z13runNpBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesPrimOrCnvxVsCnvx,0,$numEntriesPrimOrCnvxVsCnvx,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 __Z13runNpBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesPrimOrCnvxVsHF,0,$numEntriesPrimOrCnvxVsHF,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 __Z13runNpBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesPrimVsTrimesh,0,$numEntriesPrimVsTrimesh,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 __Z13runNpBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesCvxBoxVsTrimesh,0,$numEntriesCvxBoxVsTrimesh,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 __Z13runNpBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesOther,0,$numEntriesOther,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 STACKTOP = sp;return;
}
function __ZN5physx16PxcRunNpPCMBatchEjjjPNS_16PxsThreadContextERNS_17PxcNpMemBlockPoolEjjPNS_15PxcNpBatchEntryEjS5_jS5_jS5_jPjjRjS7_PNS_14PxLightCpuTaskERNS_2Cm9FlushPoolE($numSpusCnvx,$numSpusHF,$numSpusMesh,$context,$memBlockPool,$numContactBlocks,$numNpCacheBlocks,$entriesPrimVsPrim,$numEntriesPrimVsPrim,$entriesPrimOrCnvxVsHF,$numEntriesPrimOrCnvxVsHF,$entriesPrimOrCnvxVsTrimesh,$numEntriesPrimOrCnvxVsTrimesh,$entriesOther,$numEntriesOther,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound,$continuation,$taskPool) {
 $numSpusCnvx = $numSpusCnvx|0;
 $numSpusHF = $numSpusHF|0;
 $numSpusMesh = $numSpusMesh|0;
 $context = $context|0;
 $memBlockPool = $memBlockPool|0;
 $numContactBlocks = $numContactBlocks|0;
 $numNpCacheBlocks = $numNpCacheBlocks|0;
 $entriesPrimVsPrim = $entriesPrimVsPrim|0;
 $numEntriesPrimVsPrim = $numEntriesPrimVsPrim|0;
 $entriesPrimOrCnvxVsHF = $entriesPrimOrCnvxVsHF|0;
 $numEntriesPrimOrCnvxVsHF = $numEntriesPrimOrCnvxVsHF|0;
 $entriesPrimOrCnvxVsTrimesh = $entriesPrimOrCnvxVsTrimesh|0;
 $numEntriesPrimOrCnvxVsTrimesh = $numEntriesPrimOrCnvxVsTrimesh|0;
 $entriesOther = $entriesOther|0;
 $numEntriesOther = $numEntriesOther|0;
 $changeBitmapBase = $changeBitmapBase|0;
 $changeBitmapWordCount = $changeBitmapWordCount|0;
 $touchLost = $touchLost|0;
 $touchFound = $touchFound|0;
 $continuation = $continuation|0;
 $taskPool = $taskPool|0;
 var $$ = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$touchLost>>2] = 0;
 HEAP32[$touchFound>>2] = 0;
 $0 = ($context|0)==(0|0);
 $1 = (($context) + 16|0);
 $$ = $0 ? 0 : $1;
 __Z16runNpPCMBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesPrimVsPrim,0,$numEntriesPrimVsPrim,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 __Z16runNpPCMBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesPrimOrCnvxVsHF,0,$numEntriesPrimOrCnvxVsHF,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 __Z16runNpPCMBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesPrimOrCnvxVsTrimesh,0,$numEntriesPrimOrCnvxVsTrimesh,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 __Z16runNpPCMBatchPPUPN5physx18PxcNpThreadContextEPNS_15PxcNpBatchEntryEjjPjjRjS5_($$,$entriesOther,0,$numEntriesOther,$changeBitmapBase,$changeBitmapWordCount,$touchLost,$touchFound);
 STACKTOP = sp;return;
}
function __ZN5physx20PxcNpCacheStreamPair5resetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx20PxcNpCacheStreamPairC2ERNS_17PxcNpMemBlockPoolE($this,$blockPool) {
 $this = $this|0;
 $blockPool = $blockPool|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $blockPool;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx20PxcNpCacheStreamPair7reserveEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($size) + 15)|0;
 $1 = $0 & -16;
 $2 = ($1>>>0)>(16384);
 if ($2) {
  $$0 = (-1);
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $$pre = (($this) + 12|0);
 if ($5) {
  label = 4;
 } else {
  $6 = HEAP32[$$pre>>2]|0;
  $7 = (($6) + ($1))|0;
  $8 = ($7>>>0)>(16384);
  if ($8) {
   label = 4;
  } else {
   $14 = $4;$15 = $6;
  }
 }
 if ((label|0) == 4) {
  $9 = HEAP32[$this>>2]|0;
  $10 = (__ZN5physx17PxcNpMemBlockPool19acquireNpCacheBlockEv($9)|0);
  HEAP32[$3>>2] = $10;
  HEAP32[$$pre>>2] = 0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $14 = $10;$15 = 0;
  }
 }
 $12 = (($this) + 12|0);
 $13 = (($14) + ($15)|0);
 $16 = (($15) + ($1))|0;
 HEAP32[$12>>2] = $16;
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx28createFinalizeSolverContactsERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEbbRNS_23PxcSolverConstraintDescEPKNS_13PxcSolverBodyES8_PKNS_17PxcSolverBodyDataESB_PKNS_12PxsRigidCoreESE_ffffRNS_25PxsConstraintBlockManagerENS_14PxFrictionType4EnumE($n,$threadContext,$forceContacts,$perPointFriction,$desc,$sBody0,$sBody1,$solverBodyData0,$solverBodyData1,$body0,$body1,$invDtF32,$bounceThresholdF32,$frictionOffsetThreshold,$correlationDistance,$constraintBlockManager,$frictionType) {
 $n = $n|0;
 $threadContext = $threadContext|0;
 $forceContacts = $forceContacts|0;
 $perPointFriction = $perPointFriction|0;
 $desc = $desc|0;
 $sBody0 = $sBody0|0;
 $sBody1 = $sBody1|0;
 $solverBodyData0 = $solverBodyData0|0;
 $solverBodyData1 = $solverBodyData1|0;
 $body0 = $body0|0;
 $body1 = $body1|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $frictionOffsetThreshold = Math_fround($frictionOffsetThreshold);
 $correlationDistance = Math_fround($correlationDistance);
 $constraintBlockManager = $constraintBlockManager|0;
 $frictionType = $frictionType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i17$i = 0, $$0136 = 0, $$1$ph = 0, $$14$i = 0, $$9$i = 0, $$constraintBlock$0$i = 0, $$not$i = 0, $$not10$i = 0, $$not8$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i15$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $$sum23 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0;
 var $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0);
 var $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = 0;
 var $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = Math_fround(0);
 var $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0);
 var $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $axisConstraintCount = 0, $b0 = 0, $b1 = 0, $bodyFrame0$0 = 0, $bodyFrame1$0 = 0, $constraintBlock$0$i = 0, $constraintBlock$0$i8 = 0, $extract$t = 0;
 var $faceIndices$0$off0$i$i = 0, $frictionPatchByteSize$i = 0, $frictionPatches$0$i = 0, $frictionPatches$0$i1024 = 0, $frictionPatches$0$i11 = 0, $i$025 = 0, $idt = 0, $modify$0$off0$i$i = 0, $numContacts$035 = 0, $numContacts$1$ph = 0, $numFrictionPatches = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond5$i = 0, $or$cond7$i = 0, $phitmp = 0, $phitmp$i$i = 0, $response$0$off0$i$i = 0, $solverConstraintByteSize = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $frictionPatchByteSize$i = sp + 64|0;
 $idt = sp;
 $numFrictionPatches = sp + 28|0;
 $solverConstraintByteSize = sp + 32|0;
 $axisConstraintCount = sp + 36|0;
 $b0 = sp + 40|0;
 $b1 = sp + 52|0;
 $0 = $perPointFriction&1;
 $1 = (($threadContext) + 384|0);
 $2 = (($desc) + 26|0);
 HEAP16[$2>>1] = 0;
 $3 = (($threadContext) + 4480|0);
 HEAP32[$3>>2] = 0;
 $4 = (($n) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 HEAPF32[$idt>>2] = Math_fround(0.0);
 $6 = (($idt) + 4|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($idt) + 8|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($idt) + 12|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($idt) + 16|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($idt) + 20|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($idt) + 24|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($n) + 22|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13 & 32;
 $15 = ($14<<16>>16)==(0);
 $bodyFrame0$0 = $15 ? $idt : $body0;
 $16 = $13 & 64;
 $17 = ($16<<16>>16)==(0);
 $bodyFrame1$0 = $17 ? $idt : $body1;
 $18 = (($n) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 do {
  if (!($20)) {
   $21 = (($n) + 32|0);
   $22 = HEAP32[$21>>2]|0;
   HEAPF32[$frictionPatchByteSize$i>>2] = Math_fround(0.0);
   $23 = (($frictionPatchByteSize$i) + 4|0);
   HEAPF32[$23>>2] = Math_fround(0.0);
   $24 = (($frictionPatchByteSize$i) + 8|0);
   HEAPF32[$24>>2] = Math_fround(0.0);
   $25 = (($frictionPatchByteSize$i) + 36|0);
   HEAP32[$25>>2] = $22;
   $26 = (($frictionPatchByteSize$i) + 40|0);
   HEAP32[$26>>2] = 0;
   $27 = (($frictionPatchByteSize$i) + 44|0);
   HEAP32[$27>>2] = 0;
   $28 = (($frictionPatchByteSize$i) + 12|0);
   HEAP32[$28>>2] = $19;
   $29 = ($22|0)==(0);
   if ($29) {
    $51 = 0;$53 = 0;$55 = 0;$faceIndices$0$off0$i$i = 0;$modify$0$off0$i$i = 0;$response$0$off0$i$i = 1;
   } else {
    $30 = (($19) + 2|0);
    $31 = HEAP16[$30>>1]|0;
    $32 = $31&65535;
    $33 = $32 & 2;
    $34 = ($33|0)!=(0);
    $35 = $32 & 1;
    $36 = ($35|0)!=(0);
    $37 = $33 << 3;
    $38 = $37 | 4;
    $39 = (($19) + ($38)|0);
    $40 = $34 ? 4 : 32;
    if ($34) {
     $377 = 72;
    } else {
     $41 = $35 << 3;
     $42 = $41 | 16;
     $377 = $42;
    }
    $43 = $31 & 4;
    $phitmp$i$i = ($43<<16>>16)!=(0);
    $51 = $40;$53 = $377;$55 = $39;$faceIndices$0$off0$i$i = $36;$modify$0$off0$i$i = $34;$response$0$off0$i$i = $phitmp$i$i;
   }
   $44 = $modify$0$off0$i$i&1;
   $45 = (($frictionPatchByteSize$i) + 60|0);
   HEAP32[$45>>2] = $44;
   $46 = $faceIndices$0$off0$i$i&1;
   $47 = (($frictionPatchByteSize$i) + 56|0);
   HEAP32[$47>>2] = $46;
   $48 = $response$0$off0$i$i&1;
   $49 = (($frictionPatchByteSize$i) + 64|0);
   HEAP32[$49>>2] = $48;
   $50 = (($frictionPatchByteSize$i) + 48|0);
   HEAP32[$50>>2] = $51;
   $52 = (($frictionPatchByteSize$i) + 52|0);
   HEAP32[$52>>2] = $53;
   $54 = (($frictionPatchByteSize$i) + 24|0);
   HEAP32[$54>>2] = $55;
   $56 = (($frictionPatchByteSize$i) + 28|0);
   HEAP32[$56>>2] = $55;
   $57 = (($frictionPatchByteSize$i) + 16|0);
   HEAP32[$57>>2] = $55;
   if (!($response$0$off0$i$i)) {
    if ($modify$0$off0$i$i) {
     $58 = (($19) + 4|0);
     $59 = Math_fround(HEAPF32[$58>>2]);
     $60 = (($19) + 8|0);
     $61 = Math_fround(HEAPF32[$60>>2]);
     $62 = (($19) + 12|0);
     $63 = Math_fround(HEAPF32[$62>>2]);
     $64 = (($19) + 16|0);
     $65 = Math_fround(HEAPF32[$64>>2]);
     $371 = $59;$372 = $63;$373 = $61;$374 = $65;$72 = $44;
    } else {
     $371 = Math_fround(1.0);$372 = Math_fround(1.0);$373 = Math_fround(1.0);$374 = Math_fround(1.0);$72 = 0;
    }
    $66 = $55;
    $67 = $19;
    $68 = (($66) - ($67))|0;
    $69 = ($68>>>0)<($22>>>0);
    if (!($69)) {
     HEAP32[$3>>2] = 0;
     break;
    }
    $70 = (($frictionPatchByteSize$i) + 32|0);
    $$sum = (($53) + 128)|0;
    $71 = ($72|0)==(0);
    $$0136 = $0;$378 = $55;$379 = 0;$380 = 0;$79 = $55;$81 = $19;$83 = $66;$numContacts$035 = 0;
    while(1) {
     HEAP32[$54>>2] = $79;
     $80 = $81;
     $82 = (($83) - ($80))|0;
     $84 = ($82>>>0)<($22>>>0);
     if ($84) {
      $85 = HEAP16[$79>>1]|0;
      $86 = $85&65535;
      HEAP32[$26>>2] = $86;
      $87 = Math_imul($53, $86)|0;
      $$sum$i = (($87) + ($51))|0;
      $88 = (($79) + ($$sum$i)|0);
      HEAP32[$56>>2] = $88;
      $89 = (($79) + ($51)|0);
      HEAP32[$57>>2] = $89;
      HEAP32[$27>>2] = 0;
      $383 = $89;$384 = 0;$94 = $86;
     } else {
      HEAP32[$56>>2] = $79;
      $383 = $378;$384 = $379;$94 = $380;
     }
     $$1$ph = $$0136;$93 = $384;$98 = $383;$numContacts$1$ph = $numContacts$035;
     L22: while(1) {
      $90 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 384|0);
      $$sum23 = (($numContacts$1$ph) + 2)|0;
      $91 = ((($threadContext) + ($$sum23<<6)|0) + 384|0);
      if ($71) {
       $92 = ($93>>>0)<($94>>>0);
       if (!($92)) {
        $381 = $98;$382 = $93;
        break;
       }
       $97 = (($93) + 1)|0;
       HEAP32[$27>>2] = $97;
       HEAP32[$70>>2] = $98;
       $99 = (($98) + ($53)|0);
       HEAP32[$57>>2] = $99;
       $100 = (($98) + ($$sum)|0);
       $385 = $99;$386 = $97;$387 = $90;$388 = Math_fround(3.40282346638528859812E+38);
       label = 24;
      } else {
       $102 = $98;$96 = $93;
       while(1) {
        $95 = ($96>>>0)<($94>>>0);
        if (!($95)) {
         $381 = $102;$382 = $96;
         break L22;
        }
        $101 = (($96) + 1)|0;
        HEAP32[$27>>2] = $101;
        HEAP32[$70>>2] = $102;
        $103 = (($102) + ($53)|0);
        HEAP32[$57>>2] = $103;
        $104 = (($102) + ($$sum)|0);
        $105 = HEAP32[$70>>2]|0;
        $106 = (($105) + 48|0);
        $107 = Math_fround(HEAPF32[$106>>2]);
        $108 = $107 != Math_fround(0.0);
        if ($108) {
         break;
        } else {
         $102 = $103;$96 = $101;
        }
       }
       if ($71) {
        $385 = $103;$386 = $101;$387 = $90;$388 = $107;
        label = 24;
       } else {
        $109 = HEAP32[$70>>2]|0;
        $110 = (($109) + 24|0);
        $114 = $110;$115 = $90;$123 = $109;$147 = $107;$389 = $103;$390 = $101;
       }
      }
      if ((label|0) == 24) {
       label = 0;
       $111 = HEAP32[$54>>2]|0;
       $112 = (($111) + 4|0);
       $$pre44 = HEAP32[$70>>2]|0;
       $114 = $112;$115 = $387;$123 = $$pre44;$147 = $388;$389 = $385;$390 = $386;
      }
      $113 = Math_fround(HEAPF32[$114>>2]);
      HEAPF32[$115>>2] = $113;
      $116 = (($114) + 4|0);
      $117 = Math_fround(HEAPF32[$116>>2]);
      $118 = (($115) + 4|0);
      HEAPF32[$118>>2] = $117;
      $119 = (($114) + 8|0);
      $120 = Math_fround(HEAPF32[$119>>2]);
      $121 = (($115) + 8|0);
      HEAPF32[$121>>2] = $120;
      $122 = Math_fround(HEAPF32[$123>>2]);
      $124 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 400|0);
      HEAPF32[$124>>2] = $122;
      $125 = (($123) + 4|0);
      $126 = Math_fround(HEAPF32[$125>>2]);
      $127 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 404|0);
      HEAPF32[$127>>2] = $126;
      $128 = (($123) + 8|0);
      $129 = Math_fround(HEAPF32[$128>>2]);
      $130 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 408|0);
      HEAPF32[$130>>2] = $129;
      $131 = (($123) + 12|0);
      $132 = Math_fround(HEAPF32[$131>>2]);
      $133 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 396|0);
      HEAPF32[$133>>2] = $132;
      if ($71) {
       $158 = HEAP32[$54>>2]|0;
       $159 = (($158) + 28|0);
       $160 = HEAP16[$159>>1]|0;
       $161 = $160&65535;
       $162 = (($158) + 30|0);
       $163 = HEAP16[$162>>1]|0;
       $164 = $163&65535;
       $165 = $164 << 16;
       $166 = $165 | $161;
       $167 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 432|0);
       HEAP32[$167>>2] = $166;
       $168 = HEAP32[$54>>2]|0;
       $169 = (($168) + 2|0);
       $170 = HEAP16[$169>>1]|0;
       $171 = $170&65535;
       $172 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 436|0);
       HEAP32[$172>>2] = $171;
       $173 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 412|0);
       HEAPF32[$173>>2] = $147;
       $174 = HEAP32[$54>>2]|0;
       $175 = (($174) + 16|0);
       $176 = Math_fround(HEAPF32[$175>>2]);
       $177 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 428|0);
       HEAPF32[$177>>2] = $176;
       $178 = HEAP32[$54>>2]|0;
       $179 = (($178) + 20|0);
       $180 = Math_fround(HEAPF32[$179>>2]);
       $181 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 440|0);
       HEAPF32[$181>>2] = $180;
       $182 = HEAP32[$54>>2]|0;
       $183 = (($182) + 24|0);
       $184 = Math_fround(HEAPF32[$183>>2]);
       $185 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 444|0);
       HEAPF32[$185>>2] = $184;
       $187 = $frictionPatchByteSize$i;
      } else {
       $134 = (($123) + 64|0);
       $135 = HEAP16[$134>>1]|0;
       $136 = $135&65535;
       $137 = (($123) + 66|0);
       $138 = HEAP16[$137>>1]|0;
       $139 = $138&65535;
       $140 = $139 << 16;
       $141 = $140 | $136;
       $142 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 432|0);
       HEAP32[$142>>2] = $141;
       $143 = (($123) + 68|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 436|0);
       HEAP32[$145>>2] = $144;
       $146 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 412|0);
       HEAPF32[$146>>2] = $147;
       $148 = (($123) + 52|0);
       $149 = Math_fround(HEAPF32[$148>>2]);
       $150 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 428|0);
       HEAPF32[$150>>2] = $149;
       $151 = (($123) + 56|0);
       $152 = Math_fround(HEAPF32[$151>>2]);
       $153 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 440|0);
       HEAPF32[$153>>2] = $152;
       $154 = (($123) + 60|0);
       $155 = Math_fround(HEAPF32[$154>>2]);
       $156 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 444|0);
       HEAPF32[$156>>2] = $155;
       $157 = (($123) + 36|0);
       $187 = $157;
      }
      $186 = Math_fround(HEAPF32[$187>>2]);
      $188 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 416|0);
      HEAPF32[$188>>2] = $186;
      $189 = (($187) + 4|0);
      $190 = Math_fround(HEAPF32[$189>>2]);
      $191 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 420|0);
      HEAPF32[$191>>2] = $190;
      $192 = (($187) + 8|0);
      $193 = Math_fround(HEAPF32[$192>>2]);
      $194 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 424|0);
      HEAPF32[$194>>2] = $193;
      if ($71) {
       $201 = 0;
      } else {
       $195 = Math_fround(HEAPF32[$187>>2]);
       $196 = $195 == Math_fround(0.0);
       if ($196) {
        $197 = Math_fround(HEAPF32[$189>>2]);
        $198 = $197 == Math_fround(0.0);
        if ($198) {
         $199 = Math_fround(HEAPF32[$192>>2]);
         $phitmp = $199 != Math_fround(0.0);
         $201 = $phitmp;
        } else {
         $201 = 1;
        }
       } else {
        $201 = 1;
       }
      }
      $200 = $201&1;
      $202 = $$1$ph & 1;
      $203 = $202&255;
      $204 = $200 | $203;
      $205 = $204&255;
      $206 = (($numContacts$1$ph) + 1)|0;
      $$1$ph = $205;$93 = $390;$98 = $389;$numContacts$1$ph = $206;
     }
     $73 = HEAP32[$56>>2]|0;
     $74 = HEAP32[$28>>2]|0;
     $75 = $73;
     $76 = $74;
     $77 = (($75) - ($76))|0;
     $78 = ($77>>>0)<($22>>>0);
     if ($78) {
      $$0136 = $$1$ph;$378 = $381;$379 = $382;$380 = $94;$79 = $73;$81 = $74;$83 = $75;$numContacts$035 = $numContacts$1$ph;
     } else {
      break;
     }
    }
    HEAP32[$3>>2] = $numContacts$1$ph;
    $207 = $$1$ph & 1;
    $extract$t = ($207<<24>>24)!=(0);
    $208 = ($numContacts$1$ph|0)==(0);
    if (!($208)) {
     $212 = (($threadContext) + 4496|0);
     $213 = (($threadContext) + 8728|0);
     HEAP32[$213>>2] = 0;
     $214 = (($threadContext) + 8724|0);
     HEAP32[$214>>2] = 0;
     if (!($extract$t)) {
      $215 = HEAP16[$12>>1]|0;
      $216 = $215 & 4;
      $217 = ($216<<16>>16)==(0);
      if ($217) {
       $218 = HEAP32[$4>>2]|0;
       $219 = (($n) + 36|0);
       $220 = HEAP32[$219>>2]|0;
       (__ZL18getFrictionPatchesRN5physx26PxcFrictionPatchStreamPairERNS_20PxcCorrelationBufferEPKhjRKNS_11PxTransformES8_f($212,$218,$220,$bodyFrame0$0,$bodyFrame1$0,$correlationDistance)|0);
      }
     }
     (__ZN5physx20createContactPatchesERNS_18PxcNpThreadContextEjf($threadContext,0,Math_fround(0.999000012874603271484))|0);
     (__ZN5physx16correlatePatchesERNS_20PxcCorrelationBufferERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjj($212,$1,$bodyFrame0$0,$bodyFrame1$0,Math_fround(0.999000012874603271484),0,0)|0);
     __ZN5physx11growPatchesERNS_20PxcCorrelationBufferERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjf($212,$1,$bodyFrame0$0,$bodyFrame1$0,$correlationDistance,0,$frictionOffsetThreshold);
     HEAP32[$numFrictionPatches>>2] = 0;
     HEAP32[$solverConstraintByteSize>>2] = 0;
     HEAP32[$axisConstraintCount>>2] = 0;
     HEAP32[$frictionPatchByteSize$i>>2] = 0;
     __Z27computeBlockStreamByteSizesRKN5physx13PxcNpWorkUnitERNS_18PxcNpThreadContextEbRjS5_S5_S5_($n,$threadContext,$forceContacts,$solverConstraintByteSize,$frictionPatchByteSize$i,$numFrictionPatches,$axisConstraintCount);
     $221 = HEAP32[$solverConstraintByteSize>>2]|0;
     $222 = ($221|0)==(0);
     if ($222) {
      $constraintBlock$0$i = 0;
     } else {
      $223 = (($threadContext) + 316|0);
      $224 = (($221) + 31)|0;
      $225 = $224 & -16;
      $226 = ($225>>>0)>(16384);
      do {
       if ($226) {
        $227 = HEAP32[$223>>2]|0;
        $228 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($227,$225)|0);
        $$0$i$i = $228;
       } else {
        $229 = (($threadContext) + 320|0);
        $230 = HEAP32[$229>>2]|0;
        $231 = ($230|0)==(0|0);
        $$pre$i$i = (($threadContext) + 324|0);
        if (!($231)) {
         $232 = HEAP32[$$pre$i$i>>2]|0;
         $233 = (($232) + ($225))|0;
         $234 = ($233>>>0)>(16384);
         if (!($234)) {
          $237 = (($230) + ($232)|0);
          HEAP32[$$pre$i$i>>2] = $233;
          $$0$i$i = $237;
          break;
         }
        }
        $235 = HEAP32[$223>>2]|0;
        $236 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($235,$constraintBlockManager)|0);
        HEAP32[$229>>2] = $236;
        HEAP32[$$pre$i$i>>2] = $225;
        $$0$i$i = $236;
       }
      } while(0);
      $238 = ($$0$i$i|0)==(0|0);
      $$not8$i = ($$0$i$i|0)!=((-1)|0);
      $or$cond5$i = $238 | $$not8$i;
      $$$i = $or$cond5$i ? $$0$i$i : 0;
      $constraintBlock$0$i = $$$i;
     }
     $239 = HEAP32[$frictionPatchByteSize$i>>2]|0;
     $240 = ($239|0)==(0);
     if ($240) {
      $frictionPatches$0$i = 0;
     } else {
      $241 = ($221|0)!=(0);
      $242 = ($constraintBlock$0$i|0)==(0|0);
      $or$cond$i = $241 & $242;
      if ($or$cond$i) {
       $frictionPatches$0$i = 0;
      } else {
       $243 = ($239>>>0)>(16384);
       do {
        if ($243) {
         $$0$i17$i = (-1);
        } else {
         $244 = (($threadContext) + 348|0);
         $245 = HEAP32[$244>>2]|0;
         $246 = ($245|0)==(0|0);
         $$pre$i15$i = (($threadContext) + 352|0);
         if ($246) {
          label = 51;
         } else {
          $247 = HEAP32[$$pre$i15$i>>2]|0;
          $248 = (($247) + ($239))|0;
          $249 = ($248>>>0)>(16384);
          if ($249) {
           label = 51;
          } else {
           $255 = $245;$256 = $247;
          }
         }
         if ((label|0) == 51) {
          $250 = (($threadContext) + 344|0);
          $251 = HEAP32[$250>>2]|0;
          $252 = (__ZN5physx17PxcNpMemBlockPool20acquireFrictionBlockEv($251)|0);
          HEAP32[$244>>2] = $252;
          HEAP32[$$pre$i15$i>>2] = 0;
          $253 = ($252|0)==(0|0);
          if ($253) {
           $$0$i17$i = 0;
           break;
          } else {
           $255 = $252;$256 = 0;
          }
         }
         $254 = (($255) + ($256)|0);
         $257 = (($256) + ($239))|0;
         HEAP32[$$pre$i15$i>>2] = $257;
         $$0$i17$i = $254;
        }
       } while(0);
       $258 = ($$0$i17$i|0)==(0|0);
       $$not$i = ($$0$i17$i|0)!=((-1)|0);
       $or$cond7$i = $258 | $$not$i;
       $$9$i = $or$cond7$i ? $$0$i17$i : 0;
       $frictionPatches$0$i = $$9$i;
      }
     }
     $$not10$i = $222 ^ 1;
     $259 = ($constraintBlock$0$i|0)==(0|0);
     $or$cond11$i = $259 & $$not10$i;
     if ($or$cond11$i) {
      $264 = (($threadContext) + 8776|0);
      $265 = HEAP32[$264>>2]|0;
      $266 = (($265) + ($221))|0;
      HEAP32[$264>>2] = $266;
      $391 = 0;$constraintBlock$0$i8 = 0;
     } else {
      $$constraintBlock$0$i = $222 ? 0 : $constraintBlock$0$i;
      $260 = (($threadContext) + 8776|0);
      $261 = HEAP32[$260>>2]|0;
      $262 = (($261) + ($221))|0;
      HEAP32[$260>>2] = $262;
      $263 = ($frictionPatches$0$i|0)!=(0|0);
      $$14$i = $240 | $263;
      $391 = $$14$i;$constraintBlock$0$i8 = $$constraintBlock$0$i;
     }
     HEAP32[$4>>2] = 0;
     HEAP32[$n>>2] = 0;
     $267 = (($n) + 20|0);
     HEAP16[$267>>1] = 0;
     $268 = (($n) + 36|0);
     HEAP32[$268>>2] = 0;
     $269 = (($n) + 4|0);
     HEAP32[$269>>2] = 0;
     $270 = HEAP32[$axisConstraintCount>>2]|0;
     $271 = (($n) + 16|0);
     $272 = HEAP16[$271>>1]|0;
     $273 = $272&65535;
     $274 = (($273) + ($270))|0;
     $275 = $274&65535;
     HEAP16[$271>>1] = $275;
     if (!($391)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$4>>2] = $frictionPatches$0$i;
     HEAP32[$n>>2] = $constraintBlock$0$i8;
     $276 = $numContacts$1$ph&65535;
     HEAP16[$267>>1] = $276;
     $277 = HEAP32[$numFrictionPatches>>2]|0;
     HEAP32[$268>>2] = $277;
     HEAP32[$269>>2] = $221;
     $278 = ($frictionPatches$0$i|0)==(0|0);
     if (!($278)) {
      $279 = (($frictionPatches$0$i) + 128|0);
      $280 = (($frictionPatches$0$i) + 256|0);
      $281 = HEAP32[$213>>2]|0;
      $282 = ($281|0)==(0);
      if (!($282)) {
       $392 = $281;$frictionPatches$0$i1024 = $frictionPatches$0$i;$i$025 = 0;
       while(1) {
        $283 = ((($threadContext) + ($i$025<<2)|0) + 8336|0);
        $284 = HEAP32[$283>>2]|0;
        $285 = ($284|0)==(0);
        if ($285) {
         $358 = $392;$frictionPatches$0$i11 = $frictionPatches$0$i1024;
        } else {
         $286 = (($frictionPatches$0$i1024) + 96|0);
         $287 = ((($threadContext) + (($i$025*96)|0)|0) + 5264|0);
         $288 = HEAP8[$287>>0]|0;
         HEAP8[$frictionPatches$0$i1024>>0] = $288;
         $289 = ((($threadContext) + (($i$025*96)|0)|0) + 5280|0);
         $290 = HEAP16[$289>>1]|0;
         $291 = (($frictionPatches$0$i1024) + 16|0);
         HEAP16[$291>>1] = $290;
         $292 = ((($threadContext) + (($i$025*96)|0)|0) + 5288|0);
         $293 = Math_fround(HEAPF32[$292>>2]);
         $294 = (($frictionPatches$0$i1024) + 24|0);
         HEAPF32[$294>>2] = $293;
         $295 = ((($threadContext) + (($i$025*96)|0)|0) + 5292|0);
         $296 = Math_fround(HEAPF32[$295>>2]);
         $297 = (($frictionPatches$0$i1024) + 28|0);
         HEAPF32[$297>>2] = $296;
         $298 = ((($threadContext) + (($i$025*96)|0)|0) + 5296|0);
         $299 = Math_fround(HEAPF32[$298>>2]);
         $300 = (($frictionPatches$0$i1024) + 32|0);
         HEAPF32[$300>>2] = $299;
         $301 = ((($threadContext) + (($i$025*96)|0)|0) + 5300|0);
         $302 = Math_fround(HEAPF32[$301>>2]);
         $303 = (($frictionPatches$0$i1024) + 36|0);
         HEAPF32[$303>>2] = $302;
         $304 = ((($threadContext) + (($i$025*96)|0)|0) + 5304|0);
         $305 = Math_fround(HEAPF32[$304>>2]);
         $306 = (($frictionPatches$0$i1024) + 40|0);
         HEAPF32[$306>>2] = $305;
         $307 = ((($threadContext) + (($i$025*96)|0)|0) + 5308|0);
         $308 = Math_fround(HEAPF32[$307>>2]);
         $309 = (($frictionPatches$0$i1024) + 44|0);
         HEAPF32[$309>>2] = $308;
         $310 = ((($threadContext) + (($i$025*96)|0)|0) + 5312|0);
         $311 = Math_fround(HEAPF32[$310>>2]);
         $312 = (($frictionPatches$0$i1024) + 48|0);
         HEAPF32[$312>>2] = $311;
         $313 = ((($threadContext) + (($i$025*96)|0)|0) + 5316|0);
         $314 = Math_fround(HEAPF32[$313>>2]);
         $315 = (($frictionPatches$0$i1024) + 52|0);
         HEAPF32[$315>>2] = $314;
         $316 = ((($threadContext) + (($i$025*96)|0)|0) + 5320|0);
         $317 = Math_fround(HEAPF32[$316>>2]);
         $318 = (($frictionPatches$0$i1024) + 56|0);
         HEAPF32[$318>>2] = $317;
         $319 = ((($threadContext) + (($i$025*96)|0)|0) + 5324|0);
         $320 = Math_fround(HEAPF32[$319>>2]);
         $321 = (($frictionPatches$0$i1024) + 60|0);
         HEAPF32[$321>>2] = $320;
         $322 = ((($threadContext) + (($i$025*96)|0)|0) + 5328|0);
         $323 = Math_fround(HEAPF32[$322>>2]);
         $324 = (($frictionPatches$0$i1024) + 64|0);
         HEAPF32[$324>>2] = $323;
         $325 = ((($threadContext) + (($i$025*96)|0)|0) + 5332|0);
         $326 = Math_fround(HEAPF32[$325>>2]);
         $327 = (($frictionPatches$0$i1024) + 68|0);
         HEAPF32[$327>>2] = $326;
         $328 = ((($threadContext) + (($i$025*96)|0)|0) + 5336|0);
         $329 = Math_fround(HEAPF32[$328>>2]);
         $330 = (($frictionPatches$0$i1024) + 72|0);
         HEAPF32[$330>>2] = $329;
         $331 = ((($threadContext) + (($i$025*96)|0)|0) + 5340|0);
         $332 = Math_fround(HEAPF32[$331>>2]);
         $333 = (($frictionPatches$0$i1024) + 76|0);
         HEAPF32[$333>>2] = $332;
         $334 = ((($threadContext) + (($i$025*96)|0)|0) + 5344|0);
         $335 = Math_fround(HEAPF32[$334>>2]);
         $336 = (($frictionPatches$0$i1024) + 80|0);
         HEAPF32[$336>>2] = $335;
         $337 = ((($threadContext) + (($i$025*96)|0)|0) + 5348|0);
         $338 = Math_fround(HEAPF32[$337>>2]);
         $339 = (($frictionPatches$0$i1024) + 84|0);
         HEAPF32[$339>>2] = $338;
         $340 = ((($threadContext) + (($i$025*96)|0)|0) + 5352|0);
         $341 = Math_fround(HEAPF32[$340>>2]);
         $342 = (($frictionPatches$0$i1024) + 88|0);
         HEAPF32[$342>>2] = $341;
         $343 = ((($threadContext) + (($i$025*96)|0)|0) + 5356|0);
         $344 = Math_fround(HEAPF32[$343>>2]);
         $345 = (($frictionPatches$0$i1024) + 92|0);
         HEAPF32[$345>>2] = $344;
         $346 = ((($threadContext) + (($i$025*96)|0)|0) + 5284|0);
         $347 = HEAP16[$346>>1]|0;
         $348 = (($frictionPatches$0$i1024) + 20|0);
         HEAP16[$348>>1] = $347;
         $349 = ((($threadContext) + (($i$025*96)|0)|0) + 5282|0);
         $350 = HEAP16[$349>>1]|0;
         $351 = (($frictionPatches$0$i1024) + 18|0);
         HEAP16[$351>>1] = $350;
         $352 = ((($threadContext) + (($i$025*96)|0)|0) + 5286|0);
         $353 = HEAP16[$352>>1]|0;
         $354 = (($frictionPatches$0$i1024) + 22|0);
         HEAP16[$354>>1] = $353;
         $355 = (($286) + 256|0);
         $$pre = HEAP32[$213>>2]|0;
         $358 = $$pre;$frictionPatches$0$i11 = $286;
        }
        $356 = (($i$025) + 1)|0;
        $357 = ($356>>>0)<($358>>>0);
        if ($357) {
         $392 = $358;$frictionPatches$0$i1024 = $frictionPatches$0$i11;$i$025 = $356;
        } else {
         break;
        }
       }
      }
     }
     $359 = ($constraintBlock$0$i8|0)==(0|0);
     if ($359) {
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
     $360 = HEAP16[$12>>1]|0;
     $361 = $360 & 24;
     $362 = ($361<<16>>16)==(0);
     if ($362) {
      __ZN5physx30setupFinalizeSolverConstraintsERNS_13PxcNpWorkUnitERKNS_2Gu13ContactBufferERKNS_20PxcCorrelationBufferERKNS_11PxTransformESB_bPhRKNS_13PxcSolverBodyESF_RKNS_17PxcSolverBodyDataESI_ffffff($n,$1,$212,$bodyFrame0$0,$bodyFrame1$0,$extract$t,$constraintBlock$0$i8,$sBody0,$sBody1,$solverBodyData0,$solverBodyData1,$invDtF32,$bounceThresholdF32,$371,$372,$373,$374);
     } else {
      $363 = (($desc) + 8|0);
      $364 = HEAP16[$363>>1]|0;
      HEAP32[$b0>>2] = $sBody0;
      $365 = (($b0) + 4|0);
      HEAP32[$365>>2] = $solverBodyData0;
      $366 = (($b0) + 8|0);
      HEAP16[$366>>1] = $364;
      $367 = (($desc) + 12|0);
      $368 = HEAP16[$367>>1]|0;
      HEAP32[$b1>>2] = $sBody1;
      $369 = (($b1) + 4|0);
      HEAP32[$369>>2] = $solverBodyData1;
      $370 = (($b1) + 8|0);
      HEAP16[$370>>1] = $368;
      __ZN5physx33setupFinalizeExtSolverConstraintsERNS_13PxcNpWorkUnitERKNS_2Gu13ContactBufferERKNS_20PxcCorrelationBufferERKNS_11PxTransformESB_bPhRKNS_16PxsSolverExtBodyESF_RKNS_17PxcSolverBodyDataESI_ffffff($n,$1,$212,$bodyFrame0$0,$bodyFrame1$0,$extract$t,$constraintBlock$0$i8,$b0,$b1,$solverBodyData0,$solverBodyData1,$invDtF32,$bounceThresholdF32,$371,$372,$373,$374);
     }
     $375 = HEAP32[$solverConstraintByteSize>>2]|0;
     $376 = (($constraintBlock$0$i8) + ($375)|0);
     HEAP32[$376>>2] = 0;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 HEAP32[$4>>2] = 0;
 $209 = (($n) + 36|0);
 HEAP32[$209>>2] = 0;
 $210 = (($n) + 20|0);
 HEAP16[$210>>1] = 0;
 $211 = (($desc) + 16|0);
 HEAP32[$211>>2] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx29createFinalizeSolverContacts4EPPNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPPNS_23PxcSolverConstraintDescEPPKNS_13PxcSolverBodyESB_PPKNS_17PxcSolverBodyDataESF_PPKNS_12PxsRigidCoreESJ_ffffRNS_25PxsConstraintBlockManagerENS_14PxFrictionType4EnumE($n,$threadContext,$desc,$sBody0,$sBody1,$solverBodyData0,$solverBodyData1,$body0,$body1,$invDtF32,$bounceThresholdF32,$frictionOffsetThreshold,$correlationDistance,$constraintBlockManager,$frictionType) {
 $n = $n|0;
 $threadContext = $threadContext|0;
 $desc = $desc|0;
 $sBody0 = $sBody0|0;
 $sBody1 = $sBody1|0;
 $solverBodyData0 = $solverBodyData0|0;
 $solverBodyData1 = $solverBodyData1|0;
 $body0 = $body0|0;
 $body1 = $body1|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $frictionOffsetThreshold = Math_fround($frictionOffsetThreshold);
 $correlationDistance = Math_fround($correlationDistance);
 $constraintBlockManager = $constraintBlockManager|0;
 $frictionType = $frictionType|0;
 var $$$i11 = 0, $$$i1721$ph = 0, $$0$i = 0, $$0$i$1 = 0, $$0$i$2 = 0, $$0$i$3 = 0, $$0$i$i = 0, $$0$i$i8 = 0, $$2 = 0, $$4$i = 0, $$lcssa43 = 0, $$not$i9 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i6 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0;
 var $$sum = 0, $$sum$i = 0, $$sum23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0;
 var $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0);
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = 0;
 var $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0;
 var $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0;
 var $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0;
 var $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = Math_fround(0), $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = 0;
 var $42 = 0, $420 = Math_fround(0), $421 = 0, $422 = 0, $423 = Math_fround(0), $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = Math_fround(0), $604 = 0, $605 = Math_fround(0), $606 = 0, $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = Math_fround(0), $614 = 0, $615 = Math_fround(0), $616 = 0, $617 = Math_fround(0);
 var $618 = 0, $619 = Math_fround(0), $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = Math_fround(0), $624 = 0, $625 = Math_fround(0), $626 = 0, $627 = Math_fround(0), $628 = 0, $629 = Math_fround(0), $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = Math_fround(0), $634 = 0, $635 = Math_fround(0);
 var $636 = 0, $637 = Math_fround(0), $638 = 0, $639 = Math_fround(0), $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = Math_fround(0), $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a1$053 = 0, $a2$027 = 0, $axisConstraintCount = 0, $blockDescs = 0, $exitcond$i$i = 0, $faceIndices$0$off0$i$i = 0, $frictionPatches$0$i = 0, $frictionPatches$0$i1925 = 0, $frictionPatches$0$i20 = 0, $i$01$i$i = 0, $i$026 = 0, $iInertiaScale0 = 0, $iInertiaScale1 = 0, $iMassScale0 = 0, $iMassScale1 = 0, $idt = 0;
 var $invInertiaScale0 = 0, $invInertiaScale1 = 0, $invMassScale0 = 0, $invMassScale1 = 0, $iter = 0, $modify$0$off0$i$i = 0, $not$$i$i = 0, $not$or$cond3$i = 0, $notlhs = 0, $notrhs = 0, $numContacts$054 = 0, $numContacts$139 = 0, $numContacts$2$ph = 0, $numContacts$3 = 0, $numFrictionPatches$0$$i$i = 0, $numFrictionPatches$0$$i$i18 = 0, $numFrictionPatches$02$i$i = 0, $or$cond3$i10 = 0, $p$048 = 0, $p2$044 = 0;
 var $perPointFriction$0$off038 = 0, $perPointFriction$1$off0$ph = 0, $perPointFriction$2$off0 = 0, $phitmp = 0, $phitmp$i$i = 0, $response$0$off0$i$i = 0, $solverConstraintByteSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $blockDescs = sp + 248|0;
 $idt = sp + 216|0;
 $invMassScale0 = sp + 80|0;
 $invMassScale1 = sp + 32|0;
 $invInertiaScale0 = sp + 48|0;
 $invInertiaScale1 = sp + 16|0;
 $iter = sp + 148|0;
 $solverConstraintByteSize = sp + 144|0;
 $axisConstraintCount = sp + 128|0;
 $iMassScale0 = sp;
 $iInertiaScale0 = sp + 64|0;
 $iMassScale1 = sp + 96|0;
 $iInertiaScale1 = sp + 112|0;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($0) + 26|0);
 HEAP16[$1>>1] = 0;
 $2 = (($desc) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 26|0);
 HEAP16[$4>>1] = 0;
 $5 = (($desc) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 26|0);
 HEAP16[$7>>1] = 0;
 $8 = (($desc) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 26|0);
 HEAP16[$10>>1] = 0;
 $11 = (($threadContext) + 384|0);
 $12 = (($threadContext) + 4480|0);
 HEAP32[$12>>2] = 0;
 HEAPF32[$idt>>2] = Math_fround(0.0);
 $13 = (($idt) + 4|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($idt) + 8|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($idt) + 12|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($idt) + 16|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($idt) + 20|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($idt) + 24|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($threadContext) + 4496|0);
 $20 = (($threadContext) + 8728|0);
 HEAP32[$20>>2] = 0;
 $21 = (($threadContext) + 8724|0);
 HEAP32[$21>>2] = 0;
 $22 = (($iter) + 4|0);
 $23 = (($iter) + 8|0);
 $24 = (($iter) + 36|0);
 $25 = (($iter) + 40|0);
 $26 = (($iter) + 44|0);
 $27 = (($iter) + 12|0);
 $28 = (($iter) + 60|0);
 $29 = (($iter) + 56|0);
 $30 = (($iter) + 64|0);
 $31 = (($iter) + 48|0);
 $32 = (($iter) + 52|0);
 $33 = (($iter) + 24|0);
 $34 = (($iter) + 28|0);
 $35 = (($iter) + 16|0);
 $36 = (($iter) + 32|0);
 $a1$053 = 0;$numContacts$054 = 0;
 while(1) {
  $39 = (($n) + ($a1$053<<2)|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 22|0);
  $42 = HEAP16[$41>>1]|0;
  $43 = $42 & 32;
  $44 = ($43<<16>>16)==(0);
  if ($44) {
   $49 = ((($blockDescs) + (($a1$053*56)|0)|0) + 28|0);
   HEAP32[$49>>2] = $idt;
   $51 = $42;$644 = $40;
  } else {
   $45 = (($body0) + ($a1$053<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = HEAP32[$45>>2]|0;
   $48 = ((($blockDescs) + (($a1$053*56)|0)|0) + 28|0);
   HEAP32[$48>>2] = $47;
   $$pre = HEAP32[$39>>2]|0;
   $$phi$trans$insert = (($$pre) + 22|0);
   $$pre62 = HEAP16[$$phi$trans$insert>>1]|0;
   $51 = $$pre62;$644 = $$pre;
  }
  $50 = $51 & 64;
  $52 = ($50<<16>>16)==(0);
  if ($52) {
   $57 = ((($blockDescs) + (($a1$053*56)|0)|0) + 32|0);
   HEAP32[$57>>2] = $idt;
   $59 = $644;
  } else {
   $53 = (($body1) + ($a1$053<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = HEAP32[$53>>2]|0;
   $56 = ((($blockDescs) + (($a1$053*56)|0)|0) + 32|0);
   HEAP32[$56>>2] = $55;
   $$pre63 = HEAP32[$39>>2]|0;
   $59 = $$pre63;
  }
  $58 = (($blockDescs) + (($a1$053*56)|0)|0);
  HEAP32[$58>>2] = $59;
  $60 = ((($blockDescs) + (($a1$053*56)|0)|0) + 12|0);
  HEAP32[$60>>2] = $numContacts$054;
  $61 = (($sBody0) + ($a1$053<<2)|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($blockDescs) + (($a1$053*56)|0)|0) + 36|0);
  HEAP32[$63>>2] = $62;
  $64 = (($sBody1) + ($a1$053<<2)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($blockDescs) + (($a1$053*56)|0)|0) + 40|0);
  HEAP32[$66>>2] = $65;
  $67 = (($solverBodyData0) + ($a1$053<<2)|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($blockDescs) + (($a1$053*56)|0)|0) + 44|0);
  HEAP32[$69>>2] = $68;
  $70 = (($solverBodyData1) + ($a1$053<<2)|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ((($blockDescs) + (($a1$053*56)|0)|0) + 48|0);
  HEAP32[$72>>2] = $71;
  $73 = HEAP32[$64>>2]|0;
  $74 = HEAP32[$67>>2]|0;
  $75 = HEAP32[$70>>2]|0;
  $76 = HEAP32[$39>>2]|0;
  $77 = (($76) + 20|0);
  $78 = HEAP16[$77>>1]|0;
  $79 = $78&65535;
  $80 = (($79) + ($numContacts$054))|0;
  $81 = ($80>>>0)>(64);
  if ($81) {
   $$2 = 1;
   label = 83;
   break;
  }
  $82 = (($76) + 28|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($76) + 32|0);
  $85 = HEAP32[$84>>2]|0;
  HEAPF32[$iter>>2] = Math_fround(0.0);
  HEAPF32[$22>>2] = Math_fround(0.0);
  HEAPF32[$23>>2] = Math_fround(0.0);
  HEAP32[$24>>2] = $85;
  HEAP32[$25>>2] = 0;
  HEAP32[$26>>2] = 0;
  HEAP32[$27>>2] = $83;
  $86 = ($85|0)==(0);
  if ($86) {
   $104 = 0;$105 = 0;$106 = 0;$faceIndices$0$off0$i$i = 0;$modify$0$off0$i$i = 0;$response$0$off0$i$i = 1;
  } else {
   $87 = (($83) + 2|0);
   $88 = HEAP16[$87>>1]|0;
   $89 = $88&65535;
   $90 = $89 & 2;
   $91 = ($90|0)!=(0);
   $92 = $89 & 1;
   $93 = ($92|0)!=(0);
   $94 = $90 << 3;
   $95 = $94 | 4;
   $96 = (($83) + ($95)|0);
   $97 = $91 ? 4 : 32;
   if ($91) {
    $645 = 72;
   } else {
    $98 = $92 << 3;
    $99 = $98 | 16;
    $645 = $99;
   }
   $100 = $88 & 4;
   $phitmp$i$i = ($100<<16>>16)!=(0);
   $104 = $97;$105 = $645;$106 = $96;$faceIndices$0$off0$i$i = $93;$modify$0$off0$i$i = $91;$response$0$off0$i$i = $phitmp$i$i;
  }
  $101 = $modify$0$off0$i$i&1;
  HEAP32[$28>>2] = $101;
  $102 = $faceIndices$0$off0$i$i&1;
  HEAP32[$29>>2] = $102;
  $103 = $response$0$off0$i$i&1;
  HEAP32[$30>>2] = $103;
  HEAP32[$31>>2] = $104;
  HEAP32[$32>>2] = $105;
  HEAP32[$33>>2] = $106;
  HEAP32[$34>>2] = $106;
  HEAP32[$35>>2] = $106;
  if ($response$0$off0$i$i) {
   $numContacts$3 = $numContacts$054;$perPointFriction$2$off0 = 0;
  } else {
   if ($modify$0$off0$i$i) {
    $110 = (($83) + 4|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = (($invMassScale0) + ($a1$053<<2)|0);
    HEAPF32[$112>>2] = $111;
    $113 = (($83) + 8|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = (($invMassScale1) + ($a1$053<<2)|0);
    HEAPF32[$115>>2] = $114;
    $116 = (($83) + 12|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = (($invInertiaScale0) + ($a1$053<<2)|0);
    HEAPF32[$118>>2] = $117;
    $119 = (($83) + 16|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $122 = $120;
   } else {
    $107 = (($invMassScale0) + ($a1$053<<2)|0);
    HEAPF32[$107>>2] = Math_fround(1.0);
    $108 = (($invMassScale1) + ($a1$053<<2)|0);
    HEAPF32[$108>>2] = Math_fround(1.0);
    $109 = (($invInertiaScale0) + ($a1$053<<2)|0);
    HEAPF32[$109>>2] = Math_fround(1.0);
    $122 = Math_fround(1.0);
   }
   $121 = (($invInertiaScale1) + ($a1$053<<2)|0);
   HEAPF32[$121>>2] = $122;
   $123 = $106;
   $124 = $83;
   $125 = (($123) - ($124))|0;
   $126 = ($125>>>0)<($85>>>0);
   if ($126) {
    $$sum = (($105) + 128)|0;
    $133 = $106;$135 = $83;$137 = $123;$646 = $106;$647 = 0;$648 = 0;$numContacts$139 = $numContacts$054;$perPointFriction$0$off038 = 0;
    while(1) {
     HEAP32[$33>>2] = $133;
     $134 = $135;
     $136 = (($137) - ($134))|0;
     $138 = ($136>>>0)<($85>>>0);
     if ($138) {
      $139 = HEAP16[$133>>1]|0;
      $140 = $139&65535;
      HEAP32[$25>>2] = $140;
      $141 = Math_imul($105, $140)|0;
      $$sum$i = (($141) + ($104))|0;
      $142 = (($133) + ($$sum$i)|0);
      HEAP32[$34>>2] = $142;
      $143 = (($133) + ($104)|0);
      HEAP32[$35>>2] = $143;
      HEAP32[$26>>2] = 0;
      $148 = $140;$651 = $143;$652 = 0;
     } else {
      HEAP32[$34>>2] = $133;
      $148 = $648;$651 = $646;$652 = $647;
     }
     $147 = $652;$152 = $651;$numContacts$2$ph = $numContacts$139;$perPointFriction$1$off0$ph = $perPointFriction$0$off038;
     L31: while(1) {
      $144 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 384|0);
      $$sum23 = (($numContacts$2$ph) + 2)|0;
      $145 = ((($threadContext) + ($$sum23<<6)|0) + 384|0);
      if ($modify$0$off0$i$i) {
       $150 = $147;$156 = $152;
       while(1) {
        $149 = ($150>>>0)<($148>>>0);
        if (!($149)) {
         $649 = $156;$650 = $150;
         break L31;
        }
        $155 = (($150) + 1)|0;
        HEAP32[$26>>2] = $155;
        HEAP32[$36>>2] = $156;
        $157 = (($156) + ($105)|0);
        HEAP32[$35>>2] = $157;
        $158 = (($156) + ($$sum)|0);
        $159 = HEAP32[$36>>2]|0;
        $160 = (($159) + 48|0);
        $161 = Math_fround(HEAPF32[$160>>2]);
        $162 = $161 != Math_fround(0.0);
        if ($162) {
         break;
        } else {
         $150 = $155;$156 = $157;
        }
       }
       if ($modify$0$off0$i$i) {
        $163 = HEAP32[$36>>2]|0;
        $164 = (($163) + 24|0);
        $168 = $164;$169 = $144;$177 = $163;$201 = $161;$657 = $157;$658 = $155;
       } else {
        $653 = $157;$654 = $155;$655 = $144;$656 = $161;
        label = 32;
       }
      } else {
       $146 = ($147>>>0)<($148>>>0);
       if (!($146)) {
        $649 = $152;$650 = $147;
        break;
       }
       $151 = (($147) + 1)|0;
       HEAP32[$26>>2] = $151;
       HEAP32[$36>>2] = $152;
       $153 = (($152) + ($105)|0);
       HEAP32[$35>>2] = $153;
       $154 = (($152) + ($$sum)|0);
       $653 = $153;$654 = $151;$655 = $144;$656 = Math_fround(3.40282346638528859812E+38);
       label = 32;
      }
      if ((label|0) == 32) {
       label = 0;
       $165 = HEAP32[$33>>2]|0;
       $166 = (($165) + 4|0);
       $$pre64 = HEAP32[$36>>2]|0;
       $168 = $166;$169 = $655;$177 = $$pre64;$201 = $656;$657 = $653;$658 = $654;
      }
      $167 = Math_fround(HEAPF32[$168>>2]);
      HEAPF32[$169>>2] = $167;
      $170 = (($168) + 4|0);
      $171 = Math_fround(HEAPF32[$170>>2]);
      $172 = (($169) + 4|0);
      HEAPF32[$172>>2] = $171;
      $173 = (($168) + 8|0);
      $174 = Math_fround(HEAPF32[$173>>2]);
      $175 = (($169) + 8|0);
      HEAPF32[$175>>2] = $174;
      $176 = Math_fround(HEAPF32[$177>>2]);
      $178 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 400|0);
      HEAPF32[$178>>2] = $176;
      $179 = (($177) + 4|0);
      $180 = Math_fround(HEAPF32[$179>>2]);
      $181 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 404|0);
      HEAPF32[$181>>2] = $180;
      $182 = (($177) + 8|0);
      $183 = Math_fround(HEAPF32[$182>>2]);
      $184 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 408|0);
      HEAPF32[$184>>2] = $183;
      $185 = (($177) + 12|0);
      $186 = Math_fround(HEAPF32[$185>>2]);
      $187 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 396|0);
      HEAPF32[$187>>2] = $186;
      if ($modify$0$off0$i$i) {
       $188 = (($177) + 64|0);
       $189 = HEAP16[$188>>1]|0;
       $190 = $189&65535;
       $191 = (($177) + 66|0);
       $192 = HEAP16[$191>>1]|0;
       $193 = $192&65535;
       $194 = $193 << 16;
       $195 = $194 | $190;
       $196 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 432|0);
       HEAP32[$196>>2] = $195;
       $197 = (($177) + 68|0);
       $198 = HEAP32[$197>>2]|0;
       $199 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 436|0);
       HEAP32[$199>>2] = $198;
       $200 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 412|0);
       HEAPF32[$200>>2] = $201;
       $202 = (($177) + 52|0);
       $203 = Math_fround(HEAPF32[$202>>2]);
       $204 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 428|0);
       HEAPF32[$204>>2] = $203;
       $205 = (($177) + 56|0);
       $206 = Math_fround(HEAPF32[$205>>2]);
       $207 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 440|0);
       HEAPF32[$207>>2] = $206;
       $208 = (($177) + 60|0);
       $209 = Math_fround(HEAPF32[$208>>2]);
       $210 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 444|0);
       HEAPF32[$210>>2] = $209;
       $211 = (($177) + 36|0);
       $241 = $211;
      } else {
       $212 = HEAP32[$33>>2]|0;
       $213 = (($212) + 28|0);
       $214 = HEAP16[$213>>1]|0;
       $215 = $214&65535;
       $216 = (($212) + 30|0);
       $217 = HEAP16[$216>>1]|0;
       $218 = $217&65535;
       $219 = $218 << 16;
       $220 = $219 | $215;
       $221 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 432|0);
       HEAP32[$221>>2] = $220;
       $222 = HEAP32[$33>>2]|0;
       $223 = (($222) + 2|0);
       $224 = HEAP16[$223>>1]|0;
       $225 = $224&65535;
       $226 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 436|0);
       HEAP32[$226>>2] = $225;
       $227 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 412|0);
       HEAPF32[$227>>2] = $201;
       $228 = HEAP32[$33>>2]|0;
       $229 = (($228) + 16|0);
       $230 = Math_fround(HEAPF32[$229>>2]);
       $231 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 428|0);
       HEAPF32[$231>>2] = $230;
       $232 = HEAP32[$33>>2]|0;
       $233 = (($232) + 20|0);
       $234 = Math_fround(HEAPF32[$233>>2]);
       $235 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 440|0);
       HEAPF32[$235>>2] = $234;
       $236 = HEAP32[$33>>2]|0;
       $237 = (($236) + 24|0);
       $238 = Math_fround(HEAPF32[$237>>2]);
       $239 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 444|0);
       HEAPF32[$239>>2] = $238;
       $241 = $iter;
      }
      $240 = Math_fround(HEAPF32[$241>>2]);
      $242 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 416|0);
      HEAPF32[$242>>2] = $240;
      $243 = (($241) + 4|0);
      $244 = Math_fround(HEAPF32[$243>>2]);
      $245 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 420|0);
      HEAPF32[$245>>2] = $244;
      $246 = (($241) + 8|0);
      $247 = Math_fround(HEAPF32[$246>>2]);
      $248 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 424|0);
      HEAPF32[$248>>2] = $247;
      if ($modify$0$off0$i$i) {
       $249 = Math_fround(HEAPF32[$241>>2]);
       $250 = $249 == Math_fround(0.0);
       if ($250) {
        $251 = Math_fround(HEAPF32[$243>>2]);
        $252 = $251 == Math_fround(0.0);
        if ($252) {
         $253 = Math_fround(HEAPF32[$246>>2]);
         $phitmp = $253 != Math_fround(0.0);
         $255 = $phitmp;
        } else {
         $255 = 1;
        }
       } else {
        $255 = 1;
       }
      } else {
       $255 = 0;
      }
      $254 = $perPointFriction$1$off0$ph | $255;
      $256 = (($numContacts$2$ph) + 1)|0;
      $147 = $658;$152 = $657;$numContacts$2$ph = $256;$perPointFriction$1$off0$ph = $254;
     }
     $127 = HEAP32[$34>>2]|0;
     $128 = HEAP32[$27>>2]|0;
     $129 = $127;
     $130 = $128;
     $131 = (($129) - ($130))|0;
     $132 = ($131>>>0)<($85>>>0);
     if ($132) {
      $133 = $127;$135 = $128;$137 = $129;$646 = $649;$647 = $650;$648 = $148;$numContacts$139 = $numContacts$2$ph;$perPointFriction$0$off038 = $perPointFriction$1$off0$ph;
     } else {
      $numContacts$3 = $numContacts$2$ph;$perPointFriction$2$off0 = $perPointFriction$1$off0$ph;
      break;
     }
    }
   } else {
    $numContacts$3 = $numContacts$054;$perPointFriction$2$off0 = 0;
   }
  }
  $257 = HEAP32[$60>>2]|0;
  HEAP32[$12>>2] = $numContacts$3;
  $258 = ($numContacts$3|0)==($257|0);
  if ($258) {
   $$2 = 1;
   label = 83;
   break;
  }
  $259 = (($numContacts$3) - ($257))|0;
  $260 = ((($blockDescs) + (($a1$053*56)|0)|0) + 16|0);
  HEAP32[$260>>2] = $259;
  $261 = ((($blockDescs) + (($a1$053*56)|0)|0) + 52|0);
  $262 = $perPointFriction$2$off0&1;
  HEAP8[$261>>0] = $262;
  $263 = HEAP32[$39>>2]|0;
  $264 = (($263) + 40|0);
  $265 = HEAP32[$264>>2]|0;
  $266 = HEAP32[$20>>2]|0;
  $267 = ((($blockDescs) + (($a1$053*56)|0)|0) + 4|0);
  HEAP32[$267>>2] = $266;
  if (!($perPointFriction$2$off0)) {
   $268 = HEAP32[$39>>2]|0;
   $269 = (($268) + 22|0);
   $270 = HEAP16[$269>>1]|0;
   $271 = $270 & 4;
   $272 = ($271<<16>>16)==(0);
   if ($272) {
    $273 = (($268) + 40|0);
    $274 = HEAP32[$273>>2]|0;
    $275 = (($268) + 36|0);
    $276 = HEAP32[$275>>2]|0;
    $277 = ((($blockDescs) + (($a1$053*56)|0)|0) + 28|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = ((($blockDescs) + (($a1$053*56)|0)|0) + 32|0);
    $280 = HEAP32[$279>>2]|0;
    $281 = (__ZL18getFrictionPatchesRN5physx26PxcFrictionPatchStreamPairERNS_20PxcCorrelationBufferEPKhjRKNS_11PxTransformES8_f($19,$274,$276,$278,$280,$correlationDistance)|0);
    if (!($281)) {
     $$2 = 1;
     label = 83;
     break;
    }
   }
  }
  $282 = HEAP32[$21>>2]|0;
  $283 = ((($blockDescs) + (($a1$053*56)|0)|0) + 20|0);
  HEAP32[$283>>2] = $282;
  $284 = HEAP32[$60>>2]|0;
  $285 = (__ZN5physx20createContactPatchesERNS_18PxcNpThreadContextEjf($threadContext,$284,Math_fround(0.999000012874603271484))|0);
  if (!($285)) {
   $$2 = 1;
   label = 83;
   break;
  }
  $286 = HEAP32[$21>>2]|0;
  $287 = HEAP32[$283>>2]|0;
  $288 = (($286) - ($287))|0;
  $289 = ((($blockDescs) + (($a1$053*56)|0)|0) + 24|0);
  HEAP32[$289>>2] = $288;
  $290 = ((($blockDescs) + (($a1$053*56)|0)|0) + 28|0);
  $291 = HEAP32[$290>>2]|0;
  $292 = ((($blockDescs) + (($a1$053*56)|0)|0) + 32|0);
  $293 = HEAP32[$292>>2]|0;
  $294 = HEAP32[$267>>2]|0;
  $295 = (__ZN5physx16correlatePatchesERNS_20PxcCorrelationBufferERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjj($19,$11,$291,$293,Math_fround(0.999000012874603271484),$287,$294)|0);
  if ($295) {
   $$2 = 1;
   label = 83;
   break;
  }
  $296 = HEAP32[$290>>2]|0;
  $297 = HEAP32[$292>>2]|0;
  $298 = HEAP32[$267>>2]|0;
  __ZN5physx11growPatchesERNS_20PxcCorrelationBufferERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjf($19,$11,$296,$297,$correlationDistance,$298,$frictionOffsetThreshold);
  $299 = HEAP32[$20>>2]|0;
  $300 = HEAP32[$267>>2]|0;
  $301 = ($299>>>0)>($300>>>0);
  if ($301) {
   $308 = $299;$p$048 = $299;
   while(1) {
    $302 = (($p$048) + -1)|0;
    $303 = ((($threadContext) + ($302<<2)|0) + 8464|0);
    $304 = HEAP32[$303>>2]|0;
    $305 = ($304|0)==(65535);
    if ($305) {
     $307 = ($p$048>>>0)<($308>>>0);
     if ($307) {
      $p2$044 = $p$048;
      while(1) {
       $309 = ((($threadContext) + ($p2$044<<2)|0) + 8464|0);
       $310 = HEAP32[$309>>2]|0;
       $311 = (($p2$044) + -1)|0;
       $312 = ((($threadContext) + ($311<<2)|0) + 8464|0);
       HEAP32[$312>>2] = $310;
       $313 = ((($threadContext) + ($p2$044<<2)|0) + 8336|0);
       $314 = HEAP32[$313>>2]|0;
       $315 = ((($threadContext) + ($311<<2)|0) + 8336|0);
       HEAP32[$315>>2] = $314;
       $316 = (($p2$044) + 1)|0;
       $317 = HEAP32[$20>>2]|0;
       $318 = ($316>>>0)<($317>>>0);
       if ($318) {
        $p2$044 = $316;
       } else {
        $$lcssa43 = $317;
        break;
       }
      }
     } else {
      $$lcssa43 = $308;
     }
     $319 = (($$lcssa43) + -1)|0;
     HEAP32[$20>>2] = $319;
     $659 = $319;
    } else {
     $659 = $308;
    }
    $306 = ($302>>>0)>($300>>>0);
    if ($306) {
     $308 = $659;$p$048 = $302;
    } else {
     $321 = $659;
     break;
    }
   }
  } else {
   $321 = $299;
  }
  $320 = (($321) - ($300))|0;
  $322 = ((($blockDescs) + (($a1$053*56)|0)|0) + 8|0);
  HEAP32[$322>>2] = $320;
  $323 = (($a1$053) + 1)|0;
  $324 = ($323>>>0)<(4);
  if ($324) {
   $a1$053 = $323;$numContacts$054 = $numContacts$3;
  } else {
   label = 2;
   break;
  }
 }
 if ((label|0) == 2) {
  $37 = (($threadContext) + 348|0);
  $$pre$i$i6 = (($threadContext) + 352|0);
  $38 = (($threadContext) + 344|0);
  $a2$027 = 0;
  while(1) {
   $325 = (($n) + ($a2$027<<2)|0);
   $326 = ((($blockDescs) + (($a2$027*56)|0)|0) + 4|0);
   $327 = HEAP32[$326>>2]|0;
   $328 = ((($blockDescs) + (($a2$027*56)|0)|0) + 8|0);
   $329 = HEAP32[$328>>2]|0;
   $330 = (($329) + ($327))|0;
   $331 = ($327>>>0)<($330>>>0);
   if ($331) {
    $i$01$i$i = $327;$numFrictionPatches$02$i$i = 0;
    while(1) {
     $332 = ((($threadContext) + ($i$01$i$i<<2)|0) + 8464|0);
     $333 = HEAP32[$332>>2]|0;
     $not$$i$i = ($333|0)!=(65535);
     $334 = $not$$i$i&1;
     $numFrictionPatches$0$$i$i = (($334) + ($numFrictionPatches$02$i$i))|0;
     $335 = (($i$01$i$i) + 1)|0;
     $exitcond$i$i = ($335|0)==($330|0);
     if ($exitcond$i$i) {
      break;
     } else {
      $i$01$i$i = $335;$numFrictionPatches$02$i$i = $numFrictionPatches$0$$i$i;
     }
    }
    $336 = ($numFrictionPatches$0$$i$i*96)|0;
    $337 = ($336|0)==(0);
    if ($337) {
     $353 = 1;$frictionPatches$0$i = 0;$numFrictionPatches$0$$i$i18 = $numFrictionPatches$0$$i$i;
    } else {
     $338 = ($336>>>0)>(16384);
     do {
      if ($338) {
       $$0$i$i8 = (-1);
      } else {
       $339 = HEAP32[$37>>2]|0;
       $340 = ($339|0)==(0|0);
       if ($340) {
        label = 60;
       } else {
        $341 = HEAP32[$$pre$i$i6>>2]|0;
        $342 = (($341) + ($336))|0;
        $343 = ($342>>>0)>(16384);
        if ($343) {
         label = 60;
        } else {
         $348 = $339;$349 = $341;
        }
       }
       if ((label|0) == 60) {
        label = 0;
        $344 = HEAP32[$38>>2]|0;
        $345 = (__ZN5physx17PxcNpMemBlockPool20acquireFrictionBlockEv($344)|0);
        HEAP32[$37>>2] = $345;
        HEAP32[$$pre$i$i6>>2] = 0;
        $346 = ($345|0)==(0|0);
        if ($346) {
         $$0$i$i8 = 0;
         break;
        } else {
         $348 = $345;$349 = 0;
        }
       }
       $347 = (($348) + ($349)|0);
       $350 = (($349) + ($336))|0;
       HEAP32[$$pre$i$i6>>2] = $350;
       $$0$i$i8 = $347;
      }
     } while(0);
     $351 = ($$0$i$i8|0)==(0|0);
     $$not$i9 = ($$0$i$i8|0)!=((-1)|0);
     $or$cond3$i10 = $351 | $$not$i9;
     $$$i11 = $or$cond3$i10 ? $$0$i$i8 : 0;
     $353 = 0;$frictionPatches$0$i = $$$i11;$numFrictionPatches$0$$i$i18 = $numFrictionPatches$0$$i$i;
    }
   } else {
    $353 = 1;$frictionPatches$0$i = 0;$numFrictionPatches$0$$i$i18 = 0;
   }
   $352 = ($frictionPatches$0$i|0)!=(0|0);
   $$4$i = $353 | $352;
   $354 = HEAP32[$325>>2]|0;
   $355 = (($354) + 40|0);
   HEAP32[$355>>2] = 0;
   $356 = HEAP32[$325>>2]|0;
   $357 = (($356) + 36|0);
   HEAP32[$357>>2] = 0;
   if (!($$4$i)) {
    $$2 = 0;
    label = 83;
    break;
   }
   $358 = (($356) + 40|0);
   HEAP32[$358>>2] = $frictionPatches$0$i;
   $359 = HEAP32[$325>>2]|0;
   $360 = (($359) + 36|0);
   HEAP32[$360>>2] = $numFrictionPatches$0$$i$i18;
   $361 = ($frictionPatches$0$i|0)==(0|0);
   if (!($361)) {
    $362 = (($frictionPatches$0$i) + 128|0);
    $363 = (($frictionPatches$0$i) + 256|0);
    $364 = HEAP32[$328>>2]|0;
    $365 = ($364|0)==(0);
    if (!($365)) {
     $660 = $364;$frictionPatches$0$i1925 = $frictionPatches$0$i;$i$026 = 0;
     while(1) {
      $366 = HEAP32[$326>>2]|0;
      $367 = (($366) + ($i$026))|0;
      $368 = ((($threadContext) + ($367<<2)|0) + 8464|0);
      $369 = HEAP32[$368>>2]|0;
      $370 = ($369|0)==(65535);
      if ($370) {
       $443 = $660;$frictionPatches$0$i20 = $frictionPatches$0$i1925;
      } else {
       $371 = (($frictionPatches$0$i1925) + 96|0);
       $372 = ((($threadContext) + (($367*96)|0)|0) + 5264|0);
       $373 = HEAP8[$372>>0]|0;
       HEAP8[$frictionPatches$0$i1925>>0] = $373;
       $374 = ((($threadContext) + (($367*96)|0)|0) + 5280|0);
       $375 = HEAP16[$374>>1]|0;
       $376 = (($frictionPatches$0$i1925) + 16|0);
       HEAP16[$376>>1] = $375;
       $377 = ((($threadContext) + (($367*96)|0)|0) + 5288|0);
       $378 = Math_fround(HEAPF32[$377>>2]);
       $379 = (($frictionPatches$0$i1925) + 24|0);
       HEAPF32[$379>>2] = $378;
       $380 = ((($threadContext) + (($367*96)|0)|0) + 5292|0);
       $381 = Math_fround(HEAPF32[$380>>2]);
       $382 = (($frictionPatches$0$i1925) + 28|0);
       HEAPF32[$382>>2] = $381;
       $383 = ((($threadContext) + (($367*96)|0)|0) + 5296|0);
       $384 = Math_fround(HEAPF32[$383>>2]);
       $385 = (($frictionPatches$0$i1925) + 32|0);
       HEAPF32[$385>>2] = $384;
       $386 = ((($threadContext) + (($367*96)|0)|0) + 5300|0);
       $387 = Math_fround(HEAPF32[$386>>2]);
       $388 = (($frictionPatches$0$i1925) + 36|0);
       HEAPF32[$388>>2] = $387;
       $389 = ((($threadContext) + (($367*96)|0)|0) + 5304|0);
       $390 = Math_fround(HEAPF32[$389>>2]);
       $391 = (($frictionPatches$0$i1925) + 40|0);
       HEAPF32[$391>>2] = $390;
       $392 = ((($threadContext) + (($367*96)|0)|0) + 5308|0);
       $393 = Math_fround(HEAPF32[$392>>2]);
       $394 = (($frictionPatches$0$i1925) + 44|0);
       HEAPF32[$394>>2] = $393;
       $395 = ((($threadContext) + (($367*96)|0)|0) + 5312|0);
       $396 = Math_fround(HEAPF32[$395>>2]);
       $397 = (($frictionPatches$0$i1925) + 48|0);
       HEAPF32[$397>>2] = $396;
       $398 = ((($threadContext) + (($367*96)|0)|0) + 5316|0);
       $399 = Math_fround(HEAPF32[$398>>2]);
       $400 = (($frictionPatches$0$i1925) + 52|0);
       HEAPF32[$400>>2] = $399;
       $401 = ((($threadContext) + (($367*96)|0)|0) + 5320|0);
       $402 = Math_fround(HEAPF32[$401>>2]);
       $403 = (($frictionPatches$0$i1925) + 56|0);
       HEAPF32[$403>>2] = $402;
       $404 = ((($threadContext) + (($367*96)|0)|0) + 5324|0);
       $405 = Math_fround(HEAPF32[$404>>2]);
       $406 = (($frictionPatches$0$i1925) + 60|0);
       HEAPF32[$406>>2] = $405;
       $407 = ((($threadContext) + (($367*96)|0)|0) + 5328|0);
       $408 = Math_fround(HEAPF32[$407>>2]);
       $409 = (($frictionPatches$0$i1925) + 64|0);
       HEAPF32[$409>>2] = $408;
       $410 = ((($threadContext) + (($367*96)|0)|0) + 5332|0);
       $411 = Math_fround(HEAPF32[$410>>2]);
       $412 = (($frictionPatches$0$i1925) + 68|0);
       HEAPF32[$412>>2] = $411;
       $413 = ((($threadContext) + (($367*96)|0)|0) + 5336|0);
       $414 = Math_fround(HEAPF32[$413>>2]);
       $415 = (($frictionPatches$0$i1925) + 72|0);
       HEAPF32[$415>>2] = $414;
       $416 = ((($threadContext) + (($367*96)|0)|0) + 5340|0);
       $417 = Math_fround(HEAPF32[$416>>2]);
       $418 = (($frictionPatches$0$i1925) + 76|0);
       HEAPF32[$418>>2] = $417;
       $419 = ((($threadContext) + (($367*96)|0)|0) + 5344|0);
       $420 = Math_fround(HEAPF32[$419>>2]);
       $421 = (($frictionPatches$0$i1925) + 80|0);
       HEAPF32[$421>>2] = $420;
       $422 = ((($threadContext) + (($367*96)|0)|0) + 5348|0);
       $423 = Math_fround(HEAPF32[$422>>2]);
       $424 = (($frictionPatches$0$i1925) + 84|0);
       HEAPF32[$424>>2] = $423;
       $425 = ((($threadContext) + (($367*96)|0)|0) + 5352|0);
       $426 = Math_fround(HEAPF32[$425>>2]);
       $427 = (($frictionPatches$0$i1925) + 88|0);
       HEAPF32[$427>>2] = $426;
       $428 = ((($threadContext) + (($367*96)|0)|0) + 5356|0);
       $429 = Math_fround(HEAPF32[$428>>2]);
       $430 = (($frictionPatches$0$i1925) + 92|0);
       HEAPF32[$430>>2] = $429;
       $431 = ((($threadContext) + (($367*96)|0)|0) + 5284|0);
       $432 = HEAP16[$431>>1]|0;
       $433 = (($frictionPatches$0$i1925) + 20|0);
       HEAP16[$433>>1] = $432;
       $434 = ((($threadContext) + (($367*96)|0)|0) + 5282|0);
       $435 = HEAP16[$434>>1]|0;
       $436 = (($frictionPatches$0$i1925) + 18|0);
       HEAP16[$436>>1] = $435;
       $437 = ((($threadContext) + (($367*96)|0)|0) + 5286|0);
       $438 = HEAP16[$437>>1]|0;
       $439 = (($frictionPatches$0$i1925) + 22|0);
       HEAP16[$439>>1] = $438;
       $440 = (($371) + 256|0);
       $$pre65 = HEAP32[$328>>2]|0;
       $443 = $$pre65;$frictionPatches$0$i20 = $371;
      }
      $441 = (($i$026) + 1)|0;
      $442 = ($441>>>0)<($443>>>0);
      if ($442) {
       $660 = $443;$frictionPatches$0$i1925 = $frictionPatches$0$i20;$i$026 = $441;
      } else {
       break;
      }
     }
    }
   }
   $444 = (($a2$027) + 1)|0;
   $445 = ($444>>>0)<(4);
   if ($445) {
    $a2$027 = $444;
   } else {
    break;
   }
  }
  if ((label|0) == 83) {
   STACKTOP = sp;return ($$2|0);
  }
  HEAP32[$solverConstraintByteSize>>2] = 0;
  $446 = (($threadContext) + 316|0);
  __Z28computeBlockStreamByteSizes4PN5physx21PxcSolverContact4DescERjPjRNS_18PxcNpThreadContextE($blockDescs,$solverConstraintByteSize,$axisConstraintCount,$threadContext);
  $447 = HEAP32[$solverConstraintByteSize>>2]|0;
  $448 = ($447|0)==(0);
  if ($448) {
   $$$i1721$ph = 0;$471 = 0;
  } else {
   $449 = (($447) + 16)|0;
   $450 = ($449>>>0)>(16384);
   if ($450) {
    $$2 = 1;
    STACKTOP = sp;return ($$2|0);
   }
   $451 = (($447) + 31)|0;
   $452 = $451 & -16;
   $453 = ($452>>>0)>(16384);
   do {
    if ($453) {
     $454 = HEAP32[$446>>2]|0;
     $455 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($454,$452)|0);
     $$0$i$i = $455;
    } else {
     $456 = (($threadContext) + 320|0);
     $457 = HEAP32[$456>>2]|0;
     $458 = ($457|0)==(0|0);
     $$pre$i$i = (($threadContext) + 324|0);
     if (!($458)) {
      $459 = HEAP32[$$pre$i$i>>2]|0;
      $460 = (($459) + ($452))|0;
      $461 = ($460>>>0)>(16384);
      if (!($461)) {
       $464 = (($457) + ($459)|0);
       HEAP32[$$pre$i$i>>2] = $460;
       $$0$i$i = $464;
       break;
      }
     }
     $462 = HEAP32[$446>>2]|0;
     $463 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($462,$constraintBlockManager)|0);
     HEAP32[$456>>2] = $463;
     HEAP32[$$pre$i$i>>2] = $452;
     $$0$i$i = $463;
    }
   } while(0);
   $465 = ($$0$i$i|0)==(0|0);
   $notlhs = ($$0$i$i|0)!=(0|0);
   $notrhs = ($$0$i$i|0)==((-1)|0);
   $not$or$cond3$i = $notrhs & $notlhs;
   $466 = $465 | $not$or$cond3$i;
   $467 = (($threadContext) + 8776|0);
   $468 = HEAP32[$467>>2]|0;
   $469 = (($468) + ($447))|0;
   HEAP32[$467>>2] = $469;
   if ($466) {
    $$2 = 0;
    STACKTOP = sp;return ($$2|0);
   } else {
    $$$i1721$ph = $$0$i$i;$471 = $447;
   }
  }
  $470 = $471 >>> 4;
  $472 = $470&65535;
  $473 = HEAP32[$n>>2]|0;
  HEAP32[$473>>2] = $$$i1721$ph;
  $474 = HEAP32[$n>>2]|0;
  $475 = (($474) + 4|0);
  HEAP32[$475>>2] = $471;
  $476 = HEAP32[$axisConstraintCount>>2]|0;
  $477 = (($474) + 16|0);
  $478 = HEAP16[$477>>1]|0;
  $479 = $478&65535;
  $480 = (($479) + ($476))|0;
  $481 = $480&65535;
  HEAP16[$477>>1] = $481;
  $482 = HEAP32[$desc>>2]|0;
  $483 = (($482) + 16|0);
  HEAP32[$483>>2] = $$$i1721$ph;
  $484 = HEAP32[$desc>>2]|0;
  $485 = (($484) + 26|0);
  HEAP16[$485>>1] = $472;
  $486 = HEAP32[$n>>2]|0;
  $487 = (($486) + 98|0);
  $488 = HEAP16[$487>>1]|0;
  $489 = $488 & 16;
  $490 = ($489<<16>>16)==(0);
  if ($490) {
   $$0$i = 0;$503 = 0;
  } else {
   $491 = (($486) + 20|0);
   $492 = HEAP16[$491>>1]|0;
   $493 = (($486) + 28|0);
   $494 = HEAP32[$493>>2]|0;
   $495 = (($486) + 32|0);
   $496 = HEAP32[$495>>2]|0;
   $497 = (($496) + 15)|0;
   $498 = $497 & -16;
   $499 = (($494) + ($498)|0);
   $$0$i = $499;$503 = $492;
  }
  $500 = (($484) + 20|0);
  HEAP32[$500>>2] = $$0$i;
  $501 = HEAP32[$desc>>2]|0;
  $502 = (($501) + 24|0);
  HEAP16[$502>>1] = $503;
  $504 = (($n) + 4|0);
  $505 = HEAP32[$504>>2]|0;
  HEAP32[$505>>2] = $$$i1721$ph;
  $506 = HEAP32[$504>>2]|0;
  $507 = (($506) + 4|0);
  HEAP32[$507>>2] = $471;
  $508 = (($axisConstraintCount) + 4|0);
  $509 = HEAP32[$508>>2]|0;
  $510 = (($506) + 16|0);
  $511 = HEAP16[$510>>1]|0;
  $512 = $511&65535;
  $513 = (($512) + ($509))|0;
  $514 = $513&65535;
  HEAP16[$510>>1] = $514;
  $515 = HEAP32[$2>>2]|0;
  $516 = (($515) + 16|0);
  HEAP32[$516>>2] = $$$i1721$ph;
  $517 = HEAP32[$2>>2]|0;
  $518 = (($517) + 26|0);
  HEAP16[$518>>1] = $472;
  $519 = HEAP32[$504>>2]|0;
  $520 = (($519) + 98|0);
  $521 = HEAP16[$520>>1]|0;
  $522 = $521 & 16;
  $523 = ($522<<16>>16)==(0);
  if ($523) {
   $$0$i$1 = 0;$536 = 0;
  } else {
   $524 = (($519) + 20|0);
   $525 = HEAP16[$524>>1]|0;
   $526 = (($519) + 28|0);
   $527 = HEAP32[$526>>2]|0;
   $528 = (($519) + 32|0);
   $529 = HEAP32[$528>>2]|0;
   $530 = (($529) + 15)|0;
   $531 = $530 & -16;
   $532 = (($527) + ($531)|0);
   $$0$i$1 = $532;$536 = $525;
  }
  $533 = (($517) + 20|0);
  HEAP32[$533>>2] = $$0$i$1;
  $534 = HEAP32[$2>>2]|0;
  $535 = (($534) + 24|0);
  HEAP16[$535>>1] = $536;
  $537 = (($n) + 8|0);
  $538 = HEAP32[$537>>2]|0;
  HEAP32[$538>>2] = $$$i1721$ph;
  $539 = HEAP32[$537>>2]|0;
  $540 = (($539) + 4|0);
  HEAP32[$540>>2] = $471;
  $541 = (($axisConstraintCount) + 8|0);
  $542 = HEAP32[$541>>2]|0;
  $543 = (($539) + 16|0);
  $544 = HEAP16[$543>>1]|0;
  $545 = $544&65535;
  $546 = (($545) + ($542))|0;
  $547 = $546&65535;
  HEAP16[$543>>1] = $547;
  $548 = HEAP32[$5>>2]|0;
  $549 = (($548) + 16|0);
  HEAP32[$549>>2] = $$$i1721$ph;
  $550 = HEAP32[$5>>2]|0;
  $551 = (($550) + 26|0);
  HEAP16[$551>>1] = $472;
  $552 = HEAP32[$537>>2]|0;
  $553 = (($552) + 98|0);
  $554 = HEAP16[$553>>1]|0;
  $555 = $554 & 16;
  $556 = ($555<<16>>16)==(0);
  if ($556) {
   $$0$i$2 = 0;$569 = 0;
  } else {
   $557 = (($552) + 20|0);
   $558 = HEAP16[$557>>1]|0;
   $559 = (($552) + 28|0);
   $560 = HEAP32[$559>>2]|0;
   $561 = (($552) + 32|0);
   $562 = HEAP32[$561>>2]|0;
   $563 = (($562) + 15)|0;
   $564 = $563 & -16;
   $565 = (($560) + ($564)|0);
   $$0$i$2 = $565;$569 = $558;
  }
  $566 = (($550) + 20|0);
  HEAP32[$566>>2] = $$0$i$2;
  $567 = HEAP32[$5>>2]|0;
  $568 = (($567) + 24|0);
  HEAP16[$568>>1] = $569;
  $570 = (($n) + 12|0);
  $571 = HEAP32[$570>>2]|0;
  HEAP32[$571>>2] = $$$i1721$ph;
  $572 = HEAP32[$570>>2]|0;
  $573 = (($572) + 4|0);
  HEAP32[$573>>2] = $471;
  $574 = (($axisConstraintCount) + 12|0);
  $575 = HEAP32[$574>>2]|0;
  $576 = (($572) + 16|0);
  $577 = HEAP16[$576>>1]|0;
  $578 = $577&65535;
  $579 = (($578) + ($575))|0;
  $580 = $579&65535;
  HEAP16[$576>>1] = $580;
  $581 = HEAP32[$8>>2]|0;
  $582 = (($581) + 16|0);
  HEAP32[$582>>2] = $$$i1721$ph;
  $583 = HEAP32[$8>>2]|0;
  $584 = (($583) + 26|0);
  HEAP16[$584>>1] = $472;
  $585 = HEAP32[$570>>2]|0;
  $586 = (($585) + 98|0);
  $587 = HEAP16[$586>>1]|0;
  $588 = $587 & 16;
  $589 = ($588<<16>>16)==(0);
  if ($589) {
   $$0$i$3 = 0;$602 = 0;
  } else {
   $590 = (($585) + 20|0);
   $591 = HEAP16[$590>>1]|0;
   $592 = (($585) + 28|0);
   $593 = HEAP32[$592>>2]|0;
   $594 = (($585) + 32|0);
   $595 = HEAP32[$594>>2]|0;
   $596 = (($595) + 15)|0;
   $597 = $596 & -16;
   $598 = (($593) + ($597)|0);
   $$0$i$3 = $598;$602 = $591;
  }
  $599 = (($583) + 20|0);
  HEAP32[$599>>2] = $$0$i$3;
  $600 = HEAP32[$8>>2]|0;
  $601 = (($600) + 24|0);
  HEAP16[$601>>1] = $602;
  $603 = Math_fround(HEAPF32[$invMassScale0>>2]);
  $604 = (($invMassScale0) + 4|0);
  $605 = Math_fround(HEAPF32[$604>>2]);
  $606 = (($invMassScale0) + 8|0);
  $607 = Math_fround(HEAPF32[$606>>2]);
  $608 = (($invMassScale0) + 12|0);
  $609 = Math_fround(HEAPF32[$608>>2]);
  HEAPF32[$iMassScale0>>2] = $603;
  $610 = (($iMassScale0) + 4|0);
  HEAPF32[$610>>2] = $605;
  $611 = (($iMassScale0) + 8|0);
  HEAPF32[$611>>2] = $607;
  $612 = (($iMassScale0) + 12|0);
  HEAPF32[$612>>2] = $609;
  $613 = Math_fround(HEAPF32[$invInertiaScale0>>2]);
  $614 = (($invInertiaScale0) + 4|0);
  $615 = Math_fround(HEAPF32[$614>>2]);
  $616 = (($invInertiaScale0) + 8|0);
  $617 = Math_fround(HEAPF32[$616>>2]);
  $618 = (($invInertiaScale0) + 12|0);
  $619 = Math_fround(HEAPF32[$618>>2]);
  HEAPF32[$iInertiaScale0>>2] = $613;
  $620 = (($iInertiaScale0) + 4|0);
  HEAPF32[$620>>2] = $615;
  $621 = (($iInertiaScale0) + 8|0);
  HEAPF32[$621>>2] = $617;
  $622 = (($iInertiaScale0) + 12|0);
  HEAPF32[$622>>2] = $619;
  $623 = Math_fround(HEAPF32[$invMassScale1>>2]);
  $624 = (($invMassScale1) + 4|0);
  $625 = Math_fround(HEAPF32[$624>>2]);
  $626 = (($invMassScale1) + 8|0);
  $627 = Math_fround(HEAPF32[$626>>2]);
  $628 = (($invMassScale1) + 12|0);
  $629 = Math_fround(HEAPF32[$628>>2]);
  HEAPF32[$iMassScale1>>2] = $623;
  $630 = (($iMassScale1) + 4|0);
  HEAPF32[$630>>2] = $625;
  $631 = (($iMassScale1) + 8|0);
  HEAPF32[$631>>2] = $627;
  $632 = (($iMassScale1) + 12|0);
  HEAPF32[$632>>2] = $629;
  $633 = Math_fround(HEAPF32[$invInertiaScale1>>2]);
  $634 = (($invInertiaScale1) + 4|0);
  $635 = Math_fround(HEAPF32[$634>>2]);
  $636 = (($invInertiaScale1) + 8|0);
  $637 = Math_fround(HEAPF32[$636>>2]);
  $638 = (($invInertiaScale1) + 12|0);
  $639 = Math_fround(HEAPF32[$638>>2]);
  HEAPF32[$iInertiaScale1>>2] = $633;
  $640 = (($iInertiaScale1) + 4|0);
  HEAPF32[$640>>2] = $635;
  $641 = (($iInertiaScale1) + 8|0);
  HEAPF32[$641>>2] = $637;
  $642 = (($iInertiaScale1) + 12|0);
  HEAPF32[$642>>2] = $639;
  __ZN5physx31setupFinalizeSolverConstraints4EPNS_21PxcSolverContact4DescERNS_18PxcNpThreadContextEPhffRKNS_6shdfnd3aos5Vec4VES9_S9_S9_($blockDescs,$threadContext,$$$i1721$ph,$invDtF32,$bounceThresholdF32,$iMassScale0,$iInertiaScale0,$iMassScale1,$iInertiaScale1);
  $643 = (($$$i1721$ph) + ($471)|0);
  HEAP32[$643>>2] = 0;
  $$2 = 2;
  STACKTOP = sp;return ($$2|0);
 }
 else if ((label|0) == 83) {
  STACKTOP = sp;return ($$2|0);
 }
 return 0|0;
}
function __ZL18getFrictionPatchesRN5physx26PxcFrictionPatchStreamPairERNS_20PxcCorrelationBufferEPKhjRKNS_11PxTransformES8_f($c,$frictionCookie,$frictionPatchCount,$bodyFrame0,$bodyFrame1,$correlationDistance) {
 $c = $c|0;
 $frictionCookie = $frictionCookie|0;
 $frictionPatchCount = $frictionPatchCount|0;
 $bodyFrame0 = $bodyFrame0|0;
 $bodyFrame1 = $bodyFrame1|0;
 $correlationDistance = Math_fround($correlationDistance);
 var $$0 = 0, $$idx = 0, $$idx$val = Math_fround(0), $$idx10 = 0, $$idx10$val = Math_fround(0), $$idx11 = 0, $$idx11$val = Math_fround(0), $$idx12 = 0, $$idx12$val = Math_fround(0), $$idx13 = 0, $$idx13$val = Math_fround(0), $$idx14 = 0, $$idx14$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $$idx3 = 0, $$idx3$val = Math_fround(0), $$idx4 = 0, $$idx4$val = Math_fround(0), $$idx5 = 0;
 var $$idx5$val = Math_fround(0), $$idx6 = 0, $$idx6$val = Math_fround(0), $$idx9 = 0, $$idx9$val = Math_fround(0), $$in = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0;
 var $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0);
 var $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0;
 var $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i18 = Math_fround(0), $patches$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($frictionCookie|0)==(0|0);
 if ($0) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$bodyFrame0>>2]);
 $2 = Math_fround(-$1);
 $3 = (($bodyFrame0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$4);
 $6 = (($bodyFrame0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(-$7);
 $9 = (($bodyFrame0) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($bodyFrame1) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($bodyFrame0) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 - $14);
 $16 = (($bodyFrame1) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($bodyFrame0) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 - $19);
 $21 = (($bodyFrame1) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($bodyFrame0) + 24|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 - $24);
 $26 = Math_fround($15 * Math_fround(2.0));
 $27 = Math_fround($20 * Math_fround(2.0));
 $28 = Math_fround($25 * Math_fround(2.0));
 $29 = Math_fround($10 * $10);
 $30 = Math_fround($29 + Math_fround(-0.5));
 $31 = Math_fround($26 * $2);
 $32 = Math_fround($27 * $5);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround($28 * $8);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($30 * $26);
 $37 = Math_fround($28 * $5);
 $38 = Math_fround($27 * $8);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($10 * $39);
 $41 = Math_fround($36 + $40);
 $42 = Math_fround($35 * $2);
 $43 = Math_fround($42 + $41);
 $44 = Math_fround($30 * $27);
 $45 = Math_fround($26 * $8);
 $46 = Math_fround($28 * $2);
 $47 = Math_fround($45 - $46);
 $48 = Math_fround($10 * $47);
 $49 = Math_fround($44 + $48);
 $50 = Math_fround($35 * $5);
 $51 = Math_fround($50 + $49);
 $52 = Math_fround($30 * $28);
 $53 = Math_fround($27 * $2);
 $54 = Math_fround($26 * $5);
 $55 = Math_fround($53 - $54);
 $56 = Math_fround($10 * $55);
 $57 = Math_fround($52 + $56);
 $58 = Math_fround($35 * $8);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround(HEAPF32[$bodyFrame1>>2]);
 $61 = Math_fround($10 * $60);
 $62 = (($bodyFrame1) + 12|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $2);
 $65 = Math_fround($61 + $64);
 $66 = (($bodyFrame1) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 * $5);
 $69 = Math_fround($65 + $68);
 $70 = (($bodyFrame1) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $8);
 $73 = Math_fround($69 - $72);
 $74 = Math_fround($10 * $71);
 $75 = Math_fround($63 * $5);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($60 * $8);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($67 * $2);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($10 * $67);
 $82 = Math_fround($63 * $8);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($71 * $2);
 $85 = Math_fround($84 + $83);
 $86 = Math_fround($60 * $5);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($10 * $63);
 $89 = Math_fround($60 * $2);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($71 * $5);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($67 * $8);
 $94 = Math_fround($92 - $93);
 $95 = ($frictionPatchCount|0)==(0);
 if ($95) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $96 = Math_fround($94 * $94);
 $97 = Math_fround($96 + Math_fround(-0.5));
 $98 = (($c) + 4232|0);
 $$in = $frictionPatchCount;$patches$01 = $frictionCookie;
 L7: while(1) {
  $99 = (($$in) + -1)|0;
  $100 = (($patches$01) + 128|0);
  $101 = (($patches$01) + 96|0);
  $102 = HEAP8[$patches$01>>0]|0;
  $103 = ($102<<24>>24)==(0);
  do {
   if ($103) {
    $104 = (($patches$01) + 16|0);
    $105 = HEAP16[$104>>1]|0;
    $106 = ($105<<16>>16)==(0);
    if (!($106)) {
     $107 = (($patches$01) + 24|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     $109 = (($patches$01) + 28|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = (($patches$01) + 32|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = (($patches$01) + 36|0);
     $114 = Math_fround(HEAPF32[$113>>2]);
     $115 = Math_fround($114 * Math_fround(2.0));
     $116 = (($patches$01) + 40|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = Math_fround($117 * Math_fround(2.0));
     $119 = (($patches$01) + 44|0);
     $120 = Math_fround(HEAPF32[$119>>2]);
     $121 = Math_fround($120 * Math_fround(2.0));
     $122 = Math_fround($73 * $115);
     $123 = Math_fround($80 * $118);
     $124 = Math_fround($122 + $123);
     $125 = Math_fround($87 * $121);
     $126 = Math_fround($124 + $125);
     $127 = Math_fround($97 * $115);
     $128 = Math_fround($80 * $121);
     $129 = Math_fround($87 * $118);
     $130 = Math_fround($128 - $129);
     $131 = Math_fround($94 * $130);
     $132 = Math_fround($127 + $131);
     $133 = Math_fround($73 * $126);
     $134 = Math_fround($133 + $132);
     $135 = Math_fround($97 * $118);
     $136 = Math_fround($87 * $115);
     $137 = Math_fround($73 * $121);
     $138 = Math_fround($136 - $137);
     $139 = Math_fround($94 * $138);
     $140 = Math_fround($135 + $139);
     $141 = Math_fround($80 * $126);
     $142 = Math_fround($141 + $140);
     $143 = Math_fround($97 * $121);
     $144 = Math_fround($73 * $118);
     $145 = Math_fround($80 * $115);
     $146 = Math_fround($144 - $145);
     $147 = Math_fround($94 * $146);
     $148 = Math_fround($143 + $147);
     $149 = Math_fround($87 * $126);
     $150 = Math_fround($148 + $149);
     $151 = Math_fround($108 * $134);
     $152 = Math_fround($110 * $142);
     $153 = Math_fround($151 + $152);
     $154 = Math_fround($112 * $150);
     $155 = Math_fround($154 + $153);
     $156 = $155 > Math_fround(0.999000012874603271484);
     if ($156) {
      $$idx9 = (($patches$01) + 48|0);
      $$idx9$val = Math_fround(HEAPF32[$$idx9>>2]);
      $$idx10 = (($patches$01) + 52|0);
      $$idx10$val = Math_fround(HEAPF32[$$idx10>>2]);
      $$idx11 = (($patches$01) + 56|0);
      $$idx11$val = Math_fround(HEAPF32[$$idx11>>2]);
      $$idx12 = (($patches$01) + 72|0);
      $$idx12$val = Math_fround(HEAPF32[$$idx12>>2]);
      $$idx13 = (($patches$01) + 76|0);
      $$idx13$val = Math_fround(HEAPF32[$$idx13>>2]);
      $$idx14 = (($patches$01) + 80|0);
      $$idx14$val = Math_fround(HEAPF32[$$idx14>>2]);
      $158 = Math_fround($$idx12$val * Math_fround(2.0));
      $159 = Math_fround($$idx13$val * Math_fround(2.0));
      $160 = Math_fround($$idx14$val * Math_fround(2.0));
      $161 = Math_fround($73 * $158);
      $162 = Math_fround($80 * $159);
      $163 = Math_fround($161 + $162);
      $164 = Math_fround($87 * $160);
      $165 = Math_fround($163 + $164);
      $166 = Math_fround($97 * $158);
      $167 = Math_fround($80 * $160);
      $168 = Math_fround($87 * $159);
      $169 = Math_fround($167 - $168);
      $170 = Math_fround($94 * $169);
      $171 = Math_fround($166 + $170);
      $172 = Math_fround($73 * $165);
      $173 = Math_fround($172 + $171);
      $174 = Math_fround($97 * $159);
      $175 = Math_fround($87 * $158);
      $176 = Math_fround($73 * $160);
      $177 = Math_fround($175 - $176);
      $178 = Math_fround($94 * $177);
      $179 = Math_fround($174 + $178);
      $180 = Math_fround($80 * $165);
      $181 = Math_fround($180 + $179);
      $182 = Math_fround($97 * $160);
      $183 = Math_fround($73 * $159);
      $184 = Math_fround($80 * $158);
      $185 = Math_fround($183 - $184);
      $186 = Math_fround($94 * $185);
      $187 = Math_fround($182 + $186);
      $188 = Math_fround($87 * $165);
      $189 = Math_fround($187 + $188);
      $190 = Math_fround($43 + $173);
      $191 = Math_fround($51 + $181);
      $192 = Math_fround($59 + $189);
      $193 = Math_fround($$idx9$val - $190);
      $194 = Math_fround($$idx10$val - $191);
      $195 = Math_fround($$idx11$val - $192);
      $196 = Math_fround($108 * $193);
      $197 = Math_fround($110 * $194);
      $198 = Math_fround($196 + $197);
      $199 = Math_fround($112 * $195);
      $200 = Math_fround($199 + $198);
      $fabsf$i$i$i18 = (Math_fround(Math_abs((Math_fround($200)))));
      $201 = $fabsf$i$i$i18 < $correlationDistance;
      if ($201) {
       $202 = ($105<<16>>16)==(2);
       if ($202) {
        $$idx = (($patches$01) + 60|0);
        $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
        $$idx2 = (($patches$01) + 64|0);
        $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
        $$idx3 = (($patches$01) + 68|0);
        $$idx3$val = Math_fround(HEAPF32[$$idx3>>2]);
        $$idx4 = (($patches$01) + 84|0);
        $$idx4$val = Math_fround(HEAPF32[$$idx4>>2]);
        $$idx5 = (($patches$01) + 88|0);
        $$idx5$val = Math_fround(HEAPF32[$$idx5>>2]);
        $$idx6 = (($patches$01) + 92|0);
        $$idx6$val = Math_fround(HEAPF32[$$idx6>>2]);
        $203 = Math_fround($$idx4$val * Math_fround(2.0));
        $204 = Math_fround($$idx5$val * Math_fround(2.0));
        $205 = Math_fround($$idx6$val * Math_fround(2.0));
        $206 = Math_fround($73 * $203);
        $207 = Math_fround($80 * $204);
        $208 = Math_fround($206 + $207);
        $209 = Math_fround($87 * $205);
        $210 = Math_fround($208 + $209);
        $211 = Math_fround($97 * $203);
        $212 = Math_fround($80 * $205);
        $213 = Math_fround($87 * $204);
        $214 = Math_fround($212 - $213);
        $215 = Math_fround($94 * $214);
        $216 = Math_fround($211 + $215);
        $217 = Math_fround($73 * $210);
        $218 = Math_fround($217 + $216);
        $219 = Math_fround($97 * $204);
        $220 = Math_fround($87 * $203);
        $221 = Math_fround($73 * $205);
        $222 = Math_fround($220 - $221);
        $223 = Math_fround($94 * $222);
        $224 = Math_fround($219 + $223);
        $225 = Math_fround($80 * $210);
        $226 = Math_fround($225 + $224);
        $227 = Math_fround($97 * $205);
        $228 = Math_fround($73 * $204);
        $229 = Math_fround($80 * $203);
        $230 = Math_fround($228 - $229);
        $231 = Math_fround($94 * $230);
        $232 = Math_fround($227 + $231);
        $233 = Math_fround($87 * $210);
        $234 = Math_fround($232 + $233);
        $235 = Math_fround($43 + $218);
        $236 = Math_fround($51 + $226);
        $237 = Math_fround($59 + $234);
        $238 = Math_fround($$idx$val - $235);
        $239 = Math_fround($$idx2$val - $236);
        $240 = Math_fround($$idx3$val - $237);
        $241 = Math_fround($108 * $238);
        $242 = Math_fround($110 * $239);
        $243 = Math_fround($241 + $242);
        $244 = Math_fround($112 * $240);
        $245 = Math_fround($244 + $243);
        $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($245)))));
        $246 = !($fabsf$i$i$i < $correlationDistance);
        if ($246) {
         break;
        }
       }
       $247 = HEAP32[$98>>2]|0;
       $248 = ($247|0)==(32);
       if ($248) {
        $$0 = 0;
        label = 13;
        break L7;
       }
       $249 = ((($c) + ($247<<2)|0) + 4100|0);
       HEAP16[$249>>1] = -1;
       $250 = HEAP32[$98>>2]|0;
       $251 = ((($c) + ($250<<2)|0) + 4102|0);
       HEAP16[$251>>1] = -1;
       $252 = HEAP32[$98>>2]|0;
       $253 = (($252) + 1)|0;
       HEAP32[$98>>2] = $253;
       $254 = HEAP8[$patches$01>>0]|0;
       $255 = ((($c) + (($252*96)|0)|0) + 768|0);
       HEAP8[$255>>0] = $254;
       $256 = HEAP16[$104>>1]|0;
       $257 = ((($c) + (($252*96)|0)|0) + 784|0);
       HEAP16[$257>>1] = $256;
       $258 = Math_fround(HEAPF32[$107>>2]);
       $259 = ((($c) + (($252*96)|0)|0) + 792|0);
       HEAPF32[$259>>2] = $258;
       $260 = Math_fround(HEAPF32[$109>>2]);
       $261 = ((($c) + (($252*96)|0)|0) + 796|0);
       HEAPF32[$261>>2] = $260;
       $262 = Math_fround(HEAPF32[$111>>2]);
       $263 = ((($c) + (($252*96)|0)|0) + 800|0);
       HEAPF32[$263>>2] = $262;
       $264 = Math_fround(HEAPF32[$113>>2]);
       $265 = ((($c) + (($252*96)|0)|0) + 804|0);
       HEAPF32[$265>>2] = $264;
       $266 = Math_fround(HEAPF32[$116>>2]);
       $267 = ((($c) + (($252*96)|0)|0) + 808|0);
       HEAPF32[$267>>2] = $266;
       $268 = Math_fround(HEAPF32[$119>>2]);
       $269 = ((($c) + (($252*96)|0)|0) + 812|0);
       HEAPF32[$269>>2] = $268;
       $270 = Math_fround(HEAPF32[$$idx9>>2]);
       $271 = ((($c) + (($252*96)|0)|0) + 816|0);
       HEAPF32[$271>>2] = $270;
       $272 = Math_fround(HEAPF32[$$idx10>>2]);
       $273 = ((($c) + (($252*96)|0)|0) + 820|0);
       HEAPF32[$273>>2] = $272;
       $274 = Math_fround(HEAPF32[$$idx11>>2]);
       $275 = ((($c) + (($252*96)|0)|0) + 824|0);
       HEAPF32[$275>>2] = $274;
       $276 = (($patches$01) + 60|0);
       $277 = Math_fround(HEAPF32[$276>>2]);
       $278 = ((($c) + (($252*96)|0)|0) + 828|0);
       HEAPF32[$278>>2] = $277;
       $279 = (($patches$01) + 64|0);
       $280 = Math_fround(HEAPF32[$279>>2]);
       $281 = ((($c) + (($252*96)|0)|0) + 832|0);
       HEAPF32[$281>>2] = $280;
       $282 = (($patches$01) + 68|0);
       $283 = Math_fround(HEAPF32[$282>>2]);
       $284 = ((($c) + (($252*96)|0)|0) + 836|0);
       HEAPF32[$284>>2] = $283;
       $285 = Math_fround(HEAPF32[$$idx12>>2]);
       $286 = ((($c) + (($252*96)|0)|0) + 840|0);
       HEAPF32[$286>>2] = $285;
       $287 = Math_fround(HEAPF32[$$idx13>>2]);
       $288 = ((($c) + (($252*96)|0)|0) + 844|0);
       HEAPF32[$288>>2] = $287;
       $289 = Math_fround(HEAPF32[$$idx14>>2]);
       $290 = ((($c) + (($252*96)|0)|0) + 848|0);
       HEAPF32[$290>>2] = $289;
       $291 = (($patches$01) + 84|0);
       $292 = Math_fround(HEAPF32[$291>>2]);
       $293 = ((($c) + (($252*96)|0)|0) + 852|0);
       HEAPF32[$293>>2] = $292;
       $294 = (($patches$01) + 88|0);
       $295 = Math_fround(HEAPF32[$294>>2]);
       $296 = ((($c) + (($252*96)|0)|0) + 856|0);
       HEAPF32[$296>>2] = $295;
       $297 = (($patches$01) + 92|0);
       $298 = Math_fround(HEAPF32[$297>>2]);
       $299 = ((($c) + (($252*96)|0)|0) + 860|0);
       HEAPF32[$299>>2] = $298;
       $300 = (($patches$01) + 20|0);
       $301 = HEAP16[$300>>1]|0;
       $302 = ((($c) + (($252*96)|0)|0) + 788|0);
       HEAP16[$302>>1] = $301;
       $303 = (($patches$01) + 18|0);
       $304 = HEAP16[$303>>1]|0;
       $305 = ((($c) + (($252*96)|0)|0) + 786|0);
       HEAP16[$305>>1] = $304;
       $306 = (($patches$01) + 22|0);
       $307 = HEAP16[$306>>1]|0;
       $308 = ((($c) + (($252*96)|0)|0) + 790|0);
       HEAP16[$308>>1] = $307;
      }
     }
    }
   }
  } while(0);
  $157 = ($99|0)==(0);
  if ($157) {
   $$0 = 1;
   label = 13;
   break;
  } else {
   $$in = $99;$patches$01 = $101;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z28computeBlockStreamByteSizes4PN5physx21PxcSolverContact4DescERjPjRNS_18PxcNpThreadContextE($descs,$_solverConstraintByteSize,$_axisConstraintCount,$threadContext) {
 $descs = $descs|0;
 $_solverConstraintByteSize = $_solverConstraintByteSize|0;
 $_axisConstraintCount = $_axisConstraintCount|0;
 $threadContext = $threadContext|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $a$012 = 0, $a1$03 = 0;
 var $axisConstraintCount$0$lcssa = 0, $axisConstraintCount$07 = 0, $axisConstraintCount$1 = 0, $exitcond = 0, $i$06 = 0, $maxContactCount = 0, $maxFrictionCount = 0, $maxPatches$013 = 0, $totalContacts$0$lcssa = 0, $totalContacts$01 = 0, $totalFriction$0$lcssa = 0, $totalFriction$02 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $maxContactCount = sp + 128|0;
 $maxFrictionCount = sp;
 dest=$maxContactCount+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$maxFrictionCount+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $a$012 = 0;$maxPatches$013 = 0;
 while(1) {
  $0 = ((($descs) + (($a$012*56)|0)|0) + 8|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $$lcssa = 0;$axisConstraintCount$0$lcssa = 0;
  } else {
   $3 = ((($descs) + (($a$012*56)|0)|0) + 4|0);
   $4 = HEAP32[$3>>2]|0;
   $axisConstraintCount$07 = 0;$i$06 = 0;
   while(1) {
    $7 = (($4) + ($i$06))|0;
    $8 = ((($threadContext) + (($7*96)|0)|0) + 5286|0);
    $9 = HEAP16[$8>>1]|0;
    $10 = $9 & 1;
    $11 = ($10<<16>>16)==(0);
    if ($11) {
     $12 = ((($threadContext) + (($7*96)|0)|0) + 5280|0);
     $13 = HEAP16[$12>>1]|0;
     $14 = ($13<<16>>16)!=(0);
     $76 = $14;
    } else {
     $76 = 0;
    }
    $15 = ((($threadContext) + ($7<<2)|0) + 8336|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0);
    if ($17) {
     $axisConstraintCount$1 = $axisConstraintCount$07;
    } else {
     $18 = (($maxContactCount) + ($i$06<<2)|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($16>>>0)<($19>>>0);
     $21 = $20 ? $19 : $16;
     HEAP32[$18>>2] = $21;
     $22 = (($16) + ($axisConstraintCount$07))|0;
     if ($76) {
      $23 = ((($threadContext) + (($7*96)|0)|0) + 5280|0);
      $24 = HEAP16[$23>>1]|0;
      $25 = $24&65535;
      $26 = $25 << 1;
      $27 = (($maxFrictionCount) + ($i$06<<2)|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($26>>>0)<($28>>>0);
      $30 = $29 ? $28 : $26;
      HEAP32[$27>>2] = $30;
      $31 = (($26) + ($22))|0;
      $axisConstraintCount$1 = $31;
     } else {
      $axisConstraintCount$1 = $22;
     }
    }
    $32 = (($i$06) + 1)|0;
    $33 = ($32>>>0)<($1>>>0);
    if ($33) {
     $axisConstraintCount$07 = $axisConstraintCount$1;$i$06 = $32;
    } else {
     $$lcssa = $1;$axisConstraintCount$0$lcssa = $axisConstraintCount$1;
     break;
    }
   }
  }
  $34 = ($$lcssa>>>0)<($maxPatches$013>>>0);
  $6 = $34 ? $maxPatches$013 : $$lcssa;
  $35 = (($_axisConstraintCount) + ($a$012<<2)|0);
  HEAP32[$35>>2] = $axisConstraintCount$0$lcssa;
  $36 = (($a$012) + 1)|0;
  $exitcond = ($36|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $a$012 = $36;$maxPatches$013 = $6;
  }
 }
 $5 = ($6|0)==(0);
 if ($5) {
  $totalContacts$0$lcssa = 0;$totalFriction$0$lcssa = 0;
 } else {
  $a1$03 = 0;$totalContacts$01 = 0;$totalFriction$02 = 0;
  while(1) {
   $37 = (($maxContactCount) + ($a1$03<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + ($totalContacts$01))|0;
   $40 = (($maxFrictionCount) + ($a1$03<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + ($totalFriction$02))|0;
   $43 = (($a1$03) + 1)|0;
   $44 = ($43>>>0)<($6>>>0);
   if ($44) {
    $a1$03 = $43;$totalContacts$01 = $39;$totalFriction$02 = $42;
   } else {
    $totalContacts$0$lcssa = $39;$totalFriction$0$lcssa = $42;
    break;
   }
  }
 }
 $45 = HEAP32[$descs>>2]|0;
 $46 = (($45) + 22|0);
 $47 = HEAP16[$46>>1]|0;
 $48 = (($descs) + 56|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 22|0);
 $51 = HEAP16[$50>>1]|0;
 $52 = $51 | $47;
 $53 = (($descs) + 112|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 22|0);
 $56 = HEAP16[$55>>1]|0;
 $57 = $52 | $56;
 $58 = (($descs) + 168|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 22|0);
 $61 = HEAP16[$60>>1]|0;
 $62 = $57 | $61;
 $63 = $62 & 64;
 $64 = ($63<<16>>16)==(0);
 $65 = ($6*144)|0;
 if ($64) {
  $66 = ($totalContacts$0$lcssa*176)|0;
  $67 = ($totalFriction$0$lcssa*240)|0;
  $68 = (($67) + ($66))|0;
  $74 = $68;
  $72 = $65 | 15;
  $73 = (($72) + ($74))|0;
  $75 = $73 & -16;
  HEAP32[$_solverConstraintByteSize>>2] = $75;
  STACKTOP = sp;return;
 } else {
  $69 = ($totalContacts$0$lcssa*272)|0;
  $70 = ($totalFriction$0$lcssa*336)|0;
  $71 = (($70) + ($69))|0;
  $74 = $71;
  $72 = $65 | 15;
  $73 = (($72) + ($74))|0;
  $75 = $73 & -16;
  HEAP32[$_solverConstraintByteSize>>2] = $75;
  STACKTOP = sp;return;
 }
}
function __ZN5physx22writeCompressedContactEPKNS_2Gu12ContactPointEjRNS_18PxcNpThreadContextERtRPhRjRPfjS6_PKNS_18PxsMaterialManagerEbbPNS_15PxsMaterialInfoEjbPS4_b($contactPoints,$numContactPoints,$threadContext,$writtenContactCount,$compressedContacts,$compressedContactSize,$contactForces,$contactForceByteSize,$statusFlag,$materialManager,$hasModifiableContacts,$forceNoResponse,$pMaterial,$additionalHeaderSize,$useConstraintData,$islandContext,$insertAveragePoint) {
 $contactPoints = $contactPoints|0;
 $numContactPoints = $numContactPoints|0;
 $threadContext = $threadContext|0;
 $writtenContactCount = $writtenContactCount|0;
 $compressedContacts = $compressedContacts|0;
 $compressedContactSize = $compressedContactSize|0;
 $contactForces = $contactForces|0;
 $contactForceByteSize = $contactForceByteSize|0;
 $statusFlag = $statusFlag|0;
 $materialManager = $materialManager|0;
 $hasModifiableContacts = $hasModifiableContacts|0;
 $forceNoResponse = $forceNoResponse|0;
 $pMaterial = $pMaterial|0;
 $additionalHeaderSize = $additionalHeaderSize|0;
 $useConstraintData = $useConstraintData|0;
 $islandContext = $islandContext|0;
 $insertAveragePoint = $insertAveragePoint|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$hasModifiableContacts = 0, $$lcssa = Math_fround(0), $$lcssa33 = Math_fround(0), $$lcssa34 = Math_fround(0), $$lcssa56 = Math_fround(0), $$lcssa57 = Math_fround(0), $$lcssa58 = Math_fround(0), $$lcssa86 = Math_fround(0), $$lcssa87 = Math_fround(0), $$lcssa88 = Math_fround(0), $$off0 = 0, $$pre = 0, $$pre$i = 0, $$pre$i16 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0;
 var $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $$totalContactPoints$0 = 0, $$totalContactPoints$015 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0;
 var $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0);
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0);
 var $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = Math_fround(0);
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0);
 var $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0);
 var $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = Math_fround(0), $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = 0, $360 = Math_fround(0);
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0;
 var $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = Math_fround(0);
 var $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0;
 var $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = 0;
 var $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0116 = 0, $a1$045 = 0, $a23$0114 = 0, $a8$078 = 0, $avgPen$0$lcssa = Math_fround(0), $avgPen$035 = Math_fround(0), $avgPen19$0$lcssa = Math_fround(0), $avgPen19$059 = Math_fround(0), $avgPen34$0$lcssa = Math_fround(0), $avgPen34$089 = Math_fround(0), $b$036 = 0, $b21$060 = 0, $b22$070 = 0, $b36$090 = 0, $b37$0100 = 0, $b6$041 = 0;
 var $combinedMat = 0, $combinedMat14 = 0, $combinedMat29 = 0, $combinedMat5 = 0, $combinedRestitution$048 = Math_fround(0), $combinedRestitution$1 = Math_fround(0), $combinedRestitution$277 = Math_fround(0), $combinedRestitution$3 = Math_fround(0), $combinedRestitution$4107 = Math_fround(0), $combinedRestitution$5 = Math_fround(0), $combiner = 0, $combiner13 = 0, $combiner28 = 0, $combiner4 = 0, $currPtr$084 = 0, $currPtr$1113 = 0, $dynamicFriction$049 = Math_fround(0), $dynamicFriction$1 = Math_fround(0), $dynamicFriction$279 = Math_fround(0), $dynamicFriction$3 = Math_fround(0);
 var $dynamicFriction$4108 = Math_fround(0), $dynamicFriction$5 = Math_fround(0), $exitcond = 0, $exitcond134 = 0, $exitcond135 = 0, $exitcond140 = 0, $exitcond144 = 0, $exitcond145 = 0, $exitcond150 = 0, $exitcond154 = 0, $exitcond155 = 0, $exitcond156 = 0, $flags$047 = 0, $flags$1 = 0, $flags$276 = 0, $flags$3 = 0, $flags$4106 = 0, $flags$5 = 0, $mat0$0121 = 0, $mat0$1 = 0;
 var $mat1$0120 = 0, $mat1$1 = 0, $not$forceNoResponse = 0, $numStrideHeaders$0$lcssa = 0, $numStrideHeaders$0122 = 0, $numStrideHeaders$1 = 0, $or$cond10 = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond13 = 0, $or$cond14 = 0, $origMatIndex0$052 = 0, $origMatIndex0$1 = 0, $origMatIndex0$282 = 0, $origMatIndex0$3 = 0, $origMatIndex0$4111 = 0, $origMatIndex0$5 = 0, $origMatIndex1$051 = 0, $origMatIndex1$1 = 0, $origMatIndex1$281 = 0;
 var $origMatIndex1$3 = 0, $origMatIndex1$4110 = 0, $origMatIndex1$5 = 0, $point$046 = 0, $point$2$lcssa = 0, $point$2$ph = 0, $point$240 = 0, $point17$1$lcssa = 0, $point17$1$ph$in = 0, $point17$169 = 0, $point32$1$lcssa = 0, $point32$1$ph$in = 0, $point32$199 = 0, $scevgep = 0, $scevgep142 = 0, $scevgep152 = 0, $startIndex$053 = 0, $startIndex$183 = 0, $startIndex$2112 = 0, $staticFriction$050 = Math_fround(0);
 var $staticFriction$1 = Math_fround(0), $staticFriction$280 = Math_fround(0), $staticFriction$3 = Math_fround(0), $staticFriction$4109 = Math_fround(0), $staticFriction$5 = Math_fround(0), $strHeader = 0, $strideStart$0$lcssa = 0, $strideStart$0118 = 0, $strideStart$1 = 0, $totalContactPoints$0$lcssa = 0, $totalContactPoints$0119 = 0, $totalContactPoints$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $strHeader = sp + 88|0;
 $0 = sp + 96|0;
 $combiner = sp + 80|0;
 $combinedMat = sp + 64|0;
 $combiner4 = sp + 56|0;
 $combinedMat5 = sp + 44|0;
 $combiner13 = sp + 24|0;
 $combinedMat14 = sp + 8|0;
 $combiner28 = sp;
 $combinedMat29 = sp + 32|0;
 $1 = ($numContactPoints|0)==(0);
 if ($1) {
  HEAP16[$writtenContactCount>>1] = 0;
  HEAP32[$compressedContacts>>2] = 0;
  HEAP32[$compressedContactSize>>2] = 0;
  HEAP32[$contactForces>>2] = 0;
  $2 = HEAP16[$statusFlag>>1]|0;
  $3 = $2&65535;
  $4 = $3 & 65519;
  $5 = $4&65535;
  HEAP16[$statusFlag>>1] = $5;
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $6 = $numContactPoints << 1;
 $7 = ($6>>>0)>(1024);
 $8 = (($strHeader) + 4|0);
 $9 = $7&1;
 HEAP8[$8>>0] = $9;
 if ($7) {
  $10 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($0,$6,504456,1205)|0);
  HEAP32[$strHeader>>2] = $10;
  $50 = $10;
 } else {
  $11 = STACKTOP; STACKTOP = STACKTOP + ((((1*$6)|0)+15)&-16)|0;;
  HEAP32[$strHeader>>2] = $11;
  $50 = $11;
 }
 $12 = (($contactPoints) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(-1);
 if ($14) {
  $15 = (($contactPoints) + 52|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)!=(-1);
  $$off0 = $17;
 } else {
  $$off0 = 1;
 }
 $not$forceNoResponse = $forceNoResponse ^ 1;
 $$hasModifiableContacts = $not$forceNoResponse & $hasModifiableContacts;
 $18 = (($contactPoints) + 4|0);
 $19 = (($contactPoints) + 8|0);
 $20 = (($pMaterial) + 2|0);
 $21 = ($numContactPoints>>>0)>(1);
 if ($21) {
  $22 = HEAP16[$20>>1]|0;
  $23 = HEAP16[$pMaterial>>1]|0;
  $24 = Math_fround(HEAPF32[$19>>2]);
  $25 = Math_fround(HEAPF32[$18>>2]);
  $26 = Math_fround(HEAPF32[$contactPoints>>2]);
  $30 = $26;$34 = $25;$39 = $24;$a$0116 = 1;$mat0$0121 = $23;$mat1$0120 = $22;$numStrideHeaders$0122 = 1;$strideStart$0118 = 0;$totalContactPoints$0119 = $numContactPoints;
  while(1) {
   $27 = (($contactPoints) + ($a$0116<<6)|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = Math_fround($30 * $28);
   $31 = ((($contactPoints) + ($a$0116<<6)|0) + 4|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = Math_fround($34 * $32);
   $35 = Math_fround($29 + $33);
   $36 = ((($contactPoints) + ($a$0116<<6)|0) + 8|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = Math_fround($39 * $37);
   $40 = Math_fround($35 + $38);
   $41 = $40 < Math_fround(0.999000012874603271484);
   $$pre = (($pMaterial) + ($a$0116<<2)|0);
   if ($41) {
    label = 13;
   } else {
    $42 = HEAP16[$$pre>>1]|0;
    $43 = ($42<<16>>16)==($mat0$0121<<16>>16);
    if ($43) {
     $44 = ((($pMaterial) + ($a$0116<<2)|0) + 2|0);
     $45 = HEAP16[$44>>1]|0;
     $46 = ($45<<16>>16)==($mat1$0120<<16>>16);
     if ($46) {
      $472 = $39;$473 = $34;$474 = $30;$mat0$1 = $mat0$0121;$mat1$1 = $mat1$0120;$numStrideHeaders$1 = $numStrideHeaders$0122;$strideStart$1 = $strideStart$0118;$totalContactPoints$1 = $totalContactPoints$0119;
     } else {
      label = 13;
     }
    } else {
     label = 13;
    }
   }
   if ((label|0) == 13) {
    label = 0;
    $47 = $a$0116&65535;
    $48 = (($numStrideHeaders$0122) + -1)|0;
    $49 = (($50) + ($48<<1)|0);
    HEAP16[$49>>1] = $47;
    $51 = HEAP16[$$pre>>1]|0;
    $52 = ((($pMaterial) + ($a$0116<<2)|0) + 2|0);
    $53 = HEAP16[$52>>1]|0;
    if ($insertAveragePoint) {
     $54 = (($a$0116) - ($strideStart$0118))|0;
     $55 = ($54>>>0)>(1);
     $56 = $55&1;
     $$totalContactPoints$0 = (($56) + ($totalContactPoints$0119))|0;
     $475 = $$totalContactPoints$0;
    } else {
     $475 = $totalContactPoints$0119;
    }
    $57 = (($numStrideHeaders$0122) + 1)|0;
    $472 = $37;$473 = $32;$474 = $28;$mat0$1 = $51;$mat1$1 = $53;$numStrideHeaders$1 = $57;$strideStart$1 = $a$0116;$totalContactPoints$1 = $475;
   }
   $58 = (($a$0116) + 1)|0;
   $exitcond156 = ($58|0)==($numContactPoints|0);
   if ($exitcond156) {
    $numStrideHeaders$0$lcssa = $numStrideHeaders$1;$strideStart$0$lcssa = $strideStart$1;$totalContactPoints$0$lcssa = $totalContactPoints$1;
    break;
   } else {
    $30 = $474;$34 = $473;$39 = $472;$a$0116 = $58;$mat0$0121 = $mat0$1;$mat1$0120 = $mat1$1;$numStrideHeaders$0122 = $numStrideHeaders$1;$strideStart$0118 = $strideStart$1;$totalContactPoints$0119 = $totalContactPoints$1;
   }
  }
 } else {
  $numStrideHeaders$0$lcssa = 1;$strideStart$0$lcssa = 0;$totalContactPoints$0$lcssa = $numContactPoints;
 }
 if ($insertAveragePoint) {
  $59 = (($numContactPoints) - ($strideStart$0$lcssa))|0;
  $60 = ($59>>>0)>(1);
  $61 = $60&1;
  $$totalContactPoints$015 = (($61) + ($totalContactPoints$0$lcssa))|0;
  $62 = ($contactForceByteSize|0)==(0);
  if ($62) {
   $73 = $$totalContactPoints$015;$81 = 0;
  } else {
   $63 = (($$totalContactPoints$015) - ($numContactPoints))|0;
   $64 = $63 << 2;
   $65 = (($64) + ($contactForceByteSize))|0;
   $73 = $$totalContactPoints$015;$81 = $65;
  }
 } else {
  $73 = $totalContactPoints$0$lcssa;$81 = $contactForceByteSize;
 }
 $66 = $numContactPoints&65535;
 $67 = (($numStrideHeaders$0$lcssa) + -1)|0;
 $68 = (($50) + ($67<<1)|0);
 HEAP16[$68>>1] = $66;
 $69 = $numStrideHeaders$0$lcssa << 5;
 $$ = $$hasModifiableContacts ? 4 : $69;
 if ($$hasModifiableContacts) {
  $72 = 72;
 } else {
  $70 = $$off0 ? 24 : 16;
  $72 = $70;
 }
 $71 = Math_imul($72, $73)|0;
 $74 = $$hasModifiableContacts ? 20 : 4;
 $75 = (($74) + ($additionalHeaderSize))|0;
 $76 = (($75) + ($$))|0;
 $77 = (($76) + ($71))|0;
 $78 = (($77) + 15)|0;
 $79 = $78 & -16;
 $80 = (($79) + ($81))|0;
 do {
  if ($useConstraintData) {
   $82 = (($threadContext) + 316|0);
   $83 = (($80) + 15)|0;
   $84 = $83 & -16;
   $85 = ($84>>>0)>(16384);
   if ($85) {
    $86 = HEAP32[$82>>2]|0;
    $87 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($86,$84)|0);
    $113 = $87;
    break;
   }
   $88 = (($threadContext) + 320|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)==(0|0);
   $$pre$i16 = (($threadContext) + 324|0);
   if (!($90)) {
    $91 = HEAP32[$$pre$i16>>2]|0;
    $92 = (($91) + ($84))|0;
    $93 = ($92>>>0)>(16384);
    if (!($93)) {
     $97 = (($89) + ($91)|0);
     HEAP32[$$pre$i16>>2] = $92;
     $113 = $97;
     break;
    }
   }
   $94 = HEAP32[$82>>2]|0;
   $95 = (($islandContext) + 300|0);
   $96 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($94,$95)|0);
   HEAP32[$88>>2] = $96;
   HEAP32[$$pre$i16>>2] = $84;
   $113 = $96;
  } else {
   $98 = (($threadContext) + 332|0);
   $99 = (($80) + 15)|0;
   $100 = $99 & -16;
   $101 = ($100>>>0)>(16384);
   if ($101) {
    $102 = HEAP32[$98>>2]|0;
    $103 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($102,$100)|0);
    $113 = $103;
    break;
   }
   $104 = (($threadContext) + 336|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ($105|0)==(0|0);
   $$pre$i = (($threadContext) + 340|0);
   if (!($106)) {
    $107 = HEAP32[$$pre$i>>2]|0;
    $108 = (($107) + ($100))|0;
    $109 = ($108>>>0)>(16384);
    if (!($109)) {
     $112 = (($105) + ($107)|0);
     HEAP32[$$pre$i>>2] = $108;
     $113 = $112;
     break;
    }
   }
   $110 = HEAP32[$98>>2]|0;
   $111 = (__ZN5physx17PxcNpMemBlockPool19acquireContactBlockEv($110)|0);
   HEAP32[$104>>2] = $111;
   HEAP32[$$pre$i>>2] = $100;
   $113 = $111;
  }
 } while(0);
 HEAP32[$compressedContacts>>2] = $113;
 $114 = (($113) + 128|0);
 $115 = ($113|0)==(0|0);
 if ($115) {
  HEAP16[$writtenContactCount>>1] = 0;
  HEAP32[$compressedContacts>>2] = 0;
  HEAP32[$compressedContactSize>>2] = 0;
  HEAP32[$contactForces>>2] = 0;
  $116 = HEAP16[$statusFlag>>1]|0;
  $117 = $116&65535;
  $118 = $117 & 65519;
  $119 = $118&65535;
  HEAP16[$statusFlag>>1] = $119;
  $$0 = 0;
 } else {
  $120 = (($threadContext) + 8772|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = (($121) + ($77))|0;
  HEAP32[$120>>2] = $122;
  HEAP32[$compressedContactSize>>2] = $77;
  $123 = HEAP16[$pMaterial>>1]|0;
  $124 = HEAP16[$20>>1]|0;
  $125 = $123&65535;
  $126 = HEAP32[$materialManager>>2]|0;
  $127 = (($126) + ($125<<5)|0);
  $128 = $124&65535;
  $129 = (($126) + ($128<<5)|0);
  $130 = (Math_fround(__ZN5physx19PxsMaterialCombiner18combineRestitutionERKNS_15PxsMaterialDataES3_($127,$129)));
  __ZN5physx19PxsMaterialCombinerC2Eff($combiner,Math_fround(1.0),Math_fround(1.0));
  __ZN5physx19PxsMaterialCombiner24combineIsotropicFrictionERKNS_15PxsMaterialDataES3_($combinedMat,$combiner,$127,$129);
  $131 = Math_fround(HEAPF32[$combinedMat>>2]);
  $132 = (($combinedMat) + 4|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = (($combinedMat) + 8|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = (($113) + ($additionalHeaderSize)|0);
  $137 = $$off0&1;
  $138 = $$hasModifiableContacts ? 2 : 0;
  $139 = $forceNoResponse ? 4 : 0;
  $140 = $138 | $139;
  $141 = $140 | $137;
  $142 = $141&65535;
  $$sum2 = (($additionalHeaderSize) + 2)|0;
  $143 = (($113) + ($$sum2)|0);
  HEAP16[$143>>1] = $142;
  $144 = $73&65535;
  HEAP16[$136>>1] = $144;
  $$sum3 = (($additionalHeaderSize) + 4)|0;
  $145 = (($113) + ($$sum3)|0);
  do {
   if ($$hasModifiableContacts) {
    HEAPF32[$145>>2] = Math_fround(1.0);
    $$sum4 = (($additionalHeaderSize) + 8)|0;
    $146 = (($113) + ($$sum4)|0);
    HEAPF32[$146>>2] = Math_fround(1.0);
    $$sum5 = (($additionalHeaderSize) + 12)|0;
    $147 = (($113) + ($$sum5)|0);
    HEAPF32[$147>>2] = Math_fround(1.0);
    $$sum6 = (($additionalHeaderSize) + 16)|0;
    $148 = (($113) + ($$sum6)|0);
    HEAPF32[$148>>2] = Math_fround(1.0);
    $$sum = (($additionalHeaderSize) + 152)|0;
    $149 = (($113) + ($$sum)|0);
    $150 = ($numStrideHeaders$0$lcssa|0)==(0);
    if (!($150)) {
     $$sum8 = (($additionalHeaderSize) + 24)|0;
     $151 = (($113) + ($$sum8)|0);
     $$sum7 = (($additionalHeaderSize) + 20)|0;
     $152 = (($113) + ($$sum7)|0);
     $$sum9 = (($additionalHeaderSize) + 22)|0;
     $153 = (($113) + ($$sum9)|0);
     $154 = (($contactPoints) + 52|0);
     $155 = (($combinedMat5) + 4|0);
     $156 = (($combinedMat5) + 8|0);
     $a1$045 = 0;$combinedRestitution$048 = $130;$dynamicFriction$049 = $133;$flags$047 = $135;$origMatIndex0$052 = $123;$origMatIndex1$051 = $124;$point$046 = $151;$startIndex$053 = 0;$staticFriction$050 = $131;
     while(1) {
      $157 = (($pMaterial) + ($startIndex$053<<2)|0);
      $158 = HEAP16[$157>>1]|0;
      $159 = ((($pMaterial) + ($startIndex$053<<2)|0) + 2|0);
      $160 = HEAP16[$159>>1]|0;
      $161 = ($158<<16>>16)==($origMatIndex0$052<<16>>16);
      $162 = ($160<<16>>16)==($origMatIndex1$051<<16>>16);
      $or$cond10 = $161 & $162;
      if ($or$cond10) {
       $combinedRestitution$1 = $combinedRestitution$048;$dynamicFriction$1 = $dynamicFriction$049;$flags$1 = $flags$047;$origMatIndex0$1 = $origMatIndex0$052;$origMatIndex1$1 = $origMatIndex1$051;$staticFriction$1 = $staticFriction$050;
      } else {
       $163 = $158&65535;
       $164 = HEAP32[$materialManager>>2]|0;
       $165 = (($164) + ($163<<5)|0);
       $166 = $160&65535;
       $167 = (($164) + ($166<<5)|0);
       $168 = (Math_fround(__ZN5physx19PxsMaterialCombiner18combineRestitutionERKNS_15PxsMaterialDataES3_($165,$167)));
       __ZN5physx19PxsMaterialCombinerC2Eff($combiner4,Math_fround(1.0),Math_fround(1.0));
       __ZN5physx19PxsMaterialCombiner24combineIsotropicFrictionERKNS_15PxsMaterialDataES3_($combinedMat5,$combiner4,$165,$167);
       $169 = Math_fround(HEAPF32[$combinedMat5>>2]);
       $170 = Math_fround(HEAPF32[$155>>2]);
       $171 = HEAP32[$156>>2]|0;
       $combinedRestitution$1 = $168;$dynamicFriction$1 = $170;$flags$1 = $171;$origMatIndex0$1 = $158;$origMatIndex1$1 = $160;$staticFriction$1 = $169;
      }
      HEAP16[$152>>1] = $144;
      $172 = $flags$1&65535;
      HEAP16[$153>>1] = $172;
      $173 = (($50) + ($a1$045<<1)|0);
      $174 = HEAP16[$173>>1]|0;
      $175 = $174&65535;
      if ($insertAveragePoint) {
       $176 = (($175) - ($startIndex$053))|0;
       $177 = ($176>>>0)>(1);
       if ($177) {
        $178 = (Math_fround(($176>>>0)));
        $179 = Math_fround(Math_fround(1.0) / $178);
        $180 = ($startIndex$053>>>0)<($175>>>0);
        if ($180) {
         $184 = Math_fround(0.0);$188 = Math_fround(0.0);$192 = Math_fround(0.0);$avgPen$035 = Math_fround(0.0);$b$036 = $startIndex$053;
         while(1) {
          $181 = ((($contactPoints) + ($b$036<<6)|0) + 16|0);
          $182 = Math_fround(HEAPF32[$181>>2]);
          $183 = Math_fround($184 + $182);
          $185 = ((($contactPoints) + ($b$036<<6)|0) + 20|0);
          $186 = Math_fround(HEAPF32[$185>>2]);
          $187 = Math_fround($188 + $186);
          $189 = ((($contactPoints) + ($b$036<<6)|0) + 24|0);
          $190 = Math_fround(HEAPF32[$189>>2]);
          $191 = Math_fround($192 + $190);
          $193 = ((($contactPoints) + ($b$036<<6)|0) + 12|0);
          $194 = Math_fround(HEAPF32[$193>>2]);
          $195 = Math_fround($avgPen$035 + $194);
          $196 = (($b$036) + 1)|0;
          $exitcond = ($196|0)==($175|0);
          if ($exitcond) {
           $$lcssa = $191;$$lcssa33 = $187;$$lcssa34 = $183;$avgPen$0$lcssa = $195;
           break;
          } else {
           $184 = $183;$188 = $187;$192 = $191;$avgPen$035 = $195;$b$036 = $196;
          }
         }
        } else {
         $$lcssa = Math_fround(0.0);$$lcssa33 = Math_fround(0.0);$$lcssa34 = Math_fround(0.0);$avgPen$0$lcssa = Math_fround(0.0);
        }
        $197 = Math_fround($179 * $$lcssa34);
        $198 = Math_fround($179 * $$lcssa33);
        $199 = Math_fround($179 * $$lcssa);
        HEAPF32[$point$046>>2] = $197;
        $200 = (($point$046) + 4|0);
        HEAPF32[$200>>2] = $198;
        $201 = (($point$046) + 8|0);
        HEAPF32[$201>>2] = $199;
        $202 = Math_fround($179 * $avgPen$0$lcssa);
        $203 = (($point$046) + 12|0);
        HEAPF32[$203>>2] = $202;
        $204 = HEAP32[$12>>2]|0;
        $205 = (($point$046) + 16|0);
        HEAP32[$205>>2] = $204;
        $206 = HEAP32[$154>>2]|0;
        $207 = (($point$046) + 20|0);
        HEAP32[$207>>2] = $206;
        $208 = Math_fround(HEAPF32[$contactPoints>>2]);
        $209 = (($point$046) + 24|0);
        HEAPF32[$209>>2] = $208;
        $210 = Math_fround(HEAPF32[$18>>2]);
        $211 = (($point$046) + 28|0);
        HEAPF32[$211>>2] = $210;
        $212 = Math_fround(HEAPF32[$19>>2]);
        $213 = (($point$046) + 32|0);
        HEAPF32[$213>>2] = $212;
        $214 = (($point$046) + 48|0);
        HEAPF32[$214>>2] = Math_fround(3.40282346638528859812E+38);
        $215 = (($point$046) + 36|0);
        HEAPF32[$215>>2] = Math_fround(0.0);
        $216 = (($point$046) + 40|0);
        HEAPF32[$216>>2] = Math_fround(0.0);
        $217 = (($point$046) + 44|0);
        HEAPF32[$217>>2] = Math_fround(0.0);
        $218 = (($point$046) + 52|0);
        HEAPF32[$218>>2] = $staticFriction$1;
        $219 = (($point$046) + 56|0);
        HEAPF32[$219>>2] = $dynamicFriction$1;
        $220 = (($point$046) + 60|0);
        HEAPF32[$220>>2] = $combinedRestitution$1;
        $221 = (($point$046) + 68|0);
        HEAP32[$221>>2] = $flags$1;
        $222 = (($point$046) + 64|0);
        HEAP16[$222>>1] = $158;
        $223 = (($point$046) + 66|0);
        HEAP16[$223>>1] = $160;
        $224 = (($point$046) + 72|0);
        $225 = (($point$046) + 200|0);
        $point$2$ph = $224;
       } else {
        $point$2$ph = $point$046;
       }
      } else {
       $point$2$ph = $point$046;
      }
      $226 = ($startIndex$053>>>0)<($175>>>0);
      if ($226) {
       $227 = (($175) - ($startIndex$053))|0;
       $b6$041 = $startIndex$053;$point$240 = $point$2$ph;
       while(1) {
        $228 = ((($contactPoints) + ($b6$041<<6)|0) + 16|0);
        $229 = Math_fround(HEAPF32[$228>>2]);
        HEAPF32[$point$240>>2] = $229;
        $230 = ((($contactPoints) + ($b6$041<<6)|0) + 20|0);
        $231 = Math_fround(HEAPF32[$230>>2]);
        $232 = (($point$240) + 4|0);
        HEAPF32[$232>>2] = $231;
        $233 = ((($contactPoints) + ($b6$041<<6)|0) + 24|0);
        $234 = Math_fround(HEAPF32[$233>>2]);
        $235 = (($point$240) + 8|0);
        HEAPF32[$235>>2] = $234;
        $236 = ((($contactPoints) + ($b6$041<<6)|0) + 12|0);
        $237 = Math_fround(HEAPF32[$236>>2]);
        $238 = (($point$240) + 12|0);
        HEAPF32[$238>>2] = $237;
        $239 = ((($contactPoints) + ($b6$041<<6)|0) + 48|0);
        $240 = HEAP32[$239>>2]|0;
        $241 = (($point$240) + 16|0);
        HEAP32[$241>>2] = $240;
        $242 = ((($contactPoints) + ($b6$041<<6)|0) + 52|0);
        $243 = HEAP32[$242>>2]|0;
        $244 = (($point$240) + 20|0);
        HEAP32[$244>>2] = $243;
        $245 = (($contactPoints) + ($b6$041<<6)|0);
        $246 = Math_fround(HEAPF32[$245>>2]);
        $247 = (($point$240) + 24|0);
        HEAPF32[$247>>2] = $246;
        $248 = ((($contactPoints) + ($b6$041<<6)|0) + 4|0);
        $249 = Math_fround(HEAPF32[$248>>2]);
        $250 = (($point$240) + 28|0);
        HEAPF32[$250>>2] = $249;
        $251 = ((($contactPoints) + ($b6$041<<6)|0) + 8|0);
        $252 = Math_fround(HEAPF32[$251>>2]);
        $253 = (($point$240) + 32|0);
        HEAPF32[$253>>2] = $252;
        $254 = (($point$240) + 48|0);
        HEAPF32[$254>>2] = Math_fround(3.40282346638528859812E+38);
        $255 = (($point$240) + 36|0);
        HEAPF32[$255>>2] = Math_fround(0.0);
        $256 = (($point$240) + 40|0);
        HEAPF32[$256>>2] = Math_fround(0.0);
        $257 = (($point$240) + 44|0);
        HEAPF32[$257>>2] = Math_fround(0.0);
        $258 = (($point$240) + 52|0);
        HEAPF32[$258>>2] = $staticFriction$1;
        $259 = (($point$240) + 56|0);
        HEAPF32[$259>>2] = $dynamicFriction$1;
        $260 = (($point$240) + 60|0);
        HEAPF32[$260>>2] = $combinedRestitution$1;
        $261 = (($point$240) + 68|0);
        HEAP32[$261>>2] = $flags$1;
        $262 = (($point$240) + 64|0);
        HEAP16[$262>>1] = $158;
        $263 = (($point$240) + 66|0);
        HEAP16[$263>>1] = $160;
        $264 = (($point$240) + 72|0);
        $265 = (($point$240) + 200|0);
        $266 = (($b6$041) + 1)|0;
        $exitcond134 = ($266|0)==($175|0);
        if ($exitcond134) {
         break;
        } else {
         $b6$041 = $266;$point$240 = $264;
        }
       }
       $scevgep = (($point$2$ph) + (($227*72)|0)|0);
       $point$2$lcssa = $scevgep;
      } else {
       $point$2$lcssa = $point$2$ph;
      }
      $267 = HEAP16[$173>>1]|0;
      $268 = $267&65535;
      $269 = (($a1$045) + 1)|0;
      $exitcond135 = ($269|0)==($numStrideHeaders$0$lcssa|0);
      if ($exitcond135) {
       break;
      } else {
       $a1$045 = $269;$combinedRestitution$048 = $combinedRestitution$1;$dynamicFriction$049 = $dynamicFriction$1;$flags$047 = $flags$1;$origMatIndex0$052 = $origMatIndex0$1;$origMatIndex1$051 = $origMatIndex1$1;$point$046 = $point$2$lcssa;$startIndex$053 = $268;$staticFriction$050 = $staticFriction$1;
      }
     }
    }
   } else {
    $270 = ($numStrideHeaders$0$lcssa|0)==(0);
    if ($$off0) {
     if ($270) {
      break;
     }
     $273 = (($contactPoints) + 52|0);
     $274 = (($combinedMat14) + 4|0);
     $275 = (($combinedMat14) + 8|0);
     $a8$078 = 0;$combinedRestitution$277 = $130;$currPtr$084 = $145;$dynamicFriction$279 = $133;$flags$276 = $135;$origMatIndex0$282 = $123;$origMatIndex1$281 = $124;$startIndex$183 = 0;$staticFriction$280 = $131;
     while(1) {
      $276 = (($pMaterial) + ($startIndex$183<<2)|0);
      $277 = HEAP16[$276>>1]|0;
      $278 = ((($pMaterial) + ($startIndex$183<<2)|0) + 2|0);
      $279 = HEAP16[$278>>1]|0;
      $280 = ($277<<16>>16)==($origMatIndex0$282<<16>>16);
      $281 = ($279<<16>>16)==($origMatIndex1$281<<16>>16);
      $or$cond11 = $280 & $281;
      if ($or$cond11) {
       $combinedRestitution$3 = $combinedRestitution$277;$dynamicFriction$3 = $dynamicFriction$279;$flags$3 = $flags$276;$origMatIndex0$3 = $origMatIndex0$282;$origMatIndex1$3 = $origMatIndex1$281;$staticFriction$3 = $staticFriction$280;
      } else {
       $282 = $277&65535;
       $283 = HEAP32[$materialManager>>2]|0;
       $284 = (($283) + ($282<<5)|0);
       $285 = $279&65535;
       $286 = (($283) + ($285<<5)|0);
       $287 = (Math_fround(__ZN5physx19PxsMaterialCombiner18combineRestitutionERKNS_15PxsMaterialDataES3_($284,$286)));
       __ZN5physx19PxsMaterialCombinerC2Eff($combiner13,Math_fround(1.0),Math_fround(1.0));
       __ZN5physx19PxsMaterialCombiner24combineIsotropicFrictionERKNS_15PxsMaterialDataES3_($combinedMat14,$combiner13,$284,$286);
       $288 = Math_fround(HEAPF32[$combinedMat14>>2]);
       $289 = Math_fround(HEAPF32[$274>>2]);
       $290 = HEAP32[$275>>2]|0;
       $combinedRestitution$3 = $287;$dynamicFriction$3 = $289;$flags$3 = $290;$origMatIndex0$3 = $277;$origMatIndex1$3 = $279;$staticFriction$3 = $288;
      }
      $291 = (($currPtr$084) + 32|0);
      $292 = (($currPtr$084) + 160|0);
      $293 = (($50) + ($a8$078<<1)|0);
      $294 = HEAP16[$293>>1]|0;
      $295 = $294&65535;
      $296 = (($currPtr$084) + 4|0);
      $297 = (($contactPoints) + ($startIndex$183<<6)|0);
      $298 = Math_fround(HEAPF32[$297>>2]);
      HEAPF32[$296>>2] = $298;
      $299 = ((($contactPoints) + ($startIndex$183<<6)|0) + 4|0);
      $300 = Math_fround(HEAPF32[$299>>2]);
      $301 = (($currPtr$084) + 8|0);
      HEAPF32[$301>>2] = $300;
      $302 = ((($contactPoints) + ($startIndex$183<<6)|0) + 8|0);
      $303 = Math_fround(HEAPF32[$302>>2]);
      $304 = (($currPtr$084) + 12|0);
      HEAPF32[$304>>2] = $303;
      $305 = (($295) - ($startIndex$183))|0;
      $306 = $305&65535;
      HEAP16[$currPtr$084>>1] = $306;
      $307 = (($currPtr$084) + 16|0);
      HEAPF32[$307>>2] = $staticFriction$3;
      $308 = (($currPtr$084) + 20|0);
      HEAPF32[$308>>2] = $dynamicFriction$3;
      $309 = (($currPtr$084) + 24|0);
      HEAPF32[$309>>2] = $combinedRestitution$3;
      $310 = $flags$3&65535;
      $311 = (($currPtr$084) + 2|0);
      HEAP16[$311>>1] = $310;
      $312 = (($currPtr$084) + 28|0);
      HEAP16[$312>>1] = $277;
      $313 = (($currPtr$084) + 30|0);
      HEAP16[$313>>1] = $279;
      $314 = ($305>>>0)>(1);
      $or$cond12 = $314 & $insertAveragePoint;
      if ($or$cond12) {
       $315 = (($306) + 1)<<16>>16;
       HEAP16[$currPtr$084>>1] = $315;
       $316 = (Math_fround(($305>>>0)));
       $317 = Math_fround(Math_fround(1.0) / $316);
       $318 = ($startIndex$183>>>0)<($295>>>0);
       if ($318) {
        $322 = Math_fround(0.0);$326 = Math_fround(0.0);$330 = Math_fround(0.0);$avgPen19$059 = Math_fround(0.0);$b21$060 = $startIndex$183;
        while(1) {
         $319 = ((($contactPoints) + ($b21$060<<6)|0) + 16|0);
         $320 = Math_fround(HEAPF32[$319>>2]);
         $321 = Math_fround($322 + $320);
         $323 = ((($contactPoints) + ($b21$060<<6)|0) + 20|0);
         $324 = Math_fround(HEAPF32[$323>>2]);
         $325 = Math_fround($326 + $324);
         $327 = ((($contactPoints) + ($b21$060<<6)|0) + 24|0);
         $328 = Math_fround(HEAPF32[$327>>2]);
         $329 = Math_fround($330 + $328);
         $331 = ((($contactPoints) + ($b21$060<<6)|0) + 12|0);
         $332 = Math_fround(HEAPF32[$331>>2]);
         $333 = Math_fround($avgPen19$059 + $332);
         $334 = (($b21$060) + 1)|0;
         $exitcond140 = ($334|0)==($295|0);
         if ($exitcond140) {
          $$lcssa56 = $329;$$lcssa57 = $325;$$lcssa58 = $321;$avgPen19$0$lcssa = $333;
          break;
         } else {
          $322 = $321;$326 = $325;$330 = $329;$avgPen19$059 = $333;$b21$060 = $334;
         }
        }
       } else {
        $$lcssa56 = Math_fround(0.0);$$lcssa57 = Math_fround(0.0);$$lcssa58 = Math_fround(0.0);$avgPen19$0$lcssa = Math_fround(0.0);
       }
       $335 = Math_fround($317 * $$lcssa58);
       $336 = Math_fround($317 * $$lcssa57);
       $337 = Math_fround($317 * $$lcssa56);
       HEAPF32[$291>>2] = $335;
       $338 = (($currPtr$084) + 36|0);
       HEAPF32[$338>>2] = $336;
       $339 = (($currPtr$084) + 40|0);
       HEAPF32[$339>>2] = $337;
       $340 = Math_fround($317 * $avgPen19$0$lcssa);
       $341 = (($currPtr$084) + 44|0);
       HEAPF32[$341>>2] = $340;
       $342 = HEAP32[$12>>2]|0;
       $343 = (($currPtr$084) + 48|0);
       HEAP32[$343>>2] = $342;
       $344 = HEAP32[$273>>2]|0;
       $345 = (($currPtr$084) + 52|0);
       HEAP32[$345>>2] = $344;
       $346 = (($currPtr$084) + 56|0);
       $347 = (($currPtr$084) + 184|0);
       $point17$1$ph$in = $346;
      } else {
       $point17$1$ph$in = $291;
      }
      $348 = ($startIndex$183>>>0)<($295>>>0);
      if ($348) {
       $349 = (($295) - ($startIndex$183))|0;
       $350 = ($349*24)|0;
       $scevgep142 = (($point17$1$ph$in) + ($350)|0);
       $b22$070 = $startIndex$183;$point17$169 = $point17$1$ph$in;
       while(1) {
        $351 = ((($contactPoints) + ($b22$070<<6)|0) + 16|0);
        $352 = Math_fround(HEAPF32[$351>>2]);
        HEAPF32[$point17$169>>2] = $352;
        $353 = ((($contactPoints) + ($b22$070<<6)|0) + 20|0);
        $354 = Math_fround(HEAPF32[$353>>2]);
        $355 = (($point17$169) + 4|0);
        HEAPF32[$355>>2] = $354;
        $356 = ((($contactPoints) + ($b22$070<<6)|0) + 24|0);
        $357 = Math_fround(HEAPF32[$356>>2]);
        $358 = (($point17$169) + 8|0);
        HEAPF32[$358>>2] = $357;
        $359 = ((($contactPoints) + ($b22$070<<6)|0) + 12|0);
        $360 = Math_fround(HEAPF32[$359>>2]);
        $361 = (($point17$169) + 12|0);
        HEAPF32[$361>>2] = $360;
        $362 = ((($contactPoints) + ($b22$070<<6)|0) + 48|0);
        $363 = HEAP32[$362>>2]|0;
        $364 = (($point17$169) + 16|0);
        HEAP32[$364>>2] = $363;
        $365 = ((($contactPoints) + ($b22$070<<6)|0) + 52|0);
        $366 = HEAP32[$365>>2]|0;
        $367 = (($point17$169) + 20|0);
        HEAP32[$367>>2] = $366;
        $368 = (($point17$169) + 24|0);
        $369 = (($point17$169) + 152|0);
        $370 = (($b22$070) + 1)|0;
        $exitcond144 = ($370|0)==($295|0);
        if ($exitcond144) {
         break;
        } else {
         $b22$070 = $370;$point17$169 = $368;
        }
       }
       $point17$1$lcssa = $scevgep142;
      } else {
       $point17$1$lcssa = $point17$1$ph$in;
      }
      $371 = HEAP16[$293>>1]|0;
      $372 = $371&65535;
      $373 = (($a8$078) + 1)|0;
      $exitcond145 = ($373|0)==($numStrideHeaders$0$lcssa|0);
      if ($exitcond145) {
       break;
      } else {
       $a8$078 = $373;$combinedRestitution$277 = $combinedRestitution$3;$currPtr$084 = $point17$1$lcssa;$dynamicFriction$279 = $dynamicFriction$3;$flags$276 = $flags$3;$origMatIndex0$282 = $origMatIndex0$3;$origMatIndex1$281 = $origMatIndex1$3;$startIndex$183 = $372;$staticFriction$280 = $staticFriction$3;
      }
     }
    } else {
     if ($270) {
      break;
     }
     $271 = (($combinedMat29) + 4|0);
     $272 = (($combinedMat29) + 8|0);
     $a23$0114 = 0;$combinedRestitution$4107 = $130;$currPtr$1113 = $145;$dynamicFriction$4108 = $133;$flags$4106 = $135;$origMatIndex0$4111 = $123;$origMatIndex1$4110 = $124;$startIndex$2112 = 0;$staticFriction$4109 = $131;
     while(1) {
      $374 = (($pMaterial) + ($startIndex$2112<<2)|0);
      $375 = HEAP16[$374>>1]|0;
      $376 = ((($pMaterial) + ($startIndex$2112<<2)|0) + 2|0);
      $377 = HEAP16[$376>>1]|0;
      $378 = ($375<<16>>16)==($origMatIndex0$4111<<16>>16);
      $379 = ($377<<16>>16)==($origMatIndex1$4110<<16>>16);
      $or$cond13 = $378 & $379;
      if ($or$cond13) {
       $combinedRestitution$5 = $combinedRestitution$4107;$dynamicFriction$5 = $dynamicFriction$4108;$flags$5 = $flags$4106;$origMatIndex0$5 = $origMatIndex0$4111;$origMatIndex1$5 = $origMatIndex1$4110;$staticFriction$5 = $staticFriction$4109;
      } else {
       $380 = $375&65535;
       $381 = HEAP32[$materialManager>>2]|0;
       $382 = (($381) + ($380<<5)|0);
       $383 = $377&65535;
       $384 = (($381) + ($383<<5)|0);
       $385 = (Math_fround(__ZN5physx19PxsMaterialCombiner18combineRestitutionERKNS_15PxsMaterialDataES3_($382,$384)));
       __ZN5physx19PxsMaterialCombinerC2Eff($combiner28,Math_fround(1.0),Math_fround(1.0));
       __ZN5physx19PxsMaterialCombiner24combineIsotropicFrictionERKNS_15PxsMaterialDataES3_($combinedMat29,$combiner28,$382,$384);
       $386 = Math_fround(HEAPF32[$combinedMat29>>2]);
       $387 = Math_fround(HEAPF32[$271>>2]);
       $388 = HEAP32[$272>>2]|0;
       $combinedRestitution$5 = $385;$dynamicFriction$5 = $387;$flags$5 = $388;$origMatIndex0$5 = $375;$origMatIndex1$5 = $377;$staticFriction$5 = $386;
      }
      $389 = (($currPtr$1113) + 32|0);
      $390 = (($currPtr$1113) + 160|0);
      $391 = (($50) + ($a23$0114<<1)|0);
      $392 = HEAP16[$391>>1]|0;
      $393 = $392&65535;
      $394 = (($currPtr$1113) + 4|0);
      $395 = (($contactPoints) + ($startIndex$2112<<6)|0);
      $396 = Math_fround(HEAPF32[$395>>2]);
      HEAPF32[$394>>2] = $396;
      $397 = ((($contactPoints) + ($startIndex$2112<<6)|0) + 4|0);
      $398 = Math_fround(HEAPF32[$397>>2]);
      $399 = (($currPtr$1113) + 8|0);
      HEAPF32[$399>>2] = $398;
      $400 = ((($contactPoints) + ($startIndex$2112<<6)|0) + 8|0);
      $401 = Math_fround(HEAPF32[$400>>2]);
      $402 = (($currPtr$1113) + 12|0);
      HEAPF32[$402>>2] = $401;
      $403 = (($393) - ($startIndex$2112))|0;
      $404 = $403&65535;
      HEAP16[$currPtr$1113>>1] = $404;
      $405 = (($currPtr$1113) + 16|0);
      HEAPF32[$405>>2] = $staticFriction$5;
      $406 = (($currPtr$1113) + 20|0);
      HEAPF32[$406>>2] = $dynamicFriction$5;
      $407 = (($currPtr$1113) + 24|0);
      HEAPF32[$407>>2] = $combinedRestitution$5;
      $408 = (($currPtr$1113) + 28|0);
      HEAP16[$408>>1] = $375;
      $409 = (($currPtr$1113) + 30|0);
      HEAP16[$409>>1] = $377;
      $410 = $flags$5&65535;
      $411 = (($currPtr$1113) + 2|0);
      HEAP16[$411>>1] = $410;
      $412 = ($403>>>0)>(1);
      $or$cond14 = $412 & $insertAveragePoint;
      if ($or$cond14) {
       $413 = (($404) + 1)<<16>>16;
       HEAP16[$currPtr$1113>>1] = $413;
       $414 = (Math_fround(($403>>>0)));
       $415 = Math_fround(Math_fround(1.0) / $414);
       $416 = ($startIndex$2112>>>0)<($393>>>0);
       if ($416) {
        $420 = Math_fround(0.0);$424 = Math_fround(0.0);$428 = Math_fround(0.0);$avgPen34$089 = Math_fround(0.0);$b36$090 = $startIndex$2112;
        while(1) {
         $417 = ((($contactPoints) + ($b36$090<<6)|0) + 16|0);
         $418 = Math_fround(HEAPF32[$417>>2]);
         $419 = Math_fround($420 + $418);
         $421 = ((($contactPoints) + ($b36$090<<6)|0) + 20|0);
         $422 = Math_fround(HEAPF32[$421>>2]);
         $423 = Math_fround($424 + $422);
         $425 = ((($contactPoints) + ($b36$090<<6)|0) + 24|0);
         $426 = Math_fround(HEAPF32[$425>>2]);
         $427 = Math_fround($428 + $426);
         $429 = ((($contactPoints) + ($b36$090<<6)|0) + 12|0);
         $430 = Math_fround(HEAPF32[$429>>2]);
         $431 = Math_fround($avgPen34$089 + $430);
         $432 = (($b36$090) + 1)|0;
         $exitcond150 = ($432|0)==($393|0);
         if ($exitcond150) {
          $$lcssa86 = $427;$$lcssa87 = $423;$$lcssa88 = $419;$avgPen34$0$lcssa = $431;
          break;
         } else {
          $420 = $419;$424 = $423;$428 = $427;$avgPen34$089 = $431;$b36$090 = $432;
         }
        }
       } else {
        $$lcssa86 = Math_fround(0.0);$$lcssa87 = Math_fround(0.0);$$lcssa88 = Math_fround(0.0);$avgPen34$0$lcssa = Math_fround(0.0);
       }
       $433 = Math_fround($415 * $$lcssa88);
       $434 = Math_fround($415 * $$lcssa87);
       $435 = Math_fround($415 * $$lcssa86);
       HEAPF32[$389>>2] = $433;
       $436 = (($currPtr$1113) + 36|0);
       HEAPF32[$436>>2] = $434;
       $437 = (($currPtr$1113) + 40|0);
       HEAPF32[$437>>2] = $435;
       $438 = Math_fround($415 * $avgPen34$0$lcssa);
       $439 = (($currPtr$1113) + 44|0);
       HEAPF32[$439>>2] = $438;
       $440 = (($currPtr$1113) + 48|0);
       $441 = (($currPtr$1113) + 176|0);
       $point32$1$ph$in = $440;
      } else {
       $point32$1$ph$in = $389;
      }
      $442 = ($startIndex$2112>>>0)<($393>>>0);
      if ($442) {
       $443 = $393 << 4;
       $444 = $startIndex$2112 << 4;
       $445 = (($443) - ($444))|0;
       $scevgep152 = (($point32$1$ph$in) + ($445)|0);
       $b37$0100 = $startIndex$2112;$point32$199 = $point32$1$ph$in;
       while(1) {
        $446 = ((($contactPoints) + ($b37$0100<<6)|0) + 16|0);
        $447 = Math_fround(HEAPF32[$446>>2]);
        HEAPF32[$point32$199>>2] = $447;
        $448 = ((($contactPoints) + ($b37$0100<<6)|0) + 20|0);
        $449 = Math_fround(HEAPF32[$448>>2]);
        $450 = (($point32$199) + 4|0);
        HEAPF32[$450>>2] = $449;
        $451 = ((($contactPoints) + ($b37$0100<<6)|0) + 24|0);
        $452 = Math_fround(HEAPF32[$451>>2]);
        $453 = (($point32$199) + 8|0);
        HEAPF32[$453>>2] = $452;
        $454 = ((($contactPoints) + ($b37$0100<<6)|0) + 12|0);
        $455 = Math_fround(HEAPF32[$454>>2]);
        $456 = (($point32$199) + 12|0);
        HEAPF32[$456>>2] = $455;
        $457 = (($point32$199) + 16|0);
        $458 = (($point32$199) + 144|0);
        $459 = (($b37$0100) + 1)|0;
        $exitcond154 = ($459|0)==($393|0);
        if ($exitcond154) {
         break;
        } else {
         $b37$0100 = $459;$point32$199 = $457;
        }
       }
       $point32$1$lcssa = $scevgep152;
      } else {
       $point32$1$lcssa = $point32$1$ph$in;
      }
      $460 = HEAP16[$391>>1]|0;
      $461 = $460&65535;
      $462 = (($a23$0114) + 1)|0;
      $exitcond155 = ($462|0)==($numStrideHeaders$0$lcssa|0);
      if ($exitcond155) {
       break;
      } else {
       $a23$0114 = $462;$combinedRestitution$4107 = $combinedRestitution$5;$currPtr$1113 = $point32$1$lcssa;$dynamicFriction$4108 = $dynamicFriction$5;$flags$4106 = $flags$5;$origMatIndex0$4111 = $origMatIndex0$5;$origMatIndex1$4110 = $origMatIndex1$5;$startIndex$2112 = $461;$staticFriction$4109 = $staticFriction$5;
      }
     }
    }
   }
  } while(0);
  $463 = ($81|0)==(0);
  if (!($463)) {
   $464 = (($113) + ($79)|0);
   $465 = HEAP16[$statusFlag>>1]|0;
   $466 = $465&65535;
   $467 = $466 | 16;
   $468 = $467&65535;
   HEAP16[$statusFlag>>1] = $468;
   HEAP32[$contactForces>>2] = $464;
   _memset(($464|0),0,($81|0))|0;
  }
  HEAP16[$writtenContactCount>>1] = $144;
  $$0 = $77;
 }
 $469 = HEAP8[$8>>0]|0;
 $470 = ($469<<24>>24)==(0);
 if ($470) {
  $$1 = $$0;
  STACKTOP = sp;return ($$1|0);
 }
 $471 = HEAP32[$strHeader>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($strHeader,$471);
 $$1 = $$0;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx14finishContactsERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE($n,$threadContext,$pMaterials) {
 $n = $n|0;
 $threadContext = $threadContext|0;
 $pMaterials = $pMaterials|0;
 var $$ = 0, $$0 = 0, $$mux = 0, $$not1 = 0, $$not2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $brmerge = 0, $brmerge3 = 0, $brmerge4 = 0, $contactForceByteSize$0 = 0, $contactForces = 0, $phitmp = 0, $statusFlags$0 = 0, $statusFlags$0$in = 0, $statusFlags$0$in$v = 0, $statusFlags$1 = 0, $statusFlags$1$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $contactForces = sp;
 $0 = (($n) + 98|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = $2 & 65516;
 $4 = (($threadContext) + 4480|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 $statusFlags$0$in$v = $6 ? 1 : 2;
 $statusFlags$0$in = $statusFlags$0$in$v | $3;
 $7 = (($n) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 $$not1 = ($8|0)!=(0|0);
 $$not2 = $6 ^ 1;
 $brmerge3 = $$not1 | $$not2;
 if (!($brmerge3)) {
  $statusFlags$0 = $statusFlags$0$in&65535;
  HEAP16[$0>>1] = $statusFlags$0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($n) + 22|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $5&65535;
 $12 = (($n) + 20|0);
 HEAP16[$12>>1] = $11;
 $13 = $10 & 130;
 $14 = ($13<<16>>16)==(0);
 $brmerge4 = $14 | $6;
 $$mux = $14 ? $5 : 0;
 $15 = $statusFlags$0$in | 4;
 $16 = $statusFlags$0$in & 65515;
 $17 = $brmerge4 ? $$mux : $5;
 $statusFlags$1$in = $brmerge4 ? $16 : $15;
 $statusFlags$1 = $statusFlags$1$in&65535;
 HEAP16[$0>>1] = $statusFlags$1;
 $18 = ($17|0)==(0);
 $$ = $18 ? 0 : $8;
 HEAP32[$7>>2] = $$;
 $19 = $17 << 2;
 $20 = $10&65535;
 $21 = $20 & 1;
 $22 = ($21|0)==(0);
 do {
  if ($22) {
   $23 = (($threadContext) + 8770|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if ($25) {
    $26 = $20 & 256;
    $27 = ($26|0)==(0);
    if ($27) {
     $41 = 1;
    } else {
     $28 = $20 & 32;
     $29 = ($28|0)==(0);
     if (!($29)) {
      $30 = (($n) + 64|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($31) + 92|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($33|0)==(2139095039);
      if (!($34)) {
       $41 = 0;
       break;
      }
     }
     $35 = $10 & 64;
     $36 = ($35<<16>>16)==(0);
     if ($36) {
      $41 = 1;
     } else {
      $37 = (($n) + 68|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($38) + 92|0);
      $40 = HEAP32[$39>>2]|0;
      $phitmp = ($40|0)==(2139095039);
      $41 = $phitmp;
     }
    }
   } else {
    $41 = 0;
   }
  } else {
   $41 = 0;
  }
 } while(0);
 $brmerge = $18 | $41;
 $contactForceByteSize$0 = $brmerge ? 0 : $19;
 $42 = (($threadContext) + 384|0);
 $43 = (($n) + 28|0);
 $44 = (($n) + 32|0);
 $45 = (($n) + 80|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $10 & 128;
 $48 = ($47<<16>>16)!=(0);
 $49 = (($threadContext) + 8771|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = ($50<<24>>24)!=(0);
 $52 = (__ZN5physx22writeCompressedContactEPKNS_2Gu12ContactPointEjRNS_18PxcNpThreadContextERtRPhRjRPfjS6_PKNS_18PxsMaterialManagerEbbPNS_15PxsMaterialInfoEjbPS4_b($42,$17,$threadContext,$12,$43,$44,$contactForces,$contactForceByteSize$0,$0,$46,$48,0,$pMaterials,0,0,0,$51)|0);
 $53 = ($52|0)==(0);
 if (!($53)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $54 = HEAP32[$4>>2]|0;
 $55 = ($54|0)==(0);
 $$0 = $55;
 STACKTOP = sp;return ($$0|0);
}
function __Z27computeBlockStreamByteSizesRKN5physx13PxcNpWorkUnitERNS_18PxcNpThreadContextEbRjS5_S5_S5_($n,$threadContext,$forceContacts,$_solverConstraintByteSize,$_frictionPatchByteSize,$_numFrictionPatches,$_axisConstraintCount) {
 $n = $n|0;
 $threadContext = $threadContext|0;
 $forceContacts = $forceContacts|0;
 $_solverConstraintByteSize = $_solverConstraintByteSize|0;
 $_frictionPatchByteSize = $_frictionPatchByteSize|0;
 $_numFrictionPatches = $_numFrictionPatches|0;
 $_axisConstraintCount = $_axisConstraintCount|0;
 var $$pre10 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $axisConstraintCount$0$lcssa = 0;
 var $axisConstraintCount$03 = 0, $axisConstraintCount$03$us = 0, $axisConstraintCount$1 = 0, $axisConstraintCount$1$us = 0, $i$01 = 0, $i$01$us = 0, $not$ = 0, $not$$us = 0, $numFrictionPatches$0$ = 0, $numFrictionPatches$0$$us = 0, $numFrictionPatches$0$lcssa = 0, $numFrictionPatches$04 = 0, $numFrictionPatches$04$us = 0, $solverConstraintByteSize$0$lcssa = 0, $solverConstraintByteSize$0$op = 0, $solverConstraintByteSize$0$op$op = 0, $solverConstraintByteSize$05 = 0, $solverConstraintByteSize$05$us = 0, $solverConstraintByteSize$1 = 0, $solverConstraintByteSize$1$us = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($n) + 22|0);
 $1 = (($threadContext) + 8728|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 $$pre10 = HEAP16[$0>>1]|0;
 if ($3) {
  $axisConstraintCount$0$lcssa = 0;$numFrictionPatches$0$lcssa = 0;$solverConstraintByteSize$0$lcssa = 0;
 } else {
  $4 = $$pre10 & 24;
  $5 = ($4<<16>>16)==(0);
  if ($5) {
   $axisConstraintCount$03 = 0;$i$01 = 0;$numFrictionPatches$04 = 0;$solverConstraintByteSize$05 = 0;
   while(1) {
    $30 = ((($threadContext) + ($i$01<<2)|0) + 8464|0);
    $31 = HEAP32[$30>>2]|0;
    $not$ = ($31|0)!=(65535);
    $32 = $not$&1;
    $numFrictionPatches$0$ = (($32) + ($numFrictionPatches$04))|0;
    $33 = ((($threadContext) + ($i$01<<2)|0) + 8336|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0);
    if ($35) {
     $axisConstraintCount$1 = $axisConstraintCount$03;$solverConstraintByteSize$1 = $solverConstraintByteSize$05;
    } else {
     $36 = ((($threadContext) + (($i$01*96)|0)|0) + 5286|0);
     $37 = HEAP16[$36>>1]|0;
     $38 = $37 & 1;
     $39 = ($38<<16>>16)==(0);
     $40 = (($solverConstraintByteSize$05) + 32)|0;
     $41 = ($34*96)|0;
     $42 = (($40) + ($41))|0;
     $43 = (($34) + ($axisConstraintCount$03))|0;
     if ($39) {
      $44 = ((($threadContext) + (($i$01*96)|0)|0) + 5280|0);
      $45 = HEAP16[$44>>1]|0;
      $46 = $45&65535;
      $47 = ($46*192)|0;
      $48 = (($47) + ($42))|0;
      $49 = $45&65535;
      $50 = $49 << 1;
      $51 = (($50) + ($43))|0;
      $axisConstraintCount$1 = $51;$solverConstraintByteSize$1 = $48;
     } else {
      $axisConstraintCount$1 = $43;$solverConstraintByteSize$1 = $42;
     }
    }
    $52 = (($i$01) + 1)|0;
    $53 = ($52>>>0)<($2>>>0);
    if ($53) {
     $axisConstraintCount$03 = $axisConstraintCount$1;$i$01 = $52;$numFrictionPatches$04 = $numFrictionPatches$0$;$solverConstraintByteSize$05 = $solverConstraintByteSize$1;
    } else {
     $axisConstraintCount$0$lcssa = $axisConstraintCount$1;$numFrictionPatches$0$lcssa = $numFrictionPatches$0$;$solverConstraintByteSize$0$lcssa = $solverConstraintByteSize$1;
     break;
    }
   }
  } else {
   $axisConstraintCount$03$us = 0;$i$01$us = 0;$numFrictionPatches$04$us = 0;$solverConstraintByteSize$05$us = 0;
   while(1) {
    $6 = ((($threadContext) + ($i$01$us<<2)|0) + 8464|0);
    $7 = HEAP32[$6>>2]|0;
    $not$$us = ($7|0)!=(65535);
    $8 = $not$$us&1;
    $numFrictionPatches$0$$us = (($8) + ($numFrictionPatches$04$us))|0;
    $9 = ((($threadContext) + ($i$01$us<<2)|0) + 8336|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0);
    if ($11) {
     $axisConstraintCount$1$us = $axisConstraintCount$03$us;$solverConstraintByteSize$1$us = $solverConstraintByteSize$05$us;
    } else {
     $12 = ((($threadContext) + (($i$01$us*96)|0)|0) + 5286|0);
     $13 = HEAP16[$12>>1]|0;
     $14 = $13 & 1;
     $15 = ($14<<16>>16)==(0);
     $16 = (($solverConstraintByteSize$05$us) + 32)|0;
     $17 = $10 << 7;
     $18 = (($16) + ($17))|0;
     $19 = (($10) + ($axisConstraintCount$03$us))|0;
     if ($15) {
      $20 = ((($threadContext) + (($i$01$us*96)|0)|0) + 5280|0);
      $21 = HEAP16[$20>>1]|0;
      $22 = $21&65535;
      $23 = $22 << 8;
      $24 = (($23) + ($18))|0;
      $25 = $21&65535;
      $26 = $25 << 1;
      $27 = (($26) + ($19))|0;
      $axisConstraintCount$1$us = $27;$solverConstraintByteSize$1$us = $24;
     } else {
      $axisConstraintCount$1$us = $19;$solverConstraintByteSize$1$us = $18;
     }
    }
    $28 = (($i$01$us) + 1)|0;
    $29 = ($28>>>0)<($2>>>0);
    if ($29) {
     $axisConstraintCount$03$us = $axisConstraintCount$1$us;$i$01$us = $28;$numFrictionPatches$04$us = $numFrictionPatches$0$$us;$solverConstraintByteSize$05$us = $solverConstraintByteSize$1$us;
    } else {
     $axisConstraintCount$0$lcssa = $axisConstraintCount$1$us;$numFrictionPatches$0$lcssa = $numFrictionPatches$0$$us;$solverConstraintByteSize$0$lcssa = $solverConstraintByteSize$1$us;
     break;
    }
   }
  }
 }
 $54 = ($numFrictionPatches$0$lcssa*96)|0;
 $55 = $$pre10 & 130;
 $56 = ($55<<16>>16)==(0);
 HEAP32[$_numFrictionPatches>>2] = $numFrictionPatches$0$lcssa;
 HEAP32[$_axisConstraintCount>>2] = $axisConstraintCount$0$lcssa;
 HEAP32[$_frictionPatchByteSize>>2] = $54;
 $solverConstraintByteSize$0$op = (($solverConstraintByteSize$0$lcssa) + 15)|0;
 $solverConstraintByteSize$0$op$op = $solverConstraintByteSize$0$op & -16;
 $57 = $56 ? 0 : $solverConstraintByteSize$0$op$op;
 HEAP32[$_solverConstraintByteSize>>2] = $57;
 STACKTOP = sp;return;
}
function __Z35computeBlockStreamByteSizesCoulomb4PN5physx21PxcSolverContact4DescERNS_18PxcNpThreadContextERKNS_27PxcCorrelationBufferCoulombERjPjS7_($descs,$threadContext,$c,$_solverConstraintByteSize,$_axisConstraintCount,$_numContactPoints4) {
 $descs = $descs|0;
 $threadContext = $threadContext|0;
 $c = $c|0;
 $_solverConstraintByteSize = $_solverConstraintByteSize|0;
 $_axisConstraintCount = $_axisConstraintCount|0;
 $_numContactPoints4 = $_numContactPoints4|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $a$012 = 0, $a1$03 = 0, $axisConstraintCount$0$lcssa = 0, $axisConstraintCount$07 = 0, $axisConstraintCount$1 = 0, $exitcond = 0, $i$06 = 0, $maxContactCount = 0, $maxFrictionCount = 0, $maxPatches$013 = 0, $totalContacts$0$lcssa = 0, $totalContacts$01 = 0;
 var $totalFriction$0$lcssa = 0, $totalFriction$02 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $maxContactCount = sp + 128|0;
 $maxFrictionCount = sp;
 dest=$maxContactCount+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$maxFrictionCount+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $a$012 = 0;$maxPatches$013 = 0;
 while(1) {
  $0 = ((($descs) + (($a$012*56)|0)|0) + 8|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $$lcssa = 0;$axisConstraintCount$0$lcssa = 0;
  } else {
   $3 = ((($descs) + (($a$012*56)|0)|0) + 4|0);
   $4 = HEAP32[$3>>2]|0;
   $axisConstraintCount$07 = 0;$i$06 = 0;
   while(1) {
    $7 = (($4) + ($i$06))|0;
    $8 = ((($c) + ($7<<2)|0) + 1408|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0);
    if ($10) {
     $axisConstraintCount$1 = $axisConstraintCount$07;
    } else {
     $11 = ((($c) + (($7*20)|0)|0) + 786|0);
     $12 = HEAP16[$11>>1]|0;
     $13 = $12 & 1;
     $14 = ($13<<16>>16)==(0);
     $15 = (($maxContactCount) + ($i$06<<2)|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($9>>>0)<($16>>>0);
     $18 = $17 ? $16 : $9;
     HEAP32[$15>>2] = $18;
     $19 = (($9) + ($axisConstraintCount$07))|0;
     if ($14) {
      $20 = ((($c) + (($7*20)|0)|0) + 784|0);
      $21 = HEAP16[$20>>1]|0;
      $22 = $21&65535;
      $23 = (($maxFrictionCount) + ($i$06<<2)|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($22>>>0)<($24>>>0);
      $26 = $25 ? $24 : $22;
      HEAP32[$23>>2] = $26;
      $27 = (($22) + ($19))|0;
      $axisConstraintCount$1 = $27;
     } else {
      $axisConstraintCount$1 = $19;
     }
    }
    $28 = (($i$06) + 1)|0;
    $29 = ($28>>>0)<($1>>>0);
    if ($29) {
     $axisConstraintCount$07 = $axisConstraintCount$1;$i$06 = $28;
    } else {
     $$lcssa = $1;$axisConstraintCount$0$lcssa = $axisConstraintCount$1;
     break;
    }
   }
  }
  $30 = ($$lcssa>>>0)<($maxPatches$013>>>0);
  $6 = $30 ? $maxPatches$013 : $$lcssa;
  $31 = (($_axisConstraintCount) + ($a$012<<2)|0);
  HEAP32[$31>>2] = $axisConstraintCount$0$lcssa;
  $32 = (($a$012) + 1)|0;
  $exitcond = ($32|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $a$012 = $32;$maxPatches$013 = $6;
  }
 }
 $5 = ($6|0)==(0);
 if ($5) {
  $totalContacts$0$lcssa = 0;$totalFriction$0$lcssa = 0;
 } else {
  $a1$03 = 0;$totalContacts$01 = 0;$totalFriction$02 = 0;
  while(1) {
   $33 = (($maxContactCount) + ($a1$03<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + ($totalContacts$01))|0;
   $36 = (($maxFrictionCount) + ($a1$03<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + ($totalFriction$02))|0;
   $39 = (($a1$03) + 1)|0;
   $40 = ($39>>>0)<($6>>>0);
   if ($40) {
    $a1$03 = $39;$totalContacts$01 = $35;$totalFriction$02 = $38;
   } else {
    $totalContacts$0$lcssa = $35;$totalFriction$0$lcssa = $38;
    break;
   }
  }
 }
 HEAP32[$_numContactPoints4>>2] = $totalContacts$0$lcssa;
 $41 = HEAP32[$descs>>2]|0;
 $42 = (($41) + 22|0);
 $43 = HEAP16[$42>>1]|0;
 $44 = (($descs) + 56|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 22|0);
 $47 = HEAP16[$46>>1]|0;
 $48 = $47 | $43;
 $49 = (($descs) + 112|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 22|0);
 $52 = HEAP16[$51>>1]|0;
 $53 = $48 | $52;
 $54 = (($descs) + 168|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 22|0);
 $57 = HEAP16[$56>>1]|0;
 $58 = $53 | $57;
 $59 = $58 & 64;
 $60 = ($59<<16>>16)==(0);
 $61 = ($6*176)|0;
 $62 = (($totalFriction$0$lcssa) + ($totalContacts$0$lcssa))|0;
 if ($60) {
  $63 = ($62*192)|0;
  $66 = $63;
  $65 = (($66) + ($61))|0;
  HEAP32[$_solverConstraintByteSize>>2] = $65;
  STACKTOP = sp;return;
 } else {
  $64 = ($62*288)|0;
  $66 = $64;
  $65 = (($66) + ($61))|0;
  HEAP32[$_solverConstraintByteSize>>2] = $65;
  STACKTOP = sp;return;
 }
}
function __ZN5physx36createFinalizeSolverContacts4CoulombEPPNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPPNS_23PxcSolverConstraintDescEPPKNS_13PxcSolverBodyESB_PPKNS_17PxcSolverBodyDataESF_PPKNS_12PxsRigidCoreESJ_ffffRNS_25PxsConstraintBlockManagerENS_14PxFrictionType4EnumE($n,$threadContext,$desc,$sBody0,$sBody1,$solverBodyData0,$solverBodyData1,$body0,$body1,$invDtF32,$bounceThresholdF32,$frictionOffsetThreshold,$correlationDistance,$constraintBlockManager,$frictionType) {
 $n = $n|0;
 $threadContext = $threadContext|0;
 $desc = $desc|0;
 $sBody0 = $sBody0|0;
 $sBody1 = $sBody1|0;
 $solverBodyData0 = $solverBodyData0|0;
 $solverBodyData1 = $solverBodyData1|0;
 $body0 = $body0|0;
 $body1 = $body1|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $frictionOffsetThreshold = Math_fround($frictionOffsetThreshold);
 $correlationDistance = Math_fround($correlationDistance);
 $constraintBlockManager = $constraintBlockManager|0;
 $frictionType = $frictionType|0;
 var $$$i1112$ph = 0, $$0$i = 0, $$0$i$1 = 0, $$0$i$2 = 0, $$0$i$3 = 0, $$0$i$i = 0, $$2 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$sum = 0, $$sum$i = 0, $$sum18 = 0, $$sum19 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0;
 var $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0;
 var $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0;
 var $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0;
 var $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = 0, $492 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$033 = 0, $axisConstraintCount = 0, $blockDescs = 0, $c = 0, $faceIndices$0$off0$i$i = 0, $iInertiaScale0 = 0, $iInertiaScale1 = 0, $iMassScale0 = 0, $iMassScale1 = 0, $idt = 0;
 var $invInertiaScale0 = 0, $invInertiaScale1 = 0, $invMassScale0 = 0, $invMassScale1 = 0, $iter = 0, $modify$0$off0$i$i = 0, $not$or$cond3$i = 0, $notlhs = 0, $notrhs = 0, $numContactPoints4 = 0, $numContacts$034 = 0, $numContacts$131 = 0, $numContacts$2$ph = 0, $numContacts$3 = 0, $perPointFriction$0$off030 = 0, $perPointFriction$1$off0$ph = 0, $perPointFriction$2$off0 = 0, $phitmp = 0, $phitmp$i$i = 0, $response$0$off0$i$i = 0;
 var $solverConstraintByteSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2288|0;
 $blockDescs = sp + 2064|0;
 $idt = sp + 2032|0;
 $c = sp + 96|0;
 $invMassScale0 = sp + 32|0;
 $invMassScale1 = sp + 48|0;
 $invInertiaScale0 = sp + 64|0;
 $invInertiaScale1 = sp + 16|0;
 $iter = sp + 1964|0;
 $solverConstraintByteSize = sp + 1960|0;
 $axisConstraintCount = sp + 1944|0;
 $numContactPoints4 = sp + 1936|0;
 $iMassScale0 = sp;
 $iInertiaScale0 = sp + 80|0;
 $iMassScale1 = sp + 1904|0;
 $iInertiaScale1 = sp + 1920|0;
 $0 = HEAP32[$desc>>2]|0;
 $1 = (($0) + 26|0);
 HEAP16[$1>>1] = 0;
 $2 = (($desc) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 26|0);
 HEAP16[$4>>1] = 0;
 $5 = (($desc) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 26|0);
 HEAP16[$7>>1] = 0;
 $8 = (($desc) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 26|0);
 HEAP16[$10>>1] = 0;
 $11 = (($threadContext) + 384|0);
 $12 = (($threadContext) + 4480|0);
 HEAP32[$12>>2] = 0;
 HEAPF32[$idt>>2] = Math_fround(0.0);
 $13 = (($idt) + 4|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($idt) + 8|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($idt) + 12|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($idt) + 16|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($idt) + 20|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($idt) + 24|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($c) + 1792|0);
 $20 = (($c) + 1796|0);
 $21 = ($frictionType|0)==(1);
 $22 = $21 ? 1 : 2;
 $23 = (($iter) + 4|0);
 $24 = (($iter) + 8|0);
 $25 = (($iter) + 36|0);
 $26 = (($iter) + 40|0);
 $27 = (($iter) + 44|0);
 $28 = (($iter) + 12|0);
 $29 = (($iter) + 60|0);
 $30 = (($iter) + 56|0);
 $31 = (($iter) + 64|0);
 $32 = (($iter) + 48|0);
 $33 = (($iter) + 52|0);
 $34 = (($iter) + 24|0);
 $35 = (($iter) + 28|0);
 $36 = (($iter) + 16|0);
 $37 = (($iter) + 32|0);
 $38 = $19;
 $39 = $38;
 HEAP32[$39>>2] = 0;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = 0;
 $a$033 = 0;$numContacts$034 = 0;
 while(1) {
  $42 = (($n) + ($a$033<<2)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 22|0);
  $45 = HEAP16[$44>>1]|0;
  $46 = $45 & 32;
  $47 = ($46<<16>>16)==(0);
  if ($47) {
   $52 = ((($blockDescs) + (($a$033*56)|0)|0) + 28|0);
   HEAP32[$52>>2] = $idt;
   $478 = $43;$54 = $45;
  } else {
   $48 = (($body0) + ($a$033<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = HEAP32[$48>>2]|0;
   $51 = ((($blockDescs) + (($a$033*56)|0)|0) + 28|0);
   HEAP32[$51>>2] = $50;
   $$pre = HEAP32[$42>>2]|0;
   $$phi$trans$insert = (($$pre) + 22|0);
   $$pre41 = HEAP16[$$phi$trans$insert>>1]|0;
   $478 = $$pre;$54 = $$pre41;
  }
  $53 = $54 & 64;
  $55 = ($53<<16>>16)==(0);
  if ($55) {
   $60 = ((($blockDescs) + (($a$033*56)|0)|0) + 32|0);
   HEAP32[$60>>2] = $idt;
   $62 = $478;
  } else {
   $56 = (($body1) + ($a$033<<2)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = HEAP32[$56>>2]|0;
   $59 = ((($blockDescs) + (($a$033*56)|0)|0) + 32|0);
   HEAP32[$59>>2] = $58;
   $$pre42 = HEAP32[$42>>2]|0;
   $62 = $$pre42;
  }
  $61 = (($blockDescs) + (($a$033*56)|0)|0);
  HEAP32[$61>>2] = $62;
  $63 = ((($blockDescs) + (($a$033*56)|0)|0) + 12|0);
  HEAP32[$63>>2] = $numContacts$034;
  $64 = (($sBody0) + ($a$033<<2)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($blockDescs) + (($a$033*56)|0)|0) + 36|0);
  HEAP32[$66>>2] = $65;
  $67 = (($sBody1) + ($a$033<<2)|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($blockDescs) + (($a$033*56)|0)|0) + 40|0);
  HEAP32[$69>>2] = $68;
  $70 = (($solverBodyData0) + ($a$033<<2)|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ((($blockDescs) + (($a$033*56)|0)|0) + 44|0);
  HEAP32[$72>>2] = $71;
  $73 = (($solverBodyData1) + ($a$033<<2)|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ((($blockDescs) + (($a$033*56)|0)|0) + 48|0);
  HEAP32[$75>>2] = $74;
  $76 = HEAP32[$67>>2]|0;
  $77 = HEAP32[$70>>2]|0;
  $78 = HEAP32[$73>>2]|0;
  $79 = HEAP32[$42>>2]|0;
  $80 = (($79) + 20|0);
  $81 = HEAP16[$80>>1]|0;
  $82 = $81&65535;
  $83 = (($82) + ($numContacts$034))|0;
  $84 = ($83>>>0)>(64);
  if ($84) {
   $$2 = 1;
   label = 55;
   break;
  }
  $85 = (($79) + 28|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (($79) + 32|0);
  $88 = HEAP32[$87>>2]|0;
  HEAPF32[$iter>>2] = Math_fround(0.0);
  HEAPF32[$23>>2] = Math_fround(0.0);
  HEAPF32[$24>>2] = Math_fround(0.0);
  HEAP32[$25>>2] = $88;
  HEAP32[$26>>2] = 0;
  HEAP32[$27>>2] = 0;
  HEAP32[$28>>2] = $86;
  $89 = ($88|0)==(0);
  if ($89) {
   $107 = 0;$108 = 0;$109 = 0;$faceIndices$0$off0$i$i = 0;$modify$0$off0$i$i = 0;$response$0$off0$i$i = 1;
  } else {
   $90 = (($86) + 2|0);
   $91 = HEAP16[$90>>1]|0;
   $92 = $91&65535;
   $93 = $92 & 2;
   $94 = ($93|0)!=(0);
   $95 = $92 & 1;
   $96 = ($95|0)!=(0);
   $97 = $93 << 3;
   $98 = $97 | 4;
   $99 = (($86) + ($98)|0);
   $100 = $94 ? 4 : 32;
   if ($94) {
    $479 = 72;
   } else {
    $101 = $95 << 3;
    $102 = $101 | 16;
    $479 = $102;
   }
   $103 = $91 & 4;
   $phitmp$i$i = ($103<<16>>16)!=(0);
   $107 = $100;$108 = $479;$109 = $99;$faceIndices$0$off0$i$i = $96;$modify$0$off0$i$i = $94;$response$0$off0$i$i = $phitmp$i$i;
  }
  $104 = $modify$0$off0$i$i&1;
  HEAP32[$29>>2] = $104;
  $105 = $faceIndices$0$off0$i$i&1;
  HEAP32[$30>>2] = $105;
  $106 = $response$0$off0$i$i&1;
  HEAP32[$31>>2] = $106;
  HEAP32[$32>>2] = $107;
  HEAP32[$33>>2] = $108;
  HEAP32[$34>>2] = $109;
  HEAP32[$35>>2] = $109;
  HEAP32[$36>>2] = $109;
  if ($response$0$off0$i$i) {
   $numContacts$3 = $numContacts$034;$perPointFriction$2$off0 = 0;
  } else {
   if ($modify$0$off0$i$i) {
    $113 = (($86) + 4|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = (($invMassScale0) + ($a$033<<2)|0);
    HEAPF32[$115>>2] = $114;
    $116 = (($86) + 8|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = (($invMassScale1) + ($a$033<<2)|0);
    HEAPF32[$118>>2] = $117;
    $119 = (($86) + 12|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = (($invInertiaScale0) + ($a$033<<2)|0);
    HEAPF32[$121>>2] = $120;
    $122 = (($86) + 16|0);
    $123 = Math_fround(HEAPF32[$122>>2]);
    $125 = $123;
   } else {
    $110 = (($invMassScale0) + ($a$033<<2)|0);
    HEAPF32[$110>>2] = Math_fround(1.0);
    $111 = (($invMassScale1) + ($a$033<<2)|0);
    HEAPF32[$111>>2] = Math_fround(1.0);
    $112 = (($invInertiaScale0) + ($a$033<<2)|0);
    HEAPF32[$112>>2] = Math_fround(1.0);
    $125 = Math_fround(1.0);
   }
   $124 = (($invInertiaScale1) + ($a$033<<2)|0);
   HEAPF32[$124>>2] = $125;
   $126 = $109;
   $127 = $86;
   $128 = (($126) - ($127))|0;
   $129 = ($128>>>0)<($88>>>0);
   if ($129) {
    $$sum18 = (($108) + 128)|0;
    $136 = $109;$138 = $86;$140 = $126;$480 = $109;$481 = 0;$482 = 0;$numContacts$131 = $numContacts$034;$perPointFriction$0$off030 = 0;
    while(1) {
     HEAP32[$34>>2] = $136;
     $137 = $138;
     $139 = (($140) - ($137))|0;
     $141 = ($139>>>0)<($88>>>0);
     if ($141) {
      $142 = HEAP16[$136>>1]|0;
      $143 = $142&65535;
      HEAP32[$26>>2] = $143;
      $144 = Math_imul($108, $143)|0;
      $$sum$i = (($144) + ($107))|0;
      $145 = (($136) + ($$sum$i)|0);
      HEAP32[$35>>2] = $145;
      $146 = (($136) + ($107)|0);
      HEAP32[$36>>2] = $146;
      HEAP32[$27>>2] = 0;
      $151 = $143;$485 = $146;$486 = 0;
     } else {
      HEAP32[$35>>2] = $136;
      $151 = $482;$485 = $480;$486 = $481;
     }
     $150 = $486;$155 = $485;$numContacts$2$ph = $numContacts$131;$perPointFriction$1$off0$ph = $perPointFriction$0$off030;
     L31: while(1) {
      $147 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 384|0);
      $$sum19 = (($numContacts$2$ph) + 2)|0;
      $148 = ((($threadContext) + ($$sum19<<6)|0) + 384|0);
      if ($modify$0$off0$i$i) {
       $153 = $150;$159 = $155;
       while(1) {
        $152 = ($153>>>0)<($151>>>0);
        if (!($152)) {
         $483 = $159;$484 = $153;
         break L31;
        }
        $158 = (($153) + 1)|0;
        HEAP32[$27>>2] = $158;
        HEAP32[$37>>2] = $159;
        $160 = (($159) + ($108)|0);
        HEAP32[$36>>2] = $160;
        $161 = (($159) + ($$sum18)|0);
        $162 = HEAP32[$37>>2]|0;
        $163 = (($162) + 48|0);
        $164 = Math_fround(HEAPF32[$163>>2]);
        $165 = $164 != Math_fround(0.0);
        if ($165) {
         break;
        } else {
         $153 = $158;$159 = $160;
        }
       }
       if ($modify$0$off0$i$i) {
        $166 = HEAP32[$37>>2]|0;
        $167 = (($166) + 24|0);
        $171 = $167;$172 = $147;$180 = $166;$204 = $164;$491 = $160;$492 = $158;
       } else {
        $487 = $160;$488 = $158;$489 = $147;$490 = $164;
        label = 31;
       }
      } else {
       $149 = ($150>>>0)<($151>>>0);
       if (!($149)) {
        $483 = $155;$484 = $150;
        break;
       }
       $154 = (($150) + 1)|0;
       HEAP32[$27>>2] = $154;
       HEAP32[$37>>2] = $155;
       $156 = (($155) + ($108)|0);
       HEAP32[$36>>2] = $156;
       $157 = (($155) + ($$sum18)|0);
       $487 = $156;$488 = $154;$489 = $147;$490 = Math_fround(3.40282346638528859812E+38);
       label = 31;
      }
      if ((label|0) == 31) {
       label = 0;
       $168 = HEAP32[$34>>2]|0;
       $169 = (($168) + 4|0);
       $$pre43 = HEAP32[$37>>2]|0;
       $171 = $169;$172 = $489;$180 = $$pre43;$204 = $490;$491 = $487;$492 = $488;
      }
      $170 = Math_fround(HEAPF32[$171>>2]);
      HEAPF32[$172>>2] = $170;
      $173 = (($171) + 4|0);
      $174 = Math_fround(HEAPF32[$173>>2]);
      $175 = (($172) + 4|0);
      HEAPF32[$175>>2] = $174;
      $176 = (($171) + 8|0);
      $177 = Math_fround(HEAPF32[$176>>2]);
      $178 = (($172) + 8|0);
      HEAPF32[$178>>2] = $177;
      $179 = Math_fround(HEAPF32[$180>>2]);
      $181 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 400|0);
      HEAPF32[$181>>2] = $179;
      $182 = (($180) + 4|0);
      $183 = Math_fround(HEAPF32[$182>>2]);
      $184 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 404|0);
      HEAPF32[$184>>2] = $183;
      $185 = (($180) + 8|0);
      $186 = Math_fround(HEAPF32[$185>>2]);
      $187 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 408|0);
      HEAPF32[$187>>2] = $186;
      $188 = (($180) + 12|0);
      $189 = Math_fround(HEAPF32[$188>>2]);
      $190 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 396|0);
      HEAPF32[$190>>2] = $189;
      if ($modify$0$off0$i$i) {
       $191 = (($180) + 64|0);
       $192 = HEAP16[$191>>1]|0;
       $193 = $192&65535;
       $194 = (($180) + 66|0);
       $195 = HEAP16[$194>>1]|0;
       $196 = $195&65535;
       $197 = $196 << 16;
       $198 = $197 | $193;
       $199 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 432|0);
       HEAP32[$199>>2] = $198;
       $200 = (($180) + 68|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 436|0);
       HEAP32[$202>>2] = $201;
       $203 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 412|0);
       HEAPF32[$203>>2] = $204;
       $205 = (($180) + 52|0);
       $206 = Math_fround(HEAPF32[$205>>2]);
       $207 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 428|0);
       HEAPF32[$207>>2] = $206;
       $208 = (($180) + 56|0);
       $209 = Math_fround(HEAPF32[$208>>2]);
       $210 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 440|0);
       HEAPF32[$210>>2] = $209;
       $211 = (($180) + 60|0);
       $212 = Math_fround(HEAPF32[$211>>2]);
       $213 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 444|0);
       HEAPF32[$213>>2] = $212;
       $214 = (($180) + 36|0);
       $244 = $214;
      } else {
       $215 = HEAP32[$34>>2]|0;
       $216 = (($215) + 28|0);
       $217 = HEAP16[$216>>1]|0;
       $218 = $217&65535;
       $219 = (($215) + 30|0);
       $220 = HEAP16[$219>>1]|0;
       $221 = $220&65535;
       $222 = $221 << 16;
       $223 = $222 | $218;
       $224 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 432|0);
       HEAP32[$224>>2] = $223;
       $225 = HEAP32[$34>>2]|0;
       $226 = (($225) + 2|0);
       $227 = HEAP16[$226>>1]|0;
       $228 = $227&65535;
       $229 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 436|0);
       HEAP32[$229>>2] = $228;
       $230 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 412|0);
       HEAPF32[$230>>2] = $204;
       $231 = HEAP32[$34>>2]|0;
       $232 = (($231) + 16|0);
       $233 = Math_fround(HEAPF32[$232>>2]);
       $234 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 428|0);
       HEAPF32[$234>>2] = $233;
       $235 = HEAP32[$34>>2]|0;
       $236 = (($235) + 20|0);
       $237 = Math_fround(HEAPF32[$236>>2]);
       $238 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 440|0);
       HEAPF32[$238>>2] = $237;
       $239 = HEAP32[$34>>2]|0;
       $240 = (($239) + 24|0);
       $241 = Math_fround(HEAPF32[$240>>2]);
       $242 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 444|0);
       HEAPF32[$242>>2] = $241;
       $244 = $iter;
      }
      $243 = Math_fround(HEAPF32[$244>>2]);
      $245 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 416|0);
      HEAPF32[$245>>2] = $243;
      $246 = (($244) + 4|0);
      $247 = Math_fround(HEAPF32[$246>>2]);
      $248 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 420|0);
      HEAPF32[$248>>2] = $247;
      $249 = (($244) + 8|0);
      $250 = Math_fround(HEAPF32[$249>>2]);
      $251 = ((($threadContext) + ($numContacts$2$ph<<6)|0) + 424|0);
      HEAPF32[$251>>2] = $250;
      if ($modify$0$off0$i$i) {
       $252 = Math_fround(HEAPF32[$244>>2]);
       $253 = $252 == Math_fround(0.0);
       if ($253) {
        $254 = Math_fround(HEAPF32[$246>>2]);
        $255 = $254 == Math_fround(0.0);
        if ($255) {
         $256 = Math_fround(HEAPF32[$249>>2]);
         $phitmp = $256 != Math_fround(0.0);
         $258 = $phitmp;
        } else {
         $258 = 1;
        }
       } else {
        $258 = 1;
       }
      } else {
       $258 = 0;
      }
      $257 = $perPointFriction$1$off0$ph | $258;
      $259 = (($numContacts$2$ph) + 1)|0;
      $150 = $492;$155 = $491;$numContacts$2$ph = $259;$perPointFriction$1$off0$ph = $257;
     }
     $130 = HEAP32[$35>>2]|0;
     $131 = HEAP32[$28>>2]|0;
     $132 = $130;
     $133 = $131;
     $134 = (($132) - ($133))|0;
     $135 = ($134>>>0)<($88>>>0);
     if ($135) {
      $136 = $130;$138 = $131;$140 = $132;$480 = $483;$481 = $484;$482 = $151;$numContacts$131 = $numContacts$2$ph;$perPointFriction$0$off030 = $perPointFriction$1$off0$ph;
     } else {
      $numContacts$3 = $numContacts$2$ph;$perPointFriction$2$off0 = $perPointFriction$1$off0$ph;
      break;
     }
    }
   } else {
    $numContacts$3 = $numContacts$034;$perPointFriction$2$off0 = 0;
   }
  }
  $260 = HEAP32[$63>>2]|0;
  HEAP32[$12>>2] = $numContacts$3;
  $261 = ($numContacts$3|0)==($260|0);
  if ($261) {
   $$2 = 1;
   label = 55;
   break;
  }
  $262 = (($numContacts$3) - ($260))|0;
  $263 = ((($blockDescs) + (($a$033*56)|0)|0) + 16|0);
  HEAP32[$263>>2] = $262;
  $264 = ((($blockDescs) + (($a$033*56)|0)|0) + 52|0);
  $265 = $perPointFriction$2$off0&1;
  HEAP8[$264>>0] = $265;
  $266 = HEAP32[$20>>2]|0;
  $267 = ((($blockDescs) + (($a$033*56)|0)|0) + 4|0);
  HEAP32[$267>>2] = $266;
  $268 = HEAP32[$19>>2]|0;
  $269 = ((($blockDescs) + (($a$033*56)|0)|0) + 20|0);
  HEAP32[$269>>2] = $268;
  (__ZN5physx27createContactPatchesCoulombERNS_27PxcCorrelationBufferCoulombERNS_2Gu13ContactBufferEfj($c,$11,Math_fround(0.999000012874603271484),$260)|0);
  $270 = ((($blockDescs) + (($a$033*56)|0)|0) + 28|0);
  $271 = HEAP32[$270>>2]|0;
  $272 = ((($blockDescs) + (($a$033*56)|0)|0) + 32|0);
  $273 = HEAP32[$272>>2]|0;
  $274 = (__ZN5physx23correlatePatchesCoulombERNS_27PxcCorrelationBufferCoulombERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjjj($c,$11,$271,$273,Math_fround(0.999000012874603271484),$22,$268,$266)|0);
  if ($274) {
   $$2 = 1;
   label = 55;
   break;
  }
  $275 = HEAP32[$19>>2]|0;
  $276 = (($275) - ($268))|0;
  $277 = ((($blockDescs) + (($a$033*56)|0)|0) + 24|0);
  HEAP32[$277>>2] = $276;
  $278 = HEAP32[$20>>2]|0;
  $279 = (($278) - ($266))|0;
  $280 = ((($blockDescs) + (($a$033*56)|0)|0) + 8|0);
  HEAP32[$280>>2] = $279;
  $281 = (($a$033) + 1)|0;
  $282 = ($281>>>0)<(4);
  if ($282) {
   $a$033 = $281;$numContacts$034 = $numContacts$3;
  } else {
   label = 43;
   break;
  }
 }
 if ((label|0) == 43) {
  HEAP32[$solverConstraintByteSize>>2] = 0;
  HEAP32[$numContactPoints4>>2] = 0;
  $283 = (($threadContext) + 316|0);
  __Z35computeBlockStreamByteSizesCoulomb4PN5physx21PxcSolverContact4DescERNS_18PxcNpThreadContextERKNS_27PxcCorrelationBufferCoulombERjPjS7_($blockDescs,$threadContext,$c,$solverConstraintByteSize,$axisConstraintCount,$numContactPoints4);
  $284 = HEAP32[$solverConstraintByteSize>>2]|0;
  $285 = ($284|0)==(0);
  if ($285) {
   $$$i1112$ph = 0;$305 = 0;
  } else {
   $286 = (($284) + 16)|0;
   $287 = ($286>>>0)>(16384);
   if ($287) {
    $$2 = 1;
    STACKTOP = sp;return ($$2|0);
   }
   $288 = (($284) + 31)|0;
   $289 = $288 & -16;
   $290 = ($289>>>0)>(16384);
   do {
    if ($290) {
     $291 = HEAP32[$283>>2]|0;
     $292 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($291,$289)|0);
     $$0$i$i = $292;
    } else {
     $293 = (($threadContext) + 320|0);
     $294 = HEAP32[$293>>2]|0;
     $295 = ($294|0)==(0|0);
     $$pre$i$i = (($threadContext) + 324|0);
     if (!($295)) {
      $296 = HEAP32[$$pre$i$i>>2]|0;
      $297 = (($296) + ($289))|0;
      $298 = ($297>>>0)>(16384);
      if (!($298)) {
       $301 = (($294) + ($296)|0);
       HEAP32[$$pre$i$i>>2] = $297;
       $$0$i$i = $301;
       break;
      }
     }
     $299 = HEAP32[$283>>2]|0;
     $300 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($299,$constraintBlockManager)|0);
     HEAP32[$293>>2] = $300;
     HEAP32[$$pre$i$i>>2] = $289;
     $$0$i$i = $300;
    }
   } while(0);
   $302 = ($$0$i$i|0)==(0|0);
   $notlhs = ($$0$i$i|0)!=(0|0);
   $notrhs = ($$0$i$i|0)==((-1)|0);
   $not$or$cond3$i = $notrhs & $notlhs;
   $303 = $302 | $not$or$cond3$i;
   if ($303) {
    $$2 = 0;
    STACKTOP = sp;return ($$2|0);
   } else {
    $$$i1112$ph = $$0$i$i;$305 = $284;
   }
  }
  $304 = $305 >>> 4;
  $306 = $304&65535;
  $307 = HEAP32[$n>>2]|0;
  HEAP32[$307>>2] = $$$i1112$ph;
  $308 = HEAP32[$desc>>2]|0;
  $309 = (($308) + 16|0);
  HEAP32[$309>>2] = $$$i1112$ph;
  $310 = HEAP32[$n>>2]|0;
  $311 = (($310) + 4|0);
  HEAP32[$311>>2] = $305;
  $312 = HEAP32[$axisConstraintCount>>2]|0;
  $313 = (($310) + 16|0);
  $314 = HEAP16[$313>>1]|0;
  $315 = $314&65535;
  $316 = (($315) + ($312))|0;
  $317 = $316&65535;
  HEAP16[$313>>1] = $317;
  $318 = HEAP32[$desc>>2]|0;
  $319 = (($318) + 26|0);
  HEAP16[$319>>1] = $306;
  $320 = (($310) + 98|0);
  $321 = HEAP16[$320>>1]|0;
  $322 = $321 & 16;
  $323 = ($322<<16>>16)==(0);
  if ($323) {
   $$0$i = 0;$336 = 0;
  } else {
   $324 = (($310) + 20|0);
   $325 = HEAP16[$324>>1]|0;
   $326 = (($310) + 28|0);
   $327 = HEAP32[$326>>2]|0;
   $328 = (($310) + 32|0);
   $329 = HEAP32[$328>>2]|0;
   $330 = (($329) + 15)|0;
   $331 = $330 & -16;
   $332 = (($327) + ($331)|0);
   $$0$i = $332;$336 = $325;
  }
  $333 = (($318) + 20|0);
  HEAP32[$333>>2] = $$0$i;
  $334 = HEAP32[$desc>>2]|0;
  $335 = (($334) + 24|0);
  HEAP16[$335>>1] = $336;
  $337 = (($n) + 4|0);
  $338 = HEAP32[$337>>2]|0;
  HEAP32[$338>>2] = $$$i1112$ph;
  $339 = HEAP32[$2>>2]|0;
  $340 = (($339) + 16|0);
  HEAP32[$340>>2] = $$$i1112$ph;
  $341 = HEAP32[$337>>2]|0;
  $342 = (($341) + 4|0);
  HEAP32[$342>>2] = $305;
  $343 = (($axisConstraintCount) + 4|0);
  $344 = HEAP32[$343>>2]|0;
  $345 = (($341) + 16|0);
  $346 = HEAP16[$345>>1]|0;
  $347 = $346&65535;
  $348 = (($347) + ($344))|0;
  $349 = $348&65535;
  HEAP16[$345>>1] = $349;
  $350 = HEAP32[$2>>2]|0;
  $351 = (($350) + 26|0);
  HEAP16[$351>>1] = $306;
  $352 = (($341) + 98|0);
  $353 = HEAP16[$352>>1]|0;
  $354 = $353 & 16;
  $355 = ($354<<16>>16)==(0);
  if ($355) {
   $$0$i$1 = 0;$368 = 0;
  } else {
   $356 = (($341) + 20|0);
   $357 = HEAP16[$356>>1]|0;
   $358 = (($341) + 28|0);
   $359 = HEAP32[$358>>2]|0;
   $360 = (($341) + 32|0);
   $361 = HEAP32[$360>>2]|0;
   $362 = (($361) + 15)|0;
   $363 = $362 & -16;
   $364 = (($359) + ($363)|0);
   $$0$i$1 = $364;$368 = $357;
  }
  $365 = (($350) + 20|0);
  HEAP32[$365>>2] = $$0$i$1;
  $366 = HEAP32[$2>>2]|0;
  $367 = (($366) + 24|0);
  HEAP16[$367>>1] = $368;
  $369 = (($n) + 8|0);
  $370 = HEAP32[$369>>2]|0;
  HEAP32[$370>>2] = $$$i1112$ph;
  $371 = HEAP32[$5>>2]|0;
  $372 = (($371) + 16|0);
  HEAP32[$372>>2] = $$$i1112$ph;
  $373 = HEAP32[$369>>2]|0;
  $374 = (($373) + 4|0);
  HEAP32[$374>>2] = $305;
  $375 = (($axisConstraintCount) + 8|0);
  $376 = HEAP32[$375>>2]|0;
  $377 = (($373) + 16|0);
  $378 = HEAP16[$377>>1]|0;
  $379 = $378&65535;
  $380 = (($379) + ($376))|0;
  $381 = $380&65535;
  HEAP16[$377>>1] = $381;
  $382 = HEAP32[$5>>2]|0;
  $383 = (($382) + 26|0);
  HEAP16[$383>>1] = $306;
  $384 = (($373) + 98|0);
  $385 = HEAP16[$384>>1]|0;
  $386 = $385 & 16;
  $387 = ($386<<16>>16)==(0);
  if ($387) {
   $$0$i$2 = 0;$400 = 0;
  } else {
   $388 = (($373) + 20|0);
   $389 = HEAP16[$388>>1]|0;
   $390 = (($373) + 28|0);
   $391 = HEAP32[$390>>2]|0;
   $392 = (($373) + 32|0);
   $393 = HEAP32[$392>>2]|0;
   $394 = (($393) + 15)|0;
   $395 = $394 & -16;
   $396 = (($391) + ($395)|0);
   $$0$i$2 = $396;$400 = $389;
  }
  $397 = (($382) + 20|0);
  HEAP32[$397>>2] = $$0$i$2;
  $398 = HEAP32[$5>>2]|0;
  $399 = (($398) + 24|0);
  HEAP16[$399>>1] = $400;
  $401 = (($n) + 12|0);
  $402 = HEAP32[$401>>2]|0;
  HEAP32[$402>>2] = $$$i1112$ph;
  $403 = HEAP32[$8>>2]|0;
  $404 = (($403) + 16|0);
  HEAP32[$404>>2] = $$$i1112$ph;
  $405 = HEAP32[$401>>2]|0;
  $406 = (($405) + 4|0);
  HEAP32[$406>>2] = $305;
  $407 = (($axisConstraintCount) + 12|0);
  $408 = HEAP32[$407>>2]|0;
  $409 = (($405) + 16|0);
  $410 = HEAP16[$409>>1]|0;
  $411 = $410&65535;
  $412 = (($411) + ($408))|0;
  $413 = $412&65535;
  HEAP16[$409>>1] = $413;
  $414 = HEAP32[$8>>2]|0;
  $415 = (($414) + 26|0);
  HEAP16[$415>>1] = $306;
  $416 = (($405) + 98|0);
  $417 = HEAP16[$416>>1]|0;
  $418 = $417 & 16;
  $419 = ($418<<16>>16)==(0);
  if ($419) {
   $$0$i$3 = 0;$432 = 0;
  } else {
   $420 = (($405) + 20|0);
   $421 = HEAP16[$420>>1]|0;
   $422 = (($405) + 28|0);
   $423 = HEAP32[$422>>2]|0;
   $424 = (($405) + 32|0);
   $425 = HEAP32[$424>>2]|0;
   $426 = (($425) + 15)|0;
   $427 = $426 & -16;
   $428 = (($423) + ($427)|0);
   $$0$i$3 = $428;$432 = $421;
  }
  $429 = (($414) + 20|0);
  HEAP32[$429>>2] = $$0$i$3;
  $430 = HEAP32[$8>>2]|0;
  $431 = (($430) + 24|0);
  HEAP16[$431>>1] = $432;
  $433 = Math_fround(HEAPF32[$invMassScale0>>2]);
  $434 = (($invMassScale0) + 4|0);
  $435 = Math_fround(HEAPF32[$434>>2]);
  $436 = (($invMassScale0) + 8|0);
  $437 = Math_fround(HEAPF32[$436>>2]);
  $438 = (($invMassScale0) + 12|0);
  $439 = Math_fround(HEAPF32[$438>>2]);
  HEAPF32[$iMassScale0>>2] = $433;
  $440 = (($iMassScale0) + 4|0);
  HEAPF32[$440>>2] = $435;
  $441 = (($iMassScale0) + 8|0);
  HEAPF32[$441>>2] = $437;
  $442 = (($iMassScale0) + 12|0);
  HEAPF32[$442>>2] = $439;
  $443 = Math_fround(HEAPF32[$invInertiaScale0>>2]);
  $444 = (($invInertiaScale0) + 4|0);
  $445 = Math_fround(HEAPF32[$444>>2]);
  $446 = (($invInertiaScale0) + 8|0);
  $447 = Math_fround(HEAPF32[$446>>2]);
  $448 = (($invInertiaScale0) + 12|0);
  $449 = Math_fround(HEAPF32[$448>>2]);
  HEAPF32[$iInertiaScale0>>2] = $443;
  $450 = (($iInertiaScale0) + 4|0);
  HEAPF32[$450>>2] = $445;
  $451 = (($iInertiaScale0) + 8|0);
  HEAPF32[$451>>2] = $447;
  $452 = (($iInertiaScale0) + 12|0);
  HEAPF32[$452>>2] = $449;
  $453 = Math_fround(HEAPF32[$invMassScale1>>2]);
  $454 = (($invMassScale1) + 4|0);
  $455 = Math_fround(HEAPF32[$454>>2]);
  $456 = (($invMassScale1) + 8|0);
  $457 = Math_fround(HEAPF32[$456>>2]);
  $458 = (($invMassScale1) + 12|0);
  $459 = Math_fround(HEAPF32[$458>>2]);
  HEAPF32[$iMassScale1>>2] = $453;
  $460 = (($iMassScale1) + 4|0);
  HEAPF32[$460>>2] = $455;
  $461 = (($iMassScale1) + 8|0);
  HEAPF32[$461>>2] = $457;
  $462 = (($iMassScale1) + 12|0);
  HEAPF32[$462>>2] = $459;
  $463 = Math_fround(HEAPF32[$invInertiaScale1>>2]);
  $464 = (($invInertiaScale1) + 4|0);
  $465 = Math_fround(HEAPF32[$464>>2]);
  $466 = (($invInertiaScale1) + 8|0);
  $467 = Math_fround(HEAPF32[$466>>2]);
  $468 = (($invInertiaScale1) + 12|0);
  $469 = Math_fround(HEAPF32[$468>>2]);
  HEAPF32[$iInertiaScale1>>2] = $463;
  $470 = (($iInertiaScale1) + 4|0);
  HEAPF32[$470>>2] = $465;
  $471 = (($iInertiaScale1) + 8|0);
  HEAPF32[$471>>2] = $467;
  $472 = (($iInertiaScale1) + 12|0);
  HEAPF32[$472>>2] = $469;
  $473 = HEAP32[$numContactPoints4>>2]|0;
  $474 = (__ZN5physx38setupFinalizeSolverConstraintsCoulomb4EPNS_21PxcSolverContact4DescERNS_18PxcNpThreadContextEPhffRNS_27PxcCorrelationBufferCoulombEjjjRKNS_6shdfnd3aos5Vec4VESB_SB_SB_($blockDescs,$threadContext,$$$i1112$ph,$invDtF32,$bounceThresholdF32,$c,$22,$473,$305,$iMassScale0,$iInertiaScale0,$iMassScale1,$iInertiaScale1)|0);
  $475 = (($$$i1112$ph) + ($305)|0);
  HEAP32[$475>>2] = 0;
  $476 = $474 << 31 >> 31;
  $$sum = (($305) + 4)|0;
  $477 = (($$$i1112$ph) + ($$sum)|0);
  HEAP32[$477>>2] = $476;
  $$2 = 2;
  STACKTOP = sp;return ($$2|0);
 }
 else if ((label|0) == 55) {
  STACKTOP = sp;return ($$2|0);
 }
 return 0|0;
}
function __ZN5physx35createFinalizeSolverContactsCoulombERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEbbRNS_23PxcSolverConstraintDescEPKNS_13PxcSolverBodyES8_PKNS_17PxcSolverBodyDataESB_PKNS_12PxsRigidCoreESE_ffffRNS_25PxsConstraintBlockManagerENS_14PxFrictionType4EnumE($n,$threadContext,$forceContacts,$perPointFriction,$desc,$sBody0,$sBody1,$solverBodyData0,$solverBodyData1,$body0,$body1,$invDtF32,$bounceThresholdF32,$frictionOffsetThreshold,$correlationDistance,$constraintBlockManager,$frictionType) {
 $n = $n|0;
 $threadContext = $threadContext|0;
 $forceContacts = $forceContacts|0;
 $perPointFriction = $perPointFriction|0;
 $desc = $desc|0;
 $sBody0 = $sBody0|0;
 $sBody1 = $sBody1|0;
 $solverBodyData0 = $solverBodyData0|0;
 $solverBodyData1 = $solverBodyData1|0;
 $body0 = $body0|0;
 $body1 = $body1|0;
 $invDtF32 = Math_fround($invDtF32);
 $bounceThresholdF32 = Math_fround($bounceThresholdF32);
 $frictionOffsetThreshold = Math_fround($frictionOffsetThreshold);
 $correlationDistance = Math_fround($correlationDistance);
 $constraintBlockManager = $constraintBlockManager|0;
 $frictionType = $frictionType|0;
 var $$$0$i$i = 0, $$$i8 = 0, $$0 = 0, $$0$i$i = 0, $$0132 = 0, $$1$ph = 0, $$5$i = 0, $$pre = 0, $$pre$i$i = 0, $$sum = 0, $$sum$i = 0, $$sum20 = 0, $$sum21 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0;
 var $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0);
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0;
 var $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $axisConstraintCount$0$lcssa$i$i = 0, $axisConstraintCount$01$i$i = 0, $axisConstraintCount$01$us$i$i = 0, $axisConstraintCount$1$i$i = 0, $axisConstraintCount$1$us$i$i = 0, $b0 = 0, $b1 = 0, $bodyFrame0$0 = 0, $bodyFrame1$0 = 0, $c = 0, $constraintBlock$04$i = 0, $exitcond$i = 0, $exitcond6$i = 0, $extract$t = 0, $faceIndices$0$off0$i$i = 0, $hasFriction$0$in = 0, $i$02$i$i = 0, $i$02$us$i$i = 0, $idt = 0;
 var $iter = 0, $modify$0$off0$i$i = 0, $n$idx$val = 0, $not$ = 0, $not$or$cond3$i = 0, $notlhs = 0, $notrhs = 0, $numContacts$031 = 0, $numContacts$1$ph = 0, $phitmp = 0, $phitmp$i$i = 0, $phitmp41 = 0, $phitmp4142 = 0, $response$0$off0$i$i = 0, $solverConstraintByteSize$0$lcssa$i$i = 0, $solverConstraintByteSize$0$op$i$i = 0, $solverConstraintByteSize$0$op$op$i$i = 0, $solverConstraintByteSize$04$i$i = 0, $solverConstraintByteSize$04$us$i$i = 0, $solverConstraintByteSize$1$i$i = 0;
 var $solverConstraintByteSize$1$us$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1936|0;
 $idt = sp + 1900|0;
 $iter = sp + 1808|0;
 $c = sp;
 $b0 = sp + 1876|0;
 $b1 = sp + 1888|0;
 $0 = $perPointFriction&1;
 $1 = (($desc) + 26|0);
 HEAP16[$1>>1] = 0;
 $2 = (($threadContext) + 384|0);
 $3 = (($threadContext) + 4480|0);
 HEAP32[$3>>2] = 0;
 $4 = (($n) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 HEAPF32[$idt>>2] = Math_fround(0.0);
 $6 = (($idt) + 4|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($idt) + 8|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($idt) + 12|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($idt) + 16|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($idt) + 20|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($idt) + 24|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($n) + 22|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13 & 32;
 $15 = ($14<<16>>16)==(0);
 $bodyFrame0$0 = $15 ? $idt : $body0;
 $16 = $13 & 64;
 $17 = ($16<<16>>16)==(0);
 $bodyFrame1$0 = $17 ? $idt : $body1;
 $18 = (($n) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 do {
  if (!($20)) {
   $21 = (($n) + 32|0);
   $22 = HEAP32[$21>>2]|0;
   HEAPF32[$iter>>2] = Math_fround(0.0);
   $23 = (($iter) + 4|0);
   HEAPF32[$23>>2] = Math_fround(0.0);
   $24 = (($iter) + 8|0);
   HEAPF32[$24>>2] = Math_fround(0.0);
   $25 = (($iter) + 36|0);
   HEAP32[$25>>2] = $22;
   $26 = (($iter) + 40|0);
   HEAP32[$26>>2] = 0;
   $27 = (($iter) + 44|0);
   HEAP32[$27>>2] = 0;
   $28 = (($iter) + 12|0);
   HEAP32[$28>>2] = $19;
   $29 = ($22|0)==(0);
   if ($29) {
    $51 = 0;$53 = 0;$55 = 0;$faceIndices$0$off0$i$i = 0;$modify$0$off0$i$i = 0;$response$0$off0$i$i = 1;
   } else {
    $30 = (($19) + 2|0);
    $31 = HEAP16[$30>>1]|0;
    $32 = $31&65535;
    $33 = $32 & 2;
    $34 = ($33|0)!=(0);
    $35 = $32 & 1;
    $36 = ($35|0)!=(0);
    $37 = $33 << 3;
    $38 = $37 | 4;
    $39 = (($19) + ($38)|0);
    $40 = $34 ? 4 : 32;
    if ($34) {
     $314 = 72;
    } else {
     $41 = $35 << 3;
     $42 = $41 | 16;
     $314 = $42;
    }
    $43 = $31 & 4;
    $phitmp$i$i = ($43<<16>>16)!=(0);
    $51 = $40;$53 = $314;$55 = $39;$faceIndices$0$off0$i$i = $36;$modify$0$off0$i$i = $34;$response$0$off0$i$i = $phitmp$i$i;
   }
   $44 = $modify$0$off0$i$i&1;
   $45 = (($iter) + 60|0);
   HEAP32[$45>>2] = $44;
   $46 = $faceIndices$0$off0$i$i&1;
   $47 = (($iter) + 56|0);
   HEAP32[$47>>2] = $46;
   $48 = $response$0$off0$i$i&1;
   $49 = (($iter) + 64|0);
   HEAP32[$49>>2] = $48;
   $50 = (($iter) + 48|0);
   HEAP32[$50>>2] = $51;
   $52 = (($iter) + 52|0);
   HEAP32[$52>>2] = $53;
   $54 = (($iter) + 24|0);
   HEAP32[$54>>2] = $55;
   $56 = (($iter) + 28|0);
   HEAP32[$56>>2] = $55;
   $57 = (($iter) + 16|0);
   HEAP32[$57>>2] = $55;
   if (!($response$0$off0$i$i)) {
    if ($modify$0$off0$i$i) {
     $58 = (($19) + 4|0);
     $59 = Math_fround(HEAPF32[$58>>2]);
     $60 = (($19) + 8|0);
     $61 = Math_fround(HEAPF32[$60>>2]);
     $62 = (($19) + 12|0);
     $63 = Math_fround(HEAPF32[$62>>2]);
     $64 = (($19) + 16|0);
     $65 = Math_fround(HEAPF32[$64>>2]);
     $305 = $59;$306 = $63;$307 = $61;$308 = $65;$72 = $44;
    } else {
     $305 = Math_fround(1.0);$306 = Math_fround(1.0);$307 = Math_fround(1.0);$308 = Math_fround(1.0);$72 = 0;
    }
    $66 = $55;
    $67 = $19;
    $68 = (($66) - ($67))|0;
    $69 = ($68>>>0)<($22>>>0);
    if (!($69)) {
     HEAP32[$3>>2] = 0;
     break;
    }
    $70 = (($iter) + 32|0);
    $$sum = (($53) + 128)|0;
    $71 = ($72|0)==(0);
    $$0132 = $0;$315 = $55;$316 = 0;$317 = 0;$79 = $55;$81 = $19;$83 = $66;$numContacts$031 = 0;
    while(1) {
     HEAP32[$54>>2] = $79;
     $80 = $81;
     $82 = (($83) - ($80))|0;
     $84 = ($82>>>0)<($22>>>0);
     if ($84) {
      $85 = HEAP16[$79>>1]|0;
      $86 = $85&65535;
      HEAP32[$26>>2] = $86;
      $87 = Math_imul($53, $86)|0;
      $$sum$i = (($87) + ($51))|0;
      $88 = (($79) + ($$sum$i)|0);
      HEAP32[$56>>2] = $88;
      $89 = (($79) + ($51)|0);
      HEAP32[$57>>2] = $89;
      HEAP32[$27>>2] = 0;
      $320 = $89;$321 = 0;$94 = $86;
     } else {
      HEAP32[$56>>2] = $79;
      $320 = $315;$321 = $316;$94 = $317;
     }
     $$1$ph = $$0132;$93 = $321;$98 = $320;$numContacts$1$ph = $numContacts$031;
     L22: while(1) {
      $90 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 384|0);
      $$sum21 = (($numContacts$1$ph) + 2)|0;
      $91 = ((($threadContext) + ($$sum21<<6)|0) + 384|0);
      if ($71) {
       $92 = ($93>>>0)<($94>>>0);
       if (!($92)) {
        $318 = $98;$319 = $93;
        break;
       }
       $97 = (($93) + 1)|0;
       HEAP32[$27>>2] = $97;
       HEAP32[$70>>2] = $98;
       $99 = (($98) + ($53)|0);
       HEAP32[$57>>2] = $99;
       $100 = (($98) + ($$sum)|0);
       $322 = $99;$323 = $97;$324 = $90;$325 = Math_fround(3.40282346638528859812E+38);
       label = 24;
      } else {
       $102 = $98;$96 = $93;
       while(1) {
        $95 = ($96>>>0)<($94>>>0);
        if (!($95)) {
         $318 = $102;$319 = $96;
         break L22;
        }
        $101 = (($96) + 1)|0;
        HEAP32[$27>>2] = $101;
        HEAP32[$70>>2] = $102;
        $103 = (($102) + ($53)|0);
        HEAP32[$57>>2] = $103;
        $104 = (($102) + ($$sum)|0);
        $105 = HEAP32[$70>>2]|0;
        $106 = (($105) + 48|0);
        $107 = Math_fround(HEAPF32[$106>>2]);
        $108 = $107 != Math_fround(0.0);
        if ($108) {
         break;
        } else {
         $102 = $103;$96 = $101;
        }
       }
       if ($71) {
        $322 = $103;$323 = $101;$324 = $90;$325 = $107;
        label = 24;
       } else {
        $109 = HEAP32[$70>>2]|0;
        $110 = (($109) + 24|0);
        $114 = $110;$115 = $90;$123 = $109;$147 = $107;$326 = $103;$327 = $101;
       }
      }
      if ((label|0) == 24) {
       label = 0;
       $111 = HEAP32[$54>>2]|0;
       $112 = (($111) + 4|0);
       $$pre = HEAP32[$70>>2]|0;
       $114 = $112;$115 = $324;$123 = $$pre;$147 = $325;$326 = $322;$327 = $323;
      }
      $113 = Math_fround(HEAPF32[$114>>2]);
      HEAPF32[$115>>2] = $113;
      $116 = (($114) + 4|0);
      $117 = Math_fround(HEAPF32[$116>>2]);
      $118 = (($115) + 4|0);
      HEAPF32[$118>>2] = $117;
      $119 = (($114) + 8|0);
      $120 = Math_fround(HEAPF32[$119>>2]);
      $121 = (($115) + 8|0);
      HEAPF32[$121>>2] = $120;
      $122 = Math_fround(HEAPF32[$123>>2]);
      $124 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 400|0);
      HEAPF32[$124>>2] = $122;
      $125 = (($123) + 4|0);
      $126 = Math_fround(HEAPF32[$125>>2]);
      $127 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 404|0);
      HEAPF32[$127>>2] = $126;
      $128 = (($123) + 8|0);
      $129 = Math_fround(HEAPF32[$128>>2]);
      $130 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 408|0);
      HEAPF32[$130>>2] = $129;
      $131 = (($123) + 12|0);
      $132 = Math_fround(HEAPF32[$131>>2]);
      $133 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 396|0);
      HEAPF32[$133>>2] = $132;
      if ($71) {
       $158 = HEAP32[$54>>2]|0;
       $159 = (($158) + 28|0);
       $160 = HEAP16[$159>>1]|0;
       $161 = $160&65535;
       $162 = (($158) + 30|0);
       $163 = HEAP16[$162>>1]|0;
       $164 = $163&65535;
       $165 = $164 << 16;
       $166 = $165 | $161;
       $167 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 432|0);
       HEAP32[$167>>2] = $166;
       $168 = HEAP32[$54>>2]|0;
       $169 = (($168) + 2|0);
       $170 = HEAP16[$169>>1]|0;
       $171 = $170&65535;
       $172 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 436|0);
       HEAP32[$172>>2] = $171;
       $173 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 412|0);
       HEAPF32[$173>>2] = $147;
       $174 = HEAP32[$54>>2]|0;
       $175 = (($174) + 16|0);
       $176 = Math_fround(HEAPF32[$175>>2]);
       $177 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 428|0);
       HEAPF32[$177>>2] = $176;
       $178 = HEAP32[$54>>2]|0;
       $179 = (($178) + 20|0);
       $180 = Math_fround(HEAPF32[$179>>2]);
       $181 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 440|0);
       HEAPF32[$181>>2] = $180;
       $182 = HEAP32[$54>>2]|0;
       $183 = (($182) + 24|0);
       $184 = Math_fround(HEAPF32[$183>>2]);
       $185 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 444|0);
       HEAPF32[$185>>2] = $184;
       $187 = $iter;
      } else {
       $134 = (($123) + 64|0);
       $135 = HEAP16[$134>>1]|0;
       $136 = $135&65535;
       $137 = (($123) + 66|0);
       $138 = HEAP16[$137>>1]|0;
       $139 = $138&65535;
       $140 = $139 << 16;
       $141 = $140 | $136;
       $142 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 432|0);
       HEAP32[$142>>2] = $141;
       $143 = (($123) + 68|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 436|0);
       HEAP32[$145>>2] = $144;
       $146 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 412|0);
       HEAPF32[$146>>2] = $147;
       $148 = (($123) + 52|0);
       $149 = Math_fround(HEAPF32[$148>>2]);
       $150 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 428|0);
       HEAPF32[$150>>2] = $149;
       $151 = (($123) + 56|0);
       $152 = Math_fround(HEAPF32[$151>>2]);
       $153 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 440|0);
       HEAPF32[$153>>2] = $152;
       $154 = (($123) + 60|0);
       $155 = Math_fround(HEAPF32[$154>>2]);
       $156 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 444|0);
       HEAPF32[$156>>2] = $155;
       $157 = (($123) + 36|0);
       $187 = $157;
      }
      $186 = Math_fround(HEAPF32[$187>>2]);
      $188 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 416|0);
      HEAPF32[$188>>2] = $186;
      $189 = (($187) + 4|0);
      $190 = Math_fround(HEAPF32[$189>>2]);
      $191 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 420|0);
      HEAPF32[$191>>2] = $190;
      $192 = (($187) + 8|0);
      $193 = Math_fround(HEAPF32[$192>>2]);
      $194 = ((($threadContext) + ($numContacts$1$ph<<6)|0) + 424|0);
      HEAPF32[$194>>2] = $193;
      if ($71) {
       $201 = 0;
      } else {
       $195 = Math_fround(HEAPF32[$187>>2]);
       $196 = $195 == Math_fround(0.0);
       if ($196) {
        $197 = Math_fround(HEAPF32[$189>>2]);
        $198 = $197 == Math_fround(0.0);
        if ($198) {
         $199 = Math_fround(HEAPF32[$192>>2]);
         $phitmp = $199 != Math_fround(0.0);
         $201 = $phitmp;
        } else {
         $201 = 1;
        }
       } else {
        $201 = 1;
       }
      }
      $200 = $201&1;
      $202 = $$1$ph & 1;
      $203 = $202&255;
      $204 = $200 | $203;
      $205 = $204&255;
      $206 = (($numContacts$1$ph) + 1)|0;
      $$1$ph = $205;$93 = $327;$98 = $326;$numContacts$1$ph = $206;
     }
     $73 = HEAP32[$56>>2]|0;
     $74 = HEAP32[$28>>2]|0;
     $75 = $73;
     $76 = $74;
     $77 = (($75) - ($76))|0;
     $78 = ($77>>>0)<($22>>>0);
     if ($78) {
      $$0132 = $$1$ph;$315 = $318;$316 = $319;$317 = $94;$79 = $73;$81 = $74;$83 = $75;$numContacts$031 = $numContacts$1$ph;
     } else {
      break;
     }
    }
    HEAP32[$3>>2] = $numContacts$1$ph;
    $207 = $$1$ph & 1;
    $extract$t = ($207<<24>>24)!=(0);
    $208 = ($numContacts$1$ph|0)==(0);
    if (!($208)) {
     $211 = (($c) + 1792|0);
     HEAP32[$211>>2] = 0;
     $212 = (($c) + 1796|0);
     HEAP32[$212>>2] = 0;
     (__ZN5physx27createContactPatchesCoulombERNS_27PxcCorrelationBufferCoulombERNS_2Gu13ContactBufferEfj($c,$2,Math_fround(0.999000012874603271484),0)|0);
     $213 = ($frictionType|0)==(1);
     $214 = $213 ? 1 : 2;
     (__ZN5physx23correlatePatchesCoulombERNS_27PxcCorrelationBufferCoulombERKNS_2Gu13ContactBufferERKNS_11PxTransformES8_fjjj($c,$2,$bodyFrame0$0,$bodyFrame1$0,Math_fround(0.999000012874603271484),$214,0,0)|0);
     $n$idx$val = HEAP16[$12>>1]|0;
     $215 = HEAP32[$212>>2]|0;
     $216 = ($215|0)==(0);
     if ($216) {
      $axisConstraintCount$0$lcssa$i$i = 0;$solverConstraintByteSize$0$lcssa$i$i = 0;
     } else {
      $217 = $n$idx$val & 24;
      $218 = ($217<<16>>16)==(0);
      if ($218) {
       $axisConstraintCount$01$i$i = 0;$i$02$i$i = 0;$solverConstraintByteSize$04$i$i = 0;
       while(1) {
        $241 = ((($c) + ($i$02$i$i<<2)|0) + 1408|0);
        $242 = HEAP32[$241>>2]|0;
        $243 = ($242|0)==(0);
        if ($243) {
         $axisConstraintCount$1$i$i = $axisConstraintCount$01$i$i;$solverConstraintByteSize$1$i$i = $solverConstraintByteSize$04$i$i;
        } else {
         $244 = ((($c) + (($i$02$i$i*20)|0)|0) + 786|0);
         $245 = HEAP16[$244>>1]|0;
         $246 = $245 & 1;
         $247 = ($246<<16>>16)==(0);
         $248 = ($242*80)|0;
         $249 = (($242) + ($axisConstraintCount$01$i$i))|0;
         $250 = $242 << 2;
         $251 = (($250) + 12)|0;
         $252 = $251 & -16;
         $253 = (($solverConstraintByteSize$04$i$i) + 80)|0;
         $254 = (($253) + ($248))|0;
         $255 = (($254) + ($252))|0;
         if ($247) {
          $256 = ((($c) + (($i$02$i$i*20)|0)|0) + 784|0);
          $257 = HEAP16[$256>>1]|0;
          $258 = $257&65535;
          $259 = ($258*96)|0;
          $260 = (($259) + ($255))|0;
          $261 = (($258) + ($249))|0;
          $axisConstraintCount$1$i$i = $261;$solverConstraintByteSize$1$i$i = $260;
         } else {
          $axisConstraintCount$1$i$i = $249;$solverConstraintByteSize$1$i$i = $255;
         }
        }
        $262 = (($i$02$i$i) + 1)|0;
        $exitcond$i = ($262|0)==($215|0);
        if ($exitcond$i) {
         $axisConstraintCount$0$lcssa$i$i = $axisConstraintCount$1$i$i;$solverConstraintByteSize$0$lcssa$i$i = $solverConstraintByteSize$1$i$i;
         break;
        } else {
         $axisConstraintCount$01$i$i = $axisConstraintCount$1$i$i;$i$02$i$i = $262;$solverConstraintByteSize$04$i$i = $solverConstraintByteSize$1$i$i;
        }
       }
      } else {
       $axisConstraintCount$01$us$i$i = 0;$i$02$us$i$i = 0;$solverConstraintByteSize$04$us$i$i = 0;
       while(1) {
        $219 = ((($c) + ($i$02$us$i$i<<2)|0) + 1408|0);
        $220 = HEAP32[$219>>2]|0;
        $221 = ($220|0)==(0);
        if ($221) {
         $axisConstraintCount$1$us$i$i = $axisConstraintCount$01$us$i$i;$solverConstraintByteSize$1$us$i$i = $solverConstraintByteSize$04$us$i$i;
        } else {
         $222 = ((($c) + (($i$02$us$i$i*20)|0)|0) + 786|0);
         $223 = HEAP16[$222>>1]|0;
         $224 = $223 & 1;
         $225 = ($224<<16>>16)==(0);
         $226 = ($220*112)|0;
         $227 = (($220) + ($axisConstraintCount$01$us$i$i))|0;
         $228 = $220 << 2;
         $229 = (($228) + 12)|0;
         $230 = $229 & -16;
         $231 = (($solverConstraintByteSize$04$us$i$i) + 80)|0;
         $232 = (($231) + ($226))|0;
         $233 = (($232) + ($230))|0;
         if ($225) {
          $234 = ((($c) + (($i$02$us$i$i*20)|0)|0) + 784|0);
          $235 = HEAP16[$234>>1]|0;
          $236 = $235&65535;
          $237 = $236 << 7;
          $238 = (($237) + ($233))|0;
          $239 = (($236) + ($227))|0;
          $axisConstraintCount$1$us$i$i = $239;$solverConstraintByteSize$1$us$i$i = $238;
         } else {
          $axisConstraintCount$1$us$i$i = $227;$solverConstraintByteSize$1$us$i$i = $233;
         }
        }
        $240 = (($i$02$us$i$i) + 1)|0;
        $exitcond6$i = ($240|0)==($215|0);
        if ($exitcond6$i) {
         $axisConstraintCount$0$lcssa$i$i = $axisConstraintCount$1$us$i$i;$solverConstraintByteSize$0$lcssa$i$i = $solverConstraintByteSize$1$us$i$i;
         break;
        } else {
         $axisConstraintCount$01$us$i$i = $axisConstraintCount$1$us$i$i;$i$02$us$i$i = $240;$solverConstraintByteSize$04$us$i$i = $solverConstraintByteSize$1$us$i$i;
        }
       }
      }
     }
     $263 = $n$idx$val & 130;
     $264 = ($263<<16>>16)==(0);
     $solverConstraintByteSize$0$op$i$i = (($solverConstraintByteSize$0$lcssa$i$i) + 15)|0;
     $solverConstraintByteSize$0$op$op$i$i = $solverConstraintByteSize$0$op$i$i & -16;
     $265 = $264 ? 0 : $solverConstraintByteSize$0$op$op$i$i;
     $266 = ($265|0)==(0);
     if ($266) {
      $$$i8 = 0;$constraintBlock$04$i = 0;
     } else {
      $267 = (($threadContext) + 316|0);
      $268 = (($265) + 31)|0;
      $269 = $268 & -16;
      $270 = ($269>>>0)>(16384);
      do {
       if ($270) {
        $271 = HEAP32[$267>>2]|0;
        $272 = (__ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($271,$269)|0);
        $$0$i$i = $272;
       } else {
        $273 = (($threadContext) + 320|0);
        $274 = HEAP32[$273>>2]|0;
        $275 = ($274|0)==(0|0);
        $$pre$i$i = (($threadContext) + 324|0);
        if (!($275)) {
         $276 = HEAP32[$$pre$i$i>>2]|0;
         $277 = (($276) + ($269))|0;
         $278 = ($277>>>0)>(16384);
         if (!($278)) {
          $281 = (($274) + ($276)|0);
          HEAP32[$$pre$i$i>>2] = $277;
          $$0$i$i = $281;
          break;
         }
        }
        $279 = HEAP32[$267>>2]|0;
        $280 = (__ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($279,$constraintBlockManager)|0);
        HEAP32[$273>>2] = $280;
        HEAP32[$$pre$i$i>>2] = $269;
        $$0$i$i = $280;
       }
      } while(0);
      $282 = ($$0$i$i|0)==(0|0);
      $notlhs = ($$0$i$i|0)!=(0|0);
      $notrhs = ($$0$i$i|0)==((-1)|0);
      $not$or$cond3$i = $notrhs & $notlhs;
      $283 = $282 | $not$or$cond3$i;
      $$$0$i$i = $283 ? 0 : $$0$i$i;
      $phitmp4142 = ($$0$i$i|0)!=(0|0);
      $not$ = $283 ^ 1;
      $phitmp41 = $phitmp4142 & $not$;
      $$$i8 = $$$0$i$i;$constraintBlock$04$i = $phitmp41;
     }
     $$5$i = $266 | $constraintBlock$04$i;
     HEAP32[$4>>2] = 0;
     HEAP32[$n>>2] = 0;
     $284 = (($n) + 20|0);
     HEAP16[$284>>1] = 0;
     $285 = (($n) + 36|0);
     HEAP32[$285>>2] = 0;
     $286 = (($n) + 4|0);
     HEAP32[$286>>2] = 0;
     $287 = (($n) + 16|0);
     $288 = HEAP16[$287>>1]|0;
     $289 = $288&65535;
     $290 = (($289) + ($axisConstraintCount$0$lcssa$i$i))|0;
     $291 = $290&65535;
     HEAP16[$287>>1] = $291;
     if (!($$5$i)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$n>>2] = $$$i8;
     $292 = $numContacts$1$ph&65535;
     HEAP16[$284>>1] = $292;
     HEAP32[$286>>2] = $265;
     $293 = ($$$i8|0)==(0|0);
     if ($293) {
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
     $294 = HEAP16[$12>>1]|0;
     $295 = $294 & 24;
     $296 = ($295<<16>>16)==(0);
     if ($296) {
      $310 = (__ZN5physx37setupFinalizeSolverConstraintsCoulombERNS_13PxcNpWorkUnitERKNS_2Gu13ContactBufferERKNS_27PxcCorrelationBufferCoulombERKNS_11PxTransformESB_bPhRKNS_13PxcSolverBodyESF_RKNS_17PxcSolverBodyDataESI_ffjffff($n,$2,$c,$bodyFrame0$0,$bodyFrame1$0,$extract$t,$$$i8,$sBody0,$sBody1,$solverBodyData0,$solverBodyData1,$invDtF32,$bounceThresholdF32,$214,$305,$306,$307,$308)|0);
      $hasFriction$0$in = $310;
     } else {
      $297 = (($desc) + 8|0);
      $298 = HEAP16[$297>>1]|0;
      HEAP32[$b0>>2] = $sBody0;
      $299 = (($b0) + 4|0);
      HEAP32[$299>>2] = $solverBodyData0;
      $300 = (($b0) + 8|0);
      HEAP16[$300>>1] = $298;
      $301 = (($desc) + 12|0);
      $302 = HEAP16[$301>>1]|0;
      HEAP32[$b1>>2] = $sBody1;
      $303 = (($b1) + 4|0);
      HEAP32[$303>>2] = $solverBodyData1;
      $304 = (($b1) + 8|0);
      HEAP16[$304>>1] = $302;
      $309 = (__ZN5physx40setupFinalizeExtSolverConstraintsCoulombERNS_13PxcNpWorkUnitERKNS_2Gu13ContactBufferERKNS_27PxcCorrelationBufferCoulombERKNS_11PxTransformESB_bPhffRNS_16PxsSolverExtBodyESE_jffff($n,$2,$c,$bodyFrame0$0,$bodyFrame1$0,$extract$t,$$$i8,$invDtF32,$bounceThresholdF32,$b0,$b1,$214,$305,$306,$307,$308)|0);
      $hasFriction$0$in = $309;
     }
     $311 = (($$$i8) + ($265)|0);
     HEAP32[$311>>2] = 0;
     $312 = $hasFriction$0$in << 31 >> 31;
     $$sum20 = $265 | 4;
     $313 = (($$$i8) + ($$sum20)|0);
     HEAP32[$313>>2] = $312;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 HEAP32[$4>>2] = 0;
 $209 = (($n) + 36|0);
 HEAP32[$209>>2] = 0;
 $210 = (($n) + 20|0);
 HEAP16[$210>>1] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17PxcNpMemBlockPoolC2ERNS_19PxcScratchAllocatorE($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
 } else {
  $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__Z15PxGetFoundationv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
  $$$i$i$i$i = $11 ? 504976 : 504744;
  $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i$i,504896,111)|0);
  HEAP32[$this>>2] = $12;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($12);
  }
 }
 $14 = (($this) + 4|0);
 $15 = (($this) + 20|0);
 ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 24|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 28|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 32|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 36|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 40|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 44|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 48|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 52|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 56|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 60|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 64|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 68|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 72|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 76|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 80|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 84|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 88|0);
 $33 = (($this) + 152|0);
 $34 = (($this) + 168|0);
 dest=$32+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;
 HEAP32[$34>>2] = $allocator;
 $35 = (($this) + 172|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 176|0);
 HEAP32[$36>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool4initEjj($this,$initialBlockCount,$maxBlocks) {
 $this = $this|0;
 $initialBlockCount = $initialBlockCount|0;
 $maxBlocks = $maxBlocks|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 HEAP32[$0>>2] = $maxBlocks;
 $1 = (($this) + 148|0);
 HEAP32[$1>>2] = $initialBlockCount;
 $2 = ($initialBlockCount>>>0)<(64);
 $3 = $2 ? 64 : $initialBlockCount;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($6>>>0)<($3>>>0);
 if ($7) {
  $8 = (($this) + 4|0);
  __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE8recreateEj($8,$3);
 }
 $9 = (($this) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483632;
 $12 = ($11>>>0)<(16);
 if ($12) {
  $13 = (($this) + 100|0);
  __ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE8recreateEj($13,16);
 }
 $14 = (($this) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($3>>>0);
 if ($17) {
  $18 = (($this) + 40|0);
  __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE8recreateEj($18,$3);
 }
 $19 = (($this) + 60|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 2147483647;
 $22 = ($21>>>0)<($3>>>0);
 if ($22) {
  $23 = (($this) + 52|0);
  __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE8recreateEj($23,$3);
 }
 $24 = (($this) + 72|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26>>>0)<($3>>>0);
 if ($27) {
  $28 = (($this) + 64|0);
  __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE8recreateEj($28,$3);
 }
 $29 = (($this) + 84|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 2147483647;
 $32 = ($31>>>0)<($3>>>0);
 if ($32) {
  $33 = (($this) + 76|0);
  __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE8recreateEj($33,$3);
 }
 $34 = (($this) + 120|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35 & 2147483647;
 $37 = ($36>>>0)<($3>>>0);
 if (!($37)) {
  __ZN5physx17PxcNpMemBlockPool13setBlockCountEj($this,$initialBlockCount);
  STACKTOP = sp;return;
 }
 $38 = (($this) + 112|0);
 __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE8recreateEj($38,$3);
 __ZN5physx17PxcNpMemBlockPool13setBlockCountEj($this,$initialBlockCount);
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool13setBlockCountEj($this,$blockCount) {
 $this = $this|0;
 $blockCount = $blockCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = (($this) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)<($blockCount>>>0);
 if (!($5)) {
  $22 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
  STACKTOP = sp;return;
 }
 $6 = (($this) + 112|0);
 $7 = (($this) + 120|0);
 $8 = (($this) + 116|0);
 $9 = (($this) + 140|0);
 $i$01 = $4;
 while(1) {
  $10 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,16384,504560,100)|0);
  HEAP32[$1>>2] = $10;
  $11 = HEAP32[$7>>2]|0;
  $12 = $11 & 2147483647;
  $13 = HEAP32[$8>>2]|0;
  $14 = ($12>>>0)>($13>>>0);
  if ($14) {
   $15 = HEAP32[$6>>2]|0;
   $16 = (($15) + ($13<<2)|0);
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    HEAP32[$16>>2] = $10;
   }
   $18 = (($13) + 1)|0;
   HEAP32[$8>>2] = $18;
  } else {
   (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($6,$1)|0);
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($19) + 1)|0;
  HEAP32[$9>>2] = $20;
  $21 = (($i$01) + 1)|0;
  $exitcond = ($21|0)==($blockCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $21;
  }
 }
 $22 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
 STACKTOP = sp;return;
}
function __ZNK5physx17PxcNpMemBlockPool17getUsedBlockCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx17PxcNpMemBlockPool20getMaxUsedBlockCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx17PxcNpMemBlockPool27getPeakConstraintBlockCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 172|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx17PxcNpMemBlockPool19releaseUnusedBlocksEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $16 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($16);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 112|0);
 $6 = (($this) + 140|0);
 $8 = $3;
 while(1) {
  $7 = (($8) + -1)|0;
  $9 = HEAP32[$5>>2]|0;
  $10 = (($9) + ($7<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$2>>2] = $7;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
  $12 = HEAP32[$6>>2]|0;
  $13 = (($12) + -1)|0;
  HEAP32[$6>>2] = $13;
  $14 = HEAP32[$2>>2]|0;
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  } else {
   $8 = $14;
  }
 }
 $16 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($16);
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPoolD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i10 = 0, $or$cond$i$i2 = 0, $or$cond$i$i4 = 0, $or$cond$i$i4$1 = 0, $or$cond$i$i6 = 0, $or$cond$i$i6$1 = 0, $or$cond$i$i8 = 0, $or$cond$i$i8$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (1 - ($2))|0;
 $4 = ((($this) + (($3*12)|0)|0) + 40|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$4,0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (1 - ($5))|0;
 HEAP32[$1>>2] = $6;
 $7 = ((($this) + (($5*12)|0)|0) + 40|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = (1 - ($8))|0;
 HEAP32[$1>>2] = $9;
 $10 = (($this) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (1 - ($11))|0;
 $13 = ((($this) + (($12*12)|0)|0) + 64|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$13,0);
 $14 = HEAP32[$10>>2]|0;
 $15 = (1 - ($14))|0;
 HEAP32[$10>>2] = $15;
 $16 = ((($this) + (($14*12)|0)|0) + 64|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$16,0);
 $17 = HEAP32[$10>>2]|0;
 $18 = (1 - ($17))|0;
 HEAP32[$10>>2] = $18;
 __ZN5physx17PxcNpMemBlockPool23releaseConstraintMemoryEv($this);
 $19 = (($this) + 136|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (1 - ($20))|0;
 $22 = ((($this) + (($21*12)|0)|0) + 16|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$22,0);
 $23 = HEAP32[$19>>2]|0;
 $24 = (1 - ($23))|0;
 HEAP32[$19>>2] = $24;
 $25 = ((($this) + (($23*12)|0)|0) + 16|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$25,0);
 $26 = HEAP32[$19>>2]|0;
 $27 = (1 - ($26))|0;
 HEAP32[$19>>2] = $27;
 $28 = (($this) + 116|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = (($this) + 112|0);
  $33 = $29;
  while(1) {
   $32 = (($33) + -1)|0;
   $34 = HEAP32[$31>>2]|0;
   $35 = (($34) + ($32<<2)|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP32[$28>>2] = $32;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$36);
   $37 = HEAP32[$28>>2]|0;
   $38 = ($37|0)==(0);
   if ($38) {
    break;
   } else {
    $33 = $37;
   }
  }
 }
 $39 = (($this) + 120|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = $40 & 2147483647;
 $42 = ($41|0)!=(0);
 $43 = ($40|0)>(-1);
 $or$cond$i$i = $42 & $43;
 if ($or$cond$i$i) {
  $44 = (($this) + 112|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  if (!($46)) {
   $47 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   FUNCTION_TABLE_vii[$50 & 4095]($47,$45);
  }
 }
 $51 = (($this) + 108|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 & 2147483647;
 $54 = ($53|0)!=(0);
 $55 = ($52|0)>(-1);
 $or$cond$i$i1 = $54 & $55;
 if ($or$cond$i$i1) {
  $56 = (($this) + 100|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($60) + 12|0);
   $62 = HEAP32[$61>>2]|0;
   FUNCTION_TABLE_vii[$62 & 4095]($59,$57);
  }
 }
 $63 = (($this) + 96|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 & 2147483647;
 $66 = ($65|0)!=(0);
 $67 = ($64|0)>(-1);
 $or$cond$i$i2 = $66 & $67;
 if ($or$cond$i$i2) {
  $68 = (($this) + 88|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==(0|0);
  if (!($70)) {
   $71 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($72) + 12|0);
   $74 = HEAP32[$73>>2]|0;
   FUNCTION_TABLE_vii[$74 & 4095]($71,$69);
  }
 }
 $75 = (($this) + 84|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = $76 & 2147483647;
 $78 = ($77|0)!=(0);
 $79 = ($76|0)>(-1);
 $or$cond$i$i4 = $78 & $79;
 if ($or$cond$i$i4) {
  $80 = (($this) + 76|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)==(0|0);
  if (!($82)) {
   $83 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($84) + 12|0);
   $86 = HEAP32[$85>>2]|0;
   FUNCTION_TABLE_vii[$86 & 4095]($83,$81);
  }
 }
 $87 = (($this) + 72|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = $88 & 2147483647;
 $90 = ($89|0)!=(0);
 $91 = ($88|0)>(-1);
 $or$cond$i$i4$1 = $90 & $91;
 if ($or$cond$i$i4$1) {
  $154 = (($this) + 64|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = ($155|0)==(0|0);
  if (!($156)) {
   $157 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($158) + 12|0);
   $160 = HEAP32[$159>>2]|0;
   FUNCTION_TABLE_vii[$160 & 4095]($157,$155);
  }
 }
 $161 = (($this) + 60|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = $162 & 2147483647;
 $164 = ($163|0)!=(0);
 $165 = ($162|0)>(-1);
 $or$cond$i$i6 = $164 & $165;
 if ($or$cond$i$i6) {
  $92 = (($this) + 52|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = ($93|0)==(0|0);
  if (!($94)) {
   $95 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = (($96) + 12|0);
   $98 = HEAP32[$97>>2]|0;
   FUNCTION_TABLE_vii[$98 & 4095]($95,$93);
  }
 }
 $99 = (($this) + 48|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = $100 & 2147483647;
 $102 = ($101|0)!=(0);
 $103 = ($100|0)>(-1);
 $or$cond$i$i6$1 = $102 & $103;
 if ($or$cond$i$i6$1) {
  $142 = (($this) + 40|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ($143|0)==(0|0);
  if (!($144)) {
   $145 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = (($146) + 12|0);
   $148 = HEAP32[$147>>2]|0;
   FUNCTION_TABLE_vii[$148 & 4095]($145,$143);
  }
 }
 $149 = (($this) + 36|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = $150 & 2147483647;
 $152 = ($151|0)!=(0);
 $153 = ($150|0)>(-1);
 $or$cond$i$i8 = $152 & $153;
 if ($or$cond$i$i8) {
  $104 = (($this) + 28|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ($105|0)==(0|0);
  if (!($106)) {
   $107 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($108) + 12|0);
   $110 = HEAP32[$109>>2]|0;
   FUNCTION_TABLE_vii[$110 & 4095]($107,$105);
  }
 }
 $111 = (($this) + 24|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = $112 & 2147483647;
 $114 = ($113|0)!=(0);
 $115 = ($112|0)>(-1);
 $or$cond$i$i8$1 = $114 & $115;
 if ($or$cond$i$i8$1) {
  $130 = (($this) + 16|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ($131|0)==(0|0);
  if (!($132)) {
   $133 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 12|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_vii[$136 & 4095]($133,$131);
  }
 }
 $137 = (($this) + 12|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = $138 & 2147483647;
 $140 = ($139|0)!=(0);
 $141 = ($138|0)>(-1);
 $or$cond$i$i10 = $140 & $141;
 if ($or$cond$i$i10) {
  $116 = (($this) + 4|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = ($117|0)==(0|0);
  if (!($118)) {
   $119 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = (($120) + 12|0);
   $122 = HEAP32[$121>>2]|0;
   FUNCTION_TABLE_vii[$122 & 4095]($119,$117);
  }
 }
 $123 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($123);
 $124 = HEAP32[$this>>2]|0;
 $125 = ($124|0)==(0|0);
 if ($125) {
  STACKTOP = sp;return;
 }
 $126 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = (($127) + 12|0);
 $129 = HEAP32[$128>>2]|0;
 FUNCTION_TABLE_vii[$129 & 4095]($126,$124);
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool19swapFrictionStreamsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (1 - ($1))|0;
 $3 = ((($this) + (($2*12)|0)|0) + 40|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$3,0);
 $4 = HEAP32[$0>>2]|0;
 $5 = (1 - ($4))|0;
 HEAP32[$0>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool18swapNpCacheStreamsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (1 - ($1))|0;
 $3 = ((($this) + (($2*12)|0)|0) + 64|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$3,0);
 $4 = HEAP32[$0>>2]|0;
 $5 = (1 - ($4))|0;
 HEAP32[$0>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool23releaseConstraintMemoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $block = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$in$i = 0, $i$05 = 0, $it$02$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $block = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = (($this) + 176|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 172|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($this) + 4|0);
  $9 = (($this) + 168|0);
  $10 = (($this) + 112|0);
  $11 = (($this) + 120|0);
  $12 = (($this) + 116|0);
  $13 = (($this) + 152|0);
  $14 = (($this) + 88|0);
  $15 = (($this) + 96|0);
  $16 = (($this) + 92|0);
  $22 = $6;
  while(1) {
   $21 = (($22) + -1)|0;
   $23 = HEAP32[$8>>2]|0;
   $24 = (($23) + ($21<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$5>>2] = $21;
   HEAP32[$block>>2] = $25;
   $26 = HEAP32[$9>>2]|0;
   $27 = (($26) + 16|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28>>>0)>($25>>>0);
   do {
    if ($29) {
     label = 12;
    } else {
     $30 = (($26) + 20|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($28) + ($31)|0);
     $33 = ($32>>>0)>($25>>>0);
     if ($33) {
      $34 = HEAP32[$15>>2]|0;
      $35 = $34 & 2147483647;
      $36 = HEAP32[$16>>2]|0;
      $37 = ($35>>>0)>($36>>>0);
      if (!($37)) {
       (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($14,$block)|0);
       break;
      }
      $38 = HEAP32[$14>>2]|0;
      $39 = (($38) + ($36<<2)|0);
      $40 = ($39|0)==(0|0);
      if (!($40)) {
       HEAP32[$39>>2] = $25;
      }
      $41 = (($36) + 1)|0;
      HEAP32[$16>>2] = $41;
     } else {
      label = 12;
     }
    }
   } while(0);
   if ((label|0) == 12) {
    label = 0;
    $42 = HEAP32[$11>>2]|0;
    $43 = $42 & 2147483647;
    $44 = HEAP32[$12>>2]|0;
    $45 = ($43>>>0)>($44>>>0);
    if ($45) {
     $46 = HEAP32[$10>>2]|0;
     $47 = (($46) + ($44<<2)|0);
     $48 = ($47|0)==(0|0);
     if (!($48)) {
      HEAP32[$47>>2] = $25;
     }
     $49 = (($44) + 1)|0;
     HEAP32[$12>>2] = $49;
    } else {
     (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($10,$block)|0);
    }
    $50 = HEAP32[$13>>2]|0;
    $51 = (($50) + -1)|0;
    HEAP32[$13>>2] = $51;
   }
   $52 = HEAP32[$5>>2]|0;
   $53 = ($52|0)==(0);
   if ($53) {
    break;
   } else {
    $22 = $52;
   }
  }
 }
 $17 = (($this) + 104|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 if (!($19)) {
  $20 = (($this) + 100|0);
  $i$05 = 0;
  while(1) {
   $54 = HEAP32[$20>>2]|0;
   $55 = (($54) + ($i$05<<2)|0);
   $56 = HEAP32[$55>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$56);
   $57 = (($i$05) + 1)|0;
   $58 = HEAP32[$17>>2]|0;
   $59 = ($57>>>0)<($58>>>0);
   if ($59) {
    $i$05 = $57;
   } else {
    break;
   }
  }
 }
 HEAP32[$17>>2] = 0;
 $60 = (($this) + 92|0);
 HEAP32[$60>>2] = 0;
 $61 = (($this) + 160|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0|0);
 if ($63) {
  $92 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($92);
  STACKTOP = sp;return;
 }
 $64 = (($this) + 168|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + 16|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67>>>0)>($62>>>0);
 if ($68) {
  label = 23;
 } else {
  $69 = (($65) + 20|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($67) + ($70)|0);
  $72 = ($71>>>0)>($62>>>0);
  if ($72) {
   $73 = HEAP32[$65>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($73);
   $74 = (($65) + 8|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($65) + 4|0);
   $77 = HEAP32[$76>>2]|0;
   $i$0$in$i = $75;
   while(1) {
    $i$0$i = (($i$0$in$i) + -1)|0;
    $78 = (($77) + ($i$0$i<<2)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($79>>>0)<($62>>>0);
    if ($80) {
     $i$0$in$i = $i$0$i;
    } else {
     break;
    }
   }
   $81 = ($i$0$in$i>>>0)<($75>>>0);
   if ($81) {
    $85 = $i$0$in$i;$it$02$i$i = $78;
    while(1) {
     $82 = ($it$02$i$i|0)==(0|0);
     if (!($82)) {
      $83 = HEAP32[$76>>2]|0;
      $84 = (($83) + ($85<<2)|0);
      $86 = HEAP32[$84>>2]|0;
      HEAP32[$it$02$i$i>>2] = $86;
     }
     $87 = (($it$02$i$i) + 4|0);
     $88 = (($85) + 1)|0;
     $exitcond$i = ($88|0)==($75|0);
     if ($exitcond$i) {
      break;
     } else {
      $85 = $88;$it$02$i$i = $87;
     }
    }
   }
   $89 = (($75) + -1)|0;
   HEAP32[$74>>2] = $89;
   $90 = HEAP32[$65>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($90);
  } else {
   label = 23;
  }
 }
 if ((label|0) == 23) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$62);
 }
 HEAP32[$61>>2] = 0;
 $91 = (($this) + 164|0);
 HEAP32[$91>>2] = 0;
 $92 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($92);
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool15releaseContactsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (1 - ($1))|0;
 $3 = ((($this) + (($2*12)|0)|0) + 16|0);
 __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$3,0);
 $4 = HEAP32[$0>>2]|0;
 $5 = (1 - ($4))|0;
 HEAP32[$0>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool23acquireConstraintMemoryEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 168|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($3);
 $4 = (($2) + 4|0);
 $5 = (($2) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 $8 = HEAP32[$4>>2]|0;
 $9 = (($8) + ($7<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($2) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $10;
 $14 = $12;
 $15 = (($13) - ($14))|0;
 $16 = ($10|0)==($12|0);
 if ($16) {
  $$0$i = 0;
 } else {
  $17 = (($2) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 2147483647;
  $20 = ($19>>>0)>($6>>>0);
  if ($20) {
   $21 = (($8) + ($6<<2)|0);
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    HEAP32[$21>>2] = $12;
   }
   $23 = (($6) + 1)|0;
   HEAP32[$5>>2] = $23;
  } else {
   (__ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($4,$11)|0);
  }
  $24 = HEAP32[$11>>2]|0;
  $$0$i = $24;
 }
 $25 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($25);
 $26 = (($this) + 160|0);
 HEAP32[$26>>2] = $$0$i;
 $27 = $15 >>> 14;
 $28 = (($this) + 164|0);
 HEAP32[$28>>2] = $27;
 $29 = (($this) + 88|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($29,$27,$0);
 $30 = HEAP32[$28>>2]|0;
 $31 = ($30|0)==(0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $i$01 = 0;
 while(1) {
  $32 = HEAP32[$26>>2]|0;
  $33 = (($32) + ($i$01<<14)|0);
  $34 = HEAP32[$29>>2]|0;
  $35 = (($34) + ($i$01<<2)|0);
  HEAP32[$35>>2] = $33;
  $36 = (($i$01) + 1)|0;
  $37 = ($36>>>0)<($30>>>0);
  if ($37) {
   $i$01 = $36;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool7acquireERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPjS9_b($this,$trackingArray,$allocationCount,$peakAllocationCount,$isScratchAllocation) {
 $this = $this|0;
 $trackingArray = $trackingArray|0;
 $allocationCount = $allocationCount|0;
 $peakAllocationCount = $peakAllocationCount|0;
 $isScratchAllocation = $isScratchAllocation|0;
 var $$0 = 0, $$pre = 0, $$pre7 = 0, $$pre7$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $block = 0, $block1 = 0, $block2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $block = sp + 8|0;
 $block1 = sp;
 $block2 = sp + 4|0;
 $0 = sp + 12|0;
 $1 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = ($allocationCount|0)==(0|0);
 $3 = ($peakAllocationCount|0)==(0|0);
 $or$cond = $2 | $3;
 if (!($or$cond)) {
  $4 = HEAP32[$allocationCount>>2]|0;
  $5 = (($4) + 1)|0;
  $6 = HEAP32[$peakAllocationCount>>2]|0;
  $7 = ($5>>>0)<($6>>>0);
  $8 = $7 ? $6 : $5;
  HEAP32[$peakAllocationCount>>2] = $8;
  $9 = HEAP32[$allocationCount>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$allocationCount>>2] = $10;
 }
 if ($isScratchAllocation) {
  $11 = (($this) + 92|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if (!($13)) {
   $14 = (($12) + -1)|0;
   $15 = (($this) + 88|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($14<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$11>>2] = $14;
   HEAP32[$block>>2] = $18;
   $19 = (($trackingArray) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20 & 2147483647;
   $22 = (($trackingArray) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($21>>>0)>($23>>>0);
   if (!($24)) {
    (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($trackingArray,$block)|0);
    $$pre = HEAP32[$block>>2]|0;
    $$0 = $$pre;
    $81 = HEAP32[$this>>2]|0;
    __ZN5physx6shdfnd9MutexImpl6unlockEv($81);
    STACKTOP = sp;return ($$0|0);
   }
   $25 = HEAP32[$trackingArray>>2]|0;
   $26 = (($25) + ($23<<2)|0);
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    HEAP32[$26>>2] = $18;
   }
   $28 = (($23) + 1)|0;
   HEAP32[$22>>2] = $28;
   $$0 = $18;
   $81 = HEAP32[$this>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($81);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $29 = (($this) + 116|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if (!($31)) {
  $32 = (($30) + -1)|0;
  $33 = (($this) + 112|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($32<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$29>>2] = $32;
  HEAP32[$block1>>2] = $36;
  $37 = (($trackingArray) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38 & 2147483647;
  $40 = (($trackingArray) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($39>>>0)>($41>>>0);
  if ($42) {
   $43 = HEAP32[$trackingArray>>2]|0;
   $44 = (($43) + ($41<<2)|0);
   $45 = ($44|0)==(0|0);
   if (!($45)) {
    HEAP32[$44>>2] = $36;
   }
   $46 = (($41) + 1)|0;
   HEAP32[$40>>2] = $46;
   $82 = $36;
  } else {
   (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($trackingArray,$block1)|0);
   $$pre9 = HEAP32[$block1>>2]|0;
   $82 = $$pre9;
  }
  $47 = (($this) + 152|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 1)|0;
  $50 = (($this) + 156|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($49>>>0)<($51>>>0);
  $53 = $52 ? $51 : $49;
  HEAP32[$50>>2] = $53;
  HEAP32[$47>>2] = $49;
  $$0 = $82;
  $81 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($81);
  STACKTOP = sp;return ($$0|0);
 }
 $54 = (($this) + 140|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($this) + 144|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($55|0)==($57|0);
 if ($58) {
  $$0 = 0;
  $81 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($81);
  STACKTOP = sp;return ($$0|0);
 }
 $59 = (($55) + 1)|0;
 HEAP32[$54>>2] = $59;
 $60 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,16384,504560,235)|0);
 HEAP32[$block2>>2] = $60;
 $61 = ($60|0)==(0|0);
 if ($61) {
  $79 = HEAP32[$54>>2]|0;
  $80 = (($79) + -1)|0;
  HEAP32[$54>>2] = $80;
  $$0 = $60;
  $81 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($81);
  STACKTOP = sp;return ($$0|0);
 }
 $62 = (($trackingArray) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = $63 & 2147483647;
 $65 = (($trackingArray) + 4|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($64>>>0)>($66>>>0);
 if ($67) {
  $68 = HEAP32[$trackingArray>>2]|0;
  $69 = (($68) + ($66<<2)|0);
  $70 = ($69|0)==(0|0);
  if (!($70)) {
   HEAP32[$69>>2] = $60;
  }
  $71 = (($66) + 1)|0;
  HEAP32[$65>>2] = $71;
  $$pre7 = $60;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($trackingArray,$block2)|0);
  $$pre7$pre = HEAP32[$block2>>2]|0;
  $$pre7 = $$pre7$pre;
 }
 $72 = (($this) + 152|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73) + 1)|0;
 $75 = (($this) + 156|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($74>>>0)<($76>>>0);
 $78 = $77 ? $76 : $74;
 HEAP32[$75>>2] = $78;
 HEAP32[$72>>2] = $74;
 $$0 = $$pre7;
 $81 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($81);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17PxcNpMemBlockPool34acquireExceptionalConstraintMemoryEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $memory = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $memory = sp;
 $0 = sp + 4|0;
 $1 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$size,504560,251)|0);
 HEAP32[$memory>>2] = $1;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $16 = 0;
  STACKTOP = sp;return ($16|0);
 }
 $3 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($3);
 $4 = (($this) + 100|0);
 $5 = (($this) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = (($this) + 104|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  $11 = HEAP32[$4>>2]|0;
  $12 = (($11) + ($9<<2)|0);
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   HEAP32[$12>>2] = $1;
  }
  $14 = (($9) + 1)|0;
  HEAP32[$8>>2] = $14;
  $$pre = $1;
 } else {
  (__ZN5physx6shdfnd5ArrayIPhNS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($4,$memory)|0);
  $$pre$pre = HEAP32[$memory>>2]|0;
  $$pre = $$pre$pre;
 }
 $15 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($15);
 $16 = $$pre;
 STACKTOP = sp;return ($16|0);
}
function __ZN5physx17PxcNpMemBlockPool7releaseERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPj($this,$deadArray,$allocationCount) {
 $this = $this|0;
 $deadArray = $deadArray|0;
 $allocationCount = $allocationCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $block = sp;
 $0 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($0);
 $1 = (($deadArray) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) - ($2))|0;
 HEAP32[$3>>2] = $5;
 $6 = ($allocationCount|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$1>>2]|0;
  $8 = HEAP32[$allocationCount>>2]|0;
  $9 = (($8) - ($7))|0;
  HEAP32[$allocationCount>>2] = $9;
 }
 $10 = HEAP32[$1>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $30 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($30);
  STACKTOP = sp;return;
 }
 $12 = (($this) + 112|0);
 $13 = (($this) + 116|0);
 $14 = (($this) + 120|0);
 $16 = $10;
 while(1) {
  $15 = (($16) + -1)|0;
  $17 = HEAP32[$deadArray>>2]|0;
  $18 = (($17) + ($15<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$1>>2] = $15;
  HEAP32[$block>>2] = $19;
  $20 = HEAP32[$13>>2]|0;
  $21 = (($20) + 1)|0;
  $22 = HEAP32[$14>>2]|0;
  $23 = $22 & 2147483647;
  $24 = ($23>>>0)>($20>>>0);
  if ($24) {
   $27 = HEAP32[$12>>2]|0;
   $28 = (($27) + ($20<<2)|0);
   $29 = ($28|0)==(0|0);
   if (!($29)) {
    HEAP32[$28>>2] = $19;
   }
   HEAP32[$13>>2] = $21;
  } else {
   (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($12,$block)|0);
  }
  $25 = HEAP32[$1>>2]|0;
  $26 = ($25|0)==(0);
  if ($26) {
   break;
  } else {
   $16 = $25;
  }
 }
 $30 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($30);
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool22acquireConstraintBlockERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($this,$memBlocks) {
 $this = $this|0;
 $memBlocks = $memBlocks|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 176|0);
 $1 = (($this) + 172|0);
 $2 = (__ZN5physx17PxcNpMemBlockPool7acquireERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPjS9_b($this,$memBlocks,$0,$1,1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx17PxcNpMemBlockPool19acquireContactBlockEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($this) + (($1*12)|0)|0) + 16|0);
 $3 = (__ZN5physx17PxcNpMemBlockPool7acquireERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPjS9_b($this,$2,0,0,1)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx17PxcNpMemBlockPool23releaseConstraintBlocksERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEE($this,$memBlocks) {
 $this = $this|0;
 $memBlocks = $memBlocks|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $block = sp;
 $0 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($0);
 $1 = (($memBlocks) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $45 = HEAP32[$this>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($45);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 168|0);
 $5 = (($this) + 112|0);
 $6 = (($this) + 120|0);
 $7 = (($this) + 116|0);
 $8 = (($this) + 152|0);
 $9 = (($this) + 88|0);
 $10 = (($this) + 96|0);
 $11 = (($this) + 92|0);
 $13 = $2;
 while(1) {
  $12 = (($13) + -1)|0;
  $14 = HEAP32[$memBlocks>>2]|0;
  $15 = (($14) + ($12<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$1>>2] = $12;
  HEAP32[$block>>2] = $16;
  $17 = HEAP32[$4>>2]|0;
  $18 = (($17) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19>>>0)>($16>>>0);
  do {
   if ($20) {
    label = 10;
   } else {
    $21 = (($17) + 20|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($19) + ($22)|0);
    $24 = ($23>>>0)>($16>>>0);
    if ($24) {
     $25 = HEAP32[$10>>2]|0;
     $26 = $25 & 2147483647;
     $27 = HEAP32[$11>>2]|0;
     $28 = ($26>>>0)>($27>>>0);
     if (!($28)) {
      (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($9,$block)|0);
      break;
     }
     $29 = HEAP32[$9>>2]|0;
     $30 = (($29) + ($27<<2)|0);
     $31 = ($30|0)==(0|0);
     if (!($31)) {
      HEAP32[$30>>2] = $16;
     }
     $32 = (($27) + 1)|0;
     HEAP32[$11>>2] = $32;
    } else {
     label = 10;
    }
   }
  } while(0);
  if ((label|0) == 10) {
   label = 0;
   $33 = HEAP32[$6>>2]|0;
   $34 = $33 & 2147483647;
   $35 = HEAP32[$7>>2]|0;
   $36 = ($34>>>0)>($35>>>0);
   if ($36) {
    $37 = HEAP32[$5>>2]|0;
    $38 = (($37) + ($35<<2)|0);
    $39 = ($38|0)==(0|0);
    if (!($39)) {
     HEAP32[$38>>2] = $16;
    }
    $40 = (($35) + 1)|0;
    HEAP32[$7>>2] = $40;
   } else {
    (__ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($5,$block)|0);
   }
   $41 = HEAP32[$8>>2]|0;
   $42 = (($41) + -1)|0;
   HEAP32[$8>>2] = $42;
  }
  $43 = HEAP32[$1>>2]|0;
  $44 = ($43|0)==(0);
  if ($44) {
   break;
  } else {
   $13 = $43;
  }
 }
 $45 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($45);
 STACKTOP = sp;return;
}
function __ZN5physx17PxcNpMemBlockPool20acquireFrictionBlockEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($this) + (($1*12)|0)|0) + 40|0);
 $3 = (__ZN5physx17PxcNpMemBlockPool7acquireERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPjS9_b($this,$2,0,0,0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx17PxcNpMemBlockPool19acquireNpCacheBlockEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($this) + (($1*12)|0)|0) + 64|0);
 $3 = (__ZN5physx17PxcNpMemBlockPool7acquireERNS_6shdfnd5ArrayIPNS_13PxcNpMemBlockENS1_19ReflectionAllocatorIS4_EEEEPjS9_b($this,$2,0,0,0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 504776 : 504744;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,504664,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_13PxcNpMemBlockENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 504776 : 504744;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,504664,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx18PxcNpThreadContextC2EfffRKNS_2Cm12RenderOutputERNS_17PxcNpMemBlockPoolEb($this,$meshContactMargin,$correlationDist,$toleranceLength,$renderOutput,$memBlockPool,$createContacts) {
 $this = $this|0;
 $meshContactMargin = Math_fround($meshContactMargin);
 $correlationDist = Math_fround($correlationDist);
 $toleranceLength = Math_fround($toleranceLength);
 $renderOutput = $renderOutput|0;
 $memBlockPool = $memBlockPool|0;
 $createContacts = $createContacts|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0);
 var $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0);
 var $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0);
 var $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $renderOutput;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $this;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 $10 = (($this) + 8|0);
 $11 = (($renderOutput) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$10>>2] = $12;
 $13 = (($this) + 12|0);
 $14 = (($renderOutput) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$13>>2] = $15;
 $16 = (($this) + 16|0);
 $17 = (($renderOutput) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $18;
 $19 = (($this) + 20|0);
 $20 = (($renderOutput) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 $22 = (($this) + 24|0);
 $23 = (($renderOutput) + 24|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$22>>2] = $24;
 $25 = (($this) + 28|0);
 $26 = (($renderOutput) + 28|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($this) + 32|0);
 $29 = (($renderOutput) + 32|0);
 $30 = HEAP32[$29>>2]|0;
 HEAP32[$28>>2] = $30;
 $31 = (($this) + 36|0);
 $32 = (($renderOutput) + 36|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($this) + 40|0);
 $35 = (($renderOutput) + 40|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 $37 = (($this) + 44|0);
 $38 = (($renderOutput) + 44|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$37>>2] = $39;
 $40 = (($this) + 48|0);
 $41 = (($renderOutput) + 48|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$40>>2] = $42;
 $43 = (($this) + 52|0);
 $44 = (($renderOutput) + 52|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 HEAPF32[$43>>2] = $45;
 $46 = (($this) + 56|0);
 $47 = (($renderOutput) + 56|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$46>>2] = $48;
 $49 = (($this) + 60|0);
 $50 = (($renderOutput) + 60|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$49>>2] = $51;
 $52 = (($this) + 64|0);
 $53 = (($renderOutput) + 64|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 HEAPF32[$52>>2] = $54;
 $55 = (($this) + 68|0);
 $56 = (($renderOutput) + 68|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 HEAPF32[$55>>2] = $57;
 $58 = (($this) + 72|0);
 $59 = (($renderOutput) + 72|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 HEAPF32[$58>>2] = $60;
 $61 = (($this) + 76|0);
 $62 = (($renderOutput) + 76|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 HEAPF32[$61>>2] = $63;
 $64 = (($this) + 80|0);
 $65 = (($renderOutput) + 80|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 HEAPF32[$64>>2] = $66;
 $67 = (($this) + 84|0);
 $68 = (($renderOutput) + 84|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 HEAPF32[$67>>2] = $69;
 $70 = (($this) + 88|0);
 $71 = (($renderOutput) + 88|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 HEAPF32[$70>>2] = $72;
 $73 = (($this) + 92|0);
 $74 = (($renderOutput) + 92|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 HEAPF32[$73>>2] = $75;
 $76 = (($this) + 96|0);
 $77 = (($renderOutput) + 96|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 HEAPF32[$76>>2] = $78;
 $79 = (($this) + 100|0);
 $80 = (($renderOutput) + 100|0);
 $81 = HEAP32[$80>>2]|0;
 HEAP32[$79>>2] = $81;
 $82 = (($this) + 300|0);
 HEAP32[$82>>2] = 0;
 $83 = (($this) + 304|0);
 HEAP32[$83>>2] = 0;
 $84 = (($this) + 308|0);
 HEAP32[$84>>2] = 0;
 $85 = (($this) + 312|0);
 HEAP32[$85>>2] = $memBlockPool;
 $86 = (($this) + 316|0);
 HEAP32[$86>>2] = $memBlockPool;
 $87 = (($this) + 320|0);
 HEAP32[$87>>2] = 0;
 $88 = (($this) + 324|0);
 HEAP32[$88>>2] = 0;
 $89 = (($this) + 332|0);
 HEAP32[$89>>2] = $memBlockPool;
 $90 = (($this) + 336|0);
 HEAP32[$90>>2] = 0;
 $91 = (($this) + 340|0);
 HEAP32[$91>>2] = 0;
 $92 = (($this) + 344|0);
 __ZN5physx26PxcFrictionPatchStreamPairC2ERNS_17PxcNpMemBlockPoolE($92,$memBlockPool);
 $93 = (($this) + 356|0);
 __ZN5physx20PxcNpCacheStreamPairC2ERNS_17PxcNpMemBlockPoolE($93,$memBlockPool);
 $94 = (($this) + 8736|0);
 HEAP32[$94>>2] = 0;
 $95 = (($this) + 8740|0);
 HEAP32[$95>>2] = 0;
 $96 = (($this) + 8744|0);
 HEAP32[$96>>2] = 0;
 $97 = (($this) + 8760|0);
 HEAP32[$97>>2] = 0;
 $98 = (($this) + 8768|0);
 HEAP8[$98>>0] = 0;
 $99 = (($this) + 8769|0);
 HEAP8[$99>>0] = 0;
 $100 = (($this) + 8770|0);
 $101 = $createContacts&1;
 HEAP8[$100>>0] = $101;
 $102 = (($this) + 8771|0);
 HEAP8[$102>>0] = 0;
 $103 = (($this) + 8772|0);
 $104 = (($this) + 8776|0);
 $105 = (($this) + 8780|0);
 HEAPF32[$105>>2] = $toleranceLength;
 $106 = (($this) + 8784|0);
 HEAPF32[$106>>2] = $correlationDist;
 $107 = (($this) + 4484|0);
 HEAPF32[$107>>2] = $meshContactMargin;
 $108 = (($this) + 104|0);
 _memset(($108|0),0,196)|0;
 HEAP32[$103>>2] = 0;
 HEAP32[$104>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18PxcNpThreadContext10clearStatsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 _memset(($0|0),0,196)|0;
 $1 = (($this) + 8772|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8776|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18PxcNpThreadContextD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8744|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 8736|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 308|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i$i$i = $15 & $16;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 300|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
 STACKTOP = sp;return;
}
function __Z17PxcPoolMallocInitv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,892,505104,84)|0);
 HEAP32[505200>>2] = $1;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN17PxcPoolMallocDataC2Ev($1);
 STACKTOP = sp;return;
}
function __Z17PxcPoolMallocTermv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[505200>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 596|0);
 __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData10PoolData32ENS0_19ReflectionAllocatorIS3_EEED2Ev($3);
 $4 = (($1) + 300|0);
 __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData10PoolData16ENS0_19ReflectionAllocatorIS3_EEED2Ev($4);
 $5 = (($1) + 4|0);
 __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData9PoolData8ENS0_19ReflectionAllocatorIS3_EEED2Ev($5);
 $6 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($6);
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 4095]($9,$7);
 }
 $13 = HEAP32[505200>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$13);
 HEAP32[505200>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData32EEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 505320 : 505288;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,505456,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 505320 : 505288;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,505456,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData32EEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 505320 : 505288;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,505208,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData16EEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 505544 : 505288;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,505456,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 505544 : 505288;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,505456,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData16EEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 505544 : 505288;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,505208,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData9PoolData8EEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$ph = 0, $$ph$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $$ph19 = 0, $$ph19$be = 0, $$ph20 = 0, $$ph20$be = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0;
 var $m$01$i = 0, $or$cond = 0, $or$cond8 = 0, $or$cond9 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $$ph = 0;$$ph16 = $5;$$ph17 = 32;$$ph18 = 0;$$ph19 = 0;$$ph20 = $6;
  L2: while(1) {
   $10 = $$ph19;$58 = $$ph18;$9 = $$ph20;
   while(1) {
    $8 = ($9|0)>($10|0);
    if ($8) {
     $11 = (($9) - ($10))|0;
     $12 = ($11>>>0)<(5);
     if ($12) {
      $i$03$i = $10;
     } else {
      break;
     }
     while(1) {
      $13 = (($i$03$i) + 1)|0;
      $j$02$i = $13;$m$01$i = $i$03$i;
      while(1) {
       $14 = (($elements) + ($j$02$i<<2)|0);
       $15 = (($elements) + ($m$01$i<<2)|0);
       $16 = HEAP32[$14>>2]|0;
       $17 = HEAP32[$15>>2]|0;
       $18 = ($16>>>0)<($17>>>0);
       $j$0$m$0$i = $18 ? $j$02$i : $m$01$i;
       $19 = (($j$02$i) + 1)|0;
       $20 = ($j$02$i|0)<($9|0);
       if ($20) {
        $j$02$i = $19;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $21 = (($elements) + ($j$0$m$0$i<<2)|0);
      $22 = (($elements) + ($i$03$i<<2)|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = HEAP32[$22>>2]|0;
      HEAP32[$21>>2] = $24;
      HEAP32[$22>>2] = $23;
      $exitcond$i = ($13|0)==($9|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $13;
      }
     }
    }
    $113 = ($58|0)==(0);
    if ($113) {
     break L2;
    }
    $114 = (($58) + -1)|0;
    $115 = (($$ph16) + ($114<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($58) + -2)|0;
    $118 = (($$ph16) + ($117<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $10 = $119;$58 = $117;$9 = $116;
   }
   $25 = (($9) + ($10))|0;
   $26 = (($25|0) / 2)&-1;
   $27 = (($elements) + ($26<<2)|0);
   $28 = (($elements) + ($10<<2)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = HEAP32[$28>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    HEAP32[$28>>2] = $29;
    HEAP32[$27>>2] = $30;
    $$pre$i$i = HEAP32[$28>>2]|0;
    $129 = $30;$35 = $$pre$i$i;
   } else {
    $129 = $29;$35 = $30;
   }
   $32 = (($elements) + ($9<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33>>>0)<($35>>>0);
   if ($34) {
    HEAP32[$28>>2] = $33;
    HEAP32[$32>>2] = $35;
    $$pre1$i$i = HEAP32[$27>>2]|0;
    $37 = $35;$38 = $$pre1$i$i;
   } else {
    $37 = $33;$38 = $129;
   }
   $36 = ($37>>>0)<($38>>>0);
   if ($36) {
    HEAP32[$27>>2] = $37;
    HEAP32[$32>>2] = $38;
    $$pre2$i$i = HEAP32[$27>>2]|0;
    $42 = $$pre2$i$i;
   } else {
    $42 = $38;
   }
   $39 = (($9) + -1)|0;
   $40 = (($elements) + ($39<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$27>>2] = $41;
   HEAP32[$40>>2] = $42;
   $47 = $42;$i$0$ph$i = $10;$j$0$ph$i = $39;
   while(1) {
    $i$0$i = $i$0$ph$i;
    while(1) {
     $43 = (($i$0$i) + 1)|0;
     $44 = (($elements) + ($43<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($47>>>0);
     if ($46) {
      $i$0$i = $43;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $48 = (($j$1$i) + -1)|0;
     $49 = (($elements) + ($48<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($47>>>0)<($50>>>0);
     if ($51) {
      $j$1$i = $48;
     } else {
      break;
     }
    }
    $52 = ($43|0)<($48|0);
    if (!($52)) {
     break;
    }
    HEAP32[$44>>2] = $50;
    HEAP32[$49>>2] = $45;
    $$pre$i1 = HEAP32[$40>>2]|0;
    $47 = $$pre$i1;$i$0$ph$i = $43;$j$0$ph$i = $48;
   }
   HEAP32[$44>>2] = $47;
   HEAP32[$40>>2] = $45;
   $53 = (($43) - ($10))|0;
   $54 = (($9) - ($43))|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($$ph17) + -1)|0;
    $57 = ($58>>>0)<($56>>>0);
    if ($57) {
     $130 = $$ph;$131 = $$ph17;$82 = $$ph16;
    } else {
     $59 = $$ph17 << 1;
     $60 = $$ph17 << 3;
     $61 = ($60|0)==(0);
     if ($61) {
      $73 = 0;
     } else {
      $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (__Z15PxGetFoundationv()|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (FUNCTION_TABLE_ii[$69 & 4095]($66)|0);
      $$$i$i$i4 = $70 ? 505680 : 505288;
      $71 = (FUNCTION_TABLE_iiiiii[$65 & 255]($62,$60,$$$i$i$i4,505456,148)|0);
      $73 = $71;
     }
     $72 = $58 << 2;
     _memcpy(($73|0),($$ph16|0),($72|0))|0;
     $74 = ($$ph<<24>>24)==(0);
     $75 = ($$ph16|0)==(0|0);
     $or$cond = $74 | $75;
     if ($or$cond) {
      $130 = 1;$131 = $59;$82 = $73;
     } else {
      $76 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      FUNCTION_TABLE_vii[$79 & 4095]($76,$$ph16);
      $130 = 1;$131 = $59;$82 = $73;
     }
    }
    $80 = (($58) + 1)|0;
    $81 = (($82) + ($58<<2)|0);
    HEAP32[$81>>2] = $10;
    $83 = (($82) + ($80<<2)|0);
    HEAP32[$83>>2] = $i$0$i;
    $84 = (($i$0$i) + 2)|0;
    $$ph$be = $130;$$ph16$be = $82;$$ph17$be = $131;$$ph19$be = $84;$$ph20$be = $9;
   } else {
    $85 = (($i$0$i) + 2)|0;
    $86 = (($$ph17) + -1)|0;
    $87 = ($58>>>0)<($86>>>0);
    if ($87) {
     $111 = $$ph16;$132 = $$ph;$133 = $$ph17;
    } else {
     $88 = $$ph17 << 1;
     $89 = $$ph17 << 3;
     $90 = ($89|0)==(0);
     if ($90) {
      $102 = 0;
     } else {
      $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 8|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (__Z15PxGetFoundationv()|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
      $$$i$i$i = $99 ? 505680 : 505288;
      $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,$89,$$$i$i$i,505456,148)|0);
      $102 = $100;
     }
     $101 = $58 << 2;
     _memcpy(($102|0),($$ph16|0),($101|0))|0;
     $103 = ($$ph<<24>>24)==(0);
     $104 = ($$ph16|0)==(0|0);
     $or$cond8 = $103 | $104;
     if ($or$cond8) {
      $111 = $102;$132 = 1;$133 = $88;
     } else {
      $105 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = (($106) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      FUNCTION_TABLE_vii[$108 & 4095]($105,$$ph16);
      $111 = $102;$132 = 1;$133 = $88;
     }
    }
    $109 = (($58) + 1)|0;
    $110 = (($111) + ($58<<2)|0);
    HEAP32[$110>>2] = $85;
    $112 = (($111) + ($109<<2)|0);
    HEAP32[$112>>2] = $9;
    $$ph$be = $132;$$ph16$be = $111;$$ph17$be = $133;$$ph19$be = $10;$$ph20$be = $i$0$i;
   }
   $$ph18$be = (($58) + 2)|0;
   $$ph = $$ph$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;$$ph19 = $$ph19$be;$$ph20 = $$ph20$be;
  }
  $120 = ($$ph<<24>>24)==(0);
  $121 = ($$ph16|0)==(0|0);
  $or$cond9 = $120 | $121;
  if (!($or$cond9)) {
   $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   FUNCTION_TABLE_vii[$125 & 4095]($122,$$ph16);
  }
 }
 $126 = HEAP8[$4>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  STACKTOP = sp;return;
 }
 $128 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$128);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIN17PxcPoolMallocData9PoolData8EEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 505680 : 505288;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,505208,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData9PoolData8ENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData9PoolData8ENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData9PoolData8ENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIN17PxcPoolMallocData9PoolData8EEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData9PoolData8EEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData9PoolData8EEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<3)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 8|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData10PoolData16ENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData10PoolData16ENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData10PoolData16ENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData16EEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData16EEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData16EEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<4)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 16|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData10PoolData32ENS0_19ReflectionAllocatorIS3_EEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i = 0, $slabIt$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData10PoolData32ENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this);
 }
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $slabIt$01 = $4;
  while(1) {
   $9 = HEAP32[$slabIt$01>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_vii[$14 & 4095]($11,$9);
   }
   $15 = (($slabIt$01) + 4|0);
   $16 = ($15|0)==($7|0);
   if ($16) {
    break;
   } else {
    $slabIt$01 = $15;
   }
  }
 }
 $17 = (($this) + 272|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 2147483647;
 $20 = ($19|0)!=(0);
 $21 = ($18|0)>(-1);
 $or$cond$i$i$i = $20 & $21;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$3>>2]|0;
 $23 = (($this) + 4|0);
 $24 = ($23|0)==($22|0);
 if ($24) {
  $25 = (($this) + 260|0);
  HEAP8[$25>>0] = 0;
  STACKTOP = sp;return;
 }
 $26 = ($22|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($27,$22);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8PoolBaseIN17PxcPoolMallocData10PoolData32ENS0_19ReflectionAllocatorIS3_EEE15disposeElementsEv($this) {
 $this = $this|0;
 var $$freeIt$1 = 0, $$pre = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $freeIt$03 = 0, $freeIt$1$lcssa = 0, $freeIt$11 = 0, $freeIt$2 = 0, $freeNodes = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$i$not = 0, $phitmp = 0, $slabIt$04 = 0, $tIt$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $freeNodes = sp + 4|0;
 $0 = sp;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 HEAP32[$freeNodes>>2] = 0;
 $3 = (($freeNodes) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($freeNodes) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $19 = 0;$20 = 0;
 } else {
  $10 = 0;$11 = 0;$8 = $6;
  while(1) {
   HEAP32[$0>>2] = $8;
   $9 = ($10>>>0)>($11>>>0);
   if ($9) {
    $12 = HEAP32[$freeNodes>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     HEAP32[$13>>2] = $8;
    }
    $15 = (($11) + 1)|0;
    HEAP32[$3>>2] = $15;
   } else {
    (__ZN5physx6shdfnd5ArrayIPvNS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData32EEEE15growAndPushBackERKS2_($freeNodes,$0)|0);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$5>>2] = $17;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
   $$pre13 = HEAP32[$4>>2]|0;
   $$pre14 = HEAP32[$3>>2]|0;
   $phitmp = $$pre13 & 2147483647;
   $10 = $phitmp;$11 = $$pre14;$8 = $17;
  }
  $$pre = HEAP32[$freeNodes>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $19 = $$pre;$20 = $$pre11;
 }
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData32EEEEEvPT_jRKT0_RKT1_($19,$20,$1,$this);
 $21 = (($this) + 264|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 268|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd4sortIPvNS0_4LessIS2_EENS0_19ReflectionAllocatorIN17PxcPoolMallocData10PoolData32EEEEEvPT_jRKT0_RKT1_($22,$24,$2,$this);
 $25 = HEAP32[$21>>2]|0;
 $26 = HEAP32[$23>>2]|0;
 $27 = (($25) + ($26<<2)|0);
 $28 = ($26|0)==(0);
 if (!($28)) {
  $29 = (($this) + 276|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($19) + ($20<<2)|0);
  $freeIt$03 = $19;$slabIt$04 = $25;
  while(1) {
   $32 = HEAP32[$slabIt$04>>2]|0;
   $33 = (($32) + ($30<<5)|0);
   $34 = ($32|0)==($33|0);
   if ($34) {
    $freeIt$1$lcssa = $freeIt$03;
   } else {
    $freeIt$11 = $freeIt$03;$tIt$02 = $32;
    while(1) {
     $35 = ($freeIt$11|0)==($31|0);
     if ($35) {
      $freeIt$2 = $31;
     } else {
      $36 = HEAP32[$freeIt$11>>2]|0;
      $37 = ($36|0)==($tIt$02|0);
      $38 = (($freeIt$11) + 4|0);
      $$freeIt$1 = $37 ? $38 : $freeIt$11;
      $freeIt$2 = $$freeIt$1;
     }
     $39 = (($tIt$02) + 32|0);
     $40 = ($39|0)==($33|0);
     if ($40) {
      $freeIt$1$lcssa = $freeIt$2;
      break;
     } else {
      $freeIt$11 = $freeIt$2;$tIt$02 = $39;
     }
    }
   }
   $41 = (($slabIt$04) + 4|0);
   $42 = ($41|0)==($27|0);
   if ($42) {
    break;
   } else {
    $freeIt$03 = $freeIt$1$lcssa;$slabIt$04 = $41;
   }
  }
 }
 $43 = HEAP32[$4>>2]|0;
 $44 = $43 & 2147483647;
 $notlhs = ($44|0)==(0);
 $notrhs = ($43|0)<(0);
 $or$cond$i$i$not = $notrhs | $notlhs;
 $45 = ($19|0)==(0|0);
 $or$cond = $or$cond$i$i$not | $45;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $46 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($46,$19);
 STACKTOP = sp;return;
}
function __ZN17PxcPoolMallocDataC2Ev($this) {
 $this = $this|0;
 var $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
 } else {
  $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__Z15PxGetFoundationv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
  $$$i$i$i$i = $11 ? 505896 : 505288;
  $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i$i,505816,111)|0);
  HEAP32[$this>>2] = $12;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($12);
  }
 }
 $14 = (($this) + 8|0);
 $15 = (($this) + 264|0);
 $16 = (($this) + 268|0);
 $17 = (($this) + 272|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 276|0);
 HEAP8[$15>>0] = 1;
 HEAP32[$16>>2] = $14;
 HEAP32[$18>>2] = 64;
 $19 = (($this) + 280|0);
 HEAP32[$19>>2] = 512;
 $20 = (($this) + 284|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 288|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 292|0);
 HEAP32[$22>>2] = 4096;
 $23 = (($this) + 296|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 304|0);
 $25 = (($this) + 560|0);
 $26 = (($this) + 564|0);
 $27 = (($this) + 568|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 572|0);
 HEAP8[$25>>0] = 1;
 HEAP32[$26>>2] = $24;
 HEAP32[$28>>2] = 64;
 $29 = (($this) + 576|0);
 HEAP32[$29>>2] = 256;
 $30 = (($this) + 580|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 584|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 588|0);
 HEAP32[$32>>2] = 4096;
 $33 = (($this) + 592|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 600|0);
 $35 = (($this) + 856|0);
 $36 = (($this) + 860|0);
 $37 = (($this) + 864|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 868|0);
 HEAP8[$35>>0] = 1;
 HEAP32[$36>>2] = $34;
 HEAP32[$38>>2] = 64;
 $39 = (($this) + 872|0);
 HEAP32[$39>>2] = 128;
 $40 = (($this) + 876|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 880|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 884|0);
 HEAP32[$42>>2] = 4096;
 $43 = (($this) + 888|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPrunerC2Eb($this,$incrementalRebuild) {
 $this = $this|0;
 $incrementalRebuild = $incrementalRebuild|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((506024 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 1;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 2147483647;
 $3 = (($this) + 16|0);
 $4 = (($this) + 56|0);
 $5 = (($this) + 80|0);
 dest=$3+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$5>>2] = Math_fround(0.75);
 $6 = (($this) + 84|0);
 HEAP32[$6>>2] = -1;
 $7 = (($this) + 88|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 92|0);
 HEAP32[$8>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIjjNS0_4HashIjEENS1_11HashSetBaseIjS4_NS0_9AllocatorELb0EE6GetKeyES6_Lb0EE15reserveInternalEj($4,64);
 $9 = (($this) + 96|0);
 HEAP32[$9>>2] = $4;
 $10 = (($this) + 100|0);
 $11 = (($this) + 124|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;
 HEAPF32[$11>>2] = Math_fround(0.75);
 $12 = (($this) + 128|0);
 HEAP32[$12>>2] = -1;
 $13 = (($this) + 132|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 136|0);
 HEAP32[$14>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseIjjNS0_4HashIjEENS1_11HashSetBaseIjS4_NS0_9AllocatorELb0EE6GetKeyES6_Lb0EE15reserveInternalEj($10,64);
 $15 = (($this) + 140|0);
 HEAP32[$15>>2] = $10;
 $16 = (($this) + 144|0);
 __ZN5physx2Sq16BucketPrunerCoreC2Eb($16,0);
 $17 = (($this) + 7744|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 7748|0);
 HEAP32[$18>>2] = 100;
 $19 = (($this) + 7756|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 7760|0);
 __ZN5physx2Sq11PruningPoolC2Ev($20);
 $21 = (($this) + 7796|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 7800|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 7804|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 7808|0);
 $25 = $incrementalRebuild&1;
 HEAP8[$24>>0] = $25;
 $26 = (($this) + 7809|0);
 dest=$26+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPrunerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Sq10AABBPrunerD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPrunerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((506024 + 8|0));
 __ZN5physx2Sq10AABBPruner7releaseEv($this);
 $0 = (($this) + 7820|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 7812|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 7804|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i$i$i = $15 & $16;
 if ($or$cond$i$i$i$i) {
  $17 = (($this) + 7796|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 7760|0);
 __ZN5physx2Sq11PruningPoolD2Ev($24);
 $25 = (($this) + 144|0);
 __ZN5physx2Sq16BucketPrunerCoreD2Ev($25);
 $26 = (($this) + 100|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($26,$27);
 }
 $29 = (($this) + 56|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($29,$30);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPruner7releaseEv($this) {
 $this = $this|0;
 var $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i1 = 0, $$pre$i$i = 0, $$pre$i$i7 = 0, $$pre4$i$i = 0, $$pre4$i$i2 = 0, $$sum$i$i = 0, $$sum$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0;
 var $9 = 0, $exitcond$i$i = 0, $exitcond$i$i5 = 0, $i$01$i$i = 0, $i$01$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 144|0);
 __ZN5physx2Sq16BucketPrunerCore7releaseEv($2);
 $3 = (($this) + 56|0);
 $4 = (($this) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($this) + 92|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = (($this) + 68|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $5 << 2;
   _memset(($11|0),-1,($12|0))|0;
   $13 = (($this) + 72|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + -1)|0;
   $16 = ($15|0)==(0);
   $$phi$trans$insert$i$i = (($this) + 64|0);
   $$pre4$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
   if ($16) {
    $23 = $14;$25 = $$pre4$i$i;
   } else {
    $18 = $$pre4$i$i;$i$01$i$i = 0;
    while(1) {
     $$sum$i$i = (($i$01$i$i) + 32)|0;
     $17 = (($18) + ($$sum$i$i<<2)|0);
     $19 = (($i$01$i$i) + 1)|0;
     $20 = HEAP32[$$phi$trans$insert$i$i>>2]|0;
     $21 = (($20) + ($i$01$i$i<<2)|0);
     HEAP32[$21>>2] = $19;
     $exitcond$i$i = ($19|0)==($15|0);
     if ($exitcond$i$i) {
      break;
     } else {
      $18 = $20;$i$01$i$i = $19;
     }
    }
    $$pre$i$i = HEAP32[$13>>2]|0;
    $23 = $$pre$i$i;$25 = $20;
   }
   $22 = (($23) + -1)|0;
   $24 = (($25) + ($22<<2)|0);
   HEAP32[$24>>2] = -1;
   $26 = (($this) + 84|0);
   HEAP32[$26>>2] = 0;
   HEAP32[$7>>2] = 0;
  }
 }
 $27 = (($this) + 100|0);
 $28 = (($this) + 120|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = (($this) + 136|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(0);
  if (!($33)) {
   $34 = (($this) + 112|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $29 << 2;
   _memset(($35|0),-1,($36|0))|0;
   $37 = (($this) + 116|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + -1)|0;
   $40 = ($39|0)==(0);
   $$phi$trans$insert$i$i1 = (($this) + 108|0);
   $$pre4$i$i2 = HEAP32[$$phi$trans$insert$i$i1>>2]|0;
   if ($40) {
    $47 = $38;$49 = $$pre4$i$i2;
   } else {
    $42 = $$pre4$i$i2;$i$01$i$i3 = 0;
    while(1) {
     $$sum$i$i4 = (($i$01$i$i3) + 32)|0;
     $41 = (($42) + ($$sum$i$i4<<2)|0);
     $43 = (($i$01$i$i3) + 1)|0;
     $44 = HEAP32[$$phi$trans$insert$i$i1>>2]|0;
     $45 = (($44) + ($i$01$i$i3<<2)|0);
     HEAP32[$45>>2] = $43;
     $exitcond$i$i5 = ($43|0)==($39|0);
     if ($exitcond$i$i5) {
      break;
     } else {
      $42 = $44;$i$01$i$i3 = $43;
     }
    }
    $$pre$i$i7 = HEAP32[$37>>2]|0;
    $47 = $$pre$i$i7;$49 = $44;
   }
   $46 = (($47) + -1)|0;
   $48 = (($49) + ($46<<2)|0);
   HEAP32[$48>>2] = -1;
   $50 = (($this) + 128|0);
   HEAP32[$50>>2] = 0;
   HEAP32[$31>>2] = 0;
  }
 }
 $51 = (($this) + 96|0);
 HEAP32[$51>>2] = $3;
 $52 = (($this) + 140|0);
 HEAP32[$52>>2] = $27;
 $53 = (($this) + 7796|0);
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($53,0,$0);
 $54 = (($this) + 7800|0);
 $55 = HEAP32[$54>>2]|0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($53,$55);
 $56 = (($this) + 44|0);
 $57 = HEAP32[$56>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$57);
 HEAP32[$56>>2] = 0;
 $58 = (($this) + 24|0);
 HEAP32[$58>>2] = 0;
 $59 = (($this) + 16|0);
 HEAP32[$59>>2] = 0;
 $60 = (($this) + 20|0);
 HEAP32[$60>>2] = 0;
 $61 = (($this) + 32|0);
 HEAP32[$61>>2] = 0;
 $62 = (($this) + 36|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 40|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 if (!($65)) {
  __ZN5physx2Sq8AABBTreeD2Ev($64);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$64);
 }
 HEAP32[$63>>2] = 0;
 $66 = (($this) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  HEAP32[$66>>2] = 0;
  $69 = (($this) + 48|0);
  HEAP32[$69>>2] = 0;
  $70 = (($this) + 7744|0);
  HEAP32[$70>>2] = 0;
  $71 = (($this) + 7816|0);
  HEAP32[$71>>2] = 0;
  $72 = (($this) + 7811|0);
  HEAP8[$72>>0] = 0;
  STACKTOP = sp;return;
 }
 __ZN5physx2Sq8AABBTreeD2Ev($67);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$67);
 HEAP32[$66>>2] = 0;
 $69 = (($this) + 48|0);
 HEAP32[$69>>2] = 0;
 $70 = (($this) + 7744|0);
 HEAP32[$70>>2] = 0;
 $71 = (($this) + 7816|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 7811|0);
 HEAP8[$72>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPruner10addObjectsEPjPKNS_9PxBounds3EPKNS0_13PrunerPayloadEj($this,$results,$bounds,$payload,$count) {
 $this = $this|0;
 $results = $results|0;
 $bounds = $bounds|0;
 $payload = $payload|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exists$i = 0, $exitcond = 0, $h2 = 0, $i1$01 = 0, $or$cond$i = 0;
 var $valid$0$lcssa = 0, $valid$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp + 4|0;
 $h2 = sp;
 $0 = (($this) + 7809|0);
 HEAP8[$0>>0] = 1;
 $1 = (($this) + 7808|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $4 = (($this) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   __ZN5physx2Sq8AABBTreeD2Ev($5);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($exists$i,$5);
  }
  HEAP32[$4>>2] = 0;
 }
 $7 = (($this) + 7760|0);
 $8 = ($count|0)==(0);
 L7: do {
  if ($8) {
   $valid$0$lcssa = 0;
  } else {
   $valid$03 = 0;
   while(1) {
    $9 = (($bounds) + (($valid$03*24)|0)|0);
    $10 = (($payload) + ($valid$03<<3)|0);
    $11 = (__ZN5physx2Sq11PruningPool9addObjectERKNS_9PxBounds3ERKNS0_13PrunerPayloadE($7,$9,$10)|0);
    $12 = (($results) + ($valid$03<<2)|0);
    HEAP32[$12>>2] = $11;
    $13 = ($11|0)==(-1);
    if ($13) {
     $valid$0$lcssa = $valid$03;
     break L7;
    }
    $14 = (($valid$03) + 1)|0;
    $15 = ($14>>>0)<($count>>>0);
    if ($15) {
     $valid$03 = $14;
    } else {
     $valid$0$lcssa = $14;
     break;
    }
   }
  }
 } while(0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $34 = ($valid$0$lcssa|0)==($count|0);
  STACKTOP = sp;return ($34|0);
 }
 $19 = (($this) + 7810|0);
 HEAP8[$19>>0] = 1;
 $20 = ($valid$0$lcssa|0)==(0);
 if ($20) {
  $34 = ($valid$0$lcssa|0)==($count|0);
  STACKTOP = sp;return ($34|0);
 }
 $21 = (($this) + 96|0);
 $22 = (($this) + 144|0);
 $i1$01 = 0;
 while(1) {
  $23 = (($results) + ($i1$01<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  HEAP32[$h2>>2] = $24;
  $25 = HEAP32[$21>>2]|0;
  $26 = (__ZN5physx6shdfnd8internal8HashBaseIjjNS0_4HashIjEENS1_11HashSetBaseIjS4_NS0_9AllocatorELb0EE6GetKeyES6_Lb0EE6createERKjRb($25,$h2,$exists$i)|0);
  $27 = HEAP8[$exists$i>>0]|0;
  $28 = ($27<<24>>24)!=(0);
  $29 = ($26|0)==(0|0);
  $or$cond$i = $28 | $29;
  if (!($or$cond$i)) {
   $30 = HEAP32[$h2>>2]|0;
   HEAP32[$26>>2] = $30;
  }
  $31 = (($payload) + ($i1$01<<3)|0);
  $32 = (($bounds) + (($i1$01*24)|0)|0);
  (__ZN5physx2Sq16BucketPrunerCore9addObjectERKNS0_13PrunerPayloadERKNS_9PxBounds3E($22,$31,$32)|0);
  $33 = (($i1$01) + 1)|0;
  $exitcond = ($33|0)==($valid$0$lcssa|0);
  if ($exitcond) {
   break;
  } else {
   $i1$01 = $33;
  }
 }
 $34 = ($valid$0$lcssa|0)==($count|0);
 STACKTOP = sp;return ($34|0);
}
function __ZN5physx2Sq10AABBPruner13updateObjectsEPKjPKNS_9PxBounds3Ej($this,$handles,$newBounds,$count) {
 $this = $this|0;
 $handles = $handles|0;
 $newBounds = $newBounds|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $exitcond5 = 0, $i$03 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 7809|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 7808|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   __ZN5physx2Sq8AABBTreeD2Ev($6);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
  }
  HEAP32[$5>>2] = 0;
 }
 $8 = ($count|0)==(0);
 if (!($8)) {
  $9 = (($this) + 7780|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 7772|0);
  $12 = HEAP32[$11>>2]|0;
  $i$03 = 0;
  while(1) {
   $13 = (($handles) + ($i$03<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($10) + ($14<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($newBounds) + (($i$03*24)|0)|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = (($12) + (($16*24)|0)|0);
   HEAPF32[$19>>2] = $18;
   $20 = ((($newBounds) + (($i$03*24)|0)|0) + 4|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = ((($12) + (($16*24)|0)|0) + 4|0);
   HEAPF32[$22>>2] = $21;
   $23 = ((($newBounds) + (($i$03*24)|0)|0) + 8|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = ((($12) + (($16*24)|0)|0) + 8|0);
   HEAPF32[$25>>2] = $24;
   $26 = ((($newBounds) + (($i$03*24)|0)|0) + 12|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = ((($12) + (($16*24)|0)|0) + 12|0);
   HEAPF32[$28>>2] = $27;
   $29 = ((($newBounds) + (($i$03*24)|0)|0) + 16|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = ((($12) + (($16*24)|0)|0) + 16|0);
   HEAPF32[$31>>2] = $30;
   $32 = ((($newBounds) + (($i$03*24)|0)|0) + 20|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = ((($12) + (($16*24)|0)|0) + 20|0);
   HEAPF32[$34>>2] = $33;
   $35 = (($i$03) + 1)|0;
   $exitcond5 = ($35|0)==($count|0);
   if ($exitcond5) {
    break;
   } else {
    $i$03 = $35;
   }
  }
 }
 $36 = (($this) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($this) + 7810|0);
 HEAP8[$39>>0] = 1;
 if ($8) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 7780|0);
 $41 = (($this) + 7800|0);
 $42 = (($this) + 7796|0);
 $43 = (($this) + 144|0);
 $44 = (($this) + 7776|0);
 $i1$01 = 0;
 while(1) {
  $45 = (($handles) + ($i1$01<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$40>>2]|0;
  $48 = (($47) + ($46<<2)|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = HEAP32[$41>>2]|0;
  $51 = ($50>>>0)>($49>>>0);
  if ($51) {
   $52 = HEAP32[$42>>2]|0;
   $53 = (($52) + ($49<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(-1);
   if ($55) {
    label = 14;
   } else {
    $56 = HEAP32[$36>>2]|0;
    __ZN5physx2Sq8AABBTree12markForRefitEj($56,$54);
   }
  } else {
   label = 14;
  }
  if ((label|0) == 14) {
   label = 0;
   $57 = (($newBounds) + (($i1$01*24)|0)|0);
   $58 = HEAP32[$44>>2]|0;
   $59 = (($58) + ($49<<3)|0);
   (__ZN5physx2Sq16BucketPrunerCore12updateObjectERKNS_9PxBounds3ERKNS0_13PrunerPayloadE($43,$57,$59)|0);
  }
  $60 = (($i1$01) + 1)|0;
  $exitcond = ($60|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i1$01 = $60;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPruner13removeObjectsEPKjj($this,$handles,$count) {
 $this = $this|0;
 $handles = $handles|0;
 $count = $count|0;
 var $$pr$i$i = 0, $$pr$i$i2 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$012 = 0, $ptr$02$i$i = 0, $ptr$02$i$i3 = 0, $removedPayload = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $removedPayload = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 7809|0);
 HEAP8[$2>>0] = 1;
 $3 = (($this) + 7808|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (($this) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   __ZN5physx2Sq8AABBTreeD2Ev($7);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
  }
  HEAP32[$6>>2] = 0;
 }
 $9 = ($count|0)==(0);
 if (!($9)) {
  $10 = (($this) + 7760|0);
  $11 = (($this) + 7780|0);
  $12 = (($this) + 7776|0);
  $13 = (($this) + 4|0);
  $14 = (($this) + 7810|0);
  $15 = (($this) + 7796|0);
  $16 = (($this) + 7800|0);
  $17 = (($this) + 76|0);
  $18 = (($this) + 120|0);
  $19 = (($this) + 112|0);
  $20 = (($this) + 104|0);
  $21 = (($this) + 108|0);
  $22 = (($this) + 136|0);
  $23 = (($this) + 132|0);
  $24 = (($this) + 128|0);
  $25 = (($this) + 7811|0);
  $26 = (($this) + 7812|0);
  $27 = (($1) + 4|0);
  $28 = (($this) + 7820|0);
  $29 = (($this) + 7816|0);
  $30 = (($this) + 144|0);
  $31 = (($this) + 68|0);
  $32 = (($this) + 60|0);
  $33 = (($this) + 64|0);
  $34 = (($this) + 92|0);
  $35 = (($this) + 88|0);
  $36 = (($this) + 84|0);
  $i$012 = 0;
  while(1) {
   $37 = (($handles) + ($i$012<<2)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = HEAP32[$11>>2]|0;
   $40 = (($39) + ($38<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = HEAP32[$12>>2]|0;
   $43 = (($42) + ($41<<3)|0);
   $44 = $43;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 4)|0;
   $48 = $47;
   $49 = HEAP32[$48>>2]|0;
   $50 = $removedPayload;
   $51 = $50;
   HEAP32[$51>>2] = $46;
   $52 = (($50) + 4)|0;
   $53 = $52;
   HEAP32[$53>>2] = $49;
   $54 = HEAP32[$40>>2]|0;
   $55 = (__ZN5physx2Sq11PruningPool12removeObjectEj($10,$38)|0);
   $56 = HEAP32[$13>>2]|0;
   $57 = ($56|0)==(0|0);
   do {
    if (!($57)) {
     HEAP8[$14>>0] = 1;
     $58 = HEAP32[$16>>2]|0;
     $59 = ($58>>>0)>($54>>>0);
     if ($59) {
      $60 = HEAP32[$15>>2]|0;
      $61 = (($60) + ($54<<2)|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($62|0)==(-1);
      if (!($63)) {
       __ZN5physx2Sq8AABBTree12markForRefitEj($56,$62);
      }
     }
     $64 = HEAP32[$17>>2]|0;
     $65 = ($64|0)==(0);
     L17: do {
      if ($65) {
       label = 18;
      } else {
       $66 = $38 << 15;
       $67 = $66 ^ -1;
       $68 = (($38) + ($67))|0;
       $69 = $68 >>> 10;
       $70 = $69 ^ $68;
       $71 = ($70*9)|0;
       $72 = $71 >>> 6;
       $73 = $72 ^ $71;
       $74 = $73 << 11;
       $75 = $74 ^ -1;
       $76 = (($73) + ($75))|0;
       $77 = $76 >>> 16;
       $78 = $77 ^ $76;
       $79 = (($64) + -1)|0;
       $80 = $79 & $78;
       $81 = HEAP32[$31>>2]|0;
       $82 = (($81) + ($80<<2)|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = ($83|0)==(-1);
       if ($84) {
        label = 18;
       } else {
        $85 = HEAP32[$32>>2]|0;
        $$pr$i$i2 = $83;$ptr$02$i$i3 = $82;
        while(1) {
         $86 = (($85) + ($$pr$i$i2<<2)|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = ($87|0)==($38|0);
         if ($88) {
          break;
         }
         $89 = HEAP32[$33>>2]|0;
         $90 = (($89) + ($$pr$i$i2<<2)|0);
         $91 = HEAP32[$90>>2]|0;
         $92 = ($91|0)==(-1);
         if ($92) {
          label = 18;
          break L17;
         } else {
          $$pr$i$i2 = $91;$ptr$02$i$i3 = $90;
         }
        }
        $93 = ($$pr$i$i2|0)==(-1);
        if ($93) {
         label = 18;
        } else {
         $94 = HEAP32[$33>>2]|0;
         $95 = (($94) + ($$pr$i$i2<<2)|0);
         $96 = HEAP32[$95>>2]|0;
         HEAP32[$ptr$02$i$i3>>2] = $96;
         $97 = HEAP32[$34>>2]|0;
         $98 = (($97) + -1)|0;
         HEAP32[$34>>2] = $98;
         $99 = HEAP32[$35>>2]|0;
         $100 = (($99) + 1)|0;
         HEAP32[$35>>2] = $100;
         $101 = HEAP32[$36>>2]|0;
         HEAP32[$95>>2] = $101;
         HEAP32[$36>>2] = $$pr$i$i2;
         label = 25;
        }
       }
      }
     } while(0);
     L25: do {
      if ((label|0) == 18) {
       label = 0;
       $102 = HEAP32[$18>>2]|0;
       $103 = ($102|0)==(0);
       if (!($103)) {
        $104 = $38 << 15;
        $105 = $104 ^ -1;
        $106 = (($38) + ($105))|0;
        $107 = $106 >>> 10;
        $108 = $107 ^ $106;
        $109 = ($108*9)|0;
        $110 = $109 >>> 6;
        $111 = $110 ^ $109;
        $112 = $111 << 11;
        $113 = $112 ^ -1;
        $114 = (($111) + ($113))|0;
        $115 = $114 >>> 16;
        $116 = $115 ^ $114;
        $117 = (($102) + -1)|0;
        $118 = $117 & $116;
        $119 = HEAP32[$19>>2]|0;
        $120 = (($119) + ($118<<2)|0);
        $121 = HEAP32[$120>>2]|0;
        $122 = ($121|0)==(-1);
        if (!($122)) {
         $123 = HEAP32[$20>>2]|0;
         $$pr$i$i = $121;$ptr$02$i$i = $120;
         while(1) {
          $124 = (($123) + ($$pr$i$i<<2)|0);
          $125 = HEAP32[$124>>2]|0;
          $126 = ($125|0)==($38|0);
          if ($126) {
           break;
          }
          $127 = HEAP32[$21>>2]|0;
          $128 = (($127) + ($$pr$i$i<<2)|0);
          $129 = HEAP32[$128>>2]|0;
          $130 = ($129|0)==(-1);
          if ($130) {
           break L25;
          } else {
           $$pr$i$i = $129;$ptr$02$i$i = $128;
          }
         }
         $131 = ($$pr$i$i|0)==(-1);
         if (!($131)) {
          $132 = HEAP32[$21>>2]|0;
          $133 = (($132) + ($$pr$i$i<<2)|0);
          $134 = HEAP32[$133>>2]|0;
          HEAP32[$ptr$02$i$i>>2] = $134;
          $135 = HEAP32[$22>>2]|0;
          $136 = (($135) + -1)|0;
          HEAP32[$22>>2] = $136;
          $137 = HEAP32[$23>>2]|0;
          $138 = (($137) + 1)|0;
          HEAP32[$23>>2] = $138;
          $139 = HEAP32[$24>>2]|0;
          HEAP32[$133>>2] = $139;
          HEAP32[$24>>2] = $$pr$i$i;
          label = 25;
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 25) {
      label = 0;
      (__ZN5physx2Sq16BucketPrunerCore12removeObjectERKNS0_13PrunerPayloadE($30,$removedPayload)|0);
     }
     $140 = HEAP32[$13>>2]|0;
     __ZN5physx2Sq17AABBTreeUpdateMap10invalidateEjjRNS0_8AABBTreeE($15,$54,$55,$140);
     $141 = HEAP8[$25>>0]|0;
     $142 = ($141<<24>>24)==(0);
     if (!($142)) {
      HEAP32[$1>>2] = $54;
      HEAP32[$27>>2] = $55;
      $143 = HEAP32[$28>>2]|0;
      $144 = $143 & 2147483647;
      $145 = HEAP32[$29>>2]|0;
      $146 = ($144>>>0)>($145>>>0);
      if (!($146)) {
       (__ZN5physx6shdfnd5ArrayINS_2Sq10AABBPruner12NewTreeFixupENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($26,$1)|0);
       break;
      }
      $147 = HEAP32[$26>>2]|0;
      $148 = (($147) + ($145<<3)|0);
      $149 = ($148|0)==(0|0);
      if ($149) {
       $161 = $145;
      } else {
       $150 = $1;
       $151 = $150;
       $152 = HEAP32[$151>>2]|0;
       $153 = (($150) + 4)|0;
       $154 = $153;
       $155 = HEAP32[$154>>2]|0;
       $156 = $148;
       $157 = $156;
       HEAP32[$157>>2] = $152;
       $158 = (($156) + 4)|0;
       $159 = $158;
       HEAP32[$159>>2] = $155;
       $$pre$i = HEAP32[$29>>2]|0;
       $161 = $$pre$i;
      }
      $160 = (($161) + 1)|0;
      HEAP32[$29>>2] = $160;
     }
    }
   } while(0);
   $162 = (($i$012) + 1)|0;
   $exitcond = ($162|0)==($count|0);
   if ($exitcond) {
    break;
   } else {
    $i$012 = $162;
   }
  }
 }
 $163 = (($this) + 7764|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ($164|0)==(0);
 if (!($165)) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sq10AABBPruner7releaseEv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sq10AABBPruner7overlapERKNS0_9ShapeDataERNS0_14PrunerCallbackE($this,$queryVolume,$pcb) {
 $this = $this|0;
 $queryVolume = $queryVolume|0;
 $pcb = $pcb|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $again$1$off0 = 0, $fabsf$i$i = Math_fround(0), $test1 = 0, $test2 = 0, $test3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $0 = sp + 192|0;
 $1 = sp + 396|0;
 $2 = sp + 384|0;
 $test1 = sp + 160|0;
 $test2 = sp + 32|0;
 $test3 = sp;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if (!($5)) {
   $6 = (($queryVolume) + 144|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$7>>2]|0;
   if ((($8|0) == 3)) {
    $9 = (($queryVolume) + 68|0);
    $10 = Math_fround(HEAPF32[$9>>2]);
    $fabsf$i$i = (Math_fround(Math_abs((Math_fround($10)))));
    $11 = $fabsf$i$i < Math_fround(0.999998986721038818359);
    if ($11) {
     $12 = (($queryVolume) + 56|0);
     __ZN5physx2Gu12OBBAABBTestsILb1EEC2ERKNS_11PxTransformERKNS_13PxBoxGeometryEf($0,$12,$queryVolume,Math_fround(1.00999999046325683594));
     $13 = (($this) + 7776|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = HEAP32[$3>>2]|0;
     $16 = (__ZN15AABBTreeOverlapIN5physx2Gu12OBBAABBTestsILb1EEEEclEPNS0_2Sq13PrunerPayloadERKNS5_8AABBTreeERKS3_RNS5_14PrunerCallbackE(0,$14,$15,$0,$pcb)|0);
     if ($16) {
      break;
     } else {
      $again$1$off0 = 0;
     }
     STACKTOP = sp;return ($again$1$off0|0);
    } else {
     $86 = (($queryVolume) + 120|0);
     $87 = Math_fround(HEAPF32[$86>>2]);
     $88 = (($queryVolume) + 132|0);
     $89 = Math_fround(HEAPF32[$88>>2]);
     $90 = Math_fround($87 + $89);
     $91 = (($queryVolume) + 124|0);
     $92 = Math_fround(HEAPF32[$91>>2]);
     $93 = (($queryVolume) + 136|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = Math_fround($92 + $94);
     $96 = (($queryVolume) + 128|0);
     $97 = Math_fround(HEAPF32[$96>>2]);
     $98 = (($queryVolume) + 140|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     $100 = Math_fround($97 + $99);
     $101 = Math_fround($90 * Math_fround(0.5));
     $102 = Math_fround($95 * Math_fround(0.5));
     $103 = Math_fround($100 * Math_fround(0.5));
     HEAPF32[$test1>>2] = $101;
     $104 = (($test1) + 4|0);
     HEAPF32[$104>>2] = $102;
     $105 = (($test1) + 8|0);
     HEAPF32[$105>>2] = $103;
     $106 = (($test1) + 12|0);
     HEAPF32[$106>>2] = Math_fround(0.0);
     $107 = Math_fround($89 - $87);
     $108 = Math_fround($94 - $92);
     $109 = Math_fround($99 - $97);
     $110 = Math_fround($107 * Math_fround(0.5));
     $111 = Math_fround($108 * Math_fround(0.5));
     $112 = Math_fround($109 * Math_fround(0.5));
     $113 = (($test1) + 16|0);
     HEAPF32[$113>>2] = $110;
     $114 = (($test1) + 20|0);
     HEAPF32[$114>>2] = $111;
     $115 = (($test1) + 24|0);
     HEAPF32[$115>>2] = $112;
     $116 = (($test1) + 28|0);
     HEAPF32[$116>>2] = Math_fround(0.0);
     $117 = (($this) + 7776|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = (__ZN15AABBTreeOverlapIN5physx2Gu12AABBAABBTestEEclEPNS0_2Sq13PrunerPayloadERKNS4_8AABBTreeERKS2_RNS4_14PrunerCallbackE(0,$118,$4,$test1,$pcb)|0);
     if ($119) {
      break;
     } else {
      $again$1$off0 = 0;
     }
     STACKTOP = sp;return ($again$1$off0|0);
    }
   } else if ((($8|0) == 4)) {
    $81 = (($queryVolume) + 56|0);
    __ZN5physx2Gu12OBBAABBTestsILb1EEC2ERKNS_11PxTransformERKNS_13PxBoxGeometryEf($0,$81,$queryVolume,Math_fround(1.00999999046325683594));
    $82 = (($this) + 7776|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = HEAP32[$3>>2]|0;
    $85 = (__ZN15AABBTreeOverlapIN5physx2Gu12OBBAABBTestsILb1EEEEclEPNS0_2Sq13PrunerPayloadERKNS5_8AABBTreeERKS3_RNS5_14PrunerCallbackE(0,$83,$84,$0,$pcb)|0);
    if ($85) {
     break;
    } else {
     $again$1$off0 = 0;
    }
    STACKTOP = sp;return ($again$1$off0|0);
   } else if ((($8|0) == 2)) {
    $17 = (($queryVolume) + 56|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = Math_fround($18 * Math_fround(2.0));
    $20 = (($queryVolume) + 68|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = Math_fround($21 * Math_fround(2.0));
    $23 = Math_fround($21 * $22);
    $24 = Math_fround($23 + Math_fround(-1.0));
    $25 = Math_fround($18 * $19);
    $26 = Math_fround($25 + $24);
    $27 = (($queryVolume) + 64|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = Math_fround($28 * $22);
    $30 = (($queryVolume) + 60|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = Math_fround($19 * $31);
    $33 = Math_fround($29 + $32);
    $34 = Math_fround($22 * $31);
    $35 = Math_fround($19 * $28);
    $36 = Math_fround($35 - $34);
    $37 = (($7) + 8|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = Math_fround($38 * $26);
    $40 = Math_fround($38 * $33);
    $41 = Math_fround($38 * $36);
    $42 = (($queryVolume) + 72|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = Math_fround($43 - $39);
    $45 = (($queryVolume) + 76|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = Math_fround($46 - $40);
    $48 = (($queryVolume) + 80|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = Math_fround($49 - $41);
    HEAPF32[$0>>2] = $44;
    $51 = (($0) + 4|0);
    HEAPF32[$51>>2] = $47;
    $52 = (($0) + 8|0);
    HEAPF32[$52>>2] = $50;
    HEAPF32[$1>>2] = $26;
    $53 = (($1) + 4|0);
    HEAPF32[$53>>2] = $33;
    $54 = (($1) + 8|0);
    HEAPF32[$54>>2] = $36;
    $55 = Math_fround($38 * Math_fround(2.0));
    $56 = (($7) + 4|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = Math_fround($57 * Math_fround(1.00999999046325683594));
    HEAPF32[$2>>2] = $58;
    $59 = (($2) + 4|0);
    HEAPF32[$59>>2] = $58;
    $60 = (($2) + 8|0);
    HEAPF32[$60>>2] = $58;
    __ZN5physx2Gu11RayAABBTestC2ERKNS_6PxVec3ES4_fS4_($test2,$0,$1,$55,$2);
    $61 = (($this) + 7776|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = HEAP32[$3>>2]|0;
    $64 = (__ZN15AABBTreeOverlapIN5physx2Gu15CapsuleAABBTestEEclEPNS0_2Sq13PrunerPayloadERKNS4_8AABBTreeERKS2_RNS4_14PrunerCallbackE(0,$62,$63,$test2,$pcb)|0);
    if ($64) {
     break;
    } else {
     $again$1$off0 = 0;
    }
    STACKTOP = sp;return ($again$1$off0|0);
   } else if ((($8|0) == 0)) {
    $65 = (($queryVolume) + 148|0);
    $66 = (($queryVolume) + 160|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = Math_fround(HEAPF32[$65>>2]);
    $69 = (($queryVolume) + 152|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = (($queryVolume) + 156|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    HEAPF32[$test3>>2] = $68;
    $73 = (($test3) + 4|0);
    HEAPF32[$73>>2] = $70;
    $74 = (($test3) + 8|0);
    HEAPF32[$74>>2] = $72;
    $75 = (($test3) + 12|0);
    HEAPF32[$75>>2] = Math_fround(0.0);
    $76 = Math_fround($67 * $67);
    $77 = (($test3) + 16|0);
    HEAPF32[$77>>2] = $76;
    $78 = (($this) + 7776|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (__ZN15AABBTreeOverlapIN5physx2Gu14SphereAABBTestEEclEPNS0_2Sq13PrunerPayloadERKNS4_8AABBTreeERKS2_RNS4_14PrunerCallbackE(0,$79,$4,$test3,$pcb)|0);
    if ($80) {
     break;
    } else {
     $again$1$off0 = 0;
    }
    STACKTOP = sp;return ($again$1$off0|0);
   } else {
    break;
   }
  }
 } while(0);
 $120 = (($this) + 7808|0);
 $121 = HEAP8[$120>>0]|0;
 $122 = ($121<<24>>24)==(0);
 if ($122) {
  $again$1$off0 = 1;
  STACKTOP = sp;return ($again$1$off0|0);
 }
 $123 = (($this) + 92|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($124|0)==(0);
 if ($125) {
  $126 = (($this) + 136|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ($127|0)==(0);
  if ($128) {
   $again$1$off0 = 1;
   STACKTOP = sp;return ($again$1$off0|0);
  }
 }
 $129 = (($this) + 144|0);
 $130 = (__ZNK5physx2Sq16BucketPrunerCore7overlapERKNS0_9ShapeDataERNS0_14PrunerCallbackE($129,$queryVolume,$pcb)|0);
 $again$1$off0 = $130;
 STACKTOP = sp;return ($again$1$off0|0);
}
function __ZN15AABBTreeOverlapIN5physx2Gu12OBBAABBTestsILb1EEEEclEPNS0_2Sq13PrunerPayloadERKNS5_8AABBTreeERKS3_RNS5_14PrunerCallbackE($this,$objects,$tree,$test,$visitor) {
 $this = $this|0;
 $objects = $objects|0;
 $tree = $tree|0;
 $test = $test|0;
 $visitor = $visitor|0;
 var $$0 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $node$05 = 0, $stack = 0, $stackIndex$0$be = 0, $stackIndex$07 = 0, $stackIndex$16 = 0, $unusedDistance = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1104|0;
 $$byval_copy3 = sp + 48|0;
 $$byval_copy2 = sp;
 $stack = sp + 72|0;
 $0 = sp + 32|0;
 $1 = sp + 16|0;
 $unusedDistance = sp + 64|0;
 $2 = (($tree) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$stack>>2] = $3;
 $4 = (($0) + 4|0);
 $5 = (($0) + 8|0);
 $6 = (($0) + 12|0);
 $7 = (($1) + 4|0);
 $8 = (($1) + 8|0);
 $9 = (($1) + 12|0);
 $stackIndex$07 = 1;
 L1: while(1) {
  $10 = (($stackIndex$07) + -1)|0;
  $11 = (($stack) + ($10<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($12) + 4|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($12) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($12) + 16|0);
  $19 = $18;
  $20 = $19;
  $21 = HEAP32[$20>>2]|0;
  $22 = (($19) + 4)|0;
  $23 = $22;
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 & -256;
  $26 = (HEAP32[tempDoublePtr>>2]=$25,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $27 = Math_fround($26 * Math_fround(9.99999974737875163555E-5));
  $28 = (HEAPF32[tempDoublePtr>>2]=$13,HEAP32[tempDoublePtr>>2]|0);
  $29 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $30 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
  $31 = $28 & 255;
  $32 = $29 & 255;
  $33 = $30 & 255;
  $34 = (Math_fround(($31|0)));
  $35 = (Math_fround(($32|0)));
  $36 = (Math_fround(($33|0)));
  $37 = Math_fround($34 * $27);
  $38 = Math_fround($35 * $27);
  $39 = Math_fround($36 * $27);
  HEAPF32[$0>>2] = $13;
  HEAPF32[$4>>2] = $15;
  HEAPF32[$5>>2] = $17;
  HEAPF32[$6>>2] = Math_fround(0.0);
  HEAPF32[$1>>2] = $37;
  HEAPF32[$7>>2] = $38;
  HEAPF32[$8>>2] = $39;
  HEAPF32[$9>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$0+12>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$1+12>>2]|0;
  $40 = (__ZNK5physx2Gu12OBBAABBTestsILb1EEclENS_6shdfnd3aos5Vec3VES5_($test,$$byval_copy2,$$byval_copy3)|0);
  $41 = ($40|0)==(0);
  L3: do {
   if ($41) {
    $stackIndex$0$be = $10;
   } else {
    $node$05 = $12;$stackIndex$16 = $10;
    while(1) {
     $42 = (($node$05) + 16|0);
     $43 = $42;
     $44 = $43;
     $45 = HEAP32[$44>>2]|0;
     $46 = (($43) + 4)|0;
     $47 = $46;
     $48 = HEAP32[$47>>2]|0;
     $49 = $45 & 1;
     $50 = ($49|0)==(0);
     $51 = (0)==(0);
     $52 = $50 & $51;
     if (!($52)) {
      break;
     }
     $64 = (_bitshift64Lshr(($45|0),($48|0),21)|0);
     $65 = tempRet0;
     $66 = $64 & 524287;
     $67 = (($3) + (($66*24)|0)|0);
     $$sum = (($66) + 1)|0;
     $68 = (($3) + (($$sum*24)|0)|0);
     $69 = (($stackIndex$16) + 1)|0;
     $70 = (($stack) + ($stackIndex$16<<2)|0);
     HEAP32[$70>>2] = $68;
     $71 = Math_fround(HEAPF32[$67>>2]);
     $72 = ((($3) + (($66*24)|0)|0) + 4|0);
     $73 = Math_fround(HEAPF32[$72>>2]);
     $74 = ((($3) + (($66*24)|0)|0) + 8|0);
     $75 = Math_fround(HEAPF32[$74>>2]);
     $76 = ((($3) + (($66*24)|0)|0) + 16|0);
     $77 = $76;
     $78 = $77;
     $79 = HEAP32[$78>>2]|0;
     $80 = (($77) + 4)|0;
     $81 = $80;
     $82 = HEAP32[$81>>2]|0;
     $83 = $82 & -256;
     $84 = (HEAP32[tempDoublePtr>>2]=$83,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $85 = Math_fround($84 * Math_fround(9.99999974737875163555E-5));
     $86 = (HEAPF32[tempDoublePtr>>2]=$71,HEAP32[tempDoublePtr>>2]|0);
     $87 = (HEAPF32[tempDoublePtr>>2]=$73,HEAP32[tempDoublePtr>>2]|0);
     $88 = (HEAPF32[tempDoublePtr>>2]=$75,HEAP32[tempDoublePtr>>2]|0);
     $89 = $86 & 255;
     $90 = $87 & 255;
     $91 = $88 & 255;
     $92 = (Math_fround(($89|0)));
     $93 = (Math_fround(($90|0)));
     $94 = (Math_fround(($91|0)));
     $95 = Math_fround($92 * $85);
     $96 = Math_fround($93 * $85);
     $97 = Math_fround($94 * $85);
     HEAPF32[$0>>2] = $71;
     HEAPF32[$4>>2] = $73;
     HEAPF32[$5>>2] = $75;
     HEAPF32[$6>>2] = Math_fround(0.0);
     HEAPF32[$1>>2] = $95;
     HEAPF32[$7>>2] = $96;
     HEAPF32[$8>>2] = $97;
     HEAPF32[$9>>2] = Math_fround(0.0);
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$0+12>>2]|0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy3+12>>2]=HEAP32[$1+12>>2]|0;
     $98 = (__ZNK5physx2Gu12OBBAABBTestsILb1EEclENS_6shdfnd3aos5Vec3VES5_($test,$$byval_copy2,$$byval_copy3)|0);
     $99 = ($98|0)==(0);
     if ($99) {
      $stackIndex$0$be = $69;
      break L3;
     } else {
      $node$05 = $67;$stackIndex$16 = $69;
     }
    }
    $53 = HEAP32[$tree>>2]|0;
    $54 = (_bitshift64Lshr(($45|0),($48|0),21)|0);
    $55 = tempRet0;
    $56 = $54 & 524287;
    $57 = (($53) + ($56<<2)|0);
    $58 = HEAP32[$visitor>>2]|0;
    $59 = HEAP32[$58>>2]|0;
    $60 = HEAP32[$57>>2]|0;
    $61 = (($objects) + ($60<<3)|0);
    $62 = (FUNCTION_TABLE_iiiii[$59 & 511]($visitor,$unusedDistance,$61,1)|0);
    if ($62) {
     $stackIndex$0$be = $stackIndex$16;
    } else {
     $$0 = 0;
     label = 7;
     break L1;
    }
   }
  } while(0);
  $63 = ($stackIndex$0$be|0)==(0);
  if ($63) {
   $$0 = 1;
   label = 7;
   break;
  } else {
   $stackIndex$07 = $stackIndex$0$be;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN15AABBTreeOverlapIN5physx2Gu12AABBAABBTestEEclEPNS0_2Sq13PrunerPayloadERKNS4_8AABBTreeERKS2_RNS4_14PrunerCallbackE($this,$objects,$tree,$test,$visitor) {
 $this = $this|0;
 $objects = $objects|0;
 $tree = $tree|0;
 $test = $test|0;
 $visitor = $visitor|0;
 var $$$i$i$i = Math_fround(0), $$0 = 0, $$1$i$i$i = Math_fround(0), $$sum = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $node$0 = 0, $stack = 0, $stackIndex$020 = 0, $stackIndex$1 = 0, $unusedDistance = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $stack = sp + 8|0;
 $unusedDistance = sp;
 $0 = (($tree) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$stack>>2] = $1;
 $2 = (($test) + 16|0);
 $3 = (($test) + 20|0);
 $4 = (($test) + 24|0);
 $5 = (($test) + 4|0);
 $6 = (($test) + 8|0);
 $stackIndex$020 = 1;
 while(1) {
  $7 = (($stackIndex$020) + -1)|0;
  $8 = (($stack) + ($7<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($9) + 4|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($9) + 8|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($9) + 16|0);
  $16 = $15;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) + 4)|0;
  $20 = $19;
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & -256;
  $23 = (HEAP32[tempDoublePtr>>2]=$22,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $24 = Math_fround($23 * Math_fround(9.99999974737875163555E-5));
  $25 = (HEAPF32[tempDoublePtr>>2]=$10,HEAP32[tempDoublePtr>>2]|0);
  $26 = (HEAPF32[tempDoublePtr>>2]=$12,HEAP32[tempDoublePtr>>2]|0);
  $27 = (HEAPF32[tempDoublePtr>>2]=$14,HEAP32[tempDoublePtr>>2]|0);
  $28 = $25 & 255;
  $29 = $26 & 255;
  $30 = $27 & 255;
  $31 = (Math_fround(($28|0)));
  $32 = (Math_fround(($29|0)));
  $33 = (Math_fround(($30|0)));
  $34 = Math_fround($31 * $24);
  $35 = Math_fround($32 * $24);
  $36 = Math_fround($33 * $24);
  $37 = Math_fround(HEAPF32[$2>>2]);
  $38 = Math_fround(HEAPF32[$3>>2]);
  $39 = Math_fround(HEAPF32[$4>>2]);
  $40 = Math_fround(HEAPF32[$test>>2]);
  $41 = Math_fround(HEAPF32[$5>>2]);
  $42 = Math_fround(HEAPF32[$6>>2]);
  $44 = $34;$46 = $35;$48 = $36;$50 = $10;$52 = $12;$54 = $14;$node$0 = $9;$stackIndex$1 = $7;
  while(1) {
   $43 = Math_fround($44 + $37);
   $45 = Math_fround($46 + $38);
   $47 = Math_fround($48 + $39);
   $49 = Math_fround($50 - $40);
   $51 = Math_fround($52 - $41);
   $53 = Math_fround($54 - $42);
   $55 = Math_fround(-$49);
   $56 = Math_fround(-$51);
   $57 = Math_fround(-$53);
   $58 = $49 > $55;
   $$$i$i$i = $58 ? $49 : $55;
   $59 = $51 > $56;
   $60 = $59 ? $51 : $56;
   $61 = $53 > $57;
   $$1$i$i$i = $61 ? $53 : $57;
   $62 = $43 >= $$$i$i$i;
   $63 = $45 >= $60;
   $64 = $62 & $63;
   $65 = $47 >= $$1$i$i$i;
   $66 = $64 & $65;
   if (!($66)) {
    break;
   }
   $67 = (($node$0) + 16|0);
   $68 = $67;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $70 & 1;
   $75 = ($74|0)==(0);
   $76 = (0)==(0);
   $77 = $75 & $76;
   if (!($77)) {
    label = 5;
    break;
   }
   $89 = (_bitshift64Lshr(($70|0),($73|0),21)|0);
   $90 = tempRet0;
   $91 = $89 & 524287;
   $92 = (($1) + (($91*24)|0)|0);
   $$sum = (($91) + 1)|0;
   $93 = (($1) + (($$sum*24)|0)|0);
   $94 = (($stackIndex$1) + 1)|0;
   $95 = (($stack) + ($stackIndex$1<<2)|0);
   HEAP32[$95>>2] = $93;
   $96 = Math_fround(HEAPF32[$92>>2]);
   $97 = ((($1) + (($91*24)|0)|0) + 4|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = ((($1) + (($91*24)|0)|0) + 8|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = ((($1) + (($91*24)|0)|0) + 16|0);
   $102 = $101;
   $103 = $102;
   $104 = HEAP32[$103>>2]|0;
   $105 = (($102) + 4)|0;
   $106 = $105;
   $107 = HEAP32[$106>>2]|0;
   $108 = $107 & -256;
   $109 = (HEAP32[tempDoublePtr>>2]=$108,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $110 = Math_fround($109 * Math_fround(9.99999974737875163555E-5));
   $111 = (HEAPF32[tempDoublePtr>>2]=$96,HEAP32[tempDoublePtr>>2]|0);
   $112 = (HEAPF32[tempDoublePtr>>2]=$98,HEAP32[tempDoublePtr>>2]|0);
   $113 = (HEAPF32[tempDoublePtr>>2]=$100,HEAP32[tempDoublePtr>>2]|0);
   $114 = $111 & 255;
   $115 = $112 & 255;
   $116 = $113 & 255;
   $117 = (Math_fround(($114|0)));
   $118 = (Math_fround(($115|0)));
   $119 = (Math_fround(($116|0)));
   $120 = Math_fround($117 * $110);
   $121 = Math_fround($118 * $110);
   $122 = Math_fround($119 * $110);
   $44 = $120;$46 = $121;$48 = $122;$50 = $96;$52 = $98;$54 = $100;$node$0 = $92;$stackIndex$1 = $94;
  }
  if ((label|0) == 5) {
   label = 0;
   $78 = HEAP32[$tree>>2]|0;
   $79 = (_bitshift64Lshr(($70|0),($73|0),21)|0);
   $80 = tempRet0;
   $81 = $79 & 524287;
   $82 = (($78) + ($81<<2)|0);
   $83 = HEAP32[$visitor>>2]|0;
   $84 = HEAP32[$83>>2]|0;
   $85 = HEAP32[$82>>2]|0;
   $86 = (($objects) + ($85<<3)|0);
   $87 = (FUNCTION_TABLE_iiiii[$84 & 511]($visitor,$unusedDistance,$86,1)|0);
   if (!($87)) {
    $$0 = 0;
    label = 8;
    break;
   }
  }
  $88 = ($stackIndex$1|0)==(0);
  if ($88) {
   $$0 = 1;
   label = 8;
   break;
  } else {
   $stackIndex$020 = $stackIndex$1;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN15AABBTreeOverlapIN5physx2Gu15CapsuleAABBTestEEclEPNS0_2Sq13PrunerPayloadERKNS4_8AABBTreeERKS2_RNS4_14PrunerCallbackE($this,$objects,$tree,$test,$visitor) {
 $this = $this|0;
 $objects = $objects|0;
 $tree = $tree|0;
 $test = $test|0;
 $visitor = $visitor|0;
 var $$0 = 0, $$byval_copy1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = 0, $98 = 0, $extents = 0, $extents$byval_copy2 = 0, $node$05 = 0, $stack = 0, $stackIndex$0$be = 0, $stackIndex$07 = 0, $stackIndex$16 = 0, $unusedDistance = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1104|0;
 $extents$byval_copy2 = sp + 48|0;
 $$byval_copy1 = sp;
 $0 = sp + 16|0;
 $stack = sp + 72|0;
 $extents = sp + 32|0;
 $unusedDistance = sp + 64|0;
 $1 = (($tree) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$stack>>2] = $2;
 $3 = (($extents) + 4|0);
 $4 = (($extents) + 8|0);
 $5 = (($extents) + 12|0);
 $6 = (($0) + 4|0);
 $7 = (($0) + 8|0);
 $8 = (($0) + 12|0);
 $stackIndex$07 = 1;
 L1: while(1) {
  $9 = (($stackIndex$07) + -1)|0;
  $10 = (($stack) + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($11) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($11) + 8|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($11) + 16|0);
  $18 = $17;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = (($18) + 4)|0;
  $22 = $21;
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & -256;
  $25 = (HEAP32[tempDoublePtr>>2]=$24,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $26 = Math_fround($25 * Math_fround(9.99999974737875163555E-5));
  $27 = (HEAPF32[tempDoublePtr>>2]=$12,HEAP32[tempDoublePtr>>2]|0);
  $28 = (HEAPF32[tempDoublePtr>>2]=$14,HEAP32[tempDoublePtr>>2]|0);
  $29 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $30 = $27 & 255;
  $31 = $28 & 255;
  $32 = $29 & 255;
  $33 = (Math_fround(($30|0)));
  $34 = (Math_fround(($31|0)));
  $35 = (Math_fround(($32|0)));
  $36 = Math_fround($33 * $26);
  $37 = Math_fround($34 * $26);
  $38 = Math_fround($35 * $26);
  HEAPF32[$extents>>2] = $36;
  HEAPF32[$3>>2] = $37;
  HEAPF32[$4>>2] = $38;
  HEAPF32[$5>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = $12;
  HEAPF32[$6>>2] = $14;
  HEAPF32[$7>>2] = $16;
  HEAPF32[$8>>2] = Math_fround(0.0);
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;
  ;HEAP32[$extents$byval_copy2+0>>2]=HEAP32[$extents+0>>2]|0;HEAP32[$extents$byval_copy2+4>>2]=HEAP32[$extents+4>>2]|0;HEAP32[$extents$byval_copy2+8>>2]=HEAP32[$extents+8>>2]|0;HEAP32[$extents$byval_copy2+12>>2]=HEAP32[$extents+12>>2]|0;
  $39 = (__ZNK5physx2Gu11RayAABBTest5checkILb1EEEjNS_6shdfnd3aos5Vec3VES5_($test,$$byval_copy1,$extents$byval_copy2)|0);
  $40 = ($39|0)==(0);
  L3: do {
   if ($40) {
    $stackIndex$0$be = $9;
   } else {
    $node$05 = $11;$stackIndex$16 = $9;
    while(1) {
     $41 = (($node$05) + 16|0);
     $42 = $41;
     $43 = $42;
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + 4)|0;
     $46 = $45;
     $47 = HEAP32[$46>>2]|0;
     $48 = $44 & 1;
     $49 = ($48|0)==(0);
     $50 = (0)==(0);
     $51 = $49 & $50;
     if (!($51)) {
      break;
     }
     $63 = (_bitshift64Lshr(($44|0),($47|0),21)|0);
     $64 = tempRet0;
     $65 = $63 & 524287;
     $66 = (($2) + (($65*24)|0)|0);
     $$sum = (($65) + 1)|0;
     $67 = (($2) + (($$sum*24)|0)|0);
     $68 = (($stackIndex$16) + 1)|0;
     $69 = (($stack) + ($stackIndex$16<<2)|0);
     HEAP32[$69>>2] = $67;
     $70 = Math_fround(HEAPF32[$66>>2]);
     $71 = ((($2) + (($65*24)|0)|0) + 4|0);
     $72 = Math_fround(HEAPF32[$71>>2]);
     $73 = ((($2) + (($65*24)|0)|0) + 8|0);
     $74 = Math_fround(HEAPF32[$73>>2]);
     $75 = ((($2) + (($65*24)|0)|0) + 16|0);
     $76 = $75;
     $77 = $76;
     $78 = HEAP32[$77>>2]|0;
     $79 = (($76) + 4)|0;
     $80 = $79;
     $81 = HEAP32[$80>>2]|0;
     $82 = $81 & -256;
     $83 = (HEAP32[tempDoublePtr>>2]=$82,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $84 = Math_fround($83 * Math_fround(9.99999974737875163555E-5));
     $85 = (HEAPF32[tempDoublePtr>>2]=$70,HEAP32[tempDoublePtr>>2]|0);
     $86 = (HEAPF32[tempDoublePtr>>2]=$72,HEAP32[tempDoublePtr>>2]|0);
     $87 = (HEAPF32[tempDoublePtr>>2]=$74,HEAP32[tempDoublePtr>>2]|0);
     $88 = $85 & 255;
     $89 = $86 & 255;
     $90 = $87 & 255;
     $91 = (Math_fround(($88|0)));
     $92 = (Math_fround(($89|0)));
     $93 = (Math_fround(($90|0)));
     $94 = Math_fround($91 * $84);
     $95 = Math_fround($92 * $84);
     $96 = Math_fround($93 * $84);
     HEAPF32[$extents>>2] = $94;
     HEAPF32[$3>>2] = $95;
     HEAPF32[$4>>2] = $96;
     HEAPF32[$5>>2] = Math_fround(0.0);
     HEAPF32[$0>>2] = $70;
     HEAPF32[$6>>2] = $72;
     HEAPF32[$7>>2] = $74;
     HEAPF32[$8>>2] = Math_fround(0.0);
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;
     ;HEAP32[$extents$byval_copy2+0>>2]=HEAP32[$extents+0>>2]|0;HEAP32[$extents$byval_copy2+4>>2]=HEAP32[$extents+4>>2]|0;HEAP32[$extents$byval_copy2+8>>2]=HEAP32[$extents+8>>2]|0;HEAP32[$extents$byval_copy2+12>>2]=HEAP32[$extents+12>>2]|0;
     $97 = (__ZNK5physx2Gu11RayAABBTest5checkILb1EEEjNS_6shdfnd3aos5Vec3VES5_($test,$$byval_copy1,$extents$byval_copy2)|0);
     $98 = ($97|0)==(0);
     if ($98) {
      $stackIndex$0$be = $68;
      break L3;
     } else {
      $node$05 = $66;$stackIndex$16 = $68;
     }
    }
    $52 = HEAP32[$tree>>2]|0;
    $53 = (_bitshift64Lshr(($44|0),($47|0),21)|0);
    $54 = tempRet0;
    $55 = $53 & 524287;
    $56 = (($52) + ($55<<2)|0);
    $57 = HEAP32[$visitor>>2]|0;
    $58 = HEAP32[$57>>2]|0;
    $59 = HEAP32[$56>>2]|0;
    $60 = (($objects) + ($59<<3)|0);
    $61 = (FUNCTION_TABLE_iiiii[$58 & 511]($visitor,$unusedDistance,$60,1)|0);
    if ($61) {
     $stackIndex$0$be = $stackIndex$16;
    } else {
     $$0 = 0;
     label = 7;
     break L1;
    }
   }
  } while(0);
  $62 = ($stackIndex$0$be|0)==(0);
  if ($62) {
   $$0 = 1;
   label = 7;
   break;
  } else {
   $stackIndex$07 = $stackIndex$0$be;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN15AABBTreeOverlapIN5physx2Gu14SphereAABBTestEEclEPNS0_2Sq13PrunerPayloadERKNS4_8AABBTreeERKS2_RNS4_14PrunerCallbackE($this,$objects,$tree,$test,$visitor) {
 $this = $this|0;
 $objects = $objects|0;
 $tree = $tree|0;
 $test = $test|0;
 $visitor = $visitor|0;
 var $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$1$i$i$i = Math_fround(0), $$1$i9$i$i = Math_fround(0), $$sum = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0);
 var $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $node$0 = 0, $stack = 0, $stackIndex$020 = 0, $stackIndex$1 = 0, $unusedDistance = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $stack = sp + 8|0;
 $unusedDistance = sp;
 $0 = (($tree) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$stack>>2] = $1;
 $2 = (($test) + 4|0);
 $3 = (($test) + 8|0);
 $4 = (($test) + 16|0);
 $stackIndex$020 = 1;
 while(1) {
  $5 = (($stackIndex$020) + -1)|0;
  $6 = (($stack) + ($5<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($7) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($7) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($7) + 16|0);
  $14 = $13;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & -256;
  $21 = (HEAP32[tempDoublePtr>>2]=$20,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $22 = Math_fround($21 * Math_fround(9.99999974737875163555E-5));
  $23 = (HEAPF32[tempDoublePtr>>2]=$8,HEAP32[tempDoublePtr>>2]|0);
  $24 = (HEAPF32[tempDoublePtr>>2]=$10,HEAP32[tempDoublePtr>>2]|0);
  $25 = (HEAPF32[tempDoublePtr>>2]=$12,HEAP32[tempDoublePtr>>2]|0);
  $26 = $23 & 255;
  $27 = $24 & 255;
  $28 = $25 & 255;
  $29 = (Math_fround(($26|0)));
  $30 = (Math_fround(($27|0)));
  $31 = (Math_fround(($28|0)));
  $32 = Math_fround($29 * $22);
  $33 = Math_fround($30 * $22);
  $34 = Math_fround($31 * $22);
  $35 = Math_fround(HEAPF32[$test>>2]);
  $36 = Math_fround(HEAPF32[$2>>2]);
  $37 = Math_fround(HEAPF32[$3>>2]);
  $38 = Math_fround(HEAPF32[$4>>2]);
  $40 = $8;$42 = $10;$44 = $12;$46 = $32;$48 = $33;$50 = $34;$node$0 = $7;$stackIndex$1 = $5;
  while(1) {
   $39 = Math_fround($35 - $40);
   $41 = Math_fround($36 - $42);
   $43 = Math_fround($37 - $44);
   $45 = Math_fround(-$46);
   $47 = Math_fround(-$48);
   $49 = Math_fround(-$50);
   $51 = $39 < $46;
   $$$i$i$i = $51 ? $39 : $46;
   $52 = $41 < $48;
   $53 = $52 ? $41 : $48;
   $54 = $43 < $50;
   $$1$i$i$i = $54 ? $43 : $50;
   $55 = $$$i$i$i > $45;
   $$$i8$i$i = $55 ? $$$i$i$i : $45;
   $56 = $53 > $47;
   $57 = $56 ? $53 : $47;
   $58 = $$1$i$i$i > $49;
   $$1$i9$i$i = $58 ? $$1$i$i$i : $49;
   $59 = Math_fround($39 - $$$i8$i$i);
   $60 = Math_fround($41 - $57);
   $61 = Math_fround($43 - $$1$i9$i$i);
   $62 = Math_fround($59 * $59);
   $63 = Math_fround($60 * $60);
   $64 = Math_fround($62 + $63);
   $65 = Math_fround($61 * $61);
   $66 = Math_fround($64 + $65);
   $67 = !($38 >= $66);
   if ($67) {
    break;
   }
   $68 = (($node$0) + 16|0);
   $69 = $68;
   $70 = $69;
   $71 = HEAP32[$70>>2]|0;
   $72 = (($69) + 4)|0;
   $73 = $72;
   $74 = HEAP32[$73>>2]|0;
   $75 = $71 & 1;
   $76 = ($75|0)==(0);
   $77 = (0)==(0);
   $78 = $76 & $77;
   if (!($78)) {
    label = 5;
    break;
   }
   $90 = (_bitshift64Lshr(($71|0),($74|0),21)|0);
   $91 = tempRet0;
   $92 = $90 & 524287;
   $93 = (($1) + (($92*24)|0)|0);
   $$sum = (($92) + 1)|0;
   $94 = (($1) + (($$sum*24)|0)|0);
   $95 = (($stackIndex$1) + 1)|0;
   $96 = (($stack) + ($stackIndex$1<<2)|0);
   HEAP32[$96>>2] = $94;
   $97 = Math_fround(HEAPF32[$93>>2]);
   $98 = ((($1) + (($92*24)|0)|0) + 4|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $100 = ((($1) + (($92*24)|0)|0) + 8|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = ((($1) + (($92*24)|0)|0) + 16|0);
   $103 = $102;
   $104 = $103;
   $105 = HEAP32[$104>>2]|0;
   $106 = (($103) + 4)|0;
   $107 = $106;
   $108 = HEAP32[$107>>2]|0;
   $109 = $108 & -256;
   $110 = (HEAP32[tempDoublePtr>>2]=$109,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $111 = Math_fround($110 * Math_fround(9.99999974737875163555E-5));
   $112 = (HEAPF32[tempDoublePtr>>2]=$97,HEAP32[tempDoublePtr>>2]|0);
   $113 = (HEAPF32[tempDoublePtr>>2]=$99,HEAP32[tempDoublePtr>>2]|0);
   $114 = (HEAPF32[tempDoublePtr>>2]=$101,HEAP32[tempDoublePtr>>2]|0);
   $115 = $112 & 255;
   $116 = $113 & 255;
   $117 = $114 & 255;
   $118 = (Math_fround(($115|0)));
   $119 = (Math_fround(($116|0)));
   $120 = (Math_fround(($117|0)));
   $121 = Math_fround($118 * $111);
   $122 = Math_fround($119 * $111);
   $123 = Math_fround($120 * $111);
   $40 = $97;$42 = $99;$44 = $101;$46 = $121;$48 = $122;$50 = $123;$node$0 = $93;$stackIndex$1 = $95;
  }
  if ((label|0) == 5) {
   label = 0;
   $79 = HEAP32[$tree>>2]|0;
   $80 = (_bitshift64Lshr(($71|0),($74|0),21)|0);
   $81 = tempRet0;
   $82 = $80 & 524287;
   $83 = (($79) + ($82<<2)|0);
   $84 = HEAP32[$visitor>>2]|0;
   $85 = HEAP32[$84>>2]|0;
   $86 = HEAP32[$83>>2]|0;
   $87 = (($objects) + ($86<<3)|0);
   $88 = (FUNCTION_TABLE_iiiii[$85 & 511]($visitor,$unusedDistance,$87,1)|0);
   if (!($88)) {
    $$0 = 0;
    label = 8;
    break;
   }
  }
  $89 = ($stackIndex$1|0)==(0);
  if ($89) {
   $$0 = 1;
   label = 8;
   break;
  } else {
   $stackIndex$020 = $stackIndex$1;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Sq10AABBPruner5sweepERKNS0_9ShapeDataERKNS_6PxVec3ERfRNS0_14PrunerCallbackE($this,$queryVolume,$unitDir,$inOutDistance,$pcb) {
 $this = $this|0;
 $queryVolume = $queryVolume|0;
 $unitDir = $unitDir|0;
 $inOutDistance = $inOutDistance|0;
 $pcb = $pcb|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $again$1$off0 = 0, $extents = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $extents = sp + 12|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($queryVolume) + 132|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($queryVolume) + 120|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround($5 - $7);
  $9 = (($queryVolume) + 136|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($queryVolume) + 124|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($10 - $12);
  $14 = (($queryVolume) + 140|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($queryVolume) + 128|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($15 - $17);
  $19 = Math_fround($8 * Math_fround(0.5));
  $20 = Math_fround($13 * Math_fround(0.5));
  $21 = Math_fround($18 * Math_fround(0.5));
  HEAPF32[$extents>>2] = $19;
  $22 = (($extents) + 4|0);
  HEAPF32[$22>>2] = $20;
  $23 = (($extents) + 8|0);
  HEAPF32[$23>>2] = $21;
  $24 = (($this) + 7776|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = Math_fround($7 + $5);
  $27 = Math_fround($12 + $10);
  $28 = Math_fround($17 + $15);
  $29 = Math_fround($26 * Math_fround(0.5));
  $30 = Math_fround($27 * Math_fround(0.5));
  $31 = Math_fround($28 * Math_fround(0.5));
  HEAPF32[$0>>2] = $29;
  $32 = (($0) + 4|0);
  HEAPF32[$32>>2] = $30;
  $33 = (($0) + 8|0);
  HEAPF32[$33>>2] = $31;
  $34 = (__ZN15AABBTreeRaycastILb1EEclEPN5physx2Sq13PrunerPayloadERKNS2_8AABBTreeERKNS1_6PxVec3ESA_RfSA_RNS2_14PrunerCallbackE(0,$25,$2,$0,$unitDir,$inOutDistance,$extents,$pcb)|0);
  if (!($34)) {
   $again$1$off0 = 0;
   STACKTOP = sp;return ($again$1$off0|0);
  }
 }
 $35 = (($this) + 7808|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)==(0);
 if ($37) {
  $again$1$off0 = 1;
  STACKTOP = sp;return ($again$1$off0|0);
 }
 $38 = (($this) + 92|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 if ($40) {
  $41 = (($this) + 136|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0);
  if ($43) {
   $again$1$off0 = 1;
   STACKTOP = sp;return ($again$1$off0|0);
  }
 }
 $44 = (($this) + 144|0);
 $45 = (__ZNK5physx2Sq16BucketPrunerCore5sweepERKNS0_9ShapeDataERKNS_6PxVec3ERfRNS0_14PrunerCallbackE($44,$queryVolume,$unitDir,$inOutDistance,$pcb)|0);
 $again$1$off0 = $45;
 STACKTOP = sp;return ($again$1$off0|0);
}
function __ZN15AABBTreeRaycastILb1EEclEPN5physx2Sq13PrunerPayloadERKNS2_8AABBTreeERKNS1_6PxVec3ESA_RfSA_RNS2_14PrunerCallbackE($this,$objects,$tree,$origin,$unitDir,$maxDist,$inflation,$pcb) {
 $this = $this|0;
 $objects = $objects|0;
 $tree = $tree|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $maxDist = $maxDist|0;
 $inflation = $inflation|0;
 $pcb = $pcb|0;
 var $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i16 = Math_fround(0), $$$i$i$i37 = Math_fround(0), $$$i8$i = Math_fround(0), $$0 = 0, $$1$i$i = Math_fround(0), $$1$i$i$i = Math_fround(0), $$1$i$i$i25 = Math_fround(0), $$1$i$i$i46 = Math_fround(0), $$1$i9$i = Math_fround(0), $$316$i = 0, $$316$i23 = 0, $$316$i44 = 0, $$mux = 0, $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum131 = 0, $$sum132 = 0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0;
 var $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge = 0, $brmerge$demorgan$i = 0, $brmerge$demorgan$i24 = 0, $brmerge$demorgan$i45 = 0, $md = 0, $node$0 = 0, $node$0$ph = 0, $not$$i = 0, $not$$i22 = 0, $not$$i43 = 0, $not$320$i = 0;
 var $not$320$i19 = 0, $not$320$i40 = 0, $not$325$i = 0, $not$325$i28 = 0, $not$325$i49 = 0, $notlhs321$i = 0, $notlhs321$i17 = 0, $notlhs321$i38 = 0, $notlhs323$i = 0, $notlhs323$i20 = 0, $notlhs323$i41 = 0, $notlhs326$i = 0, $notlhs326$i26 = 0, $notlhs326$i47 = 0, $notrhs322$i = 0, $notrhs322$i18 = 0, $notrhs322$i39 = 0, $notrhs324$i = 0, $notrhs324$i21 = 0, $notrhs324$i42 = 0;
 var $notrhs327$i = 0, $notrhs327$i27 = 0, $notrhs327$i48 = 0, $or$cond$demorgan = 0, $stack = 0, $stackIndex$0$be = 0, $stackIndex$1$ph = 0, $test = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1168|0;
 $test = sp;
 $stack = sp + 136|0;
 $md = sp + 128|0;
 $0 = Math_fround(HEAPF32[$maxDist>>2]);
 __ZN5physx2Gu11RayAABBTestC2ERKNS_6PxVec3ES4_fS4_($test,$origin,$unitDir,$0,$inflation);
 $1 = (($tree) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$stack>>2] = $2;
 $3 = (($test) + 48|0);
 $4 = (($test) + 52|0);
 $5 = (($test) + 56|0);
 $6 = (($test) + 4|0);
 $7 = (($test) + 8|0);
 $8 = (($test) + 32|0);
 $9 = (($test) + 36|0);
 $10 = (($test) + 40|0);
 $11 = (($test) + 16|0);
 $12 = (($test) + 20|0);
 $13 = (($test) + 24|0);
 $14 = (($test) + 80|0);
 $15 = (($test) + 84|0);
 $16 = (($test) + 64|0);
 $17 = (($test) + 68|0);
 $18 = (($test) + 96|0);
 $19 = (($test) + 100|0);
 $20 = (($test) + 112|0);
 $21 = (($test) + 116|0);
 $22 = (($test) + 72|0);
 $23 = (($test) + 88|0);
 $24 = (($test) + 120|0);
 $25 = (($test) + 104|0);
 $26 = (($test) + 108|0);
 $27 = (($test) + 124|0);
 $29 = $2;$328 = 0;
 L1: while(1) {
  $28 = Math_fround(HEAPF32[$29>>2]);
  $30 = (($29) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($29) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($29) + 16|0);
  $35 = $34;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + 4)|0;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & -256;
  $42 = (HEAP32[tempDoublePtr>>2]=$41,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $43 = Math_fround($42 * Math_fround(9.99999974737875163555E-5));
  $44 = (HEAPF32[tempDoublePtr>>2]=$28,HEAP32[tempDoublePtr>>2]|0);
  $45 = (HEAPF32[tempDoublePtr>>2]=$31,HEAP32[tempDoublePtr>>2]|0);
  $46 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $47 = $44 & 255;
  $48 = $45 & 255;
  $49 = $46 & 255;
  $50 = (Math_fround(($47|0)));
  $51 = (Math_fround(($48|0)));
  $52 = (Math_fround(($49|0)));
  $53 = Math_fround($50 * $43);
  $54 = Math_fround($51 * $43);
  $55 = Math_fround($52 * $43);
  $56 = Math_fround(HEAPF32[$3>>2]);
  $57 = Math_fround(HEAPF32[$4>>2]);
  $58 = Math_fround(HEAPF32[$5>>2]);
  $59 = Math_fround($56 + $53);
  $60 = Math_fround($57 + $54);
  $61 = Math_fround($58 + $55);
  $62 = Math_fround($28 + $59);
  $63 = Math_fround($31 + $60);
  $64 = Math_fround($28 - $59);
  $65 = Math_fround($31 - $60);
  $66 = Math_fround(HEAPF32[$test>>2]);
  $67 = Math_fround(HEAPF32[$6>>2]);
  $68 = Math_fround(HEAPF32[$7>>2]);
  $69 = Math_fround($66 - $28);
  $70 = Math_fround($67 - $31);
  $71 = Math_fround($68 - $33);
  $72 = Math_fround(HEAPF32[$8>>2]);
  $73 = Math_fround(HEAPF32[$9>>2]);
  $74 = Math_fround(HEAPF32[$10>>2]);
  $75 = Math_fround(HEAPF32[$11>>2]);
  $76 = Math_fround(HEAPF32[$12>>2]);
  $77 = Math_fround(HEAPF32[$13>>2]);
  $78 = Math_fround($70 * $75);
  $79 = Math_fround($71 * $76);
  $80 = Math_fround($69 * $77);
  $81 = Math_fround($69 * $72);
  $82 = Math_fround($70 * $73);
  $83 = Math_fround($71 * $74);
  $84 = Math_fround($78 - $81);
  $85 = Math_fround($79 - $82);
  $86 = Math_fround($80 - $83);
  $87 = Math_fround(HEAPF32[$14>>2]);
  $88 = Math_fround(HEAPF32[$15>>2]);
  $89 = Math_fround(HEAPF32[$16>>2]);
  $90 = Math_fround(HEAPF32[$17>>2]);
  $91 = Math_fround($60 * $89);
  $92 = Math_fround($61 * $90);
  $93 = Math_fround($59 * $87);
  $94 = Math_fround($60 * $88);
  $95 = Math_fround($93 + $91);
  $96 = Math_fround($94 + $92);
  $97 = Math_fround(HEAPF32[$18>>2]);
  $98 = Math_fround(HEAPF32[$19>>2]);
  $99 = Math_fround(HEAPF32[$20>>2]);
  $100 = Math_fround(HEAPF32[$21>>2]);
  $101 = Math_fround(-$84);
  $102 = Math_fround(-$85);
  $103 = Math_fround(-$86);
  $104 = $84 > $101;
  $$$i$i$i37 = $104 ? $84 : $101;
  $105 = $85 > $102;
  $106 = $105 ? $85 : $102;
  $107 = $95 >= $$$i$i$i37;
  $108 = $96 >= $106;
  $notlhs321$i38 = $62 >= $97;
  $notrhs322$i39 = $99 >= $64;
  $not$320$i40 = $notrhs322$i39 & $notlhs321$i38;
  $109 = $107 & $not$320$i40;
  $notlhs323$i41 = $63 >= $98;
  $notrhs324$i42 = $100 >= $65;
  $not$$i43 = $notrhs324$i42 & $notlhs323$i41;
  $$316$i44 = $108 & $not$$i43;
  $brmerge$demorgan$i45 = $109 & $$316$i44;
  L3: do {
   if ($brmerge$demorgan$i45) {
    $110 = Math_fround(HEAPF32[$22>>2]);
    $111 = Math_fround(HEAPF32[$23>>2]);
    $112 = $86 > $103;
    $113 = Math_fround($61 * $111);
    $114 = Math_fround($59 * $110);
    $$1$i$i$i46 = $112 ? $86 : $103;
    $115 = Math_fround($114 + $113);
    $116 = Math_fround(HEAPF32[$24>>2]);
    $117 = Math_fround($33 - $61);
    $118 = Math_fround($33 + $61);
    $119 = Math_fround(HEAPF32[$25>>2]);
    $120 = $115 >= $$1$i$i$i46;
    $notlhs326$i47 = $118 >= $119;
    $notrhs327$i48 = $116 >= $117;
    $not$325$i49 = $notrhs327$i48 & $notlhs326$i47;
    $121 = $120 & $not$325$i49;
    if ($121) {
     $122 = Math_fround(HEAPF32[$maxDist>>2]);
     HEAPF32[$md>>2] = $122;
     $node$0$ph = $29;$stackIndex$1$ph = $328;
     L6: while(1) {
      $node$0 = $node$0$ph;
      while(1) {
       $123 = (($node$0) + 16|0);
       $124 = $123;
       $125 = $124;
       $126 = HEAP32[$125>>2]|0;
       $127 = (($124) + 4)|0;
       $128 = $127;
       $129 = HEAP32[$128>>2]|0;
       $130 = $126 & 1;
       $131 = ($130|0)==(0);
       $132 = (0)==(0);
       $133 = $131 & $132;
       if (!($133)) {
        break L6;
       }
       $134 = (_bitshift64Lshr(($126|0),($129|0),21)|0);
       $135 = tempRet0;
       $136 = $134 & 524287;
       $137 = (($2) + (($136*24)|0)|0);
       $138 = Math_fround(HEAPF32[$137>>2]);
       $139 = ((($2) + (($136*24)|0)|0) + 4|0);
       $140 = Math_fround(HEAPF32[$139>>2]);
       $141 = ((($2) + (($136*24)|0)|0) + 8|0);
       $142 = Math_fround(HEAPF32[$141>>2]);
       $143 = ((($2) + (($136*24)|0)|0) + 16|0);
       $144 = $143;
       $145 = $144;
       $146 = HEAP32[$145>>2]|0;
       $147 = (($144) + 4)|0;
       $148 = $147;
       $149 = HEAP32[$148>>2]|0;
       $150 = $149 & -256;
       $151 = (HEAP32[tempDoublePtr>>2]=$150,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $152 = Math_fround($151 * Math_fround(9.99999974737875163555E-5));
       $153 = (HEAPF32[tempDoublePtr>>2]=$138,HEAP32[tempDoublePtr>>2]|0);
       $154 = (HEAPF32[tempDoublePtr>>2]=$140,HEAP32[tempDoublePtr>>2]|0);
       $155 = (HEAPF32[tempDoublePtr>>2]=$142,HEAP32[tempDoublePtr>>2]|0);
       $156 = $153 & 255;
       $157 = $154 & 255;
       $158 = $155 & 255;
       $159 = (Math_fround(($156|0)));
       $160 = (Math_fround(($157|0)));
       $161 = (Math_fround(($158|0)));
       $162 = Math_fround($159 * $152);
       $163 = Math_fround($160 * $152);
       $164 = Math_fround($161 * $152);
       $165 = Math_fround($56 + $162);
       $166 = Math_fround($57 + $163);
       $167 = Math_fround($58 + $164);
       $168 = Math_fround($138 + $165);
       $169 = Math_fround($140 + $166);
       $170 = Math_fround($138 - $165);
       $171 = Math_fround($140 - $166);
       $172 = Math_fround($66 - $138);
       $173 = Math_fround($67 - $140);
       $174 = Math_fround($68 - $142);
       $175 = Math_fround($173 * $75);
       $176 = Math_fround($174 * $76);
       $177 = Math_fround($172 * $77);
       $178 = Math_fround($172 * $72);
       $179 = Math_fround($173 * $73);
       $180 = Math_fround($174 * $74);
       $181 = Math_fround($175 - $178);
       $182 = Math_fround($176 - $179);
       $183 = Math_fround($177 - $180);
       $184 = Math_fround($166 * $89);
       $185 = Math_fround($167 * $90);
       $186 = Math_fround($165 * $87);
       $187 = Math_fround($166 * $88);
       $188 = Math_fround($186 + $184);
       $189 = Math_fround($187 + $185);
       $190 = Math_fround(-$181);
       $191 = Math_fround(-$182);
       $192 = Math_fround(-$183);
       $193 = $181 > $190;
       $$$i$i$i16 = $193 ? $181 : $190;
       $194 = $182 > $191;
       $195 = $194 ? $182 : $191;
       $196 = $188 >= $$$i$i$i16;
       $197 = $189 >= $195;
       $notlhs321$i17 = $168 >= $97;
       $notrhs322$i18 = $99 >= $170;
       $not$320$i19 = $notrhs322$i18 & $notlhs321$i17;
       $198 = $196 & $not$320$i19;
       $notlhs323$i20 = $169 >= $98;
       $notrhs324$i21 = $100 >= $171;
       $not$$i22 = $notrhs324$i21 & $notlhs323$i20;
       $$316$i23 = $197 & $not$$i22;
       $brmerge$demorgan$i24 = $198 & $$316$i23;
       if ($brmerge$demorgan$i24) {
        $199 = $183 > $192;
        $200 = Math_fround($167 * $111);
        $201 = Math_fround($165 * $110);
        $$1$i$i$i25 = $199 ? $183 : $192;
        $202 = Math_fround($201 + $200);
        $203 = Math_fround($142 - $167);
        $204 = Math_fround($142 + $167);
        $205 = $202 >= $$1$i$i$i25;
        $notlhs326$i26 = $204 >= $119;
        $notrhs327$i27 = $116 >= $203;
        $not$325$i28 = $notrhs327$i27 & $notlhs326$i26;
        $206 = $205 & $not$325$i28;
        $277 = $206;
       } else {
        $277 = 0;
       }
       $$sum = (($136) + 1)|0;
       $207 = (($2) + (($$sum*24)|0)|0);
       $208 = Math_fround(HEAPF32[$207>>2]);
       $209 = ((($2) + (($$sum*24)|0)|0) + 4|0);
       $210 = Math_fround(HEAPF32[$209>>2]);
       $211 = ((($2) + (($$sum*24)|0)|0) + 8|0);
       $212 = Math_fround(HEAPF32[$211>>2]);
       $213 = ((($2) + (($$sum*24)|0)|0) + 16|0);
       $214 = $213;
       $215 = $214;
       $216 = HEAP32[$215>>2]|0;
       $217 = (($214) + 4)|0;
       $218 = $217;
       $219 = HEAP32[$218>>2]|0;
       $220 = $219 & -256;
       $221 = (HEAP32[tempDoublePtr>>2]=$220,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $222 = Math_fround($221 * Math_fround(9.99999974737875163555E-5));
       $223 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
       $224 = (HEAPF32[tempDoublePtr>>2]=$210,HEAP32[tempDoublePtr>>2]|0);
       $225 = (HEAPF32[tempDoublePtr>>2]=$212,HEAP32[tempDoublePtr>>2]|0);
       $226 = $223 & 255;
       $227 = $224 & 255;
       $228 = $225 & 255;
       $229 = (Math_fround(($226|0)));
       $230 = (Math_fround(($227|0)));
       $231 = (Math_fround(($228|0)));
       $232 = Math_fround($229 * $222);
       $233 = Math_fround($230 * $222);
       $234 = Math_fround($231 * $222);
       $235 = Math_fround($56 + $232);
       $236 = Math_fround($57 + $233);
       $237 = Math_fround($58 + $234);
       $238 = Math_fround($208 + $235);
       $239 = Math_fround($210 + $236);
       $240 = Math_fround($208 - $235);
       $241 = Math_fround($210 - $236);
       $242 = Math_fround($66 - $208);
       $243 = Math_fround($67 - $210);
       $244 = Math_fround($68 - $212);
       $245 = Math_fround($243 * $75);
       $246 = Math_fround($244 * $76);
       $247 = Math_fround($242 * $77);
       $248 = Math_fround($242 * $72);
       $249 = Math_fround($243 * $73);
       $250 = Math_fround($244 * $74);
       $251 = Math_fround($245 - $248);
       $252 = Math_fround($246 - $249);
       $253 = Math_fround($247 - $250);
       $254 = Math_fround($236 * $89);
       $255 = Math_fround($237 * $90);
       $256 = Math_fround($235 * $87);
       $257 = Math_fround($236 * $88);
       $258 = Math_fround($256 + $254);
       $259 = Math_fround($257 + $255);
       $260 = Math_fround(-$251);
       $261 = Math_fround(-$252);
       $262 = Math_fround(-$253);
       $263 = $251 > $260;
       $$$i$i$i = $263 ? $251 : $260;
       $264 = $252 > $261;
       $265 = $264 ? $252 : $261;
       $266 = $258 >= $$$i$i$i;
       $267 = $259 >= $265;
       $notlhs321$i = $238 >= $97;
       $notrhs322$i = $99 >= $240;
       $not$320$i = $notrhs322$i & $notlhs321$i;
       $268 = $266 & $not$320$i;
       $notlhs323$i = $239 >= $98;
       $notrhs324$i = $100 >= $241;
       $not$$i = $notrhs324$i & $notlhs323$i;
       $$316$i = $267 & $not$$i;
       $brmerge$demorgan$i = $268 & $$316$i;
       if ($brmerge$demorgan$i) {
        $269 = $253 > $262;
        $270 = Math_fround($237 * $111);
        $271 = Math_fround($235 * $110);
        $$1$i$i$i = $269 ? $253 : $262;
        $272 = Math_fround($271 + $270);
        $273 = Math_fround($212 - $237);
        $274 = Math_fround($212 + $237);
        $275 = $272 >= $$1$i$i$i;
        $notlhs326$i = $274 >= $119;
        $notrhs327$i = $116 >= $273;
        $not$325$i = $notrhs327$i & $notlhs326$i;
        $276 = $275 & $not$325$i;
        $or$cond$demorgan = $277 & $276;
        if ($or$cond$demorgan) {
         break;
        } else {
         $293 = $276;
        }
       } else {
        $293 = 0;
       }
       $brmerge = $277 | $293;
       $$mux = $277 ? $137 : $207;
       if ($brmerge) {
        $node$0 = $$mux;
       } else {
        $stackIndex$0$be = $stackIndex$1$ph;
        break L3;
       }
      }
      $278 = Math_fround($208 - $138);
      $279 = Math_fround($210 - $140);
      $280 = Math_fround($212 - $142);
      $281 = Math_fround($278 * $75);
      $282 = Math_fround($279 * $76);
      $283 = Math_fround($281 + $282);
      $284 = Math_fround($280 * $77);
      $285 = Math_fround($283 + $284);
      $286 = $285 > Math_fround(0.0);
      $287 = $286&1;
      $$sum131 = (($287) + ($136))|0;
      $288 = (($2) + (($$sum131*24)|0)|0);
      $289 = (($stackIndex$1$ph) + 1)|0;
      $290 = (($stack) + ($stackIndex$1$ph<<2)|0);
      HEAP32[$290>>2] = $288;
      $291 = $287 ^ 1;
      $$sum132 = (($291) + ($136))|0;
      $292 = (($2) + (($$sum132*24)|0)|0);
      $node$0$ph = $292;$stackIndex$1$ph = $289;
     }
     $294 = HEAP32[$tree>>2]|0;
     $295 = (_bitshift64Lshr(($126|0),($129|0),21)|0);
     $296 = tempRet0;
     $297 = $295 & 524287;
     $298 = (($294) + ($297<<2)|0);
     $299 = HEAP32[$pcb>>2]|0;
     $300 = HEAP32[$299>>2]|0;
     $301 = HEAP32[$298>>2]|0;
     $302 = (($objects) + ($301<<3)|0);
     $303 = (FUNCTION_TABLE_iiiii[$300 & 511]($pcb,$md,$302,1)|0);
     if (!($303)) {
      $$0 = 0;
      label = 18;
      break L1;
     }
     $304 = Math_fround(HEAPF32[$md>>2]);
     $305 = $304 < $122;
     if ($305) {
      HEAPF32[$maxDist>>2] = $304;
      $306 = Math_fround(HEAPF32[$11>>2]);
      $307 = Math_fround(HEAPF32[$12>>2]);
      $308 = Math_fround(HEAPF32[$13>>2]);
      $309 = Math_fround(HEAPF32[$test>>2]);
      $310 = Math_fround(HEAPF32[$6>>2]);
      $311 = Math_fround(HEAPF32[$7>>2]);
      $312 = Math_fround($304 * $306);
      $313 = Math_fround($304 * $307);
      $314 = Math_fround($304 * $308);
      $315 = Math_fround($312 + $309);
      $316 = Math_fround($313 + $310);
      $317 = Math_fround($314 + $311);
      $318 = $309 < $315;
      $$$i8$i = $318 ? $309 : $315;
      $319 = $310 < $316;
      $320 = $319 ? $310 : $316;
      $321 = $311 < $317;
      $$1$i9$i = $321 ? $311 : $317;
      HEAPF32[$18>>2] = $$$i8$i;
      HEAPF32[$19>>2] = $320;
      HEAPF32[$25>>2] = $$1$i9$i;
      HEAPF32[$26>>2] = Math_fround(0.0);
      $322 = $309 > $315;
      $$$i$i = $322 ? $309 : $315;
      $323 = $310 > $316;
      $324 = $323 ? $310 : $316;
      $325 = $311 > $317;
      $$1$i$i = $325 ? $311 : $317;
      HEAPF32[$20>>2] = $$$i$i;
      HEAPF32[$21>>2] = $324;
      HEAPF32[$24>>2] = $$1$i$i;
      HEAPF32[$27>>2] = Math_fround(0.0);
      $stackIndex$0$be = $stackIndex$1$ph;
     } else {
      $stackIndex$0$be = $stackIndex$1$ph;
     }
    } else {
     $stackIndex$0$be = $328;
    }
   } else {
    $stackIndex$0$be = $328;
   }
  } while(0);
  $326 = (($stackIndex$0$be) + -1)|0;
  $327 = ($stackIndex$0$be|0)==(0);
  if ($327) {
   $$0 = 1;
   label = 18;
   break;
  }
  $$phi$trans$insert = (($stack) + ($326<<2)|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $29 = $$pre;$328 = $326;
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Sq10AABBPruner7raycastERKNS_6PxVec3ES4_RfRNS0_14PrunerCallbackE($this,$origin,$unitDir,$inOutDistance,$pcb) {
 $this = $this|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $inOutDistance = $inOutDistance|0;
 $pcb = $pcb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $again$1$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 7776|0);
  $5 = HEAP32[$4>>2]|0;
  HEAPF32[$0>>2] = Math_fround(0.0);
  $6 = (($0) + 4|0);
  HEAPF32[$6>>2] = Math_fround(0.0);
  $7 = (($0) + 8|0);
  HEAPF32[$7>>2] = Math_fround(0.0);
  $8 = (__ZN15AABBTreeRaycastILb0EEclEPN5physx2Sq13PrunerPayloadERKNS2_8AABBTreeERKNS1_6PxVec3ESA_RfSA_RNS2_14PrunerCallbackE(0,$5,$2,$origin,$unitDir,$inOutDistance,$0,$pcb)|0);
  if (!($8)) {
   $again$1$off0 = 0;
   STACKTOP = sp;return ($again$1$off0|0);
  }
 }
 $9 = (($this) + 7808|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $again$1$off0 = 1;
  STACKTOP = sp;return ($again$1$off0|0);
 }
 $12 = (($this) + 92|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = (($this) + 136|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0);
  if ($17) {
   $again$1$off0 = 1;
   STACKTOP = sp;return ($again$1$off0|0);
  }
 }
 $18 = (($this) + 144|0);
 $19 = (__ZNK5physx2Sq16BucketPrunerCore7raycastERKNS_6PxVec3ES4_RfRNS0_14PrunerCallbackE($18,$origin,$unitDir,$inOutDistance,$pcb)|0);
 $again$1$off0 = $19;
 STACKTOP = sp;return ($again$1$off0|0);
}
function __ZN15AABBTreeRaycastILb0EEclEPN5physx2Sq13PrunerPayloadERKNS2_8AABBTreeERKNS1_6PxVec3ESA_RfSA_RNS2_14PrunerCallbackE($this,$objects,$tree,$origin,$unitDir,$maxDist,$inflation,$pcb) {
 $this = $this|0;
 $objects = $objects|0;
 $tree = $tree|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $maxDist = $maxDist|0;
 $inflation = $inflation|0;
 $pcb = $pcb|0;
 var $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i16 = Math_fround(0), $$$i$i$i37 = Math_fround(0), $$$i8$i = Math_fround(0), $$0 = 0, $$1$i$i = Math_fround(0), $$1$i$i$i = Math_fround(0), $$1$i$i$i25 = Math_fround(0), $$1$i$i$i46 = Math_fround(0), $$1$i9$i = Math_fround(0), $$296$i = 0, $$296$i23 = 0, $$296$i44 = 0, $$mux = 0, $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum131 = 0, $$sum132 = 0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $brmerge = 0, $brmerge$demorgan$i = 0, $brmerge$demorgan$i24 = 0, $brmerge$demorgan$i45 = 0, $md = 0, $node$0 = 0;
 var $node$0$ph = 0, $not$$i = 0, $not$$i22 = 0, $not$$i43 = 0, $not$300$i = 0, $not$300$i19 = 0, $not$300$i40 = 0, $not$305$i = 0, $not$305$i28 = 0, $not$305$i49 = 0, $notlhs301$i = 0, $notlhs301$i17 = 0, $notlhs301$i38 = 0, $notlhs303$i = 0, $notlhs303$i20 = 0, $notlhs303$i41 = 0, $notlhs306$i = 0, $notlhs306$i26 = 0, $notlhs306$i47 = 0, $notrhs302$i = 0;
 var $notrhs302$i18 = 0, $notrhs302$i39 = 0, $notrhs304$i = 0, $notrhs304$i21 = 0, $notrhs304$i42 = 0, $notrhs307$i = 0, $notrhs307$i27 = 0, $notrhs307$i48 = 0, $or$cond$demorgan = 0, $stack = 0, $stackIndex$0$be = 0, $stackIndex$1$ph = 0, $test = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1168|0;
 $test = sp;
 $stack = sp + 136|0;
 $md = sp + 128|0;
 $0 = Math_fround(HEAPF32[$maxDist>>2]);
 __ZN5physx2Gu11RayAABBTestC2ERKNS_6PxVec3ES4_fS4_($test,$origin,$unitDir,$0,$inflation);
 $1 = (($tree) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$stack>>2] = $2;
 $3 = (($test) + 4|0);
 $4 = (($test) + 8|0);
 $5 = (($test) + 32|0);
 $6 = (($test) + 36|0);
 $7 = (($test) + 40|0);
 $8 = (($test) + 16|0);
 $9 = (($test) + 20|0);
 $10 = (($test) + 24|0);
 $11 = (($test) + 80|0);
 $12 = (($test) + 84|0);
 $13 = (($test) + 64|0);
 $14 = (($test) + 68|0);
 $15 = (($test) + 96|0);
 $16 = (($test) + 100|0);
 $17 = (($test) + 112|0);
 $18 = (($test) + 116|0);
 $19 = (($test) + 72|0);
 $20 = (($test) + 88|0);
 $21 = (($test) + 120|0);
 $22 = (($test) + 104|0);
 $23 = (($test) + 108|0);
 $24 = (($test) + 124|0);
 $26 = $2;$313 = 0;
 L1: while(1) {
  $25 = Math_fround(HEAPF32[$26>>2]);
  $27 = (($26) + 4|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($26) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($26) + 16|0);
  $32 = $31;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $37 & -256;
  $39 = (HEAP32[tempDoublePtr>>2]=$38,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $40 = Math_fround($39 * Math_fround(9.99999974737875163555E-5));
  $41 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $42 = (HEAPF32[tempDoublePtr>>2]=$28,HEAP32[tempDoublePtr>>2]|0);
  $43 = (HEAPF32[tempDoublePtr>>2]=$30,HEAP32[tempDoublePtr>>2]|0);
  $44 = $41 & 255;
  $45 = $42 & 255;
  $46 = $43 & 255;
  $47 = (Math_fround(($44|0)));
  $48 = (Math_fround(($45|0)));
  $49 = (Math_fround(($46|0)));
  $50 = Math_fround($47 * $40);
  $51 = Math_fround($48 * $40);
  $52 = Math_fround($49 * $40);
  $53 = Math_fround($25 + $50);
  $54 = Math_fround($28 + $51);
  $55 = Math_fround($25 - $50);
  $56 = Math_fround($28 - $51);
  $57 = Math_fround(HEAPF32[$test>>2]);
  $58 = Math_fround(HEAPF32[$3>>2]);
  $59 = Math_fround(HEAPF32[$4>>2]);
  $60 = Math_fround($57 - $25);
  $61 = Math_fround($58 - $28);
  $62 = Math_fround($59 - $30);
  $63 = Math_fround(HEAPF32[$5>>2]);
  $64 = Math_fround(HEAPF32[$6>>2]);
  $65 = Math_fround(HEAPF32[$7>>2]);
  $66 = Math_fround(HEAPF32[$8>>2]);
  $67 = Math_fround(HEAPF32[$9>>2]);
  $68 = Math_fround(HEAPF32[$10>>2]);
  $69 = Math_fround($61 * $66);
  $70 = Math_fround($62 * $67);
  $71 = Math_fround($60 * $68);
  $72 = Math_fround($60 * $63);
  $73 = Math_fround($61 * $64);
  $74 = Math_fround($62 * $65);
  $75 = Math_fround($69 - $72);
  $76 = Math_fround($70 - $73);
  $77 = Math_fround($71 - $74);
  $78 = Math_fround(HEAPF32[$11>>2]);
  $79 = Math_fround(HEAPF32[$12>>2]);
  $80 = Math_fround(HEAPF32[$13>>2]);
  $81 = Math_fround(HEAPF32[$14>>2]);
  $82 = Math_fround($51 * $80);
  $83 = Math_fround($52 * $81);
  $84 = Math_fround($50 * $78);
  $85 = Math_fround($51 * $79);
  $86 = Math_fround($84 + $82);
  $87 = Math_fround($85 + $83);
  $88 = Math_fround(HEAPF32[$15>>2]);
  $89 = Math_fround(HEAPF32[$16>>2]);
  $90 = Math_fround(HEAPF32[$17>>2]);
  $91 = Math_fround(HEAPF32[$18>>2]);
  $92 = Math_fround(-$75);
  $93 = Math_fround(-$76);
  $94 = Math_fround(-$77);
  $95 = $75 > $92;
  $$$i$i$i37 = $95 ? $75 : $92;
  $96 = $76 > $93;
  $97 = $96 ? $76 : $93;
  $98 = $86 >= $$$i$i$i37;
  $99 = $87 >= $97;
  $notlhs301$i38 = $53 >= $88;
  $notrhs302$i39 = $90 >= $55;
  $not$300$i40 = $notrhs302$i39 & $notlhs301$i38;
  $100 = $98 & $not$300$i40;
  $notlhs303$i41 = $54 >= $89;
  $notrhs304$i42 = $91 >= $56;
  $not$$i43 = $notrhs304$i42 & $notlhs303$i41;
  $$296$i44 = $99 & $not$$i43;
  $brmerge$demorgan$i45 = $100 & $$296$i44;
  L3: do {
   if ($brmerge$demorgan$i45) {
    $101 = Math_fround(HEAPF32[$19>>2]);
    $102 = Math_fround(HEAPF32[$20>>2]);
    $103 = $77 > $94;
    $104 = Math_fround($52 * $102);
    $105 = Math_fround($50 * $101);
    $$1$i$i$i46 = $103 ? $77 : $94;
    $106 = Math_fround($105 + $104);
    $107 = Math_fround(HEAPF32[$21>>2]);
    $108 = Math_fround($30 - $52);
    $109 = Math_fround($30 + $52);
    $110 = Math_fround(HEAPF32[$22>>2]);
    $111 = $106 >= $$1$i$i$i46;
    $notlhs306$i47 = $109 >= $110;
    $notrhs307$i48 = $107 >= $108;
    $not$305$i49 = $notrhs307$i48 & $notlhs306$i47;
    $112 = $111 & $not$305$i49;
    if ($112) {
     $113 = Math_fround(HEAPF32[$maxDist>>2]);
     HEAPF32[$md>>2] = $113;
     $node$0$ph = $26;$stackIndex$1$ph = $313;
     L6: while(1) {
      $node$0 = $node$0$ph;
      while(1) {
       $114 = (($node$0) + 16|0);
       $115 = $114;
       $116 = $115;
       $117 = HEAP32[$116>>2]|0;
       $118 = (($115) + 4)|0;
       $119 = $118;
       $120 = HEAP32[$119>>2]|0;
       $121 = $117 & 1;
       $122 = ($121|0)==(0);
       $123 = (0)==(0);
       $124 = $122 & $123;
       if (!($124)) {
        break L6;
       }
       $125 = (_bitshift64Lshr(($117|0),($120|0),21)|0);
       $126 = tempRet0;
       $127 = $125 & 524287;
       $128 = (($2) + (($127*24)|0)|0);
       $129 = Math_fround(HEAPF32[$128>>2]);
       $130 = ((($2) + (($127*24)|0)|0) + 4|0);
       $131 = Math_fround(HEAPF32[$130>>2]);
       $132 = ((($2) + (($127*24)|0)|0) + 8|0);
       $133 = Math_fround(HEAPF32[$132>>2]);
       $134 = ((($2) + (($127*24)|0)|0) + 16|0);
       $135 = $134;
       $136 = $135;
       $137 = HEAP32[$136>>2]|0;
       $138 = (($135) + 4)|0;
       $139 = $138;
       $140 = HEAP32[$139>>2]|0;
       $141 = $140 & -256;
       $142 = (HEAP32[tempDoublePtr>>2]=$141,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $143 = Math_fround($142 * Math_fround(9.99999974737875163555E-5));
       $144 = (HEAPF32[tempDoublePtr>>2]=$129,HEAP32[tempDoublePtr>>2]|0);
       $145 = (HEAPF32[tempDoublePtr>>2]=$131,HEAP32[tempDoublePtr>>2]|0);
       $146 = (HEAPF32[tempDoublePtr>>2]=$133,HEAP32[tempDoublePtr>>2]|0);
       $147 = $144 & 255;
       $148 = $145 & 255;
       $149 = $146 & 255;
       $150 = (Math_fround(($147|0)));
       $151 = (Math_fround(($148|0)));
       $152 = (Math_fround(($149|0)));
       $153 = Math_fround($150 * $143);
       $154 = Math_fround($151 * $143);
       $155 = Math_fround($152 * $143);
       $156 = Math_fround($129 + $153);
       $157 = Math_fround($131 + $154);
       $158 = Math_fround($129 - $153);
       $159 = Math_fround($131 - $154);
       $160 = Math_fround($57 - $129);
       $161 = Math_fround($58 - $131);
       $162 = Math_fround($59 - $133);
       $163 = Math_fround($161 * $66);
       $164 = Math_fround($162 * $67);
       $165 = Math_fround($160 * $68);
       $166 = Math_fround($160 * $63);
       $167 = Math_fround($161 * $64);
       $168 = Math_fround($162 * $65);
       $169 = Math_fround($163 - $166);
       $170 = Math_fround($164 - $167);
       $171 = Math_fround($165 - $168);
       $172 = Math_fround($154 * $80);
       $173 = Math_fround($155 * $81);
       $174 = Math_fround($153 * $78);
       $175 = Math_fround($154 * $79);
       $176 = Math_fround($174 + $172);
       $177 = Math_fround($175 + $173);
       $178 = Math_fround(-$169);
       $179 = Math_fround(-$170);
       $180 = Math_fround(-$171);
       $181 = $169 > $178;
       $$$i$i$i16 = $181 ? $169 : $178;
       $182 = $170 > $179;
       $183 = $182 ? $170 : $179;
       $184 = $176 >= $$$i$i$i16;
       $185 = $177 >= $183;
       $notlhs301$i17 = $156 >= $88;
       $notrhs302$i18 = $90 >= $158;
       $not$300$i19 = $notrhs302$i18 & $notlhs301$i17;
       $186 = $184 & $not$300$i19;
       $notlhs303$i20 = $157 >= $89;
       $notrhs304$i21 = $91 >= $159;
       $not$$i22 = $notrhs304$i21 & $notlhs303$i20;
       $$296$i23 = $185 & $not$$i22;
       $brmerge$demorgan$i24 = $186 & $$296$i23;
       if ($brmerge$demorgan$i24) {
        $187 = $171 > $180;
        $188 = Math_fround($155 * $102);
        $189 = Math_fround($153 * $101);
        $$1$i$i$i25 = $187 ? $171 : $180;
        $190 = Math_fround($189 + $188);
        $191 = Math_fround($133 - $155);
        $192 = Math_fround($133 + $155);
        $193 = $190 >= $$1$i$i$i25;
        $notlhs306$i26 = $192 >= $110;
        $notrhs307$i27 = $107 >= $191;
        $not$305$i28 = $notrhs307$i27 & $notlhs306$i26;
        $194 = $193 & $not$305$i28;
        $262 = $194;
       } else {
        $262 = 0;
       }
       $$sum = (($127) + 1)|0;
       $195 = (($2) + (($$sum*24)|0)|0);
       $196 = Math_fround(HEAPF32[$195>>2]);
       $197 = ((($2) + (($$sum*24)|0)|0) + 4|0);
       $198 = Math_fround(HEAPF32[$197>>2]);
       $199 = ((($2) + (($$sum*24)|0)|0) + 8|0);
       $200 = Math_fround(HEAPF32[$199>>2]);
       $201 = ((($2) + (($$sum*24)|0)|0) + 16|0);
       $202 = $201;
       $203 = $202;
       $204 = HEAP32[$203>>2]|0;
       $205 = (($202) + 4)|0;
       $206 = $205;
       $207 = HEAP32[$206>>2]|0;
       $208 = $207 & -256;
       $209 = (HEAP32[tempDoublePtr>>2]=$208,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $210 = Math_fround($209 * Math_fround(9.99999974737875163555E-5));
       $211 = (HEAPF32[tempDoublePtr>>2]=$196,HEAP32[tempDoublePtr>>2]|0);
       $212 = (HEAPF32[tempDoublePtr>>2]=$198,HEAP32[tempDoublePtr>>2]|0);
       $213 = (HEAPF32[tempDoublePtr>>2]=$200,HEAP32[tempDoublePtr>>2]|0);
       $214 = $211 & 255;
       $215 = $212 & 255;
       $216 = $213 & 255;
       $217 = (Math_fround(($214|0)));
       $218 = (Math_fround(($215|0)));
       $219 = (Math_fround(($216|0)));
       $220 = Math_fround($217 * $210);
       $221 = Math_fround($218 * $210);
       $222 = Math_fround($219 * $210);
       $223 = Math_fround($196 + $220);
       $224 = Math_fround($198 + $221);
       $225 = Math_fround($196 - $220);
       $226 = Math_fround($198 - $221);
       $227 = Math_fround($57 - $196);
       $228 = Math_fround($58 - $198);
       $229 = Math_fround($59 - $200);
       $230 = Math_fround($228 * $66);
       $231 = Math_fround($229 * $67);
       $232 = Math_fround($227 * $68);
       $233 = Math_fround($227 * $63);
       $234 = Math_fround($228 * $64);
       $235 = Math_fround($229 * $65);
       $236 = Math_fround($230 - $233);
       $237 = Math_fround($231 - $234);
       $238 = Math_fround($232 - $235);
       $239 = Math_fround($221 * $80);
       $240 = Math_fround($222 * $81);
       $241 = Math_fround($220 * $78);
       $242 = Math_fround($221 * $79);
       $243 = Math_fround($241 + $239);
       $244 = Math_fround($242 + $240);
       $245 = Math_fround(-$236);
       $246 = Math_fround(-$237);
       $247 = Math_fround(-$238);
       $248 = $236 > $245;
       $$$i$i$i = $248 ? $236 : $245;
       $249 = $237 > $246;
       $250 = $249 ? $237 : $246;
       $251 = $243 >= $$$i$i$i;
       $252 = $244 >= $250;
       $notlhs301$i = $223 >= $88;
       $notrhs302$i = $90 >= $225;
       $not$300$i = $notrhs302$i & $notlhs301$i;
       $253 = $251 & $not$300$i;
       $notlhs303$i = $224 >= $89;
       $notrhs304$i = $91 >= $226;
       $not$$i = $notrhs304$i & $notlhs303$i;
       $$296$i = $252 & $not$$i;
       $brmerge$demorgan$i = $253 & $$296$i;
       if ($brmerge$demorgan$i) {
        $254 = $238 > $247;
        $255 = Math_fround($222 * $102);
        $256 = Math_fround($220 * $101);
        $$1$i$i$i = $254 ? $238 : $247;
        $257 = Math_fround($256 + $255);
        $258 = Math_fround($200 - $222);
        $259 = Math_fround($200 + $222);
        $260 = $257 >= $$1$i$i$i;
        $notlhs306$i = $259 >= $110;
        $notrhs307$i = $107 >= $258;
        $not$305$i = $notrhs307$i & $notlhs306$i;
        $261 = $260 & $not$305$i;
        $or$cond$demorgan = $262 & $261;
        if ($or$cond$demorgan) {
         break;
        } else {
         $278 = $261;
        }
       } else {
        $278 = 0;
       }
       $brmerge = $262 | $278;
       $$mux = $262 ? $128 : $195;
       if ($brmerge) {
        $node$0 = $$mux;
       } else {
        $stackIndex$0$be = $stackIndex$1$ph;
        break L3;
       }
      }
      $263 = Math_fround($196 - $129);
      $264 = Math_fround($198 - $131);
      $265 = Math_fround($200 - $133);
      $266 = Math_fround($263 * $66);
      $267 = Math_fround($264 * $67);
      $268 = Math_fround($266 + $267);
      $269 = Math_fround($265 * $68);
      $270 = Math_fround($268 + $269);
      $271 = $270 > Math_fround(0.0);
      $272 = $271&1;
      $$sum131 = (($272) + ($127))|0;
      $273 = (($2) + (($$sum131*24)|0)|0);
      $274 = (($stackIndex$1$ph) + 1)|0;
      $275 = (($stack) + ($stackIndex$1$ph<<2)|0);
      HEAP32[$275>>2] = $273;
      $276 = $272 ^ 1;
      $$sum132 = (($276) + ($127))|0;
      $277 = (($2) + (($$sum132*24)|0)|0);
      $node$0$ph = $277;$stackIndex$1$ph = $274;
     }
     $279 = HEAP32[$tree>>2]|0;
     $280 = (_bitshift64Lshr(($117|0),($120|0),21)|0);
     $281 = tempRet0;
     $282 = $280 & 524287;
     $283 = (($279) + ($282<<2)|0);
     $284 = HEAP32[$pcb>>2]|0;
     $285 = HEAP32[$284>>2]|0;
     $286 = HEAP32[$283>>2]|0;
     $287 = (($objects) + ($286<<3)|0);
     $288 = (FUNCTION_TABLE_iiiii[$285 & 511]($pcb,$md,$287,1)|0);
     if (!($288)) {
      $$0 = 0;
      label = 18;
      break L1;
     }
     $289 = Math_fround(HEAPF32[$md>>2]);
     $290 = $289 < $113;
     if ($290) {
      HEAPF32[$maxDist>>2] = $289;
      $291 = Math_fround(HEAPF32[$8>>2]);
      $292 = Math_fround(HEAPF32[$9>>2]);
      $293 = Math_fround(HEAPF32[$10>>2]);
      $294 = Math_fround(HEAPF32[$test>>2]);
      $295 = Math_fround(HEAPF32[$3>>2]);
      $296 = Math_fround(HEAPF32[$4>>2]);
      $297 = Math_fround($289 * $291);
      $298 = Math_fround($289 * $292);
      $299 = Math_fround($289 * $293);
      $300 = Math_fround($297 + $294);
      $301 = Math_fround($298 + $295);
      $302 = Math_fround($299 + $296);
      $303 = $294 < $300;
      $$$i8$i = $303 ? $294 : $300;
      $304 = $295 < $301;
      $305 = $304 ? $295 : $301;
      $306 = $296 < $302;
      $$1$i9$i = $306 ? $296 : $302;
      HEAPF32[$15>>2] = $$$i8$i;
      HEAPF32[$16>>2] = $305;
      HEAPF32[$22>>2] = $$1$i9$i;
      HEAPF32[$23>>2] = Math_fround(0.0);
      $307 = $294 > $300;
      $$$i$i = $307 ? $294 : $300;
      $308 = $295 > $301;
      $309 = $308 ? $295 : $301;
      $310 = $296 > $302;
      $$1$i$i = $310 ? $296 : $302;
      HEAPF32[$17>>2] = $$$i$i;
      HEAPF32[$18>>2] = $309;
      HEAPF32[$21>>2] = $$1$i$i;
      HEAPF32[$24>>2] = Math_fround(0.0);
      $stackIndex$0$be = $stackIndex$1$ph;
     } else {
      $stackIndex$0$be = $stackIndex$1$ph;
     }
    } else {
     $stackIndex$0$be = $313;
    }
   } else {
    $stackIndex$0$be = $313;
   }
  } while(0);
  $311 = (($stackIndex$0$be) + -1)|0;
  $312 = ($stackIndex$0$be|0)==(0);
  if ($312) {
   $$0 = 1;
   label = 18;
   break;
  }
  $$phi$trans$insert = (($stack) + ($311<<2)|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $26 = $$pre;$313 = $311;
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sq10AABBPruner5purgeEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sq10AABBPruner7releaseEv($this);
 $0 = (($this) + 7809|0);
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPruner18setRebuildRateHintEj($this,$nbStepsForRebuild) {
 $this = $this|0;
 $nbStepsForRebuild = $nbStepsForRebuild|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($nbStepsForRebuild) + -3)|0;
 $1 = (($this) + 7748|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 7756|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPruner6commitEv($this) {
 $this = $this|0;
 var $$lcssa$i1$ph = 0, $$lcssa$i1$ph7 = 0, $$ph5 = 0, $$ph6 = 0, $$phi$trans$insert$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre4$i$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $TB = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $r$09 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 33|0;
 $1 = sp + 32|0;
 $TB = sp;
 $2 = (($this) + 7809|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 HEAP8[$2>>0] = 0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  (__ZN5physx2Sq10AABBPruner19fullRebuildAABBTreeEv($this)|0);
 }
 $8 = (($this) + 7808|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 7744|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(3);
 if ($13) {
  $22 = (($this) + 44|0);
  $23 = HEAP32[$22>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$23);
  HEAP32[$22>>2] = 0;
  HEAP32[$11>>2] = 0;
  $24 = (($this) + 52|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($this) + 7748|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($25>>>0)>($27>>>0);
  if ($28) {
   $29 = (($this) + 7756|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 1)|0;
   HEAP32[$29>>2] = $31;
  } else {
   $32 = ($25>>>0)<($27>>>0);
   if ($32) {
    $33 = (($this) + 7756|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + -1)|0;
    HEAP32[$33>>2] = $35;
   }
  }
  $36 = HEAP32[$5>>2]|0;
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   __ZN5physx2Sq8AABBTreeD2Ev($36);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$36);
  }
  $38 = (($this) + 40|0);
  $39 = HEAP32[$38>>2]|0;
  HEAP32[$5>>2] = $39;
  HEAP32[$38>>2] = 0;
  $40 = (($this) + 7796|0);
  $41 = (($this) + 7764|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($this) + 48|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42>>>0)<($44>>>0);
  $46 = $45 ? $44 : $42;
  __ZN5physx2Sq17AABBTreeUpdateMap7initMapEjRKNS0_8AABBTreeE($40,$46,$39);
  $47 = (($this) + 7812|0);
  $48 = (($this) + 7816|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)>(0);
  if ($50) {
   $51 = HEAP32[$47>>2]|0;
   $r$09 = $51;
   while(1) {
    $52 = HEAP32[$r$09>>2]|0;
    $53 = (($r$09) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = HEAP32[$5>>2]|0;
    __ZN5physx2Sq17AABBTreeUpdateMap10invalidateEjjRNS0_8AABBTreeE($40,$52,$54,$55);
    $56 = (($r$09) + 8|0);
    $57 = HEAP32[$47>>2]|0;
    $58 = HEAP32[$48>>2]|0;
    $59 = (($57) + ($58<<3)|0);
    $60 = ($56>>>0)<($59>>>0);
    if ($60) {
     $r$09 = $56;
    } else {
     break;
    }
   }
  }
  HEAP32[$48>>2] = 0;
  $61 = (($this) + 7811|0);
  HEAP8[$61>>0] = 0;
  $62 = HEAP32[$41>>2]|0;
  $63 = (($TB) + 4|0);
  $64 = (($TB) + 8|0);
  ;HEAP32[$64+0>>2]=0|0;HEAP32[$64+4>>2]=0|0;HEAP32[$64+8>>2]=0|0;HEAP32[$64+12>>2]=0|0;HEAP32[$64+16>>2]=0|0;HEAP32[$64+20>>2]=0|0;
  HEAP32[$64>>2] = $62;
  $65 = (($this) + 7772|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($TB) + 20|0);
  HEAP32[$67>>2] = $66;
  HEAP32[$63>>2] = 2;
  HEAP32[$TB>>2] = 1;
  $68 = HEAP32[$5>>2]|0;
  $69 = HEAP32[$68>>2]|0;
  (__ZN5physx2Sq8AABBTree6refit2EPNS0_15AABBTreeBuilderEPj($68,$TB,$69)|0);
  $70 = (($this) + 140|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($71) + 16|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)==(0);
  $$pre = (($71) + 12|0);
  L25: do {
   if ($74) {
    $$lcssa$i1$ph = 0;$$ph5 = -1;
   } else {
    $75 = HEAP32[$$pre>>2]|0;
    $76 = HEAP32[$75>>2]|0;
    $77 = ($76|0)==(-1);
    if ($77) {
     $78 = (($71) + 20|0);
     $79 = HEAP32[$78>>2]|0;
     $81 = 0;
     while(1) {
      $80 = (($81) + 1)|0;
      $82 = ($80|0)==($79|0);
      if ($82) {
       $$lcssa$i1$ph = $79;$$ph5 = -1;
       break L25;
      }
      $83 = (($75) + ($80<<2)|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = ($84|0)==(-1);
      if ($85) {
       $81 = $80;
      } else {
       $$lcssa$i1$ph = $80;$$ph5 = $84;
       break;
      }
     }
    } else {
     $$lcssa$i1$ph = 0;$$ph5 = $76;
    }
   }
  } while(0);
  $86 = (($71) + 4|0);
  $87 = (($this) + 144|0);
  $88 = (($this) + 7780|0);
  $89 = (($this) + 7776|0);
  $90 = (($71) + 8|0);
  $91 = (($71) + 20|0);
  $$lcssa$i1$ph7 = $$lcssa$i1$ph;$$ph6 = $$ph5;
  L32: while(1) {
   $93 = $$ph6;
   while(1) {
    $92 = ($93|0)==(-1);
    if ($92) {
     break L32;
    }
    $94 = HEAP32[$86>>2]|0;
    $95 = (($94) + ($93<<2)|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = HEAP32[$88>>2]|0;
    $98 = (($97) + ($96<<2)|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = HEAP32[$89>>2]|0;
    $101 = (($100) + ($99<<3)|0);
    (__ZN5physx2Sq16BucketPrunerCore12removeObjectERKNS0_13PrunerPayloadE($87,$101)|0);
    $102 = HEAP32[$90>>2]|0;
    $103 = (($102) + ($93<<2)|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($104|0)==(-1);
    if ($105) {
     break;
    } else {
     $93 = $104;
    }
   }
   $106 = HEAP32[$91>>2]|0;
   $108 = $$lcssa$i1$ph7;
   while(1) {
    $107 = (($108) + 1)|0;
    $109 = ($107|0)==($106|0);
    if ($109) {
     $$lcssa$i1$ph7 = $106;$$ph6 = -1;
     continue L32;
    }
    $110 = HEAP32[$$pre>>2]|0;
    $111 = (($110) + ($107<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($112|0)==(-1);
    if ($113) {
     $108 = $107;
    } else {
     $$lcssa$i1$ph7 = $107;$$ph6 = $112;
     continue L32;
    }
   }
  }
  $114 = (($this) + 96|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($115) + 36|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = ($117|0)!=(0);
  $119 = (($this) + 7810|0);
  $120 = $118&1;
  HEAP8[$119>>0] = $120;
  $121 = HEAP32[$70>>2]|0;
  $122 = (($121) + 20|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)==(0);
  if (!($124)) {
   $125 = (($121) + 36|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($126|0)==(0);
   if (!($127)) {
    $128 = (($121) + 12|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = $123 << 2;
    _memset(($129|0),-1,($130|0))|0;
    $131 = (($121) + 16|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = (($132) + -1)|0;
    $134 = ($133|0)==(0);
    $$phi$trans$insert$i$i = (($121) + 8|0);
    $$pre4$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
    if ($134) {
     $141 = $132;$143 = $$pre4$i$i;
    } else {
     $136 = $$pre4$i$i;$i$01$i$i = 0;
     while(1) {
      $$sum$i$i = (($i$01$i$i) + 32)|0;
      $135 = (($136) + ($$sum$i$i<<2)|0);
      $137 = (($i$01$i$i) + 1)|0;
      $138 = HEAP32[$$phi$trans$insert$i$i>>2]|0;
      $139 = (($138) + ($i$01$i$i<<2)|0);
      HEAP32[$139>>2] = $137;
      $exitcond$i$i = ($137|0)==($133|0);
      if ($exitcond$i$i) {
       break;
      } else {
       $136 = $138;$i$01$i$i = $137;
      }
     }
     $$pre$i$i = HEAP32[$131>>2]|0;
     $141 = $$pre$i$i;$143 = $138;
    }
    $140 = (($141) + -1)|0;
    $142 = (($143) + ($140<<2)|0);
    HEAP32[$142>>2] = -1;
    $144 = (($121) + 28|0);
    HEAP32[$144>>2] = 0;
    HEAP32[$125>>2] = 0;
   }
  }
 } else {
  $14 = HEAP32[$5>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   $16 = (($this) + 7764|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0);
   if (!($18)) {
    $19 = (($this) + 7772|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$14>>2]|0;
    __ZN5physx2Sq8AABBTree11refitMarkedEjPKNS_9PxBounds3EPj($14,$17,$20,$21);
   }
  }
 }
 $145 = (($this) + 144|0);
 __ZN5physx2Sq16BucketPrunerCore13classifyBoxesEv($145);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPruner19fullRebuildAABBTreeEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $TB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $TB = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN5physx2Sq8AABBTreeD2Ev($2);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 }
 HEAP32[$1>>2] = 0;
 $4 = (($this) + 7764|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__Z15PxGetFoundationv()|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
 $$$i$i$i = $15 ? 506200 : 506168;
 $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,548,$$$i$i$i,506088,788)|0);
 __ZN5physx2Sq8AABBTreeC2Ev($16);
 HEAP32[$1>>2] = $16;
 $17 = (($TB) + 4|0);
 $18 = (($TB) + 8|0);
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;
 HEAP32[$18>>2] = $5;
 $19 = (($this) + 7772|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($TB) + 20|0);
 HEAP32[$21>>2] = $20;
 HEAP32[$17>>2] = 2;
 HEAP32[$TB>>2] = 1;
 $22 = (__ZN5physx2Sq8AABBTree5buildEPNS0_15AABBTreeBuilderE($16,$TB)|0);
 $23 = (($this) + 7808|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $$0 = $22;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = (($this) + 7796|0);
 $27 = (($this) + 48|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($5>>>0)<($28>>>0);
 $30 = $29 ? $28 : $5;
 $31 = HEAP32[$1>>2]|0;
 __ZN5physx2Sq17AABBTreeUpdateMap7initMapEjRKNS0_8AABBTreeE($26,$30,$31);
 $$0 = $22;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sq10AABBPruner11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 7760|0);
 __ZN5physx2Sq11PruningPool11shiftOriginERKNS_6PxVec3E($0,$shift);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN5physx2Sq8AABBTree11shiftOriginERKNS_6PxVec3E($2,$shift);
 }
 $4 = (($this) + 7808|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 144|0);
 __ZN5physx2Sq16BucketPrunerCore11shiftOriginERKNS_6PxVec3E($7,$shift);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sq10AABBPruner9visualizeERNS_2Cm12RenderOutputEj($this,$out,$color) {
 $this = $this|0;
 $out = $out|0;
 $color = $color|0;
 var $$lcssa$i12$ph = 0, $$lcssa$i12$ph20 = 0, $$lcssa$i515$ph = 0, $$lcssa$i515$ph25 = 0, $$ph18 = 0, $$ph19 = 0, $$ph23 = 0, $$ph24 = 0, $$pre = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0);
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 84|0;
 $1 = sp;
 $2 = sp + 28|0;
 $3 = sp + 56|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  HEAPF32[$0>>2] = Math_fround(0.0);
  $7 = (($0) + 4|0);
  HEAPF32[$7>>2] = Math_fround(0.0);
  $8 = (($0) + 8|0);
  HEAPF32[$8>>2] = Math_fround(0.0);
  $9 = (($0) + 12|0);
  HEAPF32[$9>>2] = Math_fround(1.0);
  $10 = (($0) + 16|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($0) + 20|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  $12 = (($0) + 24|0);
  HEAPF32[$12>>2] = Math_fround(0.0);
  (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$0)|0);
  (__ZN5physx2Cm12RenderOutputlsEj($out,$color)|0);
  $13 = (($5) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  __ZZNK5physx2Sq10AABBPruner9visualizeERNS_2Cm12RenderOutputEjEN5Local5_DrawEPKNS0_12AABBTreeNodeES8_S4_($14,$14,$out);
 }
 HEAPF32[$1>>2] = Math_fround(0.0);
 $15 = (($1) + 4|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($1) + 8|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($1) + 12|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($1) + 16|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($1) + 20|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($1) + 24|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$1)|0);
 (__ZN5physx2Cm12RenderOutputlsEj($out,-1)|0);
 $21 = (($this) + 72|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 $$pre = (($this) + 68|0);
 L4: do {
  if ($23) {
   $$lcssa$i515$ph = 0;$$ph23 = -1;
  } else {
   $24 = HEAP32[$$pre>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(-1);
   if ($26) {
    $27 = (($this) + 76|0);
    $28 = HEAP32[$27>>2]|0;
    $30 = 0;
    while(1) {
     $29 = (($30) + 1)|0;
     $31 = ($29|0)==($28|0);
     if ($31) {
      $$lcssa$i515$ph = $28;$$ph23 = -1;
      break L4;
     }
     $32 = (($24) + ($29<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(-1);
     if ($34) {
      $30 = $29;
     } else {
      $$lcssa$i515$ph = $29;$$ph23 = $33;
      break;
     }
    }
   } else {
    $$lcssa$i515$ph = 0;$$ph23 = $25;
   }
  }
 } while(0);
 $35 = (($this) + 60|0);
 $36 = (($this) + 7780|0);
 $37 = (($this) + 7772|0);
 $38 = (($2) + 4|0);
 $39 = (($2) + 8|0);
 $40 = (($2) + 12|0);
 $41 = (($2) + 16|0);
 $42 = (($2) + 20|0);
 $43 = (($2) + 24|0);
 $44 = (($this) + 64|0);
 $45 = (($this) + 76|0);
 $$lcssa$i515$ph25 = $$lcssa$i515$ph;$$ph24 = $$ph23;
 L11: while(1) {
  $47 = $$ph24;
  while(1) {
   $46 = ($47|0)==(-1);
   if ($46) {
    break L11;
   }
   $48 = HEAP32[$35>>2]|0;
   $49 = (($48) + ($47<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = HEAP32[$36>>2]|0;
   $52 = (($51) + ($50<<2)|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$37>>2]|0;
   $55 = (($54) + (($53*24)|0)|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   HEAPF32[$2>>2] = $56;
   $57 = ((($54) + (($53*24)|0)|0) + 4|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   HEAPF32[$38>>2] = $58;
   $59 = ((($54) + (($53*24)|0)|0) + 8|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   HEAPF32[$39>>2] = $60;
   $61 = ((($54) + (($53*24)|0)|0) + 12|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   HEAPF32[$40>>2] = $62;
   $63 = ((($54) + (($53*24)|0)|0) + 16|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   HEAPF32[$41>>2] = $64;
   $65 = ((($54) + (($53*24)|0)|0) + 20|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   HEAPF32[$42>>2] = $66;
   HEAP8[$43>>0] = 1;
   (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$2)|0);
   $67 = HEAP32[$44>>2]|0;
   $68 = (($67) + ($47<<2)|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(-1);
   if ($70) {
    break;
   } else {
    $47 = $69;
   }
  }
  $71 = HEAP32[$45>>2]|0;
  $73 = $$lcssa$i515$ph25;
  while(1) {
   $72 = (($73) + 1)|0;
   $74 = ($72|0)==($71|0);
   if ($74) {
    $$lcssa$i515$ph25 = $71;$$ph24 = -1;
    continue L11;
   }
   $75 = HEAP32[$$pre>>2]|0;
   $76 = (($75) + ($72<<2)|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(-1);
   if ($78) {
    $73 = $72;
   } else {
    $$lcssa$i515$ph25 = $72;$$ph24 = $77;
    continue L11;
   }
  }
 }
 $79 = (($this) + 116|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0);
 $$pre27 = (($this) + 112|0);
 L21: do {
  if ($81) {
   $$lcssa$i12$ph = 0;$$ph18 = -1;
  } else {
   $82 = HEAP32[$$pre27>>2]|0;
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==(-1);
   if ($84) {
    $85 = (($this) + 120|0);
    $86 = HEAP32[$85>>2]|0;
    $88 = 0;
    while(1) {
     $87 = (($88) + 1)|0;
     $89 = ($87|0)==($86|0);
     if ($89) {
      $$lcssa$i12$ph = $86;$$ph18 = -1;
      break L21;
     }
     $90 = (($82) + ($87<<2)|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($91|0)==(-1);
     if ($92) {
      $88 = $87;
     } else {
      $$lcssa$i12$ph = $87;$$ph18 = $91;
      break;
     }
    }
   } else {
    $$lcssa$i12$ph = 0;$$ph18 = $83;
   }
  }
 } while(0);
 $93 = (($this) + 104|0);
 $94 = (($3) + 4|0);
 $95 = (($3) + 8|0);
 $96 = (($3) + 12|0);
 $97 = (($3) + 16|0);
 $98 = (($3) + 20|0);
 $99 = (($3) + 24|0);
 $100 = (($this) + 108|0);
 $101 = (($this) + 120|0);
 $$lcssa$i12$ph20 = $$lcssa$i12$ph;$$ph19 = $$ph18;
 L28: while(1) {
  $103 = $$ph19;
  while(1) {
   $102 = ($103|0)==(-1);
   if ($102) {
    break L28;
   }
   $104 = HEAP32[$93>>2]|0;
   $105 = (($104) + ($103<<2)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = HEAP32[$36>>2]|0;
   $108 = (($107) + ($106<<2)|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = HEAP32[$37>>2]|0;
   $111 = (($110) + (($109*24)|0)|0);
   $112 = Math_fround(HEAPF32[$111>>2]);
   HEAPF32[$3>>2] = $112;
   $113 = ((($110) + (($109*24)|0)|0) + 4|0);
   $114 = Math_fround(HEAPF32[$113>>2]);
   HEAPF32[$94>>2] = $114;
   $115 = ((($110) + (($109*24)|0)|0) + 8|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   HEAPF32[$95>>2] = $116;
   $117 = ((($110) + (($109*24)|0)|0) + 12|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   HEAPF32[$96>>2] = $118;
   $119 = ((($110) + (($109*24)|0)|0) + 16|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   HEAPF32[$97>>2] = $120;
   $121 = ((($110) + (($109*24)|0)|0) + 20|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   HEAPF32[$98>>2] = $122;
   HEAP8[$99>>0] = 1;
   (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$3)|0);
   $123 = HEAP32[$100>>2]|0;
   $124 = (($123) + ($103<<2)|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = ($125|0)==(-1);
   if ($126) {
    break;
   } else {
    $103 = $125;
   }
  }
  $127 = HEAP32[$101>>2]|0;
  $129 = $$lcssa$i12$ph20;
  while(1) {
   $128 = (($129) + 1)|0;
   $130 = ($128|0)==($127|0);
   if ($130) {
    $$lcssa$i12$ph20 = $127;$$ph19 = -1;
    continue L28;
   }
   $131 = HEAP32[$$pre27>>2]|0;
   $132 = (($131) + ($128<<2)|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($133|0)==(-1);
   if ($134) {
    $129 = $128;
   } else {
    $$lcssa$i12$ph20 = $128;$$ph19 = $133;
    continue L28;
   }
  }
 }
 STACKTOP = sp;return;
}
function __ZZNK5physx2Sq10AABBPruner9visualizeERNS_2Cm12RenderOutputEjEN5Local5_DrawEPKNS0_12AABBTreeNodeES8_S4_($root,$node,$out_) {
 $root = $root|0;
 $node = $node|0;
 $out_ = $out_|0;
 var $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($node) + 16|0);
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & -256;
 $9 = HEAP32[$node>>2]|0;
 $10 = $9 & 255;
 $11 = (Math_fround(($10>>>0)));
 $12 = (($node) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 255;
 $15 = (Math_fround(($14>>>0)));
 $16 = (($node) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 255;
 $19 = (Math_fround(($18>>>0)));
 $20 = (HEAP32[tempDoublePtr>>2]=$8,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $21 = Math_fround($11 * $20);
 $22 = Math_fround($15 * $20);
 $23 = Math_fround($20 * $19);
 $24 = Math_fround($21 * Math_fround(9.99999974737875163555E-5));
 $25 = Math_fround($22 * Math_fround(9.99999974737875163555E-5));
 $26 = Math_fround($23 * Math_fround(9.99999974737875163555E-5));
 $27 = (HEAP32[tempDoublePtr>>2]=$9,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $28 = Math_fround($27 - $24);
 $29 = (HEAP32[tempDoublePtr>>2]=$13,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $30 = Math_fround($29 - $25);
 $31 = (HEAP32[tempDoublePtr>>2]=$17,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $32 = Math_fround($31 - $26);
 $33 = Math_fround($27 + $24);
 $34 = Math_fround($29 + $25);
 $35 = Math_fround($31 + $26);
 HEAPF32[$0>>2] = $28;
 $36 = (($0) + 4|0);
 HEAPF32[$36>>2] = $30;
 $37 = (($0) + 8|0);
 HEAPF32[$37>>2] = $32;
 $38 = (($0) + 12|0);
 HEAPF32[$38>>2] = $33;
 $39 = (($0) + 16|0);
 HEAPF32[$39>>2] = $34;
 $40 = (($0) + 20|0);
 HEAPF32[$40>>2] = $35;
 $41 = (($0) + 24|0);
 HEAP8[$41>>0] = 1;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out_,$0)|0);
 $42 = $1;
 $43 = $42;
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + 4)|0;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = $44 & 1;
 $49 = ($48|0)==(0);
 $50 = (0)==(0);
 $51 = $49 & $50;
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (_bitshift64Lshr(($44|0),($47|0),21)|0);
 $53 = tempRet0;
 $54 = $52 & 524287;
 $55 = (($root) + (($54*24)|0)|0);
 __ZZNK5physx2Sq10AABBPruner9visualizeERNS_2Cm12RenderOutputEjEN5Local5_DrawEPKNS0_12AABBTreeNodeES8_S4_($root,$55,$out_);
 $56 = $1;
 $57 = $56;
 $58 = HEAP32[$57>>2]|0;
 $59 = (($56) + 4)|0;
 $60 = $59;
 $61 = HEAP32[$60>>2]|0;
 $62 = (_bitshift64Lshr(($58|0),($61|0),21)|0);
 $63 = tempRet0;
 $64 = $62 & 524287;
 $65 = ($64|0)==(0);
 $$sum$i = (($64) + 1)|0;
 $66 = (($root) + (($$sum$i*24)|0)|0);
 $67 = $65 ? $root : $66;
 __ZZNK5physx2Sq10AABBPruner9visualizeERNS_2Cm12RenderOutputEjEN5Local5_DrawEPKNS0_12AABBTreeNodeES8_S4_($root,$67,$out_);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq10AABBPruner9buildStepEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$0 = 0, $$01$i = 0, $$02$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0);
 var $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$02 = 0, $i$03$i = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 7810|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 7744|0);
 $6 = HEAP32[$5>>2]|0;
 do {
  if ((($6|0) == 1)) {
   $62 = (($this) + 40|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($this) + 8|0);
   (__ZN5physx2Sq8AABBTree16progressiveBuildEPNS0_15AABBTreeBuilderEjj($63,$64,0,0)|0);
   HEAP32[$5>>2] = 2;
   $65 = (($this) + 52|0);
   HEAP32[$65>>2] = 0;
   $66 = (($this) + 16|0);
   $67 = HEAP32[$66>>2]|0;
   $$02$i = $67;$i$03$i = 0;
   while(1) {
    $70 = $$02$i >>> 1;
    $71 = ($70|0)==(0);
    $69 = (($i$03$i) + 1)|0;
    if ($71) {
     $$01$i = $i$03$i;
     break;
    }
    $68 = ($69>>>0)<(32);
    if ($68) {
     $$02$i = $70;$i$03$i = $69;
    } else {
     $$01$i = -1;
     break;
    }
   }
   $72 = Math_imul($67, $$01$i)|0;
   $73 = (($this) + 4|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + 540|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = $76 << 1;
   $78 = ($72>>>0)>($77>>>0);
   $79 = $76 >>> 1;
   $80 = ($72>>>0)<($79>>>0);
   $or$cond = $78 | $80;
   if ($or$cond) {
    $82 = (($this) + 7756|0);
    HEAP32[$82>>2] = 0;
    $83 = (($this) + 7752|0);
    HEAP32[$83>>2] = $72;
    $86 = 0;$88 = $72;
   } else {
    $81 = (($this) + 7752|0);
    HEAP32[$81>>2] = $76;
    $$phi$trans$insert = (($this) + 7756|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $86 = $$pre;$88 = $76;
   }
   $84 = (($this) + 7752|0);
   $85 = Math_imul($67, $86)|0;
   $87 = (($85) + ($88))|0;
   $89 = ($87|0)<(0);
   $90 = $89 ? 0 : $87;
   HEAP32[$84>>2] = $90;
   $107 = 2;
  } else if ((($6|0) == 2)) {
   $91 = (($this) + 52|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($92) + 1)|0;
   HEAP32[$91>>2] = $93;
   $94 = (($this) + 7752|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($this) + 7748|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($95>>>0) / ($97>>>0))&-1;
   $99 = (($98) + 1)|0;
   $100 = (($this) + 40|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (($this) + 8|0);
   $103 = (__ZN5physx2Sq8AABBTree16progressiveBuildEPNS0_15AABBTreeBuilderEjj($101,$102,1,$99)|0);
   $104 = ($103|0)==(0);
   if ($104) {
    HEAP32[$5>>2] = 3;
    $107 = 3;
    break;
   } else {
    $$pre4 = HEAP32[$5>>2]|0;
    $107 = $$pre4;
    break;
   }
  } else if ((($6|0) == 0)) {
   $7 = (($this) + 7764|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $10 = (($this) + 40|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    __ZN5physx2Sq8AABBTreeD2Ev($11);
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
   }
   $13 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__Z15PxGetFoundationv()|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (FUNCTION_TABLE_ii[$20 & 4095]($17)|0);
   $$$i$i$i = $21 ? 506200 : 506168;
   $22 = (FUNCTION_TABLE_iiiiii[$16 & 255]($13,548,$$$i$i$i,506088,677)|0);
   __ZN5physx2Sq8AABBTreeC2Ev($22);
   HEAP32[$10>>2] = $22;
   $23 = (($this) + 48|0);
   HEAP32[$23>>2] = $8;
   $24 = ($8*24)|0;
   $25 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$24,506088,680)|0);
   $26 = (($this) + 44|0);
   HEAP32[$26>>2] = $25;
   $27 = (($this) + 7772|0);
   $28 = HEAP32[$27>>2]|0;
   $i$02 = 0;
   while(1) {
    $29 = (($28) + (($i$02*24)|0)|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = (($25) + (($i$02*24)|0)|0);
    HEAPF32[$31>>2] = $30;
    $32 = ((($28) + (($i$02*24)|0)|0) + 4|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = ((($25) + (($i$02*24)|0)|0) + 4|0);
    HEAPF32[$34>>2] = $33;
    $35 = ((($28) + (($i$02*24)|0)|0) + 8|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = ((($25) + (($i$02*24)|0)|0) + 8|0);
    HEAPF32[$37>>2] = $36;
    $38 = ((($28) + (($i$02*24)|0)|0) + 12|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = ((($25) + (($i$02*24)|0)|0) + 12|0);
    HEAPF32[$40>>2] = $39;
    $41 = ((($28) + (($i$02*24)|0)|0) + 16|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = ((($25) + (($i$02*24)|0)|0) + 16|0);
    HEAPF32[$43>>2] = $42;
    $44 = ((($28) + (($i$02*24)|0)|0) + 20|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = ((($25) + (($i$02*24)|0)|0) + 20|0);
    HEAPF32[$46>>2] = $45;
    $47 = (($i$02) + 1)|0;
    $exitcond = ($47|0)==($8|0);
    if ($exitcond) {
     break;
    } else {
     $i$02 = $47;
    }
   }
   $48 = (($this) + 96|0);
   $49 = (($this) + 140|0);
   $50 = HEAP32[$48>>2]|0;
   $51 = HEAP32[$49>>2]|0;
   HEAP32[$48>>2] = $51;
   HEAP32[$49>>2] = $50;
   $52 = (($this) + 24|0);
   HEAP32[$52>>2] = 0;
   $53 = (($this) + 16|0);
   $54 = (($this) + 20|0);
   HEAP32[$54>>2] = 0;
   $55 = (($this) + 32|0);
   HEAP32[$55>>2] = 0;
   $56 = (($this) + 36|0);
   HEAP32[$56>>2] = 0;
   $57 = HEAP32[$23>>2]|0;
   HEAP32[$53>>2] = $57;
   $58 = (($this) + 28|0);
   HEAP32[$58>>2] = $25;
   $59 = (($this) + 12|0);
   HEAP32[$59>>2] = 2;
   $60 = (($this) + 8|0);
   HEAP32[$60>>2] = 1;
   $61 = (($this) + 7811|0);
   HEAP8[$61>>0] = 1;
   HEAP32[$5>>2] = 1;
   $107 = 1;
  } else {
   $107 = $6;
  }
 } while(0);
 $105 = (($this) + 7809|0);
 HEAP8[$105>>0] = 1;
 $106 = ($107|0)==(3);
 $$0 = $106;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sq10AABBPruner10getPayloadERKj($this,$h) {
 $this = $this|0;
 $h = $h|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$h>>2]|0;
 $1 = (($this) + 7780|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 7776|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<3)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx2Sq10AABBPruner11preallocateEj($this,$entries) {
 $this = $this|0;
 $entries = $entries|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 7760|0);
 __ZN5physx2Sq11PruningPool11preallocateEj($0,$entries);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11RayAABBTestC2ERKNS_6PxVec3ES4_fS4_($this,$origin_,$unitDir_,$maxDist,$inflation_) {
 $this = $this|0;
 $origin_ = $origin_|0;
 $unitDir_ = $unitDir_|0;
 $maxDist = Math_fround($maxDist);
 $inflation_ = $inflation_|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i8 = Math_fround(0), $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i9 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0;
 var $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$origin_>>2]);
 $1 = (($origin_) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($origin_) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$this>>2] = $0;
 $5 = (($this) + 4|0);
 HEAPF32[$5>>2] = $2;
 $6 = (($this) + 8|0);
 HEAPF32[$6>>2] = $4;
 $7 = (($this) + 12|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = Math_fround(HEAPF32[$unitDir_>>2]);
 $9 = (($unitDir_) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($unitDir_) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 16|0);
 HEAPF32[$13>>2] = $8;
 $14 = (($this) + 20|0);
 HEAPF32[$14>>2] = $10;
 $15 = (($this) + 24|0);
 HEAPF32[$15>>2] = $12;
 $16 = (($this) + 28|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 32|0);
 HEAPF32[$17>>2] = $10;
 $18 = (($this) + 36|0);
 HEAPF32[$18>>2] = $12;
 $19 = (($this) + 40|0);
 HEAPF32[$19>>2] = $8;
 $20 = (($this) + 44|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = Math_fround(HEAPF32[$inflation_>>2]);
 $22 = (($inflation_) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($inflation_) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 48|0);
 HEAPF32[$26>>2] = $21;
 $27 = (($this) + 52|0);
 HEAPF32[$27>>2] = $23;
 $28 = (($this) + 56|0);
 HEAPF32[$28>>2] = $25;
 $29 = (($this) + 60|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = Math_fround(-$8);
 $31 = Math_fround(-$10);
 $32 = Math_fround(-$12);
 $33 = $8 > $30;
 $$$i$i = $33 ? $8 : $30;
 $34 = $10 > $31;
 $35 = $34 ? $10 : $31;
 $36 = $12 > $32;
 $$1$i$i = $36 ? $12 : $32;
 $37 = (($this) + 64|0);
 HEAPF32[$37>>2] = $$$i$i;
 $38 = (($this) + 68|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($this) + 72|0);
 HEAPF32[$39>>2] = $$1$i$i;
 $40 = (($this) + 76|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($this) + 80|0);
 HEAPF32[$41>>2] = $35;
 $42 = (($this) + 84|0);
 HEAPF32[$42>>2] = $$1$i$i;
 $43 = (($this) + 88|0);
 HEAPF32[$43>>2] = $$$i$i;
 $44 = (($this) + 92|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = !($maxDist >= Math_fround(3.40282346638528859812E+38));
 $46 = Math_fround(HEAPF32[$unitDir_>>2]);
 do {
  if ($45) {
   $61 = Math_fround($46 * $maxDist);
   $62 = Math_fround(HEAPF32[$9>>2]);
   $63 = Math_fround($62 * $maxDist);
   $64 = Math_fround(HEAPF32[$11>>2]);
   $65 = Math_fround($64 * $maxDist);
   $66 = Math_fround(HEAPF32[$origin_>>2]);
   $67 = Math_fround($61 + $66);
   $68 = Math_fround(HEAPF32[$1>>2]);
   $69 = Math_fround($63 + $68);
   $70 = Math_fround(HEAPF32[$3>>2]);
   $71 = Math_fround($65 + $70);
   $73 = $67;$75 = $69;$78 = $71;
  } else {
   $47 = $46 == Math_fround(0.0);
   if ($47) {
    $48 = Math_fround(HEAPF32[$origin_>>2]);
    $91 = $48;
   } else {
    $49 = $46 >= Math_fround(0.0);
    $50 = $49 ? Math_fround(3.40282346638528859812E+38) : Math_fround(-3.40282346638528859812E+38);
    $91 = $50;
   }
   $51 = Math_fround(HEAPF32[$9>>2]);
   $52 = $51 == Math_fround(0.0);
   if ($52) {
    $53 = Math_fround(HEAPF32[$1>>2]);
    $92 = $53;
   } else {
    $54 = $51 >= Math_fround(0.0);
    $55 = $54 ? Math_fround(3.40282346638528859812E+38) : Math_fround(-3.40282346638528859812E+38);
    $92 = $55;
   }
   $56 = Math_fround(HEAPF32[$11>>2]);
   $57 = $56 == Math_fround(0.0);
   if ($57) {
    $58 = Math_fround(HEAPF32[$3>>2]);
    $73 = $91;$75 = $92;$78 = $58;
    break;
   } else {
    $59 = $56 >= Math_fround(0.0);
    $60 = $59 ? Math_fround(3.40282346638528859812E+38) : Math_fround(-3.40282346638528859812E+38);
    $73 = $91;$75 = $92;$78 = $60;
    break;
   }
  }
 } while(0);
 $72 = $0 < $73;
 $$$i8 = $72 ? $0 : $73;
 $74 = $2 < $75;
 $76 = $74 ? $2 : $75;
 $77 = $4 < $78;
 $$1$i9 = $77 ? $4 : $78;
 $79 = (($this) + 96|0);
 HEAPF32[$79>>2] = $$$i8;
 $80 = (($this) + 100|0);
 HEAPF32[$80>>2] = $76;
 $81 = (($this) + 104|0);
 HEAPF32[$81>>2] = $$1$i9;
 $82 = (($this) + 108|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = $0 > $73;
 $$$i = $83 ? $0 : $73;
 $84 = $2 > $75;
 $85 = $84 ? $2 : $75;
 $86 = $4 > $78;
 $$1$i = $86 ? $4 : $78;
 $87 = (($this) + 112|0);
 HEAPF32[$87>>2] = $$$i;
 $88 = (($this) + 116|0);
 HEAPF32[$88>>2] = $85;
 $89 = (($this) + 120|0);
 HEAPF32[$89>>2] = $$1$i;
 $90 = (($this) + 124|0);
 HEAPF32[$90>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu11RayAABBTest5checkILb1EEEjNS_6shdfnd3aos5Vec3VES5_($this,$center,$extents) {
 $this = $this|0;
 $center = $center|0;
 $extents = $extents|0;
 var $$$i$i = Math_fround(0), $$1$i$i = Math_fround(0), $$316 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0);
 var $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0;
 var $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $brmerge$demorgan = 0, $not$ = 0, $not$320 = 0, $not$325 = 0, $notlhs321 = 0, $notlhs323 = 0, $notlhs326 = 0, $notrhs322 = 0, $notrhs324 = 0, $notrhs327 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$extents>>2]);
 $1 = (($extents) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($extents) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 48|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 52|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 56|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($0 + $6);
 $12 = Math_fround($2 + $8);
 $13 = Math_fround($4 + $10);
 $14 = Math_fround(HEAPF32[$center>>2]);
 $15 = (($center) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($center) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($11 + $14);
 $20 = Math_fround($12 + $16);
 $21 = Math_fround($14 - $11);
 $22 = Math_fround($16 - $12);
 $23 = Math_fround(HEAPF32[$this>>2]);
 $24 = (($this) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($23 - $14);
 $29 = Math_fround($25 - $16);
 $30 = Math_fround($27 - $18);
 $31 = (($this) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($this) + 40|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($this) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($this) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($29 * $38);
 $44 = Math_fround($30 * $40);
 $45 = Math_fround($28 * $42);
 $46 = Math_fround($28 * $32);
 $47 = Math_fround($29 * $34);
 $48 = Math_fround($30 * $36);
 $49 = Math_fround($43 - $46);
 $50 = Math_fround($44 - $47);
 $51 = Math_fround($45 - $48);
 $52 = (($this) + 80|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($this) + 84|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($this) + 64|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($this) + 68|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($12 * $57);
 $61 = Math_fround($13 * $59);
 $62 = Math_fround($11 * $53);
 $63 = Math_fround($12 * $55);
 $64 = Math_fround($62 + $60);
 $65 = Math_fround($63 + $61);
 $66 = (($this) + 96|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($this) + 100|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($this) + 112|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($this) + 116|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround(-$49);
 $75 = Math_fround(-$50);
 $76 = Math_fround(-$51);
 $77 = $49 > $74;
 $$$i$i = $77 ? $49 : $74;
 $78 = $50 > $75;
 $79 = $78 ? $50 : $75;
 $80 = $64 >= $$$i$i;
 $81 = $65 >= $79;
 $notlhs321 = $19 >= $67;
 $notrhs322 = $71 >= $21;
 $not$320 = $notrhs322 & $notlhs321;
 $82 = $80 & $not$320;
 $notlhs323 = $20 >= $69;
 $notrhs324 = $73 >= $22;
 $not$ = $notrhs324 & $notlhs323;
 $$316 = $81 & $not$;
 $brmerge$demorgan = $82 & $$316;
 if (!($brmerge$demorgan)) {
  $100 = 0;
  $99 = $100&1;
  STACKTOP = sp;return ($99|0);
 }
 $83 = (($this) + 72|0);
 $84 = (($this) + 88|0);
 $85 = Math_fround(HEAPF32[$83>>2]);
 $86 = Math_fround(HEAPF32[$84>>2]);
 $87 = $51 > $76;
 $88 = Math_fround($13 * $86);
 $89 = Math_fround($11 * $85);
 $$1$i$i = $87 ? $51 : $76;
 $90 = (($this) + 120|0);
 $91 = (($this) + 104|0);
 $92 = Math_fround($89 + $88);
 $93 = Math_fround(HEAPF32[$90>>2]);
 $94 = Math_fround($18 - $13);
 $95 = Math_fround($13 + $18);
 $96 = Math_fround(HEAPF32[$91>>2]);
 $97 = $92 >= $$1$i$i;
 $notlhs326 = $95 >= $96;
 $notrhs327 = $93 >= $94;
 $not$325 = $notrhs327 & $notlhs326;
 $98 = $97 & $not$325;
 $100 = $98;
 $99 = $100&1;
 STACKTOP = sp;return ($99|0);
}
function __ZNK5physx2Gu12OBBAABBTestsILb1EEclENS_6shdfnd3aos5Vec3VES5_($this,$center,$extents) {
 $this = $this|0;
 $center = $center|0;
 $extents = $extents|0;
 var $$ = 0, $$0 = 0, $$825 = 0, $$826 = 0, $$827 = 0, $$827$ = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0);
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0;
 var $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0);
 var $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $not$ = 0, $not$835 = 0, $not$836 = 0, $not$837 = 0, $not$838 = 0, $not$841 = 0, $not$844 = 0, $not$847 = 0, $not$852 = 0, $notlhs839 = 0, $notlhs842 = 0, $notlhs845 = 0, $notlhs848 = 0, $notlhs850 = 0, $notlhs853 = 0;
 var $notrhs840 = 0, $notrhs843 = 0, $notrhs846 = 0, $notrhs849 = 0, $notrhs851 = 0, $notrhs854 = 0, $or$cond$demorgan = 0, $or$cond$i = 0, $or$cond$i178 = 0, $or$cond18$i = 0, $or$cond18$i179 = 0, $or$cond19$i = 0, $or$cond19$i180 = 0, $or$cond20$i = 0, $or$cond20$i181 = 0, $or$cond829$demorgan = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$center>>2]);
 $7 = (($center) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($center) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($1 - $6);
 $12 = Math_fround($3 - $8);
 $13 = Math_fround($5 - $10);
 $14 = Math_fround(HEAPF32[$extents>>2]);
 $15 = (($extents) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($extents) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 128|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 132|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 136|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($14 + $20);
 $26 = Math_fround($16 + $22);
 $27 = Math_fround($18 + $24);
 $28 = Math_fround(-$25);
 $29 = Math_fround(-$26);
 $30 = $11 > $25;
 $31 = $12 > $26;
 $or$cond$i178 = $30 | $31;
 $32 = $13 > $27;
 $or$cond18$i179 = $or$cond$i178 | $32;
 $33 = $11 < $28;
 $or$cond19$i180 = $or$cond18$i179 | $33;
 $34 = $12 < $29;
 $or$cond20$i181 = $or$cond19$i180 | $34;
 if ($or$cond20$i181) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $35 = Math_fround(-$27);
 $36 = $13 < $35;
 if ($36) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = (($this) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($this) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 40|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 48|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($this) + 52|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($this) + 56|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($this) + 64|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($this) + 68|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($this) + 72|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($this) + 80|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($this) + 84|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($this) + 88|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($this) + 96|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($this) + 100|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($this) + 104|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($this) + 112|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($this) + 116|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($this) + 120|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($11 * $38);
 $74 = Math_fround($11 * $40);
 $75 = Math_fround($11 * $42);
 $76 = Math_fround($12 * $44);
 $77 = Math_fround($12 * $46);
 $78 = Math_fround($12 * $48);
 $79 = Math_fround($73 + $76);
 $80 = Math_fround($74 + $77);
 $81 = Math_fround($75 + $78);
 $82 = Math_fround($13 * $50);
 $83 = Math_fround($13 * $52);
 $84 = Math_fround($13 * $54);
 $85 = Math_fround($79 + $82);
 $86 = Math_fround($80 + $83);
 $87 = Math_fround($81 + $84);
 $88 = Math_fround(HEAPF32[$this>>2]);
 $89 = (($this) + 4|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($this) + 8|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($56 * $14);
 $94 = Math_fround($58 * $14);
 $95 = Math_fround($60 * $14);
 $96 = Math_fround($93 + $88);
 $97 = Math_fround($94 + $90);
 $98 = Math_fround($95 + $92);
 $99 = Math_fround($62 * $16);
 $100 = Math_fround($64 * $16);
 $101 = Math_fround($66 * $16);
 $102 = Math_fround($99 + $96);
 $103 = Math_fround($100 + $97);
 $104 = Math_fround($101 + $98);
 $105 = Math_fround($68 * $18);
 $106 = Math_fround($70 * $18);
 $107 = Math_fround($72 * $18);
 $108 = Math_fround($105 + $102);
 $109 = Math_fround($106 + $103);
 $110 = Math_fround($107 + $104);
 $111 = Math_fround(-$108);
 $112 = Math_fround(-$109);
 $113 = $85 > $108;
 $114 = $86 > $109;
 $or$cond$i = $113 | $114;
 $115 = $87 > $110;
 $or$cond18$i = $or$cond$i | $115;
 $116 = $85 < $111;
 $or$cond19$i = $or$cond18$i | $116;
 $117 = $86 < $112;
 $or$cond20$i = $or$cond19$i | $117;
 if ($or$cond20$i) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $118 = Math_fround(-$110);
 $119 = $87 < $118;
 if ($119) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $120 = Math_fround($13 * $44);
 $121 = Math_fround($13 * $46);
 $122 = Math_fround($13 * $48);
 $123 = Math_fround($12 * $50);
 $124 = Math_fround($12 * $52);
 $125 = Math_fround($12 * $54);
 $126 = Math_fround($120 - $123);
 $127 = Math_fround($121 - $124);
 $128 = Math_fround($122 - $125);
 $129 = (($this) + 144|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($this) + 148|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($this) + 152|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($68 * $16);
 $136 = Math_fround($70 * $16);
 $137 = Math_fround($72 * $16);
 $138 = Math_fround($135 + $130);
 $139 = Math_fround($136 + $132);
 $140 = Math_fround($137 + $134);
 $141 = Math_fround($62 * $18);
 $142 = Math_fround($64 * $18);
 $143 = Math_fround($66 * $18);
 $144 = Math_fround($141 + $138);
 $145 = Math_fround($142 + $139);
 $146 = Math_fround($143 + $140);
 $147 = Math_fround(-$144);
 $148 = Math_fround(-$145);
 $149 = Math_fround(-$146);
 $150 = Math_fround($11 * $50);
 $151 = Math_fround($11 * $52);
 $152 = Math_fround($11 * $54);
 $153 = Math_fround($13 * $38);
 $154 = Math_fround($13 * $40);
 $155 = Math_fround($13 * $42);
 $156 = Math_fround($150 - $153);
 $157 = Math_fround($151 - $154);
 $158 = Math_fround($152 - $155);
 $159 = (($this) + 160|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($this) + 164|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = (($this) + 168|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = Math_fround($68 * $14);
 $166 = Math_fround($70 * $14);
 $167 = Math_fround($72 * $14);
 $168 = Math_fround($165 + $160);
 $169 = Math_fround($166 + $162);
 $170 = Math_fround($167 + $164);
 $171 = Math_fround($56 * $18);
 $172 = Math_fround($58 * $18);
 $173 = Math_fround($60 * $18);
 $174 = Math_fround($171 + $168);
 $175 = Math_fround($172 + $169);
 $176 = Math_fround($173 + $170);
 $177 = Math_fround(-$174);
 $178 = Math_fround(-$175);
 $179 = Math_fround(-$176);
 $180 = Math_fround($12 * $38);
 $181 = Math_fround($12 * $40);
 $182 = Math_fround($12 * $42);
 $183 = Math_fround($11 * $44);
 $184 = Math_fround($11 * $46);
 $185 = Math_fround($11 * $48);
 $186 = Math_fround($180 - $183);
 $187 = Math_fround($181 - $184);
 $188 = Math_fround($182 - $185);
 $189 = (($this) + 176|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($this) + 180|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($this) + 184|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround($62 * $14);
 $196 = Math_fround($64 * $14);
 $197 = Math_fround($66 * $14);
 $198 = Math_fround($195 + $190);
 $199 = Math_fround($196 + $192);
 $200 = Math_fround($197 + $194);
 $201 = Math_fround($56 * $16);
 $202 = Math_fround($58 * $16);
 $203 = Math_fround($60 * $16);
 $204 = Math_fround($201 + $198);
 $205 = Math_fround($202 + $199);
 $206 = Math_fround($203 + $200);
 $207 = Math_fround(-$204);
 $208 = Math_fround(-$205);
 $209 = Math_fround(-$206);
 $210 = $186 < $207;
 $211 = $187 < $208;
 $212 = $188 < $209;
 $not$835 = $186 > $204;
 $$825 = $210 | $not$835;
 $not$836 = $187 > $205;
 $213 = $211 | $not$836;
 $not$837 = $188 > $206;
 $$826 = $212 | $not$837;
 $notlhs839 = $156 > $174;
 $notrhs840 = $156 < $177;
 $not$838 = $notrhs840 | $notlhs839;
 $214 = $$825 | $not$838;
 $notlhs842 = $157 > $175;
 $notrhs843 = $157 < $178;
 $not$841 = $notrhs843 | $notlhs842;
 $$827 = $213 | $not$841;
 $notlhs845 = $158 > $176;
 $notrhs846 = $158 < $179;
 $not$844 = $notrhs846 | $notlhs845;
 $215 = $$826 | $not$844;
 $notlhs848 = $126 > $144;
 $notrhs849 = $126 < $147;
 $not$847 = $notrhs849 | $notlhs848;
 $216 = $214 | $not$847;
 $notlhs850 = $127 > $145;
 $notrhs851 = $127 < $148;
 $not$ = $notrhs851 | $notlhs850;
 $$827$ = $$827 | $not$;
 $notlhs853 = $128 > $146;
 $notrhs854 = $128 < $149;
 $not$852 = $notrhs854 | $notlhs853;
 $217 = $215 | $not$852;
 $or$cond$demorgan = $216 | $$827$;
 $or$cond829$demorgan = $or$cond$demorgan | $217;
 $218 = $or$cond829$demorgan&1;
 $$ = $218 ^ 1;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu12OBBAABBTestsILb1EEC2ERKNS_11PxTransformERKNS_13PxBoxGeometryEf($this,$t,$b,$inflation) {
 $this = $this|0;
 $t = $t|0;
 $b = $b|0;
 $inflation = Math_fround($inflation);
 var $$$i$i = Math_fround(0), $$$i$i60 = Math_fround(0), $$$i$i68 = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i$i61 = Math_fround(0), $$1$i$i69 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0);
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0;
 var $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($t) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($t) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 16|0);
 HEAPF32[$6>>2] = $1;
 $7 = (($this) + 20|0);
 HEAPF32[$7>>2] = $3;
 $8 = (($this) + 24|0);
 HEAPF32[$8>>2] = $5;
 $9 = (($this) + 28|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($b) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $inflation);
 $13 = (($b) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $inflation);
 $16 = (($b) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $inflation);
 HEAPF32[$this>>2] = $12;
 $19 = (($this) + 4|0);
 HEAPF32[$19>>2] = $15;
 $20 = (($this) + 8|0);
 HEAPF32[$20>>2] = $18;
 $21 = (($this) + 12|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = Math_fround(HEAPF32[$t>>2]);
 $23 = (($t) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($t) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($t) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($22 + $22);
 $30 = Math_fround($24 + $24);
 $31 = Math_fround($26 + $26);
 $32 = Math_fround($22 * $29);
 $33 = Math_fround($24 * $30);
 $34 = Math_fround($26 * $31);
 $35 = Math_fround($29 * $24);
 $36 = Math_fround($29 * $26);
 $37 = Math_fround($29 * $28);
 $38 = Math_fround($30 * $26);
 $39 = Math_fround($30 * $28);
 $40 = Math_fround($31 * $28);
 $41 = Math_fround(Math_fround(1.0) - $33);
 $42 = Math_fround($41 - $34);
 $43 = Math_fround($35 + $40);
 $44 = Math_fround($36 - $39);
 $45 = Math_fround($35 - $40);
 $46 = Math_fround(Math_fround(1.0) - $32);
 $47 = Math_fround($46 - $34);
 $48 = Math_fround($38 + $37);
 $49 = Math_fround($36 + $39);
 $50 = Math_fround($38 - $37);
 $51 = Math_fround($46 - $33);
 $52 = (($this) + 32|0);
 HEAPF32[$52>>2] = $42;
 $53 = (($this) + 36|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($this) + 40|0);
 HEAPF32[$54>>2] = $49;
 $55 = (($this) + 44|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($this) + 48|0);
 HEAPF32[$56>>2] = $43;
 $57 = (($this) + 52|0);
 HEAPF32[$57>>2] = $47;
 $58 = (($this) + 56|0);
 HEAPF32[$58>>2] = $50;
 $59 = (($this) + 60|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($this) + 64|0);
 HEAPF32[$60>>2] = $44;
 $61 = (($this) + 68|0);
 HEAPF32[$61>>2] = $48;
 $62 = (($this) + 72|0);
 HEAPF32[$62>>2] = $51;
 $63 = (($this) + 76|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = Math_fround(-$42);
 $65 = Math_fround(-$45);
 $66 = Math_fround(-$49);
 $67 = $42 > $64;
 $$$i$i68 = $67 ? $42 : $64;
 $68 = $45 > $65;
 $69 = $68 ? $45 : $65;
 $70 = $49 > $66;
 $$1$i$i69 = $70 ? $49 : $66;
 $71 = Math_fround($$$i$i68 + Math_fround(9.99999997475242707878E-7));
 $72 = Math_fround($69 + Math_fround(9.99999997475242707878E-7));
 $73 = Math_fround($$1$i$i69 + Math_fround(9.99999997475242707878E-7));
 $74 = Math_fround(-$43);
 $75 = Math_fround(-$47);
 $76 = Math_fround(-$50);
 $77 = $43 > $74;
 $$$i$i60 = $77 ? $43 : $74;
 $78 = $47 > $75;
 $79 = $78 ? $47 : $75;
 $80 = $50 > $76;
 $$1$i$i61 = $80 ? $50 : $76;
 $81 = Math_fround($$$i$i60 + Math_fround(9.99999997475242707878E-7));
 $82 = Math_fround($79 + Math_fround(9.99999997475242707878E-7));
 $83 = Math_fround($$1$i$i61 + Math_fround(9.99999997475242707878E-7));
 $84 = Math_fround(-$44);
 $85 = Math_fround(-$48);
 $86 = Math_fround(-$51);
 $87 = $44 > $84;
 $$$i$i = $87 ? $44 : $84;
 $88 = $48 > $85;
 $89 = $88 ? $48 : $85;
 $90 = $51 > $86;
 $$1$i$i = $90 ? $51 : $86;
 $91 = Math_fround($$$i$i + Math_fround(9.99999997475242707878E-7));
 $92 = Math_fround($89 + Math_fround(9.99999997475242707878E-7));
 $93 = Math_fround($$1$i$i + Math_fround(9.99999997475242707878E-7));
 $94 = (($this) + 80|0);
 HEAPF32[$94>>2] = $71;
 $95 = (($this) + 84|0);
 HEAPF32[$95>>2] = $72;
 $96 = (($this) + 88|0);
 HEAPF32[$96>>2] = $73;
 $97 = (($this) + 92|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 $98 = (($this) + 96|0);
 HEAPF32[$98>>2] = $81;
 $99 = (($this) + 100|0);
 HEAPF32[$99>>2] = $82;
 $100 = (($this) + 104|0);
 HEAPF32[$100>>2] = $83;
 $101 = (($this) + 108|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = (($this) + 112|0);
 HEAPF32[$102>>2] = $91;
 $103 = (($this) + 116|0);
 HEAPF32[$103>>2] = $92;
 $104 = (($this) + 120|0);
 HEAPF32[$104>>2] = $93;
 $105 = (($this) + 124|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = Math_fround(HEAPF32[$this>>2]);
 $107 = Math_fround(HEAPF32[$19>>2]);
 $108 = Math_fround(HEAPF32[$20>>2]);
 $109 = Math_fround($106 * $71);
 $110 = Math_fround($107 * $72);
 $111 = Math_fround($109 + $110);
 $112 = Math_fround($108 * $73);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($106 * $81);
 $115 = Math_fround($107 * $82);
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($108 * $83);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($106 * $91);
 $120 = Math_fround($107 * $92);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($108 * $93);
 $123 = Math_fround($121 + $122);
 $124 = (($this) + 128|0);
 HEAPF32[$124>>2] = $113;
 $125 = (($this) + 132|0);
 HEAPF32[$125>>2] = $118;
 $126 = (($this) + 136|0);
 HEAPF32[$126>>2] = $123;
 $127 = (($this) + 140|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = Math_fround($108 * $72);
 $129 = Math_fround($106 * $73);
 $130 = Math_fround($107 * $71);
 $131 = Math_fround($107 * $73);
 $132 = Math_fround($108 * $71);
 $133 = Math_fround($106 * $72);
 $134 = Math_fround($128 + $131);
 $135 = Math_fround($132 + $129);
 $136 = Math_fround($130 + $133);
 $137 = (($this) + 144|0);
 HEAPF32[$137>>2] = $134;
 $138 = (($this) + 148|0);
 HEAPF32[$138>>2] = $135;
 $139 = (($this) + 152|0);
 HEAPF32[$139>>2] = $136;
 $140 = (($this) + 156|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $141 = Math_fround($108 * $82);
 $142 = Math_fround($106 * $83);
 $143 = Math_fround($107 * $81);
 $144 = Math_fround($107 * $83);
 $145 = Math_fround($108 * $81);
 $146 = Math_fround($106 * $82);
 $147 = Math_fround($141 + $144);
 $148 = Math_fround($145 + $142);
 $149 = Math_fround($143 + $146);
 $150 = (($this) + 160|0);
 HEAPF32[$150>>2] = $147;
 $151 = (($this) + 164|0);
 HEAPF32[$151>>2] = $148;
 $152 = (($this) + 168|0);
 HEAPF32[$152>>2] = $149;
 $153 = (($this) + 172|0);
 HEAPF32[$153>>2] = Math_fround(0.0);
 $154 = Math_fround($108 * $92);
 $155 = Math_fround($106 * $93);
 $156 = Math_fround($107 * $91);
 $157 = Math_fround($107 * $93);
 $158 = Math_fround($108 * $91);
 $159 = Math_fround($106 * $92);
 $160 = Math_fround($154 + $157);
 $161 = Math_fround($158 + $155);
 $162 = Math_fround($156 + $159);
 $163 = (($this) + 176|0);
 HEAPF32[$163>>2] = $160;
 $164 = (($this) + 180|0);
 HEAPF32[$164>>2] = $161;
 $165 = (($this) + 184|0);
 HEAPF32[$165>>2] = $162;
 $166 = (($this) + 188|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Sq10AABBPruner12NewTreeFixupENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 506392 : 506168;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,506312,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIjjNS0_4HashIjEENS1_11HashSetBaseIjS4_NS0_9AllocatorELb0EE6GetKeyES6_Lb0EE6createERKjRb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $$pre11 = 0, $$pre11$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $h$0 = 0, $h$1 = 0, $index$0 = 0;
 var $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = $3 << 15;
   $5 = $4 ^ -1;
   $6 = (($3) + ($5))|0;
   $7 = $6 >>> 10;
   $8 = $7 ^ $6;
   $9 = ($8*9)|0;
   $10 = $9 >>> 6;
   $11 = $10 ^ $9;
   $12 = $11 << 11;
   $13 = $12 ^ -1;
   $14 = (($11) + ($13))|0;
   $15 = $14 >>> 16;
   $16 = $15 ^ $14;
   $17 = (($1) + -1)|0;
   $18 = $16 & $17;
   $19 = (($this) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + ($18<<2)|0);
   $index$05 = HEAP32[$21>>2]|0;
   $22 = ($index$05|0)==(-1);
   if ($22) {
    $h$0 = $18;
   } else {
    $23 = (($this) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $26 = (($24) + ($index$06<<2)|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($3|0);
     if ($28) {
      break;
     }
     $29 = HEAP32[$25>>2]|0;
     $30 = (($29) + ($index$06<<2)|0);
     $index$0 = HEAP32[$30>>2]|0;
     $31 = ($index$0|0)==(-1);
     if ($31) {
      $h$0 = $18;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $$0 = $26;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $32 = (($this) + 28|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(-1);
 if ($34) {
  $35 = $1 << 1;
  $$$i = $2 ? 16 : $35;
  $36 = ($1>>>0)<($$$i>>>0);
  if ($36) {
   __ZN5physx6shdfnd8internal8HashBaseIjjNS0_4HashIjEENS1_11HashSetBaseIjS4_NS0_9AllocatorELb0EE6GetKeyES6_Lb0EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $$pre11$pre = HEAP32[$32>>2]|0;
   $$pre11 = $$pre11$pre;$52 = $$pre;
  } else {
   $$pre11 = -1;$52 = $1;
  }
  $37 = HEAP32[$k>>2]|0;
  $38 = $37 << 15;
  $39 = $38 ^ -1;
  $40 = (($37) + ($39))|0;
  $41 = $40 >>> 10;
  $42 = $41 ^ $40;
  $43 = ($42*9)|0;
  $44 = $43 >>> 6;
  $45 = $44 ^ $43;
  $46 = $45 << 11;
  $47 = $46 ^ -1;
  $48 = (($45) + ($47))|0;
  $49 = $48 >>> 16;
  $50 = $49 ^ $48;
  $51 = (($52) + -1)|0;
  $53 = $50 & $51;
  $57 = $$pre11;$h$1 = $53;
 } else {
  $57 = $33;$h$1 = $h$0;
 }
 $54 = (($this) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + ($57<<2)|0);
 $58 = HEAP32[$56>>2]|0;
 HEAP32[$32>>2] = $58;
 $59 = (($this) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + ($h$1<<2)|0);
 $62 = HEAP32[$61>>2]|0;
 HEAP32[$56>>2] = $62;
 HEAP32[$61>>2] = $57;
 $63 = (($this) + 36|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 1)|0;
 HEAP32[$63>>2] = $65;
 $66 = (($this) + 32|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 1)|0;
 HEAP32[$66>>2] = $68;
 $69 = (($this) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + ($57<<2)|0);
 $$0 = $71;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseIjjNS0_4HashIjEENS1_11HashSetBaseIjS4_NS0_9AllocatorELb0EE6GetKeyES6_Lb0EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre$phi14Z2D = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $$pre12 = 0, $$pre13 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucket$06 = 0, $exitcond$i = 0, $i$01$i = 0, $index$01 = 0, $index1$0 = 0, $index1$02 = 0, $index1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($$0>>>0)));
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 $24 = (~~(($23))>>>0);
 $25 = $$0 << 2;
 $26 = $24 << 2;
 $27 = (($26) + ($25))|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 12;
 $30 = (($29) + ($27))|0;
 $31 = (($30) + ($26))|0;
 $32 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$31,506536,354)|0);
 $33 = (($32) + ($25)|0);
 $34 = (($32) + ($30)|0);
 _memset(($32|0),-1,($25|0))|0;
 if ($17) {
  $35 = (($this) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = (($this) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($$0) + -1)|0;
   $index$01 = 0;
   while(1) {
    $41 = (($39) + ($index$01<<2)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42 << 15;
    $44 = $43 ^ -1;
    $45 = (($42) + ($44))|0;
    $46 = $45 >>> 10;
    $47 = $46 ^ $45;
    $48 = ($47*9)|0;
    $49 = $48 >>> 6;
    $50 = $49 ^ $48;
    $51 = $50 << 11;
    $52 = $51 ^ -1;
    $53 = (($50) + ($52))|0;
    $54 = $53 >>> 16;
    $55 = $54 ^ $53;
    $56 = $55 & $40;
    $57 = (($32) + ($56<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($33) + ($index$01<<2)|0);
    HEAP32[$59>>2] = $58;
    HEAP32[$57>>2] = $index$01;
    $60 = (($34) + ($index$01<<2)|0);
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     $62 = HEAP32[$41>>2]|0;
     HEAP32[$60>>2] = $62;
    }
    $63 = (($index$01) + 1)|0;
    $64 = HEAP32[$35>>2]|0;
    $65 = ($63>>>0)<($64>>>0);
    if ($65) {
     $index$01 = $63;
    } else {
     break;
    }
   }
  }
  $$pre12 = (($this) + 20|0);
  $$pre13 = (($this) + 8|0);
  $$pre$phi14Z2D = $$pre13;$$pre$phiZ2D = $$pre12;
 } else {
  $66 = (($this) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$18>>2]|0;
  $69 = $68 << 2;
  _memcpy(($33|0),($67|0),($69|0))|0;
  $70 = (($this) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==(0);
  if ($72) {
   $$pre$phi14Z2D = $66;$$pre$phiZ2D = $70;
  } else {
   $73 = (($this) + 12|0);
   $74 = (($this) + 4|0);
   $75 = (($$0) + -1)|0;
   $$pre = HEAP32[$73>>2]|0;
   $115 = $71;$bucket$06 = 0;
   while(1) {
    $76 = (($$pre) + ($bucket$06<<2)|0);
    $index1$02 = HEAP32[$76>>2]|0;
    $77 = ($index1$02|0)==(-1);
    if ($77) {
     $105 = $115;
    } else {
     $$pre10 = HEAP32[$74>>2]|0;
     $index1$03 = $index1$02;
     while(1) {
      $78 = (($$pre10) + ($index1$03<<2)|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = $79 << 15;
      $81 = $80 ^ -1;
      $82 = (($79) + ($81))|0;
      $83 = $82 >>> 10;
      $84 = $83 ^ $82;
      $85 = ($84*9)|0;
      $86 = $85 >>> 6;
      $87 = $86 ^ $85;
      $88 = $87 << 11;
      $89 = $88 ^ -1;
      $90 = (($87) + ($89))|0;
      $91 = $90 >>> 16;
      $92 = $91 ^ $90;
      $93 = $92 & $75;
      $94 = (($32) + ($93<<2)|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = (($33) + ($index1$03<<2)|0);
      HEAP32[$96>>2] = $95;
      HEAP32[$94>>2] = $index1$03;
      $97 = (($34) + ($index1$03<<2)|0);
      $98 = ($97|0)==(0|0);
      if (!($98)) {
       $99 = HEAP32[$78>>2]|0;
       HEAP32[$97>>2] = $99;
      }
      $100 = HEAP32[$66>>2]|0;
      $101 = (($100) + ($index1$03<<2)|0);
      $index1$0 = HEAP32[$101>>2]|0;
      $102 = ($index1$0|0)==(-1);
      if ($102) {
       break;
      } else {
       $index1$03 = $index1$0;
      }
     }
     $$pre9 = HEAP32[$70>>2]|0;
     $105 = $$pre9;
    }
    $103 = (($bucket$06) + 1)|0;
    $104 = ($103>>>0)<($105>>>0);
    if ($104) {
     $115 = $105;$bucket$06 = $103;
    } else {
     $$pre$phi14Z2D = $66;$$pre$phiZ2D = $70;
     break;
    }
   }
  }
 }
 $106 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$106);
 HEAP32[$this>>2] = $32;
 $107 = (($this) + 12|0);
 HEAP32[$107>>2] = $32;
 HEAP32[$$pre$phiZ2D>>2] = $$0;
 HEAP32[$$pre$phi14Z2D>>2] = $33;
 $108 = (($this) + 4|0);
 HEAP32[$108>>2] = $34;
 HEAP32[$18>>2] = $24;
 $109 = (($24) + -1)|0;
 $110 = ($109>>>0)>($19>>>0);
 if ($110) {
  $i$01$i = $19;
 } else {
  $113 = HEAP32[$15>>2]|0;
  $114 = (($33) + ($109<<2)|0);
  HEAP32[$114>>2] = $113;
  HEAP32[$15>>2] = $19;
  STACKTOP = sp;return;
 }
 while(1) {
  $111 = (($i$01$i) + 1)|0;
  $112 = (($33) + ($i$01$i<<2)|0);
  HEAP32[$112>>2] = $111;
  $exitcond$i = ($111|0)==($109|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $111;
  }
 }
 $113 = HEAP32[$15>>2]|0;
 $114 = (($33) + ($109<<2)|0);
 HEAP32[$114>>2] = $113;
 HEAP32[$15>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq8AABBTreeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 536|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 540|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 544|0);
 HEAP32[$2>>2] = 0;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq8AABBTreeD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Sq8AABBTree7releaseEv($this);
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq8AABBTree7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 544|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 & 2147483647;
  $8 = ($7|0)!=(0);
  $9 = ($6|0)>(-1);
  $or$cond$i$i$i$i = $8 & $9;
  if ($or$cond$i$i$i$i) {
   $10 = HEAP32[$3>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vii[$15 & 4095]($12,$10);
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
 }
 HEAP32[$2>>2] = 0;
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (($17) + -8|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$19);
 }
 HEAP32[$16>>2] = 0;
 $20 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$20);
 HEAP32[$this>>2] = 0;
 $21 = (($this) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 << 2;
 _memset(($22|0),0,($25|0))|0;
 $26 = (($this) + 16|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq8AABBTree5buildEPNS0_15AABBTreeBuilderE($this,$builder) {
 $this = $this|0;
 $builder = $builder|0;
 var $$$i$i$i = 0, $$0 = 0, $$arith = 0, $$arith2 = 0, $$lcssa = 0, $$overflow = 0, $$overflow3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $phitmp = 0, $phitmp3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($builder|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($builder) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx2Sq8AABBTree7releaseEv($this);
 $5 = (($builder) + 24|0);
 HEAP32[$5>>2] = 1;
 $6 = (($builder) + 28|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[$2>>2]|0;
 $8 = $7 << 2;
 $9 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$8,506624,468)|0);
 HEAP32[$this>>2] = $9;
 $10 = HEAP32[$2>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$lcssa = -1;
 } else {
  $i$01 = 0;
  while(1) {
   $12 = (($9) + ($i$01<<2)|0);
   HEAP32[$12>>2] = $i$01;
   $13 = (($i$01) + 1)|0;
   $14 = HEAP32[$2>>2]|0;
   $15 = ($13>>>0)<($14>>>0);
   if ($15) {
    $i$01 = $13;
   } else {
    break;
   }
  }
  $phitmp = $14 << 1;
  $phitmp3 = (($phitmp) + -1)|0;
  $$lcssa = $phitmp3;
 }
 $$arith = ($$lcssa*24)|0;
 $$overflow = ($$lcssa>>>0)>(178956970);
 $$arith2 = (($$arith) + 8)|0;
 $$overflow3 = ($$arith>>>0)>(4294967287);
 $16 = $$overflow | $$overflow3;
 $17 = $16 ? -1 : $$arith2;
 $18 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__Z15PxGetFoundationv()|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 4095]($22)|0);
 $$$i$i$i = $26 ? 506864 : 506712;
 $27 = (FUNCTION_TABLE_iiiiii[$21 & 255]($18,$17,$$$i$i$i,506624,474)|0);
 $28 = (($27) + 4|0);
 HEAP32[$28>>2] = $$lcssa;
 $29 = (($27) + 8|0);
 $30 = (($29) + (($$lcssa*24)|0)|0);
 $32 = $29;
 while(1) {
  $31 = (($32) + 16|0);
  $33 = $31;
  $34 = $33;
  HEAP32[$34>>2] = 0;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = 0;
  $37 = (($32) + 24|0);
  $38 = ($37|0)==($30|0);
  if ($38) {
   break;
  } else {
   $32 = $37;
  }
 }
 $39 = (($this) + 4|0);
 HEAP32[$39>>2] = $29;
 $40 = (($builder) + 12|0);
 HEAP32[$40>>2] = $29;
 $41 = HEAP32[$39>>2]|0;
 $42 = (($41) + 16|0);
 $43 = $42;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$2>>2]|0;
 $50 = $45 & 2;
 $51 = $48 & -256;
 $52 = (_bitshift64Shl(($49|0),0,2)|0);
 $53 = tempRet0;
 $54 = $50 | $52;
 $55 = $51 | $53;
 HEAP32[506704>>2] = 0;
 $56 = $54 | 1;
 $57 = $42;
 $58 = $57;
 HEAP32[$58>>2] = $56;
 $59 = (($57) + 4)|0;
 $60 = $59;
 HEAP32[$60>>2] = $55;
 $61 = HEAP32[$this>>2]|0;
 __ZN5physx2Sq12AABBTreeNode15_buildHierarchyEPNS0_15AABBTreeBuilderEPj($41,$builder,$61);
 $62 = HEAP32[$5>>2]|0;
 $63 = (($this) + 536|0);
 HEAP32[$63>>2] = $62;
 $64 = (($builder) + 16|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($this) + 540|0);
 HEAP32[$66>>2] = $65;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sq12AABBTreeNode15_buildHierarchyEPNS0_15AABBTreeBuilderEPj($this,$builder,$indices) {
 $this = $this|0;
 $builder = $builder|0;
 $indices = $indices|0;
 var $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i7 = Math_fround(0), $$$i102$i = Math_fround(0), $$$i12$i = Math_fround(0), $$$i1268$lcssa$i = Math_fround(0), $$$i126872$i = Math_fround(0), $$$i164$i = Math_fround(0), $$$i170$i = Math_fround(0), $$$i66$lcssa$i = Math_fround(0), $$$i6674$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i$i$i = Math_fround(0), $$1$i13$i = Math_fround(0), $$1$i1369$lcssa$i = Math_fround(0), $$1$i136971$i = Math_fround(0), $$1$i165$i = Math_fround(0), $$1$i171$i = Math_fround(0), $$1$i67$lcssa$i = Math_fround(0), $$1$i6773$i = Math_fround(0);
 var $$in1$i$i = 0, $$in2$i$i = 0, $$lcssa$i = Math_fround(0), $$lcssa70$i = Math_fround(0), $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0;
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0;
 var $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, $exactBounds = 0, $exitcond$i = 0, $i$075$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 16|0;
 $1 = sp;
 $exactBounds = sp + 32|0;
 $2 = HEAP32[506704>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[506704>>2] = $3;
 $4 = (($this) + 16|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (_bitshift64Lshr(($7|0),($10|0),21)|0);
 $12 = tempRet0;
 $13 = $11 & 524287;
 $14 = (($indices) + ($13<<2)|0);
 $15 = (_bitshift64Lshr(($7|0),($10|0),2)|0);
 $16 = tempRet0;
 $17 = $15 & 524287;
 $18 = HEAP32[$14>>2]|0;
 $19 = (($builder) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + (($18*24)|0)|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = ((($20) + (($18*24)|0)|0) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = ((($20) + (($18*24)|0)|0) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = ((($20) + (($18*24)|0)|0) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = ((($20) + (($18*24)|0)|0) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = ((($20) + (($18*24)|0)|0) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = ($17>>>0)>(1);
 if ($33) {
  $$$i126872$i = $22;$$$i6674$i = $28;$$1$i136971$i = $26;$$1$i6773$i = $32;$44 = $24;$55 = $30;$i$075$i = 1;
  while(1) {
   $$sum = (($i$075$i) + ($13))|0;
   $34 = (($indices) + ($$sum<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($20) + (($35*24)|0)|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = ((($20) + (($35*24)|0)|0) + 4|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = ((($20) + (($35*24)|0)|0) + 8|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = $$$i126872$i < $37;
   $$$i12$i = $42 ? $$$i126872$i : $37;
   $43 = $44 < $39;
   $45 = $43 ? $44 : $39;
   $46 = $$1$i136971$i < $41;
   $$1$i13$i = $46 ? $$1$i136971$i : $41;
   $47 = ((($20) + (($35*24)|0)|0) + 12|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = ((($20) + (($35*24)|0)|0) + 16|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = ((($20) + (($35*24)|0)|0) + 20|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $53 = $$$i6674$i > $48;
   $$$i$i7 = $53 ? $$$i6674$i : $48;
   $54 = $55 > $50;
   $56 = $54 ? $55 : $50;
   $57 = $$1$i6773$i > $52;
   $$1$i$i = $57 ? $$1$i6773$i : $52;
   $58 = (($i$075$i) + 1)|0;
   $exitcond$i = ($58|0)==($17|0);
   if ($exitcond$i) {
    $$$i1268$lcssa$i = $$$i12$i;$$$i66$lcssa$i = $$$i$i7;$$1$i1369$lcssa$i = $$1$i13$i;$$1$i67$lcssa$i = $$1$i$i;$$lcssa$i = $45;$$lcssa70$i = $56;
    break;
   } else {
    $$$i126872$i = $$$i12$i;$$$i6674$i = $$$i$i7;$$1$i136971$i = $$1$i13$i;$$1$i6773$i = $$1$i$i;$44 = $45;$55 = $56;$i$075$i = $58;
   }
  }
 } else {
  $$$i1268$lcssa$i = $22;$$$i66$lcssa$i = $28;$$1$i1369$lcssa$i = $26;$$1$i67$lcssa$i = $32;$$lcssa$i = $24;$$lcssa70$i = $30;
 }
 HEAPF32[$exactBounds>>2] = $$$i1268$lcssa$i;
 $59 = (($exactBounds) + 4|0);
 HEAPF32[$59>>2] = $$lcssa$i;
 $60 = (($exactBounds) + 8|0);
 HEAPF32[$60>>2] = $$1$i1369$lcssa$i;
 $61 = (($exactBounds) + 12|0);
 HEAPF32[$61>>2] = $$$i66$lcssa$i;
 $62 = (($exactBounds) + 16|0);
 HEAPF32[$62>>2] = $$lcssa70$i;
 $63 = (($exactBounds) + 20|0);
 HEAPF32[$63>>2] = $$1$i67$lcssa$i;
 $64 = $7 | 1;
 $65 = $4;
 $66 = $65;
 HEAP32[$66>>2] = $64;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $10;
 (__ZN5physx2Sq12AABBTreeNode9subdivideERKNS_9PxBounds3EPNS0_15AABBTreeBuilderEPj($this,$exactBounds,$builder,$indices)|0);
 $69 = $$$i1268$lcssa$i > Math_fround(-9.99999994495727286427E+32);
 $$$i170$i = $69 ? $$$i1268$lcssa$i : Math_fround(-9.99999994495727286427E+32);
 $70 = $$lcssa$i > Math_fround(-9.99999994495727286427E+32);
 $71 = $70 ? $$lcssa$i : Math_fround(-9.99999994495727286427E+32);
 $72 = $$1$i1369$lcssa$i > Math_fround(-9.99999994495727286427E+32);
 $$1$i171$i = $72 ? $$1$i1369$lcssa$i : Math_fround(-9.99999994495727286427E+32);
 $73 = $$$i66$lcssa$i < Math_fround(9.99999994495727286427E+32);
 $$$i164$i = $73 ? $$$i66$lcssa$i : Math_fround(9.99999994495727286427E+32);
 $74 = $$lcssa70$i < Math_fround(9.99999994495727286427E+32);
 $75 = $74 ? $$lcssa70$i : Math_fround(9.99999994495727286427E+32);
 $76 = $$1$i67$lcssa$i < Math_fround(9.99999994495727286427E+32);
 $$1$i165$i = $76 ? $$1$i67$lcssa$i : Math_fround(9.99999994495727286427E+32);
 $77 = Math_fround($$$i164$i + $$$i170$i);
 $78 = Math_fround($75 + $71);
 $79 = Math_fround($$1$i165$i + $$1$i171$i);
 $80 = Math_fround($77 * Math_fround(0.5));
 $81 = Math_fround($78 * Math_fround(0.5));
 $82 = Math_fround($79 * Math_fround(0.5));
 $83 = Math_fround($$$i164$i - $$$i170$i);
 $84 = Math_fround($75 - $71);
 $85 = Math_fround($$1$i165$i - $$1$i171$i);
 $86 = Math_fround($83 * Math_fround(0.5));
 $87 = Math_fround($84 * Math_fround(0.5));
 $88 = Math_fround($85 * Math_fround(0.5));
 $89 = Math_fround($80 * Math_fround(9.99999974737875163555E-5));
 $90 = Math_fround($81 * Math_fround(9.99999974737875163555E-5));
 $91 = Math_fround($82 * Math_fround(9.99999974737875163555E-5));
 $92 = Math_fround(-$89);
 $93 = Math_fround(-$90);
 $94 = Math_fround(-$91);
 $95 = $89 > $92;
 $$$i$i$i = $95 ? $89 : $92;
 $96 = $90 > $93;
 $97 = $96 ? $90 : $93;
 $98 = $91 > $94;
 $$1$i$i$i = $98 ? $91 : $94;
 $99 = Math_fround($$$i$i$i + Math_fround(9.99999974737875163555E-5));
 $100 = Math_fround($97 + Math_fround(9.99999974737875163555E-5));
 $101 = Math_fround($$1$i$i$i + Math_fround(9.99999974737875163555E-5));
 $102 = Math_fround($86 + $99);
 $103 = Math_fround($87 + $100);
 $104 = Math_fround($88 + $101);
 $105 = $103 > $104;
 $$$i102$i = $105 ? $103 : $104;
 $106 = $102 > $$$i102$i;
 $$$i$i = $106 ? $102 : $$$i102$i;
 $107 = Math_fround($$$i$i * Math_fround(0.00392158422619104385376));
 $108 = Math_fround($107 * Math_fround(9.99999974737875163555E-5));
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($109 * Math_fround(1.0E+4));
 $111 = (HEAPF32[tempDoublePtr>>2]=$110,HEAP32[tempDoublePtr>>2]|0);
 $112 = Math_fround(Math_fround(1.0) / $107);
 $113 = Math_fround($112 * $102);
 $114 = Math_fround($112 * $103);
 $115 = Math_fround($112 * $104);
 $116 = Math_fround($113 + Math_fround(1.0));
 $117 = Math_fround($114 + Math_fround(1.0));
 $118 = Math_fround($115 + Math_fround(1.0));
 $119 = (~~(($116)));
 $120 = (~~(($117)));
 $121 = (~~(($118)));
 $122 = $80 == Math_fround(0.0);
 $123 = $81 == Math_fround(0.0);
 $124 = $82 == Math_fround(0.0);
 HEAPF32[$1>>2] = Math_fround(2.35098870164457501594E-38);
 $125 = (($1) + 4|0);
 HEAPF32[$125>>2] = Math_fround(2.35098870164457501594E-38);
 $126 = (($1) + 8|0);
 HEAPF32[$126>>2] = Math_fround(2.35098870164457501594E-38);
 $127 = (($1) + 12|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = $80;
 $128 = (($0) + 4|0);
 HEAPF32[$128>>2] = $81;
 $129 = (($0) + 8|0);
 HEAPF32[$129>>2] = $82;
 $130 = (($0) + 12|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $b$a$i$i = $122 ? $1 : $0;
 $131 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $123 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $132 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $124 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $133 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $134 = (HEAPF32[tempDoublePtr>>2]=$131,HEAP32[tempDoublePtr>>2]|0);
 $135 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
 $136 = (HEAPF32[tempDoublePtr>>2]=$133,HEAP32[tempDoublePtr>>2]|0);
 $137 = $134 & -256;
 $138 = $135 & -256;
 $139 = $136 & -256;
 $140 = $119 | $137;
 $141 = $120 | $138;
 $142 = $121 | $139;
 $143 = (HEAP32[tempDoublePtr>>2]=$140,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $144 = (HEAP32[tempDoublePtr>>2]=$141,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $145 = (HEAP32[tempDoublePtr>>2]=$142,Math_fround(HEAPF32[tempDoublePtr>>2]));
 HEAPF32[$this>>2] = $143;
 $146 = (($this) + 4|0);
 HEAPF32[$146>>2] = $144;
 $147 = (($this) + 8|0);
 HEAPF32[$147>>2] = $145;
 $148 = $111 >>> 8;
 $149 = $4;
 $150 = $149;
 $151 = HEAP32[$150>>2]|0;
 $152 = (($149) + 4)|0;
 $153 = $152;
 $154 = HEAP32[$153>>2]|0;
 $155 = $154 & 255;
 $156 = (_bitshift64Shl(($148|0),0,40)|0);
 $157 = tempRet0;
 $158 = $156 | $151;
 $159 = $157 | $155;
 $160 = $4;
 $161 = $160;
 HEAP32[$161>>2] = $158;
 $162 = (($160) + 4)|0;
 $163 = $162;
 HEAP32[$163>>2] = $159;
 $164 = (($builder) + 12|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = $151 & 1;
 $167 = ($166|0)==(0);
 $168 = (0)==(0);
 $169 = $167 & $168;
 if (!($169)) {
  $218 = $4;
  $219 = $218;
  $220 = HEAP32[$219>>2]|0;
  $221 = (($218) + 4)|0;
  $222 = $221;
  $223 = HEAP32[$222>>2]|0;
  $224 = (_bitshift64Lshr(($220|0),($223|0),2)|0);
  $225 = tempRet0;
  $226 = $224 & 524287;
  $227 = (($builder) + 16|0);
  $228 = HEAP32[$227>>2]|0;
  $229 = (($226) + ($228))|0;
  HEAP32[$227>>2] = $229;
  $230 = $this;
  $231 = $165;
  $232 = (($230) - ($231))|0;
  $233 = (($232|0) / 24)&-1;
  $234 = $220 & -2097149;
  $235 = (_bitshift64Shl(($233|0),0,2)|0);
  $236 = tempRet0;
  $237 = $234 | $235;
  $238 = $223 | $236;
  $239 = $4;
  $240 = $239;
  HEAP32[$240>>2] = $237;
  $241 = (($239) + 4)|0;
  $242 = $241;
  HEAP32[$242>>2] = $238;
  STACKTOP = sp;return;
 }
 $170 = (_bitshift64Lshr(($151|0),($154|0),21)|0);
 $171 = tempRet0;
 $172 = $170 & 524287;
 $173 = ($172|0)==(0);
 $$sum$i = (($172) + 1)|0;
 $174 = (($165) + (($$sum$i*24)|0)|0);
 $175 = $173 ? $165 : $174;
 if (!($173)) {
  $176 = (($165) + (($172*24)|0)|0);
  __ZN5physx2Sq12AABBTreeNode15_buildHierarchyEPNS0_15AABBTreeBuilderEPj($176,$builder,$indices);
  $177 = $this;
  $178 = $165;
  $179 = (($177) - ($178))|0;
  $180 = (($179|0) / 24)&-1;
  $181 = ((($165) + (($172*24)|0)|0) + 16|0);
  $182 = $181;
  $183 = $182;
  $184 = HEAP32[$183>>2]|0;
  $185 = (($182) + 4)|0;
  $186 = $185;
  $187 = HEAP32[$186>>2]|0;
  $188 = $184 & -2097149;
  $189 = (_bitshift64Shl(($180|0),0,2)|0);
  $190 = tempRet0;
  $191 = $188 | $189;
  $192 = $187 | $190;
  $193 = $181;
  $194 = $193;
  HEAP32[$194>>2] = $191;
  $195 = (($193) + 4)|0;
  $196 = $195;
  HEAP32[$196>>2] = $192;
 }
 $197 = ($175|0)==($165|0);
 if ($197) {
  $218 = $4;
  $219 = $218;
  $220 = HEAP32[$219>>2]|0;
  $221 = (($218) + 4)|0;
  $222 = $221;
  $223 = HEAP32[$222>>2]|0;
  $224 = (_bitshift64Lshr(($220|0),($223|0),2)|0);
  $225 = tempRet0;
  $226 = $224 & 524287;
  $227 = (($builder) + 16|0);
  $228 = HEAP32[$227>>2]|0;
  $229 = (($226) + ($228))|0;
  HEAP32[$227>>2] = $229;
  $230 = $this;
  $231 = $165;
  $232 = (($230) - ($231))|0;
  $233 = (($232|0) / 24)&-1;
  $234 = $220 & -2097149;
  $235 = (_bitshift64Shl(($233|0),0,2)|0);
  $236 = tempRet0;
  $237 = $234 | $235;
  $238 = $223 | $236;
  $239 = $4;
  $240 = $239;
  HEAP32[$240>>2] = $237;
  $241 = (($239) + 4)|0;
  $242 = $241;
  HEAP32[$242>>2] = $238;
  STACKTOP = sp;return;
 }
 __ZN5physx2Sq12AABBTreeNode15_buildHierarchyEPNS0_15AABBTreeBuilderEPj($175,$builder,$indices);
 $198 = $this;
 $199 = $165;
 $200 = (($198) - ($199))|0;
 $201 = (($200|0) / 24)&-1;
 $202 = (($175) + 16|0);
 $203 = $202;
 $204 = $203;
 $205 = HEAP32[$204>>2]|0;
 $206 = (($203) + 4)|0;
 $207 = $206;
 $208 = HEAP32[$207>>2]|0;
 $209 = $205 & -2097149;
 $210 = (_bitshift64Shl(($201|0),0,2)|0);
 $211 = tempRet0;
 $212 = $209 | $210;
 $213 = $208 | $211;
 $214 = $202;
 $215 = $214;
 HEAP32[$215>>2] = $212;
 $216 = (($214) + 4)|0;
 $217 = $216;
 HEAP32[$217>>2] = $213;
 $218 = $4;
 $219 = $218;
 $220 = HEAP32[$219>>2]|0;
 $221 = (($218) + 4)|0;
 $222 = $221;
 $223 = HEAP32[$222>>2]|0;
 $224 = (_bitshift64Lshr(($220|0),($223|0),2)|0);
 $225 = tempRet0;
 $226 = $224 & 524287;
 $227 = (($builder) + 16|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = (($226) + ($228))|0;
 HEAP32[$227>>2] = $229;
 $230 = $this;
 $231 = $165;
 $232 = (($230) - ($231))|0;
 $233 = (($232|0) / 24)&-1;
 $234 = $220 & -2097149;
 $235 = (_bitshift64Shl(($233|0),0,2)|0);
 $236 = tempRet0;
 $237 = $234 | $235;
 $238 = $223 | $236;
 $239 = $4;
 $240 = $239;
 HEAP32[$240>>2] = $237;
 $241 = (($239) + 4)|0;
 $242 = $241;
 HEAP32[$242>>2] = $238;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq8AABBTree16progressiveBuildEPNS0_15AABBTreeBuilderEjj($this,$builder,$progress,$limit) {
 $this = $this|0;
 $builder = $builder|0;
 $progress = $progress|0;
 $limit = $limit|0;
 var $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i$i$i1 = 0, $$$i$i$i2 = 0, $$$i$i10$i = Math_fround(0), $$$i102$i$i = Math_fround(0), $$$i12$i$i = Math_fround(0), $$$i1268$lcssa$i$i = Math_fround(0), $$$i126872$i$i = Math_fround(0), $$$i164$i$i = Math_fround(0), $$$i170$i$i = Math_fround(0), $$$i66$lcssa$i$i = Math_fround(0), $$$i6674$i$i = Math_fround(0), $$0 = 0, $$1$i$i$i = Math_fround(0), $$1$i$i$i$i = Math_fround(0), $$1$i13$i$i = Math_fround(0), $$1$i1369$lcssa$i$i = Math_fround(0), $$1$i136971$i$i = Math_fround(0), $$1$i165$i$i = Math_fround(0);
 var $$1$i171$i$i = Math_fround(0), $$1$i67$lcssa$i$i = Math_fround(0), $$1$i6773$i$i = Math_fround(0), $$arith = 0, $$arith2 = 0, $$in1$i$i$i = 0, $$in2$i$i$i = 0, $$lcssa = 0, $$lcssa$i$i = Math_fround(0), $$lcssa70$i$i = Math_fround(0), $$overflow = 0, $$overflow3 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i2$i = 0, $$pre11 = 0, $$sum$i = 0, $$sum$i$i = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0;
 var $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0;
 var $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0);
 var $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0);
 var $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0);
 var $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Total$06 = 0, $a$pn3$i$i$i = 0;
 var $b$a$i$i$i = 0, $b$a5$i$i$i = 0, $exactBounds$i = 0, $exitcond$i$i = 0, $i$03 = 0, $i$075$i$i = 0, $or$cond$i$i$i$i = 0, $phitmp = 0, $phitmp12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = sp + 40|0;
 $3 = sp + 32|0;
 $exactBounds$i = sp + 48|0;
 $4 = sp + 72|0;
 if ((($progress|0) == 0)) {
  $5 = ($builder|0)==(0|0);
  if ($5) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $6 = (($builder) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  __ZN5physx2Sq8AABBTree7releaseEv($this);
  $9 = (($builder) + 24|0);
  HEAP32[$9>>2] = 1;
  $10 = (($builder) + 28|0);
  HEAP32[$10>>2] = 0;
  $11 = HEAP32[$6>>2]|0;
  $12 = $11 << 2;
  $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$12,506624,556)|0);
  HEAP32[$this>>2] = $13;
  $14 = HEAP32[$6>>2]|0;
  $15 = ($14|0)==(0);
  if ($15) {
   $$lcssa = -1;
  } else {
   $i$03 = 0;
   while(1) {
    $16 = (($13) + ($i$03<<2)|0);
    HEAP32[$16>>2] = $i$03;
    $17 = (($i$03) + 1)|0;
    $18 = HEAP32[$6>>2]|0;
    $19 = ($17>>>0)<($18>>>0);
    if ($19) {
     $i$03 = $17;
    } else {
     break;
    }
   }
   $phitmp = $18 << 1;
   $phitmp12 = (($phitmp) + -1)|0;
   $$lcssa = $phitmp12;
  }
  $$arith = ($$lcssa*24)|0;
  $$overflow = ($$lcssa>>>0)>(178956970);
  $$arith2 = (($$arith) + 8)|0;
  $$overflow3 = ($$arith>>>0)>(4294967287);
  $20 = $$overflow | $$overflow3;
  $21 = $20 ? -1 : $$arith2;
  $22 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (__Z15PxGetFoundationv()|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 24|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (FUNCTION_TABLE_ii[$29 & 4095]($26)|0);
  $$$i$i$i1 = $30 ? 506864 : 506712;
  $31 = (FUNCTION_TABLE_iiiiii[$25 & 255]($22,$21,$$$i$i$i1,506624,563)|0);
  $32 = (($31) + 4|0);
  HEAP32[$32>>2] = $$lcssa;
  $33 = (($31) + 8|0);
  $34 = (($33) + (($$lcssa*24)|0)|0);
  $36 = $33;
  while(1) {
   $35 = (($36) + 16|0);
   $37 = $35;
   $38 = $37;
   HEAP32[$38>>2] = 0;
   $39 = (($37) + 4)|0;
   $40 = $39;
   HEAP32[$40>>2] = 0;
   $41 = (($36) + 24|0);
   $42 = ($41|0)==($34|0);
   if ($42) {
    break;
   } else {
    $36 = $41;
   }
  }
  $43 = (($this) + 4|0);
  HEAP32[$43>>2] = $33;
  $44 = (($builder) + 12|0);
  HEAP32[$44>>2] = $33;
  $45 = HEAP32[$43>>2]|0;
  $46 = (($45) + 16|0);
  $47 = $46;
  $48 = $47;
  $49 = HEAP32[$48>>2]|0;
  $50 = (($47) + 4)|0;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = HEAP32[$6>>2]|0;
  $54 = $49 & 2;
  $55 = $52 & -256;
  $56 = (_bitshift64Shl(($53|0),0,2)|0);
  $57 = tempRet0;
  $58 = $54 | $56;
  $59 = $55 | $57;
  $60 = $58 | 1;
  $61 = $46;
  $62 = $61;
  HEAP32[$62>>2] = $60;
  $63 = (($61) + 4)|0;
  $64 = $63;
  HEAP32[$64>>2] = $59;
  $65 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + 8|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (__Z15PxGetFoundationv()|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($70) + 24|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (FUNCTION_TABLE_ii[$72 & 4095]($69)|0);
  $$$i$i$i2 = $73 ? 506744 : 506712;
  $74 = (FUNCTION_TABLE_iiiiii[$68 & 255]($65,16,$$$i$i$i2,506624,571)|0);
  ;HEAP32[$74+0>>2]=0|0;HEAP32[$74+4>>2]=0|0;HEAP32[$74+8>>2]=0|0;HEAP32[$74+12>>2]=0|0;
  $75 = (($this) + 544|0);
  HEAP32[$75>>2] = $74;
  $76 = HEAP32[$43>>2]|0;
  HEAP32[$0>>2] = $76;
  $77 = (($0) + 4|0);
  HEAP32[$77>>2] = $76;
  (__ZN5physx6shdfnd5ArrayINS_2Sq10FIFOStack213NodeAndParentENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($74,$0)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($progress|0) == 1)) {
  $78 = (($this) + 544|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($79) + 4|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)==(0);
  if ($82) {
   $341 = (($builder) + 24|0);
   $342 = HEAP32[$341>>2]|0;
   $343 = (($this) + 536|0);
   HEAP32[$343>>2] = $342;
   $344 = (($builder) + 16|0);
   $345 = HEAP32[$344>>2]|0;
   $346 = (($this) + 540|0);
   HEAP32[$346>>2] = $345;
   $347 = ($79|0)==(0|0);
   if (!($347)) {
    $348 = (($79) + 8|0);
    $349 = HEAP32[$348>>2]|0;
    $350 = $349 & 2147483647;
    $351 = ($350|0)!=(0);
    $352 = ($349|0)>(-1);
    $or$cond$i$i$i$i = $351 & $352;
    if ($or$cond$i$i$i$i) {
     $353 = HEAP32[$79>>2]|0;
     $354 = ($353|0)==(0|0);
     if (!($354)) {
      $355 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $356 = HEAP32[$355>>2]|0;
      $357 = (($356) + 12|0);
      $358 = HEAP32[$357>>2]|0;
      FUNCTION_TABLE_vii[$358 & 4095]($355,$353);
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$79);
   }
   HEAP32[$78>>2] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $83 = ($limit|0)==(0);
  if ($83) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $84 = (($builder) + 20|0);
  $85 = (($exactBounds$i) + 4|0);
  $86 = (($exactBounds$i) + 8|0);
  $87 = (($exactBounds$i) + 12|0);
  $88 = (($exactBounds$i) + 16|0);
  $89 = (($exactBounds$i) + 20|0);
  $90 = (($1) + 4|0);
  $91 = (($1) + 8|0);
  $92 = (($1) + 12|0);
  $93 = (($0) + 4|0);
  $94 = (($0) + 8|0);
  $95 = (($0) + 12|0);
  $96 = (($builder) + 12|0);
  $97 = (($3) + 4|0);
  $98 = (($2) + 4|0);
  $99 = (($builder) + 16|0);
  $101 = $79;$103 = $81;$Total$06 = 0;
  while(1) {
   $100 = (($101) + 4|0);
   $102 = ($103|0)==(0);
   if ($102) {
    $$0 = 1;
    label = 39;
    break;
   }
   $104 = (($101) + 12|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = HEAP32[$101>>2]|0;
   $107 = (($106) + ($105<<3)|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($105) + 1)|0;
   HEAP32[$104>>2] = $109;
   $110 = ((($106) + ($105<<3)|0) + 4|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($109|0)==($103|0);
   if ($112) {
    HEAP32[$100>>2] = 0;
    HEAP32[$104>>2] = 0;
   }
   $113 = HEAP32[$this>>2]|0;
   $114 = (($108) + 16|0);
   $115 = $114;
   $116 = $115;
   $117 = HEAP32[$116>>2]|0;
   $118 = (($115) + 4)|0;
   $119 = $118;
   $120 = HEAP32[$119>>2]|0;
   $121 = (_bitshift64Lshr(($117|0),($120|0),21)|0);
   $122 = tempRet0;
   $123 = $121 & 524287;
   $124 = (($113) + ($123<<2)|0);
   $125 = (_bitshift64Lshr(($117|0),($120|0),2)|0);
   $126 = tempRet0;
   $127 = $125 & 524287;
   $128 = HEAP32[$124>>2]|0;
   $129 = HEAP32[$84>>2]|0;
   $130 = (($129) + (($128*24)|0)|0);
   $131 = Math_fround(HEAPF32[$130>>2]);
   $132 = ((($129) + (($128*24)|0)|0) + 4|0);
   $133 = Math_fround(HEAPF32[$132>>2]);
   $134 = ((($129) + (($128*24)|0)|0) + 8|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = ((($129) + (($128*24)|0)|0) + 12|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = ((($129) + (($128*24)|0)|0) + 16|0);
   $139 = Math_fround(HEAPF32[$138>>2]);
   $140 = ((($129) + (($128*24)|0)|0) + 20|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = ($127>>>0)>(1);
   if ($142) {
    $$$i126872$i$i = $131;$$$i6674$i$i = $137;$$1$i136971$i$i = $135;$$1$i6773$i$i = $141;$153 = $133;$164 = $139;$i$075$i$i = 1;
    while(1) {
     $$sum$i = (($i$075$i$i) + ($123))|0;
     $143 = (($113) + ($$sum$i<<2)|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = (($129) + (($144*24)|0)|0);
     $146 = Math_fround(HEAPF32[$145>>2]);
     $147 = ((($129) + (($144*24)|0)|0) + 4|0);
     $148 = Math_fround(HEAPF32[$147>>2]);
     $149 = ((($129) + (($144*24)|0)|0) + 8|0);
     $150 = Math_fround(HEAPF32[$149>>2]);
     $151 = $$$i126872$i$i < $146;
     $$$i12$i$i = $151 ? $$$i126872$i$i : $146;
     $152 = $153 < $148;
     $154 = $152 ? $153 : $148;
     $155 = $$1$i136971$i$i < $150;
     $$1$i13$i$i = $155 ? $$1$i136971$i$i : $150;
     $156 = ((($129) + (($144*24)|0)|0) + 12|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = ((($129) + (($144*24)|0)|0) + 16|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = ((($129) + (($144*24)|0)|0) + 20|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = $$$i6674$i$i > $157;
     $$$i$i10$i = $162 ? $$$i6674$i$i : $157;
     $163 = $164 > $159;
     $165 = $163 ? $164 : $159;
     $166 = $$1$i6773$i$i > $161;
     $$1$i$i$i = $166 ? $$1$i6773$i$i : $161;
     $167 = (($i$075$i$i) + 1)|0;
     $exitcond$i$i = ($167|0)==($127|0);
     if ($exitcond$i$i) {
      $$$i1268$lcssa$i$i = $$$i12$i$i;$$$i66$lcssa$i$i = $$$i$i10$i;$$1$i1369$lcssa$i$i = $$1$i13$i$i;$$1$i67$lcssa$i$i = $$1$i$i$i;$$lcssa$i$i = $154;$$lcssa70$i$i = $165;
      break;
     } else {
      $$$i126872$i$i = $$$i12$i$i;$$$i6674$i$i = $$$i$i10$i;$$1$i136971$i$i = $$1$i13$i$i;$$1$i6773$i$i = $$1$i$i$i;$153 = $154;$164 = $165;$i$075$i$i = $167;
     }
    }
   } else {
    $$$i1268$lcssa$i$i = $131;$$$i66$lcssa$i$i = $137;$$1$i1369$lcssa$i$i = $135;$$1$i67$lcssa$i$i = $141;$$lcssa$i$i = $133;$$lcssa70$i$i = $139;
   }
   HEAPF32[$exactBounds$i>>2] = $$$i1268$lcssa$i$i;
   HEAPF32[$85>>2] = $$lcssa$i$i;
   HEAPF32[$86>>2] = $$1$i1369$lcssa$i$i;
   HEAPF32[$87>>2] = $$$i66$lcssa$i$i;
   HEAPF32[$88>>2] = $$lcssa70$i$i;
   HEAPF32[$89>>2] = $$1$i67$lcssa$i$i;
   $168 = $117 | 1;
   $169 = $114;
   $170 = $169;
   HEAP32[$170>>2] = $168;
   $171 = (($169) + 4)|0;
   $172 = $171;
   HEAP32[$172>>2] = $120;
   (__ZN5physx2Sq12AABBTreeNode9subdivideERKNS_9PxBounds3EPNS0_15AABBTreeBuilderEPj($108,$exactBounds$i,$builder,$113)|0);
   $173 = $$$i1268$lcssa$i$i > Math_fround(-9.99999994495727286427E+32);
   $$$i170$i$i = $173 ? $$$i1268$lcssa$i$i : Math_fround(-9.99999994495727286427E+32);
   $174 = $$lcssa$i$i > Math_fround(-9.99999994495727286427E+32);
   $175 = $174 ? $$lcssa$i$i : Math_fround(-9.99999994495727286427E+32);
   $176 = $$1$i1369$lcssa$i$i > Math_fround(-9.99999994495727286427E+32);
   $$1$i171$i$i = $176 ? $$1$i1369$lcssa$i$i : Math_fround(-9.99999994495727286427E+32);
   $177 = $$$i66$lcssa$i$i < Math_fround(9.99999994495727286427E+32);
   $$$i164$i$i = $177 ? $$$i66$lcssa$i$i : Math_fround(9.99999994495727286427E+32);
   $178 = $$lcssa70$i$i < Math_fround(9.99999994495727286427E+32);
   $179 = $178 ? $$lcssa70$i$i : Math_fround(9.99999994495727286427E+32);
   $180 = $$1$i67$lcssa$i$i < Math_fround(9.99999994495727286427E+32);
   $$1$i165$i$i = $180 ? $$1$i67$lcssa$i$i : Math_fround(9.99999994495727286427E+32);
   $181 = Math_fround($$$i164$i$i + $$$i170$i$i);
   $182 = Math_fround($179 + $175);
   $183 = Math_fround($$1$i165$i$i + $$1$i171$i$i);
   $184 = Math_fround($181 * Math_fround(0.5));
   $185 = Math_fround($182 * Math_fround(0.5));
   $186 = Math_fround($183 * Math_fround(0.5));
   $187 = Math_fround($$$i164$i$i - $$$i170$i$i);
   $188 = Math_fround($179 - $175);
   $189 = Math_fround($$1$i165$i$i - $$1$i171$i$i);
   $190 = Math_fround($187 * Math_fround(0.5));
   $191 = Math_fround($188 * Math_fround(0.5));
   $192 = Math_fround($189 * Math_fround(0.5));
   $193 = Math_fround($184 * Math_fround(9.99999974737875163555E-5));
   $194 = Math_fround($185 * Math_fround(9.99999974737875163555E-5));
   $195 = Math_fround($186 * Math_fround(9.99999974737875163555E-5));
   $196 = Math_fround(-$193);
   $197 = Math_fround(-$194);
   $198 = Math_fround(-$195);
   $199 = $193 > $196;
   $$$i$i$i$i = $199 ? $193 : $196;
   $200 = $194 > $197;
   $201 = $200 ? $194 : $197;
   $202 = $195 > $198;
   $$1$i$i$i$i = $202 ? $195 : $198;
   $203 = Math_fround($$$i$i$i$i + Math_fround(9.99999974737875163555E-5));
   $204 = Math_fround($201 + Math_fround(9.99999974737875163555E-5));
   $205 = Math_fround($$1$i$i$i$i + Math_fround(9.99999974737875163555E-5));
   $206 = Math_fround($190 + $203);
   $207 = Math_fround($191 + $204);
   $208 = Math_fround($192 + $205);
   $209 = $207 > $208;
   $$$i102$i$i = $209 ? $207 : $208;
   $210 = $206 > $$$i102$i$i;
   $$$i$i$i = $210 ? $206 : $$$i102$i$i;
   $211 = Math_fround($$$i$i$i * Math_fround(0.00392158422619104385376));
   $212 = Math_fround($211 * Math_fround(9.99999974737875163555E-5));
   $213 = Math_fround($211 + $212);
   $214 = Math_fround($213 * Math_fround(1.0E+4));
   $215 = (HEAPF32[tempDoublePtr>>2]=$214,HEAP32[tempDoublePtr>>2]|0);
   $216 = Math_fround(Math_fround(1.0) / $211);
   $217 = Math_fround($216 * $206);
   $218 = Math_fround($216 * $207);
   $219 = Math_fround($216 * $208);
   $220 = Math_fround($217 + Math_fround(1.0));
   $221 = Math_fround($218 + Math_fround(1.0));
   $222 = Math_fround($219 + Math_fround(1.0));
   $223 = (~~(($220)));
   $224 = (~~(($221)));
   $225 = (~~(($222)));
   $226 = $184 == Math_fround(0.0);
   $227 = $185 == Math_fround(0.0);
   $228 = $186 == Math_fround(0.0);
   HEAPF32[$1>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$90>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$91>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$92>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $184;
   HEAPF32[$93>>2] = $185;
   HEAPF32[$94>>2] = $186;
   HEAPF32[$95>>2] = Math_fround(0.0);
   $b$a$i$i$i = $226 ? $1 : $0;
   $229 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
   $a$pn3$i$i$i = $227 ? $1 : $0;
   $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
   $230 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
   $b$a5$i$i$i = $228 ? $1 : $0;
   $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
   $231 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
   $232 = (HEAPF32[tempDoublePtr>>2]=$229,HEAP32[tempDoublePtr>>2]|0);
   $233 = (HEAPF32[tempDoublePtr>>2]=$230,HEAP32[tempDoublePtr>>2]|0);
   $234 = (HEAPF32[tempDoublePtr>>2]=$231,HEAP32[tempDoublePtr>>2]|0);
   $235 = $232 & -256;
   $236 = $233 & -256;
   $237 = $234 & -256;
   $238 = $223 | $235;
   $239 = $224 | $236;
   $240 = $225 | $237;
   $241 = (HEAP32[tempDoublePtr>>2]=$238,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $242 = (HEAP32[tempDoublePtr>>2]=$239,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $243 = (HEAP32[tempDoublePtr>>2]=$240,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$108>>2] = $241;
   $244 = (($108) + 4|0);
   HEAPF32[$244>>2] = $242;
   $245 = (($108) + 8|0);
   HEAPF32[$245>>2] = $243;
   $246 = $215 >>> 8;
   $247 = $114;
   $248 = $247;
   $249 = HEAP32[$248>>2]|0;
   $250 = (($247) + 4)|0;
   $251 = $250;
   $252 = HEAP32[$251>>2]|0;
   $253 = $252 & 255;
   $254 = (_bitshift64Shl(($246|0),0,40)|0);
   $255 = tempRet0;
   $256 = $254 | $249;
   $257 = $255 | $253;
   $258 = $114;
   $259 = $258;
   HEAP32[$259>>2] = $256;
   $260 = (($258) + 4)|0;
   $261 = $260;
   HEAP32[$261>>2] = $257;
   $262 = HEAP32[$96>>2]|0;
   $263 = $249 & 1;
   $264 = ($263|0)==(0);
   $265 = (0)==(0);
   $266 = $264 & $265;
   do {
    if ($266) {
     $267 = (_bitshift64Lshr(($249|0),($252|0),21)|0);
     $268 = tempRet0;
     $269 = $267 & 524287;
     $270 = ($269|0)==(0);
     $$sum$i$i = (($269) + 1)|0;
     $271 = (($262) + (($$sum$i$i*24)|0)|0);
     $272 = $270 ? $262 : $271;
     do {
      if (!($270)) {
       $273 = (($262) + (($269*24)|0)|0);
       HEAP32[$2>>2] = $273;
       HEAP32[$98>>2] = $108;
       $274 = (($101) + 8|0);
       $275 = HEAP32[$274>>2]|0;
       $276 = $275 & 2147483647;
       $277 = HEAP32[$100>>2]|0;
       $278 = ($276>>>0)>($277>>>0);
       if (!($278)) {
        (__ZN5physx6shdfnd5ArrayINS_2Sq10FIFOStack213NodeAndParentENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($101,$2)|0);
        break;
       }
       $279 = HEAP32[$101>>2]|0;
       $280 = (($279) + ($277<<3)|0);
       $281 = ($280|0)==(0|0);
       if ($281) {
        $293 = $277;
       } else {
        $282 = $2;
        $283 = $282;
        $284 = HEAP32[$283>>2]|0;
        $285 = (($282) + 4)|0;
        $286 = $285;
        $287 = HEAP32[$286>>2]|0;
        $288 = $280;
        $289 = $288;
        HEAP32[$289>>2] = $284;
        $290 = (($288) + 4)|0;
        $291 = $290;
        HEAP32[$291>>2] = $287;
        $$pre$i$i2$i = HEAP32[$100>>2]|0;
        $293 = $$pre$i$i2$i;
       }
       $292 = (($293) + 1)|0;
       HEAP32[$100>>2] = $292;
      }
     } while(0);
     $294 = ($272|0)==($262|0);
     if (!($294)) {
      HEAP32[$3>>2] = $272;
      HEAP32[$97>>2] = $108;
      $295 = (($101) + 8|0);
      $296 = HEAP32[$295>>2]|0;
      $297 = $296 & 2147483647;
      $298 = HEAP32[$100>>2]|0;
      $299 = ($297>>>0)>($298>>>0);
      if (!($299)) {
       (__ZN5physx6shdfnd5ArrayINS_2Sq10FIFOStack213NodeAndParentENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($101,$3)|0);
       break;
      }
      $300 = HEAP32[$101>>2]|0;
      $301 = (($300) + ($298<<3)|0);
      $302 = ($301|0)==(0|0);
      if ($302) {
       $314 = $298;
      } else {
       $303 = $3;
       $304 = $303;
       $305 = HEAP32[$304>>2]|0;
       $306 = (($303) + 4)|0;
       $307 = $306;
       $308 = HEAP32[$307>>2]|0;
       $309 = $301;
       $310 = $309;
       HEAP32[$310>>2] = $305;
       $311 = (($309) + 4)|0;
       $312 = $311;
       HEAP32[$312>>2] = $308;
       $$pre$i$i$i = HEAP32[$100>>2]|0;
       $314 = $$pre$i$i$i;
      }
      $313 = (($314) + 1)|0;
      HEAP32[$100>>2] = $313;
     }
    }
   } while(0);
   $315 = $114;
   $316 = $315;
   $317 = HEAP32[$316>>2]|0;
   $318 = (($315) + 4)|0;
   $319 = $318;
   $320 = HEAP32[$319>>2]|0;
   $321 = (_bitshift64Lshr(($317|0),($320|0),2)|0);
   $322 = tempRet0;
   $323 = $321 & 524287;
   $324 = HEAP32[$99>>2]|0;
   $325 = (($323) + ($324))|0;
   HEAP32[$99>>2] = $325;
   $326 = $111;
   $327 = $262;
   $328 = (($326) - ($327))|0;
   $329 = (($328|0) / 24)&-1;
   $330 = $317 & -2097149;
   $331 = (_bitshift64Shl(($329|0),0,2)|0);
   $332 = tempRet0;
   $333 = $331 | $330;
   $334 = $332 | $320;
   $335 = $114;
   $336 = $335;
   HEAP32[$336>>2] = $333;
   $337 = (($335) + 4)|0;
   $338 = $337;
   HEAP32[$338>>2] = $334;
   $339 = (($323) + ($Total$06))|0;
   $340 = ($339>>>0)<($limit>>>0);
   if (!($340)) {
    $$0 = 1;
    label = 39;
    break;
   }
   $$pre = HEAP32[$78>>2]|0;
   $$phi$trans$insert = (($$pre) + 4|0);
   $$pre11 = HEAP32[$$phi$trans$insert>>2]|0;
   $101 = $$pre;$103 = $$pre11;$Total$06 = $339;
  }
  if ((label|0) == 39) {
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sq8AABBTree6refit2EPNS0_15AABBTreeBuilderEPj($this,$builder,$indices) {
 $this = $this|0;
 $builder = $builder|0;
 $indices = $indices|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i39 = Math_fround(0), $$$i$i42 = Math_fround(0), $$$i102$i = Math_fround(0), $$$i102$i41 = Math_fround(0), $$$i164$i = Math_fround(0), $$$i164$i37 = Math_fround(0), $$$i170$i = Math_fround(0), $$$i170$i35 = Math_fround(0), $$$i20 = Math_fround(0), $$0 = 0, $$1$i = Math_fround(0), $$1$i$i$i = Math_fround(0), $$1$i$i$i40 = Math_fround(0), $$1$i165$i = Math_fround(0), $$1$i165$i38 = Math_fround(0), $$1$i171$i = Math_fround(0), $$1$i171$i36 = Math_fround(0);
 var $$1$i21 = Math_fround(0), $$in = 0, $$in1$i$i = 0, $$in1$i$i46 = 0, $$in2$i$i = 0, $$in2$i$i48 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0);
 var $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0;
 var $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0);
 var $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0);
 var $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn3$i$i = 0, $a$pn3$i$i45 = 0, $b$a$i$i = 0, $b$a$i$i43 = 0, $b$a5$i$i = 0, $b$a5$i$i47 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = ($builder|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($builder) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 536|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 4|0);
 $9 = (($1) + 4|0);
 $10 = (($1) + 8|0);
 $11 = (($1) + 12|0);
 $12 = (($0) + 4|0);
 $13 = (($0) + 8|0);
 $14 = (($0) + 12|0);
 $15 = (($1) + 4|0);
 $16 = (($1) + 8|0);
 $17 = (($1) + 12|0);
 $18 = (($0) + 4|0);
 $19 = (($0) + 8|0);
 $20 = (($0) + 12|0);
 $$in = $6;
 while(1) {
  $21 = (($$in) + -1)|0;
  $22 = HEAP32[$8>>2]|0;
  $23 = (($22) + (($21*24)|0)|0);
  $24 = ($21|0)==(0);
  if (!($24)) {
   $$sum = (($$in) + -2)|0;
   $25 = (($22) + (($$sum*24)|0)|0);
  }
  $26 = ((($22) + (($21*24)|0)|0) + 16|0);
  $27 = $26;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 4)|0;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = $29 & 1;
  $34 = ($33|0)==(0);
  $35 = (0)==(0);
  $36 = $34 & $35;
  if ($36) {
   $153 = HEAP32[$8>>2]|0;
   $154 = (_bitshift64Lshr(($29|0),($32|0),21)|0);
   $155 = tempRet0;
   $156 = $154 & 524287;
   $157 = ($156|0)==(0);
   $$sum$i = (($156) + 1)|0;
   $158 = (($153) + (($$sum$i*24)|0)|0);
   $159 = $157 ? $153 : $158;
   $160 = Math_fround(HEAPF32[$159>>2]);
   $161 = (($159) + 4|0);
   $162 = Math_fround(HEAPF32[$161>>2]);
   $163 = (($159) + 8|0);
   $164 = Math_fround(HEAPF32[$163>>2]);
   $165 = (($159) + 16|0);
   $166 = $165;
   $167 = $166;
   $168 = HEAP32[$167>>2]|0;
   $169 = (($166) + 4)|0;
   $170 = $169;
   $171 = HEAP32[$170>>2]|0;
   $172 = $171 & -256;
   $173 = (HEAP32[tempDoublePtr>>2]=$172,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $174 = Math_fround($173 * Math_fround(9.99999974737875163555E-5));
   $175 = (HEAPF32[tempDoublePtr>>2]=$160,HEAP32[tempDoublePtr>>2]|0);
   $176 = (HEAPF32[tempDoublePtr>>2]=$162,HEAP32[tempDoublePtr>>2]|0);
   $177 = (HEAPF32[tempDoublePtr>>2]=$164,HEAP32[tempDoublePtr>>2]|0);
   $178 = $175 & 255;
   $179 = $176 & 255;
   $180 = $177 & 255;
   $181 = (Math_fround(($178|0)));
   $182 = (Math_fround(($179|0)));
   $183 = (Math_fround(($180|0)));
   $184 = Math_fround($181 * $174);
   $185 = Math_fround($182 * $174);
   $186 = Math_fround($183 * $174);
   $187 = (($153) + (($156*24)|0)|0);
   $188 = Math_fround(HEAPF32[$187>>2]);
   $189 = ((($153) + (($156*24)|0)|0) + 4|0);
   $190 = Math_fround(HEAPF32[$189>>2]);
   $191 = ((($153) + (($156*24)|0)|0) + 8|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = ((($153) + (($156*24)|0)|0) + 16|0);
   $194 = $193;
   $195 = $194;
   $196 = HEAP32[$195>>2]|0;
   $197 = (($194) + 4)|0;
   $198 = $197;
   $199 = HEAP32[$198>>2]|0;
   $200 = $199 & -256;
   $201 = (HEAP32[tempDoublePtr>>2]=$200,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $202 = Math_fround($201 * Math_fround(9.99999974737875163555E-5));
   $203 = (HEAPF32[tempDoublePtr>>2]=$188,HEAP32[tempDoublePtr>>2]|0);
   $204 = (HEAPF32[tempDoublePtr>>2]=$190,HEAP32[tempDoublePtr>>2]|0);
   $205 = (HEAPF32[tempDoublePtr>>2]=$192,HEAP32[tempDoublePtr>>2]|0);
   $206 = $203 & 255;
   $207 = $204 & 255;
   $208 = $205 & 255;
   $209 = (Math_fround(($206|0)));
   $210 = (Math_fround(($207|0)));
   $211 = (Math_fround(($208|0)));
   $212 = Math_fround($209 * $202);
   $213 = Math_fround($210 * $202);
   $214 = Math_fround($211 * $202);
   $215 = Math_fround($188 - $212);
   $216 = Math_fround($190 - $213);
   $217 = Math_fround($192 - $214);
   $218 = Math_fround($160 - $184);
   $219 = Math_fround($162 - $185);
   $220 = Math_fround($164 - $186);
   $221 = $215 < $218;
   $$$i20 = $221 ? $215 : $218;
   $222 = $216 < $219;
   $223 = $222 ? $216 : $219;
   $224 = $217 < $220;
   $$1$i21 = $224 ? $217 : $220;
   $225 = Math_fround($188 + $212);
   $226 = Math_fround($190 + $213);
   $227 = Math_fround($192 + $214);
   $228 = Math_fround($160 + $184);
   $229 = Math_fround($162 + $185);
   $230 = Math_fround($164 + $186);
   $231 = $225 > $228;
   $$$i = $231 ? $225 : $228;
   $232 = $226 > $229;
   $233 = $232 ? $226 : $229;
   $234 = $227 > $230;
   $$1$i = $234 ? $227 : $230;
   $235 = $$$i20 > Math_fround(-9.99999994495727286427E+32);
   $$$i170$i = $235 ? $$$i20 : Math_fround(-9.99999994495727286427E+32);
   $236 = $223 > Math_fround(-9.99999994495727286427E+32);
   $237 = $236 ? $223 : Math_fround(-9.99999994495727286427E+32);
   $238 = $$1$i21 > Math_fround(-9.99999994495727286427E+32);
   $$1$i171$i = $238 ? $$1$i21 : Math_fround(-9.99999994495727286427E+32);
   $239 = $$$i < Math_fround(9.99999994495727286427E+32);
   $$$i164$i = $239 ? $$$i : Math_fround(9.99999994495727286427E+32);
   $240 = $233 < Math_fround(9.99999994495727286427E+32);
   $241 = $240 ? $233 : Math_fround(9.99999994495727286427E+32);
   $242 = $$1$i < Math_fround(9.99999994495727286427E+32);
   $$1$i165$i = $242 ? $$1$i : Math_fround(9.99999994495727286427E+32);
   $243 = Math_fround($$$i170$i + $$$i164$i);
   $244 = Math_fround($237 + $241);
   $245 = Math_fround($$1$i171$i + $$1$i165$i);
   $246 = Math_fround($243 * Math_fround(0.5));
   $247 = Math_fround($244 * Math_fround(0.5));
   $248 = Math_fround($245 * Math_fround(0.5));
   $249 = Math_fround($$$i164$i - $$$i170$i);
   $250 = Math_fround($241 - $237);
   $251 = Math_fround($$1$i165$i - $$1$i171$i);
   $252 = Math_fround($249 * Math_fround(0.5));
   $253 = Math_fround($250 * Math_fround(0.5));
   $254 = Math_fround($251 * Math_fround(0.5));
   $255 = Math_fround($246 * Math_fround(9.99999974737875163555E-5));
   $256 = Math_fround($247 * Math_fround(9.99999974737875163555E-5));
   $257 = Math_fround($248 * Math_fround(9.99999974737875163555E-5));
   $258 = Math_fround(-$255);
   $259 = Math_fround(-$256);
   $260 = Math_fround(-$257);
   $261 = $255 > $258;
   $$$i$i$i = $261 ? $255 : $258;
   $262 = $256 > $259;
   $263 = $262 ? $256 : $259;
   $264 = $257 > $260;
   $$1$i$i$i = $264 ? $257 : $260;
   $265 = Math_fround($$$i$i$i + Math_fround(9.99999974737875163555E-5));
   $266 = Math_fround($263 + Math_fround(9.99999974737875163555E-5));
   $267 = Math_fround($$1$i$i$i + Math_fround(9.99999974737875163555E-5));
   $268 = Math_fround($252 + $265);
   $269 = Math_fround($253 + $266);
   $270 = Math_fround($254 + $267);
   $271 = $269 > $270;
   $$$i102$i = $271 ? $269 : $270;
   $272 = $268 > $$$i102$i;
   $$$i$i = $272 ? $268 : $$$i102$i;
   $273 = Math_fround($$$i$i * Math_fround(0.00392158422619104385376));
   $274 = Math_fround($273 * Math_fround(9.99999974737875163555E-5));
   $275 = Math_fround($273 + $274);
   $276 = Math_fround($275 * Math_fround(1.0E+4));
   $277 = (HEAPF32[tempDoublePtr>>2]=$276,HEAP32[tempDoublePtr>>2]|0);
   $278 = Math_fround(Math_fround(1.0) / $273);
   $279 = Math_fround($278 * $268);
   $280 = Math_fround($278 * $269);
   $281 = Math_fround($278 * $270);
   $282 = Math_fround($279 + Math_fround(1.0));
   $283 = Math_fround($280 + Math_fround(1.0));
   $284 = Math_fround($281 + Math_fround(1.0));
   $285 = (~~(($282)));
   $286 = (~~(($283)));
   $287 = (~~(($284)));
   $288 = $246 == Math_fround(0.0);
   $289 = $247 == Math_fround(0.0);
   $290 = $248 == Math_fround(0.0);
   HEAPF32[$1>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$9>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$10>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$11>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $246;
   HEAPF32[$12>>2] = $247;
   HEAPF32[$13>>2] = $248;
   HEAPF32[$14>>2] = Math_fround(0.0);
   $b$a$i$i = $288 ? $1 : $0;
   $291 = Math_fround(HEAPF32[$b$a$i$i>>2]);
   $a$pn3$i$i = $289 ? $1 : $0;
   $$in1$i$i = (($a$pn3$i$i) + 4|0);
   $292 = Math_fround(HEAPF32[$$in1$i$i>>2]);
   $b$a5$i$i = $290 ? $1 : $0;
   $$in2$i$i = (($b$a5$i$i) + 8|0);
   $293 = Math_fround(HEAPF32[$$in2$i$i>>2]);
   $294 = (HEAPF32[tempDoublePtr>>2]=$291,HEAP32[tempDoublePtr>>2]|0);
   $295 = (HEAPF32[tempDoublePtr>>2]=$292,HEAP32[tempDoublePtr>>2]|0);
   $296 = (HEAPF32[tempDoublePtr>>2]=$293,HEAP32[tempDoublePtr>>2]|0);
   $297 = $294 & -256;
   $298 = $295 & -256;
   $299 = $296 & -256;
   $300 = $285 | $297;
   $301 = $286 | $298;
   $302 = $287 | $299;
   $303 = (HEAP32[tempDoublePtr>>2]=$300,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $304 = (HEAP32[tempDoublePtr>>2]=$301,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $305 = (HEAP32[tempDoublePtr>>2]=$302,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$23>>2] = $303;
   $306 = ((($22) + (($21*24)|0)|0) + 4|0);
   HEAPF32[$306>>2] = $304;
   $307 = ((($22) + (($21*24)|0)|0) + 8|0);
   HEAPF32[$307>>2] = $305;
   $308 = $277 >>> 8;
   $309 = $26;
   $310 = $309;
   $311 = HEAP32[$310>>2]|0;
   $312 = (($309) + 4)|0;
   $313 = $312;
   $314 = HEAP32[$313>>2]|0;
   $315 = $314 & 255;
   $316 = (_bitshift64Shl(($308|0),0,40)|0);
   $317 = tempRet0;
   $318 = $316 | $311;
   $319 = $317 | $315;
   $320 = $26;
   $321 = $320;
   HEAP32[$321>>2] = $318;
   $322 = (($320) + 4)|0;
   $323 = $322;
   HEAP32[$323>>2] = $319;
  } else {
   $37 = $29 & 2;
   $38 = ($37|0)==(0);
   $39 = (0)==(0);
   $40 = $38 & $39;
   if ($40) {
    $59 = Math_fround(2.49999998623931821607E+32);$61 = Math_fround(2.49999998623931821607E+32);$64 = Math_fround(2.49999998623931821607E+32);$66 = Math_fround(-2.49999998623931821607E+32);$68 = Math_fround(-2.49999998623931821607E+32);$71 = Math_fround(-2.49999998623931821607E+32);
   } else {
    $41 = (_bitshift64Lshr(($29|0),($32|0),21)|0);
    $42 = tempRet0;
    $43 = $41 & 524287;
    $44 = (($indices) + ($43<<2)|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($4) + (($45*24)|0)|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = ((($4) + (($45*24)|0)|0) + 4|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = ((($4) + (($45*24)|0)|0) + 8|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = ((($4) + (($45*24)|0)|0) + 12|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = ((($4) + (($45*24)|0)|0) + 16|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = ((($4) + (($45*24)|0)|0) + 20|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $59 = $47;$61 = $49;$64 = $51;$66 = $53;$68 = $55;$71 = $57;
   }
   $58 = $59 > Math_fround(-9.99999994495727286427E+32);
   $$$i170$i35 = $58 ? $59 : Math_fround(-9.99999994495727286427E+32);
   $60 = $61 > Math_fround(-9.99999994495727286427E+32);
   $62 = $60 ? $61 : Math_fround(-9.99999994495727286427E+32);
   $63 = $64 > Math_fround(-9.99999994495727286427E+32);
   $$1$i171$i36 = $63 ? $64 : Math_fround(-9.99999994495727286427E+32);
   $65 = $66 < Math_fround(9.99999994495727286427E+32);
   $$$i164$i37 = $65 ? $66 : Math_fround(9.99999994495727286427E+32);
   $67 = $68 < Math_fround(9.99999994495727286427E+32);
   $69 = $67 ? $68 : Math_fround(9.99999994495727286427E+32);
   $70 = $71 < Math_fround(9.99999994495727286427E+32);
   $$1$i165$i38 = $70 ? $71 : Math_fround(9.99999994495727286427E+32);
   $72 = Math_fround($$$i170$i35 + $$$i164$i37);
   $73 = Math_fround($62 + $69);
   $74 = Math_fround($$1$i171$i36 + $$1$i165$i38);
   $75 = Math_fround($72 * Math_fround(0.5));
   $76 = Math_fround($73 * Math_fround(0.5));
   $77 = Math_fround($74 * Math_fround(0.5));
   $78 = Math_fround($$$i164$i37 - $$$i170$i35);
   $79 = Math_fround($69 - $62);
   $80 = Math_fround($$1$i165$i38 - $$1$i171$i36);
   $81 = Math_fround($78 * Math_fround(0.5));
   $82 = Math_fround($79 * Math_fround(0.5));
   $83 = Math_fround($80 * Math_fround(0.5));
   $84 = Math_fround($75 * Math_fround(9.99999974737875163555E-5));
   $85 = Math_fround($76 * Math_fround(9.99999974737875163555E-5));
   $86 = Math_fround($77 * Math_fround(9.99999974737875163555E-5));
   $87 = Math_fround(-$84);
   $88 = Math_fround(-$85);
   $89 = Math_fround(-$86);
   $90 = $84 > $87;
   $$$i$i$i39 = $90 ? $84 : $87;
   $91 = $85 > $88;
   $92 = $91 ? $85 : $88;
   $93 = $86 > $89;
   $$1$i$i$i40 = $93 ? $86 : $89;
   $94 = Math_fround($$$i$i$i39 + Math_fround(9.99999974737875163555E-5));
   $95 = Math_fround($92 + Math_fround(9.99999974737875163555E-5));
   $96 = Math_fround($$1$i$i$i40 + Math_fround(9.99999974737875163555E-5));
   $97 = Math_fround($81 + $94);
   $98 = Math_fround($82 + $95);
   $99 = Math_fround($83 + $96);
   $100 = $98 > $99;
   $$$i102$i41 = $100 ? $98 : $99;
   $101 = $97 > $$$i102$i41;
   $$$i$i42 = $101 ? $97 : $$$i102$i41;
   $102 = Math_fround($$$i$i42 * Math_fround(0.00392158422619104385376));
   $103 = Math_fround($102 * Math_fround(9.99999974737875163555E-5));
   $104 = Math_fround($102 + $103);
   $105 = Math_fround($104 * Math_fround(1.0E+4));
   $106 = (HEAPF32[tempDoublePtr>>2]=$105,HEAP32[tempDoublePtr>>2]|0);
   $107 = Math_fround(Math_fround(1.0) / $102);
   $108 = Math_fround($107 * $97);
   $109 = Math_fround($107 * $98);
   $110 = Math_fround($107 * $99);
   $111 = Math_fround($108 + Math_fround(1.0));
   $112 = Math_fround($109 + Math_fround(1.0));
   $113 = Math_fround($110 + Math_fround(1.0));
   $114 = (~~(($111)));
   $115 = (~~(($112)));
   $116 = (~~(($113)));
   $117 = $75 == Math_fround(0.0);
   $118 = $76 == Math_fround(0.0);
   $119 = $77 == Math_fround(0.0);
   HEAPF32[$1>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$15>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$16>>2] = Math_fround(2.35098870164457501594E-38);
   HEAPF32[$17>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $75;
   HEAPF32[$18>>2] = $76;
   HEAPF32[$19>>2] = $77;
   HEAPF32[$20>>2] = Math_fround(0.0);
   $b$a$i$i43 = $117 ? $1 : $0;
   $120 = Math_fround(HEAPF32[$b$a$i$i43>>2]);
   $a$pn3$i$i45 = $118 ? $1 : $0;
   $$in1$i$i46 = (($a$pn3$i$i45) + 4|0);
   $121 = Math_fround(HEAPF32[$$in1$i$i46>>2]);
   $b$a5$i$i47 = $119 ? $1 : $0;
   $$in2$i$i48 = (($b$a5$i$i47) + 8|0);
   $122 = Math_fround(HEAPF32[$$in2$i$i48>>2]);
   $123 = (HEAPF32[tempDoublePtr>>2]=$120,HEAP32[tempDoublePtr>>2]|0);
   $124 = (HEAPF32[tempDoublePtr>>2]=$121,HEAP32[tempDoublePtr>>2]|0);
   $125 = (HEAPF32[tempDoublePtr>>2]=$122,HEAP32[tempDoublePtr>>2]|0);
   $126 = $123 & -256;
   $127 = $124 & -256;
   $128 = $125 & -256;
   $129 = $114 | $126;
   $130 = $115 | $127;
   $131 = $116 | $128;
   $132 = (HEAP32[tempDoublePtr>>2]=$129,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $133 = (HEAP32[tempDoublePtr>>2]=$130,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $134 = (HEAP32[tempDoublePtr>>2]=$131,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$23>>2] = $132;
   $135 = ((($22) + (($21*24)|0)|0) + 4|0);
   HEAPF32[$135>>2] = $133;
   $136 = ((($22) + (($21*24)|0)|0) + 8|0);
   HEAPF32[$136>>2] = $134;
   $137 = $106 >>> 8;
   $138 = $26;
   $139 = $138;
   $140 = HEAP32[$139>>2]|0;
   $141 = (($138) + 4)|0;
   $142 = $141;
   $143 = HEAP32[$142>>2]|0;
   $144 = $143 & 255;
   $145 = (_bitshift64Shl(($137|0),0,40)|0);
   $146 = tempRet0;
   $147 = $145 | $140;
   $148 = $146 | $144;
   $149 = $26;
   $150 = $149;
   HEAP32[$150>>2] = $147;
   $151 = (($149) + 4)|0;
   $152 = $151;
   HEAP32[$152>>2] = $148;
  }
  if ($24) {
   $$0 = 1;
   break;
  } else {
   $$in = $21;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sq8AABBTree12markForRefitEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $Current$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (($this) + 536|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 >>> 5;
  $8 = $6 & 31;
  $9 = ($8|0)!=(0);
  $10 = $9&1;
  $11 = (($10) + ($7))|0;
  $12 = (($this) + 12|0);
  HEAP32[$12>>2] = $11;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 << 2;
  $15 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$14,506624,62)|0);
  HEAP32[$2>>2] = $15;
  $16 = HEAP32[$12>>2]|0;
  $17 = $16 << 2;
  _memset(($15|0),0,($17|0))|0;
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + (($index*24)|0)|0);
 $21 = (($this) + 16|0);
 $22 = (($this) + 20|0);
 $Current$0 = $20;
 while(1) {
  $23 = HEAP32[$18>>2]|0;
  $24 = $Current$0;
  $25 = $23;
  $26 = (($24) - ($25))|0;
  $27 = (($26|0) / 24)&-1;
  $28 = $27 >>> 5;
  $29 = HEAP32[$2>>2]|0;
  $30 = (($29) + ($28<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $27 & 31;
  $33 = 1 << $32;
  $34 = $31 & $33;
  $35 = ($34|0)==(0);
  if (!($35)) {
   label = 8;
   break;
  }
  $36 = $31 | $33;
  HEAP32[$30>>2] = $36;
  $37 = HEAP32[$21>>2]|0;
  $38 = ($37>>>0)<($28>>>0);
  $39 = $38 ? $28 : $37;
  HEAP32[$21>>2] = $39;
  $40 = HEAP32[$22>>2]|0;
  $41 = ($40>>>0)<(128);
  if ($41) {
   $42 = ((($this) + ($40<<2)|0) + 24|0);
   HEAP32[$42>>2] = $27;
   $$pre = HEAP32[$22>>2]|0;
   $$pre4 = HEAP32[$18>>2]|0;
   $44 = $$pre;$56 = $$pre4;
  } else {
   $44 = $40;$56 = $23;
  }
  $43 = (($44) + 1)|0;
  HEAP32[$22>>2] = $43;
  $45 = (($Current$0) + 16|0);
  $46 = $45;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) + 4)|0;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (_bitshift64Lshr(($48|0),($51|0),2)|0);
  $53 = tempRet0;
  $54 = $52 & 524287;
  $55 = (($56) + (($54*24)|0)|0);
  $57 = ($Current$0|0)==($55|0);
  if ($57) {
   label = 8;
   break;
  } else {
   $Current$0 = $55;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sq8AABBTree11refitMarkedEjPKNS_9PxBounds3EPj($this,$nb_objects,$boxes,$indices) {
 $this = $this|0;
 $nb_objects = $nb_objects|0;
 $boxes = $boxes|0;
 $indices = $indices|0;
 var $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i100$i = Math_fround(0), $$$i162$i = Math_fround(0), $$$i168$i = Math_fround(0), $$1$i$i$i = Math_fround(0), $$1$i163$i = Math_fround(0), $$1$i169$i = Math_fround(0), $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0);
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0);
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $Index1$044 = 0, $Size$046 = 0, $Size$046$phi = 0;
 var $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, $bMax = 0, $bMin = 0, $exitcond = 0, $i$043 = 0, $linksBuffer = 0, $prevScale = 0, $prevXYZ = 0, $todoCompress = 0, $todoWriteback = 0, $wMax = 0, $wMin = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5264|0;
 $0 = sp + 4192|0;
 $1 = sp + 96|0;
 $prevScale = sp + 80|0;
 $prevXYZ = sp + 64|0;
 $todoWriteback = sp + 5256|0;
 $todoCompress = sp + 5260|0;
 $bMin = sp + 16|0;
 $bMax = sp;
 $wMin = sp + 32|0;
 $wMax = sp + 48|0;
 $linksBuffer = sp + 4232|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 HEAP32[$todoWriteback>>2] = 0;
 HEAP32[$todoCompress>>2] = 0;
 $5 = (($bMin) + 4|0);
 $6 = (($bMin) + 8|0);
 ;HEAP32[$bMin+0>>2]=0|0;HEAP32[$bMin+4>>2]=0|0;HEAP32[$bMin+8>>2]=0|0;HEAP32[$bMin+12>>2]=0|0;
 $7 = (($bMax) + 4|0);
 $8 = (($bMax) + 8|0);
 ;HEAP32[$bMax+0>>2]=0|0;HEAP32[$bMax+4>>2]=0|0;HEAP32[$bMax+8>>2]=0|0;HEAP32[$bMax+12>>2]=0|0;
 ;HEAP32[$wMin+0>>2]=0|0;HEAP32[$wMin+4>>2]=0|0;HEAP32[$wMin+8>>2]=0|0;HEAP32[$wMin+12>>2]=0|0;
 $9 = (($this) + 20|0);
 ;HEAP32[$wMax+0>>2]=0|0;HEAP32[$wMax+4>>2]=0|0;HEAP32[$wMax+8>>2]=0|0;HEAP32[$wMax+12>>2]=0|0;
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$9>>2] = 0;
 $11 = ($10>>>0)<(129);
 if ($11) {
  $12 = $10 << 2;
  $13 = STACKTOP; STACKTOP = STACKTOP + ((((1*$12)|0)+15)&-16)|0;;
  $14 = STACKTOP; STACKTOP = STACKTOP + ((((1*$12)|0)+15)&-16)|0;;
  __ZN5physx2Gu9RadixSortC2Ev($0);
  (__ZN5physx2Gu9RadixSort10SetBuffersEPjS2_S2_PS2_($0,$13,$14,$1,$linksBuffer)|0);
  $15 = (($this) + 24|0);
  $16 = (__ZN5physx2Gu9RadixSort4SortEPKjjNS0_9RadixHintE($0,$15,$10,0)|0);
  $17 = (($16) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($10|0)==(0);
  if (!($19)) {
   $20 = (($10) + -1)|0;
   $21 = (($this) + 4|0);
   $i$043 = 0;
   while(1) {
    $22 = (($20) - ($i$043))|0;
    $23 = (($18) + ($22<<2)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($this) + ($24<<2)|0) + 24|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$21>>2]|0;
    $28 = (($27) + (($26*24)|0)|0);
    $29 = $26 & 31;
    $30 = 1 << $29;
    $31 = $30 ^ -1;
    $32 = $26 >>> 5;
    $33 = HEAP32[$2>>2]|0;
    $34 = (($33) + ($32<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $35 & $31;
    HEAP32[$34>>2] = $36;
    $37 = HEAP32[$21>>2]|0;
    __ZL9refitNodePN5physx2Sq12AABBTreeNodeEjPKNS_9PxBounds3EPjRS2_S7_RNS_6shdfnd3aos7VecU32VERNS9_5Vec3VESD_SD_SD_SD_($37,$26,$boxes,$indices,$todoWriteback,$todoCompress,$prevScale,$prevXYZ,$bMin,$bMax,$wMin,$wMax);
    $38 = (($i$043) + 1)|0;
    $exitcond = ($38|0)==($10|0);
    if ($exitcond) {
     break;
    } else {
     $i$043 = $38;
    }
   }
  }
 } else {
  $39 = (($this) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 1)|0;
  $42 = ($41|0)==(0);
  if (!($42)) {
   $43 = (($this) + 4|0);
   $45 = $40;$Size$046 = $41;
   while(1) {
    $44 = (($3) + ($45<<2)|0);
    $46 = HEAP32[$44>>2]|0;
    $47 = ($46|0)==(0);
    if (!($47)) {
     $50 = $Size$046 << 5;
     $66 = 31;$Index1$044 = $50;
     while(1) {
      $51 = (($Index1$044) + -1)|0;
      $52 = HEAP32[$43>>2]|0;
      $53 = (($52) + (($51*24)|0)|0);
      $54 = $51 >>> 5;
      $55 = HEAP32[$2>>2]|0;
      $56 = (($55) + ($54<<2)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = $51 & 31;
      $59 = 1 << $58;
      $60 = $57 & $59;
      $61 = ($60|0)==(0);
      if (!($61)) {
       $62 = $59 ^ -1;
       $63 = $57 & $62;
       HEAP32[$56>>2] = $63;
       $64 = HEAP32[$43>>2]|0;
       __ZL9refitNodePN5physx2Sq12AABBTreeNodeEjPKNS_9PxBounds3EPjRS2_S7_RNS_6shdfnd3aos7VecU32VERNS9_5Vec3VESD_SD_SD_SD_($64,$51,$boxes,$indices,$todoWriteback,$todoCompress,$prevScale,$prevXYZ,$bMin,$bMax,$wMin,$wMax);
      }
      $65 = (($66) + -1)|0;
      $67 = ($66|0)==(0);
      if ($67) {
       break;
      } else {
       $66 = $65;$Index1$044 = $51;
      }
     }
    }
    $48 = (($45) + -1)|0;
    $49 = ($45|0)==(0);
    if ($49) {
     break;
    } else {
     $Size$046$phi = $45;$45 = $48;$Size$046 = $Size$046$phi;
    }
   }
  }
  HEAP32[$39>>2] = 0;
 }
 $68 = HEAP32[$todoWriteback>>2]|0;
 $69 = ($68|0)==(0|0);
 if (!($69)) {
  $70 = Math_fround(HEAPF32[$prevXYZ>>2]);
  $71 = (($prevXYZ) + 4|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($prevXYZ) + 8|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  HEAPF32[$68>>2] = $70;
  $75 = (($68) + 4|0);
  HEAPF32[$75>>2] = $72;
  $76 = (($68) + 8|0);
  HEAPF32[$76>>2] = $74;
  $77 = (($prevScale) + 4|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = $78 >>> 8;
  $80 = (($68) + 16|0);
  $81 = $80;
  $82 = $81;
  $83 = HEAP32[$82>>2]|0;
  $84 = (($81) + 4)|0;
  $85 = $84;
  $86 = HEAP32[$85>>2]|0;
  $87 = $86 & 255;
  $88 = (_bitshift64Shl(($79|0),0,40)|0);
  $89 = tempRet0;
  $90 = $88 | $83;
  $91 = $89 | $87;
  $92 = $80;
  $93 = $92;
  HEAP32[$93>>2] = $90;
  $94 = (($92) + 4)|0;
  $95 = $94;
  HEAP32[$95>>2] = $91;
 }
 $96 = HEAP32[$todoCompress>>2]|0;
 $97 = ($96|0)==(0|0);
 if ($97) {
  STACKTOP = sp;return;
 }
 $98 = Math_fround(HEAPF32[$bMin>>2]);
 $99 = Math_fround(HEAPF32[$5>>2]);
 $100 = Math_fround(HEAPF32[$6>>2]);
 $101 = Math_fround(HEAPF32[$bMax>>2]);
 $102 = Math_fround(HEAPF32[$7>>2]);
 $103 = Math_fround(HEAPF32[$8>>2]);
 $104 = $98 > Math_fround(-9.99999994495727286427E+32);
 $$$i168$i = $104 ? $98 : Math_fround(-9.99999994495727286427E+32);
 $105 = $99 > Math_fround(-9.99999994495727286427E+32);
 $106 = $105 ? $99 : Math_fround(-9.99999994495727286427E+32);
 $107 = $100 > Math_fround(-9.99999994495727286427E+32);
 $$1$i169$i = $107 ? $100 : Math_fround(-9.99999994495727286427E+32);
 $108 = $101 < Math_fround(9.99999994495727286427E+32);
 $$$i162$i = $108 ? $101 : Math_fround(9.99999994495727286427E+32);
 $109 = $102 < Math_fround(9.99999994495727286427E+32);
 $110 = $109 ? $102 : Math_fround(9.99999994495727286427E+32);
 $111 = $103 < Math_fround(9.99999994495727286427E+32);
 $$1$i163$i = $111 ? $103 : Math_fround(9.99999994495727286427E+32);
 $112 = Math_fround($$$i168$i + $$$i162$i);
 $113 = Math_fround($106 + $110);
 $114 = Math_fround($$1$i169$i + $$1$i163$i);
 $115 = Math_fround($112 * Math_fround(0.5));
 $116 = Math_fround($113 * Math_fround(0.5));
 $117 = Math_fround($114 * Math_fround(0.5));
 $118 = Math_fround($$$i162$i - $$$i168$i);
 $119 = Math_fround($110 - $106);
 $120 = Math_fround($$1$i163$i - $$1$i169$i);
 $121 = Math_fround($118 * Math_fround(0.5));
 $122 = Math_fround($119 * Math_fround(0.5));
 $123 = Math_fround($120 * Math_fround(0.5));
 $124 = Math_fround($115 * Math_fround(9.99999974737875163555E-5));
 $125 = Math_fround($116 * Math_fround(9.99999974737875163555E-5));
 $126 = Math_fround($117 * Math_fround(9.99999974737875163555E-5));
 $127 = Math_fround(-$124);
 $128 = Math_fround(-$125);
 $129 = Math_fround(-$126);
 $130 = $124 > $127;
 $$$i$i$i = $130 ? $124 : $127;
 $131 = $125 > $128;
 $132 = $131 ? $125 : $128;
 $133 = $126 > $129;
 $$1$i$i$i = $133 ? $126 : $129;
 $134 = Math_fround($$$i$i$i + Math_fround(9.99999974737875163555E-5));
 $135 = Math_fround($132 + Math_fround(9.99999974737875163555E-5));
 $136 = Math_fround($$1$i$i$i + Math_fround(9.99999974737875163555E-5));
 $137 = Math_fround($121 + $134);
 $138 = Math_fround($122 + $135);
 $139 = Math_fround($123 + $136);
 $140 = $138 > $139;
 $$$i100$i = $140 ? $138 : $139;
 $141 = $137 > $$$i100$i;
 $$$i$i = $141 ? $137 : $$$i100$i;
 $142 = Math_fround($$$i$i * Math_fround(0.00392158422619104385376));
 $143 = Math_fround($142 * Math_fround(9.99999974737875163555E-5));
 $144 = Math_fround($142 + $143);
 $145 = Math_fround($144 * Math_fround(1.0E+4));
 HEAPF32[$prevScale>>2] = $145;
 $146 = (($prevScale) + 4|0);
 HEAPF32[$146>>2] = $145;
 $147 = (($prevScale) + 8|0);
 HEAPF32[$147>>2] = $145;
 $148 = (($prevScale) + 12|0);
 HEAPF32[$148>>2] = Math_fround(0.0);
 $149 = Math_fround(Math_fround(1.0) / $142);
 $150 = Math_fround($149 * $137);
 $151 = Math_fround($149 * $138);
 $152 = Math_fround($149 * $139);
 $153 = Math_fround($150 + Math_fround(1.0));
 $154 = Math_fround($151 + Math_fround(1.0));
 $155 = Math_fround($152 + Math_fround(1.0));
 $156 = (~~(($153)));
 $157 = (~~(($154)));
 $158 = (~~(($155)));
 $159 = $115 == Math_fround(0.0);
 $160 = $116 == Math_fround(0.0);
 $161 = $117 == Math_fround(0.0);
 HEAPF32[$1>>2] = Math_fround(2.35098870164457501594E-38);
 $162 = (($1) + 4|0);
 HEAPF32[$162>>2] = Math_fround(2.35098870164457501594E-38);
 $163 = (($1) + 8|0);
 HEAPF32[$163>>2] = Math_fround(2.35098870164457501594E-38);
 $164 = (($1) + 12|0);
 HEAPF32[$164>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = $115;
 $165 = (($0) + 4|0);
 HEAPF32[$165>>2] = $116;
 $166 = (($0) + 8|0);
 HEAPF32[$166>>2] = $117;
 $167 = (($0) + 12|0);
 HEAPF32[$167>>2] = Math_fround(0.0);
 $b$a$i$i = $159 ? $1 : $0;
 $168 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $160 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $169 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $161 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $170 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $171 = (HEAPF32[tempDoublePtr>>2]=$168,HEAP32[tempDoublePtr>>2]|0);
 $172 = (HEAPF32[tempDoublePtr>>2]=$169,HEAP32[tempDoublePtr>>2]|0);
 $173 = (HEAPF32[tempDoublePtr>>2]=$170,HEAP32[tempDoublePtr>>2]|0);
 $174 = $171 & -256;
 $175 = $172 & -256;
 $176 = $173 & -256;
 $177 = $156 | $174;
 $178 = $157 | $175;
 $179 = $158 | $176;
 $180 = (HEAP32[tempDoublePtr>>2]=$177,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $181 = (HEAP32[tempDoublePtr>>2]=$178,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $182 = (HEAP32[tempDoublePtr>>2]=$179,Math_fround(HEAPF32[tempDoublePtr>>2]));
 HEAPF32[$prevXYZ>>2] = $180;
 $183 = (($prevXYZ) + 4|0);
 HEAPF32[$183>>2] = $181;
 $184 = (($prevXYZ) + 8|0);
 HEAPF32[$184>>2] = $182;
 $185 = (($prevXYZ) + 12|0);
 HEAPF32[$185>>2] = Math_fround(0.0);
 $186 = HEAP32[$todoCompress>>2]|0;
 HEAPF32[$186>>2] = $180;
 $187 = (($186) + 4|0);
 HEAPF32[$187>>2] = $181;
 $188 = (($186) + 8|0);
 HEAPF32[$188>>2] = $182;
 $189 = (HEAPF32[tempDoublePtr>>2]=$145,HEAP32[tempDoublePtr>>2]|0);
 $190 = $189 >>> 8;
 $191 = (($186) + 16|0);
 $192 = $191;
 $193 = $192;
 $194 = HEAP32[$193>>2]|0;
 $195 = (($192) + 4)|0;
 $196 = $195;
 $197 = HEAP32[$196>>2]|0;
 $198 = $197 & 255;
 $199 = (_bitshift64Shl(($190|0),0,40)|0);
 $200 = tempRet0;
 $201 = $199 | $194;
 $202 = $200 | $198;
 $203 = $191;
 $204 = $203;
 HEAP32[$204>>2] = $201;
 $205 = (($203) + 4)|0;
 $206 = $205;
 HEAP32[$206>>2] = $202;
 STACKTOP = sp;return;
}
function __ZL9refitNodePN5physx2Sq12AABBTreeNodeEjPKNS_9PxBounds3EPjRS2_S7_RNS_6shdfnd3aos7VecU32VERNS9_5Vec3VESD_SD_SD_SD_($pool,$index,$boxes,$indices,$todoWriteback,$todoCompress,$prevScale,$prevXYZ,$bMin,$bMax,$wMin,$wMax) {
 $pool = $pool|0;
 $index = $index|0;
 $boxes = $boxes|0;
 $indices = $indices|0;
 $todoWriteback = $todoWriteback|0;
 $todoCompress = $todoCompress|0;
 $prevScale = $prevScale|0;
 $prevXYZ = $prevXYZ|0;
 $bMin = $bMin|0;
 $bMax = $bMax|0;
 $wMin = $wMin|0;
 $wMax = $wMax|0;
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i34 = Math_fround(0), $$$i100$i = Math_fround(0), $$$i162$i = Math_fround(0), $$$i168$i = Math_fround(0), $$$i8 = Math_fround(0), $$1$i = Math_fround(0), $$1$i$i$i = Math_fround(0), $$1$i163$i = Math_fround(0), $$1$i169$i = Math_fround(0), $$1$i9 = Math_fround(0), $$in1$i$i = 0, $$in2$i$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0;
 var $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0;
 var $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0;
 var $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0;
 var $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0;
 var $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0);
 var $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0);
 var $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = HEAP32[$todoWriteback>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = Math_fround(HEAPF32[$prevXYZ>>2]);
  $5 = (($prevXYZ) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($prevXYZ) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$2>>2] = $4;
  $9 = (($2) + 4|0);
  HEAPF32[$9>>2] = $6;
  $10 = (($2) + 8|0);
  HEAPF32[$10>>2] = $8;
  $11 = (($prevScale) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 >>> 8;
  $14 = (($2) + 16|0);
  $15 = $14;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + 4)|0;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = $20 & 255;
  $22 = (_bitshift64Shl(($13|0),0,40)|0);
  $23 = tempRet0;
  $24 = $22 | $17;
  $25 = $23 | $21;
  $26 = $14;
  $27 = $26;
  HEAP32[$27>>2] = $24;
  $28 = (($26) + 4)|0;
  $29 = $28;
  HEAP32[$29>>2] = $25;
  HEAP32[$todoWriteback>>2] = 0;
 }
 $30 = HEAP32[$todoCompress>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = Math_fround(HEAPF32[$bMin>>2]);
  $33 = (($bMin) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($bMin) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround(HEAPF32[$bMax>>2]);
  $38 = (($bMax) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($bMax) + 8|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = $32 > Math_fround(-9.99999994495727286427E+32);
  $$$i168$i = $42 ? $32 : Math_fround(-9.99999994495727286427E+32);
  $43 = $34 > Math_fround(-9.99999994495727286427E+32);
  $44 = $43 ? $34 : Math_fround(-9.99999994495727286427E+32);
  $45 = $36 > Math_fround(-9.99999994495727286427E+32);
  $$1$i169$i = $45 ? $36 : Math_fround(-9.99999994495727286427E+32);
  $46 = $37 < Math_fround(9.99999994495727286427E+32);
  $$$i162$i = $46 ? $37 : Math_fround(9.99999994495727286427E+32);
  $47 = $39 < Math_fround(9.99999994495727286427E+32);
  $48 = $47 ? $39 : Math_fround(9.99999994495727286427E+32);
  $49 = $41 < Math_fround(9.99999994495727286427E+32);
  $$1$i163$i = $49 ? $41 : Math_fround(9.99999994495727286427E+32);
  $50 = Math_fround($$$i168$i + $$$i162$i);
  $51 = Math_fround($44 + $48);
  $52 = Math_fround($$1$i169$i + $$1$i163$i);
  $53 = Math_fround($50 * Math_fround(0.5));
  $54 = Math_fround($51 * Math_fround(0.5));
  $55 = Math_fround($52 * Math_fround(0.5));
  $56 = Math_fround($$$i162$i - $$$i168$i);
  $57 = Math_fround($48 - $44);
  $58 = Math_fround($$1$i163$i - $$1$i169$i);
  $59 = Math_fround($56 * Math_fround(0.5));
  $60 = Math_fround($57 * Math_fround(0.5));
  $61 = Math_fround($58 * Math_fround(0.5));
  $62 = Math_fround($53 * Math_fround(9.99999974737875163555E-5));
  $63 = Math_fround($54 * Math_fround(9.99999974737875163555E-5));
  $64 = Math_fround($55 * Math_fround(9.99999974737875163555E-5));
  $65 = Math_fround(-$62);
  $66 = Math_fround(-$63);
  $67 = Math_fround(-$64);
  $68 = $62 > $65;
  $$$i$i$i = $68 ? $62 : $65;
  $69 = $63 > $66;
  $70 = $69 ? $63 : $66;
  $71 = $64 > $67;
  $$1$i$i$i = $71 ? $64 : $67;
  $72 = Math_fround($$$i$i$i + Math_fround(9.99999974737875163555E-5));
  $73 = Math_fround($70 + Math_fround(9.99999974737875163555E-5));
  $74 = Math_fround($$1$i$i$i + Math_fround(9.99999974737875163555E-5));
  $75 = Math_fround($59 + $72);
  $76 = Math_fround($60 + $73);
  $77 = Math_fround($61 + $74);
  $78 = $76 > $77;
  $$$i100$i = $78 ? $76 : $77;
  $79 = $75 > $$$i100$i;
  $$$i$i34 = $79 ? $75 : $$$i100$i;
  $80 = Math_fround($$$i$i34 * Math_fround(0.00392158422619104385376));
  $81 = Math_fround($80 * Math_fround(9.99999974737875163555E-5));
  $82 = Math_fround($80 + $81);
  $83 = Math_fround($82 * Math_fround(1.0E+4));
  HEAPF32[$prevScale>>2] = $83;
  $84 = (($prevScale) + 4|0);
  HEAPF32[$84>>2] = $83;
  $85 = (($prevScale) + 8|0);
  HEAPF32[$85>>2] = $83;
  $86 = (($prevScale) + 12|0);
  HEAPF32[$86>>2] = Math_fround(0.0);
  $87 = Math_fround(Math_fround(1.0) / $80);
  $88 = Math_fround($87 * $75);
  $89 = Math_fround($87 * $76);
  $90 = Math_fround($87 * $77);
  $91 = Math_fround($88 + Math_fround(1.0));
  $92 = Math_fround($89 + Math_fround(1.0));
  $93 = Math_fround($90 + Math_fround(1.0));
  $94 = (~~(($91)));
  $95 = (~~(($92)));
  $96 = (~~(($93)));
  $97 = $53 == Math_fround(0.0);
  $98 = $54 == Math_fround(0.0);
  $99 = $55 == Math_fround(0.0);
  HEAPF32[$1>>2] = Math_fround(2.35098870164457501594E-38);
  $100 = (($1) + 4|0);
  HEAPF32[$100>>2] = Math_fround(2.35098870164457501594E-38);
  $101 = (($1) + 8|0);
  HEAPF32[$101>>2] = Math_fround(2.35098870164457501594E-38);
  $102 = (($1) + 12|0);
  HEAPF32[$102>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = $53;
  $103 = (($0) + 4|0);
  HEAPF32[$103>>2] = $54;
  $104 = (($0) + 8|0);
  HEAPF32[$104>>2] = $55;
  $105 = (($0) + 12|0);
  HEAPF32[$105>>2] = Math_fround(0.0);
  $b$a$i$i = $97 ? $1 : $0;
  $106 = Math_fround(HEAPF32[$b$a$i$i>>2]);
  $a$pn3$i$i = $98 ? $1 : $0;
  $$in1$i$i = (($a$pn3$i$i) + 4|0);
  $107 = Math_fround(HEAPF32[$$in1$i$i>>2]);
  $b$a5$i$i = $99 ? $1 : $0;
  $$in2$i$i = (($b$a5$i$i) + 8|0);
  $108 = Math_fround(HEAPF32[$$in2$i$i>>2]);
  $109 = (HEAPF32[tempDoublePtr>>2]=$106,HEAP32[tempDoublePtr>>2]|0);
  $110 = (HEAPF32[tempDoublePtr>>2]=$107,HEAP32[tempDoublePtr>>2]|0);
  $111 = (HEAPF32[tempDoublePtr>>2]=$108,HEAP32[tempDoublePtr>>2]|0);
  $112 = $109 & -256;
  $113 = $110 & -256;
  $114 = $111 & -256;
  $115 = $94 | $112;
  $116 = $95 | $113;
  $117 = $96 | $114;
  $118 = (HEAP32[tempDoublePtr>>2]=$115,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $119 = (HEAP32[tempDoublePtr>>2]=$116,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $120 = (HEAP32[tempDoublePtr>>2]=$117,Math_fround(HEAPF32[tempDoublePtr>>2]));
  HEAPF32[$prevXYZ>>2] = $118;
  $121 = (($prevXYZ) + 4|0);
  HEAPF32[$121>>2] = $119;
  $122 = (($prevXYZ) + 8|0);
  HEAPF32[$122>>2] = $120;
  $123 = (($prevXYZ) + 12|0);
  HEAPF32[$123>>2] = Math_fround(0.0);
  ;HEAP32[$wMin+0>>2]=HEAP32[$bMin+0>>2]|0;HEAP32[$wMin+4>>2]=HEAP32[$bMin+4>>2]|0;HEAP32[$wMin+8>>2]=HEAP32[$bMin+8>>2]|0;HEAP32[$wMin+12>>2]=HEAP32[$bMin+12>>2]|0;
  ;HEAP32[$wMax+0>>2]=HEAP32[$bMax+0>>2]|0;HEAP32[$wMax+4>>2]=HEAP32[$bMax+4>>2]|0;HEAP32[$wMax+8>>2]=HEAP32[$bMax+8>>2]|0;HEAP32[$wMax+12>>2]=HEAP32[$bMax+12>>2]|0;
  $124 = HEAP32[$todoCompress>>2]|0;
  HEAP32[$todoWriteback>>2] = $124;
  HEAP32[$todoCompress>>2] = 0;
 }
 $125 = (($pool) + (($index*24)|0)|0);
 $126 = ((($pool) + (($index*24)|0)|0) + 16|0);
 $127 = $126;
 $128 = $127;
 $129 = HEAP32[$128>>2]|0;
 $130 = (($127) + 4)|0;
 $131 = $130;
 $132 = HEAP32[$131>>2]|0;
 $133 = $129 & 1;
 $134 = ($133|0)==(0);
 $135 = (0)==(0);
 $136 = $134 & $135;
 $137 = (_bitshift64Lshr(($129|0),($132|0),21)|0);
 $138 = tempRet0;
 $139 = $137 & 524287;
 if (!($136)) {
  $140 = $129 & 2;
  $141 = ($140|0)==(0);
  $142 = (0)==(0);
  $143 = $141 & $142;
  if ($143) {
   $158 = Math_fround(2.49999998623931821607E+32);$160 = Math_fround(2.49999998623931821607E+32);$162 = Math_fround(2.49999998623931821607E+32);$164 = Math_fround(-2.49999998623931821607E+32);$166 = Math_fround(-2.49999998623931821607E+32);$168 = Math_fround(-2.49999998623931821607E+32);
  } else {
   $144 = (($indices) + ($139<<2)|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = (($boxes) + (($145*24)|0)|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = ((($boxes) + (($145*24)|0)|0) + 4|0);
   $149 = Math_fround(HEAPF32[$148>>2]);
   $150 = ((($boxes) + (($145*24)|0)|0) + 8|0);
   $151 = Math_fround(HEAPF32[$150>>2]);
   $152 = ((($boxes) + (($145*24)|0)|0) + 12|0);
   $153 = Math_fround(HEAPF32[$152>>2]);
   $154 = ((($boxes) + (($145*24)|0)|0) + 16|0);
   $155 = Math_fround(HEAPF32[$154>>2]);
   $156 = ((($boxes) + (($145*24)|0)|0) + 20|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $158 = $147;$160 = $149;$162 = $151;$164 = $153;$166 = $155;$168 = $157;
  }
  HEAPF32[$bMin>>2] = $158;
  $159 = (($bMin) + 4|0);
  HEAPF32[$159>>2] = $160;
  $161 = (($bMin) + 8|0);
  HEAPF32[$161>>2] = $162;
  $163 = (($bMin) + 12|0);
  HEAPF32[$163>>2] = Math_fround(0.0);
  HEAPF32[$bMax>>2] = $164;
  $165 = (($bMax) + 4|0);
  HEAPF32[$165>>2] = $166;
  $167 = (($bMax) + 8|0);
  HEAPF32[$167>>2] = $168;
  $169 = (($bMax) + 12|0);
  HEAPF32[$169>>2] = Math_fround(0.0);
  HEAP32[$todoCompress>>2] = $125;
  STACKTOP = sp;return;
 }
 $170 = (($pool) + (($139*24)|0)|0);
 $171 = HEAP32[$todoWriteback>>2]|0;
 $172 = ($170|0)==($171|0);
 if ($172) {
  $173 = Math_fround(HEAPF32[$wMin>>2]);
  $174 = (($wMin) + 4|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (($wMin) + 8|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround(HEAPF32[$wMax>>2]);
  $179 = (($wMax) + 4|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = (($wMax) + 8|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $265 = $173;$268 = $175;$272 = $177;$278 = $178;$281 = $180;$285 = $182;
 } else {
  $183 = Math_fround(HEAPF32[$170>>2]);
  $184 = ((($pool) + (($139*24)|0)|0) + 4|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = ((($pool) + (($139*24)|0)|0) + 8|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = ((($pool) + (($139*24)|0)|0) + 16|0);
  $189 = $188;
  $190 = $189;
  $191 = HEAP32[$190>>2]|0;
  $192 = (($189) + 4)|0;
  $193 = $192;
  $194 = HEAP32[$193>>2]|0;
  $195 = $194 & -256;
  $196 = (HEAP32[tempDoublePtr>>2]=$195,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $197 = Math_fround($196 * Math_fround(9.99999974737875163555E-5));
  $198 = (HEAPF32[tempDoublePtr>>2]=$183,HEAP32[tempDoublePtr>>2]|0);
  $199 = (HEAPF32[tempDoublePtr>>2]=$185,HEAP32[tempDoublePtr>>2]|0);
  $200 = (HEAPF32[tempDoublePtr>>2]=$187,HEAP32[tempDoublePtr>>2]|0);
  $201 = $198 & 255;
  $202 = $199 & 255;
  $203 = $200 & 255;
  $204 = (Math_fround(($201|0)));
  $205 = (Math_fround(($202|0)));
  $206 = (Math_fround(($203|0)));
  $207 = Math_fround($204 * $197);
  $208 = Math_fround($205 * $197);
  $209 = Math_fround($206 * $197);
  $210 = Math_fround($183 - $207);
  $211 = Math_fround($185 - $208);
  $212 = Math_fround($187 - $209);
  $213 = Math_fround($183 + $207);
  $214 = Math_fround($185 + $208);
  $215 = Math_fround($187 + $209);
  $265 = $210;$268 = $211;$272 = $212;$278 = $213;$281 = $214;$285 = $215;
 }
 $216 = ($139|0)==(0);
 $$sum$i = (($139) + 1)|0;
 $217 = (($pool) + (($$sum$i*24)|0)|0);
 $218 = $216 ? $pool : $217;
 $219 = ($218|0)==($171|0);
 if ($219) {
  $220 = Math_fround(HEAPF32[$wMin>>2]);
  $221 = (($wMin) + 4|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  $223 = (($wMin) + 8|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = Math_fround(HEAPF32[$wMax>>2]);
  $226 = (($wMax) + 4|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = (($wMax) + 8|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $264 = $220;$267 = $222;$271 = $224;$277 = $225;$280 = $227;$284 = $229;
 } else {
  $230 = Math_fround(HEAPF32[$218>>2]);
  $231 = (($218) + 4|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = (($218) + 8|0);
  $234 = Math_fround(HEAPF32[$233>>2]);
  $235 = (($218) + 16|0);
  $236 = $235;
  $237 = $236;
  $238 = HEAP32[$237>>2]|0;
  $239 = (($236) + 4)|0;
  $240 = $239;
  $241 = HEAP32[$240>>2]|0;
  $242 = $241 & -256;
  $243 = (HEAP32[tempDoublePtr>>2]=$242,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $244 = Math_fround($243 * Math_fround(9.99999974737875163555E-5));
  $245 = (HEAPF32[tempDoublePtr>>2]=$230,HEAP32[tempDoublePtr>>2]|0);
  $246 = (HEAPF32[tempDoublePtr>>2]=$232,HEAP32[tempDoublePtr>>2]|0);
  $247 = (HEAPF32[tempDoublePtr>>2]=$234,HEAP32[tempDoublePtr>>2]|0);
  $248 = $245 & 255;
  $249 = $246 & 255;
  $250 = $247 & 255;
  $251 = (Math_fround(($248|0)));
  $252 = (Math_fround(($249|0)));
  $253 = (Math_fround(($250|0)));
  $254 = Math_fround($251 * $244);
  $255 = Math_fround($252 * $244);
  $256 = Math_fround($253 * $244);
  $257 = Math_fround($230 - $254);
  $258 = Math_fround($232 - $255);
  $259 = Math_fround($234 - $256);
  $260 = Math_fround($230 + $254);
  $261 = Math_fround($232 + $255);
  $262 = Math_fround($234 + $256);
  $264 = $257;$267 = $258;$271 = $259;$277 = $260;$280 = $261;$284 = $262;
 }
 $263 = $264 < $265;
 $$$i8 = $263 ? $264 : $265;
 $266 = $267 < $268;
 $269 = $266 ? $267 : $268;
 $270 = $271 < $272;
 $$1$i9 = $270 ? $271 : $272;
 HEAPF32[$bMin>>2] = $$$i8;
 $273 = (($bMin) + 4|0);
 HEAPF32[$273>>2] = $269;
 $274 = (($bMin) + 8|0);
 HEAPF32[$274>>2] = $$1$i9;
 $275 = (($bMin) + 12|0);
 HEAPF32[$275>>2] = Math_fround(0.0);
 $276 = $277 > $278;
 $$$i = $276 ? $277 : $278;
 $279 = $280 > $281;
 $282 = $279 ? $280 : $281;
 $283 = $284 > $285;
 $$1$i = $283 ? $284 : $285;
 HEAPF32[$bMax>>2] = $$$i;
 $286 = (($bMax) + 4|0);
 HEAPF32[$286>>2] = $282;
 $287 = (($bMax) + 8|0);
 HEAPF32[$287>>2] = $$1$i;
 $288 = (($bMax) + 12|0);
 HEAPF32[$288>>2] = Math_fround(0.0);
 HEAP32[$todoCompress>>2] = $125;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq8AABBTree11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i102$i = Math_fround(0), $$$i164$i = Math_fround(0), $$$i170$i = Math_fround(0), $$1$i$i$i = Math_fround(0), $$1$i165$i = Math_fround(0), $$1$i171$i = Math_fround(0), $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0;
 var $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn3$i$i = 0, $b$a$i$i = 0;
 var $b$a5$i$i = 0, $i$092 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 536|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = (($shift) + 4|0);
 $7 = (($shift) + 8|0);
 $8 = (($1) + 4|0);
 $9 = (($1) + 8|0);
 $10 = (($1) + 12|0);
 $11 = (($0) + 4|0);
 $12 = (($0) + 8|0);
 $13 = (($0) + 12|0);
 $17 = $3;$i$092 = 0;
 while(1) {
  $14 = HEAP32[$5>>2]|0;
  $15 = (($i$092) + 1)|0;
  $16 = ($15>>>0)<($17>>>0);
  if ($16) {
   $18 = (($14) + (($15*24)|0)|0);
  }
  $19 = Math_fround(HEAPF32[$shift>>2]);
  $20 = Math_fround(HEAPF32[$6>>2]);
  $21 = Math_fround(HEAPF32[$7>>2]);
  $22 = (($14) + (($i$092*24)|0)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = ((($14) + (($i$092*24)|0)|0) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($14) + (($i$092*24)|0)|0) + 8|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = ((($14) + (($i$092*24)|0)|0) + 16|0);
  $29 = $28;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 4)|0;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = $34 & -256;
  $36 = (HEAP32[tempDoublePtr>>2]=$35,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $37 = Math_fround($36 * Math_fround(9.99999974737875163555E-5));
  $38 = (HEAPF32[tempDoublePtr>>2]=$23,HEAP32[tempDoublePtr>>2]|0);
  $39 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $40 = (HEAPF32[tempDoublePtr>>2]=$27,HEAP32[tempDoublePtr>>2]|0);
  $41 = $38 & 255;
  $42 = $39 & 255;
  $43 = $40 & 255;
  $44 = (Math_fround(($41|0)));
  $45 = (Math_fround(($42|0)));
  $46 = (Math_fround(($43|0)));
  $47 = Math_fround($44 * $37);
  $48 = Math_fround($45 * $37);
  $49 = Math_fround($46 * $37);
  $50 = Math_fround($23 - $19);
  $51 = Math_fround($25 - $20);
  $52 = Math_fround($27 - $21);
  $53 = Math_fround($50 - $47);
  $54 = Math_fround($51 - $48);
  $55 = Math_fround($52 - $49);
  $56 = Math_fround($50 + $47);
  $57 = Math_fround($51 + $48);
  $58 = Math_fround($52 + $49);
  $59 = $53 > Math_fround(-9.99999994495727286427E+32);
  $$$i170$i = $59 ? $53 : Math_fround(-9.99999994495727286427E+32);
  $60 = $54 > Math_fround(-9.99999994495727286427E+32);
  $61 = $60 ? $54 : Math_fround(-9.99999994495727286427E+32);
  $62 = $55 > Math_fround(-9.99999994495727286427E+32);
  $$1$i171$i = $62 ? $55 : Math_fround(-9.99999994495727286427E+32);
  $63 = $56 < Math_fround(9.99999994495727286427E+32);
  $$$i164$i = $63 ? $56 : Math_fround(9.99999994495727286427E+32);
  $64 = $57 < Math_fround(9.99999994495727286427E+32);
  $65 = $64 ? $57 : Math_fround(9.99999994495727286427E+32);
  $66 = $58 < Math_fround(9.99999994495727286427E+32);
  $$1$i165$i = $66 ? $58 : Math_fround(9.99999994495727286427E+32);
  $67 = Math_fround($$$i170$i + $$$i164$i);
  $68 = Math_fround($61 + $65);
  $69 = Math_fround($$1$i171$i + $$1$i165$i);
  $70 = Math_fround($67 * Math_fround(0.5));
  $71 = Math_fround($68 * Math_fround(0.5));
  $72 = Math_fround($69 * Math_fround(0.5));
  $73 = Math_fround($$$i164$i - $$$i170$i);
  $74 = Math_fround($65 - $61);
  $75 = Math_fround($$1$i165$i - $$1$i171$i);
  $76 = Math_fround($73 * Math_fround(0.5));
  $77 = Math_fround($74 * Math_fround(0.5));
  $78 = Math_fround($75 * Math_fround(0.5));
  $79 = Math_fround($70 * Math_fround(9.99999974737875163555E-5));
  $80 = Math_fround($71 * Math_fround(9.99999974737875163555E-5));
  $81 = Math_fround($72 * Math_fround(9.99999974737875163555E-5));
  $82 = Math_fround(-$79);
  $83 = Math_fround(-$80);
  $84 = Math_fround(-$81);
  $85 = $79 > $82;
  $$$i$i$i = $85 ? $79 : $82;
  $86 = $80 > $83;
  $87 = $86 ? $80 : $83;
  $88 = $81 > $84;
  $$1$i$i$i = $88 ? $81 : $84;
  $89 = Math_fround($$$i$i$i + Math_fround(9.99999974737875163555E-5));
  $90 = Math_fround($87 + Math_fround(9.99999974737875163555E-5));
  $91 = Math_fround($$1$i$i$i + Math_fround(9.99999974737875163555E-5));
  $92 = Math_fround($76 + $89);
  $93 = Math_fround($77 + $90);
  $94 = Math_fround($78 + $91);
  $95 = $93 > $94;
  $$$i102$i = $95 ? $93 : $94;
  $96 = $92 > $$$i102$i;
  $$$i$i = $96 ? $92 : $$$i102$i;
  $97 = Math_fround($$$i$i * Math_fround(0.00392158422619104385376));
  $98 = Math_fround($97 * Math_fround(9.99999974737875163555E-5));
  $99 = Math_fround($97 + $98);
  $100 = Math_fround($99 * Math_fround(1.0E+4));
  $101 = (HEAPF32[tempDoublePtr>>2]=$100,HEAP32[tempDoublePtr>>2]|0);
  $102 = Math_fround(Math_fround(1.0) / $97);
  $103 = Math_fround($102 * $92);
  $104 = Math_fround($102 * $93);
  $105 = Math_fround($102 * $94);
  $106 = Math_fround($103 + Math_fround(1.0));
  $107 = Math_fround($104 + Math_fround(1.0));
  $108 = Math_fround($105 + Math_fround(1.0));
  $109 = (~~(($106)));
  $110 = (~~(($107)));
  $111 = (~~(($108)));
  $112 = $70 == Math_fround(0.0);
  $113 = $71 == Math_fround(0.0);
  $114 = $72 == Math_fround(0.0);
  HEAPF32[$1>>2] = Math_fround(2.35098870164457501594E-38);
  HEAPF32[$8>>2] = Math_fround(2.35098870164457501594E-38);
  HEAPF32[$9>>2] = Math_fround(2.35098870164457501594E-38);
  HEAPF32[$10>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = $70;
  HEAPF32[$11>>2] = $71;
  HEAPF32[$12>>2] = $72;
  HEAPF32[$13>>2] = Math_fround(0.0);
  $b$a$i$i = $112 ? $1 : $0;
  $115 = Math_fround(HEAPF32[$b$a$i$i>>2]);
  $a$pn3$i$i = $113 ? $1 : $0;
  $$in1$i$i = (($a$pn3$i$i) + 4|0);
  $116 = Math_fround(HEAPF32[$$in1$i$i>>2]);
  $b$a5$i$i = $114 ? $1 : $0;
  $$in2$i$i = (($b$a5$i$i) + 8|0);
  $117 = Math_fround(HEAPF32[$$in2$i$i>>2]);
  $118 = (HEAPF32[tempDoublePtr>>2]=$115,HEAP32[tempDoublePtr>>2]|0);
  $119 = (HEAPF32[tempDoublePtr>>2]=$116,HEAP32[tempDoublePtr>>2]|0);
  $120 = (HEAPF32[tempDoublePtr>>2]=$117,HEAP32[tempDoublePtr>>2]|0);
  $121 = $118 & -256;
  $122 = $119 & -256;
  $123 = $120 & -256;
  $124 = $109 | $121;
  $125 = $110 | $122;
  $126 = $111 | $123;
  $127 = (HEAP32[tempDoublePtr>>2]=$124,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $128 = (HEAP32[tempDoublePtr>>2]=$125,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $129 = (HEAP32[tempDoublePtr>>2]=$126,Math_fround(HEAPF32[tempDoublePtr>>2]));
  HEAPF32[$22>>2] = $127;
  HEAPF32[$24>>2] = $128;
  HEAPF32[$26>>2] = $129;
  $130 = $101 >>> 8;
  $131 = $28;
  $132 = $131;
  $133 = HEAP32[$132>>2]|0;
  $134 = (($131) + 4)|0;
  $135 = $134;
  $136 = HEAP32[$135>>2]|0;
  $137 = $136 & 255;
  $138 = (_bitshift64Shl(($130|0),0,40)|0);
  $139 = tempRet0;
  $140 = $138 | $133;
  $141 = $139 | $137;
  $142 = $28;
  $143 = $142;
  HEAP32[$143>>2] = $140;
  $144 = (($142) + 4)|0;
  $145 = $144;
  HEAP32[$145>>2] = $141;
  $146 = HEAP32[$2>>2]|0;
  $147 = ($15>>>0)<($146>>>0);
  if ($147) {
   $17 = $146;$i$092 = $15;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sq12AABBTreeNode9subdivideERKNS_9PxBounds3EPNS0_15AABBTreeBuilderEPj($this,$exactBounds,$builder,$indices) {
 $this = $this|0;
 $exactBounds = $exactBounds|0;
 $builder = $builder|0;
 $indices = $indices|0;
 var $$0 = 0, $$lcssa = Math_fround(0), $$lcssa291 = Math_fround(0), $$lcssa292 = Math_fround(0), $$lcssa296 = Math_fround(0), $$lcssa297 = Math_fround(0), $$lcssa298 = Math_fround(0), $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0;
 var $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0);
 var $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0;
 var $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0);
 var $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = 0;
 var $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0);
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0;
 var $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = Math_fround(0), $546 = 0, $547 = Math_fround(0), $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = 0, $555 = 0, $556 = 0, $557 = Math_fround(0), $558 = 0;
 var $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = Math_fround(0), $566 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $CurAxis$0$ph = 0, $Extents = 0, $Extents3 = 0, $Min$0 = 0;
 var $Min$1 = 0, $NbPos$0 = 0, $NbPos$0$lcssa$i278 = 0, $NbPos$0$lcssa$i30 = 0, $NbPos$0$lcssa$i40 = 0, $NbPos$0$lcssa$i50 = 0, $NbPos$0$ph = 0, $NbPos$08$i = 0, $NbPos$08$i109 = 0, $NbPos$08$i17 = 0, $NbPos$08$i27 = 0, $NbPos$08$i37 = 0, $NbPos$08$i47 = 0, $NbPos$08$i56 = 0, $NbPos$1$i = 0, $NbPos$1$i111 = 0, $NbPos$1$i19 = 0, $NbPos$1$i29 = 0, $NbPos$1$i39 = 0, $NbPos$1$i49 = 0;
 var $NbPos$1$i58 = 0, $NbPos$2 = 0, $Prims$0299 = 0, $Prims$1293 = 0, $Results = 0, $SortedAxis = 0, $ValidSplit$0 = 0, $Vars3 = 0, $exitcond = 0, $i$07$i = 0, $i$07$i110 = 0, $i$07$i18 = 0, $i$07$i28 = 0, $i$07$i38 = 0, $i$07$i48 = 0, $i$07$i57 = 0, $not$or$cond = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0;
 var $or$cond328 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $Extents = sp + 48|0;
 $Vars3 = sp;
 $Results = sp + 12|0;
 $Extents3 = sp + 24|0;
 $SortedAxis = sp + 36|0;
 $0 = (($this) + 16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (_bitshift64Lshr(($3|0),($6|0),2)|0);
 $8 = tempRet0;
 $9 = $7 & 524287;
 $10 = ($9|0)==(1);
 if ($10) {
  $11 = $3 & -3;
  $12 = (_bitshift64Shl(($7|0),($8|0),1)|0);
  $13 = tempRet0;
  $14 = $12 & 2;
  $15 = $14 | $11;
  $16 = $0;
  $17 = $16;
  HEAP32[$17>>2] = $15;
  $18 = (($16) + 4)|0;
  $19 = $18;
  HEAP32[$19>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$builder>>2]|0;
 $21 = ($20>>>0)<($9>>>0);
 if (!($21)) {
  $22 = $3 & -3;
  $23 = (_bitshift64Shl(($7|0),($8|0),1)|0);
  $24 = tempRet0;
  $25 = $23 & 2;
  $26 = $25 | $22;
  $27 = $0;
  $28 = $27;
  HEAP32[$28>>2] = $26;
  $29 = (($27) + 4)|0;
  $30 = $29;
  HEAP32[$30>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (($builder) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 & 1;
 $34 = ($33|0)==(0);
 L9: do {
  if ($34) {
   $95 = $32 & 2;
   $96 = ($95|0)==(0);
   if (!($96)) {
    $97 = (Math_fround(($9>>>0)));
    $98 = (_bitshift64Lshr(($3|0),($6|0),21)|0);
    $99 = tempRet0;
    $100 = $98 & 524287;
    $$sum = (($100) + ($9))|0;
    $101 = (($indices) + ($$sum<<2)|0);
    $102 = ($100|0)<($$sum|0);
    if ($102) {
     $103 = (($indices) + ($100<<2)|0);
     $104 = (($builder) + 20|0);
     $105 = HEAP32[$104>>2]|0;
     $127 = Math_fround(0.0);$129 = Math_fround(0.0);$131 = Math_fround(0.0);$Prims$0299 = $103;
     while(1) {
      $106 = (($Prims$0299) + 4|0);
      $107 = HEAP32[$Prims$0299>>2]|0;
      $108 = (($105) + (($107*24)|0)|0);
      $109 = Math_fround(HEAPF32[$108>>2]);
      $110 = ((($105) + (($107*24)|0)|0) + 4|0);
      $111 = Math_fround(HEAPF32[$110>>2]);
      $112 = ((($105) + (($107*24)|0)|0) + 8|0);
      $113 = Math_fround(HEAPF32[$112>>2]);
      $114 = ((($105) + (($107*24)|0)|0) + 12|0);
      $115 = Math_fround(HEAPF32[$114>>2]);
      $116 = ((($105) + (($107*24)|0)|0) + 16|0);
      $117 = Math_fround(HEAPF32[$116>>2]);
      $118 = ((($105) + (($107*24)|0)|0) + 20|0);
      $119 = Math_fround(HEAPF32[$118>>2]);
      $120 = Math_fround($109 + $115);
      $121 = Math_fround($111 + $117);
      $122 = Math_fround($113 + $119);
      $123 = Math_fround($120 * Math_fround(0.5));
      $124 = Math_fround($121 * Math_fround(0.5));
      $125 = Math_fround($122 * Math_fround(0.5));
      $126 = Math_fround($127 + $123);
      $128 = Math_fround($129 + $124);
      $130 = Math_fround($131 + $125);
      $132 = ($106>>>0)<($101>>>0);
      if ($132) {
       $127 = $126;$129 = $128;$131 = $130;$Prims$0299 = $106;
      } else {
       $$lcssa296 = $130;$$lcssa297 = $128;$$lcssa298 = $126;
       break;
      }
     }
    } else {
     $$lcssa296 = Math_fround(0.0);$$lcssa297 = Math_fround(0.0);$$lcssa298 = Math_fround(0.0);
    }
    $133 = Math_fround(Math_fround(1.0) / $97);
    $134 = Math_fround($$lcssa298 * $133);
    $135 = Math_fround($$lcssa297 * $133);
    $136 = Math_fround($$lcssa296 * $133);
    $137 = ($9|0)==(0);
    if ($137) {
     $$lcssa = Math_fround(0.0);$$lcssa291 = Math_fround(0.0);$$lcssa292 = Math_fround(0.0);
    } else {
     $138 = (($indices) + ($100<<2)|0);
     $139 = (($builder) + 20|0);
     $140 = HEAP32[$139>>2]|0;
     $168 = Math_fround(0.0);$170 = Math_fround(0.0);$172 = Math_fround(0.0);$Prims$1293 = $138;
     while(1) {
      $141 = (($Prims$1293) + 4|0);
      $142 = HEAP32[$Prims$1293>>2]|0;
      $143 = (($140) + (($142*24)|0)|0);
      $144 = Math_fround(HEAPF32[$143>>2]);
      $145 = ((($140) + (($142*24)|0)|0) + 4|0);
      $146 = Math_fround(HEAPF32[$145>>2]);
      $147 = ((($140) + (($142*24)|0)|0) + 8|0);
      $148 = Math_fround(HEAPF32[$147>>2]);
      $149 = ((($140) + (($142*24)|0)|0) + 12|0);
      $150 = Math_fround(HEAPF32[$149>>2]);
      $151 = ((($140) + (($142*24)|0)|0) + 16|0);
      $152 = Math_fround(HEAPF32[$151>>2]);
      $153 = ((($140) + (($142*24)|0)|0) + 20|0);
      $154 = Math_fround(HEAPF32[$153>>2]);
      $155 = Math_fround($144 + $150);
      $156 = Math_fround($146 + $152);
      $157 = Math_fround($148 + $154);
      $158 = Math_fround($155 * Math_fround(0.5));
      $159 = Math_fround($156 * Math_fround(0.5));
      $160 = Math_fround($157 * Math_fround(0.5));
      $161 = Math_fround($158 - $134);
      $162 = Math_fround($159 - $135);
      $163 = Math_fround($160 - $136);
      $164 = Math_fround($161 * $161);
      $165 = Math_fround($162 * $162);
      $166 = Math_fround($163 * $163);
      $167 = Math_fround($168 + $164);
      $169 = Math_fround($170 + $165);
      $171 = Math_fround($172 + $166);
      $173 = ($141|0)==($101|0);
      if ($173) {
       $$lcssa = $171;$$lcssa291 = $169;$$lcssa292 = $167;
       break;
      } else {
       $168 = $167;$170 = $169;$172 = $171;$Prims$1293 = $141;
      }
     }
    }
    $174 = Math_fround($97 + Math_fround(-1.0));
    $175 = Math_fround(Math_fround(1.0) / $174);
    $176 = Math_fround($$lcssa292 * $175);
    $177 = Math_fround($$lcssa291 * $175);
    $178 = Math_fround($$lcssa * $175);
    HEAPF32[$Vars3>>2] = $176;
    $179 = (($Vars3) + 4|0);
    HEAPF32[$179>>2] = $177;
    $180 = (($Vars3) + 8|0);
    HEAPF32[$180>>2] = $178;
    $181 = $177 > $176;
    $182 = $181&1;
    $183 = (($Vars3) + ($182<<2)|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    $185 = $178 > $184;
    $186 = $185 ? 2 : $182;
    $187 = (($exactBounds) + ($186<<2)|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = (($exactBounds) + 12|0);
    $190 = (($189) + ($186<<2)|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = Math_fround($188 + $191);
    $193 = Math_fround($192 * Math_fround(0.5));
    $194 = $3 & 2097148;
    $195 = ($194|0)==(0);
    $196 = (0)==(0);
    $197 = $195 & $196;
    if ($197) {
     label = 64;
     break;
    }
    $198 = (($builder) + 20|0);
    $199 = HEAP32[$198>>2]|0;
    $NbPos$08$i56 = 0;$i$07$i57 = 0;
    while(1) {
     $200 = (($i$07$i57) + ($100))|0;
     $201 = (($indices) + ($200<<2)|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = (($199) + (($202*24)|0)|0);
     $204 = (($203) + ($186<<2)|0);
     $205 = Math_fround(HEAPF32[$204>>2]);
     $206 = ((($199) + (($202*24)|0)|0) + 12|0);
     $207 = (($206) + ($186<<2)|0);
     $208 = Math_fround(HEAPF32[$207>>2]);
     $209 = Math_fround($205 + $208);
     $210 = Math_fround($209 * Math_fround(0.5));
     $211 = $210 > $193;
     if ($211) {
      $212 = (($NbPos$08$i56) + ($100))|0;
      $213 = (($indices) + ($212<<2)|0);
      $214 = HEAP32[$213>>2]|0;
      HEAP32[$201>>2] = $214;
      HEAP32[$213>>2] = $202;
      $215 = (($NbPos$08$i56) + 1)|0;
      $NbPos$1$i58 = $215;
     } else {
      $NbPos$1$i58 = $NbPos$08$i56;
     }
     $216 = (($i$07$i57) + 1)|0;
     $217 = ($216>>>0)<($9>>>0);
     if ($217) {
      $NbPos$08$i56 = $NbPos$1$i58;$i$07$i57 = $216;
     } else {
      break;
     }
    }
    $notlhs = ($NbPos$1$i58|0)!=(0);
    $notrhs = ($NbPos$1$i58|0)!=($9|0);
    $not$or$cond = $notrhs & $notlhs;
    if ($not$or$cond) {
     $454 = $3;$455 = $6;$NbPos$2 = $NbPos$1$i58;
     break;
    } else {
     label = 64;
     break;
    }
   }
   $218 = $32 & 8;
   $219 = ($218|0)==(0);
   if (!($219)) {
    $220 = Math_fround(HEAPF32[$exactBounds>>2]);
    $221 = (($exactBounds) + 12|0);
    $222 = Math_fround(HEAPF32[$221>>2]);
    $223 = Math_fround($220 + $222);
    $224 = Math_fround($223 * Math_fround(0.5));
    $225 = $3 & 2097148;
    $226 = ($225|0)==(0);
    $227 = (0)==(0);
    $228 = $226 & $227;
    if ($228) {
     $NbPos$0$lcssa$i50 = 0;
    } else {
     $229 = (($builder) + 20|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = (_bitshift64Lshr(($3|0),($6|0),21)|0);
     $232 = tempRet0;
     $233 = $231 & 524287;
     $234 = $7 & 524287;
     $NbPos$08$i47 = 0;$i$07$i48 = 0;
     while(1) {
      $235 = (($i$07$i48) + ($233))|0;
      $236 = (($indices) + ($235<<2)|0);
      $237 = HEAP32[$236>>2]|0;
      $238 = (($230) + (($237*24)|0)|0);
      $239 = Math_fround(HEAPF32[$238>>2]);
      $240 = ((($230) + (($237*24)|0)|0) + 12|0);
      $241 = Math_fround(HEAPF32[$240>>2]);
      $242 = Math_fround($239 + $241);
      $243 = Math_fround($242 * Math_fround(0.5));
      $244 = $243 > $224;
      if ($244) {
       $245 = (($NbPos$08$i47) + ($233))|0;
       $246 = (($indices) + ($245<<2)|0);
       $247 = HEAP32[$246>>2]|0;
       HEAP32[$236>>2] = $247;
       HEAP32[$246>>2] = $237;
       $248 = (($NbPos$08$i47) + 1)|0;
       $NbPos$1$i49 = $248;
      } else {
       $NbPos$1$i49 = $NbPos$08$i47;
      }
      $249 = (($i$07$i48) + 1)|0;
      $exitcond = ($249|0)==($234|0);
      if ($exitcond) {
       $NbPos$0$lcssa$i50 = $NbPos$1$i49;
       break;
      } else {
       $NbPos$08$i47 = $NbPos$1$i49;$i$07$i48 = $249;
      }
     }
    }
    $250 = (Math_fround(($NbPos$0$lcssa$i50>>>0)));
    $251 = (Math_fround(($9>>>0)));
    $252 = Math_fround($250 / $251);
    HEAPF32[$Results>>2] = $252;
    $253 = (($exactBounds) + 4|0);
    $254 = Math_fround(HEAPF32[$253>>2]);
    $255 = (($221) + 4|0);
    $256 = Math_fround(HEAPF32[$255>>2]);
    $257 = Math_fround($254 + $256);
    $258 = Math_fround($257 * Math_fround(0.5));
    if ($228) {
     $NbPos$0$lcssa$i40 = 0;
    } else {
     $259 = (($builder) + 20|0);
     $260 = HEAP32[$259>>2]|0;
     $261 = (_bitshift64Lshr(($3|0),($6|0),21)|0);
     $262 = tempRet0;
     $263 = $261 & 524287;
     $NbPos$08$i37 = 0;$i$07$i38 = 0;
     while(1) {
      $264 = (($i$07$i38) + ($263))|0;
      $265 = (($indices) + ($264<<2)|0);
      $266 = HEAP32[$265>>2]|0;
      $267 = (($260) + (($266*24)|0)|0);
      $268 = (($267) + 4|0);
      $269 = Math_fround(HEAPF32[$268>>2]);
      $270 = ((($260) + (($266*24)|0)|0) + 12|0);
      $271 = (($270) + 4|0);
      $272 = Math_fround(HEAPF32[$271>>2]);
      $273 = Math_fround($269 + $272);
      $274 = Math_fround($273 * Math_fround(0.5));
      $275 = $274 > $258;
      if ($275) {
       $276 = (($NbPos$08$i37) + ($263))|0;
       $277 = (($indices) + ($276<<2)|0);
       $278 = HEAP32[$277>>2]|0;
       HEAP32[$265>>2] = $278;
       HEAP32[$277>>2] = $266;
       $279 = (($NbPos$08$i37) + 1)|0;
       $NbPos$1$i39 = $279;
      } else {
       $NbPos$1$i39 = $NbPos$08$i37;
      }
      $280 = (($i$07$i38) + 1)|0;
      $281 = ($280>>>0)<($9>>>0);
      if ($281) {
       $NbPos$08$i37 = $NbPos$1$i39;$i$07$i38 = $280;
      } else {
       $NbPos$0$lcssa$i40 = $NbPos$1$i39;
       break;
      }
     }
    }
    $282 = (Math_fround(($NbPos$0$lcssa$i40>>>0)));
    $283 = Math_fround($282 / $251);
    $284 = (($Results) + 4|0);
    HEAPF32[$284>>2] = $283;
    $285 = (($exactBounds) + 8|0);
    $286 = Math_fround(HEAPF32[$285>>2]);
    $287 = (($221) + 8|0);
    $288 = Math_fround(HEAPF32[$287>>2]);
    $289 = Math_fround($286 + $288);
    $290 = Math_fround($289 * Math_fround(0.5));
    if ($228) {
     $NbPos$0$lcssa$i30 = 0;
    } else {
     $291 = (($builder) + 20|0);
     $292 = HEAP32[$291>>2]|0;
     $293 = (_bitshift64Lshr(($3|0),($6|0),21)|0);
     $294 = tempRet0;
     $295 = $293 & 524287;
     $NbPos$08$i27 = 0;$i$07$i28 = 0;
     while(1) {
      $296 = (($i$07$i28) + ($295))|0;
      $297 = (($indices) + ($296<<2)|0);
      $298 = HEAP32[$297>>2]|0;
      $299 = (($292) + (($298*24)|0)|0);
      $300 = (($299) + 8|0);
      $301 = Math_fround(HEAPF32[$300>>2]);
      $302 = ((($292) + (($298*24)|0)|0) + 12|0);
      $303 = (($302) + 8|0);
      $304 = Math_fround(HEAPF32[$303>>2]);
      $305 = Math_fround($301 + $304);
      $306 = Math_fround($305 * Math_fround(0.5));
      $307 = $306 > $290;
      if ($307) {
       $308 = (($NbPos$08$i27) + ($295))|0;
       $309 = (($indices) + ($308<<2)|0);
       $310 = HEAP32[$309>>2]|0;
       HEAP32[$297>>2] = $310;
       HEAP32[$309>>2] = $298;
       $311 = (($NbPos$08$i27) + 1)|0;
       $NbPos$1$i29 = $311;
      } else {
       $NbPos$1$i29 = $NbPos$08$i27;
      }
      $312 = (($i$07$i28) + 1)|0;
      $313 = ($312>>>0)<($9>>>0);
      if ($313) {
       $NbPos$08$i27 = $NbPos$1$i29;$i$07$i28 = $312;
      } else {
       $NbPos$0$lcssa$i30 = $NbPos$1$i29;
       break;
      }
     }
    }
    $314 = (Math_fround(($NbPos$0$lcssa$i30>>>0)));
    $315 = Math_fround($314 / $251);
    $316 = (($Results) + 8|0);
    $317 = Math_fround($252 + Math_fround(-0.5));
    $318 = Math_fround($317 * $317);
    HEAPF32[$Results>>2] = $318;
    $319 = Math_fround($283 + Math_fround(-0.5));
    $320 = Math_fround($319 * $319);
    HEAPF32[$284>>2] = $320;
    $321 = Math_fround($315 + Math_fround(-0.5));
    $322 = Math_fround($321 * $321);
    HEAPF32[$316>>2] = $322;
    $323 = $320 < $318;
    $Min$0 = $323&1;
    $324 = (($Results) + ($Min$0<<2)|0);
    $325 = Math_fround(HEAPF32[$324>>2]);
    $326 = $322 < $325;
    $Min$1 = $326 ? 2 : $Min$0;
    $327 = (($exactBounds) + ($Min$1<<2)|0);
    $328 = Math_fround(HEAPF32[$327>>2]);
    $329 = (($221) + ($Min$1<<2)|0);
    $330 = Math_fround(HEAPF32[$329>>2]);
    $331 = Math_fround($328 + $330);
    $332 = Math_fround($331 * Math_fround(0.5));
    if ($228) {
     label = 64;
     break;
    }
    $333 = (($builder) + 20|0);
    $334 = HEAP32[$333>>2]|0;
    $335 = (_bitshift64Lshr(($3|0),($6|0),21)|0);
    $336 = tempRet0;
    $337 = $335 & 524287;
    $NbPos$08$i17 = 0;$i$07$i18 = 0;
    while(1) {
     $338 = (($i$07$i18) + ($337))|0;
     $339 = (($indices) + ($338<<2)|0);
     $340 = HEAP32[$339>>2]|0;
     $341 = (($334) + (($340*24)|0)|0);
     $342 = (($341) + ($Min$1<<2)|0);
     $343 = Math_fround(HEAPF32[$342>>2]);
     $344 = ((($334) + (($340*24)|0)|0) + 12|0);
     $345 = (($344) + ($Min$1<<2)|0);
     $346 = Math_fround(HEAPF32[$345>>2]);
     $347 = Math_fround($343 + $346);
     $348 = Math_fround($347 * Math_fround(0.5));
     $349 = $348 > $332;
     if ($349) {
      $350 = (($NbPos$08$i17) + ($337))|0;
      $351 = (($indices) + ($350<<2)|0);
      $352 = HEAP32[$351>>2]|0;
      HEAP32[$339>>2] = $352;
      HEAP32[$351>>2] = $340;
      $353 = (($NbPos$08$i17) + 1)|0;
      $NbPos$1$i19 = $353;
     } else {
      $NbPos$1$i19 = $NbPos$08$i17;
     }
     $354 = (($i$07$i18) + 1)|0;
     $355 = ($354>>>0)<($9>>>0);
     if ($355) {
      $NbPos$08$i17 = $NbPos$1$i19;$i$07$i18 = $354;
     } else {
      break;
     }
    }
    $356 = ($NbPos$1$i19|0)==(0);
    $357 = ($NbPos$1$i19|0)==($9|0);
    $or$cond328 = $356 | $357;
    if ($or$cond328) {
     label = 64;
     break;
    } else {
     $454 = $3;$455 = $6;$NbPos$2 = $NbPos$1$i19;
     break;
    }
   }
   $358 = $32 & 4;
   $359 = ($358|0)==(0);
   if ($359) {
    $423 = $32 & 16;
    $424 = ($423|0)==(0);
    if (!($424)) {
     $425 = $9 >>> 1;
     $454 = $3;$455 = $6;$NbPos$2 = $425;
     break;
    }
    $426 = $3 & -3;
    $427 = (_bitshift64Shl(($7|0),($8|0),1)|0);
    $428 = tempRet0;
    $429 = $427 & 2;
    $430 = $429 | $426;
    $431 = $0;
    $432 = $431;
    HEAP32[$432>>2] = $430;
    $433 = (($431) + 4)|0;
    $434 = $433;
    HEAP32[$434>>2] = $6;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $360 = (($exactBounds) + 12|0);
   $361 = Math_fround(HEAPF32[$360>>2]);
   $362 = Math_fround(HEAPF32[$exactBounds>>2]);
   $363 = Math_fround($361 - $362);
   $364 = (($exactBounds) + 16|0);
   $365 = Math_fround(HEAPF32[$364>>2]);
   $366 = (($exactBounds) + 4|0);
   $367 = Math_fround(HEAPF32[$366>>2]);
   $368 = Math_fround($365 - $367);
   $369 = (($exactBounds) + 20|0);
   $370 = Math_fround(HEAPF32[$369>>2]);
   $371 = (($exactBounds) + 8|0);
   $372 = Math_fround(HEAPF32[$371>>2]);
   $373 = Math_fround($370 - $372);
   $374 = Math_fround($363 * Math_fround(0.5));
   $375 = Math_fround($368 * Math_fround(0.5));
   $376 = Math_fround($373 * Math_fround(0.5));
   HEAPF32[$Extents3>>2] = $374;
   $377 = (($Extents3) + 4|0);
   HEAPF32[$377>>2] = $375;
   $378 = (($Extents3) + 8|0);
   HEAPF32[$378>>2] = $376;
   ;HEAP32[$SortedAxis+0>>2]=HEAP32[506984+0>>2]|0;HEAP32[$SortedAxis+4>>2]=HEAP32[506984+4>>2]|0;HEAP32[$SortedAxis+8>>2]=HEAP32[506984+8>>2]|0;
   $379 = (($SortedAxis) + 4|0);
   $380 = $374 < $375;
   if ($380) {
    HEAP32[$SortedAxis>>2] = 1;
    HEAP32[$379>>2] = 0;
    $383 = $374;$542 = 0;$544 = 1;
   } else {
    $383 = $375;$542 = 1;$544 = 0;
   }
   $381 = (($SortedAxis) + 8|0);
   $382 = $383 < $376;
   if ($382) {
    HEAP32[$379>>2] = 2;
    HEAP32[$381>>2] = $542;
    $547 = $376;$548 = 2;$550 = $542;
   } else {
    $547 = $383;$548 = $542;$550 = 2;
   }
   $543 = (($Extents3) + ($544<<2)|0);
   $545 = Math_fround(HEAPF32[$543>>2]);
   $546 = $545 < $547;
   if ($546) {
    HEAP32[$SortedAxis>>2] = $548;
    HEAP32[$379>>2] = $544;
    $553 = $545;$554 = $544;$556 = $548;
   } else {
    $553 = $547;$554 = $548;$556 = $544;
   }
   $549 = (($Extents3) + ($550<<2)|0);
   $551 = Math_fround(HEAPF32[$549>>2]);
   $552 = $553 < $551;
   if ($552) {
    HEAP32[$379>>2] = $550;
    HEAP32[$381>>2] = $554;
    $559 = $551;$560 = $550;$562 = $554;
   } else {
    $559 = $553;$560 = $554;$562 = $550;
   }
   $555 = (($Extents3) + ($556<<2)|0);
   $557 = Math_fround(HEAPF32[$555>>2]);
   $558 = $557 < $559;
   if ($558) {
    HEAP32[$SortedAxis>>2] = $560;
    HEAP32[$379>>2] = $556;
    $565 = $557;$566 = $556;
   } else {
    $565 = $559;$566 = $560;
   }
   $561 = (($Extents3) + ($562<<2)|0);
   $563 = Math_fround(HEAPF32[$561>>2]);
   $564 = $565 < $563;
   if ($564) {
    HEAP32[$379>>2] = $562;
    HEAP32[$381>>2] = $566;
   }
   $397 = (($builder) + 20|0);
   $CurAxis$0$ph = 0;$NbPos$0$ph = 0;
   while(1) {
    $422 = ($CurAxis$0$ph|0)==(3);
    $385 = (($SortedAxis) + ($CurAxis$0$ph<<2)|0);
    if ($422) {
     label = 64;
     break L9;
    } else {
     $NbPos$0 = $NbPos$0$ph;$ValidSplit$0 = 1;
    }
    while(1) {
     if (!($ValidSplit$0)) {
      $454 = $3;$455 = $6;$NbPos$2 = $NbPos$0;
      break L9;
     }
     $384 = HEAP32[$385>>2]|0;
     $386 = (($exactBounds) + ($384<<2)|0);
     $387 = Math_fround(HEAPF32[$386>>2]);
     $388 = (($360) + ($384<<2)|0);
     $389 = Math_fround(HEAPF32[$388>>2]);
     $390 = Math_fround($387 + $389);
     $391 = Math_fround($390 * Math_fround(0.5));
     $392 = $3 & 2097148;
     $393 = ($392|0)==(0);
     $394 = (0)==(0);
     $395 = $393 & $394;
     if ($395) {
      $NbPos$0$lcssa$i278 = 0;
      break;
     }
     $396 = HEAP32[$397>>2]|0;
     $398 = (_bitshift64Lshr(($3|0),($6|0),21)|0);
     $399 = tempRet0;
     $400 = $398 & 524287;
     $NbPos$08$i = 0;$i$07$i = 0;
     while(1) {
      $401 = (($i$07$i) + ($400))|0;
      $402 = (($indices) + ($401<<2)|0);
      $403 = HEAP32[$402>>2]|0;
      $404 = (($396) + (($403*24)|0)|0);
      $405 = (($404) + ($384<<2)|0);
      $406 = Math_fround(HEAPF32[$405>>2]);
      $407 = ((($396) + (($403*24)|0)|0) + 12|0);
      $408 = (($407) + ($384<<2)|0);
      $409 = Math_fround(HEAPF32[$408>>2]);
      $410 = Math_fround($406 + $409);
      $411 = Math_fround($410 * Math_fround(0.5));
      $412 = $411 > $391;
      if ($412) {
       $413 = (($NbPos$08$i) + ($400))|0;
       $414 = (($indices) + ($413<<2)|0);
       $415 = HEAP32[$414>>2]|0;
       HEAP32[$402>>2] = $415;
       HEAP32[$414>>2] = $403;
       $416 = (($NbPos$08$i) + 1)|0;
       $NbPos$1$i = $416;
      } else {
       $NbPos$1$i = $NbPos$08$i;
      }
      $417 = (($i$07$i) + 1)|0;
      $418 = ($417>>>0)<($9>>>0);
      if ($418) {
       $NbPos$08$i = $NbPos$1$i;$i$07$i = $417;
      } else {
       break;
      }
     }
     $419 = ($NbPos$1$i|0)==(0);
     if ($419) {
      $NbPos$0$lcssa$i278 = 0;
      break;
     }
     $420 = ($NbPos$1$i|0)==($9|0);
     if ($420) {
      $NbPos$0$lcssa$i278 = $9;
      break;
     } else {
      $NbPos$0 = $NbPos$1$i;$ValidSplit$0 = 0;
     }
    }
    $421 = (($CurAxis$0$ph) + 1)|0;
    $CurAxis$0$ph = $421;$NbPos$0$ph = $NbPos$0$lcssa$i278;
   }
  } else {
   $35 = (($exactBounds) + 12|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = Math_fround(HEAPF32[$exactBounds>>2]);
   $38 = Math_fround($36 - $37);
   $39 = (($exactBounds) + 16|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = (($exactBounds) + 4|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = Math_fround($40 - $42);
   $44 = (($exactBounds) + 20|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = (($exactBounds) + 8|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = Math_fround($45 - $47);
   $49 = Math_fround($38 * Math_fround(0.5));
   $50 = Math_fround($43 * Math_fround(0.5));
   $51 = Math_fround($48 * Math_fround(0.5));
   HEAPF32[$Extents>>2] = $49;
   $52 = (($Extents) + 4|0);
   HEAPF32[$52>>2] = $50;
   $53 = (($Extents) + 8|0);
   HEAPF32[$53>>2] = $51;
   $54 = $50 > $49;
   $55 = $54&1;
   $56 = (($Extents) + ($55<<2)|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = $51 > $57;
   $59 = $58 ? 2 : $55;
   $60 = (($exactBounds) + ($59<<2)|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = (($35) + ($59<<2)|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = Math_fround($61 + $63);
   $65 = Math_fround($64 * Math_fround(0.5));
   $66 = $3 & 2097148;
   $67 = ($66|0)==(0);
   $68 = (0)==(0);
   $69 = $67 & $68;
   if ($69) {
    label = 64;
   } else {
    $70 = (($builder) + 20|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (_bitshift64Lshr(($3|0),($6|0),21)|0);
    $73 = tempRet0;
    $74 = $72 & 524287;
    $NbPos$08$i109 = 0;$i$07$i110 = 0;
    while(1) {
     $75 = (($i$07$i110) + ($74))|0;
     $76 = (($indices) + ($75<<2)|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($71) + (($77*24)|0)|0);
     $79 = (($78) + ($59<<2)|0);
     $80 = Math_fround(HEAPF32[$79>>2]);
     $81 = ((($71) + (($77*24)|0)|0) + 12|0);
     $82 = (($81) + ($59<<2)|0);
     $83 = Math_fround(HEAPF32[$82>>2]);
     $84 = Math_fround($80 + $83);
     $85 = Math_fround($84 * Math_fround(0.5));
     $86 = $85 > $65;
     if ($86) {
      $87 = (($NbPos$08$i109) + ($74))|0;
      $88 = (($indices) + ($87<<2)|0);
      $89 = HEAP32[$88>>2]|0;
      HEAP32[$76>>2] = $89;
      HEAP32[$88>>2] = $77;
      $90 = (($NbPos$08$i109) + 1)|0;
      $NbPos$1$i111 = $90;
     } else {
      $NbPos$1$i111 = $NbPos$08$i109;
     }
     $91 = (($i$07$i110) + 1)|0;
     $92 = ($91>>>0)<($9>>>0);
     if ($92) {
      $NbPos$08$i109 = $NbPos$1$i111;$i$07$i110 = $91;
     } else {
      break;
     }
    }
    $93 = ($NbPos$1$i111|0)==(0);
    $94 = ($NbPos$1$i111|0)==($9|0);
    $or$cond = $93 | $94;
    if ($or$cond) {
     label = 64;
    } else {
     $454 = $3;$455 = $6;$NbPos$2 = $NbPos$1$i111;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 64) {
   $435 = $3 & -3;
   $436 = (_bitshift64Lshr(($3|0),($6|0),1)|0);
   $437 = tempRet0;
   $438 = $436 & 2;
   $439 = $438 | $435;
   $440 = $0;
   $441 = $440;
   HEAP32[$441>>2] = $439;
   $442 = (($440) + 4)|0;
   $443 = $442;
   HEAP32[$443>>2] = $6;
   $444 = HEAP32[$builder>>2]|0;
   $445 = ($9>>>0)>($444>>>0);
   if ($445) {
    $446 = (($builder) + 28|0);
    $447 = HEAP32[$446>>2]|0;
    $448 = (($447) + 1)|0;
    HEAP32[$446>>2] = $448;
    $449 = (_bitshift64Lshr(($3|0),($6|0),3)|0);
    $450 = tempRet0;
    $451 = $449 & 262143;
    $454 = $439;$455 = $6;$NbPos$2 = $451;
    break;
   } else {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $452 = (($builder) + 12|0);
 $453 = HEAP32[$452>>2]|0;
 $456 = (_bitshift64Lshr(($454|0),($455|0),21)|0);
 $457 = tempRet0;
 $458 = $456 & 524287;
 $459 = (($builder) + 24|0);
 $460 = HEAP32[$459>>2]|0;
 $461 = $454 & 2097150;
 $462 = $455 & -256;
 $463 = (_bitshift64Shl(($460|0),0,21)|0);
 $464 = tempRet0;
 $465 = $463 | $461;
 $466 = $464 | $462;
 $467 = $0;
 $468 = $467;
 HEAP32[$468>>2] = $465;
 $469 = (($467) + 4)|0;
 $470 = $469;
 HEAP32[$470>>2] = $466;
 $471 = (($460) + 2)|0;
 HEAP32[$459>>2] = $471;
 $472 = $460 & 524287;
 $473 = ($472|0)==(0);
 $$sum$i = (($472) + 1)|0;
 $474 = (($453) + (($$sum$i*24)|0)|0);
 $475 = $473 ? $453 : $474;
 $476 = ((($453) + (($472*24)|0)|0) + 16|0);
 $477 = $476;
 $478 = $477;
 $479 = HEAP32[$478>>2]|0;
 $480 = (($477) + 4)|0;
 $481 = $480;
 $482 = HEAP32[$481>>2]|0;
 $483 = $482 & -256;
 $484 = (_bitshift64Shl(($458|0),0,21)|0);
 $485 = tempRet0;
 $486 = (_bitshift64Shl(($NbPos$2|0),0,2)|0);
 $487 = tempRet0;
 $488 = (_bitshift64Shl(($NbPos$2|0),0,1)|0);
 $489 = tempRet0;
 $490 = $488 & 2;
 $491 = $486 | $490;
 $492 = $491 | $484;
 $493 = $487 | $485;
 $494 = $493 | $483;
 $495 = $492 | 1;
 $496 = $476;
 $497 = $496;
 HEAP32[$497>>2] = $495;
 $498 = (($496) + 4)|0;
 $499 = $498;
 HEAP32[$499>>2] = $494;
 $500 = (($458) + ($NbPos$2))|0;
 $501 = (($475) + 16|0);
 $502 = $501;
 $503 = $502;
 $504 = HEAP32[$503>>2]|0;
 $505 = (($502) + 4)|0;
 $506 = $505;
 $507 = HEAP32[$506>>2]|0;
 $508 = $504 & 2097151;
 $509 = $507 & -256;
 $510 = (_bitshift64Shl(($500|0),0,21)|0);
 $511 = tempRet0;
 $512 = $508 | $510;
 $513 = $509 | $511;
 $514 = $501;
 $515 = $514;
 HEAP32[$515>>2] = $512;
 $516 = (($514) + 4)|0;
 $517 = $516;
 HEAP32[$517>>2] = $513;
 $518 = $0;
 $519 = $518;
 $520 = HEAP32[$519>>2]|0;
 $521 = (($518) + 4)|0;
 $522 = $521;
 $523 = HEAP32[$522>>2]|0;
 $524 = (_bitshift64Lshr(($520|0),($523|0),2)|0);
 $525 = tempRet0;
 $526 = $524 & 524287;
 $527 = (($526) - ($NbPos$2))|0;
 $528 = $512 & -2097152;
 $529 = (_bitshift64Shl(($527|0),0,2)|0);
 $530 = tempRet0;
 $531 = (_bitshift64Shl(($527|0),0,1)|0);
 $532 = tempRet0;
 $533 = $531 & 2;
 $534 = $528 | $529;
 $535 = $513 | $530;
 $536 = $534 | $533;
 $537 = $536 | 1;
 $538 = $501;
 $539 = $538;
 HEAP32[$539>>2] = $537;
 $540 = (($538) + 4)|0;
 $541 = $540;
 HEAP32[$541>>2] = $535;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayINS_2Sq10FIFOStack213NodeAndParentENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 507080 : 506712;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,507000,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx2Sq17AABBTreeUpdateMap7initMapEjRKNS0_8AABBTreeE($this,$nbObjects,$tree) {
 $this = $this|0;
 $nbObjects = $nbObjects|0;
 $tree = $tree|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currentCapacity$0 = 0, $exitcond = 0, $i1$04 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($nbObjects|0)==(0);
 if ($1) {
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($this,0,$0);
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($this,$3);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = $nbObjects >>> 2;
 $8 = (($7) + ($nbObjects))|0;
 $9 = $6 >>> 1;
 $10 = ($8>>>0)<($9>>>0);
 $11 = (($6) - ($8))|0;
 $12 = ($11>>>0)>(1024);
 $or$cond = $10 & $12;
 $currentCapacity$0 = $or$cond ? 0 : $6;
 $13 = ($currentCapacity$0>>>0)<($nbObjects>>>0);
 if ($13) {
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($this,0,$0);
  $14 = (($this) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($this,$15);
  $16 = HEAP32[$4>>2]|0;
  $17 = $16 & 2147483647;
  $18 = ($17>>>0)<($8>>>0);
  if ($18) {
   __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($this,$8);
   $$pre$phiZ2D = $14;
  } else {
   $$pre$phiZ2D = $14;
  }
 } else {
  $$pre = (($this) + 4|0);
  $$pre$phiZ2D = $$pre;
 }
 HEAP32[$$pre$phiZ2D>>2] = $nbObjects;
 $19 = HEAP32[$this>>2]|0;
 $20 = $nbObjects << 2;
 _memset(($19|0),-1,($20|0))|0;
 $21 = (($tree) + 536|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($tree) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $i1$04 = 0;
 while(1) {
  $26 = ((($24) + (($i1$04*24)|0)|0) + 16|0);
  $27 = $26;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 4)|0;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = $29 & 1;
  $34 = ($33|0)==(0);
  $35 = (0)==(0);
  $36 = $34 & $35;
  if (!($36)) {
   $37 = HEAP32[$tree>>2]|0;
   $38 = (_bitshift64Lshr(($29|0),($32|0),21)|0);
   $39 = tempRet0;
   $40 = $38 & 524287;
   $41 = (($37) + ($40<<2)|0);
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    $43 = HEAP32[$41>>2]|0;
    $44 = HEAP32[$this>>2]|0;
    $45 = (($44) + ($43<<2)|0);
    HEAP32[$45>>2] = $i1$04;
   }
  }
  $46 = (($i1$04) + 1)|0;
  $exitcond = ($46|0)==($22|0);
  if ($exitcond) {
   break;
  } else {
   $i1$04 = $46;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17AABBTreeUpdateMap10invalidateEjjRNS0_8AABBTreeE($this,$prunerIndex0,$prunerIndex1,$tree) {
 $this = $this|0;
 $prunerIndex0 = $prunerIndex0|0;
 $prunerIndex1 = $prunerIndex1|0;
 $tree = $tree|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($prunerIndex0>>>0);
 if ($2) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + ($prunerIndex0<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $13 = $5;
 } else {
  $13 = -1;
 }
 $6 = ($1>>>0)>($prunerIndex1>>>0);
 if ($6) {
  $7 = HEAP32[$this>>2]|0;
  $8 = (($7) + ($prunerIndex1<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $34 = $9;
 } else {
  $34 = -1;
 }
 $10 = (($tree) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($13|0)==(-1);
 if (!($12)) {
  $14 = HEAP32[$tree>>2]|0;
  $15 = ((($11) + (($13*24)|0)|0) + 16|0);
  $16 = $15;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) + 4)|0;
  $20 = $19;
  $21 = HEAP32[$20>>2]|0;
  $22 = (_bitshift64Lshr(($18|0),($21|0),21)|0);
  $23 = tempRet0;
  $24 = $22 & 524287;
  $25 = (($14) + ($24<<2)|0);
  $26 = $18 & -3;
  $27 = $15;
  $28 = $27;
  HEAP32[$28>>2] = $26;
  $29 = (($27) + 4)|0;
  $30 = $29;
  HEAP32[$30>>2] = $21;
  HEAP32[$25>>2] = -1;
  $31 = HEAP32[$this>>2]|0;
  $32 = (($31) + ($prunerIndex0<<2)|0);
  HEAP32[$32>>2] = -1;
 }
 $33 = ($34|0)==(-1);
 $35 = ($13|0)==($34|0);
 $or$cond = $33 | $35;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$tree>>2]|0;
 $37 = ((($11) + (($34*24)|0)|0) + 16|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = (_bitshift64Lshr(($40|0),($43|0),21)|0);
 $45 = tempRet0;
 $46 = $44 & 524287;
 $47 = (($36) + ($46<<2)|0);
 HEAP32[$47>>2] = $prunerIndex0;
 $48 = HEAP32[$this>>2]|0;
 $49 = (($48) + ($prunerIndex0<<2)|0);
 HEAP32[$49>>2] = $34;
 $50 = (($48) + ($prunerIndex1<<2)|0);
 HEAP32[$50>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq16BucketPrunerNode13classifyBoxesEffjPNS0_9BucketBoxEPKNS0_13PrunerPayloadES3_PS4_bj($this,$limitX,$limitYZ,$nb,$boxes,$objects,$sortedBoxes,$sortedObjects,$isCrossBucket,$sortAxis) {
 $this = $this|0;
 $limitX = Math_fround($limitX);
 $limitYZ = Math_fround($limitYZ);
 $nb = $nb|0;
 $boxes = $boxes|0;
 $objects = $objects|0;
 $sortedBoxes = $sortedBoxes|0;
 $sortedObjects = $sortedObjects|0;
 $isCrossBucket = $isCrossBucket|0;
 $sortAxis = $sortAxis|0;
 var $$$i = Math_fround(0), $$$i36 = Math_fround(0), $$1$i = Math_fround(0), $$1$i37 = Math_fround(0), $$phi$trans$insert241 = 0, $$phi$trans$insert243 = 0, $$phi$trans$insert245 = 0, $$pre = 0, $$pre$phi254Z2D = 0, $$pre$phi256Z2D = 0, $$pre$phi258Z2D = 0, $$pre$phiZ2D = 0, $$pre242 = 0, $$pre244 = 0, $$pre246 = 0, $$pre247 = 0, $$pre248 = 0, $$pre249 = 0, $$pre250 = 0, $$pre253 = 0;
 var $$pre255 = 0, $$pre257 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0);
 var $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0;
 var $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $bucketBoxMax = 0, $bucketBoxMin = 0, $exitcond = 0, $exitcond236 = 0;
 var $exitcond238 = 0, $i1$0230 = 0, $i3$0227 = 0, $i5$0224 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $bucketBoxMin = sp + 80|0;
 $bucketBoxMax = sp;
 $0 = ($sortAxis|0)==(1);
 $1 = $0 ? 2 : 1;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 HEAPF32[$bucketBoxMin>>2] = Math_fround(8.50705866596322149529E+37);
 $2 = (($bucketBoxMin) + 4|0);
 HEAPF32[$2>>2] = Math_fround(8.50705866596322149529E+37);
 $3 = (($bucketBoxMin) + 8|0);
 HEAPF32[$3>>2] = Math_fround(8.50705866596322149529E+37);
 $4 = (($bucketBoxMin) + 12|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 HEAPF32[$bucketBoxMax>>2] = Math_fround(-8.50705866596322149529E+37);
 $5 = (($bucketBoxMax) + 4|0);
 HEAPF32[$5>>2] = Math_fround(-8.50705866596322149529E+37);
 $6 = (($bucketBoxMax) + 8|0);
 HEAPF32[$6>>2] = Math_fround(-8.50705866596322149529E+37);
 $7 = (($bucketBoxMax) + 12|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($bucketBoxMin) + 16|0);
 HEAPF32[$8>>2] = Math_fround(8.50705866596322149529E+37);
 $9 = (($bucketBoxMin) + 20|0);
 HEAPF32[$9>>2] = Math_fround(8.50705866596322149529E+37);
 $10 = (($bucketBoxMin) + 24|0);
 HEAPF32[$10>>2] = Math_fround(8.50705866596322149529E+37);
 $11 = (($bucketBoxMin) + 28|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($bucketBoxMax) + 16|0);
 HEAPF32[$12>>2] = Math_fround(-8.50705866596322149529E+37);
 $13 = (($bucketBoxMax) + 20|0);
 HEAPF32[$13>>2] = Math_fround(-8.50705866596322149529E+37);
 $14 = (($bucketBoxMax) + 24|0);
 HEAPF32[$14>>2] = Math_fround(-8.50705866596322149529E+37);
 $15 = (($bucketBoxMax) + 28|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($bucketBoxMin) + 32|0);
 HEAPF32[$16>>2] = Math_fround(8.50705866596322149529E+37);
 $17 = (($bucketBoxMin) + 36|0);
 HEAPF32[$17>>2] = Math_fround(8.50705866596322149529E+37);
 $18 = (($bucketBoxMin) + 40|0);
 HEAPF32[$18>>2] = Math_fround(8.50705866596322149529E+37);
 $19 = (($bucketBoxMin) + 44|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($bucketBoxMax) + 32|0);
 HEAPF32[$20>>2] = Math_fround(-8.50705866596322149529E+37);
 $21 = (($bucketBoxMax) + 36|0);
 HEAPF32[$21>>2] = Math_fround(-8.50705866596322149529E+37);
 $22 = (($bucketBoxMax) + 40|0);
 HEAPF32[$22>>2] = Math_fround(-8.50705866596322149529E+37);
 $23 = (($bucketBoxMax) + 44|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($bucketBoxMin) + 48|0);
 HEAPF32[$24>>2] = Math_fround(8.50705866596322149529E+37);
 $25 = (($bucketBoxMin) + 52|0);
 HEAPF32[$25>>2] = Math_fround(8.50705866596322149529E+37);
 $26 = (($bucketBoxMin) + 56|0);
 HEAPF32[$26>>2] = Math_fround(8.50705866596322149529E+37);
 $27 = (($bucketBoxMin) + 60|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($bucketBoxMax) + 48|0);
 HEAPF32[$28>>2] = Math_fround(-8.50705866596322149529E+37);
 $29 = (($bucketBoxMax) + 52|0);
 HEAPF32[$29>>2] = Math_fround(-8.50705866596322149529E+37);
 $30 = (($bucketBoxMax) + 56|0);
 HEAPF32[$30>>2] = Math_fround(-8.50705866596322149529E+37);
 $31 = (($bucketBoxMax) + 60|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($bucketBoxMin) + 64|0);
 HEAPF32[$32>>2] = Math_fround(8.50705866596322149529E+37);
 $33 = (($bucketBoxMin) + 68|0);
 HEAPF32[$33>>2] = Math_fround(8.50705866596322149529E+37);
 $34 = (($bucketBoxMin) + 72|0);
 HEAPF32[$34>>2] = Math_fround(8.50705866596322149529E+37);
 $35 = (($bucketBoxMin) + 76|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($bucketBoxMax) + 64|0);
 HEAPF32[$36>>2] = Math_fround(-8.50705866596322149529E+37);
 $37 = (($bucketBoxMax) + 68|0);
 HEAPF32[$37>>2] = Math_fround(-8.50705866596322149529E+37);
 $38 = (($bucketBoxMax) + 72|0);
 HEAPF32[$38>>2] = Math_fround(-8.50705866596322149529E+37);
 $39 = (($bucketBoxMax) + 76|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = ($nb|0)==(0);
 if ($40) {
  $$pre253 = (($this) + 4|0);
  $$pre255 = (($this) + 8|0);
  $$pre257 = (($this) + 12|0);
  $$pre$phi254Z2D = $$pre253;$$pre$phi256Z2D = $$pre255;$$pre$phi258Z2D = $$pre257;$$pre$phiZ2D = $this;$125 = 0;$127 = 0;$130 = 0;$133 = 0;
 } else {
  $41 = $isCrossBucket ? 16 : 0;
  $i1$0230 = 0;
  while(1) {
   $42 = (($boxes) + ($i1$0230<<5)|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = (($42) + 4|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = (($42) + 8|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = (($42) + 12|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = ((($boxes) + ($i1$0230<<5)|0) + 16|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = (($50) + 4|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = (($50) + 8|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = (($50) + 12|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround($43 - $51);
   $59 = Math_fround($45 - $53);
   $60 = Math_fround($47 - $55);
   $61 = Math_fround($49 - $57);
   $62 = Math_fround($43 + $51);
   $63 = Math_fround($45 + $53);
   $64 = Math_fround($47 + $55);
   $65 = Math_fround($49 + $57);
   $66 = (($42) + ($1<<2)|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = (($50) + ($1<<2)|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($67 + $69);
   $71 = $70 < $limitYZ;
   $72 = Math_fround($67 - $69);
   $73 = $72 > $limitYZ;
   $74 = $62 < $limitX;
   $75 = $58 > $limitX;
   $76 = $75&1;
   $77 = $74&1;
   $78 = $77 << 1;
   $79 = $73&1;
   $80 = $79 << 2;
   $81 = $71&1;
   $82 = $81 << 3;
   $83 = $80 | $41;
   $84 = $83 | $82;
   $85 = $84 | $76;
   $86 = $85 | $78;
   $87 = (507464 + ($86)|0);
   $88 = HEAP8[$87>>0]|0;
   $89 = $88&255;
   $90 = (($bucketBoxMin) + ($89<<4)|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = (($90) + 4|0);
   $93 = Math_fround(HEAPF32[$92>>2]);
   $94 = (($90) + 8|0);
   $95 = Math_fround(HEAPF32[$94>>2]);
   $96 = (($90) + 12|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = $91 < $58;
   $$$i36 = $98 ? $91 : $58;
   $99 = $93 < $59;
   $100 = $99 ? $93 : $59;
   $101 = $95 < $60;
   $$1$i37 = $101 ? $95 : $60;
   $102 = $97 < $61;
   $103 = $102 ? $97 : $61;
   $104 = (($bucketBoxMax) + ($89<<4)|0);
   $105 = Math_fround(HEAPF32[$104>>2]);
   $106 = (($104) + 4|0);
   $107 = Math_fround(HEAPF32[$106>>2]);
   $108 = (($104) + 8|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = (($104) + 12|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = $105 > $62;
   $$$i = $112 ? $105 : $62;
   $113 = $107 > $63;
   $114 = $113 ? $107 : $63;
   $115 = $109 > $64;
   $$1$i = $115 ? $109 : $64;
   $116 = $111 > $65;
   $117 = $116 ? $111 : $65;
   HEAPF32[$90>>2] = $$$i36;
   HEAPF32[$92>>2] = $100;
   HEAPF32[$94>>2] = $$1$i37;
   HEAPF32[$96>>2] = $103;
   HEAPF32[$104>>2] = $$$i;
   HEAPF32[$106>>2] = $114;
   HEAPF32[$108>>2] = $$1$i;
   HEAPF32[$110>>2] = $117;
   $118 = ((($boxes) + ($i1$0230<<5)|0) + 12|0);
   HEAP32[$118>>2] = $89;
   $119 = (($this) + ($89<<2)|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = (($120) + 1)|0;
   HEAP32[$119>>2] = $121;
   $122 = (($i1$0230) + 1)|0;
   $exitcond238 = ($122|0)==($nb|0);
   if ($exitcond238) {
    break;
   } else {
    $i1$0230 = $122;
   }
  }
  $$pre = HEAP32[$this>>2]|0;
  $$phi$trans$insert241 = (($this) + 4|0);
  $$pre242 = HEAP32[$$phi$trans$insert241>>2]|0;
  $$phi$trans$insert243 = (($this) + 8|0);
  $$pre244 = HEAP32[$$phi$trans$insert243>>2]|0;
  $$phi$trans$insert245 = (($this) + 12|0);
  $$pre246 = HEAP32[$$phi$trans$insert245>>2]|0;
  $$pre$phi254Z2D = $$phi$trans$insert241;$$pre$phi256Z2D = $$phi$trans$insert243;$$pre$phi258Z2D = $$phi$trans$insert245;$$pre$phiZ2D = $this;$125 = $$pre;$127 = $$pre242;$130 = $$pre244;$133 = $$pre246;
 }
 $123 = (($this) + 20|0);
 HEAP32[$123>>2] = 0;
 $124 = (($this) + 24|0);
 HEAP32[$124>>2] = $125;
 $126 = (($127) + ($125))|0;
 $128 = (($this) + 28|0);
 HEAP32[$128>>2] = $126;
 $129 = (($130) + ($126))|0;
 $131 = (($this) + 32|0);
 HEAP32[$131>>2] = $129;
 $132 = (($133) + ($129))|0;
 $134 = (($this) + 36|0);
 HEAP32[$134>>2] = $132;
 if ($40) {
  $176 = $125;$178 = $127;$180 = $130;$182 = $133;
 } else {
  $i3$0227 = 0;
  while(1) {
   $135 = ((($boxes) + ($i3$0227<<5)|0) + 12|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ((($this) + ($136<<2)|0) + 20|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = (($138) + 1)|0;
   HEAP32[$137>>2] = $139;
   $140 = (($boxes) + ($i3$0227<<5)|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = (($140) + 4|0);
   $143 = Math_fround(HEAPF32[$142>>2]);
   $144 = (($140) + 8|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = (HEAP32[tempDoublePtr>>2]=$136,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $147 = (($sortedBoxes) + ($138<<5)|0);
   HEAPF32[$147>>2] = $141;
   $148 = (($147) + 4|0);
   HEAPF32[$148>>2] = $143;
   $149 = (($147) + 8|0);
   HEAPF32[$149>>2] = $145;
   $150 = (($147) + 12|0);
   HEAPF32[$150>>2] = $146;
   $151 = ((($boxes) + ($i3$0227<<5)|0) + 16|0);
   $152 = Math_fround(HEAPF32[$151>>2]);
   $153 = (($151) + 4|0);
   $154 = Math_fround(HEAPF32[$153>>2]);
   $155 = (($151) + 8|0);
   $156 = Math_fround(HEAPF32[$155>>2]);
   $157 = (($151) + 12|0);
   $158 = Math_fround(HEAPF32[$157>>2]);
   $159 = ((($sortedBoxes) + ($138<<5)|0) + 16|0);
   HEAPF32[$159>>2] = $152;
   $160 = (($159) + 4|0);
   HEAPF32[$160>>2] = $154;
   $161 = (($159) + 8|0);
   HEAPF32[$161>>2] = $156;
   $162 = (($159) + 12|0);
   HEAPF32[$162>>2] = $158;
   $163 = (($sortedObjects) + ($138<<3)|0);
   $164 = (($objects) + ($i3$0227<<3)|0);
   $165 = $164;
   $166 = $165;
   $167 = HEAP32[$166>>2]|0;
   $168 = (($165) + 4)|0;
   $169 = $168;
   $170 = HEAP32[$169>>2]|0;
   $171 = $163;
   $172 = $171;
   HEAP32[$172>>2] = $167;
   $173 = (($171) + 4)|0;
   $174 = $173;
   HEAP32[$174>>2] = $170;
   $175 = (($i3$0227) + 1)|0;
   $exitcond236 = ($175|0)==($nb|0);
   if ($exitcond236) {
    break;
   } else {
    $i3$0227 = $175;
   }
  }
  $$pre247 = HEAP32[$$pre$phiZ2D>>2]|0;
  $$pre248 = HEAP32[$$pre$phi254Z2D>>2]|0;
  $$pre249 = HEAP32[$$pre$phi256Z2D>>2]|0;
  $$pre250 = HEAP32[$$pre$phi258Z2D>>2]|0;
  $176 = $$pre247;$178 = $$pre248;$180 = $$pre249;$182 = $$pre250;
 }
 HEAP32[$123>>2] = 0;
 HEAP32[$124>>2] = $176;
 $177 = (($178) + ($176))|0;
 HEAP32[$128>>2] = $177;
 $179 = (($180) + ($177))|0;
 HEAP32[$131>>2] = $179;
 $181 = (($182) + ($179))|0;
 HEAP32[$134>>2] = $181;
 $i5$0224 = 0;
 while(1) {
  $183 = (($bucketBoxMin) + ($i5$0224<<4)|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = (($183) + 4|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = (($183) + 8|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = (($bucketBoxMax) + ($i5$0224<<4)|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($189) + 4|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = (($189) + 8|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = Math_fround($184 + $190);
  $196 = Math_fround($186 + $192);
  $197 = Math_fround($188 + $194);
  $198 = Math_fround($195 * Math_fround(0.5));
  $199 = Math_fround($196 * Math_fround(0.5));
  $200 = Math_fround($197 * Math_fround(0.5));
  $201 = Math_fround($190 - $184);
  $202 = Math_fround($192 - $186);
  $203 = Math_fround($194 - $188);
  $204 = Math_fround($201 * Math_fround(0.5));
  $205 = Math_fround($202 * Math_fround(0.5));
  $206 = Math_fround($203 * Math_fround(0.5));
  $207 = ((($this) + ($i5$0224<<5)|0) + 48|0);
  HEAPF32[$207>>2] = $198;
  $208 = ((($this) + ($i5$0224<<5)|0) + 52|0);
  HEAPF32[$208>>2] = $199;
  $209 = ((($this) + ($i5$0224<<5)|0) + 56|0);
  HEAPF32[$209>>2] = $200;
  $210 = ((($this) + ($i5$0224<<5)|0) + 64|0);
  HEAPF32[$210>>2] = $204;
  $211 = ((($this) + ($i5$0224<<5)|0) + 68|0);
  HEAPF32[$211>>2] = $205;
  $212 = ((($this) + ($i5$0224<<5)|0) + 72|0);
  HEAPF32[$212>>2] = $206;
  $213 = (($i5$0224) + 1)|0;
  $exitcond = ($213|0)==(5);
  if ($exitcond) {
   break;
  } else {
   $i5$0224 = $213;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sq16BucketPrunerCoreC2Eb($this,$externalMemory) {
 $this = $this|0;
 $externalMemory = $externalMemory|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 544|0);
 $1 = (($this) + 568|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
 HEAPF32[$1>>2] = Math_fround(0.75);
 $2 = (($this) + 572|0);
 HEAP32[$2>>2] = -1;
 $3 = (($this) + 576|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 580|0);
 HEAP32[$4>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS_2Sq13PrunerPayloadEjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE15reserveInternalEj($0,64);
 $5 = (($this) + 584|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 588|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 592|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 688|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 692|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 696|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 704|0);
 HEAPF32[$11>>2] = Math_fround(-8.50705866596322149529E+37);
 $12 = (($this) + 708|0);
 HEAPF32[$12>>2] = Math_fround(-8.50705866596322149529E+37);
 $13 = (($this) + 712|0);
 HEAPF32[$13>>2] = Math_fround(-8.50705866596322149529E+37);
 $14 = (($this) + 720|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($this) + 724|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 728|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 736|0);
 HEAPF32[$17>>2] = Math_fround(-8.50705866596322149529E+37);
 $18 = (($this) + 740|0);
 HEAPF32[$18>>2] = Math_fround(-8.50705866596322149529E+37);
 $19 = (($this) + 744|0);
 HEAPF32[$19>>2] = Math_fround(-8.50705866596322149529E+37);
 $20 = (($this) + 752|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($this) + 756|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($this) + 760|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 768|0);
 HEAPF32[$23>>2] = Math_fround(-8.50705866596322149529E+37);
 $24 = (($this) + 772|0);
 HEAPF32[$24>>2] = Math_fround(-8.50705866596322149529E+37);
 $25 = (($this) + 776|0);
 HEAPF32[$25>>2] = Math_fround(-8.50705866596322149529E+37);
 $26 = (($this) + 784|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 788|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 792|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($this) + 800|0);
 HEAPF32[$29>>2] = Math_fround(-8.50705866596322149529E+37);
 $30 = (($this) + 804|0);
 HEAPF32[$30>>2] = Math_fround(-8.50705866596322149529E+37);
 $31 = (($this) + 808|0);
 HEAPF32[$31>>2] = Math_fround(-8.50705866596322149529E+37);
 $32 = (($this) + 816|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($this) + 820|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($this) + 824|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($this) + 832|0);
 HEAPF32[$35>>2] = Math_fround(-8.50705866596322149529E+37);
 $36 = (($this) + 836|0);
 HEAPF32[$36>>2] = Math_fround(-8.50705866596322149529E+37);
 $37 = (($this) + 840|0);
 HEAPF32[$37>>2] = Math_fround(-8.50705866596322149529E+37);
 $38 = (($this) + 864|0);
 $39 = (($this) + 1984|0);
 $41 = $38;
 while(1) {
  $40 = (($41) + 48|0);
  HEAPF32[$40>>2] = Math_fround(0.0);
  $42 = (($41) + 52|0);
  HEAPF32[$42>>2] = Math_fround(0.0);
  $43 = (($41) + 56|0);
  HEAPF32[$43>>2] = Math_fround(0.0);
  $44 = (($41) + 64|0);
  HEAPF32[$44>>2] = Math_fround(-8.50705866596322149529E+37);
  $45 = (($41) + 68|0);
  HEAPF32[$45>>2] = Math_fround(-8.50705866596322149529E+37);
  $46 = (($41) + 72|0);
  HEAPF32[$46>>2] = Math_fround(-8.50705866596322149529E+37);
  $47 = (($41) + 80|0);
  HEAPF32[$47>>2] = Math_fround(0.0);
  $48 = (($41) + 84|0);
  HEAPF32[$48>>2] = Math_fround(0.0);
  $49 = (($41) + 88|0);
  HEAPF32[$49>>2] = Math_fround(0.0);
  $50 = (($41) + 96|0);
  HEAPF32[$50>>2] = Math_fround(-8.50705866596322149529E+37);
  $51 = (($41) + 100|0);
  HEAPF32[$51>>2] = Math_fround(-8.50705866596322149529E+37);
  $52 = (($41) + 104|0);
  HEAPF32[$52>>2] = Math_fround(-8.50705866596322149529E+37);
  $53 = (($41) + 112|0);
  HEAPF32[$53>>2] = Math_fround(0.0);
  $54 = (($41) + 116|0);
  HEAPF32[$54>>2] = Math_fround(0.0);
  $55 = (($41) + 120|0);
  HEAPF32[$55>>2] = Math_fround(0.0);
  $56 = (($41) + 128|0);
  HEAPF32[$56>>2] = Math_fround(-8.50705866596322149529E+37);
  $57 = (($41) + 132|0);
  HEAPF32[$57>>2] = Math_fround(-8.50705866596322149529E+37);
  $58 = (($41) + 136|0);
  HEAPF32[$58>>2] = Math_fround(-8.50705866596322149529E+37);
  $59 = (($41) + 144|0);
  HEAPF32[$59>>2] = Math_fround(0.0);
  $60 = (($41) + 148|0);
  HEAPF32[$60>>2] = Math_fround(0.0);
  $61 = (($41) + 152|0);
  HEAPF32[$61>>2] = Math_fround(0.0);
  $62 = (($41) + 160|0);
  HEAPF32[$62>>2] = Math_fround(-8.50705866596322149529E+37);
  $63 = (($41) + 164|0);
  HEAPF32[$63>>2] = Math_fround(-8.50705866596322149529E+37);
  $64 = (($41) + 168|0);
  HEAPF32[$64>>2] = Math_fround(-8.50705866596322149529E+37);
  $65 = (($41) + 176|0);
  HEAPF32[$65>>2] = Math_fround(0.0);
  $66 = (($41) + 180|0);
  HEAPF32[$66>>2] = Math_fround(0.0);
  $67 = (($41) + 184|0);
  HEAPF32[$67>>2] = Math_fround(0.0);
  $68 = (($41) + 192|0);
  HEAPF32[$68>>2] = Math_fround(-8.50705866596322149529E+37);
  $69 = (($41) + 196|0);
  HEAPF32[$69>>2] = Math_fround(-8.50705866596322149529E+37);
  $70 = (($41) + 200|0);
  HEAPF32[$70>>2] = Math_fround(-8.50705866596322149529E+37);
  $71 = (($41) + 224|0);
  $72 = ($71|0)==($39|0);
  if ($72) {
   break;
  } else {
   $41 = $71;
  }
 }
 $73 = (($this) + 640|0);
 $74 = (($this) + 1984|0);
 $75 = (($this) + 7584|0);
 $77 = $74;
 while(1) {
  $76 = (($77) + 48|0);
  HEAPF32[$76>>2] = Math_fround(0.0);
  $78 = (($77) + 52|0);
  HEAPF32[$78>>2] = Math_fround(0.0);
  $79 = (($77) + 56|0);
  HEAPF32[$79>>2] = Math_fround(0.0);
  $80 = (($77) + 64|0);
  HEAPF32[$80>>2] = Math_fround(-8.50705866596322149529E+37);
  $81 = (($77) + 68|0);
  HEAPF32[$81>>2] = Math_fround(-8.50705866596322149529E+37);
  $82 = (($77) + 72|0);
  HEAPF32[$82>>2] = Math_fround(-8.50705866596322149529E+37);
  $83 = (($77) + 80|0);
  HEAPF32[$83>>2] = Math_fround(0.0);
  $84 = (($77) + 84|0);
  HEAPF32[$84>>2] = Math_fround(0.0);
  $85 = (($77) + 88|0);
  HEAPF32[$85>>2] = Math_fround(0.0);
  $86 = (($77) + 96|0);
  HEAPF32[$86>>2] = Math_fround(-8.50705866596322149529E+37);
  $87 = (($77) + 100|0);
  HEAPF32[$87>>2] = Math_fround(-8.50705866596322149529E+37);
  $88 = (($77) + 104|0);
  HEAPF32[$88>>2] = Math_fround(-8.50705866596322149529E+37);
  $89 = (($77) + 112|0);
  HEAPF32[$89>>2] = Math_fround(0.0);
  $90 = (($77) + 116|0);
  HEAPF32[$90>>2] = Math_fround(0.0);
  $91 = (($77) + 120|0);
  HEAPF32[$91>>2] = Math_fround(0.0);
  $92 = (($77) + 128|0);
  HEAPF32[$92>>2] = Math_fround(-8.50705866596322149529E+37);
  $93 = (($77) + 132|0);
  HEAPF32[$93>>2] = Math_fround(-8.50705866596322149529E+37);
  $94 = (($77) + 136|0);
  HEAPF32[$94>>2] = Math_fround(-8.50705866596322149529E+37);
  $95 = (($77) + 144|0);
  HEAPF32[$95>>2] = Math_fround(0.0);
  $96 = (($77) + 148|0);
  HEAPF32[$96>>2] = Math_fround(0.0);
  $97 = (($77) + 152|0);
  HEAPF32[$97>>2] = Math_fround(0.0);
  $98 = (($77) + 160|0);
  HEAPF32[$98>>2] = Math_fround(-8.50705866596322149529E+37);
  $99 = (($77) + 164|0);
  HEAPF32[$99>>2] = Math_fround(-8.50705866596322149529E+37);
  $100 = (($77) + 168|0);
  HEAPF32[$100>>2] = Math_fround(-8.50705866596322149529E+37);
  $101 = (($77) + 176|0);
  HEAPF32[$101>>2] = Math_fround(0.0);
  $102 = (($77) + 180|0);
  HEAPF32[$102>>2] = Math_fround(0.0);
  $103 = (($77) + 184|0);
  HEAPF32[$103>>2] = Math_fround(0.0);
  $104 = (($77) + 192|0);
  HEAPF32[$104>>2] = Math_fround(-8.50705866596322149529E+37);
  $105 = (($77) + 196|0);
  HEAPF32[$105>>2] = Math_fround(-8.50705866596322149529E+37);
  $106 = (($77) + 200|0);
  HEAPF32[$106>>2] = Math_fround(-8.50705866596322149529E+37);
  $107 = (($77) + 224|0);
  $108 = ($107|0)==($75|0);
  if ($108) {
   break;
  } else {
   $77 = $107;
  }
 }
 $109 = (($this) + 7584|0);
 HEAP8[$109>>0] = 1;
 $110 = (($this) + 7585|0);
 $111 = $externalMemory&1;
 $112 = $111 ^ 1;
 HEAP8[$110>>0] = $112;
 $113 = (($this) + 608|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = (($this) + 612|0);
 HEAPF32[$114>>2] = Math_fround(0.0);
 $115 = (($this) + 616|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = (($this) + 624|0);
 HEAPF32[$116>>2] = Math_fround(-8.50705866596322149529E+37);
 $117 = (($this) + 628|0);
 HEAPF32[$117>>2] = Math_fround(-8.50705866596322149529E+37);
 $118 = (($this) + 632|0);
 HEAPF32[$118>>2] = Math_fround(-8.50705866596322149529E+37);
 dest=$73+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$38+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $119 = (($this) + 1088|0);
 dest=$119+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $120 = (($this) + 1312|0);
 dest=$120+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $121 = (($this) + 1536|0);
 dest=$121+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $122 = (($this) + 1760|0);
 dest=$122+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$74+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $123 = (($this) + 2208|0);
 dest=$123+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $124 = (($this) + 2432|0);
 dest=$124+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $125 = (($this) + 2656|0);
 dest=$125+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $126 = (($this) + 2880|0);
 dest=$126+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $127 = (($this) + 3104|0);
 dest=$127+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $128 = (($this) + 3328|0);
 dest=$128+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $129 = (($this) + 3552|0);
 dest=$129+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $130 = (($this) + 3776|0);
 dest=$130+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $131 = (($this) + 4000|0);
 dest=$131+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $132 = (($this) + 4224|0);
 dest=$132+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $133 = (($this) + 4448|0);
 dest=$133+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $134 = (($this) + 4672|0);
 dest=$134+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $135 = (($this) + 4896|0);
 dest=$135+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $136 = (($this) + 5120|0);
 dest=$136+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $137 = (($this) + 5344|0);
 dest=$137+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $138 = (($this) + 5568|0);
 dest=$138+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $139 = (($this) + 5792|0);
 dest=$139+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $140 = (($this) + 6016|0);
 dest=$140+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $141 = (($this) + 6240|0);
 dest=$141+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $142 = (($this) + 6464|0);
 dest=$142+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $143 = (($this) + 6688|0);
 dest=$143+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $144 = (($this) + 6912|0);
 dest=$144+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $145 = (($this) + 7136|0);
 dest=$145+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $146 = (($this) + 7360|0);
 dest=$146+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Sq16BucketPrunerCoreD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Sq16BucketPrunerCore7releaseEv($this);
 $0 = (($this) + 544|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq16BucketPrunerCore7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = (($this) + 7584|0);
 HEAP8[$5>>0] = 1;
 HEAP32[$this>>2] = 0;
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 7585|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
  HEAP32[$10>>2] = 0;
  $12 = (($this) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$13);
  HEAP32[$12>>2] = 0;
  $14 = (($this) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$15);
  HEAP32[$14>>2] = 0;
 }
 $16 = (($this) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$17);
 HEAP32[$16>>2] = 0;
 $18 = (($this) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$19);
 HEAP32[$18>>2] = 0;
 $20 = (($this) + 584|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 588|0);
 HEAP32[$21>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq16BucketPrunerCore20allocateSortedMemoryEj($this,$nb) {
 $this = $this|0;
 $nb = $nb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = (($this) + 584|0);
 HEAP32[$4>>2] = $nb;
 $5 = (($this) + 588|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6>>>0)<($nb>>>0);
 $8 = $6 >>> 1;
 $9 = ($8>>>0)>($nb>>>0);
 $or$cond = $7 | $9;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $10 = $nb >>> 1;
 $11 = $10 | $nb;
 $12 = $11 >>> 2;
 $13 = $12 | $11;
 $14 = $13 >>> 4;
 $15 = $14 | $13;
 $16 = $15 >>> 8;
 $17 = $16 | $15;
 $18 = $17 >>> 16;
 $19 = $18 | $17;
 $20 = (($19) + 1)|0;
 HEAP32[$5>>2] = $20;
 $21 = $20 << 5;
 $22 = $20 << 3;
 $23 = (($22) + 15)|0;
 $24 = $23 & -16;
 $25 = (($this) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$26);
 $27 = (($this) + 20|0);
 $28 = HEAP32[$27>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$28);
 $29 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$21,507232,523)|0);
 HEAP32[$27>>2] = $29;
 $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$24,507232,524)|0);
 HEAP32[$25>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq16BucketPrunerCore10resizeCoreEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = sp + 4|0;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $9 = $7 << 1;
 $$ = $8 ? 32 : $9;
 HEAP32[$6>>2] = $$;
 $10 = ($$*24)|0;
 $11 = $$ << 3;
 $12 = $$ << 2;
 $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$10,507232,540)|0);
 $14 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$11,507232,541)|0);
 $15 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$12,507232,542)|0);
 $16 = (($this) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = HEAP32[$this>>2]|0;
  $20 = ($19*24)|0;
  _memcpy(($13|0),($17|0),($20|0))|0;
  $21 = HEAP32[$16>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$21);
 }
 $22 = (($this) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = HEAP32[$this>>2]|0;
  $26 = $25 << 3;
  _memcpy(($14|0),($23|0),($26|0))|0;
  $27 = HEAP32[$22>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$27);
 }
 $28 = (($this) + 16|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  HEAP32[$16>>2] = $13;
  HEAP32[$22>>2] = $14;
  HEAP32[$28>>2] = $15;
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$this>>2]|0;
 $32 = $31 << 2;
 _memcpy(($15|0),($29|0),($32|0))|0;
 $33 = HEAP32[$28>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$33);
 HEAP32[$16>>2] = $13;
 HEAP32[$22>>2] = $14;
 HEAP32[$28>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq16BucketPrunerCore9addObjectERKNS0_13PrunerPayloadERKNS_9PxBounds3E($this,$object,$worldAABB) {
 $this = $this|0;
 $object = $object|0;
 $worldAABB = $worldAABB|0;
 var $$pre$i = 0, $$pre$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0);
 var $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0);
 var $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exists$i$i1 = 0, $i$07 = 0, $or$cond$i$i = 0, $or$cond$i$i5 = 0;
 var $tmpcast1$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i1 = sp + 8|0;
 $tmpcast1$i2 = sp;
 $0 = (($this) + 7584|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4>>>0)<(16);
  if ($5) {
   $11 = (($4) + 1)|0;
   HEAP32[$3>>2] = $11;
   $12 = ((($this) + ($4<<3)|0) + 32|0);
   $13 = $object;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($13) + 4)|0;
   $17 = $16;
   $18 = HEAP32[$17>>2]|0;
   $19 = $12;
   $20 = $19;
   HEAP32[$20>>2] = $15;
   $21 = (($19) + 4)|0;
   $22 = $21;
   HEAP32[$22>>2] = $18;
   $23 = Math_fround(HEAPF32[$worldAABB>>2]);
   $24 = ((($this) + (($4*24)|0)|0) + 160|0);
   HEAPF32[$24>>2] = $23;
   $25 = (($worldAABB) + 4|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = ((($this) + (($4*24)|0)|0) + 164|0);
   HEAPF32[$27>>2] = $26;
   $28 = (($worldAABB) + 8|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = ((($this) + (($4*24)|0)|0) + 168|0);
   HEAPF32[$30>>2] = $29;
   $31 = (($worldAABB) + 12|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = ((($this) + (($4*24)|0)|0) + 172|0);
   HEAPF32[$33>>2] = $32;
   $34 = (($worldAABB) + 16|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = ((($this) + (($4*24)|0)|0) + 176|0);
   HEAPF32[$36>>2] = $35;
   $37 = (($worldAABB) + 20|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = ((($this) + (($4*24)|0)|0) + 180|0);
   HEAPF32[$39>>2] = $38;
   STACKTOP = sp;return 1;
  }
  $6 = (($this) + 4|0);
  $7 = (($this) + 12|0);
  $8 = (($this) + 8|0);
  $9 = (($this) + 16|0);
  $10 = (($this) + 544|0);
  $i$07 = 0;
  while(1) {
   $40 = ((($this) + ($i$07<<3)|0) + 32|0);
   $41 = HEAP32[$this>>2]|0;
   $42 = HEAP32[$6>>2]|0;
   $43 = ($41|0)==($42|0);
   if ($43) {
    __ZN5physx2Sq16BucketPrunerCore10resizeCoreEv($this);
    $$pre$i4 = HEAP32[$this>>2]|0;
    $45 = $$pre$i4;
   } else {
    $45 = $41;
   }
   $44 = (($45) + 1)|0;
   HEAP32[$this>>2] = $44;
   $46 = HEAP32[$7>>2]|0;
   $47 = (($46) + ($45<<3)|0);
   $48 = $40;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $47;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   $58 = HEAP32[$8>>2]|0;
   $59 = ((($this) + (($i$07*24)|0)|0) + 160|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = (($58) + (($45*24)|0)|0);
   HEAPF32[$61>>2] = $60;
   $62 = ((($this) + (($i$07*24)|0)|0) + 164|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = ((($58) + (($45*24)|0)|0) + 4|0);
   HEAPF32[$64>>2] = $63;
   $65 = ((($this) + (($i$07*24)|0)|0) + 168|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = ((($58) + (($45*24)|0)|0) + 8|0);
   HEAPF32[$67>>2] = $66;
   $68 = ((($this) + (($i$07*24)|0)|0) + 172|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = ((($58) + (($45*24)|0)|0) + 12|0);
   HEAPF32[$70>>2] = $69;
   $71 = ((($this) + (($i$07*24)|0)|0) + 176|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = ((($58) + (($45*24)|0)|0) + 16|0);
   HEAPF32[$73>>2] = $72;
   $74 = ((($this) + (($i$07*24)|0)|0) + 180|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = ((($58) + (($45*24)|0)|0) + 20|0);
   HEAPF32[$76>>2] = $75;
   $77 = HEAP32[$9>>2]|0;
   $78 = (($77) + ($45<<2)|0);
   HEAP32[$78>>2] = -1;
   $79 = $40;
   $80 = $79;
   $81 = HEAP32[$80>>2]|0;
   $82 = (($79) + 4)|0;
   $83 = $82;
   $84 = HEAP32[$83>>2]|0;
   $85 = $tmpcast1$i2;
   $86 = $85;
   HEAP32[$86>>2] = $81;
   $87 = (($85) + 4)|0;
   $88 = $87;
   HEAP32[$88>>2] = $84;
   $89 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS_2Sq13PrunerPayloadEjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE6createERS6_Rb($10,$tmpcast1$i2,$exists$i$i1)|0);
   $90 = HEAP8[$exists$i$i1>>0]|0;
   $91 = ($90<<24>>24)!=(0);
   $92 = ($89|0)==(0|0);
   $or$cond$i$i5 = $91 | $92;
   if (!($or$cond$i$i5)) {
    $93 = $tmpcast1$i2;
    $94 = $93;
    $95 = HEAP32[$94>>2]|0;
    $96 = (($93) + 4)|0;
    $97 = $96;
    $98 = HEAP32[$97>>2]|0;
    $99 = $89;
    $100 = $99;
    HEAP32[$100>>2] = $95;
    $101 = (($99) + 4)|0;
    $102 = $101;
    HEAP32[$102>>2] = $98;
    $103 = (($89) + 8|0);
    HEAP32[$103>>2] = $45;
   }
   $104 = (($i$07) + 1)|0;
   $105 = HEAP32[$3>>2]|0;
   $106 = ($104>>>0)<($105>>>0);
   if ($106) {
    $i$07 = $104;
   } else {
    break;
   }
  }
  HEAP32[$3>>2] = 0;
  HEAP8[$0>>0] = 1;
 }
 $107 = HEAP32[$this>>2]|0;
 $108 = (($this) + 4|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ($107|0)==($109|0);
 if ($110) {
  __ZN5physx2Sq16BucketPrunerCore10resizeCoreEv($this);
  $$pre$i = HEAP32[$this>>2]|0;
  $112 = $$pre$i;
 } else {
  $112 = $107;
 }
 $111 = (($112) + 1)|0;
 HEAP32[$this>>2] = $111;
 $113 = (($this) + 12|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (($114) + ($112<<3)|0);
 $116 = $object;
 $117 = $116;
 $118 = HEAP32[$117>>2]|0;
 $119 = (($116) + 4)|0;
 $120 = $119;
 $121 = HEAP32[$120>>2]|0;
 $122 = $115;
 $123 = $122;
 HEAP32[$123>>2] = $118;
 $124 = (($122) + 4)|0;
 $125 = $124;
 HEAP32[$125>>2] = $121;
 $126 = (($this) + 8|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = Math_fround(HEAPF32[$worldAABB>>2]);
 $129 = (($127) + (($112*24)|0)|0);
 HEAPF32[$129>>2] = $128;
 $130 = (($worldAABB) + 4|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = ((($127) + (($112*24)|0)|0) + 4|0);
 HEAPF32[$132>>2] = $131;
 $133 = (($worldAABB) + 8|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = ((($127) + (($112*24)|0)|0) + 8|0);
 HEAPF32[$135>>2] = $134;
 $136 = (($worldAABB) + 12|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = ((($127) + (($112*24)|0)|0) + 12|0);
 HEAPF32[$138>>2] = $137;
 $139 = (($worldAABB) + 16|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = ((($127) + (($112*24)|0)|0) + 16|0);
 HEAPF32[$141>>2] = $140;
 $142 = (($worldAABB) + 20|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = ((($127) + (($112*24)|0)|0) + 20|0);
 HEAPF32[$144>>2] = $143;
 $145 = (($this) + 16|0);
 $146 = HEAP32[$145>>2]|0;
 $147 = (($146) + ($112<<2)|0);
 HEAP32[$147>>2] = -1;
 $148 = $object;
 $149 = $148;
 $150 = HEAP32[$149>>2]|0;
 $151 = (($148) + 4)|0;
 $152 = $151;
 $153 = HEAP32[$152>>2]|0;
 $154 = $tmpcast1$i2;
 $155 = $154;
 HEAP32[$155>>2] = $150;
 $156 = (($154) + 4)|0;
 $157 = $156;
 HEAP32[$157>>2] = $153;
 $158 = (($this) + 544|0);
 $159 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS_2Sq13PrunerPayloadEjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE6createERS6_Rb($158,$tmpcast1$i2,$exists$i$i1)|0);
 $160 = HEAP8[$exists$i$i1>>0]|0;
 $161 = ($160<<24>>24)!=(0);
 $162 = ($159|0)==(0|0);
 $or$cond$i$i = $161 | $162;
 if ($or$cond$i$i) {
  STACKTOP = sp;return 1;
 }
 $163 = $tmpcast1$i2;
 $164 = $163;
 $165 = HEAP32[$164>>2]|0;
 $166 = (($163) + 4)|0;
 $167 = $166;
 $168 = HEAP32[$167>>2]|0;
 $169 = $159;
 $170 = $169;
 HEAP32[$170>>2] = $165;
 $171 = (($169) + 4)|0;
 $172 = $171;
 HEAP32[$172>>2] = $168;
 $173 = (($159) + 8|0);
 HEAP32[$173>>2] = $112;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Sq16BucketPrunerCore12removeObjectERKNS0_13PrunerPayloadE($this,$object) {
 $this = $this|0;
 $object = $object|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = 0;
 var $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0;
 var $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i1$015 = 0, $index$0$i$i = 0, $index$04$i$i = 0, $index$05$i$i = 0, $index$05$i$i3 = 0, $index$05$i$i3$in = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 564|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = HEAP32[$object>>2]|0;
   $4 = (($object) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $3 ^ -1;
   $7 = (_i64Add(($3|0),($5|0),-1,($6|0))|0);
   $8 = tempRet0;
   $9 = (_bitshift64Lshr(($7|0),($8|0),22)|0);
   $10 = tempRet0;
   $11 = $9 ^ $7;
   $12 = $10 ^ $8;
   $13 = (_bitshift64Shl(($11|0),($12|0),13)|0);
   $14 = tempRet0;
   $15 = $13 ^ -1;
   $16 = $14 ^ -1;
   $17 = (_i64Add(($11|0),($12|0),($15|0),($16|0))|0);
   $18 = tempRet0;
   $19 = (_bitshift64Lshr(($17|0),($18|0),8)|0);
   $20 = tempRet0;
   $21 = $19 ^ $17;
   $22 = $20 ^ $18;
   $23 = (___muldi3(($21|0),($22|0),9,0)|0);
   $24 = tempRet0;
   $25 = (_bitshift64Lshr(($23|0),($24|0),15)|0);
   $26 = tempRet0;
   $27 = $25 ^ $23;
   $28 = $26 ^ $24;
   $29 = (_bitshift64Shl(($27|0),($28|0),27)|0);
   $30 = tempRet0;
   $31 = $29 ^ -1;
   $32 = $30 ^ -1;
   $33 = (_i64Add(($27|0),($28|0),($31|0),($32|0))|0);
   $34 = tempRet0;
   $35 = (_bitshift64Lshr(($33|0),($34|0),31)|0);
   $36 = tempRet0;
   $37 = $35 ^ $33;
   $36 ^ $34;
   $38 = (($1) + -1)|0;
   $39 = $37 & $38;
   $40 = (($this) + 556|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + ($39<<2)|0);
   $index$04$i$i = HEAP32[$42>>2]|0;
   $43 = ($index$04$i$i|0)==(-1);
   if (!($43)) {
    $44 = (($this) + 548|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($this) + 552|0);
    $index$05$i$i = $index$04$i$i;
    while(1) {
     $47 = (($45) + (($index$05$i$i*12)|0)|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==($3|0);
     if ($49) {
      $50 = ((($45) + (($index$05$i$i*12)|0)|0) + 4|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==($5|0);
      if ($52) {
       break;
      }
     }
     $53 = HEAP32[$46>>2]|0;
     $54 = (($53) + ($index$05$i$i<<2)|0);
     $index$0$i$i = HEAP32[$54>>2]|0;
     $55 = ($index$0$i$i|0)==(-1);
     if ($55) {
      break L1;
     } else {
      $index$05$i$i = $index$0$i$i;
     }
    }
    $61 = (($45) + (($index$05$i$i*12)|0)|0);
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     $63 = ((($45) + (($index$05$i$i*12)|0)|0) + 8|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($this) + 16|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = (($66) + ($64<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($this) + 544|0);
     (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS_2Sq13PrunerPayloadEjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE5eraseERS6_($69,$object)|0);
     $70 = HEAP32[$this>>2]|0;
     $71 = (($70) + -1)|0;
     HEAP32[$this>>2] = $71;
     $72 = ($64|0)==($71|0);
     if (!($72)) {
      $73 = (($this) + 12|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = (($74) + ($71<<3)|0);
      $76 = (($this) + 8|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + (($71*24)|0)|0);
      $79 = Math_fround(HEAPF32[$78>>2]);
      $80 = (($77) + (($64*24)|0)|0);
      HEAPF32[$80>>2] = $79;
      $81 = ((($77) + (($71*24)|0)|0) + 4|0);
      $82 = Math_fround(HEAPF32[$81>>2]);
      $83 = ((($77) + (($64*24)|0)|0) + 4|0);
      HEAPF32[$83>>2] = $82;
      $84 = ((($77) + (($71*24)|0)|0) + 8|0);
      $85 = Math_fround(HEAPF32[$84>>2]);
      $86 = ((($77) + (($64*24)|0)|0) + 8|0);
      HEAPF32[$86>>2] = $85;
      $87 = ((($77) + (($71*24)|0)|0) + 12|0);
      $88 = Math_fround(HEAPF32[$87>>2]);
      $89 = ((($77) + (($64*24)|0)|0) + 12|0);
      HEAPF32[$89>>2] = $88;
      $90 = ((($77) + (($71*24)|0)|0) + 16|0);
      $91 = Math_fround(HEAPF32[$90>>2]);
      $92 = ((($77) + (($64*24)|0)|0) + 16|0);
      HEAPF32[$92>>2] = $91;
      $93 = ((($77) + (($71*24)|0)|0) + 20|0);
      $94 = Math_fround(HEAPF32[$93>>2]);
      $95 = ((($77) + (($64*24)|0)|0) + 20|0);
      HEAPF32[$95>>2] = $94;
      $96 = (($74) + ($64<<3)|0);
      $97 = $75;
      $98 = $97;
      $99 = HEAP32[$98>>2]|0;
      $100 = (($97) + 4)|0;
      $101 = $100;
      $102 = HEAP32[$101>>2]|0;
      $103 = $96;
      $104 = $103;
      HEAP32[$104>>2] = $99;
      $105 = (($103) + 4)|0;
      $106 = $105;
      HEAP32[$106>>2] = $102;
      $107 = HEAP32[$this>>2]|0;
      $108 = HEAP32[$65>>2]|0;
      $109 = (($108) + ($107<<2)|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = (($108) + ($64<<2)|0);
      HEAP32[$111>>2] = $110;
      $112 = HEAP32[$0>>2]|0;
      $113 = HEAP32[$75>>2]|0;
      $114 = ((($74) + ($71<<3)|0) + 4|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = $113 ^ -1;
      $117 = (_i64Add(($113|0),($115|0),-1,($116|0))|0);
      $118 = tempRet0;
      $119 = (_bitshift64Lshr(($117|0),($118|0),22)|0);
      $120 = tempRet0;
      $121 = $119 ^ $117;
      $122 = $120 ^ $118;
      $123 = (_bitshift64Shl(($121|0),($122|0),13)|0);
      $124 = tempRet0;
      $125 = $123 ^ -1;
      $126 = $124 ^ -1;
      $127 = (_i64Add(($121|0),($122|0),($125|0),($126|0))|0);
      $128 = tempRet0;
      $129 = (_bitshift64Lshr(($127|0),($128|0),8)|0);
      $130 = tempRet0;
      $131 = $129 ^ $127;
      $132 = $130 ^ $128;
      $133 = (___muldi3(($131|0),($132|0),9,0)|0);
      $134 = tempRet0;
      $135 = (_bitshift64Lshr(($133|0),($134|0),15)|0);
      $136 = tempRet0;
      $137 = $135 ^ $133;
      $138 = $136 ^ $134;
      $139 = (_bitshift64Shl(($137|0),($138|0),27)|0);
      $140 = tempRet0;
      $141 = $139 ^ -1;
      $142 = $140 ^ -1;
      $143 = (_i64Add(($137|0),($138|0),($141|0),($142|0))|0);
      $144 = tempRet0;
      $145 = (_bitshift64Lshr(($143|0),($144|0),31)|0);
      $146 = tempRet0;
      $147 = $145 ^ $143;
      $146 ^ $144;
      $148 = (($112) + -1)|0;
      $149 = $147 & $148;
      $150 = HEAP32[$40>>2]|0;
      $151 = (($150) + ($149<<2)|0);
      $152 = HEAP32[$44>>2]|0;
      $index$05$i$i3$in = $151;
      while(1) {
       $index$05$i$i3 = HEAP32[$index$05$i$i3$in>>2]|0;
       $153 = (($152) + (($index$05$i$i3*12)|0)|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = ($154|0)==($113|0);
       if ($155) {
        $156 = ((($152) + (($index$05$i$i3*12)|0)|0) + 4|0);
        $157 = HEAP32[$156>>2]|0;
        $158 = ($157|0)==($115|0);
        if ($158) {
         break;
        }
       }
       $159 = HEAP32[$46>>2]|0;
       $160 = (($159) + ($index$05$i$i3<<2)|0);
       $index$05$i$i3$in = $160;
      }
      $161 = ((($152) + (($index$05$i$i3*12)|0)|0) + 8|0);
      HEAP32[$161>>2] = $64;
     }
     $162 = (($this) + 7584|0);
     $163 = HEAP8[$162>>0]|0;
     $164 = ($163<<24>>24)==(0);
     if (!($164)) {
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
     $165 = (($this) + 20|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = (($166) + ($68<<5)|0);
     HEAPF32[$167>>2] = Math_fround(0.0);
     $168 = ((($166) + ($68<<5)|0) + 4|0);
     HEAPF32[$168>>2] = Math_fround(0.0);
     $169 = ((($166) + ($68<<5)|0) + 8|0);
     HEAPF32[$169>>2] = Math_fround(0.0);
     $170 = ((($166) + ($68<<5)|0) + 16|0);
     HEAPF32[$170>>2] = Math_fround(-8.50705866596322149529E+37);
     $171 = ((($166) + ($68<<5)|0) + 20|0);
     HEAPF32[$171>>2] = Math_fround(-8.50705866596322149529E+37);
     $172 = ((($166) + ($68<<5)|0) + 24|0);
     HEAPF32[$172>>2] = Math_fround(-8.50705866596322149529E+37);
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $56 = (($this) + 28|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0);
 if ($58) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $59 = HEAP32[$object>>2]|0;
 $60 = (($object) + 4|0);
 $i1$015 = 0;
 while(1) {
  $173 = ((($this) + ($i1$015<<3)|0) + 32|0);
  $174 = HEAP32[$173>>2]|0;
  $175 = ($174|0)==($59|0);
  if ($175) {
   $176 = ((($this) + ($i1$015<<3)|0) + 36|0);
   $177 = HEAP32[$176>>2]|0;
   $178 = HEAP32[$60>>2]|0;
   $179 = ($177|0)==($178|0);
   if ($179) {
    break;
   }
  }
  $211 = (($i1$015) + 1)|0;
  $212 = ($211>>>0)<($57>>>0);
  if ($212) {
   $i1$015 = $211;
  } else {
   $$0 = 0;
   label = 22;
   break;
  }
 }
 if ((label|0) == 22) {
  STACKTOP = sp;return ($$0|0);
 }
 $180 = (($57) + -1)|0;
 HEAP32[$56>>2] = $180;
 $181 = ((($this) + (($180*24)|0)|0) + 160|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = ((($this) + (($i1$015*24)|0)|0) + 160|0);
 HEAPF32[$183>>2] = $182;
 $184 = ((($this) + (($180*24)|0)|0) + 164|0);
 $185 = Math_fround(HEAPF32[$184>>2]);
 $186 = ((($this) + (($i1$015*24)|0)|0) + 164|0);
 HEAPF32[$186>>2] = $185;
 $187 = ((($this) + (($180*24)|0)|0) + 168|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = ((($this) + (($i1$015*24)|0)|0) + 168|0);
 HEAPF32[$189>>2] = $188;
 $190 = ((($this) + (($180*24)|0)|0) + 172|0);
 $191 = Math_fround(HEAPF32[$190>>2]);
 $192 = ((($this) + (($i1$015*24)|0)|0) + 172|0);
 HEAPF32[$192>>2] = $191;
 $193 = ((($this) + (($180*24)|0)|0) + 176|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = ((($this) + (($i1$015*24)|0)|0) + 176|0);
 HEAPF32[$195>>2] = $194;
 $196 = ((($this) + (($180*24)|0)|0) + 180|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = ((($this) + (($i1$015*24)|0)|0) + 180|0);
 HEAPF32[$198>>2] = $197;
 $199 = HEAP32[$56>>2]|0;
 $200 = ((($this) + ($199<<3)|0) + 32|0);
 $201 = $200;
 $202 = $201;
 $203 = HEAP32[$202>>2]|0;
 $204 = (($201) + 4)|0;
 $205 = $204;
 $206 = HEAP32[$205>>2]|0;
 $207 = $173;
 $208 = $207;
 HEAP32[$208>>2] = $203;
 $209 = (($207) + 4)|0;
 $210 = $209;
 HEAP32[$210>>2] = $206;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sq16BucketPrunerCore12updateObjectERKNS_9PxBounds3ERKNS0_13PrunerPayloadE($this,$worldAABB,$object) {
 $this = $this|0;
 $worldAABB = $worldAABB|0;
 $object = $object|0;
 var $$0 = 0, $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Sq16BucketPrunerCore12removeObjectERKNS0_13PrunerPayloadE($this,$object)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (__ZN5physx2Sq16BucketPrunerCore9addObjectERKNS0_13PrunerPayloadERKNS_9PxBounds3E($this,$object,$worldAABB)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sq16BucketPrunerCore13classifyBoxesEv($this) {
 $this = $this|0;
 var $$$i$i = Math_fround(0), $$$i257$lcssa$i = Math_fround(0), $$$i257271$i = Math_fround(0), $$$i53$i = Math_fround(0), $$$i53259$lcssa$i = Math_fround(0), $$$i53259269$i = Math_fround(0), $$0$i$i = 0, $$0$i1$i = 0, $$1$i$i = Math_fround(0), $$1$i258$lcssa$i = Math_fround(0), $$1$i258270$i = Math_fround(0), $$1$i54$i = Math_fround(0), $$1$i54260$lcssa$i = Math_fround(0), $$1$i54260268$i = Math_fround(0), $$lcssa$i = Math_fround(0), $$lcssa267$i = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert50 = 0, $$phi$trans$insert52 = 0, $$pre = Math_fround(0);
 var $$pre51 = Math_fround(0), $$pre53 = Math_fround(0), $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0;
 var $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $exitcond = 0;
 var $exitcond$i = 0, $exitcond$i1 = 0, $exitcond$i3 = 0, $exitcond281$i = 0, $exitcond284$i = 0, $exitcond44 = 0, $exitcond45 = 0, $exitcond46 = 0, $exitcond48 = 0, $exitcond49 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i22$i = Math_fround(0), $i$01$i = 0, $i$01$i2 = 0, $i$0272$i = 0, $i$040 = 0, $i1$0263$i = 0, $i1$035 = 0, $i2$033 = 0, $i2$033$us = 0;
 var $i3$031 = 0, $i4$0262$i = 0, $j$038 = 0, $localTempBoxes = 0, $localTempObjects = 0, $ranks$0261$i = 0, $rs$i = 0, $tempBoxes$0 = 0, $tempObjects$0 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 10352|0;
 $rs$i = sp + 10240|0;
 $0 = sp + 10340|0;
 $localTempObjects = sp + 8192|0;
 $localTempBoxes = sp;
 $1 = sp + 10341|0;
 $2 = sp + 10337|0;
 $3 = sp + 10338|0;
 $4 = sp + 10339|0;
 $5 = sp + 10336|0;
 $6 = (($this) + 7584|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAP8[$6>>0] = 0;
 $9 = HEAP32[$this>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = (($this) + 584|0);
  HEAP32[$11>>2] = 0;
  STACKTOP = sp;return;
 }
 $12 = $9 << 2;
 $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$12,507232,1015)|0);
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $i$040 = 0;
 while(1) {
  $16 = (($15) + ($i$040<<3)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($13) + ($i$040<<2)|0);
  HEAP32[$18>>2] = $17;
  HEAP32[$16>>2] = $i$040;
  $19 = (($i$040) + 1)|0;
  $exitcond48 = ($19|0)==($9|0);
  if ($exitcond48) {
   break;
  } else {
   $i$040 = $19;
  }
 }
 $20 = ($9>>>0)>(256);
 if ($20) {
  $21 = $9 << 3;
  $22 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$21,507232,1030)|0);
  $23 = $9 << 5;
  $24 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$23,507232,1031)|0);
  $tempBoxes$0 = $24;$tempObjects$0 = $22;
 } else {
  $tempBoxes$0 = $localTempBoxes;$tempObjects$0 = $localTempObjects;
 }
 $25 = (($this) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($9) + -1)|0;
 $30 = (($26) + (($29*24)|0)|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($30) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($30) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = ((($26) + (($29*24)|0)|0) + 12|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($36) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($36) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = ($29|0)==(0);
 if ($42) {
  $$$i257$lcssa$i = $37;$$$i53259$lcssa$i = $31;$$1$i258$lcssa$i = $41;$$1$i54260$lcssa$i = $35;$$lcssa$i = $33;$$lcssa267$i = $39;
 } else {
  $$$i257271$i = $37;$$$i53259269$i = $31;$$1$i258270$i = $41;$$1$i54260268$i = $35;$53 = $33;$63 = $39;$i$0272$i = 0;
  while(1) {
   $43 = (($26) + (($i$0272$i*24)|0)|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($43) + 4|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($43) + 8|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = (($43) + 12|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = $$$i53259269$i < $44;
   $$$i53$i = $51 ? $$$i53259269$i : $44;
   $52 = $53 < $46;
   $54 = $52 ? $53 : $46;
   $55 = $$1$i54260268$i < $48;
   $$1$i54$i = $55 ? $$1$i54260268$i : $48;
   $56 = ((($26) + (($i$0272$i*24)|0)|0) + 12|0);
   $57 = (($56) + 4|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = (($56) + 8|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = $$$i257271$i > $50;
   $$$i$i = $61 ? $$$i257271$i : $50;
   $62 = $63 > $58;
   $64 = $62 ? $63 : $58;
   $65 = $$1$i258270$i > $60;
   $$1$i$i = $65 ? $$1$i258270$i : $60;
   $66 = (($i$0272$i) + 1)|0;
   $exitcond284$i = ($66|0)==($29|0);
   if ($exitcond284$i) {
    $$$i257$lcssa$i = $$$i$i;$$$i53259$lcssa$i = $$$i53$i;$$1$i258$lcssa$i = $$1$i$i;$$1$i54260$lcssa$i = $$1$i54$i;$$lcssa$i = $54;$$lcssa267$i = $64;
    break;
   } else {
    $$$i257271$i = $$$i$i;$$$i53259269$i = $$$i53$i;$$1$i258270$i = $$1$i$i;$$1$i54260268$i = $$1$i54$i;$53 = $54;$63 = $64;$i$0272$i = $66;
   }
  }
 }
 $67 = Math_fround($$$i257$lcssa$i + $$$i53259$lcssa$i);
 $68 = Math_fround($$lcssa267$i + $$lcssa$i);
 $69 = Math_fround($$1$i258$lcssa$i + $$1$i54260$lcssa$i);
 $70 = Math_fround($67 * Math_fround(0.5));
 $71 = Math_fround($68 * Math_fround(0.5));
 $72 = Math_fround($69 * Math_fround(0.5));
 $73 = Math_fround($$$i257$lcssa$i - $$$i53259$lcssa$i);
 $74 = Math_fround($$lcssa267$i - $$lcssa$i);
 $75 = Math_fround($$1$i258$lcssa$i - $$1$i54260$lcssa$i);
 $76 = Math_fround($73 * Math_fround(0.5));
 $77 = Math_fround($74 * Math_fround(0.5));
 $78 = Math_fround($75 * Math_fround(0.5));
 $79 = (($this) + 608|0);
 HEAPF32[$79>>2] = $70;
 $80 = (($this) + 612|0);
 HEAPF32[$80>>2] = $71;
 $81 = (($this) + 616|0);
 HEAPF32[$81>>2] = $72;
 $82 = (($this) + 624|0);
 HEAPF32[$82>>2] = $76;
 $83 = (($this) + 628|0);
 HEAPF32[$83>>2] = $77;
 $84 = (($this) + 632|0);
 HEAPF32[$84>>2] = $78;
 $fabsf$i$i22$i = (Math_fround(Math_abs((Math_fround($77)))));
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($78)))));
 $85 = $fabsf$i$i22$i < $fabsf$i$i$i;
 $86 = $85 ? 1 : 2;
 $i1$0263$i = 0;
 while(1) {
  $87 = (($26) + (($i1$0263$i*24)|0)|0);
  $88 = (($87) + ($86<<2)|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = (($tempObjects$0) + ($i1$0263$i<<2)|0);
  HEAPF32[$90>>2] = $89;
  $91 = (($i1$0263$i) + 1)|0;
  $exitcond281$i = ($91|0)==($9|0);
  if ($exitcond281$i) {
   break;
  } else {
   $i1$0263$i = $91;
  }
 }
 __ZN5physx2Gu17RadixSortBufferedC2Ev($rs$i);
 $92 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKfj($rs$i,$tempObjects$0,$9)|0);
 $93 = (($92) + 8|0);
 $94 = HEAP32[$93>>2]|0;
 $i4$0262$i = 0;$ranks$0261$i = $94;
 while(1) {
  $95 = (($ranks$0261$i) + 4|0);
  $96 = HEAP32[$ranks$0261$i>>2]|0;
  $97 = (($26) + (($96*24)|0)|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($97) + 4|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($97) + 8|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = (($97) + 12|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = ((($26) + (($96*24)|0)|0) + 12|0);
  $106 = (($105) + 4|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = (($105) + 8|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = Math_fround($98 + $104);
  $111 = Math_fround($100 + $107);
  $112 = Math_fround($102 + $109);
  $113 = Math_fround($104 + Math_fround(0.0));
  $114 = Math_fround($110 * Math_fround(0.5));
  $115 = Math_fround($111 * Math_fround(0.5));
  $116 = Math_fround($112 * Math_fround(0.5));
  $117 = Math_fround($113 * Math_fround(0.5));
  $118 = Math_fround($104 - $98);
  $119 = Math_fround($107 - $100);
  $120 = Math_fround($109 - $102);
  $121 = Math_fround(Math_fround(0.0) - $104);
  $122 = Math_fround($118 * Math_fround(0.5));
  $123 = Math_fround($119 * Math_fround(0.5));
  $124 = Math_fround($120 * Math_fround(0.5));
  $125 = Math_fround($121 * Math_fround(0.5));
  $126 = (($tempBoxes$0) + ($i4$0262$i<<5)|0);
  HEAPF32[$126>>2] = $114;
  $127 = (($126) + 4|0);
  HEAPF32[$127>>2] = $115;
  $128 = (($126) + 8|0);
  HEAPF32[$128>>2] = $116;
  $129 = (($126) + 12|0);
  HEAPF32[$129>>2] = $117;
  $130 = ((($tempBoxes$0) + ($i4$0262$i<<5)|0) + 16|0);
  HEAPF32[$130>>2] = $122;
  $131 = (($130) + 4|0);
  HEAPF32[$131>>2] = $123;
  $132 = (($130) + 8|0);
  HEAPF32[$132>>2] = $124;
  $133 = (($130) + 12|0);
  HEAPF32[$133>>2] = $125;
  $134 = (($tempObjects$0) + ($i4$0262$i<<3)|0);
  $135 = (($28) + ($96<<3)|0);
  $136 = $135;
  $137 = $136;
  $138 = HEAP32[$137>>2]|0;
  $139 = (($136) + 4)|0;
  $140 = $139;
  $141 = HEAP32[$140>>2]|0;
  $142 = $134;
  $143 = $142;
  HEAP32[$143>>2] = $138;
  $144 = (($142) + 4)|0;
  $145 = $144;
  HEAP32[$145>>2] = $141;
  $146 = (($i4$0262$i) + 1)|0;
  $exitcond$i = ($146|0)==($9|0);
  if ($exitcond$i) {
   break;
  } else {
   $i4$0262$i = $146;$ranks$0261$i = $95;
  }
 }
 __ZN5physx2Gu17RadixSortBufferedD2Ev($rs$i);
 $147 = (($this) + 592|0);
 HEAP32[$147>>2] = $86;
 __ZN5physx2Sq16BucketPrunerCore20allocateSortedMemoryEj($this,$9);
 $148 = (($this) + 20|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = (($this) + 24|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = HEAP32[$147>>2]|0;
 $153 = ($152|0)==(1);
 $154 = $153 ? 2 : 1;
 $155 = Math_fround(HEAPF32[$79>>2]);
 $156 = (($79) + ($154<<2)|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = (($this) + 640|0);
 __ZN5physx2Sq16BucketPrunerNode13classifyBoxesEffjPNS0_9BucketBoxEPKNS0_13PrunerPayloadES3_PS4_bj($158,$155,$157,$9,$tempBoxes$0,$tempObjects$0,$149,$151,0,$152);
 $159 = HEAP32[$148>>2]|0;
 $160 = HEAP32[$150>>2]|0;
 $161 = HEAP32[$147>>2]|0;
 $162 = ($161|0)==(1);
 $163 = $162 ? 2 : 1;
 $i$01$i = 0;
 while(1) {
  $164 = ((($this) + ($i$01$i<<2)|0) + 640|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = ($165|0)==(0);
  if ($166) {
   $167 = ((($this) + (($i$01$i*224)|0)|0) + 864|0);
   dest=$167+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  } else {
   $168 = ((($this) + ($i$01$i<<2)|0) + 660|0);
   $169 = HEAP32[$168>>2]|0;
   $170 = (($159) + ($169<<5)|0);
   $171 = (($160) + ($169<<3)|0);
   $172 = ((($this) + ($i$01$i<<5)|0) + 688|0);
   $173 = Math_fround(HEAPF32[$172>>2]);
   $174 = (($172) + ($163<<2)|0);
   $175 = Math_fround(HEAPF32[$174>>2]);
   $176 = ($i$01$i|0)==(4);
   $177 = ((($this) + (($i$01$i*224)|0)|0) + 864|0);
   __ZN5physx2Sq16BucketPrunerNode13classifyBoxesEffjPNS0_9BucketBoxEPKNS0_13PrunerPayloadES3_PS4_bj($177,$173,$175,$165,$170,$171,$tempBoxes$0,$tempObjects$0,$176,$161);
   $178 = $165 << 5;
   _memcpy(($170|0),($tempBoxes$0|0),($178|0))|0;
   $179 = $165 << 3;
   _memcpy(($171|0),($tempObjects$0|0),($179|0))|0;
  }
  $180 = (($i$01$i) + 1)|0;
  $exitcond$i1 = ($180|0)==(5);
  if ($exitcond$i1) {
   $j$038 = 0;
   break;
  } else {
   $i$01$i = $180;
  }
 }
 while(1) {
  $182 = HEAP32[$148>>2]|0;
  $183 = ((($this) + ($j$038<<2)|0) + 660|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = HEAP32[$150>>2]|0;
  $186 = HEAP32[$147>>2]|0;
  $187 = ($186|0)==(1);
  $188 = $187 ? 2 : 1;
  $i$01$i2 = 0;
  while(1) {
   $189 = (((($this) + (($j$038*224)|0)|0) + ($i$01$i2<<2)|0) + 864|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = ($190|0)==(0);
   if ($191) {
    $192 = (((($this) + (($j$038*1120)|0)|0) + (($i$01$i2*224)|0)|0) + 1984|0);
    dest=$192+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   } else {
    $193 = (((($this) + (($j$038*224)|0)|0) + ($i$01$i2<<2)|0) + 884|0);
    $194 = HEAP32[$193>>2]|0;
    $$sum = (($194) + ($184))|0;
    $195 = (($182) + ($$sum<<5)|0);
    $196 = (($185) + ($$sum<<3)|0);
    $197 = (((($this) + (($j$038*224)|0)|0) + ($i$01$i2<<5)|0) + 912|0);
    $198 = Math_fround(HEAPF32[$197>>2]);
    $199 = (($197) + ($188<<2)|0);
    $200 = Math_fround(HEAPF32[$199>>2]);
    $201 = ($i$01$i2|0)==(4);
    $202 = (((($this) + (($j$038*1120)|0)|0) + (($i$01$i2*224)|0)|0) + 1984|0);
    __ZN5physx2Sq16BucketPrunerNode13classifyBoxesEffjPNS0_9BucketBoxEPKNS0_13PrunerPayloadES3_PS4_bj($202,$198,$200,$190,$195,$196,$tempBoxes$0,$tempObjects$0,$201,$186);
    $203 = $190 << 5;
    _memcpy(($195|0),($tempBoxes$0|0),($203|0))|0;
    $204 = $190 << 3;
    _memcpy(($196|0),($tempObjects$0|0),($204|0))|0;
   }
   $205 = (($i$01$i2) + 1)|0;
   $exitcond$i3 = ($205|0)==(5);
   if ($exitcond$i3) {
    break;
   } else {
    $i$01$i2 = $205;
   }
  }
  $206 = (($j$038) + 1)|0;
  $exitcond46 = ($206|0)==(5);
  if ($exitcond46) {
   break;
  } else {
   $j$038 = $206;
  }
 }
 $181 = HEAP32[$148>>2]|0;
 $i1$035 = 0;
 while(1) {
  $207 = HEAP32[$147>>2]|0;
  $208 = (($181) + ($i1$035<<5)|0);
  $209 = (($208) + ($207<<2)|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $211 = ((($181) + ($i1$035<<5)|0) + 16|0);
  $212 = (($211) + ($207<<2)|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = Math_fround($210 - $213);
  $215 = (HEAPF32[tempDoublePtr>>2]=$214,HEAP32[tempDoublePtr>>2]|0);
  $216 = Math_fround($210 + $213);
  $217 = (HEAPF32[tempDoublePtr>>2]=$216,HEAP32[tempDoublePtr>>2]|0);
  $218 = ($215|0)<(0);
  $219 = $215 ^ -1;
  $220 = $215 | -2147483648;
  $$0$i1$i = $218 ? $219 : $220;
  $221 = ((($181) + ($i1$035<<5)|0) + 12|0);
  HEAP32[$221>>2] = $$0$i1$i;
  $222 = ($217|0)<(0);
  $223 = $217 ^ -1;
  $224 = $217 | -2147483648;
  $$0$i$i = $222 ? $223 : $224;
  $225 = ((($181) + ($i1$035<<5)|0) + 28|0);
  HEAP32[$225>>2] = $$0$i$i;
  $226 = (($i1$035) + 1)|0;
  $exitcond45 = ($226|0)==($9|0);
  if ($exitcond45) {
   break;
  } else {
   $i1$035 = $226;
  }
 }
 if ($20) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$tempBoxes$0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$tempObjects$0);
 }
 $227 = HEAP32[$150>>2]|0;
 $228 = HEAP32[$27>>2]|0;
 $229 = (($this) + 16|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = ($230|0)==(0|0);
 if ($231) {
  $i2$033$us = 0;
  while(1) {
   $232 = (($227) + ($i2$033$us<<3)|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = (($13) + ($233<<2)|0);
   $235 = HEAP32[$234>>2]|0;
   HEAP32[$232>>2] = $235;
   $236 = (($228) + ($233<<3)|0);
   HEAP32[$236>>2] = $235;
   $237 = (($i2$033$us) + 1)|0;
   $exitcond49 = ($237|0)==($9|0);
   if ($exitcond49) {
    break;
   } else {
    $i2$033$us = $237;
   }
  }
 } else {
  $i2$033 = 0;
  while(1) {
   $238 = (($227) + ($i2$033<<3)|0);
   $239 = HEAP32[$238>>2]|0;
   $240 = (($13) + ($239<<2)|0);
   $241 = HEAP32[$240>>2]|0;
   HEAP32[$238>>2] = $241;
   $242 = (($228) + ($239<<3)|0);
   HEAP32[$242>>2] = $241;
   $243 = (($230) + ($239<<2)|0);
   HEAP32[$243>>2] = $i2$033;
   $244 = (($i2$033) + 1)|0;
   $exitcond44 = ($244|0)==($9|0);
   if ($exitcond44) {
    break;
   } else {
    $i2$033 = $244;
   }
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$13);
 HEAPF32[$rs$i>>2] = Math_fround(1.0);
 $245 = (($rs$i) + 4|0);
 HEAPF32[$245>>2] = Math_fround(1.0);
 $246 = (($rs$i) + 8|0);
 HEAPF32[$246>>2] = Math_fround(1.0);
 $247 = (($rs$i) + 12|0);
 HEAPF32[$247>>2] = Math_fround(1.0);
 $248 = (($rs$i) + 16|0);
 HEAPF32[$248>>2] = Math_fround(1.0);
 $249 = (($rs$i) + 20|0);
 HEAPF32[$249>>2] = Math_fround(-1.0);
 $250 = (($rs$i) + 24|0);
 HEAPF32[$250>>2] = Math_fround(1.0);
 $251 = (($rs$i) + 28|0);
 HEAPF32[$251>>2] = Math_fround(-1.0);
 $252 = (($rs$i) + 32|0);
 HEAPF32[$252>>2] = Math_fround(1.0);
 $253 = (($rs$i) + 36|0);
 HEAPF32[$253>>2] = Math_fround(1.0);
 $254 = (($rs$i) + 40|0);
 HEAPF32[$254>>2] = Math_fround(-1.0);
 $255 = (($rs$i) + 44|0);
 HEAPF32[$255>>2] = Math_fround(-1.0);
 $256 = (($rs$i) + 48|0);
 HEAPF32[$256>>2] = Math_fround(-1.0);
 $257 = (($rs$i) + 52|0);
 HEAPF32[$257>>2] = Math_fround(1.0);
 $258 = (($rs$i) + 56|0);
 HEAPF32[$258>>2] = Math_fround(1.0);
 $259 = (($rs$i) + 60|0);
 HEAPF32[$259>>2] = Math_fround(-1.0);
 $260 = (($rs$i) + 64|0);
 HEAPF32[$260>>2] = Math_fround(1.0);
 $261 = (($rs$i) + 68|0);
 HEAPF32[$261>>2] = Math_fround(-1.0);
 $262 = (($rs$i) + 72|0);
 HEAPF32[$262>>2] = Math_fround(-1.0);
 $263 = (($rs$i) + 76|0);
 HEAPF32[$263>>2] = Math_fround(-1.0);
 $264 = (($rs$i) + 80|0);
 HEAPF32[$264>>2] = Math_fround(1.0);
 $265 = (($rs$i) + 84|0);
 HEAPF32[$265>>2] = Math_fround(-1.0);
 $266 = (($rs$i) + 88|0);
 HEAPF32[$266>>2] = Math_fround(-1.0);
 $267 = (($rs$i) + 92|0);
 HEAPF32[$267>>2] = Math_fround(-1.0);
 $269 = Math_fround(1.0);$271 = Math_fround(1.0);$274 = Math_fround(1.0);$i3$031 = 0;
 while(1) {
  $268 = Math_fround($269 * $269);
  $270 = Math_fround($271 * $271);
  $272 = Math_fround($268 + $270);
  $273 = Math_fround($274 * $274);
  $275 = Math_fround($272 + $273);
  $276 = (Math_fround(Math_sqrt((Math_fround($275)))));
  $277 = $276 > Math_fround(0.0);
  if ($277) {
   $278 = ((($rs$i) + (($i3$031*12)|0)|0) + 8|0);
   $279 = ((($rs$i) + (($i3$031*12)|0)|0) + 4|0);
   $280 = (($rs$i) + (($i3$031*12)|0)|0);
   $281 = Math_fround(Math_fround(1.0) / $276);
   $282 = Math_fround($269 * $281);
   HEAPF32[$280>>2] = $282;
   $283 = Math_fround($271 * $281);
   HEAPF32[$279>>2] = $283;
   $284 = Math_fround($274 * $281);
   HEAPF32[$278>>2] = $284;
  }
  $285 = (($i3$031) + 1)|0;
  $exitcond = ($285|0)==(8);
  if ($exitcond) {
   break;
  }
  $$phi$trans$insert = (($rs$i) + (($285*12)|0)|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$phi$trans$insert50 = ((($rs$i) + (($285*12)|0)|0) + 4|0);
  $$pre51 = Math_fround(HEAPF32[$$phi$trans$insert50>>2]);
  $$phi$trans$insert52 = ((($rs$i) + (($285*12)|0)|0) + 8|0);
  $$pre53 = Math_fround(HEAPF32[$$phi$trans$insert52>>2]);
  $269 = $$pre;$271 = $$pre51;$274 = $$pre53;$i3$031 = $285;
 }
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($158,$rs$i);
 $286 = (($this) + 864|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($286,$rs$i);
 $287 = (($this) + 1088|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($287,$rs$i);
 $288 = (($this) + 1312|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($288,$rs$i);
 $289 = (($this) + 1536|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($289,$rs$i);
 $290 = (($this) + 1760|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($290,$rs$i);
 $291 = (($this) + 1984|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($291,$rs$i);
 $292 = (($this) + 2208|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($292,$rs$i);
 $293 = (($this) + 2432|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($293,$rs$i);
 $294 = (($this) + 2656|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($294,$rs$i);
 $295 = (($this) + 2880|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($295,$rs$i);
 $296 = (($this) + 3104|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($296,$rs$i);
 $297 = (($this) + 3328|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($297,$rs$i);
 $298 = (($this) + 3552|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($298,$rs$i);
 $299 = (($this) + 3776|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($299,$rs$i);
 $300 = (($this) + 4000|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($300,$rs$i);
 $301 = (($this) + 4224|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($301,$rs$i);
 $302 = (($this) + 4448|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($302,$rs$i);
 $303 = (($this) + 4672|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($303,$rs$i);
 $304 = (($this) + 4896|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($304,$rs$i);
 $305 = (($this) + 5120|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($305,$rs$i);
 $306 = (($this) + 5344|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($306,$rs$i);
 $307 = (($this) + 5568|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($307,$rs$i);
 $308 = (($this) + 5792|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($308,$rs$i);
 $309 = (($this) + 6016|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($309,$rs$i);
 $310 = (($this) + 6240|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($310,$rs$i);
 $311 = (($this) + 6464|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($311,$rs$i);
 $312 = (($this) + 6688|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($312,$rs$i);
 $313 = (($this) + 6912|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($313,$rs$i);
 $314 = (($this) + 7136|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($314,$rs$i);
 $315 = (($this) + 7360|0);
 __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($315,$rs$i);
 STACKTOP = sp;return;
}
function __ZL15gPrecomputeSortRN5physx2Sq16BucketPrunerNodeEPKNS_6PxVec3E($node,$dirs) {
 $node = $node|0;
 $dirs = $dirs|0;
 var $$$$$$i = 0, $$$$$10$i = 0, $$$$$i = 0, $$$$7$i = 0, $$$$i = 0, $$$4$i = 0, $$$i = 0, $$0$i = 0, $$1$i = 0, $$11$i = 0, $$12$i = 0, $$2$i = 0, $$3$i = 0, $$5$i = 0, $$6$i = 0, $$8$i = 0, $$9$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0;
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $i$01 = 0, $phitmp = 0, $phitmp$i = 0, $phitmp13$i = 0, $phitmp14$i = 0, $phitmp15$i = 0, $phitmp16$i = 0, $phitmp17$i = 0, $phitmp18$i = 0, $phitmp19$i = 0;
 var $phitmp20$i = 0, $phitmp21$i = 0, $phitmp22$i = 0, $phitmp23$i = 0, $phitmp24$i = 0, $phitmp25$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($node) + 4|0);
 $1 = (($node) + 8|0);
 $2 = (($node) + 12|0);
 $3 = (($node) + 16|0);
 $4 = (($node) + 176|0);
 $5 = (($node) + 180|0);
 $6 = (($node) + 184|0);
 $7 = (($node) + 144|0);
 $8 = (($node) + 148|0);
 $9 = (($node) + 152|0);
 $10 = (($node) + 112|0);
 $11 = (($node) + 116|0);
 $12 = (($node) + 120|0);
 $13 = (($node) + 80|0);
 $14 = (($node) + 84|0);
 $15 = (($node) + 88|0);
 $16 = (($node) + 48|0);
 $17 = (($node) + 52|0);
 $18 = (($node) + 56|0);
 $i$01 = 0;
 while(1) {
  $19 = (($dirs) + (($i$01*12)|0)|0);
  $20 = HEAP32[$node>>2]|0;
  $21 = HEAP32[$0>>2]|0;
  $22 = (($21) + ($20))|0;
  $23 = HEAP32[$1>>2]|0;
  $24 = (($22) + ($23))|0;
  $25 = HEAP32[$2>>2]|0;
  $26 = (($24) + ($25))|0;
  $27 = HEAP32[$3>>2]|0;
  $28 = (($26) + ($27))|0;
  $29 = ($28>>>0)<(16);
  if ($29) {
   $$0$i = 18056;
  } else {
   $30 = ($20|0)==(0);
   if ($30) {
    $102 = 2139095032;
   } else {
    $31 = Math_fround(HEAPF32[$16>>2]);
    $32 = Math_fround(HEAPF32[$19>>2]);
    $33 = Math_fround($31 * $32);
    $34 = Math_fround(HEAPF32[$17>>2]);
    $35 = ((($dirs) + (($i$01*12)|0)|0) + 4|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = Math_fround($34 * $36);
    $38 = Math_fround($33 + $37);
    $39 = Math_fround(HEAPF32[$18>>2]);
    $40 = ((($dirs) + (($i$01*12)|0)|0) + 8|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = Math_fround($39 * $41);
    $43 = Math_fround($38 + $42);
    $phitmp$i = (HEAPF32[tempDoublePtr>>2]=$43,HEAP32[tempDoublePtr>>2]|0);
    $phitmp17$i = $phitmp$i & 2147483640;
    $102 = $phitmp17$i;
   }
   $44 = ($21|0)==(0);
   if ($44) {
    $101 = 2139095033;
   } else {
    $45 = Math_fround(HEAPF32[$13>>2]);
    $46 = Math_fround(HEAPF32[$19>>2]);
    $47 = Math_fround($45 * $46);
    $48 = Math_fround(HEAPF32[$14>>2]);
    $49 = ((($dirs) + (($i$01*12)|0)|0) + 4|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = Math_fround($48 * $50);
    $52 = Math_fround($47 + $51);
    $53 = Math_fround(HEAPF32[$15>>2]);
    $54 = ((($dirs) + (($i$01*12)|0)|0) + 8|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = Math_fround($53 * $55);
    $57 = Math_fround($52 + $56);
    $phitmp13$i = (HEAPF32[tempDoublePtr>>2]=$57,HEAP32[tempDoublePtr>>2]|0);
    $phitmp18$i = $phitmp13$i & 2147483640;
    $phitmp19$i = $phitmp18$i | 1;
    $101 = $phitmp19$i;
   }
   $58 = ($23|0)==(0);
   if ($58) {
    $104 = 2139095034;
   } else {
    $59 = Math_fround(HEAPF32[$10>>2]);
    $60 = Math_fround(HEAPF32[$19>>2]);
    $61 = Math_fround($59 * $60);
    $62 = Math_fround(HEAPF32[$11>>2]);
    $63 = ((($dirs) + (($i$01*12)|0)|0) + 4|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = Math_fround($62 * $64);
    $66 = Math_fround($61 + $65);
    $67 = Math_fround(HEAPF32[$12>>2]);
    $68 = ((($dirs) + (($i$01*12)|0)|0) + 8|0);
    $69 = Math_fround(HEAPF32[$68>>2]);
    $70 = Math_fround($67 * $69);
    $71 = Math_fround($66 + $70);
    $phitmp14$i = (HEAPF32[tempDoublePtr>>2]=$71,HEAP32[tempDoublePtr>>2]|0);
    $phitmp20$i = $phitmp14$i & 2147483640;
    $phitmp21$i = $phitmp20$i | 2;
    $104 = $phitmp21$i;
   }
   $72 = ($25|0)==(0);
   if ($72) {
    $108 = 2139095035;
   } else {
    $73 = Math_fround(HEAPF32[$7>>2]);
    $74 = Math_fround(HEAPF32[$19>>2]);
    $75 = Math_fround($73 * $74);
    $76 = Math_fround(HEAPF32[$8>>2]);
    $77 = ((($dirs) + (($i$01*12)|0)|0) + 4|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = Math_fround($76 * $78);
    $80 = Math_fround($75 + $79);
    $81 = Math_fround(HEAPF32[$9>>2]);
    $82 = ((($dirs) + (($i$01*12)|0)|0) + 8|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = Math_fround($81 * $83);
    $85 = Math_fround($80 + $84);
    $phitmp15$i = (HEAPF32[tempDoublePtr>>2]=$85,HEAP32[tempDoublePtr>>2]|0);
    $phitmp22$i = $phitmp15$i & 2147483640;
    $phitmp23$i = $phitmp22$i | 3;
    $108 = $phitmp23$i;
   }
   $86 = ($27|0)==(0);
   if ($86) {
    $110 = 2139095036;
   } else {
    $87 = Math_fround(HEAPF32[$4>>2]);
    $88 = Math_fround(HEAPF32[$19>>2]);
    $89 = Math_fround($87 * $88);
    $90 = Math_fround(HEAPF32[$5>>2]);
    $91 = ((($dirs) + (($i$01*12)|0)|0) + 4|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = Math_fround($90 * $92);
    $94 = Math_fround($89 + $93);
    $95 = Math_fround(HEAPF32[$6>>2]);
    $96 = ((($dirs) + (($i$01*12)|0)|0) + 8|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = Math_fround($95 * $97);
    $99 = Math_fround($94 + $98);
    $phitmp16$i = (HEAPF32[tempDoublePtr>>2]=$99,HEAP32[tempDoublePtr>>2]|0);
    $phitmp24$i = $phitmp16$i & 2147483640;
    $phitmp25$i = $phitmp24$i | 4;
    $110 = $phitmp25$i;
   }
   $100 = ($101>>>0)<($102>>>0);
   $$$i = $100 ? $101 : $102;
   $$1$i = $100 ? $102 : $101;
   $103 = ($104>>>0)<($$1$i>>>0);
   $105 = $103 ? $104 : $$1$i;
   $106 = $103 ? $$1$i : $104;
   $107 = ($108>>>0)<($106>>>0);
   $$2$i = $107 ? $108 : $106;
   $$3$i = $107 ? $106 : $108;
   $109 = ($110>>>0)<($$3$i>>>0);
   $111 = $109 ? $110 : $$3$i;
   $112 = $109 ? $$3$i : $110;
   $113 = ($105>>>0)<($$$i>>>0);
   $$$$i = $113 ? $105 : $$$i;
   $$$4$i = $113 ? $$$i : $105;
   $114 = ($$2$i>>>0)<($$$4$i>>>0);
   $115 = $114 ? $$2$i : $$$4$i;
   $116 = $114 ? $$$4$i : $$2$i;
   $117 = ($111>>>0)<($116>>>0);
   $$5$i = $117 ? $111 : $116;
   $$6$i = $117 ? $116 : $111;
   $118 = ($112>>>0)<($$6$i>>>0);
   $119 = $118 ? $112 : $$6$i;
   $120 = $118 ? $$6$i : $112;
   $121 = ($115>>>0)<($$$$i>>>0);
   $$$$$i = $121 ? $115 : $$$$i;
   $$$$7$i = $121 ? $$$$i : $115;
   $122 = ($$5$i>>>0)<($$$$7$i>>>0);
   $123 = $122 ? $$5$i : $$$$7$i;
   $124 = $122 ? $$$$7$i : $$5$i;
   $125 = ($119>>>0)<($124>>>0);
   $$8$i = $125 ? $119 : $124;
   $$9$i = $125 ? $124 : $119;
   $126 = ($120>>>0)<($$9$i>>>0);
   $127 = $126 ? $120 : $$9$i;
   $128 = $126 ? $$9$i : $120;
   $129 = ($123>>>0)<($$$$$i>>>0);
   $$$$$$i = $129 ? $123 : $$$$$i;
   $$$$$10$i = $129 ? $$$$$i : $123;
   $130 = ($$8$i>>>0)<($$$$$10$i>>>0);
   $131 = $130 ? $$8$i : $$$$$10$i;
   $132 = $130 ? $$$$$10$i : $$8$i;
   $133 = ($127>>>0)<($132>>>0);
   $$11$i = $133 ? $127 : $132;
   $$12$i = $133 ? $132 : $127;
   $134 = ($128>>>0)<($$12$i>>>0);
   $135 = $134 ? $128 : $$12$i;
   $136 = $134 ? $$12$i : $128;
   $137 = $$$$$$i & 7;
   $138 = $131 << 3;
   $139 = $138 & 56;
   $140 = $139 | $137;
   $141 = $$11$i << 6;
   $142 = $141 & 448;
   $143 = $140 | $142;
   $144 = $135 << 9;
   $145 = $144 & 3584;
   $146 = $143 | $145;
   $147 = $136 << 12;
   $148 = $147 & 28672;
   $149 = $146 | $148;
   $phitmp = $149&65535;
   $$0$i = $phitmp;
  }
  $150 = ((($node) + ($i$01<<1)|0) + 208|0);
  HEAP16[$150>>1] = $$0$i;
  $151 = (($i$01) + 1)|0;
  $exitcond = ($151|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $151;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sq16BucketPrunerCore7raycastERKNS_6PxVec3ES4_RfRNS0_14PrunerCallbackE($this,$origin,$unitDir,$inOutDistance,$pcb) {
 $this = $this|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $inOutDistance = $inOutDistance|0;
 $pcb = $pcb|0;
 var $$$i$i$i$i = Math_fround(0), $$$i$i$i$i$i = Math_fround(0), $$$i$i$i$i23$i = Math_fround(0), $$$i$i$i$i37$i = Math_fround(0), $$$i$i$i$i53$i = Math_fround(0), $$$i$i$i$i67$i = Math_fround(0), $$$i$i$i$i9$i = Math_fround(0), $$$i8$i$i$i = Math_fround(0), $$0$i = 0, $$0$i$i$i = 0, $$0$i1$i$i = 0, $$0$i51$i = 0, $$0$i52$i = 0, $$1$i$i$i$i = Math_fround(0), $$1$i$i$i$i$i = Math_fround(0), $$1$i$i$i$i18$i = Math_fround(0), $$1$i$i$i$i32$i = Math_fround(0), $$1$i$i$i$i46$i = Math_fround(0), $$1$i$i$i$i62$i = Math_fround(0), $$1$i$i$i$i76$i = Math_fround(0);
 var $$1$i9$i$i$i = Math_fround(0), $$296$i$i$i = 0, $$296$i$i16$i = 0, $$296$i$i30$i = 0, $$296$i$i44$i = 0, $$296$i$i60$i = 0, $$296$i$i74$i = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre88$i = 0, $$sum$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0);
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0;
 var $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0);
 var $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0);
 var $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0);
 var $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0;
 var $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0);
 var $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0;
 var $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0);
 var $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0);
 var $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = Math_fround(0), $330 = 0, $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = 0, $34 = 0;
 var $340 = Math_fround(0), $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = 0;
 var $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0);
 var $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0);
 var $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0);
 var $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = Math_fround(0), $455 = 0, $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0), $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0);
 var $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0);
 var $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0);
 var $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = Math_fround(0), $515 = 0, $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0;
 var $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = Math_fround(0);
 var $539 = 0, $54 = 0, $540 = Math_fround(0), $541 = 0, $542 = Math_fround(0), $543 = 0, $544 = Math_fround(0), $545 = 0, $546 = Math_fround(0), $547 = 0, $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0);
 var $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0);
 var $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = 0;
 var $593 = Math_fround(0), $594 = 0, $595 = 0, $596 = 0, $597 = Math_fround(0), $598 = Math_fround(0), $599 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = 0, $608 = 0, $609 = 0, $61 = 0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = Math_fround(0), $627 = 0, $628 = Math_fround(0);
 var $629 = 0, $63 = 0, $630 = Math_fround(0), $631 = 0, $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = 0, $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0);
 var $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0);
 var $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = 0, $68 = Math_fround(0), $680 = 0, $681 = Math_fround(0), $682 = 0;
 var $683 = 0, $684 = 0, $685 = Math_fround(0), $686 = Math_fround(0), $687 = 0, $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = Math_fround(0), $70 = Math_fround(0);
 var $700 = Math_fround(0), $701 = 0, $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = 0, $708 = Math_fround(0), $709 = 0, $71 = 0, $710 = 0, $711 = Math_fround(0), $712 = 0, $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0);
 var $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = 0, $726 = 0, $727 = Math_fround(0), $728 = 0, $729 = 0, $73 = Math_fround(0), $730 = 0, $731 = Math_fround(0), $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0;
 var $737 = 0, $738 = 0, $739 = 0, $74 = Math_fround(0), $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = Math_fround(0), $747 = 0, $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_boxes$0$ph18$i$i = 0, $_boxes$05$i$i = 0, $_objects$0$ph17$i$i = 0, $_objects$04$i$i = 0, $brmerge$demorgan$i$i$i = 0, $brmerge$demorgan$i$i17$i = 0, $brmerge$demorgan$i$i31$i = 0, $brmerge$demorgan$i$i45$i = 0, $brmerge$demorgan$i$i61$i = 0, $brmerge$demorgan$i$i75$i = 0, $currentDist$i = 0, $exitcond = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0);
 var $i$065$i = 0, $i1$058$i = 0, $i_$055$i = 0, $j_$051$i = 0, $k_$046$i = 0, $not$$i$i$i = 0, $not$$i$i15$i = 0, $not$$i$i29$i = 0, $not$$i$i43$i = 0, $not$$i$i59$i = 0, $not$$i$i73$i = 0, $not$300$i$i$i = 0, $not$300$i$i12$i = 0, $not$300$i$i26$i = 0, $not$300$i$i40$i = 0, $not$300$i$i56$i = 0, $not$300$i$i70$i = 0, $not$305$i$i$i = 0, $not$305$i$i21$i = 0, $not$305$i$i35$i = 0;
 var $not$305$i$i49$i = 0, $not$305$i$i65$i = 0, $not$305$i$i79$i = 0, $notlhs301$i$i$i = 0, $notlhs301$i$i10$i = 0, $notlhs301$i$i24$i = 0, $notlhs301$i$i38$i = 0, $notlhs301$i$i54$i = 0, $notlhs301$i$i68$i = 0, $notlhs303$i$i$i = 0, $notlhs303$i$i13$i = 0, $notlhs303$i$i27$i = 0, $notlhs303$i$i41$i = 0, $notlhs303$i$i57$i = 0, $notlhs303$i$i71$i = 0, $notlhs306$i$i$i = 0, $notlhs306$i$i19$i = 0, $notlhs306$i$i33$i = 0, $notlhs306$i$i47$i = 0, $notlhs306$i$i63$i = 0;
 var $notlhs306$i$i77$i = 0, $notrhs302$i$i$i = 0, $notrhs302$i$i11$i = 0, $notrhs302$i$i25$i = 0, $notrhs302$i$i39$i = 0, $notrhs302$i$i55$i = 0, $notrhs302$i$i69$i = 0, $notrhs304$i$i$i = 0, $notrhs304$i$i14$i = 0, $notrhs304$i$i28$i = 0, $notrhs304$i$i42$i = 0, $notrhs304$i$i58$i = 0, $notrhs304$i$i72$i = 0, $notrhs307$i$i$i = 0, $notrhs307$i$i20$i = 0, $notrhs307$i$i34$i = 0, $notrhs307$i$i48$i = 0, $notrhs307$i$i64$i = 0, $notrhs307$i$i78$i = 0, $orderi$056$i = 0;
 var $orderj$052$i = 0, $orderk$045$i = 0, $rayDir$idx$val$i = Math_fround(0), $rayDir$idx3$i = 0, $rayDir$idx3$val$i = Math_fround(0), $rayDir$idx4$i = 0, $rayDir$idx4$val$i = Math_fround(0), $rayMaxLimitInt$0$ph10$i1654$i = 0, $rayMaxLimitInt$0$ph10$i17$i = 0, $rayMaxLimitInt$0$ph10$i1850$i = 0, $rayMaxLimitInt$0$ph10$i19$i = 0, $rayMaxLimitInt$0$ph10$i2044$i = 0, $rayMaxLimitInt$0$ph10$i21$i = 0, $rayMaxLimitInt$0$ph15$i$i = 0, $rayMinLimitInt$0$ph14$i2353$i = 0, $rayMinLimitInt$0$ph14$i24$i = 0, $rayMinLimitInt$0$ph14$i2549$i = 0, $rayMinLimitInt$0$ph14$i26$i = 0, $rayMinLimitInt$0$ph14$i2743$i = 0, $rayMinLimitInt$0$ph14$i28$i = 0;
 var $rayMinLimitInt$0$ph16$i$i = 0, $rayOrig$idx$val$i = Math_fround(0), $rayOrig$idx1$i = 0, $rayOrig$idx1$val$i = Math_fround(0), $rayOrig$idx2$i = 0, $rayOrig$idx2$val$i = Math_fround(0), $test$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $test$i = sp;
 $0 = sp + 132|0;
 $currentDist$i = sp + 128|0;
 $1 = Math_fround(HEAPF32[$inOutDistance>>2]);
 $2 = $1 == Math_fround(3.40282346638528859812E+38);
 if ($2) {
  $3 = (($this) + 608|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($this) + 624|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 - $6);
  $8 = (($this) + 612|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($this) + 628|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($9 - $11);
  $13 = (($this) + 616|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($this) + 632|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($14 - $16);
  $18 = Math_fround($4 + $6);
  $19 = Math_fround($9 + $11);
  $20 = Math_fround($14 + $16);
  $21 = Math_fround($18 + Math_fround(0.0));
  $22 = Math_fround($19 + Math_fround(0.0));
  $23 = Math_fround($20 + Math_fround(0.0));
  $24 = (($this) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0);
  if ($26) {
   $74 = $21;$75 = $7;$77 = $22;$78 = $12;$80 = $23;$81 = $17;
  } else {
   $30 = Math_fround(8.50705866596322149529E+37);$35 = Math_fround(8.50705866596322149529E+37);$40 = Math_fround(8.50705866596322149529E+37);$45 = Math_fround(-8.50705866596322149529E+37);$50 = Math_fround(-8.50705866596322149529E+37);$55 = Math_fround(-8.50705866596322149529E+37);$i$065$i = 0;
   while(1) {
    $27 = ((($this) + (($i$065$i*24)|0)|0) + 160|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = $30 < $28;
    $31 = $29 ? $30 : $28;
    $32 = ((($this) + (($i$065$i*24)|0)|0) + 164|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = $35 < $33;
    $36 = $34 ? $35 : $33;
    $37 = ((($this) + (($i$065$i*24)|0)|0) + 168|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = $40 < $38;
    $41 = $39 ? $40 : $38;
    $42 = ((($this) + (($i$065$i*24)|0)|0) + 172|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = $45 > $43;
    $46 = $44 ? $45 : $43;
    $47 = ((($this) + (($i$065$i*24)|0)|0) + 176|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = $50 > $48;
    $51 = $49 ? $50 : $48;
    $52 = ((($this) + (($i$065$i*24)|0)|0) + 180|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = $55 > $53;
    $56 = $54 ? $55 : $53;
    $57 = (($i$065$i) + 1)|0;
    $exitcond = ($57|0)==($25|0);
    if ($exitcond) {
     break;
    } else {
     $30 = $31;$35 = $36;$40 = $41;$45 = $46;$50 = $51;$55 = $56;$i$065$i = $57;
    }
   }
   $58 = Math_fround($46 + Math_fround(0.0));
   $59 = Math_fround($51 + Math_fround(0.0));
   $60 = Math_fround($56 + Math_fround(0.0));
   $61 = $7 < $31;
   $62 = $61 ? $7 : $31;
   $63 = $12 < $36;
   $64 = $63 ? $12 : $36;
   $65 = $17 < $41;
   $66 = $65 ? $17 : $41;
   $67 = $21 > $58;
   $68 = $67 ? $21 : $58;
   $69 = $22 > $59;
   $70 = $69 ? $22 : $59;
   $71 = $23 > $60;
   $72 = $71 ? $23 : $60;
   $74 = $68;$75 = $62;$77 = $70;$78 = $64;$80 = $72;$81 = $66;
  }
  $rayOrig$idx$val$i = Math_fround(HEAPF32[$origin>>2]);
  $rayOrig$idx1$i = (($origin) + 4|0);
  $rayOrig$idx1$val$i = Math_fround(HEAPF32[$rayOrig$idx1$i>>2]);
  $rayOrig$idx2$i = (($origin) + 8|0);
  $rayOrig$idx2$val$i = Math_fround(HEAPF32[$rayOrig$idx2$i>>2]);
  $rayDir$idx$val$i = Math_fround(HEAPF32[$unitDir>>2]);
  $rayDir$idx3$i = (($unitDir) + 4|0);
  $rayDir$idx3$val$i = Math_fround(HEAPF32[$rayDir$idx3$i>>2]);
  $rayDir$idx4$i = (($unitDir) + 8|0);
  $rayDir$idx4$val$i = Math_fround(HEAPF32[$rayDir$idx4$i>>2]);
  $73 = Math_fround($75 + $74);
  $76 = Math_fround($78 + $77);
  $79 = Math_fround($81 + $80);
  $82 = Math_fround($73 * Math_fround(0.5));
  $83 = Math_fround($76 * Math_fround(0.5));
  $84 = Math_fround($79 * Math_fround(0.5));
  $85 = Math_fround($74 - $75);
  $86 = Math_fround($77 - $78);
  $87 = Math_fround($80 - $81);
  $88 = Math_fround($85 * Math_fround(0.5));
  $89 = Math_fround($86 * Math_fround(0.5));
  $90 = Math_fround($87 * Math_fround(0.5));
  $91 = Math_fround($82 * $rayDir$idx$val$i);
  $92 = Math_fround($83 * $rayDir$idx3$val$i);
  $93 = Math_fround($91 + $92);
  $94 = Math_fround($84 * $rayDir$idx4$val$i);
  $95 = Math_fround($93 + $94);
  $96 = Math_fround($88 * $88);
  $97 = Math_fround($89 * $89);
  $98 = Math_fround($97 + $96);
  $99 = Math_fround($90 * $90);
  $100 = Math_fround($99 + $98);
  $101 = (Math_fround(Math_sqrt((Math_fround($100)))));
  $102 = Math_fround($95 - $101);
  $103 = Math_fround($101 + $95);
  $104 = Math_fround($rayOrig$idx$val$i * $rayDir$idx$val$i);
  $105 = Math_fround($rayOrig$idx1$val$i * $rayDir$idx3$val$i);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($rayOrig$idx2$val$i * $rayDir$idx4$val$i);
  $108 = Math_fround($106 + $107);
  $109 = Math_fround($101 * Math_fround(2.0));
  $110 = Math_fround($102 - $108);
  $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($110)))));
  $111 = Math_fround($103 - $108);
  $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($111)))));
  $112 = $fabsf$i$i1$i$i < $fabsf$i$i$i$i;
  $113 = $112 ? $fabsf$i$i1$i$i : $fabsf$i$i$i$i;
  $114 = Math_fround($109 * Math_fround(2.0));
  $115 = Math_fround($114 + $113);
  HEAPF32[$inOutDistance>>2] = $115;
  $$pre$phi$iZ2D = $24;$118 = $115;
 } else {
  $$pre88$i = (($this) + 28|0);
  $$pre$phi$iZ2D = $$pre88$i;$118 = $1;
 }
 HEAPF32[$0>>2] = Math_fround(0.0);
 $116 = (($0) + 4|0);
 HEAPF32[$116>>2] = Math_fround(0.0);
 $117 = (($0) + 8|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 __ZN5physx2Gu11RayAABBTestC2ERKNS_6PxVec3ES4_fS4_($test$i,$origin,$unitDir,$118,$0);
 $119 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 $120 = ($119|0)==(0);
 L10: do {
  if (!($120)) {
   $121 = (($test$i) + 4|0);
   $122 = (($test$i) + 8|0);
   $123 = (($test$i) + 32|0);
   $124 = (($test$i) + 36|0);
   $125 = (($test$i) + 40|0);
   $126 = (($test$i) + 16|0);
   $127 = (($test$i) + 20|0);
   $128 = (($test$i) + 24|0);
   $129 = (($test$i) + 80|0);
   $130 = (($test$i) + 84|0);
   $131 = (($test$i) + 64|0);
   $132 = (($test$i) + 68|0);
   $133 = (($test$i) + 96|0);
   $134 = (($test$i) + 100|0);
   $135 = (($test$i) + 112|0);
   $136 = (($test$i) + 116|0);
   $137 = (($test$i) + 72|0);
   $138 = (($test$i) + 88|0);
   $139 = (($test$i) + 120|0);
   $140 = (($test$i) + 104|0);
   $747 = $119;$i1$058$i = 0;
   while(1) {
    $141 = ((($this) + (($i1$058$i*24)|0)|0) + 160|0);
    $142 = Math_fround(HEAPF32[$141>>2]);
    $143 = ((($this) + (($i1$058$i*24)|0)|0) + 172|0);
    $144 = Math_fround(HEAPF32[$143>>2]);
    $145 = Math_fround($142 + $144);
    $146 = ((($this) + (($i1$058$i*24)|0)|0) + 164|0);
    $147 = Math_fround(HEAPF32[$146>>2]);
    $148 = ((($this) + (($i1$058$i*24)|0)|0) + 176|0);
    $149 = Math_fround(HEAPF32[$148>>2]);
    $150 = Math_fround($147 + $149);
    $151 = ((($this) + (($i1$058$i*24)|0)|0) + 168|0);
    $152 = Math_fround(HEAPF32[$151>>2]);
    $153 = ((($this) + (($i1$058$i*24)|0)|0) + 180|0);
    $154 = Math_fround(HEAPF32[$153>>2]);
    $155 = Math_fround($152 + $154);
    $156 = Math_fround($145 * Math_fround(0.5));
    $157 = Math_fround($150 * Math_fround(0.5));
    $158 = Math_fround($155 * Math_fround(0.5));
    $159 = Math_fround($144 - $142);
    $160 = Math_fround($149 - $147);
    $161 = Math_fround($154 - $152);
    $162 = Math_fround($159 * Math_fround(0.5));
    $163 = Math_fround($160 * Math_fround(0.5));
    $164 = Math_fround($161 * Math_fround(0.5));
    $165 = Math_fround($156 + $162);
    $166 = Math_fround($157 + $163);
    $167 = Math_fround($156 - $162);
    $168 = Math_fround($157 - $163);
    $169 = Math_fround(HEAPF32[$test$i>>2]);
    $170 = Math_fround(HEAPF32[$121>>2]);
    $171 = Math_fround(HEAPF32[$122>>2]);
    $172 = Math_fround($169 - $156);
    $173 = Math_fround($170 - $157);
    $174 = Math_fround($171 - $158);
    $175 = Math_fround(HEAPF32[$123>>2]);
    $176 = Math_fround(HEAPF32[$124>>2]);
    $177 = Math_fround(HEAPF32[$125>>2]);
    $178 = Math_fround(HEAPF32[$126>>2]);
    $179 = Math_fround(HEAPF32[$127>>2]);
    $180 = Math_fround(HEAPF32[$128>>2]);
    $181 = Math_fround($173 * $178);
    $182 = Math_fround($174 * $179);
    $183 = Math_fround($172 * $180);
    $184 = Math_fround($172 * $175);
    $185 = Math_fround($173 * $176);
    $186 = Math_fround($174 * $177);
    $187 = Math_fround($181 - $184);
    $188 = Math_fround($182 - $185);
    $189 = Math_fround($183 - $186);
    $190 = Math_fround(HEAPF32[$129>>2]);
    $191 = Math_fround(HEAPF32[$130>>2]);
    $192 = Math_fround(HEAPF32[$131>>2]);
    $193 = Math_fround(HEAPF32[$132>>2]);
    $194 = Math_fround($163 * $192);
    $195 = Math_fround($164 * $193);
    $196 = Math_fround($162 * $190);
    $197 = Math_fround($163 * $191);
    $198 = Math_fround($196 + $194);
    $199 = Math_fround($197 + $195);
    $200 = Math_fround(HEAPF32[$133>>2]);
    $201 = Math_fround(HEAPF32[$134>>2]);
    $202 = Math_fround(HEAPF32[$135>>2]);
    $203 = Math_fround(HEAPF32[$136>>2]);
    $204 = Math_fround(-$187);
    $205 = Math_fround(-$188);
    $206 = Math_fround(-$189);
    $207 = $187 > $204;
    $$$i$i$i$i67$i = $207 ? $187 : $204;
    $208 = $188 > $205;
    $209 = $208 ? $188 : $205;
    $210 = $198 >= $$$i$i$i$i67$i;
    $211 = $199 >= $209;
    $notlhs301$i$i68$i = $165 >= $200;
    $notrhs302$i$i69$i = $202 >= $167;
    $not$300$i$i70$i = $notrhs302$i$i69$i & $notlhs301$i$i68$i;
    $212 = $210 & $not$300$i$i70$i;
    $notlhs303$i$i71$i = $166 >= $201;
    $notrhs304$i$i72$i = $203 >= $168;
    $not$$i$i73$i = $notrhs304$i$i72$i & $notlhs303$i$i71$i;
    $$296$i$i74$i = $211 & $not$$i$i73$i;
    $brmerge$demorgan$i$i75$i = $212 & $$296$i$i74$i;
    if ($brmerge$demorgan$i$i75$i) {
     $213 = Math_fround(HEAPF32[$137>>2]);
     $214 = Math_fround(HEAPF32[$138>>2]);
     $215 = $189 > $206;
     $216 = Math_fround($164 * $214);
     $217 = Math_fround($162 * $213);
     $$1$i$i$i$i76$i = $215 ? $189 : $206;
     $218 = Math_fround($217 + $216);
     $219 = Math_fround(HEAPF32[$139>>2]);
     $220 = Math_fround($158 - $164);
     $221 = Math_fround($158 + $164);
     $222 = Math_fround(HEAPF32[$140>>2]);
     $223 = $218 >= $$1$i$i$i$i76$i;
     $notlhs306$i$i77$i = $221 >= $222;
     $notrhs307$i$i78$i = $219 >= $220;
     $not$305$i$i79$i = $notrhs307$i$i78$i & $notlhs306$i$i77$i;
     $224 = $223 & $not$305$i$i79$i;
     if ($224) {
      $225 = HEAP32[$pcb>>2]|0;
      $226 = HEAP32[$225>>2]|0;
      $227 = ((($this) + ($i1$058$i<<3)|0) + 32|0);
      $228 = (FUNCTION_TABLE_iiiii[$226 & 511]($pcb,$inOutDistance,$227,1)|0);
      if (!($228)) {
       $$0$i = 0;
       break;
      }
      $$pre$i = HEAP32[$$pre$phi$iZ2D>>2]|0;
      $231 = $$pre$i;
     } else {
      $231 = $747;
     }
    } else {
     $231 = $747;
    }
    $229 = (($i1$058$i) + 1)|0;
    $230 = ($229>>>0)<($231>>>0);
    if ($230) {
     $747 = $231;$i1$058$i = $229;
    } else {
     break L10;
    }
   }
   STACKTOP = sp;return ($$0$i|0);
  }
 } while(0);
 $232 = (($this) + 584|0);
 $233 = HEAP32[$232>>2]|0;
 $234 = ($233|0)==(0);
 if ($234) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $235 = (($this) + 608|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = (($this) + 612|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = (($this) + 616|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 $241 = (($this) + 624|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 $243 = (($this) + 628|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = (($this) + 632|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = Math_fround($236 + $242);
 $248 = Math_fround($238 + $244);
 $249 = Math_fround($236 - $242);
 $250 = Math_fround($238 - $244);
 $251 = Math_fround(HEAPF32[$test$i>>2]);
 $252 = (($test$i) + 4|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = (($test$i) + 8|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = Math_fround($251 - $236);
 $257 = Math_fround($253 - $238);
 $258 = Math_fround($255 - $240);
 $259 = (($test$i) + 32|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = (($test$i) + 36|0);
 $262 = Math_fround(HEAPF32[$261>>2]);
 $263 = (($test$i) + 40|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = (($test$i) + 16|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = (($test$i) + 20|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = (($test$i) + 24|0);
 $270 = Math_fround(HEAPF32[$269>>2]);
 $271 = Math_fround($257 * $266);
 $272 = Math_fround($258 * $268);
 $273 = Math_fround($256 * $270);
 $274 = Math_fround($256 * $260);
 $275 = Math_fround($257 * $262);
 $276 = Math_fround($258 * $264);
 $277 = Math_fround($271 - $274);
 $278 = Math_fround($272 - $275);
 $279 = Math_fround($273 - $276);
 $280 = (($test$i) + 80|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = (($test$i) + 84|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = (($test$i) + 64|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = (($test$i) + 68|0);
 $287 = Math_fround(HEAPF32[$286>>2]);
 $288 = Math_fround($244 * $285);
 $289 = Math_fround($246 * $287);
 $290 = Math_fround($242 * $281);
 $291 = Math_fround($244 * $283);
 $292 = Math_fround($290 + $288);
 $293 = Math_fround($291 + $289);
 $294 = (($test$i) + 96|0);
 $295 = Math_fround(HEAPF32[$294>>2]);
 $296 = (($test$i) + 100|0);
 $297 = Math_fround(HEAPF32[$296>>2]);
 $298 = (($test$i) + 112|0);
 $299 = Math_fround(HEAPF32[$298>>2]);
 $300 = (($test$i) + 116|0);
 $301 = Math_fround(HEAPF32[$300>>2]);
 $302 = Math_fround(-$277);
 $303 = Math_fround(-$278);
 $304 = Math_fround(-$279);
 $305 = $277 > $302;
 $$$i$i$i$i53$i = $305 ? $277 : $302;
 $306 = $278 > $303;
 $307 = $306 ? $278 : $303;
 $308 = $292 >= $$$i$i$i$i53$i;
 $309 = $293 >= $307;
 $notlhs301$i$i54$i = $247 >= $295;
 $notrhs302$i$i55$i = $299 >= $249;
 $not$300$i$i56$i = $notrhs302$i$i55$i & $notlhs301$i$i54$i;
 $310 = $308 & $not$300$i$i56$i;
 $notlhs303$i$i57$i = $248 >= $297;
 $notrhs304$i$i58$i = $301 >= $250;
 $not$$i$i59$i = $notrhs304$i$i58$i & $notlhs303$i$i57$i;
 $$296$i$i60$i = $309 & $not$$i$i59$i;
 $brmerge$demorgan$i$i61$i = $310 & $$296$i$i60$i;
 if (!($brmerge$demorgan$i$i61$i)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $311 = (($test$i) + 72|0);
 $312 = (($test$i) + 88|0);
 $313 = Math_fround(HEAPF32[$311>>2]);
 $314 = Math_fround(HEAPF32[$312>>2]);
 $315 = $279 > $304;
 $316 = Math_fround($246 * $314);
 $317 = Math_fround($242 * $313);
 $$1$i$i$i$i62$i = $315 ? $279 : $304;
 $318 = (($test$i) + 120|0);
 $319 = (($test$i) + 104|0);
 $320 = Math_fround($317 + $316);
 $321 = Math_fround(HEAPF32[$318>>2]);
 $322 = Math_fround($240 - $246);
 $323 = Math_fround($240 + $246);
 $324 = Math_fround(HEAPF32[$319>>2]);
 $325 = $320 >= $$1$i$i$i$i62$i;
 $notlhs306$i$i63$i = $323 >= $324;
 $notrhs307$i$i64$i = $321 >= $322;
 $not$305$i$i65$i = $notrhs307$i$i64$i & $notlhs306$i$i63$i;
 $326 = $325 & $not$305$i$i65$i;
 if (!($326)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $327 = (($this) + 592|0);
 $328 = HEAP32[$327>>2]|0;
 $329 = Math_fround(HEAPF32[$inOutDistance>>2]);
 $330 = (($origin) + ($328<<2)|0);
 $331 = Math_fround(HEAPF32[$330>>2]);
 $332 = (($unitDir) + ($328<<2)|0);
 $333 = Math_fround(HEAPF32[$332>>2]);
 $334 = Math_fround($329 * $333);
 $335 = Math_fround($331 + $334);
 $336 = $331 < $335;
 $337 = $336 ? $331 : $335;
 $338 = (HEAPF32[tempDoublePtr>>2]=$337,HEAP32[tempDoublePtr>>2]|0);
 $339 = $331 > $335;
 $340 = $339 ? $331 : $335;
 $341 = (HEAPF32[tempDoublePtr>>2]=$340,HEAP32[tempDoublePtr>>2]|0);
 $342 = ($338|0)<(0);
 $343 = $338 ^ -1;
 $344 = $338 | -2147483648;
 $$0$i52$i = $342 ? $343 : $344;
 $345 = ($341|0)<(0);
 $346 = $341 ^ -1;
 $347 = $341 | -2147483648;
 $$0$i51$i = $345 ? $346 : $347;
 HEAPF32[$currentDist$i>>2] = $329;
 $348 = HEAP32[$unitDir>>2]|0;
 $349 = $348 >>> 31;
 $350 = (($unitDir) + 4|0);
 $351 = HEAP32[$350>>2]|0;
 $352 = $351 >>> 31;
 $353 = (($unitDir) + 8|0);
 $354 = HEAP32[$353>>2]|0;
 $355 = $354 >>> 31;
 $356 = $352 << 1;
 $357 = $349 << 2;
 $358 = $356 | $357;
 $359 = $358 | $355;
 $360 = ((($this) + ($359<<1)|0) + 848|0);
 $361 = HEAP16[$360>>1]|0;
 $362 = $361&65535;
 $363 = (($this) + 20|0);
 $364 = (($this) + 24|0);
 $365 = (($test$i) + 108|0);
 $366 = (($test$i) + 124|0);
 $748 = $329;$i_$055$i = 0;$orderi$056$i = $362;$rayMaxLimitInt$0$ph10$i1654$i = $$0$i51$i;$rayMinLimitInt$0$ph14$i2353$i = $$0$i52$i;
 L30: while(1) {
  $367 = $orderi$056$i & 7;
  $368 = $orderi$056$i >>> 3;
  $369 = ((($this) + ($367<<2)|0) + 640|0);
  $370 = HEAP32[$369>>2]|0;
  $371 = ($370|0)==(0);
  if ($371) {
   $746 = $748;$rayMaxLimitInt$0$ph10$i17$i = $rayMaxLimitInt$0$ph10$i1654$i;$rayMinLimitInt$0$ph14$i24$i = $rayMinLimitInt$0$ph14$i2353$i;
  } else {
   $372 = ((($this) + ($367<<5)|0) + 688|0);
   $373 = Math_fround(HEAPF32[$372>>2]);
   $374 = ((($this) + ($367<<5)|0) + 692|0);
   $375 = Math_fround(HEAPF32[$374>>2]);
   $376 = ((($this) + ($367<<5)|0) + 696|0);
   $377 = Math_fround(HEAPF32[$376>>2]);
   $378 = ((($this) + ($367<<5)|0) + 704|0);
   $379 = Math_fround(HEAPF32[$378>>2]);
   $380 = ((($this) + ($367<<5)|0) + 708|0);
   $381 = Math_fround(HEAPF32[$380>>2]);
   $382 = ((($this) + ($367<<5)|0) + 712|0);
   $383 = Math_fround(HEAPF32[$382>>2]);
   $384 = Math_fround($373 + $379);
   $385 = Math_fround($375 + $381);
   $386 = Math_fround($373 - $379);
   $387 = Math_fround($375 - $381);
   $388 = Math_fround(HEAPF32[$test$i>>2]);
   $389 = Math_fround(HEAPF32[$252>>2]);
   $390 = Math_fround(HEAPF32[$254>>2]);
   $391 = Math_fround($388 - $373);
   $392 = Math_fround($389 - $375);
   $393 = Math_fround($390 - $377);
   $394 = Math_fround(HEAPF32[$259>>2]);
   $395 = Math_fround(HEAPF32[$261>>2]);
   $396 = Math_fround(HEAPF32[$263>>2]);
   $397 = Math_fround(HEAPF32[$265>>2]);
   $398 = Math_fround(HEAPF32[$267>>2]);
   $399 = Math_fround(HEAPF32[$269>>2]);
   $400 = Math_fround($392 * $397);
   $401 = Math_fround($393 * $398);
   $402 = Math_fround($391 * $399);
   $403 = Math_fround($391 * $394);
   $404 = Math_fround($392 * $395);
   $405 = Math_fround($393 * $396);
   $406 = Math_fround($400 - $403);
   $407 = Math_fround($401 - $404);
   $408 = Math_fround($402 - $405);
   $409 = Math_fround(HEAPF32[$280>>2]);
   $410 = Math_fround(HEAPF32[$282>>2]);
   $411 = Math_fround(HEAPF32[$284>>2]);
   $412 = Math_fround(HEAPF32[$286>>2]);
   $413 = Math_fround($381 * $411);
   $414 = Math_fround($383 * $412);
   $415 = Math_fround($379 * $409);
   $416 = Math_fround($381 * $410);
   $417 = Math_fround($415 + $413);
   $418 = Math_fround($416 + $414);
   $419 = Math_fround(HEAPF32[$294>>2]);
   $420 = Math_fround(HEAPF32[$296>>2]);
   $421 = Math_fround(HEAPF32[$298>>2]);
   $422 = Math_fround(HEAPF32[$300>>2]);
   $423 = Math_fround(-$406);
   $424 = Math_fround(-$407);
   $425 = Math_fround(-$408);
   $426 = $406 > $423;
   $$$i$i$i$i37$i = $426 ? $406 : $423;
   $427 = $407 > $424;
   $428 = $427 ? $407 : $424;
   $429 = $417 >= $$$i$i$i$i37$i;
   $430 = $418 >= $428;
   $notlhs301$i$i38$i = $384 >= $419;
   $notrhs302$i$i39$i = $421 >= $386;
   $not$300$i$i40$i = $notrhs302$i$i39$i & $notlhs301$i$i38$i;
   $431 = $429 & $not$300$i$i40$i;
   $notlhs303$i$i41$i = $385 >= $420;
   $notrhs304$i$i42$i = $422 >= $387;
   $not$$i$i43$i = $notrhs304$i$i42$i & $notlhs303$i$i41$i;
   $$296$i$i44$i = $430 & $not$$i$i43$i;
   $brmerge$demorgan$i$i45$i = $431 & $$296$i$i44$i;
   if ($brmerge$demorgan$i$i45$i) {
    $432 = Math_fround(HEAPF32[$311>>2]);
    $433 = Math_fround(HEAPF32[$312>>2]);
    $434 = $408 > $425;
    $435 = Math_fround($383 * $433);
    $436 = Math_fround($379 * $432);
    $$1$i$i$i$i46$i = $434 ? $408 : $425;
    $437 = Math_fround($436 + $435);
    $438 = Math_fround(HEAPF32[$318>>2]);
    $439 = Math_fround($377 - $383);
    $440 = Math_fround($377 + $383);
    $441 = Math_fround(HEAPF32[$319>>2]);
    $442 = $437 >= $$1$i$i$i$i46$i;
    $notlhs306$i$i47$i = $440 >= $441;
    $notrhs307$i$i48$i = $438 >= $439;
    $not$305$i$i49$i = $notrhs307$i$i48$i & $notlhs306$i$i47$i;
    $443 = $442 & $not$305$i$i49$i;
    if ($443) {
     $444 = (((($this) + (($367*224)|0)|0) + ($359<<1)|0) + 1072|0);
     $445 = HEAP16[$444>>1]|0;
     $446 = $445&65535;
     $447 = ((($this) + ($367<<2)|0) + 660|0);
     $749 = $748;$j_$051$i = 0;$orderj$052$i = $446;$rayMaxLimitInt$0$ph10$i1850$i = $rayMaxLimitInt$0$ph10$i1654$i;$rayMinLimitInt$0$ph14$i2549$i = $rayMinLimitInt$0$ph14$i2353$i;
     while(1) {
      $448 = $orderj$052$i & 7;
      $449 = $orderj$052$i >>> 3;
      $450 = (((($this) + (($367*224)|0)|0) + ($448<<2)|0) + 864|0);
      $451 = HEAP32[$450>>2]|0;
      $452 = ($451|0)==(0);
      if ($452) {
       $750 = $749;$rayMaxLimitInt$0$ph10$i19$i = $rayMaxLimitInt$0$ph10$i1850$i;$rayMinLimitInt$0$ph14$i26$i = $rayMinLimitInt$0$ph14$i2549$i;
      } else {
       $453 = (((($this) + (($367*224)|0)|0) + ($448<<5)|0) + 912|0);
       $454 = Math_fround(HEAPF32[$453>>2]);
       $455 = (((($this) + (($367*224)|0)|0) + ($448<<5)|0) + 916|0);
       $456 = Math_fround(HEAPF32[$455>>2]);
       $457 = (((($this) + (($367*224)|0)|0) + ($448<<5)|0) + 920|0);
       $458 = Math_fround(HEAPF32[$457>>2]);
       $459 = (((($this) + (($367*224)|0)|0) + ($448<<5)|0) + 928|0);
       $460 = Math_fround(HEAPF32[$459>>2]);
       $461 = (((($this) + (($367*224)|0)|0) + ($448<<5)|0) + 932|0);
       $462 = Math_fround(HEAPF32[$461>>2]);
       $463 = (((($this) + (($367*224)|0)|0) + ($448<<5)|0) + 936|0);
       $464 = Math_fround(HEAPF32[$463>>2]);
       $465 = Math_fround($454 + $460);
       $466 = Math_fround($456 + $462);
       $467 = Math_fround($454 - $460);
       $468 = Math_fround($456 - $462);
       $469 = Math_fround(HEAPF32[$test$i>>2]);
       $470 = Math_fround(HEAPF32[$252>>2]);
       $471 = Math_fround(HEAPF32[$254>>2]);
       $472 = Math_fround($469 - $454);
       $473 = Math_fround($470 - $456);
       $474 = Math_fround($471 - $458);
       $475 = Math_fround(HEAPF32[$259>>2]);
       $476 = Math_fround(HEAPF32[$261>>2]);
       $477 = Math_fround(HEAPF32[$263>>2]);
       $478 = Math_fround(HEAPF32[$265>>2]);
       $479 = Math_fround(HEAPF32[$267>>2]);
       $480 = Math_fround(HEAPF32[$269>>2]);
       $481 = Math_fround($473 * $478);
       $482 = Math_fround($474 * $479);
       $483 = Math_fround($472 * $480);
       $484 = Math_fround($472 * $475);
       $485 = Math_fround($473 * $476);
       $486 = Math_fround($474 * $477);
       $487 = Math_fround($481 - $484);
       $488 = Math_fround($482 - $485);
       $489 = Math_fround($483 - $486);
       $490 = Math_fround(HEAPF32[$280>>2]);
       $491 = Math_fround(HEAPF32[$282>>2]);
       $492 = Math_fround(HEAPF32[$284>>2]);
       $493 = Math_fround(HEAPF32[$286>>2]);
       $494 = Math_fround($462 * $492);
       $495 = Math_fround($464 * $493);
       $496 = Math_fround($460 * $490);
       $497 = Math_fround($462 * $491);
       $498 = Math_fround($496 + $494);
       $499 = Math_fround($497 + $495);
       $500 = Math_fround(HEAPF32[$294>>2]);
       $501 = Math_fround(HEAPF32[$296>>2]);
       $502 = Math_fround(HEAPF32[$298>>2]);
       $503 = Math_fround(HEAPF32[$300>>2]);
       $504 = Math_fround(-$487);
       $505 = Math_fround(-$488);
       $506 = Math_fround(-$489);
       $507 = $487 > $504;
       $$$i$i$i$i23$i = $507 ? $487 : $504;
       $508 = $488 > $505;
       $509 = $508 ? $488 : $505;
       $510 = $498 >= $$$i$i$i$i23$i;
       $511 = $499 >= $509;
       $notlhs301$i$i24$i = $465 >= $500;
       $notrhs302$i$i25$i = $502 >= $467;
       $not$300$i$i26$i = $notrhs302$i$i25$i & $notlhs301$i$i24$i;
       $512 = $510 & $not$300$i$i26$i;
       $notlhs303$i$i27$i = $466 >= $501;
       $notrhs304$i$i28$i = $503 >= $468;
       $not$$i$i29$i = $notrhs304$i$i28$i & $notlhs303$i$i27$i;
       $$296$i$i30$i = $511 & $not$$i$i29$i;
       $brmerge$demorgan$i$i31$i = $512 & $$296$i$i30$i;
       if ($brmerge$demorgan$i$i31$i) {
        $513 = Math_fround(HEAPF32[$311>>2]);
        $514 = Math_fround(HEAPF32[$312>>2]);
        $515 = $489 > $506;
        $516 = Math_fround($464 * $514);
        $517 = Math_fround($460 * $513);
        $$1$i$i$i$i32$i = $515 ? $489 : $506;
        $518 = Math_fround($517 + $516);
        $519 = Math_fround(HEAPF32[$318>>2]);
        $520 = Math_fround($458 - $464);
        $521 = Math_fround($458 + $464);
        $522 = Math_fround(HEAPF32[$319>>2]);
        $523 = $518 >= $$1$i$i$i$i32$i;
        $notlhs306$i$i33$i = $521 >= $522;
        $notrhs307$i$i34$i = $519 >= $520;
        $not$305$i$i35$i = $notrhs307$i$i34$i & $notlhs306$i$i33$i;
        $524 = $523 & $not$305$i$i35$i;
        if ($524) {
         $525 = HEAP32[$447>>2]|0;
         $526 = (((($this) + (($367*224)|0)|0) + ($448<<2)|0) + 884|0);
         $527 = HEAP32[$526>>2]|0;
         $528 = (($527) + ($525))|0;
         $529 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($359<<1)|0) + 2192|0);
         $530 = HEAP16[$529>>1]|0;
         $531 = $530&65535;
         $751 = $749;$k_$046$i = 0;$orderk$045$i = $531;$rayMaxLimitInt$0$ph10$i2044$i = $rayMaxLimitInt$0$ph10$i1850$i;$rayMinLimitInt$0$ph14$i2743$i = $rayMinLimitInt$0$ph14$i2549$i;
         while(1) {
          $532 = $orderk$045$i & 7;
          $533 = $orderk$045$i >>> 3;
          $534 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($532<<2)|0) + 1984|0);
          $535 = HEAP32[$534>>2]|0;
          $536 = ($535|0)==(0);
          L44: do {
           if ($536) {
            $752 = $751;$rayMaxLimitInt$0$ph10$i21$i = $rayMaxLimitInt$0$ph10$i2044$i;$rayMinLimitInt$0$ph14$i28$i = $rayMinLimitInt$0$ph14$i2743$i;
           } else {
            $537 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($532<<5)|0) + 2032|0);
            $538 = Math_fround(HEAPF32[$537>>2]);
            $539 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($532<<5)|0) + 2036|0);
            $540 = Math_fround(HEAPF32[$539>>2]);
            $541 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($532<<5)|0) + 2040|0);
            $542 = Math_fround(HEAPF32[$541>>2]);
            $543 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($532<<5)|0) + 2048|0);
            $544 = Math_fround(HEAPF32[$543>>2]);
            $545 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($532<<5)|0) + 2052|0);
            $546 = Math_fround(HEAPF32[$545>>2]);
            $547 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($532<<5)|0) + 2056|0);
            $548 = Math_fround(HEAPF32[$547>>2]);
            $549 = Math_fround($538 + $544);
            $550 = Math_fround($540 + $546);
            $551 = Math_fround($538 - $544);
            $552 = Math_fround($540 - $546);
            $553 = Math_fround(HEAPF32[$test$i>>2]);
            $554 = Math_fround(HEAPF32[$252>>2]);
            $555 = Math_fround(HEAPF32[$254>>2]);
            $556 = Math_fround($553 - $538);
            $557 = Math_fround($554 - $540);
            $558 = Math_fround($555 - $542);
            $559 = Math_fround(HEAPF32[$259>>2]);
            $560 = Math_fround(HEAPF32[$261>>2]);
            $561 = Math_fround(HEAPF32[$263>>2]);
            $562 = Math_fround(HEAPF32[$265>>2]);
            $563 = Math_fround(HEAPF32[$267>>2]);
            $564 = Math_fround(HEAPF32[$269>>2]);
            $565 = Math_fround($557 * $562);
            $566 = Math_fround($558 * $563);
            $567 = Math_fround($556 * $564);
            $568 = Math_fround($556 * $559);
            $569 = Math_fround($557 * $560);
            $570 = Math_fround($558 * $561);
            $571 = Math_fround($565 - $568);
            $572 = Math_fround($566 - $569);
            $573 = Math_fround($567 - $570);
            $574 = Math_fround(HEAPF32[$280>>2]);
            $575 = Math_fround(HEAPF32[$282>>2]);
            $576 = Math_fround(HEAPF32[$284>>2]);
            $577 = Math_fround(HEAPF32[$286>>2]);
            $578 = Math_fround($546 * $576);
            $579 = Math_fround($548 * $577);
            $580 = Math_fround($544 * $574);
            $581 = Math_fround($546 * $575);
            $582 = Math_fround($580 + $578);
            $583 = Math_fround($581 + $579);
            $584 = Math_fround(HEAPF32[$294>>2]);
            $585 = Math_fround(HEAPF32[$296>>2]);
            $586 = Math_fround(HEAPF32[$298>>2]);
            $587 = Math_fround(HEAPF32[$300>>2]);
            $588 = Math_fround(-$571);
            $589 = Math_fround(-$572);
            $590 = Math_fround(-$573);
            $591 = $571 > $588;
            $$$i$i$i$i9$i = $591 ? $571 : $588;
            $592 = $572 > $589;
            $593 = $592 ? $572 : $589;
            $594 = $582 >= $$$i$i$i$i9$i;
            $595 = $583 >= $593;
            $notlhs301$i$i10$i = $549 >= $584;
            $notrhs302$i$i11$i = $586 >= $551;
            $not$300$i$i12$i = $notrhs302$i$i11$i & $notlhs301$i$i10$i;
            $596 = $594 & $not$300$i$i12$i;
            $notlhs303$i$i13$i = $550 >= $585;
            $notrhs304$i$i14$i = $587 >= $552;
            $not$$i$i15$i = $notrhs304$i$i14$i & $notlhs303$i$i13$i;
            $$296$i$i16$i = $595 & $not$$i$i15$i;
            $brmerge$demorgan$i$i17$i = $596 & $$296$i$i16$i;
            if ($brmerge$demorgan$i$i17$i) {
             $597 = Math_fround(HEAPF32[$311>>2]);
             $598 = Math_fround(HEAPF32[$312>>2]);
             $599 = $573 > $590;
             $600 = Math_fround($548 * $598);
             $601 = Math_fround($544 * $597);
             $$1$i$i$i$i18$i = $599 ? $573 : $590;
             $602 = Math_fround($601 + $600);
             $603 = Math_fround(HEAPF32[$318>>2]);
             $604 = Math_fround($542 - $548);
             $605 = Math_fround($542 + $548);
             $606 = Math_fround(HEAPF32[$319>>2]);
             $607 = $602 >= $$1$i$i$i$i18$i;
             $notlhs306$i$i19$i = $605 >= $606;
             $notrhs307$i$i20$i = $603 >= $604;
             $not$305$i$i21$i = $notrhs307$i$i20$i & $notlhs306$i$i19$i;
             $608 = $607 & $not$305$i$i21$i;
             if ($608) {
              $609 = ((((($this) + (($367*1120)|0)|0) + (($448*224)|0)|0) + ($532<<2)|0) + 2004|0);
              $610 = HEAP32[$609>>2]|0;
              $611 = (($528) + ($610))|0;
              $612 = HEAP32[$363>>2]|0;
              $$sum$i$i = (($611) + ($535))|0;
              $613 = (($612) + ($$sum$i$i<<5)|0);
              $614 = HEAP32[$364>>2]|0;
              $615 = (($612) + ($611<<5)|0);
              $616 = (($614) + ($611<<3)|0);
              $753 = $751;$_boxes$0$ph18$i$i = $615;$_objects$0$ph17$i$i = $616;$rayMaxLimitInt$0$ph15$i$i = $rayMaxLimitInt$0$ph10$i2044$i;$rayMinLimitInt$0$ph16$i$i = $rayMinLimitInt$0$ph14$i2743$i;
              while(1) {
               $702 = $753;$_boxes$05$i$i = $_boxes$0$ph18$i$i;$_objects$04$i$i = $_objects$0$ph17$i$i;
               L50: while(1) {
                $617 = (($_boxes$05$i$i) + 32|0);
                $618 = (($_objects$04$i$i) + 8|0);
                $619 = (($_boxes$05$i$i) + 28|0);
                $620 = HEAP32[$619>>2]|0;
                $621 = ($620>>>0)<($rayMinLimitInt$0$ph16$i$i>>>0);
                do {
                 if ($621) {
                  $754 = $702;
                 } else {
                  $623 = (($_boxes$05$i$i) + 12|0);
                  $624 = HEAP32[$623>>2]|0;
                  $625 = ($624>>>0)>($rayMaxLimitInt$0$ph15$i$i>>>0);
                  if ($625) {
                   $752 = $702;$rayMaxLimitInt$0$ph10$i21$i = $rayMaxLimitInt$0$ph15$i$i;$rayMinLimitInt$0$ph14$i28$i = $rayMinLimitInt$0$ph16$i$i;
                   break L44;
                  }
                  $626 = Math_fround(HEAPF32[$_boxes$05$i$i>>2]);
                  $627 = (($_boxes$05$i$i) + 4|0);
                  $628 = Math_fround(HEAPF32[$627>>2]);
                  $629 = (($_boxes$05$i$i) + 8|0);
                  $630 = Math_fround(HEAPF32[$629>>2]);
                  $631 = (($_boxes$05$i$i) + 16|0);
                  $632 = Math_fround(HEAPF32[$631>>2]);
                  $633 = (($_boxes$05$i$i) + 20|0);
                  $634 = Math_fround(HEAPF32[$633>>2]);
                  $635 = (($_boxes$05$i$i) + 24|0);
                  $636 = Math_fround(HEAPF32[$635>>2]);
                  $637 = Math_fround($626 + $632);
                  $638 = Math_fround($628 + $634);
                  $639 = Math_fround($626 - $632);
                  $640 = Math_fround($628 - $634);
                  $641 = Math_fround(HEAPF32[$test$i>>2]);
                  $642 = Math_fround(HEAPF32[$252>>2]);
                  $643 = Math_fround(HEAPF32[$254>>2]);
                  $644 = Math_fround($641 - $626);
                  $645 = Math_fround($642 - $628);
                  $646 = Math_fround($643 - $630);
                  $647 = Math_fround(HEAPF32[$259>>2]);
                  $648 = Math_fround(HEAPF32[$261>>2]);
                  $649 = Math_fround(HEAPF32[$263>>2]);
                  $650 = Math_fround(HEAPF32[$265>>2]);
                  $651 = Math_fround(HEAPF32[$267>>2]);
                  $652 = Math_fround(HEAPF32[$269>>2]);
                  $653 = Math_fround($645 * $650);
                  $654 = Math_fround($646 * $651);
                  $655 = Math_fround($644 * $652);
                  $656 = Math_fround($644 * $647);
                  $657 = Math_fround($645 * $648);
                  $658 = Math_fround($646 * $649);
                  $659 = Math_fround($653 - $656);
                  $660 = Math_fround($654 - $657);
                  $661 = Math_fround($655 - $658);
                  $662 = Math_fround(HEAPF32[$280>>2]);
                  $663 = Math_fround(HEAPF32[$282>>2]);
                  $664 = Math_fround(HEAPF32[$284>>2]);
                  $665 = Math_fround(HEAPF32[$286>>2]);
                  $666 = Math_fround($634 * $664);
                  $667 = Math_fround($636 * $665);
                  $668 = Math_fround($632 * $662);
                  $669 = Math_fround($634 * $663);
                  $670 = Math_fround($668 + $666);
                  $671 = Math_fround($669 + $667);
                  $672 = Math_fround(HEAPF32[$294>>2]);
                  $673 = Math_fround(HEAPF32[$296>>2]);
                  $674 = Math_fround(HEAPF32[$298>>2]);
                  $675 = Math_fround(HEAPF32[$300>>2]);
                  $676 = Math_fround(-$659);
                  $677 = Math_fround(-$660);
                  $678 = Math_fround(-$661);
                  $679 = $659 > $676;
                  $$$i$i$i$i$i = $679 ? $659 : $676;
                  $680 = $660 > $677;
                  $681 = $680 ? $660 : $677;
                  $682 = $670 >= $$$i$i$i$i$i;
                  $683 = $671 >= $681;
                  $notlhs301$i$i$i = $637 >= $672;
                  $notrhs302$i$i$i = $674 >= $639;
                  $not$300$i$i$i = $notrhs302$i$i$i & $notlhs301$i$i$i;
                  $684 = $682 & $not$300$i$i$i;
                  $notlhs303$i$i$i = $638 >= $673;
                  $notrhs304$i$i$i = $675 >= $640;
                  $not$$i$i$i = $notrhs304$i$i$i & $notlhs303$i$i$i;
                  $$296$i$i$i = $683 & $not$$i$i$i;
                  $brmerge$demorgan$i$i$i = $684 & $$296$i$i$i;
                  if (!($brmerge$demorgan$i$i$i)) {
                   $754 = $702;
                   break;
                  }
                  $685 = Math_fround(HEAPF32[$311>>2]);
                  $686 = Math_fround(HEAPF32[$312>>2]);
                  $687 = $661 > $678;
                  $688 = Math_fround($636 * $686);
                  $689 = Math_fround($632 * $685);
                  $$1$i$i$i$i$i = $687 ? $661 : $678;
                  $690 = Math_fround($689 + $688);
                  $691 = Math_fround(HEAPF32[$318>>2]);
                  $692 = Math_fround($630 - $636);
                  $693 = Math_fround($630 + $636);
                  $694 = Math_fround(HEAPF32[$319>>2]);
                  $695 = $690 >= $$1$i$i$i$i$i;
                  $notlhs306$i$i$i = $693 >= $694;
                  $notrhs307$i$i$i = $691 >= $692;
                  $not$305$i$i$i = $notrhs307$i$i$i & $notlhs306$i$i$i;
                  $696 = $695 & $not$305$i$i$i;
                  if (!($696)) {
                   $754 = $702;
                   break;
                  }
                  $697 = HEAP32[$pcb>>2]|0;
                  $698 = HEAP32[$697>>2]|0;
                  $699 = (FUNCTION_TABLE_iiiii[$698 & 511]($pcb,$currentDist$i,$_objects$04$i$i,1)|0);
                  if (!($699)) {
                   $$0$i = 0;
                   label = 43;
                   break L30;
                  }
                  $700 = Math_fround(HEAPF32[$currentDist$i>>2]);
                  $701 = $700 < $702;
                  if ($701) {
                   break L50;
                  } else {
                   $754 = $700;
                  }
                 }
                } while(0);
                $622 = ($617|0)==($613|0);
                if ($622) {
                 $752 = $754;$rayMaxLimitInt$0$ph10$i21$i = $rayMaxLimitInt$0$ph15$i$i;$rayMinLimitInt$0$ph14$i28$i = $rayMinLimitInt$0$ph16$i$i;
                 break L44;
                } else {
                 $702 = $754;$_boxes$05$i$i = $617;$_objects$04$i$i = $618;
                }
               }
               $703 = Math_fround(HEAPF32[$330>>2]);
               $704 = Math_fround(HEAPF32[$332>>2]);
               $705 = Math_fround($700 * $704);
               $706 = Math_fround($703 + $705);
               $707 = $703 < $706;
               $708 = $707 ? $703 : $706;
               $709 = (HEAPF32[tempDoublePtr>>2]=$708,HEAP32[tempDoublePtr>>2]|0);
               $710 = $703 > $706;
               $711 = $710 ? $703 : $706;
               $712 = (HEAPF32[tempDoublePtr>>2]=$711,HEAP32[tempDoublePtr>>2]|0);
               $713 = Math_fround(HEAPF32[$265>>2]);
               $714 = Math_fround(HEAPF32[$267>>2]);
               $715 = Math_fround(HEAPF32[$269>>2]);
               $716 = Math_fround(HEAPF32[$test$i>>2]);
               $717 = Math_fround(HEAPF32[$252>>2]);
               $718 = Math_fround(HEAPF32[$254>>2]);
               $719 = Math_fround($700 * $713);
               $720 = Math_fround($700 * $714);
               $721 = Math_fround($700 * $715);
               $722 = Math_fround($719 + $716);
               $723 = Math_fround($720 + $717);
               $724 = Math_fround($721 + $718);
               $725 = $716 < $722;
               $$$i8$i$i$i = $725 ? $716 : $722;
               $726 = $717 < $723;
               $727 = $726 ? $717 : $723;
               $728 = $718 < $724;
               $$1$i9$i$i$i = $728 ? $718 : $724;
               HEAPF32[$294>>2] = $$$i8$i$i$i;
               HEAPF32[$296>>2] = $727;
               HEAPF32[$319>>2] = $$1$i9$i$i$i;
               HEAPF32[$365>>2] = Math_fround(0.0);
               $729 = $716 > $722;
               $$$i$i$i$i = $729 ? $716 : $722;
               $730 = $717 > $723;
               $731 = $730 ? $717 : $723;
               $732 = $718 > $724;
               $$1$i$i$i$i = $732 ? $718 : $724;
               HEAPF32[$298>>2] = $$$i$i$i$i;
               HEAPF32[$300>>2] = $731;
               HEAPF32[$318>>2] = $$1$i$i$i$i;
               HEAPF32[$366>>2] = Math_fround(0.0);
               $733 = ($709|0)<(0);
               $734 = $709 ^ -1;
               $735 = $709 | -2147483648;
               $$0$i1$i$i = $733 ? $734 : $735;
               $736 = ($712|0)<(0);
               $737 = $712 ^ -1;
               $738 = $712 | -2147483648;
               $$0$i$i$i = $736 ? $737 : $738;
               $739 = ($617|0)==($613|0);
               if ($739) {
                $752 = $700;$rayMaxLimitInt$0$ph10$i21$i = $$0$i$i$i;$rayMinLimitInt$0$ph14$i28$i = $$0$i1$i$i;
                break;
               } else {
                $753 = $700;$_boxes$0$ph18$i$i = $617;$_objects$0$ph17$i$i = $618;$rayMaxLimitInt$0$ph15$i$i = $$0$i$i$i;$rayMinLimitInt$0$ph16$i$i = $$0$i1$i$i;
               }
              }
             } else {
              $752 = $751;$rayMaxLimitInt$0$ph10$i21$i = $rayMaxLimitInt$0$ph10$i2044$i;$rayMinLimitInt$0$ph14$i28$i = $rayMinLimitInt$0$ph14$i2743$i;
             }
            } else {
             $752 = $751;$rayMaxLimitInt$0$ph10$i21$i = $rayMaxLimitInt$0$ph10$i2044$i;$rayMinLimitInt$0$ph14$i28$i = $rayMinLimitInt$0$ph14$i2743$i;
            }
           }
          } while(0);
          $740 = (($k_$046$i) + 1)|0;
          $741 = ($740>>>0)<(5);
          if ($741) {
           $751 = $752;$k_$046$i = $740;$orderk$045$i = $533;$rayMaxLimitInt$0$ph10$i2044$i = $rayMaxLimitInt$0$ph10$i21$i;$rayMinLimitInt$0$ph14$i2743$i = $rayMinLimitInt$0$ph14$i28$i;
          } else {
           $750 = $752;$rayMaxLimitInt$0$ph10$i19$i = $rayMaxLimitInt$0$ph10$i21$i;$rayMinLimitInt$0$ph14$i26$i = $rayMinLimitInt$0$ph14$i28$i;
           break;
          }
         }
        } else {
         $750 = $749;$rayMaxLimitInt$0$ph10$i19$i = $rayMaxLimitInt$0$ph10$i1850$i;$rayMinLimitInt$0$ph14$i26$i = $rayMinLimitInt$0$ph14$i2549$i;
        }
       } else {
        $750 = $749;$rayMaxLimitInt$0$ph10$i19$i = $rayMaxLimitInt$0$ph10$i1850$i;$rayMinLimitInt$0$ph14$i26$i = $rayMinLimitInt$0$ph14$i2549$i;
       }
      }
      $742 = (($j_$051$i) + 1)|0;
      $743 = ($742>>>0)<(5);
      if ($743) {
       $749 = $750;$j_$051$i = $742;$orderj$052$i = $449;$rayMaxLimitInt$0$ph10$i1850$i = $rayMaxLimitInt$0$ph10$i19$i;$rayMinLimitInt$0$ph14$i2549$i = $rayMinLimitInt$0$ph14$i26$i;
      } else {
       $746 = $750;$rayMaxLimitInt$0$ph10$i17$i = $rayMaxLimitInt$0$ph10$i19$i;$rayMinLimitInt$0$ph14$i24$i = $rayMinLimitInt$0$ph14$i26$i;
       break;
      }
     }
    } else {
     $746 = $748;$rayMaxLimitInt$0$ph10$i17$i = $rayMaxLimitInt$0$ph10$i1654$i;$rayMinLimitInt$0$ph14$i24$i = $rayMinLimitInt$0$ph14$i2353$i;
    }
   } else {
    $746 = $748;$rayMaxLimitInt$0$ph10$i17$i = $rayMaxLimitInt$0$ph10$i1654$i;$rayMinLimitInt$0$ph14$i24$i = $rayMinLimitInt$0$ph14$i2353$i;
   }
  }
  $744 = (($i_$055$i) + 1)|0;
  $745 = ($744>>>0)<(5);
  if ($745) {
   $748 = $746;$i_$055$i = $744;$orderi$056$i = $368;$rayMaxLimitInt$0$ph10$i1654$i = $rayMaxLimitInt$0$ph10$i17$i;$rayMinLimitInt$0$ph14$i2353$i = $rayMinLimitInt$0$ph14$i24$i;
  } else {
   break;
  }
 }
 if ((label|0) == 43) {
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAPF32[$inOutDistance>>2] = $746;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK5physx2Sq16BucketPrunerCore5sweepERKNS0_9ShapeDataERKNS_6PxVec3ERfRNS0_14PrunerCallbackE($this,$queryVolume,$unitDir,$inOutDistance,$pcb) {
 $this = $this|0;
 $queryVolume = $queryVolume|0;
 $unitDir = $unitDir|0;
 $inOutDistance = $inOutDistance|0;
 $pcb = $pcb|0;
 var $$$i$i$i$i = Math_fround(0), $$$i$i$i13$i = Math_fround(0), $$$i$i$i19$i = Math_fround(0), $$$i$i$i37$i = Math_fround(0), $$$i$i$i55$i = Math_fround(0), $$$i$i$i75$i = Math_fround(0), $$$i$i$i93$i = Math_fround(0), $$$i8$i$i$i = Math_fround(0), $$0$i = 0, $$0$i$i$i = 0, $$0$i1$i$i = 0, $$0$i69$i = 0, $$0$i70$i = 0, $$1$i$i$i$i = Math_fround(0), $$1$i$i$i102$i = Math_fround(0), $$1$i$i$i14$i = Math_fround(0), $$1$i$i$i28$i = Math_fround(0), $$1$i$i$i46$i = Math_fround(0), $$1$i$i$i64$i = Math_fround(0), $$1$i$i$i84$i = Math_fround(0);
 var $$1$i9$i$i$i = Math_fround(0), $$316$i$i = 0, $$316$i100$i = 0, $$316$i26$i = 0, $$316$i44$i = 0, $$316$i62$i = 0, $$316$i82$i = 0, $$pre$i = 0, $$pre$phi295$iZ2D = 0, $$pre294$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0;
 var $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0);
 var $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0);
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0);
 var $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0);
 var $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0);
 var $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0);
 var $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0;
 var $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0);
 var $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0;
 var $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0);
 var $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0);
 var $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0);
 var $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0);
 var $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = Math_fround(0), $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0;
 var $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0), $440 = 0, $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0);
 var $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0);
 var $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0);
 var $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = 0, $495 = 0, $496 = Math_fround(0), $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0);
 var $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = Math_fround(0);
 var $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0);
 var $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0);
 var $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0);
 var $575 = Math_fround(0), $576 = Math_fround(0), $577 = 0, $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = Math_fround(0), $584 = Math_fround(0), $585 = 0, $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0);
 var $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = Math_fround(0), $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = Math_fround(0), $609 = 0, $61 = Math_fround(0);
 var $610 = Math_fround(0), $611 = 0, $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = 0, $616 = Math_fround(0), $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0);
 var $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0);
 var $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0);
 var $665 = Math_fround(0), $666 = Math_fround(0), $667 = 0, $668 = 0, $669 = Math_fround(0), $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = Math_fround(0), $674 = Math_fround(0), $675 = 0, $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0);
 var $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = Math_fround(0), $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = Math_fround(0), $70 = 0;
 var $700 = 0, $701 = 0, $702 = Math_fround(0), $703 = 0, $704 = Math_fround(0), $705 = 0, $706 = Math_fround(0), $707 = 0, $708 = Math_fround(0), $709 = 0, $71 = Math_fround(0), $710 = Math_fround(0), $711 = 0, $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0);
 var $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0);
 var $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = Math_fround(0), $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0);
 var $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = Math_fround(0), $760 = Math_fround(0), $761 = 0, $762 = 0, $763 = Math_fround(0), $764 = 0, $765 = 0, $766 = 0, $767 = Math_fround(0), $768 = Math_fround(0), $769 = 0, $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0);
 var $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = 0, $778 = 0, $779 = 0, $78 = Math_fround(0), $780 = 0, $781 = 0, $782 = Math_fround(0), $783 = 0, $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = 0, $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0);
 var $791 = 0, $792 = 0, $793 = Math_fround(0), $794 = Math_fround(0), $795 = 0, $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = 0;
 var $809 = 0, $81 = Math_fround(0), $810 = Math_fround(0), $811 = 0, $812 = 0, $813 = 0, $814 = Math_fround(0), $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0;
 var $827 = 0, $828 = 0, $829 = Math_fround(0), $83 = Math_fround(0), $830 = 0, $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0;
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $_boxes$0$ph18$i$i = 0, $_boxes$05$i$i = 0, $_objects$0$ph17$i$i = 0, $_objects$04$i$i = 0, $brmerge$demorgan$i$i = 0, $brmerge$demorgan$i101$i = 0, $brmerge$demorgan$i27$i = 0, $brmerge$demorgan$i45$i = 0, $brmerge$demorgan$i63$i = 0, $brmerge$demorgan$i83$i = 0, $currentDist$i = 0;
 var $exitcond = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $i$0266$i = 0, $i1$0259$i = 0, $i_$0256$i = 0, $j_$0252$i = 0, $k_$0247$i = 0, $not$$i$i = 0, $not$$i25$i = 0, $not$$i43$i = 0, $not$$i61$i = 0, $not$$i81$i = 0, $not$$i99$i = 0, $not$320$i$i = 0, $not$320$i22$i = 0, $not$320$i40$i = 0, $not$320$i58$i = 0, $not$320$i78$i = 0, $not$320$i96$i = 0;
 var $not$325$i$i = 0, $not$325$i105$i = 0, $not$325$i31$i = 0, $not$325$i49$i = 0, $not$325$i67$i = 0, $not$325$i87$i = 0, $notlhs321$i$i = 0, $notlhs321$i20$i = 0, $notlhs321$i38$i = 0, $notlhs321$i56$i = 0, $notlhs321$i76$i = 0, $notlhs321$i94$i = 0, $notlhs323$i$i = 0, $notlhs323$i23$i = 0, $notlhs323$i41$i = 0, $notlhs323$i59$i = 0, $notlhs323$i79$i = 0, $notlhs323$i97$i = 0, $notlhs326$i$i = 0, $notlhs326$i103$i = 0;
 var $notlhs326$i29$i = 0, $notlhs326$i47$i = 0, $notlhs326$i65$i = 0, $notlhs326$i85$i = 0, $notrhs322$i$i = 0, $notrhs322$i21$i = 0, $notrhs322$i39$i = 0, $notrhs322$i57$i = 0, $notrhs322$i77$i = 0, $notrhs322$i95$i = 0, $notrhs324$i$i = 0, $notrhs324$i24$i = 0, $notrhs324$i42$i = 0, $notrhs324$i60$i = 0, $notrhs324$i80$i = 0, $notrhs324$i98$i = 0, $notrhs327$i$i = 0, $notrhs327$i104$i = 0, $notrhs327$i30$i = 0, $notrhs327$i48$i = 0;
 var $notrhs327$i66$i = 0, $notrhs327$i86$i = 0, $orderi$0257$i = 0, $orderj$0253$i = 0, $orderk$0246$i = 0, $rayDir$idx$val$i = Math_fround(0), $rayDir$idx3$i = 0, $rayDir$idx3$val$i = Math_fround(0), $rayDir$idx4$i = 0, $rayDir$idx4$val$i = Math_fround(0), $rayMaxLimitInt$0$ph10$i217255$i = 0, $rayMaxLimitInt$0$ph10$i218$i = 0, $rayMaxLimitInt$0$ph10$i219251$i = 0, $rayMaxLimitInt$0$ph10$i220$i = 0, $rayMaxLimitInt$0$ph10$i221245$i = 0, $rayMaxLimitInt$0$ph10$i222$i = 0, $rayMaxLimitInt$0$ph15$i$i = 0, $rayMinLimitInt$0$ph14$i224254$i = 0, $rayMinLimitInt$0$ph14$i225$i = 0, $rayMinLimitInt$0$ph14$i226250$i = 0;
 var $rayMinLimitInt$0$ph14$i227$i = 0, $rayMinLimitInt$0$ph14$i228244$i = 0, $rayMinLimitInt$0$ph14$i229$i = 0, $rayMinLimitInt$0$ph16$i$i = 0, $test$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $test$i = sp;
 $0 = sp + 156|0;
 $currentDist$i = sp + 128|0;
 $1 = sp + 132|0;
 $2 = sp + 144|0;
 $3 = (($queryVolume) + 132|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($queryVolume) + 120|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($queryVolume) + 136|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($queryVolume) + 124|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($queryVolume) + 140|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($queryVolume) + 128|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 - $16);
 $18 = Math_fround($7 * Math_fround(0.5));
 $19 = Math_fround($12 * Math_fround(0.5));
 $20 = Math_fround($17 * Math_fround(0.5));
 $21 = Math_fround($4 + $6);
 $22 = Math_fround($9 + $11);
 $23 = Math_fround($14 + $16);
 $24 = Math_fround($21 * Math_fround(0.5));
 $25 = Math_fround($22 * Math_fround(0.5));
 $26 = Math_fround($23 * Math_fround(0.5));
 HEAPF32[$1>>2] = $24;
 $27 = (($1) + 4|0);
 HEAPF32[$27>>2] = $25;
 $28 = (($1) + 8|0);
 HEAPF32[$28>>2] = $26;
 HEAPF32[$2>>2] = $18;
 $29 = (($2) + 4|0);
 HEAPF32[$29>>2] = $19;
 $30 = (($2) + 8|0);
 HEAPF32[$30>>2] = $20;
 $31 = Math_fround(HEAPF32[$inOutDistance>>2]);
 $32 = $31 == Math_fround(3.40282346638528859812E+38);
 if ($32) {
  $33 = (($this) + 608|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($this) + 624|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($34 - $36);
  $38 = (($this) + 612|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($this) + 628|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($39 - $41);
  $43 = (($this) + 616|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($this) + 632|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($44 - $46);
  $48 = Math_fround($37 - $18);
  $49 = Math_fround($42 - $19);
  $50 = Math_fround($47 - $20);
  $51 = Math_fround($34 + $36);
  $52 = Math_fround($39 + $41);
  $53 = Math_fround($44 + $46);
  $54 = Math_fround($51 + $18);
  $55 = Math_fround($52 + $19);
  $56 = Math_fround($53 + $20);
  $57 = (($this) + 28|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0);
  if ($59) {
   $110 = $54;$111 = $48;$113 = $55;$114 = $49;$116 = $56;$117 = $50;
  } else {
   $63 = Math_fround(8.50705866596322149529E+37);$68 = Math_fround(8.50705866596322149529E+37);$73 = Math_fround(8.50705866596322149529E+37);$78 = Math_fround(-8.50705866596322149529E+37);$83 = Math_fround(-8.50705866596322149529E+37);$88 = Math_fround(-8.50705866596322149529E+37);$i$0266$i = 0;
   while(1) {
    $60 = ((($this) + (($i$0266$i*24)|0)|0) + 160|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = $63 < $61;
    $64 = $62 ? $63 : $61;
    $65 = ((($this) + (($i$0266$i*24)|0)|0) + 164|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = $68 < $66;
    $69 = $67 ? $68 : $66;
    $70 = ((($this) + (($i$0266$i*24)|0)|0) + 168|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = $73 < $71;
    $74 = $72 ? $73 : $71;
    $75 = ((($this) + (($i$0266$i*24)|0)|0) + 172|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = $78 > $76;
    $79 = $77 ? $78 : $76;
    $80 = ((($this) + (($i$0266$i*24)|0)|0) + 176|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = $83 > $81;
    $84 = $82 ? $83 : $81;
    $85 = ((($this) + (($i$0266$i*24)|0)|0) + 180|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $87 = $88 > $86;
    $89 = $87 ? $88 : $86;
    $90 = (($i$0266$i) + 1)|0;
    $exitcond = ($90|0)==($58|0);
    if ($exitcond) {
     break;
    } else {
     $63 = $64;$68 = $69;$73 = $74;$78 = $79;$83 = $84;$88 = $89;$i$0266$i = $90;
    }
   }
   $91 = Math_fround($64 - $18);
   $92 = Math_fround($69 - $19);
   $93 = Math_fround($74 - $20);
   $94 = Math_fround($18 + $79);
   $95 = Math_fround($19 + $84);
   $96 = Math_fround($20 + $89);
   $97 = $48 < $91;
   $98 = $97 ? $48 : $91;
   $99 = $49 < $92;
   $100 = $99 ? $49 : $92;
   $101 = $50 < $93;
   $102 = $101 ? $50 : $93;
   $103 = $54 > $94;
   $104 = $103 ? $54 : $94;
   $105 = $55 > $95;
   $106 = $105 ? $55 : $95;
   $107 = $56 > $96;
   $108 = $107 ? $56 : $96;
   $110 = $104;$111 = $98;$113 = $106;$114 = $100;$116 = $108;$117 = $102;
  }
  $rayDir$idx$val$i = Math_fround(HEAPF32[$unitDir>>2]);
  $rayDir$idx3$i = (($unitDir) + 4|0);
  $rayDir$idx3$val$i = Math_fround(HEAPF32[$rayDir$idx3$i>>2]);
  $rayDir$idx4$i = (($unitDir) + 8|0);
  $rayDir$idx4$val$i = Math_fround(HEAPF32[$rayDir$idx4$i>>2]);
  $109 = Math_fround($111 + $110);
  $112 = Math_fround($114 + $113);
  $115 = Math_fround($117 + $116);
  $118 = Math_fround($109 * Math_fround(0.5));
  $119 = Math_fround($112 * Math_fround(0.5));
  $120 = Math_fround($115 * Math_fround(0.5));
  $121 = Math_fround($110 - $111);
  $122 = Math_fround($113 - $114);
  $123 = Math_fround($116 - $117);
  $124 = Math_fround($121 * Math_fround(0.5));
  $125 = Math_fround($122 * Math_fround(0.5));
  $126 = Math_fround($123 * Math_fround(0.5));
  $127 = Math_fround($118 * $rayDir$idx$val$i);
  $128 = Math_fround($119 * $rayDir$idx3$val$i);
  $129 = Math_fround($127 + $128);
  $130 = Math_fround($120 * $rayDir$idx4$val$i);
  $131 = Math_fround($129 + $130);
  $132 = Math_fround($124 * $124);
  $133 = Math_fround($125 * $125);
  $134 = Math_fround($133 + $132);
  $135 = Math_fround($126 * $126);
  $136 = Math_fround($135 + $134);
  $137 = (Math_fround(Math_sqrt((Math_fround($136)))));
  $138 = Math_fround($131 - $137);
  $139 = Math_fround($137 + $131);
  $140 = Math_fround($24 * $rayDir$idx$val$i);
  $141 = Math_fround($25 * $rayDir$idx3$val$i);
  $142 = Math_fround($140 + $141);
  $143 = Math_fround($26 * $rayDir$idx4$val$i);
  $144 = Math_fround($142 + $143);
  $145 = Math_fround($137 * Math_fround(2.0));
  $146 = Math_fround($138 - $144);
  $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($146)))));
  $147 = Math_fround($139 - $144);
  $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($147)))));
  $148 = $fabsf$i$i1$i$i < $fabsf$i$i$i$i;
  $149 = $148 ? $fabsf$i$i1$i$i : $fabsf$i$i$i$i;
  $150 = Math_fround($145 * Math_fround(2.0));
  $151 = Math_fround($150 + $149);
  HEAPF32[$inOutDistance>>2] = $151;
  $$pre$phi295$iZ2D = $57;$154 = $151;
 } else {
  $$pre294$i = (($this) + 28|0);
  $$pre$phi295$iZ2D = $$pre294$i;$154 = $31;
 }
 HEAPF32[$0>>2] = $18;
 $152 = (($0) + 4|0);
 HEAPF32[$152>>2] = $19;
 $153 = (($0) + 8|0);
 HEAPF32[$153>>2] = $20;
 __ZN5physx2Gu11RayAABBTestC2ERKNS_6PxVec3ES4_fS4_($test$i,$1,$unitDir,$154,$0);
 $155 = HEAP32[$$pre$phi295$iZ2D>>2]|0;
 $156 = ($155|0)==(0);
 L10: do {
  if (!($156)) {
   $157 = (($test$i) + 48|0);
   $158 = (($test$i) + 52|0);
   $159 = (($test$i) + 56|0);
   $160 = (($test$i) + 4|0);
   $161 = (($test$i) + 8|0);
   $162 = (($test$i) + 32|0);
   $163 = (($test$i) + 36|0);
   $164 = (($test$i) + 40|0);
   $165 = (($test$i) + 16|0);
   $166 = (($test$i) + 20|0);
   $167 = (($test$i) + 24|0);
   $168 = (($test$i) + 80|0);
   $169 = (($test$i) + 84|0);
   $170 = (($test$i) + 64|0);
   $171 = (($test$i) + 68|0);
   $172 = (($test$i) + 96|0);
   $173 = (($test$i) + 100|0);
   $174 = (($test$i) + 112|0);
   $175 = (($test$i) + 116|0);
   $176 = (($test$i) + 72|0);
   $177 = (($test$i) + 88|0);
   $178 = (($test$i) + 120|0);
   $179 = (($test$i) + 104|0);
   $830 = $155;$i1$0259$i = 0;
   while(1) {
    $180 = ((($this) + (($i1$0259$i*24)|0)|0) + 160|0);
    $181 = Math_fround(HEAPF32[$180>>2]);
    $182 = ((($this) + (($i1$0259$i*24)|0)|0) + 172|0);
    $183 = Math_fround(HEAPF32[$182>>2]);
    $184 = Math_fround($181 + $183);
    $185 = ((($this) + (($i1$0259$i*24)|0)|0) + 164|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = ((($this) + (($i1$0259$i*24)|0)|0) + 176|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = Math_fround($186 + $188);
    $190 = ((($this) + (($i1$0259$i*24)|0)|0) + 168|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = ((($this) + (($i1$0259$i*24)|0)|0) + 180|0);
    $193 = Math_fround(HEAPF32[$192>>2]);
    $194 = Math_fround($191 + $193);
    $195 = Math_fround($184 * Math_fround(0.5));
    $196 = Math_fround($189 * Math_fround(0.5));
    $197 = Math_fround($194 * Math_fround(0.5));
    $198 = Math_fround($183 - $181);
    $199 = Math_fround($188 - $186);
    $200 = Math_fround($193 - $191);
    $201 = Math_fround($198 * Math_fround(0.5));
    $202 = Math_fround($199 * Math_fround(0.5));
    $203 = Math_fround($200 * Math_fround(0.5));
    $204 = Math_fround(HEAPF32[$157>>2]);
    $205 = Math_fround(HEAPF32[$158>>2]);
    $206 = Math_fround(HEAPF32[$159>>2]);
    $207 = Math_fround($201 + $204);
    $208 = Math_fround($202 + $205);
    $209 = Math_fround($203 + $206);
    $210 = Math_fround($195 + $207);
    $211 = Math_fround($196 + $208);
    $212 = Math_fround($195 - $207);
    $213 = Math_fround($196 - $208);
    $214 = Math_fround(HEAPF32[$test$i>>2]);
    $215 = Math_fround(HEAPF32[$160>>2]);
    $216 = Math_fround(HEAPF32[$161>>2]);
    $217 = Math_fround($214 - $195);
    $218 = Math_fround($215 - $196);
    $219 = Math_fround($216 - $197);
    $220 = Math_fround(HEAPF32[$162>>2]);
    $221 = Math_fround(HEAPF32[$163>>2]);
    $222 = Math_fround(HEAPF32[$164>>2]);
    $223 = Math_fround(HEAPF32[$165>>2]);
    $224 = Math_fround(HEAPF32[$166>>2]);
    $225 = Math_fround(HEAPF32[$167>>2]);
    $226 = Math_fround($218 * $223);
    $227 = Math_fround($219 * $224);
    $228 = Math_fround($217 * $225);
    $229 = Math_fround($217 * $220);
    $230 = Math_fround($218 * $221);
    $231 = Math_fround($219 * $222);
    $232 = Math_fround($226 - $229);
    $233 = Math_fround($227 - $230);
    $234 = Math_fround($228 - $231);
    $235 = Math_fround(HEAPF32[$168>>2]);
    $236 = Math_fround(HEAPF32[$169>>2]);
    $237 = Math_fround(HEAPF32[$170>>2]);
    $238 = Math_fround(HEAPF32[$171>>2]);
    $239 = Math_fround($208 * $237);
    $240 = Math_fround($209 * $238);
    $241 = Math_fround($207 * $235);
    $242 = Math_fround($208 * $236);
    $243 = Math_fround($241 + $239);
    $244 = Math_fround($242 + $240);
    $245 = Math_fround(HEAPF32[$172>>2]);
    $246 = Math_fround(HEAPF32[$173>>2]);
    $247 = Math_fround(HEAPF32[$174>>2]);
    $248 = Math_fround(HEAPF32[$175>>2]);
    $249 = Math_fround(-$232);
    $250 = Math_fround(-$233);
    $251 = Math_fround(-$234);
    $252 = $232 > $249;
    $$$i$i$i93$i = $252 ? $232 : $249;
    $253 = $233 > $250;
    $254 = $253 ? $233 : $250;
    $255 = $243 >= $$$i$i$i93$i;
    $256 = $244 >= $254;
    $notlhs321$i94$i = $210 >= $245;
    $notrhs322$i95$i = $247 >= $212;
    $not$320$i96$i = $notrhs322$i95$i & $notlhs321$i94$i;
    $257 = $255 & $not$320$i96$i;
    $notlhs323$i97$i = $211 >= $246;
    $notrhs324$i98$i = $248 >= $213;
    $not$$i99$i = $notrhs324$i98$i & $notlhs323$i97$i;
    $$316$i100$i = $256 & $not$$i99$i;
    $brmerge$demorgan$i101$i = $257 & $$316$i100$i;
    if ($brmerge$demorgan$i101$i) {
     $258 = Math_fround(HEAPF32[$176>>2]);
     $259 = Math_fround(HEAPF32[$177>>2]);
     $260 = $234 > $251;
     $261 = Math_fround($209 * $259);
     $262 = Math_fround($207 * $258);
     $$1$i$i$i102$i = $260 ? $234 : $251;
     $263 = Math_fround($262 + $261);
     $264 = Math_fround(HEAPF32[$178>>2]);
     $265 = Math_fround($197 - $209);
     $266 = Math_fround($197 + $209);
     $267 = Math_fround(HEAPF32[$179>>2]);
     $268 = $263 >= $$1$i$i$i102$i;
     $notlhs326$i103$i = $266 >= $267;
     $notrhs327$i104$i = $264 >= $265;
     $not$325$i105$i = $notrhs327$i104$i & $notlhs326$i103$i;
     $269 = $268 & $not$325$i105$i;
     if ($269) {
      $270 = HEAP32[$pcb>>2]|0;
      $271 = HEAP32[$270>>2]|0;
      $272 = ((($this) + ($i1$0259$i<<3)|0) + 32|0);
      $273 = (FUNCTION_TABLE_iiiii[$271 & 511]($pcb,$inOutDistance,$272,1)|0);
      if (!($273)) {
       $$0$i = 0;
       break;
      }
      $$pre$i = HEAP32[$$pre$phi295$iZ2D>>2]|0;
      $276 = $$pre$i;
     } else {
      $276 = $830;
     }
    } else {
     $276 = $830;
    }
    $274 = (($i1$0259$i) + 1)|0;
    $275 = ($274>>>0)<($276>>>0);
    if ($275) {
     $830 = $276;$i1$0259$i = $274;
    } else {
     break L10;
    }
   }
   STACKTOP = sp;return ($$0$i|0);
  }
 } while(0);
 $277 = (($this) + 584|0);
 $278 = HEAP32[$277>>2]|0;
 $279 = ($278|0)==(0);
 if ($279) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $280 = (($this) + 608|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = (($this) + 612|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = (($this) + 616|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = (($this) + 624|0);
 $287 = Math_fround(HEAPF32[$286>>2]);
 $288 = (($this) + 628|0);
 $289 = Math_fround(HEAPF32[$288>>2]);
 $290 = (($this) + 632|0);
 $291 = Math_fround(HEAPF32[$290>>2]);
 $292 = (($test$i) + 48|0);
 $293 = Math_fround(HEAPF32[$292>>2]);
 $294 = (($test$i) + 52|0);
 $295 = Math_fround(HEAPF32[$294>>2]);
 $296 = (($test$i) + 56|0);
 $297 = Math_fround(HEAPF32[$296>>2]);
 $298 = Math_fround($287 + $293);
 $299 = Math_fround($289 + $295);
 $300 = Math_fround($291 + $297);
 $301 = Math_fround($281 + $298);
 $302 = Math_fround($283 + $299);
 $303 = Math_fround($281 - $298);
 $304 = Math_fround($283 - $299);
 $305 = Math_fround(HEAPF32[$test$i>>2]);
 $306 = (($test$i) + 4|0);
 $307 = Math_fround(HEAPF32[$306>>2]);
 $308 = (($test$i) + 8|0);
 $309 = Math_fround(HEAPF32[$308>>2]);
 $310 = Math_fround($305 - $281);
 $311 = Math_fround($307 - $283);
 $312 = Math_fround($309 - $285);
 $313 = (($test$i) + 32|0);
 $314 = Math_fround(HEAPF32[$313>>2]);
 $315 = (($test$i) + 36|0);
 $316 = Math_fround(HEAPF32[$315>>2]);
 $317 = (($test$i) + 40|0);
 $318 = Math_fround(HEAPF32[$317>>2]);
 $319 = (($test$i) + 16|0);
 $320 = Math_fround(HEAPF32[$319>>2]);
 $321 = (($test$i) + 20|0);
 $322 = Math_fround(HEAPF32[$321>>2]);
 $323 = (($test$i) + 24|0);
 $324 = Math_fround(HEAPF32[$323>>2]);
 $325 = Math_fround($311 * $320);
 $326 = Math_fround($312 * $322);
 $327 = Math_fround($310 * $324);
 $328 = Math_fround($310 * $314);
 $329 = Math_fround($311 * $316);
 $330 = Math_fround($312 * $318);
 $331 = Math_fround($325 - $328);
 $332 = Math_fround($326 - $329);
 $333 = Math_fround($327 - $330);
 $334 = (($test$i) + 80|0);
 $335 = Math_fround(HEAPF32[$334>>2]);
 $336 = (($test$i) + 84|0);
 $337 = Math_fround(HEAPF32[$336>>2]);
 $338 = (($test$i) + 64|0);
 $339 = Math_fround(HEAPF32[$338>>2]);
 $340 = (($test$i) + 68|0);
 $341 = Math_fround(HEAPF32[$340>>2]);
 $342 = Math_fround($299 * $339);
 $343 = Math_fround($300 * $341);
 $344 = Math_fround($298 * $335);
 $345 = Math_fround($299 * $337);
 $346 = Math_fround($344 + $342);
 $347 = Math_fround($345 + $343);
 $348 = (($test$i) + 96|0);
 $349 = Math_fround(HEAPF32[$348>>2]);
 $350 = (($test$i) + 100|0);
 $351 = Math_fround(HEAPF32[$350>>2]);
 $352 = (($test$i) + 112|0);
 $353 = Math_fround(HEAPF32[$352>>2]);
 $354 = (($test$i) + 116|0);
 $355 = Math_fround(HEAPF32[$354>>2]);
 $356 = Math_fround(-$331);
 $357 = Math_fround(-$332);
 $358 = Math_fround(-$333);
 $359 = $331 > $356;
 $$$i$i$i75$i = $359 ? $331 : $356;
 $360 = $332 > $357;
 $361 = $360 ? $332 : $357;
 $362 = $346 >= $$$i$i$i75$i;
 $363 = $347 >= $361;
 $notlhs321$i76$i = $301 >= $349;
 $notrhs322$i77$i = $353 >= $303;
 $not$320$i78$i = $notrhs322$i77$i & $notlhs321$i76$i;
 $364 = $362 & $not$320$i78$i;
 $notlhs323$i79$i = $302 >= $351;
 $notrhs324$i80$i = $355 >= $304;
 $not$$i81$i = $notrhs324$i80$i & $notlhs323$i79$i;
 $$316$i82$i = $363 & $not$$i81$i;
 $brmerge$demorgan$i83$i = $364 & $$316$i82$i;
 if (!($brmerge$demorgan$i83$i)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $365 = (($test$i) + 72|0);
 $366 = (($test$i) + 88|0);
 $367 = Math_fround(HEAPF32[$365>>2]);
 $368 = Math_fround(HEAPF32[$366>>2]);
 $369 = $333 > $358;
 $370 = Math_fround($300 * $368);
 $371 = Math_fround($298 * $367);
 $$1$i$i$i84$i = $369 ? $333 : $358;
 $372 = (($test$i) + 120|0);
 $373 = (($test$i) + 104|0);
 $374 = Math_fround($371 + $370);
 $375 = Math_fround(HEAPF32[$372>>2]);
 $376 = Math_fround($285 - $300);
 $377 = Math_fround($285 + $300);
 $378 = Math_fround(HEAPF32[$373>>2]);
 $379 = $374 >= $$1$i$i$i84$i;
 $notlhs326$i85$i = $377 >= $378;
 $notrhs327$i86$i = $375 >= $376;
 $not$325$i87$i = $notrhs327$i86$i & $notlhs326$i85$i;
 $380 = $379 & $not$325$i87$i;
 if (!($380)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $381 = (($this) + 592|0);
 $382 = HEAP32[$381>>2]|0;
 $383 = Math_fround(HEAPF32[$inOutDistance>>2]);
 $384 = (($2) + ($382<<2)|0);
 $385 = Math_fround(HEAPF32[$384>>2]);
 $386 = (($1) + ($382<<2)|0);
 $387 = Math_fround(HEAPF32[$386>>2]);
 $388 = (($unitDir) + ($382<<2)|0);
 $389 = Math_fround(HEAPF32[$388>>2]);
 $390 = Math_fround($383 * $389);
 $391 = Math_fround($387 + $390);
 $392 = $387 < $391;
 $393 = $392 ? $387 : $391;
 $394 = Math_fround($393 - $385);
 $395 = (HEAPF32[tempDoublePtr>>2]=$394,HEAP32[tempDoublePtr>>2]|0);
 $396 = $387 > $391;
 $397 = $396 ? $387 : $391;
 $398 = Math_fround($385 + $397);
 $399 = (HEAPF32[tempDoublePtr>>2]=$398,HEAP32[tempDoublePtr>>2]|0);
 $400 = ($395|0)<(0);
 $401 = $395 ^ -1;
 $402 = $395 | -2147483648;
 $$0$i70$i = $400 ? $401 : $402;
 $403 = ($399|0)<(0);
 $404 = $399 ^ -1;
 $405 = $399 | -2147483648;
 $$0$i69$i = $403 ? $404 : $405;
 HEAPF32[$currentDist$i>>2] = $383;
 $406 = HEAP32[$unitDir>>2]|0;
 $407 = $406 >>> 31;
 $408 = (($unitDir) + 4|0);
 $409 = HEAP32[$408>>2]|0;
 $410 = $409 >>> 31;
 $411 = (($unitDir) + 8|0);
 $412 = HEAP32[$411>>2]|0;
 $413 = $412 >>> 31;
 $414 = $410 << 1;
 $415 = $407 << 2;
 $416 = $414 | $415;
 $417 = $416 | $413;
 $418 = ((($this) + ($417<<1)|0) + 848|0);
 $419 = HEAP16[$418>>1]|0;
 $420 = $419&65535;
 $421 = (($this) + 20|0);
 $422 = (($this) + 24|0);
 $423 = (($test$i) + 108|0);
 $424 = (($test$i) + 124|0);
 $831 = $383;$i_$0256$i = 0;$orderi$0257$i = $420;$rayMaxLimitInt$0$ph10$i217255$i = $$0$i69$i;$rayMinLimitInt$0$ph14$i224254$i = $$0$i70$i;
 L30: while(1) {
  $425 = $orderi$0257$i & 7;
  $426 = $orderi$0257$i >>> 3;
  $427 = ((($this) + ($425<<2)|0) + 640|0);
  $428 = HEAP32[$427>>2]|0;
  $429 = ($428|0)==(0);
  if ($429) {
   $829 = $831;$rayMaxLimitInt$0$ph10$i218$i = $rayMaxLimitInt$0$ph10$i217255$i;$rayMinLimitInt$0$ph14$i225$i = $rayMinLimitInt$0$ph14$i224254$i;
  } else {
   $430 = ((($this) + ($425<<5)|0) + 688|0);
   $431 = Math_fround(HEAPF32[$430>>2]);
   $432 = ((($this) + ($425<<5)|0) + 692|0);
   $433 = Math_fround(HEAPF32[$432>>2]);
   $434 = ((($this) + ($425<<5)|0) + 696|0);
   $435 = Math_fround(HEAPF32[$434>>2]);
   $436 = ((($this) + ($425<<5)|0) + 704|0);
   $437 = Math_fround(HEAPF32[$436>>2]);
   $438 = ((($this) + ($425<<5)|0) + 708|0);
   $439 = Math_fround(HEAPF32[$438>>2]);
   $440 = ((($this) + ($425<<5)|0) + 712|0);
   $441 = Math_fround(HEAPF32[$440>>2]);
   $442 = Math_fround(HEAPF32[$292>>2]);
   $443 = Math_fround(HEAPF32[$294>>2]);
   $444 = Math_fround(HEAPF32[$296>>2]);
   $445 = Math_fround($437 + $442);
   $446 = Math_fround($439 + $443);
   $447 = Math_fround($441 + $444);
   $448 = Math_fround($431 + $445);
   $449 = Math_fround($433 + $446);
   $450 = Math_fround($431 - $445);
   $451 = Math_fround($433 - $446);
   $452 = Math_fround(HEAPF32[$test$i>>2]);
   $453 = Math_fround(HEAPF32[$306>>2]);
   $454 = Math_fround(HEAPF32[$308>>2]);
   $455 = Math_fround($452 - $431);
   $456 = Math_fround($453 - $433);
   $457 = Math_fround($454 - $435);
   $458 = Math_fround(HEAPF32[$313>>2]);
   $459 = Math_fround(HEAPF32[$315>>2]);
   $460 = Math_fround(HEAPF32[$317>>2]);
   $461 = Math_fround(HEAPF32[$319>>2]);
   $462 = Math_fround(HEAPF32[$321>>2]);
   $463 = Math_fround(HEAPF32[$323>>2]);
   $464 = Math_fround($456 * $461);
   $465 = Math_fround($457 * $462);
   $466 = Math_fround($455 * $463);
   $467 = Math_fround($455 * $458);
   $468 = Math_fround($456 * $459);
   $469 = Math_fround($457 * $460);
   $470 = Math_fround($464 - $467);
   $471 = Math_fround($465 - $468);
   $472 = Math_fround($466 - $469);
   $473 = Math_fround(HEAPF32[$334>>2]);
   $474 = Math_fround(HEAPF32[$336>>2]);
   $475 = Math_fround(HEAPF32[$338>>2]);
   $476 = Math_fround(HEAPF32[$340>>2]);
   $477 = Math_fround($446 * $475);
   $478 = Math_fround($447 * $476);
   $479 = Math_fround($445 * $473);
   $480 = Math_fround($446 * $474);
   $481 = Math_fround($479 + $477);
   $482 = Math_fround($480 + $478);
   $483 = Math_fround(HEAPF32[$348>>2]);
   $484 = Math_fround(HEAPF32[$350>>2]);
   $485 = Math_fround(HEAPF32[$352>>2]);
   $486 = Math_fround(HEAPF32[$354>>2]);
   $487 = Math_fround(-$470);
   $488 = Math_fround(-$471);
   $489 = Math_fround(-$472);
   $490 = $470 > $487;
   $$$i$i$i55$i = $490 ? $470 : $487;
   $491 = $471 > $488;
   $492 = $491 ? $471 : $488;
   $493 = $481 >= $$$i$i$i55$i;
   $494 = $482 >= $492;
   $notlhs321$i56$i = $448 >= $483;
   $notrhs322$i57$i = $485 >= $450;
   $not$320$i58$i = $notrhs322$i57$i & $notlhs321$i56$i;
   $495 = $493 & $not$320$i58$i;
   $notlhs323$i59$i = $449 >= $484;
   $notrhs324$i60$i = $486 >= $451;
   $not$$i61$i = $notrhs324$i60$i & $notlhs323$i59$i;
   $$316$i62$i = $494 & $not$$i61$i;
   $brmerge$demorgan$i63$i = $495 & $$316$i62$i;
   if ($brmerge$demorgan$i63$i) {
    $496 = Math_fround(HEAPF32[$365>>2]);
    $497 = Math_fround(HEAPF32[$366>>2]);
    $498 = $472 > $489;
    $499 = Math_fround($447 * $497);
    $500 = Math_fround($445 * $496);
    $$1$i$i$i64$i = $498 ? $472 : $489;
    $501 = Math_fround($500 + $499);
    $502 = Math_fround(HEAPF32[$372>>2]);
    $503 = Math_fround($435 - $447);
    $504 = Math_fround($435 + $447);
    $505 = Math_fround(HEAPF32[$373>>2]);
    $506 = $501 >= $$1$i$i$i64$i;
    $notlhs326$i65$i = $504 >= $505;
    $notrhs327$i66$i = $502 >= $503;
    $not$325$i67$i = $notrhs327$i66$i & $notlhs326$i65$i;
    $507 = $506 & $not$325$i67$i;
    if ($507) {
     $508 = (((($this) + (($425*224)|0)|0) + ($417<<1)|0) + 1072|0);
     $509 = HEAP16[$508>>1]|0;
     $510 = $509&65535;
     $511 = ((($this) + ($425<<2)|0) + 660|0);
     $832 = $831;$j_$0252$i = 0;$orderj$0253$i = $510;$rayMaxLimitInt$0$ph10$i219251$i = $rayMaxLimitInt$0$ph10$i217255$i;$rayMinLimitInt$0$ph14$i226250$i = $rayMinLimitInt$0$ph14$i224254$i;
     while(1) {
      $512 = $orderj$0253$i & 7;
      $513 = $orderj$0253$i >>> 3;
      $514 = (((($this) + (($425*224)|0)|0) + ($512<<2)|0) + 864|0);
      $515 = HEAP32[$514>>2]|0;
      $516 = ($515|0)==(0);
      if ($516) {
       $833 = $832;$rayMaxLimitInt$0$ph10$i220$i = $rayMaxLimitInt$0$ph10$i219251$i;$rayMinLimitInt$0$ph14$i227$i = $rayMinLimitInt$0$ph14$i226250$i;
      } else {
       $517 = (((($this) + (($425*224)|0)|0) + ($512<<5)|0) + 912|0);
       $518 = Math_fround(HEAPF32[$517>>2]);
       $519 = (((($this) + (($425*224)|0)|0) + ($512<<5)|0) + 916|0);
       $520 = Math_fround(HEAPF32[$519>>2]);
       $521 = (((($this) + (($425*224)|0)|0) + ($512<<5)|0) + 920|0);
       $522 = Math_fround(HEAPF32[$521>>2]);
       $523 = (((($this) + (($425*224)|0)|0) + ($512<<5)|0) + 928|0);
       $524 = Math_fround(HEAPF32[$523>>2]);
       $525 = (((($this) + (($425*224)|0)|0) + ($512<<5)|0) + 932|0);
       $526 = Math_fround(HEAPF32[$525>>2]);
       $527 = (((($this) + (($425*224)|0)|0) + ($512<<5)|0) + 936|0);
       $528 = Math_fround(HEAPF32[$527>>2]);
       $529 = Math_fround(HEAPF32[$292>>2]);
       $530 = Math_fround(HEAPF32[$294>>2]);
       $531 = Math_fround(HEAPF32[$296>>2]);
       $532 = Math_fround($524 + $529);
       $533 = Math_fround($526 + $530);
       $534 = Math_fround($528 + $531);
       $535 = Math_fround($518 + $532);
       $536 = Math_fround($520 + $533);
       $537 = Math_fround($518 - $532);
       $538 = Math_fround($520 - $533);
       $539 = Math_fround(HEAPF32[$test$i>>2]);
       $540 = Math_fround(HEAPF32[$306>>2]);
       $541 = Math_fround(HEAPF32[$308>>2]);
       $542 = Math_fround($539 - $518);
       $543 = Math_fround($540 - $520);
       $544 = Math_fround($541 - $522);
       $545 = Math_fround(HEAPF32[$313>>2]);
       $546 = Math_fround(HEAPF32[$315>>2]);
       $547 = Math_fround(HEAPF32[$317>>2]);
       $548 = Math_fround(HEAPF32[$319>>2]);
       $549 = Math_fround(HEAPF32[$321>>2]);
       $550 = Math_fround(HEAPF32[$323>>2]);
       $551 = Math_fround($543 * $548);
       $552 = Math_fround($544 * $549);
       $553 = Math_fround($542 * $550);
       $554 = Math_fround($542 * $545);
       $555 = Math_fround($543 * $546);
       $556 = Math_fround($544 * $547);
       $557 = Math_fround($551 - $554);
       $558 = Math_fround($552 - $555);
       $559 = Math_fround($553 - $556);
       $560 = Math_fround(HEAPF32[$334>>2]);
       $561 = Math_fround(HEAPF32[$336>>2]);
       $562 = Math_fround(HEAPF32[$338>>2]);
       $563 = Math_fround(HEAPF32[$340>>2]);
       $564 = Math_fround($533 * $562);
       $565 = Math_fround($534 * $563);
       $566 = Math_fround($532 * $560);
       $567 = Math_fround($533 * $561);
       $568 = Math_fround($566 + $564);
       $569 = Math_fround($567 + $565);
       $570 = Math_fround(HEAPF32[$348>>2]);
       $571 = Math_fround(HEAPF32[$350>>2]);
       $572 = Math_fround(HEAPF32[$352>>2]);
       $573 = Math_fround(HEAPF32[$354>>2]);
       $574 = Math_fround(-$557);
       $575 = Math_fround(-$558);
       $576 = Math_fround(-$559);
       $577 = $557 > $574;
       $$$i$i$i37$i = $577 ? $557 : $574;
       $578 = $558 > $575;
       $579 = $578 ? $558 : $575;
       $580 = $568 >= $$$i$i$i37$i;
       $581 = $569 >= $579;
       $notlhs321$i38$i = $535 >= $570;
       $notrhs322$i39$i = $572 >= $537;
       $not$320$i40$i = $notrhs322$i39$i & $notlhs321$i38$i;
       $582 = $580 & $not$320$i40$i;
       $notlhs323$i41$i = $536 >= $571;
       $notrhs324$i42$i = $573 >= $538;
       $not$$i43$i = $notrhs324$i42$i & $notlhs323$i41$i;
       $$316$i44$i = $581 & $not$$i43$i;
       $brmerge$demorgan$i45$i = $582 & $$316$i44$i;
       if ($brmerge$demorgan$i45$i) {
        $583 = Math_fround(HEAPF32[$365>>2]);
        $584 = Math_fround(HEAPF32[$366>>2]);
        $585 = $559 > $576;
        $586 = Math_fround($534 * $584);
        $587 = Math_fround($532 * $583);
        $$1$i$i$i46$i = $585 ? $559 : $576;
        $588 = Math_fround($587 + $586);
        $589 = Math_fround(HEAPF32[$372>>2]);
        $590 = Math_fround($522 - $534);
        $591 = Math_fround($522 + $534);
        $592 = Math_fround(HEAPF32[$373>>2]);
        $593 = $588 >= $$1$i$i$i46$i;
        $notlhs326$i47$i = $591 >= $592;
        $notrhs327$i48$i = $589 >= $590;
        $not$325$i49$i = $notrhs327$i48$i & $notlhs326$i47$i;
        $594 = $593 & $not$325$i49$i;
        if ($594) {
         $595 = HEAP32[$511>>2]|0;
         $596 = (((($this) + (($425*224)|0)|0) + ($512<<2)|0) + 884|0);
         $597 = HEAP32[$596>>2]|0;
         $598 = (($597) + ($595))|0;
         $599 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($417<<1)|0) + 2192|0);
         $600 = HEAP16[$599>>1]|0;
         $601 = $600&65535;
         $834 = $832;$k_$0247$i = 0;$orderk$0246$i = $601;$rayMaxLimitInt$0$ph10$i221245$i = $rayMaxLimitInt$0$ph10$i219251$i;$rayMinLimitInt$0$ph14$i228244$i = $rayMinLimitInt$0$ph14$i226250$i;
         while(1) {
          $602 = $orderk$0246$i & 7;
          $603 = $orderk$0246$i >>> 3;
          $604 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($602<<2)|0) + 1984|0);
          $605 = HEAP32[$604>>2]|0;
          $606 = ($605|0)==(0);
          L44: do {
           if ($606) {
            $835 = $834;$rayMaxLimitInt$0$ph10$i222$i = $rayMaxLimitInt$0$ph10$i221245$i;$rayMinLimitInt$0$ph14$i229$i = $rayMinLimitInt$0$ph14$i228244$i;
           } else {
            $607 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($602<<5)|0) + 2032|0);
            $608 = Math_fround(HEAPF32[$607>>2]);
            $609 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($602<<5)|0) + 2036|0);
            $610 = Math_fround(HEAPF32[$609>>2]);
            $611 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($602<<5)|0) + 2040|0);
            $612 = Math_fround(HEAPF32[$611>>2]);
            $613 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($602<<5)|0) + 2048|0);
            $614 = Math_fround(HEAPF32[$613>>2]);
            $615 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($602<<5)|0) + 2052|0);
            $616 = Math_fround(HEAPF32[$615>>2]);
            $617 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($602<<5)|0) + 2056|0);
            $618 = Math_fround(HEAPF32[$617>>2]);
            $619 = Math_fround(HEAPF32[$292>>2]);
            $620 = Math_fround(HEAPF32[$294>>2]);
            $621 = Math_fround(HEAPF32[$296>>2]);
            $622 = Math_fround($614 + $619);
            $623 = Math_fround($616 + $620);
            $624 = Math_fround($618 + $621);
            $625 = Math_fround($608 + $622);
            $626 = Math_fround($610 + $623);
            $627 = Math_fround($608 - $622);
            $628 = Math_fround($610 - $623);
            $629 = Math_fround(HEAPF32[$test$i>>2]);
            $630 = Math_fround(HEAPF32[$306>>2]);
            $631 = Math_fround(HEAPF32[$308>>2]);
            $632 = Math_fround($629 - $608);
            $633 = Math_fround($630 - $610);
            $634 = Math_fround($631 - $612);
            $635 = Math_fround(HEAPF32[$313>>2]);
            $636 = Math_fround(HEAPF32[$315>>2]);
            $637 = Math_fround(HEAPF32[$317>>2]);
            $638 = Math_fround(HEAPF32[$319>>2]);
            $639 = Math_fround(HEAPF32[$321>>2]);
            $640 = Math_fround(HEAPF32[$323>>2]);
            $641 = Math_fround($633 * $638);
            $642 = Math_fround($634 * $639);
            $643 = Math_fround($632 * $640);
            $644 = Math_fround($632 * $635);
            $645 = Math_fround($633 * $636);
            $646 = Math_fround($634 * $637);
            $647 = Math_fround($641 - $644);
            $648 = Math_fround($642 - $645);
            $649 = Math_fround($643 - $646);
            $650 = Math_fround(HEAPF32[$334>>2]);
            $651 = Math_fround(HEAPF32[$336>>2]);
            $652 = Math_fround(HEAPF32[$338>>2]);
            $653 = Math_fround(HEAPF32[$340>>2]);
            $654 = Math_fround($623 * $652);
            $655 = Math_fround($624 * $653);
            $656 = Math_fround($622 * $650);
            $657 = Math_fround($623 * $651);
            $658 = Math_fround($656 + $654);
            $659 = Math_fround($657 + $655);
            $660 = Math_fround(HEAPF32[$348>>2]);
            $661 = Math_fround(HEAPF32[$350>>2]);
            $662 = Math_fround(HEAPF32[$352>>2]);
            $663 = Math_fround(HEAPF32[$354>>2]);
            $664 = Math_fround(-$647);
            $665 = Math_fround(-$648);
            $666 = Math_fround(-$649);
            $667 = $647 > $664;
            $$$i$i$i19$i = $667 ? $647 : $664;
            $668 = $648 > $665;
            $669 = $668 ? $648 : $665;
            $670 = $658 >= $$$i$i$i19$i;
            $671 = $659 >= $669;
            $notlhs321$i20$i = $625 >= $660;
            $notrhs322$i21$i = $662 >= $627;
            $not$320$i22$i = $notrhs322$i21$i & $notlhs321$i20$i;
            $672 = $670 & $not$320$i22$i;
            $notlhs323$i23$i = $626 >= $661;
            $notrhs324$i24$i = $663 >= $628;
            $not$$i25$i = $notrhs324$i24$i & $notlhs323$i23$i;
            $$316$i26$i = $671 & $not$$i25$i;
            $brmerge$demorgan$i27$i = $672 & $$316$i26$i;
            if ($brmerge$demorgan$i27$i) {
             $673 = Math_fround(HEAPF32[$365>>2]);
             $674 = Math_fround(HEAPF32[$366>>2]);
             $675 = $649 > $666;
             $676 = Math_fround($624 * $674);
             $677 = Math_fround($622 * $673);
             $$1$i$i$i28$i = $675 ? $649 : $666;
             $678 = Math_fround($677 + $676);
             $679 = Math_fround(HEAPF32[$372>>2]);
             $680 = Math_fround($612 - $624);
             $681 = Math_fround($612 + $624);
             $682 = Math_fround(HEAPF32[$373>>2]);
             $683 = $678 >= $$1$i$i$i28$i;
             $notlhs326$i29$i = $681 >= $682;
             $notrhs327$i30$i = $679 >= $680;
             $not$325$i31$i = $notrhs327$i30$i & $notlhs326$i29$i;
             $684 = $683 & $not$325$i31$i;
             if ($684) {
              $685 = ((((($this) + (($425*1120)|0)|0) + (($512*224)|0)|0) + ($602<<2)|0) + 2004|0);
              $686 = HEAP32[$685>>2]|0;
              $687 = (($598) + ($686))|0;
              $688 = HEAP32[$421>>2]|0;
              $$sum$i$i = (($687) + ($605))|0;
              $689 = (($688) + ($$sum$i$i<<5)|0);
              $690 = HEAP32[$422>>2]|0;
              $691 = (($688) + ($687<<5)|0);
              $692 = (($690) + ($687<<3)|0);
              $836 = $834;$_boxes$0$ph18$i$i = $691;$_objects$0$ph17$i$i = $692;$rayMaxLimitInt$0$ph15$i$i = $rayMaxLimitInt$0$ph10$i221245$i;$rayMinLimitInt$0$ph16$i$i = $rayMinLimitInt$0$ph14$i228244$i;
              while(1) {
               $784 = $836;$_boxes$05$i$i = $_boxes$0$ph18$i$i;$_objects$04$i$i = $_objects$0$ph17$i$i;
               L50: while(1) {
                $693 = (($_boxes$05$i$i) + 32|0);
                $694 = (($_objects$04$i$i) + 8|0);
                $695 = (($_boxes$05$i$i) + 28|0);
                $696 = HEAP32[$695>>2]|0;
                $697 = ($696>>>0)<($rayMinLimitInt$0$ph16$i$i>>>0);
                do {
                 if ($697) {
                  $837 = $784;
                 } else {
                  $699 = (($_boxes$05$i$i) + 12|0);
                  $700 = HEAP32[$699>>2]|0;
                  $701 = ($700>>>0)>($rayMaxLimitInt$0$ph15$i$i>>>0);
                  if ($701) {
                   $835 = $784;$rayMaxLimitInt$0$ph10$i222$i = $rayMaxLimitInt$0$ph15$i$i;$rayMinLimitInt$0$ph14$i229$i = $rayMinLimitInt$0$ph16$i$i;
                   break L44;
                  }
                  $702 = Math_fround(HEAPF32[$_boxes$05$i$i>>2]);
                  $703 = (($_boxes$05$i$i) + 4|0);
                  $704 = Math_fround(HEAPF32[$703>>2]);
                  $705 = (($_boxes$05$i$i) + 8|0);
                  $706 = Math_fround(HEAPF32[$705>>2]);
                  $707 = (($_boxes$05$i$i) + 16|0);
                  $708 = Math_fround(HEAPF32[$707>>2]);
                  $709 = (($_boxes$05$i$i) + 20|0);
                  $710 = Math_fround(HEAPF32[$709>>2]);
                  $711 = (($_boxes$05$i$i) + 24|0);
                  $712 = Math_fround(HEAPF32[$711>>2]);
                  $713 = Math_fround(HEAPF32[$292>>2]);
                  $714 = Math_fround(HEAPF32[$294>>2]);
                  $715 = Math_fround(HEAPF32[$296>>2]);
                  $716 = Math_fround($708 + $713);
                  $717 = Math_fround($710 + $714);
                  $718 = Math_fround($712 + $715);
                  $719 = Math_fround($702 + $716);
                  $720 = Math_fround($704 + $717);
                  $721 = Math_fround($702 - $716);
                  $722 = Math_fround($704 - $717);
                  $723 = Math_fround(HEAPF32[$test$i>>2]);
                  $724 = Math_fround(HEAPF32[$306>>2]);
                  $725 = Math_fround(HEAPF32[$308>>2]);
                  $726 = Math_fround($723 - $702);
                  $727 = Math_fround($724 - $704);
                  $728 = Math_fround($725 - $706);
                  $729 = Math_fround(HEAPF32[$313>>2]);
                  $730 = Math_fround(HEAPF32[$315>>2]);
                  $731 = Math_fround(HEAPF32[$317>>2]);
                  $732 = Math_fround(HEAPF32[$319>>2]);
                  $733 = Math_fround(HEAPF32[$321>>2]);
                  $734 = Math_fround(HEAPF32[$323>>2]);
                  $735 = Math_fround($727 * $732);
                  $736 = Math_fround($728 * $733);
                  $737 = Math_fround($726 * $734);
                  $738 = Math_fround($726 * $729);
                  $739 = Math_fround($727 * $730);
                  $740 = Math_fround($728 * $731);
                  $741 = Math_fround($735 - $738);
                  $742 = Math_fround($736 - $739);
                  $743 = Math_fround($737 - $740);
                  $744 = Math_fround(HEAPF32[$334>>2]);
                  $745 = Math_fround(HEAPF32[$336>>2]);
                  $746 = Math_fround(HEAPF32[$338>>2]);
                  $747 = Math_fround(HEAPF32[$340>>2]);
                  $748 = Math_fround($717 * $746);
                  $749 = Math_fround($718 * $747);
                  $750 = Math_fround($716 * $744);
                  $751 = Math_fround($717 * $745);
                  $752 = Math_fround($750 + $748);
                  $753 = Math_fround($751 + $749);
                  $754 = Math_fround(HEAPF32[$348>>2]);
                  $755 = Math_fround(HEAPF32[$350>>2]);
                  $756 = Math_fround(HEAPF32[$352>>2]);
                  $757 = Math_fround(HEAPF32[$354>>2]);
                  $758 = Math_fround(-$741);
                  $759 = Math_fround(-$742);
                  $760 = Math_fround(-$743);
                  $761 = $741 > $758;
                  $$$i$i$i13$i = $761 ? $741 : $758;
                  $762 = $742 > $759;
                  $763 = $762 ? $742 : $759;
                  $764 = $752 >= $$$i$i$i13$i;
                  $765 = $753 >= $763;
                  $notlhs321$i$i = $719 >= $754;
                  $notrhs322$i$i = $756 >= $721;
                  $not$320$i$i = $notrhs322$i$i & $notlhs321$i$i;
                  $766 = $764 & $not$320$i$i;
                  $notlhs323$i$i = $720 >= $755;
                  $notrhs324$i$i = $757 >= $722;
                  $not$$i$i = $notrhs324$i$i & $notlhs323$i$i;
                  $$316$i$i = $765 & $not$$i$i;
                  $brmerge$demorgan$i$i = $766 & $$316$i$i;
                  if (!($brmerge$demorgan$i$i)) {
                   $837 = $784;
                   break;
                  }
                  $767 = Math_fround(HEAPF32[$365>>2]);
                  $768 = Math_fround(HEAPF32[$366>>2]);
                  $769 = $743 > $760;
                  $770 = Math_fround($718 * $768);
                  $771 = Math_fround($716 * $767);
                  $$1$i$i$i14$i = $769 ? $743 : $760;
                  $772 = Math_fround($771 + $770);
                  $773 = Math_fround(HEAPF32[$372>>2]);
                  $774 = Math_fround($706 - $718);
                  $775 = Math_fround($706 + $718);
                  $776 = Math_fround(HEAPF32[$373>>2]);
                  $777 = $772 >= $$1$i$i$i14$i;
                  $notlhs326$i$i = $775 >= $776;
                  $notrhs327$i$i = $773 >= $774;
                  $not$325$i$i = $notrhs327$i$i & $notlhs326$i$i;
                  $778 = $777 & $not$325$i$i;
                  if (!($778)) {
                   $837 = $784;
                   break;
                  }
                  $779 = HEAP32[$pcb>>2]|0;
                  $780 = HEAP32[$779>>2]|0;
                  $781 = (FUNCTION_TABLE_iiiii[$780 & 511]($pcb,$currentDist$i,$_objects$04$i$i,1)|0);
                  if (!($781)) {
                   $$0$i = 0;
                   label = 43;
                   break L30;
                  }
                  $782 = Math_fround(HEAPF32[$currentDist$i>>2]);
                  $783 = $782 < $784;
                  if ($783) {
                   break L50;
                  } else {
                   $837 = $782;
                  }
                 }
                } while(0);
                $698 = ($693|0)==($689|0);
                if ($698) {
                 $835 = $837;$rayMaxLimitInt$0$ph10$i222$i = $rayMaxLimitInt$0$ph15$i$i;$rayMinLimitInt$0$ph14$i229$i = $rayMinLimitInt$0$ph16$i$i;
                 break L44;
                } else {
                 $784 = $837;$_boxes$05$i$i = $693;$_objects$04$i$i = $694;
                }
               }
               $785 = Math_fround(HEAPF32[$388>>2]);
               $786 = Math_fround($782 * $785);
               $787 = Math_fround($387 + $786);
               $788 = $387 < $787;
               $789 = $788 ? $387 : $787;
               $790 = Math_fround($789 - $385);
               $791 = (HEAPF32[tempDoublePtr>>2]=$790,HEAP32[tempDoublePtr>>2]|0);
               $792 = $387 > $787;
               $793 = $792 ? $387 : $787;
               $794 = Math_fround($385 + $793);
               $795 = (HEAPF32[tempDoublePtr>>2]=$794,HEAP32[tempDoublePtr>>2]|0);
               $796 = Math_fround(HEAPF32[$319>>2]);
               $797 = Math_fround(HEAPF32[$321>>2]);
               $798 = Math_fround(HEAPF32[$323>>2]);
               $799 = Math_fround(HEAPF32[$test$i>>2]);
               $800 = Math_fround(HEAPF32[$306>>2]);
               $801 = Math_fround(HEAPF32[$308>>2]);
               $802 = Math_fround($782 * $796);
               $803 = Math_fround($782 * $797);
               $804 = Math_fround($782 * $798);
               $805 = Math_fround($802 + $799);
               $806 = Math_fround($803 + $800);
               $807 = Math_fround($804 + $801);
               $808 = $799 < $805;
               $$$i8$i$i$i = $808 ? $799 : $805;
               $809 = $800 < $806;
               $810 = $809 ? $800 : $806;
               $811 = $801 < $807;
               $$1$i9$i$i$i = $811 ? $801 : $807;
               HEAPF32[$348>>2] = $$$i8$i$i$i;
               HEAPF32[$350>>2] = $810;
               HEAPF32[$373>>2] = $$1$i9$i$i$i;
               HEAPF32[$423>>2] = Math_fround(0.0);
               $812 = $799 > $805;
               $$$i$i$i$i = $812 ? $799 : $805;
               $813 = $800 > $806;
               $814 = $813 ? $800 : $806;
               $815 = $801 > $807;
               $$1$i$i$i$i = $815 ? $801 : $807;
               HEAPF32[$352>>2] = $$$i$i$i$i;
               HEAPF32[$354>>2] = $814;
               HEAPF32[$372>>2] = $$1$i$i$i$i;
               HEAPF32[$424>>2] = Math_fround(0.0);
               $816 = ($791|0)<(0);
               $817 = $791 ^ -1;
               $818 = $791 | -2147483648;
               $$0$i1$i$i = $816 ? $817 : $818;
               $819 = ($795|0)<(0);
               $820 = $795 ^ -1;
               $821 = $795 | -2147483648;
               $$0$i$i$i = $819 ? $820 : $821;
               $822 = ($693|0)==($689|0);
               if ($822) {
                $835 = $782;$rayMaxLimitInt$0$ph10$i222$i = $$0$i$i$i;$rayMinLimitInt$0$ph14$i229$i = $$0$i1$i$i;
                break;
               } else {
                $836 = $782;$_boxes$0$ph18$i$i = $693;$_objects$0$ph17$i$i = $694;$rayMaxLimitInt$0$ph15$i$i = $$0$i$i$i;$rayMinLimitInt$0$ph16$i$i = $$0$i1$i$i;
               }
              }
             } else {
              $835 = $834;$rayMaxLimitInt$0$ph10$i222$i = $rayMaxLimitInt$0$ph10$i221245$i;$rayMinLimitInt$0$ph14$i229$i = $rayMinLimitInt$0$ph14$i228244$i;
             }
            } else {
             $835 = $834;$rayMaxLimitInt$0$ph10$i222$i = $rayMaxLimitInt$0$ph10$i221245$i;$rayMinLimitInt$0$ph14$i229$i = $rayMinLimitInt$0$ph14$i228244$i;
            }
           }
          } while(0);
          $823 = (($k_$0247$i) + 1)|0;
          $824 = ($823>>>0)<(5);
          if ($824) {
           $834 = $835;$k_$0247$i = $823;$orderk$0246$i = $603;$rayMaxLimitInt$0$ph10$i221245$i = $rayMaxLimitInt$0$ph10$i222$i;$rayMinLimitInt$0$ph14$i228244$i = $rayMinLimitInt$0$ph14$i229$i;
          } else {
           $833 = $835;$rayMaxLimitInt$0$ph10$i220$i = $rayMaxLimitInt$0$ph10$i222$i;$rayMinLimitInt$0$ph14$i227$i = $rayMinLimitInt$0$ph14$i229$i;
           break;
          }
         }
        } else {
         $833 = $832;$rayMaxLimitInt$0$ph10$i220$i = $rayMaxLimitInt$0$ph10$i219251$i;$rayMinLimitInt$0$ph14$i227$i = $rayMinLimitInt$0$ph14$i226250$i;
        }
       } else {
        $833 = $832;$rayMaxLimitInt$0$ph10$i220$i = $rayMaxLimitInt$0$ph10$i219251$i;$rayMinLimitInt$0$ph14$i227$i = $rayMinLimitInt$0$ph14$i226250$i;
       }
      }
      $825 = (($j_$0252$i) + 1)|0;
      $826 = ($825>>>0)<(5);
      if ($826) {
       $832 = $833;$j_$0252$i = $825;$orderj$0253$i = $513;$rayMaxLimitInt$0$ph10$i219251$i = $rayMaxLimitInt$0$ph10$i220$i;$rayMinLimitInt$0$ph14$i226250$i = $rayMinLimitInt$0$ph14$i227$i;
      } else {
       $829 = $833;$rayMaxLimitInt$0$ph10$i218$i = $rayMaxLimitInt$0$ph10$i220$i;$rayMinLimitInt$0$ph14$i225$i = $rayMinLimitInt$0$ph14$i227$i;
       break;
      }
     }
    } else {
     $829 = $831;$rayMaxLimitInt$0$ph10$i218$i = $rayMaxLimitInt$0$ph10$i217255$i;$rayMinLimitInt$0$ph14$i225$i = $rayMinLimitInt$0$ph14$i224254$i;
    }
   } else {
    $829 = $831;$rayMaxLimitInt$0$ph10$i218$i = $rayMaxLimitInt$0$ph10$i217255$i;$rayMinLimitInt$0$ph14$i225$i = $rayMinLimitInt$0$ph14$i224254$i;
   }
  }
  $827 = (($i_$0256$i) + 1)|0;
  $828 = ($827>>>0)<(5);
  if ($828) {
   $831 = $829;$i_$0256$i = $827;$orderi$0257$i = $426;$rayMaxLimitInt$0$ph10$i217255$i = $rayMaxLimitInt$0$ph10$i218$i;$rayMinLimitInt$0$ph14$i224254$i = $rayMinLimitInt$0$ph14$i225$i;
  } else {
   break;
  }
 }
 if ((label|0) == 43) {
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAPF32[$inOutDistance>>2] = $829;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK5physx2Sq16BucketPrunerCore7overlapERKNS0_9ShapeDataERNS0_14PrunerCallbackE($this,$queryVolume,$pcb) {
 $this = $this|0;
 $queryVolume = $queryVolume|0;
 $pcb = $pcb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $again$0$off0 = 0, $fabsf$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $0 = sp + 320|0;
 $1 = sp + 516|0;
 $2 = sp + 480|0;
 $3 = sp + 176|0;
 $4 = sp + 464|0;
 $5 = sp + 144|0;
 $6 = sp;
 $7 = sp + 504|0;
 $8 = (($queryVolume) + 144|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 if ((($10|0) == 0)) {
  $61 = (($queryVolume) + 148|0);
  $62 = (($queryVolume) + 160|0);
  $63 = (($queryVolume) + 120|0);
  $64 = Math_fround(HEAPF32[$61>>2]);
  $65 = (($queryVolume) + 152|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = (($queryVolume) + 156|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$5>>2] = $64;
  $69 = (($5) + 4|0);
  HEAPF32[$69>>2] = $66;
  $70 = (($5) + 8|0);
  HEAPF32[$70>>2] = $68;
  $71 = (($5) + 12|0);
  HEAPF32[$71>>2] = Math_fround(0.0);
  $72 = Math_fround(HEAPF32[$62>>2]);
  $73 = Math_fround($72 * $72);
  $74 = (($5) + 16|0);
  HEAPF32[$74>>2] = $73;
  $75 = (__ZN28BucketPrunerOverlapTraversalI19SphereAABBTest_SIMDLb1EEclERKN5physx2Sq16BucketPrunerCoreERKS0_RNS3_14PrunerCallbackERKNS2_9PxBounds3E(0,$this,$5,$pcb,$63)|0);
  $again$0$off0 = $75;
  STACKTOP = sp;return ($again$0$off0|0);
 } else if ((($10|0) == 2)) {
  $46 = (($queryVolume) + 120|0);
  $47 = (($queryVolume) + 84|0);
  $48 = (($queryVolume) + 72|0);
  $49 = (($queryVolume) + 4|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($50 * Math_fround(1.00999999046325683594));
  $52 = (($queryVolume) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($53 * Math_fround(1.00999999046325683594));
  $55 = (($queryVolume) + 12|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($56 * Math_fround(1.00999999046325683594));
  HEAPF32[$4>>2] = $51;
  $58 = (($4) + 4|0);
  HEAPF32[$58>>2] = $54;
  $59 = (($4) + 8|0);
  HEAPF32[$59>>2] = $57;
  __ZN16OBBAABBTest_SIMDC2ERKN5physx7PxMat33ERKNS0_6PxVec3ES6_($3,$47,$48,$4);
  $60 = (__ZN28BucketPrunerOverlapTraversalI16OBBAABBTest_SIMDLb0EEclERKN5physx2Sq16BucketPrunerCoreERKS0_RNS3_14PrunerCallbackERKNS2_9PxBounds3E(0,$this,$3,$pcb,$46)|0);
  $again$0$off0 = $60;
  STACKTOP = sp;return ($again$0$off0|0);
 } else if ((($10|0) == 3)) {
  $11 = (($queryVolume) + 68|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($12)))));
  $13 = $fabsf$i$i < Math_fround(0.999998986721038818359);
  $14 = (($queryVolume) + 120|0);
  if ($13) {
   $15 = (($queryVolume) + 84|0);
   $16 = (($queryVolume) + 72|0);
   $17 = (($queryVolume) + 4|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = Math_fround($18 * Math_fround(1.00999999046325683594));
   $20 = (($queryVolume) + 8|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = Math_fround($21 * Math_fround(1.00999999046325683594));
   $23 = (($queryVolume) + 12|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($24 * Math_fround(1.00999999046325683594));
   HEAPF32[$1>>2] = $19;
   $26 = (($1) + 4|0);
   HEAPF32[$26>>2] = $22;
   $27 = (($1) + 8|0);
   HEAPF32[$27>>2] = $25;
   __ZN16OBBAABBTest_SIMDC2ERKN5physx7PxMat33ERKNS0_6PxVec3ES6_($0,$15,$16,$1);
   $28 = (__ZN28BucketPrunerOverlapTraversalI16OBBAABBTest_SIMDLb0EEclERKN5physx2Sq16BucketPrunerCoreERKS0_RNS3_14PrunerCallbackERKNS2_9PxBounds3E(0,$this,$0,$pcb,$14)|0);
   $again$0$off0 = $28;
   STACKTOP = sp;return ($again$0$off0|0);
  } else {
   $29 = Math_fround(HEAPF32[$14>>2]);
   HEAPF32[$2>>2] = $29;
   $30 = (($2) + 4|0);
   $31 = (($queryVolume) + 124|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   HEAPF32[$30>>2] = $32;
   $33 = (($2) + 8|0);
   $34 = (($queryVolume) + 128|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   HEAPF32[$33>>2] = $35;
   $36 = (($2) + 12|0);
   $37 = (($queryVolume) + 132|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   HEAPF32[$36>>2] = $38;
   $39 = (($2) + 16|0);
   $40 = (($queryVolume) + 136|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   HEAPF32[$39>>2] = $41;
   $42 = (($2) + 20|0);
   $43 = (($queryVolume) + 140|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   HEAPF32[$42>>2] = $44;
   $45 = (__ZN28BucketPrunerOverlapTraversalI24BucketPrunerAABBAABBTestLb1EEclERKN5physx2Sq16BucketPrunerCoreERKS0_RNS3_14PrunerCallbackERKNS2_9PxBounds3E(0,$this,$2,$pcb,$14)|0);
   $again$0$off0 = $45;
   STACKTOP = sp;return ($again$0$off0|0);
  }
 } else if ((($10|0) == 4)) {
  $76 = (($queryVolume) + 120|0);
  $77 = (($queryVolume) + 84|0);
  $78 = (($queryVolume) + 72|0);
  $79 = (($queryVolume) + 4|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = Math_fround($80 * Math_fround(1.00999999046325683594));
  $82 = (($queryVolume) + 8|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($83 * Math_fround(1.00999999046325683594));
  $85 = (($queryVolume) + 12|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround($86 * Math_fround(1.00999999046325683594));
  HEAPF32[$7>>2] = $81;
  $88 = (($7) + 4|0);
  HEAPF32[$88>>2] = $84;
  $89 = (($7) + 8|0);
  HEAPF32[$89>>2] = $87;
  __ZN16OBBAABBTest_SIMDC2ERKN5physx7PxMat33ERKNS0_6PxVec3ES6_($6,$77,$78,$7);
  $90 = (__ZN28BucketPrunerOverlapTraversalI16OBBAABBTest_SIMDLb0EEclERKN5physx2Sq16BucketPrunerCoreERKS0_RNS3_14PrunerCallbackERKNS2_9PxBounds3E(0,$this,$6,$pcb,$76)|0);
  $again$0$off0 = $90;
  STACKTOP = sp;return ($again$0$off0|0);
 } else {
  $again$0$off0 = 1;
  STACKTOP = sp;return ($again$0$off0|0);
 }
 return 0|0;
}
function __ZN28BucketPrunerOverlapTraversalI16OBBAABBTest_SIMDLb0EEclERKN5physx2Sq16BucketPrunerCoreERKS0_RNS3_14PrunerCallbackERKNS2_9PxBounds3E($this,$core,$test,$pcb,$cullBox) {
 $this = $this|0;
 $core = $core|0;
 $test = $test|0;
 $pcb = $pcb|0;
 $cullBox = $cullBox|0;
 var $$0 = 0, $$0$i1 = 0, $$0$i2 = 0, $$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $boxes$02$i = 0;
 var $dist = 0, $dist$i = 0, $i$015 = 0, $i1$012 = 0, $j$09 = 0, $k$06 = 0, $objects$03$i = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $dist$i = sp + 36|0;
 $tmp = sp;
 $dist = sp + 32|0;
 $0 = (($core) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = (($tmp) + 4|0);
   $4 = (($tmp) + 8|0);
   $5 = (($tmp) + 16|0);
   $6 = (($tmp) + 20|0);
   $7 = (($tmp) + 24|0);
   $i$015 = 0;
   while(1) {
    ;HEAP32[$tmp+0>>2]=0|0;HEAP32[$tmp+4>>2]=0|0;HEAP32[$tmp+8>>2]=0|0;HEAP32[$tmp+12>>2]=0|0;HEAP32[$tmp+16>>2]=0|0;HEAP32[$tmp+20>>2]=0|0;HEAP32[$tmp+24>>2]=0|0;HEAP32[$tmp+28>>2]=0|0;
    $8 = ((($core) + (($i$015*24)|0)|0) + 160|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = ((($core) + (($i$015*24)|0)|0) + 172|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    $12 = Math_fround($9 + $11);
    $13 = ((($core) + (($i$015*24)|0)|0) + 164|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $15 = ((($core) + (($i$015*24)|0)|0) + 176|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = Math_fround($14 + $16);
    $18 = ((($core) + (($i$015*24)|0)|0) + 168|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = ((($core) + (($i$015*24)|0)|0) + 180|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = Math_fround($19 + $21);
    $23 = Math_fround($12 * Math_fround(0.5));
    $24 = Math_fround($17 * Math_fround(0.5));
    $25 = Math_fround($22 * Math_fround(0.5));
    HEAPF32[$tmp>>2] = $23;
    HEAPF32[$3>>2] = $24;
    HEAPF32[$4>>2] = $25;
    $26 = Math_fround($11 - $9);
    $27 = Math_fround($16 - $14);
    $28 = Math_fround($21 - $19);
    $29 = Math_fround($26 * Math_fround(0.5));
    $30 = Math_fround($27 * Math_fround(0.5));
    $31 = Math_fround($28 * Math_fround(0.5));
    HEAPF32[$5>>2] = $29;
    HEAPF32[$6>>2] = $30;
    HEAPF32[$7>>2] = $31;
    $32 = (__ZNK16OBBAABBTest_SIMDclERKN5physx2Sq9BucketBoxE($test,$tmp)|0);
    $33 = ($32|0)==(0);
    if (!($33)) {
     HEAPF32[$dist>>2] = Math_fround(-1.0);
     $34 = HEAP32[$pcb>>2]|0;
     $35 = HEAP32[$34>>2]|0;
     $36 = ((($core) + ($i$015<<3)|0) + 32|0);
     $37 = (FUNCTION_TABLE_iiiii[$35 & 511]($pcb,$dist,$36,1)|0);
     if (!($37)) {
      $$0 = 0;
      break;
     }
    }
    $38 = (($i$015) + 1)|0;
    $39 = HEAP32[$0>>2]|0;
    $40 = ($38>>>0)<($39>>>0);
    if ($40) {
     $i$015 = $38;
    } else {
     break L1;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $41 = (($core) + 584|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if ($43) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = (($core) + 608|0);
 $45 = (__ZNK16OBBAABBTest_SIMDclERKN5physx2Sq9BucketBoxE($test,$44)|0);
 $46 = ($45|0)==(0);
 if ($46) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $47 = (($core) + 592|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($cullBox) + ($48<<2)|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
 $52 = (($cullBox) + 12|0);
 $53 = (($52) + ($48<<2)|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (HEAPF32[tempDoublePtr>>2]=$54,HEAP32[tempDoublePtr>>2]|0);
 $56 = ($51|0)<(0);
 $57 = $51 ^ -1;
 $58 = $51 | -2147483648;
 $$0$i2 = $56 ? $57 : $58;
 $59 = ($55|0)<(0);
 $60 = $55 ^ -1;
 $61 = $55 | -2147483648;
 $$0$i1 = $59 ? $60 : $61;
 $62 = (($core) + 20|0);
 $63 = (($core) + 24|0);
 $i1$012 = 0;
 L16: while(1) {
  $64 = ((($core) + ($i1$012<<2)|0) + 640|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0);
  if (!($66)) {
   $67 = ((($core) + ($i1$012<<5)|0) + 688|0);
   $68 = (__ZNK16OBBAABBTest_SIMDclERKN5physx2Sq9BucketBoxE($test,$67)|0);
   $69 = ($68|0)==(0);
   if (!($69)) {
    $70 = ((($core) + ($i1$012<<2)|0) + 660|0);
    $j$09 = 0;
    while(1) {
     $71 = (((($core) + (($i1$012*224)|0)|0) + ($j$09<<2)|0) + 864|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)==(0);
     if (!($73)) {
      $74 = (((($core) + (($i1$012*224)|0)|0) + ($j$09<<5)|0) + 912|0);
      $75 = (__ZNK16OBBAABBTest_SIMDclERKN5physx2Sq9BucketBoxE($test,$74)|0);
      $76 = ($75|0)==(0);
      if (!($76)) {
       $77 = (((($core) + (($i1$012*224)|0)|0) + ($j$09<<2)|0) + 884|0);
       $k$06 = 0;
       while(1) {
        $78 = ((((($core) + (($i1$012*1120)|0)|0) + (($j$09*224)|0)|0) + ($k$06<<2)|0) + 1984|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = ($79|0)==(0);
        L28: do {
         if (!($80)) {
          $81 = ((((($core) + (($i1$012*1120)|0)|0) + (($j$09*224)|0)|0) + ($k$06<<5)|0) + 2032|0);
          $82 = (__ZNK16OBBAABBTest_SIMDclERKN5physx2Sq9BucketBoxE($test,$81)|0);
          $83 = ($82|0)==(0);
          if (!($83)) {
           $84 = HEAP32[$70>>2]|0;
           $85 = HEAP32[$77>>2]|0;
           $86 = (($85) + ($84))|0;
           $87 = ((((($core) + (($i1$012*1120)|0)|0) + (($j$09*224)|0)|0) + ($k$06<<2)|0) + 2004|0);
           $88 = HEAP32[$87>>2]|0;
           $89 = (($86) + ($88))|0;
           $90 = HEAP32[$62>>2]|0;
           $91 = HEAP32[$63>>2]|0;
           $92 = (($91) + ($89<<3)|0);
           $93 = (($90) + ($89<<5)|0);
           $$in$i = $79;$boxes$02$i = $93;$objects$03$i = $92;
           while(1) {
            $94 = (($$in$i) + -1)|0;
            $95 = (($boxes$02$i) + 32|0);
            $96 = (($objects$03$i) + 8|0);
            $97 = (($boxes$02$i) + 28|0);
            $98 = HEAP32[$97>>2]|0;
            $99 = ($98>>>0)<($$0$i2>>>0);
            if (!($99)) {
             $101 = (($boxes$02$i) + 12|0);
             $102 = HEAP32[$101>>2]|0;
             $103 = ($102>>>0)>($$0$i1>>>0);
             if ($103) {
              break L28;
             }
             $104 = (__ZNK16OBBAABBTest_SIMDclERKN5physx2Sq9BucketBoxE($test,$boxes$02$i)|0);
             $105 = ($104|0)==(0);
             if (!($105)) {
              HEAPF32[$dist$i>>2] = Math_fround(-1.0);
              $106 = HEAP32[$pcb>>2]|0;
              $107 = HEAP32[$106>>2]|0;
              $108 = (FUNCTION_TABLE_iiiii[$107 & 511]($pcb,$dist$i,$objects$03$i,1)|0);
              if (!($108)) {
               $$0 = 0;
               label = 26;
               break L16;
              }
             }
            }
            $100 = ($94|0)==(0);
            if ($100) {
             break;
            } else {
             $$in$i = $94;$boxes$02$i = $95;$objects$03$i = $96;
            }
           }
          }
         }
        } while(0);
        $109 = (($k$06) + 1)|0;
        $110 = ($109>>>0)<(5);
        if ($110) {
         $k$06 = $109;
        } else {
         break;
        }
       }
      }
     }
     $111 = (($j$09) + 1)|0;
     $112 = ($111>>>0)<(5);
     if ($112) {
      $j$09 = $111;
     } else {
      break;
     }
    }
   }
  }
  $113 = (($i1$012) + 1)|0;
  $114 = ($113>>>0)<(5);
  if ($114) {
   $i1$012 = $113;
  } else {
   $$0 = 1;
   label = 26;
   break;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN28BucketPrunerOverlapTraversalI24BucketPrunerAABBAABBTestLb1EEclERKN5physx2Sq16BucketPrunerCoreERKS0_RNS3_14PrunerCallbackERKNS2_9PxBounds3E($this,$core,$test,$pcb,$cullBox) {
 $this = $this|0;
 $core = $core|0;
 $test = $test|0;
 $pcb = $pcb|0;
 $cullBox = $cullBox|0;
 var $$0 = 0, $$0$i5 = 0, $$0$i6 = 0, $$in$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0);
 var $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0;
 var $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0;
 var $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0);
 var $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0);
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0;
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $boxes$06$i = 0, $dist = 0, $dist$i = 0, $i$044 = 0, $i1$041 = 0, $j$038 = 0, $k$036 = 0, $objects$07$i = 0, $phitmp$i$i = 0;
 var $phitmp$i$i$i = 0, $phitmp$i$i1 = 0, $phitmp$i$i3 = 0, $phitmp$i$i7 = 0, $phitmp$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dist$i = sp + 4|0;
 $dist = sp;
 $0 = (($core) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = (($test) + 12|0);
   $4 = (($test) + 4|0);
   $5 = (($test) + 16|0);
   $6 = (($test) + 8|0);
   $7 = (($test) + 20|0);
   $265 = $1;$i$044 = 0;
   while(1) {
    $8 = ((($core) + (($i$044*24)|0)|0) + 160|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = ((($core) + (($i$044*24)|0)|0) + 172|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    $12 = Math_fround($9 + $11);
    $13 = ((($core) + (($i$044*24)|0)|0) + 164|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $15 = ((($core) + (($i$044*24)|0)|0) + 176|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = Math_fround($14 + $16);
    $18 = ((($core) + (($i$044*24)|0)|0) + 168|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = ((($core) + (($i$044*24)|0)|0) + 180|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = Math_fround($19 + $21);
    $23 = Math_fround($12 * Math_fround(0.5));
    $24 = Math_fround($17 * Math_fround(0.5));
    $25 = Math_fround($22 * Math_fround(0.5));
    $26 = Math_fround($11 - $9);
    $27 = Math_fround($16 - $14);
    $28 = Math_fround($21 - $19);
    $29 = Math_fround($26 * Math_fround(0.5));
    $30 = Math_fround($27 * Math_fround(0.5));
    $31 = Math_fround($28 * Math_fround(0.5));
    $32 = Math_fround($24 - $30);
    $33 = Math_fround($25 - $31);
    $34 = Math_fround($23 + $29);
    $35 = Math_fround($24 + $30);
    $36 = Math_fround($25 + $31);
    $37 = Math_fround(HEAPF32[$test>>2]);
    $38 = $37 > $34;
    if ($38) {
     $55 = $265;
    } else {
     $39 = Math_fround($23 - $29);
     $40 = Math_fround(HEAPF32[$3>>2]);
     $41 = $39 > $40;
     if ($41) {
      $55 = $265;
     } else {
      $42 = Math_fround(HEAPF32[$4>>2]);
      $43 = $42 > $35;
      if ($43) {
       $55 = $265;
      } else {
       $44 = Math_fround(HEAPF32[$5>>2]);
       $45 = $32 > $44;
       if ($45) {
        $55 = $265;
       } else {
        $46 = Math_fround(HEAPF32[$6>>2]);
        $47 = $46 > $36;
        if ($47) {
         $55 = $265;
        } else {
         $48 = Math_fround(HEAPF32[$7>>2]);
         $phitmp$i$i9 = !($33 > $48);
         if ($phitmp$i$i9) {
          HEAPF32[$dist>>2] = Math_fround(-1.0);
          $49 = HEAP32[$pcb>>2]|0;
          $50 = HEAP32[$49>>2]|0;
          $51 = ((($core) + ($i$044<<3)|0) + 32|0);
          $52 = (FUNCTION_TABLE_iiiii[$50 & 511]($pcb,$dist,$51,1)|0);
          if (!($52)) {
           $$0 = 0;
           break;
          }
          $$pre = HEAP32[$0>>2]|0;
          $55 = $$pre;
         } else {
          $55 = $265;
         }
        }
       }
      }
     }
    }
    $53 = (($i$044) + 1)|0;
    $54 = ($53>>>0)<($55>>>0);
    if ($54) {
     $265 = $55;$i$044 = $53;
    } else {
     break L1;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $56 = (($core) + 584|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0);
 if ($58) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $59 = (($core) + 608|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($core) + 624|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($core) + 612|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($core) + 628|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($64 - $66);
 $68 = (($core) + 616|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($core) + 632|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($69 - $71);
 $73 = Math_fround($60 + $62);
 $74 = Math_fround($64 + $66);
 $75 = Math_fround($69 + $71);
 $76 = Math_fround(HEAPF32[$test>>2]);
 $77 = $76 > $73;
 if ($77) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = Math_fround($60 - $62);
 $79 = (($test) + 12|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = $78 > $80;
 if ($81) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $82 = (($test) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = $83 > $74;
 if ($84) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $85 = (($test) + 16|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = $67 > $86;
 if ($87) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $88 = (($test) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = $89 > $75;
 if ($90) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $91 = (($test) + 20|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $phitmp$i$i7 = !($72 > $92);
 if (!($phitmp$i$i7)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $93 = (($core) + 592|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($cullBox) + ($94<<2)|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (HEAPF32[tempDoublePtr>>2]=$96,HEAP32[tempDoublePtr>>2]|0);
 $98 = (($cullBox) + 12|0);
 $99 = (($98) + ($94<<2)|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (HEAPF32[tempDoublePtr>>2]=$100,HEAP32[tempDoublePtr>>2]|0);
 $102 = ($97|0)<(0);
 $103 = $97 ^ -1;
 $104 = $97 | -2147483648;
 $$0$i6 = $102 ? $103 : $104;
 $105 = ($101|0)<(0);
 $106 = $101 ^ -1;
 $107 = $101 | -2147483648;
 $$0$i5 = $105 ? $106 : $107;
 $108 = (($core) + 20|0);
 $109 = (($core) + 24|0);
 $i1$041 = 0;
 L37: while(1) {
  $110 = ((($core) + ($i1$041<<2)|0) + 640|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(0);
  if (!($112)) {
   $113 = ((($core) + ($i1$041<<5)|0) + 688|0);
   $114 = Math_fround(HEAPF32[$113>>2]);
   $115 = ((($core) + ($i1$041<<5)|0) + 704|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   $117 = ((($core) + ($i1$041<<5)|0) + 692|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = ((($core) + ($i1$041<<5)|0) + 708|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = Math_fround($118 - $120);
   $122 = ((($core) + ($i1$041<<5)|0) + 696|0);
   $123 = Math_fround(HEAPF32[$122>>2]);
   $124 = ((($core) + ($i1$041<<5)|0) + 712|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = Math_fround($123 - $125);
   $127 = Math_fround($114 + $116);
   $128 = Math_fround($118 + $120);
   $129 = Math_fround($123 + $125);
   $130 = Math_fround(HEAPF32[$test>>2]);
   $131 = $130 > $127;
   if (!($131)) {
    $132 = Math_fround($114 - $116);
    $133 = Math_fround(HEAPF32[$79>>2]);
    $134 = $132 > $133;
    if (!($134)) {
     $135 = Math_fround(HEAPF32[$82>>2]);
     $136 = $135 > $128;
     if (!($136)) {
      $137 = Math_fround(HEAPF32[$85>>2]);
      $138 = $121 > $137;
      if (!($138)) {
       $139 = Math_fround(HEAPF32[$88>>2]);
       $140 = $139 > $129;
       if (!($140)) {
        $141 = Math_fround(HEAPF32[$91>>2]);
        $phitmp$i$i3 = !($126 > $141);
        if ($phitmp$i$i3) {
         $142 = ((($core) + ($i1$041<<2)|0) + 660|0);
         $j$038 = 0;
         while(1) {
          $143 = (((($core) + (($i1$041*224)|0)|0) + ($j$038<<2)|0) + 864|0);
          $144 = HEAP32[$143>>2]|0;
          $145 = ($144|0)==(0);
          do {
           if (!($145)) {
            $146 = (((($core) + (($i1$041*224)|0)|0) + ($j$038<<5)|0) + 912|0);
            $147 = Math_fround(HEAPF32[$146>>2]);
            $148 = (((($core) + (($i1$041*224)|0)|0) + ($j$038<<5)|0) + 928|0);
            $149 = Math_fround(HEAPF32[$148>>2]);
            $150 = (((($core) + (($i1$041*224)|0)|0) + ($j$038<<5)|0) + 916|0);
            $151 = Math_fround(HEAPF32[$150>>2]);
            $152 = (((($core) + (($i1$041*224)|0)|0) + ($j$038<<5)|0) + 932|0);
            $153 = Math_fround(HEAPF32[$152>>2]);
            $154 = Math_fround($151 - $153);
            $155 = (((($core) + (($i1$041*224)|0)|0) + ($j$038<<5)|0) + 920|0);
            $156 = Math_fround(HEAPF32[$155>>2]);
            $157 = (((($core) + (($i1$041*224)|0)|0) + ($j$038<<5)|0) + 936|0);
            $158 = Math_fround(HEAPF32[$157>>2]);
            $159 = Math_fround($156 - $158);
            $160 = Math_fround($147 + $149);
            $161 = Math_fround($151 + $153);
            $162 = Math_fround($156 + $158);
            $163 = Math_fround(HEAPF32[$test>>2]);
            $164 = $163 > $160;
            if ($164) {
             break;
            }
            $165 = Math_fround($147 - $149);
            $166 = Math_fround(HEAPF32[$79>>2]);
            $167 = $165 > $166;
            if ($167) {
             break;
            }
            $168 = Math_fround(HEAPF32[$82>>2]);
            $169 = $168 > $161;
            if ($169) {
             break;
            }
            $170 = Math_fround(HEAPF32[$85>>2]);
            $171 = $154 > $170;
            if ($171) {
             break;
            }
            $172 = Math_fround(HEAPF32[$88>>2]);
            $173 = $172 > $162;
            if ($173) {
             break;
            }
            $174 = Math_fround(HEAPF32[$91>>2]);
            $phitmp$i$i1 = !($159 > $174);
            if (!($phitmp$i$i1)) {
             break;
            }
            $175 = (((($core) + (($i1$041*224)|0)|0) + ($j$038<<2)|0) + 884|0);
            $k$036 = 0;
            while(1) {
             $176 = ((((($core) + (($i1$041*1120)|0)|0) + (($j$038*224)|0)|0) + ($k$036<<2)|0) + 1984|0);
             $177 = HEAP32[$176>>2]|0;
             $178 = ($177|0)==(0);
             L59: do {
              if (!($178)) {
               $179 = ((((($core) + (($i1$041*1120)|0)|0) + (($j$038*224)|0)|0) + ($k$036<<5)|0) + 2032|0);
               $180 = Math_fround(HEAPF32[$179>>2]);
               $181 = ((((($core) + (($i1$041*1120)|0)|0) + (($j$038*224)|0)|0) + ($k$036<<5)|0) + 2048|0);
               $182 = Math_fround(HEAPF32[$181>>2]);
               $183 = ((((($core) + (($i1$041*1120)|0)|0) + (($j$038*224)|0)|0) + ($k$036<<5)|0) + 2036|0);
               $184 = Math_fround(HEAPF32[$183>>2]);
               $185 = ((((($core) + (($i1$041*1120)|0)|0) + (($j$038*224)|0)|0) + ($k$036<<5)|0) + 2052|0);
               $186 = Math_fround(HEAPF32[$185>>2]);
               $187 = Math_fround($184 - $186);
               $188 = ((((($core) + (($i1$041*1120)|0)|0) + (($j$038*224)|0)|0) + ($k$036<<5)|0) + 2040|0);
               $189 = Math_fround(HEAPF32[$188>>2]);
               $190 = ((((($core) + (($i1$041*1120)|0)|0) + (($j$038*224)|0)|0) + ($k$036<<5)|0) + 2056|0);
               $191 = Math_fround(HEAPF32[$190>>2]);
               $192 = Math_fround($189 - $191);
               $193 = Math_fround($180 + $182);
               $194 = Math_fround($184 + $186);
               $195 = Math_fround($189 + $191);
               $196 = Math_fround(HEAPF32[$test>>2]);
               $197 = $196 > $193;
               if ($197) {
                break;
               }
               $198 = Math_fround($180 - $182);
               $199 = Math_fround(HEAPF32[$79>>2]);
               $200 = $198 > $199;
               if ($200) {
                break;
               }
               $201 = Math_fround(HEAPF32[$82>>2]);
               $202 = $201 > $194;
               if ($202) {
                break;
               }
               $203 = Math_fround(HEAPF32[$85>>2]);
               $204 = $187 > $203;
               if ($204) {
                break;
               }
               $205 = Math_fround(HEAPF32[$88>>2]);
               $206 = $205 > $195;
               if ($206) {
                break;
               }
               $207 = Math_fround(HEAPF32[$91>>2]);
               $phitmp$i$i = !($192 > $207);
               if (!($phitmp$i$i)) {
                break;
               }
               $208 = HEAP32[$142>>2]|0;
               $209 = HEAP32[$175>>2]|0;
               $210 = (($209) + ($208))|0;
               $211 = ((((($core) + (($i1$041*1120)|0)|0) + (($j$038*224)|0)|0) + ($k$036<<2)|0) + 2004|0);
               $212 = HEAP32[$211>>2]|0;
               $213 = (($210) + ($212))|0;
               $214 = HEAP32[$108>>2]|0;
               $215 = HEAP32[$109>>2]|0;
               $216 = (($215) + ($213<<3)|0);
               $217 = (($214) + ($213<<5)|0);
               $$in$i = $177;$boxes$06$i = $217;$objects$07$i = $216;
               while(1) {
                $218 = (($$in$i) + -1)|0;
                $219 = (($boxes$06$i) + 32|0);
                $220 = (($objects$07$i) + 8|0);
                $221 = (($boxes$06$i) + 28|0);
                $222 = HEAP32[$221>>2]|0;
                $223 = ($222>>>0)<($$0$i6>>>0);
                do {
                 if (!($223)) {
                  $225 = (($boxes$06$i) + 12|0);
                  $226 = HEAP32[$225>>2]|0;
                  $227 = ($226>>>0)>($$0$i5>>>0);
                  if ($227) {
                   break L59;
                  }
                  $228 = Math_fround(HEAPF32[$boxes$06$i>>2]);
                  $229 = (($boxes$06$i) + 16|0);
                  $230 = Math_fround(HEAPF32[$229>>2]);
                  $231 = (($boxes$06$i) + 4|0);
                  $232 = Math_fround(HEAPF32[$231>>2]);
                  $233 = (($boxes$06$i) + 20|0);
                  $234 = Math_fround(HEAPF32[$233>>2]);
                  $235 = Math_fround($232 - $234);
                  $236 = (($boxes$06$i) + 8|0);
                  $237 = Math_fround(HEAPF32[$236>>2]);
                  $238 = (($boxes$06$i) + 24|0);
                  $239 = Math_fround(HEAPF32[$238>>2]);
                  $240 = Math_fround($237 - $239);
                  $241 = Math_fround($228 + $230);
                  $242 = Math_fround($232 + $234);
                  $243 = Math_fround($237 + $239);
                  $244 = Math_fround(HEAPF32[$test>>2]);
                  $245 = $244 > $241;
                  if ($245) {
                   break;
                  }
                  $246 = Math_fround($228 - $230);
                  $247 = Math_fround(HEAPF32[$79>>2]);
                  $248 = $246 > $247;
                  if ($248) {
                   break;
                  }
                  $249 = Math_fround(HEAPF32[$82>>2]);
                  $250 = $249 > $242;
                  if ($250) {
                   break;
                  }
                  $251 = Math_fround(HEAPF32[$85>>2]);
                  $252 = $235 > $251;
                  if ($252) {
                   break;
                  }
                  $253 = Math_fround(HEAPF32[$88>>2]);
                  $254 = $253 > $243;
                  if ($254) {
                   break;
                  }
                  $255 = Math_fround(HEAPF32[$91>>2]);
                  $phitmp$i$i$i = !($240 > $255);
                  if (!($phitmp$i$i$i)) {
                   break;
                  }
                  HEAPF32[$dist$i>>2] = Math_fround(-1.0);
                  $256 = HEAP32[$pcb>>2]|0;
                  $257 = HEAP32[$256>>2]|0;
                  $258 = (FUNCTION_TABLE_iiiii[$257 & 511]($pcb,$dist$i,$objects$07$i,1)|0);
                  if (!($258)) {
                   $$0 = 0;
                   label = 57;
                   break L37;
                  }
                 }
                } while(0);
                $224 = ($218|0)==(0);
                if ($224) {
                 break;
                } else {
                 $$in$i = $218;$boxes$06$i = $219;$objects$07$i = $220;
                }
               }
              }
             } while(0);
             $259 = (($k$036) + 1)|0;
             $260 = ($259>>>0)<(5);
             if ($260) {
              $k$036 = $259;
             } else {
              break;
             }
            }
           }
          } while(0);
          $261 = (($j$038) + 1)|0;
          $262 = ($261>>>0)<(5);
          if ($262) {
           $j$038 = $261;
          } else {
           break;
          }
         }
        }
       }
      }
     }
    }
   }
  }
  $263 = (($i1$041) + 1)|0;
  $264 = ($263>>>0)<(5);
  if ($264) {
   $i1$041 = $263;
  } else {
   $$0 = 1;
   label = 57;
   break;
  }
 }
 if ((label|0) == 57) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN28BucketPrunerOverlapTraversalI19SphereAABBTest_SIMDLb1EEclERKN5physx2Sq16BucketPrunerCoreERKS0_RNS3_14PrunerCallbackERKNS2_9PxBounds3E($this,$core,$test,$pcb,$cullBox) {
 $this = $this|0;
 $core = $core|0;
 $test = $test|0;
 $pcb = $pcb|0;
 $cullBox = $cullBox|0;
 var $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i$i$i1 = Math_fround(0), $$$i$i$i11 = Math_fround(0), $$$i$i$i15 = Math_fround(0), $$$i$i$i5 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i$i = Math_fround(0), $$$i8$i$i13 = Math_fround(0), $$$i8$i$i17 = Math_fround(0), $$$i8$i$i3 = Math_fround(0), $$$i8$i$i7 = Math_fround(0), $$0 = 0, $$0$i10 = 0, $$0$i9 = 0, $$1$i$i$i = Math_fround(0), $$1$i$i$i$i = Math_fround(0), $$1$i$i$i12 = Math_fround(0), $$1$i$i$i16 = Math_fround(0), $$1$i$i$i2 = Math_fround(0);
 var $$1$i$i$i6 = Math_fround(0), $$1$i9$i$i = Math_fround(0), $$1$i9$i$i$i = Math_fround(0), $$1$i9$i$i14 = Math_fround(0), $$1$i9$i$i18 = Math_fround(0), $$1$i9$i$i4 = Math_fround(0), $$1$i9$i$i8 = Math_fround(0), $$in$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0);
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0;
 var $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0;
 var $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0);
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0);
 var $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $boxes$02$i = 0, $dist = 0, $dist$i = 0, $i$031 = 0, $i1$028 = 0, $j$025 = 0, $k$022 = 0, $objects$03$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dist$i = sp + 4|0;
 $dist = sp;
 $0 = (($core) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = (($test) + 4|0);
   $4 = (($test) + 8|0);
   $5 = (($test) + 16|0);
   $321 = $1;$i$031 = 0;
   while(1) {
    $6 = ((($core) + (($i$031*24)|0)|0) + 160|0);
    $7 = Math_fround(HEAPF32[$6>>2]);
    $8 = ((($core) + (($i$031*24)|0)|0) + 172|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = Math_fround($7 + $9);
    $11 = ((($core) + (($i$031*24)|0)|0) + 164|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    $13 = ((($core) + (($i$031*24)|0)|0) + 176|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $15 = Math_fround($12 + $14);
    $16 = ((($core) + (($i$031*24)|0)|0) + 168|0);
    $17 = Math_fround(HEAPF32[$16>>2]);
    $18 = ((($core) + (($i$031*24)|0)|0) + 180|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = Math_fround($17 + $19);
    $21 = Math_fround($10 * Math_fround(0.5));
    $22 = Math_fround($15 * Math_fround(0.5));
    $23 = Math_fround($20 * Math_fround(0.5));
    $24 = Math_fround($9 - $7);
    $25 = Math_fround($14 - $12);
    $26 = Math_fround($19 - $17);
    $27 = Math_fround($24 * Math_fround(0.5));
    $28 = Math_fround($25 * Math_fround(0.5));
    $29 = Math_fround($26 * Math_fround(0.5));
    $30 = Math_fround(HEAPF32[$test>>2]);
    $31 = Math_fround(HEAPF32[$3>>2]);
    $32 = Math_fround(HEAPF32[$4>>2]);
    $33 = Math_fround($30 - $21);
    $34 = Math_fround($31 - $22);
    $35 = Math_fround($32 - $23);
    $36 = Math_fround(-$27);
    $37 = Math_fround(-$28);
    $38 = Math_fround(-$29);
    $39 = $33 < $27;
    $$$i$i$i15 = $39 ? $33 : $27;
    $40 = $34 < $28;
    $41 = $40 ? $34 : $28;
    $42 = $35 < $29;
    $$1$i$i$i16 = $42 ? $35 : $29;
    $43 = $$$i$i$i15 > $36;
    $$$i8$i$i17 = $43 ? $$$i$i$i15 : $36;
    $44 = $41 > $37;
    $45 = $44 ? $41 : $37;
    $46 = $$1$i$i$i16 > $38;
    $$1$i9$i$i18 = $46 ? $$1$i$i$i16 : $38;
    $47 = Math_fround($33 - $$$i8$i$i17);
    $48 = Math_fround($34 - $45);
    $49 = Math_fround($35 - $$1$i9$i$i18);
    $50 = Math_fround(HEAPF32[$5>>2]);
    $51 = Math_fround($47 * $47);
    $52 = Math_fround($48 * $48);
    $53 = Math_fround($51 + $52);
    $54 = Math_fround($49 * $49);
    $55 = Math_fround($53 + $54);
    $56 = !($50 >= $55);
    if ($56) {
     $63 = $321;
    } else {
     HEAPF32[$dist>>2] = Math_fround(-1.0);
     $57 = HEAP32[$pcb>>2]|0;
     $58 = HEAP32[$57>>2]|0;
     $59 = ((($core) + ($i$031<<3)|0) + 32|0);
     $60 = (FUNCTION_TABLE_iiiii[$58 & 511]($pcb,$dist,$59,1)|0);
     if (!($60)) {
      $$0 = 0;
      break;
     }
     $$pre = HEAP32[$0>>2]|0;
     $63 = $$pre;
    }
    $61 = (($i$031) + 1)|0;
    $62 = ($61>>>0)<($63>>>0);
    if ($62) {
     $321 = $63;$i$031 = $61;
    } else {
     break L1;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $64 = (($core) + 584|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0);
 if ($66) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = (($core) + 608|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($core) + 612|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($core) + 616|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($core) + 624|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($core) + 628|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($core) + 632|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround(HEAPF32[$test>>2]);
 $80 = (($test) + 4|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($test) + 8|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($79 - $68);
 $85 = Math_fround($81 - $70);
 $86 = Math_fround($83 - $72);
 $87 = Math_fround(-$74);
 $88 = Math_fround(-$76);
 $89 = Math_fround(-$78);
 $90 = $84 < $74;
 $$$i$i$i11 = $90 ? $84 : $74;
 $91 = $85 < $76;
 $92 = $91 ? $85 : $76;
 $93 = $86 < $78;
 $$1$i$i$i12 = $93 ? $86 : $78;
 $94 = $$$i$i$i11 > $87;
 $$$i8$i$i13 = $94 ? $$$i$i$i11 : $87;
 $95 = $92 > $88;
 $96 = $95 ? $92 : $88;
 $97 = $$1$i$i$i12 > $89;
 $$1$i9$i$i14 = $97 ? $$1$i$i$i12 : $89;
 $98 = Math_fround($84 - $$$i8$i$i13);
 $99 = Math_fround($85 - $96);
 $100 = Math_fround($86 - $$1$i9$i$i14);
 $101 = (($test) + 16|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($98 * $98);
 $104 = Math_fround($99 * $99);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($100 * $100);
 $107 = Math_fround($105 + $106);
 $108 = !($102 >= $107);
 if ($108) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $109 = (($core) + 592|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = (($cullBox) + ($110<<2)|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (HEAPF32[tempDoublePtr>>2]=$112,HEAP32[tempDoublePtr>>2]|0);
 $114 = (($cullBox) + 12|0);
 $115 = (($114) + ($110<<2)|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (HEAPF32[tempDoublePtr>>2]=$116,HEAP32[tempDoublePtr>>2]|0);
 $118 = ($113|0)<(0);
 $119 = $113 ^ -1;
 $120 = $113 | -2147483648;
 $$0$i10 = $118 ? $119 : $120;
 $121 = ($117|0)<(0);
 $122 = $117 ^ -1;
 $123 = $117 | -2147483648;
 $$0$i9 = $121 ? $122 : $123;
 $124 = (($core) + 20|0);
 $125 = (($core) + 24|0);
 $i1$028 = 0;
 L17: while(1) {
  $126 = ((($core) + ($i1$028<<2)|0) + 640|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ($127|0)==(0);
  if (!($128)) {
   $129 = ((($core) + ($i1$028<<5)|0) + 688|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = ((($core) + ($i1$028<<5)|0) + 692|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = ((($core) + ($i1$028<<5)|0) + 696|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = ((($core) + ($i1$028<<5)|0) + 704|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = ((($core) + ($i1$028<<5)|0) + 708|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   $139 = ((($core) + ($i1$028<<5)|0) + 712|0);
   $140 = Math_fround(HEAPF32[$139>>2]);
   $141 = Math_fround(HEAPF32[$test>>2]);
   $142 = Math_fround(HEAPF32[$80>>2]);
   $143 = Math_fround(HEAPF32[$82>>2]);
   $144 = Math_fround($141 - $130);
   $145 = Math_fround($142 - $132);
   $146 = Math_fround($143 - $134);
   $147 = Math_fround(-$136);
   $148 = Math_fround(-$138);
   $149 = Math_fround(-$140);
   $150 = $144 < $136;
   $$$i$i$i5 = $150 ? $144 : $136;
   $151 = $145 < $138;
   $152 = $151 ? $145 : $138;
   $153 = $146 < $140;
   $$1$i$i$i6 = $153 ? $146 : $140;
   $154 = $$$i$i$i5 > $147;
   $$$i8$i$i7 = $154 ? $$$i$i$i5 : $147;
   $155 = $152 > $148;
   $156 = $155 ? $152 : $148;
   $157 = $$1$i$i$i6 > $149;
   $$1$i9$i$i8 = $157 ? $$1$i$i$i6 : $149;
   $158 = Math_fround($144 - $$$i8$i$i7);
   $159 = Math_fround($145 - $156);
   $160 = Math_fround($146 - $$1$i9$i$i8);
   $161 = Math_fround(HEAPF32[$101>>2]);
   $162 = Math_fround($158 * $158);
   $163 = Math_fround($159 * $159);
   $164 = Math_fround($162 + $163);
   $165 = Math_fround($160 * $160);
   $166 = Math_fround($164 + $165);
   $167 = !($161 >= $166);
   if (!($167)) {
    $168 = ((($core) + ($i1$028<<2)|0) + 660|0);
    $j$025 = 0;
    while(1) {
     $169 = (((($core) + (($i1$028*224)|0)|0) + ($j$025<<2)|0) + 864|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = ($170|0)==(0);
     if (!($171)) {
      $172 = (((($core) + (($i1$028*224)|0)|0) + ($j$025<<5)|0) + 912|0);
      $173 = Math_fround(HEAPF32[$172>>2]);
      $174 = (((($core) + (($i1$028*224)|0)|0) + ($j$025<<5)|0) + 916|0);
      $175 = Math_fround(HEAPF32[$174>>2]);
      $176 = (((($core) + (($i1$028*224)|0)|0) + ($j$025<<5)|0) + 920|0);
      $177 = Math_fround(HEAPF32[$176>>2]);
      $178 = (((($core) + (($i1$028*224)|0)|0) + ($j$025<<5)|0) + 928|0);
      $179 = Math_fround(HEAPF32[$178>>2]);
      $180 = (((($core) + (($i1$028*224)|0)|0) + ($j$025<<5)|0) + 932|0);
      $181 = Math_fround(HEAPF32[$180>>2]);
      $182 = (((($core) + (($i1$028*224)|0)|0) + ($j$025<<5)|0) + 936|0);
      $183 = Math_fround(HEAPF32[$182>>2]);
      $184 = Math_fround(HEAPF32[$test>>2]);
      $185 = Math_fround(HEAPF32[$80>>2]);
      $186 = Math_fround(HEAPF32[$82>>2]);
      $187 = Math_fround($184 - $173);
      $188 = Math_fround($185 - $175);
      $189 = Math_fround($186 - $177);
      $190 = Math_fround(-$179);
      $191 = Math_fround(-$181);
      $192 = Math_fround(-$183);
      $193 = $187 < $179;
      $$$i$i$i1 = $193 ? $187 : $179;
      $194 = $188 < $181;
      $195 = $194 ? $188 : $181;
      $196 = $189 < $183;
      $$1$i$i$i2 = $196 ? $189 : $183;
      $197 = $$$i$i$i1 > $190;
      $$$i8$i$i3 = $197 ? $$$i$i$i1 : $190;
      $198 = $195 > $191;
      $199 = $198 ? $195 : $191;
      $200 = $$1$i$i$i2 > $192;
      $$1$i9$i$i4 = $200 ? $$1$i$i$i2 : $192;
      $201 = Math_fround($187 - $$$i8$i$i3);
      $202 = Math_fround($188 - $199);
      $203 = Math_fround($189 - $$1$i9$i$i4);
      $204 = Math_fround(HEAPF32[$101>>2]);
      $205 = Math_fround($201 * $201);
      $206 = Math_fround($202 * $202);
      $207 = Math_fround($205 + $206);
      $208 = Math_fround($203 * $203);
      $209 = Math_fround($207 + $208);
      $210 = !($204 >= $209);
      if (!($210)) {
       $211 = (((($core) + (($i1$028*224)|0)|0) + ($j$025<<2)|0) + 884|0);
       $k$022 = 0;
       while(1) {
        $212 = ((((($core) + (($i1$028*1120)|0)|0) + (($j$025*224)|0)|0) + ($k$022<<2)|0) + 1984|0);
        $213 = HEAP32[$212>>2]|0;
        $214 = ($213|0)==(0);
        L29: do {
         if (!($214)) {
          $215 = ((((($core) + (($i1$028*1120)|0)|0) + (($j$025*224)|0)|0) + ($k$022<<5)|0) + 2032|0);
          $216 = Math_fround(HEAPF32[$215>>2]);
          $217 = ((((($core) + (($i1$028*1120)|0)|0) + (($j$025*224)|0)|0) + ($k$022<<5)|0) + 2036|0);
          $218 = Math_fround(HEAPF32[$217>>2]);
          $219 = ((((($core) + (($i1$028*1120)|0)|0) + (($j$025*224)|0)|0) + ($k$022<<5)|0) + 2040|0);
          $220 = Math_fround(HEAPF32[$219>>2]);
          $221 = ((((($core) + (($i1$028*1120)|0)|0) + (($j$025*224)|0)|0) + ($k$022<<5)|0) + 2048|0);
          $222 = Math_fround(HEAPF32[$221>>2]);
          $223 = ((((($core) + (($i1$028*1120)|0)|0) + (($j$025*224)|0)|0) + ($k$022<<5)|0) + 2052|0);
          $224 = Math_fround(HEAPF32[$223>>2]);
          $225 = ((((($core) + (($i1$028*1120)|0)|0) + (($j$025*224)|0)|0) + ($k$022<<5)|0) + 2056|0);
          $226 = Math_fround(HEAPF32[$225>>2]);
          $227 = Math_fround(HEAPF32[$test>>2]);
          $228 = Math_fround(HEAPF32[$80>>2]);
          $229 = Math_fround(HEAPF32[$82>>2]);
          $230 = Math_fround($227 - $216);
          $231 = Math_fround($228 - $218);
          $232 = Math_fround($229 - $220);
          $233 = Math_fround(-$222);
          $234 = Math_fround(-$224);
          $235 = Math_fround(-$226);
          $236 = $230 < $222;
          $$$i$i$i = $236 ? $230 : $222;
          $237 = $231 < $224;
          $238 = $237 ? $231 : $224;
          $239 = $232 < $226;
          $$1$i$i$i = $239 ? $232 : $226;
          $240 = $$$i$i$i > $233;
          $$$i8$i$i = $240 ? $$$i$i$i : $233;
          $241 = $238 > $234;
          $242 = $241 ? $238 : $234;
          $243 = $$1$i$i$i > $235;
          $$1$i9$i$i = $243 ? $$1$i$i$i : $235;
          $244 = Math_fround($230 - $$$i8$i$i);
          $245 = Math_fround($231 - $242);
          $246 = Math_fround($232 - $$1$i9$i$i);
          $247 = Math_fround(HEAPF32[$101>>2]);
          $248 = Math_fround($244 * $244);
          $249 = Math_fround($245 * $245);
          $250 = Math_fround($248 + $249);
          $251 = Math_fround($246 * $246);
          $252 = Math_fround($250 + $251);
          $253 = !($247 >= $252);
          if (!($253)) {
           $254 = HEAP32[$168>>2]|0;
           $255 = HEAP32[$211>>2]|0;
           $256 = (($255) + ($254))|0;
           $257 = ((((($core) + (($i1$028*1120)|0)|0) + (($j$025*224)|0)|0) + ($k$022<<2)|0) + 2004|0);
           $258 = HEAP32[$257>>2]|0;
           $259 = (($256) + ($258))|0;
           $260 = HEAP32[$124>>2]|0;
           $261 = HEAP32[$125>>2]|0;
           $262 = (($261) + ($259<<3)|0);
           $263 = (($260) + ($259<<5)|0);
           $$in$i = $213;$boxes$02$i = $263;$objects$03$i = $262;
           while(1) {
            $264 = (($$in$i) + -1)|0;
            $265 = (($boxes$02$i) + 32|0);
            $266 = (($objects$03$i) + 8|0);
            $267 = (($boxes$02$i) + 28|0);
            $268 = HEAP32[$267>>2]|0;
            $269 = ($268>>>0)<($$0$i10>>>0);
            if (!($269)) {
             $271 = (($boxes$02$i) + 12|0);
             $272 = HEAP32[$271>>2]|0;
             $273 = ($272>>>0)>($$0$i9>>>0);
             if ($273) {
              break L29;
             }
             $274 = Math_fround(HEAPF32[$boxes$02$i>>2]);
             $275 = (($boxes$02$i) + 4|0);
             $276 = Math_fround(HEAPF32[$275>>2]);
             $277 = (($boxes$02$i) + 8|0);
             $278 = Math_fround(HEAPF32[$277>>2]);
             $279 = (($boxes$02$i) + 16|0);
             $280 = Math_fround(HEAPF32[$279>>2]);
             $281 = (($boxes$02$i) + 20|0);
             $282 = Math_fround(HEAPF32[$281>>2]);
             $283 = (($boxes$02$i) + 24|0);
             $284 = Math_fround(HEAPF32[$283>>2]);
             $285 = Math_fround(HEAPF32[$test>>2]);
             $286 = Math_fround(HEAPF32[$80>>2]);
             $287 = Math_fround(HEAPF32[$82>>2]);
             $288 = Math_fround($285 - $274);
             $289 = Math_fround($286 - $276);
             $290 = Math_fround($287 - $278);
             $291 = Math_fround(-$280);
             $292 = Math_fround(-$282);
             $293 = Math_fround(-$284);
             $294 = $288 < $280;
             $$$i$i$i$i = $294 ? $288 : $280;
             $295 = $289 < $282;
             $296 = $295 ? $289 : $282;
             $297 = $290 < $284;
             $$1$i$i$i$i = $297 ? $290 : $284;
             $298 = $$$i$i$i$i > $291;
             $$$i8$i$i$i = $298 ? $$$i$i$i$i : $291;
             $299 = $296 > $292;
             $300 = $299 ? $296 : $292;
             $301 = $$1$i$i$i$i > $293;
             $$1$i9$i$i$i = $301 ? $$1$i$i$i$i : $293;
             $302 = Math_fround($288 - $$$i8$i$i$i);
             $303 = Math_fround($289 - $300);
             $304 = Math_fround($290 - $$1$i9$i$i$i);
             $305 = Math_fround(HEAPF32[$101>>2]);
             $306 = Math_fround($302 * $302);
             $307 = Math_fround($303 * $303);
             $308 = Math_fround($306 + $307);
             $309 = Math_fround($304 * $304);
             $310 = Math_fround($308 + $309);
             $311 = !($305 >= $310);
             if (!($311)) {
              HEAPF32[$dist$i>>2] = Math_fround(-1.0);
              $312 = HEAP32[$pcb>>2]|0;
              $313 = HEAP32[$312>>2]|0;
              $314 = (FUNCTION_TABLE_iiiii[$313 & 511]($pcb,$dist$i,$objects$03$i,1)|0);
              if (!($314)) {
               $$0 = 0;
               label = 27;
               break L17;
              }
             }
            }
            $270 = ($264|0)==(0);
            if ($270) {
             break;
            } else {
             $$in$i = $264;$boxes$02$i = $265;$objects$03$i = $266;
            }
           }
          }
         }
        } while(0);
        $315 = (($k$022) + 1)|0;
        $316 = ($315>>>0)<(5);
        if ($316) {
         $k$022 = $315;
        } else {
         break;
        }
       }
      }
     }
     $317 = (($j$025) + 1)|0;
     $318 = ($317>>>0)<(5);
     if ($318) {
      $j$025 = $317;
     } else {
      break;
     }
    }
   }
  }
  $319 = (($i1$028) + 1)|0;
  $320 = ($319>>>0)<(5);
  if ($320) {
   $i1$028 = $319;
  } else {
   $$0 = 1;
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sq16BucketPrunerCore11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $$0$i$i = 0, $$0$i$i2 = 0, $$0$i1$i = 0, $$0$i1$i1 = 0, $$pre = 0, $$pre28 = 0, $$pre30 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0;
 var $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0);
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0;
 var $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0);
 var $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0);
 var $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $exitcond20 = 0;
 var $exitcond22 = 0, $exitcond24 = 0, $i$018 = 0, $i1$016 = 0, $i2$015 = 0, $i4$011 = 0, $i5$07 = 0, $j6$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $$pre28 = (($shift) + 4|0);
 $$pre30 = (($shift) + 8|0);
 if (!($2)) {
  $i$018 = 0;
  while(1) {
   $3 = Math_fround(HEAPF32[$shift>>2]);
   $4 = ((($this) + (($i$018*24)|0)|0) + 160|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   $6 = Math_fround($5 - $3);
   HEAPF32[$4>>2] = $6;
   $7 = Math_fround(HEAPF32[$$pre28>>2]);
   $8 = ((($this) + (($i$018*24)|0)|0) + 164|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = Math_fround($9 - $7);
   HEAPF32[$8>>2] = $10;
   $11 = Math_fround(HEAPF32[$$pre30>>2]);
   $12 = ((($this) + (($i$018*24)|0)|0) + 168|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = Math_fround($13 - $11);
   HEAPF32[$12>>2] = $14;
   $15 = Math_fround(HEAPF32[$shift>>2]);
   $16 = ((($this) + (($i$018*24)|0)|0) + 172|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround($17 - $15);
   HEAPF32[$16>>2] = $18;
   $19 = Math_fround(HEAPF32[$$pre28>>2]);
   $20 = ((($this) + (($i$018*24)|0)|0) + 176|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = Math_fround($21 - $19);
   HEAPF32[$20>>2] = $22;
   $23 = Math_fround(HEAPF32[$$pre30>>2]);
   $24 = ((($this) + (($i$018*24)|0)|0) + 180|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = Math_fround($25 - $23);
   HEAPF32[$24>>2] = $26;
   $27 = (($i$018) + 1)|0;
   $28 = HEAP32[$0>>2]|0;
   $29 = ($27>>>0)<($28>>>0);
   if ($29) {
    $i$018 = $27;
   } else {
    break;
   }
  }
 }
 $30 = HEAP32[$this>>2]|0;
 $31 = Math_fround(HEAPF32[$shift>>2]);
 $32 = (($this) + 608|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 - $31);
 HEAPF32[$32>>2] = $34;
 $35 = Math_fround(HEAPF32[$$pre28>>2]);
 $36 = (($this) + 612|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 - $35);
 HEAPF32[$36>>2] = $38;
 $39 = Math_fround(HEAPF32[$$pre30>>2]);
 $40 = (($this) + 616|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 - $39);
 HEAPF32[$40>>2] = $42;
 $43 = (($this) + 592|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($32) + ($44<<2)|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($this) + 624|0);
 $48 = (($47) + ($44<<2)|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($46 - $49);
 $51 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
 $52 = Math_fround($46 + $49);
 $53 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
 $54 = ($51|0)<(0);
 $55 = $51 ^ -1;
 $56 = $51 | -2147483648;
 $$0$i1$i1 = $54 ? $55 : $56;
 $57 = (($this) + 620|0);
 HEAP32[$57>>2] = $$0$i1$i1;
 $58 = ($53|0)<(0);
 $59 = $53 ^ -1;
 $60 = $53 | -2147483648;
 $$0$i$i2 = $58 ? $59 : $60;
 $61 = (($this) + 636|0);
 HEAP32[$61>>2] = $$0$i$i2;
 $62 = ($30|0)==(0);
 if (!($62)) {
  $63 = (($this) + 8|0);
  $64 = HEAP32[$63>>2]|0;
  $i1$016 = 0;
  while(1) {
   $70 = Math_fround(HEAPF32[$shift>>2]);
   $71 = (($64) + (($i1$016*24)|0)|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = Math_fround($72 - $70);
   HEAPF32[$71>>2] = $73;
   $74 = Math_fround(HEAPF32[$$pre28>>2]);
   $75 = ((($64) + (($i1$016*24)|0)|0) + 4|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = Math_fround($76 - $74);
   HEAPF32[$75>>2] = $77;
   $78 = Math_fround(HEAPF32[$$pre30>>2]);
   $79 = ((($64) + (($i1$016*24)|0)|0) + 8|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = Math_fround($80 - $78);
   HEAPF32[$79>>2] = $81;
   $82 = Math_fround(HEAPF32[$shift>>2]);
   $83 = ((($64) + (($i1$016*24)|0)|0) + 12|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   $85 = Math_fround($84 - $82);
   HEAPF32[$83>>2] = $85;
   $86 = Math_fround(HEAPF32[$$pre28>>2]);
   $87 = ((($64) + (($i1$016*24)|0)|0) + 16|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = Math_fround($88 - $86);
   HEAPF32[$87>>2] = $89;
   $90 = Math_fround(HEAPF32[$$pre30>>2]);
   $91 = ((($64) + (($i1$016*24)|0)|0) + 20|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = Math_fround($92 - $90);
   HEAPF32[$91>>2] = $93;
   $94 = (($i1$016) + 1)|0;
   $exitcond24 = ($94|0)==($30|0);
   if ($exitcond24) {
    break;
   } else {
    $i1$016 = $94;
   }
  }
 }
 $65 = (($this) + 584|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0);
 L10: do {
  if (!($67)) {
   $68 = (($this) + 20|0);
   $69 = HEAP32[$68>>2]|0;
   $168 = $44;$i2$015 = 0;
   while(1) {
    $155 = Math_fround(HEAPF32[$shift>>2]);
    $156 = (($69) + ($i2$015<<5)|0);
    $157 = Math_fround(HEAPF32[$156>>2]);
    $158 = Math_fround($157 - $155);
    HEAPF32[$156>>2] = $158;
    $159 = Math_fround(HEAPF32[$$pre28>>2]);
    $160 = ((($69) + ($i2$015<<5)|0) + 4|0);
    $161 = Math_fround(HEAPF32[$160>>2]);
    $162 = Math_fround($161 - $159);
    HEAPF32[$160>>2] = $162;
    $163 = Math_fround(HEAPF32[$$pre30>>2]);
    $164 = ((($69) + ($i2$015<<5)|0) + 8|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = Math_fround($165 - $163);
    HEAPF32[$164>>2] = $166;
    $167 = (($156) + ($168<<2)|0);
    $169 = Math_fround(HEAPF32[$167>>2]);
    $170 = ((($69) + ($i2$015<<5)|0) + 16|0);
    $171 = (($170) + ($168<<2)|0);
    $172 = Math_fround(HEAPF32[$171>>2]);
    $173 = Math_fround($169 - $172);
    $174 = (HEAPF32[tempDoublePtr>>2]=$173,HEAP32[tempDoublePtr>>2]|0);
    $175 = Math_fround($169 + $172);
    $176 = (HEAPF32[tempDoublePtr>>2]=$175,HEAP32[tempDoublePtr>>2]|0);
    $177 = ($174|0)<(0);
    $178 = $174 ^ -1;
    $179 = $174 | -2147483648;
    $$0$i1$i = $177 ? $178 : $179;
    $180 = ((($69) + ($i2$015<<5)|0) + 12|0);
    HEAP32[$180>>2] = $$0$i1$i;
    $181 = ($176|0)<(0);
    $182 = $176 ^ -1;
    $183 = $176 | -2147483648;
    $$0$i$i = $181 ? $182 : $183;
    $184 = ((($69) + ($i2$015<<5)|0) + 28|0);
    HEAP32[$184>>2] = $$0$i$i;
    $185 = (($i2$015) + 1)|0;
    $186 = HEAP32[$65>>2]|0;
    $187 = ($185>>>0)<($186>>>0);
    if (!($187)) {
     break L10;
    }
    $$pre = HEAP32[$43>>2]|0;
    $168 = $$pre;$i2$015 = $185;
   }
  }
 } while(0);
 $95 = Math_fround(HEAPF32[$shift>>2]);
 $96 = (($this) + 688|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 - $95);
 HEAPF32[$96>>2] = $98;
 $99 = Math_fround(HEAPF32[$$pre28>>2]);
 $100 = (($this) + 692|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($101 - $99);
 HEAPF32[$100>>2] = $102;
 $103 = Math_fround(HEAPF32[$$pre30>>2]);
 $104 = (($this) + 696|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($105 - $103);
 HEAPF32[$104>>2] = $106;
 $107 = Math_fround(HEAPF32[$shift>>2]);
 $108 = (($this) + 720|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($109 - $107);
 HEAPF32[$108>>2] = $110;
 $111 = Math_fround(HEAPF32[$$pre28>>2]);
 $112 = (($this) + 724|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($113 - $111);
 HEAPF32[$112>>2] = $114;
 $115 = Math_fround(HEAPF32[$$pre30>>2]);
 $116 = (($this) + 728|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($117 - $115);
 HEAPF32[$116>>2] = $118;
 $119 = Math_fround(HEAPF32[$shift>>2]);
 $120 = (($this) + 752|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround($121 - $119);
 HEAPF32[$120>>2] = $122;
 $123 = Math_fround(HEAPF32[$$pre28>>2]);
 $124 = (($this) + 756|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = Math_fround($125 - $123);
 HEAPF32[$124>>2] = $126;
 $127 = Math_fround(HEAPF32[$$pre30>>2]);
 $128 = (($this) + 760|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($129 - $127);
 HEAPF32[$128>>2] = $130;
 $131 = Math_fround(HEAPF32[$shift>>2]);
 $132 = (($this) + 784|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($133 - $131);
 HEAPF32[$132>>2] = $134;
 $135 = Math_fround(HEAPF32[$$pre28>>2]);
 $136 = (($this) + 788|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($137 - $135);
 HEAPF32[$136>>2] = $138;
 $139 = Math_fround(HEAPF32[$$pre30>>2]);
 $140 = (($this) + 792|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = Math_fround($141 - $139);
 HEAPF32[$140>>2] = $142;
 $143 = Math_fround(HEAPF32[$shift>>2]);
 $144 = (($this) + 816|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround($145 - $143);
 HEAPF32[$144>>2] = $146;
 $147 = Math_fround(HEAPF32[$$pre28>>2]);
 $148 = (($this) + 820|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = Math_fround($149 - $147);
 HEAPF32[$148>>2] = $150;
 $151 = Math_fround(HEAPF32[$$pre30>>2]);
 $152 = (($this) + 824|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = Math_fround($153 - $151);
 HEAPF32[$152>>2] = $154;
 $i4$011 = 0;
 while(1) {
  $188 = Math_fround(HEAPF32[$shift>>2]);
  $189 = ((($this) + (($i4$011*224)|0)|0) + 912|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = Math_fround($190 - $188);
  HEAPF32[$189>>2] = $191;
  $192 = Math_fround(HEAPF32[$$pre28>>2]);
  $193 = ((($this) + (($i4$011*224)|0)|0) + 916|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = Math_fround($194 - $192);
  HEAPF32[$193>>2] = $195;
  $196 = Math_fround(HEAPF32[$$pre30>>2]);
  $197 = ((($this) + (($i4$011*224)|0)|0) + 920|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = Math_fround($198 - $196);
  HEAPF32[$197>>2] = $199;
  $200 = Math_fround(HEAPF32[$shift>>2]);
  $201 = ((($this) + (($i4$011*224)|0)|0) + 944|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = Math_fround($202 - $200);
  HEAPF32[$201>>2] = $203;
  $204 = Math_fround(HEAPF32[$$pre28>>2]);
  $205 = ((($this) + (($i4$011*224)|0)|0) + 948|0);
  $206 = Math_fround(HEAPF32[$205>>2]);
  $207 = Math_fround($206 - $204);
  HEAPF32[$205>>2] = $207;
  $208 = Math_fround(HEAPF32[$$pre30>>2]);
  $209 = ((($this) + (($i4$011*224)|0)|0) + 952|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $211 = Math_fround($210 - $208);
  HEAPF32[$209>>2] = $211;
  $212 = Math_fround(HEAPF32[$shift>>2]);
  $213 = ((($this) + (($i4$011*224)|0)|0) + 976|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = Math_fround($214 - $212);
  HEAPF32[$213>>2] = $215;
  $216 = Math_fround(HEAPF32[$$pre28>>2]);
  $217 = ((($this) + (($i4$011*224)|0)|0) + 980|0);
  $218 = Math_fround(HEAPF32[$217>>2]);
  $219 = Math_fround($218 - $216);
  HEAPF32[$217>>2] = $219;
  $220 = Math_fround(HEAPF32[$$pre30>>2]);
  $221 = ((($this) + (($i4$011*224)|0)|0) + 984|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  $223 = Math_fround($222 - $220);
  HEAPF32[$221>>2] = $223;
  $224 = Math_fround(HEAPF32[$shift>>2]);
  $225 = ((($this) + (($i4$011*224)|0)|0) + 1008|0);
  $226 = Math_fround(HEAPF32[$225>>2]);
  $227 = Math_fround($226 - $224);
  HEAPF32[$225>>2] = $227;
  $228 = Math_fround(HEAPF32[$$pre28>>2]);
  $229 = ((($this) + (($i4$011*224)|0)|0) + 1012|0);
  $230 = Math_fround(HEAPF32[$229>>2]);
  $231 = Math_fround($230 - $228);
  HEAPF32[$229>>2] = $231;
  $232 = Math_fround(HEAPF32[$$pre30>>2]);
  $233 = ((($this) + (($i4$011*224)|0)|0) + 1016|0);
  $234 = Math_fround(HEAPF32[$233>>2]);
  $235 = Math_fround($234 - $232);
  HEAPF32[$233>>2] = $235;
  $236 = Math_fround(HEAPF32[$shift>>2]);
  $237 = ((($this) + (($i4$011*224)|0)|0) + 1040|0);
  $238 = Math_fround(HEAPF32[$237>>2]);
  $239 = Math_fround($238 - $236);
  HEAPF32[$237>>2] = $239;
  $240 = Math_fround(HEAPF32[$$pre28>>2]);
  $241 = ((($this) + (($i4$011*224)|0)|0) + 1044|0);
  $242 = Math_fround(HEAPF32[$241>>2]);
  $243 = Math_fround($242 - $240);
  HEAPF32[$241>>2] = $243;
  $244 = Math_fround(HEAPF32[$$pre30>>2]);
  $245 = ((($this) + (($i4$011*224)|0)|0) + 1048|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround($246 - $244);
  HEAPF32[$245>>2] = $247;
  $248 = (($i4$011) + 1)|0;
  $exitcond22 = ($248|0)==(5);
  if ($exitcond22) {
   $i5$07 = 0;
   break;
  } else {
   $i4$011 = $248;
  }
 }
 while(1) {
  $j6$05 = 0;
  while(1) {
   $249 = Math_fround(HEAPF32[$shift>>2]);
   $250 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2032|0);
   $251 = Math_fround(HEAPF32[$250>>2]);
   $252 = Math_fround($251 - $249);
   HEAPF32[$250>>2] = $252;
   $253 = Math_fround(HEAPF32[$$pre28>>2]);
   $254 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2036|0);
   $255 = Math_fround(HEAPF32[$254>>2]);
   $256 = Math_fround($255 - $253);
   HEAPF32[$254>>2] = $256;
   $257 = Math_fround(HEAPF32[$$pre30>>2]);
   $258 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2040|0);
   $259 = Math_fround(HEAPF32[$258>>2]);
   $260 = Math_fround($259 - $257);
   HEAPF32[$258>>2] = $260;
   $261 = Math_fround(HEAPF32[$shift>>2]);
   $262 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2064|0);
   $263 = Math_fround(HEAPF32[$262>>2]);
   $264 = Math_fround($263 - $261);
   HEAPF32[$262>>2] = $264;
   $265 = Math_fround(HEAPF32[$$pre28>>2]);
   $266 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2068|0);
   $267 = Math_fround(HEAPF32[$266>>2]);
   $268 = Math_fround($267 - $265);
   HEAPF32[$266>>2] = $268;
   $269 = Math_fround(HEAPF32[$$pre30>>2]);
   $270 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2072|0);
   $271 = Math_fround(HEAPF32[$270>>2]);
   $272 = Math_fround($271 - $269);
   HEAPF32[$270>>2] = $272;
   $273 = Math_fround(HEAPF32[$shift>>2]);
   $274 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2096|0);
   $275 = Math_fround(HEAPF32[$274>>2]);
   $276 = Math_fround($275 - $273);
   HEAPF32[$274>>2] = $276;
   $277 = Math_fround(HEAPF32[$$pre28>>2]);
   $278 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2100|0);
   $279 = Math_fround(HEAPF32[$278>>2]);
   $280 = Math_fround($279 - $277);
   HEAPF32[$278>>2] = $280;
   $281 = Math_fround(HEAPF32[$$pre30>>2]);
   $282 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2104|0);
   $283 = Math_fround(HEAPF32[$282>>2]);
   $284 = Math_fround($283 - $281);
   HEAPF32[$282>>2] = $284;
   $285 = Math_fround(HEAPF32[$shift>>2]);
   $286 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2128|0);
   $287 = Math_fround(HEAPF32[$286>>2]);
   $288 = Math_fround($287 - $285);
   HEAPF32[$286>>2] = $288;
   $289 = Math_fround(HEAPF32[$$pre28>>2]);
   $290 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2132|0);
   $291 = Math_fround(HEAPF32[$290>>2]);
   $292 = Math_fround($291 - $289);
   HEAPF32[$290>>2] = $292;
   $293 = Math_fround(HEAPF32[$$pre30>>2]);
   $294 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2136|0);
   $295 = Math_fround(HEAPF32[$294>>2]);
   $296 = Math_fround($295 - $293);
   HEAPF32[$294>>2] = $296;
   $297 = Math_fround(HEAPF32[$shift>>2]);
   $298 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2160|0);
   $299 = Math_fround(HEAPF32[$298>>2]);
   $300 = Math_fround($299 - $297);
   HEAPF32[$298>>2] = $300;
   $301 = Math_fround(HEAPF32[$$pre28>>2]);
   $302 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2164|0);
   $303 = Math_fround(HEAPF32[$302>>2]);
   $304 = Math_fround($303 - $301);
   HEAPF32[$302>>2] = $304;
   $305 = Math_fround(HEAPF32[$$pre30>>2]);
   $306 = (((($this) + (($i5$07*1120)|0)|0) + (($j6$05*224)|0)|0) + 2168|0);
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = Math_fround($307 - $305);
   HEAPF32[$306>>2] = $308;
   $309 = (($j6$05) + 1)|0;
   $exitcond = ($309|0)==(5);
   if ($exitcond) {
    break;
   } else {
    $j6$05 = $309;
   }
  }
  $310 = (($i5$07) + 1)|0;
  $exitcond20 = ($310|0)==(5);
  if ($exitcond20) {
   break;
  } else {
   $i5$07 = $310;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sq16BucketPrunerCore9visualizeERNS_2Cm12RenderOutputEj($this,$out,$color) {
 $this = $this|0;
 $out = $out|0;
 $color = $color|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $12 = 0;
 var $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond = 0, $exitcond7 = 0, $exitcond8 = 0, $i$05 = 0, $idt = 0;
 var $j$03 = 0, $k$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 28|0;
 $idt = sp;
 HEAPF32[$idt>>2] = Math_fround(0.0);
 $1 = (($idt) + 4|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($idt) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($idt) + 12|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($idt) + 16|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($idt) + 20|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($idt) + 24|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$idt)|0);
 (__ZN5physx2Cm12RenderOutputlsEj($out,$color)|0);
 $7 = (($this) + 608|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 624|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 - $10);
 $12 = (($this) + 612|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 628|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = (($this) + 616|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 632|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 - $20);
 $22 = Math_fround($8 + $10);
 $23 = Math_fround($13 + $15);
 $24 = Math_fround($18 + $20);
 HEAPF32[$0>>2] = $11;
 $25 = (($0) + 4|0);
 HEAPF32[$25>>2] = $16;
 $26 = (($0) + 8|0);
 HEAPF32[$26>>2] = $21;
 $27 = (($0) + 12|0);
 HEAPF32[$27>>2] = $22;
 $28 = (($0) + 16|0);
 HEAPF32[$28>>2] = $23;
 $29 = (($0) + 20|0);
 HEAPF32[$29>>2] = $24;
 $30 = (($0) + 24|0);
 HEAP8[$30>>0] = 1;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$0)|0);
 $31 = (($0) + 4|0);
 $32 = (($0) + 8|0);
 $33 = (($0) + 12|0);
 $34 = (($0) + 16|0);
 $35 = (($0) + 20|0);
 $36 = (($0) + 24|0);
 $37 = (($0) + 4|0);
 $38 = (($0) + 8|0);
 $39 = (($0) + 12|0);
 $40 = (($0) + 16|0);
 $41 = (($0) + 20|0);
 $42 = (($0) + 24|0);
 $43 = (($0) + 4|0);
 $44 = (($0) + 8|0);
 $45 = (($0) + 12|0);
 $46 = (($0) + 16|0);
 $47 = (($0) + 20|0);
 $48 = (($0) + 24|0);
 $i$05 = 0;
 while(1) {
  $49 = ((($this) + ($i$05<<2)|0) + 640|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==(0);
  if (!($51)) {
   $52 = ((($this) + ($i$05<<5)|0) + 688|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = ((($this) + ($i$05<<5)|0) + 704|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = Math_fround($53 - $55);
   $57 = ((($this) + ($i$05<<5)|0) + 692|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = ((($this) + ($i$05<<5)|0) + 708|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround($58 - $60);
   $62 = ((($this) + ($i$05<<5)|0) + 696|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = ((($this) + ($i$05<<5)|0) + 712|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = Math_fround($63 - $65);
   $67 = Math_fround($53 + $55);
   $68 = Math_fround($58 + $60);
   $69 = Math_fround($63 + $65);
   HEAPF32[$0>>2] = $56;
   HEAPF32[$31>>2] = $61;
   HEAPF32[$32>>2] = $66;
   HEAPF32[$33>>2] = $67;
   HEAPF32[$34>>2] = $68;
   HEAPF32[$35>>2] = $69;
   HEAP8[$36>>0] = 1;
   (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$0)|0);
   $j$03 = 0;
   while(1) {
    $70 = (((($this) + (($i$05*224)|0)|0) + ($j$03<<2)|0) + 864|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71|0)==(0);
    if (!($72)) {
     $73 = (((($this) + (($i$05*224)|0)|0) + ($j$03<<5)|0) + 912|0);
     $74 = Math_fround(HEAPF32[$73>>2]);
     $75 = (((($this) + (($i$05*224)|0)|0) + ($j$03<<5)|0) + 928|0);
     $76 = Math_fround(HEAPF32[$75>>2]);
     $77 = Math_fround($74 - $76);
     $78 = (((($this) + (($i$05*224)|0)|0) + ($j$03<<5)|0) + 916|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $80 = (((($this) + (($i$05*224)|0)|0) + ($j$03<<5)|0) + 932|0);
     $81 = Math_fround(HEAPF32[$80>>2]);
     $82 = Math_fround($79 - $81);
     $83 = (((($this) + (($i$05*224)|0)|0) + ($j$03<<5)|0) + 920|0);
     $84 = Math_fround(HEAPF32[$83>>2]);
     $85 = (((($this) + (($i$05*224)|0)|0) + ($j$03<<5)|0) + 936|0);
     $86 = Math_fround(HEAPF32[$85>>2]);
     $87 = Math_fround($84 - $86);
     $88 = Math_fround($74 + $76);
     $89 = Math_fround($79 + $81);
     $90 = Math_fround($84 + $86);
     HEAPF32[$0>>2] = $77;
     HEAPF32[$37>>2] = $82;
     HEAPF32[$38>>2] = $87;
     HEAPF32[$39>>2] = $88;
     HEAPF32[$40>>2] = $89;
     HEAPF32[$41>>2] = $90;
     HEAP8[$42>>0] = 1;
     (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$0)|0);
     $k$01 = 0;
     while(1) {
      $91 = ((((($this) + (($i$05*1120)|0)|0) + (($j$03*224)|0)|0) + ($k$01<<2)|0) + 1984|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = ($92|0)==(0);
      if (!($93)) {
       $94 = ((((($this) + (($i$05*1120)|0)|0) + (($j$03*224)|0)|0) + ($k$01<<5)|0) + 2032|0);
       $95 = Math_fround(HEAPF32[$94>>2]);
       $96 = ((((($this) + (($i$05*1120)|0)|0) + (($j$03*224)|0)|0) + ($k$01<<5)|0) + 2048|0);
       $97 = Math_fround(HEAPF32[$96>>2]);
       $98 = Math_fround($95 - $97);
       $99 = ((((($this) + (($i$05*1120)|0)|0) + (($j$03*224)|0)|0) + ($k$01<<5)|0) + 2036|0);
       $100 = Math_fround(HEAPF32[$99>>2]);
       $101 = ((((($this) + (($i$05*1120)|0)|0) + (($j$03*224)|0)|0) + ($k$01<<5)|0) + 2052|0);
       $102 = Math_fround(HEAPF32[$101>>2]);
       $103 = Math_fround($100 - $102);
       $104 = ((((($this) + (($i$05*1120)|0)|0) + (($j$03*224)|0)|0) + ($k$01<<5)|0) + 2040|0);
       $105 = Math_fround(HEAPF32[$104>>2]);
       $106 = ((((($this) + (($i$05*1120)|0)|0) + (($j$03*224)|0)|0) + ($k$01<<5)|0) + 2056|0);
       $107 = Math_fround(HEAPF32[$106>>2]);
       $108 = Math_fround($105 - $107);
       $109 = Math_fround($95 + $97);
       $110 = Math_fround($100 + $102);
       $111 = Math_fround($105 + $107);
       HEAPF32[$0>>2] = $98;
       HEAPF32[$43>>2] = $103;
       HEAPF32[$44>>2] = $108;
       HEAPF32[$45>>2] = $109;
       HEAPF32[$46>>2] = $110;
       HEAPF32[$47>>2] = $111;
       HEAP8[$48>>0] = 1;
       (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$0)|0);
      }
      $112 = (($k$01) + 1)|0;
      $exitcond = ($112|0)==(5);
      if ($exitcond) {
       break;
      } else {
       $k$01 = $112;
      }
     }
    }
    $113 = (($j$03) + 1)|0;
    $exitcond7 = ($113|0)==(5);
    if ($exitcond7) {
     break;
    } else {
     $j$03 = $113;
    }
   }
  }
  $114 = (($i$05) + 1)|0;
  $exitcond8 = ($114|0)==(5);
  if ($exitcond8) {
   break;
  } else {
   $i$05 = $114;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Sq12BucketPrunerC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((507312 + 8|0));
 $0 = (($this) + 16|0);
 __ZN5physx2Sq16BucketPrunerCoreC2Eb($0,1);
 $1 = (($this) + 7616|0);
 __ZN5physx2Sq11PruningPoolC2Ev($1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq12BucketPrunerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((507312 + 8|0));
 $1 = (($this) + 7616|0);
 __ZN5physx2Sq11PruningPoolD2Ev($1);
 $2 = (($this) + 16|0);
 __ZN5physx2Sq16BucketPrunerCore7releaseEv($2);
 $3 = (($this) + 560|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$4);
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq12BucketPrunerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((507312 + 8|0));
 $0 = (($this) + 7616|0);
 __ZN5physx2Sq11PruningPoolD2Ev($0);
 $1 = (($this) + 16|0);
 __ZN5physx2Sq16BucketPrunerCore7releaseEv($1);
 $2 = (($this) + 560|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$3);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq12BucketPruner10addObjectsEPjPKNS_9PxBounds3EPKNS0_13PrunerPayloadEj($this,$results,$bounds,$payload,$count) {
 $this = $this|0;
 $results = $results|0;
 $bounds = $bounds|0;
 $payload = $payload|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $valid$0$lcssa = 0, $valid$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 7616|0);
 $1 = ($count|0)==(0);
 L1: do {
  if ($1) {
   $valid$0$lcssa = 0;
  } else {
   $2 = (($this) + 7600|0);
   $valid$02 = 0;
   while(1) {
    $3 = (($bounds) + (($valid$02*24)|0)|0);
    $4 = (($payload) + ($valid$02<<3)|0);
    $5 = (__ZN5physx2Sq11PruningPool9addObjectERKNS_9PxBounds3ERKNS0_13PrunerPayloadE($0,$3,$4)|0);
    $6 = (($results) + ($valid$02<<2)|0);
    HEAP32[$6>>2] = $5;
    $7 = ($5|0)==(-1);
    if ($7) {
     $valid$0$lcssa = $valid$02;
     break L1;
    }
    HEAP8[$2>>0] = 1;
    $8 = (($valid$02) + 1)|0;
    $9 = ($8>>>0)<($count>>>0);
    if ($9) {
     $valid$02 = $8;
    } else {
     $valid$0$lcssa = $8;
     break;
    }
   }
  }
 } while(0);
 $10 = (($this) + 7620|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 7628|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 7632|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 16|0);
 HEAP32[$16>>2] = $11;
 $17 = (($this) + 24|0);
 HEAP32[$17>>2] = $13;
 $18 = (($this) + 28|0);
 HEAP32[$18>>2] = $15;
 $19 = (($this) + 32|0);
 HEAP32[$19>>2] = 0;
 $20 = ($valid$0$lcssa|0)==($count|0);
 STACKTOP = sp;return ($20|0);
}
function __ZN5physx2Sq12BucketPruner13removeObjectsEPKjj($this,$handles,$count) {
 $this = $this|0;
 $handles = $handles|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if (!($0)) {
  $1 = (($this) + 7616|0);
  $i$01 = 0;
  while(1) {
   $2 = (($handles) + ($i$01<<2)|0);
   $3 = HEAP32[$2>>2]|0;
   (__ZN5physx2Sq11PruningPool12removeObjectEj($1,$3)|0);
   $4 = (($i$01) + 1)|0;
   $exitcond = ($4|0)==($count|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $4;
   }
  }
 }
 $5 = (($this) + 7620|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 7628|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 7632|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 16|0);
 HEAP32[$11>>2] = $6;
 $12 = (($this) + 24|0);
 HEAP32[$12>>2] = $8;
 $13 = (($this) + 28|0);
 HEAP32[$13>>2] = $10;
 $14 = (($this) + 32|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 7600|0);
 HEAP8[$15>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq12BucketPruner13updateObjectsEPKjPKNS_9PxBounds3Ej($this,$handles,$newBounds,$count) {
 $this = $this|0;
 $handles = $handles|0;
 $newBounds = $newBounds|0;
 $count = $count|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  $$phi$trans$insert = (($this) + 7628|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $34 = $$pre;
 } else {
  $1 = (($this) + 7636|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($this) + 7628|0);
  $4 = HEAP32[$3>>2]|0;
  $i$01 = 0;
  while(1) {
   $5 = (($handles) + ($i$01<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($2) + ($6<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($newBounds) + (($i$01*24)|0)|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = (($4) + (($8*24)|0)|0);
   HEAPF32[$11>>2] = $10;
   $12 = ((($newBounds) + (($i$01*24)|0)|0) + 4|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = ((($4) + (($8*24)|0)|0) + 4|0);
   HEAPF32[$14>>2] = $13;
   $15 = ((($newBounds) + (($i$01*24)|0)|0) + 8|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = ((($4) + (($8*24)|0)|0) + 8|0);
   HEAPF32[$17>>2] = $16;
   $18 = ((($newBounds) + (($i$01*24)|0)|0) + 12|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = ((($4) + (($8*24)|0)|0) + 12|0);
   HEAPF32[$20>>2] = $19;
   $21 = ((($newBounds) + (($i$01*24)|0)|0) + 16|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = ((($4) + (($8*24)|0)|0) + 16|0);
   HEAPF32[$23>>2] = $22;
   $24 = ((($newBounds) + (($i$01*24)|0)|0) + 20|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = ((($4) + (($8*24)|0)|0) + 20|0);
   HEAPF32[$26>>2] = $25;
   $27 = (($i$01) + 1)|0;
   $exitcond = ($27|0)==($count|0);
   if ($exitcond) {
    $34 = $4;
    break;
   } else {
    $i$01 = $27;
   }
  }
 }
 $28 = (($this) + 7620|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 7632|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 16|0);
 HEAP32[$32>>2] = $29;
 $33 = (($this) + 24|0);
 HEAP32[$33>>2] = $34;
 $35 = (($this) + 28|0);
 HEAP32[$35>>2] = $31;
 $36 = (($this) + 32|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 7600|0);
 HEAP8[$37>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq12BucketPruner6commitEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Sq16BucketPrunerCore13classifyBoxesEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq12BucketPruner11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Sq16BucketPrunerCore11shiftOriginERKNS_6PxVec3E($0,$shift);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sq12BucketPruner5sweepERKNS0_9ShapeDataERKNS_6PxVec3ERfRNS0_14PrunerCallbackE($this,$queryVolume,$unitDir,$inOutDistance,$pcb) {
 $this = $this|0;
 $queryVolume = $queryVolume|0;
 $unitDir = $unitDir|0;
 $inOutDistance = $inOutDistance|0;
 $pcb = $pcb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 7600|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 16|0);
 $4 = (__ZNK5physx2Sq16BucketPrunerCore5sweepERKNS0_9ShapeDataERKNS_6PxVec3ERfRNS0_14PrunerCallbackE($3,$queryVolume,$unitDir,$inOutDistance,$pcb)|0);
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sq12BucketPruner7overlapERKNS0_9ShapeDataERNS0_14PrunerCallbackE($this,$queryVolume,$pcb) {
 $this = $this|0;
 $queryVolume = $queryVolume|0;
 $pcb = $pcb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 7600|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 16|0);
 $4 = (__ZNK5physx2Sq16BucketPrunerCore7overlapERKNS0_9ShapeDataERNS0_14PrunerCallbackE($3,$queryVolume,$pcb)|0);
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sq12BucketPruner7raycastERKNS_6PxVec3ES4_RfRNS0_14PrunerCallbackE($this,$origin,$unitDir,$inOutDistance,$pcb) {
 $this = $this|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $inOutDistance = $inOutDistance|0;
 $pcb = $pcb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 7600|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 16|0);
 $4 = (__ZNK5physx2Sq16BucketPrunerCore7raycastERKNS_6PxVec3ES4_RfRNS0_14PrunerCallbackE($3,$origin,$unitDir,$inOutDistance,$pcb)|0);
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Sq12BucketPruner9visualizeERNS_2Cm12RenderOutputEj($this,$out,$color) {
 $this = $this|0;
 $out = $out|0;
 $color = $color|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZNK5physx2Sq16BucketPrunerCore9visualizeERNS_2Cm12RenderOutputEj($0,$out,$color);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sq12BucketPruner10getPayloadERKj($this,$h) {
 $this = $this|0;
 $h = $h|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$h>>2]|0;
 $1 = (($this) + 7636|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 7632|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<3)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx2Sq12BucketPruner11preallocateEj($this,$entries) {
 $this = $this|0;
 $entries = $entries|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 7616|0);
 __ZN5physx2Sq11PruningPool11preallocateEj($0,$entries);
 STACKTOP = sp;return;
}
function __ZNK16OBBAABBTest_SIMDclERKN5physx2Sq9BucketBoxE($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $or$cond$i = 0, $or$cond$i54 = 0, $or$cond18$i = 0, $or$cond18$i55 = 0, $or$cond19$i = 0, $or$cond19$i56 = 0, $or$cond20$i = 0, $or$cond20$i57 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($box) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($box) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($box) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 20|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(HEAPF32[$box>>2]);
 $13 = (($box) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($box) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 - $12);
 $18 = Math_fround($9 - $14);
 $19 = Math_fround($11 - $16);
 $20 = (($this) + 128|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 132|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 136|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($1 + $21);
 $27 = Math_fround($3 + $23);
 $28 = Math_fround($5 + $25);
 $29 = Math_fround(-$26);
 $30 = Math_fround(-$27);
 $31 = $17 > $26;
 $32 = $18 > $27;
 $or$cond$i54 = $31 | $32;
 $33 = $19 > $28;
 $or$cond18$i55 = $or$cond$i54 | $33;
 $34 = $17 < $29;
 $or$cond19$i56 = $or$cond18$i55 | $34;
 $35 = $18 < $30;
 $or$cond20$i57 = $or$cond19$i56 | $35;
 if ($or$cond20$i57) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = Math_fround(-$28);
 $37 = $19 < $36;
 if ($37) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = (($this) + 32|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($this) + 36|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($this) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($this) + 48|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($this) + 52|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($this) + 56|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($this) + 64|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($this) + 68|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($this) + 72|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($this) + 80|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($this) + 84|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($this) + 88|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($this) + 96|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($this) + 100|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($this) + 104|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($this) + 112|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($this) + 116|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($this) + 120|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($17 * $39);
 $75 = Math_fround($17 * $41);
 $76 = Math_fround($17 * $43);
 $77 = Math_fround($18 * $45);
 $78 = Math_fround($18 * $47);
 $79 = Math_fround($18 * $49);
 $80 = Math_fround($74 + $77);
 $81 = Math_fround($75 + $78);
 $82 = Math_fround($76 + $79);
 $83 = Math_fround($19 * $51);
 $84 = Math_fround($19 * $53);
 $85 = Math_fround($19 * $55);
 $86 = Math_fround($80 + $83);
 $87 = Math_fround($81 + $84);
 $88 = Math_fround($82 + $85);
 $89 = Math_fround(HEAPF32[$this>>2]);
 $90 = (($this) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($this) + 8|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($1 * $57);
 $95 = Math_fround($1 * $59);
 $96 = Math_fround($1 * $61);
 $97 = Math_fround($94 + $89);
 $98 = Math_fround($95 + $91);
 $99 = Math_fround($96 + $93);
 $100 = Math_fround($3 * $63);
 $101 = Math_fround($3 * $65);
 $102 = Math_fround($3 * $67);
 $103 = Math_fround($100 + $97);
 $104 = Math_fround($101 + $98);
 $105 = Math_fround($102 + $99);
 $106 = Math_fround($5 * $69);
 $107 = Math_fround($5 * $71);
 $108 = Math_fround($5 * $73);
 $109 = Math_fround($106 + $103);
 $110 = Math_fround($107 + $104);
 $111 = Math_fround($108 + $105);
 $112 = Math_fround(-$109);
 $113 = Math_fround(-$110);
 $114 = $86 > $109;
 $115 = $87 > $110;
 $or$cond$i = $114 | $115;
 $116 = $88 > $111;
 $or$cond18$i = $or$cond$i | $116;
 $117 = $86 < $112;
 $or$cond19$i = $or$cond18$i | $117;
 $118 = $87 < $113;
 $or$cond20$i = $or$cond19$i | $118;
 if ($or$cond20$i) {
  $120 = 0;
 } else {
  $119 = Math_fround(-$111);
  $phitmp = !($88 < $119);
  $120 = $phitmp;
 }
 $$ = $120&1;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS_2Sq13PrunerPayloadEjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE5eraseERS6_($this,$k) {
 $this = $this|0;
 $k = $k|0;
 var $$0 = 0, $$pre = 0, $$pre$i = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ptr$0$lcssa$i = 0, $ptr$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$k>>2]|0;
 $4 = (($k) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3 ^ -1;
 $7 = (_i64Add(($3|0),($5|0),-1,($6|0))|0);
 $8 = tempRet0;
 $9 = (_bitshift64Lshr(($7|0),($8|0),22)|0);
 $10 = tempRet0;
 $11 = $9 ^ $7;
 $12 = $10 ^ $8;
 $13 = (_bitshift64Shl(($11|0),($12|0),13)|0);
 $14 = tempRet0;
 $15 = $13 ^ -1;
 $16 = $14 ^ -1;
 $17 = (_i64Add(($11|0),($12|0),($15|0),($16|0))|0);
 $18 = tempRet0;
 $19 = (_bitshift64Lshr(($17|0),($18|0),8)|0);
 $20 = tempRet0;
 $21 = $19 ^ $17;
 $22 = $20 ^ $18;
 $23 = (___muldi3(($21|0),($22|0),9,0)|0);
 $24 = tempRet0;
 $25 = (_bitshift64Lshr(($23|0),($24|0),15)|0);
 $26 = tempRet0;
 $27 = $25 ^ $23;
 $28 = $26 ^ $24;
 $29 = (_bitshift64Shl(($27|0),($28|0),27)|0);
 $30 = tempRet0;
 $31 = $29 ^ -1;
 $32 = $30 ^ -1;
 $33 = (_i64Add(($27|0),($28|0),($31|0),($32|0))|0);
 $34 = tempRet0;
 $35 = (_bitshift64Lshr(($33|0),($34|0),31)|0);
 $36 = tempRet0;
 $37 = $35 ^ $33;
 $36 ^ $34;
 $38 = (($1) + -1)|0;
 $39 = $37 & $38;
 $40 = (($this) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + ($39<<2)|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(-1);
 if ($44) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($this) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 8|0);
 $49 = $43;$ptr$02 = $42;
 while(1) {
  $48 = (($46) + (($49*12)|0)|0);
  $50 = HEAP32[$48>>2]|0;
  $51 = ($50|0)==($3|0);
  if ($51) {
   $52 = ((($46) + (($49*12)|0)|0) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==($5|0);
   if ($54) {
    break;
   }
  }
  $55 = HEAP32[$47>>2]|0;
  $56 = (($55) + ($49<<2)|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(-1);
  if ($58) {
   $$0 = 0;
   label = 15;
   break;
  } else {
   $49 = $57;$ptr$02 = $56;
  }
 }
 if ((label|0) == 15) {
  STACKTOP = sp;return ($$0|0);
 }
 $59 = ($49|0)==(-1);
 if ($59) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $60 = HEAP32[$47>>2]|0;
 $61 = (($60) + ($49<<2)|0);
 $62 = HEAP32[$61>>2]|0;
 HEAP32[$ptr$02>>2] = $62;
 $63 = (($this) + 36|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + -1)|0;
 HEAP32[$63>>2] = $65;
 $66 = (($this) + 32|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 1)|0;
 HEAP32[$66>>2] = $68;
 $69 = ($49|0)==($65|0);
 if (!($69)) {
  $70 = (($46) + (($49*12)|0)|0);
  $71 = ($70|0)==(0|0);
  if ($71) {
   $132 = $41;$87 = $60;$88 = $65;$93 = $46;
  } else {
   $72 = (($46) + (($65*12)|0)|0);
   $73 = $72;
   $74 = $73;
   $75 = HEAP32[$74>>2]|0;
   $76 = (($73) + 4)|0;
   $77 = $76;
   $78 = HEAP32[$77>>2]|0;
   $79 = $70;
   $80 = $79;
   HEAP32[$80>>2] = $75;
   $81 = (($79) + 4)|0;
   $82 = $81;
   HEAP32[$82>>2] = $78;
   $83 = ((($46) + (($49*12)|0)|0) + 8|0);
   $84 = ((($46) + (($65*12)|0)|0) + 8|0);
   $85 = HEAP32[$84>>2]|0;
   HEAP32[$83>>2] = $85;
   $$pre$i = HEAP32[$45>>2]|0;
   $$pre = HEAP32[$63>>2]|0;
   $$pre4 = HEAP32[$47>>2]|0;
   $$pre5 = HEAP32[$40>>2]|0;
   $132 = $$pre5;$87 = $$pre4;$88 = $$pre;$93 = $$pre$i;
  }
  $86 = (($87) + ($88<<2)|0);
  $89 = HEAP32[$86>>2]|0;
  $90 = (($87) + ($49<<2)|0);
  HEAP32[$90>>2] = $89;
  $91 = HEAP32[$0>>2]|0;
  $92 = (($93) + (($49*12)|0)|0);
  $94 = HEAP32[$92>>2]|0;
  $95 = ((($93) + (($49*12)|0)|0) + 4|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = $94 ^ -1;
  $98 = (_i64Add(($94|0),($96|0),-1,($97|0))|0);
  $99 = tempRet0;
  $100 = (_bitshift64Lshr(($98|0),($99|0),22)|0);
  $101 = tempRet0;
  $102 = $100 ^ $98;
  $103 = $101 ^ $99;
  $104 = (_bitshift64Shl(($102|0),($103|0),13)|0);
  $105 = tempRet0;
  $106 = $104 ^ -1;
  $107 = $105 ^ -1;
  $108 = (_i64Add(($102|0),($103|0),($106|0),($107|0))|0);
  $109 = tempRet0;
  $110 = (_bitshift64Lshr(($108|0),($109|0),8)|0);
  $111 = tempRet0;
  $112 = $110 ^ $108;
  $113 = $111 ^ $109;
  $114 = (___muldi3(($112|0),($113|0),9,0)|0);
  $115 = tempRet0;
  $116 = (_bitshift64Lshr(($114|0),($115|0),15)|0);
  $117 = tempRet0;
  $118 = $116 ^ $114;
  $119 = $117 ^ $115;
  $120 = (_bitshift64Shl(($118|0),($119|0),27)|0);
  $121 = tempRet0;
  $122 = $120 ^ -1;
  $123 = $121 ^ -1;
  $124 = (_i64Add(($118|0),($119|0),($122|0),($123|0))|0);
  $125 = tempRet0;
  $126 = (_bitshift64Lshr(($124|0),($125|0),31)|0);
  $127 = tempRet0;
  $128 = $126 ^ $124;
  $127 ^ $125;
  $129 = (($91) + -1)|0;
  $130 = $128 & $129;
  $131 = (($132) + ($130<<2)|0);
  $133 = HEAP32[$131>>2]|0;
  $134 = HEAP32[$63>>2]|0;
  $135 = ($133|0)==($134|0);
  if ($135) {
   $ptr$0$lcssa$i = $131;
  } else {
   $137 = $133;
   while(1) {
    $136 = (($87) + ($137<<2)|0);
    $138 = HEAP32[$136>>2]|0;
    $139 = ($138|0)==($134|0);
    if ($139) {
     $ptr$0$lcssa$i = $136;
     break;
    } else {
     $137 = $138;
    }
   }
  }
  HEAP32[$ptr$0$lcssa$i>>2] = $49;
 }
 $140 = (($this) + 28|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (($141) + -1)|0;
 HEAP32[$140>>2] = $142;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS_2Sq13PrunerPayloadEjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = ($21*12)|0;
 $29 = (($27) + ($28))|0;
 $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$29,507376,354)|0);
 $31 = (($30) + ($22)|0);
 $32 = (($30) + ($27)|0);
 _memset(($30|0),-1,($22|0))|0;
 $33 = (($this) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 $$pre = (($this) + 4|0);
 if (!($35)) {
  $36 = (($$0) + -1)|0;
  $index$01 = 0;
  while(1) {
   $37 = HEAP32[$$pre>>2]|0;
   $38 = (($37) + (($index$01*12)|0)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($37) + (($index$01*12)|0)|0) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = $39 ^ -1;
   $43 = (_i64Add(($39|0),($41|0),-1,($42|0))|0);
   $44 = tempRet0;
   $45 = (_bitshift64Lshr(($43|0),($44|0),22)|0);
   $46 = tempRet0;
   $47 = $45 ^ $43;
   $48 = $46 ^ $44;
   $49 = (_bitshift64Shl(($47|0),($48|0),13)|0);
   $50 = tempRet0;
   $51 = $49 ^ -1;
   $52 = $50 ^ -1;
   $53 = (_i64Add(($47|0),($48|0),($51|0),($52|0))|0);
   $54 = tempRet0;
   $55 = (_bitshift64Lshr(($53|0),($54|0),8)|0);
   $56 = tempRet0;
   $57 = $55 ^ $53;
   $58 = $56 ^ $54;
   $59 = (___muldi3(($57|0),($58|0),9,0)|0);
   $60 = tempRet0;
   $61 = (_bitshift64Lshr(($59|0),($60|0),15)|0);
   $62 = tempRet0;
   $63 = $61 ^ $59;
   $64 = $62 ^ $60;
   $65 = (_bitshift64Shl(($63|0),($64|0),27)|0);
   $66 = tempRet0;
   $67 = $65 ^ -1;
   $68 = $66 ^ -1;
   $69 = (_i64Add(($63|0),($64|0),($67|0),($68|0))|0);
   $70 = tempRet0;
   $71 = (_bitshift64Lshr(($69|0),($70|0),31)|0);
   $72 = tempRet0;
   $73 = $71 ^ $69;
   $72 ^ $70;
   $74 = $73 & $36;
   $75 = (($30) + ($74<<2)|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($31) + ($index$01<<2)|0);
   HEAP32[$77>>2] = $76;
   HEAP32[$75>>2] = $index$01;
   $78 = (($32) + (($index$01*12)|0)|0);
   $79 = ($78|0)==(0|0);
   if (!($79)) {
    $80 = (($37) + (($index$01*12)|0)|0);
    $81 = $80;
    $82 = $81;
    $83 = HEAP32[$82>>2]|0;
    $84 = (($81) + 4)|0;
    $85 = $84;
    $86 = HEAP32[$85>>2]|0;
    $87 = $78;
    $88 = $87;
    HEAP32[$88>>2] = $83;
    $89 = (($87) + 4)|0;
    $90 = $89;
    HEAP32[$90>>2] = $86;
    $91 = ((($32) + (($index$01*12)|0)|0) + 8|0);
    $92 = ((($37) + (($index$01*12)|0)|0) + 8|0);
    $93 = HEAP32[$92>>2]|0;
    HEAP32[$91>>2] = $93;
   }
   $94 = (($index$01) + 1)|0;
   $95 = HEAP32[$33>>2]|0;
   $96 = ($94>>>0)<($95>>>0);
   if ($96) {
    $index$01 = $94;
   } else {
    break;
   }
  }
 }
 $97 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$97);
 HEAP32[$this>>2] = $30;
 $98 = (($this) + 12|0);
 HEAP32[$98>>2] = $30;
 $99 = (($this) + 20|0);
 HEAP32[$99>>2] = $$0;
 $100 = (($this) + 8|0);
 HEAP32[$100>>2] = $31;
 HEAP32[$$pre>>2] = $32;
 HEAP32[$15>>2] = $21;
 $101 = (($this) + 28|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = ($102|0)==(-1);
 if (!($103)) {
  STACKTOP = sp;return;
 }
 HEAP32[$101>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN16OBBAABBTest_SIMDC2ERKN5physx7PxMat33ERKNS0_6PxVec3ES6_($this,$rotation,$translation,$extents) {
 $this = $this|0;
 $rotation = $rotation|0;
 $translation = $translation|0;
 $extents = $extents|0;
 var $$$i$i = Math_fround(0), $$$i$i14 = Math_fround(0), $$$i$i22 = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i$i15 = Math_fround(0), $$1$i$i23 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0);
 var $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$translation>>2]);
 $1 = (($translation) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($translation) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 16|0);
 HEAPF32[$5>>2] = $0;
 $6 = (($this) + 20|0);
 HEAPF32[$6>>2] = $2;
 $7 = (($this) + 24|0);
 HEAPF32[$7>>2] = $4;
 $8 = (($this) + 28|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = Math_fround(HEAPF32[$extents>>2]);
 $10 = (($extents) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($extents) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$this>>2] = $9;
 $14 = (($this) + 4|0);
 HEAPF32[$14>>2] = $11;
 $15 = (($this) + 8|0);
 HEAPF32[$15>>2] = $13;
 $16 = (($this) + 12|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = Math_fround(HEAPF32[$rotation>>2]);
 $18 = (($rotation) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($rotation) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($rotation) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($rotation) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($rotation) + 28|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($rotation) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($rotation) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($rotation) + 32|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 32|0);
 HEAPF32[$34>>2] = $17;
 $35 = (($this) + 36|0);
 HEAPF32[$35>>2] = $19;
 $36 = (($this) + 40|0);
 HEAPF32[$36>>2] = $21;
 $37 = (($this) + 44|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($this) + 48|0);
 HEAPF32[$38>>2] = $23;
 $39 = (($this) + 52|0);
 HEAPF32[$39>>2] = $25;
 $40 = (($this) + 56|0);
 HEAPF32[$40>>2] = $27;
 $41 = (($this) + 60|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($this) + 64|0);
 HEAPF32[$42>>2] = $29;
 $43 = (($this) + 68|0);
 HEAPF32[$43>>2] = $31;
 $44 = (($this) + 72|0);
 HEAPF32[$44>>2] = $33;
 $45 = (($this) + 76|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = Math_fround(-$17);
 $47 = Math_fround(-$19);
 $48 = Math_fround(-$21);
 $49 = $17 > $46;
 $$$i$i22 = $49 ? $17 : $46;
 $50 = $19 > $47;
 $51 = $50 ? $19 : $47;
 $52 = $21 > $48;
 $$1$i$i23 = $52 ? $21 : $48;
 $53 = Math_fround($$$i$i22 + Math_fround(9.99999997475242707878E-7));
 $54 = Math_fround($51 + Math_fround(9.99999997475242707878E-7));
 $55 = Math_fround($$1$i$i23 + Math_fround(9.99999997475242707878E-7));
 $56 = Math_fround(-$23);
 $57 = Math_fround(-$25);
 $58 = Math_fround(-$27);
 $59 = $23 > $56;
 $$$i$i14 = $59 ? $23 : $56;
 $60 = $25 > $57;
 $61 = $60 ? $25 : $57;
 $62 = $27 > $58;
 $$1$i$i15 = $62 ? $27 : $58;
 $63 = Math_fround($$$i$i14 + Math_fround(9.99999997475242707878E-7));
 $64 = Math_fround($61 + Math_fround(9.99999997475242707878E-7));
 $65 = Math_fround($$1$i$i15 + Math_fround(9.99999997475242707878E-7));
 $66 = Math_fround(-$29);
 $67 = Math_fround(-$31);
 $68 = Math_fround(-$33);
 $69 = $29 > $66;
 $$$i$i = $69 ? $29 : $66;
 $70 = $31 > $67;
 $71 = $70 ? $31 : $67;
 $72 = $33 > $68;
 $$1$i$i = $72 ? $33 : $68;
 $73 = Math_fround($$$i$i + Math_fround(9.99999997475242707878E-7));
 $74 = Math_fround($71 + Math_fround(9.99999997475242707878E-7));
 $75 = Math_fround($$1$i$i + Math_fround(9.99999997475242707878E-7));
 $76 = (($this) + 80|0);
 HEAPF32[$76>>2] = $53;
 $77 = (($this) + 84|0);
 HEAPF32[$77>>2] = $54;
 $78 = (($this) + 88|0);
 HEAPF32[$78>>2] = $55;
 $79 = (($this) + 92|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($this) + 96|0);
 HEAPF32[$80>>2] = $63;
 $81 = (($this) + 100|0);
 HEAPF32[$81>>2] = $64;
 $82 = (($this) + 104|0);
 HEAPF32[$82>>2] = $65;
 $83 = (($this) + 108|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($this) + 112|0);
 HEAPF32[$84>>2] = $73;
 $85 = (($this) + 116|0);
 HEAPF32[$85>>2] = $74;
 $86 = (($this) + 120|0);
 HEAPF32[$86>>2] = $75;
 $87 = (($this) + 124|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = Math_fround(HEAPF32[$this>>2]);
 $89 = Math_fround(HEAPF32[$14>>2]);
 $90 = Math_fround(HEAPF32[$15>>2]);
 $91 = Math_fround($88 * $53);
 $92 = Math_fround($89 * $54);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($90 * $55);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($88 * $63);
 $97 = Math_fround($89 * $64);
 $98 = Math_fround($96 + $97);
 $99 = Math_fround($90 * $65);
 $100 = Math_fround($98 + $99);
 $101 = Math_fround($88 * $73);
 $102 = Math_fround($89 * $74);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($90 * $75);
 $105 = Math_fround($103 + $104);
 $106 = (($this) + 128|0);
 HEAPF32[$106>>2] = $95;
 $107 = (($this) + 132|0);
 HEAPF32[$107>>2] = $100;
 $108 = (($this) + 136|0);
 HEAPF32[$108>>2] = $105;
 $109 = (($this) + 140|0);
 HEAPF32[$109>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS_2Sq13PrunerPayloadEjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE6createERS6_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $h$0 = 0, $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $h$0 = 0;
 } else {
  $3 = HEAP32[$k>>2]|0;
  $4 = (($k) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $3 ^ -1;
  $7 = (_i64Add(($3|0),($5|0),-1,($6|0))|0);
  $8 = tempRet0;
  $9 = (_bitshift64Lshr(($7|0),($8|0),22)|0);
  $10 = tempRet0;
  $11 = $9 ^ $7;
  $12 = $10 ^ $8;
  $13 = (_bitshift64Shl(($11|0),($12|0),13)|0);
  $14 = tempRet0;
  $15 = $13 ^ -1;
  $16 = $14 ^ -1;
  $17 = (_i64Add(($11|0),($12|0),($15|0),($16|0))|0);
  $18 = tempRet0;
  $19 = (_bitshift64Lshr(($17|0),($18|0),8)|0);
  $20 = tempRet0;
  $21 = $19 ^ $17;
  $22 = $20 ^ $18;
  $23 = (___muldi3(($21|0),($22|0),9,0)|0);
  $24 = tempRet0;
  $25 = (_bitshift64Lshr(($23|0),($24|0),15)|0);
  $26 = tempRet0;
  $27 = $25 ^ $23;
  $28 = $26 ^ $24;
  $29 = (_bitshift64Shl(($27|0),($28|0),27)|0);
  $30 = tempRet0;
  $31 = $29 ^ -1;
  $32 = $30 ^ -1;
  $33 = (_i64Add(($27|0),($28|0),($31|0),($32|0))|0);
  $34 = tempRet0;
  $35 = (_bitshift64Lshr(($33|0),($34|0),31)|0);
  $36 = tempRet0;
  $37 = $35 ^ $33;
  $36 ^ $34;
  $38 = (($1) + -1)|0;
  $39 = $37 & $38;
  $40 = (($this) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + ($39<<2)|0);
  $index$05 = HEAP32[$42>>2]|0;
  $43 = ($index$05|0)==(-1);
  L4: do {
   if (!($43)) {
    $44 = (($this) + 4|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($this) + 8|0);
    $index$06 = $index$05;
    while(1) {
     $47 = (($45) + (($index$06*12)|0)|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==($3|0);
     if ($49) {
      $50 = ((($45) + (($index$06*12)|0)|0) + 4|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==($5|0);
      if ($52) {
       break;
      }
     }
     $53 = HEAP32[$46>>2]|0;
     $54 = (($53) + ($index$06<<2)|0);
     $index$0 = HEAP32[$54>>2]|0;
     $55 = ($index$0|0)==(-1);
     if ($55) {
      break L4;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $56 = (($45) + (($index$06*12)|0)|0);
    $$0 = $56;
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $h$0 = $39;
 }
 HEAP8[$exists>>0] = 0;
 $57 = (($this) + 36|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 16|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($58|0)==($60|0);
 if ($61) {
  $62 = $1 << 1;
  $$$i = $2 ? 16 : $62;
  $63 = ($1>>>0)<($$$i>>>0);
  if ($63) {
   __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKNS_2Sq13PrunerPayloadEjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $100 = $$pre;
  } else {
   $100 = $1;
  }
  $64 = HEAP32[$k>>2]|0;
  $65 = (($k) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = $64 ^ -1;
  $68 = (_i64Add(($64|0),($66|0),-1,($67|0))|0);
  $69 = tempRet0;
  $70 = (_bitshift64Lshr(($68|0),($69|0),22)|0);
  $71 = tempRet0;
  $72 = $70 ^ $68;
  $73 = $71 ^ $69;
  $74 = (_bitshift64Shl(($72|0),($73|0),13)|0);
  $75 = tempRet0;
  $76 = $74 ^ -1;
  $77 = $75 ^ -1;
  $78 = (_i64Add(($72|0),($73|0),($76|0),($77|0))|0);
  $79 = tempRet0;
  $80 = (_bitshift64Lshr(($78|0),($79|0),8)|0);
  $81 = tempRet0;
  $82 = $80 ^ $78;
  $83 = $81 ^ $79;
  $84 = (___muldi3(($82|0),($83|0),9,0)|0);
  $85 = tempRet0;
  $86 = (_bitshift64Lshr(($84|0),($85|0),15)|0);
  $87 = tempRet0;
  $88 = $86 ^ $84;
  $89 = $87 ^ $85;
  $90 = (_bitshift64Shl(($88|0),($89|0),27)|0);
  $91 = tempRet0;
  $92 = $90 ^ -1;
  $93 = $91 ^ -1;
  $94 = (_i64Add(($88|0),($89|0),($92|0),($93|0))|0);
  $95 = tempRet0;
  $96 = (_bitshift64Lshr(($94|0),($95|0),31)|0);
  $97 = tempRet0;
  $98 = $96 ^ $94;
  $97 ^ $95;
  $99 = (($100) + -1)|0;
  $101 = $98 & $99;
  $h$1 = $101;
 } else {
  $h$1 = $h$0;
 }
 $102 = (($this) + 28|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + 1)|0;
 HEAP32[$102>>2] = $104;
 $105 = (($this) + 12|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = (($106) + ($h$1<<2)|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($this) + 8|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = (($110) + ($103<<2)|0);
 HEAP32[$111>>2] = $108;
 HEAP32[$107>>2] = $103;
 $112 = HEAP32[$57>>2]|0;
 $113 = (($112) + 1)|0;
 HEAP32[$57>>2] = $113;
 $114 = (($this) + 32|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (($115) + 1)|0;
 HEAP32[$114>>2] = $116;
 $117 = (($this) + 4|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = (($118) + (($103*12)|0)|0);
 $$0 = $119;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sq11PruningPoolC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((507496 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (($this) + 32|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;
 HEAP32[$1>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq11PruningPoolD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 HEAP32[$this>>2] = ((507496 + 8|0));
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$5);
 HEAP32[$4>>2] = 0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
 HEAP32[$6>>2] = 0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$9);
 HEAP32[$8>>2] = 0;
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$11);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq11PruningPoolD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 HEAP32[$this>>2] = ((507496 + 8|0));
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$5);
 HEAP32[$4>>2] = 0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
 HEAP32[$6>>2] = 0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$9);
 HEAP32[$8>>2] = 0;
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$11);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq11PruningPool6resizeEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 11|0;
 $1 = sp + 10|0;
 $2 = sp + 9|0;
 $3 = sp + 8|0;
 $4 = sp + 7|0;
 $5 = sp + 6|0;
 $6 = sp + 5|0;
 $7 = sp + 3|0;
 $8 = sp + 2|0;
 $9 = sp + 1|0;
 $10 = sp;
 $11 = sp + 4|0;
 $12 = ($newCapacity*24)|0;
 $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$12,507520,75)|0);
 $14 = $newCapacity << 3;
 $15 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$14,507520,76)|0);
 $16 = $newCapacity << 2;
 $17 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$16,507520,77)|0);
 $18 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$16,507520,78)|0);
 $19 = ($13|0)==(0|0);
 $20 = ($15|0)==(0|0);
 $or$cond = $19 | $20;
 $21 = ($17|0)==(0|0);
 $or$cond1 = $or$cond | $21;
 $22 = ($18|0)==(0|0);
 $or$cond2 = $or$cond1 | $22;
 if ($or$cond2) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$13);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$15);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$17);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$18);
  STACKTOP = sp;return;
 }
 $23 = (($this) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = (($this) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27*24)|0;
  _memcpy(($13|0),($24|0),($28|0))|0;
 }
 $29 = (($this) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = (($this) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 << 3;
  _memcpy(($15|0),($30|0),($34|0))|0;
 }
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  $38 = (($this) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = $39 << 2;
  _memcpy(($17|0),($36|0),($40|0))|0;
 }
 $41 = (($this) + 20|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $$pre = (($this) + 8|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $44 = (($this) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $45 << 2;
  _memcpy(($18|0),($42|0),($46|0))|0;
  $$pre$phiZ2D = $44;
 }
 HEAP32[$$pre$phiZ2D>>2] = $newCapacity;
 $47 = HEAP32[$23>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($8,$47);
 HEAP32[$23>>2] = 0;
 $48 = HEAP32[$29>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($9,$48);
 HEAP32[$29>>2] = 0;
 $49 = HEAP32[$41>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($10,$49);
 HEAP32[$41>>2] = 0;
 $50 = HEAP32[$35>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($11,$50);
 HEAP32[$23>>2] = $13;
 HEAP32[$29>>2] = $15;
 HEAP32[$41>>2] = $18;
 HEAP32[$35>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq11PruningPool11preallocateEj($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($newCapacity>>>0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sq11PruningPool6resizeEj($this,$newCapacity);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq11PruningPool9addObjectERKNS_9PxBounds3ERKNS0_13PrunerPayloadE($this,$worldAABB,$payload) {
 $this = $this|0;
 $worldAABB = $worldAABB|0;
 $payload = $payload|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0;
 var $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $handle$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $5 = $1 << 1;
  $6 = ($5>>>0)<(64);
  $7 = $6 ? 64 : $5;
  __ZN5physx2Sq11PruningPool6resizeEj($this,$7);
  $$pre = HEAP32[$0>>2]|0;
  $$pre1 = HEAP32[$2>>2]|0;
  $10 = $$pre1;$9 = $$pre;
 } else {
  $10 = $3;$9 = $1;
 }
 $8 = ($9|0)==($10|0);
 if ($8) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($9) + 1)|0;
 HEAP32[$0>>2] = $11;
 $12 = (($this) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$worldAABB>>2]);
 $15 = (($13) + (($9*24)|0)|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($worldAABB) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = ((($13) + (($9*24)|0)|0) + 4|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($worldAABB) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = ((($13) + (($9*24)|0)|0) + 8|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($worldAABB) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = ((($13) + (($9*24)|0)|0) + 12|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($worldAABB) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = ((($13) + (($9*24)|0)|0) + 16|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($worldAABB) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = ((($13) + (($9*24)|0)|0) + 20|0);
 HEAPF32[$30>>2] = $29;
 $31 = (($this) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($9<<3)|0);
 $34 = $payload;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = $33;
 $41 = $40;
 HEAP32[$41>>2] = $36;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $39;
 $44 = (($this) + 32|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(-1);
 if ($46) {
  $51 = (($this) + 28|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + 1)|0;
  HEAP32[$51>>2] = $53;
  $$phi$trans$insert = (($this) + 20|0);
  $$pre2 = HEAP32[$$phi$trans$insert>>2]|0;
  $58 = $$pre2;$handle$0 = $52;
 } else {
  $47 = (($this) + 20|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + ($45<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  HEAP32[$44>>2] = $50;
  $58 = $48;$handle$0 = $45;
 }
 $54 = (($this) + 24|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + ($9<<2)|0);
 HEAP32[$56>>2] = $handle$0;
 $57 = (($58) + ($handle$0<<2)|0);
 HEAP32[$57>>2] = $9;
 $$0 = $handle$0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Sq11PruningPool12removeObjectEj($this,$h) {
 $this = $this|0;
 $h = $h|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($h<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -1)|0;
 HEAP32[$4>>2] = $6;
 $7 = ($6|0)==($3|0);
 if ($7) {
  $53 = $1;
  $50 = (($this) + 32|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($53) + ($h<<2)|0);
  HEAP32[$52>>2] = $51;
  HEAP32[$50>>2] = $h;
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($6<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + (($6*24)|0)|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($13) + (($3*24)|0)|0);
 HEAPF32[$16>>2] = $15;
 $17 = ((($13) + (($6*24)|0)|0) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = ((($13) + (($3*24)|0)|0) + 4|0);
 HEAPF32[$19>>2] = $18;
 $20 = ((($13) + (($6*24)|0)|0) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = ((($13) + (($3*24)|0)|0) + 8|0);
 HEAPF32[$22>>2] = $21;
 $23 = ((($13) + (($6*24)|0)|0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = ((($13) + (($3*24)|0)|0) + 12|0);
 HEAPF32[$25>>2] = $24;
 $26 = ((($13) + (($6*24)|0)|0) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = ((($13) + (($3*24)|0)|0) + 16|0);
 HEAPF32[$28>>2] = $27;
 $29 = ((($13) + (($6*24)|0)|0) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = ((($13) + (($3*24)|0)|0) + 20|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($this) + 16|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + ($3<<3)|0);
 $35 = (($33) + ($6<<3)|0);
 $36 = $35;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $34;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 $46 = HEAP32[$8>>2]|0;
 $47 = (($46) + ($3<<2)|0);
 HEAP32[$47>>2] = $11;
 $48 = HEAP32[$0>>2]|0;
 $49 = (($48) + ($11<<2)|0);
 HEAP32[$49>>2] = $3;
 $53 = $48;
 $50 = (($this) + 32|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($53) + ($h<<2)|0);
 HEAP32[$52>>2] = $51;
 HEAP32[$50>>2] = $h;
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx2Sq11PruningPool11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($shift) + 4|0);
 $6 = (($shift) + 8|0);
 $i$01 = 0;
 while(1) {
  $7 = Math_fround(HEAPF32[$shift>>2]);
  $8 = (($4) + (($i$01*24)|0)|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($9 - $7);
  HEAPF32[$8>>2] = $10;
  $11 = Math_fround(HEAPF32[$5>>2]);
  $12 = ((($4) + (($i$01*24)|0)|0) + 4|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($13 - $11);
  HEAPF32[$12>>2] = $14;
  $15 = Math_fround(HEAPF32[$6>>2]);
  $16 = ((($4) + (($i$01*24)|0)|0) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($17 - $15);
  HEAPF32[$16>>2] = $18;
  $19 = Math_fround(HEAPF32[$shift>>2]);
  $20 = ((($4) + (($i$01*24)|0)|0) + 12|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($21 - $19);
  HEAPF32[$20>>2] = $22;
  $23 = Math_fround(HEAPF32[$5>>2]);
  $24 = ((($4) + (($i$01*24)|0)|0) + 16|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($25 - $23);
  HEAPF32[$24>>2] = $26;
  $27 = Math_fround(HEAPF32[$6>>2]);
  $28 = ((($4) + (($i$01*24)|0)|0) + 20|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($29 - $27);
  HEAPF32[$28>>2] = $30;
  $31 = (($i$01) + 1)|0;
  $32 = ($31>>>0)<($1>>>0);
  if ($32) {
   $i$01 = $31;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Sq11PruningPool10getPayloadERKj($this,$h) {
 $this = $this|0;
 $h = $h|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$h>>2]|0;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<3)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx2Sq17SceneQueryManagerC2ERNS_3Scb5SceneERKNS_11PxSceneDescE($this,$scene,$desc) {
 $this = $this|0;
 $scene = $scene|0;
 $desc = $desc|0;
 var $$$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu19GetRaycastFuncTableEv()|0);
 HEAP32[$this>>2] = $0;
 $1 = (($this) + 4|0);
 $2 = (__ZN5physx2Gu17GetGeomSweepFuncsEv()|0);
 HEAP32[$1>>2] = $2;
 $3 = (($this) + 8|0);
 $4 = (__ZN5physx2Gu25GetGeomOverlapMethodTableEv()|0);
 HEAP32[$3>>2] = $4;
 $5 = (($this) + 28|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 32|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 44|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 52|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 56|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 60|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 76|0);
 HEAP32[$12>>2] = $scene;
 $13 = (($this) + 80|0);
 $14 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  HEAP32[$13>>2] = 0;
 } else {
  $17 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (__Z15PxGetFoundationv()|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 24|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (FUNCTION_TABLE_ii[$24 & 4095]($21)|0);
  $$$i$i$i$i = $25 ? 508312 : 507840;
  $26 = (FUNCTION_TABLE_iiiiii[$20 & 255]($17,$15,$$$i$i$i$i,508232,111)|0);
  HEAP32[$13>>2] = $26;
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($26);
  }
 }
 $28 = (($desc) + 116|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 64|0);
 HEAP32[$30>>2] = $29;
 $31 = (($desc) + 120|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($this) + 68|0);
 HEAP32[$33>>2] = $32;
 $34 = (($this) + 20|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 24|0);
 HEAP32[$35>>2] = 0;
 $36 = HEAP32[$28>>2]|0;
 $37 = (__ZN5physx2Sq17SceneQueryManager12createPrunerENS_18PxPruningStructure4EnumE($36)|0);
 $38 = (($this) + 12|0);
 HEAP32[$38>>2] = $37;
 $39 = HEAP32[$31>>2]|0;
 $40 = (__ZN5physx2Sq17SceneQueryManager12createPrunerENS_18PxPruningStructure4EnumE($39)|0);
 $41 = (($this) + 16|0);
 HEAP32[$41>>2] = $40;
 $42 = (($desc) + 124|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 72|0);
 HEAP32[$44>>2] = $43;
 $45 = HEAP32[$38>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  $50 = $40;
 } else {
  $47 = HEAP32[$30>>2]|0;
  $48 = ($47|0)==(1);
  if ($48) {
   __ZN5physx2Sq10AABBPruner18setRebuildRateHintEj($45,$43);
   $$pre = HEAP32[$41>>2]|0;
   $50 = $$pre;
  } else {
   $50 = $40;
  }
 }
 $49 = ($50|0)==(0|0);
 if ($49) {
  $53 = (($desc) + 56|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($desc) + 60|0);
  $56 = HEAP32[$55>>2]|0;
  __ZN5physx2Sq17SceneQueryManager11preallocateEjj($this,$54,$56);
  STACKTOP = sp;return;
 }
 $51 = HEAP32[$33>>2]|0;
 $52 = ($51|0)==(1);
 if (!($52)) {
  $53 = (($desc) + 56|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($desc) + 60|0);
  $56 = HEAP32[$55>>2]|0;
  __ZN5physx2Sq17SceneQueryManager11preallocateEjj($this,$54,$56);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sq10AABBPruner18setRebuildRateHintEj($50,$43);
 $53 = (($desc) + 56|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($desc) + 60|0);
 $56 = HEAP32[$55>>2]|0;
 __ZN5physx2Sq17SceneQueryManager11preallocateEjj($this,$54,$56);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager12createPrunerENS_18PxPruningStructure4EnumE($type) {
 $type = $type|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$$i$i$i2 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($type|0) == 1)) {
  $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (__Z15PxGetFoundationv()|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 24|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (FUNCTION_TABLE_ii[$27 & 4095]($24)|0);
  $$$i$i$i = $28 ? 508112 : 507840;
  $29 = (FUNCTION_TABLE_iiiiii[$23 & 255]($20,7824,$$$i$i$i,507600,81)|0);
  __ZN5physx2Sq10AABBPrunerC2Eb($29,1);
  $$0 = $29;
  STACKTOP = sp;return ($$0|0);
 } else if ((($type|0) == 0)) {
  $10 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__Z15PxGetFoundationv()|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 24|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (FUNCTION_TABLE_ii[$17 & 4095]($14)|0);
  $$$i$i$i2 = $18 ? 507992 : 507840;
  $19 = (FUNCTION_TABLE_iiiiii[$13 & 255]($10,7664,$$$i$i$i2,507600,80)|0);
  __ZN5physx2Sq12BucketPrunerC2Ev($19);
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 } else if ((($type|0) == 2)) {
  $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($1) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (__Z15PxGetFoundationv()|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
  $$$i$i$i1 = $8 ? 508112 : 507840;
  $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,7824,$$$i$i$i1,507600,79)|0);
  __ZN5physx2Sq10AABBPrunerC2Eb($9,0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Sq17SceneQueryManager29setDynamicTreeRebuildRateHintEj($this,$rebuildRateHint) {
 $this = $this|0;
 $rebuildRateHint = $rebuildRateHint|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 HEAP32[$0>>2] = $rebuildRateHint;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 64|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(1);
  if ($6) {
   __ZN5physx2Sq10AABBPruner18setRebuildRateHintEj($2,$rebuildRateHint);
  }
 }
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 68|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(1);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Sq10AABBPruner18setRebuildRateHintEj($8,$rebuildRateHint);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager11preallocateEjj($this,$staticShapes,$dynamicShapes) {
 $this = $this|0;
 $staticShapes = $staticShapes|0;
 $dynamicShapes = $dynamicShapes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 5;
 $3 = ($2>>>0)<($staticShapes>>>0);
 if ($3) {
  $4 = (($staticShapes) + 31)|0;
  $5 = $4 >>> 5;
  $6 = $1 & 2147483647;
  $7 = ($5>>>0)>($6>>>0);
  if ($7) {
   $8 = (($this) + 36|0);
   $9 = $5 << 2;
   $10 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($8,$9,507688,339)|0);
   $11 = (($this) + 28|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = HEAP32[$0>>2]|0;
    $15 = $14 << 2;
    _memcpy(($10|0),($12|0),($15|0))|0;
    $16 = HEAP32[$0>>2]|0;
    $17 = ($16|0)>(-1);
    if ($17) {
     $18 = HEAP32[$11>>2]|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($8,$18);
    }
   }
   $19 = HEAP32[$0>>2]|0;
   $20 = $19 & 2147483647;
   $21 = (($10) + ($20<<2)|0);
   $22 = (($5) - ($19))|0;
   $23 = $22 << 2;
   _memset(($21|0),0,($23|0))|0;
   HEAP32[$11>>2] = $10;
   HEAP32[$0>>2] = $5;
  }
 }
 $24 = (($this) + 44|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 << 5;
 $27 = ($26>>>0)<($dynamicShapes>>>0);
 if ($27) {
  $28 = (($dynamicShapes) + 31)|0;
  $29 = $28 >>> 5;
  $30 = $25 & 2147483647;
  $31 = ($29>>>0)>($30>>>0);
  if ($31) {
   $32 = (($this) + 48|0);
   $33 = $29 << 2;
   $34 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($32,$33,507688,339)|0);
   $35 = (($this) + 40|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = HEAP32[$24>>2]|0;
    $39 = $38 << 2;
    _memcpy(($34|0),($36|0),($39|0))|0;
    $40 = HEAP32[$24>>2]|0;
    $41 = ($40|0)>(-1);
    if ($41) {
     $42 = HEAP32[$35>>2]|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($32,$42);
    }
   }
   $43 = HEAP32[$24>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($34) + ($44<<2)|0);
   $46 = (($29) - ($43))|0;
   $47 = $46 << 2;
   _memset(($45|0),0,($47|0))|0;
   HEAP32[$35>>2] = $34;
   HEAP32[$24>>2] = $29;
  }
 }
 $48 = (($this) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = HEAP32[$49>>2]|0;
  $52 = (($51) + 32|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vii[$53 & 4095]($49,$staticShapes);
 }
 $54 = (($this) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$55>>2]|0;
 $58 = (($57) + 32|0);
 $59 = HEAP32[$58>>2]|0;
 FUNCTION_TABLE_vii[$59 & 4095]($55,$dynamicShapes);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManagerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 44|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
 }
 HEAP32[$0>>2] = 0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $40 = HEAP32[$7>>2]|0;
  $41 = (($40) + 44|0);
  $42 = HEAP32[$41>>2]|0;
  FUNCTION_TABLE_vi[$42 & 4095]($7);
 }
 HEAP32[$6>>2] = 0;
 $43 = (($this) + 80|0);
 $44 = HEAP32[$43>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($44);
 $13 = HEAP32[$43>>2]|0;
 $45 = ($13|0)==(0|0);
 if (!($45)) {
  $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 4095]($9,$13);
 }
 $14 = (($this) + 60|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16|0)!=(0);
 $18 = ($15|0)>(-1);
 $or$cond$i$i = $17 & $18;
 if ($or$cond$i$i) {
  $19 = (($this) + 52|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vii[$25 & 4095]($22,$20);
  }
 }
 $26 = (($this) + 40|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = (($this) + 44|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)>(-1);
  if ($31) {
   $32 = (($this) + 48|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($32,$27);
  }
 }
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)>(-1);
 if (!($38)) {
  STACKTOP = sp;return;
 }
 $39 = (($this) + 36|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($39,$34);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager13markForUpdateEPNS0_10ActorShapeE($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $s;
 $1 = $s;
 $2 = $1 & 1;
 $3 = $1 >>> 2;
 $4 = $1 >>> 7;
 $5 = ((($this) + (($2*12)|0)|0) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $3 & 31;
 $10 = 1 << $9;
 $11 = $8 & $10;
 $12 = ($11|0)==(0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = $8 | $10;
 HEAP32[$7>>2] = $13;
 $14 = (($this) + 52|0);
 $15 = (($this) + 60|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = (($this) + 56|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17>>>0)>($19>>>0);
 if ($20) {
  $21 = HEAP32[$14>>2]|0;
  $22 = (($21) + ($19<<2)|0);
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   HEAP32[$22>>2] = $s;
  }
  $24 = (($19) + 1)|0;
  HEAP32[$18>>2] = $24;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Sq10ActorShapeENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($14,$0)|0);
 }
 $25 = ((($this) + ($2<<2)|0) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$25>>2] = $27;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager8addShapeERKNS_7NpShapeERKNS_12PxRigidActorEbPNS_9PxBounds3E($this,$shape,$actor,$dynamic,$bounds) {
 $this = $this|0;
 $shape = $shape|0;
 $actor = $actor|0;
 $dynamic = $dynamic|0;
 $bounds = $bounds|0;
 var $$op1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0);
 var $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b = 0, $handle = 0, $pp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pp = sp + 56|0;
 $b = sp;
 $0 = sp + 24|0;
 $handle = sp + 48|0;
 $1 = (($shape) + 32|0);
 $2 = (($actor) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = ((414264 + ($4<<2)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($actor) + ($6)|0);
 $8 = $1;
 HEAP32[$pp>>2] = $8;
 $9 = $7;
 $10 = (($pp) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = ($bounds|0)==(0|0);
 if ($11) {
  __ZN5physx2Sq16computeWorldAABBERKNS_3Scb5ShapeERKNS1_5ActorE($0,$1,$7);
  $43 = Math_fround(HEAPF32[$0>>2]);
  HEAPF32[$b>>2] = $43;
  $44 = (($0) + 4|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($b) + 4|0);
  HEAPF32[$46>>2] = $45;
  $47 = (($0) + 8|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($b) + 8|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($0) + 12|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($b) + 12|0);
  HEAPF32[$52>>2] = $51;
  $53 = (($0) + 16|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($b) + 16|0);
  HEAPF32[$55>>2] = $54;
  $56 = (($0) + 20|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($b) + 20|0);
  HEAPF32[$58>>2] = $57;
 } else {
  $12 = (($bounds) + 12|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround(HEAPF32[$bounds>>2]);
  $15 = Math_fround($13 - $14);
  $16 = (($bounds) + 16|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($bounds) + 4|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($17 - $19);
  $21 = (($bounds) + 20|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($bounds) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($22 - $24);
  $26 = Math_fround($15 * Math_fround(0.5));
  $27 = Math_fround($20 * Math_fround(0.5));
  $28 = Math_fround($25 * Math_fround(0.5));
  $29 = Math_fround($26 * Math_fround(0.00999999977648258209228));
  $30 = Math_fround($27 * Math_fround(0.00999999977648258209228));
  $31 = Math_fround($28 * Math_fround(0.00999999977648258209228));
  $32 = Math_fround($14 - $29);
  $33 = Math_fround($19 - $30);
  $34 = Math_fround($24 - $31);
  $35 = Math_fround($13 + $29);
  $36 = Math_fround($17 + $30);
  $37 = Math_fround($22 + $31);
  HEAPF32[$b>>2] = $32;
  $38 = (($b) + 4|0);
  HEAPF32[$38>>2] = $33;
  $39 = (($b) + 8|0);
  HEAPF32[$39>>2] = $34;
  $40 = (($b) + 12|0);
  HEAPF32[$40>>2] = $35;
  $41 = (($b) + 16|0);
  HEAPF32[$41>>2] = $36;
  $42 = (($b) + 20|0);
  HEAPF32[$42>>2] = $37;
 }
 $59 = $dynamic&1;
 $60 = ((($this) + ($59<<2)|0) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP32[$62>>2]|0;
 (FUNCTION_TABLE_iiiiii[$63 & 255]($61,$handle,$b,$pp,1)|0);
 $64 = ((($this) + ($59<<2)|0) + 20|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + 1)|0;
 HEAP32[$64>>2] = $66;
 $67 = ((($this) + (($59*12)|0)|0) + 28|0);
 $68 = ((($this) + (($59*12)|0)|0) + 32|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = $69 << 5;
 $71 = HEAP32[$handle>>2]|0;
 $72 = ($70>>>0)>($71>>>0);
 if ($72) {
  $95 = $71;
  $94 = $95 & 31;
  $96 = 1 << $94;
  $97 = $96 ^ -1;
  $98 = $95 >>> 5;
  $99 = HEAP32[$67>>2]|0;
  $100 = (($99) + ($98<<2)|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = $101 & $97;
  HEAP32[$100>>2] = $102;
  $103 = HEAP32[$handle>>2]|0;
  $104 = $103 << 2;
  $105 = $59 | $104;
  $106 = $105 | 2;
  $107 = $106;
  STACKTOP = sp;return ($107|0);
 }
 $73 = $69 << 6;
 $74 = ($73>>>0)<(1024);
 $75 = $69 << 1;
 $$op1 = $75 & 134217726;
 $76 = $74 ? 32 : $$op1;
 $77 = $69 & 2147483647;
 $78 = ($76>>>0)>($77>>>0);
 if (!($78)) {
  $95 = $71;
  $94 = $95 & 31;
  $96 = 1 << $94;
  $97 = $96 ^ -1;
  $98 = $95 >>> 5;
  $99 = HEAP32[$67>>2]|0;
  $100 = (($99) + ($98<<2)|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = $101 & $97;
  HEAP32[$100>>2] = $102;
  $103 = HEAP32[$handle>>2]|0;
  $104 = $103 << 2;
  $105 = $59 | $104;
  $106 = $105 | 2;
  $107 = $106;
  STACKTOP = sp;return ($107|0);
 }
 $79 = ((($this) + (($59*12)|0)|0) + 36|0);
 $80 = $76 << 2;
 $81 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($79,$80,507688,339)|0);
 $82 = HEAP32[$67>>2]|0;
 $83 = ($82|0)==(0|0);
 if (!($83)) {
  $84 = HEAP32[$68>>2]|0;
  $85 = $84 << 2;
  _memcpy(($81|0),($82|0),($85|0))|0;
  $86 = HEAP32[$68>>2]|0;
  $87 = ($86|0)>(-1);
  if ($87) {
   $88 = HEAP32[$67>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($79,$88);
  }
 }
 $89 = HEAP32[$68>>2]|0;
 $90 = $89 & 2147483647;
 $91 = (($81) + ($90<<2)|0);
 $92 = (($76) - ($89))|0;
 $93 = $92 << 2;
 _memset(($91|0),0,($93|0))|0;
 HEAP32[$67>>2] = $81;
 HEAP32[$68>>2] = $76;
 $$pre = HEAP32[$handle>>2]|0;
 $95 = $$pre;
 $94 = $95 & 31;
 $96 = 1 << $94;
 $97 = $96 ^ -1;
 $98 = $95 >>> 5;
 $99 = HEAP32[$67>>2]|0;
 $100 = (($99) + ($98<<2)|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = $101 & $97;
 HEAP32[$100>>2] = $102;
 $103 = HEAP32[$handle>>2]|0;
 $104 = $103 << 2;
 $105 = $59 | $104;
 $106 = $105 | 2;
 $107 = $106;
 STACKTOP = sp;return ($107|0);
}
function __ZNK5physx2Sq17SceneQueryManager10getPayloadEPKNS0_10ActorShapeE($this,$ref) {
 $this = $this|0;
 $ref = $ref|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $handle = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $handle = sp;
 $0 = $ref;
 $1 = $0 & 1;
 $2 = $0 >>> 2;
 HEAP32[$handle>>2] = $2;
 $3 = ((($this) + ($1<<2)|0) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 4095]($4,$handle)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx2Sq17SceneQueryManager11removeShapeEPNS0_10ActorShapeE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $handle = 0, $index$0$lcssa$i = 0, $index$01$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $handle = sp;
 $0 = $data;
 $1 = $0 & 1;
 $2 = $0 >>> 2;
 HEAP32[$handle>>2] = $2;
 $3 = $0 >>> 7;
 $4 = ((($this) + (($1*12)|0)|0) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($3<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $2 & 31;
 $9 = 1 << $8;
 $10 = $7 & $9;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = $9 ^ -1;
  $13 = $7 & $12;
  HEAP32[$6>>2] = $13;
  $14 = (($this) + 56|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0);
  if (!($16)) {
   $17 = (($this) + 52|0);
   $18 = HEAP32[$17>>2]|0;
   $index$01$i = 0;
   while(1) {
    $21 = (($18) + ($index$01$i<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($data|0);
    $20 = (($index$01$i) + 1)|0;
    if ($23) {
     $index$0$lcssa$i = $index$01$i;
     break;
    }
    $19 = ($20>>>0)<($15>>>0);
    if ($19) {
     $index$01$i = $20;
    } else {
     $index$0$lcssa$i = $20;
     break;
    }
   }
   $24 = ($index$0$lcssa$i|0)==($15|0);
   if (!($24)) {
    $25 = (($15) + -1)|0;
    HEAP32[$14>>2] = $25;
    $26 = (($18) + ($25<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($18) + ($index$0$lcssa$i<<2)|0);
    HEAP32[$28>>2] = $27;
   }
  }
 }
 $29 = ((($this) + ($1<<2)|0) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 $32 = ((($this) + ($1<<2)|0) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_viii[$36 & 4095]($33,$handle,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager17processSimUpdatesEv($this) {
 $this = $this|0;
 var $$in = 0, $$pre = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $actorIterator = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i4 = 0, $i$01$i = 0, $i$01$i3 = 0, $i$07 = 0, $nb$09 = 0, $nb$1$lcssa = 0, $nb$18 = 0, $nb$2 = 0, $nb$3 = 0, $tmpBuffer = 0, $worldAABB$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $worldAABB$i$i1 = sp;
 $actorIterator = sp + 24|0;
 $tmpBuffer = sp + 32|0;
 HEAP32[$actorIterator>>2] = 0;
 $1 = (($actorIterator) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 16|0);
 __ZN5physx2Sc5Scene24initActiveBodiesIteratorERNS0_12BodyIteratorE($4,$actorIterator);
 $5 = (__ZN5physx2Sc12BodyIterator7getNextEv($actorIterator)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $9 = $5;$nb$09 = 0;
  while(1) {
   $10 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($9)|0);
   $$in = (($10) + 20|0);
   $11 = (($$in) + 4|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = ($12<<16>>16)==(1);
   if ($13) {
    $29 = $$in;
   } else {
    $14 = HEAP32[$$in>>2]|0;
    $29 = $14;
   }
   $15 = (($$in) + 8|0);
   $16 = (($$in) + 12|0);
   $17 = HEAP16[$16>>1]|0;
   $18 = ($17<<16>>16)==(1);
   if ($18) {
    $23 = $15;
   } else {
    $19 = HEAP32[$15>>2]|0;
    $23 = $19;
   }
   $20 = ($12<<16>>16)==(0);
   if ($20) {
    $nb$1$lcssa = $nb$09;
   } else {
    $21 = $12&65535;
    $i$07 = 0;$nb$18 = $nb$09;
    while(1) {
     $22 = (($23) + ($i$07<<2)|0);
     $24 = HEAP32[$22>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      $nb$2 = $nb$18;
     } else {
      $26 = (($nb$18) + 1)|0;
      $27 = (($tmpBuffer) + ($nb$18<<2)|0);
      HEAP32[$27>>2] = $24;
      $28 = (($29) + ($i$07<<2)|0);
      $30 = HEAP32[$28>>2]|0;
      $31 = (($30) + 128|0);
      $32 = (($30) + 256|0);
      $nb$2 = $26;
     }
     $33 = ($nb$2|0)==(4);
     if ($33) {
      $i$01$i3 = 0;
      while(1) {
       $34 = (($tmpBuffer) + ($i$01$i3<<2)|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = $35;
       $37 = $36 & 1;
       $38 = $36 >>> 2;
       $39 = $36 >>> 7;
       $40 = ((($this) + (($37*12)|0)|0) + 28|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = (($41) + ($39<<2)|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = $38 & 31;
       $45 = 1 << $44;
       $46 = $45 & $43;
       $47 = ($46|0)==(0);
       if ($47) {
        HEAP32[$0>>2] = $38;
        $48 = ((($this) + ($37<<2)|0) + 12|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = HEAP32[$49>>2]|0;
        $51 = (($50) + 28|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = (FUNCTION_TABLE_iii[$52 & 4095]($49,$0)|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = $54;
        $56 = (($53) + 4|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = $57;
        __ZN5physx2Sq16computeWorldAABBERKNS_3Scb5ShapeERKNS1_5ActorE($worldAABB$i$i1,$55,$58);
        $59 = ((($this) + ($37<<2)|0) + 20|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = (($60) + 1)|0;
        HEAP32[$59>>2] = $61;
        $62 = HEAP32[$48>>2]|0;
        $63 = HEAP32[$62>>2]|0;
        $64 = (($63) + 8|0);
        $65 = HEAP32[$64>>2]|0;
        FUNCTION_TABLE_viiii[$65 & 511]($62,$0,$worldAABB$i$i1,1);
       }
       $66 = (($i$01$i3) + 1)|0;
       $exitcond$i4 = ($66|0)==(4);
       if ($exitcond$i4) {
        $nb$3 = 0;
        break;
       } else {
        $i$01$i3 = $66;
       }
      }
     } else {
      $nb$3 = $nb$2;
     }
     $67 = (($i$07) + 1)|0;
     $exitcond = ($67|0)==($21|0);
     if ($exitcond) {
      $nb$1$lcssa = $nb$3;
      break;
     } else {
      $i$07 = $67;$nb$18 = $nb$3;
     }
    }
   }
   $7 = (__ZN5physx2Sc12BodyIterator7getNextEv($actorIterator)|0);
   $8 = ($7|0)==(0|0);
   if ($8) {
    break;
   } else {
    $9 = $7;$nb$09 = $nb$1$lcssa;
   }
  }
  $68 = ($nb$1$lcssa|0)==(0);
  if (!($68)) {
   $i$01$i = 0;
   while(1) {
    $69 = (($tmpBuffer) + ($i$01$i<<2)|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = $70;
    $72 = $71 & 1;
    $73 = $71 >>> 2;
    $74 = $71 >>> 7;
    $75 = ((($this) + (($72*12)|0)|0) + 28|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = (($76) + ($74<<2)|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = $73 & 31;
    $80 = 1 << $79;
    $81 = $80 & $78;
    $82 = ($81|0)==(0);
    if ($82) {
     HEAP32[$0>>2] = $73;
     $83 = ((($this) + ($72<<2)|0) + 12|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = HEAP32[$84>>2]|0;
     $86 = (($85) + 28|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = (FUNCTION_TABLE_iii[$87 & 4095]($84,$0)|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = $89;
     $91 = (($88) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = $92;
     __ZN5physx2Sq16computeWorldAABBERKNS_3Scb5ShapeERKNS1_5ActorE($worldAABB$i$i1,$90,$93);
     $94 = ((($this) + ($72<<2)|0) + 20|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = (($95) + 1)|0;
     HEAP32[$94>>2] = $96;
     $97 = HEAP32[$83>>2]|0;
     $98 = HEAP32[$97>>2]|0;
     $99 = (($98) + 8|0);
     $100 = HEAP32[$99>>2]|0;
     FUNCTION_TABLE_viiii[$100 & 511]($97,$0,$worldAABB$i$i1,1);
    }
    $101 = (($i$01$i) + 1)|0;
    $exitcond$i = ($101|0)==($nb$1$lcssa|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $101;
    }
   }
  }
 }
 __ZN5physx2Sq17SceneQueryManager11flushShapesEv($this);
 $102 = (($this) + 12|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($this) + 64|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = ($105|0)==(1);
 if ($106) {
  (__ZN5physx2Sq10AABBPruner9buildStepEv($103)|0);
  $$pre = HEAP32[$102>>2]|0;
  $108 = $$pre;
 } else {
  $108 = $103;
 }
 $107 = HEAP32[$108>>2]|0;
 $109 = (($107) + 12|0);
 $110 = HEAP32[$109>>2]|0;
 FUNCTION_TABLE_vi[$110 & 4095]($108);
 $111 = (($this) + 16|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = (($this) + 68|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = ($114|0)==(1);
 if (!($115)) {
  $117 = $112;
  $116 = HEAP32[$117>>2]|0;
  $118 = (($116) + 12|0);
  $119 = HEAP32[$118>>2]|0;
  FUNCTION_TABLE_vi[$119 & 4095]($117);
  STACKTOP = sp;return;
 }
 (__ZN5physx2Sq10AABBPruner9buildStepEv($112)|0);
 $$pre12 = HEAP32[$111>>2]|0;
 $117 = $$pre12;
 $116 = HEAP32[$117>>2]|0;
 $118 = (($116) + 12|0);
 $119 = HEAP32[$118>>2]|0;
 FUNCTION_TABLE_vi[$119 & 4095]($117);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager11flushShapesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $i$01 = 0, $worldAABB$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 24|0;
 $worldAABB$i = sp;
 $1 = (($this) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 52|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($i$01<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7;
  $9 = $8 & 1;
  $10 = $8 >>> 2;
  $11 = $10 & 31;
  $12 = 1 << $11;
  $13 = $12 ^ -1;
  $14 = $8 >>> 7;
  $15 = ((($this) + (($9*12)|0)|0) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($14<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & $13;
  HEAP32[$17>>2] = $19;
  HEAP32[$0>>2] = $10;
  $20 = ((($this) + ($9<<2)|0) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 28|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (FUNCTION_TABLE_iii[$24 & 4095]($21,$0)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26;
  $28 = (($25) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = $29;
  __ZN5physx2Sq16computeWorldAABBERKNS_3Scb5ShapeERKNS1_5ActorE($worldAABB$i,$27,$30);
  $31 = ((($this) + ($9<<2)|0) + 20|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 1)|0;
  HEAP32[$31>>2] = $33;
  $34 = HEAP32[$20>>2]|0;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  FUNCTION_TABLE_viiii[$37 & 511]($34,$0,$worldAABB$i,1);
  $38 = (($i$01) + 1)|0;
  $exitcond = ($38|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $38;
  }
 }
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager12flushUpdatesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1200|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 1192|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiii[$13 & 511]($3,135,$7,$10);
 $14 = (($this) + 80|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($15);
 __ZN5physx2Sq17SceneQueryManager11flushShapesEv($this);
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = HEAP32[$17>>2]|0;
  $20 = (($19) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_vi[$21 & 4095]($17);
 }
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = HEAP32[$23>>2]|0;
  $26 = (($25) + 12|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vi[$27 & 4095]($23);
 }
 $28 = HEAP32[$14>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($28);
 $29 = HEAP32[$3>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_viiii[$31 & 511]($3,135,$7,$10);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager23forceDynamicTreeRebuildEbb($this,$rebuildStaticStructure,$rebuildDynamicStructure) {
 $this = $this|0;
 $rebuildStaticStructure = $rebuildStaticStructure|0;
 $rebuildDynamicStructure = $rebuildDynamicStructure|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1200|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 1192|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiii[$13 & 511]($3,111,$7,$10);
 $14 = (($this) + 80|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($15);
 if ($rebuildStaticStructure) {
  $16 = (($this) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = (($this) + 64|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(1);
   if ($21) {
    __ZN5physx2Sq10AABBPruner5purgeEv($17);
    $22 = HEAP32[$16>>2]|0;
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    FUNCTION_TABLE_vi[$25 & 4095]($22);
   }
  }
 }
 if ($rebuildDynamicStructure) {
  $26 = (($this) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if (!($28)) {
   $29 = (($this) + 68|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(1);
   if ($31) {
    __ZN5physx2Sq10AABBPruner5purgeEv($27);
    $32 = HEAP32[$26>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    FUNCTION_TABLE_vi[$35 & 4095]($32);
   }
  }
 }
 $36 = HEAP32[$14>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($36);
 $37 = HEAP32[$3>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_viiii[$39 & 511]($3,111,$7,$10);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq17SceneQueryManager11shiftOriginERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$shift);
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($6,$shift);
 STACKTOP = sp;return;
}
function __ZNK5physx2Sq17SceneQueryManager10getPxSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx3Scb5Scene10getPxSceneEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx2Sq17SceneQueryManager12freeSPUTasksEPNS_12NpBatchQueryE($this,$bq) {
 $this = $this|0;
 $bq = $bq|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Sq10ActorShapeENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 507872 : 507840;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,507760,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx2Sq13getGlobalPoseERKNS_7NpShapeERKNS_12PxRigidActorE($agg$result,$shape,$actor) {
 $agg$result = $agg$result|0;
 $shape = $shape|0;
 $actor = $actor|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($actor) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ((414264 + ($2<<2)|0) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($actor) + ($4)|0);
 $6 = (($shape) + 32|0);
 __ZN5physx2Sq13getGlobalPoseERKNS_3Scb5ShapeERKNS1_5ActorE($agg$result,$6,$5);
 STACKTOP = sp;return;
}
function __ZN5physx2Sq13getGlobalPoseERKNS_3Scb5ShapeERKNS1_5ActorE($agg$result,$scbShape,$scbActor) {
 $agg$result = $agg$result|0;
 $scbShape = $scbShape|0;
 $scbActor = $scbActor|0;
 var $$in = 0, $$in20 = 0, $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = Math_fround(0);
 var $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0);
 var $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0);
 var $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0);
 var $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0);
 var $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0);
 var $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0);
 var $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0);
 var $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0);
 var $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0);
 var $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0);
 var $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = 0, $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0);
 var $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0);
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0;
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $bodyTarget = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bodyTarget = sp;
 $0 = $scbActor;
 $1 = (($scbActor) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 24;
 $4 = $3 & 15;
 $5 = ((444424 + ($4<<2)|0) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($0))|0;
 $8 = $7;
 $9 = (($8) + 10|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $12 = $2 & 64;
  $13 = ($12|0)==(0);
  if ($13) {
   $21 = (($scbActor) + 32|0);
   $47 = $21;
  } else {
   $14 = (($scbActor) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $17 = HEAP32[$scbActor>>2]|0;
    $18 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($17,$4)|0);
    HEAP32[$14>>2] = $18;
    $20 = $18;
   } else {
    $20 = $15;
   }
   $19 = (($20) + 96|0);
   $47 = $19;
  }
  $22 = (($scbShape) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 4;
  $25 = ($24|0)==(0);
  if ($25) {
   $35 = (($scbShape) + 48|0);
   $37 = $35;
  } else {
   $26 = (($scbShape) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $29 = HEAP32[$scbShape>>2]|0;
    $30 = $23 >>> 24;
    $31 = $30 & 15;
    $32 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($29,$31)|0);
    HEAP32[$26>>2] = $32;
    $34 = $32;
   } else {
    $34 = $27;
   }
   $33 = (($34) + 64|0);
   $37 = $33;
  }
  $36 = (($37) + 16|0);
  $38 = Math_fround(HEAPF32[$36>>2]);
  $39 = Math_fround($38 * Math_fround(2.0));
  $40 = (($37) + 20|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($41 * Math_fround(2.0));
  $43 = (($37) + 24|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($44 * Math_fround(2.0));
  $46 = (($47) + 12|0);
  $48 = Math_fround(HEAPF32[$46>>2]);
  $49 = Math_fround($48 * $48);
  $50 = Math_fround($49 + Math_fround(-0.5));
  $51 = Math_fround(HEAPF32[$47>>2]);
  $52 = Math_fround($39 * $51);
  $53 = (($47) + 4|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($42 * $54);
  $56 = Math_fround($52 + $55);
  $57 = (($47) + 8|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($45 * $58);
  $60 = Math_fround($56 + $59);
  $61 = Math_fround($39 * $50);
  $62 = Math_fround($45 * $54);
  $63 = Math_fround($42 * $58);
  $64 = Math_fround($62 - $63);
  $65 = Math_fround($48 * $64);
  $66 = Math_fround($61 + $65);
  $67 = Math_fround($51 * $60);
  $68 = Math_fround($67 + $66);
  $69 = Math_fround($42 * $50);
  $70 = Math_fround($39 * $58);
  $71 = Math_fround($45 * $51);
  $72 = Math_fround($70 - $71);
  $73 = Math_fround($48 * $72);
  $74 = Math_fround($69 + $73);
  $75 = Math_fround($54 * $60);
  $76 = Math_fround($75 + $74);
  $77 = Math_fround($45 * $50);
  $78 = Math_fround($42 * $51);
  $79 = Math_fround($39 * $54);
  $80 = Math_fround($78 - $79);
  $81 = Math_fround($48 * $80);
  $82 = Math_fround($77 + $81);
  $83 = Math_fround($58 * $60);
  $84 = Math_fround($82 + $83);
  $85 = (($47) + 16|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround($86 + $68);
  $88 = (($47) + 20|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = Math_fround($89 + $76);
  $91 = (($47) + 24|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = Math_fround($92 + $84);
  $94 = Math_fround(HEAPF32[$37>>2]);
  $95 = Math_fround($48 * $94);
  $96 = (($37) + 12|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = Math_fround($51 * $97);
  $99 = Math_fround($95 + $98);
  $100 = (($37) + 8|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $102 = Math_fround($54 * $101);
  $103 = Math_fround($99 + $102);
  $104 = (($37) + 4|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($58 * $105);
  $107 = Math_fround($103 - $106);
  $108 = Math_fround($48 * $105);
  $109 = Math_fround($54 * $97);
  $110 = Math_fround($109 + $108);
  $111 = Math_fround($58 * $94);
  $112 = Math_fround($111 + $110);
  $113 = Math_fround($51 * $101);
  $114 = Math_fround($112 - $113);
  $115 = Math_fround($48 * $101);
  $116 = Math_fround($58 * $97);
  $117 = Math_fround($116 + $115);
  $118 = Math_fround($51 * $105);
  $119 = Math_fround($118 + $117);
  $120 = Math_fround($54 * $94);
  $121 = Math_fround($119 - $120);
  $122 = Math_fround($48 * $97);
  $123 = Math_fround($51 * $94);
  $124 = Math_fround($122 - $123);
  $125 = Math_fround($54 * $105);
  $126 = Math_fround($124 - $125);
  $127 = Math_fround($58 * $101);
  $128 = Math_fround($126 - $127);
  HEAPF32[$agg$result>>2] = $107;
  $129 = (($agg$result) + 4|0);
  HEAPF32[$129>>2] = $114;
  $130 = (($agg$result) + 8|0);
  HEAPF32[$130>>2] = $121;
  $131 = (($agg$result) + 12|0);
  HEAPF32[$131>>2] = $128;
  $132 = (($agg$result) + 16|0);
  HEAPF32[$132>>2] = $87;
  $133 = (($agg$result) + 20|0);
  HEAPF32[$133>>2] = $90;
  $134 = (($agg$result) + 24|0);
  HEAPF32[$134>>2] = $93;
  STACKTOP = sp;return;
 }
 $135 = (($scbActor) + 236|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = $136 & 4096;
 $138 = ($137|0)==(0);
 if ($138) {
  $146 = (($scbActor) + 60|0);
  $$in = $146;
 } else {
  $139 = (($scbActor) + 8|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = ($140|0)==(0|0);
  if ($141) {
   $142 = HEAP32[$scbActor>>2]|0;
   $143 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($142,$4)|0);
   HEAP32[$139>>2] = $143;
   $145 = $143;
  } else {
   $145 = $140;
  }
  $144 = (($145) + 268|0);
  $$in = $144;
 }
 $147 = HEAP8[$$in>>0]|0;
 $148 = $147 & 1;
 $149 = ($148<<24>>24)==(0);
 do {
  if ($149) {
   $150 = (($scbActor) + 176|0);
   $151 = Math_fround(HEAPF32[$150>>2]);
   $152 = (($150) + 4|0);
   $153 = Math_fround(HEAPF32[$152>>2]);
   $154 = (($150) + 8|0);
   $155 = Math_fround(HEAPF32[$154>>2]);
   $156 = (($150) + 12|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $158 = (($150) + 16|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = (($150) + 20|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = (($150) + 24|0);
   $163 = Math_fround(HEAPF32[$162>>2]);
   $313 = $157;$316 = $151;$318 = $153;$321 = $155;$348 = $159;$350 = $161;$352 = $163;
  } else {
   $164 = HEAP32[$135>>2]|0;
   $165 = $164 & 8192;
   $166 = ($165|0)==(0);
   if ($166) {
    $196 = HEAP32[$1>>2]|0;
    $$mask$i = $196 & -1073741824;
    $197 = ($$mask$i|0)==(-1073741824);
    if (!($197)) {
     $198 = (($scbActor) + 16|0);
     $199 = (__ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($198,$bodyTarget)|0);
     if ($199) {
      label = 26;
     }
    }
   } else {
    $167 = (($scbActor) + 8|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = ($168|0)==(0|0);
    if ($169) {
     $170 = HEAP32[$scbActor>>2]|0;
     $171 = HEAP32[$1>>2]|0;
     $172 = $171 >>> 24;
     $173 = $172 & 15;
     $174 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($170,$173)|0);
     HEAP32[$167>>2] = $174;
     $176 = $174;
    } else {
     $176 = $168;
    }
    $175 = (($176) + 192|0);
    $177 = Math_fround(HEAPF32[$175>>2]);
    HEAPF32[$bodyTarget>>2] = $177;
    $178 = (($176) + 196|0);
    $179 = Math_fround(HEAPF32[$178>>2]);
    $180 = (($bodyTarget) + 4|0);
    HEAPF32[$180>>2] = $179;
    $181 = (($176) + 200|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = (($bodyTarget) + 8|0);
    HEAPF32[$183>>2] = $182;
    $184 = (($176) + 204|0);
    $185 = Math_fround(HEAPF32[$184>>2]);
    $186 = (($bodyTarget) + 12|0);
    HEAPF32[$186>>2] = $185;
    $187 = (($176) + 208|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = (($bodyTarget) + 16|0);
    HEAPF32[$189>>2] = $188;
    $190 = (($176) + 212|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = (($bodyTarget) + 20|0);
    HEAPF32[$192>>2] = $191;
    $193 = (($176) + 216|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = (($bodyTarget) + 24|0);
    HEAPF32[$195>>2] = $194;
    label = 26;
   }
   if ((label|0) == 26) {
    $200 = HEAP32[$135>>2]|0;
    $201 = $200 & 4096;
    $202 = ($201|0)==(0);
    if ($202) {
     $213 = (($scbActor) + 60|0);
     $$in20 = $213;
    } else {
     $203 = (($scbActor) + 8|0);
     $204 = HEAP32[$203>>2]|0;
     $205 = ($204|0)==(0|0);
     if ($205) {
      $206 = HEAP32[$scbActor>>2]|0;
      $207 = HEAP32[$1>>2]|0;
      $208 = $207 >>> 24;
      $209 = $208 & 15;
      $210 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($206,$209)|0);
      HEAP32[$203>>2] = $210;
      $212 = $210;
     } else {
      $212 = $204;
     }
     $211 = (($212) + 268|0);
     $$in20 = $211;
    }
    $214 = HEAP8[$$in20>>0]|0;
    $215 = $214 & 2;
    $216 = ($215<<24>>24)==(0);
    if (!($216)) {
     $231 = Math_fround(HEAPF32[$bodyTarget>>2]);
     $232 = (($bodyTarget) + 4|0);
     $233 = Math_fround(HEAPF32[$232>>2]);
     $234 = (($bodyTarget) + 8|0);
     $235 = Math_fround(HEAPF32[$234>>2]);
     $236 = (($bodyTarget) + 12|0);
     $237 = Math_fround(HEAPF32[$236>>2]);
     $238 = (($bodyTarget) + 16|0);
     $239 = Math_fround(HEAPF32[$238>>2]);
     $240 = (($bodyTarget) + 20|0);
     $241 = Math_fround(HEAPF32[$240>>2]);
     $242 = (($bodyTarget) + 24|0);
     $243 = Math_fround(HEAPF32[$242>>2]);
     $313 = $237;$316 = $231;$318 = $233;$321 = $235;$348 = $239;$350 = $241;$352 = $243;
     break;
    }
   }
   $217 = (($scbActor) + 176|0);
   $218 = Math_fround(HEAPF32[$217>>2]);
   $219 = (($217) + 4|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = (($217) + 8|0);
   $222 = Math_fround(HEAPF32[$221>>2]);
   $223 = (($217) + 12|0);
   $224 = Math_fround(HEAPF32[$223>>2]);
   $225 = (($217) + 16|0);
   $226 = Math_fround(HEAPF32[$225>>2]);
   $227 = (($217) + 20|0);
   $228 = Math_fround(HEAPF32[$227>>2]);
   $229 = (($217) + 24|0);
   $230 = Math_fround(HEAPF32[$229>>2]);
   $313 = $224;$316 = $218;$318 = $220;$321 = $222;$348 = $226;$350 = $228;$352 = $230;
  }
 } while(0);
 $244 = HEAP32[$135>>2]|0;
 $245 = $244 & 512;
 $246 = ($245|0)==(0);
 if ($246) {
  $257 = (($scbActor) + 64|0);
  $259 = $257;
 } else {
  $247 = (($scbActor) + 8|0);
  $248 = HEAP32[$247>>2]|0;
  $249 = ($248|0)==(0|0);
  if ($249) {
   $250 = HEAP32[$scbActor>>2]|0;
   $251 = HEAP32[$1>>2]|0;
   $252 = $251 >>> 24;
   $253 = $252 & 15;
   $254 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($250,$253)|0);
   HEAP32[$247>>2] = $254;
   $256 = $254;
  } else {
   $256 = $248;
  }
  $255 = (($256) + 144|0);
  $259 = $255;
 }
 $258 = (($259) + 16|0);
 $260 = Math_fround(HEAPF32[$258>>2]);
 $261 = (($259) + 20|0);
 $262 = Math_fround(HEAPF32[$261>>2]);
 $263 = (($259) + 24|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = Math_fround($260 * Math_fround(-2.0));
 $266 = Math_fround($262 * Math_fround(-2.0));
 $267 = Math_fround($264 * Math_fround(-2.0));
 $268 = (($259) + 12|0);
 $269 = Math_fround(HEAPF32[$268>>2]);
 $270 = Math_fround($269 * $269);
 $271 = Math_fround($270 + Math_fround(-0.5));
 $272 = Math_fround(HEAPF32[$259>>2]);
 $273 = Math_fround($265 * $272);
 $274 = (($259) + 4|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = Math_fround($266 * $275);
 $277 = Math_fround($273 + $276);
 $278 = (($259) + 8|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = Math_fround($267 * $279);
 $281 = Math_fround($277 + $280);
 $282 = Math_fround($265 * $271);
 $283 = Math_fround($267 * $275);
 $284 = Math_fround($266 * $279);
 $285 = Math_fround($283 - $284);
 $286 = Math_fround($269 * $285);
 $287 = Math_fround($282 - $286);
 $288 = Math_fround($272 * $281);
 $289 = Math_fround($288 + $287);
 $290 = Math_fround($266 * $271);
 $291 = Math_fround($265 * $279);
 $292 = Math_fround($267 * $272);
 $293 = Math_fround($291 - $292);
 $294 = Math_fround($269 * $293);
 $295 = Math_fround($290 - $294);
 $296 = Math_fround($275 * $281);
 $297 = Math_fround($296 + $295);
 $298 = Math_fround($267 * $271);
 $299 = Math_fround($266 * $272);
 $300 = Math_fround($265 * $275);
 $301 = Math_fround($299 - $300);
 $302 = Math_fround($269 * $301);
 $303 = Math_fround($298 - $302);
 $304 = Math_fround($279 * $281);
 $305 = Math_fround($303 + $304);
 $306 = Math_fround(-$272);
 $307 = Math_fround(-$275);
 $308 = Math_fround(-$279);
 $309 = Math_fround($289 * Math_fround(2.0));
 $310 = Math_fround($297 * Math_fround(2.0));
 $311 = Math_fround($305 * Math_fround(2.0));
 $312 = Math_fround($313 * $313);
 $314 = Math_fround($312 + Math_fround(-0.5));
 $315 = Math_fround($316 * $309);
 $317 = Math_fround($318 * $310);
 $319 = Math_fround($315 + $317);
 $320 = Math_fround($321 * $311);
 $322 = Math_fround($320 + $319);
 $323 = Math_fround($314 * $309);
 $324 = Math_fround($318 * $311);
 $325 = Math_fround($321 * $310);
 $326 = Math_fround($324 - $325);
 $327 = Math_fround($313 * $326);
 $328 = Math_fround($323 + $327);
 $329 = Math_fround($316 * $322);
 $330 = Math_fround($329 + $328);
 $331 = Math_fround($314 * $310);
 $332 = Math_fround($321 * $309);
 $333 = Math_fround($316 * $311);
 $334 = Math_fround($332 - $333);
 $335 = Math_fround($313 * $334);
 $336 = Math_fround($331 + $335);
 $337 = Math_fround($318 * $322);
 $338 = Math_fround($337 + $336);
 $339 = Math_fround($314 * $311);
 $340 = Math_fround($316 * $310);
 $341 = Math_fround($318 * $309);
 $342 = Math_fround($340 - $341);
 $343 = Math_fround($313 * $342);
 $344 = Math_fround($339 + $343);
 $345 = Math_fround($321 * $322);
 $346 = Math_fround($344 + $345);
 $347 = Math_fround($348 + $330);
 $349 = Math_fround($350 + $338);
 $351 = Math_fround($352 + $346);
 $353 = Math_fround($313 * $306);
 $354 = Math_fround($316 * $269);
 $355 = Math_fround($354 + $353);
 $356 = Math_fround($318 * $308);
 $357 = Math_fround($355 + $356);
 $358 = Math_fround($321 * $307);
 $359 = Math_fround($357 - $358);
 $360 = Math_fround($313 * $307);
 $361 = Math_fround($318 * $269);
 $362 = Math_fround($361 + $360);
 $363 = Math_fround($321 * $306);
 $364 = Math_fround($363 + $362);
 $365 = Math_fround($316 * $308);
 $366 = Math_fround($364 - $365);
 $367 = Math_fround($313 * $308);
 $368 = Math_fround($321 * $269);
 $369 = Math_fround($368 + $367);
 $370 = Math_fround($316 * $307);
 $371 = Math_fround($370 + $369);
 $372 = Math_fround($318 * $306);
 $373 = Math_fround($371 - $372);
 $374 = Math_fround($313 * $269);
 $375 = Math_fround($316 * $306);
 $376 = Math_fround($374 - $375);
 $377 = Math_fround($318 * $307);
 $378 = Math_fround($376 - $377);
 $379 = Math_fround($321 * $308);
 $380 = Math_fround($378 - $379);
 $381 = (($scbShape) + 4|0);
 $382 = HEAP32[$381>>2]|0;
 $383 = $382 & 4;
 $384 = ($383|0)==(0);
 if ($384) {
  $394 = (($scbShape) + 48|0);
  $396 = $394;
 } else {
  $385 = (($scbShape) + 8|0);
  $386 = HEAP32[$385>>2]|0;
  $387 = ($386|0)==(0|0);
  if ($387) {
   $388 = HEAP32[$scbShape>>2]|0;
   $389 = $382 >>> 24;
   $390 = $389 & 15;
   $391 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($388,$390)|0);
   HEAP32[$385>>2] = $391;
   $393 = $391;
  } else {
   $393 = $386;
  }
  $392 = (($393) + 64|0);
  $396 = $392;
 }
 $395 = (($396) + 16|0);
 $397 = Math_fround(HEAPF32[$395>>2]);
 $398 = Math_fround($397 * Math_fround(2.0));
 $399 = (($396) + 20|0);
 $400 = Math_fround(HEAPF32[$399>>2]);
 $401 = Math_fround($400 * Math_fround(2.0));
 $402 = (($396) + 24|0);
 $403 = Math_fround(HEAPF32[$402>>2]);
 $404 = Math_fround($403 * Math_fround(2.0));
 $405 = Math_fround($380 * $380);
 $406 = Math_fround($405 + Math_fround(-0.5));
 $407 = Math_fround($359 * $398);
 $408 = Math_fround($366 * $401);
 $409 = Math_fround($407 + $408);
 $410 = Math_fround($373 * $404);
 $411 = Math_fround($409 + $410);
 $412 = Math_fround($406 * $398);
 $413 = Math_fround($366 * $404);
 $414 = Math_fround($373 * $401);
 $415 = Math_fround($413 - $414);
 $416 = Math_fround($380 * $415);
 $417 = Math_fround($412 + $416);
 $418 = Math_fround($359 * $411);
 $419 = Math_fround($418 + $417);
 $420 = Math_fround($406 * $401);
 $421 = Math_fround($373 * $398);
 $422 = Math_fround($359 * $404);
 $423 = Math_fround($421 - $422);
 $424 = Math_fround($380 * $423);
 $425 = Math_fround($420 + $424);
 $426 = Math_fround($366 * $411);
 $427 = Math_fround($426 + $425);
 $428 = Math_fround($406 * $404);
 $429 = Math_fround($359 * $401);
 $430 = Math_fround($366 * $398);
 $431 = Math_fround($429 - $430);
 $432 = Math_fround($380 * $431);
 $433 = Math_fround($428 + $432);
 $434 = Math_fround($373 * $411);
 $435 = Math_fround($433 + $434);
 $436 = Math_fround($347 + $419);
 $437 = Math_fround($349 + $427);
 $438 = Math_fround($351 + $435);
 $439 = Math_fround(HEAPF32[$396>>2]);
 $440 = Math_fround($380 * $439);
 $441 = (($396) + 12|0);
 $442 = Math_fround(HEAPF32[$441>>2]);
 $443 = Math_fround($359 * $442);
 $444 = Math_fround($440 + $443);
 $445 = (($396) + 8|0);
 $446 = Math_fround(HEAPF32[$445>>2]);
 $447 = Math_fround($366 * $446);
 $448 = Math_fround($444 + $447);
 $449 = (($396) + 4|0);
 $450 = Math_fround(HEAPF32[$449>>2]);
 $451 = Math_fround($373 * $450);
 $452 = Math_fround($448 - $451);
 $453 = Math_fround($380 * $450);
 $454 = Math_fround($366 * $442);
 $455 = Math_fround($454 + $453);
 $456 = Math_fround($373 * $439);
 $457 = Math_fround($456 + $455);
 $458 = Math_fround($359 * $446);
 $459 = Math_fround($457 - $458);
 $460 = Math_fround($380 * $446);
 $461 = Math_fround($373 * $442);
 $462 = Math_fround($461 + $460);
 $463 = Math_fround($359 * $450);
 $464 = Math_fround($463 + $462);
 $465 = Math_fround($366 * $439);
 $466 = Math_fround($464 - $465);
 $467 = Math_fround($380 * $442);
 $468 = Math_fround($359 * $439);
 $469 = Math_fround($467 - $468);
 $470 = Math_fround($366 * $450);
 $471 = Math_fround($469 - $470);
 $472 = Math_fround($373 * $446);
 $473 = Math_fround($471 - $472);
 HEAPF32[$agg$result>>2] = $452;
 $474 = (($agg$result) + 4|0);
 HEAPF32[$474>>2] = $459;
 $475 = (($agg$result) + 8|0);
 HEAPF32[$475>>2] = $466;
 $476 = (($agg$result) + 12|0);
 HEAPF32[$476>>2] = $473;
 $477 = (($agg$result) + 16|0);
 HEAPF32[$477>>2] = $436;
 $478 = (($agg$result) + 20|0);
 HEAPF32[$478>>2] = $437;
 $479 = (($agg$result) + 24|0);
 HEAPF32[$479>>2] = $438;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq16computeWorldAABBERKNS_3Scb5ShapeERKNS1_5ActorE($agg$result,$scbShape,$scbActor) {
 $agg$result = $agg$result|0;
 $scbShape = $scbShape|0;
 $scbActor = $scbActor|0;
 var $$0$i = 0, $$in = 0, $$mask$i = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0);
 var $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0);
 var $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $globalPose = 0, $kinematicTarget = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $globalPose = sp + 32|0;
 $kinematicTarget = sp;
 $0 = sp + 64|0;
 $1 = $scbActor;
 $2 = (($scbActor) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 24;
 $5 = $4 & 15;
 $6 = ((444424 + ($5<<2)|0) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1))|0;
 $9 = $8;
 $10 = (($9) + 10|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = (($scbShape) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 1;
 $15 = ($14|0)==(0);
 if ($15) {
  $23 = (($scbShape) + 84|0);
  $$0$i = $23;$25 = $13;
 } else {
  $16 = (($scbShape) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = HEAP32[$scbShape>>2]|0;
   $20 = $13 >>> 24;
   $21 = $20 & 15;
   $22 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($19,$21)|0);
   HEAP32[$16>>2] = $22;
   $$pre$pre = HEAP32[$12>>2]|0;
   $$pre = $$pre$pre;$252 = $22;
  } else {
   $$pre = $13;$252 = $17;
  }
  $$0$i = $252;$25 = $$pre;
 }
 $24 = $25 & 4;
 $26 = ($24|0)==(0);
 if ($26) {
  $36 = (($scbShape) + 48|0);
  $66 = $36;
 } else {
  $27 = (($scbShape) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if ($29) {
   $30 = HEAP32[$scbShape>>2]|0;
   $31 = $25 >>> 24;
   $32 = $31 & 15;
   $33 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($30,$32)|0);
   HEAP32[$27>>2] = $33;
   $35 = $33;
  } else {
   $35 = $28;
  }
  $34 = (($35) + 64|0);
  $66 = $34;
 }
 $37 = ($11<<24>>24)==(0);
 if ($37) {
  $38 = HEAP32[$2>>2]|0;
  $39 = $38 & 64;
  $40 = ($39|0)==(0);
  if ($40) {
   $50 = (($scbActor) + 32|0);
   $52 = $50;
  } else {
   $41 = (($scbActor) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    $44 = HEAP32[$scbActor>>2]|0;
    $45 = $38 >>> 24;
    $46 = $45 & 15;
    $47 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($44,$46)|0);
    HEAP32[$41>>2] = $47;
    $49 = $47;
   } else {
    $49 = $42;
   }
   $48 = (($49) + 96|0);
   $52 = $48;
  }
  $51 = (($52) + 16|0);
  $53 = Math_fround(HEAPF32[$51>>2]);
  $54 = (($52) + 20|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($52) + 24|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround(HEAPF32[$52>>2]);
  $59 = (($52) + 4|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($52) + 8|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = (($52) + 12|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($66) + 16|0);
  $67 = Math_fround(HEAPF32[$65>>2]);
  $68 = (($66) + 20|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($66) + 24|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = Math_fround(HEAPF32[$66>>2]);
  $73 = (($66) + 4|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($66) + 8|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($66) + 12|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($64 * $78);
  $80 = Math_fround($58 * $72);
  $81 = Math_fround($60 * $74);
  $82 = Math_fround($80 + $81);
  $83 = Math_fround($62 * $76);
  $84 = Math_fround($82 + $83);
  $85 = Math_fround($79 - $84);
  $86 = Math_fround($60 * $76);
  $87 = Math_fround($62 * $74);
  $88 = Math_fround($86 - $87);
  $89 = Math_fround($62 * $72);
  $90 = Math_fround($58 * $76);
  $91 = Math_fround($89 - $90);
  $92 = Math_fround($58 * $74);
  $93 = Math_fround($60 * $72);
  $94 = Math_fround($92 - $93);
  $95 = Math_fround($64 * $72);
  $96 = Math_fround($64 * $74);
  $97 = Math_fround($64 * $76);
  $98 = Math_fround($95 + $88);
  $99 = Math_fround($96 + $91);
  $100 = Math_fround($97 + $94);
  $101 = Math_fround($58 * $78);
  $102 = Math_fround($60 * $78);
  $103 = Math_fround($62 * $78);
  $104 = Math_fround($101 + $98);
  $105 = Math_fround($102 + $99);
  $106 = Math_fround($103 + $100);
  $107 = Math_fround($64 * $64);
  $108 = Math_fround($107 + Math_fround(-0.5));
  $109 = Math_fround($67 * $108);
  $110 = Math_fround($69 * $108);
  $111 = Math_fround($108 * $71);
  $112 = Math_fround($60 * $71);
  $113 = Math_fround($62 * $69);
  $114 = Math_fround($112 - $113);
  $115 = Math_fround($62 * $67);
  $116 = Math_fround($58 * $71);
  $117 = Math_fround($115 - $116);
  $118 = Math_fround($58 * $69);
  $119 = Math_fround($60 * $67);
  $120 = Math_fround($118 - $119);
  $121 = Math_fround($64 * $114);
  $122 = Math_fround($64 * $117);
  $123 = Math_fround($64 * $120);
  $124 = Math_fround($109 + $121);
  $125 = Math_fround($110 + $122);
  $126 = Math_fround($111 + $123);
  $127 = Math_fround($58 * $67);
  $128 = Math_fround($60 * $69);
  $129 = Math_fround($127 + $128);
  $130 = Math_fround($62 * $71);
  $131 = Math_fround($129 + $130);
  $132 = Math_fround($58 * $131);
  $133 = Math_fround($60 * $131);
  $134 = Math_fround($62 * $131);
  $135 = Math_fround($132 + $124);
  $136 = Math_fround($133 + $125);
  $137 = Math_fround($126 + $134);
  $138 = Math_fround($135 * Math_fround(2.0));
  $139 = Math_fround($136 * Math_fround(2.0));
  $140 = Math_fround($137 * Math_fround(2.0));
  $141 = Math_fround($53 + $138);
  $142 = Math_fround($55 + $139);
  $143 = Math_fround($57 + $140);
  $144 = (($globalPose) + 16|0);
  HEAPF32[$144>>2] = $141;
  $145 = (($globalPose) + 20|0);
  HEAPF32[$145>>2] = $142;
  $146 = (($globalPose) + 24|0);
  HEAPF32[$146>>2] = $143;
  HEAPF32[$globalPose>>2] = $104;
  $147 = (($globalPose) + 4|0);
  HEAPF32[$147>>2] = $105;
  $148 = (($globalPose) + 8|0);
  HEAPF32[$148>>2] = $106;
  $149 = (($globalPose) + 12|0);
  HEAPF32[$149>>2] = $85;
  __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($$0$i,$0,$globalPose,Math_fround(0.0),0);
  $221 = (($0) + 12|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  $223 = Math_fround(HEAPF32[$0>>2]);
  $224 = Math_fround($222 - $223);
  $225 = (($0) + 16|0);
  $226 = Math_fround(HEAPF32[$225>>2]);
  $227 = (($0) + 4|0);
  $228 = Math_fround(HEAPF32[$227>>2]);
  $229 = Math_fround($226 - $228);
  $230 = (($0) + 20|0);
  $231 = Math_fround(HEAPF32[$230>>2]);
  $232 = (($0) + 8|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = Math_fround($231 - $233);
  $235 = Math_fround($224 * Math_fround(0.5));
  $236 = Math_fround($229 * Math_fround(0.5));
  $237 = Math_fround($234 * Math_fround(0.5));
  $238 = Math_fround($235 * Math_fround(0.00999999977648258209228));
  $239 = Math_fround($236 * Math_fround(0.00999999977648258209228));
  $240 = Math_fround($237 * Math_fround(0.00999999977648258209228));
  $241 = Math_fround($223 - $238);
  $242 = Math_fround($228 - $239);
  $243 = Math_fround($233 - $240);
  $244 = Math_fround($222 + $238);
  $245 = Math_fround($226 + $239);
  $246 = Math_fround($231 + $240);
  HEAPF32[$agg$result>>2] = $241;
  $247 = (($agg$result) + 4|0);
  HEAPF32[$247>>2] = $242;
  $248 = (($agg$result) + 8|0);
  HEAPF32[$248>>2] = $243;
  $249 = (($agg$result) + 12|0);
  HEAPF32[$249>>2] = $244;
  $250 = (($agg$result) + 16|0);
  HEAPF32[$250>>2] = $245;
  $251 = (($agg$result) + 20|0);
  HEAPF32[$251>>2] = $246;
  STACKTOP = sp;return;
 }
 $150 = (($scbActor) + 236|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = $151 & 4096;
 $153 = ($152|0)==(0);
 if ($153) {
  $164 = (($scbActor) + 60|0);
  $$in = $164;
 } else {
  $154 = (($scbActor) + 8|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = ($155|0)==(0|0);
  if ($156) {
   $157 = HEAP32[$scbActor>>2]|0;
   $158 = HEAP32[$2>>2]|0;
   $159 = $158 >>> 24;
   $160 = $159 & 15;
   $161 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($157,$160)|0);
   HEAP32[$154>>2] = $161;
   $163 = $161;
  } else {
   $163 = $155;
  }
  $162 = (($163) + 268|0);
  $$in = $162;
 }
 $165 = HEAP8[$$in>>0]|0;
 $166 = $165 & 3;
 $167 = ($166<<24>>24)==(3);
 do {
  if ($167) {
   $168 = HEAP32[$150>>2]|0;
   $169 = $168 & 8192;
   $170 = ($169|0)==(0);
   if ($170) {
    $200 = HEAP32[$2>>2]|0;
    $$mask$i = $200 & -1073741824;
    $201 = ($$mask$i|0)==(-1073741824);
    if ($201) {
     label = 30;
     break;
    }
    $202 = (($scbActor) + 16|0);
    $203 = (__ZNK5physx2Sc8BodyCore18getKinematicTargetERNS_11PxTransformE($202,$kinematicTarget)|0);
    if ($203) {
     $219 = $kinematicTarget;
     break;
    } else {
     label = 30;
     break;
    }
   }
   $171 = (($scbActor) + 8|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = ($172|0)==(0|0);
   if ($173) {
    $174 = HEAP32[$scbActor>>2]|0;
    $175 = HEAP32[$2>>2]|0;
    $176 = $175 >>> 24;
    $177 = $176 & 15;
    $178 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($174,$177)|0);
    HEAP32[$171>>2] = $178;
    $180 = $178;
   } else {
    $180 = $172;
   }
   $179 = (($180) + 192|0);
   $181 = Math_fround(HEAPF32[$179>>2]);
   HEAPF32[$kinematicTarget>>2] = $181;
   $182 = (($180) + 196|0);
   $183 = Math_fround(HEAPF32[$182>>2]);
   $184 = (($kinematicTarget) + 4|0);
   HEAPF32[$184>>2] = $183;
   $185 = (($180) + 200|0);
   $186 = Math_fround(HEAPF32[$185>>2]);
   $187 = (($kinematicTarget) + 8|0);
   HEAPF32[$187>>2] = $186;
   $188 = (($180) + 204|0);
   $189 = Math_fround(HEAPF32[$188>>2]);
   $190 = (($kinematicTarget) + 12|0);
   HEAPF32[$190>>2] = $189;
   $191 = (($180) + 208|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = (($kinematicTarget) + 16|0);
   HEAPF32[$193>>2] = $192;
   $194 = (($180) + 212|0);
   $195 = Math_fround(HEAPF32[$194>>2]);
   $196 = (($kinematicTarget) + 20|0);
   HEAPF32[$196>>2] = $195;
   $197 = (($180) + 216|0);
   $198 = Math_fround(HEAPF32[$197>>2]);
   $199 = (($kinematicTarget) + 24|0);
   HEAPF32[$199>>2] = $198;
   $219 = $kinematicTarget;
  } else {
   label = 30;
  }
 } while(0);
 if ((label|0) == 30) {
  $204 = (($scbActor) + 176|0);
  $219 = $204;
 }
 $205 = HEAP32[$150>>2]|0;
 $206 = $205 & 512;
 $207 = ($206|0)==(0);
 if ($207) {
  $218 = (($scbActor) + 64|0);
  $220 = $218;
 } else {
  $208 = (($scbActor) + 8|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = ($209|0)==(0|0);
  if ($210) {
   $211 = HEAP32[$scbActor>>2]|0;
   $212 = HEAP32[$2>>2]|0;
   $213 = $212 >>> 24;
   $214 = $213 & 15;
   $215 = (__ZN5physx3Scb5Scene9getStreamENS_7ScbType4EnumE($211,$214)|0);
   HEAP32[$208>>2] = $215;
   $217 = $215;
  } else {
   $217 = $209;
  }
  $216 = (($217) + 144|0);
  $220 = $216;
 }
 __ZN5physx2Cm27getDynamicGlobalPoseAlignedERKNS_11PxTransformES3_S3_RS1_($219,$66,$220,$globalPose);
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($$0$i,$0,$globalPose,Math_fround(0.0),0);
 $221 = (($0) + 12|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = Math_fround(HEAPF32[$0>>2]);
 $224 = Math_fround($222 - $223);
 $225 = (($0) + 16|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = (($0) + 4|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 $229 = Math_fround($226 - $228);
 $230 = (($0) + 20|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($0) + 8|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = Math_fround($231 - $233);
 $235 = Math_fround($224 * Math_fround(0.5));
 $236 = Math_fround($229 * Math_fround(0.5));
 $237 = Math_fround($234 * Math_fround(0.5));
 $238 = Math_fround($235 * Math_fround(0.00999999977648258209228));
 $239 = Math_fround($236 * Math_fround(0.00999999977648258209228));
 $240 = Math_fround($237 * Math_fround(0.00999999977648258209228));
 $241 = Math_fround($223 - $238);
 $242 = Math_fround($228 - $239);
 $243 = Math_fround($233 - $240);
 $244 = Math_fround($222 + $238);
 $245 = Math_fround($226 + $239);
 $246 = Math_fround($231 + $240);
 HEAPF32[$agg$result>>2] = $241;
 $247 = (($agg$result) + 4|0);
 HEAPF32[$247>>2] = $242;
 $248 = (($agg$result) + 8|0);
 HEAPF32[$248>>2] = $243;
 $249 = (($agg$result) + 12|0);
 HEAPF32[$249>>2] = $244;
 $250 = (($agg$result) + 16|0);
 HEAPF32[$250>>2] = $245;
 $251 = (($agg$result) + 20|0);
 HEAPF32[$251>>2] = $246;
 STACKTOP = sp;return;
}
function __ZN5physx2Sq8populateEPKNS0_10ActorShapeE($p) {
 $p = $p|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($p|0);
}
function __ZN5physx2Sq8populateERKNS0_13PrunerPayloadERNS0_13PxActorShape2E($payload,$as) {
 $payload = $payload|0;
 $as = $as|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$payload>>2]|0;
 $1 = $0;
 $2 = (($as) + 8|0);
 HEAP32[$2>>2] = $1;
 $3 = (($payload) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = (($as) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = ($4|0)==(0);
 if ($7) {
  $17 = 0;$19 = $1;
 } else {
  $8 = (($5) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 >>> 24;
  $11 = $10 & 15;
  $12 = ((444424 + ($11<<2)|0) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($4))|0;
  $15 = $14;
  $16 = (__ZNK5physx2Sc9RigidCore10getPxActorEv($15)|0);
  $$pre = HEAP32[$2>>2]|0;
  $17 = $16;$19 = $$pre;
 }
 HEAP32[$as>>2] = $17;
 $18 = ($19|0)==(0|0);
 if ($18) {
  $23 = 0;
  $22 = (($as) + 4|0);
  HEAP32[$22>>2] = $23;
  STACKTOP = sp;return;
 }
 $20 = (($19) + 16|0);
 $21 = (__ZNK5physx2Sc9ShapeCore10getPxShapeEv($20)|0);
 $23 = $21;
 $22 = (($as) + 4|0);
 HEAP32[$22>>2] = $23;
 STACKTOP = sp;return;
}
function __ZNK5physx27PxVehicleDifferentialNWData16getIsDrivenWheelEj($this,$wheelId) {
 $this = $this|0;
 $wheelId = $wheelId|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wheelId >>> 5;
 $1 = (($this) + ($0<<2)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $wheelId & 31;
 $4 = 1 << $3;
 $5 = $2 & $4;
 $6 = ($5|0)!=(0);
 STACKTOP = sp;return ($6|0);
}
function __ZNK5physx27PxVehicleDifferentialNWData20getDrivenWheelStatusEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx27PxVehicleDifferentialNWData20setDrivenWheelStatusEj($this,$status) {
 $this = $this|0;
 $status = $status|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $status;
 $1 = (($this) + 4|0);
 $2 = (($this) + 8|0);
 $$pre = HEAP32[$1>>2]|0;
 $14 = $$pre;$i$01 = 0;
 while(1) {
  $3 = $i$01 >>> 5;
  $4 = (($0) + ($3<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = 1 << $i$01;
  $7 = $5 & $6;
  $8 = ($7|0)==(0);
  $9 = (($this) + ($3<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & $6;
  $12 = ($11|0)!=(0);
  if ($8) {
   if ($12) {
    $18 = (($14) + -1)|0;
    $19 = $6 ^ -1;
    $20 = $10 & $19;
    HEAP32[$9>>2] = $20;
    $21 = (Math_fround(($18>>>0)));
    $22 = $21 > Math_fround(0.0);
    if ($22) {
     $23 = Math_fround(Math_fround(1.0) / $21);
     $24 = $23;
    } else {
     $24 = Math_fround(0.0);
    }
    HEAPF32[$2>>2] = $24;
    $storemerge$i = $18;
   } else {
    $storemerge$i = $14;
   }
  } else {
   if ($12) {
    $storemerge$i = $14;
   } else {
    $13 = (($14) + 1)|0;
    $15 = $10 | $6;
    HEAP32[$9>>2] = $15;
    $16 = (Math_fround(($13>>>0)));
    $17 = Math_fround(Math_fround(1.0) / $16);
    HEAPF32[$2>>2] = $17;
    $storemerge$i = $13;
   }
  }
  HEAP32[$1>>2] = $storemerge$i;
  $25 = (($i$01) + 1)|0;
  $exitcond = ($25|0)==(20);
  if ($exitcond) {
   break;
  } else {
   $14 = $storemerge$i;$i$01 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx21PxVehicleDriveSimData13setEngineDataERKNS_19PxVehicleEngineDataE($this,$engine) {
 $this = $this|0;
 $engine = $engine|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($engine) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 3;
 _memcpy(($this|0),($engine|0),($2|0))|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($this) + 64|0);
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 80|0);
 $6 = (($engine) + 80|0);
 ;HEAP32[$5+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$5+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$5+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$5+28>>2]=HEAP32[$6+28>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(Math_fround(1.0) / $7);
 $9 = (($this) + 104|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($engine) + 88|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(Math_fround(1.0) / $11);
 $13 = (($this) + 108|0);
 HEAPF32[$13>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN5physx21PxVehicleDriveSimData12setGearsDataERKNS_18PxVehicleGearsDataE($this,$gears) {
 $this = $this|0;
 $gears = $gears|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 _memcpy(($0|0),($gears|0),144)|0;
 STACKTOP = sp;return;
}
function __ZN5physx21PxVehicleDriveSimData13setClutchDataERKNS_19PxVehicleClutchDataE($this,$clutch) {
 $this = $this|0;
 $clutch = $clutch|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 256|0);
 ;HEAP32[$0+0>>2]=HEAP32[$clutch+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$clutch+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$clutch+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$clutch+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx21PxVehicleDriveSimData14setAutoBoxDataERKNS_20PxVehicleAutoBoxDataE($this,$autobox) {
 $this = $this|0;
 $autobox = $autobox|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 272|0);
 _memcpy(($0|0),($autobox|0),256)|0;
 STACKTOP = sp;return;
}
function __ZN5physx21PxVehicleDriveDynDataC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 HEAP8[$0>>0] = 0;
 $1 = (($this) + 65|0);
 HEAP8[$1>>0] = 0;
 $2 = (($this) + 66|0);
 HEAP8[$2>>0] = 0;
 $3 = (($this) + 68|0);
 HEAP32[$3>>2] = 1;
 $4 = (($this) + 72|0);
 HEAP32[$4>>2] = 1;
 $5 = (($this) + 76|0);
 HEAPF32[$5>>2] = Math_fround(360.0);
 $6 = (($this) + 80|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 84|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 dest=$this+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx21PxVehicleDriveDynData14setAnalogInputEjf($this,$type,$analogVal) {
 $this = $this|0;
 $type = $type|0;
 $analogVal = Math_fround($analogVal);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + ($type<<2)|0);
 HEAPF32[$0>>2] = $analogVal;
 STACKTOP = sp;return;
}
function __ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + ($type<<2)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx14PxVehicleDrive15computeByteSizeEj($numWheels4) {
 $numWheels4 = $numWheels4|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($numWheels4)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx14PxVehicleDrive15patchupPointersEPS0_Phjj($veh,$ptr,$numWheels4,$numWheels) {
 $veh = $veh|0;
 $ptr = $ptr|0;
 $numWheels4 = $numWheels4|0;
 $numWheels = $numWheels|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx15PxVehicleWheels15patchupPointersEPS0_Phjjb($veh,$ptr,$numWheels4,$numWheels,1)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx14PxVehicleDrive5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataEjj($this,$physics,$vehActor,$wheelsData,$numDrivenWheels,$numNonDrivenWheels) {
 $this = $this|0;
 $physics = $physics|0;
 $vehActor = $vehActor|0;
 $wheelsData = $wheelsData|0;
 $numDrivenWheels = $numDrivenWheels|0;
 $numNonDrivenWheels = $numNonDrivenWheels|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15PxVehicleWheels5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataEjj($this,$physics,$vehActor,$wheelsData,$numDrivenWheels,$numNonDrivenWheels);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleDriveSimData4W11setDiffDataERKNS_27PxVehicleDifferential4WDataE($this,$diff) {
 $this = $this|0;
 $diff = $diff|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 528|0);
 ;HEAP32[$0+0>>2]=HEAP32[$diff+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$diff+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$diff+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$diff+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$diff+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$diff+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$diff+24>>2]|0;HEAP32[$0+28>>2]=HEAP32[$diff+28>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleDriveSimData4W24setAckermannGeometryDataERKNS_30PxVehicleAckermannGeometryDataE($this,$ackermannData) {
 $this = $this|0;
 $ackermannData = $ackermannData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 560|0);
 ;HEAP32[$0+0>>2]=HEAP32[$ackermannData+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$ackermannData+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$ackermannData+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$ackermannData+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleDrive4W8allocateEj($numWheels) {
 $numWheels = $numWheels|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($numWheels) + 3)|0;
 $2 = $1 >>> 2;
 $3 = (__ZN5physx14PxVehicleDrive15computeByteSizeEj($2)|0);
 $4 = (($3) + 800)|0;
 $5 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$4,508440,91)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZN5physx16PxVehicleDrive4WC2Ev($5);
 }
 $7 = (($5) + 800|0);
 (__ZN5physx14PxVehicleDrive15patchupPointersEPS0_Phjj($5,$7,$2,$numWheels)|0);
 $8 = (($5) + 113|0);
 HEAP8[$8>>0] = 0;
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx16PxVehicleDrive4W5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataERKNS_23PxVehicleDriveSimData4WEj($this,$physics,$vehActor,$wheelsData,$driveData,$numNonDrivenWheels) {
 $this = $this|0;
 $physics = $physics|0;
 $vehActor = $vehActor|0;
 $wheelsData = $wheelsData|0;
 $driveData = $driveData|0;
 $numNonDrivenWheels = $numNonDrivenWheels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 __ZN5physx14PxVehicleDrive5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataEjj($this,$physics,$vehActor,$wheelsData,4,$numNonDrivenWheels);
 $0 = (($this) + 224|0);
 $1 = (($driveData) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($0|0),($driveData|0),($3|0))|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($this) + 288|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 304|0);
 $7 = (($driveData) + 80|0);
 ;HEAP32[$6+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$7+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$7+20>>2]|0;HEAP32[$6+24>>2]=HEAP32[$7+24>>2]|0;HEAP32[$6+28>>2]=HEAP32[$7+28>>2]|0;
 $8 = (($this) + 336|0);
 $9 = (($driveData) + 112|0);
 _memcpy(($8|0),($9|0),416)|0;
 $10 = (($this) + 752|0);
 $11 = (($driveData) + 528|0);
 dest=$10+0|0; src=$11+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleDriveSimDataNW11setDiffDataERKNS_27PxVehicleDifferentialNWDataE($this,$diff) {
 $this = $this|0;
 $diff = $diff|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 528|0);
 ;HEAP32[$0+0>>2]=HEAP32[$diff+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$diff+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$diff+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$diff+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleDriveNW8allocateEj($numWheels) {
 $numWheels = $numWheels|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($numWheels) + 3)|0;
 $2 = $1 >>> 2;
 $3 = (__ZN5physx14PxVehicleDrive15computeByteSizeEj($2)|0);
 $4 = (($3) + 768)|0;
 $5 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$4,508528,79)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZN5physx16PxVehicleDriveNWC2Ev($5);
 }
 $7 = (($5) + 768|0);
 (__ZN5physx14PxVehicleDrive15patchupPointersEPS0_Phjj($5,$7,$2,$numWheels)|0);
 $8 = (($5) + 113|0);
 HEAP8[$8>>0] = 1;
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx16PxVehicleDriveNW5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataERKNS_23PxVehicleDriveSimDataNWEj($this,$physics,$vehActor,$wheelsData,$driveData,$numWheels) {
 $this = $this|0;
 $physics = $physics|0;
 $vehActor = $vehActor|0;
 $wheelsData = $wheelsData|0;
 $driveData = $driveData|0;
 $numWheels = $numWheels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx14PxVehicleDrive5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataEjj($this,$physics,$vehActor,$wheelsData,$numWheels,0);
 $0 = (($this) + 224|0);
 $1 = (($driveData) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($0|0),($driveData|0),($3|0))|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($this) + 288|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 304|0);
 $7 = (($driveData) + 80|0);
 ;HEAP32[$6+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$7+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$7+20>>2]|0;HEAP32[$6+24>>2]=HEAP32[$7+24>>2]|0;HEAP32[$6+28>>2]=HEAP32[$7+28>>2]|0;
 $8 = (($this) + 336|0);
 $9 = (($driveData) + 112|0);
 _memcpy(($8|0),($9|0),416)|0;
 $10 = (($this) + 752|0);
 $11 = (($driveData) + 528|0);
 ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx18PxVehicleDriveTank8allocateEj($numWheels) {
 $numWheels = $numWheels|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($numWheels) + 3)|0;
 $2 = $1 >>> 2;
 $3 = (__ZN5physx14PxVehicleDrive15computeByteSizeEj($2)|0);
 $4 = (($3) + 768)|0;
 $5 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$4,508616,62)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZN5physx18PxVehicleDriveTankC2Ev($5);
 }
 $7 = (($5) + 768|0);
 (__ZN5physx14PxVehicleDrive15patchupPointersEPS0_Phjj($5,$7,$2,$numWheels)|0);
 $8 = (($5) + 113|0);
 HEAP8[$8>>0] = 2;
 $9 = (($5) + 752|0);
 HEAP32[$9>>2] = 0;
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx18PxVehicleDriveTank5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataERKNS_21PxVehicleDriveSimDataEj($this,$physics,$vehActor,$wheelsData,$driveData,$numDrivenWheels) {
 $this = $this|0;
 $physics = $physics|0;
 $vehActor = $vehActor|0;
 $wheelsData = $wheelsData|0;
 $driveData = $driveData|0;
 $numDrivenWheels = $numDrivenWheels|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx14PxVehicleDrive5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataEjj($this,$physics,$vehActor,$wheelsData,$numDrivenWheels,0);
 $0 = (($this) + 224|0);
 $1 = (($driveData) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($0|0),($driveData|0),($3|0))|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($this) + 288|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 304|0);
 $7 = (($driveData) + 80|0);
 ;HEAP32[$6+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$7+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$7+20>>2]|0;HEAP32[$6+24>>2]=HEAP32[$7+24>>2]|0;HEAP32[$6+28>>2]=HEAP32[$7+28>>2]|0;
 $8 = (($this) + 336|0);
 $9 = (($driveData) + 112|0);
 _memcpy(($8|0),($9|0),416)|0;
 STACKTOP = sp;return;
}
function __ZN5physx21PxVehicleDriveSimData17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp$i = 0, $tmp$i$i = 0, $tmp1 = 0, $tmp1$i$i = 0, $tmp10 = 0, $tmp11 = 0, $tmp12 = 0, $tmp13 = 0, $tmp14 = 0;
 var $tmp15 = 0, $tmp16 = 0, $tmp17 = 0, $tmp18 = 0, $tmp19 = 0, $tmp2 = 0, $tmp2$i$i = 0, $tmp20 = 0, $tmp21 = 0, $tmp22 = 0, $tmp23 = 0, $tmp24 = 0, $tmp25 = 0, $tmp26 = 0, $tmp27 = 0, $tmp28 = 0, $tmp29 = 0, $tmp3 = 0, $tmp3$i$i = 0, $tmp4 = 0;
 var $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0, $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1120|0;
 $tmp$i$i = sp + 1088|0;
 $tmp1$i$i = sp + 1056|0;
 $tmp2$i$i = sp + 1024|0;
 $tmp3$i$i = sp + 992|0;
 $tmp$i = sp + 960|0;
 $tmp = sp + 928|0;
 $tmp1 = sp + 896|0;
 $tmp2 = sp + 864|0;
 $tmp3 = sp + 832|0;
 $tmp4 = sp + 800|0;
 $tmp5 = sp + 768|0;
 $tmp6 = sp + 736|0;
 $tmp7 = sp + 704|0;
 $tmp8 = sp + 672|0;
 $tmp9 = sp + 640|0;
 $tmp10 = sp + 608|0;
 $tmp11 = sp + 576|0;
 $tmp12 = sp + 544|0;
 $tmp13 = sp + 224|0;
 $tmp14 = sp;
 $tmp15 = sp + 32|0;
 $tmp16 = sp + 64|0;
 $tmp17 = sp + 96|0;
 $tmp18 = sp + 128|0;
 $tmp19 = sp + 160|0;
 $tmp20 = sp + 192|0;
 $tmp21 = sp + 256|0;
 $tmp22 = sp + 288|0;
 $tmp23 = sp + 320|0;
 $tmp24 = sp + 352|0;
 $tmp25 = sp + 384|0;
 $tmp26 = sp + 416|0;
 $tmp27 = sp + 448|0;
 $tmp28 = sp + 480|0;
 $tmp29 = sp + 512|0;
 ;HEAP32[$tmp$i$i+0>>2]=HEAP32[519056+0>>2]|0;HEAP32[$tmp$i$i+4>>2]=HEAP32[519056+4>>2]|0;HEAP32[$tmp$i$i+8>>2]=HEAP32[519056+8>>2]|0;HEAP32[$tmp$i$i+12>>2]=HEAP32[519056+12>>2]|0;HEAP32[$tmp$i$i+16>>2]=HEAP32[519056+16>>2]|0;HEAP32[$tmp$i$i+20>>2]=HEAP32[519056+20>>2]|0;HEAP32[$tmp$i$i+24>>2]=HEAP32[519056+24>>2]|0;HEAP32[$tmp$i$i+28>>2]=HEAP32[519056+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp$i$i,32)|0);
 ;HEAP32[$tmp1$i$i+0>>2]=HEAP32[519104+0>>2]|0;HEAP32[$tmp1$i$i+4>>2]=HEAP32[519104+4>>2]|0;HEAP32[$tmp1$i$i+8>>2]=HEAP32[519104+8>>2]|0;HEAP32[$tmp1$i$i+12>>2]=HEAP32[519104+12>>2]|0;HEAP32[$tmp1$i$i+16>>2]=HEAP32[519104+16>>2]|0;HEAP32[$tmp1$i$i+20>>2]=HEAP32[519104+20>>2]|0;HEAP32[$tmp1$i$i+24>>2]=HEAP32[519104+24>>2]|0;HEAP32[$tmp1$i$i+28>>2]=HEAP32[519104+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1$i$i,32)|0);
 ;HEAP32[$tmp2$i$i+0>>2]=HEAP32[519152+0>>2]|0;HEAP32[$tmp2$i$i+4>>2]=HEAP32[519152+4>>2]|0;HEAP32[$tmp2$i$i+8>>2]=HEAP32[519152+8>>2]|0;HEAP32[$tmp2$i$i+12>>2]=HEAP32[519152+12>>2]|0;HEAP32[$tmp2$i$i+16>>2]=HEAP32[519152+16>>2]|0;HEAP32[$tmp2$i$i+20>>2]=HEAP32[519152+20>>2]|0;HEAP32[$tmp2$i$i+24>>2]=HEAP32[519152+24>>2]|0;HEAP32[$tmp2$i$i+28>>2]=HEAP32[519152+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2$i$i,32)|0);
 ;HEAP32[$tmp3$i$i+0>>2]=HEAP32[519184+0>>2]|0;HEAP32[$tmp3$i$i+4>>2]=HEAP32[519184+4>>2]|0;HEAP32[$tmp3$i$i+8>>2]=HEAP32[519184+8>>2]|0;HEAP32[$tmp3$i$i+12>>2]=HEAP32[519184+12>>2]|0;HEAP32[$tmp3$i$i+16>>2]=HEAP32[519184+16>>2]|0;HEAP32[$tmp3$i$i+20>>2]=HEAP32[519184+20>>2]|0;HEAP32[$tmp3$i$i+24>>2]=HEAP32[519184+24>>2]|0;HEAP32[$tmp3$i$i+28>>2]=HEAP32[519184+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3$i$i,32)|0);
 ;HEAP32[$tmp$i+0>>2]=HEAP32[519024+0>>2]|0;HEAP32[$tmp$i+4>>2]=HEAP32[519024+4>>2]|0;HEAP32[$tmp$i+8>>2]=HEAP32[519024+8>>2]|0;HEAP32[$tmp$i+12>>2]=HEAP32[519024+12>>2]|0;HEAP32[$tmp$i+16>>2]=HEAP32[519024+16>>2]|0;HEAP32[$tmp$i+20>>2]=HEAP32[519024+20>>2]|0;HEAP32[$tmp$i+24>>2]=HEAP32[519024+24>>2]|0;HEAP32[$tmp$i+28>>2]=HEAP32[519024+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp$i,32)|0);
 ;HEAP32[$tmp+0>>2]=HEAP32[508752+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[508752+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[508752+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[508752+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[508752+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[508752+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[508752+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[508752+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp,32)|0);
 ;HEAP32[$tmp1+0>>2]=HEAP32[508808+0>>2]|0;HEAP32[$tmp1+4>>2]=HEAP32[508808+4>>2]|0;HEAP32[$tmp1+8>>2]=HEAP32[508808+8>>2]|0;HEAP32[$tmp1+12>>2]=HEAP32[508808+12>>2]|0;HEAP32[$tmp1+16>>2]=HEAP32[508808+16>>2]|0;HEAP32[$tmp1+20>>2]=HEAP32[508808+20>>2]|0;HEAP32[$tmp1+24>>2]=HEAP32[508808+24>>2]|0;HEAP32[$tmp1+28>>2]=HEAP32[508808+28>>2]|0;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[508880+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[508880+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[508880+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[508880+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[508880+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[508880+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[508880+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[508880+28>>2]|0;
 $14 = HEAP32[$stream>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_iiii[$15 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[508928+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[508928+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[508928+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[508928+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[508928+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[508928+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[508928+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[508928+28>>2]|0;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[508976+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[508976+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[508976+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[508976+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[508976+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[508976+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[508976+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[508976+28>>2]|0;
 $18 = HEAP32[$stream>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[509024+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[509024+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[509024+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[509024+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[509024+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[509024+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[509024+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[509024+28>>2]|0;
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[509088+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[509088+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[509088+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[509088+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[509088+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[509088+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[509088+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[509088+28>>2]|0;
 $22 = HEAP32[$stream>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_iiii[$23 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[509160+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[509160+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[509160+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[509160+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[509160+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[509160+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[509160+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[509160+28>>2]|0;
 $24 = HEAP32[$stream>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_iiii[$25 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[509240+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[509240+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[509240+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[509240+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[509240+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[509240+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[509240+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[509240+28>>2]|0;
 $26 = HEAP32[$stream>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_iiii[$27 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[509288+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[509288+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[509288+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[509288+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[509288+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[509288+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[509288+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[509288+28>>2]|0;
 $28 = HEAP32[$stream>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 (FUNCTION_TABLE_iiii[$29 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[509336+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[509336+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[509336+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[509336+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[509336+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[509336+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[509336+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[509336+28>>2]|0;
 $30 = HEAP32[$stream>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 (FUNCTION_TABLE_iiii[$31 & 2047]($stream,$tmp10,32)|0);
 ;HEAP32[$tmp11+0>>2]=HEAP32[509392+0>>2]|0;HEAP32[$tmp11+4>>2]=HEAP32[509392+4>>2]|0;HEAP32[$tmp11+8>>2]=HEAP32[509392+8>>2]|0;HEAP32[$tmp11+12>>2]=HEAP32[509392+12>>2]|0;HEAP32[$tmp11+16>>2]=HEAP32[509392+16>>2]|0;HEAP32[$tmp11+20>>2]=HEAP32[509392+20>>2]|0;HEAP32[$tmp11+24>>2]=HEAP32[509392+24>>2]|0;HEAP32[$tmp11+28>>2]=HEAP32[509392+28>>2]|0;
 $32 = HEAP32[$stream>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 (FUNCTION_TABLE_iiii[$33 & 2047]($stream,$tmp11,32)|0);
 ;HEAP32[$tmp12+0>>2]=HEAP32[509432+0>>2]|0;HEAP32[$tmp12+4>>2]=HEAP32[509432+4>>2]|0;HEAP32[$tmp12+8>>2]=HEAP32[509432+8>>2]|0;HEAP32[$tmp12+12>>2]=HEAP32[509432+12>>2]|0;HEAP32[$tmp12+16>>2]=HEAP32[509432+16>>2]|0;HEAP32[$tmp12+20>>2]=HEAP32[509432+20>>2]|0;HEAP32[$tmp12+24>>2]=HEAP32[509432+24>>2]|0;HEAP32[$tmp12+28>>2]=HEAP32[509432+28>>2]|0;
 $34 = HEAP32[$stream>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($stream,$tmp12,32)|0);
 ;HEAP32[$tmp13+0>>2]=HEAP32[509480+0>>2]|0;HEAP32[$tmp13+4>>2]=HEAP32[509480+4>>2]|0;HEAP32[$tmp13+8>>2]=HEAP32[509480+8>>2]|0;HEAP32[$tmp13+12>>2]=HEAP32[509480+12>>2]|0;HEAP32[$tmp13+16>>2]=HEAP32[509480+16>>2]|0;HEAP32[$tmp13+20>>2]=HEAP32[509480+20>>2]|0;HEAP32[$tmp13+24>>2]=HEAP32[509480+24>>2]|0;HEAP32[$tmp13+28>>2]=HEAP32[509480+28>>2]|0;
 $36 = HEAP32[$stream>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 (FUNCTION_TABLE_iiii[$37 & 2047]($stream,$tmp13,32)|0);
 ;HEAP32[$tmp14+0>>2]=HEAP32[509528+0>>2]|0;HEAP32[$tmp14+4>>2]=HEAP32[509528+4>>2]|0;HEAP32[$tmp14+8>>2]=HEAP32[509528+8>>2]|0;HEAP32[$tmp14+12>>2]=HEAP32[509528+12>>2]|0;HEAP32[$tmp14+16>>2]=HEAP32[509528+16>>2]|0;HEAP32[$tmp14+20>>2]=HEAP32[509528+20>>2]|0;HEAP32[$tmp14+24>>2]=HEAP32[509528+24>>2]|0;HEAP32[$tmp14+28>>2]=HEAP32[509528+28>>2]|0;
 $38 = HEAP32[$stream>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_iiii[$39 & 2047]($stream,$tmp14,32)|0);
 ;HEAP32[$tmp15+0>>2]=HEAP32[509576+0>>2]|0;HEAP32[$tmp15+4>>2]=HEAP32[509576+4>>2]|0;HEAP32[$tmp15+8>>2]=HEAP32[509576+8>>2]|0;HEAP32[$tmp15+12>>2]=HEAP32[509576+12>>2]|0;HEAP32[$tmp15+16>>2]=HEAP32[509576+16>>2]|0;HEAP32[$tmp15+20>>2]=HEAP32[509576+20>>2]|0;HEAP32[$tmp15+24>>2]=HEAP32[509576+24>>2]|0;HEAP32[$tmp15+28>>2]=HEAP32[509576+28>>2]|0;
 $40 = HEAP32[$stream>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 (FUNCTION_TABLE_iiii[$41 & 2047]($stream,$tmp15,32)|0);
 ;HEAP32[$tmp16+0>>2]=HEAP32[509616+0>>2]|0;HEAP32[$tmp16+4>>2]=HEAP32[509616+4>>2]|0;HEAP32[$tmp16+8>>2]=HEAP32[509616+8>>2]|0;HEAP32[$tmp16+12>>2]=HEAP32[509616+12>>2]|0;HEAP32[$tmp16+16>>2]=HEAP32[509616+16>>2]|0;HEAP32[$tmp16+20>>2]=HEAP32[509616+20>>2]|0;HEAP32[$tmp16+24>>2]=HEAP32[509616+24>>2]|0;HEAP32[$tmp16+28>>2]=HEAP32[509616+28>>2]|0;
 $42 = HEAP32[$stream>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 (FUNCTION_TABLE_iiii[$43 & 2047]($stream,$tmp16,32)|0);
 ;HEAP32[$tmp17+0>>2]=HEAP32[509672+0>>2]|0;HEAP32[$tmp17+4>>2]=HEAP32[509672+4>>2]|0;HEAP32[$tmp17+8>>2]=HEAP32[509672+8>>2]|0;HEAP32[$tmp17+12>>2]=HEAP32[509672+12>>2]|0;HEAP32[$tmp17+16>>2]=HEAP32[509672+16>>2]|0;HEAP32[$tmp17+20>>2]=HEAP32[509672+20>>2]|0;HEAP32[$tmp17+24>>2]=HEAP32[509672+24>>2]|0;HEAP32[$tmp17+28>>2]=HEAP32[509672+28>>2]|0;
 $44 = HEAP32[$stream>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 (FUNCTION_TABLE_iiii[$45 & 2047]($stream,$tmp17,32)|0);
 ;HEAP32[$tmp18+0>>2]=HEAP32[509720+0>>2]|0;HEAP32[$tmp18+4>>2]=HEAP32[509720+4>>2]|0;HEAP32[$tmp18+8>>2]=HEAP32[509720+8>>2]|0;HEAP32[$tmp18+12>>2]=HEAP32[509720+12>>2]|0;HEAP32[$tmp18+16>>2]=HEAP32[509720+16>>2]|0;HEAP32[$tmp18+20>>2]=HEAP32[509720+20>>2]|0;HEAP32[$tmp18+24>>2]=HEAP32[509720+24>>2]|0;HEAP32[$tmp18+28>>2]=HEAP32[509720+28>>2]|0;
 $46 = HEAP32[$stream>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 (FUNCTION_TABLE_iiii[$47 & 2047]($stream,$tmp18,32)|0);
 ;HEAP32[$tmp19+0>>2]=HEAP32[509768+0>>2]|0;HEAP32[$tmp19+4>>2]=HEAP32[509768+4>>2]|0;HEAP32[$tmp19+8>>2]=HEAP32[509768+8>>2]|0;HEAP32[$tmp19+12>>2]=HEAP32[509768+12>>2]|0;HEAP32[$tmp19+16>>2]=HEAP32[509768+16>>2]|0;HEAP32[$tmp19+20>>2]=HEAP32[509768+20>>2]|0;HEAP32[$tmp19+24>>2]=HEAP32[509768+24>>2]|0;HEAP32[$tmp19+28>>2]=HEAP32[509768+28>>2]|0;
 $48 = HEAP32[$stream>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 (FUNCTION_TABLE_iiii[$49 & 2047]($stream,$tmp19,32)|0);
 ;HEAP32[$tmp20+0>>2]=HEAP32[509824+0>>2]|0;HEAP32[$tmp20+4>>2]=HEAP32[509824+4>>2]|0;HEAP32[$tmp20+8>>2]=HEAP32[509824+8>>2]|0;HEAP32[$tmp20+12>>2]=HEAP32[509824+12>>2]|0;HEAP32[$tmp20+16>>2]=HEAP32[509824+16>>2]|0;HEAP32[$tmp20+20>>2]=HEAP32[509824+20>>2]|0;HEAP32[$tmp20+24>>2]=HEAP32[509824+24>>2]|0;HEAP32[$tmp20+28>>2]=HEAP32[509824+28>>2]|0;
 $50 = HEAP32[$stream>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 (FUNCTION_TABLE_iiii[$51 & 2047]($stream,$tmp20,32)|0);
 ;HEAP32[$tmp21+0>>2]=HEAP32[509864+0>>2]|0;HEAP32[$tmp21+4>>2]=HEAP32[509864+4>>2]|0;HEAP32[$tmp21+8>>2]=HEAP32[509864+8>>2]|0;HEAP32[$tmp21+12>>2]=HEAP32[509864+12>>2]|0;HEAP32[$tmp21+16>>2]=HEAP32[509864+16>>2]|0;HEAP32[$tmp21+20>>2]=HEAP32[509864+20>>2]|0;HEAP32[$tmp21+24>>2]=HEAP32[509864+24>>2]|0;HEAP32[$tmp21+28>>2]=HEAP32[509864+28>>2]|0;
 $52 = HEAP32[$stream>>2]|0;
 $53 = HEAP32[$52>>2]|0;
 (FUNCTION_TABLE_iiii[$53 & 2047]($stream,$tmp21,32)|0);
 ;HEAP32[$tmp22+0>>2]=HEAP32[509920+0>>2]|0;HEAP32[$tmp22+4>>2]=HEAP32[509920+4>>2]|0;HEAP32[$tmp22+8>>2]=HEAP32[509920+8>>2]|0;HEAP32[$tmp22+12>>2]=HEAP32[509920+12>>2]|0;HEAP32[$tmp22+16>>2]=HEAP32[509920+16>>2]|0;HEAP32[$tmp22+20>>2]=HEAP32[509920+20>>2]|0;HEAP32[$tmp22+24>>2]=HEAP32[509920+24>>2]|0;HEAP32[$tmp22+28>>2]=HEAP32[509920+28>>2]|0;
 $54 = HEAP32[$stream>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 (FUNCTION_TABLE_iiii[$55 & 2047]($stream,$tmp22,32)|0);
 ;HEAP32[$tmp23+0>>2]=HEAP32[509968+0>>2]|0;HEAP32[$tmp23+4>>2]=HEAP32[509968+4>>2]|0;HEAP32[$tmp23+8>>2]=HEAP32[509968+8>>2]|0;HEAP32[$tmp23+12>>2]=HEAP32[509968+12>>2]|0;HEAP32[$tmp23+16>>2]=HEAP32[509968+16>>2]|0;HEAP32[$tmp23+20>>2]=HEAP32[509968+20>>2]|0;HEAP32[$tmp23+24>>2]=HEAP32[509968+24>>2]|0;HEAP32[$tmp23+28>>2]=HEAP32[509968+28>>2]|0;
 $56 = HEAP32[$stream>>2]|0;
 $57 = HEAP32[$56>>2]|0;
 (FUNCTION_TABLE_iiii[$57 & 2047]($stream,$tmp23,32)|0);
 ;HEAP32[$tmp24+0>>2]=HEAP32[510016+0>>2]|0;HEAP32[$tmp24+4>>2]=HEAP32[510016+4>>2]|0;HEAP32[$tmp24+8>>2]=HEAP32[510016+8>>2]|0;HEAP32[$tmp24+12>>2]=HEAP32[510016+12>>2]|0;HEAP32[$tmp24+16>>2]=HEAP32[510016+16>>2]|0;HEAP32[$tmp24+20>>2]=HEAP32[510016+20>>2]|0;HEAP32[$tmp24+24>>2]=HEAP32[510016+24>>2]|0;HEAP32[$tmp24+28>>2]=HEAP32[510016+28>>2]|0;
 $58 = HEAP32[$stream>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 (FUNCTION_TABLE_iiii[$59 & 2047]($stream,$tmp24,32)|0);
 ;HEAP32[$tmp25+0>>2]=HEAP32[510072+0>>2]|0;HEAP32[$tmp25+4>>2]=HEAP32[510072+4>>2]|0;HEAP32[$tmp25+8>>2]=HEAP32[510072+8>>2]|0;HEAP32[$tmp25+12>>2]=HEAP32[510072+12>>2]|0;HEAP32[$tmp25+16>>2]=HEAP32[510072+16>>2]|0;HEAP32[$tmp25+20>>2]=HEAP32[510072+20>>2]|0;HEAP32[$tmp25+24>>2]=HEAP32[510072+24>>2]|0;HEAP32[$tmp25+28>>2]=HEAP32[510072+28>>2]|0;
 $60 = HEAP32[$stream>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 (FUNCTION_TABLE_iiii[$61 & 2047]($stream,$tmp25,32)|0);
 ;HEAP32[$tmp26+0>>2]=HEAP32[510112+0>>2]|0;HEAP32[$tmp26+4>>2]=HEAP32[510112+4>>2]|0;HEAP32[$tmp26+8>>2]=HEAP32[510112+8>>2]|0;HEAP32[$tmp26+12>>2]=HEAP32[510112+12>>2]|0;HEAP32[$tmp26+16>>2]=HEAP32[510112+16>>2]|0;HEAP32[$tmp26+20>>2]=HEAP32[510112+20>>2]|0;HEAP32[$tmp26+24>>2]=HEAP32[510112+24>>2]|0;HEAP32[$tmp26+28>>2]=HEAP32[510112+28>>2]|0;
 $62 = HEAP32[$stream>>2]|0;
 $63 = HEAP32[$62>>2]|0;
 (FUNCTION_TABLE_iiii[$63 & 2047]($stream,$tmp26,32)|0);
 ;HEAP32[$tmp27+0>>2]=HEAP32[510152+0>>2]|0;HEAP32[$tmp27+4>>2]=HEAP32[510152+4>>2]|0;HEAP32[$tmp27+8>>2]=HEAP32[510152+8>>2]|0;HEAP32[$tmp27+12>>2]=HEAP32[510152+12>>2]|0;HEAP32[$tmp27+16>>2]=HEAP32[510152+16>>2]|0;HEAP32[$tmp27+20>>2]=HEAP32[510152+20>>2]|0;HEAP32[$tmp27+24>>2]=HEAP32[510152+24>>2]|0;HEAP32[$tmp27+28>>2]=HEAP32[510152+28>>2]|0;
 $64 = HEAP32[$stream>>2]|0;
 $65 = HEAP32[$64>>2]|0;
 (FUNCTION_TABLE_iiii[$65 & 2047]($stream,$tmp27,32)|0);
 ;HEAP32[$tmp28+0>>2]=HEAP32[510192+0>>2]|0;HEAP32[$tmp28+4>>2]=HEAP32[510192+4>>2]|0;HEAP32[$tmp28+8>>2]=HEAP32[510192+8>>2]|0;HEAP32[$tmp28+12>>2]=HEAP32[510192+12>>2]|0;HEAP32[$tmp28+16>>2]=HEAP32[510192+16>>2]|0;HEAP32[$tmp28+20>>2]=HEAP32[510192+20>>2]|0;HEAP32[$tmp28+24>>2]=HEAP32[510192+24>>2]|0;HEAP32[$tmp28+28>>2]=HEAP32[510192+28>>2]|0;
 $66 = HEAP32[$stream>>2]|0;
 $67 = HEAP32[$66>>2]|0;
 (FUNCTION_TABLE_iiii[$67 & 2047]($stream,$tmp28,32)|0);
 ;HEAP32[$tmp29+0>>2]=HEAP32[510240+0>>2]|0;HEAP32[$tmp29+4>>2]=HEAP32[510240+4>>2]|0;HEAP32[$tmp29+8>>2]=HEAP32[510240+8>>2]|0;HEAP32[$tmp29+12>>2]=HEAP32[510240+12>>2]|0;HEAP32[$tmp29+16>>2]=HEAP32[510240+16>>2]|0;HEAP32[$tmp29+20>>2]=HEAP32[510240+20>>2]|0;HEAP32[$tmp29+24>>2]=HEAP32[510240+24>>2]|0;HEAP32[$tmp29+28>>2]=HEAP32[510240+28>>2]|0;
 $68 = HEAP32[$stream>>2]|0;
 $69 = HEAP32[$68>>2]|0;
 (FUNCTION_TABLE_iiii[$69 & 2047]($stream,$tmp29,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx14PxVehicleDrive17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp10 = 0, $tmp11 = 0, $tmp12 = 0;
 var $tmp13 = 0, $tmp2 = 0, $tmp3 = 0, $tmp4 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0, $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $tmp = sp + 416|0;
 $tmp1 = sp + 384|0;
 $tmp2 = sp + 352|0;
 $tmp3 = sp + 320|0;
 $tmp4 = sp + 288|0;
 $tmp5 = sp + 256|0;
 $tmp6 = sp + 224|0;
 $tmp7 = sp + 192|0;
 $tmp8 = sp + 128|0;
 $tmp9 = sp + 96|0;
 $tmp10 = sp + 64|0;
 $tmp11 = sp + 32|0;
 $tmp12 = sp;
 $tmp13 = sp + 160|0;
 ;HEAP32[$tmp+0>>2]=HEAP32[510296+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[510296+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[510296+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[510296+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[510296+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[510296+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[510296+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[510296+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 ;HEAP32[$tmp1+0>>2]=HEAP32[510352+0>>2]|0;HEAP32[$tmp1+4>>2]=HEAP32[510352+4>>2]|0;HEAP32[$tmp1+8>>2]=HEAP32[510352+8>>2]|0;HEAP32[$tmp1+12>>2]=HEAP32[510352+12>>2]|0;HEAP32[$tmp1+16>>2]=HEAP32[510352+16>>2]|0;HEAP32[$tmp1+20>>2]=HEAP32[510352+20>>2]|0;HEAP32[$tmp1+24>>2]=HEAP32[510352+24>>2]|0;HEAP32[$tmp1+28>>2]=HEAP32[510352+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[510408+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[510408+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[510408+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[510408+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[510408+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[510408+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[510408+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[510408+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[510456+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[510456+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[510456+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[510456+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[510456+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[510456+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[510456+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[510456+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[510512+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[510512+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[510512+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[510512+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[510512+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[510512+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[510512+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[510512+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[510560+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[510560+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[510560+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[510560+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[510560+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[510560+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[510560+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[510560+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[510608+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[510608+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[510608+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[510608+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[510608+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[510608+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[510608+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[510608+28>>2]|0;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[510656+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[510656+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[510656+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[510656+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[510656+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[510656+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[510656+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[510656+28>>2]|0;
 $14 = HEAP32[$stream>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_iiii[$15 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[510704+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[510704+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[510704+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[510704+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[510704+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[510704+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[510704+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[510704+28>>2]|0;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[510760+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[510760+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[510760+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[510760+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[510760+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[510760+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[510760+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[510760+28>>2]|0;
 $18 = HEAP32[$stream>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[510792+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[510792+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[510792+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[510792+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[510792+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[510792+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[510792+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[510792+28>>2]|0;
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$tmp10,32)|0);
 ;HEAP32[$tmp11+0>>2]=HEAP32[510840+0>>2]|0;HEAP32[$tmp11+4>>2]=HEAP32[510840+4>>2]|0;HEAP32[$tmp11+8>>2]=HEAP32[510840+8>>2]|0;HEAP32[$tmp11+12>>2]=HEAP32[510840+12>>2]|0;HEAP32[$tmp11+16>>2]=HEAP32[510840+16>>2]|0;HEAP32[$tmp11+20>>2]=HEAP32[510840+20>>2]|0;HEAP32[$tmp11+24>>2]=HEAP32[510840+24>>2]|0;HEAP32[$tmp11+28>>2]=HEAP32[510840+28>>2]|0;
 $22 = HEAP32[$stream>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_iiii[$23 & 2047]($stream,$tmp11,32)|0);
 HEAP32[$tmp12>>2] = 510824;
 $24 = (($tmp12) + 4|0);
 HEAP32[$24>>2] = 510872;
 $25 = (($tmp12) + 8|0);
 HEAP32[$25>>2] = 0;
 $26 = (($tmp12) + 12|0);
 HEAP32[$26>>2] = 224;
 $27 = (($tmp12) + 16|0);
 HEAP32[$27>>2] = 0;
 $28 = (($tmp12) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($tmp12) + 24|0);
 HEAP32[$29>>2] = 1;
 $30 = (($tmp12) + 28|0);
 HEAP32[$30>>2] = 0;
 $31 = HEAP32[$stream>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 (FUNCTION_TABLE_iiii[$32 & 2047]($stream,$tmp12,32)|0);
 ;HEAP32[$tmp13+0>>2]=HEAP32[510904+0>>2]|0;HEAP32[$tmp13+4>>2]=HEAP32[510904+4>>2]|0;HEAP32[$tmp13+8>>2]=HEAP32[510904+8>>2]|0;HEAP32[$tmp13+12>>2]=HEAP32[510904+12>>2]|0;HEAP32[$tmp13+16>>2]=HEAP32[510904+16>>2]|0;HEAP32[$tmp13+20>>2]=HEAP32[510904+20>>2]|0;HEAP32[$tmp13+24>>2]=HEAP32[510904+24>>2]|0;HEAP32[$tmp13+28>>2]=HEAP32[510904+28>>2]|0;
 $33 = HEAP32[$stream>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_iiii[$34 & 2047]($stream,$tmp13,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleDriveSimData4W17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp10 = 0, $tmp11 = 0, $tmp12 = 0, $tmp13 = 0, $tmp14 = 0, $tmp15 = 0, $tmp16 = 0, $tmp17 = 0, $tmp2 = 0, $tmp3 = 0, $tmp4 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0;
 var $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $tmp = sp + 544|0;
 $tmp1 = sp + 512|0;
 $tmp2 = sp + 480|0;
 $tmp3 = sp + 448|0;
 $tmp4 = sp + 416|0;
 $tmp5 = sp + 384|0;
 $tmp6 = sp + 352|0;
 $tmp7 = sp + 320|0;
 $tmp8 = sp + 288|0;
 $tmp9 = sp + 256|0;
 $tmp10 = sp + 192|0;
 $tmp11 = sp + 160|0;
 $tmp12 = sp + 128|0;
 $tmp13 = sp + 96|0;
 $tmp14 = sp + 64|0;
 $tmp15 = sp + 32|0;
 $tmp16 = sp;
 $tmp17 = sp + 224|0;
 ;HEAP32[$tmp+0>>2]=HEAP32[510968+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[510968+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[510968+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[510968+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[510968+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[510968+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[510968+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[510968+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 ;HEAP32[$tmp1+0>>2]=HEAP32[511016+0>>2]|0;HEAP32[$tmp1+4>>2]=HEAP32[511016+4>>2]|0;HEAP32[$tmp1+8>>2]=HEAP32[511016+8>>2]|0;HEAP32[$tmp1+12>>2]=HEAP32[511016+12>>2]|0;HEAP32[$tmp1+16>>2]=HEAP32[511016+16>>2]|0;HEAP32[$tmp1+20>>2]=HEAP32[511016+20>>2]|0;HEAP32[$tmp1+24>>2]=HEAP32[511016+24>>2]|0;HEAP32[$tmp1+28>>2]=HEAP32[511016+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[511072+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[511072+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[511072+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[511072+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[511072+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[511072+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[511072+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[511072+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[511128+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[511128+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[511128+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[511128+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[511128+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[511128+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[511128+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[511128+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[511176+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[511176+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[511176+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[511176+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[511176+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[511176+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[511176+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[511176+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[511224+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[511224+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[511224+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[511224+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[511224+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[511224+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[511224+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[511224+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[511272+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[511272+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[511272+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[511272+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[511272+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[511272+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[511272+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[511272+28>>2]|0;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[511312+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[511312+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[511312+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[511312+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[511312+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[511312+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[511312+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[511312+28>>2]|0;
 $14 = HEAP32[$stream>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_iiii[$15 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[511344+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[511344+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[511344+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[511344+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[511344+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[511344+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[511344+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[511344+28>>2]|0;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[511408+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[511408+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[511408+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[511408+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[511408+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[511408+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[511408+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[511408+28>>2]|0;
 $18 = HEAP32[$stream>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[511456+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[511456+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[511456+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[511456+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[511456+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[511456+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[511456+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[511456+28>>2]|0;
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$tmp10,32)|0);
 ;HEAP32[$tmp11+0>>2]=HEAP32[511504+0>>2]|0;HEAP32[$tmp11+4>>2]=HEAP32[511504+4>>2]|0;HEAP32[$tmp11+8>>2]=HEAP32[511504+8>>2]|0;HEAP32[$tmp11+12>>2]=HEAP32[511504+12>>2]|0;HEAP32[$tmp11+16>>2]=HEAP32[511504+16>>2]|0;HEAP32[$tmp11+20>>2]=HEAP32[511504+20>>2]|0;HEAP32[$tmp11+24>>2]=HEAP32[511504+24>>2]|0;HEAP32[$tmp11+28>>2]=HEAP32[511504+28>>2]|0;
 $22 = HEAP32[$stream>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_iiii[$23 & 2047]($stream,$tmp11,32)|0);
 ;HEAP32[$tmp12+0>>2]=HEAP32[511552+0>>2]|0;HEAP32[$tmp12+4>>2]=HEAP32[511552+4>>2]|0;HEAP32[$tmp12+8>>2]=HEAP32[511552+8>>2]|0;HEAP32[$tmp12+12>>2]=HEAP32[511552+12>>2]|0;HEAP32[$tmp12+16>>2]=HEAP32[511552+16>>2]|0;HEAP32[$tmp12+20>>2]=HEAP32[511552+20>>2]|0;HEAP32[$tmp12+24>>2]=HEAP32[511552+24>>2]|0;HEAP32[$tmp12+28>>2]=HEAP32[511552+28>>2]|0;
 $24 = HEAP32[$stream>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_iiii[$25 & 2047]($stream,$tmp12,32)|0);
 ;HEAP32[$tmp13+0>>2]=HEAP32[511600+0>>2]|0;HEAP32[$tmp13+4>>2]=HEAP32[511600+4>>2]|0;HEAP32[$tmp13+8>>2]=HEAP32[511600+8>>2]|0;HEAP32[$tmp13+12>>2]=HEAP32[511600+12>>2]|0;HEAP32[$tmp13+16>>2]=HEAP32[511600+16>>2]|0;HEAP32[$tmp13+20>>2]=HEAP32[511600+20>>2]|0;HEAP32[$tmp13+24>>2]=HEAP32[511600+24>>2]|0;HEAP32[$tmp13+28>>2]=HEAP32[511600+28>>2]|0;
 $26 = HEAP32[$stream>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_iiii[$27 & 2047]($stream,$tmp13,32)|0);
 ;HEAP32[$tmp14+0>>2]=HEAP32[511656+0>>2]|0;HEAP32[$tmp14+4>>2]=HEAP32[511656+4>>2]|0;HEAP32[$tmp14+8>>2]=HEAP32[511656+8>>2]|0;HEAP32[$tmp14+12>>2]=HEAP32[511656+12>>2]|0;HEAP32[$tmp14+16>>2]=HEAP32[511656+16>>2]|0;HEAP32[$tmp14+20>>2]=HEAP32[511656+20>>2]|0;HEAP32[$tmp14+24>>2]=HEAP32[511656+24>>2]|0;HEAP32[$tmp14+28>>2]=HEAP32[511656+28>>2]|0;
 $28 = HEAP32[$stream>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 (FUNCTION_TABLE_iiii[$29 & 2047]($stream,$tmp14,32)|0);
 HEAP32[$tmp15>>2] = 511632;
 $30 = (($tmp15) + 4|0);
 HEAP32[$30>>2] = 510048;
 $31 = (($tmp15) + 8|0);
 HEAP32[$31>>2] = 0;
 $32 = (($tmp15) + 12|0);
 HEAP32[$32>>2] = 576;
 $33 = (($tmp15) + 16|0);
 HEAP32[$33>>2] = 0;
 $34 = (($tmp15) + 20|0);
 HEAP32[$34>>2] = 0;
 $35 = (($tmp15) + 24|0);
 HEAP32[$35>>2] = 1;
 $36 = (($tmp15) + 28|0);
 HEAP32[$36>>2] = 0;
 $37 = HEAP32[$stream>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 (FUNCTION_TABLE_iiii[$38 & 2047]($stream,$tmp15,32)|0);
 ;HEAP32[$tmp16+0>>2]=HEAP32[511696+0>>2]|0;HEAP32[$tmp16+4>>2]=HEAP32[511696+4>>2]|0;HEAP32[$tmp16+8>>2]=HEAP32[511696+8>>2]|0;HEAP32[$tmp16+12>>2]=HEAP32[511696+12>>2]|0;HEAP32[$tmp16+16>>2]=HEAP32[511696+16>>2]|0;HEAP32[$tmp16+20>>2]=HEAP32[511696+20>>2]|0;HEAP32[$tmp16+24>>2]=HEAP32[511696+24>>2]|0;HEAP32[$tmp16+28>>2]=HEAP32[511696+28>>2]|0;
 $39 = HEAP32[$stream>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 (FUNCTION_TABLE_iiii[$40 & 2047]($stream,$tmp16,32)|0);
 ;HEAP32[$tmp17+0>>2]=HEAP32[511752+0>>2]|0;HEAP32[$tmp17+4>>2]=HEAP32[511752+4>>2]|0;HEAP32[$tmp17+8>>2]=HEAP32[511752+8>>2]|0;HEAP32[$tmp17+12>>2]=HEAP32[511752+12>>2]|0;HEAP32[$tmp17+16>>2]=HEAP32[511752+16>>2]|0;HEAP32[$tmp17+20>>2]=HEAP32[511752+20>>2]|0;HEAP32[$tmp17+24>>2]=HEAP32[511752+24>>2]|0;HEAP32[$tmp17+28>>2]=HEAP32[511752+28>>2]|0;
 $41 = HEAP32[$stream>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 (FUNCTION_TABLE_iiii[$42 & 2047]($stream,$tmp17,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleNoDrive17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp10 = 0, $tmp11 = 0, $tmp12 = 0, $tmp13 = 0, $tmp14 = 0, $tmp15 = 0, $tmp16 = 0, $tmp17 = 0, $tmp2 = 0, $tmp3 = 0, $tmp4 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0;
 var $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $tmp = sp + 544|0;
 $tmp1 = sp + 512|0;
 $tmp2 = sp + 480|0;
 $tmp3 = sp + 448|0;
 $tmp4 = sp + 416|0;
 $tmp5 = sp + 384|0;
 $tmp6 = sp + 352|0;
 $tmp7 = sp + 320|0;
 $tmp8 = sp + 288|0;
 $tmp9 = sp + 256|0;
 $tmp10 = sp + 192|0;
 $tmp11 = sp + 160|0;
 $tmp12 = sp + 128|0;
 $tmp13 = sp + 96|0;
 $tmp14 = sp + 64|0;
 $tmp15 = sp + 32|0;
 $tmp16 = sp;
 $tmp17 = sp + 224|0;
 __ZN5physx14PxVehicleDrive17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 __ZN5physx15PxVehicleWheels17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 __ZN5physx21PxVehicleDriveSimData17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 ;HEAP32[$tmp+0>>2]=HEAP32[512144+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[512144+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[512144+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[512144+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[512144+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[512144+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[512144+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[512144+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 HEAP32[$tmp1>>2] = 512120;
 $2 = (($tmp1) + 4|0);
 HEAP32[$2>>2] = 510872;
 $3 = (($tmp1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tmp1) + 12|0);
 HEAP32[$4>>2] = 144;
 $5 = (($tmp1) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($tmp1) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($tmp1) + 24|0);
 HEAP32[$7>>2] = 1;
 $8 = (($tmp1) + 28|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$stream>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_iiii[$10 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[512192+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[512192+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[512192+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[512192+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[512192+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[512192+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[512192+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[512192+28>>2]|0;
 $11 = HEAP32[$stream>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[512240+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[512240+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[512240+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[512240+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[512240+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[512240+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[512240+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[512240+28>>2]|0;
 $13 = HEAP32[$stream>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 (FUNCTION_TABLE_iiii[$14 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[512288+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[512288+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[512288+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[512288+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[512288+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[512288+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[512288+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[512288+28>>2]|0;
 $15 = HEAP32[$stream>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 (FUNCTION_TABLE_iiii[$16 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[512320+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[512320+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[512320+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[512320+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[512320+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[512320+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[512320+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[512320+28>>2]|0;
 $17 = HEAP32[$stream>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_iiii[$18 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[512352+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[512352+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[512352+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[512352+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[512352+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[512352+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[512352+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[512352+28>>2]|0;
 $19 = HEAP32[$stream>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_iiii[$20 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[512384+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[512384+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[512384+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[512384+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[512384+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[512384+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[512384+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[512384+28>>2]|0;
 $21 = HEAP32[$stream>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 (FUNCTION_TABLE_iiii[$22 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[512384+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[512384+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[512384+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[512384+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[512384+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[512384+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[512384+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[512384+28>>2]|0;
 $23 = HEAP32[$stream>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 (FUNCTION_TABLE_iiii[$24 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[512384+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[512384+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[512384+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[512384+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[512384+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[512384+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[512384+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[512384+28>>2]|0;
 $25 = HEAP32[$stream>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 (FUNCTION_TABLE_iiii[$26 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[512416+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[512416+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[512416+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[512416+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[512416+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[512416+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[512416+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[512416+28>>2]|0;
 $27 = HEAP32[$stream>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 (FUNCTION_TABLE_iiii[$28 & 2047]($stream,$tmp10,32)|0);
 ;HEAP32[$tmp11+0>>2]=HEAP32[512416+0>>2]|0;HEAP32[$tmp11+4>>2]=HEAP32[512416+4>>2]|0;HEAP32[$tmp11+8>>2]=HEAP32[512416+8>>2]|0;HEAP32[$tmp11+12>>2]=HEAP32[512416+12>>2]|0;HEAP32[$tmp11+16>>2]=HEAP32[512416+16>>2]|0;HEAP32[$tmp11+20>>2]=HEAP32[512416+20>>2]|0;HEAP32[$tmp11+24>>2]=HEAP32[512416+24>>2]|0;HEAP32[$tmp11+28>>2]=HEAP32[512416+28>>2]|0;
 $29 = HEAP32[$stream>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 (FUNCTION_TABLE_iiii[$30 & 2047]($stream,$tmp11,32)|0);
 ;HEAP32[$tmp12+0>>2]=HEAP32[512416+0>>2]|0;HEAP32[$tmp12+4>>2]=HEAP32[512416+4>>2]|0;HEAP32[$tmp12+8>>2]=HEAP32[512416+8>>2]|0;HEAP32[$tmp12+12>>2]=HEAP32[512416+12>>2]|0;HEAP32[$tmp12+16>>2]=HEAP32[512416+16>>2]|0;HEAP32[$tmp12+20>>2]=HEAP32[512416+20>>2]|0;HEAP32[$tmp12+24>>2]=HEAP32[512416+24>>2]|0;HEAP32[$tmp12+28>>2]=HEAP32[512416+28>>2]|0;
 $31 = HEAP32[$stream>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 (FUNCTION_TABLE_iiii[$32 & 2047]($stream,$tmp12,32)|0);
 ;HEAP32[$tmp13+0>>2]=HEAP32[512416+0>>2]|0;HEAP32[$tmp13+4>>2]=HEAP32[512416+4>>2]|0;HEAP32[$tmp13+8>>2]=HEAP32[512416+8>>2]|0;HEAP32[$tmp13+12>>2]=HEAP32[512416+12>>2]|0;HEAP32[$tmp13+16>>2]=HEAP32[512416+16>>2]|0;HEAP32[$tmp13+20>>2]=HEAP32[512416+20>>2]|0;HEAP32[$tmp13+24>>2]=HEAP32[512416+24>>2]|0;HEAP32[$tmp13+28>>2]=HEAP32[512416+28>>2]|0;
 $33 = HEAP32[$stream>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_iiii[$34 & 2047]($stream,$tmp13,32)|0);
 ;HEAP32[$tmp14+0>>2]=HEAP32[512448+0>>2]|0;HEAP32[$tmp14+4>>2]=HEAP32[512448+4>>2]|0;HEAP32[$tmp14+8>>2]=HEAP32[512448+8>>2]|0;HEAP32[$tmp14+12>>2]=HEAP32[512448+12>>2]|0;HEAP32[$tmp14+16>>2]=HEAP32[512448+16>>2]|0;HEAP32[$tmp14+20>>2]=HEAP32[512448+20>>2]|0;HEAP32[$tmp14+24>>2]=HEAP32[512448+24>>2]|0;HEAP32[$tmp14+28>>2]=HEAP32[512448+28>>2]|0;
 $35 = HEAP32[$stream>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($stream,$tmp14,32)|0);
 ;HEAP32[$tmp15+0>>2]=HEAP32[512448+0>>2]|0;HEAP32[$tmp15+4>>2]=HEAP32[512448+4>>2]|0;HEAP32[$tmp15+8>>2]=HEAP32[512448+8>>2]|0;HEAP32[$tmp15+12>>2]=HEAP32[512448+12>>2]|0;HEAP32[$tmp15+16>>2]=HEAP32[512448+16>>2]|0;HEAP32[$tmp15+20>>2]=HEAP32[512448+20>>2]|0;HEAP32[$tmp15+24>>2]=HEAP32[512448+24>>2]|0;HEAP32[$tmp15+28>>2]=HEAP32[512448+28>>2]|0;
 $37 = HEAP32[$stream>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 (FUNCTION_TABLE_iiii[$38 & 2047]($stream,$tmp15,32)|0);
 ;HEAP32[$tmp16+0>>2]=HEAP32[512448+0>>2]|0;HEAP32[$tmp16+4>>2]=HEAP32[512448+4>>2]|0;HEAP32[$tmp16+8>>2]=HEAP32[512448+8>>2]|0;HEAP32[$tmp16+12>>2]=HEAP32[512448+12>>2]|0;HEAP32[$tmp16+16>>2]=HEAP32[512448+16>>2]|0;HEAP32[$tmp16+20>>2]=HEAP32[512448+20>>2]|0;HEAP32[$tmp16+24>>2]=HEAP32[512448+24>>2]|0;HEAP32[$tmp16+28>>2]=HEAP32[512448+28>>2]|0;
 $39 = HEAP32[$stream>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 (FUNCTION_TABLE_iiii[$40 & 2047]($stream,$tmp16,32)|0);
 ;HEAP32[$tmp17+0>>2]=HEAP32[512448+0>>2]|0;HEAP32[$tmp17+4>>2]=HEAP32[512448+4>>2]|0;HEAP32[$tmp17+8>>2]=HEAP32[512448+8>>2]|0;HEAP32[$tmp17+12>>2]=HEAP32[512448+12>>2]|0;HEAP32[$tmp17+16>>2]=HEAP32[512448+16>>2]|0;HEAP32[$tmp17+20>>2]=HEAP32[512448+20>>2]|0;HEAP32[$tmp17+24>>2]=HEAP32[512448+24>>2]|0;HEAP32[$tmp17+28>>2]=HEAP32[512448+28>>2]|0;
 $41 = HEAP32[$stream>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 (FUNCTION_TABLE_iiii[$42 & 2047]($stream,$tmp17,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleWheels17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp2 = 0, $tmp3 = 0, $tmp4 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $tmp = sp + 256|0;
 $tmp1 = sp + 224|0;
 $tmp2 = sp + 192|0;
 $tmp3 = sp + 160|0;
 $tmp4 = sp + 128|0;
 $tmp5 = sp + 64|0;
 $tmp6 = sp + 32|0;
 $tmp7 = sp;
 $tmp8 = sp + 96|0;
 __ZN5physx22PxVehicleWheelsSimData17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 __ZN5physx22PxVehicleWheelsDynData17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 ;HEAP32[$tmp+0>>2]=HEAP32[514536+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[514536+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[514536+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[514536+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[514536+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[514536+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[514536+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[514536+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 HEAP32[$tmp1>>2] = 510872;
 $2 = (($tmp1) + 4|0);
 HEAP32[$2>>2] = 514568;
 $3 = (($tmp1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tmp1) + 12|0);
 HEAP32[$4>>2] = 128;
 $5 = (($tmp1) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($tmp1) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($tmp1) + 24|0);
 HEAP32[$7>>2] = 1;
 $8 = (($tmp1) + 28|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$stream>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_iiii[$10 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[514592+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[514592+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[514592+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[514592+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[514592+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[514592+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[514592+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[514592+28>>2]|0;
 $11 = HEAP32[$stream>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[514640+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[514640+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[514640+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[514640+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[514640+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[514640+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[514640+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[514640+28>>2]|0;
 $13 = HEAP32[$stream>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 (FUNCTION_TABLE_iiii[$14 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[514696+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[514696+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[514696+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[514696+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[514696+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[514696+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[514696+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[514696+28>>2]|0;
 $15 = HEAP32[$stream>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 (FUNCTION_TABLE_iiii[$16 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[514752+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[514752+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[514752+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[514752+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[514752+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[514752+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[514752+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[514752+28>>2]|0;
 $17 = HEAP32[$stream>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_iiii[$18 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[514816+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[514816+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[514816+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[514816+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[514816+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[514816+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[514816+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[514816+28>>2]|0;
 $19 = HEAP32[$stream>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_iiii[$20 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[514848+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[514848+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[514848+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[514848+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[514848+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[514848+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[514848+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[514848+28>>2]|0;
 $21 = HEAP32[$stream>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 (FUNCTION_TABLE_iiii[$22 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[514880+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[514880+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[514880+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[514880+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[514880+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[514880+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[514880+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[514880+28>>2]|0;
 $23 = HEAP32[$stream>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 (FUNCTION_TABLE_iiii[$24 & 2047]($stream,$tmp8,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleNoDrive15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($1)|0);
 $3 = HEAP32[$stream>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($stream,16);
 $6 = HEAP32[$stream>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viii[$8 & 4095]($stream,$10,$2);
 $11 = HEAP32[$0>>2]|0;
 $12 = $11 << 4;
 $13 = HEAP32[$stream>>2]|0;
 $14 = (($13) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($stream,16);
 $16 = HEAP32[$stream>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 128|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_viii[$18 & 4095]($stream,$20,$12);
 $21 = HEAP32[$stream>>2]|0;
 $22 = (($21) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 132|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_viii[$23 & 4095]($stream,$25,$12);
 $26 = HEAP32[$stream>>2]|0;
 $27 = (($26) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 136|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_viii[$28 & 4095]($stream,$30,$12);
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleWheels15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($1)|0);
 $3 = HEAP32[$stream>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($stream,16);
 $6 = HEAP32[$stream>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viii[$8 & 4095]($stream,$10,$2);
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleNoDrive12createObjectERPhRNS_24PxDeserializationContextE($address,$context) {
 $address = $address|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$address>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $5 = 0;
 } else {
  $2 = (($0) + 6|0);
  HEAP16[$2>>1] = 2;
  HEAP32[$0>>2] = ((518776 + 8|0));
  $5 = $0;
 }
 $3 = (($0) + 144|0);
 HEAP32[$address>>2] = $3;
 $4 = (($5) + 44|0);
 $6 = HEAP32[$4>>2]|0;
 $7 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($6)|0);
 $8 = (($context) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) + 15)|0;
 $12 = $11 & -16;
 $13 = $12;
 $14 = (($13) + ($7)|0);
 HEAP32[$8>>2] = $14;
 $15 = HEAP32[$4>>2]|0;
 $16 = (($5) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 (__ZN5physx15PxVehicleWheels15patchupPointersEPS0_Phjjb($5,$13,$15,$17,0)|0);
 $18 = HEAP32[$8>>2]|0;
 $19 = $18;
 $20 = (($19) + 15)|0;
 $21 = $20 & -16;
 $22 = $21;
 $23 = HEAP32[$4>>2]|0;
 $24 = $23 << 4;
 $25 = $21;
 $26 = (($22) + ($24)|0);
 HEAP32[$8>>2] = $26;
 $27 = (($5) + 128|0);
 HEAP32[$27>>2] = $25;
 $28 = HEAP32[$8>>2]|0;
 $29 = (($28) + ($24)|0);
 HEAP32[$8>>2] = $29;
 $30 = (($5) + 132|0);
 HEAP32[$30>>2] = $28;
 $31 = HEAP32[$8>>2]|0;
 $32 = (($31) + ($24)|0);
 HEAP32[$8>>2] = $32;
 $33 = (($5) + 136|0);
 HEAP32[$33>>2] = $31;
 __ZN5physx15PxVehicleWheels17resolveReferencesERNS_24PxDeserializationContextE($5,$context);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx16PxVehicleDrive4W17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmp = sp + 64|0;
 $tmp1 = sp;
 $tmp2 = sp + 32|0;
 __ZN5physx14PxVehicleDrive17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 __ZN5physx15PxVehicleWheels17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 __ZN5physx21PxVehicleDriveSimData17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 __ZN5physx23PxVehicleDriveSimData4W17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 ;HEAP32[$tmp+0>>2]=HEAP32[512504+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[512504+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[512504+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[512504+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[512504+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[512504+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[512504+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[512504+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 HEAP32[$tmp1>>2] = 512480;
 $2 = (($tmp1) + 4|0);
 HEAP32[$2>>2] = 510824;
 $3 = (($tmp1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tmp1) + 12|0);
 HEAP32[$4>>2] = 800;
 $5 = (($tmp1) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($tmp1) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($tmp1) + 24|0);
 HEAP32[$7>>2] = 1;
 $8 = (($tmp1) + 28|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$stream>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_iiii[$10 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[512552+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[512552+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[512552+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[512552+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[512552+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[512552+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[512552+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[512552+28>>2]|0;
 $11 = HEAP32[$stream>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$tmp2,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleDrive4W12createObjectERPhRNS_24PxDeserializationContextE($address,$context) {
 $address = $address|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$address>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $5 = 0;
 } else {
  $2 = (($0) + 6|0);
  HEAP16[$2>>1] = 2;
  HEAP32[$0>>2] = ((518896 + 8|0));
  $5 = $0;
 }
 $3 = (($0) + 800|0);
 HEAP32[$address>>2] = $3;
 $4 = (($5) + 44|0);
 $6 = HEAP32[$4>>2]|0;
 $7 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($6)|0);
 $8 = (($context) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) + 15)|0;
 $12 = $11 & -16;
 $13 = $12;
 $14 = (($13) + ($7)|0);
 HEAP32[$8>>2] = $14;
 $15 = HEAP32[$4>>2]|0;
 $16 = (($5) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 (__ZN5physx15PxVehicleWheels15patchupPointersEPS0_Phjjb($5,$13,$15,$17,0)|0);
 __ZN5physx15PxVehicleWheels17resolveReferencesERNS_24PxDeserializationContextE($5,$context);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx16PxVehicleDriveNW17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp$i = 0, $tmp1 = 0, $tmp1$i = 0;
 var $tmp2 = 0, $tmp2$i = 0, $tmp3$i = 0, $tmp4$i = 0, $tmp5$i = 0, $tmp6$i = 0, $tmp7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $tmp$i = sp + 320|0;
 $tmp1$i = sp + 288|0;
 $tmp2$i = sp + 256|0;
 $tmp3$i = sp + 224|0;
 $tmp4$i = sp + 192|0;
 $tmp5$i = sp + 160|0;
 $tmp6$i = sp + 96|0;
 $tmp7$i = sp + 64|0;
 $tmp = sp + 32|0;
 $tmp1 = sp;
 $tmp2 = sp + 128|0;
 ;HEAP32[$tmp$i+0>>2]=HEAP32[511816+0>>2]|0;HEAP32[$tmp$i+4>>2]=HEAP32[511816+4>>2]|0;HEAP32[$tmp$i+8>>2]=HEAP32[511816+8>>2]|0;HEAP32[$tmp$i+12>>2]=HEAP32[511816+12>>2]|0;HEAP32[$tmp$i+16>>2]=HEAP32[511816+16>>2]|0;HEAP32[$tmp$i+20>>2]=HEAP32[511816+20>>2]|0;HEAP32[$tmp$i+24>>2]=HEAP32[511816+24>>2]|0;HEAP32[$tmp$i+28>>2]=HEAP32[511816+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp$i,32)|0);
 ;HEAP32[$tmp1$i+0>>2]=HEAP32[511864+0>>2]|0;HEAP32[$tmp1$i+4>>2]=HEAP32[511864+4>>2]|0;HEAP32[$tmp1$i+8>>2]=HEAP32[511864+8>>2]|0;HEAP32[$tmp1$i+12>>2]=HEAP32[511864+12>>2]|0;HEAP32[$tmp1$i+16>>2]=HEAP32[511864+16>>2]|0;HEAP32[$tmp1$i+20>>2]=HEAP32[511864+20>>2]|0;HEAP32[$tmp1$i+24>>2]=HEAP32[511864+24>>2]|0;HEAP32[$tmp1$i+28>>2]=HEAP32[511864+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1$i,32)|0);
 ;HEAP32[$tmp2$i+0>>2]=HEAP32[511912+0>>2]|0;HEAP32[$tmp2$i+4>>2]=HEAP32[511912+4>>2]|0;HEAP32[$tmp2$i+8>>2]=HEAP32[511912+8>>2]|0;HEAP32[$tmp2$i+12>>2]=HEAP32[511912+12>>2]|0;HEAP32[$tmp2$i+16>>2]=HEAP32[511912+16>>2]|0;HEAP32[$tmp2$i+20>>2]=HEAP32[511912+20>>2]|0;HEAP32[$tmp2$i+24>>2]=HEAP32[511912+24>>2]|0;HEAP32[$tmp2$i+28>>2]=HEAP32[511912+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2$i,32)|0);
 ;HEAP32[$tmp3$i+0>>2]=HEAP32[511968+0>>2]|0;HEAP32[$tmp3$i+4>>2]=HEAP32[511968+4>>2]|0;HEAP32[$tmp3$i+8>>2]=HEAP32[511968+8>>2]|0;HEAP32[$tmp3$i+12>>2]=HEAP32[511968+12>>2]|0;HEAP32[$tmp3$i+16>>2]=HEAP32[511968+16>>2]|0;HEAP32[$tmp3$i+20>>2]=HEAP32[511968+20>>2]|0;HEAP32[$tmp3$i+24>>2]=HEAP32[511968+24>>2]|0;HEAP32[$tmp3$i+28>>2]=HEAP32[511968+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3$i,32)|0);
 ;HEAP32[$tmp4$i+0>>2]=HEAP32[512000+0>>2]|0;HEAP32[$tmp4$i+4>>2]=HEAP32[512000+4>>2]|0;HEAP32[$tmp4$i+8>>2]=HEAP32[512000+8>>2]|0;HEAP32[$tmp4$i+12>>2]=HEAP32[512000+12>>2]|0;HEAP32[$tmp4$i+16>>2]=HEAP32[512000+16>>2]|0;HEAP32[$tmp4$i+20>>2]=HEAP32[512000+20>>2]|0;HEAP32[$tmp4$i+24>>2]=HEAP32[512000+24>>2]|0;HEAP32[$tmp4$i+28>>2]=HEAP32[512000+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp4$i,32)|0);
 ;HEAP32[$tmp5$i+0>>2]=HEAP32[512056+0>>2]|0;HEAP32[$tmp5$i+4>>2]=HEAP32[512056+4>>2]|0;HEAP32[$tmp5$i+8>>2]=HEAP32[512056+8>>2]|0;HEAP32[$tmp5$i+12>>2]=HEAP32[512056+12>>2]|0;HEAP32[$tmp5$i+16>>2]=HEAP32[512056+16>>2]|0;HEAP32[$tmp5$i+20>>2]=HEAP32[512056+20>>2]|0;HEAP32[$tmp5$i+24>>2]=HEAP32[512056+24>>2]|0;HEAP32[$tmp5$i+28>>2]=HEAP32[512056+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp5$i,32)|0);
 HEAP32[$tmp6$i>>2] = 512032;
 $12 = (($tmp6$i) + 4|0);
 HEAP32[$12>>2] = 510048;
 $13 = (($tmp6$i) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($tmp6$i) + 12|0);
 HEAP32[$14>>2] = 544;
 $15 = (($tmp6$i) + 16|0);
 HEAP32[$15>>2] = 0;
 $16 = (($tmp6$i) + 20|0);
 HEAP32[$16>>2] = 0;
 $17 = (($tmp6$i) + 24|0);
 HEAP32[$17>>2] = 1;
 $18 = (($tmp6$i) + 28|0);
 HEAP32[$18>>2] = 0;
 $19 = HEAP32[$stream>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_iiii[$20 & 2047]($stream,$tmp6$i,32)|0);
 ;HEAP32[$tmp7$i+0>>2]=HEAP32[512088+0>>2]|0;HEAP32[$tmp7$i+4>>2]=HEAP32[512088+4>>2]|0;HEAP32[$tmp7$i+8>>2]=HEAP32[512088+8>>2]|0;HEAP32[$tmp7$i+12>>2]=HEAP32[512088+12>>2]|0;HEAP32[$tmp7$i+16>>2]=HEAP32[512088+16>>2]|0;HEAP32[$tmp7$i+20>>2]=HEAP32[512088+20>>2]|0;HEAP32[$tmp7$i+24>>2]=HEAP32[512088+24>>2]|0;HEAP32[$tmp7$i+28>>2]=HEAP32[512088+28>>2]|0;
 $21 = HEAP32[$stream>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 (FUNCTION_TABLE_iiii[$22 & 2047]($stream,$tmp7$i,32)|0);
 ;HEAP32[$tmp+0>>2]=HEAP32[512608+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[512608+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[512608+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[512608+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[512608+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[512608+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[512608+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[512608+28>>2]|0;
 $23 = HEAP32[$stream>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 (FUNCTION_TABLE_iiii[$24 & 2047]($stream,$tmp,32)|0);
 HEAP32[$tmp1>>2] = 512584;
 $25 = (($tmp1) + 4|0);
 HEAP32[$25>>2] = 510824;
 $26 = (($tmp1) + 8|0);
 HEAP32[$26>>2] = 0;
 $27 = (($tmp1) + 12|0);
 HEAP32[$27>>2] = 768;
 $28 = (($tmp1) + 16|0);
 HEAP32[$28>>2] = 0;
 $29 = (($tmp1) + 20|0);
 HEAP32[$29>>2] = 0;
 $30 = (($tmp1) + 24|0);
 HEAP32[$30>>2] = 1;
 $31 = (($tmp1) + 28|0);
 HEAP32[$31>>2] = 0;
 $32 = HEAP32[$stream>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 (FUNCTION_TABLE_iiii[$33 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[512640+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[512640+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[512640+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[512640+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[512640+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[512640+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[512640+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[512640+28>>2]|0;
 $34 = HEAP32[$stream>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($stream,$tmp2,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleDriveNW12createObjectERPhRNS_24PxDeserializationContextE($address,$context) {
 $address = $address|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$address>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $5 = 0;
 } else {
  $2 = (($0) + 6|0);
  HEAP16[$2>>1] = 2;
  HEAP32[$0>>2] = ((518856 + 8|0));
  $5 = $0;
 }
 $3 = (($0) + 768|0);
 HEAP32[$address>>2] = $3;
 $4 = (($5) + 44|0);
 $6 = HEAP32[$4>>2]|0;
 $7 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($6)|0);
 $8 = (($context) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) + 15)|0;
 $12 = $11 & -16;
 $13 = $12;
 $14 = (($13) + ($7)|0);
 HEAP32[$8>>2] = $14;
 $15 = HEAP32[$4>>2]|0;
 $16 = (($5) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 (__ZN5physx15PxVehicleWheels15patchupPointersEPS0_Phjjb($5,$13,$15,$17,0)|0);
 __ZN5physx15PxVehicleWheels17resolveReferencesERNS_24PxDeserializationContextE($5,$context);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx18PxVehicleDriveTank17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp2 = 0;
 var $tmp3 = 0, $tmp4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $tmp = sp + 128|0;
 $tmp1 = sp;
 $tmp2 = sp + 32|0;
 $tmp3 = sp + 64|0;
 $tmp4 = sp + 96|0;
 ;HEAP32[$tmp+0>>2]=HEAP32[512696+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[512696+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[512696+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[512696+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[512696+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[512696+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[512696+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[512696+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 HEAP32[$tmp1>>2] = 512672;
 $2 = (($tmp1) + 4|0);
 HEAP32[$2>>2] = 510824;
 $3 = (($tmp1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tmp1) + 12|0);
 HEAP32[$4>>2] = 768;
 $5 = (($tmp1) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($tmp1) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($tmp1) + 24|0);
 HEAP32[$7>>2] = 1;
 $8 = (($tmp1) + 28|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$stream>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_iiii[$10 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[512728+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[512728+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[512728+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[512728+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[512728+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[512728+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[512728+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[512728+28>>2]|0;
 $11 = HEAP32[$stream>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[512776+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[512776+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[512776+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[512776+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[512776+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[512776+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[512776+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[512776+28>>2]|0;
 $13 = HEAP32[$stream>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 (FUNCTION_TABLE_iiii[$14 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[512808+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[512808+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[512808+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[512808+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[512808+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[512808+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[512808+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[512808+28>>2]|0;
 $15 = HEAP32[$stream>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 (FUNCTION_TABLE_iiii[$16 & 2047]($stream,$tmp4,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx18PxVehicleDriveTank12createObjectERPhRNS_24PxDeserializationContextE($address,$context) {
 $address = $address|0;
 $context = $context|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i$i$i$i = 0, $i$01$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$address>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $37 = 0;$39 = 0;
  $36 = (($37) + 768|0);
  HEAP32[$address>>2] = $36;
  $38 = (($39) + 44|0);
  $40 = HEAP32[$38>>2]|0;
  $41 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($40)|0);
  $42 = (($context) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = $43;
  $45 = (($44) + 15)|0;
  $46 = $45 & -16;
  $47 = $46;
  $48 = (($47) + ($41)|0);
  HEAP32[$42>>2] = $48;
  $49 = HEAP32[$38>>2]|0;
  $50 = (($39) + 48|0);
  $51 = HEAP32[$50>>2]|0;
  (__ZN5physx15PxVehicleWheels15patchupPointersEPS0_Phjjb($39,$47,$49,$51,0)|0);
  __ZN5physx15PxVehicleWheels17resolveReferencesERNS_24PxDeserializationContextE($39,$context);
  STACKTOP = sp;return ($39|0);
 }
 $2 = (($0) + 6|0);
 HEAP16[$2>>1] = 2;
 HEAP32[$0>>2] = ((518816 + 8|0));
 $3 = (($0) + 288|0);
 $4 = (($0) + 304|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($0) + 308|0);
 HEAPF32[$5>>2] = Math_fround(500.0);
 $6 = (($0) + 312|0);
 HEAPF32[$6>>2] = Math_fround(600.0);
 $7 = (($0) + 316|0);
 HEAPF32[$7>>2] = Math_fround(0.150000005960464477539);
 $8 = (($0) + 320|0);
 HEAPF32[$8>>2] = Math_fround(2.0);
 $9 = (($0) + 324|0);
 HEAPF32[$9>>2] = Math_fround(0.349999994039535522461);
 $10 = (($0) + 224|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($0) + 228|0);
 HEAPF32[$11>>2] = Math_fround(0.800000011920928955078);
 $12 = (($0) + 232|0);
 HEAPF32[$12>>2] = Math_fround(0.330000013113021850586);
 $13 = (($0) + 236|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($0) + 240|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($0) + 244|0);
 HEAPF32[$15>>2] = Math_fround(0.800000011920928955078);
 HEAP32[$3>>2] = 3;
 $16 = (($0) + 328|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($0) + 332|0);
 HEAPF32[$17>>2] = Math_fround(0.00166666670702397823334);
 $18 = (($0) + 464|0);
 HEAPF32[$18>>2] = Math_fround(4.0);
 $19 = (($0) + 468|0);
 HEAP32[$19>>2] = 7;
 $20 = (($0) + 472|0);
 HEAPF32[$20>>2] = Math_fround(0.5);
 $21 = (($0) + 336|0);
 HEAPF32[$21>>2] = Math_fround(-4.0);
 $22 = (($0) + 340|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($0) + 344|0);
 HEAPF32[$23>>2] = Math_fround(4.0);
 $24 = (($0) + 348|0);
 HEAPF32[$24>>2] = Math_fround(2.0);
 $25 = (($0) + 352|0);
 HEAPF32[$25>>2] = Math_fround(1.5);
 $26 = (($0) + 356|0);
 HEAPF32[$26>>2] = Math_fround(1.10000002384185791016);
 $27 = (($0) + 360|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $scevgep$i$i$i$i$i$i = (($0) + 364|0);
 dest=$scevgep$i$i$i$i$i$i+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $28 = (($0) + 480|0);
 HEAPF32[$28>>2] = Math_fround(10.0);
 $29 = (($0) + 484|0);
 HEAP32[$29>>2] = 1;
 $30 = (($0) + 488|0);
 HEAP32[$30>>2] = 5;
 $i$01$i$i$i$i$i$i = 0;
 while(1) {
  $31 = ((($0) + ($i$01$i$i$i$i$i$i<<2)|0) + 496|0);
  HEAPF32[$31>>2] = Math_fround(0.649999976158142089844);
  $32 = ((($0) + ($i$01$i$i$i$i$i$i<<2)|0) + 624|0);
  HEAPF32[$32>>2] = Math_fround(0.5);
  $33 = (($i$01$i$i$i$i$i$i) + 1)|0;
  $exitcond$i$i$i$i$i$i = ($33|0)==(32);
  if ($exitcond$i$i$i$i$i$i) {
   break;
  } else {
   $i$01$i$i$i$i$i$i = $33;
  }
 }
 $34 = (($0) + 500|0);
 HEAPF32[$34>>2] = Math_fround(0.150000005960464477539);
 $35 = (($0) + 624|0);
 HEAPF32[$35>>2] = Math_fround(2.0);
 $$pre = HEAP32[$address>>2]|0;
 $37 = $$pre;$39 = $0;
 $36 = (($37) + 768|0);
 HEAP32[$address>>2] = $36;
 $38 = (($39) + 44|0);
 $40 = HEAP32[$38>>2]|0;
 $41 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($40)|0);
 $42 = (($context) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43;
 $45 = (($44) + 15)|0;
 $46 = $45 & -16;
 $47 = $46;
 $48 = (($47) + ($41)|0);
 HEAP32[$42>>2] = $48;
 $49 = HEAP32[$38>>2]|0;
 $50 = (($39) + 48|0);
 $51 = HEAP32[$50>>2]|0;
 (__ZN5physx15PxVehicleWheels15patchupPointersEPS0_Phjjb($39,$47,$49,$51,0)|0);
 __ZN5physx15PxVehicleWheels17resolveReferencesERNS_24PxDeserializationContextE($39,$context);
 STACKTOP = sp;return ($39|0);
}
function __ZN5physx22PxVehicleWheelsSimData17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp10 = 0, $tmp11 = 0;
 var $tmp12 = 0, $tmp13 = 0, $tmp14 = 0, $tmp15 = 0, $tmp16 = 0, $tmp17 = 0, $tmp2 = 0, $tmp3 = 0, $tmp4 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0, $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $tmp = sp + 544|0;
 $tmp1 = sp + 512|0;
 $tmp2 = sp + 480|0;
 $tmp3 = sp + 448|0;
 $tmp4 = sp + 416|0;
 $tmp5 = sp + 384|0;
 $tmp6 = sp + 352|0;
 $tmp7 = sp + 320|0;
 $tmp8 = sp + 288|0;
 $tmp9 = sp + 256|0;
 $tmp10 = sp + 192|0;
 $tmp11 = sp + 160|0;
 $tmp12 = sp + 128|0;
 $tmp13 = sp + 96|0;
 $tmp14 = sp + 64|0;
 $tmp15 = sp + 32|0;
 $tmp16 = sp;
 $tmp17 = sp + 224|0;
 __ZN5physx23PxVehicleWheels4SimData17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 ;HEAP32[$tmp+0>>2]=HEAP32[512872+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[512872+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[512872+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[512872+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[512872+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[512872+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[512872+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[512872+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 ;HEAP32[$tmp1+0>>2]=HEAP32[512928+0>>2]|0;HEAP32[$tmp1+4>>2]=HEAP32[512928+4>>2]|0;HEAP32[$tmp1+8>>2]=HEAP32[512928+8>>2]|0;HEAP32[$tmp1+12>>2]=HEAP32[512928+12>>2]|0;HEAP32[$tmp1+16>>2]=HEAP32[512928+16>>2]|0;HEAP32[$tmp1+20>>2]=HEAP32[512928+20>>2]|0;HEAP32[$tmp1+24>>2]=HEAP32[512928+24>>2]|0;HEAP32[$tmp1+28>>2]=HEAP32[512928+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[512992+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[512992+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[512992+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[512992+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[512992+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[512992+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[512992+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[512992+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[513048+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[513048+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[513048+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[513048+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[513048+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[513048+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[513048+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[513048+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[513112+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[513112+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[513112+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[513112+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[513112+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[513112+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[513112+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[513112+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[513160+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[513160+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[513160+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[513160+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[513160+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[513160+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[513160+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[513160+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[514304+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[514304+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[514304+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[514304+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[514304+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[514304+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[514304+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[514304+28>>2]|0;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[513216+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[513216+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[513216+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[513216+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[513216+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[513216+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[513216+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[513216+28>>2]|0;
 $14 = HEAP32[$stream>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_iiii[$15 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[513272+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[513272+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[513272+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[513272+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[513272+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[513272+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[513272+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[513272+28>>2]|0;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[513344+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[513344+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[513344+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[513344+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[513344+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[513344+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[513344+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[513344+28>>2]|0;
 $18 = HEAP32[$stream>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[513392+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[513392+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[513392+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[513392+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[513392+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[513392+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[513392+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[513392+28>>2]|0;
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$tmp10,32)|0);
 ;HEAP32[$tmp11+0>>2]=HEAP32[513440+0>>2]|0;HEAP32[$tmp11+4>>2]=HEAP32[513440+4>>2]|0;HEAP32[$tmp11+8>>2]=HEAP32[513440+8>>2]|0;HEAP32[$tmp11+12>>2]=HEAP32[513440+12>>2]|0;HEAP32[$tmp11+16>>2]=HEAP32[513440+16>>2]|0;HEAP32[$tmp11+20>>2]=HEAP32[513440+20>>2]|0;HEAP32[$tmp11+24>>2]=HEAP32[513440+24>>2]|0;HEAP32[$tmp11+28>>2]=HEAP32[513440+28>>2]|0;
 $22 = HEAP32[$stream>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_iiii[$23 & 2047]($stream,$tmp11,32)|0);
 ;HEAP32[$tmp12+0>>2]=HEAP32[513504+0>>2]|0;HEAP32[$tmp12+4>>2]=HEAP32[513504+4>>2]|0;HEAP32[$tmp12+8>>2]=HEAP32[513504+8>>2]|0;HEAP32[$tmp12+12>>2]=HEAP32[513504+12>>2]|0;HEAP32[$tmp12+16>>2]=HEAP32[513504+16>>2]|0;HEAP32[$tmp12+20>>2]=HEAP32[513504+20>>2]|0;HEAP32[$tmp12+24>>2]=HEAP32[513504+24>>2]|0;HEAP32[$tmp12+28>>2]=HEAP32[513504+28>>2]|0;
 $24 = HEAP32[$stream>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_iiii[$25 & 2047]($stream,$tmp12,32)|0);
 ;HEAP32[$tmp13+0>>2]=HEAP32[513568+0>>2]|0;HEAP32[$tmp13+4>>2]=HEAP32[513568+4>>2]|0;HEAP32[$tmp13+8>>2]=HEAP32[513568+8>>2]|0;HEAP32[$tmp13+12>>2]=HEAP32[513568+12>>2]|0;HEAP32[$tmp13+16>>2]=HEAP32[513568+16>>2]|0;HEAP32[$tmp13+20>>2]=HEAP32[513568+20>>2]|0;HEAP32[$tmp13+24>>2]=HEAP32[513568+24>>2]|0;HEAP32[$tmp13+28>>2]=HEAP32[513568+28>>2]|0;
 $26 = HEAP32[$stream>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_iiii[$27 & 2047]($stream,$tmp13,32)|0);
 ;HEAP32[$tmp14+0>>2]=HEAP32[513632+0>>2]|0;HEAP32[$tmp14+4>>2]=HEAP32[513632+4>>2]|0;HEAP32[$tmp14+8>>2]=HEAP32[513632+8>>2]|0;HEAP32[$tmp14+12>>2]=HEAP32[513632+12>>2]|0;HEAP32[$tmp14+16>>2]=HEAP32[513632+16>>2]|0;HEAP32[$tmp14+20>>2]=HEAP32[513632+20>>2]|0;HEAP32[$tmp14+24>>2]=HEAP32[513632+24>>2]|0;HEAP32[$tmp14+28>>2]=HEAP32[513632+28>>2]|0;
 $28 = HEAP32[$stream>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 (FUNCTION_TABLE_iiii[$29 & 2047]($stream,$tmp14,32)|0);
 ;HEAP32[$tmp15+0>>2]=HEAP32[513696+0>>2]|0;HEAP32[$tmp15+4>>2]=HEAP32[513696+4>>2]|0;HEAP32[$tmp15+8>>2]=HEAP32[513696+8>>2]|0;HEAP32[$tmp15+12>>2]=HEAP32[513696+12>>2]|0;HEAP32[$tmp15+16>>2]=HEAP32[513696+16>>2]|0;HEAP32[$tmp15+20>>2]=HEAP32[513696+20>>2]|0;HEAP32[$tmp15+24>>2]=HEAP32[513696+24>>2]|0;HEAP32[$tmp15+28>>2]=HEAP32[513696+28>>2]|0;
 $30 = HEAP32[$stream>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 (FUNCTION_TABLE_iiii[$31 & 2047]($stream,$tmp15,32)|0);
 ;HEAP32[$tmp16+0>>2]=HEAP32[513752+0>>2]|0;HEAP32[$tmp16+4>>2]=HEAP32[513752+4>>2]|0;HEAP32[$tmp16+8>>2]=HEAP32[513752+8>>2]|0;HEAP32[$tmp16+12>>2]=HEAP32[513752+12>>2]|0;HEAP32[$tmp16+16>>2]=HEAP32[513752+16>>2]|0;HEAP32[$tmp16+20>>2]=HEAP32[513752+20>>2]|0;HEAP32[$tmp16+24>>2]=HEAP32[513752+24>>2]|0;HEAP32[$tmp16+28>>2]=HEAP32[513752+28>>2]|0;
 $32 = HEAP32[$stream>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 (FUNCTION_TABLE_iiii[$33 & 2047]($stream,$tmp16,32)|0);
 ;HEAP32[$tmp17+0>>2]=HEAP32[513784+0>>2]|0;HEAP32[$tmp17+4>>2]=HEAP32[513784+4>>2]|0;HEAP32[$tmp17+8>>2]=HEAP32[513784+8>>2]|0;HEAP32[$tmp17+12>>2]=HEAP32[513784+12>>2]|0;HEAP32[$tmp17+16>>2]=HEAP32[513784+16>>2]|0;HEAP32[$tmp17+20>>2]=HEAP32[513784+20>>2]|0;HEAP32[$tmp17+24>>2]=HEAP32[513784+24>>2]|0;HEAP32[$tmp17+28>>2]=HEAP32[513784+28>>2]|0;
 $34 = HEAP32[$stream>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($stream,$tmp17,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $tmp = 0, $tmp1 = 0;
 var $tmp10 = 0, $tmp11 = 0, $tmp12 = 0, $tmp13 = 0, $tmp14 = 0, $tmp15 = 0, $tmp16 = 0, $tmp17 = 0, $tmp18 = 0, $tmp19 = 0, $tmp2 = 0, $tmp20 = 0, $tmp21 = 0, $tmp22 = 0, $tmp23 = 0, $tmp24 = 0, $tmp25 = 0, $tmp26 = 0, $tmp27 = 0, $tmp28 = 0;
 var $tmp29 = 0, $tmp3 = 0, $tmp30 = 0, $tmp31 = 0, $tmp32 = 0, $tmp33 = 0, $tmp34 = 0, $tmp35 = 0, $tmp36 = 0, $tmp37 = 0, $tmp38 = 0, $tmp39 = 0, $tmp4 = 0, $tmp40 = 0, $tmp41 = 0, $tmp42 = 0, $tmp43 = 0, $tmp44 = 0, $tmp45 = 0, $tmp46 = 0;
 var $tmp47 = 0, $tmp48 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0, $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1568|0;
 $tmp = sp + 1536|0;
 $tmp1 = sp + 1504|0;
 $tmp2 = sp + 1472|0;
 $tmp3 = sp + 1440|0;
 $tmp4 = sp + 1408|0;
 $tmp5 = sp + 1376|0;
 $tmp6 = sp + 1344|0;
 $tmp7 = sp + 1312|0;
 $tmp8 = sp + 1280|0;
 $tmp9 = sp + 1248|0;
 $tmp10 = sp + 1216|0;
 $tmp11 = sp + 1184|0;
 $tmp12 = sp + 1152|0;
 $tmp13 = sp + 1120|0;
 $tmp14 = sp + 1088|0;
 $tmp15 = sp + 1056|0;
 $tmp16 = sp + 1024|0;
 $tmp17 = sp + 992|0;
 $tmp18 = sp + 960|0;
 $tmp19 = sp + 928|0;
 $tmp20 = sp + 896|0;
 $tmp21 = sp + 864|0;
 $tmp22 = sp + 832|0;
 $tmp23 = sp + 800|0;
 $tmp24 = sp + 768|0;
 $tmp25 = sp + 320|0;
 $tmp26 = sp + 288|0;
 $tmp27 = sp + 256|0;
 $tmp28 = sp + 224|0;
 $tmp29 = sp + 192|0;
 $tmp30 = sp + 160|0;
 $tmp31 = sp + 96|0;
 $tmp32 = sp + 64|0;
 $tmp33 = sp + 32|0;
 $tmp34 = sp;
 $tmp35 = sp + 128|0;
 $tmp36 = sp + 352|0;
 $tmp37 = sp + 384|0;
 $tmp38 = sp + 416|0;
 $tmp39 = sp + 448|0;
 $tmp40 = sp + 480|0;
 $tmp41 = sp + 512|0;
 $tmp42 = sp + 544|0;
 $tmp43 = sp + 576|0;
 $tmp44 = sp + 608|0;
 $tmp45 = sp + 640|0;
 $tmp46 = sp + 672|0;
 $tmp47 = sp + 704|0;
 $tmp48 = sp + 736|0;
 ;HEAP32[$tmp+0>>2]=HEAP32[515744+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[515744+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[515744+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[515744+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[515744+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[515744+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[515744+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[515744+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 ;HEAP32[$tmp1+0>>2]=HEAP32[515792+0>>2]|0;HEAP32[$tmp1+4>>2]=HEAP32[515792+4>>2]|0;HEAP32[$tmp1+8>>2]=HEAP32[515792+8>>2]|0;HEAP32[$tmp1+12>>2]=HEAP32[515792+12>>2]|0;HEAP32[$tmp1+16>>2]=HEAP32[515792+16>>2]|0;HEAP32[$tmp1+20>>2]=HEAP32[515792+20>>2]|0;HEAP32[$tmp1+24>>2]=HEAP32[515792+24>>2]|0;HEAP32[$tmp1+28>>2]=HEAP32[515792+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[515848+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[515848+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[515848+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[515848+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[515848+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[515848+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[515848+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[515848+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[515896+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[515896+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[515896+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[515896+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[515896+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[515896+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[515896+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[515896+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[515944+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[515944+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[515944+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[515944+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[515944+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[515944+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[515944+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[515944+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[515992+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[515992+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[515992+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[515992+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[515992+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[515992+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[515992+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[515992+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[516040+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[516040+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[516040+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[516040+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[516040+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[516040+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[516040+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[516040+28>>2]|0;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[516096+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[516096+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[516096+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[516096+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[516096+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[516096+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[516096+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[516096+28>>2]|0;
 $14 = HEAP32[$stream>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_iiii[$15 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[516152+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[516152+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[516152+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[516152+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[516152+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[516152+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[516152+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[516152+28>>2]|0;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[516208+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[516208+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[516208+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[516208+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[516208+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[516208+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[516208+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[516208+28>>2]|0;
 $18 = HEAP32[$stream>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[516256+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[516256+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[516256+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[516256+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[516256+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[516256+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[516256+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[516256+28>>2]|0;
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$tmp10,32)|0);
 ;HEAP32[$tmp11+0>>2]=HEAP32[516288+0>>2]|0;HEAP32[$tmp11+4>>2]=HEAP32[516288+4>>2]|0;HEAP32[$tmp11+8>>2]=HEAP32[516288+8>>2]|0;HEAP32[$tmp11+12>>2]=HEAP32[516288+12>>2]|0;HEAP32[$tmp11+16>>2]=HEAP32[516288+16>>2]|0;HEAP32[$tmp11+20>>2]=HEAP32[516288+20>>2]|0;HEAP32[$tmp11+24>>2]=HEAP32[516288+24>>2]|0;HEAP32[$tmp11+28>>2]=HEAP32[516288+28>>2]|0;
 $22 = HEAP32[$stream>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_iiii[$23 & 2047]($stream,$tmp11,32)|0);
 ;HEAP32[$tmp12+0>>2]=HEAP32[516344+0>>2]|0;HEAP32[$tmp12+4>>2]=HEAP32[516344+4>>2]|0;HEAP32[$tmp12+8>>2]=HEAP32[516344+8>>2]|0;HEAP32[$tmp12+12>>2]=HEAP32[516344+12>>2]|0;HEAP32[$tmp12+16>>2]=HEAP32[516344+16>>2]|0;HEAP32[$tmp12+20>>2]=HEAP32[516344+20>>2]|0;HEAP32[$tmp12+24>>2]=HEAP32[516344+24>>2]|0;HEAP32[$tmp12+28>>2]=HEAP32[516344+28>>2]|0;
 $24 = HEAP32[$stream>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_iiii[$25 & 2047]($stream,$tmp12,32)|0);
 ;HEAP32[$tmp13+0>>2]=HEAP32[516384+0>>2]|0;HEAP32[$tmp13+4>>2]=HEAP32[516384+4>>2]|0;HEAP32[$tmp13+8>>2]=HEAP32[516384+8>>2]|0;HEAP32[$tmp13+12>>2]=HEAP32[516384+12>>2]|0;HEAP32[$tmp13+16>>2]=HEAP32[516384+16>>2]|0;HEAP32[$tmp13+20>>2]=HEAP32[516384+20>>2]|0;HEAP32[$tmp13+24>>2]=HEAP32[516384+24>>2]|0;HEAP32[$tmp13+28>>2]=HEAP32[516384+28>>2]|0;
 $26 = HEAP32[$stream>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_iiii[$27 & 2047]($stream,$tmp13,32)|0);
 ;HEAP32[$tmp14+0>>2]=HEAP32[516424+0>>2]|0;HEAP32[$tmp14+4>>2]=HEAP32[516424+4>>2]|0;HEAP32[$tmp14+8>>2]=HEAP32[516424+8>>2]|0;HEAP32[$tmp14+12>>2]=HEAP32[516424+12>>2]|0;HEAP32[$tmp14+16>>2]=HEAP32[516424+16>>2]|0;HEAP32[$tmp14+20>>2]=HEAP32[516424+20>>2]|0;HEAP32[$tmp14+24>>2]=HEAP32[516424+24>>2]|0;HEAP32[$tmp14+28>>2]=HEAP32[516424+28>>2]|0;
 $28 = HEAP32[$stream>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 (FUNCTION_TABLE_iiii[$29 & 2047]($stream,$tmp14,32)|0);
 ;HEAP32[$tmp15+0>>2]=HEAP32[516464+0>>2]|0;HEAP32[$tmp15+4>>2]=HEAP32[516464+4>>2]|0;HEAP32[$tmp15+8>>2]=HEAP32[516464+8>>2]|0;HEAP32[$tmp15+12>>2]=HEAP32[516464+12>>2]|0;HEAP32[$tmp15+16>>2]=HEAP32[516464+16>>2]|0;HEAP32[$tmp15+20>>2]=HEAP32[516464+20>>2]|0;HEAP32[$tmp15+24>>2]=HEAP32[516464+24>>2]|0;HEAP32[$tmp15+28>>2]=HEAP32[516464+28>>2]|0;
 $30 = HEAP32[$stream>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 (FUNCTION_TABLE_iiii[$31 & 2047]($stream,$tmp15,32)|0);
 ;HEAP32[$tmp16+0>>2]=HEAP32[516496+0>>2]|0;HEAP32[$tmp16+4>>2]=HEAP32[516496+4>>2]|0;HEAP32[$tmp16+8>>2]=HEAP32[516496+8>>2]|0;HEAP32[$tmp16+12>>2]=HEAP32[516496+12>>2]|0;HEAP32[$tmp16+16>>2]=HEAP32[516496+16>>2]|0;HEAP32[$tmp16+20>>2]=HEAP32[516496+20>>2]|0;HEAP32[$tmp16+24>>2]=HEAP32[516496+24>>2]|0;HEAP32[$tmp16+28>>2]=HEAP32[516496+28>>2]|0;
 $32 = HEAP32[$stream>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 (FUNCTION_TABLE_iiii[$33 & 2047]($stream,$tmp16,32)|0);
 ;HEAP32[$tmp17+0>>2]=HEAP32[516544+0>>2]|0;HEAP32[$tmp17+4>>2]=HEAP32[516544+4>>2]|0;HEAP32[$tmp17+8>>2]=HEAP32[516544+8>>2]|0;HEAP32[$tmp17+12>>2]=HEAP32[516544+12>>2]|0;HEAP32[$tmp17+16>>2]=HEAP32[516544+16>>2]|0;HEAP32[$tmp17+20>>2]=HEAP32[516544+20>>2]|0;HEAP32[$tmp17+24>>2]=HEAP32[516544+24>>2]|0;HEAP32[$tmp17+28>>2]=HEAP32[516544+28>>2]|0;
 $34 = HEAP32[$stream>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($stream,$tmp17,32)|0);
 ;HEAP32[$tmp18+0>>2]=HEAP32[516592+0>>2]|0;HEAP32[$tmp18+4>>2]=HEAP32[516592+4>>2]|0;HEAP32[$tmp18+8>>2]=HEAP32[516592+8>>2]|0;HEAP32[$tmp18+12>>2]=HEAP32[516592+12>>2]|0;HEAP32[$tmp18+16>>2]=HEAP32[516592+16>>2]|0;HEAP32[$tmp18+20>>2]=HEAP32[516592+20>>2]|0;HEAP32[$tmp18+24>>2]=HEAP32[516592+24>>2]|0;HEAP32[$tmp18+28>>2]=HEAP32[516592+28>>2]|0;
 $36 = HEAP32[$stream>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 (FUNCTION_TABLE_iiii[$37 & 2047]($stream,$tmp18,32)|0);
 ;HEAP32[$tmp19+0>>2]=HEAP32[516648+0>>2]|0;HEAP32[$tmp19+4>>2]=HEAP32[516648+4>>2]|0;HEAP32[$tmp19+8>>2]=HEAP32[516648+8>>2]|0;HEAP32[$tmp19+12>>2]=HEAP32[516648+12>>2]|0;HEAP32[$tmp19+16>>2]=HEAP32[516648+16>>2]|0;HEAP32[$tmp19+20>>2]=HEAP32[516648+20>>2]|0;HEAP32[$tmp19+24>>2]=HEAP32[516648+24>>2]|0;HEAP32[$tmp19+28>>2]=HEAP32[516648+28>>2]|0;
 $38 = HEAP32[$stream>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_iiii[$39 & 2047]($stream,$tmp19,32)|0);
 ;HEAP32[$tmp20+0>>2]=HEAP32[516696+0>>2]|0;HEAP32[$tmp20+4>>2]=HEAP32[516696+4>>2]|0;HEAP32[$tmp20+8>>2]=HEAP32[516696+8>>2]|0;HEAP32[$tmp20+12>>2]=HEAP32[516696+12>>2]|0;HEAP32[$tmp20+16>>2]=HEAP32[516696+16>>2]|0;HEAP32[$tmp20+20>>2]=HEAP32[516696+20>>2]|0;HEAP32[$tmp20+24>>2]=HEAP32[516696+24>>2]|0;HEAP32[$tmp20+28>>2]=HEAP32[516696+28>>2]|0;
 $40 = HEAP32[$stream>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 (FUNCTION_TABLE_iiii[$41 & 2047]($stream,$tmp20,32)|0);
 ;HEAP32[$tmp21+0>>2]=HEAP32[516744+0>>2]|0;HEAP32[$tmp21+4>>2]=HEAP32[516744+4>>2]|0;HEAP32[$tmp21+8>>2]=HEAP32[516744+8>>2]|0;HEAP32[$tmp21+12>>2]=HEAP32[516744+12>>2]|0;HEAP32[$tmp21+16>>2]=HEAP32[516744+16>>2]|0;HEAP32[$tmp21+20>>2]=HEAP32[516744+20>>2]|0;HEAP32[$tmp21+24>>2]=HEAP32[516744+24>>2]|0;HEAP32[$tmp21+28>>2]=HEAP32[516744+28>>2]|0;
 $42 = HEAP32[$stream>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 (FUNCTION_TABLE_iiii[$43 & 2047]($stream,$tmp21,32)|0);
 ;HEAP32[$tmp22+0>>2]=HEAP32[516792+0>>2]|0;HEAP32[$tmp22+4>>2]=HEAP32[516792+4>>2]|0;HEAP32[$tmp22+8>>2]=HEAP32[516792+8>>2]|0;HEAP32[$tmp22+12>>2]=HEAP32[516792+12>>2]|0;HEAP32[$tmp22+16>>2]=HEAP32[516792+16>>2]|0;HEAP32[$tmp22+20>>2]=HEAP32[516792+20>>2]|0;HEAP32[$tmp22+24>>2]=HEAP32[516792+24>>2]|0;HEAP32[$tmp22+28>>2]=HEAP32[516792+28>>2]|0;
 $44 = HEAP32[$stream>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 (FUNCTION_TABLE_iiii[$45 & 2047]($stream,$tmp22,32)|0);
 ;HEAP32[$tmp23+0>>2]=HEAP32[516824+0>>2]|0;HEAP32[$tmp23+4>>2]=HEAP32[516824+4>>2]|0;HEAP32[$tmp23+8>>2]=HEAP32[516824+8>>2]|0;HEAP32[$tmp23+12>>2]=HEAP32[516824+12>>2]|0;HEAP32[$tmp23+16>>2]=HEAP32[516824+16>>2]|0;HEAP32[$tmp23+20>>2]=HEAP32[516824+20>>2]|0;HEAP32[$tmp23+24>>2]=HEAP32[516824+24>>2]|0;HEAP32[$tmp23+28>>2]=HEAP32[516824+28>>2]|0;
 $46 = HEAP32[$stream>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 (FUNCTION_TABLE_iiii[$47 & 2047]($stream,$tmp23,32)|0);
 ;HEAP32[$tmp24+0>>2]=HEAP32[516856+0>>2]|0;HEAP32[$tmp24+4>>2]=HEAP32[516856+4>>2]|0;HEAP32[$tmp24+8>>2]=HEAP32[516856+8>>2]|0;HEAP32[$tmp24+12>>2]=HEAP32[516856+12>>2]|0;HEAP32[$tmp24+16>>2]=HEAP32[516856+16>>2]|0;HEAP32[$tmp24+20>>2]=HEAP32[516856+20>>2]|0;HEAP32[$tmp24+24>>2]=HEAP32[516856+24>>2]|0;HEAP32[$tmp24+28>>2]=HEAP32[516856+28>>2]|0;
 $48 = HEAP32[$stream>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 (FUNCTION_TABLE_iiii[$49 & 2047]($stream,$tmp24,32)|0);
 ;HEAP32[$tmp25+0>>2]=HEAP32[516912+0>>2]|0;HEAP32[$tmp25+4>>2]=HEAP32[516912+4>>2]|0;HEAP32[$tmp25+8>>2]=HEAP32[516912+8>>2]|0;HEAP32[$tmp25+12>>2]=HEAP32[516912+12>>2]|0;HEAP32[$tmp25+16>>2]=HEAP32[516912+16>>2]|0;HEAP32[$tmp25+20>>2]=HEAP32[516912+20>>2]|0;HEAP32[$tmp25+24>>2]=HEAP32[516912+24>>2]|0;HEAP32[$tmp25+28>>2]=HEAP32[516912+28>>2]|0;
 $50 = HEAP32[$stream>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 (FUNCTION_TABLE_iiii[$51 & 2047]($stream,$tmp25,32)|0);
 ;HEAP32[$tmp26+0>>2]=HEAP32[516960+0>>2]|0;HEAP32[$tmp26+4>>2]=HEAP32[516960+4>>2]|0;HEAP32[$tmp26+8>>2]=HEAP32[516960+8>>2]|0;HEAP32[$tmp26+12>>2]=HEAP32[516960+12>>2]|0;HEAP32[$tmp26+16>>2]=HEAP32[516960+16>>2]|0;HEAP32[$tmp26+20>>2]=HEAP32[516960+20>>2]|0;HEAP32[$tmp26+24>>2]=HEAP32[516960+24>>2]|0;HEAP32[$tmp26+28>>2]=HEAP32[516960+28>>2]|0;
 $52 = HEAP32[$stream>>2]|0;
 $53 = HEAP32[$52>>2]|0;
 (FUNCTION_TABLE_iiii[$53 & 2047]($stream,$tmp26,32)|0);
 ;HEAP32[$tmp27+0>>2]=HEAP32[517008+0>>2]|0;HEAP32[$tmp27+4>>2]=HEAP32[517008+4>>2]|0;HEAP32[$tmp27+8>>2]=HEAP32[517008+8>>2]|0;HEAP32[$tmp27+12>>2]=HEAP32[517008+12>>2]|0;HEAP32[$tmp27+16>>2]=HEAP32[517008+16>>2]|0;HEAP32[$tmp27+20>>2]=HEAP32[517008+20>>2]|0;HEAP32[$tmp27+24>>2]=HEAP32[517008+24>>2]|0;HEAP32[$tmp27+28>>2]=HEAP32[517008+28>>2]|0;
 $54 = HEAP32[$stream>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 (FUNCTION_TABLE_iiii[$55 & 2047]($stream,$tmp27,32)|0);
 ;HEAP32[$tmp28+0>>2]=HEAP32[517080+0>>2]|0;HEAP32[$tmp28+4>>2]=HEAP32[517080+4>>2]|0;HEAP32[$tmp28+8>>2]=HEAP32[517080+8>>2]|0;HEAP32[$tmp28+12>>2]=HEAP32[517080+12>>2]|0;HEAP32[$tmp28+16>>2]=HEAP32[517080+16>>2]|0;HEAP32[$tmp28+20>>2]=HEAP32[517080+20>>2]|0;HEAP32[$tmp28+24>>2]=HEAP32[517080+24>>2]|0;HEAP32[$tmp28+28>>2]=HEAP32[517080+28>>2]|0;
 $56 = HEAP32[$stream>>2]|0;
 $57 = HEAP32[$56>>2]|0;
 (FUNCTION_TABLE_iiii[$57 & 2047]($stream,$tmp28,32)|0);
 ;HEAP32[$tmp29+0>>2]=HEAP32[517144+0>>2]|0;HEAP32[$tmp29+4>>2]=HEAP32[517144+4>>2]|0;HEAP32[$tmp29+8>>2]=HEAP32[517144+8>>2]|0;HEAP32[$tmp29+12>>2]=HEAP32[517144+12>>2]|0;HEAP32[$tmp29+16>>2]=HEAP32[517144+16>>2]|0;HEAP32[$tmp29+20>>2]=HEAP32[517144+20>>2]|0;HEAP32[$tmp29+24>>2]=HEAP32[517144+24>>2]|0;HEAP32[$tmp29+28>>2]=HEAP32[517144+28>>2]|0;
 $58 = HEAP32[$stream>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 (FUNCTION_TABLE_iiii[$59 & 2047]($stream,$tmp29,32)|0);
 ;HEAP32[$tmp30+0>>2]=HEAP32[517200+0>>2]|0;HEAP32[$tmp30+4>>2]=HEAP32[517200+4>>2]|0;HEAP32[$tmp30+8>>2]=HEAP32[517200+8>>2]|0;HEAP32[$tmp30+12>>2]=HEAP32[517200+12>>2]|0;HEAP32[$tmp30+16>>2]=HEAP32[517200+16>>2]|0;HEAP32[$tmp30+20>>2]=HEAP32[517200+20>>2]|0;HEAP32[$tmp30+24>>2]=HEAP32[517200+24>>2]|0;HEAP32[$tmp30+28>>2]=HEAP32[517200+28>>2]|0;
 $60 = HEAP32[$stream>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 (FUNCTION_TABLE_iiii[$61 & 2047]($stream,$tmp30,32)|0);
 ;HEAP32[$tmp31+0>>2]=HEAP32[517232+0>>2]|0;HEAP32[$tmp31+4>>2]=HEAP32[517232+4>>2]|0;HEAP32[$tmp31+8>>2]=HEAP32[517232+8>>2]|0;HEAP32[$tmp31+12>>2]=HEAP32[517232+12>>2]|0;HEAP32[$tmp31+16>>2]=HEAP32[517232+16>>2]|0;HEAP32[$tmp31+20>>2]=HEAP32[517232+20>>2]|0;HEAP32[$tmp31+24>>2]=HEAP32[517232+24>>2]|0;HEAP32[$tmp31+28>>2]=HEAP32[517232+28>>2]|0;
 $62 = HEAP32[$stream>>2]|0;
 $63 = HEAP32[$62>>2]|0;
 (FUNCTION_TABLE_iiii[$63 & 2047]($stream,$tmp31,32)|0);
 ;HEAP32[$tmp32+0>>2]=HEAP32[517312+0>>2]|0;HEAP32[$tmp32+4>>2]=HEAP32[517312+4>>2]|0;HEAP32[$tmp32+8>>2]=HEAP32[517312+8>>2]|0;HEAP32[$tmp32+12>>2]=HEAP32[517312+12>>2]|0;HEAP32[$tmp32+16>>2]=HEAP32[517312+16>>2]|0;HEAP32[$tmp32+20>>2]=HEAP32[517312+20>>2]|0;HEAP32[$tmp32+24>>2]=HEAP32[517312+24>>2]|0;HEAP32[$tmp32+28>>2]=HEAP32[517312+28>>2]|0;
 $64 = HEAP32[$stream>>2]|0;
 $65 = HEAP32[$64>>2]|0;
 (FUNCTION_TABLE_iiii[$65 & 2047]($stream,$tmp32,32)|0);
 ;HEAP32[$tmp33+0>>2]=HEAP32[517384+0>>2]|0;HEAP32[$tmp33+4>>2]=HEAP32[517384+4>>2]|0;HEAP32[$tmp33+8>>2]=HEAP32[517384+8>>2]|0;HEAP32[$tmp33+12>>2]=HEAP32[517384+12>>2]|0;HEAP32[$tmp33+16>>2]=HEAP32[517384+16>>2]|0;HEAP32[$tmp33+20>>2]=HEAP32[517384+20>>2]|0;HEAP32[$tmp33+24>>2]=HEAP32[517384+24>>2]|0;HEAP32[$tmp33+28>>2]=HEAP32[517384+28>>2]|0;
 $66 = HEAP32[$stream>>2]|0;
 $67 = HEAP32[$66>>2]|0;
 (FUNCTION_TABLE_iiii[$67 & 2047]($stream,$tmp33,32)|0);
 ;HEAP32[$tmp34+0>>2]=HEAP32[517456+0>>2]|0;HEAP32[$tmp34+4>>2]=HEAP32[517456+4>>2]|0;HEAP32[$tmp34+8>>2]=HEAP32[517456+8>>2]|0;HEAP32[$tmp34+12>>2]=HEAP32[517456+12>>2]|0;HEAP32[$tmp34+16>>2]=HEAP32[517456+16>>2]|0;HEAP32[$tmp34+20>>2]=HEAP32[517456+20>>2]|0;HEAP32[$tmp34+24>>2]=HEAP32[517456+24>>2]|0;HEAP32[$tmp34+28>>2]=HEAP32[517456+28>>2]|0;
 $68 = HEAP32[$stream>>2]|0;
 $69 = HEAP32[$68>>2]|0;
 (FUNCTION_TABLE_iiii[$69 & 2047]($stream,$tmp34,32)|0);
 ;HEAP32[$tmp35+0>>2]=HEAP32[517488+0>>2]|0;HEAP32[$tmp35+4>>2]=HEAP32[517488+4>>2]|0;HEAP32[$tmp35+8>>2]=HEAP32[517488+8>>2]|0;HEAP32[$tmp35+12>>2]=HEAP32[517488+12>>2]|0;HEAP32[$tmp35+16>>2]=HEAP32[517488+16>>2]|0;HEAP32[$tmp35+20>>2]=HEAP32[517488+20>>2]|0;HEAP32[$tmp35+24>>2]=HEAP32[517488+24>>2]|0;HEAP32[$tmp35+28>>2]=HEAP32[517488+28>>2]|0;
 $70 = HEAP32[$stream>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 (FUNCTION_TABLE_iiii[$71 & 2047]($stream,$tmp35,32)|0);
 ;HEAP32[$tmp36+0>>2]=HEAP32[517520+0>>2]|0;HEAP32[$tmp36+4>>2]=HEAP32[517520+4>>2]|0;HEAP32[$tmp36+8>>2]=HEAP32[517520+8>>2]|0;HEAP32[$tmp36+12>>2]=HEAP32[517520+12>>2]|0;HEAP32[$tmp36+16>>2]=HEAP32[517520+16>>2]|0;HEAP32[$tmp36+20>>2]=HEAP32[517520+20>>2]|0;HEAP32[$tmp36+24>>2]=HEAP32[517520+24>>2]|0;HEAP32[$tmp36+28>>2]=HEAP32[517520+28>>2]|0;
 $72 = HEAP32[$stream>>2]|0;
 $73 = HEAP32[$72>>2]|0;
 (FUNCTION_TABLE_iiii[$73 & 2047]($stream,$tmp36,32)|0);
 ;HEAP32[$tmp37+0>>2]=HEAP32[517568+0>>2]|0;HEAP32[$tmp37+4>>2]=HEAP32[517568+4>>2]|0;HEAP32[$tmp37+8>>2]=HEAP32[517568+8>>2]|0;HEAP32[$tmp37+12>>2]=HEAP32[517568+12>>2]|0;HEAP32[$tmp37+16>>2]=HEAP32[517568+16>>2]|0;HEAP32[$tmp37+20>>2]=HEAP32[517568+20>>2]|0;HEAP32[$tmp37+24>>2]=HEAP32[517568+24>>2]|0;HEAP32[$tmp37+28>>2]=HEAP32[517568+28>>2]|0;
 $74 = HEAP32[$stream>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 (FUNCTION_TABLE_iiii[$75 & 2047]($stream,$tmp37,32)|0);
 ;HEAP32[$tmp38+0>>2]=HEAP32[517608+0>>2]|0;HEAP32[$tmp38+4>>2]=HEAP32[517608+4>>2]|0;HEAP32[$tmp38+8>>2]=HEAP32[517608+8>>2]|0;HEAP32[$tmp38+12>>2]=HEAP32[517608+12>>2]|0;HEAP32[$tmp38+16>>2]=HEAP32[517608+16>>2]|0;HEAP32[$tmp38+20>>2]=HEAP32[517608+20>>2]|0;HEAP32[$tmp38+24>>2]=HEAP32[517608+24>>2]|0;HEAP32[$tmp38+28>>2]=HEAP32[517608+28>>2]|0;
 $76 = HEAP32[$stream>>2]|0;
 $77 = HEAP32[$76>>2]|0;
 (FUNCTION_TABLE_iiii[$77 & 2047]($stream,$tmp38,32)|0);
 ;HEAP32[$tmp39+0>>2]=HEAP32[517648+0>>2]|0;HEAP32[$tmp39+4>>2]=HEAP32[517648+4>>2]|0;HEAP32[$tmp39+8>>2]=HEAP32[517648+8>>2]|0;HEAP32[$tmp39+12>>2]=HEAP32[517648+12>>2]|0;HEAP32[$tmp39+16>>2]=HEAP32[517648+16>>2]|0;HEAP32[$tmp39+20>>2]=HEAP32[517648+20>>2]|0;HEAP32[$tmp39+24>>2]=HEAP32[517648+24>>2]|0;HEAP32[$tmp39+28>>2]=HEAP32[517648+28>>2]|0;
 $78 = HEAP32[$stream>>2]|0;
 $79 = HEAP32[$78>>2]|0;
 (FUNCTION_TABLE_iiii[$79 & 2047]($stream,$tmp39,32)|0);
 ;HEAP32[$tmp40+0>>2]=HEAP32[517712+0>>2]|0;HEAP32[$tmp40+4>>2]=HEAP32[517712+4>>2]|0;HEAP32[$tmp40+8>>2]=HEAP32[517712+8>>2]|0;HEAP32[$tmp40+12>>2]=HEAP32[517712+12>>2]|0;HEAP32[$tmp40+16>>2]=HEAP32[517712+16>>2]|0;HEAP32[$tmp40+20>>2]=HEAP32[517712+20>>2]|0;HEAP32[$tmp40+24>>2]=HEAP32[517712+24>>2]|0;HEAP32[$tmp40+28>>2]=HEAP32[517712+28>>2]|0;
 $80 = HEAP32[$stream>>2]|0;
 $81 = HEAP32[$80>>2]|0;
 (FUNCTION_TABLE_iiii[$81 & 2047]($stream,$tmp40,32)|0);
 ;HEAP32[$tmp41+0>>2]=HEAP32[517776+0>>2]|0;HEAP32[$tmp41+4>>2]=HEAP32[517776+4>>2]|0;HEAP32[$tmp41+8>>2]=HEAP32[517776+8>>2]|0;HEAP32[$tmp41+12>>2]=HEAP32[517776+12>>2]|0;HEAP32[$tmp41+16>>2]=HEAP32[517776+16>>2]|0;HEAP32[$tmp41+20>>2]=HEAP32[517776+20>>2]|0;HEAP32[$tmp41+24>>2]=HEAP32[517776+24>>2]|0;HEAP32[$tmp41+28>>2]=HEAP32[517776+28>>2]|0;
 $82 = HEAP32[$stream>>2]|0;
 $83 = HEAP32[$82>>2]|0;
 (FUNCTION_TABLE_iiii[$83 & 2047]($stream,$tmp41,32)|0);
 ;HEAP32[$tmp42+0>>2]=HEAP32[517840+0>>2]|0;HEAP32[$tmp42+4>>2]=HEAP32[517840+4>>2]|0;HEAP32[$tmp42+8>>2]=HEAP32[517840+8>>2]|0;HEAP32[$tmp42+12>>2]=HEAP32[517840+12>>2]|0;HEAP32[$tmp42+16>>2]=HEAP32[517840+16>>2]|0;HEAP32[$tmp42+20>>2]=HEAP32[517840+20>>2]|0;HEAP32[$tmp42+24>>2]=HEAP32[517840+24>>2]|0;HEAP32[$tmp42+28>>2]=HEAP32[517840+28>>2]|0;
 $84 = HEAP32[$stream>>2]|0;
 $85 = HEAP32[$84>>2]|0;
 (FUNCTION_TABLE_iiii[$85 & 2047]($stream,$tmp42,32)|0);
 ;HEAP32[$tmp43+0>>2]=HEAP32[517896+0>>2]|0;HEAP32[$tmp43+4>>2]=HEAP32[517896+4>>2]|0;HEAP32[$tmp43+8>>2]=HEAP32[517896+8>>2]|0;HEAP32[$tmp43+12>>2]=HEAP32[517896+12>>2]|0;HEAP32[$tmp43+16>>2]=HEAP32[517896+16>>2]|0;HEAP32[$tmp43+20>>2]=HEAP32[517896+20>>2]|0;HEAP32[$tmp43+24>>2]=HEAP32[517896+24>>2]|0;HEAP32[$tmp43+28>>2]=HEAP32[517896+28>>2]|0;
 $86 = HEAP32[$stream>>2]|0;
 $87 = HEAP32[$86>>2]|0;
 (FUNCTION_TABLE_iiii[$87 & 2047]($stream,$tmp43,32)|0);
 ;HEAP32[$tmp44+0>>2]=HEAP32[517944+0>>2]|0;HEAP32[$tmp44+4>>2]=HEAP32[517944+4>>2]|0;HEAP32[$tmp44+8>>2]=HEAP32[517944+8>>2]|0;HEAP32[$tmp44+12>>2]=HEAP32[517944+12>>2]|0;HEAP32[$tmp44+16>>2]=HEAP32[517944+16>>2]|0;HEAP32[$tmp44+20>>2]=HEAP32[517944+20>>2]|0;HEAP32[$tmp44+24>>2]=HEAP32[517944+24>>2]|0;HEAP32[$tmp44+28>>2]=HEAP32[517944+28>>2]|0;
 $88 = HEAP32[$stream>>2]|0;
 $89 = HEAP32[$88>>2]|0;
 (FUNCTION_TABLE_iiii[$89 & 2047]($stream,$tmp44,32)|0);
 ;HEAP32[$tmp45+0>>2]=HEAP32[518000+0>>2]|0;HEAP32[$tmp45+4>>2]=HEAP32[518000+4>>2]|0;HEAP32[$tmp45+8>>2]=HEAP32[518000+8>>2]|0;HEAP32[$tmp45+12>>2]=HEAP32[518000+12>>2]|0;HEAP32[$tmp45+16>>2]=HEAP32[518000+16>>2]|0;HEAP32[$tmp45+20>>2]=HEAP32[518000+20>>2]|0;HEAP32[$tmp45+24>>2]=HEAP32[518000+24>>2]|0;HEAP32[$tmp45+28>>2]=HEAP32[518000+28>>2]|0;
 $90 = HEAP32[$stream>>2]|0;
 $91 = HEAP32[$90>>2]|0;
 (FUNCTION_TABLE_iiii[$91 & 2047]($stream,$tmp45,32)|0);
 ;HEAP32[$tmp46+0>>2]=HEAP32[518064+0>>2]|0;HEAP32[$tmp46+4>>2]=HEAP32[518064+4>>2]|0;HEAP32[$tmp46+8>>2]=HEAP32[518064+8>>2]|0;HEAP32[$tmp46+12>>2]=HEAP32[518064+12>>2]|0;HEAP32[$tmp46+16>>2]=HEAP32[518064+16>>2]|0;HEAP32[$tmp46+20>>2]=HEAP32[518064+20>>2]|0;HEAP32[$tmp46+24>>2]=HEAP32[518064+24>>2]|0;HEAP32[$tmp46+28>>2]=HEAP32[518064+28>>2]|0;
 $92 = HEAP32[$stream>>2]|0;
 $93 = HEAP32[$92>>2]|0;
 (FUNCTION_TABLE_iiii[$93 & 2047]($stream,$tmp46,32)|0);
 ;HEAP32[$tmp47+0>>2]=HEAP32[518112+0>>2]|0;HEAP32[$tmp47+4>>2]=HEAP32[518112+4>>2]|0;HEAP32[$tmp47+8>>2]=HEAP32[518112+8>>2]|0;HEAP32[$tmp47+12>>2]=HEAP32[518112+12>>2]|0;HEAP32[$tmp47+16>>2]=HEAP32[518112+16>>2]|0;HEAP32[$tmp47+20>>2]=HEAP32[518112+20>>2]|0;HEAP32[$tmp47+24>>2]=HEAP32[518112+24>>2]|0;HEAP32[$tmp47+28>>2]=HEAP32[518112+28>>2]|0;
 $94 = HEAP32[$stream>>2]|0;
 $95 = HEAP32[$94>>2]|0;
 (FUNCTION_TABLE_iiii[$95 & 2047]($stream,$tmp47,32)|0);
 ;HEAP32[$tmp48+0>>2]=HEAP32[518144+0>>2]|0;HEAP32[$tmp48+4>>2]=HEAP32[518144+4>>2]|0;HEAP32[$tmp48+8>>2]=HEAP32[518144+8>>2]|0;HEAP32[$tmp48+12>>2]=HEAP32[518144+12>>2]|0;HEAP32[$tmp48+16>>2]=HEAP32[518144+16>>2]|0;HEAP32[$tmp48+20>>2]=HEAP32[518144+20>>2]|0;HEAP32[$tmp48+24>>2]=HEAP32[518144+24>>2]|0;HEAP32[$tmp48+28>>2]=HEAP32[518144+28>>2]|0;
 $96 = HEAP32[$stream>>2]|0;
 $97 = HEAP32[$96>>2]|0;
 (FUNCTION_TABLE_iiii[$97 & 2047]($stream,$tmp48,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsDynData17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp10 = 0, $tmp11 = 0, $tmp12 = 0, $tmp13 = 0, $tmp14 = 0, $tmp15 = 0, $tmp16 = 0, $tmp17 = 0, $tmp18 = 0, $tmp19 = 0, $tmp2 = 0, $tmp20 = 0, $tmp21 = 0, $tmp3 = 0;
 var $tmp4 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0, $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 704|0;
 $tmp = sp + 672|0;
 $tmp1 = sp + 640|0;
 $tmp2 = sp + 608|0;
 $tmp3 = sp + 576|0;
 $tmp4 = sp + 544|0;
 $tmp5 = sp + 512|0;
 $tmp6 = sp + 480|0;
 $tmp7 = sp + 448|0;
 $tmp8 = sp + 416|0;
 $tmp9 = sp + 384|0;
 $tmp10 = sp + 352|0;
 $tmp11 = sp + 320|0;
 $tmp12 = sp + 96|0;
 $tmp13 = sp;
 $tmp14 = sp + 32|0;
 $tmp15 = sp + 64|0;
 $tmp16 = sp + 128|0;
 $tmp17 = sp + 160|0;
 $tmp18 = sp + 192|0;
 $tmp19 = sp + 224|0;
 $tmp20 = sp + 256|0;
 $tmp21 = sp + 288|0;
 __ZN5physx23PxVehicleWheels4DynData17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 __ZN5physx25PxVehicleConstraintShader17getBinaryMetaDataERNS_14PxOutputStreamE($stream);
 ;HEAP32[$tmp+0>>2]=HEAP32[513848+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[513848+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[513848+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[513848+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[513848+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[513848+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[513848+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[513848+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 ;HEAP32[$tmp1+0>>2]=HEAP32[513904+0>>2]|0;HEAP32[$tmp1+4>>2]=HEAP32[513904+4>>2]|0;HEAP32[$tmp1+8>>2]=HEAP32[513904+8>>2]|0;HEAP32[$tmp1+12>>2]=HEAP32[513904+12>>2]|0;HEAP32[$tmp1+16>>2]=HEAP32[513904+16>>2]|0;HEAP32[$tmp1+20>>2]=HEAP32[513904+20>>2]|0;HEAP32[$tmp1+24>>2]=HEAP32[513904+24>>2]|0;HEAP32[$tmp1+28>>2]=HEAP32[513904+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[513944+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[513944+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[513944+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[513944+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[513944+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[513944+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[513944+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[513944+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[513976+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[513976+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[513976+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[513976+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[513976+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[513976+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[513976+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[513976+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[514032+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[514032+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[514032+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[514032+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[514032+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[514032+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[514032+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[514032+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[514104+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[514104+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[514104+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[514104+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[514104+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[514104+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[514104+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[514104+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[514160+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[514160+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[514160+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[514160+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[514160+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[514160+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[514160+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[514160+28>>2]|0;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[514208+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[514208+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[514208+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[514208+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[514208+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[514208+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[514208+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[514208+28>>2]|0;
 $14 = HEAP32[$stream>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_iiii[$15 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[514240+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[514240+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[514240+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[514240+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[514240+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[514240+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[514240+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[514240+28>>2]|0;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[514272+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[514272+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[514272+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[514272+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[514272+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[514272+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[514272+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[514272+28>>2]|0;
 $18 = HEAP32[$stream>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[514304+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[514304+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[514304+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[514304+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[514304+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[514304+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[514304+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[514304+28>>2]|0;
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$tmp10,32)|0);
 ;HEAP32[$tmp11+0>>2]=HEAP32[514336+0>>2]|0;HEAP32[$tmp11+4>>2]=HEAP32[514336+4>>2]|0;HEAP32[$tmp11+8>>2]=HEAP32[514336+8>>2]|0;HEAP32[$tmp11+12>>2]=HEAP32[514336+12>>2]|0;HEAP32[$tmp11+16>>2]=HEAP32[514336+16>>2]|0;HEAP32[$tmp11+20>>2]=HEAP32[514336+20>>2]|0;HEAP32[$tmp11+24>>2]=HEAP32[514336+24>>2]|0;HEAP32[$tmp11+28>>2]=HEAP32[514336+28>>2]|0;
 $22 = HEAP32[$stream>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_iiii[$23 & 2047]($stream,$tmp11,32)|0);
 ;HEAP32[$tmp12+0>>2]=HEAP32[514368+0>>2]|0;HEAP32[$tmp12+4>>2]=HEAP32[514368+4>>2]|0;HEAP32[$tmp12+8>>2]=HEAP32[514368+8>>2]|0;HEAP32[$tmp12+12>>2]=HEAP32[514368+12>>2]|0;HEAP32[$tmp12+16>>2]=HEAP32[514368+16>>2]|0;HEAP32[$tmp12+20>>2]=HEAP32[514368+20>>2]|0;HEAP32[$tmp12+24>>2]=HEAP32[514368+24>>2]|0;HEAP32[$tmp12+28>>2]=HEAP32[514368+28>>2]|0;
 $24 = HEAP32[$stream>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_iiii[$25 & 2047]($stream,$tmp12,32)|0);
 ;HEAP32[$tmp13+0>>2]=HEAP32[514408+0>>2]|0;HEAP32[$tmp13+4>>2]=HEAP32[514408+4>>2]|0;HEAP32[$tmp13+8>>2]=HEAP32[514408+8>>2]|0;HEAP32[$tmp13+12>>2]=HEAP32[514408+12>>2]|0;HEAP32[$tmp13+16>>2]=HEAP32[514408+16>>2]|0;HEAP32[$tmp13+20>>2]=HEAP32[514408+20>>2]|0;HEAP32[$tmp13+24>>2]=HEAP32[514408+24>>2]|0;HEAP32[$tmp13+28>>2]=HEAP32[514408+28>>2]|0;
 $26 = HEAP32[$stream>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_iiii[$27 & 2047]($stream,$tmp13,32)|0);
 ;HEAP32[$tmp14+0>>2]=HEAP32[514408+0>>2]|0;HEAP32[$tmp14+4>>2]=HEAP32[514408+4>>2]|0;HEAP32[$tmp14+8>>2]=HEAP32[514408+8>>2]|0;HEAP32[$tmp14+12>>2]=HEAP32[514408+12>>2]|0;HEAP32[$tmp14+16>>2]=HEAP32[514408+16>>2]|0;HEAP32[$tmp14+20>>2]=HEAP32[514408+20>>2]|0;HEAP32[$tmp14+24>>2]=HEAP32[514408+24>>2]|0;HEAP32[$tmp14+28>>2]=HEAP32[514408+28>>2]|0;
 $28 = HEAP32[$stream>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 (FUNCTION_TABLE_iiii[$29 & 2047]($stream,$tmp14,32)|0);
 ;HEAP32[$tmp15+0>>2]=HEAP32[514408+0>>2]|0;HEAP32[$tmp15+4>>2]=HEAP32[514408+4>>2]|0;HEAP32[$tmp15+8>>2]=HEAP32[514408+8>>2]|0;HEAP32[$tmp15+12>>2]=HEAP32[514408+12>>2]|0;HEAP32[$tmp15+16>>2]=HEAP32[514408+16>>2]|0;HEAP32[$tmp15+20>>2]=HEAP32[514408+20>>2]|0;HEAP32[$tmp15+24>>2]=HEAP32[514408+24>>2]|0;HEAP32[$tmp15+28>>2]=HEAP32[514408+28>>2]|0;
 $30 = HEAP32[$stream>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 (FUNCTION_TABLE_iiii[$31 & 2047]($stream,$tmp15,32)|0);
 ;HEAP32[$tmp16+0>>2]=HEAP32[514408+0>>2]|0;HEAP32[$tmp16+4>>2]=HEAP32[514408+4>>2]|0;HEAP32[$tmp16+8>>2]=HEAP32[514408+8>>2]|0;HEAP32[$tmp16+12>>2]=HEAP32[514408+12>>2]|0;HEAP32[$tmp16+16>>2]=HEAP32[514408+16>>2]|0;HEAP32[$tmp16+20>>2]=HEAP32[514408+20>>2]|0;HEAP32[$tmp16+24>>2]=HEAP32[514408+24>>2]|0;HEAP32[$tmp16+28>>2]=HEAP32[514408+28>>2]|0;
 $32 = HEAP32[$stream>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 (FUNCTION_TABLE_iiii[$33 & 2047]($stream,$tmp16,32)|0);
 ;HEAP32[$tmp17+0>>2]=HEAP32[514440+0>>2]|0;HEAP32[$tmp17+4>>2]=HEAP32[514440+4>>2]|0;HEAP32[$tmp17+8>>2]=HEAP32[514440+8>>2]|0;HEAP32[$tmp17+12>>2]=HEAP32[514440+12>>2]|0;HEAP32[$tmp17+16>>2]=HEAP32[514440+16>>2]|0;HEAP32[$tmp17+20>>2]=HEAP32[514440+20>>2]|0;HEAP32[$tmp17+24>>2]=HEAP32[514440+24>>2]|0;HEAP32[$tmp17+28>>2]=HEAP32[514440+28>>2]|0;
 $34 = HEAP32[$stream>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($stream,$tmp17,32)|0);
 ;HEAP32[$tmp18+0>>2]=HEAP32[514440+0>>2]|0;HEAP32[$tmp18+4>>2]=HEAP32[514440+4>>2]|0;HEAP32[$tmp18+8>>2]=HEAP32[514440+8>>2]|0;HEAP32[$tmp18+12>>2]=HEAP32[514440+12>>2]|0;HEAP32[$tmp18+16>>2]=HEAP32[514440+16>>2]|0;HEAP32[$tmp18+20>>2]=HEAP32[514440+20>>2]|0;HEAP32[$tmp18+24>>2]=HEAP32[514440+24>>2]|0;HEAP32[$tmp18+28>>2]=HEAP32[514440+28>>2]|0;
 $36 = HEAP32[$stream>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 (FUNCTION_TABLE_iiii[$37 & 2047]($stream,$tmp18,32)|0);
 ;HEAP32[$tmp19+0>>2]=HEAP32[514440+0>>2]|0;HEAP32[$tmp19+4>>2]=HEAP32[514440+4>>2]|0;HEAP32[$tmp19+8>>2]=HEAP32[514440+8>>2]|0;HEAP32[$tmp19+12>>2]=HEAP32[514440+12>>2]|0;HEAP32[$tmp19+16>>2]=HEAP32[514440+16>>2]|0;HEAP32[$tmp19+20>>2]=HEAP32[514440+20>>2]|0;HEAP32[$tmp19+24>>2]=HEAP32[514440+24>>2]|0;HEAP32[$tmp19+28>>2]=HEAP32[514440+28>>2]|0;
 $38 = HEAP32[$stream>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_iiii[$39 & 2047]($stream,$tmp19,32)|0);
 ;HEAP32[$tmp20+0>>2]=HEAP32[514440+0>>2]|0;HEAP32[$tmp20+4>>2]=HEAP32[514440+4>>2]|0;HEAP32[$tmp20+8>>2]=HEAP32[514440+8>>2]|0;HEAP32[$tmp20+12>>2]=HEAP32[514440+12>>2]|0;HEAP32[$tmp20+16>>2]=HEAP32[514440+16>>2]|0;HEAP32[$tmp20+20>>2]=HEAP32[514440+20>>2]|0;HEAP32[$tmp20+24>>2]=HEAP32[514440+24>>2]|0;HEAP32[$tmp20+28>>2]=HEAP32[514440+28>>2]|0;
 $40 = HEAP32[$stream>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 (FUNCTION_TABLE_iiii[$41 & 2047]($stream,$tmp20,32)|0);
 ;HEAP32[$tmp21+0>>2]=HEAP32[514504+0>>2]|0;HEAP32[$tmp21+4>>2]=HEAP32[514504+4>>2]|0;HEAP32[$tmp21+8>>2]=HEAP32[514504+8>>2]|0;HEAP32[$tmp21+12>>2]=HEAP32[514504+12>>2]|0;HEAP32[$tmp21+16>>2]=HEAP32[514504+16>>2]|0;HEAP32[$tmp21+20>>2]=HEAP32[514504+20>>2]|0;HEAP32[$tmp21+24>>2]=HEAP32[514504+24>>2]|0;HEAP32[$tmp21+28>>2]=HEAP32[514504+28>>2]|0;
 $42 = HEAP32[$stream>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 (FUNCTION_TABLE_iiii[$43 & 2047]($stream,$tmp21,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4DynData17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp10 = 0, $tmp2 = 0, $tmp3 = 0, $tmp4 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0, $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $tmp = sp + 320|0;
 $tmp1 = sp + 288|0;
 $tmp2 = sp + 256|0;
 $tmp3 = sp + 224|0;
 $tmp4 = sp + 192|0;
 $tmp5 = sp + 160|0;
 $tmp6 = sp + 96|0;
 $tmp7 = sp + 64|0;
 $tmp8 = sp + 32|0;
 $tmp9 = sp;
 $tmp10 = sp + 128|0;
 ;HEAP32[$tmp+0>>2]=HEAP32[518176+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[518176+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[518176+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[518176+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[518176+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[518176+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[518176+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[518176+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 ;HEAP32[$tmp1+0>>2]=HEAP32[518224+0>>2]|0;HEAP32[$tmp1+4>>2]=HEAP32[518224+4>>2]|0;HEAP32[$tmp1+8>>2]=HEAP32[518224+8>>2]|0;HEAP32[$tmp1+12>>2]=HEAP32[518224+12>>2]|0;HEAP32[$tmp1+16>>2]=HEAP32[518224+16>>2]|0;HEAP32[$tmp1+20>>2]=HEAP32[518224+20>>2]|0;HEAP32[$tmp1+24>>2]=HEAP32[518224+24>>2]|0;HEAP32[$tmp1+28>>2]=HEAP32[518224+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[518280+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[518280+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[518280+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[518280+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[518280+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[518280+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[518280+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[518280+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[518336+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[518336+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[518336+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[518336+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[518336+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[518336+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[518336+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[518336+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[518400+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[518400+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[518400+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[518400+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[518400+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[518400+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[518400+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[518400+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[518456+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[518456+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[518456+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[518456+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[518456+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[518456+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[518456+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[518456+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[518520+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[518520+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[518520+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[518520+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[518520+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[518520+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[518520+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[518520+28>>2]|0;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[518576+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[518576+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[518576+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[518576+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[518576+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[518576+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[518576+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[518576+28>>2]|0;
 $14 = HEAP32[$stream>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_iiii[$15 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[518648+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[518648+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[518648+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[518648+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[518648+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[518648+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[518648+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[518648+28>>2]|0;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[518712+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[518712+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[518712+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[518712+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[518712+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[518712+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[518712+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[518712+28>>2]|0;
 $18 = HEAP32[$stream>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[518744+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[518744+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[518744+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[518744+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[518744+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[518744+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[518744+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[518744+28>>2]|0;
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$tmp10,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx25PxVehicleConstraintShader17getBinaryMetaDataERNS_14PxOutputStreamE($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp10 = 0, $tmp11 = 0, $tmp12 = 0, $tmp13 = 0, $tmp14 = 0, $tmp15 = 0, $tmp16 = 0, $tmp17 = 0, $tmp18 = 0, $tmp19 = 0, $tmp2 = 0;
 var $tmp3 = 0, $tmp4 = 0, $tmp5 = 0, $tmp6 = 0, $tmp7 = 0, $tmp8 = 0, $tmp9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 640|0;
 $tmp = sp + 608|0;
 $tmp1 = sp + 576|0;
 $tmp2 = sp + 544|0;
 $tmp3 = sp + 512|0;
 $tmp4 = sp + 480|0;
 $tmp5 = sp + 448|0;
 $tmp6 = sp + 416|0;
 $tmp7 = sp + 384|0;
 $tmp8 = sp + 352|0;
 $tmp9 = sp + 320|0;
 $tmp10 = sp + 288|0;
 $tmp11 = sp + 96|0;
 $tmp12 = sp;
 $tmp13 = sp + 32|0;
 $tmp14 = sp + 64|0;
 $tmp15 = sp + 128|0;
 $tmp16 = sp + 160|0;
 $tmp17 = sp + 192|0;
 $tmp18 = sp + 224|0;
 $tmp19 = sp + 256|0;
 ;HEAP32[$tmp+0>>2]=HEAP32[514936+0>>2]|0;HEAP32[$tmp+4>>2]=HEAP32[514936+4>>2]|0;HEAP32[$tmp+8>>2]=HEAP32[514936+8>>2]|0;HEAP32[$tmp+12>>2]=HEAP32[514936+12>>2]|0;HEAP32[$tmp+16>>2]=HEAP32[514936+16>>2]|0;HEAP32[$tmp+20>>2]=HEAP32[514936+20>>2]|0;HEAP32[$tmp+24>>2]=HEAP32[514936+24>>2]|0;HEAP32[$tmp+28>>2]=HEAP32[514936+28>>2]|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$tmp,32)|0);
 ;HEAP32[$tmp1+0>>2]=HEAP32[515120+0>>2]|0;HEAP32[$tmp1+4>>2]=HEAP32[515120+4>>2]|0;HEAP32[$tmp1+8>>2]=HEAP32[515120+8>>2]|0;HEAP32[$tmp1+12>>2]=HEAP32[515120+12>>2]|0;HEAP32[$tmp1+16>>2]=HEAP32[515120+16>>2]|0;HEAP32[$tmp1+20>>2]=HEAP32[515120+20>>2]|0;HEAP32[$tmp1+24>>2]=HEAP32[515120+24>>2]|0;HEAP32[$tmp1+28>>2]=HEAP32[515120+28>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$tmp1,32)|0);
 ;HEAP32[$tmp2+0>>2]=HEAP32[515152+0>>2]|0;HEAP32[$tmp2+4>>2]=HEAP32[515152+4>>2]|0;HEAP32[$tmp2+8>>2]=HEAP32[515152+8>>2]|0;HEAP32[$tmp2+12>>2]=HEAP32[515152+12>>2]|0;HEAP32[$tmp2+16>>2]=HEAP32[515152+16>>2]|0;HEAP32[$tmp2+20>>2]=HEAP32[515152+20>>2]|0;HEAP32[$tmp2+24>>2]=HEAP32[515152+24>>2]|0;HEAP32[$tmp2+28>>2]=HEAP32[515152+28>>2]|0;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$tmp2,32)|0);
 ;HEAP32[$tmp3+0>>2]=HEAP32[515008+0>>2]|0;HEAP32[$tmp3+4>>2]=HEAP32[515008+4>>2]|0;HEAP32[$tmp3+8>>2]=HEAP32[515008+8>>2]|0;HEAP32[$tmp3+12>>2]=HEAP32[515008+12>>2]|0;HEAP32[$tmp3+16>>2]=HEAP32[515008+16>>2]|0;HEAP32[$tmp3+20>>2]=HEAP32[515008+20>>2]|0;HEAP32[$tmp3+24>>2]=HEAP32[515008+24>>2]|0;HEAP32[$tmp3+28>>2]=HEAP32[515008+28>>2]|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$tmp3,32)|0);
 ;HEAP32[$tmp4+0>>2]=HEAP32[515232+0>>2]|0;HEAP32[$tmp4+4>>2]=HEAP32[515232+4>>2]|0;HEAP32[$tmp4+8>>2]=HEAP32[515232+8>>2]|0;HEAP32[$tmp4+12>>2]=HEAP32[515232+12>>2]|0;HEAP32[$tmp4+16>>2]=HEAP32[515232+16>>2]|0;HEAP32[$tmp4+20>>2]=HEAP32[515232+20>>2]|0;HEAP32[$tmp4+24>>2]=HEAP32[515232+24>>2]|0;HEAP32[$tmp4+28>>2]=HEAP32[515232+28>>2]|0;
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$tmp4,32)|0);
 ;HEAP32[$tmp5+0>>2]=HEAP32[515088+0>>2]|0;HEAP32[$tmp5+4>>2]=HEAP32[515088+4>>2]|0;HEAP32[$tmp5+8>>2]=HEAP32[515088+8>>2]|0;HEAP32[$tmp5+12>>2]=HEAP32[515088+12>>2]|0;HEAP32[$tmp5+16>>2]=HEAP32[515088+16>>2]|0;HEAP32[$tmp5+20>>2]=HEAP32[515088+20>>2]|0;HEAP32[$tmp5+24>>2]=HEAP32[515088+24>>2]|0;HEAP32[$tmp5+28>>2]=HEAP32[515088+28>>2]|0;
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$tmp5,32)|0);
 ;HEAP32[$tmp6+0>>2]=HEAP32[515120+0>>2]|0;HEAP32[$tmp6+4>>2]=HEAP32[515120+4>>2]|0;HEAP32[$tmp6+8>>2]=HEAP32[515120+8>>2]|0;HEAP32[$tmp6+12>>2]=HEAP32[515120+12>>2]|0;HEAP32[$tmp6+16>>2]=HEAP32[515120+16>>2]|0;HEAP32[$tmp6+20>>2]=HEAP32[515120+20>>2]|0;HEAP32[$tmp6+24>>2]=HEAP32[515120+24>>2]|0;HEAP32[$tmp6+28>>2]=HEAP32[515120+28>>2]|0;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$tmp6,32)|0);
 ;HEAP32[$tmp7+0>>2]=HEAP32[515152+0>>2]|0;HEAP32[$tmp7+4>>2]=HEAP32[515152+4>>2]|0;HEAP32[$tmp7+8>>2]=HEAP32[515152+8>>2]|0;HEAP32[$tmp7+12>>2]=HEAP32[515152+12>>2]|0;HEAP32[$tmp7+16>>2]=HEAP32[515152+16>>2]|0;HEAP32[$tmp7+20>>2]=HEAP32[515152+20>>2]|0;HEAP32[$tmp7+24>>2]=HEAP32[515152+24>>2]|0;HEAP32[$tmp7+28>>2]=HEAP32[515152+28>>2]|0;
 $14 = HEAP32[$stream>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 (FUNCTION_TABLE_iiii[$15 & 2047]($stream,$tmp7,32)|0);
 ;HEAP32[$tmp8+0>>2]=HEAP32[515200+0>>2]|0;HEAP32[$tmp8+4>>2]=HEAP32[515200+4>>2]|0;HEAP32[$tmp8+8>>2]=HEAP32[515200+8>>2]|0;HEAP32[$tmp8+12>>2]=HEAP32[515200+12>>2]|0;HEAP32[$tmp8+16>>2]=HEAP32[515200+16>>2]|0;HEAP32[$tmp8+20>>2]=HEAP32[515200+20>>2]|0;HEAP32[$tmp8+24>>2]=HEAP32[515200+24>>2]|0;HEAP32[$tmp8+28>>2]=HEAP32[515200+28>>2]|0;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$tmp8,32)|0);
 ;HEAP32[$tmp9+0>>2]=HEAP32[515232+0>>2]|0;HEAP32[$tmp9+4>>2]=HEAP32[515232+4>>2]|0;HEAP32[$tmp9+8>>2]=HEAP32[515232+8>>2]|0;HEAP32[$tmp9+12>>2]=HEAP32[515232+12>>2]|0;HEAP32[$tmp9+16>>2]=HEAP32[515232+16>>2]|0;HEAP32[$tmp9+20>>2]=HEAP32[515232+20>>2]|0;HEAP32[$tmp9+24>>2]=HEAP32[515232+24>>2]|0;HEAP32[$tmp9+28>>2]=HEAP32[515232+28>>2]|0;
 $18 = HEAP32[$stream>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$tmp9,32)|0);
 ;HEAP32[$tmp10+0>>2]=HEAP32[515288+0>>2]|0;HEAP32[$tmp10+4>>2]=HEAP32[515288+4>>2]|0;HEAP32[$tmp10+8>>2]=HEAP32[515288+8>>2]|0;HEAP32[$tmp10+12>>2]=HEAP32[515288+12>>2]|0;HEAP32[$tmp10+16>>2]=HEAP32[515288+16>>2]|0;HEAP32[$tmp10+20>>2]=HEAP32[515288+20>>2]|0;HEAP32[$tmp10+24>>2]=HEAP32[515288+24>>2]|0;HEAP32[$tmp10+28>>2]=HEAP32[515288+28>>2]|0;
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$tmp10,32)|0);
 ;HEAP32[$tmp11+0>>2]=HEAP32[515336+0>>2]|0;HEAP32[$tmp11+4>>2]=HEAP32[515336+4>>2]|0;HEAP32[$tmp11+8>>2]=HEAP32[515336+8>>2]|0;HEAP32[$tmp11+12>>2]=HEAP32[515336+12>>2]|0;HEAP32[$tmp11+16>>2]=HEAP32[515336+16>>2]|0;HEAP32[$tmp11+20>>2]=HEAP32[515336+20>>2]|0;HEAP32[$tmp11+24>>2]=HEAP32[515336+24>>2]|0;HEAP32[$tmp11+28>>2]=HEAP32[515336+28>>2]|0;
 $22 = HEAP32[$stream>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_iiii[$23 & 2047]($stream,$tmp11,32)|0);
 ;HEAP32[$tmp12+0>>2]=HEAP32[515392+0>>2]|0;HEAP32[$tmp12+4>>2]=HEAP32[515392+4>>2]|0;HEAP32[$tmp12+8>>2]=HEAP32[515392+8>>2]|0;HEAP32[$tmp12+12>>2]=HEAP32[515392+12>>2]|0;HEAP32[$tmp12+16>>2]=HEAP32[515392+16>>2]|0;HEAP32[$tmp12+20>>2]=HEAP32[515392+20>>2]|0;HEAP32[$tmp12+24>>2]=HEAP32[515392+24>>2]|0;HEAP32[$tmp12+28>>2]=HEAP32[515392+28>>2]|0;
 $24 = HEAP32[$stream>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_iiii[$25 & 2047]($stream,$tmp12,32)|0);
 ;HEAP32[$tmp13+0>>2]=HEAP32[515448+0>>2]|0;HEAP32[$tmp13+4>>2]=HEAP32[515448+4>>2]|0;HEAP32[$tmp13+8>>2]=HEAP32[515448+8>>2]|0;HEAP32[$tmp13+12>>2]=HEAP32[515448+12>>2]|0;HEAP32[$tmp13+16>>2]=HEAP32[515448+16>>2]|0;HEAP32[$tmp13+20>>2]=HEAP32[515448+20>>2]|0;HEAP32[$tmp13+24>>2]=HEAP32[515448+24>>2]|0;HEAP32[$tmp13+28>>2]=HEAP32[515448+28>>2]|0;
 $26 = HEAP32[$stream>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 (FUNCTION_TABLE_iiii[$27 & 2047]($stream,$tmp13,32)|0);
 ;HEAP32[$tmp14+0>>2]=HEAP32[515480+0>>2]|0;HEAP32[$tmp14+4>>2]=HEAP32[515480+4>>2]|0;HEAP32[$tmp14+8>>2]=HEAP32[515480+8>>2]|0;HEAP32[$tmp14+12>>2]=HEAP32[515480+12>>2]|0;HEAP32[$tmp14+16>>2]=HEAP32[515480+16>>2]|0;HEAP32[$tmp14+20>>2]=HEAP32[515480+20>>2]|0;HEAP32[$tmp14+24>>2]=HEAP32[515480+24>>2]|0;HEAP32[$tmp14+28>>2]=HEAP32[515480+28>>2]|0;
 $28 = HEAP32[$stream>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 (FUNCTION_TABLE_iiii[$29 & 2047]($stream,$tmp14,32)|0);
 HEAP32[$tmp15>>2] = 514472;
 $30 = (($tmp15) + 4|0);
 HEAP32[$30>>2] = 515512;
 $31 = (($tmp15) + 8|0);
 HEAP32[$31>>2] = 0;
 $32 = (($tmp15) + 12|0);
 HEAP32[$32>>2] = 368;
 $33 = (($tmp15) + 16|0);
 HEAP32[$33>>2] = 0;
 $34 = (($tmp15) + 20|0);
 HEAP32[$34>>2] = 0;
 $35 = (($tmp15) + 24|0);
 HEAP32[$35>>2] = 1;
 $36 = (($tmp15) + 28|0);
 HEAP32[$36>>2] = 0;
 $37 = HEAP32[$stream>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 (FUNCTION_TABLE_iiii[$38 & 2047]($stream,$tmp15,32)|0);
 ;HEAP32[$tmp16+0>>2]=HEAP32[515544+0>>2]|0;HEAP32[$tmp16+4>>2]=HEAP32[515544+4>>2]|0;HEAP32[$tmp16+8>>2]=HEAP32[515544+8>>2]|0;HEAP32[$tmp16+12>>2]=HEAP32[515544+12>>2]|0;HEAP32[$tmp16+16>>2]=HEAP32[515544+16>>2]|0;HEAP32[$tmp16+20>>2]=HEAP32[515544+20>>2]|0;HEAP32[$tmp16+24>>2]=HEAP32[515544+24>>2]|0;HEAP32[$tmp16+28>>2]=HEAP32[515544+28>>2]|0;
 $39 = HEAP32[$stream>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 (FUNCTION_TABLE_iiii[$40 & 2047]($stream,$tmp16,32)|0);
 ;HEAP32[$tmp17+0>>2]=HEAP32[515608+0>>2]|0;HEAP32[$tmp17+4>>2]=HEAP32[515608+4>>2]|0;HEAP32[$tmp17+8>>2]=HEAP32[515608+8>>2]|0;HEAP32[$tmp17+12>>2]=HEAP32[515608+12>>2]|0;HEAP32[$tmp17+16>>2]=HEAP32[515608+16>>2]|0;HEAP32[$tmp17+20>>2]=HEAP32[515608+20>>2]|0;HEAP32[$tmp17+24>>2]=HEAP32[515608+24>>2]|0;HEAP32[$tmp17+28>>2]=HEAP32[515608+28>>2]|0;
 $41 = HEAP32[$stream>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 (FUNCTION_TABLE_iiii[$42 & 2047]($stream,$tmp17,32)|0);
 ;HEAP32[$tmp18+0>>2]=HEAP32[515656+0>>2]|0;HEAP32[$tmp18+4>>2]=HEAP32[515656+4>>2]|0;HEAP32[$tmp18+8>>2]=HEAP32[515656+8>>2]|0;HEAP32[$tmp18+12>>2]=HEAP32[515656+12>>2]|0;HEAP32[$tmp18+16>>2]=HEAP32[515656+16>>2]|0;HEAP32[$tmp18+20>>2]=HEAP32[515656+20>>2]|0;HEAP32[$tmp18+24>>2]=HEAP32[515656+24>>2]|0;HEAP32[$tmp18+28>>2]=HEAP32[515656+28>>2]|0;
 $43 = HEAP32[$stream>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 (FUNCTION_TABLE_iiii[$44 & 2047]($stream,$tmp18,32)|0);
 ;HEAP32[$tmp19+0>>2]=HEAP32[515688+0>>2]|0;HEAP32[$tmp19+4>>2]=HEAP32[515688+4>>2]|0;HEAP32[$tmp19+8>>2]=HEAP32[515688+8>>2]|0;HEAP32[$tmp19+12>>2]=HEAP32[515688+12>>2]|0;HEAP32[$tmp19+16>>2]=HEAP32[515688+16>>2]|0;HEAP32[$tmp19+20>>2]=HEAP32[515688+20>>2]|0;HEAP32[$tmp19+24>>2]=HEAP32[515688+24>>2]|0;HEAP32[$tmp19+28>>2]=HEAP32[515688+28>>2]|0;
 $45 = HEAP32[$stream>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 (FUNCTION_TABLE_iiii[$46 & 2047]($stream,$tmp19,32)|0);
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleWheels7releaseEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15PxVehicleWheels4freeEv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxVehicleNoDrive19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (512120|0);
}
function __ZN5physx16PxVehicleNoDriveD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleNoDriveD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxVehicleNoDrive8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(512120,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,514568)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx18PxVehicleDriveTank19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (512672|0);
}
function __ZN5physx18PxVehicleDriveTankD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx18PxVehicleDriveTankD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx18PxVehicleDriveTank8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(512672,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,514568)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx16PxVehicleDriveNW19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (512584|0);
}
function __ZN5physx16PxVehicleDriveNWD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleDriveNWD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxVehicleDriveNW8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(512584,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,514568)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx16PxVehicleDrive4W19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (512480|0);
}
function __ZN5physx16PxVehicleDrive4WD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleDrive4WD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx16PxVehicleDrive4W8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(512480,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,514568)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx16PxVehicleNoDrive8allocateEj($numWheels) {
 $numWheels = $numWheels|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($numWheels) + 3)|0;
 $2 = $1 >>> 2;
 $3 = $2 << 4;
 $4 = ($2*48)|0;
 $5 = (($4) + 144)|0;
 $6 = (__ZN5physx15PxVehicleWheels15computeByteSizeEj($2)|0);
 $7 = (($5) + ($6))|0;
 $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$7,519216,63)|0);
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  __ZN5physx16PxVehicleNoDriveC2Ev($8);
 }
 $10 = (($8) + 144|0);
 $11 = (__ZN5physx15PxVehicleWheels15patchupPointersEPS0_Phjjb($8,$10,$2,$numWheels,1)|0);
 $12 = (($8) + 128|0);
 HEAP32[$12>>2] = $11;
 $13 = (($11) + ($3)|0);
 $14 = (($8) + 132|0);
 HEAP32[$14>>2] = $13;
 $$sum = $2 << 5;
 $15 = (($11) + ($$sum)|0);
 $16 = (($8) + 136|0);
 HEAP32[$16>>2] = $15;
 _memset(($11|0),0,($3|0))|0;
 $17 = HEAP32[$14>>2]|0;
 _memset(($17|0),0,($3|0))|0;
 $18 = HEAP32[$16>>2]|0;
 _memset(($18|0),0,($3|0))|0;
 $19 = (($8) + 113|0);
 HEAP8[$19>>0] = 3;
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx16PxVehicleNoDrive4freeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15PxVehicleWheels4freeEv($this);
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleNoDrive5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataE($this,$physics,$vehActor,$wheelsData) {
 $this = $this|0;
 $physics = $physics|0;
 $vehActor = $vehActor|0;
 $wheelsData = $wheelsData|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($wheelsData) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx15PxVehicleWheels5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataEjj($this,$physics,$vehActor,$wheelsData,0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleNoDrive14setBrakeTorqueEjf($this,$id,$brakeTorque) {
 $this = $this|0;
 $id = $id|0;
 $brakeTorque = Math_fround($brakeTorque);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($id<<2)|0);
 HEAPF32[$2>>2] = $brakeTorque;
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleNoDrive14setDriveTorqueEjf($this,$id,$driveTorque) {
 $this = $this|0;
 $id = $id|0;
 $driveTorque = Math_fround($driveTorque);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($id<<2)|0);
 HEAPF32[$2>>2] = $driveTorque;
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleNoDrive13setSteerAngleEjf($this,$id,$steerAngle) {
 $this = $this|0;
 $id = $id|0;
 $steerAngle = Math_fround($steerAngle);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($id<<2)|0);
 HEAPF32[$2>>2] = $steerAngle;
 STACKTOP = sp;return;
}
function __ZNK5physx16PxVehicleNoDrive14getBrakeTorqueEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($id<<2)|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 STACKTOP = sp;return (Math_fround($3));
}
function __ZNK5physx16PxVehicleNoDrive14getDriveTorqueEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($id<<2)|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 STACKTOP = sp;return (Math_fround($3));
}
function __ZNK5physx16PxVehicleNoDrive13getSteerAngleEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($id<<2)|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 STACKTOP = sp;return (Math_fround($3));
}
function __ZN5physx16PxInitVehicleSDKERNS_9PxPhysicsEPNS_23PxSerializationRegistryE($physics,$sr) {
 $physics = $physics|0;
 $sr = $sr|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx6shdfnd10Foundation11incRefCountEv();
 $0 = HEAP32[$physics>>2]|0;
 $1 = (($0) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($physics)|0);
 __ZN5physx24setVehicleToleranceScaleERKNS_17PxTolerancesScaleE($3);
 __ZN5physx27setSerializationRegistryPtrEPKNS_23PxSerializationRegistryE($sr);
 $4 = ($sr|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return 1;
 }
 $5 = HEAP32[$sr>>2]|0;
 $6 = (($5) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z15PxGetFoundationv()|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,8,519304,519328,65)|0);
 $17 = (__Z15PxGetFoundationv()|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_ii[$20 & 4095]($17)|0);
 $22 = (($16) + 4|0);
 HEAP32[$22>>2] = $21;
 HEAP32[$16>>2] = ((521024 + 8|0));
 FUNCTION_TABLE_viii[$7 & 4095]($sr,513,$16);
 $23 = HEAP32[$sr>>2]|0;
 $24 = (($23) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (__Z15PxGetFoundationv()|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (FUNCTION_TABLE_ii[$29 & 4095]($26)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_iiiiii[$33 & 255]($30,8,519304,519328,66)|0);
 $35 = (__Z15PxGetFoundationv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 4095]($35)|0);
 $40 = (($34) + 4|0);
 HEAP32[$40>>2] = $39;
 HEAP32[$34>>2] = ((521280 + 8|0));
 FUNCTION_TABLE_viii[$25 & 4095]($sr,515,$34);
 $41 = HEAP32[$sr>>2]|0;
 $42 = (($41) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (__Z15PxGetFoundationv()|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 20|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (FUNCTION_TABLE_ii[$47 & 4095]($44)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 8|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (FUNCTION_TABLE_iiiiii[$51 & 255]($48,8,519304,519328,67)|0);
 $53 = (__Z15PxGetFoundationv()|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 20|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (FUNCTION_TABLE_ii[$56 & 4095]($53)|0);
 $58 = (($52) + 4|0);
 HEAP32[$58>>2] = $57;
 HEAP32[$52>>2] = ((521320 + 8|0));
 FUNCTION_TABLE_viii[$43 & 4095]($sr,514,$52);
 $59 = HEAP32[$sr>>2]|0;
 $60 = (($59) + 16|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (__Z15PxGetFoundationv()|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 20|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (FUNCTION_TABLE_ii[$65 & 4095]($62)|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 8|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (FUNCTION_TABLE_iiiiii[$69 & 255]($66,8,519304,519328,68)|0);
 $71 = (__Z15PxGetFoundationv()|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + 20|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (FUNCTION_TABLE_ii[$74 & 4095]($71)|0);
 $76 = (($70) + 4|0);
 HEAP32[$76>>2] = $75;
 HEAP32[$70>>2] = ((521360 + 8|0));
 FUNCTION_TABLE_viii[$61 & 4095]($sr,512,$70);
 $77 = HEAP32[$sr>>2]|0;
 $78 = HEAP32[$77>>2]|0;
 $79 = (__Z15PxGetFoundationv()|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + 20|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (FUNCTION_TABLE_ii[$82 & 4095]($79)|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($84) + 8|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (FUNCTION_TABLE_iiiiii[$86 & 255]($83,8,519416,519328,70)|0);
 $88 = ($87|0)==(0|0);
 if ($88) {
  $90 = 0;
 } else {
  HEAP32[$87>>2] = ((519856 + 8|0));
  $89 = (($87) + 4|0);
  HEAP32[$89>>2] = 519448;
  $90 = $87;
 }
 FUNCTION_TABLE_viii[$78 & 4095]($sr,513,$90);
 $91 = HEAP32[$sr>>2]|0;
 $92 = HEAP32[$91>>2]|0;
 $93 = (__Z15PxGetFoundationv()|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($94) + 20|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (FUNCTION_TABLE_ii[$96 & 4095]($93)|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (($98) + 8|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (FUNCTION_TABLE_iiiiii[$100 & 255]($97,8,519416,519328,71)|0);
 $102 = ($101|0)==(0|0);
 if ($102) {
  $104 = 0;
 } else {
  HEAP32[$101>>2] = ((519784 + 8|0));
  $103 = (($101) + 4|0);
  HEAP32[$103>>2] = 519472;
  $104 = $101;
 }
 FUNCTION_TABLE_viii[$92 & 4095]($sr,515,$104);
 $105 = HEAP32[$sr>>2]|0;
 $106 = HEAP32[$105>>2]|0;
 $107 = (__Z15PxGetFoundationv()|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($108) + 20|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = (FUNCTION_TABLE_ii[$110 & 4095]($107)|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = (($112) + 8|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (FUNCTION_TABLE_iiiiii[$114 & 255]($111,8,519416,519328,72)|0);
 $116 = ($115|0)==(0|0);
 if ($116) {
  $118 = 0;
 } else {
  HEAP32[$115>>2] = ((519712 + 8|0));
  $117 = (($115) + 4|0);
  HEAP32[$117>>2] = 519496;
  $118 = $115;
 }
 FUNCTION_TABLE_viii[$106 & 4095]($sr,512,$118);
 $119 = HEAP32[$sr>>2]|0;
 $120 = HEAP32[$119>>2]|0;
 $121 = (__Z15PxGetFoundationv()|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 20|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (FUNCTION_TABLE_ii[$124 & 4095]($121)|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (($126) + 8|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = (FUNCTION_TABLE_iiiiii[$128 & 255]($125,8,519416,519328,73)|0);
 $130 = ($129|0)==(0|0);
 if ($130) {
  $132 = 0;
 } else {
  HEAP32[$129>>2] = ((519640 + 8|0));
  $131 = (($129) + 4|0);
  HEAP32[$131>>2] = 519520;
  $132 = $129;
 }
 FUNCTION_TABLE_viii[$120 & 4095]($sr,514,$132);
 $133 = HEAP32[$sr>>2]|0;
 $134 = (($133) + 8|0);
 $135 = HEAP32[$134>>2]|0;
 FUNCTION_TABLE_vii[$135 & 4095]($sr,3369);
 $136 = HEAP32[$sr>>2]|0;
 $137 = (($136) + 8|0);
 $138 = HEAP32[$137>>2]|0;
 FUNCTION_TABLE_vii[$138 & 4095]($sr,3370);
 $139 = HEAP32[$sr>>2]|0;
 $140 = (($139) + 8|0);
 $141 = HEAP32[$140>>2]|0;
 FUNCTION_TABLE_vii[$141 & 4095]($sr,3371);
 $142 = HEAP32[$sr>>2]|0;
 $143 = (($142) + 8|0);
 $144 = HEAP32[$143>>2]|0;
 FUNCTION_TABLE_vii[$144 & 4095]($sr,3372);
 STACKTOP = sp;return 1;
}
function __ZN5physx17PxCloseVehicleSDKEPNS_23PxSerializationRegistryE($sr) {
 $sr = $sr|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 __ZN5physx6shdfnd10Foundation11decRefCountEv();
 __ZN5physx26resetVehicleToleranceScaleEv();
 $0 = (__ZN5physx29resetSerializationRegistryPtrEv()|0);
 $1 = ($0|0)==($sr|0);
 if (!($1)) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,4,519328,91,519544,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $3 = ($sr|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$sr>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iii[$6 & 4095]($sr,513)|0);
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($7);
  $12 = (__Z15PxGetFoundationv()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vii[$19 & 4095]($16,$7);
 }
 $20 = HEAP32[$sr>>2]|0;
 $21 = (($20) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_iii[$22 & 4095]($sr,515)|0);
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = HEAP32[$23>>2]|0;
  $26 = (($25) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vi[$27 & 4095]($23);
  $28 = (__Z15PxGetFoundationv()|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 20|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 12|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vii[$35 & 4095]($32,$23);
 }
 $36 = HEAP32[$sr>>2]|0;
 $37 = (($36) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_iii[$38 & 4095]($sr,512)|0);
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = HEAP32[$39>>2]|0;
  $42 = (($41) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_vi[$43 & 4095]($39);
  $44 = (__Z15PxGetFoundationv()|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 20|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (FUNCTION_TABLE_ii[$47 & 4095]($44)|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 12|0);
  $51 = HEAP32[$50>>2]|0;
  FUNCTION_TABLE_vii[$51 & 4095]($48,$39);
 }
 $52 = HEAP32[$sr>>2]|0;
 $53 = (($52) + 4|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (FUNCTION_TABLE_iii[$54 & 4095]($sr,514)|0);
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = HEAP32[$55>>2]|0;
  $58 = (($57) + 32|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vi[$59 & 4095]($55);
  $60 = (__Z15PxGetFoundationv()|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + 12|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_vii[$67 & 4095]($64,$55);
 }
 $68 = HEAP32[$sr>>2]|0;
 $69 = (($68) + 20|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (FUNCTION_TABLE_iii[$70 & 4095]($sr,513)|0);
 $72 = ($71|0)==(0|0);
 if (!($72)) {
  $73 = (__Z15PxGetFoundationv()|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + 20|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (FUNCTION_TABLE_ii[$76 & 4095]($73)|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($78) + 12|0);
  $80 = HEAP32[$79>>2]|0;
  FUNCTION_TABLE_vii[$80 & 4095]($77,$71);
 }
 $81 = HEAP32[$sr>>2]|0;
 $82 = (($81) + 20|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (FUNCTION_TABLE_iii[$83 & 4095]($sr,515)|0);
 $85 = ($84|0)==(0|0);
 if (!($85)) {
  $86 = (__Z15PxGetFoundationv()|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (($87) + 20|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (FUNCTION_TABLE_ii[$89 & 4095]($86)|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($91) + 12|0);
  $93 = HEAP32[$92>>2]|0;
  FUNCTION_TABLE_vii[$93 & 4095]($90,$84);
 }
 $94 = HEAP32[$sr>>2]|0;
 $95 = (($94) + 20|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (FUNCTION_TABLE_iii[$96 & 4095]($sr,512)|0);
 $98 = ($97|0)==(0|0);
 if (!($98)) {
  $99 = (__Z15PxGetFoundationv()|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($100) + 20|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (FUNCTION_TABLE_ii[$102 & 4095]($99)|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($104) + 12|0);
  $106 = HEAP32[$105>>2]|0;
  FUNCTION_TABLE_vii[$106 & 4095]($103,$97);
 }
 $107 = HEAP32[$sr>>2]|0;
 $108 = (($107) + 20|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = (FUNCTION_TABLE_iii[$109 & 4095]($sr,514)|0);
 $111 = ($110|0)==(0|0);
 if ($111) {
  STACKTOP = sp;return;
 }
 $112 = (__Z15PxGetFoundationv()|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($113) + 20|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (FUNCTION_TABLE_ii[$115 & 4095]($112)|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = (($117) + 12|0);
 $119 = HEAP32[$118>>2]|0;
 FUNCTION_TABLE_vii[$119 & 4095]($116,$110);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE8requiresERNS_6PxBaseERNS_23PxProcessPxBaseCallbackE($this,$obj,$c) {
 $this = $this|0;
 $obj = $obj|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($obj,$c);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE13isSubordinateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE15exportExtraDataERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($obj,$s);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE10exportDataERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$s>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($s,$obj,768);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $callback = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $callback = sp;
 $0 = HEAP32[$s>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = $obj;
 FUNCTION_TABLE_viiii[$1 & 511]($s,$obj,-2147483648,$2);
 HEAP32[$callback>>2] = ((519688 + 8|0));
 $3 = (($callback) + 4|0);
 HEAP32[$3>>2] = $s;
 $4 = HEAP32[$obj>>2]|0;
 $5 = (($4) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($obj,$callback);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE12getClassSizeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 768;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE12createObjectERPhRNS_24PxDeserializationContextE($this,$address,$context) {
 $this = $this|0;
 $address = $address|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx16PxVehicleDriveNW12createObjectERPhRNS_24PxDeserializationContextE($address,$context)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD2E_4v($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD0E_4v($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallback7processE_4S4_($this,$base) {
 $this = $this|0;
 $base = $base|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = $base;
 FUNCTION_TABLE_viiii[$3 & 511]($1,$base,-2147483648,$4);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE8requiresERNS_6PxBaseERNS_23PxProcessPxBaseCallbackE($this,$obj,$c) {
 $this = $this|0;
 $obj = $obj|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($obj,$c);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE13isSubordinateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE15exportExtraDataERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($obj,$s);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE10exportDataERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$s>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($s,$obj,144);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $callback = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $callback = sp;
 $0 = HEAP32[$s>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = $obj;
 FUNCTION_TABLE_viiii[$1 & 511]($s,$obj,-2147483648,$2);
 HEAP32[$callback>>2] = ((519760 + 8|0));
 $3 = (($callback) + 4|0);
 HEAP32[$3>>2] = $s;
 $4 = HEAP32[$obj>>2]|0;
 $5 = (($4) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($obj,$callback);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE12getClassSizeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 144;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE12createObjectERPhRNS_24PxDeserializationContextE($this,$address,$context) {
 $this = $this|0;
 $address = $address|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx16PxVehicleNoDrive12createObjectERPhRNS_24PxDeserializationContextE($address,$context)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD2E_3v($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD0E_3v($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallback7processE_3S4_($this,$base) {
 $this = $this|0;
 $base = $base|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = $base;
 FUNCTION_TABLE_viiii[$3 & 511]($1,$base,-2147483648,$4);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE8requiresERNS_6PxBaseERNS_23PxProcessPxBaseCallbackE($this,$obj,$c) {
 $this = $this|0;
 $obj = $obj|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($obj,$c);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE13isSubordinateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE15exportExtraDataERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($obj,$s);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE10exportDataERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$s>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($s,$obj,768);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $callback = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $callback = sp;
 $0 = HEAP32[$s>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = $obj;
 FUNCTION_TABLE_viiii[$1 & 511]($s,$obj,-2147483648,$2);
 HEAP32[$callback>>2] = ((519832 + 8|0));
 $3 = (($callback) + 4|0);
 HEAP32[$3>>2] = $s;
 $4 = HEAP32[$obj>>2]|0;
 $5 = (($4) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($obj,$callback);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE12getClassSizeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 768;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE12createObjectERPhRNS_24PxDeserializationContextE($this,$address,$context) {
 $this = $this|0;
 $address = $address|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx18PxVehicleDriveTank12createObjectERPhRNS_24PxDeserializationContextE($address,$context)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD2E_2v($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD0E_2v($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallback7processE_2S4_($this,$base) {
 $this = $this|0;
 $base = $base|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = $base;
 FUNCTION_TABLE_viiii[$3 & 511]($1,$base,-2147483648,$4);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE8requiresERNS_6PxBaseERNS_23PxProcessPxBaseCallbackE($this,$obj,$c) {
 $this = $this|0;
 $obj = $obj|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($obj,$c);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE13isSubordinateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE15exportExtraDataERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($obj,$s);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE10exportDataERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$s>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($s,$obj,800);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextE($this,$obj,$s) {
 $this = $this|0;
 $obj = $obj|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $callback = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $callback = sp;
 $0 = HEAP32[$s>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = $obj;
 FUNCTION_TABLE_viiii[$1 & 511]($s,$obj,-2147483648,$2);
 HEAP32[$callback>>2] = ((519904 + 8|0));
 $3 = (($callback) + 4|0);
 HEAP32[$3>>2] = $s;
 $4 = HEAP32[$obj>>2]|0;
 $5 = (($4) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($obj,$callback);
 STACKTOP = sp;return;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE12getClassSizeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 800;
}
function __ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE12createObjectERPhRNS_24PxDeserializationContextE($this,$address,$context) {
 $this = $this|0;
 $address = $address|0;
 $context = $context|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx16PxVehicleDrive4W12createObjectERPhRNS_24PxDeserializationContextE($address,$context)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD2E_1v($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD0E_1v($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallback7processE_1S4_($this,$base) {
 $this = $this|0;
 $base = $base|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = $base;
 FUNCTION_TABLE_viiii[$3 & 511]($1,$base,-2147483648,$4);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleNoDriveEE11getTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (519496|0);
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleNoDriveEE12objectToFileERKNS_12PxRepXObjectEPNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE($this,$inLiveObject,$inCollection,$inWriter,$inTempBuffer,$inArgs) {
 $this = $this|0;
 $inLiveObject = $inLiveObject|0;
 $inCollection = $inCollection|0;
 $inWriter = $inWriter|0;
 $inTempBuffer = $inTempBuffer|0;
 $inArgs = $inArgs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inLiveObject) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiiiii[$4 & 255]($this,$1,$inCollection,$inWriter,$inTempBuffer,$inArgs);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleNoDriveEE16fileToObjectImplEPS1_RNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE($this,$inObj,$inReader,$inAllocator,$inArgs,$inCollection) {
 $this = $this|0;
 $inObj = $inObj|0;
 $inReader = $inReader|0;
 $inAllocator = $inAllocator|0;
 $inArgs = $inArgs|0;
 $inCollection = $inCollection|0;
 var $inArgs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $inArgs$byval_copy = sp;
 ;HEAP32[$inArgs$byval_copy+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy+8>>2]=HEAP32[$inArgs+8>>2]|0;
 __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleNoDriveEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy,$inReader,$inObj,$inAllocator,$inCollection);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleNoDriveEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($args,$reader,$obj,$alloc,$collection) {
 $args = $args|0;
 $reader = $reader|0;
 $obj = $obj|0;
 $alloc = $alloc|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $contexts = 0, $info = 0;
 var $names = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $wrapper = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $0 = sp + 256|0;
 $1 = sp + 16|0;
 $2 = sp;
 $wrapper = sp + 64|0;
 $names = sp + 72|0;
 $contexts = sp + 88|0;
 $info = sp + 104|0;
 $3 = HEAP32[$alloc>>2]|0;
 $4 = (($3) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($alloc)|0);
 HEAP32[$wrapper>>2] = $6;
 HEAP32[$names>>2] = $wrapper;
 $7 = (($names) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($names) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($names) + 12|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$contexts>>2] = $wrapper;
 $10 = (($contexts) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($contexts) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (($contexts) + 12|0);
 HEAP32[$12>>2] = 0;
 __ZN5physx29PxVehicleNoDriveGeneratedInfoC2Ev($info);
 ;HEAP32[$2+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$args+8>>2]|0;
 HEAP32[$0>>2] = $names;
 $13 = (($0) + 4|0);
 HEAP32[$13>>2] = $contexts;
 $14 = (($0) + 8|0);
 ;HEAP32[$14+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$2+8>>2]|0;
 $15 = (($0) + 20|0);
 HEAP32[$15>>2] = $reader;
 $16 = (($0) + 24|0);
 HEAP32[$16>>2] = $obj;
 $17 = (($0) + 28|0);
 HEAP32[$17>>2] = $alloc;
 $18 = (($0) + 32|0);
 HEAP32[$18>>2] = $collection;
 $19 = (($0) + 36|0);
 HEAP8[$19>>0] = 1;
 $20 = (($0) + 40|0);
 HEAP32[$20>>2] = 0;
 $21 = (($0) + 44|0);
 HEAP32[$21>>2] = 0;
 $22 = (($info) + 36|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEEclILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$22,0);
 $23 = (($info) + 52|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEEclILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$23,0);
 HEAP32[$1>>2] = $names;
 $24 = (($1) + 4|0);
 HEAP32[$24>>2] = $contexts;
 $25 = (($1) + 8|0);
 ;HEAP32[$25+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$args+8>>2]|0;
 $26 = (($1) + 20|0);
 HEAP32[$26>>2] = $reader;
 $27 = (($1) + 24|0);
 HEAP32[$27>>2] = $obj;
 $28 = (($1) + 28|0);
 HEAP32[$28>>2] = $alloc;
 $29 = (($1) + 32|0);
 HEAP32[$29>>2] = $collection;
 $30 = (($1) + 36|0);
 HEAP8[$30>>0] = 1;
 $31 = (($1) + 40|0);
 HEAP32[$31>>2] = 0;
 $32 = (($1) + 44|0);
 HEAP32[$32>>2] = 0;
 $33 = (($info) + 68|0);
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEE27handleExtendedIndexPropertyILj685ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($1,0,$33,$0);
 $34 = (($info) + 92|0);
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEE27handleExtendedIndexPropertyILj686ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($1,1,$34,$0);
 $35 = (($info) + 116|0);
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEE27handleExtendedIndexPropertyILj687ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($1,2,$35,$0);
 $36 = HEAP32[$12>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37|0)!=(0);
 $39 = ($36|0)>(-1);
 $or$cond$i$i$i1 = $38 & $39;
 if ($or$cond$i$i$i1) {
  $40 = HEAP32[$10>>2]|0;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = HEAP32[$contexts>>2]|0;
   $43 = HEAP32[$42>>2]|0;
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   FUNCTION_TABLE_vii[$46 & 4095]($43,$40);
  }
 }
 $47 = HEAP32[$9>>2]|0;
 $48 = $47 & 2147483647;
 $49 = ($48|0)!=(0);
 $50 = ($47|0)>(-1);
 $or$cond$i$i$i = $49 & $50;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $51 = HEAP32[$7>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = HEAP32[$names>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 12|0);
 $57 = HEAP32[$56>>2]|0;
 FUNCTION_TABLE_vii[$57 & 4095]($54,$51);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEE27handleExtendedIndexPropertyILj687ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj687ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj687ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$0$lcssa$i$i$ph$i$i = 0, $$05$i$i$i$i = 0, $$14$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dest$0$lcssa$i$i$i$i = 0;
 var $dest$03$i$i$i$i = 0, $end$i$i$i$i = 0, $index$01 = 0, $temp$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i$i = sp + 8|0;
 $end$i$i$i$i = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$temp$i$i$i$i>>2] = $5;
 $6 = (($2) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($2) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = (($2) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = $10;
  } else {
   HEAP32[$14>>2] = $5;
   $$pre$i$i = HEAP32[$9>>2]|0;
   $17 = $$pre$i$i;
  }
  $16 = (($17) + 1)|0;
  HEAP32[$9>>2] = $16;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($2,$temp$i$i$i$i)|0);
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = ((($24) + ($22<<3)|0) + 4|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = (($this) + 36|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $41 = $20;$43 = $24;$44 = 0;
   } else {
    $32 = (($this) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$25>>2]|0;
    $38 = (FUNCTION_TABLE_iii[$36 & 4095]($33,$37)|0);
    $39 = $38&1;
    HEAP8[$29>>0] = $39;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $41 = $$pre1$i;$43 = $$pre3$i;$44 = $39;
   }
   $40 = (($41) + -1)|0;
   $42 = ((($43) + ($40<<3)|0) + 5|0);
   HEAP8[$42>>0] = $44;
   $45 = HEAP8[$29>>0]|0;
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + -1)|0;
   $50 = (($46) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51) + ($49<<3)|0) + 4|0);
   HEAP8[$52>>0] = $45;
  }
 }
 $53 = (($this) + 36|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,519928);
 $56 = HEAP8[$53>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $72 = 0;
 } else {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  $64 = $63&1;
  HEAP8[$53>>0] = $64;
  $72 = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + -1)|0;
 $69 = (($65) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70) + ($68<<3)|0) + 5|0);
 HEAP8[$71>>0] = $72;
 $73 = HEAP8[$53>>0]|0;
 $74 = HEAP32[$this>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + -1)|0;
 $78 = (($74) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 4|0);
 HEAP8[$80>>0] = $73;
 $81 = HEAP8[$53>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $83 = (($this) + 20|0);
 $84 = (($this) + 24|0);
 $85 = (($inProp) + 12|0);
 $86 = (($temp$i$i$i$i) + 255|0);
 $130 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $87 = HEAP32[$83>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 36|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 4095]($87)|0);
  $92 = ($91|0)==(0|0);
  if ($92) {
   $121 = $130;
  } else {
   $93 = HEAP8[$91>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $121 = $130;
   } else {
    $$05$i$i$i$i = $91;$99 = $93;
    while(1) {
     $98 = $99&255;
     $100 = (_isspace($98)|0);
     $101 = ($100|0)==(0);
     $96 = (($$05$i$i$i$i) + 1|0);
     if ($101) {
      $$0$lcssa$i$i$ph$i$i = $$05$i$i$i$i;
      break;
     }
     $95 = HEAP8[$96>>0]|0;
     $97 = ($95<<24>>24)==(0);
     if ($97) {
      $$0$lcssa$i$i$ph$i$i = $96;
      break;
     } else {
      $$05$i$i$i$i = $96;$99 = $95;
     }
    }
    _memset(($temp$i$i$i$i|0),0,256)|0;
    HEAP32[$end$i$i$i$i>>2] = $86;
    $102 = HEAP8[$$0$lcssa$i$i$ph$i$i>>0]|0;
    $103 = ($102<<24>>24)==(0);
    L32: do {
     if ($103) {
      $dest$0$lcssa$i$i$i$i = $temp$i$i$i$i;
     } else {
      $$14$i$i$i$i = $$0$lcssa$i$i$ph$i$i;$105 = $102;$dest$03$i$i$i$i = $temp$i$i$i$i;
      while(1) {
       $104 = $105&255;
       $106 = (_isspace($104)|0);
       $107 = ($106|0)==(0);
       if (!($107)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $108 = HEAP32[$end$i$i$i$i>>2]|0;
       $109 = ($dest$03$i$i$i$i>>>0)<($108>>>0);
       if (!($109)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $110 = (($$14$i$i$i$i) + 1|0);
       $111 = HEAP8[$$14$i$i$i$i>>0]|0;
       $112 = (($dest$03$i$i$i$i) + 1|0);
       HEAP8[$dest$03$i$i$i$i>>0] = $111;
       $113 = HEAP8[$110>>0]|0;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        $dest$0$lcssa$i$i$i$i = $112;
        break;
       } else {
        $$14$i$i$i$i = $110;$105 = $113;$dest$03$i$i$i$i = $112;
       }
      }
     }
    } while(0);
    HEAP8[$dest$0$lcssa$i$i$i$i>>0] = 0;
    $115 = (+_strtod($temp$i$i$i$i,$end$i$i$i$i));
    $116 = Math_fround($115);
    $121 = $116;
   }
  }
  $117 = HEAP32[$84>>2]|0;
  $118 = HEAP32[$85>>2]|0;
  $119 = (($118) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  FUNCTION_TABLE_viif[$120 & 63]($117,$index$01,$121);
  $122 = HEAP8[$53>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   label = 27;
   break;
  }
  $124 = (($index$01) + 1)|0;
  $125 = HEAP32[$83>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  if ($129) {
   $130 = $121;$index$01 = $124;
  } else {
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + -1)|0;
 $6 = (($1) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12>>>0)>($9>>>0);
 if ($13) {
  $14 = (($this) + 36|0);
  $15 = (($this) + 20|0);
  $17 = $12;$21 = $10;
  while(1) {
   $16 = ($17|0)==(0);
   if ($16) {
    label = 5;
    break;
   }
   $19 = (($17) + -1)|0;
   $20 = (($21) + 4|0);
   $22 = HEAP32[$20>>2]|0;
   $23 = ((($22) + ($19<<3)|0) + 4|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if ($25) {
    $34 = $21;$36 = $17;
   } else {
    $26 = ((($22) + ($19<<3)|0) + 5|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $34 = $21;$36 = $17;
    } else {
     $29 = HEAP32[$15>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($30) + 40|0);
     $32 = HEAP32[$31>>2]|0;
     (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
     $$pre2$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
     $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
     $34 = $$pre2$i;$36 = $$pre4$i;
    }
   }
   $33 = (($34) + 8|0);
   $35 = (($36) + -1)|0;
   HEAP32[$33>>2] = $35;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   HEAP8[$14>>0] = 1;
   $37 = ($$pre1$i|0)==(0);
   if ($37) {
    break;
   }
   $38 = (($$pre1$i) + -1)|0;
   $39 = (($$pre$i) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($40) + ($38<<3)|0) + 5|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    HEAP8[$14>>0] = 0;
   }
   $18 = ($$pre1$i>>>0)>($9>>>0);
   if ($18) {
    $17 = $$pre1$i;$21 = $$pre$i;
   } else {
    break;
   }
  }
  if ((label|0) == 5) {
   HEAP8[$14>>0] = 1;
  }
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
  $45 = $$pre;$47 = $$pre1;
 } else {
  $45 = $1;$47 = $3;
 }
 $44 = (($45) + 8|0);
 $46 = (($47) + -1)|0;
 HEAP32[$44>>2] = $46;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEE27handleExtendedIndexPropertyILj686ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj686ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,0);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj686ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$0$lcssa$i$i$ph$i$i = 0, $$05$i$i$i$i = 0, $$14$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dest$0$lcssa$i$i$i$i = 0;
 var $dest$03$i$i$i$i = 0, $end$i$i$i$i = 0, $index$01 = 0, $temp$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i$i = sp + 8|0;
 $end$i$i$i$i = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$temp$i$i$i$i>>2] = $5;
 $6 = (($2) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($2) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = (($2) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = $10;
  } else {
   HEAP32[$14>>2] = $5;
   $$pre$i$i = HEAP32[$9>>2]|0;
   $17 = $$pre$i$i;
  }
  $16 = (($17) + 1)|0;
  HEAP32[$9>>2] = $16;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($2,$temp$i$i$i$i)|0);
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = ((($24) + ($22<<3)|0) + 4|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = (($this) + 36|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $41 = $20;$43 = $24;$44 = 0;
   } else {
    $32 = (($this) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$25>>2]|0;
    $38 = (FUNCTION_TABLE_iii[$36 & 4095]($33,$37)|0);
    $39 = $38&1;
    HEAP8[$29>>0] = $39;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $41 = $$pre1$i;$43 = $$pre3$i;$44 = $39;
   }
   $40 = (($41) + -1)|0;
   $42 = ((($43) + ($40<<3)|0) + 5|0);
   HEAP8[$42>>0] = $44;
   $45 = HEAP8[$29>>0]|0;
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + -1)|0;
   $50 = (($46) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51) + ($49<<3)|0) + 4|0);
   HEAP8[$52>>0] = $45;
  }
 }
 $53 = (($this) + 36|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,519928);
 $56 = HEAP8[$53>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $72 = 0;
 } else {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  $64 = $63&1;
  HEAP8[$53>>0] = $64;
  $72 = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + -1)|0;
 $69 = (($65) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70) + ($68<<3)|0) + 5|0);
 HEAP8[$71>>0] = $72;
 $73 = HEAP8[$53>>0]|0;
 $74 = HEAP32[$this>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + -1)|0;
 $78 = (($74) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 4|0);
 HEAP8[$80>>0] = $73;
 $81 = HEAP8[$53>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $83 = (($this) + 20|0);
 $84 = (($this) + 24|0);
 $85 = (($inProp) + 12|0);
 $86 = (($temp$i$i$i$i) + 255|0);
 $130 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $87 = HEAP32[$83>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 36|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 4095]($87)|0);
  $92 = ($91|0)==(0|0);
  if ($92) {
   $121 = $130;
  } else {
   $93 = HEAP8[$91>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $121 = $130;
   } else {
    $$05$i$i$i$i = $91;$99 = $93;
    while(1) {
     $98 = $99&255;
     $100 = (_isspace($98)|0);
     $101 = ($100|0)==(0);
     $96 = (($$05$i$i$i$i) + 1|0);
     if ($101) {
      $$0$lcssa$i$i$ph$i$i = $$05$i$i$i$i;
      break;
     }
     $95 = HEAP8[$96>>0]|0;
     $97 = ($95<<24>>24)==(0);
     if ($97) {
      $$0$lcssa$i$i$ph$i$i = $96;
      break;
     } else {
      $$05$i$i$i$i = $96;$99 = $95;
     }
    }
    _memset(($temp$i$i$i$i|0),0,256)|0;
    HEAP32[$end$i$i$i$i>>2] = $86;
    $102 = HEAP8[$$0$lcssa$i$i$ph$i$i>>0]|0;
    $103 = ($102<<24>>24)==(0);
    L32: do {
     if ($103) {
      $dest$0$lcssa$i$i$i$i = $temp$i$i$i$i;
     } else {
      $$14$i$i$i$i = $$0$lcssa$i$i$ph$i$i;$105 = $102;$dest$03$i$i$i$i = $temp$i$i$i$i;
      while(1) {
       $104 = $105&255;
       $106 = (_isspace($104)|0);
       $107 = ($106|0)==(0);
       if (!($107)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $108 = HEAP32[$end$i$i$i$i>>2]|0;
       $109 = ($dest$03$i$i$i$i>>>0)<($108>>>0);
       if (!($109)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $110 = (($$14$i$i$i$i) + 1|0);
       $111 = HEAP8[$$14$i$i$i$i>>0]|0;
       $112 = (($dest$03$i$i$i$i) + 1|0);
       HEAP8[$dest$03$i$i$i$i>>0] = $111;
       $113 = HEAP8[$110>>0]|0;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        $dest$0$lcssa$i$i$i$i = $112;
        break;
       } else {
        $$14$i$i$i$i = $110;$105 = $113;$dest$03$i$i$i$i = $112;
       }
      }
     }
    } while(0);
    HEAP8[$dest$0$lcssa$i$i$i$i>>0] = 0;
    $115 = (+_strtod($temp$i$i$i$i,$end$i$i$i$i));
    $116 = Math_fround($115);
    $121 = $116;
   }
  }
  $117 = HEAP32[$84>>2]|0;
  $118 = HEAP32[$85>>2]|0;
  $119 = (($118) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  FUNCTION_TABLE_viif[$120 & 63]($117,$index$01,$121);
  $122 = HEAP8[$53>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   label = 27;
   break;
  }
  $124 = (($index$01) + 1)|0;
  $125 = HEAP32[$83>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  if ($129) {
   $130 = $121;$index$01 = $124;
  } else {
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEE27handleExtendedIndexPropertyILj685ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj685ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,0);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj685ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$0$lcssa$i$i$ph$i$i = 0, $$05$i$i$i$i = 0, $$14$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dest$0$lcssa$i$i$i$i = 0;
 var $dest$03$i$i$i$i = 0, $end$i$i$i$i = 0, $index$01 = 0, $temp$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i$i = sp + 8|0;
 $end$i$i$i$i = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$temp$i$i$i$i>>2] = $5;
 $6 = (($2) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($2) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = (($2) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = $10;
  } else {
   HEAP32[$14>>2] = $5;
   $$pre$i$i = HEAP32[$9>>2]|0;
   $17 = $$pre$i$i;
  }
  $16 = (($17) + 1)|0;
  HEAP32[$9>>2] = $16;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($2,$temp$i$i$i$i)|0);
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = ((($24) + ($22<<3)|0) + 4|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = (($this) + 36|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $41 = $20;$43 = $24;$44 = 0;
   } else {
    $32 = (($this) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$25>>2]|0;
    $38 = (FUNCTION_TABLE_iii[$36 & 4095]($33,$37)|0);
    $39 = $38&1;
    HEAP8[$29>>0] = $39;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $41 = $$pre1$i;$43 = $$pre3$i;$44 = $39;
   }
   $40 = (($41) + -1)|0;
   $42 = ((($43) + ($40<<3)|0) + 5|0);
   HEAP8[$42>>0] = $44;
   $45 = HEAP8[$29>>0]|0;
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + -1)|0;
   $50 = (($46) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51) + ($49<<3)|0) + 4|0);
   HEAP8[$52>>0] = $45;
  }
 }
 $53 = (($this) + 36|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,519928);
 $56 = HEAP8[$53>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $72 = 0;
 } else {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  $64 = $63&1;
  HEAP8[$53>>0] = $64;
  $72 = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + -1)|0;
 $69 = (($65) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70) + ($68<<3)|0) + 5|0);
 HEAP8[$71>>0] = $72;
 $73 = HEAP8[$53>>0]|0;
 $74 = HEAP32[$this>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + -1)|0;
 $78 = (($74) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 4|0);
 HEAP8[$80>>0] = $73;
 $81 = HEAP8[$53>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $83 = (($this) + 20|0);
 $84 = (($this) + 24|0);
 $85 = (($inProp) + 12|0);
 $86 = (($temp$i$i$i$i) + 255|0);
 $130 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $87 = HEAP32[$83>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 36|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 4095]($87)|0);
  $92 = ($91|0)==(0|0);
  if ($92) {
   $121 = $130;
  } else {
   $93 = HEAP8[$91>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $121 = $130;
   } else {
    $$05$i$i$i$i = $91;$99 = $93;
    while(1) {
     $98 = $99&255;
     $100 = (_isspace($98)|0);
     $101 = ($100|0)==(0);
     $96 = (($$05$i$i$i$i) + 1|0);
     if ($101) {
      $$0$lcssa$i$i$ph$i$i = $$05$i$i$i$i;
      break;
     }
     $95 = HEAP8[$96>>0]|0;
     $97 = ($95<<24>>24)==(0);
     if ($97) {
      $$0$lcssa$i$i$ph$i$i = $96;
      break;
     } else {
      $$05$i$i$i$i = $96;$99 = $95;
     }
    }
    _memset(($temp$i$i$i$i|0),0,256)|0;
    HEAP32[$end$i$i$i$i>>2] = $86;
    $102 = HEAP8[$$0$lcssa$i$i$ph$i$i>>0]|0;
    $103 = ($102<<24>>24)==(0);
    L32: do {
     if ($103) {
      $dest$0$lcssa$i$i$i$i = $temp$i$i$i$i;
     } else {
      $$14$i$i$i$i = $$0$lcssa$i$i$ph$i$i;$105 = $102;$dest$03$i$i$i$i = $temp$i$i$i$i;
      while(1) {
       $104 = $105&255;
       $106 = (_isspace($104)|0);
       $107 = ($106|0)==(0);
       if (!($107)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $108 = HEAP32[$end$i$i$i$i>>2]|0;
       $109 = ($dest$03$i$i$i$i>>>0)<($108>>>0);
       if (!($109)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $110 = (($$14$i$i$i$i) + 1|0);
       $111 = HEAP8[$$14$i$i$i$i>>0]|0;
       $112 = (($dest$03$i$i$i$i) + 1|0);
       HEAP8[$dest$03$i$i$i$i>>0] = $111;
       $113 = HEAP8[$110>>0]|0;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        $dest$0$lcssa$i$i$i$i = $112;
        break;
       } else {
        $$14$i$i$i$i = $110;$105 = $113;$dest$03$i$i$i$i = $112;
       }
      }
     }
    } while(0);
    HEAP8[$dest$0$lcssa$i$i$i$i>>0] = 0;
    $115 = (+_strtod($temp$i$i$i$i,$end$i$i$i$i));
    $116 = Math_fround($115);
    $121 = $116;
   }
  }
  $117 = HEAP32[$84>>2]|0;
  $118 = HEAP32[$85>>2]|0;
  $119 = (($118) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  FUNCTION_TABLE_viif[$120 & 63]($117,$index$01,$121);
  $122 = HEAP8[$53>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   label = 27;
   break;
  }
  $124 = (($index$01) + 1)|0;
  $125 = HEAP32[$83>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  if ($129) {
   $130 = $121;$index$01 = $124;
  } else {
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEEclILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 12;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 12)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 _memset(($1|0),0,256)|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE15complexPropertyINS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES7_EEKNS_35PxVehicleWheelsSimDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleNoDriveEEEEclILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 76;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 76)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 dest=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE15complexPropertyINS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES7_EEKNS_35PxVehicleWheelsDynDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE15complexPropertyINS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES7_EEKNS_35PxVehicleWheelsDynDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $1 = sp + 80|0;
 $2 = sp;
 $propVal = sp + 48|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inProp) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$2>>2] = $46;
 $55 = (($2) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($2) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($2) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($2) + 24|0);
 HEAP32[$58>>2] = $propVal;
 $59 = (($2) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($2) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($2) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($2) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($2) + 44|0);
 HEAP32[$63>>2] = 0;
 $64 = (($inInfo) + 12|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj623ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,1,$64,$1);
 $65 = (($inInfo) + 36|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj624ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,2,$65,$1);
 $66 = HEAP32[$41>>2]|0;
 $67 = (($inProp) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$propVal+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$propVal+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$propVal+24>>2]|0;HEAP32[$1+28>>2]=HEAP32[$propVal+28>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj624ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj624ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj624ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$0$lcssa$i$i$ph$i$i = 0, $$05$i$i$i$i = 0, $$14$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dest$0$lcssa$i$i$i$i = 0;
 var $dest$03$i$i$i$i = 0, $end$i$i$i$i = 0, $index$01 = 0, $temp$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i$i = sp + 8|0;
 $end$i$i$i$i = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$temp$i$i$i$i>>2] = $5;
 $6 = (($2) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($2) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = (($2) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = $10;
  } else {
   HEAP32[$14>>2] = $5;
   $$pre$i$i = HEAP32[$9>>2]|0;
   $17 = $$pre$i$i;
  }
  $16 = (($17) + 1)|0;
  HEAP32[$9>>2] = $16;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($2,$temp$i$i$i$i)|0);
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = ((($24) + ($22<<3)|0) + 4|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = (($this) + 36|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $41 = $20;$43 = $24;$44 = 0;
   } else {
    $32 = (($this) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$25>>2]|0;
    $38 = (FUNCTION_TABLE_iii[$36 & 4095]($33,$37)|0);
    $39 = $38&1;
    HEAP8[$29>>0] = $39;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $41 = $$pre1$i;$43 = $$pre3$i;$44 = $39;
   }
   $40 = (($41) + -1)|0;
   $42 = ((($43) + ($40<<3)|0) + 5|0);
   HEAP8[$42>>0] = $44;
   $45 = HEAP8[$29>>0]|0;
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + -1)|0;
   $50 = (($46) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51) + ($49<<3)|0) + 4|0);
   HEAP8[$52>>0] = $45;
  }
 }
 $53 = (($this) + 36|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE8pushNameEPKc($this,519928);
 $56 = HEAP8[$53>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $72 = 0;
 } else {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  $64 = $63&1;
  HEAP8[$53>>0] = $64;
  $72 = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + -1)|0;
 $69 = (($65) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70) + ($68<<3)|0) + 5|0);
 HEAP8[$71>>0] = $72;
 $73 = HEAP8[$53>>0]|0;
 $74 = HEAP32[$this>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + -1)|0;
 $78 = (($74) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 4|0);
 HEAP8[$80>>0] = $73;
 $81 = HEAP8[$53>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $83 = (($this) + 20|0);
 $84 = (($this) + 24|0);
 $85 = (($inProp) + 12|0);
 $86 = (($temp$i$i$i$i) + 255|0);
 $130 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $87 = HEAP32[$83>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 36|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 4095]($87)|0);
  $92 = ($91|0)==(0|0);
  if ($92) {
   $121 = $130;
  } else {
   $93 = HEAP8[$91>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $121 = $130;
   } else {
    $$05$i$i$i$i = $91;$99 = $93;
    while(1) {
     $98 = $99&255;
     $100 = (_isspace($98)|0);
     $101 = ($100|0)==(0);
     $96 = (($$05$i$i$i$i) + 1|0);
     if ($101) {
      $$0$lcssa$i$i$ph$i$i = $$05$i$i$i$i;
      break;
     }
     $95 = HEAP8[$96>>0]|0;
     $97 = ($95<<24>>24)==(0);
     if ($97) {
      $$0$lcssa$i$i$ph$i$i = $96;
      break;
     } else {
      $$05$i$i$i$i = $96;$99 = $95;
     }
    }
    _memset(($temp$i$i$i$i|0),0,256)|0;
    HEAP32[$end$i$i$i$i>>2] = $86;
    $102 = HEAP8[$$0$lcssa$i$i$ph$i$i>>0]|0;
    $103 = ($102<<24>>24)==(0);
    L32: do {
     if ($103) {
      $dest$0$lcssa$i$i$i$i = $temp$i$i$i$i;
     } else {
      $$14$i$i$i$i = $$0$lcssa$i$i$ph$i$i;$105 = $102;$dest$03$i$i$i$i = $temp$i$i$i$i;
      while(1) {
       $104 = $105&255;
       $106 = (_isspace($104)|0);
       $107 = ($106|0)==(0);
       if (!($107)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $108 = HEAP32[$end$i$i$i$i>>2]|0;
       $109 = ($dest$03$i$i$i$i>>>0)<($108>>>0);
       if (!($109)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $110 = (($$14$i$i$i$i) + 1|0);
       $111 = HEAP8[$$14$i$i$i$i>>0]|0;
       $112 = (($dest$03$i$i$i$i) + 1|0);
       HEAP8[$dest$03$i$i$i$i>>0] = $111;
       $113 = HEAP8[$110>>0]|0;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        $dest$0$lcssa$i$i$i$i = $112;
        break;
       } else {
        $$14$i$i$i$i = $110;$105 = $113;$dest$03$i$i$i$i = $112;
       }
      }
     }
    } while(0);
    HEAP8[$dest$0$lcssa$i$i$i$i>>0] = 0;
    $115 = (+_strtod($temp$i$i$i$i,$end$i$i$i$i));
    $116 = Math_fround($115);
    $121 = $116;
   }
  }
  $117 = HEAP32[$84>>2]|0;
  $118 = HEAP32[$85>>2]|0;
  $119 = (($118) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  FUNCTION_TABLE_viif[$120 & 63]($117,$index$01,$121);
  $122 = HEAP8[$53>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   label = 27;
   break;
  }
  $124 = (($index$01) + 1)|0;
  $125 = HEAP32[$83>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  if ($129) {
   $130 = $121;$index$01 = $124;
  } else {
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE17popCurrentContextEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + -1)|0;
 $6 = (($1) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12>>>0)>($9>>>0);
 if ($13) {
  $14 = (($this) + 36|0);
  $15 = (($this) + 20|0);
  $17 = $12;$21 = $10;
  while(1) {
   $16 = ($17|0)==(0);
   if ($16) {
    label = 5;
    break;
   }
   $19 = (($17) + -1)|0;
   $20 = (($21) + 4|0);
   $22 = HEAP32[$20>>2]|0;
   $23 = ((($22) + ($19<<3)|0) + 4|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if ($25) {
    $34 = $21;$36 = $17;
   } else {
    $26 = ((($22) + ($19<<3)|0) + 5|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $34 = $21;$36 = $17;
    } else {
     $29 = HEAP32[$15>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($30) + 40|0);
     $32 = HEAP32[$31>>2]|0;
     (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
     $$pre2$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
     $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
     $34 = $$pre2$i;$36 = $$pre4$i;
    }
   }
   $33 = (($34) + 8|0);
   $35 = (($36) + -1)|0;
   HEAP32[$33>>2] = $35;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   HEAP8[$14>>0] = 1;
   $37 = ($$pre1$i|0)==(0);
   if ($37) {
    break;
   }
   $38 = (($$pre1$i) + -1)|0;
   $39 = (($$pre$i) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($40) + ($38<<3)|0) + 5|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    HEAP8[$14>>0] = 0;
   }
   $18 = ($$pre1$i>>>0)>($9>>>0);
   if ($18) {
    $17 = $$pre1$i;$21 = $$pre$i;
   } else {
    break;
   }
  }
  if ((label|0) == 5) {
   HEAP8[$14>>0] = 1;
  }
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
  $45 = $$pre;$47 = $$pre1;
 } else {
  $45 = $1;$47 = $3;
 }
 $44 = (($45) + 8|0);
 $46 = (($47) + -1)|0;
 HEAP32[$44>>2] = $46;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj623ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj623ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,0);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj623ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$0$lcssa$i$i$ph$i$i = 0, $$05$i$i$i$i = 0, $$14$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dest$0$lcssa$i$i$i$i = 0;
 var $dest$03$i$i$i$i = 0, $end$i$i$i$i = 0, $index$01 = 0, $temp$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i$i = sp + 8|0;
 $end$i$i$i$i = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$temp$i$i$i$i>>2] = $5;
 $6 = (($2) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($2) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = (($2) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = $10;
  } else {
   HEAP32[$14>>2] = $5;
   $$pre$i$i = HEAP32[$9>>2]|0;
   $17 = $$pre$i$i;
  }
  $16 = (($17) + 1)|0;
  HEAP32[$9>>2] = $16;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($2,$temp$i$i$i$i)|0);
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = ((($24) + ($22<<3)|0) + 4|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = (($this) + 36|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $41 = $20;$43 = $24;$44 = 0;
   } else {
    $32 = (($this) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$25>>2]|0;
    $38 = (FUNCTION_TABLE_iii[$36 & 4095]($33,$37)|0);
    $39 = $38&1;
    HEAP8[$29>>0] = $39;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $41 = $$pre1$i;$43 = $$pre3$i;$44 = $39;
   }
   $40 = (($41) + -1)|0;
   $42 = ((($43) + ($40<<3)|0) + 5|0);
   HEAP8[$42>>0] = $44;
   $45 = HEAP8[$29>>0]|0;
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + -1)|0;
   $50 = (($46) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51) + ($49<<3)|0) + 4|0);
   HEAP8[$52>>0] = $45;
  }
 }
 $53 = (($this) + 36|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE8pushNameEPKc($this,519928);
 $56 = HEAP8[$53>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $72 = 0;
 } else {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  $64 = $63&1;
  HEAP8[$53>>0] = $64;
  $72 = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + -1)|0;
 $69 = (($65) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70) + ($68<<3)|0) + 5|0);
 HEAP8[$71>>0] = $72;
 $73 = HEAP8[$53>>0]|0;
 $74 = HEAP32[$this>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + -1)|0;
 $78 = (($74) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 4|0);
 HEAP8[$80>>0] = $73;
 $81 = HEAP8[$53>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $83 = (($this) + 20|0);
 $84 = (($this) + 24|0);
 $85 = (($inProp) + 12|0);
 $86 = (($temp$i$i$i$i) + 255|0);
 $130 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $87 = HEAP32[$83>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 36|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 4095]($87)|0);
  $92 = ($91|0)==(0|0);
  if ($92) {
   $121 = $130;
  } else {
   $93 = HEAP8[$91>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $121 = $130;
   } else {
    $$05$i$i$i$i = $91;$99 = $93;
    while(1) {
     $98 = $99&255;
     $100 = (_isspace($98)|0);
     $101 = ($100|0)==(0);
     $96 = (($$05$i$i$i$i) + 1|0);
     if ($101) {
      $$0$lcssa$i$i$ph$i$i = $$05$i$i$i$i;
      break;
     }
     $95 = HEAP8[$96>>0]|0;
     $97 = ($95<<24>>24)==(0);
     if ($97) {
      $$0$lcssa$i$i$ph$i$i = $96;
      break;
     } else {
      $$05$i$i$i$i = $96;$99 = $95;
     }
    }
    _memset(($temp$i$i$i$i|0),0,256)|0;
    HEAP32[$end$i$i$i$i>>2] = $86;
    $102 = HEAP8[$$0$lcssa$i$i$ph$i$i>>0]|0;
    $103 = ($102<<24>>24)==(0);
    L32: do {
     if ($103) {
      $dest$0$lcssa$i$i$i$i = $temp$i$i$i$i;
     } else {
      $$14$i$i$i$i = $$0$lcssa$i$i$ph$i$i;$105 = $102;$dest$03$i$i$i$i = $temp$i$i$i$i;
      while(1) {
       $104 = $105&255;
       $106 = (_isspace($104)|0);
       $107 = ($106|0)==(0);
       if (!($107)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $108 = HEAP32[$end$i$i$i$i>>2]|0;
       $109 = ($dest$03$i$i$i$i>>>0)<($108>>>0);
       if (!($109)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $110 = (($$14$i$i$i$i) + 1|0);
       $111 = HEAP8[$$14$i$i$i$i>>0]|0;
       $112 = (($dest$03$i$i$i$i) + 1|0);
       HEAP8[$dest$03$i$i$i$i>>0] = $111;
       $113 = HEAP8[$110>>0]|0;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        $dest$0$lcssa$i$i$i$i = $112;
        break;
       } else {
        $$14$i$i$i$i = $110;$105 = $113;$dest$03$i$i$i$i = $112;
       }
      }
     }
    } while(0);
    HEAP8[$dest$0$lcssa$i$i$i$i>>0] = 0;
    $115 = (+_strtod($temp$i$i$i$i,$end$i$i$i$i));
    $116 = Math_fround($115);
    $121 = $116;
   }
  }
  $117 = HEAP32[$84>>2]|0;
  $118 = HEAP32[$85>>2]|0;
  $119 = (($118) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  FUNCTION_TABLE_viif[$120 & 63]($117,$index$01,$121);
  $122 = HEAP8[$53>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   label = 27;
   break;
  }
  $124 = (($index$01) + 1)|0;
  $125 = HEAP32[$83>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  if ($129) {
   $130 = $121;$index$01 = $124;
  } else {
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleNoDriveEE15complexPropertyINS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES7_EEKNS_35PxVehicleWheelsSimDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $1 = sp + 64|0;
 $propVal = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($4) + -1)|0;
  $7 = (($2) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($6<<3)|0);
  $10 = ((($8) + ($6<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($this) + 36|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $25 = $4;$27 = $8;$28 = 0;
   } else {
    $16 = (($this) + 20|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$9>>2]|0;
    $22 = (FUNCTION_TABLE_iii[$20 & 4095]($17,$21)|0);
    $23 = $22&1;
    HEAP8[$13>>0] = $23;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $25 = $$pre1$i;$27 = $$pre3$i;$28 = $23;
   }
   $24 = (($25) + -1)|0;
   $26 = ((($27) + ($24<<3)|0) + 5|0);
   HEAP8[$26>>0] = $28;
   $29 = HEAP8[$13>>0]|0;
   $30 = HEAP32[$this>>2]|0;
   $31 = (($30) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + -1)|0;
   $34 = (($30) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35) + ($33<<3)|0) + 4|0);
   HEAP8[$36>>0] = $29;
  }
 }
 $37 = (($this) + 36|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($inProp) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 FUNCTION_TABLE_vii[$43 & 4095]($propVal,$41);
 $44 = (($this) + 8|0);
 $45 = HEAP32[$this>>2]|0;
 $46 = (($this) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($this) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 28|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 32|0);
 $53 = HEAP32[$52>>2]|0;
 HEAP32[$1>>2] = $45;
 $54 = (($1) + 4|0);
 HEAP32[$54>>2] = $47;
 $55 = (($1) + 8|0);
 ;HEAP32[$55+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$44+8>>2]|0;
 $56 = (($1) + 20|0);
 HEAP32[$56>>2] = $49;
 $57 = (($1) + 24|0);
 HEAP32[$57>>2] = $propVal;
 $58 = (($1) + 28|0);
 HEAP32[$58>>2] = $51;
 $59 = (($1) + 32|0);
 HEAP32[$59>>2] = $53;
 $60 = (($1) + 36|0);
 HEAP8[$60>>0] = 1;
 $61 = (($1) + 40|0);
 HEAP32[$61>>2] = 0;
 $62 = (($1) + 44|0);
 HEAP32[$62>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($inInfo,$1,0)|0);
 $63 = HEAP32[$40>>2]|0;
 $64 = (($inProp) + 20|0);
 $65 = HEAP32[$64>>2]|0;
 dest=$1+0|0; src=$propVal+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$65 & 4095]($63,$1);
 STACKTOP = sp;return;
}
function __ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = (($inStartIndex) + 1)|0;
 _memset(($0|0),0,164)|0;
 __ZN5physx36PxVehicleSuspensionDataGeneratedInfoC2Ev($0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj609ES4_NS_23PxVehicleSuspensionDataEKjNS_36PxVehicleSuspensionDataGeneratedInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$2,$1,$0);
 $3 = (($this) + 36|0);
 $4 = (($inStartIndex) + 2)|0;
 _memset(($0|0),0,168)|0;
 __ZN5physx31PxVehicleWheelDataGeneratedInfoC2Ev($0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj610ES4_NS_18PxVehicleWheelDataEKjNS_31PxVehicleWheelDataGeneratedInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$4,$3,$0);
 $5 = (($this) + 60|0);
 $6 = (($inStartIndex) + 3)|0;
 _memset(($0|0),0,140)|0;
 __ZN5physx30PxVehicleTireDataGeneratedInfoC2Ev($0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj611ES4_NS_17PxVehicleTireDataEKjNS_30PxVehicleTireDataGeneratedInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$6,$5,$0);
 $7 = (($this) + 84|0);
 $8 = (($inStartIndex) + 4)|0;
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj612ES4_NS_6PxVec3EKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$8,$7,$0);
 $9 = (($this) + 108|0);
 $10 = (($inStartIndex) + 5)|0;
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj613ES4_NS_6PxVec3EKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$10,$9,$0);
 $11 = (($this) + 132|0);
 $12 = (($inStartIndex) + 6)|0;
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj614ES4_NS_6PxVec3EKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$12,$11,$0);
 $13 = (($this) + 156|0);
 $14 = (($inStartIndex) + 7)|0;
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj615ES4_NS_6PxVec3EKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$14,$13,$0);
 $15 = (($this) + 180|0);
 $16 = (($inStartIndex) + 8)|0;
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj616ES4_iKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$16,$15,$0);
 $17 = (($this) + 204|0);
 $18 = (($inStartIndex) + 9)|0;
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj617ES4_NS_12PxFilterDataEKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$18,$17,$0);
 $19 = (($this) + 228|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEEclILj618ES3_RKNS_27PxVehicleTireLoadFilterDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$19,0);
 $20 = (($inStartIndex) + 12)|0;
 STACKTOP = sp;return ($20|0);
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEEclILj618ES3_RKNS_27PxVehicleTireLoadFilterDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 0;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $$0$i$i = $7;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $retval$0$i$i = 618;
 } else {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
  $retval$0$i$i = $11;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE14handleAccessorILj618ENS_22PxRepXPropertyAccessorILj618ES4_RKNS_27PxVehicleTireLoadFilterDataES9_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE14handleAccessorILj618ENS_22PxRepXPropertyAccessorILj618ES4_RKNS_27PxVehicleTireLoadFilterDataES9_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $0 = sp + 144|0;
 $1 = sp;
 $propVal$i$i = sp + 32|0;
 $2 = sp + 64|0;
 dest=$2+0|0; stop=dest+76|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx40PxVehicleTireLoadFilterDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 $64 = (($2) + 12|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleTireLoadFilterDataEEEEclILj561ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 28|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleTireLoadFilterDataEEEEclILj562ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = (($2) + 44|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleTireLoadFilterDataEEEEclILj563ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$66,0);
 $67 = (($2) + 60|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleTireLoadFilterDataEEEEclILj564ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$67,0);
 $68 = HEAP32[$41>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal$i$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal$i$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal$i$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal$i$i+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$propVal$i$i+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$propVal$i$i+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$propVal$i$i+24>>2]|0;HEAP32[$1+28>>2]=HEAP32[$propVal$i$i+28>>2]|0;
 $69 = (($inAccessor) + 20|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_vii[$70 & 4095]($68,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleTireLoadFilterDataEEEEclILj561ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleTireLoadFilterDataEEEEclILj562ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleTireLoadFilterDataEEEEclILj563ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleTireLoadFilterDataEEEEclILj564ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleTireLoadFilterDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj617ES4_NS_12PxFilterDataEKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj617ES2_KjNS_12PxFilterDataEEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj617ES2_KjNS_12PxFilterDataEEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$byval_copy = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$02 = 0, $theValue$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 24|0;
 $1 = sp;
 $theValue$i$i = sp + 16|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$$byval_copy>>2] = $6;
 $7 = (($3) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = (($3) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $18 = $11;
  } else {
   HEAP32[$15>>2] = $6;
   $$pre$i$i = HEAP32[$10>>2]|0;
   $18 = $$pre$i$i;
  }
  $17 = (($18) + 1)|0;
  HEAP32[$10>>2] = $17;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($3,$$byval_copy)|0);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = ((($25) + ($23<<3)|0) + 4|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $30 = (($this) + 36|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $42 = $21;$44 = $25;$45 = 0;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$26>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$37 & 4095]($34,$38)|0);
    $40 = $39&1;
    HEAP8[$30>>0] = $40;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $42 = $$pre1$i;$44 = $$pre3$i;$45 = $40;
   }
   $41 = (($42) + -1)|0;
   $43 = ((($44) + ($41<<3)|0) + 5|0);
   HEAP8[$43>>0] = $45;
   $46 = HEAP8[$30>>0]|0;
   $47 = HEAP32[$this>>2]|0;
   $48 = (($47) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = (($47) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52) + ($50<<3)|0) + 4|0);
   HEAP8[$53>>0] = $46;
  }
 }
 $54 = (($this) + 36|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $57 = HEAP8[$54>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $73 = 0;
 } else {
  $59 = (($this) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = $64&1;
  HEAP8[$54>>0] = $65;
  $73 = $65;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 $70 = (($66) + 4|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71) + ($69<<3)|0) + 5|0);
 HEAP8[$72>>0] = $73;
 $74 = HEAP8[$54>>0]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + -1)|0;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<3)|0) + 4|0);
 HEAP8[$81>>0] = $74;
 $82 = HEAP8[$54>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $84 = (($this) + 20|0);
 $85 = (($this) + 24|0);
 $86 = (($1) + 4|0);
 $87 = (($1) + 8|0);
 $88 = (($1) + 12|0);
 $89 = (($inProp) + 12|0);
 $index$02 = 0;
 while(1) {
  $90 = HEAP32[$84>>2]|0;
  $91 = HEAP32[$90>>2]|0;
  $92 = (($91) + 36|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (FUNCTION_TABLE_ii[$93 & 4095]($90)|0);
  $95 = ($94|0)==(0|0);
  if ($95) {
   $106 = 0;$107 = 0;$108 = 0;$109 = 0;
  } else {
   $96 = HEAP8[$94>>0]|0;
   $97 = ($96<<24>>24)==(0);
   if ($97) {
    $106 = 0;$107 = 0;$108 = 0;$109 = 0;
   } else {
    HEAP32[$theValue$i$i>>2] = $94;
    $98 = (_strtoul($94,$theValue$i$i,10)|0);
    $99 = HEAP32[$theValue$i$i>>2]|0;
    $100 = (_strtoul($99,$theValue$i$i,10)|0);
    $101 = HEAP32[$theValue$i$i>>2]|0;
    $102 = (_strtoul($101,$theValue$i$i,10)|0);
    $103 = HEAP32[$theValue$i$i>>2]|0;
    $104 = (_strtoul($103,0,10)|0);
    $106 = $98;$107 = $100;$108 = $102;$109 = $104;
   }
  }
  $105 = HEAP32[$85>>2]|0;
  HEAP32[$1>>2] = $106;
  HEAP32[$86>>2] = $107;
  HEAP32[$87>>2] = $108;
  HEAP32[$88>>2] = $109;
  $110 = HEAP32[$89>>2]|0;
  $111 = (($110) + 8|0);
  $112 = HEAP32[$111>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
  FUNCTION_TABLE_viii[$112 & 4095]($105,$index$02,$$byval_copy);
  $113 = HEAP8[$54>>0]|0;
  $114 = ($113<<24>>24)==(0);
  if ($114) {
   label = 21;
   break;
  }
  $115 = (($index$02) + 1)|0;
  $116 = HEAP32[$84>>2]|0;
  $117 = HEAP32[$116>>2]|0;
  $118 = (($117) + 24|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = (FUNCTION_TABLE_ii[$119 & 4095]($116)|0);
  if ($120) {
   $index$02 = $115;
  } else {
   label = 21;
   break;
  }
 }
 if ((label|0) == 21) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + -1)|0;
 $6 = (($1) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12>>>0)>($9>>>0);
 if ($13) {
  $14 = (($this) + 36|0);
  $15 = (($this) + 20|0);
  $17 = $12;$21 = $10;
  while(1) {
   $16 = ($17|0)==(0);
   if ($16) {
    label = 5;
    break;
   }
   $19 = (($17) + -1)|0;
   $20 = (($21) + 4|0);
   $22 = HEAP32[$20>>2]|0;
   $23 = ((($22) + ($19<<3)|0) + 4|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if ($25) {
    $34 = $21;$36 = $17;
   } else {
    $26 = ((($22) + ($19<<3)|0) + 5|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $34 = $21;$36 = $17;
    } else {
     $29 = HEAP32[$15>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($30) + 40|0);
     $32 = HEAP32[$31>>2]|0;
     (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
     $$pre2$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
     $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
     $34 = $$pre2$i;$36 = $$pre4$i;
    }
   }
   $33 = (($34) + 8|0);
   $35 = (($36) + -1)|0;
   HEAP32[$33>>2] = $35;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   HEAP8[$14>>0] = 1;
   $37 = ($$pre1$i|0)==(0);
   if ($37) {
    break;
   }
   $38 = (($$pre1$i) + -1)|0;
   $39 = (($$pre$i) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($40) + ($38<<3)|0) + 5|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    HEAP8[$14>>0] = 0;
   }
   $18 = ($$pre1$i>>>0)>($9>>>0);
   if ($18) {
    $17 = $$pre1$i;$21 = $$pre$i;
   } else {
    break;
   }
  }
  if ((label|0) == 5) {
   HEAP8[$14>>0] = 1;
  }
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
  $45 = $$pre;$47 = $$pre1;
 } else {
  $45 = $1;$47 = $3;
 }
 $44 = (($45) + 8|0);
 $46 = (($47) + -1)|0;
 HEAP32[$44>>2] = $46;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj616ES4_iKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj616ES2_KjiEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj616ES2_KjiEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$01 = 0, $theValue$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$theValue$i$i>>2] = $5;
 $6 = (($2) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($2) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = (($2) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = $10;
  } else {
   HEAP32[$14>>2] = $5;
   $$pre$i$i = HEAP32[$9>>2]|0;
   $17 = $$pre$i$i;
  }
  $16 = (($17) + 1)|0;
  HEAP32[$9>>2] = $16;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($2,$theValue$i$i)|0);
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = ((($24) + ($22<<3)|0) + 4|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = (($this) + 36|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $41 = $20;$43 = $24;$44 = 0;
   } else {
    $32 = (($this) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$25>>2]|0;
    $38 = (FUNCTION_TABLE_iii[$36 & 4095]($33,$37)|0);
    $39 = $38&1;
    HEAP8[$29>>0] = $39;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $41 = $$pre1$i;$43 = $$pre3$i;$44 = $39;
   }
   $40 = (($41) + -1)|0;
   $42 = ((($43) + ($40<<3)|0) + 5|0);
   HEAP8[$42>>0] = $44;
   $45 = HEAP8[$29>>0]|0;
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + -1)|0;
   $50 = (($46) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51) + ($49<<3)|0) + 4|0);
   HEAP8[$52>>0] = $45;
  }
 }
 $53 = (($this) + 36|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $56 = HEAP8[$53>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $72 = 0;
 } else {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  $64 = $63&1;
  HEAP8[$53>>0] = $64;
  $72 = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + -1)|0;
 $69 = (($65) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70) + ($68<<3)|0) + 5|0);
 HEAP8[$71>>0] = $72;
 $73 = HEAP8[$53>>0]|0;
 $74 = HEAP32[$this>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + -1)|0;
 $78 = (($74) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 4|0);
 HEAP8[$80>>0] = $73;
 $81 = HEAP8[$53>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $83 = (($this) + 20|0);
 $84 = (($this) + 24|0);
 $85 = (($inProp) + 12|0);
 $108 = 0;$index$01 = 0;
 while(1) {
  $86 = HEAP32[$83>>2]|0;
  $87 = HEAP32[$86>>2]|0;
  $88 = (($87) + 36|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (FUNCTION_TABLE_ii[$89 & 4095]($86)|0);
  $91 = ($90|0)==(0|0);
  if ($91) {
   $99 = $108;
  } else {
   $92 = HEAP8[$90>>0]|0;
   $93 = ($92<<24>>24)==(0);
   if ($93) {
    $99 = $108;
   } else {
    HEAP32[$theValue$i$i>>2] = $90;
    $94 = (_strtoul($90,$theValue$i$i,10)|0);
    $99 = $94;
   }
  }
  $95 = HEAP32[$84>>2]|0;
  $96 = HEAP32[$85>>2]|0;
  $97 = (($96) + 8|0);
  $98 = HEAP32[$97>>2]|0;
  FUNCTION_TABLE_viii[$98 & 4095]($95,$index$01,$99);
  $100 = HEAP8[$53>>0]|0;
  $101 = ($100<<24>>24)==(0);
  if ($101) {
   label = 21;
   break;
  }
  $102 = (($index$01) + 1)|0;
  $103 = HEAP32[$83>>2]|0;
  $104 = HEAP32[$103>>2]|0;
  $105 = (($104) + 24|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (FUNCTION_TABLE_ii[$106 & 4095]($103)|0);
  if ($107) {
   $108 = $99;$index$01 = $102;
  } else {
   label = 21;
   break;
  }
 }
 if ((label|0) == 21) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj615ES4_NS_6PxVec3EKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj615ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj615ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = Math_fround(0), $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre2 = Math_fround(0), $$pre3 = Math_fround(0), $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$01 = 0, $propVal = 0, $theValue$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $1 = sp + 16|0;
 $theValue$i$i = sp;
 $propVal = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 $7 = (($3) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = (($3) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $18 = $11;
  } else {
   HEAP32[$15>>2] = $6;
   $$pre$i$i = HEAP32[$10>>2]|0;
   $18 = $$pre$i$i;
  }
  $17 = (($18) + 1)|0;
  HEAP32[$10>>2] = $17;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($3,$1)|0);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = ((($25) + ($23<<3)|0) + 4|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $30 = (($this) + 36|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $42 = $21;$44 = $25;$45 = 0;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$26>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$37 & 4095]($34,$38)|0);
    $40 = $39&1;
    HEAP8[$30>>0] = $40;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $42 = $$pre1$i;$44 = $$pre3$i;$45 = $40;
   }
   $41 = (($42) + -1)|0;
   $43 = ((($44) + ($41<<3)|0) + 5|0);
   HEAP8[$43>>0] = $45;
   $46 = HEAP8[$30>>0]|0;
   $47 = HEAP32[$this>>2]|0;
   $48 = (($47) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = (($47) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52) + ($50<<3)|0) + 4|0);
   HEAP8[$53>>0] = $46;
  }
 }
 $54 = (($this) + 36|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $57 = HEAP8[$54>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $73 = 0;
 } else {
  $59 = (($this) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = $64&1;
  HEAP8[$54>>0] = $65;
  $73 = $65;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 $70 = (($66) + 4|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71) + ($69<<3)|0) + 5|0);
 HEAP8[$72>>0] = $73;
 $74 = HEAP8[$54>>0]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + -1)|0;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<3)|0) + 4|0);
 HEAP8[$81>>0] = $74;
 $82 = HEAP8[$54>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $84 = (($this) + 20|0);
 $85 = (($this) + 24|0);
 $86 = (($propVal) + 4|0);
 $87 = (($propVal) + 8|0);
 $88 = (($inProp) + 12|0);
 $89 = (($1) + 4|0);
 $90 = (($1) + 8|0);
 $116 = Math_fround(0.0);$117 = Math_fround(0.0);$118 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $91 = HEAP32[$84>>2]|0;
  $92 = HEAP32[$91>>2]|0;
  $93 = (($92) + 36|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (FUNCTION_TABLE_ii[$94 & 4095]($91)|0);
  $96 = ($95|0)==(0|0);
  if ($96) {
   $105 = $118;$106 = $117;$107 = $116;
  } else {
   $97 = HEAP8[$95>>0]|0;
   $98 = ($97<<24>>24)==(0);
   if ($98) {
    $105 = $118;$106 = $117;$107 = $116;
   } else {
    HEAP32[$theValue$i$i>>2] = $95;
    $99 = HEAP8[$95>>0]|0;
    $100 = ($99<<24>>24)==(0);
    if ($100) {
     $105 = $118;$106 = $117;$107 = $116;
    } else {
     __ZN5physx2Sn9StrToImplINS_6PxVec3EE5strtoERS2_RPKc(0,$propVal,$theValue$i$i);
     $$pre = Math_fround(HEAPF32[$propVal>>2]);
     $$pre2 = Math_fround(HEAPF32[$86>>2]);
     $$pre3 = Math_fround(HEAPF32[$87>>2]);
     $105 = $$pre;$106 = $$pre2;$107 = $$pre3;
    }
   }
  }
  $101 = HEAP32[$85>>2]|0;
  $102 = HEAP32[$88>>2]|0;
  $103 = (($102) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  HEAPF32[$1>>2] = $105;
  HEAPF32[$89>>2] = $106;
  HEAPF32[$90>>2] = $107;
  FUNCTION_TABLE_viii[$104 & 4095]($101,$index$01,$1);
  $108 = HEAP8[$54>>0]|0;
  $109 = ($108<<24>>24)==(0);
  if ($109) {
   label = 22;
   break;
  }
  $110 = (($index$01) + 1)|0;
  $111 = HEAP32[$84>>2]|0;
  $112 = HEAP32[$111>>2]|0;
  $113 = (($112) + 24|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (FUNCTION_TABLE_ii[$114 & 4095]($111)|0);
  if ($115) {
   $116 = $107;$117 = $106;$118 = $105;$index$01 = $110;
  } else {
   label = 22;
   break;
  }
 }
 if ((label|0) == 22) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj614ES4_NS_6PxVec3EKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj614ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,0);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj614ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = Math_fround(0), $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre2 = Math_fround(0), $$pre3 = Math_fround(0), $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$01 = 0, $propVal = 0, $theValue$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $1 = sp + 16|0;
 $theValue$i$i = sp;
 $propVal = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 $7 = (($3) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = (($3) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $18 = $11;
  } else {
   HEAP32[$15>>2] = $6;
   $$pre$i$i = HEAP32[$10>>2]|0;
   $18 = $$pre$i$i;
  }
  $17 = (($18) + 1)|0;
  HEAP32[$10>>2] = $17;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($3,$1)|0);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = ((($25) + ($23<<3)|0) + 4|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $30 = (($this) + 36|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $42 = $21;$44 = $25;$45 = 0;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$26>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$37 & 4095]($34,$38)|0);
    $40 = $39&1;
    HEAP8[$30>>0] = $40;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $42 = $$pre1$i;$44 = $$pre3$i;$45 = $40;
   }
   $41 = (($42) + -1)|0;
   $43 = ((($44) + ($41<<3)|0) + 5|0);
   HEAP8[$43>>0] = $45;
   $46 = HEAP8[$30>>0]|0;
   $47 = HEAP32[$this>>2]|0;
   $48 = (($47) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = (($47) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52) + ($50<<3)|0) + 4|0);
   HEAP8[$53>>0] = $46;
  }
 }
 $54 = (($this) + 36|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $57 = HEAP8[$54>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $73 = 0;
 } else {
  $59 = (($this) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = $64&1;
  HEAP8[$54>>0] = $65;
  $73 = $65;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 $70 = (($66) + 4|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71) + ($69<<3)|0) + 5|0);
 HEAP8[$72>>0] = $73;
 $74 = HEAP8[$54>>0]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + -1)|0;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<3)|0) + 4|0);
 HEAP8[$81>>0] = $74;
 $82 = HEAP8[$54>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $84 = (($this) + 20|0);
 $85 = (($this) + 24|0);
 $86 = (($propVal) + 4|0);
 $87 = (($propVal) + 8|0);
 $88 = (($inProp) + 12|0);
 $89 = (($1) + 4|0);
 $90 = (($1) + 8|0);
 $116 = Math_fround(0.0);$117 = Math_fround(0.0);$118 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $91 = HEAP32[$84>>2]|0;
  $92 = HEAP32[$91>>2]|0;
  $93 = (($92) + 36|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (FUNCTION_TABLE_ii[$94 & 4095]($91)|0);
  $96 = ($95|0)==(0|0);
  if ($96) {
   $105 = $118;$106 = $117;$107 = $116;
  } else {
   $97 = HEAP8[$95>>0]|0;
   $98 = ($97<<24>>24)==(0);
   if ($98) {
    $105 = $118;$106 = $117;$107 = $116;
   } else {
    HEAP32[$theValue$i$i>>2] = $95;
    $99 = HEAP8[$95>>0]|0;
    $100 = ($99<<24>>24)==(0);
    if ($100) {
     $105 = $118;$106 = $117;$107 = $116;
    } else {
     __ZN5physx2Sn9StrToImplINS_6PxVec3EE5strtoERS2_RPKc(0,$propVal,$theValue$i$i);
     $$pre = Math_fround(HEAPF32[$propVal>>2]);
     $$pre2 = Math_fround(HEAPF32[$86>>2]);
     $$pre3 = Math_fround(HEAPF32[$87>>2]);
     $105 = $$pre;$106 = $$pre2;$107 = $$pre3;
    }
   }
  }
  $101 = HEAP32[$85>>2]|0;
  $102 = HEAP32[$88>>2]|0;
  $103 = (($102) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  HEAPF32[$1>>2] = $105;
  HEAPF32[$89>>2] = $106;
  HEAPF32[$90>>2] = $107;
  FUNCTION_TABLE_viii[$104 & 4095]($101,$index$01,$1);
  $108 = HEAP8[$54>>0]|0;
  $109 = ($108<<24>>24)==(0);
  if ($109) {
   label = 22;
   break;
  }
  $110 = (($index$01) + 1)|0;
  $111 = HEAP32[$84>>2]|0;
  $112 = HEAP32[$111>>2]|0;
  $113 = (($112) + 24|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (FUNCTION_TABLE_ii[$114 & 4095]($111)|0);
  if ($115) {
   $116 = $107;$117 = $106;$118 = $105;$index$01 = $110;
  } else {
   label = 22;
   break;
  }
 }
 if ((label|0) == 22) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj613ES4_NS_6PxVec3EKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj613ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,0);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj613ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = Math_fround(0), $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre2 = Math_fround(0), $$pre3 = Math_fround(0), $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$01 = 0, $propVal = 0, $theValue$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $1 = sp + 16|0;
 $theValue$i$i = sp;
 $propVal = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 $7 = (($3) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = (($3) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $18 = $11;
  } else {
   HEAP32[$15>>2] = $6;
   $$pre$i$i = HEAP32[$10>>2]|0;
   $18 = $$pre$i$i;
  }
  $17 = (($18) + 1)|0;
  HEAP32[$10>>2] = $17;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($3,$1)|0);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = ((($25) + ($23<<3)|0) + 4|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $30 = (($this) + 36|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $42 = $21;$44 = $25;$45 = 0;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$26>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$37 & 4095]($34,$38)|0);
    $40 = $39&1;
    HEAP8[$30>>0] = $40;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $42 = $$pre1$i;$44 = $$pre3$i;$45 = $40;
   }
   $41 = (($42) + -1)|0;
   $43 = ((($44) + ($41<<3)|0) + 5|0);
   HEAP8[$43>>0] = $45;
   $46 = HEAP8[$30>>0]|0;
   $47 = HEAP32[$this>>2]|0;
   $48 = (($47) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = (($47) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52) + ($50<<3)|0) + 4|0);
   HEAP8[$53>>0] = $46;
  }
 }
 $54 = (($this) + 36|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $57 = HEAP8[$54>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $73 = 0;
 } else {
  $59 = (($this) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = $64&1;
  HEAP8[$54>>0] = $65;
  $73 = $65;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 $70 = (($66) + 4|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71) + ($69<<3)|0) + 5|0);
 HEAP8[$72>>0] = $73;
 $74 = HEAP8[$54>>0]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + -1)|0;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<3)|0) + 4|0);
 HEAP8[$81>>0] = $74;
 $82 = HEAP8[$54>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $84 = (($this) + 20|0);
 $85 = (($this) + 24|0);
 $86 = (($propVal) + 4|0);
 $87 = (($propVal) + 8|0);
 $88 = (($inProp) + 12|0);
 $89 = (($1) + 4|0);
 $90 = (($1) + 8|0);
 $116 = Math_fround(0.0);$117 = Math_fround(0.0);$118 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $91 = HEAP32[$84>>2]|0;
  $92 = HEAP32[$91>>2]|0;
  $93 = (($92) + 36|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (FUNCTION_TABLE_ii[$94 & 4095]($91)|0);
  $96 = ($95|0)==(0|0);
  if ($96) {
   $105 = $118;$106 = $117;$107 = $116;
  } else {
   $97 = HEAP8[$95>>0]|0;
   $98 = ($97<<24>>24)==(0);
   if ($98) {
    $105 = $118;$106 = $117;$107 = $116;
   } else {
    HEAP32[$theValue$i$i>>2] = $95;
    $99 = HEAP8[$95>>0]|0;
    $100 = ($99<<24>>24)==(0);
    if ($100) {
     $105 = $118;$106 = $117;$107 = $116;
    } else {
     __ZN5physx2Sn9StrToImplINS_6PxVec3EE5strtoERS2_RPKc(0,$propVal,$theValue$i$i);
     $$pre = Math_fround(HEAPF32[$propVal>>2]);
     $$pre2 = Math_fround(HEAPF32[$86>>2]);
     $$pre3 = Math_fround(HEAPF32[$87>>2]);
     $105 = $$pre;$106 = $$pre2;$107 = $$pre3;
    }
   }
  }
  $101 = HEAP32[$85>>2]|0;
  $102 = HEAP32[$88>>2]|0;
  $103 = (($102) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  HEAPF32[$1>>2] = $105;
  HEAPF32[$89>>2] = $106;
  HEAPF32[$90>>2] = $107;
  FUNCTION_TABLE_viii[$104 & 4095]($101,$index$01,$1);
  $108 = HEAP8[$54>>0]|0;
  $109 = ($108<<24>>24)==(0);
  if ($109) {
   label = 22;
   break;
  }
  $110 = (($index$01) + 1)|0;
  $111 = HEAP32[$84>>2]|0;
  $112 = HEAP32[$111>>2]|0;
  $113 = (($112) + 24|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (FUNCTION_TABLE_ii[$114 & 4095]($111)|0);
  if ($115) {
   $116 = $107;$117 = $106;$118 = $105;$index$01 = $110;
  } else {
   label = 22;
   break;
  }
 }
 if ((label|0) == 22) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj612ES4_NS_6PxVec3EKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj612ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,0);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj612ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = Math_fround(0), $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre2 = Math_fround(0), $$pre3 = Math_fround(0), $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$01 = 0, $propVal = 0, $theValue$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $1 = sp + 16|0;
 $theValue$i$i = sp;
 $propVal = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 $7 = (($3) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = (($3) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $18 = $11;
  } else {
   HEAP32[$15>>2] = $6;
   $$pre$i$i = HEAP32[$10>>2]|0;
   $18 = $$pre$i$i;
  }
  $17 = (($18) + 1)|0;
  HEAP32[$10>>2] = $17;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($3,$1)|0);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = ((($25) + ($23<<3)|0) + 4|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $30 = (($this) + 36|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $42 = $21;$44 = $25;$45 = 0;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$26>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$37 & 4095]($34,$38)|0);
    $40 = $39&1;
    HEAP8[$30>>0] = $40;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $42 = $$pre1$i;$44 = $$pre3$i;$45 = $40;
   }
   $41 = (($42) + -1)|0;
   $43 = ((($44) + ($41<<3)|0) + 5|0);
   HEAP8[$43>>0] = $45;
   $46 = HEAP8[$30>>0]|0;
   $47 = HEAP32[$this>>2]|0;
   $48 = (($47) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = (($47) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52) + ($50<<3)|0) + 4|0);
   HEAP8[$53>>0] = $46;
  }
 }
 $54 = (($this) + 36|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $57 = HEAP8[$54>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $73 = 0;
 } else {
  $59 = (($this) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = $64&1;
  HEAP8[$54>>0] = $65;
  $73 = $65;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 $70 = (($66) + 4|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71) + ($69<<3)|0) + 5|0);
 HEAP8[$72>>0] = $73;
 $74 = HEAP8[$54>>0]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + -1)|0;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<3)|0) + 4|0);
 HEAP8[$81>>0] = $74;
 $82 = HEAP8[$54>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $84 = (($this) + 20|0);
 $85 = (($this) + 24|0);
 $86 = (($propVal) + 4|0);
 $87 = (($propVal) + 8|0);
 $88 = (($inProp) + 12|0);
 $89 = (($1) + 4|0);
 $90 = (($1) + 8|0);
 $116 = Math_fround(0.0);$117 = Math_fround(0.0);$118 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $91 = HEAP32[$84>>2]|0;
  $92 = HEAP32[$91>>2]|0;
  $93 = (($92) + 36|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (FUNCTION_TABLE_ii[$94 & 4095]($91)|0);
  $96 = ($95|0)==(0|0);
  if ($96) {
   $105 = $118;$106 = $117;$107 = $116;
  } else {
   $97 = HEAP8[$95>>0]|0;
   $98 = ($97<<24>>24)==(0);
   if ($98) {
    $105 = $118;$106 = $117;$107 = $116;
   } else {
    HEAP32[$theValue$i$i>>2] = $95;
    $99 = HEAP8[$95>>0]|0;
    $100 = ($99<<24>>24)==(0);
    if ($100) {
     $105 = $118;$106 = $117;$107 = $116;
    } else {
     __ZN5physx2Sn9StrToImplINS_6PxVec3EE5strtoERS2_RPKc(0,$propVal,$theValue$i$i);
     $$pre = Math_fround(HEAPF32[$propVal>>2]);
     $$pre2 = Math_fround(HEAPF32[$86>>2]);
     $$pre3 = Math_fround(HEAPF32[$87>>2]);
     $105 = $$pre;$106 = $$pre2;$107 = $$pre3;
    }
   }
  }
  $101 = HEAP32[$85>>2]|0;
  $102 = HEAP32[$88>>2]|0;
  $103 = (($102) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  HEAPF32[$1>>2] = $105;
  HEAPF32[$89>>2] = $106;
  HEAPF32[$90>>2] = $107;
  FUNCTION_TABLE_viii[$104 & 4095]($101,$index$01,$1);
  $108 = HEAP8[$54>>0]|0;
  $109 = ($108<<24>>24)==(0);
  if ($109) {
   label = 22;
   break;
  }
  $110 = (($index$01) + 1)|0;
  $111 = HEAP32[$84>>2]|0;
  $112 = HEAP32[$111>>2]|0;
  $113 = (($112) + 24|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (FUNCTION_TABLE_ii[$114 & 4095]($111)|0);
  if ($115) {
   $116 = $107;$117 = $106;$118 = $105;$index$01 = $110;
  } else {
   label = 22;
   break;
  }
 }
 if ((label|0) == 22) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj611ES4_NS_17PxVehicleTireDataEKjNS_30PxVehicleTireDataGeneratedInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj611ES2_KjNS_17PxVehicleTireDataEEEKNS_30PxVehicleTireDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj611ES2_KjNS_17PxVehicleTireDataEEEKNS_30PxVehicleTireDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$byval_copy = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$02 = 0, $propVal = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy = sp + 128|0;
 $1 = sp;
 $propVal = sp + 64|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$$byval_copy>>2] = $6;
 $7 = (($3) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = (($3) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $18 = $11;
  } else {
   HEAP32[$15>>2] = $6;
   $$pre$i$i = HEAP32[$10>>2]|0;
   $18 = $$pre$i$i;
  }
  $17 = (($18) + 1)|0;
  HEAP32[$10>>2] = $17;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($3,$$byval_copy)|0);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = ((($25) + ($23<<3)|0) + 4|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $30 = (($this) + 36|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $42 = $21;$44 = $25;$45 = 0;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$26>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$37 & 4095]($34,$38)|0);
    $40 = $39&1;
    HEAP8[$30>>0] = $40;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $42 = $$pre1$i;$44 = $$pre3$i;$45 = $40;
   }
   $41 = (($42) + -1)|0;
   $43 = ((($44) + ($41<<3)|0) + 5|0);
   HEAP8[$43>>0] = $45;
   $46 = HEAP8[$30>>0]|0;
   $47 = HEAP32[$this>>2]|0;
   $48 = (($47) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = (($47) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52) + ($50<<3)|0) + 4|0);
   HEAP8[$53>>0] = $46;
  }
 }
 $54 = (($this) + 36|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $57 = HEAP8[$54>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $73 = 0;
 } else {
  $59 = (($this) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = $64&1;
  HEAP8[$54>>0] = $65;
  $73 = $65;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 $70 = (($66) + 4|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71) + ($69<<3)|0) + 5|0);
 HEAP8[$72>>0] = $73;
 $74 = HEAP8[$54>>0]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + -1)|0;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<3)|0) + 4|0);
 HEAP8[$81>>0] = $74;
 $82 = HEAP8[$54>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $84 = (($propVal) + 4|0);
 $85 = (($propVal) + 8|0);
 $86 = (($propVal) + 12|0);
 $87 = (($propVal) + 40|0);
 $88 = (($propVal) + 16|0);
 $89 = (($propVal) + 20|0);
 $90 = (($propVal) + 24|0);
 $91 = (($propVal) + 28|0);
 $92 = (($propVal) + 32|0);
 $93 = (($propVal) + 36|0);
 $94 = (($propVal) + 44|0);
 $95 = (($propVal) + 48|0);
 $96 = (($propVal) + 52|0);
 $97 = (($this) + 8|0);
 $98 = (($this) + 20|0);
 $99 = (($this) + 28|0);
 $100 = (($this) + 32|0);
 $101 = (($$byval_copy) + 4|0);
 $102 = (($$byval_copy) + 8|0);
 $103 = (($$byval_copy) + 20|0);
 $104 = (($$byval_copy) + 24|0);
 $105 = (($$byval_copy) + 28|0);
 $106 = (($$byval_copy) + 32|0);
 $107 = (($$byval_copy) + 36|0);
 $108 = (($$byval_copy) + 40|0);
 $109 = (($$byval_copy) + 44|0);
 $110 = (($inInfo) + 36|0);
 $111 = (($inInfo) + 52|0);
 $112 = (($inInfo) + 68|0);
 $113 = (($inInfo) + 84|0);
 $114 = (($inInfo) + 100|0);
 $115 = (($inInfo) + 116|0);
 $116 = (($inInfo) + 132|0);
 $117 = (($inInfo) + 136|0);
 $118 = (($this) + 24|0);
 $119 = (($inProp) + 12|0);
 $index$02 = 0;
 while(1) {
  HEAPF32[$propVal>>2] = Math_fround(2.0);
  HEAPF32[$84>>2] = Math_fround(17.90493011474609375);
  HEAPF32[$85>>2] = Math_fround(1000.0);
  HEAPF32[$86>>2] = Math_fround(5.72957754135131835938);
  HEAP32[$87>>2] = 0;
  HEAPF32[$88>>2] = Math_fround(0.0);
  HEAPF32[$89>>2] = Math_fround(1.0);
  HEAPF32[$90>>2] = Math_fround(0.100000001490116119385);
  HEAPF32[$91>>2] = Math_fround(1.0);
  HEAPF32[$92>>2] = Math_fround(1.0);
  HEAPF32[$93>>2] = Math_fround(1.0);
  HEAPF32[$94>>2] = Math_fround(0.00100000004749745130539);
  HEAPF32[$95>>2] = Math_fround(10.0);
  HEAPF32[$96>>2] = Math_fround(1.11111116409301757813);
  $120 = HEAP32[$this>>2]|0;
  $121 = HEAP32[$2>>2]|0;
  $122 = HEAP32[$98>>2]|0;
  $123 = HEAP32[$99>>2]|0;
  $124 = HEAP32[$100>>2]|0;
  HEAP32[$$byval_copy>>2] = $120;
  HEAP32[$101>>2] = $121;
  ;HEAP32[$102+0>>2]=HEAP32[$97+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$97+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$97+8>>2]|0;
  HEAP32[$103>>2] = $122;
  HEAP32[$104>>2] = $propVal;
  HEAP32[$105>>2] = $123;
  HEAP32[$106>>2] = $124;
  HEAP8[$107>>0] = 1;
  HEAP32[$108>>2] = 0;
  HEAP32[$109>>2] = 0;
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj596ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$110,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj597ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$111,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj598ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$112,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj599ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$113,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj600ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$114,0);
  $125 = HEAP32[$116>>2]|0;
  $126 = HEAP32[$117>>2]|0;
  __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEE27extendedDualIndexedPropertyILj601ES4_jjfEEvjRKNS_33PxExtendedDualIndexedPropertyInfoIXT_ET0_T1_T2_T3_EEjj($$byval_copy,0,$115,$125,$126);
  $127 = HEAP32[$118>>2]|0;
  dest=$1+0|0; src=$propVal+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $128 = HEAP32[$119>>2]|0;
  $129 = (($128) + 8|0);
  $130 = HEAP32[$129>>2]|0;
  dest=$$byval_copy+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  FUNCTION_TABLE_viii[$130 & 4095]($127,$index$02,$$byval_copy);
  $131 = HEAP8[$54>>0]|0;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   label = 18;
   break;
  }
  $133 = (($index$02) + 1)|0;
  $134 = HEAP32[$98>>2]|0;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + 24|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = (FUNCTION_TABLE_ii[$137 & 4095]($134)|0);
  if ($138) {
   $index$02 = $133;
  } else {
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj596ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj597ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj598ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj599ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEEclILj600ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEE14handleAccessorILj600ENS_22PxRepXPropertyAccessorILj600ES4_jjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEE27extendedDualIndexedPropertyILj601ES4_jjfEEvjRKNS_33PxExtendedDualIndexedPropertyInfoIXT_ET0_T1_T2_T3_EEjj($this,$0,$inProp,$id0Count,$id1Count) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $id0Count = $id0Count|0;
 $id1Count = $id1Count|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i14 = 0, $$phi$trans$insert$i6 = 0, $$phi$trans$insert3$i = 0, $$phi$trans$insert3$i11 = 0, $$phi$trans$insert3$i3 = 0, $$pre = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i5 = 0, $$pre1$i = 0, $$pre1$i15 = 0, $$pre1$i7 = 0, $$pre2$i = 0, $$pre2$i10 = 0, $$pre2$i2 = 0, $$pre4$i = 0, $$pre4$i12 = 0, $$pre4$i4 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer1 = 0, $buffer2 = 0, $exitcond = 0, $exitcond23 = 0, $i$018 = 0, $j$017 = 0, $rangeStart = 0, $rangeStart$ = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer1 = sp;
 $rangeStart = sp + 4|0;
 $buffer1 = sp + 40|0;
 $buffer2 = sp + 8|0;
 $1 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$1);
 HEAP32[$rangeStart>>2] = 601;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $rangeStart$ = $4 ? $rangeStart : $3;
 $5 = ($id0Count|0)==(0);
 if ($5) {
  $$pre = HEAP32[$this>>2]|0;
  $76 = $$pre;
 } else {
  $6 = ($id1Count|0)==(0);
  $7 = (($this) + 36|0);
  $8 = (($this) + 20|0);
  $9 = (($this) + 24|0);
  $10 = (($inProp) + 8|0);
  $i$018 = 0;
  while(1) {
   dest=$buffer1+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$018;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer1,0,519952,$vararg_buffer1)|0);
   __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$buffer1);
   if (!($6)) {
    $j$017 = 0;
    while(1) {
     dest=$buffer2+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
     HEAP32[$vararg_buffer1>>2] = $j$017;
     (__ZN5physx6string9sprintf_sEPcjPKcz($buffer2,0,519960,$vararg_buffer1)|0);
     __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$buffer2);
     $11 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE12readPropertyIfEEbRT_($this,$vararg_buffer1)|0);
     if ($11) {
      $12 = HEAP32[$9>>2]|0;
      $13 = Math_fround(HEAPF32[$vararg_buffer1>>2]);
      $14 = HEAP32[$10>>2]|0;
      FUNCTION_TABLE_viiif[$14 & 15]($12,$i$018,$j$017,$13);
     }
     $15 = HEAP32[$this>>2]|0;
     $16 = (($15) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0);
     if ($18) {
      HEAP8[$7>>0] = 1;
     } else {
      $19 = (($17) + -1)|0;
      $20 = (($15) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ((($21) + ($19<<3)|0) + 4|0);
      $23 = HEAP8[$22>>0]|0;
      $24 = ($23<<24>>24)==(0);
      if ($24) {
       $33 = $15;$35 = $17;
      } else {
       $25 = ((($21) + ($19<<3)|0) + 5|0);
       $26 = HEAP8[$25>>0]|0;
       $27 = ($26<<24>>24)==(0);
       if ($27) {
        $33 = $15;$35 = $17;
       } else {
        $28 = HEAP32[$8>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        $30 = (($29) + 40|0);
        $31 = HEAP32[$30>>2]|0;
        (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
        $$pre2$i10 = HEAP32[$this>>2]|0;
        $$phi$trans$insert3$i11 = (($$pre2$i10) + 8|0);
        $$pre4$i12 = HEAP32[$$phi$trans$insert3$i11>>2]|0;
        $33 = $$pre2$i10;$35 = $$pre4$i12;
       }
      }
      $32 = (($33) + 8|0);
      $34 = (($35) + -1)|0;
      HEAP32[$32>>2] = $34;
      $$pre$i13 = HEAP32[$this>>2]|0;
      $$phi$trans$insert$i14 = (($$pre$i13) + 8|0);
      $$pre1$i15 = HEAP32[$$phi$trans$insert$i14>>2]|0;
      HEAP8[$7>>0] = 1;
      $36 = ($$pre1$i15|0)==(0);
      if (!($36)) {
       $37 = (($$pre1$i15) + -1)|0;
       $38 = (($$pre$i13) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = ((($39) + ($37<<3)|0) + 5|0);
       $41 = HEAP8[$40>>0]|0;
       $42 = ($41<<24>>24)==(0);
       if ($42) {
        HEAP8[$7>>0] = 0;
       }
      }
     }
     $43 = HEAP32[$rangeStart$>>2]|0;
     $44 = (($43) + 1)|0;
     HEAP32[$rangeStart$>>2] = $44;
     $45 = (($j$017) + 1)|0;
     $exitcond = ($45|0)==($id1Count|0);
     if ($exitcond) {
      break;
     } else {
      $j$017 = $45;
     }
    }
   }
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0);
   if ($49) {
    HEAP8[$7>>0] = 1;
    $106 = $46;
   } else {
    $50 = (($48) + -1)|0;
    $51 = (($46) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ((($52) + ($50<<3)|0) + 4|0);
    $54 = HEAP8[$53>>0]|0;
    $55 = ($54<<24>>24)==(0);
    if ($55) {
     $64 = $46;$66 = $48;
    } else {
     $56 = ((($52) + ($50<<3)|0) + 5|0);
     $57 = HEAP8[$56>>0]|0;
     $58 = ($57<<24>>24)==(0);
     if ($58) {
      $64 = $46;$66 = $48;
     } else {
      $59 = HEAP32[$8>>2]|0;
      $60 = HEAP32[$59>>2]|0;
      $61 = (($60) + 40|0);
      $62 = HEAP32[$61>>2]|0;
      (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
      $$pre2$i2 = HEAP32[$this>>2]|0;
      $$phi$trans$insert3$i3 = (($$pre2$i2) + 8|0);
      $$pre4$i4 = HEAP32[$$phi$trans$insert3$i3>>2]|0;
      $64 = $$pre2$i2;$66 = $$pre4$i4;
     }
    }
    $63 = (($64) + 8|0);
    $65 = (($66) + -1)|0;
    HEAP32[$63>>2] = $65;
    $$pre$i5 = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i6 = (($$pre$i5) + 8|0);
    $$pre1$i7 = HEAP32[$$phi$trans$insert$i6>>2]|0;
    HEAP8[$7>>0] = 1;
    $67 = ($$pre1$i7|0)==(0);
    if ($67) {
     $106 = $$pre$i5;
    } else {
     $68 = (($$pre1$i7) + -1)|0;
     $69 = (($$pre$i5) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ((($70) + ($68<<3)|0) + 5|0);
     $72 = HEAP8[$71>>0]|0;
     $73 = ($72<<24>>24)==(0);
     if ($73) {
      HEAP8[$7>>0] = 0;
      $106 = $$pre$i5;
     } else {
      $106 = $$pre$i5;
     }
    }
   }
   $74 = (($i$018) + 1)|0;
   $exitcond23 = ($74|0)==($id0Count|0);
   if ($exitcond23) {
    $76 = $106;
    break;
   } else {
    $i$018 = $74;
   }
  }
 }
 $75 = (($76) + 8|0);
 $77 = HEAP32[$75>>2]|0;
 $78 = ($77|0)==(0);
 if ($78) {
  $79 = (($this) + 36|0);
  HEAP8[$79>>0] = 1;
  STACKTOP = sp;return;
 }
 $80 = (($77) + -1)|0;
 $81 = (($76) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ((($82) + ($80<<3)|0) + 4|0);
 $84 = HEAP8[$83>>0]|0;
 $85 = ($84<<24>>24)==(0);
 if ($85) {
  $95 = $76;$97 = $77;
 } else {
  $86 = ((($82) + ($80<<3)|0) + 5|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = ($87<<24>>24)==(0);
  if ($88) {
   $95 = $76;$97 = $77;
  } else {
   $89 = (($this) + 20|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = HEAP32[$90>>2]|0;
   $92 = (($91) + 40|0);
   $93 = HEAP32[$92>>2]|0;
   (FUNCTION_TABLE_ii[$93 & 4095]($90)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $95 = $$pre2$i;$97 = $$pre4$i;
  }
 }
 $94 = (($95) + 8|0);
 $96 = (($97) + -1)|0;
 HEAP32[$94>>2] = $96;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $98 = (($this) + 36|0);
 HEAP8[$98>>0] = 1;
 $99 = ($$pre1$i|0)==(0);
 if ($99) {
  STACKTOP = sp;return;
 }
 $100 = (($$pre1$i) + -1)|0;
 $101 = (($$pre$i) + 4|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = ((($102) + ($100<<3)|0) + 5|0);
 $104 = HEAP8[$103>>0]|0;
 $105 = ($104<<24>>24)==(0);
 if (!($105)) {
  STACKTOP = sp;return;
 }
 HEAP8[$98>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_17PxVehicleTireDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_17PxVehicleTireDataEEEE14handleAccessorILj600ENS_22PxRepXPropertyAccessorILj600ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 28;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $33 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($inAccessor) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($35,$33);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj610ES4_NS_18PxVehicleWheelDataEKjNS_31PxVehicleWheelDataGeneratedInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj610ES2_KjNS_18PxVehicleWheelDataEEEKNS_31PxVehicleWheelDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj610ES2_KjNS_18PxVehicleWheelDataEEEKNS_31PxVehicleWheelDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$byval_copy = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$02 = 0, $propVal = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 96|0;
 $1 = sp;
 $propVal = sp + 48|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$$byval_copy>>2] = $6;
 $7 = (($3) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = (($3) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $18 = $11;
  } else {
   HEAP32[$15>>2] = $6;
   $$pre$i$i = HEAP32[$10>>2]|0;
   $18 = $$pre$i$i;
  }
  $17 = (($18) + 1)|0;
  HEAP32[$10>>2] = $17;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($3,$$byval_copy)|0);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = ((($25) + ($23<<3)|0) + 4|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $30 = (($this) + 36|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $42 = $21;$44 = $25;$45 = 0;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$26>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$37 & 4095]($34,$38)|0);
    $40 = $39&1;
    HEAP8[$30>>0] = $40;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $42 = $$pre1$i;$44 = $$pre3$i;$45 = $40;
   }
   $41 = (($42) + -1)|0;
   $43 = ((($44) + ($41<<3)|0) + 5|0);
   HEAP8[$43>>0] = $45;
   $46 = HEAP8[$30>>0]|0;
   $47 = HEAP32[$this>>2]|0;
   $48 = (($47) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = (($47) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52) + ($50<<3)|0) + 4|0);
   HEAP8[$53>>0] = $46;
  }
 }
 $54 = (($this) + 36|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $57 = HEAP8[$54>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $73 = 0;
 } else {
  $59 = (($this) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = $64&1;
  HEAP8[$54>>0] = $65;
  $73 = $65;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 $70 = (($66) + 4|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71) + ($69<<3)|0) + 5|0);
 HEAP8[$72>>0] = $73;
 $74 = HEAP8[$54>>0]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + -1)|0;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<3)|0) + 4|0);
 HEAP8[$81>>0] = $74;
 $82 = HEAP8[$54>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $84 = (($propVal) + 4|0);
 $85 = (($propVal) + 8|0);
 $86 = (($propVal) + 12|0);
 $87 = (($propVal) + 16|0);
 $88 = (($propVal) + 20|0);
 $89 = (($propVal) + 24|0);
 $90 = (($this) + 8|0);
 $91 = (($this) + 20|0);
 $92 = (($this) + 28|0);
 $93 = (($this) + 32|0);
 $94 = (($$byval_copy) + 4|0);
 $95 = (($$byval_copy) + 8|0);
 $96 = (($$byval_copy) + 20|0);
 $97 = (($$byval_copy) + 24|0);
 $98 = (($$byval_copy) + 28|0);
 $99 = (($$byval_copy) + 32|0);
 $100 = (($$byval_copy) + 36|0);
 $101 = (($$byval_copy) + 40|0);
 $102 = (($$byval_copy) + 44|0);
 $103 = (($inInfo) + 24|0);
 $104 = (($inInfo) + 40|0);
 $105 = (($inInfo) + 56|0);
 $106 = (($inInfo) + 72|0);
 $107 = (($inInfo) + 88|0);
 $108 = (($inInfo) + 104|0);
 $109 = (($inInfo) + 120|0);
 $110 = (($inInfo) + 136|0);
 $111 = (($inInfo) + 152|0);
 $112 = (($this) + 24|0);
 $113 = (($inProp) + 12|0);
 $index$02 = 0;
 while(1) {
  HEAPF32[$propVal>>2] = Math_fround(0.0);
  HEAPF32[$84>>2] = Math_fround(0.0);
  HEAPF32[$85>>2] = Math_fround(20.0);
  HEAPF32[$86>>2] = Math_fround(0.0);
  HEAPF32[$87>>2] = Math_fround(0.25);
  HEAPF32[$88>>2] = Math_fround(1500.0);
  ;HEAP32[$89+0>>2]=0|0;HEAP32[$89+4>>2]=0|0;HEAP32[$89+8>>2]=0|0;HEAP32[$89+12>>2]=0|0;HEAP32[$89+16>>2]=0|0;
  $114 = HEAP32[$this>>2]|0;
  $115 = HEAP32[$2>>2]|0;
  $116 = HEAP32[$91>>2]|0;
  $117 = HEAP32[$92>>2]|0;
  $118 = HEAP32[$93>>2]|0;
  HEAP32[$$byval_copy>>2] = $114;
  HEAP32[$94>>2] = $115;
  ;HEAP32[$95+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$90+8>>2]|0;
  HEAP32[$96>>2] = $116;
  HEAP32[$97>>2] = $propVal;
  HEAP32[$98>>2] = $117;
  HEAP32[$99>>2] = $118;
  HEAP8[$100>>0] = 1;
  HEAP32[$101>>2] = 0;
  HEAP32[$102>>2] = 0;
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj569ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$103,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj570ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$104,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj571ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$105,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj572ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$106,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj573ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$107,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj574ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$108,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj575ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$109,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj576ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$110,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj577ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$111,0);
  $119 = HEAP32[$112>>2]|0;
  dest=$1+0|0; src=$propVal+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $120 = HEAP32[$113>>2]|0;
  $121 = (($120) + 8|0);
  $122 = HEAP32[$121>>2]|0;
  dest=$$byval_copy+0|0; src=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  FUNCTION_TABLE_viii[$122 & 4095]($119,$index$02,$$byval_copy);
  $123 = HEAP8[$54>>0]|0;
  $124 = ($123<<24>>24)==(0);
  if ($124) {
   label = 18;
   break;
  }
  $125 = (($index$02) + 1)|0;
  $126 = HEAP32[$91>>2]|0;
  $127 = HEAP32[$126>>2]|0;
  $128 = (($127) + 24|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (FUNCTION_TABLE_ii[$129 & 4095]($126)|0);
  if ($130) {
   $index$02 = $125;
  } else {
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj569ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj570ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj571ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj572ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj573ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj574ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj575ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj576ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleWheelDataEEEEclILj577ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleWheelDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEE27handleExtendedIndexPropertyILj609ES4_NS_23PxVehicleSuspensionDataEKjNS_36PxVehicleSuspensionDataGeneratedInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj609ES2_KjNS_23PxVehicleSuspensionDataEEEKNS_36PxVehicleSuspensionDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj609ES2_KjNS_23PxVehicleSuspensionDataEEEKNS_36PxVehicleSuspensionDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$byval_copy = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$02 = 0, $propVal = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 96|0;
 $1 = sp;
 $propVal = sp + 48|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$$byval_copy>>2] = $6;
 $7 = (($3) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = (($3) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $18 = $11;
  } else {
   HEAP32[$15>>2] = $6;
   $$pre$i$i = HEAP32[$10>>2]|0;
   $18 = $$pre$i$i;
  }
  $17 = (($18) + 1)|0;
  HEAP32[$10>>2] = $17;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($3,$$byval_copy)|0);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = ((($25) + ($23<<3)|0) + 4|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $30 = (($this) + 36|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $42 = $21;$44 = $25;$45 = 0;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$26>>2]|0;
    $39 = (FUNCTION_TABLE_iii[$37 & 4095]($34,$38)|0);
    $40 = $39&1;
    HEAP8[$30>>0] = $40;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $42 = $$pre1$i;$44 = $$pre3$i;$45 = $40;
   }
   $41 = (($42) + -1)|0;
   $43 = ((($44) + ($41<<3)|0) + 5|0);
   HEAP8[$43>>0] = $45;
   $46 = HEAP8[$30>>0]|0;
   $47 = HEAP32[$this>>2]|0;
   $48 = (($47) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = (($47) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($52) + ($50<<3)|0) + 4|0);
   HEAP8[$53>>0] = $46;
  }
 }
 $54 = (($this) + 36|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE8pushNameEPKc($this,519928);
 $57 = HEAP8[$54>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $73 = 0;
 } else {
  $59 = (($this) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 20|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = $64&1;
  HEAP8[$54>>0] = $65;
  $73 = $65;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + -1)|0;
 $70 = (($66) + 4|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ((($71) + ($69<<3)|0) + 5|0);
 HEAP8[$72>>0] = $73;
 $74 = HEAP8[$54>>0]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($77) + -1)|0;
 $79 = (($75) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<3)|0) + 4|0);
 HEAP8[$81>>0] = $74;
 $82 = HEAP8[$54>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $84 = (($propVal) + 4|0);
 $85 = (($propVal) + 8|0);
 $86 = (($propVal) + 12|0);
 $87 = (($propVal) + 16|0);
 $88 = (($propVal) + 32|0);
 $89 = (($propVal) + 36|0);
 $90 = (($this) + 8|0);
 $91 = (($this) + 20|0);
 $92 = (($this) + 28|0);
 $93 = (($this) + 32|0);
 $94 = (($$byval_copy) + 4|0);
 $95 = (($$byval_copy) + 8|0);
 $96 = (($$byval_copy) + 20|0);
 $97 = (($$byval_copy) + 24|0);
 $98 = (($$byval_copy) + 28|0);
 $99 = (($$byval_copy) + 32|0);
 $100 = (($$byval_copy) + 36|0);
 $101 = (($$byval_copy) + 40|0);
 $102 = (($$byval_copy) + 44|0);
 $103 = (($inInfo) + 36|0);
 $104 = (($inInfo) + 52|0);
 $105 = (($inInfo) + 68|0);
 $106 = (($inInfo) + 84|0);
 $107 = (($inInfo) + 100|0);
 $108 = (($inInfo) + 116|0);
 $109 = (($inInfo) + 132|0);
 $110 = (($inInfo) + 148|0);
 $111 = (($this) + 24|0);
 $112 = (($inProp) + 12|0);
 $index$02 = 0;
 while(1) {
  HEAPF32[$propVal>>2] = Math_fround(0.0);
  HEAPF32[$84>>2] = Math_fround(0.0);
  HEAPF32[$85>>2] = Math_fround(0.300000011920928955078);
  HEAPF32[$86>>2] = Math_fround(0.100000001490116119385);
  ;HEAP32[$87+0>>2]=0|0;HEAP32[$87+4>>2]=0|0;HEAP32[$87+8>>2]=0|0;HEAP32[$87+12>>2]=0|0;
  HEAPF32[$88>>2] = Math_fround(1.0);
  HEAPF32[$89>>2] = Math_fround(1.0);
  $113 = HEAP32[$this>>2]|0;
  $114 = HEAP32[$2>>2]|0;
  $115 = HEAP32[$91>>2]|0;
  $116 = HEAP32[$92>>2]|0;
  $117 = HEAP32[$93>>2]|0;
  HEAP32[$$byval_copy>>2] = $113;
  HEAP32[$94>>2] = $114;
  ;HEAP32[$95+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$90+8>>2]|0;
  HEAP32[$96>>2] = $115;
  HEAP32[$97>>2] = $propVal;
  HEAP32[$98>>2] = $116;
  HEAP32[$99>>2] = $117;
  HEAP8[$100>>0] = 1;
  HEAP32[$101>>2] = 0;
  HEAP32[$102>>2] = 0;
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj583ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$103,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj584ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$104,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj585ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$105,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj586ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$106,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj587ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$107,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj588ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$108,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj589ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$109,0);
  __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj590ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($$byval_copy,$110,0);
  $118 = HEAP32[$111>>2]|0;
  dest=$1+0|0; src=$propVal+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $119 = HEAP32[$112>>2]|0;
  $120 = (($119) + 8|0);
  $121 = HEAP32[$120>>2]|0;
  dest=$$byval_copy+0|0; src=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  FUNCTION_TABLE_viii[$121 & 4095]($118,$index$02,$$byval_copy);
  $122 = HEAP8[$54>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   label = 18;
   break;
  }
  $124 = (($index$02) + 1)|0;
  $125 = HEAP32[$91>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  if ($129) {
   $index$02 = $124;
  } else {
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_22PxVehicleWheelsSimDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj583ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj584ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj585ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj586ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj587ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj588ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj589ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleSuspensionDataEEEEclILj590ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleSuspensionDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleDriveNWEE11getTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (519520|0);
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleDriveNWEE12objectToFileERKNS_12PxRepXObjectEPNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE($this,$inLiveObject,$inCollection,$inWriter,$inTempBuffer,$inArgs) {
 $this = $this|0;
 $inLiveObject = $inLiveObject|0;
 $inCollection = $inCollection|0;
 $inWriter = $inWriter|0;
 $inTempBuffer = $inTempBuffer|0;
 $inArgs = $inArgs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inLiveObject) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiiiii[$4 & 255]($this,$1,$inCollection,$inWriter,$inTempBuffer,$inArgs);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleDriveNWEE16fileToObjectImplEPS1_RNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE($this,$inObj,$inReader,$inAllocator,$inArgs,$inCollection) {
 $this = $this|0;
 $inObj = $inObj|0;
 $inReader = $inReader|0;
 $inAllocator = $inAllocator|0;
 $inArgs = $inArgs|0;
 $inCollection = $inCollection|0;
 var $inArgs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $inArgs$byval_copy = sp;
 ;HEAP32[$inArgs$byval_copy+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy+8>>2]=HEAP32[$inArgs+8>>2]|0;
 __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleDriveNWEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy,$inReader,$inObj,$inAllocator,$inCollection);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleDriveNWEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($args,$reader,$obj,$alloc,$collection) {
 $args = $args|0;
 $reader = $reader|0;
 $obj = $obj|0;
 $alloc = $alloc|0;
 $collection = $collection|0;
 var $$sroa$2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $contexts = 0, $info = 0, $names = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $wrapper = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $0 = sp + 288|0;
 $1 = sp + 240|0;
 $$sroa$2$i = sp;
 $2 = sp + 192|0;
 $3 = sp + 16|0;
 $wrapper = sp + 172|0;
 $names = sp + 32|0;
 $contexts = sp + 176|0;
 $info = sp + 48|0;
 $4 = HEAP32[$alloc>>2]|0;
 $5 = (($4) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($alloc)|0);
 HEAP32[$wrapper>>2] = $7;
 HEAP32[$names>>2] = $wrapper;
 $8 = (($names) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($names) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($names) + 12|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$contexts>>2] = $wrapper;
 $11 = (($contexts) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($contexts) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = (($contexts) + 12|0);
 HEAP32[$13>>2] = 0;
 __ZN5physx29PxVehicleDriveNWGeneratedInfoC2Ev($info);
 ;HEAP32[$3+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$args+8>>2]|0;
 ;HEAP32[$$sroa$2$i+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$sroa$2$i+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$sroa$2$i+8>>2]=HEAP32[$3+8>>2]|0;
 HEAP32[$0>>2] = $names;
 $14 = (($0) + 4|0);
 HEAP32[$14>>2] = $contexts;
 $15 = (($0) + 8|0);
 ;HEAP32[$15+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$3+8>>2]|0;
 $16 = (($0) + 20|0);
 HEAP32[$16>>2] = $reader;
 $17 = (($0) + 24|0);
 HEAP32[$17>>2] = $obj;
 $18 = (($0) + 28|0);
 HEAP32[$18>>2] = $alloc;
 $19 = (($0) + 32|0);
 HEAP32[$19>>2] = $collection;
 $20 = (($0) + 36|0);
 HEAP8[$20>>0] = 1;
 $21 = (($0) + 40|0);
 HEAP32[$21>>2] = 0;
 $22 = (($0) + 44|0);
 HEAP32[$22>>2] = 0;
 $23 = (($info) + 36|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDriveNWEEEEclILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$23,0);
 $24 = (($info) + 52|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDriveNWEEEEclILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$24,0);
 HEAP32[$1>>2] = $names;
 $25 = (($1) + 4|0);
 HEAP32[$25>>2] = $contexts;
 $26 = (($1) + 8|0);
 ;HEAP32[$26+0>>2]=HEAP32[$$sroa$2$i+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$$sroa$2$i+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$$sroa$2$i+8>>2]|0;
 $27 = (($1) + 20|0);
 HEAP32[$27>>2] = $reader;
 $28 = (($1) + 24|0);
 HEAP32[$28>>2] = $obj;
 $29 = (($1) + 28|0);
 HEAP32[$29>>2] = $alloc;
 $30 = (($1) + 32|0);
 HEAP32[$30>>2] = $collection;
 $31 = (($1) + 36|0);
 HEAP8[$31>>0] = 1;
 $32 = (($1) + 40|0);
 HEAP32[$32>>2] = 0;
 $33 = (($1) + 44|0);
 HEAP32[$33>>2] = 0;
 $34 = (($info) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDriveNWEEEEclILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$34,0);
 HEAP32[$2>>2] = $names;
 $35 = (($2) + 4|0);
 HEAP32[$35>>2] = $contexts;
 $36 = (($2) + 8|0);
 ;HEAP32[$36+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$args+8>>2]|0;
 $37 = (($2) + 20|0);
 HEAP32[$37>>2] = $reader;
 $38 = (($2) + 24|0);
 HEAP32[$38>>2] = $obj;
 $39 = (($2) + 28|0);
 HEAP32[$39>>2] = $alloc;
 $40 = (($2) + 32|0);
 HEAP32[$40>>2] = $collection;
 $41 = (($2) + 36|0);
 HEAP8[$41>>0] = 1;
 $42 = (($2) + 40|0);
 HEAP32[$42>>2] = 0;
 $43 = (($2) + 44|0);
 HEAP32[$43>>2] = 0;
 $44 = (($info) + 108|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDriveNWEEEEclILj682ES3_NS_23PxVehicleDriveSimDataNWES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$44,0);
 $45 = HEAP32[$13>>2]|0;
 $46 = $45 & 2147483647;
 $47 = ($46|0)!=(0);
 $48 = ($45|0)>(-1);
 $or$cond$i$i$i1 = $47 & $48;
 if ($or$cond$i$i$i1) {
  $49 = HEAP32[$11>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = HEAP32[$contexts>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  }
 }
 $56 = HEAP32[$10>>2]|0;
 $57 = $56 & 2147483647;
 $58 = ($57|0)!=(0);
 $59 = ($56|0)>(-1);
 $or$cond$i$i$i = $58 & $59;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $60 = HEAP32[$8>>2]|0;
 $61 = ($60|0)==(0|0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $62 = HEAP32[$names>>2]|0;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 FUNCTION_TABLE_vii[$66 & 4095]($63,$60);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDriveNWEEEEclILj682ES3_NS_23PxVehicleDriveSimDataNWES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 212;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 212)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 dest=$1+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx36PxVehicleDriveSimDataNWGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj682ES2_NS_23PxVehicleDriveSimDataNWES6_EEKNS_36PxVehicleDriveSimDataNWGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj682ES2_NS_23PxVehicleDriveSimDataNWES6_EEKNS_36PxVehicleDriveSimDataNWGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2240|0;
 $1 = sp + 1696|0;
 $2 = sp;
 $3 = sp + 560|0;
 $4 = sp + 544|0;
 $propVal = sp + 608|0;
 $5 = sp + 1152|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($8) + -1)|0;
  $11 = (($6) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($10<<3)|0);
  $14 = ((($12) + ($10<<3)|0) + 4|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $17 = (($this) + 36|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    $29 = $8;$31 = $12;$32 = 0;
   } else {
    $20 = (($this) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + 16|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = HEAP32[$13>>2]|0;
    $26 = (FUNCTION_TABLE_iii[$24 & 4095]($21,$25)|0);
    $27 = $26&1;
    HEAP8[$17>>0] = $27;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $29 = $$pre1$i;$31 = $$pre3$i;$32 = $27;
   }
   $28 = (($29) + -1)|0;
   $30 = ((($31) + ($28<<3)|0) + 5|0);
   HEAP8[$30>>0] = $32;
   $33 = HEAP8[$17>>0]|0;
   $34 = HEAP32[$this>>2]|0;
   $35 = (($34) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + -1)|0;
   $38 = (($34) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39) + ($37<<3)|0) + 4|0);
   HEAP8[$40>>0] = $33;
  }
 }
 $41 = (($this) + 36|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  STACKTOP = sp;return;
 }
 $44 = (($this) + 24|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($inProp) + 16|0);
 $47 = HEAP32[$46>>2]|0;
 FUNCTION_TABLE_vii[$47 & 4095]($propVal,$45);
 $48 = (($this) + 8|0);
 ;HEAP32[$4+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$48+8>>2]|0;
 $49 = HEAP32[$this>>2]|0;
 $50 = (($this) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 20|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 28|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($this) + 32|0);
 $57 = HEAP32[$56>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$48+8>>2]|0;
 HEAP32[$1>>2] = $49;
 $58 = (($1) + 4|0);
 HEAP32[$58>>2] = $51;
 $59 = (($1) + 8|0);
 ;HEAP32[$59+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$4+8>>2]|0;
 $60 = (($1) + 20|0);
 HEAP32[$60>>2] = $53;
 $61 = (($1) + 24|0);
 HEAP32[$61>>2] = $propVal;
 $62 = (($1) + 28|0);
 HEAP32[$62>>2] = $55;
 $63 = (($1) + 32|0);
 HEAP32[$63>>2] = $57;
 $64 = (($1) + 36|0);
 HEAP8[$64>>0] = 1;
 $65 = (($1) + 40|0);
 HEAP32[$65>>2] = 0;
 $66 = (($1) + 44|0);
 HEAP32[$66>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$inInfo,0);
 $67 = (($inInfo) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$67,0);
 $68 = (($inInfo) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$68,0);
 $69 = (($inInfo) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$69,0);
 HEAP32[$3>>2] = $49;
 $70 = (($3) + 4|0);
 HEAP32[$70>>2] = $51;
 $71 = (($3) + 8|0);
 ;HEAP32[$71+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$2+8>>2]|0;
 $72 = (($3) + 20|0);
 HEAP32[$72>>2] = $53;
 $73 = (($3) + 24|0);
 HEAP32[$73>>2] = $propVal;
 $74 = (($3) + 28|0);
 HEAP32[$74>>2] = $55;
 $75 = (($3) + 32|0);
 HEAP32[$75>>2] = $57;
 $76 = (($3) + 36|0);
 HEAP8[$76>>0] = 1;
 $77 = (($3) + 40|0);
 HEAP32[$77>>2] = 0;
 $78 = (($3) + 44|0);
 HEAP32[$78>>2] = 0;
 $79 = (($inInfo) + 64|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj678ES3_RKNS_27PxVehicleDifferentialNWDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($3,$79,0);
 $80 = HEAP32[$44>>2]|0;
 $81 = (($propVal) + 64|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = $82 << 3;
 _memcpy(($5|0),($propVal|0),($83|0))|0;
 $84 = (($5) + 64|0);
 HEAP32[$84>>2] = $82;
 $85 = (($5) + 80|0);
 $86 = (($propVal) + 80|0);
 ;HEAP32[$85+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$86+8>>2]|0;HEAP32[$85+12>>2]=HEAP32[$86+12>>2]|0;HEAP32[$85+16>>2]=HEAP32[$86+16>>2]|0;HEAP32[$85+20>>2]=HEAP32[$86+20>>2]|0;HEAP32[$85+24>>2]=HEAP32[$86+24>>2]|0;HEAP32[$85+28>>2]=HEAP32[$86+28>>2]|0;
 $87 = (($5) + 112|0);
 $88 = (($propVal) + 112|0);
 _memcpy(($87|0),($88|0),416)|0;
 $89 = (($5) + 528|0);
 $90 = (($propVal) + 528|0);
 ;HEAP32[$89+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$90+12>>2]|0;
 _memcpy(($2|0),($5|0),($83|0))|0;
 $91 = (($2) + 64|0);
 HEAP32[$91>>2] = $82;
 $92 = (($2) + 80|0);
 ;HEAP32[$92+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$86+8>>2]|0;HEAP32[$92+12>>2]=HEAP32[$86+12>>2]|0;HEAP32[$92+16>>2]=HEAP32[$86+16>>2]|0;HEAP32[$92+20>>2]=HEAP32[$86+20>>2]|0;HEAP32[$92+24>>2]=HEAP32[$86+24>>2]|0;HEAP32[$92+28>>2]=HEAP32[$86+28>>2]|0;
 $93 = (($2) + 112|0);
 _memcpy(($93|0),($88|0),416)|0;
 $94 = (($2) + 528|0);
 ;HEAP32[$94+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$94+12>>2]=HEAP32[$90+12>>2]|0;
 $95 = (($inProp) + 20|0);
 $96 = HEAP32[$95>>2]|0;
 _memcpy(($1|0),($2|0),($83|0))|0;
 $97 = (($1) + 64|0);
 HEAP32[$97>>2] = $82;
 $98 = (($1) + 80|0);
 ;HEAP32[$98+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$86+8>>2]|0;HEAP32[$98+12>>2]=HEAP32[$86+12>>2]|0;HEAP32[$98+16>>2]=HEAP32[$86+16>>2]|0;HEAP32[$98+20>>2]=HEAP32[$86+20>>2]|0;HEAP32[$98+24>>2]=HEAP32[$86+24>>2]|0;HEAP32[$98+28>>2]=HEAP32[$86+28>>2]|0;
 $99 = (($1) + 112|0);
 _memcpy(($99|0),($88|0),416)|0;
 $100 = (($1) + 528|0);
 ;HEAP32[$100+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$100+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$100+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$100+12>>2]=HEAP32[$90+12>>2]|0;
 FUNCTION_TABLE_vii[$96 & 4095]($80,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj678ES3_RKNS_27PxVehicleDifferentialNWDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 528;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 528)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 __ZN5physx40PxVehicleDifferentialNWDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj678ES2_RKNS_27PxVehicleDifferentialNWDataES6_EEKNS_40PxVehicleDifferentialNWDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj678ES2_RKNS_27PxVehicleDifferentialNWDataES6_EEKNS_40PxVehicleDifferentialNWDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $1 = sp;
 $2 = sp + 32|0;
 $propVal = sp + 16|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inProp) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$2>>2] = $46;
 $55 = (($2) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($2) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($2) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($2) + 24|0);
 HEAP32[$58>>2] = $propVal;
 $59 = (($2) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($2) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($2) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($2) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($2) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferentialNWDataEEEEclILj546ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$inInfo,0);
 $64 = HEAP32[$41>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal+12>>2]|0;
 $65 = (($inProp) + 20|0);
 $66 = HEAP32[$65>>2]|0;
 FUNCTION_TABLE_vii[$66 & 4095]($64,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferentialNWDataEEEEclILj546ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferentialNWDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferentialNWDataEEEE14handleAccessorILj546ENS_22PxRepXPropertyAccessorILj546ES4_jjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferentialNWDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferentialNWDataEEEE14handleAccessorILj546ENS_22PxRepXPropertyAccessorILj546ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $$0$i = $3;
 }
 HEAP8[$inAccessor>>0] = 1;
 $4 = (($inAccessor) + 4|0);
 HEAP32[$4>>2] = $$0$i;
 $5 = (($this) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$6>>2] = $9;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $10 = (($this) + 36|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = HEAP32[$25>>2]|0;
  $$0$i$i$i$i$i$i = $26;
 }
 $27 = (FUNCTION_TABLE_iiii[$17 & 2047]($14,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $28 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $27 ? $28 : 0;
 $29 = ($$$i$i$i$i$i|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $32 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $33 = (($this) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($inAccessor) + 20|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($34,$32);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 0;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
 }
 _memset(($1|0),0,144)|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES7_EEKNS_32PxVehicleEngineDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 112;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 112)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 656;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataESA_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 256;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 256)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 657;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataESA_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEEclILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 272;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 272)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 658;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataESA_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataESA_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $0 = sp + 560|0;
 $1 = sp;
 $propVal$i$i = sp + 256|0;
 $2 = sp + 512|0;
 dest=$2+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEEclILj532ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$2,0);
 $64 = (($2) + 16|0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj533ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$64,519968,0);
 $65 = (($2) + 32|0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj534ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$65,519968,0);
 $66 = HEAP32[$41>>2]|0;
 _memcpy(($1|0),($propVal$i$i|0),256)|0;
 $67 = (($inAccessor) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEEclILj532ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj534ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($this,$0,$inProp,$theConversions,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $theConversions = $theConversions|0;
 $1 = $1|0;
 var $$09 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i6 = 0, $$phi$trans$insert3$i = 0, $$phi$trans$insert3$i3 = 0, $$pre$i = 0, $$pre$i5 = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $$pre1$i7 = 0, $$pre2$i = 0, $$pre2$i2 = 0, $$pre4$i = 0, $$pre4$i4 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $rangeStart = 0, $rangeStart$ = 0, $value$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i = sp + 4|0;
 $rangeStart = sp;
 $2 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE8pushNameEPKc($this,$2);
 HEAP32[$rangeStart>>2] = 534;
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $rangeStart$ = $5 ? $rangeStart : $4;
 $6 = HEAP32[$theConversions>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$pre$phiZ2D = $this;
 } else {
  $8 = (($this) + 24|0);
  $9 = (($inProp) + 8|0);
  $10 = (($this) + 36|0);
  $11 = (($this) + 20|0);
  $$09 = $theConversions;$12 = $6;
  while(1) {
   __ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE8pushNameEPKc($this,$12);
   $13 = (($$09) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE12readPropertyIfEEbRT_($this,$value$i$i$i)|0);
   if ($15) {
    $16 = HEAP32[$8>>2]|0;
    $17 = Math_fround(HEAPF32[$value$i$i$i>>2]);
    $18 = HEAP32[$9>>2]|0;
    FUNCTION_TABLE_viif[$18 & 63]($16,$14,$17);
   }
   $19 = HEAP32[$this>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    HEAP8[$10>>0] = 1;
   } else {
    $23 = (($21) + -1)|0;
    $24 = (($19) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($25) + ($23<<3)|0) + 4|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $37 = $19;$39 = $21;
    } else {
     $29 = ((($25) + ($23<<3)|0) + 5|0);
     $30 = HEAP8[$29>>0]|0;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      $37 = $19;$39 = $21;
     } else {
      $32 = HEAP32[$11>>2]|0;
      $33 = HEAP32[$32>>2]|0;
      $34 = (($33) + 40|0);
      $35 = HEAP32[$34>>2]|0;
      (FUNCTION_TABLE_ii[$35 & 4095]($32)|0);
      $$pre2$i2 = HEAP32[$this>>2]|0;
      $$phi$trans$insert3$i3 = (($$pre2$i2) + 8|0);
      $$pre4$i4 = HEAP32[$$phi$trans$insert3$i3>>2]|0;
      $37 = $$pre2$i2;$39 = $$pre4$i4;
     }
    }
    $36 = (($37) + 8|0);
    $38 = (($39) + -1)|0;
    HEAP32[$36>>2] = $38;
    $$pre$i5 = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i6 = (($$pre$i5) + 8|0);
    $$pre1$i7 = HEAP32[$$phi$trans$insert$i6>>2]|0;
    HEAP8[$10>>0] = 1;
    $40 = ($$pre1$i7|0)==(0);
    if (!($40)) {
     $41 = (($$pre1$i7) + -1)|0;
     $42 = (($$pre$i5) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ((($43) + ($41<<3)|0) + 5|0);
     $45 = HEAP8[$44>>0]|0;
     $46 = ($45<<24>>24)==(0);
     if ($46) {
      HEAP8[$10>>0] = 0;
     }
    }
   }
   $47 = HEAP32[$rangeStart$>>2]|0;
   $48 = (($47) + 1)|0;
   HEAP32[$rangeStart$>>2] = $48;
   $49 = (($$09) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $$pre$phiZ2D = $this;
    break;
   } else {
    $$09 = $49;$12 = $50;
   }
  }
 }
 $52 = HEAP32[$$pre$phiZ2D>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $56 = (($this) + 36|0);
  HEAP8[$56>>0] = 1;
  STACKTOP = sp;return;
 }
 $57 = (($54) + -1)|0;
 $58 = (($52) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59) + ($57<<3)|0) + 4|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $72 = $52;$74 = $54;
 } else {
  $63 = ((($59) + ($57<<3)|0) + 5|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = ($64<<24>>24)==(0);
  if ($65) {
   $72 = $52;$74 = $54;
  } else {
   $66 = (($this) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + 40|0);
   $70 = HEAP32[$69>>2]|0;
   (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
   $$pre2$i = HEAP32[$$pre$phiZ2D>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $72 = $$pre2$i;$74 = $$pre4$i;
  }
 }
 $71 = (($72) + 8|0);
 $73 = (($74) + -1)|0;
 HEAP32[$71>>2] = $73;
 $$pre$i = HEAP32[$$pre$phiZ2D>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $75 = (($this) + 36|0);
 HEAP8[$75>>0] = 1;
 $76 = ($$pre1$i|0)==(0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (($$pre1$i) + -1)|0;
 $78 = (($$pre$i) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 5|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if (!($82)) {
  STACKTOP = sp;return;
 }
 HEAP8[$75>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj533ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($this,$0,$inProp,$theConversions,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $theConversions = $theConversions|0;
 $1 = $1|0;
 var $$09 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i6 = 0, $$phi$trans$insert3$i = 0, $$phi$trans$insert3$i3 = 0, $$pre$i = 0, $$pre$i5 = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $$pre1$i7 = 0, $$pre2$i = 0, $$pre2$i2 = 0, $$pre4$i = 0, $$pre4$i4 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $rangeStart = 0, $rangeStart$ = 0, $value$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i = sp + 4|0;
 $rangeStart = sp;
 $2 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE8pushNameEPKc($this,$2);
 HEAP32[$rangeStart>>2] = 533;
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $rangeStart$ = $5 ? $rangeStart : $4;
 $6 = HEAP32[$theConversions>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$pre$phiZ2D = $this;
 } else {
  $8 = (($this) + 24|0);
  $9 = (($inProp) + 8|0);
  $10 = (($this) + 36|0);
  $11 = (($this) + 20|0);
  $$09 = $theConversions;$12 = $6;
  while(1) {
   __ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE8pushNameEPKc($this,$12);
   $13 = (($$09) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_20PxVehicleAutoBoxDataEE12readPropertyIfEEbRT_($this,$value$i$i$i)|0);
   if ($15) {
    $16 = HEAP32[$8>>2]|0;
    $17 = Math_fround(HEAPF32[$value$i$i$i>>2]);
    $18 = HEAP32[$9>>2]|0;
    FUNCTION_TABLE_viif[$18 & 63]($16,$14,$17);
   }
   $19 = HEAP32[$this>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    HEAP8[$10>>0] = 1;
   } else {
    $23 = (($21) + -1)|0;
    $24 = (($19) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($25) + ($23<<3)|0) + 4|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $37 = $19;$39 = $21;
    } else {
     $29 = ((($25) + ($23<<3)|0) + 5|0);
     $30 = HEAP8[$29>>0]|0;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      $37 = $19;$39 = $21;
     } else {
      $32 = HEAP32[$11>>2]|0;
      $33 = HEAP32[$32>>2]|0;
      $34 = (($33) + 40|0);
      $35 = HEAP32[$34>>2]|0;
      (FUNCTION_TABLE_ii[$35 & 4095]($32)|0);
      $$pre2$i2 = HEAP32[$this>>2]|0;
      $$phi$trans$insert3$i3 = (($$pre2$i2) + 8|0);
      $$pre4$i4 = HEAP32[$$phi$trans$insert3$i3>>2]|0;
      $37 = $$pre2$i2;$39 = $$pre4$i4;
     }
    }
    $36 = (($37) + 8|0);
    $38 = (($39) + -1)|0;
    HEAP32[$36>>2] = $38;
    $$pre$i5 = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i6 = (($$pre$i5) + 8|0);
    $$pre1$i7 = HEAP32[$$phi$trans$insert$i6>>2]|0;
    HEAP8[$10>>0] = 1;
    $40 = ($$pre1$i7|0)==(0);
    if (!($40)) {
     $41 = (($$pre1$i7) + -1)|0;
     $42 = (($$pre$i5) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ((($43) + ($41<<3)|0) + 5|0);
     $45 = HEAP8[$44>>0]|0;
     $46 = ($45<<24>>24)==(0);
     if ($46) {
      HEAP8[$10>>0] = 0;
     }
    }
   }
   $47 = HEAP32[$rangeStart$>>2]|0;
   $48 = (($47) + 1)|0;
   HEAP32[$rangeStart$>>2] = $48;
   $49 = (($$09) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $$pre$phiZ2D = $this;
    break;
   } else {
    $$09 = $49;$12 = $50;
   }
  }
 }
 $52 = HEAP32[$$pre$phiZ2D>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $56 = (($this) + 36|0);
  HEAP8[$56>>0] = 1;
  STACKTOP = sp;return;
 }
 $57 = (($54) + -1)|0;
 $58 = (($52) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59) + ($57<<3)|0) + 4|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $72 = $52;$74 = $54;
 } else {
  $63 = ((($59) + ($57<<3)|0) + 5|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = ($64<<24>>24)==(0);
  if ($65) {
   $72 = $52;$74 = $54;
  } else {
   $66 = (($this) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + 40|0);
   $70 = HEAP32[$69>>2]|0;
   (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
   $$pre2$i = HEAP32[$$pre$phiZ2D>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $72 = $$pre2$i;$74 = $$pre4$i;
  }
 }
 $71 = (($72) + 8|0);
 $73 = (($74) + -1)|0;
 HEAP32[$71>>2] = $73;
 $$pre$i = HEAP32[$$pre$phiZ2D>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $75 = (($this) + 36|0);
 HEAP8[$75>>0] = 1;
 $76 = ($$pre1$i|0)==(0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (($$pre1$i) + -1)|0;
 $78 = (($$pre$i) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 5|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if (!($82)) {
  STACKTOP = sp;return;
 }
 HEAP8[$75>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataESA_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 80|0;
 $1 = sp;
 $propVal$i$i = sp + 16|0;
 $2 = sp + 32|0;
 dest=$2+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj555ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$2,0);
 $64 = (($2) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj556ES3_NS_27PxVehicleClutchAccuracyMode4EnumES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj557ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = HEAP32[$41>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal$i$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal$i$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal$i$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal$i$i+12>>2]|0;
 $67 = (($inAccessor) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj555ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleClutchDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEE14handleAccessorILj555ENS_22PxRepXPropertyAccessorILj555ES4_ffEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj556ES3_NS_27PxVehicleClutchAccuracyMode4EnumES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleClutchDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEE14handleAccessorILj556ENS_22PxRepXPropertyAccessorILj556ES4_NS_27PxVehicleClutchAccuracyMode4EnumESA_EEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj557ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleClutchDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEE14handleAccessorILj557ENS_22PxRepXPropertyAccessorILj557ES4_jjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleClutchDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEE14handleAccessorILj557ENS_22PxRepXPropertyAccessorILj557ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $33 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($inAccessor) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($35,$33);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEE14handleAccessorILj556ENS_22PxRepXPropertyAccessorILj556ES4_NS_27PxVehicleClutchAccuracyMode4EnumESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$02$i$i$i$i$i = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 4;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 4)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i,$value$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i>>2]|0;
 $$$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (520696|0)==(0|0);
 L19: do {
  if ($33) {
   $$0$i$i1$i$i$i = 0;
  } else {
   $38 = 520696;$idx$02$i$i$i$i$i = 0;
   while(1) {
    $39 = (_strcasecmp($38,$$$i$i$i$i)|0);
    $40 = ($39|0)==(0);
    $35 = (($idx$02$i$i$i$i$i) + 1)|0;
    if ($40) {
     break;
    }
    $34 = (520672 + ($35<<3)|0);
    $36 = HEAP32[$34>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$0$i$i1$i$i$i = 0;
     break L19;
    } else {
     $38 = $36;$idx$02$i$i$i$i$i = $35;
    }
   }
   $41 = ((520672 + ($idx$02$i$i$i$i$i<<3)|0) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $$0$i$i1$i$i$i = $42;
  }
 } while(0);
 $43 = (($this) + 24|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($inAccessor) + 20|0);
 $46 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_vii[$46 & 4095]($44,$$0$i$i1$i$i$i);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEE14handleAccessorILj555ENS_22PxRepXPropertyAccessorILj555ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $$0$i = $3;
 }
 HEAP8[$inAccessor>>0] = 1;
 $4 = (($inAccessor) + 4|0);
 HEAP32[$4>>2] = $$0$i;
 $5 = (($this) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$6>>2] = $9;
 }
 HEAP32[$temp$i$i$i>>2] = 0;
 $10 = (($this) + 36|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = HEAP32[$25>>2]|0;
  $$0$i$i$i$i$i$i = $26;
 }
 $27 = (FUNCTION_TABLE_iiii[$17 & 2047]($14,$$0$i$i$i$i$i$i,$temp$i$i$i)|0);
 $28 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i$i$i$i$i = $27 ? $28 : 0;
 $29 = ($$$i$i$i$i$i|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $$05$i$i$i = $28;$36 = $30;
 while(1) {
  $35 = $36&255;
  $37 = (_isspace($35)|0);
  $38 = ($37|0)==(0);
  $33 = (($$05$i$i$i) + 1|0);
  if ($38) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $32 = HEAP8[$33>>0]|0;
  $34 = ($32<<24>>24)==(0);
  if ($34) {
   $$0$lcssa$i$i$ph$i = $33;
   break;
  } else {
   $$05$i$i$i = $33;$36 = $32;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $39 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $39;
 $40 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $41 = ($40<<24>>24)==(0);
 L23: do {
  if ($41) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$43 = $40;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $42 = $43&255;
    $44 = (_isspace($42)|0);
    $45 = ($44|0)==(0);
    if (!($45)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L23;
    }
    $46 = HEAP32[$end$i$i$i>>2]|0;
    $47 = ($dest$03$i$i$i>>>0)<($46>>>0);
    if (!($47)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L23;
    }
    $48 = (($$14$i$i$i) + 1|0);
    $49 = HEAP8[$$14$i$i$i>>0]|0;
    $50 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $49;
    $51 = HEAP8[$48>>0]|0;
    $52 = ($51<<24>>24)==(0);
    if ($52) {
     $dest$0$lcssa$i$i$i = $50;
     break;
    } else {
     $$14$i$i$i = $48;$43 = $51;$dest$03$i$i$i = $50;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $53 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $54 = Math_fround($53);
 $55 = (($this) + 24|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($inAccessor) + 20|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_vif[$58 & 255]($56,$54);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataESA_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $0 = sp + 352|0;
 $1 = sp;
 $propVal$i$i = sp + 144|0;
 $2 = sp + 288|0;
 dest=$2+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEE15indexedPropertyILj526ES4_NS4_4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$2,519968,0);
 $64 = (($2) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj527ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj528ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = (($2) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj529ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$66,0);
 $67 = HEAP32[$41>>2]|0;
 _memcpy(($1|0),($propVal$i$i|0),144)|0;
 $68 = (($inAccessor) + 20|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vii[$69 & 4095]($67,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj527ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj528ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEE14handleAccessorILj528ENS_22PxRepXPropertyAccessorILj528ES4_jjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj529ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEE14handleAccessorILj528ENS_22PxRepXPropertyAccessorILj528ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 132;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 132)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $33 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($inAccessor) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($35,$33);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEE15indexedPropertyILj526ES4_NS4_4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($this,$0,$inProp,$theConversions,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $theConversions = $theConversions|0;
 $1 = $1|0;
 var $$09 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i6 = 0, $$phi$trans$insert3$i = 0, $$phi$trans$insert3$i3 = 0, $$pre$i = 0, $$pre$i5 = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $$pre1$i7 = 0, $$pre2$i = 0, $$pre2$i2 = 0, $$pre4$i = 0, $$pre4$i4 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $rangeStart = 0, $rangeStart$ = 0, $value$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i = sp + 4|0;
 $rangeStart = sp;
 $2 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE8pushNameEPKc($this,$2);
 HEAP32[$rangeStart>>2] = 526;
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $rangeStart$ = $5 ? $rangeStart : $4;
 $6 = HEAP32[$theConversions>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$pre$phiZ2D = $this;
 } else {
  $8 = (($this) + 24|0);
  $9 = (($inProp) + 8|0);
  $10 = (($this) + 36|0);
  $11 = (($this) + 20|0);
  $$09 = $theConversions;$12 = $6;
  while(1) {
   __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE8pushNameEPKc($this,$12);
   $13 = (($$09) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleGearsDataEE12readPropertyIfEEbRT_($this,$value$i$i$i)|0);
   if ($15) {
    $16 = HEAP32[$8>>2]|0;
    $17 = Math_fround(HEAPF32[$value$i$i$i>>2]);
    $18 = HEAP32[$9>>2]|0;
    FUNCTION_TABLE_viif[$18 & 63]($16,$14,$17);
   }
   $19 = HEAP32[$this>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    HEAP8[$10>>0] = 1;
   } else {
    $23 = (($21) + -1)|0;
    $24 = (($19) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($25) + ($23<<3)|0) + 4|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $37 = $19;$39 = $21;
    } else {
     $29 = ((($25) + ($23<<3)|0) + 5|0);
     $30 = HEAP8[$29>>0]|0;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      $37 = $19;$39 = $21;
     } else {
      $32 = HEAP32[$11>>2]|0;
      $33 = HEAP32[$32>>2]|0;
      $34 = (($33) + 40|0);
      $35 = HEAP32[$34>>2]|0;
      (FUNCTION_TABLE_ii[$35 & 4095]($32)|0);
      $$pre2$i2 = HEAP32[$this>>2]|0;
      $$phi$trans$insert3$i3 = (($$pre2$i2) + 8|0);
      $$pre4$i4 = HEAP32[$$phi$trans$insert3$i3>>2]|0;
      $37 = $$pre2$i2;$39 = $$pre4$i4;
     }
    }
    $36 = (($37) + 8|0);
    $38 = (($39) + -1)|0;
    HEAP32[$36>>2] = $38;
    $$pre$i5 = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i6 = (($$pre$i5) + 8|0);
    $$pre1$i7 = HEAP32[$$phi$trans$insert$i6>>2]|0;
    HEAP8[$10>>0] = 1;
    $40 = ($$pre1$i7|0)==(0);
    if (!($40)) {
     $41 = (($$pre1$i7) + -1)|0;
     $42 = (($$pre$i5) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ((($43) + ($41<<3)|0) + 5|0);
     $45 = HEAP8[$44>>0]|0;
     $46 = ($45<<24>>24)==(0);
     if ($46) {
      HEAP8[$10>>0] = 0;
     }
    }
   }
   $47 = HEAP32[$rangeStart$>>2]|0;
   $48 = (($47) + 1)|0;
   HEAP32[$rangeStart$>>2] = $48;
   $49 = (($$09) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $$pre$phiZ2D = $this;
    break;
   } else {
    $$09 = $49;$12 = $50;
   }
  }
 }
 $52 = HEAP32[$$pre$phiZ2D>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $56 = (($this) + 36|0);
  HEAP8[$56>>0] = 1;
  STACKTOP = sp;return;
 }
 $57 = (($54) + -1)|0;
 $58 = (($52) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59) + ($57<<3)|0) + 4|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $72 = $52;$74 = $54;
 } else {
  $63 = ((($59) + ($57<<3)|0) + 5|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = ($64<<24>>24)==(0);
  if ($65) {
   $72 = $52;$74 = $54;
  } else {
   $66 = (($this) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + 40|0);
   $70 = HEAP32[$69>>2]|0;
   (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
   $$pre2$i = HEAP32[$$pre$phiZ2D>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $72 = $$pre2$i;$74 = $$pre4$i;
  }
 }
 $71 = (($72) + 8|0);
 $73 = (($74) + -1)|0;
 HEAP32[$71>>2] = $73;
 $$pre$i = HEAP32[$$pre$phiZ2D>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $75 = (($this) + 36|0);
 HEAP8[$75>>0] = 1;
 $76 = ($$pre1$i|0)==(0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (($$pre1$i) + -1)|0;
 $78 = (($$pre$i) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 5|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if (!($82)) {
  STACKTOP = sp;return;
 }
 HEAP8[$75>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimDataNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES7_EEKNS_32PxVehicleEngineDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $1 = sp + 272|0;
 $2 = sp;
 $propVal = sp + 48|0;
 $3 = sp + 160|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8<<3)|0);
  $12 = ((($10) + ($8<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($this) + 36|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    $27 = $6;$29 = $10;$30 = 0;
   } else {
    $18 = (($this) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$11>>2]|0;
    $24 = (FUNCTION_TABLE_iii[$22 & 4095]($19,$23)|0);
    $25 = $24&1;
    HEAP8[$15>>0] = $25;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $27 = $$pre1$i;$29 = $$pre3$i;$30 = $25;
   }
   $26 = (($27) + -1)|0;
   $28 = ((($29) + ($26<<3)|0) + 5|0);
   HEAP8[$28>>0] = $30;
   $31 = HEAP8[$15>>0]|0;
   $32 = HEAP32[$this>>2]|0;
   $33 = (($32) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + -1)|0;
   $36 = (($32) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($37) + ($35<<3)|0) + 4|0);
   HEAP8[$38>>0] = $31;
  }
 }
 $39 = (($this) + 36|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($this) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($inProp) + 16|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($propVal,$43);
 $46 = (($this) + 8|0);
 $47 = HEAP32[$this>>2]|0;
 $48 = (($this) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 20|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 32|0);
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$2>>2] = $47;
 $56 = (($2) + 4|0);
 HEAP32[$56>>2] = $49;
 $57 = (($2) + 8|0);
 ;HEAP32[$57+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$46+8>>2]|0;
 $58 = (($2) + 20|0);
 HEAP32[$58>>2] = $51;
 $59 = (($2) + 24|0);
 HEAP32[$59>>2] = $propVal;
 $60 = (($2) + 28|0);
 HEAP32[$60>>2] = $53;
 $61 = (($2) + 32|0);
 HEAP32[$61>>2] = $55;
 $62 = (($2) + 36|0);
 HEAP8[$62>>0] = 1;
 $63 = (($2) + 40|0);
 HEAP32[$63>>2] = 0;
 $64 = (($2) + 44|0);
 HEAP32[$64>>2] = 0;
 $65 = (($inInfo) + 24|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEE27handleExtendedIndexPropertyILj517ES4_fjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,2,$65,$1);
 $66 = (($inInfo) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj518ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$66,0);
 $67 = (($inInfo) + 64|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj519ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$67,0);
 $68 = (($inInfo) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj520ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$68,0);
 $69 = (($inInfo) + 96|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj521ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$69,0);
 $70 = (($inInfo) + 112|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj522ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$70,0);
 $71 = (($inInfo) + 128|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj523ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$71,0);
 $72 = HEAP32[$42>>2]|0;
 $73 = (($propVal) + 64|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $74 << 3;
 _memcpy(($3|0),($propVal|0),($75|0))|0;
 $76 = (($3) + 64|0);
 HEAP32[$76>>2] = $74;
 $77 = (($3) + 80|0);
 $78 = (($propVal) + 80|0);
 ;HEAP32[$77+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$78+12>>2]|0;HEAP32[$77+16>>2]=HEAP32[$78+16>>2]|0;HEAP32[$77+20>>2]=HEAP32[$78+20>>2]|0;HEAP32[$77+24>>2]=HEAP32[$78+24>>2]|0;HEAP32[$77+28>>2]=HEAP32[$78+28>>2]|0;
 $79 = (($inProp) + 20|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($72,$3);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj518ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj519ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj520ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj521ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj522ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj523ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEE27handleExtendedIndexPropertyILj517ES4_fjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj517ES2_jfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj517ES2_jfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$0$lcssa$i$i$ph$i$i = 0, $$05$i$i$i$i = 0, $$14$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dest$0$lcssa$i$i$i$i = 0;
 var $dest$03$i$i$i$i = 0, $end$i$i$i$i = 0, $index$01 = 0, $temp$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i$i = sp + 8|0;
 $end$i$i$i$i = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$temp$i$i$i$i>>2] = $5;
 $6 = (($2) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($2) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = (($2) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = $10;
  } else {
   HEAP32[$14>>2] = $5;
   $$pre$i$i = HEAP32[$9>>2]|0;
   $17 = $$pre$i$i;
  }
  $16 = (($17) + 1)|0;
  HEAP32[$9>>2] = $16;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($2,$temp$i$i$i$i)|0);
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = ((($24) + ($22<<3)|0) + 4|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = (($this) + 36|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $41 = $20;$43 = $24;$44 = 0;
   } else {
    $32 = (($this) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$25>>2]|0;
    $38 = (FUNCTION_TABLE_iii[$36 & 4095]($33,$37)|0);
    $39 = $38&1;
    HEAP8[$29>>0] = $39;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $41 = $$pre1$i;$43 = $$pre3$i;$44 = $39;
   }
   $40 = (($41) + -1)|0;
   $42 = ((($43) + ($40<<3)|0) + 5|0);
   HEAP8[$42>>0] = $44;
   $45 = HEAP8[$29>>0]|0;
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + -1)|0;
   $50 = (($46) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51) + ($49<<3)|0) + 4|0);
   HEAP8[$52>>0] = $45;
  }
 }
 $53 = (($this) + 36|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE8pushNameEPKc($this,519928);
 $56 = HEAP8[$53>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $72 = 0;
 } else {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  $64 = $63&1;
  HEAP8[$53>>0] = $64;
  $72 = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + -1)|0;
 $69 = (($65) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70) + ($68<<3)|0) + 5|0);
 HEAP8[$71>>0] = $72;
 $73 = HEAP8[$53>>0]|0;
 $74 = HEAP32[$this>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + -1)|0;
 $78 = (($74) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 4|0);
 HEAP8[$80>>0] = $73;
 $81 = HEAP8[$53>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $83 = (($this) + 20|0);
 $84 = (($this) + 24|0);
 $85 = (($inProp) + 12|0);
 $86 = (($temp$i$i$i$i) + 255|0);
 $130 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $87 = HEAP32[$83>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 36|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 4095]($87)|0);
  $92 = ($91|0)==(0|0);
  if ($92) {
   $121 = $130;
  } else {
   $93 = HEAP8[$91>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $121 = $130;
   } else {
    $$05$i$i$i$i = $91;$99 = $93;
    while(1) {
     $98 = $99&255;
     $100 = (_isspace($98)|0);
     $101 = ($100|0)==(0);
     $96 = (($$05$i$i$i$i) + 1|0);
     if ($101) {
      $$0$lcssa$i$i$ph$i$i = $$05$i$i$i$i;
      break;
     }
     $95 = HEAP8[$96>>0]|0;
     $97 = ($95<<24>>24)==(0);
     if ($97) {
      $$0$lcssa$i$i$ph$i$i = $96;
      break;
     } else {
      $$05$i$i$i$i = $96;$99 = $95;
     }
    }
    _memset(($temp$i$i$i$i|0),0,256)|0;
    HEAP32[$end$i$i$i$i>>2] = $86;
    $102 = HEAP8[$$0$lcssa$i$i$ph$i$i>>0]|0;
    $103 = ($102<<24>>24)==(0);
    L32: do {
     if ($103) {
      $dest$0$lcssa$i$i$i$i = $temp$i$i$i$i;
     } else {
      $$14$i$i$i$i = $$0$lcssa$i$i$ph$i$i;$105 = $102;$dest$03$i$i$i$i = $temp$i$i$i$i;
      while(1) {
       $104 = $105&255;
       $106 = (_isspace($104)|0);
       $107 = ($106|0)==(0);
       if (!($107)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $108 = HEAP32[$end$i$i$i$i>>2]|0;
       $109 = ($dest$03$i$i$i$i>>>0)<($108>>>0);
       if (!($109)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $110 = (($$14$i$i$i$i) + 1|0);
       $111 = HEAP8[$$14$i$i$i$i>>0]|0;
       $112 = (($dest$03$i$i$i$i) + 1|0);
       HEAP8[$dest$03$i$i$i$i>>0] = $111;
       $113 = HEAP8[$110>>0]|0;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        $dest$0$lcssa$i$i$i$i = $112;
        break;
       } else {
        $$14$i$i$i$i = $110;$105 = $113;$dest$03$i$i$i$i = $112;
       }
      }
     }
    } while(0);
    HEAP8[$dest$0$lcssa$i$i$i$i>>0] = 0;
    $115 = (+_strtod($temp$i$i$i$i,$end$i$i$i$i));
    $116 = Math_fround($115);
    $121 = $116;
   }
  }
  $117 = HEAP32[$84>>2]|0;
  $118 = HEAP32[$85>>2]|0;
  $119 = (($118) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  FUNCTION_TABLE_viif[$120 & 63]($117,$index$01,$121);
  $122 = HEAP8[$53>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   label = 27;
   break;
  }
  $124 = (($index$01) + 1)|0;
  $125 = HEAP32[$83>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  if ($129) {
   $130 = $121;$index$01 = $124;
  } else {
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_19PxVehicleEngineDataEE17popCurrentContextEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + -1)|0;
 $6 = (($1) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12>>>0)>($9>>>0);
 if ($13) {
  $14 = (($this) + 36|0);
  $15 = (($this) + 20|0);
  $17 = $12;$21 = $10;
  while(1) {
   $16 = ($17|0)==(0);
   if ($16) {
    label = 5;
    break;
   }
   $19 = (($17) + -1)|0;
   $20 = (($21) + 4|0);
   $22 = HEAP32[$20>>2]|0;
   $23 = ((($22) + ($19<<3)|0) + 4|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if ($25) {
    $34 = $21;$36 = $17;
   } else {
    $26 = ((($22) + ($19<<3)|0) + 5|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $34 = $21;$36 = $17;
    } else {
     $29 = HEAP32[$15>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($30) + 40|0);
     $32 = HEAP32[$31>>2]|0;
     (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
     $$pre2$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
     $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
     $34 = $$pre2$i;$36 = $$pre4$i;
    }
   }
   $33 = (($34) + 8|0);
   $35 = (($36) + -1)|0;
   HEAP32[$33>>2] = $35;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   HEAP8[$14>>0] = 1;
   $37 = ($$pre1$i|0)==(0);
   if ($37) {
    break;
   }
   $38 = (($$pre1$i) + -1)|0;
   $39 = (($$pre$i) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($40) + ($38<<3)|0) + 5|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    HEAP8[$14>>0] = 0;
   }
   $18 = ($$pre1$i>>>0)>($9>>>0);
   if ($18) {
    $17 = $$pre1$i;$21 = $$pre$i;
   } else {
    break;
   }
  }
  if ((label|0) == 5) {
   HEAP8[$14>>0] = 1;
  }
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
  $45 = $$pre;$47 = $$pre1;
 } else {
  $45 = $1;$47 = $3;
 }
 $44 = (($45) + 8|0);
 $46 = (($47) + -1)|0;
 HEAP32[$44>>2] = $46;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDriveNWEEEEclILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 112;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 112)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 _memset(($1|0),0,296)|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES7_EEKNS_34PxVehicleDriveDynDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES7_EEKNS_34PxVehicleDriveDynDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, $propVal$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $propVal$byval_copy = sp + 96|0;
 $propVal = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($this) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($inProp) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vii[$42 & 4095]($propVal,$40);
 $43 = (($this) + 8|0);
 $44 = HEAP32[$this>>2]|0;
 $45 = (($this) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 20|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 28|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 32|0);
 $52 = HEAP32[$51>>2]|0;
 HEAP32[$propVal$byval_copy>>2] = $44;
 $53 = (($propVal$byval_copy) + 4|0);
 HEAP32[$53>>2] = $46;
 $54 = (($propVal$byval_copy) + 8|0);
 ;HEAP32[$54+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$43+8>>2]|0;
 $55 = (($propVal$byval_copy) + 20|0);
 HEAP32[$55>>2] = $48;
 $56 = (($propVal$byval_copy) + 24|0);
 HEAP32[$56>>2] = $propVal;
 $57 = (($propVal$byval_copy) + 28|0);
 HEAP32[$57>>2] = $50;
 $58 = (($propVal$byval_copy) + 32|0);
 HEAP32[$58>>2] = $52;
 $59 = (($propVal$byval_copy) + 36|0);
 HEAP8[$59>>0] = 1;
 $60 = (($propVal$byval_copy) + 40|0);
 HEAP32[$60>>2] = 0;
 $61 = (($propVal$byval_copy) + 44|0);
 HEAP32[$61>>2] = 0;
 (__ZNK5physx34PxVehicleDriveDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEEEEjT_j($inInfo,$propVal$byval_copy,0)|0);
 $62 = HEAP32[$39>>2]|0;
 $63 = (($inProp) + 20|0);
 $64 = HEAP32[$63>>2]|0;
 dest=$propVal$byval_copy+0|0; src=$propVal+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$64 & 4095]($62,$propVal$byval_copy);
 STACKTOP = sp;return;
}
function __ZNK5physx34PxVehicleDriveDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP8[$0>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE27handleExtendedIndexPropertyILj635ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($inOperator,$inStartIndex,$this,$0);
 $1 = (($this) + 24|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj636ES3_KbbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$1,0);
 $2 = (($this) + 40|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj637ES3_KbbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$2,0);
 $3 = (($this) + 56|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj638ES3_KbbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$3,0);
 $4 = (($this) + 72|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj639ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$4,0);
 $5 = (($this) + 88|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj640ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$5,0);
 $6 = (($this) + 104|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj641ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$6,0);
 $7 = (($this) + 120|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj642ES3_KjjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$7,0);
 $8 = (($this) + 136|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj643ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$8,0);
 $9 = (($this) + 152|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj644ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$9,0);
 $10 = (($this) + 168|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj645ES3_bbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$10,0);
 $11 = (($this) + 184|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj646ES3_bbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$11,0);
 $12 = (($this) + 200|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj647ES3_bbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$12,0);
 $13 = (($this) + 216|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj648ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$13,0);
 $14 = (($this) + 232|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj649ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$14,0);
 $15 = (($this) + 248|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj650ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$15,0);
 $16 = (($this) + 264|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj651ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$16,0);
 $17 = (($this) + 280|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj652ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($inOperator,$17,0);
 $18 = (($inStartIndex) + 18)|0;
 STACKTOP = sp;return ($18|0);
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj636ES3_KbbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 HEAP32[$value$i$i$i$i$i$i>>2] = 0;
 $9 = (($this) + 36|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $$pre$phiZ2D = $this;
 } else {
  $12 = (($this) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$this>>2]|0;
  $18 = (($17) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0);
  if ($20) {
   $$0$i$i$i$i$i$i$i = 519936;
  } else {
   $21 = (($19) + -1)|0;
   $22 = (($17) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + ($21<<3)|0);
   $25 = HEAP32[$24>>2]|0;
   $$0$i$i$i$i$i$i$i = $25;
  }
  $26 = (FUNCTION_TABLE_iiii[$16 & 2047]($13,$$0$i$i$i$i$i$i$i,$value$i$i$i$i$i$i)|0);
  $27 = HEAP32[$value$i$i$i$i$i$i>>2]|0;
  $$$i$i$i$i$i$i = $26 ? $27 : 0;
  $28 = ($$$i$i$i$i$i$i|0)==(0|0);
  if ($28) {
   $$pre$phiZ2D = $this;
  } else {
   $29 = HEAP8[$$$i$i$i$i$i$i>>0]|0;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $$pre$phiZ2D = $this;
   } else {
    $31 = (_strcasecmp($$$i$i$i$i$i$i,520728)|0);
    $32 = ($31|0)==(0);
    $33 = (($this) + 24|0);
    $34 = HEAP32[$33>>2]|0;
    FUNCTION_TABLE_vii[$2 & 4095]($34,$32);
    $$pre$phiZ2D = $this;
   }
  }
 }
 $35 = HEAP32[$$pre$phiZ2D>>2]|0;
 $36 = (($35) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  HEAP8[$9>>0] = 1;
  STACKTOP = sp;return;
 }
 $39 = (($37) + -1)|0;
 $40 = (($35) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 4|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if ($44) {
  $54 = $35;$56 = $37;
 } else {
  $45 = ((($41) + ($39<<3)|0) + 5|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   $54 = $35;$56 = $37;
  } else {
   $48 = (($this) + 20|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($50) + 40|0);
   $52 = HEAP32[$51>>2]|0;
   (FUNCTION_TABLE_ii[$52 & 4095]($49)|0);
   $$pre2$i = HEAP32[$$pre$phiZ2D>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $54 = $$pre2$i;$56 = $$pre4$i;
  }
 }
 $53 = (($54) + 8|0);
 $55 = (($56) + -1)|0;
 HEAP32[$53>>2] = $55;
 $$pre$i = HEAP32[$$pre$phiZ2D>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 HEAP8[$9>>0] = 1;
 $57 = ($$pre1$i|0)==(0);
 if ($57) {
  STACKTOP = sp;return;
 }
 $58 = (($$pre1$i) + -1)|0;
 $59 = (($$pre$i) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($60) + ($58<<3)|0) + 5|0);
 $62 = HEAP8[$61>>0]|0;
 $63 = ($62<<24>>24)==(0);
 if (!($63)) {
  STACKTOP = sp;return;
 }
 HEAP8[$9>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj637ES3_KbbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj637ENS_22PxRepXPropertyAccessorILj637ES4_KbbEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj638ES3_KbbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj638ENS_22PxRepXPropertyAccessorILj638ES4_KbbEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj639ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj639ENS_22PxRepXPropertyAccessorILj639ES4_jjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj640ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj640ENS_22PxRepXPropertyAccessorILj640ES4_jjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj641ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj642ES3_KjjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj642ENS_22PxRepXPropertyAccessorILj642ES4_KjjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj643ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj644ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj645ES3_bbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj645ENS_22PxRepXPropertyAccessorILj645ES4_bbEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj646ES3_bbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj646ENS_22PxRepXPropertyAccessorILj646ES4_bbEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj647ES3_bbEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj647ENS_22PxRepXPropertyAccessorILj647ES4_bbEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj648ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj648ENS_22PxRepXPropertyAccessorILj648ES4_jjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj649ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj649ENS_22PxRepXPropertyAccessorILj649ES4_jjEEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj650ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj651ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEclILj652ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj649ENS_22PxRepXPropertyAccessorILj649ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 36;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 36)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $33 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($inAccessor) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($35,$33);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj648ENS_22PxRepXPropertyAccessorILj648ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 32;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 32)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $33 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($inAccessor) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($35,$33);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj647ENS_22PxRepXPropertyAccessorILj647ES4_bbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 30;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 30)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (_strcasecmp($$$i$i$i$i$i,520728)|0);
 $34 = ($33|0)==(0);
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($inAccessor) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($36,$34);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj646ENS_22PxRepXPropertyAccessorILj646ES4_bbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 29;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 29)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (_strcasecmp($$$i$i$i$i$i,520728)|0);
 $34 = ($33|0)==(0);
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($inAccessor) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($36,$34);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj645ENS_22PxRepXPropertyAccessorILj645ES4_bbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 28;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (_strcasecmp($$$i$i$i$i$i,520728)|0);
 $34 = ($33|0)==(0);
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($inAccessor) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($36,$34);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj642ENS_22PxRepXPropertyAccessorILj642ES4_KjjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 16;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 16)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $33 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($inAccessor) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($35,$33);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj640ENS_22PxRepXPropertyAccessorILj640ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $33 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($inAccessor) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($35,$33);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj639ENS_22PxRepXPropertyAccessorILj639ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theValue$i$i$i$i$i = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theValue$i$i$i$i$i = sp + 4|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 4;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 4)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$theValue$i$i$i$i$i>>2] = $$$i$i$i$i$i;
 $33 = (_strtoul($$$i$i$i$i$i,$theValue$i$i$i$i$i,10)|0);
 $34 = (($this) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($inAccessor) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($35,$33);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj638ENS_22PxRepXPropertyAccessorILj638ES4_KbbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 2;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 2)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (_strcasecmp($$$i$i$i$i$i,520728)|0);
 $34 = ($33|0)==(0);
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($inAccessor) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($36,$34);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj637ENS_22PxRepXPropertyAccessorILj637ES4_KbbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $value$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 1;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 1)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i$i,$value$i$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i$i>>2]|0;
 $$$i$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (_strcasecmp($$$i$i$i$i$i,520728)|0);
 $34 = ($33|0)==(0);
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($inAccessor) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($36,$34);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEE27handleExtendedIndexPropertyILj635ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($this,$inIndex,$inProp,$inInfo) {
 $this = $this|0;
 $inIndex = $inIndex|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theAccessor = sp;
 $0 = HEAP32[$inProp>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,$0);
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 HEAP32[$2>>2] = $inIndex;
 $3 = (($theAccessor) + 12|0);
 HEAP32[$3>>2] = $inProp;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj635ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$inInfo);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj635ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$0$lcssa$i$i$ph$i$i = 0, $$05$i$i$i$i = 0, $$14$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dest$0$lcssa$i$i$i$i = 0;
 var $dest$03$i$i$i$i = 0, $end$i$i$i$i = 0, $index$01 = 0, $temp$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i$i = sp + 8|0;
 $end$i$i$i$i = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$temp$i$i$i$i>>2] = $5;
 $6 = (($2) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = (($2) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  $12 = (($2) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = $10;
  } else {
   HEAP32[$14>>2] = $5;
   $$pre$i$i = HEAP32[$9>>2]|0;
   $17 = $$pre$i$i;
  }
  $16 = (($17) + 1)|0;
  HEAP32[$9>>2] = $16;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS_7profile26WrapperReflectionAllocatorIjEEE15growAndPushBackERKj($2,$temp$i$i$i$i)|0);
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = (($20) + -1)|0;
  $23 = (($18) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22<<3)|0);
  $26 = ((($24) + ($22<<3)|0) + 4|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $29 = (($this) + 36|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $41 = $20;$43 = $24;$44 = 0;
   } else {
    $32 = (($this) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$25>>2]|0;
    $38 = (FUNCTION_TABLE_iii[$36 & 4095]($33,$37)|0);
    $39 = $38&1;
    HEAP8[$29>>0] = $39;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $41 = $$pre1$i;$43 = $$pre3$i;$44 = $39;
   }
   $40 = (($41) + -1)|0;
   $42 = ((($43) + ($40<<3)|0) + 5|0);
   HEAP8[$42>>0] = $44;
   $45 = HEAP8[$29>>0]|0;
   $46 = HEAP32[$this>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + -1)|0;
   $50 = (($46) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51) + ($49<<3)|0) + 4|0);
   HEAP8[$52>>0] = $45;
  }
 }
 $53 = (($this) + 36|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE8pushNameEPKc($this,519928);
 $56 = HEAP8[$53>>0]|0;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $72 = 0;
 } else {
  $58 = (($this) + 20|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 20|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  $64 = $63&1;
  HEAP8[$53>>0] = $64;
  $72 = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + -1)|0;
 $69 = (($65) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70) + ($68<<3)|0) + 5|0);
 HEAP8[$71>>0] = $72;
 $73 = HEAP8[$53>>0]|0;
 $74 = HEAP32[$this>>2]|0;
 $75 = (($74) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + -1)|0;
 $78 = (($74) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ((($79) + ($77<<3)|0) + 4|0);
 HEAP8[$80>>0] = $73;
 $81 = HEAP8[$53>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
 $83 = (($this) + 20|0);
 $84 = (($this) + 24|0);
 $85 = (($inProp) + 12|0);
 $86 = (($temp$i$i$i$i) + 255|0);
 $130 = Math_fround(0.0);$index$01 = 0;
 while(1) {
  $87 = HEAP32[$83>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 36|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (FUNCTION_TABLE_ii[$90 & 4095]($87)|0);
  $92 = ($91|0)==(0|0);
  if ($92) {
   $121 = $130;
  } else {
   $93 = HEAP8[$91>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $121 = $130;
   } else {
    $$05$i$i$i$i = $91;$99 = $93;
    while(1) {
     $98 = $99&255;
     $100 = (_isspace($98)|0);
     $101 = ($100|0)==(0);
     $96 = (($$05$i$i$i$i) + 1|0);
     if ($101) {
      $$0$lcssa$i$i$ph$i$i = $$05$i$i$i$i;
      break;
     }
     $95 = HEAP8[$96>>0]|0;
     $97 = ($95<<24>>24)==(0);
     if ($97) {
      $$0$lcssa$i$i$ph$i$i = $96;
      break;
     } else {
      $$05$i$i$i$i = $96;$99 = $95;
     }
    }
    _memset(($temp$i$i$i$i|0),0,256)|0;
    HEAP32[$end$i$i$i$i>>2] = $86;
    $102 = HEAP8[$$0$lcssa$i$i$ph$i$i>>0]|0;
    $103 = ($102<<24>>24)==(0);
    L32: do {
     if ($103) {
      $dest$0$lcssa$i$i$i$i = $temp$i$i$i$i;
     } else {
      $$14$i$i$i$i = $$0$lcssa$i$i$ph$i$i;$105 = $102;$dest$03$i$i$i$i = $temp$i$i$i$i;
      while(1) {
       $104 = $105&255;
       $106 = (_isspace($104)|0);
       $107 = ($106|0)==(0);
       if (!($107)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $108 = HEAP32[$end$i$i$i$i>>2]|0;
       $109 = ($dest$03$i$i$i$i>>>0)<($108>>>0);
       if (!($109)) {
        $dest$0$lcssa$i$i$i$i = $dest$03$i$i$i$i;
        break L32;
       }
       $110 = (($$14$i$i$i$i) + 1|0);
       $111 = HEAP8[$$14$i$i$i$i>>0]|0;
       $112 = (($dest$03$i$i$i$i) + 1|0);
       HEAP8[$dest$03$i$i$i$i>>0] = $111;
       $113 = HEAP8[$110>>0]|0;
       $114 = ($113<<24>>24)==(0);
       if ($114) {
        $dest$0$lcssa$i$i$i$i = $112;
        break;
       } else {
        $$14$i$i$i$i = $110;$105 = $113;$dest$03$i$i$i$i = $112;
       }
      }
     }
    } while(0);
    HEAP8[$dest$0$lcssa$i$i$i$i>>0] = 0;
    $115 = (+_strtod($temp$i$i$i$i,$end$i$i$i$i));
    $116 = Math_fround($115);
    $121 = $116;
   }
  }
  $117 = HEAP32[$84>>2]|0;
  $118 = HEAP32[$85>>2]|0;
  $119 = (($118) + 8|0);
  $120 = HEAP32[$119>>2]|0;
  FUNCTION_TABLE_viif[$120 & 63]($117,$index$01,$121);
  $122 = HEAP8[$53>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   label = 27;
   break;
  }
  $124 = (($index$01) + 1)|0;
  $125 = HEAP32[$83>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  if ($129) {
   $130 = $121;$index$01 = $124;
  } else {
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE17popCurrentContextEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveDynDataEE17popCurrentContextEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + -1)|0;
 $6 = (($1) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12>>>0)>($9>>>0);
 if ($13) {
  $14 = (($this) + 36|0);
  $15 = (($this) + 20|0);
  $17 = $12;$21 = $10;
  while(1) {
   $16 = ($17|0)==(0);
   if ($16) {
    label = 5;
    break;
   }
   $19 = (($17) + -1)|0;
   $20 = (($21) + 4|0);
   $22 = HEAP32[$20>>2]|0;
   $23 = ((($22) + ($19<<3)|0) + 4|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if ($25) {
    $34 = $21;$36 = $17;
   } else {
    $26 = ((($22) + ($19<<3)|0) + 5|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $34 = $21;$36 = $17;
    } else {
     $29 = HEAP32[$15>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($30) + 40|0);
     $32 = HEAP32[$31>>2]|0;
     (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
     $$pre2$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
     $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
     $34 = $$pre2$i;$36 = $$pre4$i;
    }
   }
   $33 = (($34) + 8|0);
   $35 = (($36) + -1)|0;
   HEAP32[$33>>2] = $35;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   HEAP8[$14>>0] = 1;
   $37 = ($$pre1$i|0)==(0);
   if ($37) {
    break;
   }
   $38 = (($$pre1$i) + -1)|0;
   $39 = (($$pre$i) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ((($40) + ($38<<3)|0) + 5|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    HEAP8[$14>>0] = 0;
   }
   $18 = ($$pre1$i>>>0)>($9>>>0);
   if ($18) {
    $17 = $$pre1$i;$21 = $$pre$i;
   } else {
    break;
   }
  }
  if ((label|0) == 5) {
   HEAP8[$14>>0] = 1;
  }
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
  $45 = $$pre;$47 = $$pre1;
 } else {
  $45 = $1;$47 = $3;
 }
 $44 = (($45) + 8|0);
 $46 = (($47) + -1)|0;
 HEAP32[$44>>2] = $46;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDriveNWEEEEclILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 12;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 12)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 _memset(($1|0),0,256)|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES7_EEKNS_35PxVehicleWheelsSimDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDriveNWEEEEclILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 76;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 76)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 dest=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES7_EEKNS_35PxVehicleWheelsDynDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES7_EEKNS_35PxVehicleWheelsDynDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $1 = sp + 80|0;
 $2 = sp;
 $propVal = sp + 48|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inProp) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$2>>2] = $46;
 $55 = (($2) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($2) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($2) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($2) + 24|0);
 HEAP32[$58>>2] = $propVal;
 $59 = (($2) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($2) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($2) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($2) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($2) + 44|0);
 HEAP32[$63>>2] = 0;
 $64 = (($inInfo) + 12|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj623ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,1,$64,$1);
 $65 = (($inInfo) + 36|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj624ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,2,$65,$1);
 $66 = HEAP32[$41>>2]|0;
 $67 = (($inProp) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$propVal+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$propVal+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$propVal+24>>2]|0;HEAP32[$1+28>>2]=HEAP32[$propVal+28>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDriveNWEE15complexPropertyINS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES7_EEKNS_35PxVehicleWheelsSimDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $1 = sp + 64|0;
 $propVal = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($4) + -1)|0;
  $7 = (($2) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($6<<3)|0);
  $10 = ((($8) + ($6<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($this) + 36|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $25 = $4;$27 = $8;$28 = 0;
   } else {
    $16 = (($this) + 20|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$9>>2]|0;
    $22 = (FUNCTION_TABLE_iii[$20 & 4095]($17,$21)|0);
    $23 = $22&1;
    HEAP8[$13>>0] = $23;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $25 = $$pre1$i;$27 = $$pre3$i;$28 = $23;
   }
   $24 = (($25) + -1)|0;
   $26 = ((($27) + ($24<<3)|0) + 5|0);
   HEAP8[$26>>0] = $28;
   $29 = HEAP8[$13>>0]|0;
   $30 = HEAP32[$this>>2]|0;
   $31 = (($30) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + -1)|0;
   $34 = (($30) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35) + ($33<<3)|0) + 4|0);
   HEAP8[$36>>0] = $29;
  }
 }
 $37 = (($this) + 36|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($inProp) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 FUNCTION_TABLE_vii[$43 & 4095]($propVal,$41);
 $44 = (($this) + 8|0);
 $45 = HEAP32[$this>>2]|0;
 $46 = (($this) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($this) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 28|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 32|0);
 $53 = HEAP32[$52>>2]|0;
 HEAP32[$1>>2] = $45;
 $54 = (($1) + 4|0);
 HEAP32[$54>>2] = $47;
 $55 = (($1) + 8|0);
 ;HEAP32[$55+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$44+8>>2]|0;
 $56 = (($1) + 20|0);
 HEAP32[$56>>2] = $49;
 $57 = (($1) + 24|0);
 HEAP32[$57>>2] = $propVal;
 $58 = (($1) + 28|0);
 HEAP32[$58>>2] = $51;
 $59 = (($1) + 32|0);
 HEAP32[$59>>2] = $53;
 $60 = (($1) + 36|0);
 HEAP8[$60>>0] = 1;
 $61 = (($1) + 40|0);
 HEAP32[$61>>2] = 0;
 $62 = (($1) + 44|0);
 HEAP32[$62>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($inInfo,$1,0)|0);
 $63 = HEAP32[$40>>2]|0;
 $64 = (($inProp) + 20|0);
 $65 = HEAP32[$64>>2]|0;
 dest=$1+0|0; src=$propVal+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$65 & 4095]($63,$1);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXSerializerImplINS_18PxVehicleDriveTankEE11getTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (519472|0);
}
function __ZN5physx18RepXSerializerImplINS_18PxVehicleDriveTankEE12objectToFileERKNS_12PxRepXObjectEPNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE($this,$inLiveObject,$inCollection,$inWriter,$inTempBuffer,$inArgs) {
 $this = $this|0;
 $inLiveObject = $inLiveObject|0;
 $inCollection = $inCollection|0;
 $inWriter = $inWriter|0;
 $inTempBuffer = $inTempBuffer|0;
 $inArgs = $inArgs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inLiveObject) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiiiii[$4 & 255]($this,$1,$inCollection,$inWriter,$inTempBuffer,$inArgs);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXSerializerImplINS_18PxVehicleDriveTankEE16fileToObjectImplEPS1_RNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE($this,$inObj,$inReader,$inAllocator,$inArgs,$inCollection) {
 $this = $this|0;
 $inObj = $inObj|0;
 $inReader = $inReader|0;
 $inAllocator = $inAllocator|0;
 $inArgs = $inArgs|0;
 $inCollection = $inCollection|0;
 var $inArgs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $inArgs$byval_copy = sp;
 ;HEAP32[$inArgs$byval_copy+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy+8>>2]=HEAP32[$inArgs+8>>2]|0;
 __ZN5physx2Sn17readAllPropertiesINS_18PxVehicleDriveTankEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy,$inReader,$inObj,$inAllocator,$inCollection);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn17readAllPropertiesINS_18PxVehicleDriveTankEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($args,$reader,$obj,$alloc,$collection) {
 $args = $args|0;
 $reader = $reader|0;
 $obj = $obj|0;
 $alloc = $alloc|0;
 $collection = $collection|0;
 var $$sroa$2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $contexts = 0, $info = 0, $names = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $wrapper = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $0 = sp + 304|0;
 $1 = sp + 256|0;
 $$sroa$2$i = sp;
 $2 = sp + 208|0;
 $3 = sp + 16|0;
 $wrapper = sp + 188|0;
 $names = sp + 32|0;
 $contexts = sp + 192|0;
 $info = sp + 48|0;
 $4 = HEAP32[$alloc>>2]|0;
 $5 = (($4) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($alloc)|0);
 HEAP32[$wrapper>>2] = $7;
 HEAP32[$names>>2] = $wrapper;
 $8 = (($names) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($names) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($names) + 12|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$contexts>>2] = $wrapper;
 $11 = (($contexts) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($contexts) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = (($contexts) + 12|0);
 HEAP32[$13>>2] = 0;
 __ZN5physx31PxVehicleDriveTankGeneratedInfoC2Ev($info);
 ;HEAP32[$3+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$args+8>>2]|0;
 ;HEAP32[$$sroa$2$i+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$sroa$2$i+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$sroa$2$i+8>>2]=HEAP32[$3+8>>2]|0;
 HEAP32[$0>>2] = $names;
 $14 = (($0) + 4|0);
 HEAP32[$14>>2] = $contexts;
 $15 = (($0) + 8|0);
 ;HEAP32[$15+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$3+8>>2]|0;
 $16 = (($0) + 20|0);
 HEAP32[$16>>2] = $reader;
 $17 = (($0) + 24|0);
 HEAP32[$17>>2] = $obj;
 $18 = (($0) + 28|0);
 HEAP32[$18>>2] = $alloc;
 $19 = (($0) + 32|0);
 HEAP32[$19>>2] = $collection;
 $20 = (($0) + 36|0);
 HEAP8[$20>>0] = 1;
 $21 = (($0) + 40|0);
 HEAP32[$21>>2] = 0;
 $22 = (($0) + 44|0);
 HEAP32[$22>>2] = 0;
 $23 = (($info) + 36|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$23,0);
 $24 = (($info) + 52|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$24,0);
 HEAP32[$1>>2] = $names;
 $25 = (($1) + 4|0);
 HEAP32[$25>>2] = $contexts;
 $26 = (($1) + 8|0);
 ;HEAP32[$26+0>>2]=HEAP32[$$sroa$2$i+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$$sroa$2$i+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$$sroa$2$i+8>>2]|0;
 $27 = (($1) + 20|0);
 HEAP32[$27>>2] = $reader;
 $28 = (($1) + 24|0);
 HEAP32[$28>>2] = $obj;
 $29 = (($1) + 28|0);
 HEAP32[$29>>2] = $alloc;
 $30 = (($1) + 32|0);
 HEAP32[$30>>2] = $collection;
 $31 = (($1) + 36|0);
 HEAP8[$31>>0] = 1;
 $32 = (($1) + 40|0);
 HEAP32[$32>>2] = 0;
 $33 = (($1) + 44|0);
 HEAP32[$33>>2] = 0;
 $34 = (($info) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$34,0);
 HEAP32[$2>>2] = $names;
 $35 = (($2) + 4|0);
 HEAP32[$35>>2] = $contexts;
 $36 = (($2) + 8|0);
 ;HEAP32[$36+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$args+8>>2]|0;
 $37 = (($2) + 20|0);
 HEAP32[$37>>2] = $reader;
 $38 = (($2) + 24|0);
 HEAP32[$38>>2] = $obj;
 $39 = (($2) + 28|0);
 HEAP32[$39>>2] = $alloc;
 $40 = (($2) + 32|0);
 HEAP32[$40>>2] = $collection;
 $41 = (($2) + 36|0);
 HEAP8[$41>>0] = 1;
 $42 = (($2) + 40|0);
 HEAP32[$42>>2] = 0;
 $43 = (($2) + 44|0);
 HEAP32[$43>>2] = 0;
 $44 = (($info) + 96|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj673ES3_KNS_30PxVehicleDriveTankControlModel4EnumES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$44,0);
 $45 = (($info) + 124|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj675ES3_NS_21PxVehicleDriveSimDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$45,0);
 $46 = HEAP32[$13>>2]|0;
 $47 = $46 & 2147483647;
 $48 = ($47|0)!=(0);
 $49 = ($46|0)>(-1);
 $or$cond$i$i$i1 = $48 & $49;
 if ($or$cond$i$i$i1) {
  $50 = HEAP32[$11>>2]|0;
  $51 = ($50|0)==(0|0);
  if (!($51)) {
   $52 = HEAP32[$contexts>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 12|0);
   $56 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vii[$56 & 4095]($53,$50);
  }
 }
 $57 = HEAP32[$10>>2]|0;
 $58 = $57 & 2147483647;
 $59 = ($58|0)!=(0);
 $60 = ($57|0)>(-1);
 $or$cond$i$i$i = $59 & $60;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $61 = HEAP32[$8>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = HEAP32[$names>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + 12|0);
 $67 = HEAP32[$66>>2]|0;
 FUNCTION_TABLE_vii[$67 & 4095]($64,$61);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj673ES3_KNS_30PxVehicleDriveTankControlModel4EnumES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEE14handleAccessorILj673ENS_22PxRepXPropertyAccessorILj673ES4_KNS_30PxVehicleDriveTankControlModel4EnumESA_EEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj675ES3_NS_21PxVehicleDriveSimDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 216;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 216)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 dest=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx34PxVehicleDriveSimDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE15complexPropertyINS_22PxRepXPropertyAccessorILj675ES2_NS_21PxVehicleDriveSimDataES6_EEKNS_34PxVehicleDriveSimDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE15complexPropertyINS_22PxRepXPropertyAccessorILj675ES2_NS_21PxVehicleDriveSimDataES6_EEKNS_34PxVehicleDriveSimDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2112|0;
 $1 = sp + 1584|0;
 $2 = sp;
 $propVal = sp + 528|0;
 $3 = sp + 1056|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8<<3)|0);
  $12 = ((($10) + ($8<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($this) + 36|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    $27 = $6;$29 = $10;$30 = 0;
   } else {
    $18 = (($this) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$11>>2]|0;
    $24 = (FUNCTION_TABLE_iii[$22 & 4095]($19,$23)|0);
    $25 = $24&1;
    HEAP8[$15>>0] = $25;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $27 = $$pre1$i;$29 = $$pre3$i;$30 = $25;
   }
   $26 = (($27) + -1)|0;
   $28 = ((($29) + ($26<<3)|0) + 5|0);
   HEAP8[$28>>0] = $30;
   $31 = HEAP8[$15>>0]|0;
   $32 = HEAP32[$this>>2]|0;
   $33 = (($32) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + -1)|0;
   $36 = (($32) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($37) + ($35<<3)|0) + 4|0);
   HEAP8[$38>>0] = $31;
  }
 }
 $39 = (($this) + 36|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($this) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($inProp) + 16|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($propVal,$43);
 $46 = (($this) + 8|0);
 $47 = HEAP32[$this>>2]|0;
 $48 = (($this) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 20|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 32|0);
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$1>>2] = $47;
 $56 = (($1) + 4|0);
 HEAP32[$56>>2] = $49;
 $57 = (($1) + 8|0);
 ;HEAP32[$57+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$46+8>>2]|0;
 $58 = (($1) + 20|0);
 HEAP32[$58>>2] = $51;
 $59 = (($1) + 24|0);
 HEAP32[$59>>2] = $propVal;
 $60 = (($1) + 28|0);
 HEAP32[$60>>2] = $53;
 $61 = (($1) + 32|0);
 HEAP32[$61>>2] = $55;
 $62 = (($1) + 36|0);
 HEAP8[$62>>0] = 1;
 $63 = (($1) + 40|0);
 HEAP32[$63>>2] = 0;
 $64 = (($1) + 44|0);
 HEAP32[$64>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEEclILj655ES3_RKNS_19PxVehicleEngineDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$inInfo,0);
 $65 = (($inInfo) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEEclILj656ES3_RKNS_18PxVehicleGearsDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$65,0);
 $66 = (($inInfo) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEEclILj657ES3_RKNS_19PxVehicleClutchDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$66,0);
 $67 = (($inInfo) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEEclILj658ES3_RKNS_20PxVehicleAutoBoxDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$67,0);
 $68 = HEAP32[$42>>2]|0;
 $69 = (($propVal) + 64|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = $70 << 3;
 _memcpy(($3|0),($propVal|0),($71|0))|0;
 $72 = (($3) + 64|0);
 HEAP32[$72>>2] = $70;
 $73 = (($3) + 80|0);
 $74 = (($propVal) + 80|0);
 ;HEAP32[$73+0>>2]=HEAP32[$74+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$74+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$74+12>>2]|0;HEAP32[$73+16>>2]=HEAP32[$74+16>>2]|0;HEAP32[$73+20>>2]=HEAP32[$74+20>>2]|0;HEAP32[$73+24>>2]=HEAP32[$74+24>>2]|0;HEAP32[$73+28>>2]=HEAP32[$74+28>>2]|0;
 $75 = (($3) + 112|0);
 $76 = (($propVal) + 112|0);
 _memcpy(($75|0),($76|0),416)|0;
 _memcpy(($2|0),($3|0),($71|0))|0;
 $77 = (($2) + 64|0);
 HEAP32[$77>>2] = $70;
 $78 = (($2) + 80|0);
 ;HEAP32[$78+0>>2]=HEAP32[$74+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$74+8>>2]|0;HEAP32[$78+12>>2]=HEAP32[$74+12>>2]|0;HEAP32[$78+16>>2]=HEAP32[$74+16>>2]|0;HEAP32[$78+20>>2]=HEAP32[$74+20>>2]|0;HEAP32[$78+24>>2]=HEAP32[$74+24>>2]|0;HEAP32[$78+28>>2]=HEAP32[$74+28>>2]|0;
 $79 = (($2) + 112|0);
 _memcpy(($79|0),($76|0),416)|0;
 $80 = (($inProp) + 20|0);
 $81 = HEAP32[$80>>2]|0;
 _memcpy(($1|0),($2|0),($71|0))|0;
 $82 = (($1) + 64|0);
 HEAP32[$82>>2] = $70;
 $83 = (($1) + 80|0);
 ;HEAP32[$83+0>>2]=HEAP32[$74+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$74+8>>2]|0;HEAP32[$83+12>>2]=HEAP32[$74+12>>2]|0;HEAP32[$83+16>>2]=HEAP32[$74+16>>2]|0;HEAP32[$83+20>>2]=HEAP32[$74+20>>2]|0;HEAP32[$83+24>>2]=HEAP32[$74+24>>2]|0;HEAP32[$83+28>>2]=HEAP32[$74+28>>2]|0;
 $84 = (($1) + 112|0);
 _memcpy(($84|0),($76|0),416)|0;
 FUNCTION_TABLE_vii[$81 & 4095]($68,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEEclILj655ES3_RKNS_19PxVehicleEngineDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveSimDataEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 0;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
 }
 _memset(($1|0),0,144)|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveSimDataEE15complexPropertyINS_22PxRepXPropertyAccessorILj655ES2_RKNS_19PxVehicleEngineDataES6_EEKNS_32PxVehicleEngineDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEEclILj656ES3_RKNS_18PxVehicleGearsDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveSimDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 112;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 112)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 656;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ES4_RKNS_18PxVehicleGearsDataES9_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEEclILj657ES3_RKNS_19PxVehicleClutchDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveSimDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 256;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 256)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 657;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ES4_RKNS_19PxVehicleClutchDataES9_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEEclILj658ES3_RKNS_20PxVehicleAutoBoxDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveSimDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 272;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 272)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 658;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ES4_RKNS_20PxVehicleAutoBoxDataES9_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveSimDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ES4_RKNS_20PxVehicleAutoBoxDataES9_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $0 = sp + 560|0;
 $1 = sp;
 $propVal$i$i = sp + 256|0;
 $2 = sp + 512|0;
 dest=$2+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEEclILj532ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$2,0);
 $64 = (($2) + 16|0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj533ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$64,519968,0);
 $65 = (($2) + 32|0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj534ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$65,519968,0);
 $66 = HEAP32[$41>>2]|0;
 _memcpy(($1|0),($propVal$i$i|0),256)|0;
 $67 = (($inAccessor) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ES4_RKNS_19PxVehicleClutchDataES9_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 80|0;
 $1 = sp;
 $propVal$i$i = sp + 16|0;
 $2 = sp + 32|0;
 dest=$2+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj555ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$2,0);
 $64 = (($2) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj556ES3_NS_27PxVehicleClutchAccuracyMode4EnumES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj557ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = HEAP32[$41>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal$i$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal$i$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal$i$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal$i$i+12>>2]|0;
 $67 = (($inAccessor) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ES4_RKNS_18PxVehicleGearsDataES9_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $0 = sp + 352|0;
 $1 = sp;
 $propVal$i$i = sp + 144|0;
 $2 = sp + 288|0;
 dest=$2+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEE15indexedPropertyILj526ES4_NS4_4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$2,519968,0);
 $64 = (($2) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj527ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj528ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = (($2) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj529ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$66,0);
 $67 = HEAP32[$41>>2]|0;
 _memcpy(($1|0),($propVal$i$i|0),144)|0;
 $68 = (($inAccessor) + 20|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vii[$69 & 4095]($67,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_21PxVehicleDriveSimDataEE15complexPropertyINS_22PxRepXPropertyAccessorILj655ES2_RKNS_19PxVehicleEngineDataES6_EEKNS_32PxVehicleEngineDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $1 = sp + 272|0;
 $2 = sp;
 $propVal = sp + 48|0;
 $3 = sp + 160|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8<<3)|0);
  $12 = ((($10) + ($8<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($this) + 36|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    $27 = $6;$29 = $10;$30 = 0;
   } else {
    $18 = (($this) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$11>>2]|0;
    $24 = (FUNCTION_TABLE_iii[$22 & 4095]($19,$23)|0);
    $25 = $24&1;
    HEAP8[$15>>0] = $25;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $27 = $$pre1$i;$29 = $$pre3$i;$30 = $25;
   }
   $26 = (($27) + -1)|0;
   $28 = ((($29) + ($26<<3)|0) + 5|0);
   HEAP8[$28>>0] = $30;
   $31 = HEAP8[$15>>0]|0;
   $32 = HEAP32[$this>>2]|0;
   $33 = (($32) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + -1)|0;
   $36 = (($32) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($37) + ($35<<3)|0) + 4|0);
   HEAP8[$38>>0] = $31;
  }
 }
 $39 = (($this) + 36|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($this) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($inProp) + 16|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($propVal,$43);
 $46 = (($this) + 8|0);
 $47 = HEAP32[$this>>2]|0;
 $48 = (($this) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 20|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 32|0);
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$2>>2] = $47;
 $56 = (($2) + 4|0);
 HEAP32[$56>>2] = $49;
 $57 = (($2) + 8|0);
 ;HEAP32[$57+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$46+8>>2]|0;
 $58 = (($2) + 20|0);
 HEAP32[$58>>2] = $51;
 $59 = (($2) + 24|0);
 HEAP32[$59>>2] = $propVal;
 $60 = (($2) + 28|0);
 HEAP32[$60>>2] = $53;
 $61 = (($2) + 32|0);
 HEAP32[$61>>2] = $55;
 $62 = (($2) + 36|0);
 HEAP8[$62>>0] = 1;
 $63 = (($2) + 40|0);
 HEAP32[$63>>2] = 0;
 $64 = (($2) + 44|0);
 HEAP32[$64>>2] = 0;
 $65 = (($inInfo) + 24|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEE27handleExtendedIndexPropertyILj517ES4_fjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,2,$65,$1);
 $66 = (($inInfo) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj518ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$66,0);
 $67 = (($inInfo) + 64|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj519ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$67,0);
 $68 = (($inInfo) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj520ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$68,0);
 $69 = (($inInfo) + 96|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj521ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$69,0);
 $70 = (($inInfo) + 112|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj522ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$70,0);
 $71 = (($inInfo) + 128|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj523ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$71,0);
 $72 = HEAP32[$42>>2]|0;
 $73 = (($propVal) + 64|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $74 << 3;
 _memcpy(($3|0),($propVal|0),($75|0))|0;
 $76 = (($3) + 64|0);
 HEAP32[$76>>2] = $74;
 $77 = (($3) + 80|0);
 $78 = (($propVal) + 80|0);
 ;HEAP32[$77+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$78+12>>2]|0;HEAP32[$77+16>>2]=HEAP32[$78+16>>2]|0;HEAP32[$77+20>>2]=HEAP32[$78+20>>2]|0;HEAP32[$77+24>>2]=HEAP32[$78+24>>2]|0;HEAP32[$77+28>>2]=HEAP32[$78+28>>2]|0;
 $79 = (($inProp) + 20|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($72,$3);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEE14handleAccessorILj673ENS_22PxRepXPropertyAccessorILj673ES4_KNS_30PxVehicleDriveTankControlModel4EnumESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$02$i$i$i$i$i = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 208;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 208)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i,$value$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i>>2]|0;
 $$$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (520760|0)==(0|0);
 L19: do {
  if ($33) {
   $$0$i$i1$i$i$i = 0;
  } else {
   $38 = 520760;$idx$02$i$i$i$i$i = 0;
   while(1) {
    $39 = (_strcasecmp($38,$$$i$i$i$i)|0);
    $40 = ($39|0)==(0);
    $35 = (($idx$02$i$i$i$i$i) + 1)|0;
    if ($40) {
     break;
    }
    $34 = (520736 + ($35<<3)|0);
    $36 = HEAP32[$34>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$0$i$i1$i$i$i = 0;
     break L19;
    } else {
     $38 = $36;$idx$02$i$i$i$i$i = $35;
    }
   }
   $41 = ((520736 + ($idx$02$i$i$i$i$i<<3)|0) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $$0$i$i1$i$i$i = $42;
  }
 } while(0);
 $43 = (($this) + 24|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($inAccessor) + 20|0);
 $46 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_vii[$46 & 4095]($44,$$0$i$i1$i$i$i);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 112;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 112)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 _memset(($1|0),0,296)|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE15complexPropertyINS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES7_EEKNS_34PxVehicleDriveDynDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE15complexPropertyINS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES7_EEKNS_34PxVehicleDriveDynDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, $propVal$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $propVal$byval_copy = sp + 96|0;
 $propVal = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($this) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($inProp) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vii[$42 & 4095]($propVal,$40);
 $43 = (($this) + 8|0);
 $44 = HEAP32[$this>>2]|0;
 $45 = (($this) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 20|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 28|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 32|0);
 $52 = HEAP32[$51>>2]|0;
 HEAP32[$propVal$byval_copy>>2] = $44;
 $53 = (($propVal$byval_copy) + 4|0);
 HEAP32[$53>>2] = $46;
 $54 = (($propVal$byval_copy) + 8|0);
 ;HEAP32[$54+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$43+8>>2]|0;
 $55 = (($propVal$byval_copy) + 20|0);
 HEAP32[$55>>2] = $48;
 $56 = (($propVal$byval_copy) + 24|0);
 HEAP32[$56>>2] = $propVal;
 $57 = (($propVal$byval_copy) + 28|0);
 HEAP32[$57>>2] = $50;
 $58 = (($propVal$byval_copy) + 32|0);
 HEAP32[$58>>2] = $52;
 $59 = (($propVal$byval_copy) + 36|0);
 HEAP8[$59>>0] = 1;
 $60 = (($propVal$byval_copy) + 40|0);
 HEAP32[$60>>2] = 0;
 $61 = (($propVal$byval_copy) + 44|0);
 HEAP32[$61>>2] = 0;
 (__ZNK5physx34PxVehicleDriveDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEEEEjT_j($inInfo,$propVal$byval_copy,0)|0);
 $62 = HEAP32[$39>>2]|0;
 $63 = (($inProp) + 20|0);
 $64 = HEAP32[$63>>2]|0;
 dest=$propVal$byval_copy+0|0; src=$propVal+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$64 & 4095]($62,$propVal$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 12;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 12)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 _memset(($1|0),0,256)|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE15complexPropertyINS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES7_EEKNS_35PxVehicleWheelsSimDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleDriveTankEEEEclILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 76;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 76)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 dest=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE15complexPropertyINS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES7_EEKNS_35PxVehicleWheelsDynDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE15complexPropertyINS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES7_EEKNS_35PxVehicleWheelsDynDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $1 = sp + 80|0;
 $2 = sp;
 $propVal = sp + 48|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inProp) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$2>>2] = $46;
 $55 = (($2) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($2) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($2) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($2) + 24|0);
 HEAP32[$58>>2] = $propVal;
 $59 = (($2) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($2) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($2) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($2) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($2) + 44|0);
 HEAP32[$63>>2] = 0;
 $64 = (($inInfo) + 12|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj623ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,1,$64,$1);
 $65 = (($inInfo) + 36|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj624ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,2,$65,$1);
 $66 = HEAP32[$41>>2]|0;
 $67 = (($inProp) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$propVal+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$propVal+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$propVal+24>>2]|0;HEAP32[$1+28>>2]=HEAP32[$propVal+28>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_18PxVehicleDriveTankEE15complexPropertyINS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES7_EEKNS_35PxVehicleWheelsSimDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $1 = sp + 64|0;
 $propVal = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($4) + -1)|0;
  $7 = (($2) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($6<<3)|0);
  $10 = ((($8) + ($6<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($this) + 36|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $25 = $4;$27 = $8;$28 = 0;
   } else {
    $16 = (($this) + 20|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$9>>2]|0;
    $22 = (FUNCTION_TABLE_iii[$20 & 4095]($17,$21)|0);
    $23 = $22&1;
    HEAP8[$13>>0] = $23;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $25 = $$pre1$i;$27 = $$pre3$i;$28 = $23;
   }
   $24 = (($25) + -1)|0;
   $26 = ((($27) + ($24<<3)|0) + 5|0);
   HEAP8[$26>>0] = $28;
   $29 = HEAP8[$13>>0]|0;
   $30 = HEAP32[$this>>2]|0;
   $31 = (($30) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + -1)|0;
   $34 = (($30) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35) + ($33<<3)|0) + 4|0);
   HEAP8[$36>>0] = $29;
  }
 }
 $37 = (($this) + 36|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($inProp) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 FUNCTION_TABLE_vii[$43 & 4095]($propVal,$41);
 $44 = (($this) + 8|0);
 $45 = HEAP32[$this>>2]|0;
 $46 = (($this) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($this) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 28|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 32|0);
 $53 = HEAP32[$52>>2]|0;
 HEAP32[$1>>2] = $45;
 $54 = (($1) + 4|0);
 HEAP32[$54>>2] = $47;
 $55 = (($1) + 8|0);
 ;HEAP32[$55+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$44+8>>2]|0;
 $56 = (($1) + 20|0);
 HEAP32[$56>>2] = $49;
 $57 = (($1) + 24|0);
 HEAP32[$57>>2] = $propVal;
 $58 = (($1) + 28|0);
 HEAP32[$58>>2] = $51;
 $59 = (($1) + 32|0);
 HEAP32[$59>>2] = $53;
 $60 = (($1) + 36|0);
 HEAP8[$60>>0] = 1;
 $61 = (($1) + 40|0);
 HEAP32[$61>>2] = 0;
 $62 = (($1) + 44|0);
 HEAP32[$62>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($inInfo,$1,0)|0);
 $63 = HEAP32[$40>>2]|0;
 $64 = (($inProp) + 20|0);
 $65 = HEAP32[$64>>2]|0;
 dest=$1+0|0; src=$propVal+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$65 & 4095]($63,$1);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleDrive4WEE11getTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (519448|0);
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleDrive4WEE12objectToFileERKNS_12PxRepXObjectEPNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE($this,$inLiveObject,$inCollection,$inWriter,$inTempBuffer,$inArgs) {
 $this = $this|0;
 $inLiveObject = $inLiveObject|0;
 $inCollection = $inCollection|0;
 $inWriter = $inWriter|0;
 $inTempBuffer = $inTempBuffer|0;
 $inArgs = $inArgs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inLiveObject) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiiiii[$4 & 255]($this,$1,$inCollection,$inWriter,$inTempBuffer,$inArgs);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXSerializerImplINS_16PxVehicleDrive4WEE16fileToObjectImplEPS1_RNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE($this,$inObj,$inReader,$inAllocator,$inArgs,$inCollection) {
 $this = $this|0;
 $inObj = $inObj|0;
 $inReader = $inReader|0;
 $inAllocator = $inAllocator|0;
 $inArgs = $inArgs|0;
 $inCollection = $inCollection|0;
 var $inArgs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $inArgs$byval_copy = sp;
 ;HEAP32[$inArgs$byval_copy+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy+8>>2]=HEAP32[$inArgs+8>>2]|0;
 __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleDrive4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy,$inReader,$inObj,$inAllocator,$inCollection);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleDrive4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($args,$reader,$obj,$alloc,$collection) {
 $args = $args|0;
 $reader = $reader|0;
 $obj = $obj|0;
 $alloc = $alloc|0;
 $collection = $collection|0;
 var $$sroa$2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $contexts = 0, $info = 0, $names = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $wrapper = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $0 = sp + 288|0;
 $1 = sp + 240|0;
 $$sroa$2$i = sp;
 $2 = sp + 192|0;
 $3 = sp + 16|0;
 $wrapper = sp + 172|0;
 $names = sp + 32|0;
 $contexts = sp + 176|0;
 $info = sp + 48|0;
 $4 = HEAP32[$alloc>>2]|0;
 $5 = (($4) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($alloc)|0);
 HEAP32[$wrapper>>2] = $7;
 HEAP32[$names>>2] = $wrapper;
 $8 = (($names) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($names) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($names) + 12|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$contexts>>2] = $wrapper;
 $11 = (($contexts) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($contexts) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = (($contexts) + 12|0);
 HEAP32[$13>>2] = 0;
 __ZN5physx29PxVehicleDrive4WGeneratedInfoC2Ev($info);
 ;HEAP32[$3+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$args+8>>2]|0;
 ;HEAP32[$$sroa$2$i+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$sroa$2$i+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$sroa$2$i+8>>2]=HEAP32[$3+8>>2]|0;
 HEAP32[$0>>2] = $names;
 $14 = (($0) + 4|0);
 HEAP32[$14>>2] = $contexts;
 $15 = (($0) + 8|0);
 ;HEAP32[$15+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$3+8>>2]|0;
 $16 = (($0) + 20|0);
 HEAP32[$16>>2] = $reader;
 $17 = (($0) + 24|0);
 HEAP32[$17>>2] = $obj;
 $18 = (($0) + 28|0);
 HEAP32[$18>>2] = $alloc;
 $19 = (($0) + 32|0);
 HEAP32[$19>>2] = $collection;
 $20 = (($0) + 36|0);
 HEAP8[$20>>0] = 1;
 $21 = (($0) + 40|0);
 HEAP32[$21>>2] = 0;
 $22 = (($0) + 44|0);
 HEAP32[$22>>2] = 0;
 $23 = (($info) + 36|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDrive4WEEEEclILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$23,0);
 $24 = (($info) + 52|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDrive4WEEEEclILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$24,0);
 HEAP32[$1>>2] = $names;
 $25 = (($1) + 4|0);
 HEAP32[$25>>2] = $contexts;
 $26 = (($1) + 8|0);
 ;HEAP32[$26+0>>2]=HEAP32[$$sroa$2$i+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$$sroa$2$i+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$$sroa$2$i+8>>2]|0;
 $27 = (($1) + 20|0);
 HEAP32[$27>>2] = $reader;
 $28 = (($1) + 24|0);
 HEAP32[$28>>2] = $obj;
 $29 = (($1) + 28|0);
 HEAP32[$29>>2] = $alloc;
 $30 = (($1) + 32|0);
 HEAP32[$30>>2] = $collection;
 $31 = (($1) + 36|0);
 HEAP8[$31>>0] = 1;
 $32 = (($1) + 40|0);
 HEAP32[$32>>2] = 0;
 $33 = (($1) + 44|0);
 HEAP32[$33>>2] = 0;
 $34 = (($info) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDrive4WEEEEclILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$34,0);
 HEAP32[$2>>2] = $names;
 $35 = (($2) + 4|0);
 HEAP32[$35>>2] = $contexts;
 $36 = (($2) + 8|0);
 ;HEAP32[$36+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$args+8>>2]|0;
 $37 = (($2) + 20|0);
 HEAP32[$37>>2] = $reader;
 $38 = (($2) + 24|0);
 HEAP32[$38>>2] = $obj;
 $39 = (($2) + 28|0);
 HEAP32[$39>>2] = $alloc;
 $40 = (($2) + 32|0);
 HEAP32[$40>>2] = $collection;
 $41 = (($2) + 36|0);
 HEAP8[$41>>0] = 1;
 $42 = (($2) + 40|0);
 HEAP32[$42>>2] = 0;
 $43 = (($2) + 44|0);
 HEAP32[$43>>2] = 0;
 $44 = (($info) + 108|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDrive4WEEEEclILj670ES3_NS_23PxVehicleDriveSimData4WES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$44,0);
 $45 = HEAP32[$13>>2]|0;
 $46 = $45 & 2147483647;
 $47 = ($46|0)!=(0);
 $48 = ($45|0)>(-1);
 $or$cond$i$i$i1 = $47 & $48;
 if ($or$cond$i$i$i1) {
  $49 = HEAP32[$11>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = HEAP32[$contexts>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  }
 }
 $56 = HEAP32[$10>>2]|0;
 $57 = $56 & 2147483647;
 $58 = ($57|0)!=(0);
 $59 = ($56|0)>(-1);
 $or$cond$i$i$i = $58 & $59;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $60 = HEAP32[$8>>2]|0;
 $61 = ($60|0)==(0|0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $62 = HEAP32[$names>>2]|0;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 FUNCTION_TABLE_vii[$66 & 4095]($63,$60);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDrive4WEEEEclILj670ES3_NS_23PxVehicleDriveSimData4WES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 212;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 212)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 dest=$1+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx36PxVehicleDriveSimData4WGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj670ES2_NS_23PxVehicleDriveSimData4WES6_EEKNS_36PxVehicleDriveSimData4WGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj670ES2_NS_23PxVehicleDriveSimData4WES6_EEKNS_36PxVehicleDriveSimData4WGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $propVal = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2368|0;
 $1 = sp + 1792|0;
 $2 = sp;
 $3 = sp + 592|0;
 $4 = sp + 576|0;
 $propVal = sp + 640|0;
 $5 = sp + 1216|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($8) + -1)|0;
  $11 = (($6) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($10<<3)|0);
  $14 = ((($12) + ($10<<3)|0) + 4|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $17 = (($this) + 36|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    $29 = $8;$31 = $12;$32 = 0;
   } else {
    $20 = (($this) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + 16|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = HEAP32[$13>>2]|0;
    $26 = (FUNCTION_TABLE_iii[$24 & 4095]($21,$25)|0);
    $27 = $26&1;
    HEAP8[$17>>0] = $27;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $29 = $$pre1$i;$31 = $$pre3$i;$32 = $27;
   }
   $28 = (($29) + -1)|0;
   $30 = ((($31) + ($28<<3)|0) + 5|0);
   HEAP8[$30>>0] = $32;
   $33 = HEAP8[$17>>0]|0;
   $34 = HEAP32[$this>>2]|0;
   $35 = (($34) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + -1)|0;
   $38 = (($34) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39) + ($37<<3)|0) + 4|0);
   HEAP8[$40>>0] = $33;
  }
 }
 $41 = (($this) + 36|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  STACKTOP = sp;return;
 }
 $44 = (($this) + 24|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($inProp) + 16|0);
 $47 = HEAP32[$46>>2]|0;
 FUNCTION_TABLE_vii[$47 & 4095]($propVal,$45);
 $48 = (($this) + 8|0);
 ;HEAP32[$4+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$48+8>>2]|0;
 $49 = HEAP32[$this>>2]|0;
 $50 = (($this) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 20|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 28|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($this) + 32|0);
 $57 = HEAP32[$56>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$48+8>>2]|0;
 HEAP32[$1>>2] = $49;
 $58 = (($1) + 4|0);
 HEAP32[$58>>2] = $51;
 $59 = (($1) + 8|0);
 ;HEAP32[$59+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$4+8>>2]|0;
 $60 = (($1) + 20|0);
 HEAP32[$60>>2] = $53;
 $61 = (($1) + 24|0);
 HEAP32[$61>>2] = $propVal;
 $62 = (($1) + 28|0);
 HEAP32[$62>>2] = $55;
 $63 = (($1) + 32|0);
 HEAP32[$63>>2] = $57;
 $64 = (($1) + 36|0);
 HEAP8[$64>>0] = 1;
 $65 = (($1) + 40|0);
 HEAP32[$65>>2] = 0;
 $66 = (($1) + 44|0);
 HEAP32[$66>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$inInfo,0);
 $67 = (($inInfo) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$67,0);
 $68 = (($inInfo) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$68,0);
 $69 = (($inInfo) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$69,0);
 HEAP32[$3>>2] = $49;
 $70 = (($3) + 4|0);
 HEAP32[$70>>2] = $51;
 $71 = (($3) + 8|0);
 ;HEAP32[$71+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$2+8>>2]|0;
 $72 = (($3) + 20|0);
 HEAP32[$72>>2] = $53;
 $73 = (($3) + 24|0);
 HEAP32[$73>>2] = $propVal;
 $74 = (($3) + 28|0);
 HEAP32[$74>>2] = $55;
 $75 = (($3) + 32|0);
 HEAP32[$75>>2] = $57;
 $76 = (($3) + 36|0);
 HEAP8[$76>>0] = 1;
 $77 = (($3) + 40|0);
 HEAP32[$77>>2] = 0;
 $78 = (($3) + 44|0);
 HEAP32[$78>>2] = 0;
 $79 = (($inInfo) + 64|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj661ES3_RKNS_27PxVehicleDifferential4WDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($3,$79,0);
 $80 = (($inInfo) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj662ES3_RKNS_30PxVehicleAckermannGeometryDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($3,$80,0);
 $81 = HEAP32[$44>>2]|0;
 $82 = (($propVal) + 64|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = $83 << 3;
 _memcpy(($5|0),($propVal|0),($84|0))|0;
 $85 = (($5) + 64|0);
 HEAP32[$85>>2] = $83;
 $86 = (($5) + 80|0);
 $87 = (($propVal) + 80|0);
 ;HEAP32[$86+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$86+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$86+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$86+12>>2]=HEAP32[$87+12>>2]|0;HEAP32[$86+16>>2]=HEAP32[$87+16>>2]|0;HEAP32[$86+20>>2]=HEAP32[$87+20>>2]|0;HEAP32[$86+24>>2]=HEAP32[$87+24>>2]|0;HEAP32[$86+28>>2]=HEAP32[$87+28>>2]|0;
 $88 = (($5) + 112|0);
 $89 = (($propVal) + 112|0);
 _memcpy(($88|0),($89|0),416)|0;
 $90 = (($5) + 528|0);
 $91 = (($propVal) + 528|0);
 dest=$90+0|0; src=$91+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 _memcpy(($2|0),($5|0),($84|0))|0;
 $92 = (($2) + 64|0);
 HEAP32[$92>>2] = $83;
 $93 = (($2) + 80|0);
 ;HEAP32[$93+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$93+12>>2]=HEAP32[$87+12>>2]|0;HEAP32[$93+16>>2]=HEAP32[$87+16>>2]|0;HEAP32[$93+20>>2]=HEAP32[$87+20>>2]|0;HEAP32[$93+24>>2]=HEAP32[$87+24>>2]|0;HEAP32[$93+28>>2]=HEAP32[$87+28>>2]|0;
 $94 = (($2) + 112|0);
 _memcpy(($94|0),($89|0),416)|0;
 $95 = (($2) + 528|0);
 dest=$95+0|0; src=$91+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $96 = (($inProp) + 20|0);
 $97 = HEAP32[$96>>2]|0;
 _memcpy(($1|0),($2|0),($84|0))|0;
 $98 = (($1) + 64|0);
 HEAP32[$98>>2] = $83;
 $99 = (($1) + 80|0);
 ;HEAP32[$99+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$87+12>>2]|0;HEAP32[$99+16>>2]=HEAP32[$87+16>>2]|0;HEAP32[$99+20>>2]=HEAP32[$87+20>>2]|0;HEAP32[$99+24>>2]=HEAP32[$87+24>>2]|0;HEAP32[$99+28>>2]=HEAP32[$87+28>>2]|0;
 $100 = (($1) + 112|0);
 _memcpy(($100|0),($89|0),416)|0;
 $101 = (($1) + 528|0);
 dest=$101+0|0; src=$91+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$97 & 4095]($81,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj661ES3_RKNS_27PxVehicleDifferential4WDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 528;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 528)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 661;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj661ENS_22PxRepXPropertyAccessorILj661ES4_RKNS_27PxVehicleDifferential4WDataES9_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj662ES3_RKNS_30PxVehicleAckermannGeometryDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 560;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 560)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 662;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj662ENS_22PxRepXPropertyAccessorILj662ES4_RKNS_30PxVehicleAckermannGeometryDataES9_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj662ENS_22PxRepXPropertyAccessorILj662ES4_RKNS_30PxVehicleAckermannGeometryDataES9_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 96|0;
 $1 = sp;
 $propVal$i$i = sp + 16|0;
 $2 = sp + 32|0;
 dest=$2+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx43PxVehicleAckermannGeometryDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_30PxVehicleAckermannGeometryDataEEEEclILj549ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$2,0);
 $64 = (($2) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_30PxVehicleAckermannGeometryDataEEEEclILj550ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_30PxVehicleAckermannGeometryDataEEEEclILj551ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = (($2) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_30PxVehicleAckermannGeometryDataEEEEclILj552ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$66,0);
 $67 = HEAP32[$41>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal$i$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal$i$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal$i$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal$i$i+12>>2]|0;
 $68 = (($inAccessor) + 20|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vii[$69 & 4095]($67,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_30PxVehicleAckermannGeometryDataEEEEclILj549ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_30PxVehicleAckermannGeometryDataEEEEclILj550ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_30PxVehicleAckermannGeometryDataEEEEclILj551ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_30PxVehicleAckermannGeometryDataEEEEclILj552ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_30PxVehicleAckermannGeometryDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj661ENS_22PxRepXPropertyAccessorILj661ES4_RKNS_27PxVehicleDifferential4WDataES9_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $0 = sp + 176|0;
 $1 = sp;
 $propVal$i$i = sp + 32|0;
 $2 = sp + 64|0;
 dest=$2+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx40PxVehicleDifferential4WDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj537ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$2,0);
 $64 = (($2) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj538ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj539ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = (($2) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj540ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$66,0);
 $67 = (($2) + 64|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj541ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$67,0);
 $68 = (($2) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj542ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$68,0);
 $69 = (($2) + 96|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj543ES3_NS3_4EnumES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$69,0);
 $70 = HEAP32[$41>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal$i$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal$i$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal$i$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal$i$i+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$propVal$i$i+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$propVal$i$i+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$propVal$i$i+24>>2]|0;HEAP32[$1+28>>2]=HEAP32[$propVal$i$i+28>>2]|0;
 $71 = (($inAccessor) + 20|0);
 $72 = HEAP32[$71>>2]|0;
 FUNCTION_TABLE_vii[$72 & 4095]($70,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj537ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj538ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj539ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj540ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj541ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj542ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $1 = (($prop) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE8pushNameEPKc($this,$3);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$5>>2] = $8;
 }
 $9 = (__ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE12readPropertyIfEEbRT_($this,$value$i$i$i$i)|0);
 if ($9) {
  $10 = (($this) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_fround(HEAPF32[$value$i$i$i$i>>2]);
  FUNCTION_TABLE_vif[$2 & 255]($11,$12);
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($this) + 36|0);
  HEAP8[$17>>0] = 1;
  STACKTOP = sp;return;
 }
 $18 = (($15) + -1)|0;
 $19 = (($13) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($20) + ($18<<3)|0) + 4|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $33 = $13;$35 = $15;
 } else {
  $24 = ((($20) + ($18<<3)|0) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $33 = $13;$35 = $15;
  } else {
   $27 = (($this) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $33 = $$pre2$i;$35 = $$pre4$i;
  }
 }
 $32 = (($33) + 8|0);
 $34 = (($35) + -1)|0;
 HEAP32[$32>>2] = $34;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $36 = (($this) + 36|0);
 HEAP8[$36>>0] = 1;
 $37 = ($$pre1$i|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($$pre1$i) + -1)|0;
 $39 = (($$pre$i) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40) + ($38<<3)|0) + 5|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 HEAP8[$36>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEEclILj543ES3_NS3_4EnumES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE8pushNameEPKc($this,$3);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj543ENS_22PxRepXPropertyAccessorILj543ES4_NS4_4EnumES9_EEEEvRKT0_($this,$theAccessor);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (($this) + 36|0);
  HEAP8[$8>>0] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($6) + -1)|0;
 $10 = (($4) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<3)|0) + 4|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $24 = $4;$26 = $6;
 } else {
  $15 = ((($11) + ($9<<3)|0) + 5|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $24 = $4;$26 = $6;
  } else {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $24 = $$pre2$i;$26 = $$pre4$i;
  }
 }
 $23 = (($24) + 8|0);
 $25 = (($26) + -1)|0;
 HEAP32[$23>>2] = $25;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 $28 = ($$pre1$i|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($$pre1$i) + -1)|0;
 $30 = (($$pre$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 5|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE8pushNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $41 = $1;$46 = 0;
 } else {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
   $$pre = HEAP32[$this>>2]|0;
   $$phi$trans$insert = (($$pre) + 8|0);
   $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
   $41 = $$pre;$46 = $$pre3;
  } else {
   $41 = $1;$46 = $3;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP32[$0>>2] = $name;
 $38 = (($0) + 4|0);
 HEAP8[$38>>0] = 0;
 $39 = (($0) + 5|0);
 HEAP8[$39>>0] = $37;
 $40 = (($41) + 12|0);
 $42 = HEAP32[$40>>2]|0;
 $43 = $42 & 2147483647;
 $44 = (($41) + 8|0);
 $45 = ($43>>>0)>($46>>>0);
 if (!($45)) {
  (__ZN5physx6shdfnd5ArrayINS_2Sn20ReaderNameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($41,$0)|0);
  STACKTOP = sp;return;
 }
 $47 = (($41) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<3)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $62 = $46;
 } else {
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $49;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $$pre$i1 = HEAP32[$44>>2]|0;
  $62 = $$pre$i1;
 }
 $61 = (($62) + 1)|0;
 HEAP32[$44>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj543ENS_22PxRepXPropertyAccessorILj543ES4_NS4_4EnumES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$$i$i$i$i = 0, $$0$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$02$i$i$i$i$i = 0, $value$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value$i$i$i$i = sp;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 24;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 24)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 HEAP32[$value$i$i$i$i>>2] = 0;
 $11 = (($this) + 36|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i$i = 519936;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i$i = $27;
 }
 $28 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$0$i$i$i$i$i,$value$i$i$i$i)|0);
 $29 = HEAP32[$value$i$i$i$i>>2]|0;
 $$$i$i$i$i = $28 ? $29 : 0;
 $30 = ($$$i$i$i$i|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP8[$$$i$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (520856|0)==(0|0);
 L19: do {
  if ($33) {
   $$0$i$i1$i$i$i = 0;
  } else {
   $38 = 520856;$idx$02$i$i$i$i$i = 0;
   while(1) {
    $39 = (_strcasecmp($38,$$$i$i$i$i)|0);
    $40 = ($39|0)==(0);
    $35 = (($idx$02$i$i$i$i$i) + 1)|0;
    if ($40) {
     break;
    }
    $34 = (520792 + ($35<<3)|0);
    $36 = HEAP32[$34>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$0$i$i1$i$i$i = 0;
     break L19;
    } else {
     $38 = $36;$idx$02$i$i$i$i$i = $35;
    }
   }
   $41 = ((520792 + ($idx$02$i$i$i$i$i<<3)|0) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $$0$i$i1$i$i$i = $42;
  }
 } while(0);
 $43 = (($this) + 24|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($inAccessor) + 20|0);
 $46 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_vii[$46 & 4095]($44,$$0$i$i1$i$i$i);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_27PxVehicleDifferential4WDataEE12readPropertyIfEEbRT_($this,$outType) {
 $this = $this|0;
 $outType = $outType|0;
 var $$$i = 0, $$0 = 0, $$0$i$i = 0, $$0$lcssa$i$i$ph$i = 0, $$05$i$i$i = 0, $$14$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$0$lcssa$i$i$i = 0, $dest$03$i$i$i = 0, $end$i$i$i = 0, $temp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $temp$i$i$i = sp + 8|0;
 $end$i$i$i = sp;
 HEAP32[$temp$i$i$i>>2] = 0;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i$i = 519936;
 } else {
  $12 = (($10) + -1)|0;
  $13 = (($8) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($12<<3)|0);
  $16 = HEAP32[$15>>2]|0;
  $$0$i$i = $16;
 }
 $17 = (FUNCTION_TABLE_iiii[$7 & 2047]($4,$$0$i$i,$temp$i$i$i)|0);
 $18 = HEAP32[$temp$i$i$i>>2]|0;
 $$$i = $17 ? $18 : 0;
 $19 = ($$$i|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP8[$$$i>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$05$i$i$i = $18;$26 = $20;
 while(1) {
  $25 = $26&255;
  $27 = (_isspace($25)|0);
  $28 = ($27|0)==(0);
  $23 = (($$05$i$i$i) + 1|0);
  if ($28) {
   $$0$lcssa$i$i$ph$i = $$05$i$i$i;
   break;
  }
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $$0$lcssa$i$i$ph$i = $23;
   break;
  } else {
   $$05$i$i$i = $23;$26 = $22;
  }
 }
 _memset(($temp$i$i$i|0),0,256)|0;
 $29 = (($temp$i$i$i) + 255|0);
 HEAP32[$end$i$i$i>>2] = $29;
 $30 = HEAP8[$$0$lcssa$i$i$ph$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 L17: do {
  if ($31) {
   $dest$0$lcssa$i$i$i = $temp$i$i$i;
  } else {
   $$14$i$i$i = $$0$lcssa$i$i$ph$i;$33 = $30;$dest$03$i$i$i = $temp$i$i$i;
   while(1) {
    $32 = $33&255;
    $34 = (_isspace($32)|0);
    $35 = ($34|0)==(0);
    if (!($35)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $36 = HEAP32[$end$i$i$i>>2]|0;
    $37 = ($dest$03$i$i$i>>>0)<($36>>>0);
    if (!($37)) {
     $dest$0$lcssa$i$i$i = $dest$03$i$i$i;
     break L17;
    }
    $38 = (($$14$i$i$i) + 1|0);
    $39 = HEAP8[$$14$i$i$i>>0]|0;
    $40 = (($dest$03$i$i$i) + 1|0);
    HEAP8[$dest$03$i$i$i>>0] = $39;
    $41 = HEAP8[$38>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $dest$0$lcssa$i$i$i = $40;
     break;
    } else {
     $$14$i$i$i = $38;$33 = $41;$dest$03$i$i$i = $40;
    }
   }
  }
 } while(0);
 HEAP8[$dest$0$lcssa$i$i$i>>0] = 0;
 $43 = (+_strtod($temp$i$i$i,$end$i$i$i));
 $44 = Math_fround($43);
 HEAPF32[$outType>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 0;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
 }
 _memset(($1|0),0,144)|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES7_EEKNS_32PxVehicleEngineDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 112;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 112)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 656;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataESA_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 256;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 256)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 657;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataESA_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $retval$0$i$i = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $1 = (($theAccessor) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$prop+12>>2]|0;
 $3 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE8pushNameEPKc($this,$3);
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$i$i = 272;
 } else {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 272)|0;
  $$0$i$i = $8;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$1>>2] = $$0$i$i;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $retval$0$i$i = 658;
 } else {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
  $retval$0$i$i = $12;
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataESA_EEEEvjRKT0_($this,$retval$0$i$i,$theAccessor);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $18 = (($this) + 36|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
 $19 = (($16) + -1)|0;
 $20 = (($14) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($19<<3)|0) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $34 = $14;$36 = $16;
 } else {
  $25 = ((($21) + ($19<<3)|0) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $34 = $14;$36 = $16;
  } else {
   $28 = (($this) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 40|0);
   $32 = HEAP32[$31>>2]|0;
   (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $34 = $$pre2$i;$36 = $$pre4$i;
  }
 }
 $33 = (($34) + 8|0);
 $35 = (($36) + -1)|0;
 HEAP32[$33>>2] = $35;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $37 = (($this) + 36|0);
 HEAP8[$37>>0] = 1;
 $38 = ($$pre1$i|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($$pre1$i) + -1)|0;
 $40 = (($$pre$i) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($41) + ($39<<3)|0) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataESA_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $0 = sp + 560|0;
 $1 = sp;
 $propVal$i$i = sp + 256|0;
 $2 = sp + 512|0;
 dest=$2+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEEclILj532ES3_KffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$2,0);
 $64 = (($2) + 16|0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj533ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$64,519968,0);
 $65 = (($2) + 32|0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj534ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$65,519968,0);
 $66 = HEAP32[$41>>2]|0;
 _memcpy(($1|0),($propVal$i$i|0),256)|0;
 $67 = (($inAccessor) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataESA_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 80|0;
 $1 = sp;
 $propVal$i$i = sp + 16|0;
 $2 = sp + 32|0;
 dest=$2+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj555ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$2,0);
 $64 = (($2) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj556ES3_NS_27PxVehicleClutchAccuracyMode4EnumES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleClutchDataEEEEclILj557ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = HEAP32[$41>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal$i$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal$i$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal$i$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal$i$i+12>>2]|0;
 $67 = (($inAccessor) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataESA_EEEEvjRKT0_($this,$inKey,$inAccessor) {
 $this = $this|0;
 $inKey = $inKey|0;
 $inAccessor = $inAccessor|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $0 = sp + 352|0;
 $1 = sp;
 $propVal$i$i = sp + 144|0;
 $2 = sp + 288|0;
 dest=$2+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inAccessor) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal$i$i,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $46;
 $55 = (($0) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($0) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($0) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($0) + 24|0);
 HEAP32[$58>>2] = $propVal$i$i;
 $59 = (($0) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($0) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($0) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($0) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($0) + 44|0);
 HEAP32[$63>>2] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEE15indexedPropertyILj526ES4_NS4_4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($0,0,$2,519968,0);
 $64 = (($2) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj527ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$64,0);
 $65 = (($2) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj528ES3_jjEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$65,0);
 $66 = (($2) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_18PxVehicleGearsDataEEEEclILj529ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$66,0);
 $67 = HEAP32[$41>>2]|0;
 _memcpy(($1|0),($propVal$i$i|0),144)|0;
 $68 = (($inAccessor) + 20|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vii[$69 & 4095]($67,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_23PxVehicleDriveSimData4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES7_EEKNS_32PxVehicleEngineDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $1 = sp + 272|0;
 $2 = sp;
 $propVal = sp + 48|0;
 $3 = sp + 160|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8<<3)|0);
  $12 = ((($10) + ($8<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($this) + 36|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    $27 = $6;$29 = $10;$30 = 0;
   } else {
    $18 = (($this) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$11>>2]|0;
    $24 = (FUNCTION_TABLE_iii[$22 & 4095]($19,$23)|0);
    $25 = $24&1;
    HEAP8[$15>>0] = $25;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $27 = $$pre1$i;$29 = $$pre3$i;$30 = $25;
   }
   $26 = (($27) + -1)|0;
   $28 = ((($29) + ($26<<3)|0) + 5|0);
   HEAP8[$28>>0] = $30;
   $31 = HEAP8[$15>>0]|0;
   $32 = HEAP32[$this>>2]|0;
   $33 = (($32) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + -1)|0;
   $36 = (($32) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($37) + ($35<<3)|0) + 4|0);
   HEAP8[$38>>0] = $31;
  }
 }
 $39 = (($this) + 36|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($this) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($inProp) + 16|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($propVal,$43);
 $46 = (($this) + 8|0);
 $47 = HEAP32[$this>>2]|0;
 $48 = (($this) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 20|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 32|0);
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$2>>2] = $47;
 $56 = (($2) + 4|0);
 HEAP32[$56>>2] = $49;
 $57 = (($2) + 8|0);
 ;HEAP32[$57+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$46+8>>2]|0;
 $58 = (($2) + 20|0);
 HEAP32[$58>>2] = $51;
 $59 = (($2) + 24|0);
 HEAP32[$59>>2] = $propVal;
 $60 = (($2) + 28|0);
 HEAP32[$60>>2] = $53;
 $61 = (($2) + 32|0);
 HEAP32[$61>>2] = $55;
 $62 = (($2) + 36|0);
 HEAP8[$62>>0] = 1;
 $63 = (($2) + 40|0);
 HEAP32[$63>>2] = 0;
 $64 = (($2) + 44|0);
 HEAP32[$64>>2] = 0;
 $65 = (($inInfo) + 24|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEE27handleExtendedIndexPropertyILj517ES4_fjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,2,$65,$1);
 $66 = (($inInfo) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj518ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$66,0);
 $67 = (($inInfo) + 64|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj519ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$67,0);
 $68 = (($inInfo) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj520ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$68,0);
 $69 = (($inInfo) + 96|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj521ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$69,0);
 $70 = (($inInfo) + 112|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj522ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$70,0);
 $71 = (($inInfo) + 128|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_19PxVehicleEngineDataEEEEclILj523ES3_ffEEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($2,$71,0);
 $72 = HEAP32[$42>>2]|0;
 $73 = (($propVal) + 64|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $74 << 3;
 _memcpy(($3|0),($propVal|0),($75|0))|0;
 $76 = (($3) + 64|0);
 HEAP32[$76>>2] = $74;
 $77 = (($3) + 80|0);
 $78 = (($propVal) + 80|0);
 ;HEAP32[$77+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$78+12>>2]|0;HEAP32[$77+16>>2]=HEAP32[$78+16>>2]|0;HEAP32[$77+20>>2]=HEAP32[$78+20>>2]|0;HEAP32[$77+24>>2]=HEAP32[$78+24>>2]|0;HEAP32[$77+28>>2]=HEAP32[$78+28>>2]|0;
 $79 = (($inProp) + 20|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($72,$3);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDrive4WEEEEclILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 112;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 112)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 _memset(($1|0),0,296)|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES7_EEKNS_34PxVehicleDriveDynDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataES7_EEKNS_34PxVehicleDriveDynDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, $propVal$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $propVal$byval_copy = sp + 96|0;
 $propVal = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = (($3) + -1)|0;
  $6 = (($1) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = ((($7) + ($5<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($this) + 36|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $24 = $3;$26 = $7;$27 = 0;
   } else {
    $15 = (($this) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $21 = (FUNCTION_TABLE_iii[$19 & 4095]($16,$20)|0);
    $22 = $21&1;
    HEAP8[$12>>0] = $22;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $24 = $$pre1$i;$26 = $$pre3$i;$27 = $22;
   }
   $23 = (($24) + -1)|0;
   $25 = ((($26) + ($23<<3)|0) + 5|0);
   HEAP8[$25>>0] = $27;
   $28 = HEAP8[$12>>0]|0;
   $29 = HEAP32[$this>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   $33 = (($29) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($32<<3)|0) + 4|0);
   HEAP8[$35>>0] = $28;
  }
 }
 $36 = (($this) + 36|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($this) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($inProp) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vii[$42 & 4095]($propVal,$40);
 $43 = (($this) + 8|0);
 $44 = HEAP32[$this>>2]|0;
 $45 = (($this) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 20|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 28|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 32|0);
 $52 = HEAP32[$51>>2]|0;
 HEAP32[$propVal$byval_copy>>2] = $44;
 $53 = (($propVal$byval_copy) + 4|0);
 HEAP32[$53>>2] = $46;
 $54 = (($propVal$byval_copy) + 8|0);
 ;HEAP32[$54+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$43+8>>2]|0;
 $55 = (($propVal$byval_copy) + 20|0);
 HEAP32[$55>>2] = $48;
 $56 = (($propVal$byval_copy) + 24|0);
 HEAP32[$56>>2] = $propVal;
 $57 = (($propVal$byval_copy) + 28|0);
 HEAP32[$57>>2] = $50;
 $58 = (($propVal$byval_copy) + 32|0);
 HEAP32[$58>>2] = $52;
 $59 = (($propVal$byval_copy) + 36|0);
 HEAP8[$59>>0] = 1;
 $60 = (($propVal$byval_copy) + 40|0);
 HEAP32[$60>>2] = 0;
 $61 = (($propVal$byval_copy) + 44|0);
 HEAP32[$61>>2] = 0;
 (__ZNK5physx34PxVehicleDriveDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_21PxVehicleDriveDynDataEEEEEEEjT_j($inInfo,$propVal$byval_copy,0)|0);
 $62 = HEAP32[$39>>2]|0;
 $63 = (($inProp) + 20|0);
 $64 = HEAP32[$63>>2]|0;
 dest=$propVal$byval_copy+0|0; src=$propVal+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$64 & 4095]($62,$propVal$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDrive4WEEEEclILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 12;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 12)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 _memset(($1|0),0,256)|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES7_EEKNS_35PxVehicleWheelsSimDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_16PxVehicleDrive4WEEEEclILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($this,$prop,$0) {
 $this = $this|0;
 $prop = $prop|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert3$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre4$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theAccessor = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $1 = sp + 24|0;
 $theAccessor = sp;
 HEAP8[$theAccessor>>0] = 0;
 $2 = (($theAccessor) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$prop+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$prop+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$prop+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$prop+12>>2]|0;
 $4 = HEAP32[$prop>>2]|0;
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE8pushNameEPKc($this,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0$i$i = 76;
 } else {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 76)|0;
  $$0$i$i = $9;
 }
 HEAP8[$theAccessor>>0] = 1;
 HEAP32[$2>>2] = $$0$i$i;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + 1)|0;
  HEAP32[$11>>2] = $14;
 }
 dest=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($1);
 __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES7_EEKNS_35PxVehicleWheelsDynDataGeneratedInfoEEEvPjRKT_RT0_($this,0,$theAccessor,$1);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $19 = (($this) + 36|0);
  HEAP8[$19>>0] = 1;
  STACKTOP = sp;return;
 }
 $20 = (($17) + -1)|0;
 $21 = (($15) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($22) + ($20<<3)|0) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $35 = $15;$37 = $17;
 } else {
  $26 = ((($22) + ($20<<3)|0) + 5|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $35 = $15;$37 = $17;
  } else {
   $29 = (($this) + 20|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
   $$pre2$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert3$i = (($$pre2$i) + 8|0);
   $$pre4$i = HEAP32[$$phi$trans$insert3$i>>2]|0;
   $35 = $$pre2$i;$37 = $$pre4$i;
  }
 }
 $34 = (($35) + 8|0);
 $36 = (($37) + -1)|0;
 HEAP32[$34>>2] = $36;
 $$pre$i = HEAP32[$this>>2]|0;
 $$phi$trans$insert$i = (($$pre$i) + 8|0);
 $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
 $38 = (($this) + 36|0);
 HEAP8[$38>>0] = 1;
 $39 = ($$pre1$i|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($$pre1$i) + -1)|0;
 $41 = (($$pre$i) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42) + ($40<<3)|0) + 5|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 HEAP8[$38>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataES7_EEKNS_35PxVehicleWheelsDynDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $1 = sp + 80|0;
 $2 = sp;
 $propVal = sp + 48|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($7<<3)|0);
  $11 = ((($9) + ($7<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($this) + 36|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $26 = $5;$28 = $9;$29 = 0;
   } else {
    $17 = (($this) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($19) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$10>>2]|0;
    $23 = (FUNCTION_TABLE_iii[$21 & 4095]($18,$22)|0);
    $24 = $23&1;
    HEAP8[$14>>0] = $24;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $26 = $$pre1$i;$28 = $$pre3$i;$29 = $24;
   }
   $25 = (($26) + -1)|0;
   $27 = ((($28) + ($25<<3)|0) + 5|0);
   HEAP8[$27>>0] = $29;
   $30 = HEAP8[$14>>0]|0;
   $31 = HEAP32[$this>>2]|0;
   $32 = (($31) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   $35 = (($31) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36) + ($34<<3)|0) + 4|0);
   HEAP8[$37>>0] = $30;
  }
 }
 $38 = (($this) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($inProp) + 16|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($propVal,$42);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = (($this) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$2>>2] = $46;
 $55 = (($2) + 4|0);
 HEAP32[$55>>2] = $48;
 $56 = (($2) + 8|0);
 ;HEAP32[$56+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$45+8>>2]|0;
 $57 = (($2) + 20|0);
 HEAP32[$57>>2] = $50;
 $58 = (($2) + 24|0);
 HEAP32[$58>>2] = $propVal;
 $59 = (($2) + 28|0);
 HEAP32[$59>>2] = $52;
 $60 = (($2) + 32|0);
 HEAP32[$60>>2] = $54;
 $61 = (($2) + 36|0);
 HEAP8[$61>>0] = 1;
 $62 = (($2) + 40|0);
 HEAP32[$62>>2] = 0;
 $63 = (($2) + 44|0);
 HEAP32[$63>>2] = 0;
 $64 = (($inInfo) + 12|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj623ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,1,$64,$1);
 $65 = (($inInfo) + 36|0);
 HEAP8[$1>>0] = 0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsDynDataEEEE27handleExtendedIndexPropertyILj624ES4_fKjNS_18PxUnknownClassInfoEEEvjRKNS_29PxExtendedIndexedPropertyInfoIXT_ET0_T2_T1_EERKT3_($2,2,$65,$1);
 $66 = HEAP32[$41>>2]|0;
 $67 = (($inProp) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$propVal+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$propVal+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$propVal+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$propVal+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$propVal+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$propVal+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$propVal+24>>2]|0;HEAP32[$1+28>>2]=HEAP32[$propVal+28>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($66,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorReaderBaseINS_16PxVehicleDrive4WEE15complexPropertyINS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataES7_EEKNS_35PxVehicleWheelsSimDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$inInfo) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $inInfo = $inInfo|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert2$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre3$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $propVal = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $1 = sp + 64|0;
 $propVal = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($4) + -1)|0;
  $7 = (($2) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($6<<3)|0);
  $10 = ((($8) + ($6<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($this) + 36|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $25 = $4;$27 = $8;$28 = 0;
   } else {
    $16 = (($this) + 20|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$9>>2]|0;
    $22 = (FUNCTION_TABLE_iii[$20 & 4095]($17,$21)|0);
    $23 = $22&1;
    HEAP8[$13>>0] = $23;
    $$pre$i = HEAP32[$this>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 8|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$phi$trans$insert2$i = (($$pre$i) + 4|0);
    $$pre3$i = HEAP32[$$phi$trans$insert2$i>>2]|0;
    $25 = $$pre1$i;$27 = $$pre3$i;$28 = $23;
   }
   $24 = (($25) + -1)|0;
   $26 = ((($27) + ($24<<3)|0) + 5|0);
   HEAP8[$26>>0] = $28;
   $29 = HEAP8[$13>>0]|0;
   $30 = HEAP32[$this>>2]|0;
   $31 = (($30) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + -1)|0;
   $34 = (($30) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ((($35) + ($33<<3)|0) + 4|0);
   HEAP8[$36>>0] = $29;
  }
 }
 $37 = (($this) + 36|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($inProp) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 FUNCTION_TABLE_vii[$43 & 4095]($propVal,$41);
 $44 = (($this) + 8|0);
 $45 = HEAP32[$this>>2]|0;
 $46 = (($this) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($this) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 28|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($this) + 32|0);
 $53 = HEAP32[$52>>2]|0;
 HEAP32[$1>>2] = $45;
 $54 = (($1) + 4|0);
 HEAP32[$54>>2] = $47;
 $55 = (($1) + 8|0);
 ;HEAP32[$55+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$44+8>>2]|0;
 $56 = (($1) + 20|0);
 HEAP32[$56>>2] = $49;
 $57 = (($1) + 24|0);
 HEAP32[$57>>2] = $propVal;
 $58 = (($1) + 28|0);
 HEAP32[$58>>2] = $51;
 $59 = (($1) + 32|0);
 HEAP32[$59>>2] = $53;
 $60 = (($1) + 36|0);
 HEAP8[$60>>0] = 1;
 $61 = (($1) + 40|0);
 HEAP32[$61>>2] = 0;
 $62 = (($1) + 44|0);
 HEAP32[$62>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($inInfo,$1,0)|0);
 $63 = HEAP32[$40>>2]|0;
 $64 = (($inProp) + 20|0);
 $65 = HEAP32[$64>>2]|0;
 dest=$1+0|0; src=$propVal+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$65 & 4095]($63,$1);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEE12fileToObjectERNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE($agg$result,$this,$inReader,$inAllocator,$inArgs,$inCollection) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inReader = $inReader|0;
 $inAllocator = $inAllocator|0;
 $inArgs = $inArgs|0;
 $inCollection = $inCollection|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $exitcond$i$i$i$i$i = 0, $i$01$i$i$i$i$i = 0;
 var $i$010 = 0, $inArgs$byval_copy3 = 0, $scevgep$i$i$i$i$i = 0, $theValue$i$i = 0, $theValue$i$i$i = 0, $theValue$i$i1 = 0, $value$i$i = 0, $vehActor$$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $inArgs$byval_copy3 = sp + 592|0;
 $theValue$i$i1 = sp;
 $theValue$i$i = sp + 4|0;
 $theValue$i$i$i = sp + 8|0;
 $value$i$i = sp + 16|0;
 $0 = HEAP32[$inReader>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 2047]($inReader,521064,$value$i$i)|0);
 do {
  if ($3) {
   $4 = HEAP32[$value$i$i>>2]|0;
   HEAP32[$theValue$i$i$i>>2] = $4;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = HEAP8[$4>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if (!($7)) {
     $8 = (_strtoull($4,$theValue$i$i$i,10)|0);
     $9 = tempRet0;
     $10 = ($8|0)==(0);
     $11 = ($9|0)==(0);
     $12 = $10 & $11;
     if (!($12)) {
      $13 = HEAP32[$inCollection>>2]|0;
      $14 = (($13) + 40|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (FUNCTION_TABLE_iiii[$15 & 2047]($inCollection,$8,$9)|0);
      $cond = ($16|0)==(0|0);
      if ($cond) {
       (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(2,521064,523648,130)|0);
       break;
      }
      $23 = HEAP32[$inReader>>2]|0;
      $24 = (($23) + 8|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (FUNCTION_TABLE_iiii[$25 & 2047]($inReader,521192,$inArgs$byval_copy3)|0);
      if ($26) {
       $27 = HEAP32[$inArgs$byval_copy3>>2]|0;
       HEAP32[$theValue$i$i>>2] = $27;
       $28 = ($27|0)==(0|0);
       if (!($28)) {
        $29 = HEAP8[$27>>0]|0;
        $30 = ($29<<24>>24)==(0);
        if (!($30)) {
         $31 = (_strtoul($27,$theValue$i$i,10)|0);
         $32 = ($31|0)==(0);
         if (!($32)) {
          $39 = HEAP32[$inReader>>2]|0;
          $40 = (($39) + 8|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = (FUNCTION_TABLE_iiii[$41 & 2047]($inReader,521208,$inArgs$byval_copy3)|0);
          if ($42) {
           $43 = HEAP32[$inArgs$byval_copy3>>2]|0;
           HEAP32[$theValue$i$i1>>2] = $43;
           $44 = ($43|0)==(0|0);
           if ($44) {
            $131 = 0;
           } else {
            $45 = HEAP8[$43>>0]|0;
            $46 = ($45<<24>>24)==(0);
            if ($46) {
             $131 = 0;
            } else {
             $47 = (_strtoul($43,$theValue$i$i1,10)|0);
             $131 = $47;
            }
           }
          } else {
           $131 = 0;
          }
          $48 = (__ZN5physx22PxVehicleWheelsSimData8allocateEj($31)|0);
          $49 = HEAP32[$inReader>>2]|0;
          $50 = (($49) + 44|0);
          $51 = HEAP32[$50>>2]|0;
          FUNCTION_TABLE_vi[$51 & 4095]($inReader);
          $52 = HEAP32[$inReader>>2]|0;
          $53 = (($52) + 16|0);
          $54 = HEAP32[$53>>2]|0;
          $55 = (FUNCTION_TABLE_iii[$54 & 4095]($inReader,521232)|0);
          if ($55) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_22PxVehicleWheelsSimDataEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$48,$inAllocator,$inCollection);
          }
          $56 = HEAP32[$inReader>>2]|0;
          $57 = (($56) + 48|0);
          $58 = HEAP32[$57>>2]|0;
          FUNCTION_TABLE_vi[$58 & 4095]($inReader);
          $59 = (($value$i$i) + 64|0);
          $60 = (($value$i$i) + 80|0);
          HEAPF32[$60>>2] = Math_fround(1.0);
          $61 = (($value$i$i) + 84|0);
          HEAPF32[$61>>2] = Math_fround(500.0);
          $62 = (($value$i$i) + 88|0);
          HEAPF32[$62>>2] = Math_fround(600.0);
          $63 = (($value$i$i) + 92|0);
          HEAPF32[$63>>2] = Math_fround(0.150000005960464477539);
          $64 = (($value$i$i) + 96|0);
          HEAPF32[$64>>2] = Math_fround(2.0);
          $65 = (($value$i$i) + 100|0);
          HEAPF32[$65>>2] = Math_fround(0.349999994039535522461);
          HEAPF32[$value$i$i>>2] = Math_fround(0.0);
          $66 = (($value$i$i) + 4|0);
          HEAPF32[$66>>2] = Math_fround(0.800000011920928955078);
          $67 = (($value$i$i) + 8|0);
          HEAPF32[$67>>2] = Math_fround(0.330000013113021850586);
          $68 = (($value$i$i) + 12|0);
          HEAPF32[$68>>2] = Math_fround(1.0);
          $69 = (($value$i$i) + 16|0);
          HEAPF32[$69>>2] = Math_fround(1.0);
          $70 = (($value$i$i) + 20|0);
          HEAPF32[$70>>2] = Math_fround(0.800000011920928955078);
          HEAP32[$59>>2] = 3;
          $71 = (($value$i$i) + 104|0);
          HEAPF32[$71>>2] = Math_fround(1.0);
          $72 = (($value$i$i) + 108|0);
          HEAPF32[$72>>2] = Math_fround(0.00166666670702397823334);
          $73 = (($value$i$i) + 240|0);
          HEAPF32[$73>>2] = Math_fround(4.0);
          $74 = (($value$i$i) + 244|0);
          HEAP32[$74>>2] = 7;
          $75 = (($value$i$i) + 248|0);
          HEAPF32[$75>>2] = Math_fround(0.5);
          $76 = (($value$i$i) + 112|0);
          HEAPF32[$76>>2] = Math_fround(-4.0);
          $77 = (($value$i$i) + 116|0);
          HEAPF32[$77>>2] = Math_fround(0.0);
          $78 = (($value$i$i) + 120|0);
          HEAPF32[$78>>2] = Math_fround(4.0);
          $79 = (($value$i$i) + 124|0);
          HEAPF32[$79>>2] = Math_fround(2.0);
          $80 = (($value$i$i) + 128|0);
          HEAPF32[$80>>2] = Math_fround(1.5);
          $81 = (($value$i$i) + 132|0);
          HEAPF32[$81>>2] = Math_fround(1.10000002384185791016);
          $82 = (($value$i$i) + 136|0);
          HEAPF32[$82>>2] = Math_fround(1.0);
          $scevgep$i$i$i$i$i = (($value$i$i) + 140|0);
          dest=$scevgep$i$i$i$i$i+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          $83 = (($value$i$i) + 256|0);
          HEAPF32[$83>>2] = Math_fround(10.0);
          $84 = (($value$i$i) + 260|0);
          HEAP32[$84>>2] = 1;
          $85 = (($value$i$i) + 264|0);
          HEAP32[$85>>2] = 5;
          $i$01$i$i$i$i$i = 0;
          while(1) {
           $86 = ((($value$i$i) + ($i$01$i$i$i$i$i<<2)|0) + 272|0);
           HEAPF32[$86>>2] = Math_fround(0.649999976158142089844);
           $87 = ((($value$i$i) + ($i$01$i$i$i$i$i<<2)|0) + 400|0);
           HEAPF32[$87>>2] = Math_fround(0.5);
           $88 = (($i$01$i$i$i$i$i) + 1)|0;
           $exitcond$i$i$i$i$i = ($88|0)==(32);
           if ($exitcond$i$i$i$i$i) {
            break;
           } else {
            $i$01$i$i$i$i$i = $88;
           }
          }
          $89 = (($value$i$i) + 276|0);
          HEAPF32[$89>>2] = Math_fround(0.150000005960464477539);
          $90 = (($value$i$i) + 400|0);
          HEAPF32[$90>>2] = Math_fround(2.0);
          $91 = (($value$i$i) + 528|0);
          HEAPF32[$91>>2] = Math_fround(0.449999988079071044922);
          $92 = (($value$i$i) + 532|0);
          HEAPF32[$92>>2] = Math_fround(0.5);
          $93 = (($value$i$i) + 536|0);
          HEAPF32[$93>>2] = Math_fround(0.5);
          $94 = (($value$i$i) + 540|0);
          HEAPF32[$94>>2] = Math_fround(1.29999995231628417969);
          $95 = (($value$i$i) + 544|0);
          HEAPF32[$95>>2] = Math_fround(1.29999995231628417969);
          $96 = (($value$i$i) + 548|0);
          HEAPF32[$96>>2] = Math_fround(1.29999995231628417969);
          $97 = (($value$i$i) + 552|0);
          HEAP32[$97>>2] = 0;
          $98 = (($value$i$i) + 560|0);
          HEAPF32[$98>>2] = Math_fround(1.0);
          $99 = (($value$i$i) + 564|0);
          HEAPF32[$99>>2] = Math_fround(0.0);
          $100 = (($value$i$i) + 568|0);
          HEAPF32[$100>>2] = Math_fround(0.0);
          $101 = (($value$i$i) + 572|0);
          HEAPF32[$101>>2] = Math_fround(0.0);
          $102 = HEAP32[$inReader>>2]|0;
          $103 = (($102) + 44|0);
          $104 = HEAP32[$103>>2]|0;
          FUNCTION_TABLE_vi[$104 & 4095]($inReader);
          $105 = HEAP32[$inReader>>2]|0;
          $106 = (($105) + 16|0);
          $107 = HEAP32[$106>>2]|0;
          $108 = (FUNCTION_TABLE_iii[$107 & 4095]($inReader,521248)|0);
          if ($108) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$value$i$i,$inAllocator,$inCollection);
          }
          $109 = HEAP32[$inReader>>2]|0;
          $110 = (($109) + 48|0);
          $111 = HEAP32[$110>>2]|0;
          FUNCTION_TABLE_vi[$111 & 4095]($inReader);
          $112 = HEAP32[$inReader>>2]|0;
          $113 = (($112) + 44|0);
          $114 = HEAP32[$113>>2]|0;
          FUNCTION_TABLE_vi[$114 & 4095]($inReader);
          $115 = HEAP32[$inReader>>2]|0;
          $116 = (($115) + 16|0);
          $117 = HEAP32[$116>>2]|0;
          $118 = (FUNCTION_TABLE_iii[$117 & 4095]($inReader,521264)|0);
          if ($118) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$value$i$i,$inAllocator,$inCollection);
          }
          $119 = HEAP32[$inReader>>2]|0;
          $120 = (($119) + 48|0);
          $121 = HEAP32[$120>>2]|0;
          FUNCTION_TABLE_vi[$121 & 4095]($inReader);
          $122 = HEAP32[$inArgs>>2]|0;
          $123 = (($16) + 4|0);
          $124 = HEAP16[$123>>1]|0;
          $125 = ($124<<16>>16)==(5);
          if ($125) {
           $128 = $16;
          } else {
           $128 = 0;
          }
          $126 = (__ZN5physx16PxVehicleDrive4W8allocateEj($31)|0);
          $127 = (($128) + 4|0);
          $129 = HEAP16[$127>>1]|0;
          $130 = ($129<<16>>16)==(5);
          $vehActor$$i = $130 ? $128 : 0;
          __ZN5physx16PxVehicleDrive4W5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataERKNS_23PxVehicleDriveSimData4WEj($126,$122,$vehActor$$i,$48,$value$i$i,$131);
          ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
          __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleDrive4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$126,$inAllocator,$inCollection);
          $132 = (($126) + 72|0);
          $133 = HEAP32[$132>>2]|0;
          $134 = (($48) + 36|0);
          $135 = HEAP32[$134>>2]|0;
          $136 = ($135|0)==(0);
          if (!($136)) {
           $155 = $135;$i$010 = 0;
           while(1) {
            $137 = ((($133) + (($i$010*208)|0)|0) + 192|0);
            $138 = HEAP32[$137>>2]|0;
            $139 = (($138) + 352|0);
            $140 = HEAP32[$139>>2]|0;
            $141 = ($140|0)==(0|0);
            if ($141) {
             $146 = $155;
            } else {
             $142 = HEAP32[$inCollection>>2]|0;
             $143 = HEAP32[$142>>2]|0;
             FUNCTION_TABLE_viiii[$143 & 511]($inCollection,$140,0,0);
             $$pre = HEAP32[$134>>2]|0;
             $146 = $$pre;
            }
            $144 = (($i$010) + 1)|0;
            $145 = ($144>>>0)<($146>>>0);
            if ($145) {
             $155 = $146;$i$010 = $144;
            } else {
             break;
            }
           }
          }
          $147 = ($48|0)==(0|0);
          if (!($147)) {
           __ZN5physx22PxVehicleWheelsSimData4freeEv($48);
          }
          $148 = $126;
          HEAP32[$agg$result>>2] = 521456;
          $149 = (($agg$result) + 4|0);
          HEAP32[$149>>2] = $126;
          $150 = (($agg$result) + 8|0);
          $151 = $150;
          $152 = $151;
          HEAP32[$152>>2] = $148;
          $153 = (($151) + 4)|0;
          $154 = $153;
          HEAP32[$154>>2] = 0;
          STACKTOP = sp;return;
         }
        }
       }
      }
      HEAP32[$agg$result>>2] = 521184;
      $33 = (($agg$result) + 4|0);
      HEAP32[$33>>2] = 0;
      $34 = (($agg$result) + 8|0);
      $35 = $34;
      $36 = $35;
      HEAP32[$36>>2] = 0;
      $37 = (($35) + 4)|0;
      $38 = $37;
      HEAP32[$38>>2] = 0;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(3,521064,521088,98)|0);
 HEAP32[$agg$result>>2] = 521184;
 $17 = (($agg$result) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($agg$result) + 8|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = 0;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn17readAllPropertiesINS_22PxVehicleWheelsSimDataEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($args,$reader,$obj,$alloc,$collection) {
 $args = $args|0;
 $reader = $reader|0;
 $obj = $obj|0;
 $alloc = $alloc|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $contexts = 0, $info = 0, $names = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $wrapper = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $0 = sp + 296|0;
 $wrapper = sp;
 $names = sp + 8|0;
 $contexts = sp + 24|0;
 $info = sp + 40|0;
 $1 = HEAP32[$alloc>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($alloc)|0);
 HEAP32[$wrapper>>2] = $4;
 HEAP32[$names>>2] = $wrapper;
 $5 = (($names) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($names) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($names) + 12|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$contexts>>2] = $wrapper;
 $8 = (($contexts) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($contexts) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($contexts) + 12|0);
 HEAP32[$10>>2] = 0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($info);
 HEAP32[$0>>2] = $names;
 $11 = (($0) + 4|0);
 HEAP32[$11>>2] = $contexts;
 $12 = (($0) + 8|0);
 ;HEAP32[$12+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$args+8>>2]|0;
 $13 = (($0) + 20|0);
 HEAP32[$13>>2] = $reader;
 $14 = (($0) + 24|0);
 HEAP32[$14>>2] = $obj;
 $15 = (($0) + 28|0);
 HEAP32[$15>>2] = $alloc;
 $16 = (($0) + 32|0);
 HEAP32[$16>>2] = $collection;
 $17 = (($0) + 36|0);
 HEAP8[$17>>0] = 1;
 $18 = (($0) + 40|0);
 HEAP32[$18>>2] = 0;
 $19 = (($0) + 44|0);
 HEAP32[$19>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($info,$0,0)|0);
 $20 = HEAP32[$10>>2]|0;
 $21 = $20 & 2147483647;
 $22 = ($21|0)!=(0);
 $23 = ($20|0)>(-1);
 $or$cond$i$i$i1 = $22 & $23;
 if ($or$cond$i$i$i1) {
  $24 = HEAP32[$8>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   $26 = HEAP32[$contexts>>2]|0;
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vii[$30 & 4095]($27,$24);
  }
 }
 $31 = HEAP32[$7>>2]|0;
 $32 = $31 & 2147483647;
 $33 = ($32|0)!=(0);
 $34 = ($31|0)>(-1);
 $or$cond$i$i$i = $33 & $34;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $35 = HEAP32[$5>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$names>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($38,$35);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($args,$reader,$obj,$alloc,$collection) {
 $args = $args|0;
 $reader = $reader|0;
 $obj = $obj|0;
 $alloc = $alloc|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $contexts = 0, $info = 0;
 var $names = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0, $wrapper = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $0 = sp + 200|0;
 $1 = sp + 16|0;
 $2 = sp;
 $wrapper = sp + 64|0;
 $names = sp + 72|0;
 $contexts = sp + 88|0;
 $info = sp + 104|0;
 $3 = HEAP32[$alloc>>2]|0;
 $4 = (($3) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($alloc)|0);
 HEAP32[$wrapper>>2] = $6;
 HEAP32[$names>>2] = $wrapper;
 $7 = (($names) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($names) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($names) + 12|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$contexts>>2] = $wrapper;
 $10 = (($contexts) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($contexts) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (($contexts) + 12|0);
 HEAP32[$12>>2] = 0;
 __ZN5physx36PxVehicleDriveSimData4WGeneratedInfoC2Ev($info);
 ;HEAP32[$2+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$args+8>>2]|0;
 HEAP32[$0>>2] = $names;
 $13 = (($0) + 4|0);
 HEAP32[$13>>2] = $contexts;
 $14 = (($0) + 8|0);
 ;HEAP32[$14+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$2+8>>2]|0;
 $15 = (($0) + 20|0);
 HEAP32[$15>>2] = $reader;
 $16 = (($0) + 24|0);
 HEAP32[$16>>2] = $obj;
 $17 = (($0) + 28|0);
 HEAP32[$17>>2] = $alloc;
 $18 = (($0) + 32|0);
 HEAP32[$18>>2] = $collection;
 $19 = (($0) + 36|0);
 HEAP8[$19>>0] = 1;
 $20 = (($0) + 40|0);
 HEAP32[$20>>2] = 0;
 $21 = (($0) + 44|0);
 HEAP32[$21>>2] = 0;
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$info,0);
 $22 = (($info) + 16|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$22,0);
 $23 = (($info) + 32|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$23,0);
 $24 = (($info) + 48|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataES8_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($0,$24,0);
 HEAP32[$1>>2] = $names;
 $25 = (($1) + 4|0);
 HEAP32[$25>>2] = $contexts;
 $26 = (($1) + 8|0);
 ;HEAP32[$26+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$args+8>>2]|0;
 $27 = (($1) + 20|0);
 HEAP32[$27>>2] = $reader;
 $28 = (($1) + 24|0);
 HEAP32[$28>>2] = $obj;
 $29 = (($1) + 28|0);
 HEAP32[$29>>2] = $alloc;
 $30 = (($1) + 32|0);
 HEAP32[$30>>2] = $collection;
 $31 = (($1) + 36|0);
 HEAP8[$31>>0] = 1;
 $32 = (($1) + 40|0);
 HEAP32[$32>>2] = 0;
 $33 = (($1) + 44|0);
 HEAP32[$33>>2] = 0;
 $34 = (($info) + 64|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj661ES3_RKNS_27PxVehicleDifferential4WDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$34,0);
 $35 = (($info) + 80|0);
 __ZN5physx18RepXPropertyFilterINS_2Sn17RepXVisitorReaderINS_23PxVehicleDriveSimData4WEEEEclILj662ES3_RKNS_30PxVehicleAckermannGeometryDataES7_EEvRKNS_14PxPropertyInfoIXT_ET0_T1_T2_EEj($1,$35,0);
 $36 = HEAP32[$12>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37|0)!=(0);
 $39 = ($36|0)>(-1);
 $or$cond$i$i$i1 = $38 & $39;
 if ($or$cond$i$i$i1) {
  $40 = HEAP32[$10>>2]|0;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = HEAP32[$contexts>>2]|0;
   $43 = HEAP32[$42>>2]|0;
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   FUNCTION_TABLE_vii[$46 & 4095]($43,$40);
  }
 }
 $47 = HEAP32[$9>>2]|0;
 $48 = $47 & 2147483647;
 $49 = ($48|0)!=(0);
 $50 = ($47|0)>(-1);
 $or$cond$i$i$i = $49 & $50;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $51 = HEAP32[$7>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = HEAP32[$names>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 12|0);
 $57 = HEAP32[$56>>2]|0;
 FUNCTION_TABLE_vii[$57 & 4095]($54,$51);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEE16objectToFileImplEPKS1_PNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE($this,$drive,$inCollection,$inWriter,$inTempBuffer,$0) {
 $this = $this|0;
 $drive = $drive|0;
 $inCollection = $inCollection|0;
 $inWriter = $inWriter|0;
 $inTempBuffer = $inTempBuffer|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $cond$i = 0, $magicptr$i = 0, $or$cond$i$i$i$i = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i = sp + 16|0;
 $1 = (($drive) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $magicptr$i = $2;
 $cond$i = ($2|0)==(0|0);
 if ($cond$i) {
  $24 = 0;$27 = 0;
 } else {
  $3 = HEAP32[$inCollection>>2]|0;
  $4 = (($3) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iii[$5 & 4095]($inCollection,$2)|0);
  if (!($6)) {
   (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(2,521064,523520,52)|0);
  }
  $7 = HEAP32[$inCollection>>2]|0;
  $8 = (($7) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_iii[$9 & 4095]($inCollection,$2)|0);
  $11 = tempRet0;
  $12 = ($10|0)==(0);
  $13 = ($11|0)==(0);
  $14 = $12 & $13;
  $15 = $14 ? $magicptr$i : $10;
  $16 = $14 ? 0 : $11;
  $24 = $15;$27 = $16;
 }
 $17 = HEAP32[$inWriter>>2]|0;
 $18 = (($17) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$vararg_buffer1>>2] = 523632;
 $20 = (($vararg_buffer1) + 4|0);
 HEAP32[$20>>2] = $2;
 $21 = (($vararg_buffer1) + 8|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = $24;
 $25 = (($22) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $27;
 FUNCTION_TABLE_viii[$19 & 4095]($inWriter,521064,$vararg_buffer1);
 $28 = (($drive) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer1>>2] = $29;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer1)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$inTempBuffer>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($inTempBuffer,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer1>>0] = 0;
 $35 = HEAP32[$inTempBuffer>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
 $37 = HEAP32[$inWriter>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($inTempBuffer) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($inWriter,521192,$41);
 $42 = (($inTempBuffer) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($inTempBuffer) + 12|0);
 HEAP32[$43>>2] = 0;
 $44 = (($drive) + 108|0);
 $45 = HEAP32[$44>>2]|0;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer1>>2] = $45;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer1)|0);
 $46 = HEAP8[$buffer$i$i$i>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if (!($47)) {
  $48 = HEAP32[$inTempBuffer>>2]|0;
  $49 = HEAP32[$48>>2]|0;
  $50 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$49 & 2047]($inTempBuffer,$buffer$i$i$i,$50)|0);
 }
 HEAP8[$vararg_buffer1>>0] = 0;
 $51 = HEAP32[$inTempBuffer>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 (FUNCTION_TABLE_iiii[$52 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
 $53 = HEAP32[$inWriter>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$55 & 4095]($inWriter,521208,$56);
 HEAP32[$42>>2] = 0;
 HEAP32[$43>>2] = 0;
 $57 = (($inTempBuffer) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 HEAP32[$vararg_buffer1>>2] = $58;
 $59 = (($vararg_buffer1) + 4|0);
 HEAP32[$59>>2] = 0;
 $60 = (($vararg_buffer1) + 8|0);
 HEAP32[$60>>2] = 0;
 $61 = (($vararg_buffer1) + 12|0);
 HEAP32[$61>>2] = 0;
 __ZN5physx2Sn18writeAllPropertiesINS_16PxVehicleDrive4WEEEvRNS_7profile12ProfileArrayINS0_14NameStackEntryEEEPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($vararg_buffer1,$drive,$inWriter,$inTempBuffer,$inCollection);
 $62 = HEAP32[$61>>2]|0;
 $63 = $62 & 2147483647;
 $64 = ($63|0)!=(0);
 $65 = ($62|0)>(-1);
 $or$cond$i$i$i$i = $64 & $65;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $66 = HEAP32[$59>>2]|0;
 $67 = ($66|0)==(0|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $68 = HEAP32[$vararg_buffer1>>2]|0;
 $69 = HEAP32[$68>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + 12|0);
 $72 = HEAP32[$71>>2]|0;
 FUNCTION_TABLE_vii[$72 & 4095]($69,$66);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEE14allocateObjectERNS_23PxRepXInstantiationArgsE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEE12fileToObjectERNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE($agg$result,$this,$inReader,$inAllocator,$inArgs,$inCollection) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inReader = $inReader|0;
 $inAllocator = $inAllocator|0;
 $inArgs = $inArgs|0;
 $inCollection = $inCollection|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $exitcond$i$i$i$i$i = 0;
 var $i$01$i$i$i$i$i = 0, $i$010 = 0, $inArgs$byval_copy3 = 0, $scevgep$i$i$i$i$i = 0, $theValue$i$i = 0, $theValue$i$i$i = 0, $theValue$i$i1 = 0, $value$i$i = 0, $vehActor$$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $inArgs$byval_copy3 = sp + 592|0;
 $theValue$i$i1 = sp;
 $theValue$i$i = sp + 4|0;
 $theValue$i$i$i = sp + 8|0;
 $value$i$i = sp + 16|0;
 $0 = HEAP32[$inReader>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 2047]($inReader,521064,$value$i$i)|0);
 do {
  if ($3) {
   $4 = HEAP32[$value$i$i>>2]|0;
   HEAP32[$theValue$i$i$i>>2] = $4;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = HEAP8[$4>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if (!($7)) {
     $8 = (_strtoull($4,$theValue$i$i$i,10)|0);
     $9 = tempRet0;
     $10 = ($8|0)==(0);
     $11 = ($9|0)==(0);
     $12 = $10 & $11;
     if (!($12)) {
      $13 = HEAP32[$inCollection>>2]|0;
      $14 = (($13) + 40|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (FUNCTION_TABLE_iiii[$15 & 2047]($inCollection,$8,$9)|0);
      $cond = ($16|0)==(0|0);
      if ($cond) {
       (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(2,521064,523648,130)|0);
       break;
      }
      $23 = HEAP32[$inReader>>2]|0;
      $24 = (($23) + 8|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (FUNCTION_TABLE_iiii[$25 & 2047]($inReader,521192,$inArgs$byval_copy3)|0);
      if ($26) {
       $27 = HEAP32[$inArgs$byval_copy3>>2]|0;
       HEAP32[$theValue$i$i>>2] = $27;
       $28 = ($27|0)==(0|0);
       if (!($28)) {
        $29 = HEAP8[$27>>0]|0;
        $30 = ($29<<24>>24)==(0);
        if (!($30)) {
         $31 = (_strtoul($27,$theValue$i$i,10)|0);
         $32 = ($31|0)==(0);
         if (!($32)) {
          $39 = HEAP32[$inReader>>2]|0;
          $40 = (($39) + 8|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = (FUNCTION_TABLE_iiii[$41 & 2047]($inReader,521208,$inArgs$byval_copy3)|0);
          if ($42) {
           $43 = HEAP32[$inArgs$byval_copy3>>2]|0;
           HEAP32[$theValue$i$i1>>2] = $43;
           $44 = ($43|0)==(0|0);
           if ($44) {
            $132 = 0;
           } else {
            $45 = HEAP8[$43>>0]|0;
            $46 = ($45<<24>>24)==(0);
            if ($46) {
             $132 = 0;
            } else {
             $47 = (_strtoul($43,$theValue$i$i1,10)|0);
             $132 = $47;
            }
           }
          } else {
           $132 = 0;
          }
          $48 = (__ZN5physx22PxVehicleWheelsSimData8allocateEj($31)|0);
          $49 = HEAP32[$inReader>>2]|0;
          $50 = (($49) + 44|0);
          $51 = HEAP32[$50>>2]|0;
          FUNCTION_TABLE_vi[$51 & 4095]($inReader);
          $52 = HEAP32[$inReader>>2]|0;
          $53 = (($52) + 16|0);
          $54 = HEAP32[$53>>2]|0;
          $55 = (FUNCTION_TABLE_iii[$54 & 4095]($inReader,521232)|0);
          if ($55) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_22PxVehicleWheelsSimDataEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$48,$inAllocator,$inCollection);
          }
          $56 = HEAP32[$inReader>>2]|0;
          $57 = (($56) + 48|0);
          $58 = HEAP32[$57>>2]|0;
          FUNCTION_TABLE_vi[$58 & 4095]($inReader);
          $59 = (($value$i$i) + 64|0);
          $60 = (($value$i$i) + 80|0);
          HEAPF32[$60>>2] = Math_fround(1.0);
          $61 = (($value$i$i) + 84|0);
          HEAPF32[$61>>2] = Math_fround(500.0);
          $62 = (($value$i$i) + 88|0);
          HEAPF32[$62>>2] = Math_fround(600.0);
          $63 = (($value$i$i) + 92|0);
          HEAPF32[$63>>2] = Math_fround(0.150000005960464477539);
          $64 = (($value$i$i) + 96|0);
          HEAPF32[$64>>2] = Math_fround(2.0);
          $65 = (($value$i$i) + 100|0);
          HEAPF32[$65>>2] = Math_fround(0.349999994039535522461);
          HEAPF32[$value$i$i>>2] = Math_fround(0.0);
          $66 = (($value$i$i) + 4|0);
          HEAPF32[$66>>2] = Math_fround(0.800000011920928955078);
          $67 = (($value$i$i) + 8|0);
          HEAPF32[$67>>2] = Math_fround(0.330000013113021850586);
          $68 = (($value$i$i) + 12|0);
          HEAPF32[$68>>2] = Math_fround(1.0);
          $69 = (($value$i$i) + 16|0);
          HEAPF32[$69>>2] = Math_fround(1.0);
          $70 = (($value$i$i) + 20|0);
          HEAPF32[$70>>2] = Math_fround(0.800000011920928955078);
          HEAP32[$59>>2] = 3;
          $71 = (($value$i$i) + 104|0);
          HEAPF32[$71>>2] = Math_fround(1.0);
          $72 = (($value$i$i) + 108|0);
          HEAPF32[$72>>2] = Math_fround(0.00166666670702397823334);
          $73 = (($value$i$i) + 240|0);
          HEAPF32[$73>>2] = Math_fround(4.0);
          $74 = (($value$i$i) + 244|0);
          HEAP32[$74>>2] = 7;
          $75 = (($value$i$i) + 248|0);
          HEAPF32[$75>>2] = Math_fround(0.5);
          $76 = (($value$i$i) + 112|0);
          HEAPF32[$76>>2] = Math_fround(-4.0);
          $77 = (($value$i$i) + 116|0);
          HEAPF32[$77>>2] = Math_fround(0.0);
          $78 = (($value$i$i) + 120|0);
          HEAPF32[$78>>2] = Math_fround(4.0);
          $79 = (($value$i$i) + 124|0);
          HEAPF32[$79>>2] = Math_fround(2.0);
          $80 = (($value$i$i) + 128|0);
          HEAPF32[$80>>2] = Math_fround(1.5);
          $81 = (($value$i$i) + 132|0);
          HEAPF32[$81>>2] = Math_fround(1.10000002384185791016);
          $82 = (($value$i$i) + 136|0);
          HEAPF32[$82>>2] = Math_fround(1.0);
          $scevgep$i$i$i$i$i = (($value$i$i) + 140|0);
          dest=$scevgep$i$i$i$i$i+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          $83 = (($value$i$i) + 256|0);
          HEAPF32[$83>>2] = Math_fround(10.0);
          $84 = (($value$i$i) + 260|0);
          HEAP32[$84>>2] = 1;
          $85 = (($value$i$i) + 264|0);
          HEAP32[$85>>2] = 5;
          $i$01$i$i$i$i$i = 0;
          while(1) {
           $86 = ((($value$i$i) + ($i$01$i$i$i$i$i<<2)|0) + 272|0);
           HEAPF32[$86>>2] = Math_fround(0.649999976158142089844);
           $87 = ((($value$i$i) + ($i$01$i$i$i$i$i<<2)|0) + 400|0);
           HEAPF32[$87>>2] = Math_fround(0.5);
           $88 = (($i$01$i$i$i$i$i) + 1)|0;
           $exitcond$i$i$i$i$i = ($88|0)==(32);
           if ($exitcond$i$i$i$i$i) {
            break;
           } else {
            $i$01$i$i$i$i$i = $88;
           }
          }
          $89 = (($value$i$i) + 276|0);
          HEAPF32[$89>>2] = Math_fround(0.150000005960464477539);
          $90 = (($value$i$i) + 400|0);
          HEAPF32[$90>>2] = Math_fround(2.0);
          $91 = (($value$i$i) + 528|0);
          HEAPF32[$91>>2] = Math_fround(0.449999988079071044922);
          $92 = (($value$i$i) + 532|0);
          HEAPF32[$92>>2] = Math_fround(0.5);
          $93 = (($value$i$i) + 536|0);
          HEAPF32[$93>>2] = Math_fround(0.5);
          $94 = (($value$i$i) + 540|0);
          HEAPF32[$94>>2] = Math_fround(1.29999995231628417969);
          $95 = (($value$i$i) + 544|0);
          HEAPF32[$95>>2] = Math_fround(1.29999995231628417969);
          $96 = (($value$i$i) + 548|0);
          HEAPF32[$96>>2] = Math_fround(1.29999995231628417969);
          $97 = (($value$i$i) + 552|0);
          HEAP32[$97>>2] = 0;
          $98 = (($value$i$i) + 560|0);
          HEAPF32[$98>>2] = Math_fround(1.0);
          $99 = (($value$i$i) + 564|0);
          HEAPF32[$99>>2] = Math_fround(0.0);
          $100 = (($value$i$i) + 568|0);
          HEAPF32[$100>>2] = Math_fround(0.0);
          $101 = (($value$i$i) + 572|0);
          HEAPF32[$101>>2] = Math_fround(0.0);
          $102 = HEAP32[$inReader>>2]|0;
          $103 = (($102) + 44|0);
          $104 = HEAP32[$103>>2]|0;
          FUNCTION_TABLE_vi[$104 & 4095]($inReader);
          $105 = HEAP32[$inReader>>2]|0;
          $106 = (($105) + 16|0);
          $107 = HEAP32[$106>>2]|0;
          $108 = (FUNCTION_TABLE_iii[$107 & 4095]($inReader,521248)|0);
          if ($108) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$value$i$i,$inAllocator,$inCollection);
          }
          $109 = HEAP32[$inReader>>2]|0;
          $110 = (($109) + 48|0);
          $111 = HEAP32[$110>>2]|0;
          FUNCTION_TABLE_vi[$111 & 4095]($inReader);
          $112 = HEAP32[$inReader>>2]|0;
          $113 = (($112) + 44|0);
          $114 = HEAP32[$113>>2]|0;
          FUNCTION_TABLE_vi[$114 & 4095]($inReader);
          $115 = HEAP32[$inReader>>2]|0;
          $116 = (($115) + 16|0);
          $117 = HEAP32[$116>>2]|0;
          $118 = (FUNCTION_TABLE_iii[$117 & 4095]($inReader,521264)|0);
          if ($118) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$value$i$i,$inAllocator,$inCollection);
          }
          $119 = HEAP32[$inReader>>2]|0;
          $120 = (($119) + 48|0);
          $121 = HEAP32[$120>>2]|0;
          FUNCTION_TABLE_vi[$121 & 4095]($inReader);
          $122 = HEAP32[$inArgs>>2]|0;
          $123 = (($16) + 4|0);
          $124 = HEAP16[$123>>1]|0;
          $125 = ($124<<16>>16)==(5);
          if ($125) {
           $128 = $16;
          } else {
           $128 = 0;
          }
          $126 = (__ZN5physx18PxVehicleDriveTank8allocateEj($31)|0);
          $127 = (($128) + 4|0);
          $129 = HEAP16[$127>>1]|0;
          $130 = ($129<<16>>16)==(5);
          $vehActor$$i = $130 ? $128 : 0;
          $131 = (($31) - ($132))|0;
          __ZN5physx18PxVehicleDriveTank5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataERKNS_21PxVehicleDriveSimDataEj($126,$122,$vehActor$$i,$48,$value$i$i,$131);
          ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
          __ZN5physx2Sn17readAllPropertiesINS_18PxVehicleDriveTankEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$126,$inAllocator,$inCollection);
          $133 = (($126) + 72|0);
          $134 = HEAP32[$133>>2]|0;
          $135 = (($48) + 36|0);
          $136 = HEAP32[$135>>2]|0;
          $137 = ($136|0)==(0);
          if (!($137)) {
           $156 = $136;$i$010 = 0;
           while(1) {
            $138 = ((($134) + (($i$010*208)|0)|0) + 192|0);
            $139 = HEAP32[$138>>2]|0;
            $140 = (($139) + 352|0);
            $141 = HEAP32[$140>>2]|0;
            $142 = ($141|0)==(0|0);
            if ($142) {
             $147 = $156;
            } else {
             $143 = HEAP32[$inCollection>>2]|0;
             $144 = HEAP32[$143>>2]|0;
             FUNCTION_TABLE_viiii[$144 & 511]($inCollection,$141,0,0);
             $$pre = HEAP32[$135>>2]|0;
             $147 = $$pre;
            }
            $145 = (($i$010) + 1)|0;
            $146 = ($145>>>0)<($147>>>0);
            if ($146) {
             $156 = $147;$i$010 = $145;
            } else {
             break;
            }
           }
          }
          $148 = ($48|0)==(0|0);
          if (!($148)) {
           __ZN5physx22PxVehicleWheelsSimData4freeEv($48);
          }
          $149 = $126;
          HEAP32[$agg$result>>2] = 521400;
          $150 = (($agg$result) + 4|0);
          HEAP32[$150>>2] = $126;
          $151 = (($agg$result) + 8|0);
          $152 = $151;
          $153 = $152;
          HEAP32[$153>>2] = $149;
          $154 = (($152) + 4)|0;
          $155 = $154;
          HEAP32[$155>>2] = 0;
          STACKTOP = sp;return;
         }
        }
       }
      }
      HEAP32[$agg$result>>2] = 521184;
      $33 = (($agg$result) + 4|0);
      HEAP32[$33>>2] = 0;
      $34 = (($agg$result) + 8|0);
      $35 = $34;
      $36 = $35;
      HEAP32[$36>>2] = 0;
      $37 = (($35) + 4)|0;
      $38 = $37;
      HEAP32[$38>>2] = 0;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(3,521064,521088,98)|0);
 HEAP32[$agg$result>>2] = 521184;
 $17 = (($agg$result) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($agg$result) + 8|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = 0;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEE16objectToFileImplEPKS1_PNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE($this,$drive,$inCollection,$inWriter,$inTempBuffer,$0) {
 $this = $this|0;
 $drive = $drive|0;
 $inCollection = $inCollection|0;
 $inWriter = $inWriter|0;
 $inTempBuffer = $inTempBuffer|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $cond$i = 0, $magicptr$i = 0, $vararg_buffer1 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i = sp + 16|0;
 $1 = (($drive) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $magicptr$i = $2;
 $cond$i = ($2|0)==(0|0);
 if ($cond$i) {
  $24 = 0;$27 = 0;
 } else {
  $3 = HEAP32[$inCollection>>2]|0;
  $4 = (($3) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iii[$5 & 4095]($inCollection,$2)|0);
  if (!($6)) {
   (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(2,521064,523520,52)|0);
  }
  $7 = HEAP32[$inCollection>>2]|0;
  $8 = (($7) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_iii[$9 & 4095]($inCollection,$2)|0);
  $11 = tempRet0;
  $12 = ($10|0)==(0);
  $13 = ($11|0)==(0);
  $14 = $12 & $13;
  $15 = $14 ? $magicptr$i : $10;
  $16 = $14 ? 0 : $11;
  $24 = $15;$27 = $16;
 }
 $17 = HEAP32[$inWriter>>2]|0;
 $18 = (($17) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$vararg_buffer1>>2] = 523632;
 $20 = (($vararg_buffer1) + 4|0);
 HEAP32[$20>>2] = $2;
 $21 = (($vararg_buffer1) + 8|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = $24;
 $25 = (($22) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $27;
 FUNCTION_TABLE_viii[$19 & 4095]($inWriter,521064,$vararg_buffer1);
 $28 = (($drive) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer1>>2] = $29;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer1)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$inTempBuffer>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($inTempBuffer,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer1>>0] = 0;
 $35 = HEAP32[$inTempBuffer>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
 $37 = HEAP32[$inWriter>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($inTempBuffer) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($inWriter,521192,$41);
 $42 = (($inTempBuffer) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($inTempBuffer) + 12|0);
 HEAP32[$43>>2] = 0;
 $44 = (($drive) + 108|0);
 $45 = HEAP32[$44>>2]|0;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer1>>2] = $45;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer1)|0);
 $46 = HEAP8[$buffer$i$i$i>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if ($47) {
  HEAP8[$vararg_buffer1>>0] = 0;
  $51 = HEAP32[$inTempBuffer>>2]|0;
  $52 = HEAP32[$51>>2]|0;
  (FUNCTION_TABLE_iiii[$52 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
  $53 = HEAP32[$inWriter>>2]|0;
  $54 = (($53) + 8|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_viii[$55 & 4095]($inWriter,521208,$56);
  HEAP32[$42>>2] = 0;
  HEAP32[$43>>2] = 0;
  __ZN5physx2Sn18writeAllPropertiesINS_18PxVehicleDriveTankEEEvPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($drive,$inWriter,$inTempBuffer,$inCollection);
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$inTempBuffer>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = (_strlen(($buffer$i$i$i|0))|0);
 (FUNCTION_TABLE_iiii[$49 & 2047]($inTempBuffer,$buffer$i$i$i,$50)|0);
 HEAP8[$vararg_buffer1>>0] = 0;
 $51 = HEAP32[$inTempBuffer>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 (FUNCTION_TABLE_iiii[$52 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
 $53 = HEAP32[$inWriter>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$55 & 4095]($inWriter,521208,$56);
 HEAP32[$42>>2] = 0;
 HEAP32[$43>>2] = 0;
 __ZN5physx2Sn18writeAllPropertiesINS_18PxVehicleDriveTankEEEvPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($drive,$inWriter,$inTempBuffer,$inCollection);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn18writeAllPropertiesINS_18PxVehicleDriveTankEEEvPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($inObj,$writer,$buffer,$collection) {
 $inObj = $inObj|0;
 $writer = $writer|0;
 $buffer = $buffer|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i = 0, $or$cond$i$i$i = 0;
 var $theNames = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $0 = sp + 216|0;
 $1 = sp;
 $info$i = sp + 28|0;
 $2 = sp + 168|0;
 $theNames = sp + 200|0;
 $3 = (($buffer) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$theNames>>2] = $4;
 $5 = (($theNames) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($theNames) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($theNames) + 12|0);
 HEAP32[$7>>2] = 0;
 __ZN5physx31PxVehicleDriveTankGeneratedInfoC2Ev($info$i);
 HEAP32[$0>>2] = $theNames;
 $8 = (($0) + 4|0);
 HEAP32[$8>>2] = $writer;
 $9 = (($0) + 8|0);
 HEAP32[$9>>2] = $inObj;
 $10 = (($0) + 12|0);
 HEAP32[$10>>2] = $buffer;
 $11 = (($0) + 16|0);
 HEAP32[$11>>2] = $collection;
 $12 = (($0) + 20|0);
 HEAP32[$12>>2] = 0;
 $13 = (($0) + 24|0);
 HEAP32[$13>>2] = 0;
 $14 = (__ZNK5physx28PxVehicleWheelsGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEEEEEjT_j($info$i,$0,0)|0);
 HEAP32[$1>>2] = $theNames;
 $15 = (($1) + 4|0);
 HEAP32[$15>>2] = $writer;
 $16 = (($1) + 8|0);
 HEAP32[$16>>2] = $inObj;
 $17 = (($1) + 12|0);
 HEAP32[$17>>2] = $buffer;
 $18 = (($1) + 16|0);
 HEAP32[$18>>2] = $collection;
 $19 = (($1) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($1) + 24|0);
 HEAP32[$20>>2] = 0;
 (__ZNK5physx27PxVehicleDriveGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEEEEEjT_j($info$i,$1,$14)|0);
 HEAP32[$2>>2] = $theNames;
 $21 = (($2) + 4|0);
 HEAP32[$21>>2] = $writer;
 $22 = (($2) + 8|0);
 HEAP32[$22>>2] = $inObj;
 $23 = (($2) + 12|0);
 HEAP32[$23>>2] = $buffer;
 $24 = (($2) + 16|0);
 HEAP32[$24>>2] = $collection;
 $25 = (($2) + 20|0);
 HEAP32[$25>>2] = 0;
 $26 = (($2) + 24|0);
 HEAP32[$26>>2] = 0;
 (__ZNK5physx31PxVehicleDriveTankGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEEEEEjT_j($info$i,$2,0)|0);
 $27 = HEAP32[$7>>2]|0;
 $28 = $27 & 2147483647;
 $29 = ($28|0)!=(0);
 $30 = ($27|0)>(-1);
 $or$cond$i$i$i = $29 & $30;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$5>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$theNames>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($34,$31);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEE14allocateObjectERNS_23PxRepXInstantiationArgsE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEE12fileToObjectERNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE($agg$result,$this,$inReader,$inAllocator,$inArgs,$inCollection) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inReader = $inReader|0;
 $inAllocator = $inAllocator|0;
 $inArgs = $inArgs|0;
 $inCollection = $inCollection|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $exitcond$i$i$i$i$i = 0, $exitcond$i$i$i$i$i8 = 0, $i$01$i$i$i$i$i = 0, $i$01$i$i$i$i$i7 = 0, $i$010 = 0, $inArgs$byval_copy3 = 0;
 var $nmSimData = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i5 = 0, $theValue$i$i = 0, $theValue$i$i$i = 0, $theValue$i$i1 = 0, $value$i$i = 0, $vehActor$$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1152|0;
 $inArgs$byval_copy3 = sp + 1136|0;
 $theValue$i$i1 = sp;
 $theValue$i$i = sp + 4|0;
 $theValue$i$i$i = sp + 8|0;
 $value$i$i = sp + 16|0;
 $nmSimData = sp + 592|0;
 $0 = HEAP32[$inReader>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 2047]($inReader,521064,$value$i$i)|0);
 do {
  if ($3) {
   $4 = HEAP32[$value$i$i>>2]|0;
   HEAP32[$theValue$i$i$i>>2] = $4;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = HEAP8[$4>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if (!($7)) {
     $8 = (_strtoull($4,$theValue$i$i$i,10)|0);
     $9 = tempRet0;
     $10 = ($8|0)==(0);
     $11 = ($9|0)==(0);
     $12 = $10 & $11;
     if (!($12)) {
      $13 = HEAP32[$inCollection>>2]|0;
      $14 = (($13) + 40|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (FUNCTION_TABLE_iiii[$15 & 2047]($inCollection,$8,$9)|0);
      $cond = ($16|0)==(0|0);
      if ($cond) {
       (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(2,521064,523648,130)|0);
       break;
      }
      $23 = HEAP32[$inReader>>2]|0;
      $24 = (($23) + 8|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (FUNCTION_TABLE_iiii[$25 & 2047]($inReader,521192,$inArgs$byval_copy3)|0);
      if ($26) {
       $27 = HEAP32[$inArgs$byval_copy3>>2]|0;
       HEAP32[$theValue$i$i>>2] = $27;
       $28 = ($27|0)==(0|0);
       if (!($28)) {
        $29 = HEAP8[$27>>0]|0;
        $30 = ($29<<24>>24)==(0);
        if (!($30)) {
         $31 = (_strtoul($27,$theValue$i$i,10)|0);
         $32 = ($31|0)==(0);
         if (!($32)) {
          $39 = HEAP32[$inReader>>2]|0;
          $40 = (($39) + 8|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = (FUNCTION_TABLE_iiii[$41 & 2047]($inReader,521208,$inArgs$byval_copy3)|0);
          if ($42) {
           $43 = HEAP32[$inArgs$byval_copy3>>2]|0;
           HEAP32[$theValue$i$i1>>2] = $43;
           $44 = ($43|0)==(0|0);
           if ($44) {
            $167 = 0;
           } else {
            $45 = HEAP8[$43>>0]|0;
            $46 = ($45<<24>>24)==(0);
            if ($46) {
             $167 = 0;
            } else {
             $47 = (_strtoul($43,$theValue$i$i1,10)|0);
             $167 = $47;
            }
           }
          } else {
           $167 = 0;
          }
          $48 = (__ZN5physx22PxVehicleWheelsSimData8allocateEj($31)|0);
          $49 = HEAP32[$inReader>>2]|0;
          $50 = (($49) + 44|0);
          $51 = HEAP32[$50>>2]|0;
          FUNCTION_TABLE_vi[$51 & 4095]($inReader);
          $52 = HEAP32[$inReader>>2]|0;
          $53 = (($52) + 16|0);
          $54 = HEAP32[$53>>2]|0;
          $55 = (FUNCTION_TABLE_iii[$54 & 4095]($inReader,521232)|0);
          if ($55) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_22PxVehicleWheelsSimDataEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$48,$inAllocator,$inCollection);
          }
          $56 = HEAP32[$inReader>>2]|0;
          $57 = (($56) + 48|0);
          $58 = HEAP32[$57>>2]|0;
          FUNCTION_TABLE_vi[$58 & 4095]($inReader);
          $59 = (($value$i$i) + 64|0);
          $60 = (($value$i$i) + 80|0);
          HEAPF32[$60>>2] = Math_fround(1.0);
          $61 = (($value$i$i) + 84|0);
          HEAPF32[$61>>2] = Math_fround(500.0);
          $62 = (($value$i$i) + 88|0);
          HEAPF32[$62>>2] = Math_fround(600.0);
          $63 = (($value$i$i) + 92|0);
          HEAPF32[$63>>2] = Math_fround(0.150000005960464477539);
          $64 = (($value$i$i) + 96|0);
          HEAPF32[$64>>2] = Math_fround(2.0);
          $65 = (($value$i$i) + 100|0);
          HEAPF32[$65>>2] = Math_fround(0.349999994039535522461);
          HEAPF32[$value$i$i>>2] = Math_fround(0.0);
          $66 = (($value$i$i) + 4|0);
          HEAPF32[$66>>2] = Math_fround(0.800000011920928955078);
          $67 = (($value$i$i) + 8|0);
          HEAPF32[$67>>2] = Math_fround(0.330000013113021850586);
          $68 = (($value$i$i) + 12|0);
          HEAPF32[$68>>2] = Math_fround(1.0);
          $69 = (($value$i$i) + 16|0);
          HEAPF32[$69>>2] = Math_fround(1.0);
          $70 = (($value$i$i) + 20|0);
          HEAPF32[$70>>2] = Math_fround(0.800000011920928955078);
          HEAP32[$59>>2] = 3;
          $71 = (($value$i$i) + 104|0);
          HEAPF32[$71>>2] = Math_fround(1.0);
          $72 = (($value$i$i) + 108|0);
          HEAPF32[$72>>2] = Math_fround(0.00166666670702397823334);
          $73 = (($value$i$i) + 240|0);
          HEAPF32[$73>>2] = Math_fround(4.0);
          $74 = (($value$i$i) + 244|0);
          HEAP32[$74>>2] = 7;
          $75 = (($value$i$i) + 248|0);
          HEAPF32[$75>>2] = Math_fround(0.5);
          $76 = (($value$i$i) + 112|0);
          HEAPF32[$76>>2] = Math_fround(-4.0);
          $77 = (($value$i$i) + 116|0);
          HEAPF32[$77>>2] = Math_fround(0.0);
          $78 = (($value$i$i) + 120|0);
          HEAPF32[$78>>2] = Math_fround(4.0);
          $79 = (($value$i$i) + 124|0);
          HEAPF32[$79>>2] = Math_fround(2.0);
          $80 = (($value$i$i) + 128|0);
          HEAPF32[$80>>2] = Math_fround(1.5);
          $81 = (($value$i$i) + 132|0);
          HEAPF32[$81>>2] = Math_fround(1.10000002384185791016);
          $82 = (($value$i$i) + 136|0);
          HEAPF32[$82>>2] = Math_fround(1.0);
          $scevgep$i$i$i$i$i = (($value$i$i) + 140|0);
          dest=$scevgep$i$i$i$i$i+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          $83 = (($value$i$i) + 256|0);
          HEAPF32[$83>>2] = Math_fround(10.0);
          $84 = (($value$i$i) + 260|0);
          HEAP32[$84>>2] = 1;
          $85 = (($value$i$i) + 264|0);
          HEAP32[$85>>2] = 5;
          $i$01$i$i$i$i$i = 0;
          while(1) {
           $86 = ((($value$i$i) + ($i$01$i$i$i$i$i<<2)|0) + 272|0);
           HEAPF32[$86>>2] = Math_fround(0.649999976158142089844);
           $87 = ((($value$i$i) + ($i$01$i$i$i$i$i<<2)|0) + 400|0);
           HEAPF32[$87>>2] = Math_fround(0.5);
           $88 = (($i$01$i$i$i$i$i) + 1)|0;
           $exitcond$i$i$i$i$i = ($88|0)==(32);
           if ($exitcond$i$i$i$i$i) {
            break;
           } else {
            $i$01$i$i$i$i$i = $88;
           }
          }
          $89 = (($value$i$i) + 276|0);
          HEAPF32[$89>>2] = Math_fround(0.150000005960464477539);
          $90 = (($value$i$i) + 400|0);
          HEAPF32[$90>>2] = Math_fround(2.0);
          $91 = (($value$i$i) + 528|0);
          HEAPF32[$91>>2] = Math_fround(0.449999988079071044922);
          $92 = (($value$i$i) + 532|0);
          HEAPF32[$92>>2] = Math_fround(0.5);
          $93 = (($value$i$i) + 536|0);
          HEAPF32[$93>>2] = Math_fround(0.5);
          $94 = (($value$i$i) + 540|0);
          HEAPF32[$94>>2] = Math_fround(1.29999995231628417969);
          $95 = (($value$i$i) + 544|0);
          HEAPF32[$95>>2] = Math_fround(1.29999995231628417969);
          $96 = (($value$i$i) + 548|0);
          HEAPF32[$96>>2] = Math_fround(1.29999995231628417969);
          $97 = (($value$i$i) + 552|0);
          HEAP32[$97>>2] = 0;
          $98 = (($value$i$i) + 560|0);
          HEAPF32[$98>>2] = Math_fround(1.0);
          $99 = (($value$i$i) + 564|0);
          HEAPF32[$99>>2] = Math_fround(0.0);
          $100 = (($value$i$i) + 568|0);
          HEAPF32[$100>>2] = Math_fround(0.0);
          $101 = (($value$i$i) + 572|0);
          HEAPF32[$101>>2] = Math_fround(0.0);
          $102 = HEAP32[$inReader>>2]|0;
          $103 = (($102) + 44|0);
          $104 = HEAP32[$103>>2]|0;
          FUNCTION_TABLE_vi[$104 & 4095]($inReader);
          $105 = HEAP32[$inReader>>2]|0;
          $106 = (($105) + 16|0);
          $107 = HEAP32[$106>>2]|0;
          $108 = (FUNCTION_TABLE_iii[$107 & 4095]($inReader,521248)|0);
          if ($108) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$value$i$i,$inAllocator,$inCollection);
          }
          $109 = HEAP32[$inReader>>2]|0;
          $110 = (($109) + 48|0);
          $111 = HEAP32[$110>>2]|0;
          FUNCTION_TABLE_vi[$111 & 4095]($inReader);
          $112 = (($nmSimData) + 64|0);
          $113 = (($nmSimData) + 80|0);
          HEAPF32[$113>>2] = Math_fround(1.0);
          $114 = (($nmSimData) + 84|0);
          HEAPF32[$114>>2] = Math_fround(500.0);
          $115 = (($nmSimData) + 88|0);
          HEAPF32[$115>>2] = Math_fround(600.0);
          $116 = (($nmSimData) + 92|0);
          HEAPF32[$116>>2] = Math_fround(0.150000005960464477539);
          $117 = (($nmSimData) + 96|0);
          HEAPF32[$117>>2] = Math_fround(2.0);
          $118 = (($nmSimData) + 100|0);
          HEAPF32[$118>>2] = Math_fround(0.349999994039535522461);
          HEAPF32[$nmSimData>>2] = Math_fround(0.0);
          $119 = (($nmSimData) + 4|0);
          HEAPF32[$119>>2] = Math_fround(0.800000011920928955078);
          $120 = (($nmSimData) + 8|0);
          HEAPF32[$120>>2] = Math_fround(0.330000013113021850586);
          $121 = (($nmSimData) + 12|0);
          HEAPF32[$121>>2] = Math_fround(1.0);
          $122 = (($nmSimData) + 16|0);
          HEAPF32[$122>>2] = Math_fround(1.0);
          $123 = (($nmSimData) + 20|0);
          HEAPF32[$123>>2] = Math_fround(0.800000011920928955078);
          HEAP32[$112>>2] = 3;
          $124 = (($nmSimData) + 104|0);
          HEAPF32[$124>>2] = Math_fround(1.0);
          $125 = (($nmSimData) + 108|0);
          HEAPF32[$125>>2] = Math_fround(0.00166666670702397823334);
          $126 = (($nmSimData) + 240|0);
          HEAPF32[$126>>2] = Math_fround(4.0);
          $127 = (($nmSimData) + 244|0);
          HEAP32[$127>>2] = 7;
          $128 = (($nmSimData) + 248|0);
          HEAPF32[$128>>2] = Math_fround(0.5);
          $129 = (($nmSimData) + 112|0);
          HEAPF32[$129>>2] = Math_fround(-4.0);
          $130 = (($nmSimData) + 116|0);
          HEAPF32[$130>>2] = Math_fround(0.0);
          $131 = (($nmSimData) + 120|0);
          HEAPF32[$131>>2] = Math_fround(4.0);
          $132 = (($nmSimData) + 124|0);
          HEAPF32[$132>>2] = Math_fround(2.0);
          $133 = (($nmSimData) + 128|0);
          HEAPF32[$133>>2] = Math_fround(1.5);
          $134 = (($nmSimData) + 132|0);
          HEAPF32[$134>>2] = Math_fround(1.10000002384185791016);
          $135 = (($nmSimData) + 136|0);
          HEAPF32[$135>>2] = Math_fround(1.0);
          $scevgep$i$i$i$i$i5 = (($nmSimData) + 140|0);
          dest=$scevgep$i$i$i$i$i5+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          $136 = (($nmSimData) + 256|0);
          HEAPF32[$136>>2] = Math_fround(10.0);
          $137 = (($nmSimData) + 260|0);
          HEAP32[$137>>2] = 1;
          $138 = (($nmSimData) + 264|0);
          HEAP32[$138>>2] = 5;
          $i$01$i$i$i$i$i7 = 0;
          while(1) {
           $139 = ((($nmSimData) + ($i$01$i$i$i$i$i7<<2)|0) + 272|0);
           HEAPF32[$139>>2] = Math_fround(0.649999976158142089844);
           $140 = ((($nmSimData) + ($i$01$i$i$i$i$i7<<2)|0) + 400|0);
           HEAPF32[$140>>2] = Math_fround(0.5);
           $141 = (($i$01$i$i$i$i$i7) + 1)|0;
           $exitcond$i$i$i$i$i8 = ($141|0)==(32);
           if ($exitcond$i$i$i$i$i8) {
            break;
           } else {
            $i$01$i$i$i$i$i7 = $141;
           }
          }
          $142 = (($nmSimData) + 276|0);
          HEAPF32[$142>>2] = Math_fround(0.150000005960464477539);
          $143 = (($nmSimData) + 400|0);
          HEAPF32[$143>>2] = Math_fround(2.0);
          $144 = (($nmSimData) + 528|0);
          HEAP32[$144>>2] = 0;
          $145 = (($nmSimData) + 532|0);
          HEAP32[$145>>2] = 0;
          $146 = (($nmSimData) + 536|0);
          HEAPF32[$146>>2] = Math_fround(0.0);
          $147 = HEAP32[$inReader>>2]|0;
          $148 = (($147) + 44|0);
          $149 = HEAP32[$148>>2]|0;
          FUNCTION_TABLE_vi[$149 & 4095]($inReader);
          $150 = HEAP32[$inReader>>2]|0;
          $151 = (($150) + 16|0);
          $152 = HEAP32[$151>>2]|0;
          $153 = (FUNCTION_TABLE_iii[$152 & 4095]($inReader,521264)|0);
          if ($153) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$value$i$i,$inAllocator,$inCollection);
          }
          $154 = HEAP32[$inReader>>2]|0;
          $155 = (($154) + 48|0);
          $156 = HEAP32[$155>>2]|0;
          FUNCTION_TABLE_vi[$156 & 4095]($inReader);
          $157 = HEAP32[$inArgs>>2]|0;
          $158 = (($16) + 4|0);
          $159 = HEAP16[$158>>1]|0;
          $160 = ($159<<16>>16)==(5);
          if ($160) {
           $163 = $16;
          } else {
           $163 = 0;
          }
          $161 = (__ZN5physx16PxVehicleDriveNW8allocateEj($31)|0);
          $162 = (($163) + 4|0);
          $164 = HEAP16[$162>>1]|0;
          $165 = ($164<<16>>16)==(5);
          $vehActor$$i = $165 ? $163 : 0;
          $166 = (($31) - ($167))|0;
          __ZN5physx16PxVehicleDriveNW5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataERKNS_23PxVehicleDriveSimDataNWEj($161,$157,$vehActor$$i,$48,$nmSimData,$166);
          ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
          __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleDriveNWEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$161,$inAllocator,$inCollection);
          $168 = (($161) + 72|0);
          $169 = HEAP32[$168>>2]|0;
          $170 = (($48) + 36|0);
          $171 = HEAP32[$170>>2]|0;
          $172 = ($171|0)==(0);
          if (!($172)) {
           $191 = $171;$i$010 = 0;
           while(1) {
            $173 = ((($169) + (($i$010*208)|0)|0) + 192|0);
            $174 = HEAP32[$173>>2]|0;
            $175 = (($174) + 352|0);
            $176 = HEAP32[$175>>2]|0;
            $177 = ($176|0)==(0|0);
            if ($177) {
             $182 = $191;
            } else {
             $178 = HEAP32[$inCollection>>2]|0;
             $179 = HEAP32[$178>>2]|0;
             FUNCTION_TABLE_viiii[$179 & 511]($inCollection,$176,0,0);
             $$pre = HEAP32[$170>>2]|0;
             $182 = $$pre;
            }
            $180 = (($i$010) + 1)|0;
            $181 = ($180>>>0)<($182>>>0);
            if ($181) {
             $191 = $182;$i$010 = $180;
            } else {
             break;
            }
           }
          }
          $183 = ($48|0)==(0|0);
          if (!($183)) {
           __ZN5physx22PxVehicleWheelsSimData4freeEv($48);
          }
          $184 = $161;
          HEAP32[$agg$result>>2] = 521432;
          $185 = (($agg$result) + 4|0);
          HEAP32[$185>>2] = $161;
          $186 = (($agg$result) + 8|0);
          $187 = $186;
          $188 = $187;
          HEAP32[$188>>2] = $184;
          $189 = (($187) + 4)|0;
          $190 = $189;
          HEAP32[$190>>2] = 0;
          STACKTOP = sp;return;
         }
        }
       }
      }
      HEAP32[$agg$result>>2] = 521184;
      $33 = (($agg$result) + 4|0);
      HEAP32[$33>>2] = 0;
      $34 = (($agg$result) + 8|0);
      $35 = $34;
      $36 = $35;
      HEAP32[$36>>2] = 0;
      $37 = (($35) + 4)|0;
      $38 = $37;
      HEAP32[$38>>2] = 0;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(3,521064,521088,98)|0);
 HEAP32[$agg$result>>2] = 521184;
 $17 = (($agg$result) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($agg$result) + 8|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = 0;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEE16objectToFileImplEPKS1_PNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE($this,$drive,$inCollection,$inWriter,$inTempBuffer,$0) {
 $this = $this|0;
 $drive = $drive|0;
 $inCollection = $inCollection|0;
 $inWriter = $inWriter|0;
 $inTempBuffer = $inTempBuffer|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $cond$i = 0, $magicptr$i = 0, $or$cond$i$i$i$i = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i = sp + 16|0;
 $1 = (($drive) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $magicptr$i = $2;
 $cond$i = ($2|0)==(0|0);
 if ($cond$i) {
  $24 = 0;$27 = 0;
 } else {
  $3 = HEAP32[$inCollection>>2]|0;
  $4 = (($3) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iii[$5 & 4095]($inCollection,$2)|0);
  if (!($6)) {
   (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(2,521064,523520,52)|0);
  }
  $7 = HEAP32[$inCollection>>2]|0;
  $8 = (($7) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_iii[$9 & 4095]($inCollection,$2)|0);
  $11 = tempRet0;
  $12 = ($10|0)==(0);
  $13 = ($11|0)==(0);
  $14 = $12 & $13;
  $15 = $14 ? $magicptr$i : $10;
  $16 = $14 ? 0 : $11;
  $24 = $15;$27 = $16;
 }
 $17 = HEAP32[$inWriter>>2]|0;
 $18 = (($17) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$vararg_buffer1>>2] = 523632;
 $20 = (($vararg_buffer1) + 4|0);
 HEAP32[$20>>2] = $2;
 $21 = (($vararg_buffer1) + 8|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = $24;
 $25 = (($22) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $27;
 FUNCTION_TABLE_viii[$19 & 4095]($inWriter,521064,$vararg_buffer1);
 $28 = (($drive) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer1>>2] = $29;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer1)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$inTempBuffer>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($inTempBuffer,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer1>>0] = 0;
 $35 = HEAP32[$inTempBuffer>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
 $37 = HEAP32[$inWriter>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($inTempBuffer) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($inWriter,521192,$41);
 $42 = (($inTempBuffer) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($inTempBuffer) + 12|0);
 HEAP32[$43>>2] = 0;
 $44 = (($drive) + 108|0);
 $45 = HEAP32[$44>>2]|0;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer1>>2] = $45;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer1)|0);
 $46 = HEAP8[$buffer$i$i$i>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if (!($47)) {
  $48 = HEAP32[$inTempBuffer>>2]|0;
  $49 = HEAP32[$48>>2]|0;
  $50 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$49 & 2047]($inTempBuffer,$buffer$i$i$i,$50)|0);
 }
 HEAP8[$vararg_buffer1>>0] = 0;
 $51 = HEAP32[$inTempBuffer>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 (FUNCTION_TABLE_iiii[$52 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
 $53 = HEAP32[$inWriter>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$55 & 4095]($inWriter,521208,$56);
 HEAP32[$42>>2] = 0;
 HEAP32[$43>>2] = 0;
 $57 = (($inTempBuffer) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 HEAP32[$vararg_buffer1>>2] = $58;
 $59 = (($vararg_buffer1) + 4|0);
 HEAP32[$59>>2] = 0;
 $60 = (($vararg_buffer1) + 8|0);
 HEAP32[$60>>2] = 0;
 $61 = (($vararg_buffer1) + 12|0);
 HEAP32[$61>>2] = 0;
 __ZN5physx2Sn18writeAllPropertiesINS_16PxVehicleDriveNWEEEvRNS_7profile12ProfileArrayINS0_14NameStackEntryEEEPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($vararg_buffer1,$drive,$inWriter,$inTempBuffer,$inCollection);
 $62 = HEAP32[$61>>2]|0;
 $63 = $62 & 2147483647;
 $64 = ($63|0)!=(0);
 $65 = ($62|0)>(-1);
 $or$cond$i$i$i$i = $64 & $65;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $66 = HEAP32[$59>>2]|0;
 $67 = ($66|0)==(0|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $68 = HEAP32[$vararg_buffer1>>2]|0;
 $69 = HEAP32[$68>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + 12|0);
 $72 = HEAP32[$71>>2]|0;
 FUNCTION_TABLE_vii[$72 & 4095]($69,$66);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEE14allocateObjectERNS_23PxRepXInstantiationArgsE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEE12fileToObjectERNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE($agg$result,$this,$inReader,$inAllocator,$inArgs,$inCollection) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inReader = $inReader|0;
 $inAllocator = $inAllocator|0;
 $inArgs = $inArgs|0;
 $inCollection = $inCollection|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $exitcond$i$i$i$i$i = 0, $i$01$i$i$i$i$i = 0, $i$010 = 0, $inArgs$byval_copy3 = 0;
 var $scevgep$i$i$i$i$i = 0, $theValue$i$i = 0, $theValue$i$i$i = 0, $theValue$i$i1 = 0, $value$i$i = 0, $vehActor$$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $inArgs$byval_copy3 = sp + 592|0;
 $theValue$i$i1 = sp;
 $theValue$i$i = sp + 4|0;
 $theValue$i$i$i = sp + 8|0;
 $value$i$i = sp + 16|0;
 $0 = HEAP32[$inReader>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 2047]($inReader,521064,$value$i$i)|0);
 do {
  if ($3) {
   $4 = HEAP32[$value$i$i>>2]|0;
   HEAP32[$theValue$i$i$i>>2] = $4;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = HEAP8[$4>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if (!($7)) {
     $8 = (_strtoull($4,$theValue$i$i$i,10)|0);
     $9 = tempRet0;
     $10 = ($8|0)==(0);
     $11 = ($9|0)==(0);
     $12 = $10 & $11;
     if (!($12)) {
      $13 = HEAP32[$inCollection>>2]|0;
      $14 = (($13) + 40|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (FUNCTION_TABLE_iiii[$15 & 2047]($inCollection,$8,$9)|0);
      $cond = ($16|0)==(0|0);
      if ($cond) {
       (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(2,521064,523648,130)|0);
       break;
      }
      $23 = HEAP32[$inReader>>2]|0;
      $24 = (($23) + 8|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (FUNCTION_TABLE_iiii[$25 & 2047]($inReader,521192,$inArgs$byval_copy3)|0);
      if ($26) {
       $27 = HEAP32[$inArgs$byval_copy3>>2]|0;
       HEAP32[$theValue$i$i>>2] = $27;
       $28 = ($27|0)==(0|0);
       if (!($28)) {
        $29 = HEAP8[$27>>0]|0;
        $30 = ($29<<24>>24)==(0);
        if (!($30)) {
         $31 = (_strtoul($27,$theValue$i$i,10)|0);
         $32 = ($31|0)==(0);
         if (!($32)) {
          $39 = HEAP32[$inReader>>2]|0;
          $40 = (($39) + 8|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = (FUNCTION_TABLE_iiii[$41 & 2047]($inReader,521208,$inArgs$byval_copy3)|0);
          if ($42) {
           $43 = HEAP32[$inArgs$byval_copy3>>2]|0;
           HEAP32[$theValue$i$i1>>2] = $43;
           $44 = ($43|0)==(0|0);
           if (!($44)) {
            $45 = HEAP8[$43>>0]|0;
            $46 = ($45<<24>>24)==(0);
            if (!($46)) {
             (_strtoul($43,$theValue$i$i1,10)|0);
            }
           }
          }
          $47 = (__ZN5physx22PxVehicleWheelsSimData8allocateEj($31)|0);
          $48 = HEAP32[$inReader>>2]|0;
          $49 = (($48) + 44|0);
          $50 = HEAP32[$49>>2]|0;
          FUNCTION_TABLE_vi[$50 & 4095]($inReader);
          $51 = HEAP32[$inReader>>2]|0;
          $52 = (($51) + 16|0);
          $53 = HEAP32[$52>>2]|0;
          $54 = (FUNCTION_TABLE_iii[$53 & 4095]($inReader,521232)|0);
          if ($54) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_22PxVehicleWheelsSimDataEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$47,$inAllocator,$inCollection);
          }
          $55 = HEAP32[$inReader>>2]|0;
          $56 = (($55) + 48|0);
          $57 = HEAP32[$56>>2]|0;
          FUNCTION_TABLE_vi[$57 & 4095]($inReader);
          $58 = (($value$i$i) + 64|0);
          $59 = (($value$i$i) + 80|0);
          HEAPF32[$59>>2] = Math_fround(1.0);
          $60 = (($value$i$i) + 84|0);
          HEAPF32[$60>>2] = Math_fround(500.0);
          $61 = (($value$i$i) + 88|0);
          HEAPF32[$61>>2] = Math_fround(600.0);
          $62 = (($value$i$i) + 92|0);
          HEAPF32[$62>>2] = Math_fround(0.150000005960464477539);
          $63 = (($value$i$i) + 96|0);
          HEAPF32[$63>>2] = Math_fround(2.0);
          $64 = (($value$i$i) + 100|0);
          HEAPF32[$64>>2] = Math_fround(0.349999994039535522461);
          HEAPF32[$value$i$i>>2] = Math_fround(0.0);
          $65 = (($value$i$i) + 4|0);
          HEAPF32[$65>>2] = Math_fround(0.800000011920928955078);
          $66 = (($value$i$i) + 8|0);
          HEAPF32[$66>>2] = Math_fround(0.330000013113021850586);
          $67 = (($value$i$i) + 12|0);
          HEAPF32[$67>>2] = Math_fround(1.0);
          $68 = (($value$i$i) + 16|0);
          HEAPF32[$68>>2] = Math_fround(1.0);
          $69 = (($value$i$i) + 20|0);
          HEAPF32[$69>>2] = Math_fround(0.800000011920928955078);
          HEAP32[$58>>2] = 3;
          $70 = (($value$i$i) + 104|0);
          HEAPF32[$70>>2] = Math_fround(1.0);
          $71 = (($value$i$i) + 108|0);
          HEAPF32[$71>>2] = Math_fround(0.00166666670702397823334);
          $72 = (($value$i$i) + 240|0);
          HEAPF32[$72>>2] = Math_fround(4.0);
          $73 = (($value$i$i) + 244|0);
          HEAP32[$73>>2] = 7;
          $74 = (($value$i$i) + 248|0);
          HEAPF32[$74>>2] = Math_fround(0.5);
          $75 = (($value$i$i) + 112|0);
          HEAPF32[$75>>2] = Math_fround(-4.0);
          $76 = (($value$i$i) + 116|0);
          HEAPF32[$76>>2] = Math_fround(0.0);
          $77 = (($value$i$i) + 120|0);
          HEAPF32[$77>>2] = Math_fround(4.0);
          $78 = (($value$i$i) + 124|0);
          HEAPF32[$78>>2] = Math_fround(2.0);
          $79 = (($value$i$i) + 128|0);
          HEAPF32[$79>>2] = Math_fround(1.5);
          $80 = (($value$i$i) + 132|0);
          HEAPF32[$80>>2] = Math_fround(1.10000002384185791016);
          $81 = (($value$i$i) + 136|0);
          HEAPF32[$81>>2] = Math_fround(1.0);
          $scevgep$i$i$i$i$i = (($value$i$i) + 140|0);
          dest=$scevgep$i$i$i$i$i+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          $82 = (($value$i$i) + 256|0);
          HEAPF32[$82>>2] = Math_fround(10.0);
          $83 = (($value$i$i) + 260|0);
          HEAP32[$83>>2] = 1;
          $84 = (($value$i$i) + 264|0);
          HEAP32[$84>>2] = 5;
          $i$01$i$i$i$i$i = 0;
          while(1) {
           $85 = ((($value$i$i) + ($i$01$i$i$i$i$i<<2)|0) + 272|0);
           HEAPF32[$85>>2] = Math_fround(0.649999976158142089844);
           $86 = ((($value$i$i) + ($i$01$i$i$i$i$i<<2)|0) + 400|0);
           HEAPF32[$86>>2] = Math_fround(0.5);
           $87 = (($i$01$i$i$i$i$i) + 1)|0;
           $exitcond$i$i$i$i$i = ($87|0)==(32);
           if ($exitcond$i$i$i$i$i) {
            break;
           } else {
            $i$01$i$i$i$i$i = $87;
           }
          }
          $88 = (($value$i$i) + 276|0);
          HEAPF32[$88>>2] = Math_fround(0.150000005960464477539);
          $89 = (($value$i$i) + 400|0);
          HEAPF32[$89>>2] = Math_fround(2.0);
          $90 = (($value$i$i) + 528|0);
          HEAPF32[$90>>2] = Math_fround(0.449999988079071044922);
          $91 = (($value$i$i) + 532|0);
          HEAPF32[$91>>2] = Math_fround(0.5);
          $92 = (($value$i$i) + 536|0);
          HEAPF32[$92>>2] = Math_fround(0.5);
          $93 = (($value$i$i) + 540|0);
          HEAPF32[$93>>2] = Math_fround(1.29999995231628417969);
          $94 = (($value$i$i) + 544|0);
          HEAPF32[$94>>2] = Math_fround(1.29999995231628417969);
          $95 = (($value$i$i) + 548|0);
          HEAPF32[$95>>2] = Math_fround(1.29999995231628417969);
          $96 = (($value$i$i) + 552|0);
          HEAP32[$96>>2] = 0;
          $97 = (($value$i$i) + 560|0);
          HEAPF32[$97>>2] = Math_fround(1.0);
          $98 = (($value$i$i) + 564|0);
          HEAPF32[$98>>2] = Math_fround(0.0);
          $99 = (($value$i$i) + 568|0);
          HEAPF32[$99>>2] = Math_fround(0.0);
          $100 = (($value$i$i) + 572|0);
          HEAPF32[$100>>2] = Math_fround(0.0);
          $101 = HEAP32[$inReader>>2]|0;
          $102 = (($101) + 44|0);
          $103 = HEAP32[$102>>2]|0;
          FUNCTION_TABLE_vi[$103 & 4095]($inReader);
          $104 = HEAP32[$inReader>>2]|0;
          $105 = (($104) + 16|0);
          $106 = HEAP32[$105>>2]|0;
          $107 = (FUNCTION_TABLE_iii[$106 & 4095]($inReader,521248)|0);
          if ($107) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$value$i$i,$inAllocator,$inCollection);
          }
          $108 = HEAP32[$inReader>>2]|0;
          $109 = (($108) + 48|0);
          $110 = HEAP32[$109>>2]|0;
          FUNCTION_TABLE_vi[$110 & 4095]($inReader);
          $111 = HEAP32[$inReader>>2]|0;
          $112 = (($111) + 44|0);
          $113 = HEAP32[$112>>2]|0;
          FUNCTION_TABLE_vi[$113 & 4095]($inReader);
          $114 = HEAP32[$inReader>>2]|0;
          $115 = (($114) + 16|0);
          $116 = HEAP32[$115>>2]|0;
          $117 = (FUNCTION_TABLE_iii[$116 & 4095]($inReader,521264)|0);
          if ($117) {
           ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
           __ZN5physx2Sn17readAllPropertiesINS_23PxVehicleDriveSimData4WEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$value$i$i,$inAllocator,$inCollection);
          }
          $118 = HEAP32[$inReader>>2]|0;
          $119 = (($118) + 48|0);
          $120 = HEAP32[$119>>2]|0;
          FUNCTION_TABLE_vi[$120 & 4095]($inReader);
          $121 = HEAP32[$inArgs>>2]|0;
          $122 = (($16) + 4|0);
          $123 = HEAP16[$122>>1]|0;
          $124 = ($123<<16>>16)==(5);
          if ($124) {
           $127 = $16;
          } else {
           $127 = 0;
          }
          $125 = (__ZN5physx16PxVehicleNoDrive8allocateEj($31)|0);
          $126 = (($127) + 4|0);
          $128 = HEAP16[$126>>1]|0;
          $129 = ($128<<16>>16)==(5);
          $vehActor$$i = $129 ? $127 : 0;
          __ZN5physx16PxVehicleNoDrive5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataE($125,$121,$vehActor$$i,$47);
          ;HEAP32[$inArgs$byval_copy3+0>>2]=HEAP32[$inArgs+0>>2]|0;HEAP32[$inArgs$byval_copy3+4>>2]=HEAP32[$inArgs+4>>2]|0;HEAP32[$inArgs$byval_copy3+8>>2]=HEAP32[$inArgs+8>>2]|0;
          __ZN5physx2Sn17readAllPropertiesINS_16PxVehicleNoDriveEEEvNS_23PxRepXInstantiationArgsERNS_9XmlReaderEPT_RNS_18XmlMemoryAllocatorERNS_12PxCollectionE($inArgs$byval_copy3,$inReader,$125,$inAllocator,$inCollection);
          $130 = (($125) + 72|0);
          $131 = HEAP32[$130>>2]|0;
          $132 = (($47) + 36|0);
          $133 = HEAP32[$132>>2]|0;
          $134 = ($133|0)==(0);
          if (!($134)) {
           $153 = $133;$i$010 = 0;
           while(1) {
            $135 = ((($131) + (($i$010*208)|0)|0) + 192|0);
            $136 = HEAP32[$135>>2]|0;
            $137 = (($136) + 352|0);
            $138 = HEAP32[$137>>2]|0;
            $139 = ($138|0)==(0|0);
            if ($139) {
             $144 = $153;
            } else {
             $140 = HEAP32[$inCollection>>2]|0;
             $141 = HEAP32[$140>>2]|0;
             FUNCTION_TABLE_viiii[$141 & 511]($inCollection,$138,0,0);
             $$pre = HEAP32[$132>>2]|0;
             $144 = $$pre;
            }
            $142 = (($i$010) + 1)|0;
            $143 = ($142>>>0)<($144>>>0);
            if ($143) {
             $153 = $144;$i$010 = $142;
            } else {
             break;
            }
           }
          }
          $145 = ($47|0)==(0|0);
          if (!($145)) {
           __ZN5physx22PxVehicleWheelsSimData4freeEv($47);
          }
          $146 = $125;
          HEAP32[$agg$result>>2] = 521480;
          $147 = (($agg$result) + 4|0);
          HEAP32[$147>>2] = $125;
          $148 = (($agg$result) + 8|0);
          $149 = $148;
          $150 = $149;
          HEAP32[$150>>2] = $146;
          $151 = (($149) + 4)|0;
          $152 = $151;
          HEAP32[$152>>2] = 0;
          STACKTOP = sp;return;
         }
        }
       }
      }
      HEAP32[$agg$result>>2] = 521184;
      $33 = (($agg$result) + 4|0);
      HEAP32[$33>>2] = 0;
      $34 = (($agg$result) + 8|0);
      $35 = $34;
      $36 = $35;
      HEAP32[$36>>2] = 0;
      $37 = (($35) + 4)|0;
      $38 = $37;
      HEAP32[$38>>2] = 0;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(3,521064,521088,98)|0);
 HEAP32[$agg$result>>2] = 521184;
 $17 = (($agg$result) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($agg$result) + 8|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = 0;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEE16objectToFileImplEPKS1_PNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE($this,$drive,$inCollection,$inWriter,$inTempBuffer,$0) {
 $this = $this|0;
 $drive = $drive|0;
 $inCollection = $inCollection|0;
 $inWriter = $inWriter|0;
 $inTempBuffer = $inTempBuffer|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $buffer$i$i$i = 0, $cond$i = 0, $magicptr$i = 0, $or$cond$i$i$i$i = 0, $theNames$i = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i = sp + 72|0;
 $1 = sp + 28|0;
 $theNames$i = sp + 56|0;
 $2 = (($drive) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 $magicptr$i = $3;
 $cond$i = ($3|0)==(0|0);
 if ($cond$i) {
  $25 = 0;$28 = 0;
 } else {
  $4 = HEAP32[$inCollection>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iii[$6 & 4095]($inCollection,$3)|0);
  if (!($7)) {
   (__ZN5physx2Sn11ReportErrorENS0_15PxRepXErrorCode4EnumEPKcS4_i(2,521064,523520,52)|0);
  }
  $8 = HEAP32[$inCollection>>2]|0;
  $9 = (($8) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_iii[$10 & 4095]($inCollection,$3)|0);
  $12 = tempRet0;
  $13 = ($11|0)==(0);
  $14 = ($12|0)==(0);
  $15 = $13 & $14;
  $16 = $15 ? $magicptr$i : $11;
  $17 = $15 ? 0 : $12;
  $25 = $16;$28 = $17;
 }
 $18 = HEAP32[$inWriter>>2]|0;
 $19 = (($18) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$vararg_buffer1>>2] = 523632;
 $21 = (($vararg_buffer1) + 4|0);
 HEAP32[$21>>2] = $3;
 $22 = (($vararg_buffer1) + 8|0);
 $23 = $22;
 $24 = $23;
 HEAP32[$24>>2] = $25;
 $26 = (($23) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $28;
 FUNCTION_TABLE_viii[$20 & 4095]($inWriter,521064,$vararg_buffer1);
 $29 = (($drive) + 48|0);
 $30 = HEAP32[$29>>2]|0;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer1>>2] = $30;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer1)|0);
 $31 = HEAP8[$buffer$i$i$i>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if (!($32)) {
  $33 = HEAP32[$inTempBuffer>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$34 & 2047]($inTempBuffer,$buffer$i$i$i,$35)|0);
 }
 HEAP8[$vararg_buffer1>>0] = 0;
 $36 = HEAP32[$inTempBuffer>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 (FUNCTION_TABLE_iiii[$37 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
 $38 = HEAP32[$inWriter>>2]|0;
 $39 = (($38) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($inTempBuffer) + 20|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_viii[$40 & 4095]($inWriter,521192,$42);
 $43 = (($inTempBuffer) + 16|0);
 HEAP32[$43>>2] = 0;
 $44 = (($inTempBuffer) + 12|0);
 HEAP32[$44>>2] = 0;
 $45 = (($drive) + 108|0);
 $46 = HEAP32[$45>>2]|0;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer1>>2] = $46;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer1)|0);
 $47 = HEAP8[$buffer$i$i$i>>0]|0;
 $48 = ($47<<24>>24)==(0);
 if (!($48)) {
  $49 = HEAP32[$inTempBuffer>>2]|0;
  $50 = HEAP32[$49>>2]|0;
  $51 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$50 & 2047]($inTempBuffer,$buffer$i$i$i,$51)|0);
 }
 HEAP8[$vararg_buffer1>>0] = 0;
 $52 = HEAP32[$inTempBuffer>>2]|0;
 $53 = HEAP32[$52>>2]|0;
 (FUNCTION_TABLE_iiii[$53 & 2047]($inTempBuffer,$vararg_buffer1,1)|0);
 $54 = HEAP32[$inWriter>>2]|0;
 $55 = (($54) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_viii[$56 & 4095]($inWriter,521208,$57);
 HEAP32[$43>>2] = 0;
 HEAP32[$44>>2] = 0;
 $58 = (($inTempBuffer) + 8|0);
 $59 = HEAP32[$58>>2]|0;
 HEAP32[$theNames$i>>2] = $59;
 $60 = (($theNames$i) + 4|0);
 HEAP32[$60>>2] = 0;
 $61 = (($theNames$i) + 8|0);
 HEAP32[$61>>2] = 0;
 $62 = (($theNames$i) + 12|0);
 HEAP32[$62>>2] = 0;
 __ZN5physx29PxVehicleNoDriveGeneratedInfoC2Ev($buffer$i$i$i);
 HEAP32[$vararg_buffer1>>2] = $theNames$i;
 $63 = (($vararg_buffer1) + 4|0);
 HEAP32[$63>>2] = $inWriter;
 $64 = (($vararg_buffer1) + 8|0);
 HEAP32[$64>>2] = $drive;
 $65 = (($vararg_buffer1) + 12|0);
 HEAP32[$65>>2] = $inTempBuffer;
 $66 = (($vararg_buffer1) + 16|0);
 HEAP32[$66>>2] = $inCollection;
 $67 = (($vararg_buffer1) + 20|0);
 HEAP32[$67>>2] = 0;
 $68 = (($vararg_buffer1) + 24|0);
 HEAP32[$68>>2] = 0;
 (__ZNK5physx28PxVehicleWheelsGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleNoDriveEEEEEEEjT_j($buffer$i$i$i,$vararg_buffer1,0)|0);
 HEAP32[$1>>2] = $theNames$i;
 $69 = (($1) + 4|0);
 HEAP32[$69>>2] = $inWriter;
 $70 = (($1) + 8|0);
 HEAP32[$70>>2] = $drive;
 $71 = (($1) + 12|0);
 HEAP32[$71>>2] = $inTempBuffer;
 $72 = (($1) + 16|0);
 HEAP32[$72>>2] = $inCollection;
 $73 = (($1) + 20|0);
 HEAP32[$73>>2] = 0;
 $74 = (($1) + 24|0);
 HEAP32[$74>>2] = 0;
 (__ZNK5physx29PxVehicleNoDriveGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleNoDriveEEEEEEEjT_j($buffer$i$i$i,$1,0)|0);
 $75 = HEAP32[$62>>2]|0;
 $76 = $75 & 2147483647;
 $77 = ($76|0)!=(0);
 $78 = ($75|0)>(-1);
 $or$cond$i$i$i$i = $77 & $78;
 if (!($or$cond$i$i$i$i)) {
  STACKTOP = sp;return;
 }
 $79 = HEAP32[$60>>2]|0;
 $80 = ($79|0)==(0|0);
 if ($80) {
  STACKTOP = sp;return;
 }
 $81 = HEAP32[$theNames$i>>2]|0;
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$82>>2]|0;
 $84 = (($83) + 12|0);
 $85 = HEAP32[$84>>2]|0;
 FUNCTION_TABLE_vii[$85 & 4095]($82,$79);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEE14allocateObjectERNS_23PxRepXInstantiationArgsE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN5physx16PxVehicleNoDriveC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 512;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 $2 = (($this) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 12|0);
 HEAPF32[$3>>2] = Math_fround(0.230800002813339233398);
 $4 = (($this) + 16|0);
 HEAPF32[$4>>2] = Math_fround(3.0);
 $5 = (($this) + 20|0);
 HEAPF32[$5>>2] = Math_fround(3.0);
 $6 = (($this) + 24|0);
 HEAPF32[$6>>2] = Math_fround(0.333333343267440795898);
 HEAP32[$this>>2] = ((518776 + 8|0));
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleDrive4WC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i$i$i = 0, $i$01$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 513;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 $2 = (($this) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 12|0);
 HEAPF32[$3>>2] = Math_fround(0.230800002813339233398);
 $4 = (($this) + 16|0);
 HEAPF32[$4>>2] = Math_fround(3.0);
 $5 = (($this) + 20|0);
 HEAPF32[$5>>2] = Math_fround(3.0);
 $6 = (($this) + 24|0);
 HEAPF32[$6>>2] = Math_fround(0.333333343267440795898);
 HEAP32[$this>>2] = ((523760 + 8|0));
 $7 = (($this) + 128|0);
 __ZN5physx21PxVehicleDriveDynDataC2Ev($7);
 HEAP32[$this>>2] = ((518896 + 8|0));
 $8 = (($this) + 288|0);
 $9 = (($this) + 304|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 308|0);
 HEAPF32[$10>>2] = Math_fround(500.0);
 $11 = (($this) + 312|0);
 HEAPF32[$11>>2] = Math_fround(600.0);
 $12 = (($this) + 316|0);
 HEAPF32[$12>>2] = Math_fround(0.150000005960464477539);
 $13 = (($this) + 320|0);
 HEAPF32[$13>>2] = Math_fround(2.0);
 $14 = (($this) + 324|0);
 HEAPF32[$14>>2] = Math_fround(0.349999994039535522461);
 $15 = (($this) + 224|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 228|0);
 HEAPF32[$16>>2] = Math_fround(0.800000011920928955078);
 $17 = (($this) + 232|0);
 HEAPF32[$17>>2] = Math_fround(0.330000013113021850586);
 $18 = (($this) + 236|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 240|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($this) + 244|0);
 HEAPF32[$20>>2] = Math_fround(0.800000011920928955078);
 HEAP32[$8>>2] = 3;
 $21 = (($this) + 328|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 332|0);
 HEAPF32[$22>>2] = Math_fround(0.00166666670702397823334);
 $23 = (($this) + 464|0);
 HEAPF32[$23>>2] = Math_fround(4.0);
 $24 = (($this) + 468|0);
 HEAP32[$24>>2] = 7;
 $25 = (($this) + 472|0);
 HEAPF32[$25>>2] = Math_fround(0.5);
 $26 = (($this) + 336|0);
 HEAPF32[$26>>2] = Math_fround(-4.0);
 $27 = (($this) + 340|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 344|0);
 HEAPF32[$28>>2] = Math_fround(4.0);
 $29 = (($this) + 348|0);
 HEAPF32[$29>>2] = Math_fround(2.0);
 $30 = (($this) + 352|0);
 HEAPF32[$30>>2] = Math_fround(1.5);
 $31 = (($this) + 356|0);
 HEAPF32[$31>>2] = Math_fround(1.10000002384185791016);
 $32 = (($this) + 360|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $scevgep$i$i$i$i$i = (($this) + 364|0);
 dest=$scevgep$i$i$i$i$i+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $33 = (($this) + 480|0);
 HEAPF32[$33>>2] = Math_fround(10.0);
 $34 = (($this) + 484|0);
 HEAP32[$34>>2] = 1;
 $35 = (($this) + 488|0);
 HEAP32[$35>>2] = 5;
 $i$01$i$i$i$i$i = 0;
 while(1) {
  $36 = ((($this) + ($i$01$i$i$i$i$i<<2)|0) + 496|0);
  HEAPF32[$36>>2] = Math_fround(0.649999976158142089844);
  $37 = ((($this) + ($i$01$i$i$i$i$i<<2)|0) + 624|0);
  HEAPF32[$37>>2] = Math_fround(0.5);
  $38 = (($i$01$i$i$i$i$i) + 1)|0;
  $exitcond$i$i$i$i$i = ($38|0)==(32);
  if ($exitcond$i$i$i$i$i) {
   break;
  } else {
   $i$01$i$i$i$i$i = $38;
  }
 }
 $39 = (($this) + 500|0);
 HEAPF32[$39>>2] = Math_fround(0.150000005960464477539);
 $40 = (($this) + 624|0);
 HEAPF32[$40>>2] = Math_fround(2.0);
 $41 = (($this) + 752|0);
 HEAPF32[$41>>2] = Math_fround(0.449999988079071044922);
 $42 = (($this) + 756|0);
 HEAPF32[$42>>2] = Math_fround(0.5);
 $43 = (($this) + 760|0);
 HEAPF32[$43>>2] = Math_fround(0.5);
 $44 = (($this) + 764|0);
 HEAPF32[$44>>2] = Math_fround(1.29999995231628417969);
 $45 = (($this) + 768|0);
 HEAPF32[$45>>2] = Math_fround(1.29999995231628417969);
 $46 = (($this) + 772|0);
 HEAPF32[$46>>2] = Math_fround(1.29999995231628417969);
 $47 = (($this) + 776|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 784|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($this) + 788|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($this) + 792|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($this) + 796|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleDriveNWC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i$i$i = 0, $i$01$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 514;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 $2 = (($this) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 12|0);
 HEAPF32[$3>>2] = Math_fround(0.230800002813339233398);
 $4 = (($this) + 16|0);
 HEAPF32[$4>>2] = Math_fround(3.0);
 $5 = (($this) + 20|0);
 HEAPF32[$5>>2] = Math_fround(3.0);
 $6 = (($this) + 24|0);
 HEAPF32[$6>>2] = Math_fround(0.333333343267440795898);
 HEAP32[$this>>2] = ((523760 + 8|0));
 $7 = (($this) + 128|0);
 __ZN5physx21PxVehicleDriveDynDataC2Ev($7);
 HEAP32[$this>>2] = ((518856 + 8|0));
 $8 = (($this) + 288|0);
 $9 = (($this) + 304|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 308|0);
 HEAPF32[$10>>2] = Math_fround(500.0);
 $11 = (($this) + 312|0);
 HEAPF32[$11>>2] = Math_fround(600.0);
 $12 = (($this) + 316|0);
 HEAPF32[$12>>2] = Math_fround(0.150000005960464477539);
 $13 = (($this) + 320|0);
 HEAPF32[$13>>2] = Math_fround(2.0);
 $14 = (($this) + 324|0);
 HEAPF32[$14>>2] = Math_fround(0.349999994039535522461);
 $15 = (($this) + 224|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 228|0);
 HEAPF32[$16>>2] = Math_fround(0.800000011920928955078);
 $17 = (($this) + 232|0);
 HEAPF32[$17>>2] = Math_fround(0.330000013113021850586);
 $18 = (($this) + 236|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 240|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($this) + 244|0);
 HEAPF32[$20>>2] = Math_fround(0.800000011920928955078);
 HEAP32[$8>>2] = 3;
 $21 = (($this) + 328|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 332|0);
 HEAPF32[$22>>2] = Math_fround(0.00166666670702397823334);
 $23 = (($this) + 464|0);
 HEAPF32[$23>>2] = Math_fround(4.0);
 $24 = (($this) + 468|0);
 HEAP32[$24>>2] = 7;
 $25 = (($this) + 472|0);
 HEAPF32[$25>>2] = Math_fround(0.5);
 $26 = (($this) + 336|0);
 HEAPF32[$26>>2] = Math_fround(-4.0);
 $27 = (($this) + 340|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 344|0);
 HEAPF32[$28>>2] = Math_fround(4.0);
 $29 = (($this) + 348|0);
 HEAPF32[$29>>2] = Math_fround(2.0);
 $30 = (($this) + 352|0);
 HEAPF32[$30>>2] = Math_fround(1.5);
 $31 = (($this) + 356|0);
 HEAPF32[$31>>2] = Math_fround(1.10000002384185791016);
 $32 = (($this) + 360|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $scevgep$i$i$i$i$i = (($this) + 364|0);
 dest=$scevgep$i$i$i$i$i+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $33 = (($this) + 480|0);
 HEAPF32[$33>>2] = Math_fround(10.0);
 $34 = (($this) + 484|0);
 HEAP32[$34>>2] = 1;
 $35 = (($this) + 488|0);
 HEAP32[$35>>2] = 5;
 $i$01$i$i$i$i$i = 0;
 while(1) {
  $36 = ((($this) + ($i$01$i$i$i$i$i<<2)|0) + 496|0);
  HEAPF32[$36>>2] = Math_fround(0.649999976158142089844);
  $37 = ((($this) + ($i$01$i$i$i$i$i<<2)|0) + 624|0);
  HEAPF32[$37>>2] = Math_fround(0.5);
  $38 = (($i$01$i$i$i$i$i) + 1)|0;
  $exitcond$i$i$i$i$i = ($38|0)==(32);
  if ($exitcond$i$i$i$i$i) {
   break;
  } else {
   $i$01$i$i$i$i$i = $38;
  }
 }
 $39 = (($this) + 500|0);
 HEAPF32[$39>>2] = Math_fround(0.150000005960464477539);
 $40 = (($this) + 624|0);
 HEAPF32[$40>>2] = Math_fround(2.0);
 $41 = (($this) + 752|0);
 HEAP8[$41>>0]=0&255;HEAP8[$41+1>>0]=(0>>8)&255;HEAP8[$41+2>>0]=(0>>16)&255;HEAP8[$41+3>>0]=0>>24;
 $42 = (($this) + 756|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 760|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx18PxVehicleDriveTankC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond$i$i$i$i = 0, $i$01$i$i$i$i = 0, $scevgep$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 515;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 $2 = (($this) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 12|0);
 HEAPF32[$3>>2] = Math_fround(0.230800002813339233398);
 $4 = (($this) + 16|0);
 HEAPF32[$4>>2] = Math_fround(3.0);
 $5 = (($this) + 20|0);
 HEAPF32[$5>>2] = Math_fround(3.0);
 $6 = (($this) + 24|0);
 HEAPF32[$6>>2] = Math_fround(0.333333343267440795898);
 HEAP32[$this>>2] = ((523760 + 8|0));
 $7 = (($this) + 128|0);
 __ZN5physx21PxVehicleDriveDynDataC2Ev($7);
 HEAP32[$this>>2] = ((518816 + 8|0));
 $8 = (($this) + 288|0);
 $9 = (($this) + 304|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 308|0);
 HEAPF32[$10>>2] = Math_fround(500.0);
 $11 = (($this) + 312|0);
 HEAPF32[$11>>2] = Math_fround(600.0);
 $12 = (($this) + 316|0);
 HEAPF32[$12>>2] = Math_fround(0.150000005960464477539);
 $13 = (($this) + 320|0);
 HEAPF32[$13>>2] = Math_fround(2.0);
 $14 = (($this) + 324|0);
 HEAPF32[$14>>2] = Math_fround(0.349999994039535522461);
 $15 = (($this) + 224|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 228|0);
 HEAPF32[$16>>2] = Math_fround(0.800000011920928955078);
 $17 = (($this) + 232|0);
 HEAPF32[$17>>2] = Math_fround(0.330000013113021850586);
 $18 = (($this) + 236|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 240|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($this) + 244|0);
 HEAPF32[$20>>2] = Math_fround(0.800000011920928955078);
 HEAP32[$8>>2] = 3;
 $21 = (($this) + 328|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 332|0);
 HEAPF32[$22>>2] = Math_fround(0.00166666670702397823334);
 $23 = (($this) + 464|0);
 HEAPF32[$23>>2] = Math_fround(4.0);
 $24 = (($this) + 468|0);
 HEAP32[$24>>2] = 7;
 $25 = (($this) + 472|0);
 HEAPF32[$25>>2] = Math_fround(0.5);
 $26 = (($this) + 336|0);
 HEAPF32[$26>>2] = Math_fround(-4.0);
 $27 = (($this) + 340|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 344|0);
 HEAPF32[$28>>2] = Math_fround(4.0);
 $29 = (($this) + 348|0);
 HEAPF32[$29>>2] = Math_fround(2.0);
 $30 = (($this) + 352|0);
 HEAPF32[$30>>2] = Math_fround(1.5);
 $31 = (($this) + 356|0);
 HEAPF32[$31>>2] = Math_fround(1.10000002384185791016);
 $32 = (($this) + 360|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $scevgep$i$i$i$i = (($this) + 364|0);
 dest=$scevgep$i$i$i$i+0|0; stop=dest+100|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $33 = (($this) + 480|0);
 HEAPF32[$33>>2] = Math_fround(10.0);
 $34 = (($this) + 484|0);
 HEAP32[$34>>2] = 1;
 $35 = (($this) + 488|0);
 HEAP32[$35>>2] = 5;
 $i$01$i$i$i$i = 0;
 while(1) {
  $36 = ((($this) + ($i$01$i$i$i$i<<2)|0) + 496|0);
  HEAPF32[$36>>2] = Math_fround(0.649999976158142089844);
  $37 = ((($this) + ($i$01$i$i$i$i<<2)|0) + 624|0);
  HEAPF32[$37>>2] = Math_fround(0.5);
  $38 = (($i$01$i$i$i$i) + 1)|0;
  $exitcond$i$i$i$i = ($38|0)==(32);
  if ($exitcond$i$i$i$i) {
   break;
  } else {
   $i$01$i$i$i$i = $38;
  }
 }
 $39 = (($this) + 500|0);
 HEAPF32[$39>>2] = Math_fround(0.150000005960464477539);
 $40 = (($this) + 624|0);
 HEAPF32[$40>>2] = Math_fround(2.0);
 $41 = (($this) + 752|0);
 HEAP32[$41>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx29PxVehicleNoDriveGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleNoDriveEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i$i$i = 0, $$phi$trans$insert$i$i$i$i14 = 0, $$phi$trans$insert$i$i$i$i3 = 0, $$phi$trans$insert$i18 = 0, $$phi$trans$insert$i7 = 0, $$phi$trans$insert25 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i13 = 0, $$pre$i$i$i$i2 = 0, $$pre$i$i10 = 0, $$pre$i$i21 = 0, $$pre$i17 = 0, $$pre$i6 = 0, $$pre1$i = 0, $$pre1$i$i$i$i = 0;
 var $$pre1$i$i$i$i15 = 0, $$pre1$i$i$i$i4 = 0, $$pre1$i19 = 0, $$pre1$i8 = 0, $$pre23 = 0, $$pre24 = 0, $$pre26 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $theAccessor$i$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i$i$i12 = sp + 8|0;
 $1 = (($this) + 68|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$inOperator>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $29 = $3;$34 = 0;
 } else {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9) + ($7<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($inOperator) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($9) + ($7<<3)|0);
   $19 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_vii[$17 & 4095]($14,$19);
   $20 = HEAP32[$inOperator>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + -1)|0;
   $24 = (($20) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($25) + ($23<<3)|0) + 4|0);
   HEAP8[$26>>0] = 1;
   $$pre$i6 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i7 = (($$pre$i6) + 8|0);
   $$pre1$i8 = HEAP32[$$phi$trans$insert$i7>>2]|0;
   $29 = $$pre$i6;$34 = $$pre1$i8;
  } else {
   $29 = $3;$34 = $5;
  }
 }
 HEAP32[$0>>2] = $2;
 $27 = (($0) + 4|0);
 HEAP8[$27>>0] = 0;
 $28 = (($29) + 12|0);
 $30 = HEAP32[$28>>2]|0;
 $31 = $30 & 2147483647;
 $32 = (($29) + 8|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  $35 = (($29) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($34<<3)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   $50 = $34;
  } else {
   $39 = $0;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 4)|0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = $37;
   $46 = $45;
   HEAP32[$46>>2] = $41;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $44;
   $$pre$i$i10 = HEAP32[$32>>2]|0;
   $50 = $$pre$i$i10;
  }
  $49 = (($50) + 1)|0;
  HEAP32[$32>>2] = $49;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($29,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i12>>0] = 0;
 $51 = (($theAccessor$i$i$i12) + 4|0);
 HEAP32[$51>>2] = 0;
 $52 = (($theAccessor$i$i$i12) + 8|0);
 HEAP32[$52>>2] = $inStartIndex;
 $53 = (($theAccessor$i$i$i12) + 12|0);
 HEAP32[$53>>2] = $1;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj685ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i12,0);
 $54 = HEAP32[$inOperator>>2]|0;
 $55 = (($54) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0);
 if ($57) {
  $77 = 0;$80 = $54;
 } else {
  $58 = (($56) + -1)|0;
  $59 = (($54) + 4|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($60) + ($58<<3)|0) + 4|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = ($62<<24>>24)==(0);
  if ($63) {
   $70 = $54;$72 = $56;
  } else {
   $64 = (($inOperator) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[$65>>2]|0;
   $67 = (($66) + 20|0);
   $68 = HEAP32[$67>>2]|0;
   FUNCTION_TABLE_vi[$68 & 4095]($65);
   $$pre$i$i$i$i2 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i3 = (($$pre$i$i$i$i2) + 8|0);
   $$pre1$i$i$i$i4 = HEAP32[$$phi$trans$insert$i$i$i$i3>>2]|0;
   $70 = $$pre$i$i$i$i2;$72 = $$pre1$i$i$i$i4;
  }
  $69 = (($70) + 8|0);
  $71 = (($72) + -1)|0;
  HEAP32[$69>>2] = $71;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre23 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre23;$80 = $$pre;
 }
 $73 = (($this) + 92|0);
 $74 = (($inStartIndex) + 1)|0;
 $75 = HEAP32[$73>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i17 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i18 = (($$pre$i17) + 8|0);
   $$pre1$i19 = HEAP32[$$phi$trans$insert$i18>>2]|0;
   $101 = $$pre$i17;$106 = $$pre1$i19;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i21 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i21;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i12>>0] = 0;
 $123 = (($theAccessor$i$i$i12) + 4|0);
 HEAP32[$123>>2] = 0;
 $124 = (($theAccessor$i$i$i12) + 8|0);
 HEAP32[$124>>2] = $74;
 $125 = (($theAccessor$i$i$i12) + 12|0);
 HEAP32[$125>>2] = $73;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj686ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i12,0);
 $126 = HEAP32[$inOperator>>2]|0;
 $127 = (($126) + 8|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = ($128|0)==(0);
 if ($129) {
  $149 = 0;$152 = $126;
 } else {
  $130 = (($128) + -1)|0;
  $131 = (($126) + 4|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = ((($132) + ($130<<3)|0) + 4|0);
  $134 = HEAP8[$133>>0]|0;
  $135 = ($134<<24>>24)==(0);
  if ($135) {
   $142 = $126;$144 = $128;
  } else {
   $136 = (($inOperator) + 4|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = HEAP32[$137>>2]|0;
   $139 = (($138) + 20|0);
   $140 = HEAP32[$139>>2]|0;
   FUNCTION_TABLE_vi[$140 & 4095]($137);
   $$pre$i$i$i$i13 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i14 = (($$pre$i$i$i$i13) + 8|0);
   $$pre1$i$i$i$i15 = HEAP32[$$phi$trans$insert$i$i$i$i14>>2]|0;
   $142 = $$pre$i$i$i$i13;$144 = $$pre1$i$i$i$i15;
  }
  $141 = (($142) + 8|0);
  $143 = (($144) + -1)|0;
  HEAP32[$141>>2] = $143;
  $$pre24 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert25 = (($$pre24) + 8|0);
  $$pre26 = HEAP32[$$phi$trans$insert25>>2]|0;
  $149 = $$pre26;$152 = $$pre24;
 }
 $145 = (($this) + 116|0);
 $146 = (($inStartIndex) + 2)|0;
 $147 = HEAP32[$145>>2]|0;
 $148 = ($149|0)==(0);
 if ($148) {
  $173 = $152;$178 = 0;
 } else {
  $150 = (($149) + -1)|0;
  $151 = (($152) + 4|0);
  $153 = HEAP32[$151>>2]|0;
  $154 = ((($153) + ($150<<3)|0) + 4|0);
  $155 = HEAP8[$154>>0]|0;
  $156 = ($155<<24>>24)==(0);
  if ($156) {
   $157 = (($inOperator) + 4|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = HEAP32[$158>>2]|0;
   $160 = (($159) + 16|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = (($153) + ($150<<3)|0);
   $163 = HEAP32[$162>>2]|0;
   FUNCTION_TABLE_vii[$161 & 4095]($158,$163);
   $164 = HEAP32[$inOperator>>2]|0;
   $165 = (($164) + 8|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = (($166) + -1)|0;
   $168 = (($164) + 4|0);
   $169 = HEAP32[$168>>2]|0;
   $170 = ((($169) + ($167<<3)|0) + 4|0);
   HEAP8[$170>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $173 = $$pre$i;$178 = $$pre1$i;
  } else {
   $173 = $152;$178 = $149;
  }
 }
 HEAP32[$0>>2] = $147;
 $171 = (($0) + 4|0);
 HEAP8[$171>>0] = 0;
 $172 = (($173) + 12|0);
 $174 = HEAP32[$172>>2]|0;
 $175 = $174 & 2147483647;
 $176 = (($173) + 8|0);
 $177 = ($175>>>0)>($178>>>0);
 if ($177) {
  $179 = (($173) + 4|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = (($180) + ($178<<3)|0);
  $182 = ($181|0)==(0|0);
  if ($182) {
   $194 = $178;
  } else {
   $183 = $0;
   $184 = $183;
   $185 = HEAP32[$184>>2]|0;
   $186 = (($183) + 4)|0;
   $187 = $186;
   $188 = HEAP32[$187>>2]|0;
   $189 = $181;
   $190 = $189;
   HEAP32[$190>>2] = $185;
   $191 = (($189) + 4)|0;
   $192 = $191;
   HEAP32[$192>>2] = $188;
   $$pre$i$i = HEAP32[$176>>2]|0;
   $194 = $$pre$i$i;
  }
  $193 = (($194) + 1)|0;
  HEAP32[$176>>2] = $193;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($173,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i12>>0] = 0;
 $195 = (($theAccessor$i$i$i12) + 4|0);
 HEAP32[$195>>2] = 0;
 $196 = (($theAccessor$i$i$i12) + 8|0);
 HEAP32[$196>>2] = $146;
 $197 = (($theAccessor$i$i$i12) + 12|0);
 HEAP32[$197>>2] = $145;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj687ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i12,0);
 $198 = HEAP32[$inOperator>>2]|0;
 $199 = (($198) + 8|0);
 $200 = HEAP32[$199>>2]|0;
 $201 = ($200|0)==(0);
 if ($201) {
  $217 = (($inStartIndex) + 4)|0;
  STACKTOP = sp;return ($217|0);
 }
 $202 = (($200) + -1)|0;
 $203 = (($198) + 4|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = ((($204) + ($202<<3)|0) + 4|0);
 $206 = HEAP8[$205>>0]|0;
 $207 = ($206<<24>>24)==(0);
 if ($207) {
  $214 = $198;$216 = $200;
 } else {
  $208 = (($inOperator) + 4|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = HEAP32[$209>>2]|0;
  $211 = (($210) + 20|0);
  $212 = HEAP32[$211>>2]|0;
  FUNCTION_TABLE_vi[$212 & 4095]($209);
  $$pre$i$i$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i$i$i = (($$pre$i$i$i$i) + 8|0);
  $$pre1$i$i$i$i = HEAP32[$$phi$trans$insert$i$i$i$i>>2]|0;
  $214 = $$pre$i$i$i$i;$216 = $$pre1$i$i$i$i;
 }
 $213 = (($214) + 8|0);
 $215 = (($216) + -1)|0;
 HEAP32[$213>>2] = $215;
 $217 = (($inStartIndex) + 4)|0;
 STACKTOP = sp;return ($217|0);
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj687ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $buffer$i$i$i$i = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $theData = 0, $vararg_buffer1 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i$i = sp + 80|0;
 $theData = sp + 8|0;
 $2 = sp + 44|0;
 $buffer = sp + 48|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($inProp) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 $10 = (($theData) + 20|0);
 $11 = (($theData) + 24|0);
 $12 = (($theData) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($theData) + 32|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $theData;
 HEAP32[$13>>2] = 5;
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE6resizeEjRKf($theData,$9,$2);
 $14 = ($9|0)==(0);
 if (!($14)) {
  $15 = (($vararg_buffer1) + 4|0);
  $16 = (($this) + 4|0);
  $17 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer1)|0);
   $18 = HEAP32[$this>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $42 = $18;$47 = 0;
   } else {
    $22 = (($20) + -1)|0;
    $23 = (($18) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($24) + ($22<<3)|0) + 4|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($24) + ($22<<3)|0);
     $33 = HEAP32[$32>>2]|0;
     FUNCTION_TABLE_vii[$31 & 4095]($28,$33);
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + -1)|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39) + ($37<<3)|0) + 4|0);
     HEAP8[$40>>0] = 1;
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $42 = $$pre$i;$47 = $$pre1$i;
    } else {
     $42 = $18;$47 = $20;
    }
   }
   HEAP32[$vararg_buffer1>>2] = $buffer;
   HEAP8[$15>>0] = 0;
   $41 = (($42) + 12|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($42) + 8|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    $48 = (($42) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47<<3)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $63 = $47;
    } else {
     $52 = $vararg_buffer1;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $50;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $$pre$i$i = HEAP32[$45>>2]|0;
     $63 = $$pre$i$i;
    }
    $62 = (($63) + 1)|0;
    HEAP32[$45>>2] = $62;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($42,$vararg_buffer1)|0);
   }
   $64 = HEAP32[$3>>2]|0;
   $65 = HEAP32[$5>>2]|0;
   $66 = (($65) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (Math_fround(FUNCTION_TABLE_fii[$67 & 63]($64,$i$04)));
   $69 = HEAP32[$16>>2]|0;
   $70 = HEAP32[$17>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   $80 = +$68;
   dest=$buffer$i$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$80;HEAP32[$vararg_buffer1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer1+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i$i,0,521528,$vararg_buffer1)|0);
   $81 = HEAP8[$buffer$i$i$i$i>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if (!($82)) {
    $83 = HEAP32[$70>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = (_strlen(($buffer$i$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$84 & 2047]($70,$buffer$i$i$i$i,$85)|0);
   }
   HEAP8[$vararg_buffer1>>0] = 0;
   $86 = HEAP32[$70>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   (FUNCTION_TABLE_iiii[$87 & 2047]($70,$vararg_buffer1,1)|0);
   $88 = HEAP32[$69>>2]|0;
   $89 = (($88) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($70) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   FUNCTION_TABLE_viii[$90 & 4095]($69,$$0$i$i,$92);
   $93 = (($70) + 16|0);
   HEAP32[$93>>2] = 0;
   $94 = (($70) + 12|0);
   HEAP32[$94>>2] = 0;
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0);
   if (!($98)) {
    $99 = (($97) + -1)|0;
    $100 = (($95) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101) + ($99<<3)|0) + 4|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(0);
    if ($104) {
     $110 = $95;$112 = $97;
    } else {
     $105 = HEAP32[$16>>2]|0;
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + 20|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$108 & 4095]($105);
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $110 = $$pre$i1;$112 = $$pre1$i3;
    }
    $109 = (($110) + 8|0);
    $111 = (($112) + -1)|0;
    HEAP32[$109>>2] = $111;
   }
   $113 = (($i$04) + 1)|0;
   $exitcond = ($113|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $113;
   }
  }
 }
 $114 = HEAP32[$13>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i$i = $116 & $117;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$11>>2]|0;
 $119 = ($theData|0)==($118|0);
 if ($119) {
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $120 = ($118|0)==(0|0);
 if ($120) {
  STACKTOP = sp;return;
 }
 $121 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_vii[$124 & 4095]($121,$118);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE6resizeEjRKf($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($size<<2)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + ($7<<2)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   $12 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $12;
  }
  $13 = (($$01$i) + 4|0);
  $14 = ($13>>>0)<($8>>>0);
  if ($14) {
   $$01$i = $13;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = (($this) + 20|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(21);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 521648 : 521616;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,521536,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<2)|0);
 $21 = (($this) + 24|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($19>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = (($this) + 32|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(-1);
 if (!($31)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$21>>2]|0;
 $33 = ($this|0)==($32|0);
 if ($33) {
  $34 = (($this) + 20|0);
  HEAP8[$34>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = ($32|0)==(0|0);
 if ($35) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vii[$39 & 4095]($36,$32);
 HEAP32[$21>>2] = $20;
 HEAP32[$29>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj686ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $buffer$i$i$i$i = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $theData = 0, $vararg_buffer1 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i$i = sp + 80|0;
 $theData = sp + 8|0;
 $2 = sp + 44|0;
 $buffer = sp + 48|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($inProp) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 $10 = (($theData) + 20|0);
 $11 = (($theData) + 24|0);
 $12 = (($theData) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($theData) + 32|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $theData;
 HEAP32[$13>>2] = 5;
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE6resizeEjRKf($theData,$9,$2);
 $14 = ($9|0)==(0);
 if (!($14)) {
  $15 = (($vararg_buffer1) + 4|0);
  $16 = (($this) + 4|0);
  $17 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer1)|0);
   $18 = HEAP32[$this>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $42 = $18;$47 = 0;
   } else {
    $22 = (($20) + -1)|0;
    $23 = (($18) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($24) + ($22<<3)|0) + 4|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($24) + ($22<<3)|0);
     $33 = HEAP32[$32>>2]|0;
     FUNCTION_TABLE_vii[$31 & 4095]($28,$33);
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + -1)|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39) + ($37<<3)|0) + 4|0);
     HEAP8[$40>>0] = 1;
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $42 = $$pre$i;$47 = $$pre1$i;
    } else {
     $42 = $18;$47 = $20;
    }
   }
   HEAP32[$vararg_buffer1>>2] = $buffer;
   HEAP8[$15>>0] = 0;
   $41 = (($42) + 12|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($42) + 8|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    $48 = (($42) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47<<3)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $63 = $47;
    } else {
     $52 = $vararg_buffer1;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $50;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $$pre$i$i = HEAP32[$45>>2]|0;
     $63 = $$pre$i$i;
    }
    $62 = (($63) + 1)|0;
    HEAP32[$45>>2] = $62;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($42,$vararg_buffer1)|0);
   }
   $64 = HEAP32[$3>>2]|0;
   $65 = HEAP32[$5>>2]|0;
   $66 = (($65) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (Math_fround(FUNCTION_TABLE_fii[$67 & 63]($64,$i$04)));
   $69 = HEAP32[$16>>2]|0;
   $70 = HEAP32[$17>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   $80 = +$68;
   dest=$buffer$i$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$80;HEAP32[$vararg_buffer1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer1+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i$i,0,521528,$vararg_buffer1)|0);
   $81 = HEAP8[$buffer$i$i$i$i>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if (!($82)) {
    $83 = HEAP32[$70>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = (_strlen(($buffer$i$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$84 & 2047]($70,$buffer$i$i$i$i,$85)|0);
   }
   HEAP8[$vararg_buffer1>>0] = 0;
   $86 = HEAP32[$70>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   (FUNCTION_TABLE_iiii[$87 & 2047]($70,$vararg_buffer1,1)|0);
   $88 = HEAP32[$69>>2]|0;
   $89 = (($88) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($70) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   FUNCTION_TABLE_viii[$90 & 4095]($69,$$0$i$i,$92);
   $93 = (($70) + 16|0);
   HEAP32[$93>>2] = 0;
   $94 = (($70) + 12|0);
   HEAP32[$94>>2] = 0;
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0);
   if (!($98)) {
    $99 = (($97) + -1)|0;
    $100 = (($95) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101) + ($99<<3)|0) + 4|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(0);
    if ($104) {
     $110 = $95;$112 = $97;
    } else {
     $105 = HEAP32[$16>>2]|0;
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + 20|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$108 & 4095]($105);
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $110 = $$pre$i1;$112 = $$pre1$i3;
    }
    $109 = (($110) + 8|0);
    $111 = (($112) + -1)|0;
    HEAP32[$109>>2] = $111;
   }
   $113 = (($i$04) + 1)|0;
   $exitcond = ($113|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $113;
   }
  }
 }
 $114 = HEAP32[$13>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i$i = $116 & $117;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$11>>2]|0;
 $119 = ($theData|0)==($118|0);
 if ($119) {
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $120 = ($118|0)==(0|0);
 if ($120) {
  STACKTOP = sp;return;
 }
 $121 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_vii[$124 & 4095]($121,$118);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_16PxVehicleNoDriveEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj685ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $buffer$i$i$i$i = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $theData = 0, $vararg_buffer1 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i$i = sp + 80|0;
 $theData = sp + 8|0;
 $2 = sp + 44|0;
 $buffer = sp + 48|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($inProp) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 $10 = (($theData) + 20|0);
 $11 = (($theData) + 24|0);
 $12 = (($theData) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($theData) + 32|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $theData;
 HEAP32[$13>>2] = 5;
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE6resizeEjRKf($theData,$9,$2);
 $14 = ($9|0)==(0);
 if (!($14)) {
  $15 = (($vararg_buffer1) + 4|0);
  $16 = (($this) + 4|0);
  $17 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer1)|0);
   $18 = HEAP32[$this>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $42 = $18;$47 = 0;
   } else {
    $22 = (($20) + -1)|0;
    $23 = (($18) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($24) + ($22<<3)|0) + 4|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($24) + ($22<<3)|0);
     $33 = HEAP32[$32>>2]|0;
     FUNCTION_TABLE_vii[$31 & 4095]($28,$33);
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + -1)|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39) + ($37<<3)|0) + 4|0);
     HEAP8[$40>>0] = 1;
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $42 = $$pre$i;$47 = $$pre1$i;
    } else {
     $42 = $18;$47 = $20;
    }
   }
   HEAP32[$vararg_buffer1>>2] = $buffer;
   HEAP8[$15>>0] = 0;
   $41 = (($42) + 12|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($42) + 8|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    $48 = (($42) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47<<3)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $63 = $47;
    } else {
     $52 = $vararg_buffer1;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $50;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $$pre$i$i = HEAP32[$45>>2]|0;
     $63 = $$pre$i$i;
    }
    $62 = (($63) + 1)|0;
    HEAP32[$45>>2] = $62;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($42,$vararg_buffer1)|0);
   }
   $64 = HEAP32[$3>>2]|0;
   $65 = HEAP32[$5>>2]|0;
   $66 = (($65) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (Math_fround(FUNCTION_TABLE_fii[$67 & 63]($64,$i$04)));
   $69 = HEAP32[$16>>2]|0;
   $70 = HEAP32[$17>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   $80 = +$68;
   dest=$buffer$i$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$80;HEAP32[$vararg_buffer1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer1+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i$i,0,521528,$vararg_buffer1)|0);
   $81 = HEAP8[$buffer$i$i$i$i>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if (!($82)) {
    $83 = HEAP32[$70>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = (_strlen(($buffer$i$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$84 & 2047]($70,$buffer$i$i$i$i,$85)|0);
   }
   HEAP8[$vararg_buffer1>>0] = 0;
   $86 = HEAP32[$70>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   (FUNCTION_TABLE_iiii[$87 & 2047]($70,$vararg_buffer1,1)|0);
   $88 = HEAP32[$69>>2]|0;
   $89 = (($88) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($70) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   FUNCTION_TABLE_viii[$90 & 4095]($69,$$0$i$i,$92);
   $93 = (($70) + 16|0);
   HEAP32[$93>>2] = 0;
   $94 = (($70) + 12|0);
   HEAP32[$94>>2] = 0;
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0);
   if (!($98)) {
    $99 = (($97) + -1)|0;
    $100 = (($95) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101) + ($99<<3)|0) + 4|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(0);
    if ($104) {
     $110 = $95;$112 = $97;
    } else {
     $105 = HEAP32[$16>>2]|0;
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + 20|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$108 & 4095]($105);
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $110 = $$pre$i1;$112 = $$pre1$i3;
    }
    $109 = (($110) + 8|0);
    $111 = (($112) + -1)|0;
    HEAP32[$109>>2] = $111;
   }
   $113 = (($i$04) + 1)|0;
   $exitcond = ($113|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $113;
   }
  }
 }
 $114 = HEAP32[$13>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i$i = $116 & $117;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$11>>2]|0;
 $119 = ($theData|0)==($118|0);
 if ($119) {
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $120 = ($118|0)==(0|0);
 if ($120) {
  STACKTOP = sp;return;
 }
 $121 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_vii[$124 & 4095]($121,$118);
 STACKTOP = sp;return;
}
function __ZNK5physx28PxVehicleWheelsGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleNoDriveEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i8 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i3 = 0, $$pre$i7 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i5 = 0, $$pre1$i9 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i2 = sp + 8|0;
 $1 = (($this) + 36|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $2 = (($theAccessor$i2) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i8 = (($$pre$i7) + 8|0);
   $$pre1$i9 = HEAP32[$$phi$trans$insert$i8>>2]|0;
   $31 = $$pre$i7;$36 = $$pre1$i9;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i11 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i11;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleNoDriveEEEE14handleAccessorILj631ENS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataESA_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre13 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre13;$80 = $$pre;
 }
 $72 = (($this) + 52|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $73 = (($theAccessor$i2) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $101 = $$pre$i;$106 = $$pre1$i;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i1 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i1;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleNoDriveEEEE14handleAccessorILj632ENS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataESA_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $142 = (($inStartIndex) + 5)|0;
  STACKTOP = sp;return ($142|0);
 }
 $127 = (($125) + -1)|0;
 $128 = (($123) + 4|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($129) + ($127<<3)|0) + 4|0);
 $131 = HEAP8[$130>>0]|0;
 $132 = ($131<<24>>24)==(0);
 if ($132) {
  $139 = $123;$141 = $125;
 } else {
  $133 = (($inOperator) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + 20|0);
  $137 = HEAP32[$136>>2]|0;
  FUNCTION_TABLE_vi[$137 & 4095]($134);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $139 = $$pre$i$i;$141 = $$pre1$i$i;
 }
 $138 = (($139) + 8|0);
 $140 = (($141) + -1)|0;
 HEAP32[$138>>2] = $140;
 $142 = (($inStartIndex) + 5)|0;
 STACKTOP = sp;return ($142|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleNoDriveEEEE14handleAccessorILj632ENS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $info$i$i$i$i$i = sp + 136|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 64|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 76;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 76)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsDynDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx35PxVehicleWheelsDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsDynDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i$i$i = 0, $$phi$trans$insert$i$i$i$i3 = 0, $$phi$trans$insert$i7 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i2 = 0, $$pre$i$i10 = 0, $$pre$i6 = 0, $$pre1$i = 0, $$pre1$i$i$i$i = 0, $$pre1$i$i$i$i4 = 0, $$pre1$i8 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $theAccessor$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i$i$i1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($inStartIndex) + 1)|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i6 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i7 = (($$pre$i6) + 8|0);
   $$pre1$i8 = HEAP32[$$phi$trans$insert$i7>>2]|0;
   $30 = $$pre$i6;$35 = $$pre1$i8;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i10 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i10;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i1>>0] = 0;
 $52 = (($theAccessor$i$i$i1) + 4|0);
 HEAP32[$52>>2] = 0;
 $53 = (($theAccessor$i$i$i1) + 8|0);
 HEAP32[$53>>2] = $2;
 $54 = (($theAccessor$i$i$i1) + 12|0);
 HEAP32[$54>>2] = $1;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj623ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i1,0);
 $55 = HEAP32[$inOperator>>2]|0;
 $56 = (($55) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0);
 if ($58) {
  $78 = 0;$81 = $55;
 } else {
  $59 = (($57) + -1)|0;
  $60 = (($55) + 4|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($61) + ($59<<3)|0) + 4|0);
  $63 = HEAP8[$62>>0]|0;
  $64 = ($63<<24>>24)==(0);
  if ($64) {
   $71 = $55;$73 = $57;
  } else {
   $65 = (($inOperator) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = (($67) + 20|0);
   $69 = HEAP32[$68>>2]|0;
   FUNCTION_TABLE_vi[$69 & 4095]($66);
   $$pre$i$i$i$i2 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i3 = (($$pre$i$i$i$i2) + 8|0);
   $$pre1$i$i$i$i4 = HEAP32[$$phi$trans$insert$i$i$i$i3>>2]|0;
   $71 = $$pre$i$i$i$i2;$73 = $$pre1$i$i$i$i4;
  }
  $70 = (($71) + 8|0);
  $72 = (($73) + -1)|0;
  HEAP32[$70>>2] = $72;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre12 = HEAP32[$$phi$trans$insert>>2]|0;
  $78 = $$pre12;$81 = $$pre;
 }
 $74 = (($this) + 36|0);
 $75 = (($inStartIndex) + 2)|0;
 $76 = HEAP32[$74>>2]|0;
 $77 = ($78|0)==(0);
 if ($77) {
  $102 = $81;$107 = 0;
 } else {
  $79 = (($78) + -1)|0;
  $80 = (($81) + 4|0);
  $82 = HEAP32[$80>>2]|0;
  $83 = ((($82) + ($79<<3)|0) + 4|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = ($84<<24>>24)==(0);
  if ($85) {
   $86 = (($inOperator) + 4|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   $89 = (($88) + 16|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($82) + ($79<<3)|0);
   $92 = HEAP32[$91>>2]|0;
   FUNCTION_TABLE_vii[$90 & 4095]($87,$92);
   $93 = HEAP32[$inOperator>>2]|0;
   $94 = (($93) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($95) + -1)|0;
   $97 = (($93) + 4|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ((($98) + ($96<<3)|0) + 4|0);
   HEAP8[$99>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $102 = $$pre$i;$107 = $$pre1$i;
  } else {
   $102 = $81;$107 = $78;
  }
 }
 HEAP32[$0>>2] = $76;
 $100 = (($0) + 4|0);
 HEAP8[$100>>0] = 0;
 $101 = (($102) + 12|0);
 $103 = HEAP32[$101>>2]|0;
 $104 = $103 & 2147483647;
 $105 = (($102) + 8|0);
 $106 = ($104>>>0)>($107>>>0);
 if ($106) {
  $108 = (($102) + 4|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($109) + ($107<<3)|0);
  $111 = ($110|0)==(0|0);
  if ($111) {
   $123 = $107;
  } else {
   $112 = $0;
   $113 = $112;
   $114 = HEAP32[$113>>2]|0;
   $115 = (($112) + 4)|0;
   $116 = $115;
   $117 = HEAP32[$116>>2]|0;
   $118 = $110;
   $119 = $118;
   HEAP32[$119>>2] = $114;
   $120 = (($118) + 4)|0;
   $121 = $120;
   HEAP32[$121>>2] = $117;
   $$pre$i$i = HEAP32[$105>>2]|0;
   $123 = $$pre$i$i;
  }
  $122 = (($123) + 1)|0;
  HEAP32[$105>>2] = $122;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($102,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i1>>0] = 0;
 $124 = (($theAccessor$i$i$i1) + 4|0);
 HEAP32[$124>>2] = 0;
 $125 = (($theAccessor$i$i$i1) + 8|0);
 HEAP32[$125>>2] = $75;
 $126 = (($theAccessor$i$i$i1) + 12|0);
 HEAP32[$126>>2] = $74;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj624ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i1,0);
 $127 = HEAP32[$inOperator>>2]|0;
 $128 = (($127) + 8|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ($129|0)==(0);
 if ($130) {
  $146 = (($inStartIndex) + 4)|0;
  STACKTOP = sp;return ($146|0);
 }
 $131 = (($129) + -1)|0;
 $132 = (($127) + 4|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = ((($133) + ($131<<3)|0) + 4|0);
 $135 = HEAP8[$134>>0]|0;
 $136 = ($135<<24>>24)==(0);
 if ($136) {
  $143 = $127;$145 = $129;
 } else {
  $137 = (($inOperator) + 4|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = HEAP32[$138>>2]|0;
  $140 = (($139) + 20|0);
  $141 = HEAP32[$140>>2]|0;
  FUNCTION_TABLE_vi[$141 & 4095]($138);
  $$pre$i$i$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i$i$i = (($$pre$i$i$i$i) + 8|0);
  $$pre1$i$i$i$i = HEAP32[$$phi$trans$insert$i$i$i$i>>2]|0;
  $143 = $$pre$i$i$i$i;$145 = $$pre1$i$i$i$i;
 }
 $142 = (($143) + 8|0);
 $144 = (($145) + -1)|0;
 HEAP32[$142>>2] = $144;
 $146 = (($inStartIndex) + 4)|0;
 STACKTOP = sp;return ($146|0);
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj624ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $buffer$i$i$i$i = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $theData = 0, $vararg_buffer1 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i$i = sp + 80|0;
 $theData = sp + 8|0;
 $2 = sp + 44|0;
 $buffer = sp + 48|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($inProp) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 $10 = (($theData) + 20|0);
 $11 = (($theData) + 24|0);
 $12 = (($theData) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($theData) + 32|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $theData;
 HEAP32[$13>>2] = 5;
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE6resizeEjRKf($theData,$9,$2);
 $14 = ($9|0)==(0);
 if (!($14)) {
  $15 = (($vararg_buffer1) + 4|0);
  $16 = (($this) + 4|0);
  $17 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer1)|0);
   $18 = HEAP32[$this>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $42 = $18;$47 = 0;
   } else {
    $22 = (($20) + -1)|0;
    $23 = (($18) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($24) + ($22<<3)|0) + 4|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($24) + ($22<<3)|0);
     $33 = HEAP32[$32>>2]|0;
     FUNCTION_TABLE_vii[$31 & 4095]($28,$33);
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + -1)|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39) + ($37<<3)|0) + 4|0);
     HEAP8[$40>>0] = 1;
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $42 = $$pre$i;$47 = $$pre1$i;
    } else {
     $42 = $18;$47 = $20;
    }
   }
   HEAP32[$vararg_buffer1>>2] = $buffer;
   HEAP8[$15>>0] = 0;
   $41 = (($42) + 12|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($42) + 8|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    $48 = (($42) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47<<3)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $63 = $47;
    } else {
     $52 = $vararg_buffer1;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $50;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $$pre$i$i = HEAP32[$45>>2]|0;
     $63 = $$pre$i$i;
    }
    $62 = (($63) + 1)|0;
    HEAP32[$45>>2] = $62;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($42,$vararg_buffer1)|0);
   }
   $64 = HEAP32[$3>>2]|0;
   $65 = HEAP32[$5>>2]|0;
   $66 = (($65) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (Math_fround(FUNCTION_TABLE_fii[$67 & 63]($64,$i$04)));
   $69 = HEAP32[$16>>2]|0;
   $70 = HEAP32[$17>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   $80 = +$68;
   dest=$buffer$i$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$80;HEAP32[$vararg_buffer1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer1+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i$i,0,521528,$vararg_buffer1)|0);
   $81 = HEAP8[$buffer$i$i$i$i>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if (!($82)) {
    $83 = HEAP32[$70>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = (_strlen(($buffer$i$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$84 & 2047]($70,$buffer$i$i$i$i,$85)|0);
   }
   HEAP8[$vararg_buffer1>>0] = 0;
   $86 = HEAP32[$70>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   (FUNCTION_TABLE_iiii[$87 & 2047]($70,$vararg_buffer1,1)|0);
   $88 = HEAP32[$69>>2]|0;
   $89 = (($88) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($70) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   FUNCTION_TABLE_viii[$90 & 4095]($69,$$0$i$i,$92);
   $93 = (($70) + 16|0);
   HEAP32[$93>>2] = 0;
   $94 = (($70) + 12|0);
   HEAP32[$94>>2] = 0;
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0);
   if (!($98)) {
    $99 = (($97) + -1)|0;
    $100 = (($95) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101) + ($99<<3)|0) + 4|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(0);
    if ($104) {
     $110 = $95;$112 = $97;
    } else {
     $105 = HEAP32[$16>>2]|0;
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + 20|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$108 & 4095]($105);
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $110 = $$pre$i1;$112 = $$pre1$i3;
    }
    $109 = (($110) + 8|0);
    $111 = (($112) + -1)|0;
    HEAP32[$109>>2] = $111;
   }
   $113 = (($i$04) + 1)|0;
   $exitcond = ($113|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $113;
   }
  }
 }
 $114 = HEAP32[$13>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i$i = $116 & $117;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$11>>2]|0;
 $119 = ($theData|0)==($118|0);
 if ($119) {
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $120 = ($118|0)==(0|0);
 if ($120) {
  STACKTOP = sp;return;
 }
 $121 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_vii[$124 & 4095]($121,$118);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj623ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $buffer$i$i$i$i = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $theData = 0, $vararg_buffer1 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i$i = sp + 80|0;
 $theData = sp + 8|0;
 $2 = sp + 44|0;
 $buffer = sp + 48|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($inProp) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 $10 = (($theData) + 20|0);
 $11 = (($theData) + 24|0);
 $12 = (($theData) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($theData) + 32|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $theData;
 HEAP32[$13>>2] = 5;
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE6resizeEjRKf($theData,$9,$2);
 $14 = ($9|0)==(0);
 if (!($14)) {
  $15 = (($vararg_buffer1) + 4|0);
  $16 = (($this) + 4|0);
  $17 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer1)|0);
   $18 = HEAP32[$this>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $42 = $18;$47 = 0;
   } else {
    $22 = (($20) + -1)|0;
    $23 = (($18) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($24) + ($22<<3)|0) + 4|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($24) + ($22<<3)|0);
     $33 = HEAP32[$32>>2]|0;
     FUNCTION_TABLE_vii[$31 & 4095]($28,$33);
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + -1)|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39) + ($37<<3)|0) + 4|0);
     HEAP8[$40>>0] = 1;
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $42 = $$pre$i;$47 = $$pre1$i;
    } else {
     $42 = $18;$47 = $20;
    }
   }
   HEAP32[$vararg_buffer1>>2] = $buffer;
   HEAP8[$15>>0] = 0;
   $41 = (($42) + 12|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($42) + 8|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    $48 = (($42) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47<<3)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $63 = $47;
    } else {
     $52 = $vararg_buffer1;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $50;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $$pre$i$i = HEAP32[$45>>2]|0;
     $63 = $$pre$i$i;
    }
    $62 = (($63) + 1)|0;
    HEAP32[$45>>2] = $62;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($42,$vararg_buffer1)|0);
   }
   $64 = HEAP32[$3>>2]|0;
   $65 = HEAP32[$5>>2]|0;
   $66 = (($65) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (Math_fround(FUNCTION_TABLE_fii[$67 & 63]($64,$i$04)));
   $69 = HEAP32[$16>>2]|0;
   $70 = HEAP32[$17>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   $80 = +$68;
   dest=$buffer$i$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$80;HEAP32[$vararg_buffer1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer1+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i$i,0,521528,$vararg_buffer1)|0);
   $81 = HEAP8[$buffer$i$i$i$i>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if (!($82)) {
    $83 = HEAP32[$70>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = (_strlen(($buffer$i$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$84 & 2047]($70,$buffer$i$i$i$i,$85)|0);
   }
   HEAP8[$vararg_buffer1>>0] = 0;
   $86 = HEAP32[$70>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   (FUNCTION_TABLE_iiii[$87 & 2047]($70,$vararg_buffer1,1)|0);
   $88 = HEAP32[$69>>2]|0;
   $89 = (($88) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($70) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   FUNCTION_TABLE_viii[$90 & 4095]($69,$$0$i$i,$92);
   $93 = (($70) + 16|0);
   HEAP32[$93>>2] = 0;
   $94 = (($70) + 12|0);
   HEAP32[$94>>2] = 0;
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0);
   if (!($98)) {
    $99 = (($97) + -1)|0;
    $100 = (($95) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101) + ($99<<3)|0) + 4|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(0);
    if ($104) {
     $110 = $95;$112 = $97;
    } else {
     $105 = HEAP32[$16>>2]|0;
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + 20|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$108 & 4095]($105);
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $110 = $$pre$i1;$112 = $$pre1$i3;
    }
    $109 = (($110) + 8|0);
    $111 = (($112) + -1)|0;
    HEAP32[$109>>2] = $111;
   }
   $113 = (($i$04) + 1)|0;
   $exitcond = ($113|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $113;
   }
  }
 }
 $114 = HEAP32[$13>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i$i = $116 & $117;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$11>>2]|0;
 $119 = ($theData|0)==($118|0);
 if ($119) {
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $120 = ($118|0)==(0|0);
 if ($120) {
  STACKTOP = sp;return;
 }
 $121 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_vii[$124 & 4095]($121,$118);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleNoDriveEEEE14handleAccessorILj631ENS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $info$i$i$i$i$i = sp + 352|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 96|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 12;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 12)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 _memset(($1|0),0,256)|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i$i$i = 0, $$phi$trans$insert$i$i$i$i11 = 0, $$phi$trans$insert$i$i$i$i22 = 0, $$phi$trans$insert$i$i$i$i33 = 0, $$phi$trans$insert$i$i$i$i44 = 0, $$phi$trans$insert$i$i$i$i55 = 0, $$phi$trans$insert$i$i$i$i66 = 0, $$phi$trans$insert$i$i$i$i77 = 0, $$phi$trans$insert$i$i$i$i88 = 0, $$phi$trans$insert$i15 = 0, $$phi$trans$insert$i26 = 0, $$phi$trans$insert$i37 = 0, $$phi$trans$insert$i4 = 0, $$phi$trans$insert$i48 = 0, $$phi$trans$insert$i59 = 0, $$phi$trans$insert$i70 = 0, $$phi$trans$insert$i81 = 0;
 var $$phi$trans$insert$i92 = 0, $$phi$trans$insert100 = 0, $$phi$trans$insert103 = 0, $$phi$trans$insert106 = 0, $$phi$trans$insert109 = 0, $$phi$trans$insert112 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i10 = 0, $$pre$i$i$i$i21 = 0, $$pre$i$i$i$i32 = 0, $$pre$i$i$i$i43 = 0, $$pre$i$i$i$i54 = 0, $$pre$i$i$i$i65 = 0, $$pre$i$i$i$i76 = 0, $$pre$i$i$i$i87 = 0, $$pre$i$i1 = 0, $$pre$i$i18 = 0;
 var $$pre$i$i29 = 0, $$pre$i$i40 = 0, $$pre$i$i51 = 0, $$pre$i$i62 = 0, $$pre$i$i7 = 0, $$pre$i$i73 = 0, $$pre$i$i84 = 0, $$pre$i$i95 = 0, $$pre$i14 = 0, $$pre$i25 = 0, $$pre$i3 = 0, $$pre$i36 = 0, $$pre$i47 = 0, $$pre$i58 = 0, $$pre$i69 = 0, $$pre$i80 = 0, $$pre$i91 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i$i$i = 0;
 var $$pre1$i$i$i$i12 = 0, $$pre1$i$i$i$i23 = 0, $$pre1$i$i$i$i34 = 0, $$pre1$i$i$i$i45 = 0, $$pre1$i$i$i$i56 = 0, $$pre1$i$i$i$i67 = 0, $$pre1$i$i$i$i78 = 0, $$pre1$i$i$i$i89 = 0, $$pre1$i16 = 0, $$pre1$i27 = 0, $$pre1$i38 = 0, $$pre1$i49 = 0, $$pre1$i5 = 0, $$pre1$i60 = 0, $$pre1$i71 = 0, $$pre1$i82 = 0, $$pre1$i93 = 0, $$pre101 = 0, $$pre102 = 0, $$pre104 = 0;
 var $$pre105 = 0, $$pre107 = 0, $$pre108 = 0, $$pre110 = 0, $$pre111 = 0, $$pre113 = 0, $$pre97 = 0, $$pre98 = 0, $$pre99 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0;
 var $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0;
 var $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0;
 var $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0;
 var $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0;
 var $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0;
 var $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0;
 var $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0;
 var $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0;
 var $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0;
 var $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0;
 var $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $theAccessor$i$i$i86 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp;
 $theAccessor$i$i$i86 = sp + 176|0;
 $1 = sp + 8|0;
 $2 = (($this) + 12|0);
 $3 = (($inStartIndex) + 1)|0;
 _memset(($1|0),0,164)|0;
 __ZN5physx36PxVehicleSuspensionDataGeneratedInfoC2Ev($1);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i4 = (($$pre$i3) + 8|0);
   $$pre1$i5 = HEAP32[$$phi$trans$insert$i4>>2]|0;
   $31 = $$pre$i3;$36 = $$pre1$i5;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i7 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i7;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $53 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$53>>2] = 0;
 $54 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$54>>2] = $3;
 $55 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$55>>2] = $2;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj609ES2_KjNS_23PxVehicleSuspensionDataEEEKNS_36PxVehicleSuspensionDataGeneratedInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $56 = HEAP32[$inOperator>>2]|0;
 $57 = (($56) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0);
 if (!($59)) {
  $60 = (($58) + -1)|0;
  $61 = (($56) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ((($62) + ($60<<3)|0) + 4|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = ($64<<24>>24)==(0);
  if ($65) {
   $72 = $56;$74 = $58;
  } else {
   $66 = (($inOperator) + 4|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + 20|0);
   $70 = HEAP32[$69>>2]|0;
   FUNCTION_TABLE_vi[$70 & 4095]($67);
   $$pre$i$i$i$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i = (($$pre$i$i$i$i) + 8|0);
   $$pre1$i$i$i$i = HEAP32[$$phi$trans$insert$i$i$i$i>>2]|0;
   $72 = $$pre$i$i$i$i;$74 = $$pre1$i$i$i$i;
  }
  $71 = (($72) + 8|0);
  $73 = (($74) + -1)|0;
  HEAP32[$71>>2] = $73;
 }
 $75 = (($this) + 36|0);
 $76 = (($inStartIndex) + 2)|0;
 _memset(($1|0),0,168)|0;
 __ZN5physx31PxVehicleWheelDataGeneratedInfoC2Ev($1);
 $77 = HEAP32[$75>>2]|0;
 $78 = HEAP32[$inOperator>>2]|0;
 $79 = (($78) + 8|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0);
 if ($81) {
  $104 = $78;$109 = 0;
 } else {
  $82 = (($80) + -1)|0;
  $83 = (($78) + 4|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($84) + ($82<<3)|0) + 4|0);
  $86 = HEAP8[$85>>0]|0;
  $87 = ($86<<24>>24)==(0);
  if ($87) {
   $88 = (($inOperator) + 4|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($90) + 16|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($84) + ($82<<3)|0);
   $94 = HEAP32[$93>>2]|0;
   FUNCTION_TABLE_vii[$92 & 4095]($89,$94);
   $95 = HEAP32[$inOperator>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($97) + -1)|0;
   $99 = (($95) + 4|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ((($100) + ($98<<3)|0) + 4|0);
   HEAP8[$101>>0] = 1;
   $$pre$i14 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i15 = (($$pre$i14) + 8|0);
   $$pre1$i16 = HEAP32[$$phi$trans$insert$i15>>2]|0;
   $104 = $$pre$i14;$109 = $$pre1$i16;
  } else {
   $104 = $78;$109 = $80;
  }
 }
 HEAP32[$0>>2] = $77;
 $102 = (($0) + 4|0);
 HEAP8[$102>>0] = 0;
 $103 = (($104) + 12|0);
 $105 = HEAP32[$103>>2]|0;
 $106 = $105 & 2147483647;
 $107 = (($104) + 8|0);
 $108 = ($106>>>0)>($109>>>0);
 if ($108) {
  $110 = (($104) + 4|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = (($111) + ($109<<3)|0);
  $113 = ($112|0)==(0|0);
  if ($113) {
   $125 = $109;
  } else {
   $114 = $0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = (($114) + 4)|0;
   $118 = $117;
   $119 = HEAP32[$118>>2]|0;
   $120 = $112;
   $121 = $120;
   HEAP32[$121>>2] = $116;
   $122 = (($120) + 4)|0;
   $123 = $122;
   HEAP32[$123>>2] = $119;
   $$pre$i$i18 = HEAP32[$107>>2]|0;
   $125 = $$pre$i$i18;
  }
  $124 = (($125) + 1)|0;
  HEAP32[$107>>2] = $124;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($104,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $126 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$126>>2] = 0;
 $127 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$127>>2] = $76;
 $128 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$128>>2] = $75;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj610ES2_KjNS_18PxVehicleWheelDataEEEKNS_31PxVehicleWheelDataGeneratedInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $129 = HEAP32[$inOperator>>2]|0;
 $130 = (($129) + 8|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ($131|0)==(0);
 if (!($132)) {
  $133 = (($131) + -1)|0;
  $134 = (($129) + 4|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ((($135) + ($133<<3)|0) + 4|0);
  $137 = HEAP8[$136>>0]|0;
  $138 = ($137<<24>>24)==(0);
  if ($138) {
   $145 = $129;$147 = $131;
  } else {
   $139 = (($inOperator) + 4|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = HEAP32[$140>>2]|0;
   $142 = (($141) + 20|0);
   $143 = HEAP32[$142>>2]|0;
   FUNCTION_TABLE_vi[$143 & 4095]($140);
   $$pre$i$i$i$i10 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i11 = (($$pre$i$i$i$i10) + 8|0);
   $$pre1$i$i$i$i12 = HEAP32[$$phi$trans$insert$i$i$i$i11>>2]|0;
   $145 = $$pre$i$i$i$i10;$147 = $$pre1$i$i$i$i12;
  }
  $144 = (($145) + 8|0);
  $146 = (($147) + -1)|0;
  HEAP32[$144>>2] = $146;
 }
 $148 = (($this) + 60|0);
 $149 = (($inStartIndex) + 3)|0;
 _memset(($1|0),0,140)|0;
 __ZN5physx30PxVehicleTireDataGeneratedInfoC2Ev($1);
 $150 = HEAP32[$148>>2]|0;
 $151 = HEAP32[$inOperator>>2]|0;
 $152 = (($151) + 8|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = ($153|0)==(0);
 if ($154) {
  $177 = $151;$182 = 0;
 } else {
  $155 = (($153) + -1)|0;
  $156 = (($151) + 4|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = ((($157) + ($155<<3)|0) + 4|0);
  $159 = HEAP8[$158>>0]|0;
  $160 = ($159<<24>>24)==(0);
  if ($160) {
   $161 = (($inOperator) + 4|0);
   $162 = HEAP32[$161>>2]|0;
   $163 = HEAP32[$162>>2]|0;
   $164 = (($163) + 16|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = (($157) + ($155<<3)|0);
   $167 = HEAP32[$166>>2]|0;
   FUNCTION_TABLE_vii[$165 & 4095]($162,$167);
   $168 = HEAP32[$inOperator>>2]|0;
   $169 = (($168) + 8|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = (($170) + -1)|0;
   $172 = (($168) + 4|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = ((($173) + ($171<<3)|0) + 4|0);
   HEAP8[$174>>0] = 1;
   $$pre$i25 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i26 = (($$pre$i25) + 8|0);
   $$pre1$i27 = HEAP32[$$phi$trans$insert$i26>>2]|0;
   $177 = $$pre$i25;$182 = $$pre1$i27;
  } else {
   $177 = $151;$182 = $153;
  }
 }
 HEAP32[$0>>2] = $150;
 $175 = (($0) + 4|0);
 HEAP8[$175>>0] = 0;
 $176 = (($177) + 12|0);
 $178 = HEAP32[$176>>2]|0;
 $179 = $178 & 2147483647;
 $180 = (($177) + 8|0);
 $181 = ($179>>>0)>($182>>>0);
 if ($181) {
  $183 = (($177) + 4|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = (($184) + ($182<<3)|0);
  $186 = ($185|0)==(0|0);
  if ($186) {
   $198 = $182;
  } else {
   $187 = $0;
   $188 = $187;
   $189 = HEAP32[$188>>2]|0;
   $190 = (($187) + 4)|0;
   $191 = $190;
   $192 = HEAP32[$191>>2]|0;
   $193 = $185;
   $194 = $193;
   HEAP32[$194>>2] = $189;
   $195 = (($193) + 4)|0;
   $196 = $195;
   HEAP32[$196>>2] = $192;
   $$pre$i$i29 = HEAP32[$180>>2]|0;
   $198 = $$pre$i$i29;
  }
  $197 = (($198) + 1)|0;
  HEAP32[$180>>2] = $197;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($177,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $199 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$199>>2] = 0;
 $200 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$200>>2] = $149;
 $201 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$201>>2] = $148;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj611ES2_KjNS_17PxVehicleTireDataEEEKNS_30PxVehicleTireDataGeneratedInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $202 = HEAP32[$inOperator>>2]|0;
 $203 = (($202) + 8|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = ($204|0)==(0);
 if ($205) {
  $225 = $202;
 } else {
  $206 = (($204) + -1)|0;
  $207 = (($202) + 4|0);
  $208 = HEAP32[$207>>2]|0;
  $209 = ((($208) + ($206<<3)|0) + 4|0);
  $210 = HEAP8[$209>>0]|0;
  $211 = ($210<<24>>24)==(0);
  if ($211) {
   $218 = $202;$220 = $204;
  } else {
   $212 = (($inOperator) + 4|0);
   $213 = HEAP32[$212>>2]|0;
   $214 = HEAP32[$213>>2]|0;
   $215 = (($214) + 20|0);
   $216 = HEAP32[$215>>2]|0;
   FUNCTION_TABLE_vi[$216 & 4095]($213);
   $$pre$i$i$i$i21 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i22 = (($$pre$i$i$i$i21) + 8|0);
   $$pre1$i$i$i$i23 = HEAP32[$$phi$trans$insert$i$i$i$i22>>2]|0;
   $218 = $$pre$i$i$i$i21;$220 = $$pre1$i$i$i$i23;
  }
  $217 = (($218) + 8|0);
  $219 = (($220) + -1)|0;
  HEAP32[$217>>2] = $219;
  $$pre = HEAP32[$inOperator>>2]|0;
  $225 = $$pre;
 }
 $221 = (($this) + 84|0);
 $222 = (($inStartIndex) + 4)|0;
 $223 = HEAP32[$221>>2]|0;
 $224 = (($225) + 8|0);
 $226 = HEAP32[$224>>2]|0;
 $227 = ($226|0)==(0);
 if ($227) {
  $250 = $225;$255 = 0;
 } else {
  $228 = (($226) + -1)|0;
  $229 = (($225) + 4|0);
  $230 = HEAP32[$229>>2]|0;
  $231 = ((($230) + ($228<<3)|0) + 4|0);
  $232 = HEAP8[$231>>0]|0;
  $233 = ($232<<24>>24)==(0);
  if ($233) {
   $234 = (($inOperator) + 4|0);
   $235 = HEAP32[$234>>2]|0;
   $236 = HEAP32[$235>>2]|0;
   $237 = (($236) + 16|0);
   $238 = HEAP32[$237>>2]|0;
   $239 = (($230) + ($228<<3)|0);
   $240 = HEAP32[$239>>2]|0;
   FUNCTION_TABLE_vii[$238 & 4095]($235,$240);
   $241 = HEAP32[$inOperator>>2]|0;
   $242 = (($241) + 8|0);
   $243 = HEAP32[$242>>2]|0;
   $244 = (($243) + -1)|0;
   $245 = (($241) + 4|0);
   $246 = HEAP32[$245>>2]|0;
   $247 = ((($246) + ($244<<3)|0) + 4|0);
   HEAP8[$247>>0] = 1;
   $$pre$i36 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i37 = (($$pre$i36) + 8|0);
   $$pre1$i38 = HEAP32[$$phi$trans$insert$i37>>2]|0;
   $250 = $$pre$i36;$255 = $$pre1$i38;
  } else {
   $250 = $225;$255 = $226;
  }
 }
 HEAP32[$0>>2] = $223;
 $248 = (($0) + 4|0);
 HEAP8[$248>>0] = 0;
 $249 = (($250) + 12|0);
 $251 = HEAP32[$249>>2]|0;
 $252 = $251 & 2147483647;
 $253 = (($250) + 8|0);
 $254 = ($252>>>0)>($255>>>0);
 if ($254) {
  $256 = (($250) + 4|0);
  $257 = HEAP32[$256>>2]|0;
  $258 = (($257) + ($255<<3)|0);
  $259 = ($258|0)==(0|0);
  if ($259) {
   $271 = $255;
  } else {
   $260 = $0;
   $261 = $260;
   $262 = HEAP32[$261>>2]|0;
   $263 = (($260) + 4)|0;
   $264 = $263;
   $265 = HEAP32[$264>>2]|0;
   $266 = $258;
   $267 = $266;
   HEAP32[$267>>2] = $262;
   $268 = (($266) + 4)|0;
   $269 = $268;
   HEAP32[$269>>2] = $265;
   $$pre$i$i40 = HEAP32[$253>>2]|0;
   $271 = $$pre$i$i40;
  }
  $270 = (($271) + 1)|0;
  HEAP32[$253>>2] = $270;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($250,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $272 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$272>>2] = 0;
 $273 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$273>>2] = $222;
 $274 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$274>>2] = $221;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj612ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $275 = HEAP32[$inOperator>>2]|0;
 $276 = (($275) + 8|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = ($277|0)==(0);
 if ($278) {
  $298 = 0;$301 = $275;
 } else {
  $279 = (($277) + -1)|0;
  $280 = (($275) + 4|0);
  $281 = HEAP32[$280>>2]|0;
  $282 = ((($281) + ($279<<3)|0) + 4|0);
  $283 = HEAP8[$282>>0]|0;
  $284 = ($283<<24>>24)==(0);
  if ($284) {
   $291 = $275;$293 = $277;
  } else {
   $285 = (($inOperator) + 4|0);
   $286 = HEAP32[$285>>2]|0;
   $287 = HEAP32[$286>>2]|0;
   $288 = (($287) + 20|0);
   $289 = HEAP32[$288>>2]|0;
   FUNCTION_TABLE_vi[$289 & 4095]($286);
   $$pre$i$i$i$i32 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i33 = (($$pre$i$i$i$i32) + 8|0);
   $$pre1$i$i$i$i34 = HEAP32[$$phi$trans$insert$i$i$i$i33>>2]|0;
   $291 = $$pre$i$i$i$i32;$293 = $$pre1$i$i$i$i34;
  }
  $290 = (($291) + 8|0);
  $292 = (($293) + -1)|0;
  HEAP32[$290>>2] = $292;
  $$pre97 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre97) + 8|0);
  $$pre98 = HEAP32[$$phi$trans$insert>>2]|0;
  $298 = $$pre98;$301 = $$pre97;
 }
 $294 = (($this) + 108|0);
 $295 = (($inStartIndex) + 5)|0;
 $296 = HEAP32[$294>>2]|0;
 $297 = ($298|0)==(0);
 if ($297) {
  $322 = $301;$327 = 0;
 } else {
  $299 = (($298) + -1)|0;
  $300 = (($301) + 4|0);
  $302 = HEAP32[$300>>2]|0;
  $303 = ((($302) + ($299<<3)|0) + 4|0);
  $304 = HEAP8[$303>>0]|0;
  $305 = ($304<<24>>24)==(0);
  if ($305) {
   $306 = (($inOperator) + 4|0);
   $307 = HEAP32[$306>>2]|0;
   $308 = HEAP32[$307>>2]|0;
   $309 = (($308) + 16|0);
   $310 = HEAP32[$309>>2]|0;
   $311 = (($302) + ($299<<3)|0);
   $312 = HEAP32[$311>>2]|0;
   FUNCTION_TABLE_vii[$310 & 4095]($307,$312);
   $313 = HEAP32[$inOperator>>2]|0;
   $314 = (($313) + 8|0);
   $315 = HEAP32[$314>>2]|0;
   $316 = (($315) + -1)|0;
   $317 = (($313) + 4|0);
   $318 = HEAP32[$317>>2]|0;
   $319 = ((($318) + ($316<<3)|0) + 4|0);
   HEAP8[$319>>0] = 1;
   $$pre$i47 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i48 = (($$pre$i47) + 8|0);
   $$pre1$i49 = HEAP32[$$phi$trans$insert$i48>>2]|0;
   $322 = $$pre$i47;$327 = $$pre1$i49;
  } else {
   $322 = $301;$327 = $298;
  }
 }
 HEAP32[$0>>2] = $296;
 $320 = (($0) + 4|0);
 HEAP8[$320>>0] = 0;
 $321 = (($322) + 12|0);
 $323 = HEAP32[$321>>2]|0;
 $324 = $323 & 2147483647;
 $325 = (($322) + 8|0);
 $326 = ($324>>>0)>($327>>>0);
 if ($326) {
  $328 = (($322) + 4|0);
  $329 = HEAP32[$328>>2]|0;
  $330 = (($329) + ($327<<3)|0);
  $331 = ($330|0)==(0|0);
  if ($331) {
   $343 = $327;
  } else {
   $332 = $0;
   $333 = $332;
   $334 = HEAP32[$333>>2]|0;
   $335 = (($332) + 4)|0;
   $336 = $335;
   $337 = HEAP32[$336>>2]|0;
   $338 = $330;
   $339 = $338;
   HEAP32[$339>>2] = $334;
   $340 = (($338) + 4)|0;
   $341 = $340;
   HEAP32[$341>>2] = $337;
   $$pre$i$i51 = HEAP32[$325>>2]|0;
   $343 = $$pre$i$i51;
  }
  $342 = (($343) + 1)|0;
  HEAP32[$325>>2] = $342;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($322,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $344 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$344>>2] = 0;
 $345 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$345>>2] = $295;
 $346 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$346>>2] = $294;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj613ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $347 = HEAP32[$inOperator>>2]|0;
 $348 = (($347) + 8|0);
 $349 = HEAP32[$348>>2]|0;
 $350 = ($349|0)==(0);
 if ($350) {
  $370 = 0;$373 = $347;
 } else {
  $351 = (($349) + -1)|0;
  $352 = (($347) + 4|0);
  $353 = HEAP32[$352>>2]|0;
  $354 = ((($353) + ($351<<3)|0) + 4|0);
  $355 = HEAP8[$354>>0]|0;
  $356 = ($355<<24>>24)==(0);
  if ($356) {
   $363 = $347;$365 = $349;
  } else {
   $357 = (($inOperator) + 4|0);
   $358 = HEAP32[$357>>2]|0;
   $359 = HEAP32[$358>>2]|0;
   $360 = (($359) + 20|0);
   $361 = HEAP32[$360>>2]|0;
   FUNCTION_TABLE_vi[$361 & 4095]($358);
   $$pre$i$i$i$i43 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i44 = (($$pre$i$i$i$i43) + 8|0);
   $$pre1$i$i$i$i45 = HEAP32[$$phi$trans$insert$i$i$i$i44>>2]|0;
   $363 = $$pre$i$i$i$i43;$365 = $$pre1$i$i$i$i45;
  }
  $362 = (($363) + 8|0);
  $364 = (($365) + -1)|0;
  HEAP32[$362>>2] = $364;
  $$pre99 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert100 = (($$pre99) + 8|0);
  $$pre101 = HEAP32[$$phi$trans$insert100>>2]|0;
  $370 = $$pre101;$373 = $$pre99;
 }
 $366 = (($this) + 132|0);
 $367 = (($inStartIndex) + 6)|0;
 $368 = HEAP32[$366>>2]|0;
 $369 = ($370|0)==(0);
 if ($369) {
  $394 = $373;$399 = 0;
 } else {
  $371 = (($370) + -1)|0;
  $372 = (($373) + 4|0);
  $374 = HEAP32[$372>>2]|0;
  $375 = ((($374) + ($371<<3)|0) + 4|0);
  $376 = HEAP8[$375>>0]|0;
  $377 = ($376<<24>>24)==(0);
  if ($377) {
   $378 = (($inOperator) + 4|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = HEAP32[$379>>2]|0;
   $381 = (($380) + 16|0);
   $382 = HEAP32[$381>>2]|0;
   $383 = (($374) + ($371<<3)|0);
   $384 = HEAP32[$383>>2]|0;
   FUNCTION_TABLE_vii[$382 & 4095]($379,$384);
   $385 = HEAP32[$inOperator>>2]|0;
   $386 = (($385) + 8|0);
   $387 = HEAP32[$386>>2]|0;
   $388 = (($387) + -1)|0;
   $389 = (($385) + 4|0);
   $390 = HEAP32[$389>>2]|0;
   $391 = ((($390) + ($388<<3)|0) + 4|0);
   HEAP8[$391>>0] = 1;
   $$pre$i58 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i59 = (($$pre$i58) + 8|0);
   $$pre1$i60 = HEAP32[$$phi$trans$insert$i59>>2]|0;
   $394 = $$pre$i58;$399 = $$pre1$i60;
  } else {
   $394 = $373;$399 = $370;
  }
 }
 HEAP32[$0>>2] = $368;
 $392 = (($0) + 4|0);
 HEAP8[$392>>0] = 0;
 $393 = (($394) + 12|0);
 $395 = HEAP32[$393>>2]|0;
 $396 = $395 & 2147483647;
 $397 = (($394) + 8|0);
 $398 = ($396>>>0)>($399>>>0);
 if ($398) {
  $400 = (($394) + 4|0);
  $401 = HEAP32[$400>>2]|0;
  $402 = (($401) + ($399<<3)|0);
  $403 = ($402|0)==(0|0);
  if ($403) {
   $415 = $399;
  } else {
   $404 = $0;
   $405 = $404;
   $406 = HEAP32[$405>>2]|0;
   $407 = (($404) + 4)|0;
   $408 = $407;
   $409 = HEAP32[$408>>2]|0;
   $410 = $402;
   $411 = $410;
   HEAP32[$411>>2] = $406;
   $412 = (($410) + 4)|0;
   $413 = $412;
   HEAP32[$413>>2] = $409;
   $$pre$i$i62 = HEAP32[$397>>2]|0;
   $415 = $$pre$i$i62;
  }
  $414 = (($415) + 1)|0;
  HEAP32[$397>>2] = $414;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($394,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $416 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$416>>2] = 0;
 $417 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$417>>2] = $367;
 $418 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$418>>2] = $366;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj614ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $419 = HEAP32[$inOperator>>2]|0;
 $420 = (($419) + 8|0);
 $421 = HEAP32[$420>>2]|0;
 $422 = ($421|0)==(0);
 if ($422) {
  $442 = 0;$445 = $419;
 } else {
  $423 = (($421) + -1)|0;
  $424 = (($419) + 4|0);
  $425 = HEAP32[$424>>2]|0;
  $426 = ((($425) + ($423<<3)|0) + 4|0);
  $427 = HEAP8[$426>>0]|0;
  $428 = ($427<<24>>24)==(0);
  if ($428) {
   $435 = $419;$437 = $421;
  } else {
   $429 = (($inOperator) + 4|0);
   $430 = HEAP32[$429>>2]|0;
   $431 = HEAP32[$430>>2]|0;
   $432 = (($431) + 20|0);
   $433 = HEAP32[$432>>2]|0;
   FUNCTION_TABLE_vi[$433 & 4095]($430);
   $$pre$i$i$i$i54 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i55 = (($$pre$i$i$i$i54) + 8|0);
   $$pre1$i$i$i$i56 = HEAP32[$$phi$trans$insert$i$i$i$i55>>2]|0;
   $435 = $$pre$i$i$i$i54;$437 = $$pre1$i$i$i$i56;
  }
  $434 = (($435) + 8|0);
  $436 = (($437) + -1)|0;
  HEAP32[$434>>2] = $436;
  $$pre102 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert103 = (($$pre102) + 8|0);
  $$pre104 = HEAP32[$$phi$trans$insert103>>2]|0;
  $442 = $$pre104;$445 = $$pre102;
 }
 $438 = (($this) + 156|0);
 $439 = (($inStartIndex) + 7)|0;
 $440 = HEAP32[$438>>2]|0;
 $441 = ($442|0)==(0);
 do {
  if ($441) {
   $466 = $445;$471 = 0;
  } else {
   $443 = (($442) + -1)|0;
   $444 = (($445) + 4|0);
   $446 = HEAP32[$444>>2]|0;
   $447 = ((($446) + ($443<<3)|0) + 4|0);
   $448 = HEAP8[$447>>0]|0;
   $449 = ($448<<24>>24)==(0);
   if (!($449)) {
    $466 = $445;$471 = $442;
    break;
   }
   $450 = (($inOperator) + 4|0);
   $451 = HEAP32[$450>>2]|0;
   $452 = HEAP32[$451>>2]|0;
   $453 = (($452) + 16|0);
   $454 = HEAP32[$453>>2]|0;
   $455 = (($446) + ($443<<3)|0);
   $456 = HEAP32[$455>>2]|0;
   FUNCTION_TABLE_vii[$454 & 4095]($451,$456);
   $457 = HEAP32[$inOperator>>2]|0;
   $458 = (($457) + 8|0);
   $459 = HEAP32[$458>>2]|0;
   $460 = (($459) + -1)|0;
   $461 = (($457) + 4|0);
   $462 = HEAP32[$461>>2]|0;
   $463 = ((($462) + ($460<<3)|0) + 4|0);
   HEAP8[$463>>0] = 1;
   $$pre$i69 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i70 = (($$pre$i69) + 8|0);
   $$pre1$i71 = HEAP32[$$phi$trans$insert$i70>>2]|0;
   $466 = $$pre$i69;$471 = $$pre1$i71;
  }
 } while(0);
 HEAP32[$0>>2] = $440;
 $464 = (($0) + 4|0);
 HEAP8[$464>>0] = 0;
 $465 = (($466) + 12|0);
 $467 = HEAP32[$465>>2]|0;
 $468 = $467 & 2147483647;
 $469 = (($466) + 8|0);
 $470 = ($468>>>0)>($471>>>0);
 if ($470) {
  $472 = (($466) + 4|0);
  $473 = HEAP32[$472>>2]|0;
  $474 = (($473) + ($471<<3)|0);
  $475 = ($474|0)==(0|0);
  if ($475) {
   $487 = $471;
  } else {
   $476 = $0;
   $477 = $476;
   $478 = HEAP32[$477>>2]|0;
   $479 = (($476) + 4)|0;
   $480 = $479;
   $481 = HEAP32[$480>>2]|0;
   $482 = $474;
   $483 = $482;
   HEAP32[$483>>2] = $478;
   $484 = (($482) + 4)|0;
   $485 = $484;
   HEAP32[$485>>2] = $481;
   $$pre$i$i73 = HEAP32[$469>>2]|0;
   $487 = $$pre$i$i73;
  }
  $486 = (($487) + 1)|0;
  HEAP32[$469>>2] = $486;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($466,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $488 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$488>>2] = 0;
 $489 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$489>>2] = $439;
 $490 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$490>>2] = $438;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj615ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $491 = HEAP32[$inOperator>>2]|0;
 $492 = (($491) + 8|0);
 $493 = HEAP32[$492>>2]|0;
 $494 = ($493|0)==(0);
 if ($494) {
  $514 = 0;$517 = $491;
 } else {
  $495 = (($493) + -1)|0;
  $496 = (($491) + 4|0);
  $497 = HEAP32[$496>>2]|0;
  $498 = ((($497) + ($495<<3)|0) + 4|0);
  $499 = HEAP8[$498>>0]|0;
  $500 = ($499<<24>>24)==(0);
  if ($500) {
   $507 = $491;$509 = $493;
  } else {
   $501 = (($inOperator) + 4|0);
   $502 = HEAP32[$501>>2]|0;
   $503 = HEAP32[$502>>2]|0;
   $504 = (($503) + 20|0);
   $505 = HEAP32[$504>>2]|0;
   FUNCTION_TABLE_vi[$505 & 4095]($502);
   $$pre$i$i$i$i65 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i66 = (($$pre$i$i$i$i65) + 8|0);
   $$pre1$i$i$i$i67 = HEAP32[$$phi$trans$insert$i$i$i$i66>>2]|0;
   $507 = $$pre$i$i$i$i65;$509 = $$pre1$i$i$i$i67;
  }
  $506 = (($507) + 8|0);
  $508 = (($509) + -1)|0;
  HEAP32[$506>>2] = $508;
  $$pre105 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert106 = (($$pre105) + 8|0);
  $$pre107 = HEAP32[$$phi$trans$insert106>>2]|0;
  $514 = $$pre107;$517 = $$pre105;
 }
 $510 = (($this) + 180|0);
 $511 = (($inStartIndex) + 8)|0;
 $512 = HEAP32[$510>>2]|0;
 $513 = ($514|0)==(0);
 do {
  if ($513) {
   $538 = $517;$543 = 0;
  } else {
   $515 = (($514) + -1)|0;
   $516 = (($517) + 4|0);
   $518 = HEAP32[$516>>2]|0;
   $519 = ((($518) + ($515<<3)|0) + 4|0);
   $520 = HEAP8[$519>>0]|0;
   $521 = ($520<<24>>24)==(0);
   if (!($521)) {
    $538 = $517;$543 = $514;
    break;
   }
   $522 = (($inOperator) + 4|0);
   $523 = HEAP32[$522>>2]|0;
   $524 = HEAP32[$523>>2]|0;
   $525 = (($524) + 16|0);
   $526 = HEAP32[$525>>2]|0;
   $527 = (($518) + ($515<<3)|0);
   $528 = HEAP32[$527>>2]|0;
   FUNCTION_TABLE_vii[$526 & 4095]($523,$528);
   $529 = HEAP32[$inOperator>>2]|0;
   $530 = (($529) + 8|0);
   $531 = HEAP32[$530>>2]|0;
   $532 = (($531) + -1)|0;
   $533 = (($529) + 4|0);
   $534 = HEAP32[$533>>2]|0;
   $535 = ((($534) + ($532<<3)|0) + 4|0);
   HEAP8[$535>>0] = 1;
   $$pre$i80 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i81 = (($$pre$i80) + 8|0);
   $$pre1$i82 = HEAP32[$$phi$trans$insert$i81>>2]|0;
   $538 = $$pre$i80;$543 = $$pre1$i82;
  }
 } while(0);
 HEAP32[$0>>2] = $512;
 $536 = (($0) + 4|0);
 HEAP8[$536>>0] = 0;
 $537 = (($538) + 12|0);
 $539 = HEAP32[$537>>2]|0;
 $540 = $539 & 2147483647;
 $541 = (($538) + 8|0);
 $542 = ($540>>>0)>($543>>>0);
 if ($542) {
  $544 = (($538) + 4|0);
  $545 = HEAP32[$544>>2]|0;
  $546 = (($545) + ($543<<3)|0);
  $547 = ($546|0)==(0|0);
  if ($547) {
   $559 = $543;
  } else {
   $548 = $0;
   $549 = $548;
   $550 = HEAP32[$549>>2]|0;
   $551 = (($548) + 4)|0;
   $552 = $551;
   $553 = HEAP32[$552>>2]|0;
   $554 = $546;
   $555 = $554;
   HEAP32[$555>>2] = $550;
   $556 = (($554) + 4)|0;
   $557 = $556;
   HEAP32[$557>>2] = $553;
   $$pre$i$i84 = HEAP32[$541>>2]|0;
   $559 = $$pre$i$i84;
  }
  $558 = (($559) + 1)|0;
  HEAP32[$541>>2] = $558;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($538,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $560 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$560>>2] = 0;
 $561 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$561>>2] = $511;
 $562 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$562>>2] = $510;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj616ES2_KjiEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $563 = HEAP32[$inOperator>>2]|0;
 $564 = (($563) + 8|0);
 $565 = HEAP32[$564>>2]|0;
 $566 = ($565|0)==(0);
 if ($566) {
  $586 = 0;$589 = $563;
 } else {
  $567 = (($565) + -1)|0;
  $568 = (($563) + 4|0);
  $569 = HEAP32[$568>>2]|0;
  $570 = ((($569) + ($567<<3)|0) + 4|0);
  $571 = HEAP8[$570>>0]|0;
  $572 = ($571<<24>>24)==(0);
  if ($572) {
   $579 = $563;$581 = $565;
  } else {
   $573 = (($inOperator) + 4|0);
   $574 = HEAP32[$573>>2]|0;
   $575 = HEAP32[$574>>2]|0;
   $576 = (($575) + 20|0);
   $577 = HEAP32[$576>>2]|0;
   FUNCTION_TABLE_vi[$577 & 4095]($574);
   $$pre$i$i$i$i76 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i77 = (($$pre$i$i$i$i76) + 8|0);
   $$pre1$i$i$i$i78 = HEAP32[$$phi$trans$insert$i$i$i$i77>>2]|0;
   $579 = $$pre$i$i$i$i76;$581 = $$pre1$i$i$i$i78;
  }
  $578 = (($579) + 8|0);
  $580 = (($581) + -1)|0;
  HEAP32[$578>>2] = $580;
  $$pre108 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert109 = (($$pre108) + 8|0);
  $$pre110 = HEAP32[$$phi$trans$insert109>>2]|0;
  $586 = $$pre110;$589 = $$pre108;
 }
 $582 = (($this) + 204|0);
 $583 = (($inStartIndex) + 9)|0;
 $584 = HEAP32[$582>>2]|0;
 $585 = ($586|0)==(0);
 do {
  if ($585) {
   $610 = $589;$615 = 0;
  } else {
   $587 = (($586) + -1)|0;
   $588 = (($589) + 4|0);
   $590 = HEAP32[$588>>2]|0;
   $591 = ((($590) + ($587<<3)|0) + 4|0);
   $592 = HEAP8[$591>>0]|0;
   $593 = ($592<<24>>24)==(0);
   if (!($593)) {
    $610 = $589;$615 = $586;
    break;
   }
   $594 = (($inOperator) + 4|0);
   $595 = HEAP32[$594>>2]|0;
   $596 = HEAP32[$595>>2]|0;
   $597 = (($596) + 16|0);
   $598 = HEAP32[$597>>2]|0;
   $599 = (($590) + ($587<<3)|0);
   $600 = HEAP32[$599>>2]|0;
   FUNCTION_TABLE_vii[$598 & 4095]($595,$600);
   $601 = HEAP32[$inOperator>>2]|0;
   $602 = (($601) + 8|0);
   $603 = HEAP32[$602>>2]|0;
   $604 = (($603) + -1)|0;
   $605 = (($601) + 4|0);
   $606 = HEAP32[$605>>2]|0;
   $607 = ((($606) + ($604<<3)|0) + 4|0);
   HEAP8[$607>>0] = 1;
   $$pre$i91 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i92 = (($$pre$i91) + 8|0);
   $$pre1$i93 = HEAP32[$$phi$trans$insert$i92>>2]|0;
   $610 = $$pre$i91;$615 = $$pre1$i93;
  }
 } while(0);
 HEAP32[$0>>2] = $584;
 $608 = (($0) + 4|0);
 HEAP8[$608>>0] = 0;
 $609 = (($610) + 12|0);
 $611 = HEAP32[$609>>2]|0;
 $612 = $611 & 2147483647;
 $613 = (($610) + 8|0);
 $614 = ($612>>>0)>($615>>>0);
 if ($614) {
  $616 = (($610) + 4|0);
  $617 = HEAP32[$616>>2]|0;
  $618 = (($617) + ($615<<3)|0);
  $619 = ($618|0)==(0|0);
  if ($619) {
   $631 = $615;
  } else {
   $620 = $0;
   $621 = $620;
   $622 = HEAP32[$621>>2]|0;
   $623 = (($620) + 4)|0;
   $624 = $623;
   $625 = HEAP32[$624>>2]|0;
   $626 = $618;
   $627 = $626;
   HEAP32[$627>>2] = $622;
   $628 = (($626) + 4)|0;
   $629 = $628;
   HEAP32[$629>>2] = $625;
   $$pre$i$i95 = HEAP32[$613>>2]|0;
   $631 = $$pre$i$i95;
  }
  $630 = (($631) + 1)|0;
  HEAP32[$613>>2] = $630;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($610,$0)|0);
 }
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $632 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$632>>2] = 0;
 $633 = (($theAccessor$i$i$i86) + 8|0);
 HEAP32[$633>>2] = $583;
 $634 = (($theAccessor$i$i$i86) + 12|0);
 HEAP32[$634>>2] = $582;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj617ES2_KjNS_12PxFilterDataEEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i$i$i86,0);
 $635 = HEAP32[$inOperator>>2]|0;
 $636 = (($635) + 8|0);
 $637 = HEAP32[$636>>2]|0;
 $638 = ($637|0)==(0);
 if ($638) {
  $659 = 0;$662 = $635;
 } else {
  $639 = (($637) + -1)|0;
  $640 = (($635) + 4|0);
  $641 = HEAP32[$640>>2]|0;
  $642 = ((($641) + ($639<<3)|0) + 4|0);
  $643 = HEAP8[$642>>0]|0;
  $644 = ($643<<24>>24)==(0);
  if ($644) {
   $651 = $635;$653 = $637;
  } else {
   $645 = (($inOperator) + 4|0);
   $646 = HEAP32[$645>>2]|0;
   $647 = HEAP32[$646>>2]|0;
   $648 = (($647) + 20|0);
   $649 = HEAP32[$648>>2]|0;
   FUNCTION_TABLE_vi[$649 & 4095]($646);
   $$pre$i$i$i$i87 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i88 = (($$pre$i$i$i$i87) + 8|0);
   $$pre1$i$i$i$i89 = HEAP32[$$phi$trans$insert$i$i$i$i88>>2]|0;
   $651 = $$pre$i$i$i$i87;$653 = $$pre1$i$i$i$i89;
  }
  $650 = (($651) + 8|0);
  $652 = (($653) + -1)|0;
  HEAP32[$650>>2] = $652;
  $$pre111 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert112 = (($$pre111) + 8|0);
  $$pre113 = HEAP32[$$phi$trans$insert112>>2]|0;
  $659 = $$pre113;$662 = $$pre111;
 }
 $654 = (($this) + 228|0);
 HEAP8[$theAccessor$i$i$i86>>0] = 0;
 $655 = (($theAccessor$i$i$i86) + 4|0);
 HEAP32[$655>>2] = 0;
 $656 = (($theAccessor$i$i$i86) + 8|0);
 ;HEAP32[$656+0>>2]=HEAP32[$654+0>>2]|0;HEAP32[$656+4>>2]=HEAP32[$654+4>>2]|0;HEAP32[$656+8>>2]=HEAP32[$654+8>>2]|0;HEAP32[$656+12>>2]=HEAP32[$654+12>>2]|0;
 $657 = HEAP32[$654>>2]|0;
 $658 = ($659|0)==(0);
 do {
  if ($658) {
   $683 = $662;$688 = 0;
  } else {
   $660 = (($659) + -1)|0;
   $661 = (($662) + 4|0);
   $663 = HEAP32[$661>>2]|0;
   $664 = ((($663) + ($660<<3)|0) + 4|0);
   $665 = HEAP8[$664>>0]|0;
   $666 = ($665<<24>>24)==(0);
   if (!($666)) {
    $683 = $662;$688 = $659;
    break;
   }
   $667 = (($inOperator) + 4|0);
   $668 = HEAP32[$667>>2]|0;
   $669 = HEAP32[$668>>2]|0;
   $670 = (($669) + 16|0);
   $671 = HEAP32[$670>>2]|0;
   $672 = (($663) + ($660<<3)|0);
   $673 = HEAP32[$672>>2]|0;
   FUNCTION_TABLE_vii[$671 & 4095]($668,$673);
   $674 = HEAP32[$inOperator>>2]|0;
   $675 = (($674) + 8|0);
   $676 = HEAP32[$675>>2]|0;
   $677 = (($676) + -1)|0;
   $678 = (($674) + 4|0);
   $679 = HEAP32[$678>>2]|0;
   $680 = ((($679) + ($677<<3)|0) + 4|0);
   HEAP8[$680>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $683 = $$pre$i;$688 = $$pre1$i;
  }
 } while(0);
 HEAP32[$0>>2] = $657;
 $681 = (($0) + 4|0);
 HEAP8[$681>>0] = 0;
 $682 = (($683) + 12|0);
 $684 = HEAP32[$682>>2]|0;
 $685 = $684 & 2147483647;
 $686 = (($683) + 8|0);
 $687 = ($685>>>0)>($688>>>0);
 if ($687) {
  $689 = (($683) + 4|0);
  $690 = HEAP32[$689>>2]|0;
  $691 = (($690) + ($688<<3)|0);
  $692 = ($691|0)==(0|0);
  if ($692) {
   $704 = $688;
  } else {
   $693 = $0;
   $694 = $693;
   $695 = HEAP32[$694>>2]|0;
   $696 = (($693) + 4)|0;
   $697 = $696;
   $698 = HEAP32[$697>>2]|0;
   $699 = $691;
   $700 = $699;
   HEAP32[$700>>2] = $695;
   $701 = (($699) + 4)|0;
   $702 = $701;
   HEAP32[$702>>2] = $698;
   $$pre$i$i1 = HEAP32[$686>>2]|0;
   $704 = $$pre$i$i1;
  }
  $703 = (($704) + 1)|0;
  HEAP32[$686>>2] = $703;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($683,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsSimDataEEEE14handleAccessorILj618ENS_22PxRepXPropertyAccessorILj618ES4_RKNS_27PxVehicleTireLoadFilterDataES9_EEEEvRKT0_($inOperator,$theAccessor$i$i$i86);
 $705 = HEAP32[$inOperator>>2]|0;
 $706 = (($705) + 8|0);
 $707 = HEAP32[$706>>2]|0;
 $708 = ($707|0)==(0);
 if ($708) {
  $724 = (($inStartIndex) + 12)|0;
  STACKTOP = sp;return ($724|0);
 }
 $709 = (($707) + -1)|0;
 $710 = (($705) + 4|0);
 $711 = HEAP32[$710>>2]|0;
 $712 = ((($711) + ($709<<3)|0) + 4|0);
 $713 = HEAP8[$712>>0]|0;
 $714 = ($713<<24>>24)==(0);
 if ($714) {
  $721 = $705;$723 = $707;
 } else {
  $715 = (($inOperator) + 4|0);
  $716 = HEAP32[$715>>2]|0;
  $717 = HEAP32[$716>>2]|0;
  $718 = (($717) + 20|0);
  $719 = HEAP32[$718>>2]|0;
  FUNCTION_TABLE_vi[$719 & 4095]($716);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $721 = $$pre$i$i;$723 = $$pre1$i$i;
 }
 $720 = (($721) + 8|0);
 $722 = (($723) + -1)|0;
 HEAP32[$720>>2] = $722;
 $724 = (($inStartIndex) + 12)|0;
 STACKTOP = sp;return ($724|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsSimDataEEEE14handleAccessorILj618ENS_22PxRepXPropertyAccessorILj618ES4_RKNS_27PxVehicleTireLoadFilterDataES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $info$i$i$i$i$i = sp + 140|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 64|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 0;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $$0$i = $5;
 }
 HEAP8[$inAccessor>>0] = 1;
 $6 = (($inAccessor) + 4|0);
 HEAP32[$6>>2] = $$0$i;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$8>>2] = $11;
 }
 dest=$1+0|0; stop=dest+76|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx40PxVehicleTireLoadFilterDataGeneratedInfoC2Ev($1);
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($inAccessor) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($propVal$i$i$i,$13);
 $16 = HEAP32[$this>>2]|0;
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx40PxVehicleTireLoadFilterDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $16;
 $23 = (($0) + 4|0);
 HEAP32[$23>>2] = $18;
 $24 = (($0) + 8|0);
 HEAP32[$24>>2] = $propVal$i$i$i;
 $25 = (($0) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($0) + 16|0);
 HEAP32[$26>>2] = $22;
 $27 = (($0) + 20|0);
 HEAP32[$27>>2] = 0;
 $28 = (($0) + 24|0);
 HEAP32[$28>>2] = 0;
 (__ZNK5physx40PxVehicleTireLoadFilterDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx40PxVehicleTireLoadFilterDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i12 = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i16 = 0, $$phi$trans$insert$i23 = 0, $$phi$trans$insert$i30 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert40 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i19 = 0, $$pre$i$i26 = 0, $$pre$i$i3 = 0, $$pre$i$i33 = 0;
 var $$pre$i$i7 = 0, $$pre$i15 = 0, $$pre$i22 = 0, $$pre$i29 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i13 = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i17 = 0, $$pre1$i24 = 0, $$pre1$i31 = 0, $$pre35 = 0, $$pre36 = 0, $$pre38 = 0, $$pre39 = 0, $$pre41 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i10 = sp + 8|0;
 $1 = (($this) + 12|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $2 = (($theAccessor$i10) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i15 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i16 = (($$pre$i15) + 8|0);
   $$pre1$i17 = HEAP32[$$phi$trans$insert$i16>>2]|0;
   $31 = $$pre$i15;$36 = $$pre1$i17;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i19 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i19;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEE14handleAccessorILj561ENS_22PxRepXPropertyAccessorILj561ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i10);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre35 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre35;$80 = $$pre;
 }
 $72 = (($this) + 28|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $73 = (($theAccessor$i10) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i22 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i23 = (($$pre$i22) + 8|0);
   $$pre1$i24 = HEAP32[$$phi$trans$insert$i23>>2]|0;
   $101 = $$pre$i22;$106 = $$pre1$i24;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i26 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i26;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEE14handleAccessorILj562ENS_22PxRepXPropertyAccessorILj562ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i10);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $147 = 0;$150 = $123;
 } else {
  $127 = (($125) + -1)|0;
  $128 = (($123) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129) + ($127<<3)|0) + 4|0);
  $131 = HEAP8[$130>>0]|0;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $139 = $123;$141 = $125;
  } else {
   $133 = (($inOperator) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = HEAP32[$134>>2]|0;
   $136 = (($135) + 20|0);
   $137 = HEAP32[$136>>2]|0;
   FUNCTION_TABLE_vi[$137 & 4095]($134);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $139 = $$pre$i$i7;$141 = $$pre1$i$i9;
  }
  $138 = (($139) + 8|0);
  $140 = (($141) + -1)|0;
  HEAP32[$138>>2] = $140;
  $$pre36 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert37 = (($$pre36) + 8|0);
  $$pre38 = HEAP32[$$phi$trans$insert37>>2]|0;
  $147 = $$pre38;$150 = $$pre36;
 }
 $142 = (($this) + 44|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $143 = (($theAccessor$i10) + 4|0);
 HEAP32[$143>>2] = 0;
 $144 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$144+0>>2]=HEAP32[$142+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$142+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$142+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$142+12>>2]|0;
 $145 = HEAP32[$142>>2]|0;
 $146 = ($147|0)==(0);
 if ($146) {
  $171 = $150;$176 = 0;
 } else {
  $148 = (($147) + -1)|0;
  $149 = (($150) + 4|0);
  $151 = HEAP32[$149>>2]|0;
  $152 = ((($151) + ($148<<3)|0) + 4|0);
  $153 = HEAP8[$152>>0]|0;
  $154 = ($153<<24>>24)==(0);
  if ($154) {
   $155 = (($inOperator) + 4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = HEAP32[$156>>2]|0;
   $158 = (($157) + 16|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($151) + ($148<<3)|0);
   $161 = HEAP32[$160>>2]|0;
   FUNCTION_TABLE_vii[$159 & 4095]($156,$161);
   $162 = HEAP32[$inOperator>>2]|0;
   $163 = (($162) + 8|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($164) + -1)|0;
   $166 = (($162) + 4|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ((($167) + ($165<<3)|0) + 4|0);
   HEAP8[$168>>0] = 1;
   $$pre$i29 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i30 = (($$pre$i29) + 8|0);
   $$pre1$i31 = HEAP32[$$phi$trans$insert$i30>>2]|0;
   $171 = $$pre$i29;$176 = $$pre1$i31;
  } else {
   $171 = $150;$176 = $147;
  }
 }
 HEAP32[$0>>2] = $145;
 $169 = (($0) + 4|0);
 HEAP8[$169>>0] = 0;
 $170 = (($171) + 12|0);
 $172 = HEAP32[$170>>2]|0;
 $173 = $172 & 2147483647;
 $174 = (($171) + 8|0);
 $175 = ($173>>>0)>($176>>>0);
 if ($175) {
  $177 = (($171) + 4|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + ($176<<3)|0);
  $180 = ($179|0)==(0|0);
  if ($180) {
   $192 = $176;
  } else {
   $181 = $0;
   $182 = $181;
   $183 = HEAP32[$182>>2]|0;
   $184 = (($181) + 4)|0;
   $185 = $184;
   $186 = HEAP32[$185>>2]|0;
   $187 = $179;
   $188 = $187;
   HEAP32[$188>>2] = $183;
   $189 = (($187) + 4)|0;
   $190 = $189;
   HEAP32[$190>>2] = $186;
   $$pre$i$i33 = HEAP32[$174>>2]|0;
   $192 = $$pre$i$i33;
  }
  $191 = (($192) + 1)|0;
  HEAP32[$174>>2] = $191;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($171,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEE14handleAccessorILj563ENS_22PxRepXPropertyAccessorILj563ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i10);
 $193 = HEAP32[$inOperator>>2]|0;
 $194 = (($193) + 8|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)==(0);
 if ($196) {
  $217 = 0;$220 = $193;
 } else {
  $197 = (($195) + -1)|0;
  $198 = (($193) + 4|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ((($199) + ($197<<3)|0) + 4|0);
  $201 = HEAP8[$200>>0]|0;
  $202 = ($201<<24>>24)==(0);
  if ($202) {
   $209 = $193;$211 = $195;
  } else {
   $203 = (($inOperator) + 4|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = HEAP32[$204>>2]|0;
   $206 = (($205) + 20|0);
   $207 = HEAP32[$206>>2]|0;
   FUNCTION_TABLE_vi[$207 & 4095]($204);
   $$pre$i$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i12 = (($$pre$i$i11) + 8|0);
   $$pre1$i$i13 = HEAP32[$$phi$trans$insert$i$i12>>2]|0;
   $209 = $$pre$i$i11;$211 = $$pre1$i$i13;
  }
  $208 = (($209) + 8|0);
  $210 = (($211) + -1)|0;
  HEAP32[$208>>2] = $210;
  $$pre39 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert40 = (($$pre39) + 8|0);
  $$pre41 = HEAP32[$$phi$trans$insert40>>2]|0;
  $217 = $$pre41;$220 = $$pre39;
 }
 $212 = (($this) + 60|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $213 = (($theAccessor$i10) + 4|0);
 HEAP32[$213>>2] = 0;
 $214 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$214+0>>2]=HEAP32[$212+0>>2]|0;HEAP32[$214+4>>2]=HEAP32[$212+4>>2]|0;HEAP32[$214+8>>2]=HEAP32[$212+8>>2]|0;HEAP32[$214+12>>2]=HEAP32[$212+12>>2]|0;
 $215 = HEAP32[$212>>2]|0;
 $216 = ($217|0)==(0);
 if ($216) {
  $241 = $220;$246 = 0;
 } else {
  $218 = (($217) + -1)|0;
  $219 = (($220) + 4|0);
  $221 = HEAP32[$219>>2]|0;
  $222 = ((($221) + ($218<<3)|0) + 4|0);
  $223 = HEAP8[$222>>0]|0;
  $224 = ($223<<24>>24)==(0);
  if ($224) {
   $225 = (($inOperator) + 4|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = HEAP32[$226>>2]|0;
   $228 = (($227) + 16|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = (($221) + ($218<<3)|0);
   $231 = HEAP32[$230>>2]|0;
   FUNCTION_TABLE_vii[$229 & 4095]($226,$231);
   $232 = HEAP32[$inOperator>>2]|0;
   $233 = (($232) + 8|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = (($234) + -1)|0;
   $236 = (($232) + 4|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ((($237) + ($235<<3)|0) + 4|0);
   HEAP8[$238>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $241 = $$pre$i;$246 = $$pre1$i;
  } else {
   $241 = $220;$246 = $217;
  }
 }
 HEAP32[$0>>2] = $215;
 $239 = (($0) + 4|0);
 HEAP8[$239>>0] = 0;
 $240 = (($241) + 12|0);
 $242 = HEAP32[$240>>2]|0;
 $243 = $242 & 2147483647;
 $244 = (($241) + 8|0);
 $245 = ($243>>>0)>($246>>>0);
 if ($245) {
  $247 = (($241) + 4|0);
  $248 = HEAP32[$247>>2]|0;
  $249 = (($248) + ($246<<3)|0);
  $250 = ($249|0)==(0|0);
  if ($250) {
   $262 = $246;
  } else {
   $251 = $0;
   $252 = $251;
   $253 = HEAP32[$252>>2]|0;
   $254 = (($251) + 4)|0;
   $255 = $254;
   $256 = HEAP32[$255>>2]|0;
   $257 = $249;
   $258 = $257;
   HEAP32[$258>>2] = $253;
   $259 = (($257) + 4)|0;
   $260 = $259;
   HEAP32[$260>>2] = $256;
   $$pre$i$i1 = HEAP32[$244>>2]|0;
   $262 = $$pre$i$i1;
  }
  $261 = (($262) + 1)|0;
  HEAP32[$244>>2] = $261;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($241,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEE14handleAccessorILj564ENS_22PxRepXPropertyAccessorILj564ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i10);
 $263 = HEAP32[$inOperator>>2]|0;
 $264 = (($263) + 8|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = ($265|0)==(0);
 if ($266) {
  $282 = (($inStartIndex) + 5)|0;
  STACKTOP = sp;return ($282|0);
 }
 $267 = (($265) + -1)|0;
 $268 = (($263) + 4|0);
 $269 = HEAP32[$268>>2]|0;
 $270 = ((($269) + ($267<<3)|0) + 4|0);
 $271 = HEAP8[$270>>0]|0;
 $272 = ($271<<24>>24)==(0);
 if ($272) {
  $279 = $263;$281 = $265;
 } else {
  $273 = (($inOperator) + 4|0);
  $274 = HEAP32[$273>>2]|0;
  $275 = HEAP32[$274>>2]|0;
  $276 = (($275) + 20|0);
  $277 = HEAP32[$276>>2]|0;
  FUNCTION_TABLE_vi[$277 & 4095]($274);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $279 = $$pre$i$i;$281 = $$pre1$i$i;
 }
 $278 = (($279) + 8|0);
 $280 = (($281) + -1)|0;
 HEAP32[$278>>2] = $280;
 $282 = (($inStartIndex) + 5)|0;
 STACKTOP = sp;return ($282|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEE14handleAccessorILj564ENS_22PxRepXPropertyAccessorILj564ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 16;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 16)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEE14handleAccessorILj563ENS_22PxRepXPropertyAccessorILj563ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 12;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEE14handleAccessorILj562ENS_22PxRepXPropertyAccessorILj562ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleTireLoadFilterDataEEEE14handleAccessorILj561ENS_22PxRepXPropertyAccessorILj561ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 4;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 4)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj617ES2_KjNS_12PxFilterDataEEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $propVal = 0, $theData = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $vararg_buffer = sp + 16|0;
 $2 = sp;
 $theData = sp + 56|0;
 $3 = sp + 24|0;
 $buffer = sp + 152|0;
 $propVal = sp + 40|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($inProp) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($5)|0);
 $11 = (($theData) + 80|0);
 $12 = (($theData) + 84|0);
 $13 = (($theData) + 88|0);
 HEAP32[$13>>2] = 0;
 $14 = (($theData) + 92|0);
 HEAP8[$11>>0] = 1;
 HEAP32[$12>>2] = $theData;
 HEAP32[$14>>2] = 5;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_12PxFilterDataENS0_15InlineAllocatorILj80ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($theData,$10,$3);
 $15 = ($10|0)==(0);
 if (!($15)) {
  $16 = (($vararg_buffer) + 4|0);
  $17 = (($this) + 4|0);
  $18 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer)|0);
   $19 = HEAP32[$this>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    $43 = $19;$48 = 0;
   } else {
    $23 = (($21) + -1)|0;
    $24 = (($19) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($25) + ($23<<3)|0) + 4|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $29 = HEAP32[$17>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($30) + 16|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($25) + ($23<<3)|0);
     $34 = HEAP32[$33>>2]|0;
     FUNCTION_TABLE_vii[$32 & 4095]($29,$34);
     $35 = HEAP32[$this>>2]|0;
     $36 = (($35) + 8|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($37) + -1)|0;
     $39 = (($35) + 4|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ((($40) + ($38<<3)|0) + 4|0);
     HEAP8[$41>>0] = 1;
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $43 = $$pre$i1;$48 = $$pre1$i3;
    } else {
     $43 = $19;$48 = $21;
    }
   }
   HEAP32[$vararg_buffer>>2] = $buffer;
   HEAP8[$16>>0] = 0;
   $42 = (($43) + 12|0);
   $44 = HEAP32[$42>>2]|0;
   $45 = $44 & 2147483647;
   $46 = (($43) + 8|0);
   $47 = ($45>>>0)>($48>>>0);
   if ($47) {
    $49 = (($43) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + ($48<<3)|0);
    $52 = ($51|0)==(0|0);
    if ($52) {
     $64 = $48;
    } else {
     $53 = $vararg_buffer;
     $54 = $53;
     $55 = HEAP32[$54>>2]|0;
     $56 = (($53) + 4)|0;
     $57 = $56;
     $58 = HEAP32[$57>>2]|0;
     $59 = $51;
     $60 = $59;
     HEAP32[$60>>2] = $55;
     $61 = (($59) + 4)|0;
     $62 = $61;
     HEAP32[$62>>2] = $58;
     $$pre$i$i = HEAP32[$46>>2]|0;
     $64 = $$pre$i$i;
    }
    $63 = (($64) + 1)|0;
    HEAP32[$46>>2] = $63;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($43,$vararg_buffer)|0);
   }
   $65 = HEAP32[$4>>2]|0;
   $66 = HEAP32[$6>>2]|0;
   $67 = (($66) + 12|0);
   $68 = HEAP32[$67>>2]|0;
   FUNCTION_TABLE_viii[$68 & 4095]($propVal,$65,$i$04);
   $69 = HEAP32[$17>>2]|0;
   $70 = HEAP32[$18>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   ;HEAP32[$2+0>>2]=HEAP32[$propVal+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$propVal+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$propVal+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$propVal+12>>2]|0;
   (__ZN5physxlsERNS_14PxOutputStreamERKNS_12PxFilterDataE($70,$2)|0);
   HEAP8[$vararg_buffer>>0] = 0;
   $80 = HEAP32[$70>>2]|0;
   $81 = HEAP32[$80>>2]|0;
   (FUNCTION_TABLE_iiii[$81 & 2047]($70,$vararg_buffer,1)|0);
   $82 = HEAP32[$69>>2]|0;
   $83 = (($82) + 8|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($70) + 20|0);
   $86 = HEAP32[$85>>2]|0;
   FUNCTION_TABLE_viii[$84 & 4095]($69,$$0$i$i,$86);
   $87 = (($70) + 16|0);
   HEAP32[$87>>2] = 0;
   $88 = (($70) + 12|0);
   HEAP32[$88>>2] = 0;
   $89 = HEAP32[$this>>2]|0;
   $90 = (($89) + 8|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(0);
   if (!($92)) {
    $93 = (($91) + -1)|0;
    $94 = (($89) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ((($95) + ($93<<3)|0) + 4|0);
    $97 = HEAP8[$96>>0]|0;
    $98 = ($97<<24>>24)==(0);
    if ($98) {
     $104 = $89;$106 = $91;
    } else {
     $99 = HEAP32[$17>>2]|0;
     $100 = HEAP32[$99>>2]|0;
     $101 = (($100) + 20|0);
     $102 = HEAP32[$101>>2]|0;
     FUNCTION_TABLE_vi[$102 & 4095]($99);
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $104 = $$pre$i;$106 = $$pre1$i;
    }
    $103 = (($104) + 8|0);
    $105 = (($106) + -1)|0;
    HEAP32[$103>>2] = $105;
   }
   $107 = (($i$04) + 1)|0;
   $exitcond = ($107|0)==($10|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $107;
   }
  }
 }
 $108 = HEAP32[$14>>2]|0;
 $109 = $108 & 2147483647;
 $110 = ($109|0)!=(0);
 $111 = ($108|0)>(-1);
 $or$cond$i$i$i = $110 & $111;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $112 = HEAP32[$12>>2]|0;
 $113 = ($theData|0)==($112|0);
 if ($113) {
  HEAP8[$11>>0] = 0;
  STACKTOP = sp;return;
 }
 $114 = ($112|0)==(0|0);
 if ($114) {
  STACKTOP = sp;return;
 }
 $115 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($116) + 12|0);
 $118 = HEAP32[$117>>2]|0;
 FUNCTION_TABLE_vii[$118 & 4095]($115,$112);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_12PxFilterDataENS0_15InlineAllocatorILj80ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_12PxFilterDataENS0_15InlineAllocatorILj80ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($size<<4)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + ($7<<4)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$a+12>>2]|0;
  }
  $12 = (($$01$i) + 16|0);
  $13 = ($12>>>0)<($8>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_12PxFilterDataENS0_15InlineAllocatorILj80ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 4;
  $2 = (($this) + 80|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(81);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 521744 : 521616;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,521536,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 88|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<4)|0);
 $21 = (($this) + 84|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;
   }
   $25 = (($$012$i) + 16|0);
   $26 = (($$03$i) + 16|0);
   $27 = ($25>>>0)<($19>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
 }
 $28 = (($this) + 92|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)>(-1);
 if (!($30)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$21>>2]|0;
 $32 = ($this|0)==($31|0);
 if ($32) {
  $33 = (($this) + 80|0);
  HEAP8[$33>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $34 = ($31|0)==(0|0);
 if ($34) {
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($35,$31);
 HEAP32[$21>>2] = $20;
 HEAP32[$28>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj616ES2_KjiEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $buffer$i$i$i$i = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $theData = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i$i = sp + 80|0;
 $theData = sp + 8|0;
 $2 = sp + 44|0;
 $buffer = sp + 48|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($inProp) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 $10 = (($theData) + 20|0);
 $11 = (($theData) + 24|0);
 $12 = (($theData) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($theData) + 32|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $theData;
 HEAP32[$13>>2] = 5;
 HEAP32[$2>>2] = 0;
 __ZN5physx6shdfnd5ArrayIiNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIiEEEEE6resizeEjRKi($theData,$9,$2);
 $14 = ($9|0)==(0);
 if (!($14)) {
  $15 = (($vararg_buffer1) + 4|0);
  $16 = (($this) + 4|0);
  $17 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer1)|0);
   $18 = HEAP32[$this>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $42 = $18;$47 = 0;
   } else {
    $22 = (($20) + -1)|0;
    $23 = (($18) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($24) + ($22<<3)|0) + 4|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($24) + ($22<<3)|0);
     $33 = HEAP32[$32>>2]|0;
     FUNCTION_TABLE_vii[$31 & 4095]($28,$33);
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + -1)|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39) + ($37<<3)|0) + 4|0);
     HEAP8[$40>>0] = 1;
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $42 = $$pre$i;$47 = $$pre1$i;
    } else {
     $42 = $18;$47 = $20;
    }
   }
   HEAP32[$vararg_buffer1>>2] = $buffer;
   HEAP8[$15>>0] = 0;
   $41 = (($42) + 12|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($42) + 8|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    $48 = (($42) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47<<3)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $63 = $47;
    } else {
     $52 = $vararg_buffer1;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $50;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $$pre$i$i = HEAP32[$45>>2]|0;
     $63 = $$pre$i$i;
    }
    $62 = (($63) + 1)|0;
    HEAP32[$45>>2] = $62;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($42,$vararg_buffer1)|0);
   }
   $64 = HEAP32[$3>>2]|0;
   $65 = HEAP32[$5>>2]|0;
   $66 = (($65) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (FUNCTION_TABLE_iii[$67 & 4095]($64,$i$04)|0);
   $69 = HEAP32[$16>>2]|0;
   $70 = HEAP32[$17>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   dest=$buffer$i$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $68;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i$i,0,521856,$vararg_buffer1)|0);
   $80 = HEAP8[$buffer$i$i$i$i>>0]|0;
   $81 = ($80<<24>>24)==(0);
   if (!($81)) {
    $82 = HEAP32[$70>>2]|0;
    $83 = HEAP32[$82>>2]|0;
    $84 = (_strlen(($buffer$i$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$83 & 2047]($70,$buffer$i$i$i$i,$84)|0);
   }
   HEAP8[$vararg_buffer1>>0] = 0;
   $85 = HEAP32[$70>>2]|0;
   $86 = HEAP32[$85>>2]|0;
   (FUNCTION_TABLE_iiii[$86 & 2047]($70,$vararg_buffer1,1)|0);
   $87 = HEAP32[$69>>2]|0;
   $88 = (($87) + 8|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($70) + 20|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_viii[$89 & 4095]($69,$$0$i$i,$91);
   $92 = (($70) + 16|0);
   HEAP32[$92>>2] = 0;
   $93 = (($70) + 12|0);
   HEAP32[$93>>2] = 0;
   $94 = HEAP32[$this>>2]|0;
   $95 = (($94) + 8|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0);
   if (!($97)) {
    $98 = (($96) + -1)|0;
    $99 = (($94) + 4|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = ((($100) + ($98<<3)|0) + 4|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $109 = $94;$111 = $96;
    } else {
     $104 = HEAP32[$16>>2]|0;
     $105 = HEAP32[$104>>2]|0;
     $106 = (($105) + 20|0);
     $107 = HEAP32[$106>>2]|0;
     FUNCTION_TABLE_vi[$107 & 4095]($104);
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $109 = $$pre$i1;$111 = $$pre1$i3;
    }
    $108 = (($109) + 8|0);
    $110 = (($111) + -1)|0;
    HEAP32[$108>>2] = $110;
   }
   $112 = (($i$04) + 1)|0;
   $exitcond = ($112|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $112;
   }
  }
 }
 $113 = HEAP32[$13>>2]|0;
 $114 = $113 & 2147483647;
 $115 = ($114|0)!=(0);
 $116 = ($113|0)>(-1);
 $or$cond$i$i$i = $115 & $116;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $117 = HEAP32[$11>>2]|0;
 $118 = ($theData|0)==($117|0);
 if ($118) {
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $119 = ($117|0)==(0|0);
 if ($119) {
  STACKTOP = sp;return;
 }
 $120 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = (($121) + 12|0);
 $123 = HEAP32[$122>>2]|0;
 FUNCTION_TABLE_vii[$123 & 4095]($120,$117);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIiNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIiEEEEE6resizeEjRKi($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIiNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIiEEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($size<<2)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + ($7<<2)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $12;
  }
  $13 = (($$01$i) + 4|0);
  $14 = ($13>>>0)<($8>>>0);
  if ($14) {
   $$01$i = $13;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIiNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIiEEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = (($this) + 20|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(21);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 521864 : 521616;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,521536,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<2)|0);
 $21 = (($this) + 24|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($19>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = (($this) + 32|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(-1);
 if (!($31)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$21>>2]|0;
 $33 = ($this|0)==($32|0);
 if ($33) {
  $34 = (($this) + 20|0);
  HEAP8[$34>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = ($32|0)==(0|0);
 if ($35) {
  HEAP32[$21>>2] = $20;
  HEAP32[$29>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $36 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_vii[$39 & 4095]($36,$32);
 HEAP32[$21>>2] = $20;
 HEAP32[$29>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj615ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $propVal = 0, $theData = 0, $vararg_buffer = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $vararg_buffer = sp;
 $2 = sp + 108|0;
 $theData = sp + 8|0;
 $3 = sp + 84|0;
 $buffer = sp + 120|0;
 $propVal = sp + 96|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($inProp) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($5)|0);
 $11 = (($theData) + 60|0);
 $12 = (($theData) + 64|0);
 $13 = (($theData) + 68|0);
 HEAP32[$13>>2] = 0;
 $14 = (($theData) + 72|0);
 HEAP8[$11>>0] = 1;
 HEAP32[$12>>2] = $theData;
 HEAP32[$14>>2] = 5;
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_15InlineAllocatorILj60ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($theData,$10,$3);
 $15 = ($10|0)==(0);
 if (!($15)) {
  $16 = (($vararg_buffer) + 4|0);
  $17 = (($this) + 4|0);
  $18 = (($this) + 12|0);
  $19 = (($2) + 4|0);
  $20 = (($propVal) + 4|0);
  $21 = (($2) + 8|0);
  $22 = (($propVal) + 8|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer)|0);
   $23 = HEAP32[$this>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if ($26) {
    $47 = $23;$52 = 0;
   } else {
    $27 = (($25) + -1)|0;
    $28 = (($23) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($29) + ($27<<3)|0) + 4|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     $33 = HEAP32[$17>>2]|0;
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 16|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($29) + ($27<<3)|0);
     $38 = HEAP32[$37>>2]|0;
     FUNCTION_TABLE_vii[$36 & 4095]($33,$38);
     $39 = HEAP32[$this>>2]|0;
     $40 = (($39) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + -1)|0;
     $43 = (($39) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ((($44) + ($42<<3)|0) + 4|0);
     HEAP8[$45>>0] = 1;
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $47 = $$pre$i1;$52 = $$pre1$i3;
    } else {
     $47 = $23;$52 = $25;
    }
   }
   HEAP32[$vararg_buffer>>2] = $buffer;
   HEAP8[$16>>0] = 0;
   $46 = (($47) + 12|0);
   $48 = HEAP32[$46>>2]|0;
   $49 = $48 & 2147483647;
   $50 = (($47) + 8|0);
   $51 = ($49>>>0)>($52>>>0);
   if ($51) {
    $53 = (($47) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + ($52<<3)|0);
    $56 = ($55|0)==(0|0);
    if ($56) {
     $68 = $52;
    } else {
     $57 = $vararg_buffer;
     $58 = $57;
     $59 = HEAP32[$58>>2]|0;
     $60 = (($57) + 4)|0;
     $61 = $60;
     $62 = HEAP32[$61>>2]|0;
     $63 = $55;
     $64 = $63;
     HEAP32[$64>>2] = $59;
     $65 = (($63) + 4)|0;
     $66 = $65;
     HEAP32[$66>>2] = $62;
     $$pre$i$i = HEAP32[$50>>2]|0;
     $68 = $$pre$i$i;
    }
    $67 = (($68) + 1)|0;
    HEAP32[$50>>2] = $67;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($47,$vararg_buffer)|0);
   }
   $69 = HEAP32[$4>>2]|0;
   $70 = HEAP32[$6>>2]|0;
   $71 = (($70) + 12|0);
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_viii[$72 & 4095]($propVal,$69,$i$04);
   $73 = HEAP32[$17>>2]|0;
   $74 = HEAP32[$18>>2]|0;
   $75 = HEAP32[$this>>2]|0;
   $76 = (($75) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0);
   if ($78) {
    $$0$i$i = 521512;
   } else {
    $79 = (($77) + -1)|0;
    $80 = (($75) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($81) + ($79<<3)|0);
    $83 = HEAP32[$82>>2]|0;
    $$0$i$i = $83;
   }
   $84 = Math_fround(HEAPF32[$propVal>>2]);
   HEAPF32[$2>>2] = $84;
   $85 = Math_fround(HEAPF32[$20>>2]);
   HEAPF32[$19>>2] = $85;
   $86 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$21>>2] = $86;
   (__ZN5physxlsERNS_14PxOutputStreamERKNS_6PxVec3E($74,$2)|0);
   HEAP8[$vararg_buffer>>0] = 0;
   $87 = HEAP32[$74>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   (FUNCTION_TABLE_iiii[$88 & 2047]($74,$vararg_buffer,1)|0);
   $89 = HEAP32[$73>>2]|0;
   $90 = (($89) + 8|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($74) + 20|0);
   $93 = HEAP32[$92>>2]|0;
   FUNCTION_TABLE_viii[$91 & 4095]($73,$$0$i$i,$93);
   $94 = (($74) + 16|0);
   HEAP32[$94>>2] = 0;
   $95 = (($74) + 12|0);
   HEAP32[$95>>2] = 0;
   $96 = HEAP32[$this>>2]|0;
   $97 = (($96) + 8|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==(0);
   if (!($99)) {
    $100 = (($98) + -1)|0;
    $101 = (($96) + 4|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ((($102) + ($100<<3)|0) + 4|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = ($104<<24>>24)==(0);
    if ($105) {
     $111 = $96;$113 = $98;
    } else {
     $106 = HEAP32[$17>>2]|0;
     $107 = HEAP32[$106>>2]|0;
     $108 = (($107) + 20|0);
     $109 = HEAP32[$108>>2]|0;
     FUNCTION_TABLE_vi[$109 & 4095]($106);
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $111 = $$pre$i;$113 = $$pre1$i;
    }
    $110 = (($111) + 8|0);
    $112 = (($113) + -1)|0;
    HEAP32[$110>>2] = $112;
   }
   $114 = (($i$04) + 1)|0;
   $exitcond = ($114|0)==($10|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $114;
   }
  }
 }
 $115 = HEAP32[$14>>2]|0;
 $116 = $115 & 2147483647;
 $117 = ($116|0)!=(0);
 $118 = ($115|0)>(-1);
 $or$cond$i$i$i = $117 & $118;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $119 = HEAP32[$12>>2]|0;
 $120 = ($theData|0)==($119|0);
 if ($120) {
  HEAP8[$11>>0] = 0;
  STACKTOP = sp;return;
 }
 $121 = ($119|0)==(0|0);
 if ($121) {
  STACKTOP = sp;return;
 }
 $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($123) + 12|0);
 $125 = HEAP32[$124>>2]|0;
 FUNCTION_TABLE_vii[$125 & 4095]($122,$119);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_15InlineAllocatorILj60ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_15InlineAllocatorILj60ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + (($size*12)|0)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + (($7*12)|0)|0);
 $11 = (($a) + 4|0);
 $12 = (($a) + 8|0);
 $$01$i = $10;
 while(1) {
  $13 = ($$01$i|0)==(0|0);
  if (!($13)) {
   $14 = Math_fround(HEAPF32[$a>>2]);
   HEAPF32[$$01$i>>2] = $14;
   $15 = (($$01$i) + 4|0);
   $16 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$15>>2] = $16;
   $17 = (($$01$i) + 8|0);
   $18 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$17>>2] = $18;
  }
  $19 = (($$01$i) + 12|0);
  $20 = ($19>>>0)<($8>>>0);
  if ($20) {
   $$01$i = $19;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_15InlineAllocatorILj60ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = ($capacity*12)|0;
  $2 = (($this) + 60|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(61);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 521944 : 521616;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,521536,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + (($18*12)|0)|0);
 $21 = (($this) + 64|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
   }
   $32 = (($$012$i) + 12|0);
   $33 = (($$03$i) + 12|0);
   $34 = ($32>>>0)<($19>>>0);
   if ($34) {
    $$012$i = $32;$$03$i = $33;
   } else {
    break;
   }
  }
 }
 $35 = (($this) + 72|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)>(-1);
 if (!($37)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$35>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$21>>2]|0;
 $39 = ($this|0)==($38|0);
 if ($39) {
  $40 = (($this) + 60|0);
  HEAP8[$40>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$35>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $41 = ($38|0)==(0|0);
 if ($41) {
  HEAP32[$21>>2] = $20;
  HEAP32[$35>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $42 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($42,$38);
 HEAP32[$21>>2] = $20;
 HEAP32[$35>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj614ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $propVal = 0, $theData = 0, $vararg_buffer = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $vararg_buffer = sp;
 $2 = sp + 108|0;
 $theData = sp + 8|0;
 $3 = sp + 84|0;
 $buffer = sp + 120|0;
 $propVal = sp + 96|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($inProp) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($5)|0);
 $11 = (($theData) + 60|0);
 $12 = (($theData) + 64|0);
 $13 = (($theData) + 68|0);
 HEAP32[$13>>2] = 0;
 $14 = (($theData) + 72|0);
 HEAP8[$11>>0] = 1;
 HEAP32[$12>>2] = $theData;
 HEAP32[$14>>2] = 5;
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_15InlineAllocatorILj60ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($theData,$10,$3);
 $15 = ($10|0)==(0);
 if (!($15)) {
  $16 = (($vararg_buffer) + 4|0);
  $17 = (($this) + 4|0);
  $18 = (($this) + 12|0);
  $19 = (($2) + 4|0);
  $20 = (($propVal) + 4|0);
  $21 = (($2) + 8|0);
  $22 = (($propVal) + 8|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer)|0);
   $23 = HEAP32[$this>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if ($26) {
    $47 = $23;$52 = 0;
   } else {
    $27 = (($25) + -1)|0;
    $28 = (($23) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($29) + ($27<<3)|0) + 4|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     $33 = HEAP32[$17>>2]|0;
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 16|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($29) + ($27<<3)|0);
     $38 = HEAP32[$37>>2]|0;
     FUNCTION_TABLE_vii[$36 & 4095]($33,$38);
     $39 = HEAP32[$this>>2]|0;
     $40 = (($39) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + -1)|0;
     $43 = (($39) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ((($44) + ($42<<3)|0) + 4|0);
     HEAP8[$45>>0] = 1;
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $47 = $$pre$i1;$52 = $$pre1$i3;
    } else {
     $47 = $23;$52 = $25;
    }
   }
   HEAP32[$vararg_buffer>>2] = $buffer;
   HEAP8[$16>>0] = 0;
   $46 = (($47) + 12|0);
   $48 = HEAP32[$46>>2]|0;
   $49 = $48 & 2147483647;
   $50 = (($47) + 8|0);
   $51 = ($49>>>0)>($52>>>0);
   if ($51) {
    $53 = (($47) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + ($52<<3)|0);
    $56 = ($55|0)==(0|0);
    if ($56) {
     $68 = $52;
    } else {
     $57 = $vararg_buffer;
     $58 = $57;
     $59 = HEAP32[$58>>2]|0;
     $60 = (($57) + 4)|0;
     $61 = $60;
     $62 = HEAP32[$61>>2]|0;
     $63 = $55;
     $64 = $63;
     HEAP32[$64>>2] = $59;
     $65 = (($63) + 4)|0;
     $66 = $65;
     HEAP32[$66>>2] = $62;
     $$pre$i$i = HEAP32[$50>>2]|0;
     $68 = $$pre$i$i;
    }
    $67 = (($68) + 1)|0;
    HEAP32[$50>>2] = $67;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($47,$vararg_buffer)|0);
   }
   $69 = HEAP32[$4>>2]|0;
   $70 = HEAP32[$6>>2]|0;
   $71 = (($70) + 12|0);
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_viii[$72 & 4095]($propVal,$69,$i$04);
   $73 = HEAP32[$17>>2]|0;
   $74 = HEAP32[$18>>2]|0;
   $75 = HEAP32[$this>>2]|0;
   $76 = (($75) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0);
   if ($78) {
    $$0$i$i = 521512;
   } else {
    $79 = (($77) + -1)|0;
    $80 = (($75) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($81) + ($79<<3)|0);
    $83 = HEAP32[$82>>2]|0;
    $$0$i$i = $83;
   }
   $84 = Math_fround(HEAPF32[$propVal>>2]);
   HEAPF32[$2>>2] = $84;
   $85 = Math_fround(HEAPF32[$20>>2]);
   HEAPF32[$19>>2] = $85;
   $86 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$21>>2] = $86;
   (__ZN5physxlsERNS_14PxOutputStreamERKNS_6PxVec3E($74,$2)|0);
   HEAP8[$vararg_buffer>>0] = 0;
   $87 = HEAP32[$74>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   (FUNCTION_TABLE_iiii[$88 & 2047]($74,$vararg_buffer,1)|0);
   $89 = HEAP32[$73>>2]|0;
   $90 = (($89) + 8|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($74) + 20|0);
   $93 = HEAP32[$92>>2]|0;
   FUNCTION_TABLE_viii[$91 & 4095]($73,$$0$i$i,$93);
   $94 = (($74) + 16|0);
   HEAP32[$94>>2] = 0;
   $95 = (($74) + 12|0);
   HEAP32[$95>>2] = 0;
   $96 = HEAP32[$this>>2]|0;
   $97 = (($96) + 8|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==(0);
   if (!($99)) {
    $100 = (($98) + -1)|0;
    $101 = (($96) + 4|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ((($102) + ($100<<3)|0) + 4|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = ($104<<24>>24)==(0);
    if ($105) {
     $111 = $96;$113 = $98;
    } else {
     $106 = HEAP32[$17>>2]|0;
     $107 = HEAP32[$106>>2]|0;
     $108 = (($107) + 20|0);
     $109 = HEAP32[$108>>2]|0;
     FUNCTION_TABLE_vi[$109 & 4095]($106);
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $111 = $$pre$i;$113 = $$pre1$i;
    }
    $110 = (($111) + 8|0);
    $112 = (($113) + -1)|0;
    HEAP32[$110>>2] = $112;
   }
   $114 = (($i$04) + 1)|0;
   $exitcond = ($114|0)==($10|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $114;
   }
  }
 }
 $115 = HEAP32[$14>>2]|0;
 $116 = $115 & 2147483647;
 $117 = ($116|0)!=(0);
 $118 = ($115|0)>(-1);
 $or$cond$i$i$i = $117 & $118;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $119 = HEAP32[$12>>2]|0;
 $120 = ($theData|0)==($119|0);
 if ($120) {
  HEAP8[$11>>0] = 0;
  STACKTOP = sp;return;
 }
 $121 = ($119|0)==(0|0);
 if ($121) {
  STACKTOP = sp;return;
 }
 $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($123) + 12|0);
 $125 = HEAP32[$124>>2]|0;
 FUNCTION_TABLE_vii[$125 & 4095]($122,$119);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj613ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $propVal = 0, $theData = 0, $vararg_buffer = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $vararg_buffer = sp;
 $2 = sp + 108|0;
 $theData = sp + 8|0;
 $3 = sp + 84|0;
 $buffer = sp + 120|0;
 $propVal = sp + 96|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($inProp) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($5)|0);
 $11 = (($theData) + 60|0);
 $12 = (($theData) + 64|0);
 $13 = (($theData) + 68|0);
 HEAP32[$13>>2] = 0;
 $14 = (($theData) + 72|0);
 HEAP8[$11>>0] = 1;
 HEAP32[$12>>2] = $theData;
 HEAP32[$14>>2] = 5;
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_15InlineAllocatorILj60ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($theData,$10,$3);
 $15 = ($10|0)==(0);
 if (!($15)) {
  $16 = (($vararg_buffer) + 4|0);
  $17 = (($this) + 4|0);
  $18 = (($this) + 12|0);
  $19 = (($2) + 4|0);
  $20 = (($propVal) + 4|0);
  $21 = (($2) + 8|0);
  $22 = (($propVal) + 8|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer)|0);
   $23 = HEAP32[$this>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if ($26) {
    $47 = $23;$52 = 0;
   } else {
    $27 = (($25) + -1)|0;
    $28 = (($23) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($29) + ($27<<3)|0) + 4|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     $33 = HEAP32[$17>>2]|0;
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 16|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($29) + ($27<<3)|0);
     $38 = HEAP32[$37>>2]|0;
     FUNCTION_TABLE_vii[$36 & 4095]($33,$38);
     $39 = HEAP32[$this>>2]|0;
     $40 = (($39) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + -1)|0;
     $43 = (($39) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ((($44) + ($42<<3)|0) + 4|0);
     HEAP8[$45>>0] = 1;
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $47 = $$pre$i1;$52 = $$pre1$i3;
    } else {
     $47 = $23;$52 = $25;
    }
   }
   HEAP32[$vararg_buffer>>2] = $buffer;
   HEAP8[$16>>0] = 0;
   $46 = (($47) + 12|0);
   $48 = HEAP32[$46>>2]|0;
   $49 = $48 & 2147483647;
   $50 = (($47) + 8|0);
   $51 = ($49>>>0)>($52>>>0);
   if ($51) {
    $53 = (($47) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + ($52<<3)|0);
    $56 = ($55|0)==(0|0);
    if ($56) {
     $68 = $52;
    } else {
     $57 = $vararg_buffer;
     $58 = $57;
     $59 = HEAP32[$58>>2]|0;
     $60 = (($57) + 4)|0;
     $61 = $60;
     $62 = HEAP32[$61>>2]|0;
     $63 = $55;
     $64 = $63;
     HEAP32[$64>>2] = $59;
     $65 = (($63) + 4)|0;
     $66 = $65;
     HEAP32[$66>>2] = $62;
     $$pre$i$i = HEAP32[$50>>2]|0;
     $68 = $$pre$i$i;
    }
    $67 = (($68) + 1)|0;
    HEAP32[$50>>2] = $67;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($47,$vararg_buffer)|0);
   }
   $69 = HEAP32[$4>>2]|0;
   $70 = HEAP32[$6>>2]|0;
   $71 = (($70) + 12|0);
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_viii[$72 & 4095]($propVal,$69,$i$04);
   $73 = HEAP32[$17>>2]|0;
   $74 = HEAP32[$18>>2]|0;
   $75 = HEAP32[$this>>2]|0;
   $76 = (($75) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0);
   if ($78) {
    $$0$i$i = 521512;
   } else {
    $79 = (($77) + -1)|0;
    $80 = (($75) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($81) + ($79<<3)|0);
    $83 = HEAP32[$82>>2]|0;
    $$0$i$i = $83;
   }
   $84 = Math_fround(HEAPF32[$propVal>>2]);
   HEAPF32[$2>>2] = $84;
   $85 = Math_fround(HEAPF32[$20>>2]);
   HEAPF32[$19>>2] = $85;
   $86 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$21>>2] = $86;
   (__ZN5physxlsERNS_14PxOutputStreamERKNS_6PxVec3E($74,$2)|0);
   HEAP8[$vararg_buffer>>0] = 0;
   $87 = HEAP32[$74>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   (FUNCTION_TABLE_iiii[$88 & 2047]($74,$vararg_buffer,1)|0);
   $89 = HEAP32[$73>>2]|0;
   $90 = (($89) + 8|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($74) + 20|0);
   $93 = HEAP32[$92>>2]|0;
   FUNCTION_TABLE_viii[$91 & 4095]($73,$$0$i$i,$93);
   $94 = (($74) + 16|0);
   HEAP32[$94>>2] = 0;
   $95 = (($74) + 12|0);
   HEAP32[$95>>2] = 0;
   $96 = HEAP32[$this>>2]|0;
   $97 = (($96) + 8|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==(0);
   if (!($99)) {
    $100 = (($98) + -1)|0;
    $101 = (($96) + 4|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ((($102) + ($100<<3)|0) + 4|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = ($104<<24>>24)==(0);
    if ($105) {
     $111 = $96;$113 = $98;
    } else {
     $106 = HEAP32[$17>>2]|0;
     $107 = HEAP32[$106>>2]|0;
     $108 = (($107) + 20|0);
     $109 = HEAP32[$108>>2]|0;
     FUNCTION_TABLE_vi[$109 & 4095]($106);
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $111 = $$pre$i;$113 = $$pre1$i;
    }
    $110 = (($111) + 8|0);
    $112 = (($113) + -1)|0;
    HEAP32[$110>>2] = $112;
   }
   $114 = (($i$04) + 1)|0;
   $exitcond = ($114|0)==($10|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $114;
   }
  }
 }
 $115 = HEAP32[$14>>2]|0;
 $116 = $115 & 2147483647;
 $117 = ($116|0)!=(0);
 $118 = ($115|0)>(-1);
 $or$cond$i$i$i = $117 & $118;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $119 = HEAP32[$12>>2]|0;
 $120 = ($theData|0)==($119|0);
 if ($120) {
  HEAP8[$11>>0] = 0;
  STACKTOP = sp;return;
 }
 $121 = ($119|0)==(0|0);
 if ($121) {
  STACKTOP = sp;return;
 }
 $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($123) + 12|0);
 $125 = HEAP32[$124>>2]|0;
 FUNCTION_TABLE_vii[$125 & 4095]($122,$119);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj612ES2_KjNS_6PxVec3EEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $propVal = 0, $theData = 0, $vararg_buffer = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $vararg_buffer = sp;
 $2 = sp + 108|0;
 $theData = sp + 8|0;
 $3 = sp + 84|0;
 $buffer = sp + 120|0;
 $propVal = sp + 96|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($inProp) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($5)|0);
 $11 = (($theData) + 60|0);
 $12 = (($theData) + 64|0);
 $13 = (($theData) + 68|0);
 HEAP32[$13>>2] = 0;
 $14 = (($theData) + 72|0);
 HEAP8[$11>>0] = 1;
 HEAP32[$12>>2] = $theData;
 HEAP32[$14>>2] = 5;
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_15InlineAllocatorILj60ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($theData,$10,$3);
 $15 = ($10|0)==(0);
 if (!($15)) {
  $16 = (($vararg_buffer) + 4|0);
  $17 = (($this) + 4|0);
  $18 = (($this) + 12|0);
  $19 = (($2) + 4|0);
  $20 = (($propVal) + 4|0);
  $21 = (($2) + 8|0);
  $22 = (($propVal) + 8|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer)|0);
   $23 = HEAP32[$this>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if ($26) {
    $47 = $23;$52 = 0;
   } else {
    $27 = (($25) + -1)|0;
    $28 = (($23) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($29) + ($27<<3)|0) + 4|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     $33 = HEAP32[$17>>2]|0;
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 16|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($29) + ($27<<3)|0);
     $38 = HEAP32[$37>>2]|0;
     FUNCTION_TABLE_vii[$36 & 4095]($33,$38);
     $39 = HEAP32[$this>>2]|0;
     $40 = (($39) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + -1)|0;
     $43 = (($39) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ((($44) + ($42<<3)|0) + 4|0);
     HEAP8[$45>>0] = 1;
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $47 = $$pre$i1;$52 = $$pre1$i3;
    } else {
     $47 = $23;$52 = $25;
    }
   }
   HEAP32[$vararg_buffer>>2] = $buffer;
   HEAP8[$16>>0] = 0;
   $46 = (($47) + 12|0);
   $48 = HEAP32[$46>>2]|0;
   $49 = $48 & 2147483647;
   $50 = (($47) + 8|0);
   $51 = ($49>>>0)>($52>>>0);
   if ($51) {
    $53 = (($47) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + ($52<<3)|0);
    $56 = ($55|0)==(0|0);
    if ($56) {
     $68 = $52;
    } else {
     $57 = $vararg_buffer;
     $58 = $57;
     $59 = HEAP32[$58>>2]|0;
     $60 = (($57) + 4)|0;
     $61 = $60;
     $62 = HEAP32[$61>>2]|0;
     $63 = $55;
     $64 = $63;
     HEAP32[$64>>2] = $59;
     $65 = (($63) + 4)|0;
     $66 = $65;
     HEAP32[$66>>2] = $62;
     $$pre$i$i = HEAP32[$50>>2]|0;
     $68 = $$pre$i$i;
    }
    $67 = (($68) + 1)|0;
    HEAP32[$50>>2] = $67;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($47,$vararg_buffer)|0);
   }
   $69 = HEAP32[$4>>2]|0;
   $70 = HEAP32[$6>>2]|0;
   $71 = (($70) + 12|0);
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_viii[$72 & 4095]($propVal,$69,$i$04);
   $73 = HEAP32[$17>>2]|0;
   $74 = HEAP32[$18>>2]|0;
   $75 = HEAP32[$this>>2]|0;
   $76 = (($75) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0);
   if ($78) {
    $$0$i$i = 521512;
   } else {
    $79 = (($77) + -1)|0;
    $80 = (($75) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($81) + ($79<<3)|0);
    $83 = HEAP32[$82>>2]|0;
    $$0$i$i = $83;
   }
   $84 = Math_fround(HEAPF32[$propVal>>2]);
   HEAPF32[$2>>2] = $84;
   $85 = Math_fround(HEAPF32[$20>>2]);
   HEAPF32[$19>>2] = $85;
   $86 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$21>>2] = $86;
   (__ZN5physxlsERNS_14PxOutputStreamERKNS_6PxVec3E($74,$2)|0);
   HEAP8[$vararg_buffer>>0] = 0;
   $87 = HEAP32[$74>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   (FUNCTION_TABLE_iiii[$88 & 2047]($74,$vararg_buffer,1)|0);
   $89 = HEAP32[$73>>2]|0;
   $90 = (($89) + 8|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($74) + 20|0);
   $93 = HEAP32[$92>>2]|0;
   FUNCTION_TABLE_viii[$91 & 4095]($73,$$0$i$i,$93);
   $94 = (($74) + 16|0);
   HEAP32[$94>>2] = 0;
   $95 = (($74) + 12|0);
   HEAP32[$95>>2] = 0;
   $96 = HEAP32[$this>>2]|0;
   $97 = (($96) + 8|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==(0);
   if (!($99)) {
    $100 = (($98) + -1)|0;
    $101 = (($96) + 4|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ((($102) + ($100<<3)|0) + 4|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = ($104<<24>>24)==(0);
    if ($105) {
     $111 = $96;$113 = $98;
    } else {
     $106 = HEAP32[$17>>2]|0;
     $107 = HEAP32[$106>>2]|0;
     $108 = (($107) + 20|0);
     $109 = HEAP32[$108>>2]|0;
     FUNCTION_TABLE_vi[$109 & 4095]($106);
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $111 = $$pre$i;$113 = $$pre1$i;
    }
    $110 = (($111) + 8|0);
    $112 = (($113) + -1)|0;
    HEAP32[$110>>2] = $112;
   }
   $114 = (($i$04) + 1)|0;
   $exitcond = ($114|0)==($10|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $114;
   }
  }
 }
 $115 = HEAP32[$14>>2]|0;
 $116 = $115 & 2147483647;
 $117 = ($116|0)!=(0);
 $118 = ($115|0)>(-1);
 $or$cond$i$i$i = $117 & $118;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $119 = HEAP32[$12>>2]|0;
 $120 = ($theData|0)==($119|0);
 if ($120) {
  HEAP8[$11>>0] = 0;
  STACKTOP = sp;return;
 }
 $121 = ($119|0)==(0|0);
 if ($121) {
  STACKTOP = sp;return;
 }
 $122 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($123) + 12|0);
 $125 = HEAP32[$124>>2]|0;
 FUNCTION_TABLE_vii[$125 & 4095]($122,$119);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj611ES2_KjNS_17PxVehicleTireDataEEEKNS_30PxVehicleTireDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $propVal = 0, $theData = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 816|0;
 $vararg_buffer = sp;
 $2 = sp + 752|0;
 $theData = sp + 144|0;
 $3 = sp + 480|0;
 $buffer = sp + 784|0;
 $propVal = sp + 688|0;
 $4 = sp + 544|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($inProp) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($6)|0);
 $12 = (($theData) + 320|0);
 $13 = (($theData) + 324|0);
 $14 = (($theData) + 328|0);
 HEAP32[$14>>2] = 0;
 $15 = (($theData) + 332|0);
 HEAP8[$12>>0] = 1;
 HEAP32[$13>>2] = $theData;
 HEAP32[$15>>2] = 5;
 HEAPF32[$3>>2] = Math_fround(2.0);
 $16 = (($3) + 4|0);
 HEAPF32[$16>>2] = Math_fround(17.90493011474609375);
 $17 = (($3) + 8|0);
 HEAPF32[$17>>2] = Math_fround(1000.0);
 $18 = (($3) + 12|0);
 HEAPF32[$18>>2] = Math_fround(5.72957754135131835938);
 $19 = (($3) + 40|0);
 HEAP32[$19>>2] = 0;
 $20 = (($3) + 16|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($3) + 20|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($3) + 24|0);
 HEAPF32[$22>>2] = Math_fround(0.100000001490116119385);
 $23 = (($3) + 28|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($3) + 32|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($3) + 36|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($3) + 44|0);
 HEAPF32[$26>>2] = Math_fround(0.00100000004749745130539);
 $27 = (($3) + 48|0);
 HEAPF32[$27>>2] = Math_fround(10.0);
 $28 = (($3) + 52|0);
 HEAPF32[$28>>2] = Math_fround(1.11111116409301757813);
 __ZN5physx6shdfnd5ArrayINS_17PxVehicleTireDataENS0_15InlineAllocatorILj320ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($theData,$11,$3);
 $29 = ($11|0)==(0);
 if (!($29)) {
  $30 = (($vararg_buffer) + 4|0);
  $31 = (($this) + 4|0);
  $32 = (($this) + 12|0);
  $33 = (($this) + 16|0);
  $34 = (($2) + 4|0);
  $35 = (($2) + 8|0);
  $36 = (($2) + 12|0);
  $37 = (($2) + 16|0);
  $38 = (($2) + 20|0);
  $39 = (($2) + 24|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer)|0);
   $40 = HEAP32[$this>>2]|0;
   $41 = (($40) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0);
   if ($43) {
    $64 = $40;$69 = 0;
   } else {
    $44 = (($42) + -1)|0;
    $45 = (($40) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ((($46) + ($44<<3)|0) + 4|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = ($48<<24>>24)==(0);
    if ($49) {
     $50 = HEAP32[$31>>2]|0;
     $51 = HEAP32[$50>>2]|0;
     $52 = (($51) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = (($46) + ($44<<3)|0);
     $55 = HEAP32[$54>>2]|0;
     FUNCTION_TABLE_vii[$53 & 4095]($50,$55);
     $56 = HEAP32[$this>>2]|0;
     $57 = (($56) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($58) + -1)|0;
     $60 = (($56) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ((($61) + ($59<<3)|0) + 4|0);
     HEAP8[$62>>0] = 1;
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $64 = $$pre$i1;$69 = $$pre1$i3;
    } else {
     $64 = $40;$69 = $42;
    }
   }
   HEAP32[$vararg_buffer>>2] = $buffer;
   HEAP8[$30>>0] = 0;
   $63 = (($64) + 12|0);
   $65 = HEAP32[$63>>2]|0;
   $66 = $65 & 2147483647;
   $67 = (($64) + 8|0);
   $68 = ($66>>>0)>($69>>>0);
   if ($68) {
    $70 = (($64) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($71) + ($69<<3)|0);
    $73 = ($72|0)==(0|0);
    if ($73) {
     $85 = $69;
    } else {
     $74 = $vararg_buffer;
     $75 = $74;
     $76 = HEAP32[$75>>2]|0;
     $77 = (($74) + 4)|0;
     $78 = $77;
     $79 = HEAP32[$78>>2]|0;
     $80 = $72;
     $81 = $80;
     HEAP32[$81>>2] = $76;
     $82 = (($80) + 4)|0;
     $83 = $82;
     HEAP32[$83>>2] = $79;
     $$pre$i$i = HEAP32[$67>>2]|0;
     $85 = $$pre$i$i;
    }
    $84 = (($85) + 1)|0;
    HEAP32[$67>>2] = $84;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($64,$vararg_buffer)|0);
   }
   $86 = HEAP32[$5>>2]|0;
   $87 = HEAP32[$7>>2]|0;
   $88 = (($87) + 12|0);
   $89 = HEAP32[$88>>2]|0;
   FUNCTION_TABLE_viii[$89 & 4095]($propVal,$86,$i$04);
   _memset(($4|0),0,140)|0;
   __ZN5physx30PxVehicleTireDataGeneratedInfoC2Ev($4);
   $90 = HEAP32[$this>>2]|0;
   $91 = HEAP32[$31>>2]|0;
   $92 = HEAP32[$32>>2]|0;
   $93 = HEAP32[$33>>2]|0;
   __ZN5physx30PxVehicleTireDataGeneratedInfoC2Ev($vararg_buffer);
   HEAP32[$2>>2] = $90;
   HEAP32[$34>>2] = $91;
   HEAP32[$35>>2] = $propVal;
   HEAP32[$36>>2] = $92;
   HEAP32[$37>>2] = $93;
   HEAP32[$38>>2] = 0;
   HEAP32[$39>>2] = 0;
   (__ZNK5physx30PxVehicleTireDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEEEEEjT_j($vararg_buffer,$2,0)|0);
   $94 = HEAP32[$this>>2]|0;
   $95 = (($94) + 8|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0);
   if (!($97)) {
    $98 = (($96) + -1)|0;
    $99 = (($94) + 4|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = ((($100) + ($98<<3)|0) + 4|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $109 = $94;$111 = $96;
    } else {
     $104 = HEAP32[$31>>2]|0;
     $105 = HEAP32[$104>>2]|0;
     $106 = (($105) + 20|0);
     $107 = HEAP32[$106>>2]|0;
     FUNCTION_TABLE_vi[$107 & 4095]($104);
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $109 = $$pre$i;$111 = $$pre1$i;
    }
    $108 = (($109) + 8|0);
    $110 = (($111) + -1)|0;
    HEAP32[$108>>2] = $110;
   }
   $112 = (($i$04) + 1)|0;
   $exitcond = ($112|0)==($11|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $112;
   }
  }
 }
 $113 = HEAP32[$15>>2]|0;
 $114 = $113 & 2147483647;
 $115 = ($114|0)!=(0);
 $116 = ($113|0)>(-1);
 $or$cond$i$i$i = $115 & $116;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $117 = HEAP32[$13>>2]|0;
 $118 = ($theData|0)==($117|0);
 if ($118) {
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 }
 $119 = ($117|0)==(0|0);
 if ($119) {
  STACKTOP = sp;return;
 }
 $120 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = (($121) + 12|0);
 $123 = HEAP32[$122>>2]|0;
 FUNCTION_TABLE_vii[$123 & 4095]($120,$117);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_17PxVehicleTireDataENS0_15InlineAllocatorILj320ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 332|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_17PxVehicleTireDataENS0_15InlineAllocatorILj320ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 324|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 328|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($size<<6)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + ($7<<6)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   dest=$$01$i+0|0; src=$a+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $12 = (($$01$i) + 64|0);
  $13 = ($12>>>0)<($8>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx30PxVehicleTireDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i12 = 0, $$phi$trans$insert$i$i16 = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i20 = 0, $$phi$trans$insert$i27 = 0, $$phi$trans$insert$i34 = 0, $$phi$trans$insert$i41 = 0, $$phi$trans$insert48 = 0, $$phi$trans$insert51 = 0, $$phi$trans$insert54 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i15 = 0;
 var $$pre$i$i23 = 0, $$pre$i$i3 = 0, $$pre$i$i30 = 0, $$pre$i$i37 = 0, $$pre$i$i44 = 0, $$pre$i$i7 = 0, $$pre$i19 = 0, $$pre$i26 = 0, $$pre$i33 = 0, $$pre$i40 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i13 = 0, $$pre1$i$i17 = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i21 = 0, $$pre1$i28 = 0, $$pre1$i35 = 0, $$pre1$i42 = 0;
 var $$pre46 = 0, $$pre47 = 0, $$pre49 = 0, $$pre50 = 0, $$pre52 = 0, $$pre53 = 0, $$pre55 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $theAccessor$i14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i14 = sp + 8|0;
 $1 = (($this) + 36|0);
 HEAP8[$theAccessor$i14>>0] = 0;
 $2 = (($theAccessor$i14) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i14) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i19 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i20 = (($$pre$i19) + 8|0);
   $$pre1$i21 = HEAP32[$$phi$trans$insert$i20>>2]|0;
   $31 = $$pre$i19;$36 = $$pre1$i21;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i23 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i23;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj596ENS_22PxRepXPropertyAccessorILj596ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i14);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre46 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre46;$80 = $$pre;
 }
 $72 = (($this) + 52|0);
 HEAP8[$theAccessor$i14>>0] = 0;
 $73 = (($theAccessor$i14) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i14) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i26 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i27 = (($$pre$i26) + 8|0);
   $$pre1$i28 = HEAP32[$$phi$trans$insert$i27>>2]|0;
   $101 = $$pre$i26;$106 = $$pre1$i28;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i30 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i30;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj597ENS_22PxRepXPropertyAccessorILj597ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i14);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $147 = 0;$150 = $123;
 } else {
  $127 = (($125) + -1)|0;
  $128 = (($123) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129) + ($127<<3)|0) + 4|0);
  $131 = HEAP8[$130>>0]|0;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $139 = $123;$141 = $125;
  } else {
   $133 = (($inOperator) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = HEAP32[$134>>2]|0;
   $136 = (($135) + 20|0);
   $137 = HEAP32[$136>>2]|0;
   FUNCTION_TABLE_vi[$137 & 4095]($134);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $139 = $$pre$i$i7;$141 = $$pre1$i$i9;
  }
  $138 = (($139) + 8|0);
  $140 = (($141) + -1)|0;
  HEAP32[$138>>2] = $140;
  $$pre47 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert48 = (($$pre47) + 8|0);
  $$pre49 = HEAP32[$$phi$trans$insert48>>2]|0;
  $147 = $$pre49;$150 = $$pre47;
 }
 $142 = (($this) + 68|0);
 HEAP8[$theAccessor$i14>>0] = 0;
 $143 = (($theAccessor$i14) + 4|0);
 HEAP32[$143>>2] = 0;
 $144 = (($theAccessor$i14) + 8|0);
 ;HEAP32[$144+0>>2]=HEAP32[$142+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$142+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$142+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$142+12>>2]|0;
 $145 = HEAP32[$142>>2]|0;
 $146 = ($147|0)==(0);
 if ($146) {
  $171 = $150;$176 = 0;
 } else {
  $148 = (($147) + -1)|0;
  $149 = (($150) + 4|0);
  $151 = HEAP32[$149>>2]|0;
  $152 = ((($151) + ($148<<3)|0) + 4|0);
  $153 = HEAP8[$152>>0]|0;
  $154 = ($153<<24>>24)==(0);
  if ($154) {
   $155 = (($inOperator) + 4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = HEAP32[$156>>2]|0;
   $158 = (($157) + 16|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($151) + ($148<<3)|0);
   $161 = HEAP32[$160>>2]|0;
   FUNCTION_TABLE_vii[$159 & 4095]($156,$161);
   $162 = HEAP32[$inOperator>>2]|0;
   $163 = (($162) + 8|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($164) + -1)|0;
   $166 = (($162) + 4|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ((($167) + ($165<<3)|0) + 4|0);
   HEAP8[$168>>0] = 1;
   $$pre$i33 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i34 = (($$pre$i33) + 8|0);
   $$pre1$i35 = HEAP32[$$phi$trans$insert$i34>>2]|0;
   $171 = $$pre$i33;$176 = $$pre1$i35;
  } else {
   $171 = $150;$176 = $147;
  }
 }
 HEAP32[$0>>2] = $145;
 $169 = (($0) + 4|0);
 HEAP8[$169>>0] = 0;
 $170 = (($171) + 12|0);
 $172 = HEAP32[$170>>2]|0;
 $173 = $172 & 2147483647;
 $174 = (($171) + 8|0);
 $175 = ($173>>>0)>($176>>>0);
 if ($175) {
  $177 = (($171) + 4|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + ($176<<3)|0);
  $180 = ($179|0)==(0|0);
  if ($180) {
   $192 = $176;
  } else {
   $181 = $0;
   $182 = $181;
   $183 = HEAP32[$182>>2]|0;
   $184 = (($181) + 4)|0;
   $185 = $184;
   $186 = HEAP32[$185>>2]|0;
   $187 = $179;
   $188 = $187;
   HEAP32[$188>>2] = $183;
   $189 = (($187) + 4)|0;
   $190 = $189;
   HEAP32[$190>>2] = $186;
   $$pre$i$i37 = HEAP32[$174>>2]|0;
   $192 = $$pre$i$i37;
  }
  $191 = (($192) + 1)|0;
  HEAP32[$174>>2] = $191;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($171,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj598ENS_22PxRepXPropertyAccessorILj598ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i14);
 $193 = HEAP32[$inOperator>>2]|0;
 $194 = (($193) + 8|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)==(0);
 if ($196) {
  $217 = 0;$220 = $193;
 } else {
  $197 = (($195) + -1)|0;
  $198 = (($193) + 4|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ((($199) + ($197<<3)|0) + 4|0);
  $201 = HEAP8[$200>>0]|0;
  $202 = ($201<<24>>24)==(0);
  if ($202) {
   $209 = $193;$211 = $195;
  } else {
   $203 = (($inOperator) + 4|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = HEAP32[$204>>2]|0;
   $206 = (($205) + 20|0);
   $207 = HEAP32[$206>>2]|0;
   FUNCTION_TABLE_vi[$207 & 4095]($204);
   $$pre$i$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i12 = (($$pre$i$i11) + 8|0);
   $$pre1$i$i13 = HEAP32[$$phi$trans$insert$i$i12>>2]|0;
   $209 = $$pre$i$i11;$211 = $$pre1$i$i13;
  }
  $208 = (($209) + 8|0);
  $210 = (($211) + -1)|0;
  HEAP32[$208>>2] = $210;
  $$pre50 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert51 = (($$pre50) + 8|0);
  $$pre52 = HEAP32[$$phi$trans$insert51>>2]|0;
  $217 = $$pre52;$220 = $$pre50;
 }
 $212 = (($this) + 84|0);
 HEAP8[$theAccessor$i14>>0] = 0;
 $213 = (($theAccessor$i14) + 4|0);
 HEAP32[$213>>2] = 0;
 $214 = (($theAccessor$i14) + 8|0);
 ;HEAP32[$214+0>>2]=HEAP32[$212+0>>2]|0;HEAP32[$214+4>>2]=HEAP32[$212+4>>2]|0;HEAP32[$214+8>>2]=HEAP32[$212+8>>2]|0;HEAP32[$214+12>>2]=HEAP32[$212+12>>2]|0;
 $215 = HEAP32[$212>>2]|0;
 $216 = ($217|0)==(0);
 if ($216) {
  $241 = $220;$246 = 0;
 } else {
  $218 = (($217) + -1)|0;
  $219 = (($220) + 4|0);
  $221 = HEAP32[$219>>2]|0;
  $222 = ((($221) + ($218<<3)|0) + 4|0);
  $223 = HEAP8[$222>>0]|0;
  $224 = ($223<<24>>24)==(0);
  if ($224) {
   $225 = (($inOperator) + 4|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = HEAP32[$226>>2]|0;
   $228 = (($227) + 16|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = (($221) + ($218<<3)|0);
   $231 = HEAP32[$230>>2]|0;
   FUNCTION_TABLE_vii[$229 & 4095]($226,$231);
   $232 = HEAP32[$inOperator>>2]|0;
   $233 = (($232) + 8|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = (($234) + -1)|0;
   $236 = (($232) + 4|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ((($237) + ($235<<3)|0) + 4|0);
   HEAP8[$238>>0] = 1;
   $$pre$i40 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i41 = (($$pre$i40) + 8|0);
   $$pre1$i42 = HEAP32[$$phi$trans$insert$i41>>2]|0;
   $241 = $$pre$i40;$246 = $$pre1$i42;
  } else {
   $241 = $220;$246 = $217;
  }
 }
 HEAP32[$0>>2] = $215;
 $239 = (($0) + 4|0);
 HEAP8[$239>>0] = 0;
 $240 = (($241) + 12|0);
 $242 = HEAP32[$240>>2]|0;
 $243 = $242 & 2147483647;
 $244 = (($241) + 8|0);
 $245 = ($243>>>0)>($246>>>0);
 if ($245) {
  $247 = (($241) + 4|0);
  $248 = HEAP32[$247>>2]|0;
  $249 = (($248) + ($246<<3)|0);
  $250 = ($249|0)==(0|0);
  if ($250) {
   $262 = $246;
  } else {
   $251 = $0;
   $252 = $251;
   $253 = HEAP32[$252>>2]|0;
   $254 = (($251) + 4)|0;
   $255 = $254;
   $256 = HEAP32[$255>>2]|0;
   $257 = $249;
   $258 = $257;
   HEAP32[$258>>2] = $253;
   $259 = (($257) + 4)|0;
   $260 = $259;
   HEAP32[$260>>2] = $256;
   $$pre$i$i44 = HEAP32[$244>>2]|0;
   $262 = $$pre$i$i44;
  }
  $261 = (($262) + 1)|0;
  HEAP32[$244>>2] = $261;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($241,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj599ENS_22PxRepXPropertyAccessorILj599ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i14);
 $263 = HEAP32[$inOperator>>2]|0;
 $264 = (($263) + 8|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = ($265|0)==(0);
 if ($266) {
  $287 = 0;$290 = $263;
 } else {
  $267 = (($265) + -1)|0;
  $268 = (($263) + 4|0);
  $269 = HEAP32[$268>>2]|0;
  $270 = ((($269) + ($267<<3)|0) + 4|0);
  $271 = HEAP8[$270>>0]|0;
  $272 = ($271<<24>>24)==(0);
  if ($272) {
   $279 = $263;$281 = $265;
  } else {
   $273 = (($inOperator) + 4|0);
   $274 = HEAP32[$273>>2]|0;
   $275 = HEAP32[$274>>2]|0;
   $276 = (($275) + 20|0);
   $277 = HEAP32[$276>>2]|0;
   FUNCTION_TABLE_vi[$277 & 4095]($274);
   $$pre$i$i15 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i16 = (($$pre$i$i15) + 8|0);
   $$pre1$i$i17 = HEAP32[$$phi$trans$insert$i$i16>>2]|0;
   $279 = $$pre$i$i15;$281 = $$pre1$i$i17;
  }
  $278 = (($279) + 8|0);
  $280 = (($281) + -1)|0;
  HEAP32[$278>>2] = $280;
  $$pre53 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert54 = (($$pre53) + 8|0);
  $$pre55 = HEAP32[$$phi$trans$insert54>>2]|0;
  $287 = $$pre55;$290 = $$pre53;
 }
 $282 = (($this) + 100|0);
 HEAP8[$theAccessor$i14>>0] = 0;
 $283 = (($theAccessor$i14) + 4|0);
 HEAP32[$283>>2] = 0;
 $284 = (($theAccessor$i14) + 8|0);
 ;HEAP32[$284+0>>2]=HEAP32[$282+0>>2]|0;HEAP32[$284+4>>2]=HEAP32[$282+4>>2]|0;HEAP32[$284+8>>2]=HEAP32[$282+8>>2]|0;HEAP32[$284+12>>2]=HEAP32[$282+12>>2]|0;
 $285 = HEAP32[$282>>2]|0;
 $286 = ($287|0)==(0);
 if ($286) {
  $311 = $290;$316 = 0;
 } else {
  $288 = (($287) + -1)|0;
  $289 = (($290) + 4|0);
  $291 = HEAP32[$289>>2]|0;
  $292 = ((($291) + ($288<<3)|0) + 4|0);
  $293 = HEAP8[$292>>0]|0;
  $294 = ($293<<24>>24)==(0);
  if ($294) {
   $295 = (($inOperator) + 4|0);
   $296 = HEAP32[$295>>2]|0;
   $297 = HEAP32[$296>>2]|0;
   $298 = (($297) + 16|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = (($291) + ($288<<3)|0);
   $301 = HEAP32[$300>>2]|0;
   FUNCTION_TABLE_vii[$299 & 4095]($296,$301);
   $302 = HEAP32[$inOperator>>2]|0;
   $303 = (($302) + 8|0);
   $304 = HEAP32[$303>>2]|0;
   $305 = (($304) + -1)|0;
   $306 = (($302) + 4|0);
   $307 = HEAP32[$306>>2]|0;
   $308 = ((($307) + ($305<<3)|0) + 4|0);
   HEAP8[$308>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $311 = $$pre$i;$316 = $$pre1$i;
  } else {
   $311 = $290;$316 = $287;
  }
 }
 HEAP32[$0>>2] = $285;
 $309 = (($0) + 4|0);
 HEAP8[$309>>0] = 0;
 $310 = (($311) + 12|0);
 $312 = HEAP32[$310>>2]|0;
 $313 = $312 & 2147483647;
 $314 = (($311) + 8|0);
 $315 = ($313>>>0)>($316>>>0);
 if ($315) {
  $317 = (($311) + 4|0);
  $318 = HEAP32[$317>>2]|0;
  $319 = (($318) + ($316<<3)|0);
  $320 = ($319|0)==(0|0);
  if ($320) {
   $332 = $316;
  } else {
   $321 = $0;
   $322 = $321;
   $323 = HEAP32[$322>>2]|0;
   $324 = (($321) + 4)|0;
   $325 = $324;
   $326 = HEAP32[$325>>2]|0;
   $327 = $319;
   $328 = $327;
   HEAP32[$328>>2] = $323;
   $329 = (($327) + 4)|0;
   $330 = $329;
   HEAP32[$330>>2] = $326;
   $$pre$i$i1 = HEAP32[$314>>2]|0;
   $332 = $$pre$i$i1;
  }
  $331 = (($332) + 1)|0;
  HEAP32[$314>>2] = $331;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($311,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj600ENS_22PxRepXPropertyAccessorILj600ES4_jjEEEEvRKT0_($inOperator,$theAccessor$i14);
 $333 = HEAP32[$inOperator>>2]|0;
 $334 = (($333) + 8|0);
 $335 = HEAP32[$334>>2]|0;
 $336 = ($335|0)==(0);
 if ($336) {
  $352 = (($this) + 116|0);
  $353 = (($this) + 132|0);
  $354 = HEAP32[$353>>2]|0;
  $355 = (($this) + 136|0);
  $356 = HEAP32[$355>>2]|0;
  __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE27extendedDualIndexedPropertyILj601ES4_jjfEEvjRKNS_33PxExtendedDualIndexedPropertyInfoIXT_ET0_T1_T2_T3_EEjj($inOperator,0,$352,$354,$356);
  $357 = (($inStartIndex) + 9)|0;
  STACKTOP = sp;return ($357|0);
 }
 $337 = (($335) + -1)|0;
 $338 = (($333) + 4|0);
 $339 = HEAP32[$338>>2]|0;
 $340 = ((($339) + ($337<<3)|0) + 4|0);
 $341 = HEAP8[$340>>0]|0;
 $342 = ($341<<24>>24)==(0);
 if ($342) {
  $349 = $333;$351 = $335;
 } else {
  $343 = (($inOperator) + 4|0);
  $344 = HEAP32[$343>>2]|0;
  $345 = HEAP32[$344>>2]|0;
  $346 = (($345) + 20|0);
  $347 = HEAP32[$346>>2]|0;
  FUNCTION_TABLE_vi[$347 & 4095]($344);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $349 = $$pre$i$i;$351 = $$pre1$i$i;
 }
 $348 = (($349) + 8|0);
 $350 = (($351) + -1)|0;
 HEAP32[$348>>2] = $350;
 $352 = (($this) + 116|0);
 $353 = (($this) + 132|0);
 $354 = HEAP32[$353>>2]|0;
 $355 = (($this) + 136|0);
 $356 = HEAP32[$355>>2]|0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE27extendedDualIndexedPropertyILj601ES4_jjfEEvjRKNS_33PxExtendedDualIndexedPropertyInfoIXT_ET0_T1_T2_T3_EEjj($inOperator,0,$352,$354,$356);
 $357 = (($inStartIndex) + 9)|0;
 STACKTOP = sp;return ($357|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE27extendedDualIndexedPropertyILj601ES4_jjfEEvjRKNS_33PxExtendedDualIndexedPropertyInfoIXT_ET0_T1_T2_T3_EEjj($this,$0,$inProp,$id0Count,$id1Count) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $id0Count = $id0Count|0;
 $id1Count = $id1Count|0;
 var $$0$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i10 = 0, $$phi$trans$insert$i13 = 0, $$phi$trans$insert$i17 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i7 = 0, $$pre$i$i1 = 0, $$pre$i$i3 = 0, $$pre$i12 = 0, $$pre$i16 = 0, $$pre$i9 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i5 = 0, $$pre1$i11 = 0;
 var $$pre1$i14 = 0, $$pre1$i18 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0.0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $buffer$i$i$i = 0, $buffer1 = 0, $buffer2 = 0, $exitcond = 0, $exitcond25 = 0, $i$021 = 0, $j$020 = 0, $rangeStart = 0, $rangeStart$ = 0, $vararg_buffer4 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $vararg_buffer4 = sp + 8|0;
 $buffer$i$i$i = sp + 88|0;
 $1 = sp;
 $rangeStart = sp + 16|0;
 $buffer1 = sp + 24|0;
 $buffer2 = sp + 56|0;
 $2 = HEAP32[$inProp>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $29 = $3;$34 = 0;
 } else {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9) + ($7<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($this) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($9) + ($7<<3)|0);
   $19 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_vii[$17 & 4095]($14,$19);
   $20 = HEAP32[$this>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + -1)|0;
   $24 = (($20) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($25) + ($23<<3)|0) + 4|0);
   HEAP8[$26>>0] = 1;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $29 = $$pre$i;$34 = $$pre1$i;
  } else {
   $29 = $3;$34 = $5;
  }
 }
 HEAP32[$vararg_buffer4>>2] = $2;
 $27 = (($vararg_buffer4) + 4|0);
 HEAP8[$27>>0] = 0;
 $28 = (($29) + 12|0);
 $30 = HEAP32[$28>>2]|0;
 $31 = $30 & 2147483647;
 $32 = (($29) + 8|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  $35 = (($29) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($34<<3)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   $50 = $34;
  } else {
   $39 = $vararg_buffer4;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 4)|0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = $37;
   $46 = $45;
   HEAP32[$46>>2] = $41;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $44;
   $$pre$i$i = HEAP32[$32>>2]|0;
   $50 = $$pre$i$i;
  }
  $49 = (($50) + 1)|0;
  HEAP32[$32>>2] = $49;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($29,$vararg_buffer4)|0);
 }
 HEAP32[$rangeStart>>2] = 601;
 $51 = (($this) + 20|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 $rangeStart$ = $53 ? $rangeStart : $52;
 $54 = ($id0Count|0)==(0);
 if (!($54)) {
  $55 = (($1) + 4|0);
  $56 = ($id1Count|0)==(0);
  $57 = (($this) + 4|0);
  $58 = (($vararg_buffer4) + 4|0);
  $59 = (($this) + 8|0);
  $60 = (($inProp) + 12|0);
  $61 = (($this) + 12|0);
  $i$021 = 0;
  while(1) {
   dest=$buffer1+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer4>>2] = $i$021;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer1,0,522048,$vararg_buffer4)|0);
   $62 = HEAP32[$this>>2]|0;
   $63 = (($62) + 8|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   if ($65) {
    $86 = $62;$91 = 0;
   } else {
    $66 = (($64) + -1)|0;
    $67 = (($62) + 4|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ((($68) + ($66<<3)|0) + 4|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = ($70<<24>>24)==(0);
    if ($71) {
     $72 = HEAP32[$57>>2]|0;
     $73 = HEAP32[$72>>2]|0;
     $74 = (($73) + 16|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($68) + ($66<<3)|0);
     $77 = HEAP32[$76>>2]|0;
     FUNCTION_TABLE_vii[$75 & 4095]($72,$77);
     $78 = HEAP32[$this>>2]|0;
     $79 = (($78) + 8|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (($80) + -1)|0;
     $82 = (($78) + 4|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ((($83) + ($81<<3)|0) + 4|0);
     HEAP8[$84>>0] = 1;
     $$pre$i$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i$i = (($$pre$i$i1) + 8|0);
     $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
     $86 = $$pre$i$i1;$91 = $$pre1$i$i;
    } else {
     $86 = $62;$91 = $64;
    }
   }
   HEAP32[$1>>2] = $buffer1;
   HEAP8[$55>>0] = 0;
   $85 = (($86) + 12|0);
   $87 = HEAP32[$85>>2]|0;
   $88 = $87 & 2147483647;
   $89 = (($86) + 8|0);
   $90 = ($88>>>0)>($91>>>0);
   if ($90) {
    $92 = (($86) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($93) + ($91<<3)|0);
    $95 = ($94|0)==(0|0);
    if ($95) {
     $107 = $91;
    } else {
     $96 = $1;
     $97 = $96;
     $98 = HEAP32[$97>>2]|0;
     $99 = (($96) + 4)|0;
     $100 = $99;
     $101 = HEAP32[$100>>2]|0;
     $102 = $94;
     $103 = $102;
     HEAP32[$103>>2] = $98;
     $104 = (($102) + 4)|0;
     $105 = $104;
     HEAP32[$105>>2] = $101;
     $$pre$i$i$i = HEAP32[$89>>2]|0;
     $107 = $$pre$i$i$i;
    }
    $106 = (($107) + 1)|0;
    HEAP32[$89>>2] = $106;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($86,$1)|0);
   }
   if (!($56)) {
    $j$020 = 0;
    while(1) {
     dest=$buffer2+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
     HEAP32[$vararg_buffer4>>2] = $j$020;
     (__ZN5physx6string9sprintf_sEPcjPKcz($buffer2,0,522056,$vararg_buffer4)|0);
     $108 = HEAP32[$this>>2]|0;
     $109 = (($108) + 8|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0);
     if ($111) {
      $132 = $108;$137 = 0;
     } else {
      $112 = (($110) + -1)|0;
      $113 = (($108) + 4|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = ((($114) + ($112<<3)|0) + 4|0);
      $116 = HEAP8[$115>>0]|0;
      $117 = ($116<<24>>24)==(0);
      if ($117) {
       $118 = HEAP32[$57>>2]|0;
       $119 = HEAP32[$118>>2]|0;
       $120 = (($119) + 16|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = (($114) + ($112<<3)|0);
       $123 = HEAP32[$122>>2]|0;
       FUNCTION_TABLE_vii[$121 & 4095]($118,$123);
       $124 = HEAP32[$this>>2]|0;
       $125 = (($124) + 8|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = (($126) + -1)|0;
       $128 = (($124) + 4|0);
       $129 = HEAP32[$128>>2]|0;
       $130 = ((($129) + ($127<<3)|0) + 4|0);
       HEAP8[$130>>0] = 1;
       $$pre$i$i3 = HEAP32[$this>>2]|0;
       $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
       $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
       $132 = $$pre$i$i3;$137 = $$pre1$i$i5;
      } else {
       $132 = $108;$137 = $110;
      }
     }
     HEAP32[$vararg_buffer4>>2] = $buffer2;
     HEAP8[$58>>0] = 0;
     $131 = (($132) + 12|0);
     $133 = HEAP32[$131>>2]|0;
     $134 = $133 & 2147483647;
     $135 = (($132) + 8|0);
     $136 = ($134>>>0)>($137>>>0);
     if ($136) {
      $138 = (($132) + 4|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = (($139) + ($137<<3)|0);
      $141 = ($140|0)==(0|0);
      if ($141) {
       $153 = $137;
      } else {
       $142 = $vararg_buffer4;
       $143 = $142;
       $144 = HEAP32[$143>>2]|0;
       $145 = (($142) + 4)|0;
       $146 = $145;
       $147 = HEAP32[$146>>2]|0;
       $148 = $140;
       $149 = $148;
       HEAP32[$149>>2] = $144;
       $150 = (($148) + 4)|0;
       $151 = $150;
       HEAP32[$151>>2] = $147;
       $$pre$i$i$i7 = HEAP32[$135>>2]|0;
       $153 = $$pre$i$i$i7;
      }
      $152 = (($153) + 1)|0;
      HEAP32[$135>>2] = $152;
     } else {
      (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($132,$vararg_buffer4)|0);
     }
     $154 = HEAP32[$59>>2]|0;
     $155 = HEAP32[$60>>2]|0;
     $156 = (Math_fround(FUNCTION_TABLE_fiii[$155 & 31]($154,$i$021,$j$020)));
     $157 = HEAP32[$57>>2]|0;
     $158 = HEAP32[$61>>2]|0;
     $159 = HEAP32[$this>>2]|0;
     $160 = (($159) + 8|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = ($161|0)==(0);
     if ($162) {
      $$0$i$i$i$i = 521512;
     } else {
      $163 = (($161) + -1)|0;
      $164 = (($159) + 4|0);
      $165 = HEAP32[$164>>2]|0;
      $166 = (($165) + ($163<<3)|0);
      $167 = HEAP32[$166>>2]|0;
      $$0$i$i$i$i = $167;
     }
     $168 = +$156;
     dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
     HEAPF64[tempDoublePtr>>3]=$168;HEAP32[$vararg_buffer4>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer4+4>>2]=HEAP32[tempDoublePtr+4>>2];
     (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer4)|0);
     $169 = HEAP8[$buffer$i$i$i>>0]|0;
     $170 = ($169<<24>>24)==(0);
     if (!($170)) {
      $171 = HEAP32[$158>>2]|0;
      $172 = HEAP32[$171>>2]|0;
      $173 = (_strlen(($buffer$i$i$i|0))|0);
      (FUNCTION_TABLE_iiii[$172 & 2047]($158,$buffer$i$i$i,$173)|0);
     }
     HEAP8[$vararg_buffer4>>0] = 0;
     $174 = HEAP32[$158>>2]|0;
     $175 = HEAP32[$174>>2]|0;
     (FUNCTION_TABLE_iiii[$175 & 2047]($158,$vararg_buffer4,1)|0);
     $176 = HEAP32[$157>>2]|0;
     $177 = (($176) + 8|0);
     $178 = HEAP32[$177>>2]|0;
     $179 = (($158) + 20|0);
     $180 = HEAP32[$179>>2]|0;
     FUNCTION_TABLE_viii[$178 & 4095]($157,$$0$i$i$i$i,$180);
     $181 = (($158) + 16|0);
     HEAP32[$181>>2] = 0;
     $182 = (($158) + 12|0);
     HEAP32[$182>>2] = 0;
     $183 = HEAP32[$this>>2]|0;
     $184 = (($183) + 8|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = ($185|0)==(0);
     if (!($186)) {
      $187 = (($185) + -1)|0;
      $188 = (($183) + 4|0);
      $189 = HEAP32[$188>>2]|0;
      $190 = ((($189) + ($187<<3)|0) + 4|0);
      $191 = HEAP8[$190>>0]|0;
      $192 = ($191<<24>>24)==(0);
      if ($192) {
       $198 = $183;$200 = $185;
      } else {
       $193 = HEAP32[$57>>2]|0;
       $194 = HEAP32[$193>>2]|0;
       $195 = (($194) + 20|0);
       $196 = HEAP32[$195>>2]|0;
       FUNCTION_TABLE_vi[$196 & 4095]($193);
       $$pre$i9 = HEAP32[$this>>2]|0;
       $$phi$trans$insert$i10 = (($$pre$i9) + 8|0);
       $$pre1$i11 = HEAP32[$$phi$trans$insert$i10>>2]|0;
       $198 = $$pre$i9;$200 = $$pre1$i11;
      }
      $197 = (($198) + 8|0);
      $199 = (($200) + -1)|0;
      HEAP32[$197>>2] = $199;
     }
     $201 = HEAP32[$rangeStart$>>2]|0;
     $202 = (($201) + 1)|0;
     HEAP32[$rangeStart$>>2] = $202;
     $203 = (($j$020) + 1)|0;
     $exitcond = ($203|0)==($id1Count|0);
     if ($exitcond) {
      break;
     } else {
      $j$020 = $203;
     }
    }
   }
   $204 = HEAP32[$this>>2]|0;
   $205 = (($204) + 8|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = ($206|0)==(0);
   if (!($207)) {
    $208 = (($206) + -1)|0;
    $209 = (($204) + 4|0);
    $210 = HEAP32[$209>>2]|0;
    $211 = ((($210) + ($208<<3)|0) + 4|0);
    $212 = HEAP8[$211>>0]|0;
    $213 = ($212<<24>>24)==(0);
    if ($213) {
     $219 = $204;$221 = $206;
    } else {
     $214 = HEAP32[$57>>2]|0;
     $215 = HEAP32[$214>>2]|0;
     $216 = (($215) + 20|0);
     $217 = HEAP32[$216>>2]|0;
     FUNCTION_TABLE_vi[$217 & 4095]($214);
     $$pre$i12 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i13 = (($$pre$i12) + 8|0);
     $$pre1$i14 = HEAP32[$$phi$trans$insert$i13>>2]|0;
     $219 = $$pre$i12;$221 = $$pre1$i14;
    }
    $218 = (($219) + 8|0);
    $220 = (($221) + -1)|0;
    HEAP32[$218>>2] = $220;
   }
   $222 = (($i$021) + 1)|0;
   $exitcond25 = ($222|0)==($id0Count|0);
   if ($exitcond25) {
    break;
   } else {
    $i$021 = $222;
   }
  }
 }
 $223 = HEAP32[$this>>2]|0;
 $224 = (($223) + 8|0);
 $225 = HEAP32[$224>>2]|0;
 $226 = ($225|0)==(0);
 if ($226) {
  STACKTOP = sp;return;
 }
 $227 = (($225) + -1)|0;
 $228 = (($223) + 4|0);
 $229 = HEAP32[$228>>2]|0;
 $230 = ((($229) + ($227<<3)|0) + 4|0);
 $231 = HEAP8[$230>>0]|0;
 $232 = ($231<<24>>24)==(0);
 if ($232) {
  $239 = $223;$241 = $225;
 } else {
  $233 = (($this) + 4|0);
  $234 = HEAP32[$233>>2]|0;
  $235 = HEAP32[$234>>2]|0;
  $236 = (($235) + 20|0);
  $237 = HEAP32[$236>>2]|0;
  FUNCTION_TABLE_vi[$237 & 4095]($234);
  $$pre$i16 = HEAP32[$this>>2]|0;
  $$phi$trans$insert$i17 = (($$pre$i16) + 8|0);
  $$pre1$i18 = HEAP32[$$phi$trans$insert$i17>>2]|0;
  $239 = $$pre$i16;$241 = $$pre1$i18;
 }
 $238 = (($239) + 8|0);
 $240 = (($241) + -1)|0;
 HEAP32[$238>>2] = $240;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj600ENS_22PxRepXPropertyAccessorILj600ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 28;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $15;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$19>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($19,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($19,$vararg_buffer,1)|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($19) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($17,$$0$i$i$i$i,$40);
 $41 = (($19) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($19) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj599ENS_22PxRepXPropertyAccessorILj599ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 24;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 24)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj598ENS_22PxRepXPropertyAccessorILj598ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 20;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 20)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj597ENS_22PxRepXPropertyAccessorILj597ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 16;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 16)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_17PxVehicleTireDataEEEE14handleAccessorILj596ENS_22PxRepXPropertyAccessorILj596ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 12;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_17PxVehicleTireDataENS0_15InlineAllocatorILj320ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = $capacity << 6;
  $2 = (($this) + 320|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(321);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 522064 : 521616;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,521536,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 328|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + ($18<<6)|0);
 $21 = (($this) + 324|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    dest=$$012$i+0|0; src=$$03$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $25 = (($$012$i) + 64|0);
   $26 = (($$03$i) + 64|0);
   $27 = ($25>>>0)<($19>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
 }
 $28 = (($this) + 332|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)>(-1);
 if (!($30)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$21>>2]|0;
 $32 = ($this|0)==($31|0);
 if ($32) {
  $33 = (($this) + 320|0);
  HEAP8[$33>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $34 = ($31|0)==(0|0);
 if ($34) {
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($35,$31);
 HEAP32[$21>>2] = $20;
 HEAP32[$28>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj610ES2_KjNS_18PxVehicleWheelDataEEEKNS_31PxVehicleWheelDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $buffer = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $propVal = 0, $theData = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 752|0;
 $vararg_buffer = sp;
 $2 = sp + 688|0;
 $theData = sp + 168|0;
 $3 = sp + 424|0;
 $buffer = sp + 720|0;
 $propVal = sp + 640|0;
 $4 = sp + 472|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($inProp) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($6)|0);
 $12 = (($theData) + 240|0);
 $13 = (($theData) + 244|0);
 $14 = (($theData) + 248|0);
 HEAP32[$14>>2] = 0;
 $15 = (($theData) + 252|0);
 HEAP8[$12>>0] = 1;
 HEAP32[$13>>2] = $theData;
 HEAP32[$15>>2] = 5;
 HEAPF32[$3>>2] = Math_fround(0.0);
 $16 = (($3) + 4|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($3) + 8|0);
 HEAPF32[$17>>2] = Math_fround(20.0);
 $18 = (($3) + 12|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($3) + 16|0);
 HEAPF32[$19>>2] = Math_fround(0.25);
 $20 = (($3) + 20|0);
 HEAPF32[$20>>2] = Math_fround(1500.0);
 $21 = (($3) + 24|0);
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;
 __ZN5physx6shdfnd5ArrayINS_18PxVehicleWheelDataENS0_15InlineAllocatorILj240ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($theData,$11,$3);
 $22 = ($11|0)==(0);
 if (!($22)) {
  $23 = (($vararg_buffer) + 4|0);
  $24 = (($this) + 4|0);
  $25 = (($this) + 12|0);
  $26 = (($this) + 16|0);
  $27 = (($2) + 4|0);
  $28 = (($2) + 8|0);
  $29 = (($2) + 12|0);
  $30 = (($2) + 16|0);
  $31 = (($2) + 20|0);
  $32 = (($2) + 24|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer)|0);
   $33 = HEAP32[$this>>2]|0;
   $34 = (($33) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0);
   if ($36) {
    $57 = $33;$62 = 0;
   } else {
    $37 = (($35) + -1)|0;
    $38 = (($33) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ((($39) + ($37<<3)|0) + 4|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $43 = HEAP32[$24>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + 16|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($39) + ($37<<3)|0);
     $48 = HEAP32[$47>>2]|0;
     FUNCTION_TABLE_vii[$46 & 4095]($43,$48);
     $49 = HEAP32[$this>>2]|0;
     $50 = (($49) + 8|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($51) + -1)|0;
     $53 = (($49) + 4|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ((($54) + ($52<<3)|0) + 4|0);
     HEAP8[$55>>0] = 1;
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $57 = $$pre$i1;$62 = $$pre1$i3;
    } else {
     $57 = $33;$62 = $35;
    }
   }
   HEAP32[$vararg_buffer>>2] = $buffer;
   HEAP8[$23>>0] = 0;
   $56 = (($57) + 12|0);
   $58 = HEAP32[$56>>2]|0;
   $59 = $58 & 2147483647;
   $60 = (($57) + 8|0);
   $61 = ($59>>>0)>($62>>>0);
   if ($61) {
    $63 = (($57) + 4|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($64) + ($62<<3)|0);
    $66 = ($65|0)==(0|0);
    if ($66) {
     $78 = $62;
    } else {
     $67 = $vararg_buffer;
     $68 = $67;
     $69 = HEAP32[$68>>2]|0;
     $70 = (($67) + 4)|0;
     $71 = $70;
     $72 = HEAP32[$71>>2]|0;
     $73 = $65;
     $74 = $73;
     HEAP32[$74>>2] = $69;
     $75 = (($73) + 4)|0;
     $76 = $75;
     HEAP32[$76>>2] = $72;
     $$pre$i$i = HEAP32[$60>>2]|0;
     $78 = $$pre$i$i;
    }
    $77 = (($78) + 1)|0;
    HEAP32[$60>>2] = $77;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($57,$vararg_buffer)|0);
   }
   $79 = HEAP32[$5>>2]|0;
   $80 = HEAP32[$7>>2]|0;
   $81 = (($80) + 12|0);
   $82 = HEAP32[$81>>2]|0;
   FUNCTION_TABLE_viii[$82 & 4095]($propVal,$79,$i$04);
   _memset(($4|0),0,168)|0;
   __ZN5physx31PxVehicleWheelDataGeneratedInfoC2Ev($4);
   $83 = HEAP32[$this>>2]|0;
   $84 = HEAP32[$24>>2]|0;
   $85 = HEAP32[$25>>2]|0;
   $86 = HEAP32[$26>>2]|0;
   __ZN5physx31PxVehicleWheelDataGeneratedInfoC2Ev($vararg_buffer);
   HEAP32[$2>>2] = $83;
   HEAP32[$27>>2] = $84;
   HEAP32[$28>>2] = $propVal;
   HEAP32[$29>>2] = $85;
   HEAP32[$30>>2] = $86;
   HEAP32[$31>>2] = 0;
   HEAP32[$32>>2] = 0;
   (__ZNK5physx31PxVehicleWheelDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEEEEEjT_j($vararg_buffer,$2,0)|0);
   $87 = HEAP32[$this>>2]|0;
   $88 = (($87) + 8|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)==(0);
   if (!($90)) {
    $91 = (($89) + -1)|0;
    $92 = (($87) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ((($93) + ($91<<3)|0) + 4|0);
    $95 = HEAP8[$94>>0]|0;
    $96 = ($95<<24>>24)==(0);
    if ($96) {
     $102 = $87;$104 = $89;
    } else {
     $97 = HEAP32[$24>>2]|0;
     $98 = HEAP32[$97>>2]|0;
     $99 = (($98) + 20|0);
     $100 = HEAP32[$99>>2]|0;
     FUNCTION_TABLE_vi[$100 & 4095]($97);
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $102 = $$pre$i;$104 = $$pre1$i;
    }
    $101 = (($102) + 8|0);
    $103 = (($104) + -1)|0;
    HEAP32[$101>>2] = $103;
   }
   $105 = (($i$04) + 1)|0;
   $exitcond = ($105|0)==($11|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $105;
   }
  }
 }
 $106 = HEAP32[$15>>2]|0;
 $107 = $106 & 2147483647;
 $108 = ($107|0)!=(0);
 $109 = ($106|0)>(-1);
 $or$cond$i$i$i = $108 & $109;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $110 = HEAP32[$13>>2]|0;
 $111 = ($theData|0)==($110|0);
 if ($111) {
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 }
 $112 = ($110|0)==(0|0);
 if ($112) {
  STACKTOP = sp;return;
 }
 $113 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (($114) + 12|0);
 $116 = HEAP32[$115>>2]|0;
 FUNCTION_TABLE_vii[$116 & 4095]($113,$110);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_18PxVehicleWheelDataENS0_15InlineAllocatorILj240ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 252|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_18PxVehicleWheelDataENS0_15InlineAllocatorILj240ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 244|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 248|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + (($size*48)|0)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + (($7*48)|0)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   dest=$$01$i+0|0; src=$a+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $12 = (($$01$i) + 48|0);
  $13 = ($12>>>0)<($8>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx31PxVehicleWheelDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i12 = 0, $$phi$trans$insert$i$i16 = 0, $$phi$trans$insert$i$i20 = 0, $$phi$trans$insert$i$i24 = 0, $$phi$trans$insert$i$i28 = 0, $$phi$trans$insert$i$i32 = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i36 = 0, $$phi$trans$insert$i43 = 0, $$phi$trans$insert$i50 = 0, $$phi$trans$insert$i57 = 0, $$phi$trans$insert$i64 = 0, $$phi$trans$insert$i71 = 0, $$phi$trans$insert$i78 = 0, $$phi$trans$insert$i85 = 0, $$phi$trans$insert101 = 0;
 var $$phi$trans$insert104 = 0, $$phi$trans$insert107 = 0, $$phi$trans$insert110 = 0, $$phi$trans$insert92 = 0, $$phi$trans$insert95 = 0, $$phi$trans$insert98 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i15 = 0, $$pre$i$i19 = 0, $$pre$i$i23 = 0, $$pre$i$i27 = 0, $$pre$i$i3 = 0, $$pre$i$i31 = 0, $$pre$i$i39 = 0, $$pre$i$i46 = 0, $$pre$i$i53 = 0;
 var $$pre$i$i60 = 0, $$pre$i$i67 = 0, $$pre$i$i7 = 0, $$pre$i$i74 = 0, $$pre$i$i81 = 0, $$pre$i$i88 = 0, $$pre$i35 = 0, $$pre$i42 = 0, $$pre$i49 = 0, $$pre$i56 = 0, $$pre$i63 = 0, $$pre$i70 = 0, $$pre$i77 = 0, $$pre$i84 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i13 = 0, $$pre1$i$i17 = 0, $$pre1$i$i21 = 0, $$pre1$i$i25 = 0;
 var $$pre1$i$i29 = 0, $$pre1$i$i33 = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i37 = 0, $$pre1$i44 = 0, $$pre1$i51 = 0, $$pre1$i58 = 0, $$pre1$i65 = 0, $$pre1$i72 = 0, $$pre1$i79 = 0, $$pre1$i86 = 0, $$pre100 = 0, $$pre102 = 0, $$pre103 = 0, $$pre105 = 0, $$pre106 = 0, $$pre108 = 0, $$pre109 = 0, $$pre111 = 0;
 var $$pre90 = 0, $$pre91 = 0, $$pre93 = 0, $$pre94 = 0, $$pre96 = 0, $$pre97 = 0, $$pre99 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i30 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i30 = sp + 8|0;
 $1 = (($this) + 24|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $2 = (($theAccessor$i30) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i35 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i36 = (($$pre$i35) + 8|0);
   $$pre1$i37 = HEAP32[$$phi$trans$insert$i36>>2]|0;
   $31 = $$pre$i35;$36 = $$pre1$i37;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i39 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i39;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj569ENS_22PxRepXPropertyAccessorILj569ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre90 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre90;$80 = $$pre;
 }
 $72 = (($this) + 40|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $73 = (($theAccessor$i30) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i42 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i43 = (($$pre$i42) + 8|0);
   $$pre1$i44 = HEAP32[$$phi$trans$insert$i43>>2]|0;
   $101 = $$pre$i42;$106 = $$pre1$i44;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i46 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i46;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj570ENS_22PxRepXPropertyAccessorILj570ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $147 = 0;$150 = $123;
 } else {
  $127 = (($125) + -1)|0;
  $128 = (($123) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129) + ($127<<3)|0) + 4|0);
  $131 = HEAP8[$130>>0]|0;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $139 = $123;$141 = $125;
  } else {
   $133 = (($inOperator) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = HEAP32[$134>>2]|0;
   $136 = (($135) + 20|0);
   $137 = HEAP32[$136>>2]|0;
   FUNCTION_TABLE_vi[$137 & 4095]($134);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $139 = $$pre$i$i7;$141 = $$pre1$i$i9;
  }
  $138 = (($139) + 8|0);
  $140 = (($141) + -1)|0;
  HEAP32[$138>>2] = $140;
  $$pre91 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert92 = (($$pre91) + 8|0);
  $$pre93 = HEAP32[$$phi$trans$insert92>>2]|0;
  $147 = $$pre93;$150 = $$pre91;
 }
 $142 = (($this) + 56|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $143 = (($theAccessor$i30) + 4|0);
 HEAP32[$143>>2] = 0;
 $144 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$144+0>>2]=HEAP32[$142+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$142+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$142+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$142+12>>2]|0;
 $145 = HEAP32[$142>>2]|0;
 $146 = ($147|0)==(0);
 if ($146) {
  $171 = $150;$176 = 0;
 } else {
  $148 = (($147) + -1)|0;
  $149 = (($150) + 4|0);
  $151 = HEAP32[$149>>2]|0;
  $152 = ((($151) + ($148<<3)|0) + 4|0);
  $153 = HEAP8[$152>>0]|0;
  $154 = ($153<<24>>24)==(0);
  if ($154) {
   $155 = (($inOperator) + 4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = HEAP32[$156>>2]|0;
   $158 = (($157) + 16|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($151) + ($148<<3)|0);
   $161 = HEAP32[$160>>2]|0;
   FUNCTION_TABLE_vii[$159 & 4095]($156,$161);
   $162 = HEAP32[$inOperator>>2]|0;
   $163 = (($162) + 8|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($164) + -1)|0;
   $166 = (($162) + 4|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ((($167) + ($165<<3)|0) + 4|0);
   HEAP8[$168>>0] = 1;
   $$pre$i49 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i50 = (($$pre$i49) + 8|0);
   $$pre1$i51 = HEAP32[$$phi$trans$insert$i50>>2]|0;
   $171 = $$pre$i49;$176 = $$pre1$i51;
  } else {
   $171 = $150;$176 = $147;
  }
 }
 HEAP32[$0>>2] = $145;
 $169 = (($0) + 4|0);
 HEAP8[$169>>0] = 0;
 $170 = (($171) + 12|0);
 $172 = HEAP32[$170>>2]|0;
 $173 = $172 & 2147483647;
 $174 = (($171) + 8|0);
 $175 = ($173>>>0)>($176>>>0);
 if ($175) {
  $177 = (($171) + 4|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + ($176<<3)|0);
  $180 = ($179|0)==(0|0);
  if ($180) {
   $192 = $176;
  } else {
   $181 = $0;
   $182 = $181;
   $183 = HEAP32[$182>>2]|0;
   $184 = (($181) + 4)|0;
   $185 = $184;
   $186 = HEAP32[$185>>2]|0;
   $187 = $179;
   $188 = $187;
   HEAP32[$188>>2] = $183;
   $189 = (($187) + 4)|0;
   $190 = $189;
   HEAP32[$190>>2] = $186;
   $$pre$i$i53 = HEAP32[$174>>2]|0;
   $192 = $$pre$i$i53;
  }
  $191 = (($192) + 1)|0;
  HEAP32[$174>>2] = $191;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($171,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj571ENS_22PxRepXPropertyAccessorILj571ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $193 = HEAP32[$inOperator>>2]|0;
 $194 = (($193) + 8|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)==(0);
 if ($196) {
  $217 = 0;$220 = $193;
 } else {
  $197 = (($195) + -1)|0;
  $198 = (($193) + 4|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ((($199) + ($197<<3)|0) + 4|0);
  $201 = HEAP8[$200>>0]|0;
  $202 = ($201<<24>>24)==(0);
  if ($202) {
   $209 = $193;$211 = $195;
  } else {
   $203 = (($inOperator) + 4|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = HEAP32[$204>>2]|0;
   $206 = (($205) + 20|0);
   $207 = HEAP32[$206>>2]|0;
   FUNCTION_TABLE_vi[$207 & 4095]($204);
   $$pre$i$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i12 = (($$pre$i$i11) + 8|0);
   $$pre1$i$i13 = HEAP32[$$phi$trans$insert$i$i12>>2]|0;
   $209 = $$pre$i$i11;$211 = $$pre1$i$i13;
  }
  $208 = (($209) + 8|0);
  $210 = (($211) + -1)|0;
  HEAP32[$208>>2] = $210;
  $$pre94 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert95 = (($$pre94) + 8|0);
  $$pre96 = HEAP32[$$phi$trans$insert95>>2]|0;
  $217 = $$pre96;$220 = $$pre94;
 }
 $212 = (($this) + 72|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $213 = (($theAccessor$i30) + 4|0);
 HEAP32[$213>>2] = 0;
 $214 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$214+0>>2]=HEAP32[$212+0>>2]|0;HEAP32[$214+4>>2]=HEAP32[$212+4>>2]|0;HEAP32[$214+8>>2]=HEAP32[$212+8>>2]|0;HEAP32[$214+12>>2]=HEAP32[$212+12>>2]|0;
 $215 = HEAP32[$212>>2]|0;
 $216 = ($217|0)==(0);
 if ($216) {
  $241 = $220;$246 = 0;
 } else {
  $218 = (($217) + -1)|0;
  $219 = (($220) + 4|0);
  $221 = HEAP32[$219>>2]|0;
  $222 = ((($221) + ($218<<3)|0) + 4|0);
  $223 = HEAP8[$222>>0]|0;
  $224 = ($223<<24>>24)==(0);
  if ($224) {
   $225 = (($inOperator) + 4|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = HEAP32[$226>>2]|0;
   $228 = (($227) + 16|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = (($221) + ($218<<3)|0);
   $231 = HEAP32[$230>>2]|0;
   FUNCTION_TABLE_vii[$229 & 4095]($226,$231);
   $232 = HEAP32[$inOperator>>2]|0;
   $233 = (($232) + 8|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = (($234) + -1)|0;
   $236 = (($232) + 4|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ((($237) + ($235<<3)|0) + 4|0);
   HEAP8[$238>>0] = 1;
   $$pre$i56 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i57 = (($$pre$i56) + 8|0);
   $$pre1$i58 = HEAP32[$$phi$trans$insert$i57>>2]|0;
   $241 = $$pre$i56;$246 = $$pre1$i58;
  } else {
   $241 = $220;$246 = $217;
  }
 }
 HEAP32[$0>>2] = $215;
 $239 = (($0) + 4|0);
 HEAP8[$239>>0] = 0;
 $240 = (($241) + 12|0);
 $242 = HEAP32[$240>>2]|0;
 $243 = $242 & 2147483647;
 $244 = (($241) + 8|0);
 $245 = ($243>>>0)>($246>>>0);
 if ($245) {
  $247 = (($241) + 4|0);
  $248 = HEAP32[$247>>2]|0;
  $249 = (($248) + ($246<<3)|0);
  $250 = ($249|0)==(0|0);
  if ($250) {
   $262 = $246;
  } else {
   $251 = $0;
   $252 = $251;
   $253 = HEAP32[$252>>2]|0;
   $254 = (($251) + 4)|0;
   $255 = $254;
   $256 = HEAP32[$255>>2]|0;
   $257 = $249;
   $258 = $257;
   HEAP32[$258>>2] = $253;
   $259 = (($257) + 4)|0;
   $260 = $259;
   HEAP32[$260>>2] = $256;
   $$pre$i$i60 = HEAP32[$244>>2]|0;
   $262 = $$pre$i$i60;
  }
  $261 = (($262) + 1)|0;
  HEAP32[$244>>2] = $261;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($241,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj572ENS_22PxRepXPropertyAccessorILj572ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $263 = HEAP32[$inOperator>>2]|0;
 $264 = (($263) + 8|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = ($265|0)==(0);
 if ($266) {
  $287 = 0;$290 = $263;
 } else {
  $267 = (($265) + -1)|0;
  $268 = (($263) + 4|0);
  $269 = HEAP32[$268>>2]|0;
  $270 = ((($269) + ($267<<3)|0) + 4|0);
  $271 = HEAP8[$270>>0]|0;
  $272 = ($271<<24>>24)==(0);
  if ($272) {
   $279 = $263;$281 = $265;
  } else {
   $273 = (($inOperator) + 4|0);
   $274 = HEAP32[$273>>2]|0;
   $275 = HEAP32[$274>>2]|0;
   $276 = (($275) + 20|0);
   $277 = HEAP32[$276>>2]|0;
   FUNCTION_TABLE_vi[$277 & 4095]($274);
   $$pre$i$i15 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i16 = (($$pre$i$i15) + 8|0);
   $$pre1$i$i17 = HEAP32[$$phi$trans$insert$i$i16>>2]|0;
   $279 = $$pre$i$i15;$281 = $$pre1$i$i17;
  }
  $278 = (($279) + 8|0);
  $280 = (($281) + -1)|0;
  HEAP32[$278>>2] = $280;
  $$pre97 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert98 = (($$pre97) + 8|0);
  $$pre99 = HEAP32[$$phi$trans$insert98>>2]|0;
  $287 = $$pre99;$290 = $$pre97;
 }
 $282 = (($this) + 88|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $283 = (($theAccessor$i30) + 4|0);
 HEAP32[$283>>2] = 0;
 $284 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$284+0>>2]=HEAP32[$282+0>>2]|0;HEAP32[$284+4>>2]=HEAP32[$282+4>>2]|0;HEAP32[$284+8>>2]=HEAP32[$282+8>>2]|0;HEAP32[$284+12>>2]=HEAP32[$282+12>>2]|0;
 $285 = HEAP32[$282>>2]|0;
 $286 = ($287|0)==(0);
 if ($286) {
  $311 = $290;$316 = 0;
 } else {
  $288 = (($287) + -1)|0;
  $289 = (($290) + 4|0);
  $291 = HEAP32[$289>>2]|0;
  $292 = ((($291) + ($288<<3)|0) + 4|0);
  $293 = HEAP8[$292>>0]|0;
  $294 = ($293<<24>>24)==(0);
  if ($294) {
   $295 = (($inOperator) + 4|0);
   $296 = HEAP32[$295>>2]|0;
   $297 = HEAP32[$296>>2]|0;
   $298 = (($297) + 16|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = (($291) + ($288<<3)|0);
   $301 = HEAP32[$300>>2]|0;
   FUNCTION_TABLE_vii[$299 & 4095]($296,$301);
   $302 = HEAP32[$inOperator>>2]|0;
   $303 = (($302) + 8|0);
   $304 = HEAP32[$303>>2]|0;
   $305 = (($304) + -1)|0;
   $306 = (($302) + 4|0);
   $307 = HEAP32[$306>>2]|0;
   $308 = ((($307) + ($305<<3)|0) + 4|0);
   HEAP8[$308>>0] = 1;
   $$pre$i63 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i64 = (($$pre$i63) + 8|0);
   $$pre1$i65 = HEAP32[$$phi$trans$insert$i64>>2]|0;
   $311 = $$pre$i63;$316 = $$pre1$i65;
  } else {
   $311 = $290;$316 = $287;
  }
 }
 HEAP32[$0>>2] = $285;
 $309 = (($0) + 4|0);
 HEAP8[$309>>0] = 0;
 $310 = (($311) + 12|0);
 $312 = HEAP32[$310>>2]|0;
 $313 = $312 & 2147483647;
 $314 = (($311) + 8|0);
 $315 = ($313>>>0)>($316>>>0);
 if ($315) {
  $317 = (($311) + 4|0);
  $318 = HEAP32[$317>>2]|0;
  $319 = (($318) + ($316<<3)|0);
  $320 = ($319|0)==(0|0);
  if ($320) {
   $332 = $316;
  } else {
   $321 = $0;
   $322 = $321;
   $323 = HEAP32[$322>>2]|0;
   $324 = (($321) + 4)|0;
   $325 = $324;
   $326 = HEAP32[$325>>2]|0;
   $327 = $319;
   $328 = $327;
   HEAP32[$328>>2] = $323;
   $329 = (($327) + 4)|0;
   $330 = $329;
   HEAP32[$330>>2] = $326;
   $$pre$i$i67 = HEAP32[$314>>2]|0;
   $332 = $$pre$i$i67;
  }
  $331 = (($332) + 1)|0;
  HEAP32[$314>>2] = $331;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($311,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj573ENS_22PxRepXPropertyAccessorILj573ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $333 = HEAP32[$inOperator>>2]|0;
 $334 = (($333) + 8|0);
 $335 = HEAP32[$334>>2]|0;
 $336 = ($335|0)==(0);
 if ($336) {
  $357 = 0;$360 = $333;
 } else {
  $337 = (($335) + -1)|0;
  $338 = (($333) + 4|0);
  $339 = HEAP32[$338>>2]|0;
  $340 = ((($339) + ($337<<3)|0) + 4|0);
  $341 = HEAP8[$340>>0]|0;
  $342 = ($341<<24>>24)==(0);
  if ($342) {
   $349 = $333;$351 = $335;
  } else {
   $343 = (($inOperator) + 4|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = HEAP32[$344>>2]|0;
   $346 = (($345) + 20|0);
   $347 = HEAP32[$346>>2]|0;
   FUNCTION_TABLE_vi[$347 & 4095]($344);
   $$pre$i$i19 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i20 = (($$pre$i$i19) + 8|0);
   $$pre1$i$i21 = HEAP32[$$phi$trans$insert$i$i20>>2]|0;
   $349 = $$pre$i$i19;$351 = $$pre1$i$i21;
  }
  $348 = (($349) + 8|0);
  $350 = (($351) + -1)|0;
  HEAP32[$348>>2] = $350;
  $$pre100 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert101 = (($$pre100) + 8|0);
  $$pre102 = HEAP32[$$phi$trans$insert101>>2]|0;
  $357 = $$pre102;$360 = $$pre100;
 }
 $352 = (($this) + 104|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $353 = (($theAccessor$i30) + 4|0);
 HEAP32[$353>>2] = 0;
 $354 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$354+0>>2]=HEAP32[$352+0>>2]|0;HEAP32[$354+4>>2]=HEAP32[$352+4>>2]|0;HEAP32[$354+8>>2]=HEAP32[$352+8>>2]|0;HEAP32[$354+12>>2]=HEAP32[$352+12>>2]|0;
 $355 = HEAP32[$352>>2]|0;
 $356 = ($357|0)==(0);
 if ($356) {
  $381 = $360;$386 = 0;
 } else {
  $358 = (($357) + -1)|0;
  $359 = (($360) + 4|0);
  $361 = HEAP32[$359>>2]|0;
  $362 = ((($361) + ($358<<3)|0) + 4|0);
  $363 = HEAP8[$362>>0]|0;
  $364 = ($363<<24>>24)==(0);
  if ($364) {
   $365 = (($inOperator) + 4|0);
   $366 = HEAP32[$365>>2]|0;
   $367 = HEAP32[$366>>2]|0;
   $368 = (($367) + 16|0);
   $369 = HEAP32[$368>>2]|0;
   $370 = (($361) + ($358<<3)|0);
   $371 = HEAP32[$370>>2]|0;
   FUNCTION_TABLE_vii[$369 & 4095]($366,$371);
   $372 = HEAP32[$inOperator>>2]|0;
   $373 = (($372) + 8|0);
   $374 = HEAP32[$373>>2]|0;
   $375 = (($374) + -1)|0;
   $376 = (($372) + 4|0);
   $377 = HEAP32[$376>>2]|0;
   $378 = ((($377) + ($375<<3)|0) + 4|0);
   HEAP8[$378>>0] = 1;
   $$pre$i70 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i71 = (($$pre$i70) + 8|0);
   $$pre1$i72 = HEAP32[$$phi$trans$insert$i71>>2]|0;
   $381 = $$pre$i70;$386 = $$pre1$i72;
  } else {
   $381 = $360;$386 = $357;
  }
 }
 HEAP32[$0>>2] = $355;
 $379 = (($0) + 4|0);
 HEAP8[$379>>0] = 0;
 $380 = (($381) + 12|0);
 $382 = HEAP32[$380>>2]|0;
 $383 = $382 & 2147483647;
 $384 = (($381) + 8|0);
 $385 = ($383>>>0)>($386>>>0);
 if ($385) {
  $387 = (($381) + 4|0);
  $388 = HEAP32[$387>>2]|0;
  $389 = (($388) + ($386<<3)|0);
  $390 = ($389|0)==(0|0);
  if ($390) {
   $402 = $386;
  } else {
   $391 = $0;
   $392 = $391;
   $393 = HEAP32[$392>>2]|0;
   $394 = (($391) + 4)|0;
   $395 = $394;
   $396 = HEAP32[$395>>2]|0;
   $397 = $389;
   $398 = $397;
   HEAP32[$398>>2] = $393;
   $399 = (($397) + 4)|0;
   $400 = $399;
   HEAP32[$400>>2] = $396;
   $$pre$i$i74 = HEAP32[$384>>2]|0;
   $402 = $$pre$i$i74;
  }
  $401 = (($402) + 1)|0;
  HEAP32[$384>>2] = $401;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($381,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj574ENS_22PxRepXPropertyAccessorILj574ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $403 = HEAP32[$inOperator>>2]|0;
 $404 = (($403) + 8|0);
 $405 = HEAP32[$404>>2]|0;
 $406 = ($405|0)==(0);
 if ($406) {
  $427 = 0;$430 = $403;
 } else {
  $407 = (($405) + -1)|0;
  $408 = (($403) + 4|0);
  $409 = HEAP32[$408>>2]|0;
  $410 = ((($409) + ($407<<3)|0) + 4|0);
  $411 = HEAP8[$410>>0]|0;
  $412 = ($411<<24>>24)==(0);
  if ($412) {
   $419 = $403;$421 = $405;
  } else {
   $413 = (($inOperator) + 4|0);
   $414 = HEAP32[$413>>2]|0;
   $415 = HEAP32[$414>>2]|0;
   $416 = (($415) + 20|0);
   $417 = HEAP32[$416>>2]|0;
   FUNCTION_TABLE_vi[$417 & 4095]($414);
   $$pre$i$i23 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i24 = (($$pre$i$i23) + 8|0);
   $$pre1$i$i25 = HEAP32[$$phi$trans$insert$i$i24>>2]|0;
   $419 = $$pre$i$i23;$421 = $$pre1$i$i25;
  }
  $418 = (($419) + 8|0);
  $420 = (($421) + -1)|0;
  HEAP32[$418>>2] = $420;
  $$pre103 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert104 = (($$pre103) + 8|0);
  $$pre105 = HEAP32[$$phi$trans$insert104>>2]|0;
  $427 = $$pre105;$430 = $$pre103;
 }
 $422 = (($this) + 120|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $423 = (($theAccessor$i30) + 4|0);
 HEAP32[$423>>2] = 0;
 $424 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$424+0>>2]=HEAP32[$422+0>>2]|0;HEAP32[$424+4>>2]=HEAP32[$422+4>>2]|0;HEAP32[$424+8>>2]=HEAP32[$422+8>>2]|0;HEAP32[$424+12>>2]=HEAP32[$422+12>>2]|0;
 $425 = HEAP32[$422>>2]|0;
 $426 = ($427|0)==(0);
 do {
  if ($426) {
   $451 = $430;$456 = 0;
  } else {
   $428 = (($427) + -1)|0;
   $429 = (($430) + 4|0);
   $431 = HEAP32[$429>>2]|0;
   $432 = ((($431) + ($428<<3)|0) + 4|0);
   $433 = HEAP8[$432>>0]|0;
   $434 = ($433<<24>>24)==(0);
   if (!($434)) {
    $451 = $430;$456 = $427;
    break;
   }
   $435 = (($inOperator) + 4|0);
   $436 = HEAP32[$435>>2]|0;
   $437 = HEAP32[$436>>2]|0;
   $438 = (($437) + 16|0);
   $439 = HEAP32[$438>>2]|0;
   $440 = (($431) + ($428<<3)|0);
   $441 = HEAP32[$440>>2]|0;
   FUNCTION_TABLE_vii[$439 & 4095]($436,$441);
   $442 = HEAP32[$inOperator>>2]|0;
   $443 = (($442) + 8|0);
   $444 = HEAP32[$443>>2]|0;
   $445 = (($444) + -1)|0;
   $446 = (($442) + 4|0);
   $447 = HEAP32[$446>>2]|0;
   $448 = ((($447) + ($445<<3)|0) + 4|0);
   HEAP8[$448>>0] = 1;
   $$pre$i77 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i78 = (($$pre$i77) + 8|0);
   $$pre1$i79 = HEAP32[$$phi$trans$insert$i78>>2]|0;
   $451 = $$pre$i77;$456 = $$pre1$i79;
  }
 } while(0);
 HEAP32[$0>>2] = $425;
 $449 = (($0) + 4|0);
 HEAP8[$449>>0] = 0;
 $450 = (($451) + 12|0);
 $452 = HEAP32[$450>>2]|0;
 $453 = $452 & 2147483647;
 $454 = (($451) + 8|0);
 $455 = ($453>>>0)>($456>>>0);
 if ($455) {
  $457 = (($451) + 4|0);
  $458 = HEAP32[$457>>2]|0;
  $459 = (($458) + ($456<<3)|0);
  $460 = ($459|0)==(0|0);
  if ($460) {
   $472 = $456;
  } else {
   $461 = $0;
   $462 = $461;
   $463 = HEAP32[$462>>2]|0;
   $464 = (($461) + 4)|0;
   $465 = $464;
   $466 = HEAP32[$465>>2]|0;
   $467 = $459;
   $468 = $467;
   HEAP32[$468>>2] = $463;
   $469 = (($467) + 4)|0;
   $470 = $469;
   HEAP32[$470>>2] = $466;
   $$pre$i$i81 = HEAP32[$454>>2]|0;
   $472 = $$pre$i$i81;
  }
  $471 = (($472) + 1)|0;
  HEAP32[$454>>2] = $471;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($451,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj575ENS_22PxRepXPropertyAccessorILj575ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $473 = HEAP32[$inOperator>>2]|0;
 $474 = (($473) + 8|0);
 $475 = HEAP32[$474>>2]|0;
 $476 = ($475|0)==(0);
 if ($476) {
  $497 = 0;$500 = $473;
 } else {
  $477 = (($475) + -1)|0;
  $478 = (($473) + 4|0);
  $479 = HEAP32[$478>>2]|0;
  $480 = ((($479) + ($477<<3)|0) + 4|0);
  $481 = HEAP8[$480>>0]|0;
  $482 = ($481<<24>>24)==(0);
  if ($482) {
   $489 = $473;$491 = $475;
  } else {
   $483 = (($inOperator) + 4|0);
   $484 = HEAP32[$483>>2]|0;
   $485 = HEAP32[$484>>2]|0;
   $486 = (($485) + 20|0);
   $487 = HEAP32[$486>>2]|0;
   FUNCTION_TABLE_vi[$487 & 4095]($484);
   $$pre$i$i27 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i28 = (($$pre$i$i27) + 8|0);
   $$pre1$i$i29 = HEAP32[$$phi$trans$insert$i$i28>>2]|0;
   $489 = $$pre$i$i27;$491 = $$pre1$i$i29;
  }
  $488 = (($489) + 8|0);
  $490 = (($491) + -1)|0;
  HEAP32[$488>>2] = $490;
  $$pre106 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert107 = (($$pre106) + 8|0);
  $$pre108 = HEAP32[$$phi$trans$insert107>>2]|0;
  $497 = $$pre108;$500 = $$pre106;
 }
 $492 = (($this) + 136|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $493 = (($theAccessor$i30) + 4|0);
 HEAP32[$493>>2] = 0;
 $494 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$494+0>>2]=HEAP32[$492+0>>2]|0;HEAP32[$494+4>>2]=HEAP32[$492+4>>2]|0;HEAP32[$494+8>>2]=HEAP32[$492+8>>2]|0;HEAP32[$494+12>>2]=HEAP32[$492+12>>2]|0;
 $495 = HEAP32[$492>>2]|0;
 $496 = ($497|0)==(0);
 do {
  if ($496) {
   $521 = $500;$526 = 0;
  } else {
   $498 = (($497) + -1)|0;
   $499 = (($500) + 4|0);
   $501 = HEAP32[$499>>2]|0;
   $502 = ((($501) + ($498<<3)|0) + 4|0);
   $503 = HEAP8[$502>>0]|0;
   $504 = ($503<<24>>24)==(0);
   if (!($504)) {
    $521 = $500;$526 = $497;
    break;
   }
   $505 = (($inOperator) + 4|0);
   $506 = HEAP32[$505>>2]|0;
   $507 = HEAP32[$506>>2]|0;
   $508 = (($507) + 16|0);
   $509 = HEAP32[$508>>2]|0;
   $510 = (($501) + ($498<<3)|0);
   $511 = HEAP32[$510>>2]|0;
   FUNCTION_TABLE_vii[$509 & 4095]($506,$511);
   $512 = HEAP32[$inOperator>>2]|0;
   $513 = (($512) + 8|0);
   $514 = HEAP32[$513>>2]|0;
   $515 = (($514) + -1)|0;
   $516 = (($512) + 4|0);
   $517 = HEAP32[$516>>2]|0;
   $518 = ((($517) + ($515<<3)|0) + 4|0);
   HEAP8[$518>>0] = 1;
   $$pre$i84 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i85 = (($$pre$i84) + 8|0);
   $$pre1$i86 = HEAP32[$$phi$trans$insert$i85>>2]|0;
   $521 = $$pre$i84;$526 = $$pre1$i86;
  }
 } while(0);
 HEAP32[$0>>2] = $495;
 $519 = (($0) + 4|0);
 HEAP8[$519>>0] = 0;
 $520 = (($521) + 12|0);
 $522 = HEAP32[$520>>2]|0;
 $523 = $522 & 2147483647;
 $524 = (($521) + 8|0);
 $525 = ($523>>>0)>($526>>>0);
 if ($525) {
  $527 = (($521) + 4|0);
  $528 = HEAP32[$527>>2]|0;
  $529 = (($528) + ($526<<3)|0);
  $530 = ($529|0)==(0|0);
  if ($530) {
   $542 = $526;
  } else {
   $531 = $0;
   $532 = $531;
   $533 = HEAP32[$532>>2]|0;
   $534 = (($531) + 4)|0;
   $535 = $534;
   $536 = HEAP32[$535>>2]|0;
   $537 = $529;
   $538 = $537;
   HEAP32[$538>>2] = $533;
   $539 = (($537) + 4)|0;
   $540 = $539;
   HEAP32[$540>>2] = $536;
   $$pre$i$i88 = HEAP32[$524>>2]|0;
   $542 = $$pre$i$i88;
  }
  $541 = (($542) + 1)|0;
  HEAP32[$524>>2] = $541;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($521,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj576ENS_22PxRepXPropertyAccessorILj576ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $543 = HEAP32[$inOperator>>2]|0;
 $544 = (($543) + 8|0);
 $545 = HEAP32[$544>>2]|0;
 $546 = ($545|0)==(0);
 if ($546) {
  $567 = 0;$570 = $543;
 } else {
  $547 = (($545) + -1)|0;
  $548 = (($543) + 4|0);
  $549 = HEAP32[$548>>2]|0;
  $550 = ((($549) + ($547<<3)|0) + 4|0);
  $551 = HEAP8[$550>>0]|0;
  $552 = ($551<<24>>24)==(0);
  if ($552) {
   $559 = $543;$561 = $545;
  } else {
   $553 = (($inOperator) + 4|0);
   $554 = HEAP32[$553>>2]|0;
   $555 = HEAP32[$554>>2]|0;
   $556 = (($555) + 20|0);
   $557 = HEAP32[$556>>2]|0;
   FUNCTION_TABLE_vi[$557 & 4095]($554);
   $$pre$i$i31 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i32 = (($$pre$i$i31) + 8|0);
   $$pre1$i$i33 = HEAP32[$$phi$trans$insert$i$i32>>2]|0;
   $559 = $$pre$i$i31;$561 = $$pre1$i$i33;
  }
  $558 = (($559) + 8|0);
  $560 = (($561) + -1)|0;
  HEAP32[$558>>2] = $560;
  $$pre109 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert110 = (($$pre109) + 8|0);
  $$pre111 = HEAP32[$$phi$trans$insert110>>2]|0;
  $567 = $$pre111;$570 = $$pre109;
 }
 $562 = (($this) + 152|0);
 HEAP8[$theAccessor$i30>>0] = 0;
 $563 = (($theAccessor$i30) + 4|0);
 HEAP32[$563>>2] = 0;
 $564 = (($theAccessor$i30) + 8|0);
 ;HEAP32[$564+0>>2]=HEAP32[$562+0>>2]|0;HEAP32[$564+4>>2]=HEAP32[$562+4>>2]|0;HEAP32[$564+8>>2]=HEAP32[$562+8>>2]|0;HEAP32[$564+12>>2]=HEAP32[$562+12>>2]|0;
 $565 = HEAP32[$562>>2]|0;
 $566 = ($567|0)==(0);
 do {
  if ($566) {
   $591 = $570;$596 = 0;
  } else {
   $568 = (($567) + -1)|0;
   $569 = (($570) + 4|0);
   $571 = HEAP32[$569>>2]|0;
   $572 = ((($571) + ($568<<3)|0) + 4|0);
   $573 = HEAP8[$572>>0]|0;
   $574 = ($573<<24>>24)==(0);
   if (!($574)) {
    $591 = $570;$596 = $567;
    break;
   }
   $575 = (($inOperator) + 4|0);
   $576 = HEAP32[$575>>2]|0;
   $577 = HEAP32[$576>>2]|0;
   $578 = (($577) + 16|0);
   $579 = HEAP32[$578>>2]|0;
   $580 = (($571) + ($568<<3)|0);
   $581 = HEAP32[$580>>2]|0;
   FUNCTION_TABLE_vii[$579 & 4095]($576,$581);
   $582 = HEAP32[$inOperator>>2]|0;
   $583 = (($582) + 8|0);
   $584 = HEAP32[$583>>2]|0;
   $585 = (($584) + -1)|0;
   $586 = (($582) + 4|0);
   $587 = HEAP32[$586>>2]|0;
   $588 = ((($587) + ($585<<3)|0) + 4|0);
   HEAP8[$588>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $591 = $$pre$i;$596 = $$pre1$i;
  }
 } while(0);
 HEAP32[$0>>2] = $565;
 $589 = (($0) + 4|0);
 HEAP8[$589>>0] = 0;
 $590 = (($591) + 12|0);
 $592 = HEAP32[$590>>2]|0;
 $593 = $592 & 2147483647;
 $594 = (($591) + 8|0);
 $595 = ($593>>>0)>($596>>>0);
 if ($595) {
  $597 = (($591) + 4|0);
  $598 = HEAP32[$597>>2]|0;
  $599 = (($598) + ($596<<3)|0);
  $600 = ($599|0)==(0|0);
  if ($600) {
   $612 = $596;
  } else {
   $601 = $0;
   $602 = $601;
   $603 = HEAP32[$602>>2]|0;
   $604 = (($601) + 4)|0;
   $605 = $604;
   $606 = HEAP32[$605>>2]|0;
   $607 = $599;
   $608 = $607;
   HEAP32[$608>>2] = $603;
   $609 = (($607) + 4)|0;
   $610 = $609;
   HEAP32[$610>>2] = $606;
   $$pre$i$i1 = HEAP32[$594>>2]|0;
   $612 = $$pre$i$i1;
  }
  $611 = (($612) + 1)|0;
  HEAP32[$594>>2] = $611;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($591,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj577ENS_22PxRepXPropertyAccessorILj577ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i30);
 $613 = HEAP32[$inOperator>>2]|0;
 $614 = (($613) + 8|0);
 $615 = HEAP32[$614>>2]|0;
 $616 = ($615|0)==(0);
 if ($616) {
  $632 = (($inStartIndex) + 11)|0;
  STACKTOP = sp;return ($632|0);
 }
 $617 = (($615) + -1)|0;
 $618 = (($613) + 4|0);
 $619 = HEAP32[$618>>2]|0;
 $620 = ((($619) + ($617<<3)|0) + 4|0);
 $621 = HEAP8[$620>>0]|0;
 $622 = ($621<<24>>24)==(0);
 if ($622) {
  $629 = $613;$631 = $615;
 } else {
  $623 = (($inOperator) + 4|0);
  $624 = HEAP32[$623>>2]|0;
  $625 = HEAP32[$624>>2]|0;
  $626 = (($625) + 20|0);
  $627 = HEAP32[$626>>2]|0;
  FUNCTION_TABLE_vi[$627 & 4095]($624);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $629 = $$pre$i$i;$631 = $$pre1$i$i;
 }
 $628 = (($629) + 8|0);
 $630 = (($631) + -1)|0;
 HEAP32[$628>>2] = $630;
 $632 = (($inStartIndex) + 11)|0;
 STACKTOP = sp;return ($632|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj577ENS_22PxRepXPropertyAccessorILj577ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 40;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 40)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj576ENS_22PxRepXPropertyAccessorILj576ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 36;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 36)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj575ENS_22PxRepXPropertyAccessorILj575ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 32;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 32)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj574ENS_22PxRepXPropertyAccessorILj574ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 28;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj573ENS_22PxRepXPropertyAccessorILj573ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 24;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 24)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj572ENS_22PxRepXPropertyAccessorILj572ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 20;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 20)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj571ENS_22PxRepXPropertyAccessorILj571ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 16;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 16)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj570ENS_22PxRepXPropertyAccessorILj570ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 12;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleWheelDataEEEE14handleAccessorILj569ENS_22PxRepXPropertyAccessorILj569ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_18PxVehicleWheelDataENS0_15InlineAllocatorILj240ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = ($capacity*48)|0;
  $2 = (($this) + 240|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(241);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 522192 : 521616;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,521536,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 248|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + (($18*48)|0)|0);
 $21 = (($this) + 244|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    dest=$$012$i+0|0; src=$$03$i+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $25 = (($$012$i) + 48|0);
   $26 = (($$03$i) + 48|0);
   $27 = ($25>>>0)<($19>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
 }
 $28 = (($this) + 252|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)>(-1);
 if (!($30)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$21>>2]|0;
 $32 = ($this|0)==($31|0);
 if ($32) {
  $33 = (($this) + 240|0);
  HEAP8[$33>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $34 = ($31|0)==(0|0);
 if ($34) {
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($35,$31);
 HEAP32[$21>>2] = $20;
 HEAP32[$28>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_22PxVehicleWheelsSimDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj609ES2_KjNS_23PxVehicleSuspensionDataEEEKNS_36PxVehicleSuspensionDataGeneratedInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $buffer = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $propVal = 0, $theData = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 752|0;
 $vararg_buffer = sp;
 $2 = sp + 688|0;
 $theData = sp + 168|0;
 $3 = sp + 424|0;
 $buffer = sp + 720|0;
 $propVal = sp + 640|0;
 $4 = sp + 472|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($inProp) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($6)|0);
 $12 = (($theData) + 240|0);
 $13 = (($theData) + 244|0);
 $14 = (($theData) + 248|0);
 HEAP32[$14>>2] = 0;
 $15 = (($theData) + 252|0);
 HEAP8[$12>>0] = 1;
 HEAP32[$13>>2] = $theData;
 HEAP32[$15>>2] = 5;
 HEAPF32[$3>>2] = Math_fround(0.0);
 $16 = (($3) + 4|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($3) + 8|0);
 HEAPF32[$17>>2] = Math_fround(0.300000011920928955078);
 $18 = (($3) + 12|0);
 HEAPF32[$18>>2] = Math_fround(0.100000001490116119385);
 $19 = (($3) + 16|0);
 $20 = (($3) + 32|0);
 ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($3) + 36|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 __ZN5physx6shdfnd5ArrayINS_23PxVehicleSuspensionDataENS0_15InlineAllocatorILj240ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($theData,$11,$3);
 $22 = ($11|0)==(0);
 if (!($22)) {
  $23 = (($vararg_buffer) + 4|0);
  $24 = (($this) + 4|0);
  $25 = (($this) + 12|0);
  $26 = (($this) + 16|0);
  $27 = (($2) + 4|0);
  $28 = (($2) + 8|0);
  $29 = (($2) + 12|0);
  $30 = (($2) + 16|0);
  $31 = (($2) + 20|0);
  $32 = (($2) + 24|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer)|0);
   $33 = HEAP32[$this>>2]|0;
   $34 = (($33) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0);
   if ($36) {
    $57 = $33;$62 = 0;
   } else {
    $37 = (($35) + -1)|0;
    $38 = (($33) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ((($39) + ($37<<3)|0) + 4|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $43 = HEAP32[$24>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + 16|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($39) + ($37<<3)|0);
     $48 = HEAP32[$47>>2]|0;
     FUNCTION_TABLE_vii[$46 & 4095]($43,$48);
     $49 = HEAP32[$this>>2]|0;
     $50 = (($49) + 8|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($51) + -1)|0;
     $53 = (($49) + 4|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ((($54) + ($52<<3)|0) + 4|0);
     HEAP8[$55>>0] = 1;
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $57 = $$pre$i1;$62 = $$pre1$i3;
    } else {
     $57 = $33;$62 = $35;
    }
   }
   HEAP32[$vararg_buffer>>2] = $buffer;
   HEAP8[$23>>0] = 0;
   $56 = (($57) + 12|0);
   $58 = HEAP32[$56>>2]|0;
   $59 = $58 & 2147483647;
   $60 = (($57) + 8|0);
   $61 = ($59>>>0)>($62>>>0);
   if ($61) {
    $63 = (($57) + 4|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($64) + ($62<<3)|0);
    $66 = ($65|0)==(0|0);
    if ($66) {
     $78 = $62;
    } else {
     $67 = $vararg_buffer;
     $68 = $67;
     $69 = HEAP32[$68>>2]|0;
     $70 = (($67) + 4)|0;
     $71 = $70;
     $72 = HEAP32[$71>>2]|0;
     $73 = $65;
     $74 = $73;
     HEAP32[$74>>2] = $69;
     $75 = (($73) + 4)|0;
     $76 = $75;
     HEAP32[$76>>2] = $72;
     $$pre$i$i = HEAP32[$60>>2]|0;
     $78 = $$pre$i$i;
    }
    $77 = (($78) + 1)|0;
    HEAP32[$60>>2] = $77;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($57,$vararg_buffer)|0);
   }
   $79 = HEAP32[$5>>2]|0;
   $80 = HEAP32[$7>>2]|0;
   $81 = (($80) + 12|0);
   $82 = HEAP32[$81>>2]|0;
   FUNCTION_TABLE_viii[$82 & 4095]($propVal,$79,$i$04);
   _memset(($4|0),0,164)|0;
   __ZN5physx36PxVehicleSuspensionDataGeneratedInfoC2Ev($4);
   $83 = HEAP32[$this>>2]|0;
   $84 = HEAP32[$24>>2]|0;
   $85 = HEAP32[$25>>2]|0;
   $86 = HEAP32[$26>>2]|0;
   __ZN5physx36PxVehicleSuspensionDataGeneratedInfoC2Ev($vararg_buffer);
   HEAP32[$2>>2] = $83;
   HEAP32[$27>>2] = $84;
   HEAP32[$28>>2] = $propVal;
   HEAP32[$29>>2] = $85;
   HEAP32[$30>>2] = $86;
   HEAP32[$31>>2] = 0;
   HEAP32[$32>>2] = 0;
   (__ZNK5physx36PxVehicleSuspensionDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEEEEEjT_j($vararg_buffer,$2,0)|0);
   $87 = HEAP32[$this>>2]|0;
   $88 = (($87) + 8|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)==(0);
   if (!($90)) {
    $91 = (($89) + -1)|0;
    $92 = (($87) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ((($93) + ($91<<3)|0) + 4|0);
    $95 = HEAP8[$94>>0]|0;
    $96 = ($95<<24>>24)==(0);
    if ($96) {
     $102 = $87;$104 = $89;
    } else {
     $97 = HEAP32[$24>>2]|0;
     $98 = HEAP32[$97>>2]|0;
     $99 = (($98) + 20|0);
     $100 = HEAP32[$99>>2]|0;
     FUNCTION_TABLE_vi[$100 & 4095]($97);
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $102 = $$pre$i;$104 = $$pre1$i;
    }
    $101 = (($102) + 8|0);
    $103 = (($104) + -1)|0;
    HEAP32[$101>>2] = $103;
   }
   $105 = (($i$04) + 1)|0;
   $exitcond = ($105|0)==($11|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $105;
   }
  }
 }
 $106 = HEAP32[$15>>2]|0;
 $107 = $106 & 2147483647;
 $108 = ($107|0)!=(0);
 $109 = ($106|0)>(-1);
 $or$cond$i$i$i = $108 & $109;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $110 = HEAP32[$13>>2]|0;
 $111 = ($theData|0)==($110|0);
 if ($111) {
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 }
 $112 = ($110|0)==(0|0);
 if ($112) {
  STACKTOP = sp;return;
 }
 $113 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (($114) + 12|0);
 $116 = HEAP32[$115>>2]|0;
 FUNCTION_TABLE_vii[$116 & 4095]($113,$110);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_23PxVehicleSuspensionDataENS0_15InlineAllocatorILj240ENS0_19ReflectionAllocatorIS2_EEEEE6resizeEjRKS2_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 252|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_23PxVehicleSuspensionDataENS0_15InlineAllocatorILj240ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$size);
 }
 $4 = (($this) + 244|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 248|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + (($size*48)|0)|0);
 $9 = ($7|0)<($size|0);
 if (!($9)) {
  HEAP32[$6>>2] = $size;
  STACKTOP = sp;return;
 }
 $10 = (($5) + (($7*48)|0)|0);
 $$01$i = $10;
 while(1) {
  $11 = ($$01$i|0)==(0|0);
  if (!($11)) {
   dest=$$01$i+0|0; src=$a+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $12 = (($$01$i) + 48|0);
  $13 = ($12>>>0)<($8>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$6>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK5physx36PxVehicleSuspensionDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i12 = 0, $$phi$trans$insert$i$i16 = 0, $$phi$trans$insert$i$i20 = 0, $$phi$trans$insert$i$i24 = 0, $$phi$trans$insert$i$i28 = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i32 = 0, $$phi$trans$insert$i39 = 0, $$phi$trans$insert$i46 = 0, $$phi$trans$insert$i53 = 0, $$phi$trans$insert$i60 = 0, $$phi$trans$insert$i67 = 0, $$phi$trans$insert$i74 = 0, $$phi$trans$insert81 = 0, $$phi$trans$insert84 = 0, $$phi$trans$insert87 = 0;
 var $$phi$trans$insert90 = 0, $$phi$trans$insert93 = 0, $$phi$trans$insert96 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i15 = 0, $$pre$i$i19 = 0, $$pre$i$i23 = 0, $$pre$i$i27 = 0, $$pre$i$i3 = 0, $$pre$i$i35 = 0, $$pre$i$i42 = 0, $$pre$i$i49 = 0, $$pre$i$i56 = 0, $$pre$i$i63 = 0, $$pre$i$i7 = 0, $$pre$i$i70 = 0;
 var $$pre$i$i77 = 0, $$pre$i31 = 0, $$pre$i38 = 0, $$pre$i45 = 0, $$pre$i52 = 0, $$pre$i59 = 0, $$pre$i66 = 0, $$pre$i73 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i13 = 0, $$pre1$i$i17 = 0, $$pre1$i$i21 = 0, $$pre1$i$i25 = 0, $$pre1$i$i29 = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i33 = 0, $$pre1$i40 = 0, $$pre1$i47 = 0;
 var $$pre1$i54 = 0, $$pre1$i61 = 0, $$pre1$i68 = 0, $$pre1$i75 = 0, $$pre79 = 0, $$pre80 = 0, $$pre82 = 0, $$pre83 = 0, $$pre85 = 0, $$pre86 = 0, $$pre88 = 0, $$pre89 = 0, $$pre91 = 0, $$pre92 = 0, $$pre94 = 0, $$pre95 = 0, $$pre97 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0;
 var $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i26 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i26 = sp + 8|0;
 $1 = (($this) + 36|0);
 HEAP8[$theAccessor$i26>>0] = 0;
 $2 = (($theAccessor$i26) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i26) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i38 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i39 = (($$pre$i38) + 8|0);
   $$pre1$i40 = HEAP32[$$phi$trans$insert$i39>>2]|0;
   $31 = $$pre$i38;$36 = $$pre1$i40;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i42 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i42;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj583ENS_22PxRepXPropertyAccessorILj583ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i26);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $69 = $$pre$i$i7;$71 = $$pre1$i$i9;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre79 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre79;$80 = $$pre;
 }
 $72 = (($this) + 52|0);
 HEAP8[$theAccessor$i26>>0] = 0;
 $73 = (($theAccessor$i26) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i26) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i45 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i46 = (($$pre$i45) + 8|0);
   $$pre1$i47 = HEAP32[$$phi$trans$insert$i46>>2]|0;
   $101 = $$pre$i45;$106 = $$pre1$i47;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i49 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i49;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj584ENS_22PxRepXPropertyAccessorILj584ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i26);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $147 = 0;$150 = $123;
 } else {
  $127 = (($125) + -1)|0;
  $128 = (($123) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129) + ($127<<3)|0) + 4|0);
  $131 = HEAP8[$130>>0]|0;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $139 = $123;$141 = $125;
  } else {
   $133 = (($inOperator) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = HEAP32[$134>>2]|0;
   $136 = (($135) + 20|0);
   $137 = HEAP32[$136>>2]|0;
   FUNCTION_TABLE_vi[$137 & 4095]($134);
   $$pre$i$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i12 = (($$pre$i$i11) + 8|0);
   $$pre1$i$i13 = HEAP32[$$phi$trans$insert$i$i12>>2]|0;
   $139 = $$pre$i$i11;$141 = $$pre1$i$i13;
  }
  $138 = (($139) + 8|0);
  $140 = (($141) + -1)|0;
  HEAP32[$138>>2] = $140;
  $$pre80 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert81 = (($$pre80) + 8|0);
  $$pre82 = HEAP32[$$phi$trans$insert81>>2]|0;
  $147 = $$pre82;$150 = $$pre80;
 }
 $142 = (($this) + 68|0);
 HEAP8[$theAccessor$i26>>0] = 0;
 $143 = (($theAccessor$i26) + 4|0);
 HEAP32[$143>>2] = 0;
 $144 = (($theAccessor$i26) + 8|0);
 ;HEAP32[$144+0>>2]=HEAP32[$142+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$142+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$142+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$142+12>>2]|0;
 $145 = HEAP32[$142>>2]|0;
 $146 = ($147|0)==(0);
 if ($146) {
  $171 = $150;$176 = 0;
 } else {
  $148 = (($147) + -1)|0;
  $149 = (($150) + 4|0);
  $151 = HEAP32[$149>>2]|0;
  $152 = ((($151) + ($148<<3)|0) + 4|0);
  $153 = HEAP8[$152>>0]|0;
  $154 = ($153<<24>>24)==(0);
  if ($154) {
   $155 = (($inOperator) + 4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = HEAP32[$156>>2]|0;
   $158 = (($157) + 16|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($151) + ($148<<3)|0);
   $161 = HEAP32[$160>>2]|0;
   FUNCTION_TABLE_vii[$159 & 4095]($156,$161);
   $162 = HEAP32[$inOperator>>2]|0;
   $163 = (($162) + 8|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($164) + -1)|0;
   $166 = (($162) + 4|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ((($167) + ($165<<3)|0) + 4|0);
   HEAP8[$168>>0] = 1;
   $$pre$i52 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i53 = (($$pre$i52) + 8|0);
   $$pre1$i54 = HEAP32[$$phi$trans$insert$i53>>2]|0;
   $171 = $$pre$i52;$176 = $$pre1$i54;
  } else {
   $171 = $150;$176 = $147;
  }
 }
 HEAP32[$0>>2] = $145;
 $169 = (($0) + 4|0);
 HEAP8[$169>>0] = 0;
 $170 = (($171) + 12|0);
 $172 = HEAP32[$170>>2]|0;
 $173 = $172 & 2147483647;
 $174 = (($171) + 8|0);
 $175 = ($173>>>0)>($176>>>0);
 if ($175) {
  $177 = (($171) + 4|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + ($176<<3)|0);
  $180 = ($179|0)==(0|0);
  if ($180) {
   $192 = $176;
  } else {
   $181 = $0;
   $182 = $181;
   $183 = HEAP32[$182>>2]|0;
   $184 = (($181) + 4)|0;
   $185 = $184;
   $186 = HEAP32[$185>>2]|0;
   $187 = $179;
   $188 = $187;
   HEAP32[$188>>2] = $183;
   $189 = (($187) + 4)|0;
   $190 = $189;
   HEAP32[$190>>2] = $186;
   $$pre$i$i56 = HEAP32[$174>>2]|0;
   $192 = $$pre$i$i56;
  }
  $191 = (($192) + 1)|0;
  HEAP32[$174>>2] = $191;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($171,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj585ENS_22PxRepXPropertyAccessorILj585ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i26);
 $193 = HEAP32[$inOperator>>2]|0;
 $194 = (($193) + 8|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)==(0);
 if ($196) {
  $217 = 0;$220 = $193;
 } else {
  $197 = (($195) + -1)|0;
  $198 = (($193) + 4|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ((($199) + ($197<<3)|0) + 4|0);
  $201 = HEAP8[$200>>0]|0;
  $202 = ($201<<24>>24)==(0);
  if ($202) {
   $209 = $193;$211 = $195;
  } else {
   $203 = (($inOperator) + 4|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = HEAP32[$204>>2]|0;
   $206 = (($205) + 20|0);
   $207 = HEAP32[$206>>2]|0;
   FUNCTION_TABLE_vi[$207 & 4095]($204);
   $$pre$i$i15 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i16 = (($$pre$i$i15) + 8|0);
   $$pre1$i$i17 = HEAP32[$$phi$trans$insert$i$i16>>2]|0;
   $209 = $$pre$i$i15;$211 = $$pre1$i$i17;
  }
  $208 = (($209) + 8|0);
  $210 = (($211) + -1)|0;
  HEAP32[$208>>2] = $210;
  $$pre83 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert84 = (($$pre83) + 8|0);
  $$pre85 = HEAP32[$$phi$trans$insert84>>2]|0;
  $217 = $$pre85;$220 = $$pre83;
 }
 $212 = (($this) + 84|0);
 HEAP8[$theAccessor$i26>>0] = 0;
 $213 = (($theAccessor$i26) + 4|0);
 HEAP32[$213>>2] = 0;
 $214 = (($theAccessor$i26) + 8|0);
 ;HEAP32[$214+0>>2]=HEAP32[$212+0>>2]|0;HEAP32[$214+4>>2]=HEAP32[$212+4>>2]|0;HEAP32[$214+8>>2]=HEAP32[$212+8>>2]|0;HEAP32[$214+12>>2]=HEAP32[$212+12>>2]|0;
 $215 = HEAP32[$212>>2]|0;
 $216 = ($217|0)==(0);
 if ($216) {
  $241 = $220;$246 = 0;
 } else {
  $218 = (($217) + -1)|0;
  $219 = (($220) + 4|0);
  $221 = HEAP32[$219>>2]|0;
  $222 = ((($221) + ($218<<3)|0) + 4|0);
  $223 = HEAP8[$222>>0]|0;
  $224 = ($223<<24>>24)==(0);
  if ($224) {
   $225 = (($inOperator) + 4|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = HEAP32[$226>>2]|0;
   $228 = (($227) + 16|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = (($221) + ($218<<3)|0);
   $231 = HEAP32[$230>>2]|0;
   FUNCTION_TABLE_vii[$229 & 4095]($226,$231);
   $232 = HEAP32[$inOperator>>2]|0;
   $233 = (($232) + 8|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = (($234) + -1)|0;
   $236 = (($232) + 4|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ((($237) + ($235<<3)|0) + 4|0);
   HEAP8[$238>>0] = 1;
   $$pre$i59 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i60 = (($$pre$i59) + 8|0);
   $$pre1$i61 = HEAP32[$$phi$trans$insert$i60>>2]|0;
   $241 = $$pre$i59;$246 = $$pre1$i61;
  } else {
   $241 = $220;$246 = $217;
  }
 }
 HEAP32[$0>>2] = $215;
 $239 = (($0) + 4|0);
 HEAP8[$239>>0] = 0;
 $240 = (($241) + 12|0);
 $242 = HEAP32[$240>>2]|0;
 $243 = $242 & 2147483647;
 $244 = (($241) + 8|0);
 $245 = ($243>>>0)>($246>>>0);
 if ($245) {
  $247 = (($241) + 4|0);
  $248 = HEAP32[$247>>2]|0;
  $249 = (($248) + ($246<<3)|0);
  $250 = ($249|0)==(0|0);
  if ($250) {
   $262 = $246;
  } else {
   $251 = $0;
   $252 = $251;
   $253 = HEAP32[$252>>2]|0;
   $254 = (($251) + 4)|0;
   $255 = $254;
   $256 = HEAP32[$255>>2]|0;
   $257 = $249;
   $258 = $257;
   HEAP32[$258>>2] = $253;
   $259 = (($257) + 4)|0;
   $260 = $259;
   HEAP32[$260>>2] = $256;
   $$pre$i$i63 = HEAP32[$244>>2]|0;
   $262 = $$pre$i$i63;
  }
  $261 = (($262) + 1)|0;
  HEAP32[$244>>2] = $261;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($241,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj586ENS_22PxRepXPropertyAccessorILj586ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i26);
 $263 = HEAP32[$inOperator>>2]|0;
 $264 = (($263) + 8|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = ($265|0)==(0);
 if ($266) {
  $287 = 0;$290 = $263;
 } else {
  $267 = (($265) + -1)|0;
  $268 = (($263) + 4|0);
  $269 = HEAP32[$268>>2]|0;
  $270 = ((($269) + ($267<<3)|0) + 4|0);
  $271 = HEAP8[$270>>0]|0;
  $272 = ($271<<24>>24)==(0);
  if ($272) {
   $279 = $263;$281 = $265;
  } else {
   $273 = (($inOperator) + 4|0);
   $274 = HEAP32[$273>>2]|0;
   $275 = HEAP32[$274>>2]|0;
   $276 = (($275) + 20|0);
   $277 = HEAP32[$276>>2]|0;
   FUNCTION_TABLE_vi[$277 & 4095]($274);
   $$pre$i$i19 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i20 = (($$pre$i$i19) + 8|0);
   $$pre1$i$i21 = HEAP32[$$phi$trans$insert$i$i20>>2]|0;
   $279 = $$pre$i$i19;$281 = $$pre1$i$i21;
  }
  $278 = (($279) + 8|0);
  $280 = (($281) + -1)|0;
  HEAP32[$278>>2] = $280;
  $$pre86 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert87 = (($$pre86) + 8|0);
  $$pre88 = HEAP32[$$phi$trans$insert87>>2]|0;
  $287 = $$pre88;$290 = $$pre86;
 }
 $282 = (($this) + 100|0);
 HEAP8[$theAccessor$i26>>0] = 0;
 $283 = (($theAccessor$i26) + 4|0);
 HEAP32[$283>>2] = 0;
 $284 = (($theAccessor$i26) + 8|0);
 ;HEAP32[$284+0>>2]=HEAP32[$282+0>>2]|0;HEAP32[$284+4>>2]=HEAP32[$282+4>>2]|0;HEAP32[$284+8>>2]=HEAP32[$282+8>>2]|0;HEAP32[$284+12>>2]=HEAP32[$282+12>>2]|0;
 $285 = HEAP32[$282>>2]|0;
 $286 = ($287|0)==(0);
 if ($286) {
  $311 = $290;$316 = 0;
 } else {
  $288 = (($287) + -1)|0;
  $289 = (($290) + 4|0);
  $291 = HEAP32[$289>>2]|0;
  $292 = ((($291) + ($288<<3)|0) + 4|0);
  $293 = HEAP8[$292>>0]|0;
  $294 = ($293<<24>>24)==(0);
  if ($294) {
   $295 = (($inOperator) + 4|0);
   $296 = HEAP32[$295>>2]|0;
   $297 = HEAP32[$296>>2]|0;
   $298 = (($297) + 16|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = (($291) + ($288<<3)|0);
   $301 = HEAP32[$300>>2]|0;
   FUNCTION_TABLE_vii[$299 & 4095]($296,$301);
   $302 = HEAP32[$inOperator>>2]|0;
   $303 = (($302) + 8|0);
   $304 = HEAP32[$303>>2]|0;
   $305 = (($304) + -1)|0;
   $306 = (($302) + 4|0);
   $307 = HEAP32[$306>>2]|0;
   $308 = ((($307) + ($305<<3)|0) + 4|0);
   HEAP8[$308>>0] = 1;
   $$pre$i66 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i67 = (($$pre$i66) + 8|0);
   $$pre1$i68 = HEAP32[$$phi$trans$insert$i67>>2]|0;
   $311 = $$pre$i66;$316 = $$pre1$i68;
  } else {
   $311 = $290;$316 = $287;
  }
 }
 HEAP32[$0>>2] = $285;
 $309 = (($0) + 4|0);
 HEAP8[$309>>0] = 0;
 $310 = (($311) + 12|0);
 $312 = HEAP32[$310>>2]|0;
 $313 = $312 & 2147483647;
 $314 = (($311) + 8|0);
 $315 = ($313>>>0)>($316>>>0);
 if ($315) {
  $317 = (($311) + 4|0);
  $318 = HEAP32[$317>>2]|0;
  $319 = (($318) + ($316<<3)|0);
  $320 = ($319|0)==(0|0);
  if ($320) {
   $332 = $316;
  } else {
   $321 = $0;
   $322 = $321;
   $323 = HEAP32[$322>>2]|0;
   $324 = (($321) + 4)|0;
   $325 = $324;
   $326 = HEAP32[$325>>2]|0;
   $327 = $319;
   $328 = $327;
   HEAP32[$328>>2] = $323;
   $329 = (($327) + 4)|0;
   $330 = $329;
   HEAP32[$330>>2] = $326;
   $$pre$i$i70 = HEAP32[$314>>2]|0;
   $332 = $$pre$i$i70;
  }
  $331 = (($332) + 1)|0;
  HEAP32[$314>>2] = $331;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($311,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj587ENS_22PxRepXPropertyAccessorILj587ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i26);
 $333 = HEAP32[$inOperator>>2]|0;
 $334 = (($333) + 8|0);
 $335 = HEAP32[$334>>2]|0;
 $336 = ($335|0)==(0);
 if ($336) {
  $357 = 0;$360 = $333;
 } else {
  $337 = (($335) + -1)|0;
  $338 = (($333) + 4|0);
  $339 = HEAP32[$338>>2]|0;
  $340 = ((($339) + ($337<<3)|0) + 4|0);
  $341 = HEAP8[$340>>0]|0;
  $342 = ($341<<24>>24)==(0);
  if ($342) {
   $349 = $333;$351 = $335;
  } else {
   $343 = (($inOperator) + 4|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = HEAP32[$344>>2]|0;
   $346 = (($345) + 20|0);
   $347 = HEAP32[$346>>2]|0;
   FUNCTION_TABLE_vi[$347 & 4095]($344);
   $$pre$i$i23 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i24 = (($$pre$i$i23) + 8|0);
   $$pre1$i$i25 = HEAP32[$$phi$trans$insert$i$i24>>2]|0;
   $349 = $$pre$i$i23;$351 = $$pre1$i$i25;
  }
  $348 = (($349) + 8|0);
  $350 = (($351) + -1)|0;
  HEAP32[$348>>2] = $350;
  $$pre89 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert90 = (($$pre89) + 8|0);
  $$pre91 = HEAP32[$$phi$trans$insert90>>2]|0;
  $357 = $$pre91;$360 = $$pre89;
 }
 $352 = (($this) + 116|0);
 HEAP8[$theAccessor$i26>>0] = 0;
 $353 = (($theAccessor$i26) + 4|0);
 HEAP32[$353>>2] = 0;
 $354 = (($theAccessor$i26) + 8|0);
 ;HEAP32[$354+0>>2]=HEAP32[$352+0>>2]|0;HEAP32[$354+4>>2]=HEAP32[$352+4>>2]|0;HEAP32[$354+8>>2]=HEAP32[$352+8>>2]|0;HEAP32[$354+12>>2]=HEAP32[$352+12>>2]|0;
 $355 = HEAP32[$352>>2]|0;
 $356 = ($357|0)==(0);
 if ($356) {
  $381 = $360;$386 = 0;
 } else {
  $358 = (($357) + -1)|0;
  $359 = (($360) + 4|0);
  $361 = HEAP32[$359>>2]|0;
  $362 = ((($361) + ($358<<3)|0) + 4|0);
  $363 = HEAP8[$362>>0]|0;
  $364 = ($363<<24>>24)==(0);
  if ($364) {
   $365 = (($inOperator) + 4|0);
   $366 = HEAP32[$365>>2]|0;
   $367 = HEAP32[$366>>2]|0;
   $368 = (($367) + 16|0);
   $369 = HEAP32[$368>>2]|0;
   $370 = (($361) + ($358<<3)|0);
   $371 = HEAP32[$370>>2]|0;
   FUNCTION_TABLE_vii[$369 & 4095]($366,$371);
   $372 = HEAP32[$inOperator>>2]|0;
   $373 = (($372) + 8|0);
   $374 = HEAP32[$373>>2]|0;
   $375 = (($374) + -1)|0;
   $376 = (($372) + 4|0);
   $377 = HEAP32[$376>>2]|0;
   $378 = ((($377) + ($375<<3)|0) + 4|0);
   HEAP8[$378>>0] = 1;
   $$pre$i73 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i74 = (($$pre$i73) + 8|0);
   $$pre1$i75 = HEAP32[$$phi$trans$insert$i74>>2]|0;
   $381 = $$pre$i73;$386 = $$pre1$i75;
  } else {
   $381 = $360;$386 = $357;
  }
 }
 HEAP32[$0>>2] = $355;
 $379 = (($0) + 4|0);
 HEAP8[$379>>0] = 0;
 $380 = (($381) + 12|0);
 $382 = HEAP32[$380>>2]|0;
 $383 = $382 & 2147483647;
 $384 = (($381) + 8|0);
 $385 = ($383>>>0)>($386>>>0);
 if ($385) {
  $387 = (($381) + 4|0);
  $388 = HEAP32[$387>>2]|0;
  $389 = (($388) + ($386<<3)|0);
  $390 = ($389|0)==(0|0);
  if ($390) {
   $402 = $386;
  } else {
   $391 = $0;
   $392 = $391;
   $393 = HEAP32[$392>>2]|0;
   $394 = (($391) + 4)|0;
   $395 = $394;
   $396 = HEAP32[$395>>2]|0;
   $397 = $389;
   $398 = $397;
   HEAP32[$398>>2] = $393;
   $399 = (($397) + 4)|0;
   $400 = $399;
   HEAP32[$400>>2] = $396;
   $$pre$i$i77 = HEAP32[$384>>2]|0;
   $402 = $$pre$i$i77;
  }
  $401 = (($402) + 1)|0;
  HEAP32[$384>>2] = $401;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($381,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj588ENS_22PxRepXPropertyAccessorILj588ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i26);
 $403 = HEAP32[$inOperator>>2]|0;
 $404 = (($403) + 8|0);
 $405 = HEAP32[$404>>2]|0;
 $406 = ($405|0)==(0);
 if ($406) {
  $427 = 0;$430 = $403;
 } else {
  $407 = (($405) + -1)|0;
  $408 = (($403) + 4|0);
  $409 = HEAP32[$408>>2]|0;
  $410 = ((($409) + ($407<<3)|0) + 4|0);
  $411 = HEAP8[$410>>0]|0;
  $412 = ($411<<24>>24)==(0);
  if ($412) {
   $419 = $403;$421 = $405;
  } else {
   $413 = (($inOperator) + 4|0);
   $414 = HEAP32[$413>>2]|0;
   $415 = HEAP32[$414>>2]|0;
   $416 = (($415) + 20|0);
   $417 = HEAP32[$416>>2]|0;
   FUNCTION_TABLE_vi[$417 & 4095]($414);
   $$pre$i$i27 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i28 = (($$pre$i$i27) + 8|0);
   $$pre1$i$i29 = HEAP32[$$phi$trans$insert$i$i28>>2]|0;
   $419 = $$pre$i$i27;$421 = $$pre1$i$i29;
  }
  $418 = (($419) + 8|0);
  $420 = (($421) + -1)|0;
  HEAP32[$418>>2] = $420;
  $$pre92 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert93 = (($$pre92) + 8|0);
  $$pre94 = HEAP32[$$phi$trans$insert93>>2]|0;
  $427 = $$pre94;$430 = $$pre92;
 }
 $422 = (($this) + 132|0);
 HEAP8[$theAccessor$i26>>0] = 0;
 $423 = (($theAccessor$i26) + 4|0);
 HEAP32[$423>>2] = 0;
 $424 = (($theAccessor$i26) + 8|0);
 ;HEAP32[$424+0>>2]=HEAP32[$422+0>>2]|0;HEAP32[$424+4>>2]=HEAP32[$422+4>>2]|0;HEAP32[$424+8>>2]=HEAP32[$422+8>>2]|0;HEAP32[$424+12>>2]=HEAP32[$422+12>>2]|0;
 $425 = HEAP32[$422>>2]|0;
 $426 = ($427|0)==(0);
 do {
  if ($426) {
   $451 = $430;$456 = 0;
  } else {
   $428 = (($427) + -1)|0;
   $429 = (($430) + 4|0);
   $431 = HEAP32[$429>>2]|0;
   $432 = ((($431) + ($428<<3)|0) + 4|0);
   $433 = HEAP8[$432>>0]|0;
   $434 = ($433<<24>>24)==(0);
   if (!($434)) {
    $451 = $430;$456 = $427;
    break;
   }
   $435 = (($inOperator) + 4|0);
   $436 = HEAP32[$435>>2]|0;
   $437 = HEAP32[$436>>2]|0;
   $438 = (($437) + 16|0);
   $439 = HEAP32[$438>>2]|0;
   $440 = (($431) + ($428<<3)|0);
   $441 = HEAP32[$440>>2]|0;
   FUNCTION_TABLE_vii[$439 & 4095]($436,$441);
   $442 = HEAP32[$inOperator>>2]|0;
   $443 = (($442) + 8|0);
   $444 = HEAP32[$443>>2]|0;
   $445 = (($444) + -1)|0;
   $446 = (($442) + 4|0);
   $447 = HEAP32[$446>>2]|0;
   $448 = ((($447) + ($445<<3)|0) + 4|0);
   HEAP8[$448>>0] = 1;
   $$pre$i31 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i32 = (($$pre$i31) + 8|0);
   $$pre1$i33 = HEAP32[$$phi$trans$insert$i32>>2]|0;
   $451 = $$pre$i31;$456 = $$pre1$i33;
  }
 } while(0);
 HEAP32[$0>>2] = $425;
 $449 = (($0) + 4|0);
 HEAP8[$449>>0] = 0;
 $450 = (($451) + 12|0);
 $452 = HEAP32[$450>>2]|0;
 $453 = $452 & 2147483647;
 $454 = (($451) + 8|0);
 $455 = ($453>>>0)>($456>>>0);
 if ($455) {
  $457 = (($451) + 4|0);
  $458 = HEAP32[$457>>2]|0;
  $459 = (($458) + ($456<<3)|0);
  $460 = ($459|0)==(0|0);
  if ($460) {
   $472 = $456;
  } else {
   $461 = $0;
   $462 = $461;
   $463 = HEAP32[$462>>2]|0;
   $464 = (($461) + 4)|0;
   $465 = $464;
   $466 = HEAP32[$465>>2]|0;
   $467 = $459;
   $468 = $467;
   HEAP32[$468>>2] = $463;
   $469 = (($467) + 4)|0;
   $470 = $469;
   HEAP32[$470>>2] = $466;
   $$pre$i$i35 = HEAP32[$454>>2]|0;
   $472 = $$pre$i$i35;
  }
  $471 = (($472) + 1)|0;
  HEAP32[$454>>2] = $471;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($451,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj589ENS_22PxRepXPropertyAccessorILj589ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i26);
 $473 = HEAP32[$inOperator>>2]|0;
 $474 = (($473) + 8|0);
 $475 = HEAP32[$474>>2]|0;
 $476 = ($475|0)==(0);
 if ($476) {
  $497 = 0;$500 = $473;
 } else {
  $477 = (($475) + -1)|0;
  $478 = (($473) + 4|0);
  $479 = HEAP32[$478>>2]|0;
  $480 = ((($479) + ($477<<3)|0) + 4|0);
  $481 = HEAP8[$480>>0]|0;
  $482 = ($481<<24>>24)==(0);
  if ($482) {
   $489 = $473;$491 = $475;
  } else {
   $483 = (($inOperator) + 4|0);
   $484 = HEAP32[$483>>2]|0;
   $485 = HEAP32[$484>>2]|0;
   $486 = (($485) + 20|0);
   $487 = HEAP32[$486>>2]|0;
   FUNCTION_TABLE_vi[$487 & 4095]($484);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $489 = $$pre$i$i3;$491 = $$pre1$i$i5;
  }
  $488 = (($489) + 8|0);
  $490 = (($491) + -1)|0;
  HEAP32[$488>>2] = $490;
  $$pre95 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert96 = (($$pre95) + 8|0);
  $$pre97 = HEAP32[$$phi$trans$insert96>>2]|0;
  $497 = $$pre97;$500 = $$pre95;
 }
 $492 = (($this) + 148|0);
 HEAP8[$theAccessor$i26>>0] = 0;
 $493 = (($theAccessor$i26) + 4|0);
 HEAP32[$493>>2] = 0;
 $494 = (($theAccessor$i26) + 8|0);
 ;HEAP32[$494+0>>2]=HEAP32[$492+0>>2]|0;HEAP32[$494+4>>2]=HEAP32[$492+4>>2]|0;HEAP32[$494+8>>2]=HEAP32[$492+8>>2]|0;HEAP32[$494+12>>2]=HEAP32[$492+12>>2]|0;
 $495 = HEAP32[$492>>2]|0;
 $496 = ($497|0)==(0);
 do {
  if ($496) {
   $521 = $500;$526 = 0;
  } else {
   $498 = (($497) + -1)|0;
   $499 = (($500) + 4|0);
   $501 = HEAP32[$499>>2]|0;
   $502 = ((($501) + ($498<<3)|0) + 4|0);
   $503 = HEAP8[$502>>0]|0;
   $504 = ($503<<24>>24)==(0);
   if (!($504)) {
    $521 = $500;$526 = $497;
    break;
   }
   $505 = (($inOperator) + 4|0);
   $506 = HEAP32[$505>>2]|0;
   $507 = HEAP32[$506>>2]|0;
   $508 = (($507) + 16|0);
   $509 = HEAP32[$508>>2]|0;
   $510 = (($501) + ($498<<3)|0);
   $511 = HEAP32[$510>>2]|0;
   FUNCTION_TABLE_vii[$509 & 4095]($506,$511);
   $512 = HEAP32[$inOperator>>2]|0;
   $513 = (($512) + 8|0);
   $514 = HEAP32[$513>>2]|0;
   $515 = (($514) + -1)|0;
   $516 = (($512) + 4|0);
   $517 = HEAP32[$516>>2]|0;
   $518 = ((($517) + ($515<<3)|0) + 4|0);
   HEAP8[$518>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $521 = $$pre$i;$526 = $$pre1$i;
  }
 } while(0);
 HEAP32[$0>>2] = $495;
 $519 = (($0) + 4|0);
 HEAP8[$519>>0] = 0;
 $520 = (($521) + 12|0);
 $522 = HEAP32[$520>>2]|0;
 $523 = $522 & 2147483647;
 $524 = (($521) + 8|0);
 $525 = ($523>>>0)>($526>>>0);
 if ($525) {
  $527 = (($521) + 4|0);
  $528 = HEAP32[$527>>2]|0;
  $529 = (($528) + ($526<<3)|0);
  $530 = ($529|0)==(0|0);
  if ($530) {
   $542 = $526;
  } else {
   $531 = $0;
   $532 = $531;
   $533 = HEAP32[$532>>2]|0;
   $534 = (($531) + 4)|0;
   $535 = $534;
   $536 = HEAP32[$535>>2]|0;
   $537 = $529;
   $538 = $537;
   HEAP32[$538>>2] = $533;
   $539 = (($537) + 4)|0;
   $540 = $539;
   HEAP32[$540>>2] = $536;
   $$pre$i$i1 = HEAP32[$524>>2]|0;
   $542 = $$pre$i$i1;
  }
  $541 = (($542) + 1)|0;
  HEAP32[$524>>2] = $541;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($521,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj590ENS_22PxRepXPropertyAccessorILj590ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i26);
 $543 = HEAP32[$inOperator>>2]|0;
 $544 = (($543) + 8|0);
 $545 = HEAP32[$544>>2]|0;
 $546 = ($545|0)==(0);
 if ($546) {
  $562 = (($inStartIndex) + 11)|0;
  STACKTOP = sp;return ($562|0);
 }
 $547 = (($545) + -1)|0;
 $548 = (($543) + 4|0);
 $549 = HEAP32[$548>>2]|0;
 $550 = ((($549) + ($547<<3)|0) + 4|0);
 $551 = HEAP8[$550>>0]|0;
 $552 = ($551<<24>>24)==(0);
 if ($552) {
  $559 = $543;$561 = $545;
 } else {
  $553 = (($inOperator) + 4|0);
  $554 = HEAP32[$553>>2]|0;
  $555 = HEAP32[$554>>2]|0;
  $556 = (($555) + 20|0);
  $557 = HEAP32[$556>>2]|0;
  FUNCTION_TABLE_vi[$557 & 4095]($554);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $559 = $$pre$i$i;$561 = $$pre1$i$i;
 }
 $558 = (($559) + 8|0);
 $560 = (($561) + -1)|0;
 HEAP32[$558>>2] = $560;
 $562 = (($inStartIndex) + 11)|0;
 STACKTOP = sp;return ($562|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj590ENS_22PxRepXPropertyAccessorILj590ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 36;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 36)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj589ENS_22PxRepXPropertyAccessorILj589ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 32;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 32)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj588ENS_22PxRepXPropertyAccessorILj588ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 28;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj587ENS_22PxRepXPropertyAccessorILj587ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 24;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 24)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj586ENS_22PxRepXPropertyAccessorILj586ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 20;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 20)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj585ENS_22PxRepXPropertyAccessorILj585ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 16;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 16)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj584ENS_22PxRepXPropertyAccessorILj584ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 12;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleSuspensionDataEEEE14handleAccessorILj583ENS_22PxRepXPropertyAccessorILj583ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_23PxVehicleSuspensionDataENS0_15InlineAllocatorILj240ENS0_19ReflectionAllocatorIS2_EEEEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $20 = 0;
 } else {
  $1 = ($capacity*48)|0;
  $2 = (($this) + 240|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $5 = ($1>>>0)<(241);
  $or$cond$i$i = $4 & $5;
  if ($or$cond$i$i) {
   HEAP8[$2>>0] = 1;
   $$0$i$i = $this;
  } else {
   $6 = ($1|0)==(0);
   if ($6) {
    $$0$i$i = 0;
   } else {
    $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__Z15PxGetFoundationv()|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
    $$$i$i$i$i = $15 ? 522320 : 521616;
    $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$1,$$$i$i$i$i,521536,558)|0);
    $$0$i$i = $16;
   }
  }
  $20 = $$0$i$i;
 }
 $17 = (($this) + 248|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($20) + (($18*48)|0)|0);
 $21 = (($this) + 244|0);
 $22 = ($18|0)>(0);
 if ($22) {
  $23 = HEAP32[$21>>2]|0;
  $$012$i = $20;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    dest=$$012$i+0|0; src=$$03$i+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $25 = (($$012$i) + 48|0);
   $26 = (($$03$i) + 48|0);
   $27 = ($25>>>0)<($19>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
 }
 $28 = (($this) + 252|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)>(-1);
 if (!($30)) {
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$21>>2]|0;
 $32 = ($this|0)==($31|0);
 if ($32) {
  $33 = (($this) + 240|0);
  HEAP8[$33>>0] = 0;
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $34 = ($31|0)==(0|0);
 if ($34) {
  HEAP32[$21>>2] = $20;
  HEAP32[$28>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($35,$31);
 HEAP32[$21>>2] = $20;
 HEAP32[$28>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn18writeAllPropertiesINS_16PxVehicleDriveNWEEEvRNS_7profile12ProfileArrayINS0_14NameStackEntryEEEPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($inNameStack,$inObj,$writer,$buffer,$collection) {
 $inNameStack = $inNameStack|0;
 $inObj = $inObj|0;
 $writer = $writer|0;
 $buffer = $buffer|0;
 $collection = $collection|0;
 var $$pre$i$i = 0, $$pre1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $info = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp;
 $1 = sp + 180|0;
 $info = sp + 28|0;
 $2 = sp + 152|0;
 __ZN5physx29PxVehicleDriveNWGeneratedInfoC2Ev($info);
 HEAP32[$0>>2] = $inNameStack;
 $3 = (($0) + 4|0);
 HEAP32[$3>>2] = $writer;
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $inObj;
 $5 = (($0) + 12|0);
 HEAP32[$5>>2] = $buffer;
 $6 = (($0) + 16|0);
 HEAP32[$6>>2] = $collection;
 $7 = (($0) + 20|0);
 HEAP32[$7>>2] = 0;
 $8 = (($0) + 24|0);
 HEAP32[$8>>2] = 0;
 $9 = (__ZNK5physx28PxVehicleWheelsGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEEEEEjT_j($info,$0,0)|0);
 HEAP32[$1>>2] = $inNameStack;
 $10 = (($1) + 4|0);
 HEAP32[$10>>2] = $writer;
 $11 = (($1) + 8|0);
 HEAP32[$11>>2] = $inObj;
 $12 = (($1) + 12|0);
 HEAP32[$12>>2] = $buffer;
 $13 = (($1) + 16|0);
 HEAP32[$13>>2] = $collection;
 $14 = (($1) + 20|0);
 HEAP32[$14>>2] = 0;
 $15 = (($1) + 24|0);
 HEAP32[$15>>2] = 0;
 (__ZNK5physx27PxVehicleDriveGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEEEEEjT_j($info,$1,$9)|0);
 HEAP32[$2>>2] = $inNameStack;
 $16 = (($2) + 4|0);
 HEAP32[$16>>2] = $writer;
 $17 = (($2) + 8|0);
 HEAP32[$17>>2] = $inObj;
 $18 = (($2) + 12|0);
 HEAP32[$18>>2] = $buffer;
 $19 = (($2) + 16|0);
 HEAP32[$19>>2] = $collection;
 $20 = (($2) + 20|0);
 HEAP32[$20>>2] = 0;
 $21 = (($2) + 24|0);
 HEAP32[$21>>2] = 0;
 $22 = (($info) + 108|0);
 HEAP8[$1>>0] = 0;
 $23 = (($1) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = (($1) + 8|0);
 ;HEAP32[$24+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$22+12>>2]|0;
 $25 = HEAP32[$22>>2]|0;
 $26 = (($inNameStack) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  $49 = 0;
 } else {
  $29 = (($27) + -1)|0;
  $30 = (($inNameStack) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($31) + ($29<<3)|0) + 4|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   $35 = HEAP32[$writer>>2]|0;
   $36 = (($35) + 16|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($31) + ($29<<3)|0);
   $39 = HEAP32[$38>>2]|0;
   FUNCTION_TABLE_vii[$37 & 4095]($writer,$39);
   $40 = HEAP32[$26>>2]|0;
   $41 = (($40) + -1)|0;
   $42 = HEAP32[$30>>2]|0;
   $43 = ((($42) + ($41<<3)|0) + 4|0);
   HEAP8[$43>>0] = 1;
   $49 = $40;
  } else {
   $49 = $27;
  }
 }
 HEAP32[$0>>2] = $25;
 $44 = (($0) + 4|0);
 HEAP8[$44>>0] = 0;
 $45 = (($inNameStack) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 & 2147483647;
 $48 = ($47>>>0)>($49>>>0);
 if ($48) {
  $50 = (($inNameStack) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + ($49<<3)|0);
  $53 = ($52|0)==(0|0);
  if ($53) {
   $65 = $49;
  } else {
   $54 = $0;
   $55 = $54;
   $56 = HEAP32[$55>>2]|0;
   $57 = (($54) + 4)|0;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = $52;
   $61 = $60;
   HEAP32[$61>>2] = $56;
   $62 = (($60) + 4)|0;
   $63 = $62;
   HEAP32[$63>>2] = $59;
   $$pre$i$i = HEAP32[$26>>2]|0;
   $65 = $$pre$i$i;
  }
  $64 = (($65) + 1)|0;
  HEAP32[$26>>2] = $64;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($inNameStack,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEE14handleAccessorILj682ENS_22PxRepXPropertyAccessorILj682ES4_NS_23PxVehicleDriveSimDataNWES9_EEEEvRKT0_($2,$1);
 $66 = HEAP32[$2>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0);
 if ($69) {
  STACKTOP = sp;return;
 }
 $70 = (($68) + -1)|0;
 $71 = (($66) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($72) + ($70<<3)|0) + 4|0);
 $74 = HEAP8[$73>>0]|0;
 $75 = ($74<<24>>24)==(0);
 if ($75) {
  $81 = $68;
 } else {
  $76 = HEAP32[$16>>2]|0;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($77) + 20|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_vi[$79 & 4095]($76);
  $$pre1$i$i$i = HEAP32[$67>>2]|0;
  $81 = $$pre1$i$i$i;
 }
 $80 = (($81) + -1)|0;
 HEAP32[$67>>2] = $80;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEE14handleAccessorILj682ENS_22PxRepXPropertyAccessorILj682ES4_NS_23PxVehicleDriveSimDataNWES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 768|0;
 $0 = sp + 736|0;
 $info$i$i$i$i$i = sp;
 $1 = sp + 80|0;
 $propVal$i$i$i = sp + 112|0;
 $2 = sp + 656|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0$i = 212;
 } else {
  $6 = HEAP32[$4>>2]|0;
  $7 = (($6) + 212)|0;
  $$0$i = $7;
 }
 HEAP8[$inAccessor>>0] = 1;
 $8 = (($inAccessor) + 4|0);
 HEAP32[$8>>2] = $$0$i;
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
 }
 dest=$2+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx36PxVehicleDriveSimDataNWGeneratedInfoC2Ev($2);
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($inAccessor) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($propVal$i$i$i,$15);
 $18 = HEAP32[$this>>2]|0;
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx36PxVehicleDriveSimDataNWGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $18;
 $25 = (($0) + 4|0);
 HEAP32[$25>>2] = $20;
 $26 = (($0) + 8|0);
 HEAP32[$26>>2] = $propVal$i$i$i;
 $27 = (($0) + 12|0);
 HEAP32[$27>>2] = $22;
 $28 = (($0) + 16|0);
 HEAP32[$28>>2] = $24;
 $29 = (($0) + 20|0);
 HEAP32[$29>>2] = 0;
 $30 = (($0) + 24|0);
 HEAP32[$30>>2] = 0;
 (__ZNK5physx34PxVehicleDriveSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 HEAP32[$1>>2] = $18;
 $31 = (($1) + 4|0);
 HEAP32[$31>>2] = $20;
 $32 = (($1) + 8|0);
 HEAP32[$32>>2] = $propVal$i$i$i;
 $33 = (($1) + 12|0);
 HEAP32[$33>>2] = $22;
 $34 = (($1) + 16|0);
 HEAP32[$34>>2] = $24;
 $35 = (($1) + 20|0);
 HEAP32[$35>>2] = 0;
 $36 = (($1) + 24|0);
 HEAP32[$36>>2] = 0;
 (__ZNK5physx36PxVehicleDriveSimDataNWGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEEEEEjT_j($info$i$i$i$i$i,$1,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx36PxVehicleDriveSimDataNWGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = (($this) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$inOperator>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $32 = $6;$37 = 0;
 } else {
  $10 = (($8) + -1)|0;
  $11 = (($6) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12) + ($10<<3)|0) + 4|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $16 = (($inOperator) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($12) + ($10<<3)|0);
   $22 = HEAP32[$21>>2]|0;
   FUNCTION_TABLE_vii[$20 & 4095]($17,$22);
   $23 = HEAP32[$inOperator>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + -1)|0;
   $27 = (($23) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ((($28) + ($26<<3)|0) + 4|0);
   HEAP8[$29>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $32 = $$pre$i;$37 = $$pre1$i;
  } else {
   $32 = $6;$37 = $8;
  }
 }
 HEAP32[$0>>2] = $5;
 $30 = (($0) + 4|0);
 HEAP8[$30>>0] = 0;
 $31 = (($32) + 12|0);
 $33 = HEAP32[$31>>2]|0;
 $34 = $33 & 2147483647;
 $35 = (($32) + 8|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  $38 = (($32) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + ($37<<3)|0);
  $41 = ($40|0)==(0|0);
  if ($41) {
   $53 = $37;
  } else {
   $42 = $0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = (($42) + 4)|0;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = $40;
   $49 = $48;
   HEAP32[$49>>2] = $44;
   $50 = (($48) + 4)|0;
   $51 = $50;
   HEAP32[$51>>2] = $47;
   $$pre$i$i1 = HEAP32[$35>>2]|0;
   $53 = $$pre$i$i1;
  }
  $52 = (($53) + 1)|0;
  HEAP32[$35>>2] = $52;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($32,$0)|0);
 }
 $54 = (($inOperator) + 20|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = HEAP32[$55>>2]|0;
  $58 = (($57) + 1)|0;
  HEAP32[$55>>2] = $58;
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 __ZN5physx40PxVehicleDifferentialNWDataGeneratedInfoC2Ev($1);
 $59 = (($inOperator) + 8|0);
 $60 = HEAP32[$59>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$60);
 $61 = HEAP32[$inOperator>>2]|0;
 $62 = (($inOperator) + 4|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($inOperator) + 12|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($inOperator) + 16|0);
 $67 = HEAP32[$66>>2]|0;
 __ZN5physx2Sn18writeAllPropertiesINS_27PxVehicleDifferentialNWDataEEEvRNS_7profile12ProfileArrayINS0_14NameStackEntryEEEPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($61,$0,$63,$65,$67);
 $68 = HEAP32[$inOperator>>2]|0;
 $69 = (($68) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(0);
 if ($71) {
  $86 = (($inStartIndex) + 1)|0;
  STACKTOP = sp;return ($86|0);
 }
 $72 = (($70) + -1)|0;
 $73 = (($68) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ((($74) + ($72<<3)|0) + 4|0);
 $76 = HEAP8[$75>>0]|0;
 $77 = ($76<<24>>24)==(0);
 if ($77) {
  $83 = $68;$85 = $70;
 } else {
  $78 = HEAP32[$62>>2]|0;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($79) + 20|0);
  $81 = HEAP32[$80>>2]|0;
  FUNCTION_TABLE_vi[$81 & 4095]($78);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $83 = $$pre$i$i;$85 = $$pre1$i$i;
 }
 $82 = (($83) + 8|0);
 $84 = (($85) + -1)|0;
 HEAP32[$82>>2] = $84;
 $86 = (($inStartIndex) + 1)|0;
 STACKTOP = sp;return ($86|0);
}
function __ZN5physx2Sn18writeAllPropertiesINS_27PxVehicleDifferentialNWDataEEEvRNS_7profile12ProfileArrayINS0_14NameStackEntryEEEPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($inNameStack,$inObj,$writer,$buffer,$collection) {
 $inNameStack = $inNameStack|0;
 $inObj = $inObj|0;
 $writer = $writer|0;
 $buffer = $buffer|0;
 $collection = $collection|0;
 var $$pre$i$i = 0, $$pre1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $info = 0, $theAccessor$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp;
 $theAccessor$i$i = sp + 56|0;
 $info = sp + 8|0;
 $1 = sp + 24|0;
 __ZN5physx40PxVehicleDifferentialNWDataGeneratedInfoC2Ev($info);
 HEAP32[$1>>2] = $inNameStack;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = $writer;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = $inObj;
 $4 = (($1) + 12|0);
 HEAP32[$4>>2] = $buffer;
 $5 = (($1) + 16|0);
 HEAP32[$5>>2] = $collection;
 $6 = (($1) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($1) + 24|0);
 HEAP32[$7>>2] = 0;
 HEAP8[$theAccessor$i$i>>0] = 0;
 $8 = (($theAccessor$i$i) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($theAccessor$i$i) + 8|0);
 ;HEAP32[$9+0>>2]=HEAP32[$info+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$info+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$info+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$info+12>>2]|0;
 $10 = HEAP32[$info>>2]|0;
 $11 = (($inNameStack) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  $34 = 0;
 } else {
  $14 = (($12) + -1)|0;
  $15 = (($inNameStack) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16) + ($14<<3)|0) + 4|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $20 = HEAP32[$writer>>2]|0;
   $21 = (($20) + 16|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($16) + ($14<<3)|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_vii[$22 & 4095]($writer,$24);
   $25 = HEAP32[$11>>2]|0;
   $26 = (($25) + -1)|0;
   $27 = HEAP32[$15>>2]|0;
   $28 = ((($27) + ($26<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $34 = $25;
  } else {
   $34 = $12;
  }
 }
 HEAP32[$0>>2] = $10;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($inNameStack) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 & 2147483647;
 $33 = ($32>>>0)>($34>>>0);
 if ($33) {
  $35 = (($inNameStack) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($34<<3)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   $50 = $34;
  } else {
   $39 = $0;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 4)|0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = $37;
   $46 = $45;
   HEAP32[$46>>2] = $41;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $44;
   $$pre$i$i = HEAP32[$11>>2]|0;
   $50 = $$pre$i$i;
  }
  $49 = (($50) + 1)|0;
  HEAP32[$11>>2] = $49;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($inNameStack,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferentialNWDataEEEE14handleAccessorILj546ENS_22PxRepXPropertyAccessorILj546ES4_jjEEEEvRKT0_($1,$theAccessor$i$i);
 $51 = HEAP32[$1>>2]|0;
 $52 = (($51) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0);
 if ($54) {
  STACKTOP = sp;return;
 }
 $55 = (($53) + -1)|0;
 $56 = (($51) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ((($57) + ($55<<3)|0) + 4|0);
 $59 = HEAP8[$58>>0]|0;
 $60 = ($59<<24>>24)==(0);
 if ($60) {
  $66 = $53;
 } else {
  $61 = HEAP32[$2>>2]|0;
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + 20|0);
  $64 = HEAP32[$63>>2]|0;
  FUNCTION_TABLE_vi[$64 & 4095]($61);
  $$pre1$i$i$i = HEAP32[$52>>2]|0;
  $66 = $$pre1$i$i$i;
 }
 $65 = (($66) + -1)|0;
 HEAP32[$52>>2] = $65;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferentialNWDataEEEE14handleAccessorILj546ENS_22PxRepXPropertyAccessorILj546ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $$0$i = $3;
 }
 HEAP8[$inAccessor>>0] = 1;
 $4 = (($inAccessor) + 4|0);
 HEAP32[$4>>2] = $$0$i;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$6>>2] = $9;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($inAccessor) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 4095]($11)|0);
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i = 521512;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i = $27;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $14;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $28 = HEAP8[$buffer$i$i$i>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  $30 = HEAP32[$18>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$31 & 2047]($18,$buffer$i$i$i,$32)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $33 = HEAP32[$18>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 (FUNCTION_TABLE_iiii[$34 & 2047]($18,$vararg_buffer,1)|0);
 $35 = HEAP32[$16>>2]|0;
 $36 = (($35) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($18) + 20|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_viii[$37 & 4095]($16,$$0$i$i$i$i,$39);
 $40 = (($18) + 16|0);
 HEAP32[$40>>2] = 0;
 $41 = (($18) + 12|0);
 HEAP32[$41>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx34PxVehicleDriveSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i12 = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i16 = 0, $$phi$trans$insert$i23 = 0, $$phi$trans$insert$i30 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert40 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i19 = 0, $$pre$i$i26 = 0, $$pre$i$i3 = 0, $$pre$i$i33 = 0;
 var $$pre$i$i7 = 0, $$pre$i15 = 0, $$pre$i22 = 0, $$pre$i29 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i13 = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i17 = 0, $$pre1$i24 = 0, $$pre1$i31 = 0, $$pre35 = 0, $$pre36 = 0, $$pre38 = 0, $$pre39 = 0, $$pre41 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $theAccessor$i10 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i10 = sp + 8|0;
 HEAP8[$theAccessor$i10>>0] = 0;
 $1 = (($theAccessor$i10) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$this+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$this+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$this+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$this+12>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i15 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i16 = (($$pre$i15) + 8|0);
   $$pre1$i17 = HEAP32[$$phi$trans$insert$i16>>2]|0;
   $30 = $$pre$i15;$35 = $$pre1$i17;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i19 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i19;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj655ENS_22PxRepXPropertyAccessorILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataESA_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $52 = HEAP32[$inOperator>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $76 = 0;$79 = $52;
 } else {
  $56 = (($54) + -1)|0;
  $57 = (($52) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58) + ($56<<3)|0) + 4|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $68 = $52;$70 = $54;
  } else {
   $62 = (($inOperator) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vi[$66 & 4095]($63);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $68 = $$pre$i$i3;$70 = $$pre1$i$i5;
  }
  $67 = (($68) + 8|0);
  $69 = (($70) + -1)|0;
  HEAP32[$67>>2] = $69;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre35 = HEAP32[$$phi$trans$insert>>2]|0;
  $76 = $$pre35;$79 = $$pre;
 }
 $71 = (($this) + 16|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $72 = (($theAccessor$i10) + 4|0);
 HEAP32[$72>>2] = 0;
 $73 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$73+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$71+12>>2]|0;
 $74 = HEAP32[$71>>2]|0;
 $75 = ($76|0)==(0);
 if ($75) {
  $100 = $79;$105 = 0;
 } else {
  $77 = (($76) + -1)|0;
  $78 = (($79) + 4|0);
  $80 = HEAP32[$78>>2]|0;
  $81 = ((($80) + ($77<<3)|0) + 4|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = ($82<<24>>24)==(0);
  if ($83) {
   $84 = (($inOperator) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 16|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($80) + ($77<<3)|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_vii[$88 & 4095]($85,$90);
   $91 = HEAP32[$inOperator>>2]|0;
   $92 = (($91) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + -1)|0;
   $95 = (($91) + 4|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ((($96) + ($94<<3)|0) + 4|0);
   HEAP8[$97>>0] = 1;
   $$pre$i22 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i23 = (($$pre$i22) + 8|0);
   $$pre1$i24 = HEAP32[$$phi$trans$insert$i23>>2]|0;
   $100 = $$pre$i22;$105 = $$pre1$i24;
  } else {
   $100 = $79;$105 = $76;
  }
 }
 HEAP32[$0>>2] = $74;
 $98 = (($0) + 4|0);
 HEAP8[$98>>0] = 0;
 $99 = (($100) + 12|0);
 $101 = HEAP32[$99>>2]|0;
 $102 = $101 & 2147483647;
 $103 = (($100) + 8|0);
 $104 = ($102>>>0)>($105>>>0);
 if ($104) {
  $106 = (($100) + 4|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($107) + ($105<<3)|0);
  $109 = ($108|0)==(0|0);
  if ($109) {
   $121 = $105;
  } else {
   $110 = $0;
   $111 = $110;
   $112 = HEAP32[$111>>2]|0;
   $113 = (($110) + 4)|0;
   $114 = $113;
   $115 = HEAP32[$114>>2]|0;
   $116 = $108;
   $117 = $116;
   HEAP32[$117>>2] = $112;
   $118 = (($116) + 4)|0;
   $119 = $118;
   HEAP32[$119>>2] = $115;
   $$pre$i$i26 = HEAP32[$103>>2]|0;
   $121 = $$pre$i$i26;
  }
  $120 = (($121) + 1)|0;
  HEAP32[$103>>2] = $120;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($100,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataESA_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $122 = HEAP32[$inOperator>>2]|0;
 $123 = (($122) + 8|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($124|0)==(0);
 if ($125) {
  $146 = 0;$149 = $122;
 } else {
  $126 = (($124) + -1)|0;
  $127 = (($122) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ((($128) + ($126<<3)|0) + 4|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = ($130<<24>>24)==(0);
  if ($131) {
   $138 = $122;$140 = $124;
  } else {
   $132 = (($inOperator) + 4|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 20|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_vi[$136 & 4095]($133);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $138 = $$pre$i$i7;$140 = $$pre1$i$i9;
  }
  $137 = (($138) + 8|0);
  $139 = (($140) + -1)|0;
  HEAP32[$137>>2] = $139;
  $$pre36 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert37 = (($$pre36) + 8|0);
  $$pre38 = HEAP32[$$phi$trans$insert37>>2]|0;
  $146 = $$pre38;$149 = $$pre36;
 }
 $141 = (($this) + 32|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $142 = (($theAccessor$i10) + 4|0);
 HEAP32[$142>>2] = 0;
 $143 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$143+0>>2]=HEAP32[$141+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$141+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$141+8>>2]|0;HEAP32[$143+12>>2]=HEAP32[$141+12>>2]|0;
 $144 = HEAP32[$141>>2]|0;
 $145 = ($146|0)==(0);
 if ($145) {
  $170 = $149;$175 = 0;
 } else {
  $147 = (($146) + -1)|0;
  $148 = (($149) + 4|0);
  $150 = HEAP32[$148>>2]|0;
  $151 = ((($150) + ($147<<3)|0) + 4|0);
  $152 = HEAP8[$151>>0]|0;
  $153 = ($152<<24>>24)==(0);
  if ($153) {
   $154 = (($inOperator) + 4|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = HEAP32[$155>>2]|0;
   $157 = (($156) + 16|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($150) + ($147<<3)|0);
   $160 = HEAP32[$159>>2]|0;
   FUNCTION_TABLE_vii[$158 & 4095]($155,$160);
   $161 = HEAP32[$inOperator>>2]|0;
   $162 = (($161) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = (($163) + -1)|0;
   $165 = (($161) + 4|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ((($166) + ($164<<3)|0) + 4|0);
   HEAP8[$167>>0] = 1;
   $$pre$i29 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i30 = (($$pre$i29) + 8|0);
   $$pre1$i31 = HEAP32[$$phi$trans$insert$i30>>2]|0;
   $170 = $$pre$i29;$175 = $$pre1$i31;
  } else {
   $170 = $149;$175 = $146;
  }
 }
 HEAP32[$0>>2] = $144;
 $168 = (($0) + 4|0);
 HEAP8[$168>>0] = 0;
 $169 = (($170) + 12|0);
 $171 = HEAP32[$169>>2]|0;
 $172 = $171 & 2147483647;
 $173 = (($170) + 8|0);
 $174 = ($172>>>0)>($175>>>0);
 if ($174) {
  $176 = (($170) + 4|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($177) + ($175<<3)|0);
  $179 = ($178|0)==(0|0);
  if ($179) {
   $191 = $175;
  } else {
   $180 = $0;
   $181 = $180;
   $182 = HEAP32[$181>>2]|0;
   $183 = (($180) + 4)|0;
   $184 = $183;
   $185 = HEAP32[$184>>2]|0;
   $186 = $178;
   $187 = $186;
   HEAP32[$187>>2] = $182;
   $188 = (($186) + 4)|0;
   $189 = $188;
   HEAP32[$189>>2] = $185;
   $$pre$i$i33 = HEAP32[$173>>2]|0;
   $191 = $$pre$i$i33;
  }
  $190 = (($191) + 1)|0;
  HEAP32[$173>>2] = $190;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($170,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataESA_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $192 = HEAP32[$inOperator>>2]|0;
 $193 = (($192) + 8|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194|0)==(0);
 if ($195) {
  $216 = 0;$219 = $192;
 } else {
  $196 = (($194) + -1)|0;
  $197 = (($192) + 4|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ((($198) + ($196<<3)|0) + 4|0);
  $200 = HEAP8[$199>>0]|0;
  $201 = ($200<<24>>24)==(0);
  if ($201) {
   $208 = $192;$210 = $194;
  } else {
   $202 = (($inOperator) + 4|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = HEAP32[$203>>2]|0;
   $205 = (($204) + 20|0);
   $206 = HEAP32[$205>>2]|0;
   FUNCTION_TABLE_vi[$206 & 4095]($203);
   $$pre$i$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i12 = (($$pre$i$i11) + 8|0);
   $$pre1$i$i13 = HEAP32[$$phi$trans$insert$i$i12>>2]|0;
   $208 = $$pre$i$i11;$210 = $$pre1$i$i13;
  }
  $207 = (($208) + 8|0);
  $209 = (($210) + -1)|0;
  HEAP32[$207>>2] = $209;
  $$pre39 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert40 = (($$pre39) + 8|0);
  $$pre41 = HEAP32[$$phi$trans$insert40>>2]|0;
  $216 = $$pre41;$219 = $$pre39;
 }
 $211 = (($this) + 48|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $212 = (($theAccessor$i10) + 4|0);
 HEAP32[$212>>2] = 0;
 $213 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$213+0>>2]=HEAP32[$211+0>>2]|0;HEAP32[$213+4>>2]=HEAP32[$211+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$211+8>>2]|0;HEAP32[$213+12>>2]=HEAP32[$211+12>>2]|0;
 $214 = HEAP32[$211>>2]|0;
 $215 = ($216|0)==(0);
 if ($215) {
  $240 = $219;$245 = 0;
 } else {
  $217 = (($216) + -1)|0;
  $218 = (($219) + 4|0);
  $220 = HEAP32[$218>>2]|0;
  $221 = ((($220) + ($217<<3)|0) + 4|0);
  $222 = HEAP8[$221>>0]|0;
  $223 = ($222<<24>>24)==(0);
  if ($223) {
   $224 = (($inOperator) + 4|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = HEAP32[$225>>2]|0;
   $227 = (($226) + 16|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = (($220) + ($217<<3)|0);
   $230 = HEAP32[$229>>2]|0;
   FUNCTION_TABLE_vii[$228 & 4095]($225,$230);
   $231 = HEAP32[$inOperator>>2]|0;
   $232 = (($231) + 8|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = (($233) + -1)|0;
   $235 = (($231) + 4|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ((($236) + ($234<<3)|0) + 4|0);
   HEAP8[$237>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $240 = $$pre$i;$245 = $$pre1$i;
  } else {
   $240 = $219;$245 = $216;
  }
 }
 HEAP32[$0>>2] = $214;
 $238 = (($0) + 4|0);
 HEAP8[$238>>0] = 0;
 $239 = (($240) + 12|0);
 $241 = HEAP32[$239>>2]|0;
 $242 = $241 & 2147483647;
 $243 = (($240) + 8|0);
 $244 = ($242>>>0)>($245>>>0);
 if ($244) {
  $246 = (($240) + 4|0);
  $247 = HEAP32[$246>>2]|0;
  $248 = (($247) + ($245<<3)|0);
  $249 = ($248|0)==(0|0);
  if ($249) {
   $261 = $245;
  } else {
   $250 = $0;
   $251 = $250;
   $252 = HEAP32[$251>>2]|0;
   $253 = (($250) + 4)|0;
   $254 = $253;
   $255 = HEAP32[$254>>2]|0;
   $256 = $248;
   $257 = $256;
   HEAP32[$257>>2] = $252;
   $258 = (($256) + 4)|0;
   $259 = $258;
   HEAP32[$259>>2] = $255;
   $$pre$i$i1 = HEAP32[$243>>2]|0;
   $261 = $$pre$i$i1;
  }
  $260 = (($261) + 1)|0;
  HEAP32[$243>>2] = $260;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($240,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataESA_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $262 = HEAP32[$inOperator>>2]|0;
 $263 = (($262) + 8|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = ($264|0)==(0);
 if ($265) {
  $281 = (($inStartIndex) + 4)|0;
  STACKTOP = sp;return ($281|0);
 }
 $266 = (($264) + -1)|0;
 $267 = (($262) + 4|0);
 $268 = HEAP32[$267>>2]|0;
 $269 = ((($268) + ($266<<3)|0) + 4|0);
 $270 = HEAP8[$269>>0]|0;
 $271 = ($270<<24>>24)==(0);
 if ($271) {
  $278 = $262;$280 = $264;
 } else {
  $272 = (($inOperator) + 4|0);
  $273 = HEAP32[$272>>2]|0;
  $274 = HEAP32[$273>>2]|0;
  $275 = (($274) + 20|0);
  $276 = HEAP32[$275>>2]|0;
  FUNCTION_TABLE_vi[$276 & 4095]($273);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $278 = $$pre$i$i;$280 = $$pre1$i$i;
 }
 $277 = (($278) + 8|0);
 $279 = (($280) + -1)|0;
 HEAP32[$277>>2] = $279;
 $281 = (($inStartIndex) + 4)|0;
 STACKTOP = sp;return ($281|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $info$i$i$i$i$i = sp + 336|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 288|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 272;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 272)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx33PxVehicleAutoBoxDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx33PxVehicleAutoBoxDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0;
 var $9 = 0, $theAccessor$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i = sp + 8|0;
 HEAP8[$theAccessor$i>>0] = 0;
 $1 = (($theAccessor$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor$i) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$this+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$this+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$this+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$this+12>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $30 = $$pre$i;$35 = $$pre1$i;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i1 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i1;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEE14handleAccessorILj532ENS_22PxRepXPropertyAccessorILj532ES4_KffEEEEvRKT0_($inOperator,$theAccessor$i);
 $52 = HEAP32[$inOperator>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if (!($55)) {
  $56 = (($54) + -1)|0;
  $57 = (($52) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58) + ($56<<3)|0) + 4|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $68 = $52;$70 = $54;
  } else {
   $62 = (($inOperator) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vi[$66 & 4095]($63);
   $$pre$i$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
   $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
   $68 = $$pre$i$i;$70 = $$pre1$i$i;
  }
  $67 = (($68) + 8|0);
  $69 = (($70) + -1)|0;
  HEAP32[$67>>2] = $69;
 }
 $71 = (($this) + 16|0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj533ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($inOperator,0,$71,522456,0);
 $72 = (($this) + 32|0);
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj534ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($inOperator,0,$72,522456,0);
 $73 = (($inStartIndex) + 3)|0;
 STACKTOP = sp;return ($73|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj534ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($this,$0,$inProp,$theConversions,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $theConversions = $theConversions|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$09 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i3 = 0, $$phi$trans$insert$i6 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i1 = 0, $$pre$i2 = 0, $$pre$i5 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i4 = 0, $$pre1$i7 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer$i$i$i = 0, $rangeStart = 0, $rangeStart$ = 0, $vararg_buffer = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 16|0;
 $rangeStart = sp + 8|0;
 $2 = HEAP32[$inProp>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $29 = $3;$34 = 0;
 } else {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9) + ($7<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($this) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($9) + ($7<<3)|0);
   $19 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_vii[$17 & 4095]($14,$19);
   $20 = HEAP32[$this>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + -1)|0;
   $24 = (($20) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($25) + ($23<<3)|0) + 4|0);
   HEAP8[$26>>0] = 1;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $29 = $$pre$i;$34 = $$pre1$i;
  } else {
   $29 = $3;$34 = $5;
  }
 }
 HEAP32[$vararg_buffer>>2] = $2;
 $27 = (($vararg_buffer) + 4|0);
 HEAP8[$27>>0] = 0;
 $28 = (($29) + 12|0);
 $30 = HEAP32[$28>>2]|0;
 $31 = $30 & 2147483647;
 $32 = (($29) + 8|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  $35 = (($29) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($34<<3)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   $50 = $34;
  } else {
   $39 = $vararg_buffer;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 4)|0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = $37;
   $46 = $45;
   HEAP32[$46>>2] = $41;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $44;
   $$pre$i$i = HEAP32[$32>>2]|0;
   $50 = $$pre$i$i;
  }
  $49 = (($50) + 1)|0;
  HEAP32[$32>>2] = $49;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($29,$vararg_buffer)|0);
 }
 HEAP32[$rangeStart>>2] = 534;
 $51 = (($this) + 20|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 $rangeStart$ = $53 ? $rangeStart : $52;
 $54 = HEAP32[$theConversions>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = (($vararg_buffer) + 4|0);
  $57 = (($this) + 8|0);
  $58 = (($inProp) + 12|0);
  $59 = (($this) + 4|0);
  $60 = (($this) + 12|0);
  $$09 = $theConversions;$84 = $54;
  while(1) {
   $61 = HEAP32[$this>>2]|0;
   $62 = (($61) + 8|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0);
   if ($64) {
    $86 = $61;$91 = 0;
   } else {
    $65 = (($63) + -1)|0;
    $66 = (($61) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($67) + ($65<<3)|0) + 4|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = ($69<<24>>24)==(0);
    if ($70) {
     $71 = HEAP32[$59>>2]|0;
     $72 = HEAP32[$71>>2]|0;
     $73 = (($72) + 16|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($67) + ($65<<3)|0);
     $76 = HEAP32[$75>>2]|0;
     FUNCTION_TABLE_vii[$74 & 4095]($71,$76);
     $77 = HEAP32[$this>>2]|0;
     $78 = (($77) + 8|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($79) + -1)|0;
     $81 = (($77) + 4|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = ((($82) + ($80<<3)|0) + 4|0);
     HEAP8[$83>>0] = 1;
     $$pre$i$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i$i = (($$pre$i$i1) + 8|0);
     $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
     $86 = $$pre$i$i1;$91 = $$pre1$i$i;
    } else {
     $86 = $61;$91 = $63;
    }
   }
   HEAP32[$vararg_buffer>>2] = $84;
   HEAP8[$56>>0] = 0;
   $85 = (($86) + 12|0);
   $87 = HEAP32[$85>>2]|0;
   $88 = $87 & 2147483647;
   $89 = (($86) + 8|0);
   $90 = ($88>>>0)>($91>>>0);
   if ($90) {
    $92 = (($86) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($93) + ($91<<3)|0);
    $95 = ($94|0)==(0|0);
    if ($95) {
     $107 = $91;
    } else {
     $96 = $vararg_buffer;
     $97 = $96;
     $98 = HEAP32[$97>>2]|0;
     $99 = (($96) + 4)|0;
     $100 = $99;
     $101 = HEAP32[$100>>2]|0;
     $102 = $94;
     $103 = $102;
     HEAP32[$103>>2] = $98;
     $104 = (($102) + 4)|0;
     $105 = $104;
     HEAP32[$105>>2] = $101;
     $$pre$i$i$i = HEAP32[$89>>2]|0;
     $107 = $$pre$i$i$i;
    }
    $106 = (($107) + 1)|0;
    HEAP32[$89>>2] = $106;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($86,$vararg_buffer)|0);
   }
   $108 = (($$09) + 4|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = HEAP32[$57>>2]|0;
   $111 = HEAP32[$58>>2]|0;
   $112 = (Math_fround(FUNCTION_TABLE_fii[$111 & 63]($110,$109)));
   $113 = HEAP32[$59>>2]|0;
   $114 = HEAP32[$60>>2]|0;
   $115 = HEAP32[$this>>2]|0;
   $116 = (($115) + 8|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = ($117|0)==(0);
   if ($118) {
    $$0$i$i$i$i = 521512;
   } else {
    $119 = (($117) + -1)|0;
    $120 = (($115) + 4|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = (($121) + ($119<<3)|0);
    $123 = HEAP32[$122>>2]|0;
    $$0$i$i$i$i = $123;
   }
   $124 = +$112;
   dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$124;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
   $125 = HEAP8[$buffer$i$i$i>>0]|0;
   $126 = ($125<<24>>24)==(0);
   if (!($126)) {
    $127 = HEAP32[$114>>2]|0;
    $128 = HEAP32[$127>>2]|0;
    $129 = (_strlen(($buffer$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$128 & 2047]($114,$buffer$i$i$i,$129)|0);
   }
   HEAP8[$vararg_buffer>>0] = 0;
   $130 = HEAP32[$114>>2]|0;
   $131 = HEAP32[$130>>2]|0;
   (FUNCTION_TABLE_iiii[$131 & 2047]($114,$vararg_buffer,1)|0);
   $132 = HEAP32[$113>>2]|0;
   $133 = (($132) + 8|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = (($114) + 20|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_viii[$134 & 4095]($113,$$0$i$i$i$i,$136);
   $137 = (($114) + 16|0);
   HEAP32[$137>>2] = 0;
   $138 = (($114) + 12|0);
   HEAP32[$138>>2] = 0;
   $139 = HEAP32[$this>>2]|0;
   $140 = (($139) + 8|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = ($141|0)==(0);
   if (!($142)) {
    $143 = (($141) + -1)|0;
    $144 = (($139) + 4|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = ((($145) + ($143<<3)|0) + 4|0);
    $147 = HEAP8[$146>>0]|0;
    $148 = ($147<<24>>24)==(0);
    if ($148) {
     $154 = $139;$156 = $141;
    } else {
     $149 = HEAP32[$59>>2]|0;
     $150 = HEAP32[$149>>2]|0;
     $151 = (($150) + 20|0);
     $152 = HEAP32[$151>>2]|0;
     FUNCTION_TABLE_vi[$152 & 4095]($149);
     $$pre$i5 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i6 = (($$pre$i5) + 8|0);
     $$pre1$i7 = HEAP32[$$phi$trans$insert$i6>>2]|0;
     $154 = $$pre$i5;$156 = $$pre1$i7;
    }
    $153 = (($154) + 8|0);
    $155 = (($156) + -1)|0;
    HEAP32[$153>>2] = $155;
   }
   $157 = HEAP32[$rangeStart$>>2]|0;
   $158 = (($157) + 1)|0;
   HEAP32[$rangeStart$>>2] = $158;
   $159 = (($$09) + 8|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($160|0)==(0|0);
   if ($161) {
    break;
   } else {
    $$09 = $159;$84 = $160;
   }
  }
 }
 $162 = HEAP32[$this>>2]|0;
 $163 = (($162) + 8|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ($164|0)==(0);
 if ($165) {
  STACKTOP = sp;return;
 }
 $166 = (($164) + -1)|0;
 $167 = (($162) + 4|0);
 $168 = HEAP32[$167>>2]|0;
 $169 = ((($168) + ($166<<3)|0) + 4|0);
 $170 = HEAP8[$169>>0]|0;
 $171 = ($170<<24>>24)==(0);
 if ($171) {
  $178 = $162;$180 = $164;
 } else {
  $172 = (($this) + 4|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = HEAP32[$173>>2]|0;
  $175 = (($174) + 20|0);
  $176 = HEAP32[$175>>2]|0;
  FUNCTION_TABLE_vi[$176 & 4095]($173);
  $$pre$i2 = HEAP32[$this>>2]|0;
  $$phi$trans$insert$i3 = (($$pre$i2) + 8|0);
  $$pre1$i4 = HEAP32[$$phi$trans$insert$i3>>2]|0;
  $178 = $$pre$i2;$180 = $$pre1$i4;
 }
 $177 = (($178) + 8|0);
 $179 = (($180) + -1)|0;
 HEAP32[$177>>2] = $179;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEE15indexedPropertyILj533ES4_NS_18PxVehicleGearsData4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($this,$0,$inProp,$theConversions,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $theConversions = $theConversions|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$09 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i3 = 0, $$phi$trans$insert$i6 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i1 = 0, $$pre$i2 = 0, $$pre$i5 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i4 = 0, $$pre1$i7 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer$i$i$i = 0, $rangeStart = 0, $rangeStart$ = 0, $vararg_buffer = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 16|0;
 $rangeStart = sp + 8|0;
 $2 = HEAP32[$inProp>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $29 = $3;$34 = 0;
 } else {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9) + ($7<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($this) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($9) + ($7<<3)|0);
   $19 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_vii[$17 & 4095]($14,$19);
   $20 = HEAP32[$this>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + -1)|0;
   $24 = (($20) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($25) + ($23<<3)|0) + 4|0);
   HEAP8[$26>>0] = 1;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $29 = $$pre$i;$34 = $$pre1$i;
  } else {
   $29 = $3;$34 = $5;
  }
 }
 HEAP32[$vararg_buffer>>2] = $2;
 $27 = (($vararg_buffer) + 4|0);
 HEAP8[$27>>0] = 0;
 $28 = (($29) + 12|0);
 $30 = HEAP32[$28>>2]|0;
 $31 = $30 & 2147483647;
 $32 = (($29) + 8|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  $35 = (($29) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($34<<3)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   $50 = $34;
  } else {
   $39 = $vararg_buffer;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 4)|0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = $37;
   $46 = $45;
   HEAP32[$46>>2] = $41;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $44;
   $$pre$i$i = HEAP32[$32>>2]|0;
   $50 = $$pre$i$i;
  }
  $49 = (($50) + 1)|0;
  HEAP32[$32>>2] = $49;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($29,$vararg_buffer)|0);
 }
 HEAP32[$rangeStart>>2] = 533;
 $51 = (($this) + 20|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 $rangeStart$ = $53 ? $rangeStart : $52;
 $54 = HEAP32[$theConversions>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = (($vararg_buffer) + 4|0);
  $57 = (($this) + 8|0);
  $58 = (($inProp) + 12|0);
  $59 = (($this) + 4|0);
  $60 = (($this) + 12|0);
  $$09 = $theConversions;$84 = $54;
  while(1) {
   $61 = HEAP32[$this>>2]|0;
   $62 = (($61) + 8|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0);
   if ($64) {
    $86 = $61;$91 = 0;
   } else {
    $65 = (($63) + -1)|0;
    $66 = (($61) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($67) + ($65<<3)|0) + 4|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = ($69<<24>>24)==(0);
    if ($70) {
     $71 = HEAP32[$59>>2]|0;
     $72 = HEAP32[$71>>2]|0;
     $73 = (($72) + 16|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($67) + ($65<<3)|0);
     $76 = HEAP32[$75>>2]|0;
     FUNCTION_TABLE_vii[$74 & 4095]($71,$76);
     $77 = HEAP32[$this>>2]|0;
     $78 = (($77) + 8|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($79) + -1)|0;
     $81 = (($77) + 4|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = ((($82) + ($80<<3)|0) + 4|0);
     HEAP8[$83>>0] = 1;
     $$pre$i$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i$i = (($$pre$i$i1) + 8|0);
     $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
     $86 = $$pre$i$i1;$91 = $$pre1$i$i;
    } else {
     $86 = $61;$91 = $63;
    }
   }
   HEAP32[$vararg_buffer>>2] = $84;
   HEAP8[$56>>0] = 0;
   $85 = (($86) + 12|0);
   $87 = HEAP32[$85>>2]|0;
   $88 = $87 & 2147483647;
   $89 = (($86) + 8|0);
   $90 = ($88>>>0)>($91>>>0);
   if ($90) {
    $92 = (($86) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($93) + ($91<<3)|0);
    $95 = ($94|0)==(0|0);
    if ($95) {
     $107 = $91;
    } else {
     $96 = $vararg_buffer;
     $97 = $96;
     $98 = HEAP32[$97>>2]|0;
     $99 = (($96) + 4)|0;
     $100 = $99;
     $101 = HEAP32[$100>>2]|0;
     $102 = $94;
     $103 = $102;
     HEAP32[$103>>2] = $98;
     $104 = (($102) + 4)|0;
     $105 = $104;
     HEAP32[$105>>2] = $101;
     $$pre$i$i$i = HEAP32[$89>>2]|0;
     $107 = $$pre$i$i$i;
    }
    $106 = (($107) + 1)|0;
    HEAP32[$89>>2] = $106;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($86,$vararg_buffer)|0);
   }
   $108 = (($$09) + 4|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = HEAP32[$57>>2]|0;
   $111 = HEAP32[$58>>2]|0;
   $112 = (Math_fround(FUNCTION_TABLE_fii[$111 & 63]($110,$109)));
   $113 = HEAP32[$59>>2]|0;
   $114 = HEAP32[$60>>2]|0;
   $115 = HEAP32[$this>>2]|0;
   $116 = (($115) + 8|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = ($117|0)==(0);
   if ($118) {
    $$0$i$i$i$i = 521512;
   } else {
    $119 = (($117) + -1)|0;
    $120 = (($115) + 4|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = (($121) + ($119<<3)|0);
    $123 = HEAP32[$122>>2]|0;
    $$0$i$i$i$i = $123;
   }
   $124 = +$112;
   dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$124;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
   $125 = HEAP8[$buffer$i$i$i>>0]|0;
   $126 = ($125<<24>>24)==(0);
   if (!($126)) {
    $127 = HEAP32[$114>>2]|0;
    $128 = HEAP32[$127>>2]|0;
    $129 = (_strlen(($buffer$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$128 & 2047]($114,$buffer$i$i$i,$129)|0);
   }
   HEAP8[$vararg_buffer>>0] = 0;
   $130 = HEAP32[$114>>2]|0;
   $131 = HEAP32[$130>>2]|0;
   (FUNCTION_TABLE_iiii[$131 & 2047]($114,$vararg_buffer,1)|0);
   $132 = HEAP32[$113>>2]|0;
   $133 = (($132) + 8|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = (($114) + 20|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_viii[$134 & 4095]($113,$$0$i$i$i$i,$136);
   $137 = (($114) + 16|0);
   HEAP32[$137>>2] = 0;
   $138 = (($114) + 12|0);
   HEAP32[$138>>2] = 0;
   $139 = HEAP32[$this>>2]|0;
   $140 = (($139) + 8|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = ($141|0)==(0);
   if (!($142)) {
    $143 = (($141) + -1)|0;
    $144 = (($139) + 4|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = ((($145) + ($143<<3)|0) + 4|0);
    $147 = HEAP8[$146>>0]|0;
    $148 = ($147<<24>>24)==(0);
    if ($148) {
     $154 = $139;$156 = $141;
    } else {
     $149 = HEAP32[$59>>2]|0;
     $150 = HEAP32[$149>>2]|0;
     $151 = (($150) + 20|0);
     $152 = HEAP32[$151>>2]|0;
     FUNCTION_TABLE_vi[$152 & 4095]($149);
     $$pre$i5 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i6 = (($$pre$i5) + 8|0);
     $$pre1$i7 = HEAP32[$$phi$trans$insert$i6>>2]|0;
     $154 = $$pre$i5;$156 = $$pre1$i7;
    }
    $153 = (($154) + 8|0);
    $155 = (($156) + -1)|0;
    HEAP32[$153>>2] = $155;
   }
   $157 = HEAP32[$rangeStart$>>2]|0;
   $158 = (($157) + 1)|0;
   HEAP32[$rangeStart$>>2] = $158;
   $159 = (($$09) + 8|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($160|0)==(0|0);
   if ($161) {
    break;
   } else {
    $$09 = $159;$84 = $160;
   }
  }
 }
 $162 = HEAP32[$this>>2]|0;
 $163 = (($162) + 8|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ($164|0)==(0);
 if ($165) {
  STACKTOP = sp;return;
 }
 $166 = (($164) + -1)|0;
 $167 = (($162) + 4|0);
 $168 = HEAP32[$167>>2]|0;
 $169 = ((($168) + ($166<<3)|0) + 4|0);
 $170 = HEAP8[$169>>0]|0;
 $171 = ($170<<24>>24)==(0);
 if ($171) {
  $178 = $162;$180 = $164;
 } else {
  $172 = (($this) + 4|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = HEAP32[$173>>2]|0;
  $175 = (($174) + 20|0);
  $176 = HEAP32[$175>>2]|0;
  FUNCTION_TABLE_vi[$176 & 4095]($173);
  $$pre$i2 = HEAP32[$this>>2]|0;
  $$phi$trans$insert$i3 = (($$pre$i2) + 8|0);
  $$pre1$i4 = HEAP32[$$phi$trans$insert$i3>>2]|0;
  $178 = $$pre$i2;$180 = $$pre1$i4;
 }
 $177 = (($178) + 8|0);
 $179 = (($180) + -1)|0;
 HEAP32[$177>>2] = $179;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEE14handleAccessorILj532ENS_22PxRepXPropertyAccessorILj532ES4_KffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $$0$i = $3;
 }
 HEAP8[$inAccessor>>0] = 1;
 $4 = (($inAccessor) + 4|0);
 HEAP32[$4>>2] = $$0$i;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$6>>2] = $9;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($inAccessor) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (Math_fround(FUNCTION_TABLE_fi[$13 & 255]($11)));
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i = 521512;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i = $27;
 }
 $28 = +$14;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$18>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($18,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$18>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($18,$vararg_buffer,1)|0);
 $36 = HEAP32[$16>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($18) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($16,$$0$i$i$i$i,$40);
 $41 = (($18) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($18) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $info$i$i$i$i$i = sp + 96|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 48|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 256;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 256)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx32PxVehicleClutchDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleClutchDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx32PxVehicleClutchDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleClutchDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$0$i$i$i$i$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i12 = 0, $$phi$trans$insert$i19 = 0, $$phi$trans$insert26 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i15 = 0, $$pre$i$i22 = 0, $$pre$i$i3 = 0, $$pre$i$i7 = 0, $$pre$i11 = 0, $$pre$i18 = 0, $$pre1$i = 0;
 var $$pre1$i$i = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i13 = 0, $$pre1$i20 = 0, $$pre24 = 0, $$pre25 = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $conv$01$i$i$i$i$i = 0, $theAccessor$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i2 = sp + 8|0;
 HEAP8[$theAccessor$i2>>0] = 0;
 $1 = (($theAccessor$i2) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$this+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$this+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$this+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$this+12>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i12 = (($$pre$i11) + 8|0);
   $$pre1$i13 = HEAP32[$$phi$trans$insert$i12>>2]|0;
   $30 = $$pre$i11;$35 = $$pre1$i13;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i15 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i15;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleClutchDataEEEE14handleAccessorILj555ENS_22PxRepXPropertyAccessorILj555ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i2);
 $52 = HEAP32[$inOperator>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $76 = 0;$79 = $52;
 } else {
  $56 = (($54) + -1)|0;
  $57 = (($52) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58) + ($56<<3)|0) + 4|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $68 = $52;$70 = $54;
  } else {
   $62 = (($inOperator) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vi[$66 & 4095]($63);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $68 = $$pre$i$i3;$70 = $$pre1$i$i5;
  }
  $67 = (($68) + 8|0);
  $69 = (($70) + -1)|0;
  HEAP32[$67>>2] = $69;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre24 = HEAP32[$$phi$trans$insert>>2]|0;
  $76 = $$pre24;$79 = $$pre;
 }
 $71 = (($this) + 24|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($this) + 16|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($76|0)==(0);
 if ($75) {
  $100 = $79;$105 = 0;
 } else {
  $77 = (($76) + -1)|0;
  $78 = (($79) + 4|0);
  $80 = HEAP32[$78>>2]|0;
  $81 = ((($80) + ($77<<3)|0) + 4|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = ($82<<24>>24)==(0);
  if ($83) {
   $84 = (($inOperator) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 16|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($80) + ($77<<3)|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_vii[$88 & 4095]($85,$90);
   $91 = HEAP32[$inOperator>>2]|0;
   $92 = (($91) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + -1)|0;
   $95 = (($91) + 4|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ((($96) + ($94<<3)|0) + 4|0);
   HEAP8[$97>>0] = 1;
   $$pre$i18 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i19 = (($$pre$i18) + 8|0);
   $$pre1$i20 = HEAP32[$$phi$trans$insert$i19>>2]|0;
   $100 = $$pre$i18;$105 = $$pre1$i20;
  } else {
   $100 = $79;$105 = $76;
  }
 }
 HEAP32[$0>>2] = $74;
 $98 = (($0) + 4|0);
 HEAP8[$98>>0] = 0;
 $99 = (($100) + 12|0);
 $101 = HEAP32[$99>>2]|0;
 $102 = $101 & 2147483647;
 $103 = (($100) + 8|0);
 $104 = ($102>>>0)>($105>>>0);
 if ($104) {
  $106 = (($100) + 4|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($107) + ($105<<3)|0);
  $109 = ($108|0)==(0|0);
  if ($109) {
   $121 = $105;
  } else {
   $110 = $0;
   $111 = $110;
   $112 = HEAP32[$111>>2]|0;
   $113 = (($110) + 4)|0;
   $114 = $113;
   $115 = HEAP32[$114>>2]|0;
   $116 = $108;
   $117 = $116;
   HEAP32[$117>>2] = $112;
   $118 = (($116) + 4)|0;
   $119 = $118;
   HEAP32[$119>>2] = $115;
   $$pre$i$i22 = HEAP32[$103>>2]|0;
   $121 = $$pre$i$i22;
  }
  $120 = (($121) + 1)|0;
  HEAP32[$103>>2] = $120;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($100,$0)|0);
 }
 $122 = (($inOperator) + 20|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ($123|0)==(0|0);
 if (!($124)) {
  $125 = HEAP32[$123>>2]|0;
  $126 = (($125) + 1)|0;
  HEAP32[$123>>2] = $126;
 }
 $127 = (($inOperator) + 4|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = HEAP32[$inOperator>>2]|0;
 $130 = (($129) + 8|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ($131|0)==(0);
 if ($132) {
  $$0$i$i$i$i$i = 521512;
 } else {
  $133 = (($131) + -1)|0;
  $134 = (($129) + 4|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + ($133<<3)|0);
  $137 = HEAP32[$136>>2]|0;
  $$0$i$i$i$i$i = $137;
 }
 $138 = (($inOperator) + 8|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = (FUNCTION_TABLE_ii[$72 & 4095]($139)|0);
 $141 = (523184|0)==(0|0);
 if (!($141)) {
  $148 = 523184;$conv$01$i$i$i$i$i = 523160;
  while(1) {
   $142 = (($conv$01$i$i$i$i$i) + 4|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = ($143|0)==($140|0);
   if ($144) {
    $145 = HEAP32[$128>>2]|0;
    $146 = (($145) + 8|0);
    $147 = HEAP32[$146>>2]|0;
    FUNCTION_TABLE_viii[$147 & 4095]($128,$$0$i$i$i$i$i,$148);
   }
   $149 = (($conv$01$i$i$i$i$i) + 8|0);
   $150 = HEAP32[$149>>2]|0;
   $151 = ($150|0)==(0|0);
   if ($151) {
    break;
   } else {
    $148 = $150;$conv$01$i$i$i$i$i = $149;
   }
  }
 }
 $152 = HEAP32[$inOperator>>2]|0;
 $153 = (($152) + 8|0);
 $154 = HEAP32[$153>>2]|0;
 $155 = ($154|0)==(0);
 if ($155) {
  $175 = 0;$178 = $152;
 } else {
  $156 = (($154) + -1)|0;
  $157 = (($152) + 4|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = ((($158) + ($156<<3)|0) + 4|0);
  $160 = HEAP8[$159>>0]|0;
  $161 = ($160<<24>>24)==(0);
  if ($161) {
   $167 = $152;$169 = $154;
  } else {
   $162 = HEAP32[$127>>2]|0;
   $163 = HEAP32[$162>>2]|0;
   $164 = (($163) + 20|0);
   $165 = HEAP32[$164>>2]|0;
   FUNCTION_TABLE_vi[$165 & 4095]($162);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $167 = $$pre$i$i7;$169 = $$pre1$i$i9;
  }
  $166 = (($167) + 8|0);
  $168 = (($169) + -1)|0;
  HEAP32[$166>>2] = $168;
  $$pre25 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert26 = (($$pre25) + 8|0);
  $$pre27 = HEAP32[$$phi$trans$insert26>>2]|0;
  $175 = $$pre27;$178 = $$pre25;
 }
 $170 = (($this) + 32|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $171 = (($theAccessor$i2) + 4|0);
 HEAP32[$171>>2] = 0;
 $172 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$172+0>>2]=HEAP32[$170+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$170+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$170+8>>2]|0;HEAP32[$172+12>>2]=HEAP32[$170+12>>2]|0;
 $173 = HEAP32[$170>>2]|0;
 $174 = ($175|0)==(0);
 if ($174) {
  $198 = $178;$203 = 0;
 } else {
  $176 = (($175) + -1)|0;
  $177 = (($178) + 4|0);
  $179 = HEAP32[$177>>2]|0;
  $180 = ((($179) + ($176<<3)|0) + 4|0);
  $181 = HEAP8[$180>>0]|0;
  $182 = ($181<<24>>24)==(0);
  if ($182) {
   $183 = HEAP32[$127>>2]|0;
   $184 = HEAP32[$183>>2]|0;
   $185 = (($184) + 16|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = (($179) + ($176<<3)|0);
   $188 = HEAP32[$187>>2]|0;
   FUNCTION_TABLE_vii[$186 & 4095]($183,$188);
   $189 = HEAP32[$inOperator>>2]|0;
   $190 = (($189) + 8|0);
   $191 = HEAP32[$190>>2]|0;
   $192 = (($191) + -1)|0;
   $193 = (($189) + 4|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = ((($194) + ($192<<3)|0) + 4|0);
   HEAP8[$195>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $198 = $$pre$i;$203 = $$pre1$i;
  } else {
   $198 = $178;$203 = $175;
  }
 }
 HEAP32[$0>>2] = $173;
 $196 = (($0) + 4|0);
 HEAP8[$196>>0] = 0;
 $197 = (($198) + 12|0);
 $199 = HEAP32[$197>>2]|0;
 $200 = $199 & 2147483647;
 $201 = (($198) + 8|0);
 $202 = ($200>>>0)>($203>>>0);
 if ($202) {
  $204 = (($198) + 4|0);
  $205 = HEAP32[$204>>2]|0;
  $206 = (($205) + ($203<<3)|0);
  $207 = ($206|0)==(0|0);
  if ($207) {
   $219 = $203;
  } else {
   $208 = $0;
   $209 = $208;
   $210 = HEAP32[$209>>2]|0;
   $211 = (($208) + 4)|0;
   $212 = $211;
   $213 = HEAP32[$212>>2]|0;
   $214 = $206;
   $215 = $214;
   HEAP32[$215>>2] = $210;
   $216 = (($214) + 4)|0;
   $217 = $216;
   HEAP32[$217>>2] = $213;
   $$pre$i$i1 = HEAP32[$201>>2]|0;
   $219 = $$pre$i$i1;
  }
  $218 = (($219) + 1)|0;
  HEAP32[$201>>2] = $218;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($198,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleClutchDataEEEE14handleAccessorILj557ENS_22PxRepXPropertyAccessorILj557ES4_jjEEEEvRKT0_($inOperator,$theAccessor$i2);
 $220 = HEAP32[$inOperator>>2]|0;
 $221 = (($220) + 8|0);
 $222 = HEAP32[$221>>2]|0;
 $223 = ($222|0)==(0);
 if ($223) {
  $238 = (($inStartIndex) + 3)|0;
  STACKTOP = sp;return ($238|0);
 }
 $224 = (($222) + -1)|0;
 $225 = (($220) + 4|0);
 $226 = HEAP32[$225>>2]|0;
 $227 = ((($226) + ($224<<3)|0) + 4|0);
 $228 = HEAP8[$227>>0]|0;
 $229 = ($228<<24>>24)==(0);
 if ($229) {
  $235 = $220;$237 = $222;
 } else {
  $230 = HEAP32[$127>>2]|0;
  $231 = HEAP32[$230>>2]|0;
  $232 = (($231) + 20|0);
  $233 = HEAP32[$232>>2]|0;
  FUNCTION_TABLE_vi[$233 & 4095]($230);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $235 = $$pre$i$i;$237 = $$pre1$i$i;
 }
 $234 = (($235) + 8|0);
 $236 = (($237) + -1)|0;
 HEAP32[$234>>2] = $236;
 $238 = (($inStartIndex) + 3)|0;
 STACKTOP = sp;return ($238|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleClutchDataEEEE14handleAccessorILj557ENS_22PxRepXPropertyAccessorILj557ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $15;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$19>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($19,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($19,$vararg_buffer,1)|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($19) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($17,$$0$i$i$i$i,$40);
 $41 = (($19) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($19) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleClutchDataEEEE14handleAccessorILj555ENS_22PxRepXPropertyAccessorILj555ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $$0$i = $3;
 }
 HEAP8[$inAccessor>>0] = 1;
 $4 = (($inAccessor) + 4|0);
 HEAP32[$4>>2] = $$0$i;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$6>>2] = $9;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($inAccessor) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (Math_fround(FUNCTION_TABLE_fi[$13 & 255]($11)));
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i = 521512;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i = $27;
 }
 $28 = +$14;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$18>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($18,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$18>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($18,$vararg_buffer,1)|0);
 $36 = HEAP32[$16>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($18) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($16,$$0$i$i$i$i,$40);
 $41 = (($18) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($18) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $info$i$i$i$i$i = sp + 240|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 176|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 112;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 112)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx31PxVehicleGearsDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx31PxVehicleGearsDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i12 = 0, $$phi$trans$insert$i19 = 0, $$phi$trans$insert26 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i15 = 0, $$pre$i$i22 = 0, $$pre$i$i3 = 0, $$pre$i$i7 = 0, $$pre$i11 = 0, $$pre$i18 = 0, $$pre1$i = 0, $$pre1$i$i = 0;
 var $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i13 = 0, $$pre1$i20 = 0, $$pre24 = 0, $$pre25 = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i6 = sp + 8|0;
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEE15indexedPropertyILj526ES4_NS4_4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($inOperator,0,$this,522456,0);
 $1 = (($this) + 16|0);
 HEAP8[$theAccessor$i6>>0] = 0;
 $2 = (($theAccessor$i6) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i6) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i12 = (($$pre$i11) + 8|0);
   $$pre1$i13 = HEAP32[$$phi$trans$insert$i12>>2]|0;
   $31 = $$pre$i11;$36 = $$pre1$i13;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i15 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i15;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEE14handleAccessorILj527ENS_22PxRepXPropertyAccessorILj527ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i6);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre24 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre24;$80 = $$pre;
 }
 $72 = (($this) + 32|0);
 HEAP8[$theAccessor$i6>>0] = 0;
 $73 = (($theAccessor$i6) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i6) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i18 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i19 = (($$pre$i18) + 8|0);
   $$pre1$i20 = HEAP32[$$phi$trans$insert$i19>>2]|0;
   $101 = $$pre$i18;$106 = $$pre1$i20;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i22 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i22;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEE14handleAccessorILj528ENS_22PxRepXPropertyAccessorILj528ES4_jjEEEEvRKT0_($inOperator,$theAccessor$i6);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $147 = 0;$150 = $123;
 } else {
  $127 = (($125) + -1)|0;
  $128 = (($123) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129) + ($127<<3)|0) + 4|0);
  $131 = HEAP8[$130>>0]|0;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $139 = $123;$141 = $125;
  } else {
   $133 = (($inOperator) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = HEAP32[$134>>2]|0;
   $136 = (($135) + 20|0);
   $137 = HEAP32[$136>>2]|0;
   FUNCTION_TABLE_vi[$137 & 4095]($134);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $139 = $$pre$i$i7;$141 = $$pre1$i$i9;
  }
  $138 = (($139) + 8|0);
  $140 = (($141) + -1)|0;
  HEAP32[$138>>2] = $140;
  $$pre25 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert26 = (($$pre25) + 8|0);
  $$pre27 = HEAP32[$$phi$trans$insert26>>2]|0;
  $147 = $$pre27;$150 = $$pre25;
 }
 $142 = (($this) + 48|0);
 HEAP8[$theAccessor$i6>>0] = 0;
 $143 = (($theAccessor$i6) + 4|0);
 HEAP32[$143>>2] = 0;
 $144 = (($theAccessor$i6) + 8|0);
 ;HEAP32[$144+0>>2]=HEAP32[$142+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$142+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$142+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$142+12>>2]|0;
 $145 = HEAP32[$142>>2]|0;
 $146 = ($147|0)==(0);
 if ($146) {
  $171 = $150;$176 = 0;
 } else {
  $148 = (($147) + -1)|0;
  $149 = (($150) + 4|0);
  $151 = HEAP32[$149>>2]|0;
  $152 = ((($151) + ($148<<3)|0) + 4|0);
  $153 = HEAP8[$152>>0]|0;
  $154 = ($153<<24>>24)==(0);
  if ($154) {
   $155 = (($inOperator) + 4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = HEAP32[$156>>2]|0;
   $158 = (($157) + 16|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($151) + ($148<<3)|0);
   $161 = HEAP32[$160>>2]|0;
   FUNCTION_TABLE_vii[$159 & 4095]($156,$161);
   $162 = HEAP32[$inOperator>>2]|0;
   $163 = (($162) + 8|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($164) + -1)|0;
   $166 = (($162) + 4|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ((($167) + ($165<<3)|0) + 4|0);
   HEAP8[$168>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $171 = $$pre$i;$176 = $$pre1$i;
  } else {
   $171 = $150;$176 = $147;
  }
 }
 HEAP32[$0>>2] = $145;
 $169 = (($0) + 4|0);
 HEAP8[$169>>0] = 0;
 $170 = (($171) + 12|0);
 $172 = HEAP32[$170>>2]|0;
 $173 = $172 & 2147483647;
 $174 = (($171) + 8|0);
 $175 = ($173>>>0)>($176>>>0);
 if ($175) {
  $177 = (($171) + 4|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + ($176<<3)|0);
  $180 = ($179|0)==(0|0);
  if ($180) {
   $192 = $176;
  } else {
   $181 = $0;
   $182 = $181;
   $183 = HEAP32[$182>>2]|0;
   $184 = (($181) + 4)|0;
   $185 = $184;
   $186 = HEAP32[$185>>2]|0;
   $187 = $179;
   $188 = $187;
   HEAP32[$188>>2] = $183;
   $189 = (($187) + 4)|0;
   $190 = $189;
   HEAP32[$190>>2] = $186;
   $$pre$i$i1 = HEAP32[$174>>2]|0;
   $192 = $$pre$i$i1;
  }
  $191 = (($192) + 1)|0;
  HEAP32[$174>>2] = $191;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($171,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEE14handleAccessorILj529ENS_22PxRepXPropertyAccessorILj529ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i6);
 $193 = HEAP32[$inOperator>>2]|0;
 $194 = (($193) + 8|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)==(0);
 if ($196) {
  $212 = (($inStartIndex) + 4)|0;
  STACKTOP = sp;return ($212|0);
 }
 $197 = (($195) + -1)|0;
 $198 = (($193) + 4|0);
 $199 = HEAP32[$198>>2]|0;
 $200 = ((($199) + ($197<<3)|0) + 4|0);
 $201 = HEAP8[$200>>0]|0;
 $202 = ($201<<24>>24)==(0);
 if ($202) {
  $209 = $193;$211 = $195;
 } else {
  $203 = (($inOperator) + 4|0);
  $204 = HEAP32[$203>>2]|0;
  $205 = HEAP32[$204>>2]|0;
  $206 = (($205) + 20|0);
  $207 = HEAP32[$206>>2]|0;
  FUNCTION_TABLE_vi[$207 & 4095]($204);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $209 = $$pre$i$i;$211 = $$pre1$i$i;
 }
 $208 = (($209) + 8|0);
 $210 = (($211) + -1)|0;
 HEAP32[$208>>2] = $210;
 $212 = (($inStartIndex) + 4)|0;
 STACKTOP = sp;return ($212|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEE14handleAccessorILj529ENS_22PxRepXPropertyAccessorILj529ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 136;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 136)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEE14handleAccessorILj528ENS_22PxRepXPropertyAccessorILj528ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 132;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 132)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $15;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$19>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($19,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($19,$vararg_buffer,1)|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($19) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($17,$$0$i$i$i$i,$40);
 $41 = (($19) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($19) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEE14handleAccessorILj527ENS_22PxRepXPropertyAccessorILj527ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 128;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 128)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEE15indexedPropertyILj526ES4_NS4_4EnumEfEEvjRKNS_21PxIndexedPropertyInfoIXT_ET0_T1_T2_EEPKNS_11PxU32ToNameERKNS_18PxUnknownClassInfoE($this,$0,$inProp,$theConversions,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $theConversions = $theConversions|0;
 $1 = $1|0;
 var $$0$i$i$i$i = 0, $$09 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i3 = 0, $$phi$trans$insert$i6 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i1 = 0, $$pre$i2 = 0, $$pre$i5 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i4 = 0, $$pre1$i7 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer$i$i$i = 0, $rangeStart = 0, $rangeStart$ = 0, $vararg_buffer = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 16|0;
 $rangeStart = sp + 8|0;
 $2 = HEAP32[$inProp>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $29 = $3;$34 = 0;
 } else {
  $7 = (($5) + -1)|0;
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9) + ($7<<3)|0) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($this) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($9) + ($7<<3)|0);
   $19 = HEAP32[$18>>2]|0;
   FUNCTION_TABLE_vii[$17 & 4095]($14,$19);
   $20 = HEAP32[$this>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + -1)|0;
   $24 = (($20) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($25) + ($23<<3)|0) + 4|0);
   HEAP8[$26>>0] = 1;
   $$pre$i = HEAP32[$this>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $29 = $$pre$i;$34 = $$pre1$i;
  } else {
   $29 = $3;$34 = $5;
  }
 }
 HEAP32[$vararg_buffer>>2] = $2;
 $27 = (($vararg_buffer) + 4|0);
 HEAP8[$27>>0] = 0;
 $28 = (($29) + 12|0);
 $30 = HEAP32[$28>>2]|0;
 $31 = $30 & 2147483647;
 $32 = (($29) + 8|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  $35 = (($29) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($34<<3)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   $50 = $34;
  } else {
   $39 = $vararg_buffer;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 4)|0;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = $37;
   $46 = $45;
   HEAP32[$46>>2] = $41;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $44;
   $$pre$i$i = HEAP32[$32>>2]|0;
   $50 = $$pre$i$i;
  }
  $49 = (($50) + 1)|0;
  HEAP32[$32>>2] = $49;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($29,$vararg_buffer)|0);
 }
 HEAP32[$rangeStart>>2] = 526;
 $51 = (($this) + 20|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 $rangeStart$ = $53 ? $rangeStart : $52;
 $54 = HEAP32[$theConversions>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = (($vararg_buffer) + 4|0);
  $57 = (($this) + 8|0);
  $58 = (($inProp) + 12|0);
  $59 = (($this) + 4|0);
  $60 = (($this) + 12|0);
  $$09 = $theConversions;$84 = $54;
  while(1) {
   $61 = HEAP32[$this>>2]|0;
   $62 = (($61) + 8|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0);
   if ($64) {
    $86 = $61;$91 = 0;
   } else {
    $65 = (($63) + -1)|0;
    $66 = (($61) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($67) + ($65<<3)|0) + 4|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = ($69<<24>>24)==(0);
    if ($70) {
     $71 = HEAP32[$59>>2]|0;
     $72 = HEAP32[$71>>2]|0;
     $73 = (($72) + 16|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($67) + ($65<<3)|0);
     $76 = HEAP32[$75>>2]|0;
     FUNCTION_TABLE_vii[$74 & 4095]($71,$76);
     $77 = HEAP32[$this>>2]|0;
     $78 = (($77) + 8|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($79) + -1)|0;
     $81 = (($77) + 4|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = ((($82) + ($80<<3)|0) + 4|0);
     HEAP8[$83>>0] = 1;
     $$pre$i$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i$i = (($$pre$i$i1) + 8|0);
     $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
     $86 = $$pre$i$i1;$91 = $$pre1$i$i;
    } else {
     $86 = $61;$91 = $63;
    }
   }
   HEAP32[$vararg_buffer>>2] = $84;
   HEAP8[$56>>0] = 0;
   $85 = (($86) + 12|0);
   $87 = HEAP32[$85>>2]|0;
   $88 = $87 & 2147483647;
   $89 = (($86) + 8|0);
   $90 = ($88>>>0)>($91>>>0);
   if ($90) {
    $92 = (($86) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($93) + ($91<<3)|0);
    $95 = ($94|0)==(0|0);
    if ($95) {
     $107 = $91;
    } else {
     $96 = $vararg_buffer;
     $97 = $96;
     $98 = HEAP32[$97>>2]|0;
     $99 = (($96) + 4)|0;
     $100 = $99;
     $101 = HEAP32[$100>>2]|0;
     $102 = $94;
     $103 = $102;
     HEAP32[$103>>2] = $98;
     $104 = (($102) + 4)|0;
     $105 = $104;
     HEAP32[$105>>2] = $101;
     $$pre$i$i$i = HEAP32[$89>>2]|0;
     $107 = $$pre$i$i$i;
    }
    $106 = (($107) + 1)|0;
    HEAP32[$89>>2] = $106;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($86,$vararg_buffer)|0);
   }
   $108 = (($$09) + 4|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = HEAP32[$57>>2]|0;
   $111 = HEAP32[$58>>2]|0;
   $112 = (Math_fround(FUNCTION_TABLE_fii[$111 & 63]($110,$109)));
   $113 = HEAP32[$59>>2]|0;
   $114 = HEAP32[$60>>2]|0;
   $115 = HEAP32[$this>>2]|0;
   $116 = (($115) + 8|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = ($117|0)==(0);
   if ($118) {
    $$0$i$i$i$i = 521512;
   } else {
    $119 = (($117) + -1)|0;
    $120 = (($115) + 4|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = (($121) + ($119<<3)|0);
    $123 = HEAP32[$122>>2]|0;
    $$0$i$i$i$i = $123;
   }
   $124 = +$112;
   dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$124;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
   $125 = HEAP8[$buffer$i$i$i>>0]|0;
   $126 = ($125<<24>>24)==(0);
   if (!($126)) {
    $127 = HEAP32[$114>>2]|0;
    $128 = HEAP32[$127>>2]|0;
    $129 = (_strlen(($buffer$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$128 & 2047]($114,$buffer$i$i$i,$129)|0);
   }
   HEAP8[$vararg_buffer>>0] = 0;
   $130 = HEAP32[$114>>2]|0;
   $131 = HEAP32[$130>>2]|0;
   (FUNCTION_TABLE_iiii[$131 & 2047]($114,$vararg_buffer,1)|0);
   $132 = HEAP32[$113>>2]|0;
   $133 = (($132) + 8|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = (($114) + 20|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_viii[$134 & 4095]($113,$$0$i$i$i$i,$136);
   $137 = (($114) + 16|0);
   HEAP32[$137>>2] = 0;
   $138 = (($114) + 12|0);
   HEAP32[$138>>2] = 0;
   $139 = HEAP32[$this>>2]|0;
   $140 = (($139) + 8|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = ($141|0)==(0);
   if (!($142)) {
    $143 = (($141) + -1)|0;
    $144 = (($139) + 4|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = ((($145) + ($143<<3)|0) + 4|0);
    $147 = HEAP8[$146>>0]|0;
    $148 = ($147<<24>>24)==(0);
    if ($148) {
     $154 = $139;$156 = $141;
    } else {
     $149 = HEAP32[$59>>2]|0;
     $150 = HEAP32[$149>>2]|0;
     $151 = (($150) + 20|0);
     $152 = HEAP32[$151>>2]|0;
     FUNCTION_TABLE_vi[$152 & 4095]($149);
     $$pre$i5 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i6 = (($$pre$i5) + 8|0);
     $$pre1$i7 = HEAP32[$$phi$trans$insert$i6>>2]|0;
     $154 = $$pre$i5;$156 = $$pre1$i7;
    }
    $153 = (($154) + 8|0);
    $155 = (($156) + -1)|0;
    HEAP32[$153>>2] = $155;
   }
   $157 = HEAP32[$rangeStart$>>2]|0;
   $158 = (($157) + 1)|0;
   HEAP32[$rangeStart$>>2] = $158;
   $159 = (($$09) + 8|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($160|0)==(0|0);
   if ($161) {
    break;
   } else {
    $$09 = $159;$84 = $160;
   }
  }
 }
 $162 = HEAP32[$this>>2]|0;
 $163 = (($162) + 8|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = ($164|0)==(0);
 if ($165) {
  STACKTOP = sp;return;
 }
 $166 = (($164) + -1)|0;
 $167 = (($162) + 4|0);
 $168 = HEAP32[$167>>2]|0;
 $169 = ((($168) + ($166<<3)|0) + 4|0);
 $170 = HEAP8[$169>>0]|0;
 $171 = ($170<<24>>24)==(0);
 if ($171) {
  $178 = $162;$180 = $164;
 } else {
  $172 = (($this) + 4|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = HEAP32[$173>>2]|0;
  $175 = (($174) + 20|0);
  $176 = HEAP32[$175>>2]|0;
  FUNCTION_TABLE_vi[$176 & 4095]($173);
  $$pre$i2 = HEAP32[$this>>2]|0;
  $$phi$trans$insert$i3 = (($$pre$i2) + 8|0);
  $$pre1$i4 = HEAP32[$$phi$trans$insert$i3>>2]|0;
  $178 = $$pre$i2;$180 = $$pre1$i4;
 }
 $177 = (($178) + 8|0);
 $179 = (($180) + -1)|0;
 HEAP32[$177>>2] = $179;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimDataNWEEEE14handleAccessorILj655ENS_22PxRepXPropertyAccessorILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $info$i$i$i$i$i = sp + 288|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 144|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 0;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $$0$i = $5;
 }
 HEAP8[$inAccessor>>0] = 1;
 $6 = (($inAccessor) + 4|0);
 HEAP32[$6>>2] = $$0$i;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$8>>2] = $11;
 }
 _memset(($1|0),0,144)|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($1);
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($inAccessor) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($propVal$i$i$i,$13);
 $16 = HEAP32[$this>>2]|0;
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $16;
 $23 = (($0) + 4|0);
 HEAP32[$23>>2] = $18;
 $24 = (($0) + 8|0);
 HEAP32[$24>>2] = $propVal$i$i$i;
 $25 = (($0) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($0) + 16|0);
 HEAP32[$26>>2] = $22;
 $27 = (($0) + 20|0);
 HEAP32[$27>>2] = 0;
 $28 = (($0) + 24|0);
 HEAP32[$28>>2] = 0;
 (__ZNK5physx32PxVehicleEngineDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx32PxVehicleEngineDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i$i$i = 0, $$phi$trans$insert$i$i11 = 0, $$phi$trans$insert$i$i15 = 0, $$phi$trans$insert$i$i19 = 0, $$phi$trans$insert$i$i23 = 0, $$phi$trans$insert$i$i27 = 0, $$phi$trans$insert$i31 = 0, $$phi$trans$insert$i38 = 0, $$phi$trans$insert$i4 = 0, $$phi$trans$insert$i45 = 0, $$phi$trans$insert$i52 = 0, $$phi$trans$insert$i59 = 0, $$phi$trans$insert66 = 0, $$phi$trans$insert69 = 0, $$phi$trans$insert72 = 0, $$phi$trans$insert75 = 0, $$phi$trans$insert78 = 0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i10 = 0, $$pre$i$i14 = 0, $$pre$i$i18 = 0, $$pre$i$i22 = 0, $$pre$i$i26 = 0, $$pre$i$i34 = 0, $$pre$i$i41 = 0, $$pre$i$i48 = 0, $$pre$i$i55 = 0, $$pre$i$i62 = 0, $$pre$i$i7 = 0, $$pre$i3 = 0, $$pre$i30 = 0, $$pre$i37 = 0, $$pre$i44 = 0;
 var $$pre$i51 = 0, $$pre$i58 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i$i$i = 0, $$pre1$i$i12 = 0, $$pre1$i$i16 = 0, $$pre1$i$i20 = 0, $$pre1$i$i24 = 0, $$pre1$i$i28 = 0, $$pre1$i32 = 0, $$pre1$i39 = 0, $$pre1$i46 = 0, $$pre1$i5 = 0, $$pre1$i53 = 0, $$pre1$i60 = 0, $$pre64 = 0, $$pre65 = 0, $$pre67 = 0, $$pre68 = 0;
 var $$pre70 = 0, $$pre71 = 0, $$pre73 = 0, $$pre74 = 0, $$pre76 = 0, $$pre77 = 0, $$pre79 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $theAccessor$i25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i25 = sp + 8|0;
 $1 = (($this) + 24|0);
 $2 = (($inStartIndex) + 2)|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i4 = (($$pre$i3) + 8|0);
   $$pre1$i5 = HEAP32[$$phi$trans$insert$i4>>2]|0;
   $30 = $$pre$i3;$35 = $$pre1$i5;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i7 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i7;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 HEAP8[$theAccessor$i25>>0] = 0;
 $52 = (($theAccessor$i25) + 4|0);
 HEAP32[$52>>2] = 0;
 $53 = (($theAccessor$i25) + 8|0);
 HEAP32[$53>>2] = $2;
 $54 = (($theAccessor$i25) + 12|0);
 HEAP32[$54>>2] = $1;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_19PxVehicleEngineDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj517ES2_jfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i25,0);
 $55 = HEAP32[$inOperator>>2]|0;
 $56 = (($55) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0);
 if ($58) {
  $79 = 0;$82 = $55;
 } else {
  $59 = (($57) + -1)|0;
  $60 = (($55) + 4|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($61) + ($59<<3)|0) + 4|0);
  $63 = HEAP8[$62>>0]|0;
  $64 = ($63<<24>>24)==(0);
  if ($64) {
   $71 = $55;$73 = $57;
  } else {
   $65 = (($inOperator) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = (($67) + 20|0);
   $69 = HEAP32[$68>>2]|0;
   FUNCTION_TABLE_vi[$69 & 4095]($66);
   $$pre$i$i$i$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i = (($$pre$i$i$i$i) + 8|0);
   $$pre1$i$i$i$i = HEAP32[$$phi$trans$insert$i$i$i$i>>2]|0;
   $71 = $$pre$i$i$i$i;$73 = $$pre1$i$i$i$i;
  }
  $70 = (($71) + 8|0);
  $72 = (($73) + -1)|0;
  HEAP32[$70>>2] = $72;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre64 = HEAP32[$$phi$trans$insert>>2]|0;
  $79 = $$pre64;$82 = $$pre;
 }
 $74 = (($this) + 48|0);
 HEAP8[$theAccessor$i25>>0] = 0;
 $75 = (($theAccessor$i25) + 4|0);
 HEAP32[$75>>2] = 0;
 $76 = (($theAccessor$i25) + 8|0);
 ;HEAP32[$76+0>>2]=HEAP32[$74+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$74+8>>2]|0;HEAP32[$76+12>>2]=HEAP32[$74+12>>2]|0;
 $77 = HEAP32[$74>>2]|0;
 $78 = ($79|0)==(0);
 if ($78) {
  $103 = $82;$108 = 0;
 } else {
  $80 = (($79) + -1)|0;
  $81 = (($82) + 4|0);
  $83 = HEAP32[$81>>2]|0;
  $84 = ((($83) + ($80<<3)|0) + 4|0);
  $85 = HEAP8[$84>>0]|0;
  $86 = ($85<<24>>24)==(0);
  if ($86) {
   $87 = (($inOperator) + 4|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP32[$88>>2]|0;
   $90 = (($89) + 16|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($83) + ($80<<3)|0);
   $93 = HEAP32[$92>>2]|0;
   FUNCTION_TABLE_vii[$91 & 4095]($88,$93);
   $94 = HEAP32[$inOperator>>2]|0;
   $95 = (($94) + 8|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = (($96) + -1)|0;
   $98 = (($94) + 4|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ((($99) + ($97<<3)|0) + 4|0);
   HEAP8[$100>>0] = 1;
   $$pre$i30 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i31 = (($$pre$i30) + 8|0);
   $$pre1$i32 = HEAP32[$$phi$trans$insert$i31>>2]|0;
   $103 = $$pre$i30;$108 = $$pre1$i32;
  } else {
   $103 = $82;$108 = $79;
  }
 }
 HEAP32[$0>>2] = $77;
 $101 = (($0) + 4|0);
 HEAP8[$101>>0] = 0;
 $102 = (($103) + 12|0);
 $104 = HEAP32[$102>>2]|0;
 $105 = $104 & 2147483647;
 $106 = (($103) + 8|0);
 $107 = ($105>>>0)>($108>>>0);
 if ($107) {
  $109 = (($103) + 4|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (($110) + ($108<<3)|0);
  $112 = ($111|0)==(0|0);
  if ($112) {
   $124 = $108;
  } else {
   $113 = $0;
   $114 = $113;
   $115 = HEAP32[$114>>2]|0;
   $116 = (($113) + 4)|0;
   $117 = $116;
   $118 = HEAP32[$117>>2]|0;
   $119 = $111;
   $120 = $119;
   HEAP32[$120>>2] = $115;
   $121 = (($119) + 4)|0;
   $122 = $121;
   HEAP32[$122>>2] = $118;
   $$pre$i$i34 = HEAP32[$106>>2]|0;
   $124 = $$pre$i$i34;
  }
  $123 = (($124) + 1)|0;
  HEAP32[$106>>2] = $123;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($103,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj518ENS_22PxRepXPropertyAccessorILj518ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i25);
 $125 = HEAP32[$inOperator>>2]|0;
 $126 = (($125) + 8|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = ($127|0)==(0);
 if ($128) {
  $149 = 0;$152 = $125;
 } else {
  $129 = (($127) + -1)|0;
  $130 = (($125) + 4|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ((($131) + ($129<<3)|0) + 4|0);
  $133 = HEAP8[$132>>0]|0;
  $134 = ($133<<24>>24)==(0);
  if ($134) {
   $141 = $125;$143 = $127;
  } else {
   $135 = (($inOperator) + 4|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = HEAP32[$136>>2]|0;
   $138 = (($137) + 20|0);
   $139 = HEAP32[$138>>2]|0;
   FUNCTION_TABLE_vi[$139 & 4095]($136);
   $$pre$i$i10 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i11 = (($$pre$i$i10) + 8|0);
   $$pre1$i$i12 = HEAP32[$$phi$trans$insert$i$i11>>2]|0;
   $141 = $$pre$i$i10;$143 = $$pre1$i$i12;
  }
  $140 = (($141) + 8|0);
  $142 = (($143) + -1)|0;
  HEAP32[$140>>2] = $142;
  $$pre65 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert66 = (($$pre65) + 8|0);
  $$pre67 = HEAP32[$$phi$trans$insert66>>2]|0;
  $149 = $$pre67;$152 = $$pre65;
 }
 $144 = (($this) + 64|0);
 HEAP8[$theAccessor$i25>>0] = 0;
 $145 = (($theAccessor$i25) + 4|0);
 HEAP32[$145>>2] = 0;
 $146 = (($theAccessor$i25) + 8|0);
 ;HEAP32[$146+0>>2]=HEAP32[$144+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$144+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$144+8>>2]|0;HEAP32[$146+12>>2]=HEAP32[$144+12>>2]|0;
 $147 = HEAP32[$144>>2]|0;
 $148 = ($149|0)==(0);
 if ($148) {
  $173 = $152;$178 = 0;
 } else {
  $150 = (($149) + -1)|0;
  $151 = (($152) + 4|0);
  $153 = HEAP32[$151>>2]|0;
  $154 = ((($153) + ($150<<3)|0) + 4|0);
  $155 = HEAP8[$154>>0]|0;
  $156 = ($155<<24>>24)==(0);
  if ($156) {
   $157 = (($inOperator) + 4|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = HEAP32[$158>>2]|0;
   $160 = (($159) + 16|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = (($153) + ($150<<3)|0);
   $163 = HEAP32[$162>>2]|0;
   FUNCTION_TABLE_vii[$161 & 4095]($158,$163);
   $164 = HEAP32[$inOperator>>2]|0;
   $165 = (($164) + 8|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = (($166) + -1)|0;
   $168 = (($164) + 4|0);
   $169 = HEAP32[$168>>2]|0;
   $170 = ((($169) + ($167<<3)|0) + 4|0);
   HEAP8[$170>>0] = 1;
   $$pre$i37 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i38 = (($$pre$i37) + 8|0);
   $$pre1$i39 = HEAP32[$$phi$trans$insert$i38>>2]|0;
   $173 = $$pre$i37;$178 = $$pre1$i39;
  } else {
   $173 = $152;$178 = $149;
  }
 }
 HEAP32[$0>>2] = $147;
 $171 = (($0) + 4|0);
 HEAP8[$171>>0] = 0;
 $172 = (($173) + 12|0);
 $174 = HEAP32[$172>>2]|0;
 $175 = $174 & 2147483647;
 $176 = (($173) + 8|0);
 $177 = ($175>>>0)>($178>>>0);
 if ($177) {
  $179 = (($173) + 4|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = (($180) + ($178<<3)|0);
  $182 = ($181|0)==(0|0);
  if ($182) {
   $194 = $178;
  } else {
   $183 = $0;
   $184 = $183;
   $185 = HEAP32[$184>>2]|0;
   $186 = (($183) + 4)|0;
   $187 = $186;
   $188 = HEAP32[$187>>2]|0;
   $189 = $181;
   $190 = $189;
   HEAP32[$190>>2] = $185;
   $191 = (($189) + 4)|0;
   $192 = $191;
   HEAP32[$192>>2] = $188;
   $$pre$i$i41 = HEAP32[$176>>2]|0;
   $194 = $$pre$i$i41;
  }
  $193 = (($194) + 1)|0;
  HEAP32[$176>>2] = $193;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($173,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj519ENS_22PxRepXPropertyAccessorILj519ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i25);
 $195 = HEAP32[$inOperator>>2]|0;
 $196 = (($195) + 8|0);
 $197 = HEAP32[$196>>2]|0;
 $198 = ($197|0)==(0);
 if ($198) {
  $219 = 0;$222 = $195;
 } else {
  $199 = (($197) + -1)|0;
  $200 = (($195) + 4|0);
  $201 = HEAP32[$200>>2]|0;
  $202 = ((($201) + ($199<<3)|0) + 4|0);
  $203 = HEAP8[$202>>0]|0;
  $204 = ($203<<24>>24)==(0);
  if ($204) {
   $211 = $195;$213 = $197;
  } else {
   $205 = (($inOperator) + 4|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = HEAP32[$206>>2]|0;
   $208 = (($207) + 20|0);
   $209 = HEAP32[$208>>2]|0;
   FUNCTION_TABLE_vi[$209 & 4095]($206);
   $$pre$i$i14 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i15 = (($$pre$i$i14) + 8|0);
   $$pre1$i$i16 = HEAP32[$$phi$trans$insert$i$i15>>2]|0;
   $211 = $$pre$i$i14;$213 = $$pre1$i$i16;
  }
  $210 = (($211) + 8|0);
  $212 = (($213) + -1)|0;
  HEAP32[$210>>2] = $212;
  $$pre68 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert69 = (($$pre68) + 8|0);
  $$pre70 = HEAP32[$$phi$trans$insert69>>2]|0;
  $219 = $$pre70;$222 = $$pre68;
 }
 $214 = (($this) + 80|0);
 HEAP8[$theAccessor$i25>>0] = 0;
 $215 = (($theAccessor$i25) + 4|0);
 HEAP32[$215>>2] = 0;
 $216 = (($theAccessor$i25) + 8|0);
 ;HEAP32[$216+0>>2]=HEAP32[$214+0>>2]|0;HEAP32[$216+4>>2]=HEAP32[$214+4>>2]|0;HEAP32[$216+8>>2]=HEAP32[$214+8>>2]|0;HEAP32[$216+12>>2]=HEAP32[$214+12>>2]|0;
 $217 = HEAP32[$214>>2]|0;
 $218 = ($219|0)==(0);
 if ($218) {
  $243 = $222;$248 = 0;
 } else {
  $220 = (($219) + -1)|0;
  $221 = (($222) + 4|0);
  $223 = HEAP32[$221>>2]|0;
  $224 = ((($223) + ($220<<3)|0) + 4|0);
  $225 = HEAP8[$224>>0]|0;
  $226 = ($225<<24>>24)==(0);
  if ($226) {
   $227 = (($inOperator) + 4|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = HEAP32[$228>>2]|0;
   $230 = (($229) + 16|0);
   $231 = HEAP32[$230>>2]|0;
   $232 = (($223) + ($220<<3)|0);
   $233 = HEAP32[$232>>2]|0;
   FUNCTION_TABLE_vii[$231 & 4095]($228,$233);
   $234 = HEAP32[$inOperator>>2]|0;
   $235 = (($234) + 8|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = (($236) + -1)|0;
   $238 = (($234) + 4|0);
   $239 = HEAP32[$238>>2]|0;
   $240 = ((($239) + ($237<<3)|0) + 4|0);
   HEAP8[$240>>0] = 1;
   $$pre$i44 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i45 = (($$pre$i44) + 8|0);
   $$pre1$i46 = HEAP32[$$phi$trans$insert$i45>>2]|0;
   $243 = $$pre$i44;$248 = $$pre1$i46;
  } else {
   $243 = $222;$248 = $219;
  }
 }
 HEAP32[$0>>2] = $217;
 $241 = (($0) + 4|0);
 HEAP8[$241>>0] = 0;
 $242 = (($243) + 12|0);
 $244 = HEAP32[$242>>2]|0;
 $245 = $244 & 2147483647;
 $246 = (($243) + 8|0);
 $247 = ($245>>>0)>($248>>>0);
 if ($247) {
  $249 = (($243) + 4|0);
  $250 = HEAP32[$249>>2]|0;
  $251 = (($250) + ($248<<3)|0);
  $252 = ($251|0)==(0|0);
  if ($252) {
   $264 = $248;
  } else {
   $253 = $0;
   $254 = $253;
   $255 = HEAP32[$254>>2]|0;
   $256 = (($253) + 4)|0;
   $257 = $256;
   $258 = HEAP32[$257>>2]|0;
   $259 = $251;
   $260 = $259;
   HEAP32[$260>>2] = $255;
   $261 = (($259) + 4)|0;
   $262 = $261;
   HEAP32[$262>>2] = $258;
   $$pre$i$i48 = HEAP32[$246>>2]|0;
   $264 = $$pre$i$i48;
  }
  $263 = (($264) + 1)|0;
  HEAP32[$246>>2] = $263;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($243,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj520ENS_22PxRepXPropertyAccessorILj520ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i25);
 $265 = HEAP32[$inOperator>>2]|0;
 $266 = (($265) + 8|0);
 $267 = HEAP32[$266>>2]|0;
 $268 = ($267|0)==(0);
 if ($268) {
  $289 = 0;$292 = $265;
 } else {
  $269 = (($267) + -1)|0;
  $270 = (($265) + 4|0);
  $271 = HEAP32[$270>>2]|0;
  $272 = ((($271) + ($269<<3)|0) + 4|0);
  $273 = HEAP8[$272>>0]|0;
  $274 = ($273<<24>>24)==(0);
  if ($274) {
   $281 = $265;$283 = $267;
  } else {
   $275 = (($inOperator) + 4|0);
   $276 = HEAP32[$275>>2]|0;
   $277 = HEAP32[$276>>2]|0;
   $278 = (($277) + 20|0);
   $279 = HEAP32[$278>>2]|0;
   FUNCTION_TABLE_vi[$279 & 4095]($276);
   $$pre$i$i18 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i19 = (($$pre$i$i18) + 8|0);
   $$pre1$i$i20 = HEAP32[$$phi$trans$insert$i$i19>>2]|0;
   $281 = $$pre$i$i18;$283 = $$pre1$i$i20;
  }
  $280 = (($281) + 8|0);
  $282 = (($283) + -1)|0;
  HEAP32[$280>>2] = $282;
  $$pre71 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert72 = (($$pre71) + 8|0);
  $$pre73 = HEAP32[$$phi$trans$insert72>>2]|0;
  $289 = $$pre73;$292 = $$pre71;
 }
 $284 = (($this) + 96|0);
 HEAP8[$theAccessor$i25>>0] = 0;
 $285 = (($theAccessor$i25) + 4|0);
 HEAP32[$285>>2] = 0;
 $286 = (($theAccessor$i25) + 8|0);
 ;HEAP32[$286+0>>2]=HEAP32[$284+0>>2]|0;HEAP32[$286+4>>2]=HEAP32[$284+4>>2]|0;HEAP32[$286+8>>2]=HEAP32[$284+8>>2]|0;HEAP32[$286+12>>2]=HEAP32[$284+12>>2]|0;
 $287 = HEAP32[$284>>2]|0;
 $288 = ($289|0)==(0);
 if ($288) {
  $313 = $292;$318 = 0;
 } else {
  $290 = (($289) + -1)|0;
  $291 = (($292) + 4|0);
  $293 = HEAP32[$291>>2]|0;
  $294 = ((($293) + ($290<<3)|0) + 4|0);
  $295 = HEAP8[$294>>0]|0;
  $296 = ($295<<24>>24)==(0);
  if ($296) {
   $297 = (($inOperator) + 4|0);
   $298 = HEAP32[$297>>2]|0;
   $299 = HEAP32[$298>>2]|0;
   $300 = (($299) + 16|0);
   $301 = HEAP32[$300>>2]|0;
   $302 = (($293) + ($290<<3)|0);
   $303 = HEAP32[$302>>2]|0;
   FUNCTION_TABLE_vii[$301 & 4095]($298,$303);
   $304 = HEAP32[$inOperator>>2]|0;
   $305 = (($304) + 8|0);
   $306 = HEAP32[$305>>2]|0;
   $307 = (($306) + -1)|0;
   $308 = (($304) + 4|0);
   $309 = HEAP32[$308>>2]|0;
   $310 = ((($309) + ($307<<3)|0) + 4|0);
   HEAP8[$310>>0] = 1;
   $$pre$i51 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i52 = (($$pre$i51) + 8|0);
   $$pre1$i53 = HEAP32[$$phi$trans$insert$i52>>2]|0;
   $313 = $$pre$i51;$318 = $$pre1$i53;
  } else {
   $313 = $292;$318 = $289;
  }
 }
 HEAP32[$0>>2] = $287;
 $311 = (($0) + 4|0);
 HEAP8[$311>>0] = 0;
 $312 = (($313) + 12|0);
 $314 = HEAP32[$312>>2]|0;
 $315 = $314 & 2147483647;
 $316 = (($313) + 8|0);
 $317 = ($315>>>0)>($318>>>0);
 if ($317) {
  $319 = (($313) + 4|0);
  $320 = HEAP32[$319>>2]|0;
  $321 = (($320) + ($318<<3)|0);
  $322 = ($321|0)==(0|0);
  if ($322) {
   $334 = $318;
  } else {
   $323 = $0;
   $324 = $323;
   $325 = HEAP32[$324>>2]|0;
   $326 = (($323) + 4)|0;
   $327 = $326;
   $328 = HEAP32[$327>>2]|0;
   $329 = $321;
   $330 = $329;
   HEAP32[$330>>2] = $325;
   $331 = (($329) + 4)|0;
   $332 = $331;
   HEAP32[$332>>2] = $328;
   $$pre$i$i55 = HEAP32[$316>>2]|0;
   $334 = $$pre$i$i55;
  }
  $333 = (($334) + 1)|0;
  HEAP32[$316>>2] = $333;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($313,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj521ENS_22PxRepXPropertyAccessorILj521ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i25);
 $335 = HEAP32[$inOperator>>2]|0;
 $336 = (($335) + 8|0);
 $337 = HEAP32[$336>>2]|0;
 $338 = ($337|0)==(0);
 if ($338) {
  $359 = 0;$362 = $335;
 } else {
  $339 = (($337) + -1)|0;
  $340 = (($335) + 4|0);
  $341 = HEAP32[$340>>2]|0;
  $342 = ((($341) + ($339<<3)|0) + 4|0);
  $343 = HEAP8[$342>>0]|0;
  $344 = ($343<<24>>24)==(0);
  if ($344) {
   $351 = $335;$353 = $337;
  } else {
   $345 = (($inOperator) + 4|0);
   $346 = HEAP32[$345>>2]|0;
   $347 = HEAP32[$346>>2]|0;
   $348 = (($347) + 20|0);
   $349 = HEAP32[$348>>2]|0;
   FUNCTION_TABLE_vi[$349 & 4095]($346);
   $$pre$i$i22 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i23 = (($$pre$i$i22) + 8|0);
   $$pre1$i$i24 = HEAP32[$$phi$trans$insert$i$i23>>2]|0;
   $351 = $$pre$i$i22;$353 = $$pre1$i$i24;
  }
  $350 = (($351) + 8|0);
  $352 = (($353) + -1)|0;
  HEAP32[$350>>2] = $352;
  $$pre74 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert75 = (($$pre74) + 8|0);
  $$pre76 = HEAP32[$$phi$trans$insert75>>2]|0;
  $359 = $$pre76;$362 = $$pre74;
 }
 $354 = (($this) + 112|0);
 HEAP8[$theAccessor$i25>>0] = 0;
 $355 = (($theAccessor$i25) + 4|0);
 HEAP32[$355>>2] = 0;
 $356 = (($theAccessor$i25) + 8|0);
 ;HEAP32[$356+0>>2]=HEAP32[$354+0>>2]|0;HEAP32[$356+4>>2]=HEAP32[$354+4>>2]|0;HEAP32[$356+8>>2]=HEAP32[$354+8>>2]|0;HEAP32[$356+12>>2]=HEAP32[$354+12>>2]|0;
 $357 = HEAP32[$354>>2]|0;
 $358 = ($359|0)==(0);
 if ($358) {
  $383 = $362;$388 = 0;
 } else {
  $360 = (($359) + -1)|0;
  $361 = (($362) + 4|0);
  $363 = HEAP32[$361>>2]|0;
  $364 = ((($363) + ($360<<3)|0) + 4|0);
  $365 = HEAP8[$364>>0]|0;
  $366 = ($365<<24>>24)==(0);
  if ($366) {
   $367 = (($inOperator) + 4|0);
   $368 = HEAP32[$367>>2]|0;
   $369 = HEAP32[$368>>2]|0;
   $370 = (($369) + 16|0);
   $371 = HEAP32[$370>>2]|0;
   $372 = (($363) + ($360<<3)|0);
   $373 = HEAP32[$372>>2]|0;
   FUNCTION_TABLE_vii[$371 & 4095]($368,$373);
   $374 = HEAP32[$inOperator>>2]|0;
   $375 = (($374) + 8|0);
   $376 = HEAP32[$375>>2]|0;
   $377 = (($376) + -1)|0;
   $378 = (($374) + 4|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = ((($379) + ($377<<3)|0) + 4|0);
   HEAP8[$380>>0] = 1;
   $$pre$i58 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i59 = (($$pre$i58) + 8|0);
   $$pre1$i60 = HEAP32[$$phi$trans$insert$i59>>2]|0;
   $383 = $$pre$i58;$388 = $$pre1$i60;
  } else {
   $383 = $362;$388 = $359;
  }
 }
 HEAP32[$0>>2] = $357;
 $381 = (($0) + 4|0);
 HEAP8[$381>>0] = 0;
 $382 = (($383) + 12|0);
 $384 = HEAP32[$382>>2]|0;
 $385 = $384 & 2147483647;
 $386 = (($383) + 8|0);
 $387 = ($385>>>0)>($388>>>0);
 if ($387) {
  $389 = (($383) + 4|0);
  $390 = HEAP32[$389>>2]|0;
  $391 = (($390) + ($388<<3)|0);
  $392 = ($391|0)==(0|0);
  if ($392) {
   $404 = $388;
  } else {
   $393 = $0;
   $394 = $393;
   $395 = HEAP32[$394>>2]|0;
   $396 = (($393) + 4)|0;
   $397 = $396;
   $398 = HEAP32[$397>>2]|0;
   $399 = $391;
   $400 = $399;
   HEAP32[$400>>2] = $395;
   $401 = (($399) + 4)|0;
   $402 = $401;
   HEAP32[$402>>2] = $398;
   $$pre$i$i62 = HEAP32[$386>>2]|0;
   $404 = $$pre$i$i62;
  }
  $403 = (($404) + 1)|0;
  HEAP32[$386>>2] = $403;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($383,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj522ENS_22PxRepXPropertyAccessorILj522ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i25);
 $405 = HEAP32[$inOperator>>2]|0;
 $406 = (($405) + 8|0);
 $407 = HEAP32[$406>>2]|0;
 $408 = ($407|0)==(0);
 if ($408) {
  $429 = 0;$432 = $405;
 } else {
  $409 = (($407) + -1)|0;
  $410 = (($405) + 4|0);
  $411 = HEAP32[$410>>2]|0;
  $412 = ((($411) + ($409<<3)|0) + 4|0);
  $413 = HEAP8[$412>>0]|0;
  $414 = ($413<<24>>24)==(0);
  if ($414) {
   $421 = $405;$423 = $407;
  } else {
   $415 = (($inOperator) + 4|0);
   $416 = HEAP32[$415>>2]|0;
   $417 = HEAP32[$416>>2]|0;
   $418 = (($417) + 20|0);
   $419 = HEAP32[$418>>2]|0;
   FUNCTION_TABLE_vi[$419 & 4095]($416);
   $$pre$i$i26 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i27 = (($$pre$i$i26) + 8|0);
   $$pre1$i$i28 = HEAP32[$$phi$trans$insert$i$i27>>2]|0;
   $421 = $$pre$i$i26;$423 = $$pre1$i$i28;
  }
  $420 = (($421) + 8|0);
  $422 = (($423) + -1)|0;
  HEAP32[$420>>2] = $422;
  $$pre77 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert78 = (($$pre77) + 8|0);
  $$pre79 = HEAP32[$$phi$trans$insert78>>2]|0;
  $429 = $$pre79;$432 = $$pre77;
 }
 $424 = (($this) + 128|0);
 HEAP8[$theAccessor$i25>>0] = 0;
 $425 = (($theAccessor$i25) + 4|0);
 HEAP32[$425>>2] = 0;
 $426 = (($theAccessor$i25) + 8|0);
 ;HEAP32[$426+0>>2]=HEAP32[$424+0>>2]|0;HEAP32[$426+4>>2]=HEAP32[$424+4>>2]|0;HEAP32[$426+8>>2]=HEAP32[$424+8>>2]|0;HEAP32[$426+12>>2]=HEAP32[$424+12>>2]|0;
 $427 = HEAP32[$424>>2]|0;
 $428 = ($429|0)==(0);
 do {
  if ($428) {
   $453 = $432;$458 = 0;
  } else {
   $430 = (($429) + -1)|0;
   $431 = (($432) + 4|0);
   $433 = HEAP32[$431>>2]|0;
   $434 = ((($433) + ($430<<3)|0) + 4|0);
   $435 = HEAP8[$434>>0]|0;
   $436 = ($435<<24>>24)==(0);
   if (!($436)) {
    $453 = $432;$458 = $429;
    break;
   }
   $437 = (($inOperator) + 4|0);
   $438 = HEAP32[$437>>2]|0;
   $439 = HEAP32[$438>>2]|0;
   $440 = (($439) + 16|0);
   $441 = HEAP32[$440>>2]|0;
   $442 = (($433) + ($430<<3)|0);
   $443 = HEAP32[$442>>2]|0;
   FUNCTION_TABLE_vii[$441 & 4095]($438,$443);
   $444 = HEAP32[$inOperator>>2]|0;
   $445 = (($444) + 8|0);
   $446 = HEAP32[$445>>2]|0;
   $447 = (($446) + -1)|0;
   $448 = (($444) + 4|0);
   $449 = HEAP32[$448>>2]|0;
   $450 = ((($449) + ($447<<3)|0) + 4|0);
   HEAP8[$450>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $453 = $$pre$i;$458 = $$pre1$i;
  }
 } while(0);
 HEAP32[$0>>2] = $427;
 $451 = (($0) + 4|0);
 HEAP8[$451>>0] = 0;
 $452 = (($453) + 12|0);
 $454 = HEAP32[$452>>2]|0;
 $455 = $454 & 2147483647;
 $456 = (($453) + 8|0);
 $457 = ($455>>>0)>($458>>>0);
 if ($457) {
  $459 = (($453) + 4|0);
  $460 = HEAP32[$459>>2]|0;
  $461 = (($460) + ($458<<3)|0);
  $462 = ($461|0)==(0|0);
  if ($462) {
   $474 = $458;
  } else {
   $463 = $0;
   $464 = $463;
   $465 = HEAP32[$464>>2]|0;
   $466 = (($463) + 4)|0;
   $467 = $466;
   $468 = HEAP32[$467>>2]|0;
   $469 = $461;
   $470 = $469;
   HEAP32[$470>>2] = $465;
   $471 = (($469) + 4)|0;
   $472 = $471;
   HEAP32[$472>>2] = $468;
   $$pre$i$i1 = HEAP32[$456>>2]|0;
   $474 = $$pre$i$i1;
  }
  $473 = (($474) + 1)|0;
  HEAP32[$456>>2] = $473;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($453,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj523ENS_22PxRepXPropertyAccessorILj523ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i25);
 $475 = HEAP32[$inOperator>>2]|0;
 $476 = (($475) + 8|0);
 $477 = HEAP32[$476>>2]|0;
 $478 = ($477|0)==(0);
 if ($478) {
  $494 = (($inStartIndex) + 9)|0;
  STACKTOP = sp;return ($494|0);
 }
 $479 = (($477) + -1)|0;
 $480 = (($475) + 4|0);
 $481 = HEAP32[$480>>2]|0;
 $482 = ((($481) + ($479<<3)|0) + 4|0);
 $483 = HEAP8[$482>>0]|0;
 $484 = ($483<<24>>24)==(0);
 if ($484) {
  $491 = $475;$493 = $477;
 } else {
  $485 = (($inOperator) + 4|0);
  $486 = HEAP32[$485>>2]|0;
  $487 = HEAP32[$486>>2]|0;
  $488 = (($487) + 20|0);
  $489 = HEAP32[$488>>2]|0;
  FUNCTION_TABLE_vi[$489 & 4095]($486);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $491 = $$pre$i$i;$493 = $$pre1$i$i;
 }
 $490 = (($491) + 8|0);
 $492 = (($493) + -1)|0;
 HEAP32[$490>>2] = $492;
 $494 = (($inStartIndex) + 9)|0;
 STACKTOP = sp;return ($494|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj523ENS_22PxRepXPropertyAccessorILj523ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 28;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj522ENS_22PxRepXPropertyAccessorILj522ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 24;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 24)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj521ENS_22PxRepXPropertyAccessorILj521ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 20;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 20)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj520ENS_22PxRepXPropertyAccessorILj520ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 16;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 16)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj519ENS_22PxRepXPropertyAccessorILj519ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 12;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEE14handleAccessorILj518ENS_22PxRepXPropertyAccessorILj518ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_19PxVehicleEngineDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj517ES2_jfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $buffer$i$i$i$i = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $theData = 0, $vararg_buffer1 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i$i = sp + 80|0;
 $theData = sp + 8|0;
 $2 = sp + 44|0;
 $buffer = sp + 48|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($inProp) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 $10 = (($theData) + 20|0);
 $11 = (($theData) + 24|0);
 $12 = (($theData) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($theData) + 32|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $theData;
 HEAP32[$13>>2] = 5;
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE6resizeEjRKf($theData,$9,$2);
 $14 = ($9|0)==(0);
 if (!($14)) {
  $15 = (($vararg_buffer1) + 4|0);
  $16 = (($this) + 4|0);
  $17 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer1)|0);
   $18 = HEAP32[$this>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $42 = $18;$47 = 0;
   } else {
    $22 = (($20) + -1)|0;
    $23 = (($18) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($24) + ($22<<3)|0) + 4|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($24) + ($22<<3)|0);
     $33 = HEAP32[$32>>2]|0;
     FUNCTION_TABLE_vii[$31 & 4095]($28,$33);
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + -1)|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39) + ($37<<3)|0) + 4|0);
     HEAP8[$40>>0] = 1;
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $42 = $$pre$i;$47 = $$pre1$i;
    } else {
     $42 = $18;$47 = $20;
    }
   }
   HEAP32[$vararg_buffer1>>2] = $buffer;
   HEAP8[$15>>0] = 0;
   $41 = (($42) + 12|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($42) + 8|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    $48 = (($42) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47<<3)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $63 = $47;
    } else {
     $52 = $vararg_buffer1;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $50;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $$pre$i$i = HEAP32[$45>>2]|0;
     $63 = $$pre$i$i;
    }
    $62 = (($63) + 1)|0;
    HEAP32[$45>>2] = $62;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($42,$vararg_buffer1)|0);
   }
   $64 = HEAP32[$3>>2]|0;
   $65 = HEAP32[$5>>2]|0;
   $66 = (($65) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (Math_fround(FUNCTION_TABLE_fii[$67 & 63]($64,$i$04)));
   $69 = HEAP32[$16>>2]|0;
   $70 = HEAP32[$17>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   $80 = +$68;
   dest=$buffer$i$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$80;HEAP32[$vararg_buffer1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer1+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i$i,0,521528,$vararg_buffer1)|0);
   $81 = HEAP8[$buffer$i$i$i$i>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if (!($82)) {
    $83 = HEAP32[$70>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = (_strlen(($buffer$i$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$84 & 2047]($70,$buffer$i$i$i$i,$85)|0);
   }
   HEAP8[$vararg_buffer1>>0] = 0;
   $86 = HEAP32[$70>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   (FUNCTION_TABLE_iiii[$87 & 2047]($70,$vararg_buffer1,1)|0);
   $88 = HEAP32[$69>>2]|0;
   $89 = (($88) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($70) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   FUNCTION_TABLE_viii[$90 & 4095]($69,$$0$i$i,$92);
   $93 = (($70) + 16|0);
   HEAP32[$93>>2] = 0;
   $94 = (($70) + 12|0);
   HEAP32[$94>>2] = 0;
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0);
   if (!($98)) {
    $99 = (($97) + -1)|0;
    $100 = (($95) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101) + ($99<<3)|0) + 4|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(0);
    if ($104) {
     $110 = $95;$112 = $97;
    } else {
     $105 = HEAP32[$16>>2]|0;
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + 20|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$108 & 4095]($105);
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $110 = $$pre$i1;$112 = $$pre1$i3;
    }
    $109 = (($110) + 8|0);
    $111 = (($112) + -1)|0;
    HEAP32[$109>>2] = $111;
   }
   $113 = (($i$04) + 1)|0;
   $exitcond = ($113|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $113;
   }
  }
 }
 $114 = HEAP32[$13>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i$i = $116 & $117;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$11>>2]|0;
 $119 = ($theData|0)==($118|0);
 if ($119) {
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $120 = ($118|0)==(0|0);
 if ($120) {
  STACKTOP = sp;return;
 }
 $121 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_vii[$124 & 4095]($121,$118);
 STACKTOP = sp;return;
}
function __ZNK5physx27PxVehicleDriveGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0;
 var $theAccessor$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i = sp + 8|0;
 $1 = (($this) + 80|0);
 HEAP8[$theAccessor$i>>0] = 0;
 $2 = (($theAccessor$i) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $31 = $$pre$i;$36 = $$pre1$i;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i1 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i1;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEE14handleAccessorILj666ENS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataESA_EEEEvRKT0_($inOperator,$theAccessor$i);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $72 = (($inStartIndex) + 2)|0;
  STACKTOP = sp;return ($72|0);
 }
 $57 = (($55) + -1)|0;
 $58 = (($53) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59) + ($57<<3)|0) + 4|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $69 = $53;$71 = $55;
 } else {
  $63 = (($inOperator) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + 20|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_vi[$67 & 4095]($64);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $69 = $$pre$i$i;$71 = $$pre1$i$i;
 }
 $68 = (($69) + 8|0);
 $70 = (($71) + -1)|0;
 HEAP32[$68>>2] = $70;
 $72 = (($inStartIndex) + 2)|0;
 STACKTOP = sp;return ($72|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEE14handleAccessorILj666ENS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 720|0;
 $info$i$i$i$i$i = sp + 424|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 128|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 112;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 112)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 _memset(($1|0),0,296)|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx34PxVehicleDriveDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx34PxVehicleDriveDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i$i$i = 0, $$phi$trans$insert$i$i11 = 0, $$phi$trans$insert$i$i15 = 0, $$phi$trans$insert$i$i19 = 0, $$phi$trans$insert$i$i23 = 0, $$phi$trans$insert$i$i27 = 0, $$phi$trans$insert$i$i31 = 0, $$phi$trans$insert$i$i35 = 0, $$phi$trans$insert$i$i39 = 0, $$phi$trans$insert$i$i43 = 0, $$phi$trans$insert$i$i47 = 0, $$phi$trans$insert$i$i51 = 0, $$phi$trans$insert$i$i55 = 0, $$phi$trans$insert$i$i59 = 0, $$phi$trans$insert$i$i63 = 0, $$phi$trans$insert$i$i67 = 0, $$phi$trans$insert$i$i71 = 0;
 var $$phi$trans$insert$i103 = 0, $$phi$trans$insert$i110 = 0, $$phi$trans$insert$i117 = 0, $$phi$trans$insert$i124 = 0, $$phi$trans$insert$i131 = 0, $$phi$trans$insert$i138 = 0, $$phi$trans$insert$i145 = 0, $$phi$trans$insert$i152 = 0, $$phi$trans$insert$i159 = 0, $$phi$trans$insert$i166 = 0, $$phi$trans$insert$i173 = 0, $$phi$trans$insert$i180 = 0, $$phi$trans$insert$i4 = 0, $$phi$trans$insert$i75 = 0, $$phi$trans$insert$i82 = 0, $$phi$trans$insert$i89 = 0, $$phi$trans$insert$i96 = 0, $$phi$trans$insert187 = 0, $$phi$trans$insert190 = 0, $$phi$trans$insert193 = 0;
 var $$phi$trans$insert196 = 0, $$phi$trans$insert199 = 0, $$phi$trans$insert202 = 0, $$phi$trans$insert205 = 0, $$phi$trans$insert208 = 0, $$phi$trans$insert211 = 0, $$phi$trans$insert214 = 0, $$phi$trans$insert217 = 0, $$phi$trans$insert220 = 0, $$phi$trans$insert223 = 0, $$phi$trans$insert226 = 0, $$phi$trans$insert229 = 0, $$phi$trans$insert232 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i10 = 0, $$pre$i$i106 = 0;
 var $$pre$i$i113 = 0, $$pre$i$i120 = 0, $$pre$i$i127 = 0, $$pre$i$i134 = 0, $$pre$i$i14 = 0, $$pre$i$i141 = 0, $$pre$i$i148 = 0, $$pre$i$i155 = 0, $$pre$i$i162 = 0, $$pre$i$i169 = 0, $$pre$i$i176 = 0, $$pre$i$i18 = 0, $$pre$i$i183 = 0, $$pre$i$i22 = 0, $$pre$i$i26 = 0, $$pre$i$i30 = 0, $$pre$i$i34 = 0, $$pre$i$i38 = 0, $$pre$i$i42 = 0, $$pre$i$i46 = 0;
 var $$pre$i$i50 = 0, $$pre$i$i54 = 0, $$pre$i$i58 = 0, $$pre$i$i62 = 0, $$pre$i$i66 = 0, $$pre$i$i7 = 0, $$pre$i$i70 = 0, $$pre$i$i78 = 0, $$pre$i$i85 = 0, $$pre$i$i92 = 0, $$pre$i$i99 = 0, $$pre$i102 = 0, $$pre$i109 = 0, $$pre$i116 = 0, $$pre$i123 = 0, $$pre$i130 = 0, $$pre$i137 = 0, $$pre$i144 = 0, $$pre$i151 = 0, $$pre$i158 = 0;
 var $$pre$i165 = 0, $$pre$i172 = 0, $$pre$i179 = 0, $$pre$i3 = 0, $$pre$i74 = 0, $$pre$i81 = 0, $$pre$i88 = 0, $$pre$i95 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i$i$i = 0, $$pre1$i$i12 = 0, $$pre1$i$i16 = 0, $$pre1$i$i20 = 0, $$pre1$i$i24 = 0, $$pre1$i$i28 = 0, $$pre1$i$i32 = 0, $$pre1$i$i36 = 0, $$pre1$i$i40 = 0, $$pre1$i$i44 = 0;
 var $$pre1$i$i48 = 0, $$pre1$i$i52 = 0, $$pre1$i$i56 = 0, $$pre1$i$i60 = 0, $$pre1$i$i64 = 0, $$pre1$i$i68 = 0, $$pre1$i$i72 = 0, $$pre1$i104 = 0, $$pre1$i111 = 0, $$pre1$i118 = 0, $$pre1$i125 = 0, $$pre1$i132 = 0, $$pre1$i139 = 0, $$pre1$i146 = 0, $$pre1$i153 = 0, $$pre1$i160 = 0, $$pre1$i167 = 0, $$pre1$i174 = 0, $$pre1$i181 = 0, $$pre1$i5 = 0;
 var $$pre1$i76 = 0, $$pre1$i83 = 0, $$pre1$i90 = 0, $$pre1$i97 = 0, $$pre185 = 0, $$pre186 = 0, $$pre188 = 0, $$pre189 = 0, $$pre191 = 0, $$pre192 = 0, $$pre194 = 0, $$pre195 = 0, $$pre197 = 0, $$pre198 = 0, $$pre200 = 0, $$pre201 = 0, $$pre203 = 0, $$pre204 = 0, $$pre206 = 0, $$pre207 = 0;
 var $$pre209 = 0, $$pre210 = 0, $$pre212 = 0, $$pre213 = 0, $$pre215 = 0, $$pre216 = 0, $$pre218 = 0, $$pre219 = 0, $$pre221 = 0, $$pre222 = 0, $$pre224 = 0, $$pre225 = 0, $$pre227 = 0, $$pre228 = 0, $$pre230 = 0, $$pre231 = 0, $$pre233 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0;
 var $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0;
 var $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0;
 var $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0;
 var $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0;
 var $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0;
 var $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0;
 var $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0;
 var $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0;
 var $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0;
 var $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0;
 var $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0;
 var $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0;
 var $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0;
 var $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0;
 var $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0;
 var $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0;
 var $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0;
 var $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0;
 var $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0;
 var $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0;
 var $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0;
 var $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0;
 var $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0;
 var $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0;
 var $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0;
 var $theAccessor$i69 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i69 = sp + 8|0;
 $1 = HEAP32[$this>>2]|0;
 $2 = HEAP32[$inOperator>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $28 = $2;$33 = 0;
 } else {
  $6 = (($4) + -1)|0;
  $7 = (($2) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8) + ($6<<3)|0) + 4|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $12 = (($inOperator) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($8) + ($6<<3)|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vii[$16 & 4095]($13,$18);
   $19 = HEAP32[$inOperator>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + -1)|0;
   $23 = (($19) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($24) + ($22<<3)|0) + 4|0);
   HEAP8[$25>>0] = 1;
   $$pre$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i4 = (($$pre$i3) + 8|0);
   $$pre1$i5 = HEAP32[$$phi$trans$insert$i4>>2]|0;
   $28 = $$pre$i3;$33 = $$pre1$i5;
  } else {
   $28 = $2;$33 = $4;
  }
 }
 HEAP32[$0>>2] = $1;
 $26 = (($0) + 4|0);
 HEAP8[$26>>0] = 0;
 $27 = (($28) + 12|0);
 $29 = HEAP32[$27>>2]|0;
 $30 = $29 & 2147483647;
 $31 = (($28) + 8|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  $34 = (($28) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + ($33<<3)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   $49 = $33;
  } else {
   $38 = $0;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = (($38) + 4)|0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = $36;
   $45 = $44;
   HEAP32[$45>>2] = $40;
   $46 = (($44) + 4)|0;
   $47 = $46;
   HEAP32[$47>>2] = $43;
   $$pre$i$i7 = HEAP32[$31>>2]|0;
   $49 = $$pre$i$i7;
  }
  $48 = (($49) + 1)|0;
  HEAP32[$31>>2] = $48;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($28,$0)|0);
 }
 HEAP8[$theAccessor$i69>>0] = 0;
 $50 = (($theAccessor$i69) + 4|0);
 HEAP32[$50>>2] = 0;
 $51 = (($theAccessor$i69) + 8|0);
 HEAP32[$51>>2] = $inStartIndex;
 $52 = (($theAccessor$i69) + 12|0);
 HEAP32[$52>>2] = $this;
 __ZN5physx2Sn21RepXVisitorWriterBaseINS_21PxVehicleDriveDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj635ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($inOperator,0,$theAccessor$i69,0);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i$i$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i$i$i = (($$pre$i$i$i$i) + 8|0);
   $$pre1$i$i$i$i = HEAP32[$$phi$trans$insert$i$i$i$i>>2]|0;
   $69 = $$pre$i$i$i$i;$71 = $$pre1$i$i$i$i;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre185 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre185;$80 = $$pre;
 }
 $72 = (($this) + 24|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $73 = (($theAccessor$i69) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i74 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i75 = (($$pre$i74) + 8|0);
   $$pre1$i76 = HEAP32[$$phi$trans$insert$i75>>2]|0;
   $101 = $$pre$i74;$106 = $$pre1$i76;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i78 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i78;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj636ENS_22PxRepXPropertyAccessorILj636ES4_KbbEEEEvRKT0_($inOperator,$theAccessor$i69);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $147 = 0;$150 = $123;
 } else {
  $127 = (($125) + -1)|0;
  $128 = (($123) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ((($129) + ($127<<3)|0) + 4|0);
  $131 = HEAP8[$130>>0]|0;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $139 = $123;$141 = $125;
  } else {
   $133 = (($inOperator) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = HEAP32[$134>>2]|0;
   $136 = (($135) + 20|0);
   $137 = HEAP32[$136>>2]|0;
   FUNCTION_TABLE_vi[$137 & 4095]($134);
   $$pre$i$i10 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i11 = (($$pre$i$i10) + 8|0);
   $$pre1$i$i12 = HEAP32[$$phi$trans$insert$i$i11>>2]|0;
   $139 = $$pre$i$i10;$141 = $$pre1$i$i12;
  }
  $138 = (($139) + 8|0);
  $140 = (($141) + -1)|0;
  HEAP32[$138>>2] = $140;
  $$pre186 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert187 = (($$pre186) + 8|0);
  $$pre188 = HEAP32[$$phi$trans$insert187>>2]|0;
  $147 = $$pre188;$150 = $$pre186;
 }
 $142 = (($this) + 40|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $143 = (($theAccessor$i69) + 4|0);
 HEAP32[$143>>2] = 0;
 $144 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$144+0>>2]=HEAP32[$142+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$142+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$142+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$142+12>>2]|0;
 $145 = HEAP32[$142>>2]|0;
 $146 = ($147|0)==(0);
 if ($146) {
  $171 = $150;$176 = 0;
 } else {
  $148 = (($147) + -1)|0;
  $149 = (($150) + 4|0);
  $151 = HEAP32[$149>>2]|0;
  $152 = ((($151) + ($148<<3)|0) + 4|0);
  $153 = HEAP8[$152>>0]|0;
  $154 = ($153<<24>>24)==(0);
  if ($154) {
   $155 = (($inOperator) + 4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = HEAP32[$156>>2]|0;
   $158 = (($157) + 16|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($151) + ($148<<3)|0);
   $161 = HEAP32[$160>>2]|0;
   FUNCTION_TABLE_vii[$159 & 4095]($156,$161);
   $162 = HEAP32[$inOperator>>2]|0;
   $163 = (($162) + 8|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($164) + -1)|0;
   $166 = (($162) + 4|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ((($167) + ($165<<3)|0) + 4|0);
   HEAP8[$168>>0] = 1;
   $$pre$i81 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i82 = (($$pre$i81) + 8|0);
   $$pre1$i83 = HEAP32[$$phi$trans$insert$i82>>2]|0;
   $171 = $$pre$i81;$176 = $$pre1$i83;
  } else {
   $171 = $150;$176 = $147;
  }
 }
 HEAP32[$0>>2] = $145;
 $169 = (($0) + 4|0);
 HEAP8[$169>>0] = 0;
 $170 = (($171) + 12|0);
 $172 = HEAP32[$170>>2]|0;
 $173 = $172 & 2147483647;
 $174 = (($171) + 8|0);
 $175 = ($173>>>0)>($176>>>0);
 if ($175) {
  $177 = (($171) + 4|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + ($176<<3)|0);
  $180 = ($179|0)==(0|0);
  if ($180) {
   $192 = $176;
  } else {
   $181 = $0;
   $182 = $181;
   $183 = HEAP32[$182>>2]|0;
   $184 = (($181) + 4)|0;
   $185 = $184;
   $186 = HEAP32[$185>>2]|0;
   $187 = $179;
   $188 = $187;
   HEAP32[$188>>2] = $183;
   $189 = (($187) + 4)|0;
   $190 = $189;
   HEAP32[$190>>2] = $186;
   $$pre$i$i85 = HEAP32[$174>>2]|0;
   $192 = $$pre$i$i85;
  }
  $191 = (($192) + 1)|0;
  HEAP32[$174>>2] = $191;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($171,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj637ENS_22PxRepXPropertyAccessorILj637ES4_KbbEEEEvRKT0_($inOperator,$theAccessor$i69);
 $193 = HEAP32[$inOperator>>2]|0;
 $194 = (($193) + 8|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)==(0);
 if ($196) {
  $217 = 0;$220 = $193;
 } else {
  $197 = (($195) + -1)|0;
  $198 = (($193) + 4|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ((($199) + ($197<<3)|0) + 4|0);
  $201 = HEAP8[$200>>0]|0;
  $202 = ($201<<24>>24)==(0);
  if ($202) {
   $209 = $193;$211 = $195;
  } else {
   $203 = (($inOperator) + 4|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = HEAP32[$204>>2]|0;
   $206 = (($205) + 20|0);
   $207 = HEAP32[$206>>2]|0;
   FUNCTION_TABLE_vi[$207 & 4095]($204);
   $$pre$i$i14 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i15 = (($$pre$i$i14) + 8|0);
   $$pre1$i$i16 = HEAP32[$$phi$trans$insert$i$i15>>2]|0;
   $209 = $$pre$i$i14;$211 = $$pre1$i$i16;
  }
  $208 = (($209) + 8|0);
  $210 = (($211) + -1)|0;
  HEAP32[$208>>2] = $210;
  $$pre189 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert190 = (($$pre189) + 8|0);
  $$pre191 = HEAP32[$$phi$trans$insert190>>2]|0;
  $217 = $$pre191;$220 = $$pre189;
 }
 $212 = (($this) + 56|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $213 = (($theAccessor$i69) + 4|0);
 HEAP32[$213>>2] = 0;
 $214 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$214+0>>2]=HEAP32[$212+0>>2]|0;HEAP32[$214+4>>2]=HEAP32[$212+4>>2]|0;HEAP32[$214+8>>2]=HEAP32[$212+8>>2]|0;HEAP32[$214+12>>2]=HEAP32[$212+12>>2]|0;
 $215 = HEAP32[$212>>2]|0;
 $216 = ($217|0)==(0);
 if ($216) {
  $241 = $220;$246 = 0;
 } else {
  $218 = (($217) + -1)|0;
  $219 = (($220) + 4|0);
  $221 = HEAP32[$219>>2]|0;
  $222 = ((($221) + ($218<<3)|0) + 4|0);
  $223 = HEAP8[$222>>0]|0;
  $224 = ($223<<24>>24)==(0);
  if ($224) {
   $225 = (($inOperator) + 4|0);
   $226 = HEAP32[$225>>2]|0;
   $227 = HEAP32[$226>>2]|0;
   $228 = (($227) + 16|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = (($221) + ($218<<3)|0);
   $231 = HEAP32[$230>>2]|0;
   FUNCTION_TABLE_vii[$229 & 4095]($226,$231);
   $232 = HEAP32[$inOperator>>2]|0;
   $233 = (($232) + 8|0);
   $234 = HEAP32[$233>>2]|0;
   $235 = (($234) + -1)|0;
   $236 = (($232) + 4|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ((($237) + ($235<<3)|0) + 4|0);
   HEAP8[$238>>0] = 1;
   $$pre$i88 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i89 = (($$pre$i88) + 8|0);
   $$pre1$i90 = HEAP32[$$phi$trans$insert$i89>>2]|0;
   $241 = $$pre$i88;$246 = $$pre1$i90;
  } else {
   $241 = $220;$246 = $217;
  }
 }
 HEAP32[$0>>2] = $215;
 $239 = (($0) + 4|0);
 HEAP8[$239>>0] = 0;
 $240 = (($241) + 12|0);
 $242 = HEAP32[$240>>2]|0;
 $243 = $242 & 2147483647;
 $244 = (($241) + 8|0);
 $245 = ($243>>>0)>($246>>>0);
 if ($245) {
  $247 = (($241) + 4|0);
  $248 = HEAP32[$247>>2]|0;
  $249 = (($248) + ($246<<3)|0);
  $250 = ($249|0)==(0|0);
  if ($250) {
   $262 = $246;
  } else {
   $251 = $0;
   $252 = $251;
   $253 = HEAP32[$252>>2]|0;
   $254 = (($251) + 4)|0;
   $255 = $254;
   $256 = HEAP32[$255>>2]|0;
   $257 = $249;
   $258 = $257;
   HEAP32[$258>>2] = $253;
   $259 = (($257) + 4)|0;
   $260 = $259;
   HEAP32[$260>>2] = $256;
   $$pre$i$i92 = HEAP32[$244>>2]|0;
   $262 = $$pre$i$i92;
  }
  $261 = (($262) + 1)|0;
  HEAP32[$244>>2] = $261;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($241,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj638ENS_22PxRepXPropertyAccessorILj638ES4_KbbEEEEvRKT0_($inOperator,$theAccessor$i69);
 $263 = HEAP32[$inOperator>>2]|0;
 $264 = (($263) + 8|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = ($265|0)==(0);
 if ($266) {
  $287 = 0;$290 = $263;
 } else {
  $267 = (($265) + -1)|0;
  $268 = (($263) + 4|0);
  $269 = HEAP32[$268>>2]|0;
  $270 = ((($269) + ($267<<3)|0) + 4|0);
  $271 = HEAP8[$270>>0]|0;
  $272 = ($271<<24>>24)==(0);
  if ($272) {
   $279 = $263;$281 = $265;
  } else {
   $273 = (($inOperator) + 4|0);
   $274 = HEAP32[$273>>2]|0;
   $275 = HEAP32[$274>>2]|0;
   $276 = (($275) + 20|0);
   $277 = HEAP32[$276>>2]|0;
   FUNCTION_TABLE_vi[$277 & 4095]($274);
   $$pre$i$i18 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i19 = (($$pre$i$i18) + 8|0);
   $$pre1$i$i20 = HEAP32[$$phi$trans$insert$i$i19>>2]|0;
   $279 = $$pre$i$i18;$281 = $$pre1$i$i20;
  }
  $278 = (($279) + 8|0);
  $280 = (($281) + -1)|0;
  HEAP32[$278>>2] = $280;
  $$pre192 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert193 = (($$pre192) + 8|0);
  $$pre194 = HEAP32[$$phi$trans$insert193>>2]|0;
  $287 = $$pre194;$290 = $$pre192;
 }
 $282 = (($this) + 72|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $283 = (($theAccessor$i69) + 4|0);
 HEAP32[$283>>2] = 0;
 $284 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$284+0>>2]=HEAP32[$282+0>>2]|0;HEAP32[$284+4>>2]=HEAP32[$282+4>>2]|0;HEAP32[$284+8>>2]=HEAP32[$282+8>>2]|0;HEAP32[$284+12>>2]=HEAP32[$282+12>>2]|0;
 $285 = HEAP32[$282>>2]|0;
 $286 = ($287|0)==(0);
 if ($286) {
  $311 = $290;$316 = 0;
 } else {
  $288 = (($287) + -1)|0;
  $289 = (($290) + 4|0);
  $291 = HEAP32[$289>>2]|0;
  $292 = ((($291) + ($288<<3)|0) + 4|0);
  $293 = HEAP8[$292>>0]|0;
  $294 = ($293<<24>>24)==(0);
  if ($294) {
   $295 = (($inOperator) + 4|0);
   $296 = HEAP32[$295>>2]|0;
   $297 = HEAP32[$296>>2]|0;
   $298 = (($297) + 16|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = (($291) + ($288<<3)|0);
   $301 = HEAP32[$300>>2]|0;
   FUNCTION_TABLE_vii[$299 & 4095]($296,$301);
   $302 = HEAP32[$inOperator>>2]|0;
   $303 = (($302) + 8|0);
   $304 = HEAP32[$303>>2]|0;
   $305 = (($304) + -1)|0;
   $306 = (($302) + 4|0);
   $307 = HEAP32[$306>>2]|0;
   $308 = ((($307) + ($305<<3)|0) + 4|0);
   HEAP8[$308>>0] = 1;
   $$pre$i95 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i96 = (($$pre$i95) + 8|0);
   $$pre1$i97 = HEAP32[$$phi$trans$insert$i96>>2]|0;
   $311 = $$pre$i95;$316 = $$pre1$i97;
  } else {
   $311 = $290;$316 = $287;
  }
 }
 HEAP32[$0>>2] = $285;
 $309 = (($0) + 4|0);
 HEAP8[$309>>0] = 0;
 $310 = (($311) + 12|0);
 $312 = HEAP32[$310>>2]|0;
 $313 = $312 & 2147483647;
 $314 = (($311) + 8|0);
 $315 = ($313>>>0)>($316>>>0);
 if ($315) {
  $317 = (($311) + 4|0);
  $318 = HEAP32[$317>>2]|0;
  $319 = (($318) + ($316<<3)|0);
  $320 = ($319|0)==(0|0);
  if ($320) {
   $332 = $316;
  } else {
   $321 = $0;
   $322 = $321;
   $323 = HEAP32[$322>>2]|0;
   $324 = (($321) + 4)|0;
   $325 = $324;
   $326 = HEAP32[$325>>2]|0;
   $327 = $319;
   $328 = $327;
   HEAP32[$328>>2] = $323;
   $329 = (($327) + 4)|0;
   $330 = $329;
   HEAP32[$330>>2] = $326;
   $$pre$i$i99 = HEAP32[$314>>2]|0;
   $332 = $$pre$i$i99;
  }
  $331 = (($332) + 1)|0;
  HEAP32[$314>>2] = $331;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($311,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj639ENS_22PxRepXPropertyAccessorILj639ES4_jjEEEEvRKT0_($inOperator,$theAccessor$i69);
 $333 = HEAP32[$inOperator>>2]|0;
 $334 = (($333) + 8|0);
 $335 = HEAP32[$334>>2]|0;
 $336 = ($335|0)==(0);
 if ($336) {
  $357 = 0;$360 = $333;
 } else {
  $337 = (($335) + -1)|0;
  $338 = (($333) + 4|0);
  $339 = HEAP32[$338>>2]|0;
  $340 = ((($339) + ($337<<3)|0) + 4|0);
  $341 = HEAP8[$340>>0]|0;
  $342 = ($341<<24>>24)==(0);
  if ($342) {
   $349 = $333;$351 = $335;
  } else {
   $343 = (($inOperator) + 4|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = HEAP32[$344>>2]|0;
   $346 = (($345) + 20|0);
   $347 = HEAP32[$346>>2]|0;
   FUNCTION_TABLE_vi[$347 & 4095]($344);
   $$pre$i$i22 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i23 = (($$pre$i$i22) + 8|0);
   $$pre1$i$i24 = HEAP32[$$phi$trans$insert$i$i23>>2]|0;
   $349 = $$pre$i$i22;$351 = $$pre1$i$i24;
  }
  $348 = (($349) + 8|0);
  $350 = (($351) + -1)|0;
  HEAP32[$348>>2] = $350;
  $$pre195 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert196 = (($$pre195) + 8|0);
  $$pre197 = HEAP32[$$phi$trans$insert196>>2]|0;
  $357 = $$pre197;$360 = $$pre195;
 }
 $352 = (($this) + 88|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $353 = (($theAccessor$i69) + 4|0);
 HEAP32[$353>>2] = 0;
 $354 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$354+0>>2]=HEAP32[$352+0>>2]|0;HEAP32[$354+4>>2]=HEAP32[$352+4>>2]|0;HEAP32[$354+8>>2]=HEAP32[$352+8>>2]|0;HEAP32[$354+12>>2]=HEAP32[$352+12>>2]|0;
 $355 = HEAP32[$352>>2]|0;
 $356 = ($357|0)==(0);
 if ($356) {
  $381 = $360;$386 = 0;
 } else {
  $358 = (($357) + -1)|0;
  $359 = (($360) + 4|0);
  $361 = HEAP32[$359>>2]|0;
  $362 = ((($361) + ($358<<3)|0) + 4|0);
  $363 = HEAP8[$362>>0]|0;
  $364 = ($363<<24>>24)==(0);
  if ($364) {
   $365 = (($inOperator) + 4|0);
   $366 = HEAP32[$365>>2]|0;
   $367 = HEAP32[$366>>2]|0;
   $368 = (($367) + 16|0);
   $369 = HEAP32[$368>>2]|0;
   $370 = (($361) + ($358<<3)|0);
   $371 = HEAP32[$370>>2]|0;
   FUNCTION_TABLE_vii[$369 & 4095]($366,$371);
   $372 = HEAP32[$inOperator>>2]|0;
   $373 = (($372) + 8|0);
   $374 = HEAP32[$373>>2]|0;
   $375 = (($374) + -1)|0;
   $376 = (($372) + 4|0);
   $377 = HEAP32[$376>>2]|0;
   $378 = ((($377) + ($375<<3)|0) + 4|0);
   HEAP8[$378>>0] = 1;
   $$pre$i102 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i103 = (($$pre$i102) + 8|0);
   $$pre1$i104 = HEAP32[$$phi$trans$insert$i103>>2]|0;
   $381 = $$pre$i102;$386 = $$pre1$i104;
  } else {
   $381 = $360;$386 = $357;
  }
 }
 HEAP32[$0>>2] = $355;
 $379 = (($0) + 4|0);
 HEAP8[$379>>0] = 0;
 $380 = (($381) + 12|0);
 $382 = HEAP32[$380>>2]|0;
 $383 = $382 & 2147483647;
 $384 = (($381) + 8|0);
 $385 = ($383>>>0)>($386>>>0);
 if ($385) {
  $387 = (($381) + 4|0);
  $388 = HEAP32[$387>>2]|0;
  $389 = (($388) + ($386<<3)|0);
  $390 = ($389|0)==(0|0);
  if ($390) {
   $402 = $386;
  } else {
   $391 = $0;
   $392 = $391;
   $393 = HEAP32[$392>>2]|0;
   $394 = (($391) + 4)|0;
   $395 = $394;
   $396 = HEAP32[$395>>2]|0;
   $397 = $389;
   $398 = $397;
   HEAP32[$398>>2] = $393;
   $399 = (($397) + 4)|0;
   $400 = $399;
   HEAP32[$400>>2] = $396;
   $$pre$i$i106 = HEAP32[$384>>2]|0;
   $402 = $$pre$i$i106;
  }
  $401 = (($402) + 1)|0;
  HEAP32[$384>>2] = $401;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($381,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj640ENS_22PxRepXPropertyAccessorILj640ES4_jjEEEEvRKT0_($inOperator,$theAccessor$i69);
 $403 = HEAP32[$inOperator>>2]|0;
 $404 = (($403) + 8|0);
 $405 = HEAP32[$404>>2]|0;
 $406 = ($405|0)==(0);
 if ($406) {
  $427 = 0;$430 = $403;
 } else {
  $407 = (($405) + -1)|0;
  $408 = (($403) + 4|0);
  $409 = HEAP32[$408>>2]|0;
  $410 = ((($409) + ($407<<3)|0) + 4|0);
  $411 = HEAP8[$410>>0]|0;
  $412 = ($411<<24>>24)==(0);
  if ($412) {
   $419 = $403;$421 = $405;
  } else {
   $413 = (($inOperator) + 4|0);
   $414 = HEAP32[$413>>2]|0;
   $415 = HEAP32[$414>>2]|0;
   $416 = (($415) + 20|0);
   $417 = HEAP32[$416>>2]|0;
   FUNCTION_TABLE_vi[$417 & 4095]($414);
   $$pre$i$i26 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i27 = (($$pre$i$i26) + 8|0);
   $$pre1$i$i28 = HEAP32[$$phi$trans$insert$i$i27>>2]|0;
   $419 = $$pre$i$i26;$421 = $$pre1$i$i28;
  }
  $418 = (($419) + 8|0);
  $420 = (($421) + -1)|0;
  HEAP32[$418>>2] = $420;
  $$pre198 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert199 = (($$pre198) + 8|0);
  $$pre200 = HEAP32[$$phi$trans$insert199>>2]|0;
  $427 = $$pre200;$430 = $$pre198;
 }
 $422 = (($this) + 104|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $423 = (($theAccessor$i69) + 4|0);
 HEAP32[$423>>2] = 0;
 $424 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$424+0>>2]=HEAP32[$422+0>>2]|0;HEAP32[$424+4>>2]=HEAP32[$422+4>>2]|0;HEAP32[$424+8>>2]=HEAP32[$422+8>>2]|0;HEAP32[$424+12>>2]=HEAP32[$422+12>>2]|0;
 $425 = HEAP32[$422>>2]|0;
 $426 = ($427|0)==(0);
 do {
  if ($426) {
   $451 = $430;$456 = 0;
  } else {
   $428 = (($427) + -1)|0;
   $429 = (($430) + 4|0);
   $431 = HEAP32[$429>>2]|0;
   $432 = ((($431) + ($428<<3)|0) + 4|0);
   $433 = HEAP8[$432>>0]|0;
   $434 = ($433<<24>>24)==(0);
   if (!($434)) {
    $451 = $430;$456 = $427;
    break;
   }
   $435 = (($inOperator) + 4|0);
   $436 = HEAP32[$435>>2]|0;
   $437 = HEAP32[$436>>2]|0;
   $438 = (($437) + 16|0);
   $439 = HEAP32[$438>>2]|0;
   $440 = (($431) + ($428<<3)|0);
   $441 = HEAP32[$440>>2]|0;
   FUNCTION_TABLE_vii[$439 & 4095]($436,$441);
   $442 = HEAP32[$inOperator>>2]|0;
   $443 = (($442) + 8|0);
   $444 = HEAP32[$443>>2]|0;
   $445 = (($444) + -1)|0;
   $446 = (($442) + 4|0);
   $447 = HEAP32[$446>>2]|0;
   $448 = ((($447) + ($445<<3)|0) + 4|0);
   HEAP8[$448>>0] = 1;
   $$pre$i109 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i110 = (($$pre$i109) + 8|0);
   $$pre1$i111 = HEAP32[$$phi$trans$insert$i110>>2]|0;
   $451 = $$pre$i109;$456 = $$pre1$i111;
  }
 } while(0);
 HEAP32[$0>>2] = $425;
 $449 = (($0) + 4|0);
 HEAP8[$449>>0] = 0;
 $450 = (($451) + 12|0);
 $452 = HEAP32[$450>>2]|0;
 $453 = $452 & 2147483647;
 $454 = (($451) + 8|0);
 $455 = ($453>>>0)>($456>>>0);
 if ($455) {
  $457 = (($451) + 4|0);
  $458 = HEAP32[$457>>2]|0;
  $459 = (($458) + ($456<<3)|0);
  $460 = ($459|0)==(0|0);
  if ($460) {
   $472 = $456;
  } else {
   $461 = $0;
   $462 = $461;
   $463 = HEAP32[$462>>2]|0;
   $464 = (($461) + 4)|0;
   $465 = $464;
   $466 = HEAP32[$465>>2]|0;
   $467 = $459;
   $468 = $467;
   HEAP32[$468>>2] = $463;
   $469 = (($467) + 4)|0;
   $470 = $469;
   HEAP32[$470>>2] = $466;
   $$pre$i$i113 = HEAP32[$454>>2]|0;
   $472 = $$pre$i$i113;
  }
  $471 = (($472) + 1)|0;
  HEAP32[$454>>2] = $471;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($451,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj641ENS_22PxRepXPropertyAccessorILj641ES4_KffEEEEvRKT0_($inOperator,$theAccessor$i69);
 $473 = HEAP32[$inOperator>>2]|0;
 $474 = (($473) + 8|0);
 $475 = HEAP32[$474>>2]|0;
 $476 = ($475|0)==(0);
 if ($476) {
  $497 = 0;$500 = $473;
 } else {
  $477 = (($475) + -1)|0;
  $478 = (($473) + 4|0);
  $479 = HEAP32[$478>>2]|0;
  $480 = ((($479) + ($477<<3)|0) + 4|0);
  $481 = HEAP8[$480>>0]|0;
  $482 = ($481<<24>>24)==(0);
  if ($482) {
   $489 = $473;$491 = $475;
  } else {
   $483 = (($inOperator) + 4|0);
   $484 = HEAP32[$483>>2]|0;
   $485 = HEAP32[$484>>2]|0;
   $486 = (($485) + 20|0);
   $487 = HEAP32[$486>>2]|0;
   FUNCTION_TABLE_vi[$487 & 4095]($484);
   $$pre$i$i30 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i31 = (($$pre$i$i30) + 8|0);
   $$pre1$i$i32 = HEAP32[$$phi$trans$insert$i$i31>>2]|0;
   $489 = $$pre$i$i30;$491 = $$pre1$i$i32;
  }
  $488 = (($489) + 8|0);
  $490 = (($491) + -1)|0;
  HEAP32[$488>>2] = $490;
  $$pre201 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert202 = (($$pre201) + 8|0);
  $$pre203 = HEAP32[$$phi$trans$insert202>>2]|0;
  $497 = $$pre203;$500 = $$pre201;
 }
 $492 = (($this) + 120|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $493 = (($theAccessor$i69) + 4|0);
 HEAP32[$493>>2] = 0;
 $494 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$494+0>>2]=HEAP32[$492+0>>2]|0;HEAP32[$494+4>>2]=HEAP32[$492+4>>2]|0;HEAP32[$494+8>>2]=HEAP32[$492+8>>2]|0;HEAP32[$494+12>>2]=HEAP32[$492+12>>2]|0;
 $495 = HEAP32[$492>>2]|0;
 $496 = ($497|0)==(0);
 do {
  if ($496) {
   $521 = $500;$526 = 0;
  } else {
   $498 = (($497) + -1)|0;
   $499 = (($500) + 4|0);
   $501 = HEAP32[$499>>2]|0;
   $502 = ((($501) + ($498<<3)|0) + 4|0);
   $503 = HEAP8[$502>>0]|0;
   $504 = ($503<<24>>24)==(0);
   if (!($504)) {
    $521 = $500;$526 = $497;
    break;
   }
   $505 = (($inOperator) + 4|0);
   $506 = HEAP32[$505>>2]|0;
   $507 = HEAP32[$506>>2]|0;
   $508 = (($507) + 16|0);
   $509 = HEAP32[$508>>2]|0;
   $510 = (($501) + ($498<<3)|0);
   $511 = HEAP32[$510>>2]|0;
   FUNCTION_TABLE_vii[$509 & 4095]($506,$511);
   $512 = HEAP32[$inOperator>>2]|0;
   $513 = (($512) + 8|0);
   $514 = HEAP32[$513>>2]|0;
   $515 = (($514) + -1)|0;
   $516 = (($512) + 4|0);
   $517 = HEAP32[$516>>2]|0;
   $518 = ((($517) + ($515<<3)|0) + 4|0);
   HEAP8[$518>>0] = 1;
   $$pre$i116 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i117 = (($$pre$i116) + 8|0);
   $$pre1$i118 = HEAP32[$$phi$trans$insert$i117>>2]|0;
   $521 = $$pre$i116;$526 = $$pre1$i118;
  }
 } while(0);
 HEAP32[$0>>2] = $495;
 $519 = (($0) + 4|0);
 HEAP8[$519>>0] = 0;
 $520 = (($521) + 12|0);
 $522 = HEAP32[$520>>2]|0;
 $523 = $522 & 2147483647;
 $524 = (($521) + 8|0);
 $525 = ($523>>>0)>($526>>>0);
 if ($525) {
  $527 = (($521) + 4|0);
  $528 = HEAP32[$527>>2]|0;
  $529 = (($528) + ($526<<3)|0);
  $530 = ($529|0)==(0|0);
  if ($530) {
   $542 = $526;
  } else {
   $531 = $0;
   $532 = $531;
   $533 = HEAP32[$532>>2]|0;
   $534 = (($531) + 4)|0;
   $535 = $534;
   $536 = HEAP32[$535>>2]|0;
   $537 = $529;
   $538 = $537;
   HEAP32[$538>>2] = $533;
   $539 = (($537) + 4)|0;
   $540 = $539;
   HEAP32[$540>>2] = $536;
   $$pre$i$i120 = HEAP32[$524>>2]|0;
   $542 = $$pre$i$i120;
  }
  $541 = (($542) + 1)|0;
  HEAP32[$524>>2] = $541;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($521,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj642ENS_22PxRepXPropertyAccessorILj642ES4_KjjEEEEvRKT0_($inOperator,$theAccessor$i69);
 $543 = HEAP32[$inOperator>>2]|0;
 $544 = (($543) + 8|0);
 $545 = HEAP32[$544>>2]|0;
 $546 = ($545|0)==(0);
 if ($546) {
  $567 = 0;$570 = $543;
 } else {
  $547 = (($545) + -1)|0;
  $548 = (($543) + 4|0);
  $549 = HEAP32[$548>>2]|0;
  $550 = ((($549) + ($547<<3)|0) + 4|0);
  $551 = HEAP8[$550>>0]|0;
  $552 = ($551<<24>>24)==(0);
  if ($552) {
   $559 = $543;$561 = $545;
  } else {
   $553 = (($inOperator) + 4|0);
   $554 = HEAP32[$553>>2]|0;
   $555 = HEAP32[$554>>2]|0;
   $556 = (($555) + 20|0);
   $557 = HEAP32[$556>>2]|0;
   FUNCTION_TABLE_vi[$557 & 4095]($554);
   $$pre$i$i34 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i35 = (($$pre$i$i34) + 8|0);
   $$pre1$i$i36 = HEAP32[$$phi$trans$insert$i$i35>>2]|0;
   $559 = $$pre$i$i34;$561 = $$pre1$i$i36;
  }
  $558 = (($559) + 8|0);
  $560 = (($561) + -1)|0;
  HEAP32[$558>>2] = $560;
  $$pre204 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert205 = (($$pre204) + 8|0);
  $$pre206 = HEAP32[$$phi$trans$insert205>>2]|0;
  $567 = $$pre206;$570 = $$pre204;
 }
 $562 = (($this) + 136|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $563 = (($theAccessor$i69) + 4|0);
 HEAP32[$563>>2] = 0;
 $564 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$564+0>>2]=HEAP32[$562+0>>2]|0;HEAP32[$564+4>>2]=HEAP32[$562+4>>2]|0;HEAP32[$564+8>>2]=HEAP32[$562+8>>2]|0;HEAP32[$564+12>>2]=HEAP32[$562+12>>2]|0;
 $565 = HEAP32[$562>>2]|0;
 $566 = ($567|0)==(0);
 do {
  if ($566) {
   $591 = $570;$596 = 0;
  } else {
   $568 = (($567) + -1)|0;
   $569 = (($570) + 4|0);
   $571 = HEAP32[$569>>2]|0;
   $572 = ((($571) + ($568<<3)|0) + 4|0);
   $573 = HEAP8[$572>>0]|0;
   $574 = ($573<<24>>24)==(0);
   if (!($574)) {
    $591 = $570;$596 = $567;
    break;
   }
   $575 = (($inOperator) + 4|0);
   $576 = HEAP32[$575>>2]|0;
   $577 = HEAP32[$576>>2]|0;
   $578 = (($577) + 16|0);
   $579 = HEAP32[$578>>2]|0;
   $580 = (($571) + ($568<<3)|0);
   $581 = HEAP32[$580>>2]|0;
   FUNCTION_TABLE_vii[$579 & 4095]($576,$581);
   $582 = HEAP32[$inOperator>>2]|0;
   $583 = (($582) + 8|0);
   $584 = HEAP32[$583>>2]|0;
   $585 = (($584) + -1)|0;
   $586 = (($582) + 4|0);
   $587 = HEAP32[$586>>2]|0;
   $588 = ((($587) + ($585<<3)|0) + 4|0);
   HEAP8[$588>>0] = 1;
   $$pre$i123 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i124 = (($$pre$i123) + 8|0);
   $$pre1$i125 = HEAP32[$$phi$trans$insert$i124>>2]|0;
   $591 = $$pre$i123;$596 = $$pre1$i125;
  }
 } while(0);
 HEAP32[$0>>2] = $565;
 $589 = (($0) + 4|0);
 HEAP8[$589>>0] = 0;
 $590 = (($591) + 12|0);
 $592 = HEAP32[$590>>2]|0;
 $593 = $592 & 2147483647;
 $594 = (($591) + 8|0);
 $595 = ($593>>>0)>($596>>>0);
 if ($595) {
  $597 = (($591) + 4|0);
  $598 = HEAP32[$597>>2]|0;
  $599 = (($598) + ($596<<3)|0);
  $600 = ($599|0)==(0|0);
  if ($600) {
   $612 = $596;
  } else {
   $601 = $0;
   $602 = $601;
   $603 = HEAP32[$602>>2]|0;
   $604 = (($601) + 4)|0;
   $605 = $604;
   $606 = HEAP32[$605>>2]|0;
   $607 = $599;
   $608 = $607;
   HEAP32[$608>>2] = $603;
   $609 = (($607) + 4)|0;
   $610 = $609;
   HEAP32[$610>>2] = $606;
   $$pre$i$i127 = HEAP32[$594>>2]|0;
   $612 = $$pre$i$i127;
  }
  $611 = (($612) + 1)|0;
  HEAP32[$594>>2] = $611;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($591,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj643ENS_22PxRepXPropertyAccessorILj643ES4_KffEEEEvRKT0_($inOperator,$theAccessor$i69);
 $613 = HEAP32[$inOperator>>2]|0;
 $614 = (($613) + 8|0);
 $615 = HEAP32[$614>>2]|0;
 $616 = ($615|0)==(0);
 if ($616) {
  $637 = 0;$640 = $613;
 } else {
  $617 = (($615) + -1)|0;
  $618 = (($613) + 4|0);
  $619 = HEAP32[$618>>2]|0;
  $620 = ((($619) + ($617<<3)|0) + 4|0);
  $621 = HEAP8[$620>>0]|0;
  $622 = ($621<<24>>24)==(0);
  if ($622) {
   $629 = $613;$631 = $615;
  } else {
   $623 = (($inOperator) + 4|0);
   $624 = HEAP32[$623>>2]|0;
   $625 = HEAP32[$624>>2]|0;
   $626 = (($625) + 20|0);
   $627 = HEAP32[$626>>2]|0;
   FUNCTION_TABLE_vi[$627 & 4095]($624);
   $$pre$i$i38 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i39 = (($$pre$i$i38) + 8|0);
   $$pre1$i$i40 = HEAP32[$$phi$trans$insert$i$i39>>2]|0;
   $629 = $$pre$i$i38;$631 = $$pre1$i$i40;
  }
  $628 = (($629) + 8|0);
  $630 = (($631) + -1)|0;
  HEAP32[$628>>2] = $630;
  $$pre207 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert208 = (($$pre207) + 8|0);
  $$pre209 = HEAP32[$$phi$trans$insert208>>2]|0;
  $637 = $$pre209;$640 = $$pre207;
 }
 $632 = (($this) + 152|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $633 = (($theAccessor$i69) + 4|0);
 HEAP32[$633>>2] = 0;
 $634 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$634+0>>2]=HEAP32[$632+0>>2]|0;HEAP32[$634+4>>2]=HEAP32[$632+4>>2]|0;HEAP32[$634+8>>2]=HEAP32[$632+8>>2]|0;HEAP32[$634+12>>2]=HEAP32[$632+12>>2]|0;
 $635 = HEAP32[$632>>2]|0;
 $636 = ($637|0)==(0);
 do {
  if ($636) {
   $661 = $640;$666 = 0;
  } else {
   $638 = (($637) + -1)|0;
   $639 = (($640) + 4|0);
   $641 = HEAP32[$639>>2]|0;
   $642 = ((($641) + ($638<<3)|0) + 4|0);
   $643 = HEAP8[$642>>0]|0;
   $644 = ($643<<24>>24)==(0);
   if (!($644)) {
    $661 = $640;$666 = $637;
    break;
   }
   $645 = (($inOperator) + 4|0);
   $646 = HEAP32[$645>>2]|0;
   $647 = HEAP32[$646>>2]|0;
   $648 = (($647) + 16|0);
   $649 = HEAP32[$648>>2]|0;
   $650 = (($641) + ($638<<3)|0);
   $651 = HEAP32[$650>>2]|0;
   FUNCTION_TABLE_vii[$649 & 4095]($646,$651);
   $652 = HEAP32[$inOperator>>2]|0;
   $653 = (($652) + 8|0);
   $654 = HEAP32[$653>>2]|0;
   $655 = (($654) + -1)|0;
   $656 = (($652) + 4|0);
   $657 = HEAP32[$656>>2]|0;
   $658 = ((($657) + ($655<<3)|0) + 4|0);
   HEAP8[$658>>0] = 1;
   $$pre$i130 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i131 = (($$pre$i130) + 8|0);
   $$pre1$i132 = HEAP32[$$phi$trans$insert$i131>>2]|0;
   $661 = $$pre$i130;$666 = $$pre1$i132;
  }
 } while(0);
 HEAP32[$0>>2] = $635;
 $659 = (($0) + 4|0);
 HEAP8[$659>>0] = 0;
 $660 = (($661) + 12|0);
 $662 = HEAP32[$660>>2]|0;
 $663 = $662 & 2147483647;
 $664 = (($661) + 8|0);
 $665 = ($663>>>0)>($666>>>0);
 if ($665) {
  $667 = (($661) + 4|0);
  $668 = HEAP32[$667>>2]|0;
  $669 = (($668) + ($666<<3)|0);
  $670 = ($669|0)==(0|0);
  if ($670) {
   $682 = $666;
  } else {
   $671 = $0;
   $672 = $671;
   $673 = HEAP32[$672>>2]|0;
   $674 = (($671) + 4)|0;
   $675 = $674;
   $676 = HEAP32[$675>>2]|0;
   $677 = $669;
   $678 = $677;
   HEAP32[$678>>2] = $673;
   $679 = (($677) + 4)|0;
   $680 = $679;
   HEAP32[$680>>2] = $676;
   $$pre$i$i134 = HEAP32[$664>>2]|0;
   $682 = $$pre$i$i134;
  }
  $681 = (($682) + 1)|0;
  HEAP32[$664>>2] = $681;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($661,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj644ENS_22PxRepXPropertyAccessorILj644ES4_KffEEEEvRKT0_($inOperator,$theAccessor$i69);
 $683 = HEAP32[$inOperator>>2]|0;
 $684 = (($683) + 8|0);
 $685 = HEAP32[$684>>2]|0;
 $686 = ($685|0)==(0);
 if ($686) {
  $707 = 0;$710 = $683;
 } else {
  $687 = (($685) + -1)|0;
  $688 = (($683) + 4|0);
  $689 = HEAP32[$688>>2]|0;
  $690 = ((($689) + ($687<<3)|0) + 4|0);
  $691 = HEAP8[$690>>0]|0;
  $692 = ($691<<24>>24)==(0);
  if ($692) {
   $699 = $683;$701 = $685;
  } else {
   $693 = (($inOperator) + 4|0);
   $694 = HEAP32[$693>>2]|0;
   $695 = HEAP32[$694>>2]|0;
   $696 = (($695) + 20|0);
   $697 = HEAP32[$696>>2]|0;
   FUNCTION_TABLE_vi[$697 & 4095]($694);
   $$pre$i$i42 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i43 = (($$pre$i$i42) + 8|0);
   $$pre1$i$i44 = HEAP32[$$phi$trans$insert$i$i43>>2]|0;
   $699 = $$pre$i$i42;$701 = $$pre1$i$i44;
  }
  $698 = (($699) + 8|0);
  $700 = (($701) + -1)|0;
  HEAP32[$698>>2] = $700;
  $$pre210 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert211 = (($$pre210) + 8|0);
  $$pre212 = HEAP32[$$phi$trans$insert211>>2]|0;
  $707 = $$pre212;$710 = $$pre210;
 }
 $702 = (($this) + 168|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $703 = (($theAccessor$i69) + 4|0);
 HEAP32[$703>>2] = 0;
 $704 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$704+0>>2]=HEAP32[$702+0>>2]|0;HEAP32[$704+4>>2]=HEAP32[$702+4>>2]|0;HEAP32[$704+8>>2]=HEAP32[$702+8>>2]|0;HEAP32[$704+12>>2]=HEAP32[$702+12>>2]|0;
 $705 = HEAP32[$702>>2]|0;
 $706 = ($707|0)==(0);
 do {
  if ($706) {
   $731 = $710;$736 = 0;
  } else {
   $708 = (($707) + -1)|0;
   $709 = (($710) + 4|0);
   $711 = HEAP32[$709>>2]|0;
   $712 = ((($711) + ($708<<3)|0) + 4|0);
   $713 = HEAP8[$712>>0]|0;
   $714 = ($713<<24>>24)==(0);
   if (!($714)) {
    $731 = $710;$736 = $707;
    break;
   }
   $715 = (($inOperator) + 4|0);
   $716 = HEAP32[$715>>2]|0;
   $717 = HEAP32[$716>>2]|0;
   $718 = (($717) + 16|0);
   $719 = HEAP32[$718>>2]|0;
   $720 = (($711) + ($708<<3)|0);
   $721 = HEAP32[$720>>2]|0;
   FUNCTION_TABLE_vii[$719 & 4095]($716,$721);
   $722 = HEAP32[$inOperator>>2]|0;
   $723 = (($722) + 8|0);
   $724 = HEAP32[$723>>2]|0;
   $725 = (($724) + -1)|0;
   $726 = (($722) + 4|0);
   $727 = HEAP32[$726>>2]|0;
   $728 = ((($727) + ($725<<3)|0) + 4|0);
   HEAP8[$728>>0] = 1;
   $$pre$i137 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i138 = (($$pre$i137) + 8|0);
   $$pre1$i139 = HEAP32[$$phi$trans$insert$i138>>2]|0;
   $731 = $$pre$i137;$736 = $$pre1$i139;
  }
 } while(0);
 HEAP32[$0>>2] = $705;
 $729 = (($0) + 4|0);
 HEAP8[$729>>0] = 0;
 $730 = (($731) + 12|0);
 $732 = HEAP32[$730>>2]|0;
 $733 = $732 & 2147483647;
 $734 = (($731) + 8|0);
 $735 = ($733>>>0)>($736>>>0);
 if ($735) {
  $737 = (($731) + 4|0);
  $738 = HEAP32[$737>>2]|0;
  $739 = (($738) + ($736<<3)|0);
  $740 = ($739|0)==(0|0);
  if ($740) {
   $752 = $736;
  } else {
   $741 = $0;
   $742 = $741;
   $743 = HEAP32[$742>>2]|0;
   $744 = (($741) + 4)|0;
   $745 = $744;
   $746 = HEAP32[$745>>2]|0;
   $747 = $739;
   $748 = $747;
   HEAP32[$748>>2] = $743;
   $749 = (($747) + 4)|0;
   $750 = $749;
   HEAP32[$750>>2] = $746;
   $$pre$i$i141 = HEAP32[$734>>2]|0;
   $752 = $$pre$i$i141;
  }
  $751 = (($752) + 1)|0;
  HEAP32[$734>>2] = $751;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($731,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj645ENS_22PxRepXPropertyAccessorILj645ES4_bbEEEEvRKT0_($inOperator,$theAccessor$i69);
 $753 = HEAP32[$inOperator>>2]|0;
 $754 = (($753) + 8|0);
 $755 = HEAP32[$754>>2]|0;
 $756 = ($755|0)==(0);
 if ($756) {
  $777 = 0;$780 = $753;
 } else {
  $757 = (($755) + -1)|0;
  $758 = (($753) + 4|0);
  $759 = HEAP32[$758>>2]|0;
  $760 = ((($759) + ($757<<3)|0) + 4|0);
  $761 = HEAP8[$760>>0]|0;
  $762 = ($761<<24>>24)==(0);
  if ($762) {
   $769 = $753;$771 = $755;
  } else {
   $763 = (($inOperator) + 4|0);
   $764 = HEAP32[$763>>2]|0;
   $765 = HEAP32[$764>>2]|0;
   $766 = (($765) + 20|0);
   $767 = HEAP32[$766>>2]|0;
   FUNCTION_TABLE_vi[$767 & 4095]($764);
   $$pre$i$i46 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i47 = (($$pre$i$i46) + 8|0);
   $$pre1$i$i48 = HEAP32[$$phi$trans$insert$i$i47>>2]|0;
   $769 = $$pre$i$i46;$771 = $$pre1$i$i48;
  }
  $768 = (($769) + 8|0);
  $770 = (($771) + -1)|0;
  HEAP32[$768>>2] = $770;
  $$pre213 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert214 = (($$pre213) + 8|0);
  $$pre215 = HEAP32[$$phi$trans$insert214>>2]|0;
  $777 = $$pre215;$780 = $$pre213;
 }
 $772 = (($this) + 184|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $773 = (($theAccessor$i69) + 4|0);
 HEAP32[$773>>2] = 0;
 $774 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$774+0>>2]=HEAP32[$772+0>>2]|0;HEAP32[$774+4>>2]=HEAP32[$772+4>>2]|0;HEAP32[$774+8>>2]=HEAP32[$772+8>>2]|0;HEAP32[$774+12>>2]=HEAP32[$772+12>>2]|0;
 $775 = HEAP32[$772>>2]|0;
 $776 = ($777|0)==(0);
 do {
  if ($776) {
   $801 = $780;$806 = 0;
  } else {
   $778 = (($777) + -1)|0;
   $779 = (($780) + 4|0);
   $781 = HEAP32[$779>>2]|0;
   $782 = ((($781) + ($778<<3)|0) + 4|0);
   $783 = HEAP8[$782>>0]|0;
   $784 = ($783<<24>>24)==(0);
   if (!($784)) {
    $801 = $780;$806 = $777;
    break;
   }
   $785 = (($inOperator) + 4|0);
   $786 = HEAP32[$785>>2]|0;
   $787 = HEAP32[$786>>2]|0;
   $788 = (($787) + 16|0);
   $789 = HEAP32[$788>>2]|0;
   $790 = (($781) + ($778<<3)|0);
   $791 = HEAP32[$790>>2]|0;
   FUNCTION_TABLE_vii[$789 & 4095]($786,$791);
   $792 = HEAP32[$inOperator>>2]|0;
   $793 = (($792) + 8|0);
   $794 = HEAP32[$793>>2]|0;
   $795 = (($794) + -1)|0;
   $796 = (($792) + 4|0);
   $797 = HEAP32[$796>>2]|0;
   $798 = ((($797) + ($795<<3)|0) + 4|0);
   HEAP8[$798>>0] = 1;
   $$pre$i144 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i145 = (($$pre$i144) + 8|0);
   $$pre1$i146 = HEAP32[$$phi$trans$insert$i145>>2]|0;
   $801 = $$pre$i144;$806 = $$pre1$i146;
  }
 } while(0);
 HEAP32[$0>>2] = $775;
 $799 = (($0) + 4|0);
 HEAP8[$799>>0] = 0;
 $800 = (($801) + 12|0);
 $802 = HEAP32[$800>>2]|0;
 $803 = $802 & 2147483647;
 $804 = (($801) + 8|0);
 $805 = ($803>>>0)>($806>>>0);
 if ($805) {
  $807 = (($801) + 4|0);
  $808 = HEAP32[$807>>2]|0;
  $809 = (($808) + ($806<<3)|0);
  $810 = ($809|0)==(0|0);
  if ($810) {
   $822 = $806;
  } else {
   $811 = $0;
   $812 = $811;
   $813 = HEAP32[$812>>2]|0;
   $814 = (($811) + 4)|0;
   $815 = $814;
   $816 = HEAP32[$815>>2]|0;
   $817 = $809;
   $818 = $817;
   HEAP32[$818>>2] = $813;
   $819 = (($817) + 4)|0;
   $820 = $819;
   HEAP32[$820>>2] = $816;
   $$pre$i$i148 = HEAP32[$804>>2]|0;
   $822 = $$pre$i$i148;
  }
  $821 = (($822) + 1)|0;
  HEAP32[$804>>2] = $821;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($801,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj646ENS_22PxRepXPropertyAccessorILj646ES4_bbEEEEvRKT0_($inOperator,$theAccessor$i69);
 $823 = HEAP32[$inOperator>>2]|0;
 $824 = (($823) + 8|0);
 $825 = HEAP32[$824>>2]|0;
 $826 = ($825|0)==(0);
 if ($826) {
  $847 = 0;$850 = $823;
 } else {
  $827 = (($825) + -1)|0;
  $828 = (($823) + 4|0);
  $829 = HEAP32[$828>>2]|0;
  $830 = ((($829) + ($827<<3)|0) + 4|0);
  $831 = HEAP8[$830>>0]|0;
  $832 = ($831<<24>>24)==(0);
  if ($832) {
   $839 = $823;$841 = $825;
  } else {
   $833 = (($inOperator) + 4|0);
   $834 = HEAP32[$833>>2]|0;
   $835 = HEAP32[$834>>2]|0;
   $836 = (($835) + 20|0);
   $837 = HEAP32[$836>>2]|0;
   FUNCTION_TABLE_vi[$837 & 4095]($834);
   $$pre$i$i50 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i51 = (($$pre$i$i50) + 8|0);
   $$pre1$i$i52 = HEAP32[$$phi$trans$insert$i$i51>>2]|0;
   $839 = $$pre$i$i50;$841 = $$pre1$i$i52;
  }
  $838 = (($839) + 8|0);
  $840 = (($841) + -1)|0;
  HEAP32[$838>>2] = $840;
  $$pre216 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert217 = (($$pre216) + 8|0);
  $$pre218 = HEAP32[$$phi$trans$insert217>>2]|0;
  $847 = $$pre218;$850 = $$pre216;
 }
 $842 = (($this) + 200|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $843 = (($theAccessor$i69) + 4|0);
 HEAP32[$843>>2] = 0;
 $844 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$844+0>>2]=HEAP32[$842+0>>2]|0;HEAP32[$844+4>>2]=HEAP32[$842+4>>2]|0;HEAP32[$844+8>>2]=HEAP32[$842+8>>2]|0;HEAP32[$844+12>>2]=HEAP32[$842+12>>2]|0;
 $845 = HEAP32[$842>>2]|0;
 $846 = ($847|0)==(0);
 do {
  if ($846) {
   $871 = $850;$876 = 0;
  } else {
   $848 = (($847) + -1)|0;
   $849 = (($850) + 4|0);
   $851 = HEAP32[$849>>2]|0;
   $852 = ((($851) + ($848<<3)|0) + 4|0);
   $853 = HEAP8[$852>>0]|0;
   $854 = ($853<<24>>24)==(0);
   if (!($854)) {
    $871 = $850;$876 = $847;
    break;
   }
   $855 = (($inOperator) + 4|0);
   $856 = HEAP32[$855>>2]|0;
   $857 = HEAP32[$856>>2]|0;
   $858 = (($857) + 16|0);
   $859 = HEAP32[$858>>2]|0;
   $860 = (($851) + ($848<<3)|0);
   $861 = HEAP32[$860>>2]|0;
   FUNCTION_TABLE_vii[$859 & 4095]($856,$861);
   $862 = HEAP32[$inOperator>>2]|0;
   $863 = (($862) + 8|0);
   $864 = HEAP32[$863>>2]|0;
   $865 = (($864) + -1)|0;
   $866 = (($862) + 4|0);
   $867 = HEAP32[$866>>2]|0;
   $868 = ((($867) + ($865<<3)|0) + 4|0);
   HEAP8[$868>>0] = 1;
   $$pre$i151 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i152 = (($$pre$i151) + 8|0);
   $$pre1$i153 = HEAP32[$$phi$trans$insert$i152>>2]|0;
   $871 = $$pre$i151;$876 = $$pre1$i153;
  }
 } while(0);
 HEAP32[$0>>2] = $845;
 $869 = (($0) + 4|0);
 HEAP8[$869>>0] = 0;
 $870 = (($871) + 12|0);
 $872 = HEAP32[$870>>2]|0;
 $873 = $872 & 2147483647;
 $874 = (($871) + 8|0);
 $875 = ($873>>>0)>($876>>>0);
 if ($875) {
  $877 = (($871) + 4|0);
  $878 = HEAP32[$877>>2]|0;
  $879 = (($878) + ($876<<3)|0);
  $880 = ($879|0)==(0|0);
  if ($880) {
   $892 = $876;
  } else {
   $881 = $0;
   $882 = $881;
   $883 = HEAP32[$882>>2]|0;
   $884 = (($881) + 4)|0;
   $885 = $884;
   $886 = HEAP32[$885>>2]|0;
   $887 = $879;
   $888 = $887;
   HEAP32[$888>>2] = $883;
   $889 = (($887) + 4)|0;
   $890 = $889;
   HEAP32[$890>>2] = $886;
   $$pre$i$i155 = HEAP32[$874>>2]|0;
   $892 = $$pre$i$i155;
  }
  $891 = (($892) + 1)|0;
  HEAP32[$874>>2] = $891;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($871,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj647ENS_22PxRepXPropertyAccessorILj647ES4_bbEEEEvRKT0_($inOperator,$theAccessor$i69);
 $893 = HEAP32[$inOperator>>2]|0;
 $894 = (($893) + 8|0);
 $895 = HEAP32[$894>>2]|0;
 $896 = ($895|0)==(0);
 if ($896) {
  $917 = 0;$920 = $893;
 } else {
  $897 = (($895) + -1)|0;
  $898 = (($893) + 4|0);
  $899 = HEAP32[$898>>2]|0;
  $900 = ((($899) + ($897<<3)|0) + 4|0);
  $901 = HEAP8[$900>>0]|0;
  $902 = ($901<<24>>24)==(0);
  if ($902) {
   $909 = $893;$911 = $895;
  } else {
   $903 = (($inOperator) + 4|0);
   $904 = HEAP32[$903>>2]|0;
   $905 = HEAP32[$904>>2]|0;
   $906 = (($905) + 20|0);
   $907 = HEAP32[$906>>2]|0;
   FUNCTION_TABLE_vi[$907 & 4095]($904);
   $$pre$i$i54 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i55 = (($$pre$i$i54) + 8|0);
   $$pre1$i$i56 = HEAP32[$$phi$trans$insert$i$i55>>2]|0;
   $909 = $$pre$i$i54;$911 = $$pre1$i$i56;
  }
  $908 = (($909) + 8|0);
  $910 = (($911) + -1)|0;
  HEAP32[$908>>2] = $910;
  $$pre219 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert220 = (($$pre219) + 8|0);
  $$pre221 = HEAP32[$$phi$trans$insert220>>2]|0;
  $917 = $$pre221;$920 = $$pre219;
 }
 $912 = (($this) + 216|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $913 = (($theAccessor$i69) + 4|0);
 HEAP32[$913>>2] = 0;
 $914 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$914+0>>2]=HEAP32[$912+0>>2]|0;HEAP32[$914+4>>2]=HEAP32[$912+4>>2]|0;HEAP32[$914+8>>2]=HEAP32[$912+8>>2]|0;HEAP32[$914+12>>2]=HEAP32[$912+12>>2]|0;
 $915 = HEAP32[$912>>2]|0;
 $916 = ($917|0)==(0);
 do {
  if ($916) {
   $941 = $920;$946 = 0;
  } else {
   $918 = (($917) + -1)|0;
   $919 = (($920) + 4|0);
   $921 = HEAP32[$919>>2]|0;
   $922 = ((($921) + ($918<<3)|0) + 4|0);
   $923 = HEAP8[$922>>0]|0;
   $924 = ($923<<24>>24)==(0);
   if (!($924)) {
    $941 = $920;$946 = $917;
    break;
   }
   $925 = (($inOperator) + 4|0);
   $926 = HEAP32[$925>>2]|0;
   $927 = HEAP32[$926>>2]|0;
   $928 = (($927) + 16|0);
   $929 = HEAP32[$928>>2]|0;
   $930 = (($921) + ($918<<3)|0);
   $931 = HEAP32[$930>>2]|0;
   FUNCTION_TABLE_vii[$929 & 4095]($926,$931);
   $932 = HEAP32[$inOperator>>2]|0;
   $933 = (($932) + 8|0);
   $934 = HEAP32[$933>>2]|0;
   $935 = (($934) + -1)|0;
   $936 = (($932) + 4|0);
   $937 = HEAP32[$936>>2]|0;
   $938 = ((($937) + ($935<<3)|0) + 4|0);
   HEAP8[$938>>0] = 1;
   $$pre$i158 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i159 = (($$pre$i158) + 8|0);
   $$pre1$i160 = HEAP32[$$phi$trans$insert$i159>>2]|0;
   $941 = $$pre$i158;$946 = $$pre1$i160;
  }
 } while(0);
 HEAP32[$0>>2] = $915;
 $939 = (($0) + 4|0);
 HEAP8[$939>>0] = 0;
 $940 = (($941) + 12|0);
 $942 = HEAP32[$940>>2]|0;
 $943 = $942 & 2147483647;
 $944 = (($941) + 8|0);
 $945 = ($943>>>0)>($946>>>0);
 if ($945) {
  $947 = (($941) + 4|0);
  $948 = HEAP32[$947>>2]|0;
  $949 = (($948) + ($946<<3)|0);
  $950 = ($949|0)==(0|0);
  if ($950) {
   $962 = $946;
  } else {
   $951 = $0;
   $952 = $951;
   $953 = HEAP32[$952>>2]|0;
   $954 = (($951) + 4)|0;
   $955 = $954;
   $956 = HEAP32[$955>>2]|0;
   $957 = $949;
   $958 = $957;
   HEAP32[$958>>2] = $953;
   $959 = (($957) + 4)|0;
   $960 = $959;
   HEAP32[$960>>2] = $956;
   $$pre$i$i162 = HEAP32[$944>>2]|0;
   $962 = $$pre$i$i162;
  }
  $961 = (($962) + 1)|0;
  HEAP32[$944>>2] = $961;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($941,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj648ENS_22PxRepXPropertyAccessorILj648ES4_jjEEEEvRKT0_($inOperator,$theAccessor$i69);
 $963 = HEAP32[$inOperator>>2]|0;
 $964 = (($963) + 8|0);
 $965 = HEAP32[$964>>2]|0;
 $966 = ($965|0)==(0);
 if ($966) {
  $987 = 0;$990 = $963;
 } else {
  $967 = (($965) + -1)|0;
  $968 = (($963) + 4|0);
  $969 = HEAP32[$968>>2]|0;
  $970 = ((($969) + ($967<<3)|0) + 4|0);
  $971 = HEAP8[$970>>0]|0;
  $972 = ($971<<24>>24)==(0);
  if ($972) {
   $979 = $963;$981 = $965;
  } else {
   $973 = (($inOperator) + 4|0);
   $974 = HEAP32[$973>>2]|0;
   $975 = HEAP32[$974>>2]|0;
   $976 = (($975) + 20|0);
   $977 = HEAP32[$976>>2]|0;
   FUNCTION_TABLE_vi[$977 & 4095]($974);
   $$pre$i$i58 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i59 = (($$pre$i$i58) + 8|0);
   $$pre1$i$i60 = HEAP32[$$phi$trans$insert$i$i59>>2]|0;
   $979 = $$pre$i$i58;$981 = $$pre1$i$i60;
  }
  $978 = (($979) + 8|0);
  $980 = (($981) + -1)|0;
  HEAP32[$978>>2] = $980;
  $$pre222 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert223 = (($$pre222) + 8|0);
  $$pre224 = HEAP32[$$phi$trans$insert223>>2]|0;
  $987 = $$pre224;$990 = $$pre222;
 }
 $982 = (($this) + 232|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $983 = (($theAccessor$i69) + 4|0);
 HEAP32[$983>>2] = 0;
 $984 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$984+0>>2]=HEAP32[$982+0>>2]|0;HEAP32[$984+4>>2]=HEAP32[$982+4>>2]|0;HEAP32[$984+8>>2]=HEAP32[$982+8>>2]|0;HEAP32[$984+12>>2]=HEAP32[$982+12>>2]|0;
 $985 = HEAP32[$982>>2]|0;
 $986 = ($987|0)==(0);
 do {
  if ($986) {
   $1011 = $990;$1016 = 0;
  } else {
   $988 = (($987) + -1)|0;
   $989 = (($990) + 4|0);
   $991 = HEAP32[$989>>2]|0;
   $992 = ((($991) + ($988<<3)|0) + 4|0);
   $993 = HEAP8[$992>>0]|0;
   $994 = ($993<<24>>24)==(0);
   if (!($994)) {
    $1011 = $990;$1016 = $987;
    break;
   }
   $995 = (($inOperator) + 4|0);
   $996 = HEAP32[$995>>2]|0;
   $997 = HEAP32[$996>>2]|0;
   $998 = (($997) + 16|0);
   $999 = HEAP32[$998>>2]|0;
   $1000 = (($991) + ($988<<3)|0);
   $1001 = HEAP32[$1000>>2]|0;
   FUNCTION_TABLE_vii[$999 & 4095]($996,$1001);
   $1002 = HEAP32[$inOperator>>2]|0;
   $1003 = (($1002) + 8|0);
   $1004 = HEAP32[$1003>>2]|0;
   $1005 = (($1004) + -1)|0;
   $1006 = (($1002) + 4|0);
   $1007 = HEAP32[$1006>>2]|0;
   $1008 = ((($1007) + ($1005<<3)|0) + 4|0);
   HEAP8[$1008>>0] = 1;
   $$pre$i165 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i166 = (($$pre$i165) + 8|0);
   $$pre1$i167 = HEAP32[$$phi$trans$insert$i166>>2]|0;
   $1011 = $$pre$i165;$1016 = $$pre1$i167;
  }
 } while(0);
 HEAP32[$0>>2] = $985;
 $1009 = (($0) + 4|0);
 HEAP8[$1009>>0] = 0;
 $1010 = (($1011) + 12|0);
 $1012 = HEAP32[$1010>>2]|0;
 $1013 = $1012 & 2147483647;
 $1014 = (($1011) + 8|0);
 $1015 = ($1013>>>0)>($1016>>>0);
 if ($1015) {
  $1017 = (($1011) + 4|0);
  $1018 = HEAP32[$1017>>2]|0;
  $1019 = (($1018) + ($1016<<3)|0);
  $1020 = ($1019|0)==(0|0);
  if ($1020) {
   $1032 = $1016;
  } else {
   $1021 = $0;
   $1022 = $1021;
   $1023 = HEAP32[$1022>>2]|0;
   $1024 = (($1021) + 4)|0;
   $1025 = $1024;
   $1026 = HEAP32[$1025>>2]|0;
   $1027 = $1019;
   $1028 = $1027;
   HEAP32[$1028>>2] = $1023;
   $1029 = (($1027) + 4)|0;
   $1030 = $1029;
   HEAP32[$1030>>2] = $1026;
   $$pre$i$i169 = HEAP32[$1014>>2]|0;
   $1032 = $$pre$i$i169;
  }
  $1031 = (($1032) + 1)|0;
  HEAP32[$1014>>2] = $1031;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($1011,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj649ENS_22PxRepXPropertyAccessorILj649ES4_jjEEEEvRKT0_($inOperator,$theAccessor$i69);
 $1033 = HEAP32[$inOperator>>2]|0;
 $1034 = (($1033) + 8|0);
 $1035 = HEAP32[$1034>>2]|0;
 $1036 = ($1035|0)==(0);
 if ($1036) {
  $1057 = 0;$1060 = $1033;
 } else {
  $1037 = (($1035) + -1)|0;
  $1038 = (($1033) + 4|0);
  $1039 = HEAP32[$1038>>2]|0;
  $1040 = ((($1039) + ($1037<<3)|0) + 4|0);
  $1041 = HEAP8[$1040>>0]|0;
  $1042 = ($1041<<24>>24)==(0);
  if ($1042) {
   $1049 = $1033;$1051 = $1035;
  } else {
   $1043 = (($inOperator) + 4|0);
   $1044 = HEAP32[$1043>>2]|0;
   $1045 = HEAP32[$1044>>2]|0;
   $1046 = (($1045) + 20|0);
   $1047 = HEAP32[$1046>>2]|0;
   FUNCTION_TABLE_vi[$1047 & 4095]($1044);
   $$pre$i$i62 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i63 = (($$pre$i$i62) + 8|0);
   $$pre1$i$i64 = HEAP32[$$phi$trans$insert$i$i63>>2]|0;
   $1049 = $$pre$i$i62;$1051 = $$pre1$i$i64;
  }
  $1048 = (($1049) + 8|0);
  $1050 = (($1051) + -1)|0;
  HEAP32[$1048>>2] = $1050;
  $$pre225 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert226 = (($$pre225) + 8|0);
  $$pre227 = HEAP32[$$phi$trans$insert226>>2]|0;
  $1057 = $$pre227;$1060 = $$pre225;
 }
 $1052 = (($this) + 248|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $1053 = (($theAccessor$i69) + 4|0);
 HEAP32[$1053>>2] = 0;
 $1054 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$1054+0>>2]=HEAP32[$1052+0>>2]|0;HEAP32[$1054+4>>2]=HEAP32[$1052+4>>2]|0;HEAP32[$1054+8>>2]=HEAP32[$1052+8>>2]|0;HEAP32[$1054+12>>2]=HEAP32[$1052+12>>2]|0;
 $1055 = HEAP32[$1052>>2]|0;
 $1056 = ($1057|0)==(0);
 do {
  if ($1056) {
   $1081 = $1060;$1086 = 0;
  } else {
   $1058 = (($1057) + -1)|0;
   $1059 = (($1060) + 4|0);
   $1061 = HEAP32[$1059>>2]|0;
   $1062 = ((($1061) + ($1058<<3)|0) + 4|0);
   $1063 = HEAP8[$1062>>0]|0;
   $1064 = ($1063<<24>>24)==(0);
   if (!($1064)) {
    $1081 = $1060;$1086 = $1057;
    break;
   }
   $1065 = (($inOperator) + 4|0);
   $1066 = HEAP32[$1065>>2]|0;
   $1067 = HEAP32[$1066>>2]|0;
   $1068 = (($1067) + 16|0);
   $1069 = HEAP32[$1068>>2]|0;
   $1070 = (($1061) + ($1058<<3)|0);
   $1071 = HEAP32[$1070>>2]|0;
   FUNCTION_TABLE_vii[$1069 & 4095]($1066,$1071);
   $1072 = HEAP32[$inOperator>>2]|0;
   $1073 = (($1072) + 8|0);
   $1074 = HEAP32[$1073>>2]|0;
   $1075 = (($1074) + -1)|0;
   $1076 = (($1072) + 4|0);
   $1077 = HEAP32[$1076>>2]|0;
   $1078 = ((($1077) + ($1075<<3)|0) + 4|0);
   HEAP8[$1078>>0] = 1;
   $$pre$i172 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i173 = (($$pre$i172) + 8|0);
   $$pre1$i174 = HEAP32[$$phi$trans$insert$i173>>2]|0;
   $1081 = $$pre$i172;$1086 = $$pre1$i174;
  }
 } while(0);
 HEAP32[$0>>2] = $1055;
 $1079 = (($0) + 4|0);
 HEAP8[$1079>>0] = 0;
 $1080 = (($1081) + 12|0);
 $1082 = HEAP32[$1080>>2]|0;
 $1083 = $1082 & 2147483647;
 $1084 = (($1081) + 8|0);
 $1085 = ($1083>>>0)>($1086>>>0);
 if ($1085) {
  $1087 = (($1081) + 4|0);
  $1088 = HEAP32[$1087>>2]|0;
  $1089 = (($1088) + ($1086<<3)|0);
  $1090 = ($1089|0)==(0|0);
  if ($1090) {
   $1102 = $1086;
  } else {
   $1091 = $0;
   $1092 = $1091;
   $1093 = HEAP32[$1092>>2]|0;
   $1094 = (($1091) + 4)|0;
   $1095 = $1094;
   $1096 = HEAP32[$1095>>2]|0;
   $1097 = $1089;
   $1098 = $1097;
   HEAP32[$1098>>2] = $1093;
   $1099 = (($1097) + 4)|0;
   $1100 = $1099;
   HEAP32[$1100>>2] = $1096;
   $$pre$i$i176 = HEAP32[$1084>>2]|0;
   $1102 = $$pre$i$i176;
  }
  $1101 = (($1102) + 1)|0;
  HEAP32[$1084>>2] = $1101;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($1081,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj650ENS_22PxRepXPropertyAccessorILj650ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i69);
 $1103 = HEAP32[$inOperator>>2]|0;
 $1104 = (($1103) + 8|0);
 $1105 = HEAP32[$1104>>2]|0;
 $1106 = ($1105|0)==(0);
 if ($1106) {
  $1127 = 0;$1130 = $1103;
 } else {
  $1107 = (($1105) + -1)|0;
  $1108 = (($1103) + 4|0);
  $1109 = HEAP32[$1108>>2]|0;
  $1110 = ((($1109) + ($1107<<3)|0) + 4|0);
  $1111 = HEAP8[$1110>>0]|0;
  $1112 = ($1111<<24>>24)==(0);
  if ($1112) {
   $1119 = $1103;$1121 = $1105;
  } else {
   $1113 = (($inOperator) + 4|0);
   $1114 = HEAP32[$1113>>2]|0;
   $1115 = HEAP32[$1114>>2]|0;
   $1116 = (($1115) + 20|0);
   $1117 = HEAP32[$1116>>2]|0;
   FUNCTION_TABLE_vi[$1117 & 4095]($1114);
   $$pre$i$i66 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i67 = (($$pre$i$i66) + 8|0);
   $$pre1$i$i68 = HEAP32[$$phi$trans$insert$i$i67>>2]|0;
   $1119 = $$pre$i$i66;$1121 = $$pre1$i$i68;
  }
  $1118 = (($1119) + 8|0);
  $1120 = (($1121) + -1)|0;
  HEAP32[$1118>>2] = $1120;
  $$pre228 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert229 = (($$pre228) + 8|0);
  $$pre230 = HEAP32[$$phi$trans$insert229>>2]|0;
  $1127 = $$pre230;$1130 = $$pre228;
 }
 $1122 = (($this) + 264|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $1123 = (($theAccessor$i69) + 4|0);
 HEAP32[$1123>>2] = 0;
 $1124 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$1124+0>>2]=HEAP32[$1122+0>>2]|0;HEAP32[$1124+4>>2]=HEAP32[$1122+4>>2]|0;HEAP32[$1124+8>>2]=HEAP32[$1122+8>>2]|0;HEAP32[$1124+12>>2]=HEAP32[$1122+12>>2]|0;
 $1125 = HEAP32[$1122>>2]|0;
 $1126 = ($1127|0)==(0);
 do {
  if ($1126) {
   $1151 = $1130;$1156 = 0;
  } else {
   $1128 = (($1127) + -1)|0;
   $1129 = (($1130) + 4|0);
   $1131 = HEAP32[$1129>>2]|0;
   $1132 = ((($1131) + ($1128<<3)|0) + 4|0);
   $1133 = HEAP8[$1132>>0]|0;
   $1134 = ($1133<<24>>24)==(0);
   if (!($1134)) {
    $1151 = $1130;$1156 = $1127;
    break;
   }
   $1135 = (($inOperator) + 4|0);
   $1136 = HEAP32[$1135>>2]|0;
   $1137 = HEAP32[$1136>>2]|0;
   $1138 = (($1137) + 16|0);
   $1139 = HEAP32[$1138>>2]|0;
   $1140 = (($1131) + ($1128<<3)|0);
   $1141 = HEAP32[$1140>>2]|0;
   FUNCTION_TABLE_vii[$1139 & 4095]($1136,$1141);
   $1142 = HEAP32[$inOperator>>2]|0;
   $1143 = (($1142) + 8|0);
   $1144 = HEAP32[$1143>>2]|0;
   $1145 = (($1144) + -1)|0;
   $1146 = (($1142) + 4|0);
   $1147 = HEAP32[$1146>>2]|0;
   $1148 = ((($1147) + ($1145<<3)|0) + 4|0);
   HEAP8[$1148>>0] = 1;
   $$pre$i179 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i180 = (($$pre$i179) + 8|0);
   $$pre1$i181 = HEAP32[$$phi$trans$insert$i180>>2]|0;
   $1151 = $$pre$i179;$1156 = $$pre1$i181;
  }
 } while(0);
 HEAP32[$0>>2] = $1125;
 $1149 = (($0) + 4|0);
 HEAP8[$1149>>0] = 0;
 $1150 = (($1151) + 12|0);
 $1152 = HEAP32[$1150>>2]|0;
 $1153 = $1152 & 2147483647;
 $1154 = (($1151) + 8|0);
 $1155 = ($1153>>>0)>($1156>>>0);
 if ($1155) {
  $1157 = (($1151) + 4|0);
  $1158 = HEAP32[$1157>>2]|0;
  $1159 = (($1158) + ($1156<<3)|0);
  $1160 = ($1159|0)==(0|0);
  if ($1160) {
   $1172 = $1156;
  } else {
   $1161 = $0;
   $1162 = $1161;
   $1163 = HEAP32[$1162>>2]|0;
   $1164 = (($1161) + 4)|0;
   $1165 = $1164;
   $1166 = HEAP32[$1165>>2]|0;
   $1167 = $1159;
   $1168 = $1167;
   HEAP32[$1168>>2] = $1163;
   $1169 = (($1167) + 4)|0;
   $1170 = $1169;
   HEAP32[$1170>>2] = $1166;
   $$pre$i$i183 = HEAP32[$1154>>2]|0;
   $1172 = $$pre$i$i183;
  }
  $1171 = (($1172) + 1)|0;
  HEAP32[$1154>>2] = $1171;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($1151,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj651ENS_22PxRepXPropertyAccessorILj651ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i69);
 $1173 = HEAP32[$inOperator>>2]|0;
 $1174 = (($1173) + 8|0);
 $1175 = HEAP32[$1174>>2]|0;
 $1176 = ($1175|0)==(0);
 if ($1176) {
  $1197 = 0;$1200 = $1173;
 } else {
  $1177 = (($1175) + -1)|0;
  $1178 = (($1173) + 4|0);
  $1179 = HEAP32[$1178>>2]|0;
  $1180 = ((($1179) + ($1177<<3)|0) + 4|0);
  $1181 = HEAP8[$1180>>0]|0;
  $1182 = ($1181<<24>>24)==(0);
  if ($1182) {
   $1189 = $1173;$1191 = $1175;
  } else {
   $1183 = (($inOperator) + 4|0);
   $1184 = HEAP32[$1183>>2]|0;
   $1185 = HEAP32[$1184>>2]|0;
   $1186 = (($1185) + 20|0);
   $1187 = HEAP32[$1186>>2]|0;
   FUNCTION_TABLE_vi[$1187 & 4095]($1184);
   $$pre$i$i70 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i71 = (($$pre$i$i70) + 8|0);
   $$pre1$i$i72 = HEAP32[$$phi$trans$insert$i$i71>>2]|0;
   $1189 = $$pre$i$i70;$1191 = $$pre1$i$i72;
  }
  $1188 = (($1189) + 8|0);
  $1190 = (($1191) + -1)|0;
  HEAP32[$1188>>2] = $1190;
  $$pre231 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert232 = (($$pre231) + 8|0);
  $$pre233 = HEAP32[$$phi$trans$insert232>>2]|0;
  $1197 = $$pre233;$1200 = $$pre231;
 }
 $1192 = (($this) + 280|0);
 HEAP8[$theAccessor$i69>>0] = 0;
 $1193 = (($theAccessor$i69) + 4|0);
 HEAP32[$1193>>2] = 0;
 $1194 = (($theAccessor$i69) + 8|0);
 ;HEAP32[$1194+0>>2]=HEAP32[$1192+0>>2]|0;HEAP32[$1194+4>>2]=HEAP32[$1192+4>>2]|0;HEAP32[$1194+8>>2]=HEAP32[$1192+8>>2]|0;HEAP32[$1194+12>>2]=HEAP32[$1192+12>>2]|0;
 $1195 = HEAP32[$1192>>2]|0;
 $1196 = ($1197|0)==(0);
 do {
  if ($1196) {
   $1221 = $1200;$1226 = 0;
  } else {
   $1198 = (($1197) + -1)|0;
   $1199 = (($1200) + 4|0);
   $1201 = HEAP32[$1199>>2]|0;
   $1202 = ((($1201) + ($1198<<3)|0) + 4|0);
   $1203 = HEAP8[$1202>>0]|0;
   $1204 = ($1203<<24>>24)==(0);
   if (!($1204)) {
    $1221 = $1200;$1226 = $1197;
    break;
   }
   $1205 = (($inOperator) + 4|0);
   $1206 = HEAP32[$1205>>2]|0;
   $1207 = HEAP32[$1206>>2]|0;
   $1208 = (($1207) + 16|0);
   $1209 = HEAP32[$1208>>2]|0;
   $1210 = (($1201) + ($1198<<3)|0);
   $1211 = HEAP32[$1210>>2]|0;
   FUNCTION_TABLE_vii[$1209 & 4095]($1206,$1211);
   $1212 = HEAP32[$inOperator>>2]|0;
   $1213 = (($1212) + 8|0);
   $1214 = HEAP32[$1213>>2]|0;
   $1215 = (($1214) + -1)|0;
   $1216 = (($1212) + 4|0);
   $1217 = HEAP32[$1216>>2]|0;
   $1218 = ((($1217) + ($1215<<3)|0) + 4|0);
   HEAP8[$1218>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $1221 = $$pre$i;$1226 = $$pre1$i;
  }
 } while(0);
 HEAP32[$0>>2] = $1195;
 $1219 = (($0) + 4|0);
 HEAP8[$1219>>0] = 0;
 $1220 = (($1221) + 12|0);
 $1222 = HEAP32[$1220>>2]|0;
 $1223 = $1222 & 2147483647;
 $1224 = (($1221) + 8|0);
 $1225 = ($1223>>>0)>($1226>>>0);
 if ($1225) {
  $1227 = (($1221) + 4|0);
  $1228 = HEAP32[$1227>>2]|0;
  $1229 = (($1228) + ($1226<<3)|0);
  $1230 = ($1229|0)==(0|0);
  if ($1230) {
   $1242 = $1226;
  } else {
   $1231 = $0;
   $1232 = $1231;
   $1233 = HEAP32[$1232>>2]|0;
   $1234 = (($1231) + 4)|0;
   $1235 = $1234;
   $1236 = HEAP32[$1235>>2]|0;
   $1237 = $1229;
   $1238 = $1237;
   HEAP32[$1238>>2] = $1233;
   $1239 = (($1237) + 4)|0;
   $1240 = $1239;
   HEAP32[$1240>>2] = $1236;
   $$pre$i$i1 = HEAP32[$1224>>2]|0;
   $1242 = $$pre$i$i1;
  }
  $1241 = (($1242) + 1)|0;
  HEAP32[$1224>>2] = $1241;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($1221,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj652ENS_22PxRepXPropertyAccessorILj652ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i69);
 $1243 = HEAP32[$inOperator>>2]|0;
 $1244 = (($1243) + 8|0);
 $1245 = HEAP32[$1244>>2]|0;
 $1246 = ($1245|0)==(0);
 if ($1246) {
  $1262 = (($inStartIndex) + 18)|0;
  STACKTOP = sp;return ($1262|0);
 }
 $1247 = (($1245) + -1)|0;
 $1248 = (($1243) + 4|0);
 $1249 = HEAP32[$1248>>2]|0;
 $1250 = ((($1249) + ($1247<<3)|0) + 4|0);
 $1251 = HEAP8[$1250>>0]|0;
 $1252 = ($1251<<24>>24)==(0);
 if ($1252) {
  $1259 = $1243;$1261 = $1245;
 } else {
  $1253 = (($inOperator) + 4|0);
  $1254 = HEAP32[$1253>>2]|0;
  $1255 = HEAP32[$1254>>2]|0;
  $1256 = (($1255) + 20|0);
  $1257 = HEAP32[$1256>>2]|0;
  FUNCTION_TABLE_vi[$1257 & 4095]($1254);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $1259 = $$pre$i$i;$1261 = $$pre1$i$i;
 }
 $1258 = (($1259) + 8|0);
 $1260 = (($1261) + -1)|0;
 HEAP32[$1258>>2] = $1260;
 $1262 = (($inStartIndex) + 18)|0;
 STACKTOP = sp;return ($1262|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj652ENS_22PxRepXPropertyAccessorILj652ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 48;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 48)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj651ENS_22PxRepXPropertyAccessorILj651ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 44;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 44)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj650ENS_22PxRepXPropertyAccessorILj650ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 40;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 40)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj649ENS_22PxRepXPropertyAccessorILj649ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 36;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 36)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $15;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$19>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($19,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($19,$vararg_buffer,1)|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($19) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($17,$$0$i$i$i$i,$40);
 $41 = (($19) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($19) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj648ENS_22PxRepXPropertyAccessorILj648ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 32;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 32)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $15;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$19>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($19,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($19,$vararg_buffer,1)|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($19) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($17,$$0$i$i$i$i,$40);
 $41 = (($19) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($19) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj647ENS_22PxRepXPropertyAccessorILj647ES4_bbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i$i$i$i = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 30;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 30)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = $15 ? 523216 : 523224;
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($29|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$29,$34)|0);
 }
 HEAP8[$data$i$i$i$i$i>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$data$i$i$i$i$i,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj646ENS_22PxRepXPropertyAccessorILj646ES4_bbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i$i$i$i = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 29;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 29)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = $15 ? 523216 : 523224;
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($29|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$29,$34)|0);
 }
 HEAP8[$data$i$i$i$i$i>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$data$i$i$i$i$i,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj645ENS_22PxRepXPropertyAccessorILj645ES4_bbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i$i$i$i = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 28;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 28)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = $15 ? 523216 : 523224;
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($29|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$29,$34)|0);
 }
 HEAP8[$data$i$i$i$i$i>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$data$i$i$i$i$i,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj644ENS_22PxRepXPropertyAccessorILj644ES4_KffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 24;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 24)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj643ENS_22PxRepXPropertyAccessorILj643ES4_KffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 20;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 20)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj642ENS_22PxRepXPropertyAccessorILj642ES4_KjjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 16;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 16)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $15;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$19>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($19,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($19,$vararg_buffer,1)|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($19) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($17,$$0$i$i$i$i,$40);
 $41 = (($19) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($19) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj641ENS_22PxRepXPropertyAccessorILj641ES4_KffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 12;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj640ENS_22PxRepXPropertyAccessorILj640ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $15;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$19>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($19,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($19,$vararg_buffer,1)|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($19) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($17,$$0$i$i$i$i,$40);
 $41 = (($19) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($19) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj639ENS_22PxRepXPropertyAccessorILj639ES4_jjEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 4;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 4)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$vararg_buffer>>2] = $15;
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521736,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$19>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($19,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($19,$vararg_buffer,1)|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($19) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($17,$$0$i$i$i$i,$40);
 $41 = (($19) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($19) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj638ENS_22PxRepXPropertyAccessorILj638ES4_KbbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i$i$i$i = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 2;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 2)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = $15 ? 523216 : 523224;
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($29|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$29,$34)|0);
 }
 HEAP8[$data$i$i$i$i$i>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$data$i$i$i$i$i,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj637ENS_22PxRepXPropertyAccessorILj637ES4_KbbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i$i$i$i = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 1;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 1)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($12)|0);
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = $15 ? 523216 : 523224;
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($29|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$29,$34)|0);
 }
 HEAP8[$data$i$i$i$i$i>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$data$i$i$i$i$i,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEE14handleAccessorILj636ENS_22PxRepXPropertyAccessorILj636ES4_KbbEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i$i$i$i = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $$0$i = $3;
 }
 HEAP8[$inAccessor>>0] = 1;
 $4 = (($inAccessor) + 4|0);
 HEAP32[$4>>2] = $$0$i;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$6>>2] = $9;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($inAccessor) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 4095]($11)|0);
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i = 521512;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i = $27;
 }
 $28 = $14 ? 523216 : 523224;
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$18>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($28|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($18,$28,$33)|0);
 }
 HEAP8[$data$i$i$i$i$i>>0] = 0;
 $34 = HEAP32[$18>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($18,$data$i$i$i$i$i,1)|0);
 $36 = HEAP32[$16>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($18) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($16,$$0$i$i$i$i,$40);
 $41 = (($18) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($18) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Sn21RepXVisitorWriterBaseINS_21PxVehicleDriveDynDataEE23extendedIndexedPropertyINS_3Pvd36PxPvdExtendedIndexedPropertyAccessorILj635ES2_KjfEEKNS_18PxUnknownClassInfoEEEvPjRKT_RT0_($this,$0,$inProp,$1) {
 $this = $this|0;
 $0 = $0|0;
 $inProp = $inProp|0;
 $1 = $1|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i2 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1 = 0, $$pre1$i = 0, $$pre1$i3 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $buffer$i$i$i$i = 0, $exitcond = 0, $i$04 = 0, $or$cond$i$i$i = 0, $theData = 0, $vararg_buffer1 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vararg_buffer1 = sp;
 $buffer$i$i$i$i = sp + 80|0;
 $theData = sp + 8|0;
 $2 = sp + 44|0;
 $buffer = sp + 48|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($inProp) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
 $10 = (($theData) + 20|0);
 $11 = (($theData) + 24|0);
 $12 = (($theData) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($theData) + 32|0);
 HEAP8[$10>>0] = 1;
 HEAP32[$11>>2] = $theData;
 HEAP32[$13>>2] = 5;
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN5physx6shdfnd5ArrayIfNS0_15InlineAllocatorILj20ENS0_19ReflectionAllocatorIfEEEEE6resizeEjRKf($theData,$9,$2);
 $14 = ($9|0)==(0);
 if (!($14)) {
  $15 = (($vararg_buffer1) + 4|0);
  $16 = (($this) + 4|0);
  $17 = (($this) + 12|0);
  $i$04 = 0;
  while(1) {
   dest=$buffer+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAP32[$vararg_buffer1>>2] = $i$04;
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer,0,521504,$vararg_buffer1)|0);
   $18 = HEAP32[$this>>2]|0;
   $19 = (($18) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $42 = $18;$47 = 0;
   } else {
    $22 = (($20) + -1)|0;
    $23 = (($18) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ((($24) + ($22<<3)|0) + 4|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($24) + ($22<<3)|0);
     $33 = HEAP32[$32>>2]|0;
     FUNCTION_TABLE_vii[$31 & 4095]($28,$33);
     $34 = HEAP32[$this>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + -1)|0;
     $38 = (($34) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($39) + ($37<<3)|0) + 4|0);
     HEAP8[$40>>0] = 1;
     $$pre$i = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i = (($$pre$i) + 8|0);
     $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $42 = $$pre$i;$47 = $$pre1$i;
    } else {
     $42 = $18;$47 = $20;
    }
   }
   HEAP32[$vararg_buffer1>>2] = $buffer;
   HEAP8[$15>>0] = 0;
   $41 = (($42) + 12|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = $43 & 2147483647;
   $45 = (($42) + 8|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    $48 = (($42) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47<<3)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $63 = $47;
    } else {
     $52 = $vararg_buffer1;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $50;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $$pre$i$i = HEAP32[$45>>2]|0;
     $63 = $$pre$i$i;
    }
    $62 = (($63) + 1)|0;
    HEAP32[$45>>2] = $62;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($42,$vararg_buffer1)|0);
   }
   $64 = HEAP32[$3>>2]|0;
   $65 = HEAP32[$5>>2]|0;
   $66 = (($65) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (Math_fround(FUNCTION_TABLE_fii[$67 & 63]($64,$i$04)));
   $69 = HEAP32[$16>>2]|0;
   $70 = HEAP32[$17>>2]|0;
   $71 = HEAP32[$this>>2]|0;
   $72 = (($71) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0);
   if ($74) {
    $$0$i$i = 521512;
   } else {
    $75 = (($73) + -1)|0;
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($75<<3)|0);
    $79 = HEAP32[$78>>2]|0;
    $$0$i$i = $79;
   }
   $80 = +$68;
   dest=$buffer$i$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   HEAPF64[tempDoublePtr>>3]=$80;HEAP32[$vararg_buffer1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer1+4>>2]=HEAP32[tempDoublePtr+4>>2];
   (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i$i,0,521528,$vararg_buffer1)|0);
   $81 = HEAP8[$buffer$i$i$i$i>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if (!($82)) {
    $83 = HEAP32[$70>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = (_strlen(($buffer$i$i$i$i|0))|0);
    (FUNCTION_TABLE_iiii[$84 & 2047]($70,$buffer$i$i$i$i,$85)|0);
   }
   HEAP8[$vararg_buffer1>>0] = 0;
   $86 = HEAP32[$70>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   (FUNCTION_TABLE_iiii[$87 & 2047]($70,$vararg_buffer1,1)|0);
   $88 = HEAP32[$69>>2]|0;
   $89 = (($88) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($70) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   FUNCTION_TABLE_viii[$90 & 4095]($69,$$0$i$i,$92);
   $93 = (($70) + 16|0);
   HEAP32[$93>>2] = 0;
   $94 = (($70) + 12|0);
   HEAP32[$94>>2] = 0;
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0);
   if (!($98)) {
    $99 = (($97) + -1)|0;
    $100 = (($95) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101) + ($99<<3)|0) + 4|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(0);
    if ($104) {
     $110 = $95;$112 = $97;
    } else {
     $105 = HEAP32[$16>>2]|0;
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + 20|0);
     $108 = HEAP32[$107>>2]|0;
     FUNCTION_TABLE_vi[$108 & 4095]($105);
     $$pre$i1 = HEAP32[$this>>2]|0;
     $$phi$trans$insert$i2 = (($$pre$i1) + 8|0);
     $$pre1$i3 = HEAP32[$$phi$trans$insert$i2>>2]|0;
     $110 = $$pre$i1;$112 = $$pre1$i3;
    }
    $109 = (($110) + 8|0);
    $111 = (($112) + -1)|0;
    HEAP32[$109>>2] = $111;
   }
   $113 = (($i$04) + 1)|0;
   $exitcond = ($113|0)==($9|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $113;
   }
  }
 }
 $114 = HEAP32[$13>>2]|0;
 $115 = $114 & 2147483647;
 $116 = ($115|0)!=(0);
 $117 = ($114|0)>(-1);
 $or$cond$i$i$i = $116 & $117;
 if (!($or$cond$i$i$i)) {
  STACKTOP = sp;return;
 }
 $118 = HEAP32[$11>>2]|0;
 $119 = ($theData|0)==($118|0);
 if ($119) {
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $120 = ($118|0)==(0|0);
 if ($120) {
  STACKTOP = sp;return;
 }
 $121 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 FUNCTION_TABLE_vii[$124 & 4095]($121,$118);
 STACKTOP = sp;return;
}
function __ZNK5physx28PxVehicleWheelsGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i8 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i3 = 0, $$pre$i7 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i5 = 0, $$pre1$i9 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i2 = sp + 8|0;
 $1 = (($this) + 36|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $2 = (($theAccessor$i2) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i8 = (($$pre$i7) + 8|0);
   $$pre1$i9 = HEAP32[$$phi$trans$insert$i8>>2]|0;
   $31 = $$pre$i7;$36 = $$pre1$i9;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i11 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i11;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEE14handleAccessorILj631ENS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataESA_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre13 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre13;$80 = $$pre;
 }
 $72 = (($this) + 52|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $73 = (($theAccessor$i2) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $101 = $$pre$i;$106 = $$pre1$i;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i1 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i1;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEE14handleAccessorILj632ENS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataESA_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $142 = (($inStartIndex) + 5)|0;
  STACKTOP = sp;return ($142|0);
 }
 $127 = (($125) + -1)|0;
 $128 = (($123) + 4|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($129) + ($127<<3)|0) + 4|0);
 $131 = HEAP8[$130>>0]|0;
 $132 = ($131<<24>>24)==(0);
 if ($132) {
  $139 = $123;$141 = $125;
 } else {
  $133 = (($inOperator) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + 20|0);
  $137 = HEAP32[$136>>2]|0;
  FUNCTION_TABLE_vi[$137 & 4095]($134);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $139 = $$pre$i$i;$141 = $$pre1$i$i;
 }
 $138 = (($139) + 8|0);
 $140 = (($141) + -1)|0;
 HEAP32[$138>>2] = $140;
 $142 = (($inStartIndex) + 5)|0;
 STACKTOP = sp;return ($142|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEE14handleAccessorILj632ENS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $info$i$i$i$i$i = sp + 136|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 64|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 76;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 76)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsDynDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDriveNWEEEE14handleAccessorILj631ENS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $info$i$i$i$i$i = sp + 352|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 96|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 12;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 12)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 _memset(($1|0),0,256)|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx31PxVehicleDriveTankGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$0$i$i$i$i$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i8 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i3 = 0, $$pre$i7 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i5 = 0, $$pre1$i9 = 0, $$pre13 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $conv$01$i$i$i$i$i = 0, $theAccessor$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i = sp + 8|0;
 $1 = (($this) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i8 = (($$pre$i7) + 8|0);
   $$pre1$i9 = HEAP32[$$phi$trans$insert$i8>>2]|0;
   $31 = $$pre$i7;$36 = $$pre1$i9;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i11 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i11;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 $53 = (($inOperator) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = HEAP32[$54>>2]|0;
  $57 = (($56) + 1)|0;
  HEAP32[$54>>2] = $57;
 }
 $58 = (($inOperator) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$inOperator>>2]|0;
 $61 = (($60) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  $$0$i$i$i$i$i = 521512;
 } else {
  $64 = (($62) + -1)|0;
  $65 = (($60) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + ($64<<3)|0);
  $68 = HEAP32[$67>>2]|0;
  $$0$i$i$i$i$i = $68;
 }
 $69 = (($inOperator) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (FUNCTION_TABLE_ii[$2 & 4095]($70)|0);
 $72 = (523256|0)==(0|0);
 if (!($72)) {
  $79 = 523256;$conv$01$i$i$i$i$i = 523232;
  while(1) {
   $73 = (($conv$01$i$i$i$i$i) + 4|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==($71|0);
   if ($75) {
    $76 = HEAP32[$59>>2]|0;
    $77 = (($76) + 8|0);
    $78 = HEAP32[$77>>2]|0;
    FUNCTION_TABLE_viii[$78 & 4095]($59,$$0$i$i$i$i$i,$79);
   }
   $80 = (($conv$01$i$i$i$i$i) + 8|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0|0);
   if ($82) {
    break;
   } else {
    $79 = $81;$conv$01$i$i$i$i$i = $80;
   }
  }
 }
 $83 = HEAP32[$inOperator>>2]|0;
 $84 = (($83) + 8|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($85|0)==(0);
 if ($86) {
  $106 = 0;$109 = $83;
 } else {
  $87 = (($85) + -1)|0;
  $88 = (($83) + 4|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ((($89) + ($87<<3)|0) + 4|0);
  $91 = HEAP8[$90>>0]|0;
  $92 = ($91<<24>>24)==(0);
  if ($92) {
   $100 = $85;$98 = $83;
  } else {
   $93 = HEAP32[$58>>2]|0;
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + 20|0);
   $96 = HEAP32[$95>>2]|0;
   FUNCTION_TABLE_vi[$96 & 4095]($93);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $100 = $$pre1$i$i5;$98 = $$pre$i$i3;
  }
  $97 = (($98) + 8|0);
  $99 = (($100) + -1)|0;
  HEAP32[$97>>2] = $99;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre13 = HEAP32[$$phi$trans$insert>>2]|0;
  $106 = $$pre13;$109 = $$pre;
 }
 $101 = (($this) + 124|0);
 HEAP8[$theAccessor$i>>0] = 0;
 $102 = (($theAccessor$i) + 4|0);
 HEAP32[$102>>2] = 0;
 $103 = (($theAccessor$i) + 8|0);
 ;HEAP32[$103+0>>2]=HEAP32[$101+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$101+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$101+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$101+12>>2]|0;
 $104 = HEAP32[$101>>2]|0;
 $105 = ($106|0)==(0);
 if ($105) {
  $129 = $109;$134 = 0;
 } else {
  $107 = (($106) + -1)|0;
  $108 = (($109) + 4|0);
  $110 = HEAP32[$108>>2]|0;
  $111 = ((($110) + ($107<<3)|0) + 4|0);
  $112 = HEAP8[$111>>0]|0;
  $113 = ($112<<24>>24)==(0);
  if ($113) {
   $114 = HEAP32[$58>>2]|0;
   $115 = HEAP32[$114>>2]|0;
   $116 = (($115) + 16|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = (($110) + ($107<<3)|0);
   $119 = HEAP32[$118>>2]|0;
   FUNCTION_TABLE_vii[$117 & 4095]($114,$119);
   $120 = HEAP32[$inOperator>>2]|0;
   $121 = (($120) + 8|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = (($122) + -1)|0;
   $124 = (($120) + 4|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = ((($125) + ($123<<3)|0) + 4|0);
   HEAP8[$126>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $129 = $$pre$i;$134 = $$pre1$i;
  } else {
   $129 = $109;$134 = $106;
  }
 }
 HEAP32[$0>>2] = $104;
 $127 = (($0) + 4|0);
 HEAP8[$127>>0] = 0;
 $128 = (($129) + 12|0);
 $130 = HEAP32[$128>>2]|0;
 $131 = $130 & 2147483647;
 $132 = (($129) + 8|0);
 $133 = ($131>>>0)>($134>>>0);
 if ($133) {
  $135 = (($129) + 4|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = (($136) + ($134<<3)|0);
  $138 = ($137|0)==(0|0);
  if ($138) {
   $150 = $134;
  } else {
   $139 = $0;
   $140 = $139;
   $141 = HEAP32[$140>>2]|0;
   $142 = (($139) + 4)|0;
   $143 = $142;
   $144 = HEAP32[$143>>2]|0;
   $145 = $137;
   $146 = $145;
   HEAP32[$146>>2] = $141;
   $147 = (($145) + 4)|0;
   $148 = $147;
   HEAP32[$148>>2] = $144;
   $$pre$i$i1 = HEAP32[$132>>2]|0;
   $150 = $$pre$i$i1;
  }
  $149 = (($150) + 1)|0;
  HEAP32[$132>>2] = $149;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($129,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEE14handleAccessorILj675ENS_22PxRepXPropertyAccessorILj675ES4_NS_21PxVehicleDriveSimDataES9_EEEEvRKT0_($inOperator,$theAccessor$i);
 $151 = HEAP32[$inOperator>>2]|0;
 $152 = (($151) + 8|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = ($153|0)==(0);
 if ($154) {
  $169 = (($inStartIndex) + 3)|0;
  STACKTOP = sp;return ($169|0);
 }
 $155 = (($153) + -1)|0;
 $156 = (($151) + 4|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = ((($157) + ($155<<3)|0) + 4|0);
 $159 = HEAP8[$158>>0]|0;
 $160 = ($159<<24>>24)==(0);
 if ($160) {
  $166 = $151;$168 = $153;
 } else {
  $161 = HEAP32[$58>>2]|0;
  $162 = HEAP32[$161>>2]|0;
  $163 = (($162) + 20|0);
  $164 = HEAP32[$163>>2]|0;
  FUNCTION_TABLE_vi[$164 & 4095]($161);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $166 = $$pre$i$i;$168 = $$pre1$i$i;
 }
 $165 = (($166) + 8|0);
 $167 = (($168) + -1)|0;
 HEAP32[$165>>2] = $167;
 $169 = (($inStartIndex) + 3)|0;
 STACKTOP = sp;return ($169|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEE14handleAccessorILj675ENS_22PxRepXPropertyAccessorILj675ES4_NS_21PxVehicleDriveSimDataES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 688|0;
 $info$i$i$i$i$i = sp + 624|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 560|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 216;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 216)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx34PxVehicleDriveSimDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx34PxVehicleDriveSimDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx34PxVehicleDriveSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx34PxVehicleDriveSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i12 = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i16 = 0, $$phi$trans$insert$i23 = 0, $$phi$trans$insert$i30 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert40 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i19 = 0, $$pre$i$i26 = 0, $$pre$i$i3 = 0, $$pre$i$i33 = 0;
 var $$pre$i$i7 = 0, $$pre$i15 = 0, $$pre$i22 = 0, $$pre$i29 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i13 = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i17 = 0, $$pre1$i24 = 0, $$pre1$i31 = 0, $$pre35 = 0, $$pre36 = 0, $$pre38 = 0, $$pre39 = 0, $$pre41 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $theAccessor$i10 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i10 = sp + 8|0;
 HEAP8[$theAccessor$i10>>0] = 0;
 $1 = (($theAccessor$i10) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$this+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$this+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$this+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$this+12>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i15 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i16 = (($$pre$i15) + 8|0);
   $$pre1$i17 = HEAP32[$$phi$trans$insert$i16>>2]|0;
   $30 = $$pre$i15;$35 = $$pre1$i17;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i19 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i19;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj655ENS_22PxRepXPropertyAccessorILj655ES4_RKNS_19PxVehicleEngineDataES9_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $52 = HEAP32[$inOperator>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $76 = 0;$79 = $52;
 } else {
  $56 = (($54) + -1)|0;
  $57 = (($52) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58) + ($56<<3)|0) + 4|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $68 = $52;$70 = $54;
  } else {
   $62 = (($inOperator) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vi[$66 & 4095]($63);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $68 = $$pre$i$i3;$70 = $$pre1$i$i5;
  }
  $67 = (($68) + 8|0);
  $69 = (($70) + -1)|0;
  HEAP32[$67>>2] = $69;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre35 = HEAP32[$$phi$trans$insert>>2]|0;
  $76 = $$pre35;$79 = $$pre;
 }
 $71 = (($this) + 16|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $72 = (($theAccessor$i10) + 4|0);
 HEAP32[$72>>2] = 0;
 $73 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$73+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$71+12>>2]|0;
 $74 = HEAP32[$71>>2]|0;
 $75 = ($76|0)==(0);
 if ($75) {
  $100 = $79;$105 = 0;
 } else {
  $77 = (($76) + -1)|0;
  $78 = (($79) + 4|0);
  $80 = HEAP32[$78>>2]|0;
  $81 = ((($80) + ($77<<3)|0) + 4|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = ($82<<24>>24)==(0);
  if ($83) {
   $84 = (($inOperator) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 16|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($80) + ($77<<3)|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_vii[$88 & 4095]($85,$90);
   $91 = HEAP32[$inOperator>>2]|0;
   $92 = (($91) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + -1)|0;
   $95 = (($91) + 4|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ((($96) + ($94<<3)|0) + 4|0);
   HEAP8[$97>>0] = 1;
   $$pre$i22 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i23 = (($$pre$i22) + 8|0);
   $$pre1$i24 = HEAP32[$$phi$trans$insert$i23>>2]|0;
   $100 = $$pre$i22;$105 = $$pre1$i24;
  } else {
   $100 = $79;$105 = $76;
  }
 }
 HEAP32[$0>>2] = $74;
 $98 = (($0) + 4|0);
 HEAP8[$98>>0] = 0;
 $99 = (($100) + 12|0);
 $101 = HEAP32[$99>>2]|0;
 $102 = $101 & 2147483647;
 $103 = (($100) + 8|0);
 $104 = ($102>>>0)>($105>>>0);
 if ($104) {
  $106 = (($100) + 4|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($107) + ($105<<3)|0);
  $109 = ($108|0)==(0|0);
  if ($109) {
   $121 = $105;
  } else {
   $110 = $0;
   $111 = $110;
   $112 = HEAP32[$111>>2]|0;
   $113 = (($110) + 4)|0;
   $114 = $113;
   $115 = HEAP32[$114>>2]|0;
   $116 = $108;
   $117 = $116;
   HEAP32[$117>>2] = $112;
   $118 = (($116) + 4)|0;
   $119 = $118;
   HEAP32[$119>>2] = $115;
   $$pre$i$i26 = HEAP32[$103>>2]|0;
   $121 = $$pre$i$i26;
  }
  $120 = (($121) + 1)|0;
  HEAP32[$103>>2] = $120;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($100,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ES4_RKNS_18PxVehicleGearsDataES9_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $122 = HEAP32[$inOperator>>2]|0;
 $123 = (($122) + 8|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($124|0)==(0);
 if ($125) {
  $146 = 0;$149 = $122;
 } else {
  $126 = (($124) + -1)|0;
  $127 = (($122) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ((($128) + ($126<<3)|0) + 4|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = ($130<<24>>24)==(0);
  if ($131) {
   $138 = $122;$140 = $124;
  } else {
   $132 = (($inOperator) + 4|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 20|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_vi[$136 & 4095]($133);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $138 = $$pre$i$i7;$140 = $$pre1$i$i9;
  }
  $137 = (($138) + 8|0);
  $139 = (($140) + -1)|0;
  HEAP32[$137>>2] = $139;
  $$pre36 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert37 = (($$pre36) + 8|0);
  $$pre38 = HEAP32[$$phi$trans$insert37>>2]|0;
  $146 = $$pre38;$149 = $$pre36;
 }
 $141 = (($this) + 32|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $142 = (($theAccessor$i10) + 4|0);
 HEAP32[$142>>2] = 0;
 $143 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$143+0>>2]=HEAP32[$141+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$141+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$141+8>>2]|0;HEAP32[$143+12>>2]=HEAP32[$141+12>>2]|0;
 $144 = HEAP32[$141>>2]|0;
 $145 = ($146|0)==(0);
 if ($145) {
  $170 = $149;$175 = 0;
 } else {
  $147 = (($146) + -1)|0;
  $148 = (($149) + 4|0);
  $150 = HEAP32[$148>>2]|0;
  $151 = ((($150) + ($147<<3)|0) + 4|0);
  $152 = HEAP8[$151>>0]|0;
  $153 = ($152<<24>>24)==(0);
  if ($153) {
   $154 = (($inOperator) + 4|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = HEAP32[$155>>2]|0;
   $157 = (($156) + 16|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($150) + ($147<<3)|0);
   $160 = HEAP32[$159>>2]|0;
   FUNCTION_TABLE_vii[$158 & 4095]($155,$160);
   $161 = HEAP32[$inOperator>>2]|0;
   $162 = (($161) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = (($163) + -1)|0;
   $165 = (($161) + 4|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ((($166) + ($164<<3)|0) + 4|0);
   HEAP8[$167>>0] = 1;
   $$pre$i29 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i30 = (($$pre$i29) + 8|0);
   $$pre1$i31 = HEAP32[$$phi$trans$insert$i30>>2]|0;
   $170 = $$pre$i29;$175 = $$pre1$i31;
  } else {
   $170 = $149;$175 = $146;
  }
 }
 HEAP32[$0>>2] = $144;
 $168 = (($0) + 4|0);
 HEAP8[$168>>0] = 0;
 $169 = (($170) + 12|0);
 $171 = HEAP32[$169>>2]|0;
 $172 = $171 & 2147483647;
 $173 = (($170) + 8|0);
 $174 = ($172>>>0)>($175>>>0);
 if ($174) {
  $176 = (($170) + 4|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($177) + ($175<<3)|0);
  $179 = ($178|0)==(0|0);
  if ($179) {
   $191 = $175;
  } else {
   $180 = $0;
   $181 = $180;
   $182 = HEAP32[$181>>2]|0;
   $183 = (($180) + 4)|0;
   $184 = $183;
   $185 = HEAP32[$184>>2]|0;
   $186 = $178;
   $187 = $186;
   HEAP32[$187>>2] = $182;
   $188 = (($186) + 4)|0;
   $189 = $188;
   HEAP32[$189>>2] = $185;
   $$pre$i$i33 = HEAP32[$173>>2]|0;
   $191 = $$pre$i$i33;
  }
  $190 = (($191) + 1)|0;
  HEAP32[$173>>2] = $190;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($170,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ES4_RKNS_19PxVehicleClutchDataES9_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $192 = HEAP32[$inOperator>>2]|0;
 $193 = (($192) + 8|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194|0)==(0);
 if ($195) {
  $216 = 0;$219 = $192;
 } else {
  $196 = (($194) + -1)|0;
  $197 = (($192) + 4|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ((($198) + ($196<<3)|0) + 4|0);
  $200 = HEAP8[$199>>0]|0;
  $201 = ($200<<24>>24)==(0);
  if ($201) {
   $208 = $192;$210 = $194;
  } else {
   $202 = (($inOperator) + 4|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = HEAP32[$203>>2]|0;
   $205 = (($204) + 20|0);
   $206 = HEAP32[$205>>2]|0;
   FUNCTION_TABLE_vi[$206 & 4095]($203);
   $$pre$i$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i12 = (($$pre$i$i11) + 8|0);
   $$pre1$i$i13 = HEAP32[$$phi$trans$insert$i$i12>>2]|0;
   $208 = $$pre$i$i11;$210 = $$pre1$i$i13;
  }
  $207 = (($208) + 8|0);
  $209 = (($210) + -1)|0;
  HEAP32[$207>>2] = $209;
  $$pre39 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert40 = (($$pre39) + 8|0);
  $$pre41 = HEAP32[$$phi$trans$insert40>>2]|0;
  $216 = $$pre41;$219 = $$pre39;
 }
 $211 = (($this) + 48|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $212 = (($theAccessor$i10) + 4|0);
 HEAP32[$212>>2] = 0;
 $213 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$213+0>>2]=HEAP32[$211+0>>2]|0;HEAP32[$213+4>>2]=HEAP32[$211+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$211+8>>2]|0;HEAP32[$213+12>>2]=HEAP32[$211+12>>2]|0;
 $214 = HEAP32[$211>>2]|0;
 $215 = ($216|0)==(0);
 if ($215) {
  $240 = $219;$245 = 0;
 } else {
  $217 = (($216) + -1)|0;
  $218 = (($219) + 4|0);
  $220 = HEAP32[$218>>2]|0;
  $221 = ((($220) + ($217<<3)|0) + 4|0);
  $222 = HEAP8[$221>>0]|0;
  $223 = ($222<<24>>24)==(0);
  if ($223) {
   $224 = (($inOperator) + 4|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = HEAP32[$225>>2]|0;
   $227 = (($226) + 16|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = (($220) + ($217<<3)|0);
   $230 = HEAP32[$229>>2]|0;
   FUNCTION_TABLE_vii[$228 & 4095]($225,$230);
   $231 = HEAP32[$inOperator>>2]|0;
   $232 = (($231) + 8|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = (($233) + -1)|0;
   $235 = (($231) + 4|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ((($236) + ($234<<3)|0) + 4|0);
   HEAP8[$237>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $240 = $$pre$i;$245 = $$pre1$i;
  } else {
   $240 = $219;$245 = $216;
  }
 }
 HEAP32[$0>>2] = $214;
 $238 = (($0) + 4|0);
 HEAP8[$238>>0] = 0;
 $239 = (($240) + 12|0);
 $241 = HEAP32[$239>>2]|0;
 $242 = $241 & 2147483647;
 $243 = (($240) + 8|0);
 $244 = ($242>>>0)>($245>>>0);
 if ($244) {
  $246 = (($240) + 4|0);
  $247 = HEAP32[$246>>2]|0;
  $248 = (($247) + ($245<<3)|0);
  $249 = ($248|0)==(0|0);
  if ($249) {
   $261 = $245;
  } else {
   $250 = $0;
   $251 = $250;
   $252 = HEAP32[$251>>2]|0;
   $253 = (($250) + 4)|0;
   $254 = $253;
   $255 = HEAP32[$254>>2]|0;
   $256 = $248;
   $257 = $256;
   HEAP32[$257>>2] = $252;
   $258 = (($256) + 4)|0;
   $259 = $258;
   HEAP32[$259>>2] = $255;
   $$pre$i$i1 = HEAP32[$243>>2]|0;
   $261 = $$pre$i$i1;
  }
  $260 = (($261) + 1)|0;
  HEAP32[$243>>2] = $260;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($240,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ES4_RKNS_20PxVehicleAutoBoxDataES9_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $262 = HEAP32[$inOperator>>2]|0;
 $263 = (($262) + 8|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = ($264|0)==(0);
 if ($265) {
  $281 = (($inStartIndex) + 4)|0;
  STACKTOP = sp;return ($281|0);
 }
 $266 = (($264) + -1)|0;
 $267 = (($262) + 4|0);
 $268 = HEAP32[$267>>2]|0;
 $269 = ((($268) + ($266<<3)|0) + 4|0);
 $270 = HEAP8[$269>>0]|0;
 $271 = ($270<<24>>24)==(0);
 if ($271) {
  $278 = $262;$280 = $264;
 } else {
  $272 = (($inOperator) + 4|0);
  $273 = HEAP32[$272>>2]|0;
  $274 = HEAP32[$273>>2]|0;
  $275 = (($274) + 20|0);
  $276 = HEAP32[$275>>2]|0;
  FUNCTION_TABLE_vi[$276 & 4095]($273);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $278 = $$pre$i$i;$280 = $$pre1$i$i;
 }
 $277 = (($278) + 8|0);
 $279 = (($280) + -1)|0;
 HEAP32[$277>>2] = $279;
 $281 = (($inStartIndex) + 4)|0;
 STACKTOP = sp;return ($281|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ES4_RKNS_20PxVehicleAutoBoxDataES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $info$i$i$i$i$i = sp + 336|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 288|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 272;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 272)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx33PxVehicleAutoBoxDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ES4_RKNS_19PxVehicleClutchDataES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $info$i$i$i$i$i = sp + 96|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 48|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 256;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 256)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx32PxVehicleClutchDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleClutchDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ES4_RKNS_18PxVehicleGearsDataES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $info$i$i$i$i$i = sp + 240|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 176|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 112;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 112)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx31PxVehicleGearsDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveSimDataEEEE14handleAccessorILj655ENS_22PxRepXPropertyAccessorILj655ES4_RKNS_19PxVehicleEngineDataES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $info$i$i$i$i$i = sp + 288|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 144|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 0;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $$0$i = $5;
 }
 HEAP8[$inAccessor>>0] = 1;
 $6 = (($inAccessor) + 4|0);
 HEAP32[$6>>2] = $$0$i;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$8>>2] = $11;
 }
 _memset(($1|0),0,144)|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($1);
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($inAccessor) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($propVal$i$i$i,$13);
 $16 = HEAP32[$this>>2]|0;
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $16;
 $23 = (($0) + 4|0);
 HEAP32[$23>>2] = $18;
 $24 = (($0) + 8|0);
 HEAP32[$24>>2] = $propVal$i$i$i;
 $25 = (($0) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($0) + 16|0);
 HEAP32[$26>>2] = $22;
 $27 = (($0) + 20|0);
 HEAP32[$27>>2] = 0;
 $28 = (($0) + 24|0);
 HEAP32[$28>>2] = 0;
 (__ZNK5physx32PxVehicleEngineDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx27PxVehicleDriveGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0;
 var $theAccessor$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i = sp + 8|0;
 $1 = (($this) + 80|0);
 HEAP8[$theAccessor$i>>0] = 0;
 $2 = (($theAccessor$i) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $31 = $$pre$i;$36 = $$pre1$i;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i1 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i1;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEE14handleAccessorILj666ENS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataESA_EEEEvRKT0_($inOperator,$theAccessor$i);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $72 = (($inStartIndex) + 2)|0;
  STACKTOP = sp;return ($72|0);
 }
 $57 = (($55) + -1)|0;
 $58 = (($53) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59) + ($57<<3)|0) + 4|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $69 = $53;$71 = $55;
 } else {
  $63 = (($inOperator) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + 20|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_vi[$67 & 4095]($64);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $69 = $$pre$i$i;$71 = $$pre1$i$i;
 }
 $68 = (($69) + 8|0);
 $70 = (($71) + -1)|0;
 HEAP32[$68>>2] = $70;
 $72 = (($inStartIndex) + 2)|0;
 STACKTOP = sp;return ($72|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEE14handleAccessorILj666ENS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 720|0;
 $info$i$i$i$i$i = sp + 424|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 128|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 112;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 112)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 _memset(($1|0),0,296)|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx34PxVehicleDriveDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx28PxVehicleWheelsGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i8 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i3 = 0, $$pre$i7 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i5 = 0, $$pre1$i9 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i2 = sp + 8|0;
 $1 = (($this) + 36|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $2 = (($theAccessor$i2) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i8 = (($$pre$i7) + 8|0);
   $$pre1$i9 = HEAP32[$$phi$trans$insert$i8>>2]|0;
   $31 = $$pre$i7;$36 = $$pre1$i9;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i11 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i11;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEE14handleAccessorILj631ENS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataESA_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre13 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre13;$80 = $$pre;
 }
 $72 = (($this) + 52|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $73 = (($theAccessor$i2) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $101 = $$pre$i;$106 = $$pre1$i;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i1 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i1;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEE14handleAccessorILj632ENS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataESA_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $142 = (($inStartIndex) + 5)|0;
  STACKTOP = sp;return ($142|0);
 }
 $127 = (($125) + -1)|0;
 $128 = (($123) + 4|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($129) + ($127<<3)|0) + 4|0);
 $131 = HEAP8[$130>>0]|0;
 $132 = ($131<<24>>24)==(0);
 if ($132) {
  $139 = $123;$141 = $125;
 } else {
  $133 = (($inOperator) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + 20|0);
  $137 = HEAP32[$136>>2]|0;
  FUNCTION_TABLE_vi[$137 & 4095]($134);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $139 = $$pre$i$i;$141 = $$pre1$i$i;
 }
 $138 = (($139) + 8|0);
 $140 = (($141) + -1)|0;
 HEAP32[$138>>2] = $140;
 $142 = (($inStartIndex) + 5)|0;
 STACKTOP = sp;return ($142|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEE14handleAccessorILj632ENS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $info$i$i$i$i$i = sp + 136|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 64|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 76;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 76)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsDynDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleDriveTankEEEE14handleAccessorILj631ENS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $info$i$i$i$i$i = sp + 352|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 96|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 12;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 12)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 _memset(($1|0),0,256)|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Sn18writeAllPropertiesINS_16PxVehicleDrive4WEEEvRNS_7profile12ProfileArrayINS0_14NameStackEntryEEEPKT_RNS_9XmlWriterERNS_12MemoryBufferERNS_12PxCollectionE($inNameStack,$inObj,$writer,$buffer,$collection) {
 $inNameStack = $inNameStack|0;
 $inObj = $inObj|0;
 $writer = $writer|0;
 $buffer = $buffer|0;
 $collection = $collection|0;
 var $$pre$i$i = 0, $$pre1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $info = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp;
 $1 = sp + 180|0;
 $info = sp + 28|0;
 $2 = sp + 152|0;
 __ZN5physx29PxVehicleDrive4WGeneratedInfoC2Ev($info);
 HEAP32[$0>>2] = $inNameStack;
 $3 = (($0) + 4|0);
 HEAP32[$3>>2] = $writer;
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $inObj;
 $5 = (($0) + 12|0);
 HEAP32[$5>>2] = $buffer;
 $6 = (($0) + 16|0);
 HEAP32[$6>>2] = $collection;
 $7 = (($0) + 20|0);
 HEAP32[$7>>2] = 0;
 $8 = (($0) + 24|0);
 HEAP32[$8>>2] = 0;
 $9 = (__ZNK5physx28PxVehicleWheelsGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEEEEEjT_j($info,$0,0)|0);
 HEAP32[$1>>2] = $inNameStack;
 $10 = (($1) + 4|0);
 HEAP32[$10>>2] = $writer;
 $11 = (($1) + 8|0);
 HEAP32[$11>>2] = $inObj;
 $12 = (($1) + 12|0);
 HEAP32[$12>>2] = $buffer;
 $13 = (($1) + 16|0);
 HEAP32[$13>>2] = $collection;
 $14 = (($1) + 20|0);
 HEAP32[$14>>2] = 0;
 $15 = (($1) + 24|0);
 HEAP32[$15>>2] = 0;
 (__ZNK5physx27PxVehicleDriveGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEEEEEjT_j($info,$1,$9)|0);
 HEAP32[$2>>2] = $inNameStack;
 $16 = (($2) + 4|0);
 HEAP32[$16>>2] = $writer;
 $17 = (($2) + 8|0);
 HEAP32[$17>>2] = $inObj;
 $18 = (($2) + 12|0);
 HEAP32[$18>>2] = $buffer;
 $19 = (($2) + 16|0);
 HEAP32[$19>>2] = $collection;
 $20 = (($2) + 20|0);
 HEAP32[$20>>2] = 0;
 $21 = (($2) + 24|0);
 HEAP32[$21>>2] = 0;
 $22 = (($info) + 108|0);
 HEAP8[$1>>0] = 0;
 $23 = (($1) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = (($1) + 8|0);
 ;HEAP32[$24+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$22+12>>2]|0;
 $25 = HEAP32[$22>>2]|0;
 $26 = (($inNameStack) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  $49 = 0;
 } else {
  $29 = (($27) + -1)|0;
  $30 = (($inNameStack) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($31) + ($29<<3)|0) + 4|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   $35 = HEAP32[$writer>>2]|0;
   $36 = (($35) + 16|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($31) + ($29<<3)|0);
   $39 = HEAP32[$38>>2]|0;
   FUNCTION_TABLE_vii[$37 & 4095]($writer,$39);
   $40 = HEAP32[$26>>2]|0;
   $41 = (($40) + -1)|0;
   $42 = HEAP32[$30>>2]|0;
   $43 = ((($42) + ($41<<3)|0) + 4|0);
   HEAP8[$43>>0] = 1;
   $49 = $40;
  } else {
   $49 = $27;
  }
 }
 HEAP32[$0>>2] = $25;
 $44 = (($0) + 4|0);
 HEAP8[$44>>0] = 0;
 $45 = (($inNameStack) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 & 2147483647;
 $48 = ($47>>>0)>($49>>>0);
 if ($48) {
  $50 = (($inNameStack) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + ($49<<3)|0);
  $53 = ($52|0)==(0|0);
  if ($53) {
   $65 = $49;
  } else {
   $54 = $0;
   $55 = $54;
   $56 = HEAP32[$55>>2]|0;
   $57 = (($54) + 4)|0;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = $52;
   $61 = $60;
   HEAP32[$61>>2] = $56;
   $62 = (($60) + 4)|0;
   $63 = $62;
   HEAP32[$63>>2] = $59;
   $$pre$i$i = HEAP32[$26>>2]|0;
   $65 = $$pre$i$i;
  }
  $64 = (($65) + 1)|0;
  HEAP32[$26>>2] = $64;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($inNameStack,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEE14handleAccessorILj670ENS_22PxRepXPropertyAccessorILj670ES4_NS_23PxVehicleDriveSimData4WES9_EEEEvRKT0_($2,$1);
 $66 = HEAP32[$2>>2]|0;
 $67 = (($66) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0);
 if ($69) {
  STACKTOP = sp;return;
 }
 $70 = (($68) + -1)|0;
 $71 = (($66) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($72) + ($70<<3)|0) + 4|0);
 $74 = HEAP8[$73>>0]|0;
 $75 = ($74<<24>>24)==(0);
 if ($75) {
  $81 = $68;
 } else {
  $76 = HEAP32[$16>>2]|0;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($77) + 20|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_vi[$79 & 4095]($76);
  $$pre1$i$i$i = HEAP32[$67>>2]|0;
  $81 = $$pre1$i$i$i;
 }
 $80 = (($81) + -1)|0;
 HEAP32[$67>>2] = $80;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEE14handleAccessorILj670ENS_22PxRepXPropertyAccessorILj670ES4_NS_23PxVehicleDriveSimData4WES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 832|0;
 $0 = sp + 800|0;
 $info$i$i$i$i$i = sp;
 $1 = sp + 96|0;
 $propVal$i$i$i = sp + 128|0;
 $2 = sp + 704|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0$i = 212;
 } else {
  $6 = HEAP32[$4>>2]|0;
  $7 = (($6) + 212)|0;
  $$0$i = $7;
 }
 HEAP8[$inAccessor>>0] = 1;
 $8 = (($inAccessor) + 4|0);
 HEAP32[$8>>2] = $$0$i;
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$10>>2] = $13;
 }
 dest=$2+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx36PxVehicleDriveSimData4WGeneratedInfoC2Ev($2);
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($inAccessor) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($propVal$i$i$i,$15);
 $18 = HEAP32[$this>>2]|0;
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 __ZN5physx36PxVehicleDriveSimData4WGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $18;
 $25 = (($0) + 4|0);
 HEAP32[$25>>2] = $20;
 $26 = (($0) + 8|0);
 HEAP32[$26>>2] = $propVal$i$i$i;
 $27 = (($0) + 12|0);
 HEAP32[$27>>2] = $22;
 $28 = (($0) + 16|0);
 HEAP32[$28>>2] = $24;
 $29 = (($0) + 20|0);
 HEAP32[$29>>2] = 0;
 $30 = (($0) + 24|0);
 HEAP32[$30>>2] = 0;
 (__ZNK5physx34PxVehicleDriveSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 HEAP32[$1>>2] = $18;
 $31 = (($1) + 4|0);
 HEAP32[$31>>2] = $20;
 $32 = (($1) + 8|0);
 HEAP32[$32>>2] = $propVal$i$i$i;
 $33 = (($1) + 12|0);
 HEAP32[$33>>2] = $22;
 $34 = (($1) + 16|0);
 HEAP32[$34>>2] = $24;
 $35 = (($1) + 20|0);
 HEAP32[$35>>2] = 0;
 $36 = (($1) + 24|0);
 HEAP32[$36>>2] = 0;
 (__ZNK5physx36PxVehicleDriveSimData4WGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEEEEEjT_j($info$i$i$i$i$i,$1,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx36PxVehicleDriveSimData4WGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i8 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i3 = 0, $$pre$i7 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i5 = 0, $$pre1$i9 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i2 = sp + 8|0;
 $1 = (($this) + 64|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $2 = (($theAccessor$i2) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i8 = (($$pre$i7) + 8|0);
   $$pre1$i9 = HEAP32[$$phi$trans$insert$i8>>2]|0;
   $31 = $$pre$i7;$36 = $$pre1$i9;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i11 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i11;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj661ENS_22PxRepXPropertyAccessorILj661ES4_RKNS_27PxVehicleDifferential4WDataES9_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre13 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre13;$80 = $$pre;
 }
 $72 = (($this) + 80|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $73 = (($theAccessor$i2) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $101 = $$pre$i;$106 = $$pre1$i;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i1 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i1;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj662ENS_22PxRepXPropertyAccessorILj662ES4_RKNS_30PxVehicleAckermannGeometryDataES9_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $142 = (($inStartIndex) + 2)|0;
  STACKTOP = sp;return ($142|0);
 }
 $127 = (($125) + -1)|0;
 $128 = (($123) + 4|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($129) + ($127<<3)|0) + 4|0);
 $131 = HEAP8[$130>>0]|0;
 $132 = ($131<<24>>24)==(0);
 if ($132) {
  $139 = $123;$141 = $125;
 } else {
  $133 = (($inOperator) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + 20|0);
  $137 = HEAP32[$136>>2]|0;
  FUNCTION_TABLE_vi[$137 & 4095]($134);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $139 = $$pre$i$i;$141 = $$pre1$i$i;
 }
 $138 = (($139) + 8|0);
 $140 = (($141) + -1)|0;
 HEAP32[$138>>2] = $140;
 $142 = (($inStartIndex) + 2)|0;
 STACKTOP = sp;return ($142|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj662ENS_22PxRepXPropertyAccessorILj662ES4_RKNS_30PxVehicleAckermannGeometryDataES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $info$i$i$i$i$i = sp + 112|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 48|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 560;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 560)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx43PxVehicleAckermannGeometryDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx43PxVehicleAckermannGeometryDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx43PxVehicleAckermannGeometryDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx43PxVehicleAckermannGeometryDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i12 = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i16 = 0, $$phi$trans$insert$i23 = 0, $$phi$trans$insert$i30 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert40 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i19 = 0, $$pre$i$i26 = 0, $$pre$i$i3 = 0, $$pre$i$i33 = 0;
 var $$pre$i$i7 = 0, $$pre$i15 = 0, $$pre$i22 = 0, $$pre$i29 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i13 = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i17 = 0, $$pre1$i24 = 0, $$pre1$i31 = 0, $$pre35 = 0, $$pre36 = 0, $$pre38 = 0, $$pre39 = 0, $$pre41 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $theAccessor$i10 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i10 = sp + 8|0;
 HEAP8[$theAccessor$i10>>0] = 0;
 $1 = (($theAccessor$i10) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$this+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$this+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$this+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$this+12>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i15 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i16 = (($$pre$i15) + 8|0);
   $$pre1$i17 = HEAP32[$$phi$trans$insert$i16>>2]|0;
   $30 = $$pre$i15;$35 = $$pre1$i17;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i19 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i19;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEE14handleAccessorILj549ENS_22PxRepXPropertyAccessorILj549ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i10);
 $52 = HEAP32[$inOperator>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $76 = 0;$79 = $52;
 } else {
  $56 = (($54) + -1)|0;
  $57 = (($52) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58) + ($56<<3)|0) + 4|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $68 = $52;$70 = $54;
  } else {
   $62 = (($inOperator) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vi[$66 & 4095]($63);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $68 = $$pre$i$i3;$70 = $$pre1$i$i5;
  }
  $67 = (($68) + 8|0);
  $69 = (($70) + -1)|0;
  HEAP32[$67>>2] = $69;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre35 = HEAP32[$$phi$trans$insert>>2]|0;
  $76 = $$pre35;$79 = $$pre;
 }
 $71 = (($this) + 16|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $72 = (($theAccessor$i10) + 4|0);
 HEAP32[$72>>2] = 0;
 $73 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$73+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$71+12>>2]|0;
 $74 = HEAP32[$71>>2]|0;
 $75 = ($76|0)==(0);
 if ($75) {
  $100 = $79;$105 = 0;
 } else {
  $77 = (($76) + -1)|0;
  $78 = (($79) + 4|0);
  $80 = HEAP32[$78>>2]|0;
  $81 = ((($80) + ($77<<3)|0) + 4|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = ($82<<24>>24)==(0);
  if ($83) {
   $84 = (($inOperator) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 16|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($80) + ($77<<3)|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_vii[$88 & 4095]($85,$90);
   $91 = HEAP32[$inOperator>>2]|0;
   $92 = (($91) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + -1)|0;
   $95 = (($91) + 4|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ((($96) + ($94<<3)|0) + 4|0);
   HEAP8[$97>>0] = 1;
   $$pre$i22 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i23 = (($$pre$i22) + 8|0);
   $$pre1$i24 = HEAP32[$$phi$trans$insert$i23>>2]|0;
   $100 = $$pre$i22;$105 = $$pre1$i24;
  } else {
   $100 = $79;$105 = $76;
  }
 }
 HEAP32[$0>>2] = $74;
 $98 = (($0) + 4|0);
 HEAP8[$98>>0] = 0;
 $99 = (($100) + 12|0);
 $101 = HEAP32[$99>>2]|0;
 $102 = $101 & 2147483647;
 $103 = (($100) + 8|0);
 $104 = ($102>>>0)>($105>>>0);
 if ($104) {
  $106 = (($100) + 4|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($107) + ($105<<3)|0);
  $109 = ($108|0)==(0|0);
  if ($109) {
   $121 = $105;
  } else {
   $110 = $0;
   $111 = $110;
   $112 = HEAP32[$111>>2]|0;
   $113 = (($110) + 4)|0;
   $114 = $113;
   $115 = HEAP32[$114>>2]|0;
   $116 = $108;
   $117 = $116;
   HEAP32[$117>>2] = $112;
   $118 = (($116) + 4)|0;
   $119 = $118;
   HEAP32[$119>>2] = $115;
   $$pre$i$i26 = HEAP32[$103>>2]|0;
   $121 = $$pre$i$i26;
  }
  $120 = (($121) + 1)|0;
  HEAP32[$103>>2] = $120;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($100,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEE14handleAccessorILj550ENS_22PxRepXPropertyAccessorILj550ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i10);
 $122 = HEAP32[$inOperator>>2]|0;
 $123 = (($122) + 8|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($124|0)==(0);
 if ($125) {
  $146 = 0;$149 = $122;
 } else {
  $126 = (($124) + -1)|0;
  $127 = (($122) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ((($128) + ($126<<3)|0) + 4|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = ($130<<24>>24)==(0);
  if ($131) {
   $138 = $122;$140 = $124;
  } else {
   $132 = (($inOperator) + 4|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 20|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_vi[$136 & 4095]($133);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $138 = $$pre$i$i7;$140 = $$pre1$i$i9;
  }
  $137 = (($138) + 8|0);
  $139 = (($140) + -1)|0;
  HEAP32[$137>>2] = $139;
  $$pre36 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert37 = (($$pre36) + 8|0);
  $$pre38 = HEAP32[$$phi$trans$insert37>>2]|0;
  $146 = $$pre38;$149 = $$pre36;
 }
 $141 = (($this) + 32|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $142 = (($theAccessor$i10) + 4|0);
 HEAP32[$142>>2] = 0;
 $143 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$143+0>>2]=HEAP32[$141+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$141+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$141+8>>2]|0;HEAP32[$143+12>>2]=HEAP32[$141+12>>2]|0;
 $144 = HEAP32[$141>>2]|0;
 $145 = ($146|0)==(0);
 if ($145) {
  $170 = $149;$175 = 0;
 } else {
  $147 = (($146) + -1)|0;
  $148 = (($149) + 4|0);
  $150 = HEAP32[$148>>2]|0;
  $151 = ((($150) + ($147<<3)|0) + 4|0);
  $152 = HEAP8[$151>>0]|0;
  $153 = ($152<<24>>24)==(0);
  if ($153) {
   $154 = (($inOperator) + 4|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = HEAP32[$155>>2]|0;
   $157 = (($156) + 16|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($150) + ($147<<3)|0);
   $160 = HEAP32[$159>>2]|0;
   FUNCTION_TABLE_vii[$158 & 4095]($155,$160);
   $161 = HEAP32[$inOperator>>2]|0;
   $162 = (($161) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = (($163) + -1)|0;
   $165 = (($161) + 4|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ((($166) + ($164<<3)|0) + 4|0);
   HEAP8[$167>>0] = 1;
   $$pre$i29 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i30 = (($$pre$i29) + 8|0);
   $$pre1$i31 = HEAP32[$$phi$trans$insert$i30>>2]|0;
   $170 = $$pre$i29;$175 = $$pre1$i31;
  } else {
   $170 = $149;$175 = $146;
  }
 }
 HEAP32[$0>>2] = $144;
 $168 = (($0) + 4|0);
 HEAP8[$168>>0] = 0;
 $169 = (($170) + 12|0);
 $171 = HEAP32[$169>>2]|0;
 $172 = $171 & 2147483647;
 $173 = (($170) + 8|0);
 $174 = ($172>>>0)>($175>>>0);
 if ($174) {
  $176 = (($170) + 4|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($177) + ($175<<3)|0);
  $179 = ($178|0)==(0|0);
  if ($179) {
   $191 = $175;
  } else {
   $180 = $0;
   $181 = $180;
   $182 = HEAP32[$181>>2]|0;
   $183 = (($180) + 4)|0;
   $184 = $183;
   $185 = HEAP32[$184>>2]|0;
   $186 = $178;
   $187 = $186;
   HEAP32[$187>>2] = $182;
   $188 = (($186) + 4)|0;
   $189 = $188;
   HEAP32[$189>>2] = $185;
   $$pre$i$i33 = HEAP32[$173>>2]|0;
   $191 = $$pre$i$i33;
  }
  $190 = (($191) + 1)|0;
  HEAP32[$173>>2] = $190;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($170,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEE14handleAccessorILj551ENS_22PxRepXPropertyAccessorILj551ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i10);
 $192 = HEAP32[$inOperator>>2]|0;
 $193 = (($192) + 8|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194|0)==(0);
 if ($195) {
  $216 = 0;$219 = $192;
 } else {
  $196 = (($194) + -1)|0;
  $197 = (($192) + 4|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ((($198) + ($196<<3)|0) + 4|0);
  $200 = HEAP8[$199>>0]|0;
  $201 = ($200<<24>>24)==(0);
  if ($201) {
   $208 = $192;$210 = $194;
  } else {
   $202 = (($inOperator) + 4|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = HEAP32[$203>>2]|0;
   $205 = (($204) + 20|0);
   $206 = HEAP32[$205>>2]|0;
   FUNCTION_TABLE_vi[$206 & 4095]($203);
   $$pre$i$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i12 = (($$pre$i$i11) + 8|0);
   $$pre1$i$i13 = HEAP32[$$phi$trans$insert$i$i12>>2]|0;
   $208 = $$pre$i$i11;$210 = $$pre1$i$i13;
  }
  $207 = (($208) + 8|0);
  $209 = (($210) + -1)|0;
  HEAP32[$207>>2] = $209;
  $$pre39 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert40 = (($$pre39) + 8|0);
  $$pre41 = HEAP32[$$phi$trans$insert40>>2]|0;
  $216 = $$pre41;$219 = $$pre39;
 }
 $211 = (($this) + 48|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $212 = (($theAccessor$i10) + 4|0);
 HEAP32[$212>>2] = 0;
 $213 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$213+0>>2]=HEAP32[$211+0>>2]|0;HEAP32[$213+4>>2]=HEAP32[$211+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$211+8>>2]|0;HEAP32[$213+12>>2]=HEAP32[$211+12>>2]|0;
 $214 = HEAP32[$211>>2]|0;
 $215 = ($216|0)==(0);
 if ($215) {
  $240 = $219;$245 = 0;
 } else {
  $217 = (($216) + -1)|0;
  $218 = (($219) + 4|0);
  $220 = HEAP32[$218>>2]|0;
  $221 = ((($220) + ($217<<3)|0) + 4|0);
  $222 = HEAP8[$221>>0]|0;
  $223 = ($222<<24>>24)==(0);
  if ($223) {
   $224 = (($inOperator) + 4|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = HEAP32[$225>>2]|0;
   $227 = (($226) + 16|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = (($220) + ($217<<3)|0);
   $230 = HEAP32[$229>>2]|0;
   FUNCTION_TABLE_vii[$228 & 4095]($225,$230);
   $231 = HEAP32[$inOperator>>2]|0;
   $232 = (($231) + 8|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = (($233) + -1)|0;
   $235 = (($231) + 4|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ((($236) + ($234<<3)|0) + 4|0);
   HEAP8[$237>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $240 = $$pre$i;$245 = $$pre1$i;
  } else {
   $240 = $219;$245 = $216;
  }
 }
 HEAP32[$0>>2] = $214;
 $238 = (($0) + 4|0);
 HEAP8[$238>>0] = 0;
 $239 = (($240) + 12|0);
 $241 = HEAP32[$239>>2]|0;
 $242 = $241 & 2147483647;
 $243 = (($240) + 8|0);
 $244 = ($242>>>0)>($245>>>0);
 if ($244) {
  $246 = (($240) + 4|0);
  $247 = HEAP32[$246>>2]|0;
  $248 = (($247) + ($245<<3)|0);
  $249 = ($248|0)==(0|0);
  if ($249) {
   $261 = $245;
  } else {
   $250 = $0;
   $251 = $250;
   $252 = HEAP32[$251>>2]|0;
   $253 = (($250) + 4)|0;
   $254 = $253;
   $255 = HEAP32[$254>>2]|0;
   $256 = $248;
   $257 = $256;
   HEAP32[$257>>2] = $252;
   $258 = (($256) + 4)|0;
   $259 = $258;
   HEAP32[$259>>2] = $255;
   $$pre$i$i1 = HEAP32[$243>>2]|0;
   $261 = $$pre$i$i1;
  }
  $260 = (($261) + 1)|0;
  HEAP32[$243>>2] = $260;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($240,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEE14handleAccessorILj552ENS_22PxRepXPropertyAccessorILj552ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i10);
 $262 = HEAP32[$inOperator>>2]|0;
 $263 = (($262) + 8|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = ($264|0)==(0);
 if ($265) {
  $281 = (($inStartIndex) + 4)|0;
  STACKTOP = sp;return ($281|0);
 }
 $266 = (($264) + -1)|0;
 $267 = (($262) + 4|0);
 $268 = HEAP32[$267>>2]|0;
 $269 = ((($268) + ($266<<3)|0) + 4|0);
 $270 = HEAP8[$269>>0]|0;
 $271 = ($270<<24>>24)==(0);
 if ($271) {
  $278 = $262;$280 = $264;
 } else {
  $272 = (($inOperator) + 4|0);
  $273 = HEAP32[$272>>2]|0;
  $274 = HEAP32[$273>>2]|0;
  $275 = (($274) + 20|0);
  $276 = HEAP32[$275>>2]|0;
  FUNCTION_TABLE_vi[$276 & 4095]($273);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $278 = $$pre$i$i;$280 = $$pre1$i$i;
 }
 $277 = (($278) + 8|0);
 $279 = (($280) + -1)|0;
 HEAP32[$277>>2] = $279;
 $281 = (($inStartIndex) + 4)|0;
 STACKTOP = sp;return ($281|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEE14handleAccessorILj552ENS_22PxRepXPropertyAccessorILj552ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 12;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEE14handleAccessorILj551ENS_22PxRepXPropertyAccessorILj551ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEE14handleAccessorILj550ENS_22PxRepXPropertyAccessorILj550ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 4;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 4)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_30PxVehicleAckermannGeometryDataEEEE14handleAccessorILj549ENS_22PxRepXPropertyAccessorILj549ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $$0$i = $3;
 }
 HEAP8[$inAccessor>>0] = 1;
 $4 = (($inAccessor) + 4|0);
 HEAP32[$4>>2] = $$0$i;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$6>>2] = $9;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($inAccessor) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (Math_fround(FUNCTION_TABLE_fi[$13 & 255]($11)));
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i = 521512;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i = $27;
 }
 $28 = +$14;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$18>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($18,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$18>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($18,$vararg_buffer,1)|0);
 $36 = HEAP32[$16>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($18) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($16,$$0$i$i$i$i,$40);
 $41 = (($18) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($18) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj661ENS_22PxRepXPropertyAccessorILj661ES4_RKNS_27PxVehicleDifferential4WDataES9_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $info$i$i$i$i$i = sp + 176|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 64|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 528;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 528)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx40PxVehicleDifferential4WDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx40PxVehicleDifferential4WDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx40PxVehicleDifferential4WDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx40PxVehicleDifferential4WDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$0$i$i$i$i$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i11 = 0, $$phi$trans$insert$i$i15 = 0, $$phi$trans$insert$i$i19 = 0, $$phi$trans$insert$i$i23 = 0, $$phi$trans$insert$i$i3 = 0, $$phi$trans$insert$i$i7 = 0, $$phi$trans$insert$i28 = 0, $$phi$trans$insert$i35 = 0, $$phi$trans$insert$i42 = 0, $$phi$trans$insert$i49 = 0, $$phi$trans$insert$i56 = 0, $$phi$trans$insert$i63 = 0, $$phi$trans$insert70 = 0, $$phi$trans$insert73 = 0, $$phi$trans$insert76 = 0, $$phi$trans$insert79 = 0;
 var $$phi$trans$insert82 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i10 = 0, $$pre$i$i14 = 0, $$pre$i$i18 = 0, $$pre$i$i2 = 0, $$pre$i$i22 = 0, $$pre$i$i25 = 0, $$pre$i$i31 = 0, $$pre$i$i38 = 0, $$pre$i$i45 = 0, $$pre$i$i52 = 0, $$pre$i$i59 = 0, $$pre$i$i6 = 0, $$pre$i$i66 = 0, $$pre$i27 = 0, $$pre$i34 = 0, $$pre$i41 = 0;
 var $$pre$i48 = 0, $$pre$i55 = 0, $$pre$i62 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i12 = 0, $$pre1$i$i16 = 0, $$pre1$i$i20 = 0, $$pre1$i$i24 = 0, $$pre1$i$i4 = 0, $$pre1$i$i8 = 0, $$pre1$i29 = 0, $$pre1$i36 = 0, $$pre1$i43 = 0, $$pre1$i50 = 0, $$pre1$i57 = 0, $$pre1$i64 = 0, $$pre68 = 0, $$pre69 = 0, $$pre71 = 0;
 var $$pre72 = 0, $$pre74 = 0, $$pre75 = 0, $$pre77 = 0, $$pre78 = 0, $$pre80 = 0, $$pre81 = 0, $$pre83 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $conv$01$i$i$i$i$i = 0, $theAccessor$i21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i21 = sp + 8|0;
 HEAP8[$theAccessor$i21>>0] = 0;
 $1 = (($theAccessor$i21) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor$i21) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$this+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$this+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$this+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$this+12>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i27 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i28 = (($$pre$i27) + 8|0);
   $$pre1$i29 = HEAP32[$$phi$trans$insert$i28>>2]|0;
   $30 = $$pre$i27;$35 = $$pre1$i29;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i31 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i31;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj537ENS_22PxRepXPropertyAccessorILj537ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i21);
 $52 = HEAP32[$inOperator>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $76 = 0;$79 = $52;
 } else {
  $56 = (($54) + -1)|0;
  $57 = (($52) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58) + ($56<<3)|0) + 4|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $68 = $52;$70 = $54;
  } else {
   $62 = (($inOperator) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vi[$66 & 4095]($63);
   $$pre$i$i2 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i3 = (($$pre$i$i2) + 8|0);
   $$pre1$i$i4 = HEAP32[$$phi$trans$insert$i$i3>>2]|0;
   $68 = $$pre$i$i2;$70 = $$pre1$i$i4;
  }
  $67 = (($68) + 8|0);
  $69 = (($70) + -1)|0;
  HEAP32[$67>>2] = $69;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre68 = HEAP32[$$phi$trans$insert>>2]|0;
  $76 = $$pre68;$79 = $$pre;
 }
 $71 = (($this) + 16|0);
 HEAP8[$theAccessor$i21>>0] = 0;
 $72 = (($theAccessor$i21) + 4|0);
 HEAP32[$72>>2] = 0;
 $73 = (($theAccessor$i21) + 8|0);
 ;HEAP32[$73+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$71+12>>2]|0;
 $74 = HEAP32[$71>>2]|0;
 $75 = ($76|0)==(0);
 if ($75) {
  $100 = $79;$105 = 0;
 } else {
  $77 = (($76) + -1)|0;
  $78 = (($79) + 4|0);
  $80 = HEAP32[$78>>2]|0;
  $81 = ((($80) + ($77<<3)|0) + 4|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = ($82<<24>>24)==(0);
  if ($83) {
   $84 = (($inOperator) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 16|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($80) + ($77<<3)|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_vii[$88 & 4095]($85,$90);
   $91 = HEAP32[$inOperator>>2]|0;
   $92 = (($91) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + -1)|0;
   $95 = (($91) + 4|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ((($96) + ($94<<3)|0) + 4|0);
   HEAP8[$97>>0] = 1;
   $$pre$i34 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i35 = (($$pre$i34) + 8|0);
   $$pre1$i36 = HEAP32[$$phi$trans$insert$i35>>2]|0;
   $100 = $$pre$i34;$105 = $$pre1$i36;
  } else {
   $100 = $79;$105 = $76;
  }
 }
 HEAP32[$0>>2] = $74;
 $98 = (($0) + 4|0);
 HEAP8[$98>>0] = 0;
 $99 = (($100) + 12|0);
 $101 = HEAP32[$99>>2]|0;
 $102 = $101 & 2147483647;
 $103 = (($100) + 8|0);
 $104 = ($102>>>0)>($105>>>0);
 if ($104) {
  $106 = (($100) + 4|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($107) + ($105<<3)|0);
  $109 = ($108|0)==(0|0);
  if ($109) {
   $121 = $105;
  } else {
   $110 = $0;
   $111 = $110;
   $112 = HEAP32[$111>>2]|0;
   $113 = (($110) + 4)|0;
   $114 = $113;
   $115 = HEAP32[$114>>2]|0;
   $116 = $108;
   $117 = $116;
   HEAP32[$117>>2] = $112;
   $118 = (($116) + 4)|0;
   $119 = $118;
   HEAP32[$119>>2] = $115;
   $$pre$i$i38 = HEAP32[$103>>2]|0;
   $121 = $$pre$i$i38;
  }
  $120 = (($121) + 1)|0;
  HEAP32[$103>>2] = $120;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($100,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj538ENS_22PxRepXPropertyAccessorILj538ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i21);
 $122 = HEAP32[$inOperator>>2]|0;
 $123 = (($122) + 8|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($124|0)==(0);
 if ($125) {
  $146 = 0;$149 = $122;
 } else {
  $126 = (($124) + -1)|0;
  $127 = (($122) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ((($128) + ($126<<3)|0) + 4|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = ($130<<24>>24)==(0);
  if ($131) {
   $138 = $122;$140 = $124;
  } else {
   $132 = (($inOperator) + 4|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 20|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_vi[$136 & 4095]($133);
   $$pre$i$i6 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i7 = (($$pre$i$i6) + 8|0);
   $$pre1$i$i8 = HEAP32[$$phi$trans$insert$i$i7>>2]|0;
   $138 = $$pre$i$i6;$140 = $$pre1$i$i8;
  }
  $137 = (($138) + 8|0);
  $139 = (($140) + -1)|0;
  HEAP32[$137>>2] = $139;
  $$pre69 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert70 = (($$pre69) + 8|0);
  $$pre71 = HEAP32[$$phi$trans$insert70>>2]|0;
  $146 = $$pre71;$149 = $$pre69;
 }
 $141 = (($this) + 32|0);
 HEAP8[$theAccessor$i21>>0] = 0;
 $142 = (($theAccessor$i21) + 4|0);
 HEAP32[$142>>2] = 0;
 $143 = (($theAccessor$i21) + 8|0);
 ;HEAP32[$143+0>>2]=HEAP32[$141+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$141+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$141+8>>2]|0;HEAP32[$143+12>>2]=HEAP32[$141+12>>2]|0;
 $144 = HEAP32[$141>>2]|0;
 $145 = ($146|0)==(0);
 if ($145) {
  $170 = $149;$175 = 0;
 } else {
  $147 = (($146) + -1)|0;
  $148 = (($149) + 4|0);
  $150 = HEAP32[$148>>2]|0;
  $151 = ((($150) + ($147<<3)|0) + 4|0);
  $152 = HEAP8[$151>>0]|0;
  $153 = ($152<<24>>24)==(0);
  if ($153) {
   $154 = (($inOperator) + 4|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = HEAP32[$155>>2]|0;
   $157 = (($156) + 16|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($150) + ($147<<3)|0);
   $160 = HEAP32[$159>>2]|0;
   FUNCTION_TABLE_vii[$158 & 4095]($155,$160);
   $161 = HEAP32[$inOperator>>2]|0;
   $162 = (($161) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = (($163) + -1)|0;
   $165 = (($161) + 4|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ((($166) + ($164<<3)|0) + 4|0);
   HEAP8[$167>>0] = 1;
   $$pre$i41 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i42 = (($$pre$i41) + 8|0);
   $$pre1$i43 = HEAP32[$$phi$trans$insert$i42>>2]|0;
   $170 = $$pre$i41;$175 = $$pre1$i43;
  } else {
   $170 = $149;$175 = $146;
  }
 }
 HEAP32[$0>>2] = $144;
 $168 = (($0) + 4|0);
 HEAP8[$168>>0] = 0;
 $169 = (($170) + 12|0);
 $171 = HEAP32[$169>>2]|0;
 $172 = $171 & 2147483647;
 $173 = (($170) + 8|0);
 $174 = ($172>>>0)>($175>>>0);
 if ($174) {
  $176 = (($170) + 4|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($177) + ($175<<3)|0);
  $179 = ($178|0)==(0|0);
  if ($179) {
   $191 = $175;
  } else {
   $180 = $0;
   $181 = $180;
   $182 = HEAP32[$181>>2]|0;
   $183 = (($180) + 4)|0;
   $184 = $183;
   $185 = HEAP32[$184>>2]|0;
   $186 = $178;
   $187 = $186;
   HEAP32[$187>>2] = $182;
   $188 = (($186) + 4)|0;
   $189 = $188;
   HEAP32[$189>>2] = $185;
   $$pre$i$i45 = HEAP32[$173>>2]|0;
   $191 = $$pre$i$i45;
  }
  $190 = (($191) + 1)|0;
  HEAP32[$173>>2] = $190;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($170,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj539ENS_22PxRepXPropertyAccessorILj539ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i21);
 $192 = HEAP32[$inOperator>>2]|0;
 $193 = (($192) + 8|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194|0)==(0);
 if ($195) {
  $216 = 0;$219 = $192;
 } else {
  $196 = (($194) + -1)|0;
  $197 = (($192) + 4|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ((($198) + ($196<<3)|0) + 4|0);
  $200 = HEAP8[$199>>0]|0;
  $201 = ($200<<24>>24)==(0);
  if ($201) {
   $208 = $192;$210 = $194;
  } else {
   $202 = (($inOperator) + 4|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = HEAP32[$203>>2]|0;
   $205 = (($204) + 20|0);
   $206 = HEAP32[$205>>2]|0;
   FUNCTION_TABLE_vi[$206 & 4095]($203);
   $$pre$i$i10 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i11 = (($$pre$i$i10) + 8|0);
   $$pre1$i$i12 = HEAP32[$$phi$trans$insert$i$i11>>2]|0;
   $208 = $$pre$i$i10;$210 = $$pre1$i$i12;
  }
  $207 = (($208) + 8|0);
  $209 = (($210) + -1)|0;
  HEAP32[$207>>2] = $209;
  $$pre72 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert73 = (($$pre72) + 8|0);
  $$pre74 = HEAP32[$$phi$trans$insert73>>2]|0;
  $216 = $$pre74;$219 = $$pre72;
 }
 $211 = (($this) + 48|0);
 HEAP8[$theAccessor$i21>>0] = 0;
 $212 = (($theAccessor$i21) + 4|0);
 HEAP32[$212>>2] = 0;
 $213 = (($theAccessor$i21) + 8|0);
 ;HEAP32[$213+0>>2]=HEAP32[$211+0>>2]|0;HEAP32[$213+4>>2]=HEAP32[$211+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$211+8>>2]|0;HEAP32[$213+12>>2]=HEAP32[$211+12>>2]|0;
 $214 = HEAP32[$211>>2]|0;
 $215 = ($216|0)==(0);
 if ($215) {
  $240 = $219;$245 = 0;
 } else {
  $217 = (($216) + -1)|0;
  $218 = (($219) + 4|0);
  $220 = HEAP32[$218>>2]|0;
  $221 = ((($220) + ($217<<3)|0) + 4|0);
  $222 = HEAP8[$221>>0]|0;
  $223 = ($222<<24>>24)==(0);
  if ($223) {
   $224 = (($inOperator) + 4|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = HEAP32[$225>>2]|0;
   $227 = (($226) + 16|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = (($220) + ($217<<3)|0);
   $230 = HEAP32[$229>>2]|0;
   FUNCTION_TABLE_vii[$228 & 4095]($225,$230);
   $231 = HEAP32[$inOperator>>2]|0;
   $232 = (($231) + 8|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = (($233) + -1)|0;
   $235 = (($231) + 4|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ((($236) + ($234<<3)|0) + 4|0);
   HEAP8[$237>>0] = 1;
   $$pre$i48 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i49 = (($$pre$i48) + 8|0);
   $$pre1$i50 = HEAP32[$$phi$trans$insert$i49>>2]|0;
   $240 = $$pre$i48;$245 = $$pre1$i50;
  } else {
   $240 = $219;$245 = $216;
  }
 }
 HEAP32[$0>>2] = $214;
 $238 = (($0) + 4|0);
 HEAP8[$238>>0] = 0;
 $239 = (($240) + 12|0);
 $241 = HEAP32[$239>>2]|0;
 $242 = $241 & 2147483647;
 $243 = (($240) + 8|0);
 $244 = ($242>>>0)>($245>>>0);
 if ($244) {
  $246 = (($240) + 4|0);
  $247 = HEAP32[$246>>2]|0;
  $248 = (($247) + ($245<<3)|0);
  $249 = ($248|0)==(0|0);
  if ($249) {
   $261 = $245;
  } else {
   $250 = $0;
   $251 = $250;
   $252 = HEAP32[$251>>2]|0;
   $253 = (($250) + 4)|0;
   $254 = $253;
   $255 = HEAP32[$254>>2]|0;
   $256 = $248;
   $257 = $256;
   HEAP32[$257>>2] = $252;
   $258 = (($256) + 4)|0;
   $259 = $258;
   HEAP32[$259>>2] = $255;
   $$pre$i$i52 = HEAP32[$243>>2]|0;
   $261 = $$pre$i$i52;
  }
  $260 = (($261) + 1)|0;
  HEAP32[$243>>2] = $260;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($240,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj540ENS_22PxRepXPropertyAccessorILj540ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i21);
 $262 = HEAP32[$inOperator>>2]|0;
 $263 = (($262) + 8|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = ($264|0)==(0);
 if ($265) {
  $286 = 0;$289 = $262;
 } else {
  $266 = (($264) + -1)|0;
  $267 = (($262) + 4|0);
  $268 = HEAP32[$267>>2]|0;
  $269 = ((($268) + ($266<<3)|0) + 4|0);
  $270 = HEAP8[$269>>0]|0;
  $271 = ($270<<24>>24)==(0);
  if ($271) {
   $278 = $262;$280 = $264;
  } else {
   $272 = (($inOperator) + 4|0);
   $273 = HEAP32[$272>>2]|0;
   $274 = HEAP32[$273>>2]|0;
   $275 = (($274) + 20|0);
   $276 = HEAP32[$275>>2]|0;
   FUNCTION_TABLE_vi[$276 & 4095]($273);
   $$pre$i$i14 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i15 = (($$pre$i$i14) + 8|0);
   $$pre1$i$i16 = HEAP32[$$phi$trans$insert$i$i15>>2]|0;
   $278 = $$pre$i$i14;$280 = $$pre1$i$i16;
  }
  $277 = (($278) + 8|0);
  $279 = (($280) + -1)|0;
  HEAP32[$277>>2] = $279;
  $$pre75 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert76 = (($$pre75) + 8|0);
  $$pre77 = HEAP32[$$phi$trans$insert76>>2]|0;
  $286 = $$pre77;$289 = $$pre75;
 }
 $281 = (($this) + 64|0);
 HEAP8[$theAccessor$i21>>0] = 0;
 $282 = (($theAccessor$i21) + 4|0);
 HEAP32[$282>>2] = 0;
 $283 = (($theAccessor$i21) + 8|0);
 ;HEAP32[$283+0>>2]=HEAP32[$281+0>>2]|0;HEAP32[$283+4>>2]=HEAP32[$281+4>>2]|0;HEAP32[$283+8>>2]=HEAP32[$281+8>>2]|0;HEAP32[$283+12>>2]=HEAP32[$281+12>>2]|0;
 $284 = HEAP32[$281>>2]|0;
 $285 = ($286|0)==(0);
 if ($285) {
  $310 = $289;$315 = 0;
 } else {
  $287 = (($286) + -1)|0;
  $288 = (($289) + 4|0);
  $290 = HEAP32[$288>>2]|0;
  $291 = ((($290) + ($287<<3)|0) + 4|0);
  $292 = HEAP8[$291>>0]|0;
  $293 = ($292<<24>>24)==(0);
  if ($293) {
   $294 = (($inOperator) + 4|0);
   $295 = HEAP32[$294>>2]|0;
   $296 = HEAP32[$295>>2]|0;
   $297 = (($296) + 16|0);
   $298 = HEAP32[$297>>2]|0;
   $299 = (($290) + ($287<<3)|0);
   $300 = HEAP32[$299>>2]|0;
   FUNCTION_TABLE_vii[$298 & 4095]($295,$300);
   $301 = HEAP32[$inOperator>>2]|0;
   $302 = (($301) + 8|0);
   $303 = HEAP32[$302>>2]|0;
   $304 = (($303) + -1)|0;
   $305 = (($301) + 4|0);
   $306 = HEAP32[$305>>2]|0;
   $307 = ((($306) + ($304<<3)|0) + 4|0);
   HEAP8[$307>>0] = 1;
   $$pre$i55 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i56 = (($$pre$i55) + 8|0);
   $$pre1$i57 = HEAP32[$$phi$trans$insert$i56>>2]|0;
   $310 = $$pre$i55;$315 = $$pre1$i57;
  } else {
   $310 = $289;$315 = $286;
  }
 }
 HEAP32[$0>>2] = $284;
 $308 = (($0) + 4|0);
 HEAP8[$308>>0] = 0;
 $309 = (($310) + 12|0);
 $311 = HEAP32[$309>>2]|0;
 $312 = $311 & 2147483647;
 $313 = (($310) + 8|0);
 $314 = ($312>>>0)>($315>>>0);
 if ($314) {
  $316 = (($310) + 4|0);
  $317 = HEAP32[$316>>2]|0;
  $318 = (($317) + ($315<<3)|0);
  $319 = ($318|0)==(0|0);
  if ($319) {
   $331 = $315;
  } else {
   $320 = $0;
   $321 = $320;
   $322 = HEAP32[$321>>2]|0;
   $323 = (($320) + 4)|0;
   $324 = $323;
   $325 = HEAP32[$324>>2]|0;
   $326 = $318;
   $327 = $326;
   HEAP32[$327>>2] = $322;
   $328 = (($326) + 4)|0;
   $329 = $328;
   HEAP32[$329>>2] = $325;
   $$pre$i$i59 = HEAP32[$313>>2]|0;
   $331 = $$pre$i$i59;
  }
  $330 = (($331) + 1)|0;
  HEAP32[$313>>2] = $330;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($310,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj541ENS_22PxRepXPropertyAccessorILj541ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i21);
 $332 = HEAP32[$inOperator>>2]|0;
 $333 = (($332) + 8|0);
 $334 = HEAP32[$333>>2]|0;
 $335 = ($334|0)==(0);
 if ($335) {
  $356 = 0;$359 = $332;
 } else {
  $336 = (($334) + -1)|0;
  $337 = (($332) + 4|0);
  $338 = HEAP32[$337>>2]|0;
  $339 = ((($338) + ($336<<3)|0) + 4|0);
  $340 = HEAP8[$339>>0]|0;
  $341 = ($340<<24>>24)==(0);
  if ($341) {
   $348 = $332;$350 = $334;
  } else {
   $342 = (($inOperator) + 4|0);
   $343 = HEAP32[$342>>2]|0;
   $344 = HEAP32[$343>>2]|0;
   $345 = (($344) + 20|0);
   $346 = HEAP32[$345>>2]|0;
   FUNCTION_TABLE_vi[$346 & 4095]($343);
   $$pre$i$i18 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i19 = (($$pre$i$i18) + 8|0);
   $$pre1$i$i20 = HEAP32[$$phi$trans$insert$i$i19>>2]|0;
   $348 = $$pre$i$i18;$350 = $$pre1$i$i20;
  }
  $347 = (($348) + 8|0);
  $349 = (($350) + -1)|0;
  HEAP32[$347>>2] = $349;
  $$pre78 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert79 = (($$pre78) + 8|0);
  $$pre80 = HEAP32[$$phi$trans$insert79>>2]|0;
  $356 = $$pre80;$359 = $$pre78;
 }
 $351 = (($this) + 80|0);
 HEAP8[$theAccessor$i21>>0] = 0;
 $352 = (($theAccessor$i21) + 4|0);
 HEAP32[$352>>2] = 0;
 $353 = (($theAccessor$i21) + 8|0);
 ;HEAP32[$353+0>>2]=HEAP32[$351+0>>2]|0;HEAP32[$353+4>>2]=HEAP32[$351+4>>2]|0;HEAP32[$353+8>>2]=HEAP32[$351+8>>2]|0;HEAP32[$353+12>>2]=HEAP32[$351+12>>2]|0;
 $354 = HEAP32[$351>>2]|0;
 $355 = ($356|0)==(0);
 if ($355) {
  $380 = $359;$385 = 0;
 } else {
  $357 = (($356) + -1)|0;
  $358 = (($359) + 4|0);
  $360 = HEAP32[$358>>2]|0;
  $361 = ((($360) + ($357<<3)|0) + 4|0);
  $362 = HEAP8[$361>>0]|0;
  $363 = ($362<<24>>24)==(0);
  if ($363) {
   $364 = (($inOperator) + 4|0);
   $365 = HEAP32[$364>>2]|0;
   $366 = HEAP32[$365>>2]|0;
   $367 = (($366) + 16|0);
   $368 = HEAP32[$367>>2]|0;
   $369 = (($360) + ($357<<3)|0);
   $370 = HEAP32[$369>>2]|0;
   FUNCTION_TABLE_vii[$368 & 4095]($365,$370);
   $371 = HEAP32[$inOperator>>2]|0;
   $372 = (($371) + 8|0);
   $373 = HEAP32[$372>>2]|0;
   $374 = (($373) + -1)|0;
   $375 = (($371) + 4|0);
   $376 = HEAP32[$375>>2]|0;
   $377 = ((($376) + ($374<<3)|0) + 4|0);
   HEAP8[$377>>0] = 1;
   $$pre$i62 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i63 = (($$pre$i62) + 8|0);
   $$pre1$i64 = HEAP32[$$phi$trans$insert$i63>>2]|0;
   $380 = $$pre$i62;$385 = $$pre1$i64;
  } else {
   $380 = $359;$385 = $356;
  }
 }
 HEAP32[$0>>2] = $354;
 $378 = (($0) + 4|0);
 HEAP8[$378>>0] = 0;
 $379 = (($380) + 12|0);
 $381 = HEAP32[$379>>2]|0;
 $382 = $381 & 2147483647;
 $383 = (($380) + 8|0);
 $384 = ($382>>>0)>($385>>>0);
 if ($384) {
  $386 = (($380) + 4|0);
  $387 = HEAP32[$386>>2]|0;
  $388 = (($387) + ($385<<3)|0);
  $389 = ($388|0)==(0|0);
  if ($389) {
   $401 = $385;
  } else {
   $390 = $0;
   $391 = $390;
   $392 = HEAP32[$391>>2]|0;
   $393 = (($390) + 4)|0;
   $394 = $393;
   $395 = HEAP32[$394>>2]|0;
   $396 = $388;
   $397 = $396;
   HEAP32[$397>>2] = $392;
   $398 = (($396) + 4)|0;
   $399 = $398;
   HEAP32[$399>>2] = $395;
   $$pre$i$i66 = HEAP32[$383>>2]|0;
   $401 = $$pre$i$i66;
  }
  $400 = (($401) + 1)|0;
  HEAP32[$383>>2] = $400;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($380,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj542ENS_22PxRepXPropertyAccessorILj542ES4_ffEEEEvRKT0_($inOperator,$theAccessor$i21);
 $402 = HEAP32[$inOperator>>2]|0;
 $403 = (($402) + 8|0);
 $404 = HEAP32[$403>>2]|0;
 $405 = ($404|0)==(0);
 if ($405) {
  $426 = 0;$429 = $402;
 } else {
  $406 = (($404) + -1)|0;
  $407 = (($402) + 4|0);
  $408 = HEAP32[$407>>2]|0;
  $409 = ((($408) + ($406<<3)|0) + 4|0);
  $410 = HEAP8[$409>>0]|0;
  $411 = ($410<<24>>24)==(0);
  if ($411) {
   $418 = $402;$420 = $404;
  } else {
   $412 = (($inOperator) + 4|0);
   $413 = HEAP32[$412>>2]|0;
   $414 = HEAP32[$413>>2]|0;
   $415 = (($414) + 20|0);
   $416 = HEAP32[$415>>2]|0;
   FUNCTION_TABLE_vi[$416 & 4095]($413);
   $$pre$i$i22 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i23 = (($$pre$i$i22) + 8|0);
   $$pre1$i$i24 = HEAP32[$$phi$trans$insert$i$i23>>2]|0;
   $418 = $$pre$i$i22;$420 = $$pre1$i$i24;
  }
  $417 = (($418) + 8|0);
  $419 = (($420) + -1)|0;
  HEAP32[$417>>2] = $419;
  $$pre81 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert82 = (($$pre81) + 8|0);
  $$pre83 = HEAP32[$$phi$trans$insert82>>2]|0;
  $426 = $$pre83;$429 = $$pre81;
 }
 $421 = (($this) + 104|0);
 $422 = HEAP32[$421>>2]|0;
 $423 = (($this) + 96|0);
 $424 = HEAP32[$423>>2]|0;
 $425 = ($426|0)==(0);
 do {
  if ($425) {
   $450 = $429;$455 = 0;
  } else {
   $427 = (($426) + -1)|0;
   $428 = (($429) + 4|0);
   $430 = HEAP32[$428>>2]|0;
   $431 = ((($430) + ($427<<3)|0) + 4|0);
   $432 = HEAP8[$431>>0]|0;
   $433 = ($432<<24>>24)==(0);
   if (!($433)) {
    $450 = $429;$455 = $426;
    break;
   }
   $434 = (($inOperator) + 4|0);
   $435 = HEAP32[$434>>2]|0;
   $436 = HEAP32[$435>>2]|0;
   $437 = (($436) + 16|0);
   $438 = HEAP32[$437>>2]|0;
   $439 = (($430) + ($427<<3)|0);
   $440 = HEAP32[$439>>2]|0;
   FUNCTION_TABLE_vii[$438 & 4095]($435,$440);
   $441 = HEAP32[$inOperator>>2]|0;
   $442 = (($441) + 8|0);
   $443 = HEAP32[$442>>2]|0;
   $444 = (($443) + -1)|0;
   $445 = (($441) + 4|0);
   $446 = HEAP32[$445>>2]|0;
   $447 = ((($446) + ($444<<3)|0) + 4|0);
   HEAP8[$447>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $450 = $$pre$i;$455 = $$pre1$i;
  }
 } while(0);
 HEAP32[$0>>2] = $424;
 $448 = (($0) + 4|0);
 HEAP8[$448>>0] = 0;
 $449 = (($450) + 12|0);
 $451 = HEAP32[$449>>2]|0;
 $452 = $451 & 2147483647;
 $453 = (($450) + 8|0);
 $454 = ($452>>>0)>($455>>>0);
 if ($454) {
  $456 = (($450) + 4|0);
  $457 = HEAP32[$456>>2]|0;
  $458 = (($457) + ($455<<3)|0);
  $459 = ($458|0)==(0|0);
  if ($459) {
   $471 = $455;
  } else {
   $460 = $0;
   $461 = $460;
   $462 = HEAP32[$461>>2]|0;
   $463 = (($460) + 4)|0;
   $464 = $463;
   $465 = HEAP32[$464>>2]|0;
   $466 = $458;
   $467 = $466;
   HEAP32[$467>>2] = $462;
   $468 = (($466) + 4)|0;
   $469 = $468;
   HEAP32[$469>>2] = $465;
   $$pre$i$i25 = HEAP32[$453>>2]|0;
   $471 = $$pre$i$i25;
  }
  $470 = (($471) + 1)|0;
  HEAP32[$453>>2] = $470;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($450,$0)|0);
 }
 $472 = (($inOperator) + 20|0);
 $473 = HEAP32[$472>>2]|0;
 $474 = ($473|0)==(0|0);
 if (!($474)) {
  $475 = HEAP32[$473>>2]|0;
  $476 = (($475) + 1)|0;
  HEAP32[$473>>2] = $476;
 }
 $477 = (($inOperator) + 4|0);
 $478 = HEAP32[$477>>2]|0;
 $479 = HEAP32[$inOperator>>2]|0;
 $480 = (($479) + 8|0);
 $481 = HEAP32[$480>>2]|0;
 $482 = ($481|0)==(0);
 if ($482) {
  $$0$i$i$i$i$i = 521512;
 } else {
  $483 = (($481) + -1)|0;
  $484 = (($479) + 4|0);
  $485 = HEAP32[$484>>2]|0;
  $486 = (($485) + ($483<<3)|0);
  $487 = HEAP32[$486>>2]|0;
  $$0$i$i$i$i$i = $487;
 }
 $488 = (($inOperator) + 8|0);
 $489 = HEAP32[$488>>2]|0;
 $490 = (FUNCTION_TABLE_ii[$422 & 4095]($489)|0);
 $491 = (523352|0)==(0|0);
 if (!($491)) {
  $498 = 523352;$conv$01$i$i$i$i$i = 523288;
  while(1) {
   $492 = (($conv$01$i$i$i$i$i) + 4|0);
   $493 = HEAP32[$492>>2]|0;
   $494 = ($493|0)==($490|0);
   if ($494) {
    $495 = HEAP32[$478>>2]|0;
    $496 = (($495) + 8|0);
    $497 = HEAP32[$496>>2]|0;
    FUNCTION_TABLE_viii[$497 & 4095]($478,$$0$i$i$i$i$i,$498);
   }
   $499 = (($conv$01$i$i$i$i$i) + 8|0);
   $500 = HEAP32[$499>>2]|0;
   $501 = ($500|0)==(0|0);
   if ($501) {
    break;
   } else {
    $498 = $500;$conv$01$i$i$i$i$i = $499;
   }
  }
 }
 $502 = HEAP32[$inOperator>>2]|0;
 $503 = (($502) + 8|0);
 $504 = HEAP32[$503>>2]|0;
 $505 = ($504|0)==(0);
 if ($505) {
  $520 = (($inStartIndex) + 7)|0;
  STACKTOP = sp;return ($520|0);
 }
 $506 = (($504) + -1)|0;
 $507 = (($502) + 4|0);
 $508 = HEAP32[$507>>2]|0;
 $509 = ((($508) + ($506<<3)|0) + 4|0);
 $510 = HEAP8[$509>>0]|0;
 $511 = ($510<<24>>24)==(0);
 if ($511) {
  $517 = $502;$519 = $504;
 } else {
  $512 = HEAP32[$477>>2]|0;
  $513 = HEAP32[$512>>2]|0;
  $514 = (($513) + 20|0);
  $515 = HEAP32[$514>>2]|0;
  FUNCTION_TABLE_vi[$515 & 4095]($512);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $517 = $$pre$i$i;$519 = $$pre1$i$i;
 }
 $516 = (($517) + 8|0);
 $518 = (($519) + -1)|0;
 HEAP32[$516>>2] = $518;
 $520 = (($inStartIndex) + 7)|0;
 STACKTOP = sp;return ($520|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj542ENS_22PxRepXPropertyAccessorILj542ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 20;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 20)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj541ENS_22PxRepXPropertyAccessorILj541ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 16;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 16)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj540ENS_22PxRepXPropertyAccessorILj540ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 12;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 12)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj539ENS_22PxRepXPropertyAccessorILj539ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 8;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 8)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj538ENS_22PxRepXPropertyAccessorILj538ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 4;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 4)|0;
  $$0$i = $4;
 }
 HEAP8[$inAccessor>>0] = 1;
 $5 = (($inAccessor) + 4|0);
 HEAP32[$5>>2] = $$0$i;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 1)|0;
  HEAP32[$7>>2] = $10;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($inAccessor) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($12)));
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i$i$i = 521512;
 } else {
  $24 = (($22) + -1)|0;
  $25 = (($20) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($24<<3)|0);
  $28 = HEAP32[$27>>2]|0;
  $$0$i$i$i$i = $28;
 }
 $29 = +$15;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$29;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $30 = HEAP8[$buffer$i$i$i>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = HEAP32[$19>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$33 & 2047]($19,$buffer$i$i$i,$34)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $35 = HEAP32[$19>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($19,$vararg_buffer,1)|0);
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($19) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($17,$$0$i$i$i$i,$41);
 $42 = (($19) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($19) + 12|0);
 HEAP32[$43>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_27PxVehicleDifferential4WDataEEEE14handleAccessorILj537ENS_22PxRepXPropertyAccessorILj537ES4_ffEEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer = sp;
 $buffer$i$i$i = sp + 8|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $$0$i = $3;
 }
 HEAP8[$inAccessor>>0] = 1;
 $4 = (($inAccessor) + 4|0);
 HEAP32[$4>>2] = $$0$i;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$6>>2] = $9;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($inAccessor) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (Math_fround(FUNCTION_TABLE_fi[$13 & 255]($11)));
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $$0$i$i$i$i = 521512;
 } else {
  $23 = (($21) + -1)|0;
  $24 = (($19) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($23<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $$0$i$i$i$i = $27;
 }
 $28 = +$14;
 dest=$buffer$i$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_buffer>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer+4>>2]=HEAP32[tempDoublePtr+4>>2];
 (__ZN5physx6string9sprintf_sEPcjPKcz($buffer$i$i$i,0,521528,$vararg_buffer)|0);
 $29 = HEAP8[$buffer$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP32[$18>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_strlen(($buffer$i$i$i|0))|0);
  (FUNCTION_TABLE_iiii[$32 & 2047]($18,$buffer$i$i$i,$33)|0);
 }
 HEAP8[$vararg_buffer>>0] = 0;
 $34 = HEAP32[$18>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 (FUNCTION_TABLE_iiii[$35 & 2047]($18,$vararg_buffer,1)|0);
 $36 = HEAP32[$16>>2]|0;
 $37 = (($36) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($18) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_viii[$38 & 4095]($16,$$0$i$i$i$i,$40);
 $41 = (($18) + 16|0);
 HEAP32[$41>>2] = 0;
 $42 = (($18) + 12|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx34PxVehicleDriveSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i12 = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i$i8 = 0, $$phi$trans$insert$i16 = 0, $$phi$trans$insert$i23 = 0, $$phi$trans$insert$i30 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert40 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i19 = 0, $$pre$i$i26 = 0, $$pre$i$i3 = 0, $$pre$i$i33 = 0;
 var $$pre$i$i7 = 0, $$pre$i15 = 0, $$pre$i22 = 0, $$pre$i29 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i13 = 0, $$pre1$i$i5 = 0, $$pre1$i$i9 = 0, $$pre1$i17 = 0, $$pre1$i24 = 0, $$pre1$i31 = 0, $$pre35 = 0, $$pre36 = 0, $$pre38 = 0, $$pre39 = 0, $$pre41 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $theAccessor$i10 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i10 = sp + 8|0;
 HEAP8[$theAccessor$i10>>0] = 0;
 $1 = (($theAccessor$i10) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$2+0>>2]=HEAP32[$this+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$this+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$this+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$this+12>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$inOperator>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = $4;$35 = 0;
 } else {
  $8 = (($6) + -1)|0;
  $9 = (($4) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($8<<3)|0) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $14 = (($inOperator) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($10) + ($8<<3)|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$18 & 4095]($15,$20);
   $21 = HEAP32[$inOperator>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   $25 = (($21) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($26) + ($24<<3)|0) + 4|0);
   HEAP8[$27>>0] = 1;
   $$pre$i15 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i16 = (($$pre$i15) + 8|0);
   $$pre1$i17 = HEAP32[$$phi$trans$insert$i16>>2]|0;
   $30 = $$pre$i15;$35 = $$pre1$i17;
  } else {
   $30 = $4;$35 = $6;
  }
 }
 HEAP32[$0>>2] = $3;
 $28 = (($0) + 4|0);
 HEAP8[$28>>0] = 0;
 $29 = (($30) + 12|0);
 $31 = HEAP32[$29>>2]|0;
 $32 = $31 & 2147483647;
 $33 = (($30) + 8|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  $36 = (($30) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + ($35<<3)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   $51 = $35;
  } else {
   $40 = $0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $38;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $$pre$i$i19 = HEAP32[$33>>2]|0;
   $51 = $$pre$i$i19;
  }
  $50 = (($51) + 1)|0;
  HEAP32[$33>>2] = $50;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($30,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj655ENS_22PxRepXPropertyAccessorILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataESA_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $52 = HEAP32[$inOperator>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if ($55) {
  $76 = 0;$79 = $52;
 } else {
  $56 = (($54) + -1)|0;
  $57 = (($52) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58) + ($56<<3)|0) + 4|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $68 = $52;$70 = $54;
  } else {
   $62 = (($inOperator) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vi[$66 & 4095]($63);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $68 = $$pre$i$i3;$70 = $$pre1$i$i5;
  }
  $67 = (($68) + 8|0);
  $69 = (($70) + -1)|0;
  HEAP32[$67>>2] = $69;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre35 = HEAP32[$$phi$trans$insert>>2]|0;
  $76 = $$pre35;$79 = $$pre;
 }
 $71 = (($this) + 16|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $72 = (($theAccessor$i10) + 4|0);
 HEAP32[$72>>2] = 0;
 $73 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$73+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$71+12>>2]|0;
 $74 = HEAP32[$71>>2]|0;
 $75 = ($76|0)==(0);
 if ($75) {
  $100 = $79;$105 = 0;
 } else {
  $77 = (($76) + -1)|0;
  $78 = (($79) + 4|0);
  $80 = HEAP32[$78>>2]|0;
  $81 = ((($80) + ($77<<3)|0) + 4|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = ($82<<24>>24)==(0);
  if ($83) {
   $84 = (($inOperator) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 16|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($80) + ($77<<3)|0);
   $90 = HEAP32[$89>>2]|0;
   FUNCTION_TABLE_vii[$88 & 4095]($85,$90);
   $91 = HEAP32[$inOperator>>2]|0;
   $92 = (($91) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($93) + -1)|0;
   $95 = (($91) + 4|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ((($96) + ($94<<3)|0) + 4|0);
   HEAP8[$97>>0] = 1;
   $$pre$i22 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i23 = (($$pre$i22) + 8|0);
   $$pre1$i24 = HEAP32[$$phi$trans$insert$i23>>2]|0;
   $100 = $$pre$i22;$105 = $$pre1$i24;
  } else {
   $100 = $79;$105 = $76;
  }
 }
 HEAP32[$0>>2] = $74;
 $98 = (($0) + 4|0);
 HEAP8[$98>>0] = 0;
 $99 = (($100) + 12|0);
 $101 = HEAP32[$99>>2]|0;
 $102 = $101 & 2147483647;
 $103 = (($100) + 8|0);
 $104 = ($102>>>0)>($105>>>0);
 if ($104) {
  $106 = (($100) + 4|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($107) + ($105<<3)|0);
  $109 = ($108|0)==(0|0);
  if ($109) {
   $121 = $105;
  } else {
   $110 = $0;
   $111 = $110;
   $112 = HEAP32[$111>>2]|0;
   $113 = (($110) + 4)|0;
   $114 = $113;
   $115 = HEAP32[$114>>2]|0;
   $116 = $108;
   $117 = $116;
   HEAP32[$117>>2] = $112;
   $118 = (($116) + 4)|0;
   $119 = $118;
   HEAP32[$119>>2] = $115;
   $$pre$i$i26 = HEAP32[$103>>2]|0;
   $121 = $$pre$i$i26;
  }
  $120 = (($121) + 1)|0;
  HEAP32[$103>>2] = $120;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($100,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataESA_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $122 = HEAP32[$inOperator>>2]|0;
 $123 = (($122) + 8|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($124|0)==(0);
 if ($125) {
  $146 = 0;$149 = $122;
 } else {
  $126 = (($124) + -1)|0;
  $127 = (($122) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ((($128) + ($126<<3)|0) + 4|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = ($130<<24>>24)==(0);
  if ($131) {
   $138 = $122;$140 = $124;
  } else {
   $132 = (($inOperator) + 4|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 20|0);
   $136 = HEAP32[$135>>2]|0;
   FUNCTION_TABLE_vi[$136 & 4095]($133);
   $$pre$i$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i8 = (($$pre$i$i7) + 8|0);
   $$pre1$i$i9 = HEAP32[$$phi$trans$insert$i$i8>>2]|0;
   $138 = $$pre$i$i7;$140 = $$pre1$i$i9;
  }
  $137 = (($138) + 8|0);
  $139 = (($140) + -1)|0;
  HEAP32[$137>>2] = $139;
  $$pre36 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert37 = (($$pre36) + 8|0);
  $$pre38 = HEAP32[$$phi$trans$insert37>>2]|0;
  $146 = $$pre38;$149 = $$pre36;
 }
 $141 = (($this) + 32|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $142 = (($theAccessor$i10) + 4|0);
 HEAP32[$142>>2] = 0;
 $143 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$143+0>>2]=HEAP32[$141+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$141+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$141+8>>2]|0;HEAP32[$143+12>>2]=HEAP32[$141+12>>2]|0;
 $144 = HEAP32[$141>>2]|0;
 $145 = ($146|0)==(0);
 if ($145) {
  $170 = $149;$175 = 0;
 } else {
  $147 = (($146) + -1)|0;
  $148 = (($149) + 4|0);
  $150 = HEAP32[$148>>2]|0;
  $151 = ((($150) + ($147<<3)|0) + 4|0);
  $152 = HEAP8[$151>>0]|0;
  $153 = ($152<<24>>24)==(0);
  if ($153) {
   $154 = (($inOperator) + 4|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = HEAP32[$155>>2]|0;
   $157 = (($156) + 16|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($150) + ($147<<3)|0);
   $160 = HEAP32[$159>>2]|0;
   FUNCTION_TABLE_vii[$158 & 4095]($155,$160);
   $161 = HEAP32[$inOperator>>2]|0;
   $162 = (($161) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = (($163) + -1)|0;
   $165 = (($161) + 4|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ((($166) + ($164<<3)|0) + 4|0);
   HEAP8[$167>>0] = 1;
   $$pre$i29 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i30 = (($$pre$i29) + 8|0);
   $$pre1$i31 = HEAP32[$$phi$trans$insert$i30>>2]|0;
   $170 = $$pre$i29;$175 = $$pre1$i31;
  } else {
   $170 = $149;$175 = $146;
  }
 }
 HEAP32[$0>>2] = $144;
 $168 = (($0) + 4|0);
 HEAP8[$168>>0] = 0;
 $169 = (($170) + 12|0);
 $171 = HEAP32[$169>>2]|0;
 $172 = $171 & 2147483647;
 $173 = (($170) + 8|0);
 $174 = ($172>>>0)>($175>>>0);
 if ($174) {
  $176 = (($170) + 4|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = (($177) + ($175<<3)|0);
  $179 = ($178|0)==(0|0);
  if ($179) {
   $191 = $175;
  } else {
   $180 = $0;
   $181 = $180;
   $182 = HEAP32[$181>>2]|0;
   $183 = (($180) + 4)|0;
   $184 = $183;
   $185 = HEAP32[$184>>2]|0;
   $186 = $178;
   $187 = $186;
   HEAP32[$187>>2] = $182;
   $188 = (($186) + 4)|0;
   $189 = $188;
   HEAP32[$189>>2] = $185;
   $$pre$i$i33 = HEAP32[$173>>2]|0;
   $191 = $$pre$i$i33;
  }
  $190 = (($191) + 1)|0;
  HEAP32[$173>>2] = $190;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($170,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataESA_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $192 = HEAP32[$inOperator>>2]|0;
 $193 = (($192) + 8|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194|0)==(0);
 if ($195) {
  $216 = 0;$219 = $192;
 } else {
  $196 = (($194) + -1)|0;
  $197 = (($192) + 4|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ((($198) + ($196<<3)|0) + 4|0);
  $200 = HEAP8[$199>>0]|0;
  $201 = ($200<<24>>24)==(0);
  if ($201) {
   $208 = $192;$210 = $194;
  } else {
   $202 = (($inOperator) + 4|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = HEAP32[$203>>2]|0;
   $205 = (($204) + 20|0);
   $206 = HEAP32[$205>>2]|0;
   FUNCTION_TABLE_vi[$206 & 4095]($203);
   $$pre$i$i11 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i12 = (($$pre$i$i11) + 8|0);
   $$pre1$i$i13 = HEAP32[$$phi$trans$insert$i$i12>>2]|0;
   $208 = $$pre$i$i11;$210 = $$pre1$i$i13;
  }
  $207 = (($208) + 8|0);
  $209 = (($210) + -1)|0;
  HEAP32[$207>>2] = $209;
  $$pre39 = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert40 = (($$pre39) + 8|0);
  $$pre41 = HEAP32[$$phi$trans$insert40>>2]|0;
  $216 = $$pre41;$219 = $$pre39;
 }
 $211 = (($this) + 48|0);
 HEAP8[$theAccessor$i10>>0] = 0;
 $212 = (($theAccessor$i10) + 4|0);
 HEAP32[$212>>2] = 0;
 $213 = (($theAccessor$i10) + 8|0);
 ;HEAP32[$213+0>>2]=HEAP32[$211+0>>2]|0;HEAP32[$213+4>>2]=HEAP32[$211+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$211+8>>2]|0;HEAP32[$213+12>>2]=HEAP32[$211+12>>2]|0;
 $214 = HEAP32[$211>>2]|0;
 $215 = ($216|0)==(0);
 if ($215) {
  $240 = $219;$245 = 0;
 } else {
  $217 = (($216) + -1)|0;
  $218 = (($219) + 4|0);
  $220 = HEAP32[$218>>2]|0;
  $221 = ((($220) + ($217<<3)|0) + 4|0);
  $222 = HEAP8[$221>>0]|0;
  $223 = ($222<<24>>24)==(0);
  if ($223) {
   $224 = (($inOperator) + 4|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = HEAP32[$225>>2]|0;
   $227 = (($226) + 16|0);
   $228 = HEAP32[$227>>2]|0;
   $229 = (($220) + ($217<<3)|0);
   $230 = HEAP32[$229>>2]|0;
   FUNCTION_TABLE_vii[$228 & 4095]($225,$230);
   $231 = HEAP32[$inOperator>>2]|0;
   $232 = (($231) + 8|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = (($233) + -1)|0;
   $235 = (($231) + 4|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = ((($236) + ($234<<3)|0) + 4|0);
   HEAP8[$237>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $240 = $$pre$i;$245 = $$pre1$i;
  } else {
   $240 = $219;$245 = $216;
  }
 }
 HEAP32[$0>>2] = $214;
 $238 = (($0) + 4|0);
 HEAP8[$238>>0] = 0;
 $239 = (($240) + 12|0);
 $241 = HEAP32[$239>>2]|0;
 $242 = $241 & 2147483647;
 $243 = (($240) + 8|0);
 $244 = ($242>>>0)>($245>>>0);
 if ($244) {
  $246 = (($240) + 4|0);
  $247 = HEAP32[$246>>2]|0;
  $248 = (($247) + ($245<<3)|0);
  $249 = ($248|0)==(0|0);
  if ($249) {
   $261 = $245;
  } else {
   $250 = $0;
   $251 = $250;
   $252 = HEAP32[$251>>2]|0;
   $253 = (($250) + 4)|0;
   $254 = $253;
   $255 = HEAP32[$254>>2]|0;
   $256 = $248;
   $257 = $256;
   HEAP32[$257>>2] = $252;
   $258 = (($256) + 4)|0;
   $259 = $258;
   HEAP32[$259>>2] = $255;
   $$pre$i$i1 = HEAP32[$243>>2]|0;
   $261 = $$pre$i$i1;
  }
  $260 = (($261) + 1)|0;
  HEAP32[$243>>2] = $260;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($240,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataESA_EEEEvRKT0_($inOperator,$theAccessor$i10);
 $262 = HEAP32[$inOperator>>2]|0;
 $263 = (($262) + 8|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = ($264|0)==(0);
 if ($265) {
  $281 = (($inStartIndex) + 4)|0;
  STACKTOP = sp;return ($281|0);
 }
 $266 = (($264) + -1)|0;
 $267 = (($262) + 4|0);
 $268 = HEAP32[$267>>2]|0;
 $269 = ((($268) + ($266<<3)|0) + 4|0);
 $270 = HEAP8[$269>>0]|0;
 $271 = ($270<<24>>24)==(0);
 if ($271) {
  $278 = $262;$280 = $264;
 } else {
  $272 = (($inOperator) + 4|0);
  $273 = HEAP32[$272>>2]|0;
  $274 = HEAP32[$273>>2]|0;
  $275 = (($274) + 20|0);
  $276 = HEAP32[$275>>2]|0;
  FUNCTION_TABLE_vi[$276 & 4095]($273);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $278 = $$pre$i$i;$280 = $$pre1$i$i;
 }
 $277 = (($278) + 8|0);
 $279 = (($280) + -1)|0;
 HEAP32[$277>>2] = $279;
 $281 = (($inStartIndex) + 4)|0;
 STACKTOP = sp;return ($281|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj658ENS_22PxRepXPropertyAccessorILj658ENS_21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $info$i$i$i$i$i = sp + 336|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 288|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 272;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 272)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx33PxVehicleAutoBoxDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_20PxVehicleAutoBoxDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj657ENS_22PxRepXPropertyAccessorILj657ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $info$i$i$i$i$i = sp + 96|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 48|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 256;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 256)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx32PxVehicleClutchDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleClutchDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj656ENS_22PxRepXPropertyAccessorILj656ENS_21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $info$i$i$i$i$i = sp + 240|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 176|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 112;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 112)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx31PxVehicleGearsDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_18PxVehicleGearsDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_23PxVehicleDriveSimData4WEEEE14handleAccessorILj655ENS_22PxRepXPropertyAccessorILj655ENS_21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $info$i$i$i$i$i = sp + 288|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 144|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 0;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $$0$i = $5;
 }
 HEAP8[$inAccessor>>0] = 1;
 $6 = (($inAccessor) + 4|0);
 HEAP32[$6>>2] = $$0$i;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$8>>2] = $11;
 }
 _memset(($1|0),0,144)|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($1);
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($inAccessor) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($propVal$i$i$i,$13);
 $16 = HEAP32[$this>>2]|0;
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $16;
 $23 = (($0) + 4|0);
 HEAP32[$23>>2] = $18;
 $24 = (($0) + 8|0);
 HEAP32[$24>>2] = $propVal$i$i$i;
 $25 = (($0) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($0) + 16|0);
 HEAP32[$26>>2] = $22;
 $27 = (($0) + 20|0);
 HEAP32[$27>>2] = 0;
 $28 = (($0) + 24|0);
 HEAP32[$28>>2] = 0;
 (__ZNK5physx32PxVehicleEngineDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_19PxVehicleEngineDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx27PxVehicleDriveGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0;
 var $theAccessor$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i = sp + 8|0;
 $1 = (($this) + 80|0);
 HEAP8[$theAccessor$i>>0] = 0;
 $2 = (($theAccessor$i) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $31 = $$pre$i;$36 = $$pre1$i;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i1 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i1;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEE14handleAccessorILj666ENS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataESA_EEEEvRKT0_($inOperator,$theAccessor$i);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $72 = (($inStartIndex) + 2)|0;
  STACKTOP = sp;return ($72|0);
 }
 $57 = (($55) + -1)|0;
 $58 = (($53) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59) + ($57<<3)|0) + 4|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $69 = $53;$71 = $55;
 } else {
  $63 = (($inOperator) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + 20|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_vi[$67 & 4095]($64);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $69 = $$pre$i$i;$71 = $$pre1$i$i;
 }
 $68 = (($69) + 8|0);
 $70 = (($71) + -1)|0;
 HEAP32[$68>>2] = $70;
 $72 = (($inStartIndex) + 2)|0;
 STACKTOP = sp;return ($72|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEE14handleAccessorILj666ENS_22PxRepXPropertyAccessorILj666ENS_14PxVehicleDriveENS_21PxVehicleDriveDynDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 720|0;
 $info$i$i$i$i$i = sp + 424|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 128|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 112;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 112)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 _memset(($1|0),0,296)|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx34PxVehicleDriveDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_21PxVehicleDriveDynDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx28PxVehicleWheelsGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEEEEEjT_j($this,$inOperator,$inStartIndex) {
 $this = $this|0;
 $inOperator = $inOperator|0;
 $inStartIndex = $inStartIndex|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i$i = 0, $$phi$trans$insert$i$i4 = 0, $$phi$trans$insert$i8 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i11 = 0, $$pre$i$i3 = 0, $$pre$i7 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i5 = 0, $$pre1$i9 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $theAccessor$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $theAccessor$i2 = sp + 8|0;
 $1 = (($this) + 36|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $2 = (($theAccessor$i2) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$inOperator>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $31 = $5;$36 = 0;
 } else {
  $9 = (($7) + -1)|0;
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($11) + ($9<<3)|0) + 4|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($inOperator) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($11) + ($9<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($16,$21);
   $22 = HEAP32[$inOperator>>2]|0;
   $23 = (($22) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + -1)|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($27) + ($25<<3)|0) + 4|0);
   HEAP8[$28>>0] = 1;
   $$pre$i7 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i8 = (($$pre$i7) + 8|0);
   $$pre1$i9 = HEAP32[$$phi$trans$insert$i8>>2]|0;
   $31 = $$pre$i7;$36 = $$pre1$i9;
  } else {
   $31 = $5;$36 = $7;
  }
 }
 HEAP32[$0>>2] = $4;
 $29 = (($0) + 4|0);
 HEAP8[$29>>0] = 0;
 $30 = (($31) + 12|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = $32 & 2147483647;
 $34 = (($31) + 8|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  $37 = (($31) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($36<<3)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $52 = $36;
  } else {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $39;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $$pre$i$i11 = HEAP32[$34>>2]|0;
   $52 = $$pre$i$i11;
  }
  $51 = (($52) + 1)|0;
  HEAP32[$34>>2] = $51;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($31,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEE14handleAccessorILj631ENS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataESA_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $53 = HEAP32[$inOperator>>2]|0;
 $54 = (($53) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $77 = 0;$80 = $53;
 } else {
  $57 = (($55) + -1)|0;
  $58 = (($53) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($59) + ($57<<3)|0) + 4|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $69 = $53;$71 = $55;
  } else {
   $63 = (($inOperator) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 20|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vi[$67 & 4095]($64);
   $$pre$i$i3 = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i$i4 = (($$pre$i$i3) + 8|0);
   $$pre1$i$i5 = HEAP32[$$phi$trans$insert$i$i4>>2]|0;
   $69 = $$pre$i$i3;$71 = $$pre1$i$i5;
  }
  $68 = (($69) + 8|0);
  $70 = (($71) + -1)|0;
  HEAP32[$68>>2] = $70;
  $$pre = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre13 = HEAP32[$$phi$trans$insert>>2]|0;
  $77 = $$pre13;$80 = $$pre;
 }
 $72 = (($this) + 52|0);
 HEAP8[$theAccessor$i2>>0] = 0;
 $73 = (($theAccessor$i2) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($theAccessor$i2) + 8|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 $75 = HEAP32[$72>>2]|0;
 $76 = ($77|0)==(0);
 if ($76) {
  $101 = $80;$106 = 0;
 } else {
  $78 = (($77) + -1)|0;
  $79 = (($80) + 4|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = ((($81) + ($78<<3)|0) + 4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $85 = (($inOperator) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($81) + ($78<<3)|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$89 & 4095]($86,$91);
   $92 = HEAP32[$inOperator>>2]|0;
   $93 = (($92) + 8|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($94) + -1)|0;
   $96 = (($92) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($97) + ($95<<3)|0) + 4|0);
   HEAP8[$98>>0] = 1;
   $$pre$i = HEAP32[$inOperator>>2]|0;
   $$phi$trans$insert$i = (($$pre$i) + 8|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $101 = $$pre$i;$106 = $$pre1$i;
  } else {
   $101 = $80;$106 = $77;
  }
 }
 HEAP32[$0>>2] = $75;
 $99 = (($0) + 4|0);
 HEAP8[$99>>0] = 0;
 $100 = (($101) + 12|0);
 $102 = HEAP32[$100>>2]|0;
 $103 = $102 & 2147483647;
 $104 = (($101) + 8|0);
 $105 = ($103>>>0)>($106>>>0);
 if ($105) {
  $107 = (($101) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + ($106<<3)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $122 = $106;
  } else {
   $111 = $0;
   $112 = $111;
   $113 = HEAP32[$112>>2]|0;
   $114 = (($111) + 4)|0;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = $109;
   $118 = $117;
   HEAP32[$118>>2] = $113;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $116;
   $$pre$i$i1 = HEAP32[$104>>2]|0;
   $122 = $$pre$i$i1;
  }
  $121 = (($122) + 1)|0;
  HEAP32[$104>>2] = $121;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_2Sn14NameStackEntryENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($101,$0)|0);
 }
 __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEE14handleAccessorILj632ENS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataESA_EEEEvRKT0_($inOperator,$theAccessor$i2);
 $123 = HEAP32[$inOperator>>2]|0;
 $124 = (($123) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($126) {
  $142 = (($inStartIndex) + 5)|0;
  STACKTOP = sp;return ($142|0);
 }
 $127 = (($125) + -1)|0;
 $128 = (($123) + 4|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($129) + ($127<<3)|0) + 4|0);
 $131 = HEAP8[$130>>0]|0;
 $132 = ($131<<24>>24)==(0);
 if ($132) {
  $139 = $123;$141 = $125;
 } else {
  $133 = (($inOperator) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + 20|0);
  $137 = HEAP32[$136>>2]|0;
  FUNCTION_TABLE_vi[$137 & 4095]($134);
  $$pre$i$i = HEAP32[$inOperator>>2]|0;
  $$phi$trans$insert$i$i = (($$pre$i$i) + 8|0);
  $$pre1$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
  $139 = $$pre$i$i;$141 = $$pre1$i$i;
 }
 $138 = (($139) + 8|0);
 $140 = (($141) + -1)|0;
 HEAP32[$138>>2] = $140;
 $142 = (($inStartIndex) + 5)|0;
 STACKTOP = sp;return ($142|0);
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEE14handleAccessorILj632ENS_22PxRepXPropertyAccessorILj632ENS_15PxVehicleWheelsENS_22PxVehicleWheelsDynDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $info$i$i$i$i$i = sp + 136|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 64|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 76;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 76)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 dest=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsDynDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsDynDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx3Pvd17PvdPropertyFilterINS_2Sn17RepXVisitorWriterINS_16PxVehicleDrive4WEEEE14handleAccessorILj631ENS_22PxRepXPropertyAccessorILj631ENS_15PxVehicleWheelsENS_22PxVehicleWheelsSimDataESA_EEEEvRKT0_($this,$inAccessor) {
 $this = $this|0;
 $inAccessor = $inAccessor|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info$i$i$i$i$i = 0, $propVal$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $info$i$i$i$i$i = sp + 352|0;
 $0 = sp;
 $propVal$i$i$i = sp + 32|0;
 $1 = sp + 96|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 12;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 12)|0;
  $$0$i = $6;
 }
 HEAP8[$inAccessor>>0] = 1;
 $7 = (($inAccessor) + 4|0);
 HEAP32[$7>>2] = $$0$i;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$9>>2] = $12;
 }
 _memset(($1|0),0,256)|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($1);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($inAccessor) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($propVal$i$i$i,$14);
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($info$i$i$i$i$i);
 HEAP32[$0>>2] = $17;
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $19;
 $25 = (($0) + 8|0);
 HEAP32[$25>>2] = $propVal$i$i$i;
 $26 = (($0) + 12|0);
 HEAP32[$26>>2] = $21;
 $27 = (($0) + 16|0);
 HEAP32[$27>>2] = $23;
 $28 = (($0) + 20|0);
 HEAP32[$28>>2] = 0;
 $29 = (($0) + 24|0);
 HEAP32[$29>>2] = 0;
 (__ZNK5physx35PxVehicleWheelsSimDataGeneratedInfo23visitInstancePropertiesINS_18RepXPropertyFilterINS_2Sn17RepXVisitorWriterINS_22PxVehicleWheelsSimDataEEEEEEEjT_j($info$i$i$i$i$i,$0,0)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx14PxVehicleDrive19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (523800|0);
}
function __ZN5physx14PxVehicleDriveD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx14PxVehicleDriveD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx14PxVehicleDrive8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(523800,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,521424)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx23PxVehicleWheels4SimDataC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = Math_fround(0.0);
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.300000011920928955078);
 $2 = (($this) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.100000001490116119385);
 $3 = (($this) + 16|0);
 $4 = (($this) + 32|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 36|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 48|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 52|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 56|0);
 HEAPF32[$8>>2] = Math_fround(0.300000011920928955078);
 $9 = (($this) + 60|0);
 HEAPF32[$9>>2] = Math_fround(0.100000001490116119385);
 $10 = (($this) + 64|0);
 $11 = (($this) + 80|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($this) + 84|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($this) + 96|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($this) + 100|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($this) + 104|0);
 HEAPF32[$15>>2] = Math_fround(0.300000011920928955078);
 $16 = (($this) + 108|0);
 HEAPF32[$16>>2] = Math_fround(0.100000001490116119385);
 $17 = (($this) + 112|0);
 $18 = (($this) + 128|0);
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 132|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($this) + 144|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($this) + 148|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($this) + 152|0);
 HEAPF32[$22>>2] = Math_fround(0.300000011920928955078);
 $23 = (($this) + 156|0);
 HEAPF32[$23>>2] = Math_fround(0.100000001490116119385);
 $24 = (($this) + 160|0);
 $25 = (($this) + 176|0);
 ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($this) + 180|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($this) + 192|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 196|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($this) + 200|0);
 HEAPF32[$29>>2] = Math_fround(20.0);
 $30 = (($this) + 204|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($this) + 208|0);
 HEAPF32[$31>>2] = Math_fround(0.25);
 $32 = (($this) + 212|0);
 HEAPF32[$32>>2] = Math_fround(1500.0);
 $33 = (($this) + 216|0);
 ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;HEAP32[$33+16>>2]=0|0;
 $34 = (($this) + 240|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($this) + 244|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($this) + 248|0);
 HEAPF32[$36>>2] = Math_fround(20.0);
 $37 = (($this) + 252|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($this) + 256|0);
 HEAPF32[$38>>2] = Math_fround(0.25);
 $39 = (($this) + 260|0);
 HEAPF32[$39>>2] = Math_fround(1500.0);
 $40 = (($this) + 264|0);
 ;HEAP32[$40+0>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;HEAP32[$40+16>>2]=0|0;
 $41 = (($this) + 288|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($this) + 292|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($this) + 296|0);
 HEAPF32[$43>>2] = Math_fround(20.0);
 $44 = (($this) + 300|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($this) + 304|0);
 HEAPF32[$45>>2] = Math_fround(0.25);
 $46 = (($this) + 308|0);
 HEAPF32[$46>>2] = Math_fround(1500.0);
 $47 = (($this) + 312|0);
 ;HEAP32[$47+0>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;HEAP32[$47+12>>2]=0|0;HEAP32[$47+16>>2]=0|0;
 $48 = (($this) + 336|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($this) + 340|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($this) + 344|0);
 HEAPF32[$50>>2] = Math_fround(20.0);
 $51 = (($this) + 348|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($this) + 352|0);
 HEAPF32[$52>>2] = Math_fround(0.25);
 $53 = (($this) + 356|0);
 HEAPF32[$53>>2] = Math_fround(1500.0);
 $54 = (($this) + 360|0);
 ;HEAP32[$54+0>>2]=0|0;HEAP32[$54+4>>2]=0|0;HEAP32[$54+8>>2]=0|0;HEAP32[$54+12>>2]=0|0;HEAP32[$54+16>>2]=0|0;
 $55 = (($this) + 384|0);
 HEAPF32[$55>>2] = Math_fround(2.0);
 $56 = (($this) + 388|0);
 HEAPF32[$56>>2] = Math_fround(17.90493011474609375);
 $57 = (($this) + 392|0);
 HEAPF32[$57>>2] = Math_fround(1000.0);
 $58 = (($this) + 396|0);
 HEAPF32[$58>>2] = Math_fround(5.72957754135131835938);
 $59 = (($this) + 424|0);
 HEAP32[$59>>2] = 0;
 $60 = (($this) + 400|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($this) + 404|0);
 HEAPF32[$61>>2] = Math_fround(1.0);
 $62 = (($this) + 408|0);
 HEAPF32[$62>>2] = Math_fround(0.100000001490116119385);
 $63 = (($this) + 412|0);
 HEAPF32[$63>>2] = Math_fround(1.0);
 $64 = (($this) + 416|0);
 HEAPF32[$64>>2] = Math_fround(1.0);
 $65 = (($this) + 420|0);
 HEAPF32[$65>>2] = Math_fround(1.0);
 $66 = (($this) + 428|0);
 HEAPF32[$66>>2] = Math_fround(0.00100000004749745130539);
 $67 = (($this) + 432|0);
 HEAPF32[$67>>2] = Math_fround(10.0);
 $68 = (($this) + 436|0);
 HEAPF32[$68>>2] = Math_fround(1.11111116409301757813);
 $69 = (($this) + 448|0);
 HEAPF32[$69>>2] = Math_fround(2.0);
 $70 = (($this) + 452|0);
 HEAPF32[$70>>2] = Math_fround(17.90493011474609375);
 $71 = (($this) + 456|0);
 HEAPF32[$71>>2] = Math_fround(1000.0);
 $72 = (($this) + 460|0);
 HEAPF32[$72>>2] = Math_fround(5.72957754135131835938);
 $73 = (($this) + 488|0);
 HEAP32[$73>>2] = 0;
 $74 = (($this) + 464|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($this) + 468|0);
 HEAPF32[$75>>2] = Math_fround(1.0);
 $76 = (($this) + 472|0);
 HEAPF32[$76>>2] = Math_fround(0.100000001490116119385);
 $77 = (($this) + 476|0);
 HEAPF32[$77>>2] = Math_fround(1.0);
 $78 = (($this) + 480|0);
 HEAPF32[$78>>2] = Math_fround(1.0);
 $79 = (($this) + 484|0);
 HEAPF32[$79>>2] = Math_fround(1.0);
 $80 = (($this) + 492|0);
 HEAPF32[$80>>2] = Math_fround(0.00100000004749745130539);
 $81 = (($this) + 496|0);
 HEAPF32[$81>>2] = Math_fround(10.0);
 $82 = (($this) + 500|0);
 HEAPF32[$82>>2] = Math_fround(1.11111116409301757813);
 $83 = (($this) + 512|0);
 HEAPF32[$83>>2] = Math_fround(2.0);
 $84 = (($this) + 516|0);
 HEAPF32[$84>>2] = Math_fround(17.90493011474609375);
 $85 = (($this) + 520|0);
 HEAPF32[$85>>2] = Math_fround(1000.0);
 $86 = (($this) + 524|0);
 HEAPF32[$86>>2] = Math_fround(5.72957754135131835938);
 $87 = (($this) + 552|0);
 HEAP32[$87>>2] = 0;
 $88 = (($this) + 528|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($this) + 532|0);
 HEAPF32[$89>>2] = Math_fround(1.0);
 $90 = (($this) + 536|0);
 HEAPF32[$90>>2] = Math_fround(0.100000001490116119385);
 $91 = (($this) + 540|0);
 HEAPF32[$91>>2] = Math_fround(1.0);
 $92 = (($this) + 544|0);
 HEAPF32[$92>>2] = Math_fround(1.0);
 $93 = (($this) + 548|0);
 HEAPF32[$93>>2] = Math_fround(1.0);
 $94 = (($this) + 556|0);
 HEAPF32[$94>>2] = Math_fround(0.00100000004749745130539);
 $95 = (($this) + 560|0);
 HEAPF32[$95>>2] = Math_fround(10.0);
 $96 = (($this) + 564|0);
 HEAPF32[$96>>2] = Math_fround(1.11111116409301757813);
 $97 = (($this) + 576|0);
 HEAPF32[$97>>2] = Math_fround(2.0);
 $98 = (($this) + 580|0);
 HEAPF32[$98>>2] = Math_fround(17.90493011474609375);
 $99 = (($this) + 584|0);
 HEAPF32[$99>>2] = Math_fround(1000.0);
 $100 = (($this) + 588|0);
 HEAPF32[$100>>2] = Math_fround(5.72957754135131835938);
 $101 = (($this) + 616|0);
 HEAP32[$101>>2] = 0;
 $102 = (($this) + 592|0);
 HEAPF32[$102>>2] = Math_fround(0.0);
 $103 = (($this) + 596|0);
 HEAPF32[$103>>2] = Math_fround(1.0);
 $104 = (($this) + 600|0);
 HEAPF32[$104>>2] = Math_fround(0.100000001490116119385);
 $105 = (($this) + 604|0);
 HEAPF32[$105>>2] = Math_fround(1.0);
 $106 = (($this) + 608|0);
 HEAPF32[$106>>2] = Math_fround(1.0);
 $107 = (($this) + 612|0);
 HEAPF32[$107>>2] = Math_fround(1.0);
 $108 = (($this) + 620|0);
 HEAPF32[$108>>2] = Math_fround(0.00100000004749745130539);
 $109 = (($this) + 624|0);
 HEAPF32[$109>>2] = Math_fround(10.0);
 $110 = (($this) + 628|0);
 HEAPF32[$110>>2] = Math_fround(1.11111116409301757813);
 $111 = (($this) + 864|0);
 ;HEAP32[$111+0>>2]=0|0;HEAP32[$111+4>>2]=0|0;HEAP32[$111+8>>2]=0|0;HEAP32[$111+12>>2]=0|0;
 $112 = (($this) + 880|0);
 ;HEAP32[$112+0>>2]=0|0;HEAP32[$112+4>>2]=0|0;HEAP32[$112+8>>2]=0|0;HEAP32[$112+12>>2]=0|0;
 $113 = (($this) + 896|0);
 ;HEAP32[$113+0>>2]=0|0;HEAP32[$113+4>>2]=0|0;HEAP32[$113+8>>2]=0|0;HEAP32[$113+12>>2]=0|0;
 $114 = (($this) + 912|0);
 ;HEAP32[$114+0>>2]=0|0;HEAP32[$114+4>>2]=0|0;HEAP32[$114+8>>2]=0|0;HEAP32[$114+12>>2]=0|0;
 $115 = (($this) + 640|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = (($this) + 644|0);
 HEAPF32[$116>>2] = Math_fround(0.0);
 $117 = (($this) + 648|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 $118 = (($this) + 688|0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 $119 = (($this) + 692|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($this) + 696|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($this) + 736|0);
 HEAPF32[$121>>2] = Math_fround(0.0);
 $122 = (($this) + 740|0);
 HEAPF32[$122>>2] = Math_fround(0.0);
 $123 = (($this) + 744|0);
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = (($this) + 784|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = (($this) + 788|0);
 HEAPF32[$125>>2] = Math_fround(0.0);
 $126 = (($this) + 792|0);
 HEAPF32[$126>>2] = Math_fround(0.0);
 $127 = (($this) + 832|0);
 HEAPF32[$127>>2] = Math_fround(1520.0);
 $128 = (($this) + 848|0);
 HEAPF32[$128>>2] = Math_fround(6.57894765026867389678E-4);
 $129 = (($this) + 652|0);
 HEAPF32[$129>>2] = Math_fround(0.0);
 $130 = (($this) + 656|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = (($this) + 660|0);
 HEAPF32[$131>>2] = Math_fround(0.0);
 $132 = (($this) + 700|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = (($this) + 704|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = (($this) + 708|0);
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = (($this) + 748|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = (($this) + 752|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 $137 = (($this) + 756|0);
 HEAPF32[$137>>2] = Math_fround(0.0);
 $138 = (($this) + 796|0);
 HEAPF32[$138>>2] = Math_fround(0.0);
 $139 = (($this) + 800|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($this) + 804|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $141 = (($this) + 836|0);
 HEAPF32[$141>>2] = Math_fround(1520.0);
 $142 = (($this) + 852|0);
 HEAPF32[$142>>2] = Math_fround(6.57894765026867389678E-4);
 $143 = (($this) + 664|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = (($this) + 668|0);
 HEAPF32[$144>>2] = Math_fround(0.0);
 $145 = (($this) + 672|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = (($this) + 712|0);
 HEAPF32[$146>>2] = Math_fround(0.0);
 $147 = (($this) + 716|0);
 HEAPF32[$147>>2] = Math_fround(0.0);
 $148 = (($this) + 720|0);
 HEAPF32[$148>>2] = Math_fround(0.0);
 $149 = (($this) + 760|0);
 HEAPF32[$149>>2] = Math_fround(0.0);
 $150 = (($this) + 764|0);
 HEAPF32[$150>>2] = Math_fround(0.0);
 $151 = (($this) + 768|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = (($this) + 808|0);
 HEAPF32[$152>>2] = Math_fround(0.0);
 $153 = (($this) + 812|0);
 HEAPF32[$153>>2] = Math_fround(0.0);
 $154 = (($this) + 816|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 $155 = (($this) + 840|0);
 HEAPF32[$155>>2] = Math_fround(1520.0);
 $156 = (($this) + 856|0);
 HEAPF32[$156>>2] = Math_fround(6.57894765026867389678E-4);
 $157 = (($this) + 676|0);
 HEAPF32[$157>>2] = Math_fround(0.0);
 $158 = (($this) + 680|0);
 HEAPF32[$158>>2] = Math_fround(0.0);
 $159 = (($this) + 684|0);
 HEAPF32[$159>>2] = Math_fround(0.0);
 $160 = (($this) + 724|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 $161 = (($this) + 728|0);
 HEAPF32[$161>>2] = Math_fround(0.0);
 $162 = (($this) + 732|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 $163 = (($this) + 772|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = (($this) + 776|0);
 HEAPF32[$164>>2] = Math_fround(0.0);
 $165 = (($this) + 780|0);
 HEAPF32[$165>>2] = Math_fround(0.0);
 $166 = (($this) + 820|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = (($this) + 824|0);
 HEAPF32[$167>>2] = Math_fround(0.0);
 $168 = (($this) + 828|0);
 HEAPF32[$168>>2] = Math_fround(0.0);
 $169 = (($this) + 844|0);
 HEAPF32[$169>>2] = Math_fround(1520.0);
 $170 = (($this) + 860|0);
 HEAPF32[$170>>2] = Math_fround(6.57894765026867389678E-4);
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData17setSuspensionDataEjRKNS_23PxVehicleSuspensionDataE($this,$id,$susp) {
 $this = $this|0;
 $id = $id|0;
 $susp = $susp|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0);
 var $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + (($id*48)|0)|0);
 dest=$0+0|0; src=$susp+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (($susp) + 8|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 > Math_fround(0.0);
 $4 = $3 ? $2 : Math_fround(1.0);
 $5 = Math_fround(Math_fround(1.0) / $4);
 $6 = ((($this) + (($id*48)|0)|0) + 32|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($susp) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $8 > Math_fround(0.0);
 $10 = $9 ? $8 : Math_fround(1.0);
 $11 = Math_fround(Math_fround(1.0) / $10);
 $12 = ((($this) + (($id*48)|0)|0) + 36|0);
 HEAPF32[$12>>2] = $11;
 $13 = ((($this) + (($id*48)|0)|0) + 200|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = ((($this) + (($id*48)|0)|0) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 + $16);
 $18 = ((($this) + ($id<<2)|0) + 832|0);
 HEAPF32[$18>>2] = $17;
 $19 = Math_fround(Math_fround(1.0) / $17);
 $20 = ((($this) + ($id<<2)|0) + 848|0);
 HEAPF32[$20>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData12setWheelDataEjRKNS_18PxVehicleWheelDataE($this,$id,$wheel) {
 $this = $this|0;
 $id = $id|0;
 $wheel = $wheel|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 $0 = ((($this) + (($id*48)|0)|0) + 192|0);
 dest=$0+0|0; src=$wheel+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(Math_fround(1.0) / $1);
 $3 = ((($this) + (($id*48)|0)|0) + 228|0);
 HEAPF32[$3>>2] = $2;
 $4 = ((($this) + (($id*48)|0)|0) + 204|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(Math_fround(1.0) / $5);
 $7 = ((($this) + (($id*48)|0)|0) + 232|0);
 HEAPF32[$7>>2] = $6;
 $8 = ((($this) + (($id*48)|0)|0) + 200|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($this) + (($id*48)|0)|0) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 + $11);
 $13 = ((($this) + ($id<<2)|0) + 832|0);
 HEAPF32[$13>>2] = $12;
 $14 = Math_fround(Math_fround(1.0) / $12);
 $15 = ((($this) + ($id<<2)|0) + 848|0);
 HEAPF32[$15>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData11setTireDataEjRKNS_17PxVehicleTireDataE($this,$id,$tire) {
 $this = $this|0;
 $id = $id|0;
 $tire = $tire|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ((($this) + ($id<<6)|0) + 384|0);
 dest=$0+0|0; src=$tire+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = ((($this) + ($id<<6)|0) + 392|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(Math_fround(1.0) / $2);
 $4 = ((($this) + ($id<<6)|0) + 428|0);
 HEAPF32[$4>>2] = $3;
 $5 = ((($this) + ($id<<6)|0) + 408|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = ((($this) + ($id<<6)|0) + 400|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = Math_fround(Math_fround(1.0) / $9);
 $11 = ((($this) + ($id<<6)|0) + 432|0);
 HEAPF32[$11>>2] = $10;
 $12 = ((($this) + ($id<<6)|0) + 416|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 - $6);
 $15 = Math_fround(Math_fround(1.0) / $14);
 $16 = ((($this) + ($id<<6)|0) + 436|0);
 HEAPF32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData22setSuspTravelDirectionEjRKNS_6PxVec3E($this,$id,$dir) {
 $this = $this|0;
 $id = $id|0;
 $dir = $dir|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$dir>>2]);
 $1 = ((($this) + (($id*12)|0)|0) + 640|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($dir) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = ((($this) + (($id*12)|0)|0) + 644|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($dir) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = ((($this) + (($id*12)|0)|0) + 648|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData26setSuspForceAppPointOffsetEjRKNS_6PxVec3E($this,$id,$offset) {
 $this = $this|0;
 $id = $id|0;
 $offset = $offset|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$offset>>2]);
 $1 = ((($this) + (($id*12)|0)|0) + 688|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($offset) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = ((($this) + (($id*12)|0)|0) + 692|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($offset) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = ((($this) + (($id*12)|0)|0) + 696|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData26setTireForceAppPointOffsetEjRKNS_6PxVec3E($this,$id,$offset) {
 $this = $this|0;
 $id = $id|0;
 $offset = $offset|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$offset>>2]);
 $1 = ((($this) + (($id*12)|0)|0) + 736|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($offset) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = ((($this) + (($id*12)|0)|0) + 740|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($offset) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = ((($this) + (($id*12)|0)|0) + 744|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData20setWheelCentreOffsetEjRKNS_6PxVec3E($this,$id,$offset) {
 $this = $this|0;
 $id = $id|0;
 $offset = $offset|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$offset>>2]);
 $1 = ((($this) + (($id*12)|0)|0) + 784|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($offset) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = ((($this) + (($id*12)|0)|0) + 788|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($offset) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = ((($this) + (($id*12)|0)|0) + 792|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData20setWheelShapeMappingEji($this,$id,$shapeId) {
 $this = $this|0;
 $id = $id|0;
 $shapeId = $shapeId|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $shapeId&255;
 $1 = ((($this) + ($id)|0) + 928|0);
 HEAP8[$1>>0] = $0;
 STACKTOP = sp;return;
}
function __ZN5physx23PxVehicleWheels4SimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($this,$id,$sqFilterData) {
 $this = $this|0;
 $id = $id|0;
 $sqFilterData = $sqFilterData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($this) + ($id<<4)|0) + 864|0);
 ;HEAP32[$0+0>>2]=HEAP32[$sqFilterData+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$sqFilterData+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$sqFilterData+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$sqFilterData+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx43PxVehicleDrivableSurfaceToTireFrictionPairs8allocateEjj($maxNbTireTypes,$maxNbSurfaceTypes) {
 $maxNbTireTypes = $maxNbTireTypes|0;
 $maxNbSurfaceTypes = $maxNbSurfaceTypes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $factor$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $maxNbTireTypes << 2;
 $2 = Math_imul($1, $maxNbSurfaceTypes)|0;
 $3 = $maxNbSurfaceTypes << 3;
 $4 = (($3) + 30)|0;
 $factor$i = $4 & -32;
 $5 = (($2) + 47)|0;
 $6 = $5 & -16;
 $7 = (($6) + ($factor$i))|0;
 $8 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$7,523816,55)|0);
 _memset(($8|0),0,($7|0))|0;
 HEAP32[$8>>2] = 0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 8|0);
 HEAP32[$10>>2] = 0;
 $11 = (($8) + 20|0);
 HEAP32[$11>>2] = 0;
 $12 = (($8) + 24|0);
 HEAP32[$12>>2] = $maxNbTireTypes;
 $13 = (($8) + 12|0);
 HEAP32[$13>>2] = 0;
 $14 = (($8) + 16|0);
 HEAP32[$14>>2] = $maxNbSurfaceTypes;
 STACKTOP = sp;return ($8|0);
}
function __ZN5physx43PxVehicleDrivableSurfaceToTireFrictionPairs5setupEjjPPKNS_10PxMaterialEPKNS_28PxVehicleDrivableSurfaceTypeE($this,$numTireTypes,$numSurfaceTypes,$drivableSurfaceMaterials,$drivableSurfaceTypes) {
 $this = $this|0;
 $numTireTypes = $numTireTypes|0;
 $numSurfaceTypes = $numSurfaceTypes|0;
 $drivableSurfaceMaterials = $drivableSurfaceMaterials|0;
 $drivableSurfaceTypes = $drivableSurfaceTypes|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $exitcond5 = 0, $factor$i = 0, $i$02 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1 << 2;
 $5 = Math_imul($4, $3)|0;
 $6 = $3 << 3;
 $7 = (($6) + 30)|0;
 $factor$i = $7 & -32;
 $8 = (($5) + 47)|0;
 $9 = $8 & -16;
 $10 = (($9) + ($factor$i))|0;
 _memset(($this|0),0,($10|0))|0;
 HEAP32[$0>>2] = $1;
 HEAP32[$2>>2] = $3;
 $11 = (($this) + 32|0);
 HEAP32[$this>>2] = $11;
 $12 = Math_imul($numSurfaceTypes, $numTireTypes)|0;
 $13 = $12 << 2;
 $14 = (($13) + 15)|0;
 $15 = $14 & -16;
 $16 = (($11) + ($15)|0);
 $17 = (($this) + 4|0);
 HEAP32[$17>>2] = $16;
 $18 = $numSurfaceTypes << 2;
 $19 = (($18) + 15)|0;
 $20 = $19 & -16;
 $$sum = (($15) + ($20))|0;
 $21 = (($11) + ($$sum)|0);
 $22 = (($this) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = ($numSurfaceTypes|0)==(0);
 L1: do {
  if (!($23)) {
   $29 = $21;$33 = $16;$i$02 = 0;
   while(1) {
    $26 = (($drivableSurfaceTypes) + ($i$02<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($29) + ($i$02<<2)|0);
    HEAP32[$28>>2] = $27;
    $30 = (($drivableSurfaceMaterials) + ($i$02<<2)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($33) + ($i$02<<2)|0);
    HEAP32[$32>>2] = $31;
    $34 = (($i$02) + 1)|0;
    $exitcond5 = ($34|0)==($numSurfaceTypes|0);
    if ($exitcond5) {
     break L1;
    }
    $$pre = HEAP32[$22>>2]|0;
    $$pre7 = HEAP32[$17>>2]|0;
    $29 = $$pre;$33 = $$pre7;$i$02 = $34;
   }
  }
 } while(0);
 $24 = ($12|0)==(0);
 if ($24) {
  $37 = (($this) + 20|0);
  HEAP32[$37>>2] = $numTireTypes;
  $38 = (($this) + 12|0);
  HEAP32[$38>>2] = $numSurfaceTypes;
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$this>>2]|0;
 $i1$01 = 0;
 while(1) {
  $35 = (($25) + ($i1$01<<2)|0);
  HEAPF32[$35>>2] = Math_fround(1.0);
  $36 = (($i1$01) + 1)|0;
  $exitcond = ($36|0)==($12|0);
  if ($exitcond) {
   break;
  } else {
   $i1$01 = $36;
  }
 }
 $37 = (($this) + 20|0);
 HEAP32[$37>>2] = $numTireTypes;
 $38 = (($this) + 12|0);
 HEAP32[$38>>2] = $numSurfaceTypes;
 STACKTOP = sp;return;
}
function __ZN5physx43PxVehicleDrivableSurfaceToTireFrictionPairs7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx43PxVehicleDrivableSurfaceToTireFrictionPairs19getTypePairFrictionEjj($this,$surfaceType,$tireType) {
 $this = $this|0;
 $surfaceType = $surfaceType|0;
 $tireType = $tireType|0;
 var $$sum = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_imul($2, $surfaceType)|0;
 $$sum = (($3) + ($tireType))|0;
 $4 = (($0) + ($$sum<<2)|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN5physx24setVehicleToleranceScaleERKNS_17PxTolerancesScaleE($ts) {
 $ts = $ts|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$ts>>2]);
 $1 = Math_fround($0 * Math_fround(5.0));
 HEAPF32[523912>>2] = $1;
 $2 = Math_fround(Math_fround(1.0) / $1);
 HEAPF32[523920>>2] = $2;
 $3 = Math_fround(HEAPF32[$ts>>2]);
 HEAPF32[523928>>2] = $3;
 $4 = Math_fround(HEAPF32[$ts>>2]);
 $5 = Math_fround($4 * Math_fround(0.20000000298023223877));
 HEAPF32[523936>>2] = $5;
 $6 = Math_fround(HEAPF32[$ts>>2]);
 HEAPF32[523944>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx26resetVehicleToleranceScaleEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[523912>>2] = Math_fround(0.0);
 HEAPF32[523920>>2] = Math_fround(0.0);
 HEAPF32[523928>>2] = Math_fround(0.0);
 HEAPF32[523936>>2] = Math_fround(0.0);
 HEAPF32[523944>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx27setSerializationRegistryPtrEPKNS_23PxSerializationRegistryE($sr) {
 $sr = $sr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[523952>>2] = $sr;
 STACKTOP = sp;return;
}
function __ZN5physx29resetSerializationRegistryPtrEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[523952>>2]|0;
 HEAP32[523952>>2] = 0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx19computeSprungMassesEjPKNS_6PxVec3ERS1_fjPf($numSprungMasses,$sprungMassCoordinates,$centreOfMass,$totalMass,$gravityDirection,$sprungMasses) {
 $numSprungMasses = $numSprungMasses|0;
 $sprungMassCoordinates = $sprungMassCoordinates|0;
 $centreOfMass = $centreOfMass|0;
 $totalMass = Math_fround($totalMass);
 $gravityDirection = $gravityDirection|0;
 $sprungMasses = $sprungMasses|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $A = 0, $b = 0, $cm = 0, $exitcond26 = 0, $exitcond29 = 0;
 var $i$019 = 0, $i5$016 = 0, $i6$013$us = 0, $result = 0, $scevgep = 0, $solver = 0, $v = 0, $w = 0, $x0 = 0, $x1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4592|0;
 $v = sp + 4572|0;
 $w = sp + 4560|0;
 $cm = sp + 4548|0;
 $x0 = sp + 4536|0;
 $x1 = sp + 4524|0;
 $A = sp + 192|0;
 $b = sp + 96|0;
 $result = sp;
 $solver = sp + 2312|0;
 if ((($numSprungMasses|0) == 3)) {
  $98 = (($gravityDirection) + 1)|0;
  $99 = (($98>>>0) % 3)&-1;
  $100 = (($gravityDirection) + 2)|0;
  $101 = (($100>>>0) % 3)&-1;
  $102 = (($A) + 2116|0);
  HEAP32[$102>>2] = 3;
  $103 = (($b) + 92|0);
  HEAP32[$103>>2] = 3;
  $104 = (($sprungMassCoordinates) + ($99<<2)|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  HEAPF32[$A>>2] = $105;
  $106 = (($sprungMassCoordinates) + 12|0);
  $107 = (($106) + ($99<<2)|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = (($A) + 4|0);
  HEAPF32[$109>>2] = $108;
  $110 = (($sprungMassCoordinates) + 24|0);
  $111 = (($110) + ($99<<2)|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($A) + 8|0);
  HEAPF32[$113>>2] = $112;
  $114 = (($sprungMassCoordinates) + ($101<<2)|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($A) + 92|0);
  HEAPF32[$116>>2] = $115;
  $117 = (($106) + ($101<<2)|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = (($A) + 96|0);
  HEAPF32[$119>>2] = $118;
  $120 = (($110) + ($101<<2)|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = (($A) + 100|0);
  HEAPF32[$122>>2] = $121;
  $123 = (($A) + 184|0);
  HEAPF32[$123>>2] = Math_fround(1.0);
  $124 = (($A) + 188|0);
  HEAPF32[$124>>2] = Math_fround(1.0);
  $125 = (($A) + 192|0);
  HEAPF32[$125>>2] = Math_fround(1.0);
  $126 = (($centreOfMass) + ($99<<2)|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = Math_fround($127 * $totalMass);
  HEAPF32[$b>>2] = $128;
  $129 = (($centreOfMass) + ($101<<2)|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($130 * $totalMass);
  $132 = (($b) + 4|0);
  HEAPF32[$132>>2] = $131;
  $133 = (($b) + 8|0);
  HEAPF32[$133>>2] = $totalMass;
  $134 = (($result) + 92|0);
  HEAP32[$134>>2] = 3;
  $135 = (($solver) + 2208|0);
  HEAP32[$135>>2] = 0;
  __ZN5physx16MatrixNNLUSolver11decomposeLUERKNS_8MatrixNNE($solver,$A);
  __ZNK5physx16MatrixNNLUSolver5solveERKNS_7VectorNERS1_($solver,$b,$result);
  $136 = Math_fround(HEAPF32[$result>>2]);
  HEAPF32[$sprungMasses>>2] = $136;
  $137 = (($result) + 4|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = (($sprungMasses) + 4|0);
  HEAPF32[$139>>2] = $138;
  $140 = (($result) + 8|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = (($sprungMasses) + 8|0);
  HEAPF32[$142>>2] = $141;
  STACKTOP = sp;return;
 } else if ((($numSprungMasses|0) == 1)) {
  HEAPF32[$sprungMasses>>2] = $totalMass;
  STACKTOP = sp;return;
 } else if ((($numSprungMasses|0) == 2)) {
  $0 = Math_fround(HEAPF32[$sprungMassCoordinates>>2]);
  HEAPF32[$v>>2] = $0;
  $1 = (($v) + 4|0);
  $2 = (($sprungMassCoordinates) + 4|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$1>>2] = $3;
  $4 = (($v) + 8|0);
  $5 = (($sprungMassCoordinates) + 8|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  HEAPF32[$4>>2] = $6;
  $7 = (($v) + ($gravityDirection<<2)|0);
  HEAPF32[$7>>2] = Math_fround(0.0);
  $8 = (($sprungMassCoordinates) + 12|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($9 - $0);
  $11 = (($sprungMassCoordinates) + 16|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($12 - $3);
  $14 = (($sprungMassCoordinates) + 20|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($15 - $6);
  HEAPF32[$w>>2] = $10;
  $17 = (($w) + 4|0);
  HEAPF32[$17>>2] = $13;
  $18 = (($w) + 8|0);
  HEAPF32[$18>>2] = $16;
  $19 = (($w) + ($gravityDirection<<2)|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = Math_fround(HEAPF32[$w>>2]);
  $21 = Math_fround($20 * $20);
  $22 = Math_fround(HEAPF32[$17>>2]);
  $23 = Math_fround($22 * $22);
  $24 = Math_fround($21 + $23);
  $25 = Math_fround(HEAPF32[$18>>2]);
  $26 = Math_fround($25 * $25);
  $27 = Math_fround($24 + $26);
  $28 = (Math_fround(Math_sqrt((Math_fround($27)))));
  $29 = $28 > Math_fround(0.0);
  if ($29) {
   $30 = Math_fround(Math_fround(1.0) / $28);
   $31 = Math_fround($20 * $30);
   HEAPF32[$w>>2] = $31;
   $32 = Math_fround($22 * $30);
   HEAPF32[$17>>2] = $32;
   $33 = Math_fround($25 * $30);
   HEAPF32[$18>>2] = $33;
   $52 = $31;$54 = $32;$57 = $33;
  } else {
   $52 = $20;$54 = $22;$57 = $25;
  }
  $34 = Math_fround(HEAPF32[$centreOfMass>>2]);
  HEAPF32[$cm>>2] = $34;
  $35 = (($cm) + 4|0);
  $36 = (($centreOfMass) + 4|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  HEAPF32[$35>>2] = $37;
  $38 = (($cm) + 8|0);
  $39 = (($centreOfMass) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$38>>2] = $40;
  $41 = (($cm) + ($gravityDirection<<2)|0);
  HEAPF32[$41>>2] = Math_fround(0.0);
  $42 = Math_fround(HEAPF32[$cm>>2]);
  $43 = Math_fround(HEAPF32[$v>>2]);
  $44 = Math_fround($42 - $43);
  $45 = Math_fround(HEAPF32[$35>>2]);
  $46 = Math_fround(HEAPF32[$1>>2]);
  $47 = Math_fround($45 - $46);
  $48 = Math_fround(HEAPF32[$38>>2]);
  $49 = Math_fround(HEAPF32[$4>>2]);
  $50 = Math_fround($48 - $49);
  $51 = Math_fround($44 * $52);
  $53 = Math_fround($47 * $54);
  $55 = Math_fround($51 + $53);
  $56 = Math_fround($50 * $57);
  $58 = Math_fround($55 + $56);
  $59 = Math_fround($52 * $58);
  $60 = Math_fround($54 * $58);
  $61 = Math_fround($57 * $58);
  $62 = Math_fround($43 + $59);
  $63 = Math_fround($46 + $60);
  $64 = Math_fround($49 + $61);
  HEAPF32[$x0>>2] = $0;
  $65 = (($x0) + 4|0);
  HEAPF32[$65>>2] = $3;
  $66 = (($x0) + 8|0);
  HEAPF32[$66>>2] = $6;
  $67 = (($x0) + ($gravityDirection<<2)|0);
  HEAPF32[$67>>2] = Math_fround(0.0);
  HEAPF32[$x1>>2] = $9;
  $68 = (($x1) + 4|0);
  HEAPF32[$68>>2] = $12;
  $69 = (($x1) + 8|0);
  HEAPF32[$69>>2] = $15;
  $70 = (($x1) + ($gravityDirection<<2)|0);
  HEAPF32[$70>>2] = Math_fround(0.0);
  $71 = Math_fround(HEAPF32[$x0>>2]);
  $72 = Math_fround($71 - $62);
  $73 = Math_fround(HEAPF32[$65>>2]);
  $74 = Math_fround($73 - $63);
  $75 = Math_fround(HEAPF32[$66>>2]);
  $76 = Math_fround($75 - $64);
  $77 = Math_fround($72 * $52);
  $78 = Math_fround($74 * $54);
  $79 = Math_fround($77 + $78);
  $80 = Math_fround($76 * $57);
  $81 = Math_fround($79 + $80);
  $82 = Math_fround(HEAPF32[$x1>>2]);
  $83 = Math_fround($82 - $62);
  $84 = Math_fround(HEAPF32[$68>>2]);
  $85 = Math_fround($84 - $63);
  $86 = Math_fround(HEAPF32[$69>>2]);
  $87 = Math_fround($86 - $64);
  $88 = Math_fround($52 * $83);
  $89 = Math_fround($54 * $85);
  $90 = Math_fround($88 + $89);
  $91 = Math_fround($57 * $87);
  $92 = Math_fround($90 + $91);
  $93 = Math_fround($92 * $totalMass);
  $94 = Math_fround($92 - $81);
  $95 = Math_fround($93 / $94);
  $96 = Math_fround($totalMass - $95);
  HEAPF32[$sprungMasses>>2] = $95;
  $97 = (($sprungMasses) + 4|0);
  HEAPF32[$97>>2] = $96;
  STACKTOP = sp;return;
 } else {
  $143 = ($numSprungMasses>>>0)>(3);
  if (!($143)) {
   STACKTOP = sp;return;
  }
  $144 = (($gravityDirection) + 1)|0;
  $145 = (($144>>>0) % 3)&-1;
  $146 = (($gravityDirection) + 2)|0;
  $147 = (($146>>>0) % 3)&-1;
  $148 = (Math_fround(($numSprungMasses>>>0)));
  $149 = Math_fround($totalMass / $148);
  $150 = (($numSprungMasses) + 3)|0;
  $151 = (($A) + 2116|0);
  HEAP32[$151>>2] = $150;
  $152 = (($b) + 92|0);
  HEAP32[$152>>2] = $150;
  $i$019 = 0;
  while(1) {
   $154 = (($sprungMassCoordinates) + (($i$019*12)|0)|0);
   $155 = (($154) + ($145<<2)|0);
   $156 = Math_fround(HEAPF32[$155>>2]);
   $157 = (($A) + ($i$019<<2)|0);
   HEAPF32[$157>>2] = $156;
   $158 = (($154) + ($147<<2)|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = ((($A) + ($i$019<<2)|0) + 92|0);
   HEAPF32[$160>>2] = $159;
   $161 = ((($A) + ($i$019<<2)|0) + 184|0);
   HEAPF32[$161>>2] = Math_fround(1.0);
   $162 = (($i$019) + 1)|0;
   $exitcond26 = ($162|0)==($numSprungMasses|0);
   if ($exitcond26) {
    break;
   } else {
    $i$019 = $162;
   }
  }
  $153 = ($numSprungMasses>>>0)<(4294967293);
  if ($153) {
   $i5$016 = $numSprungMasses;
   while(1) {
    $163 = (($A) + ($i5$016<<2)|0);
    HEAPF32[$163>>2] = Math_fround(0.0);
    $164 = ((($A) + ($i5$016<<2)|0) + 92|0);
    HEAPF32[$164>>2] = Math_fround(0.0);
    $165 = ((($A) + ($i5$016<<2)|0) + 184|0);
    HEAPF32[$165>>2] = Math_fround(0.0);
    $166 = (($i5$016) + 1)|0;
    $167 = ($166>>>0)<($150>>>0);
    if ($167) {
     $i5$016 = $166;
    } else {
     break;
    }
   }
  }
  $168 = (($centreOfMass) + ($145<<2)|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = Math_fround($169 * $totalMass);
  HEAPF32[$b>>2] = $170;
  $171 = (($centreOfMass) + ($147<<2)|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = Math_fround($172 * $totalMass);
  $174 = (($b) + 4|0);
  HEAPF32[$174>>2] = $173;
  $175 = (($b) + 8|0);
  HEAPF32[$175>>2] = $totalMass;
  $176 = (($numSprungMasses) + 1)|0;
  $177 = (($numSprungMasses) + 2)|0;
  $178 = Math_fround($149 * Math_fround(2.0));
  $179 = $numSprungMasses << 2;
  $i6$013$us = 0;
  while(1) {
   $180 = (($i6$013$us) + 3)|0;
   $scevgep = (($A) + (($180*92)|0)|0);
   _memset(($scevgep|0),0,($179|0))|0;
   $181 = ((($A) + (($180*92)|0)|0) + ($i6$013$us<<2)|0);
   HEAPF32[$181>>2] = Math_fround(2.0);
   $182 = (($sprungMassCoordinates) + (($i6$013$us*12)|0)|0);
   $183 = (($182) + ($145<<2)|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = ((($A) + (($180*92)|0)|0) + ($numSprungMasses<<2)|0);
   HEAPF32[$185>>2] = $184;
   $186 = (($182) + ($147<<2)|0);
   $187 = Math_fround(HEAPF32[$186>>2]);
   $188 = ((($A) + (($180*92)|0)|0) + ($176<<2)|0);
   HEAPF32[$188>>2] = $187;
   $189 = ((($A) + (($180*92)|0)|0) + ($177<<2)|0);
   HEAPF32[$189>>2] = Math_fround(1.0);
   $190 = (($b) + ($180<<2)|0);
   HEAPF32[$190>>2] = $178;
   $191 = (($i6$013$us) + 1)|0;
   $exitcond29 = ($191|0)==($numSprungMasses|0);
   if ($exitcond29) {
    break;
   } else {
    $i6$013$us = $191;
   }
  }
  $192 = (($result) + 92|0);
  HEAP32[$192>>2] = $150;
  $193 = (($solver) + 2208|0);
  HEAP32[$193>>2] = 0;
  __ZN5physx16MatrixNNLUSolver11decomposeLUERKNS_8MatrixNNE($solver,$A);
  __ZNK5physx16MatrixNNLUSolver5solveERKNS_7VectorNERS1_($solver,$b,$result);
  $194 = $numSprungMasses << 2;
  _memcpy(($sprungMasses|0),($result|0),($194|0))|0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx16MatrixNNLUSolver11decomposeLUERKNS_8MatrixNNE($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$lcssa$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $LU = 0, $big$037 = Math_fround(0), $big$115 = Math_fround(0), $big$115$us = Math_fround(0), $big$2 = Math_fround(0), $big$2$us = Math_fround(0), $exitcond = 0, $exitcond51 = 0, $exitcond52 = 0, $exitcond60 = 0;
 var $fabsf$i$i = Math_fround(0), $fabsf$i$i$us = Math_fround(0), $fabsf$i$i1 = Math_fround(0), $i$02$i = 0, $i$02$i$i = 0, $i1$040 = 0, $i4$016 = 0, $i4$016$us = 0, $i8$0 = 0, $i8$026 = 0, $i8$027 = 0, $imax$031 = 0, $imax$114 = 0, $imax$114$us = 0, $imax$2 = 0, $imax$2$us = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$next59$pre = 0, $indvars$iv$next59$pre$phiZZZ2D = 0;
 var $indvars$iv58 = 0, $j$038 = 0, $k$03 = 0, $k6$08$us = 0, $k7$022 = 0, $scevgep = 0, $scevgep46 = 0, $scevgep64 = 0, $scevgep66 = 0, $split20 = 0, $sum$0$lcssa = Math_fround(0), $sum$02 = Math_fround(0), $sum5$07$us = Math_fround(0), $vv = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2224|0;
 $LU = sp + 96|0;
 $vv = sp;
 $0 = (($a) + 2116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($LU) + 2116|0);
  HEAP32[$3>>2] = 0;
  $80 = $3;
 } else {
  $5 = $1;$i$02$i$i = 0;
  while(1) {
   $4 = ($5|0)==(0);
   if ($4) {
    $9 = 0;
   } else {
    $scevgep66 = (($a) + (($i$02$i$i*92)|0)|0);
    $scevgep64 = (($LU) + (($i$02$i$i*92)|0)|0);
    $6 = $5 << 2;
    _memcpy(($scevgep64|0),($scevgep66|0),($6|0))|0;
    $9 = $5;
   }
   $7 = (($i$02$i$i) + 1)|0;
   $8 = ($7>>>0)<($9>>>0);
   if ($8) {
    $5 = $9;$i$02$i$i = $7;
   } else {
    break;
   }
  }
  $10 = (($LU) + 2116|0);
  HEAP32[$10>>2] = $9;
  if ($2) {
   $80 = $10;
  } else {
   $11 = $1 << 2;
   _memset(($this|0),-1,($11|0))|0;
   $80 = $10;
  }
 }
 $12 = (($1) + -1)|0;
 $i1$040 = 0;
 while(1) {
  $big$037 = Math_fround(0.0);$j$038 = 0;
  while(1) {
   $13 = ((($LU) + (($i1$040*92)|0)|0) + ($j$038<<2)|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $fabsf$i$i1 = (Math_fround(Math_abs((Math_fround($14)))));
   $15 = $fabsf$i$i1 > $big$037;
   $16 = $15 ? $fabsf$i$i1 : $big$037;
   $17 = (($j$038) + 1)|0;
   $18 = ($17>>>0)>($12>>>0);
   if ($18) {
    break;
   } else {
    $big$037 = $16;$j$038 = $17;
   }
  }
  $19 = Math_fround(Math_fround(1.0) / $16);
  $20 = (($vv) + ($i1$040<<2)|0);
  HEAPF32[$20>>2] = $19;
  $21 = (($i1$040) + 1)|0;
  $22 = ($21>>>0)>($12>>>0);
  if ($22) {
   $imax$031 = 0;$indvars$iv58 = 0;
   break;
  } else {
   $i1$040 = $21;
  }
 }
 while(1) {
  $23 = ($indvars$iv58|0)==(0);
  if ($23) {
   $big$115 = Math_fround(0.0);$i4$016 = 0;$imax$114 = $imax$031;
   label = 20;
  } else {
   $indvars$iv = 0;
   while(1) {
    $24 = ((($LU) + (($indvars$iv*92)|0)|0) + ($indvars$iv58<<2)|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = ($indvars$iv|0)==(0);
    if ($26) {
     $sum$0$lcssa = $25;
    } else {
     $k$03 = 0;$sum$02 = $25;
     while(1) {
      $27 = ((($LU) + (($indvars$iv*92)|0)|0) + ($k$03<<2)|0);
      $28 = Math_fround(HEAPF32[$27>>2]);
      $29 = ((($LU) + (($k$03*92)|0)|0) + ($indvars$iv58<<2)|0);
      $30 = Math_fround(HEAPF32[$29>>2]);
      $31 = Math_fround($28 * $30);
      $32 = Math_fround($sum$02 - $31);
      $33 = (($k$03) + 1)|0;
      $exitcond = ($33|0)==($indvars$iv|0);
      if ($exitcond) {
       $sum$0$lcssa = $32;
       break;
      } else {
       $k$03 = $33;$sum$02 = $32;
      }
     }
    }
    HEAPF32[$24>>2] = $sum$0$lcssa;
    $indvars$iv$next = (($indvars$iv) + 1)|0;
    $exitcond51 = ($indvars$iv$next|0)==($indvars$iv58|0);
    if ($exitcond51) {
     break;
    } else {
     $indvars$iv = $indvars$iv$next;
    }
   }
   if ($23) {
    $big$115 = Math_fround(0.0);$i4$016 = 0;$imax$114 = $imax$031;
    label = 20;
   } else {
    $big$115$us = Math_fround(0.0);$i4$016$us = $indvars$iv58;$imax$114$us = $imax$031;
    while(1) {
     $35 = ((($LU) + (($i4$016$us*92)|0)|0) + ($indvars$iv58<<2)|0);
     $48 = Math_fround(HEAPF32[$35>>2]);
     $k6$08$us = 0;$sum5$07$us = $48;
     while(1) {
      $42 = ((($LU) + (($i4$016$us*92)|0)|0) + ($k6$08$us<<2)|0);
      $43 = Math_fround(HEAPF32[$42>>2]);
      $44 = ((($LU) + (($k6$08$us*92)|0)|0) + ($indvars$iv58<<2)|0);
      $45 = Math_fround(HEAPF32[$44>>2]);
      $46 = Math_fround($43 * $45);
      $34 = Math_fround($sum5$07$us - $46);
      $47 = (($k6$08$us) + 1)|0;
      $exitcond60 = ($47|0)==($indvars$iv58|0);
      if ($exitcond60) {
       break;
      } else {
       $k6$08$us = $47;$sum5$07$us = $34;
      }
     }
     HEAPF32[$35>>2] = $34;
     $36 = (($vv) + ($i4$016$us<<2)|0);
     $37 = Math_fround(HEAPF32[$36>>2]);
     $fabsf$i$i$us = (Math_fround(Math_abs((Math_fround($34)))));
     $38 = Math_fround($37 * $fabsf$i$i$us);
     $39 = !($38 >= $big$115$us);
     $imax$2$us = $39 ? $imax$114$us : $i4$016$us;
     $big$2$us = $39 ? $big$115$us : $38;
     $40 = (($i4$016$us) + 1)|0;
     $41 = ($40>>>0)>($12>>>0);
     if ($41) {
      $split20 = $imax$2$us;
      break;
     } else {
      $big$115$us = $big$2$us;$i4$016$us = $40;$imax$114$us = $imax$2$us;
     }
    }
   }
  }
  if ((label|0) == 20) {
   while(1) {
    label = 0;
    $49 = (($LU) + (($i4$016*92)|0)|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = (($vv) + ($i4$016<<2)|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $fabsf$i$i = (Math_fround(Math_abs((Math_fround($50)))));
    $53 = Math_fround($52 * $fabsf$i$i);
    $54 = !($53 >= $big$115);
    $imax$2 = $54 ? $imax$114 : $i4$016;
    $big$2 = $54 ? $big$115 : $53;
    $55 = (($i4$016) + 1)|0;
    $56 = ($55>>>0)>($12>>>0);
    if ($56) {
     $split20 = $imax$2;
     break;
    } else {
     $big$115 = $big$2;$i4$016 = $55;$imax$114 = $imax$2;
     label = 20;
    }
   }
  }
  $57 = ($indvars$iv58|0)==($split20|0);
  if (!($57)) {
   if (!($2)) {
    $k7$022 = 0;
    while(1) {
     $58 = ((($LU) + (($split20*92)|0)|0) + ($k7$022<<2)|0);
     $59 = Math_fround(HEAPF32[$58>>2]);
     $60 = ((($LU) + (($indvars$iv58*92)|0)|0) + ($k7$022<<2)|0);
     $61 = Math_fround(HEAPF32[$60>>2]);
     HEAPF32[$58>>2] = $61;
     HEAPF32[$60>>2] = $59;
     $62 = (($k7$022) + 1)|0;
     $exitcond52 = ($62|0)==($1|0);
     if ($exitcond52) {
      break;
     } else {
      $k7$022 = $62;
     }
    }
   }
   $63 = (($vv) + ($indvars$iv58<<2)|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = (($vv) + ($split20<<2)|0);
   HEAPF32[$65>>2] = $64;
  }
  $66 = (($this) + ($indvars$iv58<<2)|0);
  HEAP32[$66>>2] = $split20;
  $67 = ((($LU) + (($indvars$iv58*92)|0)|0) + ($indvars$iv58<<2)|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = $68 == Math_fround(0.0);
  if ($69) {
   HEAPF32[$67>>2] = Math_fround(9.99999968265522538896E-21);
   $72 = Math_fround(9.99999968265522538896E-21);
  } else {
   $72 = $68;
  }
  $70 = ($indvars$iv58|0)==($12|0);
  if ($70) {
   $indvars$iv$next59$pre = (($indvars$iv58) + 1)|0;
   $indvars$iv$next59$pre$phiZZZ2D = $indvars$iv$next59$pre;
  } else {
   $71 = Math_fround(Math_fround(1.0) / $72);
   $i8$026 = (($indvars$iv58) + 1)|0;
   $73 = ($i8$026>>>0)>($12>>>0);
   if ($73) {
    $indvars$iv$next59$pre$phiZZZ2D = $i8$026;
   } else {
    $i8$027 = $i8$026;
    while(1) {
     $74 = ((($LU) + (($i8$027*92)|0)|0) + ($indvars$iv58<<2)|0);
     $75 = Math_fround(HEAPF32[$74>>2]);
     $76 = Math_fround($71 * $75);
     HEAPF32[$74>>2] = $76;
     $i8$0 = (($i8$027) + 1)|0;
     $77 = ($i8$0>>>0)>($12>>>0);
     if ($77) {
      $indvars$iv$next59$pre$phiZZZ2D = $i8$026;
      break;
     } else {
      $i8$027 = $i8$0;
     }
    }
   }
  }
  $78 = ($indvars$iv$next59$pre$phiZZZ2D>>>0)>($12>>>0);
  if ($78) {
   break;
  } else {
   $imax$031 = $split20;$indvars$iv58 = $indvars$iv$next59$pre$phiZZZ2D;
  }
 }
 $79 = HEAP32[$80>>2]|0;
 $81 = ($79|0)==(0);
 if ($81) {
  $$lcssa$i = 0;
  $88 = (($this) + 2208|0);
  HEAP32[$88>>2] = $$lcssa$i;
  STACKTOP = sp;return;
 } else {
  $83 = $79;$i$02$i = 0;
 }
 while(1) {
  $82 = ($83|0)==(0);
  if ($82) {
   $87 = 0;
  } else {
   $scevgep46 = (($LU) + (($i$02$i*92)|0)|0);
   $scevgep = ((($this) + (($i$02$i*92)|0)|0) + 92|0);
   $84 = $83 << 2;
   _memcpy(($scevgep|0),($scevgep46|0),($84|0))|0;
   $87 = $83;
  }
  $85 = (($i$02$i) + 1)|0;
  $86 = ($85>>>0)<($87>>>0);
  if ($86) {
   $83 = $87;$i$02$i = $85;
  } else {
   $$lcssa$i = $87;
   break;
  }
 }
 $88 = (($this) + 2208|0);
 HEAP32[$88>>2] = $$lcssa$i;
 STACKTOP = sp;return;
}
function __ZNK5physx16MatrixNNLUSolver5solveERKNS_7VectorNERS1_($this,$input,$result) {
 $this = $this|0;
 $input = $input|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond19 = 0, $i$01$i = 0, $i$013 = 0, $i1$04 = 0, $ii$012 = 0, $ii$1 = 0, $j$09 = 0, $j2$0 = 0, $j2$01 = 0, $j2$03 = 0, $sum$08 = Math_fround(0), $sum$1 = Math_fround(0), $sum$2$lcssa = Math_fround(0), $sum$22 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($input) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($result) + 92|0);
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $i$01$i = 0;
 }
 while(1) {
  $4 = (($input) + ($i$01$i<<2)|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($result) + ($i$01$i<<2)|0);
  HEAPF32[$6>>2] = $5;
  $7 = (($i$01$i) + 1)|0;
  $exitcond19 = ($7|0)==($1|0);
  if ($exitcond19) {
   break;
  } else {
   $i$01$i = $7;
  }
 }
 $8 = (($result) + 92|0);
 HEAP32[$8>>2] = $1;
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $i$013 = 0;$ii$012 = -1;
 }
 while(1) {
  $9 = (($this) + ($i$013<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($result) + ($10<<2)|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($result) + ($i$013<<2)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$11>>2] = $14;
  $15 = ($ii$012|0)==(-1);
  if ($15) {
   $26 = $12 != Math_fround(0.0);
   if ($26) {
    $ii$1 = $i$013;$sum$1 = $12;
   } else {
    $ii$1 = -1;$sum$1 = $12;
   }
  } else {
   $16 = (($i$013) + -1)|0;
   $17 = ($ii$012>>>0)>($16>>>0);
   if ($17) {
    $ii$1 = $ii$012;$sum$1 = $12;
   } else {
    $j$09 = $ii$012;$sum$08 = $12;
    while(1) {
     $18 = (((($this) + (($i$013*92)|0)|0) + ($j$09<<2)|0) + 92|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($result) + ($j$09<<2)|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($19 * $21);
     $23 = Math_fround($sum$08 - $22);
     $24 = (($j$09) + 1)|0;
     $25 = ($24>>>0)>($16>>>0);
     if ($25) {
      $ii$1 = $ii$012;$sum$1 = $23;
      break;
     } else {
      $j$09 = $24;$sum$08 = $23;
     }
    }
   }
  }
  HEAPF32[$13>>2] = $sum$1;
  $27 = (($i$013) + 1)|0;
  $exitcond = ($27|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$013 = $27;$ii$012 = $ii$1;
  }
 }
 $28 = (($1) + -1)|0;
 $29 = ($28|0)>(-1);
 if ($29) {
  $i1$04 = $28;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $30 = (($result) + ($i1$04<<2)|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $j2$01 = (($i1$04) + 1)|0;
  $32 = ($j2$01>>>0)>($28>>>0);
  if ($32) {
   $sum$2$lcssa = $31;
  } else {
   $j2$03 = $j2$01;$sum$22 = $31;
   while(1) {
    $33 = (((($this) + (($i1$04*92)|0)|0) + ($j2$03<<2)|0) + 92|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($result) + ($j2$03<<2)|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = Math_fround($34 * $36);
    $38 = Math_fround($sum$22 - $37);
    $j2$0 = (($j2$03) + 1)|0;
    $39 = ($j2$0>>>0)>($28>>>0);
    if ($39) {
     $sum$2$lcssa = $38;
     break;
    } else {
     $j2$03 = $j2$0;$sum$22 = $38;
    }
   }
  }
  $40 = (((($this) + (($i1$04*92)|0)|0) + ($i1$04<<2)|0) + 92|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($sum$2$lcssa / $41);
  HEAPF32[$30>>2] = $42;
  $43 = (($i1$04) + -1)|0;
  $44 = ($i1$04|0)>(0);
  if ($44) {
   $i1$04 = $43;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx12processGearsEfRKNS_18PxVehicleGearsDataERNS_21PxVehicleDriveDynDataE($timestep,$gears,$car) {
 $timestep = Math_fround($timestep);
 $gears = $gears|0;
 $car = $car|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($car) + 65|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if (!($2)) {
   $3 = (($gears) + 132|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + -1)|0;
   $6 = (($car) + 68|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5|0)==($7|0);
   if (!($8)) {
    $9 = (($car) + 72|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($7|0)==($10|0);
    if ($11) {
     $12 = ($7|0)==(0);
     if ($12) {
      $13 = (($car) + 80|0);
      HEAPF32[$13>>2] = Math_fround(0.0);
      HEAP32[$9>>2] = 2;
      HEAP32[$6>>2] = 1;
      break;
     }
     $14 = ($7|0)==(1);
     $15 = (($car) + 80|0);
     HEAPF32[$15>>2] = Math_fround(0.0);
     if ($14) {
      HEAP32[$9>>2] = 2;
      HEAP32[$6>>2] = 1;
      break;
     } else {
      $16 = (($7) + 1)|0;
      HEAP32[$9>>2] = $16;
      HEAP32[$6>>2] = 1;
      break;
     }
    }
   }
  }
 } while(0);
 $17 = (($car) + 66|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 $$phi$trans$insert = (($car) + 68|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 do {
  if ($19) {
   $33 = $$pre;
  } else {
   $20 = ($$pre|0)==(0);
   if ($20) {
    $33 = 0;
   } else {
    $21 = (($car) + 72|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($$pre|0)==($22|0);
    if ($23) {
     $24 = ($$pre|0)==(2);
     if ($24) {
      $25 = (($car) + 80|0);
      HEAPF32[$25>>2] = Math_fround(0.0);
      HEAP32[$21>>2] = 0;
      HEAP32[$$phi$trans$insert>>2] = 1;
      $33 = 1;
      break;
     }
     $26 = ($$pre|0)==(1);
     $27 = (($car) + 80|0);
     HEAPF32[$27>>2] = Math_fround(0.0);
     if ($26) {
      HEAP32[$21>>2] = 0;
      HEAP32[$$phi$trans$insert>>2] = 1;
      $33 = 1;
      break;
     } else {
      $28 = (($$pre) + -1)|0;
      HEAP32[$21>>2] = $28;
      HEAP32[$$phi$trans$insert>>2] = 1;
      $33 = 1;
      break;
     }
    } else {
     $33 = $$pre;
    }
   }
  }
 } while(0);
 $29 = (($car) + 68|0);
 $30 = (($car) + 72|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($33|0)==($31|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $34 = (($car) + 80|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($gears) + 136|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = $35 > $37;
 if ($38) {
  HEAP32[$29>>2] = $31;
  HEAPF32[$34>>2] = Math_fround(0.0);
  HEAP8[$17>>0] = 0;
  HEAP8[$0>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $39 = Math_fround($35 + $timestep);
  HEAPF32[$34>>2] = $39;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15computeTankDiffEffjPKbPfS2_S2_($thrustLeft,$thrustRight,$numActiveWheels,$activeWheelStates,$aveWheelSpeedContributions,$diffTorqueRatios,$wheelGearings) {
 $thrustLeft = Math_fround($thrustLeft);
 $thrustRight = Math_fround($thrustRight);
 $numActiveWheels = $numActiveWheels|0;
 $activeWheelStates = $activeWheelStates|0;
 $aveWheelSpeedContributions = $aveWheelSpeedContributions|0;
 $diffTorqueRatios = $diffTorqueRatios|0;
 $wheelGearings = $wheelGearings|0;
 var $$pn = Math_fround(0), $$pn18 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $fabsf$i$i = Math_fround(0);
 var $fabsf$i$i1 = Math_fround(0), $i$012 = 0, $i1$07 = 0, $i2$04 = 0, $i3$03 = 0, $numLeftWheels$013 = Math_fround(0), $numLeftWheels$1 = Math_fround(0), $numRightWheels$08 = Math_fround(0), $numRightWheels$1 = Math_fround(0), $wheelGearingLeft$0 = Math_fround(0), $wheelGearingRight$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($thrustLeft)))));
 $fabsf$i$i1 = (Math_fround(Math_abs((Math_fround($thrustRight)))));
 $0 = ($numActiveWheels|0)==(0);
 if ($0) {
  $34 = Math_fround(0.0);$36 = Math_fround(0.0);$55 = 0;
 } else {
  $i$012 = 0;$numLeftWheels$013 = Math_fround(0.0);
  while(1) {
   $1 = (($activeWheelStates) + ($i$012)|0);
   $2 = HEAP8[$1>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    $numLeftWheels$1 = $numLeftWheels$013;
   } else {
    $4 = Math_fround($numLeftWheels$013 + Math_fround(1.0));
    $numLeftWheels$1 = $4;
   }
   $5 = (($i$012) + 2)|0;
   $6 = ($5>>>0)<($numActiveWheels>>>0);
   if ($6) {
    $i$012 = $5;$numLeftWheels$013 = $numLeftWheels$1;
   } else {
    break;
   }
  }
  $7 = $numLeftWheels$1 > Math_fround(0.0);
  if ($7) {
   $8 = Math_fround(Math_fround(1.0) / $numLeftWheels$1);
   $56 = $8;
  } else {
   $56 = Math_fround(0.0);
  }
  $9 = ($numActiveWheels>>>0)>(1);
  if ($9) {
   $i1$07 = 1;$numRightWheels$08 = Math_fround(0.0);
   while(1) {
    $10 = (($activeWheelStates) + ($i1$07)|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = ($11<<24>>24)==(0);
    if ($12) {
     $numRightWheels$1 = $numRightWheels$08;
    } else {
     $13 = Math_fround($numRightWheels$08 + Math_fround(1.0));
     $numRightWheels$1 = $13;
    }
    $14 = (($i1$07) + 2)|0;
    $15 = ($14>>>0)<($numActiveWheels>>>0);
    if ($15) {
     $i1$07 = $14;$numRightWheels$08 = $numRightWheels$1;
    } else {
     break;
    }
   }
   $16 = $numRightWheels$1 > Math_fround(0.0);
   if ($16) {
    $17 = Math_fround(Math_fround(1.0) / $numRightWheels$1);
    $34 = $56;$36 = $17;$55 = $9;
   } else {
    $34 = $56;$36 = Math_fround(0.0);$55 = $9;
   }
  } else {
   $34 = $56;$36 = Math_fround(0.0);$55 = 0;
  }
 }
 $18 = Math_fround($fabsf$i$i + $fabsf$i$i1);
 $19 = $18 > Math_fround(0.00100000004749745130539);
 if ($19) {
  $20 = Math_fround($fabsf$i$i - $fabsf$i$i1);
  $21 = Math_fround($20 * Math_fround(0.5));
  $22 = Math_fround($21 / $18);
  $23 = Math_fround($22 + Math_fround(0.5));
  $24 = Math_fround(Math_fround(0.5) - $22);
  $25 = $thrustLeft <= Math_fround(-0.0);
  $26 = $25 ? Math_fround(0.0) : Math_fround(1.0);
  $27 = $thrustLeft >= Math_fround(0.0);
  $28 = $27 ? $26 : Math_fround(-1.0);
  $29 = $thrustRight <= Math_fround(-0.0);
  $30 = $29 ? Math_fround(0.0) : Math_fround(1.0);
  $31 = $thrustRight >= Math_fround(0.0);
  $32 = $31 ? $30 : Math_fround(-1.0);
  $$pn = $24;$$pn18 = $23;$wheelGearingLeft$0 = $28;$wheelGearingRight$0 = $32;
 } else {
  $$pn = Math_fround(0.5);$$pn18 = Math_fround(0.5);$wheelGearingLeft$0 = Math_fround(1.0);$wheelGearingRight$0 = Math_fround(1.0);
 }
 $33 = Math_fround($34 * $$pn18);
 $35 = Math_fround($36 * $$pn);
 $37 = Math_fround($34 * Math_fround(0.5));
 $38 = Math_fround($36 * Math_fround(0.5));
 if (!($0)) {
  $i2$04 = 0;
  while(1) {
   $39 = (($activeWheelStates) + ($i2$04)|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if (!($41)) {
    $42 = (($aveWheelSpeedContributions) + ($i2$04<<2)|0);
    HEAPF32[$42>>2] = $37;
    $43 = (($diffTorqueRatios) + ($i2$04<<2)|0);
    HEAPF32[$43>>2] = $33;
    $44 = (($wheelGearings) + ($i2$04<<2)|0);
    HEAPF32[$44>>2] = $wheelGearingLeft$0;
   }
   $45 = (($i2$04) + 2)|0;
   $46 = ($45>>>0)<($numActiveWheels>>>0);
   if ($46) {
    $i2$04 = $45;
   } else {
    break;
   }
  }
 }
 if ($55) {
  $i3$03 = 1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $47 = (($activeWheelStates) + ($i3$03)|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48<<24>>24)==(0);
  if (!($49)) {
   $50 = (($aveWheelSpeedContributions) + ($i3$03<<2)|0);
   HEAPF32[$50>>2] = $38;
   $51 = (($diffTorqueRatios) + ($i3$03<<2)|0);
   HEAPF32[$51>>2] = $35;
   $52 = (($wheelGearings) + ($i3$03<<2)|0);
   HEAPF32[$52>>2] = $wheelGearingRight$0;
  }
  $53 = (($i3$03) + 2)|0;
  $54 = ($53>>>0)<($numActiveWheels>>>0);
  if ($54) {
   $i3$03 = $53;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx32PxVehicleComputeTireForceDefaultEPKvffffffffffffRfS2_S2_S2_($tireShaderData,$tireFriction,$longSlip,$latSlip,$camber,$wheelOmega,$wheelRadius,$recipWheelRadius,$restTireLoad,$normalisedTireLoad,$tireLoad,$gravity,$recipGravity,$wheelTorque,$tireLongForceMag,$tireLatForceMag,$tireAlignMoment) {
 $tireShaderData = $tireShaderData|0;
 $tireFriction = Math_fround($tireFriction);
 $longSlip = Math_fround($longSlip);
 $latSlip = Math_fround($latSlip);
 $camber = Math_fround($camber);
 $wheelOmega = Math_fround($wheelOmega);
 $wheelRadius = Math_fround($wheelRadius);
 $recipWheelRadius = Math_fround($recipWheelRadius);
 $restTireLoad = Math_fround($restTireLoad);
 $normalisedTireLoad = Math_fround($normalisedTireLoad);
 $tireLoad = Math_fround($tireLoad);
 $gravity = Math_fround($gravity);
 $recipGravity = Math_fround($recipGravity);
 $wheelTorque = $wheelTorque|0;
 $tireLongForceMag = $tireLongForceMag|0;
 $tireLatForceMag = $tireLatForceMag|0;
 $tireAlignMoment = $tireAlignMoment|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0.0, $29 = 0.0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $9 = Math_fround(0), $nu$0 = Math_fround(0), $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$wheelTorque>>2] = Math_fround(0.0);
 HEAPF32[$tireLongForceMag>>2] = Math_fround(0.0);
 HEAPF32[$tireLatForceMag>>2] = Math_fround(0.0);
 HEAPF32[$tireAlignMoment>>2] = Math_fround(0.0);
 $0 = $latSlip == Math_fround(0.0);
 $1 = $longSlip == Math_fround(0.0);
 $or$cond = $0 & $1;
 $2 = $camber == Math_fround(0.0);
 $or$cond1 = $or$cond & $2;
 if ($or$cond1) {
  STACKTOP = sp;return;
 }
 $3 = (($tireShaderData) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $restTireLoad);
 $6 = Math_fround($normalisedTireLoad * Math_fround(3.0));
 $7 = Math_fround(HEAPF32[$tireShaderData>>2]);
 $8 = Math_fround($6 / $7);
 $9 = Math_fround($8 * Math_fround(0.333330005407333374023));
 $10 = Math_fround($8 * $9);
 $11 = Math_fround($8 - $10);
 $12 = Math_fround($8 * Math_fround(0.0370370000600814819336));
 $13 = Math_fround($8 * $12);
 $14 = Math_fround($8 * $13);
 $15 = Math_fround($11 + $14);
 $16 = $15 > Math_fround(1.0);
 $17 = $16 ? Math_fround(1.0) : $15;
 $18 = Math_fround($5 * $17);
 $19 = (($tireShaderData) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $gravity);
 $22 = (($tireShaderData) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $gravity);
 $25 = Math_fround($24 * $camber);
 $26 = Math_fround($25 / $18);
 $27 = Math_fround($latSlip - $26);
 $28 = +$27;
 $29 = (+Math_tan((+$28)));
 $30 = Math_fround($29);
 $31 = Math_fround($30 * $18);
 $32 = Math_fround($18 * $31);
 $33 = Math_fround($30 * $32);
 $34 = Math_fround($21 * $longSlip);
 $35 = Math_fround($21 * $34);
 $36 = Math_fround($35 * $longSlip);
 $37 = Math_fround($36 + $33);
 $38 = (Math_fround(Math_sqrt((Math_fround($37)))));
 $39 = Math_fround($tireFriction * $tireLoad);
 $40 = Math_fround($38 / $39);
 $41 = Math_fround($40 * Math_fround(0.333330005407333374023));
 $42 = Math_fround($40 * $41);
 $43 = Math_fround($40 - $42);
 $44 = Math_fround($40 * Math_fround(0.0370370000600814819336));
 $45 = Math_fround($40 * $44);
 $46 = Math_fround($40 * $45);
 $47 = Math_fround($43 + $46);
 $48 = $47 > Math_fround(1.0);
 $49 = $48 ? Math_fround(1.0) : $47;
 $50 = Math_fround($40 * $40);
 $51 = Math_fround($40 - $50);
 $52 = Math_fround($40 * $42);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($40 * $46);
 $55 = Math_fround($53 - $54);
 $56 = !($40 <= Math_fround(6.28318548202514648438));
 if ($56) {
  $nu$0 = Math_fround(1.0);
 } else {
  $57 = (($tireShaderData) + 44|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($58 * $recipGravity);
  $60 = Math_fround($18 * $59);
  $61 = Math_fround($60 + Math_fround(1.0));
  $62 = Math_fround(Math_fround(1.0) - $60);
  $63 = Math_fround($40 * Math_fround(0.5));
  $64 = (Math_fround(+(Math_cos((+$63)))));
  $65 = Math_fround($64 * $62);
  $66 = Math_fround($61 - $65);
  $67 = Math_fround($66 * Math_fround(0.5));
  $nu$0 = $67;
 }
 $68 = Math_fround($longSlip * $longSlip);
 $69 = Math_fround($30 * $nu$0);
 $70 = Math_fround($nu$0 * $69);
 $71 = Math_fround($30 * $70);
 $72 = Math_fround($68 + $71);
 $73 = (Math_fround(Math_sqrt((Math_fround($72)))));
 $74 = Math_fround($39 / $73);
 $75 = Math_fround($49 * $longSlip);
 $76 = Math_fround($75 * $74);
 $77 = Math_fround($49 * $69);
 $78 = Math_fround($77 * $74);
 $79 = Math_fround(-$78);
 $80 = Math_fround($55 * $69);
 $81 = Math_fround($80 * $74);
 $82 = Math_fround($76 * $wheelRadius);
 $83 = Math_fround(-$82);
 HEAPF32[$wheelTorque>>2] = $83;
 HEAPF32[$tireLongForceMag>>2] = $76;
 HEAPF32[$tireLatForceMag>>2] = $79;
 HEAPF32[$tireAlignMoment>>2] = $81;
 STACKTOP = sp;return;
}
function __ZN5physx21processSuspTireWheelsEjRKNS_29ProcessSuspWheelTireConstDataERKNS_29ProcessSuspWheelTireInputDataERNS_30ProcessSuspWheelTireOutputDataE($startWheelIndex,$constData,$inputData,$outputData) {
 $startWheelIndex = $startWheelIndex|0;
 $constData = $constData|0;
 $inputData = $inputData|0;
 $outputData = $outputData|0;
 var $$0$i = Math_fround(0), $$not$i = 0, $$not$i14 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0);
 var $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = 0, $102 = Math_fround(0), $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0;
 var $103 = Math_fround(0), $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = Math_fround(0), $1040 = 0, $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0;
 var $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = 0, $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = 0, $1056 = Math_fround(0), $1057 = 0, $1058 = Math_fround(0), $1059 = 0, $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = 0, $1062 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0);
 var $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = 0;
 var $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = 0;
 var $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0;
 var $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0;
 var $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0);
 var $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0;
 var $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0);
 var $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0);
 var $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = 0, $47 = Math_fround(0);
 var $470 = Math_fround(0), $471 = 0, $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = 0, $503 = Math_fround(0), $504 = 0, $505 = 0;
 var $506 = Math_fround(0), $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = Math_fround(0), $513 = 0, $514 = 0, $515 = Math_fround(0), $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = 0, $522 = Math_fround(0), $523 = 0;
 var $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = 0, $53 = Math_fround(0), $530 = Math_fround(0), $531 = 0, $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = 0, $536 = Math_fround(0), $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0;
 var $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = Math_fround(0);
 var $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0);
 var $597 = Math_fround(0), $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = 0, $602 = Math_fround(0), $603 = Math_fround(0), $604 = 0, $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = 0, $613 = Math_fround(0);
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0);
 var $632 = Math_fround(0), $633 = Math_fround(0), $634 = 0, $635 = Math_fround(0), $636 = Math_fround(0), $637 = 0, $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = 0, $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0;
 var $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0);
 var $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0);
 var $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0);
 var $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = 0, $711 = Math_fround(0), $712 = 0, $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = Math_fround(0), $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = 0, $734 = 0, $735 = 0, $736 = Math_fround(0), $737 = 0, $738 = Math_fround(0), $739 = 0, $74 = Math_fround(0);
 var $740 = Math_fround(0), $741 = 0, $742 = Math_fround(0), $743 = 0, $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = 0, $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = 0, $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0);
 var $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = 0, $762 = Math_fround(0), $763 = Math_fround(0), $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = Math_fround(0), $770 = 0, $771 = 0, $772 = Math_fround(0), $773 = Math_fround(0), $774 = 0, $775 = Math_fround(0), $776 = 0;
 var $777 = Math_fround(0), $778 = 0, $779 = Math_fround(0), $78 = Math_fround(0), $780 = 0, $781 = Math_fround(0), $782 = 0, $783 = Math_fround(0), $784 = 0, $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0);
 var $795 = 0, $796 = 0, $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = 0.0, $804 = 0.0, $805 = Math_fround(0), $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0;
 var $812 = 0, $813 = 0, $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = 0, $82 = Math_fround(0), $820 = Math_fround(0), $821 = 0, $822 = Math_fround(0), $823 = Math_fround(0), $824 = 0, $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0);
 var $830 = 0, $831 = Math_fround(0), $832 = Math_fround(0), $833 = 0, $834 = Math_fround(0), $835 = 0, $836 = 0, $837 = Math_fround(0), $838 = 0, $839 = 0, $84 = Math_fround(0), $840 = Math_fround(0), $841 = Math_fround(0), $842 = 0, $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = 0, $847 = Math_fround(0), $848 = Math_fround(0);
 var $849 = 0, $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = 0, $854 = Math_fround(0), $855 = 0, $856 = Math_fround(0), $857 = 0, $858 = Math_fround(0), $859 = 0, $86 = Math_fround(0), $860 = Math_fround(0), $861 = 0, $862 = Math_fround(0), $863 = 0, $864 = 0, $865 = 0, $866 = Math_fround(0);
 var $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = 0, $874 = Math_fround(0), $875 = 0, $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = 0, $883 = Math_fround(0), $884 = 0;
 var $885 = 0, $886 = Math_fround(0), $887 = Math_fround(0), $888 = 0, $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = 0, $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0);
 var $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = Math_fround(0);
 var $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = 0, $93 = Math_fround(0), $930 = Math_fround(0), $931 = Math_fround(0), $932 = 0, $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = 0, $937 = Math_fround(0), $938 = Math_fround(0);
 var $939 = Math_fround(0), $94 = Math_fround(0), $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = 0, $949 = 0, $95 = Math_fround(0), $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = Math_fround(0);
 var $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = Math_fround(0), $960 = 0, $961 = 0, $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0;
 var $975 = 0, $976 = 0, $977 = 0, $978 = Math_fround(0), $979 = Math_fround(0), $98 = Math_fround(0), $980 = Math_fround(0), $981 = Math_fround(0), $982 = 0, $983 = 0, $984 = 0, $985 = Math_fround(0), $986 = 0, $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = Math_fround(0), $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0);
 var $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $brmerge$i = 0, $brmerge$i10 = 0, $brmerge$i15 = 0, $brmerge$not$i = 0, $camber$0 = Math_fround(0), $dynamicHitActor$0 = 0, $exitcond = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i13 = Math_fround(0), $fabsf$i$i$i21 = Math_fround(0), $fabsf$i$i$i24 = Math_fround(0), $fabsf$i$i2 = Math_fround(0);
 var $fabsf$i$i2$i = Math_fround(0), $hitContactActors4 = 0, $hitContactMaterials4 = 0, $hitContactNormals4 = 0, $hitContactPoints4 = 0, $hitContactShapes4 = 0, $hitCounts4 = 0, $hitDistances4 = 0, $hitFrictionMultipliers4 = 0, $hitNorm4 = 0, $hitPlanes4 = 0, $hitSurfaceTypes4 = 0, $i$094 = 0, $i1$090 = 0, $i2$088 = 0, $id$0$i = 0, $id$02$i = 0, $id$03$i = 0, $latDir = 0, $mu$0$i = Math_fround(0);
 var $notlhs = 0, $notlhs$i = 0, $notrhs = 0, $notrhs$i = 0, $or$cond$i = 0, $or$cond$i25 = 0, $or$cond$not = 0, $or$cond$not$i = 0, $or$cond1 = 0, $or$cond1$i = 0, $storemerge$i16 = Math_fround(0), $storemerge$i83 = Math_fround(0), $surfaceType$0 = 0, $surfaceTypeHashTable = 0, $tireAlignMoment = 0, $tireLatDir = 0, $tireLatForceMag = 0, $tireLongDir = 0, $tireLongForceMag = 0, $wheelBottomPos = 0;
 var $wheelTorque = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2432|0;
 $latDir = sp + 2416|0;
 $hitCounts4 = sp + 2400|0;
 $hitDistances4 = sp + 2384|0;
 $hitPlanes4 = sp + 2320|0;
 $hitFrictionMultipliers4 = sp + 2304|0;
 $hitContactShapes4 = sp + 2288|0;
 $hitContactActors4 = sp + 2272|0;
 $hitContactMaterials4 = sp + 2256|0;
 $hitSurfaceTypes4 = sp + 2240|0;
 $hitContactPoints4 = sp + 2192|0;
 $hitContactNormals4 = sp + 2104|0;
 $surfaceTypeHashTable = sp;
 $hitNorm4 = sp + 2064|0;
 $wheelBottomPos = sp + 2076|0;
 $0 = sp + 2088|0;
 $1 = sp + 2428|0;
 $tireLongDir = sp + 2152|0;
 $tireLatDir = sp + 2164|0;
 $wheelTorque = sp + 2176|0;
 $tireLongForceMag = sp + 2180|0;
 $tireLatForceMag = sp + 2184|0;
 $tireAlignMoment = sp + 2188|0;
 $2 = HEAP32[523960>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (523960 + ($startWheelIndex<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  HEAPF32[$5>>2] = Math_fround(0.0);
  $6 = (($startWheelIndex) + 1)|0;
  $7 = (523960 + ($6<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  HEAPF32[$8>>2] = Math_fround(0.0);
  $9 = (($startWheelIndex) + 2)|0;
  $10 = (523960 + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  HEAPF32[$11>>2] = Math_fround(0.0);
  $12 = (($startWheelIndex) + 3)|0;
  $13 = (523960 + ($12<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  HEAPF32[$14>>2] = Math_fround(0.0);
  $15 = (($5) + 4|0);
  HEAPF32[$15>>2] = Math_fround(0.0);
  $16 = (($8) + 4|0);
  HEAPF32[$16>>2] = Math_fround(0.0);
  $17 = (($11) + 4|0);
  HEAPF32[$17>>2] = Math_fround(0.0);
  $18 = (($14) + 4|0);
  HEAPF32[$18>>2] = Math_fround(0.0);
  $19 = (($5) + 8|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = (($8) + 8|0);
  HEAPF32[$20>>2] = Math_fround(0.0);
  $21 = (($11) + 8|0);
  HEAPF32[$21>>2] = Math_fround(0.0);
  $22 = (($14) + 8|0);
  HEAPF32[$22>>2] = Math_fround(0.0);
  $23 = (($5) + 12|0);
  HEAPF32[$23>>2] = Math_fround(0.0);
  $24 = (($8) + 12|0);
  HEAPF32[$24>>2] = Math_fround(0.0);
  $25 = (($11) + 12|0);
  HEAPF32[$25>>2] = Math_fround(0.0);
  $26 = (($14) + 12|0);
  HEAPF32[$26>>2] = Math_fround(0.0);
  $27 = (($5) + 28|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  $28 = (($8) + 28|0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  $29 = (($11) + 28|0);
  HEAPF32[$29>>2] = Math_fround(0.0);
  $30 = (($14) + 28|0);
  HEAPF32[$30>>2] = Math_fround(0.0);
  $31 = (($5) + 36|0);
  HEAPF32[$31>>2] = Math_fround(0.0);
  $32 = (($8) + 36|0);
  HEAPF32[$32>>2] = Math_fround(0.0);
  $33 = (($11) + 36|0);
  HEAPF32[$33>>2] = Math_fround(0.0);
  $34 = (($14) + 36|0);
  HEAPF32[$34>>2] = Math_fround(0.0);
  $35 = (($5) + 24|0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  $36 = (($8) + 24|0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $37 = (($11) + 24|0);
  HEAPF32[$37>>2] = Math_fround(0.0);
  $38 = (($14) + 24|0);
  HEAPF32[$38>>2] = Math_fround(0.0);
  $39 = (($5) + 32|0);
  HEAPF32[$39>>2] = Math_fround(0.0);
  $40 = (($8) + 32|0);
  HEAPF32[$40>>2] = Math_fround(0.0);
  $41 = (($11) + 32|0);
  HEAPF32[$41>>2] = Math_fround(0.0);
  $42 = (($14) + 32|0);
  HEAPF32[$42>>2] = Math_fround(0.0);
  $43 = (($5) + 20|0);
  HEAPF32[$43>>2] = Math_fround(0.0);
  $44 = (($8) + 20|0);
  HEAPF32[$44>>2] = Math_fround(0.0);
  $45 = (($11) + 20|0);
  HEAPF32[$45>>2] = Math_fround(0.0);
  $46 = (($14) + 20|0);
  HEAPF32[$46>>2] = Math_fround(0.0);
 }
 $47 = Math_fround(HEAPF32[$constData>>2]);
 $48 = (($constData) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($constData) + 24|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($constData) + 20|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($constData) + 28|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = (($constData) + 32|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($inputData) + 72|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($inputData) + 76|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($inputData) + 80|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($inputData) + 84|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = Math_fround(Math_fround(1.0) * Math_fround(2.0));
 $67 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $68 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $69 = (($inputData) + 32|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $70);
 $72 = Math_fround($71 + Math_fround(-0.5));
 $73 = (($inputData) + 20|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($66 * $74);
 $76 = (($inputData) + 24|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($67 * $77);
 $79 = Math_fround($75 + $78);
 $80 = (($inputData) + 28|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($68 * $81);
 $83 = Math_fround($79 + $82);
 $84 = Math_fround($66 * $72);
 $85 = Math_fround($68 * $77);
 $86 = Math_fround($67 * $81);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($70 * $87);
 $89 = Math_fround($84 + $88);
 $90 = Math_fround($74 * $83);
 $91 = Math_fround($90 + $89);
 $92 = Math_fround($67 * $72);
 $93 = Math_fround($66 * $81);
 $94 = Math_fround($68 * $74);
 $95 = Math_fround($93 - $94);
 $96 = Math_fround($70 * $95);
 $97 = Math_fround($92 + $96);
 $98 = Math_fround($77 * $83);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($68 * $72);
 $101 = Math_fround($67 * $74);
 $102 = Math_fround($66 * $77);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($70 * $103);
 $105 = Math_fround($100 + $104);
 $106 = Math_fround($81 * $83);
 $107 = Math_fround($105 + $106);
 HEAPF32[$latDir>>2] = $91;
 $108 = (($latDir) + 4|0);
 HEAPF32[$108>>2] = $99;
 $109 = (($latDir) + 8|0);
 HEAPF32[$109>>2] = $107;
 $110 = HEAP8[$inputData>>0]|0;
 $111 = (($inputData) + 12|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = (($inputData) + 8|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (($inputData) + 4|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($inputData) + 16|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = ($55<<24>>24)==(0);
 $120 = ($110<<24>>24)!=(0);
 $121 = (($61) + 196|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($122|0)==(0|0);
 $124 = (($inputData) + 88|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0);
 if ($123) {
  if (!($126)) {
   $274 = (($61) + 80|0);
   $275 = (($61) + 176|0);
   $276 = (($61) + 160|0);
   $277 = (($61) + 144|0);
   $i1$090 = 0;
   while(1) {
    $278 = (($275) + ($i1$090<<1)|0);
    $279 = HEAP16[$278>>1]|0;
    $280 = $279&65535;
    $281 = (($hitCounts4) + ($i1$090<<2)|0);
    HEAP32[$281>>2] = $280;
    $282 = (($276) + ($i1$090<<2)|0);
    $283 = Math_fround(HEAPF32[$282>>2]);
    $284 = (($hitDistances4) + ($i1$090<<2)|0);
    HEAPF32[$284>>2] = $283;
    $285 = (($274) + ($i1$090<<4)|0);
    $286 = Math_fround(HEAPF32[$285>>2]);
    $287 = (($hitPlanes4) + ($i1$090<<4)|0);
    HEAPF32[$287>>2] = $286;
    $288 = ((($274) + ($i1$090<<4)|0) + 4|0);
    $289 = Math_fround(HEAPF32[$288>>2]);
    $290 = ((($hitPlanes4) + ($i1$090<<4)|0) + 4|0);
    HEAPF32[$290>>2] = $289;
    $291 = ((($274) + ($i1$090<<4)|0) + 8|0);
    $292 = Math_fround(HEAPF32[$291>>2]);
    $293 = ((($hitPlanes4) + ($i1$090<<4)|0) + 8|0);
    HEAPF32[$293>>2] = $292;
    $294 = ((($274) + ($i1$090<<4)|0) + 12|0);
    $295 = Math_fround(HEAPF32[$294>>2]);
    $296 = ((($hitPlanes4) + ($i1$090<<4)|0) + 12|0);
    HEAPF32[$296>>2] = $295;
    $297 = (($277) + ($i1$090<<2)|0);
    $298 = Math_fround(HEAPF32[$297>>2]);
    $299 = (($hitFrictionMultipliers4) + ($i1$090<<2)|0);
    HEAPF32[$299>>2] = $298;
    $300 = (($hitContactShapes4) + ($i1$090<<2)|0);
    HEAP32[$300>>2] = 0;
    $301 = (($hitContactActors4) + ($i1$090<<2)|0);
    HEAP32[$301>>2] = 0;
    $302 = (($hitContactMaterials4) + ($i1$090<<2)|0);
    HEAP32[$302>>2] = 0;
    $303 = (($hitSurfaceTypes4) + ($i1$090<<2)|0);
    HEAP32[$303>>2] = -1;
    $304 = (($hitContactPoints4) + (($i1$090*12)|0)|0);
    HEAPF32[$304>>2] = Math_fround(0.0);
    $305 = ((($hitContactPoints4) + (($i1$090*12)|0)|0) + 4|0);
    HEAPF32[$305>>2] = Math_fround(0.0);
    $306 = ((($hitContactPoints4) + (($i1$090*12)|0)|0) + 8|0);
    HEAPF32[$306>>2] = Math_fround(0.0);
    $307 = (($hitContactNormals4) + (($i1$090*12)|0)|0);
    HEAPF32[$307>>2] = Math_fround(0.0);
    $308 = ((($hitContactNormals4) + (($i1$090*12)|0)|0) + 4|0);
    HEAPF32[$308>>2] = Math_fround(0.0);
    $309 = ((($hitContactNormals4) + (($i1$090*12)|0)|0) + 8|0);
    HEAPF32[$309>>2] = Math_fround(0.0);
    $310 = ((($outputData) + ($i1$090<<2)|0) + 888|0);
    HEAP32[$310>>2] = $280;
    $311 = ((($outputData) + ($i1$090<<4)|0) + 904|0);
    HEAPF32[$311>>2] = $286;
    $312 = Math_fround(HEAPF32[$288>>2]);
    $313 = ((($outputData) + ($i1$090<<4)|0) + 908|0);
    HEAPF32[$313>>2] = $312;
    $314 = Math_fround(HEAPF32[$291>>2]);
    $315 = ((($outputData) + ($i1$090<<4)|0) + 912|0);
    HEAPF32[$315>>2] = $314;
    $316 = Math_fround(HEAPF32[$294>>2]);
    $317 = ((($outputData) + ($i1$090<<4)|0) + 916|0);
    HEAPF32[$317>>2] = $316;
    $318 = Math_fround(HEAPF32[$282>>2]);
    $319 = ((($outputData) + ($i1$090<<2)|0) + 968|0);
    HEAPF32[$319>>2] = $318;
    $320 = Math_fround(HEAPF32[$297>>2]);
    $321 = ((($outputData) + ($i1$090<<2)|0) + 984|0);
    HEAPF32[$321>>2] = $320;
    $322 = (($i1$090) + 1)|0;
    $323 = HEAP32[$124>>2]|0;
    $324 = ($322>>>0)<($323>>>0);
    if ($324) {
     $i1$090 = $322;
    } else {
     break;
    }
   }
  }
 } else {
  if (!($126)) {
   $127 = (($constData) + 40|0);
   $128 = (($surfaceTypeHashTable) + 2060|0);
   $129 = (($surfaceTypeHashTable) + 4|0);
   $130 = (($surfaceTypeHashTable) + 8|0);
   $i$094 = 0;
   while(1) {
    $164 = ((($122) + (($i$094*80)|0)|0) + 77|0);
    $165 = HEAP8[$164>>0]|0;
    $166 = ($165<<24>>24)==(0);
    $167 = $165&255;
    $168 = (($hitCounts4) + ($i$094<<2)|0);
    if ($166) {
     HEAP32[$168>>2] = 0;
     $254 = (($hitDistances4) + ($i$094<<2)|0);
     HEAPF32[$254>>2] = Math_fround(0.0);
     $255 = (($hitPlanes4) + ($i$094<<4)|0);
     $256 = (($hitFrictionMultipliers4) + ($i$094<<2)|0);
     ;HEAP32[$255+0>>2]=0|0;HEAP32[$255+4>>2]=0|0;HEAP32[$255+8>>2]=0|0;HEAP32[$255+12>>2]=0|0;
     HEAPF32[$256>>2] = Math_fround(0.0);
     $257 = (($hitContactShapes4) + ($i$094<<2)|0);
     HEAP32[$257>>2] = 0;
     $258 = (($hitContactActors4) + ($i$094<<2)|0);
     HEAP32[$258>>2] = 0;
     $259 = (($hitContactMaterials4) + ($i$094<<2)|0);
     HEAP32[$259>>2] = 0;
     $260 = (($hitSurfaceTypes4) + ($i$094<<2)|0);
     HEAP32[$260>>2] = -1;
     $261 = (($hitContactPoints4) + (($i$094*12)|0)|0);
     HEAPF32[$261>>2] = Math_fround(0.0);
     $262 = ((($hitContactPoints4) + (($i$094*12)|0)|0) + 4|0);
     HEAPF32[$262>>2] = Math_fround(0.0);
     $263 = ((($hitContactPoints4) + (($i$094*12)|0)|0) + 8|0);
     HEAPF32[$263>>2] = Math_fround(0.0);
     $264 = (($hitContactNormals4) + (($i$094*12)|0)|0);
     HEAPF32[$264>>2] = Math_fround(0.0);
     $265 = ((($hitContactNormals4) + (($i$094*12)|0)|0) + 4|0);
     HEAPF32[$265>>2] = Math_fround(0.0);
     $266 = ((($hitContactNormals4) + (($i$094*12)|0)|0) + 8|0);
     HEAPF32[$266>>2] = Math_fround(0.0);
     $267 = ((($outputData) + ($i$094<<2)|0) + 888|0);
     HEAP32[$267>>2] = 0;
     $268 = ((($outputData) + ($i$094<<4)|0) + 904|0);
     $269 = ((($outputData) + ($i$094<<2)|0) + 968|0);
     ;HEAP32[$268+0>>2]=0|0;HEAP32[$268+4>>2]=0|0;HEAP32[$268+8>>2]=0|0;HEAP32[$268+12>>2]=0|0;
     HEAPF32[$269>>2] = Math_fround(0.0);
     $270 = ((($outputData) + ($i$094<<2)|0) + 984|0);
     HEAPF32[$270>>2] = Math_fround(0.0);
    } else {
     HEAP32[$168>>2] = $167;
     $169 = ((($122) + (($i$094*80)|0)|0) + 40|0);
     $170 = Math_fround(HEAPF32[$169>>2]);
     $171 = (($hitDistances4) + ($i$094<<2)|0);
     HEAPF32[$171>>2] = $170;
     $172 = ((($122) + (($i$094*80)|0)|0) + 16|0);
     $173 = Math_fround(HEAPF32[$172>>2]);
     $174 = ((($122) + (($i$094*80)|0)|0) + 20|0);
     $175 = Math_fround(HEAPF32[$174>>2]);
     $176 = ((($122) + (($i$094*80)|0)|0) + 24|0);
     $177 = Math_fround(HEAPF32[$176>>2]);
     $178 = ((($122) + (($i$094*80)|0)|0) + 28|0);
     $179 = Math_fround(HEAPF32[$178>>2]);
     $180 = ((($122) + (($i$094*80)|0)|0) + 32|0);
     $181 = Math_fround(HEAPF32[$180>>2]);
     $182 = ((($122) + (($i$094*80)|0)|0) + 36|0);
     $183 = Math_fround(HEAPF32[$182>>2]);
     $184 = Math_fround($173 * $179);
     $185 = Math_fround($175 * $181);
     $186 = Math_fround($184 + $185);
     $187 = Math_fround($177 * $183);
     $188 = Math_fround($186 + $187);
     $189 = Math_fround(-$188);
     $190 = (($hitPlanes4) + ($i$094<<4)|0);
     HEAPF32[$190>>2] = $179;
     $191 = ((($hitPlanes4) + ($i$094<<4)|0) + 4|0);
     HEAPF32[$191>>2] = $181;
     $192 = ((($hitPlanes4) + ($i$094<<4)|0) + 8|0);
     HEAPF32[$192>>2] = $183;
     $193 = ((($hitPlanes4) + ($i$094<<4)|0) + 12|0);
     HEAPF32[$193>>2] = $189;
     $194 = $170 != Math_fround(0.0);
     if ($194) {
      $195 = ((($122) + (($i$094*80)|0)|0) + 4|0);
      $196 = HEAP32[$195>>2]|0;
      $197 = HEAP32[$196>>2]|0;
      $198 = (($197) + 108|0);
      $199 = HEAP32[$198>>2]|0;
      $200 = ((($122) + (($i$094*80)|0)|0) + 8|0);
      $201 = HEAP32[$200>>2]|0;
      $202 = (FUNCTION_TABLE_iii[$199 & 4095]($196,$201)|0);
      $205 = $202;
     } else {
      $205 = 0;
     }
     $203 = HEAP32[$127>>2]|0;
     __ZN5physx27VehicleSurfaceTypeHashTableC2ERKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsE($surfaceTypeHashTable,$203);
     $204 = ($205|0)==(0|0);
     L18: do {
      if ($204) {
       $surfaceType$0 = 0;
      } else {
       $206 = HEAP32[$128>>2]|0;
       $207 = $205;
       $208 = $207 >>> $206;
       $209 = $208 & 255;
       $210 = ((($surfaceTypeHashTable) + ($209<<2)|0) + 12|0);
       $id$02$i = HEAP32[$210>>2]|0;
       $211 = ($id$02$i|0)==(-1);
       if ($211) {
        $surfaceType$0 = 0;
       } else {
        $212 = HEAP32[$129>>2]|0;
        $id$03$i = $id$02$i;
        while(1) {
         $213 = (($212) + ($id$03$i<<2)|0);
         $214 = HEAP32[$213>>2]|0;
         $215 = ($214|0)==($205|0);
         if ($215) {
          break;
         }
         $219 = ((($surfaceTypeHashTable) + ($id$03$i<<2)|0) + 1036|0);
         $id$0$i = HEAP32[$219>>2]|0;
         $220 = ($id$0$i|0)==(-1);
         if ($220) {
          $surfaceType$0 = 0;
          break L18;
         } else {
          $id$03$i = $id$0$i;
         }
        }
        $216 = HEAP32[$130>>2]|0;
        $217 = (($216) + ($id$03$i<<2)|0);
        $218 = HEAP32[$217>>2]|0;
        $surfaceType$0 = $218;
       }
      }
     } while(0);
     $221 = HEAP32[$58>>2]|0;
     $222 = ((($221) + ($i$094<<6)|0) + 424|0);
     $223 = HEAP32[$222>>2]|0;
     $224 = (Math_fround(__ZNK5physx43PxVehicleDrivableSurfaceToTireFrictionPairs19getTypePairFrictionEjj($203,$surfaceType$0,$223)));
     $225 = (($hitFrictionMultipliers4) + ($i$094<<2)|0);
     HEAPF32[$225>>2] = $224;
     $226 = ((($122) + (($i$094*80)|0)|0) + 4|0);
     $227 = HEAP32[$226>>2]|0;
     $228 = (($hitContactShapes4) + ($i$094<<2)|0);
     HEAP32[$228>>2] = $227;
     $229 = (($122) + (($i$094*80)|0)|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = (($hitContactActors4) + ($i$094<<2)|0);
     HEAP32[$231>>2] = $230;
     $232 = (($hitContactMaterials4) + ($i$094<<2)|0);
     HEAP32[$232>>2] = $205;
     $233 = (($hitSurfaceTypes4) + ($i$094<<2)|0);
     HEAP32[$233>>2] = $surfaceType$0;
     $234 = Math_fround(HEAPF32[$172>>2]);
     $235 = (($hitContactPoints4) + (($i$094*12)|0)|0);
     HEAPF32[$235>>2] = $234;
     $236 = Math_fround(HEAPF32[$174>>2]);
     $237 = ((($hitContactPoints4) + (($i$094*12)|0)|0) + 4|0);
     HEAPF32[$237>>2] = $236;
     $238 = Math_fround(HEAPF32[$176>>2]);
     $239 = ((($hitContactPoints4) + (($i$094*12)|0)|0) + 8|0);
     HEAPF32[$239>>2] = $238;
     $240 = Math_fround(HEAPF32[$178>>2]);
     $241 = (($hitContactNormals4) + (($i$094*12)|0)|0);
     HEAPF32[$241>>2] = $240;
     $242 = Math_fround(HEAPF32[$180>>2]);
     $243 = ((($hitContactNormals4) + (($i$094*12)|0)|0) + 4|0);
     HEAPF32[$243>>2] = $242;
     $244 = Math_fround(HEAPF32[$182>>2]);
     $245 = ((($hitContactNormals4) + (($i$094*12)|0)|0) + 8|0);
     HEAPF32[$245>>2] = $244;
     $246 = ((($outputData) + ($i$094<<2)|0) + 888|0);
     HEAP32[$246>>2] = $167;
     $247 = ((($outputData) + ($i$094<<4)|0) + 904|0);
     HEAPF32[$247>>2] = $179;
     $248 = ((($outputData) + ($i$094<<4)|0) + 908|0);
     HEAPF32[$248>>2] = $181;
     $249 = ((($outputData) + ($i$094<<4)|0) + 912|0);
     HEAPF32[$249>>2] = $183;
     $250 = ((($outputData) + ($i$094<<4)|0) + 916|0);
     HEAPF32[$250>>2] = $189;
     $251 = Math_fround(HEAPF32[$169>>2]);
     $252 = ((($outputData) + ($i$094<<2)|0) + 968|0);
     HEAPF32[$252>>2] = $251;
     $253 = ((($outputData) + ($i$094<<2)|0) + 984|0);
     HEAPF32[$253>>2] = $224;
    }
    $271 = (($i$094) + 1)|0;
    $272 = HEAP32[$124>>2]|0;
    $273 = ($271>>>0)<($272>>>0);
    if ($273) {
     $i$094 = $271;
    } else {
     break;
    }
   }
  }
 }
 $131 = (($hitNorm4) + 4|0);
 $132 = (($hitNorm4) + 8|0);
 $133 = (($inputData) + 36|0);
 $134 = (($inputData) + 40|0);
 $135 = (($inputData) + 44|0);
 $136 = (($wheelBottomPos) + 4|0);
 $137 = (($wheelBottomPos) + 8|0);
 $138 = (($inputData) + 48|0);
 $139 = (($inputData) + 52|0);
 $140 = (($inputData) + 56|0);
 $141 = (($inputData) + 64|0);
 $142 = (($inputData) + 68|0);
 $143 = (($inputData) + 60|0);
 $144 = (($constData) + 8|0);
 $145 = (($constData) + 12|0);
 $146 = (($constData) + 16|0);
 $147 = (($outputData) + 484|0);
 $148 = (($outputData) + 488|0);
 $149 = (($outputData) + 492|0);
 $150 = (($outputData) + 496|0);
 $151 = (($outputData) + 500|0);
 $152 = (($outputData) + 504|0);
 $153 = (($65) + 8|0);
 $154 = (($65) + 4|0);
 $155 = (($65) + 12|0);
 $156 = (($65) + 16|0);
 $157 = (($tireLongDir) + 4|0);
 $158 = (($tireLongDir) + 8|0);
 $159 = (($tireLatDir) + 4|0);
 $160 = (($tireLatDir) + 8|0);
 $161 = (($63) + 16|0);
 $162 = (($0) + 4|0);
 $163 = (($0) + 8|0);
 $i2$088 = 0;
 while(1) {
  $325 = ((($61) + ($i2$088<<2)|0) + 48|0);
  $326 = Math_fround(HEAPF32[$325>>2]);
  $327 = ((($outputData) + ($i2$088<<2)|0) + 508|0);
  HEAPF32[$327>>2] = $326;
  $328 = ((($61) + ($i2$088<<2)|0) + 64|0);
  $329 = Math_fround(HEAPF32[$328>>2]);
  $330 = ((($outputData) + ($i2$088<<2)|0) + 524|0);
  HEAPF32[$330>>2] = $329;
  $331 = ((($59) + (($i2$088*48)|0)|0) + 12|0);
  $332 = HEAP32[523960>>2]|0;
  $333 = ($332|0)==(0|0);
  if (!($333)) {
   $334 = Math_fround(HEAPF32[$331>>2]);
   $335 = Math_fround(-$334);
   $336 = (($i2$088) + ($startWheelIndex))|0;
   $337 = (523960 + ($336<<2)|0);
   $338 = HEAP32[$337>>2]|0;
   HEAPF32[$338>>2] = $335;
  }
  $339 = Math_fround(HEAPF32[$331>>2]);
  $340 = Math_fround(-$339);
  $341 = ((($outputData) + ($i2$088<<2)|0) + 292|0);
  HEAPF32[$341>>2] = $340;
  $342 = ((($outputData) + ($i2$088)|0) + 652|0);
  HEAP8[$342>>0] = 0;
  $343 = ((($outputData) + ($i2$088<<2)|0) + 636|0);
  HEAPF32[$343>>2] = Math_fround(0.0);
  $344 = ((($outputData) + ($i2$088)|0) + 768|0);
  HEAP8[$344>>0] = 0;
  $345 = ((($outputData) + ($i2$088<<2)|0) + 752|0);
  HEAPF32[$345>>2] = Math_fround(0.0);
  $346 = ((($outputData) + ($i2$088)|0) + 884|0);
  HEAP8[$346>>0] = 0;
  $347 = ((($outputData) + ($i2$088<<2)|0) + 868|0);
  HEAPF32[$347>>2] = Math_fround(0.0);
  $348 = ((($outputData) + ($i2$088)|0) + 112|0);
  HEAP8[$348>>0] = 1;
  $349 = (($118) + ($i2$088)|0);
  $350 = HEAP8[$349>>0]|0;
  $351 = (($hitCounts4) + ($i2$088<<2)|0);
  $352 = HEAP32[$351>>2]|0;
  $353 = (($hitDistances4) + ($i2$088<<2)|0);
  $354 = Math_fround(HEAPF32[$353>>2]);
  $355 = (($hitPlanes4) + ($i2$088<<4)|0);
  $356 = Math_fround(HEAPF32[$355>>2]);
  $357 = ((($hitPlanes4) + ($i2$088<<4)|0) + 4|0);
  $358 = Math_fround(HEAPF32[$357>>2]);
  $359 = ((($hitPlanes4) + ($i2$088<<4)|0) + 8|0);
  $360 = Math_fround(HEAPF32[$359>>2]);
  HEAPF32[$hitNorm4>>2] = $356;
  HEAPF32[$131>>2] = $358;
  HEAPF32[$132>>2] = $360;
  $361 = ((($59) + (($i2$088*48)|0)|0) + 192|0);
  $362 = Math_fround(HEAPF32[$361>>2]);
  $363 = ((($59) + (($i2$088*48)|0)|0) + 8|0);
  $364 = Math_fround(HEAPF32[$363>>2]);
  $365 = ((($59) + (($i2$088*12)|0)|0) + 640|0);
  $366 = Math_fround(HEAPF32[$365>>2]);
  $367 = Math_fround($366 * Math_fround(2.0));
  $368 = ((($59) + (($i2$088*12)|0)|0) + 644|0);
  $369 = Math_fround(HEAPF32[$368>>2]);
  $370 = Math_fround($369 * Math_fround(2.0));
  $371 = ((($59) + (($i2$088*12)|0)|0) + 648|0);
  $372 = Math_fround(HEAPF32[$371>>2]);
  $373 = Math_fround($372 * Math_fround(2.0));
  $374 = Math_fround(HEAPF32[$69>>2]);
  $375 = Math_fround($374 * $374);
  $376 = Math_fround($375 + Math_fround(-0.5));
  $377 = Math_fround(HEAPF32[$73>>2]);
  $378 = Math_fround($367 * $377);
  $379 = Math_fround(HEAPF32[$76>>2]);
  $380 = Math_fround($370 * $379);
  $381 = Math_fround($378 + $380);
  $382 = Math_fround(HEAPF32[$80>>2]);
  $383 = Math_fround($373 * $382);
  $384 = Math_fround($381 + $383);
  $385 = Math_fround($367 * $376);
  $386 = Math_fround($373 * $379);
  $387 = Math_fround($370 * $382);
  $388 = Math_fround($386 - $387);
  $389 = Math_fround($374 * $388);
  $390 = Math_fround($385 + $389);
  $391 = Math_fround($377 * $384);
  $392 = Math_fround($391 + $390);
  $393 = Math_fround($370 * $376);
  $394 = Math_fround($367 * $382);
  $395 = Math_fround($373 * $377);
  $396 = Math_fround($394 - $395);
  $397 = Math_fround($374 * $396);
  $398 = Math_fround($393 + $397);
  $399 = Math_fround($379 * $384);
  $400 = Math_fround($399 + $398);
  $401 = Math_fround($373 * $376);
  $402 = Math_fround($370 * $377);
  $403 = Math_fround($367 * $379);
  $404 = Math_fround($402 - $403);
  $405 = Math_fround($374 * $404);
  $406 = Math_fround($401 + $405);
  $407 = Math_fround($382 * $384);
  $408 = Math_fround($406 + $407);
  $409 = ((($59) + (($i2$088*12)|0)|0) + 784|0);
  $410 = Math_fround(HEAPF32[$409>>2]);
  $411 = Math_fround($410 * Math_fround(2.0));
  $412 = ((($59) + (($i2$088*12)|0)|0) + 788|0);
  $413 = Math_fround(HEAPF32[$412>>2]);
  $414 = Math_fround($413 * Math_fround(2.0));
  $415 = ((($59) + (($i2$088*12)|0)|0) + 792|0);
  $416 = Math_fround(HEAPF32[$415>>2]);
  $417 = Math_fround($416 * Math_fround(2.0));
  $418 = Math_fround($377 * $411);
  $419 = Math_fround($379 * $414);
  $420 = Math_fround($418 + $419);
  $421 = Math_fround($382 * $417);
  $422 = Math_fround($420 + $421);
  $423 = Math_fround($376 * $411);
  $424 = Math_fround($379 * $417);
  $425 = Math_fround($382 * $414);
  $426 = Math_fround($424 - $425);
  $427 = Math_fround($374 * $426);
  $428 = Math_fround($423 + $427);
  $429 = Math_fround($377 * $422);
  $430 = Math_fround($429 + $428);
  $431 = Math_fround($376 * $414);
  $432 = Math_fround($382 * $411);
  $433 = Math_fround($377 * $417);
  $434 = Math_fround($432 - $433);
  $435 = Math_fround($374 * $434);
  $436 = Math_fround($431 + $435);
  $437 = Math_fround($379 * $422);
  $438 = Math_fround($437 + $436);
  $439 = Math_fround($376 * $417);
  $440 = Math_fround($377 * $414);
  $441 = Math_fround($379 * $411);
  $442 = Math_fround($440 - $441);
  $443 = Math_fround($374 * $442);
  $444 = Math_fround($439 + $443);
  $445 = Math_fround($382 * $422);
  $446 = Math_fround($444 + $445);
  $447 = Math_fround(HEAPF32[$133>>2]);
  $448 = Math_fround($447 + $430);
  $449 = Math_fround(HEAPF32[$134>>2]);
  $450 = Math_fround($449 + $438);
  $451 = Math_fround(HEAPF32[$135>>2]);
  $452 = Math_fround($451 + $446);
  $453 = Math_fround($362 + $364);
  $454 = Math_fround($453 * $392);
  $455 = Math_fround($453 * $400);
  $456 = Math_fround($453 * $408);
  $457 = Math_fround($448 - $454);
  $458 = Math_fround($450 - $455);
  $459 = Math_fround($452 - $456);
  $notlhs = ($350<<24>>24)!=(0);
  $notrhs = ($352|0)!=(0);
  $or$cond$not = $notrhs & $notlhs;
  $460 = $354 != Math_fround(0.0);
  $or$cond1 = $or$cond$not & $460;
  do {
   if ($or$cond1) {
    $461 = Math_fround(HEAPF32[$hitNorm4>>2]);
    $462 = Math_fround($392 * $461);
    $463 = Math_fround(HEAPF32[$131>>2]);
    $464 = Math_fround($400 * $463);
    $465 = Math_fround($462 + $464);
    $466 = Math_fround($360 * $408);
    $467 = Math_fround($466 + $465);
    $468 = $467 < Math_fround(0.0);
    if ($468) {
     $469 = (($hitFrictionMultipliers4) + ($i2$088<<2)|0);
     $470 = Math_fround(HEAPF32[$469>>2]);
     $471 = ((($hitPlanes4) + ($i2$088<<4)|0) + 12|0);
     $472 = Math_fround(HEAPF32[$471>>2]);
     $473 = Math_fround($457 * $461);
     $474 = Math_fround($458 * $463);
     $475 = Math_fround($473 + $474);
     $476 = Math_fround($360 * $459);
     $477 = Math_fround($476 + $475);
     $478 = Math_fround($477 + $472);
     $479 = Math_fround(-$478);
     $480 = Math_fround($479 / $467);
     $481 = Math_fround($362 * Math_fround(2.0));
     $482 = Math_fround($481 + $364);
     $483 = Math_fround($482 - $480);
     $484 = Math_fround(HEAPF32[$331>>2]);
     $485 = Math_fround(-$484);
     $486 = $483 > $485;
     if ($486) {
      $487 = (($hitContactShapes4) + ($i2$088<<2)|0);
      $488 = HEAP32[$487>>2]|0;
      $489 = ((($outputData) + ($i2$088<<2)|0) + 132|0);
      HEAP32[$489>>2] = $488;
      $490 = (($hitContactActors4) + ($i2$088<<2)|0);
      $491 = HEAP32[$490>>2]|0;
      $492 = ((($outputData) + ($i2$088<<2)|0) + 116|0);
      HEAP32[$492>>2] = $491;
      $493 = (($hitContactMaterials4) + ($i2$088<<2)|0);
      $494 = HEAP32[$493>>2]|0;
      $495 = ((($outputData) + ($i2$088<<2)|0) + 148|0);
      HEAP32[$495>>2] = $494;
      $496 = (($hitSurfaceTypes4) + ($i2$088<<2)|0);
      $497 = HEAP32[$496>>2]|0;
      $498 = ((($outputData) + ($i2$088<<2)|0) + 164|0);
      HEAP32[$498>>2] = $497;
      $499 = (($hitContactPoints4) + (($i2$088*12)|0)|0);
      $500 = Math_fround(HEAPF32[$499>>2]);
      $501 = ((($outputData) + (($i2$088*12)|0)|0) + 180|0);
      HEAPF32[$501>>2] = $500;
      $502 = ((($hitContactPoints4) + (($i2$088*12)|0)|0) + 4|0);
      $503 = Math_fround(HEAPF32[$502>>2]);
      $504 = ((($outputData) + (($i2$088*12)|0)|0) + 184|0);
      HEAPF32[$504>>2] = $503;
      $505 = ((($hitContactPoints4) + (($i2$088*12)|0)|0) + 8|0);
      $506 = Math_fround(HEAPF32[$505>>2]);
      $507 = ((($outputData) + (($i2$088*12)|0)|0) + 188|0);
      HEAPF32[$507>>2] = $506;
      $508 = (($hitContactNormals4) + (($i2$088*12)|0)|0);
      $509 = Math_fround(HEAPF32[$508>>2]);
      $510 = ((($outputData) + (($i2$088*12)|0)|0) + 228|0);
      HEAPF32[$510>>2] = $509;
      $511 = ((($hitContactNormals4) + (($i2$088*12)|0)|0) + 4|0);
      $512 = Math_fround(HEAPF32[$511>>2]);
      $513 = ((($outputData) + (($i2$088*12)|0)|0) + 232|0);
      HEAPF32[$513>>2] = $512;
      $514 = ((($hitContactNormals4) + (($i2$088*12)|0)|0) + 8|0);
      $515 = Math_fround(HEAPF32[$514>>2]);
      $516 = ((($outputData) + (($i2$088*12)|0)|0) + 236|0);
      HEAPF32[$516>>2] = $515;
      HEAP8[$348>>0] = 0;
      $517 = Math_fround(HEAPF32[$363>>2]);
      $518 = Math_fround($483 - $517);
      HEAPF32[$343>>2] = $518;
      $519 = Math_fround(HEAPF32[$363>>2]);
      $520 = $483 > $519;
      $521 = $520&1;
      HEAP8[$342>>0] = $521;
      $522 = Math_fround(HEAPF32[$409>>2]);
      $523 = ((($outputData) + (($i2$088*12)|0)|0) + 540|0);
      HEAPF32[$523>>2] = $522;
      $524 = Math_fround(HEAPF32[$412>>2]);
      $525 = ((($outputData) + (($i2$088*12)|0)|0) + 544|0);
      HEAPF32[$525>>2] = $524;
      $526 = Math_fround(HEAPF32[$415>>2]);
      $527 = ((($outputData) + (($i2$088*12)|0)|0) + 548|0);
      HEAPF32[$527>>2] = $526;
      $528 = Math_fround(HEAPF32[$365>>2]);
      $529 = ((($outputData) + (($i2$088*12)|0)|0) + 588|0);
      HEAPF32[$529>>2] = $528;
      $530 = Math_fround(HEAPF32[$368>>2]);
      $531 = ((($outputData) + (($i2$088*12)|0)|0) + 592|0);
      HEAPF32[$531>>2] = $530;
      $532 = Math_fround(HEAPF32[$371>>2]);
      $533 = ((($outputData) + (($i2$088*12)|0)|0) + 596|0);
      HEAPF32[$533>>2] = $532;
      $534 = Math_fround(HEAPF32[$363>>2]);
      $535 = $483 < $534;
      $536 = $535 ? $483 : $534;
      HEAPF32[$341>>2] = $536;
      $537 = HEAP32[523960>>2]|0;
      $538 = ($537|0)==(0|0);
      if (!($538)) {
       $539 = (($i2$088) + ($startWheelIndex))|0;
       $540 = (523960 + ($539<<2)|0);
       $541 = HEAP32[$540>>2]|0;
       HEAPF32[$541>>2] = $536;
      }
      $542 = Math_fround($482 - $536);
      $543 = Math_fround($392 * $542);
      $544 = Math_fround($400 * $542);
      $545 = Math_fround($408 * $542);
      $546 = Math_fround($457 + $543);
      $547 = Math_fround($458 + $544);
      $548 = Math_fround($459 + $545);
      HEAPF32[$wheelBottomPos>>2] = $546;
      HEAPF32[$136>>2] = $547;
      HEAPF32[$137>>2] = $548;
      $549 = Math_fround(HEAPF32[$133>>2]);
      $550 = Math_fround($546 - $549);
      $551 = Math_fround(HEAPF32[$134>>2]);
      $552 = Math_fround($547 - $551);
      $553 = Math_fround(HEAPF32[$135>>2]);
      $554 = Math_fround($548 - $553);
      $555 = Math_fround(HEAPF32[$138>>2]);
      $556 = Math_fround(HEAPF32[$139>>2]);
      $557 = Math_fround(HEAPF32[$140>>2]);
      $558 = Math_fround(HEAPF32[$141>>2]);
      $559 = Math_fround($554 * $558);
      $560 = Math_fround(HEAPF32[$142>>2]);
      $561 = Math_fround($552 * $560);
      $562 = Math_fround($559 - $561);
      $563 = Math_fround($550 * $560);
      $564 = Math_fround(HEAPF32[$143>>2]);
      $565 = Math_fround($554 * $564);
      $566 = Math_fround($563 - $565);
      $567 = Math_fround($552 * $564);
      $568 = Math_fround($550 * $558);
      $569 = Math_fround($567 - $568);
      $570 = Math_fround($555 + $562);
      $571 = Math_fround($556 + $566);
      $572 = Math_fround($557 + $569);
      $573 = ($491|0)==(0|0);
      if ($573) {
       $584 = $570;$586 = $571;$589 = $572;$616 = $537;$939 = Math_fround(0.0);$941 = Math_fround(0.0);$944 = Math_fround(0.0);$dynamicHitActor$0 = 0;
      } else {
       $574 = (($491) + 4|0);
       $575 = HEAP16[$574>>1]|0;
       $576 = ($575<<16>>16)==(5);
       if ($576) {
        __ZN5physx14PxRigidBodyExt16getVelocityAtPosERKNS_11PxRigidBodyERKNS_6PxVec3E($0,$491,$wheelBottomPos);
        $577 = Math_fround(HEAPF32[$0>>2]);
        $578 = Math_fround(HEAPF32[$162>>2]);
        $579 = Math_fround(HEAPF32[$163>>2]);
        $580 = Math_fround($570 - $577);
        $581 = Math_fround($571 - $578);
        $582 = Math_fround($572 - $579);
        $$pre = HEAP32[523960>>2]|0;
        $584 = $580;$586 = $581;$589 = $582;$616 = $$pre;$939 = $577;$941 = $578;$944 = $579;$dynamicHitActor$0 = $491;
       } else {
        $584 = $570;$586 = $571;$589 = $572;$616 = $537;$939 = Math_fround(0.0);$941 = Math_fround(0.0);$944 = Math_fround(0.0);$dynamicHitActor$0 = 0;
       }
      }
      $583 = Math_fround($392 * $584);
      $585 = Math_fround($400 * $586);
      $587 = Math_fround($585 + $583);
      $588 = Math_fround($408 * $589);
      $590 = Math_fround($588 + $587);
      $591 = Math_fround(HEAPF32[$144>>2]);
      $592 = Math_fround($392 * $591);
      $593 = Math_fround(HEAPF32[$145>>2]);
      $594 = Math_fround($400 * $593);
      $595 = Math_fround($592 + $594);
      $596 = Math_fround(HEAPF32[$146>>2]);
      $597 = Math_fround($408 * $596);
      $598 = Math_fround($595 + $597);
      $599 = $598 < Math_fround(0.0);
      $600 = $599 ? Math_fround(0.0) : $598;
      $601 = ((($59) + (($i2$088*48)|0)|0) + 16|0);
      $602 = Math_fround(HEAPF32[$601>>2]);
      $603 = Math_fround($602 * $600);
      $604 = (($59) + (($i2$088*48)|0)|0);
      $605 = Math_fround(HEAPF32[$604>>2]);
      $606 = Math_fround($536 * $605);
      $607 = Math_fround($606 + $603);
      $608 = ((($59) + (($i2$088*48)|0)|0) + 4|0);
      $609 = Math_fround(HEAPF32[$608>>2]);
      $610 = Math_fround($590 * $609);
      $611 = Math_fround($610 + $607);
      $612 = $611 > Math_fround(0.0);
      $613 = $612 ? $611 : Math_fround(0.0);
      $614 = ((($outputData) + ($i2$088<<2)|0) + 308|0);
      HEAPF32[$614>>2] = $613;
      $615 = ($616|0)==(0|0);
      if (!($615)) {
       $617 = (($i2$088) + ($startWheelIndex))|0;
       $618 = (523960 + ($617<<2)|0);
       $619 = HEAP32[$618>>2]|0;
       $620 = (($619) + 4|0);
       HEAPF32[$620>>2] = $613;
      }
      $621 = Math_fround($613 * Math_fround(-1.0));
      $622 = Math_fround($392 * $621);
      $623 = Math_fround($400 * $621);
      $624 = Math_fround($408 * $621);
      $625 = Math_fround($622 * $461);
      $626 = Math_fround($623 * $463);
      $627 = Math_fround($625 + $626);
      $628 = Math_fround(HEAPF32[$132>>2]);
      $629 = Math_fround($624 * $628);
      $630 = Math_fround($627 + $629);
      $631 = Math_fround($461 * $630);
      $632 = Math_fround($463 * $630);
      $633 = Math_fround($628 * $630);
      $634 = ((($59) + (($i2$088*12)|0)|0) + 688|0);
      $635 = Math_fround(HEAPF32[$634>>2]);
      $636 = Math_fround($635 * Math_fround(2.0));
      $637 = ((($59) + (($i2$088*12)|0)|0) + 692|0);
      $638 = Math_fround(HEAPF32[$637>>2]);
      $639 = Math_fround($638 * Math_fround(2.0));
      $640 = ((($59) + (($i2$088*12)|0)|0) + 696|0);
      $641 = Math_fround(HEAPF32[$640>>2]);
      $642 = Math_fround($641 * Math_fround(2.0));
      $643 = Math_fround(HEAPF32[$69>>2]);
      $644 = Math_fround($643 * $643);
      $645 = Math_fround($644 + Math_fround(-0.5));
      $646 = Math_fround(HEAPF32[$73>>2]);
      $647 = Math_fround($636 * $646);
      $648 = Math_fround(HEAPF32[$76>>2]);
      $649 = Math_fround($639 * $648);
      $650 = Math_fround($647 + $649);
      $651 = Math_fround(HEAPF32[$80>>2]);
      $652 = Math_fround($642 * $651);
      $653 = Math_fround($650 + $652);
      $654 = Math_fround($636 * $645);
      $655 = Math_fround($642 * $648);
      $656 = Math_fround($639 * $651);
      $657 = Math_fround($655 - $656);
      $658 = Math_fround($643 * $657);
      $659 = Math_fround($654 + $658);
      $660 = Math_fround($646 * $653);
      $661 = Math_fround($660 + $659);
      $662 = Math_fround($639 * $645);
      $663 = Math_fround($636 * $651);
      $664 = Math_fround($642 * $646);
      $665 = Math_fround($663 - $664);
      $666 = Math_fround($643 * $665);
      $667 = Math_fround($662 + $666);
      $668 = Math_fround($648 * $653);
      $669 = Math_fround($668 + $667);
      $670 = Math_fround($642 * $645);
      $671 = Math_fround($639 * $646);
      $672 = Math_fround($636 * $648);
      $673 = Math_fround($671 - $672);
      $674 = Math_fround($643 * $673);
      $675 = Math_fround($670 + $674);
      $676 = Math_fround($651 * $653);
      $677 = Math_fround($675 + $676);
      $678 = Math_fround($633 * $669);
      $679 = Math_fround($632 * $677);
      $680 = Math_fround($678 - $679);
      $681 = Math_fround($631 * $677);
      $682 = Math_fround($633 * $661);
      $683 = Math_fround($681 - $682);
      $684 = Math_fround($632 * $661);
      $685 = Math_fround($631 * $669);
      $686 = Math_fround($684 - $685);
      $687 = Math_fround(HEAPF32[$147>>2]);
      $688 = Math_fround($631 + $687);
      HEAPF32[$147>>2] = $688;
      $689 = Math_fround(HEAPF32[$148>>2]);
      $690 = Math_fround($632 + $689);
      HEAPF32[$148>>2] = $690;
      $691 = Math_fround(HEAPF32[$149>>2]);
      $692 = Math_fround($633 + $691);
      HEAPF32[$149>>2] = $692;
      $693 = Math_fround(HEAPF32[$150>>2]);
      $694 = Math_fround($693 + $680);
      HEAPF32[$150>>2] = $694;
      $695 = Math_fround(HEAPF32[$151>>2]);
      $696 = Math_fround($695 + $683);
      HEAPF32[$151>>2] = $696;
      $697 = Math_fround(HEAPF32[$152>>2]);
      $698 = Math_fround($697 + $686);
      HEAPF32[$152>>2] = $698;
      $699 = Math_fround($408 * $628);
      $700 = Math_fround($465 + $699);
      $701 = Math_fround($621 * $700);
      $702 = Math_fround(HEAPF32[$144>>2]);
      $703 = Math_fround($461 * $702);
      $704 = Math_fround(HEAPF32[$145>>2]);
      $705 = Math_fround($463 * $704);
      $706 = Math_fround($703 + $705);
      $707 = Math_fround(HEAPF32[$146>>2]);
      $708 = Math_fround($628 * $707);
      $709 = Math_fround($706 + $708);
      $710 = $709 < Math_fround(0.0);
      $711 = $710 ? $709 : Math_fround(0.0);
      $712 = ((($59) + (($i2$088*48)|0)|0) + 200|0);
      $713 = Math_fround(HEAPF32[$712>>2]);
      $714 = Math_fround($713 * $711);
      $715 = Math_fround($701 - $714);
      $716 = ($dynamicHitActor$0|0)==(0|0);
      if (!($716)) {
       $717 = HEAP32[$dynamicHitActor$0>>2]|0;
       $718 = (($717) + 204|0);
       $719 = HEAP32[$718>>2]|0;
       FUNCTION_TABLE_vii[$719 & 4095]($1,$dynamicHitActor$0);
       $720 = HEAP8[$1>>0]|0;
       $721 = $720 & 1;
       $722 = ($721<<24>>24)==(0);
       if ($722) {
        $723 = ((($outputData) + ($i2$088<<2)|0) + 1000|0);
        HEAP32[$723>>2] = $dynamicHitActor$0;
        $724 = Math_fround(-$715);
        $725 = Math_fround(HEAPF32[$hitNorm4>>2]);
        $726 = Math_fround($725 * $724);
        $727 = Math_fround(HEAPF32[$131>>2]);
        $728 = Math_fround($727 * $724);
        $729 = Math_fround($628 * $724);
        $730 = Math_fround($47 * $726);
        $731 = Math_fround($47 * $728);
        $732 = Math_fround($47 * $729);
        $733 = ((($outputData) + (($i2$088*12)|0)|0) + 1016|0);
        HEAPF32[$733>>2] = $730;
        $734 = ((($outputData) + (($i2$088*12)|0)|0) + 1020|0);
        HEAPF32[$734>>2] = $731;
        $735 = ((($outputData) + (($i2$088*12)|0)|0) + 1024|0);
        HEAPF32[$735>>2] = $732;
        $736 = Math_fround(HEAPF32[$499>>2]);
        $737 = ((($outputData) + (($i2$088*12)|0)|0) + 1064|0);
        HEAPF32[$737>>2] = $736;
        $738 = Math_fround(HEAPF32[$502>>2]);
        $739 = ((($outputData) + (($i2$088*12)|0)|0) + 1068|0);
        HEAPF32[$739>>2] = $738;
        $740 = Math_fround(HEAPF32[$505>>2]);
        $741 = ((($outputData) + (($i2$088*12)|0)|0) + 1072|0);
        HEAPF32[$741>>2] = $740;
       }
      }
      $742 = Math_fround($51 * $715);
      $743 = ((($59) + ($i2$088<<2)|0) + 848|0);
      $744 = Math_fround(HEAPF32[$743>>2]);
      $745 = Math_fround($742 * $744);
      $746 = Math_fround(HEAPF32[$65>>2]);
      $747 = !($746 >= $745);
      do {
       if ($747) {
        $749 = Math_fround(HEAPF32[$153>>2]);
        $750 = !($749 <= $745);
        if ($750) {
         $752 = Math_fround(HEAPF32[$154>>2]);
         $753 = Math_fround(HEAPF32[$155>>2]);
         $754 = Math_fround(HEAPF32[$156>>2]);
         $755 = Math_fround($745 - $746);
         $756 = Math_fround($753 - $752);
         $757 = Math_fround($755 * $756);
         $758 = Math_fround($754 * $757);
         $759 = Math_fround($752 + $758);
         $$0$i = $759;
         break;
        } else {
         $751 = Math_fround(HEAPF32[$155>>2]);
         $$0$i = $751;
         break;
        }
       } else {
        $748 = Math_fround(HEAPF32[$154>>2]);
        $$0$i = $748;
       }
      } while(0);
      $760 = Math_fround($53 * $$0$i);
      $761 = ((($59) + ($i2$088<<2)|0) + 832|0);
      $762 = Math_fround(HEAPF32[$761>>2]);
      $763 = Math_fround($760 * $762);
      $764 = HEAP32[523960>>2]|0;
      $765 = ($764|0)==(0|0);
      if (!($765)) {
       $766 = (($i2$088) + ($startWheelIndex))|0;
       $767 = (523960 + ($766<<2)|0);
       $768 = HEAP32[$767>>2]|0;
       $769 = (($768) + 8|0);
       HEAPF32[$769>>2] = $763;
       $770 = (($768) + 12|0);
       HEAPF32[$770>>2] = $$0$i;
      }
      $771 = (($112) + ($i2$088<<2)|0);
      $772 = Math_fround(HEAPF32[$771>>2]);
      __ZN5physx15computeTireDirsERKNS_6PxVec3ES2_fRS0_S3_($latDir,$hitNorm4,$772,$tireLongDir,$tireLatDir);
      $773 = Math_fround(HEAPF32[$tireLongDir>>2]);
      $774 = ((($outputData) + (($i2$088*12)|0)|0) + 324|0);
      HEAPF32[$774>>2] = $773;
      $775 = Math_fround(HEAPF32[$157>>2]);
      $776 = ((($outputData) + (($i2$088*12)|0)|0) + 328|0);
      HEAPF32[$776>>2] = $775;
      $777 = Math_fround(HEAPF32[$158>>2]);
      $778 = ((($outputData) + (($i2$088*12)|0)|0) + 332|0);
      HEAPF32[$778>>2] = $777;
      $779 = Math_fround(HEAPF32[$tireLatDir>>2]);
      $780 = ((($outputData) + (($i2$088*12)|0)|0) + 372|0);
      HEAPF32[$780>>2] = $779;
      $781 = Math_fround(HEAPF32[$159>>2]);
      $782 = ((($outputData) + (($i2$088*12)|0)|0) + 376|0);
      HEAPF32[$782>>2] = $781;
      $783 = Math_fround(HEAPF32[$160>>2]);
      $784 = ((($outputData) + (($i2$088*12)|0)|0) + 380|0);
      HEAPF32[$784>>2] = $783;
      $785 = Math_fround($584 * $773);
      $786 = Math_fround($586 * $775);
      $787 = Math_fround($785 + $786);
      $788 = Math_fround($589 * $777);
      $789 = Math_fround($787 + $788);
      $790 = Math_fround($584 * $779);
      $791 = Math_fround($586 * $781);
      $792 = Math_fround($790 + $791);
      $793 = Math_fround($589 * $783);
      $794 = Math_fround($792 + $793);
      $795 = ((($outputData) + ($i2$088<<2)|0) + 452|0);
      HEAPF32[$795>>2] = $789;
      $796 = (($61) + ($i2$088<<2)|0);
      $797 = Math_fround(HEAPF32[$796>>2]);
      $798 = Math_fround(HEAPF32[$361>>2]);
      $fabsf$i$i$i24 = (Math_fround(Math_abs((Math_fround($789)))));
      $799 = Math_fround($797 * $798);
      $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($799)))));
      $800 = Math_fround(HEAPF32[523928>>2]);
      $801 = Math_fround($fabsf$i$i$i24 + $800);
      $802 = Math_fround($794 / $801);
      $803 = +$802;
      $804 = (+Math_atan((+$803)));
      $805 = Math_fround($804);
      $806 = $789 == Math_fround(0.0);
      $807 = $797 == Math_fround(0.0);
      $or$cond$i25 = $806 & $807;
      do {
       if ($or$cond$i25) {
        $834 = Math_fround(0.0);
       } else {
        $808 = (($114) + ($i2$088)|0);
        $809 = (($116) + ($i2$088)|0);
        $810 = HEAP8[$808>>0]|0;
        $811 = HEAP8[$809>>0]|0;
        $812 = $811 | $810;
        $813 = ($812<<24>>24)!=(0);
        $814 = Math_fround($799 - $789);
        if ($119) {
         $824 = $fabsf$i$i$i24 > $fabsf$i$i2$i;
         $825 = $824 ? $fabsf$i$i$i24 : $fabsf$i$i2$i;
         if ($813) {
          $826 = Math_fround(HEAPF32[523944>>2]);
          $827 = Math_fround($826 * Math_fround(0.100000001490116119385));
          $828 = Math_fround($825 + $827);
          $829 = Math_fround($814 / $828);
          $834 = $829;
          break;
         } else {
          $830 = $825 < $57;
          $831 = $830 ? $57 : $825;
          $832 = Math_fround($814 / $831);
          $834 = $832;
          break;
         }
        } else {
         if ($813) {
          $815 = Math_fround(HEAPF32[523944>>2]);
          $816 = Math_fround($815 * Math_fround(0.100000001490116119385));
          $817 = Math_fround($fabsf$i$i$i24 + $816);
          $818 = Math_fround($814 / $817);
          $834 = $818;
          break;
         } else {
          $819 = $fabsf$i$i$i24 > $fabsf$i$i2$i;
          $820 = $819 ? $fabsf$i$i$i24 : $fabsf$i$i2$i;
          $821 = $820 < $57;
          $822 = $821 ? $57 : $820;
          $823 = Math_fround($814 / $822);
          $834 = $823;
          break;
         }
        }
       }
      } while(0);
      $833 = ((($outputData) + ($i2$088<<2)|0) + 420|0);
      HEAPF32[$833>>2] = $834;
      $835 = ((($outputData) + ($i2$088<<2)|0) + 436|0);
      HEAPF32[$835>>2] = $805;
      $836 = ((($59) + (($i2$088*48)|0)|0) + 20|0);
      $837 = Math_fround(HEAPF32[$836>>2]);
      $838 = $536 > Math_fround(0.0);
      if ($838) {
       $839 = ((($59) + (($i2$088*48)|0)|0) + 24|0);
       $840 = Math_fround(HEAPF32[$839>>2]);
       $841 = Math_fround($536 * $840);
       $842 = ((($59) + (($i2$088*48)|0)|0) + 32|0);
       $843 = Math_fround(HEAPF32[$842>>2]);
       $844 = Math_fround($841 * $843);
       $845 = Math_fround($837 + $844);
       $camber$0 = $845;
      } else {
       $846 = ((($59) + (($i2$088*48)|0)|0) + 28|0);
       $847 = Math_fround(HEAPF32[$846>>2]);
       $848 = Math_fround($536 * $847);
       $849 = ((($59) + (($i2$088*48)|0)|0) + 36|0);
       $850 = Math_fround(HEAPF32[$849>>2]);
       $851 = Math_fround($848 * $850);
       $852 = Math_fround($837 - $851);
       $camber$0 = $852;
      }
      $853 = ((($59) + ($i2$088<<6)|0) + 404|0);
      $854 = Math_fround(HEAPF32[$853>>2]);
      $855 = ((($59) + ($i2$088<<6)|0) + 408|0);
      $856 = Math_fround(HEAPF32[$855>>2]);
      $857 = ((($59) + ($i2$088<<6)|0) + 412|0);
      $858 = Math_fround(HEAPF32[$857>>2]);
      $859 = ((($59) + ($i2$088<<6)|0) + 420|0);
      $860 = Math_fround(HEAPF32[$859>>2]);
      $861 = ((($59) + ($i2$088<<6)|0) + 436|0);
      $862 = Math_fround(HEAPF32[$861>>2]);
      $fabsf$i$i$i21 = (Math_fround(Math_abs((Math_fround($834)))));
      $863 = $fabsf$i$i$i21 < $856;
      if ($863) {
       $864 = ((($59) + ($i2$088<<6)|0) + 432|0);
       $865 = ((($59) + ($i2$088<<6)|0) + 400|0);
       $866 = Math_fround(HEAPF32[$864>>2]);
       $867 = Math_fround(HEAPF32[$865>>2]);
       $868 = Math_fround($858 - $854);
       $869 = Math_fround($fabsf$i$i$i21 - $867);
       $870 = Math_fround($868 * $869);
       $871 = Math_fround($866 * $870);
       $872 = Math_fround($854 + $871);
       $mu$0$i = $872;
      } else {
       $873 = ((($59) + ($i2$088<<6)|0) + 416|0);
       $874 = Math_fround(HEAPF32[$873>>2]);
       $875 = $fabsf$i$i$i21 < $874;
       if ($875) {
        $876 = Math_fround($860 - $858);
        $877 = Math_fround($fabsf$i$i$i21 - $856);
        $878 = Math_fround($876 * $877);
        $879 = Math_fround($862 * $878);
        $880 = Math_fround($858 + $879);
        $mu$0$i = $880;
       } else {
        $mu$0$i = $860;
       }
      }
      $881 = Math_fround($470 * $mu$0$i);
      $882 = ((($outputData) + ($i2$088<<2)|0) + 276|0);
      HEAPF32[$882>>2] = $881;
      $883 = Math_fround($470 * $763);
      $884 = $883 > Math_fround(0.0);
      if ($884) {
       $885 = ((($59) + (($i2$088*12)|0)|0) + 736|0);
       $886 = Math_fround(HEAPF32[$885>>2]);
       $887 = Math_fround($886 * Math_fround(2.0));
       $888 = ((($59) + (($i2$088*12)|0)|0) + 740|0);
       $889 = Math_fround(HEAPF32[$888>>2]);
       $890 = Math_fround($889 * Math_fround(2.0));
       $891 = ((($59) + (($i2$088*12)|0)|0) + 744|0);
       $892 = Math_fround(HEAPF32[$891>>2]);
       $893 = Math_fround($892 * Math_fround(2.0));
       $894 = Math_fround(HEAPF32[$69>>2]);
       $895 = Math_fround($894 * $894);
       $896 = Math_fround($895 + Math_fround(-0.5));
       $897 = Math_fround(HEAPF32[$73>>2]);
       $898 = Math_fround($887 * $897);
       $899 = Math_fround(HEAPF32[$76>>2]);
       $900 = Math_fround($890 * $899);
       $901 = Math_fround($898 + $900);
       $902 = Math_fround(HEAPF32[$80>>2]);
       $903 = Math_fround($893 * $902);
       $904 = Math_fround($901 + $903);
       $905 = Math_fround($887 * $896);
       $906 = Math_fround($893 * $899);
       $907 = Math_fround($890 * $902);
       $908 = Math_fround($906 - $907);
       $909 = Math_fround($894 * $908);
       $910 = Math_fround($905 + $909);
       $911 = Math_fround($897 * $904);
       $912 = Math_fround($911 + $910);
       $913 = Math_fround($890 * $896);
       $914 = Math_fround($887 * $902);
       $915 = Math_fround($893 * $897);
       $916 = Math_fround($914 - $915);
       $917 = Math_fround($894 * $916);
       $918 = Math_fround($913 + $917);
       $919 = Math_fround($899 * $904);
       $920 = Math_fround($919 + $918);
       $921 = Math_fround($893 * $896);
       $922 = Math_fround($890 * $897);
       $923 = Math_fround($887 * $899);
       $924 = Math_fround($922 - $923);
       $925 = Math_fround($894 * $924);
       $926 = Math_fround($921 + $925);
       $927 = Math_fround($902 * $904);
       $928 = Math_fround($926 + $927);
       $929 = ((($59) + (($i2$088*48)|0)|0) + 228|0);
       $930 = Math_fround(HEAPF32[$327>>2]);
       $931 = Math_fround(HEAPF32[523936>>2]);
       $932 = $fabsf$i$i$i24 < $931;
       do {
        if ($932) {
         $933 = Math_fround(HEAPF32[$929>>2]);
         $fabsf$i$i$i13 = (Math_fround(Math_abs((Math_fround($797)))));
         $934 = Math_fround($931 * $933);
         $$not$i14 = !($fabsf$i$i$i13 < $934);
         $brmerge$i15 = $$not$i14 | $120;
         if ($brmerge$i15) {
          $storemerge$i16 = Math_fround(0.0);
          break;
         }
         $935 = Math_fround($49 + $930);
         $storemerge$i16 = $935;
        } else {
         $storemerge$i16 = Math_fround(0.0);
        }
       } while(0);
       $notlhs$i = !($fabsf$i$i$i24 < $931);
       $notrhs$i = $797 != Math_fround(0.0);
       $or$cond$not$i = $notrhs$i | $notlhs$i;
       $brmerge$i10 = $or$cond$not$i | $120;
       $brmerge$not$i = $brmerge$i10 ^ 1;
       $936 = $storemerge$i16 > Math_fround(1.0);
       $or$cond1$i = $936 | $brmerge$not$i;
       if ($or$cond1$i) {
        $937 = Math_fround($789 * Math_fround(0.00999999977648258209228));
        $947 = $937;$948 = 1;
       } else {
        $947 = Math_fround(0.0);$948 = 0;
       }
       $938 = Math_fround($939 * $773);
       $940 = Math_fround($941 * $775);
       $942 = Math_fround($938 + $940);
       $943 = Math_fround($944 * $777);
       $945 = Math_fround($942 + $943);
       $946 = Math_fround($947 + $945);
       HEAPF32[$327>>2] = $storemerge$i16;
       HEAP8[$344>>0] = $948;
       HEAPF32[$345>>2] = $946;
       $949 = ((($outputData) + (($i2$088*12)|0)|0) + 704|0);
       HEAPF32[$949>>2] = $773;
       $950 = ((($outputData) + (($i2$088*12)|0)|0) + 708|0);
       HEAPF32[$950>>2] = $775;
       $951 = ((($outputData) + (($i2$088*12)|0)|0) + 712|0);
       HEAPF32[$951>>2] = $777;
       $952 = ((($outputData) + (($i2$088*12)|0)|0) + 656|0);
       HEAPF32[$952>>2] = $912;
       $953 = ((($outputData) + (($i2$088*12)|0)|0) + 660|0);
       HEAPF32[$953>>2] = $920;
       $954 = ((($outputData) + (($i2$088*12)|0)|0) + 664|0);
       HEAPF32[$954>>2] = $928;
       $955 = ($948<<24>>24)!=(0);
       $956 = $955 ? Math_fround(0.0) : $834;
       HEAPF32[$833>>2] = $956;
       $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($794)))));
       $957 = Math_fround(HEAPF32[523936>>2]);
       $$not$i = !($fabsf$i$i$i < $957);
       $brmerge$i = $$not$i | $120;
       do {
        if ($brmerge$i) {
         $969 = Math_fround(0.0);$970 = 0;$storemerge$i83 = Math_fround(0.0);
        } else {
         $958 = Math_fround(HEAPF32[$330>>2]);
         $959 = Math_fround($49 + $958);
         $960 = $storemerge$i16 > Math_fround(0.0);
         $961 = $959 > Math_fround(1.0);
         $or$cond$i = $960 & $961;
         if (!($or$cond$i)) {
          $969 = Math_fround(0.0);$970 = 0;$storemerge$i83 = $959;
          break;
         }
         $962 = Math_fround($794 * Math_fround(0.100000001490116119385));
         $969 = $962;$970 = 1;$storemerge$i83 = $959;
        }
       } while(0);
       $963 = Math_fround($939 * $779);
       $964 = Math_fround($941 * $781);
       $965 = Math_fround($963 + $964);
       $966 = Math_fround($944 * $783);
       $967 = Math_fround($965 + $966);
       $968 = Math_fround($969 + $967);
       HEAPF32[$330>>2] = $storemerge$i83;
       HEAP8[$346>>0] = $970;
       HEAPF32[$347>>2] = $968;
       $971 = ((($outputData) + (($i2$088*12)|0)|0) + 820|0);
       HEAPF32[$971>>2] = $779;
       $972 = ((($outputData) + (($i2$088*12)|0)|0) + 824|0);
       HEAPF32[$972>>2] = $781;
       $973 = ((($outputData) + (($i2$088*12)|0)|0) + 828|0);
       HEAPF32[$973>>2] = $783;
       $974 = ((($outputData) + (($i2$088*12)|0)|0) + 772|0);
       HEAPF32[$974>>2] = $912;
       $975 = ((($outputData) + (($i2$088*12)|0)|0) + 776|0);
       HEAPF32[$975>>2] = $920;
       $976 = ((($outputData) + (($i2$088*12)|0)|0) + 780|0);
       HEAPF32[$976>>2] = $928;
       $977 = ($970<<24>>24)!=(0);
       $978 = $977 ? Math_fround(0.0) : $805;
       HEAPF32[$835>>2] = $978;
       HEAPF32[$wheelTorque>>2] = Math_fround(0.0);
       HEAPF32[$tireLongForceMag>>2] = Math_fround(0.0);
       HEAPF32[$tireLatForceMag>>2] = Math_fround(0.0);
       HEAPF32[$tireAlignMoment>>2] = Math_fround(0.0);
       $979 = Math_fround(HEAPF32[$761>>2]);
       $980 = Math_fround($53 * $979);
       $981 = Math_fround(HEAPF32[$929>>2]);
       $982 = HEAP32[$161>>2]|0;
       $983 = (($63) + ($i2$088<<2)|0);
       $984 = HEAP32[$983>>2]|0;
       FUNCTION_TABLE_viffffffffffffiiii[$982 & 1]($984,$881,$956,$978,$camber$0,$797,$798,$981,$980,$$0$i,$763,$53,$51,$wheelTorque,$tireLongForceMag,$tireLatForceMag,$tireAlignMoment);
       $985 = Math_fround(HEAPF32[$wheelTorque>>2]);
       $986 = ((($outputData) + ($i2$088<<2)|0) + 468|0);
       HEAPF32[$986>>2] = $985;
       $987 = Math_fround(HEAPF32[$tireLongForceMag>>2]);
       $988 = Math_fround($987 * $773);
       $989 = Math_fround($987 * $775);
       $990 = Math_fround($987 * $777);
       $991 = Math_fround(HEAPF32[$tireLatForceMag>>2]);
       $992 = Math_fround($991 * $779);
       $993 = Math_fround($991 * $781);
       $994 = Math_fround($991 * $783);
       $995 = Math_fround($988 + $992);
       $996 = Math_fround($989 + $993);
       $997 = Math_fround($990 + $994);
       $998 = Math_fround($920 * $997);
       $999 = Math_fround($928 * $996);
       $1000 = Math_fround($998 - $999);
       $1001 = Math_fround($928 * $995);
       $1002 = Math_fround($912 * $997);
       $1003 = Math_fround($1001 - $1002);
       $1004 = Math_fround($912 * $996);
       $1005 = Math_fround($920 * $995);
       $1006 = Math_fround($1004 - $1005);
       $1007 = Math_fround(HEAPF32[$147>>2]);
       $1008 = Math_fround($995 + $1007);
       HEAPF32[$147>>2] = $1008;
       $1009 = Math_fround(HEAPF32[$148>>2]);
       $1010 = Math_fround($996 + $1009);
       HEAPF32[$148>>2] = $1010;
       $1011 = Math_fround(HEAPF32[$149>>2]);
       $1012 = Math_fround($997 + $1011);
       HEAPF32[$149>>2] = $1012;
       $1013 = Math_fround(HEAPF32[$150>>2]);
       $1014 = Math_fround($1000 + $1013);
       HEAPF32[$150>>2] = $1014;
       $1015 = Math_fround(HEAPF32[$151>>2]);
       $1016 = Math_fround($1003 + $1015);
       HEAPF32[$151>>2] = $1016;
       $1017 = Math_fround(HEAPF32[$152>>2]);
       $1018 = Math_fround($1006 + $1017);
       HEAPF32[$152>>2] = $1018;
       $1019 = (0|0)==(0|0);
       if (!($1019)) {
        $1020 = Math_fround(HEAPF32[$133>>2]);
        $1021 = Math_fround($912 + $1020);
        $1022 = Math_fround(HEAPF32[$134>>2]);
        $1023 = Math_fround($920 + $1022);
        $1024 = Math_fround(HEAPF32[$135>>2]);
        $1025 = Math_fround($928 + $1024);
        $1026 = (0 + (($i2$088*12)|0)|0);
        HEAPF32[$1026>>2] = $1021;
        $1027 = ((0 + (($i2$088*12)|0)|0) + 4|0);
        HEAPF32[$1027>>2] = $1023;
        $1028 = ((0 + (($i2$088*12)|0)|0) + 8|0);
        HEAPF32[$1028>>2] = $1025;
       }
       $1029 = (0|0)==(0|0);
       if (!($1029)) {
        $1030 = Math_fround(HEAPF32[$133>>2]);
        $1031 = Math_fround($661 + $1030);
        $1032 = Math_fround(HEAPF32[$134>>2]);
        $1033 = Math_fround($669 + $1032);
        $1034 = Math_fround(HEAPF32[$135>>2]);
        $1035 = Math_fround($677 + $1034);
        $1036 = (0 + (($i2$088*12)|0)|0);
        HEAPF32[$1036>>2] = $1031;
        $1037 = ((0 + (($i2$088*12)|0)|0) + 4|0);
        HEAPF32[$1037>>2] = $1033;
        $1038 = ((0 + (($i2$088*12)|0)|0) + 8|0);
        HEAPF32[$1038>>2] = $1035;
       }
       $1039 = HEAP32[523960>>2]|0;
       $1040 = ($1039|0)==(0|0);
       if ($1040) {
        break;
       }
       $1041 = Math_fround(HEAPF32[$tireLongForceMag>>2]);
       $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($1041)))));
       $1042 = Math_fround($745 * $fabsf$i$i2);
       $1043 = Math_fround($1042 / $715);
       $1044 = (($i2$088) + ($startWheelIndex))|0;
       $1045 = (523960 + ($1044<<2)|0);
       $1046 = HEAP32[$1045>>2]|0;
       $1047 = (($1046) + 28|0);
       HEAPF32[$1047>>2] = $1043;
       $1048 = Math_fround(HEAPF32[$tireLatForceMag>>2]);
       $fabsf$i$i = (Math_fround(Math_abs((Math_fround($1048)))));
       $1049 = Math_fround($745 * $fabsf$i$i);
       $1050 = Math_fround($1049 / $715);
       $1051 = (($1046) + 36|0);
       HEAPF32[$1051>>2] = $1050;
       $1052 = Math_fround(HEAPF32[$tireAlignMoment>>2]);
       $1053 = Math_fround($745 * $1052);
       $1054 = Math_fround($1053 / $715);
       $1055 = (($1046) + 40|0);
       HEAPF32[$1055>>2] = $1054;
       $1056 = Math_fround(HEAPF32[$833>>2]);
       $1057 = (($1046) + 24|0);
       HEAPF32[$1057>>2] = $1056;
       $1058 = Math_fround(HEAPF32[$835>>2]);
       $1059 = (($1046) + 32|0);
       HEAPF32[$1059>>2] = $1058;
       $1060 = Math_fround(HEAPF32[$882>>2]);
       $1061 = (($1046) + 20|0);
       HEAPF32[$1061>>2] = $1060;
      }
     }
    }
   }
  } while(0);
  $1062 = (($i2$088) + 1)|0;
  $exitcond = ($1062|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $i2$088 = $1062;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15computeTireDirsERKNS_6PxVec3ES2_fRS0_S3_($chassisLatDir,$hitNorm,$wheelSteerAngle,$tireLongDir,$tireLatDir) {
 $chassisLatDir = $chassisLatDir|0;
 $hitNorm = $hitNorm|0;
 $wheelSteerAngle = Math_fround($wheelSteerAngle);
 $tireLongDir = $tireLongDir|0;
 $tireLatDir = $tireLatDir|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($chassisLatDir) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($hitNorm) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 * $3);
 $5 = (($chassisLatDir) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($hitNorm) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = Math_fround($4 - $9);
 $11 = Math_fround(HEAPF32[$hitNorm>>2]);
 $12 = Math_fround($6 * $11);
 $13 = Math_fround(HEAPF32[$chassisLatDir>>2]);
 $14 = Math_fround($3 * $13);
 $15 = Math_fround($12 - $14);
 $16 = Math_fround($8 * $13);
 $17 = Math_fround($1 * $11);
 $18 = Math_fround($16 - $17);
 $19 = Math_fround($8 * $18);
 $20 = Math_fround($3 * $15);
 $21 = Math_fround($19 - $20);
 $22 = Math_fround($3 * $10);
 $23 = Math_fround($11 * $18);
 $24 = Math_fround($22 - $23);
 $25 = Math_fround($11 * $15);
 $26 = Math_fround($8 * $10);
 $27 = Math_fround($25 - $26);
 $28 = Math_fround($10 * $10);
 $29 = Math_fround($15 * $15);
 $30 = Math_fround($28 + $29);
 $31 = Math_fround($18 * $18);
 $32 = Math_fround($31 + $30);
 $33 = (Math_fround(Math_sqrt((Math_fround($32)))));
 $34 = $33 > Math_fround(0.0);
 if ($34) {
  $35 = Math_fround(Math_fround(1.0) / $33);
  $36 = Math_fround($10 * $35);
  $37 = Math_fround($15 * $35);
  $38 = Math_fround($18 * $35);
  $53 = $36;$55 = $37;$57 = $38;
 } else {
  $53 = $10;$55 = $15;$57 = $18;
 }
 $39 = Math_fround($21 * $21);
 $40 = Math_fround($24 * $24);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($27 * $27);
 $43 = Math_fround($42 + $41);
 $44 = (Math_fround(Math_sqrt((Math_fround($43)))));
 $45 = $44 > Math_fround(0.0);
 if ($45) {
  $46 = Math_fround(Math_fround(1.0) / $44);
  $47 = Math_fround($21 * $46);
  $48 = Math_fround($24 * $46);
  $49 = Math_fround($27 * $46);
  $59 = $47;$61 = $48;$63 = $49;
 } else {
  $59 = $21;$61 = $24;$63 = $27;
 }
 $50 = (Math_fround(+(Math_cos((+$wheelSteerAngle)))));
 $51 = (Math_fround(+(Math_sin((+$wheelSteerAngle)))));
 $52 = Math_fround($53 * $50);
 $54 = Math_fround($55 * $50);
 $56 = Math_fround($57 * $50);
 $58 = Math_fround($59 * $51);
 $60 = Math_fround($61 * $51);
 $62 = Math_fround($63 * $51);
 $64 = Math_fround($52 + $58);
 $65 = Math_fround($54 + $60);
 $66 = Math_fround($56 + $62);
 $67 = Math_fround($59 * $50);
 $68 = Math_fround($61 * $50);
 $69 = Math_fround($63 * $50);
 $70 = Math_fround($53 * $51);
 $71 = Math_fround($55 * $51);
 $72 = Math_fround($57 * $51);
 $73 = Math_fround($67 - $70);
 $74 = Math_fround($68 - $71);
 $75 = Math_fround($69 - $72);
 HEAPF32[$tireLongDir>>2] = $64;
 $76 = (($tireLongDir) + 4|0);
 HEAPF32[$76>>2] = $65;
 $77 = (($tireLongDir) + 8|0);
 HEAPF32[$77>>2] = $66;
 HEAPF32[$tireLatDir>>2] = $73;
 $78 = (($tireLatDir) + 4|0);
 HEAPF32[$78>>2] = $74;
 $79 = (($tireLatDir) + 8|0);
 HEAPF32[$79>>2] = $75;
 STACKTOP = sp;return;
}
function __ZN5physx19updateCachedHitDataEPKjPKNS_6PxVec4EPKfS6_PNS_23PxVehicleWheels4DynDataE($cachedHitCounts,$cachedHitPlanes,$cachedHitDistances,$cachedFrictionMultipliers,$wheels4DynData) {
 $cachedHitCounts = $cachedHitCounts|0;
 $cachedHitPlanes = $cachedHitPlanes|0;
 $cachedHitDistances = $cachedHitDistances|0;
 $cachedFrictionMultipliers = $cachedFrictionMultipliers|0;
 $wheels4DynData = $wheels4DynData|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($wheels4DynData) + 196|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($wheels4DynData) + 200|0);
  HEAP8[$3>>0] = 1;
 }
 $4 = (($wheels4DynData) + 80|0);
 $5 = (($wheels4DynData) + 176|0);
 $6 = (($wheels4DynData) + 160|0);
 $7 = (($wheels4DynData) + 144|0);
 $8 = HEAP32[$cachedHitCounts>>2]|0;
 $9 = $8&65535;
 HEAP16[$5>>1] = $9;
 $10 = Math_fround(HEAPF32[$cachedHitPlanes>>2]);
 HEAPF32[$4>>2] = $10;
 $11 = (($cachedHitPlanes) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($wheels4DynData) + 84|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($cachedHitPlanes) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($wheels4DynData) + 88|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($cachedHitPlanes) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($wheels4DynData) + 92|0);
 HEAPF32[$19>>2] = $18;
 $20 = Math_fround(HEAPF32[$cachedHitDistances>>2]);
 HEAPF32[$6>>2] = $20;
 $21 = Math_fround(HEAPF32[$cachedFrictionMultipliers>>2]);
 HEAPF32[$7>>2] = $21;
 $22 = (($cachedHitCounts) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23&65535;
 $25 = (($wheels4DynData) + 178|0);
 HEAP16[$25>>1] = $24;
 $26 = (($cachedHitPlanes) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($wheels4DynData) + 96|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($cachedHitPlanes) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($wheels4DynData) + 100|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($cachedHitPlanes) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($wheels4DynData) + 104|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($cachedHitPlanes) + 28|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($wheels4DynData) + 108|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($cachedHitDistances) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($wheels4DynData) + 164|0);
 HEAPF32[$40>>2] = $39;
 $41 = (($cachedFrictionMultipliers) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($wheels4DynData) + 148|0);
 HEAPF32[$43>>2] = $42;
 $44 = (($cachedHitCounts) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45&65535;
 $47 = (($wheels4DynData) + 180|0);
 HEAP16[$47>>1] = $46;
 $48 = (($cachedHitPlanes) + 32|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($wheels4DynData) + 112|0);
 HEAPF32[$50>>2] = $49;
 $51 = (($cachedHitPlanes) + 36|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($wheels4DynData) + 116|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($cachedHitPlanes) + 40|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($wheels4DynData) + 120|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($cachedHitPlanes) + 44|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($wheels4DynData) + 124|0);
 HEAPF32[$59>>2] = $58;
 $60 = (($cachedHitDistances) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($wheels4DynData) + 168|0);
 HEAPF32[$62>>2] = $61;
 $63 = (($cachedFrictionMultipliers) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($wheels4DynData) + 152|0);
 HEAPF32[$65>>2] = $64;
 $66 = (($cachedHitCounts) + 12|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = $67&65535;
 $69 = (($wheels4DynData) + 182|0);
 HEAP16[$69>>1] = $68;
 $70 = (($cachedHitPlanes) + 48|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($wheels4DynData) + 128|0);
 HEAPF32[$72>>2] = $71;
 $73 = (($cachedHitPlanes) + 52|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($wheels4DynData) + 132|0);
 HEAPF32[$75>>2] = $74;
 $76 = (($cachedHitPlanes) + 56|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($wheels4DynData) + 136|0);
 HEAPF32[$78>>2] = $77;
 $79 = (($cachedHitPlanes) + 60|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($wheels4DynData) + 140|0);
 HEAPF32[$81>>2] = $80;
 $82 = (($cachedHitDistances) + 12|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($wheels4DynData) + 172|0);
 HEAPF32[$84>>2] = $83;
 $85 = (($cachedFrictionMultipliers) + 12|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($wheels4DynData) + 156|0);
 HEAPF32[$87>>2] = $86;
 STACKTOP = sp;return;
}
function __ZN5physx49solveDrive4WInternaDynamicsEnginePlusDrivenWheelsERKNS_19ImplicitSolverInputEPNS_20ImplicitSolverOutputE($input,$output) {
 $input = $input|0;
 $output = $output|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert10 = 0, $$phi$trans$insert12 = 0, $$phi$trans$insert8 = 0, $$pre = Math_fround(0), $$pre$phiZ2D = 0, $$pre11 = Math_fround(0), $$pre13 = Math_fround(0), $$pre14$pre = 0, $$pre14$pre$phiZZ2D = 0, $$pre7 = Math_fround(0), $$pre9 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0;
 var $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0;
 var $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0;
 var $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0;
 var $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0;
 var $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $A = 0, $b = 0, $exitcond = 0, $i$01 = 0, $result = 0, $solver = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4528|0;
 $A = sp + 2408|0;
 $b = sp;
 $result = sp + 96|0;
 $solver = sp + 192|0;
 $0 = Math_fround(HEAPF32[$input>>2]);
 $1 = (($input) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($input) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($input) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($input) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($input) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($input) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($input) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($input) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($input) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($input) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($input) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($input) + 64|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($input) + 68|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($output) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$output>>2]|0;
 $30 = Math_fround($2 * $4);
 $31 = Math_fround($4 * $30);
 $32 = (($A) + 2116|0);
 HEAP32[$32>>2] = 5;
 $33 = (($b) + 92|0);
 HEAP32[$33>>2] = 5;
 $34 = (($result) + 92|0);
 HEAP32[$34>>2] = 5;
 $35 = (($28) + 76|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$16>>2]);
 $38 = (($16) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($16) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($16) + 12|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 ;HEAP32[$result+0>>2]=HEAP32[$29+0>>2]|0;HEAP32[$result+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$result+8>>2]=HEAP32[$29+8>>2]|0;HEAP32[$result+12>>2]=HEAP32[$29+12>>2]|0;
 $60 = $37;$i$01 = 0;
 while(1) {
  $44 = ((($24) + (($i$01*48)|0)|0) + 232|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($0 * $45);
  $47 = (($14) + ($i$01<<2)|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($31 * $46);
  $50 = Math_fround($48 * $49);
  $51 = Math_fround($37 * $50);
  $52 = (($A) + (($i$01*92)|0)|0);
  HEAPF32[$52>>2] = $51;
  $53 = Math_fround($50 * $39);
  $54 = ((($A) + (($i$01*92)|0)|0) + 4|0);
  HEAPF32[$54>>2] = $53;
  $55 = Math_fround($50 * $41);
  $56 = ((($A) + (($i$01*92)|0)|0) + 8|0);
  HEAPF32[$56>>2] = $55;
  $57 = Math_fround($50 * $43);
  $58 = ((($A) + (($i$01*92)|0)|0) + 12|0);
  HEAPF32[$58>>2] = $57;
  $59 = Math_fround($50 * $60);
  $61 = Math_fround($59 + Math_fround(1.0));
  $62 = ((($24) + (($i$01*48)|0)|0) + 208|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($46 * $63);
  $65 = Math_fround($61 + $64);
  $66 = ((($A) + (($i$01*92)|0)|0) + ($i$01<<2)|0);
  HEAPF32[$66>>2] = $65;
  $67 = Math_fround($30 * $46);
  $68 = Math_fround($48 * $67);
  $69 = Math_fround(-$68);
  $70 = ((($A) + (($i$01*92)|0)|0) + 16|0);
  HEAPF32[$70>>2] = $69;
  $71 = (($29) + ($i$01<<2)|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($18) + ($i$01<<2)|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($22) + ($i$01<<2)|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($74 + $76);
  $78 = Math_fround($46 * $77);
  $79 = Math_fround($72 + $78);
  $80 = (($b) + ($i$01<<2)|0);
  HEAPF32[$80>>2] = $79;
  $81 = (($i$01) + 1)|0;
  $exitcond = ($81|0)==(4);
  if ($exitcond) {
   break;
  }
  $$phi$trans$insert = (($16) + ($81<<2)|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $60 = $$pre;$i$01 = $81;
 }
 $82 = (($26) + 104|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($0 * $83);
 $85 = Math_fround($2 * $84);
 $86 = Math_fround($4 * $85);
 $87 = Math_fround(-$86);
 $88 = Math_fround($37 * $87);
 $89 = (($A) + 368|0);
 HEAPF32[$89>>2] = $88;
 $90 = Math_fround($39 * $87);
 $91 = (($A) + 372|0);
 HEAPF32[$91>>2] = $90;
 $92 = Math_fround($41 * $87);
 $93 = (($A) + 376|0);
 HEAPF32[$93>>2] = $92;
 $94 = Math_fround($43 * $87);
 $95 = (($A) + 380|0);
 HEAPF32[$95>>2] = $94;
 $96 = Math_fround($2 + $12);
 $97 = Math_fround($96 * $84);
 $98 = Math_fround($97 + Math_fround(1.0));
 $99 = (($A) + 384|0);
 HEAPF32[$99>>2] = $98;
 $100 = Math_fround($10 * $84);
 $101 = Math_fround($36 + $100);
 $102 = (($b) + 16|0);
 HEAPF32[$102>>2] = $101;
 $103 = (($result) + 16|0);
 HEAPF32[$103>>2] = $36;
 $104 = ($6|0)==(1);
 if ($104) {
  $105 = (($solver) + 2208|0);
  HEAP32[$105>>2] = 0;
  __ZN5physx16MatrixNNLUSolver11decomposeLUERKNS_8MatrixNNE($solver,$A);
  __ZNK5physx16MatrixNNLUSolver5solveERKNS_7VectorNERS1_($solver,$b,$result);
 } else {
  __ZNK5physx24MatrixNGaussSeidelSolver5solveEjfRKNS_8MatrixNNERKNS_7VectorNERS4_(0,$8,Math_fround(1.00000001335143196002E-10),$A,$b,$result);
 }
 $106 = HEAP8[$20>>0]|0;
 $107 = ($106<<24>>24)==(0);
 if ($107) {
  $$pre7 = Math_fround(HEAPF32[$result>>2]);
  $155 = $$pre7;
  label = 10;
 } else {
  $108 = Math_fround(HEAPF32[$29>>2]);
  $109 = Math_fround(HEAPF32[$result>>2]);
  $110 = Math_fround($108 * $109);
  $111 = !($110 <= Math_fround(0.0));
  if ($111) {
   $155 = $109;
   label = 10;
  } else {
   $112 = Math_fround(0.0);
  }
 }
 if ((label|0) == 10) {
  $112 = $155;
 }
 HEAPF32[$result>>2] = $112;
 $113 = (($20) + 1|0);
 $114 = HEAP8[$113>>0]|0;
 $115 = ($114<<24>>24)==(0);
 if ($115) {
  $$phi$trans$insert8 = (($result) + 4|0);
  $$pre9 = Math_fround(HEAPF32[$$phi$trans$insert8>>2]);
  $156 = $$pre9;
  label = 14;
 } else {
  $116 = (($29) + 4|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = (($result) + 4|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround($117 * $119);
  $121 = !($120 <= Math_fround(0.0));
  if ($121) {
   $156 = $119;
   label = 14;
  } else {
   $123 = Math_fround(0.0);
  }
 }
 if ((label|0) == 14) {
  $123 = $156;
 }
 $122 = (($result) + 4|0);
 HEAPF32[$122>>2] = $123;
 $124 = (($20) + 2|0);
 $125 = HEAP8[$124>>0]|0;
 $126 = ($125<<24>>24)==(0);
 if ($126) {
  $$phi$trans$insert10 = (($result) + 8|0);
  $$pre11 = Math_fround(HEAPF32[$$phi$trans$insert10>>2]);
  $157 = $$pre11;
  label = 18;
 } else {
  $127 = (($29) + 8|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = (($result) + 8|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($128 * $130);
  $132 = !($131 <= Math_fround(0.0));
  if ($132) {
   $157 = $130;
   label = 18;
  } else {
   $134 = Math_fround(0.0);
  }
 }
 if ((label|0) == 18) {
  $134 = $157;
 }
 $133 = (($result) + 8|0);
 HEAPF32[$133>>2] = $134;
 $135 = (($20) + 3|0);
 $136 = HEAP8[$135>>0]|0;
 $137 = ($136<<24>>24)==(0);
 if ($137) {
  $$phi$trans$insert12 = (($result) + 12|0);
  $$pre13 = Math_fround(HEAPF32[$$phi$trans$insert12>>2]);
  $$pre14$pre = (($29) + 12|0);
  $$pre14$pre$phiZZ2D = $$pre14$pre;$158 = $$pre13;
 } else {
  $138 = (($29) + 12|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = (($result) + 12|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = Math_fround($139 * $141);
  $143 = !($142 <= Math_fround(0.0));
  if ($143) {
   $$pre14$pre$phiZZ2D = $138;$158 = $141;
  } else {
   $$pre$phiZ2D = $138;$145 = Math_fround(0.0);
   $144 = (($result) + 12|0);
   HEAPF32[$144>>2] = $145;
   $146 = Math_fround(HEAPF32[$103>>2]);
   $147 = (($26) + 88|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = $146 < Math_fround(0.0);
   $150 = $149 ? Math_fround(0.0) : $146;
   $151 = $150 > $148;
   $152 = $151 ? $148 : $150;
   HEAPF32[$29>>2] = $112;
   $153 = (($29) + 4|0);
   HEAPF32[$153>>2] = $123;
   $154 = (($29) + 8|0);
   HEAPF32[$154>>2] = $134;
   HEAPF32[$$pre$phiZ2D>>2] = $145;
   HEAPF32[$35>>2] = $152;
   STACKTOP = sp;return;
  }
 }
 $$pre$phiZ2D = $$pre14$pre$phiZZ2D;$145 = $158;
 $144 = (($result) + 12|0);
 HEAPF32[$144>>2] = $145;
 $146 = Math_fround(HEAPF32[$103>>2]);
 $147 = (($26) + 88|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = $146 < Math_fround(0.0);
 $150 = $149 ? Math_fround(0.0) : $146;
 $151 = $150 > $148;
 $152 = $151 ? $148 : $150;
 HEAPF32[$29>>2] = $112;
 $153 = (($29) + 4|0);
 HEAPF32[$153>>2] = $123;
 $154 = (($29) + 8|0);
 HEAPF32[$154>>2] = $134;
 HEAPF32[$$pre$phiZ2D>>2] = $145;
 HEAPF32[$35>>2] = $152;
 STACKTOP = sp;return;
}
function __ZNK5physx24MatrixNGaussSeidelSolver5solveEjfRKNS_8MatrixNNERKNS_7VectorNERS4_($this,$maxIterations,$tolerance,$A,$b,$result) {
 $this = $this|0;
 $maxIterations = $maxIterations|0;
 $tolerance = Math_fround($tolerance);
 $A = $A|0;
 $b = $b|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $DInv = 0, $bLength2$0$lcssa = Math_fround(0), $bLength2$028 = Math_fround(0), $e$013$us = Math_fround(0);
 var $exitcond = 0, $exitcond34 = 0, $exitcond35 = 0, $exitcond39 = 0, $exitcond41 = 0, $exitcond43 = 0, $i$029 = 0, $i3$020$us = 0, $indvars$iv = 0, $indvars$iv$next = 0, $iteration$027 = 0, $j$02 = 0, $j2$04 = 0, $j4$014$us = 0, $l$0$lcssa = Math_fround(0), $l$01 = Math_fround(0), $or$cond = 0, $or$cond26 = 0, $phitmp = Math_fround(0), $rLength2$0$lcssa = Math_fround(0);
 var $rLength2$019$us = Math_fround(0), $u$0$lcssa = Math_fround(0), $u$03 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $DInv = sp;
 $0 = (($A) + 2116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($DInv) + 92|0);
 HEAP32[$2>>2] = $1;
 $3 = ($1|0)==(0);
 if ($3) {
  $bLength2$0$lcssa = Math_fround(1.00000001335143196002E-10);
 } else {
  $bLength2$028 = Math_fround(0.0);$i$029 = 0;
  while(1) {
   $7 = ((($A) + (($i$029*92)|0)|0) + ($i$029<<2)|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = Math_fround(Math_fround(1.0) / $8);
   $10 = (($DInv) + ($i$029<<2)|0);
   HEAPF32[$10>>2] = $9;
   $11 = (($b) + ($i$029<<2)|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = Math_fround($12 * $12);
   $4 = Math_fround($bLength2$028 + $13);
   $14 = (($i$029) + 1)|0;
   $exitcond43 = ($14|0)==($1|0);
   if ($exitcond43) {
    break;
   } else {
    $bLength2$028 = $4;$i$029 = $14;
   }
  }
  $phitmp = Math_fround($4 + Math_fround(1.00000001335143196002E-10));
  $bLength2$0$lcssa = $phitmp;
 }
 $5 = ($maxIterations|0)!=(0);
 $6 = $tolerance < Math_fround(3.40282346638528859812E+38);
 $or$cond26 = $5 & $6;
 if ($or$cond26) {
  $iteration$027 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  if ($3) {
   $rLength2$0$lcssa = Math_fround(0.0);
  } else {
   $indvars$iv = 0;
   while(1) {
    $15 = ($indvars$iv|0)==(0);
    if ($15) {
     $l$0$lcssa = Math_fround(0.0);
    } else {
     $j$02 = 0;$l$01 = Math_fround(0.0);
     while(1) {
      $16 = ((($A) + (($indvars$iv*92)|0)|0) + ($j$02<<2)|0);
      $17 = Math_fround(HEAPF32[$16>>2]);
      $18 = (($result) + ($j$02<<2)|0);
      $19 = Math_fround(HEAPF32[$18>>2]);
      $20 = Math_fround($17 * $19);
      $21 = Math_fround($l$01 + $20);
      $22 = (($j$02) + 1)|0;
      $exitcond = ($22|0)==($indvars$iv|0);
      if ($exitcond) {
       $l$0$lcssa = $21;
       break;
      } else {
       $j$02 = $22;$l$01 = $21;
      }
     }
    }
    $indvars$iv$next = (($indvars$iv) + 1)|0;
    $23 = ($indvars$iv$next>>>0)<($1>>>0);
    if ($23) {
     $j2$04 = $indvars$iv$next;$u$03 = Math_fround(0.0);
     while(1) {
      $24 = ((($A) + (($indvars$iv*92)|0)|0) + ($j2$04<<2)|0);
      $25 = Math_fround(HEAPF32[$24>>2]);
      $26 = (($result) + ($j2$04<<2)|0);
      $27 = Math_fround(HEAPF32[$26>>2]);
      $28 = Math_fround($25 * $27);
      $29 = Math_fround($u$03 + $28);
      $30 = (($j2$04) + 1)|0;
      $exitcond34 = ($30|0)==($1|0);
      if ($exitcond34) {
       $u$0$lcssa = $29;
       break;
      } else {
       $j2$04 = $30;$u$03 = $29;
      }
     }
    } else {
     $u$0$lcssa = Math_fround(0.0);
    }
    $31 = (($DInv) + ($indvars$iv<<2)|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = (($b) + ($indvars$iv<<2)|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = Math_fround($34 - $l$0$lcssa);
    $36 = Math_fround($35 - $u$0$lcssa);
    $37 = Math_fround($32 * $36);
    $38 = (($result) + ($indvars$iv<<2)|0);
    HEAPF32[$38>>2] = $37;
    $exitcond35 = ($indvars$iv$next|0)==($1|0);
    if ($exitcond35) {
     break;
    } else {
     $indvars$iv = $indvars$iv$next;
    }
   }
   if ($3) {
    $rLength2$0$lcssa = Math_fround(0.0);
   } else {
    $i3$020$us = 0;$rLength2$019$us = Math_fround(0.0);
    while(1) {
     $49 = (($b) + ($i3$020$us<<2)|0);
     $50 = Math_fround(HEAPF32[$49>>2]);
     $51 = Math_fround(-$50);
     $e$013$us = $51;$j4$014$us = 0;
     while(1) {
      $43 = ((($A) + (($i3$020$us*92)|0)|0) + ($j4$014$us<<2)|0);
      $44 = Math_fround(HEAPF32[$43>>2]);
      $45 = (($result) + ($j4$014$us<<2)|0);
      $46 = Math_fround(HEAPF32[$45>>2]);
      $47 = Math_fround($44 * $46);
      $40 = Math_fround($e$013$us + $47);
      $48 = (($j4$014$us) + 1)|0;
      $exitcond39 = ($48|0)==($1|0);
      if ($exitcond39) {
       break;
      } else {
       $e$013$us = $40;$j4$014$us = $48;
      }
     }
     $39 = Math_fround($40 * $40);
     $41 = Math_fround($rLength2$019$us + $39);
     $42 = (($i3$020$us) + 1)|0;
     $exitcond41 = ($42|0)==($1|0);
     if ($exitcond41) {
      $rLength2$0$lcssa = $41;
      break;
     } else {
      $i3$020$us = $42;$rLength2$019$us = $41;
     }
    }
   }
  }
  $52 = Math_fround($rLength2$0$lcssa / $bLength2$0$lcssa);
  $53 = (($iteration$027) + 1)|0;
  $54 = ($53>>>0)<($maxIterations>>>0);
  $55 = $52 > $tolerance;
  $or$cond = $54 & $55;
  if ($or$cond) {
   $iteration$027 = $53;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx50solveDriveNWInternalDynamicsEnginePlusDrivenWheelsERKNS_19ImplicitSolverInputEPNS_20ImplicitSolverOutputE($input,$output) {
 $input = $input|0;
 $output = $output|0;
 var $$phi$trans$insert = 0, $$pre = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $A = 0, $b = 0, $exitcond = 0, $exitcond19 = 0, $exitcond20 = 0;
 var $exitcond22 = 0, $exitcond23 = 0, $i$014$us = 0, $i2$06 = 0, $i4$02 = 0, $i5$01 = 0, $j$010$us = 0, $result = 0, $solver = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4528|0;
 $A = sp + 2408|0;
 $b = sp;
 $result = sp + 96|0;
 $solver = sp + 192|0;
 $0 = Math_fround(HEAPF32[$input>>2]);
 $1 = (($input) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($input) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($input) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($input) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($input) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($input) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($input) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($input) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($input) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($input) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($input) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($input) + 60|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($input) + 64|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($input) + 68|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($output) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$output>>2]|0;
 $32 = Math_fround($2 * $4);
 $33 = Math_fround($4 * $32);
 $34 = (($24) + 1)|0;
 $35 = (($A) + 2116|0);
 HEAP32[$35>>2] = $34;
 $36 = (($b) + 92|0);
 HEAP32[$36>>2] = $34;
 $37 = (($result) + 92|0);
 HEAP32[$37>>2] = $34;
 $38 = (($30) + 76|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = ($24|0)==(0);
 if ($40) {
  $41 = (($28) + 104|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($0 * $42);
  $96 = $43;
 } else {
  $i$014$us = 0;
  while(1) {
   $50 = $i$014$us >>> 2;
   $51 = $i$014$us & 3;
   $79 = (((($26) + (($50*944)|0)|0) + (($51*48)|0)|0) + 232|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $54 = Math_fround($0 * $80);
   $81 = (($14) + ($i$014$us<<2)|0);
   $59 = Math_fround(HEAPF32[$81>>2]);
   $82 = Math_fround($33 * $54);
   $47 = Math_fround($59 * $82);
   $j$010$us = 0;
   while(1) {
    $74 = (($16) + ($j$010$us<<2)|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = Math_fround($47 * $75);
    $77 = ((($A) + (($i$014$us*92)|0)|0) + ($j$010$us<<2)|0);
    HEAPF32[$77>>2] = $76;
    $78 = (($j$010$us) + 1)|0;
    $exitcond22 = ($78|0)==($24|0);
    if ($exitcond22) {
     break;
    } else {
     $j$010$us = $78;
    }
   }
   $44 = (($16) + ($i$014$us<<2)|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = Math_fround($47 * $45);
   $48 = Math_fround($46 + Math_fround(1.0));
   $49 = (((($26) + (($50*944)|0)|0) + (($51*48)|0)|0) + 208|0);
   $52 = Math_fround(HEAPF32[$49>>2]);
   $53 = Math_fround($54 * $52);
   $55 = Math_fround($48 + $53);
   $56 = ((($A) + (($i$014$us*92)|0)|0) + ($i$014$us<<2)|0);
   HEAPF32[$56>>2] = $55;
   $57 = Math_fround($32 * $54);
   $58 = Math_fround($59 * $57);
   $60 = Math_fround(-$58);
   $61 = ((($A) + (($i$014$us*92)|0)|0) + ($24<<2)|0);
   HEAPF32[$61>>2] = $60;
   $62 = ((($31) + (($50*208)|0)|0) + ($51<<2)|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = (($18) + ($i$014$us<<2)|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = (($22) + ($i$014$us<<2)|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = Math_fround($65 + $67);
   $69 = Math_fround($54 * $68);
   $70 = Math_fround($63 + $69);
   $71 = (($b) + ($i$014$us<<2)|0);
   HEAPF32[$71>>2] = $70;
   $72 = (($result) + ($i$014$us<<2)|0);
   HEAPF32[$72>>2] = $63;
   $73 = (($i$014$us) + 1)|0;
   $exitcond23 = ($73|0)==($24|0);
   if ($exitcond23) {
    break;
   } else {
    $i$014$us = $73;
   }
  }
  $83 = (($28) + 104|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = Math_fround($0 * $84);
  $86 = Math_fround($2 * $85);
  $87 = Math_fround($4 * $86);
  if ($40) {
   $96 = $85;
  } else {
   $i2$06 = 0;
   while(1) {
    $88 = (($16) + ($i2$06<<2)|0);
    $89 = Math_fround(HEAPF32[$88>>2]);
    $90 = Math_fround($87 * $89);
    $91 = Math_fround(-$90);
    $92 = ((($A) + (($24*92)|0)|0) + ($i2$06<<2)|0);
    HEAPF32[$92>>2] = $91;
    $93 = (($i2$06) + 1)|0;
    $exitcond20 = ($93|0)==($24|0);
    if ($exitcond20) {
     $96 = $85;
     break;
    } else {
     $i2$06 = $93;
    }
   }
  }
 }
 $94 = Math_fround($2 + $12);
 $95 = Math_fround($94 * $96);
 $97 = Math_fround($95 + Math_fround(1.0));
 $98 = ((($A) + (($24*92)|0)|0) + ($24<<2)|0);
 HEAPF32[$98>>2] = $97;
 $99 = Math_fround($10 * $96);
 $100 = Math_fround($39 + $99);
 $101 = (($b) + ($24<<2)|0);
 HEAPF32[$101>>2] = $100;
 $102 = (($result) + ($24<<2)|0);
 HEAPF32[$102>>2] = $39;
 $103 = ($6|0)==(1);
 if ($103) {
  $104 = (($solver) + 2208|0);
  HEAP32[$104>>2] = 0;
  __ZN5physx16MatrixNNLUSolver11decomposeLUERKNS_8MatrixNNE($solver,$A);
  __ZNK5physx16MatrixNNLUSolver5solveERKNS_7VectorNERS1_($solver,$b,$result);
 } else {
  __ZNK5physx24MatrixNGaussSeidelSolver5solveEjfRKNS_8MatrixNNERKNS_7VectorNERS4_(0,$8,Math_fround(1.00000001335143196002E-10),$A,$b,$result);
 }
 if (!($40)) {
  $i4$02 = 0;
  while(1) {
   $105 = (($20) + ($i4$02)|0);
   $106 = HEAP8[$105>>0]|0;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $$phi$trans$insert = (($result) + ($i4$02<<2)|0);
    $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
    $132 = $$pre;
    label = 15;
   } else {
    $108 = $i4$02 & 3;
    $109 = $i4$02 >>> 2;
    $110 = ((($31) + (($109*208)|0)|0) + ($108<<2)|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = (($result) + ($i4$02<<2)|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = Math_fround($111 * $113);
    $115 = !($114 <= Math_fround(0.0));
    if ($115) {
     $132 = $113;
     label = 15;
    } else {
     $117 = Math_fround(0.0);
    }
   }
   if ((label|0) == 15) {
    label = 0;
    $117 = $132;
   }
   $116 = (($result) + ($i4$02<<2)|0);
   HEAPF32[$116>>2] = $117;
   $118 = (($i4$02) + 1)|0;
   $exitcond19 = ($118|0)==($24|0);
   if ($exitcond19) {
    break;
   } else {
    $i4$02 = $118;
   }
  }
 }
 $119 = Math_fround(HEAPF32[$102>>2]);
 $120 = (($28) + 88|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = $119 < Math_fround(0.0);
 $123 = $122 ? Math_fround(0.0) : $119;
 $124 = $123 > $121;
 $125 = $124 ? $121 : $123;
 HEAPF32[$102>>2] = $125;
 if ($40) {
  HEAPF32[$38>>2] = $125;
  STACKTOP = sp;return;
 } else {
  $i5$01 = 0;
 }
 while(1) {
  $126 = (($result) + ($i5$01<<2)|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = $i5$01 & 3;
  $129 = $i5$01 >>> 2;
  $130 = ((($31) + (($129*208)|0)|0) + ($128<<2)|0);
  HEAPF32[$130>>2] = $127;
  $131 = (($i5$01) + 1)|0;
  $exitcond = ($131|0)==($24|0);
  if ($exitcond) {
   break;
  } else {
   $i5$01 = $131;
  }
 }
 HEAPF32[$38>>2] = $125;
 STACKTOP = sp;return;
}
function __ZN5physx46solveTankInternaDynamicsEnginePlusDrivenWheelsERKNS_19ImplicitSolverInputEPKbPKfPNS_20ImplicitSolverOutputE($input,$activeWheelStates,$wheelGearings,$output) {
 $input = $input|0;
 $activeWheelStates = $activeWheelStates|0;
 $wheelGearings = $wheelGearings|0;
 $output = $output|0;
 var $$ph100 = Math_fround(0), $$ph101 = Math_fround(0), $$ph102 = Math_fround(0), $$ph103 = Math_fround(0), $$ph104 = Math_fround(0), $$ph105 = Math_fround(0), $$ph106 = Math_fround(0), $$ph107 = Math_fround(0), $$ph108 = Math_fround(0), $$ph109 = Math_fround(0), $$ph110 = Math_fround(0), $$ph111 = Math_fround(0), $$ph112 = Math_fround(0), $$ph113 = Math_fround(0), $$ph114 = Math_fround(0), $$ph115 = Math_fround(0), $$ph116 = Math_fround(0), $$ph97 = Math_fround(0), $$ph98 = Math_fround(0), $$ph99 = Math_fround(0);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0;
 var $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = 0, $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = 0, $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0), $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0);
 var $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0);
 var $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0);
 var $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $A = 0;
 var $M = 0, $b = 0, $dampingRates = 0, $exitcond = 0, $exitcond63 = 0, $exitcond64 = 0, $exitcond65 = 0, $exitcond65$1 = 0, $exitcond65$2 = 0, $exitcond68 = 0, $exitcond68$1 = 0, $exitcond68$1$1 = 0, $exitcond68$1$2 = 0, $exitcond68$175 = 0, $exitcond68$2 = 0, $exitcond68$2$1 = 0, $exitcond68$2$2 = 0, $exitcond68$282 = 0, $exitcond87 = 0, $exitcond88 = 0;
 var $exitcond89 = 0, $exitcond90 = 0, $exitcond91 = 0, $exitcond95 = 0, $i$058 = 0, $i1$054 = 0, $i13$08 = 0, $i14$06 = 0, $i15$03 = 0, $i16$01 = 0, $i3$049 = 0, $i5$041 = 0, $i6$036 = 0, $j$045 = 0, $j12$013 = 0, $j12$013$1 = 0, $j12$013$2 = 0, $j7$029 = 0, $k$020 = 0, $k$020$1 = 0;
 var $k$020$1$1 = 0, $k$020$1$2 = 0, $k$020$173 = 0, $k$020$2 = 0, $k$020$2$1 = 0, $k$020$2$2 = 0, $k$020$280 = 0, $recipMOI = 0, $scevgep = 0, $scevgep93 = 0, $sum$019 = Math_fround(0), $sum$019$1 = Math_fround(0), $sum$019$1$1 = Math_fround(0), $sum$019$1$2 = Math_fround(0), $sum$019$174 = Math_fround(0), $sum$019$2 = Math_fround(0), $sum$019$2$1 = Math_fround(0), $sum$019$2$2 = Math_fround(0), $sum$019$281 = Math_fround(0), $sum0$0$lcssa = Math_fround(0);
 var $sum0$030 = Math_fround(0), $sum1$0$lcssa = Math_fround(0), $sum1$028 = Math_fround(0), $sum11$012 = Math_fround(0), $sum11$012$1 = Math_fround(0), $sum11$012$2 = Math_fround(0), $wheelRecipRadii = 0, $wheelSpeedResults = 0, $wheelSpeeds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4736|0;
 $recipMOI = sp + 4656|0;
 $dampingRates = sp;
 $wheelSpeeds = sp + 80|0;
 $wheelRecipRadii = sp + 160|0;
 $M = sp + 240|0;
 $b = sp + 2360|0;
 $A = sp + 2456|0;
 $wheelSpeedResults = sp + 4576|0;
 $0 = Math_fround(HEAPF32[$input>>2]);
 $1 = (($input) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($input) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($input) + 28|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($input) + 32|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($input) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($input) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($input) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($input) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($input) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($input) + 56|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($input) + 60|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($input) + 64|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($input) + 68|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$output>>2]|0;
 $28 = (($output) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = Math_fround($2 * $4);
 $31 = Math_fround($4 * $30);
 $32 = (($20) + -1)|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $i$058 = 0;
  while(1) {
   $34 = ((($24) + (($i$058*944)|0)|0) + 232|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = $i$058 << 2;
   $37 = (($recipMOI) + ($36<<2)|0);
   HEAPF32[$37>>2] = $35;
   $38 = ((($24) + (($i$058*944)|0)|0) + 280|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = $36 | 1;
   $41 = (($recipMOI) + ($40<<2)|0);
   HEAPF32[$41>>2] = $39;
   $42 = ((($24) + (($i$058*944)|0)|0) + 328|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = $36 | 2;
   $45 = (($recipMOI) + ($44<<2)|0);
   HEAPF32[$45>>2] = $43;
   $46 = ((($24) + (($i$058*944)|0)|0) + 376|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = $36 | 3;
   $49 = (($recipMOI) + ($48<<2)|0);
   HEAPF32[$49>>2] = $47;
   $50 = ((($24) + (($i$058*944)|0)|0) + 208|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = (($dampingRates) + ($36<<2)|0);
   HEAPF32[$52>>2] = $51;
   $53 = ((($24) + (($i$058*944)|0)|0) + 256|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = (($dampingRates) + ($40<<2)|0);
   HEAPF32[$55>>2] = $54;
   $56 = ((($24) + (($i$058*944)|0)|0) + 304|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = (($dampingRates) + ($44<<2)|0);
   HEAPF32[$58>>2] = $57;
   $59 = ((($24) + (($i$058*944)|0)|0) + 352|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = (($dampingRates) + ($48<<2)|0);
   HEAPF32[$61>>2] = $60;
   $62 = ((($24) + (($i$058*944)|0)|0) + 228|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = (($wheelRecipRadii) + ($36<<2)|0);
   HEAPF32[$64>>2] = $63;
   $65 = ((($24) + (($i$058*944)|0)|0) + 276|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = (($wheelRecipRadii) + ($40<<2)|0);
   HEAPF32[$67>>2] = $66;
   $68 = ((($24) + (($i$058*944)|0)|0) + 324|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = (($wheelRecipRadii) + ($44<<2)|0);
   HEAPF32[$70>>2] = $69;
   $71 = ((($24) + (($i$058*944)|0)|0) + 372|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = (($wheelRecipRadii) + ($48<<2)|0);
   HEAPF32[$73>>2] = $72;
   $74 = (($27) + (($i$058*208)|0)|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = (($wheelSpeeds) + ($36<<2)|0);
   HEAPF32[$76>>2] = $75;
   $77 = ((($27) + (($i$058*208)|0)|0) + 4|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = (($wheelSpeeds) + ($40<<2)|0);
   HEAPF32[$79>>2] = $78;
   $80 = ((($27) + (($i$058*208)|0)|0) + 8|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   $82 = (($wheelSpeeds) + ($44<<2)|0);
   HEAPF32[$82>>2] = $81;
   $83 = ((($27) + (($i$058*208)|0)|0) + 12|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   $85 = (($wheelSpeeds) + ($48<<2)|0);
   HEAPF32[$85>>2] = $84;
   $86 = (($i$058) + 1)|0;
   $exitcond95 = ($86|0)==($32|0);
   if ($exitcond95) {
    break;
   } else {
    $i$058 = $86;
   }
  }
 }
 $87 = $20 << 2;
 $88 = (($22) - ($87))|0;
 $89 = ($88|0)==(-4);
 if (!($89)) {
  $90 = $32 << 2;
  $91 = (($22) + 4)|0;
  $92 = $20 << 2;
  $93 = (($91) - ($92))|0;
  $94 = (($92) + -4)|0;
  $scevgep = (($wheelSpeeds) + ($94<<2)|0);
  $scevgep93 = (($27) + (($32*208)|0)|0);
  $95 = $93 << 2;
  _memcpy(($scevgep|0),($scevgep93|0),($95|0))|0;
  $i1$054 = 0;
  while(1) {
   $96 = (((($24) + (($32*944)|0)|0) + (($i1$054*48)|0)|0) + 232|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = (($i1$054) + ($90))|0;
   $99 = (($recipMOI) + ($98<<2)|0);
   HEAPF32[$99>>2] = $97;
   $100 = (((($24) + (($32*944)|0)|0) + (($i1$054*48)|0)|0) + 208|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = (($dampingRates) + ($98<<2)|0);
   HEAPF32[$102>>2] = $101;
   $103 = (((($24) + (($32*944)|0)|0) + (($i1$054*48)|0)|0) + 228|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = (($wheelRecipRadii) + ($98<<2)|0);
   HEAPF32[$105>>2] = $104;
   $106 = (($i1$054) + 1)|0;
   $exitcond91 = ($106|0)==($93|0);
   if ($exitcond91) {
    break;
   } else {
    $i1$054 = $106;
   }
  }
 }
 $107 = (($24) + 192|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($24) + 240|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($22) + 1)|0;
 $112 = (($M) + 2116|0);
 HEAP32[$112>>2] = $111;
 $113 = (($b) + 92|0);
 HEAP32[$113>>2] = $111;
 $114 = ($22|0)==(0);
 if (!($114)) {
  $i3$049 = 0;
  while(1) {
   $115 = (($recipMOI) + ($i3$049<<2)|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   $117 = Math_fround($0 * $116);
   $118 = (($10) + ($i3$049<<2)|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = (($wheelGearings) + ($i3$049<<2)|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = Math_fround($31 * $117);
   $123 = Math_fround($119 * $122);
   $124 = Math_fround($121 * $123);
   $j$045 = 0;
   while(1) {
    $125 = (($12) + ($j$045<<2)|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = Math_fround($124 * $126);
    $128 = (($wheelGearings) + ($j$045<<2)|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = Math_fround($127 * $129);
    $131 = ((($M) + (($i3$049*92)|0)|0) + ($j$045<<2)|0);
    HEAPF32[$131>>2] = $130;
    $132 = (($j$045) + 1)|0;
    $exitcond89 = ($132|0)==($22|0);
    if ($exitcond89) {
     break;
    } else {
     $j$045 = $132;
    }
   }
   $133 = (($12) + ($i3$049<<2)|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = Math_fround($124 * $134);
   $136 = Math_fround($135 * $121);
   $137 = Math_fround($136 + Math_fround(1.0));
   $138 = (($dampingRates) + ($i3$049<<2)|0);
   $139 = Math_fround(HEAPF32[$138>>2]);
   $140 = Math_fround($117 * $139);
   $141 = Math_fround($137 + $140);
   $142 = ((($M) + (($i3$049*92)|0)|0) + ($i3$049<<2)|0);
   HEAPF32[$142>>2] = $141;
   $143 = Math_fround($30 * $117);
   $144 = Math_fround($119 * $143);
   $145 = Math_fround($121 * $144);
   $146 = Math_fround(-$145);
   $147 = ((($M) + (($i3$049*92)|0)|0) + ($22<<2)|0);
   HEAPF32[$147>>2] = $146;
   $148 = (($wheelSpeeds) + ($i3$049<<2)|0);
   $149 = Math_fround(HEAPF32[$148>>2]);
   $150 = (($14) + ($i3$049<<2)|0);
   $151 = Math_fround(HEAPF32[$150>>2]);
   $152 = (($18) + ($i3$049<<2)|0);
   $153 = Math_fround(HEAPF32[$152>>2]);
   $154 = Math_fround($151 + $153);
   $155 = Math_fround($117 * $154);
   $156 = Math_fround($149 + $155);
   $157 = (($b) + ($i3$049<<2)|0);
   HEAPF32[$157>>2] = $156;
   $158 = (($i3$049) + 1)|0;
   $exitcond90 = ($158|0)==($22|0);
   if ($exitcond90) {
    break;
   } else {
    $i3$049 = $158;
   }
  }
 }
 $159 = (($29) + 76|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($26) + 104|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = Math_fround($0 * $162);
 $164 = Math_fround($2 * $163);
 $165 = Math_fround($4 * $164);
 if (!($114)) {
  $i5$041 = 0;
  while(1) {
   $166 = (($12) + ($i5$041<<2)|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = Math_fround($165 * $167);
   $169 = (($wheelGearings) + ($i5$041<<2)|0);
   $170 = Math_fround(HEAPF32[$169>>2]);
   $171 = Math_fround($168 * $170);
   $172 = Math_fround(-$171);
   $173 = ((($M) + (($22*92)|0)|0) + ($i5$041<<2)|0);
   HEAPF32[$173>>2] = $172;
   $174 = (($i5$041) + 1)|0;
   $exitcond88 = ($174|0)==($22|0);
   if ($exitcond88) {
    break;
   } else {
    $i5$041 = $174;
   }
  }
 }
 $175 = Math_fround($2 + $8);
 $176 = Math_fround($175 * $163);
 $177 = Math_fround($176 + Math_fround(1.0));
 $178 = ((($M) + (($22*92)|0)|0) + ($22<<2)|0);
 HEAPF32[$178>>2] = $177;
 $179 = Math_fround($6 * $163);
 $180 = Math_fround($160 + $179);
 $181 = (($b) + ($22<<2)|0);
 HEAPF32[$181>>2] = $180;
 $182 = (($A) + 2116|0);
 HEAP32[$182>>2] = $111;
 $183 = ($111|0)==(0);
 do {
  if ($183) {
   HEAP32[$112>>2] = 3;
   label = 20;
  } else {
   $184 = ($22>>>0)>(2);
   $i6$036 = 0;
   while(1) {
    $185 = (($M) + (($i6$036*92)|0)|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = ((($M) + (($i6$036*92)|0)|0) + 4|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    if ($184) {
     $j7$029 = 2;$sum0$030 = $186;$sum1$028 = $188;
     while(1) {
      $189 = ((($M) + (($i6$036*92)|0)|0) + ($j7$029<<2)|0);
      $190 = Math_fround(HEAPF32[$189>>2]);
      $191 = Math_fround($108 * $190);
      $192 = (($wheelRecipRadii) + ($j7$029<<2)|0);
      $193 = Math_fround(HEAPF32[$192>>2]);
      $194 = Math_fround($191 * $193);
      $195 = Math_fround($sum0$030 + $194);
      $196 = $j7$029 | 1;
      $197 = ((($M) + (($i6$036*92)|0)|0) + ($196<<2)|0);
      $198 = Math_fround(HEAPF32[$197>>2]);
      $199 = Math_fround($110 * $198);
      $200 = (($wheelRecipRadii) + ($196<<2)|0);
      $201 = Math_fround(HEAPF32[$200>>2]);
      $202 = Math_fround($199 * $201);
      $203 = Math_fround($sum1$028 + $202);
      $204 = (($j7$029) + 2)|0;
      $205 = ($204>>>0)<($22>>>0);
      if ($205) {
       $j7$029 = $204;$sum0$030 = $195;$sum1$028 = $203;
      } else {
       $sum0$0$lcssa = $195;$sum1$0$lcssa = $203;
       break;
      }
     }
    } else {
     $sum0$0$lcssa = $186;$sum1$0$lcssa = $188;
    }
    $206 = (($A) + (($i6$036*92)|0)|0);
    HEAPF32[$206>>2] = $sum0$0$lcssa;
    $207 = ((($A) + (($i6$036*92)|0)|0) + 4|0);
    HEAPF32[$207>>2] = $sum1$0$lcssa;
    $208 = ((($M) + (($i6$036*92)|0)|0) + ($22<<2)|0);
    $209 = Math_fround(HEAPF32[$208>>2]);
    $210 = ((($A) + (($i6$036*92)|0)|0) + 8|0);
    HEAPF32[$210>>2] = $209;
    $211 = (($i6$036) + 1)|0;
    $exitcond87 = ($211|0)==($111|0);
    if ($exitcond87) {
     break;
    } else {
     $i6$036 = $211;
    }
   }
   HEAP32[$112>>2] = 3;
   if ($183) {
    label = 20;
   } else {
    $k$020 = 0;$sum$019 = Math_fround(0.0);
    while(1) {
     $212 = (($A) + (($k$020*92)|0)|0);
     $213 = Math_fround(HEAPF32[$212>>2]);
     $214 = Math_fround($213 * $213);
     $215 = Math_fround($sum$019 + $214);
     $216 = (($k$020) + 1)|0;
     $exitcond68 = ($216|0)==($111|0);
     if ($exitcond68) {
      break;
     } else {
      $k$020 = $216;$sum$019 = $215;
     }
    }
    HEAPF32[$M>>2] = $215;
    if ($183) {
     $217 = (($M) + 4|0);
     HEAPF32[$217>>2] = Math_fround(0.0);
     $$ph97 = Math_fround(0.0);$$ph98 = $215;
     label = 56;
     break;
    } else {
     $k$020$1 = 0;$sum$019$1 = Math_fround(0.0);
     while(1) {
      $372 = (($A) + (($k$020$1*92)|0)|0);
      $373 = Math_fround(HEAPF32[$372>>2]);
      $374 = ((($A) + (($k$020$1*92)|0)|0) + 4|0);
      $375 = Math_fround(HEAPF32[$374>>2]);
      $376 = Math_fround($373 * $375);
      $377 = Math_fround($sum$019$1 + $376);
      $378 = (($k$020$1) + 1)|0;
      $exitcond68$1 = ($378|0)==($111|0);
      if ($exitcond68$1) {
       $380 = $377;$443 = $215;
       label = 54;
       break;
      } else {
       $k$020$1 = $378;$sum$019$1 = $377;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  HEAPF32[$M>>2] = Math_fround(0.0);
  $380 = Math_fround(0.0);$443 = Math_fround(0.0);
  label = 54;
 }
 do {
  if ((label|0) == 54) {
   $379 = (($M) + 4|0);
   HEAPF32[$379>>2] = $380;
   if ($183) {
    $$ph97 = $380;$$ph98 = $443;
    label = 56;
   } else {
    $k$020$2 = 0;$sum$019$2 = Math_fround(0.0);
    while(1) {
     $381 = (($A) + (($k$020$2*92)|0)|0);
     $382 = Math_fround(HEAPF32[$381>>2]);
     $383 = ((($A) + (($k$020$2*92)|0)|0) + 8|0);
     $384 = Math_fround(HEAPF32[$383>>2]);
     $385 = Math_fround($382 * $384);
     $386 = Math_fround($sum$019$2 + $385);
     $387 = (($k$020$2) + 1)|0;
     $exitcond68$2 = ($387|0)==($111|0);
     if ($exitcond68$2) {
      break;
     } else {
      $k$020$2 = $387;$sum$019$2 = $386;
     }
    }
    $389 = (($M) + 8|0);
    HEAPF32[$389>>2] = $386;
    if ($183) {
     $390 = (($M) + 92|0);
     HEAPF32[$390>>2] = Math_fround(0.0);
     $$ph100 = $380;$$ph101 = $443;$$ph102 = $386;$$ph99 = Math_fround(0.0);
     label = 62;
     break;
    } else {
     $k$020$173 = 0;$sum$019$174 = Math_fround(0.0);
     while(1) {
      $391 = ((($A) + (($k$020$173*92)|0)|0) + 4|0);
      $392 = Math_fround(HEAPF32[$391>>2]);
      $393 = (($A) + (($k$020$173*92)|0)|0);
      $394 = Math_fround(HEAPF32[$393>>2]);
      $395 = Math_fround($392 * $394);
      $396 = Math_fround($sum$019$174 + $395);
      $397 = (($k$020$173) + 1)|0;
      $exitcond68$175 = ($397|0)==($111|0);
      if ($exitcond68$175) {
       $399 = $396;$451 = $386;$452 = $443;$453 = $380;
       label = 60;
       break;
      } else {
       $k$020$173 = $397;$sum$019$174 = $396;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 56) {
  $388 = (($M) + 8|0);
  HEAPF32[$388>>2] = Math_fround(0.0);
  $399 = Math_fround(0.0);$451 = Math_fround(0.0);$452 = $$ph98;$453 = $$ph97;
  label = 60;
 }
 do {
  if ((label|0) == 60) {
   $398 = (($M) + 92|0);
   HEAPF32[$398>>2] = $399;
   if ($183) {
    $$ph100 = $453;$$ph101 = $452;$$ph102 = $451;$$ph99 = $399;
    label = 62;
   } else {
    $k$020$1$1 = 0;$sum$019$1$1 = Math_fround(0.0);
    while(1) {
     $400 = ((($A) + (($k$020$1$1*92)|0)|0) + 4|0);
     $401 = Math_fround(HEAPF32[$400>>2]);
     $402 = Math_fround($401 * $401);
     $403 = Math_fround($sum$019$1$1 + $402);
     $404 = (($k$020$1$1) + 1)|0;
     $exitcond68$1$1 = ($404|0)==($111|0);
     if ($exitcond68$1$1) {
      break;
     } else {
      $k$020$1$1 = $404;$sum$019$1$1 = $403;
     }
    }
    $406 = (($M) + 96|0);
    HEAPF32[$406>>2] = $403;
    if ($183) {
     $407 = (($M) + 100|0);
     HEAPF32[$407>>2] = Math_fround(0.0);
     $$ph103 = Math_fround(0.0);$$ph104 = $399;$$ph105 = $453;$$ph106 = $452;$$ph107 = $451;$$ph108 = $403;
     label = 68;
     break;
    } else {
     $k$020$2$1 = 0;$sum$019$2$1 = Math_fround(0.0);
     while(1) {
      $408 = ((($A) + (($k$020$2$1*92)|0)|0) + 4|0);
      $409 = Math_fround(HEAPF32[$408>>2]);
      $410 = ((($A) + (($k$020$2$1*92)|0)|0) + 8|0);
      $411 = Math_fround(HEAPF32[$410>>2]);
      $412 = Math_fround($409 * $411);
      $413 = Math_fround($sum$019$2$1 + $412);
      $414 = (($k$020$2$1) + 1)|0;
      $exitcond68$2$1 = ($414|0)==($111|0);
      if ($exitcond68$2$1) {
       $416 = $413;$454 = $403;$455 = $451;$456 = $452;$457 = $453;$458 = $399;
       label = 66;
       break;
      } else {
       $k$020$2$1 = $414;$sum$019$2$1 = $413;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 62) {
  $405 = (($M) + 96|0);
  HEAPF32[$405>>2] = Math_fround(0.0);
  $416 = Math_fround(0.0);$454 = Math_fround(0.0);$455 = $$ph102;$456 = $$ph101;$457 = $$ph100;$458 = $$ph99;
  label = 66;
 }
 do {
  if ((label|0) == 66) {
   $415 = (($M) + 100|0);
   HEAPF32[$415>>2] = $416;
   if ($183) {
    $$ph103 = $416;$$ph104 = $458;$$ph105 = $457;$$ph106 = $456;$$ph107 = $455;$$ph108 = $454;
    label = 68;
   } else {
    $k$020$280 = 0;$sum$019$281 = Math_fround(0.0);
    while(1) {
     $417 = ((($A) + (($k$020$280*92)|0)|0) + 8|0);
     $418 = Math_fround(HEAPF32[$417>>2]);
     $419 = (($A) + (($k$020$280*92)|0)|0);
     $420 = Math_fround(HEAPF32[$419>>2]);
     $421 = Math_fround($418 * $420);
     $422 = Math_fround($sum$019$281 + $421);
     $423 = (($k$020$280) + 1)|0;
     $exitcond68$282 = ($423|0)==($111|0);
     if ($exitcond68$282) {
      break;
     } else {
      $k$020$280 = $423;$sum$019$281 = $422;
     }
    }
    $425 = (($M) + 184|0);
    HEAPF32[$425>>2] = $422;
    if ($183) {
     $426 = (($M) + 188|0);
     HEAPF32[$426>>2] = Math_fround(0.0);
     $$ph109 = Math_fround(0.0);$$ph110 = $416;$$ph111 = $458;$$ph112 = $457;$$ph113 = $456;$$ph114 = $455;$$ph115 = $454;$$ph116 = $422;
     label = 74;
     break;
    } else {
     $k$020$1$2 = 0;$sum$019$1$2 = Math_fround(0.0);
     while(1) {
      $427 = ((($A) + (($k$020$1$2*92)|0)|0) + 8|0);
      $428 = Math_fround(HEAPF32[$427>>2]);
      $429 = ((($A) + (($k$020$1$2*92)|0)|0) + 4|0);
      $430 = Math_fround(HEAPF32[$429>>2]);
      $431 = Math_fround($428 * $430);
      $432 = Math_fround($sum$019$1$2 + $431);
      $433 = (($k$020$1$2) + 1)|0;
      $exitcond68$1$2 = ($433|0)==($111|0);
      if ($exitcond68$1$2) {
       $435 = $432;$444 = $422;$445 = $454;$446 = $455;$447 = $456;$448 = $457;$449 = $458;$450 = $416;
       label = 72;
       break;
      } else {
       $k$020$1$2 = $433;$sum$019$1$2 = $432;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 68) {
  $424 = (($M) + 184|0);
  HEAPF32[$424>>2] = Math_fround(0.0);
  $435 = Math_fround(0.0);$444 = Math_fround(0.0);$445 = $$ph108;$446 = $$ph107;$447 = $$ph106;$448 = $$ph105;$449 = $$ph104;$450 = $$ph103;
  label = 72;
 }
 if ((label|0) == 72) {
  $434 = (($M) + 188|0);
  HEAPF32[$434>>2] = $435;
  if ($183) {
   $$ph109 = $435;$$ph110 = $450;$$ph111 = $449;$$ph112 = $448;$$ph113 = $447;$$ph114 = $446;$$ph115 = $445;$$ph116 = $444;
   label = 74;
  } else {
   $k$020$2$2 = 0;$sum$019$2$2 = Math_fround(0.0);
   while(1) {
    $436 = ((($A) + (($k$020$2$2*92)|0)|0) + 8|0);
    $437 = Math_fround(HEAPF32[$436>>2]);
    $438 = Math_fround($437 * $437);
    $439 = Math_fround($sum$019$2$2 + $438);
    $440 = (($k$020$2$2) + 1)|0;
    $exitcond68$2$2 = ($440|0)==($111|0);
    if ($exitcond68$2$2) {
     break;
    } else {
     $k$020$2$2 = $440;$sum$019$2$2 = $439;
    }
   }
   $442 = (($M) + 192|0);
   HEAPF32[$442>>2] = $439;
   if ($183) {
    $228 = $439;$229 = $448;$231 = $435;$232 = $446;$235 = $450;$237 = $445;$240 = $447;$242 = $444;$246 = $449;$255 = Math_fround(0.0);$258 = Math_fround(0.0);$261 = Math_fround(0.0);
   } else {
    $j12$013 = 0;$sum11$012 = Math_fround(0.0);
    while(1) {
     $218 = (($A) + (($j12$013*92)|0)|0);
     $219 = Math_fround(HEAPF32[$218>>2]);
     $220 = (($b) + ($j12$013<<2)|0);
     $221 = Math_fround(HEAPF32[$220>>2]);
     $222 = Math_fround($219 * $221);
     $223 = Math_fround($sum11$012 + $222);
     $224 = (($j12$013) + 1)|0;
     $exitcond65 = ($224|0)==($111|0);
     if ($exitcond65) {
      break;
     } else {
      $j12$013 = $224;$sum11$012 = $223;
     }
    }
    if ($183) {
     $228 = $439;$229 = $448;$231 = $435;$232 = $446;$235 = $450;$237 = $445;$240 = $447;$242 = $444;$246 = $449;$255 = $223;$258 = Math_fround(0.0);$261 = Math_fround(0.0);
    } else {
     $j12$013$1 = 0;$sum11$012$1 = Math_fround(0.0);
     while(1) {
      $347 = ((($A) + (($j12$013$1*92)|0)|0) + 4|0);
      $348 = Math_fround(HEAPF32[$347>>2]);
      $349 = (($b) + ($j12$013$1<<2)|0);
      $350 = Math_fround(HEAPF32[$349>>2]);
      $351 = Math_fround($348 * $350);
      $352 = Math_fround($sum11$012$1 + $351);
      $353 = (($j12$013$1) + 1)|0;
      $exitcond65$1 = ($353|0)==($111|0);
      if ($exitcond65$1) {
       break;
      } else {
       $j12$013$1 = $353;$sum11$012$1 = $352;
      }
     }
     if ($183) {
      $228 = $439;$229 = $448;$231 = $435;$232 = $446;$235 = $450;$237 = $445;$240 = $447;$242 = $444;$246 = $449;$255 = $223;$258 = $352;$261 = Math_fround(0.0);
     } else {
      $j12$013$2 = 0;$sum11$012$2 = Math_fround(0.0);
      while(1) {
       $354 = ((($A) + (($j12$013$2*92)|0)|0) + 8|0);
       $355 = Math_fround(HEAPF32[$354>>2]);
       $356 = (($b) + ($j12$013$2<<2)|0);
       $357 = Math_fround(HEAPF32[$356>>2]);
       $358 = Math_fround($355 * $357);
       $359 = Math_fround($sum11$012$2 + $358);
       $360 = (($j12$013$2) + 1)|0;
       $exitcond65$2 = ($360|0)==($111|0);
       if ($exitcond65$2) {
        $228 = $439;$229 = $448;$231 = $435;$232 = $446;$235 = $450;$237 = $445;$240 = $447;$242 = $444;$246 = $449;$255 = $223;$258 = $352;$261 = $359;
        break;
       } else {
        $j12$013$2 = $360;$sum11$012$2 = $359;
       }
      }
     }
    }
   }
  }
 }
 if ((label|0) == 74) {
  $441 = (($M) + 192|0);
  HEAPF32[$441>>2] = Math_fround(0.0);
  $228 = Math_fround(0.0);$229 = $$ph112;$231 = $$ph109;$232 = $$ph114;$235 = $$ph110;$237 = $$ph115;$240 = $$ph113;$242 = $$ph116;$246 = $$ph111;$255 = Math_fround(0.0);$258 = Math_fround(0.0);$261 = Math_fround(0.0);
 }
 $361 = Math_fround($237 * $228);
 $362 = Math_fround($235 * $231);
 $256 = Math_fround($361 - $362);
 $363 = Math_fround($240 * $256);
 $364 = Math_fround($246 * $228);
 $365 = Math_fround($235 * $242);
 $265 = Math_fround($364 - $365);
 $366 = Math_fround($229 * $265);
 $367 = Math_fround($363 - $366);
 $368 = Math_fround($246 * $231);
 $369 = Math_fround($237 * $242);
 $272 = Math_fround($368 - $369);
 $370 = Math_fround($232 * $272);
 $226 = Math_fround($370 + $367);
 $371 = $226 == Math_fround(0.0);
 if ($371) {
  STACKTOP = sp;return;
 }
 $225 = Math_fround(Math_fround(1.0) / $226);
 $227 = Math_fround($229 * $228);
 $230 = Math_fround($232 * $231);
 $233 = Math_fround($227 - $230);
 $234 = Math_fround($229 * $235);
 $236 = Math_fround($232 * $237);
 $238 = Math_fround($234 - $236);
 $239 = Math_fround($240 * $228);
 $241 = Math_fround($232 * $242);
 $243 = Math_fround($239 - $241);
 $244 = Math_fround($240 * $235);
 $245 = Math_fround($232 * $246);
 $247 = Math_fround($244 - $245);
 $248 = Math_fround($240 * $231);
 $249 = Math_fround($229 * $242);
 $250 = Math_fround($248 - $249);
 $251 = Math_fround($240 * $237);
 $252 = Math_fround($229 * $246);
 $253 = Math_fround($251 - $252);
 $254 = Math_fround($256 * $255);
 $257 = Math_fround($233 * $258);
 $259 = Math_fround($254 - $257);
 $260 = Math_fround($238 * $261);
 $262 = Math_fround($259 + $260);
 $263 = Math_fround($225 * $262);
 $264 = Math_fround($265 * $255);
 $266 = Math_fround($243 * $258);
 $267 = Math_fround($266 - $264);
 $268 = Math_fround($247 * $261);
 $269 = Math_fround($267 - $268);
 $270 = Math_fround($225 * $269);
 $271 = Math_fround($272 * $255);
 $273 = Math_fround($250 * $258);
 $274 = Math_fround($271 - $273);
 $275 = Math_fround($253 * $261);
 $276 = Math_fround($274 + $275);
 $277 = Math_fround($225 * $276);
 $278 = (($26) + 88|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = $277 < Math_fround(0.0);
 $281 = $280 ? Math_fround(0.0) : $277;
 $282 = $281 > $279;
 $283 = $282 ? $279 : $281;
 HEAPF32[$wheelSpeedResults>>2] = $263;
 $284 = (($wheelSpeedResults) + 4|0);
 HEAPF32[$284>>2] = $270;
 $285 = ($22>>>0)>(2);
 if ($285) {
  $i13$08 = 2;
  while(1) {
   $286 = (($wheelSpeedResults) + ($i13$08<<2)|0);
   HEAPF32[$286>>2] = $263;
   $287 = $i13$08 | 1;
   $288 = (($wheelSpeedResults) + ($287<<2)|0);
   HEAPF32[$288>>2] = $270;
   $289 = (($i13$08) + 2)|0;
   $290 = ($289>>>0)<($22>>>0);
   if ($290) {
    $i13$08 = $289;
   } else {
    break;
   }
  }
 }
 if (!($114)) {
  $i14$06 = 0;
  while(1) {
   $291 = (($wheelSpeedResults) + ($i14$06<<2)|0);
   $292 = (($16) + ($i14$06)|0);
   $293 = HEAP8[$292>>0]|0;
   $294 = ($293<<24>>24)==(0);
   if (!($294)) {
    $295 = (($wheelSpeeds) + ($i14$06<<2)|0);
    $296 = Math_fround(HEAPF32[$291>>2]);
    $297 = Math_fround(HEAPF32[$295>>2]);
    $298 = Math_fround($296 * $297);
    $299 = !($298 <= Math_fround(0.0));
    if (!($299)) {
     HEAPF32[$291>>2] = Math_fround(0.0);
    }
   }
   $300 = (($i14$06) + 1)|0;
   $exitcond64 = ($300|0)==($22|0);
   if ($exitcond64) {
    break;
   } else {
    $i14$06 = $300;
   }
  }
 }
 if (!($33)) {
  $i15$03 = 0;
  while(1) {
   $305 = $i15$03 << 2;
   $306 = (($activeWheelStates) + ($305)|0);
   $307 = HEAP8[$306>>0]|0;
   $308 = ($307<<24>>24)==(0);
   if ($308) {
    $312 = Math_fround(0.0);
   } else {
    $309 = (($wheelSpeedResults) + ($305<<2)|0);
    $310 = Math_fround(HEAPF32[$309>>2]);
    $312 = $310;
   }
   $311 = (($27) + (($i15$03*208)|0)|0);
   HEAPF32[$311>>2] = $312;
   $313 = $305 | 1;
   $314 = (($activeWheelStates) + ($313)|0);
   $315 = HEAP8[$314>>0]|0;
   $316 = ($315<<24>>24)==(0);
   if ($316) {
    $320 = Math_fround(0.0);
   } else {
    $317 = (($wheelSpeedResults) + ($313<<2)|0);
    $318 = Math_fround(HEAPF32[$317>>2]);
    $320 = $318;
   }
   $319 = ((($27) + (($i15$03*208)|0)|0) + 4|0);
   HEAPF32[$319>>2] = $320;
   $321 = $305 | 2;
   $322 = (($activeWheelStates) + ($321)|0);
   $323 = HEAP8[$322>>0]|0;
   $324 = ($323<<24>>24)==(0);
   if ($324) {
    $328 = Math_fround(0.0);
   } else {
    $325 = (($wheelSpeedResults) + ($321<<2)|0);
    $326 = Math_fround(HEAPF32[$325>>2]);
    $328 = $326;
   }
   $327 = ((($27) + (($i15$03*208)|0)|0) + 8|0);
   HEAPF32[$327>>2] = $328;
   $329 = $305 | 3;
   $330 = (($activeWheelStates) + ($329)|0);
   $331 = HEAP8[$330>>0]|0;
   $332 = ($331<<24>>24)==(0);
   if ($332) {
    $336 = Math_fround(0.0);
   } else {
    $333 = (($wheelSpeedResults) + ($329<<2)|0);
    $334 = Math_fround(HEAPF32[$333>>2]);
    $336 = $334;
   }
   $335 = ((($27) + (($i15$03*208)|0)|0) + 12|0);
   HEAPF32[$335>>2] = $336;
   $337 = (($i15$03) + 1)|0;
   $exitcond63 = ($337|0)==($32|0);
   if ($exitcond63) {
    break;
   } else {
    $i15$03 = $337;
   }
  }
 }
 if (!($89)) {
  $301 = $32 << 2;
  $302 = (($22) + 4)|0;
  $303 = $20 << 2;
  $304 = (($302) - ($303))|0;
  $i16$01 = 0;
  while(1) {
   $338 = (($i16$01) + ($301))|0;
   $339 = (($activeWheelStates) + ($338)|0);
   $340 = HEAP8[$339>>0]|0;
   $341 = ($340<<24>>24)==(0);
   if ($341) {
    $345 = Math_fround(0.0);
   } else {
    $342 = (($wheelSpeedResults) + ($338<<2)|0);
    $343 = Math_fround(HEAPF32[$342>>2]);
    $345 = $343;
   }
   $344 = ((($27) + (($32*208)|0)|0) + ($i16$01<<2)|0);
   HEAPF32[$344>>2] = $345;
   $346 = (($i16$01) + 1)|0;
   $exitcond = ($346|0)==($304|0);
   if ($exitcond) {
    break;
   } else {
    $i16$01 = $346;
   }
  }
 }
 HEAPF32[$159>>2] = $283;
 STACKTOP = sp;return;
}
function __ZN5physx27integrateNoDriveWheelSpeedsEfPKfPKbS1_S1_S1_RKNS_23PxVehicleWheels4SimDataERNS_23PxVehicleWheels4DynDataE($subTimestep,$brakeTorques,$isBrakeApplied,$driveTorques,$tireTorques,$dampingRates,$vehSuspWheelTire4SimData,$vehSuspWheelTire4) {
 $subTimestep = Math_fround($subTimestep);
 $brakeTorques = $brakeTorques|0;
 $isBrakeApplied = $isBrakeApplied|0;
 $driveTorques = $driveTorques|0;
 $tireTorques = $tireTorques|0;
 $dampingRates = $dampingRates|0;
 $vehSuspWheelTire4SimData = $vehSuspWheelTire4SimData|0;
 $vehSuspWheelTire4 = $vehSuspWheelTire4|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0;
 var $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($vehSuspWheelTire4SimData) + 232|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * $subTimestep);
 $3 = (($vehSuspWheelTire4SimData) + 280|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $subTimestep);
 $6 = (($vehSuspWheelTire4SimData) + 328|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $subTimestep);
 $9 = (($vehSuspWheelTire4SimData) + 376|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $subTimestep);
 $12 = Math_fround(HEAPF32[$vehSuspWheelTire4>>2]);
 $13 = Math_fround(HEAPF32[$tireTorques>>2]);
 $14 = Math_fround(HEAPF32[$driveTorques>>2]);
 $15 = Math_fround($13 + $14);
 $16 = Math_fround(HEAPF32[$brakeTorques>>2]);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($2 * $17);
 $19 = Math_fround($12 + $18);
 $20 = Math_fround(HEAPF32[$dampingRates>>2]);
 $21 = Math_fround($2 * $20);
 $22 = Math_fround($21 + Math_fround(1.0));
 $23 = Math_fround($19 / $22);
 $24 = (($vehSuspWheelTire4) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($tireTorques) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($driveTorques) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($27 + $29);
 $31 = (($brakeTorques) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($30 + $32);
 $34 = Math_fround($5 * $33);
 $35 = Math_fround($25 + $34);
 $36 = (($dampingRates) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($5 * $37);
 $39 = Math_fround($38 + Math_fround(1.0));
 $40 = Math_fround($35 / $39);
 $41 = (($vehSuspWheelTire4) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($tireTorques) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($driveTorques) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($44 + $46);
 $48 = (($brakeTorques) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($47 + $49);
 $51 = Math_fround($8 * $50);
 $52 = Math_fround($42 + $51);
 $53 = (($dampingRates) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($8 * $54);
 $56 = Math_fround($55 + Math_fround(1.0));
 $57 = Math_fround($52 / $56);
 $58 = (($vehSuspWheelTire4) + 12|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($tireTorques) + 12|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($driveTorques) + 12|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($61 + $63);
 $65 = (($brakeTorques) + 12|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($64 + $66);
 $68 = Math_fround($11 * $67);
 $69 = Math_fround($59 + $68);
 $70 = (($dampingRates) + 12|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($11 * $71);
 $73 = Math_fround($72 + Math_fround(1.0));
 $74 = Math_fround($69 / $73);
 $75 = HEAP8[$isBrakeApplied>>0]|0;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  label = 3;
 } else {
  $77 = Math_fround($12 * $23);
  $78 = !($77 <= Math_fround(0.0));
  if ($78) {
   label = 3;
  } else {
   $94 = Math_fround(0.0);
  }
 }
 if ((label|0) == 3) {
  $94 = $23;
 }
 $79 = (($isBrakeApplied) + 1|0);
 $80 = HEAP8[$79>>0]|0;
 $81 = ($80<<24>>24)==(0);
 if ($81) {
  label = 6;
 } else {
  $82 = Math_fround($40 * $25);
  $83 = !($82 <= Math_fround(0.0));
  if ($83) {
   label = 6;
  } else {
   $95 = Math_fround(0.0);
  }
 }
 if ((label|0) == 6) {
  $95 = $40;
 }
 $84 = (($isBrakeApplied) + 2|0);
 $85 = HEAP8[$84>>0]|0;
 $86 = ($85<<24>>24)==(0);
 if ($86) {
  label = 9;
 } else {
  $87 = Math_fround($57 * $42);
  $88 = !($87 <= Math_fround(0.0));
  if ($88) {
   label = 9;
  } else {
   $96 = Math_fround(0.0);
  }
 }
 if ((label|0) == 9) {
  $96 = $57;
 }
 $89 = (($isBrakeApplied) + 3|0);
 $90 = HEAP8[$89>>0]|0;
 $91 = ($90<<24>>24)==(0);
 if (!($91)) {
  $92 = Math_fround($74 * $59);
  $93 = !($92 <= Math_fround(0.0));
  if (!($93)) {
   $97 = Math_fround(0.0);
   HEAPF32[$vehSuspWheelTire4>>2] = $94;
   HEAPF32[$24>>2] = $95;
   HEAPF32[$41>>2] = $96;
   HEAPF32[$58>>2] = $97;
   STACKTOP = sp;return;
  }
 }
 $97 = $74;
 HEAPF32[$vehSuspWheelTire4>>2] = $94;
 HEAPF32[$24>>2] = $95;
 HEAPF32[$41>>2] = $96;
 HEAPF32[$58>>2] = $97;
 STACKTOP = sp;return;
}
function __ZN5physx35integrateUndriveWheelRotationSpeedsEfffPKfS1_RKNS_23PxVehicleWheels4SimDataERNS_23PxVehicleWheels4DynDataE($subTimestep,$brake,$handbrake,$tireTorques,$brakeTorques,$vehSuspWheelTire4SimData,$vehSuspWheelTire4) {
 $subTimestep = Math_fround($subTimestep);
 $brake = Math_fround($brake);
 $handbrake = Math_fround($handbrake);
 $tireTorques = $tireTorques|0;
 $brakeTorques = $brakeTorques|0;
 $vehSuspWheelTire4SimData = $vehSuspWheelTire4SimData|0;
 $vehSuspWheelTire4 = $vehSuspWheelTire4|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0);
 var $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0;
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0;
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $phitmp = Math_fround(0), $phitmp$1 = Math_fround(0), $phitmp$2 = Math_fround(0), $phitmp$3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$vehSuspWheelTire4>>2]);
 $1 = (($vehSuspWheelTire4SimData) + 232|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($2 * $subTimestep);
 $4 = (($vehSuspWheelTire4SimData) + 208|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$tireTorques>>2]);
 $7 = Math_fround(HEAPF32[$brakeTorques>>2]);
 $8 = Math_fround($6 + $7);
 $9 = Math_fround($3 * $8);
 $10 = Math_fround($0 + $9);
 $11 = Math_fround($5 * $3);
 $12 = Math_fround($11 + Math_fround(1.0));
 $13 = Math_fround($10 / $12);
 $14 = (($vehSuspWheelTire4SimData) + 212|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($vehSuspWheelTire4SimData) + 216|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $brake);
 $19 = Math_fround($17 * $handbrake);
 $20 = Math_fround($18 + $19);
 $21 = $20 != Math_fround(0.0);
 if ($21) {
  $22 = Math_fround($0 * $13);
  $23 = $22 <= Math_fround(0.0);
  $phitmp = $23 ? Math_fround(0.0) : $13;
  $24 = $phitmp;
 } else {
  $24 = $13;
 }
 HEAPF32[$vehSuspWheelTire4>>2] = $24;
 $25 = (($vehSuspWheelTire4) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($vehSuspWheelTire4SimData) + 280|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $subTimestep);
 $30 = (($vehSuspWheelTire4SimData) + 256|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($tireTorques) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($brakeTorques) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 + $35);
 $37 = Math_fround($29 * $36);
 $38 = Math_fround($26 + $37);
 $39 = Math_fround($31 * $29);
 $40 = Math_fround($39 + Math_fround(1.0));
 $41 = Math_fround($38 / $40);
 $42 = (($vehSuspWheelTire4SimData) + 260|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($vehSuspWheelTire4SimData) + 264|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 * $brake);
 $47 = Math_fround($45 * $handbrake);
 $48 = Math_fround($46 + $47);
 $49 = $48 != Math_fround(0.0);
 if ($49) {
  $50 = Math_fround($26 * $41);
  $51 = $50 <= Math_fround(0.0);
  $phitmp$1 = $51 ? Math_fround(0.0) : $41;
  $52 = $phitmp$1;
 } else {
  $52 = $41;
 }
 HEAPF32[$25>>2] = $52;
 $53 = (($vehSuspWheelTire4) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($vehSuspWheelTire4SimData) + 328|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 * $subTimestep);
 $58 = (($vehSuspWheelTire4SimData) + 304|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($tireTorques) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($brakeTorques) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($61 + $63);
 $65 = Math_fround($57 * $64);
 $66 = Math_fround($54 + $65);
 $67 = Math_fround($59 * $57);
 $68 = Math_fround($67 + Math_fround(1.0));
 $69 = Math_fround($66 / $68);
 $70 = (($vehSuspWheelTire4SimData) + 308|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($vehSuspWheelTire4SimData) + 312|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($71 * $brake);
 $75 = Math_fround($73 * $handbrake);
 $76 = Math_fround($74 + $75);
 $77 = $76 != Math_fround(0.0);
 if ($77) {
  $78 = Math_fround($54 * $69);
  $79 = $78 <= Math_fround(0.0);
  $phitmp$2 = $79 ? Math_fround(0.0) : $69;
  $80 = $phitmp$2;
 } else {
  $80 = $69;
 }
 HEAPF32[$53>>2] = $80;
 $81 = (($vehSuspWheelTire4) + 12|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($vehSuspWheelTire4SimData) + 376|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 * $subTimestep);
 $86 = (($vehSuspWheelTire4SimData) + 352|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($tireTorques) + 12|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($brakeTorques) + 12|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($89 + $91);
 $93 = Math_fround($85 * $92);
 $94 = Math_fround($82 + $93);
 $95 = Math_fround($87 * $85);
 $96 = Math_fround($95 + Math_fround(1.0));
 $97 = Math_fround($94 / $96);
 $98 = (($vehSuspWheelTire4SimData) + 356|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($vehSuspWheelTire4SimData) + 360|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($99 * $brake);
 $103 = Math_fround($101 * $handbrake);
 $104 = Math_fround($102 + $103);
 $105 = $104 != Math_fround(0.0);
 if (!($105)) {
  $108 = $97;
  HEAPF32[$81>>2] = $108;
  STACKTOP = sp;return;
 }
 $106 = Math_fround($82 * $97);
 $107 = $106 <= Math_fround(0.0);
 $phitmp$3 = $107 ? Math_fround(0.0) : $97;
 $108 = $phitmp$3;
 HEAPF32[$81>>2] = $108;
 STACKTOP = sp;return;
}
function __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($wheelsSimData,$wheelsDynData,$wheelQueryResults,$numWheelsToPose,$vehChassisCMLocalPose,$localPoses) {
 $wheelsSimData = $wheelsSimData|0;
 $wheelsDynData = $wheelsDynData|0;
 $wheelQueryResults = $wheelQueryResults|0;
 $numWheelsToPose = $numWheelsToPose|0;
 $vehChassisCMLocalPose = $vehChassisCMLocalPose|0;
 $localPoses = $localPoses|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0;
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $camberAngle$0 = Math_fround(0), $exitcond = 0, $i$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($vehChassisCMLocalPose) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($vehChassisCMLocalPose) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($vehChassisCMLocalPose) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = ($numWheelsToPose|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
 $8 = Math_fround(Math_fround(1.0) * Math_fround(1.0));
 $9 = Math_fround(Math_fround(0.0) * Math_fround(1.0));
 $10 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
 $11 = Math_fround(Math_fround(0.0) * Math_fround(1.0));
 $12 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
 $13 = Math_fround($8 - $7);
 $14 = Math_fround($10 - $9);
 $15 = Math_fround($12 - $11);
 $16 = Math_fround($15 * Math_fround(2.0));
 $17 = Math_fround($14 * Math_fround(2.0));
 $18 = Math_fround($13 * Math_fround(2.0));
 $i$013 = 0;
 while(1) {
  $19 = ((($wheelQueryResults) + (($i$013*148)|0)|0) + 76|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = ((($wheelsSimData) + (($i$013*48)|0)|0) + 20|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = $20 > Math_fround(0.0);
  if ($23) {
   $24 = ((($wheelsSimData) + (($i$013*48)|0)|0) + 24|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = Math_fround($20 * $25);
   $27 = ((($wheelsSimData) + (($i$013*48)|0)|0) + 32|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = Math_fround($26 * $28);
   $30 = Math_fround($22 + $29);
   $camberAngle$0 = $30;
  } else {
   $31 = ((($wheelsSimData) + (($i$013*48)|0)|0) + 28|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = Math_fround($20 * $32);
   $34 = ((($wheelsSimData) + (($i$013*48)|0)|0) + 36|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = Math_fround($33 * $35);
   $37 = Math_fround($22 - $36);
   $camberAngle$0 = $37;
  }
  $38 = ((($wheelsSimData) + (($i$013*12)|0)|0) + 784|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($1 + $39);
  $41 = ((($wheelsSimData) + (($i$013*12)|0)|0) + 788|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($3 + $42);
  $44 = ((($wheelsSimData) + (($i$013*12)|0)|0) + 792|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($5 + $45);
  $47 = ((($wheelsSimData) + (($i$013*12)|0)|0) + 640|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($20 * $48);
  $50 = ((($wheelsSimData) + (($i$013*12)|0)|0) + 644|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($20 * $51);
  $53 = ((($wheelsSimData) + (($i$013*12)|0)|0) + 648|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($20 * $54);
  $56 = Math_fround($40 - $49);
  $57 = Math_fround($43 - $52);
  $58 = Math_fround($46 - $55);
  $59 = ((($wheelQueryResults) + (($i$013*148)|0)|0) + 116|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($60 * Math_fround(0.5));
  $62 = (Math_fround(+(Math_sin((+$61)))));
  $63 = (Math_fround(+(Math_cos((+$61)))));
  $64 = Math_fround($62 * Math_fround(0.0));
  $65 = Math_fround($62 * Math_fround(1.0));
  $66 = Math_fround($62 * Math_fround(0.0));
  $67 = Math_fround($63 * $63);
  $68 = Math_fround($67 + Math_fround(-0.5));
  $69 = Math_fround($16 * $64);
  $70 = Math_fround($17 * $65);
  $71 = Math_fround($69 + $70);
  $72 = Math_fround($18 * $66);
  $73 = Math_fround($71 + $72);
  $74 = Math_fround($16 * $68);
  $75 = Math_fround($18 * $65);
  $76 = Math_fround($17 * $66);
  $77 = Math_fround($75 - $76);
  $78 = Math_fround($63 * $77);
  $79 = Math_fround($74 + $78);
  $80 = Math_fround($64 * $73);
  $81 = Math_fround($80 + $79);
  $82 = Math_fround($17 * $68);
  $83 = Math_fround($16 * $66);
  $84 = Math_fround($18 * $64);
  $85 = Math_fround($83 - $84);
  $86 = Math_fround($63 * $85);
  $87 = Math_fround($82 + $86);
  $88 = Math_fround($65 * $73);
  $89 = Math_fround($88 + $87);
  $90 = Math_fround($18 * $68);
  $91 = Math_fround($17 * $64);
  $92 = Math_fround($16 * $65);
  $93 = Math_fround($91 - $92);
  $94 = Math_fround($63 * $93);
  $95 = Math_fround($90 + $94);
  $96 = Math_fround($66 * $73);
  $97 = Math_fround($95 + $96);
  $98 = Math_fround($camberAngle$0 * Math_fround(0.5));
  $99 = (Math_fround(+(Math_sin((+$98)))));
  $100 = (Math_fround(+(Math_cos((+$98)))));
  $101 = Math_fround($99 * $81);
  $102 = Math_fround($99 * $89);
  $103 = Math_fround($99 * $97);
  $104 = Math_fround($64 * $100);
  $105 = Math_fround($63 * $101);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($66 * $102);
  $108 = Math_fround($107 + $106);
  $109 = Math_fround($65 * $103);
  $110 = Math_fround($108 - $109);
  $111 = Math_fround($65 * $100);
  $112 = Math_fround($63 * $102);
  $113 = Math_fround($111 + $112);
  $114 = Math_fround($64 * $103);
  $115 = Math_fround($114 + $113);
  $116 = Math_fround($66 * $101);
  $117 = Math_fround($115 - $116);
  $118 = Math_fround($66 * $100);
  $119 = Math_fround($63 * $103);
  $120 = Math_fround($118 + $119);
  $121 = Math_fround($65 * $101);
  $122 = Math_fround($121 + $120);
  $123 = Math_fround($64 * $102);
  $124 = Math_fround($122 - $123);
  $125 = Math_fround($63 * $100);
  $126 = Math_fround($64 * $101);
  $127 = Math_fround($125 - $126);
  $128 = Math_fround($65 * $102);
  $129 = Math_fround($127 - $128);
  $130 = Math_fround($66 * $103);
  $131 = Math_fround($129 - $130);
  $132 = ((($wheelsDynData) + ($i$013<<2)|0) + 32|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = Math_fround(Math_fround(1.0) * Math_fround(2.0));
  $135 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
  $136 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
  $137 = Math_fround($131 * $131);
  $138 = Math_fround($137 + Math_fround(-0.5));
  $139 = Math_fround($134 * $110);
  $140 = Math_fround($135 * $117);
  $141 = Math_fround($139 + $140);
  $142 = Math_fround($136 * $124);
  $143 = Math_fround($142 + $141);
  $144 = Math_fround($134 * $138);
  $145 = Math_fround($136 * $117);
  $146 = Math_fround($135 * $124);
  $147 = Math_fround($145 - $146);
  $148 = Math_fround($131 * $147);
  $149 = Math_fround($144 + $148);
  $150 = Math_fround($110 * $143);
  $151 = Math_fround($150 + $149);
  $152 = Math_fround($135 * $138);
  $153 = Math_fround($134 * $124);
  $154 = Math_fround($136 * $110);
  $155 = Math_fround($153 - $154);
  $156 = Math_fround($131 * $155);
  $157 = Math_fround($152 + $156);
  $158 = Math_fround($117 * $143);
  $159 = Math_fround($158 + $157);
  $160 = Math_fround($136 * $138);
  $161 = Math_fround($135 * $110);
  $162 = Math_fround($134 * $117);
  $163 = Math_fround($161 - $162);
  $164 = Math_fround($131 * $163);
  $165 = Math_fround($160 + $164);
  $166 = Math_fround($124 * $143);
  $167 = Math_fround($165 + $166);
  $168 = Math_fround($133 * Math_fround(0.5));
  $169 = (Math_fround(+(Math_sin((+$168)))));
  $170 = (Math_fround(+(Math_cos((+$168)))));
  $171 = Math_fround($169 * $151);
  $172 = Math_fround($169 * $159);
  $173 = Math_fround($169 * $167);
  $174 = Math_fround($170 * $110);
  $175 = Math_fround($131 * $171);
  $176 = Math_fround($174 + $175);
  $177 = Math_fround($124 * $172);
  $178 = Math_fround($177 + $176);
  $179 = Math_fround($117 * $173);
  $180 = Math_fround($178 - $179);
  $181 = Math_fround($170 * $117);
  $182 = Math_fround($131 * $172);
  $183 = Math_fround($181 + $182);
  $184 = Math_fround($110 * $173);
  $185 = Math_fround($184 + $183);
  $186 = Math_fround($124 * $171);
  $187 = Math_fround($185 - $186);
  $188 = Math_fround($170 * $124);
  $189 = Math_fround($131 * $173);
  $190 = Math_fround($188 + $189);
  $191 = Math_fround($117 * $171);
  $192 = Math_fround($191 + $190);
  $193 = Math_fround($110 * $172);
  $194 = Math_fround($192 - $193);
  $195 = Math_fround($170 * $131);
  $196 = Math_fround($110 * $171);
  $197 = Math_fround($195 - $196);
  $198 = Math_fround($117 * $172);
  $199 = Math_fround($197 - $198);
  $200 = Math_fround($124 * $173);
  $201 = Math_fround($199 - $200);
  $202 = (($localPoses) + (($i$013*28)|0)|0);
  HEAPF32[$202>>2] = $180;
  $203 = ((($localPoses) + (($i$013*28)|0)|0) + 4|0);
  HEAPF32[$203>>2] = $187;
  $204 = ((($localPoses) + (($i$013*28)|0)|0) + 8|0);
  HEAPF32[$204>>2] = $194;
  $205 = ((($localPoses) + (($i$013*28)|0)|0) + 12|0);
  HEAPF32[$205>>2] = $201;
  $206 = ((($localPoses) + (($i$013*28)|0)|0) + 16|0);
  HEAPF32[$206>>2] = $56;
  $207 = ((($localPoses) + (($i$013*28)|0)|0) + 20|0);
  HEAPF32[$207>>2] = $57;
  $208 = ((($localPoses) + (($i$013*28)|0)|0) + 24|0);
  HEAPF32[$208>>2] = $58;
  $209 = (($i$013) + 1)|0;
  $exitcond = ($209|0)==($numWheelsToPose|0);
  if ($exitcond) {
   break;
  } else {
   $i$013 = $209;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleUpdate13updateDrive4WEfRKNS_6PxVec3EffRKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEPNS_16PxVehicleDrive4WEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$gravityMagnitude,$recipGravityMagnitude,$drivableSurfaceToTireFrictionPairs,$vehDrive4W,$vehWheelQueryResults,$vehConcurrentUpdates) {
 $timestep = Math_fround($timestep);
 $gravity = $gravity|0;
 $gravityMagnitude = Math_fround($gravityMagnitude);
 $recipGravityMagnitude = Math_fround($recipGravityMagnitude);
 $drivableSurfaceToTireFrictionPairs = $drivableSurfaceToTireFrictionPairs|0;
 $vehDrive4W = $vehDrive4W|0;
 $vehWheelQueryResults = $vehWheelQueryResults|0;
 $vehConcurrentUpdates = $vehConcurrentUpdates|0;
 var $$$i = Math_fround(0), $$0$i$i = Math_fround(0), $$pre = Math_fround(0), $$pre158 = Math_fround(0), $$pre159 = Math_fround(0), $$pre160 = Math_fround(0), $$pre161 = Math_fround(0), $$pre162 = Math_fround(0), $$pre163 = Math_fround(0), $$pre164 = Math_fround(0), $$pre165 = Math_fround(0), $$pre166 = Math_fround(0), $$pre167 = Math_fround(0), $$pre168 = 0, $$pre169 = 0, $$promoted = Math_fround(0), $$promoted101 = Math_fround(0), $$promoted102 = Math_fround(0), $$promoted103 = Math_fround(0), $$promoted104 = Math_fround(0);
 var $$promoted105 = Math_fround(0), $$sum = 0, $$sum4445 = 0, $$sum5859 = 0, $$sum7273 = 0, $$sum8687 = 0, $$sum8889 = 0, $$sum9091 = 0, $$val = Math_fround(0), $$val37 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0;
 var $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0;
 var $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0;
 var $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0;
 var $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0;
 var $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = Math_fround(0), $1096 = 0;
 var $1097 = Math_fround(0), $1098 = 0, $1099 = Math_fround(0), $11 = 0, $110 = 0, $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = 0, $1113 = 0;
 var $1114 = Math_fround(0), $1115 = 0, $1116 = Math_fround(0), $1117 = 0, $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = 0, $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0), $113 = 0, $1130 = Math_fround(0), $1131 = 0;
 var $1132 = 0, $1133 = Math_fround(0), $1134 = 0, $1135 = Math_fround(0), $1136 = 0, $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = 0, $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = 0;
 var $1150 = 0, $1151 = 0, $1152 = Math_fround(0), $1153 = 0, $1154 = Math_fround(0), $1155 = 0, $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = Math_fround(0), $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0);
 var $1169 = 0, $117 = 0, $1170 = 0, $1171 = Math_fround(0), $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = Math_fround(0), $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = 0, $1180 = Math_fround(0), $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0), $1184 = 0, $1185 = 0, $1186 = Math_fround(0);
 var $1187 = Math_fround(0), $1188 = 0, $1189 = Math_fround(0), $119 = 0, $1190 = Math_fround(0), $1191 = 0, $1192 = Math_fround(0), $1193 = 0, $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = 0, $1197 = Math_fround(0), $1198 = 0, $1199 = Math_fround(0), $12 = 0, $120 = 0, $1200 = Math_fround(0), $1201 = 0, $1202 = Math_fround(0), $1203 = 0;
 var $1204 = Math_fround(0), $1205 = 0, $1206 = Math_fround(0), $1207 = Math_fround(0), $1208 = 0, $1209 = Math_fround(0), $121 = 0, $1210 = Math_fround(0), $1211 = 0, $1212 = Math_fround(0), $1213 = 0, $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = 0, $1217 = Math_fround(0), $1218 = 0, $1219 = Math_fround(0), $122 = 0, $1220 = Math_fround(0), $1221 = 0;
 var $1222 = Math_fround(0), $1223 = 0, $1224 = Math_fround(0), $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = Math_fround(0), $1233 = Math_fround(0), $1234 = Math_fround(0), $1235 = Math_fround(0), $1236 = 0, $1237 = 0, $1238 = Math_fround(0), $1239 = Math_fround(0), $124 = 0;
 var $1240 = Math_fround(0), $1241 = Math_fround(0), $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = 0, $1245 = 0, $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = 0, $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = 0, $1253 = 0, $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0);
 var $1259 = Math_fround(0), $126 = 0, $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0), $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = Math_fround(0), $1276 = Math_fround(0);
 var $1277 = Math_fround(0), $1278 = 0, $1279 = Math_fround(0), $128 = 0, $1280 = 0, $1281 = Math_fround(0), $1282 = 0, $1283 = Math_fround(0), $1284 = 0, $1285 = Math_fround(0), $1286 = 0, $1287 = Math_fround(0), $1288 = 0, $1289 = Math_fround(0), $129 = 0, $1290 = 0, $1291 = Math_fround(0), $1292 = 0, $1293 = Math_fround(0), $1294 = 0;
 var $1295 = Math_fround(0), $1296 = 0, $1297 = Math_fround(0), $1298 = 0, $1299 = Math_fround(0), $13 = 0, $130 = 0, $1300 = 0, $1301 = Math_fround(0), $1302 = 0, $1303 = Math_fround(0), $1304 = 0, $1305 = Math_fround(0), $1306 = 0, $1307 = Math_fround(0), $1308 = 0, $1309 = Math_fround(0), $131 = 0, $1310 = 0, $1311 = Math_fround(0);
 var $1312 = 0, $1313 = Math_fround(0), $1314 = 0, $1315 = Math_fround(0), $1316 = 0, $1317 = Math_fround(0), $1318 = 0, $1319 = Math_fround(0), $132 = 0, $1320 = 0, $1321 = Math_fround(0), $1322 = 0, $1323 = Math_fround(0), $1324 = 0, $1325 = Math_fround(0), $1326 = 0, $1327 = 0, $1328 = Math_fround(0), $1329 = 0, $133 = 0;
 var $1330 = Math_fround(0), $1331 = 0, $1332 = Math_fround(0), $1333 = 0, $1334 = Math_fround(0), $1335 = 0, $1336 = Math_fround(0), $1337 = 0, $1338 = Math_fround(0), $1339 = 0, $134 = 0, $1340 = Math_fround(0), $1341 = 0, $1342 = Math_fround(0), $1343 = 0, $1344 = Math_fround(0), $1345 = 0, $1346 = Math_fround(0), $1347 = 0, $1348 = Math_fround(0);
 var $1349 = 0, $135 = 0, $1350 = Math_fround(0), $1351 = 0, $1352 = Math_fround(0), $1353 = 0, $1354 = Math_fround(0), $1355 = 0, $1356 = Math_fround(0), $1357 = 0, $1358 = Math_fround(0), $1359 = 0, $136 = 0, $1360 = Math_fround(0), $1361 = 0, $1362 = Math_fround(0), $1363 = 0, $1364 = Math_fround(0), $1365 = 0, $1366 = Math_fround(0);
 var $1367 = 0, $1368 = Math_fround(0), $1369 = 0, $137 = 0, $1370 = Math_fround(0), $1371 = 0, $1372 = Math_fround(0), $1373 = 0, $1374 = Math_fround(0), $1375 = 0, $1376 = 0, $1377 = Math_fround(0), $1378 = 0, $1379 = Math_fround(0), $138 = 0, $1380 = 0, $1381 = Math_fround(0), $1382 = 0, $1383 = Math_fround(0), $1384 = 0;
 var $1385 = Math_fround(0), $1386 = 0, $1387 = Math_fround(0), $1388 = 0, $1389 = Math_fround(0), $139 = 0, $1390 = 0, $1391 = Math_fround(0), $1392 = 0, $1393 = Math_fround(0), $1394 = 0, $1395 = Math_fround(0), $1396 = 0, $1397 = Math_fround(0), $1398 = 0, $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = 0, $1401 = Math_fround(0);
 var $1402 = 0, $1403 = Math_fround(0), $1404 = 0, $1405 = Math_fround(0), $1406 = 0, $1407 = Math_fround(0), $1408 = 0, $1409 = Math_fround(0), $141 = 0, $1410 = 0, $1411 = Math_fround(0), $1412 = 0, $1413 = Math_fround(0), $1414 = 0, $1415 = Math_fround(0), $1416 = 0, $1417 = Math_fround(0), $1418 = 0, $1419 = Math_fround(0), $142 = 0;
 var $1420 = 0, $1421 = Math_fround(0), $1422 = 0, $1423 = Math_fround(0), $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = Math_fround(0), $1433 = 0, $1434 = Math_fround(0), $1435 = Math_fround(0), $1436 = 0, $1437 = Math_fround(0), $1438 = 0;
 var $1439 = Math_fround(0), $144 = 0, $1440 = Math_fround(0), $1441 = 0, $1442 = Math_fround(0), $1443 = 0, $1444 = Math_fround(0), $1445 = Math_fround(0), $1446 = 0, $1447 = Math_fround(0), $1448 = 0, $1449 = 0, $145 = Math_fround(0), $1450 = Math_fround(0), $1451 = 0, $1452 = 0, $1453 = Math_fround(0), $1454 = 0, $1455 = 0, $1456 = Math_fround(0);
 var $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = 0, $1460 = Math_fround(0), $1461 = 0, $1462 = Math_fround(0), $1463 = 0, $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = Math_fround(0), $1470 = Math_fround(0), $1471 = 0, $1472 = 0, $1473 = Math_fround(0), $1474 = 0;
 var $1475 = 0, $1476 = Math_fround(0), $1477 = Math_fround(0), $1478 = Math_fround(0), $1479 = Math_fround(0), $148 = 0, $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = Math_fround(0), $1487 = Math_fround(0), $1488 = 0, $1489 = 0, $149 = Math_fround(0), $1490 = Math_fround(0), $1491 = Math_fround(0), $1492 = Math_fround(0);
 var $1493 = Math_fround(0), $1494 = Math_fround(0), $1495 = 0, $1496 = Math_fround(0), $1497 = 0, $1498 = Math_fround(0), $1499 = 0, $15 = Math_fround(0), $150 = 0, $1500 = Math_fround(0), $1501 = Math_fround(0), $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = Math_fround(0), $1508 = Math_fround(0), $1509 = Math_fround(0), $151 = 0;
 var $1510 = 0, $1511 = 0, $1512 = Math_fround(0), $1513 = Math_fround(0), $1514 = 0, $1515 = 0, $1516 = Math_fround(0), $1517 = Math_fround(0), $1518 = Math_fround(0), $1519 = Math_fround(0), $152 = 0, $1520 = Math_fround(0), $1521 = Math_fround(0), $1522 = Math_fround(0), $1523 = Math_fround(0), $1524 = 0, $1525 = Math_fround(0), $1526 = Math_fround(0), $1527 = Math_fround(0), $1528 = Math_fround(0);
 var $1529 = Math_fround(0), $153 = 0, $1530 = Math_fround(0), $1531 = 0, $1532 = Math_fround(0), $1533 = 0, $1534 = Math_fround(0), $1535 = 0, $1536 = 0, $1537 = Math_fround(0), $1538 = Math_fround(0), $1539 = Math_fround(0), $154 = 0, $1540 = Math_fround(0), $1541 = Math_fround(0), $1542 = Math_fround(0), $1543 = Math_fround(0), $1544 = Math_fround(0), $1545 = Math_fround(0), $1546 = Math_fround(0);
 var $1547 = Math_fround(0), $1548 = Math_fround(0), $1549 = Math_fround(0), $155 = 0, $1550 = 0, $1551 = 0, $1552 = Math_fround(0), $1553 = 0, $1554 = Math_fround(0), $1555 = 0, $1556 = Math_fround(0), $1557 = 0, $1558 = Math_fround(0), $1559 = 0, $156 = 0, $1560 = Math_fround(0), $1561 = 0, $1562 = Math_fround(0), $1563 = 0, $1564 = Math_fround(0);
 var $1565 = Math_fround(0), $1566 = 0, $1567 = Math_fround(0), $1568 = Math_fround(0), $1569 = Math_fround(0), $157 = 0, $1570 = 0, $1571 = Math_fround(0), $1572 = Math_fround(0), $1573 = Math_fround(0), $1574 = Math_fround(0), $1575 = Math_fround(0), $1576 = Math_fround(0), $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = Math_fround(0), $1581 = 0, $1582 = Math_fround(0);
 var $1583 = 0, $1584 = Math_fround(0), $1585 = Math_fround(0), $1586 = 0, $1587 = Math_fround(0), $1588 = Math_fround(0), $1589 = Math_fround(0), $159 = 0, $1590 = 0, $1591 = Math_fround(0), $1592 = Math_fround(0), $1593 = Math_fround(0), $1594 = Math_fround(0), $1595 = Math_fround(0), $1596 = Math_fround(0), $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0;
 var $1600 = Math_fround(0), $1601 = 0, $1602 = Math_fround(0), $1603 = 0, $1604 = Math_fround(0), $1605 = Math_fround(0), $1606 = 0, $1607 = Math_fround(0), $1608 = Math_fround(0), $1609 = Math_fround(0), $161 = 0, $1610 = 0, $1611 = Math_fround(0), $1612 = Math_fround(0), $1613 = Math_fround(0), $1614 = Math_fround(0), $1615 = Math_fround(0), $1616 = Math_fround(0), $1617 = 0, $1618 = 0;
 var $1619 = 0, $162 = 0, $1620 = Math_fround(0), $1621 = 0, $1622 = Math_fround(0), $1623 = 0, $1624 = Math_fround(0), $1625 = Math_fround(0), $1626 = 0, $1627 = Math_fround(0), $1628 = Math_fround(0), $1629 = Math_fround(0), $163 = 0, $1630 = 0, $1631 = Math_fround(0), $1632 = Math_fround(0), $1633 = Math_fround(0), $1634 = Math_fround(0), $1635 = Math_fround(0), $1636 = Math_fround(0);
 var $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0;
 var $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = Math_fround(0), $1666 = Math_fround(0), $1667 = 0, $1668 = Math_fround(0), $1669 = Math_fround(0), $167 = 0, $1670 = 0, $1671 = Math_fround(0), $1672 = 0;
 var $1673 = Math_fround(0), $1674 = Math_fround(0), $1675 = 0, $1676 = Math_fround(0), $1677 = 0, $1678 = Math_fround(0), $1679 = Math_fround(0), $168 = 0, $1680 = 0, $1681 = Math_fround(0), $1682 = 0, $1683 = Math_fround(0), $1684 = 0, $1685 = Math_fround(0), $1686 = Math_fround(0), $1687 = 0, $1688 = Math_fround(0), $1689 = Math_fround(0), $169 = 0, $1690 = 0;
 var $1691 = Math_fround(0), $1692 = 0, $1693 = Math_fround(0), $1694 = Math_fround(0), $1695 = 0, $1696 = Math_fround(0), $1697 = 0, $1698 = Math_fround(0), $1699 = Math_fround(0), $17 = 0, $170 = 0, $1700 = 0, $1701 = Math_fround(0), $1702 = 0, $1703 = Math_fround(0), $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0;
 var $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = Math_fround(0), $1715 = Math_fround(0), $1716 = 0, $1717 = Math_fround(0), $1718 = 0, $1719 = Math_fround(0), $172 = 0, $1720 = 0, $1721 = Math_fround(0), $1722 = Math_fround(0), $1723 = 0, $1724 = 0, $1725 = 0, $1726 = Math_fround(0);
 var $1727 = 0, $1728 = Math_fround(0), $1729 = 0, $173 = 0, $1730 = Math_fround(0), $1731 = 0, $1732 = Math_fround(0), $1733 = 0, $1734 = Math_fround(0), $1735 = 0, $1736 = Math_fround(0), $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = Math_fround(0), $1742 = 0, $1743 = Math_fround(0), $1744 = 0;
 var $1745 = Math_fround(0), $1746 = 0, $1747 = Math_fround(0), $1748 = 0, $1749 = Math_fround(0), $175 = 0, $1750 = 0, $1751 = Math_fround(0), $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = Math_fround(0), $1757 = 0, $1758 = Math_fround(0), $1759 = 0, $176 = 0, $1760 = Math_fround(0), $1761 = 0, $1762 = Math_fround(0);
 var $1763 = 0, $1764 = Math_fround(0), $1765 = 0, $1766 = Math_fround(0), $1767 = 0, $1768 = Math_fround(0), $1769 = Math_fround(0), $177 = 0, $1770 = Math_fround(0), $1771 = Math_fround(0), $1772 = Math_fround(0), $1773 = Math_fround(0), $1774 = Math_fround(0), $1775 = Math_fround(0), $1776 = Math_fround(0), $1777 = Math_fround(0), $1778 = Math_fround(0), $1779 = Math_fround(0), $178 = 0, $1780 = Math_fround(0);
 var $1781 = Math_fround(0), $1782 = Math_fround(0), $1783 = Math_fround(0), $1784 = Math_fround(0), $1785 = Math_fround(0), $1786 = 0, $1787 = 0, $1788 = Math_fround(0), $1789 = 0, $179 = 0, $1790 = Math_fround(0), $1791 = 0, $1792 = Math_fround(0), $1793 = 0, $1794 = Math_fround(0), $1795 = 0, $1796 = Math_fround(0), $1797 = 0, $1798 = Math_fround(0), $1799 = 0;
 var $18 = Math_fround(0), $180 = 0, $1800 = Math_fround(0), $1801 = 0, $1802 = Math_fround(0), $1803 = 0, $1804 = Math_fround(0), $1805 = 0, $1806 = Math_fround(0), $1807 = 0, $1808 = Math_fround(0), $1809 = 0, $181 = 0, $1810 = Math_fround(0), $1811 = 0, $1812 = Math_fround(0), $1813 = 0, $1814 = Math_fround(0), $1815 = 0, $1816 = Math_fround(0);
 var $1817 = 0, $1818 = Math_fround(0), $1819 = 0, $182 = 0, $1820 = Math_fround(0), $1821 = 0, $1822 = Math_fround(0), $1823 = 0, $1824 = Math_fround(0), $1825 = 0, $1826 = Math_fround(0), $1827 = 0, $1828 = Math_fround(0), $1829 = 0, $183 = 0, $1830 = Math_fround(0), $1831 = 0, $1832 = Math_fround(0), $1833 = 0, $1834 = Math_fround(0);
 var $1835 = 0, $1836 = 0, $1837 = Math_fround(0), $1838 = 0, $1839 = Math_fround(0), $184 = 0, $1840 = 0, $1841 = Math_fround(0), $1842 = 0, $1843 = Math_fround(0), $1844 = 0, $1845 = Math_fround(0), $1846 = 0, $1847 = Math_fround(0), $1848 = 0, $1849 = Math_fround(0), $185 = 0, $1850 = 0, $1851 = Math_fround(0), $1852 = 0;
 var $1853 = Math_fround(0), $1854 = 0, $1855 = Math_fround(0), $1856 = 0, $1857 = Math_fround(0), $1858 = 0, $1859 = Math_fround(0), $186 = 0, $1860 = 0, $1861 = Math_fround(0), $1862 = 0, $1863 = Math_fround(0), $1864 = 0, $1865 = Math_fround(0), $1866 = 0, $1867 = Math_fround(0), $1868 = 0, $1869 = Math_fround(0), $187 = 0, $1870 = 0;
 var $1871 = Math_fround(0), $1872 = 0, $1873 = Math_fround(0), $1874 = 0, $1875 = Math_fround(0), $1876 = 0, $1877 = Math_fround(0), $1878 = 0, $1879 = Math_fround(0), $188 = 0, $1880 = 0, $1881 = Math_fround(0), $1882 = 0, $1883 = Math_fround(0), $1884 = 0, $1885 = 0, $1886 = Math_fround(0), $1887 = 0, $1888 = Math_fround(0), $1889 = 0;
 var $189 = 0, $1890 = Math_fround(0), $1891 = 0, $1892 = Math_fround(0), $1893 = 0, $1894 = Math_fround(0), $1895 = 0, $1896 = Math_fround(0), $1897 = 0, $1898 = Math_fround(0), $1899 = 0, $19 = 0, $190 = 0, $1900 = Math_fround(0), $1901 = 0, $1902 = Math_fround(0), $1903 = 0, $1904 = Math_fround(0), $1905 = 0, $1906 = Math_fround(0);
 var $1907 = 0, $1908 = Math_fround(0), $1909 = 0, $191 = 0, $1910 = Math_fround(0), $1911 = 0, $1912 = Math_fround(0), $1913 = 0, $1914 = Math_fround(0), $1915 = 0, $1916 = Math_fround(0), $1917 = 0, $1918 = Math_fround(0), $1919 = 0, $192 = 0, $1920 = Math_fround(0), $1921 = 0, $1922 = Math_fround(0), $1923 = 0, $1924 = Math_fround(0);
 var $1925 = 0, $1926 = Math_fround(0), $1927 = 0, $1928 = Math_fround(0), $1929 = 0, $193 = 0, $1930 = Math_fround(0), $1931 = 0, $1932 = Math_fround(0), $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0;
 var $1943 = 0, $1944 = Math_fround(0), $1945 = 0, $1946 = Math_fround(0), $1947 = Math_fround(0), $1948 = 0, $1949 = Math_fround(0), $195 = 0, $1950 = 0, $1951 = Math_fround(0), $1952 = Math_fround(0), $1953 = 0, $1954 = Math_fround(0), $1955 = 0, $1956 = Math_fround(0), $1957 = Math_fround(0), $1958 = 0, $1959 = Math_fround(0), $196 = 0, $1960 = 0;
 var $1961 = 0, $1962 = Math_fround(0), $1963 = 0, $1964 = 0, $1965 = Math_fround(0), $1966 = 0, $1967 = 0, $1968 = 0, $1969 = Math_fround(0), $197 = 0, $1970 = 0, $1971 = Math_fround(0), $1972 = 0, $1973 = Math_fround(0), $1974 = Math_fround(0), $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0;
 var $198 = 0, $1980 = Math_fround(0), $1981 = Math_fround(0), $1982 = Math_fround(0), $1983 = 0, $1984 = 0, $1985 = Math_fround(0), $1986 = Math_fround(0), $1987 = 0, $1988 = 0, $1989 = Math_fround(0), $199 = 0, $1990 = Math_fround(0), $1991 = Math_fround(0), $1992 = Math_fround(0), $1993 = Math_fround(0), $1994 = Math_fround(0), $1995 = Math_fround(0), $1996 = Math_fround(0), $1997 = 0;
 var $1998 = Math_fround(0), $1999 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $2000 = Math_fround(0), $2001 = Math_fround(0), $2002 = Math_fround(0), $2003 = Math_fround(0), $2004 = 0, $2005 = Math_fround(0), $2006 = 0, $2007 = Math_fround(0), $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0;
 var $2014 = Math_fround(0), $2015 = Math_fround(0), $2016 = 0, $2017 = Math_fround(0), $2018 = 0, $2019 = Math_fround(0), $202 = 0, $2020 = 0, $2021 = Math_fround(0), $2022 = 0, $2023 = Math_fround(0), $2024 = 0, $2025 = Math_fround(0), $2026 = Math_fround(0), $2027 = Math_fround(0), $2028 = Math_fround(0), $2029 = Math_fround(0), $203 = 0, $2030 = Math_fround(0), $2031 = Math_fround(0);
 var $2032 = Math_fround(0), $2033 = 0, $2034 = 0, $2035 = Math_fround(0), $2036 = Math_fround(0), $2037 = Math_fround(0), $2038 = Math_fround(0), $2039 = Math_fround(0), $204 = 0, $2040 = Math_fround(0), $2041 = Math_fround(0), $2042 = Math_fround(0), $2043 = Math_fround(0), $2044 = Math_fround(0), $2045 = Math_fround(0), $2046 = Math_fround(0), $2047 = 0, $2048 = 0, $2049 = 0, $205 = 0;
 var $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0, $2067 = 0, $2068 = 0;
 var $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = Math_fround(0), $2079 = 0, $208 = 0, $2080 = Math_fround(0), $2081 = 0, $2082 = Math_fround(0), $2083 = 0, $2084 = Math_fround(0), $2085 = 0, $2086 = Math_fround(0);
 var $2087 = 0, $2088 = Math_fround(0), $2089 = 0, $209 = 0, $2090 = Math_fround(0), $2091 = 0, $2092 = Math_fround(0), $2093 = 0, $2094 = Math_fround(0), $2095 = 0, $2096 = Math_fround(0), $2097 = 0, $2098 = Math_fround(0), $2099 = 0, $21 = 0, $210 = 0, $2100 = Math_fround(0), $2101 = 0, $2102 = Math_fround(0), $2103 = 0;
 var $2104 = Math_fround(0), $2105 = 0, $2106 = Math_fround(0), $2107 = 0, $2108 = Math_fround(0), $2109 = 0, $211 = 0, $2110 = Math_fround(0), $2111 = 0, $2112 = Math_fround(0), $2113 = 0, $2114 = Math_fround(0), $2115 = 0, $2116 = Math_fround(0), $2117 = 0, $2118 = Math_fround(0), $2119 = 0, $212 = 0, $2120 = Math_fround(0), $2121 = 0;
 var $2122 = Math_fround(0), $2123 = 0, $2124 = Math_fround(0), $2125 = 0, $2126 = Math_fround(0), $2127 = 0, $2128 = Math_fround(0), $2129 = 0, $213 = 0, $2130 = Math_fround(0), $2131 = 0, $2132 = Math_fround(0), $2133 = 0, $2134 = 0, $2135 = Math_fround(0), $2136 = 0, $2137 = Math_fround(0), $2138 = 0, $2139 = Math_fround(0), $214 = 0;
 var $2140 = 0, $2141 = Math_fround(0), $2142 = 0, $2143 = Math_fround(0), $2144 = 0, $2145 = Math_fround(0), $2146 = 0, $2147 = Math_fround(0), $2148 = 0, $2149 = Math_fround(0), $215 = 0, $2150 = 0, $2151 = Math_fround(0), $2152 = 0, $2153 = Math_fround(0), $2154 = 0, $2155 = Math_fround(0), $2156 = 0, $2157 = Math_fround(0), $2158 = 0;
 var $2159 = Math_fround(0), $216 = 0, $2160 = 0, $2161 = Math_fround(0), $2162 = 0, $2163 = Math_fround(0), $2164 = 0, $2165 = Math_fround(0), $2166 = 0, $2167 = Math_fround(0), $2168 = 0, $2169 = Math_fround(0), $217 = 0, $2170 = 0, $2171 = Math_fround(0), $2172 = 0, $2173 = Math_fround(0), $2174 = 0, $2175 = Math_fround(0), $2176 = 0;
 var $2177 = Math_fround(0), $2178 = 0, $2179 = Math_fround(0), $218 = 0, $2180 = 0, $2181 = Math_fround(0), $2182 = 0, $2183 = Math_fround(0), $2184 = 0, $2185 = Math_fround(0), $2186 = 0, $2187 = Math_fround(0), $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0;
 var $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0, $22 = 0, $220 = 0, $2200 = 0, $2201 = 0, $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0, $2210 = 0, $2211 = 0;
 var $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0, $2216 = 0, $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0, $2221 = 0, $2222 = 0, $2223 = Math_fround(0), $2224 = 0, $2225 = Math_fround(0), $2226 = 0, $2227 = Math_fround(0), $2228 = 0, $2229 = Math_fround(0), $223 = 0;
 var $2230 = 0, $2231 = Math_fround(0), $2232 = 0, $2233 = Math_fround(0), $2234 = 0, $2235 = Math_fround(0), $2236 = 0, $2237 = 0, $2238 = Math_fround(0), $2239 = 0, $224 = 0, $2240 = Math_fround(0), $2241 = 0, $2242 = Math_fround(0), $2243 = 0, $2244 = Math_fround(0), $2245 = 0, $2246 = Math_fround(0), $2247 = 0, $2248 = Math_fround(0);
 var $2249 = 0, $225 = 0, $2250 = Math_fround(0), $2251 = 0, $2252 = 0, $2253 = Math_fround(0), $2254 = 0, $2255 = Math_fround(0), $2256 = 0, $2257 = Math_fround(0), $2258 = 0, $2259 = Math_fround(0), $226 = 0, $2260 = 0, $2261 = Math_fround(0), $2262 = 0, $2263 = Math_fround(0), $2264 = 0, $2265 = Math_fround(0), $2266 = 0;
 var $2267 = 0, $2268 = Math_fround(0), $2269 = 0, $227 = 0, $2270 = Math_fround(0), $2271 = 0, $2272 = Math_fround(0), $2273 = 0, $2274 = Math_fround(0), $2275 = 0, $2276 = Math_fround(0), $2277 = 0, $2278 = Math_fround(0), $2279 = 0, $228 = 0, $2280 = Math_fround(0), $2281 = 0, $2282 = 0, $2283 = 0, $2284 = Math_fround(0);
 var $2285 = 0, $2286 = Math_fround(0), $2287 = 0, $2288 = Math_fround(0), $2289 = 0, $229 = 0, $2290 = Math_fround(0), $2291 = 0, $2292 = Math_fround(0), $2293 = 0, $2294 = Math_fround(0), $2295 = 0, $2296 = Math_fround(0), $2297 = 0, $2298 = Math_fround(0), $2299 = 0, $23 = 0, $230 = 0, $2300 = Math_fround(0), $2301 = 0;
 var $2302 = Math_fround(0), $2303 = 0, $2304 = Math_fround(0), $2305 = 0, $2306 = Math_fround(0), $2307 = 0, $2308 = Math_fround(0), $2309 = 0, $231 = 0, $2310 = Math_fround(0), $2311 = 0, $2312 = Math_fround(0), $2313 = 0, $2314 = Math_fround(0), $2315 = 0, $2316 = Math_fround(0), $2317 = 0, $2318 = Math_fround(0), $2319 = 0, $232 = 0;
 var $2320 = Math_fround(0), $2321 = 0, $2322 = Math_fround(0), $2323 = 0, $2324 = Math_fround(0), $2325 = 0, $2326 = Math_fround(0), $2327 = 0, $2328 = Math_fround(0), $2329 = 0, $233 = 0, $2330 = Math_fround(0), $2331 = 0, $2332 = Math_fround(0), $2333 = 0, $2334 = Math_fround(0), $2335 = 0, $2336 = Math_fround(0), $2337 = 0, $2338 = 0;
 var $2339 = 0, $234 = 0, $2340 = 0, $2341 = 0, $2342 = 0, $2343 = 0, $2344 = 0, $2345 = 0, $2346 = 0, $2347 = Math_fround(0), $2348 = 0, $2349 = 0, $235 = 0, $2350 = Math_fround(0), $2351 = 0, $2352 = 0, $2353 = Math_fround(0), $2354 = 0, $2355 = 0, $2356 = Math_fround(0);
 var $2357 = 0, $2358 = 0, $2359 = Math_fround(0), $236 = 0, $2360 = 0, $2361 = 0, $2362 = Math_fround(0), $2363 = 0, $2364 = 0, $2365 = 0, $2366 = 0, $2367 = 0, $2368 = 0, $2369 = 0, $237 = 0, $2370 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = 0;
 var $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0;
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0;
 var $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0);
 var $44 = 0, $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = 0, $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0);
 var $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = 0, $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0);
 var $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = 0, $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = Math_fround(0);
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = 0, $545 = 0, $546 = Math_fround(0), $547 = 0;
 var $548 = Math_fround(0), $549 = 0, $55 = 0, $550 = 0, $551 = Math_fround(0), $552 = 0, $553 = 0, $554 = Math_fround(0), $555 = 0, $556 = Math_fround(0), $557 = 0, $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = 0, $562 = Math_fround(0), $563 = 0, $564 = 0, $565 = Math_fround(0);
 var $566 = 0, $567 = 0, $568 = Math_fround(0), $569 = 0, $57 = 0, $570 = 0, $571 = Math_fround(0), $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = 0, $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = 0, $583 = Math_fround(0);
 var $584 = 0, $585 = 0, $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = Math_fround(0), $59 = 0, $590 = 0, $591 = 0, $592 = Math_fround(0), $593 = 0, $594 = 0, $595 = Math_fround(0), $596 = 0, $597 = 0, $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = Math_fround(0), $602 = 0, $603 = 0, $604 = Math_fround(0), $605 = 0, $606 = 0, $607 = Math_fround(0), $608 = 0, $609 = 0, $61 = 0, $610 = Math_fround(0), $611 = 0, $612 = 0, $613 = Math_fround(0), $614 = 0, $615 = 0, $616 = Math_fround(0), $617 = 0, $618 = 0, $619 = Math_fround(0);
 var $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0);
 var $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0);
 var $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = 0, $672 = Math_fround(0), $673 = 0;
 var $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = 0, $684 = Math_fround(0), $685 = 0, $686 = 0, $687 = Math_fround(0), $688 = 0, $689 = 0, $69 = 0, $690 = Math_fround(0), $691 = 0;
 var $692 = 0, $693 = Math_fround(0), $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = Math_fround(0), $706 = 0, $707 = 0, $708 = 0, $709 = 0;
 var $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0;
 var $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0;
 var $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0;
 var $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0;
 var $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0;
 var $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0;
 var $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0;
 var $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0;
 var $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0;
 var $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0;
 var $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0;
 var $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0;
 var $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = Math_fround(0), $933 = Math_fround(0), $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0;
 var $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0;
 var $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0;
 var $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0;
 var $999 = 0, $activeWheelStates = 0, $autoboxCompensatedAnalogAccel$0 = Math_fround(0), $aveWheelSpeedContributions = 0, $brakeTorques = 0, $brmerge$i = 0, $carChassisAngVel = 0, $carChassisCMLocalPose = 0, $carChassisLinVel = 0, $carChassisTransform = 0, $chassisForce = 0, $chassisTorque = 0, $constData = 0, $diffTorqueRatios = 0, $driveSimData = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i12 = 0, $exitcond$i5 = 0, $exitcond$i9 = 0;
 var $exitcond152 = 0, $exitcond153 = 0, $exitcond154 = 0, $exitcond155 = 0, $exitcond156 = 0, $exitcond157 = 0, $extraInputData = 0, $extraIsAccelApplied = 0, $extraIsBrakeApplied = 0, $extraOutputData = 0, $extraWheelActiveStates = 0, $extraWheelBrakeTorques = 0, $extraWheelSteerAngles = 0, $extraWheelsDiffTorqueRatios = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i7 = Math_fround(0), $finiteInputApplied$0$off0 = 0, $i$01$i = 0, $i$01$i$i = 0;
 var $i$01$i11 = 0, $i$0134 = 0, $i$04$i = 0, $i$07$i$i = 0, $i1$0127 = 0, $i2$0123 = 0, $i3$0120 = 0, $i7$0116 = 0, $i9$092 = 0, $implicitSolverInput = 0, $implicitSolverOutput = 0, $inertia = 0, $inputData = 0, $inverseInertia = 0, $isAccelApplied = 0, $isBrakeApplied = 0, $j$02$i = 0, $j$02$i17 = 0, $j$02$i6 = 0, $j$098 = 0;
 var $k$0112 = 0, $not$or$cond2$i = 0, $notlhs$i = 0, $notrhs$i = 0, $numActiveWheelsPerBlock4 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond3$i = 0, $outputData = 0, $steerAngles = 0, $tires4ForceCalculators = 0, $type$0$i = 0, $vehWheels = 0, $vehicleConcurrentUpdates = 0, $wheelConcurrentUpdates = 0, $wheelOmega$0$i = Math_fround(0), $wheelOmega$0$i8 = Math_fround(0), $wheelQueryResults = 0, $x0$08$i$i = Math_fround(0);
 var $y0$06$i$i = Math_fround(0), dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 7744|0;
 $driveSimData = sp + 7168|0;
 $wheelConcurrentUpdates = sp + 6048|0;
 $vehicleConcurrentUpdates = sp + 6008|0;
 $numActiveWheelsPerBlock4 = sp + 5988|0;
 $tires4ForceCalculators = sp + 5888|0;
 $wheelQueryResults = sp + 2928|0;
 $carChassisCMLocalPose = sp + 2896|0;
 $carChassisTransform = sp + 2868|0;
 $inverseInertia = sp + 2856|0;
 $carChassisLinVel = sp + 2844|0;
 $carChassisAngVel = sp + 2832|0;
 $0 = sp + 2804|0;
 $1 = sp + 2776|0;
 $inertia = sp + 2764|0;
 $2 = sp + 2752|0;
 $3 = sp + 2740|0;
 $activeWheelStates = sp + 2736|0;
 $aveWheelSpeedContributions = sp + 2720|0;
 $isAccelApplied = sp + 2712|0;
 $steerAngles = sp + 2696|0;
 $constData = sp + 1344|0;
 $chassisForce = sp + 1332|0;
 $chassisTorque = sp + 1320|0;
 $brakeTorques = sp + 1304|0;
 $isBrakeApplied = sp + 1296|0;
 $inputData = sp + 1128|0;
 $outputData = sp + 16|0;
 $diffTorqueRatios = sp;
 $implicitSolverInput = sp + 1224|0;
 $implicitSolverOutput = sp + 1392|0;
 $extraWheelSteerAngles = sp + 1400|0;
 $extraWheelsDiffTorqueRatios = sp + 1416|0;
 $extraIsAccelApplied = sp + 1432|0;
 $extraWheelBrakeTorques = sp + 1440|0;
 $extraIsBrakeApplied = sp + 1456|0;
 $extraWheelActiveStates = sp + 1460|0;
 $extraInputData = sp + 1464|0;
 $extraOutputData = sp + 1576|0;
 $vehWheels = sp + 2688|0;
 $4 = (($vehDrive4W) + 8|0);
 $5 = (($vehDrive4W) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $48 = 0;
 } else {
  $8 = (($vehDrive4W) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $i$0134 = 0;
  while(1) {
   $10 = $i$0134 << 2;
   $11 = (523960 + ($10<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = (($9) + (($i$0134*208)|0)|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = (($12) + 16|0);
    HEAPF32[$16>>2] = $15;
    $17 = ((($9) + (($i$0134*208)|0)|0) + 4|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = $10 | 1;
    $20 = (523960 + ($19<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 16|0);
    HEAPF32[$22>>2] = $18;
    $23 = ((($9) + (($i$0134*208)|0)|0) + 8|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = $10 | 2;
    $26 = (523960 + ($25<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 16|0);
    HEAPF32[$28>>2] = $24;
    $29 = ((($9) + (($i$0134*208)|0)|0) + 12|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = $10 | 3;
    $32 = (523960 + ($31<<2)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 16|0);
    HEAPF32[$34>>2] = $30;
   }
   $35 = (($i$0134) + 1)|0;
   $36 = ($35>>>0)<($6>>>0);
   if ($36) {
    $i$0134 = $35;
   } else {
    $48 = $6;
    break;
   }
  }
 }
 $37 = (($vehDrive4W) + 128|0);
 $38 = (($vehDrive4W) + 204|0);
 $39 = (0|0)==(0|0);
 if (!($39)) {
  $40 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[0>>2] = $40;
 }
 $41 = (($vehDrive4W) + 40|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($vehDrive4W) + 72|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($vehDrive4W) + 48|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $48 << 2;
 $49 = (4 - ($47))|0;
 $50 = (($vehDrive4W) + 224|0);
 $51 = (($vehDrive4W) + 288|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 << 3;
 _memcpy(($driveSimData|0),($50|0),($53|0))|0;
 $54 = (($driveSimData) + 64|0);
 HEAP32[$54>>2] = $52;
 $55 = (($driveSimData) + 80|0);
 $56 = (($vehDrive4W) + 304|0);
 ;HEAP32[$55+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$56+12>>2]|0;HEAP32[$55+16>>2]=HEAP32[$56+16>>2]|0;HEAP32[$55+20>>2]=HEAP32[$56+20>>2]|0;HEAP32[$55+24>>2]=HEAP32[$56+24>>2]|0;HEAP32[$55+28>>2]=HEAP32[$56+28>>2]|0;
 $57 = (($driveSimData) + 112|0);
 $58 = (($vehDrive4W) + 336|0);
 _memcpy(($57|0),($58|0),416)|0;
 $59 = (($driveSimData) + 528|0);
 $60 = (($vehDrive4W) + 752|0);
 dest=$59+0|0; src=$60+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $61 = (($vehDrive4W) + 104|0);
 $62 = HEAP32[$61>>2]|0;
 HEAPF32[$wheelConcurrentUpdates>>2] = Math_fround(0.0);
 $63 = (($wheelConcurrentUpdates) + 4|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($wheelConcurrentUpdates) + 8|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = (($wheelConcurrentUpdates) + 12|0);
 HEAPF32[$65>>2] = Math_fround(1.0);
 $66 = (($wheelConcurrentUpdates) + 16|0);
 $67 = (($wheelConcurrentUpdates) + 60|0);
 dest=$66+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($wheelConcurrentUpdates) + 64|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($wheelConcurrentUpdates) + 68|0);
 HEAPF32[$69>>2] = Math_fround(1.0);
 $70 = (($wheelConcurrentUpdates) + 72|0);
 $71 = (($wheelConcurrentUpdates) + 116|0);
 dest=$70+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($wheelConcurrentUpdates) + 120|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($wheelConcurrentUpdates) + 124|0);
 HEAPF32[$73>>2] = Math_fround(1.0);
 $74 = (($wheelConcurrentUpdates) + 128|0);
 $75 = (($wheelConcurrentUpdates) + 172|0);
 dest=$74+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($wheelConcurrentUpdates) + 176|0);
 HEAPF32[$76>>2] = Math_fround(0.0);
 $77 = (($wheelConcurrentUpdates) + 180|0);
 HEAPF32[$77>>2] = Math_fround(1.0);
 $78 = (($wheelConcurrentUpdates) + 184|0);
 $79 = (($wheelConcurrentUpdates) + 228|0);
 dest=$78+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($wheelConcurrentUpdates) + 232|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 $81 = (($wheelConcurrentUpdates) + 236|0);
 HEAPF32[$81>>2] = Math_fround(1.0);
 $82 = (($wheelConcurrentUpdates) + 240|0);
 $83 = (($wheelConcurrentUpdates) + 284|0);
 dest=$82+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($wheelConcurrentUpdates) + 288|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 $85 = (($wheelConcurrentUpdates) + 292|0);
 HEAPF32[$85>>2] = Math_fround(1.0);
 $86 = (($wheelConcurrentUpdates) + 296|0);
 $87 = (($wheelConcurrentUpdates) + 340|0);
 dest=$86+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($wheelConcurrentUpdates) + 344|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($wheelConcurrentUpdates) + 348|0);
 HEAPF32[$89>>2] = Math_fround(1.0);
 $90 = (($wheelConcurrentUpdates) + 352|0);
 $91 = (($wheelConcurrentUpdates) + 396|0);
 dest=$90+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($wheelConcurrentUpdates) + 400|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $93 = (($wheelConcurrentUpdates) + 404|0);
 HEAPF32[$93>>2] = Math_fround(1.0);
 $94 = (($wheelConcurrentUpdates) + 408|0);
 $95 = (($wheelConcurrentUpdates) + 452|0);
 dest=$94+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($wheelConcurrentUpdates) + 456|0);
 HEAPF32[$96>>2] = Math_fround(0.0);
 $97 = (($wheelConcurrentUpdates) + 460|0);
 HEAPF32[$97>>2] = Math_fround(1.0);
 $98 = (($wheelConcurrentUpdates) + 464|0);
 $99 = (($wheelConcurrentUpdates) + 508|0);
 dest=$98+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = (($wheelConcurrentUpdates) + 512|0);
 HEAPF32[$100>>2] = Math_fround(0.0);
 $101 = (($wheelConcurrentUpdates) + 516|0);
 HEAPF32[$101>>2] = Math_fround(1.0);
 $102 = (($wheelConcurrentUpdates) + 520|0);
 $103 = (($wheelConcurrentUpdates) + 564|0);
 dest=$102+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($wheelConcurrentUpdates) + 568|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($wheelConcurrentUpdates) + 572|0);
 HEAPF32[$105>>2] = Math_fround(1.0);
 $106 = (($wheelConcurrentUpdates) + 576|0);
 $107 = (($wheelConcurrentUpdates) + 620|0);
 dest=$106+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($wheelConcurrentUpdates) + 624|0);
 HEAPF32[$108>>2] = Math_fround(0.0);
 $109 = (($wheelConcurrentUpdates) + 628|0);
 HEAPF32[$109>>2] = Math_fround(1.0);
 $110 = (($wheelConcurrentUpdates) + 632|0);
 $111 = (($wheelConcurrentUpdates) + 676|0);
 dest=$110+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = (($wheelConcurrentUpdates) + 680|0);
 HEAPF32[$112>>2] = Math_fround(0.0);
 $113 = (($wheelConcurrentUpdates) + 684|0);
 HEAPF32[$113>>2] = Math_fround(1.0);
 $114 = (($wheelConcurrentUpdates) + 688|0);
 $115 = (($wheelConcurrentUpdates) + 732|0);
 dest=$114+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = (($wheelConcurrentUpdates) + 736|0);
 HEAPF32[$116>>2] = Math_fround(0.0);
 $117 = (($wheelConcurrentUpdates) + 740|0);
 HEAPF32[$117>>2] = Math_fround(1.0);
 $118 = (($wheelConcurrentUpdates) + 744|0);
 $119 = (($wheelConcurrentUpdates) + 788|0);
 dest=$118+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($wheelConcurrentUpdates) + 792|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($wheelConcurrentUpdates) + 796|0);
 HEAPF32[$121>>2] = Math_fround(1.0);
 $122 = (($wheelConcurrentUpdates) + 800|0);
 $123 = (($wheelConcurrentUpdates) + 844|0);
 dest=$122+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = (($wheelConcurrentUpdates) + 848|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = (($wheelConcurrentUpdates) + 852|0);
 HEAPF32[$125>>2] = Math_fround(1.0);
 $126 = (($wheelConcurrentUpdates) + 856|0);
 $127 = (($wheelConcurrentUpdates) + 900|0);
 dest=$126+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = (($wheelConcurrentUpdates) + 904|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 $129 = (($wheelConcurrentUpdates) + 908|0);
 HEAPF32[$129>>2] = Math_fround(1.0);
 $130 = (($wheelConcurrentUpdates) + 912|0);
 $131 = (($wheelConcurrentUpdates) + 956|0);
 dest=$130+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$131>>2] = Math_fround(0.0);
 $132 = (($wheelConcurrentUpdates) + 960|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = (($wheelConcurrentUpdates) + 964|0);
 HEAPF32[$133>>2] = Math_fround(1.0);
 $134 = (($wheelConcurrentUpdates) + 968|0);
 $135 = (($wheelConcurrentUpdates) + 1012|0);
 dest=$134+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = (($wheelConcurrentUpdates) + 1016|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 $137 = (($wheelConcurrentUpdates) + 1020|0);
 HEAPF32[$137>>2] = Math_fround(1.0);
 $138 = (($wheelConcurrentUpdates) + 1024|0);
 $139 = (($wheelConcurrentUpdates) + 1068|0);
 dest=$138+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($wheelConcurrentUpdates) + 1072|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $141 = (($wheelConcurrentUpdates) + 1076|0);
 HEAPF32[$141>>2] = Math_fround(1.0);
 $142 = (($wheelConcurrentUpdates) + 1080|0);
 dest=$142+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $143 = (($49) + ($46))|0;
 ;HEAP32[$vehicleConcurrentUpdates+0>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+4>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+8>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+12>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+16>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+20>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+24>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+28>>2]=0|0;HEAP16[$vehicleConcurrentUpdates+32>>1]=0|0;
 $144 = (($vehicleConcurrentUpdates) + 4|0);
 HEAP32[$144>>2] = $46;
 HEAP32[$vehicleConcurrentUpdates>>2] = $wheelConcurrentUpdates;
 $145 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($37,3)));
 $146 = $145 != Math_fround(0.0);
 if ($146) {
  label = 13;
 } else {
  $147 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($37,4)));
  $148 = $147 != Math_fround(0.0);
  if ($148) {
   label = 13;
  } else {
   $149 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($37,0)));
   $150 = $149 != Math_fround(0.0);
   if ($150) {
    label = 13;
   } else {
    $151 = (($vehDrive4W) + 194|0);
    $152 = HEAP8[$151>>0]|0;
    $153 = ($152<<24>>24)==(0);
    if ($153) {
     $154 = (($vehDrive4W) + 193|0);
     $155 = HEAP8[$154>>0]|0;
     $156 = ($155<<24>>24)==(0);
     if ($156) {
      $finiteInputApplied$0$off0 = 0;
     } else {
      label = 13;
     }
    } else {
     label = 13;
    }
   }
  }
 }
 if ((label|0) == 13) {
  $finiteInputApplied$0$off0 = 1;
 }
 $157 = HEAP32[$62>>2]|0;
 $158 = (($157) + 256|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = (FUNCTION_TABLE_ii[$159 & 4095]($62)|0);
 L20: do {
  if ($160) {
   if ($finiteInputApplied$0$off0) {
    $161 = (($vehicleConcurrentUpdates) + 33|0);
    HEAP8[$161>>0] = 1;
    break;
   }
   $162 = HEAP32[$5>>2]|0;
   $163 = HEAP32[$43>>2]|0;
   $164 = ($162|0)==(0);
   L25: do {
    if (!($164)) {
     $i$04$i = 0;
     L26: while(1) {
      $165 = $i$04$i << 2;
      $166 = ((($163) + (($i$04$i*208)|0)|0) + 196|0);
      $j$02$i17 = 0;
      while(1) {
       $167 = (($j$02$i17) + ($165))|0;
       $168 = (__ZNK5physx22PxVehicleWheelsSimData18getIsWheelDisabledEj($4,$167)|0);
       if (!($168)) {
        $169 = HEAP32[$166>>2]|0;
        $170 = ((($169) + (($j$02$i17*80)|0)|0) + 77|0);
        $171 = HEAP8[$170>>0]|0;
        $172 = ($171<<24>>24)==(0);
        if (!($172)) {
         $173 = (($169) + (($j$02$i17*80)|0)|0);
         $174 = HEAP32[$173>>2]|0;
         $175 = ($174|0)==(0|0);
         if (!($175)) {
          $176 = (($174) + 4|0);
          $177 = HEAP16[$176>>1]|0;
          $178 = ($177<<16>>16)==(5);
          if ($178) {
           break L26;
          }
         }
        }
       }
       $179 = (($j$02$i17) + 1)|0;
       $180 = ($179>>>0)<(4);
       if ($180) {
        $j$02$i17 = $179;
       } else {
        break;
       }
      }
      $181 = (($i$04$i) + 1)|0;
      $182 = ($181>>>0)<($162>>>0);
      if ($182) {
       $i$04$i = $181;
      } else {
       break L25;
      }
     }
     $183 = (($vehicleConcurrentUpdates) + 33|0);
     HEAP8[$183>>0] = 1;
     break L20;
    }
   } while(0);
   $184 = (($vehDrive4W) + 88|0);
   $185 = HEAP32[$184>>2]|0;
   $186 = ($185|0)==(0);
   if (!($186)) {
    $i$01$i$i = 0;
    while(1) {
     __ZN5physx22PxVehicleWheelsDynData21setWheelRotationSpeedEjf($43,$i$01$i$i,Math_fround(0.0));
     $187 = (($i$01$i$i) + 1)|0;
     $188 = HEAP32[$184>>2]|0;
     $189 = ($187>>>0)<($188>>>0);
     if ($189) {
      $i$01$i$i = $187;
     } else {
      break;
     }
    }
   }
   HEAPF32[$38>>2] = Math_fround(0.0);
   $190 = ($vehConcurrentUpdates|0)==(0|0);
   if ($190) {
    STACKTOP = sp;return;
   }
   $191 = (($vehConcurrentUpdates) + 32|0);
   HEAP8[$191>>0] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 ;HEAP32[$numActiveWheelsPerBlock4+0>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+4>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+8>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+12>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+16>>2]=0|0;
 $192 = ($46>>>0)<(4);
 $193 = $192 ? $46 : 4;
 HEAP32[$numActiveWheelsPerBlock4>>2] = $193;
 $194 = (($48) + -1)|0;
 $195 = ($194>>>0)>(1);
 if ($195) {
  $i1$0127 = 1;
  while(1) {
   $196 = (($numActiveWheelsPerBlock4) + ($i1$0127<<2)|0);
   HEAP32[$196>>2] = 4;
   $197 = (($i1$0127) + 1)|0;
   $exitcond157 = ($197|0)==($194|0);
   if ($exitcond157) {
    break;
   } else {
    $i1$0127 = $197;
   }
  }
 }
 $198 = (($numActiveWheelsPerBlock4) + ($194<<2)|0);
 HEAP32[$198>>2] = $143;
 $199 = ($48|0)==(0);
 if (!($199)) {
  $200 = (($vehDrive4W) + 76|0);
  $$pre168 = HEAP32[$200>>2]|0;
  $i2$0123 = 0;
  while(1) {
   $201 = $i2$0123 << 2;
   $202 = HEAP32[$$pre168>>2]|0;
   $203 = (($202) + ($201<<2)|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = (($tires4ForceCalculators) + (($i2$0123*20)|0)|0);
   HEAP32[$205>>2] = $204;
   $206 = $201 | 1;
   $207 = HEAP32[$$pre168>>2]|0;
   $208 = (($207) + ($206<<2)|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = ((($tires4ForceCalculators) + (($i2$0123*20)|0)|0) + 4|0);
   HEAP32[$210>>2] = $209;
   $211 = $201 | 2;
   $212 = HEAP32[$$pre168>>2]|0;
   $213 = (($212) + ($211<<2)|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = ((($tires4ForceCalculators) + (($i2$0123*20)|0)|0) + 8|0);
   HEAP32[$215>>2] = $214;
   $216 = $201 | 3;
   $217 = HEAP32[$$pre168>>2]|0;
   $218 = (($217) + ($216<<2)|0);
   $219 = HEAP32[$218>>2]|0;
   $220 = ((($tires4ForceCalculators) + (($i2$0123*20)|0)|0) + 12|0);
   HEAP32[$220>>2] = $219;
   $221 = (($$pre168) + 4|0);
   $222 = HEAP32[$221>>2]|0;
   $223 = ((($tires4ForceCalculators) + (($i2$0123*20)|0)|0) + 16|0);
   HEAP32[$223>>2] = $222;
   $224 = (($i2$0123) + 1)|0;
   $exitcond156 = ($224|0)==($48|0);
   if ($exitcond156) {
    break;
   } else {
    $i2$0123 = $224;
   }
  }
  if (!($199)) {
   $i3$0120 = 0;
   while(1) {
    $225 = ((($44) + (($i3$0120*208)|0)|0) + 192|0);
    $226 = HEAP32[$225>>2]|0;
    $227 = (($226) + 352|0);
    $228 = HEAP32[$227>>2]|0;
    $229 = HEAP32[$228>>2]|0;
    $230 = (($229) + 36|0);
    $231 = HEAP32[$230>>2]|0;
    FUNCTION_TABLE_vi[$231 & 4095]($228);
    $232 = (($i3$0120) + 1)|0;
    $exitcond155 = ($232|0)==($48|0);
    if ($exitcond155) {
     break;
    } else {
     $i3$0120 = $232;
    }
   }
  }
 }
 $233 = (($wheelQueryResults) + 2960|0);
 $234 = $wheelQueryResults;
 while(1) {
  _memset(($234|0),0,136)|0;
  $235 = (($234) + 28|0);
  HEAP8[$235>>0] = 1;
  $236 = (($234) + 44|0);
  HEAP32[$236>>2] = -1;
  $237 = (($234) + 120|0);
  HEAPF32[$237>>2] = Math_fround(0.0);
  $238 = (($234) + 124|0);
  HEAPF32[$238>>2] = Math_fround(0.0);
  $239 = (($234) + 128|0);
  HEAPF32[$239>>2] = Math_fround(0.0);
  $240 = (($234) + 132|0);
  HEAPF32[$240>>2] = Math_fround(1.0);
  $241 = (($234) + 136|0);
  HEAPF32[$241>>2] = Math_fround(0.0);
  $242 = (($234) + 140|0);
  HEAPF32[$242>>2] = Math_fround(0.0);
  $243 = (($234) + 144|0);
  HEAPF32[$243>>2] = Math_fround(0.0);
  $244 = (($234) + 148|0);
  $245 = ($244|0)==($233|0);
  if ($245) {
   break;
  } else {
   $234 = $244;
  }
 }
 $246 = HEAP32[$62>>2]|0;
 $247 = (($246) + 124|0);
 $248 = HEAP32[$247>>2]|0;
 FUNCTION_TABLE_vii[$248 & 4095]($0,$62);
 $249 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$carChassisCMLocalPose>>2] = $249;
 $250 = (($0) + 4|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = (($carChassisCMLocalPose) + 4|0);
 HEAPF32[$252>>2] = $251;
 $253 = (($0) + 8|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = (($carChassisCMLocalPose) + 8|0);
 HEAPF32[$255>>2] = $254;
 $256 = (($0) + 12|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = (($carChassisCMLocalPose) + 12|0);
 HEAPF32[$258>>2] = $257;
 $259 = (($0) + 16|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = (($carChassisCMLocalPose) + 16|0);
 HEAPF32[$261>>2] = $260;
 $262 = (($0) + 20|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 $264 = (($carChassisCMLocalPose) + 20|0);
 HEAPF32[$264>>2] = $263;
 $265 = (($0) + 24|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = (($carChassisCMLocalPose) + 24|0);
 HEAPF32[$267>>2] = $266;
 $268 = HEAP32[$62>>2]|0;
 $269 = (($268) + 84|0);
 $270 = HEAP32[$269>>2]|0;
 FUNCTION_TABLE_vii[$270 & 4095]($1,$62);
 $271 = Math_fround($260 * Math_fround(2.0));
 $272 = Math_fround($263 * Math_fround(2.0));
 $273 = Math_fround($266 * Math_fround(2.0));
 $274 = (($1) + 12|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = Math_fround($275 * $275);
 $277 = Math_fround($276 + Math_fround(-0.5));
 $278 = Math_fround(HEAPF32[$1>>2]);
 $279 = Math_fround($271 * $278);
 $280 = (($1) + 4|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = Math_fround($272 * $281);
 $283 = Math_fround($279 + $282);
 $284 = (($1) + 8|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = Math_fround($273 * $285);
 $287 = Math_fround($283 + $286);
 $288 = Math_fround($271 * $277);
 $289 = Math_fround($273 * $281);
 $290 = Math_fround($272 * $285);
 $291 = Math_fround($289 - $290);
 $292 = Math_fround($275 * $291);
 $293 = Math_fround($288 + $292);
 $294 = Math_fround($278 * $287);
 $295 = Math_fround($294 + $293);
 $296 = Math_fround($272 * $277);
 $297 = Math_fround($271 * $285);
 $298 = Math_fround($273 * $278);
 $299 = Math_fround($297 - $298);
 $300 = Math_fround($275 * $299);
 $301 = Math_fround($296 + $300);
 $302 = Math_fround($281 * $287);
 $303 = Math_fround($302 + $301);
 $304 = Math_fround($273 * $277);
 $305 = Math_fround($272 * $278);
 $306 = Math_fround($271 * $281);
 $307 = Math_fround($305 - $306);
 $308 = Math_fround($275 * $307);
 $309 = Math_fround($304 + $308);
 $310 = Math_fround($285 * $287);
 $311 = Math_fround($309 + $310);
 $312 = (($1) + 16|0);
 $313 = Math_fround(HEAPF32[$312>>2]);
 $314 = Math_fround($313 + $295);
 $315 = (($1) + 20|0);
 $316 = Math_fround(HEAPF32[$315>>2]);
 $317 = Math_fround($316 + $303);
 $318 = (($1) + 24|0);
 $319 = Math_fround(HEAPF32[$318>>2]);
 $320 = Math_fround($319 + $311);
 $321 = Math_fround($275 * $249);
 $322 = Math_fround($278 * $257);
 $323 = Math_fround($321 + $322);
 $324 = Math_fround($281 * $254);
 $325 = Math_fround($323 + $324);
 $326 = Math_fround($285 * $251);
 $327 = Math_fround($325 - $326);
 $328 = Math_fround($275 * $251);
 $329 = Math_fround($281 * $257);
 $330 = Math_fround($329 + $328);
 $331 = Math_fround($285 * $249);
 $332 = Math_fround($331 + $330);
 $333 = Math_fround($278 * $254);
 $334 = Math_fround($332 - $333);
 $335 = Math_fround($275 * $254);
 $336 = Math_fround($285 * $257);
 $337 = Math_fround($336 + $335);
 $338 = Math_fround($278 * $251);
 $339 = Math_fround($338 + $337);
 $340 = Math_fround($281 * $249);
 $341 = Math_fround($339 - $340);
 $342 = Math_fround($275 * $257);
 $343 = Math_fround($278 * $249);
 $344 = Math_fround($342 - $343);
 $345 = Math_fround($281 * $251);
 $346 = Math_fround($344 - $345);
 $347 = Math_fround($285 * $254);
 $348 = Math_fround($346 - $347);
 HEAPF32[$carChassisTransform>>2] = $327;
 $349 = (($carChassisTransform) + 4|0);
 HEAPF32[$349>>2] = $334;
 $350 = (($carChassisTransform) + 8|0);
 HEAPF32[$350>>2] = $341;
 $351 = (($carChassisTransform) + 12|0);
 HEAPF32[$351>>2] = $348;
 $352 = (($carChassisTransform) + 16|0);
 HEAPF32[$352>>2] = $314;
 $353 = (($carChassisTransform) + 20|0);
 HEAPF32[$353>>2] = $317;
 $354 = (($carChassisTransform) + 24|0);
 HEAPF32[$354>>2] = $320;
 $355 = HEAP32[$62>>2]|0;
 $356 = (($355) + 132|0);
 $357 = HEAP32[$356>>2]|0;
 $358 = (Math_fround(FUNCTION_TABLE_fi[$357 & 255]($62)));
 $359 = Math_fround(Math_fround(1.0) / $358);
 $360 = HEAP32[$62>>2]|0;
 $361 = (($360) + 144|0);
 $362 = HEAP32[$361>>2]|0;
 FUNCTION_TABLE_vii[$362 & 4095]($inertia,$62);
 $363 = Math_fround(HEAPF32[$inertia>>2]);
 $364 = Math_fround(Math_fround(1.0) / $363);
 $365 = (($inertia) + 4|0);
 $366 = Math_fround(HEAPF32[$365>>2]);
 $367 = Math_fround(Math_fround(1.0) / $366);
 $368 = (($inertia) + 8|0);
 $369 = Math_fround(HEAPF32[$368>>2]);
 $370 = Math_fround(Math_fround(1.0) / $369);
 HEAPF32[$inverseInertia>>2] = $364;
 $371 = (($inverseInertia) + 4|0);
 HEAPF32[$371>>2] = $367;
 $372 = (($inverseInertia) + 8|0);
 HEAPF32[$372>>2] = $370;
 $373 = HEAP32[$62>>2]|0;
 $374 = (($373) + 152|0);
 $375 = HEAP32[$374>>2]|0;
 FUNCTION_TABLE_vii[$375 & 4095]($2,$62);
 $376 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$carChassisLinVel>>2] = $376;
 $377 = (($2) + 4|0);
 $378 = Math_fround(HEAPF32[$377>>2]);
 $379 = (($carChassisLinVel) + 4|0);
 HEAPF32[$379>>2] = $378;
 $380 = (($2) + 8|0);
 $381 = Math_fround(HEAPF32[$380>>2]);
 $382 = (($carChassisLinVel) + 8|0);
 HEAPF32[$382>>2] = $381;
 $383 = HEAP32[$62>>2]|0;
 $384 = (($383) + 160|0);
 $385 = HEAP32[$384>>2]|0;
 FUNCTION_TABLE_vii[$385 & 4095]($3,$62);
 $386 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$carChassisAngVel>>2] = $386;
 $387 = (($3) + 4|0);
 $388 = Math_fround(HEAPF32[$387>>2]);
 $389 = (($carChassisAngVel) + 4|0);
 HEAPF32[$389>>2] = $388;
 $390 = (($3) + 8|0);
 $391 = Math_fround(HEAPF32[$390>>2]);
 $392 = (($carChassisAngVel) + 8|0);
 HEAPF32[$392>>2] = $391;
 $393 = Math_fround(HEAPF32[$37>>2]);
 $394 = (($vehDrive4W) + 192|0);
 $395 = HEAP8[$394>>0]|0;
 $396 = ($395<<24>>24)==(0);
 $$pre169 = (($vehDrive4W) + 196|0);
 do {
  if ($396) {
   $autoboxCompensatedAnalogAccel$0 = $393;
  } else {
   $397 = HEAP32[$$pre169>>2]|0;
   $398 = (($vehDrive4W) + 200|0);
   $399 = HEAP32[$398>>2]|0;
   $400 = ($399|0)!=($397|0);
   $401 = ($397|0)==(1);
   $or$cond$i = $400 & $401;
   $$$i = $or$cond$i ? Math_fround(0.0) : $393;
   $402 = (($vehDrive4W) + 212|0);
   $403 = Math_fround(HEAPF32[$402>>2]);
   $404 = ($399|0)==($397|0);
   if ($404) {
    $405 = (($driveSimData) + 400|0);
    $406 = Math_fround(HEAPF32[$405>>2]);
    $407 = $403 > $406;
    if ($407) {
     $408 = Math_fround(HEAPF32[$38>>2]);
     $409 = (($driveSimData) + 108|0);
     $410 = Math_fround(HEAPF32[$409>>2]);
     $411 = Math_fround($408 * $410);
     $412 = ((($driveSimData) + ($397<<2)|0) + 272|0);
     $413 = Math_fround(HEAPF32[$412>>2]);
     $notlhs$i = $411 > $413;
     $notrhs$i = ($397|0)!=(0);
     $not$or$cond2$i = $notrhs$i & $notlhs$i;
     $414 = ((($driveSimData) + ($397<<2)|0) + 400|0);
     $415 = Math_fround(HEAPF32[$414>>2]);
     $416 = $411 < $415;
     $417 = ($397>>>0)>(2);
     $or$cond3$i = $416 & $417;
     $brmerge$i = $not$or$cond2$i | $or$cond3$i;
     if (!($brmerge$i)) {
      $autoboxCompensatedAnalogAccel$0 = $$$i;
      break;
     }
     $418 = (($vehDrive4W) + 193|0);
     $419 = $not$or$cond2$i&1;
     HEAP8[$418>>0] = $419;
     $420 = (($vehDrive4W) + 194|0);
     $421 = $or$cond3$i&1;
     HEAP8[$420>>0] = $421;
     HEAPF32[$402>>2] = Math_fround(0.0);
     $autoboxCompensatedAnalogAccel$0 = $$$i;
     break;
    }
   }
   $422 = Math_fround($403 + $timestep);
   HEAPF32[$402>>2] = $422;
   $autoboxCompensatedAnalogAccel$0 = $$$i;
  }
 } while(0);
 __ZN5physx12processGearsEfRKNS_18PxVehicleGearsDataERNS_21PxVehicleDriveDynDataE($timestep,$57,$37);
 $423 = HEAP32[$$pre169>>2]|0;
 $424 = ($423|0)==(1);
 if ($424) {
  $933 = Math_fround(0.0);
 } else {
  $425 = (($driveSimData) + 256|0);
  $426 = Math_fround(HEAPF32[$425>>2]);
  $933 = $426;
 }
 $427 = (($driveSimData) + 260|0);
 $428 = HEAP32[$427>>2]|0;
 $429 = (($driveSimData) + 264|0);
 $430 = HEAP32[$429>>2]|0;
 $431 = ((($driveSimData) + ($423<<2)|0) + 112|0);
 $432 = Math_fround(HEAPF32[$431>>2]);
 $433 = (($driveSimData) + 240|0);
 $434 = Math_fround(HEAPF32[$433>>2]);
 $435 = Math_fround($432 * $434);
 $436 = (0|0)==(0|0);
 if (!($436)) {
  $437 = (0 + 32|0);
  HEAPF32[$437>>2] = $435;
 }
 $438 = (($vehDrive4W) + 132|0);
 $439 = Math_fround(HEAPF32[$438>>2]);
 $440 = (($vehDrive4W) + 136|0);
 $441 = Math_fround(HEAPF32[$440>>2]);
 $442 = (($vehDrive4W) + 140|0);
 $443 = Math_fround(HEAPF32[$442>>2]);
 $444 = (($vehDrive4W) + 144|0);
 $445 = Math_fround(HEAPF32[$444>>2]);
 $446 = Math_fround($445 - $443);
 $447 = $autoboxCompensatedAnalogAccel$0 > Math_fround(0.0);
 $448 = $439 == Math_fround(0.0);
 $or$cond = $447 & $448;
 if ($or$cond) {
  $449 = $441 == Math_fround(0.0);
  $724 = $449;
 } else {
  $724 = 0;
 }
 if (!($436)) {
  $450 = (0 + 12|0);
  HEAPF32[$450>>2] = $autoboxCompensatedAnalogAccel$0;
  $451 = (0 + 16|0);
  HEAPF32[$451>>2] = $439;
  $452 = (0 + 20|0);
  HEAPF32[$452>>2] = $441;
  $453 = (0 + 24|0);
  HEAPF32[$453>>2] = $443;
  $454 = (0 + 28|0);
  HEAPF32[$454>>2] = $445;
 }
 HEAP32[$activeWheelStates>>2] = 0;
 $455 = (($vehDrive4W) + 52|0);
 $456 = HEAP32[$455>>2]|0;
 $457 = $456 & 1;
 $458 = ($457|0)==(0);
 if (!($458)) {
  HEAP8[$activeWheelStates>>0] = 1;
 }
 $459 = $456 & 2;
 $460 = ($459|0)==(0);
 if (!($460)) {
  $461 = (($activeWheelStates) + 1|0);
  HEAP8[$461>>0] = 1;
 }
 $462 = $456 & 4;
 $463 = ($462|0)==(0);
 if (!($463)) {
  $464 = (($activeWheelStates) + 2|0);
  HEAP8[$464>>0] = 1;
 }
 $465 = $456 & 8;
 $466 = ($465|0)==(0);
 if (!($466)) {
  $467 = (($activeWheelStates) + 3|0);
  HEAP8[$467>>0] = 1;
 }
 ;HEAP32[$aveWheelSpeedContributions+0>>2]=0|0;HEAP32[$aveWheelSpeedContributions+4>>2]=0|0;HEAP32[$aveWheelSpeedContributions+8>>2]=0|0;HEAP32[$aveWheelSpeedContributions+12>>2]=0|0;
 $468 = (($driveSimData) + 552|0);
 $469 = HEAP32[$468>>2]|0;
 $470 = $441 > Math_fround(0.0);
 do {
  if ($470) {
   if ((($469|0) == 3)) {
    $type$0$i = 4;
    break;
   } else if ((($469|0) == 0)) {
    $type$0$i = 1;
    break;
   } else {
    $type$0$i = $469;
    break;
   }
  } else {
   $type$0$i = $469;
  }
 } while(0);
 $471 = Math_fround(HEAPF32[$59>>2]);
 $472 = (($driveSimData) + 532|0);
 $473 = Math_fround(HEAPF32[$472>>2]);
 $474 = (($driveSimData) + 536|0);
 $475 = Math_fround(HEAPF32[$474>>2]);
 $476 = Math_fround(Math_fround(1.0) - $471);
 $477 = Math_fround(Math_fround(1.0) - $473);
 $478 = Math_fround(Math_fround(1.0) - $475);
 switch ($type$0$i|0) {
 case 4: case 1:  {
  HEAPF32[$aveWheelSpeedContributions>>2] = $473;
  $486 = (($aveWheelSpeedContributions) + 4|0);
  HEAPF32[$486>>2] = $477;
  $487 = (($aveWheelSpeedContributions) + 8|0);
  HEAPF32[$487>>2] = Math_fround(0.0);
  $488 = (($aveWheelSpeedContributions) + 12|0);
  HEAPF32[$488>>2] = Math_fround(0.0);
  $495 = $473;$500 = $477;$505 = Math_fround(0.0);$510 = Math_fround(0.0);
  break;
 }
 case 3: case 0:  {
  $479 = Math_fround($471 * $473);
  HEAPF32[$aveWheelSpeedContributions>>2] = $479;
  $480 = Math_fround($471 * $477);
  $481 = (($aveWheelSpeedContributions) + 4|0);
  HEAPF32[$481>>2] = $480;
  $482 = Math_fround($476 * $475);
  $483 = (($aveWheelSpeedContributions) + 8|0);
  HEAPF32[$483>>2] = $482;
  $484 = Math_fround($476 * $478);
  $485 = (($aveWheelSpeedContributions) + 12|0);
  HEAPF32[$485>>2] = $484;
  $495 = $479;$500 = $480;$505 = $482;$510 = $484;
  break;
 }
 case 5: case 2:  {
  HEAPF32[$aveWheelSpeedContributions>>2] = Math_fround(0.0);
  $489 = (($aveWheelSpeedContributions) + 4|0);
  HEAPF32[$489>>2] = Math_fround(0.0);
  $490 = (($aveWheelSpeedContributions) + 8|0);
  HEAPF32[$490>>2] = $475;
  $491 = (($aveWheelSpeedContributions) + 12|0);
  HEAPF32[$491>>2] = $478;
  $495 = Math_fround(0.0);$500 = Math_fround(0.0);$505 = $475;$510 = $478;
  break;
 }
 default: {
  $495 = Math_fround(0.0);$500 = Math_fround(0.0);$505 = Math_fround(0.0);$510 = Math_fround(0.0);
 }
 }
 if (!($436)) {
  $492 = Math_fround(HEAPF32[$38>>2]);
  $493 = Math_fround(HEAPF32[$44>>2]);
  $494 = Math_fround($493 * $495);
  $496 = Math_fround($494 + Math_fround(0.0));
  $497 = (($44) + 4|0);
  $498 = Math_fround(HEAPF32[$497>>2]);
  $499 = Math_fround($498 * $500);
  $501 = Math_fround($496 + $499);
  $502 = (($44) + 8|0);
  $503 = Math_fround(HEAPF32[$502>>2]);
  $504 = Math_fround($503 * $505);
  $506 = Math_fround($501 + $504);
  $507 = (($44) + 12|0);
  $508 = Math_fround(HEAPF32[$507>>2]);
  $509 = Math_fround($508 * $510);
  $511 = Math_fround($506 + $509);
  $512 = Math_fround($435 * $511);
  $513 = Math_fround($512 - $492);
  $514 = (0 + 8|0);
  HEAPF32[$514>>2] = $513;
 }
 HEAP32[$isAccelApplied>>2] = 0;
 if ($724) {
  $515 = Math_fround(HEAPF32[$aveWheelSpeedContributions>>2]);
  $516 = $515 != Math_fround(0.0);
  $517 = $516&1;
  HEAP8[$isAccelApplied>>0] = $517;
  $518 = (($aveWheelSpeedContributions) + 4|0);
  $519 = Math_fround(HEAPF32[$518>>2]);
  $520 = $519 != Math_fround(0.0);
  $521 = (($isAccelApplied) + 1|0);
  $522 = $520&1;
  HEAP8[$521>>0] = $522;
  $523 = (($aveWheelSpeedContributions) + 8|0);
  $524 = Math_fround(HEAPF32[$523>>2]);
  $525 = $524 != Math_fround(0.0);
  $526 = (($isAccelApplied) + 2|0);
  $527 = $525&1;
  HEAP8[$526>>0] = $527;
  $528 = (($aveWheelSpeedContributions) + 12|0);
  $529 = Math_fround(HEAPF32[$528>>2]);
  $530 = $529 != Math_fround(0.0);
  $531 = (($isAccelApplied) + 3|0);
  $532 = $530&1;
  HEAP8[$531>>0] = $532;
 }
 ;HEAP32[$steerAngles+0>>2]=0|0;HEAP32[$steerAngles+4>>2]=0|0;HEAP32[$steerAngles+8>>2]=0|0;HEAP32[$steerAngles+12>>2]=0|0;
 __ZN5physx36computeAckermannCorrectedSteerAnglesERKNS_23PxVehicleDriveSimData4WERKNS_23PxVehicleWheels4SimDataEfPf($driveSimData,$42,$446,$steerAngles);
 if ($199) {
  $2037 = $386;$2040 = $388;$2043 = $391;$629 = $348;$632 = $327;$634 = $334;$637 = $341;$664 = $376;$666 = $378;$669 = $381;
 } else {
  $i7$0116 = 0;
  while(1) {
   $533 = $i7$0116 << 2;
   $534 = (($wheelQueryResults) + (($533*148)|0)|0);
   $535 = ((($44) + (($i7$0116*208)|0)|0) + 196|0);
   $536 = HEAP32[$535>>2]|0;
   $537 = ($536|0)==(0|0);
   if ($537) {
    $$sum8687 = $533 | 1;
    $621 = (($wheelQueryResults) + (($$sum8687*148)|0)|0);
    $$sum8889 = $533 | 2;
    $622 = (($wheelQueryResults) + (($$sum8889*148)|0)|0);
    $$sum9091 = $533 | 3;
    $623 = (($wheelQueryResults) + (($$sum9091*148)|0)|0);
    ;HEAP32[$534+0>>2]=0|0;HEAP32[$534+4>>2]=0|0;HEAP32[$534+8>>2]=0|0;HEAP32[$534+12>>2]=0|0;HEAP32[$534+16>>2]=0|0;HEAP32[$534+20>>2]=0|0;HEAP32[$534+24>>2]=0|0;
    ;HEAP32[$621+0>>2]=0|0;HEAP32[$621+4>>2]=0|0;HEAP32[$621+8>>2]=0|0;HEAP32[$621+12>>2]=0|0;HEAP32[$621+16>>2]=0|0;HEAP32[$621+20>>2]=0|0;HEAP32[$621+24>>2]=0|0;
    ;HEAP32[$622+0>>2]=0|0;HEAP32[$622+4>>2]=0|0;HEAP32[$622+8>>2]=0|0;HEAP32[$622+12>>2]=0|0;HEAP32[$622+16>>2]=0|0;HEAP32[$622+20>>2]=0|0;HEAP32[$622+24>>2]=0|0;
    ;HEAP32[$623+0>>2]=0|0;HEAP32[$623+4>>2]=0|0;HEAP32[$623+8>>2]=0|0;HEAP32[$623+12>>2]=0|0;HEAP32[$623+16>>2]=0|0;HEAP32[$623+20>>2]=0|0;HEAP32[$623+24>>2]=0|0;
   } else {
    $538 = ((($44) + (($i7$0116*208)|0)|0) + 80|0);
    $539 = ((($44) + (($i7$0116*208)|0)|0) + 128|0);
    $540 = ((($44) + (($i7$0116*208)|0)|0) + 176|0);
    $541 = Math_fround(HEAPF32[$538>>2]);
    HEAPF32[$534>>2] = $541;
    $542 = ((($44) + (($i7$0116*208)|0)|0) + 84|0);
    $543 = Math_fround(HEAPF32[$542>>2]);
    $544 = ((($wheelQueryResults) + (($533*148)|0)|0) + 4|0);
    HEAPF32[$544>>2] = $543;
    $545 = ((($44) + (($i7$0116*208)|0)|0) + 88|0);
    $546 = Math_fround(HEAPF32[$545>>2]);
    $547 = ((($wheelQueryResults) + (($533*148)|0)|0) + 8|0);
    HEAPF32[$547>>2] = $546;
    $548 = Math_fround(HEAPF32[$539>>2]);
    $549 = ((($wheelQueryResults) + (($533*148)|0)|0) + 12|0);
    HEAPF32[$549>>2] = $548;
    $550 = ((($44) + (($i7$0116*208)|0)|0) + 132|0);
    $551 = Math_fround(HEAPF32[$550>>2]);
    $552 = ((($wheelQueryResults) + (($533*148)|0)|0) + 16|0);
    HEAPF32[$552>>2] = $551;
    $553 = ((($44) + (($i7$0116*208)|0)|0) + 136|0);
    $554 = Math_fround(HEAPF32[$553>>2]);
    $555 = ((($wheelQueryResults) + (($533*148)|0)|0) + 20|0);
    HEAPF32[$555>>2] = $554;
    $556 = Math_fround(HEAPF32[$540>>2]);
    $557 = ((($wheelQueryResults) + (($533*148)|0)|0) + 24|0);
    HEAPF32[$557>>2] = $556;
    $558 = ((($44) + (($i7$0116*208)|0)|0) + 92|0);
    $559 = Math_fround(HEAPF32[$558>>2]);
    $$sum4445 = $533 | 1;
    $560 = (($wheelQueryResults) + (($$sum4445*148)|0)|0);
    HEAPF32[$560>>2] = $559;
    $561 = ((($44) + (($i7$0116*208)|0)|0) + 96|0);
    $562 = Math_fround(HEAPF32[$561>>2]);
    $563 = ((($wheelQueryResults) + (($$sum4445*148)|0)|0) + 4|0);
    HEAPF32[$563>>2] = $562;
    $564 = ((($44) + (($i7$0116*208)|0)|0) + 100|0);
    $565 = Math_fround(HEAPF32[$564>>2]);
    $566 = ((($wheelQueryResults) + (($$sum4445*148)|0)|0) + 8|0);
    HEAPF32[$566>>2] = $565;
    $567 = ((($44) + (($i7$0116*208)|0)|0) + 140|0);
    $568 = Math_fround(HEAPF32[$567>>2]);
    $569 = ((($wheelQueryResults) + (($$sum4445*148)|0)|0) + 12|0);
    HEAPF32[$569>>2] = $568;
    $570 = ((($44) + (($i7$0116*208)|0)|0) + 144|0);
    $571 = Math_fround(HEAPF32[$570>>2]);
    $572 = ((($wheelQueryResults) + (($$sum4445*148)|0)|0) + 16|0);
    HEAPF32[$572>>2] = $571;
    $573 = ((($44) + (($i7$0116*208)|0)|0) + 148|0);
    $574 = Math_fround(HEAPF32[$573>>2]);
    $575 = ((($wheelQueryResults) + (($$sum4445*148)|0)|0) + 20|0);
    HEAPF32[$575>>2] = $574;
    $576 = ((($44) + (($i7$0116*208)|0)|0) + 180|0);
    $577 = Math_fround(HEAPF32[$576>>2]);
    $578 = ((($wheelQueryResults) + (($$sum4445*148)|0)|0) + 24|0);
    HEAPF32[$578>>2] = $577;
    $579 = ((($44) + (($i7$0116*208)|0)|0) + 104|0);
    $580 = Math_fround(HEAPF32[$579>>2]);
    $$sum5859 = $533 | 2;
    $581 = (($wheelQueryResults) + (($$sum5859*148)|0)|0);
    HEAPF32[$581>>2] = $580;
    $582 = ((($44) + (($i7$0116*208)|0)|0) + 108|0);
    $583 = Math_fround(HEAPF32[$582>>2]);
    $584 = ((($wheelQueryResults) + (($$sum5859*148)|0)|0) + 4|0);
    HEAPF32[$584>>2] = $583;
    $585 = ((($44) + (($i7$0116*208)|0)|0) + 112|0);
    $586 = Math_fround(HEAPF32[$585>>2]);
    $587 = ((($wheelQueryResults) + (($$sum5859*148)|0)|0) + 8|0);
    HEAPF32[$587>>2] = $586;
    $588 = ((($44) + (($i7$0116*208)|0)|0) + 152|0);
    $589 = Math_fround(HEAPF32[$588>>2]);
    $590 = ((($wheelQueryResults) + (($$sum5859*148)|0)|0) + 12|0);
    HEAPF32[$590>>2] = $589;
    $591 = ((($44) + (($i7$0116*208)|0)|0) + 156|0);
    $592 = Math_fround(HEAPF32[$591>>2]);
    $593 = ((($wheelQueryResults) + (($$sum5859*148)|0)|0) + 16|0);
    HEAPF32[$593>>2] = $592;
    $594 = ((($44) + (($i7$0116*208)|0)|0) + 160|0);
    $595 = Math_fround(HEAPF32[$594>>2]);
    $596 = ((($wheelQueryResults) + (($$sum5859*148)|0)|0) + 20|0);
    HEAPF32[$596>>2] = $595;
    $597 = ((($44) + (($i7$0116*208)|0)|0) + 184|0);
    $598 = Math_fround(HEAPF32[$597>>2]);
    $599 = ((($wheelQueryResults) + (($$sum5859*148)|0)|0) + 24|0);
    HEAPF32[$599>>2] = $598;
    $600 = ((($44) + (($i7$0116*208)|0)|0) + 116|0);
    $601 = Math_fround(HEAPF32[$600>>2]);
    $$sum7273 = $533 | 3;
    $602 = (($wheelQueryResults) + (($$sum7273*148)|0)|0);
    HEAPF32[$602>>2] = $601;
    $603 = ((($44) + (($i7$0116*208)|0)|0) + 120|0);
    $604 = Math_fround(HEAPF32[$603>>2]);
    $605 = ((($wheelQueryResults) + (($$sum7273*148)|0)|0) + 4|0);
    HEAPF32[$605>>2] = $604;
    $606 = ((($44) + (($i7$0116*208)|0)|0) + 124|0);
    $607 = Math_fround(HEAPF32[$606>>2]);
    $608 = ((($wheelQueryResults) + (($$sum7273*148)|0)|0) + 8|0);
    HEAPF32[$608>>2] = $607;
    $609 = ((($44) + (($i7$0116*208)|0)|0) + 164|0);
    $610 = Math_fround(HEAPF32[$609>>2]);
    $611 = ((($wheelQueryResults) + (($$sum7273*148)|0)|0) + 12|0);
    HEAPF32[$611>>2] = $610;
    $612 = ((($44) + (($i7$0116*208)|0)|0) + 168|0);
    $613 = Math_fround(HEAPF32[$612>>2]);
    $614 = ((($wheelQueryResults) + (($$sum7273*148)|0)|0) + 16|0);
    HEAPF32[$614>>2] = $613;
    $615 = ((($44) + (($i7$0116*208)|0)|0) + 172|0);
    $616 = Math_fround(HEAPF32[$615>>2]);
    $617 = ((($wheelQueryResults) + (($$sum7273*148)|0)|0) + 20|0);
    HEAPF32[$617>>2] = $616;
    $618 = ((($44) + (($i7$0116*208)|0)|0) + 188|0);
    $619 = Math_fround(HEAPF32[$618>>2]);
    $620 = ((($wheelQueryResults) + (($$sum7273*148)|0)|0) + 24|0);
    HEAPF32[$620>>2] = $619;
   }
   $624 = (($i7$0116) + 1)|0;
   $exitcond154 = ($624|0)==($48|0);
   if ($exitcond154) {
    break;
   } else {
    $i7$0116 = $624;
   }
  }
  $$pre = Math_fround(HEAPF32[$carChassisLinVel>>2]);
  $$pre158 = Math_fround(HEAPF32[$379>>2]);
  $$pre159 = Math_fround(HEAPF32[$382>>2]);
  $$pre160 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $$pre161 = Math_fround(HEAPF32[$389>>2]);
  $$pre162 = Math_fround(HEAPF32[$392>>2]);
  $$pre163 = Math_fround(HEAPF32[$351>>2]);
  $$pre164 = Math_fround(HEAPF32[$carChassisTransform>>2]);
  $$pre165 = Math_fround(HEAPF32[$349>>2]);
  $$pre166 = Math_fround(HEAPF32[$350>>2]);
  $2037 = $$pre160;$2040 = $$pre161;$2043 = $$pre162;$629 = $$pre163;$632 = $$pre164;$634 = $$pre165;$637 = $$pre166;$664 = $$pre;$666 = $$pre158;$669 = $$pre159;
 }
 $625 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $626 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $627 = Math_fround(Math_fround(1.0) * Math_fround(2.0));
 $628 = Math_fround($629 * $629);
 $630 = Math_fround($628 + Math_fround(-0.5));
 $631 = Math_fround($625 * $632);
 $633 = Math_fround($626 * $634);
 $635 = Math_fround($631 + $633);
 $636 = Math_fround($627 * $637);
 $638 = Math_fround($635 + $636);
 $639 = Math_fround($625 * $630);
 $640 = Math_fround($627 * $634);
 $641 = Math_fround($626 * $637);
 $642 = Math_fround($640 - $641);
 $643 = Math_fround($629 * $642);
 $644 = Math_fround($639 + $643);
 $645 = Math_fround($632 * $638);
 $646 = Math_fround($645 + $644);
 $647 = Math_fround($626 * $630);
 $648 = Math_fround($625 * $637);
 $649 = Math_fround($627 * $632);
 $650 = Math_fround($648 - $649);
 $651 = Math_fround($629 * $650);
 $652 = Math_fround($647 + $651);
 $653 = Math_fround($634 * $638);
 $654 = Math_fround($653 + $652);
 $655 = Math_fround($627 * $630);
 $656 = Math_fround($626 * $632);
 $657 = Math_fround($625 * $634);
 $658 = Math_fround($656 - $657);
 $659 = Math_fround($629 * $658);
 $660 = Math_fround($655 + $659);
 $661 = Math_fround($637 * $638);
 $662 = Math_fround($660 + $661);
 $663 = Math_fround($664 * $646);
 $665 = Math_fround($666 * $654);
 $667 = Math_fround($663 + $665);
 $668 = Math_fround($669 * $662);
 $670 = Math_fround($668 + $667);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($670)))));
 $671 = (($vehDrive4W) + 56|0);
 $672 = Math_fround(HEAPF32[$671>>2]);
 $673 = (($vehDrive4W) + 60|0);
 $674 = HEAP32[$673>>2]|0;
 $675 = (($vehDrive4W) + 64|0);
 $676 = HEAP32[$675>>2]|0;
 $677 = $fabsf$i$i$i < $672;
 $678 = $677 ? $674 : $676;
 $679 = (Math_fround(($678>>>0)));
 $680 = Math_fround(Math_fround(1.0) / $679);
 $681 = Math_fround($680 * $timestep);
 $682 = Math_fround(Math_fround(1.0) / $timestep);
 $683 = (($vehDrive4W) + 68|0);
 $684 = Math_fround(HEAPF32[$683>>2]);
 HEAPF32[$constData>>2] = $680;
 $685 = (($constData) + 4|0);
 HEAPF32[$685>>2] = $681;
 $686 = (($constData) + 8|0);
 $687 = Math_fround(HEAPF32[$gravity>>2]);
 HEAPF32[$686>>2] = $687;
 $688 = (($constData) + 12|0);
 $689 = (($gravity) + 4|0);
 $690 = Math_fround(HEAPF32[$689>>2]);
 HEAPF32[$688>>2] = $690;
 $691 = (($constData) + 16|0);
 $692 = (($gravity) + 8|0);
 $693 = Math_fround(HEAPF32[$692>>2]);
 HEAPF32[$691>>2] = $693;
 $694 = (($constData) + 20|0);
 HEAPF32[$694>>2] = $gravityMagnitude;
 $695 = (($constData) + 24|0);
 HEAPF32[$695>>2] = $recipGravityMagnitude;
 $696 = (($constData) + 28|0);
 HEAP8[$696>>0] = 0;
 $697 = (($constData) + 32|0);
 HEAPF32[$697>>2] = $684;
 $698 = (($constData) + 36|0);
 HEAP32[$698>>2] = $62;
 $699 = (($constData) + 40|0);
 HEAP32[$699>>2] = $drivableSurfaceToTireFrictionPairs;
 $700 = ($678|0)==(0);
 if ($700) {
  $2014 = $664;
 } else {
  $701 = (($chassisForce) + 4|0);
  $702 = (($chassisForce) + 8|0);
  $703 = (($chassisTorque) + 4|0);
  $704 = (($chassisTorque) + 8|0);
  $705 = Math_fround(-$439);
  $706 = (($42) + 212|0);
  $707 = (($42) + 216|0);
  $708 = (($44) + 4|0);
  $709 = (($42) + 260|0);
  $710 = (($42) + 264|0);
  $711 = (($brakeTorques) + 4|0);
  $712 = (($isBrakeApplied) + 1|0);
  $713 = (($44) + 8|0);
  $714 = (($42) + 308|0);
  $715 = (($42) + 312|0);
  $716 = (($brakeTorques) + 8|0);
  $717 = (($isBrakeApplied) + 2|0);
  $718 = (($44) + 12|0);
  $719 = (($42) + 356|0);
  $720 = (($42) + 360|0);
  $721 = (($brakeTorques) + 12|0);
  $722 = (($isBrakeApplied) + 3|0);
  $723 = $724&1;
  $725 = (($inputData) + 4|0);
  $726 = (($inputData) + 8|0);
  $727 = (($inputData) + 12|0);
  $728 = (($inputData) + 16|0);
  $729 = (($inputData) + 20|0);
  $730 = (($inputData) + 24|0);
  $731 = (($inputData) + 28|0);
  $732 = (($inputData) + 32|0);
  $733 = (($inputData) + 36|0);
  $734 = (($inputData) + 40|0);
  $735 = (($inputData) + 44|0);
  $736 = (($inputData) + 48|0);
  $737 = (($inputData) + 52|0);
  $738 = (($inputData) + 56|0);
  $739 = (($inputData) + 60|0);
  $740 = (($inputData) + 64|0);
  $741 = (($inputData) + 68|0);
  $742 = (($inputData) + 72|0);
  $743 = (($inputData) + 76|0);
  $744 = (($inputData) + 80|0);
  $745 = (($inputData) + 84|0);
  $746 = (($inputData) + 88|0);
  $747 = HEAP32[$numActiveWheelsPerBlock4>>2]|0;
  $748 = (($outputData) + 112|0);
  $749 = (($outputData) + 164|0);
  $750 = (($outputData) + 113|0);
  $751 = (($outputData) + 168|0);
  $752 = (($outputData) + 114|0);
  $753 = (($outputData) + 172|0);
  $754 = (($outputData) + 115|0);
  $755 = (($outputData) + 176|0);
  $756 = (($outputData) + 508|0);
  $757 = (($outputData) + 512|0);
  $758 = (($outputData) + 516|0);
  $759 = (($outputData) + 520|0);
  $760 = (($outputData) + 524|0);
  $761 = (($outputData) + 528|0);
  $762 = (($outputData) + 532|0);
  $763 = (($outputData) + 536|0);
  $764 = (($678) + -1)|0;
  $765 = (($outputData) + 888|0);
  $766 = (($outputData) + 968|0);
  $767 = (($outputData) + 984|0);
  $768 = (($44) + 196|0);
  $769 = (($44) + 80|0);
  $770 = (($44) + 176|0);
  $771 = (($44) + 160|0);
  $772 = (($44) + 144|0);
  $773 = (($outputData) + 904|0);
  $774 = (($outputData) + 908|0);
  $775 = (($44) + 84|0);
  $776 = (($outputData) + 912|0);
  $777 = (($44) + 88|0);
  $778 = (($outputData) + 916|0);
  $779 = (($44) + 92|0);
  $780 = (($outputData) + 892|0);
  $781 = (($44) + 178|0);
  $782 = (($outputData) + 920|0);
  $783 = (($44) + 96|0);
  $784 = (($outputData) + 924|0);
  $785 = (($44) + 100|0);
  $786 = (($outputData) + 928|0);
  $787 = (($44) + 104|0);
  $788 = (($outputData) + 932|0);
  $789 = (($44) + 108|0);
  $790 = (($outputData) + 972|0);
  $791 = (($44) + 164|0);
  $792 = (($outputData) + 988|0);
  $793 = (($44) + 148|0);
  $794 = (($outputData) + 896|0);
  $795 = (($44) + 180|0);
  $796 = (($outputData) + 936|0);
  $797 = (($44) + 112|0);
  $798 = (($outputData) + 940|0);
  $799 = (($44) + 116|0);
  $800 = (($outputData) + 944|0);
  $801 = (($44) + 120|0);
  $802 = (($outputData) + 948|0);
  $803 = (($44) + 124|0);
  $804 = (($outputData) + 976|0);
  $805 = (($44) + 168|0);
  $806 = (($outputData) + 992|0);
  $807 = (($44) + 152|0);
  $808 = (($outputData) + 900|0);
  $809 = (($44) + 182|0);
  $810 = (($outputData) + 952|0);
  $811 = (($44) + 128|0);
  $812 = (($outputData) + 956|0);
  $813 = (($44) + 132|0);
  $814 = (($outputData) + 960|0);
  $815 = (($44) + 136|0);
  $816 = (($outputData) + 964|0);
  $817 = (($44) + 140|0);
  $818 = (($outputData) + 980|0);
  $819 = (($44) + 172|0);
  $820 = (($outputData) + 996|0);
  $821 = (($44) + 156|0);
  $822 = (($44) + 200|0);
  $823 = (($outputData) + 484|0);
  $824 = (($outputData) + 488|0);
  $825 = (($outputData) + 492|0);
  $826 = (($outputData) + 496|0);
  $827 = (($outputData) + 500|0);
  $828 = (($outputData) + 504|0);
  $829 = (($44) + 192|0);
  $830 = (($outputData) + 540|0);
  $831 = (($outputData) + 544|0);
  $832 = (($outputData) + 548|0);
  $833 = (($outputData) + 552|0);
  $834 = (($outputData) + 556|0);
  $835 = (($outputData) + 560|0);
  $836 = (($outputData) + 564|0);
  $837 = (($outputData) + 568|0);
  $838 = (($outputData) + 572|0);
  $839 = (($outputData) + 576|0);
  $840 = (($outputData) + 580|0);
  $841 = (($outputData) + 584|0);
  $842 = (($outputData) + 588|0);
  $843 = (($outputData) + 592|0);
  $844 = (($outputData) + 596|0);
  $845 = (($outputData) + 600|0);
  $846 = (($outputData) + 604|0);
  $847 = (($outputData) + 608|0);
  $848 = (($outputData) + 612|0);
  $849 = (($outputData) + 616|0);
  $850 = (($outputData) + 620|0);
  $851 = (($outputData) + 624|0);
  $852 = (($outputData) + 628|0);
  $853 = (($outputData) + 632|0);
  $854 = (($outputData) + 636|0);
  $855 = (($outputData) + 656|0);
  $856 = (($outputData) + 660|0);
  $857 = (($outputData) + 664|0);
  $858 = (($outputData) + 668|0);
  $859 = (($outputData) + 672|0);
  $860 = (($outputData) + 676|0);
  $861 = (($outputData) + 680|0);
  $862 = (($outputData) + 684|0);
  $863 = (($outputData) + 688|0);
  $864 = (($outputData) + 692|0);
  $865 = (($outputData) + 696|0);
  $866 = (($outputData) + 700|0);
  $867 = (($outputData) + 704|0);
  $868 = (($outputData) + 708|0);
  $869 = (($outputData) + 712|0);
  $870 = (($outputData) + 716|0);
  $871 = (($outputData) + 720|0);
  $872 = (($outputData) + 724|0);
  $873 = (($outputData) + 728|0);
  $874 = (($outputData) + 732|0);
  $875 = (($outputData) + 736|0);
  $876 = (($outputData) + 740|0);
  $877 = (($outputData) + 744|0);
  $878 = (($outputData) + 748|0);
  $879 = (($outputData) + 752|0);
  $880 = (($outputData) + 772|0);
  $881 = (($outputData) + 776|0);
  $882 = (($outputData) + 780|0);
  $883 = (($outputData) + 784|0);
  $884 = (($outputData) + 788|0);
  $885 = (($outputData) + 792|0);
  $886 = (($outputData) + 796|0);
  $887 = (($outputData) + 800|0);
  $888 = (($outputData) + 804|0);
  $889 = (($outputData) + 808|0);
  $890 = (($outputData) + 812|0);
  $891 = (($outputData) + 816|0);
  $892 = (($outputData) + 820|0);
  $893 = (($outputData) + 824|0);
  $894 = (($outputData) + 828|0);
  $895 = (($outputData) + 832|0);
  $896 = (($outputData) + 836|0);
  $897 = (($outputData) + 840|0);
  $898 = (($outputData) + 844|0);
  $899 = (($outputData) + 848|0);
  $900 = (($outputData) + 852|0);
  $901 = (($outputData) + 856|0);
  $902 = (($outputData) + 860|0);
  $903 = (($outputData) + 864|0);
  $904 = (($outputData) + 868|0);
  $905 = HEAP32[$numActiveWheelsPerBlock4>>2]|0;
  $906 = ($905|0)==(0);
  $907 = (($driveSimData) + 84|0);
  $908 = (($driveSimData) + 108|0);
  $909 = (($driveSimData) + 4|0);
  $910 = (($driveSimData) + 92|0);
  $911 = (($driveSimData) + 96|0);
  $912 = (($driveSimData) + 100|0);
  $913 = (($implicitSolverInput) + 4|0);
  $914 = (($implicitSolverInput) + 8|0);
  $915 = (($implicitSolverInput) + 12|0);
  $916 = (($implicitSolverInput) + 16|0);
  $917 = (($implicitSolverInput) + 20|0);
  $918 = (($implicitSolverInput) + 24|0);
  $919 = (($implicitSolverInput) + 28|0);
  $920 = (($implicitSolverInput) + 32|0);
  $921 = (($implicitSolverInput) + 36|0);
  $922 = (($implicitSolverInput) + 40|0);
  $923 = (($implicitSolverInput) + 44|0);
  $924 = (($implicitSolverInput) + 48|0);
  $925 = (($implicitSolverInput) + 52|0);
  $926 = (($outputData) + 468|0);
  $927 = (($implicitSolverInput) + 56|0);
  $928 = (($implicitSolverInput) + 60|0);
  $929 = (($implicitSolverInput) + 64|0);
  $930 = (($implicitSolverInput) + 68|0);
  $931 = (($implicitSolverOutput) + 4|0);
  $932 = Math_fround($933 * $435);
  $934 = ($48>>>0)>(1);
  $935 = (($extraWheelSteerAngles) + 4|0);
  $936 = (($extraWheelSteerAngles) + 8|0);
  $937 = (($extraWheelSteerAngles) + 12|0);
  $938 = (($extraWheelBrakeTorques) + 4|0);
  $939 = (($extraIsBrakeApplied) + 1|0);
  $940 = (($extraWheelBrakeTorques) + 8|0);
  $941 = (($extraIsBrakeApplied) + 2|0);
  $942 = (($extraWheelBrakeTorques) + 12|0);
  $943 = (($extraIsBrakeApplied) + 3|0);
  $944 = (($extraInputData) + 4|0);
  $945 = (($extraInputData) + 8|0);
  $946 = (($extraInputData) + 12|0);
  $947 = (($extraInputData) + 16|0);
  $948 = (($extraInputData) + 20|0);
  $949 = (($extraInputData) + 24|0);
  $950 = (($extraInputData) + 28|0);
  $951 = (($extraInputData) + 32|0);
  $952 = (($extraInputData) + 36|0);
  $953 = (($extraInputData) + 40|0);
  $954 = (($extraInputData) + 44|0);
  $955 = (($extraInputData) + 48|0);
  $956 = (($extraInputData) + 52|0);
  $957 = (($extraInputData) + 56|0);
  $958 = (($extraInputData) + 60|0);
  $959 = (($extraInputData) + 64|0);
  $960 = (($extraInputData) + 68|0);
  $961 = (($extraInputData) + 72|0);
  $962 = (($extraInputData) + 76|0);
  $963 = (($extraInputData) + 80|0);
  $964 = (($extraInputData) + 84|0);
  $965 = (($extraInputData) + 88|0);
  $966 = (($extraOutputData) + 112|0);
  $967 = (($extraOutputData) + 164|0);
  $968 = (($extraOutputData) + 113|0);
  $969 = (($extraOutputData) + 168|0);
  $970 = (($extraOutputData) + 114|0);
  $971 = (($extraOutputData) + 172|0);
  $972 = (($extraOutputData) + 115|0);
  $973 = (($extraOutputData) + 176|0);
  $974 = (($extraOutputData) + 508|0);
  $975 = (($extraOutputData) + 512|0);
  $976 = (($extraOutputData) + 516|0);
  $977 = (($extraOutputData) + 520|0);
  $978 = (($extraOutputData) + 524|0);
  $979 = (($extraOutputData) + 528|0);
  $980 = (($extraOutputData) + 532|0);
  $981 = (($extraOutputData) + 536|0);
  $982 = (($extraOutputData) + 888|0);
  $983 = (($extraOutputData) + 968|0);
  $984 = (($extraOutputData) + 984|0);
  $985 = (($extraOutputData) + 904|0);
  $986 = (($extraOutputData) + 908|0);
  $987 = (($extraOutputData) + 912|0);
  $988 = (($extraOutputData) + 916|0);
  $989 = (($extraOutputData) + 892|0);
  $990 = (($extraOutputData) + 920|0);
  $991 = (($extraOutputData) + 924|0);
  $992 = (($extraOutputData) + 928|0);
  $993 = (($extraOutputData) + 932|0);
  $994 = (($extraOutputData) + 972|0);
  $995 = (($extraOutputData) + 988|0);
  $996 = (($extraOutputData) + 896|0);
  $997 = (($extraOutputData) + 936|0);
  $998 = (($extraOutputData) + 940|0);
  $999 = (($extraOutputData) + 944|0);
  $1000 = (($extraOutputData) + 948|0);
  $1001 = (($extraOutputData) + 976|0);
  $1002 = (($extraOutputData) + 992|0);
  $1003 = (($extraOutputData) + 900|0);
  $1004 = (($extraOutputData) + 952|0);
  $1005 = (($extraOutputData) + 956|0);
  $1006 = (($extraOutputData) + 960|0);
  $1007 = (($extraOutputData) + 964|0);
  $1008 = (($extraOutputData) + 980|0);
  $1009 = (($extraOutputData) + 996|0);
  $1010 = (($extraOutputData) + 484|0);
  $1011 = (($extraOutputData) + 488|0);
  $1012 = (($extraOutputData) + 492|0);
  $1013 = (($extraOutputData) + 496|0);
  $1014 = (($extraOutputData) + 500|0);
  $1015 = (($extraOutputData) + 504|0);
  $1016 = (($extraOutputData) + 540|0);
  $1017 = (($extraOutputData) + 544|0);
  $1018 = (($extraOutputData) + 548|0);
  $1019 = (($extraOutputData) + 552|0);
  $1020 = (($extraOutputData) + 556|0);
  $1021 = (($extraOutputData) + 560|0);
  $1022 = (($extraOutputData) + 564|0);
  $1023 = (($extraOutputData) + 568|0);
  $1024 = (($extraOutputData) + 572|0);
  $1025 = (($extraOutputData) + 576|0);
  $1026 = (($extraOutputData) + 580|0);
  $1027 = (($extraOutputData) + 584|0);
  $1028 = (($extraOutputData) + 588|0);
  $1029 = (($extraOutputData) + 592|0);
  $1030 = (($extraOutputData) + 596|0);
  $1031 = (($extraOutputData) + 600|0);
  $1032 = (($extraOutputData) + 604|0);
  $1033 = (($extraOutputData) + 608|0);
  $1034 = (($extraOutputData) + 612|0);
  $1035 = (($extraOutputData) + 616|0);
  $1036 = (($extraOutputData) + 620|0);
  $1037 = (($extraOutputData) + 624|0);
  $1038 = (($extraOutputData) + 628|0);
  $1039 = (($extraOutputData) + 632|0);
  $1040 = (($extraOutputData) + 636|0);
  $1041 = (($extraOutputData) + 656|0);
  $1042 = (($extraOutputData) + 660|0);
  $1043 = (($extraOutputData) + 664|0);
  $1044 = (($extraOutputData) + 668|0);
  $1045 = (($extraOutputData) + 672|0);
  $1046 = (($extraOutputData) + 676|0);
  $1047 = (($extraOutputData) + 680|0);
  $1048 = (($extraOutputData) + 684|0);
  $1049 = (($extraOutputData) + 688|0);
  $1050 = (($extraOutputData) + 692|0);
  $1051 = (($extraOutputData) + 696|0);
  $1052 = (($extraOutputData) + 700|0);
  $1053 = (($extraOutputData) + 704|0);
  $1054 = (($extraOutputData) + 708|0);
  $1055 = (($extraOutputData) + 712|0);
  $1056 = (($extraOutputData) + 716|0);
  $1057 = (($extraOutputData) + 720|0);
  $1058 = (($extraOutputData) + 724|0);
  $1059 = (($extraOutputData) + 728|0);
  $1060 = (($extraOutputData) + 732|0);
  $1061 = (($extraOutputData) + 736|0);
  $1062 = (($extraOutputData) + 740|0);
  $1063 = (($extraOutputData) + 744|0);
  $1064 = (($extraOutputData) + 748|0);
  $1065 = (($extraOutputData) + 752|0);
  $1066 = (($extraOutputData) + 772|0);
  $1067 = (($extraOutputData) + 776|0);
  $1068 = (($extraOutputData) + 780|0);
  $1069 = (($extraOutputData) + 784|0);
  $1070 = (($extraOutputData) + 788|0);
  $1071 = (($extraOutputData) + 792|0);
  $1072 = (($extraOutputData) + 796|0);
  $1073 = (($extraOutputData) + 800|0);
  $1074 = (($extraOutputData) + 804|0);
  $1075 = (($extraOutputData) + 808|0);
  $1076 = (($extraOutputData) + 812|0);
  $1077 = (($extraOutputData) + 816|0);
  $1078 = (($extraOutputData) + 820|0);
  $1079 = (($extraOutputData) + 824|0);
  $1080 = (($extraOutputData) + 828|0);
  $1081 = (($extraOutputData) + 832|0);
  $1082 = (($extraOutputData) + 836|0);
  $1083 = (($extraOutputData) + 840|0);
  $1084 = (($extraOutputData) + 844|0);
  $1085 = (($extraOutputData) + 848|0);
  $1086 = (($extraOutputData) + 852|0);
  $1087 = (($extraOutputData) + 856|0);
  $1088 = (($extraOutputData) + 860|0);
  $1089 = (($extraOutputData) + 864|0);
  $1090 = (($extraOutputData) + 868|0);
  $1091 = (($extraOutputData) + 468|0);
  $1092 = (($extraWheelActiveStates) + 3|0);
  $1093 = (($extraWheelActiveStates) + 2|0);
  $1094 = (($extraWheelActiveStates) + 1|0);
  $k$0112 = 0;
  while(1) {
   HEAPF32[$chassisForce>>2] = Math_fround(0.0);
   HEAPF32[$701>>2] = Math_fround(0.0);
   HEAPF32[$702>>2] = Math_fround(0.0);
   HEAPF32[$chassisTorque>>2] = Math_fround(0.0);
   HEAPF32[$703>>2] = Math_fround(0.0);
   HEAPF32[$704>>2] = Math_fround(0.0);
   ;HEAP32[$brakeTorques+0>>2]=0|0;HEAP32[$brakeTorques+4>>2]=0|0;HEAP32[$brakeTorques+8>>2]=0|0;HEAP32[$brakeTorques+12>>2]=0|0;
   HEAP32[$isBrakeApplied>>2] = 0;
   $1095 = Math_fround(HEAPF32[$44>>2]);
   $1096 = $1095 <= Math_fround(-0.0);
   $1097 = $1096 ? Math_fround(0.0) : Math_fround(1.0);
   $1098 = $1095 >= Math_fround(0.0);
   $1099 = $1098 ? $1097 : Math_fround(-1.0);
   $1100 = Math_fround($1099 * $705);
   $1101 = Math_fround(HEAPF32[$706>>2]);
   $1102 = Math_fround($1101 * $1100);
   $1103 = Math_fround($441 * $1099);
   $1104 = Math_fround(HEAPF32[$707>>2]);
   $1105 = Math_fround($1104 * $1103);
   $1106 = Math_fround($1102 - $1105);
   HEAPF32[$brakeTorques>>2] = $1106;
   $1107 = Math_fround(HEAPF32[$706>>2]);
   $1108 = Math_fround($439 * $1107);
   $1109 = Math_fround(HEAPF32[$707>>2]);
   $1110 = Math_fround($441 * $1109);
   $1111 = Math_fround($1108 + $1110);
   $1112 = $1111 != Math_fround(0.0);
   $1113 = $1112&1;
   HEAP8[$isBrakeApplied>>0] = $1113;
   $1114 = Math_fround(HEAPF32[$708>>2]);
   $1115 = $1114 <= Math_fround(-0.0);
   $1116 = $1115 ? Math_fround(0.0) : Math_fround(1.0);
   $1117 = $1114 >= Math_fround(0.0);
   $1118 = $1117 ? $1116 : Math_fround(-1.0);
   $1119 = Math_fround($1118 * $705);
   $1120 = Math_fround(HEAPF32[$709>>2]);
   $1121 = Math_fround($1120 * $1119);
   $1122 = Math_fround($441 * $1118);
   $1123 = Math_fround(HEAPF32[$710>>2]);
   $1124 = Math_fround($1123 * $1122);
   $1125 = Math_fround($1121 - $1124);
   HEAPF32[$711>>2] = $1125;
   $1126 = Math_fround(HEAPF32[$709>>2]);
   $1127 = Math_fround($439 * $1126);
   $1128 = Math_fround(HEAPF32[$710>>2]);
   $1129 = Math_fround($441 * $1128);
   $1130 = Math_fround($1127 + $1129);
   $1131 = $1130 != Math_fround(0.0);
   $1132 = $1131&1;
   HEAP8[$712>>0] = $1132;
   $1133 = Math_fround(HEAPF32[$713>>2]);
   $1134 = $1133 <= Math_fround(-0.0);
   $1135 = $1134 ? Math_fround(0.0) : Math_fround(1.0);
   $1136 = $1133 >= Math_fround(0.0);
   $1137 = $1136 ? $1135 : Math_fround(-1.0);
   $1138 = Math_fround($1137 * $705);
   $1139 = Math_fround(HEAPF32[$714>>2]);
   $1140 = Math_fround($1139 * $1138);
   $1141 = Math_fround($441 * $1137);
   $1142 = Math_fround(HEAPF32[$715>>2]);
   $1143 = Math_fround($1142 * $1141);
   $1144 = Math_fround($1140 - $1143);
   HEAPF32[$716>>2] = $1144;
   $1145 = Math_fround(HEAPF32[$714>>2]);
   $1146 = Math_fround($439 * $1145);
   $1147 = Math_fround(HEAPF32[$715>>2]);
   $1148 = Math_fround($441 * $1147);
   $1149 = Math_fround($1146 + $1148);
   $1150 = $1149 != Math_fround(0.0);
   $1151 = $1150&1;
   HEAP8[$717>>0] = $1151;
   $1152 = Math_fround(HEAPF32[$718>>2]);
   $1153 = $1152 <= Math_fround(-0.0);
   $1154 = $1153 ? Math_fround(0.0) : Math_fround(1.0);
   $1155 = $1152 >= Math_fround(0.0);
   $1156 = $1155 ? $1154 : Math_fround(-1.0);
   $1157 = Math_fround($1156 * $705);
   $1158 = Math_fround(HEAPF32[$719>>2]);
   $1159 = Math_fround($1158 * $1157);
   $1160 = Math_fround($441 * $1156);
   $1161 = Math_fround(HEAPF32[$720>>2]);
   $1162 = Math_fround($1161 * $1160);
   $1163 = Math_fround($1159 - $1162);
   HEAPF32[$721>>2] = $1163;
   $1164 = Math_fround(HEAPF32[$719>>2]);
   $1165 = Math_fround($439 * $1164);
   $1166 = Math_fround(HEAPF32[$720>>2]);
   $1167 = Math_fround($441 * $1166);
   $1168 = Math_fround($1165 + $1167);
   $1169 = $1168 != Math_fround(0.0);
   $1170 = $1169&1;
   HEAP8[$722>>0] = $1170;
   HEAP8[$inputData>>0] = $723;
   HEAP32[$725>>2] = $isAccelApplied;
   HEAP32[$726>>2] = $isBrakeApplied;
   HEAP32[$727>>2] = $steerAngles;
   HEAP32[$728>>2] = $activeWheelStates;
   $1171 = Math_fround(HEAPF32[$carChassisTransform>>2]);
   HEAPF32[$729>>2] = $1171;
   $1172 = Math_fround(HEAPF32[$349>>2]);
   HEAPF32[$730>>2] = $1172;
   $1173 = Math_fround(HEAPF32[$350>>2]);
   HEAPF32[$731>>2] = $1173;
   $1174 = Math_fround(HEAPF32[$351>>2]);
   HEAPF32[$732>>2] = $1174;
   $1175 = Math_fround(HEAPF32[$352>>2]);
   HEAPF32[$733>>2] = $1175;
   $1176 = Math_fround(HEAPF32[$353>>2]);
   HEAPF32[$734>>2] = $1176;
   $1177 = Math_fround(HEAPF32[$354>>2]);
   HEAPF32[$735>>2] = $1177;
   $1178 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
   HEAPF32[$736>>2] = $1178;
   $1179 = Math_fround(HEAPF32[$379>>2]);
   HEAPF32[$737>>2] = $1179;
   $1180 = Math_fround(HEAPF32[$382>>2]);
   HEAPF32[$738>>2] = $1180;
   $1181 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
   HEAPF32[$739>>2] = $1181;
   $1182 = Math_fround(HEAPF32[$389>>2]);
   HEAPF32[$740>>2] = $1182;
   $1183 = Math_fround(HEAPF32[$392>>2]);
   HEAPF32[$741>>2] = $1183;
   HEAP32[$742>>2] = $42;
   HEAP32[$743>>2] = $44;
   HEAP32[$744>>2] = $tires4ForceCalculators;
   HEAP32[$745>>2] = $4;
   HEAP32[$746>>2] = $747;
   _memset(($outputData|0),0,1112)|0;
   HEAP8[$748>>0] = 1;
   HEAP32[$749>>2] = -1;
   HEAP8[$750>>0] = 1;
   HEAP32[$751>>2] = -1;
   HEAP8[$752>>0] = 1;
   HEAP32[$753>>2] = -1;
   HEAP8[$754>>0] = 1;
   HEAP32[$755>>2] = -1;
   __ZN5physx21processSuspTireWheelsEjRKNS_29ProcessSuspWheelTireConstDataERKNS_29ProcessSuspWheelTireInputDataERNS_30ProcessSuspWheelTireOutputDataE(0,$constData,$inputData,$outputData);
   $1184 = HEAP32[$743>>2]|0;
   $1185 = (($1184) + 48|0);
   $1186 = Math_fround(HEAPF32[$756>>2]);
   $1187 = Math_fround(HEAPF32[$1185>>2]);
   $1188 = $1186 != $1187;
   $1189 = $1188 ? $1186 : Math_fround(0.0);
   HEAPF32[$1185>>2] = $1189;
   $1190 = Math_fround(HEAPF32[$757>>2]);
   $1191 = (($1184) + 52|0);
   $1192 = Math_fround(HEAPF32[$1191>>2]);
   $1193 = $1190 != $1192;
   $1194 = $1193 ? $1190 : Math_fround(0.0);
   HEAPF32[$1191>>2] = $1194;
   $1195 = Math_fround(HEAPF32[$758>>2]);
   $1196 = (($1184) + 56|0);
   $1197 = Math_fround(HEAPF32[$1196>>2]);
   $1198 = $1195 != $1197;
   $1199 = $1198 ? $1195 : Math_fround(0.0);
   HEAPF32[$1196>>2] = $1199;
   $1200 = Math_fround(HEAPF32[$759>>2]);
   $1201 = (($1184) + 60|0);
   $1202 = Math_fround(HEAPF32[$1201>>2]);
   $1203 = $1200 != $1202;
   $1204 = $1203 ? $1200 : Math_fround(0.0);
   HEAPF32[$1201>>2] = $1204;
   $1205 = (($1184) + 64|0);
   $1206 = Math_fround(HEAPF32[$760>>2]);
   $1207 = Math_fround(HEAPF32[$1205>>2]);
   $1208 = $1206 != $1207;
   $1209 = $1208 ? $1206 : Math_fround(0.0);
   HEAPF32[$1205>>2] = $1209;
   $1210 = Math_fround(HEAPF32[$761>>2]);
   $1211 = (($1184) + 68|0);
   $1212 = Math_fround(HEAPF32[$1211>>2]);
   $1213 = $1210 != $1212;
   $1214 = $1213 ? $1210 : Math_fround(0.0);
   HEAPF32[$1211>>2] = $1214;
   $1215 = Math_fround(HEAPF32[$762>>2]);
   $1216 = (($1184) + 72|0);
   $1217 = Math_fround(HEAPF32[$1216>>2]);
   $1218 = $1215 != $1217;
   $1219 = $1218 ? $1215 : Math_fround(0.0);
   HEAPF32[$1216>>2] = $1219;
   $1220 = Math_fround(HEAPF32[$763>>2]);
   $1221 = (($1184) + 76|0);
   $1222 = Math_fround(HEAPF32[$1221>>2]);
   $1223 = $1220 != $1222;
   $1224 = $1223 ? $1220 : Math_fround(0.0);
   HEAPF32[$1221>>2] = $1224;
   $1225 = ($764|0)==($k$0112|0);
   if ($1225) {
    $1226 = HEAP32[$768>>2]|0;
    $1227 = ($1226|0)==(0|0);
    if (!($1227)) {
     HEAP8[$822>>0] = 1;
    }
    $1228 = HEAP32[$765>>2]|0;
    $1229 = $1228&65535;
    HEAP16[$770>>1] = $1229;
    $1230 = Math_fround(HEAPF32[$773>>2]);
    HEAPF32[$769>>2] = $1230;
    $1231 = Math_fround(HEAPF32[$774>>2]);
    HEAPF32[$775>>2] = $1231;
    $1232 = Math_fround(HEAPF32[$776>>2]);
    HEAPF32[$777>>2] = $1232;
    $1233 = Math_fround(HEAPF32[$778>>2]);
    HEAPF32[$779>>2] = $1233;
    $1234 = Math_fround(HEAPF32[$766>>2]);
    HEAPF32[$771>>2] = $1234;
    $1235 = Math_fround(HEAPF32[$767>>2]);
    HEAPF32[$772>>2] = $1235;
    $1236 = HEAP32[$780>>2]|0;
    $1237 = $1236&65535;
    HEAP16[$781>>1] = $1237;
    $1238 = Math_fround(HEAPF32[$782>>2]);
    HEAPF32[$783>>2] = $1238;
    $1239 = Math_fround(HEAPF32[$784>>2]);
    HEAPF32[$785>>2] = $1239;
    $1240 = Math_fround(HEAPF32[$786>>2]);
    HEAPF32[$787>>2] = $1240;
    $1241 = Math_fround(HEAPF32[$788>>2]);
    HEAPF32[$789>>2] = $1241;
    $1242 = Math_fround(HEAPF32[$790>>2]);
    HEAPF32[$791>>2] = $1242;
    $1243 = Math_fround(HEAPF32[$792>>2]);
    HEAPF32[$793>>2] = $1243;
    $1244 = HEAP32[$794>>2]|0;
    $1245 = $1244&65535;
    HEAP16[$795>>1] = $1245;
    $1246 = Math_fround(HEAPF32[$796>>2]);
    HEAPF32[$797>>2] = $1246;
    $1247 = Math_fround(HEAPF32[$798>>2]);
    HEAPF32[$799>>2] = $1247;
    $1248 = Math_fround(HEAPF32[$800>>2]);
    HEAPF32[$801>>2] = $1248;
    $1249 = Math_fround(HEAPF32[$802>>2]);
    HEAPF32[$803>>2] = $1249;
    $1250 = Math_fround(HEAPF32[$804>>2]);
    HEAPF32[$805>>2] = $1250;
    $1251 = Math_fround(HEAPF32[$806>>2]);
    HEAPF32[$807>>2] = $1251;
    $1252 = HEAP32[$808>>2]|0;
    $1253 = $1252&65535;
    HEAP16[$809>>1] = $1253;
    $1254 = Math_fround(HEAPF32[$810>>2]);
    HEAPF32[$811>>2] = $1254;
    $1255 = Math_fround(HEAPF32[$812>>2]);
    HEAPF32[$813>>2] = $1255;
    $1256 = Math_fround(HEAPF32[$814>>2]);
    HEAPF32[$815>>2] = $1256;
    $1257 = Math_fround(HEAPF32[$816>>2]);
    HEAPF32[$817>>2] = $1257;
    $1258 = Math_fround(HEAPF32[$818>>2]);
    HEAPF32[$819>>2] = $1258;
    $1259 = Math_fround(HEAPF32[$820>>2]);
    HEAPF32[$821>>2] = $1259;
   }
   $1260 = Math_fround(HEAPF32[$823>>2]);
   $1261 = Math_fround(HEAPF32[$chassisForce>>2]);
   $1262 = Math_fround($1260 + $1261);
   HEAPF32[$chassisForce>>2] = $1262;
   $1263 = Math_fround(HEAPF32[$824>>2]);
   $1264 = Math_fround(HEAPF32[$701>>2]);
   $1265 = Math_fround($1263 + $1264);
   HEAPF32[$701>>2] = $1265;
   $1266 = Math_fround(HEAPF32[$825>>2]);
   $1267 = Math_fround(HEAPF32[$702>>2]);
   $1268 = Math_fround($1266 + $1267);
   HEAPF32[$702>>2] = $1268;
   $1269 = Math_fround(HEAPF32[$826>>2]);
   $1270 = Math_fround(HEAPF32[$chassisTorque>>2]);
   $1271 = Math_fround($1269 + $1270);
   HEAPF32[$chassisTorque>>2] = $1271;
   $1272 = Math_fround(HEAPF32[$827>>2]);
   $1273 = Math_fround(HEAPF32[$703>>2]);
   $1274 = Math_fround($1272 + $1273);
   HEAPF32[$703>>2] = $1274;
   $1275 = Math_fround(HEAPF32[$828>>2]);
   $1276 = Math_fround(HEAPF32[$704>>2]);
   $1277 = Math_fround($1275 + $1276);
   HEAPF32[$704>>2] = $1277;
   $1278 = HEAP32[$829>>2]|0;
   $1279 = Math_fround(HEAPF32[$830>>2]);
   $1280 = (($1278) + 4|0);
   HEAPF32[$1280>>2] = $1279;
   $1281 = Math_fround(HEAPF32[$831>>2]);
   $1282 = (($1278) + 8|0);
   HEAPF32[$1282>>2] = $1281;
   $1283 = Math_fround(HEAPF32[$832>>2]);
   $1284 = (($1278) + 12|0);
   HEAPF32[$1284>>2] = $1283;
   $1285 = Math_fround(HEAPF32[$833>>2]);
   $1286 = (($1278) + 16|0);
   HEAPF32[$1286>>2] = $1285;
   $1287 = Math_fround(HEAPF32[$834>>2]);
   $1288 = (($1278) + 20|0);
   HEAPF32[$1288>>2] = $1287;
   $1289 = Math_fround(HEAPF32[$835>>2]);
   $1290 = (($1278) + 24|0);
   HEAPF32[$1290>>2] = $1289;
   $1291 = Math_fround(HEAPF32[$836>>2]);
   $1292 = (($1278) + 28|0);
   HEAPF32[$1292>>2] = $1291;
   $1293 = Math_fround(HEAPF32[$837>>2]);
   $1294 = (($1278) + 32|0);
   HEAPF32[$1294>>2] = $1293;
   $1295 = Math_fround(HEAPF32[$838>>2]);
   $1296 = (($1278) + 36|0);
   HEAPF32[$1296>>2] = $1295;
   $1297 = Math_fround(HEAPF32[$839>>2]);
   $1298 = (($1278) + 40|0);
   HEAPF32[$1298>>2] = $1297;
   $1299 = Math_fround(HEAPF32[$840>>2]);
   $1300 = (($1278) + 44|0);
   HEAPF32[$1300>>2] = $1299;
   $1301 = Math_fround(HEAPF32[$841>>2]);
   $1302 = (($1278) + 48|0);
   HEAPF32[$1302>>2] = $1301;
   $1303 = Math_fround(HEAPF32[$842>>2]);
   $1304 = (($1278) + 52|0);
   HEAPF32[$1304>>2] = $1303;
   $1305 = Math_fround(HEAPF32[$843>>2]);
   $1306 = (($1278) + 56|0);
   HEAPF32[$1306>>2] = $1305;
   $1307 = Math_fround(HEAPF32[$844>>2]);
   $1308 = (($1278) + 60|0);
   HEAPF32[$1308>>2] = $1307;
   $1309 = Math_fround(HEAPF32[$845>>2]);
   $1310 = (($1278) + 64|0);
   HEAPF32[$1310>>2] = $1309;
   $1311 = Math_fround(HEAPF32[$846>>2]);
   $1312 = (($1278) + 68|0);
   HEAPF32[$1312>>2] = $1311;
   $1313 = Math_fround(HEAPF32[$847>>2]);
   $1314 = (($1278) + 72|0);
   HEAPF32[$1314>>2] = $1313;
   $1315 = Math_fround(HEAPF32[$848>>2]);
   $1316 = (($1278) + 76|0);
   HEAPF32[$1316>>2] = $1315;
   $1317 = Math_fround(HEAPF32[$849>>2]);
   $1318 = (($1278) + 80|0);
   HEAPF32[$1318>>2] = $1317;
   $1319 = Math_fround(HEAPF32[$850>>2]);
   $1320 = (($1278) + 84|0);
   HEAPF32[$1320>>2] = $1319;
   $1321 = Math_fround(HEAPF32[$851>>2]);
   $1322 = (($1278) + 88|0);
   HEAPF32[$1322>>2] = $1321;
   $1323 = Math_fround(HEAPF32[$852>>2]);
   $1324 = (($1278) + 92|0);
   HEAPF32[$1324>>2] = $1323;
   $1325 = Math_fround(HEAPF32[$853>>2]);
   $1326 = (($1278) + 96|0);
   HEAPF32[$1326>>2] = $1325;
   $1327 = (($1278) + 100|0);
   ;HEAP32[$1327+0>>2]=HEAP32[$854+0>>2]|0;HEAP32[$1327+4>>2]=HEAP32[$854+4>>2]|0;HEAP32[$1327+8>>2]=HEAP32[$854+8>>2]|0;HEAP32[$1327+12>>2]=HEAP32[$854+12>>2]|0;HEAP32[$1327+16>>2]=HEAP32[$854+16>>2]|0;
   $1328 = Math_fround(HEAPF32[$855>>2]);
   $1329 = (($1278) + 120|0);
   HEAPF32[$1329>>2] = $1328;
   $1330 = Math_fround(HEAPF32[$856>>2]);
   $1331 = (($1278) + 124|0);
   HEAPF32[$1331>>2] = $1330;
   $1332 = Math_fround(HEAPF32[$857>>2]);
   $1333 = (($1278) + 128|0);
   HEAPF32[$1333>>2] = $1332;
   $1334 = Math_fround(HEAPF32[$858>>2]);
   $1335 = (($1278) + 132|0);
   HEAPF32[$1335>>2] = $1334;
   $1336 = Math_fround(HEAPF32[$859>>2]);
   $1337 = (($1278) + 136|0);
   HEAPF32[$1337>>2] = $1336;
   $1338 = Math_fround(HEAPF32[$860>>2]);
   $1339 = (($1278) + 140|0);
   HEAPF32[$1339>>2] = $1338;
   $1340 = Math_fround(HEAPF32[$861>>2]);
   $1341 = (($1278) + 144|0);
   HEAPF32[$1341>>2] = $1340;
   $1342 = Math_fround(HEAPF32[$862>>2]);
   $1343 = (($1278) + 148|0);
   HEAPF32[$1343>>2] = $1342;
   $1344 = Math_fround(HEAPF32[$863>>2]);
   $1345 = (($1278) + 152|0);
   HEAPF32[$1345>>2] = $1344;
   $1346 = Math_fround(HEAPF32[$864>>2]);
   $1347 = (($1278) + 156|0);
   HEAPF32[$1347>>2] = $1346;
   $1348 = Math_fround(HEAPF32[$865>>2]);
   $1349 = (($1278) + 160|0);
   HEAPF32[$1349>>2] = $1348;
   $1350 = Math_fround(HEAPF32[$866>>2]);
   $1351 = (($1278) + 164|0);
   HEAPF32[$1351>>2] = $1350;
   $1352 = Math_fround(HEAPF32[$867>>2]);
   $1353 = (($1278) + 168|0);
   HEAPF32[$1353>>2] = $1352;
   $1354 = Math_fround(HEAPF32[$868>>2]);
   $1355 = (($1278) + 172|0);
   HEAPF32[$1355>>2] = $1354;
   $1356 = Math_fround(HEAPF32[$869>>2]);
   $1357 = (($1278) + 176|0);
   HEAPF32[$1357>>2] = $1356;
   $1358 = Math_fround(HEAPF32[$870>>2]);
   $1359 = (($1278) + 180|0);
   HEAPF32[$1359>>2] = $1358;
   $1360 = Math_fround(HEAPF32[$871>>2]);
   $1361 = (($1278) + 184|0);
   HEAPF32[$1361>>2] = $1360;
   $1362 = Math_fround(HEAPF32[$872>>2]);
   $1363 = (($1278) + 188|0);
   HEAPF32[$1363>>2] = $1362;
   $1364 = Math_fround(HEAPF32[$873>>2]);
   $1365 = (($1278) + 192|0);
   HEAPF32[$1365>>2] = $1364;
   $1366 = Math_fround(HEAPF32[$874>>2]);
   $1367 = (($1278) + 196|0);
   HEAPF32[$1367>>2] = $1366;
   $1368 = Math_fround(HEAPF32[$875>>2]);
   $1369 = (($1278) + 200|0);
   HEAPF32[$1369>>2] = $1368;
   $1370 = Math_fround(HEAPF32[$876>>2]);
   $1371 = (($1278) + 204|0);
   HEAPF32[$1371>>2] = $1370;
   $1372 = Math_fround(HEAPF32[$877>>2]);
   $1373 = (($1278) + 208|0);
   HEAPF32[$1373>>2] = $1372;
   $1374 = Math_fround(HEAPF32[$878>>2]);
   $1375 = (($1278) + 212|0);
   HEAPF32[$1375>>2] = $1374;
   $1376 = (($1278) + 216|0);
   ;HEAP32[$1376+0>>2]=HEAP32[$879+0>>2]|0;HEAP32[$1376+4>>2]=HEAP32[$879+4>>2]|0;HEAP32[$1376+8>>2]=HEAP32[$879+8>>2]|0;HEAP32[$1376+12>>2]=HEAP32[$879+12>>2]|0;HEAP32[$1376+16>>2]=HEAP32[$879+16>>2]|0;
   $1377 = Math_fround(HEAPF32[$880>>2]);
   $1378 = (($1278) + 236|0);
   HEAPF32[$1378>>2] = $1377;
   $1379 = Math_fround(HEAPF32[$881>>2]);
   $1380 = (($1278) + 240|0);
   HEAPF32[$1380>>2] = $1379;
   $1381 = Math_fround(HEAPF32[$882>>2]);
   $1382 = (($1278) + 244|0);
   HEAPF32[$1382>>2] = $1381;
   $1383 = Math_fround(HEAPF32[$883>>2]);
   $1384 = (($1278) + 248|0);
   HEAPF32[$1384>>2] = $1383;
   $1385 = Math_fround(HEAPF32[$884>>2]);
   $1386 = (($1278) + 252|0);
   HEAPF32[$1386>>2] = $1385;
   $1387 = Math_fround(HEAPF32[$885>>2]);
   $1388 = (($1278) + 256|0);
   HEAPF32[$1388>>2] = $1387;
   $1389 = Math_fround(HEAPF32[$886>>2]);
   $1390 = (($1278) + 260|0);
   HEAPF32[$1390>>2] = $1389;
   $1391 = Math_fround(HEAPF32[$887>>2]);
   $1392 = (($1278) + 264|0);
   HEAPF32[$1392>>2] = $1391;
   $1393 = Math_fround(HEAPF32[$888>>2]);
   $1394 = (($1278) + 268|0);
   HEAPF32[$1394>>2] = $1393;
   $1395 = Math_fround(HEAPF32[$889>>2]);
   $1396 = (($1278) + 272|0);
   HEAPF32[$1396>>2] = $1395;
   $1397 = Math_fround(HEAPF32[$890>>2]);
   $1398 = (($1278) + 276|0);
   HEAPF32[$1398>>2] = $1397;
   $1399 = Math_fround(HEAPF32[$891>>2]);
   $1400 = (($1278) + 280|0);
   HEAPF32[$1400>>2] = $1399;
   $1401 = Math_fround(HEAPF32[$892>>2]);
   $1402 = (($1278) + 284|0);
   HEAPF32[$1402>>2] = $1401;
   $1403 = Math_fround(HEAPF32[$893>>2]);
   $1404 = (($1278) + 288|0);
   HEAPF32[$1404>>2] = $1403;
   $1405 = Math_fround(HEAPF32[$894>>2]);
   $1406 = (($1278) + 292|0);
   HEAPF32[$1406>>2] = $1405;
   $1407 = Math_fround(HEAPF32[$895>>2]);
   $1408 = (($1278) + 296|0);
   HEAPF32[$1408>>2] = $1407;
   $1409 = Math_fround(HEAPF32[$896>>2]);
   $1410 = (($1278) + 300|0);
   HEAPF32[$1410>>2] = $1409;
   $1411 = Math_fround(HEAPF32[$897>>2]);
   $1412 = (($1278) + 304|0);
   HEAPF32[$1412>>2] = $1411;
   $1413 = Math_fround(HEAPF32[$898>>2]);
   $1414 = (($1278) + 308|0);
   HEAPF32[$1414>>2] = $1413;
   $1415 = Math_fround(HEAPF32[$899>>2]);
   $1416 = (($1278) + 312|0);
   HEAPF32[$1416>>2] = $1415;
   $1417 = Math_fround(HEAPF32[$900>>2]);
   $1418 = (($1278) + 316|0);
   HEAPF32[$1418>>2] = $1417;
   $1419 = Math_fround(HEAPF32[$901>>2]);
   $1420 = (($1278) + 320|0);
   HEAPF32[$1420>>2] = $1419;
   $1421 = Math_fround(HEAPF32[$902>>2]);
   $1422 = (($1278) + 324|0);
   HEAPF32[$1422>>2] = $1421;
   $1423 = Math_fround(HEAPF32[$903>>2]);
   $1424 = (($1278) + 328|0);
   HEAPF32[$1424>>2] = $1423;
   $1425 = (($1278) + 332|0);
   ;HEAP32[$1425+0>>2]=HEAP32[$904+0>>2]|0;HEAP32[$1425+4>>2]=HEAP32[$904+4>>2]|0;HEAP32[$1425+8>>2]=HEAP32[$904+8>>2]|0;HEAP32[$1425+12>>2]=HEAP32[$904+12>>2]|0;HEAP32[$1425+16>>2]=HEAP32[$904+16>>2]|0;
   $1426 = HEAP32[$727>>2]|0;
   __ZN5physx15PxVehicleUpdate25storeSuspWheelTireResultsERKNS_30ProcessSuspWheelTireOutputDataEPKfPNS_18PxWheelQueryResultEj($outputData,$1426,$wheelQueryResults,$905);
   $1427 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
   if (!($906)) {
    $i$01$i11 = 0;
    while(1) {
     $1428 = ((($outputData) + ($i$01$i11<<2)|0) + 1000|0);
     $1429 = HEAP32[$1428>>2]|0;
     $1430 = ((($1427) + (($i$01$i11*56)|0)|0) + 28|0);
     HEAP32[$1430>>2] = $1429;
     $1431 = ((($outputData) + (($i$01$i11*12)|0)|0) + 1016|0);
     $1432 = Math_fround(HEAPF32[$1431>>2]);
     $1433 = ((($1427) + (($i$01$i11*56)|0)|0) + 32|0);
     $1434 = Math_fround(HEAPF32[$1433>>2]);
     $1435 = Math_fround($1432 + $1434);
     HEAPF32[$1433>>2] = $1435;
     $1436 = ((($outputData) + (($i$01$i11*12)|0)|0) + 1020|0);
     $1437 = Math_fround(HEAPF32[$1436>>2]);
     $1438 = ((($1427) + (($i$01$i11*56)|0)|0) + 36|0);
     $1439 = Math_fround(HEAPF32[$1438>>2]);
     $1440 = Math_fround($1437 + $1439);
     HEAPF32[$1438>>2] = $1440;
     $1441 = ((($outputData) + (($i$01$i11*12)|0)|0) + 1024|0);
     $1442 = Math_fround(HEAPF32[$1441>>2]);
     $1443 = ((($1427) + (($i$01$i11*56)|0)|0) + 40|0);
     $1444 = Math_fround(HEAPF32[$1443>>2]);
     $1445 = Math_fround($1442 + $1444);
     HEAPF32[$1443>>2] = $1445;
     $1446 = ((($outputData) + (($i$01$i11*12)|0)|0) + 1064|0);
     $1447 = Math_fround(HEAPF32[$1446>>2]);
     $1448 = ((($1427) + (($i$01$i11*56)|0)|0) + 44|0);
     HEAPF32[$1448>>2] = $1447;
     $1449 = ((($outputData) + (($i$01$i11*12)|0)|0) + 1068|0);
     $1450 = Math_fround(HEAPF32[$1449>>2]);
     $1451 = ((($1427) + (($i$01$i11*56)|0)|0) + 48|0);
     HEAPF32[$1451>>2] = $1450;
     $1452 = ((($outputData) + (($i$01$i11*12)|0)|0) + 1072|0);
     $1453 = Math_fround(HEAPF32[$1452>>2]);
     $1454 = ((($1427) + (($i$01$i11*56)|0)|0) + 52|0);
     HEAPF32[$1454>>2] = $1453;
     $1455 = (($i$01$i11) + 1)|0;
     $exitcond$i12 = ($1455|0)==($905|0);
     if ($exitcond$i12) {
      break;
     } else {
      $i$01$i11 = $1455;
     }
    }
   }
   ;HEAP32[$diffTorqueRatios+0>>2]=0|0;HEAP32[$diffTorqueRatios+4>>2]=0|0;HEAP32[$diffTorqueRatios+8>>2]=0|0;HEAP32[$diffTorqueRatios+12>>2]=0|0;
   __ZN5physx23computeDiffTorqueRatiosERKNS_27PxVehicleDifferential4WDataEfPKfPf($59,$441,$44,$diffTorqueRatios);
   $1456 = Math_fround(HEAPF32[$38>>2]);
   $1457 = Math_fround(HEAPF32[$907>>2]);
   $1458 = Math_fround($autoboxCompensatedAnalogAccel$0 * $1457);
   $1459 = Math_fround(HEAPF32[$908>>2]);
   $1460 = Math_fround($1456 * $1459);
   $1461 = HEAP32[$54>>2]|0;
   do {
    if ((($1461|0) == 1)) {
     label = 89;
    } else if ((($1461|0) == 0)) {
     $$0$i$i = Math_fround(0.0);
    } else {
     $1462 = Math_fround(HEAPF32[$driveSimData>>2]);
     $1463 = $1462 > $1460;
     if ($1463) {
      label = 89;
      break;
     }
     $1465 = Math_fround(HEAPF32[$909>>2]);
     $i$07$i$i = 1;$x0$08$i$i = $1462;$y0$06$i$i = $1465;
     while(1) {
      $1468 = $i$07$i$i << 1;
      $1469 = (($driveSimData) + ($1468<<2)|0);
      $1470 = Math_fround(HEAPF32[$1469>>2]);
      $1471 = $1468 | 1;
      $1472 = (($driveSimData) + ($1471<<2)|0);
      $1473 = Math_fround(HEAPF32[$1472>>2]);
      $1474 = $x0$08$i$i <= $1460;
      $1475 = $1470 > $1460;
      $or$cond$i$i = $1474 & $1475;
      $1467 = (($i$07$i$i) + 1)|0;
      if ($or$cond$i$i) {
       label = 93;
       break;
      }
      $1466 = ($1467>>>0)<($1461>>>0);
      if ($1466) {
       $i$07$i$i = $1467;$x0$08$i$i = $1470;$y0$06$i$i = $1473;
      } else {
       label = 94;
       break;
      }
     }
     if ((label|0) == 93) {
      label = 0;
      $1476 = Math_fround($1473 - $y0$06$i$i);
      $1477 = Math_fround($1460 - $x0$08$i$i);
      $1478 = Math_fround($1477 * $1476);
      $1479 = Math_fround($1470 - $x0$08$i$i);
      $1480 = Math_fround($1478 / $1479);
      $1481 = Math_fround($y0$06$i$i + $1480);
      $$0$i$i = $1481;
      break;
     }
     else if ((label|0) == 94) {
      label = 0;
      $1482 = $1461 << 1;
      $1483 = (($1482) + -2)|0;
      $1484 = $1483 | 1;
      $1485 = (($driveSimData) + ($1484<<2)|0);
      $1486 = Math_fround(HEAPF32[$1485>>2]);
      $$0$i$i = $1486;
      break;
     }
    }
   } while(0);
   if ((label|0) == 89) {
    label = 0;
    $1464 = Math_fround(HEAPF32[$909>>2]);
    $$0$i$i = $1464;
   }
   $1487 = Math_fround($1458 * $$0$i$i);
   $1488 = (0|0)==(0|0);
   if (!($1488)) {
    $1489 = (0 + 4|0);
    HEAPF32[$1489>>2] = $1487;
   }
   $1490 = Math_fround(HEAPF32[$910>>2]);
   $$val = Math_fround(HEAPF32[$912>>2]);
   $$val37 = Math_fround(HEAPF32[$911>>2]);
   $1491 = $424 ? $$val : $$val37;
   $1492 = Math_fround($1490 - $1491);
   $1493 = Math_fround($autoboxCompensatedAnalogAccel$0 * $1492);
   $1494 = Math_fround($1491 + $1493);
   HEAPF32[$implicitSolverInput>>2] = $681;
   HEAPF32[$913>>2] = $439;
   HEAPF32[$914>>2] = $441;
   HEAPF32[$915>>2] = $933;
   HEAPF32[$916>>2] = $435;
   HEAP32[$917>>2] = $428;
   HEAP32[$918>>2] = $430;
   HEAPF32[$919>>2] = $1487;
   HEAPF32[$920>>2] = $1494;
   HEAP32[$921>>2] = $diffTorqueRatios;
   HEAP32[$922>>2] = $aveWheelSpeedContributions;
   HEAP32[$923>>2] = $brakeTorques;
   HEAP32[$924>>2] = $isBrakeApplied;
   HEAP32[$925>>2] = $926;
   HEAP32[$927>>2] = 1;
   HEAP32[$928>>2] = 4;
   HEAP32[$929>>2] = $42;
   HEAP32[$930>>2] = $driveSimData;
   HEAP32[$implicitSolverOutput>>2] = $44;
   HEAP32[$931>>2] = $37;
   __ZN5physx49solveDrive4WInternaDynamicsEnginePlusDrivenWheelsERKNS_19ImplicitSolverInputEPNS_20ImplicitSolverOutputE($implicitSolverInput,$implicitSolverOutput);
   $j$02$i6 = 0;
   while(1) {
    $1495 = (($44) + ($j$02$i6<<2)|0);
    $1496 = Math_fround(HEAPF32[$1495>>2]);
    $1497 = ((($outputData) + ($j$02$i6<<2)|0) + 292|0);
    $1498 = Math_fround(HEAPF32[$1497>>2]);
    $1499 = ((($42) + (($j$02$i6*48)|0)|0) + 12|0);
    $1500 = Math_fround(HEAPF32[$1499>>2]);
    $1501 = Math_fround(-$1500);
    $1502 = $1498 > $1501;
    do {
     if ($1502) {
      $1503 = (($isBrakeApplied) + ($j$02$i6)|0);
      $1504 = HEAP8[$1503>>0]|0;
      $1505 = ($1504<<24>>24)==(0);
      if (!($1505)) {
       $wheelOmega$0$i8 = $1496;
       break;
      }
      $1506 = (($diffTorqueRatios) + ($j$02$i6<<2)|0);
      $1507 = Math_fround(HEAPF32[$1506>>2]);
      $1508 = Math_fround($932 * $1507);
      $1509 = Math_fround($1487 * $1508);
      $1510 = $1509 == Math_fround(0.0);
      if (!($1510)) {
       $wheelOmega$0$i8 = $1496;
       break;
      }
      $1511 = ((($outputData) + ($j$02$i6<<2)|0) + 452|0);
      $1512 = Math_fround(HEAPF32[$1511>>2]);
      $fabsf$i$i1$i7 = (Math_fround(Math_abs((Math_fround($1512)))));
      $1513 = Math_fround(HEAPF32[523912>>2]);
      $1514 = $fabsf$i$i1$i7 < $1513;
      if (!($1514)) {
       $wheelOmega$0$i8 = $1496;
       break;
      }
      $1515 = ((($42) + (($j$02$i6*48)|0)|0) + 228|0);
      $1516 = Math_fround(HEAPF32[$1515>>2]);
      $1517 = Math_fround(HEAPF32[523920>>2]);
      $1518 = Math_fround($fabsf$i$i1$i7 * $1517);
      $1519 = Math_fround($1512 * $1516);
      $1520 = Math_fround(Math_fround(1.0) - $1518);
      $1521 = Math_fround($1519 * $1520);
      $1522 = Math_fround($1496 * $1518);
      $1523 = Math_fround($1522 + $1521);
      $wheelOmega$0$i8 = $1523;
     } else {
      $wheelOmega$0$i8 = $1496;
     }
    } while(0);
    $1524 = ((($44) + ($j$02$i6<<2)|0) + 32|0);
    $1525 = Math_fround(HEAPF32[$1524>>2]);
    $1526 = Math_fround($681 * $wheelOmega$0$i8);
    $1527 = Math_fround($1525 + $1526);
    $1528 = Math_fround($1527 + Math_fround(-31.415927886962890625));
    $1529 = Math_fround(Math_fround(-31.415927886962890625) - $1527);
    $1530 = Math_fround($1527 + Math_fround(31.415927886962890625));
    $1531 = $1529 >= Math_fround(0.0);
    $1532 = $1531 ? $1530 : $1527;
    $1533 = $1528 >= Math_fround(0.0);
    $1534 = $1533 ? $1528 : $1532;
    HEAPF32[$1524>>2] = $1534;
    $1535 = ((($44) + ($j$02$i6<<2)|0) + 16|0);
    HEAPF32[$1535>>2] = $wheelOmega$0$i8;
    $1536 = (($j$02$i6) + 1)|0;
    $exitcond$i9 = ($1536|0)==(4);
    if ($exitcond$i9) {
     break;
    } else {
     $j$02$i6 = $1536;
    }
   }
   if ($934) {
    $1537 = Math_fround(HEAPF32[$carChassisTransform>>2]);
    $1538 = Math_fround(HEAPF32[$349>>2]);
    $1539 = Math_fround(HEAPF32[$350>>2]);
    $1540 = Math_fround(HEAPF32[$351>>2]);
    $1541 = Math_fround(HEAPF32[$352>>2]);
    $1542 = Math_fround(HEAPF32[$353>>2]);
    $1543 = Math_fround(HEAPF32[$354>>2]);
    $1544 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
    $1545 = Math_fround(HEAPF32[$379>>2]);
    $1546 = Math_fround(HEAPF32[$382>>2]);
    $1547 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
    $1548 = Math_fround(HEAPF32[$389>>2]);
    $1549 = Math_fround(HEAPF32[$392>>2]);
    $$promoted = Math_fround(HEAPF32[$chassisForce>>2]);
    $$promoted101 = Math_fround(HEAPF32[$701>>2]);
    $$promoted102 = Math_fround(HEAPF32[$702>>2]);
    $$promoted103 = Math_fround(HEAPF32[$chassisTorque>>2]);
    $$promoted104 = Math_fround(HEAPF32[$703>>2]);
    $$promoted105 = Math_fround(HEAPF32[$704>>2]);
    $1770 = $$promoted;$1773 = $$promoted101;$1776 = $$promoted102;$1779 = $$promoted103;$1782 = $$promoted104;$1785 = $$promoted105;$j$098 = 1;
    while(1) {
     $1550 = (($42) + (($j$098*944)|0)|0);
     $1551 = ((($42) + (($j$098*944)|0)|0) + 224|0);
     $1552 = Math_fround(HEAPF32[$1551>>2]);
     $1553 = ((($42) + (($j$098*944)|0)|0) + 272|0);
     $1554 = Math_fround(HEAPF32[$1553>>2]);
     $1555 = ((($42) + (($j$098*944)|0)|0) + 320|0);
     $1556 = Math_fround(HEAPF32[$1555>>2]);
     $1557 = ((($42) + (($j$098*944)|0)|0) + 368|0);
     $1558 = Math_fround(HEAPF32[$1557>>2]);
     HEAPF32[$extraWheelSteerAngles>>2] = $1552;
     HEAPF32[$935>>2] = $1554;
     HEAPF32[$936>>2] = $1556;
     HEAPF32[$937>>2] = $1558;
     ;HEAP32[$extraWheelsDiffTorqueRatios+0>>2]=0|0;HEAP32[$extraWheelsDiffTorqueRatios+4>>2]=0|0;HEAP32[$extraWheelsDiffTorqueRatios+8>>2]=0|0;HEAP32[$extraWheelsDiffTorqueRatios+12>>2]=0|0;
     HEAP32[$extraIsAccelApplied>>2] = 0;
     ;HEAP32[$extraWheelBrakeTorques+0>>2]=0|0;HEAP32[$extraWheelBrakeTorques+4>>2]=0|0;HEAP32[$extraWheelBrakeTorques+8>>2]=0|0;
     HEAP32[$extraIsBrakeApplied>>2] = 0;
     $1559 = (($44) + (($j$098*208)|0)|0);
     $1560 = Math_fround(HEAPF32[$1559>>2]);
     $1561 = $1560 <= Math_fround(-0.0);
     $1562 = $1561 ? Math_fround(0.0) : Math_fround(1.0);
     $1563 = $1560 >= Math_fround(0.0);
     $1564 = $1563 ? $1562 : Math_fround(-1.0);
     $1565 = Math_fround($1564 * $705);
     $1566 = ((($42) + (($j$098*944)|0)|0) + 212|0);
     $1567 = Math_fround(HEAPF32[$1566>>2]);
     $1568 = Math_fround($1567 * $1565);
     $1569 = Math_fround($441 * $1564);
     $1570 = ((($42) + (($j$098*944)|0)|0) + 216|0);
     $1571 = Math_fround(HEAPF32[$1570>>2]);
     $1572 = Math_fround($1571 * $1569);
     $1573 = Math_fround($1568 - $1572);
     HEAPF32[$extraWheelBrakeTorques>>2] = $1573;
     $1574 = Math_fround($439 * $1567);
     $1575 = Math_fround($441 * $1571);
     $1576 = Math_fround($1574 + $1575);
     $1577 = $1576 != Math_fround(0.0);
     $1578 = $1577&1;
     HEAP8[$extraIsBrakeApplied>>0] = $1578;
     $1579 = ((($44) + (($j$098*208)|0)|0) + 4|0);
     $1580 = Math_fround(HEAPF32[$1579>>2]);
     $1581 = $1580 <= Math_fround(-0.0);
     $1582 = $1581 ? Math_fround(0.0) : Math_fround(1.0);
     $1583 = $1580 >= Math_fround(0.0);
     $1584 = $1583 ? $1582 : Math_fround(-1.0);
     $1585 = Math_fround($1584 * $705);
     $1586 = ((($42) + (($j$098*944)|0)|0) + 260|0);
     $1587 = Math_fround(HEAPF32[$1586>>2]);
     $1588 = Math_fround($1587 * $1585);
     $1589 = Math_fround($441 * $1584);
     $1590 = ((($42) + (($j$098*944)|0)|0) + 264|0);
     $1591 = Math_fround(HEAPF32[$1590>>2]);
     $1592 = Math_fround($1591 * $1589);
     $1593 = Math_fround($1588 - $1592);
     HEAPF32[$938>>2] = $1593;
     $1594 = Math_fround($439 * $1587);
     $1595 = Math_fround($441 * $1591);
     $1596 = Math_fround($1594 + $1595);
     $1597 = $1596 != Math_fround(0.0);
     $1598 = $1597&1;
     HEAP8[$939>>0] = $1598;
     $1599 = ((($44) + (($j$098*208)|0)|0) + 8|0);
     $1600 = Math_fround(HEAPF32[$1599>>2]);
     $1601 = $1600 <= Math_fround(-0.0);
     $1602 = $1601 ? Math_fround(0.0) : Math_fround(1.0);
     $1603 = $1600 >= Math_fround(0.0);
     $1604 = $1603 ? $1602 : Math_fround(-1.0);
     $1605 = Math_fround($1604 * $705);
     $1606 = ((($42) + (($j$098*944)|0)|0) + 308|0);
     $1607 = Math_fround(HEAPF32[$1606>>2]);
     $1608 = Math_fround($1607 * $1605);
     $1609 = Math_fround($441 * $1604);
     $1610 = ((($42) + (($j$098*944)|0)|0) + 312|0);
     $1611 = Math_fround(HEAPF32[$1610>>2]);
     $1612 = Math_fround($1611 * $1609);
     $1613 = Math_fround($1608 - $1612);
     HEAPF32[$940>>2] = $1613;
     $1614 = Math_fround($439 * $1607);
     $1615 = Math_fround($441 * $1611);
     $1616 = Math_fround($1614 + $1615);
     $1617 = $1616 != Math_fround(0.0);
     $1618 = $1617&1;
     HEAP8[$941>>0] = $1618;
     $1619 = ((($44) + (($j$098*208)|0)|0) + 12|0);
     $1620 = Math_fround(HEAPF32[$1619>>2]);
     $1621 = $1620 <= Math_fround(-0.0);
     $1622 = $1621 ? Math_fround(0.0) : Math_fround(1.0);
     $1623 = $1620 >= Math_fround(0.0);
     $1624 = $1623 ? $1622 : Math_fround(-1.0);
     $1625 = Math_fround($1624 * $705);
     $1626 = ((($42) + (($j$098*944)|0)|0) + 356|0);
     $1627 = Math_fround(HEAPF32[$1626>>2]);
     $1628 = Math_fround($1627 * $1625);
     $1629 = Math_fround($441 * $1624);
     $1630 = ((($42) + (($j$098*944)|0)|0) + 360|0);
     $1631 = Math_fround(HEAPF32[$1630>>2]);
     $1632 = Math_fround($1631 * $1629);
     $1633 = Math_fround($1628 - $1632);
     HEAPF32[$942>>2] = $1633;
     $1634 = Math_fround($439 * $1627);
     $1635 = Math_fround($441 * $1631);
     $1636 = Math_fround($1634 + $1635);
     $1637 = $1636 != Math_fround(0.0);
     $1638 = $1637&1;
     HEAP8[$943>>0] = $1638;
     HEAP32[$extraWheelActiveStates>>2] = 0;
     $1639 = $j$098 << 2;
     $1640 = $j$098 >>> 3;
     $1641 = $1640 & 134217727;
     $1642 = ((($vehDrive4W) + ($1641<<2)|0) + 52|0);
     $1643 = HEAP32[$1642>>2]|0;
     $1644 = $1639 & 28;
     $1645 = 1 << $1644;
     $1646 = $1643 & $1645;
     $1647 = ($1646|0)==(0);
     if (!($1647)) {
      HEAP8[$extraWheelActiveStates>>0] = 1;
     }
     $1648 = $1644 | 1;
     $1649 = 1 << $1648;
     $1650 = $1643 & $1649;
     $1651 = ($1650|0)==(0);
     if (!($1651)) {
      HEAP8[$1094>>0] = 1;
     }
     $1652 = $1644 | 2;
     $1653 = 1 << $1652;
     $1654 = $1643 & $1653;
     $1655 = ($1654|0)==(0);
     if (!($1655)) {
      HEAP8[$1093>>0] = 1;
     }
     $1656 = $1644 | 3;
     $1657 = 1 << $1656;
     $1658 = $1643 & $1657;
     $1659 = ($1658|0)==(0);
     if (!($1659)) {
      HEAP8[$1092>>0] = 1;
     }
     HEAP8[$extraInputData>>0] = $723;
     HEAP32[$944>>2] = $extraIsAccelApplied;
     HEAP32[$945>>2] = $extraIsBrakeApplied;
     HEAP32[$946>>2] = $extraWheelSteerAngles;
     HEAP32[$947>>2] = $extraWheelActiveStates;
     HEAPF32[$948>>2] = $1537;
     HEAPF32[$949>>2] = $1538;
     HEAPF32[$950>>2] = $1539;
     HEAPF32[$951>>2] = $1540;
     HEAPF32[$952>>2] = $1541;
     HEAPF32[$953>>2] = $1542;
     HEAPF32[$954>>2] = $1543;
     HEAPF32[$955>>2] = $1544;
     HEAPF32[$956>>2] = $1545;
     HEAPF32[$957>>2] = $1546;
     HEAPF32[$958>>2] = $1547;
     HEAPF32[$959>>2] = $1548;
     HEAPF32[$960>>2] = $1549;
     HEAP32[$961>>2] = $1550;
     HEAP32[$962>>2] = $1559;
     $1660 = (($tires4ForceCalculators) + (($j$098*20)|0)|0);
     HEAP32[$963>>2] = $1660;
     HEAP32[$964>>2] = $4;
     $1661 = (($numActiveWheelsPerBlock4) + ($j$098<<2)|0);
     $1662 = HEAP32[$1661>>2]|0;
     HEAP32[$965>>2] = $1662;
     _memset(($extraOutputData|0),0,1112)|0;
     HEAP8[$966>>0] = 1;
     HEAP32[$967>>2] = -1;
     HEAP8[$968>>0] = 1;
     HEAP32[$969>>2] = -1;
     HEAP8[$970>>0] = 1;
     HEAP32[$971>>2] = -1;
     HEAP8[$972>>0] = 1;
     HEAP32[$973>>2] = -1;
     __ZN5physx21processSuspTireWheelsEjRKNS_29ProcessSuspWheelTireConstDataERKNS_29ProcessSuspWheelTireInputDataERNS_30ProcessSuspWheelTireOutputDataE($1639,$constData,$extraInputData,$extraOutputData);
     $1663 = HEAP32[$962>>2]|0;
     $1664 = (($1663) + 48|0);
     $1665 = Math_fround(HEAPF32[$974>>2]);
     $1666 = Math_fround(HEAPF32[$1664>>2]);
     $1667 = $1665 != $1666;
     $1668 = $1667 ? $1665 : Math_fround(0.0);
     HEAPF32[$1664>>2] = $1668;
     $1669 = Math_fround(HEAPF32[$975>>2]);
     $1670 = (($1663) + 52|0);
     $1671 = Math_fround(HEAPF32[$1670>>2]);
     $1672 = $1669 != $1671;
     $1673 = $1672 ? $1669 : Math_fround(0.0);
     HEAPF32[$1670>>2] = $1673;
     $1674 = Math_fround(HEAPF32[$976>>2]);
     $1675 = (($1663) + 56|0);
     $1676 = Math_fround(HEAPF32[$1675>>2]);
     $1677 = $1674 != $1676;
     $1678 = $1677 ? $1674 : Math_fround(0.0);
     HEAPF32[$1675>>2] = $1678;
     $1679 = Math_fround(HEAPF32[$977>>2]);
     $1680 = (($1663) + 60|0);
     $1681 = Math_fround(HEAPF32[$1680>>2]);
     $1682 = $1679 != $1681;
     $1683 = $1682 ? $1679 : Math_fround(0.0);
     HEAPF32[$1680>>2] = $1683;
     $1684 = (($1663) + 64|0);
     $1685 = Math_fround(HEAPF32[$978>>2]);
     $1686 = Math_fround(HEAPF32[$1684>>2]);
     $1687 = $1685 != $1686;
     $1688 = $1687 ? $1685 : Math_fround(0.0);
     HEAPF32[$1684>>2] = $1688;
     $1689 = Math_fround(HEAPF32[$979>>2]);
     $1690 = (($1663) + 68|0);
     $1691 = Math_fround(HEAPF32[$1690>>2]);
     $1692 = $1689 != $1691;
     $1693 = $1692 ? $1689 : Math_fround(0.0);
     HEAPF32[$1690>>2] = $1693;
     $1694 = Math_fround(HEAPF32[$980>>2]);
     $1695 = (($1663) + 72|0);
     $1696 = Math_fround(HEAPF32[$1695>>2]);
     $1697 = $1694 != $1696;
     $1698 = $1697 ? $1694 : Math_fround(0.0);
     HEAPF32[$1695>>2] = $1698;
     $1699 = Math_fround(HEAPF32[$981>>2]);
     $1700 = (($1663) + 76|0);
     $1701 = Math_fround(HEAPF32[$1700>>2]);
     $1702 = $1699 != $1701;
     $1703 = $1702 ? $1699 : Math_fround(0.0);
     HEAPF32[$1700>>2] = $1703;
     if ($1225) {
      $1704 = ((($44) + (($j$098*208)|0)|0) + 196|0);
      $1705 = HEAP32[$1704>>2]|0;
      $1706 = ($1705|0)==(0|0);
      if (!($1706)) {
       $1707 = ((($44) + (($j$098*208)|0)|0) + 200|0);
       HEAP8[$1707>>0] = 1;
      }
      $1708 = ((($44) + (($j$098*208)|0)|0) + 80|0);
      $1709 = ((($44) + (($j$098*208)|0)|0) + 176|0);
      $1710 = ((($44) + (($j$098*208)|0)|0) + 160|0);
      $1711 = ((($44) + (($j$098*208)|0)|0) + 144|0);
      $1712 = HEAP32[$982>>2]|0;
      $1713 = $1712&65535;
      HEAP16[$1709>>1] = $1713;
      $1714 = Math_fround(HEAPF32[$985>>2]);
      HEAPF32[$1708>>2] = $1714;
      $1715 = Math_fround(HEAPF32[$986>>2]);
      $1716 = ((($44) + (($j$098*208)|0)|0) + 84|0);
      HEAPF32[$1716>>2] = $1715;
      $1717 = Math_fround(HEAPF32[$987>>2]);
      $1718 = ((($44) + (($j$098*208)|0)|0) + 88|0);
      HEAPF32[$1718>>2] = $1717;
      $1719 = Math_fround(HEAPF32[$988>>2]);
      $1720 = ((($44) + (($j$098*208)|0)|0) + 92|0);
      HEAPF32[$1720>>2] = $1719;
      $1721 = Math_fround(HEAPF32[$983>>2]);
      HEAPF32[$1710>>2] = $1721;
      $1722 = Math_fround(HEAPF32[$984>>2]);
      HEAPF32[$1711>>2] = $1722;
      $1723 = HEAP32[$989>>2]|0;
      $1724 = $1723&65535;
      $1725 = ((($44) + (($j$098*208)|0)|0) + 178|0);
      HEAP16[$1725>>1] = $1724;
      $1726 = Math_fround(HEAPF32[$990>>2]);
      $1727 = ((($44) + (($j$098*208)|0)|0) + 96|0);
      HEAPF32[$1727>>2] = $1726;
      $1728 = Math_fround(HEAPF32[$991>>2]);
      $1729 = ((($44) + (($j$098*208)|0)|0) + 100|0);
      HEAPF32[$1729>>2] = $1728;
      $1730 = Math_fround(HEAPF32[$992>>2]);
      $1731 = ((($44) + (($j$098*208)|0)|0) + 104|0);
      HEAPF32[$1731>>2] = $1730;
      $1732 = Math_fround(HEAPF32[$993>>2]);
      $1733 = ((($44) + (($j$098*208)|0)|0) + 108|0);
      HEAPF32[$1733>>2] = $1732;
      $1734 = Math_fround(HEAPF32[$994>>2]);
      $1735 = ((($44) + (($j$098*208)|0)|0) + 164|0);
      HEAPF32[$1735>>2] = $1734;
      $1736 = Math_fround(HEAPF32[$995>>2]);
      $1737 = ((($44) + (($j$098*208)|0)|0) + 148|0);
      HEAPF32[$1737>>2] = $1736;
      $1738 = HEAP32[$996>>2]|0;
      $1739 = $1738&65535;
      $1740 = ((($44) + (($j$098*208)|0)|0) + 180|0);
      HEAP16[$1740>>1] = $1739;
      $1741 = Math_fround(HEAPF32[$997>>2]);
      $1742 = ((($44) + (($j$098*208)|0)|0) + 112|0);
      HEAPF32[$1742>>2] = $1741;
      $1743 = Math_fround(HEAPF32[$998>>2]);
      $1744 = ((($44) + (($j$098*208)|0)|0) + 116|0);
      HEAPF32[$1744>>2] = $1743;
      $1745 = Math_fround(HEAPF32[$999>>2]);
      $1746 = ((($44) + (($j$098*208)|0)|0) + 120|0);
      HEAPF32[$1746>>2] = $1745;
      $1747 = Math_fround(HEAPF32[$1000>>2]);
      $1748 = ((($44) + (($j$098*208)|0)|0) + 124|0);
      HEAPF32[$1748>>2] = $1747;
      $1749 = Math_fround(HEAPF32[$1001>>2]);
      $1750 = ((($44) + (($j$098*208)|0)|0) + 168|0);
      HEAPF32[$1750>>2] = $1749;
      $1751 = Math_fround(HEAPF32[$1002>>2]);
      $1752 = ((($44) + (($j$098*208)|0)|0) + 152|0);
      HEAPF32[$1752>>2] = $1751;
      $1753 = HEAP32[$1003>>2]|0;
      $1754 = $1753&65535;
      $1755 = ((($44) + (($j$098*208)|0)|0) + 182|0);
      HEAP16[$1755>>1] = $1754;
      $1756 = Math_fround(HEAPF32[$1004>>2]);
      $1757 = ((($44) + (($j$098*208)|0)|0) + 128|0);
      HEAPF32[$1757>>2] = $1756;
      $1758 = Math_fround(HEAPF32[$1005>>2]);
      $1759 = ((($44) + (($j$098*208)|0)|0) + 132|0);
      HEAPF32[$1759>>2] = $1758;
      $1760 = Math_fround(HEAPF32[$1006>>2]);
      $1761 = ((($44) + (($j$098*208)|0)|0) + 136|0);
      HEAPF32[$1761>>2] = $1760;
      $1762 = Math_fround(HEAPF32[$1007>>2]);
      $1763 = ((($44) + (($j$098*208)|0)|0) + 140|0);
      HEAPF32[$1763>>2] = $1762;
      $1764 = Math_fround(HEAPF32[$1008>>2]);
      $1765 = ((($44) + (($j$098*208)|0)|0) + 172|0);
      HEAPF32[$1765>>2] = $1764;
      $1766 = Math_fround(HEAPF32[$1009>>2]);
      $1767 = ((($44) + (($j$098*208)|0)|0) + 156|0);
      HEAPF32[$1767>>2] = $1766;
     }
     $1768 = Math_fround(HEAPF32[$1010>>2]);
     $1769 = Math_fround($1768 + $1770);
     $1771 = Math_fround(HEAPF32[$1011>>2]);
     $1772 = Math_fround($1771 + $1773);
     $1774 = Math_fround(HEAPF32[$1012>>2]);
     $1775 = Math_fround($1774 + $1776);
     $1777 = Math_fround(HEAPF32[$1013>>2]);
     $1778 = Math_fround($1777 + $1779);
     $1780 = Math_fround(HEAPF32[$1014>>2]);
     $1781 = Math_fround($1780 + $1782);
     $1783 = Math_fround(HEAPF32[$1015>>2]);
     $1784 = Math_fround($1783 + $1785);
     $1786 = ((($44) + (($j$098*208)|0)|0) + 192|0);
     $1787 = HEAP32[$1786>>2]|0;
     $1788 = Math_fround(HEAPF32[$1016>>2]);
     $1789 = (($1787) + 4|0);
     HEAPF32[$1789>>2] = $1788;
     $1790 = Math_fround(HEAPF32[$1017>>2]);
     $1791 = (($1787) + 8|0);
     HEAPF32[$1791>>2] = $1790;
     $1792 = Math_fround(HEAPF32[$1018>>2]);
     $1793 = (($1787) + 12|0);
     HEAPF32[$1793>>2] = $1792;
     $1794 = Math_fround(HEAPF32[$1019>>2]);
     $1795 = (($1787) + 16|0);
     HEAPF32[$1795>>2] = $1794;
     $1796 = Math_fround(HEAPF32[$1020>>2]);
     $1797 = (($1787) + 20|0);
     HEAPF32[$1797>>2] = $1796;
     $1798 = Math_fround(HEAPF32[$1021>>2]);
     $1799 = (($1787) + 24|0);
     HEAPF32[$1799>>2] = $1798;
     $1800 = Math_fround(HEAPF32[$1022>>2]);
     $1801 = (($1787) + 28|0);
     HEAPF32[$1801>>2] = $1800;
     $1802 = Math_fround(HEAPF32[$1023>>2]);
     $1803 = (($1787) + 32|0);
     HEAPF32[$1803>>2] = $1802;
     $1804 = Math_fround(HEAPF32[$1024>>2]);
     $1805 = (($1787) + 36|0);
     HEAPF32[$1805>>2] = $1804;
     $1806 = Math_fround(HEAPF32[$1025>>2]);
     $1807 = (($1787) + 40|0);
     HEAPF32[$1807>>2] = $1806;
     $1808 = Math_fround(HEAPF32[$1026>>2]);
     $1809 = (($1787) + 44|0);
     HEAPF32[$1809>>2] = $1808;
     $1810 = Math_fround(HEAPF32[$1027>>2]);
     $1811 = (($1787) + 48|0);
     HEAPF32[$1811>>2] = $1810;
     $1812 = Math_fround(HEAPF32[$1028>>2]);
     $1813 = (($1787) + 52|0);
     HEAPF32[$1813>>2] = $1812;
     $1814 = Math_fround(HEAPF32[$1029>>2]);
     $1815 = (($1787) + 56|0);
     HEAPF32[$1815>>2] = $1814;
     $1816 = Math_fround(HEAPF32[$1030>>2]);
     $1817 = (($1787) + 60|0);
     HEAPF32[$1817>>2] = $1816;
     $1818 = Math_fround(HEAPF32[$1031>>2]);
     $1819 = (($1787) + 64|0);
     HEAPF32[$1819>>2] = $1818;
     $1820 = Math_fround(HEAPF32[$1032>>2]);
     $1821 = (($1787) + 68|0);
     HEAPF32[$1821>>2] = $1820;
     $1822 = Math_fround(HEAPF32[$1033>>2]);
     $1823 = (($1787) + 72|0);
     HEAPF32[$1823>>2] = $1822;
     $1824 = Math_fround(HEAPF32[$1034>>2]);
     $1825 = (($1787) + 76|0);
     HEAPF32[$1825>>2] = $1824;
     $1826 = Math_fround(HEAPF32[$1035>>2]);
     $1827 = (($1787) + 80|0);
     HEAPF32[$1827>>2] = $1826;
     $1828 = Math_fround(HEAPF32[$1036>>2]);
     $1829 = (($1787) + 84|0);
     HEAPF32[$1829>>2] = $1828;
     $1830 = Math_fround(HEAPF32[$1037>>2]);
     $1831 = (($1787) + 88|0);
     HEAPF32[$1831>>2] = $1830;
     $1832 = Math_fround(HEAPF32[$1038>>2]);
     $1833 = (($1787) + 92|0);
     HEAPF32[$1833>>2] = $1832;
     $1834 = Math_fround(HEAPF32[$1039>>2]);
     $1835 = (($1787) + 96|0);
     HEAPF32[$1835>>2] = $1834;
     $1836 = (($1787) + 100|0);
     ;HEAP32[$1836+0>>2]=HEAP32[$1040+0>>2]|0;HEAP32[$1836+4>>2]=HEAP32[$1040+4>>2]|0;HEAP32[$1836+8>>2]=HEAP32[$1040+8>>2]|0;HEAP32[$1836+12>>2]=HEAP32[$1040+12>>2]|0;HEAP32[$1836+16>>2]=HEAP32[$1040+16>>2]|0;
     $1837 = Math_fround(HEAPF32[$1041>>2]);
     $1838 = (($1787) + 120|0);
     HEAPF32[$1838>>2] = $1837;
     $1839 = Math_fround(HEAPF32[$1042>>2]);
     $1840 = (($1787) + 124|0);
     HEAPF32[$1840>>2] = $1839;
     $1841 = Math_fround(HEAPF32[$1043>>2]);
     $1842 = (($1787) + 128|0);
     HEAPF32[$1842>>2] = $1841;
     $1843 = Math_fround(HEAPF32[$1044>>2]);
     $1844 = (($1787) + 132|0);
     HEAPF32[$1844>>2] = $1843;
     $1845 = Math_fround(HEAPF32[$1045>>2]);
     $1846 = (($1787) + 136|0);
     HEAPF32[$1846>>2] = $1845;
     $1847 = Math_fround(HEAPF32[$1046>>2]);
     $1848 = (($1787) + 140|0);
     HEAPF32[$1848>>2] = $1847;
     $1849 = Math_fround(HEAPF32[$1047>>2]);
     $1850 = (($1787) + 144|0);
     HEAPF32[$1850>>2] = $1849;
     $1851 = Math_fround(HEAPF32[$1048>>2]);
     $1852 = (($1787) + 148|0);
     HEAPF32[$1852>>2] = $1851;
     $1853 = Math_fround(HEAPF32[$1049>>2]);
     $1854 = (($1787) + 152|0);
     HEAPF32[$1854>>2] = $1853;
     $1855 = Math_fround(HEAPF32[$1050>>2]);
     $1856 = (($1787) + 156|0);
     HEAPF32[$1856>>2] = $1855;
     $1857 = Math_fround(HEAPF32[$1051>>2]);
     $1858 = (($1787) + 160|0);
     HEAPF32[$1858>>2] = $1857;
     $1859 = Math_fround(HEAPF32[$1052>>2]);
     $1860 = (($1787) + 164|0);
     HEAPF32[$1860>>2] = $1859;
     $1861 = Math_fround(HEAPF32[$1053>>2]);
     $1862 = (($1787) + 168|0);
     HEAPF32[$1862>>2] = $1861;
     $1863 = Math_fround(HEAPF32[$1054>>2]);
     $1864 = (($1787) + 172|0);
     HEAPF32[$1864>>2] = $1863;
     $1865 = Math_fround(HEAPF32[$1055>>2]);
     $1866 = (($1787) + 176|0);
     HEAPF32[$1866>>2] = $1865;
     $1867 = Math_fround(HEAPF32[$1056>>2]);
     $1868 = (($1787) + 180|0);
     HEAPF32[$1868>>2] = $1867;
     $1869 = Math_fround(HEAPF32[$1057>>2]);
     $1870 = (($1787) + 184|0);
     HEAPF32[$1870>>2] = $1869;
     $1871 = Math_fround(HEAPF32[$1058>>2]);
     $1872 = (($1787) + 188|0);
     HEAPF32[$1872>>2] = $1871;
     $1873 = Math_fround(HEAPF32[$1059>>2]);
     $1874 = (($1787) + 192|0);
     HEAPF32[$1874>>2] = $1873;
     $1875 = Math_fround(HEAPF32[$1060>>2]);
     $1876 = (($1787) + 196|0);
     HEAPF32[$1876>>2] = $1875;
     $1877 = Math_fround(HEAPF32[$1061>>2]);
     $1878 = (($1787) + 200|0);
     HEAPF32[$1878>>2] = $1877;
     $1879 = Math_fround(HEAPF32[$1062>>2]);
     $1880 = (($1787) + 204|0);
     HEAPF32[$1880>>2] = $1879;
     $1881 = Math_fround(HEAPF32[$1063>>2]);
     $1882 = (($1787) + 208|0);
     HEAPF32[$1882>>2] = $1881;
     $1883 = Math_fround(HEAPF32[$1064>>2]);
     $1884 = (($1787) + 212|0);
     HEAPF32[$1884>>2] = $1883;
     $1885 = (($1787) + 216|0);
     ;HEAP32[$1885+0>>2]=HEAP32[$1065+0>>2]|0;HEAP32[$1885+4>>2]=HEAP32[$1065+4>>2]|0;HEAP32[$1885+8>>2]=HEAP32[$1065+8>>2]|0;HEAP32[$1885+12>>2]=HEAP32[$1065+12>>2]|0;HEAP32[$1885+16>>2]=HEAP32[$1065+16>>2]|0;
     $1886 = Math_fround(HEAPF32[$1066>>2]);
     $1887 = (($1787) + 236|0);
     HEAPF32[$1887>>2] = $1886;
     $1888 = Math_fround(HEAPF32[$1067>>2]);
     $1889 = (($1787) + 240|0);
     HEAPF32[$1889>>2] = $1888;
     $1890 = Math_fround(HEAPF32[$1068>>2]);
     $1891 = (($1787) + 244|0);
     HEAPF32[$1891>>2] = $1890;
     $1892 = Math_fround(HEAPF32[$1069>>2]);
     $1893 = (($1787) + 248|0);
     HEAPF32[$1893>>2] = $1892;
     $1894 = Math_fround(HEAPF32[$1070>>2]);
     $1895 = (($1787) + 252|0);
     HEAPF32[$1895>>2] = $1894;
     $1896 = Math_fround(HEAPF32[$1071>>2]);
     $1897 = (($1787) + 256|0);
     HEAPF32[$1897>>2] = $1896;
     $1898 = Math_fround(HEAPF32[$1072>>2]);
     $1899 = (($1787) + 260|0);
     HEAPF32[$1899>>2] = $1898;
     $1900 = Math_fround(HEAPF32[$1073>>2]);
     $1901 = (($1787) + 264|0);
     HEAPF32[$1901>>2] = $1900;
     $1902 = Math_fround(HEAPF32[$1074>>2]);
     $1903 = (($1787) + 268|0);
     HEAPF32[$1903>>2] = $1902;
     $1904 = Math_fround(HEAPF32[$1075>>2]);
     $1905 = (($1787) + 272|0);
     HEAPF32[$1905>>2] = $1904;
     $1906 = Math_fround(HEAPF32[$1076>>2]);
     $1907 = (($1787) + 276|0);
     HEAPF32[$1907>>2] = $1906;
     $1908 = Math_fround(HEAPF32[$1077>>2]);
     $1909 = (($1787) + 280|0);
     HEAPF32[$1909>>2] = $1908;
     $1910 = Math_fround(HEAPF32[$1078>>2]);
     $1911 = (($1787) + 284|0);
     HEAPF32[$1911>>2] = $1910;
     $1912 = Math_fround(HEAPF32[$1079>>2]);
     $1913 = (($1787) + 288|0);
     HEAPF32[$1913>>2] = $1912;
     $1914 = Math_fround(HEAPF32[$1080>>2]);
     $1915 = (($1787) + 292|0);
     HEAPF32[$1915>>2] = $1914;
     $1916 = Math_fround(HEAPF32[$1081>>2]);
     $1917 = (($1787) + 296|0);
     HEAPF32[$1917>>2] = $1916;
     $1918 = Math_fround(HEAPF32[$1082>>2]);
     $1919 = (($1787) + 300|0);
     HEAPF32[$1919>>2] = $1918;
     $1920 = Math_fround(HEAPF32[$1083>>2]);
     $1921 = (($1787) + 304|0);
     HEAPF32[$1921>>2] = $1920;
     $1922 = Math_fround(HEAPF32[$1084>>2]);
     $1923 = (($1787) + 308|0);
     HEAPF32[$1923>>2] = $1922;
     $1924 = Math_fround(HEAPF32[$1085>>2]);
     $1925 = (($1787) + 312|0);
     HEAPF32[$1925>>2] = $1924;
     $1926 = Math_fround(HEAPF32[$1086>>2]);
     $1927 = (($1787) + 316|0);
     HEAPF32[$1927>>2] = $1926;
     $1928 = Math_fround(HEAPF32[$1087>>2]);
     $1929 = (($1787) + 320|0);
     HEAPF32[$1929>>2] = $1928;
     $1930 = Math_fround(HEAPF32[$1088>>2]);
     $1931 = (($1787) + 324|0);
     HEAPF32[$1931>>2] = $1930;
     $1932 = Math_fround(HEAPF32[$1089>>2]);
     $1933 = (($1787) + 328|0);
     HEAPF32[$1933>>2] = $1932;
     $1934 = (($1787) + 332|0);
     ;HEAP32[$1934+0>>2]=HEAP32[$1090+0>>2]|0;HEAP32[$1934+4>>2]=HEAP32[$1090+4>>2]|0;HEAP32[$1934+8>>2]=HEAP32[$1090+8>>2]|0;HEAP32[$1934+12>>2]=HEAP32[$1090+12>>2]|0;HEAP32[$1934+16>>2]=HEAP32[$1090+16>>2]|0;
     $1935 = HEAP32[$946>>2]|0;
     $1936 = (($wheelQueryResults) + (($1639*148)|0)|0);
     $1937 = HEAP32[$1661>>2]|0;
     __ZN5physx15PxVehicleUpdate25storeSuspWheelTireResultsERKNS_30ProcessSuspWheelTireOutputDataEPKfPNS_18PxWheelQueryResultEj($extraOutputData,$1935,$1936,$1937);
     $1938 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
     $1939 = ($1937|0)==(0);
     if (!($1939)) {
      $i$01$i = 0;
      while(1) {
       $1940 = ((($extraOutputData) + ($i$01$i<<2)|0) + 1000|0);
       $1941 = HEAP32[$1940>>2]|0;
       $$sum = (($i$01$i) + ($1639))|0;
       $1942 = ((($1938) + (($$sum*56)|0)|0) + 28|0);
       HEAP32[$1942>>2] = $1941;
       $1943 = ((($extraOutputData) + (($i$01$i*12)|0)|0) + 1016|0);
       $1944 = Math_fround(HEAPF32[$1943>>2]);
       $1945 = ((($1938) + (($$sum*56)|0)|0) + 32|0);
       $1946 = Math_fround(HEAPF32[$1945>>2]);
       $1947 = Math_fround($1944 + $1946);
       HEAPF32[$1945>>2] = $1947;
       $1948 = ((($extraOutputData) + (($i$01$i*12)|0)|0) + 1020|0);
       $1949 = Math_fround(HEAPF32[$1948>>2]);
       $1950 = ((($1938) + (($$sum*56)|0)|0) + 36|0);
       $1951 = Math_fround(HEAPF32[$1950>>2]);
       $1952 = Math_fround($1949 + $1951);
       HEAPF32[$1950>>2] = $1952;
       $1953 = ((($extraOutputData) + (($i$01$i*12)|0)|0) + 1024|0);
       $1954 = Math_fround(HEAPF32[$1953>>2]);
       $1955 = ((($1938) + (($$sum*56)|0)|0) + 40|0);
       $1956 = Math_fround(HEAPF32[$1955>>2]);
       $1957 = Math_fround($1954 + $1956);
       HEAPF32[$1955>>2] = $1957;
       $1958 = ((($extraOutputData) + (($i$01$i*12)|0)|0) + 1064|0);
       $1959 = Math_fround(HEAPF32[$1958>>2]);
       $1960 = ((($1938) + (($$sum*56)|0)|0) + 44|0);
       HEAPF32[$1960>>2] = $1959;
       $1961 = ((($extraOutputData) + (($i$01$i*12)|0)|0) + 1068|0);
       $1962 = Math_fround(HEAPF32[$1961>>2]);
       $1963 = ((($1938) + (($$sum*56)|0)|0) + 48|0);
       HEAPF32[$1963>>2] = $1962;
       $1964 = ((($extraOutputData) + (($i$01$i*12)|0)|0) + 1072|0);
       $1965 = Math_fround(HEAPF32[$1964>>2]);
       $1966 = ((($1938) + (($$sum*56)|0)|0) + 52|0);
       HEAPF32[$1966>>2] = $1965;
       $1967 = (($i$01$i) + 1)|0;
       $exitcond$i5 = ($1967|0)==($1937|0);
       if ($exitcond$i5) {
        break;
       } else {
        $i$01$i = $1967;
       }
      }
     }
     __ZN5physx35integrateUndriveWheelRotationSpeedsEfffPKfS1_RKNS_23PxVehicleWheels4SimDataERNS_23PxVehicleWheels4DynDataE($681,$439,$441,$1091,$extraWheelBrakeTorques,$1550,$1559);
     $j$02$i = 0;
     while(1) {
      $1968 = ((($44) + (($j$098*208)|0)|0) + ($j$02$i<<2)|0);
      $1969 = Math_fround(HEAPF32[$1968>>2]);
      $1970 = ((($extraOutputData) + ($j$02$i<<2)|0) + 292|0);
      $1971 = Math_fround(HEAPF32[$1970>>2]);
      $1972 = (((($42) + (($j$098*944)|0)|0) + (($j$02$i*48)|0)|0) + 12|0);
      $1973 = Math_fround(HEAPF32[$1972>>2]);
      $1974 = Math_fround(-$1973);
      $1975 = $1971 > $1974;
      do {
       if ($1975) {
        $1976 = (($extraIsBrakeApplied) + ($j$02$i)|0);
        $1977 = HEAP8[$1976>>0]|0;
        $1978 = ($1977<<24>>24)==(0);
        if (!($1978)) {
         $wheelOmega$0$i = $1969;
         break;
        }
        $1979 = (($extraWheelsDiffTorqueRatios) + ($j$02$i<<2)|0);
        $1980 = Math_fround(HEAPF32[$1979>>2]);
        $1981 = Math_fround($1980 * Math_fround(0.0));
        $1982 = Math_fround($1981 * Math_fround(0.0));
        $1983 = $1982 == Math_fround(0.0);
        if (!($1983)) {
         $wheelOmega$0$i = $1969;
         break;
        }
        $1984 = ((($extraOutputData) + ($j$02$i<<2)|0) + 452|0);
        $1985 = Math_fround(HEAPF32[$1984>>2]);
        $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($1985)))));
        $1986 = Math_fround(HEAPF32[523912>>2]);
        $1987 = $fabsf$i$i1$i < $1986;
        if (!($1987)) {
         $wheelOmega$0$i = $1969;
         break;
        }
        $1988 = (((($42) + (($j$098*944)|0)|0) + (($j$02$i*48)|0)|0) + 228|0);
        $1989 = Math_fround(HEAPF32[$1988>>2]);
        $1990 = Math_fround(HEAPF32[523920>>2]);
        $1991 = Math_fround($fabsf$i$i1$i * $1990);
        $1992 = Math_fround($1985 * $1989);
        $1993 = Math_fround(Math_fround(1.0) - $1991);
        $1994 = Math_fround($1992 * $1993);
        $1995 = Math_fround($1969 * $1991);
        $1996 = Math_fround($1995 + $1994);
        $wheelOmega$0$i = $1996;
       } else {
        $wheelOmega$0$i = $1969;
       }
      } while(0);
      $1997 = (((($44) + (($j$098*208)|0)|0) + ($j$02$i<<2)|0) + 32|0);
      $1998 = Math_fround(HEAPF32[$1997>>2]);
      $1999 = Math_fround($681 * $wheelOmega$0$i);
      $2000 = Math_fround($1998 + $1999);
      $2001 = Math_fround($2000 + Math_fround(-31.415927886962890625));
      $2002 = Math_fround(Math_fround(-31.415927886962890625) - $2000);
      $2003 = Math_fround($2000 + Math_fround(31.415927886962890625));
      $2004 = $2002 >= Math_fround(0.0);
      $2005 = $2004 ? $2003 : $2000;
      $2006 = $2001 >= Math_fround(0.0);
      $2007 = $2006 ? $2001 : $2005;
      HEAPF32[$1997>>2] = $2007;
      $2008 = (((($44) + (($j$098*208)|0)|0) + ($j$02$i<<2)|0) + 16|0);
      HEAPF32[$2008>>2] = $wheelOmega$0$i;
      $2009 = (($j$02$i) + 1)|0;
      $exitcond$i = ($2009|0)==(4);
      if ($exitcond$i) {
       break;
      } else {
       $j$02$i = $2009;
      }
     }
     $2010 = (($j$098) + 1)|0;
     $exitcond152 = ($2010|0)==($48|0);
     if ($exitcond152) {
      break;
     } else {
      $1770 = $1769;$1773 = $1772;$1776 = $1775;$1779 = $1778;$1782 = $1781;$1785 = $1784;$j$098 = $2010;
     }
    }
    HEAPF32[$chassisForce>>2] = $1769;
    HEAPF32[$701>>2] = $1772;
    HEAPF32[$702>>2] = $1775;
    HEAPF32[$chassisTorque>>2] = $1778;
    HEAPF32[$703>>2] = $1781;
    HEAPF32[$704>>2] = $1784;
   }
   __ZN5physx13integrateBodyEfRKNS_6PxVec3ES2_S2_fRS0_S3_RNS_11PxTransformE($359,$inverseInertia,$chassisForce,$chassisTorque,$681,$carChassisLinVel,$carChassisAngVel,$carChassisTransform);
   $2011 = (($k$0112) + 1)|0;
   $exitcond153 = ($2011|0)==($678|0);
   if ($exitcond153) {
    break;
   } else {
    $k$0112 = $2011;
   }
  }
  $$pre167 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
  $2014 = $$pre167;
 }
 $2012 = (0)==(0);
 $2013 = (($vehicleConcurrentUpdates) + 8|0);
 if ($2012) {
  HEAPF32[$2013>>2] = $2014;
  $2015 = Math_fround(HEAPF32[$379>>2]);
  $2016 = (($vehicleConcurrentUpdates) + 12|0);
  HEAPF32[$2016>>2] = $2015;
  $2017 = Math_fround(HEAPF32[$382>>2]);
  $2018 = (($vehicleConcurrentUpdates) + 16|0);
  HEAPF32[$2018>>2] = $2017;
  $2019 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $2020 = (($vehicleConcurrentUpdates) + 20|0);
  HEAPF32[$2020>>2] = $2019;
  $2021 = Math_fround(HEAPF32[$389>>2]);
  $2022 = (($vehicleConcurrentUpdates) + 24|0);
  HEAPF32[$2022>>2] = $2021;
  $2023 = Math_fround(HEAPF32[$392>>2]);
  $2024 = (($vehicleConcurrentUpdates) + 28|0);
  HEAPF32[$2024>>2] = $2023;
 } else {
  $2025 = Math_fround($2014 - $664);
  $2026 = Math_fround(HEAPF32[$379>>2]);
  $2027 = Math_fround($2026 - $666);
  $2028 = Math_fround(HEAPF32[$382>>2]);
  $2029 = Math_fround($2028 - $669);
  $2030 = Math_fround($682 * $2025);
  $2031 = Math_fround($682 * $2027);
  $2032 = Math_fround($682 * $2029);
  HEAPF32[$2013>>2] = $2030;
  $2033 = (($vehicleConcurrentUpdates) + 12|0);
  HEAPF32[$2033>>2] = $2031;
  $2034 = (($vehicleConcurrentUpdates) + 16|0);
  HEAPF32[$2034>>2] = $2032;
  $2035 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $2036 = Math_fround($2035 - $2037);
  $2038 = Math_fround(HEAPF32[$389>>2]);
  $2039 = Math_fround($2038 - $2040);
  $2041 = Math_fround(HEAPF32[$392>>2]);
  $2042 = Math_fround($2041 - $2043);
  $2044 = Math_fround($682 * $2036);
  $2045 = Math_fround($682 * $2039);
  $2046 = Math_fround($682 * $2042);
  $2047 = (($vehicleConcurrentUpdates) + 20|0);
  HEAPF32[$2047>>2] = $2044;
  $2048 = (($vehicleConcurrentUpdates) + 24|0);
  HEAPF32[$2048>>2] = $2045;
  $2049 = (($vehicleConcurrentUpdates) + 28|0);
  HEAPF32[$2049>>2] = $2046;
 }
 HEAPF32[$extraInputData>>2] = Math_fround(0.0);
 $2050 = (($extraInputData) + 4|0);
 HEAPF32[$2050>>2] = Math_fround(0.0);
 $2051 = (($extraInputData) + 8|0);
 HEAPF32[$2051>>2] = Math_fround(0.0);
 $2052 = (($extraInputData) + 12|0);
 HEAPF32[$2052>>2] = Math_fround(1.0);
 $2053 = (($extraInputData) + 16|0);
 $2054 = (($extraInputData) + 20|0);
 $2055 = (($extraInputData) + 24|0);
 $2056 = (($extraInputData) + 28|0);
 $2057 = (($extraInputData) + 32|0);
 $2058 = (($extraInputData) + 36|0);
 $2059 = (($extraInputData) + 40|0);
 ;HEAP32[$2053+0>>2]=0|0;HEAP32[$2053+4>>2]=0|0;HEAP32[$2053+8>>2]=0|0;HEAP32[$2053+12>>2]=0|0;HEAP32[$2053+16>>2]=0|0;HEAP32[$2053+20>>2]=0|0;
 HEAPF32[$2059>>2] = Math_fround(1.0);
 $2060 = (($extraInputData) + 44|0);
 $2061 = (($extraInputData) + 48|0);
 $2062 = (($extraInputData) + 52|0);
 $2063 = (($extraInputData) + 56|0);
 $2064 = (($extraInputData) + 60|0);
 $2065 = (($extraInputData) + 64|0);
 $2066 = (($extraInputData) + 68|0);
 ;HEAP32[$2060+0>>2]=0|0;HEAP32[$2060+4>>2]=0|0;HEAP32[$2060+8>>2]=0|0;HEAP32[$2060+12>>2]=0|0;HEAP32[$2060+16>>2]=0|0;HEAP32[$2060+20>>2]=0|0;
 HEAPF32[$2066>>2] = Math_fround(1.0);
 $2067 = (($extraInputData) + 72|0);
 $2068 = (($extraInputData) + 76|0);
 $2069 = (($extraInputData) + 80|0);
 $2070 = (($extraInputData) + 84|0);
 $2071 = (($extraInputData) + 88|0);
 $2072 = (($extraInputData) + 92|0);
 $2073 = (($extraInputData) + 96|0);
 ;HEAP32[$2067+0>>2]=0|0;HEAP32[$2067+4>>2]=0|0;HEAP32[$2067+8>>2]=0|0;HEAP32[$2067+12>>2]=0|0;HEAP32[$2067+16>>2]=0|0;HEAP32[$2067+20>>2]=0|0;
 HEAPF32[$2073>>2] = Math_fround(1.0);
 $2074 = (($extraInputData) + 100|0);
 HEAPF32[$2074>>2] = Math_fround(0.0);
 $2075 = (($extraInputData) + 104|0);
 HEAPF32[$2075>>2] = Math_fround(0.0);
 $2076 = (($extraInputData) + 108|0);
 HEAPF32[$2076>>2] = Math_fround(0.0);
 $2077 = HEAP32[$numActiveWheelsPerBlock4>>2]|0;
 __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($42,$44,$wheelQueryResults,$2077,$carChassisCMLocalPose,$extraInputData);
 $2078 = Math_fround(HEAPF32[$extraInputData>>2]);
 $2079 = (($wheelQueryResults) + 120|0);
 HEAPF32[$2079>>2] = $2078;
 $2080 = Math_fround(HEAPF32[$2050>>2]);
 $2081 = (($wheelQueryResults) + 124|0);
 HEAPF32[$2081>>2] = $2080;
 $2082 = Math_fround(HEAPF32[$2051>>2]);
 $2083 = (($wheelQueryResults) + 128|0);
 HEAPF32[$2083>>2] = $2082;
 $2084 = Math_fround(HEAPF32[$2052>>2]);
 $2085 = (($wheelQueryResults) + 132|0);
 HEAPF32[$2085>>2] = $2084;
 $2086 = Math_fround(HEAPF32[$2053>>2]);
 $2087 = (($wheelQueryResults) + 136|0);
 HEAPF32[$2087>>2] = $2086;
 $2088 = Math_fround(HEAPF32[$2054>>2]);
 $2089 = (($wheelQueryResults) + 140|0);
 HEAPF32[$2089>>2] = $2088;
 $2090 = Math_fround(HEAPF32[$2055>>2]);
 $2091 = (($wheelQueryResults) + 144|0);
 HEAPF32[$2091>>2] = $2090;
 $2092 = Math_fround(HEAPF32[$2056>>2]);
 $2093 = (($wheelQueryResults) + 268|0);
 HEAPF32[$2093>>2] = $2092;
 $2094 = Math_fround(HEAPF32[$2057>>2]);
 $2095 = (($wheelQueryResults) + 272|0);
 HEAPF32[$2095>>2] = $2094;
 $2096 = Math_fround(HEAPF32[$2058>>2]);
 $2097 = (($wheelQueryResults) + 276|0);
 HEAPF32[$2097>>2] = $2096;
 $2098 = Math_fround(HEAPF32[$2059>>2]);
 $2099 = (($wheelQueryResults) + 280|0);
 HEAPF32[$2099>>2] = $2098;
 $2100 = Math_fround(HEAPF32[$2060>>2]);
 $2101 = (($wheelQueryResults) + 284|0);
 HEAPF32[$2101>>2] = $2100;
 $2102 = Math_fround(HEAPF32[$2061>>2]);
 $2103 = (($wheelQueryResults) + 288|0);
 HEAPF32[$2103>>2] = $2102;
 $2104 = Math_fround(HEAPF32[$2062>>2]);
 $2105 = (($wheelQueryResults) + 292|0);
 HEAPF32[$2105>>2] = $2104;
 $2106 = Math_fround(HEAPF32[$2063>>2]);
 $2107 = (($wheelQueryResults) + 416|0);
 HEAPF32[$2107>>2] = $2106;
 $2108 = Math_fround(HEAPF32[$2064>>2]);
 $2109 = (($wheelQueryResults) + 420|0);
 HEAPF32[$2109>>2] = $2108;
 $2110 = Math_fround(HEAPF32[$2065>>2]);
 $2111 = (($wheelQueryResults) + 424|0);
 HEAPF32[$2111>>2] = $2110;
 $2112 = Math_fround(HEAPF32[$2066>>2]);
 $2113 = (($wheelQueryResults) + 428|0);
 HEAPF32[$2113>>2] = $2112;
 $2114 = Math_fround(HEAPF32[$2067>>2]);
 $2115 = (($wheelQueryResults) + 432|0);
 HEAPF32[$2115>>2] = $2114;
 $2116 = Math_fround(HEAPF32[$2068>>2]);
 $2117 = (($wheelQueryResults) + 436|0);
 HEAPF32[$2117>>2] = $2116;
 $2118 = Math_fround(HEAPF32[$2069>>2]);
 $2119 = (($wheelQueryResults) + 440|0);
 HEAPF32[$2119>>2] = $2118;
 $2120 = Math_fround(HEAPF32[$2070>>2]);
 $2121 = (($wheelQueryResults) + 564|0);
 HEAPF32[$2121>>2] = $2120;
 $2122 = Math_fround(HEAPF32[$2071>>2]);
 $2123 = (($wheelQueryResults) + 568|0);
 HEAPF32[$2123>>2] = $2122;
 $2124 = Math_fround(HEAPF32[$2072>>2]);
 $2125 = (($wheelQueryResults) + 572|0);
 HEAPF32[$2125>>2] = $2124;
 $2126 = Math_fround(HEAPF32[$2073>>2]);
 $2127 = (($wheelQueryResults) + 576|0);
 HEAPF32[$2127>>2] = $2126;
 $2128 = Math_fround(HEAPF32[$2074>>2]);
 $2129 = (($wheelQueryResults) + 580|0);
 HEAPF32[$2129>>2] = $2128;
 $2130 = Math_fround(HEAPF32[$2075>>2]);
 $2131 = (($wheelQueryResults) + 584|0);
 HEAPF32[$2131>>2] = $2130;
 $2132 = Math_fround(HEAPF32[$2076>>2]);
 $2133 = (($wheelQueryResults) + 588|0);
 HEAPF32[$2133>>2] = $2132;
 $2134 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
 HEAPF32[$2134>>2] = $2078;
 $2135 = Math_fround(HEAPF32[$2050>>2]);
 $2136 = (($2134) + 4|0);
 HEAPF32[$2136>>2] = $2135;
 $2137 = Math_fround(HEAPF32[$2051>>2]);
 $2138 = (($2134) + 8|0);
 HEAPF32[$2138>>2] = $2137;
 $2139 = Math_fround(HEAPF32[$2052>>2]);
 $2140 = (($2134) + 12|0);
 HEAPF32[$2140>>2] = $2139;
 $2141 = Math_fround(HEAPF32[$2053>>2]);
 $2142 = (($2134) + 16|0);
 HEAPF32[$2142>>2] = $2141;
 $2143 = Math_fround(HEAPF32[$2054>>2]);
 $2144 = (($2134) + 20|0);
 HEAPF32[$2144>>2] = $2143;
 $2145 = Math_fround(HEAPF32[$2055>>2]);
 $2146 = (($2134) + 24|0);
 HEAPF32[$2146>>2] = $2145;
 $2147 = Math_fround(HEAPF32[$2056>>2]);
 $2148 = (($2134) + 56|0);
 HEAPF32[$2148>>2] = $2147;
 $2149 = Math_fround(HEAPF32[$2057>>2]);
 $2150 = (($2134) + 60|0);
 HEAPF32[$2150>>2] = $2149;
 $2151 = Math_fround(HEAPF32[$2058>>2]);
 $2152 = (($2134) + 64|0);
 HEAPF32[$2152>>2] = $2151;
 $2153 = Math_fround(HEAPF32[$2059>>2]);
 $2154 = (($2134) + 68|0);
 HEAPF32[$2154>>2] = $2153;
 $2155 = Math_fround(HEAPF32[$2060>>2]);
 $2156 = (($2134) + 72|0);
 HEAPF32[$2156>>2] = $2155;
 $2157 = Math_fround(HEAPF32[$2061>>2]);
 $2158 = (($2134) + 76|0);
 HEAPF32[$2158>>2] = $2157;
 $2159 = Math_fround(HEAPF32[$2062>>2]);
 $2160 = (($2134) + 80|0);
 HEAPF32[$2160>>2] = $2159;
 $2161 = Math_fround(HEAPF32[$2063>>2]);
 $2162 = (($2134) + 112|0);
 HEAPF32[$2162>>2] = $2161;
 $2163 = Math_fround(HEAPF32[$2064>>2]);
 $2164 = (($2134) + 116|0);
 HEAPF32[$2164>>2] = $2163;
 $2165 = Math_fround(HEAPF32[$2065>>2]);
 $2166 = (($2134) + 120|0);
 HEAPF32[$2166>>2] = $2165;
 $2167 = Math_fround(HEAPF32[$2066>>2]);
 $2168 = (($2134) + 124|0);
 HEAPF32[$2168>>2] = $2167;
 $2169 = Math_fround(HEAPF32[$2067>>2]);
 $2170 = (($2134) + 128|0);
 HEAPF32[$2170>>2] = $2169;
 $2171 = Math_fround(HEAPF32[$2068>>2]);
 $2172 = (($2134) + 132|0);
 HEAPF32[$2172>>2] = $2171;
 $2173 = Math_fround(HEAPF32[$2069>>2]);
 $2174 = (($2134) + 136|0);
 HEAPF32[$2174>>2] = $2173;
 $2175 = Math_fround(HEAPF32[$2070>>2]);
 $2176 = (($2134) + 168|0);
 HEAPF32[$2176>>2] = $2175;
 $2177 = Math_fround(HEAPF32[$2071>>2]);
 $2178 = (($2134) + 172|0);
 HEAPF32[$2178>>2] = $2177;
 $2179 = Math_fround(HEAPF32[$2072>>2]);
 $2180 = (($2134) + 176|0);
 HEAPF32[$2180>>2] = $2179;
 $2181 = Math_fround(HEAPF32[$2073>>2]);
 $2182 = (($2134) + 180|0);
 HEAPF32[$2182>>2] = $2181;
 $2183 = Math_fround(HEAPF32[$2074>>2]);
 $2184 = (($2134) + 184|0);
 HEAPF32[$2184>>2] = $2183;
 $2185 = Math_fround(HEAPF32[$2075>>2]);
 $2186 = (($2134) + 188|0);
 HEAPF32[$2186>>2] = $2185;
 $2187 = Math_fround(HEAPF32[$2076>>2]);
 $2188 = (($2134) + 192|0);
 HEAPF32[$2188>>2] = $2187;
 $2189 = ($48>>>0)>(1);
 if ($2189) {
  $2190 = (($extraOutputData) + 4|0);
  $2191 = (($extraOutputData) + 8|0);
  $2192 = (($extraOutputData) + 12|0);
  $2193 = (($extraOutputData) + 16|0);
  $2194 = (($extraOutputData) + 20|0);
  $2195 = (($extraOutputData) + 24|0);
  $2196 = (($extraOutputData) + 28|0);
  $2197 = (($extraOutputData) + 32|0);
  $2198 = (($extraOutputData) + 36|0);
  $2199 = (($extraOutputData) + 40|0);
  $2200 = (($extraOutputData) + 44|0);
  $2201 = (($extraOutputData) + 48|0);
  $2202 = (($extraOutputData) + 52|0);
  $2203 = (($extraOutputData) + 56|0);
  $2204 = (($extraOutputData) + 60|0);
  $2205 = (($extraOutputData) + 64|0);
  $2206 = (($extraOutputData) + 68|0);
  $2207 = (($extraOutputData) + 72|0);
  $2208 = (($extraOutputData) + 76|0);
  $2209 = (($extraOutputData) + 80|0);
  $2210 = (($extraOutputData) + 84|0);
  $2211 = (($extraOutputData) + 88|0);
  $2212 = (($extraOutputData) + 92|0);
  $2213 = (($extraOutputData) + 96|0);
  $2214 = (($extraOutputData) + 100|0);
  $2215 = (($extraOutputData) + 104|0);
  $2216 = (($extraOutputData) + 108|0);
  $i9$092 = 1;
  while(1) {
   HEAPF32[$extraOutputData>>2] = Math_fround(0.0);
   HEAPF32[$2190>>2] = Math_fround(0.0);
   HEAPF32[$2191>>2] = Math_fround(0.0);
   HEAPF32[$2192>>2] = Math_fround(1.0);
   ;HEAP32[$2193+0>>2]=0|0;HEAP32[$2193+4>>2]=0|0;HEAP32[$2193+8>>2]=0|0;HEAP32[$2193+12>>2]=0|0;HEAP32[$2193+16>>2]=0|0;HEAP32[$2193+20>>2]=0|0;
   HEAPF32[$2199>>2] = Math_fround(1.0);
   ;HEAP32[$2200+0>>2]=0|0;HEAP32[$2200+4>>2]=0|0;HEAP32[$2200+8>>2]=0|0;HEAP32[$2200+12>>2]=0|0;HEAP32[$2200+16>>2]=0|0;HEAP32[$2200+20>>2]=0|0;
   HEAPF32[$2206>>2] = Math_fround(1.0);
   ;HEAP32[$2207+0>>2]=0|0;HEAP32[$2207+4>>2]=0|0;HEAP32[$2207+8>>2]=0|0;HEAP32[$2207+12>>2]=0|0;HEAP32[$2207+16>>2]=0|0;HEAP32[$2207+20>>2]=0|0;
   HEAPF32[$2213>>2] = Math_fround(1.0);
   HEAPF32[$2214>>2] = Math_fround(0.0);
   HEAPF32[$2215>>2] = Math_fround(0.0);
   HEAPF32[$2216>>2] = Math_fround(0.0);
   $2217 = (($42) + (($i9$092*944)|0)|0);
   $2218 = (($44) + (($i9$092*208)|0)|0);
   $2219 = $i9$092 << 2;
   $2220 = (($wheelQueryResults) + (($2219*148)|0)|0);
   $2221 = (($numActiveWheelsPerBlock4) + ($i9$092<<2)|0);
   $2222 = HEAP32[$2221>>2]|0;
   __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($2217,$2218,$2220,$2222,$carChassisCMLocalPose,$extraOutputData);
   $2223 = Math_fround(HEAPF32[$extraOutputData>>2]);
   $2224 = ((($wheelQueryResults) + (($2219*148)|0)|0) + 120|0);
   HEAPF32[$2224>>2] = $2223;
   $2225 = Math_fround(HEAPF32[$2190>>2]);
   $2226 = ((($wheelQueryResults) + (($2219*148)|0)|0) + 124|0);
   HEAPF32[$2226>>2] = $2225;
   $2227 = Math_fround(HEAPF32[$2191>>2]);
   $2228 = ((($wheelQueryResults) + (($2219*148)|0)|0) + 128|0);
   HEAPF32[$2228>>2] = $2227;
   $2229 = Math_fround(HEAPF32[$2192>>2]);
   $2230 = ((($wheelQueryResults) + (($2219*148)|0)|0) + 132|0);
   HEAPF32[$2230>>2] = $2229;
   $2231 = Math_fround(HEAPF32[$2193>>2]);
   $2232 = ((($wheelQueryResults) + (($2219*148)|0)|0) + 136|0);
   HEAPF32[$2232>>2] = $2231;
   $2233 = Math_fround(HEAPF32[$2194>>2]);
   $2234 = ((($wheelQueryResults) + (($2219*148)|0)|0) + 140|0);
   HEAPF32[$2234>>2] = $2233;
   $2235 = Math_fround(HEAPF32[$2195>>2]);
   $2236 = ((($wheelQueryResults) + (($2219*148)|0)|0) + 144|0);
   HEAPF32[$2236>>2] = $2235;
   $2237 = $2219 | 1;
   $2238 = Math_fround(HEAPF32[$2196>>2]);
   $2239 = ((($wheelQueryResults) + (($2237*148)|0)|0) + 120|0);
   HEAPF32[$2239>>2] = $2238;
   $2240 = Math_fround(HEAPF32[$2197>>2]);
   $2241 = ((($wheelQueryResults) + (($2237*148)|0)|0) + 124|0);
   HEAPF32[$2241>>2] = $2240;
   $2242 = Math_fround(HEAPF32[$2198>>2]);
   $2243 = ((($wheelQueryResults) + (($2237*148)|0)|0) + 128|0);
   HEAPF32[$2243>>2] = $2242;
   $2244 = Math_fround(HEAPF32[$2199>>2]);
   $2245 = ((($wheelQueryResults) + (($2237*148)|0)|0) + 132|0);
   HEAPF32[$2245>>2] = $2244;
   $2246 = Math_fround(HEAPF32[$2200>>2]);
   $2247 = ((($wheelQueryResults) + (($2237*148)|0)|0) + 136|0);
   HEAPF32[$2247>>2] = $2246;
   $2248 = Math_fround(HEAPF32[$2201>>2]);
   $2249 = ((($wheelQueryResults) + (($2237*148)|0)|0) + 140|0);
   HEAPF32[$2249>>2] = $2248;
   $2250 = Math_fround(HEAPF32[$2202>>2]);
   $2251 = ((($wheelQueryResults) + (($2237*148)|0)|0) + 144|0);
   HEAPF32[$2251>>2] = $2250;
   $2252 = $2219 | 2;
   $2253 = Math_fround(HEAPF32[$2203>>2]);
   $2254 = ((($wheelQueryResults) + (($2252*148)|0)|0) + 120|0);
   HEAPF32[$2254>>2] = $2253;
   $2255 = Math_fround(HEAPF32[$2204>>2]);
   $2256 = ((($wheelQueryResults) + (($2252*148)|0)|0) + 124|0);
   HEAPF32[$2256>>2] = $2255;
   $2257 = Math_fround(HEAPF32[$2205>>2]);
   $2258 = ((($wheelQueryResults) + (($2252*148)|0)|0) + 128|0);
   HEAPF32[$2258>>2] = $2257;
   $2259 = Math_fround(HEAPF32[$2206>>2]);
   $2260 = ((($wheelQueryResults) + (($2252*148)|0)|0) + 132|0);
   HEAPF32[$2260>>2] = $2259;
   $2261 = Math_fround(HEAPF32[$2207>>2]);
   $2262 = ((($wheelQueryResults) + (($2252*148)|0)|0) + 136|0);
   HEAPF32[$2262>>2] = $2261;
   $2263 = Math_fround(HEAPF32[$2208>>2]);
   $2264 = ((($wheelQueryResults) + (($2252*148)|0)|0) + 140|0);
   HEAPF32[$2264>>2] = $2263;
   $2265 = Math_fround(HEAPF32[$2209>>2]);
   $2266 = ((($wheelQueryResults) + (($2252*148)|0)|0) + 144|0);
   HEAPF32[$2266>>2] = $2265;
   $2267 = $2219 | 3;
   $2268 = Math_fround(HEAPF32[$2210>>2]);
   $2269 = ((($wheelQueryResults) + (($2267*148)|0)|0) + 120|0);
   HEAPF32[$2269>>2] = $2268;
   $2270 = Math_fround(HEAPF32[$2211>>2]);
   $2271 = ((($wheelQueryResults) + (($2267*148)|0)|0) + 124|0);
   HEAPF32[$2271>>2] = $2270;
   $2272 = Math_fround(HEAPF32[$2212>>2]);
   $2273 = ((($wheelQueryResults) + (($2267*148)|0)|0) + 128|0);
   HEAPF32[$2273>>2] = $2272;
   $2274 = Math_fround(HEAPF32[$2213>>2]);
   $2275 = ((($wheelQueryResults) + (($2267*148)|0)|0) + 132|0);
   HEAPF32[$2275>>2] = $2274;
   $2276 = Math_fround(HEAPF32[$2214>>2]);
   $2277 = ((($wheelQueryResults) + (($2267*148)|0)|0) + 136|0);
   HEAPF32[$2277>>2] = $2276;
   $2278 = Math_fround(HEAPF32[$2215>>2]);
   $2279 = ((($wheelQueryResults) + (($2267*148)|0)|0) + 140|0);
   HEAPF32[$2279>>2] = $2278;
   $2280 = Math_fround(HEAPF32[$2216>>2]);
   $2281 = ((($wheelQueryResults) + (($2267*148)|0)|0) + 144|0);
   HEAPF32[$2281>>2] = $2280;
   $2282 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
   $2283 = (($2282) + (($2219*56)|0)|0);
   HEAPF32[$2283>>2] = $2223;
   $2284 = Math_fround(HEAPF32[$2190>>2]);
   $2285 = ((($2282) + (($2219*56)|0)|0) + 4|0);
   HEAPF32[$2285>>2] = $2284;
   $2286 = Math_fround(HEAPF32[$2191>>2]);
   $2287 = ((($2282) + (($2219*56)|0)|0) + 8|0);
   HEAPF32[$2287>>2] = $2286;
   $2288 = Math_fround(HEAPF32[$2192>>2]);
   $2289 = ((($2282) + (($2219*56)|0)|0) + 12|0);
   HEAPF32[$2289>>2] = $2288;
   $2290 = Math_fround(HEAPF32[$2193>>2]);
   $2291 = ((($2282) + (($2219*56)|0)|0) + 16|0);
   HEAPF32[$2291>>2] = $2290;
   $2292 = Math_fround(HEAPF32[$2194>>2]);
   $2293 = ((($2282) + (($2219*56)|0)|0) + 20|0);
   HEAPF32[$2293>>2] = $2292;
   $2294 = Math_fround(HEAPF32[$2195>>2]);
   $2295 = ((($2282) + (($2219*56)|0)|0) + 24|0);
   HEAPF32[$2295>>2] = $2294;
   $2296 = Math_fround(HEAPF32[$2196>>2]);
   $2297 = (($2282) + (($2237*56)|0)|0);
   HEAPF32[$2297>>2] = $2296;
   $2298 = Math_fround(HEAPF32[$2197>>2]);
   $2299 = ((($2282) + (($2237*56)|0)|0) + 4|0);
   HEAPF32[$2299>>2] = $2298;
   $2300 = Math_fround(HEAPF32[$2198>>2]);
   $2301 = ((($2282) + (($2237*56)|0)|0) + 8|0);
   HEAPF32[$2301>>2] = $2300;
   $2302 = Math_fround(HEAPF32[$2199>>2]);
   $2303 = ((($2282) + (($2237*56)|0)|0) + 12|0);
   HEAPF32[$2303>>2] = $2302;
   $2304 = Math_fround(HEAPF32[$2200>>2]);
   $2305 = ((($2282) + (($2237*56)|0)|0) + 16|0);
   HEAPF32[$2305>>2] = $2304;
   $2306 = Math_fround(HEAPF32[$2201>>2]);
   $2307 = ((($2282) + (($2237*56)|0)|0) + 20|0);
   HEAPF32[$2307>>2] = $2306;
   $2308 = Math_fround(HEAPF32[$2202>>2]);
   $2309 = ((($2282) + (($2237*56)|0)|0) + 24|0);
   HEAPF32[$2309>>2] = $2308;
   $2310 = Math_fround(HEAPF32[$2203>>2]);
   $2311 = (($2282) + (($2252*56)|0)|0);
   HEAPF32[$2311>>2] = $2310;
   $2312 = Math_fround(HEAPF32[$2204>>2]);
   $2313 = ((($2282) + (($2252*56)|0)|0) + 4|0);
   HEAPF32[$2313>>2] = $2312;
   $2314 = Math_fround(HEAPF32[$2205>>2]);
   $2315 = ((($2282) + (($2252*56)|0)|0) + 8|0);
   HEAPF32[$2315>>2] = $2314;
   $2316 = Math_fround(HEAPF32[$2206>>2]);
   $2317 = ((($2282) + (($2252*56)|0)|0) + 12|0);
   HEAPF32[$2317>>2] = $2316;
   $2318 = Math_fround(HEAPF32[$2207>>2]);
   $2319 = ((($2282) + (($2252*56)|0)|0) + 16|0);
   HEAPF32[$2319>>2] = $2318;
   $2320 = Math_fround(HEAPF32[$2208>>2]);
   $2321 = ((($2282) + (($2252*56)|0)|0) + 20|0);
   HEAPF32[$2321>>2] = $2320;
   $2322 = Math_fround(HEAPF32[$2209>>2]);
   $2323 = ((($2282) + (($2252*56)|0)|0) + 24|0);
   HEAPF32[$2323>>2] = $2322;
   $2324 = Math_fround(HEAPF32[$2210>>2]);
   $2325 = (($2282) + (($2267*56)|0)|0);
   HEAPF32[$2325>>2] = $2324;
   $2326 = Math_fround(HEAPF32[$2211>>2]);
   $2327 = ((($2282) + (($2267*56)|0)|0) + 4|0);
   HEAPF32[$2327>>2] = $2326;
   $2328 = Math_fround(HEAPF32[$2212>>2]);
   $2329 = ((($2282) + (($2267*56)|0)|0) + 8|0);
   HEAPF32[$2329>>2] = $2328;
   $2330 = Math_fround(HEAPF32[$2213>>2]);
   $2331 = ((($2282) + (($2267*56)|0)|0) + 12|0);
   HEAPF32[$2331>>2] = $2330;
   $2332 = Math_fround(HEAPF32[$2214>>2]);
   $2333 = ((($2282) + (($2267*56)|0)|0) + 16|0);
   HEAPF32[$2333>>2] = $2332;
   $2334 = Math_fround(HEAPF32[$2215>>2]);
   $2335 = ((($2282) + (($2267*56)|0)|0) + 20|0);
   HEAPF32[$2335>>2] = $2334;
   $2336 = Math_fround(HEAPF32[$2216>>2]);
   $2337 = ((($2282) + (($2267*56)|0)|0) + 24|0);
   HEAPF32[$2337>>2] = $2336;
   $2338 = (($i9$092) + 1)|0;
   $exitcond = ($2338|0)==($48|0);
   if ($exitcond) {
    break;
   } else {
    $i9$092 = $2338;
   }
  }
 }
 $2339 = ($vehWheelQueryResults|0)==(0|0);
 do {
  if (!($2339)) {
   $2340 = HEAP32[$vehWheelQueryResults>>2]|0;
   $2341 = ($2340|0)==(0|0);
   if ($2341) {
    break;
   }
   $2342 = ($46*148)|0;
   _memcpy(($2340|0),($wheelQueryResults|0),($2342|0))|0;
  }
 } while(0);
 $2343 = ($vehConcurrentUpdates|0)==(0|0);
 if ($2343) {
  HEAP32[$vehWheels>>2] = $vehDrive4W;
  __ZN5physx15PxVehicleUpdate10updatePostEPKNS_29PxVehicleConcurrentUpdateDataEjPPNS_15PxVehicleWheelsE($vehicleConcurrentUpdates,1,$vehWheels);
  STACKTOP = sp;return;
 } else {
  $2344 = HEAP32[$vehConcurrentUpdates>>2]|0;
  $2345 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
  $2346 = ($46*56)|0;
  _memcpy(($2344|0),($2345|0),($2346|0))|0;
  $2347 = Math_fround(HEAPF32[$2013>>2]);
  $2348 = (($vehConcurrentUpdates) + 8|0);
  HEAPF32[$2348>>2] = $2347;
  $2349 = (($vehicleConcurrentUpdates) + 12|0);
  $2350 = Math_fround(HEAPF32[$2349>>2]);
  $2351 = (($vehConcurrentUpdates) + 12|0);
  HEAPF32[$2351>>2] = $2350;
  $2352 = (($vehicleConcurrentUpdates) + 16|0);
  $2353 = Math_fround(HEAPF32[$2352>>2]);
  $2354 = (($vehConcurrentUpdates) + 16|0);
  HEAPF32[$2354>>2] = $2353;
  $2355 = (($vehicleConcurrentUpdates) + 20|0);
  $2356 = Math_fround(HEAPF32[$2355>>2]);
  $2357 = (($vehConcurrentUpdates) + 20|0);
  HEAPF32[$2357>>2] = $2356;
  $2358 = (($vehicleConcurrentUpdates) + 24|0);
  $2359 = Math_fround(HEAPF32[$2358>>2]);
  $2360 = (($vehConcurrentUpdates) + 24|0);
  HEAPF32[$2360>>2] = $2359;
  $2361 = (($vehicleConcurrentUpdates) + 28|0);
  $2362 = Math_fround(HEAPF32[$2361>>2]);
  $2363 = (($vehConcurrentUpdates) + 28|0);
  HEAPF32[$2363>>2] = $2362;
  $2364 = (($vehicleConcurrentUpdates) + 32|0);
  $2365 = HEAP16[$2364>>1]|0;
  $2366 = $2365&255;
  $2367 = (($vehConcurrentUpdates) + 32|0);
  HEAP8[$2367>>0] = $2366;
  $2368 = ($2365&65535) >>> 8;
  $2369 = $2368&255;
  $2370 = (($vehConcurrentUpdates) + 33|0);
  HEAP8[$2370>>0] = $2369;
  STACKTOP = sp;return;
 }
}
function __ZN5physx36computeAckermannCorrectedSteerAnglesERKNS_23PxVehicleDriveSimData4WERKNS_23PxVehicleWheels4SimDataEfPf($driveSimData,$wheelsSimData,$steer,$steerAngles) {
 $driveSimData = $driveSimData|0;
 $wheelsSimData = $wheelsSimData|0;
 $steer = Math_fround($steer);
 $steerAngles = $steerAngles|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0.0, $15 = 0.0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0.0, $21 = 0.0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0.0, $51 = 0.0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0.0, $57 = 0.0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $8 = 0, $9 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i1 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($driveSimData) + 560|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($driveSimData) + 572|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($wheelsSimData) + 220|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($wheelsSimData) + 268|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $5 > $7;
 $9 = $8 ? $5 : $7;
 $10 = Math_fround($9 * $steer);
 $11 = $10 == Math_fround(0.0);
 if ($11) {
  $34 = Math_fround(0.0);$38 = Math_fround(0.0);
 } else {
  $12 = (($driveSimData) + 564|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $fabsf$i$i$i1 = (Math_fround(Math_abs((Math_fround($10)))));
  $14 = +$fabsf$i$i$i1;
  $15 = (+Math_tan((+$14)));
  $16 = Math_fround($15);
  $17 = Math_fround($3 / $16);
  $18 = Math_fround($13 + $17);
  $19 = Math_fround($3 / $18);
  $20 = +$19;
  $21 = (+Math_atan((+$20)));
  $22 = Math_fround($21);
  $23 = Math_fround($22 - $fabsf$i$i$i1);
  $24 = Math_fround($1 * $23);
  $25 = Math_fround($fabsf$i$i$i1 + $24);
  $26 = Math_fround(-$25);
  $27 = $10 >= Math_fround(0.0);
  $28 = $27 ? $fabsf$i$i$i1 : $26;
  $29 = Math_fround(-$fabsf$i$i$i1);
  $30 = $27 ? $25 : $29;
  $34 = $30;$38 = $28;
 }
 $31 = (($wheelsSimData) + 224|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($34 + $32);
 HEAPF32[$steerAngles>>2] = $33;
 $35 = (($wheelsSimData) + 272|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($38 + $36);
 $39 = (($steerAngles) + 4|0);
 HEAPF32[$39>>2] = $37;
 $40 = (($wheelsSimData) + 316|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($wheelsSimData) + 364|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = $41 > $43;
 $45 = $44 ? $41 : $43;
 $46 = Math_fround($45 * $steer);
 $47 = $46 == Math_fround(0.0);
 if ($47) {
  $70 = Math_fround(0.0);$75 = Math_fround(0.0);
  $67 = (($wheelsSimData) + 320|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($68 - $70);
  $71 = (($steerAngles) + 8|0);
  HEAPF32[$71>>2] = $69;
  $72 = (($wheelsSimData) + 368|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($73 - $75);
  $76 = (($steerAngles) + 12|0);
  HEAPF32[$76>>2] = $74;
  STACKTOP = sp;return;
 }
 $48 = (($driveSimData) + 568|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($46)))));
 $50 = +$fabsf$i$i$i;
 $51 = (+Math_tan((+$50)));
 $52 = Math_fround($51);
 $53 = Math_fround($3 / $52);
 $54 = Math_fround($49 + $53);
 $55 = Math_fround($3 / $54);
 $56 = +$55;
 $57 = (+Math_atan((+$56)));
 $58 = Math_fround($57);
 $59 = Math_fround($58 - $fabsf$i$i$i);
 $60 = Math_fround($1 * $59);
 $61 = Math_fround($fabsf$i$i$i + $60);
 $62 = Math_fround(-$61);
 $63 = $46 >= Math_fround(0.0);
 $64 = $63 ? $fabsf$i$i$i : $62;
 $65 = Math_fround(-$fabsf$i$i$i);
 $66 = $63 ? $61 : $65;
 $70 = $66;$75 = $64;
 $67 = (($wheelsSimData) + 320|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 - $70);
 $71 = (($steerAngles) + 8|0);
 HEAPF32[$71>>2] = $69;
 $72 = (($wheelsSimData) + 368|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 - $75);
 $76 = (($steerAngles) + 12|0);
 HEAPF32[$76>>2] = $74;
 STACKTOP = sp;return;
}
function __ZN5physx25PxVehicleConstraintShader21VehicleConstraintDataaSERKS1_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0);
 var $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0);
 var $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0;
 var $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0;
 var $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0;
 var $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0;
 var $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$this>>2] = $1;
 $2 = (($0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 4|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 8|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($0) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 12|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($0) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 16|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($0) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 20|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($0) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 24|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($0) + 28|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 28|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($0) + 32|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($this) + 32|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($0) + 36|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($this) + 36|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($0) + 40|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($this) + 40|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($0) + 44|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 44|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($0) + 48|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($this) + 48|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($0) + 52|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($this) + 52|0);
 HEAPF32[$40>>2] = $39;
 $41 = (($0) + 56|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 56|0);
 HEAPF32[$43>>2] = $42;
 $44 = (($0) + 60|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($this) + 60|0);
 HEAPF32[$46>>2] = $45;
 $47 = (($0) + 64|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($this) + 64|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($0) + 68|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($this) + 68|0);
 HEAPF32[$52>>2] = $51;
 $53 = (($0) + 72|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($this) + 72|0);
 HEAPF32[$55>>2] = $54;
 $56 = (($0) + 76|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($this) + 76|0);
 HEAPF32[$58>>2] = $57;
 $59 = (($0) + 80|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($this) + 80|0);
 HEAPF32[$61>>2] = $60;
 $62 = (($0) + 84|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($this) + 84|0);
 HEAPF32[$64>>2] = $63;
 $65 = (($0) + 88|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($this) + 88|0);
 HEAPF32[$67>>2] = $66;
 $68 = (($0) + 92|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($this) + 92|0);
 HEAPF32[$70>>2] = $69;
 $71 = (($this) + 96|0);
 $72 = (($0) + 96|0);
 ;HEAP32[$71+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$71+12>>2]=HEAP32[$72+12>>2]|0;HEAP32[$71+16>>2]=HEAP32[$72+16>>2]|0;
 $73 = (($0) + 116|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($this) + 116|0);
 HEAPF32[$75>>2] = $74;
 $76 = (($0) + 120|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($this) + 120|0);
 HEAPF32[$78>>2] = $77;
 $79 = (($0) + 124|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($this) + 124|0);
 HEAPF32[$81>>2] = $80;
 $82 = (($0) + 128|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($this) + 128|0);
 HEAPF32[$84>>2] = $83;
 $85 = (($0) + 132|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($this) + 132|0);
 HEAPF32[$87>>2] = $86;
 $88 = (($0) + 136|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($this) + 136|0);
 HEAPF32[$90>>2] = $89;
 $91 = (($0) + 140|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($this) + 140|0);
 HEAPF32[$93>>2] = $92;
 $94 = (($0) + 144|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($this) + 144|0);
 HEAPF32[$96>>2] = $95;
 $97 = (($0) + 148|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($this) + 148|0);
 HEAPF32[$99>>2] = $98;
 $100 = (($0) + 152|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($this) + 152|0);
 HEAPF32[$102>>2] = $101;
 $103 = (($0) + 156|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($this) + 156|0);
 HEAPF32[$105>>2] = $104;
 $106 = (($0) + 160|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($this) + 160|0);
 HEAPF32[$108>>2] = $107;
 $109 = (($0) + 164|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($this) + 164|0);
 HEAPF32[$111>>2] = $110;
 $112 = (($0) + 168|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($this) + 168|0);
 HEAPF32[$114>>2] = $113;
 $115 = (($0) + 172|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (($this) + 172|0);
 HEAPF32[$117>>2] = $116;
 $118 = (($0) + 176|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($this) + 176|0);
 HEAPF32[$120>>2] = $119;
 $121 = (($0) + 180|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($this) + 180|0);
 HEAPF32[$123>>2] = $122;
 $124 = (($0) + 184|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($this) + 184|0);
 HEAPF32[$126>>2] = $125;
 $127 = (($0) + 188|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($this) + 188|0);
 HEAPF32[$129>>2] = $128;
 $130 = (($0) + 192|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($this) + 192|0);
 HEAPF32[$132>>2] = $131;
 $133 = (($0) + 196|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($this) + 196|0);
 HEAPF32[$135>>2] = $134;
 $136 = (($0) + 200|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($this) + 200|0);
 HEAPF32[$138>>2] = $137;
 $139 = (($0) + 204|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($this) + 204|0);
 HEAPF32[$141>>2] = $140;
 $142 = (($0) + 208|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($this) + 208|0);
 HEAPF32[$144>>2] = $143;
 $145 = (($this) + 212|0);
 $146 = (($0) + 212|0);
 ;HEAP32[$145+0>>2]=HEAP32[$146+0>>2]|0;HEAP32[$145+4>>2]=HEAP32[$146+4>>2]|0;HEAP32[$145+8>>2]=HEAP32[$146+8>>2]|0;HEAP32[$145+12>>2]=HEAP32[$146+12>>2]|0;HEAP32[$145+16>>2]=HEAP32[$146+16>>2]|0;
 $147 = (($0) + 232|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = (($this) + 232|0);
 HEAPF32[$149>>2] = $148;
 $150 = (($0) + 236|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = (($this) + 236|0);
 HEAPF32[$152>>2] = $151;
 $153 = (($0) + 240|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($this) + 240|0);
 HEAPF32[$155>>2] = $154;
 $156 = (($0) + 244|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = (($this) + 244|0);
 HEAPF32[$158>>2] = $157;
 $159 = (($0) + 248|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($this) + 248|0);
 HEAPF32[$161>>2] = $160;
 $162 = (($0) + 252|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($this) + 252|0);
 HEAPF32[$164>>2] = $163;
 $165 = (($0) + 256|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = (($this) + 256|0);
 HEAPF32[$167>>2] = $166;
 $168 = (($0) + 260|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($this) + 260|0);
 HEAPF32[$170>>2] = $169;
 $171 = (($0) + 264|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = (($this) + 264|0);
 HEAPF32[$173>>2] = $172;
 $174 = (($0) + 268|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = (($this) + 268|0);
 HEAPF32[$176>>2] = $175;
 $177 = (($0) + 272|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = (($this) + 272|0);
 HEAPF32[$179>>2] = $178;
 $180 = (($0) + 276|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = (($this) + 276|0);
 HEAPF32[$182>>2] = $181;
 $183 = (($0) + 280|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = (($this) + 280|0);
 HEAPF32[$185>>2] = $184;
 $186 = (($0) + 284|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = (($this) + 284|0);
 HEAPF32[$188>>2] = $187;
 $189 = (($0) + 288|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($this) + 288|0);
 HEAPF32[$191>>2] = $190;
 $192 = (($0) + 292|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($this) + 292|0);
 HEAPF32[$194>>2] = $193;
 $195 = (($0) + 296|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($this) + 296|0);
 HEAPF32[$197>>2] = $196;
 $198 = (($0) + 300|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($this) + 300|0);
 HEAPF32[$200>>2] = $199;
 $201 = (($0) + 304|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($this) + 304|0);
 HEAPF32[$203>>2] = $202;
 $204 = (($0) + 308|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($this) + 308|0);
 HEAPF32[$206>>2] = $205;
 $207 = (($0) + 312|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($this) + 312|0);
 HEAPF32[$209>>2] = $208;
 $210 = (($0) + 316|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = (($this) + 316|0);
 HEAPF32[$212>>2] = $211;
 $213 = (($0) + 320|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = (($this) + 320|0);
 HEAPF32[$215>>2] = $214;
 $216 = (($0) + 324|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = (($this) + 324|0);
 HEAPF32[$218>>2] = $217;
 $219 = (($this) + 328|0);
 $220 = (($0) + 328|0);
 ;HEAP32[$219+0>>2]=HEAP32[$220+0>>2]|0;HEAP32[$219+4>>2]=HEAP32[$220+4>>2]|0;HEAP32[$219+8>>2]=HEAP32[$220+8>>2]|0;HEAP32[$219+12>>2]=HEAP32[$220+12>>2]|0;HEAP32[$219+16>>2]=HEAP32[$220+16>>2]|0;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx15PxVehicleUpdate25storeSuspWheelTireResultsERKNS_30ProcessSuspWheelTireOutputDataEPKfPNS_18PxWheelQueryResultEj($outputData,$steerAngles,$wheelQueryResults,$numWheels) {
 $outputData = $outputData|0;
 $steerAngles = $steerAngles|0;
 $wheelQueryResults = $wheelQueryResults|0;
 $numWheels = $numWheels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numWheels|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $1 = ((($outputData) + ($i$01)|0) + 112|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 28|0);
  HEAP8[$3>>0] = $2;
  $4 = ((($outputData) + ($i$01<<2)|0) + 116|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 32|0);
  HEAP32[$6>>2] = $5;
  $7 = ((($outputData) + ($i$01<<2)|0) + 132|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 36|0);
  HEAP32[$9>>2] = $8;
  $10 = ((($outputData) + ($i$01<<2)|0) + 148|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 40|0);
  HEAP32[$12>>2] = $11;
  $13 = ((($outputData) + ($i$01<<2)|0) + 164|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 44|0);
  HEAP32[$15>>2] = $14;
  $16 = ((($outputData) + (($i$01*12)|0)|0) + 180|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 48|0);
  HEAPF32[$18>>2] = $17;
  $19 = ((($outputData) + (($i$01*12)|0)|0) + 184|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 52|0);
  HEAPF32[$21>>2] = $20;
  $22 = ((($outputData) + (($i$01*12)|0)|0) + 188|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 56|0);
  HEAPF32[$24>>2] = $23;
  $25 = ((($outputData) + (($i$01*12)|0)|0) + 228|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 60|0);
  HEAPF32[$27>>2] = $26;
  $28 = ((($outputData) + (($i$01*12)|0)|0) + 232|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 64|0);
  HEAPF32[$30>>2] = $29;
  $31 = ((($outputData) + (($i$01*12)|0)|0) + 236|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 68|0);
  HEAPF32[$33>>2] = $32;
  $34 = ((($outputData) + ($i$01<<2)|0) + 276|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 72|0);
  HEAPF32[$36>>2] = $35;
  $37 = ((($outputData) + ($i$01<<2)|0) + 292|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 76|0);
  HEAPF32[$39>>2] = $38;
  $40 = ((($outputData) + ($i$01<<2)|0) + 308|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 80|0);
  HEAPF32[$42>>2] = $41;
  $43 = ((($outputData) + (($i$01*12)|0)|0) + 324|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 84|0);
  HEAPF32[$45>>2] = $44;
  $46 = ((($outputData) + (($i$01*12)|0)|0) + 328|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 88|0);
  HEAPF32[$48>>2] = $47;
  $49 = ((($outputData) + (($i$01*12)|0)|0) + 332|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 92|0);
  HEAPF32[$51>>2] = $50;
  $52 = ((($outputData) + (($i$01*12)|0)|0) + 372|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 96|0);
  HEAPF32[$54>>2] = $53;
  $55 = ((($outputData) + (($i$01*12)|0)|0) + 376|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 100|0);
  HEAPF32[$57>>2] = $56;
  $58 = ((($outputData) + (($i$01*12)|0)|0) + 380|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 104|0);
  HEAPF32[$60>>2] = $59;
  $61 = ((($outputData) + ($i$01<<2)|0) + 420|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 108|0);
  HEAPF32[$63>>2] = $62;
  $64 = ((($outputData) + ($i$01<<2)|0) + 436|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 112|0);
  HEAPF32[$66>>2] = $65;
  $67 = (($steerAngles) + ($i$01<<2)|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = ((($wheelQueryResults) + (($i$01*148)|0)|0) + 116|0);
  HEAPF32[$69>>2] = $68;
  $70 = (($i$01) + 1)|0;
  $exitcond = ($70|0)==($numWheels|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $70;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx23computeDiffTorqueRatiosERKNS_27PxVehicleDifferential4WDataEfPKfPf($diffData,$handbrake,$wheelOmegas,$diffTorqueRatios) {
 $diffData = $diffData|0;
 $handbrake = Math_fround($handbrake);
 $wheelOmegas = $wheelOmegas|0;
 $diffTorqueRatios = $diffTorqueRatios|0;
 var $$v$i = Math_fround(0), $$v$i12 = Math_fround(0), $$v$i16 = Math_fround(0), $$v$i3 = Math_fround(0), $$v$i8 = Math_fround(0), $$v2$i = Math_fround(0), $$v2$i13 = Math_fround(0), $$v2$i17 = Math_fround(0), $$v2$i4 = Math_fround(0), $$v2$i9 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0;
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0);
 var $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0);
 var $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0;
 var $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i1 = Math_fround(0), $fabsf$i$i$i10 = Math_fround(0), $fabsf$i$i$i14 = Math_fround(0), $fabsf$i$i$i6 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i11 = Math_fround(0), $fabsf$i$i1$i15 = Math_fround(0), $fabsf$i$i1$i2 = Math_fround(0), $fabsf$i$i1$i7 = Math_fround(0), $fabsf$i$i5 = Math_fround(0), $type$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($diffData) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $handbrake > Math_fround(0.0);
 do {
  if ($2) {
   if ((($1|0) == 3)) {
    $type$0 = 4;
    break;
   } else if ((($1|0) == 0)) {
    $type$0 = 1;
    break;
   } else {
    $type$0 = $1;
    break;
   }
  } else {
   $type$0 = $1;
  }
 } while(0);
 $3 = Math_fround(HEAPF32[$wheelOmegas>>2]);
 $4 = (($wheelOmegas) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($wheelOmegas) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($wheelOmegas) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($diffData) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($diffData) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($diffData) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$diffData>>2]);
 $17 = (($diffData) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($diffData) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(Math_fround(1.0) - $16);
 $22 = Math_fround(Math_fround(1.0) - $18);
 $23 = Math_fround(Math_fround(1.0) - $20);
 $24 = $3 <= Math_fround(-0.0);
 $25 = $24 ? Math_fround(0.0) : Math_fround(1.0);
 $26 = $3 >= Math_fround(0.0);
 $27 = $26 ? $25 : Math_fround(-1.0);
 L7: do {
  switch ($type$0|0) {
  case 3:  {
   $165 = Math_fround($16 * $18);
   $166 = Math_fround($16 * $22);
   $167 = Math_fround($21 * $20);
   $168 = Math_fround($21 * $23);
   $169 = $165;$171 = $166;$173 = $167;$175 = $168;
   break;
  }
  case 0:  {
   $28 = $27 != Math_fround(0.0);
   if ($28) {
    $29 = $5 <= Math_fround(-0.0);
    $30 = $29 ? Math_fround(0.0) : Math_fround(1.0);
    $31 = $5 >= Math_fround(0.0);
    $32 = $31 ? $30 : Math_fround(-1.0);
    $33 = $27 == $32;
    if ($33) {
     $34 = $7 <= Math_fround(-0.0);
     $35 = $34 ? Math_fround(0.0) : Math_fround(1.0);
     $36 = $7 >= Math_fround(0.0);
     $37 = $36 ? $35 : Math_fround(-1.0);
     $38 = $27 == $37;
     if ($38) {
      $39 = $9 <= Math_fround(-0.0);
      $40 = $39 ? Math_fround(0.0) : Math_fround(1.0);
      $41 = $9 >= Math_fround(0.0);
      $42 = $41 ? $40 : Math_fround(-1.0);
      $43 = $27 == $42;
      if ($43) {
       $44 = Math_fround($3 + $5);
       $fabsf$i$i = (Math_fround(Math_abs((Math_fround($44)))));
       $45 = Math_fround($7 + $9);
       $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($45)))));
       $fabsf$i$i$i6 = (Math_fround(Math_abs((Math_fround($fabsf$i$i)))));
       $fabsf$i$i1$i7 = (Math_fround(Math_abs((Math_fround($fabsf$i$i5)))));
       $46 = $fabsf$i$i$i6 > $fabsf$i$i1$i7;
       $47 = $46 ? $fabsf$i$i$i6 : $fabsf$i$i1$i7;
       $48 = $fabsf$i$i$i6 < $fabsf$i$i1$i7;
       $49 = $48 ? $fabsf$i$i$i6 : $fabsf$i$i1$i7;
       $50 = Math_fround($11 * $49);
       $51 = Math_fround($47 - $50);
       $52 = Math_fround($51 / $47);
       $53 = $51 >= Math_fround(0.0);
       $54 = $53 ? $52 : Math_fround(0.0);
       $55 = Math_fround($fabsf$i$i$i6 - $fabsf$i$i1$i7);
       $56 = Math_fround(Math_fround(1.0) - $54);
       $57 = Math_fround($54 + Math_fround(1.0));
       $58 = $55 >= Math_fround(0.0);
       $$v$i8 = $58 ? $56 : $57;
       $59 = Math_fround($16 * $$v$i8);
       $$v2$i9 = $58 ? $57 : $56;
       $60 = Math_fround($21 * $$v2$i9);
       $61 = Math_fround($59 + $60);
       $62 = Math_fround(Math_fround(1.0) / $61);
       $63 = Math_fround($62 * $59);
       $64 = Math_fround($62 * $60);
       $fabsf$i$i$i10 = (Math_fround(Math_abs((Math_fround($3)))));
       $fabsf$i$i1$i11 = (Math_fround(Math_abs((Math_fround($5)))));
       $65 = $fabsf$i$i$i10 > $fabsf$i$i1$i11;
       $66 = $65 ? $fabsf$i$i$i10 : $fabsf$i$i1$i11;
       $67 = $fabsf$i$i$i10 < $fabsf$i$i1$i11;
       $68 = $67 ? $fabsf$i$i$i10 : $fabsf$i$i1$i11;
       $69 = Math_fround($13 * $68);
       $70 = Math_fround($66 - $69);
       $71 = Math_fround($70 / $66);
       $72 = $70 >= Math_fround(0.0);
       $73 = $72 ? $71 : Math_fround(0.0);
       $74 = Math_fround($fabsf$i$i$i10 - $fabsf$i$i1$i11);
       $75 = Math_fround(Math_fround(1.0) - $73);
       $76 = Math_fround($73 + Math_fround(1.0));
       $77 = $74 >= Math_fround(0.0);
       $$v$i12 = $77 ? $75 : $76;
       $78 = Math_fround($18 * $$v$i12);
       $$v2$i13 = $77 ? $76 : $75;
       $79 = Math_fround($22 * $$v2$i13);
       $80 = Math_fround($78 + $79);
       $81 = Math_fround(Math_fround(1.0) / $80);
       $82 = Math_fround($81 * $78);
       $83 = Math_fround($81 * $79);
       $fabsf$i$i$i14 = (Math_fround(Math_abs((Math_fround($7)))));
       $fabsf$i$i1$i15 = (Math_fround(Math_abs((Math_fround($9)))));
       $84 = $fabsf$i$i$i14 > $fabsf$i$i1$i15;
       $85 = $84 ? $fabsf$i$i$i14 : $fabsf$i$i1$i15;
       $86 = $fabsf$i$i$i14 < $fabsf$i$i1$i15;
       $87 = $86 ? $fabsf$i$i$i14 : $fabsf$i$i1$i15;
       $88 = Math_fround($15 * $87);
       $89 = Math_fround($85 - $88);
       $90 = Math_fround($89 / $85);
       $91 = $89 >= Math_fround(0.0);
       $92 = $91 ? $90 : Math_fround(0.0);
       $93 = Math_fround($fabsf$i$i$i14 - $fabsf$i$i1$i15);
       $94 = Math_fround(Math_fround(1.0) - $92);
       $95 = Math_fround($92 + Math_fround(1.0));
       $96 = $93 >= Math_fround(0.0);
       $$v$i16 = $96 ? $94 : $95;
       $97 = Math_fround($20 * $$v$i16);
       $$v2$i17 = $96 ? $95 : $94;
       $98 = Math_fround($23 * $$v2$i17);
       $99 = Math_fround($97 + $98);
       $100 = Math_fround(Math_fround(1.0) / $99);
       $101 = Math_fround($100 * $97);
       $102 = Math_fround($100 * $98);
       $103 = Math_fround($63 * $82);
       $104 = Math_fround($63 * $83);
       $105 = Math_fround($64 * $101);
       $106 = Math_fround($64 * $102);
       $169 = $103;$171 = $104;$173 = $105;$175 = $106;
       break L7;
      }
     }
    }
   }
   $107 = Math_fround($16 * $18);
   $108 = Math_fround($16 * $22);
   $109 = Math_fround($21 * $20);
   $110 = Math_fround($21 * $23);
   $169 = $107;$171 = $108;$173 = $109;$175 = $110;
   break;
  }
  case 2:  {
   $136 = $7 <= Math_fround(-0.0);
   $137 = $136 ? Math_fround(0.0) : Math_fround(1.0);
   $138 = $7 >= Math_fround(0.0);
   $139 = $138 ? $137 : Math_fround(-1.0);
   $140 = $139 != Math_fround(0.0);
   if ($140) {
    $141 = $9 <= Math_fround(-0.0);
    $142 = $141 ? Math_fround(0.0) : Math_fround(1.0);
    $143 = $9 >= Math_fround(0.0);
    $144 = $143 ? $142 : Math_fround(-1.0);
    $145 = $139 == $144;
    if ($145) {
     $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($7)))));
     $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($9)))));
     $146 = $fabsf$i$i$i > $fabsf$i$i1$i;
     $147 = $146 ? $fabsf$i$i$i : $fabsf$i$i1$i;
     $148 = $fabsf$i$i$i < $fabsf$i$i1$i;
     $149 = $148 ? $fabsf$i$i$i : $fabsf$i$i1$i;
     $150 = Math_fround($15 * $149);
     $151 = Math_fround($147 - $150);
     $152 = Math_fround($151 / $147);
     $153 = $151 >= Math_fround(0.0);
     $154 = $153 ? $152 : Math_fround(0.0);
     $155 = Math_fround($fabsf$i$i$i - $fabsf$i$i1$i);
     $156 = Math_fround(Math_fround(1.0) - $154);
     $157 = Math_fround($154 + Math_fround(1.0));
     $158 = $155 >= Math_fround(0.0);
     $$v$i = $158 ? $156 : $157;
     $159 = Math_fround($20 * $$v$i);
     $$v2$i = $158 ? $157 : $156;
     $160 = Math_fround($23 * $$v2$i);
     $161 = Math_fround($159 + $160);
     $162 = Math_fround(Math_fround(1.0) / $161);
     $163 = Math_fround($162 * $159);
     $164 = Math_fround($162 * $160);
     $169 = Math_fround(0.0);$171 = Math_fround(0.0);$173 = $163;$175 = $164;
    } else {
     $169 = Math_fround(0.0);$171 = Math_fround(0.0);$173 = $20;$175 = $23;
    }
   } else {
    $169 = Math_fround(0.0);$171 = Math_fround(0.0);$173 = $20;$175 = $23;
   }
   break;
  }
  case 1:  {
   $111 = $27 != Math_fround(0.0);
   if ($111) {
    $112 = $5 <= Math_fround(-0.0);
    $113 = $112 ? Math_fround(0.0) : Math_fround(1.0);
    $114 = $5 >= Math_fround(0.0);
    $115 = $114 ? $113 : Math_fround(-1.0);
    $116 = $27 == $115;
    if ($116) {
     $fabsf$i$i$i1 = (Math_fround(Math_abs((Math_fround($3)))));
     $fabsf$i$i1$i2 = (Math_fround(Math_abs((Math_fround($5)))));
     $117 = $fabsf$i$i$i1 > $fabsf$i$i1$i2;
     $118 = $117 ? $fabsf$i$i$i1 : $fabsf$i$i1$i2;
     $119 = $fabsf$i$i$i1 < $fabsf$i$i1$i2;
     $120 = $119 ? $fabsf$i$i$i1 : $fabsf$i$i1$i2;
     $121 = Math_fround($13 * $120);
     $122 = Math_fround($118 - $121);
     $123 = Math_fround($122 / $118);
     $124 = $122 >= Math_fround(0.0);
     $125 = $124 ? $123 : Math_fround(0.0);
     $126 = Math_fround($fabsf$i$i$i1 - $fabsf$i$i1$i2);
     $127 = Math_fround(Math_fround(1.0) - $125);
     $128 = Math_fround($125 + Math_fround(1.0));
     $129 = $126 >= Math_fround(0.0);
     $$v$i3 = $129 ? $127 : $128;
     $130 = Math_fround($18 * $$v$i3);
     $$v2$i4 = $129 ? $128 : $127;
     $131 = Math_fround($22 * $$v2$i4);
     $132 = Math_fround($130 + $131);
     $133 = Math_fround(Math_fround(1.0) / $132);
     $134 = Math_fround($133 * $130);
     $135 = Math_fround($133 * $131);
     $169 = $134;$171 = $135;$173 = Math_fround(0.0);$175 = Math_fround(0.0);
    } else {
     $169 = $18;$171 = $22;$173 = Math_fround(0.0);$175 = Math_fround(0.0);
    }
   } else {
    $169 = $18;$171 = $22;$173 = Math_fround(0.0);$175 = Math_fround(0.0);
   }
   break;
  }
  case 5:  {
   $169 = Math_fround(0.0);$171 = Math_fround(0.0);$173 = $20;$175 = $23;
   break;
  }
  case 4:  {
   $169 = $18;$171 = $22;$173 = Math_fround(0.0);$175 = Math_fround(0.0);
   break;
  }
  default: {
   $169 = Math_fround(0.0);$171 = Math_fround(0.0);$173 = Math_fround(0.0);$175 = Math_fround(0.0);
  }
  }
 } while(0);
 HEAPF32[$diffTorqueRatios>>2] = $169;
 $170 = (($diffTorqueRatios) + 4|0);
 HEAPF32[$170>>2] = $171;
 $172 = (($diffTorqueRatios) + 8|0);
 HEAPF32[$172>>2] = $173;
 $174 = (($diffTorqueRatios) + 12|0);
 HEAPF32[$174>>2] = $175;
 STACKTOP = sp;return;
}
function __ZN5physx13integrateBodyEfRKNS_6PxVec3ES2_S2_fRS0_S3_RNS_11PxTransformE($inverseMass,$invInertia,$force,$torque,$dt,$v,$w,$t) {
 $inverseMass = Math_fround($inverseMass);
 $invInertia = $invInertia|0;
 $force = $force|0;
 $torque = $torque|0;
 $dt = Math_fround($dt);
 $v = $v|0;
 $w = $w|0;
 $t = $t|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($inverseMass * $dt);
 $1 = Math_fround(HEAPF32[$force>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($force) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($0 * $4);
 $6 = (($force) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($0 * $7);
 $9 = Math_fround(HEAPF32[$v>>2]);
 $10 = Math_fround($2 + $9);
 HEAPF32[$v>>2] = $10;
 $11 = (($v) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($5 + $12);
 HEAPF32[$11>>2] = $13;
 $14 = (($v) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($8 + $15);
 HEAPF32[$14>>2] = $16;
 $17 = Math_fround(HEAPF32[$t>>2]);
 $18 = (($t) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($t) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($t) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($17 + $17);
 $25 = Math_fround($19 + $19);
 $26 = Math_fround($21 + $21);
 $27 = Math_fround($17 * $24);
 $28 = Math_fround($19 * $25);
 $29 = Math_fround($21 * $26);
 $30 = Math_fround($24 * $19);
 $31 = Math_fround($24 * $21);
 $32 = Math_fround($24 * $23);
 $33 = Math_fround($25 * $21);
 $34 = Math_fround($25 * $23);
 $35 = Math_fround($26 * $23);
 $36 = Math_fround(Math_fround(1.0) - $28);
 $37 = Math_fround($36 - $29);
 $38 = Math_fround($30 + $35);
 $39 = Math_fround($31 - $34);
 $40 = Math_fround($30 - $35);
 $41 = Math_fround(Math_fround(1.0) - $27);
 $42 = Math_fround($41 - $29);
 $43 = Math_fround($33 + $32);
 $44 = Math_fround($31 + $34);
 $45 = Math_fround($33 - $32);
 $46 = Math_fround($41 - $28);
 $47 = Math_fround(HEAPF32[$invInertia>>2]);
 $48 = Math_fround($47 * $37);
 $49 = Math_fround($47 * $38);
 $50 = Math_fround($47 * $39);
 $51 = (($invInertia) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 * $40);
 $54 = Math_fround($52 * $42);
 $55 = Math_fround($52 * $43);
 $56 = (($invInertia) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($44 * $57);
 $59 = Math_fround($45 * $57);
 $60 = Math_fround($46 * $57);
 $61 = Math_fround($37 * $48);
 $62 = Math_fround($40 * $53);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($44 * $58);
 $65 = Math_fround($63 + $64);
 $66 = Math_fround($38 * $49);
 $67 = Math_fround($42 * $54);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($45 * $59);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($39 * $50);
 $72 = Math_fround($43 * $55);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($46 * $60);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($38 * $48);
 $77 = Math_fround($42 * $53);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($45 * $58);
 $80 = Math_fround($78 + $79);
 $81 = Math_fround($39 * $48);
 $82 = Math_fround($43 * $53);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($46 * $58);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($39 * $49);
 $87 = Math_fround($43 * $54);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($46 * $59);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround(HEAPF32[$torque>>2]);
 $92 = Math_fround($91 * $dt);
 $93 = (($torque) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 * $dt);
 $96 = (($torque) + 8|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 * $dt);
 $99 = Math_fround($92 * $65);
 $100 = Math_fround($92 * $80);
 $101 = Math_fround($92 * $85);
 $102 = Math_fround($95 * $80);
 $103 = Math_fround($95 * $70);
 $104 = Math_fround($95 * $90);
 $105 = Math_fround($99 + $102);
 $106 = Math_fround($100 + $103);
 $107 = Math_fround($101 + $104);
 $108 = Math_fround($85 * $98);
 $109 = Math_fround($90 * $98);
 $110 = Math_fround($75 * $98);
 $111 = Math_fround($105 + $108);
 $112 = Math_fround($106 + $109);
 $113 = Math_fround($107 + $110);
 $114 = Math_fround(HEAPF32[$w>>2]);
 $115 = Math_fround($114 + $111);
 HEAPF32[$w>>2] = $115;
 $116 = (($w) + 4|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($117 + $112);
 HEAPF32[$116>>2] = $118;
 $119 = (($w) + 8|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($113 + $120);
 HEAPF32[$119>>2] = $121;
 $122 = Math_fround(HEAPF32[$v>>2]);
 $123 = Math_fround($122 * $dt);
 $124 = Math_fround(HEAPF32[$11>>2]);
 $125 = Math_fround($124 * $dt);
 $126 = Math_fround(HEAPF32[$14>>2]);
 $127 = Math_fround($126 * $dt);
 $128 = (($t) + 16|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($123 + $129);
 HEAPF32[$128>>2] = $130;
 $131 = (($t) + 20|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($125 + $132);
 HEAPF32[$131>>2] = $133;
 $134 = (($t) + 24|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($127 + $135);
 HEAPF32[$134>>2] = $136;
 $137 = Math_fround(HEAPF32[$w>>2]);
 $138 = Math_fround(HEAPF32[$116>>2]);
 $139 = Math_fround(HEAPF32[$119>>2]);
 $140 = Math_fround(HEAPF32[$t>>2]);
 $141 = Math_fround(HEAPF32[$18>>2]);
 $142 = Math_fround(HEAPF32[$20>>2]);
 $143 = Math_fround(HEAPF32[$22>>2]);
 $144 = Math_fround($140 * Math_fround(0.0));
 $145 = Math_fround($137 * $143);
 $146 = Math_fround($144 + $145);
 $147 = Math_fround($138 * $142);
 $148 = Math_fround($147 + $146);
 $149 = Math_fround($139 * $141);
 $150 = Math_fround($148 - $149);
 $151 = Math_fround($141 * Math_fround(0.0));
 $152 = Math_fround($138 * $143);
 $153 = Math_fround($151 + $152);
 $154 = Math_fround($139 * $140);
 $155 = Math_fround($154 + $153);
 $156 = Math_fround($137 * $142);
 $157 = Math_fround($155 - $156);
 $158 = Math_fround($142 * Math_fround(0.0));
 $159 = Math_fround($139 * $143);
 $160 = Math_fround($158 + $159);
 $161 = Math_fround($137 * $141);
 $162 = Math_fround($161 + $160);
 $163 = Math_fround($138 * $140);
 $164 = Math_fround($162 - $163);
 $165 = Math_fround($143 * Math_fround(0.0));
 $166 = Math_fround($137 * $140);
 $167 = Math_fround($165 - $166);
 $168 = Math_fround($138 * $141);
 $169 = Math_fround($167 - $168);
 $170 = Math_fround($139 * $142);
 $171 = Math_fround($169 - $170);
 $172 = Math_fround($dt * Math_fround(0.5));
 $173 = Math_fround($172 * $150);
 $174 = Math_fround($172 * $157);
 $175 = Math_fround($172 * $164);
 $176 = Math_fround($172 * $171);
 $177 = Math_fround($140 + $173);
 $178 = Math_fround($141 + $174);
 $179 = Math_fround($142 + $175);
 $180 = Math_fround($143 + $176);
 $181 = Math_fround($177 * $177);
 $182 = Math_fround($178 * $178);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround($179 * $179);
 $185 = Math_fround($184 + $183);
 $186 = Math_fround($180 * $180);
 $187 = Math_fround($186 + $185);
 $188 = (Math_fround(Math_sqrt((Math_fround($187)))));
 $189 = $188 != Math_fround(0.0);
 if (!($189)) {
  $195 = $177;$196 = $178;$197 = $179;$198 = $180;
  HEAPF32[$t>>2] = $195;
  HEAPF32[$18>>2] = $196;
  HEAPF32[$20>>2] = $197;
  HEAPF32[$22>>2] = $198;
  STACKTOP = sp;return;
 }
 $190 = Math_fround(Math_fround(1.0) / $188);
 $191 = Math_fround($177 * $190);
 $192 = Math_fround($178 * $190);
 $193 = Math_fround($179 * $190);
 $194 = Math_fround($180 * $190);
 $195 = $191;$196 = $192;$197 = $193;$198 = $194;
 HEAPF32[$t>>2] = $195;
 HEAPF32[$18>>2] = $196;
 HEAPF32[$20>>2] = $197;
 HEAPF32[$22>>2] = $198;
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleUpdate13updateDriveNWEfRKNS_6PxVec3EffRKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEPNS_16PxVehicleDriveNWEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$gravityMagnitude,$recipGravityMagnitude,$drivableSurfaceToTireFrictionPairs,$vehDriveNW,$vehWheelQueryResults,$vehConcurrentUpdates) {
 $timestep = Math_fround($timestep);
 $gravity = $gravity|0;
 $gravityMagnitude = Math_fround($gravityMagnitude);
 $recipGravityMagnitude = Math_fround($recipGravityMagnitude);
 $drivableSurfaceToTireFrictionPairs = $drivableSurfaceToTireFrictionPairs|0;
 $vehDriveNW = $vehDriveNW|0;
 $vehWheelQueryResults = $vehWheelQueryResults|0;
 $vehConcurrentUpdates = $vehConcurrentUpdates|0;
 var $$$i = Math_fround(0), $$0$i$i = Math_fround(0), $$not = 0, $$pre218 = Math_fround(0), $$pre219 = Math_fround(0), $$pre220 = Math_fround(0), $$pre221 = Math_fround(0), $$pre222 = Math_fround(0), $$pre223 = Math_fround(0), $$pre224 = Math_fround(0), $$pre225 = Math_fround(0), $$pre226 = Math_fround(0), $$pre227 = Math_fround(0), $$pre228 = Math_fround(0), $$pre229 = 0, $$pre231 = 0, $$promoted = Math_fround(0), $$promoted120 = Math_fround(0), $$promoted121 = Math_fround(0), $$promoted122 = Math_fround(0);
 var $$promoted123 = Math_fround(0), $$promoted124 = Math_fround(0), $$sum = 0, $$sum101102 = 0, $$sum105106 = 0, $$sum107108 = 0, $$sum109110 = 0, $$sum26 = 0, $$sum3334 = 0, $$sum3738 = 0, $$sum4142 = 0, $$sum4546 = 0, $$sum5960 = 0, $$sum7374 = 0, $$sum8788 = 0, $$sum8990 = 0, $$sum9192 = 0, $$sum9394 = 0, $$sum9798 = 0, $$val = Math_fround(0);
 var $$val24 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = 0, $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = 0, $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0);
 var $1014 = 0, $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = 0, $1019 = Math_fround(0), $102 = 0, $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = 0, $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0;
 var $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = Math_fround(0), $1039 = 0, $104 = 0, $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = 0, $1043 = Math_fround(0), $1044 = 0, $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = 0, $1048 = Math_fround(0), $1049 = 0, $105 = 0;
 var $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = 0, $1053 = Math_fround(0), $1054 = 0, $1055 = 0, $1056 = Math_fround(0), $1057 = 0, $1058 = 0, $1059 = Math_fround(0), $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = Math_fround(0), $1065 = 0, $1066 = 0, $1067 = 0, $1068 = Math_fround(0);
 var $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = Math_fround(0), $1073 = 0, $1074 = 0, $1075 = 0, $1076 = Math_fround(0), $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = 0, $1086 = Math_fround(0);
 var $1087 = 0, $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = Math_fround(0), $1095 = 0, $1096 = 0, $1097 = Math_fround(0), $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0);
 var $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = 0, $1113 = 0, $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0;
 var $1122 = Math_fround(0), $1123 = 0, $1124 = Math_fround(0), $1125 = 0, $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = 0, $1137 = 0, $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = 0;
 var $1140 = 0, $1141 = 0, $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = 0, $1150 = 0, $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = 0, $1158 = Math_fround(0);
 var $1159 = 0, $116 = 0, $1160 = Math_fround(0), $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = Math_fround(0), $1168 = Math_fround(0), $1169 = 0, $117 = 0, $1170 = Math_fround(0), $1171 = 0, $1172 = Math_fround(0), $1173 = 0, $1174 = Math_fround(0), $1175 = 0, $1176 = Math_fround(0);
 var $1177 = 0, $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = 0, $1180 = Math_fround(0), $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0), $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = 0, $1187 = 0, $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = 0, $1190 = Math_fround(0), $1191 = Math_fround(0), $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = Math_fround(0);
 var $1195 = Math_fround(0), $1196 = Math_fround(0), $1197 = Math_fround(0), $1198 = Math_fround(0), $1199 = Math_fround(0), $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0;
 var $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0;
 var $1230 = 0, $1231 = Math_fround(0), $1232 = 0, $1233 = Math_fround(0), $1234 = 0, $1235 = Math_fround(0), $1236 = 0, $1237 = Math_fround(0), $1238 = 0, $1239 = Math_fround(0), $124 = 0, $1240 = 0, $1241 = Math_fround(0), $1242 = 0, $1243 = Math_fround(0), $1244 = 0, $1245 = Math_fround(0), $1246 = 0, $1247 = Math_fround(0), $1248 = 0;
 var $1249 = Math_fround(0), $125 = 0, $1250 = 0, $1251 = Math_fround(0), $1252 = 0, $1253 = Math_fround(0), $1254 = 0, $1255 = Math_fround(0), $1256 = 0, $1257 = Math_fround(0), $1258 = 0, $1259 = Math_fround(0), $126 = 0, $1260 = 0, $1261 = Math_fround(0), $1262 = 0, $1263 = Math_fround(0), $1264 = 0, $1265 = Math_fround(0), $1266 = 0;
 var $1267 = Math_fround(0), $1268 = 0, $1269 = Math_fround(0), $127 = 0, $1270 = 0, $1271 = Math_fround(0), $1272 = 0, $1273 = Math_fround(0), $1274 = 0, $1275 = Math_fround(0), $1276 = 0, $1277 = Math_fround(0), $1278 = 0, $1279 = Math_fround(0), $128 = 0, $1280 = 0, $1281 = Math_fround(0), $1282 = 0, $1283 = Math_fround(0), $1284 = 0;
 var $1285 = Math_fround(0), $1286 = 0, $1287 = 0, $1288 = Math_fround(0), $1289 = 0, $129 = 0, $1290 = Math_fround(0), $1291 = 0, $1292 = Math_fround(0), $1293 = 0, $1294 = Math_fround(0), $1295 = 0, $1296 = Math_fround(0), $1297 = 0, $1298 = Math_fround(0), $1299 = 0, $13 = 0, $130 = 0, $1300 = Math_fround(0), $1301 = 0;
 var $1302 = Math_fround(0), $1303 = 0, $1304 = Math_fround(0), $1305 = 0, $1306 = Math_fround(0), $1307 = 0, $1308 = Math_fround(0), $1309 = 0, $131 = 0, $1310 = Math_fround(0), $1311 = 0, $1312 = Math_fround(0), $1313 = 0, $1314 = Math_fround(0), $1315 = 0, $1316 = Math_fround(0), $1317 = 0, $1318 = Math_fround(0), $1319 = 0, $132 = 0;
 var $1320 = Math_fround(0), $1321 = 0, $1322 = Math_fround(0), $1323 = 0, $1324 = Math_fround(0), $1325 = 0, $1326 = Math_fround(0), $1327 = 0, $1328 = Math_fround(0), $1329 = 0, $133 = 0, $1330 = Math_fround(0), $1331 = 0, $1332 = Math_fround(0), $1333 = 0, $1334 = Math_fround(0), $1335 = 0, $1336 = Math_fround(0), $1337 = 0, $1338 = Math_fround(0);
 var $1339 = 0, $134 = 0, $1340 = Math_fround(0), $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0;
 var $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0;
 var $1375 = 0, $1376 = Math_fround(0), $1377 = 0, $1378 = Math_fround(0), $1379 = 0, $138 = 0, $1380 = Math_fround(0), $1381 = 0, $1382 = Math_fround(0), $1383 = 0, $1384 = Math_fround(0), $1385 = 0, $1386 = Math_fround(0), $1387 = 0, $1388 = Math_fround(0), $1389 = 0, $139 = 0, $1390 = 0, $1391 = Math_fround(0), $1392 = 0;
 var $1393 = Math_fround(0), $1394 = 0, $1395 = Math_fround(0), $1396 = 0, $1397 = Math_fround(0), $1398 = 0, $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = 0, $1401 = Math_fround(0), $1402 = 0, $1403 = Math_fround(0), $1404 = 0, $1405 = 0, $1406 = Math_fround(0), $1407 = 0, $1408 = Math_fround(0), $1409 = 0, $141 = 0;
 var $1410 = Math_fround(0), $1411 = 0, $1412 = Math_fround(0), $1413 = 0, $1414 = Math_fround(0), $1415 = 0, $1416 = Math_fround(0), $1417 = 0, $1418 = Math_fround(0), $1419 = 0, $142 = 0, $1420 = 0, $1421 = Math_fround(0), $1422 = 0, $1423 = Math_fround(0), $1424 = 0, $1425 = Math_fround(0), $1426 = 0, $1427 = Math_fround(0), $1428 = 0;
 var $1429 = Math_fround(0), $143 = 0, $1430 = 0, $1431 = Math_fround(0), $1432 = 0, $1433 = Math_fround(0), $1434 = 0, $1435 = 0, $1436 = 0, $1437 = Math_fround(0), $1438 = 0, $1439 = Math_fround(0), $144 = 0, $1440 = 0, $1441 = Math_fround(0), $1442 = 0, $1443 = Math_fround(0), $1444 = 0, $1445 = Math_fround(0), $1446 = 0;
 var $1447 = Math_fround(0), $1448 = 0, $1449 = Math_fround(0), $145 = 0, $1450 = 0, $1451 = Math_fround(0), $1452 = 0, $1453 = Math_fround(0), $1454 = 0, $1455 = Math_fround(0), $1456 = 0, $1457 = Math_fround(0), $1458 = 0, $1459 = Math_fround(0), $146 = 0, $1460 = 0, $1461 = Math_fround(0), $1462 = 0, $1463 = Math_fround(0), $1464 = 0;
 var $1465 = Math_fround(0), $1466 = 0, $1467 = Math_fround(0), $1468 = 0, $1469 = Math_fround(0), $147 = 0, $1470 = 0, $1471 = Math_fround(0), $1472 = 0, $1473 = Math_fround(0), $1474 = 0, $1475 = Math_fround(0), $1476 = 0, $1477 = Math_fround(0), $1478 = 0, $1479 = Math_fround(0), $148 = 0, $1480 = 0, $1481 = Math_fround(0), $1482 = 0;
 var $1483 = Math_fround(0), $1484 = 0, $1485 = Math_fround(0), $1486 = 0, $1487 = Math_fround(0), $1488 = 0, $1489 = Math_fround(0), $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = Math_fround(0), $150 = 0;
 var $1500 = Math_fround(0), $1501 = 0, $1502 = 0, $1503 = Math_fround(0), $1504 = 0, $1505 = 0, $1506 = Math_fround(0), $1507 = 0, $1508 = 0, $1509 = Math_fround(0), $151 = 0, $1510 = 0, $1511 = 0, $1512 = Math_fround(0), $1513 = 0, $1514 = 0, $1515 = Math_fround(0), $1516 = 0, $1517 = 0, $1518 = 0;
 var $1519 = 0, $152 = Math_fround(0), $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = 0;
 var $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0);
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0);
 var $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = 0, $485 = Math_fround(0), $486 = 0, $487 = 0, $488 = Math_fround(0), $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = 0, $506 = Math_fround(0), $507 = 0;
 var $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = Math_fround(0), $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = Math_fround(0), $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = Math_fround(0), $549 = 0, $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = 0, $554 = 0, $555 = 0, $556 = Math_fround(0), $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = Math_fround(0), $568 = 0, $569 = Math_fround(0), $57 = 0, $570 = 0, $571 = 0, $572 = Math_fround(0), $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = 0, $58 = 0;
 var $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = 0, $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = 0, $588 = Math_fround(0), $589 = 0, $59 = 0, $590 = 0, $591 = Math_fround(0), $592 = 0, $593 = 0, $594 = Math_fround(0), $595 = 0, $596 = 0, $597 = Math_fround(0), $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = 0, $602 = 0, $603 = Math_fround(0), $604 = 0, $605 = 0, $606 = Math_fround(0), $607 = 0, $608 = 0, $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = 0, $612 = Math_fround(0), $613 = 0, $614 = 0, $615 = Math_fround(0);
 var $616 = 0, $617 = 0, $618 = Math_fround(0), $619 = 0, $62 = 0, $620 = 0, $621 = Math_fround(0), $622 = 0, $623 = 0, $624 = Math_fround(0), $625 = 0, $626 = 0, $627 = Math_fround(0), $628 = 0, $629 = 0, $63 = 0, $630 = Math_fround(0), $631 = 0, $632 = 0, $633 = Math_fround(0);
 var $634 = 0, $635 = 0, $636 = Math_fround(0), $637 = 0, $638 = 0, $639 = Math_fround(0), $64 = 0, $640 = 0, $641 = 0, $642 = Math_fround(0), $643 = 0, $644 = 0, $645 = Math_fround(0), $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = Math_fround(0);
 var $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0;
 var $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0);
 var $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = 0, $698 = Math_fround(0), $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = Math_fround(0);
 var $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = 0, $71 = 0, $710 = Math_fround(0), $711 = 0, $712 = 0, $713 = Math_fround(0), $714 = 0, $715 = 0, $716 = Math_fround(0), $717 = 0, $718 = 0, $719 = Math_fround(0), $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = Math_fround(0), $756 = Math_fround(0), $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0, $781 = Math_fround(0), $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = Math_fround(0), $787 = 0, $788 = Math_fround(0), $789 = 0, $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = 0, $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = 0;
 var $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = 0, $806 = 0, $807 = 0, $808 = Math_fround(0), $809 = 0, $81 = 0, $810 = Math_fround(0), $811 = 0, $812 = Math_fround(0), $813 = Math_fround(0);
 var $814 = 0, $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = 0, $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = Math_fround(0), $822 = 0, $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = Math_fround(0), $833 = 0, $834 = Math_fround(0), $835 = 0, $836 = Math_fround(0), $837 = Math_fround(0), $838 = 0, $839 = Math_fround(0), $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = 0, $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = 0, $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0;
 var $850 = Math_fround(0), $851 = Math_fround(0), $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = Math_fround(0), $857 = 0, $858 = Math_fround(0), $859 = 0, $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = 0, $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = 0, $867 = Math_fround(0), $868 = Math_fround(0);
 var $869 = Math_fround(0), $87 = 0, $870 = 0, $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = Math_fround(0), $953 = Math_fround(0), $954 = 0, $955 = Math_fround(0), $956 = 0, $957 = Math_fround(0), $958 = 0;
 var $959 = Math_fround(0), $96 = 0, $960 = 0, $961 = Math_fround(0), $962 = 0, $963 = Math_fround(0), $964 = 0, $965 = Math_fround(0), $966 = 0, $967 = Math_fround(0), $968 = 0, $969 = Math_fround(0), $97 = 0, $970 = 0, $971 = Math_fround(0), $972 = 0, $973 = Math_fround(0), $974 = 0, $975 = 0, $976 = Math_fround(0);
 var $977 = Math_fround(0), $978 = 0, $979 = Math_fround(0), $98 = 0, $980 = 0, $981 = Math_fround(0), $982 = 0, $983 = Math_fround(0), $984 = 0, $985 = Math_fround(0), $986 = 0, $987 = Math_fround(0), $988 = 0, $989 = Math_fround(0), $99 = 0, $990 = 0, $991 = Math_fround(0), $992 = 0, $993 = Math_fround(0), $994 = 0;
 var $995 = Math_fround(0), $996 = 0, $997 = Math_fround(0), $998 = 0, $999 = 0, $activeWheelStates = 0, $autoboxCompensatedAnalogAccel$0 = Math_fround(0), $aveWheelSpeedContributions = 0, $averageWheelSpeed$0$lcssa$i = Math_fround(0), $averageWheelSpeed$01$i = Math_fround(0), $brakeTorques = 0, $brmerge = 0, $brmerge$i = 0, $carChassisAngVel = 0, $carChassisCMLocalPose = 0, $carChassisLinVel = 0, $carChassisTransform = 0, $chassisForce = 0, $chassisTorque = 0, $constData = 0;
 var $diffData = 0, $diffTorqueRatios = 0, $driveSimData = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i1 = 0, $exitcond$i4 = 0, $exitcond192 = 0, $exitcond198 = 0, $exitcond199 = 0, $exitcond206 = 0, $exitcond207 = 0, $exitcond208 = 0, $exitcond209 = 0, $exitcond210 = 0, $exitcond211 = 0, $exitcond213 = 0, $exitcond214 = 0, $exitcond215 = 0, $exitcond216 = 0;
 var $exitcond217 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $finiteInputApplied$0$off0 = 0, $i$01$i = 0, $i$01$i$i = 0, $i$0185 = 0, $i$02$i = 0, $i$04$i = 0, $i$07$i$i = 0, $i1$0178 = 0, $i10$0153 = 0, $i11$0150 = 0, $i12$0147 = 0, $i13$0112 = 0, $i14$0116 = 0, $i15$0130 = 0, $i17$0140 = 0, $i18$0111 = 0, $i2$0173 = 0;
 var $i3$0170 = 0, $i7$0166 = 0, $i8$0162 = 0, $i9$0159 = 0, $implicitSolverInput = 0, $implicitSolverOutput = 0, $inertia = 0, $inputData = 0, $inverseInertia = 0, $isAccelApplied = 0, $isBrakeApplied = 0, $j$02$i = 0, $j$02$i7 = 0, $k$0143 = 0, $not$or$cond2$i = 0, $notlhs$i = 0, $notrhs$i = 0, $numActiveWheelsPerBlock4 = 0, $or$cond = 0, $or$cond$i = 0;
 var $or$cond$i$i = 0, $or$cond3$i = 0, $outputData = 0, $steerAngles = 0, $tires4ForceCalculators = 0, $vehWheels = 0, $vehicleConcurrentUpdates = 0, $wheelConcurrentUpdates = 0, $wheelOmega$0$i = Math_fround(0), $wheelQueryResults = 0, $x0$08$i$i = Math_fround(0), $y0$06$i$i = Math_fround(0), dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 11216|0;
 $driveSimData = sp + 16|0;
 $wheelConcurrentUpdates = sp + 9968|0;
 $vehicleConcurrentUpdates = sp + 6816|0;
 $numActiveWheelsPerBlock4 = sp + 6852|0;
 $tires4ForceCalculators = sp + 6872|0;
 $wheelQueryResults = sp + 6976|0;
 $carChassisCMLocalPose = sp + 9936|0;
 $carChassisTransform = sp + 11088|0;
 $inverseInertia = sp + 11116|0;
 $carChassisLinVel = sp + 11128|0;
 $carChassisAngVel = sp + 11140|0;
 $0 = sp + 6788|0;
 $1 = sp + 6760|0;
 $inertia = sp + 6748|0;
 $2 = sp;
 $3 = sp + 816|0;
 $activeWheelStates = sp + 11152|0;
 $diffData = sp + 560|0;
 $aveWheelSpeedContributions = sp + 576|0;
 $isAccelApplied = sp + 11192|0;
 $steerAngles = sp + 656|0;
 $diffTorqueRatios = sp + 736|0;
 $constData = sp + 828|0;
 $chassisForce = sp + 872|0;
 $chassisTorque = sp + 884|0;
 $brakeTorques = sp + 896|0;
 $isBrakeApplied = sp + 11172|0;
 $outputData = sp + 1008|0;
 $inputData = sp + 6568|0;
 $implicitSolverInput = sp + 6664|0;
 $implicitSolverOutput = sp + 6736|0;
 $vehWheels = sp + 6744|0;
 $4 = (($vehDriveNW) + 8|0);
 $5 = (($vehDriveNW) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $48 = 0;
 } else {
  $8 = (($vehDriveNW) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  $i$0185 = 0;
  while(1) {
   $10 = $i$0185 << 2;
   $11 = (523960 + ($10<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = (($9) + (($i$0185*208)|0)|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = (($12) + 16|0);
    HEAPF32[$16>>2] = $15;
    $17 = ((($9) + (($i$0185*208)|0)|0) + 4|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = $10 | 1;
    $20 = (523960 + ($19<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 16|0);
    HEAPF32[$22>>2] = $18;
    $23 = ((($9) + (($i$0185*208)|0)|0) + 8|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = $10 | 2;
    $26 = (523960 + ($25<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 16|0);
    HEAPF32[$28>>2] = $24;
    $29 = ((($9) + (($i$0185*208)|0)|0) + 12|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = $10 | 3;
    $32 = (523960 + ($31<<2)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 16|0);
    HEAPF32[$34>>2] = $30;
   }
   $35 = (($i$0185) + 1)|0;
   $36 = ($35>>>0)<($6>>>0);
   if ($36) {
    $i$0185 = $35;
   } else {
    $48 = $6;
    break;
   }
  }
 }
 $37 = (($vehDriveNW) + 128|0);
 $38 = (($vehDriveNW) + 204|0);
 $39 = (0|0)==(0|0);
 if (!($39)) {
  $40 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[0>>2] = $40;
 }
 $41 = (($vehDriveNW) + 40|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($vehDriveNW) + 72|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($vehDriveNW) + 48|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $48 << 2;
 $49 = (4 - ($47))|0;
 $50 = (($vehDriveNW) + 224|0);
 $51 = (($vehDriveNW) + 288|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 << 3;
 _memcpy(($driveSimData|0),($50|0),($53|0))|0;
 $54 = (($driveSimData) + 64|0);
 HEAP32[$54>>2] = $52;
 $55 = (($driveSimData) + 80|0);
 $56 = (($vehDriveNW) + 304|0);
 ;HEAP32[$55+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$56+12>>2]|0;HEAP32[$55+16>>2]=HEAP32[$56+16>>2]|0;HEAP32[$55+20>>2]=HEAP32[$56+20>>2]|0;HEAP32[$55+24>>2]=HEAP32[$56+24>>2]|0;HEAP32[$55+28>>2]=HEAP32[$56+28>>2]|0;
 $57 = (($driveSimData) + 112|0);
 $58 = (($vehDriveNW) + 336|0);
 _memcpy(($57|0),($58|0),416)|0;
 $59 = (($driveSimData) + 528|0);
 $60 = (($vehDriveNW) + 752|0);
 ;HEAP32[$59+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$59+12>>2]=HEAP32[$60+12>>2]|0;
 $61 = (($vehDriveNW) + 104|0);
 $62 = HEAP32[$61>>2]|0;
 HEAPF32[$wheelConcurrentUpdates>>2] = Math_fround(0.0);
 $63 = (($wheelConcurrentUpdates) + 4|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($wheelConcurrentUpdates) + 8|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = (($wheelConcurrentUpdates) + 12|0);
 HEAPF32[$65>>2] = Math_fround(1.0);
 $66 = (($wheelConcurrentUpdates) + 16|0);
 $67 = (($wheelConcurrentUpdates) + 60|0);
 dest=$66+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($wheelConcurrentUpdates) + 64|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($wheelConcurrentUpdates) + 68|0);
 HEAPF32[$69>>2] = Math_fround(1.0);
 $70 = (($wheelConcurrentUpdates) + 72|0);
 $71 = (($wheelConcurrentUpdates) + 116|0);
 dest=$70+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($wheelConcurrentUpdates) + 120|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($wheelConcurrentUpdates) + 124|0);
 HEAPF32[$73>>2] = Math_fround(1.0);
 $74 = (($wheelConcurrentUpdates) + 128|0);
 $75 = (($wheelConcurrentUpdates) + 172|0);
 dest=$74+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($wheelConcurrentUpdates) + 176|0);
 HEAPF32[$76>>2] = Math_fround(0.0);
 $77 = (($wheelConcurrentUpdates) + 180|0);
 HEAPF32[$77>>2] = Math_fround(1.0);
 $78 = (($wheelConcurrentUpdates) + 184|0);
 $79 = (($wheelConcurrentUpdates) + 228|0);
 dest=$78+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($wheelConcurrentUpdates) + 232|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 $81 = (($wheelConcurrentUpdates) + 236|0);
 HEAPF32[$81>>2] = Math_fround(1.0);
 $82 = (($wheelConcurrentUpdates) + 240|0);
 $83 = (($wheelConcurrentUpdates) + 284|0);
 dest=$82+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($wheelConcurrentUpdates) + 288|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 $85 = (($wheelConcurrentUpdates) + 292|0);
 HEAPF32[$85>>2] = Math_fround(1.0);
 $86 = (($wheelConcurrentUpdates) + 296|0);
 $87 = (($wheelConcurrentUpdates) + 340|0);
 dest=$86+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($wheelConcurrentUpdates) + 344|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($wheelConcurrentUpdates) + 348|0);
 HEAPF32[$89>>2] = Math_fround(1.0);
 $90 = (($wheelConcurrentUpdates) + 352|0);
 $91 = (($wheelConcurrentUpdates) + 396|0);
 dest=$90+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($wheelConcurrentUpdates) + 400|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $93 = (($wheelConcurrentUpdates) + 404|0);
 HEAPF32[$93>>2] = Math_fround(1.0);
 $94 = (($wheelConcurrentUpdates) + 408|0);
 $95 = (($wheelConcurrentUpdates) + 452|0);
 dest=$94+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($wheelConcurrentUpdates) + 456|0);
 HEAPF32[$96>>2] = Math_fround(0.0);
 $97 = (($wheelConcurrentUpdates) + 460|0);
 HEAPF32[$97>>2] = Math_fround(1.0);
 $98 = (($wheelConcurrentUpdates) + 464|0);
 $99 = (($wheelConcurrentUpdates) + 508|0);
 dest=$98+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = (($wheelConcurrentUpdates) + 512|0);
 HEAPF32[$100>>2] = Math_fround(0.0);
 $101 = (($wheelConcurrentUpdates) + 516|0);
 HEAPF32[$101>>2] = Math_fround(1.0);
 $102 = (($wheelConcurrentUpdates) + 520|0);
 $103 = (($wheelConcurrentUpdates) + 564|0);
 dest=$102+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($wheelConcurrentUpdates) + 568|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($wheelConcurrentUpdates) + 572|0);
 HEAPF32[$105>>2] = Math_fround(1.0);
 $106 = (($wheelConcurrentUpdates) + 576|0);
 $107 = (($wheelConcurrentUpdates) + 620|0);
 dest=$106+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($wheelConcurrentUpdates) + 624|0);
 HEAPF32[$108>>2] = Math_fround(0.0);
 $109 = (($wheelConcurrentUpdates) + 628|0);
 HEAPF32[$109>>2] = Math_fround(1.0);
 $110 = (($wheelConcurrentUpdates) + 632|0);
 $111 = (($wheelConcurrentUpdates) + 676|0);
 dest=$110+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = (($wheelConcurrentUpdates) + 680|0);
 HEAPF32[$112>>2] = Math_fround(0.0);
 $113 = (($wheelConcurrentUpdates) + 684|0);
 HEAPF32[$113>>2] = Math_fround(1.0);
 $114 = (($wheelConcurrentUpdates) + 688|0);
 $115 = (($wheelConcurrentUpdates) + 732|0);
 dest=$114+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = (($wheelConcurrentUpdates) + 736|0);
 HEAPF32[$116>>2] = Math_fround(0.0);
 $117 = (($wheelConcurrentUpdates) + 740|0);
 HEAPF32[$117>>2] = Math_fround(1.0);
 $118 = (($wheelConcurrentUpdates) + 744|0);
 $119 = (($wheelConcurrentUpdates) + 788|0);
 dest=$118+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($wheelConcurrentUpdates) + 792|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($wheelConcurrentUpdates) + 796|0);
 HEAPF32[$121>>2] = Math_fround(1.0);
 $122 = (($wheelConcurrentUpdates) + 800|0);
 $123 = (($wheelConcurrentUpdates) + 844|0);
 dest=$122+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = (($wheelConcurrentUpdates) + 848|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = (($wheelConcurrentUpdates) + 852|0);
 HEAPF32[$125>>2] = Math_fround(1.0);
 $126 = (($wheelConcurrentUpdates) + 856|0);
 $127 = (($wheelConcurrentUpdates) + 900|0);
 dest=$126+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = (($wheelConcurrentUpdates) + 904|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 $129 = (($wheelConcurrentUpdates) + 908|0);
 HEAPF32[$129>>2] = Math_fround(1.0);
 $130 = (($wheelConcurrentUpdates) + 912|0);
 $131 = (($wheelConcurrentUpdates) + 956|0);
 dest=$130+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$131>>2] = Math_fround(0.0);
 $132 = (($wheelConcurrentUpdates) + 960|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = (($wheelConcurrentUpdates) + 964|0);
 HEAPF32[$133>>2] = Math_fround(1.0);
 $134 = (($wheelConcurrentUpdates) + 968|0);
 $135 = (($wheelConcurrentUpdates) + 1012|0);
 dest=$134+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = (($wheelConcurrentUpdates) + 1016|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 $137 = (($wheelConcurrentUpdates) + 1020|0);
 HEAPF32[$137>>2] = Math_fround(1.0);
 $138 = (($wheelConcurrentUpdates) + 1024|0);
 $139 = (($wheelConcurrentUpdates) + 1068|0);
 dest=$138+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($wheelConcurrentUpdates) + 1072|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $141 = (($wheelConcurrentUpdates) + 1076|0);
 HEAPF32[$141>>2] = Math_fround(1.0);
 $142 = (($wheelConcurrentUpdates) + 1080|0);
 dest=$142+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $143 = (($49) + ($46))|0;
 ;HEAP32[$vehicleConcurrentUpdates+0>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+4>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+8>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+12>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+16>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+20>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+24>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+28>>2]=0|0;HEAP16[$vehicleConcurrentUpdates+32>>1]=0|0;
 $144 = (($vehicleConcurrentUpdates) + 4|0);
 HEAP32[$144>>2] = $46;
 HEAP32[$vehicleConcurrentUpdates>>2] = $wheelConcurrentUpdates;
 ;HEAP32[$numActiveWheelsPerBlock4+0>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+4>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+8>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+12>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+16>>2]=0|0;
 $145 = ($46>>>0)<(4);
 $146 = $145 ? $46 : 4;
 HEAP32[$numActiveWheelsPerBlock4>>2] = $146;
 $147 = (($48) + -1)|0;
 $148 = ($147>>>0)>(1);
 if ($148) {
  $i1$0178 = 1;
  while(1) {
   $149 = (($numActiveWheelsPerBlock4) + ($i1$0178<<2)|0);
   HEAP32[$149>>2] = 4;
   $150 = (($i1$0178) + 1)|0;
   $exitcond217 = ($150|0)==($147|0);
   if ($exitcond217) {
    break;
   } else {
    $i1$0178 = $150;
   }
  }
 }
 $151 = (($numActiveWheelsPerBlock4) + ($147<<2)|0);
 HEAP32[$151>>2] = $143;
 $152 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($37,3)));
 $153 = $152 != Math_fround(0.0);
 if ($153) {
  label = 15;
 } else {
  $154 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($37,4)));
  $155 = $154 != Math_fround(0.0);
  if ($155) {
   label = 15;
  } else {
   $156 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($37,0)));
   $157 = $156 != Math_fround(0.0);
   if ($157) {
    label = 15;
   } else {
    $158 = (($vehDriveNW) + 194|0);
    $159 = HEAP8[$158>>0]|0;
    $160 = ($159<<24>>24)==(0);
    if ($160) {
     $161 = (($vehDriveNW) + 193|0);
     $162 = HEAP8[$161>>0]|0;
     $163 = ($162<<24>>24)==(0);
     if ($163) {
      $finiteInputApplied$0$off0 = 0;
     } else {
      label = 15;
     }
    } else {
     label = 15;
    }
   }
  }
 }
 if ((label|0) == 15) {
  $finiteInputApplied$0$off0 = 1;
 }
 $164 = HEAP32[$62>>2]|0;
 $165 = (($164) + 256|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = (FUNCTION_TABLE_ii[$166 & 4095]($62)|0);
 L24: do {
  if ($167) {
   if ($finiteInputApplied$0$off0) {
    $168 = (($vehicleConcurrentUpdates) + 33|0);
    HEAP8[$168>>0] = 1;
    break;
   }
   $169 = HEAP32[$5>>2]|0;
   $170 = HEAP32[$43>>2]|0;
   $171 = ($169|0)==(0);
   L29: do {
    if (!($171)) {
     $i$04$i = 0;
     L30: while(1) {
      $172 = $i$04$i << 2;
      $173 = ((($170) + (($i$04$i*208)|0)|0) + 196|0);
      $j$02$i7 = 0;
      while(1) {
       $174 = (($j$02$i7) + ($172))|0;
       $175 = (__ZNK5physx22PxVehicleWheelsSimData18getIsWheelDisabledEj($4,$174)|0);
       if (!($175)) {
        $176 = HEAP32[$173>>2]|0;
        $177 = ((($176) + (($j$02$i7*80)|0)|0) + 77|0);
        $178 = HEAP8[$177>>0]|0;
        $179 = ($178<<24>>24)==(0);
        if (!($179)) {
         $180 = (($176) + (($j$02$i7*80)|0)|0);
         $181 = HEAP32[$180>>2]|0;
         $182 = ($181|0)==(0|0);
         if (!($182)) {
          $183 = (($181) + 4|0);
          $184 = HEAP16[$183>>1]|0;
          $185 = ($184<<16>>16)==(5);
          if ($185) {
           break L30;
          }
         }
        }
       }
       $186 = (($j$02$i7) + 1)|0;
       $187 = ($186>>>0)<(4);
       if ($187) {
        $j$02$i7 = $186;
       } else {
        break;
       }
      }
      $188 = (($i$04$i) + 1)|0;
      $189 = ($188>>>0)<($169>>>0);
      if ($189) {
       $i$04$i = $188;
      } else {
       break L29;
      }
     }
     $190 = (($vehicleConcurrentUpdates) + 33|0);
     HEAP8[$190>>0] = 1;
     break L24;
    }
   } while(0);
   HEAPF32[$38>>2] = Math_fround(0.0);
   $191 = (($vehDriveNW) + 88|0);
   $192 = HEAP32[$191>>2]|0;
   $193 = ($192|0)==(0);
   if (!($193)) {
    $i$01$i$i = 0;
    while(1) {
     __ZN5physx22PxVehicleWheelsDynData21setWheelRotationSpeedEjf($43,$i$01$i$i,Math_fround(0.0));
     $194 = (($i$01$i$i) + 1)|0;
     $195 = HEAP32[$191>>2]|0;
     $196 = ($194>>>0)<($195>>>0);
     if ($196) {
      $i$01$i$i = $194;
     } else {
      break;
     }
    }
   }
   HEAPF32[$38>>2] = Math_fround(0.0);
   $197 = ($vehConcurrentUpdates|0)==(0|0);
   if ($197) {
    STACKTOP = sp;return;
   }
   $198 = (($vehConcurrentUpdates) + 32|0);
   HEAP8[$198>>0] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 $199 = ($48|0)==(0);
 if (!($199)) {
  $200 = (($vehDriveNW) + 76|0);
  $$pre229 = HEAP32[$200>>2]|0;
  $i2$0173 = 0;
  while(1) {
   $201 = $i2$0173 << 2;
   $202 = HEAP32[$$pre229>>2]|0;
   $203 = (($202) + ($201<<2)|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = (($tires4ForceCalculators) + (($i2$0173*20)|0)|0);
   HEAP32[$205>>2] = $204;
   $206 = $201 | 1;
   $207 = HEAP32[$$pre229>>2]|0;
   $208 = (($207) + ($206<<2)|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = ((($tires4ForceCalculators) + (($i2$0173*20)|0)|0) + 4|0);
   HEAP32[$210>>2] = $209;
   $211 = $201 | 2;
   $212 = HEAP32[$$pre229>>2]|0;
   $213 = (($212) + ($211<<2)|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = ((($tires4ForceCalculators) + (($i2$0173*20)|0)|0) + 8|0);
   HEAP32[$215>>2] = $214;
   $216 = $201 | 3;
   $217 = HEAP32[$$pre229>>2]|0;
   $218 = (($217) + ($216<<2)|0);
   $219 = HEAP32[$218>>2]|0;
   $220 = ((($tires4ForceCalculators) + (($i2$0173*20)|0)|0) + 12|0);
   HEAP32[$220>>2] = $219;
   $221 = (($$pre229) + 4|0);
   $222 = HEAP32[$221>>2]|0;
   $223 = ((($tires4ForceCalculators) + (($i2$0173*20)|0)|0) + 16|0);
   HEAP32[$223>>2] = $222;
   $224 = (($i2$0173) + 1)|0;
   $exitcond216 = ($224|0)==($48|0);
   if ($exitcond216) {
    break;
   } else {
    $i2$0173 = $224;
   }
  }
  if (!($199)) {
   $i3$0170 = 0;
   while(1) {
    $225 = ((($44) + (($i3$0170*208)|0)|0) + 192|0);
    $226 = HEAP32[$225>>2]|0;
    $227 = (($226) + 352|0);
    $228 = HEAP32[$227>>2]|0;
    $229 = HEAP32[$228>>2]|0;
    $230 = (($229) + 36|0);
    $231 = HEAP32[$230>>2]|0;
    FUNCTION_TABLE_vi[$231 & 4095]($228);
    $232 = (($i3$0170) + 1)|0;
    $exitcond215 = ($232|0)==($48|0);
    if ($exitcond215) {
     break;
    } else {
     $i3$0170 = $232;
    }
   }
  }
 }
 $233 = (($wheelQueryResults) + 2960|0);
 $234 = $wheelQueryResults;
 while(1) {
  _memset(($234|0),0,136)|0;
  $235 = (($234) + 28|0);
  HEAP8[$235>>0] = 1;
  $236 = (($234) + 44|0);
  HEAP32[$236>>2] = -1;
  $237 = (($234) + 120|0);
  HEAPF32[$237>>2] = Math_fround(0.0);
  $238 = (($234) + 124|0);
  HEAPF32[$238>>2] = Math_fround(0.0);
  $239 = (($234) + 128|0);
  HEAPF32[$239>>2] = Math_fround(0.0);
  $240 = (($234) + 132|0);
  HEAPF32[$240>>2] = Math_fround(1.0);
  $241 = (($234) + 136|0);
  HEAPF32[$241>>2] = Math_fround(0.0);
  $242 = (($234) + 140|0);
  HEAPF32[$242>>2] = Math_fround(0.0);
  $243 = (($234) + 144|0);
  HEAPF32[$243>>2] = Math_fround(0.0);
  $244 = (($234) + 148|0);
  $245 = ($244|0)==($233|0);
  if ($245) {
   break;
  } else {
   $234 = $244;
  }
 }
 $246 = HEAP32[$62>>2]|0;
 $247 = (($246) + 124|0);
 $248 = HEAP32[$247>>2]|0;
 FUNCTION_TABLE_vii[$248 & 4095]($0,$62);
 $249 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$carChassisCMLocalPose>>2] = $249;
 $250 = (($0) + 4|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = (($carChassisCMLocalPose) + 4|0);
 HEAPF32[$252>>2] = $251;
 $253 = (($0) + 8|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = (($carChassisCMLocalPose) + 8|0);
 HEAPF32[$255>>2] = $254;
 $256 = (($0) + 12|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = (($carChassisCMLocalPose) + 12|0);
 HEAPF32[$258>>2] = $257;
 $259 = (($0) + 16|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = (($carChassisCMLocalPose) + 16|0);
 HEAPF32[$261>>2] = $260;
 $262 = (($0) + 20|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 $264 = (($carChassisCMLocalPose) + 20|0);
 HEAPF32[$264>>2] = $263;
 $265 = (($0) + 24|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = (($carChassisCMLocalPose) + 24|0);
 HEAPF32[$267>>2] = $266;
 $268 = HEAP32[$62>>2]|0;
 $269 = (($268) + 84|0);
 $270 = HEAP32[$269>>2]|0;
 FUNCTION_TABLE_vii[$270 & 4095]($1,$62);
 $271 = Math_fround($260 * Math_fround(2.0));
 $272 = Math_fround($263 * Math_fround(2.0));
 $273 = Math_fround($266 * Math_fround(2.0));
 $274 = (($1) + 12|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = Math_fround($275 * $275);
 $277 = Math_fround($276 + Math_fround(-0.5));
 $278 = Math_fround(HEAPF32[$1>>2]);
 $279 = Math_fround($271 * $278);
 $280 = (($1) + 4|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = Math_fround($272 * $281);
 $283 = Math_fround($279 + $282);
 $284 = (($1) + 8|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = Math_fround($273 * $285);
 $287 = Math_fround($283 + $286);
 $288 = Math_fround($271 * $277);
 $289 = Math_fround($273 * $281);
 $290 = Math_fround($272 * $285);
 $291 = Math_fround($289 - $290);
 $292 = Math_fround($275 * $291);
 $293 = Math_fround($288 + $292);
 $294 = Math_fround($278 * $287);
 $295 = Math_fround($294 + $293);
 $296 = Math_fround($272 * $277);
 $297 = Math_fround($271 * $285);
 $298 = Math_fround($273 * $278);
 $299 = Math_fround($297 - $298);
 $300 = Math_fround($275 * $299);
 $301 = Math_fround($296 + $300);
 $302 = Math_fround($281 * $287);
 $303 = Math_fround($302 + $301);
 $304 = Math_fround($273 * $277);
 $305 = Math_fround($272 * $278);
 $306 = Math_fround($271 * $281);
 $307 = Math_fround($305 - $306);
 $308 = Math_fround($275 * $307);
 $309 = Math_fround($304 + $308);
 $310 = Math_fround($285 * $287);
 $311 = Math_fround($309 + $310);
 $312 = (($1) + 16|0);
 $313 = Math_fround(HEAPF32[$312>>2]);
 $314 = Math_fround($313 + $295);
 $315 = (($1) + 20|0);
 $316 = Math_fround(HEAPF32[$315>>2]);
 $317 = Math_fround($316 + $303);
 $318 = (($1) + 24|0);
 $319 = Math_fround(HEAPF32[$318>>2]);
 $320 = Math_fround($319 + $311);
 $321 = Math_fround($275 * $249);
 $322 = Math_fround($278 * $257);
 $323 = Math_fround($321 + $322);
 $324 = Math_fround($281 * $254);
 $325 = Math_fround($323 + $324);
 $326 = Math_fround($285 * $251);
 $327 = Math_fround($325 - $326);
 $328 = Math_fround($275 * $251);
 $329 = Math_fround($281 * $257);
 $330 = Math_fround($329 + $328);
 $331 = Math_fround($285 * $249);
 $332 = Math_fround($331 + $330);
 $333 = Math_fround($278 * $254);
 $334 = Math_fround($332 - $333);
 $335 = Math_fround($275 * $254);
 $336 = Math_fround($285 * $257);
 $337 = Math_fround($336 + $335);
 $338 = Math_fround($278 * $251);
 $339 = Math_fround($338 + $337);
 $340 = Math_fround($281 * $249);
 $341 = Math_fround($339 - $340);
 $342 = Math_fround($275 * $257);
 $343 = Math_fround($278 * $249);
 $344 = Math_fround($342 - $343);
 $345 = Math_fround($281 * $251);
 $346 = Math_fround($344 - $345);
 $347 = Math_fround($285 * $254);
 $348 = Math_fround($346 - $347);
 HEAPF32[$carChassisTransform>>2] = $327;
 $349 = (($carChassisTransform) + 4|0);
 HEAPF32[$349>>2] = $334;
 $350 = (($carChassisTransform) + 8|0);
 HEAPF32[$350>>2] = $341;
 $351 = (($carChassisTransform) + 12|0);
 HEAPF32[$351>>2] = $348;
 $352 = (($carChassisTransform) + 16|0);
 HEAPF32[$352>>2] = $314;
 $353 = (($carChassisTransform) + 20|0);
 HEAPF32[$353>>2] = $317;
 $354 = (($carChassisTransform) + 24|0);
 HEAPF32[$354>>2] = $320;
 $355 = HEAP32[$62>>2]|0;
 $356 = (($355) + 132|0);
 $357 = HEAP32[$356>>2]|0;
 $358 = (Math_fround(FUNCTION_TABLE_fi[$357 & 255]($62)));
 $359 = Math_fround(Math_fround(1.0) / $358);
 $360 = HEAP32[$62>>2]|0;
 $361 = (($360) + 144|0);
 $362 = HEAP32[$361>>2]|0;
 FUNCTION_TABLE_vii[$362 & 4095]($inertia,$62);
 $363 = Math_fround(HEAPF32[$inertia>>2]);
 $364 = Math_fround(Math_fround(1.0) / $363);
 $365 = (($inertia) + 4|0);
 $366 = Math_fround(HEAPF32[$365>>2]);
 $367 = Math_fround(Math_fround(1.0) / $366);
 $368 = (($inertia) + 8|0);
 $369 = Math_fround(HEAPF32[$368>>2]);
 $370 = Math_fround(Math_fround(1.0) / $369);
 HEAPF32[$inverseInertia>>2] = $364;
 $371 = (($inverseInertia) + 4|0);
 HEAPF32[$371>>2] = $367;
 $372 = (($inverseInertia) + 8|0);
 HEAPF32[$372>>2] = $370;
 $373 = HEAP32[$62>>2]|0;
 $374 = (($373) + 152|0);
 $375 = HEAP32[$374>>2]|0;
 FUNCTION_TABLE_vii[$375 & 4095]($2,$62);
 $376 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$carChassisLinVel>>2] = $376;
 $377 = (($2) + 4|0);
 $378 = Math_fround(HEAPF32[$377>>2]);
 $379 = (($carChassisLinVel) + 4|0);
 HEAPF32[$379>>2] = $378;
 $380 = (($2) + 8|0);
 $381 = Math_fround(HEAPF32[$380>>2]);
 $382 = (($carChassisLinVel) + 8|0);
 HEAPF32[$382>>2] = $381;
 $383 = HEAP32[$62>>2]|0;
 $384 = (($383) + 160|0);
 $385 = HEAP32[$384>>2]|0;
 FUNCTION_TABLE_vii[$385 & 4095]($3,$62);
 $386 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$carChassisAngVel>>2] = $386;
 $387 = (($3) + 4|0);
 $388 = Math_fround(HEAPF32[$387>>2]);
 $389 = (($carChassisAngVel) + 4|0);
 HEAPF32[$389>>2] = $388;
 $390 = (($3) + 8|0);
 $391 = Math_fround(HEAPF32[$390>>2]);
 $392 = (($carChassisAngVel) + 8|0);
 HEAPF32[$392>>2] = $391;
 $393 = Math_fround(HEAPF32[$37>>2]);
 $394 = (($vehDriveNW) + 192|0);
 $395 = HEAP8[$394>>0]|0;
 $396 = ($395<<24>>24)==(0);
 $$pre231 = (($vehDriveNW) + 196|0);
 do {
  if ($396) {
   $autoboxCompensatedAnalogAccel$0 = $393;
  } else {
   $397 = HEAP32[$$pre231>>2]|0;
   $398 = (($vehDriveNW) + 200|0);
   $399 = HEAP32[$398>>2]|0;
   $400 = ($399|0)!=($397|0);
   $401 = ($397|0)==(1);
   $or$cond$i = $400 & $401;
   $$$i = $or$cond$i ? Math_fround(0.0) : $393;
   $402 = (($vehDriveNW) + 212|0);
   $403 = Math_fround(HEAPF32[$402>>2]);
   $404 = ($399|0)==($397|0);
   if ($404) {
    $405 = (($driveSimData) + 400|0);
    $406 = Math_fround(HEAPF32[$405>>2]);
    $407 = $403 > $406;
    if ($407) {
     $408 = Math_fround(HEAPF32[$38>>2]);
     $409 = (($driveSimData) + 108|0);
     $410 = Math_fround(HEAPF32[$409>>2]);
     $411 = Math_fround($408 * $410);
     $412 = ((($driveSimData) + ($397<<2)|0) + 272|0);
     $413 = Math_fround(HEAPF32[$412>>2]);
     $notlhs$i = $411 > $413;
     $notrhs$i = ($397|0)!=(0);
     $not$or$cond2$i = $notrhs$i & $notlhs$i;
     $414 = ((($driveSimData) + ($397<<2)|0) + 400|0);
     $415 = Math_fround(HEAPF32[$414>>2]);
     $416 = $411 < $415;
     $417 = ($397>>>0)>(2);
     $or$cond3$i = $416 & $417;
     $brmerge$i = $not$or$cond2$i | $or$cond3$i;
     if (!($brmerge$i)) {
      $autoboxCompensatedAnalogAccel$0 = $$$i;
      break;
     }
     $418 = (($vehDriveNW) + 193|0);
     $419 = $not$or$cond2$i&1;
     HEAP8[$418>>0] = $419;
     $420 = (($vehDriveNW) + 194|0);
     $421 = $or$cond3$i&1;
     HEAP8[$420>>0] = $421;
     HEAPF32[$402>>2] = Math_fround(0.0);
     $autoboxCompensatedAnalogAccel$0 = $$$i;
     break;
    }
   }
   $422 = Math_fround($403 + $timestep);
   HEAPF32[$402>>2] = $422;
   $autoboxCompensatedAnalogAccel$0 = $$$i;
  }
 } while(0);
 __ZN5physx12processGearsEfRKNS_18PxVehicleGearsDataERNS_21PxVehicleDriveDynDataE($timestep,$57,$37);
 $423 = HEAP32[$$pre231>>2]|0;
 $424 = ($423|0)==(1);
 if ($424) {
  $756 = Math_fround(0.0);
 } else {
  $425 = (($driveSimData) + 256|0);
  $426 = Math_fround(HEAPF32[$425>>2]);
  $756 = $426;
 }
 $427 = (($driveSimData) + 260|0);
 $428 = HEAP32[$427>>2]|0;
 $429 = (($driveSimData) + 264|0);
 $430 = HEAP32[$429>>2]|0;
 $431 = ((($driveSimData) + ($423<<2)|0) + 112|0);
 $432 = Math_fround(HEAPF32[$431>>2]);
 $433 = (($driveSimData) + 240|0);
 $434 = Math_fround(HEAPF32[$433>>2]);
 $435 = Math_fround($432 * $434);
 $436 = (0|0)==(0|0);
 if (!($436)) {
  $437 = (0 + 32|0);
  HEAPF32[$437>>2] = $435;
 }
 $438 = (($vehDriveNW) + 132|0);
 $439 = Math_fround(HEAPF32[$438>>2]);
 $440 = (($vehDriveNW) + 136|0);
 $441 = Math_fround(HEAPF32[$440>>2]);
 $442 = (($vehDriveNW) + 140|0);
 $443 = Math_fround(HEAPF32[$442>>2]);
 $444 = (($vehDriveNW) + 144|0);
 $445 = Math_fround(HEAPF32[$444>>2]);
 $446 = Math_fround($445 - $443);
 $447 = $autoboxCompensatedAnalogAccel$0 > Math_fround(0.0);
 $448 = $439 == Math_fround(0.0);
 $or$cond = $447 & $448;
 if ($or$cond) {
  $449 = $441 == Math_fround(0.0);
  $523 = $449;
 } else {
  $523 = 0;
 }
 if (!($436)) {
  $450 = (0 + 12|0);
  HEAPF32[$450>>2] = $autoboxCompensatedAnalogAccel$0;
  $451 = (0 + 16|0);
  HEAPF32[$451>>2] = $439;
  $452 = (0 + 20|0);
  HEAPF32[$452>>2] = $441;
  $453 = (0 + 24|0);
  HEAPF32[$453>>2] = $443;
  $454 = (0 + 28|0);
  HEAPF32[$454>>2] = $445;
 }
 dest=$activeWheelStates+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 if (!($199)) {
  $i7$0166 = 0;
  while(1) {
   $455 = $i7$0166 << 2;
   $456 = $i7$0166 >>> 3;
   $457 = $456 & 134217727;
   $458 = ((($vehDriveNW) + ($457<<2)|0) + 52|0);
   $459 = HEAP32[$458>>2]|0;
   $460 = $455 & 28;
   $461 = 1 << $460;
   $462 = $459 & $461;
   $463 = ($462|0)==(0);
   if (!($463)) {
    $464 = (($activeWheelStates) + ($455)|0);
    HEAP8[$464>>0] = 1;
   }
   $465 = $460 | 1;
   $466 = 1 << $465;
   $467 = $459 & $466;
   $468 = ($467|0)==(0);
   if (!($468)) {
    $$sum105106 = $455 | 1;
    $469 = (($activeWheelStates) + ($$sum105106)|0);
    HEAP8[$469>>0] = 1;
   }
   $470 = $460 | 2;
   $471 = 1 << $470;
   $472 = $459 & $471;
   $473 = ($472|0)==(0);
   if (!($473)) {
    $$sum107108 = $455 | 2;
    $474 = (($activeWheelStates) + ($$sum107108)|0);
    HEAP8[$474>>0] = 1;
   }
   $475 = $460 | 3;
   $476 = 1 << $475;
   $477 = $459 & $476;
   $478 = ($477|0)==(0);
   if (!($478)) {
    $$sum109110 = $455 | 3;
    $479 = (($activeWheelStates) + ($$sum109110)|0);
    HEAP8[$479>>0] = 1;
   }
   $480 = (($i7$0166) + 1)|0;
   $exitcond214 = ($480|0)==($48|0);
   if ($exitcond214) {
    break;
   } else {
    $i7$0166 = $480;
   }
  }
 }
 ;HEAP32[$diffData+0>>2]=HEAP32[$59+0>>2]|0;HEAP32[$diffData+4>>2]=HEAP32[$59+4>>2]|0;HEAP32[$diffData+8>>2]=HEAP32[$59+8>>2]|0;HEAP32[$diffData+12>>2]=HEAP32[$59+12>>2]|0;
 $481 = (($diffData) + 8|0);
 $482 = Math_fround(HEAPF32[$481>>2]);
 dest=$aveWheelSpeedContributions+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $483 = ($46|0)==(0);
 if ($483) {
  $490 = 0;
 } else {
  $i8$0162 = 0;
  while(1) {
   $484 = (__ZNK5physx27PxVehicleDifferentialNWData16getIsDrivenWheelEj($diffData,$i8$0162)|0);
   $485 = $484 ? $482 : Math_fround(0.0);
   $486 = (($aveWheelSpeedContributions) + ($i8$0162<<2)|0);
   HEAPF32[$486>>2] = $485;
   $487 = (($i8$0162) + 1)|0;
   $exitcond213 = ($487|0)==($46|0);
   if ($exitcond213) {
    break;
   } else {
    $i8$0162 = $487;
   }
  }
  $490 = 0;
 }
 $488 = Math_fround(HEAPF32[$38>>2]);
 $489 = ($490|0)==(0|0);
 if (!($489)) {
  if ($199) {
   $averageWheelSpeed$0$lcssa$i = Math_fround(0.0);
  } else {
   $averageWheelSpeed$01$i = Math_fround(0.0);$i$02$i = 0;
   while(1) {
    $491 = (($44) + (($i$02$i*208)|0)|0);
    $492 = Math_fround(HEAPF32[$491>>2]);
    $493 = $i$02$i << 2;
    $494 = (($aveWheelSpeedContributions) + ($493<<2)|0);
    $495 = Math_fround(HEAPF32[$494>>2]);
    $496 = Math_fround($492 * $495);
    $497 = Math_fround($averageWheelSpeed$01$i + $496);
    $498 = ((($44) + (($i$02$i*208)|0)|0) + 4|0);
    $499 = Math_fround(HEAPF32[$498>>2]);
    $500 = $493 | 1;
    $501 = (($aveWheelSpeedContributions) + ($500<<2)|0);
    $502 = Math_fround(HEAPF32[$501>>2]);
    $503 = Math_fround($499 * $502);
    $504 = Math_fround($497 + $503);
    $505 = ((($44) + (($i$02$i*208)|0)|0) + 8|0);
    $506 = Math_fround(HEAPF32[$505>>2]);
    $507 = $493 | 2;
    $508 = (($aveWheelSpeedContributions) + ($507<<2)|0);
    $509 = Math_fround(HEAPF32[$508>>2]);
    $510 = Math_fround($506 * $509);
    $511 = Math_fround($504 + $510);
    $512 = ((($44) + (($i$02$i*208)|0)|0) + 12|0);
    $513 = Math_fround(HEAPF32[$512>>2]);
    $514 = $493 | 3;
    $515 = (($aveWheelSpeedContributions) + ($514<<2)|0);
    $516 = Math_fround(HEAPF32[$515>>2]);
    $517 = Math_fround($513 * $516);
    $518 = Math_fround($511 + $517);
    $519 = (($i$02$i) + 1)|0;
    $exitcond$i4 = ($519|0)==($48|0);
    if ($exitcond$i4) {
     $averageWheelSpeed$0$lcssa$i = $518;
     break;
    } else {
     $averageWheelSpeed$01$i = $518;$i$02$i = $519;
    }
   }
  }
  $520 = Math_fround($435 * $averageWheelSpeed$0$lcssa$i);
  $521 = Math_fround($520 - $488);
  $522 = (($490) + 8|0);
  HEAPF32[$522>>2] = $521;
 }
 dest=$isAccelApplied+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $$not = $523 ^ 1;
 $brmerge = $199 | $$not;
 if (!($brmerge)) {
  $i9$0159 = 0;
  while(1) {
   $524 = $i9$0159 << 2;
   $525 = (($aveWheelSpeedContributions) + ($524<<2)|0);
   $526 = (($isAccelApplied) + ($524)|0);
   $527 = Math_fround(HEAPF32[$525>>2]);
   $528 = $527 != Math_fround(0.0);
   $529 = $528&1;
   HEAP8[$526>>0] = $529;
   $$sum9394 = $524 | 1;
   $530 = (($aveWheelSpeedContributions) + ($$sum9394<<2)|0);
   $531 = Math_fround(HEAPF32[$530>>2]);
   $532 = $531 != Math_fround(0.0);
   $533 = (($isAccelApplied) + ($$sum9394)|0);
   $534 = $532&1;
   HEAP8[$533>>0] = $534;
   $$sum9798 = $524 | 2;
   $535 = (($aveWheelSpeedContributions) + ($$sum9798<<2)|0);
   $536 = Math_fround(HEAPF32[$535>>2]);
   $537 = $536 != Math_fround(0.0);
   $538 = (($isAccelApplied) + ($$sum9798)|0);
   $539 = $537&1;
   HEAP8[$538>>0] = $539;
   $$sum101102 = $524 | 3;
   $540 = (($aveWheelSpeedContributions) + ($$sum101102<<2)|0);
   $541 = Math_fround(HEAPF32[$540>>2]);
   $542 = $541 != Math_fround(0.0);
   $543 = (($isAccelApplied) + ($$sum101102)|0);
   $544 = $542&1;
   HEAP8[$543>>0] = $544;
   $545 = (($i9$0159) + 1)|0;
   $exitcond211 = ($545|0)==($48|0);
   if ($exitcond211) {
    break;
   } else {
    $i9$0159 = $545;
   }
  }
 }
 dest=$steerAngles+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 if ($483) {
  dest=$diffTorqueRatios+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $1119 = $diffTorqueRatios;
 } else {
  $i10$0153 = 0;
  while(1) {
   $546 = (__ZNK5physx22PxVehicleWheelsSimData12getWheelDataEj($4,$i10$0153)|0);
   $547 = (($546) + 28|0);
   $548 = Math_fround(HEAPF32[$547>>2]);
   $549 = (($546) + 32|0);
   $550 = Math_fround(HEAPF32[$549>>2]);
   $551 = Math_fround($446 * $548);
   $552 = Math_fround($551 + $550);
   $553 = (($steerAngles) + ($i10$0153<<2)|0);
   HEAPF32[$553>>2] = $552;
   $554 = (($i10$0153) + 1)|0;
   $exitcond210 = ($554|0)==($46|0);
   if ($exitcond210) {
    break;
   } else {
    $i10$0153 = $554;
   }
  }
  dest=$diffTorqueRatios+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  if ($483) {
   $1119 = $diffTorqueRatios;
  } else {
   $i11$0150 = 0;
   while(1) {
    $555 = (__ZNK5physx27PxVehicleDifferentialNWData16getIsDrivenWheelEj($diffData,$i11$0150)|0);
    $556 = $555 ? $482 : Math_fround(0.0);
    $557 = (($diffTorqueRatios) + ($i11$0150<<2)|0);
    HEAPF32[$557>>2] = $556;
    $558 = (($i11$0150) + 1)|0;
    $exitcond209 = ($558|0)==($46|0);
    if ($exitcond209) {
     $1119 = $diffTorqueRatios;
     break;
    } else {
     $i11$0150 = $558;
    }
   }
  }
 }
 if ($199) {
  $1190 = $386;$1193 = $388;$1196 = $391;$655 = $348;$658 = $327;$660 = $334;$663 = $341;$690 = $376;$692 = $378;$695 = $381;
 } else {
  $i12$0147 = 0;
  while(1) {
   $559 = $i12$0147 << 2;
   $560 = (($wheelQueryResults) + (($559*148)|0)|0);
   $561 = ((($44) + (($i12$0147*208)|0)|0) + 196|0);
   $562 = HEAP32[$561>>2]|0;
   $563 = ($562|0)==(0|0);
   if ($563) {
    $$sum8788 = $559 | 1;
    $647 = (($wheelQueryResults) + (($$sum8788*148)|0)|0);
    $$sum8990 = $559 | 2;
    $648 = (($wheelQueryResults) + (($$sum8990*148)|0)|0);
    $$sum9192 = $559 | 3;
    $649 = (($wheelQueryResults) + (($$sum9192*148)|0)|0);
    ;HEAP32[$560+0>>2]=0|0;HEAP32[$560+4>>2]=0|0;HEAP32[$560+8>>2]=0|0;HEAP32[$560+12>>2]=0|0;HEAP32[$560+16>>2]=0|0;HEAP32[$560+20>>2]=0|0;HEAP32[$560+24>>2]=0|0;
    ;HEAP32[$647+0>>2]=0|0;HEAP32[$647+4>>2]=0|0;HEAP32[$647+8>>2]=0|0;HEAP32[$647+12>>2]=0|0;HEAP32[$647+16>>2]=0|0;HEAP32[$647+20>>2]=0|0;HEAP32[$647+24>>2]=0|0;
    ;HEAP32[$648+0>>2]=0|0;HEAP32[$648+4>>2]=0|0;HEAP32[$648+8>>2]=0|0;HEAP32[$648+12>>2]=0|0;HEAP32[$648+16>>2]=0|0;HEAP32[$648+20>>2]=0|0;HEAP32[$648+24>>2]=0|0;
    ;HEAP32[$649+0>>2]=0|0;HEAP32[$649+4>>2]=0|0;HEAP32[$649+8>>2]=0|0;HEAP32[$649+12>>2]=0|0;HEAP32[$649+16>>2]=0|0;HEAP32[$649+20>>2]=0|0;HEAP32[$649+24>>2]=0|0;
   } else {
    $564 = ((($44) + (($i12$0147*208)|0)|0) + 80|0);
    $565 = ((($44) + (($i12$0147*208)|0)|0) + 128|0);
    $566 = ((($44) + (($i12$0147*208)|0)|0) + 176|0);
    $567 = Math_fround(HEAPF32[$564>>2]);
    HEAPF32[$560>>2] = $567;
    $568 = ((($44) + (($i12$0147*208)|0)|0) + 84|0);
    $569 = Math_fround(HEAPF32[$568>>2]);
    $570 = ((($wheelQueryResults) + (($559*148)|0)|0) + 4|0);
    HEAPF32[$570>>2] = $569;
    $571 = ((($44) + (($i12$0147*208)|0)|0) + 88|0);
    $572 = Math_fround(HEAPF32[$571>>2]);
    $573 = ((($wheelQueryResults) + (($559*148)|0)|0) + 8|0);
    HEAPF32[$573>>2] = $572;
    $574 = Math_fround(HEAPF32[$565>>2]);
    $575 = ((($wheelQueryResults) + (($559*148)|0)|0) + 12|0);
    HEAPF32[$575>>2] = $574;
    $576 = ((($44) + (($i12$0147*208)|0)|0) + 132|0);
    $577 = Math_fround(HEAPF32[$576>>2]);
    $578 = ((($wheelQueryResults) + (($559*148)|0)|0) + 16|0);
    HEAPF32[$578>>2] = $577;
    $579 = ((($44) + (($i12$0147*208)|0)|0) + 136|0);
    $580 = Math_fround(HEAPF32[$579>>2]);
    $581 = ((($wheelQueryResults) + (($559*148)|0)|0) + 20|0);
    HEAPF32[$581>>2] = $580;
    $582 = Math_fround(HEAPF32[$566>>2]);
    $583 = ((($wheelQueryResults) + (($559*148)|0)|0) + 24|0);
    HEAPF32[$583>>2] = $582;
    $584 = ((($44) + (($i12$0147*208)|0)|0) + 92|0);
    $585 = Math_fround(HEAPF32[$584>>2]);
    $$sum4546 = $559 | 1;
    $586 = (($wheelQueryResults) + (($$sum4546*148)|0)|0);
    HEAPF32[$586>>2] = $585;
    $587 = ((($44) + (($i12$0147*208)|0)|0) + 96|0);
    $588 = Math_fround(HEAPF32[$587>>2]);
    $589 = ((($wheelQueryResults) + (($$sum4546*148)|0)|0) + 4|0);
    HEAPF32[$589>>2] = $588;
    $590 = ((($44) + (($i12$0147*208)|0)|0) + 100|0);
    $591 = Math_fround(HEAPF32[$590>>2]);
    $592 = ((($wheelQueryResults) + (($$sum4546*148)|0)|0) + 8|0);
    HEAPF32[$592>>2] = $591;
    $593 = ((($44) + (($i12$0147*208)|0)|0) + 140|0);
    $594 = Math_fround(HEAPF32[$593>>2]);
    $595 = ((($wheelQueryResults) + (($$sum4546*148)|0)|0) + 12|0);
    HEAPF32[$595>>2] = $594;
    $596 = ((($44) + (($i12$0147*208)|0)|0) + 144|0);
    $597 = Math_fround(HEAPF32[$596>>2]);
    $598 = ((($wheelQueryResults) + (($$sum4546*148)|0)|0) + 16|0);
    HEAPF32[$598>>2] = $597;
    $599 = ((($44) + (($i12$0147*208)|0)|0) + 148|0);
    $600 = Math_fround(HEAPF32[$599>>2]);
    $601 = ((($wheelQueryResults) + (($$sum4546*148)|0)|0) + 20|0);
    HEAPF32[$601>>2] = $600;
    $602 = ((($44) + (($i12$0147*208)|0)|0) + 180|0);
    $603 = Math_fround(HEAPF32[$602>>2]);
    $604 = ((($wheelQueryResults) + (($$sum4546*148)|0)|0) + 24|0);
    HEAPF32[$604>>2] = $603;
    $605 = ((($44) + (($i12$0147*208)|0)|0) + 104|0);
    $606 = Math_fround(HEAPF32[$605>>2]);
    $$sum5960 = $559 | 2;
    $607 = (($wheelQueryResults) + (($$sum5960*148)|0)|0);
    HEAPF32[$607>>2] = $606;
    $608 = ((($44) + (($i12$0147*208)|0)|0) + 108|0);
    $609 = Math_fround(HEAPF32[$608>>2]);
    $610 = ((($wheelQueryResults) + (($$sum5960*148)|0)|0) + 4|0);
    HEAPF32[$610>>2] = $609;
    $611 = ((($44) + (($i12$0147*208)|0)|0) + 112|0);
    $612 = Math_fround(HEAPF32[$611>>2]);
    $613 = ((($wheelQueryResults) + (($$sum5960*148)|0)|0) + 8|0);
    HEAPF32[$613>>2] = $612;
    $614 = ((($44) + (($i12$0147*208)|0)|0) + 152|0);
    $615 = Math_fround(HEAPF32[$614>>2]);
    $616 = ((($wheelQueryResults) + (($$sum5960*148)|0)|0) + 12|0);
    HEAPF32[$616>>2] = $615;
    $617 = ((($44) + (($i12$0147*208)|0)|0) + 156|0);
    $618 = Math_fround(HEAPF32[$617>>2]);
    $619 = ((($wheelQueryResults) + (($$sum5960*148)|0)|0) + 16|0);
    HEAPF32[$619>>2] = $618;
    $620 = ((($44) + (($i12$0147*208)|0)|0) + 160|0);
    $621 = Math_fround(HEAPF32[$620>>2]);
    $622 = ((($wheelQueryResults) + (($$sum5960*148)|0)|0) + 20|0);
    HEAPF32[$622>>2] = $621;
    $623 = ((($44) + (($i12$0147*208)|0)|0) + 184|0);
    $624 = Math_fround(HEAPF32[$623>>2]);
    $625 = ((($wheelQueryResults) + (($$sum5960*148)|0)|0) + 24|0);
    HEAPF32[$625>>2] = $624;
    $626 = ((($44) + (($i12$0147*208)|0)|0) + 116|0);
    $627 = Math_fround(HEAPF32[$626>>2]);
    $$sum7374 = $559 | 3;
    $628 = (($wheelQueryResults) + (($$sum7374*148)|0)|0);
    HEAPF32[$628>>2] = $627;
    $629 = ((($44) + (($i12$0147*208)|0)|0) + 120|0);
    $630 = Math_fround(HEAPF32[$629>>2]);
    $631 = ((($wheelQueryResults) + (($$sum7374*148)|0)|0) + 4|0);
    HEAPF32[$631>>2] = $630;
    $632 = ((($44) + (($i12$0147*208)|0)|0) + 124|0);
    $633 = Math_fround(HEAPF32[$632>>2]);
    $634 = ((($wheelQueryResults) + (($$sum7374*148)|0)|0) + 8|0);
    HEAPF32[$634>>2] = $633;
    $635 = ((($44) + (($i12$0147*208)|0)|0) + 164|0);
    $636 = Math_fround(HEAPF32[$635>>2]);
    $637 = ((($wheelQueryResults) + (($$sum7374*148)|0)|0) + 12|0);
    HEAPF32[$637>>2] = $636;
    $638 = ((($44) + (($i12$0147*208)|0)|0) + 168|0);
    $639 = Math_fround(HEAPF32[$638>>2]);
    $640 = ((($wheelQueryResults) + (($$sum7374*148)|0)|0) + 16|0);
    HEAPF32[$640>>2] = $639;
    $641 = ((($44) + (($i12$0147*208)|0)|0) + 172|0);
    $642 = Math_fround(HEAPF32[$641>>2]);
    $643 = ((($wheelQueryResults) + (($$sum7374*148)|0)|0) + 20|0);
    HEAPF32[$643>>2] = $642;
    $644 = ((($44) + (($i12$0147*208)|0)|0) + 188|0);
    $645 = Math_fround(HEAPF32[$644>>2]);
    $646 = ((($wheelQueryResults) + (($$sum7374*148)|0)|0) + 24|0);
    HEAPF32[$646>>2] = $645;
   }
   $650 = (($i12$0147) + 1)|0;
   $exitcond208 = ($650|0)==($48|0);
   if ($exitcond208) {
    break;
   } else {
    $i12$0147 = $650;
   }
  }
  $$pre218 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
  $$pre219 = Math_fround(HEAPF32[$379>>2]);
  $$pre220 = Math_fround(HEAPF32[$382>>2]);
  $$pre221 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $$pre222 = Math_fround(HEAPF32[$389>>2]);
  $$pre223 = Math_fround(HEAPF32[$392>>2]);
  $$pre224 = Math_fround(HEAPF32[$351>>2]);
  $$pre225 = Math_fround(HEAPF32[$carChassisTransform>>2]);
  $$pre226 = Math_fround(HEAPF32[$349>>2]);
  $$pre227 = Math_fround(HEAPF32[$350>>2]);
  $1190 = $$pre221;$1193 = $$pre222;$1196 = $$pre223;$655 = $$pre224;$658 = $$pre225;$660 = $$pre226;$663 = $$pre227;$690 = $$pre218;$692 = $$pre219;$695 = $$pre220;
 }
 $651 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $652 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $653 = Math_fround(Math_fround(1.0) * Math_fround(2.0));
 $654 = Math_fround($655 * $655);
 $656 = Math_fround($654 + Math_fround(-0.5));
 $657 = Math_fround($651 * $658);
 $659 = Math_fround($652 * $660);
 $661 = Math_fround($657 + $659);
 $662 = Math_fround($653 * $663);
 $664 = Math_fround($661 + $662);
 $665 = Math_fround($651 * $656);
 $666 = Math_fround($653 * $660);
 $667 = Math_fround($652 * $663);
 $668 = Math_fround($666 - $667);
 $669 = Math_fround($655 * $668);
 $670 = Math_fround($665 + $669);
 $671 = Math_fround($658 * $664);
 $672 = Math_fround($671 + $670);
 $673 = Math_fround($652 * $656);
 $674 = Math_fround($651 * $663);
 $675 = Math_fround($653 * $658);
 $676 = Math_fround($674 - $675);
 $677 = Math_fround($655 * $676);
 $678 = Math_fround($673 + $677);
 $679 = Math_fround($660 * $664);
 $680 = Math_fround($679 + $678);
 $681 = Math_fround($653 * $656);
 $682 = Math_fround($652 * $658);
 $683 = Math_fround($651 * $660);
 $684 = Math_fround($682 - $683);
 $685 = Math_fround($655 * $684);
 $686 = Math_fround($681 + $685);
 $687 = Math_fround($663 * $664);
 $688 = Math_fround($686 + $687);
 $689 = Math_fround($690 * $672);
 $691 = Math_fround($692 * $680);
 $693 = Math_fround($689 + $691);
 $694 = Math_fround($695 * $688);
 $696 = Math_fround($694 + $693);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($696)))));
 $697 = (($vehDriveNW) + 56|0);
 $698 = Math_fround(HEAPF32[$697>>2]);
 $699 = (($vehDriveNW) + 60|0);
 $700 = HEAP32[$699>>2]|0;
 $701 = (($vehDriveNW) + 64|0);
 $702 = HEAP32[$701>>2]|0;
 $703 = $fabsf$i$i$i < $698;
 $704 = $703 ? $700 : $702;
 $705 = (Math_fround(($704>>>0)));
 $706 = Math_fround(Math_fround(1.0) / $705);
 $707 = Math_fround($706 * $timestep);
 $708 = Math_fround(Math_fround(1.0) / $timestep);
 $709 = (($vehDriveNW) + 68|0);
 $710 = Math_fround(HEAPF32[$709>>2]);
 HEAPF32[$constData>>2] = $706;
 $711 = (($constData) + 4|0);
 HEAPF32[$711>>2] = $707;
 $712 = (($constData) + 8|0);
 $713 = Math_fround(HEAPF32[$gravity>>2]);
 HEAPF32[$712>>2] = $713;
 $714 = (($constData) + 12|0);
 $715 = (($gravity) + 4|0);
 $716 = Math_fround(HEAPF32[$715>>2]);
 HEAPF32[$714>>2] = $716;
 $717 = (($constData) + 16|0);
 $718 = (($gravity) + 8|0);
 $719 = Math_fround(HEAPF32[$718>>2]);
 HEAPF32[$717>>2] = $719;
 $720 = (($constData) + 20|0);
 HEAPF32[$720>>2] = $gravityMagnitude;
 $721 = (($constData) + 24|0);
 HEAPF32[$721>>2] = $recipGravityMagnitude;
 $722 = (($constData) + 28|0);
 HEAP8[$722>>0] = 0;
 $723 = (($constData) + 32|0);
 HEAPF32[$723>>2] = $710;
 $724 = (($constData) + 36|0);
 HEAP32[$724>>2] = $62;
 $725 = (($constData) + 40|0);
 HEAP32[$725>>2] = $drivableSurfaceToTireFrictionPairs;
 $726 = ($704|0)==(0);
 if ($726) {
  $1167 = $690;
 } else {
  $727 = (($chassisForce) + 4|0);
  $728 = (($chassisForce) + 8|0);
  $729 = (($chassisTorque) + 4|0);
  $730 = (($chassisTorque) + 8|0);
  $731 = (($driveSimData) + 84|0);
  $732 = (($driveSimData) + 108|0);
  $733 = (($driveSimData) + 4|0);
  $734 = (($driveSimData) + 92|0);
  $735 = (($driveSimData) + 96|0);
  $736 = (($driveSimData) + 100|0);
  $737 = (($implicitSolverInput) + 4|0);
  $738 = (($implicitSolverInput) + 8|0);
  $739 = (($implicitSolverInput) + 12|0);
  $740 = (($implicitSolverInput) + 16|0);
  $741 = (($implicitSolverInput) + 20|0);
  $742 = (($implicitSolverInput) + 24|0);
  $743 = (($implicitSolverInput) + 28|0);
  $744 = (($implicitSolverInput) + 32|0);
  $745 = (($implicitSolverInput) + 36|0);
  $746 = (($implicitSolverInput) + 40|0);
  $747 = (($implicitSolverInput) + 44|0);
  $748 = (($implicitSolverInput) + 48|0);
  $749 = (($implicitSolverInput) + 52|0);
  $750 = (($implicitSolverInput) + 56|0);
  $751 = (($implicitSolverInput) + 60|0);
  $752 = (($implicitSolverInput) + 64|0);
  $753 = (($implicitSolverInput) + 68|0);
  $754 = (($implicitSolverOutput) + 4|0);
  $755 = Math_fround($756 * $435);
  $757 = $523&1;
  $758 = (($inputData) + 4|0);
  $759 = (($inputData) + 8|0);
  $760 = (($inputData) + 12|0);
  $761 = (($inputData) + 16|0);
  $762 = (($inputData) + 20|0);
  $763 = (($inputData) + 24|0);
  $764 = (($inputData) + 28|0);
  $765 = (($inputData) + 32|0);
  $766 = (($inputData) + 36|0);
  $767 = (($inputData) + 40|0);
  $768 = (($inputData) + 44|0);
  $769 = (($inputData) + 48|0);
  $770 = (($inputData) + 52|0);
  $771 = (($inputData) + 56|0);
  $772 = (($inputData) + 60|0);
  $773 = (($inputData) + 64|0);
  $774 = (($inputData) + 68|0);
  $775 = (($inputData) + 72|0);
  $776 = (($inputData) + 76|0);
  $777 = (($inputData) + 80|0);
  $778 = (($inputData) + 84|0);
  $779 = (($inputData) + 88|0);
  $780 = (($704) + -1)|0;
  $781 = Math_fround(-$439);
  $k$0143 = 0;
  while(1) {
   HEAPF32[$chassisForce>>2] = Math_fround(0.0);
   HEAPF32[$727>>2] = Math_fround(0.0);
   HEAPF32[$728>>2] = Math_fround(0.0);
   HEAPF32[$chassisTorque>>2] = Math_fround(0.0);
   HEAPF32[$729>>2] = Math_fround(0.0);
   HEAPF32[$730>>2] = Math_fround(0.0);
   dest=$brakeTorques+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   dest=$isBrakeApplied+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   if (!($199)) {
    $i13$0112 = 0;
    while(1) {
     $782 = (($44) + (($i13$0112*208)|0)|0);
     $783 = $i13$0112 << 2;
     $784 = (($brakeTorques) + ($783<<2)|0);
     $785 = (($isBrakeApplied) + ($783)|0);
     $786 = Math_fround(HEAPF32[$782>>2]);
     $787 = $786 <= Math_fround(-0.0);
     $788 = $787 ? Math_fround(0.0) : Math_fround(1.0);
     $789 = $786 >= Math_fround(0.0);
     $790 = $789 ? $788 : Math_fround(-1.0);
     $791 = Math_fround($790 * $781);
     $792 = ((($42) + (($i13$0112*944)|0)|0) + 212|0);
     $793 = Math_fround(HEAPF32[$792>>2]);
     $794 = Math_fround($793 * $791);
     $795 = Math_fround($441 * $790);
     $796 = ((($42) + (($i13$0112*944)|0)|0) + 216|0);
     $797 = Math_fround(HEAPF32[$796>>2]);
     $798 = Math_fround($797 * $795);
     $799 = Math_fround($794 - $798);
     HEAPF32[$784>>2] = $799;
     $800 = Math_fround(HEAPF32[$792>>2]);
     $801 = Math_fround($439 * $800);
     $802 = Math_fround(HEAPF32[$796>>2]);
     $803 = Math_fround($441 * $802);
     $804 = Math_fround($801 + $803);
     $805 = $804 != Math_fround(0.0);
     $806 = $805&1;
     HEAP8[$785>>0] = $806;
     $807 = ((($44) + (($i13$0112*208)|0)|0) + 4|0);
     $808 = Math_fround(HEAPF32[$807>>2]);
     $809 = $808 <= Math_fround(-0.0);
     $810 = $809 ? Math_fround(0.0) : Math_fround(1.0);
     $811 = $808 >= Math_fround(0.0);
     $812 = $811 ? $810 : Math_fround(-1.0);
     $813 = Math_fround($812 * $781);
     $814 = ((($42) + (($i13$0112*944)|0)|0) + 260|0);
     $815 = Math_fround(HEAPF32[$814>>2]);
     $816 = Math_fround($815 * $813);
     $817 = Math_fround($441 * $812);
     $818 = ((($42) + (($i13$0112*944)|0)|0) + 264|0);
     $819 = Math_fround(HEAPF32[$818>>2]);
     $820 = Math_fround($819 * $817);
     $821 = Math_fround($816 - $820);
     $$sum3334 = $783 | 1;
     $822 = (($brakeTorques) + ($$sum3334<<2)|0);
     HEAPF32[$822>>2] = $821;
     $823 = Math_fround(HEAPF32[$814>>2]);
     $824 = Math_fround($439 * $823);
     $825 = Math_fround(HEAPF32[$818>>2]);
     $826 = Math_fround($441 * $825);
     $827 = Math_fround($824 + $826);
     $828 = $827 != Math_fround(0.0);
     $829 = (($isBrakeApplied) + ($$sum3334)|0);
     $830 = $828&1;
     HEAP8[$829>>0] = $830;
     $831 = ((($44) + (($i13$0112*208)|0)|0) + 8|0);
     $832 = Math_fround(HEAPF32[$831>>2]);
     $833 = $832 <= Math_fround(-0.0);
     $834 = $833 ? Math_fround(0.0) : Math_fround(1.0);
     $835 = $832 >= Math_fround(0.0);
     $836 = $835 ? $834 : Math_fround(-1.0);
     $837 = Math_fround($836 * $781);
     $838 = ((($42) + (($i13$0112*944)|0)|0) + 308|0);
     $839 = Math_fround(HEAPF32[$838>>2]);
     $840 = Math_fround($839 * $837);
     $841 = Math_fround($441 * $836);
     $842 = ((($42) + (($i13$0112*944)|0)|0) + 312|0);
     $843 = Math_fround(HEAPF32[$842>>2]);
     $844 = Math_fround($843 * $841);
     $845 = Math_fround($840 - $844);
     $$sum3738 = $783 | 2;
     $846 = (($brakeTorques) + ($$sum3738<<2)|0);
     HEAPF32[$846>>2] = $845;
     $847 = Math_fround(HEAPF32[$838>>2]);
     $848 = Math_fround($439 * $847);
     $849 = Math_fround(HEAPF32[$842>>2]);
     $850 = Math_fround($441 * $849);
     $851 = Math_fround($848 + $850);
     $852 = $851 != Math_fround(0.0);
     $853 = (($isBrakeApplied) + ($$sum3738)|0);
     $854 = $852&1;
     HEAP8[$853>>0] = $854;
     $855 = ((($44) + (($i13$0112*208)|0)|0) + 12|0);
     $856 = Math_fround(HEAPF32[$855>>2]);
     $857 = $856 <= Math_fround(-0.0);
     $858 = $857 ? Math_fround(0.0) : Math_fround(1.0);
     $859 = $856 >= Math_fround(0.0);
     $860 = $859 ? $858 : Math_fround(-1.0);
     $861 = Math_fround($860 * $781);
     $862 = ((($42) + (($i13$0112*944)|0)|0) + 356|0);
     $863 = Math_fround(HEAPF32[$862>>2]);
     $864 = Math_fround($863 * $861);
     $865 = Math_fround($441 * $860);
     $866 = ((($42) + (($i13$0112*944)|0)|0) + 360|0);
     $867 = Math_fround(HEAPF32[$866>>2]);
     $868 = Math_fround($867 * $865);
     $869 = Math_fround($864 - $868);
     $$sum4142 = $783 | 3;
     $870 = (($brakeTorques) + ($$sum4142<<2)|0);
     HEAPF32[$870>>2] = $869;
     $871 = Math_fround(HEAPF32[$862>>2]);
     $872 = Math_fround($439 * $871);
     $873 = Math_fround(HEAPF32[$866>>2]);
     $874 = Math_fround($441 * $873);
     $875 = Math_fround($872 + $874);
     $876 = $875 != Math_fround(0.0);
     $877 = (($isBrakeApplied) + ($$sum4142)|0);
     $878 = $876&1;
     HEAP8[$877>>0] = $878;
     $879 = (($i13$0112) + 1)|0;
     $exitcond192 = ($879|0)==($48|0);
     if ($exitcond192) {
      break;
     } else {
      $i13$0112 = $879;
     }
    }
   }
   _memset(($outputData|0),0,1112)|0;
   $880 = (($outputData) + 112|0);
   HEAP8[$880>>0] = 1;
   $881 = (($outputData) + 164|0);
   HEAP32[$881>>2] = -1;
   $882 = (($outputData) + 113|0);
   HEAP8[$882>>0] = 1;
   $883 = (($outputData) + 168|0);
   HEAP32[$883>>2] = -1;
   $884 = (($outputData) + 114|0);
   HEAP8[$884>>0] = 1;
   $885 = (($outputData) + 172|0);
   HEAP32[$885>>2] = -1;
   $886 = (($outputData) + 115|0);
   HEAP8[$886>>0] = 1;
   $887 = (($outputData) + 176|0);
   HEAP32[$887>>2] = -1;
   $888 = (($outputData) + 1112|0);
   _memset(($888|0),0,1112)|0;
   $889 = (($outputData) + 1224|0);
   HEAP8[$889>>0] = 1;
   $890 = (($outputData) + 1276|0);
   HEAP32[$890>>2] = -1;
   $891 = (($outputData) + 1225|0);
   HEAP8[$891>>0] = 1;
   $892 = (($outputData) + 1280|0);
   HEAP32[$892>>2] = -1;
   $893 = (($outputData) + 1226|0);
   HEAP8[$893>>0] = 1;
   $894 = (($outputData) + 1284|0);
   HEAP32[$894>>2] = -1;
   $895 = (($outputData) + 1227|0);
   HEAP8[$895>>0] = 1;
   $896 = (($outputData) + 1288|0);
   HEAP32[$896>>2] = -1;
   $897 = (($outputData) + 2224|0);
   _memset(($897|0),0,1112)|0;
   $898 = (($outputData) + 2336|0);
   HEAP8[$898>>0] = 1;
   $899 = (($outputData) + 2388|0);
   HEAP32[$899>>2] = -1;
   $900 = (($outputData) + 2337|0);
   HEAP8[$900>>0] = 1;
   $901 = (($outputData) + 2392|0);
   HEAP32[$901>>2] = -1;
   $902 = (($outputData) + 2338|0);
   HEAP8[$902>>0] = 1;
   $903 = (($outputData) + 2396|0);
   HEAP32[$903>>2] = -1;
   $904 = (($outputData) + 2339|0);
   HEAP8[$904>>0] = 1;
   $905 = (($outputData) + 2400|0);
   HEAP32[$905>>2] = -1;
   $906 = (($outputData) + 3336|0);
   _memset(($906|0),0,1112)|0;
   $907 = (($outputData) + 3448|0);
   HEAP8[$907>>0] = 1;
   $908 = (($outputData) + 3500|0);
   HEAP32[$908>>2] = -1;
   $909 = (($outputData) + 3449|0);
   HEAP8[$909>>0] = 1;
   $910 = (($outputData) + 3504|0);
   HEAP32[$910>>2] = -1;
   $911 = (($outputData) + 3450|0);
   HEAP8[$911>>0] = 1;
   $912 = (($outputData) + 3508|0);
   HEAP32[$912>>2] = -1;
   $913 = (($outputData) + 3451|0);
   HEAP8[$913>>0] = 1;
   $914 = (($outputData) + 3512|0);
   HEAP32[$914>>2] = -1;
   $915 = (($outputData) + 4448|0);
   _memset(($915|0),0,1112)|0;
   $916 = (($outputData) + 4560|0);
   HEAP8[$916>>0] = 1;
   $917 = (($outputData) + 4612|0);
   HEAP32[$917>>2] = -1;
   $918 = (($outputData) + 4561|0);
   HEAP8[$918>>0] = 1;
   $919 = (($outputData) + 4616|0);
   HEAP32[$919>>2] = -1;
   $920 = (($outputData) + 4562|0);
   HEAP8[$920>>0] = 1;
   $921 = (($outputData) + 4620|0);
   HEAP32[$921>>2] = -1;
   $922 = (($outputData) + 4563|0);
   HEAP8[$922>>0] = 1;
   $923 = (($outputData) + 4624|0);
   HEAP32[$923>>2] = -1;
   do {
    if (!($199)) {
     $924 = Math_fround(HEAPF32[$carChassisTransform>>2]);
     $925 = Math_fround(HEAPF32[$349>>2]);
     $926 = Math_fround(HEAPF32[$350>>2]);
     $927 = Math_fround(HEAPF32[$351>>2]);
     $928 = Math_fround(HEAPF32[$352>>2]);
     $929 = Math_fround(HEAPF32[$353>>2]);
     $930 = Math_fround(HEAPF32[$354>>2]);
     $931 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
     $932 = Math_fround(HEAPF32[$379>>2]);
     $933 = Math_fround(HEAPF32[$382>>2]);
     $934 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
     $935 = Math_fround(HEAPF32[$389>>2]);
     $936 = Math_fround(HEAPF32[$392>>2]);
     $937 = ($780|0)==($k$0143|0);
     $$promoted = Math_fround(HEAPF32[$chassisForce>>2]);
     $$promoted120 = Math_fround(HEAPF32[$727>>2]);
     $$promoted121 = Math_fround(HEAPF32[$728>>2]);
     $$promoted122 = Math_fround(HEAPF32[$chassisTorque>>2]);
     $$promoted123 = Math_fround(HEAPF32[$729>>2]);
     $$promoted124 = Math_fround(HEAPF32[$730>>2]);
     $1005 = $$promoted;$1009 = $$promoted120;$1013 = $$promoted121;$1017 = $$promoted122;$1021 = $$promoted123;$1025 = $$promoted124;$i14$0116 = 0;
     while(1) {
      HEAP8[$inputData>>0] = $757;
      $938 = $i14$0116 << 2;
      $939 = (($isAccelApplied) + ($938)|0);
      HEAP32[$758>>2] = $939;
      $940 = (($isBrakeApplied) + ($938)|0);
      HEAP32[$759>>2] = $940;
      $941 = (($steerAngles) + ($938<<2)|0);
      HEAP32[$760>>2] = $941;
      $942 = (($activeWheelStates) + ($938)|0);
      HEAP32[$761>>2] = $942;
      HEAPF32[$762>>2] = $924;
      HEAPF32[$763>>2] = $925;
      HEAPF32[$764>>2] = $926;
      HEAPF32[$765>>2] = $927;
      HEAPF32[$766>>2] = $928;
      HEAPF32[$767>>2] = $929;
      HEAPF32[$768>>2] = $930;
      HEAPF32[$769>>2] = $931;
      HEAPF32[$770>>2] = $932;
      HEAPF32[$771>>2] = $933;
      HEAPF32[$772>>2] = $934;
      HEAPF32[$773>>2] = $935;
      HEAPF32[$774>>2] = $936;
      $943 = (($42) + (($i14$0116*944)|0)|0);
      HEAP32[$775>>2] = $943;
      $944 = (($44) + (($i14$0116*208)|0)|0);
      HEAP32[$776>>2] = $944;
      $945 = (($tires4ForceCalculators) + (($i14$0116*20)|0)|0);
      HEAP32[$777>>2] = $945;
      HEAP32[$778>>2] = $4;
      $946 = (($numActiveWheelsPerBlock4) + ($i14$0116<<2)|0);
      $947 = HEAP32[$946>>2]|0;
      HEAP32[$779>>2] = $947;
      $948 = (($outputData) + (($i14$0116*1112)|0)|0);
      __ZN5physx21processSuspTireWheelsEjRKNS_29ProcessSuspWheelTireConstDataERKNS_29ProcessSuspWheelTireInputDataERNS_30ProcessSuspWheelTireOutputDataE($938,$constData,$inputData,$948);
      $949 = ((($outputData) + (($i14$0116*1112)|0)|0) + 508|0);
      $950 = HEAP32[$776>>2]|0;
      $951 = (($950) + 48|0);
      $952 = Math_fround(HEAPF32[$949>>2]);
      $953 = Math_fround(HEAPF32[$951>>2]);
      $954 = $952 != $953;
      $955 = $954 ? $952 : Math_fround(0.0);
      HEAPF32[$951>>2] = $955;
      $956 = ((($outputData) + (($i14$0116*1112)|0)|0) + 512|0);
      $957 = Math_fround(HEAPF32[$956>>2]);
      $958 = (($950) + 52|0);
      $959 = Math_fround(HEAPF32[$958>>2]);
      $960 = $957 != $959;
      $961 = $960 ? $957 : Math_fround(0.0);
      HEAPF32[$958>>2] = $961;
      $962 = ((($outputData) + (($i14$0116*1112)|0)|0) + 516|0);
      $963 = Math_fround(HEAPF32[$962>>2]);
      $964 = (($950) + 56|0);
      $965 = Math_fround(HEAPF32[$964>>2]);
      $966 = $963 != $965;
      $967 = $966 ? $963 : Math_fround(0.0);
      HEAPF32[$964>>2] = $967;
      $968 = ((($outputData) + (($i14$0116*1112)|0)|0) + 520|0);
      $969 = Math_fround(HEAPF32[$968>>2]);
      $970 = (($950) + 60|0);
      $971 = Math_fround(HEAPF32[$970>>2]);
      $972 = $969 != $971;
      $973 = $972 ? $969 : Math_fround(0.0);
      HEAPF32[$970>>2] = $973;
      $974 = ((($outputData) + (($i14$0116*1112)|0)|0) + 524|0);
      $975 = (($950) + 64|0);
      $976 = Math_fround(HEAPF32[$974>>2]);
      $977 = Math_fround(HEAPF32[$975>>2]);
      $978 = $976 != $977;
      $979 = $978 ? $976 : Math_fround(0.0);
      HEAPF32[$975>>2] = $979;
      $980 = ((($outputData) + (($i14$0116*1112)|0)|0) + 528|0);
      $981 = Math_fround(HEAPF32[$980>>2]);
      $982 = (($950) + 68|0);
      $983 = Math_fround(HEAPF32[$982>>2]);
      $984 = $981 != $983;
      $985 = $984 ? $981 : Math_fround(0.0);
      HEAPF32[$982>>2] = $985;
      $986 = ((($outputData) + (($i14$0116*1112)|0)|0) + 532|0);
      $987 = Math_fround(HEAPF32[$986>>2]);
      $988 = (($950) + 72|0);
      $989 = Math_fround(HEAPF32[$988>>2]);
      $990 = $987 != $989;
      $991 = $990 ? $987 : Math_fround(0.0);
      HEAPF32[$988>>2] = $991;
      $992 = ((($outputData) + (($i14$0116*1112)|0)|0) + 536|0);
      $993 = Math_fround(HEAPF32[$992>>2]);
      $994 = (($950) + 76|0);
      $995 = Math_fround(HEAPF32[$994>>2]);
      $996 = $993 != $995;
      $997 = $996 ? $993 : Math_fround(0.0);
      HEAPF32[$994>>2] = $997;
      if ($937) {
       $998 = ((($outputData) + (($i14$0116*1112)|0)|0) + 888|0);
       $999 = ((($outputData) + (($i14$0116*1112)|0)|0) + 904|0);
       $1000 = ((($outputData) + (($i14$0116*1112)|0)|0) + 968|0);
       $1001 = ((($outputData) + (($i14$0116*1112)|0)|0) + 984|0);
       __ZN5physx19updateCachedHitDataEPKjPKNS_6PxVec4EPKfS6_PNS_23PxVehicleWheels4DynDataE($998,$999,$1000,$1001,$944);
      }
      $1002 = ((($outputData) + (($i14$0116*1112)|0)|0) + 484|0);
      $1003 = Math_fround(HEAPF32[$1002>>2]);
      $1004 = Math_fround($1003 + $1005);
      $1006 = ((($outputData) + (($i14$0116*1112)|0)|0) + 488|0);
      $1007 = Math_fround(HEAPF32[$1006>>2]);
      $1008 = Math_fround($1007 + $1009);
      $1010 = ((($outputData) + (($i14$0116*1112)|0)|0) + 492|0);
      $1011 = Math_fround(HEAPF32[$1010>>2]);
      $1012 = Math_fround($1011 + $1013);
      $1014 = ((($outputData) + (($i14$0116*1112)|0)|0) + 496|0);
      $1015 = Math_fround(HEAPF32[$1014>>2]);
      $1016 = Math_fround($1015 + $1017);
      $1018 = ((($outputData) + (($i14$0116*1112)|0)|0) + 500|0);
      $1019 = Math_fround(HEAPF32[$1018>>2]);
      $1020 = Math_fround($1019 + $1021);
      $1022 = ((($outputData) + (($i14$0116*1112)|0)|0) + 504|0);
      $1023 = Math_fround(HEAPF32[$1022>>2]);
      $1024 = Math_fround($1023 + $1025);
      $1026 = ((($44) + (($i14$0116*208)|0)|0) + 192|0);
      $1027 = HEAP32[$1026>>2]|0;
      $1028 = (($1027) + 4|0);
      $1029 = ((($outputData) + (($i14$0116*1112)|0)|0) + 540|0);
      (__ZN5physx25PxVehicleConstraintShader21VehicleConstraintDataaSERKS1_($1028,$1029)|0);
      $1030 = HEAP32[$760>>2]|0;
      $1031 = (($wheelQueryResults) + (($938*148)|0)|0);
      __ZN5physx15PxVehicleUpdate25storeSuspWheelTireResultsERKNS_30ProcessSuspWheelTireOutputDataEPKfPNS_18PxWheelQueryResultEj($948,$1030,$1031,$947);
      $1032 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
      $1033 = ($947|0)==(0);
      if (!($1033)) {
       $i$01$i = 0;
       while(1) {
        $1034 = (((($outputData) + (($i14$0116*1112)|0)|0) + ($i$01$i<<2)|0) + 1000|0);
        $1035 = HEAP32[$1034>>2]|0;
        $$sum26 = (($i$01$i) + ($938))|0;
        $1036 = ((($1032) + (($$sum26*56)|0)|0) + 28|0);
        HEAP32[$1036>>2] = $1035;
        $1037 = (((($outputData) + (($i14$0116*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1016|0);
        $1038 = Math_fround(HEAPF32[$1037>>2]);
        $1039 = ((($1032) + (($$sum26*56)|0)|0) + 32|0);
        $1040 = Math_fround(HEAPF32[$1039>>2]);
        $1041 = Math_fround($1038 + $1040);
        HEAPF32[$1039>>2] = $1041;
        $1042 = (((($outputData) + (($i14$0116*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1020|0);
        $1043 = Math_fround(HEAPF32[$1042>>2]);
        $1044 = ((($1032) + (($$sum26*56)|0)|0) + 36|0);
        $1045 = Math_fround(HEAPF32[$1044>>2]);
        $1046 = Math_fround($1043 + $1045);
        HEAPF32[$1044>>2] = $1046;
        $1047 = (((($outputData) + (($i14$0116*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1024|0);
        $1048 = Math_fround(HEAPF32[$1047>>2]);
        $1049 = ((($1032) + (($$sum26*56)|0)|0) + 40|0);
        $1050 = Math_fround(HEAPF32[$1049>>2]);
        $1051 = Math_fround($1048 + $1050);
        HEAPF32[$1049>>2] = $1051;
        $1052 = (((($outputData) + (($i14$0116*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1064|0);
        $1053 = Math_fround(HEAPF32[$1052>>2]);
        $1054 = ((($1032) + (($$sum26*56)|0)|0) + 44|0);
        HEAPF32[$1054>>2] = $1053;
        $1055 = (((($outputData) + (($i14$0116*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1068|0);
        $1056 = Math_fround(HEAPF32[$1055>>2]);
        $1057 = ((($1032) + (($$sum26*56)|0)|0) + 48|0);
        HEAPF32[$1057>>2] = $1056;
        $1058 = (((($outputData) + (($i14$0116*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1072|0);
        $1059 = Math_fround(HEAPF32[$1058>>2]);
        $1060 = ((($1032) + (($$sum26*56)|0)|0) + 52|0);
        HEAPF32[$1060>>2] = $1059;
        $1061 = (($i$01$i) + 1)|0;
        $exitcond$i1 = ($1061|0)==($947|0);
        if ($exitcond$i1) {
         break;
        } else {
         $i$01$i = $1061;
        }
       }
      }
      $1062 = (($i14$0116) + 1)|0;
      $exitcond198 = ($1062|0)==($48|0);
      if ($exitcond198) {
       break;
      } else {
       $1005 = $1004;$1009 = $1008;$1013 = $1012;$1017 = $1016;$1021 = $1020;$1025 = $1024;$i14$0116 = $1062;
      }
     }
     HEAPF32[$chassisForce>>2] = $1004;
     HEAPF32[$727>>2] = $1008;
     HEAPF32[$728>>2] = $1012;
     HEAPF32[$chassisTorque>>2] = $1016;
     HEAPF32[$729>>2] = $1020;
     HEAPF32[$730>>2] = $1024;
     if ($199) {
      break;
     } else {
      $i15$0130 = 0;
     }
     while(1) {
      $1063 = ((($outputData) + (($i15$0130*1112)|0)|0) + 468|0);
      $1064 = Math_fround(HEAPF32[$1063>>2]);
      $1065 = $i15$0130 << 2;
      $1066 = (($inputData) + ($1065<<2)|0);
      HEAPF32[$1066>>2] = $1064;
      $1067 = ((($outputData) + (($i15$0130*1112)|0)|0) + 472|0);
      $1068 = Math_fround(HEAPF32[$1067>>2]);
      $1069 = $1065 | 1;
      $1070 = (($inputData) + ($1069<<2)|0);
      HEAPF32[$1070>>2] = $1068;
      $1071 = ((($outputData) + (($i15$0130*1112)|0)|0) + 476|0);
      $1072 = Math_fround(HEAPF32[$1071>>2]);
      $1073 = $1065 | 2;
      $1074 = (($inputData) + ($1073<<2)|0);
      HEAPF32[$1074>>2] = $1072;
      $1075 = ((($outputData) + (($i15$0130*1112)|0)|0) + 480|0);
      $1076 = Math_fround(HEAPF32[$1075>>2]);
      $1077 = $1065 | 3;
      $1078 = (($inputData) + ($1077<<2)|0);
      HEAPF32[$1078>>2] = $1076;
      $1079 = (($i15$0130) + 1)|0;
      $exitcond199 = ($1079|0)==($48|0);
      if ($exitcond199) {
       break;
      } else {
       $i15$0130 = $1079;
      }
     }
    }
   } while(0);
   $1080 = Math_fround(HEAPF32[$38>>2]);
   $1081 = Math_fround(HEAPF32[$731>>2]);
   $1082 = Math_fround($autoboxCompensatedAnalogAccel$0 * $1081);
   $1083 = Math_fround(HEAPF32[$732>>2]);
   $1084 = Math_fround($1080 * $1083);
   $1085 = HEAP32[$54>>2]|0;
   do {
    if ((($1085|0) == 1)) {
     label = 98;
    } else if ((($1085|0) == 0)) {
     $$0$i$i = Math_fround(0.0);
    } else {
     $1086 = Math_fround(HEAPF32[$driveSimData>>2]);
     $1087 = $1086 > $1084;
     if ($1087) {
      label = 98;
      break;
     }
     $1089 = Math_fround(HEAPF32[$733>>2]);
     $i$07$i$i = 1;$x0$08$i$i = $1086;$y0$06$i$i = $1089;
     while(1) {
      $1092 = $i$07$i$i << 1;
      $1093 = (($driveSimData) + ($1092<<2)|0);
      $1094 = Math_fround(HEAPF32[$1093>>2]);
      $1095 = $1092 | 1;
      $1096 = (($driveSimData) + ($1095<<2)|0);
      $1097 = Math_fround(HEAPF32[$1096>>2]);
      $1098 = $x0$08$i$i <= $1084;
      $1099 = $1094 > $1084;
      $or$cond$i$i = $1098 & $1099;
      $1091 = (($i$07$i$i) + 1)|0;
      if ($or$cond$i$i) {
       label = 102;
       break;
      }
      $1090 = ($1091>>>0)<($1085>>>0);
      if ($1090) {
       $i$07$i$i = $1091;$x0$08$i$i = $1094;$y0$06$i$i = $1097;
      } else {
       label = 103;
       break;
      }
     }
     if ((label|0) == 102) {
      label = 0;
      $1100 = Math_fround($1097 - $y0$06$i$i);
      $1101 = Math_fround($1084 - $x0$08$i$i);
      $1102 = Math_fround($1101 * $1100);
      $1103 = Math_fround($1094 - $x0$08$i$i);
      $1104 = Math_fround($1102 / $1103);
      $1105 = Math_fround($y0$06$i$i + $1104);
      $$0$i$i = $1105;
      break;
     }
     else if ((label|0) == 103) {
      label = 0;
      $1106 = $1085 << 1;
      $1107 = (($1106) + -2)|0;
      $1108 = $1107 | 1;
      $1109 = (($driveSimData) + ($1108<<2)|0);
      $1110 = Math_fround(HEAPF32[$1109>>2]);
      $$0$i$i = $1110;
      break;
     }
    }
   } while(0);
   if ((label|0) == 98) {
    label = 0;
    $1088 = Math_fround(HEAPF32[$733>>2]);
    $$0$i$i = $1088;
   }
   $1111 = Math_fround($1082 * $$0$i$i);
   $1112 = (0|0)==(0|0);
   if (!($1112)) {
    $1113 = (0 + 4|0);
    HEAPF32[$1113>>2] = $1111;
   }
   $1114 = Math_fround(HEAPF32[$734>>2]);
   $$val = Math_fround(HEAPF32[$736>>2]);
   $$val24 = Math_fround(HEAPF32[$735>>2]);
   $1115 = $424 ? $$val : $$val24;
   $1116 = Math_fround($1114 - $1115);
   $1117 = Math_fround($autoboxCompensatedAnalogAccel$0 * $1116);
   $1118 = Math_fround($1115 + $1117);
   HEAPF32[$implicitSolverInput>>2] = $707;
   HEAPF32[$737>>2] = $439;
   HEAPF32[$738>>2] = $441;
   HEAPF32[$739>>2] = $756;
   HEAPF32[$740>>2] = $435;
   HEAP32[$741>>2] = $428;
   HEAP32[$742>>2] = $430;
   HEAPF32[$743>>2] = $1111;
   HEAPF32[$744>>2] = $1118;
   HEAP32[$745>>2] = $1119;
   HEAP32[$746>>2] = $aveWheelSpeedContributions;
   HEAP32[$747>>2] = $brakeTorques;
   HEAP32[$748>>2] = $isBrakeApplied;
   HEAP32[$749>>2] = $inputData;
   HEAP32[$750>>2] = $48;
   HEAP32[$751>>2] = $46;
   HEAP32[$752>>2] = $42;
   HEAP32[$753>>2] = $driveSimData;
   HEAP32[$implicitSolverOutput>>2] = $44;
   HEAP32[$754>>2] = $37;
   __ZN5physx50solveDriveNWInternalDynamicsEnginePlusDrivenWheelsERKNS_19ImplicitSolverInputEPNS_20ImplicitSolverOutputE($implicitSolverInput,$implicitSolverOutput);
   if (!($199)) {
    $i17$0140 = 0;
    while(1) {
     $1120 = $i17$0140 << 2;
     $j$02$i = 0;
     while(1) {
      $1121 = ((($44) + (($i17$0140*208)|0)|0) + ($j$02$i<<2)|0);
      $1122 = Math_fround(HEAPF32[$1121>>2]);
      $1123 = (((($outputData) + (($i17$0140*1112)|0)|0) + ($j$02$i<<2)|0) + 292|0);
      $1124 = Math_fround(HEAPF32[$1123>>2]);
      $1125 = (((($42) + (($i17$0140*944)|0)|0) + (($j$02$i*48)|0)|0) + 12|0);
      $1126 = Math_fround(HEAPF32[$1125>>2]);
      $1127 = Math_fround(-$1126);
      $1128 = $1124 > $1127;
      do {
       if ($1128) {
        $$sum = (($j$02$i) + ($1120))|0;
        $1129 = (($isBrakeApplied) + ($$sum)|0);
        $1130 = HEAP8[$1129>>0]|0;
        $1131 = ($1130<<24>>24)==(0);
        if (!($1131)) {
         $wheelOmega$0$i = $1122;
         break;
        }
        $1132 = (($diffTorqueRatios) + ($$sum<<2)|0);
        $1133 = Math_fround(HEAPF32[$1132>>2]);
        $1134 = Math_fround($755 * $1133);
        $1135 = Math_fround($1111 * $1134);
        $1136 = $1135 == Math_fround(0.0);
        if (!($1136)) {
         $wheelOmega$0$i = $1122;
         break;
        }
        $1137 = (((($outputData) + (($i17$0140*1112)|0)|0) + ($j$02$i<<2)|0) + 452|0);
        $1138 = Math_fround(HEAPF32[$1137>>2]);
        $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($1138)))));
        $1139 = Math_fround(HEAPF32[523912>>2]);
        $1140 = $fabsf$i$i1$i < $1139;
        if (!($1140)) {
         $wheelOmega$0$i = $1122;
         break;
        }
        $1141 = (((($42) + (($i17$0140*944)|0)|0) + (($j$02$i*48)|0)|0) + 228|0);
        $1142 = Math_fround(HEAPF32[$1141>>2]);
        $1143 = Math_fround(HEAPF32[523920>>2]);
        $1144 = Math_fround($fabsf$i$i1$i * $1143);
        $1145 = Math_fround($1138 * $1142);
        $1146 = Math_fround(Math_fround(1.0) - $1144);
        $1147 = Math_fround($1145 * $1146);
        $1148 = Math_fround($1122 * $1144);
        $1149 = Math_fround($1148 + $1147);
        $wheelOmega$0$i = $1149;
       } else {
        $wheelOmega$0$i = $1122;
       }
      } while(0);
      $1150 = (((($44) + (($i17$0140*208)|0)|0) + ($j$02$i<<2)|0) + 32|0);
      $1151 = Math_fround(HEAPF32[$1150>>2]);
      $1152 = Math_fround($707 * $wheelOmega$0$i);
      $1153 = Math_fround($1151 + $1152);
      $1154 = Math_fround($1153 + Math_fround(-31.415927886962890625));
      $1155 = Math_fround(Math_fround(-31.415927886962890625) - $1153);
      $1156 = Math_fround($1153 + Math_fround(31.415927886962890625));
      $1157 = $1155 >= Math_fround(0.0);
      $1158 = $1157 ? $1156 : $1153;
      $1159 = $1154 >= Math_fround(0.0);
      $1160 = $1159 ? $1154 : $1158;
      HEAPF32[$1150>>2] = $1160;
      $1161 = (((($44) + (($i17$0140*208)|0)|0) + ($j$02$i<<2)|0) + 16|0);
      HEAPF32[$1161>>2] = $wheelOmega$0$i;
      $1162 = (($j$02$i) + 1)|0;
      $exitcond$i = ($1162|0)==(4);
      if ($exitcond$i) {
       break;
      } else {
       $j$02$i = $1162;
      }
     }
     $1163 = (($i17$0140) + 1)|0;
     $exitcond206 = ($1163|0)==($48|0);
     if ($exitcond206) {
      break;
     } else {
      $i17$0140 = $1163;
     }
    }
   }
   __ZN5physx13integrateBodyEfRKNS_6PxVec3ES2_S2_fRS0_S3_RNS_11PxTransformE($359,$inverseInertia,$chassisForce,$chassisTorque,$707,$carChassisLinVel,$carChassisAngVel,$carChassisTransform);
   $1164 = (($k$0143) + 1)|0;
   $exitcond207 = ($1164|0)==($704|0);
   if ($exitcond207) {
    break;
   } else {
    $k$0143 = $1164;
   }
  }
  $$pre228 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
  $1167 = $$pre228;
 }
 $1165 = (0)==(0);
 $1166 = (($vehicleConcurrentUpdates) + 8|0);
 if ($1165) {
  HEAPF32[$1166>>2] = $1167;
  $1168 = Math_fround(HEAPF32[$379>>2]);
  $1169 = (($vehicleConcurrentUpdates) + 12|0);
  HEAPF32[$1169>>2] = $1168;
  $1170 = Math_fround(HEAPF32[$382>>2]);
  $1171 = (($vehicleConcurrentUpdates) + 16|0);
  HEAPF32[$1171>>2] = $1170;
  $1172 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $1173 = (($vehicleConcurrentUpdates) + 20|0);
  HEAPF32[$1173>>2] = $1172;
  $1174 = Math_fround(HEAPF32[$389>>2]);
  $1175 = (($vehicleConcurrentUpdates) + 24|0);
  HEAPF32[$1175>>2] = $1174;
  $1176 = Math_fround(HEAPF32[$392>>2]);
  $1177 = (($vehicleConcurrentUpdates) + 28|0);
  HEAPF32[$1177>>2] = $1176;
 } else {
  $1178 = Math_fround($1167 - $690);
  $1179 = Math_fround(HEAPF32[$379>>2]);
  $1180 = Math_fround($1179 - $692);
  $1181 = Math_fround(HEAPF32[$382>>2]);
  $1182 = Math_fround($1181 - $695);
  $1183 = Math_fround($708 * $1178);
  $1184 = Math_fround($708 * $1180);
  $1185 = Math_fround($708 * $1182);
  HEAPF32[$1166>>2] = $1183;
  $1186 = (($vehicleConcurrentUpdates) + 12|0);
  HEAPF32[$1186>>2] = $1184;
  $1187 = (($vehicleConcurrentUpdates) + 16|0);
  HEAPF32[$1187>>2] = $1185;
  $1188 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $1189 = Math_fround($1188 - $1190);
  $1191 = Math_fround(HEAPF32[$389>>2]);
  $1192 = Math_fround($1191 - $1193);
  $1194 = Math_fround(HEAPF32[$392>>2]);
  $1195 = Math_fround($1194 - $1196);
  $1197 = Math_fround($708 * $1189);
  $1198 = Math_fround($708 * $1192);
  $1199 = Math_fround($708 * $1195);
  $1200 = (($vehicleConcurrentUpdates) + 20|0);
  HEAPF32[$1200>>2] = $1197;
  $1201 = (($vehicleConcurrentUpdates) + 24|0);
  HEAPF32[$1201>>2] = $1198;
  $1202 = (($vehicleConcurrentUpdates) + 28|0);
  HEAPF32[$1202>>2] = $1199;
 }
 HEAPF32[$brakeTorques>>2] = Math_fround(0.0);
 $1203 = (($brakeTorques) + 4|0);
 HEAPF32[$1203>>2] = Math_fround(0.0);
 $1204 = (($brakeTorques) + 8|0);
 HEAPF32[$1204>>2] = Math_fround(0.0);
 $1205 = (($brakeTorques) + 12|0);
 HEAPF32[$1205>>2] = Math_fround(1.0);
 $1206 = (($brakeTorques) + 16|0);
 $1207 = (($brakeTorques) + 20|0);
 $1208 = (($brakeTorques) + 24|0);
 $1209 = (($brakeTorques) + 28|0);
 $1210 = (($brakeTorques) + 32|0);
 $1211 = (($brakeTorques) + 36|0);
 $1212 = (($brakeTorques) + 40|0);
 ;HEAP32[$1206+0>>2]=0|0;HEAP32[$1206+4>>2]=0|0;HEAP32[$1206+8>>2]=0|0;HEAP32[$1206+12>>2]=0|0;HEAP32[$1206+16>>2]=0|0;HEAP32[$1206+20>>2]=0|0;
 HEAPF32[$1212>>2] = Math_fround(1.0);
 $1213 = (($brakeTorques) + 44|0);
 $1214 = (($brakeTorques) + 48|0);
 $1215 = (($brakeTorques) + 52|0);
 $1216 = (($brakeTorques) + 56|0);
 $1217 = (($brakeTorques) + 60|0);
 $1218 = (($brakeTorques) + 64|0);
 $1219 = (($brakeTorques) + 68|0);
 ;HEAP32[$1213+0>>2]=0|0;HEAP32[$1213+4>>2]=0|0;HEAP32[$1213+8>>2]=0|0;HEAP32[$1213+12>>2]=0|0;HEAP32[$1213+16>>2]=0|0;HEAP32[$1213+20>>2]=0|0;
 HEAPF32[$1219>>2] = Math_fround(1.0);
 $1220 = (($brakeTorques) + 72|0);
 $1221 = (($brakeTorques) + 76|0);
 $1222 = (($brakeTorques) + 80|0);
 $1223 = (($brakeTorques) + 84|0);
 $1224 = (($brakeTorques) + 88|0);
 $1225 = (($brakeTorques) + 92|0);
 $1226 = (($brakeTorques) + 96|0);
 ;HEAP32[$1220+0>>2]=0|0;HEAP32[$1220+4>>2]=0|0;HEAP32[$1220+8>>2]=0|0;HEAP32[$1220+12>>2]=0|0;HEAP32[$1220+16>>2]=0|0;HEAP32[$1220+20>>2]=0|0;
 HEAPF32[$1226>>2] = Math_fround(1.0);
 $1227 = (($brakeTorques) + 100|0);
 HEAPF32[$1227>>2] = Math_fround(0.0);
 $1228 = (($brakeTorques) + 104|0);
 HEAPF32[$1228>>2] = Math_fround(0.0);
 $1229 = (($brakeTorques) + 108|0);
 HEAPF32[$1229>>2] = Math_fround(0.0);
 $1230 = HEAP32[$numActiveWheelsPerBlock4>>2]|0;
 __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($42,$44,$wheelQueryResults,$1230,$carChassisCMLocalPose,$brakeTorques);
 $1231 = Math_fround(HEAPF32[$brakeTorques>>2]);
 $1232 = (($wheelQueryResults) + 120|0);
 HEAPF32[$1232>>2] = $1231;
 $1233 = Math_fround(HEAPF32[$1203>>2]);
 $1234 = (($wheelQueryResults) + 124|0);
 HEAPF32[$1234>>2] = $1233;
 $1235 = Math_fround(HEAPF32[$1204>>2]);
 $1236 = (($wheelQueryResults) + 128|0);
 HEAPF32[$1236>>2] = $1235;
 $1237 = Math_fround(HEAPF32[$1205>>2]);
 $1238 = (($wheelQueryResults) + 132|0);
 HEAPF32[$1238>>2] = $1237;
 $1239 = Math_fround(HEAPF32[$1206>>2]);
 $1240 = (($wheelQueryResults) + 136|0);
 HEAPF32[$1240>>2] = $1239;
 $1241 = Math_fround(HEAPF32[$1207>>2]);
 $1242 = (($wheelQueryResults) + 140|0);
 HEAPF32[$1242>>2] = $1241;
 $1243 = Math_fround(HEAPF32[$1208>>2]);
 $1244 = (($wheelQueryResults) + 144|0);
 HEAPF32[$1244>>2] = $1243;
 $1245 = Math_fround(HEAPF32[$1209>>2]);
 $1246 = (($wheelQueryResults) + 268|0);
 HEAPF32[$1246>>2] = $1245;
 $1247 = Math_fround(HEAPF32[$1210>>2]);
 $1248 = (($wheelQueryResults) + 272|0);
 HEAPF32[$1248>>2] = $1247;
 $1249 = Math_fround(HEAPF32[$1211>>2]);
 $1250 = (($wheelQueryResults) + 276|0);
 HEAPF32[$1250>>2] = $1249;
 $1251 = Math_fround(HEAPF32[$1212>>2]);
 $1252 = (($wheelQueryResults) + 280|0);
 HEAPF32[$1252>>2] = $1251;
 $1253 = Math_fround(HEAPF32[$1213>>2]);
 $1254 = (($wheelQueryResults) + 284|0);
 HEAPF32[$1254>>2] = $1253;
 $1255 = Math_fround(HEAPF32[$1214>>2]);
 $1256 = (($wheelQueryResults) + 288|0);
 HEAPF32[$1256>>2] = $1255;
 $1257 = Math_fround(HEAPF32[$1215>>2]);
 $1258 = (($wheelQueryResults) + 292|0);
 HEAPF32[$1258>>2] = $1257;
 $1259 = Math_fround(HEAPF32[$1216>>2]);
 $1260 = (($wheelQueryResults) + 416|0);
 HEAPF32[$1260>>2] = $1259;
 $1261 = Math_fround(HEAPF32[$1217>>2]);
 $1262 = (($wheelQueryResults) + 420|0);
 HEAPF32[$1262>>2] = $1261;
 $1263 = Math_fround(HEAPF32[$1218>>2]);
 $1264 = (($wheelQueryResults) + 424|0);
 HEAPF32[$1264>>2] = $1263;
 $1265 = Math_fround(HEAPF32[$1219>>2]);
 $1266 = (($wheelQueryResults) + 428|0);
 HEAPF32[$1266>>2] = $1265;
 $1267 = Math_fround(HEAPF32[$1220>>2]);
 $1268 = (($wheelQueryResults) + 432|0);
 HEAPF32[$1268>>2] = $1267;
 $1269 = Math_fround(HEAPF32[$1221>>2]);
 $1270 = (($wheelQueryResults) + 436|0);
 HEAPF32[$1270>>2] = $1269;
 $1271 = Math_fround(HEAPF32[$1222>>2]);
 $1272 = (($wheelQueryResults) + 440|0);
 HEAPF32[$1272>>2] = $1271;
 $1273 = Math_fround(HEAPF32[$1223>>2]);
 $1274 = (($wheelQueryResults) + 564|0);
 HEAPF32[$1274>>2] = $1273;
 $1275 = Math_fround(HEAPF32[$1224>>2]);
 $1276 = (($wheelQueryResults) + 568|0);
 HEAPF32[$1276>>2] = $1275;
 $1277 = Math_fround(HEAPF32[$1225>>2]);
 $1278 = (($wheelQueryResults) + 572|0);
 HEAPF32[$1278>>2] = $1277;
 $1279 = Math_fround(HEAPF32[$1226>>2]);
 $1280 = (($wheelQueryResults) + 576|0);
 HEAPF32[$1280>>2] = $1279;
 $1281 = Math_fround(HEAPF32[$1227>>2]);
 $1282 = (($wheelQueryResults) + 580|0);
 HEAPF32[$1282>>2] = $1281;
 $1283 = Math_fround(HEAPF32[$1228>>2]);
 $1284 = (($wheelQueryResults) + 584|0);
 HEAPF32[$1284>>2] = $1283;
 $1285 = Math_fround(HEAPF32[$1229>>2]);
 $1286 = (($wheelQueryResults) + 588|0);
 HEAPF32[$1286>>2] = $1285;
 $1287 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
 HEAPF32[$1287>>2] = $1231;
 $1288 = Math_fround(HEAPF32[$1203>>2]);
 $1289 = (($1287) + 4|0);
 HEAPF32[$1289>>2] = $1288;
 $1290 = Math_fround(HEAPF32[$1204>>2]);
 $1291 = (($1287) + 8|0);
 HEAPF32[$1291>>2] = $1290;
 $1292 = Math_fround(HEAPF32[$1205>>2]);
 $1293 = (($1287) + 12|0);
 HEAPF32[$1293>>2] = $1292;
 $1294 = Math_fround(HEAPF32[$1206>>2]);
 $1295 = (($1287) + 16|0);
 HEAPF32[$1295>>2] = $1294;
 $1296 = Math_fround(HEAPF32[$1207>>2]);
 $1297 = (($1287) + 20|0);
 HEAPF32[$1297>>2] = $1296;
 $1298 = Math_fround(HEAPF32[$1208>>2]);
 $1299 = (($1287) + 24|0);
 HEAPF32[$1299>>2] = $1298;
 $1300 = Math_fround(HEAPF32[$1209>>2]);
 $1301 = (($1287) + 56|0);
 HEAPF32[$1301>>2] = $1300;
 $1302 = Math_fround(HEAPF32[$1210>>2]);
 $1303 = (($1287) + 60|0);
 HEAPF32[$1303>>2] = $1302;
 $1304 = Math_fround(HEAPF32[$1211>>2]);
 $1305 = (($1287) + 64|0);
 HEAPF32[$1305>>2] = $1304;
 $1306 = Math_fround(HEAPF32[$1212>>2]);
 $1307 = (($1287) + 68|0);
 HEAPF32[$1307>>2] = $1306;
 $1308 = Math_fround(HEAPF32[$1213>>2]);
 $1309 = (($1287) + 72|0);
 HEAPF32[$1309>>2] = $1308;
 $1310 = Math_fround(HEAPF32[$1214>>2]);
 $1311 = (($1287) + 76|0);
 HEAPF32[$1311>>2] = $1310;
 $1312 = Math_fround(HEAPF32[$1215>>2]);
 $1313 = (($1287) + 80|0);
 HEAPF32[$1313>>2] = $1312;
 $1314 = Math_fround(HEAPF32[$1216>>2]);
 $1315 = (($1287) + 112|0);
 HEAPF32[$1315>>2] = $1314;
 $1316 = Math_fround(HEAPF32[$1217>>2]);
 $1317 = (($1287) + 116|0);
 HEAPF32[$1317>>2] = $1316;
 $1318 = Math_fround(HEAPF32[$1218>>2]);
 $1319 = (($1287) + 120|0);
 HEAPF32[$1319>>2] = $1318;
 $1320 = Math_fround(HEAPF32[$1219>>2]);
 $1321 = (($1287) + 124|0);
 HEAPF32[$1321>>2] = $1320;
 $1322 = Math_fround(HEAPF32[$1220>>2]);
 $1323 = (($1287) + 128|0);
 HEAPF32[$1323>>2] = $1322;
 $1324 = Math_fround(HEAPF32[$1221>>2]);
 $1325 = (($1287) + 132|0);
 HEAPF32[$1325>>2] = $1324;
 $1326 = Math_fround(HEAPF32[$1222>>2]);
 $1327 = (($1287) + 136|0);
 HEAPF32[$1327>>2] = $1326;
 $1328 = Math_fround(HEAPF32[$1223>>2]);
 $1329 = (($1287) + 168|0);
 HEAPF32[$1329>>2] = $1328;
 $1330 = Math_fround(HEAPF32[$1224>>2]);
 $1331 = (($1287) + 172|0);
 HEAPF32[$1331>>2] = $1330;
 $1332 = Math_fround(HEAPF32[$1225>>2]);
 $1333 = (($1287) + 176|0);
 HEAPF32[$1333>>2] = $1332;
 $1334 = Math_fround(HEAPF32[$1226>>2]);
 $1335 = (($1287) + 180|0);
 HEAPF32[$1335>>2] = $1334;
 $1336 = Math_fround(HEAPF32[$1227>>2]);
 $1337 = (($1287) + 184|0);
 HEAPF32[$1337>>2] = $1336;
 $1338 = Math_fround(HEAPF32[$1228>>2]);
 $1339 = (($1287) + 188|0);
 HEAPF32[$1339>>2] = $1338;
 $1340 = Math_fround(HEAPF32[$1229>>2]);
 $1341 = (($1287) + 192|0);
 HEAPF32[$1341>>2] = $1340;
 $1342 = ($48>>>0)>(1);
 if ($1342) {
  $1343 = (($outputData) + 4|0);
  $1344 = (($outputData) + 8|0);
  $1345 = (($outputData) + 12|0);
  $1346 = (($outputData) + 16|0);
  $1347 = (($outputData) + 20|0);
  $1348 = (($outputData) + 24|0);
  $1349 = (($outputData) + 28|0);
  $1350 = (($outputData) + 32|0);
  $1351 = (($outputData) + 36|0);
  $1352 = (($outputData) + 40|0);
  $1353 = (($outputData) + 44|0);
  $1354 = (($outputData) + 48|0);
  $1355 = (($outputData) + 52|0);
  $1356 = (($outputData) + 56|0);
  $1357 = (($outputData) + 60|0);
  $1358 = (($outputData) + 64|0);
  $1359 = (($outputData) + 68|0);
  $1360 = (($outputData) + 72|0);
  $1361 = (($outputData) + 76|0);
  $1362 = (($outputData) + 80|0);
  $1363 = (($outputData) + 84|0);
  $1364 = (($outputData) + 88|0);
  $1365 = (($outputData) + 92|0);
  $1366 = (($outputData) + 96|0);
  $1367 = (($outputData) + 100|0);
  $1368 = (($outputData) + 104|0);
  $1369 = (($outputData) + 108|0);
  $i18$0111 = 1;
  while(1) {
   HEAPF32[$outputData>>2] = Math_fround(0.0);
   HEAPF32[$1343>>2] = Math_fround(0.0);
   HEAPF32[$1344>>2] = Math_fround(0.0);
   HEAPF32[$1345>>2] = Math_fround(1.0);
   ;HEAP32[$1346+0>>2]=0|0;HEAP32[$1346+4>>2]=0|0;HEAP32[$1346+8>>2]=0|0;HEAP32[$1346+12>>2]=0|0;HEAP32[$1346+16>>2]=0|0;HEAP32[$1346+20>>2]=0|0;
   HEAPF32[$1352>>2] = Math_fround(1.0);
   ;HEAP32[$1353+0>>2]=0|0;HEAP32[$1353+4>>2]=0|0;HEAP32[$1353+8>>2]=0|0;HEAP32[$1353+12>>2]=0|0;HEAP32[$1353+16>>2]=0|0;HEAP32[$1353+20>>2]=0|0;
   HEAPF32[$1359>>2] = Math_fround(1.0);
   ;HEAP32[$1360+0>>2]=0|0;HEAP32[$1360+4>>2]=0|0;HEAP32[$1360+8>>2]=0|0;HEAP32[$1360+12>>2]=0|0;HEAP32[$1360+16>>2]=0|0;HEAP32[$1360+20>>2]=0|0;
   HEAPF32[$1366>>2] = Math_fround(1.0);
   HEAPF32[$1367>>2] = Math_fround(0.0);
   HEAPF32[$1368>>2] = Math_fround(0.0);
   HEAPF32[$1369>>2] = Math_fround(0.0);
   $1370 = (($42) + (($i18$0111*944)|0)|0);
   $1371 = (($44) + (($i18$0111*208)|0)|0);
   $1372 = $i18$0111 << 2;
   $1373 = (($wheelQueryResults) + (($1372*148)|0)|0);
   $1374 = (($numActiveWheelsPerBlock4) + ($i18$0111<<2)|0);
   $1375 = HEAP32[$1374>>2]|0;
   __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($1370,$1371,$1373,$1375,$carChassisCMLocalPose,$outputData);
   $1376 = Math_fround(HEAPF32[$outputData>>2]);
   $1377 = ((($wheelQueryResults) + (($1372*148)|0)|0) + 120|0);
   HEAPF32[$1377>>2] = $1376;
   $1378 = Math_fround(HEAPF32[$1343>>2]);
   $1379 = ((($wheelQueryResults) + (($1372*148)|0)|0) + 124|0);
   HEAPF32[$1379>>2] = $1378;
   $1380 = Math_fround(HEAPF32[$1344>>2]);
   $1381 = ((($wheelQueryResults) + (($1372*148)|0)|0) + 128|0);
   HEAPF32[$1381>>2] = $1380;
   $1382 = Math_fround(HEAPF32[$1345>>2]);
   $1383 = ((($wheelQueryResults) + (($1372*148)|0)|0) + 132|0);
   HEAPF32[$1383>>2] = $1382;
   $1384 = Math_fround(HEAPF32[$1346>>2]);
   $1385 = ((($wheelQueryResults) + (($1372*148)|0)|0) + 136|0);
   HEAPF32[$1385>>2] = $1384;
   $1386 = Math_fround(HEAPF32[$1347>>2]);
   $1387 = ((($wheelQueryResults) + (($1372*148)|0)|0) + 140|0);
   HEAPF32[$1387>>2] = $1386;
   $1388 = Math_fround(HEAPF32[$1348>>2]);
   $1389 = ((($wheelQueryResults) + (($1372*148)|0)|0) + 144|0);
   HEAPF32[$1389>>2] = $1388;
   $1390 = $1372 | 1;
   $1391 = Math_fround(HEAPF32[$1349>>2]);
   $1392 = ((($wheelQueryResults) + (($1390*148)|0)|0) + 120|0);
   HEAPF32[$1392>>2] = $1391;
   $1393 = Math_fround(HEAPF32[$1350>>2]);
   $1394 = ((($wheelQueryResults) + (($1390*148)|0)|0) + 124|0);
   HEAPF32[$1394>>2] = $1393;
   $1395 = Math_fround(HEAPF32[$1351>>2]);
   $1396 = ((($wheelQueryResults) + (($1390*148)|0)|0) + 128|0);
   HEAPF32[$1396>>2] = $1395;
   $1397 = Math_fround(HEAPF32[$1352>>2]);
   $1398 = ((($wheelQueryResults) + (($1390*148)|0)|0) + 132|0);
   HEAPF32[$1398>>2] = $1397;
   $1399 = Math_fround(HEAPF32[$1353>>2]);
   $1400 = ((($wheelQueryResults) + (($1390*148)|0)|0) + 136|0);
   HEAPF32[$1400>>2] = $1399;
   $1401 = Math_fround(HEAPF32[$1354>>2]);
   $1402 = ((($wheelQueryResults) + (($1390*148)|0)|0) + 140|0);
   HEAPF32[$1402>>2] = $1401;
   $1403 = Math_fround(HEAPF32[$1355>>2]);
   $1404 = ((($wheelQueryResults) + (($1390*148)|0)|0) + 144|0);
   HEAPF32[$1404>>2] = $1403;
   $1405 = $1372 | 2;
   $1406 = Math_fround(HEAPF32[$1356>>2]);
   $1407 = ((($wheelQueryResults) + (($1405*148)|0)|0) + 120|0);
   HEAPF32[$1407>>2] = $1406;
   $1408 = Math_fround(HEAPF32[$1357>>2]);
   $1409 = ((($wheelQueryResults) + (($1405*148)|0)|0) + 124|0);
   HEAPF32[$1409>>2] = $1408;
   $1410 = Math_fround(HEAPF32[$1358>>2]);
   $1411 = ((($wheelQueryResults) + (($1405*148)|0)|0) + 128|0);
   HEAPF32[$1411>>2] = $1410;
   $1412 = Math_fround(HEAPF32[$1359>>2]);
   $1413 = ((($wheelQueryResults) + (($1405*148)|0)|0) + 132|0);
   HEAPF32[$1413>>2] = $1412;
   $1414 = Math_fround(HEAPF32[$1360>>2]);
   $1415 = ((($wheelQueryResults) + (($1405*148)|0)|0) + 136|0);
   HEAPF32[$1415>>2] = $1414;
   $1416 = Math_fround(HEAPF32[$1361>>2]);
   $1417 = ((($wheelQueryResults) + (($1405*148)|0)|0) + 140|0);
   HEAPF32[$1417>>2] = $1416;
   $1418 = Math_fround(HEAPF32[$1362>>2]);
   $1419 = ((($wheelQueryResults) + (($1405*148)|0)|0) + 144|0);
   HEAPF32[$1419>>2] = $1418;
   $1420 = $1372 | 3;
   $1421 = Math_fround(HEAPF32[$1363>>2]);
   $1422 = ((($wheelQueryResults) + (($1420*148)|0)|0) + 120|0);
   HEAPF32[$1422>>2] = $1421;
   $1423 = Math_fround(HEAPF32[$1364>>2]);
   $1424 = ((($wheelQueryResults) + (($1420*148)|0)|0) + 124|0);
   HEAPF32[$1424>>2] = $1423;
   $1425 = Math_fround(HEAPF32[$1365>>2]);
   $1426 = ((($wheelQueryResults) + (($1420*148)|0)|0) + 128|0);
   HEAPF32[$1426>>2] = $1425;
   $1427 = Math_fround(HEAPF32[$1366>>2]);
   $1428 = ((($wheelQueryResults) + (($1420*148)|0)|0) + 132|0);
   HEAPF32[$1428>>2] = $1427;
   $1429 = Math_fround(HEAPF32[$1367>>2]);
   $1430 = ((($wheelQueryResults) + (($1420*148)|0)|0) + 136|0);
   HEAPF32[$1430>>2] = $1429;
   $1431 = Math_fround(HEAPF32[$1368>>2]);
   $1432 = ((($wheelQueryResults) + (($1420*148)|0)|0) + 140|0);
   HEAPF32[$1432>>2] = $1431;
   $1433 = Math_fround(HEAPF32[$1369>>2]);
   $1434 = ((($wheelQueryResults) + (($1420*148)|0)|0) + 144|0);
   HEAPF32[$1434>>2] = $1433;
   $1435 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
   $1436 = (($1435) + (($1372*56)|0)|0);
   HEAPF32[$1436>>2] = $1376;
   $1437 = Math_fround(HEAPF32[$1343>>2]);
   $1438 = ((($1435) + (($1372*56)|0)|0) + 4|0);
   HEAPF32[$1438>>2] = $1437;
   $1439 = Math_fround(HEAPF32[$1344>>2]);
   $1440 = ((($1435) + (($1372*56)|0)|0) + 8|0);
   HEAPF32[$1440>>2] = $1439;
   $1441 = Math_fround(HEAPF32[$1345>>2]);
   $1442 = ((($1435) + (($1372*56)|0)|0) + 12|0);
   HEAPF32[$1442>>2] = $1441;
   $1443 = Math_fround(HEAPF32[$1346>>2]);
   $1444 = ((($1435) + (($1372*56)|0)|0) + 16|0);
   HEAPF32[$1444>>2] = $1443;
   $1445 = Math_fround(HEAPF32[$1347>>2]);
   $1446 = ((($1435) + (($1372*56)|0)|0) + 20|0);
   HEAPF32[$1446>>2] = $1445;
   $1447 = Math_fround(HEAPF32[$1348>>2]);
   $1448 = ((($1435) + (($1372*56)|0)|0) + 24|0);
   HEAPF32[$1448>>2] = $1447;
   $1449 = Math_fround(HEAPF32[$1349>>2]);
   $1450 = (($1435) + (($1390*56)|0)|0);
   HEAPF32[$1450>>2] = $1449;
   $1451 = Math_fround(HEAPF32[$1350>>2]);
   $1452 = ((($1435) + (($1390*56)|0)|0) + 4|0);
   HEAPF32[$1452>>2] = $1451;
   $1453 = Math_fround(HEAPF32[$1351>>2]);
   $1454 = ((($1435) + (($1390*56)|0)|0) + 8|0);
   HEAPF32[$1454>>2] = $1453;
   $1455 = Math_fround(HEAPF32[$1352>>2]);
   $1456 = ((($1435) + (($1390*56)|0)|0) + 12|0);
   HEAPF32[$1456>>2] = $1455;
   $1457 = Math_fround(HEAPF32[$1353>>2]);
   $1458 = ((($1435) + (($1390*56)|0)|0) + 16|0);
   HEAPF32[$1458>>2] = $1457;
   $1459 = Math_fround(HEAPF32[$1354>>2]);
   $1460 = ((($1435) + (($1390*56)|0)|0) + 20|0);
   HEAPF32[$1460>>2] = $1459;
   $1461 = Math_fround(HEAPF32[$1355>>2]);
   $1462 = ((($1435) + (($1390*56)|0)|0) + 24|0);
   HEAPF32[$1462>>2] = $1461;
   $1463 = Math_fround(HEAPF32[$1356>>2]);
   $1464 = (($1435) + (($1405*56)|0)|0);
   HEAPF32[$1464>>2] = $1463;
   $1465 = Math_fround(HEAPF32[$1357>>2]);
   $1466 = ((($1435) + (($1405*56)|0)|0) + 4|0);
   HEAPF32[$1466>>2] = $1465;
   $1467 = Math_fround(HEAPF32[$1358>>2]);
   $1468 = ((($1435) + (($1405*56)|0)|0) + 8|0);
   HEAPF32[$1468>>2] = $1467;
   $1469 = Math_fround(HEAPF32[$1359>>2]);
   $1470 = ((($1435) + (($1405*56)|0)|0) + 12|0);
   HEAPF32[$1470>>2] = $1469;
   $1471 = Math_fround(HEAPF32[$1360>>2]);
   $1472 = ((($1435) + (($1405*56)|0)|0) + 16|0);
   HEAPF32[$1472>>2] = $1471;
   $1473 = Math_fround(HEAPF32[$1361>>2]);
   $1474 = ((($1435) + (($1405*56)|0)|0) + 20|0);
   HEAPF32[$1474>>2] = $1473;
   $1475 = Math_fround(HEAPF32[$1362>>2]);
   $1476 = ((($1435) + (($1405*56)|0)|0) + 24|0);
   HEAPF32[$1476>>2] = $1475;
   $1477 = Math_fround(HEAPF32[$1363>>2]);
   $1478 = (($1435) + (($1420*56)|0)|0);
   HEAPF32[$1478>>2] = $1477;
   $1479 = Math_fround(HEAPF32[$1364>>2]);
   $1480 = ((($1435) + (($1420*56)|0)|0) + 4|0);
   HEAPF32[$1480>>2] = $1479;
   $1481 = Math_fround(HEAPF32[$1365>>2]);
   $1482 = ((($1435) + (($1420*56)|0)|0) + 8|0);
   HEAPF32[$1482>>2] = $1481;
   $1483 = Math_fround(HEAPF32[$1366>>2]);
   $1484 = ((($1435) + (($1420*56)|0)|0) + 12|0);
   HEAPF32[$1484>>2] = $1483;
   $1485 = Math_fround(HEAPF32[$1367>>2]);
   $1486 = ((($1435) + (($1420*56)|0)|0) + 16|0);
   HEAPF32[$1486>>2] = $1485;
   $1487 = Math_fround(HEAPF32[$1368>>2]);
   $1488 = ((($1435) + (($1420*56)|0)|0) + 20|0);
   HEAPF32[$1488>>2] = $1487;
   $1489 = Math_fround(HEAPF32[$1369>>2]);
   $1490 = ((($1435) + (($1420*56)|0)|0) + 24|0);
   HEAPF32[$1490>>2] = $1489;
   $1491 = (($i18$0111) + 1)|0;
   $exitcond = ($1491|0)==($48|0);
   if ($exitcond) {
    break;
   } else {
    $i18$0111 = $1491;
   }
  }
 }
 $1492 = ($vehWheelQueryResults|0)==(0|0);
 do {
  if (!($1492)) {
   $1493 = HEAP32[$vehWheelQueryResults>>2]|0;
   $1494 = ($1493|0)==(0|0);
   if ($1494) {
    break;
   }
   $1495 = ($46*148)|0;
   _memcpy(($1493|0),($wheelQueryResults|0),($1495|0))|0;
  }
 } while(0);
 $1496 = ($vehConcurrentUpdates|0)==(0|0);
 if ($1496) {
  HEAP32[$vehWheels>>2] = $vehDriveNW;
  __ZN5physx15PxVehicleUpdate10updatePostEPKNS_29PxVehicleConcurrentUpdateDataEjPPNS_15PxVehicleWheelsE($vehicleConcurrentUpdates,1,$vehWheels);
  STACKTOP = sp;return;
 } else {
  $1497 = HEAP32[$vehConcurrentUpdates>>2]|0;
  $1498 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
  $1499 = ($46*56)|0;
  _memcpy(($1497|0),($1498|0),($1499|0))|0;
  $1500 = Math_fround(HEAPF32[$1166>>2]);
  $1501 = (($vehConcurrentUpdates) + 8|0);
  HEAPF32[$1501>>2] = $1500;
  $1502 = (($vehicleConcurrentUpdates) + 12|0);
  $1503 = Math_fround(HEAPF32[$1502>>2]);
  $1504 = (($vehConcurrentUpdates) + 12|0);
  HEAPF32[$1504>>2] = $1503;
  $1505 = (($vehicleConcurrentUpdates) + 16|0);
  $1506 = Math_fround(HEAPF32[$1505>>2]);
  $1507 = (($vehConcurrentUpdates) + 16|0);
  HEAPF32[$1507>>2] = $1506;
  $1508 = (($vehicleConcurrentUpdates) + 20|0);
  $1509 = Math_fround(HEAPF32[$1508>>2]);
  $1510 = (($vehConcurrentUpdates) + 20|0);
  HEAPF32[$1510>>2] = $1509;
  $1511 = (($vehicleConcurrentUpdates) + 24|0);
  $1512 = Math_fround(HEAPF32[$1511>>2]);
  $1513 = (($vehConcurrentUpdates) + 24|0);
  HEAPF32[$1513>>2] = $1512;
  $1514 = (($vehicleConcurrentUpdates) + 28|0);
  $1515 = Math_fround(HEAPF32[$1514>>2]);
  $1516 = (($vehConcurrentUpdates) + 28|0);
  HEAPF32[$1516>>2] = $1515;
  $1517 = (($vehicleConcurrentUpdates) + 32|0);
  $1518 = HEAP16[$1517>>1]|0;
  $1519 = $1518&255;
  $1520 = (($vehConcurrentUpdates) + 32|0);
  HEAP8[$1520>>0] = $1519;
  $1521 = ($1518&65535) >>> 8;
  $1522 = $1521&255;
  $1523 = (($vehConcurrentUpdates) + 33|0);
  HEAP8[$1523>>0] = $1522;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15PxVehicleUpdate10updateTankEfRKNS_6PxVec3EffRKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEPNS_18PxVehicleDriveTankEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$gravityMagnitude,$recipGravityMagnitude,$drivableSurfaceToTireFrictionPairs,$vehDriveTank,$vehWheelQueryResults,$vehConcurrentUpdates) {
 $timestep = Math_fround($timestep);
 $gravity = $gravity|0;
 $gravityMagnitude = Math_fround($gravityMagnitude);
 $recipGravityMagnitude = Math_fround($recipGravityMagnitude);
 $drivableSurfaceToTireFrictionPairs = $drivableSurfaceToTireFrictionPairs|0;
 $vehDriveTank = $vehDriveTank|0;
 $vehWheelQueryResults = $vehWheelQueryResults|0;
 $vehConcurrentUpdates = $vehConcurrentUpdates|0;
 var $$0$i$i = Math_fround(0), $$not = 0, $$pre = Math_fround(0), $$pre204 = Math_fround(0), $$pre205 = Math_fround(0), $$pre206 = Math_fround(0), $$pre207 = Math_fround(0), $$pre208 = Math_fround(0), $$pre209 = Math_fround(0), $$pre210 = Math_fround(0), $$pre211 = Math_fround(0), $$pre212 = Math_fround(0), $$pre213 = Math_fround(0), $$pre214 = 0, $$sum = 0, $$sum100101 = 0, $$sum104105 = 0, $$sum108109 = 0, $$sum110111 = 0, $$sum112113 = 0;
 var $$sum3637 = 0, $$sum4041 = 0, $$sum4445 = 0, $$sum4849 = 0, $$sum6263 = 0, $$sum7677 = 0, $$sum9091 = 0, $$sum9293 = 0, $$sum9495 = 0, $$sum9697 = 0, $$val = Math_fround(0), $$val29 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = 0;
 var $1004 = Math_fround(0), $1005 = 0, $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = 0, $1009 = Math_fround(0), $101 = 0, $1010 = 0, $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = 0, $1014 = Math_fround(0), $1015 = 0, $1016 = 0, $1017 = Math_fround(0), $1018 = 0, $1019 = 0, $102 = 0, $1020 = Math_fround(0), $1021 = 0;
 var $1022 = 0, $1023 = 0, $1024 = 0, $1025 = Math_fround(0), $1026 = 0, $1027 = 0, $1028 = 0, $1029 = Math_fround(0), $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = Math_fround(0), $1034 = 0, $1035 = 0, $1036 = 0, $1037 = Math_fround(0), $1038 = 0, $1039 = 0, $104 = 0;
 var $1040 = 0, $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = 0, $1047 = Math_fround(0), $1048 = 0, $1049 = Math_fround(0), $105 = 0, $1050 = Math_fround(0), $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = Math_fround(0), $1056 = 0, $1057 = 0, $1058 = Math_fround(0);
 var $1059 = 0, $106 = 0, $1060 = 0, $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = 0, $1074 = 0, $1075 = Math_fround(0), $1076 = Math_fround(0);
 var $1077 = Math_fround(0), $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = 0, $1080 = 0, $1081 = Math_fround(0), $1082 = 0, $1083 = Math_fround(0), $1084 = 0, $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0);
 var $1095 = 0, $1096 = 0, $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = 0, $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0);
 var $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = 0, $1117 = Math_fround(0), $1118 = 0, $1119 = Math_fround(0), $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = 0, $1129 = Math_fround(0), $113 = 0;
 var $1130 = 0, $1131 = Math_fround(0), $1132 = 0, $1133 = Math_fround(0), $1134 = 0, $1135 = Math_fround(0), $1136 = 0, $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = 0, $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = 0, $1146 = 0, $1147 = Math_fround(0), $1148 = Math_fround(0);
 var $1149 = Math_fround(0), $115 = 0, $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0;
 var $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0;
 var $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = Math_fround(0), $1191 = 0, $1192 = Math_fround(0), $1193 = 0, $1194 = Math_fround(0), $1195 = 0, $1196 = Math_fround(0), $1197 = 0, $1198 = Math_fround(0), $1199 = 0, $12 = 0, $120 = 0, $1200 = Math_fround(0), $1201 = 0;
 var $1202 = Math_fround(0), $1203 = 0, $1204 = Math_fround(0), $1205 = 0, $1206 = Math_fround(0), $1207 = 0, $1208 = Math_fround(0), $1209 = 0, $121 = 0, $1210 = Math_fround(0), $1211 = 0, $1212 = Math_fround(0), $1213 = 0, $1214 = Math_fround(0), $1215 = 0, $1216 = Math_fround(0), $1217 = 0, $1218 = Math_fround(0), $1219 = 0, $122 = 0;
 var $1220 = Math_fround(0), $1221 = 0, $1222 = Math_fround(0), $1223 = 0, $1224 = Math_fround(0), $1225 = 0, $1226 = Math_fround(0), $1227 = 0, $1228 = Math_fround(0), $1229 = 0, $123 = 0, $1230 = Math_fround(0), $1231 = 0, $1232 = Math_fround(0), $1233 = 0, $1234 = Math_fround(0), $1235 = 0, $1236 = Math_fround(0), $1237 = 0, $1238 = Math_fround(0);
 var $1239 = 0, $124 = 0, $1240 = Math_fround(0), $1241 = 0, $1242 = Math_fround(0), $1243 = 0, $1244 = Math_fround(0), $1245 = 0, $1246 = 0, $1247 = Math_fround(0), $1248 = 0, $1249 = Math_fround(0), $125 = 0, $1250 = 0, $1251 = Math_fround(0), $1252 = 0, $1253 = Math_fround(0), $1254 = 0, $1255 = Math_fround(0), $1256 = 0;
 var $1257 = Math_fround(0), $1258 = 0, $1259 = Math_fround(0), $126 = 0, $1260 = 0, $1261 = Math_fround(0), $1262 = 0, $1263 = Math_fround(0), $1264 = 0, $1265 = Math_fround(0), $1266 = 0, $1267 = Math_fround(0), $1268 = 0, $1269 = Math_fround(0), $127 = 0, $1270 = 0, $1271 = Math_fround(0), $1272 = 0, $1273 = Math_fround(0), $1274 = 0;
 var $1275 = Math_fround(0), $1276 = 0, $1277 = Math_fround(0), $1278 = 0, $1279 = Math_fround(0), $128 = 0, $1280 = 0, $1281 = Math_fround(0), $1282 = 0, $1283 = Math_fround(0), $1284 = 0, $1285 = Math_fround(0), $1286 = 0, $1287 = Math_fround(0), $1288 = 0, $1289 = Math_fround(0), $129 = 0, $1290 = 0, $1291 = Math_fround(0), $1292 = 0;
 var $1293 = Math_fround(0), $1294 = 0, $1295 = Math_fround(0), $1296 = 0, $1297 = Math_fround(0), $1298 = 0, $1299 = Math_fround(0), $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0;
 var $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0;
 var $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = Math_fround(0), $1336 = 0, $1337 = Math_fround(0), $1338 = 0, $1339 = Math_fround(0), $134 = 0, $1340 = 0, $1341 = Math_fround(0), $1342 = 0, $1343 = Math_fround(0), $1344 = 0, $1345 = Math_fround(0), $1346 = 0;
 var $1347 = Math_fround(0), $1348 = 0, $1349 = 0, $135 = 0, $1350 = Math_fround(0), $1351 = 0, $1352 = Math_fround(0), $1353 = 0, $1354 = Math_fround(0), $1355 = 0, $1356 = Math_fround(0), $1357 = 0, $1358 = Math_fround(0), $1359 = 0, $136 = 0, $1360 = Math_fround(0), $1361 = 0, $1362 = Math_fround(0), $1363 = 0, $1364 = 0;
 var $1365 = Math_fround(0), $1366 = 0, $1367 = Math_fround(0), $1368 = 0, $1369 = Math_fround(0), $137 = 0, $1370 = 0, $1371 = Math_fround(0), $1372 = 0, $1373 = Math_fround(0), $1374 = 0, $1375 = Math_fround(0), $1376 = 0, $1377 = Math_fround(0), $1378 = 0, $1379 = 0, $138 = 0, $1380 = Math_fround(0), $1381 = 0, $1382 = Math_fround(0);
 var $1383 = 0, $1384 = Math_fround(0), $1385 = 0, $1386 = Math_fround(0), $1387 = 0, $1388 = Math_fround(0), $1389 = 0, $139 = 0, $1390 = Math_fround(0), $1391 = 0, $1392 = Math_fround(0), $1393 = 0, $1394 = 0, $1395 = 0, $1396 = Math_fround(0), $1397 = 0, $1398 = Math_fround(0), $1399 = 0, $14 = 0, $140 = 0;
 var $1400 = Math_fround(0), $1401 = 0, $1402 = Math_fround(0), $1403 = 0, $1404 = Math_fround(0), $1405 = 0, $1406 = Math_fround(0), $1407 = 0, $1408 = Math_fround(0), $1409 = 0, $141 = 0, $1410 = Math_fround(0), $1411 = 0, $1412 = Math_fround(0), $1413 = 0, $1414 = Math_fround(0), $1415 = 0, $1416 = Math_fround(0), $1417 = 0, $1418 = Math_fround(0);
 var $1419 = 0, $142 = 0, $1420 = Math_fround(0), $1421 = 0, $1422 = Math_fround(0), $1423 = 0, $1424 = Math_fround(0), $1425 = 0, $1426 = Math_fround(0), $1427 = 0, $1428 = Math_fround(0), $1429 = 0, $143 = 0, $1430 = Math_fround(0), $1431 = 0, $1432 = Math_fround(0), $1433 = 0, $1434 = Math_fround(0), $1435 = 0, $1436 = Math_fround(0);
 var $1437 = 0, $1438 = Math_fround(0), $1439 = 0, $144 = Math_fround(0), $1440 = Math_fround(0), $1441 = 0, $1442 = Math_fround(0), $1443 = 0, $1444 = Math_fround(0), $1445 = 0, $1446 = Math_fround(0), $1447 = 0, $1448 = Math_fround(0), $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0;
 var $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = Math_fround(0), $146 = Math_fround(0), $1460 = 0, $1461 = 0, $1462 = Math_fround(0), $1463 = 0, $1464 = 0, $1465 = Math_fround(0), $1466 = 0, $1467 = 0, $1468 = Math_fround(0), $1469 = 0, $147 = 0, $1470 = 0, $1471 = Math_fround(0), $1472 = 0;
 var $1473 = 0, $1474 = Math_fround(0), $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = Math_fround(0), $1480 = 0, $1481 = 0, $1482 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = 0;
 var $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0;
 var $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0;
 var $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0);
 var $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0);
 var $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0);
 var $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0);
 var $409 = 0, $41 = Math_fround(0), $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = 0, $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = Math_fround(0);
 var $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = Math_fround(0), $452 = Math_fround(0), $453 = 0, $454 = Math_fround(0), $455 = 0, $456 = Math_fround(0), $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = Math_fround(0), $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = Math_fround(0), $473 = Math_fround(0), $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = Math_fround(0), $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = 0, $531 = Math_fround(0), $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0);
 var $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = 0, $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = Math_fround(0), $562 = 0, $563 = 0, $564 = Math_fround(0), $565 = 0, $566 = Math_fround(0), $567 = 0, $568 = 0, $569 = Math_fround(0), $57 = 0, $570 = 0;
 var $571 = 0, $572 = Math_fround(0), $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = 0, $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = 0, $583 = Math_fround(0), $584 = 0, $585 = 0, $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = Math_fround(0);
 var $59 = 0, $590 = 0, $591 = 0, $592 = Math_fround(0), $593 = 0, $594 = 0, $595 = Math_fround(0), $596 = 0, $597 = 0, $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = Math_fround(0), $602 = 0, $603 = 0, $604 = Math_fround(0), $605 = 0, $606 = 0;
 var $607 = Math_fround(0), $608 = 0, $609 = 0, $61 = 0, $610 = Math_fround(0), $611 = 0, $612 = 0, $613 = Math_fround(0), $614 = 0, $615 = 0, $616 = Math_fround(0), $617 = 0, $618 = 0, $619 = Math_fround(0), $62 = 0, $620 = 0, $621 = 0, $622 = Math_fround(0), $623 = 0, $624 = 0;
 var $625 = Math_fround(0), $626 = 0, $627 = 0, $628 = Math_fround(0), $629 = 0, $63 = 0, $630 = 0, $631 = Math_fround(0), $632 = 0, $633 = 0, $634 = Math_fround(0), $635 = 0, $636 = 0, $637 = Math_fround(0), $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0);
 var $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0);
 var $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = 0, $69 = 0, $690 = Math_fround(0), $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = Math_fround(0);
 var $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = 0, $702 = Math_fround(0), $703 = 0, $704 = 0, $705 = Math_fround(0), $706 = 0, $707 = 0, $708 = Math_fround(0), $709 = 0, $71 = 0, $710 = 0, $711 = Math_fround(0), $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = Math_fround(0), $748 = Math_fround(0), $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = Math_fround(0), $774 = Math_fround(0), $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = Math_fround(0), $78 = 0, $780 = 0, $781 = Math_fround(0), $782 = 0, $783 = Math_fround(0), $784 = Math_fround(0), $785 = 0, $786 = Math_fround(0), $787 = Math_fround(0);
 var $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = Math_fround(0), $794 = 0, $795 = Math_fround(0), $796 = 0, $797 = Math_fround(0), $798 = Math_fround(0), $799 = 0, $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = 0, $803 = Math_fround(0), $804 = Math_fround(0);
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = Math_fround(0), $81 = 0, $810 = 0, $811 = Math_fround(0), $812 = 0, $813 = Math_fround(0), $814 = Math_fround(0), $815 = 0, $816 = Math_fround(0), $817 = Math_fround(0), $818 = 0, $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = Math_fround(0), $826 = 0, $827 = Math_fround(0), $828 = 0, $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = 0, $832 = Math_fround(0), $833 = Math_fround(0), $834 = 0, $835 = Math_fround(0), $836 = Math_fround(0), $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0;
 var $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0;
 var $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0);
 var $896 = Math_fround(0), $897 = Math_fround(0), $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0;
 var $913 = Math_fround(0), $914 = Math_fround(0), $915 = 0, $916 = Math_fround(0), $917 = 0, $918 = Math_fround(0), $919 = 0, $92 = 0, $920 = Math_fround(0), $921 = 0, $922 = Math_fround(0), $923 = 0, $924 = Math_fround(0), $925 = 0, $926 = Math_fround(0), $927 = 0, $928 = Math_fround(0), $929 = 0, $93 = 0, $930 = Math_fround(0);
 var $931 = 0, $932 = Math_fround(0), $933 = 0, $934 = Math_fround(0), $935 = 0, $936 = 0, $937 = Math_fround(0), $938 = Math_fround(0), $939 = 0, $94 = 0, $940 = Math_fround(0), $941 = 0, $942 = Math_fround(0), $943 = 0, $944 = Math_fround(0), $945 = 0, $946 = Math_fround(0), $947 = 0, $948 = Math_fround(0), $949 = 0;
 var $95 = 0, $950 = Math_fround(0), $951 = 0, $952 = Math_fround(0), $953 = 0, $954 = Math_fround(0), $955 = 0, $956 = Math_fround(0), $957 = 0, $958 = Math_fround(0), $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = 0;
 var $968 = Math_fround(0), $969 = Math_fround(0), $97 = 0, $970 = Math_fround(0), $971 = 0, $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = 0, $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = 0, $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = 0, $984 = Math_fround(0), $985 = Math_fround(0);
 var $986 = Math_fround(0), $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = Math_fround(0), $activeWheelStates = 0, $aveWheelSpeedContributions = 0, $brakeTorques = 0, $brmerge = 0, $brmerge$i = 0;
 var $carChassisAngVel = 0, $carChassisCMLocalPose = 0, $carChassisLinVel = 0, $carChassisTransform = 0, $chassisForce = 0, $chassisTorque = 0, $constData = 0, $diffTorqueRatios = 0, $driveSimData = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i7 = 0, $exitcond182 = 0, $exitcond188 = 0, $exitcond189 = 0, $exitcond196 = 0, $exitcond197 = 0, $exitcond198 = 0, $exitcond199 = 0, $exitcond200 = 0;
 var $exitcond201 = 0, $exitcond202 = 0, $exitcond203 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i13 = Math_fround(0), $finiteInputApplied$0$off0 = 0, $i$01$i = 0, $i$01$i$i = 0, $i$0175 = 0, $i$04$i = 0, $i$07$i$i = 0, $i1$0167 = 0, $i10$0119 = 0, $i11$0133 = 0, $i13$0143 = 0, $i14$0114 = 0, $i2$0163 = 0, $i3$0160 = 0;
 var $i6$0156 = 0, $i7$0154 = 0, $i8$0150 = 0, $i9$0115 = 0, $implicitSolverInput = 0, $implicitSolverOutput = 0, $inertia = 0, $inputData = 0, $inverseInertia = 0, $isAccelApplied = 0, $isBrakeApplied = 0, $j$02$i = 0, $j$02$i9 = 0, $k$0146 = 0, $not$or$cond2$i = 0, $notlhs$i = 0, $notrhs$i = 0, $numActiveWheelsPerBlock4 = 0, $or$cond = 0, $or$cond$i$i = 0;
 var $or$cond3$i = 0, $outputData = 0, $phitmp = 0, $steerAngles = 0, $tires4ForceCalculators = 0, $vehWheels = 0, $vehicleConcurrentUpdates = 0, $wheelConcurrentUpdates = 0, $wheelGearings = 0, $wheelOmega$0$i = Math_fround(0), $wheelQueryResults = 0, $x0$08$i$i = Math_fround(0), $y0$06$i$i = Math_fround(0), dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 11280|0;
 $driveSimData = sp + 10600|0;
 $wheelConcurrentUpdates = sp + 6304|0;
 $vehicleConcurrentUpdates = sp + 7424|0;
 $numActiveWheelsPerBlock4 = sp + 7460|0;
 $tires4ForceCalculators = sp + 7480|0;
 $wheelQueryResults = sp + 7584|0;
 $carChassisCMLocalPose = sp + 10544|0;
 $carChassisTransform = sp + 10572|0;
 $inverseInertia = sp + 11128|0;
 $carChassisLinVel = sp + 11140|0;
 $carChassisAngVel = sp + 11180|0;
 $0 = sp + 11152|0;
 $1 = sp + 11192|0;
 $2 = sp + 6276|0;
 $inertia = sp;
 $3 = sp + 344|0;
 $4 = sp + 12|0;
 $activeWheelStates = sp + 11240|0;
 $aveWheelSpeedContributions = sp + 24|0;
 $diffTorqueRatios = sp + 104|0;
 $wheelGearings = sp + 184|0;
 $isAccelApplied = sp + 11220|0;
 $steerAngles = sp + 264|0;
 $constData = sp + 356|0;
 $chassisForce = sp + 400|0;
 $chassisTorque = sp + 412|0;
 $brakeTorques = sp + 424|0;
 $isBrakeApplied = sp + 11260|0;
 $outputData = sp + 536|0;
 $inputData = sp + 6096|0;
 $implicitSolverInput = sp + 6192|0;
 $implicitSolverOutput = sp + 6264|0;
 $vehWheels = sp + 6272|0;
 $5 = (($vehDriveTank) + 8|0);
 $6 = (($vehDriveTank) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $49 = 0;
 } else {
  $9 = (($vehDriveTank) + 72|0);
  $10 = HEAP32[$9>>2]|0;
  $i$0175 = 0;
  while(1) {
   $11 = $i$0175 << 2;
   $12 = (523960 + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    $15 = (($10) + (($i$0175*208)|0)|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = (($13) + 16|0);
    HEAPF32[$17>>2] = $16;
    $18 = ((($10) + (($i$0175*208)|0)|0) + 4|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = $11 | 1;
    $21 = (523960 + ($20<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + 16|0);
    HEAPF32[$23>>2] = $19;
    $24 = ((($10) + (($i$0175*208)|0)|0) + 8|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = $11 | 2;
    $27 = (523960 + ($26<<2)|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 16|0);
    HEAPF32[$29>>2] = $25;
    $30 = ((($10) + (($i$0175*208)|0)|0) + 12|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = $11 | 3;
    $33 = (523960 + ($32<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    HEAPF32[$35>>2] = $31;
   }
   $36 = (($i$0175) + 1)|0;
   $37 = ($36>>>0)<($7>>>0);
   if ($37) {
    $i$0175 = $36;
   } else {
    $49 = $7;
    break;
   }
  }
 }
 $38 = (($vehDriveTank) + 128|0);
 $39 = (($vehDriveTank) + 204|0);
 $40 = (0|0)==(0|0);
 if (!($40)) {
  $41 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[0>>2] = $41;
 }
 $42 = (($vehDriveTank) + 40|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($vehDriveTank) + 72|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($vehDriveTank) + 48|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $49 << 2;
 $50 = (4 - ($48))|0;
 $51 = (($vehDriveTank) + 224|0);
 $52 = (($vehDriveTank) + 288|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = $53 << 3;
 _memcpy(($driveSimData|0),($51|0),($54|0))|0;
 $55 = (($driveSimData) + 64|0);
 HEAP32[$55>>2] = $53;
 $56 = (($driveSimData) + 80|0);
 $57 = (($vehDriveTank) + 304|0);
 ;HEAP32[$56+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$57+8>>2]|0;HEAP32[$56+12>>2]=HEAP32[$57+12>>2]|0;HEAP32[$56+16>>2]=HEAP32[$57+16>>2]|0;HEAP32[$56+20>>2]=HEAP32[$57+20>>2]|0;HEAP32[$56+24>>2]=HEAP32[$57+24>>2]|0;HEAP32[$56+28>>2]=HEAP32[$57+28>>2]|0;
 $58 = (($driveSimData) + 112|0);
 $59 = (($vehDriveTank) + 336|0);
 _memcpy(($58|0),($59|0),416)|0;
 $60 = (($vehDriveTank) + 104|0);
 $61 = HEAP32[$60>>2]|0;
 HEAPF32[$wheelConcurrentUpdates>>2] = Math_fround(0.0);
 $62 = (($wheelConcurrentUpdates) + 4|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($wheelConcurrentUpdates) + 8|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($wheelConcurrentUpdates) + 12|0);
 HEAPF32[$64>>2] = Math_fround(1.0);
 $65 = (($wheelConcurrentUpdates) + 16|0);
 $66 = (($wheelConcurrentUpdates) + 60|0);
 dest=$65+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($wheelConcurrentUpdates) + 64|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($wheelConcurrentUpdates) + 68|0);
 HEAPF32[$68>>2] = Math_fround(1.0);
 $69 = (($wheelConcurrentUpdates) + 72|0);
 $70 = (($wheelConcurrentUpdates) + 116|0);
 dest=$69+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($wheelConcurrentUpdates) + 120|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($wheelConcurrentUpdates) + 124|0);
 HEAPF32[$72>>2] = Math_fround(1.0);
 $73 = (($wheelConcurrentUpdates) + 128|0);
 $74 = (($wheelConcurrentUpdates) + 172|0);
 dest=$73+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($wheelConcurrentUpdates) + 176|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($wheelConcurrentUpdates) + 180|0);
 HEAPF32[$76>>2] = Math_fround(1.0);
 $77 = (($wheelConcurrentUpdates) + 184|0);
 $78 = (($wheelConcurrentUpdates) + 228|0);
 dest=$77+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = (($wheelConcurrentUpdates) + 232|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($wheelConcurrentUpdates) + 236|0);
 HEAPF32[$80>>2] = Math_fround(1.0);
 $81 = (($wheelConcurrentUpdates) + 240|0);
 $82 = (($wheelConcurrentUpdates) + 284|0);
 dest=$81+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = (($wheelConcurrentUpdates) + 288|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($wheelConcurrentUpdates) + 292|0);
 HEAPF32[$84>>2] = Math_fround(1.0);
 $85 = (($wheelConcurrentUpdates) + 296|0);
 $86 = (($wheelConcurrentUpdates) + 340|0);
 dest=$85+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = (($wheelConcurrentUpdates) + 344|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($wheelConcurrentUpdates) + 348|0);
 HEAPF32[$88>>2] = Math_fround(1.0);
 $89 = (($wheelConcurrentUpdates) + 352|0);
 $90 = (($wheelConcurrentUpdates) + 396|0);
 dest=$89+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$90>>2] = Math_fround(0.0);
 $91 = (($wheelConcurrentUpdates) + 400|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($wheelConcurrentUpdates) + 404|0);
 HEAPF32[$92>>2] = Math_fround(1.0);
 $93 = (($wheelConcurrentUpdates) + 408|0);
 $94 = (($wheelConcurrentUpdates) + 452|0);
 dest=$93+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$94>>2] = Math_fround(0.0);
 $95 = (($wheelConcurrentUpdates) + 456|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($wheelConcurrentUpdates) + 460|0);
 HEAPF32[$96>>2] = Math_fround(1.0);
 $97 = (($wheelConcurrentUpdates) + 464|0);
 $98 = (($wheelConcurrentUpdates) + 508|0);
 dest=$97+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$98>>2] = Math_fround(0.0);
 $99 = (($wheelConcurrentUpdates) + 512|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = (($wheelConcurrentUpdates) + 516|0);
 HEAPF32[$100>>2] = Math_fround(1.0);
 $101 = (($wheelConcurrentUpdates) + 520|0);
 $102 = (($wheelConcurrentUpdates) + 564|0);
 dest=$101+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$102>>2] = Math_fround(0.0);
 $103 = (($wheelConcurrentUpdates) + 568|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($wheelConcurrentUpdates) + 572|0);
 HEAPF32[$104>>2] = Math_fround(1.0);
 $105 = (($wheelConcurrentUpdates) + 576|0);
 $106 = (($wheelConcurrentUpdates) + 620|0);
 dest=$105+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$106>>2] = Math_fround(0.0);
 $107 = (($wheelConcurrentUpdates) + 624|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($wheelConcurrentUpdates) + 628|0);
 HEAPF32[$108>>2] = Math_fround(1.0);
 $109 = (($wheelConcurrentUpdates) + 632|0);
 $110 = (($wheelConcurrentUpdates) + 676|0);
 dest=$109+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$110>>2] = Math_fround(0.0);
 $111 = (($wheelConcurrentUpdates) + 680|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = (($wheelConcurrentUpdates) + 684|0);
 HEAPF32[$112>>2] = Math_fround(1.0);
 $113 = (($wheelConcurrentUpdates) + 688|0);
 $114 = (($wheelConcurrentUpdates) + 732|0);
 dest=$113+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$114>>2] = Math_fround(0.0);
 $115 = (($wheelConcurrentUpdates) + 736|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = (($wheelConcurrentUpdates) + 740|0);
 HEAPF32[$116>>2] = Math_fround(1.0);
 $117 = (($wheelConcurrentUpdates) + 744|0);
 $118 = (($wheelConcurrentUpdates) + 788|0);
 dest=$117+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$118>>2] = Math_fround(0.0);
 $119 = (($wheelConcurrentUpdates) + 792|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($wheelConcurrentUpdates) + 796|0);
 HEAPF32[$120>>2] = Math_fround(1.0);
 $121 = (($wheelConcurrentUpdates) + 800|0);
 $122 = (($wheelConcurrentUpdates) + 844|0);
 dest=$121+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$122>>2] = Math_fround(0.0);
 $123 = (($wheelConcurrentUpdates) + 848|0);
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = (($wheelConcurrentUpdates) + 852|0);
 HEAPF32[$124>>2] = Math_fround(1.0);
 $125 = (($wheelConcurrentUpdates) + 856|0);
 $126 = (($wheelConcurrentUpdates) + 900|0);
 dest=$125+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$126>>2] = Math_fround(0.0);
 $127 = (($wheelConcurrentUpdates) + 904|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = (($wheelConcurrentUpdates) + 908|0);
 HEAPF32[$128>>2] = Math_fround(1.0);
 $129 = (($wheelConcurrentUpdates) + 912|0);
 $130 = (($wheelConcurrentUpdates) + 956|0);
 dest=$129+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = (($wheelConcurrentUpdates) + 960|0);
 HEAPF32[$131>>2] = Math_fround(0.0);
 $132 = (($wheelConcurrentUpdates) + 964|0);
 HEAPF32[$132>>2] = Math_fround(1.0);
 $133 = (($wheelConcurrentUpdates) + 968|0);
 $134 = (($wheelConcurrentUpdates) + 1012|0);
 dest=$133+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = (($wheelConcurrentUpdates) + 1016|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = (($wheelConcurrentUpdates) + 1020|0);
 HEAPF32[$136>>2] = Math_fround(1.0);
 $137 = (($wheelConcurrentUpdates) + 1024|0);
 $138 = (($wheelConcurrentUpdates) + 1068|0);
 dest=$137+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$138>>2] = Math_fround(0.0);
 $139 = (($wheelConcurrentUpdates) + 1072|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($wheelConcurrentUpdates) + 1076|0);
 HEAPF32[$140>>2] = Math_fround(1.0);
 $141 = (($wheelConcurrentUpdates) + 1080|0);
 dest=$141+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $142 = (($50) + ($47))|0;
 ;HEAP32[$vehicleConcurrentUpdates+0>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+4>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+8>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+12>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+16>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+20>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+24>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+28>>2]=0|0;HEAP16[$vehicleConcurrentUpdates+32>>1]=0|0;
 $143 = (($vehicleConcurrentUpdates) + 4|0);
 HEAP32[$143>>2] = $47;
 HEAP32[$vehicleConcurrentUpdates>>2] = $wheelConcurrentUpdates;
 $144 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($38,3)));
 $145 = $144 != Math_fround(0.0);
 if ($145) {
  label = 13;
 } else {
  $146 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($38,4)));
  $147 = $146 != Math_fround(0.0);
  if ($147) {
   label = 13;
  } else {
   $148 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($38,0)));
   $149 = $148 != Math_fround(0.0);
   if ($149) {
    label = 13;
   } else {
    $150 = (($vehDriveTank) + 194|0);
    $151 = HEAP8[$150>>0]|0;
    $152 = ($151<<24>>24)==(0);
    if ($152) {
     $153 = (($vehDriveTank) + 193|0);
     $154 = HEAP8[$153>>0]|0;
     $155 = ($154<<24>>24)==(0);
     if ($155) {
      $finiteInputApplied$0$off0 = 0;
     } else {
      label = 13;
     }
    } else {
     label = 13;
    }
   }
  }
 }
 if ((label|0) == 13) {
  $finiteInputApplied$0$off0 = 1;
 }
 $156 = HEAP32[$61>>2]|0;
 $157 = (($156) + 256|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = (FUNCTION_TABLE_ii[$158 & 4095]($61)|0);
 L20: do {
  if ($159) {
   if ($finiteInputApplied$0$off0) {
    $160 = (($vehicleConcurrentUpdates) + 33|0);
    HEAP8[$160>>0] = 1;
    break;
   }
   $161 = HEAP32[$6>>2]|0;
   $162 = HEAP32[$44>>2]|0;
   $163 = ($161|0)==(0);
   L25: do {
    if (!($163)) {
     $i$04$i = 0;
     L26: while(1) {
      $164 = $i$04$i << 2;
      $165 = ((($162) + (($i$04$i*208)|0)|0) + 196|0);
      $j$02$i9 = 0;
      while(1) {
       $166 = (($j$02$i9) + ($164))|0;
       $167 = (__ZNK5physx22PxVehicleWheelsSimData18getIsWheelDisabledEj($5,$166)|0);
       if (!($167)) {
        $168 = HEAP32[$165>>2]|0;
        $169 = ((($168) + (($j$02$i9*80)|0)|0) + 77|0);
        $170 = HEAP8[$169>>0]|0;
        $171 = ($170<<24>>24)==(0);
        if (!($171)) {
         $172 = (($168) + (($j$02$i9*80)|0)|0);
         $173 = HEAP32[$172>>2]|0;
         $174 = ($173|0)==(0|0);
         if (!($174)) {
          $175 = (($173) + 4|0);
          $176 = HEAP16[$175>>1]|0;
          $177 = ($176<<16>>16)==(5);
          if ($177) {
           break L26;
          }
         }
        }
       }
       $178 = (($j$02$i9) + 1)|0;
       $179 = ($178>>>0)<(4);
       if ($179) {
        $j$02$i9 = $178;
       } else {
        break;
       }
      }
      $180 = (($i$04$i) + 1)|0;
      $181 = ($180>>>0)<($161>>>0);
      if ($181) {
       $i$04$i = $180;
      } else {
       break L25;
      }
     }
     $182 = (($vehicleConcurrentUpdates) + 33|0);
     HEAP8[$182>>0] = 1;
     break L20;
    }
   } while(0);
   $183 = (($vehDriveTank) + 88|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = ($184|0)==(0);
   if (!($185)) {
    $i$01$i$i = 0;
    while(1) {
     __ZN5physx22PxVehicleWheelsDynData21setWheelRotationSpeedEjf($44,$i$01$i$i,Math_fround(0.0));
     $186 = (($i$01$i$i) + 1)|0;
     $187 = HEAP32[$183>>2]|0;
     $188 = ($186>>>0)<($187>>>0);
     if ($188) {
      $i$01$i$i = $186;
     } else {
      break;
     }
    }
   }
   HEAPF32[$39>>2] = Math_fround(0.0);
   $189 = ($vehConcurrentUpdates|0)==(0|0);
   if ($189) {
    STACKTOP = sp;return;
   }
   $190 = (($vehConcurrentUpdates) + 32|0);
   HEAP8[$190>>0] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 ;HEAP32[$numActiveWheelsPerBlock4+0>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+4>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+8>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+12>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+16>>2]=0|0;
 $191 = ($47>>>0)<(4);
 $192 = $191 ? $47 : 4;
 HEAP32[$numActiveWheelsPerBlock4>>2] = $192;
 $193 = (($49) + -1)|0;
 $194 = ($193>>>0)>(1);
 if ($194) {
  $i1$0167 = 1;
  while(1) {
   $195 = (($numActiveWheelsPerBlock4) + ($i1$0167<<2)|0);
   HEAP32[$195>>2] = 4;
   $196 = (($i1$0167) + 1)|0;
   $exitcond203 = ($196|0)==($193|0);
   if ($exitcond203) {
    break;
   } else {
    $i1$0167 = $196;
   }
  }
 }
 $197 = (($numActiveWheelsPerBlock4) + ($193<<2)|0);
 HEAP32[$197>>2] = $142;
 $198 = ($49|0)==(0);
 if (!($198)) {
  $199 = (($vehDriveTank) + 76|0);
  $$pre214 = HEAP32[$199>>2]|0;
  $i2$0163 = 0;
  while(1) {
   $200 = $i2$0163 << 2;
   $201 = HEAP32[$$pre214>>2]|0;
   $202 = (($201) + ($200<<2)|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = (($tires4ForceCalculators) + (($i2$0163*20)|0)|0);
   HEAP32[$204>>2] = $203;
   $205 = $200 | 1;
   $206 = HEAP32[$$pre214>>2]|0;
   $207 = (($206) + ($205<<2)|0);
   $208 = HEAP32[$207>>2]|0;
   $209 = ((($tires4ForceCalculators) + (($i2$0163*20)|0)|0) + 4|0);
   HEAP32[$209>>2] = $208;
   $210 = $200 | 2;
   $211 = HEAP32[$$pre214>>2]|0;
   $212 = (($211) + ($210<<2)|0);
   $213 = HEAP32[$212>>2]|0;
   $214 = ((($tires4ForceCalculators) + (($i2$0163*20)|0)|0) + 8|0);
   HEAP32[$214>>2] = $213;
   $215 = $200 | 3;
   $216 = HEAP32[$$pre214>>2]|0;
   $217 = (($216) + ($215<<2)|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = ((($tires4ForceCalculators) + (($i2$0163*20)|0)|0) + 12|0);
   HEAP32[$219>>2] = $218;
   $220 = (($$pre214) + 4|0);
   $221 = HEAP32[$220>>2]|0;
   $222 = ((($tires4ForceCalculators) + (($i2$0163*20)|0)|0) + 16|0);
   HEAP32[$222>>2] = $221;
   $223 = (($i2$0163) + 1)|0;
   $exitcond202 = ($223|0)==($49|0);
   if ($exitcond202) {
    break;
   } else {
    $i2$0163 = $223;
   }
  }
  if (!($198)) {
   $i3$0160 = 0;
   while(1) {
    $224 = ((($45) + (($i3$0160*208)|0)|0) + 192|0);
    $225 = HEAP32[$224>>2]|0;
    $226 = (($225) + 352|0);
    $227 = HEAP32[$226>>2]|0;
    $228 = HEAP32[$227>>2]|0;
    $229 = (($228) + 36|0);
    $230 = HEAP32[$229>>2]|0;
    FUNCTION_TABLE_vi[$230 & 4095]($227);
    $231 = (($i3$0160) + 1)|0;
    $exitcond201 = ($231|0)==($49|0);
    if ($exitcond201) {
     break;
    } else {
     $i3$0160 = $231;
    }
   }
  }
 }
 $232 = (($wheelQueryResults) + 2960|0);
 $233 = $wheelQueryResults;
 while(1) {
  _memset(($233|0),0,136)|0;
  $234 = (($233) + 28|0);
  HEAP8[$234>>0] = 1;
  $235 = (($233) + 44|0);
  HEAP32[$235>>2] = -1;
  $236 = (($233) + 120|0);
  HEAPF32[$236>>2] = Math_fround(0.0);
  $237 = (($233) + 124|0);
  HEAPF32[$237>>2] = Math_fround(0.0);
  $238 = (($233) + 128|0);
  HEAPF32[$238>>2] = Math_fround(0.0);
  $239 = (($233) + 132|0);
  HEAPF32[$239>>2] = Math_fround(1.0);
  $240 = (($233) + 136|0);
  HEAPF32[$240>>2] = Math_fround(0.0);
  $241 = (($233) + 140|0);
  HEAPF32[$241>>2] = Math_fround(0.0);
  $242 = (($233) + 144|0);
  HEAPF32[$242>>2] = Math_fround(0.0);
  $243 = (($233) + 148|0);
  $244 = ($243|0)==($232|0);
  if ($244) {
   break;
  } else {
   $233 = $243;
  }
 }
 $245 = HEAP32[$61>>2]|0;
 $246 = (($245) + 124|0);
 $247 = HEAP32[$246>>2]|0;
 FUNCTION_TABLE_vii[$247 & 4095]($0,$61);
 $248 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$carChassisCMLocalPose>>2] = $248;
 $249 = (($0) + 4|0);
 $250 = Math_fround(HEAPF32[$249>>2]);
 $251 = (($carChassisCMLocalPose) + 4|0);
 HEAPF32[$251>>2] = $250;
 $252 = (($0) + 8|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = (($carChassisCMLocalPose) + 8|0);
 HEAPF32[$254>>2] = $253;
 $255 = (($0) + 12|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 $257 = (($carChassisCMLocalPose) + 12|0);
 HEAPF32[$257>>2] = $256;
 $258 = (($0) + 16|0);
 $259 = Math_fround(HEAPF32[$258>>2]);
 $260 = (($carChassisCMLocalPose) + 16|0);
 HEAPF32[$260>>2] = $259;
 $261 = (($0) + 20|0);
 $262 = Math_fround(HEAPF32[$261>>2]);
 $263 = (($carChassisCMLocalPose) + 20|0);
 HEAPF32[$263>>2] = $262;
 $264 = (($0) + 24|0);
 $265 = Math_fround(HEAPF32[$264>>2]);
 $266 = (($carChassisCMLocalPose) + 24|0);
 HEAPF32[$266>>2] = $265;
 $267 = HEAP32[$61>>2]|0;
 $268 = (($267) + 84|0);
 $269 = HEAP32[$268>>2]|0;
 FUNCTION_TABLE_vii[$269 & 4095]($1,$61);
 $270 = HEAP32[$61>>2]|0;
 $271 = (($270) + 124|0);
 $272 = HEAP32[$271>>2]|0;
 FUNCTION_TABLE_vii[$272 & 4095]($2,$61);
 $273 = (($2) + 16|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 $275 = Math_fround($274 * Math_fround(2.0));
 $276 = (($2) + 20|0);
 $277 = Math_fround(HEAPF32[$276>>2]);
 $278 = Math_fround($277 * Math_fround(2.0));
 $279 = (($2) + 24|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = Math_fround($280 * Math_fround(2.0));
 $282 = (($1) + 12|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = Math_fround($283 * $283);
 $285 = Math_fround($284 + Math_fround(-0.5));
 $286 = Math_fround(HEAPF32[$1>>2]);
 $287 = Math_fround($275 * $286);
 $288 = (($1) + 4|0);
 $289 = Math_fround(HEAPF32[$288>>2]);
 $290 = Math_fround($278 * $289);
 $291 = Math_fround($287 + $290);
 $292 = (($1) + 8|0);
 $293 = Math_fround(HEAPF32[$292>>2]);
 $294 = Math_fround($281 * $293);
 $295 = Math_fround($291 + $294);
 $296 = Math_fround($275 * $285);
 $297 = Math_fround($281 * $289);
 $298 = Math_fround($278 * $293);
 $299 = Math_fround($297 - $298);
 $300 = Math_fround($283 * $299);
 $301 = Math_fround($296 + $300);
 $302 = Math_fround($286 * $295);
 $303 = Math_fround($302 + $301);
 $304 = Math_fround($278 * $285);
 $305 = Math_fround($275 * $293);
 $306 = Math_fround($281 * $286);
 $307 = Math_fround($305 - $306);
 $308 = Math_fround($283 * $307);
 $309 = Math_fround($304 + $308);
 $310 = Math_fround($289 * $295);
 $311 = Math_fround($310 + $309);
 $312 = Math_fround($281 * $285);
 $313 = Math_fround($278 * $286);
 $314 = Math_fround($275 * $289);
 $315 = Math_fround($313 - $314);
 $316 = Math_fround($283 * $315);
 $317 = Math_fround($312 + $316);
 $318 = Math_fround($293 * $295);
 $319 = Math_fround($317 + $318);
 $320 = (($1) + 16|0);
 $321 = Math_fround(HEAPF32[$320>>2]);
 $322 = Math_fround($321 + $303);
 $323 = (($1) + 20|0);
 $324 = Math_fround(HEAPF32[$323>>2]);
 $325 = Math_fround($324 + $311);
 $326 = (($1) + 24|0);
 $327 = Math_fround(HEAPF32[$326>>2]);
 $328 = Math_fround($327 + $319);
 $329 = Math_fround(HEAPF32[$2>>2]);
 $330 = Math_fround($283 * $329);
 $331 = (($2) + 12|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = Math_fround($286 * $332);
 $334 = Math_fround($330 + $333);
 $335 = (($2) + 8|0);
 $336 = Math_fround(HEAPF32[$335>>2]);
 $337 = Math_fround($289 * $336);
 $338 = Math_fround($334 + $337);
 $339 = (($2) + 4|0);
 $340 = Math_fround(HEAPF32[$339>>2]);
 $341 = Math_fround($293 * $340);
 $342 = Math_fround($338 - $341);
 $343 = Math_fround($283 * $340);
 $344 = Math_fround($289 * $332);
 $345 = Math_fround($344 + $343);
 $346 = Math_fround($293 * $329);
 $347 = Math_fround($346 + $345);
 $348 = Math_fround($286 * $336);
 $349 = Math_fround($347 - $348);
 $350 = Math_fround($283 * $336);
 $351 = Math_fround($293 * $332);
 $352 = Math_fround($351 + $350);
 $353 = Math_fround($286 * $340);
 $354 = Math_fround($353 + $352);
 $355 = Math_fround($289 * $329);
 $356 = Math_fround($354 - $355);
 $357 = Math_fround($283 * $332);
 $358 = Math_fround($286 * $329);
 $359 = Math_fround($357 - $358);
 $360 = Math_fround($289 * $340);
 $361 = Math_fround($359 - $360);
 $362 = Math_fround($293 * $336);
 $363 = Math_fround($361 - $362);
 HEAPF32[$carChassisTransform>>2] = $342;
 $364 = (($carChassisTransform) + 4|0);
 HEAPF32[$364>>2] = $349;
 $365 = (($carChassisTransform) + 8|0);
 HEAPF32[$365>>2] = $356;
 $366 = (($carChassisTransform) + 12|0);
 HEAPF32[$366>>2] = $363;
 $367 = (($carChassisTransform) + 16|0);
 HEAPF32[$367>>2] = $322;
 $368 = (($carChassisTransform) + 20|0);
 HEAPF32[$368>>2] = $325;
 $369 = (($carChassisTransform) + 24|0);
 HEAPF32[$369>>2] = $328;
 $370 = HEAP32[$61>>2]|0;
 $371 = (($370) + 132|0);
 $372 = HEAP32[$371>>2]|0;
 $373 = (Math_fround(FUNCTION_TABLE_fi[$372 & 255]($61)));
 $374 = Math_fround(Math_fround(1.0) / $373);
 $375 = HEAP32[$61>>2]|0;
 $376 = (($375) + 144|0);
 $377 = HEAP32[$376>>2]|0;
 FUNCTION_TABLE_vii[$377 & 4095]($inertia,$61);
 $378 = Math_fround(HEAPF32[$inertia>>2]);
 $379 = Math_fround(Math_fround(1.0) / $378);
 $380 = (($inertia) + 4|0);
 $381 = Math_fround(HEAPF32[$380>>2]);
 $382 = Math_fround(Math_fround(1.0) / $381);
 $383 = (($inertia) + 8|0);
 $384 = Math_fround(HEAPF32[$383>>2]);
 $385 = Math_fround(Math_fround(1.0) / $384);
 HEAPF32[$inverseInertia>>2] = $379;
 $386 = (($inverseInertia) + 4|0);
 HEAPF32[$386>>2] = $382;
 $387 = (($inverseInertia) + 8|0);
 HEAPF32[$387>>2] = $385;
 $388 = HEAP32[$61>>2]|0;
 $389 = (($388) + 152|0);
 $390 = HEAP32[$389>>2]|0;
 FUNCTION_TABLE_vii[$390 & 4095]($3,$61);
 $391 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$carChassisLinVel>>2] = $391;
 $392 = (($3) + 4|0);
 $393 = Math_fround(HEAPF32[$392>>2]);
 $394 = (($carChassisLinVel) + 4|0);
 HEAPF32[$394>>2] = $393;
 $395 = (($3) + 8|0);
 $396 = Math_fround(HEAPF32[$395>>2]);
 $397 = (($carChassisLinVel) + 8|0);
 HEAPF32[$397>>2] = $396;
 $398 = HEAP32[$61>>2]|0;
 $399 = (($398) + 160|0);
 $400 = HEAP32[$399>>2]|0;
 FUNCTION_TABLE_vii[$400 & 4095]($4,$61);
 $401 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$carChassisAngVel>>2] = $401;
 $402 = (($4) + 4|0);
 $403 = Math_fround(HEAPF32[$402>>2]);
 $404 = (($carChassisAngVel) + 4|0);
 HEAPF32[$404>>2] = $403;
 $405 = (($4) + 8|0);
 $406 = Math_fround(HEAPF32[$405>>2]);
 $407 = (($carChassisAngVel) + 8|0);
 HEAPF32[$407>>2] = $406;
 $408 = Math_fround(HEAPF32[$38>>2]);
 $409 = (($vehDriveTank) + 132|0);
 $410 = Math_fround(HEAPF32[$409>>2]);
 $411 = (($vehDriveTank) + 136|0);
 $412 = Math_fround(HEAPF32[$411>>2]);
 $413 = (($vehDriveTank) + 140|0);
 $414 = Math_fround(HEAPF32[$413>>2]);
 $415 = (($vehDriveTank) + 144|0);
 $416 = Math_fround(HEAPF32[$415>>2]);
 $417 = (0|0)==(0|0);
 if (!($417)) {
  $418 = (0 + 12|0);
  HEAPF32[$418>>2] = $408;
  $419 = (0 + 16|0);
  HEAPF32[$419>>2] = $410;
  $420 = (0 + 20|0);
  HEAPF32[$420>>2] = $412;
  $421 = (0 + 24|0);
  HEAPF32[$421>>2] = $414;
  $422 = (0 + 28|0);
  HEAPF32[$422>>2] = $416;
 }
 $fabsf$i$i13 = (Math_fround(Math_abs((Math_fround($414)))));
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($416)))));
 $423 = Math_fround($fabsf$i$i13 + $fabsf$i$i);
 $424 = Math_fround($408 * $423);
 $425 = $424 > Math_fround(0.0);
 $426 = (($vehDriveTank) + 752|0);
 $427 = HEAP32[$426>>2]|0;
 $428 = ($427|0)==(1);
 $429 = (($vehDriveTank) + 192|0);
 $430 = HEAP8[$429>>0]|0;
 $431 = ($430<<24>>24)!=(0);
 if ($428) {
  if ($431) {
   $432 = Math_fround($414 * $416);
   $433 = !($432 >= Math_fround(0.0));
   if ($433) {
    $434 = $414 == Math_fround(0.0);
    $435 = $416 == Math_fround(0.0);
    $or$cond = $434 & $435;
    if ($or$cond) {
     label = 48;
    }
   } else {
    label = 48;
   }
  }
 } else {
  if ($431) {
   $436 = Math_fround($410 * $416);
   $437 = $436 > Math_fround(0.0);
   if (!($437)) {
    $438 = Math_fround($412 * $414);
    $phitmp = !($438 > Math_fround(0.0));
    if ($phitmp) {
     label = 48;
    }
   }
  }
 }
 do {
  if ((label|0) == 48) {
   $439 = (($vehDriveTank) + 196|0);
   $440 = HEAP32[$439>>2]|0;
   $441 = (($vehDriveTank) + 200|0);
   $442 = HEAP32[$441>>2]|0;
   $443 = (($vehDriveTank) + 212|0);
   $444 = Math_fround(HEAPF32[$443>>2]);
   $445 = ($442|0)==($440|0);
   if ($445) {
    $446 = (($driveSimData) + 400|0);
    $447 = Math_fround(HEAPF32[$446>>2]);
    $448 = $444 > $447;
    if ($448) {
     $449 = Math_fround(HEAPF32[$39>>2]);
     $450 = (($driveSimData) + 108|0);
     $451 = Math_fround(HEAPF32[$450>>2]);
     $452 = Math_fround($449 * $451);
     $453 = ((($driveSimData) + ($440<<2)|0) + 272|0);
     $454 = Math_fround(HEAPF32[$453>>2]);
     $notlhs$i = $452 > $454;
     $notrhs$i = ($440|0)!=(0);
     $not$or$cond2$i = $notrhs$i & $notlhs$i;
     $455 = ((($driveSimData) + ($440<<2)|0) + 400|0);
     $456 = Math_fround(HEAPF32[$455>>2]);
     $457 = $452 < $456;
     $458 = ($440>>>0)>(2);
     $or$cond3$i = $457 & $458;
     $brmerge$i = $not$or$cond2$i | $or$cond3$i;
     if (!($brmerge$i)) {
      break;
     }
     $459 = (($vehDriveTank) + 193|0);
     $460 = $not$or$cond2$i&1;
     HEAP8[$459>>0] = $460;
     $461 = (($vehDriveTank) + 194|0);
     $462 = $or$cond3$i&1;
     HEAP8[$461>>0] = $462;
     HEAPF32[$443>>2] = Math_fround(0.0);
     break;
    }
   }
   $463 = Math_fround($444 + $timestep);
   HEAPF32[$443>>2] = $463;
  }
 } while(0);
 __ZN5physx12processGearsEfRKNS_18PxVehicleGearsDataERNS_21PxVehicleDriveDynDataE($timestep,$58,$38);
 $464 = (($vehDriveTank) + 196|0);
 $465 = HEAP32[$464>>2]|0;
 $466 = ($465|0)==(1);
 if ($466) {
  $748 = Math_fround(0.0);
 } else {
  $467 = (($driveSimData) + 256|0);
  $468 = Math_fround(HEAPF32[$467>>2]);
  $748 = $468;
 }
 $469 = ((($driveSimData) + ($465<<2)|0) + 112|0);
 $470 = Math_fround(HEAPF32[$469>>2]);
 $471 = (($driveSimData) + 240|0);
 $472 = Math_fround(HEAPF32[$471>>2]);
 $473 = Math_fround($470 * $472);
 $474 = (0|0)==(0|0);
 if (!($474)) {
  $475 = (0 + 32|0);
  HEAPF32[$475>>2] = $473;
 }
 dest=$activeWheelStates+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 if (!($198)) {
  $i6$0156 = 0;
  while(1) {
   $476 = $i6$0156 << 2;
   $477 = $i6$0156 >>> 3;
   $478 = $477 & 134217727;
   $479 = ((($vehDriveTank) + ($478<<2)|0) + 52|0);
   $480 = HEAP32[$479>>2]|0;
   $481 = $476 & 28;
   $482 = 1 << $481;
   $483 = $480 & $482;
   $484 = ($483|0)==(0);
   if (!($484)) {
    $485 = (($activeWheelStates) + ($476)|0);
    HEAP8[$485>>0] = 1;
   }
   $486 = $481 | 1;
   $487 = 1 << $486;
   $488 = $480 & $487;
   $489 = ($488|0)==(0);
   if (!($489)) {
    $$sum108109 = $476 | 1;
    $490 = (($activeWheelStates) + ($$sum108109)|0);
    HEAP8[$490>>0] = 1;
   }
   $491 = $481 | 2;
   $492 = 1 << $491;
   $493 = $480 & $492;
   $494 = ($493|0)==(0);
   if (!($494)) {
    $$sum110111 = $476 | 2;
    $495 = (($activeWheelStates) + ($$sum110111)|0);
    HEAP8[$495>>0] = 1;
   }
   $496 = $481 | 3;
   $497 = 1 << $496;
   $498 = $480 & $497;
   $499 = ($498|0)==(0);
   if (!($499)) {
    $$sum112113 = $476 | 3;
    $500 = (($activeWheelStates) + ($$sum112113)|0);
    HEAP8[$500>>0] = 1;
   }
   $501 = (($i6$0156) + 1)|0;
   $exitcond200 = ($501|0)==($49|0);
   if ($exitcond200) {
    break;
   } else {
    $i6$0156 = $501;
   }
  }
 }
 dest=$aveWheelSpeedContributions+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$diffTorqueRatios+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$wheelGearings+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN5physx15computeTankDiffEffjPKbPfS2_S2_($414,$416,$47,$activeWheelStates,$aveWheelSpeedContributions,$diffTorqueRatios,$wheelGearings);
 dest=$isAccelApplied+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $$not = $425 ^ 1;
 $brmerge = $198 | $$not;
 if (!($brmerge)) {
  $i7$0154 = 0;
  while(1) {
   $502 = $i7$0154 << 2;
   $503 = (($aveWheelSpeedContributions) + ($502<<2)|0);
   $504 = (($isAccelApplied) + ($502)|0);
   $505 = Math_fround(HEAPF32[$503>>2]);
   $506 = $505 != Math_fround(0.0);
   $507 = $506&1;
   HEAP8[$504>>0] = $507;
   $$sum9697 = $502 | 1;
   $508 = (($aveWheelSpeedContributions) + ($$sum9697<<2)|0);
   $509 = Math_fround(HEAPF32[$508>>2]);
   $510 = $509 != Math_fround(0.0);
   $511 = (($isAccelApplied) + ($$sum9697)|0);
   $512 = $510&1;
   HEAP8[$511>>0] = $512;
   $$sum100101 = $502 | 2;
   $513 = (($aveWheelSpeedContributions) + ($$sum100101<<2)|0);
   $514 = Math_fround(HEAPF32[$513>>2]);
   $515 = $514 != Math_fround(0.0);
   $516 = (($isAccelApplied) + ($$sum100101)|0);
   $517 = $515&1;
   HEAP8[$516>>0] = $517;
   $$sum104105 = $502 | 3;
   $518 = (($aveWheelSpeedContributions) + ($$sum104105<<2)|0);
   $519 = Math_fround(HEAPF32[$518>>2]);
   $520 = $519 != Math_fround(0.0);
   $521 = (($isAccelApplied) + ($$sum104105)|0);
   $522 = $520&1;
   HEAP8[$521>>0] = $522;
   $523 = (($i7$0154) + 1)|0;
   $exitcond199 = ($523|0)==($49|0);
   if ($exitcond199) {
    break;
   } else {
    $i7$0154 = $523;
   }
  }
 }
 $524 = (0|0)==(0|0);
 if (!($524)) {
  $525 = Math_fround(HEAPF32[$39>>2]);
  $526 = Math_fround(HEAPF32[$45>>2]);
  $527 = Math_fround(HEAPF32[$aveWheelSpeedContributions>>2]);
  $528 = Math_fround($526 * $527);
  $529 = Math_fround($528 + Math_fround(0.0));
  $530 = (($45) + 4|0);
  $531 = Math_fround(HEAPF32[$530>>2]);
  $532 = (($aveWheelSpeedContributions) + 4|0);
  $533 = Math_fround(HEAPF32[$532>>2]);
  $534 = Math_fround($531 * $533);
  $535 = Math_fround($529 + $534);
  $536 = (($45) + 8|0);
  $537 = Math_fround(HEAPF32[$536>>2]);
  $538 = (($aveWheelSpeedContributions) + 8|0);
  $539 = Math_fround(HEAPF32[$538>>2]);
  $540 = Math_fround($537 * $539);
  $541 = Math_fround($535 + $540);
  $542 = (($45) + 12|0);
  $543 = Math_fround(HEAPF32[$542>>2]);
  $544 = (($aveWheelSpeedContributions) + 12|0);
  $545 = Math_fround(HEAPF32[$544>>2]);
  $546 = Math_fround($543 * $545);
  $547 = Math_fround($541 + $546);
  $548 = Math_fround($473 * $547);
  $549 = Math_fround($548 - $525);
  $550 = (0 + 8|0);
  HEAPF32[$550>>2] = $549;
 }
 dest=$steerAngles+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 if ($198) {
  $1149 = $401;$1152 = $403;$1155 = $406;$647 = $363;$650 = $342;$652 = $349;$655 = $356;$682 = $391;$684 = $393;$687 = $396;
 } else {
  $i8$0150 = 0;
  while(1) {
   $551 = $i8$0150 << 2;
   $552 = (($wheelQueryResults) + (($551*148)|0)|0);
   $553 = ((($45) + (($i8$0150*208)|0)|0) + 196|0);
   $554 = HEAP32[$553>>2]|0;
   $555 = ($554|0)==(0|0);
   if ($555) {
    $$sum9091 = $551 | 1;
    $639 = (($wheelQueryResults) + (($$sum9091*148)|0)|0);
    $$sum9293 = $551 | 2;
    $640 = (($wheelQueryResults) + (($$sum9293*148)|0)|0);
    $$sum9495 = $551 | 3;
    $641 = (($wheelQueryResults) + (($$sum9495*148)|0)|0);
    ;HEAP32[$552+0>>2]=0|0;HEAP32[$552+4>>2]=0|0;HEAP32[$552+8>>2]=0|0;HEAP32[$552+12>>2]=0|0;HEAP32[$552+16>>2]=0|0;HEAP32[$552+20>>2]=0|0;HEAP32[$552+24>>2]=0|0;
    ;HEAP32[$639+0>>2]=0|0;HEAP32[$639+4>>2]=0|0;HEAP32[$639+8>>2]=0|0;HEAP32[$639+12>>2]=0|0;HEAP32[$639+16>>2]=0|0;HEAP32[$639+20>>2]=0|0;HEAP32[$639+24>>2]=0|0;
    ;HEAP32[$640+0>>2]=0|0;HEAP32[$640+4>>2]=0|0;HEAP32[$640+8>>2]=0|0;HEAP32[$640+12>>2]=0|0;HEAP32[$640+16>>2]=0|0;HEAP32[$640+20>>2]=0|0;HEAP32[$640+24>>2]=0|0;
    ;HEAP32[$641+0>>2]=0|0;HEAP32[$641+4>>2]=0|0;HEAP32[$641+8>>2]=0|0;HEAP32[$641+12>>2]=0|0;HEAP32[$641+16>>2]=0|0;HEAP32[$641+20>>2]=0|0;HEAP32[$641+24>>2]=0|0;
   } else {
    $556 = ((($45) + (($i8$0150*208)|0)|0) + 80|0);
    $557 = ((($45) + (($i8$0150*208)|0)|0) + 128|0);
    $558 = ((($45) + (($i8$0150*208)|0)|0) + 176|0);
    $559 = Math_fround(HEAPF32[$556>>2]);
    HEAPF32[$552>>2] = $559;
    $560 = ((($45) + (($i8$0150*208)|0)|0) + 84|0);
    $561 = Math_fround(HEAPF32[$560>>2]);
    $562 = ((($wheelQueryResults) + (($551*148)|0)|0) + 4|0);
    HEAPF32[$562>>2] = $561;
    $563 = ((($45) + (($i8$0150*208)|0)|0) + 88|0);
    $564 = Math_fround(HEAPF32[$563>>2]);
    $565 = ((($wheelQueryResults) + (($551*148)|0)|0) + 8|0);
    HEAPF32[$565>>2] = $564;
    $566 = Math_fround(HEAPF32[$557>>2]);
    $567 = ((($wheelQueryResults) + (($551*148)|0)|0) + 12|0);
    HEAPF32[$567>>2] = $566;
    $568 = ((($45) + (($i8$0150*208)|0)|0) + 132|0);
    $569 = Math_fround(HEAPF32[$568>>2]);
    $570 = ((($wheelQueryResults) + (($551*148)|0)|0) + 16|0);
    HEAPF32[$570>>2] = $569;
    $571 = ((($45) + (($i8$0150*208)|0)|0) + 136|0);
    $572 = Math_fround(HEAPF32[$571>>2]);
    $573 = ((($wheelQueryResults) + (($551*148)|0)|0) + 20|0);
    HEAPF32[$573>>2] = $572;
    $574 = Math_fround(HEAPF32[$558>>2]);
    $575 = ((($wheelQueryResults) + (($551*148)|0)|0) + 24|0);
    HEAPF32[$575>>2] = $574;
    $576 = ((($45) + (($i8$0150*208)|0)|0) + 92|0);
    $577 = Math_fround(HEAPF32[$576>>2]);
    $$sum4849 = $551 | 1;
    $578 = (($wheelQueryResults) + (($$sum4849*148)|0)|0);
    HEAPF32[$578>>2] = $577;
    $579 = ((($45) + (($i8$0150*208)|0)|0) + 96|0);
    $580 = Math_fround(HEAPF32[$579>>2]);
    $581 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 4|0);
    HEAPF32[$581>>2] = $580;
    $582 = ((($45) + (($i8$0150*208)|0)|0) + 100|0);
    $583 = Math_fround(HEAPF32[$582>>2]);
    $584 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 8|0);
    HEAPF32[$584>>2] = $583;
    $585 = ((($45) + (($i8$0150*208)|0)|0) + 140|0);
    $586 = Math_fround(HEAPF32[$585>>2]);
    $587 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 12|0);
    HEAPF32[$587>>2] = $586;
    $588 = ((($45) + (($i8$0150*208)|0)|0) + 144|0);
    $589 = Math_fround(HEAPF32[$588>>2]);
    $590 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 16|0);
    HEAPF32[$590>>2] = $589;
    $591 = ((($45) + (($i8$0150*208)|0)|0) + 148|0);
    $592 = Math_fround(HEAPF32[$591>>2]);
    $593 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 20|0);
    HEAPF32[$593>>2] = $592;
    $594 = ((($45) + (($i8$0150*208)|0)|0) + 180|0);
    $595 = Math_fround(HEAPF32[$594>>2]);
    $596 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 24|0);
    HEAPF32[$596>>2] = $595;
    $597 = ((($45) + (($i8$0150*208)|0)|0) + 104|0);
    $598 = Math_fround(HEAPF32[$597>>2]);
    $$sum6263 = $551 | 2;
    $599 = (($wheelQueryResults) + (($$sum6263*148)|0)|0);
    HEAPF32[$599>>2] = $598;
    $600 = ((($45) + (($i8$0150*208)|0)|0) + 108|0);
    $601 = Math_fround(HEAPF32[$600>>2]);
    $602 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 4|0);
    HEAPF32[$602>>2] = $601;
    $603 = ((($45) + (($i8$0150*208)|0)|0) + 112|0);
    $604 = Math_fround(HEAPF32[$603>>2]);
    $605 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 8|0);
    HEAPF32[$605>>2] = $604;
    $606 = ((($45) + (($i8$0150*208)|0)|0) + 152|0);
    $607 = Math_fround(HEAPF32[$606>>2]);
    $608 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 12|0);
    HEAPF32[$608>>2] = $607;
    $609 = ((($45) + (($i8$0150*208)|0)|0) + 156|0);
    $610 = Math_fround(HEAPF32[$609>>2]);
    $611 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 16|0);
    HEAPF32[$611>>2] = $610;
    $612 = ((($45) + (($i8$0150*208)|0)|0) + 160|0);
    $613 = Math_fround(HEAPF32[$612>>2]);
    $614 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 20|0);
    HEAPF32[$614>>2] = $613;
    $615 = ((($45) + (($i8$0150*208)|0)|0) + 184|0);
    $616 = Math_fround(HEAPF32[$615>>2]);
    $617 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 24|0);
    HEAPF32[$617>>2] = $616;
    $618 = ((($45) + (($i8$0150*208)|0)|0) + 116|0);
    $619 = Math_fround(HEAPF32[$618>>2]);
    $$sum7677 = $551 | 3;
    $620 = (($wheelQueryResults) + (($$sum7677*148)|0)|0);
    HEAPF32[$620>>2] = $619;
    $621 = ((($45) + (($i8$0150*208)|0)|0) + 120|0);
    $622 = Math_fround(HEAPF32[$621>>2]);
    $623 = ((($wheelQueryResults) + (($$sum7677*148)|0)|0) + 4|0);
    HEAPF32[$623>>2] = $622;
    $624 = ((($45) + (($i8$0150*208)|0)|0) + 124|0);
    $625 = Math_fround(HEAPF32[$624>>2]);
    $626 = ((($wheelQueryResults) + (($$sum7677*148)|0)|0) + 8|0);
    HEAPF32[$626>>2] = $625;
    $627 = ((($45) + (($i8$0150*208)|0)|0) + 164|0);
    $628 = Math_fround(HEAPF32[$627>>2]);
    $629 = ((($wheelQueryResults) + (($$sum7677*148)|0)|0) + 12|0);
    HEAPF32[$629>>2] = $628;
    $630 = ((($45) + (($i8$0150*208)|0)|0) + 168|0);
    $631 = Math_fround(HEAPF32[$630>>2]);
    $632 = ((($wheelQueryResults) + (($$sum7677*148)|0)|0) + 16|0);
    HEAPF32[$632>>2] = $631;
    $633 = ((($45) + (($i8$0150*208)|0)|0) + 172|0);
    $634 = Math_fround(HEAPF32[$633>>2]);
    $635 = ((($wheelQueryResults) + (($$sum7677*148)|0)|0) + 20|0);
    HEAPF32[$635>>2] = $634;
    $636 = ((($45) + (($i8$0150*208)|0)|0) + 188|0);
    $637 = Math_fround(HEAPF32[$636>>2]);
    $638 = ((($wheelQueryResults) + (($$sum7677*148)|0)|0) + 24|0);
    HEAPF32[$638>>2] = $637;
   }
   $642 = (($i8$0150) + 1)|0;
   $exitcond198 = ($642|0)==($49|0);
   if ($exitcond198) {
    break;
   } else {
    $i8$0150 = $642;
   }
  }
  $$pre = Math_fround(HEAPF32[$carChassisLinVel>>2]);
  $$pre204 = Math_fround(HEAPF32[$394>>2]);
  $$pre205 = Math_fround(HEAPF32[$397>>2]);
  $$pre206 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $$pre207 = Math_fround(HEAPF32[$404>>2]);
  $$pre208 = Math_fround(HEAPF32[$407>>2]);
  $$pre209 = Math_fround(HEAPF32[$366>>2]);
  $$pre210 = Math_fround(HEAPF32[$carChassisTransform>>2]);
  $$pre211 = Math_fround(HEAPF32[$364>>2]);
  $$pre212 = Math_fround(HEAPF32[$365>>2]);
  $1149 = $$pre206;$1152 = $$pre207;$1155 = $$pre208;$647 = $$pre209;$650 = $$pre210;$652 = $$pre211;$655 = $$pre212;$682 = $$pre;$684 = $$pre204;$687 = $$pre205;
 }
 $643 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $644 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $645 = Math_fround(Math_fround(1.0) * Math_fround(2.0));
 $646 = Math_fround($647 * $647);
 $648 = Math_fround($646 + Math_fround(-0.5));
 $649 = Math_fround($643 * $650);
 $651 = Math_fround($644 * $652);
 $653 = Math_fround($649 + $651);
 $654 = Math_fround($645 * $655);
 $656 = Math_fround($653 + $654);
 $657 = Math_fround($643 * $648);
 $658 = Math_fround($645 * $652);
 $659 = Math_fround($644 * $655);
 $660 = Math_fround($658 - $659);
 $661 = Math_fround($647 * $660);
 $662 = Math_fround($657 + $661);
 $663 = Math_fround($650 * $656);
 $664 = Math_fround($663 + $662);
 $665 = Math_fround($644 * $648);
 $666 = Math_fround($643 * $655);
 $667 = Math_fround($645 * $650);
 $668 = Math_fround($666 - $667);
 $669 = Math_fround($647 * $668);
 $670 = Math_fround($665 + $669);
 $671 = Math_fround($652 * $656);
 $672 = Math_fround($671 + $670);
 $673 = Math_fround($645 * $648);
 $674 = Math_fround($644 * $650);
 $675 = Math_fround($643 * $652);
 $676 = Math_fround($674 - $675);
 $677 = Math_fround($647 * $676);
 $678 = Math_fround($673 + $677);
 $679 = Math_fround($655 * $656);
 $680 = Math_fround($678 + $679);
 $681 = Math_fround($682 * $664);
 $683 = Math_fround($684 * $672);
 $685 = Math_fround($681 + $683);
 $686 = Math_fround($687 * $680);
 $688 = Math_fround($686 + $685);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($688)))));
 $689 = (($vehDriveTank) + 56|0);
 $690 = Math_fround(HEAPF32[$689>>2]);
 $691 = (($vehDriveTank) + 60|0);
 $692 = HEAP32[$691>>2]|0;
 $693 = (($vehDriveTank) + 64|0);
 $694 = HEAP32[$693>>2]|0;
 $695 = $fabsf$i$i$i < $690;
 $696 = $695 ? $692 : $694;
 $697 = (Math_fround(($696>>>0)));
 $698 = Math_fround(Math_fround(1.0) / $697);
 $699 = Math_fround($698 * $timestep);
 $700 = Math_fround(Math_fround(1.0) / $timestep);
 $701 = (($vehDriveTank) + 68|0);
 $702 = Math_fround(HEAPF32[$701>>2]);
 HEAPF32[$constData>>2] = $698;
 $703 = (($constData) + 4|0);
 HEAPF32[$703>>2] = $699;
 $704 = (($constData) + 8|0);
 $705 = Math_fround(HEAPF32[$gravity>>2]);
 HEAPF32[$704>>2] = $705;
 $706 = (($constData) + 12|0);
 $707 = (($gravity) + 4|0);
 $708 = Math_fround(HEAPF32[$707>>2]);
 HEAPF32[$706>>2] = $708;
 $709 = (($constData) + 16|0);
 $710 = (($gravity) + 8|0);
 $711 = Math_fround(HEAPF32[$710>>2]);
 HEAPF32[$709>>2] = $711;
 $712 = (($constData) + 20|0);
 HEAPF32[$712>>2] = $gravityMagnitude;
 $713 = (($constData) + 24|0);
 HEAPF32[$713>>2] = $recipGravityMagnitude;
 $714 = (($constData) + 28|0);
 HEAP8[$714>>0] = 1;
 $715 = (($constData) + 32|0);
 HEAPF32[$715>>2] = $702;
 $716 = (($constData) + 36|0);
 HEAP32[$716>>2] = $61;
 $717 = (($constData) + 40|0);
 HEAP32[$717>>2] = $drivableSurfaceToTireFrictionPairs;
 $718 = ($696|0)==(0);
 if ($718) {
  $1126 = $682;
 } else {
  $719 = (($chassisForce) + 4|0);
  $720 = (($chassisForce) + 8|0);
  $721 = (($chassisTorque) + 4|0);
  $722 = (($chassisTorque) + 8|0);
  $723 = (($driveSimData) + 84|0);
  $724 = (($driveSimData) + 108|0);
  $725 = (($driveSimData) + 4|0);
  $726 = (($driveSimData) + 92|0);
  $727 = (($driveSimData) + 96|0);
  $728 = (($driveSimData) + 100|0);
  $729 = (($implicitSolverInput) + 4|0);
  $730 = (($implicitSolverInput) + 8|0);
  $731 = (($implicitSolverInput) + 12|0);
  $732 = (($implicitSolverInput) + 16|0);
  $733 = (($implicitSolverInput) + 20|0);
  $734 = (($implicitSolverInput) + 24|0);
  $735 = (($implicitSolverInput) + 28|0);
  $736 = (($implicitSolverInput) + 32|0);
  $737 = (($implicitSolverInput) + 36|0);
  $738 = (($implicitSolverInput) + 40|0);
  $739 = (($implicitSolverInput) + 44|0);
  $740 = (($implicitSolverInput) + 48|0);
  $741 = (($implicitSolverInput) + 52|0);
  $742 = (($implicitSolverInput) + 56|0);
  $743 = (($implicitSolverInput) + 60|0);
  $744 = (($implicitSolverInput) + 64|0);
  $745 = (($implicitSolverInput) + 68|0);
  $746 = (($implicitSolverOutput) + 4|0);
  $747 = Math_fround($748 * $473);
  $749 = $425&1;
  $750 = (($inputData) + 4|0);
  $751 = (($inputData) + 8|0);
  $752 = (($inputData) + 12|0);
  $753 = (($inputData) + 16|0);
  $754 = (($inputData) + 20|0);
  $755 = (($inputData) + 24|0);
  $756 = (($inputData) + 28|0);
  $757 = (($inputData) + 32|0);
  $758 = (($inputData) + 36|0);
  $759 = (($inputData) + 40|0);
  $760 = (($inputData) + 44|0);
  $761 = (($inputData) + 48|0);
  $762 = (($inputData) + 52|0);
  $763 = (($inputData) + 56|0);
  $764 = (($inputData) + 60|0);
  $765 = (($inputData) + 64|0);
  $766 = (($inputData) + 68|0);
  $767 = (($inputData) + 72|0);
  $768 = (($inputData) + 76|0);
  $769 = (($inputData) + 80|0);
  $770 = (($inputData) + 84|0);
  $771 = (($inputData) + 88|0);
  $772 = (($696) + -1)|0;
  $773 = Math_fround(-$410);
  $774 = Math_fround(-$412);
  $k$0146 = 0;
  while(1) {
   HEAPF32[$chassisForce>>2] = Math_fround(0.0);
   HEAPF32[$719>>2] = Math_fround(0.0);
   HEAPF32[$720>>2] = Math_fround(0.0);
   HEAPF32[$chassisTorque>>2] = Math_fround(0.0);
   HEAPF32[$721>>2] = Math_fround(0.0);
   HEAPF32[$722>>2] = Math_fround(0.0);
   dest=$brakeTorques+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   dest=$isBrakeApplied+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   if (!($198)) {
    $i9$0115 = 0;
    while(1) {
     $775 = (($45) + (($i9$0115*208)|0)|0);
     $776 = $i9$0115 << 2;
     $777 = (($brakeTorques) + ($776<<2)|0);
     $778 = (($isBrakeApplied) + ($776)|0);
     $779 = Math_fround(HEAPF32[$775>>2]);
     $780 = $779 <= Math_fround(-0.0);
     $781 = $780 ? Math_fround(0.0) : Math_fround(1.0);
     $782 = $779 >= Math_fround(0.0);
     $783 = $782 ? $781 : Math_fround(-1.0);
     $784 = Math_fround($783 * $773);
     $785 = ((($43) + (($i9$0115*944)|0)|0) + 212|0);
     $786 = Math_fround(HEAPF32[$785>>2]);
     $787 = Math_fround($786 * $784);
     HEAPF32[$777>>2] = $787;
     $788 = Math_fround(HEAPF32[$785>>2]);
     $789 = Math_fround($410 * $788);
     $790 = $789 != Math_fround(0.0);
     $791 = $790&1;
     HEAP8[$778>>0] = $791;
     $792 = ((($45) + (($i9$0115*208)|0)|0) + 4|0);
     $793 = Math_fround(HEAPF32[$792>>2]);
     $794 = $793 <= Math_fround(-0.0);
     $795 = $794 ? Math_fround(0.0) : Math_fround(1.0);
     $796 = $793 >= Math_fround(0.0);
     $797 = $796 ? $795 : Math_fround(-1.0);
     $798 = Math_fround($797 * $774);
     $799 = ((($43) + (($i9$0115*944)|0)|0) + 260|0);
     $800 = Math_fround(HEAPF32[$799>>2]);
     $801 = Math_fround($800 * $798);
     $$sum3637 = $776 | 1;
     $802 = (($brakeTorques) + ($$sum3637<<2)|0);
     HEAPF32[$802>>2] = $801;
     $803 = Math_fround(HEAPF32[$799>>2]);
     $804 = Math_fround($412 * $803);
     $805 = $804 != Math_fround(0.0);
     $806 = (($isBrakeApplied) + ($$sum3637)|0);
     $807 = $805&1;
     HEAP8[$806>>0] = $807;
     $808 = ((($45) + (($i9$0115*208)|0)|0) + 8|0);
     $809 = Math_fround(HEAPF32[$808>>2]);
     $810 = $809 <= Math_fround(-0.0);
     $811 = $810 ? Math_fround(0.0) : Math_fround(1.0);
     $812 = $809 >= Math_fround(0.0);
     $813 = $812 ? $811 : Math_fround(-1.0);
     $814 = Math_fround($813 * $773);
     $815 = ((($43) + (($i9$0115*944)|0)|0) + 308|0);
     $816 = Math_fround(HEAPF32[$815>>2]);
     $817 = Math_fround($816 * $814);
     $$sum4041 = $776 | 2;
     $818 = (($brakeTorques) + ($$sum4041<<2)|0);
     HEAPF32[$818>>2] = $817;
     $819 = Math_fround(HEAPF32[$815>>2]);
     $820 = Math_fround($410 * $819);
     $821 = $820 != Math_fround(0.0);
     $822 = (($isBrakeApplied) + ($$sum4041)|0);
     $823 = $821&1;
     HEAP8[$822>>0] = $823;
     $824 = ((($45) + (($i9$0115*208)|0)|0) + 12|0);
     $825 = Math_fround(HEAPF32[$824>>2]);
     $826 = $825 <= Math_fround(-0.0);
     $827 = $826 ? Math_fround(0.0) : Math_fround(1.0);
     $828 = $825 >= Math_fround(0.0);
     $829 = $828 ? $827 : Math_fround(-1.0);
     $830 = Math_fround($829 * $774);
     $831 = ((($43) + (($i9$0115*944)|0)|0) + 356|0);
     $832 = Math_fround(HEAPF32[$831>>2]);
     $833 = Math_fround($832 * $830);
     $$sum4445 = $776 | 3;
     $834 = (($brakeTorques) + ($$sum4445<<2)|0);
     HEAPF32[$834>>2] = $833;
     $835 = Math_fround(HEAPF32[$831>>2]);
     $836 = Math_fround($412 * $835);
     $837 = $836 != Math_fround(0.0);
     $838 = (($isBrakeApplied) + ($$sum4445)|0);
     $839 = $837&1;
     HEAP8[$838>>0] = $839;
     $840 = (($i9$0115) + 1)|0;
     $exitcond182 = ($840|0)==($49|0);
     if ($exitcond182) {
      break;
     } else {
      $i9$0115 = $840;
     }
    }
   }
   _memset(($outputData|0),0,1112)|0;
   $841 = (($outputData) + 112|0);
   HEAP8[$841>>0] = 1;
   $842 = (($outputData) + 164|0);
   HEAP32[$842>>2] = -1;
   $843 = (($outputData) + 113|0);
   HEAP8[$843>>0] = 1;
   $844 = (($outputData) + 168|0);
   HEAP32[$844>>2] = -1;
   $845 = (($outputData) + 114|0);
   HEAP8[$845>>0] = 1;
   $846 = (($outputData) + 172|0);
   HEAP32[$846>>2] = -1;
   $847 = (($outputData) + 115|0);
   HEAP8[$847>>0] = 1;
   $848 = (($outputData) + 176|0);
   HEAP32[$848>>2] = -1;
   $849 = (($outputData) + 1112|0);
   _memset(($849|0),0,1112)|0;
   $850 = (($outputData) + 1224|0);
   HEAP8[$850>>0] = 1;
   $851 = (($outputData) + 1276|0);
   HEAP32[$851>>2] = -1;
   $852 = (($outputData) + 1225|0);
   HEAP8[$852>>0] = 1;
   $853 = (($outputData) + 1280|0);
   HEAP32[$853>>2] = -1;
   $854 = (($outputData) + 1226|0);
   HEAP8[$854>>0] = 1;
   $855 = (($outputData) + 1284|0);
   HEAP32[$855>>2] = -1;
   $856 = (($outputData) + 1227|0);
   HEAP8[$856>>0] = 1;
   $857 = (($outputData) + 1288|0);
   HEAP32[$857>>2] = -1;
   $858 = (($outputData) + 2224|0);
   _memset(($858|0),0,1112)|0;
   $859 = (($outputData) + 2336|0);
   HEAP8[$859>>0] = 1;
   $860 = (($outputData) + 2388|0);
   HEAP32[$860>>2] = -1;
   $861 = (($outputData) + 2337|0);
   HEAP8[$861>>0] = 1;
   $862 = (($outputData) + 2392|0);
   HEAP32[$862>>2] = -1;
   $863 = (($outputData) + 2338|0);
   HEAP8[$863>>0] = 1;
   $864 = (($outputData) + 2396|0);
   HEAP32[$864>>2] = -1;
   $865 = (($outputData) + 2339|0);
   HEAP8[$865>>0] = 1;
   $866 = (($outputData) + 2400|0);
   HEAP32[$866>>2] = -1;
   $867 = (($outputData) + 3336|0);
   _memset(($867|0),0,1112)|0;
   $868 = (($outputData) + 3448|0);
   HEAP8[$868>>0] = 1;
   $869 = (($outputData) + 3500|0);
   HEAP32[$869>>2] = -1;
   $870 = (($outputData) + 3449|0);
   HEAP8[$870>>0] = 1;
   $871 = (($outputData) + 3504|0);
   HEAP32[$871>>2] = -1;
   $872 = (($outputData) + 3450|0);
   HEAP8[$872>>0] = 1;
   $873 = (($outputData) + 3508|0);
   HEAP32[$873>>2] = -1;
   $874 = (($outputData) + 3451|0);
   HEAP8[$874>>0] = 1;
   $875 = (($outputData) + 3512|0);
   HEAP32[$875>>2] = -1;
   $876 = (($outputData) + 4448|0);
   _memset(($876|0),0,1112)|0;
   $877 = (($outputData) + 4560|0);
   HEAP8[$877>>0] = 1;
   $878 = (($outputData) + 4612|0);
   HEAP32[$878>>2] = -1;
   $879 = (($outputData) + 4561|0);
   HEAP8[$879>>0] = 1;
   $880 = (($outputData) + 4616|0);
   HEAP32[$880>>2] = -1;
   $881 = (($outputData) + 4562|0);
   HEAP8[$881>>0] = 1;
   $882 = (($outputData) + 4620|0);
   HEAP32[$882>>2] = -1;
   $883 = (($outputData) + 4563|0);
   HEAP8[$883>>0] = 1;
   $884 = (($outputData) + 4624|0);
   HEAP32[$884>>2] = -1;
   do {
    if (!($198)) {
     $885 = Math_fround(HEAPF32[$carChassisTransform>>2]);
     $886 = Math_fround(HEAPF32[$364>>2]);
     $887 = Math_fround(HEAPF32[$365>>2]);
     $888 = Math_fround(HEAPF32[$366>>2]);
     $889 = Math_fround(HEAPF32[$367>>2]);
     $890 = Math_fround(HEAPF32[$368>>2]);
     $891 = Math_fround(HEAPF32[$369>>2]);
     $892 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
     $893 = Math_fround(HEAPF32[$394>>2]);
     $894 = Math_fround(HEAPF32[$397>>2]);
     $895 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
     $896 = Math_fround(HEAPF32[$404>>2]);
     $897 = Math_fround(HEAPF32[$407>>2]);
     $898 = ($772|0)==($k$0146|0);
     $966 = Math_fround(0.0);$970 = Math_fround(0.0);$974 = Math_fround(0.0);$978 = Math_fround(0.0);$982 = Math_fround(0.0);$986 = Math_fround(0.0);$i10$0119 = 0;
     while(1) {
      HEAP8[$inputData>>0] = $749;
      $899 = $i10$0119 << 2;
      $900 = (($isAccelApplied) + ($899)|0);
      HEAP32[$750>>2] = $900;
      $901 = (($isBrakeApplied) + ($899)|0);
      HEAP32[$751>>2] = $901;
      $902 = (($steerAngles) + ($899<<2)|0);
      HEAP32[$752>>2] = $902;
      $903 = (($activeWheelStates) + ($899)|0);
      HEAP32[$753>>2] = $903;
      HEAPF32[$754>>2] = $885;
      HEAPF32[$755>>2] = $886;
      HEAPF32[$756>>2] = $887;
      HEAPF32[$757>>2] = $888;
      HEAPF32[$758>>2] = $889;
      HEAPF32[$759>>2] = $890;
      HEAPF32[$760>>2] = $891;
      HEAPF32[$761>>2] = $892;
      HEAPF32[$762>>2] = $893;
      HEAPF32[$763>>2] = $894;
      HEAPF32[$764>>2] = $895;
      HEAPF32[$765>>2] = $896;
      HEAPF32[$766>>2] = $897;
      $904 = (($43) + (($i10$0119*944)|0)|0);
      HEAP32[$767>>2] = $904;
      $905 = (($45) + (($i10$0119*208)|0)|0);
      HEAP32[$768>>2] = $905;
      $906 = (($tires4ForceCalculators) + (($i10$0119*20)|0)|0);
      HEAP32[$769>>2] = $906;
      HEAP32[$770>>2] = $5;
      $907 = (($numActiveWheelsPerBlock4) + ($i10$0119<<2)|0);
      $908 = HEAP32[$907>>2]|0;
      HEAP32[$771>>2] = $908;
      $909 = (($outputData) + (($i10$0119*1112)|0)|0);
      __ZN5physx21processSuspTireWheelsEjRKNS_29ProcessSuspWheelTireConstDataERKNS_29ProcessSuspWheelTireInputDataERNS_30ProcessSuspWheelTireOutputDataE($899,$constData,$inputData,$909);
      $910 = ((($outputData) + (($i10$0119*1112)|0)|0) + 508|0);
      $911 = HEAP32[$768>>2]|0;
      $912 = (($911) + 48|0);
      $913 = Math_fround(HEAPF32[$910>>2]);
      $914 = Math_fround(HEAPF32[$912>>2]);
      $915 = $913 != $914;
      $916 = $915 ? $913 : Math_fround(0.0);
      HEAPF32[$912>>2] = $916;
      $917 = ((($outputData) + (($i10$0119*1112)|0)|0) + 512|0);
      $918 = Math_fround(HEAPF32[$917>>2]);
      $919 = (($911) + 52|0);
      $920 = Math_fround(HEAPF32[$919>>2]);
      $921 = $918 != $920;
      $922 = $921 ? $918 : Math_fround(0.0);
      HEAPF32[$919>>2] = $922;
      $923 = ((($outputData) + (($i10$0119*1112)|0)|0) + 516|0);
      $924 = Math_fround(HEAPF32[$923>>2]);
      $925 = (($911) + 56|0);
      $926 = Math_fround(HEAPF32[$925>>2]);
      $927 = $924 != $926;
      $928 = $927 ? $924 : Math_fround(0.0);
      HEAPF32[$925>>2] = $928;
      $929 = ((($outputData) + (($i10$0119*1112)|0)|0) + 520|0);
      $930 = Math_fround(HEAPF32[$929>>2]);
      $931 = (($911) + 60|0);
      $932 = Math_fround(HEAPF32[$931>>2]);
      $933 = $930 != $932;
      $934 = $933 ? $930 : Math_fround(0.0);
      HEAPF32[$931>>2] = $934;
      $935 = ((($outputData) + (($i10$0119*1112)|0)|0) + 524|0);
      $936 = (($911) + 64|0);
      $937 = Math_fround(HEAPF32[$935>>2]);
      $938 = Math_fround(HEAPF32[$936>>2]);
      $939 = $937 != $938;
      $940 = $939 ? $937 : Math_fround(0.0);
      HEAPF32[$936>>2] = $940;
      $941 = ((($outputData) + (($i10$0119*1112)|0)|0) + 528|0);
      $942 = Math_fround(HEAPF32[$941>>2]);
      $943 = (($911) + 68|0);
      $944 = Math_fround(HEAPF32[$943>>2]);
      $945 = $942 != $944;
      $946 = $945 ? $942 : Math_fround(0.0);
      HEAPF32[$943>>2] = $946;
      $947 = ((($outputData) + (($i10$0119*1112)|0)|0) + 532|0);
      $948 = Math_fround(HEAPF32[$947>>2]);
      $949 = (($911) + 72|0);
      $950 = Math_fround(HEAPF32[$949>>2]);
      $951 = $948 != $950;
      $952 = $951 ? $948 : Math_fround(0.0);
      HEAPF32[$949>>2] = $952;
      $953 = ((($outputData) + (($i10$0119*1112)|0)|0) + 536|0);
      $954 = Math_fround(HEAPF32[$953>>2]);
      $955 = (($911) + 76|0);
      $956 = Math_fround(HEAPF32[$955>>2]);
      $957 = $954 != $956;
      $958 = $957 ? $954 : Math_fround(0.0);
      HEAPF32[$955>>2] = $958;
      if ($898) {
       $959 = ((($outputData) + (($i10$0119*1112)|0)|0) + 888|0);
       $960 = ((($outputData) + (($i10$0119*1112)|0)|0) + 904|0);
       $961 = ((($outputData) + (($i10$0119*1112)|0)|0) + 968|0);
       $962 = ((($outputData) + (($i10$0119*1112)|0)|0) + 984|0);
       __ZN5physx19updateCachedHitDataEPKjPKNS_6PxVec4EPKfS6_PNS_23PxVehicleWheels4DynDataE($959,$960,$961,$962,$905);
      }
      $963 = ((($outputData) + (($i10$0119*1112)|0)|0) + 484|0);
      $964 = Math_fround(HEAPF32[$963>>2]);
      $965 = Math_fround($964 + $966);
      $967 = ((($outputData) + (($i10$0119*1112)|0)|0) + 488|0);
      $968 = Math_fround(HEAPF32[$967>>2]);
      $969 = Math_fround($968 + $970);
      $971 = ((($outputData) + (($i10$0119*1112)|0)|0) + 492|0);
      $972 = Math_fround(HEAPF32[$971>>2]);
      $973 = Math_fround($972 + $974);
      $975 = ((($outputData) + (($i10$0119*1112)|0)|0) + 496|0);
      $976 = Math_fround(HEAPF32[$975>>2]);
      $977 = Math_fround($976 + $978);
      $979 = ((($outputData) + (($i10$0119*1112)|0)|0) + 500|0);
      $980 = Math_fround(HEAPF32[$979>>2]);
      $981 = Math_fround($980 + $982);
      $983 = ((($outputData) + (($i10$0119*1112)|0)|0) + 504|0);
      $984 = Math_fround(HEAPF32[$983>>2]);
      $985 = Math_fround($984 + $986);
      $987 = ((($45) + (($i10$0119*208)|0)|0) + 192|0);
      $988 = HEAP32[$987>>2]|0;
      $989 = (($988) + 4|0);
      $990 = ((($outputData) + (($i10$0119*1112)|0)|0) + 540|0);
      (__ZN5physx25PxVehicleConstraintShader21VehicleConstraintDataaSERKS1_($989,$990)|0);
      $991 = HEAP32[$752>>2]|0;
      $992 = (($wheelQueryResults) + (($899*148)|0)|0);
      __ZN5physx15PxVehicleUpdate25storeSuspWheelTireResultsERKNS_30ProcessSuspWheelTireOutputDataEPKfPNS_18PxWheelQueryResultEj($909,$991,$992,$908);
      $993 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
      $994 = ($908|0)==(0);
      if (!($994)) {
       $i$01$i = 0;
       while(1) {
        $995 = (((($outputData) + (($i10$0119*1112)|0)|0) + ($i$01$i<<2)|0) + 1000|0);
        $996 = HEAP32[$995>>2]|0;
        $$sum = (($i$01$i) + ($899))|0;
        $997 = ((($993) + (($$sum*56)|0)|0) + 28|0);
        HEAP32[$997>>2] = $996;
        $998 = (((($outputData) + (($i10$0119*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1016|0);
        $999 = Math_fround(HEAPF32[$998>>2]);
        $1000 = ((($993) + (($$sum*56)|0)|0) + 32|0);
        $1001 = Math_fround(HEAPF32[$1000>>2]);
        $1002 = Math_fround($999 + $1001);
        HEAPF32[$1000>>2] = $1002;
        $1003 = (((($outputData) + (($i10$0119*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1020|0);
        $1004 = Math_fround(HEAPF32[$1003>>2]);
        $1005 = ((($993) + (($$sum*56)|0)|0) + 36|0);
        $1006 = Math_fround(HEAPF32[$1005>>2]);
        $1007 = Math_fround($1004 + $1006);
        HEAPF32[$1005>>2] = $1007;
        $1008 = (((($outputData) + (($i10$0119*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1024|0);
        $1009 = Math_fround(HEAPF32[$1008>>2]);
        $1010 = ((($993) + (($$sum*56)|0)|0) + 40|0);
        $1011 = Math_fround(HEAPF32[$1010>>2]);
        $1012 = Math_fround($1009 + $1011);
        HEAPF32[$1010>>2] = $1012;
        $1013 = (((($outputData) + (($i10$0119*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1064|0);
        $1014 = Math_fround(HEAPF32[$1013>>2]);
        $1015 = ((($993) + (($$sum*56)|0)|0) + 44|0);
        HEAPF32[$1015>>2] = $1014;
        $1016 = (((($outputData) + (($i10$0119*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1068|0);
        $1017 = Math_fround(HEAPF32[$1016>>2]);
        $1018 = ((($993) + (($$sum*56)|0)|0) + 48|0);
        HEAPF32[$1018>>2] = $1017;
        $1019 = (((($outputData) + (($i10$0119*1112)|0)|0) + (($i$01$i*12)|0)|0) + 1072|0);
        $1020 = Math_fround(HEAPF32[$1019>>2]);
        $1021 = ((($993) + (($$sum*56)|0)|0) + 52|0);
        HEAPF32[$1021>>2] = $1020;
        $1022 = (($i$01$i) + 1)|0;
        $exitcond$i7 = ($1022|0)==($908|0);
        if ($exitcond$i7) {
         break;
        } else {
         $i$01$i = $1022;
        }
       }
      }
      $1023 = (($i10$0119) + 1)|0;
      $exitcond188 = ($1023|0)==($49|0);
      if ($exitcond188) {
       break;
      } else {
       $966 = $965;$970 = $969;$974 = $973;$978 = $977;$982 = $981;$986 = $985;$i10$0119 = $1023;
      }
     }
     HEAPF32[$chassisForce>>2] = $965;
     HEAPF32[$719>>2] = $969;
     HEAPF32[$720>>2] = $973;
     HEAPF32[$chassisTorque>>2] = $977;
     HEAPF32[$721>>2] = $981;
     HEAPF32[$722>>2] = $985;
     if ($198) {
      break;
     } else {
      $i11$0133 = 0;
     }
     while(1) {
      $1024 = ((($outputData) + (($i11$0133*1112)|0)|0) + 468|0);
      $1025 = Math_fround(HEAPF32[$1024>>2]);
      $1026 = $i11$0133 << 2;
      $1027 = (($inputData) + ($1026<<2)|0);
      HEAPF32[$1027>>2] = $1025;
      $1028 = ((($outputData) + (($i11$0133*1112)|0)|0) + 472|0);
      $1029 = Math_fround(HEAPF32[$1028>>2]);
      $1030 = $1026 | 1;
      $1031 = (($inputData) + ($1030<<2)|0);
      HEAPF32[$1031>>2] = $1029;
      $1032 = ((($outputData) + (($i11$0133*1112)|0)|0) + 476|0);
      $1033 = Math_fround(HEAPF32[$1032>>2]);
      $1034 = $1026 | 2;
      $1035 = (($inputData) + ($1034<<2)|0);
      HEAPF32[$1035>>2] = $1033;
      $1036 = ((($outputData) + (($i11$0133*1112)|0)|0) + 480|0);
      $1037 = Math_fround(HEAPF32[$1036>>2]);
      $1038 = $1026 | 3;
      $1039 = (($inputData) + ($1038<<2)|0);
      HEAPF32[$1039>>2] = $1037;
      $1040 = (($i11$0133) + 1)|0;
      $exitcond189 = ($1040|0)==($49|0);
      if ($exitcond189) {
       break;
      } else {
       $i11$0133 = $1040;
      }
     }
    }
   } while(0);
   $1041 = Math_fround(HEAPF32[$39>>2]);
   $1042 = Math_fround(HEAPF32[$723>>2]);
   $1043 = Math_fround($408 * $1042);
   $1044 = Math_fround(HEAPF32[$724>>2]);
   $1045 = Math_fround($1041 * $1044);
   $1046 = HEAP32[$55>>2]|0;
   do {
    if ((($1046|0) == 1)) {
     label = 92;
    } else if ((($1046|0) == 0)) {
     $$0$i$i = Math_fround(0.0);
    } else {
     $1047 = Math_fround(HEAPF32[$driveSimData>>2]);
     $1048 = $1047 > $1045;
     if ($1048) {
      label = 92;
      break;
     }
     $1050 = Math_fround(HEAPF32[$725>>2]);
     $i$07$i$i = 1;$x0$08$i$i = $1047;$y0$06$i$i = $1050;
     while(1) {
      $1053 = $i$07$i$i << 1;
      $1054 = (($driveSimData) + ($1053<<2)|0);
      $1055 = Math_fround(HEAPF32[$1054>>2]);
      $1056 = $1053 | 1;
      $1057 = (($driveSimData) + ($1056<<2)|0);
      $1058 = Math_fround(HEAPF32[$1057>>2]);
      $1059 = $x0$08$i$i <= $1045;
      $1060 = $1055 > $1045;
      $or$cond$i$i = $1059 & $1060;
      $1052 = (($i$07$i$i) + 1)|0;
      if ($or$cond$i$i) {
       label = 96;
       break;
      }
      $1051 = ($1052>>>0)<($1046>>>0);
      if ($1051) {
       $i$07$i$i = $1052;$x0$08$i$i = $1055;$y0$06$i$i = $1058;
      } else {
       label = 97;
       break;
      }
     }
     if ((label|0) == 96) {
      label = 0;
      $1061 = Math_fround($1058 - $y0$06$i$i);
      $1062 = Math_fround($1045 - $x0$08$i$i);
      $1063 = Math_fround($1062 * $1061);
      $1064 = Math_fround($1055 - $x0$08$i$i);
      $1065 = Math_fround($1063 / $1064);
      $1066 = Math_fround($y0$06$i$i + $1065);
      $$0$i$i = $1066;
      break;
     }
     else if ((label|0) == 97) {
      label = 0;
      $1067 = $1046 << 1;
      $1068 = (($1067) + -2)|0;
      $1069 = $1068 | 1;
      $1070 = (($driveSimData) + ($1069<<2)|0);
      $1071 = Math_fround(HEAPF32[$1070>>2]);
      $$0$i$i = $1071;
      break;
     }
    }
   } while(0);
   if ((label|0) == 92) {
    label = 0;
    $1049 = Math_fround(HEAPF32[$725>>2]);
    $$0$i$i = $1049;
   }
   $1072 = Math_fround($1043 * $$0$i$i);
   $1073 = (0|0)==(0|0);
   if (!($1073)) {
    $1074 = (0 + 4|0);
    HEAPF32[$1074>>2] = $1072;
   }
   $1075 = Math_fround(HEAPF32[$726>>2]);
   $$val = Math_fround(HEAPF32[$728>>2]);
   $$val29 = Math_fround(HEAPF32[$727>>2]);
   $1076 = $466 ? $$val : $$val29;
   $1077 = Math_fround($1075 - $1076);
   $1078 = Math_fround($408 * $1077);
   $1079 = Math_fround($1076 + $1078);
   HEAPF32[$implicitSolverInput>>2] = $699;
   HEAPF32[$729>>2] = Math_fround(0.0);
   HEAPF32[$730>>2] = Math_fround(0.0);
   HEAPF32[$731>>2] = $748;
   HEAPF32[$732>>2] = $473;
   HEAP32[$733>>2] = 1;
   HEAP32[$734>>2] = 0;
   HEAPF32[$735>>2] = $1072;
   HEAPF32[$736>>2] = $1079;
   HEAP32[$737>>2] = $diffTorqueRatios;
   HEAP32[$738>>2] = $aveWheelSpeedContributions;
   HEAP32[$739>>2] = $brakeTorques;
   HEAP32[$740>>2] = $isBrakeApplied;
   HEAP32[$741>>2] = $inputData;
   HEAP32[$742>>2] = $49;
   HEAP32[$743>>2] = $47;
   HEAP32[$744>>2] = $43;
   HEAP32[$745>>2] = $driveSimData;
   HEAP32[$implicitSolverOutput>>2] = $45;
   HEAP32[$746>>2] = $38;
   __ZN5physx46solveTankInternaDynamicsEnginePlusDrivenWheelsERKNS_19ImplicitSolverInputEPKbPKfPNS_20ImplicitSolverOutputE($implicitSolverInput,$activeWheelStates,$wheelGearings,$implicitSolverOutput);
   if (!($198)) {
    $i13$0143 = 0;
    while(1) {
     $j$02$i = 0;
     while(1) {
      $1080 = ((($45) + (($i13$0143*208)|0)|0) + ($j$02$i<<2)|0);
      $1081 = Math_fround(HEAPF32[$1080>>2]);
      $1082 = (((($outputData) + (($i13$0143*1112)|0)|0) + ($j$02$i<<2)|0) + 292|0);
      $1083 = Math_fround(HEAPF32[$1082>>2]);
      $1084 = (((($43) + (($i13$0143*944)|0)|0) + (($j$02$i*48)|0)|0) + 12|0);
      $1085 = Math_fround(HEAPF32[$1084>>2]);
      $1086 = Math_fround(-$1085);
      $1087 = $1083 > $1086;
      do {
       if ($1087) {
        $1088 = (($isBrakeApplied) + ($j$02$i)|0);
        $1089 = HEAP8[$1088>>0]|0;
        $1090 = ($1089<<24>>24)==(0);
        if (!($1090)) {
         $wheelOmega$0$i = $1081;
         break;
        }
        $1091 = (($diffTorqueRatios) + ($j$02$i<<2)|0);
        $1092 = Math_fround(HEAPF32[$1091>>2]);
        $1093 = Math_fround($747 * $1092);
        $1094 = Math_fround($1072 * $1093);
        $1095 = $1094 == Math_fround(0.0);
        if (!($1095)) {
         $wheelOmega$0$i = $1081;
         break;
        }
        $1096 = (((($outputData) + (($i13$0143*1112)|0)|0) + ($j$02$i<<2)|0) + 452|0);
        $1097 = Math_fround(HEAPF32[$1096>>2]);
        $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($1097)))));
        $1098 = Math_fround(HEAPF32[523912>>2]);
        $1099 = $fabsf$i$i1$i < $1098;
        if (!($1099)) {
         $wheelOmega$0$i = $1081;
         break;
        }
        $1100 = (((($43) + (($i13$0143*944)|0)|0) + (($j$02$i*48)|0)|0) + 228|0);
        $1101 = Math_fround(HEAPF32[$1100>>2]);
        $1102 = Math_fround(HEAPF32[523920>>2]);
        $1103 = Math_fround($fabsf$i$i1$i * $1102);
        $1104 = Math_fround($1097 * $1101);
        $1105 = Math_fround(Math_fround(1.0) - $1103);
        $1106 = Math_fround($1104 * $1105);
        $1107 = Math_fround($1081 * $1103);
        $1108 = Math_fround($1107 + $1106);
        $wheelOmega$0$i = $1108;
       } else {
        $wheelOmega$0$i = $1081;
       }
      } while(0);
      $1109 = (((($45) + (($i13$0143*208)|0)|0) + ($j$02$i<<2)|0) + 32|0);
      $1110 = Math_fround(HEAPF32[$1109>>2]);
      $1111 = Math_fround($699 * $wheelOmega$0$i);
      $1112 = Math_fround($1110 + $1111);
      $1113 = Math_fround($1112 + Math_fround(-31.415927886962890625));
      $1114 = Math_fround(Math_fround(-31.415927886962890625) - $1112);
      $1115 = Math_fround($1112 + Math_fround(31.415927886962890625));
      $1116 = $1114 >= Math_fround(0.0);
      $1117 = $1116 ? $1115 : $1112;
      $1118 = $1113 >= Math_fround(0.0);
      $1119 = $1118 ? $1113 : $1117;
      HEAPF32[$1109>>2] = $1119;
      $1120 = (((($45) + (($i13$0143*208)|0)|0) + ($j$02$i<<2)|0) + 16|0);
      HEAPF32[$1120>>2] = $wheelOmega$0$i;
      $1121 = (($j$02$i) + 1)|0;
      $exitcond$i = ($1121|0)==(4);
      if ($exitcond$i) {
       break;
      } else {
       $j$02$i = $1121;
      }
     }
     $1122 = (($i13$0143) + 1)|0;
     $exitcond196 = ($1122|0)==($49|0);
     if ($exitcond196) {
      break;
     } else {
      $i13$0143 = $1122;
     }
    }
   }
   __ZN5physx13integrateBodyEfRKNS_6PxVec3ES2_S2_fRS0_S3_RNS_11PxTransformE($374,$inverseInertia,$chassisForce,$chassisTorque,$699,$carChassisLinVel,$carChassisAngVel,$carChassisTransform);
   $1123 = (($k$0146) + 1)|0;
   $exitcond197 = ($1123|0)==($696|0);
   if ($exitcond197) {
    break;
   } else {
    $k$0146 = $1123;
   }
  }
  $$pre213 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
  $1126 = $$pre213;
 }
 $1124 = (0)==(0);
 $1125 = (($vehicleConcurrentUpdates) + 8|0);
 if ($1124) {
  HEAPF32[$1125>>2] = $1126;
  $1127 = Math_fround(HEAPF32[$394>>2]);
  $1128 = (($vehicleConcurrentUpdates) + 12|0);
  HEAPF32[$1128>>2] = $1127;
  $1129 = Math_fround(HEAPF32[$397>>2]);
  $1130 = (($vehicleConcurrentUpdates) + 16|0);
  HEAPF32[$1130>>2] = $1129;
  $1131 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $1132 = (($vehicleConcurrentUpdates) + 20|0);
  HEAPF32[$1132>>2] = $1131;
  $1133 = Math_fround(HEAPF32[$404>>2]);
  $1134 = (($vehicleConcurrentUpdates) + 24|0);
  HEAPF32[$1134>>2] = $1133;
  $1135 = Math_fround(HEAPF32[$407>>2]);
  $1136 = (($vehicleConcurrentUpdates) + 28|0);
  HEAPF32[$1136>>2] = $1135;
 } else {
  $1137 = Math_fround($1126 - $682);
  $1138 = Math_fround(HEAPF32[$394>>2]);
  $1139 = Math_fround($1138 - $684);
  $1140 = Math_fround(HEAPF32[$397>>2]);
  $1141 = Math_fround($1140 - $687);
  $1142 = Math_fround($700 * $1137);
  $1143 = Math_fround($700 * $1139);
  $1144 = Math_fround($700 * $1141);
  HEAPF32[$1125>>2] = $1142;
  $1145 = (($vehicleConcurrentUpdates) + 12|0);
  HEAPF32[$1145>>2] = $1143;
  $1146 = (($vehicleConcurrentUpdates) + 16|0);
  HEAPF32[$1146>>2] = $1144;
  $1147 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $1148 = Math_fround($1147 - $1149);
  $1150 = Math_fround(HEAPF32[$404>>2]);
  $1151 = Math_fround($1150 - $1152);
  $1153 = Math_fround(HEAPF32[$407>>2]);
  $1154 = Math_fround($1153 - $1155);
  $1156 = Math_fround($700 * $1148);
  $1157 = Math_fround($700 * $1151);
  $1158 = Math_fround($700 * $1154);
  $1159 = (($vehicleConcurrentUpdates) + 20|0);
  HEAPF32[$1159>>2] = $1156;
  $1160 = (($vehicleConcurrentUpdates) + 24|0);
  HEAPF32[$1160>>2] = $1157;
  $1161 = (($vehicleConcurrentUpdates) + 28|0);
  HEAPF32[$1161>>2] = $1158;
 }
 HEAPF32[$brakeTorques>>2] = Math_fround(0.0);
 $1162 = (($brakeTorques) + 4|0);
 HEAPF32[$1162>>2] = Math_fround(0.0);
 $1163 = (($brakeTorques) + 8|0);
 HEAPF32[$1163>>2] = Math_fround(0.0);
 $1164 = (($brakeTorques) + 12|0);
 HEAPF32[$1164>>2] = Math_fround(1.0);
 $1165 = (($brakeTorques) + 16|0);
 $1166 = (($brakeTorques) + 20|0);
 $1167 = (($brakeTorques) + 24|0);
 $1168 = (($brakeTorques) + 28|0);
 $1169 = (($brakeTorques) + 32|0);
 $1170 = (($brakeTorques) + 36|0);
 $1171 = (($brakeTorques) + 40|0);
 ;HEAP32[$1165+0>>2]=0|0;HEAP32[$1165+4>>2]=0|0;HEAP32[$1165+8>>2]=0|0;HEAP32[$1165+12>>2]=0|0;HEAP32[$1165+16>>2]=0|0;HEAP32[$1165+20>>2]=0|0;
 HEAPF32[$1171>>2] = Math_fround(1.0);
 $1172 = (($brakeTorques) + 44|0);
 $1173 = (($brakeTorques) + 48|0);
 $1174 = (($brakeTorques) + 52|0);
 $1175 = (($brakeTorques) + 56|0);
 $1176 = (($brakeTorques) + 60|0);
 $1177 = (($brakeTorques) + 64|0);
 $1178 = (($brakeTorques) + 68|0);
 ;HEAP32[$1172+0>>2]=0|0;HEAP32[$1172+4>>2]=0|0;HEAP32[$1172+8>>2]=0|0;HEAP32[$1172+12>>2]=0|0;HEAP32[$1172+16>>2]=0|0;HEAP32[$1172+20>>2]=0|0;
 HEAPF32[$1178>>2] = Math_fround(1.0);
 $1179 = (($brakeTorques) + 72|0);
 $1180 = (($brakeTorques) + 76|0);
 $1181 = (($brakeTorques) + 80|0);
 $1182 = (($brakeTorques) + 84|0);
 $1183 = (($brakeTorques) + 88|0);
 $1184 = (($brakeTorques) + 92|0);
 $1185 = (($brakeTorques) + 96|0);
 ;HEAP32[$1179+0>>2]=0|0;HEAP32[$1179+4>>2]=0|0;HEAP32[$1179+8>>2]=0|0;HEAP32[$1179+12>>2]=0|0;HEAP32[$1179+16>>2]=0|0;HEAP32[$1179+20>>2]=0|0;
 HEAPF32[$1185>>2] = Math_fround(1.0);
 $1186 = (($brakeTorques) + 100|0);
 HEAPF32[$1186>>2] = Math_fround(0.0);
 $1187 = (($brakeTorques) + 104|0);
 HEAPF32[$1187>>2] = Math_fround(0.0);
 $1188 = (($brakeTorques) + 108|0);
 HEAPF32[$1188>>2] = Math_fround(0.0);
 $1189 = HEAP32[$numActiveWheelsPerBlock4>>2]|0;
 __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($43,$45,$wheelQueryResults,$1189,$carChassisCMLocalPose,$brakeTorques);
 $1190 = Math_fround(HEAPF32[$brakeTorques>>2]);
 $1191 = (($wheelQueryResults) + 120|0);
 HEAPF32[$1191>>2] = $1190;
 $1192 = Math_fround(HEAPF32[$1162>>2]);
 $1193 = (($wheelQueryResults) + 124|0);
 HEAPF32[$1193>>2] = $1192;
 $1194 = Math_fround(HEAPF32[$1163>>2]);
 $1195 = (($wheelQueryResults) + 128|0);
 HEAPF32[$1195>>2] = $1194;
 $1196 = Math_fround(HEAPF32[$1164>>2]);
 $1197 = (($wheelQueryResults) + 132|0);
 HEAPF32[$1197>>2] = $1196;
 $1198 = Math_fround(HEAPF32[$1165>>2]);
 $1199 = (($wheelQueryResults) + 136|0);
 HEAPF32[$1199>>2] = $1198;
 $1200 = Math_fround(HEAPF32[$1166>>2]);
 $1201 = (($wheelQueryResults) + 140|0);
 HEAPF32[$1201>>2] = $1200;
 $1202 = Math_fround(HEAPF32[$1167>>2]);
 $1203 = (($wheelQueryResults) + 144|0);
 HEAPF32[$1203>>2] = $1202;
 $1204 = Math_fround(HEAPF32[$1168>>2]);
 $1205 = (($wheelQueryResults) + 268|0);
 HEAPF32[$1205>>2] = $1204;
 $1206 = Math_fround(HEAPF32[$1169>>2]);
 $1207 = (($wheelQueryResults) + 272|0);
 HEAPF32[$1207>>2] = $1206;
 $1208 = Math_fround(HEAPF32[$1170>>2]);
 $1209 = (($wheelQueryResults) + 276|0);
 HEAPF32[$1209>>2] = $1208;
 $1210 = Math_fround(HEAPF32[$1171>>2]);
 $1211 = (($wheelQueryResults) + 280|0);
 HEAPF32[$1211>>2] = $1210;
 $1212 = Math_fround(HEAPF32[$1172>>2]);
 $1213 = (($wheelQueryResults) + 284|0);
 HEAPF32[$1213>>2] = $1212;
 $1214 = Math_fround(HEAPF32[$1173>>2]);
 $1215 = (($wheelQueryResults) + 288|0);
 HEAPF32[$1215>>2] = $1214;
 $1216 = Math_fround(HEAPF32[$1174>>2]);
 $1217 = (($wheelQueryResults) + 292|0);
 HEAPF32[$1217>>2] = $1216;
 $1218 = Math_fround(HEAPF32[$1175>>2]);
 $1219 = (($wheelQueryResults) + 416|0);
 HEAPF32[$1219>>2] = $1218;
 $1220 = Math_fround(HEAPF32[$1176>>2]);
 $1221 = (($wheelQueryResults) + 420|0);
 HEAPF32[$1221>>2] = $1220;
 $1222 = Math_fround(HEAPF32[$1177>>2]);
 $1223 = (($wheelQueryResults) + 424|0);
 HEAPF32[$1223>>2] = $1222;
 $1224 = Math_fround(HEAPF32[$1178>>2]);
 $1225 = (($wheelQueryResults) + 428|0);
 HEAPF32[$1225>>2] = $1224;
 $1226 = Math_fround(HEAPF32[$1179>>2]);
 $1227 = (($wheelQueryResults) + 432|0);
 HEAPF32[$1227>>2] = $1226;
 $1228 = Math_fround(HEAPF32[$1180>>2]);
 $1229 = (($wheelQueryResults) + 436|0);
 HEAPF32[$1229>>2] = $1228;
 $1230 = Math_fround(HEAPF32[$1181>>2]);
 $1231 = (($wheelQueryResults) + 440|0);
 HEAPF32[$1231>>2] = $1230;
 $1232 = Math_fround(HEAPF32[$1182>>2]);
 $1233 = (($wheelQueryResults) + 564|0);
 HEAPF32[$1233>>2] = $1232;
 $1234 = Math_fround(HEAPF32[$1183>>2]);
 $1235 = (($wheelQueryResults) + 568|0);
 HEAPF32[$1235>>2] = $1234;
 $1236 = Math_fround(HEAPF32[$1184>>2]);
 $1237 = (($wheelQueryResults) + 572|0);
 HEAPF32[$1237>>2] = $1236;
 $1238 = Math_fround(HEAPF32[$1185>>2]);
 $1239 = (($wheelQueryResults) + 576|0);
 HEAPF32[$1239>>2] = $1238;
 $1240 = Math_fround(HEAPF32[$1186>>2]);
 $1241 = (($wheelQueryResults) + 580|0);
 HEAPF32[$1241>>2] = $1240;
 $1242 = Math_fround(HEAPF32[$1187>>2]);
 $1243 = (($wheelQueryResults) + 584|0);
 HEAPF32[$1243>>2] = $1242;
 $1244 = Math_fround(HEAPF32[$1188>>2]);
 $1245 = (($wheelQueryResults) + 588|0);
 HEAPF32[$1245>>2] = $1244;
 $1246 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
 HEAPF32[$1246>>2] = $1190;
 $1247 = Math_fround(HEAPF32[$1162>>2]);
 $1248 = (($1246) + 4|0);
 HEAPF32[$1248>>2] = $1247;
 $1249 = Math_fround(HEAPF32[$1163>>2]);
 $1250 = (($1246) + 8|0);
 HEAPF32[$1250>>2] = $1249;
 $1251 = Math_fround(HEAPF32[$1164>>2]);
 $1252 = (($1246) + 12|0);
 HEAPF32[$1252>>2] = $1251;
 $1253 = Math_fround(HEAPF32[$1165>>2]);
 $1254 = (($1246) + 16|0);
 HEAPF32[$1254>>2] = $1253;
 $1255 = Math_fround(HEAPF32[$1166>>2]);
 $1256 = (($1246) + 20|0);
 HEAPF32[$1256>>2] = $1255;
 $1257 = Math_fround(HEAPF32[$1167>>2]);
 $1258 = (($1246) + 24|0);
 HEAPF32[$1258>>2] = $1257;
 $1259 = Math_fround(HEAPF32[$1168>>2]);
 $1260 = (($1246) + 56|0);
 HEAPF32[$1260>>2] = $1259;
 $1261 = Math_fround(HEAPF32[$1169>>2]);
 $1262 = (($1246) + 60|0);
 HEAPF32[$1262>>2] = $1261;
 $1263 = Math_fround(HEAPF32[$1170>>2]);
 $1264 = (($1246) + 64|0);
 HEAPF32[$1264>>2] = $1263;
 $1265 = Math_fround(HEAPF32[$1171>>2]);
 $1266 = (($1246) + 68|0);
 HEAPF32[$1266>>2] = $1265;
 $1267 = Math_fround(HEAPF32[$1172>>2]);
 $1268 = (($1246) + 72|0);
 HEAPF32[$1268>>2] = $1267;
 $1269 = Math_fround(HEAPF32[$1173>>2]);
 $1270 = (($1246) + 76|0);
 HEAPF32[$1270>>2] = $1269;
 $1271 = Math_fround(HEAPF32[$1174>>2]);
 $1272 = (($1246) + 80|0);
 HEAPF32[$1272>>2] = $1271;
 $1273 = Math_fround(HEAPF32[$1175>>2]);
 $1274 = (($1246) + 112|0);
 HEAPF32[$1274>>2] = $1273;
 $1275 = Math_fround(HEAPF32[$1176>>2]);
 $1276 = (($1246) + 116|0);
 HEAPF32[$1276>>2] = $1275;
 $1277 = Math_fround(HEAPF32[$1177>>2]);
 $1278 = (($1246) + 120|0);
 HEAPF32[$1278>>2] = $1277;
 $1279 = Math_fround(HEAPF32[$1178>>2]);
 $1280 = (($1246) + 124|0);
 HEAPF32[$1280>>2] = $1279;
 $1281 = Math_fround(HEAPF32[$1179>>2]);
 $1282 = (($1246) + 128|0);
 HEAPF32[$1282>>2] = $1281;
 $1283 = Math_fround(HEAPF32[$1180>>2]);
 $1284 = (($1246) + 132|0);
 HEAPF32[$1284>>2] = $1283;
 $1285 = Math_fround(HEAPF32[$1181>>2]);
 $1286 = (($1246) + 136|0);
 HEAPF32[$1286>>2] = $1285;
 $1287 = Math_fround(HEAPF32[$1182>>2]);
 $1288 = (($1246) + 168|0);
 HEAPF32[$1288>>2] = $1287;
 $1289 = Math_fround(HEAPF32[$1183>>2]);
 $1290 = (($1246) + 172|0);
 HEAPF32[$1290>>2] = $1289;
 $1291 = Math_fround(HEAPF32[$1184>>2]);
 $1292 = (($1246) + 176|0);
 HEAPF32[$1292>>2] = $1291;
 $1293 = Math_fround(HEAPF32[$1185>>2]);
 $1294 = (($1246) + 180|0);
 HEAPF32[$1294>>2] = $1293;
 $1295 = Math_fround(HEAPF32[$1186>>2]);
 $1296 = (($1246) + 184|0);
 HEAPF32[$1296>>2] = $1295;
 $1297 = Math_fround(HEAPF32[$1187>>2]);
 $1298 = (($1246) + 188|0);
 HEAPF32[$1298>>2] = $1297;
 $1299 = Math_fround(HEAPF32[$1188>>2]);
 $1300 = (($1246) + 192|0);
 HEAPF32[$1300>>2] = $1299;
 $1301 = ($49>>>0)>(1);
 if ($1301) {
  $1302 = (($outputData) + 4|0);
  $1303 = (($outputData) + 8|0);
  $1304 = (($outputData) + 12|0);
  $1305 = (($outputData) + 16|0);
  $1306 = (($outputData) + 20|0);
  $1307 = (($outputData) + 24|0);
  $1308 = (($outputData) + 28|0);
  $1309 = (($outputData) + 32|0);
  $1310 = (($outputData) + 36|0);
  $1311 = (($outputData) + 40|0);
  $1312 = (($outputData) + 44|0);
  $1313 = (($outputData) + 48|0);
  $1314 = (($outputData) + 52|0);
  $1315 = (($outputData) + 56|0);
  $1316 = (($outputData) + 60|0);
  $1317 = (($outputData) + 64|0);
  $1318 = (($outputData) + 68|0);
  $1319 = (($outputData) + 72|0);
  $1320 = (($outputData) + 76|0);
  $1321 = (($outputData) + 80|0);
  $1322 = (($outputData) + 84|0);
  $1323 = (($outputData) + 88|0);
  $1324 = (($outputData) + 92|0);
  $1325 = (($outputData) + 96|0);
  $1326 = (($outputData) + 100|0);
  $1327 = (($outputData) + 104|0);
  $1328 = (($outputData) + 108|0);
  $i14$0114 = 1;
  while(1) {
   HEAPF32[$outputData>>2] = Math_fround(0.0);
   HEAPF32[$1302>>2] = Math_fround(0.0);
   HEAPF32[$1303>>2] = Math_fround(0.0);
   HEAPF32[$1304>>2] = Math_fround(1.0);
   ;HEAP32[$1305+0>>2]=0|0;HEAP32[$1305+4>>2]=0|0;HEAP32[$1305+8>>2]=0|0;HEAP32[$1305+12>>2]=0|0;HEAP32[$1305+16>>2]=0|0;HEAP32[$1305+20>>2]=0|0;
   HEAPF32[$1311>>2] = Math_fround(1.0);
   ;HEAP32[$1312+0>>2]=0|0;HEAP32[$1312+4>>2]=0|0;HEAP32[$1312+8>>2]=0|0;HEAP32[$1312+12>>2]=0|0;HEAP32[$1312+16>>2]=0|0;HEAP32[$1312+20>>2]=0|0;
   HEAPF32[$1318>>2] = Math_fround(1.0);
   ;HEAP32[$1319+0>>2]=0|0;HEAP32[$1319+4>>2]=0|0;HEAP32[$1319+8>>2]=0|0;HEAP32[$1319+12>>2]=0|0;HEAP32[$1319+16>>2]=0|0;HEAP32[$1319+20>>2]=0|0;
   HEAPF32[$1325>>2] = Math_fround(1.0);
   HEAPF32[$1326>>2] = Math_fround(0.0);
   HEAPF32[$1327>>2] = Math_fround(0.0);
   HEAPF32[$1328>>2] = Math_fround(0.0);
   $1329 = (($43) + (($i14$0114*944)|0)|0);
   $1330 = (($45) + (($i14$0114*208)|0)|0);
   $1331 = $i14$0114 << 2;
   $1332 = (($wheelQueryResults) + (($1331*148)|0)|0);
   $1333 = (($numActiveWheelsPerBlock4) + ($i14$0114<<2)|0);
   $1334 = HEAP32[$1333>>2]|0;
   __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($1329,$1330,$1332,$1334,$carChassisCMLocalPose,$outputData);
   $1335 = Math_fround(HEAPF32[$outputData>>2]);
   $1336 = ((($wheelQueryResults) + (($1331*148)|0)|0) + 120|0);
   HEAPF32[$1336>>2] = $1335;
   $1337 = Math_fround(HEAPF32[$1302>>2]);
   $1338 = ((($wheelQueryResults) + (($1331*148)|0)|0) + 124|0);
   HEAPF32[$1338>>2] = $1337;
   $1339 = Math_fround(HEAPF32[$1303>>2]);
   $1340 = ((($wheelQueryResults) + (($1331*148)|0)|0) + 128|0);
   HEAPF32[$1340>>2] = $1339;
   $1341 = Math_fround(HEAPF32[$1304>>2]);
   $1342 = ((($wheelQueryResults) + (($1331*148)|0)|0) + 132|0);
   HEAPF32[$1342>>2] = $1341;
   $1343 = Math_fround(HEAPF32[$1305>>2]);
   $1344 = ((($wheelQueryResults) + (($1331*148)|0)|0) + 136|0);
   HEAPF32[$1344>>2] = $1343;
   $1345 = Math_fround(HEAPF32[$1306>>2]);
   $1346 = ((($wheelQueryResults) + (($1331*148)|0)|0) + 140|0);
   HEAPF32[$1346>>2] = $1345;
   $1347 = Math_fround(HEAPF32[$1307>>2]);
   $1348 = ((($wheelQueryResults) + (($1331*148)|0)|0) + 144|0);
   HEAPF32[$1348>>2] = $1347;
   $1349 = $1331 | 1;
   $1350 = Math_fround(HEAPF32[$1308>>2]);
   $1351 = ((($wheelQueryResults) + (($1349*148)|0)|0) + 120|0);
   HEAPF32[$1351>>2] = $1350;
   $1352 = Math_fround(HEAPF32[$1309>>2]);
   $1353 = ((($wheelQueryResults) + (($1349*148)|0)|0) + 124|0);
   HEAPF32[$1353>>2] = $1352;
   $1354 = Math_fround(HEAPF32[$1310>>2]);
   $1355 = ((($wheelQueryResults) + (($1349*148)|0)|0) + 128|0);
   HEAPF32[$1355>>2] = $1354;
   $1356 = Math_fround(HEAPF32[$1311>>2]);
   $1357 = ((($wheelQueryResults) + (($1349*148)|0)|0) + 132|0);
   HEAPF32[$1357>>2] = $1356;
   $1358 = Math_fround(HEAPF32[$1312>>2]);
   $1359 = ((($wheelQueryResults) + (($1349*148)|0)|0) + 136|0);
   HEAPF32[$1359>>2] = $1358;
   $1360 = Math_fround(HEAPF32[$1313>>2]);
   $1361 = ((($wheelQueryResults) + (($1349*148)|0)|0) + 140|0);
   HEAPF32[$1361>>2] = $1360;
   $1362 = Math_fround(HEAPF32[$1314>>2]);
   $1363 = ((($wheelQueryResults) + (($1349*148)|0)|0) + 144|0);
   HEAPF32[$1363>>2] = $1362;
   $1364 = $1331 | 2;
   $1365 = Math_fround(HEAPF32[$1315>>2]);
   $1366 = ((($wheelQueryResults) + (($1364*148)|0)|0) + 120|0);
   HEAPF32[$1366>>2] = $1365;
   $1367 = Math_fround(HEAPF32[$1316>>2]);
   $1368 = ((($wheelQueryResults) + (($1364*148)|0)|0) + 124|0);
   HEAPF32[$1368>>2] = $1367;
   $1369 = Math_fround(HEAPF32[$1317>>2]);
   $1370 = ((($wheelQueryResults) + (($1364*148)|0)|0) + 128|0);
   HEAPF32[$1370>>2] = $1369;
   $1371 = Math_fround(HEAPF32[$1318>>2]);
   $1372 = ((($wheelQueryResults) + (($1364*148)|0)|0) + 132|0);
   HEAPF32[$1372>>2] = $1371;
   $1373 = Math_fround(HEAPF32[$1319>>2]);
   $1374 = ((($wheelQueryResults) + (($1364*148)|0)|0) + 136|0);
   HEAPF32[$1374>>2] = $1373;
   $1375 = Math_fround(HEAPF32[$1320>>2]);
   $1376 = ((($wheelQueryResults) + (($1364*148)|0)|0) + 140|0);
   HEAPF32[$1376>>2] = $1375;
   $1377 = Math_fround(HEAPF32[$1321>>2]);
   $1378 = ((($wheelQueryResults) + (($1364*148)|0)|0) + 144|0);
   HEAPF32[$1378>>2] = $1377;
   $1379 = $1331 | 3;
   $1380 = Math_fround(HEAPF32[$1322>>2]);
   $1381 = ((($wheelQueryResults) + (($1379*148)|0)|0) + 120|0);
   HEAPF32[$1381>>2] = $1380;
   $1382 = Math_fround(HEAPF32[$1323>>2]);
   $1383 = ((($wheelQueryResults) + (($1379*148)|0)|0) + 124|0);
   HEAPF32[$1383>>2] = $1382;
   $1384 = Math_fround(HEAPF32[$1324>>2]);
   $1385 = ((($wheelQueryResults) + (($1379*148)|0)|0) + 128|0);
   HEAPF32[$1385>>2] = $1384;
   $1386 = Math_fround(HEAPF32[$1325>>2]);
   $1387 = ((($wheelQueryResults) + (($1379*148)|0)|0) + 132|0);
   HEAPF32[$1387>>2] = $1386;
   $1388 = Math_fround(HEAPF32[$1326>>2]);
   $1389 = ((($wheelQueryResults) + (($1379*148)|0)|0) + 136|0);
   HEAPF32[$1389>>2] = $1388;
   $1390 = Math_fround(HEAPF32[$1327>>2]);
   $1391 = ((($wheelQueryResults) + (($1379*148)|0)|0) + 140|0);
   HEAPF32[$1391>>2] = $1390;
   $1392 = Math_fround(HEAPF32[$1328>>2]);
   $1393 = ((($wheelQueryResults) + (($1379*148)|0)|0) + 144|0);
   HEAPF32[$1393>>2] = $1392;
   $1394 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
   $1395 = (($1394) + (($1331*56)|0)|0);
   HEAPF32[$1395>>2] = $1335;
   $1396 = Math_fround(HEAPF32[$1302>>2]);
   $1397 = ((($1394) + (($1331*56)|0)|0) + 4|0);
   HEAPF32[$1397>>2] = $1396;
   $1398 = Math_fround(HEAPF32[$1303>>2]);
   $1399 = ((($1394) + (($1331*56)|0)|0) + 8|0);
   HEAPF32[$1399>>2] = $1398;
   $1400 = Math_fround(HEAPF32[$1304>>2]);
   $1401 = ((($1394) + (($1331*56)|0)|0) + 12|0);
   HEAPF32[$1401>>2] = $1400;
   $1402 = Math_fround(HEAPF32[$1305>>2]);
   $1403 = ((($1394) + (($1331*56)|0)|0) + 16|0);
   HEAPF32[$1403>>2] = $1402;
   $1404 = Math_fround(HEAPF32[$1306>>2]);
   $1405 = ((($1394) + (($1331*56)|0)|0) + 20|0);
   HEAPF32[$1405>>2] = $1404;
   $1406 = Math_fround(HEAPF32[$1307>>2]);
   $1407 = ((($1394) + (($1331*56)|0)|0) + 24|0);
   HEAPF32[$1407>>2] = $1406;
   $1408 = Math_fround(HEAPF32[$1308>>2]);
   $1409 = (($1394) + (($1349*56)|0)|0);
   HEAPF32[$1409>>2] = $1408;
   $1410 = Math_fround(HEAPF32[$1309>>2]);
   $1411 = ((($1394) + (($1349*56)|0)|0) + 4|0);
   HEAPF32[$1411>>2] = $1410;
   $1412 = Math_fround(HEAPF32[$1310>>2]);
   $1413 = ((($1394) + (($1349*56)|0)|0) + 8|0);
   HEAPF32[$1413>>2] = $1412;
   $1414 = Math_fround(HEAPF32[$1311>>2]);
   $1415 = ((($1394) + (($1349*56)|0)|0) + 12|0);
   HEAPF32[$1415>>2] = $1414;
   $1416 = Math_fround(HEAPF32[$1312>>2]);
   $1417 = ((($1394) + (($1349*56)|0)|0) + 16|0);
   HEAPF32[$1417>>2] = $1416;
   $1418 = Math_fround(HEAPF32[$1313>>2]);
   $1419 = ((($1394) + (($1349*56)|0)|0) + 20|0);
   HEAPF32[$1419>>2] = $1418;
   $1420 = Math_fround(HEAPF32[$1314>>2]);
   $1421 = ((($1394) + (($1349*56)|0)|0) + 24|0);
   HEAPF32[$1421>>2] = $1420;
   $1422 = Math_fround(HEAPF32[$1315>>2]);
   $1423 = (($1394) + (($1364*56)|0)|0);
   HEAPF32[$1423>>2] = $1422;
   $1424 = Math_fround(HEAPF32[$1316>>2]);
   $1425 = ((($1394) + (($1364*56)|0)|0) + 4|0);
   HEAPF32[$1425>>2] = $1424;
   $1426 = Math_fround(HEAPF32[$1317>>2]);
   $1427 = ((($1394) + (($1364*56)|0)|0) + 8|0);
   HEAPF32[$1427>>2] = $1426;
   $1428 = Math_fround(HEAPF32[$1318>>2]);
   $1429 = ((($1394) + (($1364*56)|0)|0) + 12|0);
   HEAPF32[$1429>>2] = $1428;
   $1430 = Math_fround(HEAPF32[$1319>>2]);
   $1431 = ((($1394) + (($1364*56)|0)|0) + 16|0);
   HEAPF32[$1431>>2] = $1430;
   $1432 = Math_fround(HEAPF32[$1320>>2]);
   $1433 = ((($1394) + (($1364*56)|0)|0) + 20|0);
   HEAPF32[$1433>>2] = $1432;
   $1434 = Math_fround(HEAPF32[$1321>>2]);
   $1435 = ((($1394) + (($1364*56)|0)|0) + 24|0);
   HEAPF32[$1435>>2] = $1434;
   $1436 = Math_fround(HEAPF32[$1322>>2]);
   $1437 = (($1394) + (($1379*56)|0)|0);
   HEAPF32[$1437>>2] = $1436;
   $1438 = Math_fround(HEAPF32[$1323>>2]);
   $1439 = ((($1394) + (($1379*56)|0)|0) + 4|0);
   HEAPF32[$1439>>2] = $1438;
   $1440 = Math_fround(HEAPF32[$1324>>2]);
   $1441 = ((($1394) + (($1379*56)|0)|0) + 8|0);
   HEAPF32[$1441>>2] = $1440;
   $1442 = Math_fround(HEAPF32[$1325>>2]);
   $1443 = ((($1394) + (($1379*56)|0)|0) + 12|0);
   HEAPF32[$1443>>2] = $1442;
   $1444 = Math_fround(HEAPF32[$1326>>2]);
   $1445 = ((($1394) + (($1379*56)|0)|0) + 16|0);
   HEAPF32[$1445>>2] = $1444;
   $1446 = Math_fround(HEAPF32[$1327>>2]);
   $1447 = ((($1394) + (($1379*56)|0)|0) + 20|0);
   HEAPF32[$1447>>2] = $1446;
   $1448 = Math_fround(HEAPF32[$1328>>2]);
   $1449 = ((($1394) + (($1379*56)|0)|0) + 24|0);
   HEAPF32[$1449>>2] = $1448;
   $1450 = (($i14$0114) + 1)|0;
   $exitcond = ($1450|0)==($49|0);
   if ($exitcond) {
    break;
   } else {
    $i14$0114 = $1450;
   }
  }
 }
 $1451 = ($vehWheelQueryResults|0)==(0|0);
 if (!($1451)) {
  $1452 = HEAP32[$vehWheelQueryResults>>2]|0;
  $1453 = ($1452|0)==(0|0);
  if (!($1453)) {
   $1454 = ($47*148)|0;
   _memcpy(($1452|0),($wheelQueryResults|0),($1454|0))|0;
  }
 }
 $1455 = ($vehConcurrentUpdates|0)==(0|0);
 if ($1455) {
  HEAP32[$vehWheels>>2] = $vehDriveTank;
  __ZN5physx15PxVehicleUpdate10updatePostEPKNS_29PxVehicleConcurrentUpdateDataEjPPNS_15PxVehicleWheelsE($vehicleConcurrentUpdates,1,$vehWheels);
  STACKTOP = sp;return;
 } else {
  $1456 = HEAP32[$vehConcurrentUpdates>>2]|0;
  $1457 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
  $1458 = ($47*56)|0;
  _memcpy(($1456|0),($1457|0),($1458|0))|0;
  $1459 = Math_fround(HEAPF32[$1125>>2]);
  $1460 = (($vehConcurrentUpdates) + 8|0);
  HEAPF32[$1460>>2] = $1459;
  $1461 = (($vehicleConcurrentUpdates) + 12|0);
  $1462 = Math_fround(HEAPF32[$1461>>2]);
  $1463 = (($vehConcurrentUpdates) + 12|0);
  HEAPF32[$1463>>2] = $1462;
  $1464 = (($vehicleConcurrentUpdates) + 16|0);
  $1465 = Math_fround(HEAPF32[$1464>>2]);
  $1466 = (($vehConcurrentUpdates) + 16|0);
  HEAPF32[$1466>>2] = $1465;
  $1467 = (($vehicleConcurrentUpdates) + 20|0);
  $1468 = Math_fround(HEAPF32[$1467>>2]);
  $1469 = (($vehConcurrentUpdates) + 20|0);
  HEAPF32[$1469>>2] = $1468;
  $1470 = (($vehicleConcurrentUpdates) + 24|0);
  $1471 = Math_fround(HEAPF32[$1470>>2]);
  $1472 = (($vehConcurrentUpdates) + 24|0);
  HEAPF32[$1472>>2] = $1471;
  $1473 = (($vehicleConcurrentUpdates) + 28|0);
  $1474 = Math_fround(HEAPF32[$1473>>2]);
  $1475 = (($vehConcurrentUpdates) + 28|0);
  HEAPF32[$1475>>2] = $1474;
  $1476 = (($vehicleConcurrentUpdates) + 32|0);
  $1477 = HEAP16[$1476>>1]|0;
  $1478 = $1477&255;
  $1479 = (($vehConcurrentUpdates) + 32|0);
  HEAP8[$1479>>0] = $1478;
  $1480 = ($1477&65535) >>> 8;
  $1481 = $1480&255;
  $1482 = (($vehConcurrentUpdates) + 33|0);
  HEAP8[$1482>>0] = $1481;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15PxVehicleUpdate13updateNoDriveEfRKNS_6PxVec3EffRKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEPNS_16PxVehicleNoDriveEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$gravityMagnitude,$recipGravityMagnitude,$drivableSurfaceToTireFrictionPairs,$vehNoDrive,$vehWheelQueryResults,$vehConcurrentUpdates) {
 $timestep = Math_fround($timestep);
 $gravity = $gravity|0;
 $gravityMagnitude = Math_fround($gravityMagnitude);
 $recipGravityMagnitude = Math_fround($recipGravityMagnitude);
 $drivableSurfaceToTireFrictionPairs = $drivableSurfaceToTireFrictionPairs|0;
 $vehNoDrive = $vehNoDrive|0;
 $vehWheelQueryResults = $vehWheelQueryResults|0;
 $vehConcurrentUpdates = $vehConcurrentUpdates|0;
 var $$lcssa133 = 0, $$phi$trans$insert = 0, $$pre = Math_fround(0), $$pre$phi171Z2D = 0, $$pre$phiZ2D = 0, $$pre155 = Math_fround(0), $$pre156 = Math_fround(0), $$pre157 = Math_fround(0), $$pre158 = Math_fround(0), $$pre159 = Math_fround(0), $$pre160 = Math_fround(0), $$pre161 = Math_fround(0), $$pre162 = Math_fround(0), $$pre163 = Math_fround(0), $$pre164 = Math_fround(0), $$pre165 = 0, $$pre168 = 0, $$pre169 = 0, $$sum = 0, $$sum18 = 0;
 var $$sum19 = 0, $$sum20 = 0, $$sum27 = 0, $$sum3435 = 0, $$sum4849 = 0, $$sum6263 = 0, $$sum7677 = 0, $$sum7879 = 0, $$sum8081 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = Math_fround(0), $1001 = 0, $1002 = Math_fround(0), $1003 = 0, $1004 = 0, $1005 = Math_fround(0), $1006 = 0;
 var $1007 = Math_fround(0), $1008 = 0, $1009 = Math_fround(0), $101 = 0, $1010 = 0, $1011 = Math_fround(0), $1012 = 0, $1013 = Math_fround(0), $1014 = 0, $1015 = Math_fround(0), $1016 = 0, $1017 = Math_fround(0), $1018 = 0, $1019 = Math_fround(0), $102 = 0, $1020 = 0, $1021 = Math_fround(0), $1022 = 0, $1023 = Math_fround(0), $1024 = 0;
 var $1025 = Math_fround(0), $1026 = 0, $1027 = Math_fround(0), $1028 = 0, $1029 = Math_fround(0), $103 = 0, $1030 = 0, $1031 = Math_fround(0), $1032 = 0, $1033 = Math_fround(0), $1034 = 0, $1035 = Math_fround(0), $1036 = 0, $1037 = Math_fround(0), $1038 = 0, $1039 = Math_fround(0), $104 = 0, $1040 = 0, $1041 = Math_fround(0), $1042 = 0;
 var $1043 = Math_fround(0), $1044 = 0, $1045 = Math_fround(0), $1046 = 0, $1047 = Math_fround(0), $1048 = 0, $1049 = Math_fround(0), $105 = 0, $1050 = 0, $1051 = Math_fround(0), $1052 = 0, $1053 = 0, $1054 = Math_fround(0), $1055 = 0, $1056 = Math_fround(0), $1057 = 0, $1058 = Math_fround(0), $1059 = 0, $106 = 0, $1060 = Math_fround(0);
 var $1061 = 0, $1062 = Math_fround(0), $1063 = 0, $1064 = Math_fround(0), $1065 = 0, $1066 = Math_fround(0), $1067 = 0, $1068 = Math_fround(0), $1069 = 0, $107 = 0, $1070 = Math_fround(0), $1071 = 0, $1072 = Math_fround(0), $1073 = 0, $1074 = Math_fround(0), $1075 = 0, $1076 = Math_fround(0), $1077 = 0, $1078 = Math_fround(0), $1079 = 0;
 var $108 = 0, $1080 = Math_fround(0), $1081 = 0, $1082 = Math_fround(0), $1083 = 0, $1084 = Math_fround(0), $1085 = 0, $1086 = Math_fround(0), $1087 = 0, $1088 = Math_fround(0), $1089 = 0, $109 = 0, $1090 = Math_fround(0), $1091 = 0, $1092 = Math_fround(0), $1093 = 0, $1094 = Math_fround(0), $1095 = 0, $1096 = Math_fround(0), $1097 = 0;
 var $1098 = Math_fround(0), $1099 = 0, $11 = 0, $110 = 0, $1100 = Math_fround(0), $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = Math_fround(0), $1113 = 0, $1114 = Math_fround(0);
 var $1115 = Math_fround(0), $1116 = 0, $1117 = Math_fround(0), $1118 = 0, $1119 = Math_fround(0), $112 = 0, $1120 = Math_fround(0), $1121 = 0, $1122 = Math_fround(0), $1123 = 0, $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = 0, $1127 = Math_fround(0), $1128 = 0, $1129 = 0, $113 = 0, $1130 = Math_fround(0), $1131 = 0, $1132 = 0;
 var $1133 = Math_fround(0), $1134 = 0, $1135 = 0, $1136 = 0, $1137 = Math_fround(0), $1138 = 0, $1139 = Math_fround(0), $114 = 0, $1140 = 0, $1141 = Math_fround(0), $1142 = 0, $1143 = Math_fround(0), $1144 = 0, $1145 = Math_fround(0), $1146 = 0, $1147 = Math_fround(0), $1148 = 0, $1149 = Math_fround(0), $115 = 0, $1150 = Math_fround(0);
 var $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = Math_fround(0), $1157 = 0, $1158 = 0, $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = 0, $1162 = 0, $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0), $1169 = Math_fround(0);
 var $117 = 0, $1170 = Math_fround(0), $1171 = 0, $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = Math_fround(0), $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = 0, $1179 = Math_fround(0), $118 = 0, $1180 = 0, $1181 = Math_fround(0), $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0;
 var $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = 0, $1190 = 0, $1191 = Math_fround(0), $1192 = 0, $1193 = Math_fround(0), $1194 = 0, $1195 = Math_fround(0), $1196 = 0, $1197 = Math_fround(0), $1198 = 0, $1199 = Math_fround(0), $12 = 0, $120 = 0, $1200 = Math_fround(0), $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = Math_fround(0);
 var $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = 0, $1208 = 0, $1209 = Math_fround(0), $121 = 0, $1210 = Math_fround(0), $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = Math_fround(0), $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = Math_fround(0), $1217 = Math_fround(0), $1218 = Math_fround(0), $1219 = Math_fround(0), $122 = 0, $1220 = Math_fround(0), $1221 = 0, $1222 = 0;
 var $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0;
 var $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = Math_fround(0), $1253 = 0, $1254 = Math_fround(0), $1255 = 0, $1256 = Math_fround(0), $1257 = 0, $1258 = Math_fround(0), $1259 = 0;
 var $126 = 0, $1260 = Math_fround(0), $1261 = 0, $1262 = Math_fround(0), $1263 = 0, $1264 = Math_fround(0), $1265 = 0, $1266 = Math_fround(0), $1267 = 0, $1268 = Math_fround(0), $1269 = 0, $127 = 0, $1270 = Math_fround(0), $1271 = 0, $1272 = Math_fround(0), $1273 = 0, $1274 = Math_fround(0), $1275 = 0, $1276 = Math_fround(0), $1277 = 0;
 var $1278 = Math_fround(0), $1279 = 0, $128 = 0, $1280 = Math_fround(0), $1281 = 0, $1282 = Math_fround(0), $1283 = 0, $1284 = Math_fround(0), $1285 = 0, $1286 = Math_fround(0), $1287 = 0, $1288 = Math_fround(0), $1289 = 0, $129 = 0, $1290 = Math_fround(0), $1291 = 0, $1292 = Math_fround(0), $1293 = 0, $1294 = Math_fround(0), $1295 = 0;
 var $1296 = Math_fround(0), $1297 = 0, $1298 = Math_fround(0), $1299 = 0, $13 = 0, $130 = 0, $1300 = Math_fround(0), $1301 = 0, $1302 = Math_fround(0), $1303 = 0, $1304 = Math_fround(0), $1305 = 0, $1306 = Math_fround(0), $1307 = 0, $1308 = 0, $1309 = Math_fround(0), $131 = Math_fround(0), $1310 = 0, $1311 = Math_fround(0), $1312 = 0;
 var $1313 = Math_fround(0), $1314 = 0, $1315 = Math_fround(0), $1316 = 0, $1317 = Math_fround(0), $1318 = 0, $1319 = Math_fround(0), $132 = 0, $1320 = 0, $1321 = Math_fround(0), $1322 = 0, $1323 = Math_fround(0), $1324 = 0, $1325 = Math_fround(0), $1326 = 0, $1327 = Math_fround(0), $1328 = 0, $1329 = Math_fround(0), $133 = Math_fround(0), $1330 = 0;
 var $1331 = Math_fround(0), $1332 = 0, $1333 = Math_fround(0), $1334 = 0, $1335 = Math_fround(0), $1336 = 0, $1337 = Math_fround(0), $1338 = 0, $1339 = Math_fround(0), $134 = 0, $1340 = 0, $1341 = Math_fround(0), $1342 = 0, $1343 = Math_fround(0), $1344 = 0, $1345 = Math_fround(0), $1346 = 0, $1347 = Math_fround(0), $1348 = 0, $1349 = Math_fround(0);
 var $135 = 0, $1350 = 0, $1351 = Math_fround(0), $1352 = 0, $1353 = Math_fround(0), $1354 = 0, $1355 = Math_fround(0), $1356 = 0, $1357 = Math_fround(0), $1358 = 0, $1359 = Math_fround(0), $136 = 0, $1360 = 0, $1361 = Math_fround(0), $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0;
 var $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0;
 var $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = Math_fround(0), $1398 = 0, $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = 0, $1401 = Math_fround(0), $1402 = 0;
 var $1403 = Math_fround(0), $1404 = 0, $1405 = Math_fround(0), $1406 = 0, $1407 = Math_fround(0), $1408 = 0, $1409 = Math_fround(0), $141 = 0, $1410 = 0, $1411 = 0, $1412 = Math_fround(0), $1413 = 0, $1414 = Math_fround(0), $1415 = 0, $1416 = Math_fround(0), $1417 = 0, $1418 = Math_fround(0), $1419 = 0, $142 = 0, $1420 = Math_fround(0);
 var $1421 = 0, $1422 = Math_fround(0), $1423 = 0, $1424 = Math_fround(0), $1425 = 0, $1426 = 0, $1427 = Math_fround(0), $1428 = 0, $1429 = Math_fround(0), $143 = 0, $1430 = 0, $1431 = Math_fround(0), $1432 = 0, $1433 = Math_fround(0), $1434 = 0, $1435 = Math_fround(0), $1436 = 0, $1437 = Math_fround(0), $1438 = 0, $1439 = Math_fround(0);
 var $144 = 0, $1440 = 0, $1441 = 0, $1442 = Math_fround(0), $1443 = 0, $1444 = Math_fround(0), $1445 = 0, $1446 = Math_fround(0), $1447 = 0, $1448 = Math_fround(0), $1449 = 0, $145 = 0, $1450 = Math_fround(0), $1451 = 0, $1452 = Math_fround(0), $1453 = 0, $1454 = Math_fround(0), $1455 = 0, $1456 = 0, $1457 = 0;
 var $1458 = Math_fround(0), $1459 = 0, $146 = 0, $1460 = Math_fround(0), $1461 = 0, $1462 = Math_fround(0), $1463 = 0, $1464 = Math_fround(0), $1465 = 0, $1466 = Math_fround(0), $1467 = 0, $1468 = Math_fround(0), $1469 = 0, $147 = 0, $1470 = Math_fround(0), $1471 = 0, $1472 = Math_fround(0), $1473 = 0, $1474 = Math_fround(0), $1475 = 0;
 var $1476 = Math_fround(0), $1477 = 0, $1478 = Math_fround(0), $1479 = 0, $148 = 0, $1480 = Math_fround(0), $1481 = 0, $1482 = Math_fround(0), $1483 = 0, $1484 = Math_fround(0), $1485 = 0, $1486 = Math_fround(0), $1487 = 0, $1488 = Math_fround(0), $1489 = 0, $149 = 0, $1490 = Math_fround(0), $1491 = 0, $1492 = Math_fround(0), $1493 = 0;
 var $1494 = Math_fround(0), $1495 = 0, $1496 = Math_fround(0), $1497 = 0, $1498 = Math_fround(0), $1499 = 0, $15 = 0, $150 = 0, $1500 = Math_fround(0), $1501 = 0, $1502 = Math_fround(0), $1503 = 0, $1504 = Math_fround(0), $1505 = 0, $1506 = Math_fround(0), $1507 = 0, $1508 = Math_fround(0), $1509 = 0, $151 = 0, $1510 = Math_fround(0);
 var $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = Math_fround(0), $1522 = 0, $1523 = 0, $1524 = Math_fround(0), $1525 = 0, $1526 = 0, $1527 = Math_fround(0), $1528 = 0, $1529 = 0;
 var $153 = 0, $1530 = Math_fround(0), $1531 = 0, $1532 = 0, $1533 = Math_fround(0), $1534 = 0, $1535 = 0, $1536 = Math_fround(0), $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0;
 var $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0);
 var $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0);
 var $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = Math_fround(0);
 var $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = 0;
 var $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0);
 var $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = Math_fround(0);
 var $41 = 0, $410 = 0, $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = Math_fround(0), $419 = 0, $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = Math_fround(0);
 var $428 = 0, $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = 0, $436 = Math_fround(0), $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = 0, $440 = 0, $441 = 0, $442 = Math_fround(0), $443 = 0, $444 = 0, $445 = Math_fround(0);
 var $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = 0, $450 = 0, $451 = Math_fround(0), $452 = 0, $453 = 0, $454 = Math_fround(0), $455 = 0, $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = 0, $463 = Math_fround(0);
 var $464 = 0, $465 = 0, $466 = Math_fround(0), $467 = 0, $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0);
 var $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0;
 var $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0);
 var $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = 0;
 var $536 = 0, $537 = Math_fround(0), $538 = 0, $539 = 0, $54 = 0, $540 = Math_fround(0), $541 = 0, $542 = 0, $543 = Math_fround(0), $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0;
 var $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0;
 var $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0;
 var $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0;
 var $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0;
 var $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0;
 var $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0;
 var $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0;
 var $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0;
 var $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0;
 var $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0);
 var $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0;
 var $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = Math_fround(0), $768 = 0, $769 = Math_fround(0), $77 = 0;
 var $770 = 0, $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = 0, $776 = 0, $777 = 0, $778 = Math_fround(0), $779 = 0, $78 = 0, $780 = Math_fround(0), $781 = 0, $782 = Math_fround(0), $783 = 0, $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = 0, $788 = 0;
 var $789 = 0, $79 = 0, $790 = Math_fround(0), $791 = 0, $792 = Math_fround(0), $793 = 0, $794 = Math_fround(0), $795 = 0, $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = Math_fround(0), $803 = 0, $804 = Math_fround(0), $805 = 0;
 var $806 = Math_fround(0), $807 = 0, $808 = Math_fround(0), $809 = Math_fround(0), $81 = 0, $810 = Math_fround(0), $811 = 0, $812 = 0, $813 = Math_fround(0), $814 = 0, $815 = 0, $816 = 0, $817 = Math_fround(0), $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = Math_fround(0), $822 = 0, $823 = 0;
 var $824 = 0, $825 = Math_fround(0), $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = Math_fround(0), $834 = Math_fround(0), $835 = 0, $836 = Math_fround(0), $837 = Math_fround(0), $838 = 0, $839 = Math_fround(0), $84 = 0, $840 = 0, $841 = Math_fround(0);
 var $842 = Math_fround(0), $843 = 0, $844 = Math_fround(0), $845 = 0, $846 = Math_fround(0), $847 = Math_fround(0), $848 = 0, $849 = Math_fround(0), $85 = 0, $850 = 0, $851 = Math_fround(0), $852 = 0, $853 = Math_fround(0), $854 = Math_fround(0), $855 = 0, $856 = Math_fround(0), $857 = Math_fround(0), $858 = 0, $859 = Math_fround(0), $86 = 0;
 var $860 = 0, $861 = Math_fround(0), $862 = Math_fround(0), $863 = 0, $864 = Math_fround(0), $865 = 0, $866 = Math_fround(0), $867 = Math_fround(0), $868 = 0, $869 = Math_fround(0), $87 = 0, $870 = 0, $871 = Math_fround(0), $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0;
 var $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = Math_fround(0), $883 = Math_fround(0), $884 = 0, $885 = Math_fround(0), $886 = 0, $887 = Math_fround(0), $888 = 0, $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = 0, $892 = 0, $893 = 0, $894 = Math_fround(0), $895 = 0, $896 = Math_fround(0);
 var $897 = 0, $898 = Math_fround(0), $899 = 0, $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = 0, $902 = Math_fround(0), $903 = 0, $904 = Math_fround(0), $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = Math_fround(0), $91 = 0, $910 = 0, $911 = Math_fround(0), $912 = 0, $913 = Math_fround(0);
 var $914 = 0, $915 = Math_fround(0), $916 = 0, $917 = Math_fround(0), $918 = 0, $919 = Math_fround(0), $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = Math_fround(0), $925 = 0, $926 = Math_fround(0), $927 = 0, $928 = Math_fround(0), $929 = 0, $93 = 0, $930 = Math_fround(0), $931 = 0;
 var $932 = Math_fround(0), $933 = 0, $934 = Math_fround(0), $935 = 0, $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = 0, $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = 0;
 var $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = 0, $955 = 0, $956 = Math_fround(0), $957 = 0, $958 = Math_fround(0), $959 = 0, $96 = 0, $960 = Math_fround(0), $961 = 0, $962 = Math_fround(0), $963 = 0, $964 = Math_fround(0), $965 = 0, $966 = Math_fround(0), $967 = 0, $968 = Math_fround(0);
 var $969 = 0, $97 = 0, $970 = Math_fround(0), $971 = 0, $972 = Math_fround(0), $973 = 0, $974 = Math_fround(0), $975 = 0, $976 = Math_fround(0), $977 = 0, $978 = Math_fround(0), $979 = 0, $98 = 0, $980 = Math_fround(0), $981 = 0, $982 = Math_fround(0), $983 = 0, $984 = Math_fround(0), $985 = 0, $986 = Math_fround(0);
 var $987 = 0, $988 = Math_fround(0), $989 = 0, $99 = 0, $990 = Math_fround(0), $991 = 0, $992 = Math_fround(0), $993 = 0, $994 = Math_fround(0), $995 = 0, $996 = Math_fround(0), $997 = 0, $998 = Math_fround(0), $999 = 0, $activeWheelStates = 0, $brakeTorques = 0, $carChassisAngVel = 0, $carChassisCMLocalPose = 0, $carChassisLinVel = 0, $carChassisTransform = 0;
 var $chassisForce = 0, $chassisTorque = 0, $constData = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i3 = 0, $exitcond146 = 0, $exitcond147 = 0, $exitcond148 = 0, $exitcond151 = 0, $exitcond152 = 0, $exitcond153 = 0, $exitcond154 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i5 = Math_fround(0), $finiteInputApplied$0$off0 = 0, $i$01$i = 0, $i$01$i$i = 0;
 var $i$0134 = 0, $i$04$i = 0, $i1$0125 = 0, $i2$0120 = 0, $i3$0116 = 0, $i4$0113 = 0, $i5$0106 = 0, $i6$0102 = 0, $i7$083 = 0, $i8$082 = 0, $inputData = 0, $inverseInertia = 0, $isAccelApplied = 0, $isBrakeApplied = 0, $j$02$i = 0, $j$02$i2 = 0, $k$098 = 0, $maxAccel$0108 = Math_fround(0), $maxBrake$0107 = Math_fround(0), $numActiveWheelsPerBlock4 = 0;
 var $outputData = 0, $phitmp = 0, $tires4ForceCalculators = 0, $vehWheels = 0, $vehicleConcurrentUpdates = 0, $wheelConcurrentUpdates = 0, $wheelDampingRates = 0, $wheelOmega$0$i = Math_fround(0), $wheelQueryResults = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5776|0;
 $wheelConcurrentUpdates = sp + 4648|0;
 $vehicleConcurrentUpdates = sp + 4608|0;
 $numActiveWheelsPerBlock4 = sp + 4588|0;
 $tires4ForceCalculators = sp + 4488|0;
 $wheelQueryResults = sp + 1528|0;
 $carChassisCMLocalPose = sp + 1500|0;
 $carChassisTransform = sp + 1472|0;
 $inverseInertia = sp + 1460|0;
 $carChassisLinVel = sp + 1448|0;
 $carChassisAngVel = sp + 1436|0;
 $0 = sp + 1408|0;
 $1 = sp + 1380|0;
 $2 = sp + 1368|0;
 $3 = sp + 1356|0;
 $4 = sp + 72|0;
 $constData = sp;
 $chassisForce = sp + 44|0;
 $chassisTorque = sp + 56|0;
 $activeWheelStates = sp + 68|0;
 $brakeTorques = sp + 88|0;
 $isBrakeApplied = sp + 104|0;
 $isAccelApplied = sp + 108|0;
 $inputData = sp + 112|0;
 $outputData = sp + 224|0;
 $wheelDampingRates = sp + 1336|0;
 $vehWheels = sp + 1352|0;
 $5 = (($vehNoDrive) + 8|0);
 $6 = (($vehNoDrive) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$phi$trans$insert = (($vehNoDrive) + 72|0);
  $$pre168 = HEAP32[$$phi$trans$insert>>2]|0;
  $$lcssa133 = 0;$$pre$phi171Z2D = $$phi$trans$insert;$$pre$phiZ2D = $$phi$trans$insert;$204 = $$pre168;
 } else {
  $9 = (($vehNoDrive) + 72|0);
  $10 = HEAP32[$9>>2]|0;
  $i$0134 = 0;
  while(1) {
   $11 = $i$0134 << 2;
   $12 = (523960 + ($11<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    $15 = (($10) + (($i$0134*208)|0)|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = (($13) + 16|0);
    HEAPF32[$17>>2] = $16;
    $18 = ((($10) + (($i$0134*208)|0)|0) + 4|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = $11 | 1;
    $21 = (523960 + ($20<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + 16|0);
    HEAPF32[$23>>2] = $19;
    $24 = ((($10) + (($i$0134*208)|0)|0) + 8|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = $11 | 2;
    $27 = (523960 + ($26<<2)|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 16|0);
    HEAPF32[$29>>2] = $25;
    $30 = ((($10) + (($i$0134*208)|0)|0) + 12|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = $11 | 3;
    $33 = (523960 + ($32<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 16|0);
    HEAPF32[$35>>2] = $31;
   }
   $36 = (($i$0134) + 1)|0;
   $37 = ($36>>>0)<($7>>>0);
   if ($37) {
    $i$0134 = $36;
   } else {
    break;
   }
  }
  $$pre169 = (($vehNoDrive) + 72|0);
  $$lcssa133 = $7;$$pre$phi171Z2D = $$pre169;$$pre$phiZ2D = $$pre169;$204 = $10;
 }
 $38 = (($vehNoDrive) + 40|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($vehNoDrive) + 48|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $$lcssa133 << 2;
 $43 = (4 - ($42))|0;
 $44 = (($vehNoDrive) + 104|0);
 $45 = HEAP32[$44>>2]|0;
 HEAPF32[$wheelConcurrentUpdates>>2] = Math_fround(0.0);
 $46 = (($wheelConcurrentUpdates) + 4|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($wheelConcurrentUpdates) + 8|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($wheelConcurrentUpdates) + 12|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($wheelConcurrentUpdates) + 16|0);
 $50 = (($wheelConcurrentUpdates) + 60|0);
 dest=$49+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($wheelConcurrentUpdates) + 64|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($wheelConcurrentUpdates) + 68|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($wheelConcurrentUpdates) + 72|0);
 $54 = (($wheelConcurrentUpdates) + 116|0);
 dest=$53+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($wheelConcurrentUpdates) + 120|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($wheelConcurrentUpdates) + 124|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($wheelConcurrentUpdates) + 128|0);
 $58 = (($wheelConcurrentUpdates) + 172|0);
 dest=$57+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($wheelConcurrentUpdates) + 176|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($wheelConcurrentUpdates) + 180|0);
 HEAPF32[$60>>2] = Math_fround(1.0);
 $61 = (($wheelConcurrentUpdates) + 184|0);
 $62 = (($wheelConcurrentUpdates) + 228|0);
 dest=$61+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($wheelConcurrentUpdates) + 232|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($wheelConcurrentUpdates) + 236|0);
 HEAPF32[$64>>2] = Math_fround(1.0);
 $65 = (($wheelConcurrentUpdates) + 240|0);
 $66 = (($wheelConcurrentUpdates) + 284|0);
 dest=$65+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($wheelConcurrentUpdates) + 288|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($wheelConcurrentUpdates) + 292|0);
 HEAPF32[$68>>2] = Math_fround(1.0);
 $69 = (($wheelConcurrentUpdates) + 296|0);
 $70 = (($wheelConcurrentUpdates) + 340|0);
 dest=$69+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($wheelConcurrentUpdates) + 344|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($wheelConcurrentUpdates) + 348|0);
 HEAPF32[$72>>2] = Math_fround(1.0);
 $73 = (($wheelConcurrentUpdates) + 352|0);
 $74 = (($wheelConcurrentUpdates) + 396|0);
 dest=$73+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($wheelConcurrentUpdates) + 400|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($wheelConcurrentUpdates) + 404|0);
 HEAPF32[$76>>2] = Math_fround(1.0);
 $77 = (($wheelConcurrentUpdates) + 408|0);
 $78 = (($wheelConcurrentUpdates) + 452|0);
 dest=$77+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = (($wheelConcurrentUpdates) + 456|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($wheelConcurrentUpdates) + 460|0);
 HEAPF32[$80>>2] = Math_fround(1.0);
 $81 = (($wheelConcurrentUpdates) + 464|0);
 $82 = (($wheelConcurrentUpdates) + 508|0);
 dest=$81+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = (($wheelConcurrentUpdates) + 512|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($wheelConcurrentUpdates) + 516|0);
 HEAPF32[$84>>2] = Math_fround(1.0);
 $85 = (($wheelConcurrentUpdates) + 520|0);
 $86 = (($wheelConcurrentUpdates) + 564|0);
 dest=$85+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = (($wheelConcurrentUpdates) + 568|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($wheelConcurrentUpdates) + 572|0);
 HEAPF32[$88>>2] = Math_fround(1.0);
 $89 = (($wheelConcurrentUpdates) + 576|0);
 $90 = (($wheelConcurrentUpdates) + 620|0);
 dest=$89+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$90>>2] = Math_fround(0.0);
 $91 = (($wheelConcurrentUpdates) + 624|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($wheelConcurrentUpdates) + 628|0);
 HEAPF32[$92>>2] = Math_fround(1.0);
 $93 = (($wheelConcurrentUpdates) + 632|0);
 $94 = (($wheelConcurrentUpdates) + 676|0);
 dest=$93+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$94>>2] = Math_fround(0.0);
 $95 = (($wheelConcurrentUpdates) + 680|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($wheelConcurrentUpdates) + 684|0);
 HEAPF32[$96>>2] = Math_fround(1.0);
 $97 = (($wheelConcurrentUpdates) + 688|0);
 $98 = (($wheelConcurrentUpdates) + 732|0);
 dest=$97+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$98>>2] = Math_fround(0.0);
 $99 = (($wheelConcurrentUpdates) + 736|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = (($wheelConcurrentUpdates) + 740|0);
 HEAPF32[$100>>2] = Math_fround(1.0);
 $101 = (($wheelConcurrentUpdates) + 744|0);
 $102 = (($wheelConcurrentUpdates) + 788|0);
 dest=$101+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$102>>2] = Math_fround(0.0);
 $103 = (($wheelConcurrentUpdates) + 792|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($wheelConcurrentUpdates) + 796|0);
 HEAPF32[$104>>2] = Math_fround(1.0);
 $105 = (($wheelConcurrentUpdates) + 800|0);
 $106 = (($wheelConcurrentUpdates) + 844|0);
 dest=$105+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$106>>2] = Math_fround(0.0);
 $107 = (($wheelConcurrentUpdates) + 848|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($wheelConcurrentUpdates) + 852|0);
 HEAPF32[$108>>2] = Math_fround(1.0);
 $109 = (($wheelConcurrentUpdates) + 856|0);
 $110 = (($wheelConcurrentUpdates) + 900|0);
 dest=$109+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$110>>2] = Math_fround(0.0);
 $111 = (($wheelConcurrentUpdates) + 904|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = (($wheelConcurrentUpdates) + 908|0);
 HEAPF32[$112>>2] = Math_fround(1.0);
 $113 = (($wheelConcurrentUpdates) + 912|0);
 $114 = (($wheelConcurrentUpdates) + 956|0);
 dest=$113+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$114>>2] = Math_fround(0.0);
 $115 = (($wheelConcurrentUpdates) + 960|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = (($wheelConcurrentUpdates) + 964|0);
 HEAPF32[$116>>2] = Math_fround(1.0);
 $117 = (($wheelConcurrentUpdates) + 968|0);
 $118 = (($wheelConcurrentUpdates) + 1012|0);
 dest=$117+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$118>>2] = Math_fround(0.0);
 $119 = (($wheelConcurrentUpdates) + 1016|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($wheelConcurrentUpdates) + 1020|0);
 HEAPF32[$120>>2] = Math_fround(1.0);
 $121 = (($wheelConcurrentUpdates) + 1024|0);
 $122 = (($wheelConcurrentUpdates) + 1068|0);
 dest=$121+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$122>>2] = Math_fround(0.0);
 $123 = (($wheelConcurrentUpdates) + 1072|0);
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = (($wheelConcurrentUpdates) + 1076|0);
 HEAPF32[$124>>2] = Math_fround(1.0);
 $125 = (($wheelConcurrentUpdates) + 1080|0);
 dest=$125+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $126 = (($43) + ($41))|0;
 ;HEAP32[$vehicleConcurrentUpdates+0>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+4>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+8>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+12>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+16>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+20>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+24>>2]=0|0;HEAP32[$vehicleConcurrentUpdates+28>>2]=0|0;HEAP16[$vehicleConcurrentUpdates+32>>1]=0|0;
 $127 = (($vehicleConcurrentUpdates) + 4|0);
 HEAP32[$127>>2] = $41;
 HEAP32[$vehicleConcurrentUpdates>>2] = $wheelConcurrentUpdates;
 $128 = ($41|0)==(0);
 L11: do {
  if ($128) {
   $finiteInputApplied$0$off0 = 0;
  } else {
   $i1$0125 = 0;
   while(1) {
    $131 = (Math_fround(__ZNK5physx16PxVehicleNoDrive14getDriveTorqueEj($vehNoDrive,$i1$0125)));
    $132 = $131 != Math_fround(0.0);
    if ($132) {
     $finiteInputApplied$0$off0 = 1;
     break L11;
    }
    $133 = (Math_fround(__ZNK5physx16PxVehicleNoDrive13getSteerAngleEj($vehNoDrive,$i1$0125)));
    $134 = $133 != Math_fround(0.0);
    $130 = (($i1$0125) + 1)|0;
    if ($134) {
     $finiteInputApplied$0$off0 = 1;
     break L11;
    }
    $129 = ($130>>>0)<($41>>>0);
    if ($129) {
     $i1$0125 = $130;
    } else {
     $finiteInputApplied$0$off0 = 0;
     break;
    }
   }
  }
 } while(0);
 $135 = HEAP32[$45>>2]|0;
 $136 = (($135) + 256|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (FUNCTION_TABLE_ii[$137 & 4095]($45)|0);
 L17: do {
  if ($138) {
   if ($finiteInputApplied$0$off0) {
    $139 = (($vehicleConcurrentUpdates) + 33|0);
    HEAP8[$139>>0] = 1;
    break;
   }
   $140 = HEAP32[$6>>2]|0;
   $141 = HEAP32[$$pre$phi171Z2D>>2]|0;
   $142 = ($140|0)==(0);
   L22: do {
    if (!($142)) {
     $i$04$i = 0;
     L23: while(1) {
      $143 = $i$04$i << 2;
      $144 = ((($141) + (($i$04$i*208)|0)|0) + 196|0);
      $j$02$i = 0;
      while(1) {
       $145 = (($j$02$i) + ($143))|0;
       $146 = (__ZNK5physx22PxVehicleWheelsSimData18getIsWheelDisabledEj($5,$145)|0);
       if (!($146)) {
        $147 = HEAP32[$144>>2]|0;
        $148 = ((($147) + (($j$02$i*80)|0)|0) + 77|0);
        $149 = HEAP8[$148>>0]|0;
        $150 = ($149<<24>>24)==(0);
        if (!($150)) {
         $151 = (($147) + (($j$02$i*80)|0)|0);
         $152 = HEAP32[$151>>2]|0;
         $153 = ($152|0)==(0|0);
         if (!($153)) {
          $154 = (($152) + 4|0);
          $155 = HEAP16[$154>>1]|0;
          $156 = ($155<<16>>16)==(5);
          if ($156) {
           break L23;
          }
         }
        }
       }
       $157 = (($j$02$i) + 1)|0;
       $158 = ($157>>>0)<(4);
       if ($158) {
        $j$02$i = $157;
       } else {
        break;
       }
      }
      $159 = (($i$04$i) + 1)|0;
      $160 = ($159>>>0)<($140>>>0);
      if ($160) {
       $i$04$i = $159;
      } else {
       break L22;
      }
     }
     $161 = (($vehicleConcurrentUpdates) + 33|0);
     HEAP8[$161>>0] = 1;
     break L17;
    }
   } while(0);
   $162 = (($vehNoDrive) + 88|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ($163|0)==(0);
   if (!($164)) {
    $i$01$i$i = 0;
    while(1) {
     __ZN5physx22PxVehicleWheelsDynData21setWheelRotationSpeedEjf($$pre$phiZ2D,$i$01$i$i,Math_fround(0.0));
     $165 = (($i$01$i$i) + 1)|0;
     $166 = HEAP32[$162>>2]|0;
     $167 = ($165>>>0)<($166>>>0);
     if ($167) {
      $i$01$i$i = $165;
     } else {
      break;
     }
    }
   }
   $168 = ($vehConcurrentUpdates|0)==(0|0);
   if ($168) {
    STACKTOP = sp;return;
   }
   $169 = (($vehConcurrentUpdates) + 32|0);
   HEAP8[$169>>0] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 ;HEAP32[$numActiveWheelsPerBlock4+0>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+4>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+8>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+12>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+16>>2]=0|0;
 $170 = ($41>>>0)<(4);
 $171 = $170 ? $41 : 4;
 HEAP32[$numActiveWheelsPerBlock4>>2] = $171;
 $172 = (($$lcssa133) + -1)|0;
 $173 = ($172>>>0)>(1);
 if ($173) {
  $i2$0120 = 1;
  while(1) {
   $174 = (($numActiveWheelsPerBlock4) + ($i2$0120<<2)|0);
   HEAP32[$174>>2] = 4;
   $175 = (($i2$0120) + 1)|0;
   $exitcond154 = ($175|0)==($172|0);
   if ($exitcond154) {
    break;
   } else {
    $i2$0120 = $175;
   }
  }
 }
 $176 = (($numActiveWheelsPerBlock4) + ($172<<2)|0);
 HEAP32[$176>>2] = $126;
 $177 = ($$lcssa133|0)==(0);
 if (!($177)) {
  $178 = (($vehNoDrive) + 76|0);
  $$pre165 = HEAP32[$178>>2]|0;
  $i3$0116 = 0;
  while(1) {
   $179 = $i3$0116 << 2;
   $180 = HEAP32[$$pre165>>2]|0;
   $181 = (($180) + ($179<<2)|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = (($tires4ForceCalculators) + (($i3$0116*20)|0)|0);
   HEAP32[$183>>2] = $182;
   $184 = $179 | 1;
   $185 = HEAP32[$$pre165>>2]|0;
   $186 = (($185) + ($184<<2)|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ((($tires4ForceCalculators) + (($i3$0116*20)|0)|0) + 4|0);
   HEAP32[$188>>2] = $187;
   $189 = $179 | 2;
   $190 = HEAP32[$$pre165>>2]|0;
   $191 = (($190) + ($189<<2)|0);
   $192 = HEAP32[$191>>2]|0;
   $193 = ((($tires4ForceCalculators) + (($i3$0116*20)|0)|0) + 8|0);
   HEAP32[$193>>2] = $192;
   $194 = $179 | 3;
   $195 = HEAP32[$$pre165>>2]|0;
   $196 = (($195) + ($194<<2)|0);
   $197 = HEAP32[$196>>2]|0;
   $198 = ((($tires4ForceCalculators) + (($i3$0116*20)|0)|0) + 12|0);
   HEAP32[$198>>2] = $197;
   $199 = (($$pre165) + 4|0);
   $200 = HEAP32[$199>>2]|0;
   $201 = ((($tires4ForceCalculators) + (($i3$0116*20)|0)|0) + 16|0);
   HEAP32[$201>>2] = $200;
   $202 = (($i3$0116) + 1)|0;
   $exitcond153 = ($202|0)==($$lcssa133|0);
   if ($exitcond153) {
    break;
   } else {
    $i3$0116 = $202;
   }
  }
  if (!($177)) {
   $i4$0113 = 0;
   while(1) {
    $203 = ((($204) + (($i4$0113*208)|0)|0) + 192|0);
    $205 = HEAP32[$203>>2]|0;
    $206 = (($205) + 352|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = HEAP32[$207>>2]|0;
    $209 = (($208) + 36|0);
    $210 = HEAP32[$209>>2]|0;
    FUNCTION_TABLE_vi[$210 & 4095]($207);
    $211 = (($i4$0113) + 1)|0;
    $exitcond152 = ($211|0)==($$lcssa133|0);
    if ($exitcond152) {
     break;
    } else {
     $i4$0113 = $211;
    }
   }
  }
 }
 $212 = (($wheelQueryResults) + 2960|0);
 $213 = $wheelQueryResults;
 while(1) {
  _memset(($213|0),0,136)|0;
  $214 = (($213) + 28|0);
  HEAP8[$214>>0] = 1;
  $215 = (($213) + 44|0);
  HEAP32[$215>>2] = -1;
  $216 = (($213) + 120|0);
  HEAPF32[$216>>2] = Math_fround(0.0);
  $217 = (($213) + 124|0);
  HEAPF32[$217>>2] = Math_fround(0.0);
  $218 = (($213) + 128|0);
  HEAPF32[$218>>2] = Math_fround(0.0);
  $219 = (($213) + 132|0);
  HEAPF32[$219>>2] = Math_fround(1.0);
  $220 = (($213) + 136|0);
  HEAPF32[$220>>2] = Math_fround(0.0);
  $221 = (($213) + 140|0);
  HEAPF32[$221>>2] = Math_fround(0.0);
  $222 = (($213) + 144|0);
  HEAPF32[$222>>2] = Math_fround(0.0);
  $223 = (($213) + 148|0);
  $224 = ($223|0)==($212|0);
  if ($224) {
   break;
  } else {
   $213 = $223;
  }
 }
 $225 = HEAP32[$45>>2]|0;
 $226 = (($225) + 124|0);
 $227 = HEAP32[$226>>2]|0;
 FUNCTION_TABLE_vii[$227 & 4095]($0,$45);
 $228 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$carChassisCMLocalPose>>2] = $228;
 $229 = (($0) + 4|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = (($carChassisCMLocalPose) + 4|0);
 HEAPF32[$231>>2] = $230;
 $232 = (($0) + 8|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = (($carChassisCMLocalPose) + 8|0);
 HEAPF32[$234>>2] = $233;
 $235 = (($0) + 12|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = (($carChassisCMLocalPose) + 12|0);
 HEAPF32[$237>>2] = $236;
 $238 = (($0) + 16|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($carChassisCMLocalPose) + 16|0);
 HEAPF32[$240>>2] = $239;
 $241 = (($0) + 20|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 $243 = (($carChassisCMLocalPose) + 20|0);
 HEAPF32[$243>>2] = $242;
 $244 = (($0) + 24|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = (($carChassisCMLocalPose) + 24|0);
 HEAPF32[$246>>2] = $245;
 $247 = HEAP32[$45>>2]|0;
 $248 = (($247) + 84|0);
 $249 = HEAP32[$248>>2]|0;
 FUNCTION_TABLE_vii[$249 & 4095]($1,$45);
 $250 = Math_fround($239 * Math_fround(2.0));
 $251 = Math_fround($242 * Math_fround(2.0));
 $252 = Math_fround($245 * Math_fround(2.0));
 $253 = (($1) + 12|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = Math_fround($254 * $254);
 $256 = Math_fround($255 + Math_fround(-0.5));
 $257 = Math_fround(HEAPF32[$1>>2]);
 $258 = Math_fround($250 * $257);
 $259 = (($1) + 4|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = Math_fround($251 * $260);
 $262 = Math_fround($258 + $261);
 $263 = (($1) + 8|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = Math_fround($252 * $264);
 $266 = Math_fround($262 + $265);
 $267 = Math_fround($250 * $256);
 $268 = Math_fround($252 * $260);
 $269 = Math_fround($251 * $264);
 $270 = Math_fround($268 - $269);
 $271 = Math_fround($254 * $270);
 $272 = Math_fround($267 + $271);
 $273 = Math_fround($257 * $266);
 $274 = Math_fround($273 + $272);
 $275 = Math_fround($251 * $256);
 $276 = Math_fround($250 * $264);
 $277 = Math_fround($252 * $257);
 $278 = Math_fround($276 - $277);
 $279 = Math_fround($254 * $278);
 $280 = Math_fround($275 + $279);
 $281 = Math_fround($260 * $266);
 $282 = Math_fround($281 + $280);
 $283 = Math_fround($252 * $256);
 $284 = Math_fround($251 * $257);
 $285 = Math_fround($250 * $260);
 $286 = Math_fround($284 - $285);
 $287 = Math_fround($254 * $286);
 $288 = Math_fround($283 + $287);
 $289 = Math_fround($264 * $266);
 $290 = Math_fround($288 + $289);
 $291 = (($1) + 16|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = Math_fround($292 + $274);
 $294 = (($1) + 20|0);
 $295 = Math_fround(HEAPF32[$294>>2]);
 $296 = Math_fround($295 + $282);
 $297 = (($1) + 24|0);
 $298 = Math_fround(HEAPF32[$297>>2]);
 $299 = Math_fround($298 + $290);
 $300 = Math_fround($254 * $228);
 $301 = Math_fround($257 * $236);
 $302 = Math_fround($300 + $301);
 $303 = Math_fround($260 * $233);
 $304 = Math_fround($302 + $303);
 $305 = Math_fround($264 * $230);
 $306 = Math_fround($304 - $305);
 $307 = Math_fround($254 * $230);
 $308 = Math_fround($260 * $236);
 $309 = Math_fround($308 + $307);
 $310 = Math_fround($264 * $228);
 $311 = Math_fround($310 + $309);
 $312 = Math_fround($257 * $233);
 $313 = Math_fround($311 - $312);
 $314 = Math_fround($254 * $233);
 $315 = Math_fround($264 * $236);
 $316 = Math_fround($315 + $314);
 $317 = Math_fround($257 * $230);
 $318 = Math_fround($317 + $316);
 $319 = Math_fround($260 * $228);
 $320 = Math_fround($318 - $319);
 $321 = Math_fround($254 * $236);
 $322 = Math_fround($257 * $228);
 $323 = Math_fround($321 - $322);
 $324 = Math_fround($260 * $230);
 $325 = Math_fround($323 - $324);
 $326 = Math_fround($264 * $233);
 $327 = Math_fround($325 - $326);
 HEAPF32[$carChassisTransform>>2] = $306;
 $328 = (($carChassisTransform) + 4|0);
 HEAPF32[$328>>2] = $313;
 $329 = (($carChassisTransform) + 8|0);
 HEAPF32[$329>>2] = $320;
 $330 = (($carChassisTransform) + 12|0);
 HEAPF32[$330>>2] = $327;
 $331 = (($carChassisTransform) + 16|0);
 HEAPF32[$331>>2] = $293;
 $332 = (($carChassisTransform) + 20|0);
 HEAPF32[$332>>2] = $296;
 $333 = (($carChassisTransform) + 24|0);
 HEAPF32[$333>>2] = $299;
 $334 = HEAP32[$45>>2]|0;
 $335 = (($334) + 132|0);
 $336 = HEAP32[$335>>2]|0;
 $337 = (Math_fround(FUNCTION_TABLE_fi[$336 & 255]($45)));
 $338 = Math_fround(Math_fround(1.0) / $337);
 $339 = HEAP32[$45>>2]|0;
 $340 = (($339) + 148|0);
 $341 = HEAP32[$340>>2]|0;
 FUNCTION_TABLE_vii[$341 & 4095]($2,$45);
 $342 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$inverseInertia>>2] = $342;
 $343 = (($2) + 4|0);
 $344 = Math_fround(HEAPF32[$343>>2]);
 $345 = (($inverseInertia) + 4|0);
 HEAPF32[$345>>2] = $344;
 $346 = (($2) + 8|0);
 $347 = Math_fround(HEAPF32[$346>>2]);
 $348 = (($inverseInertia) + 8|0);
 HEAPF32[$348>>2] = $347;
 $349 = HEAP32[$45>>2]|0;
 $350 = (($349) + 152|0);
 $351 = HEAP32[$350>>2]|0;
 FUNCTION_TABLE_vii[$351 & 4095]($3,$45);
 $352 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$carChassisLinVel>>2] = $352;
 $353 = (($3) + 4|0);
 $354 = Math_fround(HEAPF32[$353>>2]);
 $355 = (($carChassisLinVel) + 4|0);
 HEAPF32[$355>>2] = $354;
 $356 = (($3) + 8|0);
 $357 = Math_fround(HEAPF32[$356>>2]);
 $358 = (($carChassisLinVel) + 8|0);
 HEAPF32[$358>>2] = $357;
 $359 = HEAP32[$45>>2]|0;
 $360 = (($359) + 160|0);
 $361 = HEAP32[$360>>2]|0;
 FUNCTION_TABLE_vii[$361 & 4095]($4,$45);
 $362 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$carChassisAngVel>>2] = $362;
 $363 = (($4) + 4|0);
 $364 = Math_fround(HEAPF32[$363>>2]);
 $365 = (($carChassisAngVel) + 4|0);
 HEAPF32[$365>>2] = $364;
 $366 = (($4) + 8|0);
 $367 = Math_fround(HEAPF32[$366>>2]);
 $368 = (($carChassisAngVel) + 8|0);
 HEAPF32[$368>>2] = $367;
 if ($128) {
  $568 = 0;
 } else {
  $369 = (($vehNoDrive) + 132|0);
  $370 = HEAP32[$369>>2]|0;
  $371 = (($vehNoDrive) + 136|0);
  $372 = HEAP32[$371>>2]|0;
  $i5$0106 = 0;$maxAccel$0108 = Math_fround(0.0);$maxBrake$0107 = Math_fround(0.0);
  while(1) {
   $373 = (($370) + ($i5$0106<<2)|0);
   $374 = Math_fround(HEAPF32[$373>>2]);
   $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($374)))));
   $375 = $fabsf$i$i5 > $maxAccel$0108;
   $376 = $375 ? $fabsf$i$i5 : $maxAccel$0108;
   $377 = (($372) + ($i5$0106<<2)|0);
   $378 = Math_fround(HEAPF32[$377>>2]);
   $fabsf$i$i = (Math_fround(Math_abs((Math_fround($378)))));
   $379 = $fabsf$i$i > $maxBrake$0107;
   $380 = $379 ? $fabsf$i$i : $maxBrake$0107;
   $381 = (($i5$0106) + 1)|0;
   $exitcond151 = ($381|0)==($41|0);
   if ($exitcond151) {
    break;
   } else {
    $i5$0106 = $381;$maxAccel$0108 = $376;$maxBrake$0107 = $380;
   }
  }
  $phitmp = $376 > Math_fround(0.0);
  if ($phitmp) {
   $382 = $380 == Math_fround(0.0);
   $568 = $382;
  } else {
   $568 = 0;
  }
 }
 if ($177) {
  $1211 = $362;$1214 = $364;$1217 = $367;$479 = $327;$482 = $306;$484 = $313;$487 = $320;$514 = $352;$516 = $354;$519 = $357;
 } else {
  $i6$0102 = 0;
  while(1) {
   $383 = $i6$0102 << 2;
   $384 = (($wheelQueryResults) + (($383*148)|0)|0);
   $385 = ((($204) + (($i6$0102*208)|0)|0) + 196|0);
   $386 = HEAP32[$385>>2]|0;
   $387 = ($386|0)==(0|0);
   if ($387) {
    $$sum7677 = $383 | 1;
    $471 = (($wheelQueryResults) + (($$sum7677*148)|0)|0);
    $$sum7879 = $383 | 2;
    $472 = (($wheelQueryResults) + (($$sum7879*148)|0)|0);
    $$sum8081 = $383 | 3;
    $473 = (($wheelQueryResults) + (($$sum8081*148)|0)|0);
    ;HEAP32[$384+0>>2]=0|0;HEAP32[$384+4>>2]=0|0;HEAP32[$384+8>>2]=0|0;HEAP32[$384+12>>2]=0|0;HEAP32[$384+16>>2]=0|0;HEAP32[$384+20>>2]=0|0;HEAP32[$384+24>>2]=0|0;
    ;HEAP32[$471+0>>2]=0|0;HEAP32[$471+4>>2]=0|0;HEAP32[$471+8>>2]=0|0;HEAP32[$471+12>>2]=0|0;HEAP32[$471+16>>2]=0|0;HEAP32[$471+20>>2]=0|0;HEAP32[$471+24>>2]=0|0;
    ;HEAP32[$472+0>>2]=0|0;HEAP32[$472+4>>2]=0|0;HEAP32[$472+8>>2]=0|0;HEAP32[$472+12>>2]=0|0;HEAP32[$472+16>>2]=0|0;HEAP32[$472+20>>2]=0|0;HEAP32[$472+24>>2]=0|0;
    ;HEAP32[$473+0>>2]=0|0;HEAP32[$473+4>>2]=0|0;HEAP32[$473+8>>2]=0|0;HEAP32[$473+12>>2]=0|0;HEAP32[$473+16>>2]=0|0;HEAP32[$473+20>>2]=0|0;HEAP32[$473+24>>2]=0|0;
   } else {
    $388 = ((($204) + (($i6$0102*208)|0)|0) + 80|0);
    $389 = ((($204) + (($i6$0102*208)|0)|0) + 128|0);
    $390 = ((($204) + (($i6$0102*208)|0)|0) + 176|0);
    $391 = Math_fround(HEAPF32[$388>>2]);
    HEAPF32[$384>>2] = $391;
    $392 = ((($204) + (($i6$0102*208)|0)|0) + 84|0);
    $393 = Math_fround(HEAPF32[$392>>2]);
    $394 = ((($wheelQueryResults) + (($383*148)|0)|0) + 4|0);
    HEAPF32[$394>>2] = $393;
    $395 = ((($204) + (($i6$0102*208)|0)|0) + 88|0);
    $396 = Math_fround(HEAPF32[$395>>2]);
    $397 = ((($wheelQueryResults) + (($383*148)|0)|0) + 8|0);
    HEAPF32[$397>>2] = $396;
    $398 = Math_fround(HEAPF32[$389>>2]);
    $399 = ((($wheelQueryResults) + (($383*148)|0)|0) + 12|0);
    HEAPF32[$399>>2] = $398;
    $400 = ((($204) + (($i6$0102*208)|0)|0) + 132|0);
    $401 = Math_fround(HEAPF32[$400>>2]);
    $402 = ((($wheelQueryResults) + (($383*148)|0)|0) + 16|0);
    HEAPF32[$402>>2] = $401;
    $403 = ((($204) + (($i6$0102*208)|0)|0) + 136|0);
    $404 = Math_fround(HEAPF32[$403>>2]);
    $405 = ((($wheelQueryResults) + (($383*148)|0)|0) + 20|0);
    HEAPF32[$405>>2] = $404;
    $406 = Math_fround(HEAPF32[$390>>2]);
    $407 = ((($wheelQueryResults) + (($383*148)|0)|0) + 24|0);
    HEAPF32[$407>>2] = $406;
    $408 = ((($204) + (($i6$0102*208)|0)|0) + 92|0);
    $409 = Math_fround(HEAPF32[$408>>2]);
    $$sum3435 = $383 | 1;
    $410 = (($wheelQueryResults) + (($$sum3435*148)|0)|0);
    HEAPF32[$410>>2] = $409;
    $411 = ((($204) + (($i6$0102*208)|0)|0) + 96|0);
    $412 = Math_fround(HEAPF32[$411>>2]);
    $413 = ((($wheelQueryResults) + (($$sum3435*148)|0)|0) + 4|0);
    HEAPF32[$413>>2] = $412;
    $414 = ((($204) + (($i6$0102*208)|0)|0) + 100|0);
    $415 = Math_fround(HEAPF32[$414>>2]);
    $416 = ((($wheelQueryResults) + (($$sum3435*148)|0)|0) + 8|0);
    HEAPF32[$416>>2] = $415;
    $417 = ((($204) + (($i6$0102*208)|0)|0) + 140|0);
    $418 = Math_fround(HEAPF32[$417>>2]);
    $419 = ((($wheelQueryResults) + (($$sum3435*148)|0)|0) + 12|0);
    HEAPF32[$419>>2] = $418;
    $420 = ((($204) + (($i6$0102*208)|0)|0) + 144|0);
    $421 = Math_fround(HEAPF32[$420>>2]);
    $422 = ((($wheelQueryResults) + (($$sum3435*148)|0)|0) + 16|0);
    HEAPF32[$422>>2] = $421;
    $423 = ((($204) + (($i6$0102*208)|0)|0) + 148|0);
    $424 = Math_fround(HEAPF32[$423>>2]);
    $425 = ((($wheelQueryResults) + (($$sum3435*148)|0)|0) + 20|0);
    HEAPF32[$425>>2] = $424;
    $426 = ((($204) + (($i6$0102*208)|0)|0) + 180|0);
    $427 = Math_fround(HEAPF32[$426>>2]);
    $428 = ((($wheelQueryResults) + (($$sum3435*148)|0)|0) + 24|0);
    HEAPF32[$428>>2] = $427;
    $429 = ((($204) + (($i6$0102*208)|0)|0) + 104|0);
    $430 = Math_fround(HEAPF32[$429>>2]);
    $$sum4849 = $383 | 2;
    $431 = (($wheelQueryResults) + (($$sum4849*148)|0)|0);
    HEAPF32[$431>>2] = $430;
    $432 = ((($204) + (($i6$0102*208)|0)|0) + 108|0);
    $433 = Math_fround(HEAPF32[$432>>2]);
    $434 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 4|0);
    HEAPF32[$434>>2] = $433;
    $435 = ((($204) + (($i6$0102*208)|0)|0) + 112|0);
    $436 = Math_fround(HEAPF32[$435>>2]);
    $437 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 8|0);
    HEAPF32[$437>>2] = $436;
    $438 = ((($204) + (($i6$0102*208)|0)|0) + 152|0);
    $439 = Math_fround(HEAPF32[$438>>2]);
    $440 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 12|0);
    HEAPF32[$440>>2] = $439;
    $441 = ((($204) + (($i6$0102*208)|0)|0) + 156|0);
    $442 = Math_fround(HEAPF32[$441>>2]);
    $443 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 16|0);
    HEAPF32[$443>>2] = $442;
    $444 = ((($204) + (($i6$0102*208)|0)|0) + 160|0);
    $445 = Math_fround(HEAPF32[$444>>2]);
    $446 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 20|0);
    HEAPF32[$446>>2] = $445;
    $447 = ((($204) + (($i6$0102*208)|0)|0) + 184|0);
    $448 = Math_fround(HEAPF32[$447>>2]);
    $449 = ((($wheelQueryResults) + (($$sum4849*148)|0)|0) + 24|0);
    HEAPF32[$449>>2] = $448;
    $450 = ((($204) + (($i6$0102*208)|0)|0) + 116|0);
    $451 = Math_fround(HEAPF32[$450>>2]);
    $$sum6263 = $383 | 3;
    $452 = (($wheelQueryResults) + (($$sum6263*148)|0)|0);
    HEAPF32[$452>>2] = $451;
    $453 = ((($204) + (($i6$0102*208)|0)|0) + 120|0);
    $454 = Math_fround(HEAPF32[$453>>2]);
    $455 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 4|0);
    HEAPF32[$455>>2] = $454;
    $456 = ((($204) + (($i6$0102*208)|0)|0) + 124|0);
    $457 = Math_fround(HEAPF32[$456>>2]);
    $458 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 8|0);
    HEAPF32[$458>>2] = $457;
    $459 = ((($204) + (($i6$0102*208)|0)|0) + 164|0);
    $460 = Math_fround(HEAPF32[$459>>2]);
    $461 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 12|0);
    HEAPF32[$461>>2] = $460;
    $462 = ((($204) + (($i6$0102*208)|0)|0) + 168|0);
    $463 = Math_fround(HEAPF32[$462>>2]);
    $464 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 16|0);
    HEAPF32[$464>>2] = $463;
    $465 = ((($204) + (($i6$0102*208)|0)|0) + 172|0);
    $466 = Math_fround(HEAPF32[$465>>2]);
    $467 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 20|0);
    HEAPF32[$467>>2] = $466;
    $468 = ((($204) + (($i6$0102*208)|0)|0) + 188|0);
    $469 = Math_fround(HEAPF32[$468>>2]);
    $470 = ((($wheelQueryResults) + (($$sum6263*148)|0)|0) + 24|0);
    HEAPF32[$470>>2] = $469;
   }
   $474 = (($i6$0102) + 1)|0;
   $exitcond148 = ($474|0)==($$lcssa133|0);
   if ($exitcond148) {
    break;
   } else {
    $i6$0102 = $474;
   }
  }
  $$pre = Math_fround(HEAPF32[$carChassisLinVel>>2]);
  $$pre155 = Math_fround(HEAPF32[$355>>2]);
  $$pre156 = Math_fround(HEAPF32[$358>>2]);
  $$pre157 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $$pre158 = Math_fround(HEAPF32[$365>>2]);
  $$pre159 = Math_fround(HEAPF32[$368>>2]);
  $$pre160 = Math_fround(HEAPF32[$330>>2]);
  $$pre161 = Math_fround(HEAPF32[$carChassisTransform>>2]);
  $$pre162 = Math_fround(HEAPF32[$328>>2]);
  $$pre163 = Math_fround(HEAPF32[$329>>2]);
  $1211 = $$pre157;$1214 = $$pre158;$1217 = $$pre159;$479 = $$pre160;$482 = $$pre161;$484 = $$pre162;$487 = $$pre163;$514 = $$pre;$516 = $$pre155;$519 = $$pre156;
 }
 $475 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $476 = Math_fround(Math_fround(0.0) * Math_fround(2.0));
 $477 = Math_fround(Math_fround(1.0) * Math_fround(2.0));
 $478 = Math_fround($479 * $479);
 $480 = Math_fround($478 + Math_fround(-0.5));
 $481 = Math_fround($475 * $482);
 $483 = Math_fround($476 * $484);
 $485 = Math_fround($481 + $483);
 $486 = Math_fround($477 * $487);
 $488 = Math_fround($485 + $486);
 $489 = Math_fround($475 * $480);
 $490 = Math_fround($477 * $484);
 $491 = Math_fround($476 * $487);
 $492 = Math_fround($490 - $491);
 $493 = Math_fround($479 * $492);
 $494 = Math_fround($489 + $493);
 $495 = Math_fround($482 * $488);
 $496 = Math_fround($495 + $494);
 $497 = Math_fround($476 * $480);
 $498 = Math_fround($475 * $487);
 $499 = Math_fround($477 * $482);
 $500 = Math_fround($498 - $499);
 $501 = Math_fround($479 * $500);
 $502 = Math_fround($497 + $501);
 $503 = Math_fround($484 * $488);
 $504 = Math_fround($503 + $502);
 $505 = Math_fround($477 * $480);
 $506 = Math_fround($476 * $482);
 $507 = Math_fround($475 * $484);
 $508 = Math_fround($506 - $507);
 $509 = Math_fround($479 * $508);
 $510 = Math_fround($505 + $509);
 $511 = Math_fround($487 * $488);
 $512 = Math_fround($510 + $511);
 $513 = Math_fround($514 * $496);
 $515 = Math_fround($516 * $504);
 $517 = Math_fround($513 + $515);
 $518 = Math_fround($519 * $512);
 $520 = Math_fround($518 + $517);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($520)))));
 $521 = (($vehNoDrive) + 56|0);
 $522 = Math_fround(HEAPF32[$521>>2]);
 $523 = (($vehNoDrive) + 60|0);
 $524 = HEAP32[$523>>2]|0;
 $525 = (($vehNoDrive) + 64|0);
 $526 = HEAP32[$525>>2]|0;
 $527 = $fabsf$i$i$i < $522;
 $528 = $527 ? $524 : $526;
 $529 = (Math_fround(($528>>>0)));
 $530 = Math_fround(Math_fround(1.0) / $529);
 $531 = Math_fround($530 * $timestep);
 $532 = Math_fround(Math_fround(1.0) / $timestep);
 $533 = (($vehNoDrive) + 68|0);
 $534 = Math_fround(HEAPF32[$533>>2]);
 HEAPF32[$constData>>2] = $530;
 $535 = (($constData) + 4|0);
 HEAPF32[$535>>2] = $531;
 $536 = (($constData) + 8|0);
 $537 = Math_fround(HEAPF32[$gravity>>2]);
 HEAPF32[$536>>2] = $537;
 $538 = (($constData) + 12|0);
 $539 = (($gravity) + 4|0);
 $540 = Math_fround(HEAPF32[$539>>2]);
 HEAPF32[$538>>2] = $540;
 $541 = (($constData) + 16|0);
 $542 = (($gravity) + 8|0);
 $543 = Math_fround(HEAPF32[$542>>2]);
 HEAPF32[$541>>2] = $543;
 $544 = (($constData) + 20|0);
 HEAPF32[$544>>2] = $gravityMagnitude;
 $545 = (($constData) + 24|0);
 HEAPF32[$545>>2] = $recipGravityMagnitude;
 $546 = (($constData) + 28|0);
 HEAP8[$546>>0] = 0;
 $547 = (($constData) + 32|0);
 HEAPF32[$547>>2] = $534;
 $548 = (($constData) + 36|0);
 HEAP32[$548>>2] = $45;
 $549 = (($constData) + 40|0);
 HEAP32[$549>>2] = $drivableSurfaceToTireFrictionPairs;
 $550 = ($528|0)==(0);
 if ($550) {
  $1188 = $514;
 } else {
  $551 = (($chassisForce) + 4|0);
  $552 = (($chassisForce) + 8|0);
  $553 = (($chassisTorque) + 4|0);
  $554 = (($chassisTorque) + 8|0);
  $555 = (($vehNoDrive) + 136|0);
  $556 = (($vehNoDrive) + 128|0);
  $557 = (($vehNoDrive) + 132|0);
  $558 = (($brakeTorques) + 4|0);
  $559 = (($isBrakeApplied) + 1|0);
  $560 = (($brakeTorques) + 8|0);
  $561 = (($isBrakeApplied) + 2|0);
  $562 = (($brakeTorques) + 12|0);
  $563 = (($isBrakeApplied) + 3|0);
  $564 = (($isAccelApplied) + 1|0);
  $565 = (($isAccelApplied) + 2|0);
  $566 = (($isAccelApplied) + 3|0);
  $567 = $568&1;
  $569 = (($inputData) + 4|0);
  $570 = (($inputData) + 8|0);
  $571 = (($inputData) + 12|0);
  $572 = (($inputData) + 16|0);
  $573 = (($inputData) + 20|0);
  $574 = (($inputData) + 24|0);
  $575 = (($inputData) + 28|0);
  $576 = (($inputData) + 32|0);
  $577 = (($inputData) + 36|0);
  $578 = (($inputData) + 40|0);
  $579 = (($inputData) + 44|0);
  $580 = (($inputData) + 48|0);
  $581 = (($inputData) + 52|0);
  $582 = (($inputData) + 56|0);
  $583 = (($inputData) + 60|0);
  $584 = (($inputData) + 64|0);
  $585 = (($inputData) + 68|0);
  $586 = (($inputData) + 72|0);
  $587 = (($inputData) + 76|0);
  $588 = (($inputData) + 80|0);
  $589 = (($inputData) + 84|0);
  $590 = (($inputData) + 88|0);
  $591 = (($outputData) + 112|0);
  $592 = (($outputData) + 164|0);
  $593 = (($outputData) + 113|0);
  $594 = (($outputData) + 168|0);
  $595 = (($outputData) + 114|0);
  $596 = (($outputData) + 172|0);
  $597 = (($outputData) + 115|0);
  $598 = (($outputData) + 176|0);
  $599 = (($outputData) + 508|0);
  $600 = (($outputData) + 512|0);
  $601 = (($outputData) + 516|0);
  $602 = (($outputData) + 520|0);
  $603 = (($outputData) + 524|0);
  $604 = (($outputData) + 528|0);
  $605 = (($outputData) + 532|0);
  $606 = (($outputData) + 536|0);
  $607 = (($528) + -1)|0;
  $608 = (($outputData) + 888|0);
  $609 = (($outputData) + 968|0);
  $610 = (($outputData) + 984|0);
  $611 = (($outputData) + 904|0);
  $612 = (($outputData) + 908|0);
  $613 = (($outputData) + 912|0);
  $614 = (($outputData) + 916|0);
  $615 = (($outputData) + 892|0);
  $616 = (($outputData) + 920|0);
  $617 = (($outputData) + 924|0);
  $618 = (($outputData) + 928|0);
  $619 = (($outputData) + 932|0);
  $620 = (($outputData) + 972|0);
  $621 = (($outputData) + 988|0);
  $622 = (($outputData) + 896|0);
  $623 = (($outputData) + 936|0);
  $624 = (($outputData) + 940|0);
  $625 = (($outputData) + 944|0);
  $626 = (($outputData) + 948|0);
  $627 = (($outputData) + 976|0);
  $628 = (($outputData) + 992|0);
  $629 = (($outputData) + 900|0);
  $630 = (($outputData) + 952|0);
  $631 = (($outputData) + 956|0);
  $632 = (($outputData) + 960|0);
  $633 = (($outputData) + 964|0);
  $634 = (($outputData) + 980|0);
  $635 = (($outputData) + 996|0);
  $636 = (($outputData) + 484|0);
  $637 = (($outputData) + 488|0);
  $638 = (($outputData) + 492|0);
  $639 = (($outputData) + 496|0);
  $640 = (($outputData) + 500|0);
  $641 = (($outputData) + 504|0);
  $642 = (($outputData) + 540|0);
  $643 = (($outputData) + 544|0);
  $644 = (($outputData) + 548|0);
  $645 = (($outputData) + 552|0);
  $646 = (($outputData) + 556|0);
  $647 = (($outputData) + 560|0);
  $648 = (($outputData) + 564|0);
  $649 = (($outputData) + 568|0);
  $650 = (($outputData) + 572|0);
  $651 = (($outputData) + 576|0);
  $652 = (($outputData) + 580|0);
  $653 = (($outputData) + 584|0);
  $654 = (($outputData) + 588|0);
  $655 = (($outputData) + 592|0);
  $656 = (($outputData) + 596|0);
  $657 = (($outputData) + 600|0);
  $658 = (($outputData) + 604|0);
  $659 = (($outputData) + 608|0);
  $660 = (($outputData) + 612|0);
  $661 = (($outputData) + 616|0);
  $662 = (($outputData) + 620|0);
  $663 = (($outputData) + 624|0);
  $664 = (($outputData) + 628|0);
  $665 = (($outputData) + 632|0);
  $666 = (($outputData) + 636|0);
  $667 = (($outputData) + 656|0);
  $668 = (($outputData) + 660|0);
  $669 = (($outputData) + 664|0);
  $670 = (($outputData) + 668|0);
  $671 = (($outputData) + 672|0);
  $672 = (($outputData) + 676|0);
  $673 = (($outputData) + 680|0);
  $674 = (($outputData) + 684|0);
  $675 = (($outputData) + 688|0);
  $676 = (($outputData) + 692|0);
  $677 = (($outputData) + 696|0);
  $678 = (($outputData) + 700|0);
  $679 = (($outputData) + 704|0);
  $680 = (($outputData) + 708|0);
  $681 = (($outputData) + 712|0);
  $682 = (($outputData) + 716|0);
  $683 = (($outputData) + 720|0);
  $684 = (($outputData) + 724|0);
  $685 = (($outputData) + 728|0);
  $686 = (($outputData) + 732|0);
  $687 = (($outputData) + 736|0);
  $688 = (($outputData) + 740|0);
  $689 = (($outputData) + 744|0);
  $690 = (($outputData) + 748|0);
  $691 = (($outputData) + 752|0);
  $692 = (($outputData) + 772|0);
  $693 = (($outputData) + 776|0);
  $694 = (($outputData) + 780|0);
  $695 = (($outputData) + 784|0);
  $696 = (($outputData) + 788|0);
  $697 = (($outputData) + 792|0);
  $698 = (($outputData) + 796|0);
  $699 = (($outputData) + 800|0);
  $700 = (($outputData) + 804|0);
  $701 = (($outputData) + 808|0);
  $702 = (($outputData) + 812|0);
  $703 = (($outputData) + 816|0);
  $704 = (($outputData) + 820|0);
  $705 = (($outputData) + 824|0);
  $706 = (($outputData) + 828|0);
  $707 = (($outputData) + 832|0);
  $708 = (($outputData) + 836|0);
  $709 = (($outputData) + 840|0);
  $710 = (($outputData) + 844|0);
  $711 = (($outputData) + 848|0);
  $712 = (($outputData) + 852|0);
  $713 = (($outputData) + 856|0);
  $714 = (($outputData) + 860|0);
  $715 = (($outputData) + 864|0);
  $716 = (($outputData) + 868|0);
  $717 = (($wheelDampingRates) + 4|0);
  $718 = (($wheelDampingRates) + 8|0);
  $719 = (($wheelDampingRates) + 12|0);
  $720 = (($outputData) + 468|0);
  $721 = (($activeWheelStates) + 3|0);
  $722 = (($activeWheelStates) + 2|0);
  $723 = (($activeWheelStates) + 1|0);
  $k$098 = 0;
  while(1) {
   HEAPF32[$chassisForce>>2] = Math_fround(0.0);
   HEAPF32[$551>>2] = Math_fround(0.0);
   HEAPF32[$552>>2] = Math_fround(0.0);
   HEAPF32[$chassisTorque>>2] = Math_fround(0.0);
   HEAPF32[$553>>2] = Math_fround(0.0);
   HEAPF32[$554>>2] = Math_fround(0.0);
   if (!($177)) {
    $724 = Math_fround(HEAPF32[$carChassisTransform>>2]);
    $725 = Math_fround(HEAPF32[$328>>2]);
    $726 = Math_fround(HEAPF32[$329>>2]);
    $727 = Math_fround(HEAPF32[$330>>2]);
    $728 = Math_fround(HEAPF32[$331>>2]);
    $729 = Math_fround(HEAPF32[$332>>2]);
    $730 = Math_fround(HEAPF32[$333>>2]);
    $731 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
    $732 = Math_fround(HEAPF32[$355>>2]);
    $733 = Math_fround(HEAPF32[$358>>2]);
    $734 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
    $735 = Math_fround(HEAPF32[$365>>2]);
    $736 = Math_fround(HEAPF32[$368>>2]);
    $737 = ($607|0)==($k$098|0);
    $938 = Math_fround(0.0);$941 = Math_fround(0.0);$944 = Math_fround(0.0);$947 = Math_fround(0.0);$950 = Math_fround(0.0);$953 = Math_fround(0.0);$i7$083 = 0;
    while(1) {
     $738 = $i7$083 << 2;
     $739 = HEAP32[$555>>2]|0;
     $740 = (($739) + ($738<<2)|0);
     $741 = HEAP32[$556>>2]|0;
     $742 = (($741) + ($738<<2)|0);
     $743 = HEAP32[$557>>2]|0;
     $744 = (($743) + ($738<<2)|0);
     HEAP32[$activeWheelStates>>2] = 0;
     $745 = $i7$083 >>> 3;
     $746 = $745 & 134217727;
     $747 = ((($vehNoDrive) + ($746<<2)|0) + 52|0);
     $748 = HEAP32[$747>>2]|0;
     $749 = $738 & 28;
     $750 = 1 << $749;
     $751 = $748 & $750;
     $752 = ($751|0)==(0);
     if (!($752)) {
      HEAP8[$activeWheelStates>>0] = 1;
     }
     $753 = $749 | 1;
     $754 = 1 << $753;
     $755 = $748 & $754;
     $756 = ($755|0)==(0);
     if (!($756)) {
      HEAP8[$723>>0] = 1;
     }
     $757 = $749 | 2;
     $758 = 1 << $757;
     $759 = $748 & $758;
     $760 = ($759|0)==(0);
     if (!($760)) {
      HEAP8[$722>>0] = 1;
     }
     $761 = $749 | 3;
     $762 = 1 << $761;
     $763 = $748 & $762;
     $764 = ($763|0)==(0);
     if (!($764)) {
      HEAP8[$721>>0] = 1;
     }
     $765 = (($39) + (($i7$083*944)|0)|0);
     $766 = (($204) + (($i7$083*208)|0)|0);
     ;HEAP32[$brakeTorques+0>>2]=0|0;HEAP32[$brakeTorques+4>>2]=0|0;HEAP32[$brakeTorques+8>>2]=0|0;
     HEAP32[$isBrakeApplied>>2] = 0;
     $767 = Math_fround(HEAPF32[$766>>2]);
     $768 = $767 <= Math_fround(-0.0);
     $769 = $768 ? Math_fround(0.0) : Math_fround(1.0);
     $770 = $767 >= Math_fround(0.0);
     $771 = $770 ? $769 : Math_fround(-1.0);
     $772 = Math_fround(HEAPF32[$740>>2]);
     $773 = Math_fround($772 * $771);
     $774 = Math_fround(-$773);
     HEAPF32[$brakeTorques>>2] = $774;
     $775 = $772 != Math_fround(0.0);
     $776 = $775&1;
     HEAP8[$isBrakeApplied>>0] = $776;
     $777 = ((($204) + (($i7$083*208)|0)|0) + 4|0);
     $778 = Math_fround(HEAPF32[$777>>2]);
     $779 = $778 <= Math_fround(-0.0);
     $780 = $779 ? Math_fround(0.0) : Math_fround(1.0);
     $781 = $778 >= Math_fround(0.0);
     $782 = $781 ? $780 : Math_fround(-1.0);
     $$sum18 = $738 | 1;
     $783 = (($739) + ($$sum18<<2)|0);
     $784 = Math_fround(HEAPF32[$783>>2]);
     $785 = Math_fround($784 * $782);
     $786 = Math_fround(-$785);
     HEAPF32[$558>>2] = $786;
     $787 = $784 != Math_fround(0.0);
     $788 = $787&1;
     HEAP8[$559>>0] = $788;
     $789 = ((($204) + (($i7$083*208)|0)|0) + 8|0);
     $790 = Math_fround(HEAPF32[$789>>2]);
     $791 = $790 <= Math_fround(-0.0);
     $792 = $791 ? Math_fround(0.0) : Math_fround(1.0);
     $793 = $790 >= Math_fround(0.0);
     $794 = $793 ? $792 : Math_fround(-1.0);
     $$sum19 = $738 | 2;
     $795 = (($739) + ($$sum19<<2)|0);
     $796 = Math_fround(HEAPF32[$795>>2]);
     $797 = Math_fround($796 * $794);
     $798 = Math_fround(-$797);
     HEAPF32[$560>>2] = $798;
     $799 = $796 != Math_fround(0.0);
     $800 = $799&1;
     HEAP8[$561>>0] = $800;
     $801 = ((($204) + (($i7$083*208)|0)|0) + 12|0);
     $802 = Math_fround(HEAPF32[$801>>2]);
     $803 = $802 <= Math_fround(-0.0);
     $804 = $803 ? Math_fround(0.0) : Math_fround(1.0);
     $805 = $802 >= Math_fround(0.0);
     $806 = $805 ? $804 : Math_fround(-1.0);
     $$sum20 = $738 | 3;
     $807 = (($739) + ($$sum20<<2)|0);
     $808 = Math_fround(HEAPF32[$807>>2]);
     $809 = Math_fround($808 * $806);
     $810 = Math_fround(-$809);
     HEAPF32[$562>>2] = $810;
     $811 = $808 != Math_fround(0.0);
     $812 = $811&1;
     HEAP8[$563>>0] = $812;
     HEAP32[$isAccelApplied>>2] = 0;
     if ($568) {
      $813 = Math_fround(HEAPF32[$744>>2]);
      $814 = $813 != Math_fround(0.0);
      $815 = $814&1;
      HEAP8[$isAccelApplied>>0] = $815;
      $816 = (($743) + ($$sum18<<2)|0);
      $817 = Math_fround(HEAPF32[$816>>2]);
      $818 = $817 != Math_fround(0.0);
      $819 = $818&1;
      HEAP8[$564>>0] = $819;
      $820 = (($743) + ($$sum19<<2)|0);
      $821 = Math_fround(HEAPF32[$820>>2]);
      $822 = $821 != Math_fround(0.0);
      $823 = $822&1;
      HEAP8[$565>>0] = $823;
      $824 = (($743) + ($$sum20<<2)|0);
      $825 = Math_fround(HEAPF32[$824>>2]);
      $826 = $825 != Math_fround(0.0);
      $827 = $826&1;
      HEAP8[$566>>0] = $827;
     }
     HEAP8[$inputData>>0] = $567;
     HEAP32[$569>>2] = $isAccelApplied;
     HEAP32[$570>>2] = $isBrakeApplied;
     HEAP32[$571>>2] = $742;
     HEAP32[$572>>2] = $activeWheelStates;
     HEAPF32[$573>>2] = $724;
     HEAPF32[$574>>2] = $725;
     HEAPF32[$575>>2] = $726;
     HEAPF32[$576>>2] = $727;
     HEAPF32[$577>>2] = $728;
     HEAPF32[$578>>2] = $729;
     HEAPF32[$579>>2] = $730;
     HEAPF32[$580>>2] = $731;
     HEAPF32[$581>>2] = $732;
     HEAPF32[$582>>2] = $733;
     HEAPF32[$583>>2] = $734;
     HEAPF32[$584>>2] = $735;
     HEAPF32[$585>>2] = $736;
     HEAP32[$586>>2] = $765;
     HEAP32[$587>>2] = $766;
     $828 = (($tires4ForceCalculators) + (($i7$083*20)|0)|0);
     HEAP32[$588>>2] = $828;
     HEAP32[$589>>2] = $5;
     $829 = (($numActiveWheelsPerBlock4) + ($i7$083<<2)|0);
     $830 = HEAP32[$829>>2]|0;
     HEAP32[$590>>2] = $830;
     _memset(($outputData|0),0,1112)|0;
     HEAP8[$591>>0] = 1;
     HEAP32[$592>>2] = -1;
     HEAP8[$593>>0] = 1;
     HEAP32[$594>>2] = -1;
     HEAP8[$595>>0] = 1;
     HEAP32[$596>>2] = -1;
     HEAP8[$597>>0] = 1;
     HEAP32[$598>>2] = -1;
     __ZN5physx21processSuspTireWheelsEjRKNS_29ProcessSuspWheelTireConstDataERKNS_29ProcessSuspWheelTireInputDataERNS_30ProcessSuspWheelTireOutputDataE($738,$constData,$inputData,$outputData);
     $831 = HEAP32[$587>>2]|0;
     $832 = (($831) + 48|0);
     $833 = Math_fround(HEAPF32[$599>>2]);
     $834 = Math_fround(HEAPF32[$832>>2]);
     $835 = $833 != $834;
     $836 = $835 ? $833 : Math_fround(0.0);
     HEAPF32[$832>>2] = $836;
     $837 = Math_fround(HEAPF32[$600>>2]);
     $838 = (($831) + 52|0);
     $839 = Math_fround(HEAPF32[$838>>2]);
     $840 = $837 != $839;
     $841 = $840 ? $837 : Math_fround(0.0);
     HEAPF32[$838>>2] = $841;
     $842 = Math_fround(HEAPF32[$601>>2]);
     $843 = (($831) + 56|0);
     $844 = Math_fround(HEAPF32[$843>>2]);
     $845 = $842 != $844;
     $846 = $845 ? $842 : Math_fround(0.0);
     HEAPF32[$843>>2] = $846;
     $847 = Math_fround(HEAPF32[$602>>2]);
     $848 = (($831) + 60|0);
     $849 = Math_fround(HEAPF32[$848>>2]);
     $850 = $847 != $849;
     $851 = $850 ? $847 : Math_fround(0.0);
     HEAPF32[$848>>2] = $851;
     $852 = (($831) + 64|0);
     $853 = Math_fround(HEAPF32[$603>>2]);
     $854 = Math_fround(HEAPF32[$852>>2]);
     $855 = $853 != $854;
     $856 = $855 ? $853 : Math_fround(0.0);
     HEAPF32[$852>>2] = $856;
     $857 = Math_fround(HEAPF32[$604>>2]);
     $858 = (($831) + 68|0);
     $859 = Math_fround(HEAPF32[$858>>2]);
     $860 = $857 != $859;
     $861 = $860 ? $857 : Math_fround(0.0);
     HEAPF32[$858>>2] = $861;
     $862 = Math_fround(HEAPF32[$605>>2]);
     $863 = (($831) + 72|0);
     $864 = Math_fround(HEAPF32[$863>>2]);
     $865 = $862 != $864;
     $866 = $865 ? $862 : Math_fround(0.0);
     HEAPF32[$863>>2] = $866;
     $867 = Math_fround(HEAPF32[$606>>2]);
     $868 = (($831) + 76|0);
     $869 = Math_fround(HEAPF32[$868>>2]);
     $870 = $867 != $869;
     $871 = $870 ? $867 : Math_fround(0.0);
     HEAPF32[$868>>2] = $871;
     if ($737) {
      $872 = ((($204) + (($i7$083*208)|0)|0) + 196|0);
      $873 = HEAP32[$872>>2]|0;
      $874 = ($873|0)==(0|0);
      if (!($874)) {
       $875 = ((($204) + (($i7$083*208)|0)|0) + 200|0);
       HEAP8[$875>>0] = 1;
      }
      $876 = ((($204) + (($i7$083*208)|0)|0) + 80|0);
      $877 = ((($204) + (($i7$083*208)|0)|0) + 176|0);
      $878 = ((($204) + (($i7$083*208)|0)|0) + 160|0);
      $879 = ((($204) + (($i7$083*208)|0)|0) + 144|0);
      $880 = HEAP32[$608>>2]|0;
      $881 = $880&65535;
      HEAP16[$877>>1] = $881;
      $882 = Math_fround(HEAPF32[$611>>2]);
      HEAPF32[$876>>2] = $882;
      $883 = Math_fround(HEAPF32[$612>>2]);
      $884 = ((($204) + (($i7$083*208)|0)|0) + 84|0);
      HEAPF32[$884>>2] = $883;
      $885 = Math_fround(HEAPF32[$613>>2]);
      $886 = ((($204) + (($i7$083*208)|0)|0) + 88|0);
      HEAPF32[$886>>2] = $885;
      $887 = Math_fround(HEAPF32[$614>>2]);
      $888 = ((($204) + (($i7$083*208)|0)|0) + 92|0);
      HEAPF32[$888>>2] = $887;
      $889 = Math_fround(HEAPF32[$609>>2]);
      HEAPF32[$878>>2] = $889;
      $890 = Math_fround(HEAPF32[$610>>2]);
      HEAPF32[$879>>2] = $890;
      $891 = HEAP32[$615>>2]|0;
      $892 = $891&65535;
      $893 = ((($204) + (($i7$083*208)|0)|0) + 178|0);
      HEAP16[$893>>1] = $892;
      $894 = Math_fround(HEAPF32[$616>>2]);
      $895 = ((($204) + (($i7$083*208)|0)|0) + 96|0);
      HEAPF32[$895>>2] = $894;
      $896 = Math_fround(HEAPF32[$617>>2]);
      $897 = ((($204) + (($i7$083*208)|0)|0) + 100|0);
      HEAPF32[$897>>2] = $896;
      $898 = Math_fround(HEAPF32[$618>>2]);
      $899 = ((($204) + (($i7$083*208)|0)|0) + 104|0);
      HEAPF32[$899>>2] = $898;
      $900 = Math_fround(HEAPF32[$619>>2]);
      $901 = ((($204) + (($i7$083*208)|0)|0) + 108|0);
      HEAPF32[$901>>2] = $900;
      $902 = Math_fround(HEAPF32[$620>>2]);
      $903 = ((($204) + (($i7$083*208)|0)|0) + 164|0);
      HEAPF32[$903>>2] = $902;
      $904 = Math_fround(HEAPF32[$621>>2]);
      $905 = ((($204) + (($i7$083*208)|0)|0) + 148|0);
      HEAPF32[$905>>2] = $904;
      $906 = HEAP32[$622>>2]|0;
      $907 = $906&65535;
      $908 = ((($204) + (($i7$083*208)|0)|0) + 180|0);
      HEAP16[$908>>1] = $907;
      $909 = Math_fround(HEAPF32[$623>>2]);
      $910 = ((($204) + (($i7$083*208)|0)|0) + 112|0);
      HEAPF32[$910>>2] = $909;
      $911 = Math_fround(HEAPF32[$624>>2]);
      $912 = ((($204) + (($i7$083*208)|0)|0) + 116|0);
      HEAPF32[$912>>2] = $911;
      $913 = Math_fround(HEAPF32[$625>>2]);
      $914 = ((($204) + (($i7$083*208)|0)|0) + 120|0);
      HEAPF32[$914>>2] = $913;
      $915 = Math_fround(HEAPF32[$626>>2]);
      $916 = ((($204) + (($i7$083*208)|0)|0) + 124|0);
      HEAPF32[$916>>2] = $915;
      $917 = Math_fround(HEAPF32[$627>>2]);
      $918 = ((($204) + (($i7$083*208)|0)|0) + 168|0);
      HEAPF32[$918>>2] = $917;
      $919 = Math_fround(HEAPF32[$628>>2]);
      $920 = ((($204) + (($i7$083*208)|0)|0) + 152|0);
      HEAPF32[$920>>2] = $919;
      $921 = HEAP32[$629>>2]|0;
      $922 = $921&65535;
      $923 = ((($204) + (($i7$083*208)|0)|0) + 182|0);
      HEAP16[$923>>1] = $922;
      $924 = Math_fround(HEAPF32[$630>>2]);
      $925 = ((($204) + (($i7$083*208)|0)|0) + 128|0);
      HEAPF32[$925>>2] = $924;
      $926 = Math_fround(HEAPF32[$631>>2]);
      $927 = ((($204) + (($i7$083*208)|0)|0) + 132|0);
      HEAPF32[$927>>2] = $926;
      $928 = Math_fround(HEAPF32[$632>>2]);
      $929 = ((($204) + (($i7$083*208)|0)|0) + 136|0);
      HEAPF32[$929>>2] = $928;
      $930 = Math_fround(HEAPF32[$633>>2]);
      $931 = ((($204) + (($i7$083*208)|0)|0) + 140|0);
      HEAPF32[$931>>2] = $930;
      $932 = Math_fround(HEAPF32[$634>>2]);
      $933 = ((($204) + (($i7$083*208)|0)|0) + 172|0);
      HEAPF32[$933>>2] = $932;
      $934 = Math_fround(HEAPF32[$635>>2]);
      $935 = ((($204) + (($i7$083*208)|0)|0) + 156|0);
      HEAPF32[$935>>2] = $934;
     }
     $936 = Math_fround(HEAPF32[$636>>2]);
     $937 = Math_fround($936 + $938);
     $939 = Math_fround(HEAPF32[$637>>2]);
     $940 = Math_fround($939 + $941);
     $942 = Math_fround(HEAPF32[$638>>2]);
     $943 = Math_fround($942 + $944);
     $945 = Math_fround(HEAPF32[$639>>2]);
     $946 = Math_fround($945 + $947);
     $948 = Math_fround(HEAPF32[$640>>2]);
     $949 = Math_fround($948 + $950);
     $951 = Math_fround(HEAPF32[$641>>2]);
     $952 = Math_fround($951 + $953);
     $954 = ((($204) + (($i7$083*208)|0)|0) + 192|0);
     $955 = HEAP32[$954>>2]|0;
     $956 = Math_fround(HEAPF32[$642>>2]);
     $957 = (($955) + 4|0);
     HEAPF32[$957>>2] = $956;
     $958 = Math_fround(HEAPF32[$643>>2]);
     $959 = (($955) + 8|0);
     HEAPF32[$959>>2] = $958;
     $960 = Math_fround(HEAPF32[$644>>2]);
     $961 = (($955) + 12|0);
     HEAPF32[$961>>2] = $960;
     $962 = Math_fround(HEAPF32[$645>>2]);
     $963 = (($955) + 16|0);
     HEAPF32[$963>>2] = $962;
     $964 = Math_fround(HEAPF32[$646>>2]);
     $965 = (($955) + 20|0);
     HEAPF32[$965>>2] = $964;
     $966 = Math_fround(HEAPF32[$647>>2]);
     $967 = (($955) + 24|0);
     HEAPF32[$967>>2] = $966;
     $968 = Math_fround(HEAPF32[$648>>2]);
     $969 = (($955) + 28|0);
     HEAPF32[$969>>2] = $968;
     $970 = Math_fround(HEAPF32[$649>>2]);
     $971 = (($955) + 32|0);
     HEAPF32[$971>>2] = $970;
     $972 = Math_fround(HEAPF32[$650>>2]);
     $973 = (($955) + 36|0);
     HEAPF32[$973>>2] = $972;
     $974 = Math_fround(HEAPF32[$651>>2]);
     $975 = (($955) + 40|0);
     HEAPF32[$975>>2] = $974;
     $976 = Math_fround(HEAPF32[$652>>2]);
     $977 = (($955) + 44|0);
     HEAPF32[$977>>2] = $976;
     $978 = Math_fround(HEAPF32[$653>>2]);
     $979 = (($955) + 48|0);
     HEAPF32[$979>>2] = $978;
     $980 = Math_fround(HEAPF32[$654>>2]);
     $981 = (($955) + 52|0);
     HEAPF32[$981>>2] = $980;
     $982 = Math_fround(HEAPF32[$655>>2]);
     $983 = (($955) + 56|0);
     HEAPF32[$983>>2] = $982;
     $984 = Math_fround(HEAPF32[$656>>2]);
     $985 = (($955) + 60|0);
     HEAPF32[$985>>2] = $984;
     $986 = Math_fround(HEAPF32[$657>>2]);
     $987 = (($955) + 64|0);
     HEAPF32[$987>>2] = $986;
     $988 = Math_fround(HEAPF32[$658>>2]);
     $989 = (($955) + 68|0);
     HEAPF32[$989>>2] = $988;
     $990 = Math_fround(HEAPF32[$659>>2]);
     $991 = (($955) + 72|0);
     HEAPF32[$991>>2] = $990;
     $992 = Math_fround(HEAPF32[$660>>2]);
     $993 = (($955) + 76|0);
     HEAPF32[$993>>2] = $992;
     $994 = Math_fround(HEAPF32[$661>>2]);
     $995 = (($955) + 80|0);
     HEAPF32[$995>>2] = $994;
     $996 = Math_fround(HEAPF32[$662>>2]);
     $997 = (($955) + 84|0);
     HEAPF32[$997>>2] = $996;
     $998 = Math_fround(HEAPF32[$663>>2]);
     $999 = (($955) + 88|0);
     HEAPF32[$999>>2] = $998;
     $1000 = Math_fround(HEAPF32[$664>>2]);
     $1001 = (($955) + 92|0);
     HEAPF32[$1001>>2] = $1000;
     $1002 = Math_fround(HEAPF32[$665>>2]);
     $1003 = (($955) + 96|0);
     HEAPF32[$1003>>2] = $1002;
     $1004 = (($955) + 100|0);
     ;HEAP32[$1004+0>>2]=HEAP32[$666+0>>2]|0;HEAP32[$1004+4>>2]=HEAP32[$666+4>>2]|0;HEAP32[$1004+8>>2]=HEAP32[$666+8>>2]|0;HEAP32[$1004+12>>2]=HEAP32[$666+12>>2]|0;HEAP32[$1004+16>>2]=HEAP32[$666+16>>2]|0;
     $1005 = Math_fround(HEAPF32[$667>>2]);
     $1006 = (($955) + 120|0);
     HEAPF32[$1006>>2] = $1005;
     $1007 = Math_fround(HEAPF32[$668>>2]);
     $1008 = (($955) + 124|0);
     HEAPF32[$1008>>2] = $1007;
     $1009 = Math_fround(HEAPF32[$669>>2]);
     $1010 = (($955) + 128|0);
     HEAPF32[$1010>>2] = $1009;
     $1011 = Math_fround(HEAPF32[$670>>2]);
     $1012 = (($955) + 132|0);
     HEAPF32[$1012>>2] = $1011;
     $1013 = Math_fround(HEAPF32[$671>>2]);
     $1014 = (($955) + 136|0);
     HEAPF32[$1014>>2] = $1013;
     $1015 = Math_fround(HEAPF32[$672>>2]);
     $1016 = (($955) + 140|0);
     HEAPF32[$1016>>2] = $1015;
     $1017 = Math_fround(HEAPF32[$673>>2]);
     $1018 = (($955) + 144|0);
     HEAPF32[$1018>>2] = $1017;
     $1019 = Math_fround(HEAPF32[$674>>2]);
     $1020 = (($955) + 148|0);
     HEAPF32[$1020>>2] = $1019;
     $1021 = Math_fround(HEAPF32[$675>>2]);
     $1022 = (($955) + 152|0);
     HEAPF32[$1022>>2] = $1021;
     $1023 = Math_fround(HEAPF32[$676>>2]);
     $1024 = (($955) + 156|0);
     HEAPF32[$1024>>2] = $1023;
     $1025 = Math_fround(HEAPF32[$677>>2]);
     $1026 = (($955) + 160|0);
     HEAPF32[$1026>>2] = $1025;
     $1027 = Math_fround(HEAPF32[$678>>2]);
     $1028 = (($955) + 164|0);
     HEAPF32[$1028>>2] = $1027;
     $1029 = Math_fround(HEAPF32[$679>>2]);
     $1030 = (($955) + 168|0);
     HEAPF32[$1030>>2] = $1029;
     $1031 = Math_fround(HEAPF32[$680>>2]);
     $1032 = (($955) + 172|0);
     HEAPF32[$1032>>2] = $1031;
     $1033 = Math_fround(HEAPF32[$681>>2]);
     $1034 = (($955) + 176|0);
     HEAPF32[$1034>>2] = $1033;
     $1035 = Math_fround(HEAPF32[$682>>2]);
     $1036 = (($955) + 180|0);
     HEAPF32[$1036>>2] = $1035;
     $1037 = Math_fround(HEAPF32[$683>>2]);
     $1038 = (($955) + 184|0);
     HEAPF32[$1038>>2] = $1037;
     $1039 = Math_fround(HEAPF32[$684>>2]);
     $1040 = (($955) + 188|0);
     HEAPF32[$1040>>2] = $1039;
     $1041 = Math_fround(HEAPF32[$685>>2]);
     $1042 = (($955) + 192|0);
     HEAPF32[$1042>>2] = $1041;
     $1043 = Math_fround(HEAPF32[$686>>2]);
     $1044 = (($955) + 196|0);
     HEAPF32[$1044>>2] = $1043;
     $1045 = Math_fround(HEAPF32[$687>>2]);
     $1046 = (($955) + 200|0);
     HEAPF32[$1046>>2] = $1045;
     $1047 = Math_fround(HEAPF32[$688>>2]);
     $1048 = (($955) + 204|0);
     HEAPF32[$1048>>2] = $1047;
     $1049 = Math_fround(HEAPF32[$689>>2]);
     $1050 = (($955) + 208|0);
     HEAPF32[$1050>>2] = $1049;
     $1051 = Math_fround(HEAPF32[$690>>2]);
     $1052 = (($955) + 212|0);
     HEAPF32[$1052>>2] = $1051;
     $1053 = (($955) + 216|0);
     ;HEAP32[$1053+0>>2]=HEAP32[$691+0>>2]|0;HEAP32[$1053+4>>2]=HEAP32[$691+4>>2]|0;HEAP32[$1053+8>>2]=HEAP32[$691+8>>2]|0;HEAP32[$1053+12>>2]=HEAP32[$691+12>>2]|0;HEAP32[$1053+16>>2]=HEAP32[$691+16>>2]|0;
     $1054 = Math_fround(HEAPF32[$692>>2]);
     $1055 = (($955) + 236|0);
     HEAPF32[$1055>>2] = $1054;
     $1056 = Math_fround(HEAPF32[$693>>2]);
     $1057 = (($955) + 240|0);
     HEAPF32[$1057>>2] = $1056;
     $1058 = Math_fround(HEAPF32[$694>>2]);
     $1059 = (($955) + 244|0);
     HEAPF32[$1059>>2] = $1058;
     $1060 = Math_fround(HEAPF32[$695>>2]);
     $1061 = (($955) + 248|0);
     HEAPF32[$1061>>2] = $1060;
     $1062 = Math_fround(HEAPF32[$696>>2]);
     $1063 = (($955) + 252|0);
     HEAPF32[$1063>>2] = $1062;
     $1064 = Math_fround(HEAPF32[$697>>2]);
     $1065 = (($955) + 256|0);
     HEAPF32[$1065>>2] = $1064;
     $1066 = Math_fround(HEAPF32[$698>>2]);
     $1067 = (($955) + 260|0);
     HEAPF32[$1067>>2] = $1066;
     $1068 = Math_fround(HEAPF32[$699>>2]);
     $1069 = (($955) + 264|0);
     HEAPF32[$1069>>2] = $1068;
     $1070 = Math_fround(HEAPF32[$700>>2]);
     $1071 = (($955) + 268|0);
     HEAPF32[$1071>>2] = $1070;
     $1072 = Math_fround(HEAPF32[$701>>2]);
     $1073 = (($955) + 272|0);
     HEAPF32[$1073>>2] = $1072;
     $1074 = Math_fround(HEAPF32[$702>>2]);
     $1075 = (($955) + 276|0);
     HEAPF32[$1075>>2] = $1074;
     $1076 = Math_fround(HEAPF32[$703>>2]);
     $1077 = (($955) + 280|0);
     HEAPF32[$1077>>2] = $1076;
     $1078 = Math_fround(HEAPF32[$704>>2]);
     $1079 = (($955) + 284|0);
     HEAPF32[$1079>>2] = $1078;
     $1080 = Math_fround(HEAPF32[$705>>2]);
     $1081 = (($955) + 288|0);
     HEAPF32[$1081>>2] = $1080;
     $1082 = Math_fround(HEAPF32[$706>>2]);
     $1083 = (($955) + 292|0);
     HEAPF32[$1083>>2] = $1082;
     $1084 = Math_fround(HEAPF32[$707>>2]);
     $1085 = (($955) + 296|0);
     HEAPF32[$1085>>2] = $1084;
     $1086 = Math_fround(HEAPF32[$708>>2]);
     $1087 = (($955) + 300|0);
     HEAPF32[$1087>>2] = $1086;
     $1088 = Math_fround(HEAPF32[$709>>2]);
     $1089 = (($955) + 304|0);
     HEAPF32[$1089>>2] = $1088;
     $1090 = Math_fround(HEAPF32[$710>>2]);
     $1091 = (($955) + 308|0);
     HEAPF32[$1091>>2] = $1090;
     $1092 = Math_fround(HEAPF32[$711>>2]);
     $1093 = (($955) + 312|0);
     HEAPF32[$1093>>2] = $1092;
     $1094 = Math_fround(HEAPF32[$712>>2]);
     $1095 = (($955) + 316|0);
     HEAPF32[$1095>>2] = $1094;
     $1096 = Math_fround(HEAPF32[$713>>2]);
     $1097 = (($955) + 320|0);
     HEAPF32[$1097>>2] = $1096;
     $1098 = Math_fround(HEAPF32[$714>>2]);
     $1099 = (($955) + 324|0);
     HEAPF32[$1099>>2] = $1098;
     $1100 = Math_fround(HEAPF32[$715>>2]);
     $1101 = (($955) + 328|0);
     HEAPF32[$1101>>2] = $1100;
     $1102 = (($955) + 332|0);
     ;HEAP32[$1102+0>>2]=HEAP32[$716+0>>2]|0;HEAP32[$1102+4>>2]=HEAP32[$716+4>>2]|0;HEAP32[$1102+8>>2]=HEAP32[$716+8>>2]|0;HEAP32[$1102+12>>2]=HEAP32[$716+12>>2]|0;HEAP32[$1102+16>>2]=HEAP32[$716+16>>2]|0;
     $1103 = HEAP32[$571>>2]|0;
     $1104 = (($wheelQueryResults) + (($738*148)|0)|0);
     $1105 = HEAP32[$829>>2]|0;
     __ZN5physx15PxVehicleUpdate25storeSuspWheelTireResultsERKNS_30ProcessSuspWheelTireOutputDataEPKfPNS_18PxWheelQueryResultEj($outputData,$1103,$1104,$1105);
     $1106 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
     $1107 = ($1105|0)==(0);
     if (!($1107)) {
      $i$01$i = 0;
      while(1) {
       $1108 = ((($outputData) + ($i$01$i<<2)|0) + 1000|0);
       $1109 = HEAP32[$1108>>2]|0;
       $$sum = (($i$01$i) + ($738))|0;
       $1110 = ((($1106) + (($$sum*56)|0)|0) + 28|0);
       HEAP32[$1110>>2] = $1109;
       $1111 = ((($outputData) + (($i$01$i*12)|0)|0) + 1016|0);
       $1112 = Math_fround(HEAPF32[$1111>>2]);
       $1113 = ((($1106) + (($$sum*56)|0)|0) + 32|0);
       $1114 = Math_fround(HEAPF32[$1113>>2]);
       $1115 = Math_fround($1112 + $1114);
       HEAPF32[$1113>>2] = $1115;
       $1116 = ((($outputData) + (($i$01$i*12)|0)|0) + 1020|0);
       $1117 = Math_fround(HEAPF32[$1116>>2]);
       $1118 = ((($1106) + (($$sum*56)|0)|0) + 36|0);
       $1119 = Math_fround(HEAPF32[$1118>>2]);
       $1120 = Math_fround($1117 + $1119);
       HEAPF32[$1118>>2] = $1120;
       $1121 = ((($outputData) + (($i$01$i*12)|0)|0) + 1024|0);
       $1122 = Math_fround(HEAPF32[$1121>>2]);
       $1123 = ((($1106) + (($$sum*56)|0)|0) + 40|0);
       $1124 = Math_fround(HEAPF32[$1123>>2]);
       $1125 = Math_fround($1122 + $1124);
       HEAPF32[$1123>>2] = $1125;
       $1126 = ((($outputData) + (($i$01$i*12)|0)|0) + 1064|0);
       $1127 = Math_fround(HEAPF32[$1126>>2]);
       $1128 = ((($1106) + (($$sum*56)|0)|0) + 44|0);
       HEAPF32[$1128>>2] = $1127;
       $1129 = ((($outputData) + (($i$01$i*12)|0)|0) + 1068|0);
       $1130 = Math_fround(HEAPF32[$1129>>2]);
       $1131 = ((($1106) + (($$sum*56)|0)|0) + 48|0);
       HEAPF32[$1131>>2] = $1130;
       $1132 = ((($outputData) + (($i$01$i*12)|0)|0) + 1072|0);
       $1133 = Math_fround(HEAPF32[$1132>>2]);
       $1134 = ((($1106) + (($$sum*56)|0)|0) + 52|0);
       HEAPF32[$1134>>2] = $1133;
       $1135 = (($i$01$i) + 1)|0;
       $exitcond$i3 = ($1135|0)==($1105|0);
       if ($exitcond$i3) {
        break;
       } else {
        $i$01$i = $1135;
       }
      }
     }
     $1136 = ((($39) + (($i7$083*944)|0)|0) + 208|0);
     $1137 = Math_fround(HEAPF32[$1136>>2]);
     HEAPF32[$wheelDampingRates>>2] = $1137;
     $1138 = ((($39) + (($i7$083*944)|0)|0) + 256|0);
     $1139 = Math_fround(HEAPF32[$1138>>2]);
     HEAPF32[$717>>2] = $1139;
     $1140 = ((($39) + (($i7$083*944)|0)|0) + 304|0);
     $1141 = Math_fround(HEAPF32[$1140>>2]);
     HEAPF32[$718>>2] = $1141;
     $1142 = ((($39) + (($i7$083*944)|0)|0) + 352|0);
     $1143 = Math_fround(HEAPF32[$1142>>2]);
     HEAPF32[$719>>2] = $1143;
     __ZN5physx27integrateNoDriveWheelSpeedsEfPKfPKbS1_S1_S1_RKNS_23PxVehicleWheels4SimDataERNS_23PxVehicleWheels4DynDataE($531,$brakeTorques,$isBrakeApplied,$744,$720,$wheelDampingRates,$765,$766);
     $j$02$i2 = 0;
     while(1) {
      $1144 = ((($204) + (($i7$083*208)|0)|0) + ($j$02$i2<<2)|0);
      $1145 = Math_fround(HEAPF32[$1144>>2]);
      $1146 = ((($outputData) + ($j$02$i2<<2)|0) + 292|0);
      $1147 = Math_fround(HEAPF32[$1146>>2]);
      $1148 = (((($39) + (($i7$083*944)|0)|0) + (($j$02$i2*48)|0)|0) + 12|0);
      $1149 = Math_fround(HEAPF32[$1148>>2]);
      $1150 = Math_fround(-$1149);
      $1151 = $1147 > $1150;
      do {
       if ($1151) {
        $1152 = (($isBrakeApplied) + ($j$02$i2)|0);
        $1153 = HEAP8[$1152>>0]|0;
        $1154 = ($1153<<24>>24)==(0);
        if (!($1154)) {
         $wheelOmega$0$i = $1145;
         break;
        }
        $$sum27 = (($j$02$i2) + ($738))|0;
        $1155 = (($743) + ($$sum27<<2)|0);
        $1156 = Math_fround(HEAPF32[$1155>>2]);
        $1157 = $1156 == Math_fround(0.0);
        if (!($1157)) {
         $wheelOmega$0$i = $1145;
         break;
        }
        $1158 = ((($outputData) + ($j$02$i2<<2)|0) + 452|0);
        $1159 = Math_fround(HEAPF32[$1158>>2]);
        $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($1159)))));
        $1160 = Math_fround(HEAPF32[523912>>2]);
        $1161 = $fabsf$i$i1$i < $1160;
        if (!($1161)) {
         $wheelOmega$0$i = $1145;
         break;
        }
        $1162 = (((($39) + (($i7$083*944)|0)|0) + (($j$02$i2*48)|0)|0) + 228|0);
        $1163 = Math_fround(HEAPF32[$1162>>2]);
        $1164 = Math_fround(HEAPF32[523920>>2]);
        $1165 = Math_fround($fabsf$i$i1$i * $1164);
        $1166 = Math_fround($1159 * $1163);
        $1167 = Math_fround(Math_fround(1.0) - $1165);
        $1168 = Math_fround($1166 * $1167);
        $1169 = Math_fround($1145 * $1165);
        $1170 = Math_fround($1169 + $1168);
        $wheelOmega$0$i = $1170;
       } else {
        $wheelOmega$0$i = $1145;
       }
      } while(0);
      $1171 = (((($204) + (($i7$083*208)|0)|0) + ($j$02$i2<<2)|0) + 32|0);
      $1172 = Math_fround(HEAPF32[$1171>>2]);
      $1173 = Math_fround($531 * $wheelOmega$0$i);
      $1174 = Math_fround($1172 + $1173);
      $1175 = Math_fround($1174 + Math_fround(-31.415927886962890625));
      $1176 = Math_fround(Math_fround(-31.415927886962890625) - $1174);
      $1177 = Math_fround($1174 + Math_fround(31.415927886962890625));
      $1178 = $1176 >= Math_fround(0.0);
      $1179 = $1178 ? $1177 : $1174;
      $1180 = $1175 >= Math_fround(0.0);
      $1181 = $1180 ? $1175 : $1179;
      HEAPF32[$1171>>2] = $1181;
      $1182 = (((($204) + (($i7$083*208)|0)|0) + ($j$02$i2<<2)|0) + 16|0);
      HEAPF32[$1182>>2] = $wheelOmega$0$i;
      $1183 = (($j$02$i2) + 1)|0;
      $exitcond$i = ($1183|0)==(4);
      if ($exitcond$i) {
       break;
      } else {
       $j$02$i2 = $1183;
      }
     }
     $1184 = (($i7$083) + 1)|0;
     $exitcond146 = ($1184|0)==($$lcssa133|0);
     if ($exitcond146) {
      break;
     } else {
      $938 = $937;$941 = $940;$944 = $943;$947 = $946;$950 = $949;$953 = $952;$i7$083 = $1184;
     }
    }
    HEAPF32[$chassisForce>>2] = $937;
    HEAPF32[$551>>2] = $940;
    HEAPF32[$552>>2] = $943;
    HEAPF32[$chassisTorque>>2] = $946;
    HEAPF32[$553>>2] = $949;
    HEAPF32[$554>>2] = $952;
   }
   __ZN5physx13integrateBodyEfRKNS_6PxVec3ES2_S2_fRS0_S3_RNS_11PxTransformE($338,$inverseInertia,$chassisForce,$chassisTorque,$531,$carChassisLinVel,$carChassisAngVel,$carChassisTransform);
   $1185 = (($k$098) + 1)|0;
   $exitcond147 = ($1185|0)==($528|0);
   if ($exitcond147) {
    break;
   } else {
    $k$098 = $1185;
   }
  }
  $$pre164 = Math_fround(HEAPF32[$carChassisLinVel>>2]);
  $1188 = $$pre164;
 }
 $1186 = (0)==(0);
 $1187 = (($vehicleConcurrentUpdates) + 8|0);
 if ($1186) {
  HEAPF32[$1187>>2] = $1188;
  $1189 = Math_fround(HEAPF32[$355>>2]);
  $1190 = (($vehicleConcurrentUpdates) + 12|0);
  HEAPF32[$1190>>2] = $1189;
  $1191 = Math_fround(HEAPF32[$358>>2]);
  $1192 = (($vehicleConcurrentUpdates) + 16|0);
  HEAPF32[$1192>>2] = $1191;
  $1193 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $1194 = (($vehicleConcurrentUpdates) + 20|0);
  HEAPF32[$1194>>2] = $1193;
  $1195 = Math_fround(HEAPF32[$365>>2]);
  $1196 = (($vehicleConcurrentUpdates) + 24|0);
  HEAPF32[$1196>>2] = $1195;
  $1197 = Math_fround(HEAPF32[$368>>2]);
  $1198 = (($vehicleConcurrentUpdates) + 28|0);
  HEAPF32[$1198>>2] = $1197;
 } else {
  $1199 = Math_fround($1188 - $514);
  $1200 = Math_fround(HEAPF32[$355>>2]);
  $1201 = Math_fround($1200 - $516);
  $1202 = Math_fround(HEAPF32[$358>>2]);
  $1203 = Math_fround($1202 - $519);
  $1204 = Math_fround($532 * $1199);
  $1205 = Math_fround($532 * $1201);
  $1206 = Math_fround($532 * $1203);
  HEAPF32[$1187>>2] = $1204;
  $1207 = (($vehicleConcurrentUpdates) + 12|0);
  HEAPF32[$1207>>2] = $1205;
  $1208 = (($vehicleConcurrentUpdates) + 16|0);
  HEAPF32[$1208>>2] = $1206;
  $1209 = Math_fround(HEAPF32[$carChassisAngVel>>2]);
  $1210 = Math_fround($1209 - $1211);
  $1212 = Math_fround(HEAPF32[$365>>2]);
  $1213 = Math_fround($1212 - $1214);
  $1215 = Math_fround(HEAPF32[$368>>2]);
  $1216 = Math_fround($1215 - $1217);
  $1218 = Math_fround($532 * $1210);
  $1219 = Math_fround($532 * $1213);
  $1220 = Math_fround($532 * $1216);
  $1221 = (($vehicleConcurrentUpdates) + 20|0);
  HEAPF32[$1221>>2] = $1218;
  $1222 = (($vehicleConcurrentUpdates) + 24|0);
  HEAPF32[$1222>>2] = $1219;
  $1223 = (($vehicleConcurrentUpdates) + 28|0);
  HEAPF32[$1223>>2] = $1220;
 }
 HEAPF32[$inputData>>2] = Math_fround(0.0);
 $1224 = (($inputData) + 4|0);
 HEAPF32[$1224>>2] = Math_fround(0.0);
 $1225 = (($inputData) + 8|0);
 HEAPF32[$1225>>2] = Math_fround(0.0);
 $1226 = (($inputData) + 12|0);
 HEAPF32[$1226>>2] = Math_fround(1.0);
 $1227 = (($inputData) + 16|0);
 $1228 = (($inputData) + 20|0);
 $1229 = (($inputData) + 24|0);
 $1230 = (($inputData) + 28|0);
 $1231 = (($inputData) + 32|0);
 $1232 = (($inputData) + 36|0);
 $1233 = (($inputData) + 40|0);
 ;HEAP32[$1227+0>>2]=0|0;HEAP32[$1227+4>>2]=0|0;HEAP32[$1227+8>>2]=0|0;HEAP32[$1227+12>>2]=0|0;HEAP32[$1227+16>>2]=0|0;HEAP32[$1227+20>>2]=0|0;
 HEAPF32[$1233>>2] = Math_fround(1.0);
 $1234 = (($inputData) + 44|0);
 $1235 = (($inputData) + 48|0);
 $1236 = (($inputData) + 52|0);
 $1237 = (($inputData) + 56|0);
 $1238 = (($inputData) + 60|0);
 $1239 = (($inputData) + 64|0);
 $1240 = (($inputData) + 68|0);
 ;HEAP32[$1234+0>>2]=0|0;HEAP32[$1234+4>>2]=0|0;HEAP32[$1234+8>>2]=0|0;HEAP32[$1234+12>>2]=0|0;HEAP32[$1234+16>>2]=0|0;HEAP32[$1234+20>>2]=0|0;
 HEAPF32[$1240>>2] = Math_fround(1.0);
 $1241 = (($inputData) + 72|0);
 $1242 = (($inputData) + 76|0);
 $1243 = (($inputData) + 80|0);
 $1244 = (($inputData) + 84|0);
 $1245 = (($inputData) + 88|0);
 $1246 = (($inputData) + 92|0);
 $1247 = (($inputData) + 96|0);
 ;HEAP32[$1241+0>>2]=0|0;HEAP32[$1241+4>>2]=0|0;HEAP32[$1241+8>>2]=0|0;HEAP32[$1241+12>>2]=0|0;HEAP32[$1241+16>>2]=0|0;HEAP32[$1241+20>>2]=0|0;
 HEAPF32[$1247>>2] = Math_fround(1.0);
 $1248 = (($inputData) + 100|0);
 HEAPF32[$1248>>2] = Math_fround(0.0);
 $1249 = (($inputData) + 104|0);
 HEAPF32[$1249>>2] = Math_fround(0.0);
 $1250 = (($inputData) + 108|0);
 HEAPF32[$1250>>2] = Math_fround(0.0);
 $1251 = HEAP32[$numActiveWheelsPerBlock4>>2]|0;
 __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($39,$204,$wheelQueryResults,$1251,$carChassisCMLocalPose,$inputData);
 $1252 = Math_fround(HEAPF32[$inputData>>2]);
 $1253 = (($wheelQueryResults) + 120|0);
 HEAPF32[$1253>>2] = $1252;
 $1254 = Math_fround(HEAPF32[$1224>>2]);
 $1255 = (($wheelQueryResults) + 124|0);
 HEAPF32[$1255>>2] = $1254;
 $1256 = Math_fround(HEAPF32[$1225>>2]);
 $1257 = (($wheelQueryResults) + 128|0);
 HEAPF32[$1257>>2] = $1256;
 $1258 = Math_fround(HEAPF32[$1226>>2]);
 $1259 = (($wheelQueryResults) + 132|0);
 HEAPF32[$1259>>2] = $1258;
 $1260 = Math_fround(HEAPF32[$1227>>2]);
 $1261 = (($wheelQueryResults) + 136|0);
 HEAPF32[$1261>>2] = $1260;
 $1262 = Math_fround(HEAPF32[$1228>>2]);
 $1263 = (($wheelQueryResults) + 140|0);
 HEAPF32[$1263>>2] = $1262;
 $1264 = Math_fround(HEAPF32[$1229>>2]);
 $1265 = (($wheelQueryResults) + 144|0);
 HEAPF32[$1265>>2] = $1264;
 $1266 = Math_fround(HEAPF32[$1230>>2]);
 $1267 = (($wheelQueryResults) + 268|0);
 HEAPF32[$1267>>2] = $1266;
 $1268 = Math_fround(HEAPF32[$1231>>2]);
 $1269 = (($wheelQueryResults) + 272|0);
 HEAPF32[$1269>>2] = $1268;
 $1270 = Math_fround(HEAPF32[$1232>>2]);
 $1271 = (($wheelQueryResults) + 276|0);
 HEAPF32[$1271>>2] = $1270;
 $1272 = Math_fround(HEAPF32[$1233>>2]);
 $1273 = (($wheelQueryResults) + 280|0);
 HEAPF32[$1273>>2] = $1272;
 $1274 = Math_fround(HEAPF32[$1234>>2]);
 $1275 = (($wheelQueryResults) + 284|0);
 HEAPF32[$1275>>2] = $1274;
 $1276 = Math_fround(HEAPF32[$1235>>2]);
 $1277 = (($wheelQueryResults) + 288|0);
 HEAPF32[$1277>>2] = $1276;
 $1278 = Math_fround(HEAPF32[$1236>>2]);
 $1279 = (($wheelQueryResults) + 292|0);
 HEAPF32[$1279>>2] = $1278;
 $1280 = Math_fround(HEAPF32[$1237>>2]);
 $1281 = (($wheelQueryResults) + 416|0);
 HEAPF32[$1281>>2] = $1280;
 $1282 = Math_fround(HEAPF32[$1238>>2]);
 $1283 = (($wheelQueryResults) + 420|0);
 HEAPF32[$1283>>2] = $1282;
 $1284 = Math_fround(HEAPF32[$1239>>2]);
 $1285 = (($wheelQueryResults) + 424|0);
 HEAPF32[$1285>>2] = $1284;
 $1286 = Math_fround(HEAPF32[$1240>>2]);
 $1287 = (($wheelQueryResults) + 428|0);
 HEAPF32[$1287>>2] = $1286;
 $1288 = Math_fround(HEAPF32[$1241>>2]);
 $1289 = (($wheelQueryResults) + 432|0);
 HEAPF32[$1289>>2] = $1288;
 $1290 = Math_fround(HEAPF32[$1242>>2]);
 $1291 = (($wheelQueryResults) + 436|0);
 HEAPF32[$1291>>2] = $1290;
 $1292 = Math_fround(HEAPF32[$1243>>2]);
 $1293 = (($wheelQueryResults) + 440|0);
 HEAPF32[$1293>>2] = $1292;
 $1294 = Math_fround(HEAPF32[$1244>>2]);
 $1295 = (($wheelQueryResults) + 564|0);
 HEAPF32[$1295>>2] = $1294;
 $1296 = Math_fround(HEAPF32[$1245>>2]);
 $1297 = (($wheelQueryResults) + 568|0);
 HEAPF32[$1297>>2] = $1296;
 $1298 = Math_fround(HEAPF32[$1246>>2]);
 $1299 = (($wheelQueryResults) + 572|0);
 HEAPF32[$1299>>2] = $1298;
 $1300 = Math_fround(HEAPF32[$1247>>2]);
 $1301 = (($wheelQueryResults) + 576|0);
 HEAPF32[$1301>>2] = $1300;
 $1302 = Math_fround(HEAPF32[$1248>>2]);
 $1303 = (($wheelQueryResults) + 580|0);
 HEAPF32[$1303>>2] = $1302;
 $1304 = Math_fround(HEAPF32[$1249>>2]);
 $1305 = (($wheelQueryResults) + 584|0);
 HEAPF32[$1305>>2] = $1304;
 $1306 = Math_fround(HEAPF32[$1250>>2]);
 $1307 = (($wheelQueryResults) + 588|0);
 HEAPF32[$1307>>2] = $1306;
 $1308 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
 HEAPF32[$1308>>2] = $1252;
 $1309 = Math_fround(HEAPF32[$1224>>2]);
 $1310 = (($1308) + 4|0);
 HEAPF32[$1310>>2] = $1309;
 $1311 = Math_fround(HEAPF32[$1225>>2]);
 $1312 = (($1308) + 8|0);
 HEAPF32[$1312>>2] = $1311;
 $1313 = Math_fround(HEAPF32[$1226>>2]);
 $1314 = (($1308) + 12|0);
 HEAPF32[$1314>>2] = $1313;
 $1315 = Math_fround(HEAPF32[$1227>>2]);
 $1316 = (($1308) + 16|0);
 HEAPF32[$1316>>2] = $1315;
 $1317 = Math_fround(HEAPF32[$1228>>2]);
 $1318 = (($1308) + 20|0);
 HEAPF32[$1318>>2] = $1317;
 $1319 = Math_fround(HEAPF32[$1229>>2]);
 $1320 = (($1308) + 24|0);
 HEAPF32[$1320>>2] = $1319;
 $1321 = Math_fround(HEAPF32[$1230>>2]);
 $1322 = (($1308) + 56|0);
 HEAPF32[$1322>>2] = $1321;
 $1323 = Math_fround(HEAPF32[$1231>>2]);
 $1324 = (($1308) + 60|0);
 HEAPF32[$1324>>2] = $1323;
 $1325 = Math_fround(HEAPF32[$1232>>2]);
 $1326 = (($1308) + 64|0);
 HEAPF32[$1326>>2] = $1325;
 $1327 = Math_fround(HEAPF32[$1233>>2]);
 $1328 = (($1308) + 68|0);
 HEAPF32[$1328>>2] = $1327;
 $1329 = Math_fround(HEAPF32[$1234>>2]);
 $1330 = (($1308) + 72|0);
 HEAPF32[$1330>>2] = $1329;
 $1331 = Math_fround(HEAPF32[$1235>>2]);
 $1332 = (($1308) + 76|0);
 HEAPF32[$1332>>2] = $1331;
 $1333 = Math_fround(HEAPF32[$1236>>2]);
 $1334 = (($1308) + 80|0);
 HEAPF32[$1334>>2] = $1333;
 $1335 = Math_fround(HEAPF32[$1237>>2]);
 $1336 = (($1308) + 112|0);
 HEAPF32[$1336>>2] = $1335;
 $1337 = Math_fround(HEAPF32[$1238>>2]);
 $1338 = (($1308) + 116|0);
 HEAPF32[$1338>>2] = $1337;
 $1339 = Math_fround(HEAPF32[$1239>>2]);
 $1340 = (($1308) + 120|0);
 HEAPF32[$1340>>2] = $1339;
 $1341 = Math_fround(HEAPF32[$1240>>2]);
 $1342 = (($1308) + 124|0);
 HEAPF32[$1342>>2] = $1341;
 $1343 = Math_fround(HEAPF32[$1241>>2]);
 $1344 = (($1308) + 128|0);
 HEAPF32[$1344>>2] = $1343;
 $1345 = Math_fround(HEAPF32[$1242>>2]);
 $1346 = (($1308) + 132|0);
 HEAPF32[$1346>>2] = $1345;
 $1347 = Math_fround(HEAPF32[$1243>>2]);
 $1348 = (($1308) + 136|0);
 HEAPF32[$1348>>2] = $1347;
 $1349 = Math_fround(HEAPF32[$1244>>2]);
 $1350 = (($1308) + 168|0);
 HEAPF32[$1350>>2] = $1349;
 $1351 = Math_fround(HEAPF32[$1245>>2]);
 $1352 = (($1308) + 172|0);
 HEAPF32[$1352>>2] = $1351;
 $1353 = Math_fround(HEAPF32[$1246>>2]);
 $1354 = (($1308) + 176|0);
 HEAPF32[$1354>>2] = $1353;
 $1355 = Math_fround(HEAPF32[$1247>>2]);
 $1356 = (($1308) + 180|0);
 HEAPF32[$1356>>2] = $1355;
 $1357 = Math_fround(HEAPF32[$1248>>2]);
 $1358 = (($1308) + 184|0);
 HEAPF32[$1358>>2] = $1357;
 $1359 = Math_fround(HEAPF32[$1249>>2]);
 $1360 = (($1308) + 188|0);
 HEAPF32[$1360>>2] = $1359;
 $1361 = Math_fround(HEAPF32[$1250>>2]);
 $1362 = (($1308) + 192|0);
 HEAPF32[$1362>>2] = $1361;
 $1363 = ($$lcssa133>>>0)>(1);
 if ($1363) {
  $1364 = (($outputData) + 4|0);
  $1365 = (($outputData) + 8|0);
  $1366 = (($outputData) + 12|0);
  $1367 = (($outputData) + 16|0);
  $1368 = (($outputData) + 20|0);
  $1369 = (($outputData) + 24|0);
  $1370 = (($outputData) + 28|0);
  $1371 = (($outputData) + 32|0);
  $1372 = (($outputData) + 36|0);
  $1373 = (($outputData) + 40|0);
  $1374 = (($outputData) + 44|0);
  $1375 = (($outputData) + 48|0);
  $1376 = (($outputData) + 52|0);
  $1377 = (($outputData) + 56|0);
  $1378 = (($outputData) + 60|0);
  $1379 = (($outputData) + 64|0);
  $1380 = (($outputData) + 68|0);
  $1381 = (($outputData) + 72|0);
  $1382 = (($outputData) + 76|0);
  $1383 = (($outputData) + 80|0);
  $1384 = (($outputData) + 84|0);
  $1385 = (($outputData) + 88|0);
  $1386 = (($outputData) + 92|0);
  $1387 = (($outputData) + 96|0);
  $1388 = (($outputData) + 100|0);
  $1389 = (($outputData) + 104|0);
  $1390 = (($outputData) + 108|0);
  $i8$082 = 1;
  while(1) {
   HEAPF32[$outputData>>2] = Math_fround(0.0);
   HEAPF32[$1364>>2] = Math_fround(0.0);
   HEAPF32[$1365>>2] = Math_fround(0.0);
   HEAPF32[$1366>>2] = Math_fround(1.0);
   ;HEAP32[$1367+0>>2]=0|0;HEAP32[$1367+4>>2]=0|0;HEAP32[$1367+8>>2]=0|0;HEAP32[$1367+12>>2]=0|0;HEAP32[$1367+16>>2]=0|0;HEAP32[$1367+20>>2]=0|0;
   HEAPF32[$1373>>2] = Math_fround(1.0);
   ;HEAP32[$1374+0>>2]=0|0;HEAP32[$1374+4>>2]=0|0;HEAP32[$1374+8>>2]=0|0;HEAP32[$1374+12>>2]=0|0;HEAP32[$1374+16>>2]=0|0;HEAP32[$1374+20>>2]=0|0;
   HEAPF32[$1380>>2] = Math_fround(1.0);
   ;HEAP32[$1381+0>>2]=0|0;HEAP32[$1381+4>>2]=0|0;HEAP32[$1381+8>>2]=0|0;HEAP32[$1381+12>>2]=0|0;HEAP32[$1381+16>>2]=0|0;HEAP32[$1381+20>>2]=0|0;
   HEAPF32[$1387>>2] = Math_fround(1.0);
   HEAPF32[$1388>>2] = Math_fround(0.0);
   HEAPF32[$1389>>2] = Math_fround(0.0);
   HEAPF32[$1390>>2] = Math_fround(0.0);
   $1391 = (($39) + (($i8$082*944)|0)|0);
   $1392 = (($204) + (($i8$082*208)|0)|0);
   $1393 = $i8$082 << 2;
   $1394 = (($wheelQueryResults) + (($1393*148)|0)|0);
   $1395 = (($numActiveWheelsPerBlock4) + ($i8$082<<2)|0);
   $1396 = HEAP32[$1395>>2]|0;
   __ZN5physx22computeWheelLocalPosesERKNS_23PxVehicleWheels4SimDataERKNS_23PxVehicleWheels4DynDataEPKNS_18PxWheelQueryResultEjRKNS_11PxTransformEPS9_($1391,$1392,$1394,$1396,$carChassisCMLocalPose,$outputData);
   $1397 = Math_fround(HEAPF32[$outputData>>2]);
   $1398 = ((($wheelQueryResults) + (($1393*148)|0)|0) + 120|0);
   HEAPF32[$1398>>2] = $1397;
   $1399 = Math_fround(HEAPF32[$1364>>2]);
   $1400 = ((($wheelQueryResults) + (($1393*148)|0)|0) + 124|0);
   HEAPF32[$1400>>2] = $1399;
   $1401 = Math_fround(HEAPF32[$1365>>2]);
   $1402 = ((($wheelQueryResults) + (($1393*148)|0)|0) + 128|0);
   HEAPF32[$1402>>2] = $1401;
   $1403 = Math_fround(HEAPF32[$1366>>2]);
   $1404 = ((($wheelQueryResults) + (($1393*148)|0)|0) + 132|0);
   HEAPF32[$1404>>2] = $1403;
   $1405 = Math_fround(HEAPF32[$1367>>2]);
   $1406 = ((($wheelQueryResults) + (($1393*148)|0)|0) + 136|0);
   HEAPF32[$1406>>2] = $1405;
   $1407 = Math_fround(HEAPF32[$1368>>2]);
   $1408 = ((($wheelQueryResults) + (($1393*148)|0)|0) + 140|0);
   HEAPF32[$1408>>2] = $1407;
   $1409 = Math_fround(HEAPF32[$1369>>2]);
   $1410 = ((($wheelQueryResults) + (($1393*148)|0)|0) + 144|0);
   HEAPF32[$1410>>2] = $1409;
   $1411 = $1393 | 1;
   $1412 = Math_fround(HEAPF32[$1370>>2]);
   $1413 = ((($wheelQueryResults) + (($1411*148)|0)|0) + 120|0);
   HEAPF32[$1413>>2] = $1412;
   $1414 = Math_fround(HEAPF32[$1371>>2]);
   $1415 = ((($wheelQueryResults) + (($1411*148)|0)|0) + 124|0);
   HEAPF32[$1415>>2] = $1414;
   $1416 = Math_fround(HEAPF32[$1372>>2]);
   $1417 = ((($wheelQueryResults) + (($1411*148)|0)|0) + 128|0);
   HEAPF32[$1417>>2] = $1416;
   $1418 = Math_fround(HEAPF32[$1373>>2]);
   $1419 = ((($wheelQueryResults) + (($1411*148)|0)|0) + 132|0);
   HEAPF32[$1419>>2] = $1418;
   $1420 = Math_fround(HEAPF32[$1374>>2]);
   $1421 = ((($wheelQueryResults) + (($1411*148)|0)|0) + 136|0);
   HEAPF32[$1421>>2] = $1420;
   $1422 = Math_fround(HEAPF32[$1375>>2]);
   $1423 = ((($wheelQueryResults) + (($1411*148)|0)|0) + 140|0);
   HEAPF32[$1423>>2] = $1422;
   $1424 = Math_fround(HEAPF32[$1376>>2]);
   $1425 = ((($wheelQueryResults) + (($1411*148)|0)|0) + 144|0);
   HEAPF32[$1425>>2] = $1424;
   $1426 = $1393 | 2;
   $1427 = Math_fround(HEAPF32[$1377>>2]);
   $1428 = ((($wheelQueryResults) + (($1426*148)|0)|0) + 120|0);
   HEAPF32[$1428>>2] = $1427;
   $1429 = Math_fround(HEAPF32[$1378>>2]);
   $1430 = ((($wheelQueryResults) + (($1426*148)|0)|0) + 124|0);
   HEAPF32[$1430>>2] = $1429;
   $1431 = Math_fround(HEAPF32[$1379>>2]);
   $1432 = ((($wheelQueryResults) + (($1426*148)|0)|0) + 128|0);
   HEAPF32[$1432>>2] = $1431;
   $1433 = Math_fround(HEAPF32[$1380>>2]);
   $1434 = ((($wheelQueryResults) + (($1426*148)|0)|0) + 132|0);
   HEAPF32[$1434>>2] = $1433;
   $1435 = Math_fround(HEAPF32[$1381>>2]);
   $1436 = ((($wheelQueryResults) + (($1426*148)|0)|0) + 136|0);
   HEAPF32[$1436>>2] = $1435;
   $1437 = Math_fround(HEAPF32[$1382>>2]);
   $1438 = ((($wheelQueryResults) + (($1426*148)|0)|0) + 140|0);
   HEAPF32[$1438>>2] = $1437;
   $1439 = Math_fround(HEAPF32[$1383>>2]);
   $1440 = ((($wheelQueryResults) + (($1426*148)|0)|0) + 144|0);
   HEAPF32[$1440>>2] = $1439;
   $1441 = $1393 | 3;
   $1442 = Math_fround(HEAPF32[$1384>>2]);
   $1443 = ((($wheelQueryResults) + (($1441*148)|0)|0) + 120|0);
   HEAPF32[$1443>>2] = $1442;
   $1444 = Math_fround(HEAPF32[$1385>>2]);
   $1445 = ((($wheelQueryResults) + (($1441*148)|0)|0) + 124|0);
   HEAPF32[$1445>>2] = $1444;
   $1446 = Math_fround(HEAPF32[$1386>>2]);
   $1447 = ((($wheelQueryResults) + (($1441*148)|0)|0) + 128|0);
   HEAPF32[$1447>>2] = $1446;
   $1448 = Math_fround(HEAPF32[$1387>>2]);
   $1449 = ((($wheelQueryResults) + (($1441*148)|0)|0) + 132|0);
   HEAPF32[$1449>>2] = $1448;
   $1450 = Math_fround(HEAPF32[$1388>>2]);
   $1451 = ((($wheelQueryResults) + (($1441*148)|0)|0) + 136|0);
   HEAPF32[$1451>>2] = $1450;
   $1452 = Math_fround(HEAPF32[$1389>>2]);
   $1453 = ((($wheelQueryResults) + (($1441*148)|0)|0) + 140|0);
   HEAPF32[$1453>>2] = $1452;
   $1454 = Math_fround(HEAPF32[$1390>>2]);
   $1455 = ((($wheelQueryResults) + (($1441*148)|0)|0) + 144|0);
   HEAPF32[$1455>>2] = $1454;
   $1456 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
   $1457 = (($1456) + (($1393*56)|0)|0);
   HEAPF32[$1457>>2] = $1397;
   $1458 = Math_fround(HEAPF32[$1364>>2]);
   $1459 = ((($1456) + (($1393*56)|0)|0) + 4|0);
   HEAPF32[$1459>>2] = $1458;
   $1460 = Math_fround(HEAPF32[$1365>>2]);
   $1461 = ((($1456) + (($1393*56)|0)|0) + 8|0);
   HEAPF32[$1461>>2] = $1460;
   $1462 = Math_fround(HEAPF32[$1366>>2]);
   $1463 = ((($1456) + (($1393*56)|0)|0) + 12|0);
   HEAPF32[$1463>>2] = $1462;
   $1464 = Math_fround(HEAPF32[$1367>>2]);
   $1465 = ((($1456) + (($1393*56)|0)|0) + 16|0);
   HEAPF32[$1465>>2] = $1464;
   $1466 = Math_fround(HEAPF32[$1368>>2]);
   $1467 = ((($1456) + (($1393*56)|0)|0) + 20|0);
   HEAPF32[$1467>>2] = $1466;
   $1468 = Math_fround(HEAPF32[$1369>>2]);
   $1469 = ((($1456) + (($1393*56)|0)|0) + 24|0);
   HEAPF32[$1469>>2] = $1468;
   $1470 = Math_fround(HEAPF32[$1370>>2]);
   $1471 = (($1456) + (($1411*56)|0)|0);
   HEAPF32[$1471>>2] = $1470;
   $1472 = Math_fround(HEAPF32[$1371>>2]);
   $1473 = ((($1456) + (($1411*56)|0)|0) + 4|0);
   HEAPF32[$1473>>2] = $1472;
   $1474 = Math_fround(HEAPF32[$1372>>2]);
   $1475 = ((($1456) + (($1411*56)|0)|0) + 8|0);
   HEAPF32[$1475>>2] = $1474;
   $1476 = Math_fround(HEAPF32[$1373>>2]);
   $1477 = ((($1456) + (($1411*56)|0)|0) + 12|0);
   HEAPF32[$1477>>2] = $1476;
   $1478 = Math_fround(HEAPF32[$1374>>2]);
   $1479 = ((($1456) + (($1411*56)|0)|0) + 16|0);
   HEAPF32[$1479>>2] = $1478;
   $1480 = Math_fround(HEAPF32[$1375>>2]);
   $1481 = ((($1456) + (($1411*56)|0)|0) + 20|0);
   HEAPF32[$1481>>2] = $1480;
   $1482 = Math_fround(HEAPF32[$1376>>2]);
   $1483 = ((($1456) + (($1411*56)|0)|0) + 24|0);
   HEAPF32[$1483>>2] = $1482;
   $1484 = Math_fround(HEAPF32[$1377>>2]);
   $1485 = (($1456) + (($1426*56)|0)|0);
   HEAPF32[$1485>>2] = $1484;
   $1486 = Math_fround(HEAPF32[$1378>>2]);
   $1487 = ((($1456) + (($1426*56)|0)|0) + 4|0);
   HEAPF32[$1487>>2] = $1486;
   $1488 = Math_fround(HEAPF32[$1379>>2]);
   $1489 = ((($1456) + (($1426*56)|0)|0) + 8|0);
   HEAPF32[$1489>>2] = $1488;
   $1490 = Math_fround(HEAPF32[$1380>>2]);
   $1491 = ((($1456) + (($1426*56)|0)|0) + 12|0);
   HEAPF32[$1491>>2] = $1490;
   $1492 = Math_fround(HEAPF32[$1381>>2]);
   $1493 = ((($1456) + (($1426*56)|0)|0) + 16|0);
   HEAPF32[$1493>>2] = $1492;
   $1494 = Math_fround(HEAPF32[$1382>>2]);
   $1495 = ((($1456) + (($1426*56)|0)|0) + 20|0);
   HEAPF32[$1495>>2] = $1494;
   $1496 = Math_fround(HEAPF32[$1383>>2]);
   $1497 = ((($1456) + (($1426*56)|0)|0) + 24|0);
   HEAPF32[$1497>>2] = $1496;
   $1498 = Math_fround(HEAPF32[$1384>>2]);
   $1499 = (($1456) + (($1441*56)|0)|0);
   HEAPF32[$1499>>2] = $1498;
   $1500 = Math_fround(HEAPF32[$1385>>2]);
   $1501 = ((($1456) + (($1441*56)|0)|0) + 4|0);
   HEAPF32[$1501>>2] = $1500;
   $1502 = Math_fround(HEAPF32[$1386>>2]);
   $1503 = ((($1456) + (($1441*56)|0)|0) + 8|0);
   HEAPF32[$1503>>2] = $1502;
   $1504 = Math_fround(HEAPF32[$1387>>2]);
   $1505 = ((($1456) + (($1441*56)|0)|0) + 12|0);
   HEAPF32[$1505>>2] = $1504;
   $1506 = Math_fround(HEAPF32[$1388>>2]);
   $1507 = ((($1456) + (($1441*56)|0)|0) + 16|0);
   HEAPF32[$1507>>2] = $1506;
   $1508 = Math_fround(HEAPF32[$1389>>2]);
   $1509 = ((($1456) + (($1441*56)|0)|0) + 20|0);
   HEAPF32[$1509>>2] = $1508;
   $1510 = Math_fround(HEAPF32[$1390>>2]);
   $1511 = ((($1456) + (($1441*56)|0)|0) + 24|0);
   HEAPF32[$1511>>2] = $1510;
   $1512 = (($i8$082) + 1)|0;
   $exitcond = ($1512|0)==($$lcssa133|0);
   if ($exitcond) {
    break;
   } else {
    $i8$082 = $1512;
   }
  }
 }
 $1513 = ($vehWheelQueryResults|0)==(0|0);
 if (!($1513)) {
  $1514 = HEAP32[$vehWheelQueryResults>>2]|0;
  $1515 = ($1514|0)==(0|0);
  if (!($1515)) {
   $1516 = ($41*148)|0;
   _memcpy(($1514|0),($wheelQueryResults|0),($1516|0))|0;
  }
 }
 $1517 = ($vehConcurrentUpdates|0)==(0|0);
 if ($1517) {
  HEAP32[$vehWheels>>2] = $vehNoDrive;
  __ZN5physx15PxVehicleUpdate10updatePostEPKNS_29PxVehicleConcurrentUpdateDataEjPPNS_15PxVehicleWheelsE($vehicleConcurrentUpdates,1,$vehWheels);
  STACKTOP = sp;return;
 } else {
  $1518 = HEAP32[$vehConcurrentUpdates>>2]|0;
  $1519 = HEAP32[$vehicleConcurrentUpdates>>2]|0;
  $1520 = ($41*56)|0;
  _memcpy(($1518|0),($1519|0),($1520|0))|0;
  $1521 = Math_fround(HEAPF32[$1187>>2]);
  $1522 = (($vehConcurrentUpdates) + 8|0);
  HEAPF32[$1522>>2] = $1521;
  $1523 = (($vehicleConcurrentUpdates) + 12|0);
  $1524 = Math_fround(HEAPF32[$1523>>2]);
  $1525 = (($vehConcurrentUpdates) + 12|0);
  HEAPF32[$1525>>2] = $1524;
  $1526 = (($vehicleConcurrentUpdates) + 16|0);
  $1527 = Math_fround(HEAPF32[$1526>>2]);
  $1528 = (($vehConcurrentUpdates) + 16|0);
  HEAPF32[$1528>>2] = $1527;
  $1529 = (($vehicleConcurrentUpdates) + 20|0);
  $1530 = Math_fround(HEAPF32[$1529>>2]);
  $1531 = (($vehConcurrentUpdates) + 20|0);
  HEAPF32[$1531>>2] = $1530;
  $1532 = (($vehicleConcurrentUpdates) + 24|0);
  $1533 = Math_fround(HEAPF32[$1532>>2]);
  $1534 = (($vehConcurrentUpdates) + 24|0);
  HEAPF32[$1534>>2] = $1533;
  $1535 = (($vehicleConcurrentUpdates) + 28|0);
  $1536 = Math_fround(HEAPF32[$1535>>2]);
  $1537 = (($vehConcurrentUpdates) + 28|0);
  HEAPF32[$1537>>2] = $1536;
  $1538 = (($vehicleConcurrentUpdates) + 32|0);
  $1539 = HEAP16[$1538>>1]|0;
  $1540 = $1539&255;
  $1541 = (($vehConcurrentUpdates) + 32|0);
  HEAP8[$1541>>0] = $1540;
  $1542 = ($1539&65535) >>> 8;
  $1543 = $1542&255;
  $1544 = (($vehConcurrentUpdates) + 33|0);
  HEAP8[$1544>>0] = $1543;
  STACKTOP = sp;return;
 }
}
function __ZN5physx15PxVehicleUpdate6updateEfRKNS_6PxVec3ERKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEjPPNS_15PxVehicleWheelsEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$vehicleDrivableSurfaceToTireFrictionPairs,$numVehicles,$vehicles,$vehicleWheelQueryResults,$vehicleConcurrentUpdates) {
 $timestep = Math_fround($timestep);
 $gravity = $gravity|0;
 $vehicleDrivableSurfaceToTireFrictionPairs = $vehicleDrivableSurfaceToTireFrictionPairs|0;
 $numVehicles = $numVehicles|0;
 $vehicles = $vehicles|0;
 $vehicleWheelQueryResults = $vehicleWheelQueryResults|0;
 $vehicleConcurrentUpdates = $vehicleConcurrentUpdates|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = Math_fround(0), $4 = Math_fround(0);
 var $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $exitcond = 0, $i$01 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=523960+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = Math_fround(HEAPF32[$gravity>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($gravity) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($gravity) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (Math_fround(Math_sqrt((Math_fround($9)))));
 $11 = Math_fround(Math_fround(1.0) / $10);
 $12 = ($numVehicles|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = ($vehicleWheelQueryResults|0)==(0|0);
 $14 = ($vehicleConcurrentUpdates|0)==(0|0);
 $i$01 = 0;
 while(1) {
  $15 = (($vehicles) + ($i$01<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  if ($13) {
   $22 = 0;
  } else {
   $17 = (($vehicleWheelQueryResults) + ($i$01<<3)|0);
   $22 = $17;
  }
  if ($14) {
   $23 = 0;
  } else {
   $18 = (($vehicleConcurrentUpdates) + (($i$01*36)|0)|0);
   $23 = $18;
  }
  $19 = (($16) + 113|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20&255;
  if ((($21|0) == 0)) {
   __ZN5physx15PxVehicleUpdate13updateDrive4WEfRKNS_6PxVec3EffRKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEPNS_16PxVehicleDrive4WEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$10,$11,$vehicleDrivableSurfaceToTireFrictionPairs,$16,$22,$23);
  } else if ((($21|0) == 1)) {
   __ZN5physx15PxVehicleUpdate13updateDriveNWEfRKNS_6PxVec3EffRKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEPNS_16PxVehicleDriveNWEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$10,$11,$vehicleDrivableSurfaceToTireFrictionPairs,$16,$22,$23);
  } else if ((($21|0) == 3)) {
   __ZN5physx15PxVehicleUpdate13updateNoDriveEfRKNS_6PxVec3EffRKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEPNS_16PxVehicleNoDriveEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$10,$11,$vehicleDrivableSurfaceToTireFrictionPairs,$16,$22,$23);
  } else if ((($21|0) == 2)) {
   __ZN5physx15PxVehicleUpdate10updateTankEfRKNS_6PxVec3EffRKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEPNS_18PxVehicleDriveTankEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$10,$11,$vehicleDrivableSurfaceToTireFrictionPairs,$16,$22,$23);
  }
  $24 = (($i$01) + 1)|0;
  $exitcond = ($24|0)==($numVehicles|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleUpdate10updatePostEPKNS_29PxVehicleConcurrentUpdateDataEjPPNS_15PxVehicleWheelsE($vehicleConcurentUpdates,$numVehicles,$vehicles) {
 $vehicleConcurentUpdates = $vehicleConcurentUpdates|0;
 $numVehicles = $numVehicles|0;
 $vehicles = $vehicles|0;
 var $$$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0);
 var $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $currShape$0$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond14 = 0, $exitcond15 = 0, $exitcond16 = 0, $i$01$i = 0, $i$09 = 0, $j$01 = 0, $j1$02 = 0;
 var $j2$07 = 0, $localPoses = 0, $numActiveWheelsPerBlock4 = 0, $shapeBuffer$i = 0, $shapeBuffer2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 656|0;
 $shapeBuffer$i = sp + 136|0;
 $shapeBuffer2$i = sp;
 $numActiveWheelsPerBlock4 = sp + 4|0;
 $localPoses = sp + 24|0;
 $0 = ($numVehicles|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($localPoses) + 4|0);
 $2 = (($localPoses) + 8|0);
 $3 = (($localPoses) + 12|0);
 $4 = (($localPoses) + 16|0);
 $5 = (($localPoses) + 20|0);
 $6 = (($localPoses) + 24|0);
 $7 = (($localPoses) + 28|0);
 $8 = (($localPoses) + 32|0);
 $9 = (($localPoses) + 36|0);
 $10 = (($localPoses) + 40|0);
 $11 = (($localPoses) + 44|0);
 $12 = (($localPoses) + 48|0);
 $13 = (($localPoses) + 52|0);
 $14 = (($localPoses) + 56|0);
 $15 = (($localPoses) + 60|0);
 $16 = (($localPoses) + 64|0);
 $17 = (($localPoses) + 68|0);
 $18 = (($localPoses) + 72|0);
 $19 = (($localPoses) + 76|0);
 $20 = (($localPoses) + 80|0);
 $21 = (($localPoses) + 84|0);
 $22 = (($localPoses) + 88|0);
 $23 = (($localPoses) + 92|0);
 $24 = (($localPoses) + 96|0);
 $25 = (($localPoses) + 100|0);
 $26 = (($localPoses) + 104|0);
 $27 = (($localPoses) + 108|0);
 $i$09 = 0;
 while(1) {
  $28 = (($vehicles) + ($i$09<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 104|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($vehicleConcurentUpdates) + (($i$09*36)|0)|0);
  $33 = ((($vehicleConcurentUpdates) + (($i$09*36)|0)|0) + 32|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = ($34<<24>>24)==(0);
  if ($35) {
   $36 = ((($vehicleConcurentUpdates) + (($i$09*36)|0)|0) + 33|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = ($37<<24>>24)==(0);
   if (!($38)) {
    $39 = HEAP32[$31>>2]|0;
    $40 = (($39) + 284|0);
    $41 = HEAP32[$40>>2]|0;
    FUNCTION_TABLE_vi[$41 & 4095]($31);
   }
   $42 = (0)==(0);
   if ($42) {
    $43 = HEAP32[$31>>2]|0;
    $44 = (($43) + 156|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ((($vehicleConcurentUpdates) + (($i$09*36)|0)|0) + 8|0);
    FUNCTION_TABLE_viii[$45 & 4095]($31,$46,0);
    $47 = HEAP32[$31>>2]|0;
    $48 = (($47) + 164|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ((($vehicleConcurentUpdates) + (($i$09*36)|0)|0) + 20|0);
    FUNCTION_TABLE_viii[$49 & 4095]($31,$50,0);
   } else {
    $51 = HEAP32[$31>>2]|0;
    $52 = (($51) + 168|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ((($vehicleConcurentUpdates) + (($i$09*36)|0)|0) + 8|0);
    FUNCTION_TABLE_viiii[$53 & 511]($31,$54,3,0);
    $55 = HEAP32[$31>>2]|0;
    $56 = (($55) + 172|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ((($vehicleConcurentUpdates) + (($i$09*36)|0)|0) + 20|0);
    FUNCTION_TABLE_viiii[$57 & 511]($31,$58,3,0);
   }
   $59 = (($29) + 48|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($29) + 44|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = $62 << 2;
   $64 = (($60) + 4)|0;
   $65 = (($64) - ($63))|0;
   ;HEAP32[$numActiveWheelsPerBlock4+0>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+4>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+8>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+12>>2]=0|0;HEAP32[$numActiveWheelsPerBlock4+16>>2]=0|0;
   $66 = ($60>>>0)<(4);
   $67 = $66 ? $60 : 4;
   HEAP32[$numActiveWheelsPerBlock4>>2] = $67;
   $68 = (($62) + -1)|0;
   $69 = ($68>>>0)>(1);
   if ($69) {
    $j$01 = 1;
    while(1) {
     $70 = (($numActiveWheelsPerBlock4) + ($j$01<<2)|0);
     HEAP32[$70>>2] = 4;
     $71 = (($j$01) + 1)|0;
     $exitcond = ($71|0)==($68|0);
     if ($exitcond) {
      break;
     } else {
      $j$01 = $71;
     }
    }
   }
   $72 = (($numActiveWheelsPerBlock4) + ($68<<2)|0);
   HEAP32[$72>>2] = $65;
   $73 = ($62|0)==(0);
   if (!($73)) {
    $74 = (($29) + 40|0);
    $j1$02 = 0;
    while(1) {
     $75 = $j1$02 << 2;
     $76 = HEAP32[$32>>2]|0;
     $77 = (($76) + (($75*56)|0)|0);
     $78 = Math_fround(HEAPF32[$77>>2]);
     HEAPF32[$localPoses>>2] = $78;
     $79 = ((($76) + (($75*56)|0)|0) + 4|0);
     $80 = Math_fround(HEAPF32[$79>>2]);
     HEAPF32[$1>>2] = $80;
     $81 = ((($76) + (($75*56)|0)|0) + 8|0);
     $82 = Math_fround(HEAPF32[$81>>2]);
     HEAPF32[$2>>2] = $82;
     $83 = ((($76) + (($75*56)|0)|0) + 12|0);
     $84 = Math_fround(HEAPF32[$83>>2]);
     HEAPF32[$3>>2] = $84;
     $85 = ((($76) + (($75*56)|0)|0) + 16|0);
     $86 = Math_fround(HEAPF32[$85>>2]);
     HEAPF32[$4>>2] = $86;
     $87 = ((($76) + (($75*56)|0)|0) + 20|0);
     $88 = Math_fround(HEAPF32[$87>>2]);
     HEAPF32[$5>>2] = $88;
     $89 = ((($76) + (($75*56)|0)|0) + 24|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     HEAPF32[$6>>2] = $90;
     $91 = $75 | 1;
     $92 = (($76) + (($91*56)|0)|0);
     $93 = Math_fround(HEAPF32[$92>>2]);
     HEAPF32[$7>>2] = $93;
     $94 = ((($76) + (($91*56)|0)|0) + 4|0);
     $95 = Math_fround(HEAPF32[$94>>2]);
     HEAPF32[$8>>2] = $95;
     $96 = ((($76) + (($91*56)|0)|0) + 8|0);
     $97 = Math_fround(HEAPF32[$96>>2]);
     HEAPF32[$9>>2] = $97;
     $98 = ((($76) + (($91*56)|0)|0) + 12|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     HEAPF32[$10>>2] = $99;
     $100 = ((($76) + (($91*56)|0)|0) + 16|0);
     $101 = Math_fround(HEAPF32[$100>>2]);
     HEAPF32[$11>>2] = $101;
     $102 = ((($76) + (($91*56)|0)|0) + 20|0);
     $103 = Math_fround(HEAPF32[$102>>2]);
     HEAPF32[$12>>2] = $103;
     $104 = ((($76) + (($91*56)|0)|0) + 24|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     HEAPF32[$13>>2] = $105;
     $106 = $75 | 2;
     $107 = (($76) + (($106*56)|0)|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     HEAPF32[$14>>2] = $108;
     $109 = ((($76) + (($106*56)|0)|0) + 4|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     HEAPF32[$15>>2] = $110;
     $111 = ((($76) + (($106*56)|0)|0) + 8|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     HEAPF32[$16>>2] = $112;
     $113 = ((($76) + (($106*56)|0)|0) + 12|0);
     $114 = Math_fround(HEAPF32[$113>>2]);
     HEAPF32[$17>>2] = $114;
     $115 = ((($76) + (($106*56)|0)|0) + 16|0);
     $116 = Math_fround(HEAPF32[$115>>2]);
     HEAPF32[$18>>2] = $116;
     $117 = ((($76) + (($106*56)|0)|0) + 20|0);
     $118 = Math_fround(HEAPF32[$117>>2]);
     HEAPF32[$19>>2] = $118;
     $119 = ((($76) + (($106*56)|0)|0) + 24|0);
     $120 = Math_fround(HEAPF32[$119>>2]);
     HEAPF32[$20>>2] = $120;
     $121 = $75 | 3;
     $122 = (($76) + (($121*56)|0)|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     HEAPF32[$21>>2] = $123;
     $124 = ((($76) + (($121*56)|0)|0) + 4|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     HEAPF32[$22>>2] = $125;
     $126 = ((($76) + (($121*56)|0)|0) + 8|0);
     $127 = Math_fround(HEAPF32[$126>>2]);
     HEAPF32[$23>>2] = $127;
     $128 = ((($76) + (($121*56)|0)|0) + 12|0);
     $129 = Math_fround(HEAPF32[$128>>2]);
     HEAPF32[$24>>2] = $129;
     $130 = ((($76) + (($121*56)|0)|0) + 16|0);
     $131 = Math_fround(HEAPF32[$130>>2]);
     HEAPF32[$25>>2] = $131;
     $132 = ((($76) + (($121*56)|0)|0) + 20|0);
     $133 = Math_fround(HEAPF32[$132>>2]);
     HEAPF32[$26>>2] = $133;
     $134 = ((($76) + (($121*56)|0)|0) + 24|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     HEAPF32[$27>>2] = $135;
     $136 = HEAP32[$74>>2]|0;
     $137 = (($numActiveWheelsPerBlock4) + ($j1$02<<2)|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = HEAP32[$31>>2]|0;
     $140 = (($139) + 108|0);
     $141 = HEAP32[$140>>2]|0;
     (FUNCTION_TABLE_iiiii[$141 & 511]($31,$shapeBuffer$i,128,0)|0);
     $142 = ($138|0)==(0);
     if (!($142)) {
      $i$01$i = 0;
      while(1) {
       $143 = (((($136) + (($j1$02*944)|0)|0) + ($i$01$i)|0) + 928|0);
       $144 = HEAP8[$143>>0]|0;
       $145 = ($144<<24>>24)==(-1);
       $146 = $144&255;
       $$$i$i = $145 ? -1 : $146;
       if (!($145)) {
        $147 = ($$$i$i|0)<(128);
        if ($147) {
         $148 = (($shapeBuffer$i) + ($$$i$i<<2)|0);
         $149 = HEAP32[$148>>2]|0;
         $currShape$0$i = $149;
        } else {
         $150 = HEAP32[$31>>2]|0;
         $151 = (($150) + 108|0);
         $152 = HEAP32[$151>>2]|0;
         (FUNCTION_TABLE_iiiii[$152 & 511]($31,$shapeBuffer2$i,1,$$$i$i)|0);
         $153 = HEAP32[$shapeBuffer2$i>>2]|0;
         $currShape$0$i = $153;
        }
        $154 = HEAP32[$currShape$0$i>>2]|0;
        $155 = (($154) + 68|0);
        $156 = HEAP32[$155>>2]|0;
        $157 = (($localPoses) + (($i$01$i*28)|0)|0);
        FUNCTION_TABLE_vii[$156 & 4095]($currShape$0$i,$157);
       }
       $158 = (($i$01$i) + 1)|0;
       $exitcond$i = ($158|0)==($138|0);
       if ($exitcond$i) {
        break;
       } else {
        $i$01$i = $158;
       }
      }
     }
     $159 = (($j1$02) + 1)|0;
     $exitcond14 = ($159|0)==($62|0);
     if ($exitcond14) {
      break;
     } else {
      $j1$02 = $159;
     }
    }
   }
   $160 = ($60|0)==(0);
   if (!($160)) {
    $j2$07 = 0;
    while(1) {
     $161 = HEAP32[$32>>2]|0;
     $162 = ((($161) + (($j2$07*56)|0)|0) + 28|0);
     $163 = HEAP32[$162>>2]|0;
     $164 = ($163|0)==(0|0);
     if (!($164)) {
      $165 = ((($161) + (($j2$07*56)|0)|0) + 32|0);
      $166 = ((($161) + (($j2$07*56)|0)|0) + 44|0);
      __ZN5physx14PxRigidBodyExt13addForceAtPosERNS_11PxRigidBodyERKNS_6PxVec3ES5_NS_11PxForceMode4EnumEb($163,$165,$166,0,1);
     }
     $167 = (($j2$07) + 1)|0;
     $exitcond15 = ($167|0)==($60|0);
     if ($exitcond15) {
      break;
     } else {
      $j2$07 = $167;
     }
    }
   }
  }
  $168 = (($i$09) + 1)|0;
  $exitcond16 = ($168|0)==($numVehicles|0);
  if ($exitcond16) {
   break;
  } else {
   $i$09 = $168;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx16PxVehicleUpdatesEfRKNS_6PxVec3ERKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEjPPNS_15PxVehicleWheelsEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$vehicleDrivableSurfaceToTireFrictionPairs,$numVehicles,$vehicles,$vehicleWheelQueryResults,$vehicleConcurrentUpdates) {
 $timestep = Math_fround($timestep);
 $gravity = $gravity|0;
 $vehicleDrivableSurfaceToTireFrictionPairs = $vehicleDrivableSurfaceToTireFrictionPairs|0;
 $numVehicles = $numVehicles|0;
 $vehicles = $vehicles|0;
 $vehicleWheelQueryResults = $vehicleWheelQueryResults|0;
 $vehicleConcurrentUpdates = $vehicleConcurrentUpdates|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15PxVehicleUpdate6updateEfRKNS_6PxVec3ERKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEjPPNS_15PxVehicleWheelsEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($timestep,$gravity,$vehicleDrivableSurfaceToTireFrictionPairs,$numVehicles,$vehicles,$vehicleWheelQueryResults,$vehicleConcurrentUpdates);
 STACKTOP = sp;return;
}
function __Z34PxVehicleWheels4SuspensionRaycastsPN5physx12PxBatchQueryERKNS_23PxVehicleWheels4SimDataERNS_23PxVehicleWheels4DynDataEPKNS_17PxQueryFilterDataEPKbjPNS_14PxRigidDynamicE($batchQuery,$wheels4SimData,$wheels4DynData,$carFilterData,$activeWheelStates,$numActiveWheels,$vehActor) {
 $batchQuery = $batchQuery|0;
 $wheels4SimData = $wheels4SimData|0;
 $wheels4DynData = $wheels4DynData|0;
 $carFilterData = $carFilterData|0;
 $activeWheelStates = $activeWheelStates|0;
 $numActiveWheels = $numActiveWheels|0;
 $vehActor = $vehActor|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0;
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $j$03 = 0, $maxBounce$0 = Math_fround(0), $maxDroop$0 = Math_fround(0), $radius$0 = Math_fround(0), $suspLineDir = 0, $suspLineStart = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 52|0;
 $1 = sp;
 $suspLineStart = sp + 28|0;
 $suspLineDir = sp + 40|0;
 $2 = sp + 80|0;
 $3 = HEAP32[$vehActor>>2]|0;
 $4 = (($3) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$vehActor);
 $6 = HEAP32[$vehActor>>2]|0;
 $7 = (($6) + 124|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095]($1,$vehActor);
 $9 = (($1) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * Math_fround(2.0));
 $12 = (($1) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * Math_fround(2.0));
 $15 = (($1) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * Math_fround(2.0));
 $18 = (($0) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $19);
 $21 = Math_fround($20 + Math_fround(-0.5));
 $22 = Math_fround(HEAPF32[$0>>2]);
 $23 = Math_fround($11 * $22);
 $24 = (($0) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($0) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($17 * $29);
 $31 = Math_fround($27 + $30);
 $32 = Math_fround($11 * $21);
 $33 = Math_fround($17 * $25);
 $34 = Math_fround($14 * $29);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($19 * $35);
 $37 = Math_fround($32 + $36);
 $38 = Math_fround($22 * $31);
 $39 = Math_fround($38 + $37);
 $40 = Math_fround($14 * $21);
 $41 = Math_fround($11 * $29);
 $42 = Math_fround($17 * $22);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($19 * $43);
 $45 = Math_fround($40 + $44);
 $46 = Math_fround($25 * $31);
 $47 = Math_fround($46 + $45);
 $48 = Math_fround($17 * $21);
 $49 = Math_fround($14 * $22);
 $50 = Math_fround($11 * $25);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($19 * $51);
 $53 = Math_fround($48 + $52);
 $54 = Math_fround($29 * $31);
 $55 = Math_fround($53 + $54);
 $56 = (($0) + 16|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 + $39);
 $59 = (($0) + 20|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 + $47);
 $62 = (($0) + 24|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 + $55);
 $65 = Math_fround(HEAPF32[$1>>2]);
 $66 = Math_fround($19 * $65);
 $67 = (($1) + 12|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($22 * $68);
 $70 = Math_fround($66 + $69);
 $71 = (($1) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($25 * $72);
 $74 = Math_fround($70 + $73);
 $75 = (($1) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($29 * $76);
 $78 = Math_fround($74 - $77);
 $79 = Math_fround($19 * $76);
 $80 = Math_fround($25 * $68);
 $81 = Math_fround($80 + $79);
 $82 = Math_fround($29 * $65);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($22 * $72);
 $85 = Math_fround($83 - $84);
 $86 = Math_fround($19 * $72);
 $87 = Math_fround($29 * $68);
 $88 = Math_fround($87 + $86);
 $89 = Math_fround($22 * $76);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($25 * $65);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($19 * $68);
 $94 = Math_fround($22 * $65);
 $95 = Math_fround($93 - $94);
 $96 = Math_fround($25 * $76);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($29 * $72);
 $99 = Math_fround($97 - $98);
 $100 = ($numActiveWheels|0)==(0);
 if ($100) {
  STACKTOP = sp;return;
 }
 $101 = Math_fround($99 * $99);
 $102 = Math_fround($101 + Math_fround(-0.5));
 $103 = (($suspLineDir) + 4|0);
 $104 = (($suspLineDir) + 8|0);
 $105 = (($suspLineStart) + 4|0);
 $106 = (($suspLineStart) + 8|0);
 $107 = (($wheels4DynData) + 80|0);
 $108 = (($wheels4DynData) + 128|0);
 $109 = (($wheels4DynData) + 176|0);
 $j$03 = 0;
 while(1) {
  $110 = ((($wheels4SimData) + (($j$03*12)|0)|0) + 784|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = ((($wheels4SimData) + (($j$03*12)|0)|0) + 788|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = ((($wheels4SimData) + (($j$03*12)|0)|0) + 792|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = ((($wheels4SimData) + (($j$03*48)|0)|0) + 12|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = ((($wheels4SimData) + (($j$03*48)|0)|0) + 8|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = ((($wheels4SimData) + (($j$03*48)|0)|0) + 192|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = (($activeWheelStates) + ($j$03)|0);
  $123 = HEAP8[$122>>0]|0;
  $124 = ($123<<24>>24)==(0);
  if ($124) {
   $125 = Math_fround(HEAPF32[523944>>2]);
   $126 = Math_fround($125 * Math_fround(9.99999974737875163555E-6));
   $166 = Math_fround(0.0);$168 = Math_fround(0.0);$170 = Math_fround(0.0);$maxBounce$0 = $126;$maxDroop$0 = $126;$radius$0 = $126;
  } else {
   $166 = $111;$168 = $113;$170 = $115;$maxBounce$0 = $119;$maxDroop$0 = $117;$radius$0 = $121;
  }
  $127 = ((($wheels4SimData) + (($j$03*12)|0)|0) + 640|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = Math_fround($128 * Math_fround(2.0));
  $130 = ((($wheels4SimData) + (($j$03*12)|0)|0) + 644|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  $132 = Math_fround($131 * Math_fround(2.0));
  $133 = ((($wheels4SimData) + (($j$03*12)|0)|0) + 648|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($134 * Math_fround(2.0));
  $136 = Math_fround($78 * $129);
  $137 = Math_fround($85 * $132);
  $138 = Math_fround($136 + $137);
  $139 = Math_fround($92 * $135);
  $140 = Math_fround($138 + $139);
  $141 = Math_fround($102 * $129);
  $142 = Math_fround($85 * $135);
  $143 = Math_fround($92 * $132);
  $144 = Math_fround($142 - $143);
  $145 = Math_fround($99 * $144);
  $146 = Math_fround($141 + $145);
  $147 = Math_fround($78 * $140);
  $148 = Math_fround($147 + $146);
  $149 = Math_fround($102 * $132);
  $150 = Math_fround($92 * $129);
  $151 = Math_fround($78 * $135);
  $152 = Math_fround($150 - $151);
  $153 = Math_fround($99 * $152);
  $154 = Math_fround($149 + $153);
  $155 = Math_fround($85 * $140);
  $156 = Math_fround($155 + $154);
  $157 = Math_fround($102 * $135);
  $158 = Math_fround($78 * $132);
  $159 = Math_fround($85 * $129);
  $160 = Math_fround($158 - $159);
  $161 = Math_fround($99 * $160);
  $162 = Math_fround($157 + $161);
  $163 = Math_fround($92 * $140);
  $164 = Math_fround($162 + $163);
  HEAPF32[$suspLineDir>>2] = $148;
  HEAPF32[$103>>2] = $156;
  HEAPF32[$104>>2] = $164;
  $165 = Math_fround($166 * Math_fround(2.0));
  $167 = Math_fround($168 * Math_fround(2.0));
  $169 = Math_fround($170 * Math_fround(2.0));
  $171 = Math_fround($78 * $165);
  $172 = Math_fround($85 * $167);
  $173 = Math_fround($172 + $171);
  $174 = Math_fround($92 * $169);
  $175 = Math_fround($174 + $173);
  $176 = Math_fround($102 * $165);
  $177 = Math_fround($85 * $169);
  $178 = Math_fround($92 * $167);
  $179 = Math_fround($177 - $178);
  $180 = Math_fround($99 * $179);
  $181 = Math_fround($176 + $180);
  $182 = Math_fround($78 * $175);
  $183 = Math_fround($181 + $182);
  $184 = Math_fround($102 * $167);
  $185 = Math_fround($92 * $165);
  $186 = Math_fround($78 * $169);
  $187 = Math_fround($185 - $186);
  $188 = Math_fround($99 * $187);
  $189 = Math_fround($184 + $188);
  $190 = Math_fround($85 * $175);
  $191 = Math_fround($190 + $189);
  $192 = Math_fround($102 * $169);
  $193 = Math_fround($78 * $167);
  $194 = Math_fround($85 * $165);
  $195 = Math_fround($193 - $194);
  $196 = Math_fround($99 * $195);
  $197 = Math_fround($192 + $196);
  $198 = Math_fround($92 * $175);
  $199 = Math_fround($197 + $198);
  $200 = Math_fround($58 + $183);
  $201 = Math_fround($61 + $191);
  $202 = Math_fround($64 + $199);
  $203 = Math_fround($maxBounce$0 + $radius$0);
  $204 = Math_fround($203 * $148);
  $205 = Math_fround($203 * $156);
  $206 = Math_fround($203 * $164);
  $207 = Math_fround($200 - $204);
  HEAPF32[$suspLineStart>>2] = $207;
  $208 = Math_fround($201 - $205);
  HEAPF32[$105>>2] = $208;
  $209 = Math_fround($202 - $206);
  HEAPF32[$106>>2] = $209;
  $210 = Math_fround($203 + $maxDroop$0);
  $211 = Math_fround($radius$0 + $210);
  $212 = Math_fround($radius$0 + $211);
  $213 = (($107) + (($j$03*12)|0)|0);
  HEAPF32[$213>>2] = $207;
  $214 = ((($107) + (($j$03*12)|0)|0) + 4|0);
  HEAPF32[$214>>2] = $208;
  $215 = ((($107) + (($j$03*12)|0)|0) + 8|0);
  HEAPF32[$215>>2] = $209;
  $216 = (($108) + (($j$03*12)|0)|0);
  HEAPF32[$216>>2] = $148;
  $217 = ((($108) + (($j$03*12)|0)|0) + 4|0);
  HEAPF32[$217>>2] = $156;
  $218 = ((($108) + (($j$03*12)|0)|0) + 8|0);
  HEAPF32[$218>>2] = $164;
  $219 = (($109) + ($j$03<<2)|0);
  HEAPF32[$219>>2] = $212;
  $220 = HEAP32[$batchQuery>>2]|0;
  $221 = (($220) + 44|0);
  $222 = HEAP32[$221>>2]|0;
  HEAP16[$2>>1] = 15;
  $223 = (($carFilterData) + (($j$03*20)|0)|0);
  FUNCTION_TABLE_viiifiiiii[$222 & 1]($batchQuery,$suspLineStart,$suspLineDir,$212,0,$2,$223,0,0);
  $224 = (($j$03) + 1)|0;
  $exitcond = ($224|0)==($numActiveWheels|0);
  if ($exitcond) {
   break;
  } else {
   $j$03 = $224;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleUpdate18suspensionRaycastsEPNS_12PxBatchQueryEjPPNS_15PxVehicleWheelsEjPNS_18PxBatchQueryResultINS_12PxRaycastHitEEEPKb($batchQuery,$numVehicles,$vehicles,$numSceneQueryResults,$sceneQueryResults,$vehiclesToRaycast) {
 $batchQuery = $batchQuery|0;
 $numVehicles = $numVehicles|0;
 $vehicles = $vehicles|0;
 $numSceneQueryResults = $numSceneQueryResults|0;
 $sceneQueryResults = $sceneQueryResults|0;
 $vehiclesToRaycast = $vehiclesToRaycast|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $activeWheelStates = 0, $activeWheelStates3 = 0, $carFilterData = 0, $exitcond = 0, $exitcond15 = 0, $i$011 = 0, $i1$05 = 0, $j$03 = 0, $sqres$07 = 0;
 var $sqres$1$lcssa = 0, $sqres$12 = 0, $sqres$2 = 0, $sqres$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $carFilterData = sp + 8|0;
 $activeWheelStates = sp;
 $activeWheelStates3 = sp + 4|0;
 $0 = ($numSceneQueryResults|0)==(0);
 if (!($0)) {
  $i$011 = 0;
  while(1) {
   $1 = ((($sceneQueryResults) + (($i$011*80)|0)|0) + 77|0);
   HEAP8[$1>>0] = 0;
   $2 = (($i$011) + 1)|0;
   $exitcond15 = ($2|0)==($numSceneQueryResults|0);
   if ($exitcond15) {
    break;
   } else {
    $i$011 = $2;
   }
  }
 }
 ;HEAP32[$carFilterData+0>>2]=0|0;HEAP32[$carFilterData+4>>2]=0|0;HEAP32[$carFilterData+8>>2]=0|0;HEAP32[$carFilterData+12>>2]=0|0;
 $3 = (($carFilterData) + 18|0);
 HEAP8[$3>>0] = 0;
 $4 = (($carFilterData) + 20|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 $5 = (($carFilterData) + 38|0);
 HEAP8[$5>>0] = 0;
 $6 = (($carFilterData) + 40|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;
 $7 = (($carFilterData) + 58|0);
 HEAP8[$7>>0] = 0;
 $8 = (($carFilterData) + 60|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
 $9 = (($carFilterData) + 78|0);
 HEAP8[$9>>0] = 0;
 $10 = (($carFilterData) + 16|0);
 HEAP16[$10>>1] = 7;
 $11 = (($carFilterData) + 36|0);
 HEAP16[$11>>1] = 7;
 $12 = (($carFilterData) + 56|0);
 HEAP16[$12>>1] = 7;
 $13 = (($carFilterData) + 76|0);
 HEAP16[$13>>1] = 7;
 $14 = ($numVehicles|0)==(0);
 if ($14) {
  $109 = HEAP32[$batchQuery>>2]|0;
  $110 = HEAP32[$109>>2]|0;
  FUNCTION_TABLE_vi[$110 & 4095]($batchQuery);
  STACKTOP = sp;return;
 }
 $15 = (($carFilterData) + 40|0);
 $16 = (($carFilterData) + 20|0);
 $17 = ($vehiclesToRaycast|0)==(0|0);
 $18 = (($sceneQueryResults) + (($numSceneQueryResults*80)|0)|0);
 $19 = (($activeWheelStates3) + 3|0);
 $20 = (($activeWheelStates3) + 2|0);
 $21 = (($activeWheelStates3) + 1|0);
 $22 = (($carFilterData) + 60|0);
 $23 = (($activeWheelStates) + 3|0);
 $24 = (($activeWheelStates) + 2|0);
 $25 = (($activeWheelStates) + 1|0);
 $i1$05 = 0;$sqres$07 = $sceneQueryResults;
 while(1) {
  $26 = (($vehicles) + ($i1$05<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 40|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 72|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($27) + 48|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33 >>> 2;
  $35 = $34 << 2;
  $36 = (($33) - ($35))|0;
  $37 = (($27) + 104|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($34|0)==(0);
  if ($39) {
   $sqres$1$lcssa = $sqres$07;
  } else {
   $40 = (($vehiclesToRaycast) + ($i1$05)|0);
   $j$03 = 0;$sqres$12 = $sqres$07;
   while(1) {
    HEAP32[$activeWheelStates>>2] = 0;
    $41 = $j$03 << 2;
    $42 = $j$03 >>> 3;
    $43 = $42 & 134217727;
    $44 = ((($27) + ($43<<2)|0) + 52|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = $41 & 28;
    $47 = 1 << $46;
    $48 = $45 & $47;
    $49 = ($48|0)==(0);
    if (!($49)) {
     HEAP8[$activeWheelStates>>0] = 1;
    }
    $50 = $46 | 1;
    $51 = 1 << $50;
    $52 = $45 & $51;
    $53 = ($52|0)==(0);
    if (!($53)) {
     HEAP8[$25>>0] = 1;
    }
    $54 = $46 | 2;
    $55 = 1 << $54;
    $56 = $45 & $55;
    $57 = ($56|0)==(0);
    if (!($57)) {
     HEAP8[$24>>0] = 1;
    }
    $58 = $46 | 3;
    $59 = 1 << $58;
    $60 = $45 & $59;
    $61 = ($60|0)==(0);
    if (!($61)) {
     HEAP8[$23>>0] = 1;
    }
    $62 = (($31) + (($j$03*208)|0)|0);
    $63 = ((($31) + (($j$03*208)|0)|0) + 196|0);
    HEAP32[$63>>2] = 0;
    if ($17) {
     label = 17;
    } else {
     $64 = HEAP8[$40>>0]|0;
     $65 = ($64<<24>>24)==(0);
     if ($65) {
      $sqres$2 = $sqres$12;
     } else {
      label = 17;
     }
    }
    if ((label|0) == 17) {
     label = 0;
     $66 = (($sqres$12) + 320|0);
     $67 = ($18>>>0)<($66>>>0);
     if ($67) {
      $sqres$2 = $66;
     } else {
      $68 = (($29) + (($j$03*944)|0)|0);
      $69 = ((($29) + (($j$03*944)|0)|0) + 864|0);
      ;HEAP32[$carFilterData+0>>2]=HEAP32[$69+0>>2]|0;HEAP32[$carFilterData+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$carFilterData+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$carFilterData+12>>2]=HEAP32[$69+12>>2]|0;
      $70 = ((($29) + (($j$03*944)|0)|0) + 880|0);
      ;HEAP32[$16+0>>2]=HEAP32[$70+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$70+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$70+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$70+12>>2]|0;
      $71 = ((($29) + (($j$03*944)|0)|0) + 896|0);
      ;HEAP32[$15+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$71+12>>2]|0;
      $72 = ((($29) + (($j$03*944)|0)|0) + 912|0);
      ;HEAP32[$22+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$72+12>>2]|0;
      HEAP32[$63>>2] = $sqres$12;
      __Z34PxVehicleWheels4SuspensionRaycastsPN5physx12PxBatchQueryERKNS_23PxVehicleWheels4SimDataERNS_23PxVehicleWheels4DynDataEPKNS_17PxQueryFilterDataEPKbjPNS_14PxRigidDynamicE($batchQuery,$68,$62,$carFilterData,$activeWheelStates,4,$38);
      $sqres$2 = $66;
     }
    }
    $73 = (($j$03) + 1)|0;
    $74 = ($73>>>0)<($34>>>0);
    if ($74) {
     $j$03 = $73;$sqres$12 = $sqres$2;
    } else {
     $sqres$1$lcssa = $sqres$2;
     break;
    }
   }
  }
  $75 = ($33|0)==($35|0);
  do {
   if ($75) {
    $sqres$3 = $sqres$1$lcssa;
   } else {
    HEAP32[$activeWheelStates3>>2] = 0;
    $76 = $33 >>> 5;
    $77 = ((($27) + ($76<<2)|0) + 52|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = $35 & 28;
    $80 = 1 << $79;
    $81 = $78 & $80;
    $82 = ($81|0)==(0);
    if (!($82)) {
     HEAP8[$activeWheelStates3>>0] = 1;
    }
    $83 = $79 | 1;
    $84 = 1 << $83;
    $85 = $78 & $84;
    $86 = ($85|0)==(0);
    if (!($86)) {
     HEAP8[$21>>0] = 1;
    }
    $87 = $79 | 2;
    $88 = 1 << $87;
    $89 = $78 & $88;
    $90 = ($89|0)==(0);
    if (!($90)) {
     HEAP8[$20>>0] = 1;
    }
    $91 = $79 | 3;
    $92 = 1 << $91;
    $93 = $78 & $92;
    $94 = ($93|0)==(0);
    if (!($94)) {
     HEAP8[$19>>0] = 1;
    }
    $95 = (($31) + (($34*208)|0)|0);
    $96 = ((($31) + (($34*208)|0)|0) + 196|0);
    HEAP32[$96>>2] = 0;
    if (!($17)) {
     $97 = (($vehiclesToRaycast) + ($i1$05)|0);
     $98 = HEAP8[$97>>0]|0;
     $99 = ($98<<24>>24)==(0);
     if ($99) {
      $sqres$3 = $sqres$1$lcssa;
      break;
     }
    }
    $100 = (($sqres$1$lcssa) + (($36*80)|0)|0);
    $101 = ($18>>>0)<($100>>>0);
    if ($101) {
     $sqres$3 = $100;
    } else {
     $102 = ((($29) + (($34*944)|0)|0) + 864|0);
     ;HEAP32[$carFilterData+0>>2]=HEAP32[$102+0>>2]|0;HEAP32[$carFilterData+4>>2]=HEAP32[$102+4>>2]|0;HEAP32[$carFilterData+8>>2]=HEAP32[$102+8>>2]|0;HEAP32[$carFilterData+12>>2]=HEAP32[$102+12>>2]|0;
     $103 = ($36>>>0)>(1);
     if ($103) {
      $104 = ((($29) + (($34*944)|0)|0) + 880|0);
      ;HEAP32[$16+0>>2]=HEAP32[$104+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$104+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$104+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$104+12>>2]|0;
      $105 = ($36>>>0)>(2);
      if ($105) {
       $106 = ((($29) + (($34*944)|0)|0) + 896|0);
       ;HEAP32[$15+0>>2]=HEAP32[$106+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$106+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$106+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$106+12>>2]|0;
      }
     }
     HEAP32[$96>>2] = $sqres$1$lcssa;
     $107 = (($29) + (($34*944)|0)|0);
     __Z34PxVehicleWheels4SuspensionRaycastsPN5physx12PxBatchQueryERKNS_23PxVehicleWheels4SimDataERNS_23PxVehicleWheels4DynDataEPKNS_17PxQueryFilterDataEPKbjPNS_14PxRigidDynamicE($batchQuery,$107,$95,$carFilterData,$activeWheelStates3,$36,$38);
     $sqres$3 = $100;
    }
   }
  } while(0);
  $108 = (($i1$05) + 1)|0;
  $exitcond = ($108|0)==($numVehicles|0);
  if ($exitcond) {
   break;
  } else {
   $i1$05 = $108;$sqres$07 = $sqres$3;
  }
 }
 $109 = HEAP32[$batchQuery>>2]|0;
 $110 = HEAP32[$109>>2]|0;
 FUNCTION_TABLE_vi[$110 & 4095]($batchQuery);
 STACKTOP = sp;return;
}
function __ZN5physx27PxVehicleSuspensionRaycastsEPNS_12PxBatchQueryEjPPNS_15PxVehicleWheelsEjPNS_18PxBatchQueryResultINS_12PxRaycastHitEEEPKb($batchQuery,$numVehicles,$vehicles,$numSceneQueryesults,$sceneQueryResults,$vehiclesToRaycast) {
 $batchQuery = $batchQuery|0;
 $numVehicles = $numVehicles|0;
 $vehicles = $vehicles|0;
 $numSceneQueryesults = $numSceneQueryesults|0;
 $sceneQueryResults = $sceneQueryResults|0;
 $vehiclesToRaycast = $vehiclesToRaycast|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx15PxVehicleUpdate18suspensionRaycastsEPNS_12PxBatchQueryEjPPNS_15PxVehicleWheelsEjPNS_18PxBatchQueryResultINS_12PxRaycastHitEEEPKb($batchQuery,$numVehicles,$vehicles,$numSceneQueryesults,$sceneQueryResults,$vehiclesToRaycast);
 STACKTOP = sp;return;
}
function __ZN5physx27VehicleSurfaceTypeHashTableC2ERKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsE($this,$pairs) {
 $this = $this|0;
 $pairs = $pairs|0;
 var $$pre = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $i2$02 = 0, $numUniqueHashes$02$i = 0, $numUniqueHashes$1$i = 0, $prevNumUniqueHashes$06 = 0, $prevShift$04 = 0, $prevShift$04$phi = 0, $scevgep16 = 0, $shift$05 = 0, $storemerge = 0, $words$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $words$i = sp;
 $0 = (($pairs) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$this>>2] = $1;
 $2 = (($this) + 4|0);
 $3 = (($pairs) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 8|0);
 $6 = (($pairs) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$5>>2] = $7;
 $scevgep16 = (($this) + 12|0);
 $8 = ($1|0)==(0);
 _memset(($scevgep16|0),-1,2048)|0;
 if ($8) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$words$i+0>>2]=0|0;HEAP32[$words$i+4>>2]=0|0;HEAP32[$words$i+8>>2]=0|0;HEAP32[$words$i+12>>2]=0|0;HEAP32[$words$i+16>>2]=0|0;HEAP32[$words$i+20>>2]=0|0;HEAP32[$words$i+24>>2]=0|0;HEAP32[$words$i+28>>2]=0|0;
 $prevNumUniqueHashes$06 = 0;$prevShift$04 = 0;$shift$05 = 2;
 while(1) {
  $i$01$i = 0;$numUniqueHashes$02$i = 0;
  while(1) {
   $10 = (($4) + ($i$01$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $11;
   $13 = $12 >>> $shift$05;
   $14 = $13 >>> 5;
   $15 = $14 & 7;
   $16 = (($words$i) + ($15<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $13 & 31;
   $19 = 1 << $18;
   $20 = $19 & $17;
   $21 = ($20|0)==(0);
   if ($21) {
    $22 = $19 | $17;
    HEAP32[$16>>2] = $22;
    $23 = (($numUniqueHashes$02$i) + 1)|0;
    $numUniqueHashes$1$i = $23;
   } else {
    $numUniqueHashes$1$i = $numUniqueHashes$02$i;
   }
   $24 = (($i$01$i) + 1)|0;
   $25 = ($24>>>0)<($1>>>0);
   if ($25) {
    $i$01$i = $24;$numUniqueHashes$02$i = $numUniqueHashes$1$i;
   } else {
    break;
   }
  }
  $26 = ($numUniqueHashes$1$i>>>0)>($prevNumUniqueHashes$06>>>0);
  $27 = ($numUniqueHashes$1$i|0)==($1|0);
  if (!($26)) {
   label = 11;
   break;
  }
  if ($27) {
   label = 10;
   break;
  }
  $9 = $shift$05 << 1;
  ;HEAP32[$words$i+0>>2]=0|0;HEAP32[$words$i+4>>2]=0|0;HEAP32[$words$i+8>>2]=0|0;HEAP32[$words$i+12>>2]=0|0;HEAP32[$words$i+16>>2]=0|0;HEAP32[$words$i+20>>2]=0|0;HEAP32[$words$i+24>>2]=0|0;HEAP32[$words$i+28>>2]=0|0;
  $prevShift$04$phi = $shift$05;$prevNumUniqueHashes$06 = $numUniqueHashes$1$i;$shift$05 = $9;$prevShift$04 = $prevShift$04$phi;
 }
 if ((label|0) == 10) {
  $28 = (($this) + 2060|0);
  $45 = $28;
  label = 12;
 }
 else if ((label|0) == 11) {
  $29 = (($this) + 2060|0);
  if ($27) {
   $45 = $29;
   label = 12;
  } else {
   $30 = $29;$storemerge = $prevShift$04;
  }
 }
 if ((label|0) == 12) {
  $30 = $45;$storemerge = $shift$05;
 }
 HEAP32[$30>>2] = $storemerge;
 $31 = ($1|0)==(0);
 if ($31) {
  STACKTOP = sp;return;
 } else {
  $33 = $4;$37 = $storemerge;$i2$02 = 0;
 }
 while(1) {
  $32 = (($33) + ($i2$02<<2)|0);
  $34 = HEAP32[$32>>2]|0;
  $35 = $34;
  $36 = $35 >>> $37;
  $38 = $36 & 255;
  $39 = ((($this) + ($38<<2)|0) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ((($this) + ($i2$02<<2)|0) + 1036|0);
  HEAP32[$41>>2] = $40;
  HEAP32[$39>>2] = $i2$02;
  $42 = (($i2$02) + 1)|0;
  $43 = HEAP32[$this>>2]|0;
  $44 = ($42>>>0)<($43>>>0);
  if (!($44)) {
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $$pre18 = HEAP32[$30>>2]|0;
  $33 = $$pre;$37 = $$pre18;$i2$02 = $42;
 }
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsSimData8allocateEj($numWheels) {
 $numWheels = $numWheels|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $exitcond9 = 0, $i$05 = 0, $i1$02 = 0, $i2$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = (($numWheels) + 3)|0;
 $4 = $3 >>> 2;
 $5 = ($4*944)|0;
 $6 = (($5) + 64)|0;
 $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$6,524040,66)|0);
 $8 = (($7) + 64|0);
 $9 = (($7) + 32|0);
 HEAP32[$9>>2] = $8;
 $10 = (($7) + 36|0);
 HEAP32[$10>>2] = $4;
 $11 = (($7) + 40|0);
 HEAP32[$11>>2] = $numWheels;
 $12 = ($4|0)==(0);
 L1: do {
  if (!($12)) {
   $14 = $8;$i$05 = 0;
   while(1) {
    $13 = (($14) + (($i$05*944)|0)|0);
    $15 = ($13|0)==(0|0);
    if (!($15)) {
     __ZN5physx23PxVehicleWheels4SimDataC2Ev($13);
    }
    $16 = (($i$05) + 1)|0;
    $17 = ($16>>>0)<($4>>>0);
    if (!($17)) {
     break L1;
    }
    $$pre = HEAP32[$9>>2]|0;
    $14 = $$pre;$i$05 = $16;
   }
  }
 } while(0);
 $18 = ($7|0)==(0|0);
 if (!($18)) {
  HEAPF32[$7>>2] = Math_fround(0.0);
  $19 = (($7) + 4|0);
  HEAPF32[$19>>2] = Math_fround(0.230800002813339233398);
  $20 = (($7) + 8|0);
  HEAPF32[$20>>2] = Math_fround(3.0);
  $21 = (($7) + 12|0);
  HEAPF32[$21>>2] = Math_fround(3.0);
  $22 = (($7) + 16|0);
  HEAPF32[$22>>2] = Math_fround(0.333333343267440795898);
 }
 $23 = (($7) + 44|0);
 HEAP8[$23>>0]=0&255;HEAP8[$23+1>>0]=(0>>8)&255;HEAP8[$23+2>>0]=(0>>16)&255;HEAP8[$23+3>>0]=0>>24;
 $24 = ($numWheels|0)==(0);
 if (!($24)) {
  $i1$02 = 0;
  while(1) {
   $28 = $i1$02 & 31;
   $29 = 1 << $28;
   $30 = $i1$02 >>> 5;
   $31 = ((($7) + ($30<<2)|0) + 44|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = $32 | $29;
   HEAP32[$31>>2] = $33;
   $34 = $i1$02 >>> 2;
   $35 = HEAP32[$9>>2]|0;
   $36 = (($35) + (($34*944)|0)|0);
   $37 = $i1$02 & 3;
   __ZN5physx23PxVehicleWheels4SimData20setWheelShapeMappingEji($36,$37,$i1$02);
   ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
   $38 = HEAP32[$9>>2]|0;
   $39 = (($38) + (($34*944)|0)|0);
   __ZN5physx23PxVehicleWheels4SimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($39,$37,$1);
   $40 = (($i1$02) + 1)|0;
   $exitcond9 = ($40|0)==($numWheels|0);
   if ($exitcond9) {
    break;
   } else {
    $i1$02 = $40;
   }
  }
 }
 $25 = $4 << 2;
 $26 = ($25>>>0)>($numWheels>>>0);
 if (!($26)) {
  $55 = (($7) + 48|0);
  HEAPF32[$55>>2] = Math_fround(5.0);
  $56 = (($7) + 52|0);
  HEAP32[$56>>2] = 3;
  $57 = (($7) + 56|0);
  HEAP32[$57>>2] = 1;
  $58 = (($7) + 60|0);
  HEAPF32[$58>>2] = Math_fround(4.0);
  STACKTOP = sp;return ($7|0);
 }
 $27 = $4 << 2;
 $i2$01 = $numWheels;
 while(1) {
  $41 = $i2$01 & 31;
  $42 = 1 << $41;
  $43 = $42 ^ -1;
  $44 = $i2$01 >>> 5;
  $45 = ((($7) + ($44<<2)|0) + 44|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46 & $43;
  HEAP32[$45>>2] = $47;
  $48 = $i2$01 >>> 2;
  $49 = HEAP32[$9>>2]|0;
  $50 = (($49) + (($48*944)|0)|0);
  $51 = $i2$01 & 3;
  __ZN5physx23PxVehicleWheels4SimData20setWheelShapeMappingEji($50,$51,-1);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
  $52 = HEAP32[$9>>2]|0;
  $53 = (($52) + (($48*944)|0)|0);
  __ZN5physx23PxVehicleWheels4SimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($53,$51,$2);
  $54 = (($i2$01) + 1)|0;
  $exitcond = ($54|0)==($27|0);
  if ($exitcond) {
   break;
  } else {
   $i2$01 = $54;
  }
 }
 $55 = (($7) + 48|0);
 HEAPF32[$55>>2] = Math_fround(5.0);
 $56 = (($7) + 52|0);
 HEAP32[$56>>2] = 3;
 $57 = (($7) + 56|0);
 HEAP32[$57>>2] = 1;
 $58 = (($7) + 60|0);
 HEAPF32[$58>>2] = Math_fround(4.0);
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx22PxVehicleWheelsSimData20setWheelShapeMappingEji($this,$id,$shapeId) {
 $this = $this|0;
 $id = $id|0;
 $shapeId = $shapeId|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData20setWheelShapeMappingEji($3,$4,$shapeId);
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsSimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($this,$id,$sqFilterData) {
 $this = $this|0;
 $id = $id|0;
 $sqFilterData = $sqFilterData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($3,$4,$sqFilterData);
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsSimData14setChassisMassEf($this,$chassisMass) {
 $this = $this|0;
 $chassisMass = Math_fround($chassisMass);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0);
 var $i$01 = 0, $susp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $susp = sp;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (Math_fround(($1>>>0)));
 $3 = Math_fround(Math_fround(1.0) / $2);
 $4 = Math_fround($3 * $chassisMass);
 $5 = ($1|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 32|0);
 $7 = (($susp) + 16|0);
 $8 = Math_fround($4 * Math_fround(93.3155975341796875));
 $9 = Math_fround($4 * Math_fround(1.24000000953674316406));
 $10 = Math_fround($9 * Math_fround(9.659999847412109375));
 $11 = (($susp) + 4|0);
 $i$01 = 0;
 while(1) {
  $12 = $i$01 >>> 2;
  $13 = HEAP32[$6>>2]|0;
  $14 = $i$01 & 3;
  $15 = ((($13) + (($12*944)|0)|0) + (($14*48)|0)|0);
  dest=$susp+0|0; src=$15+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  HEAPF32[$7>>2] = $4;
  HEAPF32[$susp>>2] = $8;
  HEAPF32[$11>>2] = $10;
  $16 = (($13) + (($12*944)|0)|0);
  __ZN5physx23PxVehicleWheels4SimData17setSuspensionDataEjRKNS_23PxVehicleSuspensionDataE($16,$14,$susp);
  $17 = (($i$01) + 1)|0;
  $18 = HEAP32[$0>>2]|0;
  $19 = ($17>>>0)<($18>>>0);
  if ($19) {
   $i$01 = $17;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsSimData17getSuspensionDataEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = ((($2) + (($0*944)|0)|0) + (($3*48)|0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx22PxVehicleWheelsSimData17setSuspensionDataEjRKNS_23PxVehicleSuspensionDataE($this,$id,$susp) {
 $this = $this|0;
 $id = $id|0;
 $susp = $susp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData17setSuspensionDataEjRKNS_23PxVehicleSuspensionDataE($3,$4,$susp);
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsSimData4freeEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsSimDataaSERKS0_($this,$src) {
 $this = $this|0;
 $src = $src|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0);
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0;
 var $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0;
 var $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0;
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0;
 var $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $i$01 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($src) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  ;HEAP32[$this+0>>2]=HEAP32[$src+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$src+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$src+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$src+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$src+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$src+20>>2]|0;HEAP32[$this+24>>2]=HEAP32[$src+24>>2]|0;HEAP32[$this+28>>2]=HEAP32[$src+28>>2]|0;
  $158 = (($src) + 48|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = (($this) + 48|0);
  HEAPF32[$160>>2] = $159;
  $161 = (($src) + 52|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = (($this) + 52|0);
  HEAP32[$163>>2] = $162;
  $164 = (($src) + 56|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = (($this) + 56|0);
  HEAP32[$166>>2] = $165;
  $167 = (($src) + 60|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($this) + 60|0);
  HEAPF32[$169>>2] = $168;
  $170 = (($this) + 44|0);
  $171 = (($src) + 44|0);
  $172 = HEAPU8[$171>>0]|(HEAPU8[$171+1>>0]<<8)|(HEAPU8[$171+2>>0]<<16)|(HEAPU8[$171+3>>0]<<24);
  HEAP8[$170>>0]=$172&255;HEAP8[$170+1>>0]=($172>>8)&255;HEAP8[$170+2>>0]=($172>>16)&255;HEAP8[$170+3>>0]=$172>>24;
  STACKTOP = sp;return ($this|0);
 }
 $3 = (($this) + 32|0);
 $4 = (($src) + 32|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + (($i$01*944)|0)|0);
  $7 = HEAP32[$4>>2]|0;
  $8 = (($7) + (($i$01*944)|0)|0);
  _memcpy(($6|0),($8|0),640)|0;
  $9 = ((($7) + (($i$01*944)|0)|0) + 640|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = ((($5) + (($i$01*944)|0)|0) + 640|0);
  HEAPF32[$11>>2] = $10;
  $12 = ((($7) + (($i$01*944)|0)|0) + 644|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = ((($5) + (($i$01*944)|0)|0) + 644|0);
  HEAPF32[$14>>2] = $13;
  $15 = ((($7) + (($i$01*944)|0)|0) + 648|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = ((($5) + (($i$01*944)|0)|0) + 648|0);
  HEAPF32[$17>>2] = $16;
  $18 = ((($7) + (($i$01*944)|0)|0) + 652|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = ((($5) + (($i$01*944)|0)|0) + 652|0);
  HEAPF32[$20>>2] = $19;
  $21 = ((($7) + (($i$01*944)|0)|0) + 656|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = ((($5) + (($i$01*944)|0)|0) + 656|0);
  HEAPF32[$23>>2] = $22;
  $24 = ((($7) + (($i$01*944)|0)|0) + 660|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($5) + (($i$01*944)|0)|0) + 660|0);
  HEAPF32[$26>>2] = $25;
  $27 = ((($7) + (($i$01*944)|0)|0) + 664|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = ((($5) + (($i$01*944)|0)|0) + 664|0);
  HEAPF32[$29>>2] = $28;
  $30 = ((($7) + (($i$01*944)|0)|0) + 668|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = ((($5) + (($i$01*944)|0)|0) + 668|0);
  HEAPF32[$32>>2] = $31;
  $33 = ((($7) + (($i$01*944)|0)|0) + 672|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = ((($5) + (($i$01*944)|0)|0) + 672|0);
  HEAPF32[$35>>2] = $34;
  $36 = ((($7) + (($i$01*944)|0)|0) + 676|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = ((($5) + (($i$01*944)|0)|0) + 676|0);
  HEAPF32[$38>>2] = $37;
  $39 = ((($7) + (($i$01*944)|0)|0) + 680|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = ((($5) + (($i$01*944)|0)|0) + 680|0);
  HEAPF32[$41>>2] = $40;
  $42 = ((($7) + (($i$01*944)|0)|0) + 684|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = ((($5) + (($i$01*944)|0)|0) + 684|0);
  HEAPF32[$44>>2] = $43;
  $45 = ((($7) + (($i$01*944)|0)|0) + 688|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = ((($5) + (($i$01*944)|0)|0) + 688|0);
  HEAPF32[$47>>2] = $46;
  $48 = ((($7) + (($i$01*944)|0)|0) + 692|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = ((($5) + (($i$01*944)|0)|0) + 692|0);
  HEAPF32[$50>>2] = $49;
  $51 = ((($7) + (($i$01*944)|0)|0) + 696|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = ((($5) + (($i$01*944)|0)|0) + 696|0);
  HEAPF32[$53>>2] = $52;
  $54 = ((($7) + (($i$01*944)|0)|0) + 700|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = ((($5) + (($i$01*944)|0)|0) + 700|0);
  HEAPF32[$56>>2] = $55;
  $57 = ((($7) + (($i$01*944)|0)|0) + 704|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = ((($5) + (($i$01*944)|0)|0) + 704|0);
  HEAPF32[$59>>2] = $58;
  $60 = ((($7) + (($i$01*944)|0)|0) + 708|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = ((($5) + (($i$01*944)|0)|0) + 708|0);
  HEAPF32[$62>>2] = $61;
  $63 = ((($7) + (($i$01*944)|0)|0) + 712|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = ((($5) + (($i$01*944)|0)|0) + 712|0);
  HEAPF32[$65>>2] = $64;
  $66 = ((($7) + (($i$01*944)|0)|0) + 716|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($5) + (($i$01*944)|0)|0) + 716|0);
  HEAPF32[$68>>2] = $67;
  $69 = ((($7) + (($i$01*944)|0)|0) + 720|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = ((($5) + (($i$01*944)|0)|0) + 720|0);
  HEAPF32[$71>>2] = $70;
  $72 = ((($7) + (($i$01*944)|0)|0) + 724|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = ((($5) + (($i$01*944)|0)|0) + 724|0);
  HEAPF32[$74>>2] = $73;
  $75 = ((($7) + (($i$01*944)|0)|0) + 728|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = ((($5) + (($i$01*944)|0)|0) + 728|0);
  HEAPF32[$77>>2] = $76;
  $78 = ((($7) + (($i$01*944)|0)|0) + 732|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = ((($5) + (($i$01*944)|0)|0) + 732|0);
  HEAPF32[$80>>2] = $79;
  $81 = ((($7) + (($i$01*944)|0)|0) + 736|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = ((($5) + (($i$01*944)|0)|0) + 736|0);
  HEAPF32[$83>>2] = $82;
  $84 = ((($7) + (($i$01*944)|0)|0) + 740|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = ((($5) + (($i$01*944)|0)|0) + 740|0);
  HEAPF32[$86>>2] = $85;
  $87 = ((($7) + (($i$01*944)|0)|0) + 744|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = ((($5) + (($i$01*944)|0)|0) + 744|0);
  HEAPF32[$89>>2] = $88;
  $90 = ((($7) + (($i$01*944)|0)|0) + 748|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = ((($5) + (($i$01*944)|0)|0) + 748|0);
  HEAPF32[$92>>2] = $91;
  $93 = ((($7) + (($i$01*944)|0)|0) + 752|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = ((($5) + (($i$01*944)|0)|0) + 752|0);
  HEAPF32[$95>>2] = $94;
  $96 = ((($7) + (($i$01*944)|0)|0) + 756|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = ((($5) + (($i$01*944)|0)|0) + 756|0);
  HEAPF32[$98>>2] = $97;
  $99 = ((($7) + (($i$01*944)|0)|0) + 760|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = ((($5) + (($i$01*944)|0)|0) + 760|0);
  HEAPF32[$101>>2] = $100;
  $102 = ((($7) + (($i$01*944)|0)|0) + 764|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = ((($5) + (($i$01*944)|0)|0) + 764|0);
  HEAPF32[$104>>2] = $103;
  $105 = ((($7) + (($i$01*944)|0)|0) + 768|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = ((($5) + (($i$01*944)|0)|0) + 768|0);
  HEAPF32[$107>>2] = $106;
  $108 = ((($7) + (($i$01*944)|0)|0) + 772|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = ((($5) + (($i$01*944)|0)|0) + 772|0);
  HEAPF32[$110>>2] = $109;
  $111 = ((($7) + (($i$01*944)|0)|0) + 776|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = ((($5) + (($i$01*944)|0)|0) + 776|0);
  HEAPF32[$113>>2] = $112;
  $114 = ((($7) + (($i$01*944)|0)|0) + 780|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = ((($5) + (($i$01*944)|0)|0) + 780|0);
  HEAPF32[$116>>2] = $115;
  $117 = ((($7) + (($i$01*944)|0)|0) + 784|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = ((($5) + (($i$01*944)|0)|0) + 784|0);
  HEAPF32[$119>>2] = $118;
  $120 = ((($7) + (($i$01*944)|0)|0) + 788|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = ((($5) + (($i$01*944)|0)|0) + 788|0);
  HEAPF32[$122>>2] = $121;
  $123 = ((($7) + (($i$01*944)|0)|0) + 792|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = ((($5) + (($i$01*944)|0)|0) + 792|0);
  HEAPF32[$125>>2] = $124;
  $126 = ((($7) + (($i$01*944)|0)|0) + 796|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = ((($5) + (($i$01*944)|0)|0) + 796|0);
  HEAPF32[$128>>2] = $127;
  $129 = ((($7) + (($i$01*944)|0)|0) + 800|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = ((($5) + (($i$01*944)|0)|0) + 800|0);
  HEAPF32[$131>>2] = $130;
  $132 = ((($7) + (($i$01*944)|0)|0) + 804|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = ((($5) + (($i$01*944)|0)|0) + 804|0);
  HEAPF32[$134>>2] = $133;
  $135 = ((($7) + (($i$01*944)|0)|0) + 808|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = ((($5) + (($i$01*944)|0)|0) + 808|0);
  HEAPF32[$137>>2] = $136;
  $138 = ((($7) + (($i$01*944)|0)|0) + 812|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = ((($5) + (($i$01*944)|0)|0) + 812|0);
  HEAPF32[$140>>2] = $139;
  $141 = ((($7) + (($i$01*944)|0)|0) + 816|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = ((($5) + (($i$01*944)|0)|0) + 816|0);
  HEAPF32[$143>>2] = $142;
  $144 = ((($7) + (($i$01*944)|0)|0) + 820|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = ((($5) + (($i$01*944)|0)|0) + 820|0);
  HEAPF32[$146>>2] = $145;
  $147 = ((($7) + (($i$01*944)|0)|0) + 824|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = ((($5) + (($i$01*944)|0)|0) + 824|0);
  HEAPF32[$149>>2] = $148;
  $150 = ((($7) + (($i$01*944)|0)|0) + 828|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = ((($5) + (($i$01*944)|0)|0) + 828|0);
  HEAPF32[$152>>2] = $151;
  $153 = ((($5) + (($i$01*944)|0)|0) + 832|0);
  $154 = ((($7) + (($i$01*944)|0)|0) + 832|0);
  dest=$153+0|0; src=$154+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $155 = (($i$01) + 1)|0;
  $156 = HEAP32[$0>>2]|0;
  $157 = ($155>>>0)<($156>>>0);
  if ($157) {
   $i$01 = $155;
  } else {
   break;
  }
 }
 ;HEAP32[$this+0>>2]=HEAP32[$src+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$src+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$src+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$src+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$src+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$src+20>>2]|0;HEAP32[$this+24>>2]=HEAP32[$src+24>>2]|0;HEAP32[$this+28>>2]=HEAP32[$src+28>>2]|0;
 $158 = (($src) + 48|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($this) + 48|0);
 HEAPF32[$160>>2] = $159;
 $161 = (($src) + 52|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = (($this) + 52|0);
 HEAP32[$163>>2] = $162;
 $164 = (($src) + 56|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = (($this) + 56|0);
 HEAP32[$166>>2] = $165;
 $167 = (($src) + 60|0);
 $168 = Math_fround(HEAPF32[$167>>2]);
 $169 = (($this) + 60|0);
 HEAPF32[$169>>2] = $168;
 $170 = (($this) + 44|0);
 $171 = (($src) + 44|0);
 $172 = HEAPU8[$171>>0]|(HEAPU8[$171+1>>0]<<8)|(HEAPU8[$171+2>>0]<<16)|(HEAPU8[$171+3>>0]<<24);
 HEAP8[$170>>0]=$172&255;HEAP8[$170+1>>0]=($172>>8)&255;HEAP8[$170+2>>0]=($172>>16)&255;HEAP8[$170+3>>0]=$172>>24;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx22PxVehicleWheelsSimData12setWheelDataEjRKNS_18PxVehicleWheelDataE($this,$id,$wheel) {
 $this = $this|0;
 $id = $id|0;
 $wheel = $wheel|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData12setWheelDataEjRKNS_18PxVehicleWheelDataE($3,$4,$wheel);
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsSimData12getWheelDataEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = (((($2) + (($0*944)|0)|0) + (($3*48)|0)|0) + 192|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx22PxVehicleWheelsSimData11setTireDataEjRKNS_17PxVehicleTireDataE($this,$id,$tire) {
 $this = $this|0;
 $id = $id|0;
 $tire = $tire|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData11setTireDataEjRKNS_17PxVehicleTireDataE($3,$4,$tire);
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsSimData11getTireDataEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = (((($2) + (($0*944)|0)|0) + ($3<<6)|0) + 384|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx22PxVehicleWheelsSimData22setSuspTravelDirectionEjRKNS_6PxVec3E($this,$id,$dir) {
 $this = $this|0;
 $id = $id|0;
 $dir = $dir|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData22setSuspTravelDirectionEjRKNS_6PxVec3E($3,$4,$dir);
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsSimData22getSuspTravelDirectionEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = (((($2) + (($0*944)|0)|0) + (($3*12)|0)|0) + 640|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx22PxVehicleWheelsSimData26setSuspForceAppPointOffsetEjRKNS_6PxVec3E($this,$id,$offset) {
 $this = $this|0;
 $id = $id|0;
 $offset = $offset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData26setSuspForceAppPointOffsetEjRKNS_6PxVec3E($3,$4,$offset);
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsSimData26getSuspForceAppPointOffsetEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = (((($2) + (($0*944)|0)|0) + (($3*12)|0)|0) + 688|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx22PxVehicleWheelsSimData26setTireForceAppPointOffsetEjRKNS_6PxVec3E($this,$id,$offset) {
 $this = $this|0;
 $id = $id|0;
 $offset = $offset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData26setTireForceAppPointOffsetEjRKNS_6PxVec3E($3,$4,$offset);
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsSimData26getTireForceAppPointOffsetEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = (((($2) + (($0*944)|0)|0) + (($3*12)|0)|0) + 736|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx22PxVehicleWheelsSimData20setWheelCentreOffsetEjRKNS_6PxVec3E($this,$id,$offset) {
 $this = $this|0;
 $id = $id|0;
 $offset = $offset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($0*944)|0)|0);
 $4 = $id & 3;
 __ZN5physx23PxVehicleWheels4SimData20setWheelCentreOffsetEjRKNS_6PxVec3E($3,$4,$offset);
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsSimData20getWheelCentreOffsetEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = (((($2) + (($0*944)|0)|0) + (($3*12)|0)|0) + 784|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx22PxVehicleWheelsSimData20getWheelShapeMappingEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $$$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = (((($2) + (($0*944)|0)|0) + ($3)|0) + 928|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(-1);
 $7 = $5&255;
 $$$i = $6 ? -1 : $7;
 STACKTOP = sp;return ($$$i|0);
}
function __ZNK5physx22PxVehicleWheelsSimData23getSceneQueryFilterDataEj($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $id >>> 2;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $id & 3;
 $4 = (((($2) + (($0*944)|0)|0) + ($3<<4)|0) + 864|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx22PxVehicleWheelsSimData18getIsWheelDisabledEj($this,$wheel) {
 $this = $this|0;
 $wheel = $wheel|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wheel >>> 5;
 $1 = ((($this) + ($0<<2)|0) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $wheel & 31;
 $4 = 1 << $3;
 $5 = $2 & $4;
 $not$ = ($5|0)==(0);
 STACKTOP = sp;return ($not$|0);
}
function __ZN5physx22PxVehicleWheelsSimData21setTireLoadFilterDataERKNS_27PxVehicleTireLoadFilterDataE($this,$tireLoadFilter) {
 $this = $this|0;
 $tireLoadFilter = $tireLoadFilter|0;
 var $0 = 0, $1 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=HEAP32[$tireLoadFilter+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$tireLoadFilter+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$tireLoadFilter+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$tireLoadFilter+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$tireLoadFilter+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$tireLoadFilter+20>>2]|0;HEAP32[$this+24>>2]=HEAP32[$tireLoadFilter+24>>2]|0;HEAP32[$this+28>>2]=HEAP32[$tireLoadFilter+28>>2]|0;
 $0 = (($this) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$this>>2]);
 $3 = Math_fround($1 - $2);
 $4 = Math_fround(Math_fround(1.0) / $3);
 $5 = (($this) + 16|0);
 HEAPF32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsSimData25setMinLongSlipDenominatorEf($this,$minLongSlipDenominator) {
 $this = $this|0;
 $minLongSlipDenominator = Math_fround($minLongSlipDenominator);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 HEAPF32[$0>>2] = $minLongSlipDenominator;
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsDynData26setTireForceShaderFunctionEPFvPKvffffffffffffRfS3_S3_S3_E($this,$tireForceShaderFn) {
 $this = $this|0;
 $tireForceShaderFn = $tireForceShaderFn|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = $tireForceShaderFn;
 STACKTOP = sp;return;
}
function __ZN5physx22PxVehicleWheelsDynData21setWheelRotationSpeedEjf($this,$wheelIdx,$speed) {
 $this = $this|0;
 $wheelIdx = $wheelIdx|0;
 $speed = Math_fround($speed);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wheelIdx >>> 2;
 $1 = HEAP32[$this>>2]|0;
 $2 = $wheelIdx & 3;
 $3 = ((($1) + (($0*208)|0)|0) + ($2<<2)|0);
 HEAPF32[$3>>2] = $speed;
 $4 = (((($1) + (($0*208)|0)|0) + ($2<<2)|0) + 16|0);
 HEAPF32[$4>>2] = $speed;
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsDynData21getWheelRotationSpeedEj($this,$wheelIdx) {
 $this = $this|0;
 $wheelIdx = $wheelIdx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wheelIdx >>> 2;
 $1 = HEAP32[$this>>2]|0;
 $2 = $wheelIdx & 3;
 $3 = (((($1) + (($0*208)|0)|0) + ($2<<2)|0) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 STACKTOP = sp;return (Math_fround($4));
}
function __ZN5physx22PxVehicleWheelsDynData21setWheelRotationAngleEjf($this,$wheelIdx,$angle) {
 $this = $this|0;
 $wheelIdx = $wheelIdx|0;
 $angle = Math_fround($angle);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wheelIdx >>> 2;
 $1 = HEAP32[$this>>2]|0;
 $2 = $wheelIdx & 3;
 $3 = (((($1) + (($0*208)|0)|0) + ($2<<2)|0) + 32|0);
 HEAPF32[$3>>2] = $angle;
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsDynData21getWheelRotationAngleEj($this,$wheelIdx) {
 $this = $this|0;
 $wheelIdx = $wheelIdx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $wheelIdx >>> 2;
 $1 = HEAP32[$this>>2]|0;
 $2 = $wheelIdx & 3;
 $3 = (((($1) + (($0*208)|0)|0) + ($2<<2)|0) + 32|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 STACKTOP = sp;return (Math_fround($4));
}
function __ZN5physx15PxVehicleWheels15computeByteSizeEj($numWheels4) {
 $numWheels4 = $numWheels4|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $factor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numWheels4*1152)|0;
 $1 = $0 | 16;
 $2 = ($numWheels4*368)|0;
 $factor = $numWheels4 << 5;
 $3 = (($1) + ($2))|0;
 $4 = (($3) + ($factor))|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx15PxVehicleWheels15patchupPointersEPS0_Phjjb($veh,$ptrIn,$numWheels4,$numWheels,$renew) {
 $veh = $veh|0;
 $ptrIn = $ptrIn|0;
 $numWheels4 = $numWheels4|0;
 $numWheels = $numWheels|0;
 $renew = $renew|0;
 var $$sum = 0, $$sum12 = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $exitcond = 0, $exitcond28 = 0, $exitcond29 = 0, $exitcond30 = 0, $exitcond31 = 0;
 var $exitcond32 = 0, $exitcond33 = 0, $exitcond34 = 0, $i$023 = 0, $i1$021 = 0, $i2$018 = 0, $i3$015 = 0, $i4$012 = 0, $i5$08 = 0, $i6$06 = 0, $i6$06$us = 0, $ptr$024 = 0, $tmp5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($veh) + 44|0);
 HEAP32[$2>>2] = $numWheels4;
 $3 = (($veh) + 84|0);
 HEAP32[$3>>2] = $numWheels4;
 $4 = (($veh) + 48|0);
 HEAP32[$4>>2] = $numWheels;
 $5 = (($veh) + 64|0);
 HEAP32[$5>>2] = 1;
 $6 = (($veh) + 60|0);
 HEAP32[$6>>2] = 3;
 $7 = (($veh) + 56|0);
 HEAPF32[$7>>2] = Math_fround(5.0);
 $8 = (($veh) + 88|0);
 HEAP32[$8>>2] = $numWheels;
 $9 = $numWheels4&255;
 $10 = (($veh) + 112|0);
 HEAP8[$10>>0] = $9;
 $11 = (($veh) + 40|0);
 HEAP32[$11>>2] = $ptrIn;
 $12 = ($numWheels4*944)|0;
 $13 = (($ptrIn) + ($12)|0);
 $14 = (($veh) + 72|0);
 HEAP32[$14>>2] = $13;
 $$sum = ($numWheels4*1152)|0;
 $15 = (($ptrIn) + ($$sum)|0);
 $16 = (($veh) + 76|0);
 HEAP32[$16>>2] = $15;
 $$sum12 = $$sum | 16;
 $17 = (($ptrIn) + ($$sum12)|0);
 HEAP32[$15>>2] = $17;
 $18 = $numWheels4 << 4;
 $$sum3 = (($$sum12) + ($18))|0;
 $19 = (($ptrIn) + ($$sum3)|0);
 $20 = (($veh) + 80|0);
 HEAP32[$20>>2] = $19;
 $21 = ($numWheels4|0)==(0);
 if (!($21)) {
  $$sum4 = (($$sum3) + ($18))|0;
  $22 = (($ptrIn) + ($$sum4)|0);
  $i$023 = 0;$ptr$024 = $22;
  while(1) {
   $23 = HEAP32[$14>>2]|0;
   $24 = ((($23) + (($i$023*208)|0)|0) + 192|0);
   HEAP32[$24>>2] = $ptr$024;
   $25 = (($ptr$024) + 368|0);
   $26 = (($i$023) + 1)|0;
   $exitcond33 = ($26|0)==($numWheels4|0);
   if ($exitcond33) {
    break;
   } else {
    $i$023 = $26;$ptr$024 = $25;
   }
  }
 }
 if ($renew) {
  if ($21) {
   label = 10;
  } else {
   $i1$021 = 0;
   while(1) {
    $27 = HEAP32[$11>>2]|0;
    $28 = (($27) + (($i1$021*944)|0)|0);
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     __ZN5physx23PxVehicleWheels4SimDataC2Ev($28);
    }
    $30 = (($i1$021) + 1)|0;
    $exitcond32 = ($30|0)==($numWheels4|0);
    if ($exitcond32) {
     break;
    } else {
     $i1$021 = $30;
    }
   }
   if ($21) {
    label = 10;
   } else {
    $i2$018 = 0;
    while(1) {
     $35 = HEAP32[$14>>2]|0;
     $36 = (($35) + (($i2$018*208)|0)|0);
     $37 = ($36|0)==(0|0);
     if (!($37)) {
      $38 = ((($35) + (($i2$018*208)|0)|0) + 196|0);
      HEAP32[$38>>2] = 0;
      $39 = ((($35) + (($i2$018*208)|0)|0) + 200|0);
      HEAP8[$39>>0] = 0;
      _memset(($36|0),0,192)|0;
     }
     $40 = (($i2$018) + 1)|0;
     $exitcond31 = ($40|0)==($numWheels4|0);
     if ($exitcond31) {
      break;
     } else {
      $i2$018 = $40;
     }
    }
    $32 = $numWheels4 << 2;
    $33 = ($32|0)==(0);
    if ($33) {
     $49 = 0;
    } else {
     $34 = $numWheels4 << 2;
     $i3$015 = 0;
     while(1) {
      $42 = HEAP32[$16>>2]|0;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($43) + ($i3$015<<2)|0);
      HEAP32[$44>>2] = 0;
      $45 = HEAP32[$20>>2]|0;
      $46 = (($45) + ($i3$015<<2)|0);
      HEAP32[$46>>2] = 0;
      $47 = (($i3$015) + 1)|0;
      $exitcond30 = ($47|0)==($34|0);
      if ($exitcond30) {
       $49 = $32;
       break;
      } else {
       $i3$015 = $47;
      }
     }
    }
   }
  }
  if ((label|0) == 10) {
   $31 = $numWheels4 << 2;
   $49 = $31;
  }
  $41 = ($numWheels|0)==(0);
  if (!($41)) {
   $i4$012 = 0;
   while(1) {
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    $51 = $i4$012 >>> 2;
    $52 = HEAP32[$11>>2]|0;
    $53 = (($52) + (($51*944)|0)|0);
    $54 = $i4$012 & 3;
    __ZN5physx23PxVehicleWheels4SimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($53,$54,$0);
    $55 = HEAP32[$11>>2]|0;
    $56 = (($55) + (($51*944)|0)|0);
    __ZN5physx23PxVehicleWheels4SimData20setWheelShapeMappingEji($56,$54,$i4$012);
    $57 = (($i4$012) + 1)|0;
    $exitcond29 = ($57|0)==($numWheels|0);
    if ($exitcond29) {
     break;
    } else {
     $i4$012 = $57;
    }
   }
  }
  $48 = ($49>>>0)>($numWheels>>>0);
  if ($48) {
   $50 = $numWheels4 << 2;
   $i5$08 = $numWheels;
   while(1) {
    ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
    $58 = $i5$08 >>> 2;
    $59 = HEAP32[$11>>2]|0;
    $60 = (($59) + (($58*944)|0)|0);
    $61 = $i5$08 & 3;
    __ZN5physx23PxVehicleWheels4SimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($60,$61,$1);
    $62 = HEAP32[$11>>2]|0;
    $63 = (($62) + (($58*944)|0)|0);
    __ZN5physx23PxVehicleWheels4SimData20setWheelShapeMappingEji($63,$61,-1);
    $64 = (($i5$08) + 1)|0;
    $exitcond28 = ($64|0)==($50|0);
    if ($exitcond28) {
     break;
    } else {
     $i5$08 = $64;
    }
   }
  }
  $65 = (($veh) + 8|0);
  HEAPF32[$65>>2] = Math_fround(0.0);
  $66 = (($veh) + 12|0);
  HEAPF32[$66>>2] = Math_fround(0.230800002813339233398);
  $67 = (($veh) + 16|0);
  HEAPF32[$67>>2] = Math_fround(3.0);
  $68 = (($veh) + 20|0);
  HEAPF32[$68>>2] = Math_fround(3.0);
  $69 = (($veh) + 24|0);
  HEAPF32[$69>>2] = Math_fround(0.333333343267440795898);
 }
 if (!($21)) {
  if ($renew) {
   $i6$06$us = 0;
   while(1) {
    $70 = HEAP32[$14>>2]|0;
    $71 = ((($70) + (($i6$06$us*208)|0)|0) + 192|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==(0|0);
    if (!($73)) {
     HEAP32[$72>>2] = ((524152 + 8|0));
     $74 = (($72) + 352|0);
     HEAP32[$74>>2] = 0;
     $75 = (($72) + 356|0);
     HEAP32[$75>>2] = $veh;
    }
    $76 = (($i6$06$us) + 1)|0;
    $exitcond34 = ($76|0)==($numWheels4|0);
    if ($exitcond34) {
     break;
    } else {
     $i6$06$us = $76;
    }
   }
  } else {
   $i6$06 = 0;
   while(1) {
    $77 = HEAP32[$14>>2]|0;
    $78 = ((($77) + (($i6$06*208)|0)|0) + 192|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($79|0)==(0|0);
    if (!($80)) {
     $81 = (($79) + 352|0);
     $82 = HEAP32[$81>>2]|0;
     HEAP32[$79>>2] = ((524152 + 8|0));
     $83 = (($79) + 352|0);
     HEAP32[$83>>2] = $82;
     $84 = (($79) + 356|0);
     HEAP32[$84>>2] = $veh;
    }
    $85 = (($i6$06) + 1)|0;
    $exitcond = ($85|0)==($numWheels4|0);
    if ($exitcond) {
     break;
    } else {
     $i6$06 = $85;
    }
   }
  }
 }
 $86 = HEAP32[$16>>2]|0;
 $87 = ($86|0)==(0|0);
 if ($87) {
  $tmp5 = ($numWheels4*400)|0;
  $89 = (($tmp5) + ($$sum12))|0;
  $90 = (($ptrIn) + ($89)|0);
  STACKTOP = sp;return ($90|0);
 }
 $88 = (($86) + 4|0);
 HEAP32[$88>>2] = 1;
 $tmp5 = ($numWheels4*400)|0;
 $89 = (($tmp5) + ($$sum12))|0;
 $90 = (($ptrIn) + ($89)|0);
 STACKTOP = sp;return ($90|0);
}
function __ZN5physx15PxVehicleWheels4freeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 72|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = ((($4) + (($i$01*208)|0)|0) + 192|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 352|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = HEAP32[$8>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vi[$11 & 4095]($8);
  }
  $12 = (($i$01) + 1)|0;
  $exitcond = ($12|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $12;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleWheels5setupEPNS_9PxPhysicsEPNS_14PxRigidDynamicERKNS_22PxVehicleWheelsSimDataEjj($this,$physics,$vehActor,$wheelsData,$numDrivenWheels,$numNonDrivenWheels) {
 $this = $this|0;
 $physics = $physics|0;
 $vehActor = $vehActor|0;
 $wheelsData = $wheelsData|0;
 $numDrivenWheels = $numDrivenWheels|0;
 $numNonDrivenWheels = $numNonDrivenWheels|0;
 var $$pre = 0, $$pre31 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0;
 var $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $chassisCMOffset = 0, $exitcond = 0, $exitcond29 = 0, $exitcond30 = 0, $i$023 = 0, $i1$021 = 0, $i2$016 = 0, $i3$012 = 0, $i4$010 = 0, $j$019 = 0, $shapeBuffer = 0;
 var $wheelOffset = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $chassisCMOffset = sp + 32|0;
 $wheelOffset = sp;
 $shapeBuffer = sp + 28|0;
 $0 = (($this) + 108|0);
 HEAP32[$0>>2] = $numNonDrivenWheels;
 $1 = (($this) + 8|0);
 (__ZN5physx22PxVehicleWheelsSimDataaSERKS0_($1,$wheelsData)|0);
 $2 = (($this) + 104|0);
 HEAP32[$2>>2] = $vehActor;
 $3 = (($wheelsData) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($this) + 72|0);
  $i$023 = 0;
  while(1) {
   $9 = HEAP32[$6>>2]|0;
   $10 = ((($9) + (($i$023*208)|0)|0) + 196|0);
   HEAP32[$10>>2] = 0;
   $11 = (($i$023) + 1)|0;
   $exitcond30 = ($11|0)==($4|0);
   if ($exitcond30) {
    break;
   } else {
    $i$023 = $11;
   }
  }
  if (!($5)) {
   $7 = (($this) + 72|0);
   $8 = (($wheelsData) + 32|0);
   $i1$021 = 0;
   while(1) {
    $17 = HEAP32[$7>>2]|0;
    $18 = ((($17) + (($i1$021*208)|0)|0) + 192|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$8>>2]|0;
    $j$019 = 0;
    while(1) {
     $21 = (((($20) + (($i1$021*944)|0)|0) + (($j$019*12)|0)|0) + 688|0);
     $22 = Math_fround(HEAPF32[$21>>2]);
     $23 = ((($19) + (($j$019*12)|0)|0) + 4|0);
     HEAPF32[$23>>2] = $22;
     $24 = (((($20) + (($i1$021*944)|0)|0) + (($j$019*12)|0)|0) + 692|0);
     $25 = Math_fround(HEAPF32[$24>>2]);
     $26 = ((($19) + (($j$019*12)|0)|0) + 8|0);
     HEAPF32[$26>>2] = $25;
     $27 = (((($20) + (($i1$021*944)|0)|0) + (($j$019*12)|0)|0) + 696|0);
     $28 = Math_fround(HEAPF32[$27>>2]);
     $29 = ((($19) + (($j$019*12)|0)|0) + 12|0);
     HEAPF32[$29>>2] = $28;
     $30 = (((($20) + (($i1$021*944)|0)|0) + (($j$019*12)|0)|0) + 640|0);
     $31 = Math_fround(HEAPF32[$30>>2]);
     $32 = ((($19) + (($j$019*12)|0)|0) + 52|0);
     HEAPF32[$32>>2] = $31;
     $33 = (((($20) + (($i1$021*944)|0)|0) + (($j$019*12)|0)|0) + 644|0);
     $34 = Math_fround(HEAPF32[$33>>2]);
     $35 = ((($19) + (($j$019*12)|0)|0) + 56|0);
     HEAPF32[$35>>2] = $34;
     $36 = (((($20) + (($i1$021*944)|0)|0) + (($j$019*12)|0)|0) + 648|0);
     $37 = Math_fround(HEAPF32[$36>>2]);
     $38 = ((($19) + (($j$019*12)|0)|0) + 60|0);
     HEAPF32[$38>>2] = $37;
     $39 = ((($19) + ($j$019<<2)|0) + 100|0);
     HEAPF32[$39>>2] = Math_fround(0.0);
     $40 = ((($19) + ($j$019)|0) + 116|0);
     HEAP8[$40>>0] = 0;
     $41 = ((($19) + (($j$019*12)|0)|0) + 120|0);
     HEAPF32[$41>>2] = Math_fround(0.0);
     $42 = ((($19) + (($j$019*12)|0)|0) + 124|0);
     HEAPF32[$42>>2] = Math_fround(0.0);
     $43 = ((($19) + (($j$019*12)|0)|0) + 128|0);
     HEAPF32[$43>>2] = Math_fround(0.0);
     $44 = ((($19) + (($j$019*12)|0)|0) + 168|0);
     HEAPF32[$44>>2] = Math_fround(0.0);
     $45 = ((($19) + (($j$019*12)|0)|0) + 172|0);
     HEAPF32[$45>>2] = Math_fround(0.0);
     $46 = ((($19) + (($j$019*12)|0)|0) + 176|0);
     HEAPF32[$46>>2] = Math_fround(0.0);
     $47 = ((($19) + ($j$019<<2)|0) + 216|0);
     HEAPF32[$47>>2] = Math_fround(0.0);
     $48 = ((($19) + ($j$019)|0) + 232|0);
     HEAP8[$48>>0] = 0;
     $49 = ((($19) + (($j$019*12)|0)|0) + 236|0);
     HEAPF32[$49>>2] = Math_fround(0.0);
     $50 = ((($19) + (($j$019*12)|0)|0) + 240|0);
     HEAPF32[$50>>2] = Math_fround(0.0);
     $51 = ((($19) + (($j$019*12)|0)|0) + 244|0);
     HEAPF32[$51>>2] = Math_fround(0.0);
     $52 = ((($19) + (($j$019*12)|0)|0) + 284|0);
     HEAPF32[$52>>2] = Math_fround(0.0);
     $53 = ((($19) + (($j$019*12)|0)|0) + 288|0);
     HEAPF32[$53>>2] = Math_fround(0.0);
     $54 = ((($19) + (($j$019*12)|0)|0) + 292|0);
     HEAPF32[$54>>2] = Math_fround(0.0);
     $55 = ((($19) + ($j$019<<2)|0) + 332|0);
     HEAPF32[$55>>2] = Math_fround(0.0);
     $56 = ((($19) + ($j$019)|0) + 348|0);
     HEAP8[$56>>0] = 0;
     $57 = (($j$019) + 1)|0;
     $exitcond = ($57|0)==(4);
     if ($exitcond) {
      break;
     } else {
      $j$019 = $57;
     }
    }
    $58 = HEAP32[$physics>>2]|0;
    $59 = (($58) + 136|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (FUNCTION_TABLE_iiiiiii[$60 & 255]($physics,$vehActor,0,$19,524128,348)|0);
    $62 = (($19) + 352|0);
    HEAP32[$62>>2] = $61;
    $63 = HEAP32[$61>>2]|0;
    $64 = (($63) + 36|0);
    $65 = HEAP32[$64>>2]|0;
    FUNCTION_TABLE_vi[$65 & 4095]($61);
    $66 = (($i1$021) + 1)|0;
    $exitcond29 = ($66|0)==($4|0);
    if ($exitcond29) {
     break;
    } else {
     $i1$021 = $66;
    }
   }
  }
 }
 $12 = (($wheelsData) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $71 = 0;
 } else {
  $15 = (($this) + 40|0);
  $16 = (($this) + 76|0);
  $i2$016 = 0;
  while(1) {
   $72 = $i2$016 >>> 2;
   $73 = HEAP32[$15>>2]|0;
   $74 = $i2$016 & 3;
   $75 = (((($73) + (($72*944)|0)|0) + ($74<<6)|0) + 384|0);
   $76 = HEAP32[$16>>2]|0;
   $77 = HEAP32[$76>>2]|0;
   $78 = (($77) + ($i2$016<<2)|0);
   HEAP32[$78>>2] = $75;
   $79 = (($i2$016) + 1)|0;
   $80 = ($79>>>0)<($13>>>0);
   if ($80) {
    $i2$016 = $79;
   } else {
    $71 = $13;
    break;
   }
  }
 }
 $67 = (($this) + 44|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68 << 2;
 $70 = ($71>>>0)<($69>>>0);
 if ($70) {
  $i3$012 = $71;
  while(1) {
   $96 = $i3$012 & 31;
   $97 = 1 << $96;
   $98 = $97 ^ -1;
   $99 = $i3$012 >>> 5;
   $100 = ((($this) + ($99<<2)|0) + 52|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = $101 & $98;
   HEAP32[$100>>2] = $102;
   $103 = (($i3$012) + 1)|0;
   $104 = HEAP32[$67>>2]|0;
   $105 = $104 << 2;
   $106 = ($103>>>0)<($105>>>0);
   if ($106) {
    $i3$012 = $103;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$12>>2]|0;
  $82 = $$pre;
 } else {
  $82 = $71;
 }
 $81 = ($82|0)==(0);
 if ($81) {
  STACKTOP = sp;return;
 }
 $83 = (($this) + 40|0);
 $84 = (($wheelOffset) + 4|0);
 $85 = (($chassisCMOffset) + 4|0);
 $86 = (($wheelOffset) + 8|0);
 $87 = (($chassisCMOffset) + 8|0);
 $88 = (($wheelOffset) + 12|0);
 $89 = (($chassisCMOffset) + 12|0);
 $90 = (($wheelOffset) + 16|0);
 $91 = (($chassisCMOffset) + 16|0);
 $92 = (($wheelOffset) + 20|0);
 $93 = (($chassisCMOffset) + 20|0);
 $94 = (($wheelOffset) + 24|0);
 $95 = (($chassisCMOffset) + 24|0);
 $146 = $82;$i4$010 = 0;
 while(1) {
  $107 = $i4$010 >>> 2;
  $108 = HEAP32[$83>>2]|0;
  $109 = $i4$010 & 3;
  $110 = (((($108) + (($107*944)|0)|0) + ($109)|0) + 928|0);
  $111 = HEAP8[$110>>0]|0;
  $112 = ($111<<24>>24)==(-1);
  if ($112) {
   $145 = $146;
  } else {
   $113 = $111&255;
   $114 = HEAP32[$2>>2]|0;
   $115 = HEAP32[$114>>2]|0;
   $116 = (($115) + 124|0);
   $117 = HEAP32[$116>>2]|0;
   FUNCTION_TABLE_vii[$117 & 4095]($chassisCMOffset,$114);
   $118 = Math_fround(HEAPF32[$chassisCMOffset>>2]);
   HEAPF32[$wheelOffset>>2] = $118;
   $119 = Math_fround(HEAPF32[$85>>2]);
   HEAPF32[$84>>2] = $119;
   $120 = Math_fround(HEAPF32[$87>>2]);
   HEAPF32[$86>>2] = $120;
   $121 = Math_fround(HEAPF32[$89>>2]);
   HEAPF32[$88>>2] = $121;
   $122 = Math_fround(HEAPF32[$91>>2]);
   HEAPF32[$90>>2] = $122;
   $123 = Math_fround(HEAPF32[$93>>2]);
   HEAPF32[$92>>2] = $123;
   $124 = Math_fround(HEAPF32[$95>>2]);
   HEAPF32[$94>>2] = $124;
   $125 = HEAP32[$83>>2]|0;
   $126 = (((($125) + (($107*944)|0)|0) + (($109*12)|0)|0) + 784|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = Math_fround($127 + $122);
   HEAPF32[$90>>2] = $128;
   $129 = (((($125) + (($107*944)|0)|0) + (($109*12)|0)|0) + 788|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = Math_fround($130 + $123);
   HEAPF32[$92>>2] = $131;
   $132 = (((($125) + (($107*944)|0)|0) + (($109*12)|0)|0) + 792|0);
   $133 = Math_fround(HEAPF32[$132>>2]);
   $134 = Math_fround($133 + $124);
   HEAPF32[$94>>2] = $134;
   $135 = HEAP32[$2>>2]|0;
   $136 = HEAP32[$135>>2]|0;
   $137 = (($136) + 108|0);
   $138 = HEAP32[$137>>2]|0;
   (FUNCTION_TABLE_iiiii[$138 & 511]($135,$shapeBuffer,1,$113)|0);
   $139 = HEAP32[$shapeBuffer>>2]|0;
   $140 = HEAP32[$139>>2]|0;
   $141 = (($140) + 68|0);
   $142 = HEAP32[$141>>2]|0;
   FUNCTION_TABLE_vii[$142 & 4095]($139,$wheelOffset);
   $$pre31 = HEAP32[$12>>2]|0;
   $145 = $$pre31;
  }
  $143 = (($i4$010) + 1)|0;
  $144 = ($143>>>0)<($145>>>0);
  if ($144) {
   $146 = $145;$i4$010 = $143;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleWheels8requiresERNS_23PxProcessPxBaseCallbackE($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$c>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($c,$4);
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 72|0);
 $i$01 = 0;
 while(1) {
  $9 = HEAP32[$c>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$8>>2]|0;
  $13 = ((($12) + (($i$01*208)|0)|0) + 192|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 352|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($c,$16);
  $17 = (($i$01) + 1)|0;
  $18 = HEAP32[$5>>2]|0;
  $19 = ($17>>>0)<($18>>>0);
  if ($19) {
   $i$01 = $17;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx15PxVehicleWheels17resolveReferencesERNS_24PxDeserializationContextE($this,$context) {
 $this = $this|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$02 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$context>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = $1;
  $6 = (FUNCTION_TABLE_iiii[$4 & 2047]($context,-2147483648,$5)|0);
  HEAP32[$0>>2] = $6;
 }
 $7 = (($this) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($this) + 72|0);
  $i$02 = 0;
  while(1) {
   $16 = HEAP32[$10>>2]|0;
   $17 = ((($16) + (($i$02*208)|0)|0) + 192|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 352|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $27 = 0;
   } else {
    $22 = HEAP32[$context>>2]|0;
    $23 = HEAP32[$22>>2]|0;
    $24 = $20;
    $25 = (FUNCTION_TABLE_iiii[$23 & 2047]($context,-2147483648,$24)|0);
    $27 = $25;
   }
   $26 = HEAP32[$27>>2]|0;
   $28 = (($26) + 68|0);
   $29 = HEAP32[$28>>2]|0;
   FUNCTION_TABLE_viii[$29 & 4095]($27,$18,524128);
   HEAP32[$19>>2] = $27;
   $30 = (($i$02) + 1)|0;
   $31 = HEAP32[$7>>2]|0;
   $32 = ($30>>>0)<($31>>>0);
   if ($32) {
    $i$02 = $30;
   } else {
    break;
   }
  }
 }
 $11 = (($this) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 40|0);
 $15 = (($this) + 76|0);
 $i1$01 = 0;
 while(1) {
  $33 = $i1$01 >>> 2;
  $34 = HEAP32[$14>>2]|0;
  $35 = $i1$01 & 3;
  $36 = (((($34) + (($33*944)|0)|0) + ($35<<6)|0) + 384|0);
  $37 = HEAP32[$15>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($i1$01<<2)|0);
  HEAP32[$39>>2] = $36;
  $40 = (($i1$01) + 1)|0;
  $41 = ($40>>>0)<($12>>>0);
  if ($41) {
   $i1$01 = $40;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx22PxVehicleWheelsDynData11getUserDataEj($this,$tireIdx) {
 $this = $this|0;
 $tireIdx = $tireIdx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($tireIdx<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx25PxVehicleConstraintShader36vehicleSuspLimitConstraintSolverPrepEPNS_14Px1DConstraintERNS_6PxVec3EjRNS_24PxConstraintInvMassScaleEPKvRKNS_11PxTransformESB_($constraints,$body0WorldOffset,$maxConstraints,$0,$constantBlock,$bodyAToWorld,$bodyBToWorld) {
 $constraints = $constraints|0;
 $body0WorldOffset = $body0WorldOffset|0;
 $maxConstraints = $maxConstraints|0;
 $0 = $0|0;
 $constantBlock = $constantBlock|0;
 $bodyAToWorld = $bodyAToWorld|0;
 $bodyBToWorld = $bodyBToWorld|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $exitcond42 = 0, $exitcond43 = 0, $i$040 = 0, $i1$038 = 0;
 var $i3$035 = 0, $numActive$041 = 0, $numActive$1 = 0, $numActive$239 = 0, $numActive$3 = 0, $numActive$436 = 0, $numActive$5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($constantBlock) + 48|0);
 $2 = (($bodyAToWorld) + 12|0);
 $3 = (($bodyAToWorld) + 4|0);
 $4 = (($bodyAToWorld) + 8|0);
 $5 = (($constantBlock) + 96|0);
 $i$040 = 0;$numActive$041 = 0;
 while(1) {
  $$sum2 = (($i$040) + 112)|0;
  $9 = (($constantBlock) + ($$sum2)|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   $numActive$1 = $numActive$041;
  } else {
   $12 = (($1) + (($i$040*12)|0)|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = Math_fround($13 * Math_fround(2.0));
   $15 = ((($1) + (($i$040*12)|0)|0) + 4|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($16 * Math_fround(2.0));
   $18 = ((($1) + (($i$040*12)|0)|0) + 8|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround($19 * Math_fround(2.0));
   $21 = Math_fround(HEAPF32[$2>>2]);
   $22 = Math_fround($21 * $21);
   $23 = Math_fround($22 + Math_fround(-0.5));
   $24 = Math_fround(HEAPF32[$bodyAToWorld>>2]);
   $25 = Math_fround($14 * $24);
   $26 = Math_fround(HEAPF32[$3>>2]);
   $27 = Math_fround($17 * $26);
   $28 = Math_fround($25 + $27);
   $29 = Math_fround(HEAPF32[$4>>2]);
   $30 = Math_fround($20 * $29);
   $31 = Math_fround($28 + $30);
   $32 = Math_fround($14 * $23);
   $33 = Math_fround($20 * $26);
   $34 = Math_fround($17 * $29);
   $35 = Math_fround($33 - $34);
   $36 = Math_fround($21 * $35);
   $37 = Math_fround($32 + $36);
   $38 = Math_fround($24 * $31);
   $39 = Math_fround($38 + $37);
   $40 = Math_fround($17 * $23);
   $41 = Math_fround($14 * $29);
   $42 = Math_fround($20 * $24);
   $43 = Math_fround($41 - $42);
   $44 = Math_fround($21 * $43);
   $45 = Math_fround($40 + $44);
   $46 = Math_fround($26 * $31);
   $47 = Math_fround($46 + $45);
   $48 = Math_fround($20 * $23);
   $49 = Math_fround($17 * $24);
   $50 = Math_fround($14 * $26);
   $51 = Math_fround($49 - $50);
   $52 = Math_fround($21 * $51);
   $53 = Math_fround($48 + $52);
   $54 = Math_fround($29 * $31);
   $55 = Math_fround($53 + $54);
   $56 = (($constraints) + (($numActive$041*80)|0)|0);
   HEAPF32[$56>>2] = $39;
   $57 = ((($constraints) + (($numActive$041*80)|0)|0) + 4|0);
   HEAPF32[$57>>2] = $47;
   $58 = ((($constraints) + (($numActive$041*80)|0)|0) + 8|0);
   HEAPF32[$58>>2] = $55;
   $59 = ((($constantBlock) + (($i$040*12)|0)|0) + 4|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround(HEAPF32[$18>>2]);
   $62 = Math_fround($60 * $61);
   $63 = ((($constantBlock) + (($i$040*12)|0)|0) + 8|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = Math_fround(HEAPF32[$15>>2]);
   $66 = Math_fround($64 * $65);
   $67 = Math_fround($62 - $66);
   $68 = Math_fround(HEAPF32[$12>>2]);
   $69 = Math_fround($64 * $68);
   $70 = (($constantBlock) + (($i$040*12)|0)|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = Math_fround($61 * $71);
   $73 = Math_fround($69 - $72);
   $74 = Math_fround($65 * $71);
   $75 = Math_fround($60 * $68);
   $76 = Math_fround($74 - $75);
   $77 = Math_fround($67 * Math_fround(2.0));
   $78 = Math_fround($73 * Math_fround(2.0));
   $79 = Math_fround($76 * Math_fround(2.0));
   $80 = Math_fround(HEAPF32[$2>>2]);
   $81 = Math_fround($80 * $80);
   $82 = Math_fround($81 + Math_fround(-0.5));
   $83 = Math_fround(HEAPF32[$bodyAToWorld>>2]);
   $84 = Math_fround($77 * $83);
   $85 = Math_fround(HEAPF32[$3>>2]);
   $86 = Math_fround($78 * $85);
   $87 = Math_fround($84 + $86);
   $88 = Math_fround(HEAPF32[$4>>2]);
   $89 = Math_fround($79 * $88);
   $90 = Math_fround($87 + $89);
   $91 = Math_fround($77 * $82);
   $92 = Math_fround($79 * $85);
   $93 = Math_fround($78 * $88);
   $94 = Math_fround($92 - $93);
   $95 = Math_fround($80 * $94);
   $96 = Math_fround($91 + $95);
   $97 = Math_fround($83 * $90);
   $98 = Math_fround($97 + $96);
   $99 = Math_fround($78 * $82);
   $100 = Math_fround($77 * $88);
   $101 = Math_fround($83 * $79);
   $102 = Math_fround($100 - $101);
   $103 = Math_fround($80 * $102);
   $104 = Math_fround($99 + $103);
   $105 = Math_fround($85 * $90);
   $106 = Math_fround($105 + $104);
   $107 = Math_fround($79 * $82);
   $108 = Math_fround($83 * $78);
   $109 = Math_fround($77 * $85);
   $110 = Math_fround($108 - $109);
   $111 = Math_fround($80 * $110);
   $112 = Math_fround($107 + $111);
   $113 = Math_fround($88 * $90);
   $114 = Math_fround($112 + $113);
   $115 = ((($constraints) + (($numActive$041*80)|0)|0) + 16|0);
   HEAPF32[$115>>2] = $98;
   $116 = ((($constraints) + (($numActive$041*80)|0)|0) + 20|0);
   HEAPF32[$116>>2] = $106;
   $117 = ((($constraints) + (($numActive$041*80)|0)|0) + 24|0);
   HEAPF32[$117>>2] = $114;
   $118 = (($5) + ($i$040<<2)|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = ((($constraints) + (($numActive$041*80)|0)|0) + 12|0);
   HEAPF32[$120>>2] = $119;
   $121 = ((($constraints) + (($numActive$041*80)|0)|0) + 32|0);
   HEAPF32[$121>>2] = Math_fround(0.0);
   $122 = ((($constraints) + (($numActive$041*80)|0)|0) + 36|0);
   HEAPF32[$122>>2] = Math_fround(0.0);
   $123 = ((($constraints) + (($numActive$041*80)|0)|0) + 40|0);
   HEAPF32[$123>>2] = Math_fround(0.0);
   $124 = ((($constraints) + (($numActive$041*80)|0)|0) + 48|0);
   HEAPF32[$124>>2] = Math_fround(0.0);
   $125 = ((($constraints) + (($numActive$041*80)|0)|0) + 52|0);
   HEAPF32[$125>>2] = Math_fround(0.0);
   $126 = ((($constraints) + (($numActive$041*80)|0)|0) + 56|0);
   HEAPF32[$126>>2] = Math_fround(0.0);
   $127 = ((($constraints) + (($numActive$041*80)|0)|0) + 44|0);
   HEAPF32[$127>>2] = Math_fround(-3.40282346638528859812E+38);
   $128 = ((($constraints) + (($numActive$041*80)|0)|0) + 60|0);
   HEAPF32[$128>>2] = Math_fround(0.0);
   $129 = ((($constraints) + (($numActive$041*80)|0)|0) + 28|0);
   HEAPF32[$129>>2] = Math_fround(0.0);
   $130 = (($numActive$041) + 1)|0;
   HEAP8[$9>>0] = 0;
   $numActive$1 = $130;
  }
  $131 = (($i$040) + 1)|0;
  $exitcond43 = ($131|0)==(4);
  if ($exitcond43) {
   break;
  } else {
   $i$040 = $131;$numActive$041 = $numActive$1;
  }
 }
 $6 = (($constantBlock) + 116|0);
 $7 = (($constantBlock) + 164|0);
 $8 = (($constantBlock) + 212|0);
 $i1$038 = 0;$numActive$239 = $numActive$1;
 while(1) {
  $$sum1 = (($i1$038) + 228)|0;
  $135 = (($constantBlock) + ($$sum1)|0);
  $136 = HEAP8[$135>>0]|0;
  $137 = ($136<<24>>24)==(0);
  if ($137) {
   $numActive$3 = $numActive$239;
  } else {
   $138 = (($7) + (($i1$038*12)|0)|0);
   $139 = Math_fround(HEAPF32[$138>>2]);
   $140 = (($constraints) + (($numActive$239*80)|0)|0);
   HEAPF32[$140>>2] = $139;
   $141 = ((($7) + (($i1$038*12)|0)|0) + 4|0);
   $142 = Math_fround(HEAPF32[$141>>2]);
   $143 = ((($constraints) + (($numActive$239*80)|0)|0) + 4|0);
   HEAPF32[$143>>2] = $142;
   $144 = ((($7) + (($i1$038*12)|0)|0) + 8|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = ((($constraints) + (($numActive$239*80)|0)|0) + 8|0);
   HEAPF32[$146>>2] = $145;
   $147 = ((($6) + (($i1$038*12)|0)|0) + 4|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = Math_fround(HEAPF32[$144>>2]);
   $150 = Math_fround($148 * $149);
   $151 = ((($6) + (($i1$038*12)|0)|0) + 8|0);
   $152 = Math_fround(HEAPF32[$151>>2]);
   $153 = Math_fround(HEAPF32[$141>>2]);
   $154 = Math_fround($152 * $153);
   $155 = Math_fround($150 - $154);
   $156 = Math_fround(HEAPF32[$138>>2]);
   $157 = Math_fround($152 * $156);
   $158 = (($6) + (($i1$038*12)|0)|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = Math_fround($149 * $159);
   $161 = Math_fround($157 - $160);
   $162 = Math_fround($153 * $159);
   $163 = Math_fround($148 * $156);
   $164 = Math_fround($162 - $163);
   $165 = ((($constraints) + (($numActive$239*80)|0)|0) + 16|0);
   HEAPF32[$165>>2] = $155;
   $166 = ((($constraints) + (($numActive$239*80)|0)|0) + 20|0);
   HEAPF32[$166>>2] = $161;
   $167 = ((($constraints) + (($numActive$239*80)|0)|0) + 24|0);
   HEAPF32[$167>>2] = $164;
   $168 = ((($constraints) + (($numActive$239*80)|0)|0) + 12|0);
   HEAPF32[$168>>2] = Math_fround(0.0);
   $169 = ((($constraints) + (($numActive$239*80)|0)|0) + 32|0);
   HEAPF32[$169>>2] = Math_fround(0.0);
   $170 = ((($constraints) + (($numActive$239*80)|0)|0) + 36|0);
   HEAPF32[$170>>2] = Math_fround(0.0);
   $171 = ((($constraints) + (($numActive$239*80)|0)|0) + 40|0);
   HEAPF32[$171>>2] = Math_fround(0.0);
   $172 = ((($constraints) + (($numActive$239*80)|0)|0) + 48|0);
   HEAPF32[$172>>2] = Math_fround(0.0);
   $173 = ((($constraints) + (($numActive$239*80)|0)|0) + 52|0);
   HEAPF32[$173>>2] = Math_fround(0.0);
   $174 = ((($constraints) + (($numActive$239*80)|0)|0) + 56|0);
   HEAPF32[$174>>2] = Math_fround(0.0);
   $175 = ((($constraints) + (($numActive$239*80)|0)|0) + 44|0);
   HEAPF32[$175>>2] = Math_fround(-3.40282346638528859812E+38);
   $176 = ((($constraints) + (($numActive$239*80)|0)|0) + 60|0);
   HEAPF32[$176>>2] = Math_fround(3.40282346638528859812E+38);
   $177 = (($8) + ($i1$038<<2)|0);
   $178 = Math_fround(HEAPF32[$177>>2]);
   $179 = ((($constraints) + (($numActive$239*80)|0)|0) + 28|0);
   HEAPF32[$179>>2] = $178;
   $180 = ((($constraints) + (($numActive$239*80)|0)|0) + 68|0);
   HEAPF32[$180>>2] = Math_fround(1000.0);
   $181 = ((($constraints) + (($numActive$239*80)|0)|0) + 76|0);
   HEAP16[$181>>1] = 3;
   $182 = (($numActive$239) + 1)|0;
   HEAP8[$135>>0] = 0;
   $numActive$3 = $182;
  }
  $183 = (($i1$038) + 1)|0;
  $exitcond42 = ($183|0)==(4);
  if ($exitcond42) {
   break;
  } else {
   $i1$038 = $183;$numActive$239 = $numActive$3;
  }
 }
 $132 = (($constantBlock) + 232|0);
 $133 = (($constantBlock) + 280|0);
 $134 = (($constantBlock) + 328|0);
 $i3$035 = 0;$numActive$436 = $numActive$3;
 while(1) {
  $$sum = (($i3$035) + 344)|0;
  $184 = (($constantBlock) + ($$sum)|0);
  $185 = HEAP8[$184>>0]|0;
  $186 = ($185<<24>>24)==(0);
  if ($186) {
   $numActive$5 = $numActive$436;
  } else {
   $187 = (($133) + (($i3$035*12)|0)|0);
   $188 = Math_fround(HEAPF32[$187>>2]);
   $189 = (($constraints) + (($numActive$436*80)|0)|0);
   HEAPF32[$189>>2] = $188;
   $190 = ((($133) + (($i3$035*12)|0)|0) + 4|0);
   $191 = Math_fround(HEAPF32[$190>>2]);
   $192 = ((($constraints) + (($numActive$436*80)|0)|0) + 4|0);
   HEAPF32[$192>>2] = $191;
   $193 = ((($133) + (($i3$035*12)|0)|0) + 8|0);
   $194 = Math_fround(HEAPF32[$193>>2]);
   $195 = ((($constraints) + (($numActive$436*80)|0)|0) + 8|0);
   HEAPF32[$195>>2] = $194;
   $196 = ((($132) + (($i3$035*12)|0)|0) + 4|0);
   $197 = Math_fround(HEAPF32[$196>>2]);
   $198 = Math_fround(HEAPF32[$193>>2]);
   $199 = Math_fround($197 * $198);
   $200 = ((($132) + (($i3$035*12)|0)|0) + 8|0);
   $201 = Math_fround(HEAPF32[$200>>2]);
   $202 = Math_fround(HEAPF32[$190>>2]);
   $203 = Math_fround($201 * $202);
   $204 = Math_fround($199 - $203);
   $205 = Math_fround(HEAPF32[$187>>2]);
   $206 = Math_fround($201 * $205);
   $207 = (($132) + (($i3$035*12)|0)|0);
   $208 = Math_fround(HEAPF32[$207>>2]);
   $209 = Math_fround($198 * $208);
   $210 = Math_fround($206 - $209);
   $211 = Math_fround($202 * $208);
   $212 = Math_fround($197 * $205);
   $213 = Math_fround($211 - $212);
   $214 = ((($constraints) + (($numActive$436*80)|0)|0) + 16|0);
   HEAPF32[$214>>2] = $204;
   $215 = ((($constraints) + (($numActive$436*80)|0)|0) + 20|0);
   HEAPF32[$215>>2] = $210;
   $216 = ((($constraints) + (($numActive$436*80)|0)|0) + 24|0);
   HEAPF32[$216>>2] = $213;
   $217 = ((($constraints) + (($numActive$436*80)|0)|0) + 12|0);
   HEAPF32[$217>>2] = Math_fround(0.0);
   $218 = ((($constraints) + (($numActive$436*80)|0)|0) + 32|0);
   HEAPF32[$218>>2] = Math_fround(0.0);
   $219 = ((($constraints) + (($numActive$436*80)|0)|0) + 36|0);
   HEAPF32[$219>>2] = Math_fround(0.0);
   $220 = ((($constraints) + (($numActive$436*80)|0)|0) + 40|0);
   HEAPF32[$220>>2] = Math_fround(0.0);
   $221 = ((($constraints) + (($numActive$436*80)|0)|0) + 48|0);
   HEAPF32[$221>>2] = Math_fround(0.0);
   $222 = ((($constraints) + (($numActive$436*80)|0)|0) + 52|0);
   HEAPF32[$222>>2] = Math_fround(0.0);
   $223 = ((($constraints) + (($numActive$436*80)|0)|0) + 56|0);
   HEAPF32[$223>>2] = Math_fround(0.0);
   $224 = ((($constraints) + (($numActive$436*80)|0)|0) + 44|0);
   HEAPF32[$224>>2] = Math_fround(-3.40282346638528859812E+38);
   $225 = ((($constraints) + (($numActive$436*80)|0)|0) + 60|0);
   HEAPF32[$225>>2] = Math_fround(3.40282346638528859812E+38);
   $226 = (($134) + ($i3$035<<2)|0);
   $227 = Math_fround(HEAPF32[$226>>2]);
   $228 = ((($constraints) + (($numActive$436*80)|0)|0) + 28|0);
   HEAPF32[$228>>2] = $227;
   $229 = ((($constraints) + (($numActive$436*80)|0)|0) + 68|0);
   HEAPF32[$229>>2] = Math_fround(1000.0);
   $230 = ((($constraints) + (($numActive$436*80)|0)|0) + 76|0);
   HEAP16[$230>>1] = 3;
   $231 = (($numActive$436) + 1)|0;
   HEAP8[$184>>0] = 0;
   $numActive$5 = $231;
  }
  $232 = (($i3$035) + 1)|0;
  $exitcond = ($232|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $i3$035 = $232;$numActive$436 = $numActive$5;
  }
 }
 STACKTOP = sp;return ($numActive$5|0);
}
function __ZN5physx25PxVehicleConstraintShader19visualiseConstraintERNS_22PxConstraintVisualizerEPKvRKNS_11PxTransformES7_j($viz,$constantBlock,$body0Transform,$body1Transform,$flags) {
 $viz = $viz|0;
 $constantBlock = $constantBlock|0;
 $body0Transform = $body0Transform|0;
 $body1Transform = $body1Transform|0;
 $flags = $flags|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx25PxVehicleConstraintShader11prepareDataEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx25PxVehicleConstraintShader19updatePvdPropertiesERNS_8debugger4comm13PvdDataStreamEPKNS_12PxConstraintENS_15PxPvdUpdateType4EnumE($this,$pvdConnection,$c,$updateType) {
 $this = $this|0;
 $pvdConnection = $pvdConnection|0;
 $c = $c|0;
 $updateType = $updateType|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5physx25PxVehicleConstraintShader19onConstraintReleaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 356|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 112|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = (($4) + -1)<<24>>24;
 HEAP8[$3>>0] = $5;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($6) + 112|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
 STACKTOP = sp;return;
}
function __ZN5physx25PxVehicleConstraintShader10onComShiftEj($this,$actor) {
 $this = $this|0;
 $actor = $actor|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx25PxVehicleConstraintShader13onOriginShiftERKNS_6PxVec3E($this,$shift) {
 $this = $this|0;
 $shift = $shift|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx25PxVehicleConstraintShader20getExternalReferenceERj($this,$typeID) {
 $this = $this|0;
 $typeID = $typeID|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$typeID>>2] = 1;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx25PxVehicleConstraintShader15getSerializableEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN5physx25PxVehicleConstraintShaderD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx25PxVehicleConstraintShaderD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx28PxVehicleComputeSprungMassesEjPKNS_6PxVec3ERS1_fjPf($numSprungMasses,$sprungMassCoordinates,$centreOfMass,$totalMass,$gravityDirection,$sprungMasses) {
 $numSprungMasses = $numSprungMasses|0;
 $sprungMassCoordinates = $sprungMassCoordinates|0;
 $centreOfMass = $centreOfMass|0;
 $totalMass = Math_fround($totalMass);
 $gravityDirection = $gravityDirection|0;
 $sprungMasses = $sprungMasses|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx19computeSprungMassesEjPKNS_6PxVec3ERS1_fjPf($numSprungMasses,$sprungMassCoordinates,$centreOfMass,$totalMass,$gravityDirection,$sprungMasses);
 STACKTOP = sp;return;
}
function __Z31getPxVehicleEngineData_RecipMOIPKN5physx19PxVehicleEngineDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 104|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z36getPxVehicleEngineData_RecipMaxOmegaPKN5physx19PxVehicleEngineDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 108|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx32PxVehicleEngineDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524216;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 515;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 164;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 524232;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 516;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 165;
 $5 = (($this) + 24|0);
 __ZN5physx20MTorqueCurvePropertyC2Ev($5);
 $6 = (($this) + 48|0);
 HEAP32[$6>>2] = 524200;
 $7 = (($this) + 52|0);
 HEAP32[$7>>2] = 518;
 $8 = (($this) + 56|0);
 HEAP32[$8>>2] = 166;
 $9 = (($this) + 60|0);
 HEAP32[$9>>2] = 129;
 $10 = (($this) + 64|0);
 HEAP32[$10>>2] = 524248;
 $11 = (($this) + 68|0);
 HEAP32[$11>>2] = 519;
 $12 = (($this) + 72|0);
 HEAP32[$12>>2] = 167;
 $13 = (($this) + 76|0);
 HEAP32[$13>>2] = 130;
 $14 = (($this) + 80|0);
 HEAP32[$14>>2] = 524264;
 $15 = (($this) + 84|0);
 HEAP32[$15>>2] = 520;
 $16 = (($this) + 88|0);
 HEAP32[$16>>2] = 168;
 $17 = (($this) + 92|0);
 HEAP32[$17>>2] = 131;
 $18 = (($this) + 96|0);
 HEAP32[$18>>2] = 524280;
 $19 = (($this) + 100|0);
 HEAP32[$19>>2] = 521;
 $20 = (($this) + 104|0);
 HEAP32[$20>>2] = 169;
 $21 = (($this) + 108|0);
 HEAP32[$21>>2] = 132;
 $22 = (($this) + 112|0);
 HEAP32[$22>>2] = 524312;
 $23 = (($this) + 116|0);
 HEAP32[$23>>2] = 522;
 $24 = (($this) + 120|0);
 HEAP32[$24>>2] = 170;
 $25 = (($this) + 124|0);
 HEAP32[$25>>2] = 133;
 $26 = (($this) + 128|0);
 HEAP32[$26>>2] = 524352;
 $27 = (($this) + 132|0);
 HEAP32[$27>>2] = 523;
 $28 = (($this) + 136|0);
 HEAP32[$28>>2] = 171;
 $29 = (($this) + 140|0);
 HEAP32[$29>>2] = 134;
 STACKTOP = sp;return;
}
function __Z26setPxVehicleEngineDataMMOIPN5physx19PxVehicleEngineDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 80|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z26getPxVehicleEngineDataMMOIPKN5physx19PxVehicleEngineDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z33setPxVehicleEngineDataMPeakTorquePN5physx19PxVehicleEngineDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 84|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z33getPxVehicleEngineDataMPeakTorquePKN5physx19PxVehicleEngineDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 84|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z31setPxVehicleEngineDataMMaxOmegaPN5physx19PxVehicleEngineDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 88|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z31getPxVehicleEngineDataMMaxOmegaPKN5physx19PxVehicleEngineDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 88|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z46setPxVehicleEngineDataMDampingRateFullThrottlePN5physx19PxVehicleEngineDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 92|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z46getPxVehicleEngineDataMDampingRateFullThrottlePKN5physx19PxVehicleEngineDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 92|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z59setPxVehicleEngineDataMDampingRateZeroThrottleClutchEngagedPN5physx19PxVehicleEngineDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 96|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z59getPxVehicleEngineDataMDampingRateZeroThrottleClutchEngagedPKN5physx19PxVehicleEngineDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 96|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z62setPxVehicleEngineDataMDampingRateZeroThrottleClutchDisengagedPN5physx19PxVehicleEngineDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 100|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z62getPxVehicleEngineDataMDampingRateZeroThrottleClutchDisengagedPKN5physx19PxVehicleEngineDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 100|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z31setPxVehicleGearsData_GearRatioPN5physx18PxVehicleGearsDataENS0_4EnumEf($inObj,$inIndex,$inArg) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inArg = Math_fround($inArg);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + ($inIndex<<2)|0);
 HEAPF32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z31getPxVehicleGearsData_GearRatioPKN5physx18PxVehicleGearsDataENS0_4EnumE($inObj,$inIndex) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + ($inIndex<<2)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx31PxVehicleGearsDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524400;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 526;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 31;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 44;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 524416;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 527;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 172;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 135;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 524432;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 528;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 3170;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2536;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 524448;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 529;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 173;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 136;
 STACKTOP = sp;return;
}
function __Z32setPxVehicleGearsDataMFinalRatioPN5physx18PxVehicleGearsDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 128|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z32getPxVehicleGearsDataMFinalRatioPKN5physx18PxVehicleGearsDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 128|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z30setPxVehicleGearsDataMNbRatiosPN5physx18PxVehicleGearsDataEj($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 132|0);
 HEAP32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z30getPxVehicleGearsDataMNbRatiosPKN5physx18PxVehicleGearsDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 132|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z32setPxVehicleGearsDataMSwitchTimePN5physx18PxVehicleGearsDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 136|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z32getPxVehicleGearsDataMSwitchTimePKN5physx18PxVehicleGearsDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 136|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z31setPxVehicleAutoBoxData_LatencyPN5physx20PxVehicleAutoBoxDataEf($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = Math_fround($inArg);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 128|0);
 HEAPF32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z31getPxVehicleAutoBoxData_LatencyPKN5physx20PxVehicleAutoBoxDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 128|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z32setPxVehicleAutoBoxData_UpRatiosPN5physx20PxVehicleAutoBoxDataENS_18PxVehicleGearsData4EnumEf($inObj,$inIndex,$inArg) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inArg = Math_fround($inArg);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + ($inIndex<<2)|0);
 HEAPF32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z32getPxVehicleAutoBoxData_UpRatiosPKN5physx20PxVehicleAutoBoxDataENS_18PxVehicleGearsData4EnumE($inObj,$inIndex) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + ($inIndex<<2)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z34setPxVehicleAutoBoxData_DownRatiosPN5physx20PxVehicleAutoBoxDataENS_18PxVehicleGearsData4EnumEf($inObj,$inIndex,$inArg) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inArg = Math_fround($inArg);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($inObj) + ($inIndex<<2)|0) + 128|0);
 HEAPF32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z34getPxVehicleAutoBoxData_DownRatiosPKN5physx20PxVehicleAutoBoxDataENS_18PxVehicleGearsData4EnumE($inObj,$inIndex) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($inObj) + ($inIndex<<2)|0) + 128|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx33PxVehicleAutoBoxDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524464;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 532;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 174;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 137;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 524472;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 533;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 32;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 45;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 524488;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 534;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 33;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 46;
 STACKTOP = sp;return;
}
function __ZN5physx40PxVehicleDifferential4WDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524504;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 537;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 175;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 138;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 524520;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 538;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 176;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 139;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 524544;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 539;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 177;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 140;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 524568;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 540;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 178;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 141;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 524584;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 541;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 179;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 142;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 524600;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 542;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 180;
 $22 = (($this) + 92|0);
 HEAP32[$22>>2] = 143;
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = 524616;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = 543;
 $25 = (($this) + 104|0);
 HEAP32[$25>>2] = 3171;
 $26 = (($this) + 108|0);
 HEAP32[$26>>2] = 2537;
 STACKTOP = sp;return;
}
function __Z45setPxVehicleDifferential4WDataMFrontRearSplitPN5physx27PxVehicleDifferential4WDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$inOwner>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z45getPxVehicleDifferential4WDataMFrontRearSplitPKN5physx27PxVehicleDifferential4WDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inOwner>>2]);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z50setPxVehicleDifferential4WDataMFrontLeftRightSplitPN5physx27PxVehicleDifferential4WDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z50getPxVehicleDifferential4WDataMFrontLeftRightSplitPKN5physx27PxVehicleDifferential4WDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z49setPxVehicleDifferential4WDataMRearLeftRightSplitPN5physx27PxVehicleDifferential4WDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z49getPxVehicleDifferential4WDataMRearLeftRightSplitPKN5physx27PxVehicleDifferential4WDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z41setPxVehicleDifferential4WDataMCentreBiasPN5physx27PxVehicleDifferential4WDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z41getPxVehicleDifferential4WDataMCentreBiasPKN5physx27PxVehicleDifferential4WDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z40setPxVehicleDifferential4WDataMFrontBiasPN5physx27PxVehicleDifferential4WDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 16|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z40getPxVehicleDifferential4WDataMFrontBiasPKN5physx27PxVehicleDifferential4WDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z39setPxVehicleDifferential4WDataMRearBiasPN5physx27PxVehicleDifferential4WDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 20|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z39getPxVehicleDifferential4WDataMRearBiasPKN5physx27PxVehicleDifferential4WDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 20|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z35setPxVehicleDifferential4WDataMTypePN5physx27PxVehicleDifferential4WDataENS0_4EnumE($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 24|0);
 HEAP32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z35getPxVehicleDifferential4WDataMTypePKN5physx27PxVehicleDifferential4WDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z48setPxVehicleDifferentialNWData_DrivenWheelStatusPN5physx27PxVehicleDifferentialNWDataEj($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx27PxVehicleDifferentialNWData20setDrivenWheelStatusEj($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z48getPxVehicleDifferentialNWData_DrivenWheelStatusPKN5physx27PxVehicleDifferentialNWDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx27PxVehicleDifferentialNWData20getDrivenWheelStatusEv($inObj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx40PxVehicleDifferentialNWDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524624;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 546;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 3172;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 2538;
 STACKTOP = sp;return;
}
function __ZN5physx43PxVehicleAckermannGeometryDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524648;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 549;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 181;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 144;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 524664;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 550;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 182;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 145;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 524680;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 551;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 183;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 146;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 524696;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 552;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 184;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 147;
 STACKTOP = sp;return;
}
function __Z42setPxVehicleAckermannGeometryDataMAccuracyPN5physx30PxVehicleAckermannGeometryDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$inOwner>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z42getPxVehicleAckermannGeometryDataMAccuracyPKN5physx30PxVehicleAckermannGeometryDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inOwner>>2]);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z44setPxVehicleAckermannGeometryDataMFrontWidthPN5physx30PxVehicleAckermannGeometryDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z44getPxVehicleAckermannGeometryDataMFrontWidthPKN5physx30PxVehicleAckermannGeometryDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z43setPxVehicleAckermannGeometryDataMRearWidthPN5physx30PxVehicleAckermannGeometryDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z43getPxVehicleAckermannGeometryDataMRearWidthPKN5physx30PxVehicleAckermannGeometryDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z48setPxVehicleAckermannGeometryDataMAxleSeparationPN5physx30PxVehicleAckermannGeometryDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z48getPxVehicleAckermannGeometryDataMAxleSeparationPKN5physx30PxVehicleAckermannGeometryDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx32PxVehicleClutchDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524712;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 555;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 185;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 148;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 524728;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 556;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 3173;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 2539;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 524744;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 557;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 3174;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2540;
 STACKTOP = sp;return;
}
function __Z31setPxVehicleClutchDataMStrengthPN5physx19PxVehicleClutchDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$inOwner>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z31getPxVehicleClutchDataMStrengthPKN5physx19PxVehicleClutchDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inOwner>>2]);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z35setPxVehicleClutchDataMAccuracyModePN5physx19PxVehicleClutchDataENS_27PxVehicleClutchAccuracyMode4EnumE($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 HEAP32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z35getPxVehicleClutchDataMAccuracyModePKN5physx19PxVehicleClutchDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z41setPxVehicleClutchDataMEstimateIterationsPN5physx19PxVehicleClutchDataEj($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 HEAP32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z41getPxVehicleClutchDataMEstimateIterationsPKN5physx19PxVehicleClutchDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z42getPxVehicleTireLoadFilterData_DenominatorPKN5physx27PxVehicleTireLoadFilterDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx40PxVehicleTireLoadFilterDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524768;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 560;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 186;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 524784;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 561;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 187;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 149;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 524808;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 562;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 188;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 150;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 524840;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 563;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 189;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 151;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 524864;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 564;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 190;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 152;
 STACKTOP = sp;return;
}
function __Z48setPxVehicleTireLoadFilterDataMMinNormalisedLoadPN5physx27PxVehicleTireLoadFilterDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$inOwner>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z48getPxVehicleTireLoadFilterDataMMinNormalisedLoadPKN5physx27PxVehicleTireLoadFilterDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inOwner>>2]);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z56setPxVehicleTireLoadFilterDataMMinFilteredNormalisedLoadPN5physx27PxVehicleTireLoadFilterDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z56getPxVehicleTireLoadFilterDataMMinFilteredNormalisedLoadPKN5physx27PxVehicleTireLoadFilterDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z48setPxVehicleTireLoadFilterDataMMaxNormalisedLoadPN5physx27PxVehicleTireLoadFilterDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z48getPxVehicleTireLoadFilterDataMMaxNormalisedLoadPKN5physx27PxVehicleTireLoadFilterDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z56setPxVehicleTireLoadFilterDataMMaxFilteredNormalisedLoadPN5physx27PxVehicleTireLoadFilterDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z56getPxVehicleTireLoadFilterDataMMaxFilteredNormalisedLoadPKN5physx27PxVehicleTireLoadFilterDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z33getPxVehicleWheelData_RecipRadiusPKN5physx18PxVehicleWheelDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z30getPxVehicleWheelData_RecipMOIPKN5physx18PxVehicleWheelDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx31PxVehicleWheelDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 524896;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 567;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 191;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 524216;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 568;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 192;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 524912;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 569;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 193;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 153;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 524920;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 570;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 194;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 154;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 524208;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 571;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 195;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 155;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 524200;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 572;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 196;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 156;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 524928;
 $22 = (($this) + 92|0);
 HEAP32[$22>>2] = 573;
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = 197;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = 157;
 $25 = (($this) + 104|0);
 HEAP32[$25>>2] = 524944;
 $26 = (($this) + 108|0);
 HEAP32[$26>>2] = 574;
 $27 = (($this) + 112|0);
 HEAP32[$27>>2] = 198;
 $28 = (($this) + 116|0);
 HEAP32[$28>>2] = 158;
 $29 = (($this) + 120|0);
 HEAP32[$29>>2] = 524960;
 $30 = (($this) + 124|0);
 HEAP32[$30>>2] = 575;
 $31 = (($this) + 128|0);
 HEAP32[$31>>2] = 199;
 $32 = (($this) + 132|0);
 HEAP32[$32>>2] = 159;
 $33 = (($this) + 136|0);
 HEAP32[$33>>2] = 524984;
 $34 = (($this) + 140|0);
 HEAP32[$34>>2] = 576;
 $35 = (($this) + 144|0);
 HEAP32[$35>>2] = 200;
 $36 = (($this) + 148|0);
 HEAP32[$36>>2] = 160;
 $37 = (($this) + 152|0);
 HEAP32[$37>>2] = 525000;
 $38 = (($this) + 156|0);
 HEAP32[$38>>2] = 577;
 $39 = (($this) + 160|0);
 HEAP32[$39>>2] = 201;
 $40 = (($this) + 164|0);
 HEAP32[$40>>2] = 161;
 STACKTOP = sp;return;
}
function __Z28setPxVehicleWheelDataMRadiusPN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$inOwner>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z28getPxVehicleWheelDataMRadiusPKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inOwner>>2]);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z27setPxVehicleWheelDataMWidthPN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z27getPxVehicleWheelDataMWidthPKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z26setPxVehicleWheelDataMMassPN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z26getPxVehicleWheelDataMMassPKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z25setPxVehicleWheelDataMMOIPN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z25getPxVehicleWheelDataMMOIPKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z33setPxVehicleWheelDataMDampingRatePN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 16|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z33getPxVehicleWheelDataMDampingRatePKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z36setPxVehicleWheelDataMMaxBrakeTorquePN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 20|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z36getPxVehicleWheelDataMMaxBrakeTorquePKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 20|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z40setPxVehicleWheelDataMMaxHandBrakeTorquePN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 24|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z40getPxVehicleWheelDataMMaxHandBrakeTorquePKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z30setPxVehicleWheelDataMMaxSteerPN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 28|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z30getPxVehicleWheelDataMMaxSteerPKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 28|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z30setPxVehicleWheelDataMToeAnglePN5physx18PxVehicleWheelDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 32|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z30getPxVehicleWheelDataMToeAnglePKN5physx18PxVehicleWheelDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 32|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z46getPxVehicleSuspensionData_RecipMaxCompressionPKN5physx23PxVehicleSuspensionDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 32|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z40getPxVehicleSuspensionData_RecipMaxDroopPKN5physx23PxVehicleSuspensionDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z58setPxVehicleSuspensionData_MassAndPreserveNaturalFrequencyPN5physx23PxVehicleSuspensionDataEf($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = Math_fround($inArg);
 var $0 = Math_fround(0), $1 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inObj>>2]);
 $1 = (($inObj) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($inArg / $2);
 $4 = Math_fround($0 * $3);
 HEAPF32[$inObj>>2] = $4;
 HEAPF32[$1>>2] = $inArg;
 STACKTOP = sp;return;
}
function __ZN5physx36PxVehicleSuspensionDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525016;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 580;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 202;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 525040;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 581;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 203;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 525056;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 582;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 162;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 525088;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 583;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 204;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 163;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 525104;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 584;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 205;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 164;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 525128;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 585;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 206;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 165;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 525144;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 586;
 $22 = (($this) + 92|0);
 HEAP32[$22>>2] = 207;
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = 166;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = 525160;
 $25 = (($this) + 104|0);
 HEAP32[$25>>2] = 587;
 $26 = (($this) + 108|0);
 HEAP32[$26>>2] = 208;
 $27 = (($this) + 112|0);
 HEAP32[$27>>2] = 167;
 $28 = (($this) + 116|0);
 HEAP32[$28>>2] = 525176;
 $29 = (($this) + 120|0);
 HEAP32[$29>>2] = 588;
 $30 = (($this) + 124|0);
 HEAP32[$30>>2] = 209;
 $31 = (($this) + 128|0);
 HEAP32[$31>>2] = 168;
 $32 = (($this) + 132|0);
 HEAP32[$32>>2] = 525192;
 $33 = (($this) + 136|0);
 HEAP32[$33>>2] = 589;
 $34 = (($this) + 140|0);
 HEAP32[$34>>2] = 210;
 $35 = (($this) + 144|0);
 HEAP32[$35>>2] = 169;
 $36 = (($this) + 148|0);
 HEAP32[$36>>2] = 525216;
 $37 = (($this) + 152|0);
 HEAP32[$37>>2] = 590;
 $38 = (($this) + 156|0);
 HEAP32[$38>>2] = 211;
 $39 = (($this) + 160|0);
 HEAP32[$39>>2] = 170;
 STACKTOP = sp;return;
}
function __Z41setPxVehicleSuspensionDataMSpringStrengthPN5physx23PxVehicleSuspensionDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$inOwner>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z41getPxVehicleSuspensionDataMSpringStrengthPKN5physx23PxVehicleSuspensionDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inOwner>>2]);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z43setPxVehicleSuspensionDataMSpringDamperRatePN5physx23PxVehicleSuspensionDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z43getPxVehicleSuspensionDataMSpringDamperRatePKN5physx23PxVehicleSuspensionDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z41setPxVehicleSuspensionDataMMaxCompressionPN5physx23PxVehicleSuspensionDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z41getPxVehicleSuspensionDataMMaxCompressionPKN5physx23PxVehicleSuspensionDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z35setPxVehicleSuspensionDataMMaxDroopPN5physx23PxVehicleSuspensionDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z35getPxVehicleSuspensionDataMMaxDroopPKN5physx23PxVehicleSuspensionDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z37setPxVehicleSuspensionDataMSprungMassPN5physx23PxVehicleSuspensionDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 16|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z37getPxVehicleSuspensionDataMSprungMassPKN5physx23PxVehicleSuspensionDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z39setPxVehicleSuspensionDataMCamberAtRestPN5physx23PxVehicleSuspensionDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 20|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z39getPxVehicleSuspensionDataMCamberAtRestPKN5physx23PxVehicleSuspensionDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 20|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z49setPxVehicleSuspensionDataMCamberAtMaxCompressionPN5physx23PxVehicleSuspensionDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 24|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z49getPxVehicleSuspensionDataMCamberAtMaxCompressionPKN5physx23PxVehicleSuspensionDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z43setPxVehicleSuspensionDataMCamberAtMaxDroopPN5physx23PxVehicleSuspensionDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 28|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z43getPxVehicleSuspensionDataMCamberAtMaxDroopPKN5physx23PxVehicleSuspensionDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 28|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z61getPxVehicleTireData_RecipLongitudinalStiffnessPerUnitGravityPKN5physx17PxVehicleTireDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 44|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z54getPxVehicleTireData_FrictionVsSlipGraphRecipx1Minusx0PKN5physx17PxVehicleTireDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z54getPxVehicleTireData_FrictionVsSlipGraphRecipx2Minusx1PKN5physx17PxVehicleTireDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 52|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx30PxVehicleTireDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525240;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 593;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 212;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 525288;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 594;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 213;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 525328;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 595;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 214;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 525368;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 596;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 215;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 171;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 525384;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 597;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 216;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 172;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 525400;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 598;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 217;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 173;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 525440;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 599;
 $22 = (($this) + 92|0);
 HEAP32[$22>>2] = 218;
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = 174;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = 524616;
 $25 = (($this) + 104|0);
 HEAP32[$25>>2] = 600;
 $26 = (($this) + 108|0);
 HEAP32[$26>>2] = 3175;
 $27 = (($this) + 112|0);
 HEAP32[$27>>2] = 2541;
 $28 = (($this) + 116|0);
 __ZN5physx28MFrictionVsSlipGraphPropertyC2Ev($28);
 STACKTOP = sp;return;
}
function __Z30setPxVehicleTireDataMLatStiffXPN5physx17PxVehicleTireDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$inOwner>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z30getPxVehicleTireDataMLatStiffXPKN5physx17PxVehicleTireDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inOwner>>2]);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z30setPxVehicleTireDataMLatStiffYPN5physx17PxVehicleTireDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z30getPxVehicleTireDataMLatStiffYPKN5physx17PxVehicleTireDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z56setPxVehicleTireDataMLongitudinalStiffnessPerUnitGravityPN5physx17PxVehicleTireDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z56getPxVehicleTireDataMLongitudinalStiffnessPerUnitGravityPKN5physx17PxVehicleTireDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z50setPxVehicleTireDataMCamberStiffnessPerUnitGravityPN5physx17PxVehicleTireDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z50getPxVehicleTireDataMCamberStiffnessPerUnitGravityPKN5physx17PxVehicleTireDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z25setPxVehicleTireDataMTypePN5physx17PxVehicleTireDataEj($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 40|0);
 HEAP32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z25getPxVehicleTireDataMTypePKN5physx17PxVehicleTireDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z37setPxVehicleWheelsSimData_ChassisMassPN5physx22PxVehicleWheelsSimDataEf($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = Math_fround($inArg);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData14setChassisMassEf($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z40getPxVehicleWheelsSimData_SuspensionDataPKN5physx22PxVehicleWheelsSimDataEj($agg$result,$inObj,$index) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData17getSuspensionDataEj($inObj,$index)|0);
 dest=$agg$result+0|0; src=$0+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z42getNbPxVehicleWheelsSimData_SuspensionDataPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z40setPxVehicleWheelsSimData_SuspensionDataPN5physx22PxVehicleWheelsSimDataEjNS_23PxVehicleSuspensionDataE($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData17setSuspensionDataEjRKNS_23PxVehicleSuspensionDataE($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z35getPxVehicleWheelsSimData_WheelDataPKN5physx22PxVehicleWheelsSimDataEj($agg$result,$inObj,$index) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData12getWheelDataEj($inObj,$index)|0);
 dest=$agg$result+0|0; src=$0+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z37getNbPxVehicleWheelsSimData_WheelDataPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z35setPxVehicleWheelsSimData_WheelDataPN5physx22PxVehicleWheelsSimDataEjNS_18PxVehicleWheelDataE($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData12setWheelDataEjRKNS_18PxVehicleWheelDataE($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z34getPxVehicleWheelsSimData_TireDataPKN5physx22PxVehicleWheelsSimDataEj($agg$result,$inObj,$index) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData11getTireDataEj($inObj,$index)|0);
 dest=$agg$result+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z36getNbPxVehicleWheelsSimData_TireDataPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z34setPxVehicleWheelsSimData_TireDataPN5physx22PxVehicleWheelsSimDataEjNS_17PxVehicleTireDataE($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData11setTireDataEjRKNS_17PxVehicleTireDataE($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z45getPxVehicleWheelsSimData_SuspTravelDirectionPKN5physx22PxVehicleWheelsSimDataEj($agg$result,$inObj,$index) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData22getSuspTravelDirectionEj($inObj,$index)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __Z47getNbPxVehicleWheelsSimData_SuspTravelDirectionPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z45setPxVehicleWheelsSimData_SuspTravelDirectionPN5physx22PxVehicleWheelsSimDataEjNS_6PxVec3E($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData22setSuspTravelDirectionEjRKNS_6PxVec3E($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z49getPxVehicleWheelsSimData_SuspForceAppPointOffsetPKN5physx22PxVehicleWheelsSimDataEj($agg$result,$inObj,$index) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData26getSuspForceAppPointOffsetEj($inObj,$index)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __Z51getNbPxVehicleWheelsSimData_SuspForceAppPointOffsetPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z49setPxVehicleWheelsSimData_SuspForceAppPointOffsetPN5physx22PxVehicleWheelsSimDataEjNS_6PxVec3E($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData26setSuspForceAppPointOffsetEjRKNS_6PxVec3E($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z49getPxVehicleWheelsSimData_TireForceAppPointOffsetPKN5physx22PxVehicleWheelsSimDataEj($agg$result,$inObj,$index) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData26getTireForceAppPointOffsetEj($inObj,$index)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __Z51getNbPxVehicleWheelsSimData_TireForceAppPointOffsetPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z49setPxVehicleWheelsSimData_TireForceAppPointOffsetPN5physx22PxVehicleWheelsSimDataEjNS_6PxVec3E($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData26setTireForceAppPointOffsetEjRKNS_6PxVec3E($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z43getPxVehicleWheelsSimData_WheelCentreOffsetPKN5physx22PxVehicleWheelsSimDataEj($agg$result,$inObj,$index) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData20getWheelCentreOffsetEj($inObj,$index)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __Z45getNbPxVehicleWheelsSimData_WheelCentreOffsetPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z43setPxVehicleWheelsSimData_WheelCentreOffsetPN5physx22PxVehicleWheelsSimDataEjNS_6PxVec3E($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData20setWheelCentreOffsetEjRKNS_6PxVec3E($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z43getPxVehicleWheelsSimData_WheelShapeMappingPKN5physx22PxVehicleWheelsSimDataEj($inObj,$index) {
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData20getWheelShapeMappingEj($inObj,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z45getNbPxVehicleWheelsSimData_WheelShapeMappingPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z43setPxVehicleWheelsSimData_WheelShapeMappingPN5physx22PxVehicleWheelsSimDataEji($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData20setWheelShapeMappingEji($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z46getPxVehicleWheelsSimData_SceneQueryFilterDataPKN5physx22PxVehicleWheelsSimDataEj($agg$result,$inObj,$index) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5physx22PxVehicleWheelsSimData23getSceneQueryFilterDataEj($inObj,$index)|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __Z48getNbPxVehicleWheelsSimData_SceneQueryFilterDataPKN5physx22PxVehicleWheelsSimDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z46setPxVehicleWheelsSimData_SceneQueryFilterDataPN5physx22PxVehicleWheelsSimDataEjNS_12PxFilterDataE($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = $inValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z44setPxVehicleWheelsSimData_TireLoadFilterDataPN5physx22PxVehicleWheelsSimDataERKNS_27PxVehicleTireLoadFilterDataE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData21setTireLoadFilterDataERKNS_27PxVehicleTireLoadFilterDataE($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z44getPxVehicleWheelsSimData_TireLoadFilterDataPKN5physx22PxVehicleWheelsSimDataE($agg$result,$inObj) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=HEAP32[$inObj+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$inObj+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$inObj+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$inObj+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$inObj+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$inObj+20>>2]|0;HEAP32[$agg$result+24>>2]=HEAP32[$inObj+24>>2]|0;HEAP32[$agg$result+28>>2]=HEAP32[$inObj+28>>2]|0;
 STACKTOP = sp;return;
}
function __Z48setPxVehicleWheelsSimData_MinLongSlipDenominatorPN5physx22PxVehicleWheelsSimDataEf($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = Math_fround($inArg);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsSimData25setMinLongSlipDenominatorEf($inObj,$inArg);
 STACKTOP = sp;return;
}
function __ZN5physx35PxVehicleWheelsSimDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525472;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 608;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 175;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 525488;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 609;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 1597;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 1598;
 $6 = (($this) + 32|0);
 HEAP32[$6>>2] = 3176;
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = 525504;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = 610;
 $9 = (($this) + 44|0);
 HEAP32[$9>>2] = 1599;
 $10 = (($this) + 48|0);
 HEAP32[$10>>2] = 1600;
 $11 = (($this) + 56|0);
 HEAP32[$11>>2] = 3177;
 $12 = (($this) + 60|0);
 HEAP32[$12>>2] = 525520;
 $13 = (($this) + 64|0);
 HEAP32[$13>>2] = 611;
 $14 = (($this) + 68|0);
 HEAP32[$14>>2] = 1601;
 $15 = (($this) + 72|0);
 HEAP32[$15>>2] = 1602;
 $16 = (($this) + 80|0);
 HEAP32[$16>>2] = 3178;
 $17 = (($this) + 84|0);
 HEAP32[$17>>2] = 525536;
 $18 = (($this) + 88|0);
 HEAP32[$18>>2] = 612;
 $19 = (($this) + 92|0);
 HEAP32[$19>>2] = 1603;
 $20 = (($this) + 96|0);
 HEAP32[$20>>2] = 1604;
 $21 = (($this) + 104|0);
 HEAP32[$21>>2] = 3179;
 $22 = (($this) + 108|0);
 HEAP32[$22>>2] = 525560;
 $23 = (($this) + 112|0);
 HEAP32[$23>>2] = 613;
 $24 = (($this) + 116|0);
 HEAP32[$24>>2] = 1605;
 $25 = (($this) + 120|0);
 HEAP32[$25>>2] = 1606;
 $26 = (($this) + 128|0);
 HEAP32[$26>>2] = 3180;
 $27 = (($this) + 132|0);
 HEAP32[$27>>2] = 525584;
 $28 = (($this) + 136|0);
 HEAP32[$28>>2] = 614;
 $29 = (($this) + 140|0);
 HEAP32[$29>>2] = 1607;
 $30 = (($this) + 144|0);
 HEAP32[$30>>2] = 1608;
 $31 = (($this) + 152|0);
 HEAP32[$31>>2] = 3181;
 $32 = (($this) + 156|0);
 HEAP32[$32>>2] = 525608;
 $33 = (($this) + 160|0);
 HEAP32[$33>>2] = 615;
 $34 = (($this) + 164|0);
 HEAP32[$34>>2] = 1609;
 $35 = (($this) + 168|0);
 HEAP32[$35>>2] = 1610;
 $36 = (($this) + 176|0);
 HEAP32[$36>>2] = 3182;
 $37 = (($this) + 180|0);
 HEAP32[$37>>2] = 525632;
 $38 = (($this) + 184|0);
 HEAP32[$38>>2] = 616;
 $39 = (($this) + 188|0);
 HEAP32[$39>>2] = 1611;
 $40 = (($this) + 192|0);
 HEAP32[$40>>2] = 2348;
 $41 = (($this) + 200|0);
 HEAP32[$41>>2] = 3183;
 $42 = (($this) + 204|0);
 HEAP32[$42>>2] = 525656;
 $43 = (($this) + 208|0);
 HEAP32[$43>>2] = 617;
 $44 = (($this) + 212|0);
 HEAP32[$44>>2] = 1612;
 $45 = (($this) + 216|0);
 HEAP32[$45>>2] = 1613;
 $46 = (($this) + 224|0);
 HEAP32[$46>>2] = 3184;
 $47 = (($this) + 228|0);
 HEAP32[$47>>2] = 525680;
 $48 = (($this) + 232|0);
 HEAP32[$48>>2] = 618;
 $49 = (($this) + 236|0);
 HEAP32[$49>>2] = 2542;
 $50 = (($this) + 240|0);
 HEAP32[$50>>2] = 2543;
 $51 = (($this) + 244|0);
 HEAP32[$51>>2] = 525704;
 $52 = (($this) + 248|0);
 HEAP32[$52>>2] = 619;
 $53 = (($this) + 252|0);
 HEAP32[$53>>2] = 176;
 STACKTOP = sp;return;
}
function __Z49setPxVehicleWheelsDynData_TireForceShaderFunctionPN5physx22PxVehicleWheelsDynDataEPFvPKvffffffffffffRfS4_S4_S4_E($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsDynData26setTireForceShaderFunctionEPFvPKvffffffffffffRfS3_S3_S3_E($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z44getPxVehicleWheelsDynData_WheelRotationSpeedPKN5physx22PxVehicleWheelsDynDataEj($inObj,$index) {
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZNK5physx22PxVehicleWheelsDynData21getWheelRotationSpeedEj($inObj,$index)));
 STACKTOP = sp;return (Math_fround($0));
}
function __Z46getNbPxVehicleWheelsDynData_WheelRotationSpeedPKN5physx22PxVehicleWheelsDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z44setPxVehicleWheelsDynData_WheelRotationSpeedPN5physx22PxVehicleWheelsDynDataEjf($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = Math_fround($inValue);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsDynData21setWheelRotationSpeedEjf($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z44getPxVehicleWheelsDynData_WheelRotationAnglePKN5physx22PxVehicleWheelsDynDataEj($inObj,$index) {
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZNK5physx22PxVehicleWheelsDynData21getWheelRotationAngleEj($inObj,$index)));
 STACKTOP = sp;return (Math_fround($0));
}
function __Z46getNbPxVehicleWheelsDynData_WheelRotationAnglePKN5physx22PxVehicleWheelsDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z44setPxVehicleWheelsDynData_WheelRotationAnglePN5physx22PxVehicleWheelsDynDataEjf($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = Math_fround($inValue);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx22PxVehicleWheelsDynData21setWheelRotationAngleEjf($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z39getPxVehicleWheelsDynData_Wheel4DynDataPKN5physx22PxVehicleWheelsDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$inObj>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx35PxVehicleWheelsDynDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525728;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 622;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 2544;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 525752;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 623;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 34;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 47;
 $6 = (($this) + 32|0);
 HEAP32[$6>>2] = 3185;
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = 525776;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = 624;
 $9 = (($this) + 44|0);
 HEAP32[$9>>2] = 35;
 $10 = (($this) + 48|0);
 HEAP32[$10>>2] = 48;
 $11 = (($this) + 56|0);
 HEAP32[$11>>2] = 3186;
 $12 = (($this) + 60|0);
 HEAP32[$12>>2] = 525800;
 $13 = (($this) + 64|0);
 HEAP32[$13>>2] = 625;
 $14 = (($this) + 68|0);
 HEAP32[$14>>2] = 3187;
 STACKTOP = sp;return;
}
function __Z30getPxVehicleWheels_VehicleTypePKN5physx15PxVehicleWheelsE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 113|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 STACKTOP = sp;return ($2|0);
}
function __Z36getPxVehicleWheels_RigidDynamicActorPKN5physx15PxVehicleWheelsE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z35getPxVehicleWheels_ConcreteTypeNamePKN5physx15PxVehicleWheelsE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$inObj>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($inObj)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z32setPxVehicleWheelsMWheelsSimDataPN5physx15PxVehicleWheelsENS_22PxVehicleWheelsSimDataE($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 (__ZN5physx22PxVehicleWheelsSimDataaSERKS0_($0,$inData)|0);
 STACKTOP = sp;return;
}
function __Z32getPxVehicleWheelsMWheelsSimDataPKN5physx15PxVehicleWheelsE($agg$result,$inOwner) {
 $agg$result = $agg$result|0;
 $inOwner = $inOwner|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 8|0);
 dest=$agg$result+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z32setPxVehicleWheelsMWheelsDynDataPN5physx15PxVehicleWheelsENS_22PxVehicleWheelsDynDataE($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 72|0);
 ;HEAP32[$0+0>>2]=HEAP32[$inData+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$inData+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$inData+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$inData+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$inData+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$inData+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$inData+24>>2]|0;HEAP32[$0+28>>2]=HEAP32[$inData+28>>2]|0;
 STACKTOP = sp;return;
}
function __Z32getPxVehicleWheelsMWheelsDynDataPKN5physx15PxVehicleWheelsE($agg$result,$inOwner) {
 $agg$result = $agg$result|0;
 $inOwner = $inOwner|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 72|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$agg$result+24>>2]=HEAP32[$0+24>>2]|0;HEAP32[$agg$result+28>>2]=HEAP32[$0+28>>2]|0;
 STACKTOP = sp;return;
}
function __Z36getPxVehicleDriveDynData_AnalogInputPKN5physx21PxVehicleDriveDynDataEj($inObj,$index) {
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZNK5physx21PxVehicleDriveDynData14getAnalogInputEj($inObj,$index)));
 STACKTOP = sp;return (Math_fround($0));
}
function __Z38getNbPxVehicleDriveDynData_AnalogInputPKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 16;
}
function __Z36setPxVehicleDriveDynData_AnalogInputPN5physx21PxVehicleDriveDynDataEjf($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = Math_fround($inValue);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx21PxVehicleDriveDynData14setAnalogInputEjf($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z31setPxVehicleDriveDynData_GearUpPN5physx21PxVehicleDriveDynDataEb($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 65|0);
 $1 = $inArg&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __Z31getPxVehicleDriveDynData_GearUpPKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 65|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __Z33setPxVehicleDriveDynData_GearDownPN5physx21PxVehicleDriveDynDataEb($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 66|0);
 $1 = $inArg&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __Z33getPxVehicleDriveDynData_GearDownPKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 66|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __Z37setPxVehicleDriveDynData_UseAutoGearsPN5physx21PxVehicleDriveDynDataEb($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 64|0);
 $1 = $inArg&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __Z37getPxVehicleDriveDynData_UseAutoGearsPKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 64|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __Z36setPxVehicleDriveDynData_CurrentGearPN5physx21PxVehicleDriveDynDataEj($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 68|0);
 HEAP32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z36getPxVehicleDriveDynData_CurrentGearPKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z35setPxVehicleDriveDynData_TargetGearPN5physx21PxVehicleDriveDynDataEj($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 72|0);
 HEAP32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z35getPxVehicleDriveDynData_TargetGearPKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z44setPxVehicleDriveDynData_EngineRotationSpeedPN5physx21PxVehicleDriveDynDataEf($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = Math_fround($inArg);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 76|0);
 HEAPF32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z44getPxVehicleDriveDynData_EngineRotationSpeedPKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 76|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z35setPxVehicleDriveDynData_GearChangePN5physx21PxVehicleDriveDynDataEj($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 72|0);
 HEAP32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z35getPxVehicleDriveDynData_GearChangePKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z39setPxVehicleDriveDynData_GearSwitchTimePN5physx21PxVehicleDriveDynDataEf($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = Math_fround($inArg);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 80|0);
 HEAPF32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z39getPxVehicleDriveDynData_GearSwitchTimePKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z42setPxVehicleDriveDynData_AutoBoxSwitchTimePN5physx21PxVehicleDriveDynDataEf($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = Math_fround($inArg);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 84|0);
 HEAPF32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z42getPxVehicleDriveDynData_AutoBoxSwitchTimePKN5physx21PxVehicleDriveDynDataE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 84|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx34PxVehicleDriveDynDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525912;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 635;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 36;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 49;
 $3 = (($this) + 20|0);
 HEAP32[$3>>2] = 3188;
 $4 = (($this) + 24|0);
 HEAP32[$4>>2] = 525928;
 $5 = (($this) + 28|0);
 HEAP32[$5>>2] = 636;
 $6 = (($this) + 32|0);
 HEAP32[$6>>2] = 3189;
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = 2545;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = 525936;
 $9 = (($this) + 44|0);
 HEAP32[$9>>2] = 637;
 $10 = (($this) + 48|0);
 HEAP32[$10>>2] = 3190;
 $11 = (($this) + 52|0);
 HEAP32[$11>>2] = 2546;
 $12 = (($this) + 56|0);
 HEAP32[$12>>2] = 525952;
 $13 = (($this) + 60|0);
 HEAP32[$13>>2] = 638;
 $14 = (($this) + 64|0);
 HEAP32[$14>>2] = 3191;
 $15 = (($this) + 68|0);
 HEAP32[$15>>2] = 2547;
 $16 = (($this) + 72|0);
 HEAP32[$16>>2] = 525968;
 $17 = (($this) + 76|0);
 HEAP32[$17>>2] = 639;
 $18 = (($this) + 80|0);
 HEAP32[$18>>2] = 3192;
 $19 = (($this) + 84|0);
 HEAP32[$19>>2] = 2548;
 $20 = (($this) + 88|0);
 HEAP32[$20>>2] = 525984;
 $21 = (($this) + 92|0);
 HEAP32[$21>>2] = 640;
 $22 = (($this) + 96|0);
 HEAP32[$22>>2] = 3193;
 $23 = (($this) + 100|0);
 HEAP32[$23>>2] = 2549;
 $24 = (($this) + 104|0);
 HEAP32[$24>>2] = 526000;
 $25 = (($this) + 108|0);
 HEAP32[$25>>2] = 641;
 $26 = (($this) + 112|0);
 HEAP32[$26>>2] = 219;
 $27 = (($this) + 116|0);
 HEAP32[$27>>2] = 177;
 $28 = (($this) + 120|0);
 HEAP32[$28>>2] = 526024;
 $29 = (($this) + 124|0);
 HEAP32[$29>>2] = 642;
 $30 = (($this) + 128|0);
 HEAP32[$30>>2] = 3194;
 $31 = (($this) + 132|0);
 HEAP32[$31>>2] = 2550;
 $32 = (($this) + 136|0);
 HEAP32[$32>>2] = 526040;
 $33 = (($this) + 140|0);
 HEAP32[$33>>2] = 643;
 $34 = (($this) + 144|0);
 HEAP32[$34>>2] = 220;
 $35 = (($this) + 148|0);
 HEAP32[$35>>2] = 178;
 $36 = (($this) + 152|0);
 HEAP32[$36>>2] = 526056;
 $37 = (($this) + 156|0);
 HEAP32[$37>>2] = 644;
 $38 = (($this) + 160|0);
 HEAP32[$38>>2] = 221;
 $39 = (($this) + 164|0);
 HEAP32[$39>>2] = 179;
 $40 = (($this) + 168|0);
 HEAP32[$40>>2] = 526080;
 $41 = (($this) + 172|0);
 HEAP32[$41>>2] = 645;
 $42 = (($this) + 176|0);
 HEAP32[$42>>2] = 3195;
 $43 = (($this) + 180|0);
 HEAP32[$43>>2] = 2551;
 $44 = (($this) + 184|0);
 HEAP32[$44>>2] = 526096;
 $45 = (($this) + 188|0);
 HEAP32[$45>>2] = 646;
 $46 = (($this) + 192|0);
 HEAP32[$46>>2] = 3196;
 $47 = (($this) + 196|0);
 HEAP32[$47>>2] = 2552;
 $48 = (($this) + 200|0);
 HEAP32[$48>>2] = 526112;
 $49 = (($this) + 204|0);
 HEAP32[$49>>2] = 647;
 $50 = (($this) + 208|0);
 HEAP32[$50>>2] = 3197;
 $51 = (($this) + 212|0);
 HEAP32[$51>>2] = 2553;
 $52 = (($this) + 216|0);
 HEAP32[$52>>2] = 526136;
 $53 = (($this) + 220|0);
 HEAP32[$53>>2] = 648;
 $54 = (($this) + 224|0);
 HEAP32[$54>>2] = 3198;
 $55 = (($this) + 228|0);
 HEAP32[$55>>2] = 2554;
 $56 = (($this) + 232|0);
 HEAP32[$56>>2] = 526152;
 $57 = (($this) + 236|0);
 HEAP32[$57>>2] = 649;
 $58 = (($this) + 240|0);
 HEAP32[$58>>2] = 3199;
 $59 = (($this) + 244|0);
 HEAP32[$59>>2] = 2555;
 $60 = (($this) + 248|0);
 HEAP32[$60>>2] = 526168;
 $61 = (($this) + 252|0);
 HEAP32[$61>>2] = 650;
 $62 = (($this) + 256|0);
 HEAP32[$62>>2] = 222;
 $63 = (($this) + 260|0);
 HEAP32[$63>>2] = 180;
 $64 = (($this) + 264|0);
 HEAP32[$64>>2] = 526184;
 $65 = (($this) + 268|0);
 HEAP32[$65>>2] = 651;
 $66 = (($this) + 272|0);
 HEAP32[$66>>2] = 223;
 $67 = (($this) + 276|0);
 HEAP32[$67>>2] = 181;
 $68 = (($this) + 280|0);
 HEAP32[$68>>2] = 526200;
 $69 = (($this) + 284|0);
 HEAP32[$69>>2] = 652;
 $70 = (($this) + 288|0);
 HEAP32[$70>>2] = 224;
 $71 = (($this) + 292|0);
 HEAP32[$71>>2] = 182;
 STACKTOP = sp;return;
}
function __Z37setPxVehicleDriveDynDataMUseAutoGearsPN5physx21PxVehicleDriveDynDataEb($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 64|0);
 $1 = $inData&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __Z37getPxVehicleDriveDynDataMUseAutoGearsPKN5physx21PxVehicleDriveDynDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 64|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __Z38setPxVehicleDriveDynDataMGearUpPressedPN5physx21PxVehicleDriveDynDataEb($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 65|0);
 $1 = $inData&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __Z38getPxVehicleDriveDynDataMGearUpPressedPKN5physx21PxVehicleDriveDynDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 65|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __Z40setPxVehicleDriveDynDataMGearDownPressedPN5physx21PxVehicleDriveDynDataEb($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 66|0);
 $1 = $inData&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __Z40getPxVehicleDriveDynDataMGearDownPressedPKN5physx21PxVehicleDriveDynDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 66|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __Z36setPxVehicleDriveDynDataMCurrentGearPN5physx21PxVehicleDriveDynDataEj($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 68|0);
 HEAP32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z36getPxVehicleDriveDynDataMCurrentGearPKN5physx21PxVehicleDriveDynDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z35setPxVehicleDriveDynDataMTargetGearPN5physx21PxVehicleDriveDynDataEj($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 72|0);
 HEAP32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z35getPxVehicleDriveDynDataMTargetGearPKN5physx21PxVehicleDriveDynDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z36setPxVehicleDriveDynDataMEnginespeedPN5physx21PxVehicleDriveDynDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 76|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z36getPxVehicleDriveDynDataMEnginespeedPKN5physx21PxVehicleDriveDynDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 76|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z39setPxVehicleDriveDynDataMGearSwitchTimePN5physx21PxVehicleDriveDynDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 80|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z39getPxVehicleDriveDynDataMGearSwitchTimePKN5physx21PxVehicleDriveDynDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z42setPxVehicleDriveDynDataMAutoBoxSwitchTimePN5physx21PxVehicleDriveDynDataEf($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 84|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __Z42getPxVehicleDriveDynDataMAutoBoxSwitchTimePKN5physx21PxVehicleDriveDynDataE($inOwner) {
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 84|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z35setPxVehicleDriveSimData_EngineDataPN5physx21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx21PxVehicleDriveSimData13setEngineDataERKNS_19PxVehicleEngineDataE($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z35getPxVehicleDriveSimData_EngineDataPKN5physx21PxVehicleDriveSimDataE($agg$result,$inObj) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 3;
 _memcpy(($agg$result|0),($inObj|0),($2|0))|0;
 $3 = (($agg$result) + 64|0);
 HEAP32[$3>>2] = $1;
 $4 = (($agg$result) + 80|0);
 $5 = (($inObj) + 80|0);
 ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$5+20>>2]|0;HEAP32[$4+24>>2]=HEAP32[$5+24>>2]|0;HEAP32[$4+28>>2]=HEAP32[$5+28>>2]|0;
 STACKTOP = sp;return;
}
function __Z34setPxVehicleDriveSimData_GearsDataPN5physx21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx21PxVehicleDriveSimData12setGearsDataERKNS_18PxVehicleGearsDataE($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z34getPxVehicleDriveSimData_GearsDataPKN5physx21PxVehicleDriveSimDataE($agg$result,$inObj) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 112|0);
 _memcpy(($agg$result|0),($0|0),144)|0;
 STACKTOP = sp;return;
}
function __Z35setPxVehicleDriveSimData_ClutchDataPN5physx21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx21PxVehicleDriveSimData13setClutchDataERKNS_19PxVehicleClutchDataE($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z35getPxVehicleDriveSimData_ClutchDataPKN5physx21PxVehicleDriveSimDataE($agg$result,$inObj) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 256|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __Z36setPxVehicleDriveSimData_AutoBoxDataPN5physx21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx21PxVehicleDriveSimData14setAutoBoxDataERKNS_20PxVehicleAutoBoxDataE($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z36getPxVehicleDriveSimData_AutoBoxDataPKN5physx21PxVehicleDriveSimDataE($agg$result,$inObj) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 272|0);
 _memcpy(($agg$result|0),($0|0),256)|0;
 STACKTOP = sp;return;
}
function __ZN5physx34PxVehicleDriveSimDataGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 526224;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 655;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 2556;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 2557;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 526240;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 656;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 2558;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 2559;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 526256;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 657;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 2560;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2561;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 526272;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 658;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 2562;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 2563;
 STACKTOP = sp;return;
}
function __Z35setPxVehicleDriveSimData4W_DiffDataPN5physx23PxVehicleDriveSimData4WERKNS_27PxVehicleDifferential4WDataE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx23PxVehicleDriveSimData4W11setDiffDataERKNS_27PxVehicleDifferential4WDataE($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z35getPxVehicleDriveSimData4W_DiffDataPKN5physx23PxVehicleDriveSimData4WE($agg$result,$inObj) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 528|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$agg$result+24>>2]=HEAP32[$0+24>>2]|0;HEAP32[$agg$result+28>>2]=HEAP32[$0+28>>2]|0;
 STACKTOP = sp;return;
}
function __Z48setPxVehicleDriveSimData4W_AckermannGeometryDataPN5physx23PxVehicleDriveSimData4WERKNS_30PxVehicleAckermannGeometryDataE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx23PxVehicleDriveSimData4W24setAckermannGeometryDataERKNS_30PxVehicleAckermannGeometryDataE($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z48getPxVehicleDriveSimData4W_AckermannGeometryDataPKN5physx23PxVehicleDriveSimData4WE($agg$result,$inObj) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 560|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx36PxVehicleDriveSimData4WGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 526224;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 655;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 2556;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 2557;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 526240;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 656;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 2558;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 2559;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 526256;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 657;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 2560;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2561;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 526272;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 658;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 2562;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 2563;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 526288;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 661;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 2564;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 2565;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 526304;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 662;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 2566;
 $22 = (($this) + 92|0);
 HEAP32[$22>>2] = 2567;
 STACKTOP = sp;return;
}
function __Z34getPxVehicleDrive_ConcreteTypeNamePKN5physx14PxVehicleDriveE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$inObj>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($inObj)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z30setPxVehicleDriveMDriveDynDataPN5physx14PxVehicleDriveENS_21PxVehicleDriveDynDataE($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 128|0);
 dest=$0+0|0; src=$inData+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z30getPxVehicleDriveMDriveDynDataPKN5physx14PxVehicleDriveE($agg$result,$inOwner) {
 $agg$result = $agg$result|0;
 $inOwner = $inOwner|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 128|0);
 dest=$agg$result+0|0; src=$0+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z36getPxVehicleDrive4W_ConcreteTypeNamePKN5physx16PxVehicleDrive4WE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$inObj>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($inObj)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx29PxVehicleDrive4WGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525816;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 628;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 3200;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 525832;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 629;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 3201;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 525856;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 630;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 3202;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 525880;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 631;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2568;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 2569;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 525896;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 632;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 2570;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 2571;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 525856;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 665;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 3203;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 526328;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 666;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 2572;
 $22 = (($this) + 92|0);
 HEAP32[$22>>2] = 2573;
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = 525856;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = 669;
 $25 = (($this) + 104|0);
 HEAP32[$25>>2] = 3204;
 $26 = (($this) + 108|0);
 HEAP32[$26>>2] = 526344;
 $27 = (($this) + 112|0);
 HEAP32[$27>>2] = 670;
 $28 = (($this) + 116|0);
 HEAP32[$28>>2] = 2574;
 $29 = (($this) + 120|0);
 HEAP32[$29>>2] = 2575;
 STACKTOP = sp;return;
}
function __Z32setPxVehicleDrive4WMDriveSimDataPN5physx16PxVehicleDrive4WENS_23PxVehicleDriveSimData4WE($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 224|0);
 $1 = (($inData) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($0|0),($inData|0),($3|0))|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($inOwner) + 288|0);
 HEAP32[$5>>2] = $4;
 $6 = (($inOwner) + 304|0);
 $7 = (($inData) + 80|0);
 ;HEAP32[$6+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$7+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$7+20>>2]|0;HEAP32[$6+24>>2]=HEAP32[$7+24>>2]|0;HEAP32[$6+28>>2]=HEAP32[$7+28>>2]|0;
 $8 = (($inOwner) + 336|0);
 $9 = (($inData) + 112|0);
 _memcpy(($8|0),($9|0),416)|0;
 $10 = (($inOwner) + 752|0);
 $11 = (($inData) + 528|0);
 dest=$10+0|0; src=$11+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z32getPxVehicleDrive4WMDriveSimDataPKN5physx16PxVehicleDrive4WE($agg$result,$inOwner) {
 $agg$result = $agg$result|0;
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 224|0);
 $1 = (($inOwner) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($agg$result|0),($0|0),($3|0))|0;
 $4 = (($agg$result) + 64|0);
 HEAP32[$4>>2] = $2;
 $5 = (($agg$result) + 80|0);
 $6 = (($inOwner) + 304|0);
 ;HEAP32[$5+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$5+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$5+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$5+28>>2]=HEAP32[$6+28>>2]|0;
 $7 = (($agg$result) + 112|0);
 $8 = (($inOwner) + 336|0);
 _memcpy(($7|0),($8|0),416)|0;
 $9 = (($agg$result) + 528|0);
 $10 = (($inOwner) + 752|0);
 dest=$9+0|0; src=$10+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z32setPxVehicleDriveTank_DriveModelPN5physx18PxVehicleDriveTankENS_30PxVehicleDriveTankControlModel4EnumE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 752|0);
 HEAP32[$0>>2] = $inArg;
 STACKTOP = sp;return;
}
function __Z32getPxVehicleDriveTank_DriveModelPKN5physx18PxVehicleDriveTankE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 752|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z38getPxVehicleDriveTank_ConcreteTypeNamePKN5physx18PxVehicleDriveTankE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$inObj>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($inObj)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx31PxVehicleDriveTankGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525816;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 628;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 3200;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 525832;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 629;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 3201;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 525856;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 630;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 3202;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 525880;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 631;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2568;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 2569;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 525896;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 632;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 2570;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 2571;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 525856;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 665;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 3203;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 526328;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 666;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 2572;
 $22 = (($this) + 92|0);
 HEAP32[$22>>2] = 2573;
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = 526360;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = 673;
 $25 = (($this) + 104|0);
 HEAP32[$25>>2] = 3205;
 $26 = (($this) + 108|0);
 HEAP32[$26>>2] = 2576;
 $27 = (($this) + 112|0);
 HEAP32[$27>>2] = 525856;
 $28 = (($this) + 116|0);
 HEAP32[$28>>2] = 674;
 $29 = (($this) + 120|0);
 HEAP32[$29>>2] = 3206;
 $30 = (($this) + 124|0);
 HEAP32[$30>>2] = 526344;
 $31 = (($this) + 128|0);
 HEAP32[$31>>2] = 675;
 $32 = (($this) + 132|0);
 HEAP32[$32>>2] = 2577;
 $33 = (($this) + 136|0);
 HEAP32[$33>>2] = 2578;
 STACKTOP = sp;return;
}
function __Z34setPxVehicleDriveTankMDriveSimDataPN5physx18PxVehicleDriveTankENS_21PxVehicleDriveSimDataE($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 224|0);
 $1 = (($inData) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($0|0),($inData|0),($3|0))|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($inOwner) + 288|0);
 HEAP32[$5>>2] = $4;
 $6 = (($inOwner) + 304|0);
 $7 = (($inData) + 80|0);
 ;HEAP32[$6+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$7+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$7+20>>2]|0;HEAP32[$6+24>>2]=HEAP32[$7+24>>2]|0;HEAP32[$6+28>>2]=HEAP32[$7+28>>2]|0;
 $8 = (($inOwner) + 336|0);
 $9 = (($inData) + 112|0);
 _memcpy(($8|0),($9|0),416)|0;
 STACKTOP = sp;return;
}
function __Z34getPxVehicleDriveTankMDriveSimDataPKN5physx18PxVehicleDriveTankE($agg$result,$inOwner) {
 $agg$result = $agg$result|0;
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 224|0);
 $1 = (($inOwner) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($agg$result|0),($0|0),($3|0))|0;
 $4 = (($agg$result) + 64|0);
 HEAP32[$4>>2] = $2;
 $5 = (($agg$result) + 80|0);
 $6 = (($inOwner) + 304|0);
 ;HEAP32[$5+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$5+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$5+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$5+28>>2]=HEAP32[$6+28>>2]|0;
 $7 = (($agg$result) + 112|0);
 $8 = (($inOwner) + 336|0);
 _memcpy(($7|0),($8|0),416)|0;
 STACKTOP = sp;return;
}
function __Z35setPxVehicleDriveSimDataNW_DiffDataPN5physx23PxVehicleDriveSimDataNWERKNS_27PxVehicleDifferentialNWDataE($inObj,$inArg) {
 $inObj = $inObj|0;
 $inArg = $inArg|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx23PxVehicleDriveSimDataNW11setDiffDataERKNS_27PxVehicleDifferentialNWDataE($inObj,$inArg);
 STACKTOP = sp;return;
}
function __Z35getPxVehicleDriveSimDataNW_DiffDataPKN5physx23PxVehicleDriveSimDataNWE($agg$result,$inObj) {
 $agg$result = $agg$result|0;
 $inObj = $inObj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 528|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx36PxVehicleDriveSimDataNWGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 526224;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 655;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 2556;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 2557;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 526240;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 656;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 2558;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 2559;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 526256;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 657;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 2560;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2561;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 526272;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 658;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 2562;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 2563;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 526288;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 678;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 2579;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 2580;
 STACKTOP = sp;return;
}
function __Z36getPxVehicleDriveNW_ConcreteTypeNamePKN5physx16PxVehicleDriveNWE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$inObj>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($inObj)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx29PxVehicleDriveNWGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525816;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 628;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 3200;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 525832;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 629;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 3201;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 525856;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 630;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 3202;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 525880;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 631;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2568;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 2569;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 525896;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 632;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 2570;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 2571;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 525856;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 665;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 3203;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 526328;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 666;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 2572;
 $22 = (($this) + 92|0);
 HEAP32[$22>>2] = 2573;
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = 525856;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = 681;
 $25 = (($this) + 104|0);
 HEAP32[$25>>2] = 3207;
 $26 = (($this) + 108|0);
 HEAP32[$26>>2] = 526344;
 $27 = (($this) + 112|0);
 HEAP32[$27>>2] = 682;
 $28 = (($this) + 116|0);
 HEAP32[$28>>2] = 2581;
 $29 = (($this) + 120|0);
 HEAP32[$29>>2] = 2582;
 STACKTOP = sp;return;
}
function __Z32setPxVehicleDriveNWMDriveSimDataPN5physx16PxVehicleDriveNWENS_23PxVehicleDriveSimDataNWE($inOwner,$inData) {
 $inOwner = $inOwner|0;
 $inData = $inData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 224|0);
 $1 = (($inData) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($0|0),($inData|0),($3|0))|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($inOwner) + 288|0);
 HEAP32[$5>>2] = $4;
 $6 = (($inOwner) + 304|0);
 $7 = (($inData) + 80|0);
 ;HEAP32[$6+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$7+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$7+20>>2]|0;HEAP32[$6+24>>2]=HEAP32[$7+24>>2]|0;HEAP32[$6+28>>2]=HEAP32[$7+28>>2]|0;
 $8 = (($inOwner) + 336|0);
 $9 = (($inData) + 112|0);
 _memcpy(($8|0),($9|0),416)|0;
 $10 = (($inOwner) + 752|0);
 $11 = (($inData) + 528|0);
 ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
 STACKTOP = sp;return;
}
function __Z32getPxVehicleDriveNWMDriveSimDataPKN5physx16PxVehicleDriveNWE($agg$result,$inOwner) {
 $agg$result = $agg$result|0;
 $inOwner = $inOwner|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inOwner) + 224|0);
 $1 = (($inOwner) + 288|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 3;
 _memcpy(($agg$result|0),($0|0),($3|0))|0;
 $4 = (($agg$result) + 64|0);
 HEAP32[$4>>2] = $2;
 $5 = (($agg$result) + 80|0);
 $6 = (($inOwner) + 304|0);
 ;HEAP32[$5+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$5+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$5+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$5+28>>2]=HEAP32[$6+28>>2]|0;
 $7 = (($agg$result) + 112|0);
 $8 = (($inOwner) + 336|0);
 _memcpy(($7|0),($8|0),416)|0;
 $9 = (($agg$result) + 528|0);
 $10 = (($inOwner) + 752|0);
 ;HEAP32[$9+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$10+12>>2]|0;
 STACKTOP = sp;return;
}
function __Z31getPxVehicleNoDrive_BrakeTorquePKN5physx16PxVehicleNoDriveEj($inObj,$index) {
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZNK5physx16PxVehicleNoDrive14getBrakeTorqueEj($inObj,$index)));
 STACKTOP = sp;return (Math_fround($0));
}
function __Z33getNbPxVehicleNoDrive_BrakeTorquePKN5physx16PxVehicleNoDriveE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z31setPxVehicleNoDrive_BrakeTorquePN5physx16PxVehicleNoDriveEjf($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = Math_fround($inValue);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx16PxVehicleNoDrive14setBrakeTorqueEjf($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z31getPxVehicleNoDrive_DriveTorquePKN5physx16PxVehicleNoDriveEj($inObj,$index) {
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZNK5physx16PxVehicleNoDrive14getDriveTorqueEj($inObj,$index)));
 STACKTOP = sp;return (Math_fround($0));
}
function __Z33getNbPxVehicleNoDrive_DriveTorquePKN5physx16PxVehicleNoDriveE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z31setPxVehicleNoDrive_DriveTorquePN5physx16PxVehicleNoDriveEjf($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = Math_fround($inValue);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx16PxVehicleNoDrive14setDriveTorqueEjf($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z30getPxVehicleNoDrive_SteerAnglePKN5physx16PxVehicleNoDriveEj($inObj,$index) {
 $inObj = $inObj|0;
 $index = $index|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZNK5physx16PxVehicleNoDrive13getSteerAngleEj($inObj,$index)));
 STACKTOP = sp;return (Math_fround($0));
}
function __Z32getNbPxVehicleNoDrive_SteerAnglePKN5physx16PxVehicleNoDriveE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inObj) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z30setPxVehicleNoDrive_SteerAnglePN5physx16PxVehicleNoDriveEjf($inObj,$inIndex,$inValue) {
 $inObj = $inObj|0;
 $inIndex = $inIndex|0;
 $inValue = Math_fround($inValue);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx16PxVehicleNoDrive13setSteerAngleEjf($inObj,$inIndex,$inValue);
 STACKTOP = sp;return;
}
function __Z36getPxVehicleNoDrive_ConcreteTypeNamePKN5physx16PxVehicleNoDriveE($inObj) {
 $inObj = $inObj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$inObj>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($inObj)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx29PxVehicleNoDriveGeneratedInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 525816;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 628;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 3200;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 525832;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 629;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 3201;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 525856;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 630;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 3202;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 525880;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 631;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 2568;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 2569;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 525896;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 632;
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = 2570;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 2571;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 526376;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 685;
 $18 = (($this) + 76|0);
 HEAP32[$18>>2] = 37;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 50;
 $20 = (($this) + 88|0);
 HEAP32[$20>>2] = 3208;
 $21 = (($this) + 92|0);
 HEAP32[$21>>2] = 526392;
 $22 = (($this) + 96|0);
 HEAP32[$22>>2] = 686;
 $23 = (($this) + 100|0);
 HEAP32[$23>>2] = 38;
 $24 = (($this) + 104|0);
 HEAP32[$24>>2] = 51;
 $25 = (($this) + 112|0);
 HEAP32[$25>>2] = 3209;
 $26 = (($this) + 116|0);
 HEAP32[$26>>2] = 526408;
 $27 = (($this) + 120|0);
 HEAP32[$27>>2] = 687;
 $28 = (($this) + 124|0);
 HEAP32[$28>>2] = 39;
 $29 = (($this) + 128|0);
 HEAP32[$29>>2] = 52;
 $30 = (($this) + 136|0);
 HEAP32[$30>>2] = 3210;
 $31 = (($this) + 140|0);
 HEAP32[$31>>2] = 525856;
 $32 = (($this) + 144|0);
 HEAP32[$32>>2] = 688;
 $33 = (($this) + 148|0);
 HEAP32[$33>>2] = 3211;
 STACKTOP = sp;return;
}
function __ZN5physx28MFrictionVsSlipGraphPropertyC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 526424;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 601;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 6;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 14;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 3;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 2;
 STACKTOP = sp;return;
}
function __ZN5physx23SetMFrictionVsSlipGraphEPNS_17PxVehicleTireDataEjjf($inTireData,$idx1,$idx2,$val) {
 $inTireData = $inTireData|0;
 $idx1 = $idx1|0;
 $idx2 = $idx2|0;
 $val = Math_fround($val);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (((($inTireData) + ($idx1<<3)|0) + ($idx2<<2)|0) + 16|0);
 HEAPF32[$0>>2] = $val;
 STACKTOP = sp;return;
}
function __ZN5physx23GetMFrictionVsSlipGraphEPKNS_17PxVehicleTireDataEjj($inTireData,$idx1,$idx2) {
 $inTireData = $inTireData|0;
 $idx1 = $idx1|0;
 $idx2 = $idx2|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (((($inTireData) + ($idx1<<3)|0) + ($idx2<<2)|0) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx20MTorqueCurvePropertyC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 526448;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 517;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 40;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 53;
 $3 = (($this) + 20|0);
 HEAP32[$3>>2] = 3212;
 STACKTOP = sp;return;
}
function __ZN5physx18GetTorqueCurvePairEPKNS_19PxVehicleEngineDataEj($inStats,$index) {
 $inStats = $inStats|0;
 $index = $index|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inStats) + ($index<<2)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5physx20GetNbTorqueCurvePairEPKNS_19PxVehicleEngineDataE($inStats) {
 $inStats = $inStats|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inStats) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 1;
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx18SetTorqueCurvePairEPNS_19PxVehicleEngineDataEjf($inStats,$index,$inData) {
 $inStats = $inStats|0;
 $index = $index|0;
 $inData = Math_fround($inData);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inStats) + ($index<<2)|0);
 HEAPF32[$0>>2] = $inData;
 STACKTOP = sp;return;
}
function __ZN5physx11AdjacenciesD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + -4|0);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$4);
 }
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx11Adjacencies22ComputeNbBoundaryEdgesEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0 = 0, $$Nb$1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $Nb$01 = 0, $Nb$1$i = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $Nb$01 = 0;$i$02 = 0;
 }
 while(1) {
  $5 = (($1) + (($i$02*12)|0)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 & 536870911;
  $8 = ($7|0)==(536870911);
  $$$i = $8&1;
  $9 = ((($1) + (($i$02*12)|0)|0) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & 536870911;
  $12 = ($11|0)==(536870911);
  $13 = $8 ? 2 : 1;
  $Nb$1$i = $12 ? $13 : $$$i;
  $14 = ((($1) + (($i$02*12)|0)|0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 & 536870911;
  $17 = ($16|0)==(536870911);
  $18 = $17&1;
  $$Nb$1$i = (($Nb$1$i) + ($Nb$01))|0;
  $19 = (($$Nb$1$i) + ($18))|0;
  $20 = (($i$02) + 1)|0;
  $21 = ($20>>>0)<($3>>>0);
  if ($21) {
   $Nb$01 = $19;$i$02 = $20;
  } else {
   $$0 = $19;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx18AdjacenciesBuilderC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18AdjacenciesBuilder4InitERKNS_17ADJACENCIESCREATEE($this,$create) {
 $this = $this|0;
 $create = $create|0;
 var $$$i$i$i = 0, $$$i$i$i$i = 0, $$$i$i$i3 = 0, $$0 = 0, $$01$i = 0, $$01$ph$i = 0, $$arith = 0, $$arith10 = 0, $$arith14 = 0, $$arith2 = 0, $$arith6 = 0, $$lcssa23 = 0, $$overflow = 0, $$overflow11 = 0, $$overflow15 = 0, $$overflow3 = 0, $$overflow7 = 0, $$pr = 0, $$pr43$pr = 0, $$pre = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Core$i = 0, $Count$0$i = 0, $Count$0$ph$i = 0, $EL = 0, $ELC = 0;
 var $LastRef0$0$ph$i = 0, $LastRef1$0$ph$i = 0, $Sorted$0$i = 0, $Sorted$0$ph$i = 0, $TmpBuffer$i = 0, $exitcond$i = 0, $exitcond36$i = 0, $i$014$i = 0, $i$024 = 0, $i$113$i = 0, $i1$04 = 0, $or$cond$i = 0, $storemerge = 0, $storemerge$i = 0, $storemerge1 = 0, $storemerge1$i = 0, $storemerge2 = 0, $storemerge2$i = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $vararg_buffer = sp;
 $Core$i = sp + 72|0;
 $0 = sp + 108|0;
 $TmpBuffer$i = sp + 32|0;
 $ELC = sp + 48|0;
 $EL = sp + 8|0;
 $1 = HEAP32[$create>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$this>>2] = $1;
 $$arith6 = ($1*12)|0;
 $$overflow7 = ($1>>>0)>(357913941);
 $$arith14 = (($$arith6) + 4)|0;
 $$overflow15 = ($$arith6>>>0)>(4294967291);
 $3 = $$overflow7 | $$overflow15;
 $4 = $3 ? -1 : $$arith14;
 $5 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__Z15PxGetFoundationv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $$$i$i$i = $13 ? 526664 : 526544;
 $14 = (FUNCTION_TABLE_iiiiii[$8 & 255]($5,$4,$$$i$i$i,526464,821)|0);
 HEAP32[$14>>2] = $1;
 $15 = (($14) + 4|0);
 $16 = (($this) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = HEAP32[$this>>2]|0;
 $18 = ($17*3)|0;
 $$arith2 = ($18*12)|0;
 $$overflow3 = ($18>>>0)>(357913941);
 $$arith10 = (($$arith2) + 4)|0;
 $$overflow11 = ($$arith2>>>0)>(4294967291);
 $19 = $$overflow3 | $$overflow11;
 $20 = $19 ? -1 : $$arith10;
 $21 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (__Z15PxGetFoundationv()|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 4095]($25)|0);
 $$$i$i$i3 = $29 ? 526576 : 526544;
 $30 = (FUNCTION_TABLE_iiiiii[$24 & 255]($21,$20,$$$i$i$i3,526464,823)|0);
 HEAP32[$30>>2] = $18;
 $31 = (($30) + 4|0);
 $32 = HEAP32[$this>>2]|0;
 $33 = ($32|0)==(0);
 if ($33) {
  $$pre = HEAP32[$16>>2]|0;
  $$lcssa23 = 0;$144 = $$pre;
 } else {
  $34 = (($create) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  $37 = (($create) + 8|0);
  $38 = HEAP32[$16>>2]|0;
  $74 = 0;$i$024 = 0;
  while(1) {
   if ($36) {
    $39 = HEAP32[$37>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $71 = 0;$72 = 1;$80 = 2;
    } else {
     $41 = ($i$024*3)|0;
     $42 = (($39) + ($41<<1)|0);
     $43 = HEAP16[$42>>1]|0;
     $44 = $43&65535;
     $$pr = HEAP32[$37>>2]|0;
     $45 = ($$pr|0)==(0|0);
     if ($45) {
      $71 = $44;$72 = 1;$80 = 2;
     } else {
      $57 = ($i$024*3)|0;
      $58 = (($57) + 1)|0;
      $59 = (($$pr) + ($58<<1)|0);
      $60 = HEAP16[$59>>1]|0;
      $61 = $60&65535;
      $$pr43$pr = HEAP32[$37>>2]|0;
      $62 = ($$pr43$pr|0)==(0|0);
      if ($62) {
       $71 = $44;$72 = $61;$80 = 2;
      } else {
       $63 = (($57) + 2)|0;
       $64 = (($$pr43$pr) + ($63<<1)|0);
       $65 = HEAP16[$64>>1]|0;
       $66 = $65&65535;
       $71 = $44;$72 = $61;$80 = $66;
      }
     }
    }
   } else {
    $46 = ($i$024*3)|0;
    $47 = (($35) + ($46<<2)|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($i$024*3)|0;
    $50 = (($49) + 1)|0;
    $51 = (($35) + ($50<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($i$024*3)|0;
    $54 = (($53) + 2)|0;
    $55 = (($35) + ($54<<2)|0);
    $56 = HEAP32[$55>>2]|0;
    $71 = $48;$72 = $52;$80 = $56;
   }
   $67 = (($38) + (($i$024*12)|0)|0);
   HEAP32[$67>>2] = -1;
   $68 = ((($38) + (($i$024*12)|0)|0) + 4|0);
   HEAP32[$68>>2] = -1;
   $69 = ((($38) + (($i$024*12)|0)|0) + 8|0);
   HEAP32[$69>>2] = -1;
   $70 = ($71>>>0)<($72>>>0);
   $73 = (($31) + (($74*12)|0)|0);
   if ($70) {
    HEAP32[$73>>2] = $71;
    $75 = ((($31) + (($74*12)|0)|0) + 4|0);
    HEAP32[$75>>2] = $72;
    $76 = ((($31) + (($74*12)|0)|0) + 8|0);
    HEAP32[$76>>2] = $i$024;
   } else {
    HEAP32[$73>>2] = $72;
    $77 = ((($31) + (($74*12)|0)|0) + 4|0);
    HEAP32[$77>>2] = $71;
    $78 = ((($31) + (($74*12)|0)|0) + 8|0);
    HEAP32[$78>>2] = $i$024;
   }
   $storemerge$i = (($74) + 1)|0;
   $79 = ($71>>>0)<($80>>>0);
   $81 = (($31) + (($storemerge$i*12)|0)|0);
   if ($79) {
    HEAP32[$81>>2] = $71;
    $82 = ((($31) + (($storemerge$i*12)|0)|0) + 4|0);
    HEAP32[$82>>2] = $80;
    $83 = ((($31) + (($storemerge$i*12)|0)|0) + 8|0);
    HEAP32[$83>>2] = $i$024;
   } else {
    HEAP32[$81>>2] = $80;
    $84 = ((($31) + (($storemerge$i*12)|0)|0) + 4|0);
    HEAP32[$84>>2] = $71;
    $85 = ((($31) + (($storemerge$i*12)|0)|0) + 8|0);
    HEAP32[$85>>2] = $i$024;
   }
   $storemerge1$i = (($74) + 2)|0;
   $86 = ($72>>>0)<($80>>>0);
   $87 = (($31) + (($storemerge1$i*12)|0)|0);
   if ($86) {
    HEAP32[$87>>2] = $72;
    $88 = ((($31) + (($storemerge1$i*12)|0)|0) + 4|0);
    HEAP32[$88>>2] = $80;
    $89 = ((($31) + (($storemerge1$i*12)|0)|0) + 8|0);
    HEAP32[$89>>2] = $i$024;
   } else {
    HEAP32[$87>>2] = $80;
    $90 = ((($31) + (($storemerge1$i*12)|0)|0) + 4|0);
    HEAP32[$90>>2] = $72;
    $91 = ((($31) + (($storemerge1$i*12)|0)|0) + 8|0);
    HEAP32[$91>>2] = $i$024;
   }
   $storemerge2$i = (($74) + 3)|0;
   $92 = (($i$024) + 1)|0;
   $93 = HEAP32[$this>>2]|0;
   $94 = ($92>>>0)<($93>>>0);
   if ($94) {
    $74 = $storemerge2$i;$i$024 = $92;
   } else {
    $$lcssa23 = $storemerge2$i;$144 = $38;
    break;
   }
  }
 }
 __ZN5physx2Gu17RadixSortBufferedC2Ev($Core$i);
 $$arith = $$lcssa23<<2;
 $$overflow = ($$lcssa23>>>0)>(1073741823);
 $95 = $$overflow ? -1 : $$arith;
 $96 = ($95|0)==(0);
 if ($96) {
  $108 = 0;
 } else {
  $97 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = (($98) + 8|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (__Z15PxGetFoundationv()|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($102) + 24|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (FUNCTION_TABLE_ii[$104 & 4095]($101)|0);
  $$$i$i$i$i = $105 ? 526984 : 526544;
  $106 = (FUNCTION_TABLE_iiiiii[$100 & 255]($97,$95,$$$i$i$i$i,526464,736)|0);
  $108 = $106;
 }
 $107 = ($$lcssa23|0)==(0);
 if ($107) {
  (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($Core$i,$108,0,0)|0);
 } else {
  $i$014$i = 0;
  while(1) {
   $109 = (($31) + (($i$014$i*12)|0)|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = (($108) + ($i$014$i<<2)|0);
   HEAP32[$111>>2] = $110;
   $112 = (($i$014$i) + 1)|0;
   $exitcond36$i = ($112|0)==($$lcssa23|0);
   if ($exitcond36$i) {
    break;
   } else {
    $i$014$i = $112;
   }
  }
  (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($Core$i,$108,$$lcssa23,0)|0);
  $i$113$i = 0;
  while(1) {
   $113 = ((($31) + (($i$113$i*12)|0)|0) + 4|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = (($108) + ($i$113$i<<2)|0);
   HEAP32[$115>>2] = $114;
   $116 = (($i$113$i) + 1)|0;
   $exitcond$i = ($116|0)==($$lcssa23|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$113$i = $116;
   }
  }
 }
 (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($Core$i,$108,$$lcssa23,0)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$108);
 $117 = (($Core$i) + 8|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = HEAP32[$118>>2]|0;
 $120 = (($31) + (($119*12)|0)|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ((($31) + (($119*12)|0)|0) + 4|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($TmpBuffer$i) + 4|0);
 $$01$ph$i = $$lcssa23;$Count$0$ph$i = 0;$LastRef0$0$ph$i = $121;$LastRef1$0$ph$i = $123;$Sorted$0$ph$i = $118;
 L40: while(1) {
  $$01$i = $$01$ph$i;$Count$0$i = $Count$0$ph$i;$Sorted$0$i = $Sorted$0$ph$i;
  while(1) {
   $125 = (($$01$i) + -1)|0;
   $126 = ($$01$i|0)==(0);
   if ($126) {
    label = 37;
    break L40;
   }
   $127 = (($Sorted$0$i) + 4|0);
   $128 = HEAP32[$Sorted$0$i>>2]|0;
   $129 = ((($31) + (($128*12)|0)|0) + 8|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = (($31) + (($128*12)|0)|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = ((($31) + (($128*12)|0)|0) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ($132|0)==($LastRef0$0$ph$i|0);
   $136 = ($134|0)==($LastRef1$0$ph$i|0);
   $or$cond$i = $135 & $136;
   if (!($or$cond$i)) {
    break;
   }
   $137 = (($Count$0$i) + 1)|0;
   $138 = (($TmpBuffer$i) + ($Count$0$i<<2)|0);
   HEAP32[$138>>2] = $130;
   $139 = ($137|0)==(3);
   if ($139) {
    label = 33;
    break L40;
   } else {
    $$01$i = $125;$Count$0$i = $137;$Sorted$0$i = $127;
   }
  }
  $141 = ($Count$0$i|0)==(2);
  if ($141) {
   $142 = HEAP32[$TmpBuffer$i>>2]|0;
   $143 = HEAP32[$124>>2]|0;
   $145 = (__ZL10UpdateLinkjjjjPN5physx11AdjTriangleERKNS_17ADJACENCIESCREATEE($142,$143,$LastRef0$0$ph$i,$LastRef1$0$ph$i,$144,$create)|0);
   if (!($145)) {
    label = 46;
    break;
   }
  }
  HEAP32[$TmpBuffer$i>>2] = $130;
  $$01$ph$i = $125;$Count$0$ph$i = 1;$LastRef0$0$ph$i = $132;$LastRef1$0$ph$i = $134;$Sorted$0$ph$i = $127;
 }
 if ((label|0) == 33) {
  $140 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($140,8,526464,766,526776,$vararg_buffer);
  __ZN5physx2Gu17RadixSortBufferedD2Ev($Core$i);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$30);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 37) {
  $146 = ($Count$0$i|0)==(2);
  if ($146) {
   $147 = HEAP32[$TmpBuffer$i>>2]|0;
   $148 = HEAP32[$124>>2]|0;
   $149 = (__ZL10UpdateLinkjjjjPN5physx11AdjTriangleERKNS_17ADJACENCIESCREATEE($147,$148,$LastRef0$0$ph$i,$LastRef1$0$ph$i,$144,$create)|0);
   __ZN5physx2Gu17RadixSortBufferedD2Ev($Core$i);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$30);
   if (!($149)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   __ZN5physx2Gu17RadixSortBufferedD2Ev($Core$i);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$30);
  }
  $150 = (($create) + 12|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ($151|0)==(0|0);
  if ($152) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $153 = (($ELC) + 16|0);
  $154 = (($ELC) + 20|0);
  ;HEAP32[$ELC+0>>2]=0|0;HEAP32[$ELC+4>>2]=0|0;HEAP32[$ELC+8>>2]=0|0;HEAP16[$ELC+12>>1]=0|0;
  $155 = HEAP32[$create>>2]|0;
  HEAP32[$ELC>>2] = $155;
  $156 = (($create) + 4|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = (($ELC) + 4|0);
  HEAP32[$158>>2] = $157;
  $159 = (($create) + 8|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = (($ELC) + 8|0);
  HEAP32[$161>>2] = $160;
  $162 = (($ELC) + 12|0);
  HEAP8[$162>>0] = 1;
  HEAP32[$153>>2] = $151;
  $163 = (($create) + 16|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  HEAPF32[$154>>2] = $164;
  __ZN5physx2Gu15EdgeListBuilderC2Ev($EL);
  $165 = (__ZN5physx2Gu15EdgeListBuilder4InitERKNS0_14EDGELISTCREATEE($EL,$ELC)|0);
  if ($165) {
   $166 = HEAP32[$this>>2]|0;
   $167 = ($166|0)==(0);
   if (!($167)) {
    $168 = (($EL) + 12|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = HEAP32[$16>>2]|0;
    $i1$04 = 0;
    while(1) {
     $171 = (($169) + (($i1$04*12)|0)|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = ($172|0)>(-1);
     $174 = (($170) + (($i1$04*12)|0)|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = $175 & -536870913;
     $177 = $175 | 536870912;
     $storemerge = $173 ? $176 : $177;
     HEAP32[$174>>2] = $storemerge;
     $178 = ((($169) + (($i1$04*12)|0)|0) + 8|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = ($179|0)>(-1);
     $181 = ((($170) + (($i1$04*12)|0)|0) + 4|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = $182 & -536870913;
     $184 = $182 | 536870912;
     $storemerge1 = $180 ? $183 : $184;
     HEAP32[$181>>2] = $storemerge1;
     $185 = ((($169) + (($i1$04*12)|0)|0) + 4|0);
     $186 = HEAP32[$185>>2]|0;
     $187 = ($186|0)>(-1);
     $188 = ((($170) + (($i1$04*12)|0)|0) + 8|0);
     $189 = HEAP32[$188>>2]|0;
     $190 = $189 & -536870913;
     $191 = $189 | 536870912;
     $storemerge2 = $187 ? $190 : $191;
     HEAP32[$188>>2] = $storemerge2;
     $192 = (($i1$04) + 1)|0;
     $193 = HEAP32[$this>>2]|0;
     $194 = ($192>>>0)<($193>>>0);
     if ($194) {
      $i1$04 = $192;
     } else {
      break;
     }
    }
   }
  }
  __ZN5physx2Gu8EdgeListD2Ev($EL);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 46) {
  __ZN5physx2Gu17RadixSortBufferedD2Ev($Core$i);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$30);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL10UpdateLinkjjjjPN5physx11AdjTriangleERKNS_17ADJACENCIESCREATEE($first_tri,$second_tri,$ref0,$ref1,$faces,$create) {
 $first_tri = $first_tri|0;
 $second_tri = $second_tri|0;
 $ref0 = $ref0|0;
 $ref1 = $ref1|0;
 $faces = $faces|0;
 $create = $create|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$0$i2 = 0, $$17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond13 = 0, $or$cond14 = 0, $or$cond15 = 0, $or$cond16 = 0, $or$cond4 = 0, $or$cond5 = 0, $or$cond6 = 0, $or$cond7 = 0;
 var $or$cond8 = 0, $or$cond9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($create) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $77 = 0;$78 = 0;$79 = 0;$80 = 0;$81 = 0;$82 = 0;
 } else {
  $3 = ($first_tri*3)|0;
  $4 = (($1) + ($3<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 1)|0;
  $7 = (($1) + ($6<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($3) + 2)|0;
  $10 = (($1) + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($second_tri*3)|0;
  $13 = (($1) + ($12<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 1)|0;
  $16 = (($1) + ($15<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($12) + 2)|0;
  $19 = (($1) + ($18<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $77 = $11;$78 = $8;$79 = $5;$80 = $20;$81 = $17;$82 = $14;
 }
 $21 = (($create) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $49 = $79;$51 = $78;$55 = $77;$58 = $82;$60 = $81;$64 = $80;
 } else {
  $24 = ($first_tri*3)|0;
  $25 = (($22) + ($24<<1)|0);
  $26 = HEAP16[$25>>1]|0;
  $27 = $26&65535;
  $28 = (($24) + 1)|0;
  $29 = (($22) + ($28<<1)|0);
  $30 = HEAP16[$29>>1]|0;
  $31 = $30&65535;
  $32 = (($24) + 2)|0;
  $33 = (($22) + ($32<<1)|0);
  $34 = HEAP16[$33>>1]|0;
  $35 = $34&65535;
  $36 = ($second_tri*3)|0;
  $37 = (($22) + ($36<<1)|0);
  $38 = HEAP16[$37>>1]|0;
  $39 = $38&65535;
  $40 = (($36) + 1)|0;
  $41 = (($22) + ($40<<1)|0);
  $42 = HEAP16[$41>>1]|0;
  $43 = $42&65535;
  $44 = (($36) + 2)|0;
  $45 = (($22) + ($44<<1)|0);
  $46 = HEAP16[$45>>1]|0;
  $47 = $46&65535;
  $49 = $27;$51 = $31;$55 = $35;$58 = $39;$60 = $43;$64 = $47;
 }
 $48 = ($49|0)==($ref0|0);
 $50 = ($51|0)==($ref1|0);
 $or$cond = $48 & $50;
 if ($or$cond) {
  $$0$i2 = 0;
 } else {
  $52 = ($49|0)==($ref1|0);
  $53 = ($51|0)==($ref0|0);
  $or$cond4 = $52 & $53;
  if ($or$cond4) {
   $$0$i2 = 0;
  } else {
   $54 = ($55|0)==($ref1|0);
   $or$cond5 = $48 & $54;
   $56 = ($55|0)==($ref0|0);
   $or$cond6 = $52 & $56;
   $or$cond15 = $or$cond5 | $or$cond6;
   if ($or$cond15) {
    $$0$i2 = 1;
   } else {
    $or$cond7 = $53 & $54;
    if ($or$cond7) {
     $$0$i2 = 2;
    } else {
     $or$cond8 = $50 & $56;
     $$ = $or$cond8 ? 2 : -1;
     $$0$i2 = $$;
    }
   }
  }
 }
 $57 = ($58|0)==($ref0|0);
 $59 = ($60|0)==($ref1|0);
 $or$cond9 = $57 & $59;
 if ($or$cond9) {
  $$0$i = 0;
 } else {
  $61 = ($58|0)==($ref1|0);
  $62 = ($60|0)==($ref0|0);
  $or$cond10 = $61 & $62;
  if ($or$cond10) {
   $$0$i = 0;
  } else {
   $63 = ($64|0)==($ref1|0);
   $or$cond11 = $57 & $63;
   $65 = ($64|0)==($ref0|0);
   $or$cond12 = $61 & $65;
   $or$cond16 = $or$cond11 | $or$cond12;
   if ($or$cond16) {
    $$0$i = 1;
   } else {
    $or$cond13 = $62 & $63;
    if ($or$cond13) {
     $$0$i = 2;
    } else {
     $or$cond14 = $59 & $65;
     $$17 = $or$cond14 ? 2 : -1;
     $$0$i = $$17;
    }
   }
  }
 }
 $66 = $$0$i2&255;
 $67 = ($$0$i2<<24>>24)==(-1);
 if (!($67)) {
  $68 = $$0$i&255;
  $69 = ($$0$i<<24>>24)==(-1);
  if (!($69)) {
   $71 = $68 << 30;
   $72 = $71 | $second_tri;
   $73 = ((($faces) + (($first_tri*12)|0)|0) + ($66<<2)|0);
   HEAP32[$73>>2] = $72;
   $74 = $66 << 30;
   $75 = $74 | $first_tri;
   $76 = ((($faces) + (($second_tri*12)|0)|0) + ($68<<2)|0);
   HEAP32[$76>>2] = $75;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $70 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($70,8,526464,709,526936,$vararg_buffer);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx7Cooking9setParamsERKNS_15PxCookingParamsE($this,$params) {
 $this = $this|0;
 $params = $params|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 dest=$0+0|0; src=$params+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx7Cooking9getParamsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx7Cooking16platformMismatchEv($this) {
 $this = $this|0;
 var $$clear = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $switch$cast = 0, $switch$cast$clear = 0, $switch$downshift = 0, $switch$masked = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<(5);
 if ($2) {
  $switch$cast = $1&255;
  $switch$cast$clear = $switch$cast & 31;
  $switch$downshift = (22&255) >>> $switch$cast$clear;
  $3 = $switch$downshift & 1;
  $$clear = $3 & 31;
  $switch$masked = ($$clear<<24>>24)!=(0);
  STACKTOP = sp;return ($switch$masked|0);
 } else {
  STACKTOP = sp;return 0;
 }
 return 0|0;
}
function __ZN5physx7Cooking7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if (!($0)) {
  $1 = HEAP32[$this>>2]|0;
  $2 = (($1) + 48|0);
  $3 = HEAP32[$2>>2]|0;
  FUNCTION_TABLE_vi[$3 & 4095]($this);
 }
 __ZN5physx6shdfnd10Foundation11decRefCountEv();
 STACKTOP = sp;return;
}
function __ZN5physx7Cooking20validateTriangleMeshERKNS_18PxTriangleMeshDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mesh = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $mesh = sp;
 $0 = (($desc) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<(3);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($desc) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($1>>>0) % 3)&-1;
  $7 = ($6|0)==(0);
  if (!($7)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $8 = (($desc) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = (($desc) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12>>>0)<(2);
  if ($13) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $14 = ($1>>>0)>(65535);
 if ($14) {
  $15 = (($desc) + 24|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = $16 & 2;
  $18 = ($17<<16>>16)==(0);
  if (!($18)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $19 = (($desc) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = HEAP32[$desc>>2]|0;
 $23 = ($22>>>0)<(12);
 if ($23) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($5)) {
  $24 = (($desc) + 24|0);
  $25 = HEAP16[$24>>1]|0;
  $26 = $25 & 2;
  $27 = ($26<<16>>16)!=(0);
  $28 = $27 ? 6 : 12;
  $29 = (($desc) + 12|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30>>>0)<($28>>>0);
  if ($31) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 __ZN5physx2Gu12TriangleMeshC2Ev($mesh);
 HEAP32[$mesh>>2] = ((528040 + 8|0));
 $32 = (($mesh) + 8|0);
 HEAP32[$32>>2] = ((528040 + 88|0));
 $33 = (($this) + 4|0);
 $34 = (__ZN5physx19TriangleMeshBuilder12loadFromDescERKNS_18PxTriangleMeshDescERKNS_15PxCookingParamsEb($mesh,$desc,$33,1)|0);
 __ZN5physx2Gu12TriangleMeshD2Ev($mesh);
 $$0 = $34;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx19TriangleMeshBuilderD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Gu12TriangleMeshD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx7Cooking20loadTriangleMeshDescERKNS_18PxTriangleMeshDescERNS_19TriangleMeshBuilderE($this,$desc,$meshBuilder) {
 $this = $this|0;
 $desc = $desc|0;
 $meshBuilder = $meshBuilder|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($desc) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 != Math_fround(0.00100000004749745130539);
 if ($2) {
  $3 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,2,527088,137,527168,$vararg_buffer);
 }
 $4 = (($desc) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)<(3);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($desc) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (($5>>>0) % 3)&-1;
  $11 = ($10|0)==(0);
  if (!($11)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $12 = (($desc) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($desc) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16>>>0)<(2);
  if ($17) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $18 = ($5>>>0)>(65535);
 if ($18) {
  $19 = (($desc) + 24|0);
  $20 = HEAP16[$19>>1]|0;
  $21 = $20 & 2;
  $22 = ($21<<16>>16)==(0);
  if (!($22)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $23 = (($desc) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = HEAP32[$desc>>2]|0;
 $27 = ($26>>>0)<(12);
 if ($27) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($9)) {
  $28 = (($desc) + 24|0);
  $29 = HEAP16[$28>>1]|0;
  $30 = $29 & 2;
  $31 = ($30<<16>>16)!=(0);
  $32 = $31 ? 6 : 12;
  $33 = (($desc) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34>>>0)<($32>>>0);
  if ($35) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $36 = (($this) + 4|0);
 $37 = (__ZN5physx19TriangleMeshBuilder12loadFromDescERKNS_18PxTriangleMeshDescERKNS_15PxCookingParamsEb($meshBuilder,$desc,$36,0)|0);
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx7Cooking16cookTriangleMeshERKNS_18PxTriangleMeshDescERNS_14PxOutputStreamE($this,$desc,$stream) {
 $this = $this|0;
 $desc = $desc|0;
 $stream = $stream|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 527912 : 527656;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,240,$$$i$i$i,527088,158)|0);
 __ZN5physx2Gu12TriangleMeshC2Ev($9);
 HEAP32[$9>>2] = ((528040 + 8|0));
 $10 = (($9) + 8|0);
 HEAP32[$10>>2] = ((528040 + 88|0));
 $11 = ($9|0)==(0|0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (__ZN5physx7Cooking20loadTriangleMeshDescERKNS_18PxTriangleMeshDescERNS_19TriangleMeshBuilderE($this,$desc,$9)|0);
 if ($12) {
  $16 = HEAP32[$this>>2]|0;
  $17 = (($16) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (FUNCTION_TABLE_ii[$18 & 4095]($this)|0);
  (__ZNK5physx19TriangleMeshBuilder4saveERNS_14PxOutputStreamEb($9,$stream,$19)|0);
  $20 = HEAP32[$9>>2]|0;
  $21 = (($20) + 16|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_vi[$22 & 4095]($9);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $13 = HEAP32[$9>>2]|0;
  $14 = (($13) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$15 & 4095]($9);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx7Cooking18createTriangleMeshERKNS_18PxTriangleMeshDescERNS_26PxPhysicsInsertionCallbackE($this,$desc,$insertionCallback) {
 $this = $this|0;
 $desc = $desc|0;
 $insertionCallback = $insertionCallback|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 527912 : 527656;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,240,$$$i$i$i,527088,183)|0);
 __ZN5physx2Gu12TriangleMeshC2Ev($9);
 HEAP32[$9>>2] = ((528040 + 8|0));
 $10 = (($9) + 8|0);
 HEAP32[$10>>2] = ((528040 + 88|0));
 $11 = ($9|0)==(0|0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (__ZN5physx7Cooking20loadTriangleMeshDescERKNS_18PxTriangleMeshDescERNS_19TriangleMeshBuilderE($this,$desc,$9)|0);
 if (!($12)) {
  $13 = HEAP32[$9>>2]|0;
  $14 = (($13) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$15 & 4095]($9);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = HEAP32[$insertionCallback>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_iii[$17 & 4095]($insertionCallback,$9)|0);
 if ($18) {
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 } else {
  $19 = HEAP32[$9>>2]|0;
  $20 = (($19) + 16|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_vi[$21 & 4095]($9);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx7Cooking14cookConvexMeshERKNS_16PxConvexMeshDescERNS_14PxOutputStreamEPNS_25PxConvexMeshCookingResult4EnumE($this,$desc_,$stream,$condition) {
 $this = $this|0;
 $desc_ = $desc_|0;
 $stream = $stream|0;
 $condition = $condition|0;
 var $$0 = 0, $$1 = 0, $$2 = 0, $$off = 0, $$off$i = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $HD = 0, $HL = 0, $HR = 0, $brmerge$demorgan = 0, $desc = 0, $not$$i = 0, $vararg_buffer5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $vararg_buffer5 = sp;
 $desc = sp + 236|0;
 $HD = sp + 176|0;
 $HR = sp + 208|0;
 $HL = sp + 232|0;
 $0 = ($condition|0)!=(0|0);
 if ($0) {
  HEAP32[$condition>>2] = 2;
 }
 $1 = (($desc_) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)<(3);
 L4: do {
  if (!($3)) {
   $4 = ($2>>>0)>(65535);
   if ($4) {
    $5 = (($desc_) + 48|0);
    $6 = HEAP16[$5>>1]|0;
    $7 = $6 & 2;
    $8 = ($7<<16>>16)==(0);
    if (!($8)) {
     break;
    }
   }
   $9 = (($desc_) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = HEAP32[$desc_>>2]|0;
    $13 = ($12>>>0)<(12);
    if (!($13)) {
     $14 = (($desc_) + 16|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0|0);
     do {
      if ($16) {
       $28 = (($desc_) + 28|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29|0)==(0|0);
       if ($30) {
        $48 = (($desc_) + 48|0);
        $49 = HEAP16[$48>>1]|0;
        $50 = $49 & 4;
        $51 = ($50<<16>>16)==(0);
        if ($51) {
         break L4;
        } else {
         $56 = $49;
         break;
        }
       }
       $31 = (($desc_) + 32|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = ($32>>>0)<(4);
       if ($33) {
        break L4;
       }
       $34 = (($desc_) + 40|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = ($35|0)==(0|0);
       if ($36) {
        break L4;
       }
       $37 = (($desc_) + 48|0);
       $38 = HEAP16[$37>>1]|0;
       $39 = $38 & 2;
       $40 = ($39<<16>>16)!=(0);
       $41 = $40 ? 2 : 4;
       $42 = (($desc_) + 36|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = ($43>>>0)<($41>>>0);
       if ($44) {
        break L4;
       }
       $45 = (($desc_) + 24|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46>>>0)<(20);
       if ($47) {
        break L4;
       } else {
        $56 = $38;
       }
      } else {
       $17 = (($desc_) + 20|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = ($18>>>0)<(2);
       if ($19) {
        break L4;
       }
       $20 = (($desc_) + 48|0);
       $21 = HEAP16[$20>>1]|0;
       $22 = $21 & 2;
       $23 = ($22<<16>>16)!=(0);
       $24 = $23 ? 6 : 12;
       $25 = (($desc_) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = ($26>>>0)<($24>>>0);
       if ($27) {
        break L4;
       } else {
        $56 = $21;
       }
      }
     } while(0);
     $52 = (($desc_) + 50|0);
     $53 = HEAP16[$52>>1]|0;
     $$off$i = (($53) + -4)<<16>>16;
     $not$$i = ($$off$i&65535)<(253);
     if ($not$$i) {
      dest=$desc+0|0; src=$desc_+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $55 = (($desc) + 48|0);
      HEAP16[$55>>1] = $56;
      $57 = (($desc) + 50|0);
      HEAP16[$57>>1] = $53;
      $58 = (($HD) + 16|0);
      ;HEAP32[$HD+0>>2]=0|0;HEAP32[$HD+4>>2]=0|0;HEAP32[$HD+8>>2]=0|0;HEAP32[$HD+12>>2]=0|0;
      HEAPF32[$58>>2] = Math_fround(0.00100000004749745130539);
      $59 = (($HD) + 28|0);
      HEAP32[$59>>2] = 4096;
      $60 = (($HD) + 20|0);
      HEAPF32[$60>>2] = Math_fround(0.00999999977648258209228);
      HEAP8[$HR>>0] = 1;
      $61 = (($HR) + 4|0);
      ;HEAP32[$61+0>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;HEAP32[$61+12>>2]=0|0;HEAP32[$61+16>>2]=0|0;
      __ZN5physx11HullLibraryC2Ev($HL);
      $62 = HEAP32[$55>>2]|0;
      $63 = $62 & 4;
      $64 = ($63|0)==(0);
      $65 = $62 >>> 16;
      $66 = $65&65535;
      do {
       if ($64) {
        $$phi$trans$insert = (($desc) + 8|0);
        $$pre = HEAP32[$$phi$trans$insert>>2]|0;
        $104 = $$pre;
        label = 35;
       } else {
        $67 = $62 & 8;
        $68 = ($67|0)==(0);
        $69 = $62 & 16;
        $70 = ($69|0)==(0);
        HEAP32[$HD>>2] = 5;
        $71 = (($desc) + 8|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = (($HD) + 4|0);
        HEAP32[$73>>2] = $72;
        $74 = (($desc) + 4|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($HD) + 8|0);
        HEAP32[$76>>2] = $75;
        $77 = HEAP32[$desc>>2]|0;
        $78 = (($HD) + 12|0);
        HEAP32[$78>>2] = $77;
        if ($68) {
         HEAPF32[$60>>2] = Math_fround(0.0);
        } else {
         $79 = (($this) + 8|0);
         $80 = Math_fround(HEAPF32[$79>>2]);
         HEAPF32[$60>>2] = $80;
         $81 = !($80 <= Math_fround(0.0));
         if (!($81)) {
          $82 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
          __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($82,4,527088,237,527352,$vararg_buffer5);
          $$1 = 0;
          break;
         }
        }
        if ($70) {
         $88 = (($HD) + 24|0);
         HEAPF32[$88>>2] = Math_fround(0.0);
        } else {
         $83 = (($this) + 12|0);
         $84 = Math_fround(HEAPF32[$83>>2]);
         $85 = (($HD) + 24|0);
         HEAPF32[$85>>2] = $84;
         $86 = !($84 <= Math_fround(0.0));
         if (!($86)) {
          $87 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
          __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($87,4,527088,243,527432,$vararg_buffer5);
          $$1 = 0;
          break;
         }
        }
        $$off = (($66) + -4)<<16>>16;
        $89 = ($$off&65535)<(252);
        if ($89) {
         HEAP32[$59>>2] = $65;
        }
        $90 = (__ZN5physx11HullLibrary16CreateConvexHullERKNS_8HullDescERNS_10HullResultE($HL,$HD,$HR)|0);
        if ((($90|0) == 0)) {
         $91 = HEAP32[$61>>2]|0;
         HEAP32[$71>>2] = $91;
         HEAP32[$desc>>2] = 12;
         $92 = (($HR) + 8|0);
         $93 = HEAP32[$92>>2]|0;
         HEAP32[$74>>2] = $93;
         $94 = (($HR) + 12|0);
         $95 = HEAP32[$94>>2]|0;
         $96 = (($desc) + 20|0);
         HEAP32[$96>>2] = $95;
         $97 = (($HR) + 20|0);
         $98 = HEAP32[$97>>2]|0;
         $99 = (($desc) + 16|0);
         HEAP32[$99>>2] = $98;
         $100 = (($desc) + 12|0);
         HEAP32[$100>>2] = 12;
         $101 = HEAP16[$55>>1]|0;
         $102 = $101 & -5;
         HEAP16[$55>>1] = $102;
         $104 = $91;
         label = 35;
         break;
        } else if (!((($90|0) == 3))) {
         $$1 = 0;
         break;
        }
        if ($0) {
         HEAP32[$condition>>2] = 1;
         $$1 = 0;
        } else {
         $$1 = 0;
        }
       }
      } while(0);
      do {
       if ((label|0) == 35) {
        $103 = ($104>>>0)>(255);
        if ($103) {
         $105 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
         __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($105,32,527088,278,527512,$vararg_buffer5);
         (__ZN5physx11HullLibrary13ReleaseResultERNS_10HullResultE($HL,$HR)|0);
         $$1 = 0;
         break;
        }
        __ZN5physx17ConvexMeshBuilderC2Ev($vararg_buffer5);
        $106 = (($this) + 4|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = (__ZN5physx17ConvexMeshBuilder12loadFromDescERKNS_16PxConvexMeshDescENS_10PxPlatform4EnumE($vararg_buffer5,$desc,$107)|0);
        if ($108) {
         $109 = HEAP32[$this>>2]|0;
         $110 = (($109) + 12|0);
         $111 = HEAP32[$110>>2]|0;
         $112 = (FUNCTION_TABLE_ii[$111 & 4095]($this)|0);
         $113 = (__ZNK5physx17ConvexMeshBuilder4saveERNS_14PxOutputStreamEb($vararg_buffer5,$stream,$112)|0);
         (__ZN5physx11HullLibrary13ReleaseResultERNS_10HullResultE($HL,$HR)|0);
         $brmerge$demorgan = $113 & $0;
         if ($brmerge$demorgan) {
          HEAP32[$condition>>2] = 0;
          $$0 = 1;
         } else {
          $$0 = $113;
         }
        } else {
         (__ZN5physx11HullLibrary13ReleaseResultERNS_10HullResultE($HL,$HR)|0);
         $$0 = 0;
        }
        __ZN5physx17ConvexMeshBuilderD2Ev($vararg_buffer5);
        $$1 = $$0;
       }
      } while(0);
      __ZN5physx11HullLibraryD2Ev($HL);
      $$2 = $$1;
      STACKTOP = sp;return ($$2|0);
     }
    }
   }
  }
 } while(0);
 $54 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($54,4,527088,217,527272,$vararg_buffer5);
 $$2 = 0;
 STACKTOP = sp;return ($$2|0);
}
function __ZN5physx7Cooking19computeHullPolygonsERKNS_20PxSimpleTriangleMeshERNS_19PxAllocatorCallbackERjRPNS_6PxVec3ES6_RPjS6_RPNS_13PxHullPolygonE($this,$mesh,$inCallback,$nbVerts,$vertices,$nbIndices,$indices,$nbPolygons,$hullPolygons) {
 $this = $this|0;
 $mesh = $mesh|0;
 $inCallback = $inCallback|0;
 $nbVerts = $nbVerts|0;
 $vertices = $vertices|0;
 $nbIndices = $nbIndices|0;
 $indices = $indices|0;
 $nbPolygons = $nbPolygons|0;
 $hullPolygons = $hullPolygons|0;
 var $$01$i = 0, $$01$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $d$03$i = 0, $d$03$i1 = 0, $dest$07 = 0, $meshBuilder = 0, $s$02$i = 0, $s$02$i2 = 0, $source$08 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $meshBuilder = sp;
 $0 = (($mesh) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1*12)|0;
 $3 = STACKTOP; STACKTOP = STACKTOP + ((((1*$2)|0)+15)&-16)|0;;
 $4 = HEAP32[$mesh>>2]|0;
 $5 = ($1|0)==(0);
 if (!($5)) {
  $6 = (($mesh) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $$01$i = $1;$d$03$i = $3;$s$02$i = $7;
  while(1) {
   $8 = (($$01$i) + -1)|0;
   dest=$d$03$i+0|0; src=$s$02$i+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $9 = (($d$03$i) + 12|0);
   $10 = (($s$02$i) + ($4)|0);
   $11 = ($8|0)==(0);
   if ($11) {
    break;
   } else {
    $$01$i = $8;$d$03$i = $9;$s$02$i = $10;
   }
  }
 }
 $12 = (($mesh) + 12|0);
 $13 = (($mesh) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14*12)|0;
 $16 = STACKTOP; STACKTOP = STACKTOP + ((((1*$15)|0)+15)&-16)|0;;
 $17 = (($mesh) + 24|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 & 2;
 $20 = ($19<<16>>16)==(0);
 if ($20) {
  $40 = HEAP32[$12>>2]|0;
  $41 = ($14|0)==(0);
  if (!($41)) {
   $42 = (($mesh) + 16|0);
   $43 = HEAP32[$42>>2]|0;
   $$01$i3 = $14;$d$03$i1 = $16;$s$02$i2 = $43;
   while(1) {
    $44 = (($$01$i3) + -1)|0;
    dest=$d$03$i1+0|0; src=$s$02$i2+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $45 = (($d$03$i1) + 12|0);
    $46 = (($s$02$i2) + ($40)|0);
    $47 = ($44|0)==(0);
    if ($47) {
     break;
    } else {
     $$01$i3 = $44;$d$03$i1 = $45;$s$02$i2 = $46;
    }
   }
  }
 } else {
  $21 = ($14*3)|0;
  $22 = (($16) + ($21<<2)|0);
  $23 = ($16>>>0)<($22>>>0);
  if ($23) {
   $24 = (($mesh) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $dest$07 = $16;$source$08 = $25;
   while(1) {
    $26 = HEAP16[$source$08>>1]|0;
    $27 = $26&65535;
    $28 = (($dest$07) + 4|0);
    HEAP32[$dest$07>>2] = $27;
    $29 = (($source$08) + 2|0);
    $30 = HEAP16[$29>>1]|0;
    $31 = $30&65535;
    $32 = (($dest$07) + 8|0);
    HEAP32[$28>>2] = $31;
    $33 = (($source$08) + 4|0);
    $34 = HEAP16[$33>>1]|0;
    $35 = $34&65535;
    $36 = (($dest$07) + 12|0);
    HEAP32[$32>>2] = $35;
    $37 = HEAP32[$12>>2]|0;
    $38 = (($source$08) + ($37)|0);
    $39 = ($36>>>0)<($22>>>0);
    if ($39) {
     $dest$07 = $36;$source$08 = $38;
    } else {
     break;
    }
   }
  }
 }
 __ZN5physx17ConvexMeshBuilderC2Ev($meshBuilder);
 $48 = (__ZN5physx17ConvexMeshBuilder19computeHullPolygonsERKjPKNS_6PxVec3ES2_PS1_RNS_19PxAllocatorCallbackERjRPS3_S9_RPjS9_RPNS_13PxHullPolygonE($meshBuilder,$0,$3,$13,$16,$inCallback,$nbVerts,$vertices,$nbIndices,$indices,$nbPolygons,$hullPolygons)|0);
 __ZN5physx17ConvexMeshBuilderD2Ev($meshBuilder);
 STACKTOP = sp;return ($48|0);
}
function __ZN5physx7Cooking15cookHeightFieldERKNS_17PxHeightFieldDescERNS_14PxOutputStreamE($this,$desc,$stream) {
 $this = $this|0;
 $desc = $desc|0;
 $stream = $stream|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $cond$i = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($desc) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<(2);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$desc>>2]|0;
 $4 = ($3>>>0)<(2);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($desc) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $cond$i = ($6|0)==(1);
 if (!($cond$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($desc) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8>>>0)<(4);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($desc) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = $11 < Math_fround(0.0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($desc) + 28|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = $14&65535;
 $16 = $15 & 1;
 $17 = $16&65535;
 $not$$i = ($17<<16>>16)==($14<<16>>16);
 if (!($not$$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__Z15PxGetFoundationv()|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 4095]($22)|0);
 $$$i$i$i = $26 ? 527792 : 527656;
 $27 = (FUNCTION_TABLE_iiiiii[$21 & 255]($18,116,$$$i$i$i,527088,348)|0);
 __ZN5physx2Gu11HeightFieldC2EPNS_13GuMeshFactoryE($27,0);
 $28 = ($27|0)==(0|0);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (__ZN5physx2Gu11HeightField12loadFromDescERKNS_17PxHeightFieldDescEb($27,$desc,0)|0);
 if ($29) {
  $33 = HEAP32[$this>>2]|0;
  $34 = (($33) + 12|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (FUNCTION_TABLE_ii[$35 & 4095]($this)|0);
  $37 = (__ZN5physx15saveHeightFieldERKNS_2Gu11HeightFieldERNS_14PxOutputStreamEb($27,$stream,$36)|0);
  __ZN5physx2Gu11HeightField13releaseMemoryEb($27,0);
  $38 = HEAP32[$27>>2]|0;
  $39 = (($38) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_vi[$40 & 4095]($27);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 } else {
  __ZN5physx2Gu11HeightField13releaseMemoryEb($27,0);
  $30 = HEAP32[$27>>2]|0;
  $31 = (($30) + 16|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vi[$32 & 4095]($27);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx7Cooking17createHeightFieldERKNS_17PxHeightFieldDescERNS_26PxPhysicsInsertionCallbackE($this,$desc,$insertionCallback) {
 $this = $this|0;
 $desc = $desc|0;
 $insertionCallback = $insertionCallback|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $cond$i = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($desc) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<(2);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$desc>>2]|0;
 $4 = ($3>>>0)<(2);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($desc) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $cond$i = ($6|0)==(1);
 if (!($cond$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($desc) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8>>>0)<(4);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($desc) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = $11 < Math_fround(0.0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($desc) + 28|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = $14&65535;
 $16 = $15 & 1;
 $17 = $16&65535;
 $not$$i = ($17<<16>>16)==($14<<16>>16);
 if (!($not$$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__Z15PxGetFoundationv()|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 4095]($22)|0);
 $$$i$i$i = $26 ? 527792 : 527656;
 $27 = (FUNCTION_TABLE_iiiiii[$21 & 255]($18,116,$$$i$i$i,527088,383)|0);
 __ZN5physx2Gu11HeightFieldC2EPNS_13GuMeshFactoryE($27,0);
 $28 = ($27|0)==(0|0);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (__ZN5physx2Gu11HeightField12loadFromDescERKNS_17PxHeightFieldDescEb($27,$desc,1)|0);
 if (!($29)) {
  __ZN5physx2Gu11HeightField13releaseMemoryEb($27,0);
  $30 = HEAP32[$27>>2]|0;
  $31 = (($30) + 16|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vi[$32 & 4095]($27);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP32[$insertionCallback>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (FUNCTION_TABLE_iii[$34 & 4095]($insertionCallback,$27)|0);
 if ($35) {
  $$0 = $27;
  STACKTOP = sp;return ($$0|0);
 } else {
  __ZN5physx2Gu11HeightField13releaseMemoryEb($27,0);
  $36 = HEAP32[$27>>2]|0;
  $37 = (($36) + 16|0);
  $38 = HEAP32[$37>>2]|0;
  FUNCTION_TABLE_vi[$38 & 4095]($27);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z15PxCreateCookingjRN5physx12PxFoundationERKNS_15PxCookingParamsE($0,$foundation,$params) {
 $0 = $0|0;
 $foundation = $foundation|0;
 $params = $params|0;
 var $$$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx6shdfnd10Foundation11incRefCountEv();
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15PxGetFoundationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $$$i$i$i = $9 ? 527688 : 527656;
 $10 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,48,$$$i$i$i,527088,413)|0);
 HEAP32[$10>>2] = ((527592 + 8|0));
 $11 = (($10) + 4|0);
 ;HEAP32[$11+0>>2]=HEAP32[$params+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$params+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$params+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$params+12>>2]|0;HEAP32[$11+16>>2]=HEAP32[$params+16>>2]|0;HEAP32[$11+20>>2]=HEAP32[$params+20>>2]|0;HEAP32[$11+24>>2]=HEAP32[$params+24>>2]|0;
 $12 = (($params) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($10) + 32|0);
 HEAP32[$14>>2] = $13;
 $15 = (($10) + 36|0);
 $16 = (($params) + 32|0);
 ;HEAP32[$15+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$16+8>>2]|0;
 STACKTOP = sp;return ($10|0);
}
function __ZN5physx7CookingD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx7CookingD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx19TriangleMeshBuilderD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 __ZN5physx2Gu12TriangleMeshD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNK5physx14PxTriangleMesh19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (528144|0);
}
function __ZN5physx19TriangleMeshBuilderD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Gu12TriangleMeshD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZNK5physx14PxTriangleMesh8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(528144,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,528160)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Gu12TriangleMesh13getNbVerticesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu12TriangleMesh11getVerticesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu12TriangleMesh14getNbTrianglesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu12TriangleMesh12getTrianglesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu12TriangleMesh20getTriangleMeshFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 172|0);
 $1 = HEAP8[$0>>0]|0;
 HEAP8[$agg$result>>0] = $1;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu12TriangleMesh17getTrianglesRemapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 180|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu12TriangleMesh24getTriangleMaterialIndexEj($this,$triangleIndex) {
 $this = $this|0;
 $triangleIndex = $triangleIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 176|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = -1;
  STACKTOP = sp;return ($5|0);
 }
 $3 = (($1) + ($triangleIndex<<1)|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4;
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Gu12TriangleMesh14getLocalBoundsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 144|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 148|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 152|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 $8 = (($agg$result) + 12|0);
 $9 = (($this) + 156|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $10;
 $11 = (($agg$result) + 16|0);
 $12 = (($this) + 160|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$11>>2] = $13;
 $14 = (($agg$result) + 20|0);
 $15 = (($this) + 164|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$14>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12TriangleMesh8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx19TriangleMeshBuilderD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 __ZN5physx2Gu12TriangleMeshD2Ev($1);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx18ReducedVertexCloudC2EPKNS_6PxVec3Ej($this,$verts,$nb_verts) {
 $this = $this|0;
 $verts = $verts|0;
 $nb_verts = $nb_verts|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = $verts;
 HEAP32[$this>>2] = $nb_verts;
 STACKTOP = sp;return;
}
function __ZN5physx18ReducedVertexCloudD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
 HEAP32[$2>>2] = 0;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$5);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx18ReducedVertexCloud6ReduceEPNS_12REDUCEDCLOUDE($this,$rc) {
 $this = $this|0;
 $rc = $rc|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$arith = 0, $$arith2 = 0, $$in = 0, $$lcssa = 0, $$lcssa8 = 0, $$overflow = 0, $$overflow3 = 0, $$pre = 0, $$pre17 = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $Junk = 0, $Previous$03 = 0, $Sorted$02 = 0, $i$014 = 0, $i1$09 = 0, $i2$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 12|0;
 $1 = sp + 50|0;
 $2 = sp + 48|0;
 $Junk = sp;
 $3 = sp + 49|0;
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$5);
 HEAP32[$4>>2] = 0;
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
 HEAP32[$6>>2] = 0;
 $8 = HEAP32[$this>>2]|0;
 $$arith2 = $8<<2;
 $$overflow3 = ($8>>>0)>(1073741823);
 $9 = $$overflow3 ? -1 : $$arith2;
 $10 = ($9|0)==(0);
 if ($10) {
  $21 = 0;$22 = $8;
 } else {
  $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z15PxGetFoundationv()|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
  $$$i$i$i = $19 ? 528376 : 528256;
  $20 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,$9,$$$i$i$i,528168,74)|0);
  $$pre = HEAP32[$this>>2]|0;
  $21 = $20;$22 = $$pre;
 }
 HEAP32[$4>>2] = $21;
 $$arith = $22<<2;
 $$overflow = ($22>>>0)>(1073741823);
 $23 = $$overflow ? -1 : $$arith;
 $24 = ($23|0)==(0);
 if ($24) {
  $36 = $22;$42 = 0;
 } else {
  $25 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (__Z15PxGetFoundationv()|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 24|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
  $$$i$i$i1 = $33 ? 528288 : 528256;
  $34 = (FUNCTION_TABLE_iiiiii[$28 & 255]($25,$23,$$$i$i$i1,528168,76)|0);
  $$pre17 = HEAP32[$this>>2]|0;
  $36 = $$pre17;$42 = $34;
 }
 $35 = ($36|0)==(0);
 if (!($35)) {
  $37 = (($this) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $i$014 = 0;
  while(1) {
   $39 = (($38) + (($i$014*12)|0)|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = (($42) + ($i$014<<2)|0);
   HEAPF32[$41>>2] = $40;
   $43 = (($i$014) + 1)|0;
   $44 = ($43>>>0)<($36>>>0);
   if ($44) {
    $i$014 = $43;
   } else {
    break;
   }
  }
 }
 __ZN5physx2Gu17RadixSortBufferedC2Ev($0);
 $45 = HEAP32[$this>>2]|0;
 (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($0,$42,$45,1)|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = ($46|0)==(0);
 if ($47) {
  $$lcssa8 = 0;
 } else {
  $48 = (($this) + 4|0);
  $49 = HEAP32[$48>>2]|0;
  $i1$09 = 0;
  while(1) {
   $50 = ((($49) + (($i1$09*12)|0)|0) + 4|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = (($42) + ($i1$09<<2)|0);
   HEAPF32[$52>>2] = $51;
   $53 = (($i1$09) + 1)|0;
   $54 = ($53>>>0)<($46>>>0);
   if ($54) {
    $i1$09 = $53;
   } else {
    $$lcssa8 = $46;
    break;
   }
  }
 }
 (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($0,$42,$$lcssa8,1)|0);
 $55 = HEAP32[$this>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $$lcssa = 0;
 } else {
  $57 = (($this) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $i2$04 = 0;
  while(1) {
   $59 = ((($58) + (($i2$04*12)|0)|0) + 8|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = (($42) + ($i2$04<<2)|0);
   HEAPF32[$61>>2] = $60;
   $62 = (($i2$04) + 1)|0;
   $63 = ($62>>>0)<($55>>>0);
   if ($63) {
    $i2$04 = $62;
   } else {
    $$lcssa = $55;
    break;
   }
  }
 }
 $64 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($0,$42,$$lcssa,1)|0);
 $65 = (($64) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$42);
 $67 = (($this) + 8|0);
 HEAP32[$67>>2] = 0;
 ;HEAP32[$Junk+0>>2]=4294967295|0;HEAP32[$Junk+4>>2]=4294967295|0;HEAP32[$Junk+8>>2]=4294967295|0;
 $68 = HEAP32[$this>>2]|0;
 $69 = ($68*12)|0;
 $70 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$69,528168,97)|0);
 HEAP32[$6>>2] = $70;
 $71 = HEAP32[$this>>2]|0;
 $72 = ($71|0)==(0);
 if (!($72)) {
  $73 = (($this) + 4|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = HEAP32[$4>>2]|0;
  $$in = $71;$Previous$03 = $Junk;$Sorted$02 = $66;
  while(1) {
   $76 = (($$in) + -1)|0;
   $77 = (($Sorted$02) + 4|0);
   $78 = HEAP32[$Sorted$02>>2]|0;
   $79 = (($74) + (($78*12)|0)|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = HEAP32[$Previous$03>>2]|0;
   $82 = ($80|0)==($81|0);
   $83 = ((($74) + (($78*12)|0)|0) + 4|0);
   if ($82) {
    $84 = HEAP32[$83>>2]|0;
    $85 = (($Previous$03) + 4|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($84|0)==($86|0);
    if ($87) {
     $88 = ((($74) + (($78*12)|0)|0) + 8|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = (($Previous$03) + 8|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($89|0)==($91|0);
     if ($92) {
      $$pre19 = HEAP32[$67>>2]|0;
      $104 = $$pre19;
     } else {
      label = 20;
     }
    } else {
     label = 20;
    }
   } else {
    label = 20;
   }
   if ((label|0) == 20) {
    label = 0;
    $93 = HEAP32[$67>>2]|0;
    $94 = (($93) + 1)|0;
    HEAP32[$67>>2] = $94;
    $95 = (($74) + (($78*12)|0)|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $97 = (($70) + (($93*12)|0)|0);
    HEAPF32[$97>>2] = $96;
    $98 = Math_fround(HEAPF32[$83>>2]);
    $99 = ((($70) + (($93*12)|0)|0) + 4|0);
    HEAPF32[$99>>2] = $98;
    $100 = ((($74) + (($78*12)|0)|0) + 8|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = ((($70) + (($93*12)|0)|0) + 8|0);
    HEAPF32[$102>>2] = $101;
    $104 = $94;
   }
   $103 = (($104) + -1)|0;
   $105 = (($75) + ($78<<2)|0);
   HEAP32[$105>>2] = $103;
   $106 = ($76|0)==(0);
   if ($106) {
    break;
   } else {
    $$in = $76;$Previous$03 = $79;$Sorted$02 = $77;
   }
  }
 }
 $107 = ($rc|0)==(0|0);
 if ($107) {
  __ZN5physx2Gu17RadixSortBufferedD2Ev($0);
  STACKTOP = sp;return 1;
 }
 $108 = HEAP32[$4>>2]|0;
 $109 = (($rc) + 8|0);
 HEAP32[$109>>2] = $108;
 $110 = HEAP32[$67>>2]|0;
 $111 = (($rc) + 4|0);
 HEAP32[$111>>2] = $110;
 $112 = HEAP32[$6>>2]|0;
 HEAP32[$rc>>2] = $112;
 __ZN5physx2Gu17RadixSortBufferedD2Ev($0);
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu8EdgeListD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$5);
 HEAP32[$4>>2] = 0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
 HEAP32[$6>>2] = 0;
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$9);
 HEAP32[$8>>2] = 0;
 $10 = (($this) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$11);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15EdgeListBuilder4InitERKNS0_14EDGELISTCREATEE($this,$create) {
 $this = $this|0;
 $create = $create|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($create) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($create) + 12|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  $9 = (($create) + 13|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)!=(0);
  if ($8) {
   $47 = $11;
  } else {
   $46 = $11;
   label = 3;
  }
 } else {
  $46 = 1;
  label = 3;
 }
 if ((label|0) == 3) {
  $12 = HEAP32[$create>>2]|0;
  $13 = (($create) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($create) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (__ZN5physx2Gu15EdgeListBuilder18CreateFacesToEdgesEjPKjPKt($this,$12,$14,$16)|0);
  if ($17) {
   $47 = $46;
  } else {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 if ($47) {
  $18 = HEAP32[$create>>2]|0;
  $19 = (($create) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($create) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (__ZN5physx2Gu15EdgeListBuilder18CreateEdgesToFacesEjPKjPKt($this,$18,$20,$22)|0);
  if (!($23)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $24 = HEAP32[$3>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$create>>2]|0;
  $27 = (($create) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($create) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($create) + 20|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (__ZN5physx2Gu15EdgeListBuilder18ComputeActiveEdgesEjPKjPKtPKNS_6PxVec3Ef($this,$26,$28,$30,$24,$32)|0);
  if (!($33)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $34 = (($create) + 12|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = ($35<<24>>24)==(0);
 if ($36) {
  $37 = (($this) + 12|0);
  $38 = HEAP32[$37>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$38);
  HEAP32[$37>>2] = 0;
 }
 $39 = (($create) + 13|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if (!($41)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = (($this) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$43);
 HEAP32[$42>>2] = 0;
 $44 = (($this) + 20|0);
 $45 = HEAP32[$44>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$45);
 HEAP32[$44>>2] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15EdgeListBuilder18CreateFacesToEdgesEjPKjPKt($this,$nb_faces,$dfaces,$wfaces) {
 $this = $this|0;
 $nb_faces = $nb_faces|0;
 $dfaces = $dfaces|0;
 $wfaces = $wfaces|0;
 var $$$i$i$i = 0, $$$i$i$i2 = 0, $$$i$i$i3 = 0, $$$i$i$i4 = 0, $$0 = 0, $$arith = 0, $$arith2 = 0, $$arith6 = 0, $$not = 0, $$overflow = 0, $$overflow3 = 0, $$overflow7 = 0, $$pre = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $PreviousRef0$010 = 0, $PreviousRef1$011 = 0, $exitcond = 0, $exitcond16 = 0, $exitcond17 = 0, $i$013 = 0, $i$013$us = 0, $i1$012 = 0, $or$cond = 0, $or$cond1 = 0, $phitmp20 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $0 = sp + 39|0;
 $1 = sp + 36|0;
 $2 = sp + 37|0;
 $3 = sp + 38|0;
 $4 = ($nb_faces|0)==(0);
 if (!($4)) {
  $5 = ($dfaces|0)!=(0|0);
  $$not = $5 ^ 1;
  $6 = ($wfaces|0)==(0|0);
  $or$cond = $6 & $$not;
  if (!($or$cond)) {
   $8 = (($this) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $$arith6 = ($nb_faces*12)|0;
   $$overflow7 = ($nb_faces>>>0)>(357913941);
   $11 = $$overflow7 ? -1 : $$arith6;
   $12 = ($11|0)==(0);
   if ($12) {
    $23 = 0;
   } else {
    $13 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (__Z15PxGetFoundationv()|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 24|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (FUNCTION_TABLE_ii[$20 & 4095]($17)|0);
    $$$i$i$i2 = $21 ? 529168 : 528920;
    $22 = (FUNCTION_TABLE_iiiiii[$16 & 255]($13,$11,$$$i$i$i2,528480,152)|0);
    $23 = $22;
   }
   HEAP32[$8>>2] = $23;
   $24 = ($nb_faces*3)|0;
   $$arith2 = $24<<2;
   $$overflow3 = ($24>>>0)>(1073741823);
   $25 = $$overflow3 ? -1 : $$arith2;
   $26 = ($25|0)==(0);
   if ($26) {
    $151 = 0;$70 = 0;$72 = 0;
   } else {
    $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (__Z15PxGetFoundationv()|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($32) + 24|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (FUNCTION_TABLE_ii[$34 & 4095]($31)|0);
    $$$i$i$i3 = $35 ? 529064 : 528920;
    $36 = (FUNCTION_TABLE_iiiiii[$30 & 255]($27,$25,$$$i$i$i3,528480,153)|0);
    $37 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (__Z15PxGetFoundationv()|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + 24|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (FUNCTION_TABLE_ii[$44 & 4095]($41)|0);
    $$$i$i$i4 = $45 ? 529064 : 528920;
    $46 = (FUNCTION_TABLE_iiiiii[$40 & 255]($37,$25,$$$i$i$i4,528480,154)|0);
    $151 = $36;$70 = $36;$72 = $46;
   }
   $$arith = $24<<3;
   $$overflow = ($24>>>0)>(536870911);
   $47 = $$overflow ? -1 : $$arith;
   $48 = ($47|0)==(0);
   if ($48) {
    $136 = 0;
   } else {
    $49 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + 8|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (__Z15PxGetFoundationv()|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($54) + 24|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (FUNCTION_TABLE_ii[$56 & 4095]($53)|0);
    $$$i$i$i = $57 ? 528952 : 528920;
    $58 = (FUNCTION_TABLE_iiiiii[$52 & 255]($49,$47,$$$i$i$i,528480,155)|0);
    $136 = $58;
   }
   if ($5) {
    $i$013$us = 0;
    while(1) {
     $59 = ($i$013$us*3)|0;
     $60 = (($dfaces) + ($59<<2)|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($59) + 1)|0;
     $63 = (($dfaces) + ($62<<2)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($59) + 2)|0;
     $66 = (($dfaces) + ($65<<2)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($61>>>0)<($64>>>0);
     $69 = (($70) + ($59<<2)|0);
     if ($68) {
      HEAP32[$69>>2] = $61;
      $73 = (($72) + ($59<<2)|0);
      HEAP32[$73>>2] = $64;
     } else {
      HEAP32[$69>>2] = $64;
      $71 = (($72) + ($59<<2)|0);
      HEAP32[$71>>2] = $61;
     }
     $74 = ($64>>>0)<($67>>>0);
     $75 = (($59) + 1)|0;
     $76 = (($70) + ($75<<2)|0);
     if ($74) {
      HEAP32[$76>>2] = $64;
      $78 = (($72) + ($75<<2)|0);
      HEAP32[$78>>2] = $67;
     } else {
      HEAP32[$76>>2] = $67;
      $77 = (($72) + ($75<<2)|0);
      HEAP32[$77>>2] = $64;
     }
     $79 = ($67>>>0)<($61>>>0);
     $80 = (($59) + 2)|0;
     $81 = (($70) + ($80<<2)|0);
     if ($79) {
      HEAP32[$81>>2] = $67;
      $83 = (($72) + ($80<<2)|0);
      HEAP32[$83>>2] = $61;
     } else {
      HEAP32[$81>>2] = $61;
      $82 = (($72) + ($80<<2)|0);
      HEAP32[$82>>2] = $67;
     }
     $84 = (($i$013$us) + 1)|0;
     $exitcond17 = ($84|0)==($nb_faces|0);
     if ($exitcond17) {
      break;
     } else {
      $i$013$us = $84;
     }
    }
   } else {
    $i$013 = 0;
    while(1) {
     $85 = ($i$013*3)|0;
     if ($6) {
      $86 = (($70) + ($85<<2)|0);
      $100 = 0;$101 = $86;$103 = 1;$152 = 2;
      label = 25;
     } else {
      $87 = (($wfaces) + ($85<<1)|0);
      $88 = HEAP16[$87>>1]|0;
      $89 = $88&65535;
      $90 = (($85) + 1)|0;
      $91 = (($wfaces) + ($90<<1)|0);
      $92 = HEAP16[$91>>1]|0;
      $93 = $92&65535;
      $94 = (($85) + 2)|0;
      $95 = (($wfaces) + ($94<<1)|0);
      $96 = HEAP16[$95>>1]|0;
      $97 = $96&65535;
      $98 = ($88&65535)<($92&65535);
      $99 = (($70) + ($85<<2)|0);
      if ($98) {
       $100 = $89;$101 = $99;$103 = $93;$152 = $97;
       label = 25;
      } else {
       HEAP32[$99>>2] = $93;
       $104 = (($72) + ($85<<2)|0);
       HEAP32[$104>>2] = $89;
       $106 = $93;$107 = $97;$113 = $89;
      }
     }
     if ((label|0) == 25) {
      label = 0;
      HEAP32[$101>>2] = $100;
      $102 = (($72) + ($85<<2)|0);
      HEAP32[$102>>2] = $103;
      $106 = $103;$107 = $152;$113 = $100;
     }
     $105 = ($106>>>0)<($107>>>0);
     $108 = (($85) + 1)|0;
     $109 = (($70) + ($108<<2)|0);
     if ($105) {
      HEAP32[$109>>2] = $106;
      $110 = (($72) + ($108<<2)|0);
      HEAP32[$110>>2] = $107;
     } else {
      HEAP32[$109>>2] = $107;
      $111 = (($72) + ($108<<2)|0);
      HEAP32[$111>>2] = $106;
     }
     $112 = ($107>>>0)<($113>>>0);
     $114 = (($85) + 2)|0;
     $115 = (($70) + ($114<<2)|0);
     if ($112) {
      HEAP32[$115>>2] = $107;
      $116 = (($72) + ($114<<2)|0);
      HEAP32[$116>>2] = $113;
     } else {
      HEAP32[$115>>2] = $113;
      $117 = (($72) + ($114<<2)|0);
      HEAP32[$117>>2] = $107;
     }
     $118 = (($i$013) + 1)|0;
     $exitcond16 = ($118|0)==($nb_faces|0);
     if ($exitcond16) {
      break;
     } else {
      $i$013 = $118;
     }
    }
   }
   __ZN5physx2Gu17RadixSortBufferedC2Ev($vararg_buffer);
   $119 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($vararg_buffer,$72,$24,0)|0);
   $120 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($119,$70,$24,0)|0);
   $121 = (($120) + 8|0);
   $122 = HEAP32[$121>>2]|0;
   HEAP32[$this>>2] = 0;
   $123 = (($this) + 8|0);
   HEAP32[$123>>2] = $nb_faces;
   $124 = ($24|0)==(0);
   if ($124) {
    $146 = 0;
   } else {
    $125 = HEAP32[$8>>2]|0;
    $PreviousRef0$010 = -1;$PreviousRef1$011 = -1;$i1$012 = 0;
    while(1) {
     $126 = (($122) + ($i1$012<<2)|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = (($127>>>0) % 3)&-1;
     $129 = (($70) + ($127<<2)|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = (($72) + ($127<<2)|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ($130|0)==($PreviousRef0$010|0);
     $134 = ($132|0)==($PreviousRef1$011|0);
     $or$cond1 = $133 & $134;
     $$pre19 = HEAP32[$this>>2]|0;
     if ($or$cond1) {
      $142 = $$pre19;
     } else {
      $135 = (($136) + ($$pre19<<3)|0);
      HEAP32[$135>>2] = $130;
      $137 = HEAP32[$this>>2]|0;
      $138 = ((($136) + ($137<<3)|0) + 4|0);
      HEAP32[$138>>2] = $132;
      $139 = HEAP32[$this>>2]|0;
      $140 = (($139) + 1)|0;
      HEAP32[$this>>2] = $140;
      $142 = $140;
     }
     $141 = (($142) + -1)|0;
     $143 = (($127>>>0) / 3)&-1;
     $144 = ((($125) + (($143*12)|0)|0) + ($128<<2)|0);
     HEAP32[$144>>2] = $141;
     $145 = (($i1$012) + 1)|0;
     $exitcond = ($145|0)==($24|0);
     if ($exitcond) {
      break;
     } else {
      $PreviousRef0$010 = $130;$PreviousRef1$011 = $132;$i1$012 = $145;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $phitmp20 = $$pre << 3;
    $146 = $phitmp20;
   }
   $147 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$146,528480,209)|0);
   $148 = (($this) + 4|0);
   HEAP32[$148>>2] = $147;
   $149 = HEAP32[$this>>2]|0;
   $150 = $149 << 3;
   _memcpy(($147|0),($136|0),($150|0))|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$136);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$72);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$151);
   __ZN5physx2Gu17RadixSortBufferedD2Ev($vararg_buffer);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $7 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,8,528480,145,528560,$vararg_buffer);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15EdgeListBuilder18CreateEdgesToFacesEjPKjPKt($this,$nb_faces,$dfaces,$wfaces) {
 $this = $this|0;
 $nb_faces = $nb_faces|0;
 $dfaces = $dfaces|0;
 $wfaces = $wfaces|0;
 var $$0 = 0, $$lcssa = 0, $$pre = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $exitcond = 0, $exitcond13 = 0, $i$08 = 0, $i1$04 = 0, $i2$02 = 0, $i3$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (__ZN5physx2Gu15EdgeListBuilder18CreateFacesToEdgesEjPKjPKt($this,$nb_faces,$dfaces,$wfaces)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = $3 << 3;
 $5 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$4,528480,242)|0);
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$this>>2]|0;
 $8 = $7 << 3;
 _memset(($5|0),0,($8|0))|0;
 $9 = ($nb_faces|0)==(0);
 if ($9) {
  $$pre = HEAP32[$6>>2]|0;
  $30 = $$pre;
 } else {
  $10 = (($this) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$6>>2]|0;
  $i$08 = 0;
  while(1) {
   $13 = (($11) + (($i$08*12)|0)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($12) + ($14<<3)|0) + 2|0);
   $16 = HEAP16[$15>>1]|0;
   $17 = (($16) + 1)<<16>>16;
   HEAP16[$15>>1] = $17;
   $18 = ((($11) + (($i$08*12)|0)|0) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($12) + ($19<<3)|0) + 2|0);
   $21 = HEAP16[$20>>1]|0;
   $22 = (($21) + 1)<<16>>16;
   HEAP16[$20>>1] = $22;
   $23 = ((($11) + (($i$08*12)|0)|0) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($12) + ($24<<3)|0) + 2|0);
   $26 = HEAP16[$25>>1]|0;
   $27 = (($26) + 1)<<16>>16;
   HEAP16[$25>>1] = $27;
   $28 = (($i$08) + 1)|0;
   $exitcond13 = ($28|0)==($nb_faces|0);
   if ($exitcond13) {
    $30 = $12;
    break;
   } else {
    $i$08 = $28;
   }
  }
 }
 $29 = (($30) + 4|0);
 HEAP32[$29>>2] = 0;
 $31 = HEAP32[$this>>2]|0;
 $32 = ($31>>>0)>(1);
 if ($32) {
  $38 = 0;$i1$04 = 1;
  while(1) {
   $33 = (($i1$04) + -1)|0;
   $34 = ((($30) + ($33<<3)|0) + 2|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = $35&65535;
   $37 = (($36) + ($38))|0;
   $39 = ((($30) + ($i1$04<<3)|0) + 4|0);
   HEAP32[$39>>2] = $37;
   $40 = (($i1$04) + 1)|0;
   $41 = HEAP32[$this>>2]|0;
   $42 = ($40>>>0)<($41>>>0);
   if ($42) {
    $38 = $37;$i1$04 = $40;
   } else {
    $$lcssa = $41;
    break;
   }
  }
 } else {
  $$lcssa = $31;
 }
 $43 = (($$lcssa) + -1)|0;
 $44 = ((($30) + ($43<<3)|0) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($30) + ($43<<3)|0) + 2|0);
 $47 = HEAP16[$46>>1]|0;
 $48 = $47&65535;
 $49 = (($48) + ($45))|0;
 $50 = $49 << 2;
 $51 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$50,528480,261)|0);
 $52 = (($this) + 20|0);
 HEAP32[$52>>2] = $51;
 if ($9) {
  $$pre16 = HEAP32[$6>>2]|0;
  $76 = $$pre16;
 } else {
  $53 = (($this) + 12|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = HEAP32[$6>>2]|0;
  $i2$02 = 0;
  while(1) {
   $56 = (($54) + (($i2$02*12)|0)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ((($55) + ($57<<3)|0) + 4|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 1)|0;
   HEAP32[$58>>2] = $60;
   $61 = (($51) + ($59<<2)|0);
   HEAP32[$61>>2] = $i2$02;
   $62 = ((($54) + (($i2$02*12)|0)|0) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($55) + ($63<<3)|0) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 1)|0;
   HEAP32[$64>>2] = $66;
   $67 = (($51) + ($65<<2)|0);
   HEAP32[$67>>2] = $i2$02;
   $68 = ((($54) + (($i2$02*12)|0)|0) + 8|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ((($55) + ($69<<3)|0) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($71) + 1)|0;
   HEAP32[$70>>2] = $72;
   $73 = (($51) + ($71<<2)|0);
   HEAP32[$73>>2] = $i2$02;
   $74 = (($i2$02) + 1)|0;
   $exitcond = ($74|0)==($nb_faces|0);
   if ($exitcond) {
    $76 = $55;
    break;
   } else {
    $i2$02 = $74;
   }
  }
 }
 $75 = (($76) + 4|0);
 HEAP32[$75>>2] = 0;
 $77 = HEAP32[$this>>2]|0;
 $78 = ($77>>>0)>(1);
 if ($78) {
  $84 = 0;$i3$01 = 1;
 } else {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $79 = (($i3$01) + -1)|0;
  $80 = ((($76) + ($79<<3)|0) + 2|0);
  $81 = HEAP16[$80>>1]|0;
  $82 = $81&65535;
  $83 = (($82) + ($84))|0;
  $85 = ((($76) + ($i3$01<<3)|0) + 4|0);
  HEAP32[$85>>2] = $83;
  $86 = (($i3$01) + 1)|0;
  $87 = HEAP32[$this>>2]|0;
  $88 = ($86>>>0)<($87>>>0);
  if ($88) {
   $84 = $83;$i3$01 = $86;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15EdgeListBuilder18ComputeActiveEdgesEjPKjPKtPKNS_6PxVec3Ef($this,$nb_faces,$dfaces,$wfaces,$verts,$epsilon) {
 $this = $this|0;
 $nb_faces = $nb_faces|0;
 $dfaces = $dfaces|0;
 $wfaces = $wfaces|0;
 $verts = $verts|0;
 $epsilon = Math_fround($epsilon);
 var $$0 = 0, $$0$i = 0, $$0$i28 = 0, $$in = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0;
 var $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0.0, $236 = 0.0, $237 = 0.0;
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0);
 var $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0);
 var $364 = 0, $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0;
 var $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0;
 var $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = Math_fround(0);
 var $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0);
 var $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0);
 var $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0;
 var $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0);
 var $508 = Math_fround(0), $509 = 0, $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0);
 var $544 = 0, $545 = Math_fround(0), $546 = 0, $547 = Math_fround(0), $548 = 0, $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0);
 var $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0;
 var $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = 0, $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0);
 var $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = Math_fround(0);
 var $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0);
 var $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = 0.0, $645 = 0.0, $646 = 0.0, $647 = Math_fround(0), $648 = Math_fround(0), $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = Math_fround(0), $664 = 0, $665 = Math_fround(0), $666 = Math_fround(0), $667 = 0, $668 = Math_fround(0), $669 = 0, $67 = 0;
 var $670 = Math_fround(0), $671 = Math_fround(0), $672 = 0, $673 = Math_fround(0), $674 = 0, $675 = Math_fround(0), $676 = Math_fround(0), $677 = 0, $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = 0, $681 = Math_fround(0), $682 = Math_fround(0), $683 = 0, $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0);
 var $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = 0, $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0);
 var $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = 0, $715 = Math_fround(0), $716 = Math_fround(0), $717 = 0, $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = 0, $722 = Math_fround(0), $723 = Math_fround(0);
 var $724 = Math_fround(0), $725 = Math_fround(0), $726 = 0, $727 = 0, $728 = Math_fround(0), $729 = 0, $73 = 0, $730 = Math_fround(0), $731 = 0, $732 = Math_fround(0), $733 = 0, $734 = Math_fround(0), $735 = 0, $736 = Math_fround(0), $737 = 0, $738 = Math_fround(0), $739 = 0, $74 = 0, $740 = Math_fround(0), $741 = 0;
 var $742 = Math_fround(0), $743 = 0, $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0;
 var $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = 0, $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = 0, $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0);
 var $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0);
 var $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = 0.0, $804 = 0.0, $805 = 0.0, $806 = Math_fround(0), $807 = Math_fround(0), $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = Math_fround(0), $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = Math_fround(0), $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = Math_fround(0), $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $Active$3$off0 = 0, $Active$4$off0 = 0, $Active$5$off0 = 0, $CurrentMark$088 = 0, $ED$089 = 0, $Edges$090 = 0, $MaxIndex$0$lcssa = 0, $MaxIndex$048 = 0, $MaxIndex$048$us = 0, $MaxIndex$2 = 0, $MaxIndex$2$us = 0, $VRef = 0, $VRef0$0 = 0, $VRef00$0 = 0, $VRef005$0 = 0, $VRef01$0 = 0, $VRef016$0 = 0, $VRef02$0 = 0, $VRef027$0 = 0;
 var $VRef035$0$MaxIndex$0 = 0, $VRef035$0$MaxIndex$0$us = 0, $VRef1$0 = 0, $VRef10$0 = 0, $VRef108$073 = 0, $VRef108$1 = 0, $VRef11$0 = 0, $VRef119$074 = 0, $VRef119$1 = 0, $VRef12$0 = 0, $VRef1210$075 = 0, $VRef1210$1 = 0, $VRef2$0 = 0, $VRef237$0$MaxIndex$2 = 0, $VRef237$0$MaxIndex$2$us = 0, $a11$079 = 0, $brmerge = 0, $doubleSided0$0$off077 = 0, $doubleSided0$1$off0 = 0, $doubleSided0$2$off0 = 0;
 var $doubleSided1$0$off078 = 0, $doubleSided1$1$off0 = 0, $doubleSided1$2$off0 = 0, $exitcond = 0, $exitcond101 = 0, $i$059 = 0, $i33$054 = 0, $i34$049 = 0, $i34$049$us = 0, $i38$045 = 0, $i42$043 = 0, $numUniqueTriangles$076 = 0, $numUniqueTriangles$1 = 0, $or$cond = 0, $or$cond15 = 0, $or$cond16 = 0, $or$cond17 = 0, $or$cond18 = 0, $or$cond19 = 0, $or$cond20 = 0;
 var $or$cond21 = 0, $or$cond22 = 0, $or$cond23 = 0, $or$cond24 = 0, $or$cond25 = 0, $or$cond26 = 0, $phitmp = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer7 = sp;
 $0 = sp + 19|0;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 $VRef = sp + 4|0;
 $3 = sp + 18|0;
 $4 = ($verts|0)==(0|0);
 if (!($4)) {
  $5 = ($dfaces|0)!=(0|0);
  $$not = $5 ^ 1;
  $6 = ($wfaces|0)==(0|0);
  $or$cond = $6 & $$not;
  if (!($or$cond)) {
   $8 = HEAP32[$this>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($10,8,528480,323,528656,$vararg_buffer7);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $11 = (($this) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,8,528480,330,528712,$vararg_buffer7);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $15 = (($this) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $18 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($18,8,528480,337,528776,$vararg_buffer7);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $19 = (($this) + 20|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $22 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($22,8,528480,344,528848,$vararg_buffer7);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $23 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$8,528480,349)|0);
   $$in = $8;$CurrentMark$088 = $23;$ED$089 = $16;$Edges$090 = $12;
   while(1) {
    $29 = (($$in) + -1)|0;
    $30 = (($ED$089) + 2|0);
    $31 = HEAP16[$30>>1]|0;
    $32 = $31&65535;
    $33 = ($31<<16>>16)==(1);
    L22: do {
     if ($33) {
      $Active$5$off0 = 1;
     } else {
      $34 = ($31<<16>>16)==(2);
      $35 = (($ED$089) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($20) + ($36<<2)|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38*3)|0;
      if ($34) {
       $40 = (($36) + 1)|0;
       $41 = (($20) + ($40<<2)|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42*3)|0;
       if ($5) {
        $44 = (($dfaces) + ($39<<2)|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = (($39) + 1)|0;
        $47 = (($dfaces) + ($46<<2)|0);
        $48 = HEAP32[$47>>2]|0;
        $49 = (($39) + 2)|0;
        $50 = (($dfaces) + ($49<<2)|0);
        $51 = HEAP32[$50>>2]|0;
        $52 = (($dfaces) + ($43<<2)|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = (($43) + 1)|0;
        $55 = (($dfaces) + ($54<<2)|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = (($43) + 2)|0;
        $58 = (($dfaces) + ($57<<2)|0);
        $59 = HEAP32[$58>>2]|0;
        $VRef00$0 = $45;$VRef01$0 = $48;$VRef02$0 = $51;$VRef10$0 = $53;$VRef11$0 = $56;$VRef12$0 = $59;
       } else {
        $60 = (($wfaces) + ($39<<1)|0);
        $61 = HEAP16[$60>>1]|0;
        $62 = $61&65535;
        $63 = (($39) + 1)|0;
        $64 = (($wfaces) + ($63<<1)|0);
        $65 = HEAP16[$64>>1]|0;
        $66 = $65&65535;
        $67 = (($39) + 2)|0;
        $68 = (($wfaces) + ($67<<1)|0);
        $69 = HEAP16[$68>>1]|0;
        $70 = $69&65535;
        $71 = (($wfaces) + ($43<<1)|0);
        $72 = HEAP16[$71>>1]|0;
        $73 = $72&65535;
        $74 = (($43) + 1)|0;
        $75 = (($wfaces) + ($74<<1)|0);
        $76 = HEAP16[$75>>1]|0;
        $77 = $76&65535;
        $78 = (($43) + 2)|0;
        $79 = (($wfaces) + ($78<<1)|0);
        $80 = HEAP16[$79>>1]|0;
        $81 = $80&65535;
        $VRef00$0 = $62;$VRef01$0 = $66;$VRef02$0 = $70;$VRef10$0 = $73;$VRef11$0 = $77;$VRef12$0 = $81;
       }
       $82 = HEAP32[$Edges$090>>2]|0;
       $83 = (($Edges$090) + 4|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = ($82|0)==($VRef00$0|0);
       do {
        if ($85) {
         $86 = ($84|0)==($VRef01$0|0);
         if ($86) {
          $$0$i = $VRef02$0;
         } else {
          $87 = ($84|0)==($VRef02$0|0);
          if ($87) {
           $$0$i = $VRef01$0;
          } else {
           label = 29;
          }
         }
        } else {
         $88 = ($82|0)==($VRef01$0|0);
         if ($88) {
          $89 = ($84|0)==($VRef00$0|0);
          if ($89) {
           $$0$i = $VRef02$0;
           break;
          }
          $90 = ($84|0)==($VRef02$0|0);
          if ($90) {
           $$0$i = $VRef00$0;
           break;
          } else {
           label = 29;
           break;
          }
         }
         $91 = ($82|0)==($VRef02$0|0);
         if ($91) {
          $92 = ($84|0)==($VRef01$0|0);
          if ($92) {
           $$0$i = $VRef00$0;
          } else {
           $93 = ($84|0)==($VRef00$0|0);
           if ($93) {
            $$0$i = $VRef01$0;
           } else {
            label = 29;
           }
          }
         } else {
          label = 29;
         }
        }
       } while(0);
       if ((label|0) == 29) {
        label = 0;
        $$0$i = -1;
       }
       $94 = (($verts) + (($VRef11$0*12)|0)|0);
       $95 = Math_fround(HEAPF32[$94>>2]);
       $96 = (($verts) + (($VRef10$0*12)|0)|0);
       $97 = Math_fround(HEAPF32[$96>>2]);
       $98 = Math_fround($95 - $97);
       $99 = ((($verts) + (($VRef11$0*12)|0)|0) + 4|0);
       $100 = Math_fround(HEAPF32[$99>>2]);
       $101 = ((($verts) + (($VRef10$0*12)|0)|0) + 4|0);
       $102 = Math_fround(HEAPF32[$101>>2]);
       $103 = Math_fround($100 - $102);
       $104 = ((($verts) + (($VRef11$0*12)|0)|0) + 8|0);
       $105 = Math_fround(HEAPF32[$104>>2]);
       $106 = ((($verts) + (($VRef10$0*12)|0)|0) + 8|0);
       $107 = Math_fround(HEAPF32[$106>>2]);
       $108 = Math_fround($105 - $107);
       $109 = (($verts) + (($VRef12$0*12)|0)|0);
       $110 = Math_fround(HEAPF32[$109>>2]);
       $111 = Math_fround($110 - $97);
       $112 = ((($verts) + (($VRef12$0*12)|0)|0) + 4|0);
       $113 = Math_fround(HEAPF32[$112>>2]);
       $114 = Math_fround($113 - $102);
       $115 = ((($verts) + (($VRef12$0*12)|0)|0) + 8|0);
       $116 = Math_fround(HEAPF32[$115>>2]);
       $117 = Math_fround($116 - $107);
       $118 = Math_fround($103 * $117);
       $119 = Math_fround($108 * $114);
       $120 = Math_fround($118 - $119);
       $121 = Math_fround($108 * $111);
       $122 = Math_fround($98 * $117);
       $123 = Math_fround($121 - $122);
       $124 = Math_fround($98 * $114);
       $125 = Math_fround($103 * $111);
       $126 = Math_fround($124 - $125);
       $127 = Math_fround($120 * $120);
       $128 = Math_fround($123 * $123);
       $129 = Math_fround($127 + $128);
       $130 = Math_fround($126 * $126);
       $131 = Math_fround($130 + $129);
       $132 = $131 > Math_fround(0.0);
       if ($132) {
        $133 = (Math_fround(Math_sqrt((Math_fround($131)))));
        $134 = Math_fround(Math_fround(1.0) / $133);
        $135 = Math_fround($120 * $134);
        $136 = Math_fround($123 * $134);
        $137 = Math_fround($126 * $134);
        $139 = $135;$141 = $136;$144 = $137;
       } else {
        $139 = Math_fround(0.0);$141 = Math_fround(0.0);$144 = Math_fround(0.0);
       }
       $138 = Math_fround($139 * $97);
       $140 = Math_fround($141 * $102);
       $142 = Math_fround($138 + $140);
       $143 = Math_fround($144 * $107);
       $145 = Math_fround($142 + $143);
       $146 = (($verts) + (($$0$i*12)|0)|0);
       $147 = Math_fround(HEAPF32[$146>>2]);
       $148 = Math_fround($139 * $147);
       $149 = ((($verts) + (($$0$i*12)|0)|0) + 4|0);
       $150 = Math_fround(HEAPF32[$149>>2]);
       $151 = Math_fround($141 * $150);
       $152 = Math_fround($148 + $151);
       $153 = ((($verts) + (($$0$i*12)|0)|0) + 8|0);
       $154 = Math_fround(HEAPF32[$153>>2]);
       $155 = Math_fround($144 * $154);
       $156 = Math_fround($152 + $155);
       $157 = Math_fround($156 - $145);
       $158 = $157 < Math_fround(0.0);
       $159 = (($verts) + (($VRef00$0*12)|0)|0);
       $160 = Math_fround(HEAPF32[$159>>2]);
       $161 = ((($verts) + (($VRef00$0*12)|0)|0) + 4|0);
       $162 = Math_fround(HEAPF32[$161>>2]);
       $163 = ((($verts) + (($VRef00$0*12)|0)|0) + 8|0);
       $164 = Math_fround(HEAPF32[$163>>2]);
       $165 = (($verts) + (($VRef01$0*12)|0)|0);
       $166 = Math_fround(HEAPF32[$165>>2]);
       $167 = ((($verts) + (($VRef01$0*12)|0)|0) + 4|0);
       $168 = Math_fround(HEAPF32[$167>>2]);
       $169 = ((($verts) + (($VRef01$0*12)|0)|0) + 8|0);
       $170 = Math_fround(HEAPF32[$169>>2]);
       $171 = (($verts) + (($VRef02$0*12)|0)|0);
       $172 = Math_fround(HEAPF32[$171>>2]);
       $173 = ((($verts) + (($VRef02$0*12)|0)|0) + 4|0);
       $174 = Math_fround(HEAPF32[$173>>2]);
       $175 = ((($verts) + (($VRef02$0*12)|0)|0) + 8|0);
       $176 = Math_fround(HEAPF32[$175>>2]);
       $177 = Math_fround($166 - $160);
       $178 = Math_fround($168 - $162);
       $179 = Math_fround($170 - $164);
       $180 = Math_fround($172 - $160);
       $181 = Math_fround($174 - $162);
       $182 = Math_fround($176 - $164);
       $183 = Math_fround($178 * $182);
       $184 = Math_fround($179 * $181);
       $185 = Math_fround($183 - $184);
       $186 = Math_fround($179 * $180);
       $187 = Math_fround($177 * $182);
       $188 = Math_fround($186 - $187);
       $189 = Math_fround($177 * $181);
       $190 = Math_fround($178 * $180);
       $191 = Math_fround($189 - $190);
       $192 = Math_fround($185 * $185);
       $193 = Math_fround($188 * $188);
       $194 = Math_fround($192 + $193);
       $195 = Math_fround($191 * $191);
       $196 = Math_fround($195 + $194);
       $197 = (Math_fround(Math_sqrt((Math_fround($196)))));
       $198 = $197 > Math_fround(0.0);
       if ($158) {
        if ($198) {
         $199 = Math_fround(Math_fround(1.0) / $197);
         $200 = Math_fround($185 * $199);
         $201 = Math_fround($188 * $199);
         $202 = Math_fround($191 * $199);
         $211 = $200;$214 = $201;$218 = $202;
        } else {
         $211 = $185;$214 = $188;$218 = $191;
        }
        $203 = (Math_fround(Math_sqrt((Math_fround($131)))));
        $204 = $203 > Math_fround(0.0);
        if ($204) {
         $205 = Math_fround(Math_fround(1.0) / $203);
         $206 = Math_fround($120 * $205);
         $207 = Math_fround($123 * $205);
         $208 = Math_fround($126 * $205);
         $210 = $206;$213 = $207;$217 = $208;
        } else {
         $210 = $120;$213 = $123;$217 = $126;
        }
        $209 = Math_fround($211 * $210);
        $212 = Math_fround($214 * $213);
        $215 = Math_fround($212 + $209);
        $216 = Math_fround($218 * $217);
        $219 = Math_fround($216 + $215);
        $220 = Math_fround($214 * $217);
        $221 = Math_fround($218 * $213);
        $222 = Math_fround($220 - $221);
        $223 = Math_fround($218 * $210);
        $224 = Math_fround($211 * $217);
        $225 = Math_fround($223 - $224);
        $226 = Math_fround($211 * $213);
        $227 = Math_fround($214 * $210);
        $228 = Math_fround($226 - $227);
        $229 = Math_fround($222 * $222);
        $230 = Math_fround($225 * $225);
        $231 = Math_fround($229 + $230);
        $232 = Math_fround($228 * $228);
        $233 = Math_fround($232 + $231);
        $234 = (Math_fround(Math_sqrt((Math_fround($233)))));
        $235 = +$234;
        $236 = +$219;
        $237 = (+Math_atan2((+$235),(+$236)));
        $238 = Math_fround($237);
        $239 = (Math_fround(Math_abs((Math_fround($238)))));
        $240 = $239 > $epsilon;
        $Active$5$off0 = $240;
        break;
       } else {
        if ($198) {
         $241 = Math_fround(Math_fround(1.0) / $197);
         $242 = Math_fround($185 * $241);
         $243 = Math_fround($188 * $241);
         $244 = Math_fround($191 * $241);
         $253 = $242;$256 = $243;$260 = $244;
        } else {
         $253 = $185;$256 = $188;$260 = $191;
        }
        $245 = (Math_fround(Math_sqrt((Math_fround($131)))));
        $246 = $245 > Math_fround(0.0);
        if ($246) {
         $247 = Math_fround(Math_fround(1.0) / $245);
         $248 = Math_fround($120 * $247);
         $249 = Math_fround($123 * $247);
         $250 = Math_fround($126 * $247);
         $252 = $248;$255 = $249;$259 = $250;
        } else {
         $252 = $120;$255 = $123;$259 = $126;
        }
        $251 = Math_fround($253 * $252);
        $254 = Math_fround($256 * $255);
        $257 = Math_fround($254 + $251);
        $258 = Math_fround($260 * $259);
        $261 = Math_fround($258 + $257);
        $262 = $261 < Math_fround(-0.999000012874603271484);
        $Active$5$off0 = $262;
        break;
       }
      }
      if ($5) {
       $263 = (($dfaces) + ($39<<2)|0);
       $264 = HEAP32[$263>>2]|0;
       $265 = (($39) + 1)|0;
       $266 = (($dfaces) + ($265<<2)|0);
       $267 = HEAP32[$266>>2]|0;
       $268 = (($39) + 2)|0;
       $269 = (($dfaces) + ($268<<2)|0);
       $270 = HEAP32[$269>>2]|0;
       $VRef005$0 = $264;$VRef016$0 = $267;$VRef027$0 = $270;
      } else {
       $271 = (($wfaces) + ($39<<1)|0);
       $272 = HEAP16[$271>>1]|0;
       $273 = $272&65535;
       $274 = (($39) + 1)|0;
       $275 = (($wfaces) + ($274<<1)|0);
       $276 = HEAP16[$275>>1]|0;
       $277 = $276&65535;
       $278 = (($39) + 2)|0;
       $279 = (($wfaces) + ($278<<1)|0);
       $280 = HEAP16[$279>>1]|0;
       $281 = $280&65535;
       $VRef005$0 = $273;$VRef016$0 = $277;$VRef027$0 = $281;
      }
      $282 = ($31&65535)>(1);
      if ($282) {
       $283 = (($verts) + (($VRef005$0*12)|0)|0);
       $284 = ((($verts) + (($VRef005$0*12)|0)|0) + 4|0);
       $285 = ((($verts) + (($VRef005$0*12)|0)|0) + 8|0);
       $286 = (($verts) + (($VRef016$0*12)|0)|0);
       $287 = ((($verts) + (($VRef016$0*12)|0)|0) + 4|0);
       $288 = ((($verts) + (($VRef016$0*12)|0)|0) + 8|0);
       $289 = (($verts) + (($VRef027$0*12)|0)|0);
       $290 = ((($verts) + (($VRef027$0*12)|0)|0) + 4|0);
       $291 = ((($verts) + (($VRef027$0*12)|0)|0) + 8|0);
       $VRef108$073 = 0;$VRef119$074 = 0;$VRef1210$075 = 0;$a11$079 = 1;$doubleSided0$0$off077 = 0;$doubleSided1$0$off078 = 0;$numUniqueTriangles$076 = 1;
       while(1) {
        $292 = (($36) + ($a11$079))|0;
        $293 = (($20) + ($292<<2)|0);
        $294 = HEAP32[$293>>2]|0;
        $295 = ($294*3)|0;
        if ($5) {
         $296 = (($dfaces) + ($295<<2)|0);
         $297 = HEAP32[$296>>2]|0;
         $298 = (($295) + 1)|0;
         $299 = (($dfaces) + ($298<<2)|0);
         $300 = HEAP32[$299>>2]|0;
         $301 = (($295) + 2)|0;
         $302 = (($dfaces) + ($301<<2)|0);
         $303 = HEAP32[$302>>2]|0;
         $VRef0$0 = $297;$VRef1$0 = $300;$VRef2$0 = $303;
        } else {
         $304 = (($wfaces) + ($295<<1)|0);
         $305 = HEAP16[$304>>1]|0;
         $306 = $305&65535;
         $307 = (($295) + 1)|0;
         $308 = (($wfaces) + ($307<<1)|0);
         $309 = HEAP16[$308>>1]|0;
         $310 = $309&65535;
         $311 = (($295) + 2)|0;
         $312 = (($wfaces) + ($311<<1)|0);
         $313 = HEAP16[$312>>1]|0;
         $314 = $313&65535;
         $VRef0$0 = $306;$VRef1$0 = $310;$VRef2$0 = $314;
        }
        $315 = ($VRef0$0|0)==($VRef005$0|0);
        $316 = ($VRef0$0|0)==($VRef016$0|0);
        $or$cond15 = $315 | $316;
        $317 = ($VRef0$0|0)==($VRef027$0|0);
        $or$cond16 = $or$cond15 | $317;
        if ($or$cond16) {
         $318 = ($VRef1$0|0)==($VRef005$0|0);
         $319 = ($VRef1$0|0)==($VRef016$0|0);
         $or$cond17 = $318 | $319;
         $320 = ($VRef1$0|0)==($VRef027$0|0);
         $or$cond18 = $or$cond17 | $320;
         if ($or$cond18) {
          $321 = ($VRef2$0|0)==($VRef005$0|0);
          $322 = ($VRef2$0|0)==($VRef016$0|0);
          $or$cond19 = $321 | $322;
          $323 = ($VRef2$0|0)==($VRef027$0|0);
          $or$cond20 = $or$cond19 | $323;
          if ($or$cond20) {
           $435 = Math_fround(HEAPF32[$283>>2]);
           $436 = Math_fround(HEAPF32[$284>>2]);
           $437 = Math_fround(HEAPF32[$285>>2]);
           $438 = Math_fround(HEAPF32[$286>>2]);
           $439 = Math_fround(HEAPF32[$287>>2]);
           $440 = Math_fround(HEAPF32[$288>>2]);
           $441 = Math_fround(HEAPF32[$289>>2]);
           $442 = Math_fround(HEAPF32[$290>>2]);
           $443 = Math_fround(HEAPF32[$291>>2]);
           $444 = (($verts) + (($VRef0$0*12)|0)|0);
           $445 = Math_fround(HEAPF32[$444>>2]);
           $446 = ((($verts) + (($VRef0$0*12)|0)|0) + 4|0);
           $447 = Math_fround(HEAPF32[$446>>2]);
           $448 = ((($verts) + (($VRef0$0*12)|0)|0) + 8|0);
           $449 = Math_fround(HEAPF32[$448>>2]);
           $450 = (($verts) + (($VRef1$0*12)|0)|0);
           $451 = Math_fround(HEAPF32[$450>>2]);
           $452 = ((($verts) + (($VRef1$0*12)|0)|0) + 4|0);
           $453 = Math_fround(HEAPF32[$452>>2]);
           $454 = ((($verts) + (($VRef1$0*12)|0)|0) + 8|0);
           $455 = Math_fround(HEAPF32[$454>>2]);
           $456 = (($verts) + (($VRef2$0*12)|0)|0);
           $457 = Math_fround(HEAPF32[$456>>2]);
           $458 = ((($verts) + (($VRef2$0*12)|0)|0) + 4|0);
           $459 = Math_fround(HEAPF32[$458>>2]);
           $460 = ((($verts) + (($VRef2$0*12)|0)|0) + 8|0);
           $461 = Math_fround(HEAPF32[$460>>2]);
           $462 = Math_fround($438 - $435);
           $463 = Math_fround($439 - $436);
           $464 = Math_fround($440 - $437);
           $465 = Math_fround($441 - $435);
           $466 = Math_fround($442 - $436);
           $467 = Math_fround($443 - $437);
           $468 = Math_fround($463 * $467);
           $469 = Math_fround($464 * $466);
           $470 = Math_fround($468 - $469);
           $471 = Math_fround($464 * $465);
           $472 = Math_fround($462 * $467);
           $473 = Math_fround($471 - $472);
           $474 = Math_fround($462 * $466);
           $475 = Math_fround($463 * $465);
           $476 = Math_fround($474 - $475);
           $477 = Math_fround($470 * $470);
           $478 = Math_fround($473 * $473);
           $479 = Math_fround($477 + $478);
           $480 = Math_fround($476 * $476);
           $481 = Math_fround($480 + $479);
           $482 = (Math_fround(Math_sqrt((Math_fround($481)))));
           $483 = $482 > Math_fround(0.0);
           if ($483) {
            $484 = Math_fround(Math_fround(1.0) / $482);
            $485 = Math_fround($470 * $484);
            $486 = Math_fround($473 * $484);
            $487 = Math_fround($476 * $484);
            $516 = $485;$519 = $486;$523 = $487;
           } else {
            $516 = $470;$519 = $473;$523 = $476;
           }
           $488 = Math_fround($451 - $445);
           $489 = Math_fround($453 - $447);
           $490 = Math_fround($455 - $449);
           $491 = Math_fround($457 - $445);
           $492 = Math_fround($459 - $447);
           $493 = Math_fround($461 - $449);
           $494 = Math_fround($489 * $493);
           $495 = Math_fround($490 * $492);
           $496 = Math_fround($494 - $495);
           $497 = Math_fround($490 * $491);
           $498 = Math_fround($488 * $493);
           $499 = Math_fround($497 - $498);
           $500 = Math_fround($488 * $492);
           $501 = Math_fround($489 * $491);
           $502 = Math_fround($500 - $501);
           $503 = Math_fround($496 * $496);
           $504 = Math_fround($499 * $499);
           $505 = Math_fround($503 + $504);
           $506 = Math_fround($502 * $502);
           $507 = Math_fround($506 + $505);
           $508 = (Math_fround(Math_sqrt((Math_fround($507)))));
           $509 = $508 > Math_fround(0.0);
           if ($509) {
            $510 = Math_fround(Math_fround(1.0) / $508);
            $511 = Math_fround($496 * $510);
            $512 = Math_fround($499 * $510);
            $513 = Math_fround($502 * $510);
            $515 = $511;$518 = $512;$522 = $513;
           } else {
            $515 = $496;$518 = $499;$522 = $502;
           }
           $514 = Math_fround($516 * $515);
           $517 = Math_fround($519 * $518);
           $520 = Math_fround($517 + $514);
           $521 = Math_fround($523 * $522);
           $524 = Math_fround($521 + $520);
           $525 = $524 < Math_fround(-0.999000012874603271484);
           $doubleSided0$1$off0 = $525 | $doubleSided0$0$off077;
           $VRef108$1 = $VRef108$073;$VRef119$1 = $VRef119$074;$VRef1210$1 = $VRef1210$075;$doubleSided0$2$off0 = $doubleSided0$1$off0;$doubleSided1$2$off0 = $doubleSided1$0$off078;$numUniqueTriangles$1 = $numUniqueTriangles$076;
          } else {
           label = 54;
          }
         } else {
          label = 54;
         }
        } else {
         label = 54;
        }
        do {
         if ((label|0) == 54) {
          label = 0;
          $324 = ($numUniqueTriangles$076|0)==(2);
          if (!($324)) {
           $434 = (($numUniqueTriangles$076) + 1)|0;
           $VRef108$1 = $VRef0$0;$VRef119$1 = $VRef1$0;$VRef1210$1 = $VRef2$0;$doubleSided0$2$off0 = $doubleSided0$0$off077;$doubleSided1$2$off0 = $doubleSided1$0$off078;$numUniqueTriangles$1 = $434;
           break;
          }
          $325 = ($VRef0$0|0)==($VRef108$073|0);
          $326 = ($VRef0$0|0)==($VRef119$074|0);
          $or$cond21 = $325 | $326;
          $327 = ($VRef0$0|0)==($VRef1210$075|0);
          $or$cond22 = $or$cond21 | $327;
          if (!($or$cond22)) {
           $Active$5$off0 = 1;
           break L22;
          }
          $328 = ($VRef1$0|0)==($VRef108$073|0);
          $329 = ($VRef1$0|0)==($VRef119$074|0);
          $or$cond23 = $328 | $329;
          $330 = ($VRef1$0|0)==($VRef1210$075|0);
          $or$cond24 = $or$cond23 | $330;
          if (!($or$cond24)) {
           $Active$5$off0 = 1;
           break L22;
          }
          $331 = ($VRef2$0|0)==($VRef108$073|0);
          $332 = ($VRef2$0|0)==($VRef119$074|0);
          $or$cond25 = $331 | $332;
          $333 = ($VRef2$0|0)==($VRef1210$075|0);
          $or$cond26 = $or$cond25 | $333;
          if (!($or$cond26)) {
           $Active$5$off0 = 1;
           break L22;
          }
          $334 = (($verts) + (($VRef108$073*12)|0)|0);
          $335 = Math_fround(HEAPF32[$334>>2]);
          $336 = ((($verts) + (($VRef108$073*12)|0)|0) + 4|0);
          $337 = Math_fround(HEAPF32[$336>>2]);
          $338 = ((($verts) + (($VRef108$073*12)|0)|0) + 8|0);
          $339 = Math_fround(HEAPF32[$338>>2]);
          $340 = (($verts) + (($VRef119$074*12)|0)|0);
          $341 = Math_fround(HEAPF32[$340>>2]);
          $342 = ((($verts) + (($VRef119$074*12)|0)|0) + 4|0);
          $343 = Math_fround(HEAPF32[$342>>2]);
          $344 = ((($verts) + (($VRef119$074*12)|0)|0) + 8|0);
          $345 = Math_fround(HEAPF32[$344>>2]);
          $346 = (($verts) + (($VRef1210$075*12)|0)|0);
          $347 = Math_fround(HEAPF32[$346>>2]);
          $348 = ((($verts) + (($VRef1210$075*12)|0)|0) + 4|0);
          $349 = Math_fround(HEAPF32[$348>>2]);
          $350 = ((($verts) + (($VRef1210$075*12)|0)|0) + 8|0);
          $351 = Math_fround(HEAPF32[$350>>2]);
          $352 = (($verts) + (($VRef0$0*12)|0)|0);
          $353 = Math_fround(HEAPF32[$352>>2]);
          $354 = ((($verts) + (($VRef0$0*12)|0)|0) + 4|0);
          $355 = Math_fround(HEAPF32[$354>>2]);
          $356 = ((($verts) + (($VRef0$0*12)|0)|0) + 8|0);
          $357 = Math_fround(HEAPF32[$356>>2]);
          $358 = (($verts) + (($VRef1$0*12)|0)|0);
          $359 = Math_fround(HEAPF32[$358>>2]);
          $360 = ((($verts) + (($VRef1$0*12)|0)|0) + 4|0);
          $361 = Math_fround(HEAPF32[$360>>2]);
          $362 = ((($verts) + (($VRef1$0*12)|0)|0) + 8|0);
          $363 = Math_fround(HEAPF32[$362>>2]);
          $364 = (($verts) + (($VRef2$0*12)|0)|0);
          $365 = Math_fround(HEAPF32[$364>>2]);
          $366 = ((($verts) + (($VRef2$0*12)|0)|0) + 4|0);
          $367 = Math_fround(HEAPF32[$366>>2]);
          $368 = ((($verts) + (($VRef2$0*12)|0)|0) + 8|0);
          $369 = Math_fround(HEAPF32[$368>>2]);
          $370 = Math_fround($341 - $335);
          $371 = Math_fround($343 - $337);
          $372 = Math_fround($345 - $339);
          $373 = Math_fround($347 - $335);
          $374 = Math_fround($349 - $337);
          $375 = Math_fround($351 - $339);
          $376 = Math_fround($371 * $375);
          $377 = Math_fround($372 * $374);
          $378 = Math_fround($376 - $377);
          $379 = Math_fround($372 * $373);
          $380 = Math_fround($370 * $375);
          $381 = Math_fround($379 - $380);
          $382 = Math_fround($370 * $374);
          $383 = Math_fround($371 * $373);
          $384 = Math_fround($382 - $383);
          $385 = Math_fround($378 * $378);
          $386 = Math_fround($381 * $381);
          $387 = Math_fround($385 + $386);
          $388 = Math_fround($384 * $384);
          $389 = Math_fround($388 + $387);
          $390 = (Math_fround(Math_sqrt((Math_fround($389)))));
          $391 = $390 > Math_fround(0.0);
          if ($391) {
           $392 = Math_fround(Math_fround(1.0) / $390);
           $393 = Math_fround($378 * $392);
           $394 = Math_fround($381 * $392);
           $395 = Math_fround($384 * $392);
           $424 = $393;$427 = $394;$431 = $395;
          } else {
           $424 = $378;$427 = $381;$431 = $384;
          }
          $396 = Math_fround($359 - $353);
          $397 = Math_fround($361 - $355);
          $398 = Math_fround($363 - $357);
          $399 = Math_fround($365 - $353);
          $400 = Math_fround($367 - $355);
          $401 = Math_fround($369 - $357);
          $402 = Math_fround($397 * $401);
          $403 = Math_fround($398 * $400);
          $404 = Math_fround($402 - $403);
          $405 = Math_fround($398 * $399);
          $406 = Math_fround($396 * $401);
          $407 = Math_fround($405 - $406);
          $408 = Math_fround($396 * $400);
          $409 = Math_fround($397 * $399);
          $410 = Math_fround($408 - $409);
          $411 = Math_fround($404 * $404);
          $412 = Math_fround($407 * $407);
          $413 = Math_fround($411 + $412);
          $414 = Math_fround($410 * $410);
          $415 = Math_fround($414 + $413);
          $416 = (Math_fround(Math_sqrt((Math_fround($415)))));
          $417 = $416 > Math_fround(0.0);
          if ($417) {
           $418 = Math_fround(Math_fround(1.0) / $416);
           $419 = Math_fround($404 * $418);
           $420 = Math_fround($407 * $418);
           $421 = Math_fround($410 * $418);
           $423 = $419;$426 = $420;$430 = $421;
          } else {
           $423 = $404;$426 = $407;$430 = $410;
          }
          $422 = Math_fround($424 * $423);
          $425 = Math_fround($427 * $426);
          $428 = Math_fround($425 + $422);
          $429 = Math_fround($431 * $430);
          $432 = Math_fround($429 + $428);
          $433 = $432 < Math_fround(-0.999000012874603271484);
          $doubleSided1$1$off0 = $433 | $doubleSided1$0$off078;
          $VRef108$1 = $VRef108$073;$VRef119$1 = $VRef119$074;$VRef1210$1 = $VRef1210$075;$doubleSided0$2$off0 = $doubleSided0$0$off077;$doubleSided1$2$off0 = $doubleSided1$1$off0;$numUniqueTriangles$1 = 2;
         }
        } while(0);
        $526 = (($a11$079) + 1)|0;
        $527 = ($526>>>0)<($32>>>0);
        if ($527) {
         $VRef108$073 = $VRef108$1;$VRef119$074 = $VRef119$1;$VRef1210$075 = $VRef1210$1;$a11$079 = $526;$doubleSided0$0$off077 = $doubleSided0$2$off0;$doubleSided1$0$off078 = $doubleSided1$2$off0;$numUniqueTriangles$076 = $numUniqueTriangles$1;
        } else {
         break;
        }
       }
       $528 = ($numUniqueTriangles$1|0)==(1);
       $529 = ($numUniqueTriangles$1|0)==(2);
       if ($529) {
        $brmerge = $doubleSided0$2$off0 | $doubleSided1$2$off0;
        if ($brmerge) {
         $530 = (($verts) + (($VRef119$1*12)|0)|0);
         $531 = (($verts) + (($VRef108$1*12)|0)|0);
         $532 = ((($verts) + (($VRef119$1*12)|0)|0) + 4|0);
         $533 = ((($verts) + (($VRef108$1*12)|0)|0) + 4|0);
         $534 = ((($verts) + (($VRef119$1*12)|0)|0) + 8|0);
         $535 = ((($verts) + (($VRef108$1*12)|0)|0) + 8|0);
         $536 = (($verts) + (($VRef1210$1*12)|0)|0);
         $537 = ((($verts) + (($VRef1210$1*12)|0)|0) + 4|0);
         $538 = ((($verts) + (($VRef1210$1*12)|0)|0) + 8|0);
         $539 = Math_fround(HEAPF32[$531>>2]);
         $540 = Math_fround(HEAPF32[$533>>2]);
         $541 = Math_fround(HEAPF32[$535>>2]);
         $542 = (($verts) + (($VRef005$0*12)|0)|0);
         $543 = Math_fround(HEAPF32[$542>>2]);
         $544 = ((($verts) + (($VRef005$0*12)|0)|0) + 4|0);
         $545 = Math_fround(HEAPF32[$544>>2]);
         $546 = ((($verts) + (($VRef005$0*12)|0)|0) + 8|0);
         $547 = Math_fround(HEAPF32[$546>>2]);
         $548 = (($verts) + (($VRef016$0*12)|0)|0);
         $549 = Math_fround(HEAPF32[$548>>2]);
         $550 = ((($verts) + (($VRef016$0*12)|0)|0) + 4|0);
         $551 = Math_fround(HEAPF32[$550>>2]);
         $552 = ((($verts) + (($VRef016$0*12)|0)|0) + 8|0);
         $553 = Math_fround(HEAPF32[$552>>2]);
         $554 = (($verts) + (($VRef027$0*12)|0)|0);
         $555 = Math_fround(HEAPF32[$554>>2]);
         $556 = ((($verts) + (($VRef027$0*12)|0)|0) + 4|0);
         $557 = Math_fround(HEAPF32[$556>>2]);
         $558 = ((($verts) + (($VRef027$0*12)|0)|0) + 8|0);
         $559 = Math_fround(HEAPF32[$558>>2]);
         $560 = Math_fround(HEAPF32[$530>>2]);
         $561 = Math_fround(HEAPF32[$532>>2]);
         $562 = Math_fround(HEAPF32[$534>>2]);
         $563 = Math_fround(HEAPF32[$536>>2]);
         $564 = Math_fround(HEAPF32[$537>>2]);
         $565 = Math_fround(HEAPF32[$538>>2]);
         $566 = Math_fround($549 - $543);
         $567 = Math_fround($551 - $545);
         $568 = Math_fround($553 - $547);
         $569 = Math_fround($555 - $543);
         $570 = Math_fround($557 - $545);
         $571 = Math_fround($559 - $547);
         $572 = Math_fround($567 * $571);
         $573 = Math_fround($568 * $570);
         $574 = Math_fround($572 - $573);
         $575 = Math_fround($568 * $569);
         $576 = Math_fround($566 * $571);
         $577 = Math_fround($575 - $576);
         $578 = Math_fround($566 * $570);
         $579 = Math_fround($567 * $569);
         $580 = Math_fround($578 - $579);
         $581 = Math_fround($574 * $574);
         $582 = Math_fround($577 * $577);
         $583 = Math_fround($581 + $582);
         $584 = Math_fround($580 * $580);
         $585 = Math_fround($584 + $583);
         $586 = (Math_fround(Math_sqrt((Math_fround($585)))));
         $587 = $586 > Math_fround(0.0);
         if ($587) {
          $588 = Math_fround(Math_fround(1.0) / $586);
          $589 = Math_fround($574 * $588);
          $590 = Math_fround($577 * $588);
          $591 = Math_fround($580 * $588);
          $620 = $589;$623 = $590;$627 = $591;
         } else {
          $620 = $574;$623 = $577;$627 = $580;
         }
         $592 = Math_fround($560 - $539);
         $593 = Math_fround($561 - $540);
         $594 = Math_fround($562 - $541);
         $595 = Math_fround($563 - $539);
         $596 = Math_fround($564 - $540);
         $597 = Math_fround($565 - $541);
         $598 = Math_fround($593 * $597);
         $599 = Math_fround($594 * $596);
         $600 = Math_fround($598 - $599);
         $601 = Math_fround($594 * $595);
         $602 = Math_fround($592 * $597);
         $603 = Math_fround($601 - $602);
         $604 = Math_fround($592 * $596);
         $605 = Math_fround($593 * $595);
         $606 = Math_fround($604 - $605);
         $607 = Math_fround($600 * $600);
         $608 = Math_fround($603 * $603);
         $609 = Math_fround($607 + $608);
         $610 = Math_fround($606 * $606);
         $611 = Math_fround($610 + $609);
         $612 = (Math_fround(Math_sqrt((Math_fround($611)))));
         $613 = $612 > Math_fround(0.0);
         if ($613) {
          $614 = Math_fround(Math_fround(1.0) / $612);
          $615 = Math_fround($600 * $614);
          $616 = Math_fround($603 * $614);
          $617 = Math_fround($606 * $614);
          $619 = $615;$622 = $616;$626 = $617;
         } else {
          $619 = $600;$622 = $603;$626 = $606;
         }
         $618 = Math_fround($620 * $619);
         $621 = Math_fround($623 * $622);
         $624 = Math_fround($621 + $618);
         $625 = Math_fround($627 * $626);
         $628 = Math_fround($625 + $624);
         $629 = Math_fround($623 * $626);
         $630 = Math_fround($627 * $622);
         $631 = Math_fround($629 - $630);
         $632 = Math_fround($627 * $619);
         $633 = Math_fround($620 * $626);
         $634 = Math_fround($632 - $633);
         $635 = Math_fround($620 * $622);
         $636 = Math_fround($623 * $619);
         $637 = Math_fround($635 - $636);
         $638 = Math_fround($631 * $631);
         $639 = Math_fround($634 * $634);
         $640 = Math_fround($638 + $639);
         $641 = Math_fround($637 * $637);
         $642 = Math_fround($641 + $640);
         $643 = (Math_fround(Math_sqrt((Math_fround($642)))));
         $644 = +$643;
         $645 = +$628;
         $646 = (+Math_atan2((+$644),(+$645)));
         $647 = Math_fround($646);
         $648 = (Math_fround(Math_abs((Math_fround($647)))));
         $649 = $648 > $epsilon;
         $Active$3$off0 = $649 | $528;
         $Active$5$off0 = $Active$3$off0;
         break;
        }
        $650 = HEAP32[$Edges$090>>2]|0;
        $651 = (($Edges$090) + 4|0);
        $652 = HEAP32[$651>>2]|0;
        $653 = ($650|0)==($VRef005$0|0);
        do {
         if ($653) {
          $654 = ($652|0)==($VRef016$0|0);
          if ($654) {
           $$0$i28 = $VRef027$0;
          } else {
           $655 = ($652|0)==($VRef027$0|0);
           if ($655) {
            $$0$i28 = $VRef016$0;
           } else {
            label = 86;
           }
          }
         } else {
          $656 = ($650|0)==($VRef016$0|0);
          if ($656) {
           $657 = ($652|0)==($VRef005$0|0);
           if ($657) {
            $$0$i28 = $VRef027$0;
            break;
           }
           $658 = ($652|0)==($VRef027$0|0);
           if ($658) {
            $$0$i28 = $VRef005$0;
            break;
           } else {
            label = 86;
            break;
           }
          }
          $659 = ($650|0)==($VRef027$0|0);
          if ($659) {
           $660 = ($652|0)==($VRef016$0|0);
           if ($660) {
            $$0$i28 = $VRef005$0;
           } else {
            $661 = ($652|0)==($VRef005$0|0);
            if ($661) {
             $$0$i28 = $VRef016$0;
            } else {
             label = 86;
            }
           }
          } else {
           label = 86;
          }
         }
        } while(0);
        if ((label|0) == 86) {
         label = 0;
         $$0$i28 = -1;
        }
        $662 = (($verts) + (($VRef119$1*12)|0)|0);
        $663 = Math_fround(HEAPF32[$662>>2]);
        $664 = (($verts) + (($VRef108$1*12)|0)|0);
        $665 = Math_fround(HEAPF32[$664>>2]);
        $666 = Math_fround($663 - $665);
        $667 = ((($verts) + (($VRef119$1*12)|0)|0) + 4|0);
        $668 = Math_fround(HEAPF32[$667>>2]);
        $669 = ((($verts) + (($VRef108$1*12)|0)|0) + 4|0);
        $670 = Math_fround(HEAPF32[$669>>2]);
        $671 = Math_fround($668 - $670);
        $672 = ((($verts) + (($VRef119$1*12)|0)|0) + 8|0);
        $673 = Math_fround(HEAPF32[$672>>2]);
        $674 = ((($verts) + (($VRef108$1*12)|0)|0) + 8|0);
        $675 = Math_fround(HEAPF32[$674>>2]);
        $676 = Math_fround($673 - $675);
        $677 = (($verts) + (($VRef1210$1*12)|0)|0);
        $678 = Math_fround(HEAPF32[$677>>2]);
        $679 = Math_fround($678 - $665);
        $680 = ((($verts) + (($VRef1210$1*12)|0)|0) + 4|0);
        $681 = Math_fround(HEAPF32[$680>>2]);
        $682 = Math_fround($681 - $670);
        $683 = ((($verts) + (($VRef1210$1*12)|0)|0) + 8|0);
        $684 = Math_fround(HEAPF32[$683>>2]);
        $685 = Math_fround($684 - $675);
        $686 = Math_fround($671 * $685);
        $687 = Math_fround($676 * $682);
        $688 = Math_fround($686 - $687);
        $689 = Math_fround($676 * $679);
        $690 = Math_fround($666 * $685);
        $691 = Math_fround($689 - $690);
        $692 = Math_fround($666 * $682);
        $693 = Math_fround($671 * $679);
        $694 = Math_fround($692 - $693);
        $695 = Math_fround($688 * $688);
        $696 = Math_fround($691 * $691);
        $697 = Math_fround($695 + $696);
        $698 = Math_fround($694 * $694);
        $699 = Math_fround($698 + $697);
        $700 = $699 > Math_fround(0.0);
        if ($700) {
         $701 = (Math_fround(Math_sqrt((Math_fround($699)))));
         $702 = Math_fround(Math_fround(1.0) / $701);
         $703 = Math_fround($688 * $702);
         $704 = Math_fround($691 * $702);
         $705 = Math_fround($694 * $702);
         $707 = $703;$709 = $704;$712 = $705;
        } else {
         $707 = Math_fround(0.0);$709 = Math_fround(0.0);$712 = Math_fround(0.0);
        }
        $706 = Math_fround($707 * $665);
        $708 = Math_fround($709 * $670);
        $710 = Math_fround($706 + $708);
        $711 = Math_fround($712 * $675);
        $713 = Math_fround($710 + $711);
        $714 = (($verts) + (($$0$i28*12)|0)|0);
        $715 = Math_fround(HEAPF32[$714>>2]);
        $716 = Math_fround($707 * $715);
        $717 = ((($verts) + (($$0$i28*12)|0)|0) + 4|0);
        $718 = Math_fround(HEAPF32[$717>>2]);
        $719 = Math_fround($709 * $718);
        $720 = Math_fround($716 + $719);
        $721 = ((($verts) + (($$0$i28*12)|0)|0) + 8|0);
        $722 = Math_fround(HEAPF32[$721>>2]);
        $723 = Math_fround($712 * $722);
        $724 = Math_fround($720 + $723);
        $725 = Math_fround($724 - $713);
        $726 = $725 < Math_fround(0.0);
        if ($726) {
         $727 = (($verts) + (($VRef005$0*12)|0)|0);
         $728 = Math_fround(HEAPF32[$727>>2]);
         $729 = ((($verts) + (($VRef005$0*12)|0)|0) + 4|0);
         $730 = Math_fround(HEAPF32[$729>>2]);
         $731 = ((($verts) + (($VRef005$0*12)|0)|0) + 8|0);
         $732 = Math_fround(HEAPF32[$731>>2]);
         $733 = (($verts) + (($VRef016$0*12)|0)|0);
         $734 = Math_fround(HEAPF32[$733>>2]);
         $735 = ((($verts) + (($VRef016$0*12)|0)|0) + 4|0);
         $736 = Math_fround(HEAPF32[$735>>2]);
         $737 = ((($verts) + (($VRef016$0*12)|0)|0) + 8|0);
         $738 = Math_fround(HEAPF32[$737>>2]);
         $739 = (($verts) + (($VRef027$0*12)|0)|0);
         $740 = Math_fround(HEAPF32[$739>>2]);
         $741 = ((($verts) + (($VRef027$0*12)|0)|0) + 4|0);
         $742 = Math_fround(HEAPF32[$741>>2]);
         $743 = ((($verts) + (($VRef027$0*12)|0)|0) + 8|0);
         $744 = Math_fround(HEAPF32[$743>>2]);
         $745 = Math_fround($734 - $728);
         $746 = Math_fround($736 - $730);
         $747 = Math_fround($738 - $732);
         $748 = Math_fround($740 - $728);
         $749 = Math_fround($742 - $730);
         $750 = Math_fround($744 - $732);
         $751 = Math_fround($746 * $750);
         $752 = Math_fround($747 * $749);
         $753 = Math_fround($751 - $752);
         $754 = Math_fround($747 * $748);
         $755 = Math_fround($745 * $750);
         $756 = Math_fround($754 - $755);
         $757 = Math_fround($745 * $749);
         $758 = Math_fround($746 * $748);
         $759 = Math_fround($757 - $758);
         $760 = Math_fround($753 * $753);
         $761 = Math_fround($756 * $756);
         $762 = Math_fround($760 + $761);
         $763 = Math_fround($759 * $759);
         $764 = Math_fround($763 + $762);
         $765 = (Math_fround(Math_sqrt((Math_fround($764)))));
         $766 = $765 > Math_fround(0.0);
         if ($766) {
          $767 = Math_fround(Math_fround(1.0) / $765);
          $768 = Math_fround($753 * $767);
          $769 = Math_fround($756 * $767);
          $770 = Math_fround($759 * $767);
          $779 = $768;$782 = $769;$786 = $770;
         } else {
          $779 = $753;$782 = $756;$786 = $759;
         }
         $771 = (Math_fround(Math_sqrt((Math_fround($699)))));
         $772 = $771 > Math_fround(0.0);
         if ($772) {
          $773 = Math_fround(Math_fround(1.0) / $771);
          $774 = Math_fround($688 * $773);
          $775 = Math_fround($691 * $773);
          $776 = Math_fround($694 * $773);
          $778 = $774;$781 = $775;$785 = $776;
         } else {
          $778 = $688;$781 = $691;$785 = $694;
         }
         $777 = Math_fround($779 * $778);
         $780 = Math_fround($782 * $781);
         $783 = Math_fround($780 + $777);
         $784 = Math_fround($786 * $785);
         $787 = Math_fround($784 + $783);
         $788 = Math_fround($782 * $785);
         $789 = Math_fround($786 * $781);
         $790 = Math_fround($788 - $789);
         $791 = Math_fround($786 * $778);
         $792 = Math_fround($779 * $785);
         $793 = Math_fround($791 - $792);
         $794 = Math_fround($779 * $781);
         $795 = Math_fround($782 * $778);
         $796 = Math_fround($794 - $795);
         $797 = Math_fround($790 * $790);
         $798 = Math_fround($793 * $793);
         $799 = Math_fround($797 + $798);
         $800 = Math_fround($796 * $796);
         $801 = Math_fround($800 + $799);
         $802 = (Math_fround(Math_sqrt((Math_fround($801)))));
         $803 = +$802;
         $804 = +$787;
         $805 = (+Math_atan2((+$803),(+$804)));
         $806 = Math_fround($805);
         $807 = (Math_fround(Math_abs((Math_fround($806)))));
         $808 = $807 > $epsilon;
         $Active$4$off0 = $808 | $528;
         $Active$5$off0 = $Active$4$off0;
        } else {
         $Active$5$off0 = $528;
        }
       } else {
        $Active$5$off0 = 1;
       }
      } else {
       $Active$5$off0 = 1;
      }
     }
    } while(0);
    $809 = (($CurrentMark$088) + 1|0);
    $810 = $Active$5$off0&1;
    HEAP8[$CurrentMark$088>>0] = $810;
    $811 = (($ED$089) + 8|0);
    $812 = (($Edges$090) + 8|0);
    $813 = ($29|0)==(0);
    if ($813) {
     break;
    } else {
     $$in = $29;$CurrentMark$088 = $809;$ED$089 = $811;$Edges$090 = $812;
    }
   }
   $24 = (($this) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if (!($26)) {
    $27 = (($this) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $i$059 = 0;
    while(1) {
     $816 = (($28) + (($i$059*12)|0)|0);
     $817 = HEAP32[$816>>2]|0;
     $818 = ($817|0)<(0);
     if (!($818)) {
      $819 = $817 & 268435455;
      $820 = (($23) + ($819)|0);
      $821 = HEAP8[$820>>0]|0;
      $822 = ($821<<24>>24)==(0);
      if (!($822)) {
       $823 = $817 | -2147483648;
       HEAP32[$816>>2] = $823;
      }
     }
     $824 = ((($28) + (($i$059*12)|0)|0) + 4|0);
     $825 = HEAP32[$824>>2]|0;
     $826 = ($825|0)<(0);
     if (!($826)) {
      $977 = $825 & 268435455;
      $978 = (($23) + ($977)|0);
      $979 = HEAP8[$978>>0]|0;
      $980 = ($979<<24>>24)==(0);
      if (!($980)) {
       $981 = $825 | -2147483648;
       HEAP32[$824>>2] = $981;
      }
     }
     $982 = ((($28) + (($i$059*12)|0)|0) + 8|0);
     $983 = HEAP32[$982>>2]|0;
     $984 = ($983|0)<(0);
     if (!($984)) {
      $985 = $983 & 268435455;
      $986 = (($23) + ($985)|0);
      $987 = HEAP8[$986>>0]|0;
      $988 = ($987<<24>>24)==(0);
      if (!($988)) {
       $989 = $983 | -2147483648;
       HEAP32[$982>>2] = $989;
      }
     }
     $990 = (($i$059) + 1)|0;
     $991 = HEAP32[$24>>2]|0;
     $992 = ($990>>>0)<($991>>>0);
     if ($992) {
      $i$059 = $990;
     } else {
      break;
     }
    }
   }
   $814 = HEAP32[$this>>2]|0;
   $815 = ($814|0)==(0);
   if (!($815)) {
    $i33$054 = 0;
    while(1) {
     $827 = (($23) + ($i33$054)|0);
     $828 = HEAP8[$827>>0]|0;
     $829 = ($828<<24>>24)==(0);
     if (!($829)) {
      $830 = HEAP32[$15>>2]|0;
      $831 = (($830) + ($i33$054<<3)|0);
      $832 = HEAP16[$831>>1]|0;
      $833 = $832&65535;
      $834 = $833 | 1;
      $835 = $834&65535;
      HEAP16[$831>>1] = $835;
     }
     $836 = (($i33$054) + 1)|0;
     $837 = ($836>>>0)<($814>>>0);
     if ($837) {
      $i33$054 = $836;
     } else {
      break;
     }
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$23);
   $838 = ($nb_faces|0)==(0);
   if ($838) {
    $MaxIndex$0$lcssa = 0;
   } else {
    if ($5) {
     $MaxIndex$048$us = 0;$i34$049$us = 0;
     while(1) {
      $839 = ($i34$049$us*3)|0;
      $840 = (($dfaces) + ($839<<2)|0);
      $841 = HEAP32[$840>>2]|0;
      $842 = (($839) + 1)|0;
      $843 = (($dfaces) + ($842<<2)|0);
      $844 = HEAP32[$843>>2]|0;
      $845 = (($839) + 2)|0;
      $846 = (($dfaces) + ($845<<2)|0);
      $847 = HEAP32[$846>>2]|0;
      $848 = ($841>>>0)>($MaxIndex$048$us>>>0);
      $VRef035$0$MaxIndex$0$us = $848 ? $841 : $MaxIndex$048$us;
      $849 = ($844>>>0)>($VRef035$0$MaxIndex$0$us>>>0);
      $MaxIndex$2$us = $849 ? $844 : $VRef035$0$MaxIndex$0$us;
      $850 = ($847>>>0)>($MaxIndex$2$us>>>0);
      $VRef237$0$MaxIndex$2$us = $850 ? $847 : $MaxIndex$2$us;
      $851 = (($i34$049$us) + 1)|0;
      $exitcond101 = ($851|0)==($nb_faces|0);
      if ($exitcond101) {
       $MaxIndex$0$lcssa = $VRef237$0$MaxIndex$2$us;
       break;
      } else {
       $MaxIndex$048$us = $VRef237$0$MaxIndex$2$us;$i34$049$us = $851;
      }
     }
    } else {
     $MaxIndex$048 = 0;$i34$049 = 0;
     while(1) {
      $852 = ($i34$049*3)|0;
      $853 = (($wfaces) + ($852<<1)|0);
      $854 = HEAP16[$853>>1]|0;
      $855 = $854&65535;
      $856 = (($852) + 1)|0;
      $857 = (($wfaces) + ($856<<1)|0);
      $858 = HEAP16[$857>>1]|0;
      $859 = $858&65535;
      $860 = (($852) + 2)|0;
      $861 = (($wfaces) + ($860<<1)|0);
      $862 = HEAP16[$861>>1]|0;
      $863 = $862&65535;
      $864 = ($855>>>0)>($MaxIndex$048>>>0);
      $VRef035$0$MaxIndex$0 = $864 ? $855 : $MaxIndex$048;
      $865 = ($859>>>0)>($VRef035$0$MaxIndex$0>>>0);
      $MaxIndex$2 = $865 ? $859 : $VRef035$0$MaxIndex$0;
      $866 = ($863>>>0)>($MaxIndex$2>>>0);
      $VRef237$0$MaxIndex$2 = $866 ? $863 : $MaxIndex$2;
      $867 = (($i34$049) + 1)|0;
      $exitcond = ($867|0)==($nb_faces|0);
      if ($exitcond) {
       $MaxIndex$0$lcssa = $VRef237$0$MaxIndex$2;
       break;
      } else {
       $MaxIndex$048 = $VRef237$0$MaxIndex$2;$i34$049 = $867;
      }
     }
    }
   }
   $868 = (($MaxIndex$0$lcssa) + 1)|0;
   $869 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$868,528480,651)|0);
   _memset(($869|0),0,($868|0))|0;
   $870 = HEAP32[$24>>2]|0;
   $871 = ($870|0)==(0);
   if (!($871)) {
    $872 = (($VRef) + 4|0);
    $873 = (($VRef) + 8|0);
    $874 = (($this) + 12|0);
    $875 = HEAP32[$874>>2]|0;
    $i38$045 = 0;
    while(1) {
     if ($5) {
      $878 = ($i38$045*3)|0;
      $879 = (($dfaces) + ($878<<2)|0);
      $880 = HEAP32[$879>>2]|0;
      HEAP32[$VRef>>2] = $880;
      $881 = (($878) + 1)|0;
      $882 = (($dfaces) + ($881<<2)|0);
      $883 = HEAP32[$882>>2]|0;
      HEAP32[$872>>2] = $883;
      $884 = (($878) + 2)|0;
      $885 = (($dfaces) + ($884<<2)|0);
      $886 = HEAP32[$885>>2]|0;
      HEAP32[$873>>2] = $886;
     } else {
      if (!($6)) {
       $887 = ($i38$045*3)|0;
       $888 = (($wfaces) + ($887<<1)|0);
       $889 = HEAP16[$888>>1]|0;
       $890 = $889&65535;
       HEAP32[$VRef>>2] = $890;
       $891 = (($887) + 1)|0;
       $892 = (($wfaces) + ($891<<1)|0);
       $893 = HEAP16[$892>>1]|0;
       $894 = $893&65535;
       HEAP32[$872>>2] = $894;
       $895 = (($887) + 2)|0;
       $896 = (($wfaces) + ($895<<1)|0);
       $897 = HEAP16[$896>>1]|0;
       $898 = $897&65535;
       HEAP32[$873>>2] = $898;
      }
     }
     $899 = (($875) + (($i38$045*12)|0)|0);
     $900 = HEAP32[$899>>2]|0;
     $901 = ($900|0)<(0);
     if ($901) {
      $902 = (($VRef) + 4|0);
      $903 = HEAP32[$902>>2]|0;
      $904 = (($869) + ($903)|0);
      HEAP8[$904>>0] = 1;
      $905 = HEAP32[$VRef>>2]|0;
      $906 = (($869) + ($905)|0);
      HEAP8[$906>>0] = 1;
     }
     $907 = ((($875) + (($i38$045*12)|0)|0) + 4|0);
     $908 = HEAP32[$907>>2]|0;
     $909 = ($908|0)<(0);
     if ($909) {
      $961 = (($VRef) + 8|0);
      $962 = HEAP32[$961>>2]|0;
      $963 = (($869) + ($962)|0);
      HEAP8[$963>>0] = 1;
      $964 = (($VRef) + 4|0);
      $965 = HEAP32[$964>>2]|0;
      $966 = (($869) + ($965)|0);
      HEAP8[$966>>0] = 1;
     }
     $967 = ((($875) + (($i38$045*12)|0)|0) + 8|0);
     $968 = HEAP32[$967>>2]|0;
     $969 = ($968|0)<(0);
     if ($969) {
      $970 = (($VRef) + 8|0);
      $971 = HEAP32[$970>>2]|0;
      $972 = (($869) + ($971)|0);
      HEAP8[$972>>0] = 1;
      $973 = HEAP32[$VRef>>2]|0;
      $974 = (($869) + ($973)|0);
      HEAP8[$974>>0] = 1;
     }
     $975 = (($i38$045) + 1)|0;
     $976 = ($975>>>0)<($870>>>0);
     if ($976) {
      $i38$045 = $975;
     } else {
      break;
     }
    }
    $phitmp = ($870|0)==(0);
    if (!($phitmp)) {
     $876 = (($this) + 12|0);
     $877 = HEAP32[$876>>2]|0;
     $993 = 0;$994 = 0;$995 = 0;$i42$043 = 0;
     while(1) {
      if ($5) {
       $910 = ($i42$043*3)|0;
       $911 = (($dfaces) + ($910<<2)|0);
       $912 = HEAP32[$911>>2]|0;
       $913 = (($910) + 1)|0;
       $914 = (($dfaces) + ($913<<2)|0);
       $915 = HEAP32[$914>>2]|0;
       $916 = (($910) + 2)|0;
       $917 = (($dfaces) + ($916<<2)|0);
       $918 = HEAP32[$917>>2]|0;
       $936 = $912;$945 = $915;$954 = $918;
      } else {
       if ($6) {
        $936 = $995;$945 = $994;$954 = $993;
       } else {
        $919 = ($i42$043*3)|0;
        $920 = (($wfaces) + ($919<<1)|0);
        $921 = HEAP16[$920>>1]|0;
        $922 = $921&65535;
        $923 = (($919) + 1)|0;
        $924 = (($wfaces) + ($923<<1)|0);
        $925 = HEAP16[$924>>1]|0;
        $926 = $925&65535;
        $927 = (($919) + 2)|0;
        $928 = (($wfaces) + ($927<<1)|0);
        $929 = HEAP16[$928>>1]|0;
        $930 = $929&65535;
        $936 = $922;$945 = $926;$954 = $930;
       }
      }
      $931 = (($877) + (($i42$043*12)|0)|0);
      $932 = HEAP32[$931>>2]|0;
      $933 = $932 & 1073741824;
      $934 = ($933|0)==(0);
      if ($934) {
       $935 = (($869) + ($936)|0);
       $937 = HEAP8[$935>>0]|0;
       $938 = ($937<<24>>24)==(0);
       if (!($938)) {
        $939 = $932 | 1073741824;
        HEAP32[$931>>2] = $939;
       }
      }
      $940 = ((($877) + (($i42$043*12)|0)|0) + 4|0);
      $941 = HEAP32[$940>>2]|0;
      $942 = $941 & 1073741824;
      $943 = ($942|0)==(0);
      if ($943) {
       $944 = (($869) + ($945)|0);
       $946 = HEAP8[$944>>0]|0;
       $947 = ($946<<24>>24)==(0);
       if (!($947)) {
        $948 = $941 | 1073741824;
        HEAP32[$940>>2] = $948;
       }
      }
      $949 = ((($877) + (($i42$043*12)|0)|0) + 8|0);
      $950 = HEAP32[$949>>2]|0;
      $951 = $950 & 1073741824;
      $952 = ($951|0)==(0);
      if ($952) {
       $953 = (($869) + ($954)|0);
       $955 = HEAP8[$953>>0]|0;
       $956 = ($955<<24>>24)==(0);
       if (!($956)) {
        $957 = $950 | 1073741824;
        HEAP32[$949>>2] = $957;
       }
      }
      $958 = (($i42$043) + 1)|0;
      $959 = HEAP32[$24>>2]|0;
      $960 = ($958>>>0)<($959>>>0);
      if ($960) {
       $993 = $954;$994 = $945;$995 = $936;$i42$043 = $958;
      } else {
       break;
      }
     }
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$869);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $7 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,8,528480,316,528608,$vararg_buffer7);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15EdgeListBuilderC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 20|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx27InternalTriangleMeshBuilderC2EPNS_20InternalTriangleMeshERKNS_15PxCookingParamsE($this,$m,$params) {
 $this = $this|0;
 $m = $m|0;
 $params = $params|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $m;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $params;
 STACKTOP = sp;return;
}
function __ZN5physx27InternalTriangleMeshBuilderD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN5physx2Gu8EdgeListD2Ev($2);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 }
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx27InternalTriangleMeshBuilder13remapTopologyEPKj($this,$order) {
 $this = $this|0;
 $order = $order|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$arith = 0, $$arith2 = 0, $$overflow = 0, $$overflow3 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $i$07 = 0, $i1$04 = 0, $i2$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ($6*12)|0;
 $9 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$8,529296,62)|0);
 $10 = HEAP32[$5>>2]|0;
 $11 = ($10|0)==(0);
 $$pre15 = (($4) + 12|0);
 if (!($11)) {
  $i$07 = 0;
  while(1) {
   $12 = (($9) + (($i$07*12)|0)|0);
   $13 = (($order) + ($i$07<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$$pre15>>2]|0;
   $16 = (($15) + (($14*12)|0)|0);
   ;HEAP32[$12+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$16+8>>2]|0;
   $17 = (($i$07) + 1)|0;
   $18 = HEAP32[$5>>2]|0;
   $19 = ($17>>>0)<($18>>>0);
   if ($19) {
    $i$07 = $17;
   } else {
    break;
   }
  }
 }
 $20 = HEAP32[$$pre15>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$20);
 HEAP32[$$pre15>>2] = $9;
 $21 = HEAP32[$this>>2]|0;
 $22 = (($21) + 160|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = HEAP32[$5>>2]|0;
  $$arith2 = $25<<1;
  $$overflow3 = ($25>>>0)>(2147483647);
  $26 = $$overflow3 ? -1 : $$arith2;
  $27 = ($26|0)==(0);
  if ($27) {
   $39 = $25;$45 = 0;
  } else {
   $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (__Z15PxGetFoundationv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 24|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (FUNCTION_TABLE_ii[$35 & 4095]($32)|0);
   $$$i$i$i1 = $36 ? 529968 : 529600;
   $37 = (FUNCTION_TABLE_iiiiii[$31 & 255]($28,$26,$$$i$i$i1,529296,70)|0);
   $$pre11 = HEAP32[$5>>2]|0;
   $39 = $$pre11;$45 = $37;
  }
  $38 = ($39|0)==(0);
  $$pre12 = HEAP32[$this>>2]|0;
  $$phi$trans$insert = (($$pre12) + 160|0);
  $$pre13 = HEAP32[$$phi$trans$insert>>2]|0;
  if (!($38)) {
   $i1$04 = 0;
   while(1) {
    $40 = (($order) + ($i1$04<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($$pre13) + ($41<<1)|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = (($45) + ($i1$04<<1)|0);
    HEAP16[$44>>1] = $43;
    $46 = (($i1$04) + 1)|0;
    $47 = ($46>>>0)<($39>>>0);
    if ($47) {
     $i1$04 = $46;
    } else {
     break;
    }
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$$pre13);
  $48 = HEAP32[$this>>2]|0;
  $49 = (($48) + 160|0);
  HEAP32[$49>>2] = 0;
  $50 = HEAP32[$this>>2]|0;
  $51 = (($50) + 160|0);
  HEAP32[$51>>2] = $45;
 }
 $52 = (($this) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 12|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if (!($56)) {
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$5>>2]|0;
 $$arith = $57<<2;
 $$overflow = ($57>>>0)>(1073741823);
 $58 = $$overflow ? -1 : $$arith;
 $59 = ($58|0)==(0);
 if ($59) {
  $71 = $57;$81 = 0;
 } else {
  $60 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 8|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (__Z15PxGetFoundationv()|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + 24|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (FUNCTION_TABLE_ii[$67 & 4095]($64)|0);
  $$$i$i$i = $68 ? 529864 : 529600;
  $69 = (FUNCTION_TABLE_iiiiii[$63 & 255]($60,$58,$$$i$i$i,529296,79)|0);
  $$pre = HEAP32[$5>>2]|0;
  $71 = $$pre;$81 = $69;
 }
 $70 = ($71|0)==(0);
 $72 = HEAP32[$this>>2]|0;
 $73 = (($72) + 164|0);
 $74 = HEAP32[$73>>2]|0;
 if (!($70)) {
  $i2$03 = 0;
  while(1) {
   $75 = ($74|0)==(0|0);
   $76 = (($order) + ($i2$03<<2)|0);
   $77 = HEAP32[$76>>2]|0;
   if ($75) {
    $82 = $77;
   } else {
    $78 = (($74) + ($77<<2)|0);
    $79 = HEAP32[$78>>2]|0;
    $82 = $79;
   }
   $80 = (($81) + ($i2$03<<2)|0);
   HEAP32[$80>>2] = $82;
   $83 = (($i2$03) + 1)|0;
   $84 = HEAP32[$5>>2]|0;
   $85 = ($83>>>0)<($84>>>0);
   if ($85) {
    $i2$03 = $83;
   } else {
    break;
   }
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$74);
 $86 = HEAP32[$this>>2]|0;
 $87 = (($86) + 164|0);
 HEAP32[$87>>2] = 0;
 $88 = HEAP32[$this>>2]|0;
 $89 = (($88) + 164|0);
 HEAP32[$89>>2] = $81;
 STACKTOP = sp;return;
}
function __ZN5physx27InternalTriangleMeshBuilder11createRTreeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $rc = 0, $resultPermute = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $resultPermute = sp + 8|0;
 $rc = sp;
 $0 = HEAP32[$this>>2]|0;
 __ZN5physx20InternalTriangleMesh18setupMeshInterfaceEv($0);
 $1 = HEAP32[$this>>2]|0;
 HEAP32[$resultPermute>>2] = 0;
 $2 = (($resultPermute) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($resultPermute) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($1) + 32|0);
 $5 = (($1) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$rc>>2] = ((530072 + 8|0));
 $7 = (($rc) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($1) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$1>>2]|0;
 $11 = (($1) + 156|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12 & 2;
 $14 = ($13<<24>>24)==(0);
 $15 = (($1) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 if ($14) {
  $24 = 0;$25 = $16;
 } else {
  $24 = $16;$25 = 0;
 }
 $17 = HEAP32[$5>>2]|0;
 $18 = (($this) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 40|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($19) + 32|0);
 $23 = HEAP32[$22>>2]|0;
 __ZN5physx11RTreeCooker18buildFromTrianglesERNS_2Gu5RTreeEPKNS_6PxVec3EjPKtPKjjRNS_6shdfnd5ArrayIjNSB_19ReflectionAllocatorIjEEEEPNS0_13RemapCallbackEfNS_17PxMeshCookingHint4EnumE($4,$9,$10,$24,$25,$17,$resultPermute,$rc,$21,$23);
 $26 = HEAP32[$resultPermute>>2]|0;
 __ZN5physx27InternalTriangleMeshBuilder13remapTopologyEPKj($this,$26);
 $27 = HEAP32[$3>>2]|0;
 $28 = $27 & 2147483647;
 $29 = ($28|0)!=(0);
 $30 = ($27|0)>(-1);
 $or$cond$i$i = $29 & $30;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$resultPermute>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return 1;
 }
 $33 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($33,$31);
 STACKTOP = sp;return 1;
}
function __ZN16RTreeCookerRemapD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx27InternalTriangleMeshBuilder14fillRemapTableEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$arith = 0, $$overflow = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 164|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 164|0);
 HEAP32[$5>>2] = 0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $$arith = $8<<2;
 $$overflow = ($8>>>0)>(1073741823);
 $9 = $$overflow ? -1 : $$arith;
 $10 = ($9|0)==(0);
 if ($10) {
  $22 = $6;$23 = 0;$25 = $8;
 } else {
  $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z15PxGetFoundationv()|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
  $$$i$i$i = $19 ? 529864 : 529600;
  $20 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,$9,$$$i$i$i,529296,145)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre2 = HEAP32[$7>>2]|0;
  $22 = $$pre;$23 = $20;$25 = $$pre2;
 }
 $21 = (($22) + 164|0);
 HEAP32[$21>>2] = $23;
 $24 = ($25|0)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = (($26) + 164|0);
 $28 = HEAP32[$27>>2]|0;
 $i$01 = 0;
 while(1) {
  $29 = (($28) + ($i$01<<2)|0);
  HEAP32[$29>>2] = $i$01;
  $30 = (($i$01) + 1)|0;
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)<($31>>>0);
  if ($32) {
   $i$01 = $30;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx27InternalTriangleMeshBuilder9cleanMeshEb($this,$validate) {
 $this = $this|0;
 $validate = $validate|0;
 var $$$i$i$i = 0, $$$i$i$i3 = 0, $$01 = 0, $$arith = 0, $$arith2 = 0, $$overflow = 0, $$overflow3 = 0, $$phi$trans$insert = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert23 = 0, $$pre = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre22 = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0);
 var $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0);
 var $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bigTriangle$0$off012 = 0, $bigTriangle$1$off0 = 0;
 var $cleaner = 0, $exitcond = 0, $i$014 = 0, $i1$013 = 0, $meshWeldTolerance$0 = Math_fround(0), $vararg_buffer6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer6 = sp;
 $cleaner = sp + 4|0;
 $0 = sp + 27|0;
 $1 = sp + 24|0;
 $2 = sp + 25|0;
 $3 = sp + 26|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($10) {
  $meshWeldTolerance$0 = Math_fround(0.0);
 } else {
  $11 = (($6) + 36|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = $12 == Math_fround(0.0);
  if ($13) {
   $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,2,529296,164,529392,$vararg_buffer6);
   $meshWeldTolerance$0 = Math_fround(0.0);
  } else {
   $meshWeldTolerance$0 = $12;
  }
 }
 $15 = HEAP32[$4>>2]|0;
 $16 = (($4) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($4) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($4) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 __ZN5physx11MeshCleanerC2EjPKNS_6PxVec3EjPKjf($cleaner,$15,$17,$19,$21,$meshWeldTolerance$0);
 $22 = (($cleaner) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if ($24) {
  $$01 = 0;
  __ZN5physx11MeshCleanerD2Ev($cleaner);
  STACKTOP = sp;return ($$01|0);
 }
 if ($validate) {
  $25 = HEAP32[$cleaner>>2]|0;
  $26 = HEAP32[$4>>2]|0;
  $27 = ($25|0)==($26|0);
  if (!($27)) {
   $$01 = 0;
   __ZN5physx11MeshCleanerD2Ev($cleaner);
   STACKTOP = sp;return ($$01|0);
  }
  $28 = HEAP32[$18>>2]|0;
  $29 = ($23|0)==($28|0);
  if (!($29)) {
   $$01 = 0;
   __ZN5physx11MeshCleanerD2Ev($cleaner);
   STACKTOP = sp;return ($$01|0);
  }
 }
 $30 = HEAP32[$this>>2]|0;
 $31 = (($30) + 164|0);
 $32 = HEAP32[$31>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$32);
 $33 = HEAP32[$this>>2]|0;
 $34 = (($33) + 164|0);
 HEAP32[$34>>2] = 0;
 $35 = (($cleaner) + 16|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  $38 = HEAP32[$5>>2]|0;
  $39 = (($38) + 12|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $42 = HEAP32[$22>>2]|0;
   $$arith2 = $42<<2;
   $$overflow3 = ($42>>>0)>(1073741823);
   $43 = $$overflow3 ? -1 : $$arith2;
   $44 = ($43|0)==(0);
   if ($44) {
    $57 = 0;
   } else {
    $45 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (__Z15PxGetFoundationv()|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + 24|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (FUNCTION_TABLE_ii[$52 & 4095]($49)|0);
    $$$i$i$i3 = $53 ? 529864 : 529600;
    $54 = (FUNCTION_TABLE_iiiiii[$48 & 255]($45,$43,$$$i$i$i3,529296,193)|0);
    $57 = $54;
   }
   $55 = HEAP32[$this>>2]|0;
   $56 = (($55) + 164|0);
   HEAP32[$56>>2] = $57;
   $58 = HEAP32[$this>>2]|0;
   $59 = (($58) + 164|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = HEAP32[$35>>2]|0;
   $62 = $42 << 2;
   _memcpy(($60|0),($61|0),($62|0))|0;
   $63 = HEAP32[$this>>2]|0;
   $64 = (($63) + 160|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==(0|0);
   if (!($66)) {
    $$arith = $42<<1;
    $$overflow = ($42>>>0)>(2147483647);
    $67 = $$overflow ? -1 : $$arith;
    $68 = ($67|0)==(0);
    if ($68) {
     $80 = $63;$86 = 0;
    } else {
     $69 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($70) + 8|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = (__Z15PxGetFoundationv()|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($74) + 24|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = (FUNCTION_TABLE_ii[$76 & 4095]($73)|0);
     $$$i$i$i = $77 ? 529968 : 529600;
     $78 = (FUNCTION_TABLE_iiiiii[$72 & 255]($69,$67,$$$i$i$i,529296,199)|0);
     $$pre19 = HEAP32[$this>>2]|0;
     $80 = $$pre19;$86 = $78;
    }
    $79 = ($42|0)==(0);
    if ($79) {
     $$phi$trans$insert23 = (($80) + 160|0);
     $$pre24 = HEAP32[$$phi$trans$insert23>>2]|0;
     $88 = $$pre24;
    } else {
     $$phi$trans$insert = (($80) + 164|0);
     $$pre20 = HEAP32[$$phi$trans$insert>>2]|0;
     $$phi$trans$insert21 = (($80) + 160|0);
     $$pre22 = HEAP32[$$phi$trans$insert21>>2]|0;
     $i$014 = 0;
     while(1) {
      $81 = (($$pre20) + ($i$014<<2)|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($$pre22) + ($82<<1)|0);
      $84 = HEAP16[$83>>1]|0;
      $85 = (($86) + ($i$014<<1)|0);
      HEAP16[$85>>1] = $84;
      $87 = (($i$014) + 1)|0;
      $exitcond = ($87|0)==($42|0);
      if ($exitcond) {
       $88 = $$pre22;
       break;
      } else {
       $i$014 = $87;
      }
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$88);
    $89 = HEAP32[$this>>2]|0;
    $90 = (($89) + 160|0);
    HEAP32[$90>>2] = 0;
    $91 = HEAP32[$this>>2]|0;
    $92 = (($91) + 160|0);
    HEAP32[$92>>2] = $86;
   }
  }
 }
 $93 = HEAP32[$4>>2]|0;
 $94 = HEAP32[$cleaner>>2]|0;
 $95 = ($93|0)==($94|0);
 if ($95) {
  $103 = $93;
 } else {
  $96 = HEAP32[$16>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$96);
  HEAP32[$16>>2] = 0;
  $97 = HEAP32[$this>>2]|0;
  $98 = HEAP32[$cleaner>>2]|0;
  (__ZN5physx20InternalTriangleMesh16allocateVerticesEj($97,$98)|0);
  $$pre = HEAP32[$4>>2]|0;
  $103 = $$pre;
 }
 $99 = HEAP32[$16>>2]|0;
 $100 = (($cleaner) + 8|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($103*12)|0;
 _memcpy(($99|0),($101|0),($102|0))|0;
 $104 = HEAP32[$18>>2]|0;
 $105 = HEAP32[$22>>2]|0;
 $106 = ($104|0)==($105|0);
 if ($106) {
  $117 = $104;
 } else {
  $107 = HEAP32[$20>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$107);
  HEAP32[$20>>2] = 0;
  $108 = HEAP32[$this>>2]|0;
  $109 = HEAP32[$22>>2]|0;
  (__ZN5physx20InternalTriangleMesh17allocateTrianglesEjb($108,$109,1)|0);
  $$pre18 = HEAP32[$18>>2]|0;
  $117 = $$pre18;
 }
 $110 = HEAP32[$5>>2]|0;
 $111 = (($110) + 16|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($112 * Math_fround(2.5E+5));
 $114 = Math_fround($112 * $113);
 $115 = HEAP32[$16>>2]|0;
 $116 = ($117|0)==(0);
 if ($116) {
  $$01 = 1;
  __ZN5physx11MeshCleanerD2Ev($cleaner);
  STACKTOP = sp;return ($$01|0);
 }
 $118 = (($cleaner) + 12|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = HEAP32[$20>>2]|0;
 $bigTriangle$0$off012 = 0;$i1$013 = 0;
 while(1) {
  $121 = ($i1$013*3)|0;
  $122 = (($119) + ($121<<2)|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = (($121) + 1)|0;
  $125 = (($119) + ($124<<2)|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (($121) + 2)|0;
  $128 = (($119) + ($127<<2)|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (($120) + (($i1$013*12)|0)|0);
  HEAP32[$130>>2] = $123;
  $131 = ((($120) + (($i1$013*12)|0)|0) + 4|0);
  HEAP32[$131>>2] = $126;
  $132 = ((($120) + (($i1$013*12)|0)|0) + 8|0);
  HEAP32[$132>>2] = $129;
  $133 = (($115) + (($123*12)|0)|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($115) + (($126*12)|0)|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = Math_fround($134 - $136);
  $138 = ((($115) + (($123*12)|0)|0) + 4|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = ((($115) + (($126*12)|0)|0) + 4|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = Math_fround($139 - $141);
  $143 = ((($115) + (($123*12)|0)|0) + 8|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = ((($115) + (($126*12)|0)|0) + 8|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = Math_fround($144 - $146);
  $148 = Math_fround($137 * $137);
  $149 = Math_fround($142 * $142);
  $150 = Math_fround($148 + $149);
  $151 = Math_fround($147 * $147);
  $152 = Math_fround($150 + $151);
  $153 = !($152 >= $114);
  if ($153) {
   $154 = (($115) + (($129*12)|0)|0);
   $155 = Math_fround(HEAPF32[$154>>2]);
   $156 = Math_fround($136 - $155);
   $157 = ((($115) + (($129*12)|0)|0) + 4|0);
   $158 = Math_fround(HEAPF32[$157>>2]);
   $159 = Math_fround($141 - $158);
   $160 = ((($115) + (($129*12)|0)|0) + 8|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = Math_fround($146 - $161);
   $163 = Math_fround($156 * $156);
   $164 = Math_fround($159 * $159);
   $165 = Math_fround($163 + $164);
   $166 = Math_fround($162 * $162);
   $167 = Math_fround($165 + $166);
   $168 = !($167 >= $114);
   if ($168) {
    $169 = Math_fround($155 - $134);
    $170 = Math_fround($158 - $139);
    $171 = Math_fround($161 - $144);
    $172 = Math_fround($169 * $169);
    $173 = Math_fround($170 * $170);
    $174 = Math_fround($172 + $173);
    $175 = Math_fround($171 * $171);
    $176 = Math_fround($174 + $175);
    $177 = !($176 >= $114);
    if ($177) {
     $bigTriangle$1$off0 = $bigTriangle$0$off012;
    } else {
     label = 29;
    }
   } else {
    label = 29;
   }
  } else {
   label = 29;
  }
  if ((label|0) == 29) {
   label = 0;
   $bigTriangle$1$off0 = 1;
  }
  $178 = (($i1$013) + 1)|0;
  $179 = HEAP32[$18>>2]|0;
  $180 = ($178>>>0)<($179>>>0);
  if ($180) {
   $bigTriangle$0$off012 = $bigTriangle$1$off0;$i1$013 = $178;
  } else {
   break;
  }
 }
 if (!($bigTriangle$1$off0)) {
  $$01 = 1;
  __ZN5physx11MeshCleanerD2Ev($cleaner);
  STACKTOP = sp;return ($$01|0);
 }
 $181 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($181,2,529296,249,529456,$vararg_buffer6);
 $$01 = 1;
 __ZN5physx11MeshCleanerD2Ev($cleaner);
 STACKTOP = sp;return ($$01|0);
}
function __ZN5physx27InternalTriangleMeshBuilder20createSharedEdgeDataEbb($this,$buildAdjacencies,$buildActiveEdges) {
 $this = $this|0;
 $buildAdjacencies = $buildAdjacencies|0;
 $buildActiveEdges = $buildActiveEdges|0;
 var $$$i$i$i = 0, $$$i$i$i4 = 0, $$0$i = 0, $$0$i2 = 0, $$arith = 0, $$in = 0, $$overflow = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ED$07 = 0, $Edges$06 = 0, $i$09 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 5|0;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$4);
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 152|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 168|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$9);
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 168|0);
 HEAP32[$11>>2] = 0;
 $12 = HEAP32[$this>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $27 = $12;$28 = 0;
 } else {
  $16 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (__Z15PxGetFoundationv()|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (FUNCTION_TABLE_ii[$23 & 4095]($20)|0);
  $$$i$i$i4 = $24 ? 529760 : 529600;
  $25 = (FUNCTION_TABLE_iiiiii[$19 & 255]($16,$14,$$$i$i$i4,529296,267)|0);
  $$pre = HEAP32[$this>>2]|0;
  $27 = $$pre;$28 = $25;
 }
 $26 = (($27) + 152|0);
 HEAP32[$26>>2] = $28;
 $29 = $buildActiveEdges | $buildAdjacencies;
 $30 = HEAP32[$this>>2]|0;
 $31 = (($30) + 152|0);
 $32 = HEAP32[$31>>2]|0;
 if (!($29)) {
  _memset(($32|0),56,($14|0))|0;
  STACKTOP = sp;return;
 }
 _memset(($32|0),0,($14|0))|0;
 $33 = HEAP32[$this>>2]|0;
 $34 = (($33) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($14>>>0)>(1073741823);
 if ($36) {
  $37 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($37,4,529296,280,529552,$vararg_buffer);
  STACKTOP = sp;return;
 }
 __ZN5physx27InternalTriangleMeshBuilder14createEdgeListEv($this);
 $38 = (($this) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = (($39) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$this>>2]|0;
  $44 = (($43) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($42|0)!=($45|0);
  $47 = ($42|0)==(0);
  $or$cond = $46 | $47;
  if (!($or$cond)) {
   $49 = $39;$i$09 = 0;
   while(1) {
    $48 = (($49) + 12|0);
    $50 = HEAP32[$48>>2]|0;
    $51 = (($50) + (($i$09*12)|0)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)>(-1);
    if (!($53)) {
     $54 = HEAP32[$this>>2]|0;
     $55 = (($54) + 152|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($56) + ($i$09)|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = $58&255;
     $60 = $59 | 8;
     $61 = $60&255;
     HEAP8[$57>>0] = $61;
    }
    $62 = ((($50) + (($i$09*12)|0)|0) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = ($63|0)>(-1);
    if (!($64)) {
     $65 = HEAP32[$this>>2]|0;
     $66 = (($65) + 152|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($67) + ($i$09)|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = $69&255;
     $71 = $70 | 16;
     $72 = $71&255;
     HEAP8[$68>>0] = $72;
    }
    $73 = ((($50) + (($i$09*12)|0)|0) + 8|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)>(-1);
    if (!($75)) {
     $76 = HEAP32[$this>>2]|0;
     $77 = (($76) + 152|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = (($78) + ($i$09)|0);
     $80 = HEAP8[$79>>0]|0;
     $81 = $80&255;
     $82 = $81 | 32;
     $83 = $82&255;
     HEAP8[$79>>0] = $83;
    }
    $84 = (($i$09) + 1)|0;
    $85 = HEAP32[$38>>2]|0;
    $86 = (($85) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($84>>>0)<($87>>>0);
    if ($88) {
     $49 = $85;$i$09 = $84;
    } else {
     break;
    }
   }
  }
 }
 if (!($buildAdjacencies)) {
  STACKTOP = sp;return;
 }
 $89 = ($14*3)|0;
 $$arith = $89<<2;
 $$overflow = ($89>>>0)>(1073741823);
 $90 = $$overflow ? -1 : $$arith;
 $91 = ($90|0)==(0);
 if ($91) {
  $104 = 0;
 } else {
  $92 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (($93) + 8|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (__Z15PxGetFoundationv()|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($97) + 24|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = (FUNCTION_TABLE_ii[$99 & 4095]($96)|0);
  $$$i$i$i = $100 ? 529864 : 529600;
  $101 = (FUNCTION_TABLE_iiiiii[$95 & 255]($92,$90,$$$i$i$i,529296,304)|0);
  $104 = $101;
 }
 $102 = HEAP32[$this>>2]|0;
 $103 = (($102) + 168|0);
 HEAP32[$103>>2] = $104;
 $105 = HEAP32[$this>>2]|0;
 $106 = (($105) + 168|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = ($14*12)|0;
 _memset(($107|0),-1,($108|0))|0;
 $109 = HEAP32[$38>>2]|0;
 $110 = HEAP32[$109>>2]|0;
 $111 = (($109) + 20|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ($110|0)==(0);
 if ($113) {
  STACKTOP = sp;return;
 }
 $114 = (($109) + 4|0);
 $115 = (($109) + 16|0);
 $116 = HEAP32[$114>>2]|0;
 $117 = HEAP32[$115>>2]|0;
 $$in = $110;$ED$07 = $117;$Edges$06 = $116;
 while(1) {
  $118 = (($$in) + -1)|0;
  $119 = (($ED$07) + 2|0);
  $120 = HEAP16[$119>>1]|0;
  $121 = ($120&65535)>(1);
  if ($121) {
   $122 = (($ED$07) + 4|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($112) + ($123<<2)|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = (($123) + 1)|0;
   $127 = (($112) + ($126<<2)|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = HEAP32[$Edges$06>>2]|0;
   $130 = (($Edges$06) + 4|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = (($35) + (($125*12)|0)|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($133|0)==($129|0);
   if ($134) {
    $135 = ((($35) + (($125*12)|0)|0) + 4|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = ($136|0)==($131|0);
    if ($137) {
     $$0$i2 = 0;
    } else {
     label = 24;
    }
   } else {
    label = 24;
   }
   do {
    if ((label|0) == 24) {
     label = 0;
     $138 = ($133|0)==($131|0);
     if ($138) {
      $139 = ((($35) + (($125*12)|0)|0) + 4|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = ($140|0)==($129|0);
      if ($141) {
       $$0$i2 = 0;
       break;
      }
     }
     if ($134) {
      $142 = ((($35) + (($125*12)|0)|0) + 8|0);
      $143 = HEAP32[$142>>2]|0;
      $144 = ($143|0)==($131|0);
      if ($144) {
       $$0$i2 = 2;
       break;
      }
     }
     if ($138) {
      $145 = ((($35) + (($125*12)|0)|0) + 8|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($146|0)==($129|0);
      if ($147) {
       $$0$i2 = 2;
       break;
      }
     }
     $148 = ((($35) + (($125*12)|0)|0) + 4|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ($149|0)==($129|0);
     if ($150) {
      $151 = ((($35) + (($125*12)|0)|0) + 8|0);
      $152 = HEAP32[$151>>2]|0;
      $153 = ($152|0)==($131|0);
      if ($153) {
       $$0$i2 = 1;
       break;
      }
     }
     $154 = ($149|0)==($131|0);
     if ($154) {
      $155 = ((($35) + (($125*12)|0)|0) + 8|0);
      $156 = HEAP32[$155>>2]|0;
      $157 = ($156|0)==($129|0);
      if ($157) {
       $$0$i2 = 1;
       break;
      }
     }
     $$0$i2 = 255;
    }
   } while(0);
   $158 = (($35) + (($128*12)|0)|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = ($159|0)==($129|0);
   if ($160) {
    $161 = ((($35) + (($128*12)|0)|0) + 4|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = ($162|0)==($131|0);
    if ($163) {
     $$0$i = 0;
    } else {
     label = 37;
    }
   } else {
    label = 37;
   }
   do {
    if ((label|0) == 37) {
     label = 0;
     $164 = ($159|0)==($131|0);
     if ($164) {
      $165 = ((($35) + (($128*12)|0)|0) + 4|0);
      $166 = HEAP32[$165>>2]|0;
      $167 = ($166|0)==($129|0);
      if ($167) {
       $$0$i = 0;
       break;
      }
     }
     if ($160) {
      $168 = ((($35) + (($128*12)|0)|0) + 8|0);
      $169 = HEAP32[$168>>2]|0;
      $170 = ($169|0)==($131|0);
      if ($170) {
       $$0$i = 2;
       break;
      }
     }
     if ($164) {
      $171 = ((($35) + (($128*12)|0)|0) + 8|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = ($172|0)==($129|0);
      if ($173) {
       $$0$i = 2;
       break;
      }
     }
     $174 = ((($35) + (($128*12)|0)|0) + 4|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = ($175|0)==($129|0);
     if ($176) {
      $177 = ((($35) + (($128*12)|0)|0) + 8|0);
      $178 = HEAP32[$177>>2]|0;
      $179 = ($178|0)==($131|0);
      if ($179) {
       $$0$i = 1;
       break;
      }
     }
     $180 = ($175|0)==($131|0);
     if ($180) {
      $181 = ((($35) + (($128*12)|0)|0) + 8|0);
      $182 = HEAP32[$181>>2]|0;
      $183 = ($182|0)==($129|0);
      if ($183) {
       $$0$i = 1;
       break;
      }
     }
     $$0$i = 255;
    }
   } while(0);
   $184 = HEAP32[$this>>2]|0;
   $185 = ($125*3)|0;
   $186 = (($$0$i2) + ($185))|0;
   $187 = (($184) + 168|0);
   $188 = HEAP32[$187>>2]|0;
   $189 = (($188) + ($186<<2)|0);
   HEAP32[$189>>2] = $128;
   $190 = ($128*3)|0;
   $191 = (($$0$i) + ($190))|0;
   $192 = (($188) + ($191<<2)|0);
   HEAP32[$192>>2] = $125;
  }
  $193 = (($ED$07) + 8|0);
  $194 = (($Edges$06) + 8|0);
  $195 = ($118|0)==(0);
  if ($195) {
   break;
  } else {
   $$in = $118;$ED$07 = $193;$Edges$06 = $194;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx27InternalTriangleMeshBuilder14createEdgeListEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $create = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 24|0;
 $create = sp;
 $1 = (($create) + 16|0);
 HEAP32[$1>>2] = 0;
 $2 = (($create) + 20|0);
 ;HEAP32[$create+0>>2]=0|0;HEAP32[$create+4>>2]=0|0;HEAP32[$create+8>>2]=0|0;HEAP16[$create+12>>1]=0|0;
 HEAPF32[$2>>2] = Math_fround(0.100000001490116119385);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$create>>2] = $5;
 $6 = (($3) + 156|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 2;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $14 = (($3) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($create) + 4|0);
  HEAP32[$16>>2] = $15;
  $17 = (($create) + 8|0);
  HEAP32[$17>>2] = 0;
 } else {
  $10 = (($create) + 4|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($create) + 8|0);
  HEAP32[$13>>2] = $12;
 }
 $18 = (($create) + 12|0);
 HEAP8[$18>>0] = 1;
 $19 = (($create) + 13|0);
 HEAP8[$19>>0] = 1;
 $20 = (($3) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$1>>2] = $21;
 $22 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (__Z15PxGetFoundationv()|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (FUNCTION_TABLE_ii[$29 & 4095]($26)|0);
 $$$i$i$i = $30 ? 529632 : 529600;
 $31 = (FUNCTION_TABLE_iiiiii[$25 & 255]($22,24,$$$i$i$i,529296,370)|0);
 __ZN5physx2Gu15EdgeListBuilderC2Ev($31);
 $32 = (($this) + 4|0);
 HEAP32[$32>>2] = $31;
 $33 = (__ZN5physx2Gu15EdgeListBuilder4InitERKNS0_14EDGELISTCREATEE($31,$create)|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$32>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  __ZN5physx2Gu8EdgeListD2Ev($34);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$34);
 }
 HEAP32[$32>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16RTreeCookerRemapD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16RTreeCookerRemap5remapEPjjj($this,$val,$start,$leafCount) {
 $this = $this|0;
 $val = $val|0;
 $start = $start|0;
 $leafCount = $leafCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $start << 5;
 $1 = $leafCount << 1;
 $2 = (($1) + 30)|0;
 $3 = $2 & 30;
 $4 = $0 | $3;
 $5 = $4 | 1;
 HEAP32[$val>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN5physx11MeshCleanerC2EjPKNS_6PxVec3EjPKjf($this,$nbVerts,$srcVerts,$nbTris,$srcIndices,$meshWeldTolerance) {
 $this = $this|0;
 $nbVerts = $nbVerts|0;
 $srcVerts = $srcVerts|0;
 $nbTris = $nbTris|0;
 $srcIndices = $srcIndices|0;
 $meshWeldTolerance = Math_fround($meshWeldTolerance);
 var $$048 = 0, $$idx$val = 0, $$idx12 = 0, $$idx12$val = 0, $$idx13 = 0, $$idx13$val = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum4 = 0, $$sum5 = 0, $$sum5$us = 0, $$sum6 = 0, $$sum6$us = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0;
 var $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0;
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0);
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = 0;
 var $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $cond = 0, $cond$us = 0, $cond11 = 0, $cond1133 = 0, $cond56 = 0, $cond56$us = 0, $exitcond = 0, $exitcond75 = 0, $exitcond76 = 0, $exitcond79 = 0, $exitcond80 = 0;
 var $exitcond81 = 0, $exitcond84 = 0, $i$071 = 0, $i1$067 = 0, $i2$062 = 0, $i2$062$us = 0, $i3$046 = 0, $i4$040 = 0, $i8$030 = 0, $idtRemap$0$off0$ = 0, $idtRemap$0$off0$lcssa = 0, $idtRemap$0$off039 = 0, $idtRemap$2$off0 = 0, $nbCleanedTris$0$lcssa = 0, $nbCleanedTris$047 = 0, $nbCleanedTris$1 = 0, $nbCleanedTris$2$lcssa = 0, $nbCleanedTris$238 = 0, $nbCleanedTris$3 = 0, $nbCleanedVerts$0$lcssa = 0;
 var $nbCleanedVerts$064 = 0, $nbCleanedVerts$064$us = 0, $nbCleanedVerts$1 = 0, $nbCleanedVerts$1$us = 0, $offset$0 = 0, $offset$0$us = 0, $offset$055 = 0, $offset$055$us = 0, $offset$057 = 0, $offset$057$us = 0, $offset7$0 = 0, $offset7$032 = 0, $offset7$034 = 0, $or$cond = 0, $or$cond7 = 0, $or$cond8 = 0, $or$cond9 = 0, $vertexIndices$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 9|0;
 $1 = sp + 8|0;
 $2 = sp + 7|0;
 $3 = sp + 6|0;
 $4 = sp + 5|0;
 $5 = sp + 4|0;
 $6 = sp + 2|0;
 $7 = sp + 1|0;
 $8 = sp;
 $9 = sp + 3|0;
 $10 = ($nbVerts*12)|0;
 $11 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$10,530096,78)|0);
 $12 = $nbTris << 2;
 $13 = ($nbTris*12)|0;
 $14 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$13,530096,81)|0);
 $15 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$12,530096,83)|0);
 $16 = $meshWeldTolerance != Math_fround(0.0);
 if ($16) {
  $17 = $nbVerts << 2;
  $18 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$17,530096,88)|0);
  $19 = Math_fround(Math_fround(1.0) / $meshWeldTolerance);
  $20 = ($nbVerts|0)==(0);
  if ($20) {
   $$pre$phiZ2D = $17;$vertexIndices$0 = $18;
  } else {
   $i$071 = 0;
   while(1) {
    $21 = (($18) + ($i$071<<2)|0);
    HEAP32[$21>>2] = $i$071;
    $22 = (($srcVerts) + (($i$071*12)|0)|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = Math_fround($19 * $23);
    $25 = Math_fround($24 + Math_fround(0.5));
    $26 = (Math_fround(Math_floor((Math_fround($25)))));
    $27 = ((($srcVerts) + (($i$071*12)|0)|0) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = Math_fround($19 * $28);
    $30 = Math_fround($29 + Math_fround(0.5));
    $31 = (Math_fround(Math_floor((Math_fround($30)))));
    $32 = ((($srcVerts) + (($i$071*12)|0)|0) + 8|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = Math_fround($19 * $33);
    $35 = Math_fround($34 + Math_fround(0.5));
    $36 = (Math_fround(Math_floor((Math_fround($35)))));
    $37 = (($11) + (($i$071*12)|0)|0);
    HEAPF32[$37>>2] = $26;
    $38 = ((($11) + (($i$071*12)|0)|0) + 4|0);
    HEAPF32[$38>>2] = $31;
    $39 = ((($11) + (($i$071*12)|0)|0) + 8|0);
    HEAPF32[$39>>2] = $36;
    $40 = (($i$071) + 1)|0;
    $exitcond81 = ($40|0)==($nbVerts|0);
    if ($exitcond81) {
     $$pre$phiZ2D = $17;$vertexIndices$0 = $18;
     break;
    } else {
     $i$071 = $40;
    }
   }
  }
 } else {
  _memcpy(($11|0),($srcVerts|0),($10|0))|0;
  $$pre = $nbVerts << 2;
  $$pre$phiZ2D = $$pre;$vertexIndices$0 = 0;
 }
 $41 = ($nbTris>>>0)<($nbVerts>>>0);
 $42 = $41 ? $nbVerts : $nbTris;
 $43 = $42 >>> 1;
 $44 = $43 | $42;
 $45 = $44 >>> 2;
 $46 = $45 | $44;
 $47 = $46 >>> 4;
 $48 = $47 | $46;
 $49 = $48 >>> 8;
 $50 = $49 | $48;
 $51 = $50 >>> 16;
 $52 = $51 | $50;
 $53 = (($52) + 1)|0;
 $54 = (($53) + ($42))|0;
 $55 = $54 << 2;
 $56 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$55,530096,107)|0);
 $57 = $53 << 2;
 _memset(($56|0),-1,($57|0))|0;
 $58 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,$$pre$phiZ2D,530096,112)|0);
 _memset(($58|0),-1,($$pre$phiZ2D|0))|0;
 $59 = ($nbTris*3)|0;
 $60 = ($59|0)==(0);
 if (!($60)) {
  $i1$067 = 0;
  while(1) {
   $105 = (($srcIndices) + ($i1$067<<2)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($106>>>0)<($nbVerts>>>0);
   if ($107) {
    $108 = (($58) + ($106<<2)|0);
    HEAP32[$108>>2] = 0;
   }
   $109 = (($i1$067) + 1)|0;
   $exitcond80 = ($109|0)==($59|0);
   if ($exitcond80) {
    break;
   } else {
    $i1$067 = $109;
   }
  }
 }
 $61 = ($nbVerts|0)==(0);
 if ($61) {
  $nbCleanedVerts$0$lcssa = 0;
 } else {
  $62 = ($vertexIndices$0|0)==(0|0);
  if ($62) {
   $i2$062$us = 0;$nbCleanedVerts$064$us = 0;
   while(1) {
    $63 = (($58) + ($i2$062$us<<2)|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($64|0)==(-1);
    L19: do {
     if ($65) {
      $nbCleanedVerts$1$us = $nbCleanedVerts$064$us;
     } else {
      $66 = (($11) + (($i2$062$us*12)|0)|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ((($11) + (($i2$062$us*12)|0)|0) + 4|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($69*11)|0;
      $71 = (($70) + ($67))|0;
      $72 = ((($11) + (($i2$062$us*12)|0)|0) + 8|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = Math_imul($73, -17)|0;
      $75 = (($71) + ($74))|0;
      $76 = $75 & 2147483647;
      $77 = $76 >>> 22;
      $78 = $76 >>> 12;
      $79 = $78 ^ $76;
      $80 = $79 ^ $77;
      $81 = $80 & $52;
      $82 = (($56) + ($81<<2)|0);
      $offset$055$us = HEAP32[$82>>2]|0;
      $cond56$us = ($offset$055$us|0)==(-1);
      $83 = (HEAP32[tempDoublePtr>>2]=$67,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $84 = (HEAP32[tempDoublePtr>>2]=$69,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $85 = (HEAP32[tempDoublePtr>>2]=$73,Math_fround(HEAPF32[tempDoublePtr>>2]));
      L21: do {
       if (!($cond56$us)) {
        $offset$057$us = $offset$055$us;
        while(1) {
         $86 = (($11) + (($offset$057$us*12)|0)|0);
         $87 = Math_fround(HEAPF32[$86>>2]);
         $88 = $87 != $83;
         if (!($88)) {
          $89 = ((($11) + (($offset$057$us*12)|0)|0) + 4|0);
          $90 = Math_fround(HEAPF32[$89>>2]);
          $91 = $90 != $84;
          if (!($91)) {
           $92 = ((($11) + (($offset$057$us*12)|0)|0) + 8|0);
           $93 = Math_fround(HEAPF32[$92>>2]);
           $94 = $93 != $85;
           if (!($94)) {
            break;
           }
          }
         }
         $$sum6$us = (($offset$057$us) + ($53))|0;
         $95 = (($56) + ($$sum6$us<<2)|0);
         $offset$0$us = HEAP32[$95>>2]|0;
         $cond$us = ($offset$0$us|0)==(-1);
         if ($cond$us) {
          break L21;
         } else {
          $offset$057$us = $offset$0$us;
         }
        }
        HEAP32[$63>>2] = $offset$057$us;
        $nbCleanedVerts$1$us = $nbCleanedVerts$064$us;
        break L19;
       }
      } while(0);
      HEAP32[$63>>2] = $nbCleanedVerts$064$us;
      $96 = (($11) + (($nbCleanedVerts$064$us*12)|0)|0);
      HEAPF32[$96>>2] = $83;
      $97 = Math_fround(HEAPF32[$68>>2]);
      $98 = ((($11) + (($nbCleanedVerts$064$us*12)|0)|0) + 4|0);
      HEAPF32[$98>>2] = $97;
      $99 = Math_fround(HEAPF32[$72>>2]);
      $100 = ((($11) + (($nbCleanedVerts$064$us*12)|0)|0) + 8|0);
      HEAPF32[$100>>2] = $99;
      $101 = HEAP32[$82>>2]|0;
      $$sum5$us = (($nbCleanedVerts$064$us) + ($53))|0;
      $102 = (($56) + ($$sum5$us<<2)|0);
      HEAP32[$102>>2] = $101;
      $103 = (($nbCleanedVerts$064$us) + 1)|0;
      HEAP32[$82>>2] = $nbCleanedVerts$064$us;
      $nbCleanedVerts$1$us = $103;
     }
    } while(0);
    $104 = (($i2$062$us) + 1)|0;
    $exitcond84 = ($104|0)==($nbVerts|0);
    if ($exitcond84) {
     $nbCleanedVerts$0$lcssa = $nbCleanedVerts$1$us;
     break;
    } else {
     $i2$062$us = $104;$nbCleanedVerts$064$us = $nbCleanedVerts$1$us;
    }
   }
  } else {
   $i2$062 = 0;$nbCleanedVerts$064 = 0;
   while(1) {
    $111 = (($58) + ($i2$062<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($112|0)==(-1);
    L33: do {
     if ($113) {
      $nbCleanedVerts$1 = $nbCleanedVerts$064;
     } else {
      $114 = (($11) + (($i2$062*12)|0)|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ((($11) + (($i2$062*12)|0)|0) + 4|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = ($117*11)|0;
      $119 = (($118) + ($115))|0;
      $120 = ((($11) + (($i2$062*12)|0)|0) + 8|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = Math_imul($121, -17)|0;
      $123 = (($119) + ($122))|0;
      $124 = $123 & 2147483647;
      $125 = $124 >>> 22;
      $126 = $124 >>> 12;
      $127 = $126 ^ $124;
      $128 = $127 ^ $125;
      $129 = $128 & $52;
      $130 = (($56) + ($129<<2)|0);
      $offset$055 = HEAP32[$130>>2]|0;
      $cond56 = ($offset$055|0)==(-1);
      $131 = (HEAP32[tempDoublePtr>>2]=$115,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $132 = (HEAP32[tempDoublePtr>>2]=$117,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $133 = (HEAP32[tempDoublePtr>>2]=$121,Math_fround(HEAPF32[tempDoublePtr>>2]));
      L35: do {
       if (!($cond56)) {
        $offset$057 = $offset$055;
        while(1) {
         $134 = (($11) + (($offset$057*12)|0)|0);
         $135 = Math_fround(HEAPF32[$134>>2]);
         $136 = $135 != $131;
         if (!($136)) {
          $137 = ((($11) + (($offset$057*12)|0)|0) + 4|0);
          $138 = Math_fround(HEAPF32[$137>>2]);
          $139 = $138 != $132;
          if (!($139)) {
           $140 = ((($11) + (($offset$057*12)|0)|0) + 8|0);
           $141 = Math_fround(HEAPF32[$140>>2]);
           $142 = $141 != $133;
           if (!($142)) {
            break;
           }
          }
         }
         $$sum6 = (($offset$057) + ($53))|0;
         $143 = (($56) + ($$sum6<<2)|0);
         $offset$0 = HEAP32[$143>>2]|0;
         $cond = ($offset$0|0)==(-1);
         if ($cond) {
          break L35;
         } else {
          $offset$057 = $offset$0;
         }
        }
        HEAP32[$111>>2] = $offset$057;
        $nbCleanedVerts$1 = $nbCleanedVerts$064;
        break L33;
       }
      } while(0);
      HEAP32[$111>>2] = $nbCleanedVerts$064;
      $144 = (($11) + (($nbCleanedVerts$064*12)|0)|0);
      HEAPF32[$144>>2] = $131;
      $145 = Math_fround(HEAPF32[$116>>2]);
      $146 = ((($11) + (($nbCleanedVerts$064*12)|0)|0) + 4|0);
      HEAPF32[$146>>2] = $145;
      $147 = Math_fround(HEAPF32[$120>>2]);
      $148 = ((($11) + (($nbCleanedVerts$064*12)|0)|0) + 8|0);
      HEAPF32[$148>>2] = $147;
      $149 = (($vertexIndices$0) + ($nbCleanedVerts$064<<2)|0);
      HEAP32[$149>>2] = $i2$062;
      $150 = HEAP32[$130>>2]|0;
      $$sum5 = (($nbCleanedVerts$064) + ($53))|0;
      $151 = (($56) + ($$sum5<<2)|0);
      HEAP32[$151>>2] = $150;
      $152 = (($nbCleanedVerts$064) + 1)|0;
      HEAP32[$130>>2] = $nbCleanedVerts$064;
      $nbCleanedVerts$1 = $152;
     }
    } while(0);
    $153 = (($i2$062) + 1)|0;
    $exitcond79 = ($153|0)==($nbVerts|0);
    if ($exitcond79) {
     $nbCleanedVerts$0$lcssa = $nbCleanedVerts$1;
     break;
    } else {
     $i2$062 = $153;$nbCleanedVerts$064 = $nbCleanedVerts$1;
    }
   }
  }
 }
 $110 = ($nbTris|0)==(0);
 if ($110) {
  $nbCleanedTris$0$lcssa = 0;
 } else {
  $$048 = $srcIndices;$i3$046 = 0;$nbCleanedTris$047 = 0;
  while(1) {
   $154 = (($$048) + 4|0);
   $155 = HEAP32[$$048>>2]|0;
   $156 = (($$048) + 8|0);
   $157 = HEAP32[$154>>2]|0;
   $158 = (($$048) + 12|0);
   $159 = HEAP32[$156>>2]|0;
   $160 = ($155>>>0)<($nbVerts>>>0);
   $161 = ($157>>>0)<($nbVerts>>>0);
   $or$cond = $160 & $161;
   $162 = ($159>>>0)<($nbVerts>>>0);
   $or$cond7 = $or$cond & $162;
   if ($or$cond7) {
    $163 = (($srcVerts) + (($155*12)|0)|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = (($srcVerts) + (($157*12)|0)|0);
    $166 = Math_fround(HEAPF32[$165>>2]);
    $167 = Math_fround($164 - $166);
    $168 = ((($srcVerts) + (($155*12)|0)|0) + 4|0);
    $169 = Math_fround(HEAPF32[$168>>2]);
    $170 = ((($srcVerts) + (($157*12)|0)|0) + 4|0);
    $171 = Math_fround(HEAPF32[$170>>2]);
    $172 = Math_fround($169 - $171);
    $173 = ((($srcVerts) + (($155*12)|0)|0) + 8|0);
    $174 = Math_fround(HEAPF32[$173>>2]);
    $175 = ((($srcVerts) + (($157*12)|0)|0) + 8|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = Math_fround($174 - $176);
    $178 = (($srcVerts) + (($159*12)|0)|0);
    $179 = Math_fround(HEAPF32[$178>>2]);
    $180 = Math_fround($164 - $179);
    $181 = ((($srcVerts) + (($159*12)|0)|0) + 4|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = Math_fround($169 - $182);
    $184 = ((($srcVerts) + (($159*12)|0)|0) + 8|0);
    $185 = Math_fround(HEAPF32[$184>>2]);
    $186 = Math_fround($174 - $185);
    $187 = Math_fround($172 * $186);
    $188 = Math_fround($177 * $183);
    $189 = Math_fround($187 - $188);
    $190 = Math_fround($177 * $180);
    $191 = Math_fround($167 * $186);
    $192 = Math_fround($190 - $191);
    $193 = Math_fround($167 * $183);
    $194 = Math_fround($172 * $180);
    $195 = Math_fround($193 - $194);
    $196 = Math_fround($189 * $189);
    $197 = Math_fround($192 * $192);
    $198 = Math_fround($196 + $197);
    $199 = Math_fround($195 * $195);
    $200 = Math_fround($199 + $198);
    $201 = $200 == Math_fround(0.0);
    if ($201) {
     $nbCleanedTris$1 = $nbCleanedTris$047;
    } else {
     $202 = (($58) + ($155<<2)|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = (($58) + ($157<<2)|0);
     $205 = HEAP32[$204>>2]|0;
     $206 = (($58) + ($159<<2)|0);
     $207 = HEAP32[$206>>2]|0;
     $208 = ($203|0)==($205|0);
     $209 = ($205|0)==($207|0);
     $or$cond8 = $208 | $209;
     $210 = ($207|0)==($203|0);
     $or$cond9 = $or$cond8 | $210;
     if ($or$cond9) {
      $nbCleanedTris$1 = $nbCleanedTris$047;
     } else {
      $211 = ($nbCleanedTris$047*3)|0;
      $212 = (($14) + ($211<<2)|0);
      HEAP32[$212>>2] = $203;
      $213 = (($211) + 1)|0;
      $214 = (($14) + ($213<<2)|0);
      HEAP32[$214>>2] = $205;
      $215 = (($211) + 2)|0;
      $216 = (($14) + ($215<<2)|0);
      HEAP32[$216>>2] = $207;
      $217 = (($nbCleanedTris$047) + 1)|0;
      $nbCleanedTris$1 = $217;
     }
    }
   } else {
    $nbCleanedTris$1 = $nbCleanedTris$047;
   }
   $218 = (($i3$046) + 1)|0;
   $exitcond76 = ($218|0)==($nbTris|0);
   if ($exitcond76) {
    $nbCleanedTris$0$lcssa = $nbCleanedTris$1;
    break;
   } else {
    $$048 = $158;$i3$046 = $218;$nbCleanedTris$047 = $nbCleanedTris$1;
   }
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$58);
 _memset(($56|0),-1,($57|0))|0;
 $219 = ($nbCleanedTris$0$lcssa|0)==(0);
 if ($219) {
  $idtRemap$0$off0$lcssa = 1;$nbCleanedTris$2$lcssa = 0;
 } else {
  $i4$040 = 0;$idtRemap$0$off039 = 1;$nbCleanedTris$238 = 0;
  while(1) {
   $220 = (($14) + (($i4$040*12)|0)|0);
   $$idx$val = HEAP32[$220>>2]|0;
   $$idx12 = ((($14) + (($i4$040*12)|0)|0) + 4|0);
   $$idx12$val = HEAP32[$$idx12>>2]|0;
   $$idx13 = ((($14) + (($i4$040*12)|0)|0) + 8|0);
   $$idx13$val = HEAP32[$$idx13>>2]|0;
   $221 = (($$idx$val) - ($$idx12$val))|0;
   $222 = (($221) - ($$idx13$val))|0;
   $223 = $$idx13$val >>> 13;
   $224 = $222 ^ $223;
   $225 = (($$idx12$val) - ($$idx13$val))|0;
   $226 = (($225) - ($224))|0;
   $227 = $224 << 8;
   $228 = $226 ^ $227;
   $229 = (($$idx13$val) - ($224))|0;
   $230 = (($229) - ($228))|0;
   $231 = $228 >>> 13;
   $232 = $230 ^ $231;
   $233 = (($224) - ($228))|0;
   $234 = (($233) - ($232))|0;
   $235 = $232 >>> 12;
   $236 = $234 ^ $235;
   $237 = (($228) - ($232))|0;
   $238 = (($237) - ($236))|0;
   $239 = $236 << 16;
   $240 = $238 ^ $239;
   $241 = (($232) - ($236))|0;
   $242 = (($241) - ($240))|0;
   $243 = $240 >>> 5;
   $244 = $242 ^ $243;
   $245 = (($236) - ($240))|0;
   $246 = (($245) - ($244))|0;
   $247 = $244 >>> 3;
   $248 = $246 ^ $247;
   $249 = (($240) - ($244))|0;
   $250 = (($249) - ($248))|0;
   $251 = $248 << 10;
   $252 = $250 ^ $251;
   $253 = (($244) - ($248))|0;
   $254 = (($253) - ($252))|0;
   $255 = $252 >>> 15;
   $256 = $254 ^ $255;
   $257 = $256 & $52;
   $258 = (($56) + ($257<<2)|0);
   $offset7$032 = HEAP32[$258>>2]|0;
   $cond1133 = ($offset7$032|0)==(-1);
   L58: do {
    if ($cond1133) {
     label = 41;
    } else {
     $offset7$034 = $offset7$032;
     while(1) {
      $259 = (($14) + (($offset7$034*12)|0)|0);
      $260 = HEAP32[$259>>2]|0;
      $261 = ($260|0)==($$idx$val|0);
      if ($261) {
       $262 = ((($14) + (($offset7$034*12)|0)|0) + 4|0);
       $263 = HEAP32[$262>>2]|0;
       $264 = ($263|0)==($$idx12$val|0);
       if ($264) {
        $265 = ((($14) + (($offset7$034*12)|0)|0) + 8|0);
        $266 = HEAP32[$265>>2]|0;
        $267 = ($266|0)==($$idx13$val|0);
        if ($267) {
         $idtRemap$2$off0 = $idtRemap$0$off039;$nbCleanedTris$3 = $nbCleanedTris$238;
         break L58;
        }
       }
      }
      $$sum4 = (($offset7$034) + ($53))|0;
      $268 = (($56) + ($$sum4<<2)|0);
      $offset7$0 = HEAP32[$268>>2]|0;
      $cond11 = ($offset7$0|0)==(-1);
      if ($cond11) {
       label = 41;
       break;
      } else {
       $offset7$034 = $offset7$0;
      }
     }
    }
   } while(0);
   if ((label|0) == 41) {
    label = 0;
    $269 = (($15) + ($nbCleanedTris$238<<2)|0);
    HEAP32[$269>>2] = $i4$040;
    $270 = ($i4$040|0)==($nbCleanedTris$238|0);
    $idtRemap$0$off0$ = $270 & $idtRemap$0$off039;
    $271 = (($14) + (($nbCleanedTris$238*12)|0)|0);
    ;HEAP32[$271+0>>2]=HEAP32[$220+0>>2]|0;HEAP32[$271+4>>2]=HEAP32[$220+4>>2]|0;HEAP32[$271+8>>2]=HEAP32[$220+8>>2]|0;
    $272 = HEAP32[$258>>2]|0;
    $$sum = (($nbCleanedTris$238) + ($53))|0;
    $273 = (($56) + ($$sum<<2)|0);
    HEAP32[$273>>2] = $272;
    $274 = (($nbCleanedTris$238) + 1)|0;
    HEAP32[$258>>2] = $nbCleanedTris$238;
    $idtRemap$2$off0 = $idtRemap$0$off0$;$nbCleanedTris$3 = $274;
   }
   $275 = (($i4$040) + 1)|0;
   $exitcond75 = ($275|0)==($nbCleanedTris$0$lcssa|0);
   if ($exitcond75) {
    $idtRemap$0$off0$lcssa = $idtRemap$2$off0;$nbCleanedTris$2$lcssa = $nbCleanedTris$3;
    break;
   } else {
    $i4$040 = $275;$idtRemap$0$off039 = $idtRemap$2$off0;$nbCleanedTris$238 = $nbCleanedTris$3;
   }
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$56);
 $276 = ($vertexIndices$0|0)==(0|0);
 if (!($276)) {
  $277 = ($nbCleanedVerts$0$lcssa|0)==(0);
  if (!($277)) {
   $i8$030 = 0;
   while(1) {
    $278 = (($vertexIndices$0) + ($i8$030<<2)|0);
    $279 = HEAP32[$278>>2]|0;
    $280 = (($srcVerts) + (($279*12)|0)|0);
    $281 = Math_fround(HEAPF32[$280>>2]);
    $282 = (($11) + (($i8$030*12)|0)|0);
    HEAPF32[$282>>2] = $281;
    $283 = ((($srcVerts) + (($279*12)|0)|0) + 4|0);
    $284 = Math_fround(HEAPF32[$283>>2]);
    $285 = ((($11) + (($i8$030*12)|0)|0) + 4|0);
    HEAPF32[$285>>2] = $284;
    $286 = ((($srcVerts) + (($279*12)|0)|0) + 8|0);
    $287 = Math_fround(HEAPF32[$286>>2]);
    $288 = ((($11) + (($i8$030*12)|0)|0) + 8|0);
    HEAPF32[$288>>2] = $287;
    $289 = (($i8$030) + 1)|0;
    $exitcond = ($289|0)==($nbCleanedVerts$0$lcssa|0);
    if ($exitcond) {
     break;
    } else {
     $i8$030 = $289;
    }
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($8,$vertexIndices$0);
 }
 HEAP32[$this>>2] = $nbCleanedVerts$0$lcssa;
 $290 = (($this) + 4|0);
 HEAP32[$290>>2] = $nbCleanedTris$2$lcssa;
 $291 = (($this) + 8|0);
 HEAP32[$291>>2] = $11;
 $292 = (($this) + 12|0);
 HEAP32[$292>>2] = $14;
 if ($idtRemap$0$off0$lcssa) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($9,$15);
  $293 = (($this) + 16|0);
  HEAP32[$293>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $294 = (($this) + 16|0);
  HEAP32[$294>>2] = $15;
  STACKTOP = sp;return;
 }
}
function __ZN5physx11MeshCleanerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$4);
 HEAP32[$3>>2] = 0;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$6);
 HEAP32[$5>>2] = 0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$8);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx15saveHeightFieldERKNS_2Gu11HeightFieldERNS_14PxOutputStreamEb($hf,$stream,$endian) {
 $hf = $hf|0;
 $stream = $stream|0;
 $endian = $endian|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0;
 var $7 = 0, $8 = Math_fround(0), $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx11writeHeaderEaaaajbRNS_14PxOutputStreamE(72,70,72,70,0,$endian,$stream)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($hf) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($2,$endian,$stream);
 $3 = (($hf) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($4,$endian,$stream);
 $5 = (($hf) + 24|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($6,$endian,$stream);
 $7 = (($hf) + 28|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($8,$endian,$stream);
 $9 = (($hf) + 32|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($10,$endian,$stream);
 $11 = (($hf) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($12,$endian,$stream);
 $13 = (($hf) + 44|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($14,$endian,$stream);
 $15 = (($hf) + 48|0);
 $16 = HEAP16[$15>>1]|0;
 __ZN5physx9writeWordEtbRNS_14PxOutputStreamE($16,$endian,$stream);
 $17 = (($hf) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($18,$endian,$stream);
 $19 = (($hf) + 56|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($20,$endian,$stream);
 $21 = (($hf) + 60|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($22,$endian,$stream);
 $23 = (($hf) + 64|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($24,$endian,$stream);
 $25 = (($hf) + 68|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($26,$endian,$stream);
 $27 = (($hf) + 72|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($28,$endian,$stream);
 $29 = (($hf) + 76|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($30,$endian,$stream);
 $31 = (($hf) + 80|0);
 $32 = HEAP32[$31>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($32,$endian,$stream);
 $33 = (($hf) + 84|0);
 $34 = HEAP32[$33>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($34,$endian,$stream);
 $35 = (($hf) + 88|0);
 $36 = HEAP32[$35>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($36,$endian,$stream);
 $37 = (($hf) + 92|0);
 $38 = HEAP32[$37>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($38,$endian,$stream);
 $39 = (($hf) + 96|0);
 $40 = HEAP32[$39>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($40,$endian,$stream);
 $41 = (($hf) + 100|0);
 $42 = HEAP32[$41>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($42,$endian,$stream);
 $43 = (($hf) + 104|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($44,$endian,$stream);
 $45 = (($hf) + 108|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($46,$endian,$stream);
 $47 = HEAP32[$41>>2]|0;
 $48 = ($47|0)==(0);
 if ($48) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = (($hf) + 36|0);
 $i$01 = 0;
 while(1) {
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + ($i$01<<2)|0);
  $52 = HEAP16[$51>>1]|0;
  __ZN5physx9writeWordEtbRNS_14PxOutputStreamE($52,$endian,$stream);
  $53 = HEAP32[$stream>>2]|0;
  $54 = HEAP32[$53>>2]|0;
  $55 = ((($50) + ($i$01<<2)|0) + 2|0);
  (FUNCTION_TABLE_iiii[$54 & 2047]($stream,$55,1)|0);
  $56 = HEAP32[$stream>>2]|0;
  $57 = HEAP32[$56>>2]|0;
  $58 = ((($50) + ($i$01<<2)|0) + 3|0);
  (FUNCTION_TABLE_iiii[$57 & 2047]($stream,$58,1)|0);
  $59 = (($i$01) + 1)|0;
  $60 = HEAP32[$41>>2]|0;
  $61 = ($59>>>0)<($60>>>0);
  if ($61) {
   $i$01 = $59;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11RTreeCooker18buildFromTrianglesERNS_2Gu5RTreeEPKNS_6PxVec3EjPKtPKjjRNS_6shdfnd5ArrayIjNSB_19ReflectionAllocatorIjEEEEPNS0_13RemapCallbackEfNS_17PxMeshCookingHint4EnumE($result,$verts,$numVerts,$tris16,$tris32,$numTris,$resultPermute,$rc,$sizePerfTradeOff01,$hint) {
 $result = $result|0;
 $verts = $verts|0;
 $numVerts = $numVerts|0;
 $tris16 = $tris16|0;
 $tris32 = $tris32|0;
 $numTris = $numTris|0;
 $resultPermute = $resultPermute|0;
 $rc = $rc|0;
 $sizePerfTradeOff01 = Math_fround($sizePerfTradeOff01);
 $hint = $hint|0;
 var $$$i = Math_fround(0), $$$i$us = Math_fround(0), $$$i14 = Math_fround(0), $$$i14$us = Math_fround(0), $$$i24 = Math_fround(0), $$$i24$us = Math_fround(0), $$$i30 = Math_fround(0), $$$i30$us = Math_fround(0), $$$i40 = Math_fround(0), $$$i40$us = Math_fround(0), $$$i40195$lcssa = Math_fround(0), $$$i40195199 = Math_fround(0), $$$i40195199$us = Math_fround(0), $$$i46 = Math_fround(0), $$$i46$us = Math_fround(0), $$$i46193$lcssa = Math_fround(0), $$$i46193201 = Math_fround(0), $$$i46193201$us = Math_fround(0), $$1$i = Math_fround(0), $$1$i$us = Math_fround(0);
 var $$1$i15 = Math_fround(0), $$1$i15$us = Math_fround(0), $$1$i25 = Math_fround(0), $$1$i25$us = Math_fround(0), $$1$i31 = Math_fround(0), $$1$i31$us = Math_fround(0), $$1$i41 = Math_fround(0), $$1$i41$us = Math_fround(0), $$1$i41196$lcssa = Math_fround(0), $$1$i41196198 = Math_fround(0), $$1$i41196198$us = Math_fround(0), $$1$i47 = Math_fround(0), $$1$i47$us = Math_fround(0), $$1$i47194$lcssa = Math_fround(0), $$1$i47194200 = Math_fround(0), $$1$i47194200$us = Math_fround(0), $$arith = 0, $$arith2 = 0, $$firstEmptyIndex$0$i = 0, $$lcssa = Math_fround(0);
 var $$lcssa197 = Math_fround(0), $$overflow = 0, $$overflow3 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1$i = 0, $$pre58$i = 0, $$pre59$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0);
 var $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0;
 var $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0);
 var $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0);
 var $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = Math_fround(0), $455 = 0, $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = 0, $466 = Math_fround(0), $467 = 0, $468 = 0;
 var $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = Math_fround(0), $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = 0, $485 = Math_fround(0), $486 = 0;
 var $487 = 0, $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = 0, $491 = Math_fround(0), $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = Math_fround(0), $502 = 0, $503 = 0;
 var $504 = Math_fround(0), $505 = 0, $506 = 0, $507 = Math_fround(0), $508 = 0, $509 = 0, $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0;
 var $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $allBounds = 0, $discard$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond212 = 0, $exitcond54$i = 0, $exitcond55$i = 0, $exitcond56$i = 0, $firstEmptyIndex$038$i = 0, $firstEmptyIndex$2$i = 0, $i$0202 = 0, $i$0202$us = 0, $i$048$i = 0, $i1$044$i = 0, $i2$040$i = 0, $i4$037$i = 0, $j$i = 0, $j5$036$i = 0, $maxLevels$i = 0, $notlhs$i = 0;
 var $notlhs65$i = 0, $notlhs67$i = 0, $notlhs69$i = 0, $notlhs71$i = 0, $notlhs73$i = 0, $notrhs$i = 0, $notrhs66$i = 0, $notrhs68$i = 0, $notrhs70$i = 0, $notrhs72$i = 0, $notrhs74$i = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i$i$i = 0, $or$cond$i$i11$not$i = 0, $or$cond$i$i13$not$i = 0, $or$cond$i$i15$not$i = 0, $or$cond$i$i17$not$i = 0, $or$cond$i$i4$i = 0;
 var $or$cond$i$i8$not$i = 0, $or$cond$i$i9$not$i = 0, $or$cond60$i = 0, $or$cond61$i = 0, $or$cond62$i = 0, $or$cond63$i = 0, $or$cond64$i = 0, $phitmp$i = 0, $q$i = 0, $qtreeNodes$i = 0, $resultTree$i = 0, $sentinel$i = 0, $sizePerfTradeOff01$op$i$i$i = Math_fround(0), $ss3$i = 0, $storemerge$i$i = 0, $storemerge52$i = 0, $xOrder$i = 0, $xRanks$i = 0, $yOrder$i = 0, $yRanks$i = 0;
 var $zOrder$i = 0, $zRanks$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $0 = sp + 296|0;
 $1 = sp + 292|0;
 $j$i = sp + 288|0;
 $sentinel$i = sp + 284|0;
 $resultTree$i = sp + 272|0;
 $maxLevels$i = sp + 268|0;
 $xRanks$i = sp + 256|0;
 $2 = sp + 252|0;
 $yRanks$i = sp + 240|0;
 $3 = sp + 236|0;
 $zRanks$i = sp + 224|0;
 $4 = sp + 220|0;
 $xOrder$i = sp + 208|0;
 $5 = sp + 108|0;
 $yOrder$i = sp + 96|0;
 $6 = sp + 76|0;
 $zOrder$i = sp + 64|0;
 $7 = sp + 80|0;
 $8 = sp + 88|0;
 $9 = sp + 200|0;
 $10 = sp + 112|0;
 $ss3$i = sp + 120|0;
 $discard$i = sp;
 $qtreeNodes$i = sp + 148|0;
 $q$i = sp + 160|0;
 $11 = sp + 352|0;
 $allBounds = sp + 188|0;
 $12 = sp + 32|0;
 HEAP32[$allBounds>>2] = 0;
 $13 = (($allBounds) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($allBounds) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = ($numTris|0)==(0);
 if ($15) {
  $$$i40195$lcssa = Math_fround(3.40282346638528859812E+38);$$$i46193$lcssa = Math_fround(-3.40282346638528859812E+38);$$1$i41196$lcssa = Math_fround(3.40282346638528859812E+38);$$1$i47194$lcssa = Math_fround(-3.40282346638528859812E+38);$$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa197 = Math_fround(-3.40282346638528859812E+38);
 } else {
  __ZN5physx6shdfnd5ArrayINS_10PxBounds3VENS0_19ReflectionAllocatorIS2_EEE8recreateEj($allBounds,$numTris);
  $16 = ($tris16|0)==(0|0);
  $17 = (($12) + 4|0);
  $18 = (($12) + 8|0);
  $19 = (($12) + 12|0);
  $20 = (($12) + 16|0);
  $21 = (($12) + 20|0);
  $22 = (($12) + 24|0);
  $23 = (($12) + 28|0);
  if ($16) {
   $$$i40195199$us = Math_fround(3.40282346638528859812E+38);$$$i46193201$us = Math_fround(-3.40282346638528859812E+38);$$1$i41196198$us = Math_fround(3.40282346638528859812E+38);$$1$i47194200$us = Math_fround(-3.40282346638528859812E+38);$75 = Math_fround(3.40282346638528859812E+38);$80 = Math_fround(-3.40282346638528859812E+38);$i$0202$us = 0;
   while(1) {
    $24 = ($i$0202$us*3)|0;
    $25 = (($tris32) + ($24<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + 1)|0;
    $28 = (($tris32) + ($27<<2)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($24) + 2)|0;
    $31 = (($tris32) + ($30<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($verts) + (($26*12)|0)|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = ((($verts) + (($26*12)|0)|0) + 4|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = ((($verts) + (($26*12)|0)|0) + 8|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = (($verts) + (($29*12)|0)|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = ((($verts) + (($29*12)|0)|0) + 4|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = ((($verts) + (($29*12)|0)|0) + 8|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = (($verts) + (($32*12)|0)|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = ((($verts) + (($32*12)|0)|0) + 4|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = ((($verts) + (($32*12)|0)|0) + 8|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = $34 < $40;
    $$$i$us = $51 ? $34 : $40;
    $52 = $36 < $42;
    $53 = $52 ? $36 : $42;
    $54 = $38 < $44;
    $$1$i$us = $54 ? $38 : $44;
    $55 = $$$i$us < $46;
    $$$i14$us = $55 ? $$$i$us : $46;
    $56 = $53 < $48;
    $57 = $56 ? $53 : $48;
    $58 = $$1$i$us < $50;
    $$1$i15$us = $58 ? $$1$i$us : $50;
    $59 = Math_fround($$$i14$us + Math_fround(-5.00000023748725652695E-4));
    $60 = Math_fround($57 + Math_fround(-5.00000023748725652695E-4));
    $61 = Math_fround($$1$i15$us + Math_fround(-5.00000023748725652695E-4));
    $62 = $34 > $40;
    $$$i24$us = $62 ? $34 : $40;
    $63 = $36 > $42;
    $64 = $63 ? $36 : $42;
    $65 = $38 > $44;
    $$1$i25$us = $65 ? $38 : $44;
    $66 = $$$i24$us > $46;
    $$$i30$us = $66 ? $$$i24$us : $46;
    $67 = $64 > $48;
    $68 = $67 ? $64 : $48;
    $69 = $$1$i25$us > $50;
    $$1$i31$us = $69 ? $$1$i25$us : $50;
    $70 = Math_fround($$$i30$us + Math_fround(5.00000023748725652695E-4));
    $71 = Math_fround($68 + Math_fround(5.00000023748725652695E-4));
    $72 = Math_fround($$1$i31$us + Math_fround(5.00000023748725652695E-4));
    $73 = $$$i40195199$us < $59;
    $$$i40$us = $73 ? $$$i40195199$us : $59;
    $74 = $75 < $60;
    $76 = $74 ? $75 : $60;
    $77 = $$1$i41196198$us < $61;
    $$1$i41$us = $77 ? $$1$i41196198$us : $61;
    $78 = $$$i46193201$us > $70;
    $$$i46$us = $78 ? $$$i46193201$us : $70;
    $79 = $80 > $71;
    $81 = $79 ? $80 : $71;
    $82 = $$1$i47194200$us > $72;
    $$1$i47$us = $82 ? $$1$i47194200$us : $72;
    HEAPF32[$12>>2] = $59;
    HEAPF32[$17>>2] = $60;
    HEAPF32[$18>>2] = $61;
    HEAPF32[$19>>2] = Math_fround(0.0);
    HEAPF32[$20>>2] = $70;
    HEAPF32[$21>>2] = $71;
    HEAPF32[$22>>2] = $72;
    HEAPF32[$23>>2] = Math_fround(0.0);
    $83 = HEAP32[$14>>2]|0;
    $84 = $83 & 2147483647;
    $85 = HEAP32[$13>>2]|0;
    $86 = ($84>>>0)>($85>>>0);
    if ($86) {
     $87 = HEAP32[$allBounds>>2]|0;
     $88 = (($87) + ($85<<5)|0);
     $89 = ($88|0)==(0|0);
     if (!($89)) {
      ;HEAP32[$88+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$88+16>>2]=HEAP32[$12+16>>2]|0;HEAP32[$88+20>>2]=HEAP32[$12+20>>2]|0;HEAP32[$88+24>>2]=HEAP32[$12+24>>2]|0;HEAP32[$88+28>>2]=HEAP32[$12+28>>2]|0;
     }
     $90 = (($85) + 1)|0;
     HEAP32[$13>>2] = $90;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_10PxBounds3VENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($allBounds,$12)|0);
    }
    $91 = (($i$0202$us) + 1)|0;
    $exitcond212 = ($91|0)==($numTris|0);
    if ($exitcond212) {
     $$$i40195$lcssa = $$$i40$us;$$$i46193$lcssa = $$$i46$us;$$1$i41196$lcssa = $$1$i41$us;$$1$i47194$lcssa = $$1$i47$us;$$lcssa = $76;$$lcssa197 = $81;
     break;
    } else {
     $$$i40195199$us = $$$i40$us;$$$i46193201$us = $$$i46$us;$$1$i41196198$us = $$1$i41$us;$$1$i47194200$us = $$1$i47$us;$75 = $76;$80 = $81;$i$0202$us = $91;
    }
   }
  } else {
   $$$i40195199 = Math_fround(3.40282346638528859812E+38);$$$i46193201 = Math_fround(-3.40282346638528859812E+38);$$1$i41196198 = Math_fround(3.40282346638528859812E+38);$$1$i47194200 = Math_fround(-3.40282346638528859812E+38);$146 = Math_fround(3.40282346638528859812E+38);$151 = Math_fround(-3.40282346638528859812E+38);$i$0202 = 0;
   while(1) {
    $92 = ($i$0202*3)|0;
    $93 = (($tris16) + ($92<<1)|0);
    $94 = HEAP16[$93>>1]|0;
    $95 = $94&65535;
    $96 = (($92) + 1)|0;
    $97 = (($tris16) + ($96<<1)|0);
    $98 = HEAP16[$97>>1]|0;
    $99 = $98&65535;
    $100 = (($92) + 2)|0;
    $101 = (($tris16) + ($100<<1)|0);
    $102 = HEAP16[$101>>1]|0;
    $103 = $102&65535;
    $104 = (($verts) + (($95*12)|0)|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = ((($verts) + (($95*12)|0)|0) + 4|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = ((($verts) + (($95*12)|0)|0) + 8|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = (($verts) + (($99*12)|0)|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = ((($verts) + (($99*12)|0)|0) + 4|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = ((($verts) + (($99*12)|0)|0) + 8|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = (($verts) + (($103*12)|0)|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = ((($verts) + (($103*12)|0)|0) + 4|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = ((($verts) + (($103*12)|0)|0) + 8|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    $122 = $105 < $111;
    $$$i = $122 ? $105 : $111;
    $123 = $107 < $113;
    $124 = $123 ? $107 : $113;
    $125 = $109 < $115;
    $$1$i = $125 ? $109 : $115;
    $126 = $$$i < $117;
    $$$i14 = $126 ? $$$i : $117;
    $127 = $124 < $119;
    $128 = $127 ? $124 : $119;
    $129 = $$1$i < $121;
    $$1$i15 = $129 ? $$1$i : $121;
    $130 = Math_fround($$$i14 + Math_fround(-5.00000023748725652695E-4));
    $131 = Math_fround($128 + Math_fround(-5.00000023748725652695E-4));
    $132 = Math_fround($$1$i15 + Math_fround(-5.00000023748725652695E-4));
    $133 = $105 > $111;
    $$$i24 = $133 ? $105 : $111;
    $134 = $107 > $113;
    $135 = $134 ? $107 : $113;
    $136 = $109 > $115;
    $$1$i25 = $136 ? $109 : $115;
    $137 = $$$i24 > $117;
    $$$i30 = $137 ? $$$i24 : $117;
    $138 = $135 > $119;
    $139 = $138 ? $135 : $119;
    $140 = $$1$i25 > $121;
    $$1$i31 = $140 ? $$1$i25 : $121;
    $141 = Math_fround($$$i30 + Math_fround(5.00000023748725652695E-4));
    $142 = Math_fround($139 + Math_fround(5.00000023748725652695E-4));
    $143 = Math_fround($$1$i31 + Math_fround(5.00000023748725652695E-4));
    $144 = $$$i40195199 < $130;
    $$$i40 = $144 ? $$$i40195199 : $130;
    $145 = $146 < $131;
    $147 = $145 ? $146 : $131;
    $148 = $$1$i41196198 < $132;
    $$1$i41 = $148 ? $$1$i41196198 : $132;
    $149 = $$$i46193201 > $141;
    $$$i46 = $149 ? $$$i46193201 : $141;
    $150 = $151 > $142;
    $152 = $150 ? $151 : $142;
    $153 = $$1$i47194200 > $143;
    $$1$i47 = $153 ? $$1$i47194200 : $143;
    HEAPF32[$12>>2] = $130;
    HEAPF32[$17>>2] = $131;
    HEAPF32[$18>>2] = $132;
    HEAPF32[$19>>2] = Math_fround(0.0);
    HEAPF32[$20>>2] = $141;
    HEAPF32[$21>>2] = $142;
    HEAPF32[$22>>2] = $143;
    HEAPF32[$23>>2] = Math_fround(0.0);
    $154 = HEAP32[$14>>2]|0;
    $155 = $154 & 2147483647;
    $156 = HEAP32[$13>>2]|0;
    $157 = ($155>>>0)>($156>>>0);
    if ($157) {
     $158 = HEAP32[$allBounds>>2]|0;
     $159 = (($158) + ($156<<5)|0);
     $160 = ($159|0)==(0|0);
     if (!($160)) {
      ;HEAP32[$159+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$159+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$159+16>>2]=HEAP32[$12+16>>2]|0;HEAP32[$159+20>>2]=HEAP32[$12+20>>2]|0;HEAP32[$159+24>>2]=HEAP32[$12+24>>2]|0;HEAP32[$159+28>>2]=HEAP32[$12+28>>2]|0;
     }
     $161 = (($156) + 1)|0;
     HEAP32[$13>>2] = $161;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_10PxBounds3VENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($allBounds,$12)|0);
    }
    $162 = (($i$0202) + 1)|0;
    $exitcond = ($162|0)==($numTris|0);
    if ($exitcond) {
     $$$i40195$lcssa = $$$i40;$$$i46193$lcssa = $$$i46;$$1$i41196$lcssa = $$1$i41;$$1$i47194$lcssa = $$1$i47;$$lcssa = $147;$$lcssa197 = $152;
     break;
    } else {
     $$$i40195199 = $$$i40;$$$i46193201 = $$$i46;$$1$i41196198 = $$1$i41;$$1$i47194200 = $$1$i47;$146 = $147;$151 = $152;$i$0202 = $162;
    }
   }
  }
 }
 $163 = HEAP32[$allBounds>>2]|0;
 HEAP32[$1>>2] = 0;
 __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($resultPermute,0,$1);
 $164 = (($numTris) + 1)|0;
 $165 = (($resultPermute) + 8|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = $166 & 2147483647;
 $168 = ($167>>>0)<($164>>>0);
 if ($168) {
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE8recreateEj($resultPermute,$164);
 }
 HEAP32[$j$i>>2] = 0;
 $$pre59$i = (($resultPermute) + 4|0);
 if (!($15)) {
  $storemerge52$i = 0;
  while(1) {
   $169 = HEAP32[$165>>2]|0;
   $170 = $169 & 2147483647;
   $171 = HEAP32[$$pre59$i>>2]|0;
   $172 = ($170>>>0)>($171>>>0);
   if ($172) {
    $173 = HEAP32[$resultPermute>>2]|0;
    $174 = (($173) + ($171<<2)|0);
    $175 = ($174|0)==(0|0);
    if ($175) {
     $177 = $171;
    } else {
     HEAP32[$174>>2] = $storemerge52$i;
     $$pre$i$i = HEAP32[$$pre59$i>>2]|0;
     $177 = $$pre$i$i;
    }
    $176 = (($177) + 1)|0;
    HEAP32[$$pre59$i>>2] = $176;
    $179 = $storemerge52$i;
   } else {
    (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($resultPermute,$j$i)|0);
    $$pre$i = HEAP32[$j$i>>2]|0;
    $179 = $$pre$i;
   }
   $178 = (($179) + 1)|0;
   HEAP32[$j$i>>2] = $178;
   $180 = ($178>>>0)<($numTris>>>0);
   if ($180) {
    $storemerge52$i = $178;
   } else {
    break;
   }
  }
 }
 HEAP32[$sentinel$i>>2] = -1412567295;
 $181 = HEAP32[$165>>2]|0;
 $182 = $181 & 2147483647;
 $183 = HEAP32[$$pre59$i>>2]|0;
 $184 = ($182>>>0)>($183>>>0);
 if ($184) {
  $185 = HEAP32[$resultPermute>>2]|0;
  $186 = (($185) + ($183<<2)|0);
  $187 = ($186|0)==(0|0);
  if ($187) {
   $189 = $183;
  } else {
   HEAP32[$186>>2] = -1412567295;
   $$pre$i1$i = HEAP32[$$pre59$i>>2]|0;
   $189 = $$pre$i1$i;
  }
  $188 = (($189) + 1)|0;
  HEAP32[$$pre59$i>>2] = $188;
 } else {
  (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($resultPermute,$sentinel$i)|0);
 }
 HEAP32[$resultTree$i>>2] = 0;
 $190 = (($resultTree$i) + 4|0);
 HEAP32[$190>>2] = 0;
 $191 = (($resultTree$i) + 8|0);
 HEAP32[$191>>2] = 0;
 $192 = $numTris << 1;
 $193 = ($192|0)==(0);
 if (!($193)) {
  __ZN5physx6shdfnd5ArrayINS_11RTreeNodeNQENS0_19ReflectionAllocatorIS2_EEE8recreateEj($resultTree$i,$192);
 }
 HEAP32[$maxLevels$i>>2] = 0;
 $194 = ($hint|0)==(0);
 if ($194) {
  HEAP32[$2>>2] = 0;
  HEAP32[$xRanks$i>>2] = 0;
  $195 = (($xRanks$i) + 4|0);
  HEAP32[$195>>2] = 0;
  $196 = (($xRanks$i) + 8|0);
  HEAP32[$196>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($xRanks$i,$numTris,$2);
  HEAP32[$3>>2] = 0;
  HEAP32[$yRanks$i>>2] = 0;
  $197 = (($yRanks$i) + 4|0);
  HEAP32[$197>>2] = 0;
  $198 = (($yRanks$i) + 8|0);
  HEAP32[$198>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($yRanks$i,$numTris,$3);
  HEAP32[$4>>2] = 0;
  HEAP32[$zRanks$i>>2] = 0;
  $199 = (($zRanks$i) + 4|0);
  HEAP32[$199>>2] = 0;
  $200 = (($zRanks$i) + 8|0);
  HEAP32[$200>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($zRanks$i,$numTris,$4);
  HEAP32[$5>>2] = 0;
  HEAP32[$xOrder$i>>2] = 0;
  $201 = (($xOrder$i) + 4|0);
  HEAP32[$201>>2] = 0;
  $202 = (($xOrder$i) + 8|0);
  HEAP32[$202>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($xOrder$i,$numTris,$5);
  HEAP32[$6>>2] = 0;
  HEAP32[$yOrder$i>>2] = 0;
  $203 = (($yOrder$i) + 4|0);
  HEAP32[$203>>2] = 0;
  $204 = (($yOrder$i) + 8|0);
  HEAP32[$204>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($yOrder$i,$numTris,$6);
  HEAP32[$7>>2] = 0;
  HEAP32[$zOrder$i>>2] = 0;
  $205 = (($zOrder$i) + 4|0);
  HEAP32[$205>>2] = 0;
  $206 = (($zOrder$i) + 8|0);
  HEAP32[$206>>2] = 0;
  __ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE6resizeEjRKj($zOrder$i,$numTris,$7);
  $207 = HEAP32[$xOrder$i>>2]|0;
  $208 = HEAP32[$resultPermute>>2]|0;
  $209 = $numTris << 2;
  _memcpy(($207|0),($208|0),($209|0))|0;
  $210 = HEAP32[$yOrder$i>>2]|0;
  $211 = HEAP32[$resultPermute>>2]|0;
  _memcpy(($210|0),($211|0),($209|0))|0;
  $212 = HEAP32[$zOrder$i>>2]|0;
  $213 = HEAP32[$resultPermute>>2]|0;
  _memcpy(($212|0),($213|0),($209|0))|0;
  $214 = HEAP32[$201>>2]|0;
  HEAP32[$8>>2] = 0;
  $215 = (($8) + 4|0);
  HEAP32[$215>>2] = $163;
  __ZN5physx6shdfnd4sortIjNS_19SortBoundsPredicateENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($207,$214,$8,$0);
  if ($15) {
   $228 = HEAP32[$203>>2]|0;
   HEAP32[$9>>2] = 1;
   $229 = (($9) + 4|0);
   HEAP32[$229>>2] = $163;
   __ZN5physx6shdfnd4sortIjNS_19SortBoundsPredicateENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($210,$228,$9,$0);
  } else {
   $216 = HEAP32[$xRanks$i>>2]|0;
   $i$048$i = 0;
   while(1) {
    $217 = (($207) + ($i$048$i<<2)|0);
    $218 = HEAP32[$217>>2]|0;
    $219 = (($216) + ($218<<2)|0);
    HEAP32[$219>>2] = $i$048$i;
    $220 = (($i$048$i) + 1)|0;
    $exitcond56$i = ($220|0)==($numTris|0);
    if ($exitcond56$i) {
     break;
    } else {
     $i$048$i = $220;
    }
   }
   $221 = HEAP32[$203>>2]|0;
   HEAP32[$9>>2] = 1;
   $222 = (($9) + 4|0);
   HEAP32[$222>>2] = $163;
   __ZN5physx6shdfnd4sortIjNS_19SortBoundsPredicateENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($210,$221,$9,$0);
   $223 = HEAP32[$yRanks$i>>2]|0;
   $i1$044$i = 0;
   while(1) {
    $224 = (($210) + ($i1$044$i<<2)|0);
    $225 = HEAP32[$224>>2]|0;
    $226 = (($223) + ($225<<2)|0);
    HEAP32[$226>>2] = $i1$044$i;
    $227 = (($i1$044$i) + 1)|0;
    $exitcond55$i = ($227|0)==($numTris|0);
    if ($exitcond55$i) {
     break;
    } else {
     $i1$044$i = $227;
    }
   }
  }
  $230 = HEAP32[$205>>2]|0;
  HEAP32[$10>>2] = 2;
  $231 = (($10) + 4|0);
  HEAP32[$231>>2] = $163;
  __ZN5physx6shdfnd4sortIjNS_19SortBoundsPredicateENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($212,$230,$10,$0);
  $$pre58$i = HEAP32[$zRanks$i>>2]|0;
  if (!($15)) {
   $i2$040$i = 0;
   while(1) {
    $232 = (($212) + ($i2$040$i<<2)|0);
    $233 = HEAP32[$232>>2]|0;
    $234 = (($$pre58$i) + ($233<<2)|0);
    HEAP32[$234>>2] = $i2$040$i;
    $235 = (($i2$040$i) + 1)|0;
    $exitcond54$i = ($235|0)==($numTris|0);
    if ($exitcond54$i) {
     break;
    } else {
     $i2$040$i = $235;
    }
   }
  }
  $236 = HEAP32[$resultPermute>>2]|0;
  $237 = HEAP32[$xRanks$i>>2]|0;
  $238 = HEAP32[$yRanks$i>>2]|0;
  HEAP32[$0>>2] = $236;
  $239 = (($0) + 8|0);
  HEAP32[$239>>2] = $163;
  $240 = (($0) + 20|0);
  HEAP32[$240>>2] = $207;
  $241 = (($0) + 24|0);
  HEAP32[$241>>2] = $210;
  $242 = (($0) + 28|0);
  HEAP32[$242>>2] = $212;
  $243 = (($0) + 32|0);
  HEAP32[$243>>2] = $237;
  $244 = (($0) + 36|0);
  HEAP32[$244>>2] = $238;
  $245 = (($0) + 40|0);
  HEAP32[$245>>2] = $$pre58$i;
  $246 = (($0) + 48|0);
  HEAP32[$246>>2] = $numTris;
  $$arith2 = $numTris<<2;
  $$overflow3 = ($numTris>>>0)>(1073741823);
  $247 = $$overflow3 ? -1 : $$arith2;
  $248 = (__Znaj($247)|0);
  $249 = (($0) + 12|0);
  HEAP32[$249>>2] = $248;
  $250 = (__Znaj($247)|0);
  $251 = (($0) + 16|0);
  HEAP32[$251>>2] = $250;
  $252 = $192 | 1;
  $$arith = $252<<2;
  $$overflow = ($252>>>0)>(1073741823);
  $253 = $$overflow ? -1 : $$arith;
  $254 = (__Znaj($253)|0);
  $255 = (($0) + 4|0);
  HEAP32[$255>>2] = $254;
  $256 = (__Znaj($247)|0);
  $257 = (($0) + 44|0);
  HEAP32[$257>>2] = $256;
  $258 = $sizePerfTradeOff01 < Math_fround(0.0);
  $sizePerfTradeOff01$op$i$i$i = Math_fround($sizePerfTradeOff01 * Math_fround(15.0));
  $259 = (~~(($sizePerfTradeOff01$op$i$i$i))>>>0);
  $260 = $258 ? 0 : $259;
  $261 = ($260>>>0)<(14);
  $262 = $261 ? $260 : 14;
  $263 = (($0) + 52|0);
  HEAP32[$263>>2] = $262;
  __ZN5physx10SubSortSAH5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjjPS4_($0,$236,$numTris,$resultTree$i,$maxLevels$i,0,0);
  $264 = HEAP32[$249>>2]|0;
  $265 = ($264|0)==(0|0);
  if (!($265)) {
   __ZdaPv($264);
  }
  HEAP32[$249>>2] = 0;
  $266 = HEAP32[$251>>2]|0;
  $267 = ($266|0)==(0|0);
  if (!($267)) {
   __ZdaPv($266);
  }
  HEAP32[$251>>2] = 0;
  $268 = HEAP32[$255>>2]|0;
  $269 = ($268|0)==(0|0);
  if (!($269)) {
   __ZdaPv($268);
  }
  HEAP32[$255>>2] = 0;
  $270 = HEAP32[$257>>2]|0;
  $271 = ($270|0)==(0|0);
  if (!($271)) {
   __ZdaPv($270);
  }
  $272 = HEAP32[$206>>2]|0;
  $273 = $272 & 2147483647;
  $notlhs$i = ($273|0)==(0);
  $notrhs$i = ($272|0)<(0);
  $or$cond$i$i17$not$i = $notrhs$i | $notlhs$i;
  $274 = ($212|0)==(0|0);
  $or$cond$i = $or$cond$i$i17$not$i | $274;
  if (!($or$cond$i)) {
   $275 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $276 = HEAP32[$275>>2]|0;
   $277 = (($276) + 12|0);
   $278 = HEAP32[$277>>2]|0;
   FUNCTION_TABLE_vii[$278 & 4095]($275,$212);
  }
  $279 = HEAP32[$204>>2]|0;
  $280 = $279 & 2147483647;
  $notlhs65$i = ($280|0)==(0);
  $notrhs66$i = ($279|0)<(0);
  $or$cond$i$i15$not$i = $notrhs66$i | $notlhs65$i;
  $281 = ($210|0)==(0|0);
  $or$cond60$i = $or$cond$i$i15$not$i | $281;
  if (!($or$cond60$i)) {
   $282 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $283 = HEAP32[$282>>2]|0;
   $284 = (($283) + 12|0);
   $285 = HEAP32[$284>>2]|0;
   FUNCTION_TABLE_vii[$285 & 4095]($282,$210);
  }
  $286 = HEAP32[$202>>2]|0;
  $287 = $286 & 2147483647;
  $notlhs67$i = ($287|0)==(0);
  $notrhs68$i = ($286|0)<(0);
  $or$cond$i$i13$not$i = $notrhs68$i | $notlhs67$i;
  $288 = ($207|0)==(0|0);
  $or$cond61$i = $or$cond$i$i13$not$i | $288;
  if (!($or$cond61$i)) {
   $289 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $290 = HEAP32[$289>>2]|0;
   $291 = (($290) + 12|0);
   $292 = HEAP32[$291>>2]|0;
   FUNCTION_TABLE_vii[$292 & 4095]($289,$207);
  }
  $293 = HEAP32[$200>>2]|0;
  $294 = $293 & 2147483647;
  $notlhs69$i = ($294|0)==(0);
  $notrhs70$i = ($293|0)<(0);
  $or$cond$i$i11$not$i = $notrhs70$i | $notlhs69$i;
  $295 = ($$pre58$i|0)==(0|0);
  $or$cond62$i = $or$cond$i$i11$not$i | $295;
  if (!($or$cond62$i)) {
   $296 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $297 = HEAP32[$296>>2]|0;
   $298 = (($297) + 12|0);
   $299 = HEAP32[$298>>2]|0;
   FUNCTION_TABLE_vii[$299 & 4095]($296,$$pre58$i);
  }
  $300 = HEAP32[$198>>2]|0;
  $301 = $300 & 2147483647;
  $notlhs71$i = ($301|0)==(0);
  $notrhs72$i = ($300|0)<(0);
  $or$cond$i$i9$not$i = $notrhs72$i | $notlhs71$i;
  $302 = ($238|0)==(0|0);
  $or$cond63$i = $or$cond$i$i9$not$i | $302;
  if (!($or$cond63$i)) {
   $303 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $304 = HEAP32[$303>>2]|0;
   $305 = (($304) + 12|0);
   $306 = HEAP32[$305>>2]|0;
   FUNCTION_TABLE_vii[$306 & 4095]($303,$238);
  }
  $307 = HEAP32[$196>>2]|0;
  $308 = $307 & 2147483647;
  $notlhs73$i = ($308|0)==(0);
  $notrhs74$i = ($307|0)<(0);
  $or$cond$i$i8$not$i = $notrhs74$i | $notlhs73$i;
  $309 = ($237|0)==(0|0);
  $or$cond64$i = $or$cond$i$i8$not$i | $309;
  if (!($or$cond64$i)) {
   $310 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $311 = HEAP32[$310>>2]|0;
   $312 = (($311) + 12|0);
   $313 = HEAP32[$312>>2]|0;
   FUNCTION_TABLE_vii[$313 & 4095]($310,$237);
  }
 } else {
  $314 = HEAP32[$resultPermute>>2]|0;
  __ZN5physx12SubSortQuickC2EPjPKNS_10PxBounds3VEjf($ss3$i,$314,$163,$numTris,$sizePerfTradeOff01);
  $315 = HEAP32[$resultPermute>>2]|0;
  $316 = HEAP32[$$pre59$i>>2]|0;
  $317 = (($316) + -1)|0;
  __ZN5physx12SubSortQuick5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjRNS_10PxBounds3VEj($ss3$i,$315,$317,$resultTree$i,$maxLevels$i,$discard$i,0);
  $318 = (($ss3$i) + 20|0);
  $319 = HEAP32[$318>>2]|0;
  $320 = $319 & 2147483647;
  $321 = ($320|0)!=(0);
  $322 = ($319|0)>(-1);
  $or$cond$i$i$i$i$i = $321 & $322;
  if ($or$cond$i$i$i$i$i) {
   $323 = (($ss3$i) + 12|0);
   $324 = HEAP32[$323>>2]|0;
   $325 = ($324|0)==(0|0);
   if (!($325)) {
    $326 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $327 = HEAP32[$326>>2]|0;
    $328 = (($327) + 12|0);
    $329 = HEAP32[$328>>2]|0;
    FUNCTION_TABLE_vii[$329 & 4095]($326,$324);
   }
  }
 }
 $330 = HEAP32[$$pre59$i>>2]|0;
 $331 = (($330) + -1)|0;
 HEAP32[$$pre59$i>>2] = $331;
 HEAP32[$qtreeNodes$i>>2] = 0;
 $332 = (($qtreeNodes$i) + 4|0);
 HEAP32[$332>>2] = 0;
 $333 = (($qtreeNodes$i) + 8|0);
 HEAP32[$333>>2] = 0;
 $334 = HEAP32[$190>>2]|0;
 $335 = ($334|0)==(0);
 if ($335) {
  $389 = 0;
 } else {
  __ZN5physx6shdfnd5ArrayINS_2Gu10RTreeNodeQENS0_19ReflectionAllocatorIS3_EEE8recreateEj($qtreeNodes$i,$334);
  $336 = HEAP32[$resultTree$i>>2]|0;
  $337 = (($q$i) + 24|0);
  $338 = (($q$i) + 8|0);
  $339 = (($q$i) + 4|0);
  $340 = (($q$i) + 20|0);
  $341 = (($q$i) + 16|0);
  $342 = (($q$i) + 12|0);
  $firstEmptyIndex$038$i = -1;$i4$037$i = 0;
  while(1) {
   $343 = ((($336) + ($i4$037$i<<5)|0) + 28|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = ($344|0)>(0);
   $346 = HEAP32[$337>>2]|0;
   $347 = $346 & -2;
   $348 = $346 | 1;
   $storemerge$i$i = $345 ? $348 : $347;
   HEAP32[$337>>2] = $storemerge$i$i;
   $349 = ((($336) + ($i4$037$i<<5)|0) + 24|0);
   $350 = HEAP32[$349>>2]|0;
   $351 = ($350|0)==(-1);
   do {
    if ($351) {
     $352 = ($firstEmptyIndex$038$i|0)==(-1);
     $353 = HEAP32[$332>>2]|0;
     $$firstEmptyIndex$0$i = $352 ? $353 : $firstEmptyIndex$038$i;
     HEAPF32[$338>>2] = Math_fround(3.40282346638528859812E+38);
     HEAPF32[$339>>2] = Math_fround(3.40282346638528859812E+38);
     HEAPF32[$q$i>>2] = Math_fround(3.40282346638528859812E+38);
     HEAPF32[$340>>2] = Math_fround(-3.40282346638528859812E+38);
     HEAPF32[$341>>2] = Math_fround(-3.40282346638528859812E+38);
     HEAPF32[$342>>2] = Math_fround(-3.40282346638528859812E+38);
     $354 = ($$firstEmptyIndex$0$i*28)|0;
     $355 = $354 | 1;
     HEAP32[$337>>2] = $355;
     $firstEmptyIndex$2$i = $$firstEmptyIndex$0$i;
    } else {
     $356 = (($336) + ($i4$037$i<<5)|0);
     $357 = Math_fround(HEAPF32[$356>>2]);
     HEAPF32[$q$i>>2] = $357;
     $358 = ((($336) + ($i4$037$i<<5)|0) + 4|0);
     $359 = Math_fround(HEAPF32[$358>>2]);
     HEAPF32[$339>>2] = $359;
     $360 = ((($336) + ($i4$037$i<<5)|0) + 8|0);
     $361 = Math_fround(HEAPF32[$360>>2]);
     HEAPF32[$338>>2] = $361;
     $362 = ((($336) + ($i4$037$i<<5)|0) + 12|0);
     $363 = Math_fround(HEAPF32[$362>>2]);
     HEAPF32[$342>>2] = $363;
     $364 = ((($336) + ($i4$037$i<<5)|0) + 16|0);
     $365 = Math_fround(HEAPF32[$364>>2]);
     HEAPF32[$341>>2] = $365;
     $366 = ((($336) + ($i4$037$i<<5)|0) + 20|0);
     $367 = Math_fround(HEAPF32[$366>>2]);
     HEAPF32[$340>>2] = $367;
     $368 = HEAP32[$343>>2]|0;
     $369 = ($368|0)>(0);
     if ($369) {
      HEAP32[$337>>2] = $350;
      $371 = HEAP32[$rc>>2]|0;
      $372 = (($371) + 8|0);
      $373 = HEAP32[$372>>2]|0;
      $374 = HEAP32[$343>>2]|0;
      FUNCTION_TABLE_viiii[$373 & 511]($rc,$337,$350,$374);
      $firstEmptyIndex$2$i = $firstEmptyIndex$038$i;
      break;
     } else {
      $370 = ($350*28)|0;
      HEAP32[$337>>2] = $370;
      $firstEmptyIndex$2$i = $firstEmptyIndex$038$i;
      break;
     }
    }
   } while(0);
   $375 = HEAP32[$333>>2]|0;
   $376 = $375 & 2147483647;
   $377 = HEAP32[$332>>2]|0;
   $378 = ($376>>>0)>($377>>>0);
   if ($378) {
    $379 = HEAP32[$qtreeNodes$i>>2]|0;
    $380 = (($379) + (($377*28)|0)|0);
    $381 = ($380|0)==(0|0);
    if (!($381)) {
     ;HEAP32[$380+0>>2]=HEAP32[$q$i+0>>2]|0;HEAP32[$380+4>>2]=HEAP32[$q$i+4>>2]|0;HEAP32[$380+8>>2]=HEAP32[$q$i+8>>2]|0;HEAP32[$380+12>>2]=HEAP32[$q$i+12>>2]|0;HEAP32[$380+16>>2]=HEAP32[$q$i+16>>2]|0;HEAP32[$380+20>>2]=HEAP32[$q$i+20>>2]|0;HEAP32[$380+24>>2]=HEAP32[$q$i+24>>2]|0;
    }
    $382 = (($377) + 1)|0;
    HEAP32[$332>>2] = $382;
   } else {
    (__ZN5physx6shdfnd5ArrayINS_2Gu10RTreeNodeQENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($qtreeNodes$i,$q$i)|0);
   }
   $383 = (($i4$037$i) + 1)|0;
   $exitcond$i = ($383|0)==($334|0);
   if ($exitcond$i) {
    break;
   } else {
    $firstEmptyIndex$038$i = $firstEmptyIndex$2$i;$i4$037$i = $383;
   }
  }
  $$pre = HEAP32[$332>>2]|0;
  $389 = $$pre;
 }
 $384 = (($result) + 32|0);
 HEAPF32[$384>>2] = Math_fround(1.0);
 $385 = (($result) + 36|0);
 HEAPF32[$385>>2] = Math_fround(1.0);
 $386 = (($result) + 40|0);
 HEAPF32[$386>>2] = Math_fround(1.0);
 $387 = (($result) + 44|0);
 HEAPF32[$387>>2] = Math_fround(1.0);
 $388 = (($result) + 76|0);
 HEAP32[$388>>2] = $389;
 $390 = $389 >>> 2;
 $391 = (($result) + 80|0);
 HEAP32[$391>>2] = $390;
 $392 = ($390*112)|0;
 $393 = (($392) + 131)|0;
 $394 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($11,$393,530456,862)|0);
 $395 = ($394|0)==(0|0);
 if ($395) {
  $404 = 0;
 } else {
  $396 = (($394) + 131|0);
  $397 = $396;
  $398 = $397 & -128;
  $399 = $394;
  $400 = (($398) - ($399))|0;
  $401 = $398;
  $402 = (($401) + -4|0);
  HEAP32[$402>>2] = $400;
  $phitmp$i = $398;
  $404 = $phitmp$i;
 }
 $403 = (($result) + 92|0);
 HEAP32[$403>>2] = $404;
 HEAPF32[$result>>2] = $$$i40195$lcssa;
 $405 = (($result) + 4|0);
 HEAPF32[$405>>2] = $$lcssa;
 $406 = (($result) + 8|0);
 HEAPF32[$406>>2] = $$1$i41196$lcssa;
 $407 = (($result) + 12|0);
 HEAPF32[$407>>2] = Math_fround(0.0);
 $408 = (($result) + 16|0);
 HEAPF32[$408>>2] = $$$i46193$lcssa;
 $409 = (($result) + 20|0);
 HEAPF32[$409>>2] = $$lcssa197;
 $410 = (($result) + 24|0);
 HEAPF32[$410>>2] = $$1$i47194$lcssa;
 $411 = (($result) + 28|0);
 HEAPF32[$411>>2] = Math_fround(0.0);
 $412 = Math_fround($$$i46193$lcssa - $$$i40195$lcssa);
 $413 = Math_fround($$lcssa197 - $$lcssa);
 $414 = Math_fround($$1$i47194$lcssa - $$1$i41196$lcssa);
 $415 = Math_fround($412 * Math_fround(1.52590218931436538696E-5));
 $416 = Math_fround($413 * Math_fround(1.52590218931436538696E-5));
 $417 = Math_fround($414 * Math_fround(1.52590218931436538696E-5));
 $418 = (($result) + 48|0);
 HEAPF32[$418>>2] = $415;
 $419 = (($result) + 52|0);
 HEAPF32[$419>>2] = $416;
 $420 = (($result) + 56|0);
 HEAPF32[$420>>2] = $417;
 $421 = (($result) + 60|0);
 HEAPF32[$421>>2] = Math_fround(0.0);
 $422 = (($result) + 64|0);
 HEAP32[$422>>2] = 4;
 $423 = HEAP32[$maxLevels$i>>2]|0;
 $424 = (($result) + 72|0);
 HEAP32[$424>>2] = $423;
 $425 = (($result) + 88|0);
 HEAP32[$425>>2] = 0;
 $426 = (($result) + 68|0);
 HEAP32[$426>>2] = 1;
 $427 = HEAP32[$391>>2]|0;
 $428 = ($427|0)==(0);
 if (!($428)) {
  $429 = HEAP32[$qtreeNodes$i>>2]|0;
  $j5$036$i = 0;
  while(1) {
   $430 = $j5$036$i << 2;
   $431 = ((($429) + (($430*28)|0)|0) + 12|0);
   $432 = Math_fround(HEAPF32[$431>>2]);
   $433 = ((($404) + (($j5$036$i*112)|0)|0) + 48|0);
   HEAPF32[$433>>2] = $432;
   $434 = ((($429) + (($430*28)|0)|0) + 16|0);
   $435 = Math_fround(HEAPF32[$434>>2]);
   $436 = ((($404) + (($j5$036$i*112)|0)|0) + 64|0);
   HEAPF32[$436>>2] = $435;
   $437 = ((($429) + (($430*28)|0)|0) + 20|0);
   $438 = Math_fround(HEAPF32[$437>>2]);
   $439 = ((($404) + (($j5$036$i*112)|0)|0) + 80|0);
   HEAPF32[$439>>2] = $438;
   $440 = (($429) + (($430*28)|0)|0);
   $441 = Math_fround(HEAPF32[$440>>2]);
   $442 = (($404) + (($j5$036$i*112)|0)|0);
   HEAPF32[$442>>2] = $441;
   $443 = ((($429) + (($430*28)|0)|0) + 4|0);
   $444 = Math_fround(HEAPF32[$443>>2]);
   $445 = ((($404) + (($j5$036$i*112)|0)|0) + 16|0);
   HEAPF32[$445>>2] = $444;
   $446 = ((($429) + (($430*28)|0)|0) + 8|0);
   $447 = Math_fround(HEAPF32[$446>>2]);
   $448 = ((($404) + (($j5$036$i*112)|0)|0) + 32|0);
   HEAPF32[$448>>2] = $447;
   $449 = ((($429) + (($430*28)|0)|0) + 24|0);
   $450 = HEAP32[$449>>2]|0;
   $451 = ((($404) + (($j5$036$i*112)|0)|0) + 96|0);
   HEAP32[$451>>2] = $450;
   $452 = $430 | 1;
   $453 = ((($429) + (($452*28)|0)|0) + 12|0);
   $454 = Math_fround(HEAPF32[$453>>2]);
   $455 = ((($404) + (($j5$036$i*112)|0)|0) + 52|0);
   HEAPF32[$455>>2] = $454;
   $456 = ((($429) + (($452*28)|0)|0) + 16|0);
   $457 = Math_fround(HEAPF32[$456>>2]);
   $458 = ((($404) + (($j5$036$i*112)|0)|0) + 68|0);
   HEAPF32[$458>>2] = $457;
   $459 = ((($429) + (($452*28)|0)|0) + 20|0);
   $460 = Math_fround(HEAPF32[$459>>2]);
   $461 = ((($404) + (($j5$036$i*112)|0)|0) + 84|0);
   HEAPF32[$461>>2] = $460;
   $462 = (($429) + (($452*28)|0)|0);
   $463 = Math_fround(HEAPF32[$462>>2]);
   $464 = ((($404) + (($j5$036$i*112)|0)|0) + 4|0);
   HEAPF32[$464>>2] = $463;
   $465 = ((($429) + (($452*28)|0)|0) + 4|0);
   $466 = Math_fround(HEAPF32[$465>>2]);
   $467 = ((($404) + (($j5$036$i*112)|0)|0) + 20|0);
   HEAPF32[$467>>2] = $466;
   $468 = ((($429) + (($452*28)|0)|0) + 8|0);
   $469 = Math_fround(HEAPF32[$468>>2]);
   $470 = ((($404) + (($j5$036$i*112)|0)|0) + 36|0);
   HEAPF32[$470>>2] = $469;
   $471 = ((($429) + (($452*28)|0)|0) + 24|0);
   $472 = HEAP32[$471>>2]|0;
   $473 = ((($404) + (($j5$036$i*112)|0)|0) + 100|0);
   HEAP32[$473>>2] = $472;
   $474 = $430 | 2;
   $475 = ((($429) + (($474*28)|0)|0) + 12|0);
   $476 = Math_fround(HEAPF32[$475>>2]);
   $477 = ((($404) + (($j5$036$i*112)|0)|0) + 56|0);
   HEAPF32[$477>>2] = $476;
   $478 = ((($429) + (($474*28)|0)|0) + 16|0);
   $479 = Math_fround(HEAPF32[$478>>2]);
   $480 = ((($404) + (($j5$036$i*112)|0)|0) + 72|0);
   HEAPF32[$480>>2] = $479;
   $481 = ((($429) + (($474*28)|0)|0) + 20|0);
   $482 = Math_fround(HEAPF32[$481>>2]);
   $483 = ((($404) + (($j5$036$i*112)|0)|0) + 88|0);
   HEAPF32[$483>>2] = $482;
   $484 = (($429) + (($474*28)|0)|0);
   $485 = Math_fround(HEAPF32[$484>>2]);
   $486 = ((($404) + (($j5$036$i*112)|0)|0) + 8|0);
   HEAPF32[$486>>2] = $485;
   $487 = ((($429) + (($474*28)|0)|0) + 4|0);
   $488 = Math_fround(HEAPF32[$487>>2]);
   $489 = ((($404) + (($j5$036$i*112)|0)|0) + 24|0);
   HEAPF32[$489>>2] = $488;
   $490 = ((($429) + (($474*28)|0)|0) + 8|0);
   $491 = Math_fround(HEAPF32[$490>>2]);
   $492 = ((($404) + (($j5$036$i*112)|0)|0) + 40|0);
   HEAPF32[$492>>2] = $491;
   $493 = ((($429) + (($474*28)|0)|0) + 24|0);
   $494 = HEAP32[$493>>2]|0;
   $495 = ((($404) + (($j5$036$i*112)|0)|0) + 104|0);
   HEAP32[$495>>2] = $494;
   $496 = $430 | 3;
   $497 = ((($429) + (($496*28)|0)|0) + 12|0);
   $498 = Math_fround(HEAPF32[$497>>2]);
   $499 = ((($404) + (($j5$036$i*112)|0)|0) + 60|0);
   HEAPF32[$499>>2] = $498;
   $500 = ((($429) + (($496*28)|0)|0) + 16|0);
   $501 = Math_fround(HEAPF32[$500>>2]);
   $502 = ((($404) + (($j5$036$i*112)|0)|0) + 76|0);
   HEAPF32[$502>>2] = $501;
   $503 = ((($429) + (($496*28)|0)|0) + 20|0);
   $504 = Math_fround(HEAPF32[$503>>2]);
   $505 = ((($404) + (($j5$036$i*112)|0)|0) + 92|0);
   HEAPF32[$505>>2] = $504;
   $506 = (($429) + (($496*28)|0)|0);
   $507 = Math_fround(HEAPF32[$506>>2]);
   $508 = ((($404) + (($j5$036$i*112)|0)|0) + 12|0);
   HEAPF32[$508>>2] = $507;
   $509 = ((($429) + (($496*28)|0)|0) + 4|0);
   $510 = Math_fround(HEAPF32[$509>>2]);
   $511 = ((($404) + (($j5$036$i*112)|0)|0) + 28|0);
   HEAPF32[$511>>2] = $510;
   $512 = ((($429) + (($496*28)|0)|0) + 8|0);
   $513 = Math_fround(HEAPF32[$512>>2]);
   $514 = ((($404) + (($j5$036$i*112)|0)|0) + 44|0);
   HEAPF32[$514>>2] = $513;
   $515 = ((($429) + (($496*28)|0)|0) + 24|0);
   $516 = HEAP32[$515>>2]|0;
   $517 = ((($404) + (($j5$036$i*112)|0)|0) + 108|0);
   HEAP32[$517>>2] = $516;
   $518 = (($j5$036$i) + 1)|0;
   $519 = HEAP32[$391>>2]|0;
   $520 = ($518>>>0)<($519>>>0);
   if ($520) {
    $j5$036$i = $518;
   } else {
    break;
   }
  }
 }
 $521 = HEAP32[$333>>2]|0;
 $522 = $521 & 2147483647;
 $523 = ($522|0)!=(0);
 $524 = ($521|0)>(-1);
 $or$cond$i$i4$i = $523 & $524;
 if ($or$cond$i$i4$i) {
  $525 = HEAP32[$qtreeNodes$i>>2]|0;
  $526 = ($525|0)==(0|0);
  if (!($526)) {
   $527 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $528 = HEAP32[$527>>2]|0;
   $529 = (($528) + 12|0);
   $530 = HEAP32[$529>>2]|0;
   FUNCTION_TABLE_vii[$530 & 4095]($527,$525);
  }
 }
 $531 = HEAP32[$191>>2]|0;
 $532 = $531 & 2147483647;
 $533 = ($532|0)!=(0);
 $534 = ($531|0)>(-1);
 $or$cond$i$i$i = $533 & $534;
 if ($or$cond$i$i$i) {
  $535 = HEAP32[$resultTree$i>>2]|0;
  $536 = ($535|0)==(0|0);
  if (!($536)) {
   $537 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $538 = HEAP32[$537>>2]|0;
   $539 = (($538) + 12|0);
   $540 = HEAP32[$539>>2]|0;
   FUNCTION_TABLE_vii[$540 & 4095]($537,$535);
  }
 }
 $541 = HEAP32[$14>>2]|0;
 $542 = $541 & 2147483647;
 $543 = ($542|0)!=(0);
 $544 = ($541|0)>(-1);
 $or$cond$i$i = $543 & $544;
 if (!($or$cond$i$i)) {
  STACKTOP = sp;return;
 }
 $545 = HEAP32[$allBounds>>2]|0;
 $546 = ($545|0)==(0|0);
 if ($546) {
  STACKTOP = sp;return;
 }
 $547 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $548 = HEAP32[$547>>2]|0;
 $549 = (($548) + 12|0);
 $550 = HEAP32[$549>>2]|0;
 FUNCTION_TABLE_vii[$550 & 4095]($547,$545);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_10PxBounds3VENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 5;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 530344 : 530312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,530232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<5)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;HEAP32[$$012$i+24>>2]=HEAP32[$$03$i+24>>2]|0;HEAP32[$$012$i+28>>2]=HEAP32[$$03$i+28>>2]|0;
   }
   $25 = (($$012$i) + 32|0);
   $26 = (($$03$i) + 32|0);
   $27 = ($25>>>0)<($20>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $19;
 }
 $28 = (($21) + ($29<<5)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  ;HEAP32[$28+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$28+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$28+20>>2]=HEAP32[$a+20>>2]|0;HEAP32[$28+24>>2]=HEAP32[$a+24>>2]|0;HEAP32[$28+28>>2]=HEAP32[$a+28>>2]|0;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if (!($32)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $39 = HEAP32[$18>>2]|0;
  $40 = (($39) + 1)|0;
  HEAP32[$18>>2] = $40;
  $41 = (($21) + ($39<<5)|0);
  STACKTOP = sp;return ($41|0);
 }
 $33 = HEAP32[$this>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $39 = HEAP32[$18>>2]|0;
  $40 = (($39) + 1)|0;
  HEAP32[$18>>2] = $40;
  $41 = (($21) + ($39<<5)|0);
  STACKTOP = sp;return ($41|0);
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = HEAP32[$18>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$18>>2] = $40;
 $41 = (($21) + ($39<<5)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayINS_10PxBounds3VENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 530344 : 530312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,530232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<5)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;HEAP32[$$012$i+24>>2]=HEAP32[$$03$i+24>>2]|0;HEAP32[$$012$i+28>>2]=HEAP32[$$03$i+28>>2]|0;
   }
   $20 = (($$012$i) + 32|0);
   $21 = (($$03$i) + 32|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx10SubSortSAH5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjjPS4_($this,$permute,$clusterSize,$resultTree,$maxLevels,$level,$parentNode) {
 $this = $this|0;
 $permute = $permute|0;
 $clusterSize = $clusterSize|0;
 $resultTree = $resultTree|0;
 $maxLevels = $maxLevels|0;
 $level = $level|0;
 $parentNode = $parentNode|0;
 var $$$i$i = Math_fround(0), $$$i$i21 = Math_fround(0), $$$i12$i = Math_fround(0), $$$i1270$lcssa$i = Math_fround(0), $$$i127078$i = Math_fround(0), $$$i72$lcssa$i = Math_fround(0), $$$i7276$i = Math_fround(0), $$$i8$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i$i22 = Math_fround(0), $$1$i13$i = Math_fround(0), $$1$i1371$lcssa$i = Math_fround(0), $$1$i137177$i = Math_fround(0), $$1$i73$lcssa$i = Math_fround(0), $$1$i7375$i = Math_fround(0), $$1$i9$i = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa$i = Math_fround(0), $$lcssa30 = Math_fround(0), $$lcssa31 = Math_fround(0);
 var $$lcssa32 = Math_fround(0), $$lcssa33 = Math_fround(0), $$lcssa34 = Math_fround(0), $$lcssa35 = Math_fround(0), $$lcssa74$i = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i17 = 0, $$pre$phiZ2D = 0, $$pre86 = 0, $$pre87 = 0, $$pre88 = 0, $$pre89 = 0, $$pre92 = 0, $$pre93 = 0, $$terminalClusterByTotalCount$0$off0 = 0, $$terminalClusterByTotalCount$0$off0$1 = 0, $$terminalClusterByTotalCount$0$off0$2 = 0;
 var $$terminalClusterByTotalCount$0$off0$3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0);
 var $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0;
 var $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0);
 var $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0;
 var $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $exitcond = 0, $exitcond74 = 0, $exitcond82 = 0;
 var $exitcond83 = 0, $exitcond84 = 0, $i$056 = 0, $i$079$i = 0, $i2$067 = 0, $i5$037 = 0, $iSplit$065 = 0, $maxSAH$059 = Math_fround(0), $maxSAH$1 = Math_fround(0), $maxSplit$0$lcssa = 0, $maxSplit$058 = 0, $maxSplit$1 = 0, $not$ = 0, $not$$1 = 0, $not$$2 = 0, $not$$3 = 0, $or$cond = 0, $or$cond$i$i$i = 0, $rtn = 0, $s4$046 = 0;
 var $sahMax$0$lcssa = Math_fround(0), $sahMax$036 = Math_fround(0), $scevgep = 0, $splitCounts = 0, $splitPos = 0, $splitStarts = 0, $splits = 0, $storemerge = 0, $terminalClusterByTotalCount$2$off045 = 0, $terminalClusterByTotalCount$3$off0 = 0, $terminalClusterByTotalCount$4$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 152|0;
 $1 = sp + 153|0;
 $splitPos = sp + 136|0;
 $splits = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp + 64|0;
 $4 = sp;
 $splitStarts = sp + 104|0;
 $splitCounts = sp + 120|0;
 $rtn = sp + 72|0;
 $5 = ($level|0)==(0);
 if ($5) {
  $storemerge = 1;
 } else {
  $6 = HEAP32[$maxLevels>>2]|0;
  $7 = (($level) + 1)|0;
  $8 = ($6>>>0)<($7>>>0);
  $9 = $8 ? $7 : $6;
  $storemerge = $9;
 }
 HEAP32[$maxLevels>>2] = $storemerge;
 HEAP32[$splitPos>>2] = 1;
 $10 = (($splitPos) + 4|0);
 HEAP32[$10>>2] = 2;
 $11 = (($splitPos) + 8|0);
 HEAP32[$11>>2] = 3;
 $12 = (($splitPos) + 12|0);
 HEAP32[$12>>2] = 4;
 $13 = ($clusterSize>>>0)>(3);
 do {
  if ($13) {
   $15 = (($splits) + 32|0);
   $16 = (($splits) + 36|0);
   $17 = (($splits) + 40|0);
   $18 = (($splits) + 44|0);
   HEAP8[$15>>0] = 1;
   HEAP32[$16>>2] = $splits;
   HEAP32[$18>>2] = 4;
   HEAP32[$2>>2] = 0;
   $19 = (($2) + 4|0);
   HEAP32[$19>>2] = $clusterSize;
   $20 = $2;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $splits;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$17>>2] = 1;
   $30 = (($3) + 4|0);
   $31 = (($4) + 4|0);
   $32 = (($this) + 8|0);
   $iSplit$065 = 0;
   while(1) {
    $33 = HEAP32[$17>>2]|0;
    $34 = ($33|0)==(0);
    $35 = HEAP32[$16>>2]|0;
    if ($34) {
     $maxSplit$0$lcssa = -1;
    } else {
     $i$056 = 0;$maxSAH$059 = Math_fround(-3.40282346638528859812E+38);$maxSplit$058 = -1;
     while(1) {
      $40 = ((($35) + ($i$056<<3)|0) + 4|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41|0)==(1);
      if ($42) {
       $maxSAH$1 = $maxSAH$059;$maxSplit$1 = $maxSplit$058;
      } else {
       $43 = (($35) + ($i$056<<3)|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = (($permute) + ($44<<2)|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = HEAP32[$32>>2]|0;
       $48 = (($47) + ($46<<5)|0);
       $49 = Math_fround(HEAPF32[$48>>2]);
       $50 = ((($47) + ($46<<5)|0) + 4|0);
       $51 = Math_fround(HEAPF32[$50>>2]);
       $52 = ((($47) + ($46<<5)|0) + 8|0);
       $53 = Math_fround(HEAPF32[$52>>2]);
       $54 = ((($47) + ($46<<5)|0) + 16|0);
       $55 = Math_fround(HEAPF32[$54>>2]);
       $56 = ((($47) + ($46<<5)|0) + 20|0);
       $57 = Math_fround(HEAPF32[$56>>2]);
       $58 = ((($47) + ($46<<5)|0) + 24|0);
       $59 = Math_fround(HEAPF32[$58>>2]);
       $60 = ($41>>>0)>(1);
       if ($60) {
        $$$i127078$i = $55;$$$i7276$i = $49;$$1$i137177$i = $59;$$1$i7375$i = $53;$72 = $51;$83 = $57;$i$079$i = 1;
        while(1) {
         $61 = (($i$079$i) + ($44))|0;
         $62 = (($permute) + ($61<<2)|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = (($47) + ($63<<5)|0);
         $65 = Math_fround(HEAPF32[$64>>2]);
         $66 = ((($47) + ($63<<5)|0) + 4|0);
         $67 = Math_fround(HEAPF32[$66>>2]);
         $68 = ((($47) + ($63<<5)|0) + 8|0);
         $69 = Math_fround(HEAPF32[$68>>2]);
         $70 = $$$i7276$i < $65;
         $$$i$i21 = $70 ? $$$i7276$i : $65;
         $71 = $72 < $67;
         $73 = $71 ? $72 : $67;
         $74 = $$1$i7375$i < $69;
         $$1$i$i22 = $74 ? $$1$i7375$i : $69;
         $75 = ((($47) + ($63<<5)|0) + 16|0);
         $76 = Math_fround(HEAPF32[$75>>2]);
         $77 = ((($47) + ($63<<5)|0) + 20|0);
         $78 = Math_fround(HEAPF32[$77>>2]);
         $79 = ((($47) + ($63<<5)|0) + 24|0);
         $80 = Math_fround(HEAPF32[$79>>2]);
         $81 = $$$i127078$i > $76;
         $$$i12$i = $81 ? $$$i127078$i : $76;
         $82 = $83 > $78;
         $84 = $82 ? $83 : $78;
         $85 = $$1$i137177$i > $80;
         $$1$i13$i = $85 ? $$1$i137177$i : $80;
         $86 = (($i$079$i) + 1)|0;
         $exitcond82 = ($86|0)==($41|0);
         if ($exitcond82) {
          $$$i1270$lcssa$i = $$$i12$i;$$$i72$lcssa$i = $$$i$i21;$$1$i1371$lcssa$i = $$1$i13$i;$$1$i73$lcssa$i = $$1$i$i22;$$lcssa$i = $73;$$lcssa74$i = $84;
          break;
         } else {
          $$$i127078$i = $$$i12$i;$$$i7276$i = $$$i$i21;$$1$i137177$i = $$1$i13$i;$$1$i7375$i = $$1$i$i22;$72 = $73;$83 = $84;$i$079$i = $86;
         }
        }
       } else {
        $$$i1270$lcssa$i = $55;$$$i72$lcssa$i = $49;$$1$i1371$lcssa$i = $59;$$1$i73$lcssa$i = $53;$$lcssa$i = $51;$$lcssa74$i = $57;
       }
       $87 = Math_fround($$$i1270$lcssa$i - $$$i72$lcssa$i);
       $88 = Math_fround($$lcssa74$i - $$lcssa$i);
       $89 = Math_fround($$1$i1371$lcssa$i - $$1$i73$lcssa$i);
       $90 = Math_fround($87 * $89);
       $91 = Math_fround($87 * $88);
       $92 = Math_fround($91 + $90);
       $93 = Math_fround($88 * $89);
       $94 = Math_fround($93 + $92);
       $95 = (Math_fround(($41>>>0)));
       $96 = Math_fround($95 * $94);
       $97 = $96 > $maxSAH$059;
       if ($97) {
        $maxSAH$1 = $96;$maxSplit$1 = $i$056;
       } else {
        $maxSAH$1 = $maxSAH$059;$maxSplit$1 = $maxSplit$058;
       }
      }
      $98 = (($i$056) + 1)|0;
      $99 = ($98>>>0)<($33>>>0);
      if ($99) {
       $i$056 = $98;$maxSAH$059 = $maxSAH$1;$maxSplit$058 = $maxSplit$1;
      } else {
       $maxSplit$0$lcssa = $maxSplit$1;
       break;
      }
     }
    }
    $100 = (($35) + ($maxSplit$0$lcssa<<3)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($35) + ($maxSplit$0$lcssa<<3)|0) + 4|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($permute) + ($101<<2)|0);
    $105 = (__ZN5physx10SubSortSAH5splitEPjj($this,$104,$103)|0);
    HEAP32[$3>>2] = $101;
    HEAP32[$30>>2] = $105;
    $106 = HEAP32[$18>>2]|0;
    $107 = $106 & 2147483647;
    $108 = HEAP32[$17>>2]|0;
    $109 = ($107>>>0)>($108>>>0);
    if ($109) {
     $110 = HEAP32[$16>>2]|0;
     $111 = (($110) + ($108<<3)|0);
     $112 = ($111|0)==(0|0);
     if ($112) {
      $124 = $108;
     } else {
      $113 = $3;
      $114 = $113;
      $115 = HEAP32[$114>>2]|0;
      $116 = (($113) + 4)|0;
      $117 = $116;
      $118 = HEAP32[$117>>2]|0;
      $119 = $111;
      $120 = $119;
      HEAP32[$120>>2] = $115;
      $121 = (($119) + 4)|0;
      $122 = $121;
      HEAP32[$122>>2] = $118;
      $$pre$i17 = HEAP32[$17>>2]|0;
      $124 = $$pre$i17;
     }
     $123 = (($124) + 1)|0;
     HEAP32[$17>>2] = $123;
     $130 = $123;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_8IntervalENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE15growAndPushBackERKS2_($splits,$3)|0);
     $$pre = HEAP32[$17>>2]|0;
     $130 = $$pre;
    }
    $125 = (($105) + ($101))|0;
    $126 = (($103) - ($105))|0;
    HEAP32[$4>>2] = $125;
    HEAP32[$31>>2] = $126;
    $127 = HEAP32[$18>>2]|0;
    $128 = $127 & 2147483647;
    $129 = ($128>>>0)>($130>>>0);
    if ($129) {
     $131 = HEAP32[$16>>2]|0;
     $132 = (($131) + ($130<<3)|0);
     $133 = ($132|0)==(0|0);
     if ($133) {
      $145 = $130;
     } else {
      $134 = $4;
      $135 = $134;
      $136 = HEAP32[$135>>2]|0;
      $137 = (($134) + 4)|0;
      $138 = $137;
      $139 = HEAP32[$138>>2]|0;
      $140 = $132;
      $141 = $140;
      HEAP32[$141>>2] = $136;
      $142 = (($140) + 4)|0;
      $143 = $142;
      HEAP32[$143>>2] = $139;
      $$pre$i13 = HEAP32[$17>>2]|0;
      $145 = $$pre$i13;
     }
     $144 = (($145) + 1)|0;
     HEAP32[$17>>2] = $144;
     $149 = $144;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_8IntervalENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE15growAndPushBackERKS2_($splits,$4)|0);
     $$pre86 = HEAP32[$17>>2]|0;
     $149 = $$pre86;
    }
    $146 = HEAP32[$16>>2]|0;
    $147 = (($146) + ($maxSplit$0$lcssa<<3)|0);
    $148 = (($149) + -1)|0;
    HEAP32[$17>>2] = $148;
    $150 = (($146) + ($148<<3)|0);
    $151 = $150;
    $152 = $151;
    $153 = HEAP32[$152>>2]|0;
    $154 = (($151) + 4)|0;
    $155 = $154;
    $156 = HEAP32[$155>>2]|0;
    $157 = $147;
    $158 = $157;
    HEAP32[$158>>2] = $153;
    $159 = (($157) + 4)|0;
    $160 = $159;
    HEAP32[$160>>2] = $156;
    $161 = (($splitPos) + ($iSplit$065<<2)|0);
    HEAP32[$161>>2] = $125;
    $162 = (($iSplit$065) + 1)|0;
    $exitcond83 = ($162|0)==(3);
    if ($exitcond83) {
     break;
    } else {
     $iSplit$065 = $162;
    }
   }
   $36 = HEAP32[$18>>2]|0;
   $37 = $36 & 2147483647;
   $38 = ($37|0)!=(0);
   $39 = ($36|0)>(-1);
   $or$cond$i$i$i = $38 & $39;
   if ($or$cond$i$i$i) {
    $163 = HEAP32[$16>>2]|0;
    $164 = ($splits|0)==($163|0);
    if ($164) {
     HEAP8[$15>>0] = 0;
     $$pre$phiZ2D = $32;
     break;
    }
    $165 = ($163|0)==(0|0);
    if ($165) {
     $$pre$phiZ2D = $32;
    } else {
     $166 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $167 = HEAP32[$166>>2]|0;
     $168 = (($167) + 12|0);
     $169 = HEAP32[$168>>2]|0;
     FUNCTION_TABLE_vii[$169 & 4095]($166,$163);
     $$pre$phiZ2D = $32;
    }
   } else {
    $$pre$phiZ2D = $32;
   }
  } else {
   $14 = ($clusterSize>>>0)<(3);
   if ($14) {
    $i2$067 = $clusterSize;
    while(1) {
     $170 = (($splitPos) + ($i2$067<<2)|0);
     HEAP32[$170>>2] = $clusterSize;
     $171 = (($i2$067) + 1)|0;
     $exitcond84 = ($171|0)==(3);
     if ($exitcond84) {
      break;
     } else {
      $i2$067 = $171;
     }
    }
   }
   $$pre93 = (($this) + 8|0);
   $$pre$phiZ2D = $$pre93;
  }
 } while(0);
 __ZN5physx6shdfnd4sortIjNS0_4LessIjEENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($splitPos,3,$0,$1);
 HEAP32[$12>>2] = $clusterSize;
 HEAP32[$splitStarts>>2] = 0;
 $172 = HEAP32[$splitPos>>2]|0;
 HEAP32[$splitCounts>>2] = $172;
 $scevgep = (($splitStarts) + 4|0);
 ;HEAP32[$scevgep+0>>2]=HEAP32[$splitPos+0>>2]|0;HEAP32[$scevgep+4>>2]=HEAP32[$splitPos+4>>2]|0;HEAP32[$scevgep+8>>2]=HEAP32[$splitPos+8>>2]|0;
 $173 = HEAP32[$10>>2]|0;
 $174 = (($173) - ($172))|0;
 $175 = (($splitCounts) + 4|0);
 HEAP32[$175>>2] = $174;
 $176 = HEAP32[$11>>2]|0;
 $177 = (($176) - ($173))|0;
 $178 = (($splitCounts) + 8|0);
 HEAP32[$178>>2] = $177;
 $179 = (($clusterSize) - ($176))|0;
 $180 = (($splitCounts) + 12|0);
 HEAP32[$180>>2] = $179;
 $181 = (($this) + 52|0);
 $182 = HEAP32[$181>>2]|0;
 $183 = (530664 + ($182<<2)|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = ($184>>>0)>=($clusterSize>>>0);
 $not$ = ($172>>>0)<(17);
 $$terminalClusterByTotalCount$0$off0 = $185 & $not$;
 $not$$1 = ($174>>>0)<(17);
 $$terminalClusterByTotalCount$0$off0$1 = $$terminalClusterByTotalCount$0$off0 & $not$$1;
 $not$$2 = ($177>>>0)<(17);
 $$terminalClusterByTotalCount$0$off0$2 = $$terminalClusterByTotalCount$0$off0$1 & $not$$2;
 $not$$3 = ($179>>>0)<(17);
 $$terminalClusterByTotalCount$0$off0$3 = $$terminalClusterByTotalCount$0$off0$2 & $not$$3;
 $186 = (($rtn) + 4|0);
 $187 = (($rtn) + 8|0);
 $188 = (($rtn) + 12|0);
 $189 = (($rtn) + 16|0);
 $190 = (($rtn) + 20|0);
 $191 = (($rtn) + 24|0);
 $192 = (($rtn) + 28|0);
 $193 = (($resultTree) + 8|0);
 $194 = (($resultTree) + 4|0);
 $195 = $permute;
 $197 = $172;$s4$046 = 0;$terminalClusterByTotalCount$2$off045 = $$terminalClusterByTotalCount$0$off0$3;
 while(1) {
  HEAPF32[$rtn>>2] = Math_fround(8.50705866596322149529E+37);
  HEAPF32[$186>>2] = Math_fround(8.50705866596322149529E+37);
  HEAPF32[$187>>2] = Math_fround(8.50705866596322149529E+37);
  HEAPF32[$188>>2] = Math_fround(-8.50705866596322149529E+37);
  HEAPF32[$189>>2] = Math_fround(-8.50705866596322149529E+37);
  HEAPF32[$190>>2] = Math_fround(-8.50705866596322149529E+37);
  HEAP32[$191>>2] = -1;
  HEAP32[$192>>2] = 0;
  $196 = ($197|0)==(0);
  do {
   if ($196) {
    HEAPF32[$rtn>>2] = Math_fround(8.50705866596322149529E+37);
    HEAPF32[$186>>2] = Math_fround(8.50705866596322149529E+37);
    HEAPF32[$187>>2] = Math_fround(8.50705866596322149529E+37);
    HEAPF32[$188>>2] = Math_fround(-8.50705866596322149529E+37);
    HEAPF32[$189>>2] = Math_fround(-8.50705866596322149529E+37);
    HEAPF32[$190>>2] = Math_fround(-8.50705866596322149529E+37);
    HEAP32[$191>>2] = -1;
    HEAP32[$192>>2] = -1;
    $287 = Math_fround(8.50705866596322149529E+37);$289 = Math_fround(8.50705866596322149529E+37);$291 = Math_fround(8.50705866596322149529E+37);$293 = Math_fround(-8.50705866596322149529E+37);$295 = Math_fround(-8.50705866596322149529E+37);$297 = Math_fround(-8.50705866596322149529E+37);$terminalClusterByTotalCount$4$off0 = $terminalClusterByTotalCount$2$off045;
   } else {
    $198 = (($splitStarts) + ($s4$046<<2)|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = (($permute) + ($199<<2)|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = HEAP32[$$pre$phiZ2D>>2]|0;
    $203 = (($202) + ($201<<5)|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = ((($202) + ($201<<5)|0) + 4|0);
    $206 = Math_fround(HEAPF32[$205>>2]);
    $207 = ((($202) + ($201<<5)|0) + 8|0);
    $208 = Math_fround(HEAPF32[$207>>2]);
    $209 = ((($202) + ($201<<5)|0) + 16|0);
    $210 = Math_fround(HEAPF32[$209>>2]);
    $211 = ((($202) + ($201<<5)|0) + 20|0);
    $212 = Math_fround(HEAPF32[$211>>2]);
    $213 = ((($202) + ($201<<5)|0) + 24|0);
    $214 = Math_fround(HEAPF32[$213>>2]);
    $215 = Math_fround($210 - $204);
    $216 = Math_fround($212 - $206);
    $217 = Math_fround($214 - $208);
    $218 = Math_fround($215 * $217);
    $219 = Math_fround($215 * $216);
    $220 = Math_fround($219 + $218);
    $221 = Math_fround($216 * $217);
    $222 = Math_fround($221 + $220);
    $223 = ($197>>>0)>(1);
    if ($223) {
     $248 = $222;$253 = $204;$255 = $206;$258 = $208;$260 = $210;$262 = $212;$265 = $214;$i5$037 = 1;$sahMax$036 = $222;
     while(1) {
      $224 = (($199) + ($i5$037))|0;
      $225 = (($permute) + ($224<<2)|0);
      $226 = HEAP32[$225>>2]|0;
      $227 = ((($202) + ($226<<5)|0) + 16|0);
      $228 = Math_fround(HEAPF32[$227>>2]);
      $229 = ((($202) + ($226<<5)|0) + 20|0);
      $230 = Math_fround(HEAPF32[$229>>2]);
      $231 = ((($202) + ($226<<5)|0) + 24|0);
      $232 = Math_fround(HEAPF32[$231>>2]);
      $233 = (($202) + ($226<<5)|0);
      $234 = Math_fround(HEAPF32[$233>>2]);
      $235 = ((($202) + ($226<<5)|0) + 4|0);
      $236 = Math_fround(HEAPF32[$235>>2]);
      $237 = ((($202) + ($226<<5)|0) + 8|0);
      $238 = Math_fround(HEAPF32[$237>>2]);
      $239 = Math_fround($228 - $234);
      $240 = Math_fround($230 - $236);
      $241 = Math_fround($232 - $238);
      $242 = Math_fround($239 * $241);
      $243 = Math_fround($239 * $240);
      $244 = Math_fround($243 + $242);
      $245 = Math_fround($240 * $241);
      $246 = Math_fround($245 + $244);
      $247 = $248 < $246;
      $249 = $247 ? $248 : $246;
      $250 = $sahMax$036 > $246;
      $251 = $250 ? $sahMax$036 : $246;
      $252 = $253 < $234;
      $$$i$i = $252 ? $253 : $234;
      $254 = $255 < $236;
      $256 = $254 ? $255 : $236;
      $257 = $258 < $238;
      $$1$i$i = $257 ? $258 : $238;
      $259 = $260 > $228;
      $$$i8$i = $259 ? $260 : $228;
      $261 = $262 > $230;
      $263 = $261 ? $262 : $230;
      $264 = $265 > $232;
      $$1$i9$i = $264 ? $265 : $232;
      $266 = (($i5$037) + 1)|0;
      $exitcond = ($266|0)==($197|0);
      if ($exitcond) {
       $$lcssa = $$1$i9$i;$$lcssa30 = $263;$$lcssa31 = $$$i8$i;$$lcssa32 = $$1$i$i;$$lcssa33 = $256;$$lcssa34 = $$$i$i;$$lcssa35 = $249;$sahMax$0$lcssa = $251;
       break;
      } else {
       $248 = $249;$253 = $$$i$i;$255 = $256;$258 = $$1$i$i;$260 = $$$i8$i;$262 = $263;$265 = $$1$i9$i;$i5$037 = $266;$sahMax$036 = $251;
      }
     }
    } else {
     $$lcssa = $214;$$lcssa30 = $212;$$lcssa31 = $210;$$lcssa32 = $208;$$lcssa33 = $206;$$lcssa34 = $204;$$lcssa35 = $222;$sahMax$0$lcssa = $222;
    }
    HEAPF32[$rtn>>2] = $$lcssa34;
    HEAPF32[$186>>2] = $$lcssa33;
    HEAPF32[$187>>2] = $$lcssa32;
    HEAPF32[$188>>2] = $$lcssa31;
    HEAPF32[$189>>2] = $$lcssa30;
    HEAPF32[$190>>2] = $$lcssa;
    $267 = Math_fround($sahMax$0$lcssa / $$lcssa35);
    $268 = $267 < Math_fround(40.0);
    $terminalClusterByTotalCount$3$off0 = $268 & $terminalClusterByTotalCount$2$off045;
    $269 = ($197>>>0)<(3);
    if (!($269)) {
     $270 = ($197>>>0)<(4);
     $or$cond = $268 & $270;
     $brmerge = $or$cond | $terminalClusterByTotalCount$3$off0;
     if (!($brmerge)) {
      $271 = HEAP32[$181>>2]|0;
      $272 = (530728 + ($271<<2)|0);
      $273 = HEAP32[$272>>2]|0;
      $274 = ($197>>>0)>($273>>>0);
      if ($274) {
       HEAP32[$191>>2] = -1;
       HEAP32[$192>>2] = 0;
       $287 = $$lcssa34;$289 = $$lcssa33;$291 = $$lcssa32;$293 = $$lcssa31;$295 = $$lcssa30;$297 = $$lcssa;$terminalClusterByTotalCount$4$off0 = 0;
       break;
      }
     }
    }
    $275 = HEAP32[$this>>2]|0;
    $276 = $275;
    $277 = (($195) - ($276))|0;
    $278 = $277 >> 2;
    $279 = (($278) + ($199))|0;
    HEAP32[$191>>2] = $279;
    HEAP32[$192>>2] = $197;
    $287 = $$lcssa34;$289 = $$lcssa33;$291 = $$lcssa32;$293 = $$lcssa31;$295 = $$lcssa30;$297 = $$lcssa;$terminalClusterByTotalCount$4$off0 = $terminalClusterByTotalCount$3$off0;
   }
  } while(0);
  $280 = HEAP32[$193>>2]|0;
  $281 = $280 & 2147483647;
  $282 = HEAP32[$194>>2]|0;
  $283 = ($281>>>0)>($282>>>0);
  if ($283) {
   $284 = HEAP32[$resultTree>>2]|0;
   $285 = (($284) + ($282<<5)|0);
   $286 = ($285|0)==(0|0);
   if ($286) {
    $310 = $282;
   } else {
    HEAPF32[$285>>2] = $287;
    $288 = ((($284) + ($282<<5)|0) + 4|0);
    HEAPF32[$288>>2] = $289;
    $290 = ((($284) + ($282<<5)|0) + 8|0);
    HEAPF32[$290>>2] = $291;
    $292 = ((($284) + ($282<<5)|0) + 12|0);
    HEAPF32[$292>>2] = $293;
    $294 = ((($284) + ($282<<5)|0) + 16|0);
    HEAPF32[$294>>2] = $295;
    $296 = ((($284) + ($282<<5)|0) + 20|0);
    HEAPF32[$296>>2] = $297;
    $298 = ((($284) + ($282<<5)|0) + 24|0);
    $299 = $191;
    $300 = $299;
    $301 = HEAP32[$300>>2]|0;
    $302 = (($299) + 4)|0;
    $303 = $302;
    $304 = HEAP32[$303>>2]|0;
    $305 = $298;
    $306 = $305;
    HEAP32[$306>>2] = $301;
    $307 = (($305) + 4)|0;
    $308 = $307;
    HEAP32[$308>>2] = $304;
    $$pre$i = HEAP32[$194>>2]|0;
    $310 = $$pre$i;
   }
   $309 = (($310) + 1)|0;
   HEAP32[$194>>2] = $309;
  } else {
   (__ZN5physx6shdfnd5ArrayINS_11RTreeNodeNQENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($resultTree,$rtn)|0);
  }
  $311 = (($s4$046) + 1)|0;
  $exitcond74 = ($311|0)==(4);
  if ($exitcond74) {
   break;
  }
  $$phi$trans$insert = (($splitCounts) + ($311<<2)|0);
  $$pre92 = HEAP32[$$phi$trans$insert>>2]|0;
  $197 = $$pre92;$s4$046 = $311;$terminalClusterByTotalCount$2$off045 = $terminalClusterByTotalCount$4$off0;
 }
 if ($terminalClusterByTotalCount$4$off0) {
  STACKTOP = sp;return;
 }
 $312 = HEAP32[$194>>2]|0;
 $313 = (($312) + -4)|0;
 $314 = (($level) + 1)|0;
 $315 = HEAP32[$resultTree>>2]|0;
 $316 = ((($315) + ($313<<5)|0) + 28|0);
 $317 = HEAP32[$316>>2]|0;
 $318 = ($317|0)==(0);
 if ($318) {
  $319 = (($315) + ($313<<5)|0);
  $320 = ((($315) + ($313<<5)|0) + 24|0);
  HEAP32[$320>>2] = $312;
  __ZN5physx10SubSortSAH5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjjPS4_($this,$permute,$172,$resultTree,$maxLevels,$314,$319);
  $$pre87 = HEAP32[$resultTree>>2]|0;
  $323 = $$pre87;
 } else {
  $323 = $315;
 }
 $321 = (($312) + -3)|0;
 $322 = ((($323) + ($321<<5)|0) + 28|0);
 $324 = HEAP32[$322>>2]|0;
 $325 = ($324|0)==(0);
 if ($325) {
  $326 = (($323) + ($321<<5)|0);
  $327 = HEAP32[$194>>2]|0;
  $328 = ((($323) + ($321<<5)|0) + 24|0);
  HEAP32[$328>>2] = $327;
  $329 = HEAP32[$scevgep>>2]|0;
  $330 = (($permute) + ($329<<2)|0);
  __ZN5physx10SubSortSAH5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjjPS4_($this,$330,$174,$resultTree,$maxLevels,$314,$326);
  $$pre88 = HEAP32[$resultTree>>2]|0;
  $333 = $$pre88;
 } else {
  $333 = $323;
 }
 $331 = (($312) + -2)|0;
 $332 = ((($333) + ($331<<5)|0) + 28|0);
 $334 = HEAP32[$332>>2]|0;
 $335 = ($334|0)==(0);
 if ($335) {
  $336 = (($333) + ($331<<5)|0);
  $337 = HEAP32[$194>>2]|0;
  $338 = ((($333) + ($331<<5)|0) + 24|0);
  HEAP32[$338>>2] = $337;
  $339 = (($splitStarts) + 8|0);
  $340 = HEAP32[$339>>2]|0;
  $341 = (($permute) + ($340<<2)|0);
  $342 = HEAP32[$178>>2]|0;
  __ZN5physx10SubSortSAH5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjjPS4_($this,$341,$342,$resultTree,$maxLevels,$314,$336);
  $$pre89 = HEAP32[$resultTree>>2]|0;
  $345 = $$pre89;
 } else {
  $345 = $333;
 }
 $343 = (($312) + -1)|0;
 $344 = ((($345) + ($343<<5)|0) + 28|0);
 $346 = HEAP32[$344>>2]|0;
 $347 = ($346|0)==(0);
 if (!($347)) {
  STACKTOP = sp;return;
 }
 $348 = (($345) + ($343<<5)|0);
 $349 = HEAP32[$194>>2]|0;
 $350 = ((($345) + ($343<<5)|0) + 24|0);
 HEAP32[$350>>2] = $349;
 $351 = (($splitStarts) + 12|0);
 $352 = HEAP32[$351>>2]|0;
 $353 = (($permute) + ($352<<2)|0);
 $354 = HEAP32[$180>>2]|0;
 __ZN5physx10SubSortSAH5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjjPS4_($this,$353,$354,$resultTree,$maxLevels,$314,$348);
 STACKTOP = sp;return;
}
function __ZN5physx12SubSortQuick5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjRNS_10PxBounds3VEj($this,$permute,$clusterSize,$resultTree,$maxLevels,$subTreeBound,$level) {
 $this = $this|0;
 $permute = $permute|0;
 $clusterSize = $clusterSize|0;
 $resultTree = $resultTree|0;
 $maxLevels = $maxLevels|0;
 $subTreeBound = $subTreeBound|0;
 $level = $level|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i1 = Math_fround(0), $$$i18 = Math_fround(0), $$$i1880$lcssa = Math_fround(0), $$$i188094 = Math_fround(0), $$$i8$i = Math_fround(0), $$$i8$i3 = Math_fround(0), $$$i82$lcssa = Math_fround(0), $$$i8292 = Math_fround(0), $$0$ph$i = 0, $$01$i = 0, $$01$ph$i = 0, $$02$ph$i = 0, $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i$i2 = Math_fround(0), $$1$i19 = Math_fround(0), $$1$i1981$lcssa = Math_fround(0), $$1$i198193 = Math_fround(0);
 var $$1$i83$lcssa = Math_fround(0), $$1$i8391 = Math_fround(0), $$1$i9$i = Math_fround(0), $$1$i9$i4 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa90 = Math_fround(0), $$pre = Math_fround(0), $$pre110 = Math_fround(0), $$pre111 = Math_fround(0), $$pre112 = Math_fround(0), $$pre113 = Math_fround(0), $$pre114 = Math_fround(0), $$pre115 = Math_fround(0), $$pre116 = Math_fround(0), $$pre117 = Math_fround(0), $$pre118 = Math_fround(0), $$pre119 = Math_fround(0), $$pre120 = Math_fround(0), $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0;
 var $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0);
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0);
 var $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0;
 var $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $childBound = 0, $count1$0 = 0, $exitcond = 0, $exitcond$i$i = 0, $exitcond106 = 0, $exitcond109 = 0, $i$01$i$i = 0, $i$095 = 0, $i1$088 = 0, $i12$087 = 0;
 var $i4$0$i$i = 0, $i4$0$in$i$i = 0, $maxElem = 0, $or$cond = 0, $or$cond125 = 0, $storeIndex$0$lcssa$i$i = 0, $storeIndex$02$i$i = 0, $storeIndex$1$i$i = 0, $storemerge = 0, $totalCount$089 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $maxElem = sp + 48|0;
 $childBound = sp;
 $0 = sp + 32|0;
 $1 = ($level|0)==(0);
 if ($1) {
  $storemerge = 1;
 } else {
  $2 = HEAP32[$maxLevels>>2]|0;
  $3 = (($level) + 1)|0;
  $4 = ($2>>>0)<($3>>>0);
  $5 = $4 ? $3 : $2;
  $storemerge = $5;
 }
 HEAP32[$maxLevels>>2] = $storemerge;
 $6 = $clusterSize >>> 2;
 $7 = ($6|0)==(0);
 $8 = $7 ? 1 : $6;
 $9 = HEAP32[$permute>>2]|0;
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11) + ($9<<5)|0) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = ((($11) + ($9<<5)|0) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = ((($11) + ($9<<5)|0) + 24|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($11) + ($9<<5)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($11) + ($9<<5)|0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = ((($11) + ($9<<5)|0) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = ($clusterSize>>>0)>(1);
 if ($24) {
  $$$i188094 = $19;$$$i8292 = $13;$$1$i198193 = $23;$$1$i8391 = $17;$35 = $15;$46 = $21;$i$095 = 1;
  while(1) {
   $25 = (($permute) + ($i$095<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($11) + ($26<<5)|0) + 16|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = ((($11) + ($26<<5)|0) + 20|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = ((($11) + ($26<<5)|0) + 24|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = $$$i8292 > $28;
   $$$i = $33 ? $$$i8292 : $28;
   $34 = $35 > $30;
   $36 = $34 ? $35 : $30;
   $37 = $$1$i8391 > $32;
   $$1$i = $37 ? $$1$i8391 : $32;
   $38 = (($11) + ($26<<5)|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = ((($11) + ($26<<5)|0) + 4|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = ((($11) + ($26<<5)|0) + 8|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = $$$i188094 < $39;
   $$$i18 = $44 ? $$$i188094 : $39;
   $45 = $46 < $41;
   $47 = $45 ? $46 : $41;
   $48 = $$1$i198193 < $43;
   $$1$i19 = $48 ? $$1$i198193 : $43;
   $49 = (($i$095) + 1)|0;
   $exitcond109 = ($49|0)==($clusterSize|0);
   if ($exitcond109) {
    $$$i1880$lcssa = $$$i18;$$$i82$lcssa = $$$i;$$1$i1981$lcssa = $$1$i19;$$1$i83$lcssa = $$1$i;$$lcssa = $36;$$lcssa90 = $47;
    break;
   } else {
    $$$i188094 = $$$i18;$$$i8292 = $$$i;$$1$i198193 = $$1$i19;$$1$i8391 = $$1$i;$35 = $36;$46 = $47;$i$095 = $49;
   }
  }
 } else {
  $$$i1880$lcssa = $19;$$$i82$lcssa = $13;$$1$i1981$lcssa = $23;$$1$i83$lcssa = $17;$$lcssa = $15;$$lcssa90 = $21;
 }
 $50 = Math_fround($$$i82$lcssa - $$$i1880$lcssa);
 $51 = Math_fround($$lcssa - $$lcssa90);
 $52 = Math_fround($$1$i83$lcssa - $$1$i1981$lcssa);
 HEAPF32[$maxElem>>2] = $50;
 $53 = (($maxElem) + 4|0);
 HEAPF32[$53>>2] = $51;
 $54 = (($maxElem) + 8|0);
 HEAPF32[$54>>2] = $52;
 $55 = $50 > $51;
 $56 = $50 > $52;
 $or$cond = $55 & $56;
 if ($or$cond) {
  $230 = 0;
 } else {
  $57 = $51 > $52;
  $58 = $57 ? 1 : 2;
  $230 = $58;
 }
 $59 = (($this) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($resultTree) + 4|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + 4)|0;
 __ZN5physx6shdfnd5ArrayINS_11RTreeNodeNQENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($resultTree,$63);
 $64 = Math_imul($8, -3)|0;
 $65 = (($64) + ($clusterSize))|0;
 $66 = ($65|0)<(0);
 $67 = $66 ? 0 : $65;
 $68 = (($clusterSize) + -1)|0;
 $69 = (($this) + 24|0);
 $70 = (($level) + 1)|0;
 $71 = (($childBound) + 4|0);
 $72 = (($childBound) + 8|0);
 $73 = (($childBound) + 16|0);
 $74 = (($childBound) + 20|0);
 $75 = (($childBound) + 24|0);
 $76 = (($subTreeBound) + 4|0);
 $77 = (($subTreeBound) + 8|0);
 $78 = (($subTreeBound) + 12|0);
 $79 = (($subTreeBound) + 16|0);
 $80 = (($subTreeBound) + 20|0);
 $81 = (($subTreeBound) + 24|0);
 $82 = (($subTreeBound) + 28|0);
 $83 = (($childBound) + 16|0);
 $84 = (($this) + 4|0);
 $85 = $permute;
 $86 = (($childBound) + 12|0);
 $87 = (($childBound) + 28|0);
 $100 = $230;$i1$088 = 0;$totalCount$089 = 0;
 while(1) {
  $88 = Math_imul($i1$088, $8)|0;
  $89 = ($i1$088>>>0)<(3);
  if ($89) {
   $90 = ($88>>>0)>($68>>>0);
   if ($90) {
    $231 = $100;$count1$0 = $8;
   } else {
    $$0$ph$i = $88;$$01$ph$i = $68;$$02$ph$i = $8;
    L15: while(1) {
     $$01$i = $$01$ph$i;
     while(1) {
      $91 = (($$01$i) + ($$0$ph$i))|0;
      $92 = $91 >>> 1;
      $93 = (($permute) + ($92<<2)|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (($permute) + ($$01$i<<2)|0);
      $96 = HEAP32[$95>>2]|0;
      HEAP32[$95>>2] = $94;
      HEAP32[$93>>2] = $96;
      $97 = ($$0$ph$i>>>0)<($$01$i>>>0);
      if ($97) {
       $98 = (($60) + (($94*12)|0)|0);
       $99 = (($98) + ($100<<2)|0);
       $101 = Math_fround(HEAPF32[$99>>2]);
       $i$01$i$i = $$0$ph$i;$storeIndex$02$i$i = $$0$ph$i;
       while(1) {
        $102 = (($permute) + ($i$01$i$i<<2)|0);
        $103 = HEAP32[$102>>2]|0;
        $104 = (($60) + (($103*12)|0)|0);
        $105 = (($104) + ($100<<2)|0);
        $106 = Math_fround(HEAPF32[$105>>2]);
        $107 = !($106 <= $101);
        if ($107) {
         $storeIndex$1$i$i = $storeIndex$02$i$i;
        } else {
         $108 = (($permute) + ($storeIndex$02$i$i<<2)|0);
         $109 = HEAP32[$108>>2]|0;
         HEAP32[$108>>2] = $103;
         HEAP32[$102>>2] = $109;
         $110 = (($storeIndex$02$i$i) + 1)|0;
         $storeIndex$1$i$i = $110;
        }
        $111 = (($i$01$i$i) + 1)|0;
        $exitcond$i$i = ($111|0)==($$01$i|0);
        if ($exitcond$i$i) {
         $storeIndex$0$lcssa$i$i = $storeIndex$1$i$i;
         break;
        } else {
         $i$01$i$i = $111;$storeIndex$02$i$i = $storeIndex$1$i$i;
        }
       }
      } else {
       $storeIndex$0$lcssa$i$i = $$0$ph$i;
      }
      $112 = HEAP32[$95>>2]|0;
      $113 = (($permute) + ($storeIndex$0$lcssa$i$i<<2)|0);
      $114 = HEAP32[$113>>2]|0;
      HEAP32[$95>>2] = $114;
      HEAP32[$113>>2] = $112;
      $i4$0$in$i$i = $storeIndex$0$lcssa$i$i;
      while(1) {
       $i4$0$i$i = (($i4$0$in$i$i) + 1)|0;
       $115 = ($i4$0$i$i>>>0)>($$01$i>>>0);
       if ($115) {
        break;
       } else {
        $i4$0$in$i$i = $i4$0$i$i;
       }
      }
      $116 = (($storeIndex$0$lcssa$i$i) - ($$0$ph$i))|0;
      $117 = (($116) + 1)|0;
      $118 = ($117|0)==($$02$ph$i|0);
      if ($118) {
       break L15;
      }
      $119 = ($$02$ph$i>>>0)<($117>>>0);
      $120 = (($storeIndex$0$lcssa$i$i) + -1)|0;
      if ($119) {
       $$01$i = $120;
      } else {
       break;
      }
     }
     $121 = (($$02$ph$i) - ($117))|0;
     $122 = (($storeIndex$0$lcssa$i$i) + 1)|0;
     $$0$ph$i = $122;$$01$ph$i = $$01$i;$$02$ph$i = $121;
    }
    $123 = (530176 + ($i1$088<<2)|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = (($maxElem) + ($100<<2)|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = Math_fround($124 * $126);
    HEAPF32[$125>>2] = $127;
    $128 = Math_fround(HEAPF32[$maxElem>>2]);
    $129 = Math_fround(HEAPF32[$53>>2]);
    $130 = $128 > $129;
    $131 = Math_fround(HEAPF32[$54>>2]);
    $132 = $128 > $131;
    $or$cond125 = $130 & $132;
    if ($or$cond125) {
     $231 = 0;$count1$0 = $8;
    } else {
     $133 = $129 > $131;
     $134 = $133 ? 1 : 2;
     $231 = $134;$count1$0 = $8;
    }
   }
  } else {
   $231 = $100;$count1$0 = $67;
  }
  $135 = (($i1$088) + ($62))|0;
  $136 = HEAP32[$resultTree>>2]|0;
  $137 = (($count1$0) + ($totalCount$089))|0;
  $138 = HEAP32[$69>>2]|0;
  $139 = ($count1$0>>>0)>($138>>>0);
  do {
   if ($139) {
    $191 = HEAP32[$61>>2]|0;
    $192 = ((($136) + ($135<<5)|0) + 24|0);
    HEAP32[$192>>2] = $191;
    $193 = ((($136) + ($135<<5)|0) + 28|0);
    HEAP32[$193>>2] = 0;
    $194 = (($permute) + ($88<<2)|0);
    __ZN5physx12SubSortQuick5sort4EPjjRNS_6shdfnd5ArrayINS_11RTreeNodeNQENS2_19ReflectionAllocatorIS4_EEEERjRNS_10PxBounds3VEj($this,$194,$count1$0,$resultTree,$maxLevels,$childBound,$70);
   } else {
    $140 = ($137>>>0)>($clusterSize>>>0);
    if ($140) {
     ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
     ;HEAP32[$83+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$83+12>>2]=HEAP32[$0+12>>2]|0;
     ;HEAP32[$childBound+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$childBound+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$childBound+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$childBound+12>>2]=HEAP32[$0+12>>2]|0;
     $183 = (($136) + ($135<<5)|0);
     HEAPF32[$183>>2] = Math_fround(8.50705866596322149529E+37);
     $184 = ((($136) + ($135<<5)|0) + 4|0);
     HEAPF32[$184>>2] = Math_fround(8.50705866596322149529E+37);
     $185 = ((($136) + ($135<<5)|0) + 8|0);
     HEAPF32[$185>>2] = Math_fround(8.50705866596322149529E+37);
     $186 = ((($136) + ($135<<5)|0) + 12|0);
     HEAPF32[$186>>2] = Math_fround(-8.50705866596322149529E+37);
     $187 = ((($136) + ($135<<5)|0) + 16|0);
     HEAPF32[$187>>2] = Math_fround(-8.50705866596322149529E+37);
     $188 = ((($136) + ($135<<5)|0) + 20|0);
     HEAPF32[$188>>2] = Math_fround(-8.50705866596322149529E+37);
     $189 = ((($136) + ($135<<5)|0) + 28|0);
     HEAP32[$189>>2] = -1;
     $190 = ((($136) + ($135<<5)|0) + 24|0);
     HEAP32[$190>>2] = -1;
     break;
    }
    $141 = ((($136) + ($135<<5)|0) + 28|0);
    HEAP32[$141>>2] = $count1$0;
    $142 = HEAP32[$84>>2]|0;
    $143 = $142;
    $144 = (($85) - ($143))|0;
    $145 = $144 >> 2;
    $146 = (($145) + ($88))|0;
    $147 = ((($136) + ($135<<5)|0) + 24|0);
    HEAP32[$147>>2] = $146;
    $148 = (($permute) + ($88<<2)|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = HEAP32[$10>>2]|0;
    $151 = (($150) + ($149<<5)|0);
    ;HEAP32[$childBound+0>>2]=HEAP32[$151+0>>2]|0;HEAP32[$childBound+4>>2]=HEAP32[$151+4>>2]|0;HEAP32[$childBound+8>>2]=HEAP32[$151+8>>2]|0;HEAP32[$childBound+12>>2]=HEAP32[$151+12>>2]|0;HEAP32[$childBound+16>>2]=HEAP32[$151+16>>2]|0;HEAP32[$childBound+20>>2]=HEAP32[$151+20>>2]|0;HEAP32[$childBound+24>>2]=HEAP32[$151+24>>2]|0;HEAP32[$childBound+28>>2]=HEAP32[$151+28>>2]|0;
    $152 = ($count1$0>>>0)>(1);
    if ($152) {
     $$pre115 = Math_fround(HEAPF32[$childBound>>2]);
     $$pre116 = Math_fround(HEAPF32[$71>>2]);
     $$pre117 = Math_fround(HEAPF32[$72>>2]);
     $$pre118 = Math_fround(HEAPF32[$73>>2]);
     $$pre119 = Math_fround(HEAPF32[$74>>2]);
     $$pre120 = Math_fround(HEAPF32[$75>>2]);
     $163 = $$pre115;$165 = $$pre116;$168 = $$pre117;$176 = $$pre118;$178 = $$pre119;$181 = $$pre120;$i12$087 = 1;
     while(1) {
      $153 = (($i12$087) + ($88))|0;
      $154 = (($permute) + ($153<<2)|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = (($150) + ($155<<5)|0);
      $157 = Math_fround(HEAPF32[$156>>2]);
      $158 = ((($150) + ($155<<5)|0) + 4|0);
      $159 = Math_fround(HEAPF32[$158>>2]);
      $160 = ((($150) + ($155<<5)|0) + 8|0);
      $161 = Math_fround(HEAPF32[$160>>2]);
      $162 = $163 < $157;
      $$$i$i1 = $162 ? $163 : $157;
      $164 = $165 < $159;
      $166 = $164 ? $165 : $159;
      $167 = $168 < $161;
      $$1$i$i2 = $167 ? $168 : $161;
      HEAPF32[$childBound>>2] = $$$i$i1;
      HEAPF32[$71>>2] = $166;
      HEAPF32[$72>>2] = $$1$i$i2;
      HEAPF32[$86>>2] = Math_fround(0.0);
      $169 = ((($150) + ($155<<5)|0) + 16|0);
      $170 = Math_fround(HEAPF32[$169>>2]);
      $171 = ((($150) + ($155<<5)|0) + 20|0);
      $172 = Math_fround(HEAPF32[$171>>2]);
      $173 = ((($150) + ($155<<5)|0) + 24|0);
      $174 = Math_fround(HEAPF32[$173>>2]);
      $175 = $176 > $170;
      $$$i8$i3 = $175 ? $176 : $170;
      $177 = $178 > $172;
      $179 = $177 ? $178 : $172;
      $180 = $181 > $174;
      $$1$i9$i4 = $180 ? $181 : $174;
      HEAPF32[$73>>2] = $$$i8$i3;
      HEAPF32[$74>>2] = $179;
      HEAPF32[$75>>2] = $$1$i9$i4;
      HEAPF32[$87>>2] = Math_fround(0.0);
      $182 = (($i12$087) + 1)|0;
      $exitcond = ($182|0)==($count1$0|0);
      if ($exitcond) {
       break;
      } else {
       $163 = $$$i$i1;$165 = $166;$168 = $$1$i$i2;$176 = $$$i8$i3;$178 = $179;$181 = $$1$i9$i4;$i12$087 = $182;
      }
     }
    }
   }
  } while(0);
  $195 = ($i1$088|0)==(0);
  if ($195) {
   ;HEAP32[$subTreeBound+0>>2]=HEAP32[$childBound+0>>2]|0;HEAP32[$subTreeBound+4>>2]=HEAP32[$childBound+4>>2]|0;HEAP32[$subTreeBound+8>>2]=HEAP32[$childBound+8>>2]|0;HEAP32[$subTreeBound+12>>2]=HEAP32[$childBound+12>>2]|0;HEAP32[$subTreeBound+16>>2]=HEAP32[$childBound+16>>2]|0;HEAP32[$subTreeBound+20>>2]=HEAP32[$childBound+20>>2]|0;HEAP32[$subTreeBound+24>>2]=HEAP32[$childBound+24>>2]|0;HEAP32[$subTreeBound+28>>2]=HEAP32[$childBound+28>>2]|0;
   $$pre = Math_fround(HEAPF32[$childBound>>2]);
   $$pre110 = Math_fround(HEAPF32[$71>>2]);
   $$pre111 = Math_fround(HEAPF32[$72>>2]);
   $$pre112 = Math_fround(HEAPF32[$73>>2]);
   $$pre113 = Math_fround(HEAPF32[$74>>2]);
   $$pre114 = Math_fround(HEAPF32[$75>>2]);
   $218 = $$pre;$220 = $$pre110;$222 = $$pre111;$224 = $$pre112;$226 = $$pre113;$228 = $$pre114;
  } else {
   $196 = Math_fround(HEAPF32[$subTreeBound>>2]);
   $197 = Math_fround(HEAPF32[$76>>2]);
   $198 = Math_fround(HEAPF32[$77>>2]);
   $199 = Math_fround(HEAPF32[$childBound>>2]);
   $200 = Math_fround(HEAPF32[$71>>2]);
   $201 = Math_fround(HEAPF32[$72>>2]);
   $202 = $196 < $199;
   $$$i$i = $202 ? $196 : $199;
   $203 = $197 < $200;
   $204 = $203 ? $197 : $200;
   $205 = $198 < $201;
   $$1$i$i = $205 ? $198 : $201;
   HEAPF32[$subTreeBound>>2] = $$$i$i;
   HEAPF32[$76>>2] = $204;
   HEAPF32[$77>>2] = $$1$i$i;
   HEAPF32[$78>>2] = Math_fround(0.0);
   $206 = Math_fround(HEAPF32[$79>>2]);
   $207 = Math_fround(HEAPF32[$80>>2]);
   $208 = Math_fround(HEAPF32[$81>>2]);
   $209 = Math_fround(HEAPF32[$73>>2]);
   $210 = Math_fround(HEAPF32[$74>>2]);
   $211 = Math_fround(HEAPF32[$75>>2]);
   $212 = $206 > $209;
   $$$i8$i = $212 ? $206 : $209;
   $213 = $207 > $210;
   $214 = $213 ? $207 : $210;
   $215 = $208 > $211;
   $$1$i9$i = $215 ? $208 : $211;
   HEAPF32[$79>>2] = $$$i8$i;
   HEAPF32[$80>>2] = $214;
   HEAPF32[$81>>2] = $$1$i9$i;
   HEAPF32[$82>>2] = Math_fround(0.0);
   $218 = $199;$220 = $200;$222 = $201;$224 = $209;$226 = $210;$228 = $211;
  }
  $216 = HEAP32[$resultTree>>2]|0;
  $217 = (($216) + ($135<<5)|0);
  HEAPF32[$217>>2] = $218;
  $219 = ((($216) + ($135<<5)|0) + 4|0);
  HEAPF32[$219>>2] = $220;
  $221 = ((($216) + ($135<<5)|0) + 8|0);
  HEAPF32[$221>>2] = $222;
  $223 = ((($216) + ($135<<5)|0) + 12|0);
  HEAPF32[$223>>2] = $224;
  $225 = ((($216) + ($135<<5)|0) + 16|0);
  HEAPF32[$225>>2] = $226;
  $227 = ((($216) + ($135<<5)|0) + 20|0);
  HEAPF32[$227>>2] = $228;
  $229 = (($i1$088) + 1)|0;
  $exitcond106 = ($229|0)==(4);
  if ($exitcond106) {
   break;
  } else {
   $100 = $231;$i1$088 = $229;$totalCount$089 = $137;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_2Gu10RTreeNodeQENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*28)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 530544 : 530312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,530232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*28)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;HEAP32[$$012$i+24>>2]=HEAP32[$$03$i+24>>2]|0;
   }
   $25 = (($$012$i) + 28|0);
   $26 = (($$03$i) + 28|0);
   $27 = ($25>>>0)<($20>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $19;
 }
 $28 = (($21) + (($29*28)|0)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  ;HEAP32[$28+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$28+16>>2]=HEAP32[$a+16>>2]|0;HEAP32[$28+20>>2]=HEAP32[$a+20>>2]|0;HEAP32[$28+24>>2]=HEAP32[$a+24>>2]|0;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if (!($32)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $39 = HEAP32[$18>>2]|0;
  $40 = (($39) + 1)|0;
  HEAP32[$18>>2] = $40;
  $41 = (($21) + (($39*28)|0)|0);
  STACKTOP = sp;return ($41|0);
 }
 $33 = HEAP32[$this>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $39 = HEAP32[$18>>2]|0;
  $40 = (($39) + 1)|0;
  HEAP32[$18>>2] = $40;
  $41 = (($21) + (($39*28)|0)|0);
  STACKTOP = sp;return ($41|0);
 }
 $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = HEAP32[$18>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$18>>2] = $40;
 $41 = (($21) + (($39*28)|0)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayINS_2Gu10RTreeNodeQENS0_19ReflectionAllocatorIS3_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = ($capacity*28)|0;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 530544 : 530312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,530232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + (($14*28)|0)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;HEAP32[$$012$i+20>>2]=HEAP32[$$03$i+20>>2]|0;HEAP32[$$012$i+24>>2]=HEAP32[$$03$i+24>>2]|0;
   }
   $20 = (($$012$i) + 28|0);
   $21 = (($$03$i) + 28|0);
   $22 = ($20>>>0)<($15>>>0);
   if ($22) {
    $$012$i = $20;$$03$i = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP32[$this>>2] = $16;
  HEAP32[$23>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$26);
 HEAP32[$this>>2] = $16;
 HEAP32[$23>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11RTreeNodeNQENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_11RTreeNodeNQENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx12SubSortQuickC2EPjPKNS_10PxBounds3VEjf($this,$permute,$allBounds_,$allBoundsSize,$sizePerfTradeOff01) {
 $this = $this|0;
 $permute = $permute|0;
 $allBounds_ = $allBounds_|0;
 $allBoundsSize = $allBoundsSize|0;
 $sizePerfTradeOff01 = Math_fround($sizePerfTradeOff01);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $sizePerfTradeOff01$op = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $allBounds_;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($permute) + ($allBoundsSize<<2)|0);
 HEAP32[$this>>2] = $5;
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = $permute;
 $7 = ($allBoundsSize|0)==(0);
 if ($7) {
  $37 = $sizePerfTradeOff01 < Math_fround(0.0);
  $sizePerfTradeOff01$op = Math_fround($sizePerfTradeOff01 * Math_fround(9.0));
  $38 = (~~(($sizePerfTradeOff01$op))>>>0);
  $39 = $37 ? 0 : $38;
  $40 = ($39>>>0)<(8);
  $41 = $40 ? $39 : 8;
  $42 = (530192 + ($41<<2)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($this) + 24|0);
  HEAP32[$44>>2] = $43;
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE8recreateEj($2,$allBoundsSize);
 $8 = (($0) + 4|0);
 $9 = (($0) + 8|0);
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$1>>2]|0;
  $11 = (($10) + ($i$01<<5)|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = ((($10) + ($i$01<<5)|0) + 16|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($12 + $14);
  $16 = ((($10) + ($i$01<<5)|0) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = ((($10) + ($i$01<<5)|0) + 20|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($17 + $19);
  $21 = ((($10) + ($i$01<<5)|0) + 8|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = ((($10) + ($i$01<<5)|0) + 24|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($22 + $24);
  HEAPF32[$0>>2] = $15;
  HEAPF32[$8>>2] = $20;
  HEAPF32[$9>>2] = $25;
  $26 = HEAP32[$4>>2]|0;
  $27 = $26 & 2147483647;
  $28 = HEAP32[$3>>2]|0;
  $29 = ($27>>>0)>($28>>>0);
  if ($29) {
   $30 = HEAP32[$2>>2]|0;
   $31 = (($30) + (($28*12)|0)|0);
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    HEAPF32[$31>>2] = $15;
    $33 = ((($30) + (($28*12)|0)|0) + 4|0);
    HEAPF32[$33>>2] = $20;
    $34 = ((($30) + (($28*12)|0)|0) + 8|0);
    HEAPF32[$34>>2] = $25;
   }
   $35 = (($28) + 1)|0;
   HEAP32[$3>>2] = $35;
  } else {
   (__ZN5physx6shdfnd5ArrayINS_6PxVec3ENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($2,$0)|0);
  }
  $36 = (($i$01) + 1)|0;
  $exitcond = ($36|0)==($allBoundsSize|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $36;
  }
 }
 $37 = $sizePerfTradeOff01 < Math_fround(0.0);
 $sizePerfTradeOff01$op = Math_fround($sizePerfTradeOff01 * Math_fround(9.0));
 $38 = (~~(($sizePerfTradeOff01$op))>>>0);
 $39 = $37 ? 0 : $38;
 $40 = ($39>>>0)<(8);
 $41 = $40 ? $39 : 8;
 $42 = (530192 + ($41<<2)|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 24|0);
 HEAP32[$44>>2] = $43;
 STACKTOP = sp;return;
}
function __ZN5physx10SubSortSAH5splitEPjj($this,$permute,$clusterSize) {
 $this = $this|0;
 $permute = $permute|0;
 $clusterSize = $clusterSize|0;
 var $$$i = Math_fround(0), $$$i14 = Math_fround(0), $$$i20 = Math_fround(0), $$$i26 = Math_fround(0), $$$i26252$lcssa = Math_fround(0), $$$i26252315 = Math_fround(0), $$$i26253328 = Math_fround(0), $$$i264$lcssa = Math_fround(0), $$$i264290 = Math_fround(0), $$$i265302 = Math_fround(0), $$$i32 = Math_fround(0), $$$i32256$lcssa = Math_fround(0), $$$i32256313 = Math_fround(0), $$$i32257326 = Math_fround(0), $$$i42 = Math_fround(0), $$$i48 = Math_fround(0), $$$i54 = Math_fround(0), $$$i54260$lcssa = Math_fround(0), $$$i54260292 = Math_fround(0), $$$i54261304 = Math_fround(0);
 var $$0 = 0, $$1$i = Math_fround(0), $$1$i15 = Math_fround(0), $$1$i21 = Math_fround(0), $$1$i266$lcssa = Math_fround(0), $$1$i266289 = Math_fround(0), $$1$i267301 = Math_fround(0), $$1$i27 = Math_fround(0), $$1$i27254$lcssa = Math_fround(0), $$1$i27254314 = Math_fround(0), $$1$i27255327 = Math_fround(0), $$1$i33 = Math_fround(0), $$1$i33258$lcssa = Math_fround(0), $$1$i33258312 = Math_fround(0), $$1$i33259325 = Math_fround(0), $$1$i43 = Math_fround(0), $$1$i49 = Math_fround(0), $$1$i55 = Math_fround(0), $$1$i55262$lcssa = Math_fround(0), $$1$i55262291 = Math_fround(0);
 var $$1$i55263303 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa288 = Math_fround(0), $$lcssa310 = Math_fround(0), $$lcssa311 = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert360 = 0, $$phi$trans$insert362 = 0, $$pre = 0, $$pre354 = 0, $$pre359 = 0, $$pre361 = 0, $$pre363 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0;
 var $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0);
 var $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0;
 var $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0;
 var $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0;
 var $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0;
 var $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $coordIndex$0341 = 0, $countL0$0305 = 0, $countR0$0329 = 0, $exitcond = 0, $exitcond343 = 0, $exitcond344 = 0, $exitcond345 = 0, $exitcond346 = 0;
 var $exitcond347 = 0, $exitcond350 = 0, $exitcond353 = 0, $i$0285 = 0, $i1$0276 = 0, $i2$0280 = 0, $i5$0268 = 0, $i6$0273 = 0, $i7$0270 = 0, $ii$0293 = 0, $ii$1306 = 0, $ii$2316 = 0, $ii$3330 = 0, $ii$4335 = 0, $ispos$i = 0, $ispos$i4 = 0, $minMetric = 0, $minMetricLocal$0$lcssa = Math_fround(0), $minMetricLocal$0334 = Math_fround(0), $minMetricLocal$1 = Math_fround(0);
 var $minMetricSplit = 0, $minMetricSplitPosition$0$lcssa = 0, $minMetricSplitPosition$0333 = 0, $minMetricSplitPosition$1 = 0, $neg$i = 0, $neg$i5 = 0, $or$cond = 0, $or$cond364 = 0, $orders3 = 0, $ranks3 = 0, $splitPoint$0 = 0, $winIndex$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 49|0;
 $1 = sp + 48|0;
 $minMetric = sp + 12|0;
 $minMetricSplit = sp + 24|0;
 $ranks3 = sp;
 $orders3 = sp + 36|0;
 $2 = ($clusterSize>>>0)<(2);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($clusterSize|0)==(2);
 if ($3) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ($clusterSize>>>0)>(3);
 $5 = $4 ? 2 : 1;
 $6 = (($clusterSize) - ($5))|0;
 $7 = (($this) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$ranks3>>2] = $8;
 $9 = (($ranks3) + 4|0);
 $10 = (($this) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$9>>2] = $11;
 $12 = (($ranks3) + 8|0);
 $13 = (($this) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 HEAP32[$12>>2] = $14;
 $15 = (($this) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$orders3>>2] = $16;
 $17 = (($orders3) + 4|0);
 $18 = (($this) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$17>>2] = $19;
 $20 = (($orders3) + 8|0);
 $21 = (($this) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = (($this) + 8|0);
 $24 = (($this) + 48|0);
 $25 = (($this) + 4|0);
 $26 = ($5|0)>($6|0);
 $27 = (($clusterSize) + -1)|0;
 $28 = (($clusterSize) + -2)|0;
 $29 = ($28|0)>($6|0);
 $30 = $clusterSize >>> 1;
 $31 = (($6) - ($5))|0;
 $32 = (($31) + 1)|0;
 $33 = ($31|0)>(-1);
 $34 = (($this) + 12|0);
 $35 = (($this) + 16|0);
 $36 = (($this) + 44|0);
 $37 = (($clusterSize) + 1)|0;
 $38 = $5 << 1;
 $39 = (($37) - ($38))|0;
 $45 = $16;$52 = $8;$coordIndex$0341 = 0;
 while(1) {
  $40 = HEAP32[$24>>2]|0;
  $41 = ($40|0)==($clusterSize|0);
  if ($41) {
   $42 = HEAP32[$25>>2]|0;
   $i$0285 = 0;
   while(1) {
    $44 = (($45) + ($i$0285<<2)|0);
    $46 = HEAP32[$44>>2]|0;
    $47 = (($42) + ($i$0285<<2)|0);
    HEAP32[$47>>2] = $46;
    $48 = (($i$0285) + 1)|0;
    $exitcond347 = ($48|0)==($clusterSize|0);
    if ($exitcond347) {
     break;
    } else {
     $i$0285 = $48;
    }
   }
  } else {
   $43 = HEAP32[$36>>2]|0;
   $i1$0276 = 0;
   while(1) {
    $49 = (($permute) + ($i1$0276<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($52) + ($50<<2)|0);
    $53 = HEAP32[$51>>2]|0;
    $54 = (($43) + ($i1$0276<<2)|0);
    HEAP32[$54>>2] = $53;
    $55 = (($i1$0276) + 1)|0;
    $exitcond345 = ($55|0)==($clusterSize|0);
    if ($exitcond345) {
     break;
    } else {
     $i1$0276 = $55;
    }
   }
   $56 = HEAP32[$36>>2]|0;
   __ZN5physx6shdfnd4sortIjNS0_4LessIjEENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($56,$clusterSize,$0,$1);
   $57 = HEAP32[$36>>2]|0;
   $58 = HEAP32[$25>>2]|0;
   $i2$0280 = 0;
   while(1) {
    $59 = (($57) + ($i2$0280<<2)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($45) + ($60<<2)|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($58) + ($i2$0280<<2)|0);
    HEAP32[$63>>2] = $62;
    $64 = (($i2$0280) + 1)|0;
    $exitcond346 = ($64|0)==($clusterSize|0);
    if ($exitcond346) {
     break;
    } else {
     $i2$0280 = $64;
    }
   }
  }
  $65 = HEAP32[$25>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = HEAP32[$23>>2]|0;
  $68 = (($67) + ($66<<5)|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = ((($67) + ($66<<5)|0) + 4|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = ((($67) + ($66<<5)|0) + 8|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = ((($67) + ($66<<5)|0) + 16|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = ((($67) + ($66<<5)|0) + 20|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = ((($67) + ($66<<5)|0) + 24|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  if ($4) {
   $$$i264290 = $69;$$$i54260292 = $75;$$1$i266289 = $73;$$1$i55262291 = $79;$101 = $77;$90 = $71;$ii$0293 = 1;
   while(1) {
    $80 = (($65) + ($ii$0293<<2)|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($67) + ($81<<5)|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = ((($67) + ($81<<5)|0) + 4|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = ((($67) + ($81<<5)|0) + 8|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = $$$i264290 < $83;
    $$$i = $88 ? $$$i264290 : $83;
    $89 = $90 < $85;
    $91 = $89 ? $90 : $85;
    $92 = $$1$i266289 < $87;
    $$1$i = $92 ? $$1$i266289 : $87;
    $93 = ((($67) + ($81<<5)|0) + 16|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $95 = ((($67) + ($81<<5)|0) + 20|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $97 = ((($67) + ($81<<5)|0) + 24|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = $$$i54260292 > $94;
    $$$i54 = $99 ? $$$i54260292 : $94;
    $100 = $101 > $96;
    $102 = $100 ? $101 : $96;
    $103 = $$1$i55262291 > $98;
    $$1$i55 = $103 ? $$1$i55262291 : $98;
    $104 = (($ii$0293) + 1)|0;
    $105 = ($104|0)<($5|0);
    if ($105) {
     $$$i264290 = $$$i;$$$i54260292 = $$$i54;$$1$i266289 = $$1$i;$$1$i55262291 = $$1$i55;$101 = $102;$90 = $91;$ii$0293 = $104;
    } else {
     $$$i264$lcssa = $$$i;$$$i54260$lcssa = $$$i54;$$1$i266$lcssa = $$1$i;$$1$i55262$lcssa = $$1$i55;$$lcssa = $91;$$lcssa288 = $102;
     break;
    }
   }
  } else {
   $$$i264$lcssa = $69;$$$i54260$lcssa = $75;$$1$i266$lcssa = $73;$$1$i55262$lcssa = $79;$$lcssa = $71;$$lcssa288 = $77;
  }
  if (!($26)) {
   $$pre354 = HEAP32[$34>>2]|0;
   $$$i265302 = $$$i264$lcssa;$$$i54261304 = $$$i54260$lcssa;$$1$i267301 = $$1$i266$lcssa;$$1$i55263303 = $$1$i55262$lcssa;$116 = $$lcssa;$127 = $$lcssa288;$countL0$0305 = 0;$ii$1306 = $5;
   while(1) {
    $106 = (($65) + ($ii$1306<<2)|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($67) + ($107<<5)|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = ((($67) + ($107<<5)|0) + 4|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = ((($67) + ($107<<5)|0) + 8|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = $$$i265302 < $109;
    $$$i48 = $114 ? $$$i265302 : $109;
    $115 = $116 < $111;
    $117 = $115 ? $116 : $111;
    $118 = $$1$i267301 < $113;
    $$1$i49 = $118 ? $$1$i267301 : $113;
    $119 = ((($67) + ($107<<5)|0) + 16|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = ((($67) + ($107<<5)|0) + 20|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = ((($67) + ($107<<5)|0) + 24|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = $$$i54261304 > $120;
    $$$i42 = $125 ? $$$i54261304 : $120;
    $126 = $127 > $122;
    $128 = $126 ? $127 : $122;
    $129 = $$1$i55263303 > $124;
    $$1$i43 = $129 ? $$1$i55263303 : $124;
    $130 = Math_fround($$$i42 - $$$i48);
    $131 = Math_fround($128 - $117);
    $132 = Math_fround($$1$i43 - $$1$i49);
    $133 = (($countL0$0305) + 1)|0;
    $134 = (($$pre354) + ($countL0$0305<<2)|0);
    $135 = Math_fround($130 * $132);
    $136 = Math_fround($130 * $131);
    $137 = Math_fround($136 + $135);
    $138 = Math_fround($131 * $132);
    $139 = Math_fround($138 + $137);
    HEAPF32[$134>>2] = $139;
    $140 = (($ii$1306) + 1)|0;
    $exitcond350 = ($133|0)==($39|0);
    if ($exitcond350) {
     break;
    } else {
     $$$i265302 = $$$i48;$$$i54261304 = $$$i42;$$1$i267301 = $$1$i49;$$1$i55263303 = $$1$i43;$116 = $117;$127 = $128;$countL0$0305 = $133;$ii$1306 = $140;
    }
   }
  }
  $141 = (($65) + ($27<<2)|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = (($67) + ($142<<5)|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = ((($67) + ($142<<5)|0) + 4|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = ((($67) + ($142<<5)|0) + 8|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = ((($67) + ($142<<5)|0) + 16|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $151 = ((($67) + ($142<<5)|0) + 20|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = ((($67) + ($142<<5)|0) + 24|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  if ($29) {
   $$$i26252315 = $150;$$$i32256313 = $144;$$1$i27254314 = $154;$$1$i33258312 = $148;$165 = $146;$176 = $152;$ii$2316 = $28;
   while(1) {
    $155 = (($65) + ($ii$2316<<2)|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = (($67) + ($156<<5)|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = ((($67) + ($156<<5)|0) + 4|0);
    $160 = Math_fround(HEAPF32[$159>>2]);
    $161 = ((($67) + ($156<<5)|0) + 8|0);
    $162 = Math_fround(HEAPF32[$161>>2]);
    $163 = $$$i32256313 < $158;
    $$$i32 = $163 ? $$$i32256313 : $158;
    $164 = $165 < $160;
    $166 = $164 ? $165 : $160;
    $167 = $$1$i33258312 < $162;
    $$1$i33 = $167 ? $$1$i33258312 : $162;
    $168 = ((($67) + ($156<<5)|0) + 16|0);
    $169 = Math_fround(HEAPF32[$168>>2]);
    $170 = ((($67) + ($156<<5)|0) + 20|0);
    $171 = Math_fround(HEAPF32[$170>>2]);
    $172 = ((($67) + ($156<<5)|0) + 24|0);
    $173 = Math_fround(HEAPF32[$172>>2]);
    $174 = $$$i26252315 > $169;
    $$$i26 = $174 ? $$$i26252315 : $169;
    $175 = $176 > $171;
    $177 = $175 ? $176 : $171;
    $178 = $$1$i27254314 > $173;
    $$1$i27 = $178 ? $$1$i27254314 : $173;
    $179 = (($ii$2316) + -1)|0;
    $180 = ($179|0)>($6|0);
    if ($180) {
     $$$i26252315 = $$$i26;$$$i32256313 = $$$i32;$$1$i27254314 = $$1$i27;$$1$i33258312 = $$1$i33;$165 = $166;$176 = $177;$ii$2316 = $179;
    } else {
     $$$i26252$lcssa = $$$i26;$$$i32256$lcssa = $$$i32;$$1$i27254$lcssa = $$1$i27;$$1$i33258$lcssa = $$1$i33;$$lcssa310 = $166;$$lcssa311 = $177;
     break;
    }
   }
  } else {
   $$$i26252$lcssa = $150;$$$i32256$lcssa = $144;$$1$i27254$lcssa = $154;$$1$i33258$lcssa = $148;$$lcssa310 = $146;$$lcssa311 = $152;
  }
  if (!($26)) {
   $$pre = HEAP32[$35>>2]|0;
   $$$i26253328 = $$$i26252$lcssa;$$$i32257326 = $$$i32256$lcssa;$$1$i27255327 = $$1$i27254$lcssa;$$1$i33259325 = $$1$i33258$lcssa;$191 = $$lcssa310;$202 = $$lcssa311;$countR0$0329 = 0;$ii$3330 = $6;
   while(1) {
    $181 = (($65) + ($ii$3330<<2)|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = (($67) + ($182<<5)|0);
    $184 = Math_fround(HEAPF32[$183>>2]);
    $185 = ((($67) + ($182<<5)|0) + 4|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = ((($67) + ($182<<5)|0) + 8|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = $$$i32257326 < $184;
    $$$i20 = $189 ? $$$i32257326 : $184;
    $190 = $191 < $186;
    $192 = $190 ? $191 : $186;
    $193 = $$1$i33259325 < $188;
    $$1$i21 = $193 ? $$1$i33259325 : $188;
    $194 = ((($67) + ($182<<5)|0) + 16|0);
    $195 = Math_fround(HEAPF32[$194>>2]);
    $196 = ((($67) + ($182<<5)|0) + 20|0);
    $197 = Math_fround(HEAPF32[$196>>2]);
    $198 = ((($67) + ($182<<5)|0) + 24|0);
    $199 = Math_fround(HEAPF32[$198>>2]);
    $200 = $$$i26253328 > $195;
    $$$i14 = $200 ? $$$i26253328 : $195;
    $201 = $202 > $197;
    $203 = $201 ? $202 : $197;
    $204 = $$1$i27255327 > $199;
    $$1$i15 = $204 ? $$1$i27255327 : $199;
    $205 = Math_fround($$$i14 - $$$i20);
    $206 = Math_fround($203 - $192);
    $207 = Math_fround($$1$i15 - $$1$i21);
    $208 = (($countR0$0329) + 1)|0;
    $209 = (($$pre) + ($countR0$0329<<2)|0);
    $210 = Math_fround($205 * $207);
    $211 = Math_fround($205 * $206);
    $212 = Math_fround($211 + $210);
    $213 = Math_fround($206 * $207);
    $214 = Math_fround($213 + $212);
    HEAPF32[$209>>2] = $214;
    $215 = (($ii$3330) + -1)|0;
    $216 = ($ii$3330|0)>($5|0);
    if ($216) {
     $$$i26253328 = $$$i14;$$$i32257326 = $$$i20;$$1$i27255327 = $$1$i15;$$1$i33259325 = $$1$i21;$191 = $192;$202 = $203;$countR0$0329 = $208;$ii$3330 = $215;
    } else {
     break;
    }
   }
  }
  if ($33) {
   $217 = HEAP32[$34>>2]|0;
   $218 = HEAP32[$35>>2]|0;
   $ii$4335 = 0;$minMetricLocal$0334 = Math_fround(3.40282346638528859812E+38);$minMetricSplitPosition$0333 = 0;
   while(1) {
    $219 = (($ii$4335) + ($5))|0;
    $220 = (Math_fround(($219|0)));
    $221 = (($32) - ($ii$4335))|0;
    $222 = (($221) + -1)|0;
    $223 = (($222) + ($5))|0;
    $224 = (Math_fround(($223|0)));
    $225 = (($217) + ($ii$4335<<2)|0);
    $226 = Math_fround(HEAPF32[$225>>2]);
    $227 = Math_fround($220 * $226);
    $228 = (($218) + ($222<<2)|0);
    $229 = Math_fround(HEAPF32[$228>>2]);
    $230 = Math_fround($224 * $229);
    $231 = Math_fround($227 + $230);
    $232 = $231 < $minMetricLocal$0334;
    if ($232) {
     label = 26;
    } else {
     $233 = !($231 <= $minMetricLocal$0334);
     if ($233) {
      $minMetricLocal$1 = $minMetricLocal$0334;$minMetricSplitPosition$1 = $minMetricSplitPosition$0333;
     } else {
      $234 = (($219) - ($30))|0;
      $ispos$i4 = ($234|0)>(-1);
      $neg$i5 = (0 - ($234))|0;
      $235 = $ispos$i4 ? $234 : $neg$i5;
      $236 = (($minMetricSplitPosition$0333) - ($30))|0;
      $ispos$i = ($236|0)>(-1);
      $neg$i = (0 - ($236))|0;
      $237 = $ispos$i ? $236 : $neg$i;
      $238 = ($235|0)<($237|0);
      if ($238) {
       label = 26;
      } else {
       $minMetricLocal$1 = $minMetricLocal$0334;$minMetricSplitPosition$1 = $minMetricSplitPosition$0333;
      }
     }
    }
    if ((label|0) == 26) {
     label = 0;
     $minMetricLocal$1 = $231;$minMetricSplitPosition$1 = $219;
    }
    $239 = (($ii$4335) + 1)|0;
    $240 = ($239|0)<($32|0);
    if ($240) {
     $ii$4335 = $239;$minMetricLocal$0334 = $minMetricLocal$1;$minMetricSplitPosition$0333 = $minMetricSplitPosition$1;
    } else {
     $minMetricLocal$0$lcssa = $minMetricLocal$1;$minMetricSplitPosition$0$lcssa = $minMetricSplitPosition$1;
     break;
    }
   }
  } else {
   $minMetricLocal$0$lcssa = Math_fround(3.40282346638528859812E+38);$minMetricSplitPosition$0$lcssa = 0;
  }
  $241 = (($minMetric) + ($coordIndex$0341<<2)|0);
  HEAPF32[$241>>2] = $minMetricLocal$0$lcssa;
  $242 = (($minMetricSplit) + ($coordIndex$0341<<2)|0);
  HEAP32[$242>>2] = $minMetricSplitPosition$0$lcssa;
  $243 = (($coordIndex$0341) + 1)|0;
  $exitcond353 = ($243|0)==(3);
  if ($exitcond353) {
   break;
  }
  $$phi$trans$insert = (($ranks3) + ($243<<2)|0);
  $$pre359 = HEAP32[$$phi$trans$insert>>2]|0;
  $$phi$trans$insert360 = (($orders3) + ($243<<2)|0);
  $$pre361 = HEAP32[$$phi$trans$insert360>>2]|0;
  $45 = $$pre361;$52 = $$pre359;$coordIndex$0341 = $243;
 }
 $244 = Math_fround(HEAPF32[$minMetric>>2]);
 $245 = (($minMetric) + 4|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = !($244 <= $246);
 $$phi$trans$insert362 = (($minMetric) + 8|0);
 $$pre363 = Math_fround(HEAPF32[$$phi$trans$insert362>>2]);
 $248 = !($244 <= $$pre363);
 $or$cond364 = $247 | $248;
 if ($or$cond364) {
  $249 = !($246 <= $$pre363);
  if ($249) {
   $winIndex$0 = 2;
  } else {
   $winIndex$0 = 1;
  }
 } else {
  $winIndex$0 = 0;
 }
 $250 = (($ranks3) + ($winIndex$0<<2)|0);
 $251 = HEAP32[$250>>2]|0;
 $252 = (($orders3) + ($winIndex$0<<2)|0);
 $253 = HEAP32[$252>>2]|0;
 $254 = HEAP32[$24>>2]|0;
 $255 = ($254|0)==($clusterSize|0);
 if ($255) {
  $i5$0268 = 0;
  while(1) {
   $257 = (($253) + ($i5$0268<<2)|0);
   $258 = HEAP32[$257>>2]|0;
   $259 = (($permute) + ($i5$0268<<2)|0);
   HEAP32[$259>>2] = $258;
   $260 = (($i5$0268) + 1)|0;
   $exitcond = ($260|0)==($clusterSize|0);
   if ($exitcond) {
    break;
   } else {
    $i5$0268 = $260;
   }
  }
 } else {
  $256 = HEAP32[$36>>2]|0;
  $i6$0273 = 0;
  while(1) {
   $261 = (($permute) + ($i6$0273<<2)|0);
   $262 = HEAP32[$261>>2]|0;
   $263 = (($251) + ($262<<2)|0);
   $264 = HEAP32[$263>>2]|0;
   $265 = (($256) + ($i6$0273<<2)|0);
   HEAP32[$265>>2] = $264;
   $266 = (($i6$0273) + 1)|0;
   $exitcond344 = ($266|0)==($clusterSize|0);
   if ($exitcond344) {
    break;
   } else {
    $i6$0273 = $266;
   }
  }
  $267 = HEAP32[$36>>2]|0;
  __ZN5physx6shdfnd4sortIjNS0_4LessIjEENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($267,$clusterSize,$0,$1);
  $268 = HEAP32[$36>>2]|0;
  $i7$0270 = 0;
  while(1) {
   $269 = (($268) + ($i7$0270<<2)|0);
   $270 = HEAP32[$269>>2]|0;
   $271 = (($253) + ($270<<2)|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = (($permute) + ($i7$0270<<2)|0);
   HEAP32[$273>>2] = $272;
   $274 = (($i7$0270) + 1)|0;
   $exitcond343 = ($274|0)==($clusterSize|0);
   if ($exitcond343) {
    break;
   } else {
    $i7$0270 = $274;
   }
  }
 }
 $275 = (($minMetricSplit) + ($winIndex$0<<2)|0);
 $276 = HEAP32[$275>>2]|0;
 $277 = ($clusterSize|0)==(3);
 $278 = ($276|0)==(0);
 $or$cond = $277 & $278;
 $splitPoint$0 = $or$cond ? 1 : $276;
 $$0 = $splitPoint$0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd5ArrayINS_11RTreeNodeNQENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0;
 var $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 5;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 530792 : 530312;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,530232,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<5)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $25;
    $26 = (($$012$i) + 4|0);
    $27 = (($$03$i) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$26>>2] = $28;
    $29 = (($$012$i) + 8|0);
    $30 = (($$03$i) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$29>>2] = $31;
    $32 = (($$012$i) + 12|0);
    $33 = (($$03$i) + 12|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    HEAPF32[$32>>2] = $34;
    $35 = (($$012$i) + 16|0);
    $36 = (($$03$i) + 16|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$35>>2] = $37;
    $38 = (($$012$i) + 20|0);
    $39 = (($$03$i) + 20|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    HEAPF32[$38>>2] = $40;
    $41 = (($$012$i) + 24|0);
    $42 = (($$03$i) + 24|0);
    $43 = $42;
    $44 = $43;
    $45 = HEAP32[$44>>2]|0;
    $46 = (($43) + 4)|0;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = $41;
    $50 = $49;
    HEAP32[$50>>2] = $45;
    $51 = (($49) + 4)|0;
    $52 = $51;
    HEAP32[$52>>2] = $48;
   }
   $53 = (($$012$i) + 32|0);
   $54 = (($$03$i) + 32|0);
   $55 = ($53>>>0)<($20>>>0);
   if ($55) {
    $$012$i = $53;$$03$i = $54;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $57 = $$pre;
 } else {
  $57 = $19;
 }
 $56 = (($21) + ($57<<5)|0);
 $58 = ($56|0)==(0|0);
 if (!($58)) {
  $59 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$56>>2] = $59;
  $60 = ((($21) + ($57<<5)|0) + 4|0);
  $61 = (($a) + 4|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$60>>2] = $62;
  $63 = ((($21) + ($57<<5)|0) + 8|0);
  $64 = (($a) + 8|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  HEAPF32[$63>>2] = $65;
  $66 = ((($21) + ($57<<5)|0) + 12|0);
  $67 = (($a) + 12|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$66>>2] = $68;
  $69 = ((($21) + ($57<<5)|0) + 16|0);
  $70 = (($a) + 16|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  HEAPF32[$69>>2] = $71;
  $72 = ((($21) + ($57<<5)|0) + 20|0);
  $73 = (($a) + 20|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  HEAPF32[$72>>2] = $74;
  $75 = ((($21) + ($57<<5)|0) + 24|0);
  $76 = (($a) + 24|0);
  $77 = $76;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($77) + 4)|0;
  $81 = $80;
  $82 = HEAP32[$81>>2]|0;
  $83 = $75;
  $84 = $83;
  HEAP32[$84>>2] = $79;
  $85 = (($83) + 4)|0;
  $86 = $85;
  HEAP32[$86>>2] = $82;
 }
 $87 = HEAP32[$0>>2]|0;
 $88 = ($87|0)>(-1);
 if (!($88)) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $95 = HEAP32[$18>>2]|0;
  $96 = (($95) + 1)|0;
  HEAP32[$18>>2] = $96;
  $97 = (($21) + ($95<<5)|0);
  STACKTOP = sp;return ($97|0);
 }
 $89 = HEAP32[$this>>2]|0;
 $90 = ($89|0)==(0|0);
 if ($90) {
  HEAP32[$this>>2] = $21;
  HEAP32[$0>>2] = $$$i;
  $95 = HEAP32[$18>>2]|0;
  $96 = (($95) + 1)|0;
  HEAP32[$18>>2] = $96;
  $97 = (($21) + ($95<<5)|0);
  STACKTOP = sp;return ($97|0);
 }
 $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + 12|0);
 $94 = HEAP32[$93>>2]|0;
 FUNCTION_TABLE_vii[$94 & 4095]($91,$89);
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $95 = HEAP32[$18>>2]|0;
 $96 = (($95) + 1)|0;
 HEAP32[$18>>2] = $96;
 $97 = (($21) + ($95<<5)|0);
 STACKTOP = sp;return ($97|0);
}
function __ZN5physx6shdfnd5ArrayINS_8IntervalENS0_15InlineAllocatorILj32ENS0_19ReflectionAllocatorIS2_EEEEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $25 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = (($this) + 32|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = ($6>>>0)<(33);
  $or$cond$i$i = $9 & $10;
  if ($or$cond$i$i) {
   HEAP8[$7>>0] = 1;
   $$0$i$i = $this;
  } else {
   $11 = ($6|0)==(0);
   if ($11) {
    $$0$i$i = 0;
   } else {
    $12 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__Z15PxGetFoundationv()|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 24|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
    $$$i$i$i$i = $20 ? 531096 : 530312;
    $21 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$6,$$$i$i$i$i,530232,558)|0);
    $$0$i$i = $21;
   }
  }
  $25 = $$0$i$i;
 }
 $22 = (($this) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($23<<3)|0);
 $26 = (($this) + 36|0);
 $27 = ($23|0)>(0);
 if ($27) {
  $28 = HEAP32[$26>>2]|0;
  $$012$i = $25;$$03$i = $28;
  while(1) {
   $29 = ($$012$i|0)==(0|0);
   if (!($29)) {
    $30 = $$03$i;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = $$012$i;
    $37 = $36;
    HEAP32[$37>>2] = $32;
    $38 = (($36) + 4)|0;
    $39 = $38;
    HEAP32[$39>>2] = $35;
   }
   $40 = (($$012$i) + 8|0);
   $41 = (($$03$i) + 8|0);
   $42 = ($40>>>0)<($24>>>0);
   if ($42) {
    $$012$i = $40;$$03$i = $41;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$22>>2]|0;
  $44 = $$pre;
 } else {
  $44 = $23;
 }
 $43 = (($25) + ($44<<3)|0);
 $45 = ($43|0)==(0|0);
 if (!($45)) {
  $46 = $a;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) + 4)|0;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = $43;
  $53 = $52;
  HEAP32[$53>>2] = $48;
  $54 = (($52) + 4)|0;
  $55 = $54;
  HEAP32[$55>>2] = $51;
 }
 $56 = HEAP32[$0>>2]|0;
 $57 = ($56|0)>(-1);
 do {
  if ($57) {
   $58 = HEAP32[$26>>2]|0;
   $59 = ($this|0)==($58|0);
   if ($59) {
    $60 = (($this) + 32|0);
    HEAP8[$60>>0] = 0;
    break;
   }
   $61 = ($58|0)==(0|0);
   if (!($61)) {
    $62 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($63) + 12|0);
    $65 = HEAP32[$64>>2]|0;
    FUNCTION_TABLE_vii[$65 & 4095]($62,$58);
   }
  }
 } while(0);
 HEAP32[$26>>2] = $25;
 HEAP32[$0>>2] = $$$i;
 $66 = HEAP32[$22>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$22>>2] = $67;
 $68 = (($25) + ($66<<3)|0);
 STACKTOP = sp;return ($68|0);
}
function __ZN5physx6shdfnd4sortIjNS_19SortBoundsPredicateENS0_19ReflectionAllocatorIjEEEEvPT_jRKT0_RKT1_($elements,$count,$compare,$inAllocator) {
 $elements = $elements|0;
 $count = $count|0;
 $compare = $compare|0;
 $inAllocator = $inAllocator|0;
 var $$$i$i$i = 0, $$$i$i$i3 = 0, $$ph = 0, $$ph$be = 0, $$ph14 = 0, $$ph14$be = 0, $$ph15 = 0, $$ph15$be = 0, $$ph16 = 0, $$ph16$be = 0, $$ph17 = 0, $$ph17$be = 0, $$ph18 = 0, $$ph18$be = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$03$i = 0, $j$0$m$0$i = 0, $j$0$ph$i = 0, $j$02$i = 0, $j$1$i = 0, $m$01$i = 0;
 var $or$cond = 0, $or$cond6 = 0, $or$cond7 = 0, $stackMem = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $stackMem = sp;
 $0 = $stackMem;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($stackMem) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = sp + 8|0;
 HEAP32[$stackMem>>2] = $5;
 $6 = (($count) + -1)|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $8 = (($compare) + 4|0);
  $$ph = 0;$$ph14 = $5;$$ph15 = 32;$$ph16 = 0;$$ph17 = 0;$$ph18 = $6;
  L3: while(1) {
   $10 = $$ph18;$11 = $$ph17;$82 = $$ph16;
   while(1) {
    $9 = ($10|0)>($11|0);
    if ($9) {
     $12 = (($10) - ($11))|0;
     $13 = ($12>>>0)<(5);
     if (!($13)) {
      break;
     }
     $14 = HEAP32[$8>>2]|0;
     $i$03$i = $11;
     while(1) {
      $15 = (($i$03$i) + 1)|0;
      $16 = HEAP32[$compare>>2]|0;
      $j$02$i = $15;$m$01$i = $i$03$i;
      while(1) {
       $17 = (($elements) + ($j$02$i<<2)|0);
       $18 = (($elements) + ($m$01$i<<2)|0);
       $19 = HEAP32[$17>>2]|0;
       $20 = (($14) + ($19<<5)|0);
       $21 = (($20) + ($16<<2)|0);
       $22 = Math_fround(HEAPF32[$21>>2]);
       $23 = ((($14) + ($19<<5)|0) + 16|0);
       $24 = (($23) + ($16<<2)|0);
       $25 = Math_fround(HEAPF32[$24>>2]);
       $26 = Math_fround($22 + $25);
       $27 = HEAP32[$18>>2]|0;
       $28 = (($14) + ($27<<5)|0);
       $29 = (($28) + ($16<<2)|0);
       $30 = Math_fround(HEAPF32[$29>>2]);
       $31 = ((($14) + ($27<<5)|0) + 16|0);
       $32 = (($31) + ($16<<2)|0);
       $33 = Math_fround(HEAPF32[$32>>2]);
       $34 = Math_fround($30 + $33);
       $35 = $26 < $34;
       $j$0$m$0$i = $35 ? $j$02$i : $m$01$i;
       $36 = (($j$02$i) + 1)|0;
       $37 = ($j$02$i|0)<($10|0);
       if ($37) {
        $j$02$i = $36;$m$01$i = $j$0$m$0$i;
       } else {
        break;
       }
      }
      $38 = (($elements) + ($j$0$m$0$i<<2)|0);
      $39 = (($elements) + ($i$03$i<<2)|0);
      $40 = HEAP32[$38>>2]|0;
      $41 = HEAP32[$39>>2]|0;
      HEAP32[$38>>2] = $41;
      HEAP32[$39>>2] = $40;
      $exitcond$i = ($15|0)==($10|0);
      if ($exitcond$i) {
       break;
      } else {
       $i$03$i = $15;
      }
     }
    }
    $137 = ($82|0)==(0);
    if ($137) {
     break L3;
    }
    $138 = (($82) + -1)|0;
    $139 = (($$ph14) + ($138<<2)|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = (($82) + -2)|0;
    $142 = (($$ph14) + ($141<<2)|0);
    $143 = HEAP32[$142>>2]|0;
    $10 = $140;$11 = $143;$82 = $141;
   }
   __ZN5physx6shdfnd8internal7median3IjKNS_19SortBoundsPredicateEEEvPT_iiRT0_($elements,$11,$10,$compare);
   $42 = (($10) + -1)|0;
   $43 = (($elements) + ($42<<2)|0);
   $44 = HEAP32[$8>>2]|0;
   $i$0$ph$i = $11;$j$0$ph$i = $42;
   while(1) {
    $45 = HEAP32[$compare>>2]|0;
    $46 = HEAP32[$43>>2]|0;
    $47 = (($44) + ($46<<5)|0);
    $48 = (($47) + ($45<<2)|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = ((($44) + ($46<<5)|0) + 16|0);
    $51 = (($50) + ($45<<2)|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = Math_fround($49 + $52);
    $i$0$i = $i$0$ph$i;
    while(1) {
     $54 = (($i$0$i) + 1)|0;
     $55 = (($elements) + ($54<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($44) + ($56<<5)|0);
     $58 = (($57) + ($45<<2)|0);
     $59 = Math_fround(HEAPF32[$58>>2]);
     $60 = ((($44) + ($56<<5)|0) + 16|0);
     $61 = (($60) + ($45<<2)|0);
     $62 = Math_fround(HEAPF32[$61>>2]);
     $63 = Math_fround($59 + $62);
     $64 = $63 < $53;
     if ($64) {
      $i$0$i = $54;
     } else {
      $j$1$i = $j$0$ph$i;
      break;
     }
    }
    while(1) {
     $65 = (($j$1$i) + -1)|0;
     $66 = (($elements) + ($65<<2)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($44) + ($67<<5)|0);
     $69 = (($68) + ($45<<2)|0);
     $70 = Math_fround(HEAPF32[$69>>2]);
     $71 = ((($44) + ($67<<5)|0) + 16|0);
     $72 = (($71) + ($45<<2)|0);
     $73 = Math_fround(HEAPF32[$72>>2]);
     $74 = Math_fround($70 + $73);
     $75 = $53 < $74;
     if ($75) {
      $j$1$i = $65;
     } else {
      break;
     }
    }
    $76 = ($54|0)<($65|0);
    if (!($76)) {
     break;
    }
    HEAP32[$55>>2] = $67;
    HEAP32[$66>>2] = $56;
    $i$0$ph$i = $54;$j$0$ph$i = $65;
   }
   HEAP32[$55>>2] = $46;
   HEAP32[$43>>2] = $56;
   $77 = (($54) - ($11))|0;
   $78 = (($10) - ($54))|0;
   $79 = ($77|0)<($78|0);
   if ($79) {
    $80 = (($$ph15) + -1)|0;
    $81 = ($82>>>0)<($80>>>0);
    if ($81) {
     $106 = $$ph14;$153 = $$ph;$154 = $$ph15;
    } else {
     $83 = $$ph15 << 1;
     $84 = $$ph15 << 3;
     $85 = ($84|0)==(0);
     if ($85) {
      $97 = 0;
     } else {
      $86 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = (($87) + 8|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = (__Z15PxGetFoundationv()|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($91) + 24|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = (FUNCTION_TABLE_ii[$93 & 4095]($90)|0);
      $$$i$i$i3 = $94 ? 530992 : 530312;
      $95 = (FUNCTION_TABLE_iiiiii[$89 & 255]($86,$84,$$$i$i$i3,530904,148)|0);
      $97 = $95;
     }
     $96 = $82 << 2;
     _memcpy(($97|0),($$ph14|0),($96|0))|0;
     $98 = ($$ph<<24>>24)==(0);
     $99 = ($$ph14|0)==(0|0);
     $or$cond = $98 | $99;
     if ($or$cond) {
      $106 = $97;$153 = 1;$154 = $83;
     } else {
      $100 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = (($101) + 12|0);
      $103 = HEAP32[$102>>2]|0;
      FUNCTION_TABLE_vii[$103 & 4095]($100,$$ph14);
      $106 = $97;$153 = 1;$154 = $83;
     }
    }
    $104 = (($82) + 1)|0;
    $105 = (($106) + ($82<<2)|0);
    HEAP32[$105>>2] = $11;
    $107 = (($106) + ($104<<2)|0);
    HEAP32[$107>>2] = $i$0$i;
    $108 = (($i$0$i) + 2)|0;
    $$ph$be = $153;$$ph14$be = $106;$$ph15$be = $154;$$ph17$be = $108;$$ph18$be = $10;
   } else {
    $109 = (($i$0$i) + 2)|0;
    $110 = (($$ph15) + -1)|0;
    $111 = ($82>>>0)<($110>>>0);
    if ($111) {
     $135 = $$ph14;$155 = $$ph;$156 = $$ph15;
    } else {
     $112 = $$ph15 << 1;
     $113 = $$ph15 << 3;
     $114 = ($113|0)==(0);
     if ($114) {
      $126 = 0;
     } else {
      $115 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = (($116) + 8|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = (__Z15PxGetFoundationv()|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = (($120) + 24|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = (FUNCTION_TABLE_ii[$122 & 4095]($119)|0);
      $$$i$i$i = $123 ? 530992 : 530312;
      $124 = (FUNCTION_TABLE_iiiiii[$118 & 255]($115,$113,$$$i$i$i,530904,148)|0);
      $126 = $124;
     }
     $125 = $82 << 2;
     _memcpy(($126|0),($$ph14|0),($125|0))|0;
     $127 = ($$ph<<24>>24)==(0);
     $128 = ($$ph14|0)==(0|0);
     $or$cond6 = $127 | $128;
     if ($or$cond6) {
      $135 = $126;$155 = 1;$156 = $112;
     } else {
      $129 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = (($130) + 12|0);
      $132 = HEAP32[$131>>2]|0;
      FUNCTION_TABLE_vii[$132 & 4095]($129,$$ph14);
      $135 = $126;$155 = 1;$156 = $112;
     }
    }
    $133 = (($82) + 1)|0;
    $134 = (($135) + ($82<<2)|0);
    HEAP32[$134>>2] = $109;
    $136 = (($135) + ($133<<2)|0);
    HEAP32[$136>>2] = $10;
    $$ph$be = $155;$$ph14$be = $135;$$ph15$be = $156;$$ph17$be = $11;$$ph18$be = $i$0$i;
   }
   $$ph16$be = (($82) + 2)|0;
   $$ph = $$ph$be;$$ph14 = $$ph14$be;$$ph15 = $$ph15$be;$$ph16 = $$ph16$be;$$ph17 = $$ph17$be;$$ph18 = $$ph18$be;
  }
  $144 = ($$ph<<24>>24)==(0);
  $145 = ($$ph14|0)==(0|0);
  $or$cond7 = $144 | $145;
  if (!($or$cond7)) {
   $146 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = (($147) + 12|0);
   $149 = HEAP32[$148>>2]|0;
   FUNCTION_TABLE_vii[$149 & 4095]($146,$$ph14);
  }
 }
 $150 = HEAP8[$4>>0]|0;
 $151 = ($150<<24>>24)==(0);
 if ($151) {
  STACKTOP = sp;return;
 }
 $152 = HEAP32[$stackMem>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($stackMem,$152);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal7median3IjKNS_19SortBoundsPredicateEEEvPT_iiRT0_($elements,$first,$last,$compare) {
 $elements = $elements|0;
 $first = $first|0;
 $last = $last|0;
 $compare = $compare|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert10 = 0, $$phi$trans$insert2 = 0, $$phi$trans$insert4 = 0, $$phi$trans$insert5 = 0, $$phi$trans$insert8 = 0, $$pre = 0, $$pre1 = 0, $$pre11 = Math_fround(0), $$pre12 = 0, $$pre13 = 0, $$pre3 = Math_fround(0), $$pre6 = Math_fround(0), $$pre7 = 0, $$pre9 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0;
 var $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0;
 var $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($last) + ($first))|0;
 $1 = (($0|0) / 2)&-1;
 $2 = (($elements) + ($1<<2)|0);
 $3 = (($elements) + ($first<<2)|0);
 $4 = HEAP32[$2>>2]|0;
 $5 = (($compare) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$compare>>2]|0;
 $8 = (($6) + ($4<<5)|0);
 $9 = (($8) + ($7<<2)|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = ((($6) + ($4<<5)|0) + 16|0);
 $12 = (($11) + ($7<<2)|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($10 + $13);
 $15 = HEAP32[$3>>2]|0;
 $16 = (($6) + ($15<<5)|0);
 $17 = (($16) + ($7<<2)|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = ((($6) + ($15<<5)|0) + 16|0);
 $20 = (($19) + ($7<<2)|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($18 + $21);
 $23 = $14 < $22;
 if ($23) {
  HEAP32[$3>>2] = $4;
  HEAP32[$2>>2] = $15;
  $$pre = HEAP32[$compare>>2]|0;
  $$pre1 = HEAP32[$3>>2]|0;
  $$phi$trans$insert = (($6) + ($$pre1<<5)|0);
  $$phi$trans$insert2 = (($$phi$trans$insert) + ($$pre<<2)|0);
  $$pre3 = Math_fround(HEAPF32[$$phi$trans$insert2>>2]);
  $$phi$trans$insert4 = ((($6) + ($$pre1<<5)|0) + 16|0);
  $$phi$trans$insert5 = (($$phi$trans$insert4) + ($$pre<<2)|0);
  $$pre6 = Math_fround(HEAPF32[$$phi$trans$insert5>>2]);
  $28 = $$pre;$35 = $$pre6;$36 = $$pre3;$39 = $$pre1;$59 = $15;
 } else {
  $28 = $7;$35 = $21;$36 = $18;$39 = $15;$59 = $4;
 }
 $24 = (($elements) + ($last<<2)|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($6) + ($25<<5)|0);
 $27 = (($26) + ($28<<2)|0);
 $29 = Math_fround(HEAPF32[$27>>2]);
 $30 = ((($6) + ($25<<5)|0) + 16|0);
 $31 = (($30) + ($28<<2)|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($29 + $32);
 $34 = Math_fround($36 + $35);
 $37 = $33 < $34;
 if ($37) {
  $38 = ((($6) + ($39<<5)|0) + 16|0);
  $40 = (($6) + ($39<<5)|0);
  HEAP32[$3>>2] = $25;
  HEAP32[$24>>2] = $39;
  $$pre7 = HEAP32[$compare>>2]|0;
  $$phi$trans$insert8 = (($40) + ($$pre7<<2)|0);
  $$pre9 = Math_fround(HEAPF32[$$phi$trans$insert8>>2]);
  $$phi$trans$insert10 = (($38) + ($$pre7<<2)|0);
  $$pre11 = Math_fround(HEAPF32[$$phi$trans$insert10>>2]);
  $$pre12 = HEAP32[$2>>2]|0;
  $42 = $$pre11;$43 = $$pre9;$45 = $$pre12;$47 = $$pre7;$54 = $39;
 } else {
  $42 = $32;$43 = $29;$45 = $59;$47 = $28;$54 = $25;
 }
 $41 = Math_fround($43 + $42);
 $44 = (($6) + ($45<<5)|0);
 $46 = (($44) + ($47<<2)|0);
 $48 = Math_fround(HEAPF32[$46>>2]);
 $49 = ((($6) + ($45<<5)|0) + 16|0);
 $50 = (($49) + ($47<<2)|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($48 + $51);
 $53 = $41 < $52;
 if (!($53)) {
  $58 = $45;
  $55 = (($last) + -1)|0;
  $56 = (($elements) + ($55<<2)|0);
  $57 = HEAP32[$56>>2]|0;
  HEAP32[$2>>2] = $57;
  HEAP32[$56>>2] = $58;
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $54;
 HEAP32[$24>>2] = $45;
 $$pre13 = HEAP32[$2>>2]|0;
 $58 = $$pre13;
 $55 = (($last) + -1)|0;
 $56 = (($elements) + ($55<<2)|0);
 $57 = HEAP32[$56>>2]|0;
 HEAP32[$2>>2] = $57;
 HEAP32[$56>>2] = $58;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11RTreeNodeNQENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 5;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 530792 : 530312;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,530232,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<5)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$$03$i>>2]);
    HEAPF32[$$012$i>>2] = $20;
    $21 = (($$012$i) + 4|0);
    $22 = (($$03$i) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    HEAPF32[$21>>2] = $23;
    $24 = (($$012$i) + 8|0);
    $25 = (($$03$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    HEAPF32[$24>>2] = $26;
    $27 = (($$012$i) + 12|0);
    $28 = (($$03$i) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    HEAPF32[$27>>2] = $29;
    $30 = (($$012$i) + 16|0);
    $31 = (($$03$i) + 16|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    HEAPF32[$30>>2] = $32;
    $33 = (($$012$i) + 20|0);
    $34 = (($$03$i) + 20|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    HEAPF32[$33>>2] = $35;
    $36 = (($$012$i) + 24|0);
    $37 = (($$03$i) + 24|0);
    $38 = $37;
    $39 = $38;
    $40 = HEAP32[$39>>2]|0;
    $41 = (($38) + 4)|0;
    $42 = $41;
    $43 = HEAP32[$42>>2]|0;
    $44 = $36;
    $45 = $44;
    HEAP32[$45>>2] = $40;
    $46 = (($44) + 4)|0;
    $47 = $46;
    HEAP32[$47>>2] = $43;
   }
   $48 = (($$012$i) + 32|0);
   $49 = (($$03$i) + 32|0);
   $50 = ($48>>>0)<($15>>>0);
   if ($50) {
    $$012$i = $48;$$03$i = $49;
   } else {
    break;
   }
  }
 }
 $51 = (($this) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)>(-1);
 if (!($53)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$51>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $54 = HEAP32[$this>>2]|0;
 $55 = ($54|0)==(0|0);
 if ($55) {
  HEAP32[$this>>2] = $16;
  HEAP32[$51>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $56 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 12|0);
 $59 = HEAP32[$58>>2]|0;
 FUNCTION_TABLE_vii[$59 & 4095]($56,$54);
 HEAP32[$this>>2] = $16;
 HEAP32[$51>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx19TriangleMeshBuilder12loadFromDescERKNS_18PxTriangleMeshDescERKNS_15PxCookingParamsEb($this,$_desc,$params,$validateMesh) {
 $this = $this|0;
 $_desc = $_desc|0;
 $params = $params|0;
 $validateMesh = $validateMesh|0;
 var $$$i$i$i = 0, $$1 = 0, $$arith = 0, $$overflow = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $builder = 0, $desc = 0, $fabsf$i$i$1$i = Math_fround(0), $fabsf$i$i$2$i = Math_fround(0);
 var $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$1$i = Math_fround(0), $fabsf$i$i1$2$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $i$02 = 0, $or$cond = 0, $topology$0 = 0, $vararg_buffer2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer2 = sp;
 $desc = sp + 24|0;
 $0 = sp + 64|0;
 $builder = sp + 8|0;
 $1 = (($_desc) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)<(3);
 do {
  if (!($3)) {
   $4 = (($_desc) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    $7 = (($2>>>0) % 3)&-1;
    $8 = ($7|0)==(0);
    if (!($8)) {
     break;
    }
   }
   $9 = (($_desc) + 32|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = (($_desc) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13>>>0)<(2);
    if ($14) {
     break;
    }
   }
   $15 = ($2>>>0)>(65535);
   if ($15) {
    $16 = (($_desc) + 24|0);
    $17 = HEAP16[$16>>1]|0;
    $18 = $17 & 2;
    $19 = ($18<<16>>16)==(0);
    if (!($19)) {
     break;
    }
   }
   $20 = (($_desc) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    $23 = HEAP32[$_desc>>2]|0;
    $24 = ($23>>>0)<(12);
    if (!($24)) {
     $$phi$trans$insert = (($_desc) + 24|0);
     $$pre = HEAP16[$$phi$trans$insert>>1]|0;
     if (!($6)) {
      $25 = $$pre & 2;
      $26 = ($25<<16>>16)!=(0);
      $27 = $26 ? 6 : 12;
      $28 = (($_desc) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29>>>0)<($27>>>0);
      if ($30) {
       break;
      }
     }
     ;HEAP32[$desc+0>>2]=HEAP32[$_desc+0>>2]|0;HEAP32[$desc+4>>2]=HEAP32[$_desc+4>>2]|0;HEAP32[$desc+8>>2]=HEAP32[$_desc+8>>2]|0;HEAP32[$desc+12>>2]=HEAP32[$_desc+12>>2]|0;HEAP32[$desc+16>>2]=HEAP32[$_desc+16>>2]|0;HEAP32[$desc+20>>2]=HEAP32[$_desc+20>>2]|0;
     $32 = (($desc) + 24|0);
     HEAP16[$32>>1] = $$pre;
     $33 = (($desc) + 28|0);
     $34 = (($_desc) + 28|0);
     ;HEAP32[$33+0>>2]=HEAP32[$34+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$34+8>>2]|0;
     $35 = (($_desc) + 36|0);
     $36 = Math_fround(HEAPF32[$35>>2]);
     $37 = (($this) + 16|0);
     $38 = (($this) + 192|0);
     HEAPF32[$38>>2] = $36;
     $39 = (($desc) + 16|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $42 = $$pre & -3;
      HEAP16[$32>>1] = $42;
      $43 = (($desc) + 12|0);
      HEAP32[$43>>2] = 12;
      $44 = (($desc) + 8|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = (($45>>>0) / 3)&-1;
      $47 = (($desc) + 20|0);
      HEAP32[$47>>2] = $46;
      $$arith = $45<<2;
      $$overflow = ($45>>>0)>(1073741823);
      $48 = $$overflow ? -1 : $$arith;
      $49 = ($48|0)==(0);
      if ($49) {
       $62 = 0;
      } else {
       $50 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 8|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (__Z15PxGetFoundationv()|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = (($55) + 24|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = (FUNCTION_TABLE_ii[$57 & 4095]($54)|0);
       $$$i$i$i = $58 ? 531504 : 531472;
       $59 = (FUNCTION_TABLE_iiiiii[$53 & 255]($50,$48,$$$i$i$i,531200,73)|0);
       $62 = $59;
      }
      $60 = ($45|0)==(0);
      if (!($60)) {
       $i$02 = 0;
       while(1) {
        $61 = (($62) + ($i$02<<2)|0);
        HEAP32[$61>>2] = $i$02;
        $63 = (($i$02) + 1)|0;
        $64 = ($63>>>0)<($45>>>0);
        if ($64) {
         $i$02 = $63;
        } else {
         break;
        }
       }
      }
      HEAP32[$39>>2] = $62;
      $topology$0 = $62;
     } else {
      $topology$0 = 0;
     }
     $65 = (__ZN5physx19TriangleMeshBuilder10importMeshERKNS_18PxTriangleMeshDescERKNS_15PxCookingParamsEb($this,$desc,$params,$validateMesh)|0);
     if (!($65)) {
      $$1 = 0;
      STACKTOP = sp;return ($$1|0);
     }
     __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$topology$0);
     $66 = (($params) + 40|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = $67 < Math_fround(0.0);
     $69 = $67 > Math_fround(1.0);
     $or$cond = $68 | $69;
     if ($or$cond) {
      $70 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
      $71 = Math_fround(HEAPF32[$66>>2]);
      $72 = +$71;
      HEAPF64[tempDoublePtr>>3]=$72;HEAP32[$vararg_buffer2>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer2+4>>2]=HEAP32[tempDoublePtr+4>>2];
      __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($70,2,531200,92,531352,$vararg_buffer2);
     }
     __ZN5physx27InternalTriangleMeshBuilderC2EPNS_20InternalTriangleMeshERKNS_15PxCookingParamsE($builder,$37,$params);
     (__ZN5physx27InternalTriangleMeshBuilder11createRTreeEv($builder)|0);
     $73 = (($this) + 144|0);
     $74 = (($this) + 16|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($this) + 24|0);
     $77 = HEAP32[$76>>2]|0;
     __ZN5physx2Gu27computeBoundsAroundVerticesERNS_9PxBounds3EjPKNS_6PxVec3E($73,$75,$77);
     $78 = (($this) + 156|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($79)))));
     $80 = Math_fround(HEAPF32[$73>>2]);
     $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($80)))));
     $81 = $fabsf$i$i1$i > $fabsf$i$i$i;
     $82 = $81 ? $fabsf$i$i1$i : $fabsf$i$i$i;
     $83 = $82 < Math_fround(0.0);
     $84 = $83 ? Math_fround(0.0) : $82;
     $85 = (($78) + 4|0);
     $86 = Math_fround(HEAPF32[$85>>2]);
     $fabsf$i$i1$1$i = (Math_fround(Math_abs((Math_fround($86)))));
     $87 = (($73) + 4|0);
     $88 = Math_fround(HEAPF32[$87>>2]);
     $fabsf$i$i$1$i = (Math_fround(Math_abs((Math_fround($88)))));
     $89 = $fabsf$i$i1$1$i > $fabsf$i$i$1$i;
     $90 = $89 ? $fabsf$i$i1$1$i : $fabsf$i$i$1$i;
     $91 = $84 > $90;
     $92 = $91 ? $84 : $90;
     $93 = (($78) + 8|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $fabsf$i$i1$2$i = (Math_fround(Math_abs((Math_fround($94)))));
     $95 = (($73) + 8|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $fabsf$i$i$2$i = (Math_fround(Math_abs((Math_fround($96)))));
     $97 = $fabsf$i$i1$2$i > $fabsf$i$i$2$i;
     $98 = $97 ? $fabsf$i$i1$2$i : $fabsf$i$i$2$i;
     $99 = $92 > $98;
     $100 = $99 ? $92 : $98;
     $101 = Math_fround($100 * Math_fround(2.384185791015625E-7));
     $102 = (($this) + 36|0);
     HEAPF32[$102>>2] = $101;
     $103 = (($params) + 13|0);
     $104 = HEAP8[$103>>0]|0;
     $105 = ($104<<24>>24)!=(0);
     $106 = (($params) + 28|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = $107 & 16;
     $109 = ($108|0)==(0);
     __ZN5physx27InternalTriangleMeshBuilder20createSharedEdgeDataEbb($builder,$105,$109);
     __ZN5physx27InternalTriangleMeshBuilderD2Ev($builder);
     $$1 = 1;
     STACKTOP = sp;return ($$1|0);
    }
   }
  }
 } while(0);
 $31 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($31,4,531200,51,531296,$vararg_buffer2);
 $$1 = 0;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx19TriangleMeshBuilder10importMeshERKNS_18PxTriangleMeshDescERKNS_15PxCookingParamsEb($this,$desc,$params,$validate) {
 $this = $this|0;
 $desc = $desc|0;
 $params = $params|0;
 $validate = $validate|0;
 var $$01$i = 0, $$01$i5 = 0, $$1 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $9 = 0, $brmerge = 0, $builder = 0, $builder1 = 0, $d$03$i = 0, $d$03$i3 = 0, $dest$016 = 0, $dest$112 = 0, $s$02$i = 0, $s$02$i4 = 0, $source$015 = 0, $source$111 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $builder = sp + 16|0;
 $builder1 = sp + 4|0;
 $0 = (($this) + 16|0);
 __ZN5physx20InternalTriangleMesh7releaseEv($0);
 $1 = (($desc) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN5physx20InternalTriangleMesh16allocateVerticesEj($0,$2)|0);
 $4 = (($desc) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN5physx20InternalTriangleMesh17allocateTrianglesEjb($0,$5,1)|0);
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$desc>>2]|0;
 $9 = ($7|0)==(0);
 if (!($9)) {
  $10 = (($desc) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $$01$i = $7;$d$03$i = $3;$s$02$i = $11;
  while(1) {
   $12 = (($$01$i) + -1)|0;
   dest=$d$03$i+0|0; src=$s$02$i+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $13 = (($d$03$i) + 12|0);
   $14 = (($s$02$i) + ($8)|0);
   $15 = ($12|0)==(0);
   if ($15) {
    break;
   } else {
    $$01$i = $12;$d$03$i = $13;$s$02$i = $14;
   }
  }
 }
 $16 = (($this) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($6) + (($17*12)|0)|0);
 $19 = (($desc) + 12|0);
 $20 = (($desc) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($desc) + 24|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = $23&65535;
 $25 = $24 & 1;
 $26 = $24 & 2;
 $27 = ($26|0)==(0);
 $28 = ($6>>>0)<($18>>>0);
 if ($27) {
  if ($28) {
   $31 = (($25) + 1)|0;
   $32 = (2 - ($25))|0;
   $dest$112 = $6;$source$111 = $21;
   while(1) {
    $47 = HEAP32[$source$111>>2]|0;
    HEAP32[$dest$112>>2] = $47;
    $48 = (($source$111) + ($31<<2)|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($dest$112) + 4|0);
    HEAP32[$50>>2] = $49;
    $51 = (($source$111) + ($32<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($dest$112) + 8|0);
    HEAP32[$53>>2] = $52;
    $54 = (($dest$112) + 12|0);
    $55 = HEAP32[$19>>2]|0;
    $56 = (($source$111) + ($55)|0);
    $57 = ($54>>>0)<($18>>>0);
    if ($57) {
     $dest$112 = $54;$source$111 = $56;
    } else {
     break;
    }
   }
  }
 } else {
  if ($28) {
   $29 = (($25) + 1)|0;
   $30 = (2 - ($25))|0;
   $dest$016 = $6;$source$015 = $21;
   while(1) {
    $33 = HEAP16[$source$015>>1]|0;
    $34 = $33&65535;
    HEAP32[$dest$016>>2] = $34;
    $35 = (($source$015) + ($29<<1)|0);
    $36 = HEAP16[$35>>1]|0;
    $37 = $36&65535;
    $38 = (($dest$016) + 4|0);
    HEAP32[$38>>2] = $37;
    $39 = (($source$015) + ($30<<1)|0);
    $40 = HEAP16[$39>>1]|0;
    $41 = $40&65535;
    $42 = (($dest$016) + 8|0);
    HEAP32[$42>>2] = $41;
    $43 = (($dest$016) + 12|0);
    $44 = HEAP32[$19>>2]|0;
    $45 = (($source$015) + ($44)|0);
    $46 = ($43>>>0)<($18>>>0);
    if ($46) {
     $dest$016 = $43;$source$015 = $45;
    } else {
     break;
    }
   }
  }
 }
 $58 = (($desc) + 32|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0|0);
 if (!($60)) {
  $61 = (__ZN5physx20InternalTriangleMesh17allocateMaterialsEv($0)|0);
  $62 = HEAP32[$16>>2]|0;
  $63 = (($desc) + 28|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ($62|0)==(0);
  if (!($65)) {
   $66 = HEAP32[$58>>2]|0;
   $$01$i5 = $62;$d$03$i3 = $61;$s$02$i4 = $66;
   while(1) {
    $67 = (($$01$i5) + -1)|0;
    $68 = HEAPU8[$s$02$i4>>0]|(HEAPU8[$s$02$i4+1>>0]<<8);
    HEAP8[$d$03$i3>>0]=$68&255;HEAP8[$d$03$i3+1>>0]=$68>>8;
    $69 = (($d$03$i3) + 2|0);
    $70 = (($s$02$i4) + ($64)|0);
    $71 = ($67|0)==(0);
    if ($71) {
     break;
    } else {
     $$01$i5 = $67;$d$03$i3 = $69;$s$02$i4 = $70;
    }
   }
  }
 }
 $72 = (($params) + 28|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73 & 8;
 $$not = ($74|0)==(0);
 $brmerge = $$not | $validate;
 if (!($brmerge)) {
  $77 = (($params) + 12|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = ($78<<24>>24)==(0);
  if (!($79)) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
  __ZN5physx27InternalTriangleMeshBuilderC2EPNS_20InternalTriangleMeshERKNS_15PxCookingParamsE($builder1,$0,$params);
  __ZN5physx27InternalTriangleMeshBuilder14fillRemapTableEv($builder1);
  __ZN5physx27InternalTriangleMeshBuilderD2Ev($builder1);
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 __ZN5physx27InternalTriangleMeshBuilderC2EPNS_20InternalTriangleMeshERKNS_15PxCookingParamsE($builder,$0,$params);
 $75 = (__ZN5physx27InternalTriangleMeshBuilder9cleanMeshEb($builder,$validate)|0);
 if ($75) {
  __ZN5physx27InternalTriangleMeshBuilderD2Ev($builder);
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 if ($validate) {
  __ZN5physx27InternalTriangleMeshBuilderD2Ev($builder);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 } else {
  $76 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($76,32,531200,279,531440,$vararg_buffer);
  __ZN5physx27InternalTriangleMeshBuilderD2Ev($builder);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZNK5physx19TriangleMeshBuilder4saveERNS_14PxOutputStreamEb($this,$stream,$platformMismatch) {
 $this = $this|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 var $$ = 0, $$0 = 0, $$maxIndex$0 = 0, $$maxIndex$2 = 0, $$serialFlags$1$ = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0;
 var $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $data = 0, $i$05 = 0, $i1$03 = 0, $i3$01 = 0, $maxIndex$06 = 0, $maxIndex$2 = 0, $not$ = 0, $serialFlags$1 = 0, $serialFlags$1$ = 0, $serialFlags$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 $0 = (__ZN5physx11writeHeaderEaaaajbRNS_14PxOutputStreamE(77,69,83,72,12,$platformMismatch,$stream)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 176|0);
 $2 = HEAP32[$1>>2]|0;
 $not$ = ($2|0)!=(0|0);
 $$ = $not$&1;
 $3 = (($this) + 180|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = $$ | 2;
 $serialFlags$1 = $5 ? $$ : $6;
 $7 = (($this) + 184|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 $10 = $serialFlags$1 | 16;
 $serialFlags$1$ = $9 ? $serialFlags$1 : $10;
 $11 = (($this) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  label = 5;
 } else {
  $i$05 = 0;$maxIndex$06 = 0;
  while(1) {
   $16 = (($12) + (($i$05*12)|0)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17>>>0)>($maxIndex$06>>>0);
   $$maxIndex$0 = $18 ? $17 : $maxIndex$06;
   $19 = ((($12) + (($i$05*12)|0)|0) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20>>>0)>($$maxIndex$0>>>0);
   $maxIndex$2 = $21 ? $20 : $$maxIndex$0;
   $22 = ((($12) + (($i$05*12)|0)|0) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23>>>0)>($maxIndex$2>>>0);
   $$maxIndex$2 = $24 ? $23 : $maxIndex$2;
   $25 = (($i$05) + 1)|0;
   $26 = ($25>>>0)<($14>>>0);
   if ($26) {
    $i$05 = $25;$maxIndex$06 = $$maxIndex$2;
   } else {
    break;
   }
  }
  $27 = ($$maxIndex$2>>>0)<(256);
  if ($27) {
   label = 5;
  } else {
   $29 = ($$maxIndex$2>>>0)<(65536);
   $30 = $serialFlags$1$ | 8;
   $$serialFlags$1$ = $29 ? $30 : $serialFlags$1$;
   $serialFlags$3 = $$serialFlags$1$;
  }
 }
 if ((label|0) == 5) {
  $28 = $serialFlags$1$ | 4;
  $serialFlags$3 = $28;
 }
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($serialFlags$3,$platformMismatch,$stream);
 $31 = (($this) + 192|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($32,$platformMismatch,$stream);
 $33 = (($this) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($34,$platformMismatch,$stream);
 $35 = HEAP32[$13>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($35,$platformMismatch,$stream);
 $36 = (($this) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$33>>2]|0;
 $39 = ($38*3)|0;
 __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($37,$39,$platformMismatch,$stream);
 $40 = $serialFlags$3 & 4;
 $41 = ($40|0)==(0);
 do {
  if ($41) {
   $54 = $serialFlags$3 & 8;
   $55 = ($54|0)==(0);
   $56 = HEAP32[$13>>2]|0;
   $57 = ($56*3)|0;
   if ($55) {
    __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($12,$57,$platformMismatch,$stream);
    break;
   }
   $58 = ($57|0)==(0);
   if (!($58)) {
    $i3$01 = 0;
    while(1) {
     $59 = (($12) + ($i3$01<<2)|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = $60&65535;
     __ZN5physx9writeWordEtbRNS_14PxOutputStreamE($61,$platformMismatch,$stream);
     $62 = (($i3$01) + 1)|0;
     $63 = HEAP32[$13>>2]|0;
     $64 = ($63*3)|0;
     $65 = ($62>>>0)<($64>>>0);
     if ($65) {
      $i3$01 = $62;
     } else {
      break;
     }
    }
   }
  } else {
   $42 = HEAP32[$13>>2]|0;
   $43 = ($42*3)|0;
   $44 = ($43|0)==(0);
   if (!($44)) {
    $i1$03 = 0;
    while(1) {
     $45 = (($12) + ($i1$03<<2)|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = $46&255;
     HEAP8[$data>>0] = $47;
     $48 = HEAP32[$stream>>2]|0;
     $49 = HEAP32[$48>>2]|0;
     (FUNCTION_TABLE_iiii[$49 & 2047]($stream,$data,1)|0);
     $50 = (($i1$03) + 1)|0;
     $51 = HEAP32[$13>>2]|0;
     $52 = ($51*3)|0;
     $53 = ($50>>>0)<($52>>>0);
     if ($53) {
      $i1$03 = $50;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 $66 = HEAP32[$1>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = HEAP32[$13>>2]|0;
  __ZN5physx15writeWordBufferEPKtjbRNS_14PxOutputStreamE($66,$68,$platformMismatch,$stream);
 }
 $69 = HEAP32[$3>>2]|0;
 $70 = ($69|0)==(0|0);
 if (!($70)) {
  $71 = HEAP32[$13>>2]|0;
  $72 = (__ZN5physx15computeMaxIndexEPKjj($69,$71)|0);
  __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($72,$platformMismatch,$stream);
  $73 = HEAP32[$13>>2]|0;
  $74 = HEAP32[$3>>2]|0;
  __ZN5physx12storeIndicesEjjPKjRNS_14PxOutputStreamEb($72,$73,$74,$stream,$platformMismatch);
 }
 $75 = HEAP32[$7>>2]|0;
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  $77 = HEAP32[$13>>2]|0;
  $78 = ($77*3)|0;
  __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($75,$78,$platformMismatch,$stream);
 }
 $79 = (($this) + 48|0);
 (__ZNK5physx2Gu5RTree4saveERNS_14PxOutputStreamE($79,$stream)|0);
 $80 = (($this) + 36|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($81,$platformMismatch,$stream);
 $82 = (($this) + 144|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($83,$platformMismatch,$stream);
 $84 = (($this) + 148|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($85,$platformMismatch,$stream);
 $86 = (($this) + 152|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($87,$platformMismatch,$stream);
 $88 = (($this) + 156|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($89,$platformMismatch,$stream);
 $90 = (($this) + 160|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($91,$platformMismatch,$stream);
 $92 = (($this) + 164|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($93,$platformMismatch,$stream);
 $94 = (($this) + 168|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 if ($96) {
  __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE(0,$platformMismatch,$stream);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $97 = HEAP32[$13>>2]|0;
  __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($97,$platformMismatch,$stream);
  $98 = HEAP32[$stream>>2]|0;
  $99 = HEAP32[$98>>2]|0;
  $100 = HEAP32[$94>>2]|0;
  $101 = HEAP32[$13>>2]|0;
  (FUNCTION_TABLE_iiii[$99 & 2047]($stream,$100,$101)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx20BigConvexDataBuilderC2EPKNS_2Gu14ConvexHullDataEPNS_13BigConvexDataEPKNS_6PxVec3E($this,$hull,$gm,$hullVerts) {
 $this = $this|0;
 $hull = $hull|0;
 $gm = $gm|0;
 $hullVerts = $hullVerts|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $hullVerts;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $gm;
 HEAP32[$this>>2] = $hull;
 STACKTOP = sp;return;
}
function __ZN5physx20BigConvexDataBuilderD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx20BigConvexDataBuilder4SaveERNS_14PxOutputStreamEbjPKNS_16HullTriangleDataE($this,$stream,$platformMismatch,$nbFaces,$faces) {
 $this = $this|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 $nbFaces = $nbFaces|0;
 $faces = $faces|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vc$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vc$i = sp;
 $0 = (__ZN5physx2Gu11WriteHeaderEhhhhjbRNS_14PxOutputStreamE(83,85,80,77,0,$platformMismatch,$stream)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN5physx2Gu11WriteHeaderEhhhhjbRNS_14PxOutputStreamE(71,65,85,83,0,$platformMismatch,$stream)|0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($5,$platformMismatch,$stream);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 2|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($9,$platformMismatch,$stream);
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$2>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 2|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16&65535;
 $18 = $17 << 1;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$14,$18)|0);
 ;HEAP32[$vc$i+0>>2]=0|0;HEAP32[$vc$i+4>>2]=0|0;HEAP32[$vc$i+8>>2]=0|0;HEAP32[$vc$i+12>>2]=0|0;HEAP32[$vc$i+16>>2]=0|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 38|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 HEAP32[$vc$i>>2] = $22;
 $23 = (($vc$i) + 4|0);
 HEAP32[$23>>2] = $nbFaces;
 $24 = (($vc$i) + 8|0);
 HEAP32[$24>>2] = $faces;
 $25 = (($vc$i) + 16|0);
 HEAP8[$25>>0] = 1;
 (__ZNK5physx20BigConvexDataBuilder7ComputeERKNS_15VALENCIESCREATEE($this,$vc$i)|0);
 $26 = (__ZNK5physx20BigConvexDataBuilder4SaveERNS_14PxOutputStreamEb($this,$stream,$platformMismatch)|0);
 $$0 = $26;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx20BigConvexDataBuilder4SaveERNS_14PxOutputStreamEb($this,$stream,$platformMismatch) {
 $this = $this|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 var $$$i$i$i = 0, $$0 = 0, $$arith = 0, $$lcssa = 0, $$overflow = 0, $$phi$trans$insert = 0, $$phi$trans$insert3 = 0, $$pre = 0, $$pre2 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx2Gu11WriteHeaderEhhhhjbRNS_14PxOutputStreamE(86,65,76,69,2,$platformMismatch,$stream)|0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($5,$platformMismatch,$stream);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($8,$platformMismatch,$stream);
 $9 = HEAP32[$2>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $$arith = $11<<1;
 $$overflow = ($11>>>0)>(2147483647);
 $12 = $$overflow ? -1 : $$arith;
 $13 = ($12|0)==(0);
 if ($13) {
  $25 = $11;$26 = $9;$30 = 0;
 } else {
  $14 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (__Z15PxGetFoundationv()|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 24|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 4095]($18)|0);
  $$$i$i$i = $22 ? 531736 : 531704;
  $23 = (FUNCTION_TABLE_iiiiii[$17 & 255]($14,$12,$$$i$i$i,531608,299)|0);
  $$pre = HEAP32[$2>>2]|0;
  $$phi$trans$insert = (($$pre) + 8|0);
  $$pre2 = HEAP32[$$phi$trans$insert>>2]|0;
  $25 = $$pre2;$26 = $$pre;$30 = $23;
 }
 $24 = ($25|0)==(0);
 if ($24) {
  $$lcssa = 0;
 } else {
  $$phi$trans$insert3 = (($26) + 16|0);
  $$pre4 = HEAP32[$$phi$trans$insert3>>2]|0;
  $i$01 = 0;
  while(1) {
   $27 = (($$pre4) + ($i$01<<2)|0);
   $28 = HEAP16[$27>>1]|0;
   $29 = (($30) + ($i$01<<1)|0);
   HEAP16[$29>>1] = $28;
   $31 = (($i$01) + 1)|0;
   $32 = ($31>>>0)<($25>>>0);
   if ($32) {
    $i$01 = $31;
   } else {
    $$lcssa = $25;
    break;
   }
  }
 }
 $33 = (__ZN5physx15computeMaxIndexEPKtj($30,$$lcssa)|0);
 $34 = $33&65535;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($34,$platformMismatch,$stream);
 $35 = HEAP32[$2>>2]|0;
 $36 = (($35) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 __ZN5physx2Gu12StoreIndicesEtjPKtRNS_14PxOutputStreamEb($33,$37,$30,$stream,$platformMismatch);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$30);
 $38 = HEAP32[$stream>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = (($40) + 20|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 (FUNCTION_TABLE_iiii[$39 & 2047]($stream,$42,$44)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx20BigConvexDataBuilder7ComputeERKNS_15VALENCIESCREATEE($this,$vc) {
 $this = $this|0;
 $vc = $vc|0;
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$0 = 0, $$arith = 0, $$overflow = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $EL = 0, $ELC = 0, $i$03 = 0, $i1$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $EL = sp + 24|0;
 $ELC = sp;
 $0 = HEAP32[$vc>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 HEAP32[$3>>2] = $0;
 $$arith = $0<<2;
 $$overflow = ($0>>>0)>(1073741823);
 $4 = $$overflow ? -1 : $$arith;
 $5 = ($4|0)==(0);
 if ($5) {
  $17 = $2;$18 = 0;
 } else {
  $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__Z15PxGetFoundationv()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
  $$$i$i$i1 = $14 ? 531840 : 531704;
  $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,$4,$$$i$i$i1,531608,226)|0);
  $$pre = HEAP32[$1>>2]|0;
  $17 = $$pre;$18 = $15;
 }
 $16 = (($17) + 16|0);
 HEAP32[$16>>2] = $18;
 $19 = HEAP32[$1>>2]|0;
 $20 = (($19) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 << 2;
 _memset(($21|0),0,($24|0))|0;
 __ZN5physx2Gu15EdgeListBuilderC2Ev($EL);
 $25 = (($ELC) + 16|0);
 HEAP32[$25>>2] = 0;
 $26 = (($ELC) + 20|0);
 ;HEAP32[$ELC+0>>2]=0|0;HEAP32[$ELC+4>>2]=0|0;HEAP32[$ELC+8>>2]=0|0;HEAP16[$ELC+12>>1]=0|0;
 HEAPF32[$26>>2] = Math_fround(0.100000001490116119385);
 $27 = (($vc) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$ELC>>2] = $28;
 $29 = (($vc) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($ELC) + 4|0);
 HEAP32[$31>>2] = $30;
 $32 = (($vc) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($ELC) + 8|0);
 HEAP32[$34>>2] = $33;
 $35 = (($ELC) + 12|0);
 HEAP8[$35>>0] = 1;
 $36 = (__ZN5physx2Gu15EdgeListBuilder4InitERKNS0_14EDGELISTCREATEE($EL,$ELC)|0);
 if (!($36)) {
  $$0 = 0;
  __ZN5physx2Gu8EdgeListD2Ev($EL);
  STACKTOP = sp;return ($$0|0);
 }
 $37 = HEAP32[$EL>>2]|0;
 $38 = ($37|0)==(0);
 if (!($38)) {
  $39 = (($EL) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = HEAP32[$1>>2]|0;
  $42 = (($41) + 16|0);
  $43 = HEAP32[$42>>2]|0;
  $i$03 = 0;
  while(1) {
   $44 = (($40) + ($i$03<<3)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($43) + ($45<<2)|0);
   $47 = HEAP16[$46>>1]|0;
   $48 = (($47) + 1)<<16>>16;
   HEAP16[$46>>1] = $48;
   $49 = ((($40) + ($i$03<<3)|0) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($43) + ($50<<2)|0);
   $52 = HEAP16[$51>>1]|0;
   $53 = (($52) + 1)<<16>>16;
   HEAP16[$51>>1] = $53;
   $54 = (($i$03) + 1)|0;
   $55 = ($54>>>0)<($37>>>0);
   if ($55) {
    $i$03 = $54;
   } else {
    break;
   }
  }
 }
 $56 = (($vc) + 16|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  $$0 = 1;
  __ZN5physx2Gu8EdgeListD2Ev($EL);
  STACKTOP = sp;return ($$0|0);
 }
 $59 = HEAP32[$1>>2]|0;
 __ZN5physx13BigConvexData13CreateOffsetsEv($59);
 $60 = HEAP32[$1>>2]|0;
 $61 = (($60) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + -1)|0;
 $64 = (($60) + 16|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($65) + ($63<<2)|0) + 2|0);
 $67 = HEAP16[$66>>1]|0;
 $68 = $67&65535;
 $69 = (($65) + ($63<<2)|0);
 $70 = HEAP16[$69>>1]|0;
 $71 = $70&65535;
 $72 = (($71) + ($68))|0;
 $73 = (($60) + 12|0);
 HEAP32[$73>>2] = $72;
 $74 = ($72|0)==(0);
 if ($74) {
  $86 = $60;$87 = 0;
 } else {
  $75 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($76) + 8|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (__Z15PxGetFoundationv()|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($80) + 24|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (FUNCTION_TABLE_ii[$82 & 4095]($79)|0);
  $$$i$i$i = $83 ? 531952 : 531704;
  $84 = (FUNCTION_TABLE_iiiiii[$78 & 255]($75,$72,$$$i$i$i,531608,269)|0);
  $$pre6 = HEAP32[$1>>2]|0;
  $86 = $$pre6;$87 = $84;
 }
 $85 = (($86) + 20|0);
 HEAP32[$85>>2] = $87;
 $88 = HEAP32[$EL>>2]|0;
 $89 = ($88|0)==(0);
 if (!($89)) {
  $90 = (($EL) + 4|0);
  $i1$02 = 0;
  while(1) {
   $91 = HEAP32[$90>>2]|0;
   $92 = (($91) + ($i1$02<<3)|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ((($91) + ($i1$02<<3)|0) + 4|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = $95&255;
   $97 = HEAP32[$1>>2]|0;
   $98 = (($97) + 16|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ((($99) + ($93<<2)|0) + 2|0);
   $101 = HEAP16[$100>>1]|0;
   $102 = (($101) + 1)<<16>>16;
   HEAP16[$100>>1] = $102;
   $103 = $101&65535;
   $104 = (($97) + 20|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + ($103)|0);
   HEAP8[$106>>0] = $96;
   $107 = $93&255;
   $108 = HEAP32[$1>>2]|0;
   $109 = (($108) + 16|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ((($110) + ($95<<2)|0) + 2|0);
   $112 = HEAP16[$111>>1]|0;
   $113 = (($112) + 1)<<16>>16;
   HEAP16[$111>>1] = $113;
   $114 = $112&65535;
   $115 = (($108) + 20|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (($116) + ($114)|0);
   HEAP8[$117>>0] = $107;
   $118 = (($i1$02) + 1)|0;
   $119 = HEAP32[$EL>>2]|0;
   $120 = ($118>>>0)<($119>>>0);
   if ($120) {
    $i1$02 = $118;
   } else {
    break;
   }
  }
 }
 $121 = HEAP32[$1>>2]|0;
 __ZN5physx13BigConvexData13CreateOffsetsEv($121);
 $$0 = 1;
 __ZN5physx2Gu8EdgeListD2Ev($EL);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx20BigConvexDataBuilder10PrecomputeEj($this,$subdiv) {
 $this = $this|0;
 $subdiv = $subdiv|0;
 var $$$i$i$i$i = 0, $$lcssa10 = Math_fround(0), $$lcssa11 = Math_fround(0), $$lcssa9 = Math_fround(0), $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0;
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0);
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $Face$019 = 0, $MinID$0$lcssa$i = 0, $MinID$0$lcssa$i$us = 0, $MinID$02$i = 0, $MinID$02$i$us = 0, $MinID$1$i = 0, $MinID$1$i$us = 0, $MinID2$0$lcssa$i = 0, $MinID2$0$lcssa$i$us = 0, $MinID2$03$i = 0, $MinID2$03$i$us = 0, $MinID2$1$i = 0, $MinID2$1$i$us = 0;
 var $exitcond = 0, $exitcond$i = 0, $exitcond$i$us = 0, $exitcond26 = 0, $exitcond27 = 0, $exitcond28 = 0, $i$04 = 0, $i$04$i = 0, $i$04$i$us = 0, $i$04$us = 0, $j$012 = 0, $min2$01$i = Math_fround(0), $min2$01$i$us = Math_fround(0), $min2$1$i = Math_fround(0), $min2$1$i$us = Math_fround(0), $minimum$05$i = Math_fround(0), $minimum$05$i$us = Math_fround(0), $minimum$1$i = Math_fround(0), $minimum$1$i$us = Math_fround(0), $phitmp$i = 0;
 var $phitmp$i$us = 0, $phitmp7$i = 0, $phitmp7$i$us = 0, $split = Math_fround(0), $split6 = Math_fround(0), $split7 = Math_fround(0), $tmp = 0, $tmp$us = 0, $tmp1 = 0, $tmp1$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($subdiv*6)|0;
 $1 = Math_imul($0, $subdiv)|0;
 $2 = $subdiv&65535;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP16[$4>>1] = $2;
 $5 = $1&65535;
 $6 = (($4) + 2|0);
 HEAP16[$6>>1] = $5;
 $7 = ($5<<16>>16)==(0);
 if ($7) {
  $21 = $4;$22 = 0;
 } else {
  $8 = $1 << 1;
  $9 = $8 & 131068;
  $10 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__Z15PxGetFoundationv()|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 24|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (FUNCTION_TABLE_ii[$17 & 4095]($14)|0);
  $$$i$i$i$i = $18 ? 531952 : 531704;
  $19 = (FUNCTION_TABLE_iiiiii[$13 & 255]($10,$9,$$$i$i$i$i,531608,61)|0);
  $$pre$i = HEAP32[$3>>2]|0;
  $21 = $$pre$i;$22 = $19;
 }
 $20 = (($21) + 4|0);
 HEAP32[$20>>2] = $22;
 $23 = (($subdiv) + -1)|0;
 $24 = (Math_fround(($23>>>0)));
 $25 = Math_fround($24 * Math_fround(0.5));
 $26 = ($subdiv|0)==(0);
 $27 = (($this) + 8|0);
 $153 = Math_fround(0.0);$154 = Math_fround(0.0);$155 = Math_fround(0.0);$Face$019 = 0;
 while(1) {
  if ($26) {
   $$lcssa10 = $154;$$lcssa11 = $153;$$lcssa9 = $155;
  } else {
   $28 = Math_imul($Face$019, $subdiv)|0;
   $29 = ($Face$019|0)==(0);
   $30 = $29 ? Math_fround(-1.0) : Math_fround(1.0);
   $31 = ($Face$019|0)==(2);
   $32 = $31 ? Math_fround(-1.0) : Math_fround(1.0);
   $33 = ($Face$019|0)==(4);
   $34 = $33 ? Math_fround(-1.0) : Math_fround(1.0);
   $156 = $153;$157 = $154;$158 = $155;$j$012 = 0;
   while(1) {
    $35 = (Math_fround(($j$012>>>0)));
    $36 = Math_fround($35 / $25);
    $37 = Math_fround(Math_fround(1.0) - $36);
    L10: do {
     if ($29) {
      $i$04$us = 0;
      while(1) {
       $tmp$us = (($i$04$us) + ($28))|0;
       $tmp1$us = Math_imul($tmp$us, $subdiv)|0;
       $38 = (($tmp1$us) + ($j$012))|0;
       $39 = (Math_fround(($i$04$us>>>0)));
       $40 = Math_fround($39 / $25);
       $41 = Math_fround(Math_fround(1.0) - $40);
       $42 = Math_fround($30 * $30);
       $43 = Math_fround($41 * $41);
       $44 = Math_fround($43 + $42);
       $45 = Math_fround($37 * $37);
       $46 = Math_fround($45 + $44);
       $47 = (Math_fround(Math_sqrt((Math_fround($46)))));
       $48 = $47 > Math_fround(0.0);
       if ($48) {
        $49 = Math_fround(Math_fround(1.0) / $47);
        $50 = Math_fround($30 * $49);
        $51 = Math_fround($41 * $49);
        $52 = Math_fround($37 * $49);
        $62 = $50;$66 = $51;$71 = $52;
       } else {
        $62 = $30;$66 = $41;$71 = $37;
       }
       $53 = HEAP32[$this>>2]|0;
       $54 = (($53) + 38|0);
       $55 = HEAP8[$54>>0]|0;
       $56 = HEAP32[$27>>2]|0;
       $57 = ($55<<24>>24)==(0);
       if ($57) {
        $MinID$0$lcssa$i$us = 0;$MinID2$0$lcssa$i$us = 0;
       } else {
        $58 = $55&255;
        $MinID$02$i$us = 0;$MinID2$03$i$us = 0;$i$04$i$us = 0;$min2$01$i$us = Math_fround(3.40282346638528859812E+38);$minimum$05$i$us = Math_fround(3.40282346638528859812E+38);
        while(1) {
         $59 = (($56) + (($i$04$i$us*12)|0)|0);
         $60 = Math_fround(HEAPF32[$59>>2]);
         $61 = Math_fround($62 * $60);
         $63 = ((($56) + (($i$04$i$us*12)|0)|0) + 4|0);
         $64 = Math_fround(HEAPF32[$63>>2]);
         $65 = Math_fround($66 * $64);
         $67 = Math_fround($61 + $65);
         $68 = ((($56) + (($i$04$i$us*12)|0)|0) + 8|0);
         $69 = Math_fround(HEAPF32[$68>>2]);
         $70 = Math_fround($71 * $69);
         $72 = Math_fround($67 + $70);
         $73 = $72 < $minimum$05$i$us;
         $MinID$1$i$us = $73 ? $i$04$i$us : $MinID$02$i$us;
         $minimum$1$i$us = $73 ? $72 : $minimum$05$i$us;
         $74 = Math_fround(-$72);
         $75 = $min2$01$i$us > $74;
         $min2$1$i$us = $75 ? $74 : $min2$01$i$us;
         $MinID2$1$i$us = $75 ? $i$04$i$us : $MinID2$03$i$us;
         $76 = (($i$04$i$us) + 1)|0;
         $exitcond$i$us = ($76|0)==($58|0);
         if ($exitcond$i$us) {
          break;
         } else {
          $MinID$02$i$us = $MinID$1$i$us;$MinID2$03$i$us = $MinID2$1$i$us;$i$04$i$us = $76;$min2$01$i$us = $min2$1$i$us;$minimum$05$i$us = $minimum$1$i$us;
         }
        }
        $phitmp$i$us = $MinID$1$i$us&255;
        $phitmp7$i$us = $MinID2$1$i$us&255;
        $MinID$0$lcssa$i$us = $phitmp$i$us;$MinID2$0$lcssa$i$us = $phitmp7$i$us;
       }
       $77 = HEAP32[$3>>2]|0;
       $78 = (($77) + 4|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = (($79) + ($38)|0);
       HEAP8[$80>>0] = $MinID$0$lcssa$i$us;
       $81 = HEAP32[$3>>2]|0;
       $82 = (($81) + 2|0);
       $83 = HEAP16[$82>>1]|0;
       $84 = $83&65535;
       $85 = (($84) + ($38))|0;
       $86 = (($81) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = (($87) + ($85)|0);
       HEAP8[$88>>0] = $MinID2$0$lcssa$i$us;
       $89 = (($i$04$us) + 1)|0;
       $exitcond26 = ($89|0)==($subdiv|0);
       if ($exitcond26) {
        $split = $62;$split6 = $66;$split7 = $71;
        break;
       } else {
        $i$04$us = $89;
       }
      }
     } else {
      $159 = $156;$160 = $157;$161 = $158;$i$04 = 0;
      while(1) {
       $tmp = (($i$04) + ($28))|0;
       $tmp1 = Math_imul($tmp, $subdiv)|0;
       $90 = (($tmp1) + ($j$012))|0;
       switch ($Face$019|0) {
       case 3: case 2:  {
        $94 = (Math_fround(($i$04>>>0)));
        $95 = Math_fround($94 / $25);
        $96 = Math_fround(Math_fround(1.0) - $95);
        $101 = $37;$103 = $32;$106 = $96;
        break;
       }
       case 1: case 0:  {
        $91 = (Math_fround(($i$04>>>0)));
        $92 = Math_fround($91 / $25);
        $93 = Math_fround(Math_fround(1.0) - $92);
        $101 = $30;$103 = $93;$106 = $37;
        break;
       }
       case 5: case 4:  {
        $97 = (Math_fround(($i$04>>>0)));
        $98 = Math_fround($97 / $25);
        $99 = Math_fround(Math_fround(1.0) - $98);
        $101 = $99;$103 = $37;$106 = $34;
        break;
       }
       default: {
        $101 = $159;$103 = $160;$106 = $161;
       }
       }
       $100 = Math_fround($101 * $101);
       $102 = Math_fround($103 * $103);
       $104 = Math_fround($102 + $100);
       $105 = Math_fround($106 * $106);
       $107 = Math_fround($105 + $104);
       $108 = (Math_fround(Math_sqrt((Math_fround($107)))));
       $109 = $108 > Math_fround(0.0);
       if ($109) {
        $110 = Math_fround(Math_fround(1.0) / $108);
        $111 = Math_fround($101 * $110);
        $112 = Math_fround($103 * $110);
        $113 = Math_fround($106 * $110);
        $123 = $111;$127 = $112;$132 = $113;
       } else {
        $123 = $101;$127 = $103;$132 = $106;
       }
       $114 = HEAP32[$this>>2]|0;
       $115 = (($114) + 38|0);
       $116 = HEAP8[$115>>0]|0;
       $117 = HEAP32[$27>>2]|0;
       $118 = ($116<<24>>24)==(0);
       if ($118) {
        $MinID$0$lcssa$i = 0;$MinID2$0$lcssa$i = 0;
       } else {
        $119 = $116&255;
        $MinID$02$i = 0;$MinID2$03$i = 0;$i$04$i = 0;$min2$01$i = Math_fround(3.40282346638528859812E+38);$minimum$05$i = Math_fround(3.40282346638528859812E+38);
        while(1) {
         $120 = (($117) + (($i$04$i*12)|0)|0);
         $121 = Math_fround(HEAPF32[$120>>2]);
         $122 = Math_fround($123 * $121);
         $124 = ((($117) + (($i$04$i*12)|0)|0) + 4|0);
         $125 = Math_fround(HEAPF32[$124>>2]);
         $126 = Math_fround($127 * $125);
         $128 = Math_fround($122 + $126);
         $129 = ((($117) + (($i$04$i*12)|0)|0) + 8|0);
         $130 = Math_fround(HEAPF32[$129>>2]);
         $131 = Math_fround($132 * $130);
         $133 = Math_fround($128 + $131);
         $134 = $133 < $minimum$05$i;
         $MinID$1$i = $134 ? $i$04$i : $MinID$02$i;
         $minimum$1$i = $134 ? $133 : $minimum$05$i;
         $135 = Math_fround(-$133);
         $136 = $min2$01$i > $135;
         $min2$1$i = $136 ? $135 : $min2$01$i;
         $MinID2$1$i = $136 ? $i$04$i : $MinID2$03$i;
         $137 = (($i$04$i) + 1)|0;
         $exitcond$i = ($137|0)==($119|0);
         if ($exitcond$i) {
          break;
         } else {
          $MinID$02$i = $MinID$1$i;$MinID2$03$i = $MinID2$1$i;$i$04$i = $137;$min2$01$i = $min2$1$i;$minimum$05$i = $minimum$1$i;
         }
        }
        $phitmp$i = $MinID$1$i&255;
        $phitmp7$i = $MinID2$1$i&255;
        $MinID$0$lcssa$i = $phitmp$i;$MinID2$0$lcssa$i = $phitmp7$i;
       }
       $138 = HEAP32[$3>>2]|0;
       $139 = (($138) + 4|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = (($140) + ($90)|0);
       HEAP8[$141>>0] = $MinID$0$lcssa$i;
       $142 = HEAP32[$3>>2]|0;
       $143 = (($142) + 2|0);
       $144 = HEAP16[$143>>1]|0;
       $145 = $144&65535;
       $146 = (($145) + ($90))|0;
       $147 = (($142) + 4|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = (($148) + ($146)|0);
       HEAP8[$149>>0] = $MinID2$0$lcssa$i;
       $150 = (($i$04) + 1)|0;
       $exitcond = ($150|0)==($subdiv|0);
       if ($exitcond) {
        $split = $123;$split6 = $127;$split7 = $132;
        break L10;
       } else {
        $159 = $123;$160 = $127;$161 = $132;$i$04 = $150;
       }
      }
     }
    } while(0);
    $151 = (($j$012) + 1)|0;
    $exitcond27 = ($151|0)==($subdiv|0);
    if ($exitcond27) {
     $$lcssa10 = $split6;$$lcssa11 = $split;$$lcssa9 = $split7;
     break;
    } else {
     $156 = $split;$157 = $split6;$158 = $split7;$j$012 = $151;
    }
   }
  }
  $152 = (($Face$019) + 1)|0;
  $exitcond28 = ($152|0)==(6);
  if ($exitcond28) {
   break;
  } else {
   $153 = $$lcssa11;$154 = $$lcssa10;$155 = $$lcssa9;$Face$019 = $152;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN5physx17ConvexHullBuilderC2EPNS_2Gu14ConvexHullDataE($this,$hull) {
 $this = $this|0;
 $hull = $hull|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 HEAP32[$0>>2] = $hull;
 $1 = (($this) + 24|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx17ConvexHullBuilderD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 6|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = sp + 4|0;
 $6 = sp + 5|0;
 $7 = (($this) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$8);
 HEAP32[$7>>2] = 0;
 $9 = (($this) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$10);
 HEAP32[$9>>2] = 0;
 $11 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$11);
 HEAP32[$this>>2] = 0;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$13);
 HEAP32[$12>>2] = 0;
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$15);
 HEAP32[$14>>2] = 0;
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$17);
 HEAP32[$16>>2] = 0;
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$19);
 HEAP32[$18>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx17ConvexHullBuilder4InitEjPKNS_6PxVec3EjPKjjPKNS_13PxHullPolygonE($this,$nbVerts,$verts,$nbTris,$indices,$nbPolygons,$hullPolygons) {
 $this = $this|0;
 $nbVerts = $nbVerts|0;
 $verts = $verts|0;
 $nbTris = $nbTris|0;
 $indices = $indices|0;
 $nbPolygons = $nbPolygons|0;
 $hullPolygons = $hullPolygons|0;
 var $$$i$i$i = 0, $$$i$i$i6 = 0, $$0 = 0, $$arith = 0, $$overflow = 0, $$pre = 0, $$pre$i = 0, $$pre$i4 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre51 = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0;
 var $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Data$025 = 0, $Data$119 = 0, $Dest$021 = 0, $Tmp$026 = 0, $Verts$08 = 0, $exitcond = 0, $exitcond41 = 0, $exitcond42 = 0, $exitcond43 = 0, $exitcond44 = 0, $i$039 = 0, $i1$036 = 0, $i2$027 = 0, $i3$022 = 0, $i8$011 = 0, $j$032 = 0;
 var $j5$015 = 0, $j6$012 = 0, $minIndex$0$lcssa = 0, $minIndex$010 = 0, $minIndex$1 = 0, $minimum$09 = Math_fround(0), $minimum$1 = Math_fround(0), $nbHullVerts = 0, $or$cond = 0, $or$cond3 = 0, $polygons = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 31|0;
 $polygons = sp + 8|0;
 $1 = sp + 30|0;
 $2 = sp + 28|0;
 $3 = sp + 29|0;
 $nbHullVerts = sp + 24|0;
 $4 = (($this) + 4|0);
 $5 = (($this) + 8|0);
 $6 = (($this) + 32|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 HEAP32[$6>>2] = $nbTris;
 $7 = $nbVerts&255;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 38|0);
 HEAP8[$10>>0] = $7;
 $11 = HEAP32[$8>>2]|0;
 $12 = (($11) + 38|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = ($14*12)|0;
 $16 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$15,532056,948)|0);
 HEAP32[$this>>2] = $16;
 $17 = HEAP32[$8>>2]|0;
 $18 = (($17) + 38|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = ($20*12)|0;
 _memcpy(($16|0),($verts|0),($21|0))|0;
 $22 = ($indices|0)!=(0|0);
 $23 = ($hullPolygons|0)==(0|0);
 $or$cond = $22 & $23;
 if ($or$cond) {
  $24 = HEAP32[$6>>2]|0;
  $$arith = ($24*12)|0;
  $$overflow = ($24>>>0)>(357913941);
  $25 = $$overflow ? -1 : $$arith;
  $26 = ($25|0)==(0);
  if ($26) {
   $38 = 0;$40 = $24;
  } else {
   $27 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (__Z15PxGetFoundationv()|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 24|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (FUNCTION_TABLE_ii[$34 & 4095]($31)|0);
   $$$i$i$i = $35 ? 533272 : 532808;
   $36 = (FUNCTION_TABLE_iiiiii[$30 & 255]($27,$25,$$$i$i$i,532056,954)|0);
   $$pre = HEAP32[$6>>2]|0;
   $38 = $36;$40 = $$pre;
  }
  $37 = (($this) + 36|0);
  HEAP32[$37>>2] = $38;
  $39 = ($40|0)==(0);
  if (!($39)) {
   $i$039 = 0;
   while(1) {
    $41 = ($i$039*3)|0;
    $42 = (($indices) + ($41<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($38) + (($i$039*12)|0)|0);
    HEAP32[$44>>2] = $43;
    $45 = (($41) + 1)|0;
    $46 = (($indices) + ($45<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ((($38) + (($i$039*12)|0)|0) + 4|0);
    HEAP32[$48>>2] = $47;
    $49 = (($41) + 2)|0;
    $50 = (($indices) + ($49<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ((($38) + (($i$039*12)|0)|0) + 8|0);
    HEAP32[$52>>2] = $51;
    $53 = (($i$039) + 1)|0;
    $54 = HEAP32[$6>>2]|0;
    $55 = ($53>>>0)<($54>>>0);
    if ($55) {
     $i$039 = $53;
    } else {
     break;
    }
   }
  }
 }
 __ZN5physx2Gu9ContainerC2Ev($polygons);
 if (!($23)) {
  $56 = ($nbPolygons|0)==(0);
  if (!($56)) {
   $57 = (($polygons) + 4|0);
   $58 = (($polygons) + 8|0);
   $i1$036 = 0;
   while(1) {
    $59 = ((($hullPolygons) + (($i1$036*20)|0)|0) + 16|0);
    $60 = HEAP16[$59>>1]|0;
    $61 = $60&65535;
    $62 = HEAP32[$57>>2]|0;
    $63 = HEAP32[$polygons>>2]|0;
    $64 = ($62|0)==($63|0);
    if ($64) {
     (__ZN5physx2Gu9Container6ResizeEj($polygons,1)|0);
     $$pre$i = HEAP32[$57>>2]|0;
     $$pre46 = HEAP16[$59>>1]|0;
     $66 = $$pre$i;$70 = $$pre46;
    } else {
     $66 = $62;$70 = $60;
    }
    $65 = (($66) + 1)|0;
    HEAP32[$57>>2] = $65;
    $67 = HEAP32[$58>>2]|0;
    $68 = (($67) + ($66<<2)|0);
    HEAP32[$68>>2] = $61;
    $69 = ($70<<16>>16)==(0);
    if ($69) {
     $90 = $67;
    } else {
     $71 = ((($hullPolygons) + (($i1$036*20)|0)|0) + 18|0);
     $206 = $70;$207 = $67;$j$032 = 0;
     while(1) {
      $72 = HEAP16[$71>>1]|0;
      $73 = $72&65535;
      $74 = (($73) + ($j$032))|0;
      $75 = (($indices) + ($74<<2)|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = HEAP32[$57>>2]|0;
      $78 = HEAP32[$polygons>>2]|0;
      $79 = ($77|0)==($78|0);
      if ($79) {
       (__ZN5physx2Gu9Container6ResizeEj($polygons,1)|0);
       $$pre$i4 = HEAP32[$57>>2]|0;
       $$pre47 = HEAP32[$58>>2]|0;
       $$pre48 = HEAP16[$59>>1]|0;
       $81 = $$pre$i4;$83 = $$pre47;$86 = $$pre48;
      } else {
       $81 = $77;$83 = $207;$86 = $206;
      }
      $80 = (($81) + 1)|0;
      HEAP32[$57>>2] = $80;
      $82 = (($83) + ($81<<2)|0);
      HEAP32[$82>>2] = $76;
      $84 = (($j$032) + 1)|0;
      $85 = $86&65535;
      $87 = ($84>>>0)<($85>>>0);
      if ($87) {
       $206 = $86;$207 = $83;$j$032 = $84;
      } else {
       $90 = $83;
       break;
      }
     }
    }
    $88 = (($i1$036) + 1)|0;
    $exitcond44 = ($88|0)==($nbPolygons|0);
    if ($exitcond44) {
     break;
    } else {
     $i1$036 = $88;
    }
   }
   $89 = ($90|0)==(0|0);
   $or$cond3 = $56 | $89;
   if (!($or$cond3)) {
    $91 = HEAP32[$8>>2]|0;
    $92 = (($91) + 39|0);
    HEAP8[$92>>0] = 0;
    $93 = HEAP32[$5>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$93);
    HEAP32[$5>>2] = 0;
    $94 = HEAP32[$4>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$94);
    HEAP32[$4>>2] = 0;
    $95 = ($nbPolygons>>>0)>(255);
    if ($95) {
     $96 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
     __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($96,32,532056,1005,532152,$vararg_buffer);
     $$0 = 0;
     __ZN5physx2Gu9ContainerD2Ev($polygons);
     STACKTOP = sp;return ($$0|0);
    }
    $97 = $nbPolygons&255;
    $98 = HEAP32[$8>>2]|0;
    $99 = (($98) + 39|0);
    HEAP8[$99>>0] = $97;
    $100 = HEAP32[$8>>2]|0;
    $101 = (($100) + 39|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = $102&255;
    $104 = ($103*20)|0;
    $105 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$104,532056,1011)|0);
    HEAP32[$4>>2] = $105;
    $Data$025 = $90;$Tmp$026 = 0;$i2$027 = 0;
    while(1) {
     $106 = HEAP32[$Data$025>>2]|0;
     $$sum2 = (($106) + 1)|0;
     $107 = (($Data$025) + ($$sum2<<2)|0);
     $108 = (($106) + ($Tmp$026))|0;
     $109 = (($i2$027) + 1)|0;
     $exitcond43 = ($109|0)==($nbPolygons|0);
     if ($exitcond43) {
      break;
     } else {
      $Data$025 = $107;$Tmp$026 = $108;$i2$027 = $109;
     }
    }
    $110 = ($108|0)==(0);
    if ($110) {
     $121 = 0;
    } else {
     $111 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = (($112) + 8|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (__Z15PxGetFoundationv()|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = (($116) + 24|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = (FUNCTION_TABLE_ii[$118 & 4095]($115)|0);
     $$$i$i$i6 = $119 ? 533168 : 532808;
     $120 = (FUNCTION_TABLE_iiiiii[$114 & 255]($111,$108,$$$i$i$i6,532056,1026)|0);
     $121 = $120;
    }
    HEAP32[$5>>2] = $121;
    $$pre45 = HEAP32[$4>>2]|0;
    $124 = $121;$128 = $$pre45;$Data$119 = $90;$Dest$021 = $121;$i3$022 = 0;
    while(1) {
     $122 = $Dest$021;
     $123 = $124;
     $125 = (($122) - ($123))|0;
     $126 = $125&65535;
     $127 = ((($128) + (($i3$022*20)|0)|0) + 16|0);
     HEAP16[$127>>1] = $126;
     $129 = HEAP32[$Data$119>>2]|0;
     $130 = $129&255;
     $131 = ((($128) + (($i3$022*20)|0)|0) + 18|0);
     HEAP8[$131>>0] = $130;
     $132 = ($129|0)==(0);
     if (!($132)) {
      $j5$015 = 0;
      while(1) {
       $$sum1 = (($j5$015) + 1)|0;
       $133 = (($Data$119) + ($$sum1<<2)|0);
       $134 = HEAP32[$133>>2]|0;
       $135 = $134&255;
       $136 = (($Dest$021) + ($j5$015)|0);
       HEAP8[$136>>0] = $135;
       $exitcond41 = ($$sum1|0)==($129|0);
       if ($exitcond41) {
        break;
       } else {
        $j5$015 = $$sum1;
       }
      }
     }
     $137 = HEAP32[$4>>2]|0;
     $138 = (($hullPolygons) + (($i3$022*20)|0)|0);
     $139 = Math_fround(HEAPF32[$138>>2]);
     $140 = ((($hullPolygons) + (($i3$022*20)|0)|0) + 4|0);
     $141 = Math_fround(HEAPF32[$140>>2]);
     $142 = ((($hullPolygons) + (($i3$022*20)|0)|0) + 8|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = ((($hullPolygons) + (($i3$022*20)|0)|0) + 12|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = (($137) + (($i3$022*20)|0)|0);
     HEAPF32[$146>>2] = $139;
     $147 = ((($137) + (($i3$022*20)|0)|0) + 4|0);
     HEAPF32[$147>>2] = $141;
     $148 = ((($137) + (($i3$022*20)|0)|0) + 8|0);
     HEAPF32[$148>>2] = $143;
     $149 = ((($137) + (($i3$022*20)|0)|0) + 12|0);
     HEAPF32[$149>>2] = $145;
     $150 = (($i3$022) + 1)|0;
     $exitcond42 = ($150|0)==($nbPolygons|0);
     if ($exitcond42) {
      break;
     }
     $$sum = (($129) + 1)|0;
     $151 = (($Dest$021) + ($129)|0);
     $152 = (($Data$119) + ($$sum<<2)|0);
     $$pre51 = HEAP32[$5>>2]|0;
     $124 = $$pre51;$128 = $137;$Data$119 = $152;$Dest$021 = $151;$i3$022 = $150;
    }
    $153 = (__ZN5physx17ConvexHullBuilder23CalculateVertexMapTableEjb($this,$nbPolygons,1)|0);
    if ($153) {
     $j6$012 = 0;
    } else {
     $$0 = 0;
     __ZN5physx2Gu9ContainerD2Ev($polygons);
     STACKTOP = sp;return ($$0|0);
    }
    while(1) {
     $154 = HEAP32[$8>>2]|0;
     $155 = (($154) + 38|0);
     $156 = HEAP8[$155>>0]|0;
     $157 = HEAP32[$4>>2]|0;
     $158 = ($156<<24>>24)==(0);
     if ($158) {
      $minIndex$0$lcssa = -1;
     } else {
      $159 = HEAP32[$this>>2]|0;
      $160 = (($157) + (($j6$012*20)|0)|0);
      $161 = Math_fround(HEAPF32[$160>>2]);
      $162 = ((($157) + (($j6$012*20)|0)|0) + 4|0);
      $163 = Math_fround(HEAPF32[$162>>2]);
      $164 = ((($157) + (($j6$012*20)|0)|0) + 8|0);
      $165 = Math_fround(HEAPF32[$164>>2]);
      $Verts$08 = $159;$i8$011 = 0;$minIndex$010 = -1;$minimum$09 = Math_fround(3.40282346638528859812E+38);
      while(1) {
       $166 = (($Verts$08) + 12|0);
       $167 = Math_fround(HEAPF32[$Verts$08>>2]);
       $168 = Math_fround($167 * $161);
       $169 = (($Verts$08) + 4|0);
       $170 = Math_fround(HEAPF32[$169>>2]);
       $171 = Math_fround($170 * $163);
       $172 = Math_fround($168 + $171);
       $173 = (($Verts$08) + 8|0);
       $174 = Math_fround(HEAPF32[$173>>2]);
       $175 = Math_fround($174 * $165);
       $176 = Math_fround($172 + $175);
       $177 = $176 < $minimum$09;
       $minimum$1 = $177 ? $176 : $minimum$09;
       $minIndex$1 = $177 ? $i8$011 : $minIndex$010;
       $178 = (($i8$011) + 1)<<24>>24;
       $179 = ($178&255)<($156&255);
       if ($179) {
        $Verts$08 = $166;$i8$011 = $178;$minIndex$010 = $minIndex$1;$minimum$09 = $minimum$1;
       } else {
        $minIndex$0$lcssa = $minIndex$1;
        break;
       }
      }
     }
     $180 = ((($157) + (($j6$012*20)|0)|0) + 19|0);
     HEAP8[$180>>0] = $minIndex$0$lcssa;
     $181 = (($j6$012) + 1)|0;
     $exitcond = ($181|0)==($nbPolygons|0);
     if ($exitcond) {
      break;
     } else {
      $j6$012 = $181;
     }
    }
    $182 = (__ZN5physx17ConvexHullBuilder27CreateTrianglesFromPolygonsEv($this)|0);
    if (!($182)) {
     $$0 = 0;
     __ZN5physx2Gu9ContainerD2Ev($polygons);
     STACKTOP = sp;return ($$0|0);
    }
    $183 = (__ZNK5physx17ConvexHullBuilder17CheckHullPolygonsEv($this)|0);
    $$0 = $183;
    __ZN5physx2Gu9ContainerD2Ev($polygons);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $184 = (($this) + 36|0);
 $185 = HEAP32[$184>>2]|0;
 $186 = HEAP32[$8>>2]|0;
 $187 = (($186) + 38|0);
 $188 = HEAP8[$187>>0]|0;
 $189 = $188&255;
 HEAP32[$nbHullVerts>>2] = $189;
 $190 = HEAP32[$this>>2]|0;
 __ZL9CleanHullRjPN5physx2Gu9TriangleTIjEES_PNS0_6PxVec3E($6,$185,$nbHullVerts,$190);
 $191 = HEAP32[$nbHullVerts>>2]|0;
 $192 = $191&255;
 $193 = HEAP32[$8>>2]|0;
 $194 = (($193) + 38|0);
 HEAP8[$194>>0] = $192;
 $195 = HEAP32[$6>>2]|0;
 $196 = HEAP32[$8>>2]|0;
 $197 = (($196) + 38|0);
 $198 = HEAP8[$197>>0]|0;
 $199 = HEAP32[$this>>2]|0;
 HEAP32[$vararg_buffer>>2] = $195;
 $200 = (__ZL22TestDuplicateTrianglesRjPN5physx2Gu9TriangleTIjEEb($vararg_buffer,$185,0)|0);
 if (!($200)) {
  $$0 = 0;
  __ZN5physx2Gu9ContainerD2Ev($polygons);
  STACKTOP = sp;return ($$0|0);
 }
 $201 = $198&255;
 $202 = HEAP32[$vararg_buffer>>2]|0;
 $203 = (__ZL18TestUnifiedNormalsjPKN5physx6PxVec3EjPNS_2Gu9TriangleTIjEEb($201,$199,$202,$185,0)|0);
 if (!($203)) {
  $$0 = 0;
  __ZN5physx2Gu9ContainerD2Ev($polygons);
  STACKTOP = sp;return ($$0|0);
 }
 $204 = (__ZN5physx17ConvexHullBuilder17CreatePolygonDataEv($this)|0);
 if (!($204)) {
  $$0 = 0;
  __ZN5physx2Gu9ContainerD2Ev($polygons);
  STACKTOP = sp;return ($$0|0);
 }
 $205 = (__ZNK5physx17ConvexHullBuilder17CheckHullPolygonsEv($this)|0);
 $$0 = $205;
 __ZN5physx2Gu9ContainerD2Ev($polygons);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17ConvexHullBuilder23CalculateVertexMapTableEjb($this,$nbPolygons,$userPolygons) {
 $this = $this|0;
 $nbPolygons = $nbPolygons|0;
 $userPolygons = $userPolygons|0;
 var $$$i$i$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $count$06$us = 0, $count$1$us = 0, $i$012$us = 0, $i1$01 = 0, $inds = 0, $j$07$us = 0, $k$02$us = 0, $vararg_buffer1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $inds = sp + 4|0;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 38|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $18 = 0;$20 = $1;
 } else {
  $5 = $3&255;
  $6 = ($5*3)|0;
  $7 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15PxGetFoundationv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $$$i$i$i = $15 ? 533168 : 532808;
  $16 = (FUNCTION_TABLE_iiiiii[$10 & 255]($7,$6,$$$i$i$i,532056,1699)|0);
  $$pre = HEAP32[$0>>2]|0;
  $18 = $16;$20 = $$pre;
 }
 $17 = (($this) + 16|0);
 HEAP32[$17>>2] = $18;
 $19 = (($20) + 38|0);
 $21 = HEAP8[$19>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = ($nbPolygons|0)==(0);
 $24 = (($inds) + 1|0);
 $25 = (($inds) + 2|0);
 $26 = (($this) + 4|0);
 $27 = (($this) + 8|0);
 L7: do {
  if (!($23)) {
   $i$012$us = 0;
   while(1) {
    $32 = HEAP32[$26>>2]|0;
    $count$06$us = 0;$j$07$us = 0;
    while(1) {
     $31 = ((($32) + (($j$07$us*20)|0)|0) + 18|0);
     $33 = HEAP8[$31>>0]|0;
     $34 = ($33<<24>>24)==(0);
     L12: do {
      if ($34) {
       $count$1$us = $count$06$us;
      } else {
       $67 = ((($32) + (($j$07$us*20)|0)|0) + 16|0);
       $68 = HEAP16[$67>>1]|0;
       $39 = $68&65535;
       $41 = HEAP32[$27>>2]|0;
       $k$02$us = 0;
       while(1) {
        $38 = (($39) + ($k$02$us))|0;
        $40 = (($41) + ($38)|0);
        $42 = HEAP8[$40>>0]|0;
        $43 = $42&255;
        $44 = ($i$012$us|0)==($43|0);
        $37 = (($k$02$us) + 1)|0;
        if ($44) {
         break;
        }
        $35 = $33&255;
        $36 = ($37>>>0)<($35>>>0);
        if ($36) {
         $k$02$us = $37;
        } else {
         $count$1$us = $count$06$us;
         break L12;
        }
       }
       $45 = $j$07$us&255;
       $46 = (($count$06$us) + 1)|0;
       $47 = (($inds) + ($count$06$us)|0);
       HEAP8[$47>>0] = $45;
       $count$1$us = $46;
      }
     } while(0);
     $48 = ($count$1$us|0)==(3);
     $29 = (($j$07$us) + 1)|0;
     if ($48) {
      break;
     }
     $28 = ($29>>>0)<($nbPolygons>>>0);
     if ($28) {
      $count$06$us = $count$1$us;$j$07$us = $29;
     } else {
      label = 6;
      break;
     }
    }
    if ((label|0) == 6) {
     label = 0;
     $30 = ($count$1$us|0)==(3);
     if (!($30)) {
      break L7;
     }
    }
    $49 = HEAP8[$inds>>0]|0;
    $50 = ($i$012$us*3)|0;
    $51 = HEAP32[$17>>2]|0;
    $52 = (($51) + ($50)|0);
    HEAP8[$52>>0] = $49;
    $53 = HEAP8[$24>>0]|0;
    $54 = (($50) + 1)|0;
    $55 = HEAP32[$17>>2]|0;
    $56 = (($55) + ($54)|0);
    HEAP8[$56>>0] = $53;
    $57 = HEAP8[$25>>0]|0;
    $58 = (($50) + 2)|0;
    $59 = HEAP32[$17>>2]|0;
    $60 = (($59) + ($58)|0);
    HEAP8[$60>>0] = $57;
    $61 = (($i$012$us) + 1)|0;
    $62 = HEAP32[$0>>2]|0;
    $63 = (($62) + 38|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = $64&255;
    $66 = ($61>>>0)<($65>>>0);
    if ($66) {
     $i$012$us = $61;
    } else {
     $$0 = 1;
     break;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $69 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 if ($userPolygons) {
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($69,128,532056,1744,532504,$vararg_buffer1);
 } else {
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($69,128,532056,1742,532392,$vararg_buffer1);
 }
 $70 = HEAP32[$0>>2]|0;
 $71 = (($70) + 38|0);
 $72 = HEAP8[$71>>0]|0;
 $73 = ($72<<24>>24)==(0);
 if ($73) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i1$01 = 0;
 }
 while(1) {
  $74 = ($i1$01*3)|0;
  $75 = HEAP32[$17>>2]|0;
  $76 = (($75) + ($74)|0);
  HEAP8[$76>>0] = -1;
  $77 = (($74) + 1)|0;
  $78 = HEAP32[$17>>2]|0;
  $79 = (($78) + ($77)|0);
  HEAP8[$79>>0] = -1;
  $80 = (($74) + 2)|0;
  $81 = HEAP32[$17>>2]|0;
  $82 = (($81) + ($80)|0);
  HEAP8[$82>>0] = -1;
  $83 = (($i1$01) + 1)|0;
  $84 = HEAP32[$0>>2]|0;
  $85 = (($84) + 38|0);
  $86 = HEAP8[$85>>0]|0;
  $87 = $86&255;
  $88 = ($83>>>0)<($87>>>0);
  if ($88) {
   $i1$01 = $83;
  } else {
   $$0 = 0;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17ConvexHullBuilder27CreateTrianglesFromPolygonsEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$$i$i$i2 = 0, $$0 = 0, $$arith = 0, $$arith2 = 0, $$overflow = 0, $$overflow3 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0);
 var $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0);
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0);
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0);
 var $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $CurrFace$013 = 0, $CurrFace$1$ph = 0;
 var $Faces$0 = 0, $GeomCenter = 0, $MaxNbTriangles$017 = 0, $NbTriangles$0$lcssa = 0, $NbTriangles$012 = 0, $NbTriangles$1$ph = 0, $i$016 = 0, $i1$011 = 0, $i2$010 = 0, $j$0 = 0, $j$0$ph = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 18|0;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 $GeomCenter = sp + 4|0;
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 39|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $MaxNbTriangles$017 = 0;$i$016 = 0;
 }
 while(1) {
  $11 = ((($9) + (($i$016*20)|0)|0) + 18|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12&255)<(3);
  if ($13) {
   label = 4;
   break;
  }
  $15 = $12&255;
  $16 = (($MaxNbTriangles$017) + -2)|0;
  $17 = (($16) + ($15))|0;
  $18 = (($i$016) + 1)|0;
  $19 = $6&255;
  $20 = ($18>>>0)<($19>>>0);
  if ($20) {
   $MaxNbTriangles$017 = $17;$i$016 = $18;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,32,532056,1126,532224,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$arith2 = ($17*12)|0;
 $$overflow3 = ($17>>>0)>(357913941);
 $21 = $$overflow3 ? -1 : $$arith2;
 $22 = ($21|0)==(0);
 if ($22) {
  $124 = 0;$37 = $4;$39 = $6;
 } else {
  $23 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__Z15PxGetFoundationv()|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 24|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 4095]($27)|0);
  $$$i$i$i = $31 ? 533272 : 532808;
  $32 = (FUNCTION_TABLE_iiiiii[$26 & 255]($23,$21,$$$i$i$i,532056,1132)|0);
  $$pre = HEAP32[$3>>2]|0;
  $$phi$trans$insert = (($$pre) + 39|0);
  $$pre24 = HEAP8[$$phi$trans$insert>>0]|0;
  $124 = $32;$37 = $$pre;$39 = $$pre24;
 }
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$this>>2]|0;
 $36 = (($37) + 39|0);
 $38 = ($39<<24>>24)==(0);
 if ($38) {
  $NbTriangles$0$lcssa = 0;
 } else {
  $$pre23 = HEAP32[$8>>2]|0;
  $CurrFace$013 = $124;$NbTriangles$012 = 0;$i1$011 = 0;
  while(1) {
   $40 = ((($$pre23) + (($i1$011*20)|0)|0) + 16|0);
   $41 = HEAP16[$40>>1]|0;
   $42 = $41&65535;
   $43 = (($34) + ($42)|0);
   $44 = ((($$pre23) + (($i1$011*20)|0)|0) + 18|0);
   $45 = HEAP8[$44>>0]|0;
   $46 = $45&255;
   $47 = (($46) + -2)|0;
   $CurrFace$1$ph = $CurrFace$013;$NbTriangles$1$ph = $NbTriangles$012;$j$0$ph = 0;
   L20: while(1) {
    $48 = (($CurrFace$1$ph) + 4|0);
    $49 = (($CurrFace$1$ph) + 8|0);
    $j$0 = $j$0$ph;
    while(1) {
     $50 = ($j$0>>>0)<($47>>>0);
     if (!($50)) {
      break L20;
     }
     $51 = HEAP8[$43>>0]|0;
     $52 = $51&255;
     HEAP32[$CurrFace$1$ph>>2] = $52;
     $53 = (($j$0) + 1)|0;
     $54 = (($53>>>0) % ($46>>>0))&-1;
     $$sum = (($54) + ($42))|0;
     $55 = (($34) + ($$sum)|0);
     $56 = HEAP8[$55>>0]|0;
     $57 = $56&255;
     HEAP32[$48>>2] = $57;
     $58 = (($j$0) + 2)|0;
     $59 = (($58>>>0) % ($46>>>0))&-1;
     $$sum1 = (($59) + ($42))|0;
     $60 = (($34) + ($$sum1)|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = $61&255;
     HEAP32[$49>>2] = $62;
     $63 = (($35) + (($57*12)|0)|0);
     $64 = Math_fround(HEAPF32[$63>>2]);
     $65 = (($35) + (($52*12)|0)|0);
     $66 = Math_fround(HEAPF32[$65>>2]);
     $67 = Math_fround($64 - $66);
     $68 = ((($35) + (($57*12)|0)|0) + 4|0);
     $69 = Math_fround(HEAPF32[$68>>2]);
     $70 = ((($35) + (($52*12)|0)|0) + 4|0);
     $71 = Math_fround(HEAPF32[$70>>2]);
     $72 = Math_fround($69 - $71);
     $73 = ((($35) + (($57*12)|0)|0) + 8|0);
     $74 = Math_fround(HEAPF32[$73>>2]);
     $75 = ((($35) + (($52*12)|0)|0) + 8|0);
     $76 = Math_fround(HEAPF32[$75>>2]);
     $77 = Math_fround($74 - $76);
     $78 = (($35) + (($62*12)|0)|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $80 = Math_fround($79 - $66);
     $81 = ((($35) + (($62*12)|0)|0) + 4|0);
     $82 = Math_fround(HEAPF32[$81>>2]);
     $83 = Math_fround($82 - $71);
     $84 = ((($35) + (($62*12)|0)|0) + 8|0);
     $85 = Math_fround(HEAPF32[$84>>2]);
     $86 = Math_fround($85 - $76);
     $87 = Math_fround($72 * $86);
     $88 = Math_fround($77 * $83);
     $89 = Math_fround($87 - $88);
     $90 = Math_fround($77 * $80);
     $91 = Math_fround($67 * $86);
     $92 = Math_fround($90 - $91);
     $93 = Math_fround($67 * $83);
     $94 = Math_fround($72 * $80);
     $95 = Math_fround($93 - $94);
     $96 = Math_fround($89 * $89);
     $97 = Math_fround($92 * $92);
     $98 = Math_fround($96 + $97);
     $99 = Math_fround($95 * $95);
     $100 = Math_fround($99 + $98);
     $101 = $100 != Math_fround(0.0);
     if ($101) {
      break;
     } else {
      $j$0 = $53;
     }
    }
    $102 = (($NbTriangles$1$ph) + 1)|0;
    $103 = (($CurrFace$1$ph) + 12|0);
    $CurrFace$1$ph = $103;$NbTriangles$1$ph = $102;$j$0$ph = $53;
   }
   $104 = (($i1$011) + 1)|0;
   $105 = HEAP8[$36>>0]|0;
   $106 = $105&255;
   $107 = ($104>>>0)<($106>>>0);
   if ($107) {
    $CurrFace$013 = $CurrFace$1$ph;$NbTriangles$012 = $NbTriangles$1$ph;$i1$011 = $104;
   } else {
    $NbTriangles$0$lcssa = $NbTriangles$1$ph;
    break;
   }
  }
 }
 $108 = (($this) + 36|0);
 $109 = HEAP32[$108>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$109);
 HEAP32[$108>>2] = 0;
 $110 = ($17|0)==($NbTriangles$0$lcssa|0);
 do {
  if ($110) {
   $Faces$0 = $124;
  } else {
   $$arith = ($NbTriangles$0$lcssa*12)|0;
   $$overflow = ($NbTriangles$0$lcssa>>>0)>(357913941);
   $111 = $$overflow ? -1 : $$arith;
   $112 = ($111|0)==(0);
   if (!($112)) {
    $113 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = (($114) + 8|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (__Z15PxGetFoundationv()|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (($118) + 24|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = (FUNCTION_TABLE_ii[$120 & 4095]($117)|0);
    $$$i$i$i2 = $121 ? 533272 : 532808;
    $122 = (FUNCTION_TABLE_iiiiii[$116 & 255]($113,$111,$$$i$i$i2,532056,1193)|0);
    $123 = ($122|0)==(0|0);
    if (!($123)) {
     $125 = ($NbTriangles$0$lcssa*12)|0;
     _memcpy(($122|0),($124|0),($125|0))|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$124);
     $Faces$0 = $122;
     break;
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$124);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$108>>2] = $Faces$0;
 $126 = (($this) + 32|0);
 HEAP32[$126>>2] = $NbTriangles$0$lcssa;
 (__ZNK5physx17ConvexHullBuilder17ComputeGeomCenterERNS_6PxVec3E($this,$GeomCenter)|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = ($127|0)==(0);
 if ($128) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $129 = HEAP32[$108>>2]|0;
 $130 = Math_fround(HEAPF32[$GeomCenter>>2]);
 $131 = (($GeomCenter) + 4|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($GeomCenter) + 8|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $203 = $127;$i2$010 = 0;
 while(1) {
  $135 = (($129) + (($i2$010*12)|0)|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = ((($129) + (($i2$010*12)|0)|0) + 4|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = ((($129) + (($i2$010*12)|0)|0) + 8|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = (($35) + (($138*12)|0)|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($35) + (($136*12)|0)|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = Math_fround($142 - $144);
  $146 = ((($35) + (($138*12)|0)|0) + 4|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  $148 = ((($35) + (($136*12)|0)|0) + 4|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = Math_fround($147 - $149);
  $151 = ((($35) + (($138*12)|0)|0) + 8|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = ((($35) + (($136*12)|0)|0) + 8|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = Math_fround($152 - $154);
  $156 = (($35) + (($140*12)|0)|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = Math_fround($157 - $144);
  $159 = ((($35) + (($140*12)|0)|0) + 4|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = Math_fround($160 - $149);
  $162 = ((($35) + (($140*12)|0)|0) + 8|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = Math_fround($163 - $154);
  $165 = Math_fround($150 * $164);
  $166 = Math_fround($155 * $161);
  $167 = Math_fround($165 - $166);
  $168 = Math_fround($155 * $158);
  $169 = Math_fround($145 * $164);
  $170 = Math_fround($168 - $169);
  $171 = Math_fround($145 * $161);
  $172 = Math_fround($150 * $158);
  $173 = Math_fround($171 - $172);
  $174 = Math_fround($167 * $167);
  $175 = Math_fround($170 * $170);
  $176 = Math_fround($174 + $175);
  $177 = Math_fround($173 * $173);
  $178 = Math_fround($177 + $176);
  $179 = $178 > Math_fround(0.0);
  if ($179) {
   $180 = (Math_fround(Math_sqrt((Math_fround($178)))));
   $181 = Math_fround(Math_fround(1.0) / $180);
   $182 = Math_fround($167 * $181);
   $183 = Math_fround($170 * $181);
   $184 = Math_fround($173 * $181);
   $186 = $182;$188 = $183;$191 = $184;
  } else {
   $186 = Math_fround(0.0);$188 = Math_fround(0.0);$191 = Math_fround(0.0);
  }
  $185 = Math_fround($186 * $144);
  $187 = Math_fround($188 * $149);
  $189 = Math_fround($185 + $187);
  $190 = Math_fround($191 * $154);
  $192 = Math_fround($189 + $190);
  $193 = Math_fround($186 * $130);
  $194 = Math_fround($188 * $132);
  $195 = Math_fround($193 + $194);
  $196 = Math_fround($191 * $134);
  $197 = Math_fround($195 + $196);
  $198 = Math_fround($197 - $192);
  $199 = $198 > Math_fround(0.0);
  if ($199) {
   HEAP32[$139>>2] = $138;
   HEAP32[$137>>2] = $140;
   $$pre22 = HEAP32[$126>>2]|0;
   $202 = $$pre22;
  } else {
   $202 = $203;
  }
  $200 = (($i2$010) + 1)|0;
  $201 = ($200>>>0)<($202>>>0);
  if ($201) {
   $203 = $202;$i2$010 = $200;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx17ConvexHullBuilder17CheckHullPolygonsEv($this) {
 $this = $this|0;
 var $$1 = 0, $$lcssa = Math_fround(0), $$lcssa40 = Math_fround(0), $$lcssa41 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $foundPlane = 0, $i1$034 = 0, $i5$025 = 0, $j$042 = 0, $j2$031 = 0, $j2$031$us = 0, $k$027 = 0, $k3$029$us = 0, $or$cond = 0, $phitmp = Math_fround(0), $phitmp47 = Math_fround(0);
 var $phitmp48 = Math_fround(0), $testVectors = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $testVectors = sp + 8|0;
 $foundPlane = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($0|0)==(0|0);
 if ($5) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $6 = (($this) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 $9 = ($4|0)==(0|0);
 $or$cond = $8 | $9;
 if ($or$cond) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $10 = (($this) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 39|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13&255)<(4);
 if ($14) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $15 = (($11) + 38|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $$lcssa = Math_fround(-3.40282346638528859812E+38);$$lcssa40 = Math_fround(-3.40282346638528859812E+38);$$lcssa41 = Math_fround(-3.40282346638528859812E+38);
 } else {
  $18 = $16&255;
  $27 = Math_fround(-3.40282346638528859812E+38);$31 = Math_fround(-3.40282346638528859812E+38);$35 = Math_fround(-3.40282346638528859812E+38);$j$042 = 0;
  while(1) {
   $19 = (($0) + (($j$042*12)|0)|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = ((($0) + (($j$042*12)|0)|0) + 4|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = ((($0) + (($j$042*12)|0)|0) + 8|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = (Math_fround(Math_abs((Math_fround($20)))));
   $26 = $25 > $27;
   $28 = $26 ? $25 : $27;
   $29 = (Math_fround(Math_abs((Math_fround($22)))));
   $30 = $29 > $31;
   $32 = $30 ? $29 : $31;
   $33 = (Math_fround(Math_abs((Math_fround($24)))));
   $34 = $33 > $35;
   $36 = $34 ? $33 : $35;
   $37 = (($j$042) + 1)|0;
   $38 = ($37>>>0)<($18>>>0);
   if ($38) {
    $27 = $28;$31 = $32;$35 = $36;$j$042 = $37;
   } else {
    break;
   }
  }
  $phitmp = Math_fround($28 + Math_fround(0.0199999995529651641846));
  $phitmp47 = Math_fround($32 + Math_fround(0.0199999995529651641846));
  $phitmp48 = Math_fround($36 + Math_fround(0.0199999995529651641846));
  $$lcssa = $phitmp48;$$lcssa40 = $phitmp47;$$lcssa41 = $phitmp;
 }
 $39 = $foundPlane;
 $40 = $39;
 HEAP32[$40>>2] = 0;
 $41 = (($39) + 4)|0;
 $42 = $41;
 HEAP32[$42>>2] = 0;
 HEAPF32[$testVectors>>2] = $$lcssa41;
 $43 = (($testVectors) + 4|0);
 HEAPF32[$43>>2] = $$lcssa40;
 $44 = (($testVectors) + 8|0);
 HEAPF32[$44>>2] = $$lcssa;
 $45 = Math_fround(-$$lcssa40);
 $46 = Math_fround(-$$lcssa);
 $47 = (($testVectors) + 12|0);
 HEAPF32[$47>>2] = $$lcssa41;
 $48 = (($testVectors) + 16|0);
 HEAPF32[$48>>2] = $45;
 $49 = (($testVectors) + 20|0);
 HEAPF32[$49>>2] = $46;
 $50 = (($testVectors) + 24|0);
 HEAPF32[$50>>2] = $$lcssa41;
 $51 = (($testVectors) + 28|0);
 HEAPF32[$51>>2] = $$lcssa40;
 $52 = (($testVectors) + 32|0);
 HEAPF32[$52>>2] = $46;
 $53 = (($testVectors) + 36|0);
 HEAPF32[$53>>2] = $$lcssa41;
 $54 = (($testVectors) + 40|0);
 HEAPF32[$54>>2] = $45;
 $55 = (($testVectors) + 44|0);
 HEAPF32[$55>>2] = $$lcssa;
 $56 = Math_fround(-$$lcssa41);
 $57 = (($testVectors) + 48|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($testVectors) + 52|0);
 HEAPF32[$58>>2] = $$lcssa40;
 $59 = (($testVectors) + 56|0);
 HEAPF32[$59>>2] = $$lcssa;
 $60 = (($testVectors) + 60|0);
 HEAPF32[$60>>2] = $56;
 $61 = (($testVectors) + 64|0);
 HEAPF32[$61>>2] = $45;
 $62 = (($testVectors) + 68|0);
 HEAPF32[$62>>2] = $$lcssa;
 $63 = (($testVectors) + 72|0);
 HEAPF32[$63>>2] = $56;
 $64 = (($testVectors) + 76|0);
 HEAPF32[$64>>2] = $$lcssa40;
 $65 = (($testVectors) + 80|0);
 HEAPF32[$65>>2] = $46;
 $66 = (($testVectors) + 84|0);
 HEAPF32[$66>>2] = $56;
 $67 = (($testVectors) + 88|0);
 HEAPF32[$67>>2] = $45;
 $68 = (($testVectors) + 92|0);
 HEAPF32[$68>>2] = $46;
 $69 = HEAP8[$12>>0]|0;
 $70 = ($69<<24>>24)==(0);
 L16: do {
  if ($70) {
   $i5$025 = 0;
  } else {
   $71 = HEAP8[$15>>0]|0;
   $72 = ($71<<24>>24)==(0);
   $i1$034 = 0;
   L18: while(1) {
    $73 = (($4) + (($i1$034*20)|0)|0);
    $74 = ((($4) + (($i1$034*20)|0)|0) + 4|0);
    $75 = ((($4) + (($i1$034*20)|0)|0) + 8|0);
    $76 = ((($4) + (($i1$034*20)|0)|0) + 12|0);
    $k$027 = 0;
    while(1) {
     $77 = (($foundPlane) + ($k$027)|0);
     $78 = HEAP8[$77>>0]|0;
     $79 = ($78<<24>>24)==(0);
     if ($79) {
      $80 = (($testVectors) + (($k$027*12)|0)|0);
      $81 = Math_fround(HEAPF32[$80>>2]);
      $82 = Math_fround(HEAPF32[$73>>2]);
      $83 = Math_fround($81 * $82);
      $84 = ((($testVectors) + (($k$027*12)|0)|0) + 4|0);
      $85 = Math_fround(HEAPF32[$84>>2]);
      $86 = Math_fround(HEAPF32[$74>>2]);
      $87 = Math_fround($85 * $86);
      $88 = Math_fround($83 + $87);
      $89 = ((($testVectors) + (($k$027*12)|0)|0) + 8|0);
      $90 = Math_fround(HEAPF32[$89>>2]);
      $91 = Math_fround(HEAPF32[$75>>2]);
      $92 = Math_fround($90 * $91);
      $93 = Math_fround($88 + $92);
      $94 = Math_fround(HEAPF32[$76>>2]);
      $95 = Math_fround($94 + $93);
      $96 = !($95 >= Math_fround(0.0));
      if (!($96)) {
       HEAP8[$77>>0] = 1;
      }
     }
     $97 = (($k$027) + 1)|0;
     $exitcond = ($97|0)==(8);
     if ($exitcond) {
      break;
     } else {
      $k$027 = $97;
     }
    }
    L27: do {
     if (!($72)) {
      $98 = ((($4) + (($i1$034*20)|0)|0) + 18|0);
      $99 = HEAP8[$98>>0]|0;
      $100 = $99&255;
      $101 = ($99<<24>>24)==(0);
      $102 = ((($4) + (($i1$034*20)|0)|0) + 16|0);
      if ($101) {
       $j2$031 = 0;
       while(1) {
        $132 = (($0) + (($j2$031*12)|0)|0);
        $133 = Math_fround(HEAPF32[$132>>2]);
        $134 = Math_fround(HEAPF32[$73>>2]);
        $135 = Math_fround($133 * $134);
        $136 = ((($0) + (($j2$031*12)|0)|0) + 4|0);
        $137 = Math_fround(HEAPF32[$136>>2]);
        $138 = Math_fround(HEAPF32[$74>>2]);
        $139 = Math_fround($137 * $138);
        $140 = Math_fround($135 + $139);
        $141 = ((($0) + (($j2$031*12)|0)|0) + 8|0);
        $142 = Math_fround(HEAPF32[$141>>2]);
        $143 = Math_fround(HEAPF32[$75>>2]);
        $144 = Math_fround($142 * $143);
        $145 = Math_fround($140 + $144);
        $146 = Math_fround(HEAPF32[$76>>2]);
        $147 = Math_fround($146 + $145);
        $148 = $147 > Math_fround(0.0199999995529651641846);
        if ($148) {
         $$1 = 0;
         label = 27;
         break L18;
        }
        $149 = (($j2$031) + 1)|0;
        $150 = (($11) + 38|0);
        $151 = HEAP8[$150>>0]|0;
        $152 = $151&255;
        $153 = ($149>>>0)<($152>>>0);
        if ($153) {
         $j2$031 = $149;
        } else {
         break L27;
        }
       }
      } else {
       $j2$031$us = 0;
      }
      while(1) {
       $131 = HEAP16[$102>>1]|0;
       $123 = $131&65535;
       $127 = $j2$031$us&255;
       $k3$029$us = 0;
       while(1) {
        $122 = (($123) + ($k3$029$us))|0;
        $124 = (($2) + ($122)|0);
        $125 = HEAP8[$124>>0]|0;
        $126 = ($125<<24>>24)==($127<<24>>24);
        $104 = (($k3$029$us) + 1)|0;
        if ($126) {
         break;
        }
        $103 = ($104>>>0)<($100>>>0);
        if ($103) {
         $k3$029$us = $104;
        } else {
         label = 18;
         break;
        }
       }
       if ((label|0) == 18) {
        label = 0;
        $105 = (($0) + (($j2$031$us*12)|0)|0);
        $106 = Math_fround(HEAPF32[$105>>2]);
        $107 = Math_fround(HEAPF32[$73>>2]);
        $108 = Math_fround($106 * $107);
        $109 = ((($0) + (($j2$031$us*12)|0)|0) + 4|0);
        $110 = Math_fround(HEAPF32[$109>>2]);
        $111 = Math_fround(HEAPF32[$74>>2]);
        $112 = Math_fround($110 * $111);
        $113 = Math_fround($108 + $112);
        $114 = ((($0) + (($j2$031$us*12)|0)|0) + 8|0);
        $115 = Math_fround(HEAPF32[$114>>2]);
        $116 = Math_fround(HEAPF32[$75>>2]);
        $117 = Math_fround($115 * $116);
        $118 = Math_fround($113 + $117);
        $119 = Math_fround(HEAPF32[$76>>2]);
        $120 = Math_fround($119 + $118);
        $121 = $120 > Math_fround(0.0199999995529651641846);
        if ($121) {
         $$1 = 0;
         label = 27;
         break L18;
        }
       }
       $128 = (($j2$031$us) + 1)|0;
       $129 = $71&255;
       $130 = ($128>>>0)<($129>>>0);
       if ($130) {
        $j2$031$us = $128;
       } else {
        break;
       }
      }
     }
    } while(0);
    $154 = (($i1$034) + 1)|0;
    $155 = (($11) + 39|0);
    $156 = HEAP8[$155>>0]|0;
    $157 = $156&255;
    $158 = ($154>>>0)<($157>>>0);
    if ($158) {
     $i1$034 = $154;
    } else {
     $i5$025 = 0;
     break L16;
    }
   }
   if ((label|0) == 27) {
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 while(1) {
  $161 = (($foundPlane) + ($i5$025)|0);
  $162 = HEAP8[$161>>0]|0;
  $163 = ($162<<24>>24)==(0);
  $160 = (($i5$025) + 1)|0;
  if ($163) {
   $$1 = 0;
   label = 27;
   break;
  }
  $159 = ($160>>>0)<(8);
  if ($159) {
   $i5$025 = $160;
  } else {
   $$1 = 1;
   label = 27;
   break;
  }
 }
 if ((label|0) == 27) {
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZL9CleanHullRjPN5physx2Gu9TriangleTIjEES_PNS0_6PxVec3E($nbFaces,$faces,$nbVerts,$verts) {
 $nbFaces = $nbFaces|0;
 $faces = $faces|0;
 $nbVerts = $nbVerts|0;
 $verts = $verts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cleaner$i = 0, $exitcond = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $cleaner$i = sp;
 $0 = HEAP32[$nbVerts>>2]|0;
 $1 = HEAP32[$nbFaces>>2]|0;
 __ZN5physx11MeshCleanerC2EjPKNS_6PxVec3EjPKjf($cleaner$i,$0,$verts,$1,$faces,Math_fround(0.0));
 $2 = (($cleaner$i) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN5physx11MeshCleanerD2Ev($cleaner$i);
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$cleaner$i>>2]|0;
 HEAP32[$nbVerts>>2] = $5;
 HEAP32[$nbFaces>>2] = $3;
 $6 = (($cleaner$i) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5*12)|0;
 _memcpy(($verts|0),($7|0),($8|0))|0;
 $9 = (($cleaner$i) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $i$01$i = 0;
 while(1) {
  $11 = ($i$01$i*3)|0;
  $12 = (($10) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($faces) + (($i$01$i*12)|0)|0);
  HEAP32[$14>>2] = $13;
  $15 = (($11) + 1)|0;
  $16 = (($10) + ($15<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($faces) + (($i$01$i*12)|0)|0) + 4|0);
  HEAP32[$18>>2] = $17;
  $19 = (($11) + 2)|0;
  $20 = (($10) + ($19<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($faces) + (($i$01$i*12)|0)|0) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = (($i$01$i) + 1)|0;
  $exitcond = ($23|0)==($3|0);
  if ($exitcond) {
   break;
  } else {
   $i$01$i = $23;
  }
 }
 __ZN5physx11MeshCleanerD2Ev($cleaner$i);
 (__ZL22TestDuplicateTrianglesRjPN5physx2Gu9TriangleTIjEEb($nbFaces,$faces,1)|0);
 $24 = HEAP32[$nbVerts>>2]|0;
 $25 = HEAP32[$nbFaces>>2]|0;
 (__ZL18TestUnifiedNormalsjPKN5physx6PxVec3EjPNS_2Gu9TriangleTIjEEb($24,$verts,$25,$faces,1)|0);
 $26 = HEAP32[$nbVerts>>2]|0;
 $27 = HEAP32[$nbFaces>>2]|0;
 (__ZL18TestUnifiedNormalsjPKN5physx6PxVec3EjPNS_2Gu9TriangleTIjEEb($26,$verts,$27,$faces,1)|0);
 (__ZL22TestDuplicateTrianglesRjPN5physx2Gu9TriangleTIjEEb($nbFaces,$faces,1)|0);
 STACKTOP = sp;return;
}
function __ZN5physx17ConvexHullBuilder17CreatePolygonDataEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$$i$i$i13 = 0, $$0 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert101 = 0, $$phi$trans$insert103 = 0, $$phi$trans$insert105 = 0, $$phi$trans$insert107 = 0, $$phi$trans$insert109 = 0, $$phi$trans$insert112 = 0, $$phi$trans$insert114 = 0, $$phi$trans$insert116 = 0, $$phi$trans$insert20$i = 0, $$phi$trans$insert21$i = 0, $$phi$trans$insert23$i = 0, $$phi$trans$insert25$i = 0, $$phi$trans$insert92 = 0, $$phi$trans$insert99 = 0, $$pre = 0, $$pre$i = 0;
 var $$pre100 = Math_fround(0), $$pre102 = Math_fround(0), $$pre104 = Math_fround(0), $$pre106 = Math_fround(0), $$pre108 = Math_fround(0), $$pre110 = Math_fround(0), $$pre111 = Math_fround(0), $$pre113 = Math_fround(0), $$pre115 = Math_fround(0), $$pre117 = Math_fround(0), $$pre119 = Math_fround(0), $$pre22$i = Math_fround(0), $$pre24$i = Math_fround(0), $$pre26$i = Math_fround(0), $$pre87 = 0, $$pre88 = 0, $$pre89 = 0, $$pre90 = 0, $$pre91 = 0, $$pre93 = 0;
 var $$pre94 = 0, $$pre97 = 0, $$pre98 = 0, $$sum = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0);
 var $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0;
 var $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0);
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0;
 var $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0);
 var $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0);
 var $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = Math_fround(0);
 var $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0), $403 = 0, $404 = Math_fround(0), $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Data$065 = 0, $Data2$052 = 0, $Dest$047 = 0, $GeomCenter = 0, $NbPolygons = 0, $RendundantVertices = 0, $Temp = 0, $Temp2 = 0;
 var $TriData$055 = 0, $TriData$1 = 0, $TriData$1$lcssa121 = 0, $TriData$131 = 0, $TriData$131$sum = 0, $TriData$134 = 0, $Verts$015 = 0, $currentIndex$071 = 0, $currentIndex$1 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond86 = 0, $flip$0$off032 = 0, $flip$1$off0 = 0, $i$01$i = 0, $i$01$i9 = 0, $i$070 = 0, $i1$064 = 0, $i3$056 = 0, $i9$018 = 0;
 var $index$0$ph45 = 0, $j$060 = 0, $j$08$i = 0, $j5$0$ph46 = 0, $j5$022 = 0, $j6$041 = 0, $j7$019 = 0, $k$033 = 0, $min$016 = Math_fround(0), $min$1 = Math_fround(0), $minIndex$0$lcssa = 0, $minIndex$017 = 0, $minIndex$1 = 0, $numReducedHullDataVertices$0 = 0, $or$cond$i = 0, $or$cond$i11 = 0, $or$cond1$i = 0, $phitmp = 0, $reducedHullDataHullVertices$0 = 0, $scevgep83 = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer = sp;
 $0 = sp + 72|0;
 $1 = sp + 68|0;
 $2 = sp + 74|0;
 $Temp = sp + 24|0;
 $Temp2 = sp + 40|0;
 $RendundantVertices = sp + 8|0;
 $NbPolygons = sp + 4|0;
 $3 = sp + 69|0;
 $4 = sp + 70|0;
 $5 = sp + 71|0;
 $GeomCenter = sp + 56|0;
 $6 = sp + 73|0;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 39|0);
 HEAP8[$9>>0] = 0;
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
 HEAP32[$10>>2] = 0;
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$13);
 HEAP32[$12>>2] = 0;
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$15);
 HEAP32[$14>>2] = 0;
 __ZN5physx2Gu9ContainerC2Ev($Temp);
 __ZN5physx2Gu9ContainerC2Ev($Temp2);
 __ZN5physx2Gu9ContainerC2Ev($RendundantVertices);
 $16 = (__ZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_($NbPolygons,$Temp,$this,$Temp2,$RendundantVertices)|0);
 if (!($16)) {
  $$0 = 0;
  __ZN5physx2Gu9ContainerD2Ev($RendundantVertices);
  __ZN5physx2Gu9ContainerD2Ev($Temp2);
  __ZN5physx2Gu9ContainerD2Ev($Temp);
  STACKTOP = sp;return ($$0|0);
 }
 $17 = HEAP32[$7>>2]|0;
 $18 = (($17) + 38|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = (($RendundantVertices) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$pre97 = HEAP32[$NbPolygons>>2]|0;
  $84 = $$pre97;$numReducedHullDataVertices$0 = $19;$reducedHullDataHullVertices$0 = $23;
 } else {
  $24 = $19&255;
  $25 = (($24) - ($21))|0;
  $26 = $25&255;
  $27 = $25 & 255;
  $28 = ($27*12)|0;
  $29 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$28,532056,1447)|0);
  $30 = HEAP32[$7>>2]|0;
  $31 = (($30) + 38|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   $76 = 0;
  } else {
   $34 = $32&255;
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (__Z15PxGetFoundationv()|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + 24|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (FUNCTION_TABLE_ii[$42 & 4095]($39)|0);
   $$$i$i$i13 = $43 ? 533168 : 532808;
   $44 = (FUNCTION_TABLE_iiiiii[$38 & 255]($35,$34,$$$i$i$i13,532056,1448)|0);
   $$pre91 = HEAP32[$7>>2]|0;
   $$phi$trans$insert92 = (($$pre91) + 38|0);
   $$pre93 = HEAP8[$$phi$trans$insert92>>0]|0;
   $phitmp = ($$pre93<<24>>24)==(0);
   if ($phitmp) {
    $76 = $44;
   } else {
    $45 = 0;$currentIndex$071 = 0;$i$070 = 0;
    while(1) {
     $46 = (__ZNK5physx2Gu9Container8ContainsEjPj($RendundantVertices,$45,0)|0);
     if ($46) {
      $60 = (($44) + ($45)|0);
      HEAP8[$60>>0] = -1;
      $currentIndex$1 = $currentIndex$071;
     } else {
      $47 = $currentIndex$071&255;
      $48 = HEAP32[$this>>2]|0;
      $49 = (($48) + (($45*12)|0)|0);
      $50 = Math_fround(HEAPF32[$49>>2]);
      $51 = (($29) + (($47*12)|0)|0);
      HEAPF32[$51>>2] = $50;
      $52 = ((($48) + (($45*12)|0)|0) + 4|0);
      $53 = Math_fround(HEAPF32[$52>>2]);
      $54 = ((($29) + (($47*12)|0)|0) + 4|0);
      HEAPF32[$54>>2] = $53;
      $55 = ((($48) + (($45*12)|0)|0) + 8|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      $57 = ((($29) + (($47*12)|0)|0) + 8|0);
      HEAPF32[$57>>2] = $56;
      $58 = (($44) + ($45)|0);
      HEAP8[$58>>0] = $currentIndex$071;
      $59 = (($currentIndex$071) + 1)<<24>>24;
      $currentIndex$1 = $59;
     }
     $61 = (($i$070) + 1)<<24>>24;
     $62 = $61&255;
     $63 = HEAP32[$7>>2]|0;
     $64 = (($63) + 38|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = ($61&255)<($65&255);
     if ($66) {
      $45 = $62;$currentIndex$071 = $currentIndex$1;$i$070 = $61;
     } else {
      $76 = $44;
      break;
     }
    }
   }
  }
  $67 = HEAP32[$NbPolygons>>2]|0;
  $68 = ($67|0)==(0);
  if ($68) {
   $421 = 0;
  } else {
   $69 = (($Temp) + 8|0);
   $70 = HEAP32[$69>>2]|0;
   $422 = $67;$Data$065 = $70;$i1$064 = 0;
   while(1) {
    $71 = HEAP32[$Data$065>>2]|0;
    $72 = ($71|0)==(0);
    if ($72) {
     $82 = $422;
    } else {
     $j$060 = 0;
     while(1) {
      $$sum5 = (($j$060) + 1)|0;
      $73 = (($Data$065) + ($$sum5<<2)|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = (($76) + ($74)|0);
      $77 = HEAP8[$75>>0]|0;
      $78 = $77&255;
      HEAP32[$73>>2] = $78;
      $exitcond86 = ($$sum5|0)==($71|0);
      if ($exitcond86) {
       break;
      } else {
       $j$060 = $$sum5;
      }
     }
     $$pre94 = HEAP32[$NbPolygons>>2]|0;
     $82 = $$pre94;
    }
    $$sum4 = (($71) + 1)|0;
    $79 = (($Data$065) + ($$sum4<<2)|0);
    $80 = (($i1$064) + 1)|0;
    $81 = ($80>>>0)<($82>>>0);
    if ($81) {
     $422 = $82;$Data$065 = $79;$i1$064 = $80;
    } else {
     $421 = $82;
     break;
    }
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$76);
  $84 = $421;$numReducedHullDataVertices$0 = $26;$reducedHullDataHullVertices$0 = $29;
 }
 $83 = ($84>>>0)>(255);
 if ($83) {
  $85 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($85,32,532056,1486,532328,$vararg_buffer);
  $$0 = 0;
  __ZN5physx2Gu9ContainerD2Ev($RendundantVertices);
  __ZN5physx2Gu9ContainerD2Ev($Temp2);
  __ZN5physx2Gu9ContainerD2Ev($Temp);
  STACKTOP = sp;return ($$0|0);
 }
 $86 = $84&255;
 $87 = HEAP32[$7>>2]|0;
 $88 = (($87) + 39|0);
 HEAP8[$88>>0] = $86;
 $89 = HEAP32[$7>>2]|0;
 $90 = (($89) + 39|0);
 $91 = HEAP8[$90>>0]|0;
 $92 = $91&255;
 $93 = ($92*20)|0;
 $94 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,$93,532056,1492)|0);
 HEAP32[$14>>2] = $94;
 $95 = HEAP32[$7>>2]|0;
 $96 = (($95) + 39|0);
 $97 = HEAP8[$96>>0]|0;
 $98 = $97&255;
 $99 = ($98*20)|0;
 _memset(($94|0),0,($99|0))|0;
 (__ZNK5physx17ConvexHullBuilder17ComputeGeomCenterERNS_6PxVec3E($this,$GeomCenter)|0);
 $100 = (($Temp) + 4|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==($84|0);
 if ($102) {
  $114 = 0;
 } else {
  $103 = (($101) - ($84))|0;
  $104 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($105) + 8|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (__Z15PxGetFoundationv()|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($109) + 24|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = (FUNCTION_TABLE_ii[$111 & 4095]($108)|0);
  $$$i$i$i = $112 ? 533168 : 532808;
  $113 = (FUNCTION_TABLE_iiiiii[$107 & 255]($104,$103,$$$i$i$i,532056,1503)|0);
  $114 = $113;
 }
 HEAP32[$10>>2] = $114;
 $115 = ($84|0)==(0);
 L34: do {
  if ($115) {
   $388 = 0;
  } else {
   $116 = (($Temp2) + 8|0);
   $117 = (($Temp) + 8|0);
   $118 = HEAP32[$116>>2]|0;
   $119 = HEAP32[$117>>2]|0;
   $120 = ($reducedHullDataHullVertices$0|0)==(0|0);
   $121 = (($GeomCenter) + 4|0);
   $122 = (($GeomCenter) + 8|0);
   $123 = (($this) + 36|0);
   $$pre = HEAP32[$14>>2]|0;
   $126 = $114;$130 = $$pre;$Data2$052 = $119;$Dest$047 = $114;$TriData$055 = $118;$i3$056 = 0;
   while(1) {
    $124 = $Dest$047;
    $125 = $126;
    $127 = (($124) - ($125))|0;
    $128 = $127&65535;
    $129 = ((($130) + (($i3$056*20)|0)|0) + 16|0);
    HEAP16[$129>>1] = $128;
    $131 = HEAP32[$Data2$052>>2]|0;
    $132 = $131&255;
    $133 = ((($130) + (($i3$056*20)|0)|0) + 18|0);
    HEAP8[$133>>0] = $132;
    $134 = ($131|0)==(0);
    L38: do {
     if (!($134)) {
      $index$0$ph45 = 0;$j5$0$ph46 = 0;
      while(1) {
       $j5$022 = $j5$0$ph46;
       while(1) {
        $$sum3 = (($j5$022) + 1)|0;
        $135 = (($Data2$052) + ($$sum3<<2)|0);
        $136 = HEAP32[$135>>2]|0;
        $137 = ($136|0)==(255);
        if (!($137)) {
         break;
        }
        $142 = HEAP32[$14>>2]|0;
        $143 = ((($142) + (($i3$056*20)|0)|0) + 18|0);
        $144 = HEAP8[$143>>0]|0;
        $145 = (($144) + -1)<<24>>24;
        HEAP8[$143>>0] = $145;
        $146 = ($$sum3>>>0)<($131>>>0);
        if ($146) {
         $j5$022 = $$sum3;
        } else {
         break L38;
        }
       }
       $138 = $136&255;
       $139 = (($Dest$047) + ($index$0$ph45)|0);
       HEAP8[$139>>0] = $138;
       $140 = (($index$0$ph45) + 1)|0;
       $141 = ($$sum3>>>0)<($131>>>0);
       if ($141) {
        $index$0$ph45 = $140;$j5$0$ph46 = $$sum3;
       } else {
        break;
       }
      }
     }
    } while(0);
    $147 = HEAP32[$14>>2]|0;
    $148 = ((($147) + (($i3$056*20)|0)|0) + 18|0);
    $149 = HEAP8[$148>>0]|0;
    $150 = $149&255;
    $151 = ($149<<24>>24)==(0);
    $152 = ($Dest$047|0)==(0|0);
    $or$cond$i11 = $151 | $152;
    $or$cond1$i = $or$cond$i11 | $120;
    if (!($or$cond1$i)) {
     $153 = (($150) + -1)|0;
     $$phi$trans$insert$i = (($Dest$047) + ($153)|0);
     $$pre$i = HEAP8[$$phi$trans$insert$i>>0]|0;
     $$phi$trans$insert20$i = $$pre$i&255;
     $$phi$trans$insert21$i = ((($reducedHullDataHullVertices$0) + (($$phi$trans$insert20$i*12)|0)|0) + 4|0);
     $$pre22$i = Math_fround(HEAPF32[$$phi$trans$insert21$i>>2]);
     $$phi$trans$insert23$i = ((($reducedHullDataHullVertices$0) + (($$phi$trans$insert20$i*12)|0)|0) + 8|0);
     $$pre24$i = Math_fround(HEAPF32[$$phi$trans$insert23$i>>2]);
     $$phi$trans$insert25$i = (($reducedHullDataHullVertices$0) + (($$phi$trans$insert20$i*12)|0)|0);
     $$pre26$i = Math_fround(HEAPF32[$$phi$trans$insert25$i>>2]);
     $160 = $$pre22$i;$164 = $$pre24$i;$167 = Math_fround(0.0);$172 = $$pre26$i;$175 = Math_fround(0.0);$180 = Math_fround(0.0);$182 = Math_fround(0.0);$184 = Math_fround(0.0);$186 = Math_fround(0.0);$j$08$i = 0;
     while(1) {
      $154 = (($Dest$047) + ($j$08$i)|0);
      $155 = HEAP8[$154>>0]|0;
      $156 = $155&255;
      $157 = ((($reducedHullDataHullVertices$0) + (($156*12)|0)|0) + 4|0);
      $158 = Math_fround(HEAPF32[$157>>2]);
      $159 = Math_fround($160 - $158);
      $161 = ((($reducedHullDataHullVertices$0) + (($156*12)|0)|0) + 8|0);
      $162 = Math_fround(HEAPF32[$161>>2]);
      $163 = Math_fround($164 + $162);
      $165 = Math_fround($159 * $163);
      $166 = Math_fround($167 + $165);
      $168 = Math_fround($164 - $162);
      $169 = (($reducedHullDataHullVertices$0) + (($156*12)|0)|0);
      $170 = Math_fround(HEAPF32[$169>>2]);
      $171 = Math_fround($172 + $170);
      $173 = Math_fround($168 * $171);
      $174 = Math_fround($175 + $173);
      $176 = Math_fround($172 - $170);
      $177 = Math_fround($160 + $158);
      $178 = Math_fround($177 * $176);
      $179 = Math_fround($180 + $178);
      $181 = Math_fround($182 + $170);
      $183 = Math_fround($184 + $158);
      $185 = Math_fround($186 + $162);
      $187 = (($j$08$i) + 1)|0;
      $exitcond$i = ($187|0)==($150|0);
      if ($exitcond$i) {
       break;
      } else {
       $160 = $158;$164 = $162;$167 = $166;$172 = $170;$175 = $174;$180 = $179;$182 = $181;$184 = $183;$186 = $185;$j$08$i = $187;
      }
     }
     $188 = (($147) + (($i3$056*20)|0)|0);
     HEAPF32[$188>>2] = $166;
     $189 = ((($147) + (($i3$056*20)|0)|0) + 4|0);
     HEAPF32[$189>>2] = $174;
     $190 = ((($147) + (($i3$056*20)|0)|0) + 8|0);
     HEAPF32[$190>>2] = $179;
     $191 = Math_fround($166 * $166);
     $192 = Math_fround($174 * $174);
     $193 = Math_fround($191 + $192);
     $194 = Math_fround($179 * $179);
     $195 = Math_fround($194 + $193);
     $196 = (Math_fround(Math_sqrt((Math_fround($195)))));
     $197 = $196 > Math_fround(0.0);
     if ($197) {
      $198 = Math_fround(Math_fround(1.0) / $196);
      $199 = Math_fround($166 * $198);
      HEAPF32[$188>>2] = $199;
      $200 = Math_fround($174 * $198);
      HEAPF32[$189>>2] = $200;
      $201 = Math_fround($179 * $198);
      HEAPF32[$190>>2] = $201;
      $203 = $199;$205 = $200;$208 = $201;
     } else {
      $203 = $166;$205 = $174;$208 = $179;
     }
     $202 = Math_fround($181 * $203);
     $204 = Math_fround($183 * $205);
     $206 = Math_fround($204 + $202);
     $207 = Math_fround($185 * $208);
     $209 = Math_fround($207 + $206);
     $210 = Math_fround(-$209);
     $211 = (Math_fround(($149&255)));
     $212 = Math_fround($210 / $211);
     $213 = ((($147) + (($i3$056*20)|0)|0) + 12|0);
     HEAPF32[$213>>2] = $212;
    }
    $214 = HEAP32[$TriData$055>>2]|0;
    $TriData$131 = (($TriData$055) + 4|0);
    $215 = ($214|0)==(0);
    if ($215) {
     $313 = $147;$TriData$1$lcssa121 = $TriData$131;
    } else {
     $216 = HEAP32[$123>>2]|0;
     $217 = HEAP32[$this>>2]|0;
     $TriData$134 = $TriData$131;$flip$0$off032 = 0;$k$033 = 0;
     while(1) {
      $218 = HEAP32[$TriData$134>>2]|0;
      $219 = (($216) + (($218*12)|0)|0);
      $220 = HEAP32[$219>>2]|0;
      $221 = ((($216) + (($218*12)|0)|0) + 4|0);
      $222 = HEAP32[$221>>2]|0;
      $223 = ((($216) + (($218*12)|0)|0) + 8|0);
      $224 = HEAP32[$223>>2]|0;
      $225 = (($217) + (($222*12)|0)|0);
      $226 = Math_fround(HEAPF32[$225>>2]);
      $227 = (($217) + (($220*12)|0)|0);
      $228 = Math_fround(HEAPF32[$227>>2]);
      $229 = Math_fround($226 - $228);
      $230 = ((($217) + (($222*12)|0)|0) + 4|0);
      $231 = Math_fround(HEAPF32[$230>>2]);
      $232 = ((($217) + (($220*12)|0)|0) + 4|0);
      $233 = Math_fround(HEAPF32[$232>>2]);
      $234 = Math_fround($231 - $233);
      $235 = ((($217) + (($222*12)|0)|0) + 8|0);
      $236 = Math_fround(HEAPF32[$235>>2]);
      $237 = ((($217) + (($220*12)|0)|0) + 8|0);
      $238 = Math_fround(HEAPF32[$237>>2]);
      $239 = Math_fround($236 - $238);
      $240 = (($217) + (($224*12)|0)|0);
      $241 = Math_fround(HEAPF32[$240>>2]);
      $242 = Math_fround($241 - $228);
      $243 = ((($217) + (($224*12)|0)|0) + 4|0);
      $244 = Math_fround(HEAPF32[$243>>2]);
      $245 = Math_fround($244 - $233);
      $246 = ((($217) + (($224*12)|0)|0) + 8|0);
      $247 = Math_fround(HEAPF32[$246>>2]);
      $248 = Math_fround($247 - $238);
      $249 = Math_fround($234 * $248);
      $250 = Math_fround($239 * $245);
      $251 = Math_fround($249 - $250);
      $252 = Math_fround($239 * $242);
      $253 = Math_fround($229 * $248);
      $254 = Math_fround($252 - $253);
      $255 = Math_fround($229 * $245);
      $256 = Math_fround($234 * $242);
      $257 = Math_fround($255 - $256);
      $258 = Math_fround($251 * $251);
      $259 = Math_fround($254 * $254);
      $260 = Math_fround($258 + $259);
      $261 = Math_fround($257 * $257);
      $262 = Math_fround($261 + $260);
      $263 = $262 > Math_fround(0.0);
      if ($263) {
       $264 = (Math_fround(Math_sqrt((Math_fround($262)))));
       $265 = Math_fround(Math_fround(1.0) / $264);
       $266 = Math_fround($251 * $265);
       $267 = Math_fround($254 * $265);
       $268 = Math_fround($257 * $265);
       $273 = $266;$277 = $267;$282 = $268;
      } else {
       $273 = Math_fround(0.0);$277 = Math_fround(0.0);$282 = Math_fround(0.0);
      }
      $269 = ($k$033|0)==(0);
      if ($269) {
       $270 = (($147) + (($i3$056*20)|0)|0);
       $271 = Math_fround(HEAPF32[$270>>2]);
       $272 = Math_fround($273 * $271);
       $274 = ((($147) + (($i3$056*20)|0)|0) + 4|0);
       $275 = Math_fround(HEAPF32[$274>>2]);
       $276 = Math_fround($277 * $275);
       $278 = Math_fround($272 + $276);
       $279 = ((($147) + (($i3$056*20)|0)|0) + 8|0);
       $280 = Math_fround(HEAPF32[$279>>2]);
       $281 = Math_fround($282 * $280);
       $283 = Math_fround($278 + $281);
       $284 = $283 < Math_fround(0.0);
       if ($284) {
        $flip$1$off0 = 1;
       } else {
        $flip$1$off0 = $flip$0$off032;
       }
      } else {
       $flip$1$off0 = $flip$0$off032;
      }
      $285 = (($k$033) + 1)|0;
      $TriData$1 = (($TriData$134) + 4|0);
      $exitcond = ($285|0)==($214|0);
      if ($exitcond) {
       break;
      } else {
       $TriData$134 = $TriData$1;$flip$0$off032 = $flip$1$off0;$k$033 = $285;
      }
     }
     $TriData$131$sum = (($214) + 1)|0;
     $scevgep83 = (($TriData$055) + ($TriData$131$sum<<2)|0);
     if ($flip$1$off0) {
      $286 = (($147) + (($i3$056*20)|0)|0);
      $287 = Math_fround(HEAPF32[$286>>2]);
      $288 = Math_fround(-$287);
      $289 = ((($147) + (($i3$056*20)|0)|0) + 4|0);
      $290 = Math_fround(HEAPF32[$289>>2]);
      $291 = Math_fround(-$290);
      $292 = ((($147) + (($i3$056*20)|0)|0) + 8|0);
      $293 = Math_fround(HEAPF32[$292>>2]);
      $294 = Math_fround(-$293);
      HEAPF32[$286>>2] = $288;
      HEAPF32[$289>>2] = $291;
      HEAPF32[$292>>2] = $294;
      $295 = ((($147) + (($i3$056*20)|0)|0) + 12|0);
      $296 = Math_fround(HEAPF32[$295>>2]);
      $297 = Math_fround(-$296);
      HEAPF32[$295>>2] = $297;
      if ($or$cond$i11) {
       $313 = $147;$TriData$1$lcssa121 = $scevgep83;
      } else {
       $298 = $150 >>> 1;
       $299 = ($298|0)==(0);
       if ($299) {
        $313 = $147;$TriData$1$lcssa121 = $scevgep83;
       } else {
        $300 = (($150) + -1)|0;
        $i$01$i9 = 0;
        while(1) {
         $301 = (($Dest$047) + ($i$01$i9)|0);
         $302 = (($300) - ($i$01$i9))|0;
         $303 = (($Dest$047) + ($302)|0);
         $304 = HEAP8[$301>>0]|0;
         $305 = HEAP8[$303>>0]|0;
         HEAP8[$301>>0] = $305;
         HEAP8[$303>>0] = $304;
         $306 = (($i$01$i9) + 1)|0;
         $307 = ($306>>>0)<($298>>>0);
         if ($307) {
          $i$01$i9 = $306;
         } else {
          break;
         }
        }
        $$pre87 = HEAP32[$14>>2]|0;
        $313 = $$pre87;$TriData$1$lcssa121 = $scevgep83;
       }
      }
     } else {
      $313 = $147;$TriData$1$lcssa121 = $scevgep83;
     }
    }
    $308 = HEAP32[$7>>2]|0;
    $309 = (($308) + 38|0);
    $310 = HEAP8[$309>>0]|0;
    $311 = ($310<<24>>24)==(0);
    $312 = (($313) + (($i3$056*20)|0)|0);
    if ($311) {
     $$phi$trans$insert99 = ((($313) + (($i3$056*20)|0)|0) + 4|0);
     $$pre100 = Math_fround(HEAPF32[$$phi$trans$insert99>>2]);
     $$phi$trans$insert101 = ((($313) + (($i3$056*20)|0)|0) + 8|0);
     $$pre102 = Math_fround(HEAPF32[$$phi$trans$insert101>>2]);
     $$phi$trans$insert103 = ((($313) + (($i3$056*20)|0)|0) + 12|0);
     $$pre104 = Math_fround(HEAPF32[$$phi$trans$insert103>>2]);
     $$pre111 = Math_fround(HEAPF32[$312>>2]);
     $334 = $$pre111;$337 = $$pre100;$341 = $$pre102;$344 = $$pre104;
    } else {
     $$pre89 = HEAP32[$this>>2]|0;
     $$phi$trans$insert105 = ((($313) + (($i3$056*20)|0)|0) + 4|0);
     $$pre106 = Math_fround(HEAPF32[$$phi$trans$insert105>>2]);
     $$phi$trans$insert107 = ((($313) + (($i3$056*20)|0)|0) + 8|0);
     $$pre108 = Math_fround(HEAPF32[$$phi$trans$insert107>>2]);
     $$phi$trans$insert109 = ((($313) + (($i3$056*20)|0)|0) + 12|0);
     $$pre110 = Math_fround(HEAPF32[$$phi$trans$insert109>>2]);
     $$pre119 = Math_fround(HEAPF32[$312>>2]);
     $327 = $$pre110;$423 = $310;$j6$041 = 0;
     while(1) {
      $314 = (($$pre89) + (($j6$041*12)|0)|0);
      $315 = Math_fround(HEAPF32[$314>>2]);
      $316 = Math_fround($$pre119 * $315);
      $317 = ((($$pre89) + (($j6$041*12)|0)|0) + 4|0);
      $318 = Math_fround(HEAPF32[$317>>2]);
      $319 = Math_fround($$pre106 * $318);
      $320 = Math_fround($316 + $319);
      $321 = ((($$pre89) + (($j6$041*12)|0)|0) + 8|0);
      $322 = Math_fround(HEAPF32[$321>>2]);
      $323 = Math_fround($$pre108 * $322);
      $324 = Math_fround($320 + $323);
      $325 = Math_fround(-$324);
      $326 = $327 > $325;
      if ($326) {
       HEAPF32[$$phi$trans$insert109>>2] = $325;
       $$pre90 = HEAP8[$309>>0]|0;
       $330 = $$pre90;$424 = $325;
      } else {
       $330 = $423;$424 = $327;
      }
      $328 = (($j6$041) + 1)|0;
      $329 = $330&255;
      $331 = ($328>>>0)<($329>>>0);
      if ($331) {
       $327 = $424;$423 = $330;$j6$041 = $328;
      } else {
       $334 = $$pre119;$337 = $$pre106;$341 = $$pre108;$344 = $424;
       break;
      }
     }
    }
    $332 = Math_fround(HEAPF32[$GeomCenter>>2]);
    $333 = Math_fround($332 * $334);
    $335 = Math_fround(HEAPF32[$121>>2]);
    $336 = Math_fround($335 * $337);
    $338 = Math_fround($333 + $336);
    $339 = Math_fround(HEAPF32[$122>>2]);
    $340 = Math_fround($339 * $341);
    $342 = Math_fround($338 + $340);
    $343 = Math_fround($344 + $342);
    $345 = $343 > Math_fround(0.0);
    if ($345) {
     $346 = ((($313) + (($i3$056*20)|0)|0) + 18|0);
     $347 = HEAP8[$346>>0]|0;
     $348 = $347&255;
     $349 = ($347<<24>>24)==(0);
     $or$cond$i = $349 | $152;
     if ($or$cond$i) {
      $361 = $313;$366 = $337;$369 = $341;$372 = $344;
     } else {
      $350 = $348 >>> 1;
      $351 = ($350|0)==(0);
      if ($351) {
       $361 = $313;$366 = $337;$369 = $341;$372 = $344;
      } else {
       $352 = (($348) + -1)|0;
       $i$01$i = 0;
       while(1) {
        $353 = (($Dest$047) + ($i$01$i)|0);
        $354 = (($352) - ($i$01$i))|0;
        $355 = (($Dest$047) + ($354)|0);
        $356 = HEAP8[$353>>0]|0;
        $357 = HEAP8[$355>>0]|0;
        HEAP8[$353>>0] = $357;
        HEAP8[$355>>0] = $356;
        $358 = (($i$01$i) + 1)|0;
        $359 = ($358>>>0)<($350>>>0);
        if ($359) {
         $i$01$i = $358;
        } else {
         break;
        }
       }
       $$pre88 = HEAP32[$14>>2]|0;
       $$phi$trans$insert112 = ((($$pre88) + (($i3$056*20)|0)|0) + 4|0);
       $$pre113 = Math_fround(HEAPF32[$$phi$trans$insert112>>2]);
       $$phi$trans$insert114 = ((($$pre88) + (($i3$056*20)|0)|0) + 8|0);
       $$pre115 = Math_fround(HEAPF32[$$phi$trans$insert114>>2]);
       $$phi$trans$insert116 = ((($$pre88) + (($i3$056*20)|0)|0) + 12|0);
       $$pre117 = Math_fround(HEAPF32[$$phi$trans$insert116>>2]);
       $361 = $$pre88;$366 = $$pre113;$369 = $$pre115;$372 = $$pre117;
      }
     }
     $360 = (($361) + (($i3$056*20)|0)|0);
     $362 = Math_fround(HEAPF32[$360>>2]);
     $363 = Math_fround(-$362);
     $364 = ((($361) + (($i3$056*20)|0)|0) + 4|0);
     $365 = Math_fround(-$366);
     $367 = ((($361) + (($i3$056*20)|0)|0) + 8|0);
     $368 = Math_fround(-$369);
     HEAPF32[$360>>2] = $363;
     HEAPF32[$364>>2] = $365;
     HEAPF32[$367>>2] = $368;
     $370 = ((($361) + (($i3$056*20)|0)|0) + 12|0);
     $371 = Math_fround(-$372);
     HEAPF32[$370>>2] = $371;
     $377 = $361;
    } else {
     $377 = $313;
    }
    $373 = (($i3$056) + 1)|0;
    $374 = HEAP32[$NbPolygons>>2]|0;
    $375 = ($373>>>0)<($374>>>0);
    if (!($375)) {
     $388 = $374;
     break L34;
    }
    $376 = ((($377) + (($i3$056*20)|0)|0) + 18|0);
    $378 = HEAP8[$376>>0]|0;
    $379 = $378&255;
    $$sum = (($131) + 1)|0;
    $380 = (($Dest$047) + ($379)|0);
    $381 = (($Data2$052) + ($$sum<<2)|0);
    $$pre98 = HEAP32[$10>>2]|0;
    $126 = $$pre98;$130 = $377;$Data2$052 = $381;$Dest$047 = $380;$TriData$055 = $TriData$1$lcssa121;$i3$056 = $373;
   }
  }
 } while(0);
 $382 = HEAP32[$this>>2]|0;
 $383 = ($reducedHullDataHullVertices$0|0)==($382|0);
 if (!($383)) {
  $384 = $numReducedHullDataVertices$0&255;
  $385 = ($384*12)|0;
  _memcpy(($382|0),($reducedHullDataHullVertices$0|0),($385|0))|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$reducedHullDataHullVertices$0);
  $386 = HEAP32[$7>>2]|0;
  $387 = (($386) + 38|0);
  HEAP8[$387>>0] = $numReducedHullDataVertices$0;
 }
 $389 = (__ZN5physx17ConvexHullBuilder23CalculateVertexMapTableEjb($this,$388,0)|0);
 if (!($389)) {
  $$0 = 0;
  __ZN5physx2Gu9ContainerD2Ev($RendundantVertices);
  __ZN5physx2Gu9ContainerD2Ev($Temp2);
  __ZN5physx2Gu9ContainerD2Ev($Temp);
  STACKTOP = sp;return ($$0|0);
 }
 $390 = ($388|0)==(0);
 if (!($390)) {
  $j7$019 = 0;
  while(1) {
   $391 = HEAP32[$7>>2]|0;
   $392 = (($391) + 38|0);
   $393 = HEAP8[$392>>0]|0;
   $394 = HEAP32[$14>>2]|0;
   $395 = ($393<<24>>24)==(0);
   if ($395) {
    $minIndex$0$lcssa = -1;
   } else {
    $396 = HEAP32[$this>>2]|0;
    $397 = (($394) + (($j7$019*20)|0)|0);
    $398 = Math_fround(HEAPF32[$397>>2]);
    $399 = ((($394) + (($j7$019*20)|0)|0) + 4|0);
    $400 = Math_fround(HEAPF32[$399>>2]);
    $401 = ((($394) + (($j7$019*20)|0)|0) + 8|0);
    $402 = Math_fround(HEAPF32[$401>>2]);
    $Verts$015 = $396;$i9$018 = 0;$min$016 = Math_fround(3.40282346638528859812E+38);$minIndex$017 = -1;
    while(1) {
     $403 = (($Verts$015) + 12|0);
     $404 = Math_fround(HEAPF32[$Verts$015>>2]);
     $405 = Math_fround($404 * $398);
     $406 = (($Verts$015) + 4|0);
     $407 = Math_fround(HEAPF32[$406>>2]);
     $408 = Math_fround($407 * $400);
     $409 = Math_fround($405 + $408);
     $410 = (($Verts$015) + 8|0);
     $411 = Math_fround(HEAPF32[$410>>2]);
     $412 = Math_fround($411 * $402);
     $413 = Math_fround($409 + $412);
     $414 = $413 < $min$016;
     $min$1 = $414 ? $413 : $min$016;
     $minIndex$1 = $414 ? $i9$018 : $minIndex$017;
     $415 = (($i9$018) + 1)<<24>>24;
     $416 = ($415&255)<($393&255);
     if ($416) {
      $Verts$015 = $403;$i9$018 = $415;$min$016 = $min$1;$minIndex$017 = $minIndex$1;
     } else {
      $minIndex$0$lcssa = $minIndex$1;
      break;
     }
    }
   }
   $417 = ((($394) + (($j7$019*20)|0)|0) + 19|0);
   HEAP8[$417>>0] = $minIndex$0$lcssa;
   $418 = (($j7$019) + 1)|0;
   $419 = ($418>>>0)<($388>>>0);
   if ($419) {
    $j7$019 = $418;
   } else {
    break;
   }
  }
 }
 $420 = (__ZN5physx17ConvexHullBuilder27CreateTrianglesFromPolygonsEv($this)|0);
 $$0 = $420;
 __ZN5physx2Gu9ContainerD2Ev($RendundantVertices);
 __ZN5physx2Gu9ContainerD2Ev($Temp2);
 __ZN5physx2Gu9ContainerD2Ev($Temp);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx17ConvexHullBuilder17ComputeGeomCenterERNS_6PxVec3E($this,$center) {
 $this = $this|0;
 $center = $center|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0;
 var $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $9 = 0, $TotalArea$0$lcssa = Math_fround(0), $TotalArea$06 = Math_fround(0), $i$07 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 38|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = ($0|0)==(0|0);
 $or$cond = $5 | $6;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$center>>2] = Math_fround(0.0);
 $7 = (($center) + 4|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($center) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $83 = Math_fround(0.0);$85 = Math_fround(0.0);$87 = Math_fround(0.0);$TotalArea$0$lcssa = Math_fround(0.0);
 } else {
  $12 = (($this) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $73 = Math_fround(0.0);$75 = Math_fround(0.0);$77 = Math_fround(0.0);$TotalArea$06 = Math_fround(0.0);$i$07 = 0;
  while(1) {
   $14 = (($13) + (($i$07*12)|0)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($13) + (($i$07*12)|0)|0) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($13) + (($i$07*12)|0)|0) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($0) + (($15*12)|0)|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = (($0) + (($17*12)|0)|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($21 - $23);
   $25 = ((($0) + (($15*12)|0)|0) + 4|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = ((($0) + (($17*12)|0)|0) + 4|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = Math_fround($26 - $28);
   $30 = ((($0) + (($15*12)|0)|0) + 8|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = ((($0) + (($17*12)|0)|0) + 8|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = Math_fround($31 - $33);
   $35 = (($0) + (($19*12)|0)|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = Math_fround($21 - $36);
   $38 = ((($0) + (($19*12)|0)|0) + 4|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = Math_fround($26 - $39);
   $41 = ((($0) + (($19*12)|0)|0) + 8|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = Math_fround($31 - $42);
   $44 = Math_fround($29 * $43);
   $45 = Math_fround($34 * $40);
   $46 = Math_fround($44 - $45);
   $47 = Math_fround($34 * $37);
   $48 = Math_fround($24 * $43);
   $49 = Math_fround($47 - $48);
   $50 = Math_fround($24 * $40);
   $51 = Math_fround($29 * $37);
   $52 = Math_fround($50 - $51);
   $53 = Math_fround($46 * $46);
   $54 = Math_fround($49 * $49);
   $55 = Math_fround($53 + $54);
   $56 = Math_fround($52 * $52);
   $57 = Math_fround($56 + $55);
   $58 = (Math_fround(Math_sqrt((Math_fround($57)))));
   $59 = Math_fround($58 * Math_fround(0.5));
   $60 = Math_fround($21 + $23);
   $61 = Math_fround($26 + $28);
   $62 = Math_fround($31 + $33);
   $63 = Math_fround($60 + $36);
   $64 = Math_fround($61 + $39);
   $65 = Math_fround($62 + $42);
   $66 = Math_fround($63 * Math_fround(0.333333343267440795898));
   $67 = Math_fround($64 * Math_fround(0.333333343267440795898));
   $68 = Math_fround($65 * Math_fround(0.333333343267440795898));
   $69 = Math_fround($66 * $59);
   $70 = Math_fround($67 * $59);
   $71 = Math_fround($59 * $68);
   $72 = Math_fround($73 + $69);
   HEAPF32[$center>>2] = $72;
   $74 = Math_fround($70 + $75);
   HEAPF32[$7>>2] = $74;
   $76 = Math_fround($71 + $77);
   HEAPF32[$8>>2] = $76;
   $78 = Math_fround($TotalArea$06 + $59);
   $79 = (($i$07) + 1)|0;
   $80 = ($79>>>0)<($10>>>0);
   if ($80) {
    $73 = $72;$75 = $74;$77 = $76;$TotalArea$06 = $78;$i$07 = $79;
   } else {
    $83 = $72;$85 = $74;$87 = $76;$TotalArea$0$lcssa = $78;
    break;
   }
  }
 }
 $81 = Math_fround(Math_fround(1.0) / $TotalArea$0$lcssa);
 $82 = Math_fround($81 * $83);
 HEAPF32[$center>>2] = $82;
 $84 = Math_fround($81 * $85);
 HEAPF32[$7>>2] = $84;
 $86 = Math_fround($81 * $87);
 HEAPF32[$8>>2] = $86;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx17ConvexHullBuilder4SaveERNS_14PxOutputStreamEb($this,$stream,$platformMismatch) {
 $this = $this|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 var $$0 = 0, $$lcssa1 = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Nb$0$lcssa = 0, $Nb$07 = 0, $TmpCopy = 0, $exitcond = 0, $i$08 = 0, $i1$04 = 0, $i2$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $TmpCopy = sp;
 $0 = (__ZN5physx2Gu11WriteHeaderEhhhhjbRNS_14PxOutputStreamE(67,76,72,76,7,$platformMismatch,$stream)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN5physx2Gu11WriteHeaderEhhhhjbRNS_14PxOutputStreamE(67,86,72,76,7,$platformMismatch,$stream)|0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__ZN5physx17ConvexHullBuilder14CreateEdgeListEv($this)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 38|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($7,$platformMismatch,$stream);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 36|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($11,$platformMismatch,$stream);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 39|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  (__ZN5physx17ConvexHullBuilder17CreatePolygonDataEv($this)|0);
  $$pre$i = HEAP32[$3>>2]|0;
  $$phi$trans$insert$i = (($$pre$i) + 39|0);
  $$pre1$i = HEAP8[$$phi$trans$insert$i>>0]|0;
  $17 = $$pre1$i;
 } else {
  $17 = $14;
 }
 $16 = $17&255;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($16,$platformMismatch,$stream);
 $18 = HEAP32[$3>>2]|0;
 $19 = (($18) + 39|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $Nb$0$lcssa = 0;
 } else {
  $22 = (($this) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $20&255;
  $Nb$07 = 0;$i$08 = 0;
  while(1) {
   $25 = ((($23) + (($i$08*20)|0)|0) + 18|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = $26&255;
   $28 = (($27) + ($Nb$07))|0;
   $29 = (($i$08) + 1)|0;
   $30 = ($29>>>0)<($24>>>0);
   if ($30) {
    $Nb$07 = $28;$i$08 = $29;
   } else {
    $Nb$0$lcssa = $28;
    break;
   }
  }
 }
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($Nb$0$lcssa,$platformMismatch,$stream);
 $31 = HEAP32[$this>>2]|0;
 $32 = HEAP32[$3>>2]|0;
 $33 = (($32) + 38|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34&255;
 $36 = ($35*3)|0;
 __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($31,$36,$platformMismatch,$stream);
 $37 = HEAP32[$3>>2]|0;
 $38 = (($37) + 39|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  $$pre$phiZ2D = $stream;$139 = $37;
 } else {
  $41 = (($this) + 4|0);
  $42 = (($TmpCopy) + 4|0);
  $43 = (($TmpCopy) + 8|0);
  $44 = (($TmpCopy) + 12|0);
  $45 = (($TmpCopy) + 16|0);
  $46 = (($TmpCopy) + 3|0);
  $47 = (($TmpCopy) + 1|0);
  $48 = (($TmpCopy) + 2|0);
  $49 = (($42) + 3|0);
  $50 = (($42) + 1|0);
  $51 = (($42) + 2|0);
  $52 = (($43) + 3|0);
  $53 = (($43) + 1|0);
  $54 = (($43) + 2|0);
  $55 = (($44) + 3|0);
  $56 = (($44) + 1|0);
  $57 = (($44) + 2|0);
  $58 = (($45) + 1|0);
  $i1$04 = 0;
  while(1) {
   $63 = HEAP32[$41>>2]|0;
   $64 = (($63) + (($i1$04*20)|0)|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   HEAPF32[$TmpCopy>>2] = $65;
   $66 = ((($63) + (($i1$04*20)|0)|0) + 4|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   HEAPF32[$42>>2] = $67;
   $68 = ((($63) + (($i1$04*20)|0)|0) + 8|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   HEAPF32[$43>>2] = $69;
   $70 = ((($63) + (($i1$04*20)|0)|0) + 12|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   HEAPF32[$44>>2] = $71;
   $72 = ((($63) + (($i1$04*20)|0)|0) + 16|0);
   $73 = HEAPU16[$72>>1]|(HEAPU16[$72+2>>1]<<16);
   HEAP32[$45>>2] = $73;
   $74 = (HEAPF32[tempDoublePtr>>2]=$65,HEAP32[tempDoublePtr>>2]|0);
   $75 = (HEAPF32[tempDoublePtr>>2]=$67,HEAP32[tempDoublePtr>>2]|0);
   $76 = (HEAPF32[tempDoublePtr>>2]=$69,HEAP32[tempDoublePtr>>2]|0);
   $77 = (HEAPF32[tempDoublePtr>>2]=$71,HEAP32[tempDoublePtr>>2]|0);
   if ($platformMismatch) {
    $78 = $73 >>> 8;
    $79 = $77 >>> 16;
    $80 = $77 >>> 8;
    $81 = $77 >>> 24;
    $82 = $76 >>> 16;
    $83 = $76 >>> 8;
    $84 = $76 >>> 24;
    $85 = $75 >>> 16;
    $86 = $75 >>> 8;
    $87 = $75 >>> 24;
    $88 = $74 >>> 16;
    $89 = $74 >>> 8;
    $90 = $74 >>> 24;
    $91 = $78&255;
    $92 = $73&255;
    $93 = $79&255;
    $94 = $80&255;
    $95 = $81&255;
    $96 = $77&255;
    $97 = $82&255;
    $98 = $83&255;
    $99 = $84&255;
    $100 = $76&255;
    $101 = $85&255;
    $102 = $86&255;
    $103 = $87&255;
    $104 = $75&255;
    $105 = $88&255;
    $106 = $89&255;
    $107 = $90&255;
    $108 = $74&255;
    HEAP8[$TmpCopy>>0] = $107;
    HEAP8[$46>>0] = $108;
    HEAP8[$47>>0] = $105;
    HEAP8[$48>>0] = $106;
    HEAP8[$42>>0] = $103;
    HEAP8[$49>>0] = $104;
    HEAP8[$50>>0] = $101;
    HEAP8[$51>>0] = $102;
    HEAP8[$43>>0] = $99;
    HEAP8[$52>>0] = $100;
    HEAP8[$53>>0] = $97;
    HEAP8[$54>>0] = $98;
    HEAP8[$44>>0] = $95;
    HEAP8[$55>>0] = $96;
    HEAP8[$56>>0] = $93;
    HEAP8[$57>>0] = $94;
    HEAP8[$45>>0] = $91;
    HEAP8[$58>>0] = $92;
   }
   $109 = HEAP32[$stream>>2]|0;
   $110 = HEAP32[$109>>2]|0;
   (FUNCTION_TABLE_iiii[$110 & 2047]($stream,$TmpCopy,20)|0);
   $111 = (($i1$04) + 1)|0;
   $112 = HEAP32[$3>>2]|0;
   $113 = (($112) + 39|0);
   $114 = HEAP8[$113>>0]|0;
   $115 = $114&255;
   $116 = ($111>>>0)<($115>>>0);
   if ($116) {
    $i1$04 = $111;
   } else {
    $$pre$phiZ2D = $stream;$139 = $112;
    break;
   }
  }
 }
 $59 = ($Nb$0$lcssa|0)==(0);
 $60 = HEAP32[$$pre$phiZ2D>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 if ($59) {
  $$lcssa1 = $61;$126 = $139;
 } else {
  $62 = (($this) + 8|0);
  $119 = $61;$i2$02 = 0;
  while(1) {
   $117 = HEAP32[$62>>2]|0;
   $118 = (($117) + ($i2$02)|0);
   (FUNCTION_TABLE_iiii[$119 & 2047]($stream,$118,1)|0);
   $120 = (($i2$02) + 1)|0;
   $121 = HEAP32[$$pre$phiZ2D>>2]|0;
   $122 = HEAP32[$121>>2]|0;
   $exitcond = ($120|0)==($Nb$0$lcssa|0);
   if ($exitcond) {
    break;
   } else {
    $119 = $122;$i2$02 = $120;
   }
  }
  $$pre = HEAP32[$3>>2]|0;
  $$lcssa1 = $122;$126 = $$pre;
 }
 $123 = (($this) + 12|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($126) + 36|0);
 $127 = HEAP16[$125>>1]|0;
 $128 = $127&65535;
 $129 = $128 << 1;
 (FUNCTION_TABLE_iiii[$$lcssa1 & 2047]($stream,$124,$129)|0);
 $130 = HEAP32[$$pre$phiZ2D>>2]|0;
 $131 = HEAP32[$130>>2]|0;
 $132 = (($this) + 16|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = HEAP32[$3>>2]|0;
 $135 = (($134) + 38|0);
 $136 = HEAP8[$135>>0]|0;
 $137 = $136&255;
 $138 = ($137*3)|0;
 (FUNCTION_TABLE_iiii[$131 & 2047]($stream,$133,$138)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17ConvexHullBuilder14CreateEdgeListEv($this) {
 $this = $this|0;
 var $$ = 0, $$$i$i$i = 0, $$$i$i$i11 = 0, $$$i$i$i13 = 0, $$$i$i$i15 = 0, $$$i$i$i16 = 0, $$$i$i$i2 = 0, $$$i$i$i3 = 0, $$$i$i$i5 = 0, $$$i$i$i7 = 0, $$$i$i$i9 = 0, $$0 = 0, $$17 = 0, $$arith = 0, $$arith2 = 0, $$overflow = 0, $$overflow3 = 0, $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$pre = 0;
 var $$pre$i = 0, $$pre1$i = 0, $$pre83 = 0, $$pre86 = 0, $$pre87 = 0, $$pre90 = 0, $$pre91 = 0, $$pre92 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Data4$033 = 0, $Data4$119 = 0, $NbEdgesUnshared$0$lcssa = 0, $NbEdgesUnshared$064 = 0, $PreviousRef0$039 = 0, $PreviousRef0$1 = 0, $PreviousRef1$040 = 0, $PreviousRef1$1 = 0, $Run0$060 = 0;
 var $Run0$1$lcssa = 0, $Run0$147 = 0, $Run1$056 = 0, $Run1$1$lcssa = 0, $Run1$144 = 0, $Run2$057 = 0, $Run2$1$lcssa = 0, $Run2$145 = 0, $Run3$058 = 0, $Run3$1$lcssa = 0, $Run3$146 = 0, $Sorter = 0, $exitcond = 0, $exitcond69 = 0, $exitcond70 = 0, $exitcond71 = 0, $exitcond79 = 0, $exitcond80 = 0, $exitcond82 = 0, $i$063 = 0;
 var $i1$059 = 0, $i2$041 = 0, $i3$036 = 0, $i5$034 = 0, $i6$029 = 0, $i7$023 = 0, $i8$020 = 0, $i9$018 = 0, $j$048 = 0, $or$cond = 0, $scevgep = 0, $scevgep76 = 0, $scevgep77 = 0, $scevgep78 = 0, $tmp = 0, $umul_with_overflow = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer = sp;
 $Sorter = sp + 4|0;
 $0 = sp + 49|0;
 $1 = sp + 48|0;
 $2 = sp + 47|0;
 $3 = sp + 46|0;
 $4 = sp + 50|0;
 $5 = sp + 44|0;
 $6 = sp + 42|0;
 $7 = sp + 41|0;
 $8 = sp + 40|0;
 $9 = sp + 45|0;
 $10 = sp + 43|0;
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 39|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  (__ZN5physx17ConvexHullBuilder17CreatePolygonDataEv($this)|0);
  $$pre$i = HEAP32[$11>>2]|0;
  $$phi$trans$insert$i = (($$pre$i) + 39|0);
  $$pre1$i = HEAP8[$$phi$trans$insert$i>>0]|0;
  $16 = ($$pre1$i<<24>>24)==(0);
  if ($16) {
   $300 = 1;$71 = 0;$NbEdgesUnshared$0$lcssa = 0;
  } else {
   $20 = $$pre1$i;
   label = 3;
  }
 } else {
  $20 = $14;
  label = 3;
 }
 if ((label|0) == 3) {
  $17 = (($this) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $20&255;
  $NbEdgesUnshared$064 = 0;$i$063 = 0;
  while(1) {
   $21 = ((($18) + (($i$063*20)|0)|0) + 18|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = $22&255;
   $24 = (($23) + ($NbEdgesUnshared$064))|0;
   $25 = (($i$063) + 1)|0;
   $exitcond82 = ($25|0)==($19|0);
   if ($exitcond82) {
    $300 = 0;$71 = $20;$NbEdgesUnshared$0$lcssa = $24;
    break;
   } else {
    $NbEdgesUnshared$064 = $24;$i$063 = $25;
   }
  }
 }
 $$arith2 = $NbEdgesUnshared$0$lcssa<<2;
 $$overflow3 = ($NbEdgesUnshared$0$lcssa>>>0)>(1073741823);
 $26 = $$overflow3 ? -1 : $$arith2;
 $27 = ($26|0)==(0);
 if ($27) {
  $137 = 0;$140 = 0;$185 = 0;$186 = 0;$187 = 0;$93 = 0;$95 = 0;
 } else {
  $28 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (__Z15PxGetFoundationv()|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 24|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (FUNCTION_TABLE_ii[$35 & 4095]($32)|0);
  $$$i$i$i2 = $36 ? 533064 : 532808;
  $37 = (FUNCTION_TABLE_iiiiii[$31 & 255]($28,$26,$$$i$i$i2,532056,1789)|0);
  $38 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (__Z15PxGetFoundationv()|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 24|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (FUNCTION_TABLE_ii[$45 & 4095]($42)|0);
  $$$i$i$i3 = $46 ? 533064 : 532808;
  $47 = (FUNCTION_TABLE_iiiiii[$41 & 255]($38,$26,$$$i$i$i3,532056,1790)|0);
  $48 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 8|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (__Z15PxGetFoundationv()|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 24|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (FUNCTION_TABLE_ii[$55 & 4095]($52)|0);
  $$$i$i$i5 = $56 ? 533064 : 532808;
  $57 = (FUNCTION_TABLE_iiiiii[$51 & 255]($48,$26,$$$i$i$i5,532056,1791)|0);
  $58 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + 8|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (__Z15PxGetFoundationv()|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($63) + 24|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (FUNCTION_TABLE_ii[$65 & 4095]($62)|0);
  $$$i$i$i7 = $66 ? 533064 : 532808;
  $67 = (FUNCTION_TABLE_iiiiii[$61 & 255]($58,$26,$$$i$i$i7,532056,1792)|0);
  $137 = $57;$140 = $67;$185 = $57;$186 = $47;$187 = $37;$93 = $47;$95 = $37;
 }
 if (!($300)) {
  $68 = (($this) + 4|0);
  $69 = (($this) + 8|0);
  $70 = $71&255;
  $$pre86 = HEAP32[$68>>2]|0;
  $$pre87 = HEAP32[$69>>2]|0;
  $Run0$060 = $95;$Run1$056 = $93;$Run2$057 = $137;$Run3$058 = $140;$i1$059 = 0;
  while(1) {
   $72 = ((($$pre86) + (($i1$059*20)|0)|0) + 18|0);
   $73 = HEAP8[$72>>0]|0;
   $74 = $73&255;
   $75 = ((($$pre86) + (($i1$059*20)|0)|0) + 16|0);
   $76 = HEAP16[$75>>1]|0;
   $77 = $76&65535;
   $78 = ($73<<24>>24)==(0);
   if ($78) {
    $Run0$1$lcssa = $Run0$060;$Run1$1$lcssa = $Run1$056;$Run2$1$lcssa = $Run2$057;$Run3$1$lcssa = $Run3$058;
   } else {
    $scevgep = (($Run3$058) + ($74<<2)|0);
    $scevgep77 = (($Run1$056) + ($74<<2)|0);
    $Run0$147 = $Run0$060;$Run1$144 = $Run1$056;$Run2$145 = $Run2$057;$Run3$146 = $Run3$058;$j$048 = 0;
    while(1) {
     $$sum = (($j$048) + ($77))|0;
     $79 = (($$pre87) + ($$sum)|0);
     $80 = HEAP8[$79>>0]|0;
     $81 = $80&255;
     $82 = (($j$048) + 1)|0;
     $83 = ($82|0)==($74|0);
     $tmp = $83 ? 0 : $82;
     $$sum1 = (($tmp) + ($77))|0;
     $84 = (($$pre87) + ($$sum1)|0);
     $85 = HEAP8[$84>>0]|0;
     $86 = $85&255;
     $87 = ($80&255)>($85&255);
     $$ = $87 ? $86 : $81;
     $$17 = $87 ? $81 : $86;
     $88 = (($Run0$147) + 4|0);
     HEAP32[$Run0$147>>2] = $$;
     $89 = (($Run1$144) + 4|0);
     HEAP32[$Run1$144>>2] = $$17;
     $90 = (($Run2$145) + 4|0);
     HEAP32[$Run2$145>>2] = $i1$059;
     $91 = (($Run3$146) + 4|0);
     HEAP32[$Run3$146>>2] = $j$048;
     $exitcond79 = ($82|0)==($74|0);
     if ($exitcond79) {
      break;
     } else {
      $Run0$147 = $88;$Run1$144 = $89;$Run2$145 = $90;$Run3$146 = $91;$j$048 = $82;
     }
    }
    $scevgep76 = (($Run2$057) + ($74<<2)|0);
    $scevgep78 = (($Run0$060) + ($74<<2)|0);
    $Run0$1$lcssa = $scevgep78;$Run1$1$lcssa = $scevgep77;$Run2$1$lcssa = $scevgep76;$Run3$1$lcssa = $scevgep;
   }
   $92 = (($i1$059) + 1)|0;
   $exitcond80 = ($92|0)==($70|0);
   if ($exitcond80) {
    break;
   } else {
    $Run0$060 = $Run0$1$lcssa;$Run1$056 = $Run1$1$lcssa;$Run2$057 = $Run2$1$lcssa;$Run3$058 = $Run3$1$lcssa;$i1$059 = $92;
   }
  }
 }
 __ZN5physx2Gu17RadixSortBufferedC2Ev($Sorter);
 $94 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($Sorter,$93,$NbEdgesUnshared$0$lcssa,0)|0);
 $96 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($94,$95,$NbEdgesUnshared$0$lcssa,0)|0);
 $97 = (($96) + 8|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$11>>2]|0;
 $100 = (($99) + 36|0);
 HEAP16[$100>>1] = 0;
 if ($27) {
  $150 = 0;$152 = 0;$157 = 0;$297 = 0;$298 = 0;
 } else {
  $101 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($102) + 8|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (__Z15PxGetFoundationv()|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($106) + 24|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (FUNCTION_TABLE_ii[$108 & 4095]($105)|0);
  $$$i$i$i9 = $109 ? 533064 : 532808;
  $110 = (FUNCTION_TABLE_iiiiii[$104 & 255]($101,$26,$$$i$i$i9,532056,1829)|0);
  $111 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = (($112) + 8|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (__Z15PxGetFoundationv()|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($116) + 24|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (FUNCTION_TABLE_ii[$118 & 4095]($115)|0);
  $$$i$i$i11 = $119 ? 533064 : 532808;
  $120 = (FUNCTION_TABLE_iiiiii[$114 & 255]($111,$26,$$$i$i$i11,532056,1830)|0);
  $121 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = (($122) + 8|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = (__Z15PxGetFoundationv()|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 24|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (FUNCTION_TABLE_ii[$128 & 4095]($125)|0);
  $$$i$i$i13 = $129 ? 533064 : 532808;
  $130 = (FUNCTION_TABLE_iiiiii[$124 & 255]($121,$26,$$$i$i$i13,532056,1831)|0);
  $150 = $110;$152 = $120;$157 = $130;$297 = $120;$298 = $110;
 }
 $131 = ($NbEdgesUnshared$0$lcssa|0)==(0);
 if (!($131)) {
  $132 = HEAP32[$11>>2]|0;
  $133 = (($132) + 36|0);
  $PreviousRef0$039 = -1;$PreviousRef1$040 = -1;$i2$041 = 0;
  while(1) {
   $134 = (($98) + ($i2$041<<2)|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = (($137) + ($135<<2)|0);
   $138 = HEAP32[$136>>2]|0;
   $139 = (($140) + ($135<<2)|0);
   $141 = HEAP32[$139>>2]|0;
   $142 = (($95) + ($135<<2)|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = (($93) + ($135<<2)|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = ($143|0)==($PreviousRef0$039|0);
   $147 = ($145|0)==($PreviousRef1$040|0);
   $or$cond = $146 & $147;
   $$pre92 = HEAP16[$133>>1]|0;
   if ($or$cond) {
    $154 = $$pre92;$PreviousRef0$1 = $PreviousRef0$039;$PreviousRef1$1 = $PreviousRef1$040;
   } else {
    $148 = (($$pre92) + 1)<<16>>16;
    HEAP16[$133>>1] = $148;
    $154 = $148;$PreviousRef0$1 = $143;$PreviousRef1$1 = $145;
   }
   $149 = (($150) + ($i2$041<<2)|0);
   HEAP32[$149>>2] = $138;
   $151 = (($152) + ($i2$041<<2)|0);
   HEAP32[$151>>2] = $141;
   $153 = $154&65535;
   $155 = (($153) + -1)|0;
   $156 = (($157) + ($i2$041<<2)|0);
   HEAP32[$156>>2] = $155;
   $158 = (($i2$041) + 1)|0;
   $exitcond71 = ($158|0)==($NbEdgesUnshared$0$lcssa|0);
   if ($exitcond71) {
    break;
   } else {
    $PreviousRef0$039 = $PreviousRef0$1;$PreviousRef1$040 = $PreviousRef1$1;$i2$041 = $158;
   }
  }
 }
 $159 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($Sorter,$152,$NbEdgesUnshared$0$lcssa,0)|0);
 $160 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($159,$150,$NbEdgesUnshared$0$lcssa,0)|0);
 $161 = (($160) + 8|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = (($this) + 28|0);
 $164 = HEAP32[$163>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$164);
 HEAP32[$163>>2] = 0;
 $$arith = $NbEdgesUnshared$0$lcssa<<1;
 $$overflow = ($NbEdgesUnshared$0$lcssa>>>0)>(2147483647);
 $165 = $$overflow ? -1 : $$arith;
 $166 = ($165|0)==(0);
 if ($166) {
  $177 = 0;
 } else {
  $167 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $168 = HEAP32[$167>>2]|0;
  $169 = (($168) + 8|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = (__Z15PxGetFoundationv()|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = (($172) + 24|0);
  $174 = HEAP32[$173>>2]|0;
  $175 = (FUNCTION_TABLE_ii[$174 & 4095]($171)|0);
  $$$i$i$i15 = $175 ? 532960 : 532808;
  $176 = (FUNCTION_TABLE_iiiiii[$170 & 255]($167,$165,$$$i$i$i15,532056,1863)|0);
  $177 = $176;
 }
 HEAP32[$163>>2] = $177;
 if (!($131)) {
  $i3$036 = 0;
  while(1) {
   $178 = (($162) + ($i3$036<<2)|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = (($157) + ($179<<2)|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = $181&65535;
   $183 = (($177) + ($i3$036<<1)|0);
   HEAP16[$183>>1] = $182;
   $184 = (($i3$036) + 1)|0;
   $exitcond70 = ($184|0)==($NbEdgesUnshared$0$lcssa|0);
   if ($exitcond70) {
    break;
   } else {
    $i3$036 = $184;
   }
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$140);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$185);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$186);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$187);
 $188 = (($this) + 24|0);
 $189 = HEAP32[$188>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$189);
 HEAP32[$188>>2] = 0;
 $190 = HEAP32[$11>>2]|0;
 $191 = (($190) + 36|0);
 $192 = HEAP16[$191>>1]|0;
 $193 = ($192<<16>>16)==(0);
 if ($193) {
  $205 = 0;$207 = 0;
 } else {
  $194 = $192&65535;
  $umul_with_overflow = $194 << 3;
  $195 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = (($196) + 8|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = (__Z15PxGetFoundationv()|0);
  $200 = HEAP32[$199>>2]|0;
  $201 = (($200) + 24|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = (FUNCTION_TABLE_ii[$202 & 4095]($199)|0);
  $$$i$i$i16 = $203 ? 532840 : 532808;
  $204 = (FUNCTION_TABLE_iiiiii[$198 & 255]($195,$umul_with_overflow,$$$i$i$i16,532056,1876)|0);
  $$pre = HEAP32[$11>>2]|0;
  $$phi$trans$insert = (($$pre) + 36|0);
  $$pre83 = HEAP16[$$phi$trans$insert>>1]|0;
  $205 = $204;$207 = $$pre83;
 }
 HEAP32[$188>>2] = $205;
 $206 = $207&65535;
 $208 = $206 << 3;
 _memset(($205|0),0,($208|0))|0;
 if ($131) {
  $$pre90 = HEAP32[$188>>2]|0;
  $216 = $$pre90;
 } else {
  $209 = HEAP32[$163>>2]|0;
  $210 = HEAP32[$188>>2]|0;
  $Data4$033 = $209;$i5$034 = 0;
  while(1) {
   $217 = (($Data4$033) + 2|0);
   $218 = HEAP16[$Data4$033>>1]|0;
   $219 = $218&65535;
   $220 = ((($210) + ($219<<3)|0) + 2|0);
   $221 = HEAP16[$220>>1]|0;
   $222 = (($221) + 1)<<16>>16;
   HEAP16[$220>>1] = $222;
   $223 = (($i5$034) + 1)|0;
   $exitcond69 = ($223|0)==($NbEdgesUnshared$0$lcssa|0);
   if ($exitcond69) {
    $216 = $210;
    break;
   } else {
    $Data4$033 = $217;$i5$034 = $223;
   }
  }
 }
 $211 = HEAP32[$11>>2]|0;
 $212 = (($211) + 36|0);
 $213 = HEAP16[$212>>1]|0;
 $214 = ($213<<16>>16)==(0);
 do {
  if ($214) {
   $215 = (($216) + 4|0);
   HEAP32[$215>>2] = 0;
   $244 = 0;
  } else {
   $i6$029 = 0;
   while(1) {
    $227 = ((($216) + ($i6$029<<3)|0) + 2|0);
    $228 = HEAP16[$227>>1]|0;
    $229 = ($228<<16>>16)==(2);
    $226 = (($i6$029) + 1)|0;
    if (!($229)) {
     label = 35;
     break;
    }
    $224 = $213&65535;
    $225 = ($226>>>0)<($224>>>0);
    if ($225) {
     $i6$029 = $226;
    } else {
     label = 36;
     break;
    }
   }
   if ((label|0) == 35) {
    $230 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($230,32,532056,1892,532728,$vararg_buffer);
    $$0 = 0;
    __ZN5physx2Gu17RadixSortBufferedD2Ev($Sorter);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 36) {
    $231 = (($216) + 4|0);
    HEAP32[$231>>2] = 0;
    $232 = $213&65535;
    $233 = ($213&65535)>(1);
    if ($233) {
     $239 = 0;$i7$023 = 1;
    } else {
     $244 = $232;
     break;
    }
    while(1) {
     $234 = (($i7$023) + -1)|0;
     $235 = ((($216) + ($234<<3)|0) + 2|0);
     $236 = HEAP16[$235>>1]|0;
     $237 = $236&65535;
     $238 = (($237) + ($239))|0;
     $240 = ((($216) + ($i7$023<<3)|0) + 4|0);
     HEAP32[$240>>2] = $238;
     $241 = (($i7$023) + 1)|0;
     $242 = ($241>>>0)<($232>>>0);
     if ($242) {
      $239 = $238;$i7$023 = $241;
     } else {
      $244 = $232;
      break;
     }
    }
   }
  }
 } while(0);
 $243 = (($244) + -1)|0;
 $245 = ((($216) + ($243<<3)|0) + 4|0);
 $246 = HEAP32[$245>>2]|0;
 $247 = ((($216) + ($243<<3)|0) + 2|0);
 $248 = HEAP16[$247>>1]|0;
 $249 = $248&65535;
 $250 = (($249) + ($246))|0;
 $251 = (($this) + 12|0);
 $252 = HEAP32[$251>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$252);
 HEAP32[$251>>2] = 0;
 $253 = ($250|0)==(0);
 if ($253) {
  $264 = 0;
 } else {
  $254 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $255 = HEAP32[$254>>2]|0;
  $256 = (($255) + 8|0);
  $257 = HEAP32[$256>>2]|0;
  $258 = (__Z15PxGetFoundationv()|0);
  $259 = HEAP32[$258>>2]|0;
  $260 = (($259) + 24|0);
  $261 = HEAP32[$260>>2]|0;
  $262 = (FUNCTION_TABLE_ii[$261 & 4095]($258)|0);
  $$$i$i$i = $262 ? 533168 : 532808;
  $263 = (FUNCTION_TABLE_iiiiii[$257 & 255]($254,$250,$$$i$i$i,532056,1905)|0);
  $264 = $263;
 }
 HEAP32[$251>>2] = $264;
 L64: do {
  if (!($131)) {
   $265 = HEAP32[$163>>2]|0;
   $278 = $264;$Data4$119 = $265;$i8$020 = 0;
   while(1) {
    $266 = (($162) + ($i8$020<<2)|0);
    $267 = HEAP32[$266>>2]|0;
    $268 = (($150) + ($267<<2)|0);
    $269 = HEAP32[$268>>2]|0;
    $270 = $269&255;
    $271 = HEAP16[$Data4$119>>1]|0;
    $272 = $271&65535;
    $273 = HEAP32[$188>>2]|0;
    $274 = ((($273) + ($272<<3)|0) + 4|0);
    $275 = HEAP32[$274>>2]|0;
    $276 = (($275) + 1)|0;
    HEAP32[$274>>2] = $276;
    $277 = (($278) + ($275)|0);
    HEAP8[$277>>0] = $270;
    $279 = (($i8$020) + 1)|0;
    $exitcond = ($279|0)==($NbEdgesUnshared$0$lcssa|0);
    if ($exitcond) {
     break L64;
    }
    $280 = (($Data4$119) + 2|0);
    $$pre91 = HEAP32[$251>>2]|0;
    $278 = $$pre91;$Data4$119 = $280;$i8$020 = $279;
   }
  }
 } while(0);
 $281 = HEAP32[$188>>2]|0;
 $282 = (($281) + 4|0);
 HEAP32[$282>>2] = 0;
 $283 = HEAP32[$11>>2]|0;
 $284 = (($283) + 36|0);
 $285 = HEAP16[$284>>1]|0;
 $286 = ($285&65535)>(1);
 if ($286) {
  $287 = $285&65535;
  $293 = 0;$i9$018 = 1;
  while(1) {
   $288 = (($i9$018) + -1)|0;
   $289 = ((($281) + ($288<<3)|0) + 2|0);
   $290 = HEAP16[$289>>1]|0;
   $291 = $290&65535;
   $292 = (($291) + ($293))|0;
   $294 = ((($281) + ($i9$018<<3)|0) + 4|0);
   HEAP32[$294>>2] = $292;
   $295 = (($i9$018) + 1)|0;
   $296 = ($295>>>0)<($287>>>0);
   if ($296) {
    $293 = $292;$i9$018 = $295;
   } else {
    break;
   }
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$157);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($8,$297);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($9,$298);
 $299 = HEAP32[$188>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($10,$299);
 HEAP32[$188>>2] = 0;
 $$0 = 1;
 __ZN5physx2Gu17RadixSortBufferedD2Ev($Sorter);
 STACKTOP = sp;return ($$0|0);
}
function __ZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_($nb_polygons,$polygon_data,$hull,$triangle_data,$rendundantVertices) {
 $nb_polygons = $nb_polygons|0;
 $polygon_data = $polygon_data|0;
 $hull = $hull|0;
 $triangle_data = $triangle_data|0;
 $rendundantVertices = $rendundantVertices|0;
 var $$$i$i = 0, $$0$i$i = 0, $$1$i$i = 0, $$3 = 0, $$found0$0$off0 = 0, $$found2$0$off0 = 0, $$lcssa88 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i15 = 0, $$pre$i$i24 = 0, $$pre$i$i33 = 0, $$pre$i$i40 = 0, $$pre$i$i43 = 0, $$pre$i1$i = 0, $$pre$i16 = 0, $$pre$i18 = 0, $$pre$i20 = 0, $$pre$i22 = 0;
 var $$pre$i27 = 0, $$pre$i29 = 0, $$pre$i3$i = 0, $$pre$i31 = 0, $$pre$i36 = 0, $$pre$i39 = 0, $$pre$i5$i = 0, $$pre119 = 0, $$pre120 = 0, $$pre121 = 0, $$pre122 = 0, $$pre123 = 0, $$pre124 = 0, $$pre44$i = 0, $$pre45$i = 0, $$pre46$i = 0, $$pre47$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ActiveSegments = 0, $Adj = 0, $Create = 0, $CurrentFace$0 = 0, $Indices = 0, $LineStrip = 0, $Ref1$0$be$i = 0;
 var $Ref1$0$ph$i = 0, $Ref1$016$i = 0, $brmerge$demorgan = 0, $brmerge$demorgan$i$i = 0, $brmerge12$demorgan = 0, $brmerge5$demorgan$i$i = 0, $exitcond = 0, $exitcond114 = 0, $found0$0$off077 = 0, $found1$0$off078 = 0, $found1$1$off0 = 0, $found1$2$off0127 = 0, $found1$2$off0130 = 0, $found2$0$off079 = 0, $found2$2$off0128 = 0, $found2$2$off0128132 = 0, $found2$2$off0128133 = 0, $found2$2$off0131 = 0, $hull$idx$val = 0, $i$0$i = 0;
 var $i$020$i = 0, $i$051 = 0, $i$06$i$i = 0, $i1$016$i = 0, $i1$073 = 0, $i2$014$i = 0, $i2$090 = 0, $i7$046 = 0, $j$017$i = 0, $j$023$i = 0, $j$080 = 0, $neighborIndex01$i$i = 0, $neighborIndex10$i$i = 0, $neighborIndex11$i$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i38 = 0, $or$cond50$i = 0, $phitmp$i = 0;
 var $testIndex0$0$i$i = 0, $testIndex1$0$i$i = 0, $testTr0$0$i$i = 0, $testTr1$0$i$i = 0, $valid$2$off0$$i = 0, $valid$2$off0$i = 0, $valid$3$off0$$i = 0, $valid$3$off0$i = 0, $valid$5$off0$$i = 0, $valid$5$off0$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $vararg_buffer = sp;
 $neighborIndex01$i$i = sp + 80|0;
 $neighborIndex10$i$i = sp + 76|0;
 $neighborIndex11$i$i = sp + 72|0;
 $Create = sp + 84|0;
 $Adj = sp + 32|0;
 $Indices = sp + 16|0;
 $ActiveSegments = sp + 40|0;
 $LineStrip = sp + 56|0;
 $0 = (($hull) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$hull>>2]|0;
 $3 = (($hull) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 38|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = (($hull) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($Create) + 16|0);
 ;HEAP32[$Create+0>>2]=0|0;HEAP32[$Create+4>>2]=0|0;HEAP32[$Create+8>>2]=0|0;
 HEAP32[$Create>>2] = $1;
 $11 = (($Create) + 4|0);
 HEAP32[$11>>2] = $9;
 $12 = (($Create) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = (($Create) + 12|0);
 HEAP32[$13>>2] = $2;
 HEAPF32[$10>>2] = Math_fround(0.00499999988824129104614);
 __ZN5physx18AdjacenciesBuilderC2Ev($Adj);
 $14 = (__ZN5physx18AdjacenciesBuilder4InitERKNS_17ADJACENCIESCREATEE($Adj,$Create)|0);
 if (!($14)) {
  $$3 = 0;
  __ZN5physx11AdjacenciesD2Ev($Adj);
  STACKTOP = sp;return ($$3|0);
 }
 $15 = (__ZNK5physx11Adjacencies22ComputeNbBoundaryEdgesEv($Adj)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  $$3 = 0;
  __ZN5physx11AdjacenciesD2Ev($Adj);
  STACKTOP = sp;return ($$3|0);
 }
 $17 = STACKTOP; STACKTOP = STACKTOP + ((((1*$1)|0)+15)&-16)|0;;
 _memset(($17|0),0,($1|0))|0;
 $18 = STACKTOP; STACKTOP = STACKTOP + ((((1*$7)|0)+15)&-16)|0;;
 _memset(($18|0),0,($7|0))|0;
 HEAP32[$nb_polygons>>2] = 0;
 $19 = (($Adj) + 4|0);
 $20 = (($Indices) + 4|0);
 $21 = (($Indices) + 8|0);
 $22 = ($9|0)==(0|0);
 $23 = (($vararg_buffer) + 8|0);
 $24 = (($vararg_buffer) + 4|0);
 $25 = (($LineStrip) + 4|0);
 $26 = (($LineStrip) + 8|0);
 $27 = (($polygon_data) + 4|0);
 $28 = (($polygon_data) + 8|0);
 $29 = ($triangle_data|0)==(0|0);
 $30 = (($triangle_data) + 4|0);
 $31 = (($triangle_data) + 8|0);
 $32 = (($rendundantVertices) + 4|0);
 $33 = (($rendundantVertices) + 8|0);
 $34 = (($ActiveSegments) + 4|0);
 $35 = (($ActiveSegments) + 8|0);
 $CurrentFace$0 = 0;
 L7: while(1) {
  $36 = ($CurrentFace$0>>>0)<($1>>>0);
  if ($36) {
   $37 = (($17) + ($CurrentFace$0)|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = ($38<<24>>24)==(0);
   if (!($39)) {
    $40 = (($CurrentFace$0) + 1)|0;
    $CurrentFace$0 = $40;
    continue;
   }
  }
  $41 = ($CurrentFace$0|0)==($1|0);
  if ($41) {
   label = 128;
   break;
  }
  __ZN5physx2Gu9ContainerC2Ev($Indices);
  L14: while(1) {
   $42 = HEAP32[$19>>2]|0;
   __ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local9FloodFillES3_PKNS0_11AdjTriangleEjPb($Indices,$42,$CurrentFace$0,$17);
   $43 = HEAP32[$19>>2]|0;
   $i$0$i = 0;
   while(1) {
    $44 = HEAP32[$20>>2]|0;
    $45 = ($i$0$i>>>0)<($44>>>0);
    if (!($45)) {
     break L14;
    }
    $46 = (($i$0$i) + 1)|0;
    $47 = ($46>>>0)<($44>>>0);
    $48 = HEAP32[$21>>2]|0;
    $49 = (($48) + ($i$0$i<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    L19: do {
     if ($47) {
      $j$017$i = $46;
      while(1) {
       $51 = (($48) + ($j$017$i<<2)|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($43) + (($52*12)|0)|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = $54 & 536870911;
       $56 = ($55|0)==($50|0);
       if ($56) {
        $57 = $54 & 536870912;
        $58 = ($57|0)==(0);
        $valid$2$off0$i = $58;
       } else {
        $valid$2$off0$i = 1;
       }
       $59 = ((($43) + (($52*12)|0)|0) + 4|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = $60 & 536870911;
       $62 = ($61|0)==($50|0);
       if ($62) {
        $63 = $60 & 536870912;
        $64 = ($63|0)==(0);
        $valid$2$off0$$i = $64 & $valid$2$off0$i;
        $valid$3$off0$i = $valid$2$off0$$i;
       } else {
        $valid$3$off0$i = $valid$2$off0$i;
       }
       $65 = ((($43) + (($52*12)|0)|0) + 8|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = $66 & 536870911;
       $68 = ($67|0)==($50|0);
       if ($68) {
        $69 = $66 & 536870912;
        $70 = ($69|0)==(0);
        $valid$3$off0$$i = $70 & $valid$3$off0$i;
        if (!($valid$3$off0$$i)) {
         $valid$5$off0$i = 0;
         break L19;
        }
       } else {
        if (!($valid$3$off0$i)) {
         $valid$5$off0$i = 0;
         break L19;
        }
       }
       $71 = (($j$017$i) + 1)|0;
       $72 = ($71>>>0)<($44>>>0);
       if ($72) {
        $j$017$i = $71;
       } else {
        $valid$5$off0$i = 1;
        break;
       }
      }
     } else {
      $valid$5$off0$i = 1;
     }
    } while(0);
    L33: do {
     if ($22) {
      $$0$i$i = 1;
     } else {
      $73 = ($50*3)|0;
      $74 = (($9) + ($73<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($73) + 1)|0;
      $77 = (($9) + ($76<<2)|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($73) + 2)|0;
      $80 = (($9) + ($79<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $i$06$i$i = 0;
      while(1) {
       $82 = ((($43) + (($50*12)|0)|0) + ($i$06$i$i<<2)|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = $83 & 536870912;
       $85 = ($84|0)==(0);
       if ($85) {
        $86 = ($i$06$i$i|0)==(0);
        if ($86) {
         $testIndex0$0$i$i = 1;$testIndex1$0$i$i = 2;$testTr0$0$i$i = $75;$testTr1$0$i$i = $78;
        } else {
         $87 = ($i$06$i$i|0)==(1);
         $$$i$i = $87 ? $75 : $78;
         $$1$i$i = $87 ? 2 : 1;
         $testIndex0$0$i$i = 0;$testIndex1$0$i$i = $$1$i$i;$testTr0$0$i$i = $$$i$i;$testTr1$0$i$i = $81;
        }
        $88 = ((($43) + (($50*12)|0)|0) + ($testIndex0$0$i$i<<2)|0);
        $89 = HEAP32[$88>>2]|0;
        $90 = $89 & 536870911;
        $91 = (__ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local15GetNeighborFaceEjjPKNS0_11AdjTriangleEPKjS_S_($50,$testTr0$0$i$i,$43,$9,$vararg_buffer,$neighborIndex01$i$i)|0);
        $92 = (__ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local15GetNeighborFaceEjjPKNS0_11AdjTriangleEPKjS_S_($90,$testTr0$0$i$i,$43,$9,$neighborIndex10$i$i,$neighborIndex11$i$i)|0);
        $brmerge$demorgan$i$i = $91 & $92;
        if ($brmerge$demorgan$i$i) {
         $93 = HEAP32[$vararg_buffer>>2]|0;
         $94 = HEAP32[$neighborIndex11$i$i>>2]|0;
         $95 = ($93|0)==($94|0);
         if ($95) {
          $96 = HEAP32[$neighborIndex01$i$i>>2]|0;
          $97 = HEAP32[$neighborIndex10$i$i>>2]|0;
          $98 = ($96|0)==($97|0);
          if ($98) {
           $$0$i$i = 0;
           break L33;
          }
         }
        }
        $99 = ((($43) + (($50*12)|0)|0) + ($testIndex1$0$i$i<<2)|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = $100 & 536870911;
        $102 = (__ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local15GetNeighborFaceEjjPKNS0_11AdjTriangleEPKjS_S_($50,$testTr1$0$i$i,$43,$9,$vararg_buffer,$neighborIndex01$i$i)|0);
        $103 = (__ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local15GetNeighborFaceEjjPKNS0_11AdjTriangleEPKjS_S_($101,$testTr1$0$i$i,$43,$9,$neighborIndex10$i$i,$neighborIndex11$i$i)|0);
        $brmerge5$demorgan$i$i = $102 & $103;
        if ($brmerge5$demorgan$i$i) {
         $104 = HEAP32[$vararg_buffer>>2]|0;
         $105 = HEAP32[$neighborIndex11$i$i>>2]|0;
         $106 = ($104|0)==($105|0);
         if ($106) {
          $107 = HEAP32[$neighborIndex01$i$i>>2]|0;
          $108 = HEAP32[$neighborIndex10$i$i>>2]|0;
          $109 = ($107|0)==($108|0);
          if ($109) {
           $$0$i$i = 0;
           break L33;
          }
         }
        }
       }
       $110 = (($i$06$i$i) + 1)|0;
       $111 = ($110>>>0)<(3);
       if ($111) {
        $i$06$i$i = $110;
       } else {
        $$0$i$i = 1;
        break;
       }
      }
     }
    } while(0);
    $valid$5$off0$$i = $$0$i$i & $valid$5$off0$i;
    if ($valid$5$off0$$i) {
     $i$0$i = $46;
    } else {
     break;
    }
   }
   $112 = HEAP32[$20>>2]|0;
   $113 = ($112|0)==(0);
   if ($113) {
    continue;
   }
   $114 = HEAP32[$21>>2]|0;
   $i1$016$i = 0;
   while(1) {
    $115 = (($114) + ($i1$016$i<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($43) + (($116*12)|0)|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = $118 | 536870912;
    HEAP32[$117>>2] = $119;
    $120 = ((($43) + (($116*12)|0)|0) + 4|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = $121 | 536870912;
    HEAP32[$120>>2] = $122;
    $123 = ((($43) + (($116*12)|0)|0) + 8|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = $124 | 536870912;
    HEAP32[$123>>2] = $125;
    $126 = HEAP32[$115>>2]|0;
    $127 = (($17) + ($126)|0);
    HEAP8[$127>>0] = 0;
    $128 = (($i1$016$i) + 1)|0;
    $129 = HEAP32[$20>>2]|0;
    $130 = ($128>>>0)<($129>>>0);
    if ($130) {
     $i1$016$i = $128;
    } else {
     break;
    }
   }
   $phitmp$i = ($129|0)==(0);
   if ($phitmp$i) {
    continue;
   }
   HEAP32[$20>>2] = 0;
  }
  __ZN5physx2Gu9ContainerC2Ev($ActiveSegments);
  $131 = HEAP32[$20>>2]|0;
  $132 = ($131|0)==(0);
  if (!($132)) {
   $i$051 = 0;
   while(1) {
    $133 = HEAP32[$21>>2]|0;
    $134 = (($133) + ($i$051<<2)|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = ($135*3)|0;
    if ($22) {
     label = 41;
     break L7;
    }
    $137 = (($9) + ($136<<2)|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = (($136) + 1)|0;
    $140 = (($9) + ($139<<2)|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (($136) + 2)|0;
    $143 = (($9) + ($142<<2)|0);
    $144 = HEAP32[$143>>2]|0;
    $145 = HEAP32[$19>>2]|0;
    $146 = (($145) + (($135*12)|0)|0);
    $147 = HEAP32[$146>>2]|0;
    $148 = $147 & 536870912;
    $149 = ($148|0)==(0);
    if ($149) {
     $165 = $145;
    } else {
     $150 = HEAP32[$34>>2]|0;
     $151 = HEAP32[$ActiveSegments>>2]|0;
     $152 = ($150|0)==($151|0);
     if ($152) {
      (__ZN5physx2Gu9Container6ResizeEj($ActiveSegments,1)|0);
      $$pre$i = HEAP32[$34>>2]|0;
      $154 = $$pre$i;
     } else {
      $154 = $150;
     }
     $153 = (($154) + 1)|0;
     HEAP32[$34>>2] = $153;
     $155 = HEAP32[$35>>2]|0;
     $156 = (($155) + ($154<<2)|0);
     HEAP32[$156>>2] = $138;
     $157 = HEAP32[$34>>2]|0;
     $158 = HEAP32[$ActiveSegments>>2]|0;
     $159 = ($157|0)==($158|0);
     if ($159) {
      (__ZN5physx2Gu9Container6ResizeEj($ActiveSegments,1)|0);
      $$pre$i16 = HEAP32[$34>>2]|0;
      $$pre124 = HEAP32[$35>>2]|0;
      $161 = $$pre$i16;$163 = $$pre124;
     } else {
      $161 = $157;$163 = $155;
     }
     $160 = (($161) + 1)|0;
     HEAP32[$34>>2] = $160;
     $162 = (($163) + ($161<<2)|0);
     HEAP32[$162>>2] = $141;
     $$pre120 = HEAP32[$19>>2]|0;
     $165 = $$pre120;
    }
    $164 = ((($165) + (($135*12)|0)|0) + 4|0);
    $166 = HEAP32[$164>>2]|0;
    $167 = $166 & 536870912;
    $168 = ($167|0)==(0);
    if ($168) {
     $184 = $165;
    } else {
     $169 = HEAP32[$34>>2]|0;
     $170 = HEAP32[$ActiveSegments>>2]|0;
     $171 = ($169|0)==($170|0);
     if ($171) {
      (__ZN5physx2Gu9Container6ResizeEj($ActiveSegments,1)|0);
      $$pre$i20 = HEAP32[$34>>2]|0;
      $173 = $$pre$i20;
     } else {
      $173 = $169;
     }
     $172 = (($173) + 1)|0;
     HEAP32[$34>>2] = $172;
     $174 = HEAP32[$35>>2]|0;
     $175 = (($174) + ($173<<2)|0);
     HEAP32[$175>>2] = $138;
     $176 = HEAP32[$34>>2]|0;
     $177 = HEAP32[$ActiveSegments>>2]|0;
     $178 = ($176|0)==($177|0);
     if ($178) {
      (__ZN5physx2Gu9Container6ResizeEj($ActiveSegments,1)|0);
      $$pre$i22 = HEAP32[$34>>2]|0;
      $$pre123 = HEAP32[$35>>2]|0;
      $180 = $$pre$i22;$182 = $$pre123;
     } else {
      $180 = $176;$182 = $174;
     }
     $179 = (($180) + 1)|0;
     HEAP32[$34>>2] = $179;
     $181 = (($182) + ($180<<2)|0);
     HEAP32[$181>>2] = $144;
     $$pre121 = HEAP32[$19>>2]|0;
     $184 = $$pre121;
    }
    $183 = ((($184) + (($135*12)|0)|0) + 8|0);
    $185 = HEAP32[$183>>2]|0;
    $186 = $185 & 536870912;
    $187 = ($186|0)==(0);
    if (!($187)) {
     $188 = HEAP32[$34>>2]|0;
     $189 = HEAP32[$ActiveSegments>>2]|0;
     $190 = ($188|0)==($189|0);
     if ($190) {
      (__ZN5physx2Gu9Container6ResizeEj($ActiveSegments,1)|0);
      $$pre$i27 = HEAP32[$34>>2]|0;
      $192 = $$pre$i27;
     } else {
      $192 = $188;
     }
     $191 = (($192) + 1)|0;
     HEAP32[$34>>2] = $191;
     $193 = HEAP32[$35>>2]|0;
     $194 = (($193) + ($192<<2)|0);
     HEAP32[$194>>2] = $141;
     $195 = HEAP32[$34>>2]|0;
     $196 = HEAP32[$ActiveSegments>>2]|0;
     $197 = ($195|0)==($196|0);
     if ($197) {
      (__ZN5physx2Gu9Container6ResizeEj($ActiveSegments,1)|0);
      $$pre$i29 = HEAP32[$34>>2]|0;
      $$pre122 = HEAP32[$35>>2]|0;
      $199 = $$pre$i29;$201 = $$pre122;
     } else {
      $199 = $195;$201 = $193;
     }
     $198 = (($199) + 1)|0;
     HEAP32[$34>>2] = $198;
     $200 = (($201) + ($199<<2)|0);
     HEAP32[$200>>2] = $144;
    }
    $202 = (($i$051) + 1)|0;
    $203 = HEAP32[$20>>2]|0;
    $204 = ($202>>>0)<($203>>>0);
    if ($204) {
     $i$051 = $202;
    } else {
     break;
    }
   }
  }
  __ZN5physx2Gu9ContainerC2Ev($LineStrip);
  __ZN5physx2Gu9ContainerC2ERKS1_($vararg_buffer,$ActiveSegments);
  $205 = HEAP32[$24>>2]|0;
  $206 = $205 >>> 1;
  $207 = ($206|0)==(0);
  L89: do {
   if ($207) {
    $254 = $205;
   } else {
    $208 = HEAP32[$23>>2]|0;
    $215 = $206;$227 = $205;
    while(1) {
     $j$023$i = 0;
     L93: while(1) {
      $209 = (($208) + ($j$023$i<<3)|0);
      $210 = HEAP32[$209>>2]|0;
      $211 = ((($208) + ($j$023$i<<3)|0) + 4|0);
      $212 = HEAP32[$211>>2]|0;
      $213 = (($j$023$i) + 1)|0;
      $214 = ($213>>>0)<($215>>>0);
      if ($214) {
       $i$020$i = $213;
      } else {
       $254 = $227;
       break L89;
      }
      while(1) {
       $216 = (($208) + ($i$020$i<<3)|0);
       $217 = HEAP32[$216>>2]|0;
       $218 = ($217|0)==($210|0);
       $219 = ((($208) + ($i$020$i<<3)|0) + 4|0);
       $220 = HEAP32[$219>>2]|0;
       $221 = ($220|0)==($212|0);
       $or$cond$i = $218 & $221;
       if ($or$cond$i) {
        break L93;
       }
       $222 = ($220|0)==($210|0);
       $223 = ($217|0)==($212|0);
       $or$cond50$i = $222 & $223;
       if ($or$cond50$i) {
        break L93;
       }
       $251 = (($i$020$i) + 1)|0;
       $252 = ($251>>>0)<($215>>>0);
       if ($252) {
        $i$020$i = $251;
       } else {
        $j$023$i = $213;
        continue L93;
       }
      }
     }
     $224 = $i$020$i << 1;
     $225 = $224 | 1;
     $226 = (($227) + -1)|0;
     HEAP32[$24>>2] = $226;
     $228 = (($208) + ($226<<2)|0);
     $229 = HEAP32[$228>>2]|0;
     $230 = (($208) + ($225<<2)|0);
     HEAP32[$230>>2] = $229;
     $231 = HEAP32[$24>>2]|0;
     $232 = (($231) + -1)|0;
     HEAP32[$24>>2] = $232;
     $233 = (($208) + ($232<<2)|0);
     $234 = HEAP32[$233>>2]|0;
     $235 = (($208) + ($224<<2)|0);
     HEAP32[$235>>2] = $234;
     $236 = $j$023$i << 1;
     $237 = $236 | 1;
     $238 = HEAP32[$24>>2]|0;
     $239 = (($238) + -1)|0;
     HEAP32[$24>>2] = $239;
     $240 = (($208) + ($239<<2)|0);
     $241 = HEAP32[$240>>2]|0;
     $242 = (($208) + ($237<<2)|0);
     HEAP32[$242>>2] = $241;
     $243 = HEAP32[$24>>2]|0;
     $244 = (($243) + -1)|0;
     HEAP32[$24>>2] = $244;
     $245 = (($208) + ($244<<2)|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = (($208) + ($236<<2)|0);
     HEAP32[$247>>2] = $246;
     $248 = HEAP32[$24>>2]|0;
     $249 = $248 >>> 1;
     $250 = ($249|0)==(0);
     if ($250) {
      $254 = $248;
      break;
     } else {
      $215 = $249;$227 = $248;
     }
    }
   }
  } while(0);
  $253 = ($254>>>0)>(1);
  if ($253) {
   $255 = HEAP32[$23>>2]|0;
   $256 = ($255|0)==(0|0);
   if ($256) {
    $285 = $254;$Ref1$0$ph$i = -1;
   } else {
    $257 = HEAP32[$255>>2]|0;
    $258 = (($255) + 4|0);
    $259 = HEAP32[$258>>2]|0;
    $260 = HEAP32[$25>>2]|0;
    $261 = HEAP32[$LineStrip>>2]|0;
    $262 = ($260|0)==($261|0);
    if ($262) {
     (__ZN5physx2Gu9Container6ResizeEj($LineStrip,1)|0);
     $$pre$i5$i = HEAP32[$25>>2]|0;
     $264 = $$pre$i5$i;
    } else {
     $264 = $260;
    }
    $263 = (($264) + 1)|0;
    HEAP32[$25>>2] = $263;
    $265 = HEAP32[$26>>2]|0;
    $266 = (($265) + ($264<<2)|0);
    HEAP32[$266>>2] = $257;
    $267 = HEAP32[$25>>2]|0;
    $268 = HEAP32[$LineStrip>>2]|0;
    $269 = ($267|0)==($268|0);
    if ($269) {
     (__ZN5physx2Gu9Container6ResizeEj($LineStrip,1)|0);
     $$pre$i3$i = HEAP32[$25>>2]|0;
     $$pre$i31 = HEAP32[$26>>2]|0;
     $271 = $$pre$i3$i;$273 = $$pre$i31;
    } else {
     $271 = $267;$273 = $265;
    }
    $270 = (($271) + 1)|0;
    HEAP32[$25>>2] = $270;
    $272 = (($273) + ($271<<2)|0);
    HEAP32[$272>>2] = $259;
    $274 = HEAP32[$24>>2]|0;
    $275 = (($274) + -1)|0;
    HEAP32[$24>>2] = $275;
    $276 = HEAP32[$23>>2]|0;
    $277 = (($276) + ($275<<2)|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = (($276) + 4|0);
    HEAP32[$279>>2] = $278;
    $280 = HEAP32[$24>>2]|0;
    $281 = (($280) + -1)|0;
    HEAP32[$24>>2] = $281;
    $282 = (($276) + ($281<<2)|0);
    $283 = HEAP32[$282>>2]|0;
    HEAP32[$276>>2] = $283;
    $$pre44$i = HEAP32[$24>>2]|0;
    $285 = $$pre44$i;$Ref1$0$ph$i = $259;
   }
  } else {
   $285 = $254;$Ref1$0$ph$i = -1;
  }
  $284 = $285 >>> 1;
  $286 = ($284|0)==(0);
  if (!($286)) {
   $$pre45$i = HEAP32[$23>>2]|0;
   $288 = $284;$293 = $$pre45$i;$Ref1$016$i = $Ref1$0$ph$i;
   while(1) {
    $287 = ($288|0)==(0);
    if ($287) {
     label = 126;
     break L7;
    } else {
     $i2$014$i = 0;
    }
    while(1) {
     $291 = $i2$014$i << 1;
     $292 = (($293) + ($291<<2)|0);
     $294 = HEAP32[$292>>2]|0;
     $295 = $291 | 1;
     $296 = (($293) + ($295<<2)|0);
     $297 = HEAP32[$296>>2]|0;
     $298 = ($294|0)==($Ref1$016$i|0);
     if ($298) {
      label = 80;
      break;
     }
     $320 = ($297|0)==($Ref1$016$i|0);
     $290 = (($i2$014$i) + 1)|0;
     if ($320) {
      label = 85;
      break;
     }
     $289 = ($290>>>0)<($288>>>0);
     if ($289) {
      $i2$014$i = $290;
     } else {
      label = 126;
      break L7;
     }
    }
    if ((label|0) == 80) {
     label = 0;
     $299 = HEAP32[$25>>2]|0;
     $300 = HEAP32[$LineStrip>>2]|0;
     $301 = ($299|0)==($300|0);
     if ($301) {
      (__ZN5physx2Gu9Container6ResizeEj($LineStrip,1)|0);
      $$pre$i1$i = HEAP32[$25>>2]|0;
      $$pre46$i = HEAP32[$23>>2]|0;
      $303 = $$pre$i1$i;$309 = $$pre46$i;
     } else {
      $303 = $299;$309 = $293;
     }
     $302 = (($303) + 1)|0;
     HEAP32[$25>>2] = $302;
     $304 = HEAP32[$26>>2]|0;
     $305 = (($304) + ($303<<2)|0);
     HEAP32[$305>>2] = $297;
     $306 = HEAP32[$24>>2]|0;
     $307 = (($306) + -1)|0;
     HEAP32[$24>>2] = $307;
     $308 = (($309) + ($307<<2)|0);
     $310 = HEAP32[$308>>2]|0;
     $311 = (($309) + ($295<<2)|0);
     HEAP32[$311>>2] = $310;
     $312 = HEAP32[$24>>2]|0;
     $313 = (($312) + -1)|0;
     HEAP32[$24>>2] = $313;
     $314 = (($309) + ($313<<2)|0);
     $315 = HEAP32[$314>>2]|0;
     $316 = (($309) + ($291<<2)|0);
     HEAP32[$316>>2] = $315;
     $455 = $309;$Ref1$0$be$i = $297;
    }
    else if ((label|0) == 85) {
     label = 0;
     $321 = HEAP32[$25>>2]|0;
     $322 = HEAP32[$LineStrip>>2]|0;
     $323 = ($321|0)==($322|0);
     if ($323) {
      (__ZN5physx2Gu9Container6ResizeEj($LineStrip,1)|0);
      $$pre$i$i33 = HEAP32[$25>>2]|0;
      $$pre47$i = HEAP32[$23>>2]|0;
      $325 = $$pre$i$i33;$331 = $$pre47$i;
     } else {
      $325 = $321;$331 = $293;
     }
     $324 = (($325) + 1)|0;
     HEAP32[$25>>2] = $324;
     $326 = HEAP32[$26>>2]|0;
     $327 = (($326) + ($325<<2)|0);
     HEAP32[$327>>2] = $294;
     $328 = HEAP32[$24>>2]|0;
     $329 = (($328) + -1)|0;
     HEAP32[$24>>2] = $329;
     $330 = (($331) + ($329<<2)|0);
     $332 = HEAP32[$330>>2]|0;
     $333 = (($331) + ($295<<2)|0);
     HEAP32[$333>>2] = $332;
     $334 = HEAP32[$24>>2]|0;
     $335 = (($334) + -1)|0;
     HEAP32[$24>>2] = $335;
     $336 = (($331) + ($335<<2)|0);
     $337 = HEAP32[$336>>2]|0;
     $338 = (($331) + ($291<<2)|0);
     HEAP32[$338>>2] = $337;
     $455 = $331;$Ref1$0$be$i = $294;
    }
    $317 = HEAP32[$24>>2]|0;
    $318 = $317 >>> 1;
    $319 = ($318|0)==(0);
    if ($319) {
     break;
    } else {
     $288 = $318;$293 = $455;$Ref1$016$i = $Ref1$0$be$i;
    }
   }
  }
  __ZN5physx2Gu9ContainerD2Ev($vararg_buffer);
  $339 = HEAP32[$25>>2]|0;
  $340 = ($339|0)==(0);
  if (!($340)) {
   $341 = HEAP32[$26>>2]|0;
   $342 = (($339) + -1)|0;
   $343 = ($342|0)==(0);
   if (!($343)) {
    $i1$073 = 0;
    while(1) {
     $344 = (($341) + ($i1$073<<2)|0);
     $345 = HEAP32[$344>>2]|0;
     $346 = (($18) + ($345)|0);
     $347 = HEAP8[$346>>0]|0;
     $348 = (($347) + 1)<<24>>24;
     HEAP8[$346>>0] = $348;
     $349 = (($i1$073) + 1)|0;
     $exitcond114 = ($349|0)==($342|0);
     if ($exitcond114) {
      break;
     } else {
      $i1$073 = $349;
     }
    }
   }
   $350 = HEAP32[$27>>2]|0;
   $351 = HEAP32[$polygon_data>>2]|0;
   $352 = ($350|0)==($351|0);
   if ($352) {
    (__ZN5physx2Gu9Container6ResizeEj($polygon_data,1)|0);
    $$pre$i36 = HEAP32[$27>>2]|0;
    $354 = $$pre$i36;
   } else {
    $354 = $350;
   }
   $353 = (($354) + 1)|0;
   HEAP32[$27>>2] = $353;
   $355 = HEAP32[$28>>2]|0;
   $356 = (($355) + ($354<<2)|0);
   HEAP32[$356>>2] = $342;
   $357 = ($341|0)==(0|0);
   $or$cond$i38 = $357 | $343;
   if (!($or$cond$i38)) {
    $358 = HEAP32[$27>>2]|0;
    $359 = (($358) + ($342))|0;
    $360 = HEAP32[$polygon_data>>2]|0;
    $361 = ($359>>>0)>($360>>>0);
    if ($361) {
     (__ZN5physx2Gu9Container6ResizeEj($polygon_data,$342)|0);
     $$pre$i39 = HEAP32[$27>>2]|0;
     $$pre119 = HEAP32[$28>>2]|0;
     $363 = $$pre119;$364 = $$pre$i39;
    } else {
     $363 = $355;$364 = $358;
    }
    $362 = (($363) + ($364<<2)|0);
    $365 = $342 << 2;
    _memcpy(($362|0),($341|0),($365|0))|0;
    $366 = HEAP32[$27>>2]|0;
    $367 = (($366) + ($342))|0;
    HEAP32[$27>>2] = $367;
   }
   $368 = HEAP32[$nb_polygons>>2]|0;
   $369 = (($368) + 1)|0;
   HEAP32[$nb_polygons>>2] = $369;
   $370 = HEAP32[$20>>2]|0;
   $371 = ($370|0)==(0);
   if ($371) {
    $$lcssa88 = 0;
   } else {
    $i2$090 = 0;
    while(1) {
     $372 = HEAP32[$21>>2]|0;
     $373 = (($372) + ($i2$090<<2)|0);
     $374 = HEAP32[$373>>2]|0;
     $375 = ($374*3)|0;
     if ($22) {
      label = 100;
      break L7;
     }
     $376 = (($9) + ($375<<2)|0);
     $377 = HEAP32[$376>>2]|0;
     $378 = (($375) + 1)|0;
     $379 = (($9) + ($378<<2)|0);
     $380 = HEAP32[$379>>2]|0;
     $381 = (($375) + 2)|0;
     $382 = (($9) + ($381<<2)|0);
     $383 = HEAP32[$382>>2]|0;
     L149: do {
      if ($343) {
       $found1$2$off0130 = 0;$found2$2$off0131 = 0;
       label = 104;
      } else {
       $found0$0$off077 = 0;$found1$0$off078 = 0;$found2$0$off079 = 0;$j$080 = 0;
       while(1) {
        $386 = (($341) + ($j$080<<2)|0);
        $387 = HEAP32[$386>>2]|0;
        $388 = ($377|0)==($387|0);
        $$found0$0$off0 = $388 | $found0$0$off077;
        $389 = ($380|0)==($387|0);
        $found1$1$off0 = $389 | $found1$0$off078;
        $390 = ($383|0)==($387|0);
        $$found2$0$off0 = $390 | $found2$0$off079;
        $brmerge$demorgan = $$found0$0$off0 & $found1$1$off0;
        $brmerge12$demorgan = $brmerge$demorgan & $$found2$0$off0;
        $385 = (($j$080) + 1)|0;
        if ($brmerge12$demorgan) {
         break L149;
        }
        $384 = ($385>>>0)<($342>>>0);
        if ($384) {
         $found0$0$off077 = $$found0$0$off0;$found1$0$off078 = $found1$1$off0;$found2$0$off079 = $$found2$0$off0;$j$080 = $385;
        } else {
         break;
        }
       }
       if ($$found0$0$off0) {
        $found1$2$off0127 = $found1$1$off0;$found2$2$off0128 = $$found2$0$off0;
        label = 108;
       } else {
        $found1$2$off0130 = $found1$1$off0;$found2$2$off0131 = $$found2$0$off0;
        label = 104;
       }
      }
     } while(0);
     do {
      if ((label|0) == 104) {
       label = 0;
       $391 = (__ZNK5physx2Gu9Container8ContainsEjPj($rendundantVertices,$377,0)|0);
       if ($391) {
        $found1$2$off0127 = $found1$2$off0130;$found2$2$off0128 = $found2$2$off0131;
        label = 108;
        break;
       }
       $392 = HEAP32[$32>>2]|0;
       $393 = HEAP32[$rendundantVertices>>2]|0;
       $394 = ($392|0)==($393|0);
       if ($394) {
        (__ZN5physx2Gu9Container6ResizeEj($rendundantVertices,1)|0);
        $$pre$i$i40 = HEAP32[$32>>2]|0;
        $396 = $$pre$i$i40;
       } else {
        $396 = $392;
       }
       $395 = (($396) + 1)|0;
       HEAP32[$32>>2] = $395;
       $397 = HEAP32[$33>>2]|0;
       $398 = (($397) + ($396<<2)|0);
       HEAP32[$398>>2] = $377;
       if ($found1$2$off0130) {
        $found2$2$off0128132 = $found2$2$off0131;
        label = 113;
       } else {
        $found2$2$off0128133 = $found2$2$off0131;
        label = 109;
       }
      }
     } while(0);
     if ((label|0) == 108) {
      label = 0;
      if ($found1$2$off0127) {
       $found2$2$off0128132 = $found2$2$off0128;
       label = 113;
      } else {
       $found2$2$off0128133 = $found2$2$off0128;
       label = 109;
      }
     }
     do {
      if ((label|0) == 109) {
       label = 0;
       $399 = (__ZNK5physx2Gu9Container8ContainsEjPj($rendundantVertices,$380,0)|0);
       if ($399) {
        $found2$2$off0128132 = $found2$2$off0128133;
        label = 113;
        break;
       }
       $400 = HEAP32[$32>>2]|0;
       $401 = HEAP32[$rendundantVertices>>2]|0;
       $402 = ($400|0)==($401|0);
       if ($402) {
        (__ZN5physx2Gu9Container6ResizeEj($rendundantVertices,1)|0);
        $$pre$i$i43 = HEAP32[$32>>2]|0;
        $404 = $$pre$i$i43;
       } else {
        $404 = $400;
       }
       $403 = (($404) + 1)|0;
       HEAP32[$32>>2] = $403;
       $405 = HEAP32[$33>>2]|0;
       $406 = (($405) + ($404<<2)|0);
       HEAP32[$406>>2] = $380;
       if (!($found2$2$off0128133)) {
        label = 114;
       }
      }
     } while(0);
     if ((label|0) == 113) {
      label = 0;
      if (!($found2$2$off0128132)) {
       label = 114;
      }
     }
     do {
      if ((label|0) == 114) {
       label = 0;
       $407 = (__ZNK5physx2Gu9Container8ContainsEjPj($rendundantVertices,$383,0)|0);
       if ($407) {
        break;
       }
       $408 = HEAP32[$32>>2]|0;
       $409 = HEAP32[$rendundantVertices>>2]|0;
       $410 = ($408|0)==($409|0);
       if ($410) {
        (__ZN5physx2Gu9Container6ResizeEj($rendundantVertices,1)|0);
        $$pre$i$i24 = HEAP32[$32>>2]|0;
        $412 = $$pre$i$i24;
       } else {
        $412 = $408;
       }
       $411 = (($412) + 1)|0;
       HEAP32[$32>>2] = $411;
       $413 = HEAP32[$33>>2]|0;
       $414 = (($413) + ($412<<2)|0);
       HEAP32[$414>>2] = $383;
      }
     } while(0);
     $415 = (($i2$090) + 1)|0;
     $416 = HEAP32[$20>>2]|0;
     $417 = ($415>>>0)<($416>>>0);
     if ($417) {
      $i2$090 = $415;
     } else {
      $$lcssa88 = $416;
      break;
     }
    }
   }
   if (!($29)) {
    $418 = HEAP32[$30>>2]|0;
    $419 = HEAP32[$triangle_data>>2]|0;
    $420 = ($418|0)==($419|0);
    if ($420) {
     (__ZN5physx2Gu9Container6ResizeEj($triangle_data,1)|0);
     $$pre$i18 = HEAP32[$30>>2]|0;
     $422 = $$pre$i18;
    } else {
     $422 = $418;
    }
    $421 = (($422) + 1)|0;
    HEAP32[$30>>2] = $421;
    $423 = HEAP32[$31>>2]|0;
    $424 = (($423) + ($422<<2)|0);
    HEAP32[$424>>2] = $$lcssa88;
    $425 = HEAP32[$21>>2]|0;
    $426 = HEAP32[$20>>2]|0;
    $427 = ($425|0)==(0|0);
    $428 = ($426|0)==(0);
    $or$cond$i$i = $427 | $428;
    if (!($or$cond$i$i)) {
     $429 = HEAP32[$30>>2]|0;
     $430 = (($429) + ($426))|0;
     $431 = HEAP32[$triangle_data>>2]|0;
     $432 = ($430>>>0)>($431>>>0);
     if ($432) {
      (__ZN5physx2Gu9Container6ResizeEj($triangle_data,$426)|0);
      $$pre$i$i15 = HEAP32[$30>>2]|0;
      $$pre = HEAP32[$31>>2]|0;
      $434 = $$pre;$435 = $$pre$i$i15;
     } else {
      $434 = $423;$435 = $429;
     }
     $433 = (($434) + ($435<<2)|0);
     $436 = $426 << 2;
     _memcpy(($433|0),($425|0),($436|0))|0;
     $437 = HEAP32[$30>>2]|0;
     $438 = (($437) + ($426))|0;
     HEAP32[$30>>2] = $438;
    }
   }
  }
  __ZN5physx2Gu9ContainerD2Ev($LineStrip);
  __ZN5physx2Gu9ContainerD2Ev($ActiveSegments);
  __ZN5physx2Gu9ContainerD2Ev($Indices);
  $CurrentFace$0 = 0;
 }
 if ((label|0) == 41) {
  _llvm_trap();
  // unreachable;
 }
 else if ((label|0) == 100) {
  _llvm_trap();
  // unreachable;
 }
 else if ((label|0) == 126) {
  __ZN5physx2Gu9ContainerD2Ev($vararg_buffer);
  $439 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($439,8,532056,752,533392,$vararg_buffer);
  __ZN5physx2Gu9ContainerD2Ev($LineStrip);
  __ZN5physx2Gu9ContainerD2Ev($ActiveSegments);
  __ZN5physx2Gu9ContainerD2Ev($Indices);
  $$3 = 0;
  __ZN5physx11AdjacenciesD2Ev($Adj);
  STACKTOP = sp;return ($$3|0);
 }
 else if ((label|0) == 128) {
  $440 = ($6<<24>>24)==(0);
  if (!($440)) {
   $i7$046 = 0;
   while(1) {
    $441 = (($18) + ($i7$046)|0);
    $442 = HEAP8[$441>>0]|0;
    $443 = ($442&255)<(3);
    if ($443) {
     $444 = (__ZNK5physx2Gu9Container8ContainsEjPj($rendundantVertices,$i7$046,0)|0);
     if (!($444)) {
      $445 = HEAP32[$32>>2]|0;
      $446 = HEAP32[$rendundantVertices>>2]|0;
      $447 = ($445|0)==($446|0);
      if ($447) {
       (__ZN5physx2Gu9Container6ResizeEj($rendundantVertices,1)|0);
       $$pre$i$i = HEAP32[$32>>2]|0;
       $449 = $$pre$i$i;
      } else {
       $449 = $445;
      }
      $448 = (($449) + 1)|0;
      HEAP32[$32>>2] = $448;
      $450 = HEAP32[$33>>2]|0;
      $451 = (($450) + ($449<<2)|0);
      HEAP32[$451>>2] = $i7$046;
     }
    }
    $452 = (($i7$046) + 1)|0;
    $exitcond = ($452|0)==($7|0);
    if ($exitcond) {
     break;
    } else {
     $i7$046 = $452;
    }
   }
  }
  $453 = HEAP32[$32>>2]|0;
  $454 = ($453|0)==(0);
  $or$cond = $454 | $29;
  if ($or$cond) {
   $$3 = 1;
   __ZN5physx11AdjacenciesD2Ev($Adj);
   STACKTOP = sp;return ($$3|0);
  }
  $hull$idx$val = HEAP32[$8>>2]|0;
  __ZL22CheckRedundantVerticesRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderES3_S3_($nb_polygons,$polygon_data,$hull$idx$val,$triangle_data,$rendundantVertices);
  $$3 = 1;
  __ZN5physx11AdjacenciesD2Ev($Adj);
  STACKTOP = sp;return ($$3|0);
 }
 return 0|0;
}
function __ZN5physx17ConvexHullBuilder19ComputeHullPolygonsERKjPKNS_6PxVec3ES2_PS1_($this,$nbVerts,$verts,$nbTriangles,$triangles) {
 $this = $this|0;
 $nbVerts = $nbVerts|0;
 $verts = $verts|0;
 $nbTriangles = $nbTriangles|0;
 $triangles = $triangles|0;
 var $$$i$i$i = 0, $$0 = 0, $$arith = 0, $$overflow = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $i$01 = 0, $nbHullVerts = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $nbHullVerts = sp;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 $2 = HEAP32[$nbTriangles>>2]|0;
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$nbVerts>>2]|0;
 $5 = $4&255;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 38|0);
 HEAP8[$8>>0] = $5;
 $9 = HEAP32[$6>>2]|0;
 $10 = (($9) + 38|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = ($12*12)|0;
 $14 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$13,532056,1664)|0);
 HEAP32[$this>>2] = $14;
 $15 = HEAP32[$6>>2]|0;
 $16 = (($15) + 38|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = ($18*12)|0;
 _memcpy(($14|0),($verts|0),($19|0))|0;
 $20 = HEAP32[$3>>2]|0;
 $$arith = ($20*12)|0;
 $$overflow = ($20>>>0)>(357913941);
 $21 = $$overflow ? -1 : $$arith;
 $22 = ($21|0)==(0);
 if ($22) {
  $34 = 0;$36 = $20;
 } else {
  $23 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__Z15PxGetFoundationv()|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 24|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 4095]($27)|0);
  $$$i$i$i = $31 ? 533272 : 532808;
  $32 = (FUNCTION_TABLE_iiiiii[$26 & 255]($23,$21,$$$i$i$i,532056,1667)|0);
  $$pre = HEAP32[$3>>2]|0;
  $34 = $32;$36 = $$pre;
 }
 $33 = (($this) + 36|0);
 HEAP32[$33>>2] = $34;
 $35 = ($36|0)==(0);
 if (!($35)) {
  $i$01 = 0;
  while(1) {
   $37 = ($i$01*3)|0;
   $38 = (($triangles) + ($37<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($34) + (($i$01*12)|0)|0);
   HEAP32[$40>>2] = $39;
   $41 = (($37) + 1)|0;
   $42 = (($triangles) + ($41<<2)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ((($34) + (($i$01*12)|0)|0) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (($37) + 2)|0;
   $46 = (($triangles) + ($45<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ((($34) + (($i$01*12)|0)|0) + 8|0);
   HEAP32[$48>>2] = $47;
   $49 = (($i$01) + 1)|0;
   $50 = HEAP32[$3>>2]|0;
   $51 = ($49>>>0)<($50>>>0);
   if ($51) {
    $i$01 = $49;
   } else {
    break;
   }
  }
 }
 $52 = HEAP32[$6>>2]|0;
 $53 = (($52) + 38|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = $54&255;
 HEAP32[$nbHullVerts>>2] = $55;
 $56 = HEAP32[$this>>2]|0;
 __ZL9CleanHullRjPN5physx2Gu9TriangleTIjEES_PNS0_6PxVec3E($3,$34,$nbHullVerts,$56);
 $57 = HEAP32[$nbHullVerts>>2]|0;
 $58 = $57&255;
 $59 = HEAP32[$6>>2]|0;
 $60 = (($59) + 38|0);
 HEAP8[$60>>0] = $58;
 $61 = HEAP32[$3>>2]|0;
 $62 = HEAP32[$6>>2]|0;
 $63 = (($62) + 38|0);
 $64 = HEAP8[$63>>0]|0;
 $65 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = $61;
 $66 = (__ZL22TestDuplicateTrianglesRjPN5physx2Gu9TriangleTIjEEb($0,$34,0)|0);
 if (!($66)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = $64&255;
 $68 = HEAP32[$0>>2]|0;
 $69 = (__ZL18TestUnifiedNormalsjPKN5physx6PxVec3EjPNS_2Gu9TriangleTIjEEb($67,$65,$68,$34,0)|0);
 if (!($69)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $70 = (__ZN5physx17ConvexHullBuilder17CreatePolygonDataEv($this)|0);
 if (!($70)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = (__ZNK5physx17ConvexHullBuilder17CheckHullPolygonsEv($this)|0);
 $$0 = $71;
 STACKTOP = sp;return ($$0|0);
}
function __ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local9FloodFillES3_PKNS0_11AdjTriangleEjPb($indices,$faces,$current,$markers) {
 $indices = $indices|0;
 $faces = $faces|0;
 $current = $current|0;
 $markers = $markers|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $current$tr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($markers) + ($current)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($indices) + 4|0);
 $4 = (($indices) + 8|0);
 $9 = $0;$current$tr1 = $current;
 while(1) {
  HEAP8[$9>>0] = 1;
  $10 = HEAP32[$3>>2]|0;
  $11 = HEAP32[$indices>>2]|0;
  $12 = ($10|0)==($11|0);
  if ($12) {
   (__ZN5physx2Gu9Container6ResizeEj($indices,1)|0);
   $$pre$i = HEAP32[$3>>2]|0;
   $14 = $$pre$i;
  } else {
   $14 = $10;
  }
  $13 = (($14) + 1)|0;
  HEAP32[$3>>2] = $13;
  $15 = HEAP32[$4>>2]|0;
  $16 = (($15) + ($14<<2)|0);
  HEAP32[$16>>2] = $current$tr1;
  $17 = (($faces) + (($current$tr1*12)|0)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 536870912;
  $20 = ($19|0)==(0);
  if ($20) {
   $21 = $18 & 536870911;
   __ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local9FloodFillES3_PKNS0_11AdjTriangleEjPb($indices,$faces,$21,$markers);
  }
  $22 = ((($faces) + (($current$tr1*12)|0)|0) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 & 536870912;
  $25 = ($24|0)==(0);
  if ($25) {
   $26 = $23 & 536870911;
   __ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local9FloodFillES3_PKNS0_11AdjTriangleEjPb($indices,$faces,$26,$markers);
  }
  $27 = ((($faces) + (($current$tr1*12)|0)|0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $28 & 536870912;
  $30 = ($29|0)==(0);
  $6 = $28 & 536870911;
  if (!($30)) {
   label = 11;
   break;
  }
  $5 = (($markers) + ($6)|0);
  $7 = HEAP8[$5>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $9 = $5;$current$tr1 = $6;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return;
 }
}
function __ZL22CheckRedundantVerticesRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderES3_S3_($nb_polygons,$polygon_data,$hull$0$9$val,$triangle_data,$redundantVertices) {
 $nb_polygons = $nb_polygons|0;
 $polygon_data = $polygon_data|0;
 $hull$0$9$val = $hull$0$9$val|0;
 $triangle_data = $triangle_data|0;
 $redundantVertices = $redundantVertices|0;
 var $$in = 0, $$needToSplitPolygons$1$off0 = 0, $$pre = 0, $$pre$i = 0, $$pre$i10 = 0, $$pre$i12 = 0, $$pre$i14 = 0, $$pre$i16 = 0, $$pre$i18 = 0, $$pre$i20 = 0, $$pre$i22 = 0, $$pre$i24 = 0, $$pre$i26 = 0, $$pre$i28 = 0, $$pre$i30 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0;
 var $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $$sum = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Data$027 = 0, $Data3$09 = 0, $TriData$012 = 0, $exitcond = 0, $exitcond45 = 0, $exitcond46 = 0, $exitcond47 = 0, $exitcond48 = 0, $i4$016 = 0, $j$0 = 0, $j1$033 = 0, $j2$021 = 0, $j6$03 = 0, $k$02 = 0;
 var $k7$06 = 0, $needToSplitPolygons$0$off039 = 0, $needToSplitPolygons$1$off0$lcssa = 0, $needToSplitPolygons$1$off034 = 0, $newNb_polygons$0$lcssa = 0, $newNb_polygons$08 = 0, $newNb_polygons$2 = 0, $newPolygon_data = 0, $newTriangle_data = 0, $numEntries$0$lcssa = 0, $numEntries$028 = 0, $numEntries$1 = 0, $numEntriesTotal$038 = 0, $polygonsContainer = 0, $t$025 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $polygonsContainer = sp + 32|0;
 $newPolygon_data = sp;
 $newTriangle_data = sp + 16|0;
 $0 = HEAP32[$nb_polygons>>2]|0;
 $1 = STACKTOP; STACKTOP = STACKTOP + ((((1*$0)|0)+15)&-16)|0;;
 _memset(($1|0),0,($0|0))|0;
 $2 = (($redundantVertices) + 4|0);
 __ZN5physx2Gu9ContainerC2Ev($polygonsContainer);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN5physx2Gu9ContainerD2Ev($polygonsContainer);
  STACKTOP = sp;return;
 }
 $5 = (($polygon_data) + 8|0);
 $6 = (($polygonsContainer) + 8|0);
 $7 = (($redundantVertices) + 8|0);
 $8 = (($polygonsContainer) + 4|0);
 $$pre54 = HEAP32[$nb_polygons>>2]|0;
 $$in = $3;$12 = $$pre54;$170 = $$pre54;$needToSplitPolygons$0$off039 = 0;$numEntriesTotal$038 = 0;
 while(1) {
  $10 = (($$in) + -1)|0;
  $11 = ($12|0)==(0);
  if ($11) {
   $171 = $170;$172 = 0;$numEntries$0$lcssa = 0;
  } else {
   $13 = HEAP32[$5>>2]|0;
   $173 = $170;$Data$027 = $13;$numEntries$028 = 0;$t$025 = 0;
   while(1) {
    $14 = HEAP32[$Data$027>>2]|0;
    $j$0 = 0;
    while(1) {
     $15 = ($j$0>>>0)<($14>>>0);
     if (!($15)) {
      $40 = $173;$numEntries$1 = $numEntries$028;
      break;
     }
     $16 = HEAP32[$7>>2]|0;
     $17 = (($16) + ($10<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $$sum9 = (($j$0) + 1)|0;
     $19 = (($Data$027) + ($$sum9<<2)|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($18|0)==($20|0);
     if ($21) {
      label = 9;
      break;
     } else {
      $j$0 = $$sum9;
     }
    }
    if ((label|0) == 9) {
     label = 0;
     $22 = HEAP32[$8>>2]|0;
     $23 = HEAP32[$polygonsContainer>>2]|0;
     $24 = ($22|0)==($23|0);
     if ($24) {
      (__ZN5physx2Gu9Container6ResizeEj($polygonsContainer,1)|0);
      $$pre$i24 = HEAP32[$8>>2]|0;
      $26 = $$pre$i24;
     } else {
      $26 = $22;
     }
     $25 = (($26) + 1)|0;
     HEAP32[$8>>2] = $25;
     $27 = HEAP32[$6>>2]|0;
     $28 = (($27) + ($26<<2)|0);
     HEAP32[$28>>2] = $t$025;
     $29 = HEAP32[$8>>2]|0;
     $30 = HEAP32[$polygonsContainer>>2]|0;
     $31 = ($29|0)==($30|0);
     if ($31) {
      (__ZN5physx2Gu9Container6ResizeEj($polygonsContainer,1)|0);
      $$pre$i26 = HEAP32[$8>>2]|0;
      $$pre55 = HEAP32[$6>>2]|0;
      $33 = $$pre$i26;$35 = $$pre55;
     } else {
      $33 = $29;$35 = $27;
     }
     $32 = (($33) + 1)|0;
     HEAP32[$8>>2] = $32;
     $34 = (($35) + ($33<<2)|0);
     HEAP32[$34>>2] = $14;
     $36 = (($numEntries$028) + 1)|0;
     $$pre56 = HEAP32[$nb_polygons>>2]|0;
     $40 = $$pre56;$numEntries$1 = $36;
    }
    $$sum8 = (($14) + 1)|0;
    $37 = (($Data$027) + ($$sum8<<2)|0);
    $38 = (($t$025) + 1)|0;
    $39 = ($38>>>0)<($40>>>0);
    if ($39) {
     $173 = $40;$Data$027 = $37;$numEntries$028 = $numEntries$1;$t$025 = $38;
    } else {
     $171 = $40;$172 = $40;$numEntries$0$lcssa = $numEntries$1;
     break;
    }
   }
  }
  $41 = (($numEntries$0$lcssa) + ($numEntriesTotal$038))|0;
  $42 = ($numEntriesTotal$038>>>0)<($41>>>0);
  if ($42) {
   $43 = HEAP32[$6>>2]|0;
   $j1$033 = $numEntriesTotal$038;$needToSplitPolygons$1$off034 = $needToSplitPolygons$0$off039;
   while(1) {
    $44 = $j1$033 << 1;
    $45 = $44 | 1;
    $46 = (($43) + ($45<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(3);
    $$needToSplitPolygons$1$off0 = $48 | $needToSplitPolygons$1$off034;
    $49 = (($j1$033) + 1)|0;
    $exitcond48 = ($49|0)==($41|0);
    if ($exitcond48) {
     $needToSplitPolygons$1$off0$lcssa = $$needToSplitPolygons$1$off0;
     break;
    } else {
     $j1$033 = $49;$needToSplitPolygons$1$off034 = $$needToSplitPolygons$1$off0;
    }
   }
  } else {
   $needToSplitPolygons$1$off0$lcssa = $needToSplitPolygons$0$off039;
  }
  $9 = ($10|0)==(0);
  if ($9) {
   break;
  } else {
   $$in = $10;$12 = $172;$170 = $171;$needToSplitPolygons$0$off039 = $needToSplitPolygons$1$off0$lcssa;$numEntriesTotal$038 = $41;
  }
 }
 if (!($needToSplitPolygons$1$off0$lcssa)) {
  __ZN5physx2Gu9ContainerD2Ev($polygonsContainer);
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$2>>2]|0;
 $51 = ($50|0)==(0);
 if (!($51)) {
  HEAP32[$2>>2] = 0;
 }
 $52 = ($41|0)==(0);
 if (!($52)) {
  $53 = (($polygonsContainer) + 8|0);
  $54 = HEAP32[$53>>2]|0;
  $j2$021 = 0;
  while(1) {
   $55 = $j2$021 << 1;
   $56 = (($54) + ($55<<2)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($1) + ($57)|0);
   HEAP8[$58>>0] = 1;
   $59 = (($j2$021) + 1)|0;
   $exitcond47 = ($59|0)==($41|0);
   if ($exitcond47) {
    break;
   } else {
    $j2$021 = $59;
   }
  }
 }
 __ZN5physx2Gu9ContainerC2Ev($newPolygon_data);
 __ZN5physx2Gu9ContainerC2Ev($newTriangle_data);
 $60 = HEAP32[$nb_polygons>>2]|0;
 $61 = ($60|0)==(0);
 if ($61) {
  $newNb_polygons$0$lcssa = 0;
 } else {
  $62 = (($triangle_data) + 8|0);
  $63 = (($polygon_data) + 8|0);
  $64 = HEAP32[$62>>2]|0;
  $65 = HEAP32[$63>>2]|0;
  $66 = (($newPolygon_data) + 4|0);
  $67 = (($newPolygon_data) + 8|0);
  $68 = (($newTriangle_data) + 4|0);
  $69 = (($newTriangle_data) + 8|0);
  $Data3$09 = $65;$TriData$012 = $64;$i4$016 = 0;$newNb_polygons$08 = 0;
  while(1) {
   $70 = HEAP32[$Data3$09>>2]|0;
   $71 = HEAP32[$TriData$012>>2]|0;
   $72 = (($1) + ($i4$016)|0);
   $73 = HEAP8[$72>>0]|0;
   $74 = ($73<<24>>24)==(0);
   if ($74) {
    $129 = (($newNb_polygons$08) + 1)|0;
    $130 = HEAP32[$66>>2]|0;
    $131 = HEAP32[$newPolygon_data>>2]|0;
    $132 = ($130|0)==($131|0);
    if ($132) {
     (__ZN5physx2Gu9Container6ResizeEj($newPolygon_data,1)|0);
     $$pre$i14 = HEAP32[$66>>2]|0;
     $134 = $$pre$i14;
    } else {
     $134 = $130;
    }
    $133 = (($134) + 1)|0;
    HEAP32[$66>>2] = $133;
    $135 = HEAP32[$67>>2]|0;
    $136 = (($135) + ($134<<2)|0);
    HEAP32[$136>>2] = $70;
    $137 = ($70|0)==(0);
    if (!($137)) {
     $174 = $135;$j6$03 = 0;
     while(1) {
      $$sum6 = (($j6$03) + 1)|0;
      $138 = (($Data3$09) + ($$sum6<<2)|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = HEAP32[$66>>2]|0;
      $141 = HEAP32[$newPolygon_data>>2]|0;
      $142 = ($140|0)==($141|0);
      if ($142) {
       (__ZN5physx2Gu9Container6ResizeEj($newPolygon_data,1)|0);
       $$pre$i12 = HEAP32[$66>>2]|0;
       $$pre49 = HEAP32[$67>>2]|0;
       $144 = $$pre$i12;$146 = $$pre49;
      } else {
       $144 = $140;$146 = $174;
      }
      $143 = (($144) + 1)|0;
      HEAP32[$66>>2] = $143;
      $145 = (($146) + ($144<<2)|0);
      HEAP32[$145>>2] = $139;
      $exitcond45 = ($$sum6|0)==($70|0);
      if ($exitcond45) {
       break;
      } else {
       $174 = $146;$j6$03 = $$sum6;
      }
     }
    }
    $147 = HEAP32[$68>>2]|0;
    $148 = HEAP32[$newTriangle_data>>2]|0;
    $149 = ($147|0)==($148|0);
    if ($149) {
     (__ZN5physx2Gu9Container6ResizeEj($newTriangle_data,1)|0);
     $$pre$i10 = HEAP32[$68>>2]|0;
     $151 = $$pre$i10;
    } else {
     $151 = $147;
    }
    $150 = (($151) + 1)|0;
    HEAP32[$68>>2] = $150;
    $152 = HEAP32[$69>>2]|0;
    $153 = (($152) + ($151<<2)|0);
    HEAP32[$153>>2] = $71;
    $154 = ($71|0)==(0);
    if ($154) {
     $newNb_polygons$2 = $129;
    } else {
     $175 = $152;$k7$06 = 0;
     while(1) {
      $$sum5 = (($k7$06) + 1)|0;
      $155 = (($TriData$012) + ($$sum5<<2)|0);
      $156 = HEAP32[$155>>2]|0;
      $157 = HEAP32[$68>>2]|0;
      $158 = HEAP32[$newTriangle_data>>2]|0;
      $159 = ($157|0)==($158|0);
      if ($159) {
       (__ZN5physx2Gu9Container6ResizeEj($newTriangle_data,1)|0);
       $$pre$i = HEAP32[$68>>2]|0;
       $$pre = HEAP32[$69>>2]|0;
       $161 = $$pre$i;$163 = $$pre;
      } else {
       $161 = $157;$163 = $175;
      }
      $160 = (($161) + 1)|0;
      HEAP32[$68>>2] = $160;
      $162 = (($163) + ($161<<2)|0);
      HEAP32[$162>>2] = $156;
      $exitcond46 = ($$sum5|0)==($71|0);
      if ($exitcond46) {
       $newNb_polygons$2 = $129;
       break;
      } else {
       $175 = $163;$k7$06 = $$sum5;
      }
     }
    }
   } else {
    $75 = ($71|0)==(0);
    if ($75) {
     $newNb_polygons$2 = $newNb_polygons$08;
    } else {
     $k$02 = 0;
     while(1) {
      $$sum7 = (($k$02) + 1)|0;
      $76 = (($TriData$012) + ($$sum7<<2)|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = HEAP32[$66>>2]|0;
      $79 = HEAP32[$newPolygon_data>>2]|0;
      $80 = ($78|0)==($79|0);
      if ($80) {
       (__ZN5physx2Gu9Container6ResizeEj($newPolygon_data,1)|0);
       $$pre$i30 = HEAP32[$66>>2]|0;
       $82 = $$pre$i30;
      } else {
       $82 = $78;
      }
      $81 = (($82) + 1)|0;
      HEAP32[$66>>2] = $81;
      $83 = HEAP32[$67>>2]|0;
      $84 = (($83) + ($82<<2)|0);
      HEAP32[$84>>2] = 3;
      $85 = ($77*3)|0;
      $86 = (($hull$0$9$val) + ($85<<2)|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = HEAP32[$66>>2]|0;
      $89 = HEAP32[$newPolygon_data>>2]|0;
      $90 = ($88|0)==($89|0);
      if ($90) {
       (__ZN5physx2Gu9Container6ResizeEj($newPolygon_data,1)|0);
       $$pre$i28 = HEAP32[$66>>2]|0;
       $$pre50 = HEAP32[$67>>2]|0;
       $92 = $$pre$i28;$94 = $$pre50;
      } else {
       $92 = $88;$94 = $83;
      }
      $91 = (($92) + 1)|0;
      HEAP32[$66>>2] = $91;
      $93 = (($94) + ($92<<2)|0);
      HEAP32[$93>>2] = $87;
      $95 = (($85) + 1)|0;
      $96 = (($hull$0$9$val) + ($95<<2)|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = HEAP32[$66>>2]|0;
      $99 = HEAP32[$newPolygon_data>>2]|0;
      $100 = ($98|0)==($99|0);
      if ($100) {
       (__ZN5physx2Gu9Container6ResizeEj($newPolygon_data,1)|0);
       $$pre$i22 = HEAP32[$66>>2]|0;
       $$pre51 = HEAP32[$67>>2]|0;
       $102 = $$pre$i22;$104 = $$pre51;
      } else {
       $102 = $98;$104 = $94;
      }
      $101 = (($102) + 1)|0;
      HEAP32[$66>>2] = $101;
      $103 = (($104) + ($102<<2)|0);
      HEAP32[$103>>2] = $97;
      $105 = (($85) + 2)|0;
      $106 = (($hull$0$9$val) + ($105<<2)|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = HEAP32[$66>>2]|0;
      $109 = HEAP32[$newPolygon_data>>2]|0;
      $110 = ($108|0)==($109|0);
      if ($110) {
       (__ZN5physx2Gu9Container6ResizeEj($newPolygon_data,1)|0);
       $$pre$i20 = HEAP32[$66>>2]|0;
       $$pre52 = HEAP32[$67>>2]|0;
       $112 = $$pre$i20;$114 = $$pre52;
      } else {
       $112 = $108;$114 = $104;
      }
      $111 = (($112) + 1)|0;
      HEAP32[$66>>2] = $111;
      $113 = (($114) + ($112<<2)|0);
      HEAP32[$113>>2] = $107;
      $115 = HEAP32[$68>>2]|0;
      $116 = HEAP32[$newTriangle_data>>2]|0;
      $117 = ($115|0)==($116|0);
      if ($117) {
       (__ZN5physx2Gu9Container6ResizeEj($newTriangle_data,1)|0);
       $$pre$i18 = HEAP32[$68>>2]|0;
       $119 = $$pre$i18;
      } else {
       $119 = $115;
      }
      $118 = (($119) + 1)|0;
      HEAP32[$68>>2] = $118;
      $120 = HEAP32[$69>>2]|0;
      $121 = (($120) + ($119<<2)|0);
      HEAP32[$121>>2] = 1;
      $122 = HEAP32[$68>>2]|0;
      $123 = HEAP32[$newTriangle_data>>2]|0;
      $124 = ($122|0)==($123|0);
      if ($124) {
       (__ZN5physx2Gu9Container6ResizeEj($newTriangle_data,1)|0);
       $$pre$i16 = HEAP32[$68>>2]|0;
       $$pre53 = HEAP32[$69>>2]|0;
       $126 = $$pre$i16;$128 = $$pre53;
      } else {
       $126 = $122;$128 = $120;
      }
      $125 = (($126) + 1)|0;
      HEAP32[$68>>2] = $125;
      $127 = (($128) + ($126<<2)|0);
      HEAP32[$127>>2] = $77;
      $exitcond = ($$sum7|0)==($71|0);
      if ($exitcond) {
       break;
      } else {
       $k$02 = $$sum7;
      }
     }
     $164 = (($newNb_polygons$08) + ($71))|0;
     $newNb_polygons$2 = $164;
    }
   }
   $$sum = (($70) + 1)|0;
   $165 = (($Data3$09) + ($$sum<<2)|0);
   $$sum4 = (($71) + 1)|0;
   $166 = (($TriData$012) + ($$sum4<<2)|0);
   $167 = (($i4$016) + 1)|0;
   $168 = HEAP32[$nb_polygons>>2]|0;
   $169 = ($167>>>0)<($168>>>0);
   if ($169) {
    $Data3$09 = $165;$TriData$012 = $166;$i4$016 = $167;$newNb_polygons$08 = $newNb_polygons$2;
   } else {
    $newNb_polygons$0$lcssa = $newNb_polygons$2;
    break;
   }
  }
 }
 (__ZN5physx2Gu9Container5EmptyEv($polygon_data)|0);
 (__ZN5physx2Gu9Container5EmptyEv($triangle_data)|0);
 __ZN5physx2Gu9ContaineraSERKS1_($polygon_data,$newPolygon_data);
 __ZN5physx2Gu9ContaineraSERKS1_($triangle_data,$newTriangle_data);
 HEAP32[$nb_polygons>>2] = $newNb_polygons$0$lcssa;
 __ZN5physx2Gu9ContainerD2Ev($newTriangle_data);
 __ZN5physx2Gu9ContainerD2Ev($newPolygon_data);
 __ZN5physx2Gu9ContainerD2Ev($polygonsContainer);
 STACKTOP = sp;return;
}
function __ZZL19ExtractHullPolygonsRjRN5physx2Gu9ContainerERKNS0_17ConvexHullBuilderEPS2_S3_EN5Local15GetNeighborFaceEjjPKNS0_11AdjTriangleEPKjS_S_($index,$triangleIndex,$faces,$dfaces,$neighbor,$current) {
 $index = $index|0;
 $triangleIndex = $triangleIndex|0;
 $faces = $faces|0;
 $dfaces = $dfaces|0;
 $neighbor = $neighbor|0;
 $current = $current|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert23 = 0, $$pre = 0, $$pre22 = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $currentIndex$0 = 0, $currentIndex$0$ = 0, $currentIndex$0$ph8 = 0, $currentIndex$0$phi = 0, $edge = 0, $firstFace$0$off0$mux = 0, $firstFace$0$off0$ph = 0, $i$05 = 0, $or$cond = 0, $phitmp = 0, $previousIndex$0 = 0, $previousIndex$0$currentIndex$0 = 0, $previousIndex$0$ph7 = 0, $previousIndex$0$phi = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $edge = sp;
 $0 = (($edge) + 4|0);
 $currentIndex$0$ph8 = $index;$firstFace$0$off0$ph = 1;$previousIndex$0$ph7 = $index;
 L1: while(1) {
  $currentIndex$0 = $currentIndex$0$ph8;$previousIndex$0 = $previousIndex$0$ph7;
  L3: while(1) {
   $1 = ($currentIndex$0*3)|0;
   $2 = (($dfaces) + ($1<<2)|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($1) + 1)|0;
   $5 = (($dfaces) + ($4<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   HEAP32[$edge>>2] = 1;
   HEAP32[$0>>2] = 2;
   $7 = ($3|0)==($triangleIndex|0);
   if ($7) {
    HEAP32[$edge>>2] = 0;
    HEAP32[$0>>2] = 1;
    $10 = 0;$15 = 1;
   } else {
    $8 = ($6|0)==($triangleIndex|0);
    if ($8) {
     HEAP32[$edge>>2] = 0;
     HEAP32[$0>>2] = 2;
     $10 = 0;$15 = 2;
    } else {
     $10 = 1;$15 = 2;
    }
   }
   $9 = ((($faces) + (($currentIndex$0*12)|0)|0) + ($10<<2)|0);
   $11 = HEAP32[$9>>2]|0;
   $12 = $11 & 536870912;
   $13 = ($12|0)==(0);
   $14 = ((($faces) + (($currentIndex$0*12)|0)|0) + ($15<<2)|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = $16 & 536870912;
   $18 = ($17|0)==(0);
   if (!($13)) {
    label = 8;
    break;
   }
   if (!($18)) {
    label = 16;
    break;
   }
   $19 = ($currentIndex$0|0)==($index|0);
   if ($19) {
    $$0 = 0;
    label = 21;
    break L1;
   }
   $20 = ($previousIndex$0|0)==($index|0);
   $23 = $11;$i$05 = 1;
   while(1) {
    $22 = $23 & 536870911;
    $24 = ($22|0)!=($index|0);
    $or$cond = $24 | $20;
    if (!($or$cond)) {
     $$0 = 0;
     label = 21;
     break L1;
    }
    $25 = ($22|0)==($previousIndex$0|0);
    if (!($25)) {
     $previousIndex$0$phi = $currentIndex$0;$currentIndex$0 = $22;$previousIndex$0 = $previousIndex$0$phi;
     continue L3;
    }
    $21 = ($i$05>>>0)<(2);
    if (!($21)) {
     $previousIndex$0$phi = $previousIndex$0;$currentIndex$0$phi = $currentIndex$0;$previousIndex$0 = $previousIndex$0$phi;$currentIndex$0 = $currentIndex$0$phi;
     continue L3;
    }
    $$phi$trans$insert21 = (($edge) + ($i$05<<2)|0);
    $$pre22 = HEAP32[$$phi$trans$insert21>>2]|0;
    $$phi$trans$insert23 = ((($faces) + (($currentIndex$0*12)|0)|0) + ($$pre22<<2)|0);
    $$pre24 = HEAP32[$$phi$trans$insert23>>2]|0;
    $phitmp = (($i$05) + 1)|0;
    $23 = $$pre24;$i$05 = $phitmp;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   if ($18) {
    $27 = $11;$31 = $15;
   } else {
    $$0 = 0;
    label = 21;
    break;
   }
  }
  else if ((label|0) == 16) {
   label = 0;
   HEAP32[$edge>>2] = $15;
   HEAP32[$0>>2] = $10;
   $$phi$trans$insert = ((($faces) + (($currentIndex$0*12)|0)|0) + ($15<<2)|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $27 = $$pre;$31 = $10;
  }
  $26 = $27 & 536870912;
  $28 = ($26|0)==(0);
  $brmerge = $28 | $firstFace$0$off0$ph;
  $firstFace$0$off0$mux = $28 & $firstFace$0$off0$ph;
  if (!($brmerge)) {
   label = 18;
   break;
  }
  $30 = ((($faces) + (($currentIndex$0*12)|0)|0) + ($31<<2)|0);
  $32 = HEAP32[$30>>2]|0;
  $33 = $32 & 536870912;
  $34 = ($33|0)==(0);
  if (!($34)) {
   $currentIndex$0$ph8 = $currentIndex$0;$firstFace$0$off0$ph = $firstFace$0$off0$mux;$previousIndex$0$ph7 = $previousIndex$0;
   continue;
  }
  $35 = $32 & 536870911;
  $36 = ($35|0)==($index|0);
  $previousIndex$0$currentIndex$0 = $36 ? $previousIndex$0 : $currentIndex$0;
  $currentIndex$0$ = $36 ? $currentIndex$0 : $35;
  $currentIndex$0$ph8 = $currentIndex$0$;$firstFace$0$off0$ph = $firstFace$0$off0$mux;$previousIndex$0$ph7 = $previousIndex$0$currentIndex$0;
 }
 if ((label|0) == 18) {
  $29 = $27 & 536870911;
  HEAP32[$neighbor>>2] = $29;
  HEAP32[$current>>2] = $currentIndex$0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL22TestDuplicateTrianglesRjPN5physx2Gu9TriangleTIjEEb($nbFaces,$faces,$repair) {
 $nbFaces = $nbFaces|0;
 $faces = $faces|0;
 $repair = $repair|0;
 var $$0 = 0, $$1 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $Reducer = 0, $brmerge = 0, $i$02 = 0, $i1$01 = 0;
 var $or$cond = 0, $rc = 0, $repair$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $Reducer = sp + 12|0;
 $rc = sp;
 $0 = HEAP32[$nbFaces>>2]|0;
 $1 = ($0|0)==(0);
 $2 = ($faces|0)==(0|0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $3 = ($0*12)|0;
 $4 = STACKTOP; STACKTOP = STACKTOP + ((((1*$3)|0)+15)&-16)|0;;
 $i$02 = 0;
 while(1) {
  $5 = (($faces) + (($i$02*12)|0)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + (($i$02*12)|0)|0);
  HEAP32[$7>>2] = $6;
  $8 = ((($faces) + (($i$02*12)|0)|0) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($4) + (($i$02*12)|0)|0) + 4|0);
  HEAP32[$10>>2] = $9;
  $11 = ((($faces) + (($i$02*12)|0)|0) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($4) + (($i$02*12)|0)|0) + 8|0);
  HEAP32[$13>>2] = $12;
  $14 = (($i$02) + 1)|0;
  $15 = ($14>>>0)<($0>>>0);
  if ($15) {
   $i$02 = $14;
  } else {
   break;
  }
 }
 __ZN5physx18ReducedVertexCloudC2EPKNS_6PxVec3Ej($Reducer,$4,$0);
 (__ZN5physx18ReducedVertexCloud6ReduceEPNS_12REDUCEDCLOUDE($Reducer,$rc)|0);
 $16 = (($rc) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$nbFaces>>2]|0;
 $$not = ($17>>>0)>=($18>>>0);
 $repair$not = $repair ^ 1;
 $brmerge = $$not | $repair$not;
 if ($brmerge) {
  $$0 = $$not;
 } else {
  HEAP32[$nbFaces>>2] = $17;
  $19 = ($17|0)==(0);
  if ($19) {
   $$0 = 0;
  } else {
   $20 = HEAP32[$rc>>2]|0;
   $i1$01 = 0;
   while(1) {
    $21 = (($20) + (($i1$01*12)|0)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($faces) + (($i1$01*12)|0)|0);
    HEAP32[$23>>2] = $22;
    $24 = ((($20) + (($i1$01*12)|0)|0) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($faces) + (($i1$01*12)|0)|0) + 4|0);
    HEAP32[$26>>2] = $25;
    $27 = ((($20) + (($i1$01*12)|0)|0) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ((($faces) + (($i1$01*12)|0)|0) + 8|0);
    HEAP32[$29>>2] = $28;
    $30 = (($i1$01) + 1)|0;
    $31 = HEAP32[$nbFaces>>2]|0;
    $32 = ($30>>>0)<($31>>>0);
    if ($32) {
     $i1$01 = $30;
    } else {
     $$0 = 0;
     break;
    }
   }
  }
 }
 __ZN5physx18ReducedVertexCloudD2Ev($Reducer);
 $$1 = $$0;
 STACKTOP = sp;return ($$1|0);
}
function __ZL18TestUnifiedNormalsjPKN5physx6PxVec3EjPNS_2Gu9TriangleTIjEEb($nbVerts,$verts,$nbFaces,$faces,$repair) {
 $nbVerts = $nbVerts|0;
 $verts = $verts|0;
 $nbFaces = $nbFaces|0;
 $faces = $faces|0;
 $repair = $repair|0;
 var $$0 = 0, $$idx = 0, $$idx$val = 0, $$idx4 = 0, $$idx4$val = 0, $$idx5 = 0, $$idx5$val = 0, $$not = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0);
 var $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0;
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $9 = Math_fround(0), $Status$0$off0$mux = 0, $Status$0$off08 = 0, $Status$1$off0 = 0, $brmerge = 0, $exitcond = 0, $exitcond20 = 0, $i$012 = 0, $i1$09 = 0, $or$cond = 0, $or$cond2 = 0, $or$cond3 = 0;
 var $repair$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nbVerts|0)==(0);
 $1 = ($verts|0)==(0|0);
 $or$cond = $0 | $1;
 $2 = ($nbFaces|0)==(0);
 $or$cond2 = $or$cond | $2;
 $3 = ($faces|0)==(0|0);
 $or$cond3 = $or$cond2 | $3;
 if ($or$cond3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (Math_fround(($nbVerts>>>0)));
 $5 = Math_fround(Math_fround(1.0) / $4);
 $10 = Math_fround(0.0);$15 = Math_fround(0.0);$20 = Math_fround(0.0);$i$012 = 0;
 while(1) {
  $6 = (($verts) + (($i$012*12)|0)|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround($5 * $7);
  $9 = Math_fround($10 + $8);
  $11 = ((($verts) + (($i$012*12)|0)|0) + 4|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($5 * $12);
  $14 = Math_fround($15 + $13);
  $16 = ((($verts) + (($i$012*12)|0)|0) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($5 * $17);
  $19 = Math_fround($20 + $18);
  $21 = (($i$012) + 1)|0;
  $exitcond20 = ($21|0)==($nbVerts|0);
  if ($exitcond20) {
   break;
  } else {
   $10 = $9;$15 = $14;$20 = $19;$i$012 = $21;
  }
 }
 $repair$not = $repair ^ 1;
 $Status$0$off08 = 1;$i1$09 = 0;
 while(1) {
  $$idx = (($faces) + (($i1$09*12)|0)|0);
  $$idx$val = HEAP32[$$idx>>2]|0;
  $$idx4 = ((($faces) + (($i1$09*12)|0)|0) + 4|0);
  $$idx4$val = HEAP32[$$idx4>>2]|0;
  $$idx5 = ((($faces) + (($i1$09*12)|0)|0) + 8|0);
  $$idx5$val = HEAP32[$$idx5>>2]|0;
  $22 = (($verts) + (($$idx4$val*12)|0)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($verts) + (($$idx$val*12)|0)|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($23 - $25);
  $27 = ((($verts) + (($$idx4$val*12)|0)|0) + 4|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = ((($verts) + (($$idx$val*12)|0)|0) + 4|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($28 - $30);
  $32 = ((($verts) + (($$idx4$val*12)|0)|0) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = ((($verts) + (($$idx$val*12)|0)|0) + 8|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($33 - $35);
  $37 = (($verts) + (($$idx5$val*12)|0)|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround($38 - $25);
  $40 = ((($verts) + (($$idx5$val*12)|0)|0) + 4|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($41 - $30);
  $43 = ((($verts) + (($$idx5$val*12)|0)|0) + 8|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($44 - $35);
  $46 = Math_fround($31 * $45);
  $47 = Math_fround($36 * $42);
  $48 = Math_fround($46 - $47);
  $49 = Math_fround($36 * $39);
  $50 = Math_fround($26 * $45);
  $51 = Math_fround($49 - $50);
  $52 = Math_fround($26 * $42);
  $53 = Math_fround($31 * $39);
  $54 = Math_fround($52 - $53);
  $55 = Math_fround($48 * $48);
  $56 = Math_fround($51 * $51);
  $57 = Math_fround($55 + $56);
  $58 = Math_fround($54 * $54);
  $59 = Math_fround($58 + $57);
  $60 = $59 > Math_fround(0.0);
  if ($60) {
   $61 = (Math_fround(Math_sqrt((Math_fround($59)))));
   $62 = Math_fround(Math_fround(1.0) / $61);
   $63 = Math_fround($48 * $62);
   $64 = Math_fround($51 * $62);
   $65 = Math_fround($54 * $62);
   $67 = $63;$69 = $64;$72 = $65;
  } else {
   $67 = Math_fround(0.0);$69 = Math_fround(0.0);$72 = Math_fround(0.0);
  }
  $66 = Math_fround($25 * $67);
  $68 = Math_fround($30 * $69);
  $70 = Math_fround($68 + $66);
  $71 = Math_fround($35 * $72);
  $73 = Math_fround($71 + $70);
  $74 = Math_fround($9 * $67);
  $75 = Math_fround($14 * $69);
  $76 = Math_fround($75 + $74);
  $77 = Math_fround($19 * $72);
  $78 = Math_fround($77 + $76);
  $79 = Math_fround($78 - $73);
  $$not = !($79 > Math_fround(0.0));
  $brmerge = $$not | $repair$not;
  $Status$0$off0$mux = $$not & $Status$0$off08;
  if ($brmerge) {
   $Status$1$off0 = $Status$0$off0$mux;
  } else {
   HEAP32[$$idx4>>2] = $$idx5$val;
   HEAP32[$$idx5>>2] = $$idx4$val;
   $Status$1$off0 = 0;
  }
  $80 = (($i1$09) + 1)|0;
  $exitcond = ($80|0)==($nbFaces|0);
  if ($exitcond) {
   $$0 = $Status$1$off0;
   break;
  } else {
   $Status$0$off08 = $Status$1$off0;$i1$09 = $80;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17ConvexMeshBuilderC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Gu10ConvexMeshC2Ev($this);
 HEAP32[$this>>2] = ((533456 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = ((533456 + 84|0));
 $1 = (($this) + 132|0);
 $2 = (($this) + 16|0);
 __ZN5physx17ConvexHullBuilderC2EPNS_2Gu14ConvexHullDataE($1,$2);
 STACKTOP = sp;return;
}
function __ZN5physx17ConvexMeshBuilderD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((533456 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((533456 + 84|0));
 $2 = (($this) + 132|0);
 __ZN5physx17ConvexHullBuilderD2Ev($2);
 __ZN5physx2Gu10ConvexMeshD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx17ConvexMeshBuilderD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 HEAP32[$1>>2] = (((533456 + 8|0)));
 $2 = (($1) + 8|0);
 HEAP32[$2>>2] = (((533456 + 84|0)));
 $3 = (($1) + 132|0);
 __ZN5physx17ConvexHullBuilderD2Ev($3);
 __ZN5physx2Gu10ConvexMeshD2Ev($1);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx17ConvexMeshBuilderD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((533456 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = ((533456 + 84|0));
 $1 = (($this) + 132|0);
 __ZN5physx17ConvexHullBuilderD2Ev($1);
 __ZN5physx2Gu10ConvexMeshD2Ev($this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx17ConvexMeshBuilderD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 HEAP32[$0>>2] = (((533456 + 8|0)));
 $1 = (($0) + 8|0);
 HEAP32[$1>>2] = (((533456 + 84|0)));
 $2 = (($0) + 132|0);
 __ZN5physx17ConvexHullBuilderD2Ev($2);
 __ZN5physx2Gu10ConvexMeshD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx17ConvexMeshBuilder12loadFromDescERKNS_16PxConvexMeshDescENS_10PxPlatform4EnumE($this,$desc,$targetPlatform) {
 $this = $this|0;
 $desc = $desc|0;
 $targetPlatform = $targetPlatform|0;
 var $$0 = 0, $$0$i = 0, $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $not$$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($desc) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<(3);
 L1: do {
  if (!($2)) {
   $3 = ($1>>>0)>(65535);
   if ($3) {
    $4 = (($desc) + 48|0);
    $5 = HEAP16[$4>>1]|0;
    $6 = $5 & 2;
    $7 = ($6<<16>>16)==(0);
    if (!($7)) {
     break;
    }
   }
   $8 = (($desc) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = HEAP32[$desc>>2]|0;
    $12 = ($11>>>0)<(12);
    if (!($12)) {
     $13 = (($desc) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0|0);
     do {
      if ($15) {
       $27 = (($desc) + 28|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = ($28|0)==(0|0);
       if ($29) {
        $47 = (($desc) + 48|0);
        $48 = HEAP16[$47>>1]|0;
        $49 = $48 & 4;
        $50 = ($49<<16>>16)==(0);
        if ($50) {
         break L1;
        } else {
         break;
        }
       }
       $30 = (($desc) + 32|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($31>>>0)<(4);
       if ($32) {
        break L1;
       }
       $33 = (($desc) + 40|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ($34|0)==(0|0);
       if ($35) {
        break L1;
       }
       $36 = (($desc) + 48|0);
       $37 = HEAP16[$36>>1]|0;
       $38 = $37 & 2;
       $39 = ($38<<16>>16)!=(0);
       $40 = $39 ? 2 : 4;
       $41 = (($desc) + 36|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42>>>0)<($40>>>0);
       if ($43) {
        break L1;
       }
       $44 = (($desc) + 24|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = ($45>>>0)<(20);
       if ($46) {
        break L1;
       }
      } else {
       $16 = (($desc) + 20|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = ($17>>>0)<(2);
       if ($18) {
        break L1;
       }
       $19 = (($desc) + 48|0);
       $20 = HEAP16[$19>>1]|0;
       $21 = $20 & 2;
       $22 = ($21<<16>>16)!=(0);
       $23 = $22 ? 6 : 12;
       $24 = (($desc) + 12|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = ($25>>>0)<($23>>>0);
       if ($26) {
        break L1;
       }
      }
     } while(0);
     $51 = (($desc) + 50|0);
     $52 = HEAP16[$51>>1]|0;
     $$off$i = (($52) + -4)<<16>>16;
     $not$$i = ($$off$i&65535)<(253);
     if ($not$$i) {
      $54 = (__ZN5physx17ConvexMeshBuilder14loadConvexHullERKNS_16PxConvexMeshDescE($this,$desc)|0);
      if (!($54)) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      $55 = (($this) + 16|0);
      $56 = (($this) + 54|0);
      $57 = HEAP8[$56>>0]|0;
      $58 = $57&255;
      $59 = (($this) + 132|0);
      $60 = HEAP32[$59>>2]|0;
      __ZN5physx2Gu27computeBoundsAroundVerticesERNS_9PxBounds3EjPKNS_6PxVec3E($55,$58,$60);
      $61 = HEAP8[$56>>0]|0;
      $62 = $61&255;
      switch ($targetPlatform|0) {
      case 0:  {
       $$0$i = 32;
       break;
      }
      case 3:  {
       $$0$i = 32;
       break;
      }
      case 4: case 2: case 1:  {
       $$0$i = 128;
       break;
      }
      default: {
       $$0$i = 0;
      }
      }
      $63 = ($62>>>0)>($$0$i>>>0);
      if ($63) {
       (__ZN5physx17ConvexMeshBuilder16computeGaussMapsEv($this)|0);
      }
      __ZN5physx17ConvexMeshBuilder22computeInternalObjectsEv($this);
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $53 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($53,4,533552,73,533648,$vararg_buffer);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17ConvexMeshBuilder14loadConvexHullERKNS_16PxConvexMeshDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$0 = 0, $$01$i = 0, $$01$i13 = 0, $$01$i3 = 0, $$01$i8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $d$03$i = 0, $d$03$i1 = 0, $d$03$i11 = 0, $d$03$i6 = 0, $dest$022 = 0, $dest1$018 = 0, $hullPolygons$0 = 0, $s$02$i = 0, $s$02$i12 = 0, $s$02$i2 = 0, $s$02$i7 = 0, $source$021 = 0;
 var $source3$019 = 0, $topology$0 = 0, $topology$1 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($desc) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1*12)|0;
 $3 = STACKTOP; STACKTOP = STACKTOP + ((((1*$2)|0)+15)&-16)|0;;
 $4 = HEAP32[$desc>>2]|0;
 $5 = ($1|0)==(0);
 if (!($5)) {
  $6 = (($desc) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $$01$i = $1;$d$03$i = $3;$s$02$i = $7;
  while(1) {
   $8 = (($$01$i) + -1)|0;
   dest=$d$03$i+0|0; src=$s$02$i+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $9 = (($d$03$i) + 12|0);
   $10 = (($s$02$i) + ($4)|0);
   $11 = ($8|0)==(0);
   if ($11) {
    break;
   } else {
    $$01$i = $8;$d$03$i = $9;$s$02$i = $10;
   }
  }
 }
 $12 = (($desc) + 12|0);
 $13 = (($desc) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 L6: do {
  if ($15) {
   $topology$0 = 0;
  } else {
   $16 = (($desc) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17*12)|0;
   $19 = STACKTOP; STACKTOP = STACKTOP + ((((1*$18)|0)+15)&-16)|0;;
   $20 = (($desc) + 48|0);
   $21 = HEAP16[$20>>1]|0;
   $22 = $21 & 2;
   $23 = ($22<<16>>16)==(0);
   if ($23) {
    $41 = HEAP32[$12>>2]|0;
    $42 = ($17|0)==(0);
    if ($42) {
     $topology$0 = $19;
     break;
    } else {
     $$01$i13 = $17;$d$03$i11 = $19;$s$02$i12 = $14;
    }
    while(1) {
     $43 = (($$01$i13) + -1)|0;
     dest=$d$03$i11+0|0; src=$s$02$i12+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $44 = (($d$03$i11) + 12|0);
     $45 = (($s$02$i12) + ($41)|0);
     $46 = ($43|0)==(0);
     if ($46) {
      $topology$0 = $19;
      break L6;
     } else {
      $$01$i13 = $43;$d$03$i11 = $44;$s$02$i12 = $45;
     }
    }
   }
   $24 = ($17*3)|0;
   $25 = (($19) + ($24<<2)|0);
   $26 = ($19>>>0)<($25>>>0);
   if ($26) {
    $dest$022 = $19;$source$021 = $14;
    while(1) {
     $27 = HEAP16[$source$021>>1]|0;
     $28 = $27&65535;
     $29 = (($dest$022) + 4|0);
     HEAP32[$dest$022>>2] = $28;
     $30 = (($source$021) + 2|0);
     $31 = HEAP16[$30>>1]|0;
     $32 = $31&65535;
     $33 = (($dest$022) + 8|0);
     HEAP32[$29>>2] = $32;
     $34 = (($source$021) + 4|0);
     $35 = HEAP16[$34>>1]|0;
     $36 = $35&65535;
     $37 = (($dest$022) + 12|0);
     HEAP32[$33>>2] = $36;
     $38 = HEAP32[$12>>2]|0;
     $39 = (($source$021) + ($38)|0);
     $40 = ($37>>>0)<($25>>>0);
     if ($40) {
      $dest$022 = $37;$source$021 = $39;
     } else {
      $topology$0 = $19;
      break;
     }
    }
   } else {
    $topology$0 = $19;
   }
  }
 } while(0);
 $47 = (($desc) + 36|0);
 $48 = (($desc) + 40|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 L17: do {
  if ($50) {
   $topology$1 = $topology$0;
  } else {
   $51 = (($desc) + 44|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = $52 << 2;
   $54 = STACKTOP; STACKTOP = STACKTOP + ((((1*$53)|0)+15)&-16)|0;;
   $55 = (($desc) + 48|0);
   $56 = HEAP16[$55>>1]|0;
   $57 = $56 & 2;
   $58 = ($57<<16>>16)==(0);
   if ($58) {
    $75 = HEAP32[$47>>2]|0;
    $76 = ($52|0)==(0);
    if ($76) {
     $topology$1 = $54;
     break;
    } else {
     $$01$i8 = $52;$d$03$i6 = $54;$s$02$i7 = $49;
    }
    while(1) {
     $77 = (($$01$i8) + -1)|0;
     $78 = HEAPU8[$s$02$i7>>0]|(HEAPU8[$s$02$i7+1>>0]<<8)|(HEAPU8[$s$02$i7+2>>0]<<16)|(HEAPU8[$s$02$i7+3>>0]<<24);
     HEAP8[$d$03$i6>>0]=$78&255;HEAP8[$d$03$i6+1>>0]=($78>>8)&255;HEAP8[$d$03$i6+2>>0]=($78>>16)&255;HEAP8[$d$03$i6+3>>0]=$78>>24;
     $79 = (($d$03$i6) + 4|0);
     $80 = (($s$02$i7) + ($75)|0);
     $81 = ($77|0)==(0);
     if ($81) {
      $topology$1 = $54;
      break L17;
     } else {
      $$01$i8 = $77;$d$03$i6 = $79;$s$02$i7 = $80;
     }
    }
   }
   $59 = (($54) + ($52<<2)|0);
   $60 = ($54>>>0)<($59>>>0);
   if ($60) {
    $dest1$018 = $54;$source3$019 = $49;
    while(1) {
     $61 = HEAP16[$source3$019>>1]|0;
     $62 = $61&65535;
     $63 = (($dest1$018) + 4|0);
     HEAP32[$dest1$018>>2] = $62;
     $64 = (($source3$019) + 2|0);
     $65 = HEAP16[$64>>1]|0;
     $66 = $65&65535;
     $67 = (($dest1$018) + 8|0);
     HEAP32[$63>>2] = $66;
     $68 = (($source3$019) + 4|0);
     $69 = HEAP16[$68>>1]|0;
     $70 = $69&65535;
     $71 = (($dest1$018) + 12|0);
     HEAP32[$67>>2] = $70;
     $72 = HEAP32[$47>>2]|0;
     $73 = (($source3$019) + ($72)|0);
     $74 = ($71>>>0)<($59>>>0);
     if ($74) {
      $dest1$018 = $71;$source3$019 = $73;
     } else {
      $topology$1 = $54;
      break;
     }
    }
   } else {
    $topology$1 = $54;
   }
  }
 } while(0);
 $82 = (($desc) + 28|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($83|0)==(0|0);
 $$pre = (($desc) + 32|0);
 if ($84) {
  $hullPolygons$0 = 0;
 } else {
  $85 = HEAP32[$$pre>>2]|0;
  $86 = ($85*20)|0;
  $87 = STACKTOP; STACKTOP = STACKTOP + ((((1*$86)|0)+15)&-16)|0;;
  $88 = (($desc) + 24|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($85|0)==(0);
  if ($90) {
   $hullPolygons$0 = $87;
  } else {
   $$01$i3 = $85;$d$03$i1 = $87;$s$02$i2 = $83;
   while(1) {
    $91 = (($$01$i3) + -1)|0;
    dest=$d$03$i1+0|0; src=$s$02$i2+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $92 = (($d$03$i1) + 20|0);
    $93 = (($s$02$i2) + ($89)|0);
    $94 = ($91|0)==(0);
    if ($94) {
     $hullPolygons$0 = $87;
     break;
    } else {
     $$01$i3 = $91;$d$03$i1 = $92;$s$02$i2 = $93;
    }
   }
  }
 }
 $95 = (($this) + 132|0);
 $96 = HEAP32[$0>>2]|0;
 $97 = (($desc) + 20|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$$pre>>2]|0;
 $100 = (__ZN5physx17ConvexHullBuilder4InitEjPKNS_6PxVec3EjPKjjPKNS_13PxHullPolygonE($95,$96,$3,$98,$topology$1,$99,$hullPolygons$0)|0);
 if ($100) {
  __ZN5physx17ConvexMeshBuilder15computeMassInfoEv($this);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $101 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($101,32,533552,266,533888,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx17ConvexMeshBuilder16computeGaussMapsEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $SVMB = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 12|0;
 $SVMB = sp;
 $1 = (($this) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN5physx13BigConvexDataD2Ev($2);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 }
 $4 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z15PxGetFoundationv()|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
 $$$i$i$i = $12 ? 534232 : 534200;
 $13 = (FUNCTION_TABLE_iiiiii[$7 & 255]($4,28,$$$i$i$i,533552,340)|0);
 __ZN5physx13BigConvexDataC2Ev($13);
 HEAP32[$1>>2] = $13;
 $14 = (($this) + 16|0);
 $15 = (($this) + 132|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN5physx20BigConvexDataBuilderC2EPKNS_2Gu14ConvexHullDataEPNS_13BigConvexDataEPKNS_6PxVec3E($SVMB,$14,$13,$16);
 (__ZN5physx20BigConvexDataBuilder10PrecomputeEj($SVMB,16)|0);
 STACKTOP = sp;return 1;
}
function __ZN5physx17ConvexMeshBuilder22computeInternalObjectsEv($this) {
 $this = $this|0;
 var $$pre = Math_fround(0), $$pre12 = Math_fround(0), $$pre13 = Math_fround(0), $$pre14 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0);
 var $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0;
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0;
 var $96 = Math_fround(0), $97 = Math_fround(0), $MaxX$0$lcssa$i = Math_fround(0), $MaxX$06$i = Math_fround(0), $MaxX$1$i = Math_fround(0), $MaxY$0$lcssa$i = Math_fround(0), $MaxY$07$i = Math_fround(0), $MaxY$1$i = Math_fround(0), $MaxZ$0$lcssa$i = Math_fround(0), $MaxZ$08$i = Math_fround(0), $MaxZ$1$i = Math_fround(0), $MinX$0$lcssa$i = Math_fround(0), $MinX$010$i = Math_fround(0), $MinX$1$i = Math_fround(0), $MinY$0$lcssa$i = Math_fround(0), $MinY$04$i = Math_fround(0), $MinY$1$i = Math_fround(0), $MinZ$0$lcssa$i = Math_fround(0), $MinZ$05$i = Math_fround(0), $MinZ$1$i = Math_fround(0);
 var $e = 0, $exitcond$i = 0, $i$08 = 0, $i$09$i = 0, $j$06 = 0, $j1$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $e = sp;
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 64|0);
 HEAPF32[$4>>2] = Math_fround(3.40282346638528859812E+38);
 $5 = (($this) + 55|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $54 = Math_fround(3.40282346638528859812E+38);
 } else {
  $8 = (($this) + 40|0);
  $9 = (($this) + 44|0);
  $10 = (($this) + 48|0);
  $$pre12 = Math_fround(HEAPF32[$8>>2]);
  $$pre13 = Math_fround(HEAPF32[$9>>2]);
  $$pre14 = Math_fround(HEAPF32[$10>>2]);
  $27 = Math_fround(3.40282346638528859812E+38);$i$08 = 0;
  while(1) {
   $11 = (($1) + (($i$08*20)|0)|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = Math_fround($$pre12 * $12);
   $14 = ((($1) + (($i$08*20)|0)|0) + 4|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($$pre13 * $15);
   $17 = Math_fround($13 + $16);
   $18 = ((($1) + (($i$08*20)|0)|0) + 8|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround($$pre14 * $19);
   $21 = Math_fround($17 + $20);
   $22 = ((($1) + (($i$08*20)|0)|0) + 12|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($23 + $21);
   $25 = (Math_fround(Math_abs((Math_fround($24)))));
   $26 = $25 < $27;
   if ($26) {
    HEAPF32[$4>>2] = $25;
    $97 = $25;
   } else {
    $97 = $27;
   }
   $28 = (($i$08) + 1)|0;
   $29 = $6&255;
   $30 = ($28>>>0)<($29>>>0);
   if ($30) {
    $27 = $97;$i$08 = $28;
   } else {
    $54 = $97;
    break;
   }
  }
 }
 $31 = (($this) + 54|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = ($32<<24>>24)==(0);
 if ($34) {
  $MaxX$0$lcssa$i = Math_fround(-3.40282346638528859812E+38);$MaxY$0$lcssa$i = Math_fround(-3.40282346638528859812E+38);$MaxZ$0$lcssa$i = Math_fround(-3.40282346638528859812E+38);$MinX$0$lcssa$i = Math_fround(3.40282346638528859812E+38);$MinY$0$lcssa$i = Math_fround(3.40282346638528859812E+38);$MinZ$0$lcssa$i = Math_fround(3.40282346638528859812E+38);
 } else {
  $MaxX$06$i = Math_fround(-3.40282346638528859812E+38);$MaxY$07$i = Math_fround(-3.40282346638528859812E+38);$MaxZ$08$i = Math_fround(-3.40282346638528859812E+38);$MinX$010$i = Math_fround(3.40282346638528859812E+38);$MinY$04$i = Math_fround(3.40282346638528859812E+38);$MinZ$05$i = Math_fround(3.40282346638528859812E+38);$i$09$i = 0;
  while(1) {
   $35 = (($3) + (($i$09$i*12)|0)|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = $36 < $MinX$010$i;
   $MinX$1$i = $37 ? $36 : $MinX$010$i;
   $38 = $36 > $MaxX$06$i;
   $MaxX$1$i = $38 ? $36 : $MaxX$06$i;
   $39 = ((($3) + (($i$09$i*12)|0)|0) + 4|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = $40 < $MinY$04$i;
   $MinY$1$i = $41 ? $40 : $MinY$04$i;
   $42 = $40 > $MaxY$07$i;
   $MaxY$1$i = $42 ? $40 : $MaxY$07$i;
   $43 = ((($3) + (($i$09$i*12)|0)|0) + 8|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = $44 < $MinZ$05$i;
   $MinZ$1$i = $45 ? $44 : $MinZ$05$i;
   $46 = $44 > $MaxZ$08$i;
   $MaxZ$1$i = $46 ? $44 : $MaxZ$08$i;
   $47 = (($i$09$i) + 1)|0;
   $exitcond$i = ($47|0)==($33|0);
   if ($exitcond$i) {
    $MaxX$0$lcssa$i = $MaxX$1$i;$MaxY$0$lcssa$i = $MaxY$1$i;$MaxZ$0$lcssa$i = $MaxZ$1$i;$MinX$0$lcssa$i = $MinX$1$i;$MinY$0$lcssa$i = $MinY$1$i;$MinZ$0$lcssa$i = $MinZ$1$i;
    break;
   } else {
    $MaxX$06$i = $MaxX$1$i;$MaxY$07$i = $MaxY$1$i;$MaxZ$08$i = $MaxZ$1$i;$MinX$010$i = $MinX$1$i;$MinY$04$i = $MinY$1$i;$MinZ$05$i = $MinZ$1$i;$i$09$i = $47;
   }
  }
 }
 $48 = Math_fround($MaxX$0$lcssa$i - $MinX$0$lcssa$i);
 $49 = Math_fround($MaxY$0$lcssa$i - $MinY$0$lcssa$i);
 $50 = Math_fround($MaxZ$0$lcssa$i - $MinZ$0$lcssa$i);
 HEAPF32[$e>>2] = $48;
 $51 = (($e) + 4|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($e) + 8|0);
 HEAPF32[$52>>2] = $50;
 $53 = Math_fround($54 / Math_fround(1.73205077648162841797));
 $55 = $49 > $48;
 $56 = $55&1;
 $57 = (($e) + ($56<<2)|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = $50 > $58;
 $60 = $59 ? 2 : $56;
 $61 = (($e) + ($60<<2)|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * Math_fround(0.5));
 $64 = Math_fround($63 - $53);
 $65 = Math_fround($64 * Math_fround(9.765625E-4));
 $66 = (($this) + 76|0);
 HEAPF32[$66>>2] = $53;
 $67 = (($this) + 72|0);
 HEAPF32[$67>>2] = $53;
 $68 = (($this) + 68|0);
 HEAPF32[$68>>2] = $53;
 $69 = ((($this) + ($60<<2)|0) + 68|0);
 HEAPF32[$69>>2] = $63;
 $70 = (($this) + 40|0);
 $75 = $63;$j$06 = 0;
 while(1) {
  $71 = HEAP8[$5>>0]|0;
  $72 = $71&255;
  $73 = (__ZL15TestContainmentRKN5physx6PxVec3EPKfjPKNS_2Gu15HullPolygonDataE($70,$68,$72,$1)|0);
  if ($73) {
   break;
  }
  $74 = Math_fround($75 - $65);
  HEAPF32[$69>>2] = $74;
  $76 = (($j$06) + 1)|0;
  $77 = ($76>>>0)<(1024);
  if ($77) {
   $75 = $74;$j$06 = $76;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  HEAPF32[$66>>2] = $53;
  HEAPF32[$67>>2] = $53;
  HEAPF32[$68>>2] = $53;
  STACKTOP = sp;return;
 }
 $78 = Math_fround(HEAPF32[$4>>2]);
 $79 = Math_fround($78 - $53);
 $80 = Math_fround($79 * Math_fround(9.765625E-4));
 $81 = 1 << $60;
 $82 = $81 & 3;
 $83 = 1 << $82;
 $84 = $83 & 3;
 $85 = ((($this) + ($82<<2)|0) + 68|0);
 $86 = ((($this) + ($84<<2)|0) + 68|0);
 $$pre = Math_fround(HEAPF32[$86>>2]);
 $96 = $$pre;$j1$04 = 0;
 while(1) {
  $89 = Math_fround(HEAPF32[$85>>2]);
  $90 = Math_fround($80 + $89);
  HEAPF32[$85>>2] = $90;
  $91 = Math_fround(HEAPF32[$86>>2]);
  $92 = Math_fround($80 + $91);
  HEAPF32[$86>>2] = $92;
  $93 = HEAP8[$5>>0]|0;
  $94 = $93&255;
  $95 = (__ZL15TestContainmentRKN5physx6PxVec3EPKfjPKNS_2Gu15HullPolygonDataE($70,$68,$94,$1)|0);
  $88 = (($j1$04) + 1)|0;
  if (!($95)) {
   break;
  }
  $87 = ($88>>>0)<(1024);
  if ($87) {
   $96 = $92;$j1$04 = $88;
  } else {
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
 HEAPF32[$85>>2] = $89;
 HEAPF32[$86>>2] = $96;
 STACKTOP = sp;return;
}
function __ZNK5physx17ConvexMeshBuilder4saveERNS_14PxOutputStreamEb($this,$stream,$platformMismatch) {
 $this = $this|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $SVMB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $SVMB = sp;
 $0 = (__ZN5physx11writeHeaderEaaaajbRNS_14PxOutputStreamE(67,86,88,77,13,$platformMismatch,$stream)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE(0,$platformMismatch,$stream);
 $1 = (($this) + 132|0);
 $2 = (__ZNK5physx17ConvexHullBuilder4SaveERNS_14PxOutputStreamEb($1,$stream,$platformMismatch)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE(Math_fround(0.0),$platformMismatch,$stream);
 $3 = (($this) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($4,$platformMismatch,$stream);
 $5 = (($this) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($6,$platformMismatch,$stream);
 $7 = (($this) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($8,$platformMismatch,$stream);
 $9 = (($this) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($10,$platformMismatch,$stream);
 $11 = (($this) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($12,$platformMismatch,$stream);
 $13 = (($this) + 36|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($14,$platformMismatch,$stream);
 $15 = (($this) + 88|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($16,$platformMismatch,$stream);
 $17 = (($this) + 92|0);
 __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($17,9,$platformMismatch,$stream);
 $18 = (($this) + 40|0);
 __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($18,3,$platformMismatch,$stream);
 $19 = (($this) + 84|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE(Math_fround(-1.0),$platformMismatch,$stream);
 } else {
  __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE(Math_fround(1.0),$platformMismatch,$stream);
  $22 = HEAP32[$19>>2]|0;
  $23 = HEAP32[$1>>2]|0;
  __ZN5physx20BigConvexDataBuilderC2EPKNS_2Gu14ConvexHullDataEPNS_13BigConvexDataEPKNS_6PxVec3E($SVMB,$3,$22,$23);
  $24 = (($this) + 164|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($this) + 168|0);
  $27 = HEAP32[$26>>2]|0;
  (__ZNK5physx20BigConvexDataBuilder4SaveERNS_14PxOutputStreamEbjPKNS_16HullTriangleDataE($SVMB,$stream,$platformMismatch,$25,$27)|0);
 }
 $28 = (($this) + 64|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($29,$platformMismatch,$stream);
 $30 = (($this) + 68|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($31,$platformMismatch,$stream);
 $32 = (($this) + 72|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($33,$platformMismatch,$stream);
 $34 = (($this) + 76|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($35,$platformMismatch,$stream);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx17ConvexMeshBuilder15computeMassInfoEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0.0, $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0.0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0.0, $46 = Math_fround(0), $47 = 0, $48 = 0.0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0.0;
 var $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0.0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0.0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0.0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $i$04 = 0, $integrals = 0, $mean = 0, $simpleMesh = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $vararg_buffer1 = sp + 168|0;
 $integrals = sp;
 $simpleMesh = sp + 184|0;
 $mean = sp + 172|0;
 $0 = (($this) + 88|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = !($1 <= Math_fround(0.0));
 if ($2) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$simpleMesh+0>>2]=0|0;HEAP32[$simpleMesh+4>>2]=0|0;HEAP32[$simpleMesh+8>>2]=0|0;HEAP32[$simpleMesh+12>>2]=0|0;HEAP32[$simpleMesh+16>>2]=0|0;HEAP32[$simpleMesh+20>>2]=0|0;HEAP16[$simpleMesh+24>>1]=0|0;
 $3 = (($this) + 54|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (($simpleMesh) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 164|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($simpleMesh) + 20|0);
 HEAP32[$9>>2] = $8;
 HEAP32[$simpleMesh>>2] = 12;
 $10 = (($simpleMesh) + 12|0);
 HEAP32[$10>>2] = 12;
 $11 = (($this) + 132|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($simpleMesh) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 168|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($simpleMesh) + 16|0);
 HEAP32[$16>>2] = $15;
 HEAPF32[$mean>>2] = Math_fround(0.0);
 $17 = (($mean) + 4|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($mean) + 8|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = ($4<<24>>24)==(0);
 if ($19) {
  $37 = Math_fround(0.0);$39 = Math_fround(0.0);$41 = Math_fround(0.0);
 } else {
  $23 = Math_fround(0.0);$27 = Math_fround(0.0);$31 = Math_fround(0.0);$i$04 = 0;
  while(1) {
   $20 = (($12) + (($i$04*12)|0)|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = Math_fround($21 + $23);
   HEAPF32[$mean>>2] = $22;
   $24 = ((($12) + (($i$04*12)|0)|0) + 4|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = Math_fround($25 + $27);
   HEAPF32[$17>>2] = $26;
   $28 = ((($12) + (($i$04*12)|0)|0) + 8|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($29 + $31);
   HEAPF32[$18>>2] = $30;
   $32 = (($i$04) + 1)|0;
   $33 = ($32>>>0)<($5>>>0);
   if ($33) {
    $23 = $22;$27 = $26;$31 = $30;$i$04 = $32;
   } else {
    $37 = $22;$39 = $26;$41 = $30;
    break;
   }
  }
 }
 $34 = (Math_fround(($5|0)));
 $35 = Math_fround(Math_fround(1.0) / $34);
 $36 = Math_fround($35 * $37);
 HEAPF32[$mean>>2] = $36;
 $38 = Math_fround($35 * $39);
 HEAPF32[$17>>2] = $38;
 $40 = Math_fround($35 * $41);
 HEAPF32[$18>>2] = $40;
 $42 = (__ZN5physx28computeVolumeIntegralsEberlyERKNS_20PxSimpleTriangleMeshEfRNS_11PxIntegralsERKNS_6PxVec3E($simpleMesh,Math_fround(1.0),$integrals,$mean)|0);
 if ($42) {
  $43 = (($this) + 92|0);
  $44 = (($integrals) + 24|0);
  $45 = +HEAPF64[$44>>3];
  $46 = Math_fround($45);
  HEAPF32[$43>>2] = $46;
  $47 = (($integrals) + 48|0);
  $48 = +HEAPF64[$47>>3];
  $49 = Math_fround($48);
  $50 = (($43) + 4|0);
  HEAPF32[$50>>2] = $49;
  $51 = (($integrals) + 72|0);
  $52 = +HEAPF64[$51>>3];
  $53 = Math_fround($52);
  $54 = (($43) + 8|0);
  HEAPF32[$54>>2] = $53;
  $55 = (($43) + 12|0);
  $56 = (($integrals) + 32|0);
  $57 = +HEAPF64[$56>>3];
  $58 = Math_fround($57);
  HEAPF32[$55>>2] = $58;
  $59 = (($integrals) + 56|0);
  $60 = +HEAPF64[$59>>3];
  $61 = Math_fround($60);
  $62 = (($55) + 4|0);
  HEAPF32[$62>>2] = $61;
  $63 = (($integrals) + 80|0);
  $64 = +HEAPF64[$63>>3];
  $65 = Math_fround($64);
  $66 = (($55) + 8|0);
  HEAPF32[$66>>2] = $65;
  $67 = (($43) + 24|0);
  $68 = (($integrals) + 40|0);
  $69 = +HEAPF64[$68>>3];
  $70 = Math_fround($69);
  HEAPF32[$67>>2] = $70;
  $71 = (($integrals) + 64|0);
  $72 = +HEAPF64[$71>>3];
  $73 = Math_fround($72);
  $74 = (($67) + 4|0);
  HEAPF32[$74>>2] = $73;
  $75 = (($integrals) + 88|0);
  $76 = +HEAPF64[$75>>3];
  $77 = Math_fround($76);
  $78 = (($67) + 8|0);
  HEAPF32[$78>>2] = $77;
  $79 = Math_fround(HEAPF32[$integrals>>2]);
  $80 = (($this) + 40|0);
  HEAPF32[$80>>2] = $79;
  $81 = (($integrals) + 4|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = (($this) + 44|0);
  HEAPF32[$83>>2] = $82;
  $84 = (($integrals) + 8|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = (($this) + 48|0);
  HEAPF32[$86>>2] = $85;
  $87 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $88 = $87 & 2139095040;
  $89 = ($88>>>0)<(2139095040);
  if ($89) {
   $90 = (($this) + 96|0);
   $91 = (HEAPF32[tempDoublePtr>>2]=$49,HEAP32[tempDoublePtr>>2]|0);
   $92 = $91 & 2139095040;
   $93 = ($92>>>0)<(2139095040);
   if ($93) {
    $94 = (($this) + 100|0);
    $95 = (HEAPF32[tempDoublePtr>>2]=$53,HEAP32[tempDoublePtr>>2]|0);
    $96 = $95 & 2139095040;
    $97 = ($96>>>0)<(2139095040);
    if ($97) {
     $98 = (($this) + 104|0);
     $99 = (HEAPF32[tempDoublePtr>>2]=$58,HEAP32[tempDoublePtr>>2]|0);
     $100 = $99 & 2139095040;
     $101 = ($100>>>0)<(2139095040);
     if ($101) {
      $102 = (($this) + 108|0);
      $103 = (HEAPF32[tempDoublePtr>>2]=$61,HEAP32[tempDoublePtr>>2]|0);
      $104 = $103 & 2139095040;
      $105 = ($104>>>0)<(2139095040);
      if ($105) {
       $106 = (($this) + 112|0);
       $107 = (HEAPF32[tempDoublePtr>>2]=$65,HEAP32[tempDoublePtr>>2]|0);
       $108 = $107 & 2139095040;
       $109 = ($108>>>0)<(2139095040);
       if ($109) {
        $110 = (($this) + 116|0);
        $111 = (HEAPF32[tempDoublePtr>>2]=$70,HEAP32[tempDoublePtr>>2]|0);
        $112 = $111 & 2139095040;
        $113 = ($112>>>0)<(2139095040);
        if ($113) {
         $114 = (($this) + 120|0);
         $115 = (HEAPF32[tempDoublePtr>>2]=$73,HEAP32[tempDoublePtr>>2]|0);
         $116 = $115 & 2139095040;
         $117 = ($116>>>0)<(2139095040);
         if ($117) {
          $118 = (($this) + 124|0);
          $119 = (HEAPF32[tempDoublePtr>>2]=$77,HEAP32[tempDoublePtr>>2]|0);
          $120 = $119 & 2139095040;
          $121 = ($120>>>0)<(2139095040);
          if ($121) {
           $122 = (HEAPF32[tempDoublePtr>>2]=$79,HEAP32[tempDoublePtr>>2]|0);
           $123 = $122 & 2139095040;
           $124 = ($123>>>0)<(2139095040);
           if ($124) {
            $125 = (HEAPF32[tempDoublePtr>>2]=$82,HEAP32[tempDoublePtr>>2]|0);
            $126 = $125 & 2139095040;
            $127 = ($126>>>0)<(2139095040);
            if ($127) {
             $128 = (HEAPF32[tempDoublePtr>>2]=$85,HEAP32[tempDoublePtr>>2]|0);
             $129 = $128 & 2139095040;
             $130 = ($129>>>0)<(2139095040);
             if ($130) {
              $131 = (($integrals) + 16|0);
              $132 = +HEAPF64[$131>>3];
              $133 = Math_fround($132);
              $134 = (HEAPF32[tempDoublePtr>>2]=$133,HEAP32[tempDoublePtr>>2]|0);
              $135 = $134 & 2139095040;
              $136 = ($135>>>0)<(2139095040);
              if ($136) {
               $137 = $132 < 0.0;
               if ($137) {
                $138 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
                __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($138,2,533552,182,533704,$vararg_buffer1);
                $139 = +HEAPF64[$131>>3];
                $140 = -$139;
                HEAPF64[$131>>3] = $140;
                $141 = Math_fround(HEAPF32[$43>>2]);
                $142 = Math_fround(-$141);
                $143 = Math_fround(HEAPF32[$90>>2]);
                $144 = Math_fround(-$143);
                $145 = Math_fround(HEAPF32[$94>>2]);
                $146 = Math_fround(-$145);
                $147 = Math_fround(HEAPF32[$98>>2]);
                $148 = Math_fround(-$147);
                $149 = Math_fround(HEAPF32[$102>>2]);
                $150 = Math_fround(-$149);
                $151 = Math_fround(HEAPF32[$106>>2]);
                $152 = Math_fround(-$151);
                $153 = Math_fround(HEAPF32[$110>>2]);
                $154 = Math_fround(-$153);
                $155 = Math_fround(HEAPF32[$114>>2]);
                $156 = Math_fround(-$155);
                $157 = Math_fround(HEAPF32[$118>>2]);
                $158 = Math_fround(-$157);
                HEAPF32[$43>>2] = $142;
                HEAPF32[$90>>2] = $144;
                HEAPF32[$94>>2] = $146;
                HEAPF32[$98>>2] = $148;
                HEAPF32[$102>>2] = $150;
                HEAPF32[$106>>2] = $152;
                HEAPF32[$110>>2] = $154;
                HEAPF32[$114>>2] = $156;
                HEAPF32[$118>>2] = $158;
                $160 = $140;
               } else {
                $160 = $132;
               }
               $159 = Math_fround($160);
               HEAPF32[$0>>2] = $159;
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $161 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($161,32,533552,191,533832,$vararg_buffer1);
 STACKTOP = sp;return;
}
function __ZN5physx17ConvexMeshBuilder19computeHullPolygonsERKjPKNS_6PxVec3ES2_PS1_RNS_19PxAllocatorCallbackERjRPS3_S9_RPjS9_RPNS_13PxHullPolygonE($this,$nbVerts,$verts,$nbTriangles,$triangles,$inAllocator,$outNbVerts,$outVertices,$nbIndices,$indices,$nbPolygons,$polygons) {
 $this = $this|0;
 $nbVerts = $nbVerts|0;
 $verts = $verts|0;
 $nbTriangles = $nbTriangles|0;
 $triangles = $triangles|0;
 $inAllocator = $inAllocator|0;
 $outNbVerts = $outNbVerts|0;
 $outVertices = $outVertices|0;
 $nbIndices = $nbIndices|0;
 $indices = $indices|0;
 $nbPolygons = $nbPolygons|0;
 $polygons = $polygons|0;
 var $$0 = 0, $$pre = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0);
 var $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var $i$04 = 0, $i1$02 = 0, $i2$01 = 0, $phitmp = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 132|0);
 $1 = (__ZN5physx17ConvexHullBuilder19ComputeHullPolygonsERKjPKNS_6PxVec3ES2_PS1_($0,$nbVerts,$verts,$nbTriangles,$triangles)|0);
 if (!($1)) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,32,533552,283,534040,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 38|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 HEAP32[$outNbVerts>>2] = $7;
 $8 = (($4) + 39|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$nbPolygons>>2] = $10;
 $11 = HEAP32[$inAllocator>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$outNbVerts>>2]|0;
 $15 = ($14*12)|0;
 $16 = (FUNCTION_TABLE_iiiiii[$13 & 255]($inAllocator,$15,534168,533552,290)|0);
 HEAP32[$outVertices>>2] = $16;
 $17 = HEAP32[$0>>2]|0;
 $18 = HEAP32[$outNbVerts>>2]|0;
 $19 = ($18*12)|0;
 _memcpy(($16|0),($17|0),($19|0))|0;
 HEAP32[$nbIndices>>2] = 0;
 $20 = HEAP32[$nbPolygons>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $34 = 0;
 } else {
  $22 = (($this) + 136|0);
  $$pre9 = HEAP32[$22>>2]|0;
  $27 = 0;$i$04 = 0;
  while(1) {
   $23 = ((($$pre9) + (($i$04*20)|0)|0) + 18|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24&255;
   $26 = (($27) + ($25))|0;
   HEAP32[$nbIndices>>2] = $26;
   $28 = (($i$04) + 1)|0;
   $29 = HEAP32[$nbPolygons>>2]|0;
   $30 = ($28>>>0)<($29>>>0);
   if ($30) {
    $27 = $26;$i$04 = $28;
   } else {
    break;
   }
  }
  $phitmp = $26 << 2;
  $34 = $phitmp;
 }
 $31 = HEAP32[$inAllocator>>2]|0;
 $32 = (($31) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $35 = (FUNCTION_TABLE_iiiiii[$33 & 255]($inAllocator,$34,534176,533552,299)|0);
 HEAP32[$indices>>2] = $35;
 $36 = HEAP32[$nbIndices>>2]|0;
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = (($this) + 140|0);
  $$pre8 = HEAP32[$38>>2]|0;
  $i1$02 = 0;
  while(1) {
   $39 = (($$pre8) + ($i1$02)|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40&255;
   $42 = (($35) + ($i1$02<<2)|0);
   HEAP32[$42>>2] = $41;
   $43 = (($i1$02) + 1)|0;
   $44 = HEAP32[$nbIndices>>2]|0;
   $45 = ($43>>>0)<($44>>>0);
   if ($45) {
    $i1$02 = $43;
   } else {
    break;
   }
  }
 }
 $46 = HEAP32[$inAllocator>>2]|0;
 $47 = (($46) + 8|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$nbPolygons>>2]|0;
 $50 = ($49*20)|0;
 $51 = (FUNCTION_TABLE_iiiiii[$48 & 255]($inAllocator,$50,534184,533552,305)|0);
 HEAP32[$polygons>>2] = $51;
 $52 = HEAP32[$nbPolygons>>2]|0;
 $53 = ($52|0)==(0);
 if ($53) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $54 = (($this) + 136|0);
 $$pre = HEAP32[$54>>2]|0;
 $i2$01 = 0;
 while(1) {
  $55 = (($$pre) + (($i2$01*20)|0)|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($51) + (($i2$01*20)|0)|0);
  HEAPF32[$57>>2] = $56;
  $58 = ((($$pre) + (($i2$01*20)|0)|0) + 4|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($51) + (($i2$01*20)|0)|0) + 4|0);
  HEAPF32[$60>>2] = $59;
  $61 = ((($$pre) + (($i2$01*20)|0)|0) + 8|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = ((($51) + (($i2$01*20)|0)|0) + 8|0);
  HEAPF32[$63>>2] = $62;
  $64 = ((($$pre) + (($i2$01*20)|0)|0) + 12|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($51) + (($i2$01*20)|0)|0) + 12|0);
  HEAPF32[$66>>2] = $65;
  $67 = ((($$pre) + (($i2$01*20)|0)|0) + 18|0);
  $68 = HEAP8[$67>>0]|0;
  $69 = $68&255;
  $70 = ((($51) + (($i2$01*20)|0)|0) + 16|0);
  HEAP16[$70>>1] = $69;
  $71 = ((($$pre) + (($i2$01*20)|0)|0) + 16|0);
  $72 = HEAP16[$71>>1]|0;
  $73 = ((($51) + (($i2$01*20)|0)|0) + 18|0);
  HEAP16[$73>>1] = $72;
  $74 = (($i2$01) + 1)|0;
  $75 = ($74>>>0)<($52>>>0);
  if ($75) {
   $i2$01 = $74;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL15TestContainmentRKN5physx6PxVec3EPKfjPKNS_2Gu15HullPolygonDataE($localCenter,$extents,$nbPolys,$polygons) {
 $localCenter = $localCenter|0;
 $extents = $extents|0;
 $nbPolys = $nbPolys|0;
 $polygons = $polygons|0;
 var $$0 = 0, $$ph$us = Math_fround(0), $$ph46$us = Math_fround(0), $$ph47$us = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0);
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0;
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $i$048$us = 0, $p$050 = 0, $p$050$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($extents) + 4|0);
 $1 = (($extents) + 8|0);
 $2 = (($localCenter) + 4|0);
 $3 = (($localCenter) + 8|0);
 $4 = ($nbPolys|0)==(0);
 if ($4) {
  $p$050 = 0;
  while(1) {
   $96 = (($p$050) + 1)|0;
   $97 = ($96>>>0)<(8);
   if ($97) {
    $p$050 = $96;
   } else {
    $$0 = 1;
    break;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $100 = Math_fround(0.0);$98 = Math_fround(0.0);$99 = Math_fround(0.0);$p$050$us = 0;
 }
 L5: while(1) {
  switch ($p$050$us|0) {
  case 6:  {
   $14 = Math_fround(HEAPF32[$extents>>2]);
   $15 = Math_fround(HEAPF32[$0>>2]);
   $16 = Math_fround(HEAPF32[$1>>2]);
   $17 = Math_fround(HEAPF32[$localCenter>>2]);
   $18 = Math_fround($17 - $14);
   $19 = Math_fround(HEAPF32[$2>>2]);
   $20 = Math_fround($19 - $15);
   $21 = Math_fround(HEAPF32[$3>>2]);
   $22 = Math_fround($16 + $21);
   $$ph$us = $22;$$ph46$us = $20;$$ph47$us = $18;
   break;
  }
  case 3:  {
   $41 = Math_fround(HEAPF32[$extents>>2]);
   $42 = Math_fround(HEAPF32[$0>>2]);
   $43 = Math_fround(HEAPF32[$1>>2]);
   $44 = Math_fround(HEAPF32[$localCenter>>2]);
   $45 = Math_fround($41 + $44);
   $46 = Math_fround(HEAPF32[$2>>2]);
   $47 = Math_fround($46 - $42);
   $48 = Math_fround(HEAPF32[$3>>2]);
   $49 = Math_fround($48 - $43);
   $$ph$us = $49;$$ph46$us = $47;$$ph47$us = $45;
   break;
  }
  case 2:  {
   $50 = Math_fround(HEAPF32[$extents>>2]);
   $51 = Math_fround(HEAPF32[$0>>2]);
   $52 = Math_fround(HEAPF32[$1>>2]);
   $53 = Math_fround(HEAPF32[$localCenter>>2]);
   $54 = Math_fround($50 + $53);
   $55 = Math_fround(HEAPF32[$2>>2]);
   $56 = Math_fround($55 - $51);
   $57 = Math_fround(HEAPF32[$3>>2]);
   $58 = Math_fround($52 + $57);
   $$ph$us = $58;$$ph46$us = $56;$$ph47$us = $54;
   break;
  }
  case 7:  {
   $5 = Math_fround(HEAPF32[$extents>>2]);
   $6 = Math_fround(HEAPF32[$0>>2]);
   $7 = Math_fround(HEAPF32[$1>>2]);
   $8 = Math_fround(HEAPF32[$localCenter>>2]);
   $9 = Math_fround($8 - $5);
   $10 = Math_fround(HEAPF32[$2>>2]);
   $11 = Math_fround($10 - $6);
   $12 = Math_fround(HEAPF32[$3>>2]);
   $13 = Math_fround($12 - $7);
   $$ph$us = $13;$$ph46$us = $11;$$ph47$us = $9;
   break;
  }
  case 5:  {
   $23 = Math_fround(HEAPF32[$extents>>2]);
   $24 = Math_fround(HEAPF32[$0>>2]);
   $25 = Math_fround(HEAPF32[$1>>2]);
   $26 = Math_fround(HEAPF32[$localCenter>>2]);
   $27 = Math_fround($26 - $23);
   $28 = Math_fround(HEAPF32[$2>>2]);
   $29 = Math_fround($24 + $28);
   $30 = Math_fround(HEAPF32[$3>>2]);
   $31 = Math_fround($30 - $25);
   $$ph$us = $31;$$ph46$us = $29;$$ph47$us = $27;
   break;
  }
  case 0:  {
   $68 = Math_fround(HEAPF32[$extents>>2]);
   $69 = Math_fround(HEAPF32[$0>>2]);
   $70 = Math_fround(HEAPF32[$1>>2]);
   $71 = Math_fround(HEAPF32[$localCenter>>2]);
   $72 = Math_fround($68 + $71);
   $73 = Math_fround(HEAPF32[$2>>2]);
   $74 = Math_fround($69 + $73);
   $75 = Math_fround(HEAPF32[$3>>2]);
   $76 = Math_fround($70 + $75);
   $$ph$us = $76;$$ph46$us = $74;$$ph47$us = $72;
   break;
  }
  case 4:  {
   $32 = Math_fround(HEAPF32[$extents>>2]);
   $33 = Math_fround(HEAPF32[$0>>2]);
   $34 = Math_fround(HEAPF32[$1>>2]);
   $35 = Math_fround(HEAPF32[$localCenter>>2]);
   $36 = Math_fround($35 - $32);
   $37 = Math_fround(HEAPF32[$2>>2]);
   $38 = Math_fround($33 + $37);
   $39 = Math_fround(HEAPF32[$3>>2]);
   $40 = Math_fround($34 + $39);
   $$ph$us = $40;$$ph46$us = $38;$$ph47$us = $36;
   break;
  }
  case 1:  {
   $59 = Math_fround(HEAPF32[$extents>>2]);
   $60 = Math_fround(HEAPF32[$0>>2]);
   $61 = Math_fround(HEAPF32[$1>>2]);
   $62 = Math_fround(HEAPF32[$localCenter>>2]);
   $63 = Math_fround($59 + $62);
   $64 = Math_fround(HEAPF32[$2>>2]);
   $65 = Math_fround($60 + $64);
   $66 = Math_fround(HEAPF32[$3>>2]);
   $67 = Math_fround($66 - $61);
   $$ph$us = $67;$$ph46$us = $65;$$ph47$us = $63;
   break;
  }
  default: {
   $$ph$us = $100;$$ph46$us = $99;$$ph47$us = $98;
  }
  }
  $i$048$us = 0;
  while(1) {
   $81 = (($polygons) + (($i$048$us*20)|0)|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $83 = ((($polygons) + (($i$048$us*20)|0)|0) + 4|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   $85 = ((($polygons) + (($i$048$us*20)|0)|0) + 8|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   $87 = Math_fround($$ph47$us * $82);
   $88 = Math_fround($$ph46$us * $84);
   $89 = Math_fround($87 + $88);
   $90 = Math_fround($$ph$us * $86);
   $91 = Math_fround($89 + $90);
   $92 = ((($polygons) + (($i$048$us*20)|0)|0) + 12|0);
   $93 = Math_fround(HEAPF32[$92>>2]);
   $94 = Math_fround($93 + $91);
   $95 = $94 > Math_fround(0.0);
   $78 = (($i$048$us) + 1)|0;
   if ($95) {
    $$0 = 0;
    label = 16;
    break L5;
   }
   $77 = ($78>>>0)<($nbPolys>>>0);
   if ($77) {
    $i$048$us = $78;
   } else {
    break;
   }
  }
  $79 = (($p$050$us) + 1)|0;
  $80 = ($79>>>0)<(8);
  if ($80) {
   $100 = $$ph$us;$98 = $$ph47$us;$99 = $$ph46$us;$p$050$us = $79;
  } else {
   $$0 = 1;
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx12PxConvexMesh19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (534352|0);
}
function __ZNK5physx12PxConvexMesh8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(534352,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,534368)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Gu10ConvexMesh13getNbVerticesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 54|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx2Gu10ConvexMesh11getVerticesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 55|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = (($1) + (($4*20)|0)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK5physx2Gu10ConvexMesh14getIndexBufferEv($this) {
 $this = $this|0;
 var $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 55|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = (($1) + (($4*20)|0)|0);
 $6 = (($this) + 54|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = (($this) + 52|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = $10&65535;
 $12 = $11 << 1;
 $tmp2$i = ($8*15)|0;
 $$sum1$i = (($12) + ($tmp2$i))|0;
 $13 = (($5) + ($$sum1$i)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZNK5physx2Gu10ConvexMesh13getNbPolygonsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 55|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx2Gu10ConvexMesh14getLocalBoundsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $2 = (($agg$result) + 4|0);
 $3 = (($this) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$2>>2] = $4;
 $5 = (($agg$result) + 8|0);
 $6 = (($this) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 $8 = (($agg$result) + 12|0);
 $9 = (($this) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $10;
 $11 = (($agg$result) + 16|0);
 $12 = (($this) + 32|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$11>>2] = $13;
 $14 = (($agg$result) + 20|0);
 $15 = (($this) + 36|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$14>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu10ConvexMesh8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx28computeVolumeIntegralsEberlyERKNS_20PxSimpleTriangleMeshEfRNS_11PxIntegralsERKNS_6PxVec3E($mesh,$density,$integrals,$origin) {
 $mesh = $mesh|0;
 $density = Math_fround($density);
 $integrals = $integrals|0;
 $origin = $origin|0;
 var $$pre$phi72$iZ2D = 0, $$pre$phiZ2D = 0, $$pre40 = 0, $$pre49$i = 0, $$pre50$i = 0, $$sum$i = 0, $$sum$us$i = 0, $$sum2$i = 0, $$sum2$us$i = 0, $$sum3$i = 0, $$sum3$us$i = 0, $$sum4$i = 0, $$sum4$us$i = 0, $$sum5$i = 0, $$sum5$us$i = 0, $$sum6$i = 0, $$sum6$us$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0;
 var $119 = 0.0, $12 = Math_fround(0), $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0;
 var $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = Math_fround(0), $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0;
 var $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = Math_fround(0), $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0;
 var $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0;
 var $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0, $198 = 0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0, $206 = 0.0, $207 = 0.0, $208 = 0.0;
 var $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0.0, $221 = Math_fround(0), $222 = 0.0, $223 = Math_fround(0), $224 = 0, $225 = 0.0, $226 = Math_fround(0);
 var $227 = 0, $228 = 0.0, $229 = 0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0.0, $233 = 0, $234 = 0.0, $235 = 0, $236 = 0, $237 = 0.0, $238 = 0, $239 = 0, $24 = 0, $240 = 0.0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0);
 var $245 = Math_fround(0), $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0, $256 = Math_fround(0), $257 = 0.0, $258 = 0.0, $259 = 0.0, $26 = 0, $260 = 0, $261 = 0.0, $262 = 0.0;
 var $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0, $267 = 0, $268 = 0.0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0, $273 = 0, $274 = 0.0, $275 = 0.0, $276 = 0.0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0;
 var $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0;
 var $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0.0, $333 = 0.0, $334 = 0.0;
 var $335 = 0.0, $336 = 0.0, $337 = 0.0, $338 = 0.0, $339 = 0.0, $34 = 0, $340 = 0.0, $341 = 0.0, $342 = 0.0, $343 = 0.0, $344 = 0.0, $345 = 0.0, $346 = 0.0, $347 = 0.0, $348 = 0.0, $349 = 0.0, $35 = 0, $350 = 0.0, $351 = 0.0, $352 = 0.0;
 var $353 = 0.0, $354 = 0.0, $355 = 0.0, $356 = 0.0, $357 = 0.0, $358 = 0.0, $359 = 0.0, $36 = 0, $360 = 0.0, $361 = 0.0, $362 = 0.0, $363 = 0.0, $364 = 0.0, $365 = 0.0, $366 = 0.0, $367 = 0.0, $368 = 0.0, $369 = 0.0, $37 = Math_fround(0), $370 = 0.0;
 var $371 = 0.0, $372 = 0.0, $373 = 0.0, $374 = 0.0, $375 = 0.0, $376 = 0.0, $377 = 0.0, $378 = 0.0, $379 = 0.0, $38 = Math_fround(0), $380 = 0.0, $381 = 0.0, $382 = 0.0, $383 = 0.0, $384 = 0.0, $385 = 0.0, $386 = 0.0, $387 = 0.0, $388 = 0.0, $389 = 0.0;
 var $39 = 0, $390 = 0.0, $391 = 0.0, $392 = 0.0, $393 = 0.0, $394 = 0.0, $395 = 0.0, $396 = 0.0, $397 = 0.0, $398 = 0.0, $399 = 0.0, $4 = 0, $40 = Math_fround(0), $400 = 0.0, $401 = 0.0, $402 = 0.0, $403 = 0.0, $404 = 0.0, $405 = 0.0, $406 = 0.0;
 var $407 = 0.0, $408 = 0.0, $409 = 0.0, $41 = Math_fround(0), $410 = 0.0, $411 = 0.0, $412 = 0.0, $413 = 0.0, $414 = 0.0, $415 = 0.0, $416 = 0.0, $417 = 0.0, $418 = 0.0, $419 = 0.0, $42 = 0, $420 = 0.0, $421 = 0.0, $422 = 0.0, $423 = 0.0, $424 = 0.0;
 var $425 = 0.0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0.0, $43 = Math_fround(0), $430 = 0.0, $431 = 0.0, $432 = 0.0, $433 = 0.0, $434 = 0.0, $435 = 0.0, $436 = 0.0, $437 = 0.0, $438 = 0.0, $439 = 0.0, $44 = Math_fround(0), $440 = 0.0, $441 = 0.0, $442 = 0.0;
 var $443 = 0.0, $444 = 0.0, $445 = 0.0, $446 = 0.0, $447 = 0.0, $448 = 0.0, $449 = 0.0, $45 = 0, $450 = 0.0, $451 = 0.0, $452 = 0.0, $453 = 0.0, $454 = 0.0, $455 = 0.0, $456 = 0.0, $457 = 0.0, $458 = 0.0, $459 = 0.0, $46 = 0, $460 = 0.0;
 var $461 = 0.0, $462 = 0.0, $463 = 0.0, $464 = 0, $465 = 0, $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = 0.0, $474 = 0.0, $475 = 0.0, $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = 0.0;
 var $48 = Math_fround(0), $480 = 0.0, $481 = 0.0, $482 = Math_fround(0), $483 = Math_fround(0), $484 = 0.0, $485 = 0.0, $486 = 0.0, $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = 0.0, $491 = 0.0, $492 = 0.0, $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0.0, $497 = 0.0;
 var $498 = 0.0, $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0.0, $503 = 0.0, $504 = 0.0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0;
 var $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0;
 var $98 = 0.0, $99 = 0.0, $i$08$i = 0, $i$08$us$i = 0, $i0$0$i = 0, $i0$0$us$i = 0, $i1$0$i = 0, $i1$0$us$i = 0, $i2$0$i = 0, $i2$0$us$i = 0, $or$cond = 0, $or$cond$i = 0, $phitmp$i = 0, $phitmp73$i = 0, $trigPointer$09$i = 0, $trigPointer$09$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($mesh) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($mesh) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$pre40 = (($origin) + 4|0);
   $$pre$phi72$iZ2D = $origin;$$pre$phiZ2D = $$pre40;$200 = 0.0;$202 = 0.0;$204 = 0.0;$206 = 0.0;$208 = 0.0;$210 = 0.0;$212 = 0.0;$214 = 0.0;$216 = 0.0;$218 = 0.0;
  } else {
   $5 = (($mesh) + 24|0);
   $6 = HEAP16[$5>>1]|0;
   $7 = $6 & 1;
   $8 = ($7<<16>>16)==(0);
   $9 = (($mesh) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$mesh>>2]|0;
   $12 = Math_fround(HEAPF32[$origin>>2]);
   $13 = (($origin) + 4|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = (($origin) + 8|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = (($mesh) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   if ($8) {
    $287 = $6;$421 = 0.0;$424 = 0.0;$427 = 0.0;$430 = 0.0;$433 = 0.0;$436 = 0.0;$439 = 0.0;$447 = 0.0;$455 = 0.0;$463 = 0.0;$i$08$i = 1;$trigPointer$09$i = $1;
    while(1) {
     $286 = $287 & 2;
     $288 = ($286<<16>>16)==(0);
     if ($288) {
      $297 = HEAP32[$trigPointer$09$i>>2]|0;
      $298 = (($trigPointer$09$i) + 4|0);
      $299 = HEAP32[$298>>2]|0;
      $300 = (($trigPointer$09$i) + 8|0);
      $301 = HEAP32[$300>>2]|0;
      $i0$0$i = $297;$i1$0$i = $299;$i2$0$i = $301;
     } else {
      $289 = HEAP16[$trigPointer$09$i>>1]|0;
      $290 = $289&65535;
      $291 = (($trigPointer$09$i) + 2|0);
      $292 = HEAP16[$291>>1]|0;
      $293 = $292&65535;
      $294 = (($trigPointer$09$i) + 4|0);
      $295 = HEAP16[$294>>1]|0;
      $296 = $295&65535;
      $i0$0$i = $290;$i1$0$i = $293;$i2$0$i = $296;
     }
     $302 = Math_imul($i0$0$i, $11)|0;
     $303 = (($10) + ($302)|0);
     $304 = Math_fround(HEAPF32[$303>>2]);
     $305 = Math_fround($304 - $12);
     $$sum$i = (($302) + 4)|0;
     $306 = (($10) + ($$sum$i)|0);
     $307 = Math_fround(HEAPF32[$306>>2]);
     $308 = Math_fround($307 - $14);
     $$sum2$i = (($302) + 8)|0;
     $309 = (($10) + ($$sum2$i)|0);
     $310 = Math_fround(HEAPF32[$309>>2]);
     $311 = Math_fround($310 - $16);
     $312 = Math_imul($i1$0$i, $11)|0;
     $313 = (($10) + ($312)|0);
     $314 = Math_fround(HEAPF32[$313>>2]);
     $315 = Math_fround($314 - $12);
     $$sum3$i = (($312) + 4)|0;
     $316 = (($10) + ($$sum3$i)|0);
     $317 = Math_fround(HEAPF32[$316>>2]);
     $318 = Math_fround($317 - $14);
     $$sum4$i = (($312) + 8)|0;
     $319 = (($10) + ($$sum4$i)|0);
     $320 = Math_fround(HEAPF32[$319>>2]);
     $321 = Math_fround($320 - $16);
     $322 = Math_imul($i2$0$i, $11)|0;
     $323 = (($10) + ($322)|0);
     $324 = Math_fround(HEAPF32[$323>>2]);
     $325 = Math_fround($324 - $12);
     $$sum5$i = (($322) + 4)|0;
     $326 = (($10) + ($$sum5$i)|0);
     $327 = Math_fround(HEAPF32[$326>>2]);
     $328 = Math_fround($327 - $14);
     $$sum6$i = (($322) + 8)|0;
     $329 = (($10) + ($$sum6$i)|0);
     $330 = Math_fround(HEAPF32[$329>>2]);
     $331 = Math_fround($330 - $16);
     $332 = +$305;
     $333 = +$308;
     $334 = +$311;
     $335 = +$315;
     $336 = +$318;
     $337 = +$321;
     $338 = +$325;
     $339 = +$328;
     $340 = +$331;
     $341 = $335 - $332;
     $342 = $336 - $333;
     $343 = $337 - $334;
     $344 = $338 - $332;
     $345 = $339 - $333;
     $346 = $340 - $334;
     $347 = $342 * $346;
     $348 = $343 * $345;
     $349 = $347 - $348;
     $350 = $343 * $344;
     $351 = $341 * $346;
     $352 = $350 - $351;
     $353 = $341 * $345;
     $354 = $342 * $344;
     $355 = $353 - $354;
     $356 = $332 + $335;
     $357 = $356 + $338;
     $358 = $332 * $332;
     $359 = $335 * $356;
     $360 = $358 + $359;
     $361 = $338 * $357;
     $362 = $360 + $361;
     $363 = $332 * $358;
     $364 = $335 * $360;
     $365 = $363 + $364;
     $366 = $338 * $362;
     $367 = $365 + $366;
     $368 = $332 + $357;
     $369 = $332 * $368;
     $370 = $362 + $369;
     $371 = $335 + $357;
     $372 = $335 * $371;
     $373 = $362 + $372;
     $374 = $338 + $357;
     $375 = $338 * $374;
     $376 = $362 + $375;
     $377 = $333 + $336;
     $378 = $377 + $339;
     $379 = $333 * $333;
     $380 = $336 * $377;
     $381 = $379 + $380;
     $382 = $339 * $378;
     $383 = $381 + $382;
     $384 = $333 * $379;
     $385 = $336 * $381;
     $386 = $384 + $385;
     $387 = $339 * $383;
     $388 = $386 + $387;
     $389 = $333 + $378;
     $390 = $333 * $389;
     $391 = $383 + $390;
     $392 = $336 + $378;
     $393 = $336 * $392;
     $394 = $383 + $393;
     $395 = $339 + $378;
     $396 = $339 * $395;
     $397 = $383 + $396;
     $398 = $334 + $337;
     $399 = $398 + $340;
     $400 = $334 * $334;
     $401 = $337 * $398;
     $402 = $400 + $401;
     $403 = $340 * $399;
     $404 = $402 + $403;
     $405 = $334 * $400;
     $406 = $337 * $402;
     $407 = $405 + $406;
     $408 = $340 * $404;
     $409 = $407 + $408;
     $410 = $334 + $399;
     $411 = $334 * $410;
     $412 = $404 + $411;
     $413 = $337 + $399;
     $414 = $337 * $413;
     $415 = $404 + $414;
     $416 = $340 + $399;
     $417 = $340 * $416;
     $418 = $404 + $417;
     $419 = $357 * $349;
     $420 = $421 + $419;
     $422 = $362 * $349;
     $423 = $424 + $422;
     $425 = $383 * $352;
     $426 = $427 + $425;
     $428 = $355 * $404;
     $429 = $430 + $428;
     $431 = $349 * $367;
     $432 = $433 + $431;
     $434 = $352 * $388;
     $435 = $436 + $434;
     $437 = $355 * $409;
     $438 = $439 + $437;
     $440 = $333 * $370;
     $441 = $336 * $373;
     $442 = $440 + $441;
     $443 = $339 * $376;
     $444 = $443 + $442;
     $445 = $349 * $444;
     $446 = $447 + $445;
     $448 = $334 * $391;
     $449 = $337 * $394;
     $450 = $448 + $449;
     $451 = $340 * $397;
     $452 = $451 + $450;
     $453 = $352 * $452;
     $454 = $455 + $453;
     $456 = $332 * $412;
     $457 = $335 * $415;
     $458 = $456 + $457;
     $459 = $338 * $418;
     $460 = $459 + $458;
     $461 = $355 * $460;
     $462 = $463 + $461;
     $464 = ($i$08$i>>>0)<($3>>>0);
     if (!($464)) {
      $$pre$phi72$iZ2D = $origin;$$pre$phiZ2D = $13;$200 = $420;$202 = $423;$204 = $426;$206 = $429;$208 = $432;$210 = $435;$212 = $438;$214 = $446;$216 = $454;$218 = $462;
      break L1;
     }
     $465 = (($trigPointer$09$i) + ($18)|0);
     $$pre49$i = HEAP16[$5>>1]|0;
     $phitmp73$i = (($i$08$i) + 1)|0;
     $287 = $$pre49$i;$421 = $420;$424 = $423;$427 = $426;$430 = $429;$433 = $432;$436 = $435;$439 = $438;$447 = $446;$455 = $454;$463 = $462;$i$08$i = $phitmp73$i;$trigPointer$09$i = $465;
    }
   } else {
    $154 = 0.0;$157 = 0.0;$160 = 0.0;$163 = 0.0;$166 = 0.0;$169 = 0.0;$172 = 0.0;$180 = 0.0;$188 = 0.0;$196 = 0.0;$20 = $6;$i$08$us$i = 1;$trigPointer$09$us$i = $1;
    while(1) {
     $19 = $20 & 2;
     $21 = ($19<<16>>16)==(0);
     if ($21) {
      $30 = HEAP32[$trigPointer$09$us$i>>2]|0;
      $31 = (($trigPointer$09$us$i) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($trigPointer$09$us$i) + 8|0);
      $34 = HEAP32[$33>>2]|0;
      $i0$0$us$i = $30;$i1$0$us$i = $32;$i2$0$us$i = $34;
     } else {
      $22 = HEAP16[$trigPointer$09$us$i>>1]|0;
      $23 = $22&65535;
      $24 = (($trigPointer$09$us$i) + 2|0);
      $25 = HEAP16[$24>>1]|0;
      $26 = $25&65535;
      $27 = (($trigPointer$09$us$i) + 4|0);
      $28 = HEAP16[$27>>1]|0;
      $29 = $28&65535;
      $i0$0$us$i = $23;$i1$0$us$i = $26;$i2$0$us$i = $29;
     }
     $35 = Math_imul($i0$0$us$i, $11)|0;
     $36 = (($10) + ($35)|0);
     $37 = Math_fround(HEAPF32[$36>>2]);
     $38 = Math_fround($37 - $12);
     $$sum$us$i = (($35) + 4)|0;
     $39 = (($10) + ($$sum$us$i)|0);
     $40 = Math_fround(HEAPF32[$39>>2]);
     $41 = Math_fround($40 - $14);
     $$sum2$us$i = (($35) + 8)|0;
     $42 = (($10) + ($$sum2$us$i)|0);
     $43 = Math_fround(HEAPF32[$42>>2]);
     $44 = Math_fround($43 - $16);
     $45 = Math_imul($i2$0$us$i, $11)|0;
     $46 = (($10) + ($45)|0);
     $47 = Math_fround(HEAPF32[$46>>2]);
     $48 = Math_fround($47 - $12);
     $$sum3$us$i = (($45) + 4)|0;
     $49 = (($10) + ($$sum3$us$i)|0);
     $50 = Math_fround(HEAPF32[$49>>2]);
     $51 = Math_fround($50 - $14);
     $$sum4$us$i = (($45) + 8)|0;
     $52 = (($10) + ($$sum4$us$i)|0);
     $53 = Math_fround(HEAPF32[$52>>2]);
     $54 = Math_fround($53 - $16);
     $55 = Math_imul($i1$0$us$i, $11)|0;
     $56 = (($10) + ($55)|0);
     $57 = Math_fround(HEAPF32[$56>>2]);
     $58 = Math_fround($57 - $12);
     $$sum5$us$i = (($55) + 4)|0;
     $59 = (($10) + ($$sum5$us$i)|0);
     $60 = Math_fround(HEAPF32[$59>>2]);
     $61 = Math_fround($60 - $14);
     $$sum6$us$i = (($55) + 8)|0;
     $62 = (($10) + ($$sum6$us$i)|0);
     $63 = Math_fround(HEAPF32[$62>>2]);
     $64 = Math_fround($63 - $16);
     $65 = +$38;
     $66 = +$41;
     $67 = +$44;
     $68 = +$48;
     $69 = +$51;
     $70 = +$54;
     $71 = +$58;
     $72 = +$61;
     $73 = +$64;
     $74 = $68 - $65;
     $75 = $69 - $66;
     $76 = $70 - $67;
     $77 = $71 - $65;
     $78 = $72 - $66;
     $79 = $73 - $67;
     $80 = $75 * $79;
     $81 = $76 * $78;
     $82 = $80 - $81;
     $83 = $76 * $77;
     $84 = $74 * $79;
     $85 = $83 - $84;
     $86 = $74 * $78;
     $87 = $75 * $77;
     $88 = $86 - $87;
     $89 = $65 + $68;
     $90 = $89 + $71;
     $91 = $65 * $65;
     $92 = $68 * $89;
     $93 = $91 + $92;
     $94 = $71 * $90;
     $95 = $93 + $94;
     $96 = $65 * $91;
     $97 = $68 * $93;
     $98 = $96 + $97;
     $99 = $71 * $95;
     $100 = $98 + $99;
     $101 = $65 + $90;
     $102 = $65 * $101;
     $103 = $95 + $102;
     $104 = $68 + $90;
     $105 = $68 * $104;
     $106 = $95 + $105;
     $107 = $71 + $90;
     $108 = $71 * $107;
     $109 = $95 + $108;
     $110 = $66 + $69;
     $111 = $110 + $72;
     $112 = $66 * $66;
     $113 = $69 * $110;
     $114 = $112 + $113;
     $115 = $72 * $111;
     $116 = $114 + $115;
     $117 = $66 * $112;
     $118 = $69 * $114;
     $119 = $117 + $118;
     $120 = $72 * $116;
     $121 = $119 + $120;
     $122 = $66 + $111;
     $123 = $66 * $122;
     $124 = $116 + $123;
     $125 = $69 + $111;
     $126 = $69 * $125;
     $127 = $116 + $126;
     $128 = $72 + $111;
     $129 = $72 * $128;
     $130 = $116 + $129;
     $131 = $67 + $70;
     $132 = $131 + $73;
     $133 = $67 * $67;
     $134 = $70 * $131;
     $135 = $133 + $134;
     $136 = $73 * $132;
     $137 = $135 + $136;
     $138 = $67 * $133;
     $139 = $70 * $135;
     $140 = $138 + $139;
     $141 = $73 * $137;
     $142 = $140 + $141;
     $143 = $67 + $132;
     $144 = $67 * $143;
     $145 = $137 + $144;
     $146 = $70 + $132;
     $147 = $70 * $146;
     $148 = $137 + $147;
     $149 = $73 + $132;
     $150 = $73 * $149;
     $151 = $137 + $150;
     $152 = $90 * $82;
     $153 = $154 + $152;
     $155 = $95 * $82;
     $156 = $157 + $155;
     $158 = $116 * $85;
     $159 = $160 + $158;
     $161 = $88 * $137;
     $162 = $163 + $161;
     $164 = $82 * $100;
     $165 = $166 + $164;
     $167 = $85 * $121;
     $168 = $169 + $167;
     $170 = $88 * $142;
     $171 = $172 + $170;
     $173 = $66 * $103;
     $174 = $69 * $106;
     $175 = $173 + $174;
     $176 = $72 * $109;
     $177 = $176 + $175;
     $178 = $82 * $177;
     $179 = $180 + $178;
     $181 = $67 * $124;
     $182 = $70 * $127;
     $183 = $181 + $182;
     $184 = $73 * $130;
     $185 = $184 + $183;
     $186 = $85 * $185;
     $187 = $188 + $186;
     $189 = $65 * $145;
     $190 = $68 * $148;
     $191 = $189 + $190;
     $192 = $71 * $151;
     $193 = $192 + $191;
     $194 = $88 * $193;
     $195 = $196 + $194;
     $197 = ($i$08$us$i>>>0)<($3>>>0);
     if (!($197)) {
      $$pre$phi72$iZ2D = $origin;$$pre$phiZ2D = $13;$200 = $153;$202 = $156;$204 = $159;$206 = $162;$208 = $165;$210 = $168;$212 = $171;$214 = $179;$216 = $187;$218 = $195;
      break L1;
     }
     $198 = (($trigPointer$09$us$i) + ($18)|0);
     $$pre50$i = HEAP16[$5>>1]|0;
     $phitmp$i = (($i$08$us$i) + 1)|0;
     $154 = $153;$157 = $156;$160 = $159;$163 = $162;$166 = $165;$169 = $168;$172 = $171;$180 = $179;$188 = $187;$196 = $195;$20 = $$pre50$i;$i$08$us$i = $phitmp$i;$trigPointer$09$us$i = $198;
    }
   }
  }
 } while(0);
 $199 = $200 * 0.166666671633720397949;
 $201 = $202 * 0.0416666679084300994873;
 $203 = $204 * 0.0416666679084300994873;
 $205 = $206 * 0.0416666679084300994873;
 $207 = $208 * 0.0166666675359010696411;
 $209 = $210 * 0.0166666675359010696411;
 $211 = $212 * 0.0166666675359010696411;
 $213 = $214 * 0.00833333376795053482056;
 $215 = $216 * 0.00833333376795053482056;
 $217 = $218 * 0.00833333376795053482056;
 $219 = (($integrals) + 16|0);
 HEAPF64[$219>>3] = $199;
 $220 = $201 / $199;
 $221 = Math_fround($220);
 HEAPF32[$integrals>>2] = $221;
 $222 = $203 / $199;
 $223 = Math_fround($222);
 $224 = (($integrals) + 4|0);
 HEAPF32[$224>>2] = $223;
 $225 = $205 / $199;
 $226 = Math_fround($225);
 $227 = (($integrals) + 8|0);
 HEAPF32[$227>>2] = $226;
 $228 = $211 + $209;
 $229 = (($integrals) + 24|0);
 HEAPF64[$229>>3] = $228;
 $230 = $211 + $207;
 $231 = (($integrals) + 56|0);
 HEAPF64[$231>>3] = $230;
 $232 = $209 + $207;
 $233 = (($integrals) + 88|0);
 HEAPF64[$233>>3] = $232;
 $234 = -$213;
 $235 = (($integrals) + 48|0);
 HEAPF64[$235>>3] = $234;
 $236 = (($integrals) + 32|0);
 HEAPF64[$236>>3] = $234;
 $237 = -$215;
 $238 = (($integrals) + 80|0);
 HEAPF64[$238>>3] = $237;
 $239 = (($integrals) + 64|0);
 HEAPF64[$239>>3] = $237;
 $240 = -$217;
 $241 = (($integrals) + 72|0);
 HEAPF64[$241>>3] = $240;
 $242 = (($integrals) + 40|0);
 HEAPF64[$242>>3] = $240;
 $243 = Math_fround($223 * $223);
 $244 = Math_fround($226 * $226);
 $245 = Math_fround($243 + $244);
 $246 = +$245;
 $247 = $199 * $246;
 $248 = $228 - $247;
 $249 = (($integrals) + 96|0);
 HEAPF64[$249>>3] = $248;
 $250 = Math_fround($221 * $221);
 $251 = Math_fround($250 + $244);
 $252 = +$251;
 $253 = $199 * $252;
 $254 = $230 - $253;
 $255 = (($integrals) + 128|0);
 HEAPF64[$255>>3] = $254;
 $256 = Math_fround($250 + $243);
 $257 = +$256;
 $258 = $199 * $257;
 $259 = $232 - $258;
 $260 = (($integrals) + 160|0);
 HEAPF64[$260>>3] = $259;
 $261 = +$221;
 $262 = $199 * $261;
 $263 = +$223;
 $264 = $262 * $263;
 $265 = $264 - $213;
 $266 = (($integrals) + 120|0);
 HEAPF64[$266>>3] = $265;
 $267 = (($integrals) + 104|0);
 HEAPF64[$267>>3] = $265;
 $268 = $199 * $263;
 $269 = +$226;
 $270 = $268 * $269;
 $271 = $270 - $215;
 $272 = (($integrals) + 152|0);
 HEAPF64[$272>>3] = $271;
 $273 = (($integrals) + 136|0);
 HEAPF64[$273>>3] = $271;
 $274 = $199 * $269;
 $275 = $261 * $274;
 $276 = $275 - $217;
 $277 = (($integrals) + 144|0);
 HEAPF64[$277>>3] = $276;
 $278 = (($integrals) + 112|0);
 HEAPF64[$278>>3] = $276;
 $279 = Math_fround(HEAPF32[$$pre$phi72$iZ2D>>2]);
 $280 = $279 == Math_fround(0.0);
 $281 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $282 = $281 == Math_fround(0.0);
 $or$cond$i = $280 & $282;
 $283 = (($origin) + 8|0);
 $284 = Math_fround(HEAPF32[$283>>2]);
 $285 = $284 == Math_fround(0.0);
 $or$cond = $or$cond$i & $285;
 if ($or$cond) {
  STACKTOP = sp;return 1;
 }
 $466 = Math_fround($221 + $279);
 $467 = Math_fround($223 + $281);
 $468 = Math_fround($226 + $284);
 $469 = Math_fround($467 * $467);
 $470 = Math_fround($468 * $468);
 $471 = Math_fround($469 + $470);
 $472 = Math_fround($245 - $471);
 $473 = +$472;
 $474 = $199 * $473;
 $475 = $228 - $474;
 HEAPF64[$229>>3] = $475;
 $476 = Math_fround($466 * $466);
 $477 = Math_fround($476 + $470);
 $478 = Math_fround($251 - $477);
 $479 = +$478;
 $480 = $199 * $479;
 $481 = $230 - $480;
 HEAPF64[$231>>3] = $481;
 $482 = Math_fround($476 + $469);
 $483 = Math_fround($256 - $482);
 $484 = +$483;
 $485 = $199 * $484;
 $486 = $232 - $485;
 HEAPF64[$233>>3] = $486;
 $487 = Math_fround($221 * $223);
 $488 = Math_fround($466 * $467);
 $489 = Math_fround($487 - $488);
 $490 = +$489;
 $491 = $199 * $490;
 $492 = $491 - $213;
 HEAPF64[$235>>3] = $492;
 HEAPF64[$236>>3] = $492;
 $493 = Math_fround($223 * $226);
 $494 = Math_fround($467 * $468);
 $495 = Math_fround($493 - $494);
 $496 = +$495;
 $497 = $199 * $496;
 $498 = $497 - $215;
 HEAPF64[$238>>3] = $498;
 HEAPF64[$239>>3] = $498;
 $499 = Math_fround($221 * $226);
 $500 = Math_fround($466 * $468);
 $501 = Math_fround($499 - $500);
 $502 = +$501;
 $503 = $199 * $502;
 $504 = $503 - $217;
 HEAPF64[$241>>3] = $504;
 HEAPF64[$242>>3] = $504;
 HEAPF32[$integrals>>2] = $466;
 HEAPF32[$224>>2] = $467;
 HEAPF32[$227>>2] = $468;
 STACKTOP = sp;return 1;
}
function __ZN5physx7ConvexHC2Eiii($this,$vertices_size,$edges_size,$facets_size) {
 $this = $this|0;
 $vertices_size = $vertices_size|0;
 $edges_size = $edges_size|0;
 $facets_size = $facets_size|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 2|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$this>>2] = 0;
 $5 = ($vertices_size|0)==(0);
 if (!($5)) {
  HEAP32[$4>>2] = $vertices_size;
  $6 = ($vertices_size*12)|0;
  $7 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$6,534704,153)|0);
  HEAP32[$this>>2] = $7;
  $8 = HEAP32[$3>>2]|0;
  $9 = ($8|0)>(0);
  if ($9) {
   ;HEAP32[$7+0>>2]=HEAP32[0+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[0+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[0+8>>2]|0;
   $10 = HEAP32[$3>>2]|0;
   $11 = ($10|0)>(1);
   if ($11) {
    $13 = 1;
    while(1) {
     $$pre$i$i$i = HEAP32[$this>>2]|0;
     $12 = (($$pre$i$i$i) + (($13*12)|0)|0);
     $14 = (0 + (($13*12)|0)|0);
     ;HEAP32[$12+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$14+8>>2]|0;
     $15 = (($13) + 1)|0;
     $16 = HEAP32[$3>>2]|0;
     $17 = ($15|0)<($16|0);
     if ($17) {
      $13 = $15;
     } else {
      break;
     }
    }
   }
  }
 }
 $18 = (($this) + 16|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 12|0);
 HEAP32[$20>>2] = 0;
 $21 = ($edges_size|0)==(0);
 if (!($21)) {
  HEAP32[$19>>2] = $edges_size;
  $22 = $edges_size << 2;
  $23 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$22,534704,153)|0);
  HEAP32[$20>>2] = $23;
  $24 = HEAP32[$18>>2]|0;
  $25 = ($24|0)>(0);
  if ($25) {
   HEAP16[$23>>1]=0&65535;HEAP16[$23+2>>1]=0>>>16;
   $26 = HEAP32[$18>>2]|0;
   $27 = ($26|0)>(1);
   if ($27) {
    $29 = 1;
    while(1) {
     $$pre$i$i$i2 = HEAP32[$20>>2]|0;
     $28 = (($$pre$i$i$i2) + ($29<<2)|0);
     $30 = (0 + ($29<<2)|0);
     $31 = HEAP32[$30>>2]|0;
     HEAP16[$28>>1]=$31&65535;HEAP16[$28+2>>1]=$31>>>16;
     $32 = (($29) + 1)|0;
     $33 = HEAP32[$18>>2]|0;
     $34 = ($32|0)<($33|0);
     if ($34) {
      $29 = $32;
     } else {
      break;
     }
    }
   }
  }
 }
 $35 = (($this) + 28|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 32|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 24|0);
 HEAP32[$37>>2] = 0;
 $38 = ($facets_size|0)==(0);
 if ($38) {
  HEAP32[$3>>2] = $vertices_size;
  HEAP32[$18>>2] = $edges_size;
  HEAP32[$35>>2] = $facets_size;
  STACKTOP = sp;return;
 }
 HEAP32[$36>>2] = $facets_size;
 $39 = $facets_size << 4;
 $40 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$39,534704,153)|0);
 HEAP32[$37>>2] = $40;
 $41 = HEAP32[$35>>2]|0;
 $42 = ($41|0)>(0);
 if (!($42)) {
  HEAP32[$3>>2] = $vertices_size;
  HEAP32[$18>>2] = $edges_size;
  HEAP32[$35>>2] = $facets_size;
  STACKTOP = sp;return;
 }
 ;HEAP32[$40+0>>2]=HEAP32[0+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[0+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[0+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[0+12>>2]|0;
 $43 = HEAP32[$35>>2]|0;
 $44 = ($43|0)>(1);
 if ($44) {
  $46 = 1;
 } else {
  HEAP32[$3>>2] = $vertices_size;
  HEAP32[$18>>2] = $edges_size;
  HEAP32[$35>>2] = $facets_size;
  STACKTOP = sp;return;
 }
 while(1) {
  $$pre$i$i$i5 = HEAP32[$37>>2]|0;
  $45 = (($$pre$i$i$i5) + ($46<<4)|0);
  $47 = (0 + ($46<<4)|0);
  ;HEAP32[$45+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$47+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$47+12>>2]|0;
  $48 = (($46) + 1)|0;
  $49 = HEAP32[$35>>2]|0;
  $50 = ($48|0)<($49|0);
  if ($50) {
   $46 = $48;
  } else {
   break;
  }
 }
 HEAP32[$3>>2] = $vertices_size;
 HEAP32[$18>>2] = $edges_size;
 HEAP32[$35>>2] = $facets_size;
 STACKTOP = sp;return;
}
function __ZN5physx11HullLibraryC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,12,534392,1420)|0);
 HEAP32[$this>>2] = $1;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($1) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx11HullLibraryD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
  HEAP32[$2>>2] = 0;
 }
 $5 = (($2) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($2) + 8|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$2>>2] = 0;
 $7 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
 STACKTOP = sp;return;
}
function __ZN5physx11HullLibrary6b2bfixEPNS_3TriES2_($this,$s,$t) {
 $this = $this|0;
 $s = $s|0;
 $t = $t|0;
 var $$0$i = 0, $$0$i14 = 0, $$0$i19 = 0, $$0$i24 = 0, $$0$i4 = 0, $$0$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$02$i = 0, $i$02$i1 = 0, $i$02$i11 = 0, $i$02$i16 = 0, $i$02$i21 = 0, $i$02$i6 = 0, $i$043 = 0;
 var $tmp = 0, $tmp$i = 0, $tmp$i12 = 0, $tmp$i17 = 0, $tmp$i2 = 0, $tmp$i22 = 0, $tmp$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$this>>2]|0;
 $2 = (($s) + 12|0);
 $3 = HEAP32[$1>>2]|0;
 $i$043 = 0;
 while(1) {
  $4 = (($i$043) + 1)|0;
  $5 = ($4|0)==(3);
  $tmp = $5 ? 0 : $4;
  $6 = (($i$043) + 2)|0;
  $7 = (($6|0) % 3)&-1;
  $8 = (($s) + ($tmp<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($s) + ($7<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $i$02$i21 = 0;
  while(1) {
   $12 = (($i$02$i21) + 1)|0;
   $13 = ($12|0)==(3);
   $tmp$i22 = $13 ? 0 : $12;
   $14 = (($i$02$i21) + 2)|0;
   $15 = (($14|0) % 3)&-1;
   $16 = (($t) + ($i$02$i21<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==($11|0);
   if ($18) {
    $19 = (($t) + ($tmp$i22<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($9|0);
    if ($21) {
     label = 5;
     break;
    }
   }
   $23 = ($17|0)==($9|0);
   if ($23) {
    $25 = (($t) + ($tmp$i22<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==($11|0);
    if ($27) {
     label = 9;
     break;
    }
   }
   $24 = ($12|0)<(3);
   if ($24) {
    $i$02$i21 = $12;
   } else {
    $$0$i24 = 534384;
    break;
   }
  }
  if ((label|0) == 5) {
   label = 0;
   $22 = (($0) + ($15<<2)|0);
   $$0$i24 = $22;
  }
  else if ((label|0) == 9) {
   label = 0;
   $28 = (($0) + ($15<<2)|0);
   $$0$i24 = $28;
  }
  $29 = HEAP32[$$0$i24>>2]|0;
  $i$02$i16 = 0;
  while(1) {
   $30 = (($i$02$i16) + 1)|0;
   $31 = ($30|0)==(3);
   $tmp$i17 = $31 ? 0 : $30;
   $32 = (($i$02$i16) + 2)|0;
   $33 = (($32|0) % 3)&-1;
   $34 = (($s) + ($i$02$i16<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($9|0);
   if ($36) {
    $37 = (($s) + ($tmp$i17<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)==($11|0);
    if ($39) {
     label = 13;
     break;
    }
   }
   $41 = ($35|0)==($11|0);
   if ($41) {
    $43 = (($s) + ($tmp$i17<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==($9|0);
    if ($45) {
     label = 17;
     break;
    }
   }
   $42 = ($30|0)<(3);
   if ($42) {
    $i$02$i16 = $30;
   } else {
    $$0$i19 = 534384;
    break;
   }
  }
  if ((label|0) == 13) {
   label = 0;
   $40 = (($2) + ($33<<2)|0);
   $$0$i19 = $40;
  }
  else if ((label|0) == 17) {
   label = 0;
   $46 = (($2) + ($33<<2)|0);
   $$0$i19 = $46;
  }
  $47 = HEAP32[$$0$i19>>2]|0;
  $48 = (($3) + ($47<<2)|0);
  $49 = HEAP32[$48>>2]|0;
  $i$02$i11 = 0;
  while(1) {
   $50 = (($i$02$i11) + 1)|0;
   $51 = ($50|0)==(3);
   $tmp$i12 = $51 ? 0 : $50;
   $52 = (($i$02$i11) + 2)|0;
   $53 = (($52|0) % 3)&-1;
   $54 = (($49) + ($i$02$i11<<2)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==($11|0);
   if ($56) {
    $57 = (($49) + ($tmp$i12<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($58|0)==($9|0);
    if ($59) {
     label = 21;
     break;
    }
   }
   $62 = ($55|0)==($9|0);
   if ($62) {
    $64 = (($49) + ($tmp$i12<<2)|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65|0)==($11|0);
    if ($66) {
     label = 25;
     break;
    }
   }
   $63 = ($50|0)<(3);
   if ($63) {
    $i$02$i11 = $50;
   } else {
    $$0$i14 = 534384;
    break;
   }
  }
  if ((label|0) == 21) {
   label = 0;
   $60 = (($49) + 12|0);
   $61 = (($60) + ($53<<2)|0);
   $$0$i14 = $61;
  }
  else if ((label|0) == 25) {
   label = 0;
   $67 = (($49) + 12|0);
   $68 = (($67) + ($53<<2)|0);
   $$0$i14 = $68;
  }
  HEAP32[$$0$i14>>2] = $29;
  $i$02$i6 = 0;
  while(1) {
   $69 = (($i$02$i6) + 1)|0;
   $70 = ($69|0)==(3);
   $tmp$i7 = $70 ? 0 : $69;
   $71 = (($i$02$i6) + 2)|0;
   $72 = (($71|0) % 3)&-1;
   $73 = (($s) + ($i$02$i6<<2)|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==($9|0);
   if ($75) {
    $76 = (($s) + ($tmp$i7<<2)|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = ($77|0)==($11|0);
    if ($78) {
     label = 29;
     break;
    }
   }
   $80 = ($74|0)==($11|0);
   if ($80) {
    $82 = (($s) + ($tmp$i7<<2)|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($83|0)==($9|0);
    if ($84) {
     label = 33;
     break;
    }
   }
   $81 = ($69|0)<(3);
   if ($81) {
    $i$02$i6 = $69;
   } else {
    $$0$i9 = 534384;
    break;
   }
  }
  if ((label|0) == 29) {
   label = 0;
   $79 = (($2) + ($72<<2)|0);
   $$0$i9 = $79;
  }
  else if ((label|0) == 33) {
   label = 0;
   $85 = (($2) + ($72<<2)|0);
   $$0$i9 = $85;
  }
  $86 = HEAP32[$$0$i9>>2]|0;
  $i$02$i1 = 0;
  while(1) {
   $87 = (($i$02$i1) + 1)|0;
   $88 = ($87|0)==(3);
   $tmp$i2 = $88 ? 0 : $87;
   $89 = (($i$02$i1) + 2)|0;
   $90 = (($89|0) % 3)&-1;
   $91 = (($t) + ($i$02$i1<<2)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ($92|0)==($11|0);
   if ($93) {
    $94 = (($t) + ($tmp$i2<<2)|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==($9|0);
    if ($96) {
     label = 37;
     break;
    }
   }
   $98 = ($92|0)==($9|0);
   if ($98) {
    $100 = (($t) + ($tmp$i2<<2)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ($101|0)==($11|0);
    if ($102) {
     label = 41;
     break;
    }
   }
   $99 = ($87|0)<(3);
   if ($99) {
    $i$02$i1 = $87;
   } else {
    $$0$i4 = 534384;
    break;
   }
  }
  if ((label|0) == 37) {
   label = 0;
   $97 = (($0) + ($90<<2)|0);
   $$0$i4 = $97;
  }
  else if ((label|0) == 41) {
   label = 0;
   $103 = (($0) + ($90<<2)|0);
   $$0$i4 = $103;
  }
  $104 = HEAP32[$$0$i4>>2]|0;
  $105 = (($3) + ($104<<2)|0);
  $106 = HEAP32[$105>>2]|0;
  $i$02$i = 0;
  while(1) {
   $107 = (($i$02$i) + 1)|0;
   $108 = ($107|0)==(3);
   $tmp$i = $108 ? 0 : $107;
   $109 = (($i$02$i) + 2)|0;
   $110 = (($109|0) % 3)&-1;
   $111 = (($106) + ($i$02$i<<2)|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ($112|0)==($9|0);
   if ($113) {
    $114 = (($106) + ($tmp$i<<2)|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = ($115|0)==($11|0);
    if ($116) {
     label = 45;
     break;
    }
   }
   $119 = ($112|0)==($11|0);
   if ($119) {
    $121 = (($106) + ($tmp$i<<2)|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = ($122|0)==($9|0);
    if ($123) {
     label = 49;
     break;
    }
   }
   $120 = ($107|0)<(3);
   if ($120) {
    $i$02$i = $107;
   } else {
    $$0$i = 534384;
    break;
   }
  }
  if ((label|0) == 45) {
   label = 0;
   $117 = (($106) + 12|0);
   $118 = (($117) + ($110<<2)|0);
   $$0$i = $118;
  }
  else if ((label|0) == 49) {
   label = 0;
   $124 = (($106) + 12|0);
   $125 = (($124) + ($110<<2)|0);
   $$0$i = $125;
  }
  HEAP32[$$0$i>>2] = $86;
  $exitcond = ($4|0)==(3);
  if ($exitcond) {
   break;
  } else {
   $i$043 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx11HullLibrary7extrudeEPNS_3TriEi($this,$t0,$v) {
 $this = $this|0;
 $t0 = $t0|0;
 $v = $v|0;
 var $$$i$i$i = 0, $$$i$i$i14 = 0, $$$i$i$i21 = 0, $$0$i = 0, $$0$i19 = 0, $$0$i25 = 0, $$idx$val = 0, $$idx$val$i = 0, $$idx$val$i11 = 0, $$idx$val$i4 = 0, $$idx1$val$i = 0, $$idx1$val$i2 = 0, $$idx1$val$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$02$i = 0, $i$02$i16 = 0, $i$02$i22 = 0, $tmp$i = 0;
 var $tmp$i17 = 0, $tmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$t0>>2]|0;
 $2 = (($t0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($t0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__Z15PxGetFoundationv()|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
 $$$i$i$i = $17 ? 534792 : 534480;
 $18 = (FUNCTION_TABLE_iiiiii[$12 & 255]($9,36,$$$i$i$i,534392,1475)|0);
 $19 = HEAP32[$this>>2]|0;
 __ZN5physx3TriC1EiiiPNS_12hullLibArray5ArrayIPS0_EE($18,$v,$3,$5,$19);
 $20 = (($18) + 12|0);
 $21 = (($t0) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($8) + 1)|0;
 $24 = (($8) + 2)|0;
 HEAP32[$20>>2] = $22;
 $25 = (($18) + 16|0);
 HEAP32[$25>>2] = $23;
 $26 = (($18) + 20|0);
 HEAP32[$26>>2] = $24;
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$21>>2]|0;
 $29 = HEAP32[$27>>2]|0;
 $30 = (($29) + ($28<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 $i$02$i = 0;
 while(1) {
  $32 = (($i$02$i) + 1)|0;
  $33 = ($32|0)==(3);
  $tmp$i = $33 ? 0 : $32;
  $34 = (($i$02$i) + 2)|0;
  $35 = (($34|0) % 3)&-1;
  $36 = (($31) + ($i$02$i<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==($3|0);
  if ($38) {
   $39 = (($31) + ($tmp$i<<2)|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==($5|0);
   if ($41) {
    label = 4;
    break;
   }
  }
  $44 = ($37|0)==($5|0);
  if ($44) {
   $46 = (($31) + ($tmp$i<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==($3|0);
   if ($48) {
    label = 8;
    break;
   }
  }
  $45 = ($32|0)<(3);
  if ($45) {
   $i$02$i = $32;
  } else {
   $$0$i = 534384;
   break;
  }
 }
 if ((label|0) == 4) {
  $42 = (($31) + 12|0);
  $43 = (($42) + ($35<<2)|0);
  $$0$i = $43;
 }
 else if ((label|0) == 8) {
  $49 = (($31) + 12|0);
  $50 = (($49) + ($35<<2)|0);
  $$0$i = $50;
 }
 HEAP32[$$0$i>>2] = $8;
 $51 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (__Z15PxGetFoundationv()|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 24|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (FUNCTION_TABLE_ii[$58 & 4095]($55)|0);
 $$$i$i$i14 = $59 ? 534792 : 534480;
 $60 = (FUNCTION_TABLE_iiiiii[$54 & 255]($51,36,$$$i$i$i14,534392,1482)|0);
 $61 = HEAP32[$this>>2]|0;
 __ZN5physx3TriC1EiiiPNS_12hullLibArray5ArrayIPS0_EE($60,$v,$5,$1,$61);
 $62 = (($60) + 12|0);
 $63 = (($21) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$62>>2] = $64;
 $65 = (($60) + 16|0);
 HEAP32[$65>>2] = $24;
 $66 = (($60) + 20|0);
 HEAP32[$66>>2] = $8;
 $67 = HEAP32[$this>>2]|0;
 $68 = HEAP32[$63>>2]|0;
 $69 = HEAP32[$67>>2]|0;
 $70 = (($69) + ($68<<2)|0);
 $71 = HEAP32[$70>>2]|0;
 $i$02$i22 = 0;
 while(1) {
  $72 = (($i$02$i22) + 1)|0;
  $73 = ($72|0)==(3);
  $tmp$i23 = $73 ? 0 : $72;
  $74 = (($i$02$i22) + 2)|0;
  $75 = (($74|0) % 3)&-1;
  $76 = (($71) + ($i$02$i22<<2)|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ($77|0)==($5|0);
  if ($78) {
   $79 = (($71) + ($tmp$i23<<2)|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==($1|0);
   if ($81) {
    label = 12;
    break;
   }
  }
  $84 = ($77|0)==($1|0);
  if ($84) {
   $86 = (($71) + ($tmp$i23<<2)|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)==($5|0);
   if ($88) {
    label = 16;
    break;
   }
  }
  $85 = ($72|0)<(3);
  if ($85) {
   $i$02$i22 = $72;
  } else {
   $$0$i25 = 534384;
   break;
  }
 }
 if ((label|0) == 12) {
  $82 = (($71) + 12|0);
  $83 = (($82) + ($75<<2)|0);
  $$0$i25 = $83;
 }
 else if ((label|0) == 16) {
  $89 = (($71) + 12|0);
  $90 = (($89) + ($75<<2)|0);
  $$0$i25 = $90;
 }
 HEAP32[$$0$i25>>2] = $23;
 $91 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + 8|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (__Z15PxGetFoundationv()|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (($96) + 24|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (FUNCTION_TABLE_ii[$98 & 4095]($95)|0);
 $$$i$i$i21 = $99 ? 534792 : 534480;
 $100 = (FUNCTION_TABLE_iiiiii[$94 & 255]($91,36,$$$i$i$i21,534392,1489)|0);
 $101 = HEAP32[$this>>2]|0;
 __ZN5physx3TriC1EiiiPNS_12hullLibArray5ArrayIPS0_EE($100,$v,$1,$3,$101);
 $102 = (($100) + 12|0);
 $103 = (($21) + 8|0);
 $104 = HEAP32[$103>>2]|0;
 HEAP32[$102>>2] = $104;
 $105 = (($100) + 16|0);
 HEAP32[$105>>2] = $8;
 $106 = (($100) + 20|0);
 HEAP32[$106>>2] = $23;
 $107 = HEAP32[$this>>2]|0;
 $108 = HEAP32[$103>>2]|0;
 $109 = HEAP32[$107>>2]|0;
 $110 = (($109) + ($108<<2)|0);
 $111 = HEAP32[$110>>2]|0;
 $i$02$i16 = 0;
 while(1) {
  $112 = (($i$02$i16) + 1)|0;
  $113 = ($112|0)==(3);
  $tmp$i17 = $113 ? 0 : $112;
  $114 = (($i$02$i16) + 2)|0;
  $115 = (($114|0) % 3)&-1;
  $116 = (($111) + ($i$02$i16<<2)|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = ($117|0)==($1|0);
  if ($118) {
   $119 = (($111) + ($tmp$i17<<2)|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ($120|0)==($3|0);
   if ($121) {
    label = 20;
    break;
   }
  }
  $124 = ($117|0)==($3|0);
  if ($124) {
   $126 = (($111) + ($tmp$i17<<2)|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)==($1|0);
   if ($128) {
    label = 24;
    break;
   }
  }
  $125 = ($112|0)<(3);
  if ($125) {
   $i$02$i16 = $112;
  } else {
   $$0$i19 = 534384;
   break;
  }
 }
 if ((label|0) == 20) {
  $122 = (($111) + 12|0);
  $123 = (($122) + ($115<<2)|0);
  $$0$i19 = $123;
 }
 else if ((label|0) == 24) {
  $129 = (($111) + 12|0);
  $130 = (($129) + ($115<<2)|0);
  $$0$i19 = $130;
 }
 HEAP32[$$0$i19>>2] = $24;
 $131 = HEAP32[$20>>2]|0;
 $132 = (($109) + ($131<<2)|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = HEAP32[$133>>2]|0;
 $135 = ($134|0)==($v|0);
 if ($135) {
  label = 28;
 } else {
  $136 = (($133) + 4|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = ($137|0)==($v|0);
  if ($138) {
   label = 28;
  } else {
   $139 = (($133) + 8|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ($140|0)==($v|0);
   if ($141) {
    label = 28;
   }
  }
 }
 if ((label|0) == 28) {
  __ZN5physx11HullLibrary6b2bfixEPNS_3TriES2_($this,$18,$133);
  $142 = HEAP32[$this>>2]|0;
  $$idx1$val$i9 = HEAP32[$142>>2]|0;
  $143 = (($18) + 24|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = (($$idx1$val$i9) + ($144<<2)|0);
  HEAP32[$145>>2] = 0;
  $146 = ($18|0)==(0|0);
  if (!($146)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$18);
  }
  $147 = HEAP32[$this>>2]|0;
  $$idx$val$i11 = HEAP32[$147>>2]|0;
  $148 = (($133) + 24|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = (($$idx$val$i11) + ($149<<2)|0);
  HEAP32[$150>>2] = 0;
  $151 = ($133|0)==(0|0);
  if (!($151)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$133);
  }
 }
 $152 = HEAP32[$this>>2]|0;
 $153 = HEAP32[$62>>2]|0;
 $154 = HEAP32[$152>>2]|0;
 $155 = (($154) + ($153<<2)|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = HEAP32[$156>>2]|0;
 $158 = ($157|0)==($v|0);
 if ($158) {
  label = 35;
 } else {
  $159 = (($156) + 4|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = ($160|0)==($v|0);
  if ($161) {
   label = 35;
  } else {
   $162 = (($156) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ($163|0)==($v|0);
   if ($164) {
    label = 35;
   }
  }
 }
 if ((label|0) == 35) {
  __ZN5physx11HullLibrary6b2bfixEPNS_3TriES2_($this,$60,$156);
  $165 = HEAP32[$this>>2]|0;
  $$idx1$val$i2 = HEAP32[$165>>2]|0;
  $166 = (($60) + 24|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = (($$idx1$val$i2) + ($167<<2)|0);
  HEAP32[$168>>2] = 0;
  $169 = ($60|0)==(0|0);
  if (!($169)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$60);
  }
  $170 = HEAP32[$this>>2]|0;
  $$idx$val$i4 = HEAP32[$170>>2]|0;
  $171 = (($156) + 24|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = (($$idx$val$i4) + ($172<<2)|0);
  HEAP32[$173>>2] = 0;
  $174 = ($156|0)==(0|0);
  if (!($174)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$156);
  }
 }
 $175 = HEAP32[$this>>2]|0;
 $176 = HEAP32[$102>>2]|0;
 $177 = HEAP32[$175>>2]|0;
 $178 = (($177) + ($176<<2)|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = HEAP32[$179>>2]|0;
 $181 = ($180|0)==($v|0);
 if ($181) {
  label = 42;
 } else {
  $182 = (($179) + 4|0);
  $183 = HEAP32[$182>>2]|0;
  $184 = ($183|0)==($v|0);
  if ($184) {
   label = 42;
  } else {
   $185 = (($179) + 8|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = ($186|0)==($v|0);
   if ($187) {
    label = 42;
   }
  }
 }
 if ((label|0) == 42) {
  __ZN5physx11HullLibrary6b2bfixEPNS_3TriES2_($this,$100,$179);
  $188 = HEAP32[$this>>2]|0;
  $$idx1$val$i = HEAP32[$188>>2]|0;
  $189 = (($100) + 24|0);
  $190 = HEAP32[$189>>2]|0;
  $191 = (($$idx1$val$i) + ($190<<2)|0);
  HEAP32[$191>>2] = 0;
  $192 = ($100|0)==(0|0);
  if (!($192)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$100);
  }
  $193 = HEAP32[$this>>2]|0;
  $$idx$val$i = HEAP32[$193>>2]|0;
  $194 = (($179) + 24|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = (($$idx$val$i) + ($195<<2)|0);
  HEAP32[$196>>2] = 0;
  $197 = ($179|0)==(0|0);
  if (!($197)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$179);
  }
 }
 $198 = HEAP32[$this>>2]|0;
 $$idx$val = HEAP32[$198>>2]|0;
 $199 = (($t0) + 24|0);
 $200 = HEAP32[$199>>2]|0;
 $201 = (($$idx$val) + ($200<<2)|0);
 HEAP32[$201>>2] = 0;
 $202 = ($t0|0)==(0|0);
 if ($202) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$t0);
 STACKTOP = sp;return;
}
function __ZN5physx3TriC1EiiiPNS_12hullLibArray5ArrayIPS0_EE($this,$a,$b,$c,$mTris) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $mTris = $mTris|0;
 var $$$i$i = 0, $$pre$i = 0, $$pre$i$i$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 HEAP32[$this>>2] = $a;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $b;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $c;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = -1;
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = -1;
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = -1;
 $7 = (($mTris) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 24|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$7>>2]|0;
 $11 = (($mTris) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 do {
  if ($13) {
   $14 = ($10|0)==(0);
   $15 = $10 << 1;
   $$$i$i = $14 ? 16 : $15;
   $16 = HEAP32[$mTris>>2]|0;
   HEAP32[$11>>2] = $$$i$i;
   $17 = $$$i$i << 2;
   $18 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$17,534704,153)|0);
   HEAP32[$mTris>>2] = $18;
   $19 = HEAP32[$7>>2]|0;
   $20 = ($19|0)>(0);
   if ($20) {
    $21 = HEAP32[$16>>2]|0;
    HEAP32[$18>>2] = $21;
    $22 = ($19|0)>(1);
    if ($22) {
     $24 = 1;
     while(1) {
      $$pre$i = HEAP32[$mTris>>2]|0;
      $23 = (($16) + ($24<<2)|0);
      $25 = HEAP32[$23>>2]|0;
      $26 = (($$pre$i) + ($24<<2)|0);
      HEAP32[$26>>2] = $25;
      $27 = (($24) + 1)|0;
      $exitcond = ($27|0)==($19|0);
      if ($exitcond) {
       break;
      } else {
       $24 = $27;
      }
     }
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
   if ((label|0) == 6) {
    $28 = ($16|0)==(0|0);
    if ($28) {
     $$pre$phiZ2D = $mTris;$30 = $19;
     break;
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$16);
   $$pre$i$i$pre = HEAP32[$7>>2]|0;
   $$pre$phiZ2D = $mTris;$30 = $$pre$i$i$pre;
  } else {
   $$pre$phiZ2D = $mTris;$30 = $10;
  }
 } while(0);
 $29 = (($30) + 1)|0;
 HEAP32[$7>>2] = $29;
 $31 = HEAP32[$$pre$phiZ2D>>2]|0;
 $32 = (($31) + ($30<<2)|0);
 HEAP32[$32>>2] = $this;
 $33 = (($this) + 28|0);
 HEAP32[$33>>2] = -1;
 $34 = (($this) + 32|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx11HullLibrary11calchullgenEPNS_6float3Eiif($this,$verts,$verts_count,$vlimit,$areaTestEpsilon) {
 $this = $this|0;
 $verts = $verts|0;
 $verts_count = $verts_count|0;
 $vlimit = $vlimit|0;
 $areaTestEpsilon = Math_fround($areaTestEpsilon);
 var $$ = 0, $$$i = 0, $$$i$i$i = 0, $$$i$i$i148 = 0, $$$i$i$i149 = 0, $$$i$i$i150 = 0, $$$i138 = 0, $$$i147 = 0, $$0 = 0, $$1 = 0, $$12$lcssa = 0, $$12257 = 0, $$142$i = 0, $$143$i = 0, $$idx$i$i = 0, $$idx$val = 0, $$idx$val$i = Math_fround(0), $$idx$val$i$i = Math_fround(0), $$idx1$i$i = 0, $$idx1$val$i$i = Math_fround(0);
 var $$idx10 = 0, $$idx10$i = 0, $$idx10$i160 = 0, $$idx10$val = Math_fround(0), $$idx10$val$i = Math_fround(0), $$idx10$val$i151 = Math_fround(0), $$idx10$val$i161 = Math_fround(0), $$idx100 = 0, $$idx100$val = Math_fround(0), $$idx104 = 0, $$idx104$val = Math_fround(0), $$idx105 = 0, $$idx105$val = Math_fround(0), $$idx106 = 0, $$idx106$val = Math_fround(0), $$idx107 = 0, $$idx107$val = Math_fround(0), $$idx108 = 0, $$idx108$val = Math_fround(0), $$idx109 = 0;
 var $$idx109$val = Math_fround(0), $$idx11$i = 0, $$idx11$i162 = 0, $$idx11$val$i = Math_fround(0), $$idx11$val$i152 = Math_fround(0), $$idx11$val$i163 = Math_fround(0), $$idx110 = 0, $$idx110$val = Math_fround(0), $$idx111 = 0, $$idx111$val = Math_fround(0), $$idx112 = 0, $$idx112$val = Math_fround(0), $$idx116 = 0, $$idx116$val = Math_fround(0), $$idx117 = 0, $$idx117$val = Math_fround(0), $$idx118 = 0, $$idx118$val = Math_fround(0), $$idx119 = 0, $$idx119$val = Math_fround(0);
 var $$idx12$i = 0, $$idx12$i164 = 0, $$idx12$val$i = Math_fround(0), $$idx12$val$i$i = Math_fround(0), $$idx12$val$i165 = Math_fround(0), $$idx120 = 0, $$idx120$val = Math_fround(0), $$idx121 = 0, $$idx121$val = Math_fround(0), $$idx122 = 0, $$idx122$val = Math_fround(0), $$idx123 = 0, $$idx123$val = Math_fround(0), $$idx124 = 0, $$idx124$val = Math_fround(0), $$idx125 = 0, $$idx125$us = 0, $$idx125$val = Math_fround(0), $$idx125$val$us = Math_fround(0), $$idx126 = 0;
 var $$idx126$us = 0, $$idx126$val = Math_fround(0), $$idx126$val$us = Math_fround(0), $$idx127 = 0, $$idx127$us = 0, $$idx127$val = Math_fround(0), $$idx127$val$us = Math_fround(0), $$idx128 = 0, $$idx128$us = 0, $$idx128$val = Math_fround(0), $$idx128$val$us = Math_fround(0), $$idx129 = 0, $$idx129$us = 0, $$idx129$val = Math_fround(0), $$idx129$val$us = Math_fround(0), $$idx13$i = 0, $$idx13$i166 = 0, $$idx13$val$i = Math_fround(0), $$idx13$val$i$i = Math_fround(0), $$idx13$val$i167 = Math_fround(0);
 var $$idx130 = 0, $$idx130$us = 0, $$idx130$val = Math_fround(0), $$idx130$val$us = Math_fround(0), $$idx131 = 0, $$idx131$us = 0, $$idx131$val = Math_fround(0), $$idx131$val$us = Math_fround(0), $$idx132 = 0, $$idx132$us = 0, $$idx132$val = Math_fround(0), $$idx132$val$us = Math_fround(0), $$idx133 = 0, $$idx133$us = 0, $$idx133$val = Math_fround(0), $$idx133$val$us = Math_fround(0), $$idx14$i = 0, $$idx14$i168 = 0, $$idx14$val$i = Math_fround(0), $$idx14$val$i$i = Math_fround(0);
 var $$idx14$val$i169 = Math_fround(0), $$idx15$i = 0, $$idx15$i153 = 0, $$idx15$i170 = 0, $$idx15$val$i = Math_fround(0), $$idx15$val$i$i = Math_fround(0), $$idx15$val$i154 = Math_fround(0), $$idx15$val$i171 = Math_fround(0), $$idx16 = 0, $$idx16$i = 0, $$idx16$i155 = 0, $$idx16$i172 = 0, $$idx16$val = Math_fround(0), $$idx16$val$i = Math_fround(0), $$idx16$val$i$i = Math_fround(0), $$idx16$val$i156 = Math_fround(0), $$idx16$val$i173 = Math_fround(0), $$idx17 = 0, $$idx17$i = 0, $$idx17$i157 = 0;
 var $$idx17$i174 = 0, $$idx17$val = Math_fround(0), $$idx17$val$i = Math_fround(0), $$idx17$val$i$i = Math_fround(0), $$idx17$val$i158 = Math_fround(0), $$idx17$val$i175 = Math_fround(0), $$idx18 = 0, $$idx18$i = 0, $$idx18$i176 = 0, $$idx18$val = Math_fround(0), $$idx18$val$i = Math_fround(0), $$idx18$val$i159 = Math_fround(0), $$idx18$val$i177 = Math_fround(0), $$idx19 = 0, $$idx19$val = Math_fround(0), $$idx19$val$i = Math_fround(0), $$idx2$i$i = 0, $$idx2$val$i$i = Math_fround(0), $$idx20 = 0, $$idx20$val = Math_fround(0);
 var $$idx20$val$i = Math_fround(0), $$idx21 = 0, $$idx21$i = 0, $$idx21$val = Math_fround(0), $$idx21$val$i = Math_fround(0), $$idx22$i = 0, $$idx22$val$i = Math_fround(0), $$idx23$i = 0, $$idx23$val$i = Math_fround(0), $$idx24$val$i = Math_fround(0), $$idx25$val$i = Math_fround(0), $$idx26$val$i = Math_fround(0), $$idx27$i = 0, $$idx27$val$i = Math_fround(0), $$idx28$i = 0, $$idx28$val$i = Math_fround(0), $$idx29$i = 0, $$idx29$val$i = Math_fround(0), $$idx3$val = 0, $$idx3$val$i$i = Math_fround(0);
 var $$idx3$val$pre$i$i = Math_fround(0), $$idx30$i = 0, $$idx30$val$i = Math_fround(0), $$idx31$i = 0, $$idx31$val$i = Math_fround(0), $$idx32$i = 0, $$idx32$val$i = Math_fround(0), $$idx34$us = 0, $$idx34$val$us = Math_fround(0), $$idx35$us = 0, $$idx35$val$us = Math_fround(0), $$idx36$us = 0, $$idx36$val$us = Math_fround(0), $$idx4$val = 0, $$idx4$val$i = Math_fround(0), $$idx4$val$i$i = Math_fround(0), $$idx4$val$pre$i$i = Math_fround(0), $$idx40$us = 0, $$idx40$val$us = Math_fround(0), $$idx41$us = 0;
 var $$idx41$val$us = Math_fround(0), $$idx42$us = 0, $$idx42$val$us = Math_fround(0), $$idx43$val$us = Math_fround(0), $$idx44$val$us = Math_fround(0), $$idx45$val$us = Math_fround(0), $$idx46 = 0, $$idx46$us = 0, $$idx46$val = Math_fround(0), $$idx46$val$us = Math_fround(0), $$idx47 = 0, $$idx47$us = 0, $$idx47$val = Math_fround(0), $$idx47$val$us = Math_fround(0), $$idx48 = 0, $$idx48$us = 0, $$idx48$val = Math_fround(0), $$idx48$val$us = Math_fround(0), $$idx49 = 0, $$idx49$us = 0;
 var $$idx49$val = Math_fround(0), $$idx49$val$us = Math_fround(0), $$idx5$val = 0, $$idx5$val$i = Math_fround(0), $$idx5$val$i$i = Math_fround(0), $$idx5$val$pre$i$i = Math_fround(0), $$idx50 = 0, $$idx50$us = 0, $$idx50$val = Math_fround(0), $$idx50$val$us = Math_fround(0), $$idx51 = 0, $$idx51$us = 0, $$idx51$val = Math_fround(0), $$idx51$val$us = Math_fround(0), $$idx54$val$i = Math_fround(0), $$idx55$val$i = Math_fround(0), $$idx56$val$i = Math_fround(0), $$idx57$i = 0, $$idx57$val$i = Math_fround(0), $$idx58$i = 0;
 var $$idx58$val$i = Math_fround(0), $$idx59$i = 0, $$idx59$val$i = Math_fround(0), $$idx6$val$i$i = Math_fround(0), $$idx63$i = 0, $$idx63$val$i = Math_fround(0), $$idx64$i = 0, $$idx64$val$i = Math_fround(0), $$idx65$i = 0, $$idx65$val$i = Math_fround(0), $$idx69$val$i = Math_fround(0), $$idx7$val$i$i = Math_fround(0), $$idx70$val$i = Math_fround(0), $$idx71$val$i = Math_fround(0), $$idx72$val$i = Math_fround(0), $$idx73$val$i = Math_fround(0), $$idx74$val$i = Math_fround(0), $$idx75$val$i = Math_fround(0), $$idx76$i = 0, $$idx76$val$i = Math_fround(0);
 var $$idx77$i = 0, $$idx77$val$i = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0), $$idx8$val$i$i = Math_fround(0), $$idx9 = 0, $$idx9$val = Math_fround(0), $$idx9$val$i = Math_fround(0), $$idx98 = 0, $$idx98$val = Math_fround(0), $$idx99 = 0, $$idx99$val = Math_fround(0), $$in = 0, $$in280 = 0, $$in281 = 0, $$phi$trans$insert = 0, $$phi$trans$insert302 = 0, $$pre = 0, $$pre$i85$i = Math_fround(0), $$pre297 = 0;
 var $$pre3$i86$i = Math_fround(0), $$pre300 = 0, $$pre301 = 0, $$pre303 = 0, $$pre305 = 0, $$pre309 = 0, $$pre4$i87$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0);
 var $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0);
 var $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0);
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0;
 var $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0;
 var $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0);
 var $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0);
 var $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0);
 var $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = Math_fround(0);
 var $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0;
 var $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0);
 var $506 = Math_fround(0), $507 = Math_fround(0), $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = Math_fround(0), $529 = 0, $53 = Math_fround(0), $530 = Math_fround(0), $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = Math_fround(0), $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0);
 var $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0);
 var $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = Math_fround(0), $613 = Math_fround(0);
 var $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0);
 var $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = 0, $65 = Math_fround(0);
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0);
 var $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = 0, $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = Math_fround(0), $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = Math_fround(0), $730 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allow = 0, $basis$i = 0;
 var $d$0$i$i = Math_fround(0), $d$0$i$i$i = Math_fround(0), $d$0$i88$i = Math_fround(0), $exitcond = 0, $exitcond285 = 0, $exitcond288 = 0, $exitcond296 = 0, $i$01$i$i = 0, $i$01$i$i139 = 0, $i$02$i = 0, $index0$0$i = 0, $index1$0$i = 0, $index2$0$i = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$next287 = 0, $indvars$iv286 = 0, $isextreme$sroa$0 = 0, $j$1261 = 0, $j$1261$us = 0;
 var $j$3$be = 0, $n = 0, $n$idx$val = Math_fround(0), $n$idx$val$us = Math_fround(0), $n$idx78$val = Math_fround(0), $n$idx78$val$us = Math_fround(0), $n$idx79$val = Math_fround(0), $n$idx79$val$us = Math_fround(0), $n6 = 0, $n6$idx$val = Math_fround(0), $n6$idx73$val = Math_fround(0), $n6$idx74$val = Math_fround(0), $not$ = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond1$i = 0, $or$cond133$i = 0, $or$cond134$i = 0, $or$cond135$i = 0;
 var $or$cond138$i = 0, $or$cond139$i = 0, $or$cond140$i = 0, $or$cond141$i = 0, $or$cond2$i = 0, $or$cond3$i = 0, $p$idx$i178 = 0, $p$idx$val$i179 = Math_fround(0), $p$idx1$i180 = 0, $p$idx1$val$i181 = Math_fround(0), $p$idx2$i182 = 0, $p$idx2$val$i183 = Math_fround(0), $storemerge = Math_fround(0), $storemerge311 = Math_fround(0), $storemerge312 = Math_fround(0), $storemerge313 = Math_fround(0), $storemerge314 = Math_fround(0), $storemerge315 = Math_fround(0), $storemerge316 = Math_fround(0), $storemerge317 = Math_fround(0);
 var $storemerge318 = Math_fround(0), $t$01$i = 0, $t$1$i = 0, $v$idx$val$i79$i = Math_fround(0), $v$idx1$i80$i = 0, $v$idx1$val$i81$i = Math_fround(0), $v$idx2$i82$i = 0, $v$idx2$val$i83$i = Math_fround(0), $vlimit$op = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp;
 $basis$i = sp + 76|0;
 $1 = sp + 124|0;
 $2 = sp + 136|0;
 $3 = sp + 112|0;
 $4 = sp + 153|0;
 $5 = sp + 152|0;
 $6 = sp + 148|0;
 $7 = sp + 151|0;
 $8 = sp + 150|0;
 $9 = sp + 149|0;
 $isextreme$sroa$0 = sp + 48|0;
 $allow = sp + 36|0;
 $n = sp + 52|0;
 $n6 = sp + 64|0;
 $10 = ($verts_count|0)<(4);
 if ($10) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $11 = ($vlimit|0)==(0);
 $12 = Math_fround(HEAPF32[$verts>>2]);
 $13 = (($verts) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($verts) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = $verts_count << 2;
 $18 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($9,$17,534704,153)|0);
 HEAP32[$isextreme$sroa$0>>2] = $18;
 $19 = (($allow) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($allow) + 8|0);
 HEAP32[$20>>2] = $verts_count;
 $21 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($8,$17,534704,153)|0);
 HEAP32[$allow>>2] = $21;
 $$pre309 = $18;$23 = $verts_count;$30 = $21;$38 = $verts_count;$53 = $12;$56 = $14;$59 = $16;$62 = $12;$65 = $14;$68 = $16;$indvars$iv = 0;$indvars$iv286 = 0;
 while(1) {
  $22 = ($indvars$iv|0)==($23|0);
  do {
   if ($22) {
    $24 = ($23|0)==(0);
    $25 = $23 << 1;
    $$$i = $24 ? 16 : $25;
    HEAP32[$20>>2] = $$$i;
    $26 = $$$i << 2;
    $27 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($6,$26,534704,153)|0);
    HEAP32[$allow>>2] = $27;
    $28 = ($23|0)>(0);
    if ($28) {
     $i$01$i$i = 0;
     while(1) {
      $29 = (($30) + ($i$01$i$i<<2)|0);
      $31 = HEAP32[$29>>2]|0;
      $32 = (($27) + ($i$01$i$i<<2)|0);
      HEAP32[$32>>2] = $31;
      $33 = (($i$01$i$i) + 1)|0;
      $exitcond285 = ($33|0)==($23|0);
      if ($exitcond285) {
       break;
      } else {
       $i$01$i$i = $33;
      }
     }
    } else {
     $34 = ($30|0)==(0|0);
     if ($34) {
      $36 = $27;$725 = $$$i;
      break;
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$30);
    $36 = $27;$725 = $$$i;
   } else {
    $36 = $30;$725 = $23;
   }
  } while(0);
  $indvars$iv$next = (($indvars$iv) + 1)|0;
  $35 = (($36) + ($indvars$iv<<2)|0);
  HEAP32[$35>>2] = 1;
  $37 = ($indvars$iv286|0)==($38|0);
  do {
   if ($37) {
    $39 = ($indvars$iv286|0)==(0);
    $40 = $indvars$iv286 << 1;
    $$$i138 = $39 ? 16 : $40;
    $41 = HEAP32[$isextreme$sroa$0>>2]|0;
    $42 = $$$i138 << 2;
    $43 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$42,534704,153)|0);
    HEAP32[$isextreme$sroa$0>>2] = $43;
    $44 = ($indvars$iv286|0)>(0);
    if ($44) {
     $i$01$i$i139 = 0;
     while(1) {
      $45 = (($41) + ($i$01$i$i139<<2)|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = (($43) + ($i$01$i$i139<<2)|0);
      HEAP32[$47>>2] = $46;
      $48 = (($i$01$i$i139) + 1)|0;
      $exitcond288 = ($48|0)==($indvars$iv286|0);
      if ($exitcond288) {
       break;
      } else {
       $i$01$i$i139 = $48;
      }
     }
    } else {
     $49 = ($41|0)==(0|0);
     if ($49) {
      $51 = $43;$726 = $$$i138;
      break;
     }
    }
    __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$41);
    $51 = $43;$726 = $$$i138;
   } else {
    $51 = $$pre309;$726 = $38;
   }
  } while(0);
  $indvars$iv$next287 = (($indvars$iv286) + 1)|0;
  $50 = (($51) + ($indvars$iv286<<2)|0);
  HEAP32[$50>>2] = 0;
  $$idx8 = (($verts) + (($indvars$iv286*12)|0)|0);
  $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
  $$idx9 = ((($verts) + (($indvars$iv286*12)|0)|0) + 4|0);
  $$idx9$val = Math_fround(HEAPF32[$$idx9>>2]);
  $$idx10 = ((($verts) + (($indvars$iv286*12)|0)|0) + 8|0);
  $$idx10$val = Math_fround(HEAPF32[$$idx10>>2]);
  $52 = $53 < $$idx8$val;
  $54 = $52 ? $53 : $$idx8$val;
  $55 = $56 < $$idx9$val;
  $57 = $55 ? $56 : $$idx9$val;
  $58 = $59 < $$idx10$val;
  $60 = $58 ? $59 : $$idx10$val;
  $61 = $62 > $$idx8$val;
  $63 = $61 ? $62 : $$idx8$val;
  $64 = $65 > $$idx9$val;
  $66 = $64 ? $65 : $$idx9$val;
  $67 = $68 > $$idx10$val;
  $69 = $67 ? $68 : $$idx10$val;
  $exitcond296 = ($indvars$iv$next287|0)==($verts_count|0);
  if ($exitcond296) {
   break;
  } else {
   $$pre309 = $51;$23 = $725;$30 = $36;$38 = $726;$53 = $54;$56 = $57;$59 = $60;$62 = $63;$65 = $66;$68 = $69;$indvars$iv = $indvars$iv$next;$indvars$iv286 = $indvars$iv$next287;
  }
 }
 HEAP32[$19>>2] = $verts_count;
 $70 = Math_fround($63 - $54);
 $71 = Math_fround($66 - $57);
 $72 = Math_fround($69 - $60);
 $73 = Math_fround($70 * $70);
 $74 = Math_fround($71 * $71);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($72 * $72);
 $77 = Math_fround($76 + $75);
 $78 = (Math_fround(Math_sqrt((Math_fround($77)))));
 $79 = Math_fround($78 * Math_fround(0.00100000004749745130539));
 $not$ = $areaTestEpsilon != Math_fround(0.0);
 if ($not$) {
  $80 = Math_fround($areaTestEpsilon * Math_fround(2.0));
  $436 = $80;
 } else {
  $81 = Math_fround($79 * $79);
  $82 = Math_fround($81 * Math_fround(0.100000001490116119385));
  $436 = $82;
 }
 $83 = $0;
 $84 = $83;
 HEAP32[$84>>2] = 0;
 $85 = (($83) + 4)|0;
 $86 = $85;
 HEAP32[$86>>2] = 0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $87 = (($0) + 4|0);
 HEAPF32[$87>>2] = Math_fround(0.0199999995529651641846);
 $88 = (($0) + 8|0);
 HEAPF32[$88>>2] = Math_fround(0.00999999977648258209228);
 $89 = (($0) + 12|0);
 HEAPF32[$89>>2] = Math_fround(-0.0199999995529651641846);
 $90 = (($0) + 16|0);
 HEAPF32[$90>>2] = Math_fround(1.0);
 $91 = (($0) + 20|0);
 HEAPF32[$91>>2] = Math_fround(-0.00999999977648258209228);
 $92 = (($0) + 24|0);
 HEAPF32[$92>>2] = Math_fround(0.00999999977648258209228);
 $93 = (($0) + 28|0);
 HEAPF32[$93>>2] = Math_fround(0.0199999995529651641846);
 $94 = (($0) + 32|0);
 HEAPF32[$94>>2] = Math_fround(1.0);
 $95 = $72 > $70;
 $96 = $72 > $71;
 $or$cond138$i = $95 & $96;
 if ($or$cond138$i) {
  $index0$0$i = 2;$index1$0$i = 0;$index2$0$i = 1;
 } else {
  $97 = $71 > $70;
  $98 = $71 > $72;
  $or$cond139$i = $97 & $98;
  $$$i147 = $or$cond139$i ? 0 : 2;
  $$142$i = $or$cond139$i ? 2 : 1;
  $$143$i = $or$cond139$i&1;
  $index0$0$i = $$143$i;$index1$0$i = $$142$i;$index2$0$i = $$$i147;
 }
 $99 = (($basis$i) + 16|0);
 $100 = (($basis$i) + 20|0);
 $101 = (($basis$i) + 24|0);
 $102 = (($basis$i) + 28|0);
 $103 = (($basis$i) + 32|0);
 $104 = (($0) + (($index0$0$i*12)|0)|0);
 dest=$basis$i+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$basis$i+0>>2]=HEAP32[$104+0>>2]|0;HEAP32[$basis$i+4>>2]=HEAP32[$104+4>>2]|0;HEAP32[$basis$i+8>>2]=HEAP32[$104+8>>2]|0;
 $105 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$basis$i,$allow)|0);
 $$idx75$val$i = Math_fround(HEAPF32[$basis$i>>2]);
 $$idx76$i = (($basis$i) + 4|0);
 $$idx76$val$i = Math_fround(HEAPF32[$$idx76$i>>2]);
 $$idx77$i = (($basis$i) + 8|0);
 $$idx77$val$i = Math_fround(HEAPF32[$$idx77$i>>2]);
 $106 = Math_fround(-$$idx75$val$i);
 $107 = Math_fround(-$$idx76$val$i);
 $108 = Math_fround(-$$idx77$val$i);
 HEAPF32[$1>>2] = $106;
 $109 = (($1) + 4|0);
 HEAPF32[$109>>2] = $107;
 $110 = (($1) + 8|0);
 HEAPF32[$110>>2] = $108;
 $111 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$1,$allow)|0);
 $$idx27$i = (($verts) + (($105*12)|0)|0);
 $$idx27$val$i = Math_fround(HEAPF32[$$idx27$i>>2]);
 $$idx28$i = ((($verts) + (($105*12)|0)|0) + 4|0);
 $$idx28$val$i = Math_fround(HEAPF32[$$idx28$i>>2]);
 $$idx29$i = ((($verts) + (($105*12)|0)|0) + 8|0);
 $$idx29$val$i = Math_fround(HEAPF32[$$idx29$i>>2]);
 $$idx30$i = (($verts) + (($111*12)|0)|0);
 $$idx30$val$i = Math_fround(HEAPF32[$$idx30$i>>2]);
 $$idx31$i = ((($verts) + (($111*12)|0)|0) + 4|0);
 $$idx31$val$i = Math_fround(HEAPF32[$$idx31$i>>2]);
 $$idx32$i = ((($verts) + (($111*12)|0)|0) + 8|0);
 $$idx32$val$i = Math_fround(HEAPF32[$$idx32$i>>2]);
 $112 = Math_fround($$idx27$val$i - $$idx30$val$i);
 $113 = Math_fround($$idx28$val$i - $$idx31$val$i);
 $114 = Math_fround($$idx29$val$i - $$idx32$val$i);
 HEAPF32[$basis$i>>2] = $112;
 HEAPF32[$$idx76$i>>2] = $113;
 HEAPF32[$$idx77$i>>2] = $114;
 $115 = ($105|0)==($111|0);
 if ($115) {
  $282 = -1;$283 = -1;$287 = -1;$291 = -1;
 } else {
  $116 = $112 == Math_fround(0.0);
  $117 = $113 == Math_fround(0.0);
  $or$cond140$i = $116 & $117;
  $118 = $114 == Math_fround(0.0);
  $or$cond141$i = $or$cond140$i & $118;
  if ($or$cond141$i) {
   $282 = -1;$283 = -1;$287 = -1;$291 = -1;
  } else {
   $119 = (($basis$i) + 12|0);
   $$idx63$i = (($0) + (($index1$0$i*12)|0)|0);
   $$idx63$val$i = Math_fround(HEAPF32[$$idx63$i>>2]);
   $$idx64$i = ((($0) + (($index1$0$i*12)|0)|0) + 4|0);
   $$idx64$val$i = Math_fround(HEAPF32[$$idx64$i>>2]);
   $$idx65$i = ((($0) + (($index1$0$i*12)|0)|0) + 8|0);
   $$idx65$val$i = Math_fround(HEAPF32[$$idx65$i>>2]);
   $120 = Math_fround($114 * $$idx64$val$i);
   $121 = Math_fround($113 * $$idx65$val$i);
   $122 = Math_fround($120 - $121);
   $123 = Math_fround($112 * $$idx65$val$i);
   $124 = Math_fround($114 * $$idx63$val$i);
   $125 = Math_fround($123 - $124);
   $126 = Math_fround($113 * $$idx63$val$i);
   $127 = Math_fround($112 * $$idx64$val$i);
   $128 = Math_fround($126 - $127);
   $129 = (($basis$i) + 12|0);
   HEAPF32[$129>>2] = $122;
   HEAPF32[$99>>2] = $125;
   HEAPF32[$100>>2] = $128;
   $130 = (($basis$i) + 24|0);
   $$idx57$i = (($0) + (($index2$0$i*12)|0)|0);
   $$idx57$val$i = Math_fround(HEAPF32[$$idx57$i>>2]);
   $$idx58$i = ((($0) + (($index2$0$i*12)|0)|0) + 4|0);
   $$idx58$val$i = Math_fround(HEAPF32[$$idx58$i>>2]);
   $$idx59$i = ((($0) + (($index2$0$i*12)|0)|0) + 8|0);
   $$idx59$val$i = Math_fround(HEAPF32[$$idx59$i>>2]);
   $131 = Math_fround($114 * $$idx58$val$i);
   $132 = Math_fround($113 * $$idx59$val$i);
   $133 = Math_fround($131 - $132);
   $134 = Math_fround($112 * $$idx59$val$i);
   $135 = Math_fround($114 * $$idx57$val$i);
   $136 = Math_fround($134 - $135);
   $137 = Math_fround($113 * $$idx57$val$i);
   $138 = Math_fround($112 * $$idx58$val$i);
   $139 = Math_fround($137 - $138);
   HEAPF32[$101>>2] = $133;
   HEAPF32[$102>>2] = $136;
   HEAPF32[$103>>2] = $139;
   $140 = Math_fround($122 * $122);
   $141 = Math_fround($125 * $125);
   $142 = Math_fround($140 + $141);
   $143 = Math_fround($128 * $128);
   $144 = Math_fround($143 + $142);
   $145 = (Math_fround(Math_sqrt((Math_fround($144)))));
   $146 = Math_fround($133 * $133);
   $147 = Math_fround($136 * $136);
   $148 = Math_fround($146 + $147);
   $149 = Math_fround($139 * $139);
   $150 = Math_fround($149 + $148);
   $151 = (Math_fround(Math_sqrt((Math_fround($150)))));
   $152 = $145 > $151;
   $153 = $152 ? $119 : $130;
   $v$idx$val$i79$i = Math_fround(HEAPF32[$153>>2]);
   $v$idx1$i80$i = (($153) + 4|0);
   $v$idx1$val$i81$i = Math_fround(HEAPF32[$v$idx1$i80$i>>2]);
   $v$idx2$i82$i = (($153) + 8|0);
   $v$idx2$val$i83$i = Math_fround(HEAPF32[$v$idx2$i82$i>>2]);
   $154 = Math_fround($v$idx$val$i79$i * $v$idx$val$i79$i);
   $155 = Math_fround($v$idx1$val$i81$i * $v$idx1$val$i81$i);
   $156 = Math_fround($154 + $155);
   $157 = Math_fround($v$idx2$val$i83$i * $v$idx2$val$i83$i);
   $158 = Math_fround($156 + $157);
   $159 = (Math_fround(Math_sqrt((Math_fround($158)))));
   $160 = $159 == Math_fround(0.0);
   if ($160) {
    (_puts((534992|0))|0);
    $$pre$i85$i = Math_fround(HEAPF32[$153>>2]);
    $$pre3$i86$i = Math_fround(HEAPF32[$v$idx1$i80$i>>2]);
    $$pre4$i87$i = Math_fround(HEAPF32[$v$idx2$i82$i>>2]);
    $163 = $$pre$i85$i;$165 = $$pre3$i86$i;$167 = $$pre4$i87$i;$d$0$i88$i = Math_fround(0.100000001490116119385);
   } else {
    $163 = $v$idx$val$i79$i;$165 = $v$idx1$val$i81$i;$167 = $v$idx2$val$i83$i;$d$0$i88$i = $159;
   }
   $161 = Math_fround(Math_fround(1.0) / $d$0$i88$i);
   $162 = Math_fround($163 * $161);
   $164 = Math_fround($165 * $161);
   $166 = Math_fround($167 * $161);
   HEAPF32[$129>>2] = $162;
   HEAPF32[$99>>2] = $164;
   HEAPF32[$100>>2] = $166;
   $168 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$119,$allow)|0);
   $169 = ($168|0)==($105|0);
   $170 = ($168|0)==($111|0);
   $or$cond$i = $169 | $170;
   if ($or$cond$i) {
    $$idx72$val$i = Math_fround(HEAPF32[$119>>2]);
    $$idx73$val$i = Math_fround(HEAPF32[$99>>2]);
    $$idx74$val$i = Math_fround(HEAPF32[$100>>2]);
    $171 = Math_fround(-$$idx72$val$i);
    $172 = Math_fround(-$$idx73$val$i);
    $173 = Math_fround(-$$idx74$val$i);
    HEAPF32[$2>>2] = $171;
    $174 = (($2) + 4|0);
    HEAPF32[$174>>2] = $172;
    $175 = (($2) + 8|0);
    HEAPF32[$175>>2] = $173;
    $176 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$2,$allow)|0);
    $178 = $176;
   } else {
    $178 = $168;
   }
   $177 = ($178|0)==($105|0);
   $179 = ($178|0)==($111|0);
   $or$cond1$i = $177 | $179;
   if ($or$cond1$i) {
    $282 = -1;$283 = -1;$287 = -1;$291 = -1;
   } else {
    $$idx21$i = (($verts) + (($178*12)|0)|0);
    $$idx21$val$i = Math_fround(HEAPF32[$$idx21$i>>2]);
    $$idx22$i = ((($verts) + (($178*12)|0)|0) + 4|0);
    $$idx22$val$i = Math_fround(HEAPF32[$$idx22$i>>2]);
    $$idx23$i = ((($verts) + (($178*12)|0)|0) + 8|0);
    $$idx23$val$i = Math_fround(HEAPF32[$$idx23$i>>2]);
    $$idx24$val$i = Math_fround(HEAPF32[$$idx27$i>>2]);
    $$idx25$val$i = Math_fround(HEAPF32[$$idx28$i>>2]);
    $$idx26$val$i = Math_fround(HEAPF32[$$idx29$i>>2]);
    $180 = Math_fround($$idx21$val$i - $$idx24$val$i);
    $181 = Math_fround($$idx22$val$i - $$idx25$val$i);
    $182 = Math_fround($$idx23$val$i - $$idx26$val$i);
    HEAPF32[$129>>2] = $180;
    HEAPF32[$99>>2] = $181;
    HEAPF32[$100>>2] = $182;
    $$idx54$val$i = Math_fround(HEAPF32[$basis$i>>2]);
    $$idx55$val$i = Math_fround(HEAPF32[$$idx76$i>>2]);
    $$idx56$val$i = Math_fround(HEAPF32[$$idx77$i>>2]);
    $183 = Math_fround($181 * $$idx56$val$i);
    $184 = Math_fround($182 * $$idx55$val$i);
    $185 = Math_fround($183 - $184);
    $186 = Math_fround($182 * $$idx54$val$i);
    $187 = Math_fround($180 * $$idx56$val$i);
    $188 = Math_fround($186 - $187);
    $189 = Math_fround($180 * $$idx55$val$i);
    $190 = Math_fround($181 * $$idx54$val$i);
    $191 = Math_fround($189 - $190);
    $192 = Math_fround($185 * $185);
    $193 = Math_fround($188 * $188);
    $194 = Math_fround($192 + $193);
    $195 = Math_fround($191 * $191);
    $196 = Math_fround($195 + $194);
    $197 = (Math_fround(Math_sqrt((Math_fround($196)))));
    $198 = $197 == Math_fround(0.0);
    if ($198) {
     (_puts((534992|0))|0);
     $d$0$i$i = Math_fround(0.100000001490116119385);
    } else {
     $d$0$i$i = $197;
    }
    $199 = Math_fround(Math_fround(1.0) / $d$0$i$i);
    $200 = Math_fround($185 * $199);
    $201 = Math_fround($188 * $199);
    $202 = Math_fround($191 * $199);
    HEAPF32[$101>>2] = $200;
    HEAPF32[$102>>2] = $201;
    HEAPF32[$103>>2] = $202;
    $203 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$130,$allow)|0);
    $204 = ($203|0)==($105|0);
    $205 = ($203|0)==($111|0);
    $or$cond2$i = $204 | $205;
    $206 = ($203|0)==($178|0);
    $or$cond133$i = $or$cond2$i | $206;
    if ($or$cond133$i) {
     label = 33;
    } else {
     $$idx12$val$i$i = Math_fround(HEAPF32[$$idx30$i>>2]);
     $$idx13$val$i$i = Math_fround(HEAPF32[$$idx31$i>>2]);
     $$idx14$val$i$i = Math_fround(HEAPF32[$$idx32$i>>2]);
     $$idx15$val$i$i = Math_fround(HEAPF32[$$idx27$i>>2]);
     $$idx16$val$i$i = Math_fround(HEAPF32[$$idx28$i>>2]);
     $$idx17$val$i$i = Math_fround(HEAPF32[$$idx29$i>>2]);
     $207 = Math_fround($$idx12$val$i$i - $$idx15$val$i$i);
     $208 = Math_fround($$idx13$val$i$i - $$idx16$val$i$i);
     $209 = Math_fround($$idx14$val$i$i - $$idx17$val$i$i);
     $$idx6$val$i$i = Math_fround(HEAPF32[$$idx21$i>>2]);
     $$idx7$val$i$i = Math_fround(HEAPF32[$$idx22$i>>2]);
     $$idx8$val$i$i = Math_fround(HEAPF32[$$idx23$i>>2]);
     $210 = Math_fround($$idx6$val$i$i - $$idx15$val$i$i);
     $211 = Math_fround($$idx7$val$i$i - $$idx16$val$i$i);
     $212 = Math_fround($$idx8$val$i$i - $$idx17$val$i$i);
     $213 = Math_fround($208 * $212);
     $214 = Math_fround($209 * $211);
     $215 = Math_fround($213 - $214);
     $216 = Math_fround($209 * $210);
     $217 = Math_fround($207 * $212);
     $218 = Math_fround($216 - $217);
     $219 = Math_fround($207 * $211);
     $220 = Math_fround($208 * $210);
     $221 = Math_fround($219 - $220);
     $222 = Math_fround($215 * $215);
     $223 = Math_fround($218 * $218);
     $224 = Math_fround($222 + $223);
     $225 = Math_fround($221 * $221);
     $226 = Math_fround($225 + $224);
     $227 = (Math_fround(Math_sqrt((Math_fround($226)))));
     $228 = $227 < Math_fround(9.99999968265522538896E-21);
     $229 = $227 > Math_fround(-9.99999968265522538896E-21);
     $or$cond$i$i = $228 & $229;
     if ($or$cond$i$i) {
      label = 33;
     } else {
      $230 = $227 == Math_fround(0.0);
      if ($230) {
       (_puts((534992|0))|0);
       $$idx3$val$pre$i$i = Math_fround(HEAPF32[$$idx27$i>>2]);
       $$idx4$val$pre$i$i = Math_fround(HEAPF32[$$idx28$i>>2]);
       $$idx5$val$pre$i$i = Math_fround(HEAPF32[$$idx29$i>>2]);
       $$idx3$val$i$i = $$idx3$val$pre$i$i;$$idx4$val$i$i = $$idx4$val$pre$i$i;$$idx5$val$i$i = $$idx5$val$pre$i$i;$d$0$i$i$i = Math_fround(0.100000001490116119385);
      } else {
       $$idx3$val$i$i = $$idx15$val$i$i;$$idx4$val$i$i = $$idx16$val$i$i;$$idx5$val$i$i = $$idx17$val$i$i;$d$0$i$i$i = $227;
      }
      $231 = Math_fround(Math_fround(1.0) / $d$0$i$i$i);
      $232 = Math_fround($215 * $231);
      $233 = Math_fround($218 * $231);
      $234 = Math_fround($221 * $231);
      $$idx$i$i = (($verts) + (($203*12)|0)|0);
      $$idx$val$i$i = Math_fround(HEAPF32[$$idx$i$i>>2]);
      $$idx1$i$i = ((($verts) + (($203*12)|0)|0) + 4|0);
      $$idx1$val$i$i = Math_fround(HEAPF32[$$idx1$i$i>>2]);
      $$idx2$i$i = ((($verts) + (($203*12)|0)|0) + 8|0);
      $$idx2$val$i$i = Math_fround(HEAPF32[$$idx2$i$i>>2]);
      $235 = Math_fround($$idx$val$i$i - $$idx3$val$i$i);
      $236 = Math_fround($$idx1$val$i$i - $$idx4$val$i$i);
      $237 = Math_fround($$idx2$val$i$i - $$idx5$val$i$i);
      $238 = Math_fround($232 * $235);
      $239 = Math_fround($233 * $236);
      $240 = Math_fround($238 + $239);
      $241 = Math_fround($234 * $237);
      $242 = Math_fround($240 + $241);
      $243 = $242 > Math_fround(9.99999968265522538896E-21);
      $244 = $242 < Math_fround(-9.99999968265522538896E-21);
      $or$cond134$i = $243 | $244;
      if ($or$cond134$i) {
       $252 = $203;
      } else {
       label = 33;
      }
     }
    }
    if ((label|0) == 33) {
     $$idx69$val$i = Math_fround(HEAPF32[$130>>2]);
     $$idx70$val$i = Math_fround(HEAPF32[$102>>2]);
     $$idx71$val$i = Math_fround(HEAPF32[$103>>2]);
     $245 = Math_fround(-$$idx69$val$i);
     $246 = Math_fround(-$$idx70$val$i);
     $247 = Math_fround(-$$idx71$val$i);
     HEAPF32[$3>>2] = $245;
     $248 = (($3) + 4|0);
     HEAPF32[$248>>2] = $246;
     $249 = (($3) + 8|0);
     HEAPF32[$249>>2] = $247;
     $250 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$3,$allow)|0);
     $252 = $250;
    }
    $251 = ($252|0)==($105|0);
    $253 = ($252|0)==($111|0);
    $or$cond3$i = $251 | $253;
    $254 = ($252|0)==($178|0);
    $or$cond135$i = $or$cond3$i | $254;
    if ($or$cond135$i) {
     $282 = -1;$283 = -1;$287 = -1;$291 = -1;
    } else {
     $$idx15$i = (($verts) + (($252*12)|0)|0);
     $$idx15$val$i = Math_fround(HEAPF32[$$idx15$i>>2]);
     $$idx16$i = ((($verts) + (($252*12)|0)|0) + 4|0);
     $$idx16$val$i = Math_fround(HEAPF32[$$idx16$i>>2]);
     $$idx17$i = ((($verts) + (($252*12)|0)|0) + 8|0);
     $$idx17$val$i = Math_fround(HEAPF32[$$idx17$i>>2]);
     $$idx18$val$i = Math_fround(HEAPF32[$$idx27$i>>2]);
     $$idx19$val$i = Math_fround(HEAPF32[$$idx28$i>>2]);
     $$idx20$val$i = Math_fround(HEAPF32[$$idx29$i>>2]);
     $255 = Math_fround($$idx15$val$i - $$idx18$val$i);
     $256 = Math_fround($$idx16$val$i - $$idx19$val$i);
     $257 = Math_fround($$idx17$val$i - $$idx20$val$i);
     $$idx9$val$i = Math_fround(HEAPF32[$$idx30$i>>2]);
     $$idx10$val$i = Math_fround(HEAPF32[$$idx31$i>>2]);
     $$idx11$val$i = Math_fround(HEAPF32[$$idx32$i>>2]);
     $258 = Math_fround($$idx9$val$i - $$idx18$val$i);
     $259 = Math_fround($$idx10$val$i - $$idx19$val$i);
     $260 = Math_fround($$idx11$val$i - $$idx20$val$i);
     $$idx$val$i = Math_fround(HEAPF32[$$idx21$i>>2]);
     $$idx4$val$i = Math_fround(HEAPF32[$$idx22$i>>2]);
     $$idx5$val$i = Math_fround(HEAPF32[$$idx23$i>>2]);
     $261 = Math_fround($$idx$val$i - $$idx18$val$i);
     $262 = Math_fround($$idx4$val$i - $$idx19$val$i);
     $263 = Math_fround($$idx5$val$i - $$idx20$val$i);
     $264 = Math_fround($259 * $263);
     $265 = Math_fround($260 * $262);
     $266 = Math_fround($264 - $265);
     $267 = Math_fround($260 * $261);
     $268 = Math_fround($258 * $263);
     $269 = Math_fround($267 - $268);
     $270 = Math_fround($258 * $262);
     $271 = Math_fround($259 * $261);
     $272 = Math_fround($270 - $271);
     $273 = Math_fround($255 * $266);
     $274 = Math_fround($256 * $269);
     $275 = Math_fround($273 + $274);
     $276 = Math_fround($257 * $272);
     $277 = Math_fround($276 + $275);
     $278 = $277 < Math_fround(0.0);
     $279 = $278 ? $252 : $178;
     $280 = $278 ? $178 : $252;
     $282 = $105;$283 = $111;$287 = $279;$291 = $280;
    }
   }
  }
 }
 $281 = ($282|0)==(-1);
 L54: do {
  if ($281) {
   $$0 = 1;$724 = $51;
  } else {
   $$idx107 = (($verts) + (($282*12)|0)|0);
   $$idx107$val = Math_fround(HEAPF32[$$idx107>>2]);
   $$idx108 = ((($verts) + (($282*12)|0)|0) + 4|0);
   $$idx108$val = Math_fround(HEAPF32[$$idx108>>2]);
   $$idx109 = ((($verts) + (($282*12)|0)|0) + 8|0);
   $$idx109$val = Math_fround(HEAPF32[$$idx109>>2]);
   $$idx110 = (($verts) + (($283*12)|0)|0);
   $$idx110$val = Math_fround(HEAPF32[$$idx110>>2]);
   $$idx111 = ((($verts) + (($283*12)|0)|0) + 4|0);
   $$idx111$val = Math_fround(HEAPF32[$$idx111>>2]);
   $$idx112 = ((($verts) + (($283*12)|0)|0) + 8|0);
   $$idx112$val = Math_fround(HEAPF32[$$idx112>>2]);
   $284 = Math_fround($$idx107$val + $$idx110$val);
   $285 = Math_fround($$idx108$val + $$idx111$val);
   $286 = Math_fround($$idx109$val + $$idx112$val);
   $$idx104 = (($verts) + (($287*12)|0)|0);
   $$idx104$val = Math_fround(HEAPF32[$$idx104>>2]);
   $$idx105 = ((($verts) + (($287*12)|0)|0) + 4|0);
   $$idx105$val = Math_fround(HEAPF32[$$idx105>>2]);
   $$idx106 = ((($verts) + (($287*12)|0)|0) + 8|0);
   $$idx106$val = Math_fround(HEAPF32[$$idx106>>2]);
   $288 = Math_fround($284 + $$idx104$val);
   $289 = Math_fround($285 + $$idx105$val);
   $290 = Math_fround($286 + $$idx106$val);
   $$idx98 = (($verts) + (($291*12)|0)|0);
   $$idx98$val = Math_fround(HEAPF32[$$idx98>>2]);
   $$idx99 = ((($verts) + (($291*12)|0)|0) + 4|0);
   $$idx99$val = Math_fround(HEAPF32[$$idx99>>2]);
   $$idx100 = ((($verts) + (($291*12)|0)|0) + 8|0);
   $$idx100$val = Math_fround(HEAPF32[$$idx100>>2]);
   $292 = Math_fround($288 + $$idx98$val);
   $293 = Math_fround($289 + $$idx99$val);
   $294 = Math_fround($290 + $$idx100$val);
   $295 = Math_fround($292 * Math_fround(0.25));
   $296 = Math_fround($293 * Math_fround(0.25));
   $297 = Math_fround($294 * Math_fround(0.25));
   $298 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = (($299) + 8|0);
   $301 = HEAP32[$300>>2]|0;
   $302 = (__Z15PxGetFoundationv()|0);
   $303 = HEAP32[$302>>2]|0;
   $304 = (($303) + 24|0);
   $305 = HEAP32[$304>>2]|0;
   $306 = (FUNCTION_TABLE_ii[$305 & 4095]($302)|0);
   $$$i$i$i = $306 ? 534792 : 534480;
   $307 = (FUNCTION_TABLE_iiiiii[$301 & 255]($298,36,$$$i$i$i,534392,1610)|0);
   $308 = HEAP32[$this>>2]|0;
   __ZN5physx3TriC1EiiiPNS_12hullLibArray5ArrayIPS0_EE($307,$287,$291,$283,$308);
   $309 = (($307) + 12|0);
   HEAP32[$309>>2] = 2;
   $310 = (($307) + 16|0);
   HEAP32[$310>>2] = 3;
   $311 = (($307) + 20|0);
   HEAP32[$311>>2] = 1;
   $312 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $313 = HEAP32[$312>>2]|0;
   $314 = (($313) + 8|0);
   $315 = HEAP32[$314>>2]|0;
   $316 = (__Z15PxGetFoundationv()|0);
   $317 = HEAP32[$316>>2]|0;
   $318 = (($317) + 24|0);
   $319 = HEAP32[$318>>2]|0;
   $320 = (FUNCTION_TABLE_ii[$319 & 4095]($316)|0);
   $$$i$i$i148 = $320 ? 534792 : 534480;
   $321 = (FUNCTION_TABLE_iiiiii[$315 & 255]($312,36,$$$i$i$i148,534392,1611)|0);
   $322 = HEAP32[$this>>2]|0;
   __ZN5physx3TriC1EiiiPNS_12hullLibArray5ArrayIPS0_EE($321,$291,$287,$282,$322);
   $323 = (($321) + 12|0);
   HEAP32[$323>>2] = 3;
   $324 = (($321) + 16|0);
   HEAP32[$324>>2] = 2;
   $325 = (($321) + 20|0);
   HEAP32[$325>>2] = 0;
   $326 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $327 = HEAP32[$326>>2]|0;
   $328 = (($327) + 8|0);
   $329 = HEAP32[$328>>2]|0;
   $330 = (__Z15PxGetFoundationv()|0);
   $331 = HEAP32[$330>>2]|0;
   $332 = (($331) + 24|0);
   $333 = HEAP32[$332>>2]|0;
   $334 = (FUNCTION_TABLE_ii[$333 & 4095]($330)|0);
   $$$i$i$i149 = $334 ? 534792 : 534480;
   $335 = (FUNCTION_TABLE_iiiiii[$329 & 255]($326,36,$$$i$i$i149,534392,1612)|0);
   $336 = HEAP32[$this>>2]|0;
   __ZN5physx3TriC1EiiiPNS_12hullLibArray5ArrayIPS0_EE($335,$282,$283,$291,$336);
   $337 = (($335) + 12|0);
   HEAP32[$337>>2] = 0;
   $338 = (($335) + 16|0);
   HEAP32[$338>>2] = 1;
   $339 = (($335) + 20|0);
   HEAP32[$339>>2] = 3;
   $340 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $341 = HEAP32[$340>>2]|0;
   $342 = (($341) + 8|0);
   $343 = HEAP32[$342>>2]|0;
   $344 = (__Z15PxGetFoundationv()|0);
   $345 = HEAP32[$344>>2]|0;
   $346 = (($345) + 24|0);
   $347 = HEAP32[$346>>2]|0;
   $348 = (FUNCTION_TABLE_ii[$347 & 4095]($344)|0);
   $$$i$i$i150 = $348 ? 534792 : 534480;
   $349 = (FUNCTION_TABLE_iiiiii[$343 & 255]($340,36,$$$i$i$i150,534392,1613)|0);
   $350 = HEAP32[$this>>2]|0;
   __ZN5physx3TriC1EiiiPNS_12hullLibArray5ArrayIPS0_EE($349,$283,$282,$287,$350);
   $351 = (($349) + 12|0);
   HEAP32[$351>>2] = 1;
   $352 = (($349) + 16|0);
   HEAP32[$352>>2] = 0;
   $353 = (($349) + 20|0);
   HEAP32[$353>>2] = 2;
   $354 = HEAP32[$isextreme$sroa$0>>2]|0;
   $355 = (($354) + ($291<<2)|0);
   HEAP32[$355>>2] = 1;
   $356 = (($354) + ($287<<2)|0);
   HEAP32[$356>>2] = 1;
   $357 = (($354) + ($283<<2)|0);
   HEAP32[$357>>2] = 1;
   $358 = (($354) + ($282<<2)|0);
   HEAP32[$358>>2] = 1;
   $359 = HEAP32[$this>>2]|0;
   $360 = (($359) + 4|0);
   $361 = HEAP32[$360>>2]|0;
   $362 = ($361|0)>(0);
   L56: do {
    if ($362) {
     $363 = (($n) + 4|0);
     $364 = (($n) + 8|0);
     if ($not$) {
      $366 = $359;$j$1261$us = 0;
     } else {
      $443 = $359;$j$1261 = 0;
      while(1) {
       $442 = HEAP32[$443>>2]|0;
       $444 = (($442) + ($j$1261<<2)|0);
       $445 = HEAP32[$444>>2]|0;
       $446 = HEAP32[$445>>2]|0;
       $447 = (($445) + 4|0);
       $448 = HEAP32[$447>>2]|0;
       $449 = (($445) + 8|0);
       $450 = HEAP32[$449>>2]|0;
       $$idx125 = (($verts) + (($446*12)|0)|0);
       $$idx125$val = Math_fround(HEAPF32[$$idx125>>2]);
       $$idx126 = ((($verts) + (($446*12)|0)|0) + 4|0);
       $$idx126$val = Math_fround(HEAPF32[$$idx126>>2]);
       $$idx127 = ((($verts) + (($446*12)|0)|0) + 8|0);
       $$idx127$val = Math_fround(HEAPF32[$$idx127>>2]);
       $$idx128 = (($verts) + (($448*12)|0)|0);
       $$idx128$val = Math_fround(HEAPF32[$$idx128>>2]);
       $$idx129 = ((($verts) + (($448*12)|0)|0) + 4|0);
       $$idx129$val = Math_fround(HEAPF32[$$idx129>>2]);
       $$idx130 = ((($verts) + (($448*12)|0)|0) + 8|0);
       $$idx130$val = Math_fround(HEAPF32[$$idx130>>2]);
       $$idx131 = (($verts) + (($450*12)|0)|0);
       $$idx131$val = Math_fround(HEAPF32[$$idx131>>2]);
       $$idx132 = ((($verts) + (($450*12)|0)|0) + 4|0);
       $$idx132$val = Math_fround(HEAPF32[$$idx132>>2]);
       $$idx133 = ((($verts) + (($450*12)|0)|0) + 8|0);
       $$idx133$val = Math_fround(HEAPF32[$$idx133>>2]);
       $451 = Math_fround($$idx128$val - $$idx125$val);
       $452 = Math_fround($$idx129$val - $$idx126$val);
       $453 = Math_fround($$idx130$val - $$idx127$val);
       $454 = Math_fround($$idx131$val - $$idx128$val);
       $455 = Math_fround($$idx132$val - $$idx129$val);
       $456 = Math_fround($$idx133$val - $$idx130$val);
       $457 = Math_fround($452 * $456);
       $458 = Math_fround($453 * $455);
       $459 = Math_fround($457 - $458);
       $460 = Math_fround($453 * $454);
       $461 = Math_fround($451 * $456);
       $462 = Math_fround($460 - $461);
       $463 = Math_fround($451 * $455);
       $464 = Math_fround($452 * $454);
       $465 = Math_fround($463 - $464);
       $466 = Math_fround($459 * $459);
       $467 = Math_fround($462 * $462);
       $468 = Math_fround($466 + $467);
       $469 = Math_fround($465 * $465);
       $470 = Math_fround($469 + $468);
       $471 = (Math_fround(Math_sqrt((Math_fround($470)))));
       $472 = $471 == Math_fround(0.0);
       if ($472) {
        $storemerge312 = Math_fround(0.0);$storemerge313 = Math_fround(0.0);$storemerge317 = Math_fround(1.0);
       } else {
        $473 = Math_fround(Math_fround(1.0) / $471);
        $474 = Math_fround($459 * $473);
        $475 = Math_fround($462 * $473);
        $476 = Math_fround($465 * $473);
        $storemerge312 = $476;$storemerge313 = $475;$storemerge317 = $474;
       }
       HEAPF32[$n>>2] = $storemerge317;
       HEAPF32[$363>>2] = $storemerge313;
       HEAPF32[$364>>2] = $storemerge312;
       $497 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$n,$allow)|0);
       $498 = (($445) + 28|0);
       HEAP32[$498>>2] = $497;
       $499 = HEAP32[$445>>2]|0;
       $$idx46 = (($verts) + (($497*12)|0)|0);
       $$idx46$val = Math_fround(HEAPF32[$$idx46>>2]);
       $$idx47 = ((($verts) + (($497*12)|0)|0) + 4|0);
       $$idx47$val = Math_fround(HEAPF32[$$idx47>>2]);
       $$idx48 = ((($verts) + (($497*12)|0)|0) + 8|0);
       $$idx48$val = Math_fround(HEAPF32[$$idx48>>2]);
       $$idx49 = (($verts) + (($499*12)|0)|0);
       $$idx49$val = Math_fround(HEAPF32[$$idx49>>2]);
       $$idx50 = ((($verts) + (($499*12)|0)|0) + 4|0);
       $$idx50$val = Math_fround(HEAPF32[$$idx50>>2]);
       $$idx51 = ((($verts) + (($499*12)|0)|0) + 8|0);
       $$idx51$val = Math_fround(HEAPF32[$$idx51>>2]);
       $500 = Math_fround($$idx46$val - $$idx49$val);
       $501 = Math_fround($$idx47$val - $$idx50$val);
       $502 = Math_fround($$idx48$val - $$idx51$val);
       $n$idx$val = Math_fround(HEAPF32[$n>>2]);
       $n$idx78$val = Math_fround(HEAPF32[$363>>2]);
       $n$idx79$val = Math_fround(HEAPF32[$364>>2]);
       $503 = Math_fround($500 * $n$idx$val);
       $504 = Math_fround($501 * $n$idx78$val);
       $505 = Math_fround($503 + $504);
       $506 = Math_fround($502 * $n$idx79$val);
       $507 = Math_fround($505 + $506);
       $508 = (($445) + 32|0);
       HEAPF32[$508>>2] = $507;
       $509 = (($j$1261) + 1)|0;
       $510 = HEAP32[$this>>2]|0;
       $511 = (($510) + 4|0);
       $512 = HEAP32[$511>>2]|0;
       $513 = ($509|0)<($512|0);
       if ($513) {
        $443 = $510;$j$1261 = $509;
       } else {
        $727 = $510;
        break L56;
       }
      }
     }
     while(1) {
      $365 = HEAP32[$366>>2]|0;
      $367 = (($365) + ($j$1261$us<<2)|0);
      $368 = HEAP32[$367>>2]|0;
      $369 = HEAP32[$368>>2]|0;
      $370 = (($368) + 4|0);
      $371 = HEAP32[$370>>2]|0;
      $372 = (($368) + 8|0);
      $373 = HEAP32[$372>>2]|0;
      $$idx125$us = (($verts) + (($369*12)|0)|0);
      $$idx125$val$us = Math_fround(HEAPF32[$$idx125$us>>2]);
      $$idx126$us = ((($verts) + (($369*12)|0)|0) + 4|0);
      $$idx126$val$us = Math_fround(HEAPF32[$$idx126$us>>2]);
      $$idx127$us = ((($verts) + (($369*12)|0)|0) + 8|0);
      $$idx127$val$us = Math_fround(HEAPF32[$$idx127$us>>2]);
      $$idx128$us = (($verts) + (($371*12)|0)|0);
      $$idx128$val$us = Math_fround(HEAPF32[$$idx128$us>>2]);
      $$idx129$us = ((($verts) + (($371*12)|0)|0) + 4|0);
      $$idx129$val$us = Math_fround(HEAPF32[$$idx129$us>>2]);
      $$idx130$us = ((($verts) + (($371*12)|0)|0) + 8|0);
      $$idx130$val$us = Math_fround(HEAPF32[$$idx130$us>>2]);
      $$idx131$us = (($verts) + (($373*12)|0)|0);
      $$idx131$val$us = Math_fround(HEAPF32[$$idx131$us>>2]);
      $$idx132$us = ((($verts) + (($373*12)|0)|0) + 4|0);
      $$idx132$val$us = Math_fround(HEAPF32[$$idx132$us>>2]);
      $$idx133$us = ((($verts) + (($373*12)|0)|0) + 8|0);
      $$idx133$val$us = Math_fround(HEAPF32[$$idx133$us>>2]);
      $374 = Math_fround($$idx128$val$us - $$idx125$val$us);
      $375 = Math_fround($$idx129$val$us - $$idx126$val$us);
      $376 = Math_fround($$idx130$val$us - $$idx127$val$us);
      $377 = Math_fround($$idx131$val$us - $$idx128$val$us);
      $378 = Math_fround($$idx132$val$us - $$idx129$val$us);
      $379 = Math_fround($$idx133$val$us - $$idx130$val$us);
      $380 = Math_fround($375 * $379);
      $381 = Math_fround($376 * $378);
      $382 = Math_fround($380 - $381);
      $383 = Math_fround($376 * $377);
      $384 = Math_fround($374 * $379);
      $385 = Math_fround($383 - $384);
      $386 = Math_fround($374 * $378);
      $387 = Math_fround($375 * $377);
      $388 = Math_fround($386 - $387);
      $389 = Math_fround($382 * $382);
      $390 = Math_fround($385 * $385);
      $391 = Math_fround($389 + $390);
      $392 = Math_fround($388 * $388);
      $393 = Math_fround($392 + $391);
      $394 = (Math_fround(Math_sqrt((Math_fround($393)))));
      $395 = $394 == Math_fround(0.0);
      if ($395) {
       $storemerge314 = Math_fround(0.0);$storemerge315 = Math_fround(0.0);$storemerge318 = Math_fround(1.0);
      } else {
       $396 = Math_fround(Math_fround(1.0) / $394);
       $397 = Math_fround($382 * $396);
       $398 = Math_fround($385 * $396);
       $399 = Math_fround($388 * $396);
       $storemerge314 = $399;$storemerge315 = $398;$storemerge318 = $397;
      }
      HEAPF32[$n>>2] = $storemerge318;
      HEAPF32[$363>>2] = $storemerge315;
      HEAPF32[$364>>2] = $storemerge314;
      $400 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$n,$allow)|0);
      $401 = (($368) + 28|0);
      HEAP32[$401>>2] = $400;
      $402 = HEAP32[$368>>2]|0;
      $$idx46$us = (($verts) + (($400*12)|0)|0);
      $$idx46$val$us = Math_fround(HEAPF32[$$idx46$us>>2]);
      $$idx47$us = ((($verts) + (($400*12)|0)|0) + 4|0);
      $$idx47$val$us = Math_fround(HEAPF32[$$idx47$us>>2]);
      $$idx48$us = ((($verts) + (($400*12)|0)|0) + 8|0);
      $$idx48$val$us = Math_fround(HEAPF32[$$idx48$us>>2]);
      $$idx49$us = (($verts) + (($402*12)|0)|0);
      $$idx49$val$us = Math_fround(HEAPF32[$$idx49$us>>2]);
      $$idx50$us = ((($verts) + (($402*12)|0)|0) + 4|0);
      $$idx50$val$us = Math_fround(HEAPF32[$$idx50$us>>2]);
      $$idx51$us = ((($verts) + (($402*12)|0)|0) + 8|0);
      $$idx51$val$us = Math_fround(HEAPF32[$$idx51$us>>2]);
      $403 = Math_fround($$idx46$val$us - $$idx49$val$us);
      $404 = Math_fround($$idx47$val$us - $$idx50$val$us);
      $405 = Math_fround($$idx48$val$us - $$idx51$val$us);
      $n$idx$val$us = Math_fround(HEAPF32[$n>>2]);
      $n$idx78$val$us = Math_fround(HEAPF32[$363>>2]);
      $n$idx79$val$us = Math_fround(HEAPF32[$364>>2]);
      $406 = Math_fround($403 * $n$idx$val$us);
      $407 = Math_fround($404 * $n$idx78$val$us);
      $408 = Math_fround($406 + $407);
      $409 = Math_fround($405 * $n$idx79$val$us);
      $410 = Math_fround($408 + $409);
      $411 = (($368) + 32|0);
      HEAPF32[$411>>2] = $410;
      $412 = HEAP32[$370>>2]|0;
      $$idx40$us = (($verts) + (($412*12)|0)|0);
      $$idx40$val$us = Math_fround(HEAPF32[$$idx40$us>>2]);
      $$idx41$us = ((($verts) + (($412*12)|0)|0) + 4|0);
      $$idx41$val$us = Math_fround(HEAPF32[$$idx41$us>>2]);
      $$idx42$us = ((($verts) + (($412*12)|0)|0) + 8|0);
      $$idx42$val$us = Math_fround(HEAPF32[$$idx42$us>>2]);
      $$idx43$val$us = Math_fround(HEAPF32[$$idx49$us>>2]);
      $$idx44$val$us = Math_fround(HEAPF32[$$idx50$us>>2]);
      $$idx45$val$us = Math_fround(HEAPF32[$$idx51$us>>2]);
      $413 = Math_fround($$idx40$val$us - $$idx43$val$us);
      $414 = Math_fround($$idx41$val$us - $$idx44$val$us);
      $415 = Math_fround($$idx42$val$us - $$idx45$val$us);
      $416 = HEAP32[$372>>2]|0;
      $$idx34$us = (($verts) + (($416*12)|0)|0);
      $$idx34$val$us = Math_fround(HEAPF32[$$idx34$us>>2]);
      $$idx35$us = ((($verts) + (($416*12)|0)|0) + 4|0);
      $$idx35$val$us = Math_fround(HEAPF32[$$idx35$us>>2]);
      $$idx36$us = ((($verts) + (($416*12)|0)|0) + 8|0);
      $$idx36$val$us = Math_fround(HEAPF32[$$idx36$us>>2]);
      $417 = Math_fround($$idx34$val$us - $$idx40$val$us);
      $418 = Math_fround($$idx35$val$us - $$idx41$val$us);
      $419 = Math_fround($$idx36$val$us - $$idx42$val$us);
      $420 = Math_fround($414 * $419);
      $421 = Math_fround($415 * $418);
      $422 = Math_fround($420 - $421);
      $423 = Math_fround($415 * $417);
      $424 = Math_fround($413 * $419);
      $425 = Math_fround($423 - $424);
      $426 = Math_fround($413 * $418);
      $427 = Math_fround($414 * $417);
      $428 = Math_fround($426 - $427);
      $429 = Math_fround($422 * $422);
      $430 = Math_fround($425 * $425);
      $431 = Math_fround($429 + $430);
      $432 = Math_fround($428 * $428);
      $433 = Math_fround($432 + $431);
      $434 = (Math_fround(Math_sqrt((Math_fround($433)))));
      $435 = $434 < $436;
      if ($435) {
       break;
      }
      $437 = (($j$1261$us) + 1)|0;
      $438 = HEAP32[$this>>2]|0;
      $439 = (($438) + 4|0);
      $440 = HEAP32[$439>>2]|0;
      $441 = ($437|0)<($440|0);
      if ($441) {
       $366 = $438;$j$1261$us = $437;
      } else {
       $727 = $438;
       break L56;
      }
     }
     $477 = HEAP32[$this>>2]|0;
     $$idx5$val = HEAP32[$477>>2]|0;
     $478 = (($307) + 24|0);
     $479 = HEAP32[$478>>2]|0;
     $480 = (($$idx5$val) + ($479<<2)|0);
     HEAP32[$480>>2] = 0;
     $481 = ($307|0)==(0|0);
     if (!($481)) {
      __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$307);
     }
     $482 = HEAP32[$this>>2]|0;
     $$idx4$val = HEAP32[$482>>2]|0;
     $483 = (($321) + 24|0);
     $484 = HEAP32[$483>>2]|0;
     $485 = (($$idx4$val) + ($484<<2)|0);
     HEAP32[$485>>2] = 0;
     $486 = ($321|0)==(0|0);
     if (!($486)) {
      __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$321);
     }
     $487 = HEAP32[$this>>2]|0;
     $$idx3$val = HEAP32[$487>>2]|0;
     $488 = (($335) + 24|0);
     $489 = HEAP32[$488>>2]|0;
     $490 = (($$idx3$val) + ($489<<2)|0);
     HEAP32[$490>>2] = 0;
     $491 = ($335|0)==(0|0);
     if (!($491)) {
      __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$335);
     }
     $492 = HEAP32[$this>>2]|0;
     $$idx$val = HEAP32[$492>>2]|0;
     $493 = (($349) + 24|0);
     $494 = HEAP32[$493>>2]|0;
     $495 = (($$idx$val) + ($494<<2)|0);
     HEAP32[$495>>2] = 0;
     $496 = ($349|0)==(0|0);
     if ($496) {
      $$0 = 3;$724 = $354;
      break L54;
     }
     __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$349);
     $$0 = 3;$724 = $354;
     break L54;
    } else {
     $727 = $359;
    }
   } while(0);
   $vlimit$op = (($vlimit) + -4)|0;
   $514 = $11 ? 999999996 : $vlimit$op;
   $515 = ($514|0)>(0);
   L82: do {
    if ($515) {
     $516 = (($n6) + 4|0);
     $517 = (($n6) + 8|0);
     $518 = Math_fround($79 * Math_fround(0.00999999977648258209228));
     $$12257 = $514;$520 = $727;
     while(1) {
      $519 = (($520) + 4|0);
      $521 = HEAP32[$519>>2]|0;
      $522 = ($521|0)>(0);
      if (!($522)) {
       $$12$lcssa = $$12257;
       break L82;
      }
      $728 = 0;$i$02$i = 0;$t$01$i = 0;
      while(1) {
       $523 = HEAP32[$520>>2]|0;
       $524 = (($523) + ($i$02$i<<2)|0);
       $525 = HEAP32[$524>>2]|0;
       if ($728) {
        $526 = ($525|0)==(0|0);
        if ($526) {
         $t$1$i = $t$01$i;
        } else {
         $527 = (($t$01$i) + 32|0);
         $528 = Math_fround(HEAPF32[$527>>2]);
         $529 = (($525) + 32|0);
         $530 = Math_fround(HEAPF32[$529>>2]);
         $531 = $528 < $530;
         if ($531) {
          label = 61;
         } else {
          $t$1$i = $t$01$i;
         }
        }
       } else {
        label = 61;
       }
       if ((label|0) == 61) {
        label = 0;
        $t$1$i = $525;
       }
       $532 = (($i$02$i) + 1)|0;
       $533 = ($t$1$i|0)!=(0|0);
       $exitcond = ($532|0)==($521|0);
       if ($exitcond) {
        break;
       } else {
        $728 = $533;$i$02$i = $532;$t$01$i = $t$1$i;
       }
      }
      if (!($533)) {
       $$12$lcssa = $$12257;
       break L82;
      }
      $534 = (($t$1$i) + 32|0);
      $535 = Math_fround(HEAPF32[$534>>2]);
      $536 = $535 > $79;
      $537 = $536 ? $t$1$i : 0;
      $538 = ($537|0)==(0|0);
      if ($538) {
       $$12$lcssa = $$12257;
       break L82;
      }
      $539 = (($537) + 28|0);
      $540 = HEAP32[$539>>2]|0;
      $541 = (($354) + ($540<<2)|0);
      HEAP32[$541>>2] = 1;
      $542 = HEAP32[$519>>2]|0;
      $543 = ($542|0)==(0);
      L98: do {
       if ($543) {
        $660 = $520;
       } else {
        $p$idx$i178 = (($verts) + (($540*12)|0)|0);
        $p$idx1$i180 = ((($verts) + (($540*12)|0)|0) + 4|0);
        $p$idx2$i182 = ((($verts) + (($540*12)|0)|0) + 8|0);
        $$in = $542;$546 = $523;$729 = $520;
        while(1) {
         $544 = (($$in) + -1)|0;
         $545 = (($546) + ($544<<2)|0);
         $547 = HEAP32[$545>>2]|0;
         $548 = ($547|0)==(0|0);
         if ($548) {
          $593 = $729;
         } else {
          $549 = HEAP32[$547>>2]|0;
          $550 = (($547) + 4|0);
          $551 = HEAP32[$550>>2]|0;
          $552 = (($547) + 8|0);
          $553 = HEAP32[$552>>2]|0;
          $$idx10$i160 = (($verts) + (($549*12)|0)|0);
          $$idx10$val$i161 = Math_fround(HEAPF32[$$idx10$i160>>2]);
          $$idx11$i162 = ((($verts) + (($549*12)|0)|0) + 4|0);
          $$idx11$val$i163 = Math_fround(HEAPF32[$$idx11$i162>>2]);
          $$idx12$i164 = ((($verts) + (($549*12)|0)|0) + 8|0);
          $$idx12$val$i165 = Math_fround(HEAPF32[$$idx12$i164>>2]);
          $$idx13$i166 = (($verts) + (($551*12)|0)|0);
          $$idx13$val$i167 = Math_fround(HEAPF32[$$idx13$i166>>2]);
          $$idx14$i168 = ((($verts) + (($551*12)|0)|0) + 4|0);
          $$idx14$val$i169 = Math_fround(HEAPF32[$$idx14$i168>>2]);
          $$idx15$i170 = ((($verts) + (($551*12)|0)|0) + 8|0);
          $$idx15$val$i171 = Math_fround(HEAPF32[$$idx15$i170>>2]);
          $$idx16$i172 = (($verts) + (($553*12)|0)|0);
          $$idx16$val$i173 = Math_fround(HEAPF32[$$idx16$i172>>2]);
          $$idx17$i174 = ((($verts) + (($553*12)|0)|0) + 4|0);
          $$idx17$val$i175 = Math_fround(HEAPF32[$$idx17$i174>>2]);
          $$idx18$i176 = ((($verts) + (($553*12)|0)|0) + 8|0);
          $$idx18$val$i177 = Math_fround(HEAPF32[$$idx18$i176>>2]);
          $554 = Math_fround($$idx13$val$i167 - $$idx10$val$i161);
          $555 = Math_fround($$idx14$val$i169 - $$idx11$val$i163);
          $556 = Math_fround($$idx15$val$i171 - $$idx12$val$i165);
          $557 = Math_fround($$idx16$val$i173 - $$idx13$val$i167);
          $558 = Math_fround($$idx17$val$i175 - $$idx14$val$i169);
          $559 = Math_fround($$idx18$val$i177 - $$idx15$val$i171);
          $560 = Math_fround($555 * $559);
          $561 = Math_fround($556 * $558);
          $562 = Math_fround($560 - $561);
          $563 = Math_fround($556 * $557);
          $564 = Math_fround($554 * $559);
          $565 = Math_fround($563 - $564);
          $566 = Math_fround($554 * $558);
          $567 = Math_fround($555 * $557);
          $568 = Math_fround($566 - $567);
          $569 = Math_fround($562 * $562);
          $570 = Math_fround($565 * $565);
          $571 = Math_fround($569 + $570);
          $572 = Math_fround($568 * $568);
          $573 = Math_fround($572 + $571);
          $574 = (Math_fround(Math_sqrt((Math_fround($573)))));
          $575 = $574 == Math_fround(0.0);
          if ($575) {
           $584 = Math_fround(1.0);$586 = Math_fround(0.0);$589 = Math_fround(0.0);
          } else {
           $576 = Math_fround(Math_fround(1.0) / $574);
           $577 = Math_fround($562 * $576);
           $578 = Math_fround($565 * $576);
           $579 = Math_fround($568 * $576);
           $584 = $577;$586 = $578;$589 = $579;
          }
          $p$idx$val$i179 = Math_fround(HEAPF32[$p$idx$i178>>2]);
          $p$idx1$val$i181 = Math_fround(HEAPF32[$p$idx1$i180>>2]);
          $p$idx2$val$i183 = Math_fround(HEAPF32[$p$idx2$i182>>2]);
          $580 = Math_fround($p$idx$val$i179 - $$idx10$val$i161);
          $581 = Math_fround($p$idx1$val$i181 - $$idx11$val$i163);
          $582 = Math_fround($p$idx2$val$i183 - $$idx12$val$i165);
          $583 = Math_fround($584 * $580);
          $585 = Math_fround($586 * $581);
          $587 = Math_fround($583 + $585);
          $588 = Math_fround($589 * $582);
          $590 = Math_fround($587 + $588);
          $591 = $590 > $518;
          if ($591) {
           __ZN5physx11HullLibrary7extrudeEPNS_3TriEi($this,$547,$540);
           $$pre297 = HEAP32[$this>>2]|0;
           $593 = $$pre297;
          } else {
           $593 = $729;
          }
         }
         $592 = ($544|0)==(0);
         if ($592) {
          break;
         }
         $$pre305 = HEAP32[$593>>2]|0;
         $$in = $544;$546 = $$pre305;$729 = $593;
        }
        $$phi$trans$insert = (($593) + 4|0);
        $$pre = HEAP32[$$phi$trans$insert>>2]|0;
        $594 = ($$pre|0)==(0);
        if ($594) {
         $660 = $593;
        } else {
         $$in280 = $$pre;$597 = $593;
         while(1) {
          $595 = (($$in280) + -1)|0;
          $596 = HEAP32[$597>>2]|0;
          $598 = (($596) + ($595<<2)|0);
          $599 = HEAP32[$598>>2]|0;
          $600 = ($599|0)==(0|0);
          do {
           if ($600) {
            $730 = $597;$j$3$be = $595;
           } else {
            $601 = HEAP32[$599>>2]|0;
            $602 = ($601|0)==($540|0);
            do {
             if ($602) {
              $$phi$trans$insert302 = (($599) + 4|0);
              $$pre303 = HEAP32[$$phi$trans$insert302>>2]|0;
              $611 = $$pre303;
             } else {
              $603 = (($599) + 4|0);
              $604 = HEAP32[$603>>2]|0;
              $605 = ($604|0)==($540|0);
              if ($605) {
               $611 = $540;
               break;
              }
              $606 = (($599) + 8|0);
              $607 = HEAP32[$606>>2]|0;
              $608 = ($607|0)==($540|0);
              if ($608) {
               $611 = $604;
              } else {
               $660 = $597;
               break L98;
              }
             }
            } while(0);
            $609 = (($599) + 8|0);
            $610 = HEAP32[$609>>2]|0;
            $$idx10$i = (($verts) + (($601*12)|0)|0);
            $$idx10$val$i151 = Math_fround(HEAPF32[$$idx10$i>>2]);
            $$idx11$i = ((($verts) + (($601*12)|0)|0) + 4|0);
            $$idx11$val$i152 = Math_fround(HEAPF32[$$idx11$i>>2]);
            $$idx12$i = ((($verts) + (($601*12)|0)|0) + 8|0);
            $$idx12$val$i = Math_fround(HEAPF32[$$idx12$i>>2]);
            $$idx13$i = (($verts) + (($611*12)|0)|0);
            $$idx13$val$i = Math_fround(HEAPF32[$$idx13$i>>2]);
            $$idx14$i = ((($verts) + (($611*12)|0)|0) + 4|0);
            $$idx14$val$i = Math_fround(HEAPF32[$$idx14$i>>2]);
            $$idx15$i153 = ((($verts) + (($611*12)|0)|0) + 8|0);
            $$idx15$val$i154 = Math_fround(HEAPF32[$$idx15$i153>>2]);
            $$idx16$i155 = (($verts) + (($610*12)|0)|0);
            $$idx16$val$i156 = Math_fround(HEAPF32[$$idx16$i155>>2]);
            $$idx17$i157 = ((($verts) + (($610*12)|0)|0) + 4|0);
            $$idx17$val$i158 = Math_fround(HEAPF32[$$idx17$i157>>2]);
            $$idx18$i = ((($verts) + (($610*12)|0)|0) + 8|0);
            $$idx18$val$i159 = Math_fround(HEAPF32[$$idx18$i>>2]);
            $612 = Math_fround($$idx13$val$i - $$idx10$val$i151);
            $613 = Math_fround($$idx14$val$i - $$idx11$val$i152);
            $614 = Math_fround($$idx15$val$i154 - $$idx12$val$i);
            $615 = Math_fround($$idx16$val$i156 - $$idx13$val$i);
            $616 = Math_fround($$idx17$val$i158 - $$idx14$val$i);
            $617 = Math_fround($$idx18$val$i159 - $$idx15$val$i154);
            $618 = Math_fround($613 * $617);
            $619 = Math_fround($614 * $616);
            $620 = Math_fround($618 - $619);
            $621 = Math_fround($614 * $615);
            $622 = Math_fround($612 * $617);
            $623 = Math_fround($621 - $622);
            $624 = Math_fround($612 * $616);
            $625 = Math_fround($613 * $615);
            $626 = Math_fround($624 - $625);
            $627 = Math_fround($620 * $620);
            $628 = Math_fround($623 * $623);
            $629 = Math_fround($627 + $628);
            $630 = Math_fround($626 * $626);
            $631 = Math_fround($630 + $629);
            $632 = (Math_fround(Math_sqrt((Math_fround($631)))));
            $633 = $632 == Math_fround(0.0);
            if ($633) {
             $642 = Math_fround(1.0);$644 = Math_fround(0.0);$647 = Math_fround(0.0);
            } else {
             $634 = Math_fround(Math_fround(1.0) / $632);
             $635 = Math_fround($620 * $634);
             $636 = Math_fround($623 * $634);
             $637 = Math_fround($626 * $634);
             $642 = $635;$644 = $636;$647 = $637;
            }
            $638 = Math_fround($295 - $$idx10$val$i151);
            $639 = Math_fround($296 - $$idx11$val$i152);
            $640 = Math_fround($297 - $$idx12$val$i);
            $641 = Math_fround($638 * $642);
            $643 = Math_fround($639 * $644);
            $645 = Math_fround($643 + $641);
            $646 = Math_fround($640 * $647);
            $648 = Math_fround($646 + $645);
            $649 = $648 > $518;
            $650 = $632 < $436;
            $or$cond = $649 | $650;
            if (!($or$cond)) {
             $730 = $597;$j$3$be = $595;
             break;
            }
            $651 = (($599) + 12|0);
            $652 = HEAP32[$651>>2]|0;
            $653 = (($596) + ($652<<2)|0);
            $654 = HEAP32[$653>>2]|0;
            __ZN5physx11HullLibrary7extrudeEPNS_3TriEi($this,$654,$540);
            $655 = HEAP32[$this>>2]|0;
            $656 = (($655) + 4|0);
            $657 = HEAP32[$656>>2]|0;
            $730 = $655;$j$3$be = $657;
           }
          } while(0);
          $658 = ($j$3$be|0)==(0);
          if ($658) {
           $660 = $730;
           break;
          } else {
           $$in280 = $j$3$be;$597 = $730;
          }
         }
        }
       }
      } while(0);
      $659 = (($660) + 4|0);
      $661 = HEAP32[$659>>2]|0;
      $662 = ($661|0)==(0);
      L126: do {
       if (!($662)) {
        $$in281 = $661;$665 = $660;
        while(1) {
         $663 = (($$in281) + -1)|0;
         $664 = HEAP32[$665>>2]|0;
         $666 = (($664) + ($663<<2)|0);
         $667 = HEAP32[$666>>2]|0;
         $668 = ($667|0)==(0|0);
         do {
          if (!($668)) {
           $669 = (($667) + 28|0);
           $670 = HEAP32[$669>>2]|0;
           $671 = ($670|0)>(-1);
           if ($671) {
            break L126;
           }
           $672 = HEAP32[$667>>2]|0;
           $673 = (($667) + 4|0);
           $674 = HEAP32[$673>>2]|0;
           $675 = (($667) + 8|0);
           $676 = HEAP32[$675>>2]|0;
           $$idx116 = (($verts) + (($672*12)|0)|0);
           $$idx116$val = Math_fround(HEAPF32[$$idx116>>2]);
           $$idx117 = ((($verts) + (($672*12)|0)|0) + 4|0);
           $$idx117$val = Math_fround(HEAPF32[$$idx117>>2]);
           $$idx118 = ((($verts) + (($672*12)|0)|0) + 8|0);
           $$idx118$val = Math_fround(HEAPF32[$$idx118>>2]);
           $$idx119 = (($verts) + (($674*12)|0)|0);
           $$idx119$val = Math_fround(HEAPF32[$$idx119>>2]);
           $$idx120 = ((($verts) + (($674*12)|0)|0) + 4|0);
           $$idx120$val = Math_fround(HEAPF32[$$idx120>>2]);
           $$idx121 = ((($verts) + (($674*12)|0)|0) + 8|0);
           $$idx121$val = Math_fround(HEAPF32[$$idx121>>2]);
           $$idx122 = (($verts) + (($676*12)|0)|0);
           $$idx122$val = Math_fround(HEAPF32[$$idx122>>2]);
           $$idx123 = ((($verts) + (($676*12)|0)|0) + 4|0);
           $$idx123$val = Math_fround(HEAPF32[$$idx123>>2]);
           $$idx124 = ((($verts) + (($676*12)|0)|0) + 8|0);
           $$idx124$val = Math_fround(HEAPF32[$$idx124>>2]);
           $677 = Math_fround($$idx119$val - $$idx116$val);
           $678 = Math_fround($$idx120$val - $$idx117$val);
           $679 = Math_fround($$idx121$val - $$idx118$val);
           $680 = Math_fround($$idx122$val - $$idx119$val);
           $681 = Math_fround($$idx123$val - $$idx120$val);
           $682 = Math_fround($$idx124$val - $$idx121$val);
           $683 = Math_fround($678 * $682);
           $684 = Math_fround($679 * $681);
           $685 = Math_fround($683 - $684);
           $686 = Math_fround($679 * $680);
           $687 = Math_fround($677 * $682);
           $688 = Math_fround($686 - $687);
           $689 = Math_fround($677 * $681);
           $690 = Math_fround($678 * $680);
           $691 = Math_fround($689 - $690);
           $692 = Math_fround($685 * $685);
           $693 = Math_fround($688 * $688);
           $694 = Math_fround($692 + $693);
           $695 = Math_fround($691 * $691);
           $696 = Math_fround($695 + $694);
           $697 = (Math_fround(Math_sqrt((Math_fround($696)))));
           $698 = $697 == Math_fround(0.0);
           if ($698) {
            $storemerge = Math_fround(0.0);$storemerge311 = Math_fround(0.0);$storemerge316 = Math_fround(1.0);
           } else {
            $699 = Math_fround(Math_fround(1.0) / $697);
            $700 = Math_fround($685 * $699);
            $701 = Math_fround($688 * $699);
            $702 = Math_fround($691 * $699);
            $storemerge = $702;$storemerge311 = $701;$storemerge316 = $700;
           }
           HEAPF32[$n6>>2] = $storemerge316;
           HEAPF32[$516>>2] = $storemerge311;
           HEAPF32[$517>>2] = $storemerge;
           $703 = (__ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($verts,$verts_count,$n6,$allow)|0);
           HEAP32[$669>>2] = $703;
           $704 = (($354) + ($703<<2)|0);
           $705 = HEAP32[$704>>2]|0;
           $706 = ($705|0)==(0);
           if ($706) {
            $707 = HEAP32[$667>>2]|0;
            $$idx16 = (($verts) + (($703*12)|0)|0);
            $$idx16$val = Math_fround(HEAPF32[$$idx16>>2]);
            $$idx17 = ((($verts) + (($703*12)|0)|0) + 4|0);
            $$idx17$val = Math_fround(HEAPF32[$$idx17>>2]);
            $$idx18 = ((($verts) + (($703*12)|0)|0) + 8|0);
            $$idx18$val = Math_fround(HEAPF32[$$idx18>>2]);
            $$idx19 = (($verts) + (($707*12)|0)|0);
            $$idx19$val = Math_fround(HEAPF32[$$idx19>>2]);
            $$idx20 = ((($verts) + (($707*12)|0)|0) + 4|0);
            $$idx20$val = Math_fround(HEAPF32[$$idx20>>2]);
            $$idx21 = ((($verts) + (($707*12)|0)|0) + 8|0);
            $$idx21$val = Math_fround(HEAPF32[$$idx21>>2]);
            $708 = Math_fround($$idx16$val - $$idx19$val);
            $709 = Math_fround($$idx17$val - $$idx20$val);
            $710 = Math_fround($$idx18$val - $$idx21$val);
            $n6$idx$val = Math_fround(HEAPF32[$n6>>2]);
            $n6$idx73$val = Math_fround(HEAPF32[$516>>2]);
            $n6$idx74$val = Math_fround(HEAPF32[$517>>2]);
            $711 = Math_fround($708 * $n6$idx$val);
            $712 = Math_fround($709 * $n6$idx73$val);
            $713 = Math_fround($711 + $712);
            $714 = Math_fround($710 * $n6$idx74$val);
            $715 = Math_fround($713 + $714);
            $716 = (($667) + 32|0);
            HEAPF32[$716>>2] = $715;
            break;
           } else {
            HEAP32[$669>>2] = -1;
            break;
           }
          }
         } while(0);
         $717 = ($663|0)==(0);
         if ($717) {
          break L126;
         }
         $$pre301 = HEAP32[$this>>2]|0;
         $$in281 = $663;$665 = $$pre301;
        }
       }
      } while(0);
      $718 = (($$12257) + -1)|0;
      $719 = ($718|0)>(0);
      if (!($719)) {
       $$12$lcssa = $718;
       break L82;
      }
      $$pre300 = HEAP32[$this>>2]|0;
      $$12257 = $718;$520 = $$pre300;
     }
    } else {
     $$12$lcssa = $514;
    }
   } while(0);
   $720 = ($$12$lcssa|0)==(0);
   $$ = $720 ? 2 : 0;
   $$0 = $$;$724 = $354;
  }
 } while(0);
 $721 = HEAP32[$allow>>2]|0;
 $722 = ($721|0)==(0|0);
 if (!($722)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$721);
  HEAP32[$allow>>2] = 0;
 }
 HEAP32[$19>>2] = 0;
 HEAP32[$20>>2] = 0;
 HEAP32[$allow>>2] = 0;
 $723 = ($724|0)==(0|0);
 if (!($723)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$724);
  HEAP32[$isextreme$sroa$0>>2] = 0;
 }
 HEAP32[$isextreme$sroa$0>>2] = 0;
 $$1 = $$0;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx12maxdirsteridINS_6float3EEEiPKT_iRS3_RNS_12hullLibArray5ArrayIiEE($p,$count,$dir,$allow) {
 $p = $p|0;
 $count = $count|0;
 $dir = $dir|0;
 $allow = $allow|0;
 var $$idx$i = 0, $$idx$i65$us = 0, $$idx$i90 = 0, $$idx$val$i = Math_fround(0), $$idx$val$i66$us = Math_fround(0), $$idx$val$i91 = Math_fround(0), $$idx1$i = 0, $$idx1$i67$us = 0, $$idx1$i92 = 0, $$idx1$val$i = Math_fround(0), $$idx1$val$i68$us = Math_fround(0), $$idx1$val$i93 = Math_fround(0), $$idx2$i = 0, $$idx2$i69$us = 0, $$idx2$i94 = 0, $$idx2$val$i = Math_fround(0), $$idx2$val$i70$us = Math_fround(0), $$idx2$val$i95 = Math_fround(0), $$idx5$i = 0, $$idx5$i56$us = 0;
 var $$idx5$i81 = 0, $$idx5$val$i = Math_fround(0), $$idx5$val$i57$us = Math_fround(0), $$idx5$val$i82 = Math_fround(0), $$idx6$i = 0, $$idx6$i58$us = 0, $$idx6$i83 = 0, $$idx6$val$i = Math_fround(0), $$idx6$val$i59$us = Math_fround(0), $$idx6$val$i84 = Math_fround(0), $$idx7$i = 0, $$idx7$i60$us = 0, $$idx7$i85 = 0, $$idx7$val$i = Math_fround(0), $$idx7$val$i61$us = Math_fround(0), $$idx7$val$i86 = Math_fround(0), $$int = 0, $$pre$i$i = Math_fround(0), $$pre3$i$i = Math_fround(0), $$pre4$i$i = Math_fround(0);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $a$b$i = 0, $a$i = 0, $b$i = 0, $d$0$i$i = Math_fround(0), $dir$idx$val$pre = Math_fround(0), $dir$idx10$i = 0, $dir$idx10$val$i = Math_fround(0), $dir$idx38$val = Math_fround(0), $dir$idx39$val = Math_fround(0), $dir$idx40$val = Math_fround(0), $dir$idx5$val$pre = Math_fround(0), $dir$idx6$val$pre = Math_fround(0), $dir$idx7$val = Math_fround(0), $dir$idx8$val = Math_fround(0), $dir$idx8$val$i = Math_fround(0), $dir$idx9$i = 0, $dir$idx9$val = Math_fround(0), $dir$idx9$val$i = Math_fround(0), $exitcond$i = 0;
 var $exitcond$i72$us = 0, $exitcond$i97 = 0, $i$012$i = 0, $i$012$i54$us = 0, $i$012$i79 = 0, $indvar$conv = Math_fround(0), $m$0$lcssa$i = 0, $m$0$lcssa$i146 = 0, $m$0$lcssa$i147 = 0, $m$0$lcssa$i98 = 0, $m$011$i = 0, $m$011$i55$us = 0, $m$011$i80 = 0, $m$1$i = 0, $m$1$i71$us = 0, $m$1$i96 = 0, $ma$0133 = 0, $mc$0127 = 0, $mc$0127$us = 0, $or$cond = 0;
 var $or$cond1 = 0, $or$cond2 = 0, $or$cond2$us = 0, $v$idx$val$i$i = Math_fround(0), $v$idx1$i$i = 0, $v$idx1$val$i$i = Math_fround(0), $v$idx2$i$i = 0, $v$idx2$val$i$i = Math_fround(0), $x$0129$int = 0, $xx$0128 = Math_fround(0), $xx$0128$us = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $a$i = sp + 12|0;
 $b$i = sp;
 $0 = ($count|0)>(0);
 $dir$idx9$i = (($dir) + 4|0);
 $dir$idx10$i = (($dir) + 8|0);
 $1 = (($a$i) + 4|0);
 $2 = (($a$i) + 8|0);
 $3 = (($b$i) + 4|0);
 $4 = (($b$i) + 8|0);
 L1: while(1) {
  $5 = HEAP32[$allow>>2]|0;
  if ($0) {
   $i$012$i = 0;$m$011$i = -1;
   while(1) {
    $6 = (($5) + ($i$012$i<<2)|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==(0);
    do {
     if ($8) {
      $m$1$i = $m$011$i;
     } else {
      $9 = ($m$011$i|0)==(-1);
      if (!($9)) {
       $$idx5$i = (($p) + (($i$012$i*12)|0)|0);
       $$idx5$val$i = Math_fround(HEAPF32[$$idx5$i>>2]);
       $$idx6$i = ((($p) + (($i$012$i*12)|0)|0) + 4|0);
       $$idx6$val$i = Math_fround(HEAPF32[$$idx6$i>>2]);
       $$idx7$i = ((($p) + (($i$012$i*12)|0)|0) + 8|0);
       $$idx7$val$i = Math_fround(HEAPF32[$$idx7$i>>2]);
       $dir$idx8$val$i = Math_fround(HEAPF32[$dir>>2]);
       $dir$idx9$val$i = Math_fround(HEAPF32[$dir$idx9$i>>2]);
       $dir$idx10$val$i = Math_fround(HEAPF32[$dir$idx10$i>>2]);
       $10 = Math_fround($$idx5$val$i * $dir$idx8$val$i);
       $11 = Math_fround($$idx6$val$i * $dir$idx9$val$i);
       $12 = Math_fround($10 + $11);
       $13 = Math_fround($$idx7$val$i * $dir$idx10$val$i);
       $14 = Math_fround($12 + $13);
       $$idx$i = (($p) + (($m$011$i*12)|0)|0);
       $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
       $$idx1$i = ((($p) + (($m$011$i*12)|0)|0) + 4|0);
       $$idx1$val$i = Math_fround(HEAPF32[$$idx1$i>>2]);
       $$idx2$i = ((($p) + (($m$011$i*12)|0)|0) + 8|0);
       $$idx2$val$i = Math_fround(HEAPF32[$$idx2$i>>2]);
       $15 = Math_fround($dir$idx8$val$i * $$idx$val$i);
       $16 = Math_fround($dir$idx9$val$i * $$idx1$val$i);
       $17 = Math_fround($15 + $16);
       $18 = Math_fround($dir$idx10$val$i * $$idx2$val$i);
       $19 = Math_fround($17 + $18);
       $20 = $14 > $19;
       if (!($20)) {
        $m$1$i = $m$011$i;
        break;
       }
      }
      $m$1$i = $i$012$i;
     }
    } while(0);
    $21 = (($i$012$i) + 1)|0;
    $exitcond$i = ($21|0)==($count|0);
    if ($exitcond$i) {
     $m$0$lcssa$i = $m$1$i;
     break;
    } else {
     $i$012$i = $21;$m$011$i = $m$1$i;
    }
   }
  } else {
   $m$0$lcssa$i = -1;
  }
  $22 = (($5) + ($m$0$lcssa$i<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(3);
  if ($24) {
   $m$0$lcssa$i146 = $m$0$lcssa$i;
   label = 37;
   break;
  }
  $dir$idx7$val = Math_fround(HEAPF32[$dir>>2]);
  $dir$idx8$val = Math_fround(HEAPF32[$dir$idx9$i>>2]);
  $dir$idx9$val = Math_fround(HEAPF32[$dir$idx10$i>>2]);
  $25 = Math_fround($dir$idx9$val * Math_fround(0.0));
  $26 = Math_fround($dir$idx8$val - $25);
  $27 = Math_fround($25 - $dir$idx7$val);
  $28 = Math_fround($dir$idx7$val * Math_fround(0.0));
  $29 = Math_fround($dir$idx8$val * Math_fround(0.0));
  $30 = Math_fround($28 - $29);
  HEAPF32[$a$i>>2] = $26;
  HEAPF32[$1>>2] = $27;
  HEAPF32[$2>>2] = $30;
  $31 = Math_fround($29 - $dir$idx9$val);
  $32 = Math_fround($25 - $28);
  $33 = Math_fround($dir$idx7$val - $29);
  HEAPF32[$b$i>>2] = $31;
  HEAPF32[$3>>2] = $32;
  HEAPF32[$4>>2] = $33;
  $34 = Math_fround($26 * $26);
  $35 = Math_fround($27 * $27);
  $36 = Math_fround($34 + $35);
  $37 = Math_fround($30 * $30);
  $38 = Math_fround($37 + $36);
  $39 = (Math_fround(Math_sqrt((Math_fround($38)))));
  $40 = Math_fround($31 * $31);
  $41 = Math_fround($32 * $32);
  $42 = Math_fround($40 + $41);
  $43 = Math_fround($33 * $33);
  $44 = Math_fround($43 + $42);
  $45 = (Math_fround(Math_sqrt((Math_fround($44)))));
  $46 = $39 > $45;
  $a$b$i = $46 ? $a$i : $b$i;
  $v$idx$val$i$i = Math_fround(HEAPF32[$a$b$i>>2]);
  $v$idx1$i$i = (($a$b$i) + 4|0);
  $v$idx1$val$i$i = Math_fround(HEAPF32[$v$idx1$i$i>>2]);
  $v$idx2$i$i = (($a$b$i) + 8|0);
  $v$idx2$val$i$i = Math_fround(HEAPF32[$v$idx2$i$i>>2]);
  $47 = Math_fround($v$idx$val$i$i * $v$idx$val$i$i);
  $48 = Math_fround($v$idx1$val$i$i * $v$idx1$val$i$i);
  $49 = Math_fround($47 + $48);
  $50 = Math_fround($v$idx2$val$i$i * $v$idx2$val$i$i);
  $51 = Math_fround($49 + $50);
  $52 = (Math_fround(Math_sqrt((Math_fround($51)))));
  $53 = $52 == Math_fround(0.0);
  if ($53) {
   (_puts((534992|0))|0);
   $$pre$i$i = Math_fround(HEAPF32[$a$b$i>>2]);
   $$pre3$i$i = Math_fround(HEAPF32[$v$idx1$i$i>>2]);
   $$pre4$i$i = Math_fround(HEAPF32[$v$idx2$i$i>>2]);
   $dir$idx$val$pre = Math_fround(HEAPF32[$dir>>2]);
   $dir$idx5$val$pre = Math_fround(HEAPF32[$dir$idx9$i>>2]);
   $dir$idx6$val$pre = Math_fround(HEAPF32[$dir$idx10$i>>2]);
   $56 = $$pre$i$i;$58 = $$pre3$i$i;$60 = $$pre4$i$i;$d$0$i$i = Math_fround(0.100000001490116119385);$dir$idx38$val = $dir$idx$val$pre;$dir$idx39$val = $dir$idx5$val$pre;$dir$idx40$val = $dir$idx6$val$pre;
  } else {
   $56 = $v$idx$val$i$i;$58 = $v$idx1$val$i$i;$60 = $v$idx2$val$i$i;$d$0$i$i = $52;$dir$idx38$val = $dir$idx7$val;$dir$idx39$val = $dir$idx8$val;$dir$idx40$val = $dir$idx9$val;
  }
  $54 = Math_fround(Math_fround(1.0) / $d$0$i$i);
  $55 = Math_fround($56 * $54);
  $57 = Math_fround($58 * $54);
  $59 = Math_fround($60 * $54);
  $61 = Math_fround($57 * $dir$idx40$val);
  $62 = Math_fround($59 * $dir$idx39$val);
  $63 = Math_fround($61 - $62);
  $64 = Math_fround($59 * $dir$idx38$val);
  $65 = Math_fround($55 * $dir$idx40$val);
  $66 = Math_fround($64 - $65);
  $67 = Math_fround($55 * $dir$idx39$val);
  $68 = Math_fround($57 * $dir$idx38$val);
  $69 = Math_fround($67 - $68);
  $ma$0133 = -1;$x$0129$int = 0;
  while(1) {
   $indvar$conv = (Math_fround(($x$0129$int|0)));
   $70 = Math_fround($indvar$conv * Math_fround(0.0174532923847436904907));
   $71 = (Math_fround(+(Math_sin((+$70)))));
   $72 = (Math_fround(+(Math_cos((+$70)))));
   $73 = Math_fround($55 * $71);
   $74 = Math_fround($57 * $71);
   $75 = Math_fround($59 * $71);
   $76 = Math_fround($63 * $72);
   $77 = Math_fround($66 * $72);
   $78 = Math_fround($69 * $72);
   $79 = Math_fround($73 + $76);
   $80 = Math_fround($74 + $77);
   $81 = Math_fround($75 + $78);
   $82 = Math_fround($79 * Math_fround(0.0250000003725290298462));
   $83 = Math_fround($80 * Math_fround(0.0250000003725290298462));
   $84 = Math_fround($81 * Math_fround(0.0250000003725290298462));
   $85 = Math_fround($dir$idx38$val + $82);
   $86 = Math_fround($dir$idx39$val + $83);
   $87 = Math_fround($dir$idx40$val + $84);
   if ($0) {
    $88 = HEAP32[$allow>>2]|0;
    $i$012$i79 = 0;$m$011$i80 = -1;
    while(1) {
     $89 = (($88) + ($i$012$i79<<2)|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($90|0)==(0);
     do {
      if ($91) {
       $m$1$i96 = $m$011$i80;
      } else {
       $92 = ($m$011$i80|0)==(-1);
       if (!($92)) {
        $$idx5$i81 = (($p) + (($i$012$i79*12)|0)|0);
        $$idx5$val$i82 = Math_fround(HEAPF32[$$idx5$i81>>2]);
        $$idx6$i83 = ((($p) + (($i$012$i79*12)|0)|0) + 4|0);
        $$idx6$val$i84 = Math_fround(HEAPF32[$$idx6$i83>>2]);
        $$idx7$i85 = ((($p) + (($i$012$i79*12)|0)|0) + 8|0);
        $$idx7$val$i86 = Math_fround(HEAPF32[$$idx7$i85>>2]);
        $93 = Math_fround($85 * $$idx5$val$i82);
        $94 = Math_fround($86 * $$idx6$val$i84);
        $95 = Math_fround($93 + $94);
        $96 = Math_fround($87 * $$idx7$val$i86);
        $97 = Math_fround($95 + $96);
        $$idx$i90 = (($p) + (($m$011$i80*12)|0)|0);
        $$idx$val$i91 = Math_fround(HEAPF32[$$idx$i90>>2]);
        $$idx1$i92 = ((($p) + (($m$011$i80*12)|0)|0) + 4|0);
        $$idx1$val$i93 = Math_fround(HEAPF32[$$idx1$i92>>2]);
        $$idx2$i94 = ((($p) + (($m$011$i80*12)|0)|0) + 8|0);
        $$idx2$val$i95 = Math_fround(HEAPF32[$$idx2$i94>>2]);
        $98 = Math_fround($85 * $$idx$val$i91);
        $99 = Math_fround($86 * $$idx1$val$i93);
        $100 = Math_fround($98 + $99);
        $101 = Math_fround($87 * $$idx2$val$i95);
        $102 = Math_fround($100 + $101);
        $103 = $97 > $102;
        if (!($103)) {
         $m$1$i96 = $m$011$i80;
         break;
        }
       }
       $m$1$i96 = $i$012$i79;
      }
     } while(0);
     $104 = (($i$012$i79) + 1)|0;
     $exitcond$i97 = ($104|0)==($count|0);
     if ($exitcond$i97) {
      $m$0$lcssa$i98 = $m$1$i96;
      break;
     } else {
      $i$012$i79 = $104;$m$011$i80 = $m$1$i96;
     }
    }
   } else {
    $m$0$lcssa$i98 = -1;
   }
   $105 = ($ma$0133|0)==($m$0$lcssa$i|0);
   $106 = ($m$0$lcssa$i98|0)==($m$0$lcssa$i|0);
   $or$cond = $105 & $106;
   if ($or$cond) {
    label = 20;
    break L1;
   }
   $109 = ($ma$0133|0)==(-1);
   $110 = ($ma$0133|0)==($m$0$lcssa$i98|0);
   $or$cond1 = $109 | $110;
   L31: do {
    if (!($or$cond1)) {
     $111 = Math_fround($indvar$conv + Math_fround(-40.0));
     $112 = !($111 <= $indvar$conv);
     if (!($112)) {
      if ($0) {
       $mc$0127$us = $ma$0133;$xx$0128$us = $111;
      } else {
       $mc$0127 = $ma$0133;$xx$0128 = $111;
       while(1) {
        $152 = ($mc$0127|0)==($m$0$lcssa$i|0);
        $153 = ($m$0$lcssa$i|0)==(-1);
        $or$cond2 = $152 & $153;
        if ($or$cond2) {
         $m$0$lcssa$i147 = -1;
         label = 33;
         break L1;
        }
        $156 = Math_fround($xx$0128 + Math_fround(5.0));
        $157 = !($156 <= $indvar$conv);
        if ($157) {
         break L31;
        } else {
         $mc$0127 = -1;$xx$0128 = $156;
        }
       }
      }
      while(1) {
       $113 = Math_fround($xx$0128$us * Math_fround(0.0174532923847436904907));
       $114 = (Math_fround(+(Math_sin((+$113)))));
       $115 = (Math_fround(+(Math_cos((+$113)))));
       $116 = Math_fround($55 * $114);
       $117 = Math_fround($57 * $114);
       $118 = Math_fround($59 * $114);
       $119 = Math_fround($63 * $115);
       $120 = Math_fround($66 * $115);
       $121 = Math_fround($69 * $115);
       $122 = Math_fround($116 + $119);
       $123 = Math_fround($117 + $120);
       $124 = Math_fround($118 + $121);
       $125 = Math_fround($122 * Math_fround(0.0250000003725290298462));
       $126 = Math_fround($123 * Math_fround(0.0250000003725290298462));
       $127 = Math_fround($124 * Math_fround(0.0250000003725290298462));
       $128 = Math_fround($dir$idx38$val + $125);
       $129 = Math_fround($dir$idx39$val + $126);
       $130 = Math_fround($dir$idx40$val + $127);
       $131 = HEAP32[$allow>>2]|0;
       $i$012$i54$us = 0;$m$011$i55$us = -1;
       while(1) {
        $132 = (($131) + ($i$012$i54$us<<2)|0);
        $133 = HEAP32[$132>>2]|0;
        $134 = ($133|0)==(0);
        do {
         if ($134) {
          $m$1$i71$us = $m$011$i55$us;
         } else {
          $135 = ($m$011$i55$us|0)==(-1);
          if (!($135)) {
           $$idx5$i56$us = (($p) + (($i$012$i54$us*12)|0)|0);
           $$idx5$val$i57$us = Math_fround(HEAPF32[$$idx5$i56$us>>2]);
           $$idx6$i58$us = ((($p) + (($i$012$i54$us*12)|0)|0) + 4|0);
           $$idx6$val$i59$us = Math_fround(HEAPF32[$$idx6$i58$us>>2]);
           $$idx7$i60$us = ((($p) + (($i$012$i54$us*12)|0)|0) + 8|0);
           $$idx7$val$i61$us = Math_fround(HEAPF32[$$idx7$i60$us>>2]);
           $136 = Math_fround($128 * $$idx5$val$i57$us);
           $137 = Math_fround($129 * $$idx6$val$i59$us);
           $138 = Math_fround($136 + $137);
           $139 = Math_fround($130 * $$idx7$val$i61$us);
           $140 = Math_fround($138 + $139);
           $$idx$i65$us = (($p) + (($m$011$i55$us*12)|0)|0);
           $$idx$val$i66$us = Math_fround(HEAPF32[$$idx$i65$us>>2]);
           $$idx1$i67$us = ((($p) + (($m$011$i55$us*12)|0)|0) + 4|0);
           $$idx1$val$i68$us = Math_fround(HEAPF32[$$idx1$i67$us>>2]);
           $$idx2$i69$us = ((($p) + (($m$011$i55$us*12)|0)|0) + 8|0);
           $$idx2$val$i70$us = Math_fround(HEAPF32[$$idx2$i69$us>>2]);
           $141 = Math_fround($128 * $$idx$val$i66$us);
           $142 = Math_fround($129 * $$idx1$val$i68$us);
           $143 = Math_fround($141 + $142);
           $144 = Math_fround($130 * $$idx2$val$i70$us);
           $145 = Math_fround($143 + $144);
           $146 = $140 > $145;
           if (!($146)) {
            $m$1$i71$us = $m$011$i55$us;
            break;
           }
          }
          $m$1$i71$us = $i$012$i54$us;
         }
        } while(0);
        $147 = (($i$012$i54$us) + 1)|0;
        $exitcond$i72$us = ($147|0)==($count|0);
        if ($exitcond$i72$us) {
         break;
        } else {
         $i$012$i54$us = $147;$m$011$i55$us = $m$1$i71$us;
        }
       }
       $148 = ($mc$0127$us|0)==($m$0$lcssa$i|0);
       $149 = ($m$1$i71$us|0)==($m$0$lcssa$i|0);
       $or$cond2$us = $148 & $149;
       if ($or$cond2$us) {
        $m$0$lcssa$i147 = $m$0$lcssa$i;
        label = 33;
        break L1;
       }
       $150 = Math_fround($xx$0128$us + Math_fround(5.0));
       $151 = !($150 <= $indvar$conv);
       if ($151) {
        break;
       } else {
        $mc$0127$us = $m$1$i71$us;$xx$0128$us = $150;
       }
      }
     }
    }
   } while(0);
   $$int = (($x$0129$int) + 45)|0;
   $158 = ($$int|0)>(360);
   if ($158) {
    break;
   } else {
    $ma$0133 = $m$0$lcssa$i98;$x$0129$int = $$int;
   }
  }
  $159 = HEAP32[$allow>>2]|0;
  $160 = (($159) + ($m$0$lcssa$i<<2)|0);
  HEAP32[$160>>2] = 0;
 }
 if ((label|0) == 20) {
  $107 = HEAP32[$allow>>2]|0;
  $108 = (($107) + ($m$0$lcssa$i<<2)|0);
  HEAP32[$108>>2] = 3;
  $m$0$lcssa$i146 = $m$0$lcssa$i;
  STACKTOP = sp;return ($m$0$lcssa$i146|0);
 }
 else if ((label|0) == 33) {
  $154 = HEAP32[$allow>>2]|0;
  $155 = (($154) + ($m$0$lcssa$i147<<2)|0);
  HEAP32[$155>>2] = 3;
  $m$0$lcssa$i146 = $m$0$lcssa$i147;
  STACKTOP = sp;return ($m$0$lcssa$i146|0);
 }
 else if ((label|0) == 37) {
  STACKTOP = sp;return ($m$0$lcssa$i146|0);
 }
 return 0|0;
}
function __ZN5physx11HullLibrary10expandhullEPNS_6float3EiRS2_Rif($this,$verts,$verts_count,$verts_out,$verts_count_out,$inflate) {
 $this = $this|0;
 $verts = $verts|0;
 $verts_count = $verts_count|0;
 $verts_out = $verts_out|0;
 $verts_count_out = $verts_count_out|0;
 $inflate = Math_fround($inflate);
 var $$ = 0, $$$i = 0, $$$i19 = 0, $$$i27 = 0, $$$i2757 = 0, $$$i2758153 = 0, $$idx10 = 0, $$idx10$val = Math_fround(0), $$idx11 = 0, $$idx11$val = Math_fround(0), $$idx12 = 0, $$idx12$val = Math_fround(0), $$idx13 = 0, $$idx13$val = Math_fround(0), $$idx14 = 0, $$idx14$val = Math_fround(0), $$idx15 = 0, $$idx15$val = Math_fround(0), $$idx7 = 0, $$idx7$val = Math_fround(0);
 var $$idx8 = 0, $$idx8$val = Math_fround(0), $$idx9 = 0, $$idx9$val = Math_fround(0), $$lcssa = 0, $$lcssa151 = 0, $$lcssa60 = 0, $$numId0$1$1236 = 0, $$numId0$1230 = 0, $$ph105 = 0, $$ph84109 = 0, $$pre = 0, $$pre$phi229Z2D = 0, $$pre$phiZ2D = 0, $$pre217 = 0, $$pre218 = 0, $$pre223 = 0, $$pre224 = 0, $$pre226 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0);
 var $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0);
 var $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0);
 var $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0);
 var $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0);
 var $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0);
 var $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0;
 var $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0);
 var $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0);
 var $98 = 0, $99 = Math_fround(0), $exitcond = 0, $exitcond191 = 0, $exitcond194 = 0, $exitcond205 = 0, $exitcond206 = 0, $exitcond207 = 0, $exitcond215 = 0, $foundIndex$0 = 0, $i$01$i$i = 0, $i1$0132 = 0, $i11$061 = 0, $i4$0124 = 0, $i6$0115 = 0, $index1$074 = 0, $index1$2$lcssa = 0, $index1$2$lcssa$1 = 0, $index1$2$lcssa$2 = 0, $index2$075 = 0;
 var $index2$2$lcssa = 0, $index2$2$lcssa$1 = 0, $index2$2$lcssa$2 = 0, $indexE$073 = 0, $indexE$2$lcssa = 0, $indexE$2$lcssa$1 = 0, $indexE$2$lcssa$2 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$next193 = 0, $indvars$iv$next214 = 0, $indvars$iv192 = 0, $indvars$iv213 = 0, $j$0$ = 0, $j$0$59 = 0, $j$0145 = 0, $j2$0128 = 0, $j8$0$ph113 = 0, $j8$093 = 0, $k10$0$index1$2$us = 0;
 var $k10$0$index1$2$us$1 = 0, $k10$0$index1$2$us$1$1 = 0, $k10$0$index1$2$us$1$2 = 0, $k10$0$index1$2$us$1164 = 0, $k10$0$index1$2$us$2 = 0, $k10$0$index1$2$us$2$1 = 0, $k10$0$index1$2$us$2$2 = 0, $k10$0$index1$2$us$2170 = 0, $l9$0$indexE$2$us = 0, $l9$0$indexE$2$us$1 = 0, $l9$0$indexE$2$us$1$1 = 0, $l9$0$indexE$2$us$1$2 = 0, $l9$0$indexE$2$us$1163 = 0, $l9$0$indexE$2$us$2 = 0, $l9$0$indexE$2$us$2$1 = 0, $l9$0$indexE$2$us$2$2 = 0, $l9$0$indexE$2$us$2169 = 0, $l9$076 = 0, $m$0$index2$2$us = 0, $m$0$index2$2$us$1 = 0;
 var $m$0$index2$2$us$1$1 = 0, $m$0$index2$2$us$1$2 = 0, $m$0$index2$2$us$1165 = 0, $m$0$index2$2$us$2 = 0, $m$0$index2$2$us$2$1 = 0, $m$0$index2$2$us$2$2 = 0, $m$0$index2$2$us$2171 = 0, $numId0$1$1236 = 0, $numId0$1$1237 = 0, $numId0$1$2242 = 0, $numId0$1$2243 = 0, $numId0$1230 = 0, $numId0$1231 = 0, $numId1$1 = 0, $numId1$1$1 = 0, $numId1$1$2 = 0, $numId2$1 = 0, $numId2$1$1 = 0, $numId2$1$2 = 0, $numPoints$4$lcssa = 0;
 var $numPoints$4118 = 0, $numPoints$5$ph114 = 0, $numPoints$7 = 0, $or$cond = 0, $planes$sroa$0 = 0, $points$sroa$0 = 0, $translateTable$sroa$0 = 0, $u$077 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 18|0;
 $1 = sp + 17|0;
 $2 = sp + 16|0;
 $3 = sp + 15|0;
 $4 = sp + 14|0;
 $5 = sp + 13|0;
 $6 = sp + 12|0;
 $planes$sroa$0 = sp + 4|0;
 $translateTable$sroa$0 = sp;
 $points$sroa$0 = sp + 8|0;
 HEAP32[$planes$sroa$0>>2] = 0;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(0);
 if ($10) {
  $$$i2758153 = 0;$15 = $7;$60 = $9;$84 = 0;$indvars$iv213 = 0;
  while(1) {
   $14 = HEAP32[$15>>2]|0;
   $16 = (($14) + ($indvars$iv213<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $101 = -1;$103 = -1;$105 = -1;$112 = -1;$93 = Math_fround(0.0);$95 = Math_fround(0.0);$97 = Math_fround(0.0);$99 = Math_fround(0.0);
   } else {
    $19 = HEAP32[$17>>2]|0;
    $20 = (($17) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($17) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $$idx7 = (($verts) + (($19*12)|0)|0);
    $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
    $$idx8 = ((($verts) + (($19*12)|0)|0) + 4|0);
    $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
    $$idx9 = ((($verts) + (($19*12)|0)|0) + 8|0);
    $$idx9$val = Math_fround(HEAPF32[$$idx9>>2]);
    $$idx10 = (($verts) + (($21*12)|0)|0);
    $$idx10$val = Math_fround(HEAPF32[$$idx10>>2]);
    $$idx11 = ((($verts) + (($21*12)|0)|0) + 4|0);
    $$idx11$val = Math_fround(HEAPF32[$$idx11>>2]);
    $$idx12 = ((($verts) + (($21*12)|0)|0) + 8|0);
    $$idx12$val = Math_fround(HEAPF32[$$idx12>>2]);
    $$idx13 = (($verts) + (($23*12)|0)|0);
    $$idx13$val = Math_fround(HEAPF32[$$idx13>>2]);
    $$idx14 = ((($verts) + (($23*12)|0)|0) + 4|0);
    $$idx14$val = Math_fround(HEAPF32[$$idx14>>2]);
    $$idx15 = ((($verts) + (($23*12)|0)|0) + 8|0);
    $$idx15$val = Math_fround(HEAPF32[$$idx15>>2]);
    $24 = Math_fround($$idx10$val - $$idx7$val);
    $25 = Math_fround($$idx11$val - $$idx8$val);
    $26 = Math_fround($$idx12$val - $$idx9$val);
    $27 = Math_fround($$idx13$val - $$idx10$val);
    $28 = Math_fround($$idx14$val - $$idx11$val);
    $29 = Math_fround($$idx15$val - $$idx12$val);
    $30 = Math_fround($25 * $29);
    $31 = Math_fround($26 * $28);
    $32 = Math_fround($30 - $31);
    $33 = Math_fround($26 * $27);
    $34 = Math_fround($24 * $29);
    $35 = Math_fround($33 - $34);
    $36 = Math_fround($24 * $28);
    $37 = Math_fround($25 * $27);
    $38 = Math_fround($36 - $37);
    $39 = Math_fround($32 * $32);
    $40 = Math_fround($35 * $35);
    $41 = Math_fround($39 + $40);
    $42 = Math_fround($38 * $38);
    $43 = Math_fround($42 + $41);
    $44 = (Math_fround(Math_sqrt((Math_fround($43)))));
    $45 = $44 == Math_fround(0.0);
    if ($45) {
     $51 = Math_fround(1.0);$53 = Math_fround(0.0);$56 = Math_fround(0.0);
    } else {
     $46 = Math_fround(Math_fround(1.0) / $44);
     $47 = Math_fround($32 * $46);
     $48 = Math_fround($35 * $46);
     $49 = Math_fround($38 * $46);
     $51 = $47;$53 = $48;$56 = $49;
    }
    $50 = Math_fround($51 * $$idx7$val);
    $52 = Math_fround($53 * $$idx8$val);
    $54 = Math_fround($50 + $52);
    $55 = Math_fround($56 * $$idx9$val);
    $57 = Math_fround($54 + $55);
    $58 = Math_fround(-$57);
    $59 = ($60|0)>(0);
    if ($59) {
     $439 = -1;$442 = -1;$444 = -1;$446 = $21;$447 = $21;$448 = $21;$449 = $21;$450 = $21;$j$0145 = 0;
     while(1) {
      $61 = (($14) + ($j$0145<<2)|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($62|0)==(0|0);
      $64 = ($indvars$iv213|0)==($j$0145|0);
      $or$cond = $63 | $64;
      if ($or$cond) {
       $451 = $446;$452 = $447;$453 = $448;$454 = $449;$455 = $450;$456 = $444;$457 = $442;$458 = $439;
      } else {
       $65 = HEAP32[$62>>2]|0;
       $66 = ($65|0)==($19|0);
       if ($66) {
        $459 = $450;$460 = $449;$461 = $448;$462 = $447;$463 = $446;$numId0$1231 = 1;
        label = 12;
       } else {
        $67 = ($65|0)==($21|0);
        $$ = $67&1;
        $68 = ($65|0)==($23|0);
        if ($68) {
         $459 = $21;$460 = $21;$461 = $21;$462 = $21;$463 = $21;$numId0$1231 = $$;
         label = 12;
        } else {
         $464 = $21;$465 = $21;$466 = $21;$467 = $21;$71 = $21;$numId0$1230 = $$;$numId1$1 = 0;
        }
       }
       if ((label|0) == 12) {
        label = 0;
        $464 = $459;$465 = $460;$466 = $461;$467 = $462;$71 = $463;$numId0$1230 = $numId0$1231;$numId1$1 = 1;
       }
       $69 = ($65|0)==($23|0);
       if ($69) {
        $468 = $71;$469 = $467;$470 = $466;$471 = $465;$472 = $464;
        label = 15;
       } else {
        $70 = ($65|0)==($71|0);
        if ($70) {
         $468 = $65;$469 = $65;$470 = $65;$471 = $65;$472 = $65;
         label = 15;
        } else {
         $417 = $71;$473 = $71;$474 = $71;$475 = $71;$476 = $71;$numId2$1 = 0;
        }
       }
       if ((label|0) == 15) {
        label = 0;
        $417 = $469;$473 = $468;$474 = $470;$475 = $471;$476 = $472;$numId2$1 = 1;
       }
       $72 = (($62) + 4|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($73|0)==($19|0);
       if ($74) {
        $75 = (($numId0$1230) + 1)|0;
        $477 = $476;$478 = $475;$479 = $474;$numId0$1$1237 = $75;
        label = 95;
       } else {
        $416 = ($73|0)==($417|0);
        $418 = $416&1;
        $$numId0$1230 = (($numId0$1230) + ($418))|0;
        $419 = ($73|0)==($23|0);
        if ($419) {
         $477 = $417;$478 = $417;$479 = $417;$numId0$1$1237 = $$numId0$1230;
         label = 95;
        } else {
         $423 = $417;$493 = $417;$494 = $417;$numId0$1$1236 = $$numId0$1230;$numId1$1$1 = $numId1$1;
        }
       }
       if ((label|0) == 95) {
        label = 0;
        $420 = (($numId1$1) + 1)|0;
        $423 = $479;$493 = $477;$494 = $478;$numId0$1$1236 = $numId0$1$1237;$numId1$1$1 = $420;
       }
       $421 = ($73|0)==($23|0);
       if ($421) {
        $495 = $423;$496 = $494;$497 = $493;
        label = 98;
       } else {
        $422 = ($73|0)==($423|0);
        if ($422) {
         $495 = $73;$496 = $73;$497 = $73;
         label = 98;
        } else {
         $430 = $423;$498 = $423;$499 = $423;$numId2$1$1 = $numId2$1;
        }
       }
       if ((label|0) == 98) {
        label = 0;
        $424 = (($numId2$1) + 1)|0;
        $430 = $496;$498 = $495;$499 = $497;$numId2$1$1 = $424;
       }
       $425 = (($62) + 8|0);
       $426 = HEAP32[$425>>2]|0;
       $427 = ($426|0)==($19|0);
       if ($427) {
        $428 = (($numId0$1$1236) + 1)|0;
        $500 = $499;$numId0$1$2243 = $428;
        label = 102;
       } else {
        $429 = ($426|0)==($430|0);
        $431 = $429&1;
        $$numId0$1$1236 = (($numId0$1$1236) + ($431))|0;
        $432 = ($426|0)==($23|0);
        if ($432) {
         $500 = $430;$numId0$1$2243 = $$numId0$1$1236;
         label = 102;
        } else {
         $436 = $430;$numId0$1$2242 = $$numId0$1$1236;$numId1$1$2 = $numId1$1$1;
        }
       }
       if ((label|0) == 102) {
        label = 0;
        $433 = (($numId1$1$1) + 1)|0;
        $436 = $500;$numId0$1$2242 = $numId0$1$2243;$numId1$1$2 = $433;
       }
       $434 = ($426|0)==($23|0);
       if ($434) {
        $501 = $436;
        label = 105;
       } else {
        $435 = ($426|0)==($436|0);
        if ($435) {
         $501 = $426;
         label = 105;
        } else {
         $502 = $436;$numId2$1$2 = $numId2$1$1;
        }
       }
       if ((label|0) == 105) {
        label = 0;
        $437 = (($numId2$1$1) + 1)|0;
        $502 = $501;$numId2$1$2 = $437;
       }
       $438 = ($numId0$1$2242|0)==(2);
       $j$0$ = $438 ? $j$0145 : $439;
       $440 = ($numId1$1$2|0)==(2);
       $441 = $440 ? $j$0145 : $442;
       $443 = ($numId2$1$2|0)==(2);
       $j$0$59 = $443 ? $j$0145 : $444;
       $451 = $473;$452 = $417;$453 = $498;$454 = $430;$455 = $502;$456 = $j$0$59;$457 = $441;$458 = $j$0$;
      }
      $76 = (($j$0145) + 1)|0;
      $77 = ($76|0)<($60|0);
      if ($77) {
       $439 = $458;$442 = $457;$444 = $456;$446 = $451;$447 = $452;$448 = $453;$449 = $454;$450 = $455;$j$0145 = $76;
      } else {
       $101 = $458;$103 = $457;$105 = $456;$112 = $indvars$iv213;$93 = $51;$95 = $53;$97 = $56;$99 = $58;
       break;
      }
     }
    } else {
     $101 = -1;$103 = -1;$105 = -1;$112 = $indvars$iv213;$93 = $51;$95 = $53;$97 = $56;$99 = $58;
    }
   }
   $78 = ($indvars$iv213|0)==($$$i2758153|0);
   do {
    if ($78) {
     $79 = ($indvars$iv213|0)==(0);
     $80 = $indvars$iv213 << 1;
     $$$i27 = $79 ? 16 : $80;
     $81 = ($$$i27*52)|0;
     $82 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$81,534704,153)|0);
     HEAP32[$planes$sroa$0>>2] = $82;
     $83 = ($indvars$iv213|0)>(0);
     if ($83) {
      dest=$82+0|0; src=$84+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $85 = ($indvars$iv213|0)>(1);
      if ($85) {
       $87 = 1;
       while(1) {
        $86 = (($82) + (($87*52)|0)|0);
        $88 = (($84) + (($87*52)|0)|0);
        dest=$86+0|0; src=$88+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $89 = (($87) + 1)|0;
        $exitcond215 = ($89|0)==($indvars$iv213|0);
        if ($exitcond215) {
         $$pre$phiZ2D = $84;
         break;
        } else {
         $87 = $89;
        }
       }
      } else {
       label = 23;
      }
     } else {
      label = 23;
     }
     if ((label|0) == 23) {
      label = 0;
      $90 = ($84|0)==(0|0);
      if ($90) {
       $$$i2757 = $$$i27;$92 = $82;
       break;
      }
      $$pre$phiZ2D = $84;
     }
     __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$$pre$phiZ2D);
     $$$i2757 = $$$i27;$92 = $82;
    } else {
     $$$i2757 = $$$i2758153;$92 = $84;
    }
   } while(0);
   $indvars$iv$next214 = (($indvars$iv213) + 1)|0;
   $91 = (($92) + (($indvars$iv213*52)|0)|0);
   HEAPF32[$91>>2] = $93;
   $94 = ((($92) + (($indvars$iv213*52)|0)|0) + 4|0);
   HEAPF32[$94>>2] = $95;
   $96 = ((($92) + (($indvars$iv213*52)|0)|0) + 8|0);
   HEAPF32[$96>>2] = $97;
   $98 = ((($92) + (($indvars$iv213*52)|0)|0) + 12|0);
   HEAPF32[$98>>2] = $99;
   $100 = ((($92) + (($indvars$iv213*52)|0)|0) + 16|0);
   HEAP32[$100>>2] = $101;
   $102 = ((($92) + (($indvars$iv213*52)|0)|0) + 20|0);
   HEAP32[$102>>2] = $103;
   $104 = ((($92) + (($indvars$iv213*52)|0)|0) + 24|0);
   HEAP32[$104>>2] = $105;
   $106 = ((($92) + (($indvars$iv213*52)|0)|0) + 28|0);
   HEAP32[$106>>2] = -1;
   $107 = ((($92) + (($indvars$iv213*52)|0)|0) + 32|0);
   HEAPF32[$107>>2] = Math_fround(-3.40282346638528859812E+38);
   $108 = ((($92) + (($indvars$iv213*52)|0)|0) + 36|0);
   HEAP32[$108>>2] = -1;
   $109 = ((($92) + (($indvars$iv213*52)|0)|0) + 40|0);
   HEAP32[$109>>2] = -1;
   $110 = ((($92) + (($indvars$iv213*52)|0)|0) + 44|0);
   HEAP32[$110>>2] = -1;
   $111 = ((($92) + (($indvars$iv213*52)|0)|0) + 48|0);
   HEAP32[$111>>2] = $112;
   $113 = HEAP32[$this>>2]|0;
   $114 = (($113) + 4|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ($indvars$iv$next214|0)<($115|0);
   if ($116) {
    $$$i2758153 = $$$i2757;$15 = $113;$60 = $115;$84 = $92;$indvars$iv213 = $indvars$iv$next214;
   } else {
    $$lcssa151 = $indvars$iv$next214;$125 = $92;$13 = $113;$445 = $115;
    break;
   }
  }
 } else {
  $$lcssa151 = 0;$125 = 0;$13 = $7;$445 = $9;
 }
 $11 = ($verts_count|0)>(0);
 if ($11) {
  $12 = (($13) + 4|0);
  $118 = $445;$i1$0132 = 0;
  while(1) {
   $117 = ($118|0)>(0);
   if ($117) {
    $119 = (($verts) + (($i1$0132*12)|0)|0);
    $120 = ((($verts) + (($i1$0132*12)|0)|0) + 4|0);
    $121 = ((($verts) + (($i1$0132*12)|0)|0) + 8|0);
    $480 = $118;$j2$0128 = 0;
    while(1) {
     $124 = ((($125) + (($j2$0128*52)|0)|0) + 48|0);
     $126 = HEAP32[$124>>2]|0;
     $127 = ($126|0)==(-1);
     if ($127) {
      $152 = $480;
     } else {
      $128 = Math_fround(HEAPF32[$119>>2]);
      $129 = (($125) + (($j2$0128*52)|0)|0);
      $130 = Math_fround(HEAPF32[$129>>2]);
      $131 = Math_fround($128 * $130);
      $132 = Math_fround(HEAPF32[$120>>2]);
      $133 = ((($125) + (($j2$0128*52)|0)|0) + 4|0);
      $134 = Math_fround(HEAPF32[$133>>2]);
      $135 = Math_fround($132 * $134);
      $136 = Math_fround($131 + $135);
      $137 = Math_fround(HEAPF32[$121>>2]);
      $138 = ((($125) + (($j2$0128*52)|0)|0) + 8|0);
      $139 = Math_fround(HEAPF32[$138>>2]);
      $140 = Math_fround($137 * $139);
      $141 = Math_fround($136 + $140);
      $142 = ((($125) + (($j2$0128*52)|0)|0) + 12|0);
      $143 = Math_fround(HEAPF32[$142>>2]);
      $144 = Math_fround($143 + $141);
      $145 = $144 > Math_fround(0.0);
      if ($145) {
       $146 = ((($125) + (($j2$0128*52)|0)|0) + 32|0);
       $147 = Math_fround(HEAPF32[$146>>2]);
       $148 = $144 > $147;
       if ($148) {
        HEAPF32[$146>>2] = $144;
        $149 = ((($125) + (($j2$0128*52)|0)|0) + 28|0);
        HEAP32[$149>>2] = $i1$0132;
        $$pre224 = HEAP32[$12>>2]|0;
        $152 = $$pre224;
       } else {
        $152 = $480;
       }
      } else {
       $152 = $480;
      }
     }
     $150 = (($j2$0128) + 1)|0;
     $151 = ($150|0)<($152|0);
     if ($151) {
      $480 = $152;$j2$0128 = $150;
     } else {
      $$pre223 = $152;
      break;
     }
    }
   } else {
    $$pre223 = $118;
   }
   $153 = (($i1$0132) + 1)|0;
   $exitcond207 = ($153|0)==($verts_count|0);
   if ($exitcond207) {
    break;
   } else {
    $118 = $$pre223;$i1$0132 = $153;
   }
  }
 }
 $122 = ($$lcssa151|0)>(0);
 if ($122) {
  $123 = HEAP32[$planes$sroa$0>>2]|0;
  $i4$0124 = 0;
  while(1) {
   $154 = ((($123) + (($i4$0124*52)|0)|0) + 48|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = ($155|0)==(-1);
   if (!($156)) {
    $157 = ((($123) + (($i4$0124*52)|0)|0) + 28|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = ($158|0)>(-1);
    if ($159) {
     $160 = ((($123) + (($i4$0124*52)|0)|0) + 32|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = Math_fround($161 + $inflate);
     $163 = ((($123) + (($i4$0124*52)|0)|0) + 12|0);
     $164 = Math_fround(HEAPF32[$163>>2]);
     $165 = Math_fround($164 - $162);
     HEAPF32[$163>>2] = $165;
    }
   }
   $166 = (($i4$0124) + 1)|0;
   $exitcond206 = ($166|0)==($$lcssa151|0);
   if ($exitcond206) {
    break;
   } else {
    $i4$0124 = $166;
   }
  }
  HEAP32[$translateTable$sroa$0>>2] = 0;
  HEAP32[$points$sroa$0>>2] = 0;
  if ($122) {
   $167 = HEAP32[$planes$sroa$0>>2]|0;
   $481 = 0;$482 = 0;$483 = 0;$484 = 0;$485 = 0;$i6$0115 = 0;$numPoints$4118 = 0;
   while(1) {
    $168 = ((($167) + (($i6$0115*52)|0)|0) + 48|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = ($169|0)==(-1);
    L88: do {
     if ($170) {
      $486 = $481;$487 = $485;$488 = $484;$489 = $483;$490 = $482;$numPoints$7 = $numPoints$4118;
     } else {
      $171 = HEAP32[$this>>2]|0;
      $172 = HEAP32[$171>>2]|0;
      $173 = (($172) + ($169<<2)|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = (($167) + (($i6$0115*52)|0)|0);
      $176 = ((($167) + (($i6$0115*52)|0)|0) + 4|0);
      $177 = ((($167) + (($i6$0115*52)|0)|0) + 8|0);
      $178 = ((($167) + (($i6$0115*52)|0)|0) + 12|0);
      $$pre = HEAP32[$translateTable$sroa$0>>2]|0;
      $$ph105 = $485;$$ph84109 = $483;$203 = $$pre;$301 = $481;$indvars$iv = $482;$indvars$iv192 = $484;$j8$0$ph113 = 0;$numPoints$5$ph114 = $numPoints$4118;
      while(1) {
       $179 = ($indvars$iv192|0)>(0);
       $j8$093 = $j8$0$ph113;
       while(1) {
        $180 = (((($167) + (($i6$0115*52)|0)|0) + ($j8$093<<2)|0) + 16|0);
        $181 = HEAP32[$180>>2]|0;
        $182 = (($j8$093) + 1)|0;
        $183 = (($182|0) % 3)&-1;
        $184 = (((($167) + (($i6$0115*52)|0)|0) + ($183<<2)|0) + 16|0);
        $185 = HEAP32[$184>>2]|0;
        $186 = HEAP32[$this>>2]|0;
        $187 = HEAP32[$186>>2]|0;
        $188 = (($187) + ($181<<2)|0);
        $189 = HEAP32[$188>>2]|0;
        $190 = (($187) + ($185<<2)|0);
        $191 = HEAP32[$190>>2]|0;
        $$pre217 = HEAP32[$189>>2]|0;
        $index1$074 = -1;$index2$075 = -1;$indexE$073 = -1;$l9$076 = 0;
        while(1) {
         $192 = (($174) + ($l9$076<<2)|0);
         $193 = HEAP32[$192>>2]|0;
         $194 = ($193|0)==($$pre217|0);
         if ($194) {
          $388 = HEAP32[$191>>2]|0;
          $389 = ($$pre217|0)==($388|0);
          $l9$0$indexE$2$us = $389 ? $l9$076 : $indexE$073;
          $k10$0$index1$2$us = $389 ? 0 : $index1$074;
          $m$0$index2$2$us = $389 ? 0 : $index2$075;
          $390 = (($191) + 4|0);
          $391 = HEAP32[$390>>2]|0;
          $392 = ($$pre217|0)==($391|0);
          $l9$0$indexE$2$us$1 = $392 ? $l9$076 : $l9$0$indexE$2$us;
          $k10$0$index1$2$us$1 = $392 ? 0 : $k10$0$index1$2$us;
          $m$0$index2$2$us$1 = $392 ? 1 : $m$0$index2$2$us;
          $393 = (($191) + 8|0);
          $394 = HEAP32[$393>>2]|0;
          $395 = ($$pre217|0)==($394|0);
          $l9$0$indexE$2$us$2 = $395 ? $l9$076 : $l9$0$indexE$2$us$1;
          $k10$0$index1$2$us$2 = $395 ? 0 : $k10$0$index1$2$us$1;
          $m$0$index2$2$us$2 = $395 ? 2 : $m$0$index2$2$us$1;
          $index1$2$lcssa = $k10$0$index1$2$us$2;$index2$2$lcssa = $m$0$index2$2$us$2;$indexE$2$lcssa = $l9$0$indexE$2$us$2;
         } else {
          $index1$2$lcssa = $index1$074;$index2$2$lcssa = $index2$075;$indexE$2$lcssa = $indexE$073;
         }
         $195 = (($189) + 4|0);
         $196 = HEAP32[$195>>2]|0;
         $197 = ($193|0)==($196|0);
         if ($197) {
          $396 = HEAP32[$191>>2]|0;
          $397 = ($193|0)==($396|0);
          $l9$0$indexE$2$us$1163 = $397 ? $l9$076 : $indexE$2$lcssa;
          $k10$0$index1$2$us$1164 = $397 ? 1 : $index1$2$lcssa;
          $m$0$index2$2$us$1165 = $397 ? 0 : $index2$2$lcssa;
          $398 = (($191) + 4|0);
          $399 = HEAP32[$398>>2]|0;
          $400 = ($193|0)==($399|0);
          $l9$0$indexE$2$us$1$1 = $400 ? $l9$076 : $l9$0$indexE$2$us$1163;
          $k10$0$index1$2$us$1$1 = $400 ? 1 : $k10$0$index1$2$us$1164;
          $m$0$index2$2$us$1$1 = $400 ? 1 : $m$0$index2$2$us$1165;
          $401 = (($191) + 8|0);
          $402 = HEAP32[$401>>2]|0;
          $403 = ($193|0)==($402|0);
          $l9$0$indexE$2$us$2$1 = $403 ? $l9$076 : $l9$0$indexE$2$us$1$1;
          $k10$0$index1$2$us$2$1 = $403 ? 1 : $k10$0$index1$2$us$1$1;
          $m$0$index2$2$us$2$1 = $403 ? 2 : $m$0$index2$2$us$1$1;
          $index1$2$lcssa$1 = $k10$0$index1$2$us$2$1;$index2$2$lcssa$1 = $m$0$index2$2$us$2$1;$indexE$2$lcssa$1 = $l9$0$indexE$2$us$2$1;
         } else {
          $index1$2$lcssa$1 = $index1$2$lcssa;$index2$2$lcssa$1 = $index2$2$lcssa;$indexE$2$lcssa$1 = $indexE$2$lcssa;
         }
         $404 = (($189) + 8|0);
         $405 = HEAP32[$404>>2]|0;
         $406 = ($193|0)==($405|0);
         if ($406) {
          $407 = HEAP32[$191>>2]|0;
          $408 = ($193|0)==($407|0);
          $l9$0$indexE$2$us$2169 = $408 ? $l9$076 : $indexE$2$lcssa$1;
          $k10$0$index1$2$us$2170 = $408 ? 2 : $index1$2$lcssa$1;
          $m$0$index2$2$us$2171 = $408 ? 0 : $index2$2$lcssa$1;
          $409 = (($191) + 4|0);
          $410 = HEAP32[$409>>2]|0;
          $411 = ($193|0)==($410|0);
          $l9$0$indexE$2$us$1$2 = $411 ? $l9$076 : $l9$0$indexE$2$us$2169;
          $k10$0$index1$2$us$1$2 = $411 ? 2 : $k10$0$index1$2$us$2170;
          $m$0$index2$2$us$1$2 = $411 ? 1 : $m$0$index2$2$us$2171;
          $412 = (($191) + 8|0);
          $413 = HEAP32[$412>>2]|0;
          $414 = ($193|0)==($413|0);
          $l9$0$indexE$2$us$2$2 = $414 ? $l9$076 : $l9$0$indexE$2$us$1$2;
          $k10$0$index1$2$us$2$2 = $414 ? 2 : $k10$0$index1$2$us$1$2;
          $m$0$index2$2$us$2$2 = $414 ? 2 : $m$0$index2$2$us$1$2;
          $index1$2$lcssa$2 = $k10$0$index1$2$us$2$2;$index2$2$lcssa$2 = $m$0$index2$2$us$2$2;$indexE$2$lcssa$2 = $l9$0$indexE$2$us$2$2;
         } else {
          $index1$2$lcssa$2 = $index1$2$lcssa$1;$index2$2$lcssa$2 = $index2$2$lcssa$1;$indexE$2$lcssa$2 = $indexE$2$lcssa$1;
         }
         $415 = (($l9$076) + 1)|0;
         $exitcond = ($415|0)==(3);
         if ($exitcond) {
          break;
         } else {
          $index1$074 = $index1$2$lcssa$2;$index2$075 = $index2$2$lcssa$2;$indexE$073 = $indexE$2$lcssa$2;$l9$076 = $415;
         }
        }
        L106: do {
         if ($179) {
          $198 = (($174) + ($indexE$2$lcssa$2<<2)|0);
          $199 = HEAP32[$198>>2]|0;
          $u$077 = 0;
          while(1) {
           $202 = (($203) + ($u$077<<2)|0);
           $204 = HEAP32[$202>>2]|0;
           $205 = ($204|0)==($199|0);
           $201 = (($u$077) + 1)|0;
           if ($205) {
            $foundIndex$0 = $u$077;
            break L106;
           }
           $200 = ($201|0)<($indvars$iv192|0);
           if ($200) {
            $u$077 = $201;
           } else {
            $foundIndex$0 = -1;
            break;
           }
          }
         } else {
          $foundIndex$0 = -1;
         }
        } while(0);
        $206 = Math_fround(HEAPF32[$175>>2]);
        $207 = Math_fround(HEAPF32[$176>>2]);
        $208 = Math_fround(HEAPF32[$177>>2]);
        $209 = (($167) + (($181*52)|0)|0);
        $210 = Math_fround(HEAPF32[$209>>2]);
        $211 = ((($167) + (($181*52)|0)|0) + 4|0);
        $212 = Math_fround(HEAPF32[$211>>2]);
        $213 = ((($167) + (($181*52)|0)|0) + 8|0);
        $214 = Math_fround(HEAPF32[$213>>2]);
        $215 = (($167) + (($185*52)|0)|0);
        $216 = Math_fround(HEAPF32[$215>>2]);
        $217 = ((($167) + (($185*52)|0)|0) + 4|0);
        $218 = Math_fround(HEAPF32[$217>>2]);
        $219 = ((($167) + (($185*52)|0)|0) + 8|0);
        $220 = Math_fround(HEAPF32[$219>>2]);
        $221 = Math_fround($206 * $212);
        $222 = Math_fround($221 * $220);
        $223 = Math_fround($207 * $214);
        $224 = Math_fround($223 * $216);
        $225 = Math_fround($224 + $222);
        $226 = Math_fround($208 * $210);
        $227 = Math_fround($226 * $218);
        $228 = Math_fround($227 + $225);
        $229 = Math_fround($206 * $214);
        $230 = Math_fround($229 * $218);
        $231 = Math_fround($228 - $230);
        $232 = Math_fround($207 * $210);
        $233 = Math_fround($232 * $220);
        $234 = Math_fround($231 - $233);
        $235 = Math_fround($208 * $212);
        $236 = Math_fround($235 * $216);
        $237 = Math_fround($234 - $236);
        $238 = Math_fround($212 * $220);
        $239 = Math_fround($214 * $218);
        $240 = Math_fround($238 - $239);
        $241 = Math_fround($240 / $237);
        $242 = Math_fround($208 * $218);
        $243 = Math_fround($207 * $220);
        $244 = Math_fround($242 - $243);
        $245 = Math_fround($244 / $237);
        $246 = Math_fround($223 - $235);
        $247 = Math_fround($246 / $237);
        $248 = Math_fround($214 * $216);
        $249 = Math_fround($210 * $220);
        $250 = Math_fround($248 - $249);
        $251 = Math_fround($250 / $237);
        $252 = Math_fround($206 * $220);
        $253 = Math_fround($208 * $216);
        $254 = Math_fround($252 - $253);
        $255 = Math_fround($254 / $237);
        $256 = Math_fround($226 - $229);
        $257 = Math_fround($256 / $237);
        $258 = Math_fround($210 * $218);
        $259 = Math_fround($212 * $216);
        $260 = Math_fround($258 - $259);
        $261 = Math_fround($260 / $237);
        $262 = Math_fround($207 * $216);
        $263 = Math_fround($206 * $218);
        $264 = Math_fround($262 - $263);
        $265 = Math_fround($264 / $237);
        $266 = Math_fround($221 - $232);
        $267 = Math_fround($266 / $237);
        $268 = Math_fround(HEAPF32[$178>>2]);
        $269 = ((($167) + (($181*52)|0)|0) + 12|0);
        $270 = Math_fround(HEAPF32[$269>>2]);
        $271 = ((($167) + (($185*52)|0)|0) + 12|0);
        $272 = Math_fround(HEAPF32[$271>>2]);
        $273 = Math_fround(-$268);
        $274 = Math_fround(-$270);
        $275 = Math_fround(-$272);
        $276 = Math_fround($241 * $273);
        $277 = Math_fround($245 * $274);
        $278 = Math_fround($276 + $277);
        $279 = Math_fround($247 * $275);
        $280 = Math_fround($278 + $279);
        $281 = Math_fround($251 * $273);
        $282 = Math_fround($255 * $274);
        $283 = Math_fround($281 + $282);
        $284 = Math_fround($257 * $275);
        $285 = Math_fround($283 + $284);
        $286 = Math_fround($261 * $273);
        $287 = Math_fround($265 * $274);
        $288 = Math_fround($286 + $287);
        $289 = Math_fround($267 * $275);
        $290 = Math_fround($288 + $289);
        $291 = ($foundIndex$0|0)==(-1);
        if ($291) {
         break;
        }
        $329 = (($301) + (($foundIndex$0*12)|0)|0);
        $330 = Math_fround(HEAPF32[$329>>2]);
        $331 = Math_fround($206 * $330);
        $332 = ((($301) + (($foundIndex$0*12)|0)|0) + 4|0);
        $333 = Math_fround(HEAPF32[$332>>2]);
        $334 = Math_fround($207 * $333);
        $335 = Math_fround($331 + $334);
        $336 = ((($301) + (($foundIndex$0*12)|0)|0) + 8|0);
        $337 = Math_fround(HEAPF32[$336>>2]);
        $338 = Math_fround($208 * $337);
        $339 = Math_fround($335 + $338);
        $340 = Math_fround($268 + $339);
        $341 = $340 < Math_fround(-0.0199999995529651641846);
        if ($341) {
         label = 72;
        } else {
         $342 = Math_fround($210 * $330);
         $343 = Math_fround($212 * $333);
         $344 = Math_fround($342 + $343);
         $345 = Math_fround($214 * $337);
         $346 = Math_fround($344 + $345);
         $347 = Math_fround($270 + $346);
         $348 = $347 < Math_fround(-0.0199999995529651641846);
         if ($348) {
          label = 72;
         } else {
          $349 = Math_fround($216 * $330);
          $350 = Math_fround($218 * $333);
          $351 = Math_fround($349 + $350);
          $352 = Math_fround($220 * $337);
          $353 = Math_fround($351 + $352);
          $354 = Math_fround($272 + $353);
          $355 = $354 < Math_fround(-0.0199999995529651641846);
          if ($355) {
           label = 72;
          }
         }
        }
        if ((label|0) == 72) {
         label = 0;
         HEAPF32[$329>>2] = $280;
         HEAPF32[$332>>2] = $285;
         HEAPF32[$336>>2] = $290;
        }
        $356 = (((($167) + (($i6$0115*52)|0)|0) + ($indexE$2$lcssa$2<<2)|0) + 36|0);
        HEAP32[$356>>2] = $foundIndex$0;
        $357 = (((($167) + (($181*52)|0)|0) + ($index1$2$lcssa$2<<2)|0) + 36|0);
        HEAP32[$357>>2] = $foundIndex$0;
        $358 = (((($167) + (($185*52)|0)|0) + ($index2$2$lcssa$2<<2)|0) + 36|0);
        HEAP32[$358>>2] = $foundIndex$0;
        $359 = ($182|0)<(3);
        if ($359) {
         $j8$093 = $182;
        } else {
         $486 = $301;$487 = $$ph105;$488 = $indvars$iv192;$489 = $$ph84109;$490 = $indvars$iv;$numPoints$7 = $numPoints$5$ph114;
         break L88;
        }
       }
       $292 = (((($167) + (($i6$0115*52)|0)|0) + ($indexE$2$lcssa$2<<2)|0) + 36|0);
       HEAP32[$292>>2] = $numPoints$5$ph114;
       $293 = (((($167) + (($181*52)|0)|0) + ($index1$2$lcssa$2<<2)|0) + 36|0);
       HEAP32[$293>>2] = $numPoints$5$ph114;
       $294 = (((($167) + (($185*52)|0)|0) + ($index2$2$lcssa$2<<2)|0) + 36|0);
       HEAP32[$294>>2] = $numPoints$5$ph114;
       $295 = ($indvars$iv|0)==($$ph84109|0);
       do {
        if ($295) {
         $296 = ($indvars$iv|0)==(0);
         $297 = $indvars$iv << 1;
         $$$i19 = $296 ? 16 : $297;
         $298 = ($$$i19*12)|0;
         $299 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$298,534704,153)|0);
         HEAP32[$points$sroa$0>>2] = $299;
         $300 = ($indvars$iv|0)>(0);
         if ($300) {
          ;HEAP32[$299+0>>2]=HEAP32[$301+0>>2]|0;HEAP32[$299+4>>2]=HEAP32[$301+4>>2]|0;HEAP32[$299+8>>2]=HEAP32[$301+8>>2]|0;
          $302 = ($indvars$iv|0)>(1);
          if ($302) {
           $304 = 1;
           while(1) {
            $303 = (($299) + (($304*12)|0)|0);
            $305 = (($301) + (($304*12)|0)|0);
            ;HEAP32[$303+0>>2]=HEAP32[$305+0>>2]|0;HEAP32[$303+4>>2]=HEAP32[$305+4>>2]|0;HEAP32[$303+8>>2]=HEAP32[$305+8>>2]|0;
            $306 = (($304) + 1)|0;
            $exitcond191 = ($306|0)==($indvars$iv|0);
            if ($exitcond191) {
             $$pre$phi229Z2D = $301;
             break;
            } else {
             $304 = $306;
            }
           }
          } else {
           label = 59;
          }
         } else {
          label = 59;
         }
         if ((label|0) == 59) {
          label = 0;
          $307 = ($301|0)==(0|0);
          if ($307) {
           $309 = $299;$491 = $$$i19;
           break;
          }
          $$pre$phi229Z2D = $301;
         }
         __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$$pre$phi229Z2D);
         $309 = $299;$491 = $$$i19;
        } else {
         $309 = $301;$491 = $$ph84109;
        }
       } while(0);
       $indvars$iv$next = (($indvars$iv) + 1)|0;
       $308 = (($309) + (($indvars$iv*12)|0)|0);
       HEAPF32[$308>>2] = $280;
       $310 = ((($309) + (($indvars$iv*12)|0)|0) + 4|0);
       HEAPF32[$310>>2] = $285;
       $311 = ((($309) + (($indvars$iv*12)|0)|0) + 8|0);
       HEAPF32[$311>>2] = $290;
       $312 = (($174) + ($indexE$2$lcssa$2<<2)|0);
       $313 = HEAP32[$312>>2]|0;
       $314 = ($indvars$iv192|0)==($$ph105|0);
       do {
        if ($314) {
         $315 = ($indvars$iv192|0)==(0);
         $316 = $indvars$iv192 << 1;
         $$$i = $315 ? 16 : $316;
         $317 = HEAP32[$translateTable$sroa$0>>2]|0;
         $318 = $$$i << 2;
         $319 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$318,534704,153)|0);
         HEAP32[$translateTable$sroa$0>>2] = $319;
         if ($179) {
          $i$01$i$i = 0;
          while(1) {
           $320 = (($317) + ($i$01$i$i<<2)|0);
           $321 = HEAP32[$320>>2]|0;
           $322 = (($319) + ($i$01$i$i<<2)|0);
           HEAP32[$322>>2] = $321;
           $323 = (($i$01$i$i) + 1)|0;
           $exitcond194 = ($323|0)==($indvars$iv192|0);
           if ($exitcond194) {
            break;
           } else {
            $i$01$i$i = $323;
           }
          }
         } else {
          $324 = ($317|0)==(0|0);
          if ($324) {
           $326 = $319;$492 = $$$i;
           break;
          }
         }
         __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$317);
         $326 = $319;$492 = $$$i;
        } else {
         $$pre226 = HEAP32[$translateTable$sroa$0>>2]|0;
         $326 = $$pre226;$492 = $$ph105;
        }
       } while(0);
       $indvars$iv$next193 = (($indvars$iv192) + 1)|0;
       $325 = (($326) + ($indvars$iv192<<2)|0);
       HEAP32[$325>>2] = $313;
       $327 = (($numPoints$5$ph114) + 1)|0;
       $328 = ($182|0)<(3);
       if ($328) {
        $$ph105 = $492;$$ph84109 = $491;$203 = $326;$301 = $309;$indvars$iv = $indvars$iv$next;$indvars$iv192 = $indvars$iv$next193;$j8$0$ph113 = $182;$numPoints$5$ph114 = $327;
       } else {
        $486 = $309;$487 = $492;$488 = $indvars$iv$next193;$489 = $491;$490 = $indvars$iv$next;$numPoints$7 = $327;
        break;
       }
      }
     }
    } while(0);
    $360 = (($i6$0115) + 1)|0;
    $exitcond205 = ($360|0)==($$lcssa151|0);
    if ($exitcond205) {
     $361 = $486;$numPoints$4$lcssa = $numPoints$7;
     break;
    } else {
     $481 = $486;$482 = $490;$483 = $489;$484 = $488;$485 = $487;$i6$0115 = $360;$numPoints$4118 = $numPoints$7;
    }
   }
  } else {
   $361 = 0;$numPoints$4$lcssa = 0;
  }
 } else {
  HEAP32[$translateTable$sroa$0>>2] = 0;
  HEAP32[$points$sroa$0>>2] = 0;
  $361 = 0;$numPoints$4$lcssa = 0;
 }
 HEAP32[$verts_count_out>>2] = $numPoints$4$lcssa;
 HEAP32[$verts_out>>2] = $361;
 HEAP32[$points$sroa$0>>2] = 0;
 $362 = HEAP32[$this>>2]|0;
 $363 = (($362) + 4|0);
 $364 = HEAP32[$363>>2]|0;
 $365 = ($364|0)>(0);
 if ($365) {
  $367 = $362;$i11$061 = 0;
  while(1) {
   $366 = HEAP32[$367>>2]|0;
   $368 = (($366) + ($i11$061<<2)|0);
   $369 = HEAP32[$368>>2]|0;
   $370 = ($369|0)==(0|0);
   if ($370) {
    $376 = $367;
   } else {
    $371 = (($369) + 24|0);
    $372 = HEAP32[$371>>2]|0;
    $373 = (($366) + ($372<<2)|0);
    HEAP32[$373>>2] = 0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$369);
    $$pre218 = HEAP32[$this>>2]|0;
    $376 = $$pre218;
   }
   $374 = (($i11$061) + 1)|0;
   $375 = (($376) + 4|0);
   $377 = HEAP32[$375>>2]|0;
   $378 = ($374|0)<($377|0);
   if ($378) {
    $367 = $376;$i11$061 = $374;
   } else {
    $$lcssa = $376;$$lcssa60 = $375;
    break;
   }
  }
 } else {
  $$lcssa = $362;$$lcssa60 = $363;
 }
 $379 = HEAP32[$$lcssa>>2]|0;
 $380 = ($379|0)==(0|0);
 if (!($380)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$379);
  HEAP32[$$lcssa>>2] = 0;
 }
 $381 = (($$lcssa) + 8|0);
 HEAP32[$381>>2] = 0;
 HEAP32[$$lcssa60>>2] = 0;
 $382 = HEAP32[$points$sroa$0>>2]|0;
 $383 = ($382|0)==(0|0);
 if (!($383)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$382);
  HEAP32[$points$sroa$0>>2] = 0;
 }
 HEAP32[$points$sroa$0>>2] = 0;
 $384 = HEAP32[$translateTable$sroa$0>>2]|0;
 $385 = ($384|0)==(0|0);
 if (!($385)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$384);
  HEAP32[$translateTable$sroa$0>>2] = 0;
 }
 HEAP32[$translateTable$sroa$0>>2] = 0;
 $386 = HEAP32[$planes$sroa$0>>2]|0;
 $387 = ($386|0)==(0|0);
 if ($387) {
  STACKTOP = sp;return 0;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$386);
 HEAP32[$planes$sroa$0>>2] = 0;
 STACKTOP = sp;return 0;
}
function __ZN5physx11HullLibrary8calchullEPNS_6float3EiRPiRiRS2_S5_if($this,$verts,$verts_count,$tris_out,$tris_count,$verts_out,$verts_count_out,$vlimit,$areaEpsilon) {
 $this = $this|0;
 $verts = $verts|0;
 $verts_count = $verts_count|0;
 $tris_out = $tris_out|0;
 $tris_count = $tris_count|0;
 $verts_out = $verts_out|0;
 $verts_count_out = $verts_count_out|0;
 $vlimit = $vlimit|0;
 $areaEpsilon = Math_fround($areaEpsilon);
 var $$$i = 0, $$$i$1 = 0, $$$i$2 = 0, $$$i8 = 0, $$$i8$1 = 0, $$$i8$2 = 0, $$0 = 0, $$lcssa25 = 0, $$lcssa36 = 0, $$pre = 0, $$pre$i = 0, $$pre$i17 = 0, $$pre57 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$1 = 0, $exitcond$2 = 0, $exitcond50 = 0, $exitcond50$1 = 0, $exitcond50$2 = 0, $i$01$i$i = 0, $i$01$i$i$1 = 0, $i$01$i$i$2 = 0, $i$01$i$i9 = 0, $i$01$i$i9$1 = 0, $i$01$i$i9$2 = 0, $i$027 = 0, $i2$038 = 0;
 var $indvars$iv$next = 0, $indvars$iv$next$1 = 0, $indvars$iv$next49 = 0, $indvars$iv$next49$1 = 0, $ts$sroa$0 = 0, $ts1$sroa$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 11|0;
 $1 = sp + 10|0;
 $2 = sp + 9|0;
 $3 = sp + 8|0;
 $ts$sroa$0 = sp;
 $ts1$sroa$0 = sp + 4|0;
 $4 = (__ZN5physx11HullLibrary11calchullgenEPNS_6float3Eiif($this,$verts,$verts_count,$vlimit,$areaEpsilon)|0);
 $5 = $4 & -3;
 $6 = ($5|0)==(1);
 if ($6) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ($4|0)==(2);
 if (!($7)) {
  HEAP32[$ts1$sroa$0>>2] = 0;
  $58 = HEAP32[$this>>2]|0;
  $59 = (($58) + 4|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)>(0);
  if ($61) {
   $63 = $58;$69 = 0;$70 = 0;$77 = 0;$i2$038 = 0;
   while(1) {
    $62 = HEAP32[$63>>2]|0;
    $64 = (($62) + ($i2$038<<2)|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65|0)==(0|0);
    if ($66) {
     $189 = $77;$190 = $70;$191 = $69;
    } else {
     $67 = HEAP32[$65>>2]|0;
     $68 = ($69|0)==($70|0);
     do {
      if ($68) {
       $71 = ($69|0)==(0);
       $72 = $69 << 1;
       $$$i = $71 ? 16 : $72;
       $73 = $$$i << 2;
       $74 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$73,534704,153)|0);
       HEAP32[$ts1$sroa$0>>2] = $74;
       $75 = ($69|0)>(0);
       if ($75) {
        $i$01$i$i = 0;
        while(1) {
         $76 = (($77) + ($i$01$i$i<<2)|0);
         $78 = HEAP32[$76>>2]|0;
         $79 = (($74) + ($i$01$i$i<<2)|0);
         HEAP32[$79>>2] = $78;
         $80 = (($i$01$i$i) + 1)|0;
         $exitcond50 = ($80|0)==($69|0);
         if ($exitcond50) {
          break;
         } else {
          $i$01$i$i = $80;
         }
        }
       } else {
        $81 = ($77|0)==(0|0);
        if ($81) {
         $$pre57 = $74;$90 = $$$i;
         break;
        }
       }
       __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$77);
       $$pre57 = $74;$90 = $$$i;
      } else {
       $$pre57 = $77;$90 = $70;
      }
     } while(0);
     $indvars$iv$next49 = (($69) + 1)|0;
     $82 = (($$pre57) + ($69<<2)|0);
     HEAP32[$82>>2] = $67;
     $83 = HEAP32[$this>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = (($84) + ($i2$038<<2)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($86) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ($indvars$iv$next49|0)==($90|0);
     do {
      if ($89) {
       $144 = ($90|0)==(0);
       $145 = $90 << 1;
       $$$i$1 = $144 ? 16 : $145;
       $146 = HEAP32[$ts1$sroa$0>>2]|0;
       $147 = $$$i$1 << 2;
       $148 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$147,534704,153)|0);
       HEAP32[$ts1$sroa$0>>2] = $148;
       $149 = ($90|0)>(0);
       if ($149) {
        $i$01$i$i$1 = 0;
        while(1) {
         $151 = (($146) + ($i$01$i$i$1<<2)|0);
         $152 = HEAP32[$151>>2]|0;
         $153 = (($148) + ($i$01$i$i$1<<2)|0);
         HEAP32[$153>>2] = $152;
         $154 = (($i$01$i$i$1) + 1)|0;
         $exitcond50$1 = ($154|0)==($90|0);
         if ($exitcond50$1) {
          break;
         } else {
          $i$01$i$i$1 = $154;
         }
        }
       } else {
        $150 = ($146|0)==(0|0);
        if ($150) {
         $156 = $148;$164 = $$$i$1;
         break;
        }
       }
       __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$146);
       $156 = $148;$164 = $$$i$1;
      } else {
       $156 = $$pre57;$164 = $90;
      }
     } while(0);
     $indvars$iv$next49$1 = (($69) + 2)|0;
     $155 = (($156) + ($indvars$iv$next49<<2)|0);
     HEAP32[$155>>2] = $88;
     $157 = HEAP32[$this>>2]|0;
     $158 = HEAP32[$157>>2]|0;
     $159 = (($158) + ($i2$038<<2)|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = (($160) + 8|0);
     $162 = HEAP32[$161>>2]|0;
     $163 = ($indvars$iv$next49$1|0)==($164|0);
     do {
      if ($163) {
       $165 = ($164|0)==(0);
       $166 = $164 << 1;
       $$$i$2 = $165 ? 16 : $166;
       $167 = $$$i$2 << 2;
       $168 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$167,534704,153)|0);
       HEAP32[$ts1$sroa$0>>2] = $168;
       $169 = ($164|0)>(0);
       if ($169) {
        $i$01$i$i$2 = 0;
        while(1) {
         $171 = (($156) + ($i$01$i$i$2<<2)|0);
         $172 = HEAP32[$171>>2]|0;
         $173 = (($168) + ($i$01$i$i$2<<2)|0);
         HEAP32[$173>>2] = $172;
         $174 = (($i$01$i$i$2) + 1)|0;
         $exitcond50$2 = ($174|0)==($164|0);
         if ($exitcond50$2) {
          break;
         } else {
          $i$01$i$i$2 = $174;
         }
        }
       } else {
        $170 = ($156|0)==(0|0);
        if ($170) {
         $176 = $168;$192 = $$$i$2;
         break;
        }
       }
       __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$156);
       $176 = $168;$192 = $$$i$2;
      } else {
       $176 = $156;$192 = $164;
      }
     } while(0);
     $175 = (($176) + ($indvars$iv$next49$1<<2)|0);
     HEAP32[$175>>2] = $162;
     $177 = HEAP32[$this>>2]|0;
     $178 = HEAP32[$177>>2]|0;
     $179 = (($178) + ($i2$038<<2)|0);
     $91 = HEAP32[$179>>2]|0;
     $180 = (($69) + 3)|0;
     $181 = (($91) + 24|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = (($178) + ($182<<2)|0);
     HEAP32[$183>>2] = 0;
     $184 = ($91|0)==(0|0);
     if ($184) {
      $189 = $176;$190 = $192;$191 = $180;
     } else {
      __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$91);
      $189 = $176;$190 = $192;$191 = $180;
     }
    }
    $92 = (($i2$038) + 1)|0;
    $93 = HEAP32[$this>>2]|0;
    $94 = (($93) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($92|0)<($95|0);
    if ($96) {
     $63 = $93;$69 = $191;$70 = $190;$77 = $189;$i2$038 = $92;
    } else {
     $$lcssa36 = $191;$98 = $189;
     break;
    }
   }
  } else {
   $$lcssa36 = 0;$98 = 0;
  }
  $97 = (($$lcssa36|0) / 3)&-1;
  HEAP32[$tris_count>>2] = $97;
  HEAP32[$tris_out>>2] = $98;
  HEAP32[$ts1$sroa$0>>2] = 0;
  $99 = HEAP32[$this>>2]|0;
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0|0);
  if (!($101)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$100);
   HEAP32[$99>>2] = 0;
  }
  $102 = (($99) + 8|0);
  HEAP32[$102>>2] = 0;
  $$pre$i = (($99) + 4|0);
  HEAP32[$$pre$i>>2] = 0;
  HEAP32[$ts1$sroa$0>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (__ZN5physx11HullLibrary10expandhullEPNS_6float3EiRS2_Rif($this,$verts,$verts_count,$verts_out,$verts_count_out,Math_fround(0.0))|0);
 $8 = HEAP32[$verts_out>>2]|0;
 $9 = HEAP32[$verts_count_out>>2]|0;
 $10 = (__ZN5physx11HullLibrary11calchullgenEPNS_6float3Eiif($this,$8,$9,256,$areaEpsilon)|0);
 $11 = $10 & -3;
 $12 = ($11|0)==(1);
 if ($12) {
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$ts$sroa$0>>2] = 0;
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(0);
 if ($16) {
  $18 = $13;$24 = 0;$25 = 0;$32 = 0;$i$027 = 0;
  while(1) {
   $17 = HEAP32[$18>>2]|0;
   $19 = (($17) + ($i$027<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $185 = $32;$186 = $25;$187 = $24;
   } else {
    $22 = HEAP32[$20>>2]|0;
    $23 = ($24|0)==($25|0);
    do {
     if ($23) {
      $26 = ($24|0)==(0);
      $27 = $24 << 1;
      $$$i8 = $26 ? 16 : $27;
      $28 = $$$i8 << 2;
      $29 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$28,534704,153)|0);
      HEAP32[$ts$sroa$0>>2] = $29;
      $30 = ($24|0)>(0);
      if ($30) {
       $i$01$i$i9 = 0;
       while(1) {
        $31 = (($32) + ($i$01$i$i9<<2)|0);
        $33 = HEAP32[$31>>2]|0;
        $34 = (($29) + ($i$01$i$i9<<2)|0);
        HEAP32[$34>>2] = $33;
        $35 = (($i$01$i$i9) + 1)|0;
        $exitcond = ($35|0)==($24|0);
        if ($exitcond) {
         break;
        } else {
         $i$01$i$i9 = $35;
        }
       }
      } else {
       $36 = ($32|0)==(0|0);
       if ($36) {
        $$pre = $29;$45 = $$$i8;
        break;
       }
      }
      __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$32);
      $$pre = $29;$45 = $$$i8;
     } else {
      $$pre = $32;$45 = $25;
     }
    } while(0);
    $indvars$iv$next = (($24) + 1)|0;
    $37 = (($$pre) + ($24<<2)|0);
    HEAP32[$37>>2] = $22;
    $38 = HEAP32[$this>>2]|0;
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + ($i$027<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($indvars$iv$next|0)==($45|0);
    do {
     if ($44) {
      $103 = ($45|0)==(0);
      $104 = $45 << 1;
      $$$i8$1 = $103 ? 16 : $104;
      $105 = HEAP32[$ts$sroa$0>>2]|0;
      $106 = $$$i8$1 << 2;
      $107 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$106,534704,153)|0);
      HEAP32[$ts$sroa$0>>2] = $107;
      $108 = ($45|0)>(0);
      if ($108) {
       $i$01$i$i9$1 = 0;
       while(1) {
        $110 = (($105) + ($i$01$i$i9$1<<2)|0);
        $111 = HEAP32[$110>>2]|0;
        $112 = (($107) + ($i$01$i$i9$1<<2)|0);
        HEAP32[$112>>2] = $111;
        $113 = (($i$01$i$i9$1) + 1)|0;
        $exitcond$1 = ($113|0)==($45|0);
        if ($exitcond$1) {
         break;
        } else {
         $i$01$i$i9$1 = $113;
        }
       }
      } else {
       $109 = ($105|0)==(0|0);
       if ($109) {
        $115 = $107;$123 = $$$i8$1;
        break;
       }
      }
      __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$105);
      $115 = $107;$123 = $$$i8$1;
     } else {
      $115 = $$pre;$123 = $45;
     }
    } while(0);
    $indvars$iv$next$1 = (($24) + 2)|0;
    $114 = (($115) + ($indvars$iv$next<<2)|0);
    HEAP32[$114>>2] = $43;
    $116 = HEAP32[$this>>2]|0;
    $117 = HEAP32[$116>>2]|0;
    $118 = (($117) + ($i$027<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($119) + 8|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = ($indvars$iv$next$1|0)==($123|0);
    do {
     if ($122) {
      $124 = ($123|0)==(0);
      $125 = $123 << 1;
      $$$i8$2 = $124 ? 16 : $125;
      $126 = $$$i8$2 << 2;
      $127 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$126,534704,153)|0);
      HEAP32[$ts$sroa$0>>2] = $127;
      $128 = ($123|0)>(0);
      if ($128) {
       $i$01$i$i9$2 = 0;
       while(1) {
        $130 = (($115) + ($i$01$i$i9$2<<2)|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = (($127) + ($i$01$i$i9$2<<2)|0);
        HEAP32[$132>>2] = $131;
        $133 = (($i$01$i$i9$2) + 1)|0;
        $exitcond$2 = ($133|0)==($123|0);
        if ($exitcond$2) {
         break;
        } else {
         $i$01$i$i9$2 = $133;
        }
       }
      } else {
       $129 = ($115|0)==(0|0);
       if ($129) {
        $135 = $127;$188 = $$$i8$2;
        break;
       }
      }
      __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$115);
      $135 = $127;$188 = $$$i8$2;
     } else {
      $135 = $115;$188 = $123;
     }
    } while(0);
    $134 = (($135) + ($indvars$iv$next$1<<2)|0);
    HEAP32[$134>>2] = $121;
    $136 = HEAP32[$this>>2]|0;
    $137 = HEAP32[$136>>2]|0;
    $138 = (($137) + ($i$027<<2)|0);
    $46 = HEAP32[$138>>2]|0;
    $139 = (($24) + 3)|0;
    $140 = (($46) + 24|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (($137) + ($141<<2)|0);
    HEAP32[$142>>2] = 0;
    $143 = ($46|0)==(0|0);
    if ($143) {
     $185 = $135;$186 = $188;$187 = $139;
    } else {
     __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$46);
     $185 = $135;$186 = $188;$187 = $139;
    }
   }
   $47 = (($i$027) + 1)|0;
   $48 = HEAP32[$this>>2]|0;
   $49 = (($48) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($47|0)<($50|0);
   if ($51) {
    $18 = $48;$24 = $187;$25 = $186;$32 = $185;$i$027 = $47;
   } else {
    $$lcssa25 = $187;$53 = $185;
    break;
   }
  }
 } else {
  $$lcssa25 = 0;$53 = 0;
 }
 $52 = (($$lcssa25|0) / 3)&-1;
 HEAP32[$tris_count>>2] = $52;
 HEAP32[$tris_out>>2] = $53;
 HEAP32[$ts$sroa$0>>2] = 0;
 $54 = HEAP32[$this>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$55);
  HEAP32[$54>>2] = 0;
 }
 $57 = (($54) + 8|0);
 HEAP32[$57>>2] = 0;
 $$pre$i17 = (($54) + 4|0);
 HEAP32[$$pre$i17>>2] = 0;
 HEAP32[$ts$sroa$0>>2] = 0;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11HullLibrary12calchullpbevEPNS_6float3EiiRNS_12hullLibArray5ArrayINS_5PlaneEEEf($this,$verts,$verts_count,$0,$planes,$bevangle) {
 $this = $this|0;
 $verts = $verts|0;
 $verts_count = $verts_count|0;
 $0 = $0|0;
 $planes = $planes|0;
 $bevangle = Math_fround($bevangle);
 var $$$i = 0, $$$i132 = 0, $$$i150 = 0, $$$i150192235 = 0, $$$i150193 = 0, $$$i150194228 = 0, $$$i150195 = 0, $$$i150196 = 0, $$0 = 0, $$idx$i = 0, $$idx$val$i = Math_fround(0), $$idx1$i = 0, $$idx1$val$i = Math_fround(0), $$idx10 = 0, $$idx10$val = Math_fround(0), $$idx100 = 0, $$idx100$val = Math_fround(0), $$idx101 = 0, $$idx101$val = Math_fround(0), $$idx102 = 0;
 var $$idx102$val = Math_fround(0), $$idx103 = 0, $$idx103$val = Math_fround(0), $$idx104 = 0, $$idx104$val = Math_fround(0), $$idx105 = 0, $$idx105$val = Math_fround(0), $$idx106 = 0, $$idx106$val = Math_fround(0), $$idx107 = 0, $$idx107$val = Math_fround(0), $$idx108 = 0, $$idx108$val = Math_fround(0), $$idx11 = 0, $$idx11$val = Math_fround(0), $$idx12 = 0, $$idx12$val = Math_fround(0), $$idx13 = 0, $$idx13$val = Math_fround(0), $$idx14 = 0;
 var $$idx14$val = Math_fround(0), $$idx2$i = 0, $$idx2$val$i = Math_fround(0), $$idx27 = 0, $$idx27$val = Math_fround(0), $$idx28 = 0, $$idx28$val = Math_fround(0), $$idx29 = 0, $$idx29$val = Math_fround(0), $$idx3 = 0, $$idx3$val = Math_fround(0), $$idx4 = 0, $$idx4$val = Math_fround(0), $$idx5 = 0, $$idx5$i = 0, $$idx5$val = Math_fround(0), $$idx5$val$i = Math_fround(0), $$idx6 = 0, $$idx6$i = 0, $$idx6$val = Math_fround(0);
 var $$idx6$val$i = Math_fround(0), $$idx64 = 0, $$idx64$val = Math_fround(0), $$idx65 = 0, $$idx65$val = Math_fround(0), $$idx66 = 0, $$idx66$val = Math_fround(0), $$idx67 = 0, $$idx67$val = Math_fround(0), $$idx68 = 0, $$idx68$val = Math_fround(0), $$idx69 = 0, $$idx69$val = Math_fround(0), $$idx7 = 0, $$idx7$i = 0, $$idx7$val = Math_fround(0), $$idx7$val$i = Math_fround(0), $$idx70 = 0, $$idx70$val = Math_fround(0), $$idx71 = 0;
 var $$idx71$val = Math_fround(0), $$idx72 = 0, $$idx72$val = Math_fround(0), $$idx73 = 0, $$idx73$val = Math_fround(0), $$idx74 = 0, $$idx74$val = Math_fround(0), $$idx75 = 0, $$idx75$val = Math_fround(0), $$idx76 = 0, $$idx76$val = Math_fround(0), $$idx77 = 0, $$idx77$val = Math_fround(0), $$idx78 = 0, $$idx78$val = Math_fround(0), $$idx79 = 0, $$idx79$val = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0), $$idx80 = 0;
 var $$idx80$val = Math_fround(0), $$idx81 = 0, $$idx81$val = Math_fround(0), $$idx82 = 0, $$idx82$val = Math_fround(0), $$idx83 = 0, $$idx83$val = Math_fround(0), $$idx84 = 0, $$idx84$val = Math_fround(0), $$idx85 = 0, $$idx85$val = Math_fround(0), $$idx86 = 0, $$idx86$val = Math_fround(0), $$idx87 = 0, $$idx87$val = Math_fround(0), $$idx88 = 0, $$idx88$val = Math_fround(0), $$idx89 = 0, $$idx89$val = Math_fround(0), $$idx9 = 0;
 var $$idx9$val = Math_fround(0), $$idx90 = 0, $$idx90$val = Math_fround(0), $$idx91 = 0, $$idx91$val = Math_fround(0), $$idx92 = 0, $$idx92$val = Math_fround(0), $$idx93 = 0, $$idx93$val = Math_fround(0), $$idx94 = 0, $$idx94$val = Math_fround(0), $$idx95 = 0, $$idx95$val = Math_fround(0), $$idx96 = 0, $$idx96$val = Math_fround(0), $$idx97 = 0, $$idx97$val = Math_fround(0), $$idx98 = 0, $$idx98$val = Math_fround(0), $$idx99 = 0;
 var $$idx99$val = Math_fround(0), $$lcssa = 0, $$phi$trans$insert259 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i134 = 0, $$pre$i137 = 0, $$pre$phi265Z2D = 0, $$pre$phi267Z2D = 0, $$pre$phi269Z2D = 0, $$pre249 = 0, $$pre250 = 0, $$pre251 = 0, $$pre258 = 0, $$pre260 = 0, $$pre261 = 0, $$pre263 = 0, $1 = 0, $10 = 0;
 var $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0);
 var $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0);
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0.0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0);
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0);
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0);
 var $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0);
 var $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0);
 var $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0);
 var $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0);
 var $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0);
 var $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0);
 var $443 = Math_fround(0), $444 = Math_fround(0), $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $bplanes$sroa$0 = 0, $d$0$i = Math_fround(0), $exitcond = 0, $exitcond$i = 0, $exitcond245 = 0, $i$012$i = 0, $i$0236 = 0, $i$1219 = 0, $i$2213 = 0;
 var $i$3211 = 0, $i$4203 = 0, $j$0229 = 0, $j$1 = 0, $j$1216 = 0, $j$2$lcssa = 0, $j$2205 = 0, $m$0$lcssa$i = 0, $m$011$i = 0, $m$1$i = 0, $or$cond = 0, $or$cond197 = 0, $or$cond201 = 0, $or$cond202 = 0, $or$cond274 = 0, $tmp247 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $1 = sp + 26|0;
 $2 = sp + 25|0;
 $3 = sp + 24|0;
 $4 = sp + 23|0;
 $5 = sp + 22|0;
 $6 = sp + 20|0;
 $7 = sp;
 $8 = sp + 21|0;
 $bplanes$sroa$0 = sp + 16|0;
 HEAP32[$bplanes$sroa$0>>2] = 0;
 $9 = (($planes) + 4|0);
 HEAP32[$9>>2] = 0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)>(0);
 L1: do {
  if ($13) {
   $14 = Math_fround($bevangle * Math_fround(0.0174532923847436904907));
   $15 = +$14;
   $16 = ($verts_count|0)>(1);
   $$$i150192235 = 0;$20 = $10;$486 = 0;$487 = 0;$i$0236 = 0;
   while(1) {
    $19 = HEAP32[$20>>2]|0;
    $21 = (($19) + ($i$0236<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$$i150193 = $$$i150192235;$207 = $20;$352 = $487;$433 = $486;
    } else {
     $24 = HEAP32[$22>>2]|0;
     $25 = (($22) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($22) + 8|0);
     $28 = HEAP32[$27>>2]|0;
     $$idx100 = (($verts) + (($24*12)|0)|0);
     $$idx100$val = Math_fround(HEAPF32[$$idx100>>2]);
     $$idx101 = ((($verts) + (($24*12)|0)|0) + 4|0);
     $$idx101$val = Math_fround(HEAPF32[$$idx101>>2]);
     $$idx102 = ((($verts) + (($24*12)|0)|0) + 8|0);
     $$idx102$val = Math_fround(HEAPF32[$$idx102>>2]);
     $$idx103 = (($verts) + (($26*12)|0)|0);
     $$idx103$val = Math_fround(HEAPF32[$$idx103>>2]);
     $$idx104 = ((($verts) + (($26*12)|0)|0) + 4|0);
     $$idx104$val = Math_fround(HEAPF32[$$idx104>>2]);
     $$idx105 = ((($verts) + (($26*12)|0)|0) + 8|0);
     $$idx105$val = Math_fround(HEAPF32[$$idx105>>2]);
     $$idx106 = (($verts) + (($28*12)|0)|0);
     $$idx106$val = Math_fround(HEAPF32[$$idx106>>2]);
     $$idx107 = ((($verts) + (($28*12)|0)|0) + 4|0);
     $$idx107$val = Math_fround(HEAPF32[$$idx107>>2]);
     $$idx108 = ((($verts) + (($28*12)|0)|0) + 8|0);
     $$idx108$val = Math_fround(HEAPF32[$$idx108>>2]);
     $29 = Math_fround($$idx103$val - $$idx100$val);
     $30 = Math_fround($$idx104$val - $$idx101$val);
     $31 = Math_fround($$idx105$val - $$idx102$val);
     $32 = Math_fround($$idx106$val - $$idx103$val);
     $33 = Math_fround($$idx107$val - $$idx104$val);
     $34 = Math_fround($$idx108$val - $$idx105$val);
     $35 = Math_fround($30 * $34);
     $36 = Math_fround($31 * $33);
     $37 = Math_fround($35 - $36);
     $38 = Math_fround($31 * $32);
     $39 = Math_fround($29 * $34);
     $40 = Math_fround($38 - $39);
     $41 = Math_fround($29 * $33);
     $42 = Math_fround($30 * $32);
     $43 = Math_fround($41 - $42);
     $44 = Math_fround($37 * $37);
     $45 = Math_fround($40 * $40);
     $46 = Math_fround($44 + $45);
     $47 = Math_fround($43 * $43);
     $48 = Math_fround($47 + $46);
     $49 = (Math_fround(Math_sqrt((Math_fround($48)))));
     $50 = $49 == Math_fround(0.0);
     if ($50) {
      $101 = Math_fround(0.0);$105 = Math_fround(0.0);$98 = Math_fround(1.0);
     } else {
      $51 = Math_fround(Math_fround(1.0) / $49);
      $52 = Math_fround($37 * $51);
      $53 = Math_fround($40 * $51);
      $54 = Math_fround($43 * $51);
      $101 = $53;$105 = $54;$98 = $52;
     }
     $55 = (($22) + 12|0);
     $56 = (($22) + 24|0);
     $$$i150194228 = $$$i150192235;$184 = $487;$190 = $486;$j$0229 = 0;
     while(1) {
      $57 = (($55) + ($j$0229<<2)|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = HEAP32[$56>>2]|0;
      $60 = ($58|0)<($59|0);
      if ($60) {
       $$$i150195 = $$$i150194228;$489 = $190;$490 = $184;
      } else {
       $61 = HEAP32[$this>>2]|0;
       $62 = HEAP32[$61>>2]|0;
       $63 = (($62) + ($58<<2)|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = (($64) + 4|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($64) + 8|0);
       $69 = HEAP32[$68>>2]|0;
       $$idx91 = (($verts) + (($65*12)|0)|0);
       $$idx91$val = Math_fround(HEAPF32[$$idx91>>2]);
       $$idx92 = ((($verts) + (($65*12)|0)|0) + 4|0);
       $$idx92$val = Math_fround(HEAPF32[$$idx92>>2]);
       $$idx93 = ((($verts) + (($65*12)|0)|0) + 8|0);
       $$idx93$val = Math_fround(HEAPF32[$$idx93>>2]);
       $$idx94 = (($verts) + (($67*12)|0)|0);
       $$idx94$val = Math_fround(HEAPF32[$$idx94>>2]);
       $$idx95 = ((($verts) + (($67*12)|0)|0) + 4|0);
       $$idx95$val = Math_fround(HEAPF32[$$idx95>>2]);
       $$idx96 = ((($verts) + (($67*12)|0)|0) + 8|0);
       $$idx96$val = Math_fround(HEAPF32[$$idx96>>2]);
       $$idx97 = (($verts) + (($69*12)|0)|0);
       $$idx97$val = Math_fround(HEAPF32[$$idx97>>2]);
       $$idx98 = ((($verts) + (($69*12)|0)|0) + 4|0);
       $$idx98$val = Math_fround(HEAPF32[$$idx98>>2]);
       $$idx99 = ((($verts) + (($69*12)|0)|0) + 8|0);
       $$idx99$val = Math_fround(HEAPF32[$$idx99>>2]);
       $70 = Math_fround($$idx94$val - $$idx91$val);
       $71 = Math_fround($$idx95$val - $$idx92$val);
       $72 = Math_fround($$idx96$val - $$idx93$val);
       $73 = Math_fround($$idx97$val - $$idx94$val);
       $74 = Math_fround($$idx98$val - $$idx95$val);
       $75 = Math_fround($$idx99$val - $$idx96$val);
       $76 = Math_fround($71 * $75);
       $77 = Math_fround($72 * $74);
       $78 = Math_fround($76 - $77);
       $79 = Math_fround($72 * $73);
       $80 = Math_fround($70 * $75);
       $81 = Math_fround($79 - $80);
       $82 = Math_fround($70 * $74);
       $83 = Math_fround($71 * $73);
       $84 = Math_fround($82 - $83);
       $85 = Math_fround($78 * $78);
       $86 = Math_fround($81 * $81);
       $87 = Math_fround($85 + $86);
       $88 = Math_fround($84 * $84);
       $89 = Math_fround($88 + $87);
       $90 = (Math_fround(Math_sqrt((Math_fround($89)))));
       $91 = $90 == Math_fround(0.0);
       if ($91) {
        $100 = Math_fround(0.0);$104 = Math_fround(0.0);$97 = Math_fround(1.0);
       } else {
        $92 = Math_fround(Math_fround(1.0) / $90);
        $93 = Math_fround($78 * $92);
        $94 = Math_fround($81 * $92);
        $95 = Math_fround($84 * $92);
        $100 = $94;$104 = $95;$97 = $93;
       }
       $96 = Math_fround($98 * $97);
       $99 = Math_fround($101 * $100);
       $102 = Math_fround($99 + $96);
       $103 = Math_fround($105 * $104);
       $106 = Math_fround($103 + $102);
       $107 = +$106;
       $108 = (+Math_cos((+$15)));
       $109 = !($107 >= $108);
       if ($109) {
        $110 = (($j$0229) + 2)|0;
        $111 = (($110|0) % 3)&-1;
        $112 = (($22) + ($111<<2)|0);
        $113 = HEAP32[$112>>2]|0;
        $114 = (($j$0229) + 1)|0;
        $115 = ($114|0)==(3);
        $tmp247 = $115 ? 0 : $114;
        $116 = (($22) + ($tmp247<<2)|0);
        $117 = HEAP32[$116>>2]|0;
        $$idx3 = (($verts) + (($113*12)|0)|0);
        $$idx3$val = Math_fround(HEAPF32[$$idx3>>2]);
        $$idx4 = ((($verts) + (($113*12)|0)|0) + 4|0);
        $$idx4$val = Math_fround(HEAPF32[$$idx4>>2]);
        $$idx5 = ((($verts) + (($113*12)|0)|0) + 8|0);
        $$idx5$val = Math_fround(HEAPF32[$$idx5>>2]);
        $$idx6 = (($verts) + (($117*12)|0)|0);
        $$idx6$val = Math_fround(HEAPF32[$$idx6>>2]);
        $$idx7 = ((($verts) + (($117*12)|0)|0) + 4|0);
        $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
        $$idx8 = ((($verts) + (($117*12)|0)|0) + 8|0);
        $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
        $118 = Math_fround($$idx3$val - $$idx6$val);
        $119 = Math_fround($$idx4$val - $$idx7$val);
        $120 = Math_fround($$idx5$val - $$idx8$val);
        $121 = $118 != Math_fround(0.0);
        $122 = $119 != Math_fround(0.0);
        $or$cond = $121 | $122;
        $123 = $120 != Math_fround(0.0);
        $or$cond201 = $or$cond | $123;
        if ($or$cond201) {
         $124 = Math_fround($100 * $120);
         $125 = Math_fround($104 * $119);
         $126 = Math_fround($124 - $125);
         $127 = Math_fround($104 * $118);
         $128 = Math_fround($97 * $120);
         $129 = Math_fround($127 - $128);
         $130 = Math_fround($97 * $119);
         $131 = Math_fround($100 * $118);
         $132 = Math_fround($130 - $131);
         $133 = Math_fround($105 * $119);
         $134 = Math_fround($101 * $120);
         $135 = Math_fround($133 - $134);
         $136 = Math_fround($98 * $120);
         $137 = Math_fround($105 * $118);
         $138 = Math_fround($136 - $137);
         $139 = Math_fround($101 * $118);
         $140 = Math_fround($98 * $119);
         $141 = Math_fround($139 - $140);
         $142 = Math_fround($126 + $135);
         $143 = Math_fround($129 + $138);
         $144 = Math_fround($132 + $141);
         $149 = $142;$151 = $143;$153 = $144;
        } else {
         $145 = Math_fround($98 + $97);
         $146 = Math_fround($101 + $100);
         $147 = Math_fround($105 + $104);
         $149 = $145;$151 = $146;$153 = $147;
        }
        $148 = $149 == Math_fround(0.0);
        $150 = $151 == Math_fround(0.0);
        $or$cond197 = $148 & $150;
        $152 = $153 == Math_fround(0.0);
        $or$cond202 = $or$cond197 & $152;
        if ($or$cond202) {
         $$0 = 1;$485 = $190;
         break L1;
        }
        $154 = Math_fround($149 * $149);
        $155 = Math_fround($151 * $151);
        $156 = Math_fround($155 + $154);
        $157 = Math_fround($153 * $153);
        $158 = Math_fround($157 + $156);
        $159 = (Math_fround(Math_sqrt((Math_fround($158)))));
        $160 = $159 == Math_fround(0.0);
        if ($160) {
         (_puts((534992|0))|0);
         $d$0$i = Math_fround(0.100000001490116119385);
        } else {
         $d$0$i = $159;
        }
        $161 = Math_fround(Math_fround(1.0) / $d$0$i);
        $162 = Math_fround($149 * $161);
        $163 = Math_fround($151 * $161);
        $164 = Math_fround($153 * $161);
        if ($16) {
         $i$012$i = 1;$m$011$i = 0;
         while(1) {
          $$idx5$i = (($verts) + (($i$012$i*12)|0)|0);
          $$idx5$val$i = Math_fround(HEAPF32[$$idx5$i>>2]);
          $$idx6$i = ((($verts) + (($i$012$i*12)|0)|0) + 4|0);
          $$idx6$val$i = Math_fround(HEAPF32[$$idx6$i>>2]);
          $$idx7$i = ((($verts) + (($i$012$i*12)|0)|0) + 8|0);
          $$idx7$val$i = Math_fround(HEAPF32[$$idx7$i>>2]);
          $165 = Math_fround($162 * $$idx5$val$i);
          $166 = Math_fround($163 * $$idx6$val$i);
          $167 = Math_fround($165 + $166);
          $168 = Math_fround($164 * $$idx7$val$i);
          $169 = Math_fround($167 + $168);
          $$idx$i = (($verts) + (($m$011$i*12)|0)|0);
          $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
          $$idx1$i = ((($verts) + (($m$011$i*12)|0)|0) + 4|0);
          $$idx1$val$i = Math_fround(HEAPF32[$$idx1$i>>2]);
          $$idx2$i = ((($verts) + (($m$011$i*12)|0)|0) + 8|0);
          $$idx2$val$i = Math_fround(HEAPF32[$$idx2$i>>2]);
          $170 = Math_fround($162 * $$idx$val$i);
          $171 = Math_fround($163 * $$idx1$val$i);
          $172 = Math_fround($170 + $171);
          $173 = Math_fround($164 * $$idx2$val$i);
          $174 = Math_fround($172 + $173);
          $175 = $169 > $174;
          $m$1$i = $175 ? $i$012$i : $m$011$i;
          $176 = (($i$012$i) + 1)|0;
          $exitcond$i = ($176|0)==($verts_count|0);
          if ($exitcond$i) {
           $m$0$lcssa$i = $m$1$i;
           break;
          } else {
           $i$012$i = $176;$m$011$i = $m$1$i;
          }
         }
        } else {
         $m$0$lcssa$i = 0;
        }
        $$idx27 = (($verts) + (($m$0$lcssa$i*12)|0)|0);
        $$idx27$val = Math_fround(HEAPF32[$$idx27>>2]);
        $$idx28 = ((($verts) + (($m$0$lcssa$i*12)|0)|0) + 4|0);
        $$idx28$val = Math_fround(HEAPF32[$$idx28>>2]);
        $$idx29 = ((($verts) + (($m$0$lcssa$i*12)|0)|0) + 8|0);
        $$idx29$val = Math_fround(HEAPF32[$$idx29>>2]);
        $177 = Math_fround($162 * $$idx27$val);
        $178 = Math_fround($163 * $$idx28$val);
        $179 = Math_fround($177 + $178);
        $180 = Math_fround($164 * $$idx29$val);
        $181 = Math_fround($179 + $180);
        $182 = Math_fround(-$181);
        $183 = ($184|0)==($$$i150194228|0);
        do {
         if ($183) {
          $185 = ($184|0)==(0);
          $186 = $184 << 1;
          $$$i150 = $185 ? 16 : $186;
          $187 = $$$i150 << 4;
          $188 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$187,534704,153)|0);
          HEAP32[$bplanes$sroa$0>>2] = $188;
          $189 = ($184|0)>(0);
          if ($189) {
           ;HEAP32[$188+0>>2]=HEAP32[$190+0>>2]|0;HEAP32[$188+4>>2]=HEAP32[$190+4>>2]|0;HEAP32[$188+8>>2]=HEAP32[$190+8>>2]|0;HEAP32[$188+12>>2]=HEAP32[$190+12>>2]|0;
           $191 = ($184|0)>(1);
           if ($191) {
            $193 = 1;
            while(1) {
             $192 = (($188) + ($193<<4)|0);
             $194 = (($190) + ($193<<4)|0);
             ;HEAP32[$192+0>>2]=HEAP32[$194+0>>2]|0;HEAP32[$192+4>>2]=HEAP32[$194+4>>2]|0;HEAP32[$192+8>>2]=HEAP32[$194+8>>2]|0;HEAP32[$192+12>>2]=HEAP32[$194+12>>2]|0;
             $195 = (($193) + 1)|0;
             $exitcond245 = ($195|0)==($184|0);
             if ($exitcond245) {
              $$pre$phi269Z2D = $190;
              break;
             } else {
              $193 = $195;
             }
            }
           } else {
            label = 25;
           }
          } else {
           label = 25;
          }
          if ((label|0) == 25) {
           label = 0;
           $196 = ($190|0)==(0|0);
           if ($196) {
            $$$i150196 = $$$i150;$199 = $188;
            break;
           }
           $$pre$phi269Z2D = $190;
          }
          __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$$pre$phi269Z2D);
          $$$i150196 = $$$i150;$199 = $188;
         } else {
          $$$i150196 = $$$i150194228;$199 = $190;
         }
        } while(0);
        $197 = (($184) + 1)|0;
        $198 = (($199) + ($184<<4)|0);
        HEAPF32[$198>>2] = $162;
        $200 = ((($199) + ($184<<4)|0) + 4|0);
        HEAPF32[$200>>2] = $163;
        $201 = ((($199) + ($184<<4)|0) + 8|0);
        HEAPF32[$201>>2] = $164;
        $202 = ((($199) + ($184<<4)|0) + 12|0);
        HEAPF32[$202>>2] = $182;
        $$$i150195 = $$$i150196;$489 = $199;$490 = $197;
       } else {
        $$$i150195 = $$$i150194228;$489 = $190;$490 = $184;
       }
      }
      $203 = (($j$0229) + 1)|0;
      $204 = ($203|0)<(3);
      if ($204) {
       $$$i150194228 = $$$i150195;$184 = $490;$190 = $489;$j$0229 = $203;
      } else {
       break;
      }
     }
     $$pre261 = HEAP32[$this>>2]|0;
     $$$i150193 = $$$i150195;$207 = $$pre261;$352 = $490;$433 = $489;
    }
    $205 = (($i$0236) + 1)|0;
    $206 = (($207) + 4|0);
    $18 = HEAP32[$206>>2]|0;
    $208 = ($205|0)<($18|0);
    if ($208) {
     $$$i150192235 = $$$i150193;$20 = $207;$486 = $433;$487 = $352;$i$0236 = $205;
    } else {
     break;
    }
   }
   $17 = ($18|0)>(0);
   if ($17) {
    $213 = $207;$218 = $18;$i$1219 = 0;
    while(1) {
     $212 = HEAP32[$213>>2]|0;
     $214 = (($212) + ($i$1219<<2)|0);
     $215 = HEAP32[$214>>2]|0;
     $216 = ($215|0)!=(0|0);
     $$pre263 = (($i$1219) + 1)|0;
     $217 = ($$pre263|0)<($218|0);
     $or$cond274 = $216 & $217;
     L49: do {
      if ($or$cond274) {
       $220 = $215;$222 = $212;$j$1216 = $$pre263;
       while(1) {
        $219 = ($220|0)==(0|0);
        do {
         if (!($219)) {
          $221 = (($222) + ($j$1216<<2)|0);
          $223 = HEAP32[$221>>2]|0;
          $224 = ($223|0)==(0|0);
          if (!($224)) {
           $229 = HEAP32[$220>>2]|0;
           $230 = (($220) + 4|0);
           $231 = HEAP32[$230>>2]|0;
           $232 = (($220) + 8|0);
           $233 = HEAP32[$232>>2]|0;
           $$idx82 = (($verts) + (($229*12)|0)|0);
           $$idx82$val = Math_fround(HEAPF32[$$idx82>>2]);
           $$idx83 = ((($verts) + (($229*12)|0)|0) + 4|0);
           $$idx83$val = Math_fround(HEAPF32[$$idx83>>2]);
           $$idx84 = ((($verts) + (($229*12)|0)|0) + 8|0);
           $$idx84$val = Math_fround(HEAPF32[$$idx84>>2]);
           $$idx85 = (($verts) + (($231*12)|0)|0);
           $$idx85$val = Math_fround(HEAPF32[$$idx85>>2]);
           $$idx86 = ((($verts) + (($231*12)|0)|0) + 4|0);
           $$idx86$val = Math_fround(HEAPF32[$$idx86>>2]);
           $$idx87 = ((($verts) + (($231*12)|0)|0) + 8|0);
           $$idx87$val = Math_fround(HEAPF32[$$idx87>>2]);
           $$idx88 = (($verts) + (($233*12)|0)|0);
           $$idx88$val = Math_fround(HEAPF32[$$idx88>>2]);
           $$idx89 = ((($verts) + (($233*12)|0)|0) + 4|0);
           $$idx89$val = Math_fround(HEAPF32[$$idx89>>2]);
           $$idx90 = ((($verts) + (($233*12)|0)|0) + 8|0);
           $$idx90$val = Math_fround(HEAPF32[$$idx90>>2]);
           $234 = Math_fround($$idx85$val - $$idx82$val);
           $235 = Math_fround($$idx86$val - $$idx83$val);
           $236 = Math_fround($$idx87$val - $$idx84$val);
           $237 = Math_fround($$idx88$val - $$idx85$val);
           $238 = Math_fround($$idx89$val - $$idx86$val);
           $239 = Math_fround($$idx90$val - $$idx87$val);
           $240 = Math_fround($235 * $239);
           $241 = Math_fround($236 * $238);
           $242 = Math_fround($240 - $241);
           $243 = Math_fround($236 * $237);
           $244 = Math_fround($234 * $239);
           $245 = Math_fround($243 - $244);
           $246 = Math_fround($234 * $238);
           $247 = Math_fround($235 * $237);
           $248 = Math_fround($246 - $247);
           $249 = Math_fround($242 * $242);
           $250 = Math_fround($245 * $245);
           $251 = Math_fround($249 + $250);
           $252 = Math_fround($248 * $248);
           $253 = Math_fround($252 + $251);
           $254 = (Math_fround(Math_sqrt((Math_fround($253)))));
           $255 = $254 == Math_fround(0.0);
           if ($255) {
            $293 = Math_fround(1.0);$296 = Math_fround(0.0);$300 = Math_fround(0.0);
           } else {
            $256 = Math_fround(Math_fround(1.0) / $254);
            $257 = Math_fround($242 * $256);
            $258 = Math_fround($245 * $256);
            $259 = Math_fround($248 * $256);
            $293 = $257;$296 = $258;$300 = $259;
           }
           $260 = HEAP32[$223>>2]|0;
           $261 = (($223) + 4|0);
           $262 = HEAP32[$261>>2]|0;
           $263 = (($223) + 8|0);
           $264 = HEAP32[$263>>2]|0;
           $$idx73 = (($verts) + (($260*12)|0)|0);
           $$idx73$val = Math_fround(HEAPF32[$$idx73>>2]);
           $$idx74 = ((($verts) + (($260*12)|0)|0) + 4|0);
           $$idx74$val = Math_fround(HEAPF32[$$idx74>>2]);
           $$idx75 = ((($verts) + (($260*12)|0)|0) + 8|0);
           $$idx75$val = Math_fround(HEAPF32[$$idx75>>2]);
           $$idx76 = (($verts) + (($262*12)|0)|0);
           $$idx76$val = Math_fround(HEAPF32[$$idx76>>2]);
           $$idx77 = ((($verts) + (($262*12)|0)|0) + 4|0);
           $$idx77$val = Math_fround(HEAPF32[$$idx77>>2]);
           $$idx78 = ((($verts) + (($262*12)|0)|0) + 8|0);
           $$idx78$val = Math_fround(HEAPF32[$$idx78>>2]);
           $$idx79 = (($verts) + (($264*12)|0)|0);
           $$idx79$val = Math_fround(HEAPF32[$$idx79>>2]);
           $$idx80 = ((($verts) + (($264*12)|0)|0) + 4|0);
           $$idx80$val = Math_fround(HEAPF32[$$idx80>>2]);
           $$idx81 = ((($verts) + (($264*12)|0)|0) + 8|0);
           $$idx81$val = Math_fround(HEAPF32[$$idx81>>2]);
           $265 = Math_fround($$idx76$val - $$idx73$val);
           $266 = Math_fround($$idx77$val - $$idx74$val);
           $267 = Math_fround($$idx78$val - $$idx75$val);
           $268 = Math_fround($$idx79$val - $$idx76$val);
           $269 = Math_fround($$idx80$val - $$idx77$val);
           $270 = Math_fround($$idx81$val - $$idx78$val);
           $271 = Math_fround($266 * $270);
           $272 = Math_fround($267 * $269);
           $273 = Math_fround($271 - $272);
           $274 = Math_fround($267 * $268);
           $275 = Math_fround($265 * $270);
           $276 = Math_fround($274 - $275);
           $277 = Math_fround($265 * $269);
           $278 = Math_fround($266 * $268);
           $279 = Math_fround($277 - $278);
           $280 = Math_fround($273 * $273);
           $281 = Math_fround($276 * $276);
           $282 = Math_fround($280 + $281);
           $283 = Math_fround($279 * $279);
           $284 = Math_fround($283 + $282);
           $285 = (Math_fround(Math_sqrt((Math_fround($284)))));
           $286 = $285 == Math_fround(0.0);
           if ($286) {
            $292 = Math_fround(1.0);$295 = Math_fround(0.0);$299 = Math_fround(0.0);
           } else {
            $287 = Math_fround(Math_fround(1.0) / $285);
            $288 = Math_fround($273 * $287);
            $289 = Math_fround($276 * $287);
            $290 = Math_fround($279 * $287);
            $292 = $288;$295 = $289;$299 = $290;
           }
           $291 = Math_fround($293 * $292);
           $294 = Math_fround($296 * $295);
           $297 = Math_fround($294 + $291);
           $298 = Math_fround($300 * $299);
           $301 = Math_fround($298 + $297);
           $302 = $301 > Math_fround(0.998629510402679443359);
           if ($302) {
            $303 = Math_fround($$idx82$val - $$idx85$val);
            $304 = Math_fround($$idx83$val - $$idx86$val);
            $305 = Math_fround($$idx84$val - $$idx87$val);
            $306 = Math_fround($$idx88$val - $$idx82$val);
            $307 = Math_fround($$idx89$val - $$idx83$val);
            $308 = Math_fround($$idx90$val - $$idx84$val);
            $309 = Math_fround($304 * $308);
            $310 = Math_fround($305 * $307);
            $311 = Math_fround($309 - $310);
            $312 = Math_fround($305 * $306);
            $313 = Math_fround($303 * $308);
            $314 = Math_fround($312 - $313);
            $315 = Math_fround($303 * $307);
            $316 = Math_fround($304 * $306);
            $317 = Math_fround($315 - $316);
            $318 = Math_fround($311 * $311);
            $319 = Math_fround($314 * $314);
            $320 = Math_fround($318 + $319);
            $321 = Math_fround($317 * $317);
            $322 = Math_fround($321 + $320);
            $323 = Math_fround($$idx73$val - $$idx76$val);
            $324 = Math_fround($$idx74$val - $$idx77$val);
            $325 = Math_fround($$idx75$val - $$idx78$val);
            $326 = Math_fround($$idx79$val - $$idx73$val);
            $327 = Math_fround($$idx80$val - $$idx74$val);
            $328 = Math_fround($$idx81$val - $$idx75$val);
            $329 = Math_fround($324 * $328);
            $330 = Math_fround($325 * $327);
            $331 = Math_fround($329 - $330);
            $332 = Math_fround($325 * $326);
            $333 = Math_fround($323 * $328);
            $334 = Math_fround($332 - $333);
            $335 = Math_fround($323 * $327);
            $336 = Math_fround($324 * $326);
            $337 = Math_fround($335 - $336);
            $338 = Math_fround($331 * $331);
            $339 = Math_fround($334 * $334);
            $340 = Math_fround($338 + $339);
            $341 = Math_fround($337 * $337);
            $342 = Math_fround($341 + $340);
            $343 = $322 < $342;
            if ($343) {
             $344 = (($220) + 24|0);
             $345 = HEAP32[$344>>2]|0;
             $346 = (($222) + ($345<<2)|0);
             HEAP32[$346>>2] = 0;
             __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$220);
             break;
            } else {
             $347 = (($223) + 24|0);
             $348 = HEAP32[$347>>2]|0;
             $349 = (($222) + ($348<<2)|0);
             HEAP32[$349>>2] = 0;
             __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$223);
             break;
            }
           }
          }
         }
        } while(0);
        $j$1 = (($j$1216) + 1)|0;
        $225 = HEAP32[$this>>2]|0;
        $226 = (($225) + 4|0);
        $227 = HEAP32[$226>>2]|0;
        $228 = ($j$1|0)<($227|0);
        if (!($228)) {
         $210 = $227;$491 = $225;
         break L49;
        }
        $$pre258 = HEAP32[$225>>2]|0;
        $$phi$trans$insert259 = (($$pre258) + ($i$1219<<2)|0);
        $$pre260 = HEAP32[$$phi$trans$insert259>>2]|0;
        $220 = $$pre260;$222 = $$pre258;$j$1216 = $j$1;
       }
      } else {
       $210 = $218;$491 = $213;
      }
     } while(0);
     $350 = ($$pre263|0)<($210|0);
     if ($350) {
      $213 = $491;$218 = $210;$i$1219 = $$pre263;
     } else {
      break;
     }
    }
    $209 = ($210|0)>(0);
    if ($209) {
     $211 = (($planes) + 8|0);
     $355 = $491;$i$2213 = 0;
     while(1) {
      $354 = HEAP32[$355>>2]|0;
      $356 = (($354) + ($i$2213<<2)|0);
      $357 = HEAP32[$356>>2]|0;
      $358 = ($357|0)==(0|0);
      if ($358) {
       $427 = $355;
      } else {
       $359 = HEAP32[$357>>2]|0;
       $360 = (($357) + 4|0);
       $361 = HEAP32[$360>>2]|0;
       $362 = (($357) + 8|0);
       $363 = HEAP32[$362>>2]|0;
       $$idx64 = (($verts) + (($359*12)|0)|0);
       $$idx64$val = Math_fround(HEAPF32[$$idx64>>2]);
       $$idx65 = ((($verts) + (($359*12)|0)|0) + 4|0);
       $$idx65$val = Math_fround(HEAPF32[$$idx65>>2]);
       $$idx66 = ((($verts) + (($359*12)|0)|0) + 8|0);
       $$idx66$val = Math_fround(HEAPF32[$$idx66>>2]);
       $$idx67 = (($verts) + (($361*12)|0)|0);
       $$idx67$val = Math_fround(HEAPF32[$$idx67>>2]);
       $$idx68 = ((($verts) + (($361*12)|0)|0) + 4|0);
       $$idx68$val = Math_fround(HEAPF32[$$idx68>>2]);
       $$idx69 = ((($verts) + (($361*12)|0)|0) + 8|0);
       $$idx69$val = Math_fround(HEAPF32[$$idx69>>2]);
       $$idx70 = (($verts) + (($363*12)|0)|0);
       $$idx70$val = Math_fround(HEAPF32[$$idx70>>2]);
       $$idx71 = ((($verts) + (($363*12)|0)|0) + 4|0);
       $$idx71$val = Math_fround(HEAPF32[$$idx71>>2]);
       $$idx72 = ((($verts) + (($363*12)|0)|0) + 8|0);
       $$idx72$val = Math_fround(HEAPF32[$$idx72>>2]);
       $364 = Math_fround($$idx67$val - $$idx64$val);
       $365 = Math_fround($$idx68$val - $$idx65$val);
       $366 = Math_fround($$idx69$val - $$idx66$val);
       $367 = Math_fround($$idx70$val - $$idx67$val);
       $368 = Math_fround($$idx71$val - $$idx68$val);
       $369 = Math_fround($$idx72$val - $$idx69$val);
       $370 = Math_fround($365 * $369);
       $371 = Math_fround($366 * $368);
       $372 = Math_fround($370 - $371);
       $373 = Math_fround($366 * $367);
       $374 = Math_fround($364 * $369);
       $375 = Math_fround($373 - $374);
       $376 = Math_fround($364 * $368);
       $377 = Math_fround($365 * $367);
       $378 = Math_fround($376 - $377);
       $379 = Math_fround($372 * $372);
       $380 = Math_fround($375 * $375);
       $381 = Math_fround($379 + $380);
       $382 = Math_fround($378 * $378);
       $383 = Math_fround($382 + $381);
       $384 = (Math_fround(Math_sqrt((Math_fround($383)))));
       $385 = $384 == Math_fround(0.0);
       if ($385) {
        $391 = Math_fround(1.0);$393 = Math_fround(0.0);$396 = Math_fround(0.0);
       } else {
        $386 = Math_fround(Math_fround(1.0) / $384);
        $387 = Math_fround($372 * $386);
        $388 = Math_fround($375 * $386);
        $389 = Math_fround($378 * $386);
        $391 = $387;$393 = $388;$396 = $389;
       }
       $390 = Math_fround($391 * $$idx64$val);
       $392 = Math_fround($393 * $$idx65$val);
       $394 = Math_fround($390 + $392);
       $395 = Math_fround($396 * $$idx66$val);
       $397 = Math_fround($394 + $395);
       $398 = Math_fround(-$397);
       $399 = HEAP32[$9>>2]|0;
       $400 = HEAP32[$211>>2]|0;
       $401 = ($399|0)==($400|0);
       do {
        if ($401) {
         $402 = ($399|0)==(0);
         $403 = $399 << 1;
         $$$i132 = $402 ? 16 : $403;
         $404 = HEAP32[$planes>>2]|0;
         HEAP32[$211>>2] = $$$i132;
         $405 = $$$i132 << 4;
         $406 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$405,534704,153)|0);
         HEAP32[$planes>>2] = $406;
         $407 = HEAP32[$9>>2]|0;
         $408 = ($407|0)>(0);
         if ($408) {
          ;HEAP32[$406+0>>2]=HEAP32[$404+0>>2]|0;HEAP32[$406+4>>2]=HEAP32[$404+4>>2]|0;HEAP32[$406+8>>2]=HEAP32[$404+8>>2]|0;HEAP32[$406+12>>2]=HEAP32[$404+12>>2]|0;
          $409 = HEAP32[$9>>2]|0;
          $410 = ($409|0)>(1);
          if ($410) {
           $412 = 1;
           while(1) {
            $$pre$i$i134 = HEAP32[$planes>>2]|0;
            $411 = (($$pre$i$i134) + ($412<<4)|0);
            $413 = (($404) + ($412<<4)|0);
            ;HEAP32[$411+0>>2]=HEAP32[$413+0>>2]|0;HEAP32[$411+4>>2]=HEAP32[$413+4>>2]|0;HEAP32[$411+8>>2]=HEAP32[$413+8>>2]|0;HEAP32[$411+12>>2]=HEAP32[$413+12>>2]|0;
            $414 = (($412) + 1)|0;
            $415 = HEAP32[$9>>2]|0;
            $416 = ($414|0)<($415|0);
            if ($416) {
             $412 = $414;
            } else {
             $$pre$phi267Z2D = $404;
             break;
            }
           }
          } else {
           $492 = $409;
           label = 57;
          }
         } else {
          $492 = $407;
          label = 57;
         }
         if ((label|0) == 57) {
          label = 0;
          $417 = ($404|0)==(0|0);
          if ($417) {
           $419 = $492;
           break;
          }
          $$pre$phi267Z2D = $404;
         }
         __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$$pre$phi267Z2D);
         $$pre$i137 = HEAP32[$9>>2]|0;
         $419 = $$pre$i137;
        } else {
         $419 = $399;
        }
       } while(0);
       $418 = (($419) + 1)|0;
       HEAP32[$9>>2] = $418;
       $420 = HEAP32[$planes>>2]|0;
       $421 = (($420) + ($419<<4)|0);
       HEAPF32[$421>>2] = $391;
       $422 = ((($420) + ($419<<4)|0) + 4|0);
       HEAPF32[$422>>2] = $393;
       $423 = ((($420) + ($419<<4)|0) + 8|0);
       HEAPF32[$423>>2] = $396;
       $424 = ((($420) + ($419<<4)|0) + 12|0);
       HEAPF32[$424>>2] = $398;
       $$pre251 = HEAP32[$this>>2]|0;
       $427 = $$pre251;
      }
      $425 = (($i$2213) + 1)|0;
      $426 = (($427) + 4|0);
      $428 = HEAP32[$426>>2]|0;
      $429 = ($425|0)<($428|0);
      if ($429) {
       $355 = $427;$i$2213 = $425;
      } else {
       $488 = $427;
       break;
      }
     }
    } else {
     $488 = $491;
    }
   } else {
    $488 = $207;
   }
   $351 = ($352|0)>(0);
   if ($351) {
    $353 = (($planes) + 8|0);
    $i$3211 = 0;
    while(1) {
     $430 = HEAP32[$9>>2]|0;
     $431 = ($430|0)>(0);
     L93: do {
      if ($431) {
       $432 = HEAP32[$planes>>2]|0;
       $$idx9 = (($433) + ($i$3211<<4)|0);
       $$idx9$val = Math_fround(HEAPF32[$$idx9>>2]);
       $$idx10 = ((($433) + ($i$3211<<4)|0) + 4|0);
       $$idx10$val = Math_fround(HEAPF32[$$idx10>>2]);
       $$idx11 = ((($433) + ($i$3211<<4)|0) + 8|0);
       $$idx11$val = Math_fround(HEAPF32[$$idx11>>2]);
       $j$2205 = 0;
       while(1) {
        $$idx12 = (($432) + ($j$2205<<4)|0);
        $$idx12$val = Math_fround(HEAPF32[$$idx12>>2]);
        $$idx13 = ((($432) + ($j$2205<<4)|0) + 4|0);
        $$idx13$val = Math_fround(HEAPF32[$$idx13>>2]);
        $$idx14 = ((($432) + ($j$2205<<4)|0) + 8|0);
        $$idx14$val = Math_fround(HEAPF32[$$idx14>>2]);
        $440 = Math_fround($$idx9$val * $$idx12$val);
        $441 = Math_fround($$idx10$val * $$idx13$val);
        $442 = Math_fround($440 + $441);
        $443 = Math_fround($$idx11$val * $$idx14$val);
        $444 = Math_fround($442 + $443);
        $445 = $444 > Math_fround(0.998629510402679443359);
        $439 = (($j$2205) + 1)|0;
        if ($445) {
         $j$2$lcssa = $j$2205;
         break L93;
        }
        $438 = ($439|0)<($430|0);
        if ($438) {
         $j$2205 = $439;
        } else {
         $j$2$lcssa = $439;
         break;
        }
       }
      } else {
       $j$2$lcssa = 0;
      }
     } while(0);
     $446 = ($j$2$lcssa|0)==($430|0);
     if ($446) {
      $447 = (($433) + ($i$3211<<4)|0);
      _memmove(($7|0),($447|0),16)|0;
      $448 = HEAP32[$353>>2]|0;
      $449 = ($430|0)==($448|0);
      do {
       if ($449) {
        $450 = ($430|0)==(0);
        $451 = $430 << 1;
        $$$i = $450 ? 16 : $451;
        $452 = HEAP32[$planes>>2]|0;
        HEAP32[$353>>2] = $$$i;
        $453 = $$$i << 4;
        $454 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($5,$453,534704,153)|0);
        HEAP32[$planes>>2] = $454;
        $455 = HEAP32[$9>>2]|0;
        $456 = ($455|0)>(0);
        if ($456) {
         ;HEAP32[$454+0>>2]=HEAP32[$452+0>>2]|0;HEAP32[$454+4>>2]=HEAP32[$452+4>>2]|0;HEAP32[$454+8>>2]=HEAP32[$452+8>>2]|0;HEAP32[$454+12>>2]=HEAP32[$452+12>>2]|0;
         $457 = HEAP32[$9>>2]|0;
         $458 = ($457|0)>(1);
         if ($458) {
          $460 = 1;
          while(1) {
           $$pre$i$i = HEAP32[$planes>>2]|0;
           $459 = (($$pre$i$i) + ($460<<4)|0);
           $461 = (($452) + ($460<<4)|0);
           ;HEAP32[$459+0>>2]=HEAP32[$461+0>>2]|0;HEAP32[$459+4>>2]=HEAP32[$461+4>>2]|0;HEAP32[$459+8>>2]=HEAP32[$461+8>>2]|0;HEAP32[$459+12>>2]=HEAP32[$461+12>>2]|0;
           $462 = (($460) + 1)|0;
           $463 = HEAP32[$9>>2]|0;
           $464 = ($462|0)<($463|0);
           if ($464) {
            $460 = $462;
           } else {
            $$pre$phi265Z2D = $452;
            break;
           }
          }
         } else {
          $493 = $457;
          label = 74;
         }
        } else {
         $493 = $455;
         label = 74;
        }
        if ((label|0) == 74) {
         label = 0;
         $465 = ($452|0)==(0|0);
         if ($465) {
          $467 = $493;
          break;
         }
         $$pre$phi265Z2D = $452;
        }
        __ZN5physx6shdfnd9Allocator10deallocateEPv($6,$$pre$phi265Z2D);
        $$pre$i = HEAP32[$9>>2]|0;
        $467 = $$pre$i;
       } else {
        $467 = $430;
       }
      } while(0);
      $466 = (($467) + 1)|0;
      HEAP32[$9>>2] = $466;
      $468 = HEAP32[$planes>>2]|0;
      $469 = (($468) + ($467<<4)|0);
      ;HEAP32[$469+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$469+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$469+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$469+12>>2]=HEAP32[$7+12>>2]|0;
     }
     $470 = (($i$3211) + 1)|0;
     $exitcond = ($470|0)==($352|0);
     if ($exitcond) {
      break;
     } else {
      $i$3211 = $470;
     }
    }
    $$pre249 = HEAP32[$this>>2]|0;
    $435 = $$pre249;
    label = 65;
   } else {
    $435 = $488;
    label = 65;
   }
  } else {
   $435 = $10;
   label = 65;
  }
 } while(0);
 if ((label|0) == 65) {
  $434 = (($435) + 4|0);
  $436 = HEAP32[$434>>2]|0;
  $437 = ($436|0)>(0);
  if ($437) {
   $472 = $435;$i$4203 = 0;
   while(1) {
    $471 = HEAP32[$472>>2]|0;
    $473 = (($471) + ($i$4203<<2)|0);
    $474 = HEAP32[$473>>2]|0;
    $475 = ($474|0)==(0|0);
    if ($475) {
     $481 = $472;
    } else {
     $476 = (($474) + 24|0);
     $477 = HEAP32[$476>>2]|0;
     $478 = (($471) + ($477<<2)|0);
     HEAP32[$478>>2] = 0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($8,$474);
     $$pre250 = HEAP32[$this>>2]|0;
     $481 = $$pre250;
    }
    $479 = (($i$4203) + 1)|0;
    $480 = (($481) + 4|0);
    $482 = HEAP32[$480>>2]|0;
    $483 = ($479|0)<($482|0);
    if ($483) {
     $472 = $481;$i$4203 = $479;
    } else {
     $$lcssa = $480;
     break;
    }
   }
  } else {
   $$lcssa = $434;
  }
  HEAP32[$$lcssa>>2] = 0;
  $$pre = HEAP32[$bplanes$sroa$0>>2]|0;
  $$0 = 0;$485 = $$pre;
 }
 $484 = ($485|0)==(0|0);
 if ($484) {
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($8,$485);
 HEAP32[$bplanes$sroa$0>>2] = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11HullLibrary9overhullvEPNS_6float3EiiRS2_RiRPiS4_ffif($this,$verts,$verts_count,$maxplanes,$verts_out,$verts_count_out,$faces_out,$faces_count_out,$inflate,$bevangle,$vlimit,$areaEpsilon) {
 $this = $this|0;
 $verts = $verts|0;
 $verts_count = $verts_count|0;
 $maxplanes = $maxplanes|0;
 $verts_out = $verts_out|0;
 $verts_count_out = $verts_count_out|0;
 $faces_out = $faces_out|0;
 $faces_count_out = $faces_count_out|0;
 $inflate = Math_fround($inflate);
 $bevangle = Math_fround($bevangle);
 $vlimit = $vlimit|0;
 $areaEpsilon = Math_fround($areaEpsilon);
 var $$$i = 0, $$$i$1 = 0, $$$i$2 = 0, $$$i$i$i = 0, $$$i$i$i$i$i = 0, $$$i$i$i$i$i$i = 0, $$$i$i$i$i$i45$i = 0, $$$i10$i$i = 0, $$$i23$i$i = 0, $$$i36$i$i = 0, $$$i3654$i$i = 0, $$$i3655$i$i = 0, $$$i3656$i$i = 0, $$$i3658$i$i = 0, $$$i3659$i$i = 0, $$$i3660$i$i = 0, $$$i3662$i$i = 0, $$$i3663$i$i = 0, $$$i366488$i$i = 0, $$0 = 0;
 var $$0$i$i = 0, $$0$i80$i = 0, $$1 = 0, $$idx$i = 0, $$idx$i$i = 0, $$idx$i$i53$i = 0, $$idx$i41$i = 0, $$idx$val$i = Math_fround(0), $$idx$val$i$i = Math_fround(0), $$idx$val$i$i$i = Math_fround(0), $$idx$val$i$pre$i$i = Math_fround(0), $$idx$val$i42$i = Math_fround(0), $$idx1$i$i = 0, $$idx1$val$i$i = Math_fround(0), $$idx10$i$i = 0, $$idx10$val$i57$i = Math_fround(0), $$idx11$i58$i = 0, $$idx11$val$i59$i = Math_fround(0), $$idx12$i$i = 0, $$idx12$val$i$i = Math_fround(0);
 var $$idx13$i$i = 0, $$idx13$val$i$i = Math_fround(0), $$idx14$i$i = 0, $$idx14$val$i$i = Math_fround(0), $$idx15$i$i = 0, $$idx15$val$i$i = Math_fround(0), $$idx16$i$i = 0, $$idx16$val$i$i = Math_fround(0), $$idx17$i$i = 0, $$idx17$val$i$i = Math_fround(0), $$idx18$i$i = 0, $$idx18$val$i$i = Math_fround(0), $$idx19$i$i = 0, $$idx19$val$i$i = Math_fround(0), $$idx2$i$i = 0, $$idx2$i43$i = 0, $$idx2$val$i$i = Math_fround(0), $$idx2$val$i44$i = Math_fround(0), $$idx20$i$i = 0, $$idx20$val$i$i = Math_fround(0);
 var $$idx21$i$i = 0, $$idx21$val$i$i = Math_fround(0), $$idx22$i$i = 0, $$idx22$val$i$i = Math_fround(0), $$idx23$i$i = 0, $$idx23$val$i$i = Math_fround(0), $$idx29$i = 0, $$idx29$val$i = Math_fround(0), $$idx3$i$i = 0, $$idx3$i$i$i = 0, $$idx3$i$i54$i = 0, $$idx3$val$i$i = Math_fround(0), $$idx3$val$i$i$i = Math_fround(0), $$idx3$val$i$pre$i$i = Math_fround(0), $$idx30$i = 0, $$idx30$val$i = Math_fround(0), $$idx31$i = 0, $$idx31$val$i = Math_fround(0), $$idx4$i = 0, $$idx4$i$i$i = 0;
 var $$idx4$i$i55$i = 0, $$idx4$val$i = Math_fround(0), $$idx4$val$i$i$i = Math_fround(0), $$idx4$val$i$pre$i$i = Math_fround(0), $$idx5$i = 0, $$idx5$val$i = Math_fround(0), $$idx9$i$i = 0, $$idx9$val$i$i = Math_fround(0), $$in$i = 0, $$lcssa$i$i = Math_fround(0), $$lcssa13 = 0, $$lcssa26$i$i = Math_fround(0), $$not$i$i = 0, $$not27$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i$pre = 0, $$pre$i7 = 0, $$pre$phi143$i$iZ2D = 0;
 var $$pre$phi145$i$iZ2D = 0, $$pre$phi147$i$iZ2D = 0, $$pre$phi149$i$iZ2D = 0, $$pre$phi151$i$iZ2D = 0, $$pre122$i$i = 0, $$pre134$i$i = Math_fround(0), $$pre141$i$i = 0, $$pre201$i = 0, $$pre85 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = Math_fround(0), $1006 = Math_fround(0);
 var $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = 0, $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0;
 var $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = Math_fround(0), $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = 0, $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0);
 var $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = 0, $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = 0, $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0);
 var $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0;
 var $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = Math_fround(0), $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0;
 var $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0;
 var $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0;
 var $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = Math_fround(0), $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = Math_fround(0), $1150 = 0;
 var $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = Math_fround(0), $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0;
 var $117 = Math_fround(0), $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = Math_fround(0), $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0;
 var $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = Math_fround(0), $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0;
 var $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = Math_fround(0), $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = Math_fround(0), $1220 = 0, $1221 = 0, $1222 = 0;
 var $1223 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0);
 var $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = 0;
 var $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0);
 var $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0);
 var $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0;
 var $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0;
 var $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0;
 var $555 = 0, $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = Math_fround(0), $566 = 0, $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0);
 var $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0);
 var $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0);
 var $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = 0, $619 = Math_fround(0), $62 = 0, $620 = 0, $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0);
 var $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = 0, $642 = 0, $643 = 0, $644 = 0;
 var $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0;
 var $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0;
 var $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0;
 var $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0;
 var $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = Math_fround(0), $722 = 0, $723 = Math_fround(0), $724 = 0, $725 = Math_fround(0), $726 = 0, $727 = Math_fround(0), $728 = 0, $729 = Math_fround(0), $73 = 0, $730 = 0, $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0);
 var $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0);
 var $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = Math_fround(0), $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0);
 var $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0), $782 = 0, $783 = Math_fround(0), $784 = 0, $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0);
 var $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = 0, $806 = 0;
 var $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = Math_fround(0), $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0;
 var $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = Math_fround(0), $840 = 0, $841 = 0, $842 = 0;
 var $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = Math_fround(0), $860 = 0;
 var $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0;
 var $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = Math_fround(0), $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0;
 var $898 = 0, $899 = 0, $9 = 0, $90 = Math_fround(0), $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = Math_fround(0), $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0;
 var $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = Math_fround(0), $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0, $931 = 0, $932 = 0;
 var $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = Math_fround(0), $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = Math_fround(0), $950 = 0;
 var $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = Math_fround(0), $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0;
 var $97 = Math_fround(0), $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0;
 var $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $bmax$bmin$i = 0, $bmax$i = 0, $bmax$idx$promoted$i = Math_fround(0), $bmax$idx$val142$i = Math_fround(0), $bmax$idx6$i = 0, $bmax$idx6$promoted$i = Math_fround(0), $bmax$idx6$val143$i = Math_fround(0);
 var $bmax$idx7$i = 0, $bmax$idx7$promoted$i = Math_fround(0), $bmax$idx7$val144$i = Math_fround(0), $bmin$i = 0, $bmin$idx$promoted$i = Math_fround(0), $bmin$idx$val139$i = Math_fround(0), $bmin$idx2$i = 0, $bmin$idx2$promoted$i = Math_fround(0), $bmin$idx2$val140$i = Math_fround(0), $bmin$idx3$i = 0, $bmin$idx3$promoted$i = Math_fround(0), $bmin$idx3$val141$i = Math_fround(0), $brmerge$i$i = 0, $c$0109$i = 0, $c$0124$i = 0, $convexClipFlags$0105$i$i = 0, $coplanaredge$0$i$i = 0, $coplanaredge$1$i$i = 0, $coplanaredge$2$i$i = 0, $coplanaredges$i$i = 0;
 var $coplanaredges_num$0$lcssa158$i$i = 0, $coplanaredges_num$093$i$i = 0, $coplanaredges_num$1$i$i = 0, $currentplane$089$i$i = 0, $d$0$lcssa$i$i = Math_fround(0), $d$037$i$i = Math_fround(0), $d$1$i$i = Math_fround(0), $dr$0$i$i = Math_fround(0), $e0$090$i$i = 0, $e1$0$i$i = 0, $e1$0$in$i$i = 0, $e1$1$i$i = 0, $edgeflag$i$i = 0, $enextface$0$i$i = 0, $enextface$1$i$i = 0, $estart$0$i$0$i$i = 0, $estart$0$i$i = 0, $estart$2$i$1$i$i = 0, $estart$220$i$i = 0, $exitcond = 0;
 var $exitcond$1 = 0, $exitcond$2 = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i49$i = 0, $exitcond116$i$i = 0, $exitcond117$i$i = 0, $exitcond118$i$i = 0, $exitcond119$i$i = 0, $exitcond155$i = 0, $exitcond183$i = 0, $exitcond184$i = 0, $exitcond191$i = 0, $i$0$i$i = 0, $i$01$i$i = 0, $i$01$i$i$1 = 0, $i$01$i$i$2 = 0, $i$0107$i$i = 0, $i$0135$i = 0, $i$015 = 0;
 var $i$042$i$i = 0, $i$1131$i = 0, $i$119$i$i = 0, $i$179$i$i = 0, $i$2127$i = 0, $i$271$i$i = 0, $i$368$i$i = 0, $i$391$i = 0, $i$4$lcssa$i = 0, $i$466$i$i = 0, $i$487$i = 0, $i1$0$i$i = 0, $i2$0$i$i = 0, $indvars$iv$next = 0, $indvars$iv$next$1 = 0, $inext$0$i$i = 0, $j$0130$i = 0, $j$027$i$i = 0, $j$076$i$i = 0, $j$1$lcssa$i = 0;
 var $j$1$lcssa203$i = 0, $j$134$i$i = 0, $j$184$i = 0, $j$286$i = 0, $k$0$lcssa$i = 0, $k$0$lcssa$i$i = 0, $k$030$i$i = 0, $k$072$i$i = 0, $k$092$i = 0, $k$1$i$i = 0, $k$269$i$i = 0, $md$041$i$i = Math_fround(0), $md$1$i$i = Math_fround(0), $n$i = 0, $n$idx$val$i = Math_fround(0), $n$idx27$val$i = Math_fround(0), $n$idx28$val$i = Math_fround(0), $nea$0$i$i = 0, $nea$0$in$i$i = 0, $nea$1$i$i = 0;
 var $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i56$i = 0, $or$cond1$i$i = 0, $or$cond123$i = 0, $p$044$i$i = 0, $p$1$i$i = 0, $phitmp$i$i = 0, $phitmp114$i$i = 0, $phitmp152$i$i = 0, $planes = 0, $planeside$0$i$i = 0, $tmpunderedges$i$i = 0, $tmpunderplanes$i$i = 0, $ts$sroa$0 = 0, $under_edge_count$0$lcssa159161$i$i = 0, $under_edge_count$092$i$i = 0, $under_edge_count$1$i$i = 0, $under_edge_count$2$i$i = 0;
 var $under_edge_count$3$i$i = 0, $underplanescount$091$i$i = 0, $underplanescount$1$i$i = 0, $underplanescount$2$i$i = 0, $underplanescount$2163$i$i = 0, $vertcountunder$0106$i$i = 0, $vertcountunder$1$i$i = 0, $vertcountunder$2$lcssa156162$i$i = 0, $vertcountunder$294$i$i = 0, $vertcountunder$3$i$i = 0, $vertcountunder$5$i$i = 0, $vertcountunder$7$i$i = 0, $vertcountunder$8$i$i = 0, $vertflag$i$i = 0, $vin$0$i$i = 0, $vin$1$i$i = 0, $vin$2$i$i = 0, $vout$0$i$i = 0, $vout$1$i$i = 0, $vout$2$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 8304|0;
 $0 = sp + 7260|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 7256|0;
 $4 = sp + 7258|0;
 $5 = sp + 7259|0;
 $6 = sp + 7261|0;
 $7 = sp + 7262|0;
 $8 = sp + 7263|0;
 $9 = sp + 7264|0;
 $10 = sp + 8296|0;
 $edgeflag$i$i = sp + 6232|0;
 $vertflag$i$i = sp + 7272|0;
 $tmpunderedges$i$i = sp + 2136|0;
 $tmpunderplanes$i$i = sp + 32|0;
 $coplanaredges$i$i = sp + 4184|0;
 $bmin$i = sp + 2080|0;
 $bmax$i = sp + 2092|0;
 $n$i = sp + 2108|0;
 $11 = sp + 7257|0;
 $planes = sp + 2120|0;
 $ts$sroa$0 = sp + 2104|0;
 $12 = ($verts_count|0)==(0);
 if ($12) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $13 = (($planes) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($planes) + 8|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$planes>>2] = 0;
 $15 = (__ZN5physx11HullLibrary11calchullgenEPNS_6float3Eiif($this,$verts,$verts_count,$vlimit,$areaEpsilon)|0);
 $16 = $15 & -3;
 $17 = ($16|0)==(1);
 do {
  if ($17) {
   $$0 = $15;
  } else {
   $18 = ($15|0)==(2);
   if ($18) {
    (__ZN5physx11HullLibrary10expandhullEPNS_6float3EiRS2_Rif($this,$verts,$verts_count,$verts_out,$verts_count_out,$inflate)|0);
    $19 = HEAP32[$verts_out>>2]|0;
    $20 = HEAP32[$verts_count_out>>2]|0;
    $21 = (__ZN5physx11HullLibrary11calchullgenEPNS_6float3Eiif($this,$19,$20,256,$areaEpsilon)|0);
    $22 = $21 & -3;
    $23 = ($22|0)==(1);
    if ($23) {
     $$0 = $21;
     break;
    }
    HEAP32[$ts$sroa$0>>2] = 0;
    $24 = HEAP32[$this>>2]|0;
    $25 = (($24) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)>(0);
    if ($27) {
     $29 = $24;$35 = 0;$36 = 0;$43 = 0;$i$015 = 0;
     while(1) {
      $28 = HEAP32[$29>>2]|0;
      $30 = (($28) + ($i$015<<2)|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==(0|0);
      if ($32) {
       $1208 = $43;$1209 = $36;$1210 = $35;
      } else {
       $33 = HEAP32[$31>>2]|0;
       $34 = ($35|0)==($36|0);
       do {
        if ($34) {
         $37 = ($35|0)==(0);
         $38 = $35 << 1;
         $$$i = $37 ? 16 : $38;
         $39 = $$$i << 2;
         $40 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$39,534704,153)|0);
         HEAP32[$ts$sroa$0>>2] = $40;
         $41 = ($35|0)>(0);
         if ($41) {
          $i$01$i$i = 0;
          while(1) {
           $42 = (($43) + ($i$01$i$i<<2)|0);
           $44 = HEAP32[$42>>2]|0;
           $45 = (($40) + ($i$01$i$i<<2)|0);
           HEAP32[$45>>2] = $44;
           $46 = (($i$01$i$i) + 1)|0;
           $exitcond = ($46|0)==($35|0);
           if ($exitcond) {
            break;
           } else {
            $i$01$i$i = $46;
           }
          }
         } else {
          $47 = ($43|0)==(0|0);
          if ($47) {
           $$pre = $40;$56 = $$$i;
           break;
          }
         }
         __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$43);
         $$pre = $40;$56 = $$$i;
        } else {
         $$pre = $43;$56 = $36;
        }
       } while(0);
       $indvars$iv$next = (($35) + 1)|0;
       $48 = (($$pre) + ($35<<2)|0);
       HEAP32[$48>>2] = $33;
       $49 = HEAP32[$this>>2]|0;
       $50 = HEAP32[$49>>2]|0;
       $51 = (($50) + ($i$015<<2)|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 4|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = ($indvars$iv$next|0)==($56|0);
       do {
        if ($55) {
         $1167 = ($56|0)==(0);
         $1168 = $56 << 1;
         $$$i$1 = $1167 ? 16 : $1168;
         $1169 = HEAP32[$ts$sroa$0>>2]|0;
         $1170 = $$$i$1 << 2;
         $1171 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$1170,534704,153)|0);
         HEAP32[$ts$sroa$0>>2] = $1171;
         $1172 = ($56|0)>(0);
         if ($1172) {
          $i$01$i$i$1 = 0;
          while(1) {
           $1174 = (($1169) + ($i$01$i$i$1<<2)|0);
           $1175 = HEAP32[$1174>>2]|0;
           $1176 = (($1171) + ($i$01$i$i$1<<2)|0);
           HEAP32[$1176>>2] = $1175;
           $1177 = (($i$01$i$i$1) + 1)|0;
           $exitcond$1 = ($1177|0)==($56|0);
           if ($exitcond$1) {
            break;
           } else {
            $i$01$i$i$1 = $1177;
           }
          }
         } else {
          $1173 = ($1169|0)==(0|0);
          if ($1173) {
           $1179 = $1171;$1187 = $$$i$1;
           break;
          }
         }
         __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$1169);
         $1179 = $1171;$1187 = $$$i$1;
        } else {
         $1179 = $$pre;$1187 = $56;
        }
       } while(0);
       $indvars$iv$next$1 = (($35) + 2)|0;
       $1178 = (($1179) + ($indvars$iv$next<<2)|0);
       HEAP32[$1178>>2] = $54;
       $1180 = HEAP32[$this>>2]|0;
       $1181 = HEAP32[$1180>>2]|0;
       $1182 = (($1181) + ($i$015<<2)|0);
       $1183 = HEAP32[$1182>>2]|0;
       $1184 = (($1183) + 8|0);
       $1185 = HEAP32[$1184>>2]|0;
       $1186 = ($indvars$iv$next$1|0)==($1187|0);
       do {
        if ($1186) {
         $1188 = ($1187|0)==(0);
         $1189 = $1187 << 1;
         $$$i$2 = $1188 ? 16 : $1189;
         $1190 = $$$i$2 << 2;
         $1191 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$1190,534704,153)|0);
         HEAP32[$ts$sroa$0>>2] = $1191;
         $1192 = ($1187|0)>(0);
         if ($1192) {
          $i$01$i$i$2 = 0;
          while(1) {
           $1194 = (($1179) + ($i$01$i$i$2<<2)|0);
           $1195 = HEAP32[$1194>>2]|0;
           $1196 = (($1191) + ($i$01$i$i$2<<2)|0);
           HEAP32[$1196>>2] = $1195;
           $1197 = (($i$01$i$i$2) + 1)|0;
           $exitcond$2 = ($1197|0)==($1187|0);
           if ($exitcond$2) {
            break;
           } else {
            $i$01$i$i$2 = $1197;
           }
          }
         } else {
          $1193 = ($1179|0)==(0|0);
          if ($1193) {
           $1199 = $1191;$1211 = $$$i$2;
           break;
          }
         }
         __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$1179);
         $1199 = $1191;$1211 = $$$i$2;
        } else {
         $1199 = $1179;$1211 = $1187;
        }
       } while(0);
       $1198 = (($1199) + ($indvars$iv$next$1<<2)|0);
       HEAP32[$1198>>2] = $1185;
       $1200 = HEAP32[$this>>2]|0;
       $1201 = HEAP32[$1200>>2]|0;
       $1202 = (($1201) + ($i$015<<2)|0);
       $57 = HEAP32[$1202>>2]|0;
       $1203 = (($35) + 3)|0;
       $1204 = (($57) + 24|0);
       $1205 = HEAP32[$1204>>2]|0;
       $1206 = (($1201) + ($1205<<2)|0);
       HEAP32[$1206>>2] = 0;
       $1207 = ($57|0)==(0|0);
       if ($1207) {
        $1208 = $1199;$1209 = $1211;$1210 = $1203;
       } else {
        __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$57);
        $1208 = $1199;$1209 = $1211;$1210 = $1203;
       }
      }
      $58 = (($i$015) + 1)|0;
      $59 = HEAP32[$this>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)<($61|0);
      if ($62) {
       $29 = $59;$35 = $1210;$36 = $1209;$43 = $1208;$i$015 = $58;
      } else {
       $$lcssa13 = $1210;$64 = $1208;
       break;
      }
     }
    } else {
     $$lcssa13 = 0;$64 = 0;
    }
    $63 = (($$lcssa13|0) / 3)&-1;
    HEAP32[$faces_count_out>>2] = $63;
    HEAP32[$faces_out>>2] = $64;
    HEAP32[$ts$sroa$0>>2] = 0;
    $65 = HEAP32[$this>>2]|0;
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    if (!($67)) {
     __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$66);
     HEAP32[$65>>2] = 0;
    }
    $68 = (($65) + 8|0);
    HEAP32[$68>>2] = 0;
    $$pre$i7 = (($65) + 4|0);
    HEAP32[$$pre$i7>>2] = 0;
    HEAP32[$ts$sroa$0>>2] = 0;
    $$0 = 2;
    break;
   }
   $69 = (__ZN5physx11HullLibrary12calchullpbevEPNS_6float3EiiRNS_12hullLibArray5ArrayINS_5PlaneEEEf($this,$verts,$verts_count,0,$planes,$bevangle)|0);
   $70 = ($69|0)==(1);
   if ($70) {
    $$0 = 1;
   } else {
    $71 = HEAP32[$planes>>2]|0;
    $72 = HEAP32[$13>>2]|0;
    $73 = ($verts_count|0)<(4);
    if ($73) {
     $$0 = 1;
    } else {
     $74 = ($72|0)>($maxplanes|0);
     ;HEAP32[$bmin$i+0>>2]=HEAP32[$verts+0>>2]|0;HEAP32[$bmin$i+4>>2]=HEAP32[$verts+4>>2]|0;HEAP32[$bmin$i+8>>2]=HEAP32[$verts+8>>2]|0;
     ;HEAP32[$bmax$i+0>>2]=HEAP32[$verts+0>>2]|0;HEAP32[$bmax$i+4>>2]=HEAP32[$verts+4>>2]|0;HEAP32[$bmax$i+8>>2]=HEAP32[$verts+8>>2]|0;
     $bmin$idx2$i = (($bmin$i) + 4|0);
     $bmin$idx3$i = (($bmin$i) + 8|0);
     $bmax$idx6$i = (($bmax$i) + 4|0);
     $bmax$idx7$i = (($bmax$i) + 8|0);
     $bmin$idx$promoted$i = Math_fround(HEAPF32[$bmin$i>>2]);
     $bmin$idx2$promoted$i = Math_fround(HEAPF32[$bmin$idx2$i>>2]);
     $bmin$idx3$promoted$i = Math_fround(HEAPF32[$bmin$idx3$i>>2]);
     $bmax$idx$promoted$i = Math_fround(HEAPF32[$bmax$i>>2]);
     $bmax$idx6$promoted$i = Math_fround(HEAPF32[$bmax$idx6$i>>2]);
     $bmax$idx7$promoted$i = Math_fround(HEAPF32[$bmax$idx7$i>>2]);
     $bmax$idx$val142$i = $bmax$idx$promoted$i;$bmax$idx6$val143$i = $bmax$idx6$promoted$i;$bmax$idx7$val144$i = $bmax$idx7$promoted$i;$bmin$idx$val139$i = $bmin$idx$promoted$i;$bmin$idx2$val140$i = $bmin$idx2$promoted$i;$bmin$idx3$val141$i = $bmin$idx3$promoted$i;$i$0135$i = 0;
     while(1) {
      $$idx$i = (($verts) + (($i$0135$i*12)|0)|0);
      $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
      $$idx4$i = ((($verts) + (($i$0135$i*12)|0)|0) + 4|0);
      $$idx4$val$i = Math_fround(HEAPF32[$$idx4$i>>2]);
      $$idx5$i = ((($verts) + (($i$0135$i*12)|0)|0) + 8|0);
      $$idx5$val$i = Math_fround(HEAPF32[$$idx5$i>>2]);
      $75 = $bmin$idx$val139$i < $$idx$val$i;
      $76 = $75 ? $bmin$idx$val139$i : $$idx$val$i;
      $77 = $bmin$idx2$val140$i < $$idx4$val$i;
      $78 = $77 ? $bmin$idx2$val140$i : $$idx4$val$i;
      $79 = $bmin$idx3$val141$i < $$idx5$val$i;
      $80 = $79 ? $bmin$idx3$val141$i : $$idx5$val$i;
      $81 = $bmax$idx$val142$i > $$idx$val$i;
      $82 = $81 ? $bmax$idx$val142$i : $$idx$val$i;
      $83 = $bmax$idx6$val143$i > $$idx4$val$i;
      $84 = $83 ? $bmax$idx6$val143$i : $$idx4$val$i;
      $85 = $bmax$idx7$val144$i > $$idx5$val$i;
      $86 = $85 ? $bmax$idx7$val144$i : $$idx5$val$i;
      $87 = (($i$0135$i) + 1)|0;
      $exitcond191$i = ($87|0)==($verts_count|0);
      if ($exitcond191$i) {
       break;
      } else {
       $bmax$idx$val142$i = $82;$bmax$idx6$val143$i = $84;$bmax$idx7$val144$i = $86;$bmin$idx$val139$i = $76;$bmin$idx2$val140$i = $78;$bmin$idx3$val141$i = $80;$i$0135$i = $87;
      }
     }
     $88 = $74 ? $maxplanes : $72;
     HEAPF32[$bmin$i>>2] = $76;
     HEAPF32[$bmin$idx2$i>>2] = $78;
     HEAPF32[$bmin$idx3$i>>2] = $80;
     HEAPF32[$bmax$i>>2] = $82;
     HEAPF32[$bmax$idx6$i>>2] = $84;
     HEAPF32[$bmax$idx7$i>>2] = $86;
     $89 = Math_fround($82 - $76);
     $90 = Math_fround($84 - $78);
     $91 = Math_fround($86 - $80);
     $92 = Math_fround($89 * $89);
     $93 = Math_fround($90 * $90);
     $94 = Math_fround($92 + $93);
     $95 = Math_fround($91 * $91);
     $96 = Math_fround($94 + $95);
     $97 = (Math_fround(Math_sqrt((Math_fround($96)))));
     $98 = ($72|0)>(0);
     if ($98) {
      $i$1131$i = 0;
      while(1) {
       $99 = ((($71) + ($i$1131$i<<4)|0) + 12|0);
       $100 = Math_fround(HEAPF32[$99>>2]);
       $101 = Math_fround($100 - $inflate);
       HEAPF32[$99>>2] = $101;
       $102 = (($i$1131$i) + 1)|0;
       $exitcond184$i = ($102|0)==($72|0);
       if ($exitcond184$i) {
        break;
       } else {
        $i$1131$i = $102;
       }
      }
     }
     $103 = Math_fround($97 * Math_fround(0.00100000004749745130539));
     HEAPF32[534376>>2] = $103;
     $104 = (($n$i) + 4|0);
     $105 = (($n$i) + 8|0);
     $106 = Math_fround($97 * Math_fround(0.5));
     $j$0130$i = 0;
     while(1) {
      HEAPF32[$n$i>>2] = Math_fround(0.0);
      HEAPF32[$104>>2] = Math_fround(0.0);
      HEAPF32[$105>>2] = Math_fround(0.0);
      $107 = $j$0130$i & 1;
      $108 = ($107|0)!=(0);
      $109 = $108 ? Math_fround(1.0) : Math_fround(-1.0);
      $110 = (($j$0130$i|0) / 2)&-1;
      $111 = (($n$i) + ($110<<2)|0);
      HEAPF32[$111>>2] = $109;
      L57: do {
       if ($98) {
        $n$idx$val$i = Math_fround(HEAPF32[$n$i>>2]);
        $n$idx27$val$i = Math_fround(HEAPF32[$104>>2]);
        $n$idx28$val$i = Math_fround(HEAPF32[$105>>2]);
        $i$2127$i = 0;
        while(1) {
         $$idx29$i = (($71) + ($i$2127$i<<4)|0);
         $$idx29$val$i = Math_fround(HEAPF32[$$idx29$i>>2]);
         $$idx30$i = ((($71) + ($i$2127$i<<4)|0) + 4|0);
         $$idx30$val$i = Math_fround(HEAPF32[$$idx30$i>>2]);
         $$idx31$i = ((($71) + ($i$2127$i<<4)|0) + 8|0);
         $$idx31$val$i = Math_fround(HEAPF32[$$idx31$i>>2]);
         $114 = Math_fround($n$idx$val$i * $$idx29$val$i);
         $115 = Math_fround($n$idx27$val$i * $$idx30$val$i);
         $116 = Math_fround($114 + $115);
         $117 = Math_fround($n$idx28$val$i * $$idx31$val$i);
         $118 = Math_fround($116 + $117);
         $119 = $118 > Math_fround(0.998629510402679443359);
         $113 = (($i$2127$i) + 1)|0;
         if ($119) {
          break;
         }
         $112 = ($113|0)<($72|0);
         if ($112) {
          $i$2127$i = $113;
         } else {
          break L57;
         }
        }
        $bmax$bmin$i = $108 ? $bmax$i : $bmin$i;
        $120 = Math_fround($106 * $n$idx$val$i);
        $121 = Math_fround($106 * $n$idx27$val$i);
        $122 = Math_fround($106 * $n$idx28$val$i);
        $123 = Math_fround(HEAPF32[$bmax$bmin$i>>2]);
        $124 = Math_fround($120 + $123);
        HEAPF32[$bmax$bmin$i>>2] = $124;
        $125 = (($bmax$bmin$i) + 4|0);
        $126 = Math_fround(HEAPF32[$125>>2]);
        $127 = Math_fround($121 + $126);
        HEAPF32[$125>>2] = $127;
        $128 = (($bmax$bmin$i) + 8|0);
        $129 = Math_fround(HEAPF32[$128>>2]);
        $130 = Math_fround($122 + $129);
        HEAPF32[$128>>2] = $130;
       }
      } while(0);
      $131 = (($j$0130$i) + 1)|0;
      $exitcond183$i = ($131|0)==(6);
      if ($exitcond183$i) {
       break;
      } else {
       $j$0130$i = $131;
      }
     }
     $132 = Math_fround(HEAPF32[$bmin$i>>2]);
     $133 = Math_fround(HEAPF32[$bmin$idx2$i>>2]);
     $134 = Math_fround(HEAPF32[$bmin$idx3$i>>2]);
     $135 = Math_fround(HEAPF32[$bmax$i>>2]);
     $136 = Math_fround(HEAPF32[$bmax$idx6$i>>2]);
     $137 = Math_fround(HEAPF32[$bmax$idx7$i>>2]);
     $138 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = (($139) + 8|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = (__Z15PxGetFoundationv()|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = (($143) + 24|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = (FUNCTION_TABLE_ii[$145 & 4095]($142)|0);
     $$$i$i$i$i$i$i = $146 ? 534888 : 534480;
     $147 = (FUNCTION_TABLE_iiiiii[$141 & 255]($138,36,$$$i$i$i$i$i$i,534392,687)|0);
     __ZN5physx7ConvexHC2Eiii($147,8,24,6);
     $148 = HEAP32[$147>>2]|0;
     HEAPF32[$148>>2] = Math_fround(0.0);
     $149 = (($148) + 4|0);
     HEAPF32[$149>>2] = Math_fround(0.0);
     $150 = (($148) + 8|0);
     HEAPF32[$150>>2] = Math_fround(0.0);
     $151 = HEAP32[$147>>2]|0;
     $152 = (($151) + 12|0);
     HEAPF32[$152>>2] = Math_fround(0.0);
     $153 = (($151) + 16|0);
     HEAPF32[$153>>2] = Math_fround(0.0);
     $154 = (($151) + 20|0);
     HEAPF32[$154>>2] = Math_fround(1.0);
     $155 = HEAP32[$147>>2]|0;
     $156 = (($155) + 24|0);
     HEAPF32[$156>>2] = Math_fround(0.0);
     $157 = (($155) + 28|0);
     HEAPF32[$157>>2] = Math_fround(1.0);
     $158 = (($155) + 32|0);
     HEAPF32[$158>>2] = Math_fround(0.0);
     $159 = HEAP32[$147>>2]|0;
     $160 = (($159) + 36|0);
     HEAPF32[$160>>2] = Math_fround(0.0);
     $161 = (($159) + 40|0);
     HEAPF32[$161>>2] = Math_fround(1.0);
     $162 = (($159) + 44|0);
     HEAPF32[$162>>2] = Math_fround(1.0);
     $163 = HEAP32[$147>>2]|0;
     $164 = (($163) + 48|0);
     HEAPF32[$164>>2] = Math_fround(1.0);
     $165 = (($163) + 52|0);
     HEAPF32[$165>>2] = Math_fround(0.0);
     $166 = (($163) + 56|0);
     HEAPF32[$166>>2] = Math_fround(0.0);
     $167 = HEAP32[$147>>2]|0;
     $168 = (($167) + 60|0);
     HEAPF32[$168>>2] = Math_fround(1.0);
     $169 = (($167) + 64|0);
     HEAPF32[$169>>2] = Math_fround(0.0);
     $170 = (($167) + 68|0);
     HEAPF32[$170>>2] = Math_fround(1.0);
     $171 = HEAP32[$147>>2]|0;
     $172 = (($171) + 72|0);
     HEAPF32[$172>>2] = Math_fround(1.0);
     $173 = (($171) + 76|0);
     HEAPF32[$173>>2] = Math_fround(1.0);
     $174 = (($171) + 80|0);
     HEAPF32[$174>>2] = Math_fround(0.0);
     $175 = HEAP32[$147>>2]|0;
     $176 = (($175) + 84|0);
     HEAPF32[$176>>2] = Math_fround(1.0);
     $177 = (($175) + 88|0);
     HEAPF32[$177>>2] = Math_fround(1.0);
     $178 = (($175) + 92|0);
     HEAPF32[$178>>2] = Math_fround(1.0);
     $179 = (($147) + 24|0);
     $180 = HEAP32[$179>>2]|0;
     HEAPF32[$180>>2] = Math_fround(-1.0);
     $181 = (($180) + 4|0);
     HEAPF32[$181>>2] = Math_fround(0.0);
     $182 = (($180) + 8|0);
     HEAPF32[$182>>2] = Math_fround(0.0);
     $183 = (($180) + 12|0);
     HEAPF32[$183>>2] = Math_fround(0.0);
     $184 = HEAP32[$179>>2]|0;
     $185 = (($184) + 16|0);
     HEAPF32[$185>>2] = Math_fround(1.0);
     $186 = (($184) + 20|0);
     HEAPF32[$186>>2] = Math_fround(0.0);
     $187 = (($184) + 24|0);
     HEAPF32[$187>>2] = Math_fround(0.0);
     $188 = (($184) + 28|0);
     HEAPF32[$188>>2] = Math_fround(-1.0);
     $189 = HEAP32[$179>>2]|0;
     $190 = (($189) + 32|0);
     HEAPF32[$190>>2] = Math_fround(0.0);
     $191 = (($189) + 36|0);
     HEAPF32[$191>>2] = Math_fround(-1.0);
     $192 = (($189) + 40|0);
     HEAPF32[$192>>2] = Math_fround(0.0);
     $193 = (($189) + 44|0);
     HEAPF32[$193>>2] = Math_fround(0.0);
     $194 = HEAP32[$179>>2]|0;
     $195 = (($194) + 48|0);
     HEAPF32[$195>>2] = Math_fround(0.0);
     $196 = (($194) + 52|0);
     HEAPF32[$196>>2] = Math_fround(1.0);
     $197 = (($194) + 56|0);
     HEAPF32[$197>>2] = Math_fround(0.0);
     $198 = (($194) + 60|0);
     HEAPF32[$198>>2] = Math_fround(-1.0);
     $199 = HEAP32[$179>>2]|0;
     $200 = (($199) + 64|0);
     HEAPF32[$200>>2] = Math_fround(0.0);
     $201 = (($199) + 68|0);
     HEAPF32[$201>>2] = Math_fround(0.0);
     $202 = (($199) + 72|0);
     HEAPF32[$202>>2] = Math_fround(-1.0);
     $203 = (($199) + 76|0);
     HEAPF32[$203>>2] = Math_fround(0.0);
     $204 = HEAP32[$179>>2]|0;
     $205 = (($204) + 80|0);
     HEAPF32[$205>>2] = Math_fround(0.0);
     $206 = (($204) + 84|0);
     HEAPF32[$206>>2] = Math_fround(0.0);
     $207 = (($204) + 88|0);
     HEAPF32[$207>>2] = Math_fround(1.0);
     $208 = (($204) + 92|0);
     HEAPF32[$208>>2] = Math_fround(-1.0);
     $209 = (($147) + 12|0);
     $210 = HEAP32[$209>>2]|0;
     HEAP16[$210>>1]=11&65535;HEAP16[$210+2>>1]=11>>>16;
     $211 = HEAP32[$209>>2]|0;
     $212 = (($211) + 4|0);
     HEAP16[$212>>1]=65559&65535;HEAP16[$212+2>>1]=65559>>>16;
     $213 = HEAP32[$209>>2]|0;
     $214 = (($213) + 8|0);
     HEAP16[$214>>1]=196623&65535;HEAP16[$214+2>>1]=196623>>>16;
     $215 = HEAP32[$209>>2]|0;
     $216 = (($215) + 12|0);
     HEAP16[$216>>1]=131088&65535;HEAP16[$216+2>>1]=131088>>>16;
     $217 = HEAP32[$209>>2]|0;
     $218 = (($217) + 16|0);
     HEAP16[$218>>1]=17170445&65535;HEAP16[$218+2>>1]=17170445>>>16;
     $219 = HEAP32[$209>>2]|0;
     $220 = (($219) + 20|0);
     HEAP16[$220>>1]=17235989&65535;HEAP16[$220+2>>1]=17235989>>>16;
     $221 = HEAP32[$209>>2]|0;
     $222 = (($221) + 24|0);
     HEAP16[$222>>1]=17104905&65535;HEAP16[$222+2>>1]=17104905>>>16;
     $223 = HEAP32[$209>>2]|0;
     $224 = (($223) + 28|0);
     HEAP16[$224>>1]=17039378&65535;HEAP16[$224+2>>1]=17039378>>>16;
     $225 = HEAP32[$209>>2]|0;
     $226 = (($225) + 32|0);
     HEAP16[$226>>1]=33554451&65535;HEAP16[$226+2>>1]=33554451>>>16;
     $227 = HEAP32[$209>>2]|0;
     $228 = (($227) + 36|0);
     HEAP16[$228>>1]=33816582&65535;HEAP16[$228+2>>1]=33816582>>>16;
     $229 = HEAP32[$209>>2]|0;
     $230 = (($229) + 40|0);
     HEAP16[$230>>1]=33882132&65535;HEAP16[$230+2>>1]=33882132>>>16;
     $231 = HEAP32[$209>>2]|0;
     $232 = (($231) + 44|0);
     HEAP16[$232>>1]=33619968&65535;HEAP16[$232+2>>1]=33619968>>>16;
     $233 = HEAP32[$209>>2]|0;
     $234 = (($233) + 48|0);
     HEAP16[$234>>1]=50528278&65535;HEAP16[$234+2>>1]=50528278>>>16;
     $235 = HEAP32[$209>>2]|0;
     $236 = (($235) + 52|0);
     HEAP16[$236>>1]=50790404&65535;HEAP16[$236+2>>1]=50790404>>>16;
     $237 = HEAP32[$209>>2]|0;
     $238 = (($237) + 56|0);
     HEAP16[$238>>1]=50724881&65535;HEAP16[$238+2>>1]=50724881>>>16;
     $239 = HEAP32[$209>>2]|0;
     $240 = (($239) + 60|0);
     HEAP16[$240>>1]=50462722&65535;HEAP16[$240+2>>1]=50462722>>>16;
     $241 = HEAP32[$209>>2]|0;
     $242 = (($241) + 64|0);
     HEAP16[$242>>1]=67108867&65535;HEAP16[$242+2>>1]=67108867>>>16;
     $243 = HEAP32[$209>>2]|0;
     $244 = (($243) + 68|0);
     HEAP16[$244>>1]=67239950&65535;HEAP16[$244+2>>1]=67239950>>>16;
     $245 = HEAP32[$209>>2]|0;
     $246 = (($245) + 72|0);
     HEAP16[$246>>1]=67502087&65535;HEAP16[$246+2>>1]=67502087>>>16;
     $247 = HEAP32[$209>>2]|0;
     $248 = (($247) + 76|0);
     HEAP16[$248>>1]=67371016&65535;HEAP16[$248+2>>1]=67371016>>>16;
     $249 = HEAP32[$209>>2]|0;
     $250 = (($249) + 80|0);
     HEAP16[$250>>1]=83951626&65535;HEAP16[$250+2>>1]=83951626>>>16;
     $251 = HEAP32[$209>>2]|0;
     $252 = (($251) + 84|0);
     HEAP16[$252>>1]=84213765&65535;HEAP16[$252+2>>1]=84213765>>>16;
     $253 = HEAP32[$209>>2]|0;
     $254 = (($253) + 88|0);
     HEAP16[$254>>1]=84344844&65535;HEAP16[$254+2>>1]=84344844>>>16;
     $255 = HEAP32[$209>>2]|0;
     $256 = (($255) + 92|0);
     HEAP16[$256>>1]=84082689&65535;HEAP16[$256+2>>1]=84082689>>>16;
     $257 = HEAP32[$147>>2]|0;
     HEAPF32[$257>>2] = $132;
     $258 = (($257) + 4|0);
     HEAPF32[$258>>2] = $133;
     $259 = (($257) + 8|0);
     HEAPF32[$259>>2] = $134;
     $260 = HEAP32[$147>>2]|0;
     $261 = (($260) + 12|0);
     HEAPF32[$261>>2] = $132;
     $262 = (($260) + 16|0);
     HEAPF32[$262>>2] = $133;
     $263 = (($260) + 20|0);
     HEAPF32[$263>>2] = $137;
     $264 = HEAP32[$147>>2]|0;
     $265 = (($264) + 24|0);
     HEAPF32[$265>>2] = $132;
     $266 = (($264) + 28|0);
     HEAPF32[$266>>2] = $136;
     $267 = (($264) + 32|0);
     HEAPF32[$267>>2] = $134;
     $268 = HEAP32[$147>>2]|0;
     $269 = (($268) + 36|0);
     HEAPF32[$269>>2] = $132;
     $270 = (($268) + 40|0);
     HEAPF32[$270>>2] = $136;
     $271 = (($268) + 44|0);
     HEAPF32[$271>>2] = $137;
     $272 = HEAP32[$147>>2]|0;
     $273 = (($272) + 48|0);
     HEAPF32[$273>>2] = $135;
     $274 = (($272) + 52|0);
     HEAPF32[$274>>2] = $133;
     $275 = (($272) + 56|0);
     HEAPF32[$275>>2] = $134;
     $276 = HEAP32[$147>>2]|0;
     $277 = (($276) + 60|0);
     HEAPF32[$277>>2] = $135;
     $278 = (($276) + 64|0);
     HEAPF32[$278>>2] = $133;
     $279 = (($276) + 68|0);
     HEAPF32[$279>>2] = $137;
     $280 = HEAP32[$147>>2]|0;
     $281 = (($280) + 72|0);
     HEAPF32[$281>>2] = $135;
     $282 = (($280) + 76|0);
     HEAPF32[$282>>2] = $136;
     $283 = (($280) + 80|0);
     HEAPF32[$283>>2] = $134;
     $284 = HEAP32[$147>>2]|0;
     $285 = (($284) + 84|0);
     HEAPF32[$285>>2] = $135;
     $286 = (($284) + 88|0);
     HEAPF32[$286>>2] = $136;
     $287 = (($284) + 92|0);
     HEAPF32[$287>>2] = $137;
     $288 = HEAP32[$179>>2]|0;
     HEAPF32[$288>>2] = Math_fround(-1.0);
     $289 = (($288) + 4|0);
     HEAPF32[$289>>2] = Math_fround(0.0);
     $290 = (($288) + 8|0);
     HEAPF32[$290>>2] = Math_fround(0.0);
     $291 = (($288) + 12|0);
     HEAPF32[$291>>2] = $132;
     $292 = HEAP32[$179>>2]|0;
     $293 = Math_fround(-$135);
     $294 = (($292) + 16|0);
     HEAPF32[$294>>2] = Math_fround(1.0);
     $295 = (($292) + 20|0);
     HEAPF32[$295>>2] = Math_fround(0.0);
     $296 = (($292) + 24|0);
     HEAPF32[$296>>2] = Math_fround(0.0);
     $297 = (($292) + 28|0);
     HEAPF32[$297>>2] = $293;
     $298 = HEAP32[$179>>2]|0;
     $299 = (($298) + 32|0);
     HEAPF32[$299>>2] = Math_fround(0.0);
     $300 = (($298) + 36|0);
     HEAPF32[$300>>2] = Math_fround(-1.0);
     $301 = (($298) + 40|0);
     HEAPF32[$301>>2] = Math_fround(0.0);
     $302 = (($298) + 44|0);
     HEAPF32[$302>>2] = $133;
     $303 = HEAP32[$179>>2]|0;
     $304 = Math_fround(-$136);
     $305 = (($303) + 48|0);
     HEAPF32[$305>>2] = Math_fround(0.0);
     $306 = (($303) + 52|0);
     HEAPF32[$306>>2] = Math_fround(1.0);
     $307 = (($303) + 56|0);
     HEAPF32[$307>>2] = Math_fround(0.0);
     $308 = (($303) + 60|0);
     HEAPF32[$308>>2] = $304;
     $309 = HEAP32[$179>>2]|0;
     $310 = (($309) + 64|0);
     HEAPF32[$310>>2] = Math_fround(0.0);
     $311 = (($309) + 68|0);
     HEAPF32[$311>>2] = Math_fround(0.0);
     $312 = (($309) + 72|0);
     HEAPF32[$312>>2] = Math_fround(-1.0);
     $313 = (($309) + 76|0);
     HEAPF32[$313>>2] = $134;
     $314 = HEAP32[$179>>2]|0;
     $315 = Math_fround(-$137);
     $316 = (($314) + 80|0);
     HEAPF32[$316>>2] = Math_fround(0.0);
     $317 = (($314) + 84|0);
     HEAPF32[$317>>2] = Math_fround(0.0);
     $318 = (($314) + 88|0);
     HEAPF32[$318>>2] = Math_fround(1.0);
     $319 = (($314) + 92|0);
     HEAPF32[$319>>2] = $315;
     $320 = ($88|0)!=(0);
     $or$cond123$i = $320 & $98;
     L65: do {
      if ($or$cond123$i) {
       $321 = (($tmpunderplanes$i$i) + 2048|0);
       $$in$i = $88;$c$0124$i = $147;
       L67: while(1) {
        $322 = (($c$0124$i) + 4|0);
        $323 = HEAP32[$322>>2]|0;
        $324 = ($323|0)>(0);
        $325 = Math_fround(HEAPF32[534376>>2]);
        $326 = (($c$0124$i) + 28|0);
        $327 = (($c$0124$i) + 24|0);
        $328 = (($c$0124$i) + 16|0);
        $329 = (($c$0124$i) + 12|0);
        $i$042$i$i = 0;$md$041$i$i = Math_fround(0.0);$p$044$i$i = -1;
        while(1) {
         if ($324) {
          $330 = HEAP32[$c$0124$i>>2]|0;
          $$idx21$i$i = (($71) + ($i$042$i$i<<4)|0);
          $$idx21$val$i$i = Math_fround(HEAPF32[$$idx21$i$i>>2]);
          $$idx22$i$i = ((($71) + ($i$042$i$i<<4)|0) + 4|0);
          $$idx22$val$i$i = Math_fround(HEAPF32[$$idx22$i$i>>2]);
          $$idx23$i$i = ((($71) + ($i$042$i$i<<4)|0) + 8|0);
          $$idx23$val$i$i = Math_fround(HEAPF32[$$idx23$i$i>>2]);
          $331 = ((($71) + ($i$042$i$i<<4)|0) + 12|0);
          $332 = Math_fround(HEAPF32[$331>>2]);
          $340 = Math_fround(0.0);$343 = Math_fround(0.0);$j$027$i$i = 0;
          while(1) {
           $$idx18$i$i = (($330) + (($j$027$i$i*12)|0)|0);
           $$idx18$val$i$i = Math_fround(HEAPF32[$$idx18$i$i>>2]);
           $$idx19$i$i = ((($330) + (($j$027$i$i*12)|0)|0) + 4|0);
           $$idx19$val$i$i = Math_fround(HEAPF32[$$idx19$i$i>>2]);
           $$idx20$i$i = ((($330) + (($j$027$i$i*12)|0)|0) + 8|0);
           $$idx20$val$i$i = Math_fround(HEAPF32[$$idx20$i$i>>2]);
           $333 = Math_fround($$idx21$val$i$i * $$idx18$val$i$i);
           $334 = Math_fround($$idx22$val$i$i * $$idx19$val$i$i);
           $335 = Math_fround($333 + $334);
           $336 = Math_fround($$idx23$val$i$i * $$idx20$val$i$i);
           $337 = Math_fround($335 + $336);
           $338 = Math_fround($332 + $337);
           $339 = $340 > $338;
           $341 = $339 ? $340 : $338;
           $342 = $343 < $338;
           $344 = $342 ? $343 : $338;
           $345 = (($j$027$i$i) + 1)|0;
           $exitcond$i = ($345|0)==($323|0);
           if ($exitcond$i) {
            $$lcssa$i$i = $341;$$lcssa26$i$i = $344;
            break;
           } else {
            $340 = $341;$343 = $344;$j$027$i$i = $345;
           }
          }
         } else {
          $$lcssa$i$i = Math_fround(0.0);$$lcssa26$i$i = Math_fround(0.0);
         }
         $346 = Math_fround($$lcssa$i$i - $$lcssa26$i$i);
         $347 = $346 < $325;
         $dr$0$i$i = $347 ? Math_fround(1.0) : $346;
         $348 = Math_fround($$lcssa$i$i / $dr$0$i$i);
         $349 = !($348 <= $md$041$i$i);
         if ($349) {
          $350 = HEAP32[$326>>2]|0;
          $351 = ($350|0)>(0);
          if ($351) {
           $352 = HEAP32[$327>>2]|0;
           $353 = (($71) + ($i$042$i$i<<4)|0);
           $354 = Math_fround(HEAPF32[$353>>2]);
           $355 = ((($71) + ($i$042$i$i<<4)|0) + 4|0);
           $356 = ((($71) + ($i$042$i$i<<4)|0) + 8|0);
           $357 = ((($71) + ($i$042$i$i<<4)|0) + 12|0);
           $358 = Math_fround(HEAPF32[$355>>2]);
           $d$037$i$i = $348;$j$134$i$i = 0;
           while(1) {
            $359 = (($352) + ($j$134$i$i<<4)|0);
            $360 = Math_fround(HEAPF32[$359>>2]);
            $361 = $354 == $360;
            $362 = ((($352) + ($j$134$i$i<<4)|0) + 4|0);
            $363 = Math_fround(HEAPF32[$362>>2]);
            $364 = $358 == $363;
            $or$cond$i = $361 & $364;
            $365 = Math_fround(HEAPF32[$356>>2]);
            $366 = ((($352) + ($j$134$i$i<<4)|0) + 8|0);
            $367 = Math_fround(HEAPF32[$366>>2]);
            $368 = $365 == $367;
            $or$cond = $or$cond$i & $368;
            if ($or$cond) {
             $369 = Math_fround(HEAPF32[$357>>2]);
             $370 = ((($352) + ($j$134$i$i<<4)|0) + 12|0);
             $371 = Math_fround(HEAPF32[$370>>2]);
             $372 = $369 == $371;
             if ($372) {
              $d$1$i$i = Math_fround(0.0);
             } else {
              label = 43;
             }
            } else {
             label = 43;
            }
            L84: do {
             if ((label|0) == 43) {
              label = 0;
              $373 = Math_fround($354 * $360);
              $374 = Math_fround($358 * $363);
              $375 = Math_fround($373 + $374);
              $376 = Math_fround($365 * $367);
              $377 = Math_fround($375 + $376);
              $378 = $377 > Math_fround(0.998629510402679443359);
              if ($378) {
               $379 = HEAP32[$328>>2]|0;
               $380 = ($379|0)>(0);
               if (!($380)) {
                $d$1$i$i = $d$037$i$i;
                break;
               }
               $381 = HEAP32[$329>>2]|0;
               $k$030$i$i = 0;
               while(1) {
                $382 = ((($381) + ($k$030$i$i<<2)|0) + 3|0);
                $383 = HEAP8[$382>>0]|0;
                $384 = $383&255;
                $385 = ($384|0)==($j$134$i$i|0);
                if ($385) {
                 $386 = ((($381) + ($k$030$i$i<<2)|0) + 2|0);
                 $387 = HEAP8[$386>>0]|0;
                 $388 = $387&255;
                 $389 = HEAP32[$c$0124$i>>2]|0;
                 $$idx$i$i = (($389) + (($388*12)|0)|0);
                 $$idx$val$i$i = Math_fround(HEAPF32[$$idx$i$i>>2]);
                 $$idx1$i$i = ((($389) + (($388*12)|0)|0) + 4|0);
                 $$idx1$val$i$i = Math_fround(HEAPF32[$$idx1$i$i>>2]);
                 $$idx2$i$i = ((($389) + (($388*12)|0)|0) + 8|0);
                 $$idx2$val$i$i = Math_fround(HEAPF32[$$idx2$i$i>>2]);
                 $390 = Math_fround($354 * $$idx$val$i$i);
                 $391 = Math_fround($358 * $$idx1$val$i$i);
                 $392 = Math_fround($390 + $391);
                 $393 = Math_fround($365 * $$idx2$val$i$i);
                 $394 = Math_fround($392 + $393);
                 $395 = Math_fround(HEAPF32[$357>>2]);
                 $396 = Math_fround($395 + $394);
                 $397 = $396 < Math_fround(0.0);
                 if ($397) {
                  $d$1$i$i = Math_fround(0.0);
                  break L84;
                 }
                }
                $398 = (($k$030$i$i) + 1)|0;
                $399 = ($398|0)<($379|0);
                if ($399) {
                 $k$030$i$i = $398;
                } else {
                 $d$1$i$i = $d$037$i$i;
                 break;
                }
               }
              } else {
               $d$1$i$i = $d$037$i$i;
              }
             }
            } while(0);
            $400 = (($j$134$i$i) + 1)|0;
            $exitcond155$i = ($400|0)==($350|0);
            if ($exitcond155$i) {
             $d$0$lcssa$i$i = $d$1$i$i;
             break;
            } else {
             $d$037$i$i = $d$1$i$i;$j$134$i$i = $400;
            }
           }
          } else {
           $d$0$lcssa$i$i = $348;
          }
          $401 = $d$0$lcssa$i$i > $md$041$i$i;
          if ($401) {
           $md$1$i$i = $d$0$lcssa$i$i;$p$1$i$i = $i$042$i$i;
          } else {
           $md$1$i$i = $md$041$i$i;$p$1$i$i = $p$044$i$i;
          }
         } else {
          $md$1$i$i = $md$041$i$i;$p$1$i$i = $p$044$i$i;
         }
         $402 = (($i$042$i$i) + 1)|0;
         $exitcond$i$i = ($402|0)==($72|0);
         if ($exitcond$i$i) {
          break;
         } else {
          $i$042$i$i = $402;$md$041$i$i = $md$1$i$i;$p$044$i$i = $p$1$i$i;
         }
        }
        $403 = (($$in$i) + -1)|0;
        $404 = $md$1$i$i > Math_fround(0.00999999977648258209228);
        $405 = $404 ? $p$1$i$i : -1;
        $406 = ($405|0)>(-1);
        if ($406) {
         $407 = $tmpunderplanes$i$i;
        } else {
         $c$0109$i = $c$0124$i;
         break L65;
        }
        while(1) {
         ;HEAP32[$407+0>>2]=0|0;HEAP32[$407+4>>2]=0|0;HEAP32[$407+8>>2]=0|0;HEAP32[$407+12>>2]=0|0;
         $408 = (($407) + 16|0);
         $409 = ($408|0)==($321|0);
         if ($409) {
          break;
         } else {
          $407 = $408;
         }
        }
        $410 = (($71) + ($405<<4)|0);
        $411 = HEAP32[$322>>2]|0;
        $412 = ($411|0)>(0);
        L101: do {
         if ($412) {
          $413 = HEAP32[$c$0124$i>>2]|0;
          $$idx3$i$i$i = ((($71) + ($405<<4)|0) + 4|0);
          $$idx4$i$i$i = ((($71) + ($405<<4)|0) + 8|0);
          $414 = ((($71) + ($405<<4)|0) + 12|0);
          $$idx$val$i$pre$i$i = Math_fround(HEAPF32[$410>>2]);
          $$idx3$val$i$pre$i$i = Math_fround(HEAPF32[$$idx3$i$i$i>>2]);
          $$idx4$val$i$pre$i$i = Math_fround(HEAPF32[$$idx4$i$i$i>>2]);
          $$pre134$i$i = Math_fround(HEAPF32[$414>>2]);
          $415 = Math_fround(-$325);
          $416 = 0;$convexClipFlags$0105$i$i = 0;$i$0107$i$i = 1;$vertcountunder$0106$i$i = 0;
          while(1) {
           $$idx$i41$i = (($413) + (($416*12)|0)|0);
           $$idx$val$i42$i = Math_fround(HEAPF32[$$idx$i41$i>>2]);
           $$idx2$i43$i = ((($413) + (($416*12)|0)|0) + 4|0);
           $$idx2$val$i44$i = Math_fround(HEAPF32[$$idx2$i43$i>>2]);
           $$idx3$i$i = ((($413) + (($416*12)|0)|0) + 8|0);
           $$idx3$val$i$i = Math_fround(HEAPF32[$$idx3$i$i>>2]);
           $417 = Math_fround($$idx$val$i$pre$i$i * $$idx$val$i42$i);
           $418 = Math_fround($$idx3$val$i$pre$i$i * $$idx2$val$i44$i);
           $419 = Math_fround($417 + $418);
           $420 = Math_fround($$idx4$val$i$pre$i$i * $$idx3$val$i$i);
           $421 = Math_fround($419 + $420);
           $422 = Math_fround($$pre134$i$i + $421);
           $423 = $422 > $325;
           do {
            if ($423) {
             $1212 = 2;
             label = 59;
            } else {
             $424 = $422 < $415;
             $425 = $424&1;
             if ((($425|0) == 0)) {
              $1212 = 0;
              label = 59;
              break;
             } else if (!((($425|0) == 1))) {
              $$0$i80$i = 0;
              break L101;
             }
             $428 = (($vertcountunder$0106$i$i) + 1)<<16>>16;
             $429 = $vertcountunder$0106$i$i&255;
             $430 = ((($vertflag$i$i) + ($416<<2)|0) + 2|0);
             HEAP8[$430>>0] = $429;
             $431 = ((($vertflag$i$i) + ($416<<2)|0) + 3|0);
             HEAP8[$431>>0] = -1;
             $433 = 1;$vertcountunder$1$i$i = $428;
            }
           } while(0);
           if ((label|0) == 59) {
            label = 0;
            $426 = ((($vertflag$i$i) + ($416<<2)|0) + 2|0);
            HEAP8[$426>>0] = -1;
            $427 = ((($vertflag$i$i) + ($416<<2)|0) + 3|0);
            HEAP8[$427>>0] = -1;
            $433 = $1212;$vertcountunder$1$i$i = $vertcountunder$0106$i$i;
           }
           $432 = $433&255;
           $434 = (($vertflag$i$i) + ($416<<2)|0);
           HEAP8[$434>>0] = $432;
           $435 = $433 | $convexClipFlags$0105$i$i;
           $436 = $i$0107$i$i&65535;
           $437 = ($436|0)<($411|0);
           $phitmp152$i$i = (($i$0107$i$i) + 1)<<16>>16;
           if ($437) {
            $416 = $436;$convexClipFlags$0105$i$i = $435;$i$0107$i$i = $phitmp152$i$i;$vertcountunder$0106$i$i = $vertcountunder$1$i$i;
           } else {
            break;
           }
          }
          $phitmp$i$i = $435 & 2;
          $phitmp114$i$i = ($phitmp$i$i|0)==(0);
          if ($phitmp114$i$i) {
           label = 64;
          } else {
           $438 = HEAP32[$326>>2]|0;
           $439 = ($438|0)>(0);
           L113: do {
            if ($439) {
             $$$i366488$i$i = 0;$1213 = 0;$1214 = 0;$coplanaredges_num$093$i$i = 0;$currentplane$089$i$i = 0;$e0$090$i$i = 0;$under_edge_count$092$i$i = 0;$underplanescount$091$i$i = 0;$vertcountunder$294$i$i = $vertcountunder$1$i$i;
             while(1) {
              $467 = $underplanescount$091$i$i&255;
              $$$i3663$i$i = $$$i366488$i$i;$528 = $1214;$534 = $1213;$coplanaredge$0$i$i = 255;$e1$0$in$i$i = $e0$090$i$i;$enextface$0$i$i = -1;$planeside$0$i$i = 0;$under_edge_count$1$i$i = $under_edge_count$092$i$i;$vertcountunder$3$i$i = $vertcountunder$294$i$i;$vin$0$i$i = -1;$vout$0$i$i = -1;
              while(1) {
               $e1$0$i$i = (($e1$0$in$i$i) + 1)|0;
               $468 = HEAP32[$328>>2]|0;
               $469 = ($e1$0$i$i|0)<($468|0);
               $470 = HEAP32[$329>>2]|0;
               if ($469) {
                $471 = ((($470) + ($e1$0$i$i<<2)|0) + 3|0);
                $472 = HEAP8[$471>>0]|0;
                $473 = $472&255;
                $474 = ($473|0)==($currentplane$089$i$i|0);
                if ($474) {
                 $e1$1$i$i = $e1$0$i$i;$enextface$1$i$i = $enextface$0$i$i;
                } else {
                 label = 68;
                }
               } else {
                label = 68;
               }
               if ((label|0) == 68) {
                label = 0;
                $e1$1$i$i = $e0$090$i$i;$enextface$1$i$i = $e1$0$i$i;
               }
               $475 = (($470) + ($e1$0$in$i$i<<2)|0);
               $476 = HEAP16[$475>>1]|0;
               $477 = $476 << 16 >> 16;
               $478 = ((($470) + ($e1$0$in$i$i<<2)|0) + 2|0);
               $479 = HEAP8[$478>>0]|0;
               $480 = $479&255;
               $481 = (($vertflag$i$i) + ($480<<2)|0);
               $482 = HEAP8[$481>>0]|0;
               $483 = $482&255;
               $484 = $483 | $planeside$0$i$i;
               $485 = ($482<<24>>24)==(1);
               $486 = ((($470) + ($e1$1$i$i<<2)|0) + 2|0);
               $487 = HEAP8[$486>>0]|0;
               $488 = $487&255;
               $489 = (($vertflag$i$i) + ($488<<2)|0);
               $490 = HEAP8[$489>>0]|0;
               $491 = ($490<<24>>24)==(1);
               do {
                if ($485) {
                 $492 = (($edgeflag$i$i) + ($e1$0$in$i$i<<1)|0);
                 HEAP16[$492>>1] = $under_edge_count$1$i$i;
                 $493 = ((($vertflag$i$i) + ($480<<2)|0) + 2|0);
                 $494 = HEAP8[$493>>0]|0;
                 $495 = $under_edge_count$1$i$i&65535;
                 $496 = ((($tmpunderedges$i$i) + ($495<<2)|0) + 2|0);
                 HEAP8[$496>>0] = $494;
                 $497 = ((($tmpunderedges$i$i) + ($495<<2)|0) + 3|0);
                 HEAP8[$497>>0] = $467;
                 $498 = HEAP16[$475>>1]|0;
                 $499 = $498 << 16 >> 16;
                 $500 = ($499|0)<($e1$0$in$i$i|0);
                 if ($491) {
                  if ($500) {
                   $848 = (($edgeflag$i$i) + ($499<<1)|0);
                   $849 = HEAP16[$848>>1]|0;
                   $850 = (($tmpunderedges$i$i) + ($495<<2)|0);
                   HEAP16[$850>>1] = $849;
                   $851 = HEAP16[$475>>1]|0;
                   $852 = $851 << 16 >> 16;
                   $853 = (($edgeflag$i$i) + ($852<<1)|0);
                   $854 = HEAP16[$853>>1]|0;
                   $855 = $854 << 16 >> 16;
                   $856 = (($tmpunderedges$i$i) + ($855<<2)|0);
                   HEAP16[$856>>1] = $under_edge_count$1$i$i;
                  }
                  $857 = (($under_edge_count$1$i$i) + 1)<<16>>16;
                  $$$i3654$i$i = $$$i3663$i$i;$1218 = $534;$1219 = $528;$coplanaredge$2$i$i = $coplanaredge$0$i$i;$under_edge_count$3$i$i = $857;$vertcountunder$8$i$i = $vertcountunder$3$i$i;$vin$2$i$i = $vin$0$i$i;$vout$2$i$i = $vout$0$i$i;
                  break;
                 }
                 do {
                  if ($500) {
                   $501 = (($edgeflag$i$i) + ($499<<1)|0);
                   $502 = HEAP16[$501>>1]|0;
                   $503 = (($tmpunderedges$i$i) + ($495<<2)|0);
                   HEAP16[$503>>1] = $502;
                   $504 = HEAP16[$475>>1]|0;
                   $505 = $504 << 16 >> 16;
                   $506 = (($edgeflag$i$i) + ($505<<1)|0);
                   $507 = HEAP16[$506>>1]|0;
                   $508 = $507 << 16 >> 16;
                   $509 = (($tmpunderedges$i$i) + ($508<<2)|0);
                   HEAP16[$509>>1] = $under_edge_count$1$i$i;
                   $510 = HEAP16[$475>>1]|0;
                   $511 = $510 << 16 >> 16;
                   $512 = (($edgeflag$i$i) + ($511<<1)|0);
                   $513 = HEAP16[$512>>1]|0;
                   $514 = $513 << 16 >> 16;
                   $515 = ((($tmpunderedges$i$i) + ($514<<2)|0) + 2|0);
                   $516 = HEAP8[$515>>0]|0;
                   $$$i3659$i$i = $$$i3663$i$i;$1216 = $534;$1217 = $528;$vertcountunder$5$i$i = $vertcountunder$3$i$i;$vout$1$i$i = $516;
                  } else {
                   $517 = HEAP8[$486>>0]|0;
                   $518 = $517&255;
                   $519 = (($vertflag$i$i) + ($518<<2)|0);
                   $520 = HEAP8[$519>>0]|0;
                   $521 = ($520<<24>>24)==(0);
                   if (!($521)) {
                    $549 = ((($470) + ($e1$0$in$i$i<<2)|0) + 3|0);
                    $550 = HEAP8[$549>>0]|0;
                    $551 = $550&255;
                    $552 = HEAP32[$327>>2]|0;
                    $553 = ((($470) + ($477<<2)|0) + 3|0);
                    $554 = HEAP8[$553>>0]|0;
                    $555 = $554&255;
                    $556 = (($552) + ($551<<4)|0);
                    $557 = Math_fround(HEAPF32[$556>>2]);
                    $558 = ((($552) + ($551<<4)|0) + 4|0);
                    $559 = Math_fround(HEAPF32[$558>>2]);
                    $560 = ((($552) + ($551<<4)|0) + 8|0);
                    $561 = Math_fround(HEAPF32[$560>>2]);
                    $562 = (($552) + ($555<<4)|0);
                    $563 = Math_fround(HEAPF32[$562>>2]);
                    $564 = ((($552) + ($555<<4)|0) + 4|0);
                    $565 = Math_fround(HEAPF32[$564>>2]);
                    $566 = ((($552) + ($555<<4)|0) + 8|0);
                    $567 = Math_fround(HEAPF32[$566>>2]);
                    $568 = Math_fround(HEAPF32[$410>>2]);
                    $569 = Math_fround(HEAPF32[$$idx3$i$i$i>>2]);
                    $570 = Math_fround(HEAPF32[$$idx4$i$i$i>>2]);
                    $571 = Math_fround($557 * $565);
                    $572 = Math_fround($571 * $570);
                    $573 = Math_fround($559 * $567);
                    $574 = Math_fround($573 * $568);
                    $575 = Math_fround($574 + $572);
                    $576 = Math_fround($561 * $563);
                    $577 = Math_fround($576 * $569);
                    $578 = Math_fround($577 + $575);
                    $579 = Math_fround($557 * $567);
                    $580 = Math_fround($579 * $569);
                    $581 = Math_fround($578 - $580);
                    $582 = Math_fround($559 * $563);
                    $583 = Math_fround($582 * $570);
                    $584 = Math_fround($581 - $583);
                    $585 = Math_fround($561 * $565);
                    $586 = Math_fround($585 * $568);
                    $587 = Math_fround($584 - $586);
                    $588 = Math_fround($565 * $570);
                    $589 = Math_fround($567 * $569);
                    $590 = Math_fround($588 - $589);
                    $591 = Math_fround($590 / $587);
                    $592 = Math_fround($561 * $569);
                    $593 = Math_fround($559 * $570);
                    $594 = Math_fround($592 - $593);
                    $595 = Math_fround($594 / $587);
                    $596 = Math_fround($573 - $585);
                    $597 = Math_fround($596 / $587);
                    $598 = Math_fround($567 * $568);
                    $599 = Math_fround($563 * $570);
                    $600 = Math_fround($598 - $599);
                    $601 = Math_fround($600 / $587);
                    $602 = Math_fround($557 * $570);
                    $603 = Math_fround($561 * $568);
                    $604 = Math_fround($602 - $603);
                    $605 = Math_fround($604 / $587);
                    $606 = Math_fround($576 - $579);
                    $607 = Math_fround($606 / $587);
                    $608 = Math_fround($563 * $569);
                    $609 = Math_fround($565 * $568);
                    $610 = Math_fround($608 - $609);
                    $611 = Math_fround($610 / $587);
                    $612 = Math_fround($559 * $568);
                    $613 = Math_fround($557 * $569);
                    $614 = Math_fround($612 - $613);
                    $615 = Math_fround($614 / $587);
                    $616 = Math_fround($571 - $582);
                    $617 = Math_fround($616 / $587);
                    $618 = ((($552) + ($551<<4)|0) + 12|0);
                    $619 = Math_fround(HEAPF32[$618>>2]);
                    $620 = ((($552) + ($555<<4)|0) + 12|0);
                    $621 = Math_fround(HEAPF32[$620>>2]);
                    $622 = Math_fround(HEAPF32[$414>>2]);
                    $623 = Math_fround(-$619);
                    $624 = Math_fround(-$621);
                    $625 = Math_fround(-$622);
                    $626 = Math_fround($591 * $623);
                    $627 = Math_fround($595 * $624);
                    $628 = Math_fround($626 + $627);
                    $629 = Math_fround($597 * $625);
                    $630 = Math_fround($628 + $629);
                    $631 = Math_fround($601 * $623);
                    $632 = Math_fround($605 * $624);
                    $633 = Math_fround($631 + $632);
                    $634 = Math_fround($607 * $625);
                    $635 = Math_fround($633 + $634);
                    $636 = Math_fround($611 * $623);
                    $637 = Math_fround($615 * $624);
                    $638 = Math_fround($636 + $637);
                    $639 = Math_fround($617 * $625);
                    $640 = Math_fround($638 + $639);
                    $641 = ($528|0)==($$$i3663$i$i|0);
                    do {
                     if ($641) {
                      $642 = ($$$i3663$i$i|0)==(0);
                      $643 = $$$i3663$i$i << 1;
                      $$$i36$i$i = $642 ? 16 : $643;
                      $644 = ($$$i36$i$i*12)|0;
                      $645 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$644,534704,153)|0);
                      $646 = ($$$i3663$i$i|0)>(0);
                      do {
                       if ($646) {
                        ;HEAP32[$645+0>>2]=HEAP32[$534+0>>2]|0;HEAP32[$645+4>>2]=HEAP32[$534+4>>2]|0;HEAP32[$645+8>>2]=HEAP32[$534+8>>2]|0;
                        $647 = ($$$i3663$i$i|0)>(1);
                        if ($647) {
                         $649 = 1;
                        } else {
                         label = 87;
                         break;
                        }
                        while(1) {
                         $648 = (($645) + (($649*12)|0)|0);
                         $650 = (($534) + (($649*12)|0)|0);
                         ;HEAP32[$648+0>>2]=HEAP32[$650+0>>2]|0;HEAP32[$648+4>>2]=HEAP32[$650+4>>2]|0;HEAP32[$648+8>>2]=HEAP32[$650+8>>2]|0;
                         $651 = (($649) + 1)|0;
                         $exitcond116$i$i = ($651|0)==($$$i3663$i$i|0);
                         if ($exitcond116$i$i) {
                          $$pre$phi151$i$iZ2D = $534;
                          break;
                         } else {
                          $649 = $651;
                         }
                        }
                       } else {
                        label = 87;
                       }
                      } while(0);
                      if ((label|0) == 87) {
                       label = 0;
                       $652 = ($534|0)==(0|0);
                       if ($652) {
                        $$$i3660$i$i = $$$i36$i$i;$655 = $645;
                        break;
                       }
                       $$pre$phi151$i$iZ2D = $534;
                      }
                      __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$$pre$phi151$i$iZ2D);
                      $$$i3660$i$i = $$$i36$i$i;$655 = $645;
                     } else {
                      $$$i3660$i$i = $$$i3663$i$i;$655 = $534;
                     }
                    } while(0);
                    $653 = (($528) + 1)|0;
                    $654 = (($655) + (($528*12)|0)|0);
                    HEAPF32[$654>>2] = $630;
                    $656 = ((($655) + (($528*12)|0)|0) + 4|0);
                    HEAPF32[$656>>2] = $635;
                    $657 = ((($655) + (($528*12)|0)|0) + 8|0);
                    HEAPF32[$657>>2] = $640;
                    $658 = (($vertcountunder$3$i$i) + 1)<<16>>16;
                    $659 = $vertcountunder$3$i$i&255;
                    $$$i3659$i$i = $$$i3660$i$i;$1216 = $655;$1217 = $653;$vertcountunder$5$i$i = $658;$vout$1$i$i = $659;
                    break;
                   }
                   $522 = ((($vertflag$i$i) + ($518<<2)|0) + 2|0);
                   $523 = HEAP8[$522>>0]|0;
                   $524 = ($523<<24>>24)==(-1);
                   if (!($524)) {
                    $$$i3659$i$i = $$$i3663$i$i;$1216 = $534;$1217 = $528;$vertcountunder$5$i$i = $vertcountunder$3$i$i;$vout$1$i$i = $523;
                    break;
                   }
                   $525 = HEAP32[$c$0124$i>>2]|0;
                   $526 = (($525) + (($518*12)|0)|0);
                   ;HEAP32[$2+0>>2]=HEAP32[$526+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$526+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$526+8>>2]|0;
                   $527 = ($528|0)==($$$i3663$i$i|0);
                   do {
                    if ($527) {
                     $529 = ($$$i3663$i$i|0)==(0);
                     $530 = $$$i3663$i$i << 1;
                     $$$i10$i$i = $529 ? 16 : $530;
                     $531 = ($$$i10$i$i*12)|0;
                     $532 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($6,$531,534704,153)|0);
                     $533 = ($$$i3663$i$i|0)>(0);
                     do {
                      if ($533) {
                       ;HEAP32[$532+0>>2]=HEAP32[$534+0>>2]|0;HEAP32[$532+4>>2]=HEAP32[$534+4>>2]|0;HEAP32[$532+8>>2]=HEAP32[$534+8>>2]|0;
                       $535 = ($$$i3663$i$i|0)>(1);
                       if ($535) {
                        $537 = 1;
                       } else {
                        label = 79;
                        break;
                       }
                       while(1) {
                        $536 = (($532) + (($537*12)|0)|0);
                        $538 = (($534) + (($537*12)|0)|0);
                        ;HEAP32[$536+0>>2]=HEAP32[$538+0>>2]|0;HEAP32[$536+4>>2]=HEAP32[$538+4>>2]|0;HEAP32[$536+8>>2]=HEAP32[$538+8>>2]|0;
                        $539 = (($537) + 1)|0;
                        $exitcond117$i$i = ($539|0)==($$$i3663$i$i|0);
                        if ($exitcond117$i$i) {
                         $$pre$phi149$i$iZ2D = $534;
                         break;
                        } else {
                         $537 = $539;
                        }
                       }
                      } else {
                       label = 79;
                      }
                     } while(0);
                     if ((label|0) == 79) {
                      label = 0;
                      $540 = ($534|0)==(0|0);
                      if ($540) {
                       $$$i3662$i$i = $$$i10$i$i;$543 = $532;
                       break;
                      }
                      $$pre$phi149$i$iZ2D = $534;
                     }
                     __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$$pre$phi149$i$iZ2D);
                     $$$i3662$i$i = $$$i10$i$i;$543 = $532;
                    } else {
                     $$$i3662$i$i = $$$i3663$i$i;$543 = $534;
                    }
                   } while(0);
                   $541 = (($528) + 1)|0;
                   $542 = (($543) + (($528*12)|0)|0);
                   ;HEAP32[$542+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$542+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$542+8>>2]=HEAP32[$2+8>>2]|0;
                   $544 = (($vertcountunder$3$i$i) + 1)<<16>>16;
                   $545 = $vertcountunder$3$i$i&255;
                   $546 = HEAP8[$486>>0]|0;
                   $547 = $546&255;
                   $548 = ((($vertflag$i$i) + ($547<<2)|0) + 2|0);
                   HEAP8[$548>>0] = $545;
                   $$$i3659$i$i = $$$i3662$i$i;$1216 = $543;$1217 = $541;$vertcountunder$5$i$i = $544;$vout$1$i$i = $545;
                  }
                 } while(0);
                 $660 = (($under_edge_count$1$i$i) + 1)<<16>>16;
                 $661 = ($vin$0$i$i<<24>>24)==(-1);
                 $662 = ($vin$0$i$i<<24>>24)==($vout$1$i$i<<24>>24);
                 $or$cond$i$i = $661 | $662;
                 if ($or$cond$i$i) {
                  $$$i3654$i$i = $$$i3659$i$i;$1218 = $1216;$1219 = $1217;$coplanaredge$2$i$i = $coplanaredge$0$i$i;$under_edge_count$3$i$i = $660;$vertcountunder$8$i$i = $vertcountunder$5$i$i;$vin$2$i$i = $vin$0$i$i;$vout$2$i$i = $vout$1$i$i;
                  break;
                 }
                 $663 = $660&65535;
                 $664 = ((($tmpunderedges$i$i) + ($663<<2)|0) + 2|0);
                 HEAP8[$664>>0] = $vout$1$i$i;
                 $665 = ((($tmpunderedges$i$i) + ($663<<2)|0) + 3|0);
                 HEAP8[$665>>0] = $467;
                 $666 = (($tmpunderedges$i$i) + ($663<<2)|0);
                 HEAP16[$666>>1] = 255;
                 $667 = (($under_edge_count$1$i$i) + 2)<<16>>16;
                 $$$i3654$i$i = $$$i3659$i$i;$1218 = $1216;$1219 = $1217;$coplanaredge$2$i$i = $663;$under_edge_count$3$i$i = $667;$vertcountunder$8$i$i = $vertcountunder$5$i$i;$vin$2$i$i = $vin$0$i$i;$vout$2$i$i = $vout$1$i$i;
                } else {
                 if (!($491)) {
                  $$$i3654$i$i = $$$i3663$i$i;$1218 = $534;$1219 = $528;$coplanaredge$2$i$i = $coplanaredge$0$i$i;$under_edge_count$3$i$i = $under_edge_count$1$i$i;$vertcountunder$8$i$i = $vertcountunder$3$i$i;$vin$2$i$i = $vin$0$i$i;$vout$2$i$i = $vout$0$i$i;
                  break;
                 }
                 $668 = ($477|0)<($e1$0$in$i$i|0);
                 do {
                  if ($668) {
                   $669 = (($edgeflag$i$i) + ($477<<1)|0);
                   $670 = HEAP16[$669>>1]|0;
                   $671 = $670 << 16 >> 16;
                   $672 = (($671) + 1)|0;
                   $673 = ((($tmpunderedges$i$i) + ($671<<2)|0) + 3|0);
                   $674 = HEAP8[$673>>0]|0;
                   $675 = $under_edge_count$1$i$i&65535;
                   $676 = ($672|0)<($675|0);
                   if ($676) {
                    $677 = ((($tmpunderedges$i$i) + ($672<<2)|0) + 3|0);
                    $678 = HEAP8[$677>>0]|0;
                    $679 = ($678<<24>>24)==($674<<24>>24);
                    if ($679) {
                     $nea$1$i$i = $672;
                    } else {
                     $nea$0$in$i$i = $671;
                     label = 97;
                    }
                   } else {
                    $nea$0$in$i$i = $671;
                    label = 97;
                   }
                   L130: do {
                    if ((label|0) == 97) {
                     while(1) {
                      label = 0;
                      $nea$0$i$i = (($nea$0$in$i$i) + -1)|0;
                      $680 = ($nea$0$i$i|0)>(0);
                      if (!($680)) {
                       $nea$1$i$i = $nea$0$i$i;
                       break L130;
                      }
                      $681 = (($nea$0$in$i$i) + -2)|0;
                      $682 = ((($tmpunderedges$i$i) + ($681<<2)|0) + 3|0);
                      $683 = HEAP8[$682>>0]|0;
                      $684 = ($683<<24>>24)==($674<<24>>24);
                      if ($684) {
                       $nea$0$in$i$i = $nea$0$i$i;
                       label = 97;
                      } else {
                       $nea$1$i$i = $nea$0$i$i;
                       break;
                      }
                     }
                    }
                   } while(0);
                   $685 = ((($tmpunderedges$i$i) + ($nea$1$i$i<<2)|0) + 2|0);
                   $686 = HEAP8[$685>>0]|0;
                   $$$i3655$i$i = $$$i3663$i$i;$1220 = $534;$1221 = $528;$vertcountunder$7$i$i = $vertcountunder$3$i$i;$vin$1$i$i = $686;
                  } else {
                   $687 = ($482<<24>>24)==(0);
                   if (!($687)) {
                    $713 = ((($470) + ($e1$0$in$i$i<<2)|0) + 3|0);
                    $714 = HEAP8[$713>>0]|0;
                    $715 = $714&255;
                    $716 = HEAP32[$327>>2]|0;
                    $717 = ((($470) + ($477<<2)|0) + 3|0);
                    $718 = HEAP8[$717>>0]|0;
                    $719 = $718&255;
                    $720 = (($716) + ($715<<4)|0);
                    $721 = Math_fround(HEAPF32[$720>>2]);
                    $722 = ((($716) + ($715<<4)|0) + 4|0);
                    $723 = Math_fround(HEAPF32[$722>>2]);
                    $724 = ((($716) + ($715<<4)|0) + 8|0);
                    $725 = Math_fround(HEAPF32[$724>>2]);
                    $726 = (($716) + ($719<<4)|0);
                    $727 = Math_fround(HEAPF32[$726>>2]);
                    $728 = ((($716) + ($719<<4)|0) + 4|0);
                    $729 = Math_fround(HEAPF32[$728>>2]);
                    $730 = ((($716) + ($719<<4)|0) + 8|0);
                    $731 = Math_fround(HEAPF32[$730>>2]);
                    $732 = Math_fround(HEAPF32[$410>>2]);
                    $733 = Math_fround(HEAPF32[$$idx3$i$i$i>>2]);
                    $734 = Math_fround(HEAPF32[$$idx4$i$i$i>>2]);
                    $735 = Math_fround($721 * $729);
                    $736 = Math_fround($735 * $734);
                    $737 = Math_fround($723 * $731);
                    $738 = Math_fround($737 * $732);
                    $739 = Math_fround($738 + $736);
                    $740 = Math_fround($725 * $727);
                    $741 = Math_fround($740 * $733);
                    $742 = Math_fround($741 + $739);
                    $743 = Math_fround($721 * $731);
                    $744 = Math_fround($743 * $733);
                    $745 = Math_fround($742 - $744);
                    $746 = Math_fround($723 * $727);
                    $747 = Math_fround($746 * $734);
                    $748 = Math_fround($745 - $747);
                    $749 = Math_fround($725 * $729);
                    $750 = Math_fround($749 * $732);
                    $751 = Math_fround($748 - $750);
                    $752 = Math_fround($729 * $734);
                    $753 = Math_fround($731 * $733);
                    $754 = Math_fround($752 - $753);
                    $755 = Math_fround($754 / $751);
                    $756 = Math_fround($725 * $733);
                    $757 = Math_fround($723 * $734);
                    $758 = Math_fround($756 - $757);
                    $759 = Math_fround($758 / $751);
                    $760 = Math_fround($737 - $749);
                    $761 = Math_fround($760 / $751);
                    $762 = Math_fround($731 * $732);
                    $763 = Math_fround($727 * $734);
                    $764 = Math_fround($762 - $763);
                    $765 = Math_fround($764 / $751);
                    $766 = Math_fround($721 * $734);
                    $767 = Math_fround($725 * $732);
                    $768 = Math_fround($766 - $767);
                    $769 = Math_fround($768 / $751);
                    $770 = Math_fround($740 - $743);
                    $771 = Math_fround($770 / $751);
                    $772 = Math_fround($727 * $733);
                    $773 = Math_fround($729 * $732);
                    $774 = Math_fround($772 - $773);
                    $775 = Math_fround($774 / $751);
                    $776 = Math_fround($723 * $732);
                    $777 = Math_fround($721 * $733);
                    $778 = Math_fround($776 - $777);
                    $779 = Math_fround($778 / $751);
                    $780 = Math_fround($735 - $746);
                    $781 = Math_fround($780 / $751);
                    $782 = ((($716) + ($715<<4)|0) + 12|0);
                    $783 = Math_fround(HEAPF32[$782>>2]);
                    $784 = ((($716) + ($719<<4)|0) + 12|0);
                    $785 = Math_fround(HEAPF32[$784>>2]);
                    $786 = Math_fround(HEAPF32[$414>>2]);
                    $787 = Math_fround(-$783);
                    $788 = Math_fround(-$785);
                    $789 = Math_fround(-$786);
                    $790 = Math_fround($755 * $787);
                    $791 = Math_fround($759 * $788);
                    $792 = Math_fround($790 + $791);
                    $793 = Math_fround($761 * $789);
                    $794 = Math_fround($792 + $793);
                    $795 = Math_fround($765 * $787);
                    $796 = Math_fround($769 * $788);
                    $797 = Math_fround($795 + $796);
                    $798 = Math_fround($771 * $789);
                    $799 = Math_fround($797 + $798);
                    $800 = Math_fround($775 * $787);
                    $801 = Math_fround($779 * $788);
                    $802 = Math_fround($800 + $801);
                    $803 = Math_fround($781 * $789);
                    $804 = Math_fround($802 + $803);
                    $805 = ($528|0)==($$$i3663$i$i|0);
                    do {
                     if ($805) {
                      $806 = ($$$i3663$i$i|0)==(0);
                      $807 = $$$i3663$i$i << 1;
                      $$$i$i$i = $806 ? 16 : $807;
                      $808 = ($$$i$i$i*12)|0;
                      $809 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($8,$808,534704,153)|0);
                      $810 = ($$$i3663$i$i|0)>(0);
                      do {
                       if ($810) {
                        ;HEAP32[$809+0>>2]=HEAP32[$534+0>>2]|0;HEAP32[$809+4>>2]=HEAP32[$534+4>>2]|0;HEAP32[$809+8>>2]=HEAP32[$534+8>>2]|0;
                        $811 = ($$$i3663$i$i|0)>(1);
                        if ($811) {
                         $813 = 1;
                        } else {
                         label = 114;
                         break;
                        }
                        while(1) {
                         $812 = (($809) + (($813*12)|0)|0);
                         $814 = (($534) + (($813*12)|0)|0);
                         ;HEAP32[$812+0>>2]=HEAP32[$814+0>>2]|0;HEAP32[$812+4>>2]=HEAP32[$814+4>>2]|0;HEAP32[$812+8>>2]=HEAP32[$814+8>>2]|0;
                         $815 = (($813) + 1)|0;
                         $exitcond118$i$i = ($815|0)==($$$i3663$i$i|0);
                         if ($exitcond118$i$i) {
                          $$pre$phi147$i$iZ2D = $534;
                          break;
                         } else {
                          $813 = $815;
                         }
                        }
                       } else {
                        label = 114;
                       }
                      } while(0);
                      if ((label|0) == 114) {
                       label = 0;
                       $816 = ($534|0)==(0|0);
                       if ($816) {
                        $$$i3656$i$i = $$$i$i$i;$819 = $809;
                        break;
                       }
                       $$pre$phi147$i$iZ2D = $534;
                      }
                      __ZN5physx6shdfnd9Allocator10deallocateEPv($9,$$pre$phi147$i$iZ2D);
                      $$$i3656$i$i = $$$i$i$i;$819 = $809;
                     } else {
                      $$$i3656$i$i = $$$i3663$i$i;$819 = $534;
                     }
                    } while(0);
                    $817 = (($528) + 1)|0;
                    $818 = (($819) + (($528*12)|0)|0);
                    HEAPF32[$818>>2] = $794;
                    $820 = ((($819) + (($528*12)|0)|0) + 4|0);
                    HEAPF32[$820>>2] = $799;
                    $821 = ((($819) + (($528*12)|0)|0) + 8|0);
                    HEAPF32[$821>>2] = $804;
                    $822 = (($vertcountunder$3$i$i) + 1)<<16>>16;
                    $823 = $vertcountunder$3$i$i&255;
                    $$$i3655$i$i = $$$i3656$i$i;$1220 = $819;$1221 = $817;$vertcountunder$7$i$i = $822;$vin$1$i$i = $823;
                    break;
                   }
                   $688 = ((($vertflag$i$i) + ($480<<2)|0) + 2|0);
                   $689 = HEAP8[$688>>0]|0;
                   $690 = ($689<<24>>24)==(-1);
                   if (!($690)) {
                    $$$i3655$i$i = $$$i3663$i$i;$1220 = $534;$1221 = $528;$vertcountunder$7$i$i = $vertcountunder$3$i$i;$vin$1$i$i = $689;
                    break;
                   }
                   $691 = HEAP32[$c$0124$i>>2]|0;
                   $692 = (($691) + (($480*12)|0)|0);
                   ;HEAP32[$1+0>>2]=HEAP32[$692+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$692+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$692+8>>2]|0;
                   $693 = ($528|0)==($$$i3663$i$i|0);
                   do {
                    if ($693) {
                     $694 = ($$$i3663$i$i|0)==(0);
                     $695 = $$$i3663$i$i << 1;
                     $$$i23$i$i = $694 ? 16 : $695;
                     $696 = ($$$i23$i$i*12)|0;
                     $697 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$696,534704,153)|0);
                     $698 = ($$$i3663$i$i|0)>(0);
                     do {
                      if ($698) {
                       ;HEAP32[$697+0>>2]=HEAP32[$534+0>>2]|0;HEAP32[$697+4>>2]=HEAP32[$534+4>>2]|0;HEAP32[$697+8>>2]=HEAP32[$534+8>>2]|0;
                       $699 = ($$$i3663$i$i|0)>(1);
                       if ($699) {
                        $701 = 1;
                       } else {
                        label = 106;
                        break;
                       }
                       while(1) {
                        $700 = (($697) + (($701*12)|0)|0);
                        $702 = (($534) + (($701*12)|0)|0);
                        ;HEAP32[$700+0>>2]=HEAP32[$702+0>>2]|0;HEAP32[$700+4>>2]=HEAP32[$702+4>>2]|0;HEAP32[$700+8>>2]=HEAP32[$702+8>>2]|0;
                        $703 = (($701) + 1)|0;
                        $exitcond119$i$i = ($703|0)==($$$i3663$i$i|0);
                        if ($exitcond119$i$i) {
                         $$pre$phi145$i$iZ2D = $534;
                         break;
                        } else {
                         $701 = $703;
                        }
                       }
                      } else {
                       label = 106;
                      }
                     } while(0);
                     if ((label|0) == 106) {
                      label = 0;
                      $704 = ($534|0)==(0|0);
                      if ($704) {
                       $$$i3658$i$i = $$$i23$i$i;$707 = $697;
                       break;
                      }
                      $$pre$phi145$i$iZ2D = $534;
                     }
                     __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$$pre$phi145$i$iZ2D);
                     $$$i3658$i$i = $$$i23$i$i;$707 = $697;
                    } else {
                     $$$i3658$i$i = $$$i3663$i$i;$707 = $534;
                    }
                   } while(0);
                   $705 = (($528) + 1)|0;
                   $706 = (($707) + (($528*12)|0)|0);
                   ;HEAP32[$706+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$706+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$706+8>>2]=HEAP32[$1+8>>2]|0;
                   $708 = (($vertcountunder$3$i$i) + 1)<<16>>16;
                   $709 = $vertcountunder$3$i$i&255;
                   $710 = HEAP8[$478>>0]|0;
                   $711 = $710&255;
                   $712 = ((($vertflag$i$i) + ($711<<2)|0) + 2|0);
                   HEAP8[$712>>0] = $709;
                   $$$i3655$i$i = $$$i3658$i$i;$1220 = $707;$1221 = $705;$vertcountunder$7$i$i = $708;$vin$1$i$i = $709;
                  }
                 } while(0);
                 $824 = ($vout$0$i$i<<24>>24)==(-1);
                 $825 = ($vin$1$i$i<<24>>24)==($vout$0$i$i<<24>>24);
                 $or$cond1$i$i = $824 | $825;
                 if ($or$cond1$i$i) {
                  $coplanaredge$1$i$i = $coplanaredge$0$i$i;$under_edge_count$2$i$i = $under_edge_count$1$i$i;
                 } else {
                  $826 = $under_edge_count$1$i$i&65535;
                  $827 = ((($tmpunderedges$i$i) + ($826<<2)|0) + 2|0);
                  HEAP8[$827>>0] = $vout$0$i$i;
                  $828 = ((($tmpunderedges$i$i) + ($826<<2)|0) + 3|0);
                  HEAP8[$828>>0] = $467;
                  $829 = (($tmpunderedges$i$i) + ($826<<2)|0);
                  HEAP16[$829>>1] = 255;
                  $830 = (($under_edge_count$1$i$i) + 1)<<16>>16;
                  $coplanaredge$1$i$i = $826;$under_edge_count$2$i$i = $830;
                 }
                 $831 = $under_edge_count$2$i$i&65535;
                 $832 = ((($tmpunderedges$i$i) + ($831<<2)|0) + 2|0);
                 HEAP8[$832>>0] = $vin$1$i$i;
                 $833 = ((($tmpunderedges$i$i) + ($831<<2)|0) + 3|0);
                 HEAP8[$833>>0] = $467;
                 $834 = (($edgeflag$i$i) + ($e1$0$in$i$i<<1)|0);
                 HEAP16[$834>>1] = $under_edge_count$2$i$i;
                 $835 = HEAP16[$475>>1]|0;
                 $836 = $835 << 16 >> 16;
                 $837 = ($836|0)<($e1$0$in$i$i|0);
                 if ($837) {
                  $838 = (($edgeflag$i$i) + ($836<<1)|0);
                  $839 = HEAP16[$838>>1]|0;
                  $840 = (($tmpunderedges$i$i) + ($831<<2)|0);
                  HEAP16[$840>>1] = $839;
                  $841 = HEAP16[$475>>1]|0;
                  $842 = $841 << 16 >> 16;
                  $843 = (($edgeflag$i$i) + ($842<<1)|0);
                  $844 = HEAP16[$843>>1]|0;
                  $845 = $844 << 16 >> 16;
                  $846 = (($tmpunderedges$i$i) + ($845<<2)|0);
                  HEAP16[$846>>1] = $under_edge_count$2$i$i;
                 }
                 $847 = (($under_edge_count$2$i$i) + 1)<<16>>16;
                 $$$i3654$i$i = $$$i3655$i$i;$1218 = $1220;$1219 = $1221;$coplanaredge$2$i$i = $coplanaredge$1$i$i;$under_edge_count$3$i$i = $847;$vertcountunder$8$i$i = $vertcountunder$7$i$i;$vin$2$i$i = $vin$1$i$i;$vout$2$i$i = $vout$0$i$i;
                }
               } while(0);
               $858 = ($e1$1$i$i|0)==($e0$090$i$i|0);
               if ($858) {
                break;
               } else {
                $$$i3663$i$i = $$$i3654$i$i;$528 = $1219;$534 = $1218;$coplanaredge$0$i$i = $coplanaredge$2$i$i;$e1$0$in$i$i = $e1$1$i$i;$enextface$0$i$i = $enextface$1$i$i;$planeside$0$i$i = $484;$under_edge_count$1$i$i = $under_edge_count$3$i$i;$vertcountunder$3$i$i = $vertcountunder$8$i$i;$vin$0$i$i = $vin$2$i$i;$vout$0$i$i = $vout$2$i$i;
               }
              }
              $859 = $484 & 1;
              $860 = ($859|0)==(0);
              if ($860) {
               $underplanescount$1$i$i = $underplanescount$091$i$i;
              } else {
               $861 = $underplanescount$091$i$i&65535;
               $862 = (($tmpunderplanes$i$i) + ($861<<4)|0);
               $863 = HEAP32[$327>>2]|0;
               $864 = (($863) + ($currentplane$089$i$i<<4)|0);
               ;HEAP32[$862+0>>2]=HEAP32[$864+0>>2]|0;HEAP32[$862+4>>2]=HEAP32[$864+4>>2]|0;HEAP32[$862+8>>2]=HEAP32[$864+8>>2]|0;HEAP32[$862+12>>2]=HEAP32[$864+12>>2]|0;
               $865 = (($underplanescount$091$i$i) + 1)<<16>>16;
               $underplanescount$1$i$i = $865;
              }
              $866 = ($coplanaredge$2$i$i|0)==(255);
              if ($866) {
               $coplanaredges_num$1$i$i = $coplanaredges_num$093$i$i;
              } else {
               $867 = $coplanaredge$2$i$i&65535;
               $868 = $867 & 255;
               $869 = (($coplanaredges$i$i) + ($coplanaredges_num$093$i$i<<2)|0);
               HEAP16[$869>>1] = $868;
               $870 = ((($coplanaredges$i$i) + ($coplanaredges_num$093$i$i<<2)|0) + 2|0);
               HEAP8[$870>>0] = $vin$2$i$i;
               $871 = ((($coplanaredges$i$i) + ($coplanaredges_num$093$i$i<<2)|0) + 3|0);
               HEAP8[$871>>0] = $vout$2$i$i;
               $872 = (($coplanaredges_num$093$i$i) + 1)|0;
               $coplanaredges_num$1$i$i = $872;
              }
              $873 = (($currentplane$089$i$i) + 1)|0;
              $874 = HEAP32[$326>>2]|0;
              $875 = ($873|0)<($874|0);
              if ($875) {
               $$$i366488$i$i = $$$i3654$i$i;$1213 = $1218;$1214 = $1219;$coplanaredges_num$093$i$i = $coplanaredges_num$1$i$i;$currentplane$089$i$i = $873;$e0$090$i$i = $enextface$1$i$i;$under_edge_count$092$i$i = $under_edge_count$3$i$i;$underplanescount$091$i$i = $underplanescount$1$i$i;$vertcountunder$294$i$i = $vertcountunder$8$i$i;
              } else {
               break;
              }
             }
             $876 = ($coplanaredges_num$1$i$i|0)>(0);
             if ($876) {
              $877 = (($underplanescount$1$i$i) + 1)<<16>>16;
              $878 = $underplanescount$1$i$i&65535;
              $879 = (($tmpunderplanes$i$i) + ($878<<4)|0);
              ;HEAP32[$879+0>>2]=HEAP32[$410+0>>2]|0;HEAP32[$879+4>>2]=HEAP32[$410+4>>2]|0;HEAP32[$879+8>>2]=HEAP32[$410+8>>2]|0;HEAP32[$879+12>>2]=HEAP32[$410+12>>2]|0;
              $1222 = 1;$underplanescount$2$i$i = $877;
             } else {
              $1222 = 0;$underplanescount$2$i$i = $underplanescount$1$i$i;
             }
             $880 = (($coplanaredges_num$1$i$i) + -1)|0;
             $881 = ($880|0)>(0);
             if ($881) {
              $883 = 0;$i$179$i$i = 0;
              while(1) {
               $882 = ((($coplanaredges$i$i) + ($883<<2)|0) + 3|0);
               $884 = HEAP8[$882>>0]|0;
               $885 = (($883) + 1)|0;
               $886 = (($coplanaredges$i$i) + ($885<<2)|0);
               $887 = ((($coplanaredges$i$i) + ($885<<2)|0) + 2|0);
               $888 = HEAP8[$887>>0]|0;
               $889 = ($884<<24>>24)==($888<<24>>24);
               if (!($889)) {
                $890 = (($883) + 2)|0;
                $891 = ($890|0)<($coplanaredges_num$1$i$i|0);
                if ($891) {
                 $j$076$i$i = $890;
                } else {
                 $$0$i$i = 0;$967 = $1218;
                 break L113;
                }
                while(1) {
                 $894 = ((($coplanaredges$i$i) + ($j$076$i$i<<2)|0) + 2|0);
                 $895 = HEAP8[$894>>0]|0;
                 $896 = ($884<<24>>24)==($895<<24>>24);
                 $893 = (($j$076$i$i) + 1)|0;
                 if ($896) {
                  break;
                 }
                 $892 = ($893|0)<($coplanaredges_num$1$i$i|0);
                 if ($892) {
                  $j$076$i$i = $893;
                 } else {
                  $$0$i$i = 0;$967 = $1218;
                  break L113;
                 }
                }
                $897 = (($coplanaredges$i$i) + ($j$076$i$i<<2)|0);
                $898 = HEAPU16[$886>>1]|(HEAPU16[$886+2>>1]<<16);
                $899 = HEAPU16[$897>>1]|(HEAPU16[$897+2>>1]<<16);
                HEAP16[$886>>1]=$899&65535;HEAP16[$886+2>>1]=$899>>>16;
                HEAP16[$897>>1]=$898&65535;HEAP16[$897+2>>1]=$898>>>16;
               }
               $900 = (($i$179$i$i) + 1)<<16>>16;
               $901 = $900&65535;
               $902 = ($901|0)<($880|0);
               if ($902) {
                $883 = $901;$i$179$i$i = $900;
               } else {
                $1215 = $1222;$943 = $1218;$coplanaredges_num$0$lcssa158$i$i = $coplanaredges_num$1$i$i;$under_edge_count$0$lcssa159161$i$i = $under_edge_count$3$i$i;$underplanescount$2163$i$i = $underplanescount$2$i$i;$vertcountunder$2$lcssa156162$i$i = $vertcountunder$8$i$i;
                label = 141;
                break;
               }
              }
             } else {
              $1215 = $1222;$943 = $1218;$coplanaredges_num$0$lcssa158$i$i = $coplanaredges_num$1$i$i;$under_edge_count$0$lcssa159161$i$i = $under_edge_count$3$i$i;$underplanescount$2163$i$i = $underplanescount$2$i$i;$vertcountunder$2$lcssa156162$i$i = $vertcountunder$8$i$i;
              label = 141;
             }
            } else {
             $1215 = 0;$943 = 0;$coplanaredges_num$0$lcssa158$i$i = 0;$under_edge_count$0$lcssa159161$i$i = 0;$underplanescount$2163$i$i = 0;$vertcountunder$2$lcssa156162$i$i = $vertcountunder$1$i$i;
             label = 141;
            }
           } while(0);
           if ((label|0) == 141) {
            label = 0;
            $903 = ($vertcountunder$2$lcssa156162$i$i<<16>>16)==(0);
            if ($903) {
             $$0$i$i = 0;$967 = $943;
            } else {
             $904 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
             $905 = HEAP32[$904>>2]|0;
             $906 = (($905) + 8|0);
             $907 = HEAP32[$906>>2]|0;
             $908 = (__Z15PxGetFoundationv()|0);
             $909 = HEAP32[$908>>2]|0;
             $910 = (($909) + 24|0);
             $911 = HEAP32[$910>>2]|0;
             $912 = (FUNCTION_TABLE_ii[$911 & 4095]($908)|0);
             $$$i$i$i$i$i = $912 ? 534888 : 534480;
             $913 = (FUNCTION_TABLE_iiiiii[$907 & 255]($904,36,$$$i$i$i$i$i,534392,1145)|0);
             $914 = $vertcountunder$2$lcssa156162$i$i&65535;
             $915 = $under_edge_count$0$lcssa159161$i$i&65535;
             $916 = (($coplanaredges_num$0$lcssa158$i$i) + ($915))|0;
             $917 = $underplanescount$2163$i$i&65535;
             __ZN5physx7ConvexHC2Eiii($913,$914,$916,$917);
             $918 = HEAP32[$322>>2]|0;
             $919 = ($918|0)>(0);
             if ($919) {
              $1223 = $918;$922 = 0;$i$271$i$i = 0;$k$072$i$i = 0;
              while(1) {
               $921 = (($vertflag$i$i) + ($922<<2)|0);
               $923 = HEAP8[$921>>0]|0;
               $924 = ($923<<24>>24)==(1);
               if ($924) {
                $925 = (($k$072$i$i) + 1)|0;
                $926 = HEAP32[$913>>2]|0;
                $927 = (($926) + (($k$072$i$i*12)|0)|0);
                $928 = HEAP32[$c$0124$i>>2]|0;
                $929 = (($928) + (($922*12)|0)|0);
                ;HEAP32[$927+0>>2]=HEAP32[$929+0>>2]|0;HEAP32[$927+4>>2]=HEAP32[$929+4>>2]|0;HEAP32[$927+8>>2]=HEAP32[$929+8>>2]|0;
                $$pre122$i$i = HEAP32[$322>>2]|0;
                $933 = $$pre122$i$i;$k$1$i$i = $925;
               } else {
                $933 = $1223;$k$1$i$i = $k$072$i$i;
               }
               $930 = (($i$271$i$i) + 1)<<16>>16;
               $931 = $930&65535;
               $932 = ($931|0)<($933|0);
               if ($932) {
                $1223 = $933;$922 = $931;$i$271$i$i = $930;$k$072$i$i = $k$1$i$i;
               } else {
                $k$0$lcssa$i$i = $k$1$i$i;
                break;
               }
              }
             } else {
              $k$0$lcssa$i$i = 0;
             }
             $920 = ($k$0$lcssa$i$i|0)<($914|0);
             if ($920) {
              $i$368$i$i = 0;$k$269$i$i = $k$0$lcssa$i$i;
              while(1) {
               $937 = (($k$269$i$i) + 1)|0;
               $938 = HEAP32[$913>>2]|0;
               $939 = (($938) + (($k$269$i$i*12)|0)|0);
               $940 = (($i$368$i$i) + 1)<<16>>16;
               $941 = $i$368$i$i&65535;
               $942 = (($943) + (($941*12)|0)|0);
               ;HEAP32[$939+0>>2]=HEAP32[$942+0>>2]|0;HEAP32[$939+4>>2]=HEAP32[$942+4>>2]|0;HEAP32[$939+8>>2]=HEAP32[$942+8>>2]|0;
               $exitcond$i49$i = ($937|0)==($914|0);
               if ($exitcond$i49$i) {
                break;
               } else {
                $i$368$i$i = $940;$k$269$i$i = $937;
               }
              }
             }
             if ($1215) {
              $934 = (($917) + 255)|0;
              $935 = $934&255;
              $936 = (($913) + 12|0);
              $945 = 0;$i$466$i$i = 0;
              while(1) {
               $944 = (($945) + ($915))|0;
               $946 = HEAP32[$936>>2]|0;
               $947 = ((($946) + ($944<<2)|0) + 3|0);
               HEAP8[$947>>0] = $935;
               $948 = (($coplanaredges$i$i) + ($945<<2)|0);
               $949 = HEAP16[$948>>1]|0;
               $950 = HEAP32[$936>>2]|0;
               $951 = (($950) + ($944<<2)|0);
               HEAP16[$951>>1] = $949;
               $952 = $944&65535;
               $953 = $949&65535;
               $954 = (($tmpunderedges$i$i) + ($953<<2)|0);
               HEAP16[$954>>1] = $952;
               $955 = ((($coplanaredges$i$i) + ($945<<2)|0) + 2|0);
               $956 = HEAP8[$955>>0]|0;
               $957 = ((($950) + ($944<<2)|0) + 2|0);
               HEAP8[$957>>0] = $956;
               $958 = (($i$466$i$i) + 1)<<16>>16;
               $959 = $958&65535;
               $960 = ($959|0)<($coplanaredges_num$0$lcssa158$i$i|0);
               if ($960) {
                $945 = $959;$i$466$i$i = $958;
               } else {
                $$pre$phi143$i$iZ2D = $936;
                break;
               }
              }
             } else {
              $$pre141$i$i = (($913) + 12|0);
              $$pre$phi143$i$iZ2D = $$pre141$i$i;
             }
             $961 = HEAP32[$$pre$phi143$i$iZ2D>>2]|0;
             $962 = $915 << 2;
             _memcpy(($961|0),($tmpunderedges$i$i|0),($962|0))|0;
             $963 = (($913) + 24|0);
             $964 = HEAP32[$963>>2]|0;
             $965 = $917 << 4;
             _memcpy(($964|0),($tmpunderplanes$i$i|0),($965|0))|0;
             $$0$i$i = $913;$967 = $943;
            }
           }
           $966 = ($967|0)==(0|0);
           if ($966) {
            $$0$i80$i = $$0$i$i;
           } else {
            __ZN5physx6shdfnd9Allocator10deallocateEPv($10,$967);
            $$0$i80$i = $$0$i$i;
           }
          }
         } else {
          label = 64;
         }
        } while(0);
        if ((label|0) == 64) {
         label = 0;
         $440 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
         $441 = HEAP32[$440>>2]|0;
         $442 = (($441) + 8|0);
         $443 = HEAP32[$442>>2]|0;
         $444 = (__Z15PxGetFoundationv()|0);
         $445 = HEAP32[$444>>2]|0;
         $446 = (($445) + 24|0);
         $447 = HEAP32[$446>>2]|0;
         $448 = (FUNCTION_TABLE_ii[$447 & 4095]($444)|0);
         $$$i$i$i$i$i45$i = $448 ? 534888 : 534480;
         $449 = (FUNCTION_TABLE_iiiiii[$443 & 255]($440,36,$$$i$i$i$i$i45$i,534392,589)|0);
         $450 = HEAP32[$322>>2]|0;
         $451 = HEAP32[$328>>2]|0;
         $452 = HEAP32[$326>>2]|0;
         __ZN5physx7ConvexHC2Eiii($449,$450,$451,$452);
         $453 = HEAP32[$449>>2]|0;
         $454 = HEAP32[$c$0124$i>>2]|0;
         $455 = HEAP32[$322>>2]|0;
         $456 = ($455*12)|0;
         _memcpy(($453|0),($454|0),($456|0))|0;
         $457 = (($449) + 12|0);
         $458 = HEAP32[$457>>2]|0;
         $459 = HEAP32[$329>>2]|0;
         $460 = HEAP32[$328>>2]|0;
         $461 = $460 << 2;
         _memcpy(($458|0),($459|0),($461|0))|0;
         $462 = (($449) + 24|0);
         $463 = HEAP32[$462>>2]|0;
         $464 = HEAP32[$327>>2]|0;
         $465 = HEAP32[$326>>2]|0;
         $466 = $465 << 4;
         _memcpy(($463|0),($464|0),($466|0))|0;
         $$0$i80$i = $449;
        }
        $968 = ($$0$i80$i|0)==(0|0);
        if ($968) {
         $c$0109$i = $c$0124$i;
         break L65;
        }
        $969 = (($$0$i80$i) + 16|0);
        $970 = HEAP32[$969>>2]|0;
        $971 = (($$0$i80$i) + 12|0);
        $estart$0$i$i = 0;$i$0$i$i = 0;
        while(1) {
         $972 = ($i$0$i$i|0)<($970|0);
         if (!($972)) {
          break;
         }
         $980 = HEAP32[$971>>2]|0;
         $981 = ((($980) + ($estart$0$i$i<<2)|0) + 3|0);
         $982 = HEAP8[$981>>0]|0;
         $983 = ((($980) + ($i$0$i$i<<2)|0) + 3|0);
         $984 = HEAP8[$983>>0]|0;
         $985 = ($982<<24>>24)==($984<<24>>24);
         $estart$0$i$0$i$i = $985 ? $estart$0$i$i : $i$0$i$i;
         $986 = (($i$0$i$i) + 1)|0;
         $987 = ($986|0)<($970|0);
         if ($987) {
          $988 = ((($980) + ($986<<2)|0) + 3|0);
          $989 = HEAP8[$988>>0]|0;
          $990 = ($989<<24>>24)==($984<<24>>24);
          if ($990) {
           $inext$0$i$i = $986;
          } else {
           label = 164;
          }
         } else {
          label = 164;
         }
         if ((label|0) == 164) {
          label = 0;
          $inext$0$i$i = $estart$0$i$0$i$i;
         }
         $991 = (($980) + ($i$0$i$i<<2)|0);
         $992 = HEAP16[$991>>1]|0;
         if ((($992<<16>>16) == 255) | (($992<<16>>16) == -1)) {
          label = 180;
          break L67;
         }
         $993 = $992 << 16 >> 16;
         $994 = ((($980) + ($993<<2)|0) + 2|0);
         $995 = HEAP8[$994>>0]|0;
         $996 = ((($980) + ($inext$0$i$i<<2)|0) + 2|0);
         $997 = HEAP8[$996>>0]|0;
         $998 = ($995<<24>>24)==($997<<24>>24);
         if ($998) {
          $estart$0$i$i = $estart$0$i$0$i$i;$i$0$i$i = $986;
         } else {
          label = 180;
          break L67;
         }
        }
        $973 = ($970|0)>(0);
        L266: do {
         if ($973) {
          $974 = HEAP32[$971>>2]|0;
          $975 = (($$0$i80$i) + 24|0);
          $976 = HEAP32[$975>>2]|0;
          $977 = HEAP32[$$0$i80$i>>2]|0;
          $978 = Math_fround(HEAPF32[534376>>2]);
          $979 = Math_fround(-$978);
          $estart$220$i$i = $estart$0$i$i;$i$119$i$i = 0;
          while(1) {
           $999 = ((($974) + ($i$119$i$i<<2)|0) + 3|0);
           $1000 = HEAP8[$999>>0]|0;
           $1001 = $1000&255;
           $1002 = ((($974) + ($i$119$i$i<<2)|0) + 2|0);
           $1003 = HEAP8[$1002>>0]|0;
           $1004 = $1003&255;
           $$idx15$i$i = (($977) + (($1004*12)|0)|0);
           $$idx15$val$i$i = Math_fround(HEAPF32[$$idx15$i$i>>2]);
           $$idx16$i$i = ((($977) + (($1004*12)|0)|0) + 4|0);
           $$idx16$val$i$i = Math_fround(HEAPF32[$$idx16$i$i>>2]);
           $$idx17$i$i = ((($977) + (($1004*12)|0)|0) + 8|0);
           $$idx17$val$i$i = Math_fround(HEAPF32[$$idx17$i$i>>2]);
           $$idx$i$i53$i = (($976) + ($1001<<4)|0);
           $$idx$val$i$i$i = Math_fround(HEAPF32[$$idx$i$i53$i>>2]);
           $$idx3$i$i54$i = ((($976) + ($1001<<4)|0) + 4|0);
           $$idx3$val$i$i$i = Math_fround(HEAPF32[$$idx3$i$i54$i>>2]);
           $$idx4$i$i55$i = ((($976) + ($1001<<4)|0) + 8|0);
           $$idx4$val$i$i$i = Math_fround(HEAPF32[$$idx4$i$i55$i>>2]);
           $1005 = Math_fround($$idx15$val$i$i * $$idx$val$i$i$i);
           $1006 = Math_fround($$idx16$val$i$i * $$idx3$val$i$i$i);
           $1007 = Math_fround($1005 + $1006);
           $1008 = Math_fround($$idx17$val$i$i * $$idx4$val$i$i$i);
           $1009 = Math_fround($1007 + $1008);
           $1010 = ((($976) + ($1001<<4)|0) + 12|0);
           $1011 = Math_fround(HEAPF32[$1010>>2]);
           $1012 = Math_fround($1011 + $1009);
           $1013 = $1012 > $978;
           $1014 = $1012 < $979;
           $or$cond$i56$i = $1013 | $1014;
           if ($or$cond$i56$i) {
            $1071 = $976;
            break L67;
           }
           $1015 = ((($974) + ($estart$220$i$i<<2)|0) + 3|0);
           $1016 = HEAP8[$1015>>0]|0;
           $1017 = ($1016<<24>>24)==($1000<<24>>24);
           $estart$2$i$1$i$i = $1017 ? $estart$220$i$i : $i$119$i$i;
           $1018 = (($i$119$i$i) + 1)|0;
           $1019 = ($1018|0)<($970|0);
           if ($1019) {
            $1020 = ((($974) + ($1018<<2)|0) + 3|0);
            $1021 = HEAP8[$1020>>0]|0;
            $1022 = ($1021<<24>>24)==($1000<<24>>24);
            if ($1022) {
             $i1$0$i$i = $1018;
            } else {
             label = 170;
            }
           } else {
            label = 170;
           }
           if ((label|0) == 170) {
            label = 0;
            $i1$0$i$i = $estart$2$i$1$i$i;
           }
           $1023 = (($i1$0$i$i) + 1)|0;
           $1024 = ($1023|0)<($970|0);
           if ($1024) {
            $1025 = ((($974) + ($1023<<2)|0) + 3|0);
            $1026 = HEAP8[$1025>>0]|0;
            $1027 = ($1026<<24>>24)==($1000<<24>>24);
            if ($1027) {
             $i2$0$i$i = $1023;
            } else {
             label = 173;
            }
           } else {
            label = 173;
           }
           if ((label|0) == 173) {
            label = 0;
            $i2$0$i$i = $estart$2$i$1$i$i;
           }
           $1028 = ($i$119$i$i|0)==($i2$0$i$i|0);
           if ($1028) {
            if ($1019) {
             $estart$220$i$i = $estart$2$i$1$i$i;$i$119$i$i = $1018;
             continue;
            } else {
             break L266;
            }
           }
           $1029 = ((($974) + ($i1$0$i$i<<2)|0) + 2|0);
           $1030 = HEAP8[$1029>>0]|0;
           $1031 = $1030&255;
           $1032 = ((($974) + ($i2$0$i$i<<2)|0) + 2|0);
           $1033 = HEAP8[$1032>>0]|0;
           $1034 = $1033&255;
           $$idx9$i$i = (($977) + (($1031*12)|0)|0);
           $$idx9$val$i$i = Math_fround(HEAPF32[$$idx9$i$i>>2]);
           $$idx10$i$i = ((($977) + (($1031*12)|0)|0) + 4|0);
           $$idx10$val$i57$i = Math_fround(HEAPF32[$$idx10$i$i>>2]);
           $$idx11$i58$i = ((($977) + (($1031*12)|0)|0) + 8|0);
           $$idx11$val$i59$i = Math_fround(HEAPF32[$$idx11$i58$i>>2]);
           $$idx12$i$i = (($977) + (($1034*12)|0)|0);
           $$idx12$val$i$i = Math_fround(HEAPF32[$$idx12$i$i>>2]);
           $$idx13$i$i = ((($977) + (($1034*12)|0)|0) + 4|0);
           $$idx13$val$i$i = Math_fround(HEAPF32[$$idx13$i$i>>2]);
           $$idx14$i$i = ((($977) + (($1034*12)|0)|0) + 8|0);
           $$idx14$val$i$i = Math_fround(HEAPF32[$$idx14$i$i>>2]);
           $1035 = Math_fround($$idx9$val$i$i - $$idx15$val$i$i);
           $1036 = Math_fround($$idx10$val$i57$i - $$idx16$val$i$i);
           $1037 = Math_fround($$idx11$val$i59$i - $$idx17$val$i$i);
           $1038 = Math_fround($$idx12$val$i$i - $$idx9$val$i$i);
           $1039 = Math_fround($$idx13$val$i$i - $$idx10$val$i57$i);
           $1040 = Math_fround($$idx14$val$i$i - $$idx11$val$i59$i);
           $1041 = Math_fround($1036 * $1040);
           $1042 = Math_fround($1037 * $1039);
           $1043 = Math_fround($1041 - $1042);
           $1044 = Math_fround($1037 * $1038);
           $1045 = Math_fround($1035 * $1040);
           $1046 = Math_fround($1044 - $1045);
           $1047 = Math_fround($1035 * $1039);
           $1048 = Math_fround($1036 * $1038);
           $1049 = Math_fround($1047 - $1048);
           $1050 = Math_fround($1043 * $1043);
           $1051 = Math_fround($1046 * $1046);
           $1052 = Math_fround($1050 + $1051);
           $1053 = Math_fround($1049 * $1049);
           $1054 = Math_fround($1053 + $1052);
           $1055 = (Math_fround(Math_sqrt((Math_fround($1054)))));
           $1056 = $1055 == Math_fround(0.0);
           if ($1056) {
            $1062 = Math_fround(1.0);$1064 = Math_fround(0.0);$1067 = Math_fround(0.0);
           } else {
            $1057 = Math_fround(Math_fround(1.0) / $1055);
            $1058 = Math_fround($1043 * $1057);
            $1059 = Math_fround($1046 * $1057);
            $1060 = Math_fround($1049 * $1057);
            $1062 = $1058;$1064 = $1059;$1067 = $1060;
           }
           $1061 = Math_fround($$idx$val$i$i$i * $1062);
           $1063 = Math_fround($$idx3$val$i$i$i * $1064);
           $1065 = Math_fround($1063 + $1061);
           $1066 = Math_fround($$idx4$val$i$i$i * $1067);
           $1068 = Math_fround($1066 + $1065);
           $$not$i$i = $1068 <= Math_fround(0.0);
           $$not27$i$i = $1019 ^ 1;
           $brmerge$i$i = $$not$i$i | $$not27$i$i;
           if ($brmerge$i$i) {
            break;
           } else {
            $estart$220$i$i = $estart$2$i$1$i$i;$i$119$i$i = $1018;
           }
          }
          if ($$not$i$i) {
           $1071 = $976;
           break L67;
          }
         }
        } while(0);
        $1081 = ($c$0124$i|0)==(0|0);
        if (!($1081)) {
         $1082 = HEAP32[$327>>2]|0;
         $1083 = ($1082|0)==(0|0);
         if (!($1083)) {
          __ZN5physx6shdfnd9Allocator10deallocateEPv($coplanaredges$i$i,$1082);
          HEAP32[$327>>2] = 0;
         }
         HEAP32[$326>>2] = 0;
         $1084 = (($c$0124$i) + 32|0);
         HEAP32[$1084>>2] = 0;
         HEAP32[$327>>2] = 0;
         $1085 = HEAP32[$329>>2]|0;
         $1086 = ($1085|0)==(0|0);
         if (!($1086)) {
          __ZN5physx6shdfnd9Allocator10deallocateEPv($coplanaredges$i$i,$1085);
          HEAP32[$329>>2] = 0;
         }
         HEAP32[$328>>2] = 0;
         $1087 = (($c$0124$i) + 20|0);
         HEAP32[$1087>>2] = 0;
         HEAP32[$329>>2] = 0;
         $1088 = HEAP32[$c$0124$i>>2]|0;
         $1089 = ($1088|0)==(0|0);
         if (!($1089)) {
          __ZN5physx6shdfnd9Allocator10deallocateEPv($coplanaredges$i$i,$1088);
          HEAP32[$c$0124$i>>2] = 0;
         }
         HEAP32[$322>>2] = 0;
         $1090 = (($c$0124$i) + 8|0);
         HEAP32[$1090>>2] = 0;
         HEAP32[$c$0124$i>>2] = 0;
         __ZN5physx6shdfnd9Allocator10deallocateEPv($coplanaredges$i$i,$c$0124$i);
        }
        $1091 = ($403|0)==(0);
        if ($1091) {
         $c$0109$i = $$0$i80$i;
         break L65;
        } else {
         $$in$i = $403;$c$0124$i = $$0$i80$i;
        }
       }
       if ((label|0) == 180) {
        $$phi$trans$insert = (($$0$i80$i) + 24|0);
        $$pre85 = HEAP32[$$phi$trans$insert>>2]|0;
        $1071 = $$pre85;
       }
       $1069 = (($$0$i80$i) + 24|0);
       $1070 = ($1071|0)==(0|0);
       if (!($1070)) {
        __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$1071);
        HEAP32[$1069>>2] = 0;
       }
       $1072 = (($$0$i80$i) + 28|0);
       HEAP32[$1072>>2] = 0;
       $1073 = (($$0$i80$i) + 32|0);
       HEAP32[$1073>>2] = 0;
       HEAP32[$1069>>2] = 0;
       $1074 = HEAP32[$971>>2]|0;
       $1075 = ($1074|0)==(0|0);
       if (!($1075)) {
        __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$1074);
        HEAP32[$971>>2] = 0;
       }
       HEAP32[$969>>2] = 0;
       $1076 = (($$0$i80$i) + 20|0);
       HEAP32[$1076>>2] = 0;
       HEAP32[$971>>2] = 0;
       $1077 = HEAP32[$$0$i80$i>>2]|0;
       $1078 = ($1077|0)==(0|0);
       if (!($1078)) {
        __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$1077);
        HEAP32[$$0$i80$i>>2] = 0;
       }
       $1079 = (($$0$i80$i) + 4|0);
       HEAP32[$1079>>2] = 0;
       $1080 = (($$0$i80$i) + 8|0);
       HEAP32[$1080>>2] = 0;
       HEAP32[$$0$i80$i>>2] = 0;
       __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$$0$i80$i);
       $c$0109$i = $c$0124$i;
      } else {
       $c$0109$i = $147;
      }
     } while(0);
     $1092 = (($c$0109$i) + 28|0);
     $1093 = HEAP32[$1092>>2]|0;
     $1094 = (($1093) + 1)|0;
     $1095 = (($c$0109$i) + 16|0);
     $1096 = HEAP32[$1095>>2]|0;
     $1097 = (($1094) + ($1096))|0;
     $1098 = $1097 << 2;
     $1099 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($11,$1098,534392,2123)|0);
     HEAP32[$faces_out>>2] = $1099;
     HEAP32[$faces_count_out>>2] = 1;
     HEAP32[$1099>>2] = -1;
     $1100 = HEAP32[$1095>>2]|0;
     $1101 = ($1100|0)>(0);
     if ($1101) {
      $1102 = (($c$0109$i) + 12|0);
      $1105 = $1100;$i$391$i = 0;$k$092$i = 0;
      while(1) {
       $1103 = (($i$391$i) + 1)|0;
       $1104 = ($1103|0)<($1105|0);
       if ($1104) {
        $1109 = HEAP32[$1102>>2]|0;
        $1110 = ((($1109) + ($i$391$i<<2)|0) + 3|0);
        $1111 = HEAP8[$1110>>0]|0;
        $1116 = $1103;$j$184$i = 1;
        while(1) {
         $1115 = ((($1109) + ($1116<<2)|0) + 3|0);
         $1117 = HEAP8[$1115>>0]|0;
         $1118 = ($1111<<24>>24)==($1117<<24>>24);
         $1113 = (($j$184$i) + 1)|0;
         if (!($1118)) {
          $j$1$lcssa$i = $j$184$i;
          break;
         }
         $1112 = (($1113) + ($i$391$i))|0;
         $1114 = ($1112|0)<($1105|0);
         if ($1114) {
          $1116 = $1112;$j$184$i = $1113;
         } else {
          $j$1$lcssa$i = $1113;
          break;
         }
        }
        $1119 = HEAP32[$faces_count_out>>2]|0;
        $1120 = (($1119) + 1)|0;
        HEAP32[$faces_count_out>>2] = $1120;
        $1121 = (($1099) + ($1119<<2)|0);
        HEAP32[$1121>>2] = $j$1$lcssa$i;
        $1122 = ($j$1$lcssa$i|0)==(0);
        if ($1122) {
         $i$4$lcssa$i = $i$391$i;
        } else {
         $$pre$i = $1109;$j$1$lcssa203$i = $j$1$lcssa$i;
         label = 205;
        }
       } else {
        $1106 = HEAP32[$faces_count_out>>2]|0;
        $1107 = (($1106) + 1)|0;
        HEAP32[$faces_count_out>>2] = $1107;
        $1108 = (($1099) + ($1106<<2)|0);
        HEAP32[$1108>>2] = 1;
        $$pre$i$pre = HEAP32[$1102>>2]|0;
        $$pre$i = $$pre$i$pre;$j$1$lcssa203$i = 1;
        label = 205;
       }
       if ((label|0) == 205) {
        label = 0;
        $i$487$i = $i$391$i;$j$286$i = $j$1$lcssa203$i;
        while(1) {
         $1123 = (($j$286$i) + -1)|0;
         $1124 = ((($$pre$i) + ($i$487$i<<2)|0) + 2|0);
         $1125 = HEAP8[$1124>>0]|0;
         $1126 = $1125&255;
         $1127 = HEAP32[$faces_count_out>>2]|0;
         $1128 = (($1127) + 1)|0;
         HEAP32[$faces_count_out>>2] = $1128;
         $1129 = (($1099) + ($1127<<2)|0);
         HEAP32[$1129>>2] = $1126;
         $1130 = (($i$487$i) + 1)|0;
         $1131 = ($1123|0)==(0);
         if ($1131) {
          break;
         } else {
          $i$487$i = $1130;$j$286$i = $1123;
         }
        }
        $1132 = (($j$1$lcssa203$i) + ($i$391$i))|0;
        $i$4$lcssa$i = $1132;
       }
       $1133 = (($k$092$i) + 1)|0;
       $1134 = HEAP32[$1095>>2]|0;
       $1135 = ($i$4$lcssa$i|0)<($1134|0);
       if ($1135) {
        $1105 = $1134;$i$391$i = $i$4$lcssa$i;$k$092$i = $1133;
       } else {
        $k$0$lcssa$i = $1133;
        break;
       }
      }
     } else {
      $k$0$lcssa$i = 0;
     }
     HEAP32[$1099>>2] = $k$0$lcssa$i;
     $1136 = HEAP32[$c$0109$i>>2]|0;
     HEAP32[$verts_out>>2] = $1136;
     $1137 = (($c$0109$i) + 4|0);
     $1138 = HEAP32[$1137>>2]|0;
     HEAP32[$verts_count_out>>2] = $1138;
     $1139 = HEAP32[$1137>>2]|0;
     $1140 = ($1139|0)>(0);
     if ($1140) {
      $1141 = HEAP32[$c$0109$i>>2]|0;
      _memmove(($1136|0),($1141|0),12)|0;
      $1142 = HEAP32[$1137>>2]|0;
      $1143 = ($1142|0)>(1);
      if ($1143) {
       $1145 = 1;
       while(1) {
        $$pre201$i = HEAP32[$verts_out>>2]|0;
        $1144 = (($$pre201$i) + (($1145*12)|0)|0);
        $1146 = HEAP32[$c$0109$i>>2]|0;
        $1147 = (($1146) + (($1145*12)|0)|0);
        _memmove(($1144|0),($1147|0),12)|0;
        $1148 = (($1145) + 1)|0;
        $1149 = HEAP32[$1137>>2]|0;
        $1150 = ($1148|0)<($1149|0);
        if ($1150) {
         $1145 = $1148;
        } else {
         break;
        }
       }
       $1151 = (($c$0109$i) + 8|0);
       HEAP32[$1151>>2] = 0;
       HEAP32[$1137>>2] = 0;
       HEAP32[$c$0109$i>>2] = 0;
       $1164 = $1151;
      } else {
       label = 213;
      }
     } else {
      label = 213;
     }
     if ((label|0) == 213) {
      $1152 = (($c$0109$i) + 8|0);
      HEAP32[$1152>>2] = 0;
      HEAP32[$1137>>2] = 0;
      HEAP32[$c$0109$i>>2] = 0;
      $1153 = ($c$0109$i|0)==(0|0);
      if ($1153) {
       $$0 = 0;
       break;
      } else {
       $1164 = $1152;
      }
     }
     $1154 = (($c$0109$i) + 24|0);
     $1155 = HEAP32[$1154>>2]|0;
     $1156 = ($1155|0)==(0|0);
     if (!($1156)) {
      __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$1155);
      HEAP32[$1154>>2] = 0;
     }
     HEAP32[$1092>>2] = 0;
     $1157 = (($c$0109$i) + 32|0);
     HEAP32[$1157>>2] = 0;
     HEAP32[$1154>>2] = 0;
     $1158 = (($c$0109$i) + 12|0);
     $1159 = HEAP32[$1158>>2]|0;
     $1160 = ($1159|0)==(0|0);
     if (!($1160)) {
      __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$1159);
      HEAP32[$1158>>2] = 0;
     }
     HEAP32[$1095>>2] = 0;
     $1161 = (($c$0109$i) + 20|0);
     HEAP32[$1161>>2] = 0;
     HEAP32[$1158>>2] = 0;
     $1162 = HEAP32[$c$0109$i>>2]|0;
     $1163 = ($1162|0)==(0|0);
     if (!($1163)) {
      __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$1162);
      HEAP32[$c$0109$i>>2] = 0;
     }
     HEAP32[$1137>>2] = 0;
     HEAP32[$1164>>2] = 0;
     HEAP32[$c$0109$i>>2] = 0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$c$0109$i);
     $$0 = 0;
    }
   }
  }
 } while(0);
 $1165 = HEAP32[$planes>>2]|0;
 $1166 = ($1165|0)==(0|0);
 if (!($1166)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($10,$1165);
  HEAP32[$planes>>2] = 0;
 }
 HEAP32[$13>>2] = 0;
 HEAP32[$14>>2] = 0;
 HEAP32[$planes>>2] = 0;
 $$1 = $$0;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx11HullLibrary11ComputeHullEjPKfRNS_11PHullResultEjff($this,$vcount,$vertices,$result,$vlimit,$inflate,$areaEpsilon) {
 $this = $this|0;
 $vcount = $vcount|0;
 $vertices = $vertices|0;
 $result = $result|0;
 $vlimit = $vlimit|0;
 $inflate = Math_fround($inflate);
 $areaEpsilon = Math_fround($areaEpsilon);
 var $$$i = 0, $$$i1017 = 0, $$$i11$lcssa = 0, $$$i1113 = 0, $$$i12 = 0, $$0 = 0, $$lcssa = 0, $$lcssa16 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond25 = 0, $exitcond26 = 0, $faces = 0, $i$019 = 0, $index_count = 0, $indvars$iv = 0, $indvars$iv$next = 0, $j$014 = 0, $k$018 = 0, $tris_count = 0;
 var $tris_out = 0, $verts_count_out = 0, $verts_out = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 26|0;
 $1 = sp + 25|0;
 $index_count = sp + 4|0;
 $faces = sp + 8|0;
 $verts_out = sp + 20|0;
 $verts_count_out = sp + 16|0;
 $tris_out = sp + 12|0;
 $tris_count = sp;
 $2 = sp + 24|0;
 $3 = $inflate == Math_fround(0.0);
 if ($3) {
  $4 = (__ZN5physx11HullLibrary8calchullEPNS_6float3EiRPiRiRS2_S5_if($this,$vertices,$vcount,$tris_out,$tris_count,$verts_out,$verts_count_out,$vlimit,$areaEpsilon)|0);
  $5 = $4 & -3;
  $6 = ($5|0)==(1);
  if ($6) {
   $$0 = $4;
   STACKTOP = sp;return ($$0|0);
  }
  $7 = HEAP32[$tris_count>>2]|0;
  $8 = ($7*3)|0;
  $9 = (($result) + 4|0);
  HEAP32[$9>>2] = $8;
  $10 = (($result) + 8|0);
  HEAP32[$10>>2] = $7;
  $11 = HEAP32[$tris_out>>2]|0;
  $12 = (($result) + 16|0);
  HEAP32[$12>>2] = $11;
  if ((($4|0) == 2)) {
   $13 = HEAP32[$verts_out>>2]|0;
   $14 = (($result) + 12|0);
   HEAP32[$14>>2] = $13;
   $15 = HEAP32[$verts_count_out>>2]|0;
   HEAP32[$result>>2] = $15;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else if ((($4|0) == 0)) {
   $16 = (($result) + 12|0);
   HEAP32[$16>>2] = $vertices;
   HEAP32[$result>>2] = $vcount;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $17 = (__ZN5physx11HullLibrary9overhullvEPNS_6float3EiiRS2_RiRPiS4_ffif($this,$vertices,$vcount,35,$verts_out,$verts_count_out,$faces,$index_count,$inflate,Math_fround(120.0),$vlimit,$areaEpsilon)|0);
 $18 = $17 & -3;
 $19 = ($18|0)==(1);
 if ($19) {
  $20 = HEAP32[$this>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$21);
   HEAP32[$20>>2] = 0;
  }
  $23 = (($20) + 8|0);
  HEAP32[$23>>2] = 0;
  $$pre$i = (($20) + 4|0);
  HEAP32[$$pre$i>>2] = 0;
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = HEAP32[$verts_out>>2]|0;
 $25 = (($result) + 12|0);
 HEAP32[$25>>2] = $24;
 $26 = HEAP32[$verts_count_out>>2]|0;
 HEAP32[$result>>2] = $26;
 $27 = ($17|0)==(2);
 if ($27) {
  $28 = HEAP32[$index_count>>2]|0;
  $29 = ($28*3)|0;
  $30 = (($result) + 4|0);
  HEAP32[$30>>2] = $29;
  $31 = (($result) + 8|0);
  HEAP32[$31>>2] = $28;
  $32 = HEAP32[$faces>>2]|0;
  $33 = (($result) + 16|0);
  HEAP32[$33>>2] = $32;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = HEAP32[$faces>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)>(0);
 if ($36) {
  $$$i1017 = 0;$43 = 0;$77 = 0;$i$019 = 0;$k$018 = 1;
  while(1) {
   $37 = (($k$018) + 1)|0;
   $38 = (($34) + ($k$018<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)>(2);
   if ($40) {
    $41 = (($34) + ($37<<2)|0);
    $42 = (($43) + -2)|0;
    $$$i1113 = $$$i1017;$57 = $77;$indvars$iv = $43;$j$014 = 2;
    while(1) {
     $44 = HEAP32[$41>>2]|0;
     $45 = (($j$014) + ($37))|0;
     $46 = (($j$014) + ($k$018))|0;
     $47 = (($34) + ($46<<2)|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($34) + ($45<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($indvars$iv|0)==($$$i1113|0);
     do {
      if ($51) {
       $52 = ($indvars$iv|0)==(0);
       $53 = $indvars$iv << 1;
       $$$i = $52 ? 16 : $53;
       $54 = ($$$i*12)|0;
       $55 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$54,534704,153)|0);
       $56 = ($indvars$iv|0)>(0);
       if ($56) {
        ;HEAP32[$55+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$57+8>>2]|0;
        $58 = ($indvars$iv|0)>(1);
        if ($58) {
         $60 = 1;
         while(1) {
          $59 = (($55) + (($60*12)|0)|0);
          $61 = (($57) + (($60*12)|0)|0);
          ;HEAP32[$59+0>>2]=HEAP32[$61+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$61+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$61+8>>2]|0;
          $62 = (($60) + 1)|0;
          $exitcond = ($62|0)==($indvars$iv|0);
          if ($exitcond) {
           $$pre$phiZ2D = $57;
           break;
          } else {
           $60 = $62;
          }
         }
        } else {
         label = 20;
        }
       } else {
        label = 20;
       }
       if ((label|0) == 20) {
        label = 0;
        $63 = ($57|0)==(0|0);
        if ($63) {
         $$$i12 = $$$i;$65 = $55;
         break;
        }
        $$pre$phiZ2D = $57;
       }
       __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$$pre$phiZ2D);
       $$$i12 = $$$i;$65 = $55;
      } else {
       $$$i12 = $$$i1113;$65 = $57;
      }
     } while(0);
     $indvars$iv$next = (($indvars$iv) + 1)|0;
     $64 = (($65) + (($indvars$iv*12)|0)|0);
     HEAP32[$64>>2] = $44;
     $66 = ((($65) + (($indvars$iv*12)|0)|0) + 4|0);
     HEAP32[$66>>2] = $48;
     $67 = ((($65) + (($indvars$iv*12)|0)|0) + 8|0);
     HEAP32[$67>>2] = $50;
     $68 = (($j$014) + 1)|0;
     $exitcond25 = ($68|0)==($39|0);
     if ($exitcond25) {
      break;
     } else {
      $$$i1113 = $$$i12;$57 = $65;$indvars$iv = $indvars$iv$next;$j$014 = $68;
     }
    }
    $69 = (($42) + ($39))|0;
    $$$i11$lcssa = $$$i12;$$lcssa = $69;$78 = $65;
   } else {
    $$$i11$lcssa = $$$i1017;$$lcssa = $43;$78 = $77;
   }
   $70 = (($39) + ($37))|0;
   $71 = (($i$019) + 1)|0;
   $exitcond26 = ($71|0)==($35|0);
   if ($exitcond26) {
    $$lcssa16 = $$lcssa;$76 = $78;
    break;
   } else {
    $$$i1017 = $$$i11$lcssa;$43 = $$lcssa;$77 = $78;$i$019 = $71;$k$018 = $70;
   }
  }
 } else {
  $$lcssa16 = 0;$76 = 0;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$34);
 HEAP32[$faces>>2] = 0;
 $72 = ($$lcssa16*3)|0;
 $73 = (($result) + 4|0);
 HEAP32[$73>>2] = $72;
 $74 = (($result) + 8|0);
 HEAP32[$74>>2] = $$lcssa16;
 $75 = (($result) + 16|0);
 HEAP32[$75>>2] = $76;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx11HullLibrary16CreateConvexHullERKNS_8HullDescERNS_10HullResultE($this,$desc,$result) {
 $this = $this|0;
 $desc = $desc|0;
 $result = $result|0;
 var $$ = 0, $$$i$i$i = 0, $$$i$i$i$i = 0, $$$i$i$i4 = 0, $$$i$i$i5 = 0, $$$i$i$i7 = 0, $$arith = 0, $$arith10 = 0, $$arith14 = 0, $$arith2 = 0, $$arith6 = 0, $$op$op = 0, $$overflow = 0, $$overflow11 = 0, $$overflow15 = 0, $$overflow3 = 0, $$overflow7 = 0, $$ph1084 = Math_fround(0), $$ph1185 = 0, $$ph1186 = 0;
 var $$ph82 = Math_fround(0), $$ph983 = Math_fround(0), $$pre = 0, $$pre78 = 0, $$pre79 = 0, $$pre79$pre = 0, $$pre80 = 0, $$sum = 0, $$sum$1$i = 0, $$sum$2$i = 0, $$sum1 = 0, $$sum1$i = 0, $$sum2$i = 0, $$sum3$i = 0, $$sum4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0);
 var $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0;
 var $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0);
 var $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0);
 var $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0);
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0);
 var $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0);
 var $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $dest$020 = 0, $dest3$016 = 0, $dx$0$i = Math_fround(0), $dx$1$i = Math_fround(0), $dx12$0$i = Math_fround(0), $dx12$1$i = Math_fround(0), $dy$0$i = Math_fround(0), $dy$1$i = Math_fround(0), $dy13$0$i = Math_fround(0), $dy13$1$i = Math_fround(0), $dz$0$i = Math_fround(0), $dz14$0$i = Math_fround(0), $exitcond = 0;
 var $exitcond$i = 0, $exitcond$i3 = 0, $exitcond57 = 0, $exitcond90$i = 0, $hr = 0, $i$01$i = 0, $i$023 = 0, $i$071$i = 0, $i1$021 = 0, $i1$065$i = 0, $i4$017 = 0, $i9$052$i = 0, $j3$054$i = 0, $j3$061$i = 0, $len$0$i = Math_fround(0), $len$1$i = Math_fround(0), $len$2$i = Math_fround(0), $len15$0$i = Math_fround(0), $len15$1$i = Math_fround(0), $len15$2$i = Math_fround(0);
 var $or$cond$i = 0, $or$cond10$i = 0, $or$cond11$i = 0, $or$cond12$i = 0, $or$cond13$i = 0, $or$cond14$i = 0, $or$cond15$i = 0, $or$cond16$i = 0, $or$cond5$i = 0, $or$cond6$i = 0, $or$cond7$i = 0, $or$cond8$i = 0, $or$cond9$i = 0, $ret$0 = 0, $skinwidth$0 = Math_fround(0), $source$019 = 0, $source2$015 = 0, $vsource$1 = 0, $vtx$072$i = 0, $vtx$166$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 25|0;
 $1 = sp + 20|0;
 $hr = sp;
 $2 = sp + 21|0;
 $3 = sp + 22|0;
 $4 = sp + 23|0;
 $5 = sp + 24|0;
 ;HEAP32[$hr+0>>2]=0|0;HEAP32[$hr+4>>2]=0|0;HEAP32[$hr+8>>2]=0|0;HEAP32[$hr+12>>2]=0|0;HEAP32[$hr+16>>2]=0|0;
 $6 = (($desc) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7>>>0)<(8);
 $$op$op = ($7*12)|0;
 $9 = $8 ? 96 : $$op$op;
 $10 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$9,534392,2595)|0);
 $11 = HEAP32[$6>>2]|0;
 $12 = (($desc) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($desc) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = ($11|0)==(0);
 if ($16) {
  $ret$0 = 1;$vsource$1 = $10;
 } else {
  $17 = (($desc) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $21 = Math_fround(3.40282346638528859812E+38);$24 = Math_fround(-3.40282346638528859812E+38);$29 = Math_fround(3.40282346638528859812E+38);$32 = Math_fround(-3.40282346638528859812E+38);$37 = Math_fround(3.40282346638528859812E+38);$40 = Math_fround(-3.40282346638528859812E+38);$i$071$i = 0;$vtx$072$i = $18;
  while(1) {
   $19 = Math_fround(HEAPF32[$vtx$072$i>>2]);
   $20 = $19 < $21;
   $22 = $20 ? $19 : $21;
   $23 = $19 > $24;
   $25 = $23 ? $19 : $24;
   $26 = (($vtx$072$i) + 4|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = $27 < $29;
   $30 = $28 ? $27 : $29;
   $31 = $27 > $32;
   $33 = $31 ? $27 : $32;
   $34 = (($vtx$072$i) + 8|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = $35 < $37;
   $38 = $36 ? $35 : $37;
   $39 = $35 > $40;
   $41 = $39 ? $35 : $40;
   $42 = (($vtx$072$i) + ($13)|0);
   $43 = (($i$071$i) + 1)|0;
   $exitcond90$i = ($43|0)==($11|0);
   if ($exitcond90$i) {
    break;
   } else {
    $21 = $22;$24 = $25;$29 = $30;$32 = $33;$37 = $38;$40 = $41;$i$071$i = $43;$vtx$072$i = $42;
   }
  }
  $44 = Math_fround($25 - $22);
  $45 = Math_fround($33 - $30);
  $46 = Math_fround($41 - $38);
  $47 = Math_fround($44 * Math_fround(0.5));
  $48 = Math_fround($22 + $47);
  $49 = Math_fround($45 * Math_fround(0.5));
  $50 = Math_fround($30 + $49);
  $51 = Math_fround($46 * Math_fround(0.5));
  $52 = Math_fround($38 + $51);
  $53 = $44 < Math_fround(9.99999997475242707878E-7);
  $54 = $45 < Math_fround(9.99999997475242707878E-7);
  $or$cond$i = $53 | $54;
  $55 = $46 < Math_fround(9.99999997475242707878E-7);
  $or$cond5$i = $or$cond$i | $55;
  $56 = ($11>>>0)<(3);
  $or$cond6$i = $or$cond5$i | $56;
  do {
   if ($or$cond6$i) {
    $57 = $44 > Math_fround(9.99999997475242707878E-7);
    $58 = $44 < Math_fround(3.40282346638528859812E+38);
    $or$cond7$i = $57 & $58;
    $len$0$i = $or$cond7$i ? $44 : Math_fround(3.40282346638528859812E+38);
    $59 = $45 > Math_fround(9.99999997475242707878E-7);
    $60 = $45 < $len$0$i;
    $or$cond8$i = $59 & $60;
    $len$1$i = $or$cond8$i ? $45 : $len$0$i;
    $61 = $46 > Math_fround(9.99999997475242707878E-7);
    $62 = $46 < $len$1$i;
    $or$cond9$i = $61 & $62;
    $len$2$i = $or$cond9$i ? $46 : $len$1$i;
    $63 = $len$2$i == Math_fround(3.40282346638528859812E+38);
    if ($63) {
     $dx$1$i = Math_fround(0.00999999977648258209228);$dy$1$i = Math_fround(0.00999999977648258209228);$dz$0$i = Math_fround(0.00999999977648258209228);
    } else {
     if ($53) {
      $64 = Math_fround($len$2$i * Math_fround(0.0500000007450580596924));
      $dx$0$i = $64;
     } else {
      $dx$0$i = $44;
     }
     if ($54) {
      $65 = Math_fround($len$2$i * Math_fround(0.0500000007450580596924));
      $dy$0$i = $65;
     } else {
      $dy$0$i = $45;
     }
     if ($55) {
      $66 = Math_fround($len$2$i * Math_fround(0.0500000007450580596924));
      $dx$1$i = $dx$0$i;$dy$1$i = $dy$0$i;$dz$0$i = $66;
     } else {
      $dx$1$i = $dx$0$i;$dy$1$i = $dy$0$i;$dz$0$i = $46;
     }
    }
    $67 = Math_fround($48 - $dx$1$i);
    $68 = Math_fround($48 + $dx$1$i);
    $69 = Math_fround($50 - $dy$1$i);
    $70 = Math_fround($50 + $dy$1$i);
    $71 = Math_fround($52 - $dz$0$i);
    $72 = Math_fround($52 + $dz$0$i);
    HEAPF32[$10>>2] = $67;
    $73 = (($10) + 4|0);
    HEAPF32[$73>>2] = $69;
    $74 = (($10) + 8|0);
    HEAPF32[$74>>2] = $71;
    $75 = (($10) + 12|0);
    HEAPF32[$75>>2] = $68;
    $76 = (($10) + 16|0);
    HEAPF32[$76>>2] = $69;
    $77 = (($10) + 20|0);
    HEAPF32[$77>>2] = $71;
    $78 = (($10) + 24|0);
    HEAPF32[$78>>2] = $68;
    $79 = (($10) + 28|0);
    HEAPF32[$79>>2] = $70;
    $80 = (($10) + 32|0);
    HEAPF32[$80>>2] = $71;
    $81 = (($10) + 36|0);
    HEAPF32[$81>>2] = $67;
    $82 = (($10) + 40|0);
    HEAPF32[$82>>2] = $70;
    $83 = (($10) + 44|0);
    HEAPF32[$83>>2] = $71;
    $84 = (($10) + 48|0);
    HEAPF32[$84>>2] = $67;
    $85 = (($10) + 52|0);
    HEAPF32[$85>>2] = $69;
    $86 = (($10) + 56|0);
    HEAPF32[$86>>2] = $72;
    $87 = (($10) + 60|0);
    HEAPF32[$87>>2] = $68;
    $88 = (($10) + 64|0);
    HEAPF32[$88>>2] = $69;
    $89 = (($10) + 68|0);
    HEAPF32[$89>>2] = $72;
    $90 = (($10) + 72|0);
    HEAPF32[$90>>2] = $68;
    $91 = (($10) + 76|0);
    HEAPF32[$91>>2] = $70;
    $92 = (($10) + 80|0);
    HEAPF32[$92>>2] = $72;
    $93 = (($10) + 84|0);
    HEAPF32[$93>>2] = $67;
    $94 = (($10) + 88|0);
    HEAPF32[$94>>2] = $70;
    $95 = (($10) + 92|0);
    HEAPF32[$95>>2] = $72;
    $$ph1084 = Math_fround(1.0);$$ph1185 = 8;$$ph82 = Math_fround(1.0);$$ph983 = Math_fround(1.0);
    label = 35;
   } else {
    $96 = Math_fround(Math_fround(1.0) / $44);
    $97 = Math_fround(Math_fround(1.0) / $45);
    $98 = Math_fround(Math_fround(1.0) / $46);
    $99 = Math_fround($48 * $96);
    $100 = Math_fround($50 * $97);
    $101 = Math_fround($52 * $98);
    $112 = 0;$i1$065$i = 0;$vtx$166$i = $18;
    while(1) {
     $102 = (($vtx$166$i) + ($13)|0);
     $103 = Math_fround(HEAPF32[$vtx$166$i>>2]);
     $104 = (($vtx$166$i) + 4|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = (($vtx$166$i) + 8|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = Math_fround($96 * $103);
     $109 = Math_fround($97 * $105);
     $110 = Math_fround($98 * $107);
     $111 = ($112|0)==(0);
     if ($111) {
      $150 = 0;
      label = 21;
     } else {
      $j3$061$i = 0;
      while(1) {
       $113 = ($j3$061$i*3)|0;
       $114 = (($10) + ($113<<2)|0);
       $115 = Math_fround(HEAPF32[$114>>2]);
       $$sum3$i = (($113) + 1)|0;
       $116 = (($10) + ($$sum3$i<<2)|0);
       $$sum4$i = (($113) + 2)|0;
       $117 = (($10) + ($$sum4$i<<2)|0);
       $118 = Math_fround(HEAPF32[$117>>2]);
       $119 = Math_fround($115 - $108);
       $120 = (Math_fround(Math_abs((Math_fround($119)))));
       $121 = $120 < $15;
       if ($121) {
        $122 = Math_fround($118 - $110);
        $123 = (Math_fround(Math_abs((Math_fround($122)))));
        $124 = Math_fround(HEAPF32[$116>>2]);
        $125 = Math_fround($124 - $109);
        $126 = (Math_fround(Math_abs((Math_fround($125)))));
        $127 = $126 < $15;
        $128 = $123 < $15;
        $or$cond10$i = $127 & $128;
        if ($or$cond10$i) {
         label = 17;
         break;
        }
       }
       $146 = (($j3$061$i) + 1)|0;
       $147 = ($146>>>0)<($112>>>0);
       if ($147) {
        $j3$061$i = $146;
       } else {
        $j3$054$i = $146;
        break;
       }
      }
      if ((label|0) == 17) {
       label = 0;
       $129 = Math_fround($108 - $99);
       $130 = Math_fround($109 - $100);
       $131 = Math_fround($110 - $101);
       $132 = Math_fround($129 * $129);
       $133 = Math_fround($130 * $130);
       $134 = Math_fround($132 + $133);
       $135 = Math_fround($131 * $131);
       $136 = Math_fround($135 + $134);
       $137 = Math_fround($115 - $99);
       $138 = Math_fround($124 - $100);
       $139 = Math_fround($118 - $101);
       $140 = Math_fround($137 * $137);
       $141 = Math_fround($138 * $138);
       $142 = Math_fround($140 + $141);
       $143 = Math_fround($139 * $139);
       $144 = Math_fround($143 + $142);
       $145 = $136 > $144;
       if ($145) {
        HEAPF32[$114>>2] = $108;
        HEAPF32[$116>>2] = $109;
        HEAPF32[$117>>2] = $110;
        $j3$054$i = $j3$061$i;
       } else {
        $j3$054$i = $j3$061$i;
       }
      }
      $148 = ($j3$054$i|0)==($112|0);
      if ($148) {
       $150 = $112;
       label = 21;
      } else {
       $157 = $112;
      }
     }
     if ((label|0) == 21) {
      label = 0;
      $149 = ($150*3)|0;
      $151 = (($10) + ($149<<2)|0);
      HEAPF32[$151>>2] = $108;
      $$sum1$i = (($149) + 1)|0;
      $152 = (($10) + ($$sum1$i<<2)|0);
      HEAPF32[$152>>2] = $109;
      $$sum2$i = (($149) + 2)|0;
      $153 = (($10) + ($$sum2$i<<2)|0);
      HEAPF32[$153>>2] = $110;
      $154 = (($150) + 1)|0;
      $157 = $154;
     }
     $155 = (($i1$065$i) + 1)|0;
     $exitcond$i = ($155|0)==($11|0);
     if ($exitcond$i) {
      break;
     } else {
      $112 = $157;$i1$065$i = $155;$vtx$166$i = $102;
     }
    }
    $156 = ($157|0)==(0);
    if ($156) {
     $185 = Math_fround(3.40282346638528859812E+38);$186 = Math_fround(-3.40282346638528859812E+38);$188 = Math_fround(3.40282346638528859812E+38);$189 = Math_fround(-3.40282346638528859812E+38);$191 = Math_fround(3.40282346638528859812E+38);$192 = Math_fround(-3.40282346638528859812E+38);$197 = 0;
    } else {
     $162 = Math_fround(3.40282346638528859812E+38);$165 = Math_fround(-3.40282346638528859812E+38);$170 = Math_fround(3.40282346638528859812E+38);$173 = Math_fround(-3.40282346638528859812E+38);$178 = Math_fround(3.40282346638528859812E+38);$181 = Math_fround(-3.40282346638528859812E+38);$i9$052$i = 0;
     while(1) {
      $158 = ($i9$052$i*3)|0;
      $159 = (($10) + ($158<<2)|0);
      $160 = Math_fround(HEAPF32[$159>>2]);
      $161 = $160 < $162;
      $163 = $161 ? $160 : $162;
      $164 = $160 > $165;
      $166 = $164 ? $160 : $165;
      $$sum$1$i = (($158) + 1)|0;
      $167 = (($10) + ($$sum$1$i<<2)|0);
      $168 = Math_fround(HEAPF32[$167>>2]);
      $169 = $168 < $170;
      $171 = $169 ? $168 : $170;
      $172 = $168 > $173;
      $174 = $172 ? $168 : $173;
      $$sum$2$i = (($158) + 2)|0;
      $175 = (($10) + ($$sum$2$i<<2)|0);
      $176 = Math_fround(HEAPF32[$175>>2]);
      $177 = $176 < $178;
      $179 = $177 ? $176 : $178;
      $180 = $176 > $181;
      $182 = $180 ? $176 : $181;
      $183 = (($i9$052$i) + 1)|0;
      $exitcond57 = ($183|0)==($157|0);
      if ($exitcond57) {
       $185 = $163;$186 = $166;$188 = $171;$189 = $174;$191 = $179;$192 = $182;$197 = $157;
       break;
      } else {
       $162 = $163;$165 = $166;$170 = $171;$173 = $174;$178 = $179;$181 = $182;$i9$052$i = $183;
      }
     }
    }
    $184 = Math_fround($186 - $185);
    $187 = Math_fround($189 - $188);
    $190 = Math_fround($192 - $191);
    $193 = $184 < Math_fround(9.99999997475242707878E-7);
    $194 = $187 < Math_fround(9.99999997475242707878E-7);
    $or$cond11$i = $193 | $194;
    $195 = $190 < Math_fround(9.99999997475242707878E-7);
    $or$cond12$i = $or$cond11$i | $195;
    $196 = ($197>>>0)<(3);
    $or$cond13$i = $or$cond12$i | $196;
    if (!($or$cond13$i)) {
     $243 = ($197|0)==(0);
     if ($243) {
      $$ph1186 = 0;
      break;
     } else {
      $$ph1084 = $44;$$ph1185 = $197;$$ph82 = $46;$$ph983 = $45;
      label = 35;
      break;
     }
    }
    $198 = Math_fround($184 * Math_fround(0.5));
    $199 = Math_fround($185 + $198);
    $200 = Math_fround($187 * Math_fround(0.5));
    $201 = Math_fround($188 + $200);
    $202 = Math_fround($190 * Math_fround(0.5));
    $203 = Math_fround($191 + $202);
    $204 = $184 >= Math_fround(9.99999997475242707878E-7);
    $205 = $184 < Math_fround(3.40282346638528859812E+38);
    $or$cond14$i = $204 & $205;
    $len15$0$i = $or$cond14$i ? $184 : Math_fround(3.40282346638528859812E+38);
    $206 = $187 >= Math_fround(9.99999997475242707878E-7);
    $207 = $187 < $len15$0$i;
    $or$cond15$i = $206 & $207;
    $len15$1$i = $or$cond15$i ? $187 : $len15$0$i;
    $208 = $190 >= Math_fround(9.99999997475242707878E-7);
    $209 = $190 < $len15$1$i;
    $or$cond16$i = $208 & $209;
    $len15$2$i = $or$cond16$i ? $190 : $len15$1$i;
    $210 = $len15$2$i == Math_fround(3.40282346638528859812E+38);
    if ($210) {
     $dx12$1$i = Math_fround(0.00999999977648258209228);$dy13$1$i = Math_fround(0.00999999977648258209228);$dz14$0$i = Math_fround(0.00999999977648258209228);
    } else {
     if ($193) {
      $211 = Math_fround($len15$2$i * Math_fround(0.0500000007450580596924));
      $dx12$0$i = $211;
     } else {
      $dx12$0$i = $184;
     }
     if ($194) {
      $212 = Math_fround($len15$2$i * Math_fround(0.0500000007450580596924));
      $dy13$0$i = $212;
     } else {
      $dy13$0$i = $187;
     }
     if ($195) {
      $213 = Math_fround($len15$2$i * Math_fround(0.0500000007450580596924));
      $dx12$1$i = $dx12$0$i;$dy13$1$i = $dy13$0$i;$dz14$0$i = $213;
     } else {
      $dx12$1$i = $dx12$0$i;$dy13$1$i = $dy13$0$i;$dz14$0$i = $190;
     }
    }
    $214 = Math_fround($199 - $dx12$1$i);
    $215 = Math_fround($199 + $dx12$1$i);
    $216 = Math_fround($201 - $dy13$1$i);
    $217 = Math_fround($201 + $dy13$1$i);
    $218 = Math_fround($203 - $dz14$0$i);
    $219 = Math_fround($203 + $dz14$0$i);
    HEAPF32[$10>>2] = $214;
    $220 = (($10) + 4|0);
    HEAPF32[$220>>2] = $216;
    $221 = (($10) + 8|0);
    HEAPF32[$221>>2] = $218;
    $222 = (($10) + 12|0);
    HEAPF32[$222>>2] = $215;
    $223 = (($10) + 16|0);
    HEAPF32[$223>>2] = $216;
    $224 = (($10) + 20|0);
    HEAPF32[$224>>2] = $218;
    $225 = (($10) + 24|0);
    HEAPF32[$225>>2] = $215;
    $226 = (($10) + 28|0);
    HEAPF32[$226>>2] = $217;
    $227 = (($10) + 32|0);
    HEAPF32[$227>>2] = $218;
    $228 = (($10) + 36|0);
    HEAPF32[$228>>2] = $214;
    $229 = (($10) + 40|0);
    HEAPF32[$229>>2] = $217;
    $230 = (($10) + 44|0);
    HEAPF32[$230>>2] = $218;
    $231 = (($10) + 48|0);
    HEAPF32[$231>>2] = $214;
    $232 = (($10) + 52|0);
    HEAPF32[$232>>2] = $216;
    $233 = (($10) + 56|0);
    HEAPF32[$233>>2] = $219;
    $234 = (($10) + 60|0);
    HEAPF32[$234>>2] = $215;
    $235 = (($10) + 64|0);
    HEAPF32[$235>>2] = $216;
    $236 = (($10) + 68|0);
    HEAPF32[$236>>2] = $219;
    $237 = (($10) + 72|0);
    HEAPF32[$237>>2] = $215;
    $238 = (($10) + 76|0);
    HEAPF32[$238>>2] = $217;
    $239 = (($10) + 80|0);
    HEAPF32[$239>>2] = $219;
    $240 = (($10) + 84|0);
    HEAPF32[$240>>2] = $214;
    $241 = (($10) + 88|0);
    HEAPF32[$241>>2] = $217;
    $242 = (($10) + 92|0);
    HEAPF32[$242>>2] = $219;
    $$ph1084 = $44;$$ph1185 = 8;$$ph82 = $46;$$ph983 = $45;
    label = 35;
   }
  } while(0);
  if ((label|0) == 35) {
   $i$023 = 0;
   while(1) {
    $244 = ($i$023*3)|0;
    $245 = (($10) + ($244<<2)|0);
    $246 = Math_fround(HEAPF32[$245>>2]);
    $247 = Math_fround($$ph1084 * $246);
    HEAPF32[$245>>2] = $247;
    $$sum = (($244) + 1)|0;
    $248 = (($10) + ($$sum<<2)|0);
    $249 = Math_fround(HEAPF32[$248>>2]);
    $250 = Math_fround($$ph983 * $249);
    HEAPF32[$248>>2] = $250;
    $$sum1 = (($244) + 2)|0;
    $251 = (($10) + ($$sum1<<2)|0);
    $252 = Math_fround(HEAPF32[$251>>2]);
    $253 = Math_fround($$ph82 * $252);
    HEAPF32[$251>>2] = $253;
    $254 = (($i$023) + 1)|0;
    $exitcond = ($254|0)==($$ph1185|0);
    if ($exitcond) {
     $$ph1186 = $$ph1185;
     break;
    } else {
     $i$023 = $254;
    }
   }
  }
  $255 = HEAP32[$desc>>2]|0;
  $256 = $255 & 4;
  $257 = ($256|0)==(0);
  if ($257) {
   $skinwidth$0 = Math_fround(0.0);
  } else {
   $258 = (($desc) + 20|0);
   $259 = Math_fround(HEAPF32[$258>>2]);
   $skinwidth$0 = $259;
  }
  $260 = (($desc) + 24|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = (($desc) + 28|0);
  $263 = HEAP32[$262>>2]|0;
  $264 = (__ZN5physx11HullLibrary11ComputeHullEjPKfRNS_11PHullResultEjff($this,$$ph1186,$10,$hr,$263,$skinwidth$0,$261)|0);
  $265 = ($264|0)==(0);
  if ($265) {
   $266 = HEAP32[$hr>>2]|0;
   $267 = ($266*12)|0;
   $268 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$267,534392,2626)|0);
   $269 = (($hr) + 12|0);
   $270 = HEAP32[$269>>2]|0;
   $271 = (($hr) + 16|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = (($hr) + 4|0);
   $274 = HEAP32[$273>>2]|0;
   $$arith14 = $266<<2;
   $$overflow15 = ($266>>>0)>(1073741823);
   $275 = $$overflow15 ? -1 : $$arith14;
   $276 = ($275|0)==(0);
   if ($276) {
    $288 = 0;
   } else {
    $277 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = (($278) + 8|0);
    $280 = HEAP32[$279>>2]|0;
    $281 = (__Z15PxGetFoundationv()|0);
    $282 = HEAP32[$281>>2]|0;
    $283 = (($282) + 24|0);
    $284 = HEAP32[$283>>2]|0;
    $285 = (FUNCTION_TABLE_ii[$284 & 4095]($281)|0);
    $$$i$i$i$i = $285 ? 534600 : 534480;
    $286 = (FUNCTION_TABLE_iiiiii[$280 & 255]($277,$275,$$$i$i$i$i,534392,2287)|0);
    $288 = $286;
   }
   $287 = $266 << 2;
   _memset(($288|0),0,($287|0))|0;
   $289 = ($274|0)==(0);
   if ($289) {
    $318 = 0;
   } else {
    $296 = 0;$i$01$i = 0;
    while(1) {
     $290 = (($272) + ($i$01$i<<2)|0);
     $291 = HEAP32[$290>>2]|0;
     $292 = (($288) + ($291<<2)|0);
     $293 = HEAP32[$292>>2]|0;
     $294 = ($293|0)==(0);
     if ($294) {
      HEAP32[$290>>2] = $296;
      $297 = ($291*3)|0;
      $298 = (($270) + ($297<<2)|0);
      $299 = Math_fround(HEAPF32[$298>>2]);
      $300 = ($296*3)|0;
      $301 = (($268) + ($300<<2)|0);
      HEAPF32[$301>>2] = $299;
      $302 = (($297) + 1)|0;
      $303 = (($270) + ($302<<2)|0);
      $304 = Math_fround(HEAPF32[$303>>2]);
      $305 = (($300) + 1)|0;
      $306 = (($268) + ($305<<2)|0);
      HEAPF32[$306>>2] = $304;
      $307 = (($297) + 2)|0;
      $308 = (($270) + ($307<<2)|0);
      $309 = Math_fround(HEAPF32[$308>>2]);
      $310 = (($300) + 2)|0;
      $311 = (($268) + ($310<<2)|0);
      HEAPF32[$311>>2] = $309;
      $312 = (($296) + 1)|0;
      HEAP32[$292>>2] = $312;
      $451 = $312;
     } else {
      $295 = (($293) + -1)|0;
      HEAP32[$290>>2] = $295;
      $451 = $296;
     }
     $313 = (($i$01$i) + 1)|0;
     $exitcond$i3 = ($313|0)==($274|0);
     if ($exitcond$i3) {
      $318 = $451;
      break;
     } else {
      $296 = $451;$i$01$i = $313;
     }
    }
   }
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$288);
   $314 = HEAP32[$desc>>2]|0;
   $315 = $314 & 1;
   $316 = ($315|0)==(0);
   do {
    if ($316) {
     HEAP8[$result>>0] = 1;
     $377 = (($result) + 4|0);
     HEAP32[$377>>2] = $318;
     $378 = ($318*3)|0;
     $$arith2 = $378<<2;
     $$overflow3 = ($378>>>0)>(1073741823);
     $379 = $$overflow3 ? -1 : $$arith2;
     $380 = ($379|0)==(0);
     if ($380) {
      $392 = 0;
     } else {
      $381 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $382 = HEAP32[$381>>2]|0;
      $383 = (($382) + 8|0);
      $384 = HEAP32[$383>>2]|0;
      $385 = (__Z15PxGetFoundationv()|0);
      $386 = HEAP32[$385>>2]|0;
      $387 = (($386) + 24|0);
      $388 = HEAP32[$387>>2]|0;
      $389 = (FUNCTION_TABLE_ii[$388 & 4095]($385)|0);
      $$$i$i$i5 = $389 ? 534512 : 534480;
      $390 = (FUNCTION_TABLE_iiiiii[$384 & 255]($381,$379,$$$i$i$i5,534392,2666)|0);
      $392 = $390;
     }
     $391 = (($result) + 8|0);
     HEAP32[$391>>2] = $392;
     $393 = (($hr) + 8|0);
     $394 = HEAP32[$393>>2]|0;
     $395 = (($result) + 12|0);
     HEAP32[$395>>2] = $394;
     $396 = (($394) + ($274))|0;
     $397 = (($result) + 16|0);
     HEAP32[$397>>2] = $396;
     $$arith = $396<<2;
     $$overflow = ($396>>>0)>(1073741823);
     $398 = $$overflow ? -1 : $$arith;
     $399 = ($398|0)==(0);
     if ($399) {
      $411 = 0;$413 = $392;
     } else {
      $400 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $401 = HEAP32[$400>>2]|0;
      $402 = (($401) + 8|0);
      $403 = HEAP32[$402>>2]|0;
      $404 = (__Z15PxGetFoundationv()|0);
      $405 = HEAP32[$404>>2]|0;
      $406 = (($405) + 24|0);
      $407 = HEAP32[$406>>2]|0;
      $408 = (FUNCTION_TABLE_ii[$407 & 4095]($404)|0);
      $$$i$i$i7 = $408 ? 534600 : 534480;
      $409 = (FUNCTION_TABLE_iiiiii[$403 & 255]($400,$398,$$$i$i$i7,534392,2669)|0);
      $$pre = HEAP32[$391>>2]|0;
      $411 = $409;$413 = $$pre;
     }
     $410 = (($result) + 20|0);
     HEAP32[$410>>2] = $411;
     $412 = ($318*12)|0;
     _memcpy(($413|0),($268|0),($412|0))|0;
     $414 = HEAP32[$393>>2]|0;
     $415 = ($414|0)==(0);
     if ($415) {
      $$pre79$pre = HEAP32[$271>>2]|0;
      $$pre79 = $$pre79$pre;
     } else {
      $416 = HEAP32[$410>>2]|0;
      $417 = HEAP32[$271>>2]|0;
      $dest3$016 = $416;$i4$017 = 0;$source2$015 = $417;
      while(1) {
       HEAP32[$dest3$016>>2] = 3;
       $418 = HEAP32[$desc>>2]|0;
       $419 = $418 & 2;
       $420 = ($419|0)==(0);
       if ($420) {
        $429 = HEAP32[$source2$015>>2]|0;
        $430 = (($dest3$016) + 4|0);
        HEAP32[$430>>2] = $429;
        $431 = (($source2$015) + 4|0);
        $432 = HEAP32[$431>>2]|0;
        $433 = (($dest3$016) + 8|0);
        HEAP32[$433>>2] = $432;
        $434 = (($source2$015) + 8|0);
        $435 = HEAP32[$434>>2]|0;
        $436 = (($dest3$016) + 12|0);
        HEAP32[$436>>2] = $435;
       } else {
        $421 = (($source2$015) + 8|0);
        $422 = HEAP32[$421>>2]|0;
        $423 = (($dest3$016) + 4|0);
        HEAP32[$423>>2] = $422;
        $424 = (($source2$015) + 4|0);
        $425 = HEAP32[$424>>2]|0;
        $426 = (($dest3$016) + 8|0);
        HEAP32[$426>>2] = $425;
        $427 = HEAP32[$source2$015>>2]|0;
        $428 = (($dest3$016) + 12|0);
        HEAP32[$428>>2] = $427;
       }
       $437 = (($dest3$016) + 16|0);
       $438 = (($source2$015) + 12|0);
       $439 = (($i4$017) + 1)|0;
       $440 = HEAP32[$393>>2]|0;
       $441 = ($439>>>0)<($440>>>0);
       if ($441) {
        $dest3$016 = $437;$i4$017 = $439;$source2$015 = $438;
       } else {
        $$pre79 = $417;
        break;
       }
      }
     }
     $$pre78 = HEAP32[$269>>2]|0;
     $443 = $$pre78;$444 = $$pre79;
    } else {
     HEAP8[$result>>0] = 0;
     $317 = (($result) + 4|0);
     HEAP32[$317>>2] = $318;
     $319 = ($318*3)|0;
     $$arith10 = $319<<2;
     $$overflow11 = ($319>>>0)>(1073741823);
     $320 = $$overflow11 ? -1 : $$arith10;
     $321 = ($320|0)==(0);
     if ($321) {
      $333 = 0;
     } else {
      $322 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $323 = HEAP32[$322>>2]|0;
      $324 = (($323) + 8|0);
      $325 = HEAP32[$324>>2]|0;
      $326 = (__Z15PxGetFoundationv()|0);
      $327 = HEAP32[$326>>2]|0;
      $328 = (($327) + 24|0);
      $329 = HEAP32[$328>>2]|0;
      $330 = (FUNCTION_TABLE_ii[$329 & 4095]($326)|0);
      $$$i$i$i = $330 ? 534512 : 534480;
      $331 = (FUNCTION_TABLE_iiiiii[$325 & 255]($322,$320,$$$i$i$i,534392,2635)|0);
      $333 = $331;
     }
     $332 = (($result) + 8|0);
     HEAP32[$332>>2] = $333;
     $334 = (($hr) + 8|0);
     $335 = HEAP32[$334>>2]|0;
     $336 = (($result) + 12|0);
     HEAP32[$336>>2] = $335;
     $337 = (($result) + 16|0);
     HEAP32[$337>>2] = $274;
     $$arith6 = $274<<2;
     $$overflow7 = ($274>>>0)>(1073741823);
     $338 = $$overflow7 ? -1 : $$arith6;
     $339 = ($338|0)==(0);
     if ($339) {
      $351 = 0;$353 = $333;
     } else {
      $340 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
      $341 = HEAP32[$340>>2]|0;
      $342 = (($341) + 8|0);
      $343 = HEAP32[$342>>2]|0;
      $344 = (__Z15PxGetFoundationv()|0);
      $345 = HEAP32[$344>>2]|0;
      $346 = (($345) + 24|0);
      $347 = HEAP32[$346>>2]|0;
      $348 = (FUNCTION_TABLE_ii[$347 & 4095]($344)|0);
      $$$i$i$i4 = $348 ? 534600 : 534480;
      $349 = (FUNCTION_TABLE_iiiiii[$343 & 255]($340,$338,$$$i$i$i4,534392,2639)|0);
      $$pre80 = HEAP32[$332>>2]|0;
      $351 = $349;$353 = $$pre80;
     }
     $350 = (($result) + 20|0);
     HEAP32[$350>>2] = $351;
     $352 = ($318*12)|0;
     _memcpy(($353|0),($268|0),($352|0))|0;
     $354 = HEAP32[$desc>>2]|0;
     $355 = $354 & 2;
     $356 = ($355|0)==(0);
     if ($356) {
      $373 = HEAP32[$350>>2]|0;
      $374 = HEAP32[$271>>2]|0;
      $375 = HEAP32[$273>>2]|0;
      $376 = $375 << 2;
      _memcpy(($373|0),($374|0),($376|0))|0;
      $443 = $270;$444 = $374;
      break;
     }
     $357 = HEAP32[$334>>2]|0;
     $358 = ($357|0)==(0);
     if ($358) {
      $443 = $270;$444 = $272;
     } else {
      $359 = HEAP32[$350>>2]|0;
      $360 = HEAP32[$271>>2]|0;
      $dest$020 = $359;$i1$021 = 0;$source$019 = $360;
      while(1) {
       $361 = (($source$019) + 8|0);
       $362 = HEAP32[$361>>2]|0;
       HEAP32[$dest$020>>2] = $362;
       $363 = (($source$019) + 4|0);
       $364 = HEAP32[$363>>2]|0;
       $365 = (($dest$020) + 4|0);
       HEAP32[$365>>2] = $364;
       $366 = HEAP32[$source$019>>2]|0;
       $367 = (($dest$020) + 8|0);
       HEAP32[$367>>2] = $366;
       $368 = (($dest$020) + 12|0);
       $369 = (($source$019) + 12|0);
       $370 = (($i1$021) + 1)|0;
       $371 = HEAP32[$334>>2]|0;
       $372 = ($370>>>0)<($371>>>0);
       if ($372) {
        $dest$020 = $368;$i1$021 = $370;$source$019 = $369;
       } else {
        $443 = $270;$444 = $360;
        break;
       }
      }
     }
    }
   } while(0);
   $442 = ($443|0)==($10|0);
   $$ = $442 ? 0 : $10;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$444);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$443);
   HEAP32[$hr>>2] = 0;
   HEAP32[$273>>2] = 0;
   $445 = $269;
   $446 = $445;
   HEAP32[$446>>2] = 0;
   $447 = (($445) + 4)|0;
   $448 = $447;
   HEAP32[$448>>2] = 0;
   $449 = ($268|0)==(0|0);
   if ($449) {
    $ret$0 = 0;$vsource$1 = $$;
   } else {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$268);
    $ret$0 = 0;$vsource$1 = $$;
   }
  } else {
   $ret$0 = $264;$vsource$1 = $10;
  }
 }
 $450 = ($vsource$1|0)==(0|0);
 if ($450) {
  STACKTOP = sp;return ($ret$0|0);
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$vsource$1);
 STACKTOP = sp;return ($ret$0|0);
}
function __ZN5physx11HullLibrary13ReleaseResultERNS_10HullResultE($this,$result) {
 $this = $this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($result) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$3);
  HEAP32[$2>>2] = 0;
 }
 $5 = (($result) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return 0;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$6);
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return 0;
}
function __ZN5physx13PxProfileZone17createProfileZoneEPNS_12PxFoundationEPKcRNS_21PxProfileNameProviderEj($inFoundation,$inSDKName,$inProvider,$inEventBufferByteSize) {
 $inFoundation = $inFoundation|0;
 $inSDKName = $inSDKName|0;
 $inProvider = $inProvider|0;
 $inEventBufferByteSize = $inEventBufferByteSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theCallback$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$inProvider>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$inProvider);
 $5 = $1;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = ($inFoundation|0)==(0|0);
 if ($11) {
  $theCallback$0$i = 0;
 } else {
  $12 = HEAP32[$inFoundation>>2]|0;
  $13 = (($12) + 16|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($inFoundation)|0);
  $theCallback$0$i = $15;
 }
 $16 = HEAP32[$theCallback$0$i>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_iiiiii[$18 & 255]($theCallback$0$i,288,535200,535024,149)|0);
 $20 = ($19|0)==(0|0);
 if ($20) {
  $26 = 0;
  $25 = (($26) + 116|0);
  STACKTOP = sp;return ($25|0);
 }
 $21 = $0;
 $22 = $21;
 HEAP32[$22>>2] = $7;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $10;
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEEC2EPNS_19PxAllocatorCallbackEPKcjRKS2_($19,$theCallback$0$i,$inSDKName,$inEventBufferByteSize,$0);
 $26 = $19;
 $25 = (($26) + 116|0);
 STACKTOP = sp;return ($25|0);
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEEC2EPNS_19PxAllocatorCallbackEPKcjRKS2_($this,$inAllocator,$inName,$bufferSize,$inProvider) {
 $this = $this|0;
 $inAllocator = $inAllocator|0;
 $inName = $inName|0;
 $bufferSize = $bufferSize|0;
 $inProvider = $inProvider|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $exitcond = 0, $idx$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEEC2EPNS_19PxAllocatorCallbackEjRKS2_PS7_RKSA_($this,$inAllocator,$bufferSize,0,0,0);
 $1 = (($this) + 116|0);
 $2 = (($this) + 120|0);
 $3 = (($this) + 124|0);
 $4 = (($this) + 128|0);
 $5 = (($this) + 132|0);
 HEAP32[$this>>2] = ((535240 + 8|0));
 HEAP32[$1>>2] = ((535240 + 112|0));
 HEAP32[$2>>2] = ((535240 + 168|0));
 HEAP32[$3>>2] = ((535240 + 188|0));
 HEAP32[$4>>2] = ((535240 + 228|0));
 HEAP32[$5>>2] = ((535240 + 248|0));
 $6 = (($this) + 136|0);
 HEAP32[$6>>2] = $inName;
 $7 = (($this) + 140|0);
 HEAP32[$7>>2] = $inAllocator;
 $8 = (($this) + 144|0);
 HEAP32[$8>>2] = $7;
 $9 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$8>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_iiiiii[$15 & 255]($12,$10,535200,535704,111)|0);
 $17 = (($this) + 148|0);
 HEAP32[$17>>2] = $16;
 $18 = ($16|0)==(0|0);
 if (!($18)) {
  __ZN5physx6shdfnd9MutexImplC2Ev($16);
 }
 $19 = (($this) + 152|0);
 HEAP32[$19>>2] = $7;
 $20 = (($this) + 156|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 160|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 164|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 168|0);
 HEAP32[$23>>2] = $7;
 $24 = (($this) + 172|0);
 $25 = (($this) + 196|0);
 ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;HEAP32[$24+16>>2]=0|0;HEAP32[$24+20>>2]=0|0;
 HEAPF32[$25>>2] = Math_fround(0.75);
 $26 = (($this) + 200|0);
 HEAP32[$26>>2] = -1;
 $27 = (($this) + 204|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 208|0);
 HEAP32[$28>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS_7profile26WrapperReflectionAllocatorIjEEE6GetKeyESD_Lb1EE15reserveInternalEj($23,64);
 $29 = (($this) + 212|0);
 HEAP32[$29>>2] = $7;
 $30 = (($this) + 216|0);
 $31 = (($this) + 240|0);
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP32[$30+16>>2]=0|0;HEAP32[$30+20>>2]=0|0;
 HEAPF32[$31>>2] = Math_fround(0.75);
 $32 = (($this) + 244|0);
 HEAP32[$32>>2] = -1;
 $33 = (($this) + 248|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 252|0);
 HEAP32[$34>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE15reserveInternalEj($29,64);
 $35 = (($this) + 256|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 260|0);
 HEAP32[$36>>2] = $7;
 $37 = (($this) + 264|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 268|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 272|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 276|0);
 HEAP8[$40>>0] = 0;
 $41 = (($this) + 280|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 72|0);
 HEAP32[$42>>2] = $8;
 $43 = $inProvider;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = $48;
 $50 = ($45|0)==(0);
 if ($50) {
  $61 = $8;$79 = $0;
  label = 7;
 } else {
  $idx$01 = 0;
  while(1) {
   $51 = (($49) + ($idx$01<<3)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($49) + ($idx$01<<3)|0) + 4|0);
   $54 = HEAP16[$53>>1]|0;
   $55 = ((($49) + ($idx$01<<3)|0) + 6|0);
   $56 = HEAP8[$55>>0]|0;
   $57 = ($56<<24>>24)!=(0);
   __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9doAddNameEPKctb($this,$52,$54,$57);
   $58 = (($idx$01) + 1)|0;
   $exitcond = ($58|0)==($45|0);
   if ($exitcond) {
    break;
   } else {
    $idx$01 = $58;
   }
  }
  $$pre = HEAP32[$42>>2]|0;
  $59 = ($$pre|0)==(0|0);
  if ($59) {
   $77 = 0;$80 = 1;$81 = $0;
  } else {
   $61 = $$pre;$79 = $0;
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $60 = (($61) + 4|0);
  $62 = HEAP32[$60>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($62);
  $77 = $61;$80 = 0;$81 = $79;
 }
 HEAP32[$0>>2] = $5;
 $63 = (($this) + 40|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 & 2147483647;
 $66 = (($this) + 36|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($65>>>0)>($67>>>0);
 if ($68) {
  $70 = (($this) + 32|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($71) + ($67<<2)|0);
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   HEAP32[$72>>2] = $5;
  }
  $74 = (($67) + 1)|0;
  HEAP32[$66>>2] = $74;
 } else {
  $69 = (($this) + 28|0);
  (__ZN5physx6shdfnd5ArrayIPNS_26PxProfileEventBufferClientENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($69,$0)|0);
 }
 $75 = (($this) + 76|0);
 HEAP8[$75>>0] = 1;
 if ($80) {
  STACKTOP = sp;return;
 }
 $76 = (($77) + 4|0);
 $78 = HEAP32[$76>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($78);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEEC2EPNS_19PxAllocatorCallbackEjRKS2_PS7_RKSA_($this,$inFoundation,$inBufferFullAmount,$inProvider,$inBufferMutex,$inEventFilter) {
 $this = $this|0;
 $inFoundation = $inFoundation|0;
 $inBufferFullAmount = $inBufferFullAmount|0;
 $inProvider = $inProvider|0;
 $inBufferMutex = $inBufferMutex|0;
 $inEventFilter = $inEventFilter|0;
 var $$0$i$i$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((535504 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $inFoundation;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 535784;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = $0;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = $inBufferFullAmount;
 $11 = (($this) + 72|0);
 HEAP32[$11>>2] = $inBufferMutex;
 $12 = (($this) + 76|0);
 HEAP8[$12>>0] = 0;
 $13 = (($this) + 80|0);
 HEAP32[$13>>2] = $1;
 $14 = (($inBufferFullAmount) + 68)|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = HEAP32[$3>>2]|0;
 $17 = $15;
 $18 = $16;
 $19 = (($17) - ($18))|0;
 $20 = HEAP32[$5>>2]|0;
 $21 = $20;
 $22 = (($21) - ($18))|0;
 $23 = ($22>>>0)>($14>>>0);
 if ($23) {
  HEAP32[$this>>2] = ((535824 + 8|0));
  $44 = (($this) + 88|0);
  dest=$44+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $24 = $14 << 1;
 $25 = ($24|0)==(0);
 if ($25) {
  $$0$i$i$i = 0;$34 = $16;
 } else {
  $26 = HEAP32[$1>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$2>>2]|0;
  $32 = (FUNCTION_TABLE_iiiiii[$30 & 255]($27,$24,$31,535536,117)|0);
  $$pre$i$i = HEAP32[$3>>2]|0;
  $$0$i$i$i = $32;$34 = $$pre$i$i;
 }
 $33 = ($34|0)==(0|0);
 if (!($33)) {
  _memcpy(($$0$i$i$i|0),($34|0),($19|0))|0;
  $35 = HEAP32[$3>>2]|0;
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   $37 = HEAP32[$1>>2]|0;
   $38 = HEAP32[$37>>2]|0;
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   FUNCTION_TABLE_vii[$41 & 4095]($38,$35);
  }
 }
 HEAP32[$3>>2] = $$0$i$i$i;
 $42 = (($$0$i$i$i) + ($19)|0);
 HEAP32[$4>>2] = $42;
 $43 = (($$0$i$i$i) + ($24)|0);
 HEAP32[$5>>2] = $43;
 HEAP32[$this>>2] = ((535824 + 8|0));
 $44 = (($this) + 88|0);
 dest=$44+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9doAddNameEPKctb($this,$inName,$inEventId,$inCompileTimeEnabled) {
 $this = $this|0;
 $inName = $inName|0;
 $inEventId = $inEventId|0;
 $inCompileTimeEnabled = $inCompileTimeEnabled|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exists$i1 = 0, $or$cond$i = 0, $or$cond$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $exists$i1 = sp + 12|0;
 $1 = sp;
 $2 = (($this) + 148|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($3);
 HEAP16[$0>>1] = $inEventId;
 $4 = (($this) + 212|0);
 $5 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($4,$0,$exists$i1)|0);
 $6 = HEAP8[$exists$i1>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = ($5|0)==(0|0);
 $or$cond$i = $7 | $8;
 if (!($or$cond$i)) {
  $9 = HEAP16[$0>>1]|0;
  HEAP16[$5>>1] = $9;
  $10 = (($5) + 4|0);
  HEAP32[$10>>2] = $inName;
 }
 $11 = (($this) + 152|0);
 $12 = (($this) + 160|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$0>>2] = $inName;
 $14 = (($this) + 168|0);
 $15 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcjEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_jS9_NS_7profile26WrapperReflectionAllocatorIjEEE6GetKeyESD_Lb1EE6createERS6_Rb($14,$0,$exists$i1)|0);
 $16 = HEAP8[$exists$i1>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = ($15|0)==(0|0);
 $or$cond$i2 = $17 | $18;
 if (!($or$cond$i2)) {
  $19 = HEAP32[$0>>2]|0;
  HEAP32[$15>>2] = $19;
  $20 = (($15) + 4|0);
  HEAP32[$20>>2] = $13;
 }
 $21 = $inCompileTimeEnabled&1;
 $22 = $21 << 16;
 $23 = $inEventId&65535;
 $24 = $22 | $23;
 HEAP32[$1>>2] = $inName;
 $25 = (($1) + 4|0);
 HEAP32[$25>>2] = $24;
 $26 = (($this) + 164|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 & 2147483647;
 $29 = HEAP32[$12>>2]|0;
 $30 = ($28>>>0)>($29>>>0);
 if (!($30)) {
  (__ZN5physx6shdfnd5ArrayINS_18PxProfileEventNameENS_7profile26WrapperReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($11,$1)|0);
  $47 = HEAP32[$2>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($47);
  STACKTOP = sp;return;
 }
 $31 = (($this) + 156|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($29<<3)|0);
 $34 = ($33|0)==(0|0);
 if ($34) {
  $46 = $29;
 } else {
  $35 = $1;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + 4)|0;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = $33;
  $42 = $41;
  HEAP32[$42>>2] = $37;
  $43 = (($41) + 4)|0;
  $44 = $43;
  HEAP32[$44>>2] = $40;
  $$pre$i = HEAP32[$12>>2]|0;
  $46 = $$pre$i;
 }
 $45 = (($46) + 1)|0;
 HEAP32[$12>>2] = $45;
 $47 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($47);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEE11flushEventsEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $idx$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($4);
 }
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $6;
 $11 = (($9) - ($10))|0;
 $12 = (($this) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $23 = $6;
 } else {
  $15 = (($this) + 32|0);
  $idx$01$i = 0;
  while(1) {
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($idx$01$i<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_viii[$21 & 4095]($18,$6,$11);
   $22 = (($idx$01$i) + 1)|0;
   $exitcond$i = ($22|0)==($13|0);
   if ($exitcond$i) {
    break;
   } else {
    $idx$01$i = $22;
   }
  }
  $$pre = HEAP32[$5>>2]|0;
  $23 = $$pre;
 }
 HEAP32[$7>>2] = $23;
 $24 = HEAP32[$this>>2]|0;
 $25 = (($24) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vi[$26 & 4095]($this);
 if ($2) {
  STACKTOP = sp;return;
 }
 $27 = (($1) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($28);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17handleBufferFlushEPKhj($this,$inData,$inLength) {
 $this = $this|0;
 $inData = $inData|0;
 $inLength = $inLength|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $idx$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 148|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 268|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $13 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($13);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 264|0);
 $idx$01 = 0;
 while(1) {
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($idx$01<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viii[$11 & 4095]($8,$inData,$inLength);
  $12 = (($idx$01) + 1)|0;
  $exitcond = ($12|0)==($3|0);
  if ($exitcond) {
   break;
  } else {
   $idx$01 = $12;
  }
 }
 $13 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($13);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE15clearCachedDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 88|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
 $2 = (($this) + 104|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21setUserCustomProfilerEPNS_20PxUserCustomProfilerE($this,$up) {
 $this = $this|0;
 $up = $up|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 HEAP32[$0>>2] = $up;
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17getEventIdForNameEPKc($this,$inName) {
 $this = $this|0;
 $inName = $inName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $inName;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$3 & 2047]($this,$0,1)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19getEventIdsForNamesEPPKcj($this,$inNames,$inLen) {
 $this = $this|0;
 $inNames = $inNames|0;
 $inLen = $inLen|0;
 var $$0 = 0, $$0$i$i6 = 0, $$not = 0, $$not$us = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $brmerge = 0, $clientIdx$09$us = 0, $eventId$0 = 0, $exitcond = 0, $h$0$lcssa$i$i$i$i$i = 0, $h$01$i$i$i$i$i = 0, $idx$015 = 0, $idx$015$us = 0, $index$0$i$i = 0, $index$0$i$i5 = 0, $index$02$i$i = 0, $index$02$i$i2 = 0, $index$03$i$i = 0, $index$03$i$i4 = 0, $nameIdx$010 = 0, $nameIdx$010$us = 0, $phitmp = 0, $phitmp28 = 0, $ptr$02$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = ($inLen|0)==(0);
 if ($3) {
  $$0 = 0;
  $115 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($115);
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 192|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 L4: do {
  if (!($6)) {
   $7 = HEAP32[$inNames>>2]|0;
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   if ($9) {
    $h$0$lcssa$i$i$i$i$i = 5381;
   } else {
    $12 = $8;$h$01$i$i$i$i$i = 5381;$ptr$02$i$i$i$i$i = $7;
    while(1) {
     $10 = ($h$01$i$i$i$i$i*33)|0;
     $11 = $12 << 24 >> 24;
     $13 = $10 ^ $11;
     $14 = (($ptr$02$i$i$i$i$i) + 1|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = ($15<<24>>24)==(0);
     if ($16) {
      $h$0$lcssa$i$i$i$i$i = $13;
      break;
     } else {
      $12 = $15;$h$01$i$i$i$i$i = $13;$ptr$02$i$i$i$i$i = $14;
     }
    }
   }
   $17 = (($5) + -1)|0;
   $18 = $h$0$lcssa$i$i$i$i$i & $17;
   $19 = (($this) + 184|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + ($18<<2)|0);
   $index$02$i$i = HEAP32[$21>>2]|0;
   $22 = ($index$02$i$i|0)==(-1);
   if (!($22)) {
    $23 = (($this) + 176|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($this) + 180|0);
    $index$03$i$i = $index$02$i$i;
    while(1) {
     $26 = (($24) + ($index$03$i$i<<3)|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (_strcmp($27,$7)|0);
     $29 = ($28|0)==(0);
     if ($29) {
      break;
     }
     $30 = HEAP32[$25>>2]|0;
     $31 = (($30) + ($index$03$i$i<<2)|0);
     $index$0$i$i = HEAP32[$31>>2]|0;
     $32 = ($index$0$i$i|0)==(-1);
     if ($32) {
      break L4;
     } else {
      $index$03$i$i = $index$0$i$i;
     }
    }
    $33 = ($26|0)==(0|0);
    if (!($33)) {
     $34 = ((($24) + ($index$03$i$i<<3)|0) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($this) + 156|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ((($37) + ($35<<3)|0) + 4|0);
     $39 = HEAP16[$38>>1]|0;
     $$0 = $39;
     $115 = HEAP32[$1>>2]|0;
     __ZN5physx6shdfnd9MutexImpl6unlockEv($115);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $40 = (($this) + 160|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41&65535;
 $43 = (($this) + 236|0);
 $44 = (($this) + 228|0);
 $45 = (($this) + 220|0);
 $46 = (($this) + 224|0);
 $eventId$0 = $42;
 while(1) {
  $47 = (($eventId$0) + 1)<<16>>16;
  $48 = $47&65535;
  $49 = HEAP32[$43>>2]|0;
  $50 = ($49|0)==(0);
  $51 = (($49) + -1)|0;
  if ($50) {
   $idx$015$us = 0;
   label = 13;
   break;
  } else {
   $55 = 0;$idx$015 = 0;
  }
  while(1) {
   $54 = (($55) + ($48))|0;
   $56 = $54&65535;
   $57 = $54 & 65535;
   $58 = $57 << 15;
   $59 = $58 ^ -1;
   $60 = (($57) + ($59))|0;
   $61 = $60 >>> 10;
   $62 = $61 ^ $60;
   $63 = ($62*9)|0;
   $64 = $63 >>> 6;
   $65 = $64 ^ $63;
   $66 = $65 << 11;
   $67 = $66 ^ -1;
   $68 = (($65) + ($67))|0;
   $69 = $68 >>> 16;
   $70 = $69 ^ $68;
   $71 = $51 & $70;
   $72 = HEAP32[$44>>2]|0;
   $73 = (($72) + ($71<<2)|0);
   $index$02$i$i2 = HEAP32[$73>>2]|0;
   $74 = ($index$02$i$i2|0)==(-1);
   L22: do {
    if ($74) {
     $$0$i$i6 = 0;
    } else {
     $75 = HEAP32[$45>>2]|0;
     $index$03$i$i4 = $index$02$i$i2;
     while(1) {
      $76 = (($75) + ($index$03$i$i4<<3)|0);
      $77 = HEAP16[$76>>1]|0;
      $78 = ($77<<16>>16)==($56<<16>>16);
      if ($78) {
       $$0$i$i6 = $76;
       break L22;
      }
      $79 = HEAP32[$46>>2]|0;
      $80 = (($79) + ($index$03$i$i4<<2)|0);
      $index$0$i$i5 = HEAP32[$80>>2]|0;
      $81 = ($index$0$i$i5|0)==(-1);
      if ($81) {
       $$0$i$i6 = 0;
       break;
      } else {
       $index$03$i$i4 = $index$0$i$i5;
      }
     }
    }
   } while(0);
   $82 = ($$0$i$i6|0)!=(0|0);
   $83 = (($idx$015) + 1)<<16>>16;
   $84 = $83&65535;
   $$not = ($84>>>0)>=($inLen>>>0);
   $brmerge = $$not | $82;
   if ($brmerge) {
    break;
   } else {
    $55 = $84;$idx$015 = $83;
   }
  }
  if ($82) {
   $eventId$0 = $47;
  } else {
   break;
  }
 }
 if ((label|0) == 13) {
  while(1) {
   label = 0;
   $52 = (($idx$015$us) + 1)<<16>>16;
   $53 = $52&65535;
   $$not$us = ($53>>>0)<($inLen>>>0);
   if ($$not$us) {
    $idx$015$us = $52;
    label = 13;
   } else {
    break;
   }
  }
 }
 $85 = (($this) + 268|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = $47&65535;
 $88 = ($86|0)==(0);
 $89 = (($this) + 264|0);
 $90 = (($0) + 4|0);
 if ($88) {
  $109 = 0;$nameIdx$010 = 1;
  while(1) {
   $108 = (($109) + ($87))|0;
   $110 = $108&65535;
   $111 = (($inNames) + ($109<<2)|0);
   $112 = HEAP32[$111>>2]|0;
   __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9doAddNameEPKctb($this,$112,$110,1);
   $113 = $nameIdx$010&65535;
   $114 = ($113>>>0)<($inLen>>>0);
   if (!($114)) {
    $$0 = $47;
    break;
   }
   $phitmp28 = (($nameIdx$010) + 1)<<16>>16;
   $109 = $113;$nameIdx$010 = $phitmp28;
  }
  $115 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($115);
  STACKTOP = sp;return ($$0|0);
 } else {
  $104 = 0;$nameIdx$010$us = 1;
 }
 while(1) {
  $103 = (($104) + ($87))|0;
  $105 = $103&65535;
  $100 = (($inNames) + ($104<<2)|0);
  $106 = HEAP32[$100>>2]|0;
  __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9doAddNameEPKctb($this,$106,$105,1);
  $107 = $103 & 65535;
  $101 = $107 | 65536;
  $clientIdx$09$us = 0;
  while(1) {
   $93 = HEAP32[$89>>2]|0;
   $94 = (($93) + ($clientIdx$09$us<<2)|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = HEAP32[$95>>2]|0;
   $97 = (($96) + 16|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = HEAP32[$100>>2]|0;
   HEAP32[$0>>2] = $99;
   HEAP32[$90>>2] = $101;
   FUNCTION_TABLE_vii[$98 & 4095]($95,$0);
   $102 = (($clientIdx$09$us) + 1)|0;
   $exitcond = ($102|0)==($86|0);
   if ($exitcond) {
    break;
   } else {
    $clientIdx$09$us = $102;
   }
  }
  $91 = $nameIdx$010$us&65535;
  $92 = ($91>>>0)<($inLen>>>0);
  if (!($92)) {
   $$0 = $47;
   break;
  }
  $phitmp = (($nameIdx$010$us) + 1)<<16>>16;
  $104 = $91;$nameIdx$010$us = $phitmp;
 }
 $115 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($115);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21setProfileZoneManagerEPNS_20PxProfileZoneManagerE($this,$inMgr) {
 $this = $this|0;
 $inMgr = $inMgr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 256|0);
 HEAP32[$0>>2] = $inMgr;
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21getProfileZoneManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 256|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9addClientERNS_19PxProfileZoneClientE($this,$inClient) {
 $this = $this|0;
 $inClient = $inClient|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 HEAP32[$0>>2] = $inClient;
 $3 = (($this) + 272|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = (($this) + 268|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if (!($8)) {
  $9 = (($this) + 260|0);
  (__ZN5physx6shdfnd5ArrayIPNS_19PxProfileZoneClientENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($9,$0)|0);
  $15 = (($this) + 276|0);
  HEAP8[$15>>0] = 1;
  $16 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($16);
  STACKTOP = sp;return;
 }
 $10 = (($this) + 264|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($7<<2)|0);
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  HEAP32[$12>>2] = $inClient;
 }
 $14 = (($7) + 1)|0;
 HEAP32[$6>>2] = $14;
 $15 = (($this) + 276|0);
 HEAP8[$15>>0] = 1;
 $16 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($16);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE12removeClientERNS_19PxProfileZoneClientE($this,$inClient) {
 $this = $this|0;
 $inClient = $inClient|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 148|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 268|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $22 = 0;
  } else {
   $5 = (($this) + 264|0);
   $6 = HEAP32[$5>>2]|0;
   $idx$04 = 0;
   while(1) {
    $9 = (($6) + ($idx$04<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($inClient|0);
    $8 = (($idx$04) + 1)|0;
    if ($11) {
     break;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $idx$04 = $8;
    } else {
     $22 = $3;
     break L1;
    }
   }
   $12 = HEAP32[$inClient>>2]|0;
   $13 = (($12) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vi[$14 & 4095]($inClient);
   $15 = HEAP32[$2>>2]|0;
   $16 = (($15) + -1)|0;
   HEAP32[$2>>2] = $16;
   $17 = HEAP32[$5>>2]|0;
   $18 = (($17) + ($16<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + ($idx$04<<2)|0);
   HEAP32[$20>>2] = $19;
   $22 = $16;
  }
 } while(0);
 $21 = ($22|0)!=(0);
 $23 = (($this) + 276|0);
 $24 = $21&1;
 HEAP8[$23>>0] = $24;
 $25 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($25);
 STACKTOP = sp;return;
}
function __ZNK5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10hasClientsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 276|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE15getProfileNamesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 148|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 156|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 160|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$agg$result>>2] = $5;
 $6 = (($agg$result) + 4|0);
 HEAP32[$6>>2] = $3;
 $7 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($7);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 $4 = HEAP32[$1>>2]|0;
 $5 = (($4) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($1,$this);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19handleClientRemovedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10startEventEty($this,$inId,$0,$1) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exists$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp + 2|0;
 $2 = sp;
 HEAP16[$2>>1] = $inId;
 $3 = (($this) + 280|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 212|0);
  $7 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($6,$2,$exists$i)|0);
  $8 = HEAP8[$exists$i>>0]|0;
  $9 = ($8<<24>>24)!=(0);
  $10 = ($7|0)==(0|0);
  $or$cond$i = $9 | $10;
  if ($or$cond$i) {
   $$pre$i = (($7) + 4|0);
   $$pre = HEAP32[$$pre$i>>2]|0;
   $16 = $$pre;
  } else {
   $11 = HEAP16[$2>>1]|0;
   HEAP16[$7>>1] = $11;
   $12 = (($7) + 4|0);
   HEAP32[$12>>2] = 0;
   $16 = 0;
  }
  $13 = HEAP32[$3>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_viiiii[$15 & 255]($13,$16,$0,$1,0);
 }
 $17 = (($this) + 276|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = HEAP16[$2>>1]|0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10startEventEty($this,$20,$0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9stopEventEty($this,$inId,$0,$1) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exists$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp + 2|0;
 $2 = sp;
 HEAP16[$2>>1] = $inId;
 $3 = (($this) + 280|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 212|0);
  $7 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($6,$2,$exists$i)|0);
  $8 = HEAP8[$exists$i>>0]|0;
  $9 = ($8<<24>>24)!=(0);
  $10 = ($7|0)==(0|0);
  $or$cond$i = $9 | $10;
  if ($or$cond$i) {
   $$pre$i = (($7) + 4|0);
   $$pre = HEAP32[$$pre$i>>2]|0;
   $17 = $$pre;
  } else {
   $11 = HEAP16[$2>>1]|0;
   HEAP16[$7>>1] = $11;
   $12 = (($7) + 4|0);
   HEAP32[$12>>2] = 0;
   $17 = 0;
  }
  $13 = HEAP32[$3>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiiii[$16 & 255]($13,$17,$0,$1,0);
 }
 $18 = (($this) + 276|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = HEAP16[$2>>1]|0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE9stopEventEty($this,$21,$0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10startEventEtyj($this,$inId,$0,$1,$threadId) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 $threadId = $threadId|0;
 var $$pre = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exists$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp + 2|0;
 $2 = sp;
 HEAP16[$2>>1] = $inId;
 $3 = (($this) + 280|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 212|0);
  $7 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($6,$2,$exists$i)|0);
  $8 = HEAP8[$exists$i>>0]|0;
  $9 = ($8<<24>>24)!=(0);
  $10 = ($7|0)==(0|0);
  $or$cond$i = $9 | $10;
  if ($or$cond$i) {
   $$pre$i = (($7) + 4|0);
   $$pre = HEAP32[$$pre$i>>2]|0;
   $16 = $$pre;
  } else {
   $11 = HEAP16[$2>>1]|0;
   HEAP16[$7>>1] = $11;
   $12 = (($7) + 4|0);
   HEAP32[$12>>2] = 0;
   $16 = 0;
  }
  $13 = HEAP32[$3>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_viiiii[$15 & 255]($13,$16,$0,$1,$threadId);
 }
 $17 = (($this) + 276|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = HEAP16[$2>>1]|0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10startEventEtyj($this,$20,$0,$1,$threadId);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9stopEventEtyj($this,$inId,$0,$1,$threadId) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 $threadId = $threadId|0;
 var $$pre = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exists$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp + 2|0;
 $2 = sp;
 HEAP16[$2>>1] = $inId;
 $3 = (($this) + 280|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 212|0);
  $7 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($6,$2,$exists$i)|0);
  $8 = HEAP8[$exists$i>>0]|0;
  $9 = ($8<<24>>24)!=(0);
  $10 = ($7|0)==(0|0);
  $or$cond$i = $9 | $10;
  if ($or$cond$i) {
   $$pre$i = (($7) + 4|0);
   $$pre = HEAP32[$$pre$i>>2]|0;
   $17 = $$pre;
  } else {
   $11 = HEAP16[$2>>1]|0;
   HEAP16[$7>>1] = $11;
   $12 = (($7) + 4|0);
   HEAP32[$12>>2] = 0;
   $17 = 0;
  }
  $13 = HEAP32[$3>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiiii[$16 & 255]($13,$17,$0,$1,$threadId);
 }
 $18 = (($this) + 276|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = HEAP16[$2>>1]|0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE9stopEventEtyj($this,$21,$0,$1,$threadId);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10eventValueEtyx($this,$inId,$0,$1,$2,$3) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$pre = 0, $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exists$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i = sp + 2|0;
 $4 = sp;
 HEAP16[$4>>1] = $inId;
 $5 = (($this) + 280|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($this) + 212|0);
  $9 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($8,$4,$exists$i)|0);
  $10 = HEAP8[$exists$i>>0]|0;
  $11 = ($10<<24>>24)!=(0);
  $12 = ($9|0)==(0|0);
  $or$cond$i = $11 | $12;
  if ($or$cond$i) {
   $$pre$i = (($9) + 4|0);
   $$pre = HEAP32[$$pre$i>>2]|0;
   $19 = $$pre;
  } else {
   $13 = HEAP16[$4>>1]|0;
   HEAP16[$9>>1] = $13;
   $14 = (($9) + 4|0);
   HEAP32[$14>>2] = 0;
   $19 = 0;
  }
  $15 = HEAP32[$5>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_viiii[$18 & 511]($15,$19,$2,$3);
 }
 $20 = (($this) + 276|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = HEAP16[$4>>1]|0;
 $24 = (__ZN5physx6shdfnd10ThreadImpl5getIdEv()|0);
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10eventValueEtjyx($this,$23,$24,$0,$1,$2,$3);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17CUDAProfileBufferEfPKhjj($this,$batchRuntimeInMilliseconds,$cudaData,$bufLenInBytes,$bufferVersion) {
 $this = $this|0;
 $batchRuntimeInMilliseconds = Math_fround($batchRuntimeInMilliseconds);
 $cudaData = $cudaData|0;
 $bufLenInBytes = $bufLenInBytes|0;
 $bufferVersion = $bufferVersion|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 276|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN5physx6shdfnd4Time22getCurrentCounterValueEv()|0);
 $4 = tempRet0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE17CUDAProfileBufferEyfPKhjj($this,$3,$4,$batchRuntimeInMilliseconds,$cudaData,$bufLenInBytes,$bufferVersion);
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE18flushProfileEventsEv($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i = 0, $idx$01$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($4);
 }
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $6;
 $11 = (($9) - ($10))|0;
 $12 = (($this) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $23 = $6;
 } else {
  $15 = (($this) + 32|0);
  $idx$01$i$i$i = 0;
  while(1) {
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($idx$01$i$i$i<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_viii[$21 & 4095]($18,$6,$11);
   $22 = (($idx$01$i$i$i) + 1)|0;
   $exitcond$i$i$i = ($22|0)==($13|0);
   if ($exitcond$i$i$i) {
    break;
   } else {
    $idx$01$i$i$i = $22;
   }
  }
  $$pre$i$i = HEAP32[$5>>2]|0;
  $23 = $$pre$i$i;
 }
 HEAP32[$7>>2] = $23;
 $24 = HEAP32[$this>>2]|0;
 $25 = (($24) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vi[$26 & 4095]($this);
 if ($2) {
  STACKTOP = sp;return;
 }
 $27 = (($1) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($28);
 STACKTOP = sp;return;
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -116|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -116|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9addClientERNS_19PxProfileZoneClientE($this,$inClient) {
 $this = $this|0;
 $inClient = $inClient|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 HEAP32[$0>>2] = $inClient;
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = (($this) + 152|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if (!($8)) {
  $9 = (($this) + 144|0);
  (__ZN5physx6shdfnd5ArrayIPNS_19PxProfileZoneClientENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($9,$0)|0);
  $15 = (($this) + 160|0);
  HEAP8[$15>>0] = 1;
  $16 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($16);
  STACKTOP = sp;return;
 }
 $10 = (($this) + 148|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($7<<2)|0);
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  HEAP32[$12>>2] = $inClient;
 }
 $14 = (($7) + 1)|0;
 HEAP32[$6>>2] = $14;
 $15 = (($this) + 160|0);
 HEAP8[$15>>0] = 1;
 $16 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($16);
 STACKTOP = sp;return;
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE12removeClientERNS_19PxProfileZoneClientE($this,$inClient) {
 $this = $this|0;
 $inClient = $inClient|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$04$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $22 = 0;
  } else {
   $5 = (($this) + 148|0);
   $6 = HEAP32[$5>>2]|0;
   $idx$04$i = 0;
   while(1) {
    $9 = (($6) + ($idx$04$i<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($inClient|0);
    $8 = (($idx$04$i) + 1)|0;
    if ($11) {
     break;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $idx$04$i = $8;
    } else {
     $22 = $3;
     break L1;
    }
   }
   $12 = HEAP32[$inClient>>2]|0;
   $13 = (($12) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vi[$14 & 4095]($inClient);
   $15 = HEAP32[$2>>2]|0;
   $16 = (($15) + -1)|0;
   HEAP32[$2>>2] = $16;
   $17 = HEAP32[$5>>2]|0;
   $18 = (($17) + ($16<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + ($idx$04$i<<2)|0);
   HEAP32[$20>>2] = $19;
   $22 = $16;
  }
 } while(0);
 $21 = ($22|0)!=(0);
 $23 = (($this) + 160|0);
 $24 = $21&1;
 HEAP8[$23>>0] = $24;
 $25 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($25);
 STACKTOP = sp;return;
}
function __ZThn116_NK5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10hasClientsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE7getNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -116|0);
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($0);
 $5 = HEAP32[$2>>2]|0;
 $6 = (($5) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($2,$0);
 STACKTOP = sp;return;
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21setProfileZoneManagerEPNS_20PxProfileZoneManagerE($this,$inMgr) {
 $this = $this|0;
 $inMgr = $inMgr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 HEAP32[$0>>2] = $inMgr;
 STACKTOP = sp;return;
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21getProfileZoneManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17getEventIdForNameEPKc($this,$inName) {
 $this = $this|0;
 $inName = $inName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -116|0);
 HEAP32[$0>>2] = $inName;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$4 & 2047]($1,$0,1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19getEventIdsForNamesEPPKcj($this,$inNames,$inLen) {
 $this = $this|0;
 $inNames = $inNames|0;
 $inLen = $inLen|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -116|0);
 $1 = (__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19getEventIdsForNamesEPPKcj($0,$inNames,$inLen)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21setUserCustomProfilerEPNS_20PxUserCustomProfilerE($this,$up) {
 $this = $this|0;
 $up = $up|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 164|0);
 HEAP32[$0>>2] = $up;
 STACKTOP = sp;return;
}
function __ZThn120_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -120|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn120_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -120|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZThn120_NK5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE15getProfileNamesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$agg$result>>2] = $5;
 $6 = (($agg$result) + 4|0);
 HEAP32[$6>>2] = $3;
 $7 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($7);
 STACKTOP = sp;return;
}
function __ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -124|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -124|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10startEventEty($this,$inId,$0,$1) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exists$i$i = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i = sp + 2|0;
 $2 = sp;
 $3 = (($this) + -124|0);
 HEAP16[$2>>1] = $inId;
 $4 = (($this) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($this) + 88|0);
  $8 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($7,$2,$exists$i$i)|0);
  $9 = HEAP8[$exists$i$i>>0]|0;
  $10 = ($9<<24>>24)!=(0);
  $11 = ($8|0)==(0|0);
  $or$cond$i$i = $10 | $11;
  if ($or$cond$i$i) {
   $$pre$i$i = (($8) + 4|0);
   $$pre$i = HEAP32[$$pre$i$i>>2]|0;
   $17 = $$pre$i;
  } else {
   $12 = HEAP16[$2>>1]|0;
   HEAP16[$8>>1] = $12;
   $13 = (($8) + 4|0);
   HEAP32[$13>>2] = 0;
   $17 = 0;
  }
  $14 = HEAP32[$4>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiiii[$16 & 255]($14,$17,$0,$1,0);
 }
 $18 = (($this) + 152|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = HEAP16[$2>>1]|0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10startEventEty($3,$21,$0,$1);
 STACKTOP = sp;return;
}
function __ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9stopEventEty($this,$inId,$0,$1) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exists$i$i = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i = sp + 2|0;
 $2 = sp;
 $3 = (($this) + -124|0);
 HEAP16[$2>>1] = $inId;
 $4 = (($this) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($this) + 88|0);
  $8 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($7,$2,$exists$i$i)|0);
  $9 = HEAP8[$exists$i$i>>0]|0;
  $10 = ($9<<24>>24)!=(0);
  $11 = ($8|0)==(0|0);
  $or$cond$i$i = $10 | $11;
  if ($or$cond$i$i) {
   $$pre$i$i = (($8) + 4|0);
   $$pre$i = HEAP32[$$pre$i$i>>2]|0;
   $18 = $$pre$i;
  } else {
   $12 = HEAP16[$2>>1]|0;
   HEAP16[$8>>1] = $12;
   $13 = (($8) + 4|0);
   HEAP32[$13>>2] = 0;
   $18 = 0;
  }
  $14 = HEAP32[$4>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_viiiii[$17 & 255]($14,$18,$0,$1,0);
 }
 $19 = (($this) + 152|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = HEAP16[$2>>1]|0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE9stopEventEty($3,$22,$0,$1);
 STACKTOP = sp;return;
}
function __ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10startEventEtyj($this,$inId,$0,$1,$threadId) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 $threadId = $threadId|0;
 var $$pre$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exists$i$i = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i = sp + 2|0;
 $2 = sp;
 $3 = (($this) + -124|0);
 HEAP16[$2>>1] = $inId;
 $4 = (($this) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($this) + 88|0);
  $8 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($7,$2,$exists$i$i)|0);
  $9 = HEAP8[$exists$i$i>>0]|0;
  $10 = ($9<<24>>24)!=(0);
  $11 = ($8|0)==(0|0);
  $or$cond$i$i = $10 | $11;
  if ($or$cond$i$i) {
   $$pre$i$i = (($8) + 4|0);
   $$pre$i = HEAP32[$$pre$i$i>>2]|0;
   $17 = $$pre$i;
  } else {
   $12 = HEAP16[$2>>1]|0;
   HEAP16[$8>>1] = $12;
   $13 = (($8) + 4|0);
   HEAP32[$13>>2] = 0;
   $17 = 0;
  }
  $14 = HEAP32[$4>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiiii[$16 & 255]($14,$17,$0,$1,$threadId);
 }
 $18 = (($this) + 152|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = HEAP16[$2>>1]|0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10startEventEtyj($3,$21,$0,$1,$threadId);
 STACKTOP = sp;return;
}
function __ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9stopEventEtyj($this,$inId,$0,$1,$threadId) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 $threadId = $threadId|0;
 var $$pre$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exists$i$i = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i = sp + 2|0;
 $2 = sp;
 $3 = (($this) + -124|0);
 HEAP16[$2>>1] = $inId;
 $4 = (($this) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($this) + 88|0);
  $8 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($7,$2,$exists$i$i)|0);
  $9 = HEAP8[$exists$i$i>>0]|0;
  $10 = ($9<<24>>24)!=(0);
  $11 = ($8|0)==(0|0);
  $or$cond$i$i = $10 | $11;
  if ($or$cond$i$i) {
   $$pre$i$i = (($8) + 4|0);
   $$pre$i = HEAP32[$$pre$i$i>>2]|0;
   $18 = $$pre$i;
  } else {
   $12 = HEAP16[$2>>1]|0;
   HEAP16[$8>>1] = $12;
   $13 = (($8) + 4|0);
   HEAP32[$13>>2] = 0;
   $18 = 0;
  }
  $14 = HEAP32[$4>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_viiiii[$17 & 255]($14,$18,$0,$1,$threadId);
 }
 $19 = (($this) + 152|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = HEAP16[$2>>1]|0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE9stopEventEtyj($3,$22,$0,$1,$threadId);
 STACKTOP = sp;return;
}
function __ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10eventValueEtyx($this,$inId,$0,$1,$2,$3) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$pre$i = 0, $$pre$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exists$i$i = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exists$i$i = sp + 2|0;
 $4 = sp;
 $5 = (($this) + -124|0);
 HEAP16[$4>>1] = $inId;
 $6 = (($this) + 156|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 88|0);
  $10 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($9,$4,$exists$i$i)|0);
  $11 = HEAP8[$exists$i$i>>0]|0;
  $12 = ($11<<24>>24)!=(0);
  $13 = ($10|0)==(0|0);
  $or$cond$i$i = $12 | $13;
  if ($or$cond$i$i) {
   $$pre$i$i = (($10) + 4|0);
   $$pre$i = HEAP32[$$pre$i$i>>2]|0;
   $20 = $$pre$i;
  } else {
   $14 = HEAP16[$4>>1]|0;
   HEAP16[$10>>1] = $14;
   $15 = (($10) + 4|0);
   HEAP32[$15>>2] = 0;
   $20 = 0;
  }
  $16 = HEAP32[$6>>2]|0;
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_viiii[$19 & 511]($16,$20,$2,$3);
 }
 $21 = (($this) + 152|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = HEAP16[$4>>1]|0;
 $25 = (__ZN5physx6shdfnd10ThreadImpl5getIdEv()|0);
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10eventValueEtjyx($5,$24,$25,$0,$1,$2,$3);
 STACKTOP = sp;return;
}
function __ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17CUDAProfileBufferEfPKhjj($this,$batchRuntimeInMilliseconds,$cudaData,$bufLenInBytes,$bufferVersion) {
 $this = $this|0;
 $batchRuntimeInMilliseconds = Math_fround($batchRuntimeInMilliseconds);
 $cudaData = $cudaData|0;
 $bufLenInBytes = $bufLenInBytes|0;
 $bufferVersion = $bufferVersion|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + -124|0);
 $4 = (__ZN5physx6shdfnd4Time22getCurrentCounterValueEv()|0);
 $5 = tempRet0;
 __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE17CUDAProfileBufferEyfPKhjj($3,$4,$5,$batchRuntimeInMilliseconds,$cudaData,$bufLenInBytes,$bufferVersion);
 STACKTOP = sp;return;
}
function __ZThn128_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -128|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn128_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -128|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZThn128_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE18flushProfileEventsEv($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i$i = 0, $idx$01$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -128|0);
 $1 = (($this) + -56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($5);
 }
 $6 = (($this) + -112|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + -108|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = $7;
 $12 = (($10) - ($11))|0;
 $13 = (($this) + -92|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $24 = $7;
 } else {
  $16 = (($this) + -96|0);
  $idx$01$i$i$i$i = 0;
  while(1) {
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + ($idx$01$i$i$i$i<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   FUNCTION_TABLE_viii[$22 & 4095]($19,$7,$12);
   $23 = (($idx$01$i$i$i$i) + 1)|0;
   $exitcond$i$i$i$i = ($23|0)==($14|0);
   if ($exitcond$i$i$i$i) {
    break;
   } else {
    $idx$01$i$i$i$i = $23;
   }
  }
  $$pre$i$i$i = HEAP32[$6>>2]|0;
  $24 = $$pre$i$i$i;
 }
 HEAP32[$8>>2] = $24;
 $25 = HEAP32[$0>>2]|0;
 $26 = (($25) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vi[$27 & 4095]($0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $28 = (($2) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($29);
 STACKTOP = sp;return;
}
function __ZThn132_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -132|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn132_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -132|0);
 __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZThn132_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17handleBufferFlushEPKhj($this,$inData,$inLength) {
 $this = $this|0;
 $inData = $inData|0;
 $inLength = $inLength|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $idx$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $13 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($13);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 132|0);
 $idx$01$i = 0;
 while(1) {
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($idx$01$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viii[$11 & 4095]($8,$inData,$inLength);
  $12 = (($idx$01$i) + 1)|0;
  $exitcond$i = ($12|0)==($3|0);
  if ($exitcond$i) {
   break;
  } else {
   $idx$01$i = $12;
  }
 }
 $13 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($13);
 STACKTOP = sp;return;
}
function __ZThn132_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19handleClientRemovedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $idx$04$i = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((535240 + 8|0));
 $0 = (($this) + 116|0);
 HEAP32[$0>>2] = ((535240 + 112|0));
 $1 = (($this) + 120|0);
 HEAP32[$1>>2] = ((535240 + 168|0));
 $2 = (($this) + 124|0);
 HEAP32[$2>>2] = ((535240 + 188|0));
 $3 = (($this) + 128|0);
 HEAP32[$3>>2] = ((535240 + 228|0));
 $4 = (($this) + 132|0);
 HEAP32[$4>>2] = ((535240 + 248|0));
 $5 = (($this) + 256|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 4095]($6,$0);
 }
 HEAP32[$5>>2] = 0;
 $11 = (($this) + 72|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = (($12) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($15);
 }
 $16 = (($this) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 L7: do {
  if ($18) {
   $36 = 0;
  } else {
   $19 = (($this) + 32|0);
   $20 = HEAP32[$19>>2]|0;
   $idx$04$i = 0;
   while(1) {
    $23 = (($20) + ($idx$04$i<<2)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==($4|0);
    $22 = (($idx$04$i) + 1)|0;
    if ($25) {
     break;
    }
    $21 = ($22>>>0)<($17>>>0);
    if ($21) {
     $idx$04$i = $22;
    } else {
     $36 = $17;
     break L7;
    }
   }
   $26 = HEAP32[$4>>2]|0;
   $27 = (($26) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   FUNCTION_TABLE_vi[$28 & 4095]($4);
   $29 = HEAP32[$16>>2]|0;
   $30 = (($29) + -1)|0;
   HEAP32[$16>>2] = $30;
   $31 = HEAP32[$19>>2]|0;
   $32 = (($31) + ($30<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + ($idx$04$i<<2)|0);
   HEAP32[$34>>2] = $33;
   $36 = $30;
  }
 } while(0);
 $35 = ($36|0)!=(0);
 $37 = (($this) + 76|0);
 $38 = $35&1;
 HEAP8[$37>>0] = $38;
 if (!($13)) {
  $39 = (($12) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($40);
 }
 $41 = (($this) + 272|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 & 2147483647;
 $44 = ($43|0)!=(0);
 $45 = ($42|0)>(-1);
 $or$cond$i$i$i = $44 & $45;
 if ($or$cond$i$i$i) {
  $46 = (($this) + 264|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  if (!($48)) {
   $49 = (($this) + 260|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = HEAP32[$50>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + 12|0);
   $54 = HEAP32[$53>>2]|0;
   FUNCTION_TABLE_vii[$54 & 4095]($51,$47);
  }
 }
 $55 = (($this) + 216|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0|0);
 if (!($57)) {
  $58 = (($this) + 212|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 12|0);
  $63 = HEAP32[$62>>2]|0;
  FUNCTION_TABLE_vii[$63 & 4095]($60,$56);
 }
 $64 = (($this) + 172|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if (!($66)) {
  $67 = (($this) + 168|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = HEAP32[$68>>2]|0;
  $70 = HEAP32[$69>>2]|0;
  $71 = (($70) + 12|0);
  $72 = HEAP32[$71>>2]|0;
  FUNCTION_TABLE_vii[$72 & 4095]($69,$65);
 }
 $73 = (($this) + 164|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $74 & 2147483647;
 $76 = ($75|0)!=(0);
 $77 = ($74|0)>(-1);
 $or$cond$i$i$i1 = $76 & $77;
 if ($or$cond$i$i$i1) {
  $78 = (($this) + 156|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)==(0|0);
  if (!($80)) {
   $81 = (($this) + 152|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = HEAP32[$82>>2]|0;
   $84 = HEAP32[$83>>2]|0;
   $85 = (($84) + 12|0);
   $86 = HEAP32[$85>>2]|0;
   FUNCTION_TABLE_vii[$86 & 4095]($83,$79);
  }
 }
 $87 = (($this) + 148|0);
 $88 = HEAP32[$87>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($88);
 $89 = HEAP32[$87>>2]|0;
 $90 = ($89|0)==(0|0);
 if ($90) {
  __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED2Ev($this);
  STACKTOP = sp;return;
 }
 $91 = (($this) + 144|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = HEAP32[$92>>2]|0;
 $94 = HEAP32[$93>>2]|0;
 $95 = (($94) + 12|0);
 $96 = HEAP32[$95>>2]|0;
 FUNCTION_TABLE_vii[$96 & 4095]($93,$89);
 __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $idx$04$i = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((535504 + 8|0));
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 32|0);
  $4 = (($this) + 72|0);
  $5 = (($this) + 76|0);
  $59 = $1;
  while(1) {
   $6 = HEAP32[$3>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$4>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $13 = $59;
   } else {
    $10 = (($8) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    __ZN5physx6shdfnd9MutexImpl4lockEv($11);
    $$pre = HEAP32[$0>>2]|0;
    $13 = $$pre;
   }
   $12 = ($13|0)==(0);
   L8: do {
    if ($12) {
     $30 = 0;
    } else {
     $14 = HEAP32[$3>>2]|0;
     $idx$04$i = 0;
     while(1) {
      $17 = (($14) + ($idx$04$i<<2)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)==($7|0);
      $16 = (($idx$04$i) + 1)|0;
      if ($19) {
       break;
      }
      $15 = ($16>>>0)<($13>>>0);
      if ($15) {
       $idx$04$i = $16;
      } else {
       $30 = $13;
       break L8;
      }
     }
     $20 = HEAP32[$7>>2]|0;
     $21 = (($20) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     FUNCTION_TABLE_vi[$22 & 4095]($7);
     $23 = HEAP32[$0>>2]|0;
     $24 = (($23) + -1)|0;
     HEAP32[$0>>2] = $24;
     $25 = HEAP32[$3>>2]|0;
     $26 = (($25) + ($24<<2)|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($25) + ($idx$04$i<<2)|0);
     HEAP32[$28>>2] = $27;
     $30 = $24;
    }
   } while(0);
   $29 = ($30|0)!=(0);
   $31 = $29&1;
   HEAP8[$5>>0] = $31;
   if (!($9)) {
    $34 = (($8) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    __ZN5physx6shdfnd9MutexImpl6unlockEv($35);
   }
   $32 = HEAP32[$0>>2]|0;
   $33 = ($32|0)==(0);
   if ($33) {
    break;
   } else {
    $59 = $32;
   }
  }
 }
 $36 = (($this) + 40|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38|0)!=(0);
 $40 = ($37|0)>(-1);
 $or$cond$i$i$i = $39 & $40;
 if ($or$cond$i$i$i) {
  $41 = (($this) + 32|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = (($this) + 28|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$45>>2]|0;
   $47 = HEAP32[$46>>2]|0;
   $48 = (($47) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   FUNCTION_TABLE_vii[$49 & 4095]($46,$42);
  }
 }
 $50 = (($this) + 16|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = (($this) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 12|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_vii[$58 & 4095]($55,$51);
 STACKTOP = sp;return;
}
function __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEE17handleBufferFlushEPKhj($this,$inData,$inDataSize) {
 $this = $this|0;
 $inData = $inData|0;
 $inDataSize = $inDataSize|0;
 var $$0$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $idx$01$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($4);
 }
 $5 = ($inData|0)==(0|0);
 $6 = ($inDataSize|0)==(0);
 $or$cond = $5 | $6;
 L4: do {
  if (!($or$cond)) {
   $7 = HEAP32[$this>>2]|0;
   $8 = (($7) + 16|0);
   $9 = HEAP32[$8>>2]|0;
   FUNCTION_TABLE_vi[$9 & 4095]($this);
   $10 = (($this) + 8|0);
   $11 = (($this) + 20|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $12;
   $16 = $14;
   $17 = (($15) + ($inDataSize))|0;
   $18 = (($17) - ($16))|0;
   $19 = (($this) + 44|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($18>>>0)<($20>>>0);
   if ($21) {
    $26 = $20;
   } else {
    $22 = HEAP32[$this>>2]|0;
    $23 = (($22) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    FUNCTION_TABLE_vi[$24 & 4095]($this);
    $$pre = HEAP32[$19>>2]|0;
    $26 = $$pre;
   }
   $25 = ($26>>>0)>($inDataSize>>>0);
   if (!($25)) {
    $27 = (($this) + 36|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0);
    if ($29) {
     break;
    }
    $30 = (($this) + 32|0);
    $idx$01$i = 0;
    while(1) {
     $31 = HEAP32[$30>>2]|0;
     $32 = (($31) + ($idx$01$i<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     FUNCTION_TABLE_viii[$36 & 4095]($33,$inData,$inDataSize);
     $37 = (($idx$01$i) + 1)|0;
     $exitcond$i = ($37|0)==($28|0);
     if ($exitcond$i) {
      break L4;
     } else {
      $idx$01$i = $37;
     }
    }
   }
   $38 = HEAP32[$11>>2]|0;
   $39 = HEAP32[$13>>2]|0;
   $40 = $38;
   $41 = $39;
   $42 = (($40) - ($41))|0;
   $43 = (($42) + ($inDataSize))|0;
   $44 = (($this) + 24|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = $45;
   $47 = (($46) - ($41))|0;
   $48 = ($47>>>0)>($43>>>0);
   if ($48) {
    $71 = $38;$73 = $39;
   } else {
    $49 = $43 << 1;
    $50 = ($49|0)==(0);
    if ($50) {
     $$0$i$i$i$i = 0;$60 = $39;
    } else {
     $51 = HEAP32[$10>>2]|0;
     $52 = HEAP32[$51>>2]|0;
     $53 = HEAP32[$52>>2]|0;
     $54 = (($53) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($this) + 12|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = (FUNCTION_TABLE_iiiiii[$55 & 255]($52,$49,$57,535536,117)|0);
     $$pre$i$i$i = HEAP32[$13>>2]|0;
     $$0$i$i$i$i = $58;$60 = $$pre$i$i$i;
    }
    $59 = ($60|0)==(0|0);
    if (!($59)) {
     _memcpy(($$0$i$i$i$i|0),($60|0),($42|0))|0;
     $61 = HEAP32[$13>>2]|0;
     $62 = ($61|0)==(0|0);
     if (!($62)) {
      $63 = HEAP32[$10>>2]|0;
      $64 = HEAP32[$63>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = (($65) + 12|0);
      $67 = HEAP32[$66>>2]|0;
      FUNCTION_TABLE_vii[$67 & 4095]($64,$61);
     }
    }
    HEAP32[$13>>2] = $$0$i$i$i$i;
    $68 = (($$0$i$i$i$i) + ($42)|0);
    HEAP32[$11>>2] = $68;
    $69 = (($$0$i$i$i$i) + ($49)|0);
    HEAP32[$44>>2] = $69;
    $71 = $68;$73 = $$0$i$i$i$i;
   }
   $70 = $71;
   $72 = $73;
   $74 = (($70) - ($72))|0;
   $75 = (($73) + ($74)|0);
   _memcpy(($75|0),($inData|0),($inDataSize|0))|0;
   $76 = HEAP32[$11>>2]|0;
   $77 = (($76) + ($inDataSize)|0);
   HEAP32[$11>>2] = $77;
  }
 } while(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $78 = (($1) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($79);
 STACKTOP = sp;return;
}
function __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEE15clearCachedDataEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE17CUDAProfileBufferEyfPKhjj($this,$0,$1,$batchRuntimeInMilliseconds,$cudaData,$bufLenInBytes,$bufferVersion) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $batchRuntimeInMilliseconds = Math_fround($batchRuntimeInMilliseconds);
 $cudaData = $cudaData|0;
 $bufLenInBytes = $bufLenInBytes|0;
 $bufferVersion = $bufferVersion|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $exitcond$i$i = 0, $exitcond$i$i$i = 0, $idx$01$i$i = 0, $idx$01$i$i$i = 0, $theEvent = 0, $theHeader = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theEvent = sp;
 $theHeader = sp + 24|0;
 $2 = (($this) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($6);
 }
 ;HEAP32[$theEvent+0>>2]=0|0;HEAP32[$theEvent+4>>2]=0|0;HEAP32[$theEvent+8>>2]=0|0;HEAP32[$theEvent+12>>2]=0|0;HEAP32[$theEvent+16>>2]=0|0;HEAP32[$theEvent+20>>2]=0|0;
 $7 = $theEvent;
 $8 = $7;
 HEAP32[$8>>2] = $0;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $1;
 $11 = (($theEvent) + 8|0);
 HEAPF32[$11>>2] = $batchRuntimeInMilliseconds;
 $12 = (($theEvent) + 12|0);
 HEAP32[$12>>2] = $cudaData;
 $13 = (($theEvent) + 16|0);
 HEAP32[$13>>2] = $bufLenInBytes;
 $14 = (($theEvent) + 20|0);
 HEAP32[$14>>2] = $bufferVersion;
 HEAP8[$theHeader>>0] = 6;
 $15 = (($theHeader) + 1|0);
 HEAP8[$15>>0] = -1;
 $16 = (($theHeader) + 2|0);
 HEAP16[$16>>1] = 0;
 $17 = (($this) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $18;
 $22 = $20;
 $23 = (($21) + ($bufLenInBytes))|0;
 $24 = (($23) - ($22))|0;
 $25 = (($this) + 44|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24>>>0)<($26>>>0);
 if (!($27)) {
  $28 = HEAP32[$2>>2]|0;
  $29 = ($28|0)==(0|0);
  if ($29) {
   $33 = $18;$35 = $20;
  } else {
   $30 = (($28) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($31);
   $$pre2 = HEAP32[$19>>2]|0;
   $$pre3 = HEAP32[$17>>2]|0;
   $33 = $$pre3;$35 = $$pre2;
  }
  $32 = $33;
  $34 = $35;
  $36 = (($32) - ($34))|0;
  $37 = (($this) + 36|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0);
  if ($39) {
   $48 = $35;
  } else {
   $40 = (($this) + 32|0);
   $idx$01$i$i = 0;
   while(1) {
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + ($idx$01$i$i<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + 8|0);
    $46 = HEAP32[$45>>2]|0;
    FUNCTION_TABLE_viii[$46 & 4095]($43,$35,$36);
    $47 = (($idx$01$i$i) + 1)|0;
    $exitcond$i$i = ($47|0)==($38|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $idx$01$i$i = $47;
    }
   }
   $$pre$i = HEAP32[$19>>2]|0;
   $48 = $$pre$i;
  }
  HEAP32[$17>>2] = $48;
  $49 = HEAP32[$this>>2]|0;
  $50 = (($49) + 16|0);
  $51 = HEAP32[$50>>2]|0;
  FUNCTION_TABLE_vi[$51 & 4095]($this);
  if (!($29)) {
   $52 = (($28) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($53);
  }
 }
 $54 = (($this) + 80|0);
 __ZN5physx7profile11EventHeader9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_($theHeader,$54);
 __ZN5physx7profile17CUDAProfileBuffer9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_RKNS0_11EventHeaderE($theEvent,$54,0);
 $55 = HEAP32[$17>>2]|0;
 $56 = HEAP32[$19>>2]|0;
 $57 = $55;
 $58 = $56;
 $59 = (($57) - ($58))|0;
 $60 = HEAP32[$25>>2]|0;
 $61 = ($59>>>0)<($60>>>0);
 if (!($61)) {
  $62 = HEAP32[$2>>2]|0;
  $63 = ($62|0)==(0|0);
  if ($63) {
   $67 = $55;$69 = $56;
  } else {
   $64 = (($62) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($65);
   $$pre = HEAP32[$19>>2]|0;
   $$pre1 = HEAP32[$17>>2]|0;
   $67 = $$pre1;$69 = $$pre;
  }
  $66 = $67;
  $68 = $69;
  $70 = (($66) - ($68))|0;
  $71 = (($this) + 36|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0);
  if ($73) {
   $82 = $69;
  } else {
   $74 = (($this) + 32|0);
   $idx$01$i$i$i = 0;
   while(1) {
    $75 = HEAP32[$74>>2]|0;
    $76 = (($75) + ($idx$01$i$i$i<<2)|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = HEAP32[$77>>2]|0;
    $79 = (($78) + 8|0);
    $80 = HEAP32[$79>>2]|0;
    FUNCTION_TABLE_viii[$80 & 4095]($77,$69,$70);
    $81 = (($idx$01$i$i$i) + 1)|0;
    $exitcond$i$i$i = ($81|0)==($72|0);
    if ($exitcond$i$i$i) {
     break;
    } else {
     $idx$01$i$i$i = $81;
    }
   }
   $$pre$i$i = HEAP32[$19>>2]|0;
   $82 = $$pre$i$i;
  }
  HEAP32[$17>>2] = $82;
  $83 = HEAP32[$this>>2]|0;
  $84 = (($83) + 16|0);
  $85 = HEAP32[$84>>2]|0;
  FUNCTION_TABLE_vi[$85 & 4095]($this);
  if (!($63)) {
   $86 = (($62) + 4|0);
   $87 = HEAP32[$86>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($87);
  }
 }
 if ($4) {
  STACKTOP = sp;return;
 }
 $88 = (($3) + 4|0);
 $89 = HEAP32[$88>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($89);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventHeader9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_($this,$inStream) {
 $this = $this|0;
 $inStream = $inStream|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i2 = 0, $$0$i$i$i$i$i7 = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i1 = 0, $$pre$i$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$inStream>>2]|0;
 $1 = HEAP8[$this>>0]|0;
 $2 = (($0) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8) + 1)|0;
 $10 = (($0) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($7))|0;
 $14 = ($13>>>0)>($9>>>0);
 if ($14) {
  $36 = $3;
 } else {
  $15 = $9 << 1;
  $16 = ($15|0)==(0);
  if ($16) {
   $$0$i$i$i$i$i = 0;$26 = $5;
  } else {
   $17 = HEAP32[$0>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($0) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (FUNCTION_TABLE_iiiiii[$21 & 255]($18,$15,$23,535536,117)|0);
   $$pre$i$i$i$i = HEAP32[$4>>2]|0;
   $$0$i$i$i$i$i = $24;$26 = $$pre$i$i$i$i;
  }
  $25 = ($26|0)==(0|0);
  if (!($25)) {
   _memcpy(($$0$i$i$i$i$i|0),($26|0),($8|0))|0;
   $27 = HEAP32[$4>>2]|0;
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    $29 = HEAP32[$0>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + 12|0);
    $33 = HEAP32[$32>>2]|0;
    FUNCTION_TABLE_vii[$33 & 4095]($30,$27);
   }
  }
  HEAP32[$4>>2] = $$0$i$i$i$i$i;
  $34 = (($$0$i$i$i$i$i) + ($8)|0);
  HEAP32[$2>>2] = $34;
  $35 = (($$0$i$i$i$i$i) + ($15)|0);
  HEAP32[$10>>2] = $35;
  $36 = $34;
 }
 HEAP8[$36>>0] = $1;
 $37 = HEAP32[$2>>2]|0;
 $38 = (($37) + 1|0);
 HEAP32[$2>>2] = $38;
 $39 = (($this) + 1|0);
 $40 = HEAP32[$inStream>>2]|0;
 $41 = HEAP8[$39>>0]|0;
 $42 = (($40) + 12|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($40) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $43;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = (($48) + 1)|0;
 $50 = (($40) + 16|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = $51;
 $53 = (($52) - ($47))|0;
 $54 = ($53>>>0)>($49>>>0);
 if ($54) {
  $76 = $43;
 } else {
  $55 = $49 << 1;
  $56 = ($55|0)==(0);
  if ($56) {
   $$0$i$i$i$i$i2 = 0;$66 = $45;
  } else {
   $57 = HEAP32[$40>>2]|0;
   $58 = HEAP32[$57>>2]|0;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 8|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($40) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (FUNCTION_TABLE_iiiiii[$61 & 255]($58,$55,$63,535536,117)|0);
   $$pre$i$i$i$i1 = HEAP32[$44>>2]|0;
   $$0$i$i$i$i$i2 = $64;$66 = $$pre$i$i$i$i1;
  }
  $65 = ($66|0)==(0|0);
  if (!($65)) {
   _memcpy(($$0$i$i$i$i$i2|0),($66|0),($48|0))|0;
   $67 = HEAP32[$44>>2]|0;
   $68 = ($67|0)==(0|0);
   if (!($68)) {
    $69 = HEAP32[$40>>2]|0;
    $70 = HEAP32[$69>>2]|0;
    $71 = HEAP32[$70>>2]|0;
    $72 = (($71) + 12|0);
    $73 = HEAP32[$72>>2]|0;
    FUNCTION_TABLE_vii[$73 & 4095]($70,$67);
   }
  }
  HEAP32[$44>>2] = $$0$i$i$i$i$i2;
  $74 = (($$0$i$i$i$i$i2) + ($48)|0);
  HEAP32[$42>>2] = $74;
  $75 = (($$0$i$i$i$i$i2) + ($55)|0);
  HEAP32[$50>>2] = $75;
  $76 = $74;
 }
 HEAP8[$76>>0] = $41;
 $77 = HEAP32[$42>>2]|0;
 $78 = (($77) + 1|0);
 HEAP32[$42>>2] = $78;
 $79 = (($this) + 2|0);
 $80 = HEAP32[$inStream>>2]|0;
 $81 = (($80) + 12|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($80) + 8|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = $82;
 $86 = $84;
 $87 = (($85) - ($86))|0;
 $88 = (($87) + 2)|0;
 $89 = (($80) + 16|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = $90;
 $92 = (($91) - ($86))|0;
 $93 = ($92>>>0)>($88>>>0);
 if ($93) {
  $116 = $82;
  $115 = HEAP8[$79>>0]|0;
  HEAP8[$116>>0] = $115;
  $117 = (($79) + 1|0);
  $118 = HEAP8[$117>>0]|0;
  $119 = (($116) + 1|0);
  HEAP8[$119>>0] = $118;
  $120 = HEAP32[$81>>2]|0;
  $121 = (($120) + 2|0);
  HEAP32[$81>>2] = $121;
  STACKTOP = sp;return;
 }
 $94 = $88 << 1;
 $95 = ($94|0)==(0);
 if ($95) {
  $$0$i$i$i$i$i7 = 0;$105 = $84;
 } else {
  $96 = HEAP32[$80>>2]|0;
  $97 = HEAP32[$96>>2]|0;
  $98 = HEAP32[$97>>2]|0;
  $99 = (($98) + 8|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($80) + 4|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (FUNCTION_TABLE_iiiiii[$100 & 255]($97,$94,$102,535536,117)|0);
  $$pre$i$i$i$i6 = HEAP32[$83>>2]|0;
  $$0$i$i$i$i$i7 = $103;$105 = $$pre$i$i$i$i6;
 }
 $104 = ($105|0)==(0|0);
 if (!($104)) {
  _memcpy(($$0$i$i$i$i$i7|0),($105|0),($87|0))|0;
  $106 = HEAP32[$83>>2]|0;
  $107 = ($106|0)==(0|0);
  if (!($107)) {
   $108 = HEAP32[$80>>2]|0;
   $109 = HEAP32[$108>>2]|0;
   $110 = HEAP32[$109>>2]|0;
   $111 = (($110) + 12|0);
   $112 = HEAP32[$111>>2]|0;
   FUNCTION_TABLE_vii[$112 & 4095]($109,$106);
  }
 }
 HEAP32[$83>>2] = $$0$i$i$i$i$i7;
 $113 = (($$0$i$i$i$i$i7) + ($87)|0);
 HEAP32[$81>>2] = $113;
 $114 = (($$0$i$i$i$i$i7) + ($94)|0);
 HEAP32[$89>>2] = $114;
 $116 = $113;
 $115 = HEAP8[$79>>0]|0;
 HEAP8[$116>>0] = $115;
 $117 = (($79) + 1|0);
 $118 = HEAP8[$117>>0]|0;
 $119 = (($116) + 1|0);
 HEAP8[$119>>0] = $118;
 $120 = HEAP32[$81>>2]|0;
 $121 = (($120) + 2|0);
 HEAP32[$81>>2] = $121;
 STACKTOP = sp;return;
}
function __ZN5physx7profile17CUDAProfileBuffer9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_RKNS0_11EventHeaderE($this,$inStream,$0) {
 $this = $this|0;
 $inStream = $inStream|0;
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i12 = 0, $$0$i$i$i$i$i2 = 0, $$0$i$i$i$i7 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i1 = 0, $$pre$i$i$i$i11 = 0, $$pre$i$i$i6 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[$inStream>>2]|0;
 __ZN5physx7profile12MemoryBufferINS0_21WrapperNamedAllocatorEE5writeIyEEvRKT_($1,$this);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$inStream>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10) + 4)|0;
 $12 = (($3) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($9))|0;
 $16 = ($15>>>0)>($11>>>0);
 if ($16) {
  $39 = $5;
 } else {
  $17 = $11 << 1;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i$i$i$i$i12 = 0;$28 = $7;
  } else {
   $19 = HEAP32[$3>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($3) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (FUNCTION_TABLE_iiiiii[$23 & 255]($20,$17,$25,535536,117)|0);
   $$pre$i$i$i$i11 = HEAP32[$6>>2]|0;
   $$0$i$i$i$i$i12 = $26;$28 = $$pre$i$i$i$i11;
  }
  $27 = ($28|0)==(0|0);
  if (!($27)) {
   _memcpy(($$0$i$i$i$i$i12|0),($28|0),($10|0))|0;
   $29 = HEAP32[$6>>2]|0;
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    $31 = HEAP32[$3>>2]|0;
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    FUNCTION_TABLE_vii[$35 & 4095]($32,$29);
   }
  }
  HEAP32[$6>>2] = $$0$i$i$i$i$i12;
  $36 = (($$0$i$i$i$i$i12) + ($10)|0);
  HEAP32[$4>>2] = $36;
  $37 = (($$0$i$i$i$i$i12) + ($17)|0);
  HEAP32[$12>>2] = $37;
  $39 = $36;
 }
 $38 = HEAP8[$2>>0]|0;
 HEAP8[$39>>0] = $38;
 $40 = (($2) + 1|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = (($39) + 1|0);
 HEAP8[$42>>0] = $41;
 $43 = (($2) + 2|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = (($39) + 2|0);
 HEAP8[$45>>0] = $44;
 $46 = (($2) + 3|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = (($39) + 3|0);
 HEAP8[$48>>0] = $47;
 $49 = HEAP32[$4>>2]|0;
 $50 = (($49) + 4|0);
 HEAP32[$4>>2] = $50;
 $51 = (($this) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54&255;
 $56 = $54 >>> 8;
 $57 = $56&255;
 $58 = $54 >>> 16;
 $59 = $58&255;
 $60 = $54 >>> 24;
 $61 = $60&255;
 $62 = HEAP32[$inStream>>2]|0;
 $63 = (($62) + 12|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($62) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $64;
 $68 = $66;
 $69 = (($67) - ($68))|0;
 $70 = (($69) + 4)|0;
 $71 = (($62) + 16|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $72;
 $74 = (($73) - ($68))|0;
 $75 = ($74>>>0)>($70>>>0);
 if ($75) {
  $97 = $64;
 } else {
  $76 = $70 << 1;
  $77 = ($76|0)==(0);
  if ($77) {
   $$0$i$i$i$i7 = 0;$87 = $66;
  } else {
   $78 = HEAP32[$62>>2]|0;
   $79 = HEAP32[$78>>2]|0;
   $80 = HEAP32[$79>>2]|0;
   $81 = (($80) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($62) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (FUNCTION_TABLE_iiiiii[$82 & 255]($79,$76,$84,535536,117)|0);
   $$pre$i$i$i6 = HEAP32[$65>>2]|0;
   $$0$i$i$i$i7 = $85;$87 = $$pre$i$i$i6;
  }
  $86 = ($87|0)==(0|0);
  if (!($86)) {
   _memcpy(($$0$i$i$i$i7|0),($87|0),($69|0))|0;
   $88 = HEAP32[$65>>2]|0;
   $89 = ($88|0)==(0|0);
   if (!($89)) {
    $90 = HEAP32[$62>>2]|0;
    $91 = HEAP32[$90>>2]|0;
    $92 = HEAP32[$91>>2]|0;
    $93 = (($92) + 12|0);
    $94 = HEAP32[$93>>2]|0;
    FUNCTION_TABLE_vii[$94 & 4095]($91,$88);
   }
  }
  HEAP32[$65>>2] = $$0$i$i$i$i7;
  $95 = (($$0$i$i$i$i7) + ($69)|0);
  HEAP32[$63>>2] = $95;
  $96 = (($$0$i$i$i$i7) + ($76)|0);
  HEAP32[$71>>2] = $96;
  $97 = $95;
 }
 HEAP8[$97>>0] = $55;
 $98 = (($97) + 1|0);
 HEAP8[$98>>0] = $57;
 $99 = (($97) + 2|0);
 HEAP8[$99>>0] = $59;
 $100 = (($97) + 3|0);
 HEAP8[$100>>0] = $61;
 $101 = HEAP32[$63>>2]|0;
 $102 = (($101) + 4|0);
 HEAP32[$63>>2] = $102;
 $103 = $60 << 24;
 $104 = $54 & 16777215;
 $105 = $104 | $103;
 $106 = ($105|0)==(0);
 if (!($106)) {
  $107 = HEAP32[$inStream>>2]|0;
  $108 = ($52|0)==(0|0);
  if (!($108)) {
   $109 = (($107) + 12|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = (($107) + 8|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = $110;
   $114 = $112;
   $115 = (($113) - ($114))|0;
   $116 = (($115) + ($105))|0;
   $117 = (($107) + 16|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = $118;
   $120 = (($119) - ($114))|0;
   $121 = ($120>>>0)>($116>>>0);
   if ($121) {
    $144 = $110;$146 = $112;
   } else {
    $122 = $116 << 1;
    $123 = ($122|0)==(0);
    if ($123) {
     $$0$i$i$i$i = 0;$133 = $112;
    } else {
     $124 = HEAP32[$107>>2]|0;
     $125 = HEAP32[$124>>2]|0;
     $126 = HEAP32[$125>>2]|0;
     $127 = (($126) + 8|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = (($107) + 4|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = (FUNCTION_TABLE_iiiiii[$128 & 255]($125,$122,$130,535536,117)|0);
     $$pre$i$i$i = HEAP32[$111>>2]|0;
     $$0$i$i$i$i = $131;$133 = $$pre$i$i$i;
    }
    $132 = ($133|0)==(0|0);
    if (!($132)) {
     _memcpy(($$0$i$i$i$i|0),($133|0),($115|0))|0;
     $134 = HEAP32[$111>>2]|0;
     $135 = ($134|0)==(0|0);
     if (!($135)) {
      $136 = HEAP32[$107>>2]|0;
      $137 = HEAP32[$136>>2]|0;
      $138 = HEAP32[$137>>2]|0;
      $139 = (($138) + 12|0);
      $140 = HEAP32[$139>>2]|0;
      FUNCTION_TABLE_vii[$140 & 4095]($137,$134);
     }
    }
    HEAP32[$111>>2] = $$0$i$i$i$i;
    $141 = (($$0$i$i$i$i) + ($115)|0);
    HEAP32[$109>>2] = $141;
    $142 = (($$0$i$i$i$i) + ($122)|0);
    HEAP32[$117>>2] = $142;
    $144 = $141;$146 = $$0$i$i$i$i;
   }
   $143 = $144;
   $145 = $146;
   $147 = (($143) - ($145))|0;
   $148 = (($146) + ($147)|0);
   _memcpy(($148|0),($52|0),($105|0))|0;
   $149 = HEAP32[$109>>2]|0;
   $150 = (($149) + ($105)|0);
   HEAP32[$109>>2] = $150;
  }
 }
 $151 = HEAP32[$inStream>>2]|0;
 $152 = (($151) + 12|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = (($151) + 8|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = $153;
 $157 = $155;
 $158 = (($156) - ($157))|0;
 $159 = (($158) + 4)|0;
 $160 = (($151) + 16|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = $161;
 $163 = (($162) - ($157))|0;
 $164 = ($163>>>0)>($159>>>0);
 if ($164) {
  $187 = $153;
 } else {
  $165 = $159 << 1;
  $166 = ($165|0)==(0);
  if ($166) {
   $$0$i$i$i$i$i = 0;$176 = $155;
  } else {
   $167 = HEAP32[$151>>2]|0;
   $168 = HEAP32[$167>>2]|0;
   $169 = HEAP32[$168>>2]|0;
   $170 = (($169) + 8|0);
   $171 = HEAP32[$170>>2]|0;
   $172 = (($151) + 4|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = (FUNCTION_TABLE_iiiiii[$171 & 255]($168,$165,$173,535536,117)|0);
   $$pre$i$i$i$i = HEAP32[$154>>2]|0;
   $$0$i$i$i$i$i = $174;$176 = $$pre$i$i$i$i;
  }
  $175 = ($176|0)==(0|0);
  if (!($175)) {
   _memcpy(($$0$i$i$i$i$i|0),($176|0),($158|0))|0;
   $177 = HEAP32[$154>>2]|0;
   $178 = ($177|0)==(0|0);
   if (!($178)) {
    $179 = HEAP32[$151>>2]|0;
    $180 = HEAP32[$179>>2]|0;
    $181 = HEAP32[$180>>2]|0;
    $182 = (($181) + 12|0);
    $183 = HEAP32[$182>>2]|0;
    FUNCTION_TABLE_vii[$183 & 4095]($180,$177);
   }
  }
  HEAP32[$154>>2] = $$0$i$i$i$i$i;
  $184 = (($$0$i$i$i$i$i) + ($158)|0);
  HEAP32[$152>>2] = $184;
  $185 = (($$0$i$i$i$i$i) + ($165)|0);
  HEAP32[$160>>2] = $185;
  $187 = $184;
 }
 $186 = HEAP8[$53>>0]|0;
 HEAP8[$187>>0] = $186;
 $188 = (($53) + 1|0);
 $189 = HEAP8[$188>>0]|0;
 $190 = (($187) + 1|0);
 HEAP8[$190>>0] = $189;
 $191 = (($53) + 2|0);
 $192 = HEAP8[$191>>0]|0;
 $193 = (($187) + 2|0);
 HEAP8[$193>>0] = $192;
 $194 = (($53) + 3|0);
 $195 = HEAP8[$194>>0]|0;
 $196 = (($187) + 3|0);
 HEAP8[$196>>0] = $195;
 $197 = HEAP32[$152>>2]|0;
 $198 = (($197) + 4|0);
 HEAP32[$152>>2] = $198;
 $199 = (($this) + 20|0);
 $200 = HEAP32[$inStream>>2]|0;
 $201 = (($200) + 12|0);
 $202 = HEAP32[$201>>2]|0;
 $203 = (($200) + 8|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = $202;
 $206 = $204;
 $207 = (($205) - ($206))|0;
 $208 = (($207) + 4)|0;
 $209 = (($200) + 16|0);
 $210 = HEAP32[$209>>2]|0;
 $211 = $210;
 $212 = (($211) - ($206))|0;
 $213 = ($212>>>0)>($208>>>0);
 if ($213) {
  $236 = $202;
  $235 = HEAP8[$199>>0]|0;
  HEAP8[$236>>0] = $235;
  $237 = (($199) + 1|0);
  $238 = HEAP8[$237>>0]|0;
  $239 = (($236) + 1|0);
  HEAP8[$239>>0] = $238;
  $240 = (($199) + 2|0);
  $241 = HEAP8[$240>>0]|0;
  $242 = (($236) + 2|0);
  HEAP8[$242>>0] = $241;
  $243 = (($199) + 3|0);
  $244 = HEAP8[$243>>0]|0;
  $245 = (($236) + 3|0);
  HEAP8[$245>>0] = $244;
  $246 = HEAP32[$201>>2]|0;
  $247 = (($246) + 4|0);
  HEAP32[$201>>2] = $247;
  STACKTOP = sp;return;
 }
 $214 = $208 << 1;
 $215 = ($214|0)==(0);
 if ($215) {
  $$0$i$i$i$i$i2 = 0;$225 = $204;
 } else {
  $216 = HEAP32[$200>>2]|0;
  $217 = HEAP32[$216>>2]|0;
  $218 = HEAP32[$217>>2]|0;
  $219 = (($218) + 8|0);
  $220 = HEAP32[$219>>2]|0;
  $221 = (($200) + 4|0);
  $222 = HEAP32[$221>>2]|0;
  $223 = (FUNCTION_TABLE_iiiiii[$220 & 255]($217,$214,$222,535536,117)|0);
  $$pre$i$i$i$i1 = HEAP32[$203>>2]|0;
  $$0$i$i$i$i$i2 = $223;$225 = $$pre$i$i$i$i1;
 }
 $224 = ($225|0)==(0|0);
 if (!($224)) {
  _memcpy(($$0$i$i$i$i$i2|0),($225|0),($207|0))|0;
  $226 = HEAP32[$203>>2]|0;
  $227 = ($226|0)==(0|0);
  if (!($227)) {
   $228 = HEAP32[$200>>2]|0;
   $229 = HEAP32[$228>>2]|0;
   $230 = HEAP32[$229>>2]|0;
   $231 = (($230) + 12|0);
   $232 = HEAP32[$231>>2]|0;
   FUNCTION_TABLE_vii[$232 & 4095]($229,$226);
  }
 }
 HEAP32[$203>>2] = $$0$i$i$i$i$i2;
 $233 = (($$0$i$i$i$i$i2) + ($207)|0);
 HEAP32[$201>>2] = $233;
 $234 = (($$0$i$i$i$i$i2) + ($214)|0);
 HEAP32[$209>>2] = $234;
 $236 = $233;
 $235 = HEAP8[$199>>0]|0;
 HEAP8[$236>>0] = $235;
 $237 = (($199) + 1|0);
 $238 = HEAP8[$237>>0]|0;
 $239 = (($236) + 1|0);
 HEAP8[$239>>0] = $238;
 $240 = (($199) + 2|0);
 $241 = HEAP8[$240>>0]|0;
 $242 = (($236) + 2|0);
 HEAP8[$242>>0] = $241;
 $243 = (($199) + 3|0);
 $244 = HEAP8[$243>>0]|0;
 $245 = (($236) + 3|0);
 HEAP8[$245>>0] = $244;
 $246 = HEAP32[$201>>2]|0;
 $247 = (($246) + 4|0);
 HEAP32[$201>>2] = $247;
 STACKTOP = sp;return;
}
function __ZN5physx7profile12MemoryBufferINS0_21WrapperNamedAllocatorEE5writeIyEEvRKT_($this,$inValue) {
 $this = $this|0;
 $inValue = $inValue|0;
 var $$0$i$i$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6) + 8)|0;
 $8 = (($this) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) - ($5))|0;
 $12 = ($11>>>0)>($7>>>0);
 if ($12) {
  $35 = $1;
 } else {
  $13 = $7 << 1;
  $14 = ($13|0)==(0);
  if ($14) {
   $$0$i$i$i = 0;$24 = $3;
  } else {
   $15 = HEAP32[$this>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (FUNCTION_TABLE_iiiiii[$19 & 255]($16,$13,$21,535536,117)|0);
   $$pre$i$i = HEAP32[$2>>2]|0;
   $$0$i$i$i = $22;$24 = $$pre$i$i;
  }
  $23 = ($24|0)==(0|0);
  if (!($23)) {
   _memcpy(($$0$i$i$i|0),($24|0),($6|0))|0;
   $25 = HEAP32[$2>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    $27 = HEAP32[$this>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$28>>2]|0;
    $30 = (($29) + 12|0);
    $31 = HEAP32[$30>>2]|0;
    FUNCTION_TABLE_vii[$31 & 4095]($28,$25);
   }
  }
  HEAP32[$2>>2] = $$0$i$i$i;
  $32 = (($$0$i$i$i) + ($6)|0);
  HEAP32[$0>>2] = $32;
  $33 = (($$0$i$i$i) + ($13)|0);
  HEAP32[$8>>2] = $33;
  $35 = $32;
 }
 $34 = HEAP8[$inValue>>0]|0;
 HEAP8[$35>>0] = $34;
 $36 = (($inValue) + 1|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = (($35) + 1|0);
 HEAP8[$38>>0] = $37;
 $39 = (($inValue) + 2|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = (($35) + 2|0);
 HEAP8[$41>>0] = $40;
 $42 = (($inValue) + 3|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = (($35) + 3|0);
 HEAP8[$44>>0] = $43;
 $45 = (($inValue) + 4|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = (($35) + 4|0);
 HEAP8[$47>>0] = $46;
 $48 = (($inValue) + 5|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = (($35) + 5|0);
 HEAP8[$50>>0] = $49;
 $51 = (($inValue) + 6|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = (($35) + 6|0);
 HEAP8[$53>>0] = $52;
 $54 = (($inValue) + 7|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = (($35) + 7|0);
 HEAP8[$56>>0] = $55;
 $57 = HEAP32[$0>>2]|0;
 $58 = (($57) + 8|0);
 HEAP32[$0>>2] = $58;
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10eventValueEtjyx($this,$inId,$threadId,$0,$1,$2,$3) {
 $this = $this|0;
 $inId = $inId|0;
 $threadId = $threadId|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$0$i$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i = 0, $idx$01$i$i$i = 0, $phitmp2 = 0, $theEvent = 0, $theHeader = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $theEvent = sp;
 $theHeader = sp + 24|0;
 $4 = (($this) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($5) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($8);
 }
 ;HEAP32[$theEvent+0>>2]=0|0;HEAP32[$theEvent+4>>2]=0|0;HEAP32[$theEvent+8>>2]=0|0;HEAP32[$theEvent+12>>2]=0|0;HEAP32[$theEvent+16>>2]=0|0;HEAP32[$theEvent+20>>2]=0|0;
 $9 = (($theEvent) + 8|0);
 $10 = $9;
 $11 = $10;
 HEAP32[$11>>2] = $0;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $1;
 $14 = (($theEvent) + 16|0);
 HEAP32[$14>>2] = $threadId;
 HEAP8[$theHeader>>0] = 5;
 $15 = (($theHeader) + 1|0);
 $16 = (($theHeader) + 2|0);
 HEAP16[$16>>1] = $inId;
 HEAP8[$15>>0] = 3;
 $17 = $theEvent;
 $18 = $17;
 HEAP32[$18>>2] = $2;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $3;
 $21 = ($1>>>0)<(0);
 $22 = ($1|0)==(0);
 $23 = ($0>>>0)<(256);
 $24 = $22 & $23;
 $25 = $21 | $24;
 if ($25) {
  $$0$i$i$i = 3;
 } else {
  $26 = ($1>>>0)<(0);
  $27 = ($1|0)==(0);
  $28 = ($0>>>0)<(65536);
  $29 = $27 & $28;
  $30 = $26 | $29;
  if ($30) {
   $$0$i$i$i = 7;
  } else {
   $31 = ($1>>>0)<(1);
   $32 = ($1|0)==(1);
   $33 = ($0>>>0)<(0);
   $34 = $32 & $33;
   $35 = $31 | $34;
   $phitmp2 = $35 ? 11 : 15;
   $$0$i$i$i = $phitmp2;
  }
 }
 HEAP8[$15>>0] = $$0$i$i$i;
 $36 = (($this) + 80|0);
 __ZN5physx7profile11EventHeader9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_($theHeader,$36);
 __ZN5physx7profile10EventValue9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_RKNS0_11EventHeaderE($theEvent,$36,$theHeader);
 $37 = (($this) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($this) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = $38;
 $42 = $40;
 $43 = (($41) - ($42))|0;
 $44 = (($this) + 44|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($43>>>0)<($45>>>0);
 if (!($46)) {
  $47 = HEAP32[$4>>2]|0;
  $48 = ($47|0)==(0|0);
  if ($48) {
   $52 = $38;$54 = $40;
  } else {
   $49 = (($47) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   __ZN5physx6shdfnd9MutexImpl4lockEv($50);
   $$pre = HEAP32[$39>>2]|0;
   $$pre1 = HEAP32[$37>>2]|0;
   $52 = $$pre1;$54 = $$pre;
  }
  $51 = $52;
  $53 = $54;
  $55 = (($51) - ($53))|0;
  $56 = (($this) + 36|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0);
  if ($58) {
   $67 = $54;
  } else {
   $59 = (($this) + 32|0);
   $idx$01$i$i$i = 0;
   while(1) {
    $60 = HEAP32[$59>>2]|0;
    $61 = (($60) + ($idx$01$i$i$i<<2)|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = HEAP32[$62>>2]|0;
    $64 = (($63) + 8|0);
    $65 = HEAP32[$64>>2]|0;
    FUNCTION_TABLE_viii[$65 & 4095]($62,$54,$55);
    $66 = (($idx$01$i$i$i) + 1)|0;
    $exitcond$i$i$i = ($66|0)==($57|0);
    if ($exitcond$i$i$i) {
     break;
    } else {
     $idx$01$i$i$i = $66;
    }
   }
   $$pre$i$i = HEAP32[$39>>2]|0;
   $67 = $$pre$i$i;
  }
  HEAP32[$37>>2] = $67;
  $68 = HEAP32[$this>>2]|0;
  $69 = (($68) + 16|0);
  $70 = HEAP32[$69>>2]|0;
  FUNCTION_TABLE_vi[$70 & 4095]($this);
  if (!($48)) {
   $71 = (($47) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   __ZN5physx6shdfnd9MutexImpl6unlockEv($72);
  }
 }
 if ($6) {
  STACKTOP = sp;return;
 }
 $73 = (($5) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($74);
 STACKTOP = sp;return;
}
function __ZN5physx7profile10EventValue9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_RKNS0_11EventHeaderE($this,$inStream,$inHeader) {
 $this = $this|0;
 $inStream = $inStream|0;
 $inHeader = $inHeader|0;
 var $$0$i$i$i$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inHeader) + 1|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 & 3;
 __ZN5physx7profile15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEE9streamifyEPKcRKyNS0_27EventStreamCompressionFlags4EnumE($inStream,0,$this,$3);
 $4 = (($this) + 8|0);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5&255;
 $7 = $6 >>> 2;
 $8 = $7 & 3;
 __ZN5physx7profile15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEE9streamifyEPKcRKyNS0_27EventStreamCompressionFlags4EnumE($inStream,0,$4,$8);
 $9 = (($this) + 16|0);
 $10 = HEAP32[$inStream>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $12;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = (($17) + 4)|0;
 $19 = (($10) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 $22 = (($21) - ($16))|0;
 $23 = ($22>>>0)>($18>>>0);
 if ($23) {
  $46 = $12;
 } else {
  $24 = $18 << 1;
  $25 = ($24|0)==(0);
  if ($25) {
   $$0$i$i$i$i$i = 0;$35 = $14;
  } else {
   $26 = HEAP32[$10>>2]|0;
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($10) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (FUNCTION_TABLE_iiiiii[$30 & 255]($27,$24,$32,535536,117)|0);
   $$pre$i$i$i$i = HEAP32[$13>>2]|0;
   $$0$i$i$i$i$i = $33;$35 = $$pre$i$i$i$i;
  }
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   _memcpy(($$0$i$i$i$i$i|0),($35|0),($17|0))|0;
   $36 = HEAP32[$13>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = HEAP32[$10>>2]|0;
    $39 = HEAP32[$38>>2]|0;
    $40 = HEAP32[$39>>2]|0;
    $41 = (($40) + 12|0);
    $42 = HEAP32[$41>>2]|0;
    FUNCTION_TABLE_vii[$42 & 4095]($39,$36);
   }
  }
  HEAP32[$13>>2] = $$0$i$i$i$i$i;
  $43 = (($$0$i$i$i$i$i) + ($17)|0);
  HEAP32[$11>>2] = $43;
  $44 = (($$0$i$i$i$i$i) + ($24)|0);
  HEAP32[$19>>2] = $44;
  $46 = $43;
 }
 $45 = HEAP8[$9>>0]|0;
 HEAP8[$46>>0] = $45;
 $47 = (($9) + 1|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = (($46) + 1|0);
 HEAP8[$49>>0] = $48;
 $50 = (($9) + 2|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = (($46) + 2|0);
 HEAP8[$52>>0] = $51;
 $53 = (($9) + 3|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = (($46) + 3|0);
 HEAP8[$55>>0] = $54;
 $56 = HEAP32[$11>>2]|0;
 $57 = (($56) + 4|0);
 HEAP32[$11>>2] = $57;
 STACKTOP = sp;return;
}
function __ZN5physx7profile15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEE9streamifyEPKcRKyNS0_27EventStreamCompressionFlags4EnumE($this,$nm,$inType,$inFlags) {
 $this = $this|0;
 $nm = $nm|0;
 $inType = $inType|0;
 $inFlags = $inFlags|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i2 = 0, $$0$i$i$i$i$i6 = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i1 = 0, $$pre$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($inFlags|0) == 2)) {
  $94 = $inType;
  $95 = $94;
  $96 = HEAP32[$95>>2]|0;
  $97 = (($94) + 4)|0;
  $98 = $97;
  $99 = HEAP32[$98>>2]|0;
  $100 = $96&255;
  $101 = $96 >>> 8;
  $102 = $101&255;
  $103 = $96 >>> 16;
  $104 = $103&255;
  $105 = $96 >>> 24;
  $106 = $105&255;
  $107 = HEAP32[$this>>2]|0;
  $108 = (($107) + 12|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($107) + 8|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = $109;
  $113 = $111;
  $114 = (($112) - ($113))|0;
  $115 = (($114) + 4)|0;
  $116 = (($107) + 16|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = $117;
  $119 = (($118) - ($113))|0;
  $120 = ($119>>>0)>($115>>>0);
  if ($120) {
   $142 = $109;
  } else {
   $121 = $115 << 1;
   $122 = ($121|0)==(0);
   if ($122) {
    $$0$i$i$i$i$i6 = 0;$132 = $111;
   } else {
    $123 = HEAP32[$107>>2]|0;
    $124 = HEAP32[$123>>2]|0;
    $125 = HEAP32[$124>>2]|0;
    $126 = (($125) + 8|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = (($107) + 4|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = (FUNCTION_TABLE_iiiiii[$127 & 255]($124,$121,$129,535536,117)|0);
    $$pre$i$i$i$i5 = HEAP32[$110>>2]|0;
    $$0$i$i$i$i$i6 = $130;$132 = $$pre$i$i$i$i5;
   }
   $131 = ($132|0)==(0|0);
   if (!($131)) {
    _memcpy(($$0$i$i$i$i$i6|0),($132|0),($114|0))|0;
    $133 = HEAP32[$110>>2]|0;
    $134 = ($133|0)==(0|0);
    if (!($134)) {
     $135 = HEAP32[$107>>2]|0;
     $136 = HEAP32[$135>>2]|0;
     $137 = HEAP32[$136>>2]|0;
     $138 = (($137) + 12|0);
     $139 = HEAP32[$138>>2]|0;
     FUNCTION_TABLE_vii[$139 & 4095]($136,$133);
    }
   }
   HEAP32[$110>>2] = $$0$i$i$i$i$i6;
   $140 = (($$0$i$i$i$i$i6) + ($114)|0);
   HEAP32[$108>>2] = $140;
   $141 = (($$0$i$i$i$i$i6) + ($121)|0);
   HEAP32[$116>>2] = $141;
   $142 = $140;
  }
  HEAP8[$142>>0] = $100;
  $143 = (($142) + 1|0);
  HEAP8[$143>>0] = $102;
  $144 = (($142) + 2|0);
  HEAP8[$144>>0] = $104;
  $145 = (($142) + 3|0);
  HEAP8[$145>>0] = $106;
  $146 = HEAP32[$108>>2]|0;
  $147 = (($146) + 4|0);
  HEAP32[$108>>2] = $147;
  STACKTOP = sp;return;
 } else if ((($inFlags|0) == 0)) {
  $0 = $inType;
  $1 = $0;
  $2 = HEAP32[$1>>2]|0;
  $3 = (($0) + 4)|0;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = $2&255;
  $7 = HEAP32[$this>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $9;
  $13 = $11;
  $14 = (($12) - ($13))|0;
  $15 = (($14) + 1)|0;
  $16 = (($7) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17;
  $19 = (($18) - ($13))|0;
  $20 = ($19>>>0)>($15>>>0);
  if ($20) {
   $42 = $9;
  } else {
   $21 = $15 << 1;
   $22 = ($21|0)==(0);
   if ($22) {
    $$0$i$i$i$i$i = 0;$32 = $11;
   } else {
    $23 = HEAP32[$7>>2]|0;
    $24 = HEAP32[$23>>2]|0;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 8|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($7) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (FUNCTION_TABLE_iiiiii[$27 & 255]($24,$21,$29,535536,117)|0);
    $$pre$i$i$i$i = HEAP32[$10>>2]|0;
    $$0$i$i$i$i$i = $30;$32 = $$pre$i$i$i$i;
   }
   $31 = ($32|0)==(0|0);
   if (!($31)) {
    _memcpy(($$0$i$i$i$i$i|0),($32|0),($14|0))|0;
    $33 = HEAP32[$10>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     $35 = HEAP32[$7>>2]|0;
     $36 = HEAP32[$35>>2]|0;
     $37 = HEAP32[$36>>2]|0;
     $38 = (($37) + 12|0);
     $39 = HEAP32[$38>>2]|0;
     FUNCTION_TABLE_vii[$39 & 4095]($36,$33);
    }
   }
   HEAP32[$10>>2] = $$0$i$i$i$i$i;
   $40 = (($$0$i$i$i$i$i) + ($14)|0);
   HEAP32[$8>>2] = $40;
   $41 = (($$0$i$i$i$i$i) + ($21)|0);
   HEAP32[$16>>2] = $41;
   $42 = $40;
  }
  HEAP8[$42>>0] = $6;
  $43 = HEAP32[$8>>2]|0;
  $44 = (($43) + 1|0);
  HEAP32[$8>>2] = $44;
  STACKTOP = sp;return;
 } else if ((($inFlags|0) == 1)) {
  $45 = $inType;
  $46 = $45;
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + 4)|0;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = $47&65535;
  $52 = $47&255;
  $53 = ($51&65535) >>> 8;
  $54 = $53&255;
  $55 = HEAP32[$this>>2]|0;
  $56 = (($55) + 12|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($55) + 8|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $57;
  $61 = $59;
  $62 = (($60) - ($61))|0;
  $63 = (($62) + 2)|0;
  $64 = (($55) + 16|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = $65;
  $67 = (($66) - ($61))|0;
  $68 = ($67>>>0)>($63>>>0);
  if ($68) {
   $90 = $57;
  } else {
   $69 = $63 << 1;
   $70 = ($69|0)==(0);
   if ($70) {
    $$0$i$i$i$i$i2 = 0;$80 = $59;
   } else {
    $71 = HEAP32[$55>>2]|0;
    $72 = HEAP32[$71>>2]|0;
    $73 = HEAP32[$72>>2]|0;
    $74 = (($73) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($55) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (FUNCTION_TABLE_iiiiii[$75 & 255]($72,$69,$77,535536,117)|0);
    $$pre$i$i$i$i1 = HEAP32[$58>>2]|0;
    $$0$i$i$i$i$i2 = $78;$80 = $$pre$i$i$i$i1;
   }
   $79 = ($80|0)==(0|0);
   if (!($79)) {
    _memcpy(($$0$i$i$i$i$i2|0),($80|0),($62|0))|0;
    $81 = HEAP32[$58>>2]|0;
    $82 = ($81|0)==(0|0);
    if (!($82)) {
     $83 = HEAP32[$55>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = HEAP32[$84>>2]|0;
     $86 = (($85) + 12|0);
     $87 = HEAP32[$86>>2]|0;
     FUNCTION_TABLE_vii[$87 & 4095]($84,$81);
    }
   }
   HEAP32[$58>>2] = $$0$i$i$i$i$i2;
   $88 = (($$0$i$i$i$i$i2) + ($62)|0);
   HEAP32[$56>>2] = $88;
   $89 = (($$0$i$i$i$i$i2) + ($69)|0);
   HEAP32[$64>>2] = $89;
   $90 = $88;
  }
  HEAP8[$90>>0] = $52;
  $91 = (($90) + 1|0);
  HEAP8[$91>>0] = $54;
  $92 = HEAP32[$56>>2]|0;
  $93 = (($92) + 2|0);
  HEAP32[$56>>2] = $93;
  STACKTOP = sp;return;
 } else {
  $148 = HEAP32[$this>>2]|0;
  __ZN5physx7profile12MemoryBufferINS0_21WrapperNamedAllocatorEE5writeIyEEvRKT_($148,$inType);
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE6createERS4_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $h$0 = 0, $h$1 = 0, $index$0 = 0, $index$05 = 0, $index$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP16[$k>>1]|0;
   $4 = $3&65535;
   $5 = $4 << 15;
   $6 = $5 ^ -1;
   $7 = (($4) + ($6))|0;
   $8 = $7 >>> 10;
   $9 = $8 ^ $7;
   $10 = ($9*9)|0;
   $11 = $10 >>> 6;
   $12 = $11 ^ $10;
   $13 = $12 << 11;
   $14 = $13 ^ -1;
   $15 = (($12) + ($14))|0;
   $16 = $15 >>> 16;
   $17 = $16 ^ $15;
   $18 = (($1) + -1)|0;
   $19 = $17 & $18;
   $20 = (($this) + 16|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<2)|0);
   $index$05 = HEAP32[$22>>2]|0;
   $23 = ($index$05|0)==(-1);
   if ($23) {
    $h$0 = $19;
   } else {
    $24 = (($this) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($this) + 12|0);
    $index$06 = $index$05;
    while(1) {
     $27 = (($25) + ($index$06<<3)|0);
     $28 = HEAP16[$27>>1]|0;
     $29 = ($28<<16>>16)==($3<<16>>16);
     if ($29) {
      break;
     }
     $30 = HEAP32[$26>>2]|0;
     $31 = (($30) + ($index$06<<2)|0);
     $index$0 = HEAP32[$31>>2]|0;
     $32 = ($index$0|0)==(-1);
     if ($32) {
      $h$0 = $19;
      break L1;
     } else {
      $index$06 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $33 = (($25) + ($index$06<<3)|0);
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $34 = (($this) + 40|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($35|0)==($37|0);
 if ($38) {
  $39 = $1 << 1;
  $$$i = $2 ? 16 : $39;
  $40 = ($1>>>0)<($$$i>>>0);
  if ($40) {
   __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $57 = $$pre;
  } else {
   $57 = $1;
  }
  $41 = HEAP16[$k>>1]|0;
  $42 = $41&65535;
  $43 = $42 << 15;
  $44 = $43 ^ -1;
  $45 = (($42) + ($44))|0;
  $46 = $45 >>> 10;
  $47 = $46 ^ $45;
  $48 = ($47*9)|0;
  $49 = $48 >>> 6;
  $50 = $49 ^ $48;
  $51 = $50 << 11;
  $52 = $51 ^ -1;
  $53 = (($50) + ($52))|0;
  $54 = $53 >>> 16;
  $55 = $54 ^ $53;
  $56 = (($57) + -1)|0;
  $58 = $55 & $56;
  $h$1 = $58;
 } else {
  $h$1 = $h$0;
 }
 $59 = (($this) + 32|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + 1)|0;
 HEAP32[$59>>2] = $61;
 $62 = (($this) + 16|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + ($h$1<<2)|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($this) + 12|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + ($60<<2)|0);
 HEAP32[$68>>2] = $65;
 HEAP32[$64>>2] = $60;
 $69 = HEAP32[$34>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$34>>2] = $70;
 $71 = (($this) + 36|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + 1)|0;
 HEAP32[$71>>2] = $73;
 $74 = (($this) + 8|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($75) + ($60<<3)|0);
 $$0 = $76;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKtPKcEEtNS0_4HashItEENS1_11HashMapBaseItS6_S9_NS_7profile26WrapperReflectionAllocatorIS6_EEE6GetKeyESD_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $index$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 28|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = $21 << 3;
 $29 = (($27) + ($28))|0;
 $30 = HEAP32[$this>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (FUNCTION_TABLE_iiiiii[$34 & 255]($31,$29,535200,535112,354)|0);
 $36 = (($35) + ($22)|0);
 $37 = (($35) + ($27)|0);
 _memset(($35|0),-1,($22|0))|0;
 $38 = (($this) + 40|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 if (!($40)) {
  $41 = (($this) + 8|0);
  $42 = (($$0) + -1)|0;
  $index$01 = 0;
  while(1) {
   $43 = HEAP32[$41>>2]|0;
   $44 = (($43) + ($index$01<<3)|0);
   $45 = HEAP16[$44>>1]|0;
   $46 = $45&65535;
   $47 = $46 << 15;
   $48 = $47 ^ -1;
   $49 = (($46) + ($48))|0;
   $50 = $49 >>> 10;
   $51 = $50 ^ $49;
   $52 = ($51*9)|0;
   $53 = $52 >>> 6;
   $54 = $53 ^ $52;
   $55 = $54 << 11;
   $56 = $55 ^ -1;
   $57 = (($54) + ($56))|0;
   $58 = $57 >>> 16;
   $59 = $58 ^ $57;
   $60 = $59 & $42;
   $61 = (($35) + ($60<<2)|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($36) + ($index$01<<2)|0);
   HEAP32[$63>>2] = $62;
   HEAP32[$61>>2] = $index$01;
   $64 = (($37) + ($index$01<<3)|0);
   $65 = ($64|0)==(0|0);
   if (!($65)) {
    HEAP16[$64>>1] = $45;
    $66 = ((($37) + ($index$01<<3)|0) + 4|0);
    $67 = ((($43) + ($index$01<<3)|0) + 4|0);
    $68 = HEAP32[$67>>2]|0;
    HEAP32[$66>>2] = $68;
   }
   $69 = (($index$01) + 1)|0;
   $70 = HEAP32[$38>>2]|0;
   $71 = ($69>>>0)<($70>>>0);
   if ($71) {
    $index$01 = $69;
   } else {
    break;
   }
  }
 }
 $72 = (($this) + 4|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(0|0);
 if (!($74)) {
  $75 = HEAP32[$this>>2]|0;
  $76 = HEAP32[$75>>2]|0;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($77) + 12|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_vii[$79 & 4095]($76,$73);
 }
 HEAP32[$72>>2] = $35;
 $80 = (($this) + 16|0);
 HEAP32[$80>>2] = $35;
 $81 = (($this) + 24|0);
 HEAP32[$81>>2] = $$0;
 $82 = (($this) + 12|0);
 HEAP32[$82>>2] = $36;
 $83 = (($this) + 8|0);
 HEAP32[$83>>2] = $37;
 HEAP32[$15>>2] = $21;
 $84 = (($this) + 32|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($85|0)==(-1);
 if (!($86)) {
  STACKTOP = sp;return;
 }
 HEAP32[$84>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE9stopEventEtyj($this,$inId,$0,$1,$threadId) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 $threadId = $threadId|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theEvent$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $2 = sp + 24|0;
 $theEvent$i = sp;
 $3 = (__ZN5physx6shdfnd4Time22getCurrentCounterValueEv()|0);
 $4 = tempRet0;
 $5 = (($this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($6) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($9);
 }
 ;HEAP32[$theEvent$i+0>>2]=0|0;HEAP32[$theEvent$i+4>>2]=0|0;HEAP32[$theEvent$i+8>>2]=0|0;HEAP32[$theEvent$i+12>>2]=0|0;
 $10 = $theEvent$i;
 $11 = $10;
 HEAP32[$11>>2] = $0;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $1;
 $14 = (($theEvent$i) + 8|0);
 HEAP32[$14>>2] = $threadId;
 $15 = (($theEvent$i) + 12|0);
 HEAP8[$15>>0] = 0;
 $16 = (($theEvent$i) + 13|0);
 HEAP8[$16>>0] = 0;
 $17 = (($theEvent$i) + 16|0);
 $18 = $17;
 $19 = $18;
 HEAP32[$19>>2] = $3;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $4;
 $22 = (($this) + 88|0);
 $23 = (($this) + 96|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($threadId|0);
 if ($25) {
  $26 = $22;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = ($28|0)==($0|0);
  $33 = ($31|0)==($1|0);
  $34 = $32 & $33;
  if ($34) {
   $35 = (($this) + 100|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    $38 = (($this) + 101|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = ($39<<24>>24)==(0);
    if ($40) {
     $41 = $2;
     $42 = $41;
     HEAP32[$42>>2] = $3;
     $43 = (($41) + 4)|0;
     $44 = $43;
     HEAP32[$44>>2] = $4;
     __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_17RelativeStopEventEEEvhtRKT_($this,4,$inId,$2);
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  ;HEAP32[$22+0>>2]=HEAP32[$theEvent$i+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$theEvent$i+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$theEvent$i+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$theEvent$i+12>>2]|0;
  __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_9StopEventEEEvhtRKT_($this,2,$inId,$theEvent$i);
 }
 if ($7) {
  STACKTOP = sp;return;
 }
 $45 = (($6) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($46);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_17RelativeStopEventEEEvhtRKT_($this,$inEventType,$eventId,$inType) {
 $this = $this|0;
 $inEventType = $inEventType|0;
 $eventId = $eventId|0;
 $inType = $inType|0;
 var $$$i$i = 0, $$0$i$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $exitcond$i$i$i = 0, $idx$01$i$i$i = 0, $theHeader = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theHeader = sp;
 HEAP8[$theHeader>>0] = $inEventType;
 $0 = (($theHeader) + 1|0);
 $1 = (($theHeader) + 2|0);
 HEAP16[$1>>1] = $eventId;
 $2 = $inType;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 104|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 HEAP8[$0>>0] = 3;
 $15 = ($11|0)==(0);
 $16 = ($14|0)==(0);
 $17 = $15 & $16;
 if ($17) {
  $41 = $4;$44 = $7;
 } else {
  $18 = (_i64Subtract(($4|0),($7|0),($11|0),($14|0))|0);
  $19 = tempRet0;
  $20 = ($19>>>0)<(0);
  $21 = ($19|0)==(0);
  $22 = ($18>>>0)<(256);
  $23 = $21 & $22;
  $24 = $20 | $23;
  if ($24) {
   $$0$i$i$i = 0;
  } else {
   $25 = ($19>>>0)<(0);
   $26 = ($19|0)==(0);
   $27 = ($18>>>0)<(65536);
   $28 = $26 & $27;
   $29 = $25 | $28;
   if ($29) {
    $$0$i$i$i = 1;
   } else {
    $30 = ($19>>>0)<(1);
    $31 = ($19|0)==(1);
    $32 = ($18>>>0)<(0);
    $33 = $31 & $32;
    $34 = $30 | $33;
    $$$i$i = $34 ? 2 : 3;
    $$0$i$i$i = $$$i$i;
   }
  }
  $35 = $$0$i$i$i&255;
  HEAP8[$0>>0] = $35;
  $36 = ($$0$i$i$i|0)==(3);
  $37 = $36 ? $4 : $18;
  $38 = $36 ? $7 : $19;
  $41 = $37;$44 = $38;
 }
 $39 = $inType;
 $40 = $39;
 HEAP32[$40>>2] = $41;
 $42 = (($39) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $44;
 $45 = $8;
 $46 = $45;
 HEAP32[$46>>2] = $4;
 $47 = (($45) + 4)|0;
 $48 = $47;
 HEAP32[$48>>2] = $7;
 $49 = (($this) + 80|0);
 __ZN5physx7profile11EventHeader9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_($theHeader,$49);
 $50 = HEAP8[$0>>0]|0;
 $51 = $50&255;
 $52 = $51 & 3;
 __ZN5physx7profile15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEE9streamifyEPKcRKyNS0_27EventStreamCompressionFlags4EnumE($49,0,$inType,$52);
 $53 = (($this) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($this) + 16|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = $54;
 $58 = $56;
 $59 = (($57) - ($58))|0;
 $60 = (($this) + 44|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($59>>>0)<($61>>>0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 72|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  $69 = $54;$71 = $56;
 } else {
  $66 = (($64) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($67);
  $$pre = HEAP32[$55>>2]|0;
  $$pre1 = HEAP32[$53>>2]|0;
  $69 = $$pre1;$71 = $$pre;
 }
 $68 = $69;
 $70 = $71;
 $72 = (($68) - ($70))|0;
 $73 = (($this) + 36|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if ($75) {
  $84 = $71;
 } else {
  $76 = (($this) + 32|0);
  $idx$01$i$i$i = 0;
  while(1) {
   $77 = HEAP32[$76>>2]|0;
   $78 = (($77) + ($idx$01$i$i$i<<2)|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = HEAP32[$79>>2]|0;
   $81 = (($80) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   FUNCTION_TABLE_viii[$82 & 4095]($79,$71,$72);
   $83 = (($idx$01$i$i$i) + 1)|0;
   $exitcond$i$i$i = ($83|0)==($74|0);
   if ($exitcond$i$i$i) {
    break;
   } else {
    $idx$01$i$i$i = $83;
   }
  }
  $$pre$i$i = HEAP32[$55>>2]|0;
  $84 = $$pre$i$i;
 }
 HEAP32[$53>>2] = $84;
 $85 = HEAP32[$this>>2]|0;
 $86 = (($85) + 16|0);
 $87 = HEAP32[$86>>2]|0;
 FUNCTION_TABLE_vi[$87 & 4095]($this);
 if ($65) {
  STACKTOP = sp;return;
 }
 $88 = (($64) + 4|0);
 $89 = HEAP32[$88>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($89);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_9StopEventEEEvhtRKT_($this,$inEventType,$eventId,$inType) {
 $this = $this|0;
 $inEventType = $inEventType|0;
 $eventId = $eventId|0;
 $inType = $inType|0;
 var $$$i$i = 0, $$$i$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i = 0, $idx$01$i$i$i = 0, $theHeader = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theHeader = sp;
 HEAP8[$theHeader>>0] = $inEventType;
 $0 = (($theHeader) + 1|0);
 $1 = (($theHeader) + 2|0);
 HEAP16[$1>>1] = $eventId;
 $2 = (($inType) + 16|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 104|0);
 $10 = $9;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 HEAP8[$0>>0] = 3;
 $16 = ($12|0)==(0);
 $17 = ($15|0)==(0);
 $18 = $16 & $17;
 if ($18) {
  $42 = $5;$45 = $8;$68 = 3;
 } else {
  $19 = (_i64Subtract(($5|0),($8|0),($12|0),($15|0))|0);
  $20 = tempRet0;
  $21 = ($20>>>0)<(0);
  $22 = ($20|0)==(0);
  $23 = ($19>>>0)<(256);
  $24 = $22 & $23;
  $25 = $21 | $24;
  if ($25) {
   $$0$i$i$i$i = 0;
  } else {
   $26 = ($20>>>0)<(0);
   $27 = ($20|0)==(0);
   $28 = ($19>>>0)<(65536);
   $29 = $27 & $28;
   $30 = $26 | $29;
   if ($30) {
    $$0$i$i$i$i = 1;
   } else {
    $31 = ($20>>>0)<(1);
    $32 = ($20|0)==(1);
    $33 = ($19>>>0)<(0);
    $34 = $32 & $33;
    $35 = $31 | $34;
    $$$i$i$i = $35 ? 2 : 3;
    $$0$i$i$i$i = $$$i$i$i;
   }
  }
  $36 = $$0$i$i$i$i&255;
  HEAP8[$0>>0] = $36;
  $37 = ($$0$i$i$i$i|0)==(3);
  $38 = $37 ? $5 : $19;
  $39 = $37 ? $8 : $20;
  $42 = $38;$45 = $39;$68 = $$0$i$i$i$i;
 }
 $40 = $2;
 $41 = $40;
 HEAP32[$41>>2] = $42;
 $43 = (($40) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $45;
 $46 = $inType;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51>>>0)<(0);
 $53 = ($51|0)==(0);
 $54 = ($48>>>0)<(256);
 $55 = $53 & $54;
 $56 = $52 | $55;
 if ($56) {
  $$0$i$i$i = 0;
 } else {
  $57 = ($51>>>0)<(0);
  $58 = ($51|0)==(0);
  $59 = ($48>>>0)<(65536);
  $60 = $58 & $59;
  $61 = $57 | $60;
  if ($61) {
   $$0$i$i$i = 4;
  } else {
   $62 = ($51>>>0)<(1);
   $63 = ($51|0)==(1);
   $64 = ($48>>>0)<(0);
   $65 = $63 & $64;
   $66 = $62 | $65;
   $$$i$i = $66 ? 8 : 12;
   $$0$i$i$i = $$$i$i;
  }
 }
 $67 = $68 | $$0$i$i$i;
 $69 = $67&255;
 HEAP8[$0>>0] = $69;
 $70 = $9;
 $71 = $70;
 HEAP32[$71>>2] = $5;
 $72 = (($70) + 4)|0;
 $73 = $72;
 HEAP32[$73>>2] = $8;
 $74 = (($this) + 80|0);
 __ZN5physx7profile11EventHeader9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_($theHeader,$74);
 $75 = HEAP8[$0>>0]|0;
 $76 = $75&255;
 $77 = $76 >>> 2;
 $78 = $77 & 3;
 __ZN5physx7profile23EventContextInformation9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_NS0_27EventStreamCompressionFlags4EnumE($inType,$74,$78);
 $79 = $76 & 3;
 __ZN5physx7profile15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEE9streamifyEPKcRKyNS0_27EventStreamCompressionFlags4EnumE($74,0,$2,$79);
 $80 = (($this) + 20|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($this) + 16|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = $81;
 $85 = $83;
 $86 = (($84) - ($85))|0;
 $87 = (($this) + 44|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($86>>>0)<($88>>>0);
 if ($89) {
  STACKTOP = sp;return;
 }
 $90 = (($this) + 72|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)==(0|0);
 if ($92) {
  $96 = $81;$98 = $83;
 } else {
  $93 = (($91) + 4|0);
  $94 = HEAP32[$93>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($94);
  $$pre = HEAP32[$82>>2]|0;
  $$pre1 = HEAP32[$80>>2]|0;
  $96 = $$pre1;$98 = $$pre;
 }
 $95 = $96;
 $97 = $98;
 $99 = (($95) - ($97))|0;
 $100 = (($this) + 36|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==(0);
 if ($102) {
  $111 = $98;
 } else {
  $103 = (($this) + 32|0);
  $idx$01$i$i$i = 0;
  while(1) {
   $104 = HEAP32[$103>>2]|0;
   $105 = (($104) + ($idx$01$i$i$i<<2)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = HEAP32[$106>>2]|0;
   $108 = (($107) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   FUNCTION_TABLE_viii[$109 & 4095]($106,$98,$99);
   $110 = (($idx$01$i$i$i) + 1)|0;
   $exitcond$i$i$i = ($110|0)==($101|0);
   if ($exitcond$i$i$i) {
    break;
   } else {
    $idx$01$i$i$i = $110;
   }
  }
  $$pre$i$i = HEAP32[$82>>2]|0;
  $111 = $$pre$i$i;
 }
 HEAP32[$80>>2] = $111;
 $112 = HEAP32[$this>>2]|0;
 $113 = (($112) + 16|0);
 $114 = HEAP32[$113>>2]|0;
 FUNCTION_TABLE_vi[$114 & 4095]($this);
 if ($92) {
  STACKTOP = sp;return;
 }
 $115 = (($91) + 4|0);
 $116 = HEAP32[$115>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($116);
 STACKTOP = sp;return;
}
function __ZN5physx7profile23EventContextInformation9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_NS0_27EventStreamCompressionFlags4EnumE($this,$inStream,$inContextIdFlags) {
 $this = $this|0;
 $inStream = $inStream|0;
 $inContextIdFlags = $inContextIdFlags|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i2 = 0, $$0$i$i$i$i$i6 = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i1 = 0, $$pre$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$inStream>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8) + 4)|0;
 $10 = (($1) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($7))|0;
 $14 = ($13>>>0)>($9>>>0);
 if ($14) {
  $37 = $3;
 } else {
  $15 = $9 << 1;
  $16 = ($15|0)==(0);
  if ($16) {
   $$0$i$i$i$i$i = 0;$26 = $5;
  } else {
   $17 = HEAP32[$1>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($1) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (FUNCTION_TABLE_iiiiii[$21 & 255]($18,$15,$23,535536,117)|0);
   $$pre$i$i$i$i = HEAP32[$4>>2]|0;
   $$0$i$i$i$i$i = $24;$26 = $$pre$i$i$i$i;
  }
  $25 = ($26|0)==(0|0);
  if (!($25)) {
   _memcpy(($$0$i$i$i$i$i|0),($26|0),($8|0))|0;
   $27 = HEAP32[$4>>2]|0;
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    $29 = HEAP32[$1>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + 12|0);
    $33 = HEAP32[$32>>2]|0;
    FUNCTION_TABLE_vii[$33 & 4095]($30,$27);
   }
  }
  HEAP32[$4>>2] = $$0$i$i$i$i$i;
  $34 = (($$0$i$i$i$i$i) + ($8)|0);
  HEAP32[$2>>2] = $34;
  $35 = (($$0$i$i$i$i$i) + ($15)|0);
  HEAP32[$10>>2] = $35;
  $37 = $34;
 }
 $36 = HEAP8[$0>>0]|0;
 HEAP8[$37>>0] = $36;
 $38 = (($0) + 1|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = (($37) + 1|0);
 HEAP8[$40>>0] = $39;
 $41 = (($0) + 2|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = (($37) + 2|0);
 HEAP8[$43>>0] = $42;
 $44 = (($0) + 3|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = (($37) + 3|0);
 HEAP8[$46>>0] = $45;
 $47 = HEAP32[$2>>2]|0;
 $48 = (($47) + 4|0);
 HEAP32[$2>>2] = $48;
 __ZN5physx7profile15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEE9streamifyEPKcRKyNS0_27EventStreamCompressionFlags4EnumE($inStream,0,$this,$inContextIdFlags);
 $49 = (($this) + 12|0);
 $50 = HEAP32[$inStream>>2]|0;
 $51 = HEAP8[$49>>0]|0;
 $52 = (($50) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($50) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $53;
 $57 = $55;
 $58 = (($56) - ($57))|0;
 $59 = (($58) + 1)|0;
 $60 = (($50) + 16|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = $61;
 $63 = (($62) - ($57))|0;
 $64 = ($63>>>0)>($59>>>0);
 if ($64) {
  $86 = $53;
 } else {
  $65 = $59 << 1;
  $66 = ($65|0)==(0);
  if ($66) {
   $$0$i$i$i$i$i2 = 0;$76 = $55;
  } else {
   $67 = HEAP32[$50>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = HEAP32[$68>>2]|0;
   $70 = (($69) + 8|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($50) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (FUNCTION_TABLE_iiiiii[$71 & 255]($68,$65,$73,535536,117)|0);
   $$pre$i$i$i$i1 = HEAP32[$54>>2]|0;
   $$0$i$i$i$i$i2 = $74;$76 = $$pre$i$i$i$i1;
  }
  $75 = ($76|0)==(0|0);
  if (!($75)) {
   _memcpy(($$0$i$i$i$i$i2|0),($76|0),($58|0))|0;
   $77 = HEAP32[$54>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    $79 = HEAP32[$50>>2]|0;
    $80 = HEAP32[$79>>2]|0;
    $81 = HEAP32[$80>>2]|0;
    $82 = (($81) + 12|0);
    $83 = HEAP32[$82>>2]|0;
    FUNCTION_TABLE_vii[$83 & 4095]($80,$77);
   }
  }
  HEAP32[$54>>2] = $$0$i$i$i$i$i2;
  $84 = (($$0$i$i$i$i$i2) + ($58)|0);
  HEAP32[$52>>2] = $84;
  $85 = (($$0$i$i$i$i$i2) + ($65)|0);
  HEAP32[$60>>2] = $85;
  $86 = $84;
 }
 HEAP8[$86>>0] = $51;
 $87 = HEAP32[$52>>2]|0;
 $88 = (($87) + 1|0);
 HEAP32[$52>>2] = $88;
 $89 = (($this) + 13|0);
 $90 = HEAP32[$inStream>>2]|0;
 $91 = HEAP8[$89>>0]|0;
 $92 = (($90) + 12|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($90) + 8|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = $93;
 $97 = $95;
 $98 = (($96) - ($97))|0;
 $99 = (($98) + 1)|0;
 $100 = (($90) + 16|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = $101;
 $103 = (($102) - ($97))|0;
 $104 = ($103>>>0)>($99>>>0);
 if ($104) {
  $126 = $93;
  HEAP8[$126>>0] = $91;
  $127 = HEAP32[$92>>2]|0;
  $128 = (($127) + 1|0);
  HEAP32[$92>>2] = $128;
  STACKTOP = sp;return;
 }
 $105 = $99 << 1;
 $106 = ($105|0)==(0);
 if ($106) {
  $$0$i$i$i$i$i6 = 0;$116 = $95;
 } else {
  $107 = HEAP32[$90>>2]|0;
  $108 = HEAP32[$107>>2]|0;
  $109 = HEAP32[$108>>2]|0;
  $110 = (($109) + 8|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = (($90) + 4|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (FUNCTION_TABLE_iiiiii[$111 & 255]($108,$105,$113,535536,117)|0);
  $$pre$i$i$i$i5 = HEAP32[$94>>2]|0;
  $$0$i$i$i$i$i6 = $114;$116 = $$pre$i$i$i$i5;
 }
 $115 = ($116|0)==(0|0);
 if (!($115)) {
  _memcpy(($$0$i$i$i$i$i6|0),($116|0),($98|0))|0;
  $117 = HEAP32[$94>>2]|0;
  $118 = ($117|0)==(0|0);
  if (!($118)) {
   $119 = HEAP32[$90>>2]|0;
   $120 = HEAP32[$119>>2]|0;
   $121 = HEAP32[$120>>2]|0;
   $122 = (($121) + 12|0);
   $123 = HEAP32[$122>>2]|0;
   FUNCTION_TABLE_vii[$123 & 4095]($120,$117);
  }
 }
 HEAP32[$94>>2] = $$0$i$i$i$i$i6;
 $124 = (($$0$i$i$i$i$i6) + ($98)|0);
 HEAP32[$92>>2] = $124;
 $125 = (($$0$i$i$i$i$i6) + ($105)|0);
 HEAP32[$100>>2] = $125;
 $126 = $124;
 HEAP8[$126>>0] = $91;
 $127 = HEAP32[$92>>2]|0;
 $128 = (($127) + 1|0);
 HEAP32[$92>>2] = $128;
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10startEventEtyj($this,$inId,$0,$1,$threadId) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 $threadId = $threadId|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theEvent$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $2 = sp + 24|0;
 $theEvent$i = sp;
 $3 = (__ZN5physx6shdfnd4Time22getCurrentCounterValueEv()|0);
 $4 = tempRet0;
 $5 = (($this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($6) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($9);
 }
 ;HEAP32[$theEvent$i+0>>2]=0|0;HEAP32[$theEvent$i+4>>2]=0|0;HEAP32[$theEvent$i+8>>2]=0|0;HEAP32[$theEvent$i+12>>2]=0|0;
 $10 = $theEvent$i;
 $11 = $10;
 HEAP32[$11>>2] = $0;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $1;
 $14 = (($theEvent$i) + 8|0);
 HEAP32[$14>>2] = $threadId;
 $15 = (($theEvent$i) + 12|0);
 HEAP8[$15>>0] = 0;
 $16 = (($theEvent$i) + 13|0);
 HEAP8[$16>>0] = 0;
 $17 = (($theEvent$i) + 16|0);
 $18 = $17;
 $19 = $18;
 HEAP32[$19>>2] = $3;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $4;
 $22 = (($this) + 88|0);
 $23 = (($this) + 96|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($threadId|0);
 if ($25) {
  $26 = $22;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = ($28|0)==($0|0);
  $33 = ($31|0)==($1|0);
  $34 = $32 & $33;
  if ($34) {
   $35 = (($this) + 100|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    $38 = (($this) + 101|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = ($39<<24>>24)==(0);
    if ($40) {
     $41 = $2;
     $42 = $41;
     HEAP32[$42>>2] = $3;
     $43 = (($41) + 4)|0;
     $44 = $43;
     HEAP32[$44>>2] = $4;
     __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_18RelativeStartEventEEEvhtRKT_($this,3,$inId,$2);
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  ;HEAP32[$22+0>>2]=HEAP32[$theEvent$i+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$theEvent$i+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$theEvent$i+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$theEvent$i+12>>2]|0;
  __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_10StartEventEEEvhtRKT_($this,1,$inId,$theEvent$i);
 }
 if ($7) {
  STACKTOP = sp;return;
 }
 $45 = (($6) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($46);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_18RelativeStartEventEEEvhtRKT_($this,$inEventType,$eventId,$inType) {
 $this = $this|0;
 $inEventType = $inEventType|0;
 $eventId = $eventId|0;
 $inType = $inType|0;
 var $$$i$i = 0, $$0$i$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $exitcond$i$i$i = 0, $idx$01$i$i$i = 0, $theHeader = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theHeader = sp;
 HEAP8[$theHeader>>0] = $inEventType;
 $0 = (($theHeader) + 1|0);
 $1 = (($theHeader) + 2|0);
 HEAP16[$1>>1] = $eventId;
 $2 = $inType;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 104|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 HEAP8[$0>>0] = 3;
 $15 = ($11|0)==(0);
 $16 = ($14|0)==(0);
 $17 = $15 & $16;
 if ($17) {
  $41 = $4;$44 = $7;
 } else {
  $18 = (_i64Subtract(($4|0),($7|0),($11|0),($14|0))|0);
  $19 = tempRet0;
  $20 = ($19>>>0)<(0);
  $21 = ($19|0)==(0);
  $22 = ($18>>>0)<(256);
  $23 = $21 & $22;
  $24 = $20 | $23;
  if ($24) {
   $$0$i$i$i = 0;
  } else {
   $25 = ($19>>>0)<(0);
   $26 = ($19|0)==(0);
   $27 = ($18>>>0)<(65536);
   $28 = $26 & $27;
   $29 = $25 | $28;
   if ($29) {
    $$0$i$i$i = 1;
   } else {
    $30 = ($19>>>0)<(1);
    $31 = ($19|0)==(1);
    $32 = ($18>>>0)<(0);
    $33 = $31 & $32;
    $34 = $30 | $33;
    $$$i$i = $34 ? 2 : 3;
    $$0$i$i$i = $$$i$i;
   }
  }
  $35 = $$0$i$i$i&255;
  HEAP8[$0>>0] = $35;
  $36 = ($$0$i$i$i|0)==(3);
  $37 = $36 ? $4 : $18;
  $38 = $36 ? $7 : $19;
  $41 = $37;$44 = $38;
 }
 $39 = $inType;
 $40 = $39;
 HEAP32[$40>>2] = $41;
 $42 = (($39) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $44;
 $45 = $8;
 $46 = $45;
 HEAP32[$46>>2] = $4;
 $47 = (($45) + 4)|0;
 $48 = $47;
 HEAP32[$48>>2] = $7;
 $49 = (($this) + 80|0);
 __ZN5physx7profile11EventHeader9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_($theHeader,$49);
 $50 = HEAP8[$0>>0]|0;
 $51 = $50&255;
 $52 = $51 & 3;
 __ZN5physx7profile15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEE9streamifyEPKcRKyNS0_27EventStreamCompressionFlags4EnumE($49,0,$inType,$52);
 $53 = (($this) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($this) + 16|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = $54;
 $58 = $56;
 $59 = (($57) - ($58))|0;
 $60 = (($this) + 44|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($59>>>0)<($61>>>0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 72|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  $69 = $54;$71 = $56;
 } else {
  $66 = (($64) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($67);
  $$pre = HEAP32[$55>>2]|0;
  $$pre1 = HEAP32[$53>>2]|0;
  $69 = $$pre1;$71 = $$pre;
 }
 $68 = $69;
 $70 = $71;
 $72 = (($68) - ($70))|0;
 $73 = (($this) + 36|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if ($75) {
  $84 = $71;
 } else {
  $76 = (($this) + 32|0);
  $idx$01$i$i$i = 0;
  while(1) {
   $77 = HEAP32[$76>>2]|0;
   $78 = (($77) + ($idx$01$i$i$i<<2)|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = HEAP32[$79>>2]|0;
   $81 = (($80) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   FUNCTION_TABLE_viii[$82 & 4095]($79,$71,$72);
   $83 = (($idx$01$i$i$i) + 1)|0;
   $exitcond$i$i$i = ($83|0)==($74|0);
   if ($exitcond$i$i$i) {
    break;
   } else {
    $idx$01$i$i$i = $83;
   }
  }
  $$pre$i$i = HEAP32[$55>>2]|0;
  $84 = $$pre$i$i;
 }
 HEAP32[$53>>2] = $84;
 $85 = HEAP32[$this>>2]|0;
 $86 = (($85) + 16|0);
 $87 = HEAP32[$86>>2]|0;
 FUNCTION_TABLE_vi[$87 & 4095]($this);
 if ($65) {
  STACKTOP = sp;return;
 }
 $88 = (($64) + 4|0);
 $89 = HEAP32[$88>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($89);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_10StartEventEEEvhtRKT_($this,$inEventType,$eventId,$inType) {
 $this = $this|0;
 $inEventType = $inEventType|0;
 $eventId = $eventId|0;
 $inType = $inType|0;
 var $$$i$i = 0, $$$i$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i = 0, $idx$01$i$i$i = 0, $theHeader = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $theHeader = sp;
 HEAP8[$theHeader>>0] = $inEventType;
 $0 = (($theHeader) + 1|0);
 $1 = (($theHeader) + 2|0);
 HEAP16[$1>>1] = $eventId;
 $2 = (($inType) + 16|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 104|0);
 $10 = $9;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 HEAP8[$0>>0] = 3;
 $16 = ($12|0)==(0);
 $17 = ($15|0)==(0);
 $18 = $16 & $17;
 if ($18) {
  $42 = $5;$45 = $8;$68 = 3;
 } else {
  $19 = (_i64Subtract(($5|0),($8|0),($12|0),($15|0))|0);
  $20 = tempRet0;
  $21 = ($20>>>0)<(0);
  $22 = ($20|0)==(0);
  $23 = ($19>>>0)<(256);
  $24 = $22 & $23;
  $25 = $21 | $24;
  if ($25) {
   $$0$i$i$i$i = 0;
  } else {
   $26 = ($20>>>0)<(0);
   $27 = ($20|0)==(0);
   $28 = ($19>>>0)<(65536);
   $29 = $27 & $28;
   $30 = $26 | $29;
   if ($30) {
    $$0$i$i$i$i = 1;
   } else {
    $31 = ($20>>>0)<(1);
    $32 = ($20|0)==(1);
    $33 = ($19>>>0)<(0);
    $34 = $32 & $33;
    $35 = $31 | $34;
    $$$i$i$i = $35 ? 2 : 3;
    $$0$i$i$i$i = $$$i$i$i;
   }
  }
  $36 = $$0$i$i$i$i&255;
  HEAP8[$0>>0] = $36;
  $37 = ($$0$i$i$i$i|0)==(3);
  $38 = $37 ? $5 : $19;
  $39 = $37 ? $8 : $20;
  $42 = $38;$45 = $39;$68 = $$0$i$i$i$i;
 }
 $40 = $2;
 $41 = $40;
 HEAP32[$41>>2] = $42;
 $43 = (($40) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $45;
 $46 = $inType;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51>>>0)<(0);
 $53 = ($51|0)==(0);
 $54 = ($48>>>0)<(256);
 $55 = $53 & $54;
 $56 = $52 | $55;
 if ($56) {
  $$0$i$i$i = 0;
 } else {
  $57 = ($51>>>0)<(0);
  $58 = ($51|0)==(0);
  $59 = ($48>>>0)<(65536);
  $60 = $58 & $59;
  $61 = $57 | $60;
  if ($61) {
   $$0$i$i$i = 4;
  } else {
   $62 = ($51>>>0)<(1);
   $63 = ($51|0)==(1);
   $64 = ($48>>>0)<(0);
   $65 = $63 & $64;
   $66 = $62 | $65;
   $$$i$i = $66 ? 8 : 12;
   $$0$i$i$i = $$$i$i;
  }
 }
 $67 = $68 | $$0$i$i$i;
 $69 = $67&255;
 HEAP8[$0>>0] = $69;
 $70 = $9;
 $71 = $70;
 HEAP32[$71>>2] = $5;
 $72 = (($70) + 4)|0;
 $73 = $72;
 HEAP32[$73>>2] = $8;
 $74 = (($this) + 80|0);
 __ZN5physx7profile11EventHeader9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_($theHeader,$74);
 $75 = HEAP8[$0>>0]|0;
 $76 = $75&255;
 $77 = $76 >>> 2;
 $78 = $77 & 3;
 __ZN5physx7profile23EventContextInformation9streamifyINS0_15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEEEEEvRT_NS0_27EventStreamCompressionFlags4EnumE($inType,$74,$78);
 $79 = $76 & 3;
 __ZN5physx7profile15EventSerializerINS0_12MemoryBufferINS0_21WrapperNamedAllocatorEEEE9streamifyEPKcRKyNS0_27EventStreamCompressionFlags4EnumE($74,0,$2,$79);
 $80 = (($this) + 20|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($this) + 16|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = $81;
 $85 = $83;
 $86 = (($84) - ($85))|0;
 $87 = (($this) + 44|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($86>>>0)<($88>>>0);
 if ($89) {
  STACKTOP = sp;return;
 }
 $90 = (($this) + 72|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)==(0|0);
 if ($92) {
  $96 = $81;$98 = $83;
 } else {
  $93 = (($91) + 4|0);
  $94 = HEAP32[$93>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($94);
  $$pre = HEAP32[$82>>2]|0;
  $$pre1 = HEAP32[$80>>2]|0;
  $96 = $$pre1;$98 = $$pre;
 }
 $95 = $96;
 $97 = $98;
 $99 = (($95) - ($97))|0;
 $100 = (($this) + 36|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)==(0);
 if ($102) {
  $111 = $98;
 } else {
  $103 = (($this) + 32|0);
  $idx$01$i$i$i = 0;
  while(1) {
   $104 = HEAP32[$103>>2]|0;
   $105 = (($104) + ($idx$01$i$i$i<<2)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = HEAP32[$106>>2]|0;
   $108 = (($107) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   FUNCTION_TABLE_viii[$109 & 4095]($106,$98,$99);
   $110 = (($idx$01$i$i$i) + 1)|0;
   $exitcond$i$i$i = ($110|0)==($101|0);
   if ($exitcond$i$i$i) {
    break;
   } else {
    $idx$01$i$i$i = $110;
   }
  }
  $$pre$i$i = HEAP32[$82>>2]|0;
  $111 = $$pre$i$i;
 }
 HEAP32[$80>>2] = $111;
 $112 = HEAP32[$this>>2]|0;
 $113 = (($112) + 16|0);
 $114 = HEAP32[$113>>2]|0;
 FUNCTION_TABLE_vi[$114 & 4095]($this);
 if ($92) {
  STACKTOP = sp;return;
 }
 $115 = (($91) + 4|0);
 $116 = HEAP32[$115>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($116);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE9stopEventEty($this,$inId,$0,$1) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theEvent$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $2 = sp + 24|0;
 $theEvent$i = sp;
 $3 = (__ZN5physx6shdfnd10ThreadImpl5getIdEv()|0);
 $4 = (__ZN5physx6shdfnd4Time22getCurrentCounterValueEv()|0);
 $5 = tempRet0;
 $6 = (($this) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($7) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($10);
 }
 ;HEAP32[$theEvent$i+0>>2]=0|0;HEAP32[$theEvent$i+4>>2]=0|0;HEAP32[$theEvent$i+8>>2]=0|0;HEAP32[$theEvent$i+12>>2]=0|0;
 $11 = $theEvent$i;
 $12 = $11;
 HEAP32[$12>>2] = $0;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $1;
 $15 = (($theEvent$i) + 8|0);
 HEAP32[$15>>2] = $3;
 $16 = (($theEvent$i) + 12|0);
 HEAP8[$16>>0] = 2;
 $17 = (($theEvent$i) + 13|0);
 HEAP8[$17>>0] = 0;
 $18 = (($theEvent$i) + 16|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = $4;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $5;
 $23 = (($this) + 88|0);
 $24 = (($this) + 96|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==($3|0);
 if ($26) {
  $27 = $23;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 4)|0;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = ($29|0)==($0|0);
  $34 = ($32|0)==($1|0);
  $35 = $33 & $34;
  if ($35) {
   $36 = (($this) + 100|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = ($37<<24>>24)==(2);
   if ($38) {
    $39 = (($this) + 101|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = ($40<<24>>24)==(0);
    if ($41) {
     $42 = $2;
     $43 = $42;
     HEAP32[$43>>2] = $4;
     $44 = (($42) + 4)|0;
     $45 = $44;
     HEAP32[$45>>2] = $5;
     __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_17RelativeStopEventEEEvhtRKT_($this,4,$inId,$2);
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  ;HEAP32[$23+0>>2]=HEAP32[$theEvent$i+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$theEvent$i+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$theEvent$i+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$theEvent$i+12>>2]|0;
  __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_9StopEventEEEvhtRKT_($this,2,$inId,$theEvent$i);
 }
 if ($8) {
  STACKTOP = sp;return;
 }
 $46 = (($7) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($47);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10startEventEty($this,$inId,$0,$1) {
 $this = $this|0;
 $inId = $inId|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $theEvent$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $2 = sp + 24|0;
 $theEvent$i = sp;
 $3 = (__ZN5physx6shdfnd10ThreadImpl5getIdEv()|0);
 $4 = (__ZN5physx6shdfnd4Time22getCurrentCounterValueEv()|0);
 $5 = tempRet0;
 $6 = (($this) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($7) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($10);
 }
 ;HEAP32[$theEvent$i+0>>2]=0|0;HEAP32[$theEvent$i+4>>2]=0|0;HEAP32[$theEvent$i+8>>2]=0|0;HEAP32[$theEvent$i+12>>2]=0|0;
 $11 = $theEvent$i;
 $12 = $11;
 HEAP32[$12>>2] = $0;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $1;
 $15 = (($theEvent$i) + 8|0);
 HEAP32[$15>>2] = $3;
 $16 = (($theEvent$i) + 12|0);
 HEAP8[$16>>0] = 2;
 $17 = (($theEvent$i) + 13|0);
 HEAP8[$17>>0] = 0;
 $18 = (($theEvent$i) + 16|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = $4;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $5;
 $23 = (($this) + 88|0);
 $24 = (($this) + 96|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==($3|0);
 if ($26) {
  $27 = $23;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 4)|0;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = ($29|0)==($0|0);
  $34 = ($32|0)==($1|0);
  $35 = $33 & $34;
  if ($35) {
   $36 = (($this) + 100|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = ($37<<24>>24)==(2);
   if ($38) {
    $39 = (($this) + 101|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = ($40<<24>>24)==(0);
    if ($41) {
     $42 = $2;
     $43 = $42;
     HEAP32[$43>>2] = $4;
     $44 = (($42) + 4)|0;
     $45 = $44;
     HEAP32[$45>>2] = $5;
     __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_18RelativeStartEventEEEvhtRKT_($this,3,$inId,$2);
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  ;HEAP32[$23+0>>2]=HEAP32[$theEvent$i+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$theEvent$i+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$theEvent$i+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$theEvent$i+12>>2]|0;
  __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE10doAddEventINS0_10StartEventEEEvhtRKT_($this,1,$inId,$theEvent$i);
 }
 if ($8) {
  STACKTOP = sp;return;
 }
 $46 = (($7) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($47);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_19PxProfileZoneClientENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $16 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = HEAP32[$this>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,535200,535624,558)|0);
  $16 = $12;
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = (($this) + 4|0);
 $18 = ($14|0)>(0);
 if ($18) {
  $19 = HEAP32[$17>>2]|0;
  $$012$i = $16;$$03$i = $19;
  while(1) {
   $20 = ($$012$i|0)==(0|0);
   if (!($20)) {
    $21 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $21;
   }
   $22 = (($$012$i) + 4|0);
   $23 = (($$03$i) + 4|0);
   $24 = ($22>>>0)<($15>>>0);
   if ($24) {
    $$012$i = $22;$$03$i = $23;
   } else {
    break;
   }
  }
 }
 $25 = ($15|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$a>>2]|0;
  HEAP32[$15>>2] = $26;
 }
 $27 = HEAP32[$0>>2]|0;
 $28 = ($27|0)>(-1);
 if ($28) {
  $29 = HEAP32[$17>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $37 = $14;
  } else {
   $31 = HEAP32[$this>>2]|0;
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$29);
   $$pre = HEAP32[$13>>2]|0;
   $37 = $$pre;
  }
 } else {
  $37 = $14;
 }
 HEAP32[$17>>2] = $16;
 HEAP32[$0>>2] = $$$i;
 $36 = (($37) + 1)|0;
 HEAP32[$13>>2] = $36;
 $38 = (($16) + ($37<<2)|0);
 STACKTOP = sp;return ($38|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_26PxProfileEventBufferClientENS_7profile26WrapperReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $16 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = HEAP32[$this>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,535200,535624,558)|0);
  $16 = $12;
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = (($this) + 4|0);
 $18 = ($14|0)>(0);
 if ($18) {
  $19 = HEAP32[$17>>2]|0;
  $$012$i = $16;$$03$i = $19;
  while(1) {
   $20 = ($$012$i|0)==(0|0);
   if (!($20)) {
    $21 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $21;
   }
   $22 = (($$012$i) + 4|0);
   $23 = (($$03$i) + 4|0);
   $24 = ($22>>>0)<($15>>>0);
   if ($24) {
    $$012$i = $22;$$03$i = $23;
   } else {
    break;
   }
  }
 }
 $25 = ($15|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$a>>2]|0;
  HEAP32[$15>>2] = $26;
 }
 $27 = HEAP32[$0>>2]|0;
 $28 = ($27|0)>(-1);
 if ($28) {
  $29 = HEAP32[$17>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $37 = $14;
  } else {
   $31 = HEAP32[$this>>2]|0;
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$29);
   $$pre = HEAP32[$13>>2]|0;
   $37 = $$pre;
  }
 } else {
  $37 = $14;
 }
 HEAP32[$17>>2] = $16;
 HEAP32[$0>>2] = $$$i;
 $36 = (($37) + 1)|0;
 HEAP32[$13>>2] = $36;
 $38 = (($16) + ($37<<2)|0);
 STACKTOP = sp;return ($38|0);
}
function __ZN5physx6shdfnd5ArrayINS_18PxProfileEventNameENS_7profile26WrapperReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $16 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = HEAP32[$this>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,535200,535624,558)|0);
  $16 = $12;
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<3)|0);
 $17 = (($this) + 4|0);
 $18 = ($14|0)>(0);
 if ($18) {
  $19 = HEAP32[$17>>2]|0;
  $$012$i = $16;$$03$i = $19;
  while(1) {
   $20 = ($$012$i|0)==(0|0);
   if (!($20)) {
    $21 = $$03$i;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + 4)|0;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    $27 = $$012$i;
    $28 = $27;
    HEAP32[$28>>2] = $23;
    $29 = (($27) + 4)|0;
    $30 = $29;
    HEAP32[$30>>2] = $26;
   }
   $31 = (($$012$i) + 8|0);
   $32 = (($$03$i) + 8|0);
   $33 = ($31>>>0)<($15>>>0);
   if ($33) {
    $$012$i = $31;$$03$i = $32;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$13>>2]|0;
  $35 = $$pre;
 } else {
  $35 = $14;
 }
 $34 = (($16) + ($35<<3)|0);
 $36 = ($34|0)==(0|0);
 if (!($36)) {
  $37 = $a;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + 4)|0;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = $34;
  $44 = $43;
  HEAP32[$44>>2] = $39;
  $45 = (($43) + 4)|0;
  $46 = $45;
  HEAP32[$46>>2] = $42;
 }
 $47 = HEAP32[$0>>2]|0;
 $48 = ($47|0)>(-1);
 if ($48) {
  $49 = HEAP32[$17>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = HEAP32[$this>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   FUNCTION_TABLE_vii[$55 & 4095]($52,$49);
  }
 }
 HEAP32[$17>>2] = $16;
 HEAP32[$0>>2] = $$$i;
 $56 = HEAP32[$13>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$13>>2] = $57;
 $58 = (($16) + ($56<<3)|0);
 STACKTOP = sp;return ($58|0);
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx13PxTaskManager17createTaskManagerEPNS_15PxCpuDispatcherEPNS_15PxGpuDispatcherEPNS_15PxSpuDispatcherE($cpuDispatcher,$gpuDispatcher,$spuDispatcher) {
 $cpuDispatcher = $cpuDispatcher|0;
 $gpuDispatcher = $gpuDispatcher|0;
 $spuDispatcher = $spuDispatcher|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 536552 : 536208;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,100,$$$i$i$i,535856,211)|0);
 __ZN5physx9PxTaskMgrC2EPNS_15PxCpuDispatcherEPNS_15PxGpuDispatcherEPNS_15PxSpuDispatcherE($9,$cpuDispatcher,$gpuDispatcher,$spuDispatcher);
 STACKTOP = sp;return ($9|0);
}
function __ZN5physx9PxTaskMgrC2EPNS_15PxCpuDispatcherEPNS_15PxGpuDispatcherEPNS_15PxSpuDispatcherE($this,$cpuDispatcher,$gpuDispatcher,$spuDispatcher) {
 $this = $this|0;
 $cpuDispatcher = $cpuDispatcher|0;
 $gpuDispatcher = $gpuDispatcher|0;
 $spuDispatcher = $spuDispatcher|0;
 var $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((535936 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $cpuDispatcher;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $gpuDispatcher;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $spuDispatcher;
 $3 = (($this) + 16|0);
 $4 = (($this) + 40|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(0.75);
 $5 = (($this) + 44|0);
 HEAP32[$5>>2] = -1;
 $6 = (($this) + 48|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 52|0);
 HEAP32[$7>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcmEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_mS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE15reserveInternalEj($3,64);
 $8 = (($this) + 56|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 60|0);
 $10 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  HEAP32[$9>>2] = 0;
  $24 = (($this) + 64|0);
  dest=$24+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $13 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__Z15PxGetFoundationv()|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_ii[$20 & 4095]($17)|0);
 $$$i$i$i$i = $21 ? 536744 : 536208;
 $22 = (FUNCTION_TABLE_iiiiii[$16 & 255]($13,$11,$$$i$i$i$i,536664,111)|0);
 HEAP32[$9>>2] = $22;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $24 = (($this) + 64|0);
  dest=$24+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9MutexImplC2Ev($22);
 $24 = (($this) + 64|0);
 dest=$24+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr19initializeProfilingERNS_20PxProfileZoneManagerE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgrD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx9PxTaskMgrD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgrD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((535936 + 8|0));
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 88|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 84|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i1 = $15 & $16;
 if ($or$cond$i$i1) {
  $17 = (($this) + 76|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 72|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i2 = $27 & $28;
 if ($or$cond$i$i2) {
  $29 = (($this) + 64|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
  }
 }
 $36 = (($this) + 60|0);
 $37 = HEAP32[$36>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($37);
 $38 = HEAP32[$36>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 12|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_vii[$43 & 4095]($40,$38);
 }
 $44 = (($this) + 16|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($44,$45);
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr13decrReferenceERNS_14PxLightCpuTaskE($this,$lighttask) {
 $this = $this|0;
 $lighttask = $lighttask|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($lighttask) + 16|0);
 $1 = (__ZN5physx6shdfnd15atomicDecrementEPVi($0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $8 = HEAP32[$lighttask>>2]|0;
  $9 = (($8) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 4095]($lighttask);
  STACKTOP = sp;return;
 } else {
  $6 = HEAP32[$4>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 4095]($4,$lighttask);
  STACKTOP = sp;return;
 }
}
function __ZN5physx9PxTaskMgr12addReferenceERNS_14PxLightCpuTaskE($this,$lighttask) {
 $this = $this|0;
 $lighttask = $lighttask|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($lighttask) + 16|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($0)|0);
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr13decrReferenceERNS_9PxSpuTaskE($this,$spuTask) {
 $this = $this|0;
 $spuTask = $spuTask|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr14emitStartEventERNS_10PxBaseTaskEj($this,$basetask,$threadId) {
 $this = $this|0;
 $basetask = $basetask|0;
 $threadId = $threadId|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr13emitStopEventERNS_10PxBaseTaskEj($this,$basetask,$threadId) {
 $this = $this|0;
 $basetask = $basetask|0;
 $threadId = $threadId|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr17resetDependenciesEv($this) {
 $this = $this|0;
 var $$phi$trans$insert$i$i = 0, $$pre$i$i = 0, $$pre4$i$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $i$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 68|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $25 = (($this) + 56|0);
  HEAP32[$25>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $25 = (($this) + 56|0);
  HEAP32[$25>>2] = 0;
  STACKTOP = sp;return;
 }
 $8 = (($this) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $3 << 2;
 _memset(($9|0),-1,($10|0))|0;
 $11 = (($this) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + -1)|0;
 $14 = ($13|0)==(0);
 $$phi$trans$insert$i$i = (($this) + 24|0);
 $$pre4$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
 if ($14) {
  $21 = $12;$23 = $$pre4$i$i;
 } else {
  $16 = $$pre4$i$i;$i$01$i$i = 0;
  while(1) {
   $$sum$i$i = (($i$01$i$i) + 32)|0;
   $15 = (($16) + ($$sum$i$i<<2)|0);
   $17 = (($i$01$i$i) + 1)|0;
   $18 = HEAP32[$$phi$trans$insert$i$i>>2]|0;
   $19 = (($18) + ($i$01$i$i<<2)|0);
   HEAP32[$19>>2] = $17;
   $exitcond$i$i = ($17|0)==($13|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $16 = $18;$i$01$i$i = $17;
   }
  }
  $$pre$i$i = HEAP32[$11>>2]|0;
  $21 = $$pre$i$i;$23 = $18;
 }
 $20 = (($21) + -1)|0;
 $22 = (($23) + ($20<<2)|0);
 HEAP32[$22>>2] = -1;
 $24 = (($this) + 44|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$5>>2] = 0;
 $25 = (($this) + 56|0);
 HEAP32[$25>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr15startSimulationEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $gpuDispatch$0$off01 = 0, $i = 0, $i1$02 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $i = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095]($1);
 }
 $5 = (($this) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 HEAP32[$i>>2] = 0;
 $8 = (($this) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$pre8 = (($this) + 92|0);
  $$pre$phiZ2D = $$pre8;
 } else {
  $11 = (($this) + 76|0);
  $12 = (($this) + 88|0);
  $13 = (($this) + 96|0);
  $14 = (($this) + 92|0);
  $20 = 0;
  while(1) {
   $18 = HEAP32[$11>>2]|0;
   $19 = ((($18) + (($20*20)|0)|0) + 8|0);
   $21 = HEAP32[$19>>2]|0;
   $22 = ($21|0)==(3);
   do {
    if ($22) {
     $35 = $20;
    } else {
     $23 = ((($18) + (($20*20)|0)|0) + 4|0);
     $24 = (__ZN5physx6shdfnd15atomicDecrementEPVi($23)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = HEAP32[$13>>2]|0;
      $27 = $26 & 2147483647;
      $28 = HEAP32[$14>>2]|0;
      $29 = ($27>>>0)>($28>>>0);
      if (!($29)) {
       (__ZN5physx6shdfnd5ArrayImNS0_19ReflectionAllocatorImEEE15growAndPushBackERKm($12,$i)|0);
       $$pre = HEAP32[$i>>2]|0;
       $35 = $$pre;
       break;
      }
      $30 = HEAP32[$12>>2]|0;
      $31 = (($30) + ($28<<2)|0);
      $32 = ($31|0)==(0|0);
      if (!($32)) {
       HEAP32[$31>>2] = $20;
      }
      $33 = (($28) + 1)|0;
      HEAP32[$14>>2] = $33;
      $35 = $20;
     } else {
      $35 = $20;
     }
    }
   } while(0);
   $34 = (($35) + 1)|0;
   HEAP32[$i>>2] = $34;
   $36 = HEAP32[$8>>2]|0;
   $37 = ($34>>>0)<($36>>>0);
   if ($37) {
    $20 = $34;
   } else {
    $$pre$phiZ2D = $14;
    break;
   }
  }
 }
 $15 = HEAP32[$$pre$phiZ2D>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  HEAP32[$$pre$phiZ2D>>2] = 0;
  STACKTOP = sp;return;
 }
 $17 = (($this) + 88|0);
 $gpuDispatch$0$off01 = 0;$i1$02 = 0;
 while(1) {
  $38 = HEAP32[$17>>2]|0;
  $39 = (($38) + ($i1$02<<2)|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (__ZN5physx9PxTaskMgr12dispatchTaskEmb($this,$40,$gpuDispatch$0$off01)|0);
  $42 = $gpuDispatch$0$off01 | $41;
  $43 = (($i1$02) + 1)|0;
  $44 = HEAP32[$$pre$phiZ2D>>2]|0;
  $45 = ($43>>>0)<($44>>>0);
  if ($45) {
   $gpuDispatch$0$off01 = $42;$i1$02 = $43;
  } else {
   break;
  }
 }
 $phitmp = $42 ^ 1;
 HEAP32[$$pre$phiZ2D>>2] = 0;
 $46 = HEAP32[$0>>2]|0;
 $47 = ($46|0)==(0|0);
 $brmerge = $47 | $phitmp;
 if ($brmerge) {
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$46>>2]|0;
 $49 = (($48) + 12|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_vi[$50 & 4095]($46);
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr12dispatchTaskEmb($this,$taskID,$gpuGroupStart) {
 $this = $this|0;
 $taskID = $taskID|0;
 $gpuGroupStart = $gpuGroupStart|0;
 var $$0 = 0, $$01$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer3 = sp;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + (($taskID*20)|0)|0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 if ((($5|0) == 2)) {
  $14 = (__ZN5physx9PxTaskMgr10resolveRowEmb($this,$taskID,$gpuGroupStart)|0);
  $15 = $14 | $gpuGroupStart;
  $$01$off0 = $15;
 } else if ((($5|0) == 1)) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($13,2,535856,817,536080,$vararg_buffer3);
  $$01$off0 = $gpuGroupStart;
 } else if ((($5|0) == 3)) {
  $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,2,535856,793,536056,$vararg_buffer3);
  $$0 = 0;
  $19 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($19);
  STACKTOP = sp;return ($$0|0);
 } else if ((($5|0) == 0)) {
  $7 = (($this) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($3) + (($taskID*20)|0)|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$10 & 4095]($8,$12);
  $$01$off0 = $gpuGroupStart;
 } else {
  $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($16,2,535856,829,536104,$vararg_buffer3);
  $17 = (__ZN5physx9PxTaskMgr10resolveRowEmb($this,$taskID,$gpuGroupStart)|0);
  $18 = $17 | $gpuGroupStart;
  $$01$off0 = $18;
 }
 HEAP32[$4>>2] = 3;
 $$0 = $$01$off0;
 $19 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($19);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9PxTaskMgr14stopSimulationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($1);
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr12getNamedTaskEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $h$0$lcssa$i$i$i$i$i = 0, $h$01$i$i$i$i$i = 0, $index$0$i$i = 0, $index$02$i$i = 0, $index$03$i$i = 0, $ptr$02$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   label = 8;
  } else {
   $5 = HEAP8[$name>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $h$0$lcssa$i$i$i$i$i = 5381;
   } else {
    $9 = $5;$h$01$i$i$i$i$i = 5381;$ptr$02$i$i$i$i$i = $name;
    while(1) {
     $7 = ($h$01$i$i$i$i$i*33)|0;
     $8 = $9 << 24 >> 24;
     $10 = $7 ^ $8;
     $11 = (($ptr$02$i$i$i$i$i) + 1|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($12<<24>>24)==(0);
     if ($13) {
      $h$0$lcssa$i$i$i$i$i = $10;
      break;
     } else {
      $9 = $12;$h$01$i$i$i$i$i = $10;$ptr$02$i$i$i$i$i = $11;
     }
    }
   }
   $14 = (($3) + -1)|0;
   $15 = $h$0$lcssa$i$i$i$i$i & $14;
   $16 = (($this) + 28|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + ($15<<2)|0);
   $index$02$i$i = HEAP32[$18>>2]|0;
   $19 = ($index$02$i$i|0)==(-1);
   if ($19) {
    label = 8;
   } else {
    $20 = (($this) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($this) + 24|0);
    $index$03$i$i = $index$02$i$i;
    while(1) {
     $23 = (($21) + ($index$03$i$i<<3)|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (_strcmp($24,$name)|0);
     $26 = ($25|0)==(0);
     if ($26) {
      break;
     }
     $27 = HEAP32[$22>>2]|0;
     $28 = (($27) + ($index$03$i$i<<2)|0);
     $index$0$i$i = HEAP32[$28>>2]|0;
     $29 = ($index$0$i$i|0)==(-1);
     if ($29) {
      label = 8;
      break L1;
     } else {
      $index$03$i$i = $index$0$i$i;
     }
    }
    $31 = HEAP32[$0>>2]|0;
    __ZN5physx6shdfnd9MutexImpl6unlockEv($31);
    $32 = ($23|0)==(0|0);
    if (!($32)) {
     $33 = ((($21) + ($index$03$i$i<<3)|0) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $$0 = $34;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $30 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($30);
 }
 $35 = HEAP32[$this>>2]|0;
 $36 = (($35) + 48|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (FUNCTION_TABLE_iiiii[$37 & 511]($this,0,$name,2)|0);
 $$0 = $38;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9PxTaskMgr13getTaskFromIDEm($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + (($id*20)|0)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($6);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx9PxTaskMgr15submitNamedTaskEPNS_6PxTaskEPKcNS_10PxTaskType4EnumE($this,$task,$name,$type) {
 $this = $this|0;
 $task = $task|0;
 $name = $name|0;
 $type = $type|0;
 var $$0 = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $exists$i = 0, $h$0$lcssa$i$i$i$i$i = 0, $h$01$i$i$i$i$i = 0, $index$0$i$i = 0;
 var $index$02$i$i = 0, $index$03$i$i = 0, $or$cond$i = 0, $ptr$02$i$i$i$i$i = 0, $r = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $exists$i = sp + 24|0;
 $0 = sp;
 $r = sp + 4|0;
 HEAP32[$0>>2] = $name;
 $1 = ($task|0)!=(0|0);
 if ($1) {
  $2 = (($task) + 8|0);
  HEAP32[$2>>2] = $this;
  $3 = HEAP32[$task>>2]|0;
  $4 = (($3) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($task);
 }
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($7);
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 L4: do {
  if (!($10)) {
   $11 = HEAP8[$name>>0]|0;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    $h$0$lcssa$i$i$i$i$i = 5381;
   } else {
    $15 = $11;$h$01$i$i$i$i$i = 5381;$ptr$02$i$i$i$i$i = $name;
    while(1) {
     $13 = ($h$01$i$i$i$i$i*33)|0;
     $14 = $15 << 24 >> 24;
     $16 = $13 ^ $14;
     $17 = (($ptr$02$i$i$i$i$i) + 1|0);
     $18 = HEAP8[$17>>0]|0;
     $19 = ($18<<24>>24)==(0);
     if ($19) {
      $h$0$lcssa$i$i$i$i$i = $16;
      break;
     } else {
      $15 = $18;$h$01$i$i$i$i$i = $16;$ptr$02$i$i$i$i$i = $17;
     }
    }
   }
   $20 = (($9) + -1)|0;
   $21 = $h$0$lcssa$i$i$i$i$i & $20;
   $22 = (($this) + 28|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + ($21<<2)|0);
   $index$02$i$i = HEAP32[$24>>2]|0;
   $25 = ($index$02$i$i|0)==(-1);
   if (!($25)) {
    $26 = (($this) + 20|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($this) + 24|0);
    $index$03$i$i = $index$02$i$i;
    while(1) {
     $29 = (($27) + ($index$03$i$i<<3)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (_strcmp($30,$name)|0);
     $32 = ($31|0)==(0);
     if ($32) {
      break;
     }
     $33 = HEAP32[$28>>2]|0;
     $34 = (($33) + ($index$03$i$i<<2)|0);
     $index$0$i$i = HEAP32[$34>>2]|0;
     $35 = ($index$0$i$i|0)==(-1);
     if ($35) {
      break L4;
     } else {
      $index$03$i$i = $index$0$i$i;
     }
    }
    $36 = ($29|0)==(0|0);
    if (!($36)) {
     $37 = ((($27) + ($index$03$i$i<<3)|0) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     if (!($1)) {
      $$0 = $38;
      $71 = HEAP32[$6>>2]|0;
      __ZN5physx6shdfnd9MutexImpl6unlockEv($71);
      STACKTOP = sp;return ($$0|0);
     }
     $39 = (($this) + 76|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($40) + (($38*20)|0)|0);
     HEAP32[$41>>2] = $task;
     $42 = HEAP32[$39>>2]|0;
     $43 = ((($42) + (($38*20)|0)|0) + 8|0);
     HEAP32[$43>>2] = $type;
     $44 = (($task) + 12|0);
     HEAP32[$44>>2] = $38;
     $$0 = $38;
     $71 = HEAP32[$6>>2]|0;
     __ZN5physx6shdfnd9MutexImpl6unlockEv($71);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $45 = (($this) + 56|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($45)|0);
 $46 = (($this) + 76|0);
 $47 = (($this) + 80|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 16|0);
 $50 = (__ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcmEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_mS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE6createERS6_Rb($49,$0,$exists$i)|0);
 $51 = HEAP8[$exists$i>>0]|0;
 $52 = ($51<<24>>24)!=(0);
 $53 = ($50|0)==(0|0);
 $or$cond$i = $52 | $53;
 if ($or$cond$i) {
  $$pre$i1 = (($50) + 4|0);
  $$pre$phi$iZ2D = $$pre$i1;
 } else {
  $54 = HEAP32[$0>>2]|0;
  HEAP32[$50>>2] = $54;
  $55 = (($50) + 4|0);
  HEAP32[$55>>2] = 0;
  $$pre$phi$iZ2D = $55;
 }
 HEAP32[$$pre$phi$iZ2D>>2] = $48;
 if ($1) {
  $56 = (($task) + 12|0);
  HEAP32[$56>>2] = $48;
 }
 $57 = (($r) + 4|0);
 HEAP32[$57>>2] = 1;
 $58 = (($r) + 12|0);
 HEAP32[$58>>2] = -1;
 $59 = (($r) + 16|0);
 HEAP32[$59>>2] = -1;
 HEAP32[$r>>2] = $task;
 $60 = (($r) + 8|0);
 HEAP32[$60>>2] = $type;
 $61 = (($this) + 84|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = $62 & 2147483647;
 $64 = HEAP32[$47>>2]|0;
 $65 = ($63>>>0)>($64>>>0);
 if (!($65)) {
  (__ZN5physx6shdfnd5ArrayINS_14PxTaskTableRowENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($46,$r)|0);
  $$0 = $48;
  $71 = HEAP32[$6>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($71);
  STACKTOP = sp;return ($$0|0);
 }
 $66 = HEAP32[$46>>2]|0;
 $67 = (($66) + (($64*20)|0)|0);
 $68 = ($67|0)==(0|0);
 if ($68) {
  $70 = $64;
 } else {
  ;HEAP32[$67+0>>2]=HEAP32[$r+0>>2]|0;HEAP32[$67+4>>2]=HEAP32[$r+4>>2]|0;HEAP32[$67+8>>2]=HEAP32[$r+8>>2]|0;HEAP32[$67+12>>2]=HEAP32[$r+12>>2]|0;HEAP32[$67+16>>2]=HEAP32[$r+16>>2]|0;
  $$pre$i = HEAP32[$47>>2]|0;
  $70 = $$pre$i;
 }
 $69 = (($70) + 1)|0;
 HEAP32[$47>>2] = $69;
 $$0 = $48;
 $71 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($71);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx9PxTaskMgr17submitUnnamedTaskERNS_6PxTaskENS_10PxTaskType4EnumE($this,$task,$type) {
 $this = $this|0;
 $task = $task|0;
 $type = $type|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $r = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $r = sp;
 $0 = (($this) + 56|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($0)|0);
 $1 = (($task) + 8|0);
 HEAP32[$1>>2] = $this;
 $2 = HEAP32[$task>>2]|0;
 $3 = (($2) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($task);
 $5 = (($this) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($6);
 $7 = (($this) + 76|0);
 $8 = (($this) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($task) + 12|0);
 HEAP32[$10>>2] = $9;
 $11 = (($r) + 4|0);
 HEAP32[$11>>2] = 1;
 $12 = (($r) + 12|0);
 HEAP32[$12>>2] = -1;
 $13 = (($r) + 16|0);
 HEAP32[$13>>2] = -1;
 HEAP32[$r>>2] = $task;
 $14 = (($r) + 8|0);
 HEAP32[$14>>2] = $type;
 $15 = (($this) + 84|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 2147483647;
 $18 = HEAP32[$8>>2]|0;
 $19 = ($17>>>0)>($18>>>0);
 if (!($19)) {
  (__ZN5physx6shdfnd5ArrayINS_14PxTaskTableRowENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($7,$r)|0);
  $25 = HEAP32[$10>>2]|0;
  $26 = HEAP32[$5>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($26);
  STACKTOP = sp;return ($25|0);
 }
 $20 = HEAP32[$7>>2]|0;
 $21 = (($20) + (($18*20)|0)|0);
 $22 = ($21|0)==(0|0);
 if ($22) {
  $24 = $18;
 } else {
  ;HEAP32[$21+0>>2]=HEAP32[$r+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$r+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$r+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$r+12>>2]|0;HEAP32[$21+16>>2]=HEAP32[$r+16>>2]|0;
  $$pre$i = HEAP32[$8>>2]|0;
  $24 = $$pre$i;
 }
 $23 = (($24) + 1)|0;
 HEAP32[$8>>2] = $23;
 $25 = HEAP32[$10>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($26);
 STACKTOP = sp;return ($25|0);
}
function __ZN5physx9PxTaskMgr13taskCompletedERNS_6PxTaskE($this,$task) {
 $this = $this|0;
 $task = $task|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($task) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN5physx9PxTaskMgr10resolveRowEmb($this,$3,0)|0);
 if ($4) {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 4095]($6);
 }
 $10 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($10);
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr10resolveRowEmb($this,$taskID,$gpuGroupStart) {
 $this = $this|0;
 $taskID = $taskID|0;
 $gpuGroupStart = $gpuGroupStart|0;
 var $$0$off0$lcssa = 0, $$0$off012 = 0, $$0$off012$us = 0, $$1$off0 = 0, $$1$off0$us = 0, $$pre = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $depRow$011 = 0, $depRow$011$us = 0, $streamIndex$0$ph = 0;
 var $syncRequired$0$off010 = 0, $syncRequired$1$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + (($taskID*20)|0)|0) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + (($taskID*20)|0)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $streamIndex$0$ph = 0;
 } else {
  $7 = (($5) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $streamIndex$0$ph = $8;
 }
 $9 = ($3|0)==(-1);
 if ($9) {
  $$0$off0$lcssa = $gpuGroupStart;
  $49 = (($this) + 56|0);
  (__ZN5physx6shdfnd15atomicDecrementEPVi($49)|0);
  STACKTOP = sp;return ($$0$off0$lcssa|0);
 }
 $10 = (($this) + 64|0);
 $11 = ($streamIndex$0$ph|0)==(0);
 if ($11) {
  $$0$off012$us = $gpuGroupStart;$16 = $1;$depRow$011$us = $3;
  while(1) {
   $12 = HEAP32[$10>>2]|0;
   $13 = (($12) + ($depRow$011$us<<3)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($16) + (($14*20)|0)|0) + 4|0);
   $17 = (__ZN5physx6shdfnd15atomicDecrementEPVi($15)|0);
   $18 = ($17|0)==(0);
   if ($18) {
    $19 = HEAP32[$13>>2]|0;
    $20 = (__ZN5physx9PxTaskMgr12dispatchTaskEmb($this,$19,$$0$off012$us)|0);
    $21 = $$0$off012$us | $20;
    $$1$off0$us = $21;
   } else {
    $$1$off0$us = $$0$off012$us;
   }
   $22 = ((($12) + ($depRow$011$us<<3)|0) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(-1);
   if ($24) {
    $$0$off0$lcssa = $$1$off0$us;
    break;
   }
   $$pre = HEAP32[$0>>2]|0;
   $$0$off012$us = $$1$off0$us;$16 = $$pre;$depRow$011$us = $23;
  }
  $49 = (($this) + 56|0);
  (__ZN5physx6shdfnd15atomicDecrementEPVi($49)|0);
  STACKTOP = sp;return ($$0$off0$lcssa|0);
 } else {
  $$0$off012 = $gpuGroupStart;$29 = $1;$depRow$011 = $3;$syncRequired$0$off010 = 0;
 }
 while(1) {
  $25 = HEAP32[$10>>2]|0;
  $26 = (($25) + ($depRow$011<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($29) + (($27*20)|0)|0);
  $30 = HEAP32[$28>>2]|0;
  $31 = ($30|0)==(0|0);
  do {
   if ($31) {
    $syncRequired$1$off0 = $syncRequired$0$off010;
   } else {
    $32 = ((($29) + (($27*20)|0)|0) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(1);
    if ($34) {
     $35 = (($30) + 16|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0);
     if (!($37)) {
      $38 = (($30) + 20|0);
      HEAP8[$38>>0] = 1;
      $syncRequired$1$off0 = $syncRequired$0$off010;
      break;
     }
     if ($syncRequired$0$off010) {
      $39 = (($30) + 20|0);
      HEAP8[$39>>0] = 1;
      $syncRequired$1$off0 = 1;
      break;
     } else {
      HEAP32[$35>>2] = $streamIndex$0$ph;
      $syncRequired$1$off0 = 1;
      break;
     }
    } else {
     $syncRequired$1$off0 = $syncRequired$0$off010;
    }
   }
  } while(0);
  $40 = ((($29) + (($27*20)|0)|0) + 4|0);
  $41 = (__ZN5physx6shdfnd15atomicDecrementEPVi($40)|0);
  $42 = ($41|0)==(0);
  if ($42) {
   $43 = HEAP32[$26>>2]|0;
   $44 = (__ZN5physx9PxTaskMgr12dispatchTaskEmb($this,$43,$$0$off012)|0);
   $45 = $$0$off012 | $44;
   $$1$off0 = $45;
  } else {
   $$1$off0 = $$0$off012;
  }
  $46 = ((($25) + ($depRow$011<<3)|0) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(-1);
  if ($48) {
   $$0$off0$lcssa = $$1$off0;
   break;
  }
  $$pre15 = HEAP32[$0>>2]|0;
  $$0$off012 = $$1$off0;$29 = $$pre15;$depRow$011 = $47;$syncRequired$0$off010 = $syncRequired$1$off0;
 }
 $49 = (($this) + 56|0);
 (__ZN5physx6shdfnd15atomicDecrementEPVi($49)|0);
 STACKTOP = sp;return ($$0$off0$lcssa|0);
}
function __ZN5physx9PxTaskMgr12finishBeforeERNS_6PxTaskEm($this,$task,$taskID) {
 $this = $this|0;
 $task = $task|0;
 $taskID = $taskID|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $row$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $row$i = sp;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($task) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 64|0);
 $7 = (($this) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$row$i>>2] = $taskID;
 $9 = (($row$i) + 4|0);
 HEAP32[$9>>2] = -1;
 $10 = (($this) + 72|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 2147483647;
 $13 = ($12>>>0)>($8>>>0);
 if ($13) {
  $14 = HEAP32[$6>>2]|0;
  $15 = (($14) + ($8<<3)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $28 = $8;
  } else {
   $17 = $row$i;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + 4)|0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = $15;
   $24 = $23;
   HEAP32[$24>>2] = $19;
   $25 = (($23) + 4)|0;
   $26 = $25;
   HEAP32[$26>>2] = $22;
   $$pre$i$i = HEAP32[$7>>2]|0;
   $28 = $$pre$i$i;
  }
  $27 = (($28) + 1)|0;
  HEAP32[$7>>2] = $27;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_17PxTaskDepTableRowENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($6,$row$i)|0);
 }
 $29 = ((($5) + (($3*20)|0)|0) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(-1);
 if ($31) {
  HEAP32[$29>>2] = $8;
  $32 = ((($5) + (($3*20)|0)|0) + 12|0);
  HEAP32[$32>>2] = $8;
  $35 = HEAP32[$4>>2]|0;
  $36 = ((($35) + (($taskID*20)|0)|0) + 4|0);
  (__ZN5physx6shdfnd15atomicIncrementEPVi($36)|0);
  $37 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($37);
  STACKTOP = sp;return;
 } else {
  $33 = HEAP32[$6>>2]|0;
  $34 = ((($33) + ($30<<3)|0) + 4|0);
  HEAP32[$34>>2] = $8;
  HEAP32[$29>>2] = $8;
  $35 = HEAP32[$4>>2]|0;
  $36 = ((($35) + (($taskID*20)|0)|0) + 4|0);
  (__ZN5physx6shdfnd15atomicIncrementEPVi($36)|0);
  $37 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($37);
  STACKTOP = sp;return;
 }
}
function __ZN5physx9PxTaskMgr10startAfterERNS_6PxTaskEm($this,$task,$taskID) {
 $this = $this|0;
 $task = $task|0;
 $taskID = $taskID|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $row$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $row$i = sp;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 64|0);
 $5 = (($task) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$row$i>>2] = $6;
 $9 = (($row$i) + 4|0);
 HEAP32[$9>>2] = -1;
 $10 = (($this) + 72|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 2147483647;
 $13 = ($12>>>0)>($8>>>0);
 if ($13) {
  $14 = HEAP32[$4>>2]|0;
  $15 = (($14) + ($8<<3)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $28 = $8;
  } else {
   $17 = $row$i;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + 4)|0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = $15;
   $24 = $23;
   HEAP32[$24>>2] = $19;
   $25 = (($23) + 4)|0;
   $26 = $25;
   HEAP32[$26>>2] = $22;
   $$pre$i$i = HEAP32[$7>>2]|0;
   $28 = $$pre$i$i;
  }
  $27 = (($28) + 1)|0;
  HEAP32[$7>>2] = $27;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_17PxTaskDepTableRowENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($4,$row$i)|0);
 }
 $29 = ((($3) + (($taskID*20)|0)|0) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(-1);
 if ($31) {
  HEAP32[$29>>2] = $8;
  $32 = ((($3) + (($taskID*20)|0)|0) + 12|0);
  HEAP32[$32>>2] = $8;
  $35 = HEAP32[$5>>2]|0;
  $36 = HEAP32[$2>>2]|0;
  $37 = ((($36) + (($35*20)|0)|0) + 4|0);
  (__ZN5physx6shdfnd15atomicIncrementEPVi($37)|0);
  $38 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($38);
  STACKTOP = sp;return;
 } else {
  $33 = HEAP32[$4>>2]|0;
  $34 = ((($33) + ($30<<3)|0) + 4|0);
  HEAP32[$34>>2] = $8;
  HEAP32[$29>>2] = $8;
  $35 = HEAP32[$5>>2]|0;
  $36 = HEAP32[$2>>2]|0;
  $37 = ((($36) + (($35*20)|0)|0) + 4|0);
  (__ZN5physx6shdfnd15atomicIncrementEPVi($37)|0);
  $38 = HEAP32[$0>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($38);
  STACKTOP = sp;return;
 }
}
function __ZN5physx9PxTaskMgr12addReferenceEm($this,$taskID) {
 $this = $this|0;
 $taskID = $taskID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + (($taskID*20)|0)|0) + 4|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($4)|0);
 $5 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($5);
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr13decrReferenceEm($this,$taskID) {
 $this = $this|0;
 $taskID = $taskID|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + (($taskID*20)|0)|0) + 4|0);
 $5 = (__ZN5physx6shdfnd15atomicDecrementEPVi($4)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (__ZN5physx9PxTaskMgr12dispatchTaskEmb($this,$taskID,0)|0);
  if ($7) {
   $8 = (($this) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vi[$12 & 4095]($9);
  }
 }
 $13 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($13);
 STACKTOP = sp;return;
}
function __ZNK5physx9PxTaskMgr12getReferenceEm($this,$taskID) {
 $this = $this|0;
 $taskID = $taskID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + (($taskID*20)|0)|0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN5physx9PxTaskMgr16setCpuDispatcherERNS_15PxCpuDispatcherE($this,$ref) {
 $this = $this|0;
 $ref = $ref|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $ref;
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr16setGpuDispatcherERNS_15PxGpuDispatcherE($this,$ref) {
 $this = $this|0;
 $ref = $ref|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $ref;
 STACKTOP = sp;return;
}
function __ZN5physx9PxTaskMgr16setSpuDispatcherERNS_15PxSpuDispatcherE($this,$ref) {
 $this = $this|0;
 $ref = $ref|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $ref;
 STACKTOP = sp;return;
}
function __ZNK5physx9PxTaskMgr16getCpuDispatcherEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9PxTaskMgr16getGpuDispatcherEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx9PxTaskMgr16getSpuDispatcherEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd5ArrayINS_14PxTaskTableRowENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = ($$$i*20)|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 536240 : 536208;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,536128,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + (($19*20)|0)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
   }
   $25 = (($$012$i) + 20|0);
   $26 = (($$03$i) + 20|0);
   $27 = ($25>>>0)<($20>>>0);
   if ($27) {
    $$012$i = $25;$$03$i = $26;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $29 = $$pre;
 } else {
  $29 = $19;
 }
 $28 = (($21) + (($29*20)|0)|0);
 $30 = ($28|0)==(0|0);
 if (!($30)) {
  ;HEAP32[$28+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$a+12>>2]|0;HEAP32[$28+16>>2]=HEAP32[$a+16>>2]|0;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = HEAP32[$18>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$18>>2] = $40;
 $41 = (($21) + (($39*20)|0)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcmEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_mS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE6createERS6_Rb($this,$k,$exists) {
 $this = $this|0;
 $k = $k|0;
 $exists = $exists|0;
 var $$$i = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0 = 0, $h$0$lcssa$i$i$i = 0, $h$0$lcssa$i$i$i5 = 0, $h$01$i$i$i = 0, $h$01$i$i$i3 = 0, $h$1 = 0, $index$0 = 0, $index$011 = 0, $index$012 = 0;
 var $ptr$02$i$i$i = 0, $ptr$02$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $h$0 = 0;
  } else {
   $3 = HEAP32[$k>>2]|0;
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $h$0$lcssa$i$i$i = 5381;
   } else {
    $8 = $4;$h$01$i$i$i = 5381;$ptr$02$i$i$i = $3;
    while(1) {
     $6 = ($h$01$i$i$i*33)|0;
     $7 = $8 << 24 >> 24;
     $9 = $6 ^ $7;
     $10 = (($ptr$02$i$i$i) + 1|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $h$0$lcssa$i$i$i = $9;
      break;
     } else {
      $8 = $11;$h$01$i$i$i = $9;$ptr$02$i$i$i = $10;
     }
    }
   }
   $13 = (($1) + -1)|0;
   $14 = $h$0$lcssa$i$i$i & $13;
   $15 = (($this) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($14<<2)|0);
   $index$011 = HEAP32[$17>>2]|0;
   $18 = ($index$011|0)==(-1);
   if ($18) {
    $h$0 = $14;
   } else {
    $19 = (($this) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($this) + 8|0);
    $index$012 = $index$011;
    while(1) {
     $22 = (($20) + ($index$012<<3)|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (_strcmp($23,$3)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      break;
     }
     $26 = HEAP32[$21>>2]|0;
     $27 = (($26) + ($index$012<<2)|0);
     $index$0 = HEAP32[$27>>2]|0;
     $28 = ($index$0|0)==(-1);
     if ($28) {
      $h$0 = $14;
      break L1;
     } else {
      $index$012 = $index$0;
     }
    }
    HEAP8[$exists>>0] = 1;
    $29 = (($20) + ($index$012<<3)|0);
    $$0 = $29;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP8[$exists>>0] = 0;
 $30 = (($this) + 36|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 16|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($31|0)==($33|0);
 if ($34) {
  $35 = $1 << 1;
  $$$i = $2 ? 16 : $35;
  $36 = ($1>>>0)<($$$i>>>0);
  if ($36) {
   __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcmEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_mS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE15reserveInternalEj($this,$$$i);
   $$pre = HEAP32[$0>>2]|0;
   $48 = $$pre;
  } else {
   $48 = $1;
  }
  $37 = HEAP32[$k>>2]|0;
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $h$0$lcssa$i$i$i5 = 5381;
  } else {
   $42 = $38;$h$01$i$i$i3 = 5381;$ptr$02$i$i$i2 = $37;
   while(1) {
    $40 = ($h$01$i$i$i3*33)|0;
    $41 = $42 << 24 >> 24;
    $43 = $40 ^ $41;
    $44 = (($ptr$02$i$i$i2) + 1|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = ($45<<24>>24)==(0);
    if ($46) {
     $h$0$lcssa$i$i$i5 = $43;
     break;
    } else {
     $42 = $45;$h$01$i$i$i3 = $43;$ptr$02$i$i$i2 = $44;
    }
   }
  }
  $47 = (($48) + -1)|0;
  $49 = $h$0$lcssa$i$i$i5 & $47;
  $h$1 = $49;
 } else {
  $h$1 = $h$0;
 }
 $50 = (($this) + 28|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 1)|0;
 HEAP32[$50>>2] = $52;
 $53 = (($this) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + ($h$1<<2)|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($this) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + ($51<<2)|0);
 HEAP32[$59>>2] = $56;
 HEAP32[$55>>2] = $51;
 $60 = HEAP32[$30>>2]|0;
 $61 = (($60) + 1)|0;
 HEAP32[$30>>2] = $61;
 $62 = (($this) + 32|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + 1)|0;
 HEAP32[$62>>2] = $64;
 $65 = (($this) + 4|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($51<<3)|0);
 $$0 = $67;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKcmEES5_NS0_4HashIS5_EENS1_11HashMapBaseIS5_mS9_NS0_9AllocatorEE6GetKeyESB_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0$lcssa$i$i = 0, $h$01$i$i = 0, $index$01 = 0, $ptr$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = $21 << 3;
 $29 = (($27) + ($28))|0;
 $30 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$29,536360,354)|0);
 $31 = (($30) + ($22)|0);
 $32 = (($30) + ($27)|0);
 _memset(($30|0),-1,($22|0))|0;
 $33 = (($this) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 $$pre = (($this) + 4|0);
 if (!($35)) {
  $36 = (($$0) + -1)|0;
  $index$01 = 0;
  while(1) {
   $37 = HEAP32[$$pre>>2]|0;
   $38 = (($37) + ($index$01<<3)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $h$0$lcssa$i$i = 5381;
   } else {
    $44 = $40;$h$01$i$i = 5381;$ptr$02$i$i = $39;
    while(1) {
     $42 = ($h$01$i$i*33)|0;
     $43 = $44 << 24 >> 24;
     $45 = $42 ^ $43;
     $46 = (($ptr$02$i$i) + 1|0);
     $47 = HEAP8[$46>>0]|0;
     $48 = ($47<<24>>24)==(0);
     if ($48) {
      $h$0$lcssa$i$i = $45;
      break;
     } else {
      $44 = $47;$h$01$i$i = $45;$ptr$02$i$i = $46;
     }
    }
   }
   $49 = $h$0$lcssa$i$i & $36;
   $50 = (($30) + ($49<<2)|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($31) + ($index$01<<2)|0);
   HEAP32[$52>>2] = $51;
   HEAP32[$50>>2] = $index$01;
   $53 = (($32) + ($index$01<<3)|0);
   $54 = ($53|0)==(0|0);
   if (!($54)) {
    HEAP32[$53>>2] = $39;
    $55 = ((($32) + ($index$01<<3)|0) + 4|0);
    $56 = ((($37) + ($index$01<<3)|0) + 4|0);
    $57 = HEAP32[$56>>2]|0;
    HEAP32[$55>>2] = $57;
   }
   $58 = (($index$01) + 1)|0;
   $59 = HEAP32[$33>>2]|0;
   $60 = ($58>>>0)<($59>>>0);
   if ($60) {
    $index$01 = $58;
   } else {
    break;
   }
  }
 }
 $61 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$61);
 HEAP32[$this>>2] = $30;
 $62 = (($this) + 12|0);
 HEAP32[$62>>2] = $30;
 $63 = (($this) + 20|0);
 HEAP32[$63>>2] = $$0;
 $64 = (($this) + 8|0);
 HEAP32[$64>>2] = $31;
 HEAP32[$$pre>>2] = $32;
 HEAP32[$15>>2] = $21;
 $65 = (($this) + 28|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(-1);
 if (!($67)) {
  STACKTOP = sp;return;
 }
 HEAP32[$65>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayImNS0_19ReflectionAllocatorImEEE15growAndPushBackERKm($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 536448 : 536208;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,536128,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayINS_17PxTaskDepTableRowENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 3;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 536872 : 536208;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,536128,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<3)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = $$03$i;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $$012$i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
   }
   $35 = (($$012$i) + 8|0);
   $36 = (($$03$i) + 8|0);
   $37 = ($35>>>0)<($20>>>0);
   if ($37) {
    $$012$i = $35;$$03$i = $36;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$18>>2]|0;
  $39 = $$pre;
 } else {
  $39 = $19;
 }
 $38 = (($21) + ($39<<3)|0);
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  $41 = $a;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $38;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
 }
 $51 = HEAP32[$0>>2]|0;
 $52 = ($51|0)>(-1);
 if ($52) {
  $53 = HEAP32[$this>>2]|0;
  $54 = ($53|0)==(0|0);
  if (!($54)) {
   $55 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095]($55,$53);
  }
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $59 = HEAP32[$18>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$18>>2] = $60;
 $61 = (($21) + ($59<<3)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$size,$file,$line) {
 $this = $this|0;
 $size = $size|0;
 $file = $file|0;
 $line = $line|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,$size,537000,$file,$line)|0);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$ptr);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd12ErrorHandlerC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd12ErrorHandlerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 $1 = (($0) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;
 $3 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($3);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd12ErrorHandler11reportErrorENS_11PxErrorCode4EnumEPKcS5_i($this,$code,$message,$file,$line) {
 $this = $this|0;
 $code = $code|0;
 $message = $message|0;
 $file = $file|0;
 $line = $line|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 $1 = (($0) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viiiii[$7 & 255]($3,$code,$message,$file,$line);
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $14 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($14);
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiiii[$13 & 255]($9,$code,$message,$file,$line);
 $14 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($14);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd12ErrorHandler21registerErrorCallbackERNS_15PxErrorCallbackE($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 $1 = (($0) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($2);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = $5 ^ 2147483647;
 $7 = (0 - ($6))|0;
 $8 = $6 & $7;
 $9 = Math_imul($8, 125613361)|0;
 $10 = $9 >>> 27;
 $11 = (412480 + ($10<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $10 & 30;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $$0 = -1;
  $22 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($this) + ($12<<2)|0);
 HEAP32[$15>>2] = $callback;
 $16 = 1 << $12;
 $17 = HEAP32[$3>>2]|0;
 $18 = $17 | $16;
 HEAP32[$3>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 1)|0;
 HEAP32[$19>>2] = $21;
 $$0 = $12;
 $22 = HEAP32[$1>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($22);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd10FoundationC2ERNS_15PxErrorCallbackERNS_19PxAllocatorCallbackE($this,$errc,$alloc) {
 $this = $this|0;
 $errc = $errc|0;
 $alloc = $alloc|0;
 var $$$i$i$i$i = 0, $$$i$i$i$i2 = 0, $$$i$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((537008 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $errc;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((537664 + 8|0));
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $alloc;
 $3 = (($this) + 36|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 40|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 44|0);
 HEAP32[$5>>2] = -1;
 $6 = (($this) + 48|0);
 $7 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$6>>2] = 0;
 } else {
  $10 = HEAP32[537056>>2]|0;
  $11 = (($10) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$10>>2]|0;
  $16 = (($15) + 24|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (FUNCTION_TABLE_ii[$17 & 4095]($10)|0);
  $$$i$i$i$i2 = $18 ? 538080 : 537696;
  $19 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,$8,$$$i$i$i$i2,538000,111)|0);
  HEAP32[$6>>2] = $19;
  $20 = ($19|0)==(0|0);
  if (!($20)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($19);
  }
 }
 $21 = (($this) + 52|0);
 $22 = (($this) + 76|0);
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;HEAP32[$21+20>>2]=0|0;
 HEAPF32[$22>>2] = Math_fround(0.75);
 $23 = (($this) + 80|0);
 HEAP32[$23>>2] = -1;
 $24 = (($this) + 84|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 88|0);
 HEAP32[$25>>2] = 0;
 __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKNS0_14NamedAllocatorEPKcEES6_NS0_4HashIS6_EENS1_11HashMapBaseIS6_S9_SC_NS0_20NonTrackingAllocatorEE6GetKeyESE_Lb1EE15reserveInternalEj($21,64);
 $26 = (($this) + 92|0);
 $27 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0);
 if ($29) {
  HEAP32[$26>>2] = 0;
 } else {
  $30 = HEAP32[537056>>2]|0;
  $31 = (($30) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = HEAP32[$30>>2]|0;
  $36 = (($35) + 24|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (FUNCTION_TABLE_ii[$37 & 4095]($30)|0);
  $$$i$i$i$i6 = $38 ? 538080 : 537696;
  $39 = (FUNCTION_TABLE_iiiiii[$34 & 255]($31,$28,$$$i$i$i$i6,538000,111)|0);
  HEAP32[$26>>2] = $39;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   __ZN5physx6shdfnd9MutexImplC2Ev($39);
  }
 }
 $41 = (($this) + 96|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 100|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 104|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 108|0);
 $45 = (__ZN5physx6shdfnd9MutexImpl7getSizeEv()|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0);
 if ($47) {
  HEAP32[$44>>2] = 0;
  $59 = (($this) + 116|0);
  __ZN5physx6shdfnd12ErrorHandlerC2Ev($59);
  $60 = HEAP32[$0>>2]|0;
  (__ZN5physx6shdfnd12ErrorHandler21registerErrorCallbackERNS_15PxErrorCallbackE($59,$60)|0);
  STACKTOP = sp;return;
 }
 $48 = HEAP32[537056>>2]|0;
 $49 = (($48) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$48>>2]|0;
 $54 = (($53) + 24|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (FUNCTION_TABLE_ii[$55 & 4095]($48)|0);
 $$$i$i$i$i = $56 ? 538080 : 537696;
 $57 = (FUNCTION_TABLE_iiiiii[$52 & 255]($49,$46,$$$i$i$i$i,538000,111)|0);
 HEAP32[$44>>2] = $57;
 $58 = ($57|0)==(0|0);
 if ($58) {
  $59 = (($this) + 116|0);
  __ZN5physx6shdfnd12ErrorHandlerC2Ev($59);
  $60 = HEAP32[$0>>2]|0;
  (__ZN5physx6shdfnd12ErrorHandler21registerErrorCallbackERNS_15PxErrorCallbackE($59,$60)|0);
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd9MutexImplC2Ev($57);
 $59 = (($this) + 116|0);
 __ZN5physx6shdfnd12ErrorHandlerC2Ev($59);
 $60 = HEAP32[$0>>2]|0;
 (__ZN5physx6shdfnd12ErrorHandler21registerErrorCallbackERNS_15PxErrorCallbackE($59,$60)|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10FoundationD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx6shdfnd10FoundationD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10FoundationD2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $alloc = 0, $i$05 = 0, $or$cond$i$i = 0, $ptr$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $alloc = sp + 4|0;
 HEAP32[$this>>2] = ((537008 + 8|0));
 $1 = (($this) + 96|0);
 $2 = (($this) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $60 = $3;$i$05 = 0;
  while(1) {
   $5 = HEAP32[$1>>2]|0;
   $6 = (($5) + ($i$05<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $13 = $60;
   } else {
    $ptr$03 = $7;
    while(1) {
     $9 = HEAP32[$ptr$03>>2]|0;
     __ZN5physx6shdfnd9Allocator10deallocateEPv($alloc,$ptr$03);
     $10 = ($9|0)==(0|0);
     if ($10) {
      break;
     } else {
      $ptr$03 = $9;
     }
    }
    $$pre = HEAP32[$2>>2]|0;
    $13 = $$pre;
   }
   $11 = (($i$05) + 1)|0;
   $12 = ($11>>>0)<($13>>>0);
   if ($12) {
    $60 = $13;$i$05 = $11;
   } else {
    break;
   }
  }
 }
 HEAP32[$0>>2] = 0;
 __ZN5physx6shdfnd5ArrayIPNS0_18TempAllocatorChunkENS0_9AllocatorEE6resizeEjRKS3_($1,0,$0);
 $14 = HEAP32[$2>>2]|0;
 __ZN5physx6shdfnd5ArrayIPNS0_18TempAllocatorChunkENS0_9AllocatorEE8recreateEj($1,$14);
 $15 = (($this) + 116|0);
 __ZN5physx6shdfnd12ErrorHandlerD2Ev($15);
 $16 = (($this) + 108|0);
 $17 = HEAP32[$16>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($17);
 $18 = HEAP32[$16>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = HEAP32[537056>>2]|0;
  $21 = (($20) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vii[$24 & 4095]($21,$18);
 }
 $25 = (($this) + 104|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26 & 2147483647;
 $28 = ($27|0)!=(0);
 $29 = ($26|0)>(-1);
 $or$cond$i$i = $28 & $29;
 if ($or$cond$i$i) {
  $30 = HEAP32[$1>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$30);
 }
 $31 = (($this) + 92|0);
 $32 = HEAP32[$31>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($32);
 $33 = HEAP32[$31>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[537056>>2]|0;
  $36 = (($35) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 12|0);
  $39 = HEAP32[$38>>2]|0;
  FUNCTION_TABLE_vii[$39 & 4095]($36,$33);
 }
 $40 = (($this) + 52|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = HEAP32[537056>>2]|0;
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 20|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (FUNCTION_TABLE_ii[$46 & 4095]($43)|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 12|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_vii[$50 & 4095]($47,$41);
 }
 $51 = (($this) + 48|0);
 $52 = HEAP32[$51>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($52);
 $53 = HEAP32[$51>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  STACKTOP = sp;return;
 }
 $55 = HEAP32[537056>>2]|0;
 $56 = (($55) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 12|0);
 $59 = HEAP32[$58>>2]|0;
 FUNCTION_TABLE_vii[$59 & 4095]($56,$53);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10Foundation19AlignCheckAllocatorD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10Foundation11getInstanceEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[537056>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx6shdfnd10Foundation20getAllocatorCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($this,$c,$file,$line,$messageFmt,$varargs) {
 $this = $this|0;
 $c = $c|0;
 $file = $file|0;
 $line = $line|0;
 $messageFmt = $messageFmt|0;
 $varargs = $varargs|0;
 var $va = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $va = sp;
 HEAP32[$va>>2] = $varargs;
 __ZN5physx6shdfnd10Foundation9errorImplENS_11PxErrorCode4EnumEPKciS5_Pi($this,$c,$file,$line,$messageFmt,$va);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10Foundation9errorImplENS_11PxErrorCode4EnumEPKciS5_Pi($this,$e,$file,$line,$messageFmt,$va) {
 $this = $this|0;
 $e = $e|0;
 $file = $file|0;
 $line = $line|0;
 $messageFmt = $messageFmt|0;
 $va = $va|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bufSize$02 = 0, $heapBuffer$0$lcssa = 0, $heapBuffer$03 = 0, $or$cond = 0, $stackBuffer = 0, $stringBuffer$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $stackBuffer = sp + 2|0;
 $0 = sp;
 $1 = sp + 1|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & $e;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($7);
 $8 = (_vsnprintf($stackBuffer,161,$messageFmt,$va)|0);
 $9 = ($8|0)<(0);
 if ($9) {
  $bufSize$02 = 161;$heapBuffer$03 = 0;
  while(1) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$heapBuffer$03);
   $10 = $bufSize$02 << 1;
   $11 = $10 | 1;
   $12 = HEAP32[537056>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$12>>2]|0;
   $18 = (($17) + 24|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (FUNCTION_TABLE_ii[$19 & 4095]($12)|0);
   $$$i$i$i = $20 ? 537728 : 537696;
   $21 = (FUNCTION_TABLE_iiiiii[$16 & 255]($13,$11,$$$i$i$i,537072,139)|0);
   $22 = (_vsnprintf($21,$10,$messageFmt,$va)|0);
   $23 = ($22|0)<(0);
   $24 = ($10|0)<(1000000);
   $or$cond = $23 & $24;
   if ($or$cond) {
    $bufSize$02 = $10;$heapBuffer$03 = $21;
   } else {
    $heapBuffer$0$lcssa = $21;$stringBuffer$0$lcssa = $21;
    break;
   }
  }
 } else {
  $heapBuffer$0$lcssa = 0;$stringBuffer$0$lcssa = $stackBuffer;
 }
 $25 = (($this) + 116|0);
 __ZN5physx6shdfnd12ErrorHandler11reportErrorENS_11PxErrorCode4EnumEPKcS5_i($25,$e,$stringBuffer$0$lcssa,$file,$line);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$heapBuffer$0$lcssa);
 $26 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($26);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10Foundation14createInstanceEjRNS_15PxErrorCallbackERNS_19PxAllocatorCallbackE($version,$errc,$alloc) {
 $version = $version|0;
 $errc = $errc|0;
 $alloc = $alloc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($version|0)==(50528512);
 if (!($0)) {
  $1 = (__Znaj(256)|0);
  HEAP32[$vararg_buffer>>2] = 50528512;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $version;
  (__ZN5physx6string9sprintf_sEPcjPKcz($1,0,537152,$vararg_buffer)|0);
  $2 = HEAP32[$errc>>2]|0;
  $3 = (($2) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_viiiii[$4 & 255]($errc,4,$1,537072,155);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[537056>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $20 = HEAP32[$errc>>2]|0;
  $21 = (($20) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_viiiii[$22 & 255]($errc,8,537296,537072,186);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$alloc>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiii[$9 & 255]($alloc,132,537224,537072,165)|0);
 HEAP32[537056>>2] = $10;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $17 = HEAP32[$errc>>2]|0;
  $18 = (($17) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_viiiii[$19 & 255]($errc,32,537248,537072,181);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  __ZN5physx6shdfnd10FoundationC2ERNS_15PxErrorCallbackERNS_19PxAllocatorCallbackE($10,$errc,$alloc);
  HEAP32[537240>>2] = 1;
  $12 = HEAP32[537064>>2]|0;
  $13 = ($12|0)==(-1);
  $14 = (($12) + 1)|0;
  $15 = $13 ? 1 : $14;
  HEAP32[537064>>2] = $15;
  $16 = HEAP32[537056>>2]|0;
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx6shdfnd10Foundation11incRefCountEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[537240>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $3 = HEAP32[537056>>2]|0;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,8,537072,220,537488,$vararg_buffer);
  STACKTOP = sp;return;
 } else {
  $2 = (($0) + 1)|0;
  HEAP32[537240>>2] = $2;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd10Foundation11decRefCountEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[537240>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $3 = HEAP32[537056>>2]|0;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($3,8,537072,234,537536,$vararg_buffer);
  STACKTOP = sp;return;
 } else {
  $2 = (($0) + -1)|0;
  HEAP32[537240>>2] = $2;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd10Foundation7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[537240>>2]|0;
 $1 = ($0|0)==(1);
 $2 = HEAP32[537056>>2]|0;
 if ($1) {
  $3 = (($2) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$2>>2]|0;
  $6 = (($5) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 4095]($2);
  $8 = HEAP32[$4>>2]|0;
  $9 = (($8) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[537056>>2]|0;
  FUNCTION_TABLE_vii[$10 & 4095]($4,$11);
  HEAP32[537056>>2] = 0;
  HEAP32[537240>>2] = 0;
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,537072,206,537376,$vararg_buffer);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx6shdfnd10Foundation16getErrorCallbackEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd10Foundation13setErrorLevelENS_11PxErrorCode4EnumE($this,$mask) {
 $this = $this|0;
 $mask = $mask|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 HEAP32[$0>>2] = $mask;
 STACKTOP = sp;return;
}
function __ZNK5physx6shdfnd10Foundation13getErrorLevelEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd12getAllocatorEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[537056>>2]|0;
 $1 = (($0) + 8|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd10Foundation19AlignCheckAllocator8allocateEjPKcS4_i($this,$size,$typeName,$filename,$line) {
 $this = $this|0;
 $size = $size|0;
 $typeName = $typeName|0;
 $filename = $filename|0;
 $line = $line|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $idx$01 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiii[$4 & 255]($1,$size,$typeName,$filename,$line)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = HEAP32[537056>>2]|0;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($7,64,537072,268,537584,$vararg_buffer1);
 }
 $8 = $5;
 $9 = $8 & 15;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $20 = HEAP32[537056>>2]|0;
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($20,64,537072,282,537616,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 } else {
  $idx$01 = 0;
 }
 while(1) {
  $14 = ((($this) + ($idx$01<<2)|0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_viiiiii[$18 & 255]($15,$size,$typeName,$filename,$line,$5);
  $19 = (($idx$01) + 1)|0;
  $exitcond = ($19|0)==($12|0);
  if ($exitcond) {
   $$0 = $5;
   break;
  } else {
   $idx$01 = $19;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z18PxCreateFoundationjRN5physx19PxAllocatorCallbackERNS_15PxErrorCallbackE($version,$allocator,$errorCallback) {
 $version = $version|0;
 $allocator = $allocator|0;
 $errorCallback = $errorCallback|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd10Foundation14createInstanceEjRNS_15PxErrorCallbackERNS_19PxAllocatorCallbackE($version,$errorCallback,$allocator)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z15PxGetFoundationv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[537056>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx6shdfnd10Foundation19AlignCheckAllocatorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10Foundation19AlignCheckAllocator10deallocateEPv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $idx$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $idx$01 = 0;
  while(1) {
   $3 = ((($this) + ($idx$01<<2)|0) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   FUNCTION_TABLE_vii[$7 & 4095]($4,$ptr);
   $8 = (($idx$01) + 1)|0;
   $exitcond = ($8|0)==($1|0);
   if ($exitcond) {
    break;
   } else {
    $idx$01 = $8;
   }
  }
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$13 & 4095]($10,$ptr);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10Foundation19AlignCheckAllocator26registerAllocationListenerERNS_20PxAllocationListenerE($this,$inListener) {
 $this = $this|0;
 $inListener = $inListener|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<(5);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($this) + ($3<<2)|0) + 8|0);
 HEAP32[$4>>2] = $inListener;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd10Foundation19AlignCheckAllocator28deregisterAllocationListenerERNS_20PxAllocationListenerE($this,$inListener) {
 $this = $this|0;
 $inListener = $inListener|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $idx$02 = 0;
 }
 while(1) {
  $6 = ((($this) + ($idx$02<<2)|0) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($inListener|0);
  $4 = (($idx$02) + 1)|0;
  $5 = HEAP32[$0>>2]|0;
  if ($8) {
   break;
  }
  $3 = ($4>>>0)<($5>>>0);
  if ($3) {
   $idx$02 = $4;
  } else {
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return;
 }
 $9 = (($5) + -1)|0;
 $10 = ((($this) + ($9<<2)|0) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$6>>2] = $11;
 $12 = HEAP32[$0>>2]|0;
 $13 = (($12) + -1)|0;
 HEAP32[$0>>2] = $13;
 STACKTOP = sp;return;
}
function __ZNK5physx6shdfnd10Foundation12getAllocatorEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK5physx6shdfnd10Foundation24getReportAllocationNamesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx6shdfnd10Foundation24setReportAllocationNamesEb($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = $value&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS0_18TempAllocatorChunkENS0_9AllocatorEE6resizeEjRKS3_($this,$size,$a) {
 $this = $this|0;
 $size = $size|0;
 $a = $a|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayIPNS0_18TempAllocatorChunkENS0_9AllocatorEE8recreateEj($this,$size);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($size<<2)|0);
 $8 = ($6|0)<($size|0);
 if (!($8)) {
  HEAP32[$5>>2] = $size;
  STACKTOP = sp;return;
 }
 $9 = (($4) + ($6<<2)|0);
 $$01$i = $9;
 while(1) {
  $10 = ($$01$i|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$a>>2]|0;
   HEAP32[$$01$i>>2] = $11;
  }
  $12 = (($$01$i) + 4|0);
  $13 = ($12>>>0)<($7>>>0);
  if ($13) {
   $$01$i = $12;
  } else {
   break;
  }
 }
 HEAP32[$5>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS0_18TempAllocatorChunkENS0_9AllocatorEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $6 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$1,537816,558)|0);
  $6 = $2;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($6) + ($4<<2)|0);
 $7 = ($4|0)>(0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $$012$i = $6;$$03$i = $8;
  while(1) {
   $9 = ($$012$i|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $10;
   }
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11>>>0)<($5>>>0);
   if ($13) {
    $$012$i = $11;$$03$i = $12;
   } else {
    break;
   }
  }
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(-1);
 if (!($16)) {
  HEAP32[$this>>2] = $6;
  HEAP32[$14>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$17);
 HEAP32[$this>>2] = $6;
 HEAP32[$14>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8internal8HashBaseINS0_4PairIKPKNS0_14NamedAllocatorEPKcEES6_NS0_4HashIS6_EENS1_11HashMapBaseIS6_S9_SC_NS0_20NonTrackingAllocatorEE6GetKeyESE_Lb1EE15reserveInternalEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $index$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  label = 3;
 } else {
  $1 = (($size) + -1)|0;
  $2 = $1 & $size;
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = $size;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = $size >>> 1;
  $5 = $4 | $size;
  $6 = $5 >>> 2;
  $7 = $6 | $5;
  $8 = $7 >>> 4;
  $9 = $8 | $7;
  $10 = $9 >>> 8;
  $11 = $10 | $9;
  $12 = $11 >>> 16;
  $13 = $12 | $11;
  $14 = (($13) + 1)|0;
  $$0 = $14;
 }
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (Math_fround(($$0>>>0)));
 $18 = (($this) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = (~~(($20))>>>0);
 $22 = $$0 << 2;
 $23 = $21 << 2;
 $24 = (($23) + ($22))|0;
 $25 = (0 - ($24))|0;
 $26 = $25 & 12;
 $27 = (($26) + ($24))|0;
 $28 = $21 << 3;
 $29 = (($27) + ($28))|0;
 $30 = HEAP32[537056>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (FUNCTION_TABLE_iiiiii[$37 & 255]($34,$29,537984,537896,354)|0);
 $39 = (($38) + ($22)|0);
 $40 = (($38) + ($27)|0);
 _memset(($38|0),-1,($22|0))|0;
 $41 = (($this) + 36|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 $$pre = (($this) + 4|0);
 if (!($43)) {
  $44 = (($$0) + -1)|0;
  $index$01 = 0;
  while(1) {
   $45 = HEAP32[$$pre>>2]|0;
   $46 = (($45) + ($index$01<<3)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47;
   $49 = $48 << 15;
   $50 = $49 ^ -1;
   $51 = (($48) + ($50))|0;
   $52 = $51 >>> 10;
   $53 = $52 ^ $51;
   $54 = ($53*9)|0;
   $55 = $54 >>> 6;
   $56 = $55 ^ $54;
   $57 = $56 << 11;
   $58 = $57 ^ -1;
   $59 = (($56) + ($58))|0;
   $60 = $59 >>> 16;
   $61 = $60 ^ $59;
   $62 = $61 & $44;
   $63 = (($38) + ($62<<2)|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($39) + ($index$01<<2)|0);
   HEAP32[$65>>2] = $64;
   HEAP32[$63>>2] = $index$01;
   $66 = (($40) + ($index$01<<3)|0);
   $67 = ($66|0)==(0|0);
   if (!($67)) {
    HEAP32[$66>>2] = $47;
    $68 = ((($40) + ($index$01<<3)|0) + 4|0);
    $69 = ((($45) + ($index$01<<3)|0) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    HEAP32[$68>>2] = $70;
   }
   $71 = (($index$01) + 1)|0;
   $72 = HEAP32[$41>>2]|0;
   $73 = ($71>>>0)<($72>>>0);
   if ($73) {
    $index$01 = $71;
   } else {
    break;
   }
  }
 }
 $74 = HEAP32[$this>>2]|0;
 $75 = HEAP32[537056>>2]|0;
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + 20|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (FUNCTION_TABLE_ii[$78 & 4095]($75)|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + 12|0);
 $82 = HEAP32[$81>>2]|0;
 FUNCTION_TABLE_vii[$82 & 4095]($79,$74);
 HEAP32[$this>>2] = $38;
 $83 = (($this) + 12|0);
 HEAP32[$83>>2] = $38;
 $84 = (($this) + 20|0);
 HEAP32[$84>>2] = $$0;
 $85 = (($this) + 8|0);
 HEAP32[$85>>2] = $39;
 HEAP32[$$pre>>2] = $40;
 HEAP32[$15>>2] = $21;
 $86 = (($this) + 28|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(-1);
 if (!($88)) {
  STACKTOP = sp;return;
 }
 HEAP32[$86>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd19optimizeBoundingBoxERNS_7PxMat33E($agg$result,$basis) {
 $agg$result = $agg$result|0;
 $basis = $basis|0;
 var $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre11 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0);
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0);
 var $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i2 = Math_fround(0), $fabsf$i$i3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$basis>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($basis) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($basis) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (($basis) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = (($basis) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($basis) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * $18);
 $20 = Math_fround($16 + $19);
 $21 = (($basis) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $22);
 $24 = (($basis) + 28|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($basis) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $29);
 $31 = Math_fround($27 + $30);
 HEAPF32[$agg$result>>2] = $9;
 $32 = (($agg$result) + 4|0);
 HEAPF32[$32>>2] = $20;
 $33 = (($agg$result) + 8|0);
 HEAPF32[$33>>2] = $31;
 $34 = $20 > $9;
 $35 = $34&1;
 $36 = $35 ^ 1;
 $37 = (($agg$result) + ($36<<2)|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = $31 > $38;
 $40 = $39 ? 2 : $36;
 $41 = $35 ^ 3;
 $42 = (($41) - ($40))|0;
 $43 = (($agg$result) + ($35<<2)|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($agg$result) + ($40<<2)|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = $44 < $46;
 $48 = $47 ? $40 : $35;
 $49 = $47 ? $35 : $40;
 $50 = (($agg$result) + ($48<<2)|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (Math_fround(Math_sqrt((Math_fround($51)))));
 $53 = Math_fround(Math_fround(1.0) / $52);
 $54 = Math_fround($51 * $53);
 $55 = (($basis) + (($48*12)|0)|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($53 * $56);
 HEAPF32[$55>>2] = $57;
 $58 = ((($basis) + (($48*12)|0)|0) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($53 * $59);
 HEAPF32[$58>>2] = $60;
 $61 = ((($basis) + (($48*12)|0)|0) + 8|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($53 * $62);
 HEAPF32[$61>>2] = $63;
 $64 = (($basis) + (($49*12)|0)|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($57 * $65);
 $67 = ((($basis) + (($49*12)|0)|0) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($60 * $68);
 $70 = Math_fround($66 + $69);
 $71 = ((($basis) + (($49*12)|0)|0) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($63 * $72);
 $74 = Math_fround($70 + $73);
 $75 = (($basis) + (($42*12)|0)|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($57 * $76);
 $78 = ((($basis) + (($42*12)|0)|0) + 4|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($60 * $79);
 $81 = Math_fround($77 + $80);
 $82 = ((($basis) + (($42*12)|0)|0) + 8|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($63 * $83);
 $85 = Math_fround($81 + $84);
 $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($74)))));
 $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($85)))));
 $86 = Math_fround($fabsf$i$i3 + $fabsf$i$i2);
 $87 = Math_fround($54 + $86);
 HEAPF32[$50>>2] = $87;
 $88 = Math_fround($74 * $57);
 $89 = Math_fround($74 * $60);
 $90 = Math_fround($74 * $63);
 $91 = Math_fround($65 - $88);
 HEAPF32[$64>>2] = $91;
 $92 = Math_fround($68 - $89);
 HEAPF32[$67>>2] = $92;
 $93 = Math_fround($72 - $90);
 HEAPF32[$71>>2] = $93;
 $94 = Math_fround(HEAPF32[$55>>2]);
 $95 = Math_fround($85 * $94);
 $96 = Math_fround(HEAPF32[$58>>2]);
 $97 = Math_fround($85 * $96);
 $98 = Math_fround(HEAPF32[$61>>2]);
 $99 = Math_fround($85 * $98);
 $100 = Math_fround(HEAPF32[$75>>2]);
 $101 = Math_fround($100 - $95);
 HEAPF32[$75>>2] = $101;
 $102 = Math_fround(HEAPF32[$78>>2]);
 $103 = Math_fround($102 - $97);
 HEAPF32[$78>>2] = $103;
 $104 = Math_fround(HEAPF32[$82>>2]);
 $105 = Math_fround($104 - $99);
 HEAPF32[$82>>2] = $105;
 $106 = Math_fround(HEAPF32[$64>>2]);
 $107 = Math_fround($106 * $106);
 $108 = Math_fround(HEAPF32[$67>>2]);
 $109 = Math_fround($108 * $108);
 $110 = Math_fround($107 + $109);
 $111 = Math_fround(HEAPF32[$71>>2]);
 $112 = Math_fround($111 * $111);
 $113 = Math_fround($110 + $112);
 $114 = (Math_fround(Math_sqrt((Math_fround($113)))));
 $115 = $114 > Math_fround(0.0);
 if ($115) {
  $116 = Math_fround(Math_fround(1.0) / $114);
  $117 = Math_fround($106 * $116);
  HEAPF32[$64>>2] = $117;
  $118 = Math_fround($108 * $116);
  HEAPF32[$67>>2] = $118;
  $119 = Math_fround($111 * $116);
  HEAPF32[$71>>2] = $119;
  $$pre = Math_fround(HEAPF32[$75>>2]);
  $$pre10 = Math_fround(HEAPF32[$78>>2]);
  $$pre11 = Math_fround(HEAPF32[$82>>2]);
  $122 = $$pre;$123 = $117;$125 = $$pre10;$126 = $118;$129 = $$pre11;$130 = $119;
 } else {
  $122 = $101;$123 = $106;$125 = $103;$126 = $108;$129 = $105;$130 = $111;
 }
 $120 = (($agg$result) + ($49<<2)|0);
 $121 = Math_fround($123 * $122);
 $124 = Math_fround($126 * $125);
 $127 = Math_fround($121 + $124);
 $128 = Math_fround($130 * $129);
 $131 = Math_fround($127 + $128);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($131)))));
 $132 = Math_fround($114 + $fabsf$i$i);
 HEAPF32[$120>>2] = $132;
 $133 = Math_fround($123 * $131);
 $134 = Math_fround($131 * $126);
 $135 = Math_fround($131 * $130);
 $136 = Math_fround($122 - $133);
 HEAPF32[$75>>2] = $136;
 $137 = Math_fround($125 - $134);
 HEAPF32[$78>>2] = $137;
 $138 = Math_fround($129 - $135);
 HEAPF32[$82>>2] = $138;
 $139 = Math_fround($136 * $136);
 $140 = Math_fround($137 * $137);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($138 * $138);
 $143 = Math_fround($142 + $141);
 $144 = (Math_fround(Math_sqrt((Math_fround($143)))));
 $145 = $144 > Math_fround(0.0);
 if (!($145)) {
  $150 = (($agg$result) + ($42<<2)|0);
  HEAPF32[$150>>2] = $144;
  STACKTOP = sp;return;
 }
 $146 = Math_fround(Math_fround(1.0) / $144);
 $147 = Math_fround($136 * $146);
 HEAPF32[$75>>2] = $147;
 $148 = Math_fround($137 * $146);
 HEAPF32[$78>>2] = $148;
 $149 = Math_fround($138 * $146);
 HEAPF32[$82>>2] = $149;
 $150 = (($agg$result) + ($42<<2)|0);
 HEAPF32[$150>>2] = $144;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5slerpEfRKNS_6PxQuatES3_($agg$result,$t,$left,$right) {
 $agg$result = $agg$result|0;
 $t = Math_fround($t);
 $left = $left|0;
 $right = $right|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $cosine$0 = Math_fround(0), $sign$0 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$left>>2]);
 $1 = Math_fround(HEAPF32[$right>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($left) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($right) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($left) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($right) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($left) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($right) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 + $19);
 $21 = $20 < Math_fround(0.0);
 if ($21) {
  $22 = Math_fround(-$20);
  $cosine$0 = $22;$sign$0 = Math_fround(-1.0);
 } else {
  $cosine$0 = $20;$sign$0 = Math_fround(1.0);
 }
 $23 = Math_fround($cosine$0 * $cosine$0);
 $24 = Math_fround(Math_fround(1.0) - $23);
 $25 = !($24 >= Math_fround(1.00000001686238352639E-16));
 if ($25) {
  HEAPF32[$agg$result>>2] = $0;
  $55 = (($agg$result) + 4|0);
  HEAPF32[$55>>2] = $4;
  $56 = (($agg$result) + 8|0);
  HEAPF32[$56>>2] = $10;
  $57 = (($agg$result) + 12|0);
  HEAPF32[$57>>2] = $16;
  STACKTOP = sp;return;
 } else {
  $26 = (Math_fround(Math_sqrt((Math_fround($24)))));
  $27 = +$26;
  $28 = +$cosine$0;
  $29 = (+Math_atan2((+$27),(+$28)));
  $30 = Math_fround($29);
  $31 = Math_fround(Math_fround(1.0) / $26);
  $32 = Math_fround(Math_fround(1.0) - $t);
  $33 = Math_fround($32 * $30);
  $34 = (Math_fround(+(Math_sin((+$33)))));
  $35 = Math_fround($31 * $34);
  $36 = Math_fround($30 * $t);
  $37 = (Math_fround(+(Math_sin((+$36)))));
  $38 = Math_fround($31 * $37);
  $39 = Math_fround($sign$0 * $38);
  $40 = Math_fround($35 * $0);
  $41 = Math_fround($35 * $4);
  $42 = Math_fround($35 * $10);
  $43 = Math_fround($35 * $16);
  $44 = Math_fround($39 * $1);
  $45 = Math_fround($39 * $6);
  $46 = Math_fround($39 * $12);
  $47 = Math_fround($39 * $18);
  $48 = Math_fround($40 + $44);
  $49 = Math_fround($41 + $45);
  $50 = Math_fround($42 + $46);
  $51 = Math_fround($43 + $47);
  HEAPF32[$agg$result>>2] = $48;
  $52 = (($agg$result) + 4|0);
  HEAPF32[$52>>2] = $49;
  $53 = (($agg$result) + 8|0);
  HEAPF32[$53>>2] = $50;
  $54 = (($agg$result) + 12|0);
  HEAPF32[$54>>2] = $51;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd13TempAllocator8allocateEjPKci($this,$size,$filename,$line) {
 $this = $this|0;
 $size = $size|0;
 $filename = $filename|0;
 $line = $line|0;
 var $$0 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0 = 0, $index$1 = 0;
 var $index$1$c = 0, $it$04 = 0, $ret$0 = 0, $ret$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($size) + 3)|0;
 $2 = $1 >>> 1;
 $3 = $2 | $1;
 $4 = $3 >>> 2;
 $5 = $4 | $3;
 $6 = $5 >>> 4;
 $7 = $6 | $5;
 $8 = $7 >>> 8;
 $9 = $8 | $7;
 $10 = $9 >>> 16;
 $11 = $10 | $9;
 $12 = Math_imul($11, 130329821)|0;
 $13 = $12 >>> 27;
 $14 = (482344 + ($13<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15>>>0)<(8);
 $17 = $16 ? 8 : $15;
 $18 = ($17>>>0)<(17);
 if ($18) {
  $19 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  $20 = (($19) + 108|0);
  $21 = HEAP32[$20>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($21);
  $22 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  $23 = (($22) + 96|0);
  $24 = HEAP32[$23>>2]|0;
  $$sum = (($17) + -8)|0;
  $25 = (($24) + ($$sum<<2)|0);
  $$sum1 = (($17) + -5)|0;
  $26 = (($24) + ($$sum1<<2)|0);
  $27 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  $28 = (($27) + 96|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 100|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + ($31<<2)|0);
  $33 = ($26>>>0)<($32>>>0);
  $34 = $33 ? $26 : $32;
  $35 = ($25>>>0)<($34>>>0);
  L7: do {
   if ($35) {
    $it$04 = $25;
    while(1) {
     $38 = HEAP32[$it$04>>2]|0;
     $39 = ($38|0)==(0|0);
     $37 = (($it$04) + 4|0);
     if (!($39)) {
      break;
     }
     $36 = ($37>>>0)<($34>>>0);
     if ($36) {
      $it$04 = $37;
     } else {
      label = 7;
      break L7;
     }
    }
    $40 = HEAP32[$38>>2]|0;
    HEAP32[$it$04>>2] = $40;
    $41 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
    $42 = (($41) + 96|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = $it$04;
    $45 = $43;
    $46 = (($44) - ($45))|0;
    $47 = $46 >> 2;
    $48 = (($47) + 8)|0;
    $index$0 = $48;$ret$0 = $38;
   } else {
    label = 7;
   }
  } while(0);
  if ((label|0) == 7) {
   $49 = 2 << $17;
   $50 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$49,$filename,$line)|0);
   $index$0 = $17;$ret$0 = $50;
  }
  $51 = HEAP32[$20>>2]|0;
  __ZN5physx6shdfnd9MutexImpl6unlockEv($51);
  $index$1 = $index$0;$ret$1 = $ret$0;
 } else {
  $52 = (($size) + 4)|0;
  $53 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($this,$52,$filename,$line)|0);
  $index$1 = $17;$ret$1 = $53;
 }
 $index$1$c = $index$1;
 HEAP32[$ret$1>>2] = $index$1$c;
 $54 = (($ret$1) + 4|0);
 $$0 = $54;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx6shdfnd13TempAllocator10deallocateEPv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($ptr|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($ptr) + -4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)>(16);
 if ($4) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($this,$2);
  STACKTOP = sp;return;
 }
 $5 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 $6 = (($5) + 108|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($7);
 $8 = (($3) + -8)|0;
 $9 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 $10 = (($9) + 100|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)>($8>>>0);
 if (!($12)) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  $14 = (($13) + 96|0);
  $15 = (($3) + -7)|0;
  HEAP32[$0>>2] = 0;
  __ZN5physx6shdfnd5ArrayIPNS0_18TempAllocatorChunkENS0_9AllocatorEE6resizeEjRKS3_($14,$15,$0);
 }
 $16 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 $17 = (($16) + 96|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + ($8<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$2>>2] = $20;
 $21 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 $22 = (($21) + 96|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + ($8<<2)|0);
 HEAP32[$24>>2] = $2;
 $25 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($25);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm19CmEventNameProvider15getProfileNamesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 545640;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $agg$result;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a6522() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[538208>>2] = 539800;
 HEAP32[((538208 + 4|0))>>2] = 65536;
 HEAP32[((538208 + 8|0))>>2] = 539824;
 HEAP32[((538208 + 12|0))>>2] = 65537;
 HEAP32[((538208 + 16|0))>>2] = 539856;
 HEAP32[((538208 + 20|0))>>2] = 65538;
 HEAP32[((538208 + 24|0))>>2] = 539888;
 HEAP32[((538208 + 28|0))>>2] = 65539;
 HEAP32[((538208 + 32|0))>>2] = 539912;
 HEAP32[((538208 + 36|0))>>2] = 65540;
 HEAP32[((538208 + 40|0))>>2] = 539936;
 HEAP32[((538208 + 44|0))>>2] = 65541;
 HEAP32[((538208 + 48|0))>>2] = 539968;
 HEAP32[((538208 + 52|0))>>2] = 65542;
 HEAP32[((538208 + 56|0))>>2] = 540000;
 HEAP32[((538208 + 60|0))>>2] = 65543;
 HEAP32[((538208 + 64|0))>>2] = 540040;
 HEAP32[((538208 + 68|0))>>2] = 65544;
 HEAP32[((538208 + 72|0))>>2] = 540072;
 HEAP32[((538208 + 76|0))>>2] = 65545;
 HEAP32[((538208 + 80|0))>>2] = 540104;
 HEAP32[((538208 + 84|0))>>2] = 65546;
 HEAP32[((538208 + 88|0))>>2] = 540128;
 HEAP32[((538208 + 92|0))>>2] = 65547;
 HEAP32[((538208 + 96|0))>>2] = 540152;
 HEAP32[((538208 + 100|0))>>2] = 65548;
 HEAP32[((538208 + 104|0))>>2] = 540176;
 HEAP32[((538208 + 108|0))>>2] = 65549;
 HEAP32[((538208 + 112|0))>>2] = 540200;
 HEAP32[((538208 + 116|0))>>2] = 65550;
 HEAP32[((538208 + 120|0))>>2] = 540232;
 HEAP32[((538208 + 124|0))>>2] = 65551;
 HEAP32[((538208 + 128|0))>>2] = 540256;
 HEAP32[((538208 + 132|0))>>2] = 65552;
 HEAP32[((538208 + 136|0))>>2] = 540280;
 HEAP32[((538208 + 140|0))>>2] = 65553;
 HEAP32[((538208 + 144|0))>>2] = 540304;
 HEAP32[((538208 + 148|0))>>2] = 65554;
 HEAP32[((538208 + 152|0))>>2] = 540336;
 HEAP32[((538208 + 156|0))>>2] = 65555;
 HEAP32[((538208 + 160|0))>>2] = 540360;
 HEAP32[((538208 + 164|0))>>2] = 65556;
 HEAP32[((538208 + 168|0))>>2] = 540392;
 HEAP32[((538208 + 172|0))>>2] = 65557;
 HEAP32[((538208 + 176|0))>>2] = 540424;
 HEAP32[((538208 + 180|0))>>2] = 65558;
 HEAP32[((538208 + 184|0))>>2] = 540456;
 HEAP32[((538208 + 188|0))>>2] = 65559;
 HEAP32[((538208 + 192|0))>>2] = 540488;
 HEAP32[((538208 + 196|0))>>2] = 65560;
 HEAP32[((538208 + 200|0))>>2] = 540520;
 HEAP32[((538208 + 204|0))>>2] = 65561;
 HEAP32[((538208 + 208|0))>>2] = 540552;
 HEAP32[((538208 + 212|0))>>2] = 65562;
 HEAP32[((538208 + 216|0))>>2] = 540584;
 HEAP32[((538208 + 220|0))>>2] = 65563;
 HEAP32[((538208 + 224|0))>>2] = 540624;
 HEAP32[((538208 + 228|0))>>2] = 65564;
 HEAP32[((538208 + 232|0))>>2] = 540656;
 HEAP32[((538208 + 236|0))>>2] = 65565;
 HEAP32[((538208 + 240|0))>>2] = 540696;
 HEAP32[((538208 + 244|0))>>2] = 65566;
 HEAP32[((538208 + 248|0))>>2] = 540736;
 HEAP32[((538208 + 252|0))>>2] = 65567;
 HEAP32[((538208 + 256|0))>>2] = 540760;
 HEAP32[((538208 + 260|0))>>2] = 65568;
 HEAP32[((538208 + 264|0))>>2] = 540792;
 HEAP32[((538208 + 268|0))>>2] = 65569;
 HEAP32[((538208 + 272|0))>>2] = 540824;
 HEAP32[((538208 + 276|0))>>2] = 65570;
 HEAP32[((538208 + 280|0))>>2] = 540856;
 HEAP32[((538208 + 284|0))>>2] = 65571;
 HEAP32[((538208 + 288|0))>>2] = 540888;
 HEAP32[((538208 + 292|0))>>2] = 65572;
 HEAP32[((538208 + 296|0))>>2] = 540928;
 HEAP32[((538208 + 300|0))>>2] = 65573;
 HEAP32[((538208 + 304|0))>>2] = 540976;
 HEAP32[((538208 + 308|0))>>2] = 65574;
 HEAP32[((538208 + 312|0))>>2] = 541008;
 HEAP32[((538208 + 316|0))>>2] = 65575;
 HEAP32[((538208 + 320|0))>>2] = 541056;
 HEAP32[((538208 + 324|0))>>2] = 65576;
 HEAP32[((538208 + 328|0))>>2] = 541104;
 HEAP32[((538208 + 332|0))>>2] = 65577;
 HEAP32[((538208 + 336|0))>>2] = 541160;
 HEAP32[((538208 + 340|0))>>2] = 65578;
 HEAP32[((538208 + 344|0))>>2] = 541216;
 HEAP32[((538208 + 348|0))>>2] = 65579;
 HEAP32[((538208 + 352|0))>>2] = 541264;
 HEAP32[((538208 + 356|0))>>2] = 65580;
 HEAP32[((538208 + 360|0))>>2] = 541288;
 HEAP32[((538208 + 364|0))>>2] = 65581;
 HEAP32[((538208 + 368|0))>>2] = 541304;
 HEAP32[((538208 + 372|0))>>2] = 65582;
 HEAP32[((538208 + 376|0))>>2] = 541328;
 HEAP32[((538208 + 380|0))>>2] = 65583;
 HEAP32[((538208 + 384|0))>>2] = 541352;
 HEAP32[((538208 + 388|0))>>2] = 65584;
 HEAP32[((538208 + 392|0))>>2] = 541368;
 HEAP32[((538208 + 396|0))>>2] = 65585;
 HEAP32[((538208 + 400|0))>>2] = 541392;
 HEAP32[((538208 + 404|0))>>2] = 65586;
 HEAP32[((538208 + 408|0))>>2] = 541416;
 HEAP32[((538208 + 412|0))>>2] = 65587;
 HEAP32[((538208 + 416|0))>>2] = 541440;
 HEAP32[((538208 + 420|0))>>2] = 65588;
 HEAP32[((538208 + 424|0))>>2] = 541464;
 HEAP32[((538208 + 428|0))>>2] = 53;
 HEAP32[((538208 + 432|0))>>2] = 541488;
 HEAP32[((538208 + 436|0))>>2] = 54;
 HEAP32[((538208 + 440|0))>>2] = 541520;
 HEAP32[((538208 + 444|0))>>2] = 55;
 HEAP32[((538208 + 448|0))>>2] = 541544;
 HEAP32[((538208 + 452|0))>>2] = 56;
 HEAP32[((538208 + 456|0))>>2] = 541576;
 HEAP32[((538208 + 460|0))>>2] = 57;
 HEAP32[((538208 + 464|0))>>2] = 541600;
 HEAP32[((538208 + 468|0))>>2] = 58;
 HEAP32[((538208 + 472|0))>>2] = 541632;
 HEAP32[((538208 + 476|0))>>2] = 59;
 HEAP32[((538208 + 480|0))>>2] = 541664;
 HEAP32[((538208 + 484|0))>>2] = 60;
 HEAP32[((538208 + 488|0))>>2] = 541696;
 HEAP32[((538208 + 492|0))>>2] = 65597;
 HEAP32[((538208 + 496|0))>>2] = 541720;
 HEAP32[((538208 + 500|0))>>2] = 65598;
 HEAP32[((538208 + 504|0))>>2] = 541744;
 HEAP32[((538208 + 508|0))>>2] = 65599;
 HEAP32[((538208 + 512|0))>>2] = 541768;
 HEAP32[((538208 + 516|0))>>2] = 65600;
 HEAP32[((538208 + 520|0))>>2] = 541792;
 HEAP32[((538208 + 524|0))>>2] = 65601;
 HEAP32[((538208 + 528|0))>>2] = 541808;
 HEAP32[((538208 + 532|0))>>2] = 65602;
 HEAP32[((538208 + 536|0))>>2] = 541824;
 HEAP32[((538208 + 540|0))>>2] = 65603;
 HEAP32[((538208 + 544|0))>>2] = 541848;
 HEAP32[((538208 + 548|0))>>2] = 65604;
 HEAP32[((538208 + 552|0))>>2] = 541872;
 HEAP32[((538208 + 556|0))>>2] = 65605;
 HEAP32[((538208 + 560|0))>>2] = 541896;
 HEAP32[((538208 + 564|0))>>2] = 65606;
 HEAP32[((538208 + 568|0))>>2] = 541920;
 HEAP32[((538208 + 572|0))>>2] = 65607;
 HEAP32[((538208 + 576|0))>>2] = 541944;
 HEAP32[((538208 + 580|0))>>2] = 65608;
 HEAP32[((538208 + 584|0))>>2] = 541960;
 HEAP32[((538208 + 588|0))>>2] = 65609;
 HEAP32[((538208 + 592|0))>>2] = 541984;
 HEAP32[((538208 + 596|0))>>2] = 65610;
 HEAP32[((538208 + 600|0))>>2] = 542016;
 HEAP32[((538208 + 604|0))>>2] = 65611;
 HEAP32[((538208 + 608|0))>>2] = 542040;
 HEAP32[((538208 + 612|0))>>2] = 65612;
 HEAP32[((538208 + 616|0))>>2] = 542064;
 HEAP32[((538208 + 620|0))>>2] = 65613;
 HEAP32[((538208 + 624|0))>>2] = 542096;
 HEAP32[((538208 + 628|0))>>2] = 65614;
 HEAP32[((538208 + 632|0))>>2] = 542128;
 HEAP32[((538208 + 636|0))>>2] = 65615;
 HEAP32[((538208 + 640|0))>>2] = 542160;
 HEAP32[((538208 + 644|0))>>2] = 65616;
 HEAP32[((538208 + 648|0))>>2] = 542184;
 HEAP32[((538208 + 652|0))>>2] = 65617;
 HEAP32[((538208 + 656|0))>>2] = 542208;
 HEAP32[((538208 + 660|0))>>2] = 65618;
 HEAP32[((538208 + 664|0))>>2] = 542232;
 HEAP32[((538208 + 668|0))>>2] = 65619;
 HEAP32[((538208 + 672|0))>>2] = 542248;
 HEAP32[((538208 + 676|0))>>2] = 65620;
 HEAP32[((538208 + 680|0))>>2] = 542264;
 HEAP32[((538208 + 684|0))>>2] = 65621;
 HEAP32[((538208 + 688|0))>>2] = 542280;
 HEAP32[((538208 + 692|0))>>2] = 65622;
 HEAP32[((538208 + 696|0))>>2] = 542304;
 HEAP32[((538208 + 700|0))>>2] = 65623;
 HEAP32[((538208 + 704|0))>>2] = 542328;
 HEAP32[((538208 + 708|0))>>2] = 65624;
 HEAP32[((538208 + 712|0))>>2] = 542352;
 HEAP32[((538208 + 716|0))>>2] = 65625;
 HEAP32[((538208 + 720|0))>>2] = 542384;
 HEAP32[((538208 + 724|0))>>2] = 65626;
 HEAP32[((538208 + 728|0))>>2] = 542408;
 HEAP32[((538208 + 732|0))>>2] = 65627;
 HEAP32[((538208 + 736|0))>>2] = 542424;
 HEAP32[((538208 + 740|0))>>2] = 65628;
 HEAP32[((538208 + 744|0))>>2] = 542448;
 HEAP32[((538208 + 748|0))>>2] = 65629;
 HEAP32[((538208 + 752|0))>>2] = 542472;
 HEAP32[((538208 + 756|0))>>2] = 65630;
 HEAP32[((538208 + 760|0))>>2] = 542496;
 HEAP32[((538208 + 764|0))>>2] = 65631;
 HEAP32[((538208 + 768|0))>>2] = 542528;
 HEAP32[((538208 + 772|0))>>2] = 65632;
 HEAP32[((538208 + 776|0))>>2] = 542552;
 HEAP32[((538208 + 780|0))>>2] = 65633;
 HEAP32[((538208 + 784|0))>>2] = 542576;
 HEAP32[((538208 + 788|0))>>2] = 65634;
 HEAP32[((538208 + 792|0))>>2] = 542600;
 HEAP32[((538208 + 796|0))>>2] = 65635;
 HEAP32[((538208 + 800|0))>>2] = 542616;
 HEAP32[((538208 + 804|0))>>2] = 65636;
 HEAP32[((538208 + 808|0))>>2] = 542640;
 HEAP32[((538208 + 812|0))>>2] = 65637;
 HEAP32[((538208 + 816|0))>>2] = 542656;
 HEAP32[((538208 + 820|0))>>2] = 65638;
 HEAP32[((538208 + 824|0))>>2] = 542672;
 HEAP32[((538208 + 828|0))>>2] = 65639;
 HEAP32[((538208 + 832|0))>>2] = 542696;
 HEAP32[((538208 + 836|0))>>2] = 65640;
 HEAP32[((538208 + 840|0))>>2] = 542728;
 HEAP32[((538208 + 844|0))>>2] = 65641;
 HEAP32[((538208 + 848|0))>>2] = 542760;
 HEAP32[((538208 + 852|0))>>2] = 65642;
 HEAP32[((538208 + 856|0))>>2] = 542784;
 HEAP32[((538208 + 860|0))>>2] = 65643;
 HEAP32[((538208 + 864|0))>>2] = 542816;
 HEAP32[((538208 + 868|0))>>2] = 65644;
 HEAP32[((538208 + 872|0))>>2] = 542840;
 HEAP32[((538208 + 876|0))>>2] = 65645;
 HEAP32[((538208 + 880|0))>>2] = 542880;
 HEAP32[((538208 + 884|0))>>2] = 65646;
 HEAP32[((538208 + 888|0))>>2] = 542912;
 HEAP32[((538208 + 892|0))>>2] = 65647;
 HEAP32[((538208 + 896|0))>>2] = 542936;
 HEAP32[((538208 + 900|0))>>2] = 65648;
 HEAP32[((538208 + 904|0))>>2] = 542968;
 HEAP32[((538208 + 908|0))>>2] = 65649;
 HEAP32[((538208 + 912|0))>>2] = 542984;
 HEAP32[((538208 + 916|0))>>2] = 65650;
 HEAP32[((538208 + 920|0))>>2] = 543016;
 HEAP32[((538208 + 924|0))>>2] = 65651;
 HEAP32[((538208 + 928|0))>>2] = 543040;
 HEAP32[((538208 + 932|0))>>2] = 65652;
 HEAP32[((538208 + 936|0))>>2] = 543072;
 HEAP32[((538208 + 940|0))>>2] = 65653;
 HEAP32[((538208 + 944|0))>>2] = 543104;
 HEAP32[((538208 + 948|0))>>2] = 65654;
 HEAP32[((538208 + 952|0))>>2] = 543152;
 HEAP32[((538208 + 956|0))>>2] = 65655;
 HEAP32[((538208 + 960|0))>>2] = 543192;
 HEAP32[((538208 + 964|0))>>2] = 65656;
 HEAP32[((538208 + 968|0))>>2] = 543208;
 HEAP32[((538208 + 972|0))>>2] = 65657;
 HEAP32[((538208 + 976|0))>>2] = 543232;
 HEAP32[((538208 + 980|0))>>2] = 65658;
 HEAP32[((538208 + 984|0))>>2] = 543256;
 HEAP32[((538208 + 988|0))>>2] = 65659;
 HEAP32[((538208 + 992|0))>>2] = 543280;
 HEAP32[((538208 + 996|0))>>2] = 65660;
 HEAP32[((538208 + 1000|0))>>2] = 543296;
 HEAP32[((538208 + 1004|0))>>2] = 65661;
 HEAP32[((538208 + 1008|0))>>2] = 543320;
 HEAP32[((538208 + 1012|0))>>2] = 65662;
 HEAP32[((538208 + 1016|0))>>2] = 543352;
 HEAP32[((538208 + 1020|0))>>2] = 65663;
 HEAP32[((538208 + 1024|0))>>2] = 543384;
 HEAP32[((538208 + 1028|0))>>2] = 65664;
 HEAP32[((538208 + 1032|0))>>2] = 543416;
 HEAP32[((538208 + 1036|0))>>2] = 65665;
 HEAP32[((538208 + 1040|0))>>2] = 543440;
 HEAP32[((538208 + 1044|0))>>2] = 65666;
 HEAP32[((538208 + 1048|0))>>2] = 543464;
 HEAP32[((538208 + 1052|0))>>2] = 65667;
 HEAP32[((538208 + 1056|0))>>2] = 543488;
 HEAP32[((538208 + 1060|0))>>2] = 65668;
 HEAP32[((538208 + 1064|0))>>2] = 543520;
 HEAP32[((538208 + 1068|0))>>2] = 65669;
 HEAP32[((538208 + 1072|0))>>2] = 543552;
 HEAP32[((538208 + 1076|0))>>2] = 65670;
 HEAP32[((538208 + 1080|0))>>2] = 543584;
 HEAP32[((538208 + 1084|0))>>2] = 65671;
 HEAP32[((538208 + 1088|0))>>2] = 543608;
 HEAP32[((538208 + 1092|0))>>2] = 65672;
 HEAP32[((538208 + 1096|0))>>2] = 543640;
 HEAP32[((538208 + 1100|0))>>2] = 65673;
 HEAP32[((538208 + 1104|0))>>2] = 543672;
 HEAP32[((538208 + 1108|0))>>2] = 65674;
 HEAP32[((538208 + 1112|0))>>2] = 543704;
 HEAP32[((538208 + 1116|0))>>2] = 65675;
 HEAP32[((538208 + 1120|0))>>2] = 543744;
 HEAP32[((538208 + 1124|0))>>2] = 65676;
 HEAP32[((538208 + 1128|0))>>2] = 543784;
 HEAP32[((538208 + 1132|0))>>2] = 65677;
 HEAP32[((538208 + 1136|0))>>2] = 543816;
 HEAP32[((538208 + 1140|0))>>2] = 65678;
 HEAP32[((538208 + 1144|0))>>2] = 543848;
 HEAP32[((538208 + 1148|0))>>2] = 65679;
 HEAP32[((538208 + 1152|0))>>2] = 543880;
 HEAP32[((538208 + 1156|0))>>2] = 65680;
 HEAP32[((538208 + 1160|0))>>2] = 543912;
 HEAP32[((538208 + 1164|0))>>2] = 65681;
 HEAP32[((538208 + 1168|0))>>2] = 543944;
 HEAP32[((538208 + 1172|0))>>2] = 65682;
 HEAP32[((538208 + 1176|0))>>2] = 543976;
 HEAP32[((538208 + 1180|0))>>2] = 65683;
 HEAP32[((538208 + 1184|0))>>2] = 544008;
 HEAP32[((538208 + 1188|0))>>2] = 65684;
 HEAP32[((538208 + 1192|0))>>2] = 544048;
 HEAP32[((538208 + 1196|0))>>2] = 65685;
 HEAP32[((538208 + 1200|0))>>2] = 544088;
 HEAP32[((538208 + 1204|0))>>2] = 65686;
 HEAP32[((538208 + 1208|0))>>2] = 544120;
 HEAP32[((538208 + 1212|0))>>2] = 65687;
 HEAP32[((538208 + 1216|0))>>2] = 544160;
 HEAP32[((538208 + 1220|0))>>2] = 65688;
 HEAP32[((538208 + 1224|0))>>2] = 544192;
 HEAP32[((538208 + 1228|0))>>2] = 65689;
 HEAP32[((538208 + 1232|0))>>2] = 544216;
 HEAP32[((538208 + 1236|0))>>2] = 65690;
 HEAP32[((538208 + 1240|0))>>2] = 544256;
 HEAP32[((538208 + 1244|0))>>2] = 65691;
 HEAP32[((538208 + 1248|0))>>2] = 544296;
 HEAP32[((538208 + 1252|0))>>2] = 65692;
 HEAP32[((538208 + 1256|0))>>2] = 544328;
 HEAP32[((538208 + 1260|0))>>2] = 65693;
 HEAP32[((538208 + 1264|0))>>2] = 544360;
 HEAP32[((538208 + 1268|0))>>2] = 65694;
 HEAP32[((538208 + 1272|0))>>2] = 544392;
 HEAP32[((538208 + 1276|0))>>2] = 65695;
 HEAP32[((538208 + 1280|0))>>2] = 544416;
 HEAP32[((538208 + 1284|0))>>2] = 65696;
 HEAP32[((538208 + 1288|0))>>2] = 544448;
 HEAP32[((538208 + 1292|0))>>2] = 65697;
 HEAP32[((538208 + 1296|0))>>2] = 544472;
 HEAP32[((538208 + 1300|0))>>2] = 65698;
 HEAP32[((538208 + 1304|0))>>2] = 544504;
 HEAP32[((538208 + 1308|0))>>2] = 65699;
 HEAP32[((538208 + 1312|0))>>2] = 544528;
 HEAP32[((538208 + 1316|0))>>2] = 65700;
 HEAP32[((538208 + 1320|0))>>2] = 544560;
 HEAP32[((538208 + 1324|0))>>2] = 65701;
 HEAP32[((538208 + 1328|0))>>2] = 544584;
 HEAP32[((538208 + 1332|0))>>2] = 65702;
 HEAP32[((538208 + 1336|0))>>2] = 544616;
 HEAP32[((538208 + 1340|0))>>2] = 65703;
 HEAP32[((538208 + 1344|0))>>2] = 544648;
 HEAP32[((538208 + 1348|0))>>2] = 65704;
 HEAP32[((538208 + 1352|0))>>2] = 544688;
 HEAP32[((538208 + 1356|0))>>2] = 65705;
 HEAP32[((538208 + 1360|0))>>2] = 544728;
 HEAP32[((538208 + 1364|0))>>2] = 65706;
 HEAP32[((538208 + 1368|0))>>2] = 544752;
 HEAP32[((538208 + 1372|0))>>2] = 65707;
 HEAP32[((538208 + 1376|0))>>2] = 544776;
 HEAP32[((538208 + 1380|0))>>2] = 65708;
 HEAP32[((538208 + 1384|0))>>2] = 544800;
 HEAP32[((538208 + 1388|0))>>2] = 65709;
 HEAP32[((538208 + 1392|0))>>2] = 544840;
 HEAP32[((538208 + 1396|0))>>2] = 65710;
 HEAP32[((538208 + 1400|0))>>2] = 544872;
 HEAP32[((538208 + 1404|0))>>2] = 65711;
 HEAP32[((538208 + 1408|0))>>2] = 544912;
 HEAP32[((538208 + 1412|0))>>2] = 65712;
 HEAP32[((538208 + 1416|0))>>2] = 544952;
 HEAP32[((538208 + 1420|0))>>2] = 65713;
 HEAP32[((538208 + 1424|0))>>2] = 544984;
 HEAP32[((538208 + 1428|0))>>2] = 65714;
 HEAP32[((538208 + 1432|0))>>2] = 545008;
 HEAP32[((538208 + 1436|0))>>2] = 65715;
 HEAP32[((538208 + 1440|0))>>2] = 545032;
 HEAP32[((538208 + 1444|0))>>2] = 65716;
 HEAP32[((538208 + 1448|0))>>2] = 545056;
 HEAP32[((538208 + 1452|0))>>2] = 65717;
 HEAP32[((538208 + 1456|0))>>2] = 545080;
 HEAP32[((538208 + 1460|0))>>2] = 65718;
 HEAP32[((538208 + 1464|0))>>2] = 545104;
 HEAP32[((538208 + 1468|0))>>2] = 65719;
 HEAP32[((538208 + 1472|0))>>2] = 545136;
 HEAP32[((538208 + 1476|0))>>2] = 65720;
 HEAP32[((538208 + 1480|0))>>2] = 545152;
 HEAP32[((538208 + 1484|0))>>2] = 65721;
 HEAP32[((538208 + 1488|0))>>2] = 545176;
 HEAP32[((538208 + 1492|0))>>2] = 65722;
 HEAP32[((538208 + 1496|0))>>2] = 545208;
 HEAP32[((538208 + 1500|0))>>2] = 65723;
 HEAP32[((538208 + 1504|0))>>2] = 545240;
 HEAP32[((538208 + 1508|0))>>2] = 65724;
 HEAP32[((538208 + 1512|0))>>2] = 545264;
 HEAP32[((538208 + 1516|0))>>2] = 65725;
 HEAP32[((538208 + 1520|0))>>2] = 545288;
 HEAP32[((538208 + 1524|0))>>2] = 65726;
 HEAP32[((538208 + 1528|0))>>2] = 545320;
 HEAP32[((538208 + 1532|0))>>2] = 65727;
 HEAP32[((538208 + 1536|0))>>2] = 545360;
 HEAP32[((538208 + 1540|0))>>2] = 65728;
 HEAP32[((538208 + 1544|0))>>2] = 545392;
 HEAP32[((538208 + 1548|0))>>2] = 65729;
 HEAP32[((538208 + 1552|0))>>2] = 545440;
 HEAP32[((538208 + 1556|0))>>2] = 65730;
 HEAP32[((538208 + 1560|0))>>2] = 545488;
 HEAP32[((538208 + 1564|0))>>2] = 65731;
 HEAP32[((538208 + 1568|0))>>2] = 545528;
 HEAP32[((538208 + 1572|0))>>2] = 65732;
 HEAP32[((538208 + 1576|0))>>2] = 545560;
 HEAP32[((538208 + 1580|0))>>2] = 65733;
 HEAP32[((538208 + 1584|0))>>2] = 545600;
 HEAP32[((538208 + 1588|0))>>2] = 65734;
 HEAP32[545640>>2] = 199;
 HEAP32[((545640 + 4|0))>>2] = 538208;
 HEAP32[545648>>2] = 65550;
 HEAP32[545656>>2] = 65559;
 HEAP32[545664>>2] = 65560;
 HEAP32[545672>>2] = 65561;
 HEAP32[545680>>2] = 65569;
 HEAP32[545688>>2] = 65570;
 HEAP32[545696>>2] = 65581;
 HEAP32[545704>>2] = 65607;
 HEAP32[545712>>2] = 65608;
 HEAP32[545720>>2] = 65609;
 HEAP32[545728>>2] = 65610;
 HEAP32[545736>>2] = 65637;
 HEAP32[545744>>2] = 65654;
 HEAP32[545752>>2] = 65656;
 HEAP32[545760>>2] = 65657;
 HEAP32[545768>>2] = 65658;
 HEAP32[545776>>2] = 65659;
 HEAP32[545784>>2] = 65679;
 HEAP32[545792>>2] = 65680;
 HEAP32[545800>>2] = 65681;
 HEAP32[545808>>2] = 65682;
 HEAP32[545816>>2] = 65683;
 HEAP32[545824>>2] = 65684;
 HEAP32[545832>>2] = 65685;
 HEAP32[545840>>2] = 65686;
 HEAP32[545848>>2] = 65687;
 HEAP32[545856>>2] = 65688;
 HEAP32[545864>>2] = 65689;
 HEAP32[545872>>2] = 65706;
 HEAP32[545880>>2] = 65707;
 HEAP32[545888>>2] = 65708;
 HEAP32[545896>>2] = 65709;
 HEAP32[545904>>2] = 65710;
 HEAP32[545912>>2] = 65711;
 HEAP32[545920>>2] = 65713;
 STACKTOP = sp;return;
}
function __ZN5physx22PxTransformFromSegmentERKNS_6PxVec3ES2_Pf($agg$result,$p0,$p1,$halfHeight) {
 $agg$result = $agg$result|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $halfHeight = $halfHeight|0;
 var $$pre = Math_fround(0), $$pre13 = Math_fround(0), $$pre14 = Math_fround(0), $$pre15 = Math_fround(0), $$pre16 = Math_fround(0), $$pre17 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0);
 var $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0;
 var $8 = 0, $9 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$p1>>2]);
 $1 = Math_fround(HEAPF32[$p0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($p1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($p0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($p1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($p0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround($2 * $2);
 $14 = Math_fround($7 * $7);
 $15 = Math_fround($13 + $14);
 $16 = Math_fround($12 * $12);
 $17 = Math_fround($15 + $16);
 $18 = (Math_fround(Math_sqrt((Math_fround($17)))));
 $19 = ($halfHeight|0)==(0|0);
 if ($19) {
  $22 = $1;$23 = $0;$25 = $6;$26 = $4;$28 = $11;$29 = $9;
 } else {
  $20 = Math_fround($18 * Math_fround(0.5));
  HEAPF32[$halfHeight>>2] = $20;
  $$pre = Math_fround(HEAPF32[$p1>>2]);
  $$pre13 = Math_fround(HEAPF32[$p0>>2]);
  $$pre14 = Math_fround(HEAPF32[$3>>2]);
  $$pre15 = Math_fround(HEAPF32[$5>>2]);
  $$pre16 = Math_fround(HEAPF32[$8>>2]);
  $$pre17 = Math_fround(HEAPF32[$10>>2]);
  $22 = $$pre13;$23 = $$pre;$25 = $$pre15;$26 = $$pre14;$28 = $$pre17;$29 = $$pre16;
 }
 $21 = Math_fround($23 + $22);
 $24 = Math_fround($26 + $25);
 $27 = Math_fround($29 + $28);
 $30 = Math_fround($21 * Math_fround(0.5));
 $31 = Math_fround($24 * Math_fround(0.5));
 $32 = Math_fround($27 * Math_fround(0.5));
 $33 = $18 < Math_fround(9.99999997475242707878E-7);
 if ($33) {
  $66 = Math_fround(0.0);$68 = Math_fround(0.0);$70 = Math_fround(0.0);$72 = Math_fround(1.0);
  HEAPF32[$agg$result>>2] = $66;
  $67 = (($agg$result) + 4|0);
  HEAPF32[$67>>2] = $68;
  $69 = (($agg$result) + 8|0);
  HEAPF32[$69>>2] = $70;
  $71 = (($agg$result) + 12|0);
  HEAPF32[$71>>2] = $72;
  $73 = (($agg$result) + 16|0);
  HEAPF32[$73>>2] = $30;
  $74 = (($agg$result) + 20|0);
  HEAPF32[$74>>2] = $31;
  $75 = (($agg$result) + 24|0);
  HEAPF32[$75>>2] = $32;
  STACKTOP = sp;return;
 }
 $34 = Math_fround(Math_fround(1.0) / $18);
 $35 = Math_fround($2 * $34);
 $36 = Math_fround($7 * $34);
 $37 = Math_fround($12 * $34);
 $38 = Math_fround($36 * Math_fround(0.0));
 $39 = Math_fround($35 + $38);
 $40 = Math_fround($37 * Math_fround(0.0));
 $41 = Math_fround($40 + $39);
 $42 = $41 > Math_fround(-1.0);
 if ($42) {
  $43 = Math_fround($35 * Math_fround(0.0));
  $44 = Math_fround($36 - $43);
  $45 = Math_fround($43 - $37);
  $46 = Math_fround($40 - $38);
  $47 = Math_fround($41 + Math_fround(1.0));
  $50 = $46;$52 = $45;$55 = $44;$58 = $47;
 } else {
  $fabsf$i$i$i = (Math_fround(Math_abs(Math_fround(1.0))));
  $48 = $fabsf$i$i$i < Math_fround(0.100000001490116119385);
  if ($48) {
   $50 = Math_fround(0.0);$52 = Math_fround(0.0);$55 = Math_fround(-0.0);$58 = Math_fround(0.0);
  } else {
   $50 = Math_fround(0.0);$52 = Math_fround(-1.0);$55 = Math_fround(0.0);$58 = Math_fround(0.0);
  }
 }
 $49 = Math_fround($50 * $50);
 $51 = Math_fround($52 * $52);
 $53 = Math_fround($51 + $49);
 $54 = Math_fround($55 * $55);
 $56 = Math_fround($54 + $53);
 $57 = Math_fround($58 * $58);
 $59 = Math_fround($57 + $56);
 $60 = (Math_fround(Math_sqrt((Math_fround($59)))));
 $61 = Math_fround(Math_fround(1.0) / $60);
 $62 = Math_fround($50 * $61);
 $63 = Math_fround($52 * $61);
 $64 = Math_fround($55 * $61);
 $65 = Math_fround($58 * $61);
 $66 = $62;$68 = $63;$70 = $64;$72 = $65;
 HEAPF32[$agg$result>>2] = $66;
 $67 = (($agg$result) + 4|0);
 HEAPF32[$67>>2] = $68;
 $69 = (($agg$result) + 8|0);
 HEAPF32[$69>>2] = $70;
 $71 = (($agg$result) + 12|0);
 HEAPF32[$71>>2] = $72;
 $73 = (($agg$result) + 16|0);
 HEAPF32[$73>>2] = $30;
 $74 = (($agg$result) + 20|0);
 HEAPF32[$74>>2] = $31;
 $75 = (($agg$result) + 24|0);
 HEAPF32[$75>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN5physx13PxDiagonalizeERKNS_7PxMat33ERNS_6PxQuatE($agg$result,$m,$massFrame) {
 $agg$result = $agg$result|0;
 $m = $m|0;
 $massFrame = $massFrame|0;
 var $$lcssa = Math_fround(0), $$lcssa41 = Math_fround(0), $$lcssa42 = Math_fround(0), $$lcssa43 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0);
 var $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0.0, $172 = Math_fround(0), $173 = 0.0, $174 = 0.0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $d = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i2 = Math_fround(0), $fabsf$i$i3 = Math_fround(0), $fabsf$i$i4 = Math_fround(0), $fabsf$i$i5 = Math_fround(0), $fabsf$i$i6 = Math_fround(0), $i$044 = 0, $or$cond = 0, $q$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $q$i1 = sp + 40|0;
 $d = sp;
 $0 = Math_fround(HEAPF32[$m>>2]);
 $1 = (($m) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($m) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($m) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($m) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($m) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($m) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($m) + 28|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($m) + 32|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($d) + 4|0);
 $18 = (($d) + 8|0);
 $19 = (($d) + 12|0);
 $20 = (($d) + 16|0);
 $21 = (($d) + 20|0);
 $22 = (($d) + 24|0);
 $23 = (($d) + 28|0);
 $24 = (($d) + 32|0);
 $25 = (($q$i1) + 4|0);
 $26 = (($q$i1) + 8|0);
 $27 = (($q$i1) + 12|0);
 $28 = (($q$i1) + 4|0);
 $29 = (($q$i1) + 8|0);
 $30 = (($q$i1) + 12|0);
 $32 = Math_fround(0.0);$34 = Math_fround(0.0);$36 = Math_fround(0.0);$43 = Math_fround(1.0);$i$044 = 0;
 while(1) {
  $31 = Math_fround($32 + $32);
  $33 = Math_fround($34 + $34);
  $35 = Math_fround($36 + $36);
  $37 = Math_fround($32 * $31);
  $38 = Math_fround($34 * $33);
  $39 = Math_fround($36 * $35);
  $40 = Math_fround($34 * $31);
  $41 = Math_fround($36 * $31);
  $42 = Math_fround($43 * $31);
  $44 = Math_fround($36 * $33);
  $45 = Math_fround($43 * $33);
  $46 = Math_fround($43 * $35);
  $47 = Math_fround(Math_fround(1.0) - $38);
  $48 = Math_fround($47 - $39);
  $49 = Math_fround($46 + $40);
  $50 = Math_fround($41 - $45);
  $51 = Math_fround($40 - $46);
  $52 = Math_fround(Math_fround(1.0) - $37);
  $53 = Math_fround($52 - $39);
  $54 = Math_fround($44 + $42);
  $55 = Math_fround($45 + $41);
  $56 = Math_fround($44 - $42);
  $57 = Math_fround($52 - $38);
  $58 = Math_fround($48 * $0);
  $59 = Math_fround($51 * $0);
  $60 = Math_fround($55 * $0);
  $61 = Math_fround($49 * $2);
  $62 = Math_fround($53 * $2);
  $63 = Math_fround($56 * $2);
  $64 = Math_fround($58 + $61);
  $65 = Math_fround($59 + $62);
  $66 = Math_fround($60 + $63);
  $67 = Math_fround($50 * $4);
  $68 = Math_fround($54 * $4);
  $69 = Math_fround($57 * $4);
  $70 = Math_fround($64 + $67);
  $71 = Math_fround($65 + $68);
  $72 = Math_fround($66 + $69);
  $73 = Math_fround($48 * $6);
  $74 = Math_fround($51 * $6);
  $75 = Math_fround($55 * $6);
  $76 = Math_fround($49 * $8);
  $77 = Math_fround($53 * $8);
  $78 = Math_fround($56 * $8);
  $79 = Math_fround($73 + $76);
  $80 = Math_fround($74 + $77);
  $81 = Math_fround($75 + $78);
  $82 = Math_fround($50 * $10);
  $83 = Math_fround($54 * $10);
  $84 = Math_fround($57 * $10);
  $85 = Math_fround($79 + $82);
  $86 = Math_fround($80 + $83);
  $87 = Math_fround($81 + $84);
  $88 = Math_fround($48 * $12);
  $89 = Math_fround($51 * $12);
  $90 = Math_fround($55 * $12);
  $91 = Math_fround($49 * $14);
  $92 = Math_fround($53 * $14);
  $93 = Math_fround($56 * $14);
  $94 = Math_fround($88 + $91);
  $95 = Math_fround($89 + $92);
  $96 = Math_fround($90 + $93);
  $97 = Math_fround($50 * $16);
  $98 = Math_fround($54 * $16);
  $99 = Math_fround($57 * $16);
  $100 = Math_fround($94 + $97);
  $101 = Math_fround($95 + $98);
  $102 = Math_fround($96 + $99);
  $103 = Math_fround($48 * $70);
  $104 = Math_fround($48 * $71);
  $105 = Math_fround($48 * $72);
  $106 = Math_fround($49 * $85);
  $107 = Math_fround($49 * $86);
  $108 = Math_fround($49 * $87);
  $109 = Math_fround($103 + $106);
  $110 = Math_fround($104 + $107);
  $111 = Math_fround($105 + $108);
  $112 = Math_fround($50 * $100);
  $113 = Math_fround($50 * $101);
  $114 = Math_fround($50 * $102);
  $115 = Math_fround($109 + $112);
  $116 = Math_fround($110 + $113);
  $117 = Math_fround($111 + $114);
  $118 = Math_fround($51 * $70);
  $119 = Math_fround($51 * $71);
  $120 = Math_fround($51 * $72);
  $121 = Math_fround($53 * $85);
  $122 = Math_fround($53 * $86);
  $123 = Math_fround($53 * $87);
  $124 = Math_fround($118 + $121);
  $125 = Math_fround($119 + $122);
  $126 = Math_fround($120 + $123);
  $127 = Math_fround($54 * $100);
  $128 = Math_fround($54 * $101);
  $129 = Math_fround($54 * $102);
  $130 = Math_fround($124 + $127);
  $131 = Math_fround($125 + $128);
  $132 = Math_fround($126 + $129);
  $133 = Math_fround($55 * $70);
  $134 = Math_fround($55 * $71);
  $135 = Math_fround($55 * $72);
  $136 = Math_fround($56 * $85);
  $137 = Math_fround($56 * $86);
  $138 = Math_fround($56 * $87);
  $139 = Math_fround($133 + $136);
  $140 = Math_fround($134 + $137);
  $141 = Math_fround($135 + $138);
  $142 = Math_fround($57 * $100);
  $143 = Math_fround($57 * $101);
  $144 = Math_fround($57 * $102);
  $145 = Math_fround($139 + $142);
  $146 = Math_fround($140 + $143);
  $147 = Math_fround($141 + $144);
  HEAPF32[$d>>2] = $115;
  HEAPF32[$17>>2] = $116;
  HEAPF32[$18>>2] = $117;
  HEAPF32[$19>>2] = $130;
  HEAPF32[$20>>2] = $131;
  HEAPF32[$21>>2] = $132;
  HEAPF32[$22>>2] = $145;
  HEAPF32[$23>>2] = $146;
  HEAPF32[$24>>2] = $147;
  $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($132)))));
  $fabsf$i$i6 = (Math_fround(Math_abs((Math_fround($117)))));
  $fabsf$i$i4 = (Math_fround(Math_abs((Math_fround($116)))));
  $148 = $fabsf$i$i5 > $fabsf$i$i6;
  $149 = $fabsf$i$i5 > $fabsf$i$i4;
  $or$cond = $148 & $149;
  if ($or$cond) {
   $153 = 0;
  } else {
   $150 = $fabsf$i$i6 > $fabsf$i$i4;
   $151 = $150 ? 1 : 2;
   $153 = $151;
  }
  $152 = (($153) + 1)|0;
  $154 = $153 >>> 1;
  $155 = (($152) + ($154))|0;
  $156 = $155 & 3;
  $157 = (($155) + 1)|0;
  $158 = $156 >>> 1;
  $159 = (($157) + ($158))|0;
  $160 = $159 & 3;
  $161 = (($d) + (($156*12)|0)|0);
  $162 = (($161) + ($160<<2)|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = $163 == Math_fround(0.0);
  if ($164) {
   $$lcssa = $43;$$lcssa41 = $36;$$lcssa42 = $34;$$lcssa43 = $32;
   label = 10;
   break;
  }
  $165 = (($161) + ($156<<2)|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($d) + (($160*12)|0)|0);
  $168 = (($167) + ($160<<2)|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = Math_fround($166 - $169);
  $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($170)))));
  $171 = +$fabsf$i$i3;
  $172 = Math_fround($163 * Math_fround(2.0));
  $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($172)))));
  $173 = +$fabsf$i$i2;
  $174 = $173 * 2.0E+6;
  $175 = $171 > $174;
  if ($175) {
   $$lcssa = $43;$$lcssa41 = $36;$$lcssa42 = $34;$$lcssa43 = $32;
   label = 10;
   break;
  }
  $176 = Math_fround($170 / $172);
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($176)))));
  $177 = $fabsf$i$i > Math_fround(1000.0);
  if ($177) {
   $178 = Math_fround($176 * Math_fround(4.0));
   $179 = Math_fround(Math_fround(1.0) / $178);
   HEAPF32[$q$i1>>2] = Math_fround(0.0);
   HEAPF32[$25>>2] = Math_fround(0.0);
   HEAPF32[$26>>2] = Math_fround(0.0);
   HEAPF32[$27>>2] = Math_fround(1.0);
   $180 = (($q$i1) + ($153<<2)|0);
   HEAPF32[$180>>2] = $179;
   $181 = Math_fround(HEAPF32[$q$i1>>2]);
   $182 = Math_fround(HEAPF32[$25>>2]);
   $183 = Math_fround(HEAPF32[$26>>2]);
   $184 = Math_fround(HEAPF32[$27>>2]);
   $209 = $181;$211 = $184;$214 = $183;$217 = $182;
  } else {
   $185 = Math_fround($176 * $176);
   $186 = Math_fround($185 + Math_fround(1.0));
   $187 = (Math_fround(Math_sqrt((Math_fround($186)))));
   $188 = Math_fround($fabsf$i$i + $187);
   $189 = Math_fround(Math_fround(1.0) / $188);
   $190 = Math_fround($189 * $189);
   $191 = Math_fround($190 + Math_fround(1.0));
   $192 = (Math_fround(Math_sqrt((Math_fround($191)))));
   $193 = Math_fround(Math_fround(1.0) / $192);
   $194 = Math_fround(Math_fround(1.0) - $193);
   $195 = Math_fround($194 * Math_fround(0.5));
   $196 = (Math_fround(Math_sqrt((Math_fround($195)))));
   $197 = $176 >= Math_fround(0.0);
   $198 = $197 ? Math_fround(1.0) : Math_fround(-1.0);
   $199 = Math_fround($198 * $196);
   $200 = Math_fround($193 + Math_fround(1.0));
   $201 = Math_fround($200 * Math_fround(0.5));
   $202 = (Math_fround(Math_sqrt((Math_fround($201)))));
   HEAPF32[$q$i1>>2] = Math_fround(0.0);
   HEAPF32[$28>>2] = Math_fround(0.0);
   HEAPF32[$29>>2] = Math_fround(0.0);
   HEAPF32[$30>>2] = $202;
   $203 = (($q$i1) + ($153<<2)|0);
   HEAPF32[$203>>2] = $199;
   $204 = Math_fround(HEAPF32[$q$i1>>2]);
   $205 = Math_fround(HEAPF32[$28>>2]);
   $206 = Math_fround(HEAPF32[$29>>2]);
   $207 = Math_fround(HEAPF32[$30>>2]);
   $209 = $204;$211 = $207;$214 = $206;$217 = $205;
  }
  $208 = Math_fround($43 * $209);
  $210 = Math_fround($32 * $211);
  $212 = Math_fround($210 + $208);
  $213 = Math_fround($34 * $214);
  $215 = Math_fround($213 + $212);
  $216 = Math_fround($36 * $217);
  $218 = Math_fround($215 - $216);
  $219 = Math_fround($43 * $217);
  $220 = Math_fround($34 * $211);
  $221 = Math_fround($220 + $219);
  $222 = Math_fround($36 * $209);
  $223 = Math_fround($221 + $222);
  $224 = Math_fround($32 * $214);
  $225 = Math_fround($223 - $224);
  $226 = Math_fround($43 * $214);
  $227 = Math_fround($36 * $211);
  $228 = Math_fround($227 + $226);
  $229 = Math_fround($32 * $217);
  $230 = Math_fround($229 + $228);
  $231 = Math_fround($34 * $209);
  $232 = Math_fround($230 - $231);
  $233 = Math_fround($43 * $211);
  $234 = Math_fround($32 * $209);
  $235 = Math_fround($233 - $234);
  $236 = Math_fround($34 * $217);
  $237 = Math_fround($235 - $236);
  $238 = Math_fround($36 * $214);
  $239 = Math_fround($237 - $238);
  $240 = Math_fround($218 * $218);
  $241 = Math_fround($225 * $225);
  $242 = Math_fround($241 + $240);
  $243 = Math_fround($232 * $232);
  $244 = Math_fround($243 + $242);
  $245 = Math_fround($239 * $239);
  $246 = Math_fround($245 + $244);
  $247 = (Math_fround(Math_sqrt((Math_fround($246)))));
  $248 = Math_fround(Math_fround(1.0) / $247);
  $249 = Math_fround($248 * $218);
  $250 = Math_fround($248 * $225);
  $251 = Math_fround($232 * $248);
  $252 = Math_fround($248 * $239);
  $253 = (($i$044) + 1)|0;
  $254 = ($253>>>0)<(24);
  if ($254) {
   $32 = $249;$34 = $250;$36 = $251;$43 = $252;$i$044 = $253;
  } else {
   $$lcssa = $252;$$lcssa41 = $251;$$lcssa42 = $250;$$lcssa43 = $249;
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  HEAPF32[$massFrame>>2] = $$lcssa43;
  $255 = (($massFrame) + 4|0);
  HEAPF32[$255>>2] = $$lcssa42;
  $256 = (($massFrame) + 8|0);
  HEAPF32[$256>>2] = $$lcssa41;
  $257 = (($massFrame) + 12|0);
  HEAPF32[$257>>2] = $$lcssa;
  HEAPF32[$agg$result>>2] = $115;
  $258 = (($agg$result) + 4|0);
  HEAPF32[$258>>2] = $131;
  $259 = (($agg$result) + 8|0);
  HEAPF32[$259>>2] = $147;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Cm8PtrTable5clearEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2&65535)>(1);
 if ($3) {
  $4 = (($this) + 6|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   $7 = HEAP32[$this>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
   HEAP32[$this>>2] = 0;
  }
 }
 HEAP16[$1>>1] = 0;
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm8PtrTable6addPtrEPv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i1 = 0, $ptrs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 10|0;
 $1 = sp + 8|0;
 $ptrs = sp;
 $2 = sp + 9|0;
 $3 = (($this) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 if ((($4<<16>>16) == 1)) {
  $18 = $this;
 } else if ((($4<<16>>16) == 0)) {
  $43 = (($this) + 7|0);
  HEAP8[$43>>0] = 1;
  HEAP32[$this>>2] = $ptr;
  HEAP16[$3>>1] = 1;
  STACKTOP = sp;return;
 } else {
  $5 = HEAP32[$this>>2]|0;
  $18 = $5;
 }
 $6 = $4&65535;
 $7 = (($6) + 1)|0;
 $8 = $7 << 2;
 $9 = ($8>>>0)>(1024);
 $10 = (($ptrs) + 4|0);
 $11 = $9&1;
 HEAP8[$10>>0] = $11;
 if ($9) {
  $12 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($2,$8,545952,83)|0);
  HEAP32[$ptrs>>2] = $12;
  $$pre = HEAP16[$3>>1]|0;
  $15 = $$pre;$17 = $12;
 } else {
  $13 = STACKTOP; STACKTOP = STACKTOP + ((((4*$7)|0)+15)&-16)|0;;
  HEAP32[$ptrs>>2] = $13;
  $15 = $4;$17 = $13;
 }
 $14 = $15&65535;
 $16 = $14 << 2;
 _memcpy(($17|0),($18|0),($16|0))|0;
 $19 = HEAP16[$3>>1]|0;
 $20 = $19&65535;
 $21 = HEAP32[$ptrs>>2]|0;
 $22 = (($21) + ($20<<2)|0);
 HEAP32[$22>>2] = $ptr;
 $23 = HEAP32[$ptrs>>2]|0;
 $24 = ($19&65535)<(2);
 $25 = ($20|0)==($7|0);
 $or$cond$i1 = $24 | $25;
 if (!($or$cond$i1)) {
  $26 = (($this) + 6|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if (!($28)) {
   $29 = HEAP32[$this>>2]|0;
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$29);
   HEAP32[$this>>2] = 0;
  }
 }
 $30 = ($7>>>0)>(1);
 $31 = (($this) + 7|0);
 if ($30) {
  HEAP8[$31>>0] = 0;
  $32 = HEAP16[$3>>1]|0;
  $33 = $32&65535;
  $34 = ($33|0)==($7|0);
  if ($34) {
   $$pre$i = HEAP32[$this>>2]|0;
   $37 = $$pre$i;
  } else {
   $35 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$8,545952,64)|0);
   HEAP32[$this>>2] = $35;
   $36 = (($this) + 6|0);
   HEAP8[$36>>0] = 1;
   $37 = $35;
  }
  _memcpy(($37|0),($23|0),($8|0))|0;
 } else {
  HEAP8[$31>>0] = 1;
  $38 = HEAP32[$23>>2]|0;
  HEAP32[$this>>2] = $38;
 }
 $39 = $7&65535;
 HEAP16[$3>>1] = $39;
 $40 = HEAP8[$10>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = HEAP32[$ptrs>>2]|0;
 __ZN5physx6shdfnd13TempAllocator10deallocateEPv($ptrs,$42);
 STACKTOP = sp;return;
}
function __ZNK5physx2Cm8PtrTable4findEPKv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ($1<<16>>16)==(1);
 if ($3) {
  $9 = $this;
  label = 4;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = ($1<<16>>16)==(0);
  if ($5) {
   $$0 = -1;
  } else {
   $9 = $4;
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $i$01 = 0;
   while(1) {
    $8 = (($9) + ($i$01<<2)|0);
    $10 = HEAP32[$8>>2]|0;
    $11 = ($10|0)==($ptr|0);
    $7 = (($i$01) + 1)|0;
    if ($11) {
     $$0 = $i$01;
     break L4;
    }
    $6 = ($7>>>0)<($2>>>0);
    if ($6) {
     $i$01 = $7;
    } else {
     $$0 = -1;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Cm8PtrTable6removeEj($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(1);
 if (!($3)) {
  $4 = HEAP32[$this>>2]|0;
  $5 = ($2&65535)>(2);
  if ($5) {
   $6 = (($2) + -1)<<16>>16;
   HEAP16[$1>>1] = $6;
   $7 = $6&65535;
   $8 = (($4) + ($7<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($4) + ($index<<2)|0);
   HEAP32[$10>>2] = $9;
   STACKTOP = sp;return;
  }
  $11 = ($2<<16>>16)==(2);
  if ($11) {
   $12 = (1 - ($index))|0;
   $13 = (($4) + ($12<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($this) + 6|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if (!($17)) {
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$4);
    HEAP32[$this>>2] = 0;
   }
   $18 = (($this) + 7|0);
   HEAP8[$18>>0] = 1;
   HEAP32[$this>>2] = $14;
   HEAP16[$1>>1] = 1;
   STACKTOP = sp;return;
  }
 }
 HEAP16[$1>>1] = 0;
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Cm8PtrTable15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1&65535)>(1);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$stream>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($stream,16);
 $6 = HEAP32[$stream>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = HEAP16[$0>>1]|0;
 $11 = $10&65535;
 $12 = $11 << 2;
 FUNCTION_TABLE_viii[$8 & 4095]($stream,$9,$12);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($this,$prim) {
 $this = $this|0;
 $prim = $prim|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $prim;
 $0 = (($this) + 32|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Cm12RenderOutputlsEj($this,$color) {
 $this = $this|0;
 $color = $color|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $color;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$transform>>2]);
 $1 = (($this) + 36|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($transform) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 40|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($transform) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 44|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($transform) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 48|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($transform) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 52|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($transform) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 56|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($transform) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 60|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($transform) + 28|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 64|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($transform) + 32|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($this) + 68|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($transform) + 36|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($this) + 72|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($transform) + 40|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($this) + 76|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($transform) + 44|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 80|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($transform) + 48|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($this) + 84|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($transform) + 52|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($this) + 88|0);
 HEAPF32[$40>>2] = $39;
 $41 = (($transform) + 56|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 92|0);
 HEAPF32[$43>>2] = $42;
 $44 = (($transform) + 60|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($this) + 96|0);
 HEAPF32[$46>>2] = $45;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$t>>2]);
 $1 = (($t) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($t) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($t) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 + $0);
 $8 = Math_fround($2 + $2);
 $9 = Math_fround($4 + $4);
 $10 = Math_fround($0 * $7);
 $11 = Math_fround($2 * $8);
 $12 = Math_fround($4 * $9);
 $13 = Math_fround($7 * $2);
 $14 = Math_fround($7 * $4);
 $15 = Math_fround($7 * $6);
 $16 = Math_fround($8 * $4);
 $17 = Math_fround($8 * $6);
 $18 = Math_fround($9 * $6);
 $19 = Math_fround(Math_fround(1.0) - $11);
 $20 = Math_fround($19 - $12);
 $21 = Math_fround($13 + $18);
 $22 = Math_fround($14 - $17);
 $23 = Math_fround($13 - $18);
 $24 = Math_fround(Math_fround(1.0) - $10);
 $25 = Math_fround($24 - $12);
 $26 = Math_fround($16 + $15);
 $27 = Math_fround($14 + $17);
 $28 = Math_fround($16 - $15);
 $29 = Math_fround($24 - $11);
 $30 = (($t) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($t) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($t) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($this) + 36|0);
 HEAPF32[$36>>2] = $20;
 $37 = (($this) + 40|0);
 HEAPF32[$37>>2] = $21;
 $38 = (($this) + 44|0);
 HEAPF32[$38>>2] = $22;
 $39 = (($this) + 48|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($this) + 52|0);
 HEAPF32[$40>>2] = $23;
 $41 = (($this) + 56|0);
 HEAPF32[$41>>2] = $25;
 $42 = (($this) + 60|0);
 HEAPF32[$42>>2] = $26;
 $43 = (($this) + 64|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($this) + 68|0);
 HEAPF32[$44>>2] = $27;
 $45 = (($this) + 72|0);
 HEAPF32[$45>>2] = $28;
 $46 = (($this) + 76|0);
 HEAPF32[$46>>2] = $29;
 $47 = (($this) + 80|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($this) + 84|0);
 HEAPF32[$48>>2] = $31;
 $49 = (($this) + 88|0);
 HEAPF32[$49>>2] = $33;
 $50 = (($this) + 92|0);
 HEAPF32[$50>>2] = $35;
 $51 = (($this) + 96|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$vertex) {
 $this = $this|0;
 $vertex = $vertex|0;
 var $$pr = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre$i10 = 0, $$pre$i5 = 0, $$pre$i8 = 0, $$pre$phi15Z2D = 0, $$pre$phi17Z2D = 0, $$pre$phiZ2D = 0, $$pre14 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0;
 var $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0;
 var $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0;
 var $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $0 = sp + 160|0;
 $1 = sp;
 $2 = sp + 32|0;
 $3 = sp + 64|0;
 $4 = sp + 112|0;
 $5 = Math_fround(HEAPF32[$vertex>>2]);
 $6 = (($vertex) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($vertex) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 36|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($5 * $11);
 $13 = (($this) + 40|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($5 * $14);
 $16 = (($this) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($5 * $17);
 $19 = (($this) + 52|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($7 * $20);
 $22 = (($this) + 56|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($7 * $23);
 $25 = (($this) + 60|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($7 * $26);
 $28 = Math_fround($12 + $21);
 $29 = Math_fround($15 + $24);
 $30 = Math_fround($18 + $27);
 $31 = (($this) + 68|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($9 * $32);
 $34 = (($this) + 72|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($9 * $35);
 $37 = (($this) + 76|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($9 * $38);
 $40 = Math_fround($28 + $33);
 $41 = Math_fround($29 + $36);
 $42 = Math_fround($30 + $39);
 $43 = (($this) + 84|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($this) + 88|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($this) + 92|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($40 + $44);
 $50 = Math_fround($41 + $46);
 $51 = Math_fround($42 + $48);
 HEAPF32[$vertex>>2] = $49;
 HEAPF32[$6>>2] = $50;
 HEAPF32[$8>>2] = $51;
 $52 = (($this) + 32|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$52>>2] = $54;
 $55 = HEAP32[$this>>2]|0;
 L1: do {
  switch ($55|0) {
  case 3:  {
   $152 = ($54|0)==(3);
   if ($152) {
    $153 = (($this) + 100|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = (($154) + 28|0);
    $156 = (($this) + 4|0);
    $157 = (($this) + 20|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    HEAPF32[$3>>2] = $158;
    $159 = (($3) + 4|0);
    $160 = (($this) + 24|0);
    $161 = Math_fround(HEAPF32[$160>>2]);
    HEAPF32[$159>>2] = $161;
    $162 = (($3) + 8|0);
    $163 = (($this) + 28|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    HEAPF32[$162>>2] = $164;
    $165 = (($3) + 12|0);
    $166 = HEAP32[$156>>2]|0;
    HEAP32[$165>>2] = $166;
    $167 = (($3) + 16|0);
    $168 = (($this) + 8|0);
    $169 = Math_fround(HEAPF32[$168>>2]);
    HEAPF32[$167>>2] = $169;
    $170 = (($3) + 20|0);
    $171 = (($this) + 12|0);
    $172 = Math_fround(HEAPF32[$171>>2]);
    HEAPF32[$170>>2] = $172;
    $173 = (($3) + 24|0);
    $174 = (($this) + 16|0);
    $175 = Math_fround(HEAPF32[$174>>2]);
    HEAPF32[$173>>2] = $175;
    $176 = (($3) + 28|0);
    HEAP32[$176>>2] = $166;
    $177 = (($3) + 32|0);
    HEAPF32[$177>>2] = $49;
    $178 = (($3) + 36|0);
    HEAPF32[$178>>2] = $50;
    $179 = (($3) + 40|0);
    HEAPF32[$179>>2] = $51;
    $180 = (($3) + 44|0);
    HEAP32[$180>>2] = $166;
    $181 = (($154) + 36|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = $182 & 2147483647;
    $184 = (($154) + 32|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ($183>>>0)>($185>>>0);
    if ($186) {
     $187 = HEAP32[$155>>2]|0;
     $188 = (($187) + (($185*48)|0)|0);
     $189 = ($188|0)==(0|0);
     if ($189) {
      $202 = $185;
     } else {
      HEAPF32[$188>>2] = $158;
      $190 = ((($187) + (($185*48)|0)|0) + 4|0);
      HEAPF32[$190>>2] = $161;
      $191 = ((($187) + (($185*48)|0)|0) + 8|0);
      HEAPF32[$191>>2] = $164;
      $192 = ((($187) + (($185*48)|0)|0) + 12|0);
      HEAP32[$192>>2] = $166;
      $193 = ((($187) + (($185*48)|0)|0) + 16|0);
      HEAPF32[$193>>2] = $169;
      $194 = ((($187) + (($185*48)|0)|0) + 20|0);
      HEAPF32[$194>>2] = $172;
      $195 = ((($187) + (($185*48)|0)|0) + 24|0);
      HEAPF32[$195>>2] = $175;
      $196 = ((($187) + (($185*48)|0)|0) + 28|0);
      HEAP32[$196>>2] = $166;
      $197 = ((($187) + (($185*48)|0)|0) + 32|0);
      HEAPF32[$197>>2] = $49;
      $198 = ((($187) + (($185*48)|0)|0) + 36|0);
      HEAPF32[$198>>2] = $50;
      $199 = ((($187) + (($185*48)|0)|0) + 40|0);
      HEAPF32[$199>>2] = $51;
      $200 = ((($187) + (($185*48)|0)|0) + 44|0);
      HEAP32[$200>>2] = $166;
      $$pre$i1 = HEAP32[$184>>2]|0;
      $202 = $$pre$i1;
     }
     $201 = (($202) + 1)|0;
     HEAP32[$184>>2] = $201;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_15PxDebugTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($155,$3)|0);
    }
    HEAP32[$52>>2] = 0;
    $$pre$phi15Z2D = $171;$$pre$phi17Z2D = $174;$$pre$phiZ2D = $168;
   } else {
    label = 33;
   }
   break;
  }
  case 4:  {
   $203 = ($54>>>0)>(2);
   if ($203) {
    $204 = (($this) + 100|0);
    $205 = HEAP32[$204>>2]|0;
    $206 = (($205) + 28|0);
    $207 = $54 & 1;
    $208 = ($207|0)!=(0);
    $209 = (($this) + 8|0);
    $210 = (($this) + 20|0);
    $211 = $208 ? $209 : $210;
    $212 = $208 ? $210 : $209;
    $213 = (($this) + 4|0);
    $214 = Math_fround(HEAPF32[$211>>2]);
    HEAPF32[$4>>2] = $214;
    $215 = (($4) + 4|0);
    $216 = (($211) + 4|0);
    $217 = Math_fround(HEAPF32[$216>>2]);
    HEAPF32[$215>>2] = $217;
    $218 = (($4) + 8|0);
    $219 = (($211) + 8|0);
    $220 = Math_fround(HEAPF32[$219>>2]);
    HEAPF32[$218>>2] = $220;
    $221 = (($4) + 12|0);
    $222 = HEAP32[$213>>2]|0;
    HEAP32[$221>>2] = $222;
    $223 = (($4) + 16|0);
    $224 = Math_fround(HEAPF32[$212>>2]);
    HEAPF32[$223>>2] = $224;
    $225 = (($4) + 20|0);
    $226 = (($212) + 4|0);
    $227 = Math_fround(HEAPF32[$226>>2]);
    HEAPF32[$225>>2] = $227;
    $228 = (($4) + 24|0);
    $229 = (($212) + 8|0);
    $230 = Math_fround(HEAPF32[$229>>2]);
    HEAPF32[$228>>2] = $230;
    $231 = (($4) + 28|0);
    HEAP32[$231>>2] = $222;
    $232 = (($4) + 32|0);
    HEAPF32[$232>>2] = $49;
    $233 = (($4) + 36|0);
    HEAPF32[$233>>2] = $50;
    $234 = (($4) + 40|0);
    HEAPF32[$234>>2] = $51;
    $235 = (($4) + 44|0);
    HEAP32[$235>>2] = $222;
    $236 = (($205) + 36|0);
    $237 = HEAP32[$236>>2]|0;
    $238 = $237 & 2147483647;
    $239 = (($205) + 32|0);
    $240 = HEAP32[$239>>2]|0;
    $241 = ($238>>>0)>($240>>>0);
    if (!($241)) {
     (__ZN5physx6shdfnd5ArrayINS_15PxDebugTriangleENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($206,$4)|0);
     label = 33;
     break L1;
    }
    $242 = HEAP32[$206>>2]|0;
    $243 = (($242) + (($240*48)|0)|0);
    $244 = ($243|0)==(0|0);
    if ($244) {
     $257 = $240;
    } else {
     HEAPF32[$243>>2] = $214;
     $245 = ((($242) + (($240*48)|0)|0) + 4|0);
     HEAPF32[$245>>2] = $217;
     $246 = ((($242) + (($240*48)|0)|0) + 8|0);
     HEAPF32[$246>>2] = $220;
     $247 = ((($242) + (($240*48)|0)|0) + 12|0);
     HEAP32[$247>>2] = $222;
     $248 = ((($242) + (($240*48)|0)|0) + 16|0);
     HEAPF32[$248>>2] = $224;
     $249 = ((($242) + (($240*48)|0)|0) + 20|0);
     HEAPF32[$249>>2] = $227;
     $250 = ((($242) + (($240*48)|0)|0) + 24|0);
     HEAPF32[$250>>2] = $230;
     $251 = ((($242) + (($240*48)|0)|0) + 28|0);
     HEAP32[$251>>2] = $222;
     $252 = ((($242) + (($240*48)|0)|0) + 32|0);
     HEAPF32[$252>>2] = $49;
     $253 = ((($242) + (($240*48)|0)|0) + 36|0);
     HEAPF32[$253>>2] = $50;
     $254 = ((($242) + (($240*48)|0)|0) + 40|0);
     HEAPF32[$254>>2] = $51;
     $255 = ((($242) + (($240*48)|0)|0) + 44|0);
     HEAP32[$255>>2] = $222;
     $$pre$i = HEAP32[$239>>2]|0;
     $257 = $$pre$i;
    }
    $256 = (($257) + 1)|0;
    HEAP32[$239>>2] = $256;
    label = 33;
   } else {
    label = 33;
   }
   break;
  }
  case 1:  {
   $78 = ($54|0)==(2);
   if ($78) {
    $79 = (($this) + 100|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($80) + 16|0);
    $82 = (($this) + 4|0);
    $83 = (($this) + 8|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    HEAPF32[$1>>2] = $84;
    $85 = (($1) + 4|0);
    $86 = (($this) + 12|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    HEAPF32[$85>>2] = $87;
    $88 = (($1) + 8|0);
    $89 = (($this) + 16|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    HEAPF32[$88>>2] = $90;
    $91 = (($1) + 12|0);
    $92 = HEAP32[$82>>2]|0;
    HEAP32[$91>>2] = $92;
    $93 = (($1) + 16|0);
    HEAPF32[$93>>2] = $49;
    $94 = (($1) + 20|0);
    HEAPF32[$94>>2] = $50;
    $95 = (($1) + 24|0);
    HEAPF32[$95>>2] = $51;
    $96 = (($1) + 28|0);
    HEAP32[$96>>2] = $92;
    $97 = (($80) + 24|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = $98 & 2147483647;
    $100 = (($80) + 20|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ($99>>>0)>($101>>>0);
    if ($102) {
     $103 = HEAP32[$81>>2]|0;
     $104 = (($103) + ($101<<5)|0);
     $105 = ($104|0)==(0|0);
     if ($105) {
      $114 = $101;
     } else {
      HEAPF32[$104>>2] = $84;
      $106 = ((($103) + ($101<<5)|0) + 4|0);
      HEAPF32[$106>>2] = $87;
      $107 = ((($103) + ($101<<5)|0) + 8|0);
      HEAPF32[$107>>2] = $90;
      $108 = ((($103) + ($101<<5)|0) + 12|0);
      HEAP32[$108>>2] = $92;
      $109 = ((($103) + ($101<<5)|0) + 16|0);
      HEAPF32[$109>>2] = $49;
      $110 = ((($103) + ($101<<5)|0) + 20|0);
      HEAPF32[$110>>2] = $50;
      $111 = ((($103) + ($101<<5)|0) + 24|0);
      HEAPF32[$111>>2] = $51;
      $112 = ((($103) + ($101<<5)|0) + 28|0);
      HEAP32[$112>>2] = $92;
      $$pre$i10 = HEAP32[$100>>2]|0;
      $114 = $$pre$i10;
     }
     $113 = (($114) + 1)|0;
     HEAP32[$100>>2] = $113;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($81,$1)|0);
    }
    HEAP32[$52>>2] = 0;
    $$pre$phi15Z2D = $86;$$pre$phi17Z2D = $89;$$pre$phiZ2D = $83;
   } else {
    label = 33;
   }
   break;
  }
  case 0:  {
   $56 = (($this) + 100|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 4|0);
   $59 = (($this) + 4|0);
   HEAPF32[$0>>2] = $49;
   $60 = (($0) + 4|0);
   HEAPF32[$60>>2] = $50;
   $61 = (($0) + 8|0);
   HEAPF32[$61>>2] = $51;
   $62 = (($0) + 12|0);
   $63 = HEAP32[$59>>2]|0;
   HEAP32[$62>>2] = $63;
   $64 = (($57) + 12|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = $65 & 2147483647;
   $67 = (($57) + 8|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($66>>>0)>($68>>>0);
   if (!($69)) {
    (__ZN5physx6shdfnd5ArrayINS_12PxDebugPointENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($58,$0)|0);
    label = 33;
    break L1;
   }
   $70 = HEAP32[$58>>2]|0;
   $71 = (($70) + ($68<<4)|0);
   $72 = ($71|0)==(0|0);
   if ($72) {
    $77 = $68;
   } else {
    HEAPF32[$71>>2] = $49;
    $73 = ((($70) + ($68<<4)|0) + 4|0);
    HEAPF32[$73>>2] = $50;
    $74 = ((($70) + ($68<<4)|0) + 8|0);
    HEAPF32[$74>>2] = $51;
    $75 = ((($70) + ($68<<4)|0) + 12|0);
    HEAP32[$75>>2] = $63;
    $$pre$i8 = HEAP32[$67>>2]|0;
    $77 = $$pre$i8;
   }
   $76 = (($77) + 1)|0;
   HEAP32[$67>>2] = $76;
   label = 33;
   break;
  }
  case 2:  {
   $115 = ($54>>>0)>(1);
   if ($115) {
    $116 = (($this) + 100|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = (($117) + 16|0);
    $119 = (($this) + 4|0);
    $120 = (($this) + 8|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    HEAPF32[$2>>2] = $121;
    $122 = (($2) + 4|0);
    $123 = (($this) + 12|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    HEAPF32[$122>>2] = $124;
    $125 = (($2) + 8|0);
    $126 = (($this) + 16|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    HEAPF32[$125>>2] = $127;
    $128 = (($2) + 12|0);
    $129 = HEAP32[$119>>2]|0;
    HEAP32[$128>>2] = $129;
    $130 = (($2) + 16|0);
    HEAPF32[$130>>2] = $49;
    $131 = (($2) + 20|0);
    HEAPF32[$131>>2] = $50;
    $132 = (($2) + 24|0);
    HEAPF32[$132>>2] = $51;
    $133 = (($2) + 28|0);
    HEAP32[$133>>2] = $129;
    $134 = (($117) + 24|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = $135 & 2147483647;
    $137 = (($117) + 20|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($136>>>0)>($138>>>0);
    if (!($139)) {
     (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($118,$2)|0);
     label = 33;
     break L1;
    }
    $140 = HEAP32[$118>>2]|0;
    $141 = (($140) + ($138<<5)|0);
    $142 = ($141|0)==(0|0);
    if ($142) {
     $151 = $138;
    } else {
     HEAPF32[$141>>2] = $121;
     $143 = ((($140) + ($138<<5)|0) + 4|0);
     HEAPF32[$143>>2] = $124;
     $144 = ((($140) + ($138<<5)|0) + 8|0);
     HEAPF32[$144>>2] = $127;
     $145 = ((($140) + ($138<<5)|0) + 12|0);
     HEAP32[$145>>2] = $129;
     $146 = ((($140) + ($138<<5)|0) + 16|0);
     HEAPF32[$146>>2] = $49;
     $147 = ((($140) + ($138<<5)|0) + 20|0);
     HEAPF32[$147>>2] = $50;
     $148 = ((($140) + ($138<<5)|0) + 24|0);
     HEAPF32[$148>>2] = $51;
     $149 = ((($140) + ($138<<5)|0) + 28|0);
     HEAP32[$149>>2] = $129;
     $$pre$i5 = HEAP32[$137>>2]|0;
     $151 = $$pre$i5;
    }
    $150 = (($151) + 1)|0;
    HEAP32[$137>>2] = $150;
    label = 33;
   } else {
    label = 33;
   }
   break;
  }
  default: {
   $259 = $54;
   label = 34;
  }
  }
 } while(0);
 if ((label|0) == 33) {
  $$pr = HEAP32[$52>>2]|0;
  $259 = $$pr;
  label = 34;
 }
 do {
  if ((label|0) == 34) {
   $258 = ($259>>>0)>(1);
   $260 = (($this) + 8|0);
   if (!($258)) {
    $$pre14 = (($this) + 12|0);
    $$pre16 = (($this) + 16|0);
    $$pre$phi15Z2D = $$pre14;$$pre$phi17Z2D = $$pre16;$$pre$phiZ2D = $260;
    break;
   }
   $261 = Math_fround(HEAPF32[$260>>2]);
   $262 = (($this) + 20|0);
   HEAPF32[$262>>2] = $261;
   $263 = (($this) + 12|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = (($this) + 24|0);
   HEAPF32[$265>>2] = $264;
   $266 = (($this) + 16|0);
   $267 = Math_fround(HEAPF32[$266>>2]);
   $268 = (($this) + 28|0);
   HEAPF32[$268>>2] = $267;
   $269 = Math_fround(HEAPF32[$vertex>>2]);
   HEAPF32[$260>>2] = $269;
   $270 = Math_fround(HEAPF32[$6>>2]);
   HEAPF32[$263>>2] = $270;
   $271 = Math_fround(HEAPF32[$8>>2]);
   HEAPF32[$266>>2] = $271;
   STACKTOP = sp;return ($this|0);
  }
 } while(0);
 $272 = Math_fround(HEAPF32[$vertex>>2]);
 HEAPF32[$$pre$phiZ2D>>2] = $272;
 $273 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$$pre$phi15Z2D>>2] = $273;
 $274 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$$pre$phi17Z2D>>2] = $274;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($out,$box) {
 $out = $out|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0;
 var $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0;
 var $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $0 = sp + 348|0;
 $1 = sp + 336|0;
 $2 = sp + 324|0;
 $3 = sp + 312|0;
 $4 = sp + 300|0;
 $5 = sp + 288|0;
 $6 = sp + 276|0;
 $7 = sp + 264|0;
 $8 = sp + 252|0;
 $9 = sp + 240|0;
 $10 = sp + 228|0;
 $11 = sp + 216|0;
 $12 = sp + 204|0;
 $13 = sp + 192|0;
 $14 = sp + 180|0;
 $15 = sp + 168|0;
 $16 = sp + 60|0;
 $17 = sp;
 $18 = sp + 12|0;
 $19 = sp + 24|0;
 $20 = sp + 36|0;
 $21 = sp + 48|0;
 $22 = sp + 72|0;
 $23 = sp + 84|0;
 $24 = sp + 96|0;
 $25 = sp + 108|0;
 $26 = sp + 120|0;
 $27 = sp + 132|0;
 $28 = sp + 144|0;
 $29 = sp + 156|0;
 $30 = (($box) + 24|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  HEAP32[$out>>2] = 4;
  $119 = (($out) + 32|0);
  HEAP32[$119>>2] = 0;
  $120 = Math_fround(HEAPF32[$box>>2]);
  $121 = (($box) + 4|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = (($box) + 8|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$16>>2] = $120;
  $125 = (($16) + 4|0);
  HEAPF32[$125>>2] = $122;
  $126 = (($16) + 8|0);
  HEAPF32[$126>>2] = $124;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$16)|0);
  $127 = Math_fround(HEAPF32[$box>>2]);
  $128 = (($box) + 16|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$17>>2] = $127;
  $131 = (($17) + 4|0);
  HEAPF32[$131>>2] = $129;
  $132 = (($17) + 8|0);
  HEAPF32[$132>>2] = $130;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$17)|0);
  $133 = (($box) + 12|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround(HEAPF32[$121>>2]);
  $136 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$18>>2] = $134;
  $137 = (($18) + 4|0);
  HEAPF32[$137>>2] = $135;
  $138 = (($18) + 8|0);
  HEAPF32[$138>>2] = $136;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$18)|0);
  $139 = Math_fround(HEAPF32[$133>>2]);
  $140 = Math_fround(HEAPF32[$128>>2]);
  $141 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$19>>2] = $139;
  $142 = (($19) + 4|0);
  HEAPF32[$142>>2] = $140;
  $143 = (($19) + 8|0);
  HEAPF32[$143>>2] = $141;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$19)|0);
  $144 = Math_fround(HEAPF32[$133>>2]);
  $145 = Math_fround(HEAPF32[$128>>2]);
  $146 = (($box) + 20|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  HEAPF32[$20>>2] = $144;
  $148 = (($20) + 4|0);
  HEAPF32[$148>>2] = $145;
  $149 = (($20) + 8|0);
  HEAPF32[$149>>2] = $147;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$20)|0);
  $150 = Math_fround(HEAPF32[$box>>2]);
  $151 = Math_fround(HEAPF32[$128>>2]);
  $152 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$21>>2] = $150;
  $153 = (($21) + 4|0);
  HEAPF32[$153>>2] = $151;
  $154 = (($21) + 8|0);
  HEAPF32[$154>>2] = $152;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$21)|0);
  $155 = Math_fround(HEAPF32[$box>>2]);
  $156 = Math_fround(HEAPF32[$128>>2]);
  $157 = Math_fround(HEAPF32[$146>>2]);
  HEAPF32[$22>>2] = $155;
  $158 = (($22) + 4|0);
  HEAPF32[$158>>2] = $156;
  $159 = (($22) + 8|0);
  HEAPF32[$159>>2] = $157;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$22)|0);
  $160 = Math_fround(HEAPF32[$box>>2]);
  $161 = Math_fround(HEAPF32[$121>>2]);
  $162 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$23>>2] = $160;
  $163 = (($23) + 4|0);
  HEAPF32[$163>>2] = $161;
  $164 = (($23) + 8|0);
  HEAPF32[$164>>2] = $162;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$23)|0);
  $165 = Math_fround(HEAPF32[$box>>2]);
  $166 = Math_fround(HEAPF32[$121>>2]);
  $167 = Math_fround(HEAPF32[$146>>2]);
  HEAPF32[$24>>2] = $165;
  $168 = (($24) + 4|0);
  HEAPF32[$168>>2] = $166;
  $169 = (($24) + 8|0);
  HEAPF32[$169>>2] = $167;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$24)|0);
  $170 = Math_fround(HEAPF32[$133>>2]);
  $171 = Math_fround(HEAPF32[$121>>2]);
  $172 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$25>>2] = $170;
  $173 = (($25) + 4|0);
  HEAPF32[$173>>2] = $171;
  $174 = (($25) + 8|0);
  HEAPF32[$174>>2] = $172;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$25)|0);
  $175 = Math_fround(HEAPF32[$133>>2]);
  $176 = Math_fround(HEAPF32[$121>>2]);
  $177 = Math_fround(HEAPF32[$146>>2]);
  HEAPF32[$26>>2] = $175;
  $178 = (($26) + 4|0);
  HEAPF32[$178>>2] = $176;
  $179 = (($26) + 8|0);
  HEAPF32[$179>>2] = $177;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$26)|0);
  $180 = Math_fround(HEAPF32[$133>>2]);
  $181 = Math_fround(HEAPF32[$128>>2]);
  $182 = Math_fround(HEAPF32[$146>>2]);
  HEAPF32[$27>>2] = $180;
  $183 = (($27) + 4|0);
  HEAPF32[$183>>2] = $181;
  $184 = (($27) + 8|0);
  HEAPF32[$184>>2] = $182;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$27)|0);
  $185 = Math_fround(HEAPF32[$box>>2]);
  $186 = Math_fround(HEAPF32[$121>>2]);
  $187 = Math_fround(HEAPF32[$146>>2]);
  HEAPF32[$28>>2] = $185;
  $188 = (($28) + 4|0);
  HEAPF32[$188>>2] = $186;
  $189 = (($28) + 8|0);
  HEAPF32[$189>>2] = $187;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$28)|0);
  $190 = Math_fround(HEAPF32[$box>>2]);
  $191 = Math_fround(HEAPF32[$128>>2]);
  $192 = Math_fround(HEAPF32[$146>>2]);
  HEAPF32[$29>>2] = $190;
  $193 = (($29) + 4|0);
  HEAPF32[$193>>2] = $191;
  $194 = (($29) + 8|0);
  HEAPF32[$194>>2] = $192;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$29)|0);
  STACKTOP = sp;return ($out|0);
 } else {
  HEAP32[$out>>2] = 2;
  $33 = (($out) + 32|0);
  HEAP32[$33>>2] = 0;
  $34 = Math_fround(HEAPF32[$box>>2]);
  $35 = (($box) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($box) + 8|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$0>>2] = $34;
  $39 = (($0) + 4|0);
  HEAPF32[$39>>2] = $36;
  $40 = (($0) + 8|0);
  HEAPF32[$40>>2] = $38;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$0)|0);
  $41 = (($box) + 12|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(HEAPF32[$35>>2]);
  $44 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$1>>2] = $42;
  $45 = (($1) + 4|0);
  HEAPF32[$45>>2] = $43;
  $46 = (($1) + 8|0);
  HEAPF32[$46>>2] = $44;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$1)|0);
  $47 = Math_fround(HEAPF32[$41>>2]);
  $48 = (($box) + 16|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$2>>2] = $47;
  $51 = (($2) + 4|0);
  HEAPF32[$51>>2] = $49;
  $52 = (($2) + 8|0);
  HEAPF32[$52>>2] = $50;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$2)|0);
  $53 = Math_fround(HEAPF32[$box>>2]);
  $54 = Math_fround(HEAPF32[$48>>2]);
  $55 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$3>>2] = $53;
  $56 = (($3) + 4|0);
  HEAPF32[$56>>2] = $54;
  $57 = (($3) + 8|0);
  HEAPF32[$57>>2] = $55;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$3)|0);
  $58 = Math_fround(HEAPF32[$box>>2]);
  $59 = Math_fround(HEAPF32[$35>>2]);
  $60 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$4>>2] = $58;
  $61 = (($4) + 4|0);
  HEAPF32[$61>>2] = $59;
  $62 = (($4) + 8|0);
  HEAPF32[$62>>2] = $60;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$4)|0);
  $63 = Math_fround(HEAPF32[$box>>2]);
  $64 = Math_fround(HEAPF32[$35>>2]);
  $65 = (($box) + 20|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$5>>2] = $63;
  $67 = (($5) + 4|0);
  HEAPF32[$67>>2] = $64;
  $68 = (($5) + 8|0);
  HEAPF32[$68>>2] = $66;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$5)|0);
  $69 = Math_fround(HEAPF32[$41>>2]);
  $70 = Math_fround(HEAPF32[$35>>2]);
  $71 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$6>>2] = $69;
  $72 = (($6) + 4|0);
  HEAPF32[$72>>2] = $70;
  $73 = (($6) + 8|0);
  HEAPF32[$73>>2] = $71;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$6)|0);
  $74 = Math_fround(HEAPF32[$41>>2]);
  $75 = Math_fround(HEAPF32[$48>>2]);
  $76 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$7>>2] = $74;
  $77 = (($7) + 4|0);
  HEAPF32[$77>>2] = $75;
  $78 = (($7) + 8|0);
  HEAPF32[$78>>2] = $76;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$7)|0);
  $79 = Math_fround(HEAPF32[$box>>2]);
  $80 = Math_fround(HEAPF32[$48>>2]);
  $81 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$8>>2] = $79;
  $82 = (($8) + 4|0);
  HEAPF32[$82>>2] = $80;
  $83 = (($8) + 8|0);
  HEAPF32[$83>>2] = $81;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$8)|0);
  $84 = Math_fround(HEAPF32[$box>>2]);
  $85 = Math_fround(HEAPF32[$35>>2]);
  $86 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$9>>2] = $84;
  $87 = (($9) + 4|0);
  HEAPF32[$87>>2] = $85;
  $88 = (($9) + 8|0);
  HEAPF32[$88>>2] = $86;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$9)|0);
  HEAP32[$out>>2] = 1;
  HEAP32[$33>>2] = 0;
  $89 = Math_fround(HEAPF32[$41>>2]);
  $90 = Math_fround(HEAPF32[$35>>2]);
  $91 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$10>>2] = $89;
  $92 = (($10) + 4|0);
  HEAPF32[$92>>2] = $90;
  $93 = (($10) + 8|0);
  HEAPF32[$93>>2] = $91;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$10)|0);
  $94 = Math_fround(HEAPF32[$41>>2]);
  $95 = Math_fround(HEAPF32[$35>>2]);
  $96 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$11>>2] = $94;
  $97 = (($11) + 4|0);
  HEAPF32[$97>>2] = $95;
  $98 = (($11) + 8|0);
  HEAPF32[$98>>2] = $96;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$11)|0);
  $99 = Math_fround(HEAPF32[$41>>2]);
  $100 = Math_fround(HEAPF32[$48>>2]);
  $101 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$12>>2] = $99;
  $102 = (($12) + 4|0);
  HEAPF32[$102>>2] = $100;
  $103 = (($12) + 8|0);
  HEAPF32[$103>>2] = $101;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$12)|0);
  $104 = Math_fround(HEAPF32[$41>>2]);
  $105 = Math_fround(HEAPF32[$48>>2]);
  $106 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$13>>2] = $104;
  $107 = (($13) + 4|0);
  HEAPF32[$107>>2] = $105;
  $108 = (($13) + 8|0);
  HEAPF32[$108>>2] = $106;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$13)|0);
  $109 = Math_fround(HEAPF32[$box>>2]);
  $110 = Math_fround(HEAPF32[$48>>2]);
  $111 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$14>>2] = $109;
  $112 = (($14) + 4|0);
  HEAPF32[$112>>2] = $110;
  $113 = (($14) + 8|0);
  HEAPF32[$113>>2] = $111;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$14)|0);
  $114 = Math_fround(HEAPF32[$box>>2]);
  $115 = Math_fround(HEAPF32[$48>>2]);
  $116 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$15>>2] = $114;
  $117 = (($15) + 4|0);
  HEAPF32[$117>>2] = $115;
  $118 = (($15) + 8|0);
  HEAPF32[$118>>2] = $116;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$15)|0);
  STACKTOP = sp;return ($out|0);
 }
 return 0|0;
}
function __ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($out,$arrow) {
 $out = $out|0;
 $arrow = $arrow|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 84|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 $6 = sp + 60|0;
 $7 = sp + 72|0;
 $8 = (($arrow) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$arrow>>2]);
 $11 = Math_fround($9 - $10);
 $12 = (($arrow) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($arrow) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = (($arrow) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($arrow) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 - $20);
 $22 = Math_fround($11 * $11);
 $23 = Math_fround($16 * $16);
 $24 = Math_fround($22 + $23);
 $25 = Math_fround($21 * $21);
 $26 = Math_fround($24 + $25);
 $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
 $28 = $27 > Math_fround(0.0);
 if ($28) {
  $29 = Math_fround(Math_fround(1.0) / $27);
  $30 = Math_fround($11 * $29);
  $31 = Math_fround($16 * $29);
  $32 = Math_fround($21 * $29);
  $33 = $30;$36 = $32;$38 = $31;
 } else {
  $33 = $11;$36 = $21;$38 = $16;
 }
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($33)))));
 $34 = $fabsf$i$i$i < Math_fround(0.707106769084930419921);
 if ($34) {
  $35 = Math_fround(-$36);
  $40 = Math_fround(0.0);$42 = $35;$45 = $38;
 } else {
  $37 = Math_fround(-$38);
  $40 = $37;$42 = $33;$45 = Math_fround(0.0);
 }
 $39 = Math_fround($40 * $40);
 $41 = Math_fround($42 * $42);
 $43 = Math_fround($41 + $39);
 $44 = Math_fround($45 * $45);
 $46 = Math_fround($44 + $43);
 $47 = (Math_fround(Math_sqrt((Math_fround($46)))));
 $48 = $47 > Math_fround(0.0);
 if ($48) {
  $49 = Math_fround(Math_fround(1.0) / $47);
  $50 = Math_fround($40 * $49);
  $51 = Math_fround($42 * $49);
  $52 = Math_fround($45 * $49);
  $54 = $52;$56 = $51;$59 = $50;
 } else {
  $54 = $45;$56 = $42;$59 = $40;
 }
 $53 = Math_fround($38 * $54);
 $55 = Math_fround($36 * $56);
 $57 = Math_fround($53 - $55);
 $58 = Math_fround($36 * $59);
 $60 = Math_fround($33 * $54);
 $61 = Math_fround($58 - $60);
 $62 = Math_fround($33 * $56);
 $63 = Math_fround($38 * $59);
 $64 = Math_fround($62 - $63);
 $65 = (($arrow) + 24|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * Math_fround(0.25));
 $68 = Math_fround($59 * $67);
 $69 = Math_fround($56 * $67);
 $70 = Math_fround($54 * $67);
 $71 = Math_fround($67 * Math_fround(1.73205077648162841797));
 $72 = Math_fround($57 * $71);
 $73 = Math_fround($61 * $71);
 $74 = Math_fround($64 * $71);
 $75 = Math_fround($33 * $66);
 $76 = Math_fround($38 * $66);
 $77 = Math_fround($36 * $66);
 $78 = Math_fround($9 - $75);
 $79 = Math_fround($13 - $76);
 $80 = Math_fround($18 - $77);
 HEAP32[$out>>2] = 1;
 $81 = (($out) + 32|0);
 HEAP32[$81>>2] = 0;
 HEAPF32[$0>>2] = $10;
 $82 = (($0) + 4|0);
 HEAPF32[$82>>2] = $15;
 $83 = (($0) + 8|0);
 HEAPF32[$83>>2] = $20;
 $84 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$0)|0);
 $85 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$1>>2] = $85;
 $86 = (($1) + 4|0);
 $87 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$86>>2] = $87;
 $88 = (($1) + 8|0);
 $89 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$88>>2] = $89;
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($84,$1)|0);
 HEAP32[$out>>2] = 4;
 HEAP32[$81>>2] = 0;
 $90 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$2>>2] = $90;
 $91 = (($2) + 4|0);
 $92 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$91>>2] = $92;
 $93 = (($2) + 8|0);
 $94 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$93>>2] = $94;
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$2)|0);
 $95 = Math_fround($78 + $68);
 $96 = Math_fround($69 + $79);
 $97 = Math_fround($70 + $80);
 $98 = Math_fround($68 + $95);
 $99 = Math_fround($69 + $96);
 $100 = Math_fround($70 + $97);
 HEAPF32[$3>>2] = $98;
 $101 = (($3) + 4|0);
 HEAPF32[$101>>2] = $99;
 $102 = (($3) + 8|0);
 HEAPF32[$102>>2] = $100;
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$3)|0);
 $103 = Math_fround($78 - $68);
 $104 = Math_fround($79 - $69);
 $105 = Math_fround($80 - $70);
 $106 = Math_fround($103 - $72);
 $107 = Math_fround($104 - $73);
 $108 = Math_fround($105 - $74);
 HEAPF32[$4>>2] = $106;
 $109 = (($4) + 4|0);
 HEAPF32[$109>>2] = $107;
 $110 = (($4) + 8|0);
 HEAPF32[$110>>2] = $108;
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$4)|0);
 $111 = Math_fround($103 + $72);
 $112 = Math_fround($73 + $104);
 $113 = Math_fround($74 + $105);
 HEAPF32[$5>>2] = $111;
 $114 = (($5) + 4|0);
 HEAPF32[$114>>2] = $112;
 $115 = (($5) + 8|0);
 HEAPF32[$115>>2] = $113;
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$5)|0);
 $116 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$6>>2] = $116;
 $117 = (($6) + 4|0);
 $118 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$117>>2] = $118;
 $119 = (($6) + 8|0);
 $120 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$119>>2] = $120;
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$6)|0);
 HEAPF32[$7>>2] = $98;
 $121 = (($7) + 4|0);
 HEAPF32[$121>>2] = $99;
 $122 = (($7) + 8|0);
 HEAPF32[$122>>2] = $100;
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$7)|0);
 STACKTOP = sp;return ($out|0);
}
function __ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($out,$basis) {
 $out = $out|0;
 $basis = $basis|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 56|0;
 $1 = sp;
 $2 = sp + 28|0;
 $3 = Math_fround(HEAPF32[$basis>>2]);
 $4 = Math_fround($3 * $3);
 $5 = (($basis) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $6);
 $8 = Math_fround($4 + $7);
 $9 = (($basis) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $10);
 $12 = Math_fround($8 + $11);
 $13 = (Math_fround(Math_sqrt((Math_fround($12)))));
 $14 = Math_fround($13 * Math_fround(0.150000005960464477539));
 $15 = (($basis) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($out) + 4|0);
 HEAP32[$17>>2] = $16;
 HEAPF32[$0>>2] = Math_fround(0.0);
 $18 = (($0) + 4|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($0) + 8|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = Math_fround($3 + Math_fround(0.0));
 $21 = (($0) + 12|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($0) + 16|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($0) + 20|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($0) + 24|0);
 HEAPF32[$24>>2] = $14;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($out,$0)|0);
 $25 = (($basis) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$17>>2] = $26;
 $27 = Math_fround(HEAPF32[$5>>2]);
 $28 = Math_fround($27 + Math_fround(0.0));
 $29 = (($1) + 16|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAPF32[$29>>2] = $28;
 $30 = (($1) + 20|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($1) + 24|0);
 HEAPF32[$31>>2] = $14;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($out,$1)|0);
 $32 = (($basis) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$17>>2] = $33;
 $34 = Math_fround(HEAPF32[$9>>2]);
 $35 = Math_fround($34 + Math_fround(0.0));
 $36 = (($2) + 20|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 HEAPF32[$36>>2] = $35;
 $37 = (($2) + 24|0);
 HEAPF32[$37>>2] = $14;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($out,$2)|0);
 STACKTOP = sp;return ($out|0);
}
function __ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($out,$circle) {
 $out = $out|0;
 $circle = $circle|0;
 var $$lcssa = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $3 = Math_fround(0), $4 = Math_fround(0);
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $angle$01 = Math_fround(0), $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP32[$circle>>2]|0;
 $3 = (Math_fround(($2>>>0)));
 $4 = Math_fround(Math_fround(6.28318548202514648438) / $3);
 HEAP32[$out>>2] = 2;
 $5 = (($out) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = HEAP32[$circle>>2]|0;
 $7 = ($6|0)==(0);
 $8 = (($circle) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 if ($7) {
  $$lcssa = $9;
 } else {
  $10 = (($0) + 4|0);
  $11 = (($0) + 8|0);
  $14 = $9;$angle$01 = Math_fround(0.0);$i$02 = 0;
  while(1) {
   $12 = (Math_fround(+(Math_sin((+$angle$01)))));
   $13 = Math_fround($14 * $12);
   $15 = (Math_fround(+(Math_cos((+$angle$01)))));
   $16 = Math_fround($14 * $15);
   HEAPF32[$0>>2] = $13;
   HEAPF32[$10>>2] = $16;
   HEAPF32[$11>>2] = Math_fround(0.0);
   (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$0)|0);
   $17 = (($i$02) + 1)|0;
   $18 = Math_fround($4 + $angle$01);
   $19 = HEAP32[$circle>>2]|0;
   $20 = ($17>>>0)<($19>>>0);
   $21 = Math_fround(HEAPF32[$8>>2]);
   if ($20) {
    $14 = $21;$angle$01 = $18;$i$02 = $17;
   } else {
    $$lcssa = $21;
    break;
   }
  }
 }
 HEAPF32[$1>>2] = Math_fround(0.0);
 $22 = (($1) + 4|0);
 HEAPF32[$22>>2] = $$lcssa;
 $23 = (($1) + 8|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$1)|0);
 STACKTOP = sp;return ($out|0);
}
function __ZN5physx2Cm12RenderOutput13outputCapsuleEffRKNS0_8Matrix34E($this,$radius,$halfHeight,$absPose) {
 $this = $this|0;
 $radius = Math_fround($radius);
 $halfHeight = Math_fround($halfHeight);
 $absPose = $absPose|0;
 var $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i3 = 0, $$pre$i$i5 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0;
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0);
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0);
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $angle$01$i = Math_fround(0), $angle$01$i13 = Math_fround(0), $angle$01$i20 = Math_fround(0), $angle$01$i27 = Math_fround(0), $angle$01$i33 = Math_fround(0), $angle$01$i9 = Math_fround(0), $exitcond = 0;
 var $exitcond132 = 0, $exitcond133 = 0, $exitcond134 = 0, $exitcond135 = 0, $exitcond136 = 0, $i$02$i = 0, $i$02$i12 = 0, $i$02$i19 = 0, $i$02$i26 = 0, $i$02$i32 = 0, $i$02$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = Math_fround(HEAPF32[$absPose>>2]);
 $3 = (($absPose) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($absPose) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($absPose) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($absPose) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($absPose) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($absPose) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($absPose) + 28|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($absPose) + 32|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($absPose) + 36|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($absPose) + 40|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($absPose) + 44|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(-$halfHeight);
 $26 = Math_fround($2 * $25);
 $27 = Math_fround($4 * $25);
 $28 = Math_fround($6 * $25);
 $29 = Math_fround($8 * Math_fround(0.0));
 $30 = Math_fround($10 * Math_fround(0.0));
 $31 = Math_fround($12 * Math_fround(0.0));
 $32 = Math_fround($26 + $29);
 $33 = Math_fround($27 + $30);
 $34 = Math_fround($28 + $31);
 $35 = Math_fround($14 * Math_fround(0.0));
 $36 = Math_fround($16 * Math_fround(0.0));
 $37 = Math_fround($18 * Math_fround(0.0));
 $38 = Math_fround($32 + $35);
 $39 = Math_fround($33 + $36);
 $40 = Math_fround($34 + $37);
 $41 = Math_fround($38 + $20);
 $42 = Math_fround($39 + $22);
 $43 = Math_fround($40 + $24);
 $44 = (($this) + 36|0);
 HEAPF32[$44>>2] = $2;
 $45 = (($this) + 40|0);
 HEAPF32[$45>>2] = $4;
 $46 = (($this) + 44|0);
 HEAPF32[$46>>2] = $6;
 $47 = (($this) + 48|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($this) + 52|0);
 HEAPF32[$48>>2] = $8;
 $49 = (($this) + 56|0);
 HEAPF32[$49>>2] = $10;
 $50 = (($this) + 60|0);
 HEAPF32[$50>>2] = $12;
 $51 = (($this) + 64|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($this) + 68|0);
 HEAPF32[$52>>2] = $14;
 $53 = (($this) + 72|0);
 HEAPF32[$53>>2] = $16;
 $54 = (($this) + 76|0);
 HEAPF32[$54>>2] = $18;
 $55 = (($this) + 80|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($this) + 84|0);
 HEAPF32[$56>>2] = $41;
 $57 = (($this) + 88|0);
 HEAPF32[$57>>2] = $42;
 $58 = (($this) + 92|0);
 HEAPF32[$58>>2] = $43;
 $59 = (($this) + 96|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 HEAP32[$this>>2] = 2;
 $60 = (($this) + 32|0);
 HEAP32[$60>>2] = 0;
 $61 = (($0) + 4|0);
 $62 = (($0) + 8|0);
 $angle$01$i9 = Math_fround(3.14159274101257324219);$i$02$i8 = 0;
 while(1) {
  $63 = (Math_fround(+(Math_sin((+$angle$01$i9)))));
  $64 = Math_fround($63 * $radius);
  $65 = (Math_fround(+(Math_cos((+$angle$01$i9)))));
  $66 = Math_fround($65 * $radius);
  HEAPF32[$0>>2] = $64;
  HEAPF32[$61>>2] = $66;
  HEAPF32[$62>>2] = Math_fround(0.0);
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$0)|0);
  $67 = (($i$02$i8) + 1)|0;
  $68 = Math_fround($angle$01$i9 + Math_fround(0.0314159281551837921143));
  $exitcond136 = ($67|0)==(100);
  if ($exitcond136) {
   break;
  } else {
   $angle$01$i9 = $68;$i$02$i8 = $67;
  }
 }
 $69 = Math_fround($radius * Math_fround(1.74845553146951715462E-7));
 HEAPF32[$1>>2] = $69;
 $70 = (($1) + 4|0);
 HEAPF32[$70>>2] = $radius;
 $71 = (($1) + 8|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$1)|0);
 $72 = Math_fround(-$14);
 $73 = Math_fround(-$16);
 $74 = Math_fround(-$18);
 HEAPF32[$44>>2] = $2;
 HEAPF32[$45>>2] = $4;
 HEAPF32[$46>>2] = $6;
 HEAPF32[$47>>2] = Math_fround(0.0);
 HEAPF32[$48>>2] = $72;
 HEAPF32[$49>>2] = $73;
 HEAPF32[$50>>2] = $74;
 HEAPF32[$51>>2] = Math_fround(-0.0);
 HEAPF32[$52>>2] = $8;
 HEAPF32[$53>>2] = $10;
 HEAPF32[$54>>2] = $12;
 HEAPF32[$55>>2] = Math_fround(0.0);
 HEAPF32[$56>>2] = $41;
 HEAPF32[$57>>2] = $42;
 HEAPF32[$58>>2] = $43;
 HEAPF32[$59>>2] = Math_fround(0.0);
 HEAP32[$this>>2] = 2;
 HEAP32[$60>>2] = 0;
 $75 = (($0) + 4|0);
 $76 = (($0) + 8|0);
 $angle$01$i20 = Math_fround(3.14159274101257324219);$i$02$i19 = 0;
 while(1) {
  $77 = (Math_fround(+(Math_sin((+$angle$01$i20)))));
  $78 = Math_fround($77 * $radius);
  $79 = (Math_fround(+(Math_cos((+$angle$01$i20)))));
  $80 = Math_fround($79 * $radius);
  HEAPF32[$0>>2] = $78;
  HEAPF32[$75>>2] = $80;
  HEAPF32[$76>>2] = Math_fround(0.0);
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$0)|0);
  $81 = (($i$02$i19) + 1)|0;
  $82 = Math_fround($angle$01$i20 + Math_fround(0.0314159281551837921143));
  $exitcond135 = ($81|0)==(100);
  if ($exitcond135) {
   break;
  } else {
   $angle$01$i20 = $82;$i$02$i19 = $81;
  }
 }
 HEAPF32[$1>>2] = $69;
 $83 = (($1) + 4|0);
 HEAPF32[$83>>2] = $radius;
 $84 = (($1) + 8|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$1)|0);
 $85 = Math_fround(-$8);
 $86 = Math_fround(-$10);
 $87 = Math_fround(-$12);
 HEAPF32[$44>>2] = $85;
 HEAPF32[$45>>2] = $86;
 HEAPF32[$46>>2] = $87;
 HEAPF32[$47>>2] = Math_fround(-0.0);
 HEAPF32[$48>>2] = $72;
 HEAPF32[$49>>2] = $73;
 HEAPF32[$50>>2] = $74;
 HEAPF32[$51>>2] = Math_fround(-0.0);
 HEAPF32[$52>>2] = $2;
 HEAPF32[$53>>2] = $4;
 HEAPF32[$54>>2] = $6;
 HEAPF32[$55>>2] = Math_fround(0.0);
 HEAPF32[$56>>2] = $41;
 HEAPF32[$57>>2] = $42;
 HEAPF32[$58>>2] = $43;
 HEAPF32[$59>>2] = Math_fround(0.0);
 HEAP32[$this>>2] = 2;
 HEAP32[$60>>2] = 0;
 $88 = (($0) + 4|0);
 $89 = (($0) + 8|0);
 $angle$01$i27 = Math_fround(0.0);$i$02$i26 = 0;
 while(1) {
  $90 = (Math_fround(+(Math_sin((+$angle$01$i27)))));
  $91 = Math_fround($90 * $radius);
  $92 = (Math_fround(+(Math_cos((+$angle$01$i27)))));
  $93 = Math_fround($92 * $radius);
  HEAPF32[$0>>2] = $91;
  HEAPF32[$88>>2] = $93;
  HEAPF32[$89>>2] = Math_fround(0.0);
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$0)|0);
  $94 = (($i$02$i26) + 1)|0;
  $95 = Math_fround($angle$01$i27 + Math_fround(0.0628318563103675842285));
  $exitcond134 = ($94|0)==(100);
  if ($exitcond134) {
   break;
  } else {
   $angle$01$i27 = $95;$i$02$i26 = $94;
  }
 }
 HEAPF32[$1>>2] = Math_fround(0.0);
 $96 = (($1) + 4|0);
 HEAPF32[$96>>2] = $radius;
 $97 = (($1) + 8|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$1)|0);
 $98 = Math_fround($2 * $halfHeight);
 $99 = Math_fround($4 * $halfHeight);
 $100 = Math_fround($6 * $halfHeight);
 $101 = Math_fround($98 + $29);
 $102 = Math_fround($99 + $30);
 $103 = Math_fround($100 + $31);
 $104 = Math_fround($101 + $35);
 $105 = Math_fround($102 + $36);
 $106 = Math_fround($103 + $37);
 $107 = Math_fround($104 + $20);
 $108 = Math_fround($105 + $22);
 $109 = Math_fround($106 + $24);
 HEAPF32[$44>>2] = $2;
 HEAPF32[$45>>2] = $4;
 HEAPF32[$46>>2] = $6;
 HEAPF32[$47>>2] = Math_fround(0.0);
 HEAPF32[$48>>2] = $8;
 HEAPF32[$49>>2] = $10;
 HEAPF32[$50>>2] = $12;
 HEAPF32[$51>>2] = Math_fround(0.0);
 HEAPF32[$52>>2] = $14;
 HEAPF32[$53>>2] = $16;
 HEAPF32[$54>>2] = $18;
 HEAPF32[$55>>2] = Math_fround(0.0);
 HEAPF32[$56>>2] = $107;
 HEAPF32[$57>>2] = $108;
 HEAPF32[$58>>2] = $109;
 HEAPF32[$59>>2] = Math_fround(0.0);
 HEAP32[$this>>2] = 2;
 HEAP32[$60>>2] = 0;
 $110 = (($0) + 4|0);
 $111 = (($0) + 8|0);
 $angle$01$i33 = Math_fround(0.0);$i$02$i32 = 0;
 while(1) {
  $112 = (Math_fround(+(Math_sin((+$angle$01$i33)))));
  $113 = Math_fround($112 * $radius);
  $114 = (Math_fround(+(Math_cos((+$angle$01$i33)))));
  $115 = Math_fround($114 * $radius);
  HEAPF32[$0>>2] = $113;
  HEAPF32[$110>>2] = $115;
  HEAPF32[$111>>2] = Math_fround(0.0);
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$0)|0);
  $116 = (($i$02$i32) + 1)|0;
  $117 = Math_fround($angle$01$i33 + Math_fround(0.0314159281551837921143));
  $exitcond133 = ($116|0)==(100);
  if ($exitcond133) {
   break;
  } else {
   $angle$01$i33 = $117;$i$02$i32 = $116;
  }
 }
 $118 = Math_fround($radius * Math_fround(-8.74227765734758577309E-8));
 $119 = Math_fround($radius * Math_fround(-1.0));
 HEAPF32[$1>>2] = $118;
 $120 = (($1) + 4|0);
 HEAPF32[$120>>2] = $119;
 $121 = (($1) + 8|0);
 HEAPF32[$121>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$1)|0);
 HEAPF32[$44>>2] = $2;
 HEAPF32[$45>>2] = $4;
 HEAPF32[$46>>2] = $6;
 HEAPF32[$47>>2] = Math_fround(0.0);
 HEAPF32[$48>>2] = $72;
 HEAPF32[$49>>2] = $73;
 HEAPF32[$50>>2] = $74;
 HEAPF32[$51>>2] = Math_fround(-0.0);
 HEAPF32[$52>>2] = $8;
 HEAPF32[$53>>2] = $10;
 HEAPF32[$54>>2] = $12;
 HEAPF32[$55>>2] = Math_fround(0.0);
 HEAPF32[$56>>2] = $107;
 HEAPF32[$57>>2] = $108;
 HEAPF32[$58>>2] = $109;
 HEAPF32[$59>>2] = Math_fround(0.0);
 HEAP32[$this>>2] = 2;
 HEAP32[$60>>2] = 0;
 $122 = (($0) + 4|0);
 $123 = (($0) + 8|0);
 $angle$01$i13 = Math_fround(0.0);$i$02$i12 = 0;
 while(1) {
  $124 = (Math_fround(+(Math_sin((+$angle$01$i13)))));
  $125 = Math_fround($124 * $radius);
  $126 = (Math_fround(+(Math_cos((+$angle$01$i13)))));
  $127 = Math_fround($126 * $radius);
  HEAPF32[$0>>2] = $125;
  HEAPF32[$122>>2] = $127;
  HEAPF32[$123>>2] = Math_fround(0.0);
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$0)|0);
  $128 = (($i$02$i12) + 1)|0;
  $129 = Math_fround($angle$01$i13 + Math_fround(0.0314159281551837921143));
  $exitcond132 = ($128|0)==(100);
  if ($exitcond132) {
   break;
  } else {
   $angle$01$i13 = $129;$i$02$i12 = $128;
  }
 }
 HEAPF32[$1>>2] = $118;
 $130 = (($1) + 4|0);
 HEAPF32[$130>>2] = $119;
 $131 = (($1) + 8|0);
 HEAPF32[$131>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$1)|0);
 HEAPF32[$44>>2] = $85;
 HEAPF32[$45>>2] = $86;
 HEAPF32[$46>>2] = $87;
 HEAPF32[$47>>2] = Math_fround(-0.0);
 HEAPF32[$48>>2] = $72;
 HEAPF32[$49>>2] = $73;
 HEAPF32[$50>>2] = $74;
 HEAPF32[$51>>2] = Math_fround(-0.0);
 HEAPF32[$52>>2] = $2;
 HEAPF32[$53>>2] = $4;
 HEAPF32[$54>>2] = $6;
 HEAPF32[$55>>2] = Math_fround(0.0);
 HEAPF32[$56>>2] = $107;
 HEAPF32[$57>>2] = $108;
 HEAPF32[$58>>2] = $109;
 HEAPF32[$59>>2] = Math_fround(0.0);
 HEAP32[$this>>2] = 2;
 HEAP32[$60>>2] = 0;
 $132 = (($0) + 4|0);
 $133 = (($0) + 8|0);
 $angle$01$i = Math_fround(0.0);$i$02$i = 0;
 while(1) {
  $134 = (Math_fround(+(Math_sin((+$angle$01$i)))));
  $135 = Math_fround($134 * $radius);
  $136 = (Math_fround(+(Math_cos((+$angle$01$i)))));
  $137 = Math_fround($136 * $radius);
  HEAPF32[$0>>2] = $135;
  HEAPF32[$132>>2] = $137;
  HEAPF32[$133>>2] = Math_fround(0.0);
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$0)|0);
  $138 = (($i$02$i) + 1)|0;
  $139 = Math_fround($angle$01$i + Math_fround(0.0628318563103675842285));
  $exitcond = ($138|0)==(100);
  if ($exitcond) {
   break;
  } else {
   $angle$01$i = $139;$i$02$i = $138;
  }
 }
 HEAPF32[$1>>2] = Math_fround(0.0);
 $140 = (($1) + 4|0);
 HEAPF32[$140>>2] = $radius;
 $141 = (($1) + 8|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($this,$1)|0);
 HEAPF32[$44>>2] = $2;
 HEAPF32[$45>>2] = $4;
 HEAPF32[$46>>2] = $6;
 HEAPF32[$47>>2] = Math_fround(0.0);
 HEAPF32[$48>>2] = $8;
 HEAPF32[$49>>2] = $10;
 HEAPF32[$50>>2] = $12;
 HEAPF32[$51>>2] = Math_fround(0.0);
 HEAPF32[$52>>2] = $14;
 HEAPF32[$53>>2] = $16;
 HEAPF32[$54>>2] = $18;
 HEAPF32[$55>>2] = Math_fround(0.0);
 HEAPF32[$56>>2] = $20;
 HEAPF32[$57>>2] = $22;
 HEAPF32[$58>>2] = $24;
 HEAPF32[$59>>2] = Math_fround(0.0);
 $142 = Math_fround($8 * $radius);
 $143 = Math_fround($10 * $radius);
 $144 = Math_fround($12 * $radius);
 $145 = Math_fround($26 + $142);
 $146 = Math_fround($27 + $143);
 $147 = Math_fround($28 + $144);
 $148 = Math_fround($145 + $35);
 $149 = Math_fround($146 + $36);
 $150 = Math_fround($147 + $37);
 $151 = Math_fround($148 + $20);
 $152 = Math_fround($149 + $22);
 $153 = Math_fround($150 + $24);
 $154 = Math_fround($98 + $142);
 $155 = Math_fround($99 + $143);
 $156 = Math_fround($100 + $144);
 $157 = Math_fround($154 + $35);
 $158 = Math_fround($155 + $36);
 $159 = Math_fround($156 + $37);
 $160 = Math_fround($157 + $20);
 $161 = Math_fround($158 + $22);
 $162 = Math_fround($159 + $24);
 $163 = (($this) + 100|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = (($164) + 16|0);
 $166 = (($this) + 4|0);
 HEAPF32[$0>>2] = $151;
 $167 = (($0) + 4|0);
 HEAPF32[$167>>2] = $152;
 $168 = (($0) + 8|0);
 HEAPF32[$168>>2] = $153;
 $169 = (($0) + 12|0);
 $170 = HEAP32[$166>>2]|0;
 HEAP32[$169>>2] = $170;
 $171 = (($0) + 16|0);
 HEAPF32[$171>>2] = $160;
 $172 = (($0) + 20|0);
 HEAPF32[$172>>2] = $161;
 $173 = (($0) + 24|0);
 HEAPF32[$173>>2] = $162;
 $174 = (($0) + 28|0);
 HEAP32[$174>>2] = $170;
 $175 = (($164) + 24|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = $176 & 2147483647;
 $178 = (($164) + 20|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ($177>>>0)>($179>>>0);
 if ($180) {
  $181 = HEAP32[$165>>2]|0;
  $182 = (($181) + ($179<<5)|0);
  $183 = ($182|0)==(0|0);
  if ($183) {
   $192 = $179;
  } else {
   HEAPF32[$182>>2] = $151;
   $184 = ((($181) + ($179<<5)|0) + 4|0);
   HEAPF32[$184>>2] = $152;
   $185 = ((($181) + ($179<<5)|0) + 8|0);
   HEAPF32[$185>>2] = $153;
   $186 = ((($181) + ($179<<5)|0) + 12|0);
   HEAP32[$186>>2] = $170;
   $187 = ((($181) + ($179<<5)|0) + 16|0);
   HEAPF32[$187>>2] = $160;
   $188 = ((($181) + ($179<<5)|0) + 20|0);
   HEAPF32[$188>>2] = $161;
   $189 = ((($181) + ($179<<5)|0) + 24|0);
   HEAPF32[$189>>2] = $162;
   $190 = ((($181) + ($179<<5)|0) + 28|0);
   HEAP32[$190>>2] = $170;
   $$pre$i$i5 = HEAP32[$178>>2]|0;
   $192 = $$pre$i$i5;
  }
  $191 = (($192) + 1)|0;
  HEAP32[$178>>2] = $191;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($165,$0)|0);
 }
 $193 = Math_fround(-$radius);
 $194 = Math_fround($8 * $193);
 $195 = Math_fround($10 * $193);
 $196 = Math_fround($12 * $193);
 $197 = Math_fround($26 + $194);
 $198 = Math_fround($27 + $195);
 $199 = Math_fround($28 + $196);
 $200 = Math_fround($197 + $35);
 $201 = Math_fround($198 + $36);
 $202 = Math_fround($199 + $37);
 $203 = Math_fround($200 + $20);
 $204 = Math_fround($201 + $22);
 $205 = Math_fround($202 + $24);
 $206 = Math_fround($98 + $194);
 $207 = Math_fround($99 + $195);
 $208 = Math_fround($100 + $196);
 $209 = Math_fround($206 + $35);
 $210 = Math_fround($207 + $36);
 $211 = Math_fround($208 + $37);
 $212 = Math_fround($209 + $20);
 $213 = Math_fround($210 + $22);
 $214 = Math_fround($211 + $24);
 $215 = HEAP32[$163>>2]|0;
 $216 = (($215) + 16|0);
 HEAPF32[$0>>2] = $203;
 $217 = (($0) + 4|0);
 HEAPF32[$217>>2] = $204;
 $218 = (($0) + 8|0);
 HEAPF32[$218>>2] = $205;
 $219 = (($0) + 12|0);
 $220 = HEAP32[$166>>2]|0;
 HEAP32[$219>>2] = $220;
 $221 = (($0) + 16|0);
 HEAPF32[$221>>2] = $212;
 $222 = (($0) + 20|0);
 HEAPF32[$222>>2] = $213;
 $223 = (($0) + 24|0);
 HEAPF32[$223>>2] = $214;
 $224 = (($0) + 28|0);
 HEAP32[$224>>2] = $220;
 $225 = (($215) + 24|0);
 $226 = HEAP32[$225>>2]|0;
 $227 = $226 & 2147483647;
 $228 = (($215) + 20|0);
 $229 = HEAP32[$228>>2]|0;
 $230 = ($227>>>0)>($229>>>0);
 if ($230) {
  $231 = HEAP32[$216>>2]|0;
  $232 = (($231) + ($229<<5)|0);
  $233 = ($232|0)==(0|0);
  if ($233) {
   $242 = $229;
  } else {
   HEAPF32[$232>>2] = $203;
   $234 = ((($231) + ($229<<5)|0) + 4|0);
   HEAPF32[$234>>2] = $204;
   $235 = ((($231) + ($229<<5)|0) + 8|0);
   HEAPF32[$235>>2] = $205;
   $236 = ((($231) + ($229<<5)|0) + 12|0);
   HEAP32[$236>>2] = $220;
   $237 = ((($231) + ($229<<5)|0) + 16|0);
   HEAPF32[$237>>2] = $212;
   $238 = ((($231) + ($229<<5)|0) + 20|0);
   HEAPF32[$238>>2] = $213;
   $239 = ((($231) + ($229<<5)|0) + 24|0);
   HEAPF32[$239>>2] = $214;
   $240 = ((($231) + ($229<<5)|0) + 28|0);
   HEAP32[$240>>2] = $220;
   $$pre$i$i3 = HEAP32[$228>>2]|0;
   $242 = $$pre$i$i3;
  }
  $241 = (($242) + 1)|0;
  HEAP32[$228>>2] = $241;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($216,$0)|0);
 }
 $243 = Math_fround($14 * $radius);
 $244 = Math_fround($16 * $radius);
 $245 = Math_fround($18 * $radius);
 $246 = Math_fround($32 + $243);
 $247 = Math_fround($33 + $244);
 $248 = Math_fround($34 + $245);
 $249 = Math_fround($246 + $20);
 $250 = Math_fround($247 + $22);
 $251 = Math_fround($248 + $24);
 $252 = Math_fround($101 + $243);
 $253 = Math_fround($102 + $244);
 $254 = Math_fround($103 + $245);
 $255 = Math_fround($252 + $20);
 $256 = Math_fround($253 + $22);
 $257 = Math_fround($254 + $24);
 $258 = HEAP32[$163>>2]|0;
 $259 = (($258) + 16|0);
 HEAPF32[$0>>2] = $249;
 $260 = (($0) + 4|0);
 HEAPF32[$260>>2] = $250;
 $261 = (($0) + 8|0);
 HEAPF32[$261>>2] = $251;
 $262 = (($0) + 12|0);
 $263 = HEAP32[$166>>2]|0;
 HEAP32[$262>>2] = $263;
 $264 = (($0) + 16|0);
 HEAPF32[$264>>2] = $255;
 $265 = (($0) + 20|0);
 HEAPF32[$265>>2] = $256;
 $266 = (($0) + 24|0);
 HEAPF32[$266>>2] = $257;
 $267 = (($0) + 28|0);
 HEAP32[$267>>2] = $263;
 $268 = (($258) + 24|0);
 $269 = HEAP32[$268>>2]|0;
 $270 = $269 & 2147483647;
 $271 = (($258) + 20|0);
 $272 = HEAP32[$271>>2]|0;
 $273 = ($270>>>0)>($272>>>0);
 if ($273) {
  $274 = HEAP32[$259>>2]|0;
  $275 = (($274) + ($272<<5)|0);
  $276 = ($275|0)==(0|0);
  if ($276) {
   $285 = $272;
  } else {
   HEAPF32[$275>>2] = $249;
   $277 = ((($274) + ($272<<5)|0) + 4|0);
   HEAPF32[$277>>2] = $250;
   $278 = ((($274) + ($272<<5)|0) + 8|0);
   HEAPF32[$278>>2] = $251;
   $279 = ((($274) + ($272<<5)|0) + 12|0);
   HEAP32[$279>>2] = $263;
   $280 = ((($274) + ($272<<5)|0) + 16|0);
   HEAPF32[$280>>2] = $255;
   $281 = ((($274) + ($272<<5)|0) + 20|0);
   HEAPF32[$281>>2] = $256;
   $282 = ((($274) + ($272<<5)|0) + 24|0);
   HEAPF32[$282>>2] = $257;
   $283 = ((($274) + ($272<<5)|0) + 28|0);
   HEAP32[$283>>2] = $263;
   $$pre$i$i1 = HEAP32[$271>>2]|0;
   $285 = $$pre$i$i1;
  }
  $284 = (($285) + 1)|0;
  HEAP32[$271>>2] = $284;
 } else {
  (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($259,$0)|0);
 }
 $286 = Math_fround($14 * $193);
 $287 = Math_fround($16 * $193);
 $288 = Math_fround($18 * $193);
 $289 = Math_fround($32 + $286);
 $290 = Math_fround($33 + $287);
 $291 = Math_fround($34 + $288);
 $292 = Math_fround($289 + $20);
 $293 = Math_fround($290 + $22);
 $294 = Math_fround($291 + $24);
 $295 = Math_fround($101 + $286);
 $296 = Math_fround($102 + $287);
 $297 = Math_fround($103 + $288);
 $298 = Math_fround($295 + $20);
 $299 = Math_fround($296 + $22);
 $300 = Math_fround($297 + $24);
 $301 = HEAP32[$163>>2]|0;
 $302 = (($301) + 16|0);
 HEAPF32[$0>>2] = $292;
 $303 = (($0) + 4|0);
 HEAPF32[$303>>2] = $293;
 $304 = (($0) + 8|0);
 HEAPF32[$304>>2] = $294;
 $305 = (($0) + 12|0);
 $306 = HEAP32[$166>>2]|0;
 HEAP32[$305>>2] = $306;
 $307 = (($0) + 16|0);
 HEAPF32[$307>>2] = $298;
 $308 = (($0) + 20|0);
 HEAPF32[$308>>2] = $299;
 $309 = (($0) + 24|0);
 HEAPF32[$309>>2] = $300;
 $310 = (($0) + 28|0);
 HEAP32[$310>>2] = $306;
 $311 = (($301) + 24|0);
 $312 = HEAP32[$311>>2]|0;
 $313 = $312 & 2147483647;
 $314 = (($301) + 20|0);
 $315 = HEAP32[$314>>2]|0;
 $316 = ($313>>>0)>($315>>>0);
 if (!($316)) {
  (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($302,$0)|0);
  STACKTOP = sp;return ($this|0);
 }
 $317 = HEAP32[$302>>2]|0;
 $318 = (($317) + ($315<<5)|0);
 $319 = ($318|0)==(0|0);
 if ($319) {
  $328 = $315;
 } else {
  HEAPF32[$318>>2] = $292;
  $320 = ((($317) + ($315<<5)|0) + 4|0);
  HEAPF32[$320>>2] = $293;
  $321 = ((($317) + ($315<<5)|0) + 8|0);
  HEAPF32[$321>>2] = $294;
  $322 = ((($317) + ($315<<5)|0) + 12|0);
  HEAP32[$322>>2] = $306;
  $323 = ((($317) + ($315<<5)|0) + 16|0);
  HEAPF32[$323>>2] = $298;
  $324 = ((($317) + ($315<<5)|0) + 20|0);
  HEAPF32[$324>>2] = $299;
  $325 = ((($317) + ($315<<5)|0) + 24|0);
  HEAPF32[$325>>2] = $300;
  $326 = ((($317) + ($315<<5)|0) + 28|0);
  HEAP32[$326>>2] = $306;
  $$pre$i$i = HEAP32[$314>>2]|0;
  $328 = $$pre$i$i;
 }
 $327 = (($328) + 1)|0;
 HEAP32[$314>>2] = $327;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Cm20visualizeJointFramesERNS0_12RenderOutputEfRKNS_11PxTransformES5_($out,$scale,$parent,$child) {
 $out = $out|0;
 $scale = Math_fround($scale);
 $parent = $parent|0;
 $child = $child|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$parent)|0);
 $3 = Math_fround($scale * Math_fround(1.5));
 HEAPF32[$0>>2] = $3;
 $4 = (($0) + 4|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($0) + 8|0);
 HEAPF32[$5>>2] = $3;
 $6 = (($0) + 12|0);
 HEAP32[$6>>2] = -2004353024;
 $7 = (($0) + 16|0);
 HEAP32[$7>>2] = -2013231104;
 $8 = (($0) + 20|0);
 HEAP32[$8>>2] = -2013265784;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($2,$0)|0);
 $9 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$child)|0);
 HEAPF32[$1>>2] = $scale;
 $10 = (($1) + 4|0);
 HEAPF32[$10>>2] = $scale;
 $11 = (($1) + 8|0);
 HEAPF32[$11>>2] = $scale;
 $12 = (($1) + 12|0);
 HEAP32[$12>>2] = -65536;
 $13 = (($1) + 16|0);
 HEAP32[$13>>2] = -16711936;
 $14 = (($1) + 20|0);
 HEAP32[$14>>2] = -16776961;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugBasisE($9,$1)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm20visualizeLinearLimitERNS0_12RenderOutputEfRKNS_11PxTransformES5_fb($out,$scale,$t0,$0,$value,$active) {
 $out = $out|0;
 $scale = Math_fround($scale);
 $t0 = $t0|0;
 $0 = $0|0;
 $value = Math_fround($value);
 $active = $active|0;
 var $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $r = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $r = sp + 64|0;
 $1 = sp;
 $2 = sp + 28|0;
 $3 = sp + 56|0;
 $4 = Math_fround(HEAPF32[$t0>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = (($t0) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(2.0));
 $9 = Math_fround($7 * $8);
 $10 = Math_fround($9 + Math_fround(-1.0));
 $11 = Math_fround($4 * $5);
 $12 = Math_fround($11 + $10);
 $13 = (($t0) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $8);
 $16 = (($t0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($5 * $17);
 $19 = Math_fround($15 + $18);
 $20 = Math_fround($8 * $17);
 $21 = Math_fround($5 * $14);
 $22 = Math_fround($21 - $20);
 $23 = Math_fround($12 * $value);
 $24 = Math_fround($19 * $value);
 $25 = Math_fround($22 * $value);
 $26 = (($t0) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 + $23);
 $29 = (($t0) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $24);
 $32 = (($t0) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 + $25);
 $35 = Math_fround($7 * Math_fround(0.0));
 $36 = Math_fround($4 * Math_fround(0.707106769084930419921));
 $37 = Math_fround($36 + $35);
 $38 = Math_fround($17 * Math_fround(0.0));
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($14 * Math_fround(0.707106769084930419921));
 $41 = Math_fround($39 - $40);
 $42 = Math_fround($7 * Math_fround(0.707106769084930419921));
 $43 = Math_fround($17 * Math_fround(0.707106769084930419921));
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($14 * Math_fround(0.0));
 $46 = Math_fround($45 + $44);
 $47 = Math_fround($4 * Math_fround(0.0));
 $48 = Math_fround($46 - $47);
 $49 = Math_fround($35 + $40);
 $50 = Math_fround($36 + $49);
 $51 = Math_fround($50 - $38);
 $52 = Math_fround($42 - $47);
 $53 = Math_fround($52 - $43);
 $54 = Math_fround($53 - $45);
 HEAPF32[$r>>2] = $41;
 $55 = (($r) + 4|0);
 HEAPF32[$55>>2] = $48;
 $56 = (($r) + 8|0);
 HEAPF32[$56>>2] = $51;
 $57 = (($r) + 12|0);
 HEAPF32[$57>>2] = $54;
 $58 = (($r) + 16|0);
 HEAPF32[$58>>2] = $28;
 $59 = (($r) + 20|0);
 HEAPF32[$59>>2] = $31;
 $60 = (($r) + 24|0);
 HEAPF32[$60>>2] = $34;
 $61 = $active ? -65536 : -8355712;
 (__ZN5physx2Cm12RenderOutputlsEj($out,$61)|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $62 = (($1) + 4|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($1) + 8|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($1) + 12|0);
 HEAPF32[$64>>2] = Math_fround(1.0);
 $65 = (($1) + 16|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 $66 = (($1) + 20|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($1) + 24|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$1)|0);
 $68 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$2>>2] = $68;
 $69 = (($2) + 4|0);
 $70 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$69>>2] = $70;
 $71 = (($2) + 8|0);
 $72 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$71>>2] = $72;
 $73 = Math_fround($68 + $28);
 $74 = Math_fround($70 + $31);
 $75 = Math_fround($72 + $34);
 $76 = (($2) + 12|0);
 HEAPF32[$76>>2] = $73;
 $77 = (($2) + 16|0);
 HEAPF32[$77>>2] = $74;
 $78 = (($2) + 20|0);
 HEAPF32[$78>>2] = $75;
 $79 = (($2) + 24|0);
 $80 = Math_fround($28 * $28);
 $81 = Math_fround($31 * $31);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($34 * $34);
 $84 = Math_fround($82 + $83);
 $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
 $86 = Math_fround($85 * Math_fround(0.150000005960464477539));
 HEAPF32[$79>>2] = $86;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($out,$2)|0);
 $87 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$r)|0);
 $88 = Math_fround($scale * Math_fround(0.300000011920928955078));
 HEAP32[$3>>2] = 20;
 $89 = (($3) + 4|0);
 HEAPF32[$89>>2] = $88;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($87,$3)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Cm21visualizeAngularLimitERNS0_12RenderOutputEfRKNS_11PxTransformEffb($out,$scale,$t,$lower,$upper,$active) {
 $out = $out|0;
 $scale = Math_fround($scale);
 $t = $t|0;
 $lower = Math_fround($lower);
 $upper = Math_fround($upper);
 $active = $active|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $angle$07 = Math_fround(0), $exitcond = 0;
 var $i$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$t)|0);
 $6 = $active ? -65536 : -8355712;
 (__ZN5physx2Cm12RenderOutputlsEj($5,$6)|0);
 $7 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,1)|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $8 = (($0) + 4|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($0) + 8|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($7,$0)|0);
 $11 = (Math_fround(+(Math_cos((+$lower)))));
 $12 = (Math_fround(+(Math_sin((+$lower)))));
 $13 = Math_fround($scale * Math_fround(0.0));
 $14 = Math_fround($11 * $scale);
 $15 = Math_fround($12 * $scale);
 HEAPF32[$1>>2] = $13;
 $16 = (($1) + 4|0);
 HEAPF32[$16>>2] = $14;
 $17 = (($1) + 8|0);
 HEAPF32[$17>>2] = $15;
 $18 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($10,$1)|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $19 = (($2) + 4|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($2) + 8|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($18,$2)|0);
 $22 = (Math_fround(+(Math_cos((+$upper)))));
 $23 = (Math_fround(+(Math_sin((+$upper)))));
 $24 = Math_fround($22 * $scale);
 $25 = Math_fround($23 * $scale);
 HEAPF32[$3>>2] = $13;
 $26 = (($3) + 4|0);
 HEAPF32[$26>>2] = $24;
 $27 = (($3) + 8|0);
 HEAPF32[$27>>2] = $25;
 (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($21,$3)|0);
 (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,2)|0);
 $28 = Math_fround($upper - $lower);
 $29 = Math_fround($28 / Math_fround(20.0));
 $30 = (($4) + 4|0);
 $31 = (($4) + 8|0);
 $angle$07 = $lower;$i$08 = 0;
 while(1) {
  $32 = (Math_fround(+(Math_cos((+$angle$07)))));
  $33 = (Math_fround(+(Math_sin((+$angle$07)))));
  $34 = Math_fround($32 * $scale);
  $35 = Math_fround($33 * $scale);
  HEAPF32[$4>>2] = $13;
  HEAPF32[$30>>2] = $34;
  HEAPF32[$31>>2] = $35;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$4)|0);
  $36 = (($i$08) + 1)|0;
  $37 = Math_fround($29 + $angle$07);
  $exitcond = ($36|0)==(21);
  if ($exitcond) {
   break;
  } else {
   $angle$07 = $37;$i$08 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm18visualizeLimitConeERNS0_12RenderOutputEfRKNS_11PxTransformEffb($out,$scale,$t,$tanQSwingY,$tanQSwingZ,$active) {
 $out = $out|0;
 $scale = Math_fround($scale);
 $t = $t|0;
 $tanQSwingY = Math_fround($tanQSwingY);
 $tanQSwingZ = Math_fround($tanQSwingZ);
 $active = $active|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 36|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$t)|0);
 $5 = $active ? -65536 : -8355712;
 (__ZN5physx2Cm12RenderOutputlsEj($4,$5)|0);
 (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,1)|0);
 $6 = (($0) + 4|0);
 $7 = (($0) + 8|0);
 $8 = (($1) + 4|0);
 $9 = (($1) + 8|0);
 $10 = (($2) + 4|0);
 $11 = (($2) + 8|0);
 $12 = (($3) + 4|0);
 $13 = (($3) + 8|0);
 $63 = Math_fround(0.0);$64 = Math_fround(0.0);$65 = Math_fround(0.0);$i$07 = 0;
 while(1) {
  $14 = (Math_fround(($i$07>>>0)));
  $15 = Math_fround($14 * Math_fround(0.196349546313285827637));
  $16 = (Math_fround(+(Math_cos((+$15)))));
  $17 = (Math_fround(+(Math_sin((+$15)))));
  $18 = Math_fround($17 * $tanQSwingZ);
  $19 = Math_fround($16 * $tanQSwingY);
  $20 = Math_fround($18 * $18);
  $21 = Math_fround($20 + Math_fround(0.0));
  $22 = Math_fround($19 * $19);
  $23 = Math_fround($22 + $21);
  $24 = Math_fround($18 * Math_fround(-2.0));
  $25 = Math_fround($19 * Math_fround(2.0));
  $26 = Math_fround(Math_fround(1.0) - $23);
  $27 = Math_fround($23 + Math_fround(1.0));
  $28 = Math_fround(Math_fround(1.0) / $27);
  $29 = Math_fround($28 * Math_fround(0.0));
  $30 = Math_fround($28 * $24);
  $31 = Math_fround($25 * $28);
  $32 = Math_fround($28 * $26);
  $33 = Math_fround($32 * $32);
  $34 = Math_fround($33 + Math_fround(-0.5));
  $35 = Math_fround($29 * Math_fround(2.0));
  $36 = Math_fround($30 * Math_fround(0.0));
  $37 = Math_fround($35 + $36);
  $38 = Math_fround($31 * Math_fround(0.0));
  $39 = Math_fround($38 + $37);
  $40 = Math_fround($34 * Math_fround(2.0));
  $41 = Math_fround($36 - $38);
  $42 = Math_fround($41 * $32);
  $43 = Math_fround($42 + $40);
  $44 = Math_fround($29 * $39);
  $45 = Math_fround($44 + $43);
  $46 = Math_fround($34 * Math_fround(0.0));
  $47 = Math_fround($31 * Math_fround(2.0));
  $48 = Math_fround($29 * Math_fround(0.0));
  $49 = Math_fround($47 - $48);
  $50 = Math_fround($49 * $32);
  $51 = Math_fround($50 + $46);
  $52 = Math_fround($30 * $39);
  $53 = Math_fround($52 + $51);
  $54 = Math_fround($30 * Math_fround(2.0));
  $55 = Math_fround($48 - $54);
  $56 = Math_fround($55 * $32);
  $57 = Math_fround($56 + $46);
  $58 = Math_fround($31 * $39);
  $59 = Math_fround($58 + $57);
  $60 = Math_fround($45 * $scale);
  $61 = Math_fround($53 * $scale);
  $62 = Math_fround($59 * $scale);
  HEAPF32[$0>>2] = $63;
  HEAPF32[$6>>2] = $64;
  HEAPF32[$7>>2] = $65;
  $66 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$0)|0);
  HEAPF32[$1>>2] = $60;
  HEAPF32[$8>>2] = $61;
  HEAPF32[$9>>2] = $62;
  $67 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($66,$1)|0);
  HEAPF32[$2>>2] = Math_fround(0.0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  $68 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($67,$2)|0);
  HEAPF32[$3>>2] = $60;
  HEAPF32[$12>>2] = $61;
  HEAPF32[$13>>2] = $62;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($68,$3)|0);
  $69 = (($i$07) + 1)|0;
  $exitcond = ($69|0)==(33);
  if ($exitcond) {
   break;
  } else {
   $63 = $60;$64 = $61;$65 = $62;$i$07 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Cm19visualizeDoubleConeERNS0_12RenderOutputEfRKNS_11PxTransformEfb($out,$scale,$t,$angle,$active) {
 $out = $out|0;
 $scale = Math_fround($scale);
 $t = $t|0;
 $angle = Math_fround($angle);
 $active = $active|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, $exitcond = 0, $exitcond13 = 0, $exitcond14 = 0, $i$012 = 0, $i1$011 = 0, $i2$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 60|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 $6 = (__ZN5physx2Cm12RenderOutputlsERKNS_11PxTransformE($out,$t)|0);
 $7 = $active ? -65536 : -8355712;
 (__ZN5physx2Cm12RenderOutputlsEj($6,$7)|0);
 $8 = +$angle;
 $9 = (+Math_sin((+$8)));
 $10 = Math_fround($9);
 (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,2)|0);
 $11 = Math_fround($10 * $scale);
 $12 = (($0) + 4|0);
 $13 = (($0) + 8|0);
 $i$012 = 0;
 while(1) {
  $14 = (Math_fround(($i$012>>>0)));
  $15 = Math_fround($14 * Math_fround(0.196349546313285827637));
  $16 = (Math_fround(+(Math_cos((+$15)))));
  $17 = (Math_fround(+(Math_sin((+$15)))));
  $18 = Math_fround($16 * $scale);
  $19 = Math_fround($17 * $scale);
  HEAPF32[$0>>2] = $11;
  HEAPF32[$12>>2] = $18;
  HEAPF32[$13>>2] = $19;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$0)|0);
  $20 = (($i$012) + 1)|0;
  $exitcond14 = ($20|0)==(33);
  if ($exitcond14) {
   break;
  } else {
   $i$012 = $20;
  }
 }
 (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,2)|0);
 $21 = Math_fround(-$11);
 $22 = (($1) + 4|0);
 $23 = (($1) + 8|0);
 $i1$011 = 0;
 while(1) {
  $24 = (Math_fround(($i1$011>>>0)));
  $25 = Math_fround($24 * Math_fround(0.196349546313285827637));
  $26 = (Math_fround(+(Math_cos((+$25)))));
  $27 = (Math_fround(+(Math_sin((+$25)))));
  $28 = Math_fround($26 * $scale);
  $29 = Math_fround($27 * $scale);
  HEAPF32[$1>>2] = $21;
  HEAPF32[$22>>2] = $28;
  HEAPF32[$23>>2] = $29;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$1)|0);
  $30 = (($i1$011) + 1)|0;
  $exitcond13 = ($30|0)==(33);
  if ($exitcond13) {
   break;
  } else {
   $i1$011 = $30;
  }
 }
 (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($out,1)|0);
 $31 = (($2) + 4|0);
 $32 = (($2) + 8|0);
 $33 = (($3) + 4|0);
 $34 = (($3) + 8|0);
 $35 = (($4) + 4|0);
 $36 = (($4) + 8|0);
 $37 = (($5) + 4|0);
 $38 = (($5) + 8|0);
 $i2$010 = 0;
 while(1) {
  HEAPF32[$2>>2] = Math_fround(0.0);
  HEAPF32[$31>>2] = Math_fround(0.0);
  HEAPF32[$32>>2] = Math_fround(0.0);
  $39 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$2)|0);
  $40 = (Math_fround(($i2$010>>>0)));
  $41 = Math_fround($40 * Math_fround(0.196349546313285827637));
  $42 = (Math_fround(+(Math_cos((+$41)))));
  $43 = (Math_fround(+(Math_sin((+$41)))));
  $44 = Math_fround($42 * $scale);
  $45 = Math_fround($43 * $scale);
  HEAPF32[$3>>2] = $21;
  HEAPF32[$33>>2] = $44;
  HEAPF32[$34>>2] = $45;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($39,$3)|0);
  HEAPF32[$4>>2] = Math_fround(0.0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $46 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($out,$4)|0);
  HEAPF32[$5>>2] = $11;
  HEAPF32[$37>>2] = $44;
  HEAPF32[$38>>2] = $45;
  (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($46,$5)|0);
  $47 = (($i2$010) + 1)|0;
  $exitcond = ($47|0)==(32);
  if ($exitcond) {
   break;
  } else {
   $i2$010 = $47;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu3Box6createERKNS0_7CapsuleE($this,$capsule) {
 $this = $this|0;
 $capsule = $capsule|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0;
 var $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0;
 var $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$capsule>>2]);
 $1 = (($capsule) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 $4 = (($capsule) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($capsule) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 $9 = (($capsule) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($capsule) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = Math_fround($3 * Math_fround(0.5));
 $15 = Math_fround($8 * Math_fround(0.5));
 $16 = Math_fround($13 * Math_fround(0.5));
 $17 = (($this) + 36|0);
 HEAPF32[$17>>2] = $14;
 $18 = (($this) + 40|0);
 HEAPF32[$18>>2] = $15;
 $19 = (($this) + 44|0);
 HEAPF32[$19>>2] = $16;
 $20 = Math_fround(HEAPF32[$1>>2]);
 $21 = Math_fround(HEAPF32[$capsule>>2]);
 $22 = Math_fround($20 - $21);
 $23 = Math_fround(HEAPF32[$6>>2]);
 $24 = Math_fround(HEAPF32[$4>>2]);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround(HEAPF32[$11>>2]);
 $27 = Math_fround(HEAPF32[$9>>2]);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($22 * $22);
 $30 = Math_fround($25 * $25);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($28 * $28);
 $33 = Math_fround($31 + $32);
 $34 = (Math_fround(Math_sqrt((Math_fround($33)))));
 $35 = Math_fround(Math_fround(1.0) / $34);
 $36 = Math_fround($22 * $35);
 $37 = Math_fround($25 * $35);
 $38 = Math_fround($28 * $35);
 HEAPF32[$this>>2] = $36;
 $39 = (($this) + 4|0);
 HEAPF32[$39>>2] = $37;
 $40 = (($this) + 8|0);
 HEAPF32[$40>>2] = $38;
 $41 = (($capsule) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($34 * Math_fround(0.5));
 $44 = Math_fround($43 + $42);
 $45 = (($this) + 48|0);
 HEAPF32[$45>>2] = $44;
 $46 = Math_fround(HEAPF32[$41>>2]);
 $47 = (($this) + 52|0);
 HEAPF32[$47>>2] = $46;
 $48 = Math_fround(HEAPF32[$41>>2]);
 $49 = (($this) + 56|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($this) + 12|0);
 $51 = (($this) + 24|0);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($37)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($36)))));
 $52 = $fabsf$i$i$i$i > $fabsf$i$i1$i$i;
 $53 = $52&1;
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($38)))));
 $54 = (($this) + ($53<<2)|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($55)))));
 $56 = $fabsf$i$i2$i$i > $fabsf$i$i3$i$i;
 $57 = $56 ? 2 : $53;
 if ((($57|0) == 1)) {
  HEAPF32[$50>>2] = Math_fround(0.0);
  $70 = Math_fround(-$38);
  $71 = (($this) + 16|0);
  HEAPF32[$71>>2] = $70;
  $72 = (($this) + 20|0);
  HEAPF32[$72>>2] = $37;
  $73 = Math_fround($37 * $37);
  $74 = Math_fround($38 * $38);
  $75 = Math_fround($73 + $74);
  HEAPF32[$51>>2] = $75;
  $76 = Math_fround($36 * $37);
  $77 = Math_fround(-$76);
  $78 = (($this) + 28|0);
  HEAPF32[$78>>2] = $77;
  $79 = Math_fround($36 * $38);
  $80 = Math_fround(-$79);
  $81 = (($this) + 32|0);
  HEAPF32[$81>>2] = $80;
  $100 = $37;$95 = Math_fround(0.0);$97 = $70;
 } else if ((($57|0) == 0)) {
  $58 = Math_fround(-$37);
  HEAPF32[$50>>2] = $58;
  $59 = (($this) + 16|0);
  HEAPF32[$59>>2] = $36;
  $60 = (($this) + 20|0);
  HEAPF32[$60>>2] = Math_fround(0.0);
  $61 = Math_fround($38 * $36);
  $62 = Math_fround(-$61);
  HEAPF32[$51>>2] = $62;
  $63 = Math_fround($38 * $37);
  $64 = Math_fround(-$63);
  $65 = (($this) + 28|0);
  HEAPF32[$65>>2] = $64;
  $66 = Math_fround($36 * $36);
  $67 = Math_fround($37 * $37);
  $68 = Math_fround($66 + $67);
  $69 = (($this) + 32|0);
  HEAPF32[$69>>2] = $68;
  $100 = Math_fround(0.0);$95 = $58;$97 = $36;
 } else {
  HEAPF32[$50>>2] = $38;
  $82 = (($this) + 16|0);
  HEAPF32[$82>>2] = Math_fround(0.0);
  $83 = Math_fround(-$36);
  $84 = (($this) + 20|0);
  HEAPF32[$84>>2] = $83;
  $85 = Math_fround($37 * $36);
  $86 = Math_fround(-$85);
  HEAPF32[$51>>2] = $86;
  $87 = Math_fround($38 * $38);
  $88 = Math_fround($36 * $36);
  $89 = Math_fround($87 + $88);
  $90 = (($this) + 28|0);
  HEAPF32[$90>>2] = $89;
  $91 = Math_fround($37 * $38);
  $92 = Math_fround(-$91);
  $93 = (($this) + 32|0);
  HEAPF32[$93>>2] = $92;
  $100 = $83;$95 = $38;$97 = Math_fround(0.0);
 }
 $94 = Math_fround($95 * $95);
 $96 = Math_fround($97 * $97);
 $98 = Math_fround($94 + $96);
 $99 = Math_fround($100 * $100);
 $101 = Math_fround($98 + $99);
 $102 = (Math_fround(Math_sqrt((Math_fround($101)))));
 $103 = $102 > Math_fround(0.0);
 if (!($103)) {
  STACKTOP = sp;return;
 }
 $104 = (($this) + 20|0);
 $105 = (($this) + 16|0);
 $106 = Math_fround(Math_fround(1.0) / $102);
 $107 = Math_fround($95 * $106);
 HEAPF32[$50>>2] = $107;
 $108 = Math_fround($97 * $106);
 HEAPF32[$105>>2] = $108;
 $109 = Math_fround($100 * $106);
 HEAPF32[$104>>2] = $109;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11getBoxEdgesEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (546032|0);
}
function __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($pts,$center,$extents,$base0,$base1,$base2) {
 $pts = $pts|0;
 $center = $center|0;
 $extents = $extents|0;
 $base0 = $base0|0;
 $base1 = $base1|0;
 $base2 = $base2|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$extents>>2]);
 $1 = Math_fround(HEAPF32[$base0>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($base0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($0 * $4);
 $6 = (($base0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($0 * $7);
 $9 = (($extents) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$base1>>2]);
 $12 = Math_fround($10 * $11);
 $13 = (($base1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($10 * $14);
 $16 = (($base1) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($10 * $17);
 $19 = (($extents) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$base2>>2]);
 $22 = Math_fround($20 * $21);
 $23 = (($base2) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($20 * $24);
 $26 = (($base2) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($20 * $27);
 $29 = Math_fround(HEAPF32[$center>>2]);
 $30 = Math_fround($29 - $2);
 $31 = (($center) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 - $5);
 $34 = (($center) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 - $8);
 $37 = (($pts) + 84|0);
 HEAPF32[$37>>2] = $30;
 $38 = (($pts) + 88|0);
 HEAPF32[$38>>2] = $33;
 $39 = (($pts) + 92|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($pts) + 48|0);
 HEAPF32[$40>>2] = $30;
 $41 = (($pts) + 52|0);
 HEAPF32[$41>>2] = $33;
 $42 = (($pts) + 56|0);
 HEAPF32[$42>>2] = $36;
 $43 = (($pts) + 36|0);
 HEAPF32[$43>>2] = $30;
 $44 = (($pts) + 40|0);
 HEAPF32[$44>>2] = $33;
 $45 = (($pts) + 44|0);
 HEAPF32[$45>>2] = $36;
 HEAPF32[$pts>>2] = $30;
 $46 = (($pts) + 4|0);
 HEAPF32[$46>>2] = $33;
 $47 = (($pts) + 8|0);
 HEAPF32[$47>>2] = $36;
 $48 = Math_fround(HEAPF32[$center>>2]);
 $49 = Math_fround($2 + $48);
 $50 = Math_fround(HEAPF32[$31>>2]);
 $51 = Math_fround($5 + $50);
 $52 = Math_fround(HEAPF32[$34>>2]);
 $53 = Math_fround($8 + $52);
 $54 = (($pts) + 72|0);
 $55 = (($pts) + 76|0);
 $56 = (($pts) + 80|0);
 $57 = (($pts) + 60|0);
 $58 = (($pts) + 64|0);
 $59 = (($pts) + 68|0);
 $60 = (($pts) + 24|0);
 $61 = (($pts) + 28|0);
 $62 = (($pts) + 32|0);
 $63 = (($pts) + 12|0);
 $64 = (($pts) + 16|0);
 $65 = (($pts) + 20|0);
 $66 = Math_fround($12 + $22);
 $67 = Math_fround($15 + $25);
 $68 = Math_fround($18 + $28);
 $69 = Math_fround($30 - $66);
 HEAPF32[$pts>>2] = $69;
 $70 = Math_fround($33 - $67);
 HEAPF32[$46>>2] = $70;
 $71 = Math_fround($36 - $68);
 HEAPF32[$47>>2] = $71;
 $72 = Math_fround($49 - $66);
 HEAPF32[$63>>2] = $72;
 $73 = Math_fround($51 - $67);
 HEAPF32[$64>>2] = $73;
 $74 = Math_fround($53 - $68);
 HEAPF32[$65>>2] = $74;
 $75 = Math_fround($66 + $49);
 HEAPF32[$54>>2] = $75;
 $76 = Math_fround($67 + $51);
 HEAPF32[$55>>2] = $76;
 $77 = Math_fround($68 + $53);
 HEAPF32[$56>>2] = $77;
 $78 = Math_fround($66 + $30);
 HEAPF32[$37>>2] = $78;
 $79 = Math_fround($67 + $33);
 HEAPF32[$38>>2] = $79;
 $80 = Math_fround($68 + $36);
 HEAPF32[$39>>2] = $80;
 $81 = Math_fround($12 - $22);
 $82 = Math_fround($15 - $25);
 $83 = Math_fround($18 - $28);
 $84 = Math_fround($81 + $49);
 HEAPF32[$60>>2] = $84;
 $85 = Math_fround($82 + $51);
 HEAPF32[$61>>2] = $85;
 $86 = Math_fround($83 + $53);
 HEAPF32[$62>>2] = $86;
 $87 = Math_fround($81 + $30);
 HEAPF32[$43>>2] = $87;
 $88 = Math_fround($82 + $33);
 HEAPF32[$44>>2] = $88;
 $89 = Math_fround($83 + $36);
 HEAPF32[$45>>2] = $89;
 $90 = Math_fround($30 - $81);
 HEAPF32[$40>>2] = $90;
 $91 = Math_fround($33 - $82);
 HEAPF32[$41>>2] = $91;
 $92 = Math_fround($36 - $83);
 HEAPF32[$42>>2] = $92;
 $93 = Math_fround($49 - $81);
 HEAPF32[$57>>2] = $93;
 $94 = Math_fround($51 - $82);
 HEAPF32[$58>>2] = $94;
 $95 = Math_fround($53 - $83);
 HEAPF32[$59>>2] = $95;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu18CompleteBoxPruningEPKNS_9PxBounds3EjRNS_6shdfnd5ArrayIjNS4_19ReflectionAllocatorIjEEEERKNS0_4AxesE($bounds,$nb,$pairs,$axes) {
 $bounds = $bounds|0;
 $nb = $nb|0;
 $pairs = $pairs|0;
 $axes = $axes|0;
 var $$0 = 0, $$pre = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0;
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = Math_fround(0), $Index0 = 0, $Index1 = 0, $RS = 0, $RunningAddress$09 = 0, $RunningAddress$1 = 0, $RunningAddress$2 = 0, $RunningAddress2$06 = 0, $Sorted$08 = 0;
 var $exitcond = 0, $i$011 = 0, $or$cond = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 45|0;
 $RS = sp;
 $Index0 = sp + 36|0;
 $Index1 = sp + 40|0;
 $1 = sp + 44|0;
 $2 = (($pairs) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ($nb|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[$axes>>2]|0;
 $5 = $nb << 2;
 $6 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$5,546056,157)|0);
 $i$011 = 0;
 while(1) {
  $7 = (($bounds) + (($i$011*24)|0)|0);
  $8 = (($7) + ($4<<2)|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($6) + ($i$011<<2)|0);
  HEAPF32[$10>>2] = $9;
  $11 = (($i$011) + 1)|0;
  $exitcond = ($11|0)==($nb|0);
  if ($exitcond) {
   break;
  } else {
   $i$011 = $11;
  }
 }
 __ZN5physx2Gu17RadixSortBufferedC2Ev($RS);
 $12 = (__ZN5physx2Gu17RadixSortBuffered4SortEPKfj($RS,$6,$nb)|0);
 $13 = (($12) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($nb<<2)|0);
 $16 = ($nb|0)>(0);
 L7: do {
  if ($16) {
   $17 = (($pairs) + 8|0);
   $RunningAddress$09 = $14;$Sorted$08 = $14;
   while(1) {
    $19 = (($Sorted$08) + 4|0);
    $21 = HEAP32[$Sorted$08>>2]|0;
    HEAP32[$Index0>>2] = $21;
    $22 = (($6) + ($21<<2)|0);
    $RunningAddress$1 = $RunningAddress$09;
    while(1) {
     $23 = ($RunningAddress$1>>>0)<($15>>>0);
     if (!($23)) {
      $RunningAddress$2 = $RunningAddress$1;
      break;
     }
     $24 = (($RunningAddress$1) + 4|0);
     $25 = HEAP32[$RunningAddress$1>>2]|0;
     $26 = (($6) + ($25<<2)|0);
     $27 = Math_fround(HEAPF32[$26>>2]);
     $28 = Math_fround(HEAPF32[$22>>2]);
     $29 = $27 < $28;
     if ($29) {
      $RunningAddress$1 = $24;
     } else {
      $RunningAddress$2 = $24;
      break;
     }
    }
    $20 = ($RunningAddress$2>>>0)<($15>>>0);
    if ($20) {
     $35 = $21;$RunningAddress2$06 = $RunningAddress$2;
    } else {
     break L7;
    }
    while(1) {
     $30 = (($RunningAddress2$06) + 4|0);
     $31 = HEAP32[$RunningAddress2$06>>2]|0;
     HEAP32[$Index1>>2] = $31;
     $32 = (($6) + ($31<<2)|0);
     $33 = Math_fround(HEAPF32[$32>>2]);
     $34 = ((($bounds) + (($35*24)|0)|0) + 12|0);
     $36 = (($34) + ($4<<2)|0);
     $37 = Math_fround(HEAPF32[$36>>2]);
     $38 = !($33 <= $37);
     if ($38) {
      break;
     }
     $39 = ($35|0)==($31|0);
     do {
      if (!($39)) {
       $40 = (($bounds) + (($31*24)|0)|0);
       $41 = Math_fround(HEAPF32[$40>>2]);
       $42 = Math_fround(HEAPF32[$34>>2]);
       $43 = $41 > $42;
       if (!($43)) {
        $44 = (($bounds) + (($35*24)|0)|0);
        $45 = Math_fround(HEAPF32[$44>>2]);
        $46 = ((($bounds) + (($31*24)|0)|0) + 12|0);
        $47 = Math_fround(HEAPF32[$46>>2]);
        $48 = $45 > $47;
        if (!($48)) {
         $49 = ((($bounds) + (($31*24)|0)|0) + 4|0);
         $50 = Math_fround(HEAPF32[$49>>2]);
         $51 = ((($bounds) + (($35*24)|0)|0) + 16|0);
         $52 = Math_fround(HEAPF32[$51>>2]);
         $53 = $50 > $52;
         if (!($53)) {
          $54 = ((($bounds) + (($35*24)|0)|0) + 4|0);
          $55 = Math_fround(HEAPF32[$54>>2]);
          $56 = ((($bounds) + (($31*24)|0)|0) + 16|0);
          $57 = Math_fround(HEAPF32[$56>>2]);
          $58 = $55 > $57;
          if (!($58)) {
           $59 = ((($bounds) + (($31*24)|0)|0) + 8|0);
           $60 = Math_fround(HEAPF32[$59>>2]);
           $61 = ((($bounds) + (($35*24)|0)|0) + 20|0);
           $62 = Math_fround(HEAPF32[$61>>2]);
           $63 = $60 > $62;
           if (!($63)) {
            $64 = ((($bounds) + (($35*24)|0)|0) + 8|0);
            $65 = Math_fround(HEAPF32[$64>>2]);
            $66 = ((($bounds) + (($31*24)|0)|0) + 20|0);
            $67 = Math_fround(HEAPF32[$66>>2]);
            $phitmp$i = !($65 > $67);
            if ($phitmp$i) {
             $69 = HEAP32[$17>>2]|0;
             $70 = $69 & 2147483647;
             $71 = HEAP32[$2>>2]|0;
             $72 = ($70>>>0)>($71>>>0);
             if ($72) {
              $73 = HEAP32[$pairs>>2]|0;
              $74 = (($73) + ($71<<2)|0);
              $75 = ($74|0)==(0|0);
              if ($75) {
               $77 = $71;
              } else {
               HEAP32[$74>>2] = $35;
               $$pre$i3 = HEAP32[$2>>2]|0;
               $77 = $$pre$i3;
              }
              $76 = (($77) + 1)|0;
              HEAP32[$2>>2] = $76;
              $81 = $76;
             } else {
              (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($pairs,$Index0)|0);
              $$pre = HEAP32[$2>>2]|0;
              $81 = $$pre;
             }
             $78 = HEAP32[$17>>2]|0;
             $79 = $78 & 2147483647;
             $80 = ($79>>>0)>($81>>>0);
             if (!($80)) {
              (__ZN5physx6shdfnd5ArrayIjNS0_19ReflectionAllocatorIjEEE15growAndPushBackERKj($pairs,$Index1)|0);
              break;
             }
             $82 = HEAP32[$pairs>>2]|0;
             $83 = (($82) + ($81<<2)|0);
             $84 = ($83|0)==(0|0);
             if ($84) {
              $86 = $81;
             } else {
              HEAP32[$83>>2] = $31;
              $$pre$i = HEAP32[$2>>2]|0;
              $86 = $$pre$i;
             }
             $85 = (($86) + 1)|0;
             HEAP32[$2>>2] = $85;
            }
           }
          }
         }
        }
       }
      }
     } while(0);
     $68 = ($30>>>0)<($15>>>0);
     if (!($68)) {
      break;
     }
     $$pre13 = HEAP32[$Index0>>2]|0;
     $35 = $$pre13;$RunningAddress2$06 = $30;
    }
    $18 = ($19>>>0)<($15>>>0);
    $or$cond = $20 & $18;
    if ($or$cond) {
     $RunningAddress$09 = $RunningAddress$2;$Sorted$08 = $19;
    } else {
     break;
    }
   }
  }
 } while(0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$6);
 __ZN5physx2Gu17RadixSortBufferedD2Ev($RS);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z23sweepCCTCapsule_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$lss,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $lss = $lss|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0);
 var $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0;
 var $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $box = 0, $closest = 0, $closest2 = 0, $movedCaps = 0, $newSphereCenter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $box = sp + 64|0;
 $0 = sp + 126|0;
 $newSphereCenter = sp + 12|0;
 $closest = sp + 24|0;
 $1 = sp + 124|0;
 $movedCaps = sp + 36|0;
 $closest2 = sp;
 $2 = Math_fround(HEAPF32[$lss>>2]);
 $3 = (($lss) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = $2 == $4;
 if ($5) {
  $6 = (($lss) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($lss) + 16|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $7 == $9;
  if ($10) {
   $11 = (($lss) + 8|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = (($lss) + 20|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = $12 == $14;
   if ($15) {
    $16 = (($geom) + 4|0);
    $17 = (($pose) + 16|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = (($box) + 36|0);
    HEAPF32[$19>>2] = $18;
    $20 = (($pose) + 20|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = (($box) + 40|0);
    HEAPF32[$22>>2] = $21;
    $23 = (($pose) + 24|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = (($box) + 44|0);
    HEAPF32[$25>>2] = $24;
    $26 = Math_fround(HEAPF32[$16>>2]);
    $27 = (($box) + 48|0);
    HEAPF32[$27>>2] = $26;
    $28 = (($geom) + 8|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = (($box) + 52|0);
    HEAPF32[$30>>2] = $29;
    $31 = (($geom) + 12|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = (($box) + 56|0);
    HEAPF32[$33>>2] = $32;
    $34 = Math_fround(HEAPF32[$pose>>2]);
    $35 = (($pose) + 4|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = (($pose) + 8|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = (($pose) + 12|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = Math_fround($34 + $34);
    $42 = Math_fround($36 + $36);
    $43 = Math_fround($38 + $38);
    $44 = Math_fround($34 * $41);
    $45 = Math_fround($36 * $42);
    $46 = Math_fround($38 * $43);
    $47 = Math_fround($41 * $36);
    $48 = Math_fround($41 * $38);
    $49 = Math_fround($41 * $40);
    $50 = Math_fround($42 * $38);
    $51 = Math_fround($42 * $40);
    $52 = Math_fround($43 * $40);
    $53 = Math_fround(Math_fround(1.0) - $45);
    $54 = Math_fround($53 - $46);
    $55 = Math_fround($47 + $52);
    $56 = Math_fround($48 - $51);
    $57 = Math_fround($47 - $52);
    $58 = Math_fround(Math_fround(1.0) - $44);
    $59 = Math_fround($58 - $46);
    $60 = Math_fround($50 + $49);
    $61 = Math_fround($48 + $51);
    $62 = Math_fround($50 - $49);
    $63 = Math_fround($58 - $45);
    HEAPF32[$box>>2] = $54;
    $64 = (($box) + 4|0);
    HEAPF32[$64>>2] = $55;
    $65 = (($box) + 8|0);
    HEAPF32[$65>>2] = $56;
    $66 = (($box) + 12|0);
    HEAPF32[$66>>2] = $57;
    $67 = (($box) + 16|0);
    HEAPF32[$67>>2] = $59;
    $68 = (($box) + 20|0);
    HEAPF32[$68>>2] = $60;
    $69 = (($box) + 24|0);
    HEAPF32[$69>>2] = $61;
    $70 = (($box) + 28|0);
    HEAPF32[$70>>2] = $62;
    $71 = (($box) + 32|0);
    HEAPF32[$71>>2] = $63;
    $72 = (($lss) + 24|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = (($sweepHit) + 40|0);
    $75 = (($sweepHit) + 28|0);
    $76 = HEAP16[$hintFlags>>1]|0;
    HEAP16[$0>>1] = $76;
    $77 = (__ZN5physx2Gu14sweepBoxSphereERKNS0_3BoxEfRKNS_6PxVec3ES6_fRfRS4_NS_7PxFlagsINS_9PxHitFlag4EnumEtEE($box,$73,$lss,$unitDir,$distance,$74,$75,$0)|0);
    if (!($77)) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $78 = Math_fround(HEAPF32[$75>>2]);
    $79 = Math_fround(-$78);
    $80 = (($sweepHit) + 32|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = Math_fround(-$81);
    $83 = (($sweepHit) + 36|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = Math_fround(-$84);
    HEAPF32[$75>>2] = $79;
    HEAPF32[$80>>2] = $82;
    HEAPF32[$83>>2] = $85;
    $86 = (($sweepHit) + 12|0);
    HEAP16[$86>>1] = 6;
    $87 = HEAP16[$hintFlags>>1]|0;
    $88 = $87 & 1;
    $89 = ($88<<16>>16)==(0);
    if ($89) {
     $$1 = 1;
     STACKTOP = sp;return ($$1|0);
    }
    $90 = Math_fround(HEAPF32[$74>>2]);
    $91 = Math_fround(HEAPF32[$unitDir>>2]);
    $92 = Math_fround($90 * $91);
    $93 = (($unitDir) + 4|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $95 = Math_fround($90 * $94);
    $96 = (($unitDir) + 8|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = Math_fround($90 * $97);
    $99 = Math_fround(HEAPF32[$lss>>2]);
    $100 = Math_fround($92 + $99);
    $101 = Math_fround(HEAPF32[$6>>2]);
    $102 = Math_fround($95 + $101);
    $103 = Math_fround(HEAPF32[$11>>2]);
    $104 = Math_fround($98 + $103);
    HEAPF32[$newSphereCenter>>2] = $100;
    $105 = (($newSphereCenter) + 4|0);
    HEAPF32[$105>>2] = $102;
    $106 = (($newSphereCenter) + 8|0);
    HEAPF32[$106>>2] = $104;
    $107 = (($box) + 36|0);
    $108 = (($box) + 48|0);
    (Math_fround(__ZN5physx2Gu23distancePointBoxSquaredERKNS_6PxVec3ES3_S3_RKNS_7PxMat33EPS1_($newSphereCenter,$107,$108,$box,$closest)));
    $109 = Math_fround(HEAPF32[$closest>>2]);
    $110 = Math_fround(HEAPF32[$box>>2]);
    $111 = Math_fround($109 * $110);
    $112 = Math_fround(HEAPF32[$64>>2]);
    $113 = Math_fround($109 * $112);
    $114 = Math_fround(HEAPF32[$65>>2]);
    $115 = Math_fround($109 * $114);
    $116 = (($closest) + 4|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = Math_fround(HEAPF32[$66>>2]);
    $119 = Math_fround($117 * $118);
    $120 = Math_fround(HEAPF32[$67>>2]);
    $121 = Math_fround($117 * $120);
    $122 = Math_fround(HEAPF32[$68>>2]);
    $123 = Math_fround($117 * $122);
    $124 = Math_fround($111 + $119);
    $125 = Math_fround($113 + $121);
    $126 = Math_fround($115 + $123);
    $127 = (($closest) + 8|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $129 = Math_fround(HEAPF32[$69>>2]);
    $130 = Math_fround($128 * $129);
    $131 = Math_fround(HEAPF32[$70>>2]);
    $132 = Math_fround($128 * $131);
    $133 = Math_fround(HEAPF32[$71>>2]);
    $134 = Math_fround($128 * $133);
    $135 = Math_fround($124 + $130);
    $136 = Math_fround($125 + $132);
    $137 = Math_fround($126 + $134);
    HEAPF32[$closest>>2] = $135;
    HEAPF32[$116>>2] = $136;
    HEAPF32[$127>>2] = $137;
    $138 = Math_fround(HEAPF32[$107>>2]);
    $139 = Math_fround($135 + $138);
    $140 = Math_fround(HEAPF32[$22>>2]);
    $141 = Math_fround($136 + $140);
    $142 = Math_fround(HEAPF32[$25>>2]);
    $143 = Math_fround($137 + $142);
    $144 = (($sweepHit) + 16|0);
    HEAPF32[$144>>2] = $139;
    $145 = (($sweepHit) + 20|0);
    HEAPF32[$145>>2] = $141;
    $146 = (($sweepHit) + 24|0);
    HEAPF32[$146>>2] = $143;
    $147 = HEAP16[$86>>1]|0;
    $148 = $147&65535;
    $149 = $148 | 1;
    $150 = $149&65535;
    HEAP16[$86>>1] = $150;
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $151 = (($geom) + 4|0);
 $152 = (($sweepHit) + 16|0);
 $153 = (($sweepHit) + 40|0);
 $154 = (($sweepHit) + 28|0);
 $155 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$1>>1] = $155;
 $156 = (__ZN5physx2Gu15sweepCapsuleBoxERKNS0_7CapsuleERKNS_11PxTransformERKNS_6PxVec3ES9_fRS7_RfSA_NS_7PxFlagsINS_9PxHitFlag4EnumEtEE($lss,$pose,$151,$unitDir,$distance,$152,$153,$154,$1)|0);
 if (!($156)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $157 = (($sweepHit) + 12|0);
 HEAP16[$157>>1] = 6;
 $158 = HEAP16[$hintFlags>>1]|0;
 $159 = $158 & 1;
 $160 = ($159<<16>>16)==(0);
 if ($160) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $161 = Math_fround(HEAPF32[$153>>2]);
 $162 = $161 != Math_fround(0.0);
 if (!($162)) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $163 = Math_fround(HEAPF32[$lss>>2]);
 $164 = (($movedCaps) + 4|0);
 $165 = (($lss) + 4|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = (($movedCaps) + 8|0);
 $168 = (($lss) + 8|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($movedCaps) + 12|0);
 $171 = Math_fround(HEAPF32[$3>>2]);
 $172 = (($movedCaps) + 16|0);
 $173 = (($lss) + 16|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($movedCaps) + 20|0);
 $176 = (($lss) + 20|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = (($movedCaps) + 24|0);
 $179 = (($lss) + 24|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 HEAPF32[$178>>2] = $180;
 $181 = Math_fround(HEAPF32[$unitDir>>2]);
 $182 = Math_fround($161 * $181);
 $183 = (($unitDir) + 4|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = Math_fround($161 * $184);
 $186 = (($unitDir) + 8|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = Math_fround($161 * $187);
 $189 = Math_fround($182 + $163);
 HEAPF32[$movedCaps>>2] = $189;
 $190 = Math_fround($185 + $166);
 HEAPF32[$164>>2] = $190;
 $191 = Math_fround($188 + $169);
 HEAPF32[$167>>2] = $191;
 $192 = Math_fround($182 + $171);
 HEAPF32[$170>>2] = $192;
 $193 = Math_fround($185 + $174);
 HEAPF32[$172>>2] = $193;
 $194 = Math_fround($188 + $177);
 HEAPF32[$175>>2] = $194;
 $195 = (($pose) + 16|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($box) + 36|0);
 HEAPF32[$197>>2] = $196;
 $198 = (($pose) + 20|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($box) + 40|0);
 HEAPF32[$200>>2] = $199;
 $201 = (($pose) + 24|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($box) + 44|0);
 HEAPF32[$203>>2] = $202;
 $204 = Math_fround(HEAPF32[$151>>2]);
 $205 = (($box) + 48|0);
 HEAPF32[$205>>2] = $204;
 $206 = (($geom) + 8|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = (($box) + 52|0);
 HEAPF32[$208>>2] = $207;
 $209 = (($geom) + 12|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($box) + 56|0);
 HEAPF32[$211>>2] = $210;
 $212 = Math_fround(HEAPF32[$pose>>2]);
 $213 = (($pose) + 4|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = (($pose) + 8|0);
 $216 = Math_fround(HEAPF32[$215>>2]);
 $217 = (($pose) + 12|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 $219 = Math_fround($212 + $212);
 $220 = Math_fround($214 + $214);
 $221 = Math_fround($216 + $216);
 $222 = Math_fround($212 * $219);
 $223 = Math_fround($214 * $220);
 $224 = Math_fround($216 * $221);
 $225 = Math_fround($219 * $214);
 $226 = Math_fround($219 * $216);
 $227 = Math_fround($219 * $218);
 $228 = Math_fround($220 * $216);
 $229 = Math_fround($220 * $218);
 $230 = Math_fround($221 * $218);
 $231 = Math_fround(Math_fround(1.0) - $223);
 $232 = Math_fround($231 - $224);
 $233 = Math_fround($225 + $230);
 $234 = Math_fround($226 - $229);
 $235 = Math_fround($225 - $230);
 $236 = Math_fround(Math_fround(1.0) - $222);
 $237 = Math_fround($236 - $224);
 $238 = Math_fround($228 + $227);
 $239 = Math_fround($226 + $229);
 $240 = Math_fround($228 - $227);
 $241 = Math_fround($236 - $223);
 HEAPF32[$box>>2] = $232;
 $242 = (($box) + 4|0);
 HEAPF32[$242>>2] = $233;
 $243 = (($box) + 8|0);
 HEAPF32[$243>>2] = $234;
 $244 = (($box) + 12|0);
 HEAPF32[$244>>2] = $235;
 $245 = (($box) + 16|0);
 HEAPF32[$245>>2] = $237;
 $246 = (($box) + 20|0);
 HEAPF32[$246>>2] = $238;
 $247 = (($box) + 24|0);
 HEAPF32[$247>>2] = $239;
 $248 = (($box) + 28|0);
 HEAPF32[$248>>2] = $240;
 $249 = (($box) + 32|0);
 HEAPF32[$249>>2] = $241;
 $250 = (($movedCaps) + 12|0);
 $251 = (($box) + 36|0);
 $252 = (($box) + 48|0);
 (Math_fround(__ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($movedCaps,$250,$251,$252,$box,0,$closest2)));
 $253 = Math_fround(HEAPF32[$closest2>>2]);
 $254 = Math_fround($253 * Math_fround(2.0));
 $255 = (($closest2) + 4|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 $257 = Math_fround($256 * Math_fround(2.0));
 $258 = (($closest2) + 8|0);
 $259 = Math_fround(HEAPF32[$258>>2]);
 $260 = Math_fround($259 * Math_fround(2.0));
 $261 = Math_fround(HEAPF32[$217>>2]);
 $262 = Math_fround($261 * $261);
 $263 = Math_fround($262 + Math_fround(-0.5));
 $264 = Math_fround(HEAPF32[$pose>>2]);
 $265 = Math_fround($254 * $264);
 $266 = Math_fround(HEAPF32[$213>>2]);
 $267 = Math_fround($257 * $266);
 $268 = Math_fround($265 + $267);
 $269 = Math_fround(HEAPF32[$215>>2]);
 $270 = Math_fround($260 * $269);
 $271 = Math_fround($268 + $270);
 $272 = Math_fround($254 * $263);
 $273 = Math_fround($260 * $266);
 $274 = Math_fround($257 * $269);
 $275 = Math_fround($273 - $274);
 $276 = Math_fround($261 * $275);
 $277 = Math_fround($272 + $276);
 $278 = Math_fround($264 * $271);
 $279 = Math_fround($278 + $277);
 $280 = Math_fround($257 * $263);
 $281 = Math_fround($254 * $269);
 $282 = Math_fround($260 * $264);
 $283 = Math_fround($281 - $282);
 $284 = Math_fround($261 * $283);
 $285 = Math_fround($280 + $284);
 $286 = Math_fround($266 * $271);
 $287 = Math_fround($286 + $285);
 $288 = Math_fround($260 * $263);
 $289 = Math_fround($257 * $264);
 $290 = Math_fround($254 * $266);
 $291 = Math_fround($289 - $290);
 $292 = Math_fround($261 * $291);
 $293 = Math_fround($288 + $292);
 $294 = Math_fround($269 * $271);
 $295 = Math_fround($293 + $294);
 HEAPF32[$closest2>>2] = $279;
 HEAPF32[$255>>2] = $287;
 HEAPF32[$258>>2] = $295;
 $296 = Math_fround(HEAPF32[$195>>2]);
 $297 = Math_fround($279 + $296);
 $298 = Math_fround(HEAPF32[$198>>2]);
 $299 = Math_fround($287 + $298);
 $300 = Math_fround(HEAPF32[$201>>2]);
 $301 = Math_fround($295 + $300);
 HEAPF32[$152>>2] = $297;
 $302 = (($sweepHit) + 20|0);
 HEAPF32[$302>>2] = $299;
 $303 = (($sweepHit) + 24|0);
 HEAPF32[$303>>2] = $301;
 $304 = HEAP16[$157>>1]|0;
 $305 = $304&65535;
 $306 = $305 | 1;
 $307 = $306&65535;
 HEAP16[$157>>1] = $307;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __Z22sweepCCTBox_SphereGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0);
 var $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $closest = 0, $newSphereCenter = 0, $relBox = 0, $unitDir$idx$val = Math_fround(0), $unitDir$idx1$val = Math_fround(0);
 var $unitDir$idx2$val = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $relBox = sp + 48|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = sp + 108|0;
 $newSphereCenter = sp + 36|0;
 $closest = sp + 24|0;
 $3 = (($box) + 36|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pose) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($box) + 40|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($pose) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($box) + 44|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($pose) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 - $16);
 $18 = Math_fround(HEAPF32[$box>>2]);
 HEAPF32[$relBox>>2] = $18;
 $19 = (($relBox) + 4|0);
 $20 = (($box) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 $22 = (($relBox) + 8|0);
 $23 = (($box) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$22>>2] = $24;
 $25 = (($relBox) + 12|0);
 $26 = (($box) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($relBox) + 16|0);
 $29 = (($box) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($relBox) + 20|0);
 $32 = (($box) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($relBox) + 24|0);
 $35 = (($box) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 $37 = (($relBox) + 28|0);
 $38 = (($box) + 28|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$37>>2] = $39;
 $40 = (($relBox) + 32|0);
 $41 = (($box) + 32|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$40>>2] = $42;
 $43 = (($relBox) + 36|0);
 HEAPF32[$43>>2] = $7;
 $44 = (($relBox) + 40|0);
 HEAPF32[$44>>2] = $12;
 $45 = (($relBox) + 44|0);
 HEAPF32[$45>>2] = $17;
 $46 = (($relBox) + 48|0);
 $47 = (($box) + 48|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$46>>2] = $48;
 $49 = (($relBox) + 52|0);
 $50 = (($box) + 52|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$49>>2] = $51;
 $52 = (($relBox) + 56|0);
 $53 = (($box) + 56|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 HEAPF32[$52>>2] = $54;
 $55 = (($geom) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 + $inflation);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $58 = (($0) + 4|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($0) + 8|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = Math_fround(HEAPF32[$unitDir>>2]);
 $61 = Math_fround(-$60);
 $62 = (($unitDir) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(-$63);
 $65 = (($unitDir) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround(-$66);
 HEAPF32[$1>>2] = $61;
 $68 = (($1) + 4|0);
 HEAPF32[$68>>2] = $64;
 $69 = (($1) + 8|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($sweepHit) + 40|0);
 $71 = (($sweepHit) + 28|0);
 $72 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$2>>1] = $72;
 $73 = (__ZN5physx2Gu14sweepBoxSphereERKNS0_3BoxEfRKNS_6PxVec3ES6_fRfRS4_NS_7PxFlagsINS_9PxHitFlag4EnumEtEE($relBox,$57,$0,$1,$distance,$70,$71,$2)|0);
 if (!($73)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $74 = (($sweepHit) + 12|0);
 HEAP16[$74>>1] = 6;
 $75 = HEAP16[$hintFlags>>1]|0;
 $76 = $75 & 1;
 $77 = ($76<<16>>16)==(0);
 if ($77) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = Math_fround(HEAPF32[$70>>2]);
 $unitDir$idx$val = Math_fround(HEAPF32[$unitDir>>2]);
 $unitDir$idx1$val = Math_fround(HEAPF32[$62>>2]);
 $unitDir$idx2$val = Math_fround(HEAPF32[$65>>2]);
 $79 = Math_fround($78 * $unitDir$idx$val);
 $80 = Math_fround($78 * $unitDir$idx1$val);
 $81 = Math_fround($78 * $unitDir$idx2$val);
 $82 = Math_fround(-$79);
 $83 = Math_fround(-$80);
 $84 = Math_fround(-$81);
 HEAPF32[$newSphereCenter>>2] = $82;
 $85 = (($newSphereCenter) + 4|0);
 HEAPF32[$85>>2] = $83;
 $86 = (($newSphereCenter) + 8|0);
 HEAPF32[$86>>2] = $84;
 $87 = (($relBox) + 36|0);
 $88 = (($relBox) + 48|0);
 (Math_fround(__ZN5physx2Gu23distancePointBoxSquaredERKNS_6PxVec3ES3_S3_RKNS_7PxMat33EPS1_($newSphereCenter,$87,$88,$relBox,$closest)));
 $89 = Math_fround(HEAPF32[$closest>>2]);
 $90 = Math_fround(HEAPF32[$relBox>>2]);
 $91 = Math_fround($89 * $90);
 $92 = Math_fround(HEAPF32[$19>>2]);
 $93 = Math_fround($89 * $92);
 $94 = Math_fround(HEAPF32[$22>>2]);
 $95 = Math_fround($89 * $94);
 $96 = (($closest) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround(HEAPF32[$25>>2]);
 $99 = Math_fround($97 * $98);
 $100 = Math_fround(HEAPF32[$28>>2]);
 $101 = Math_fround($97 * $100);
 $102 = Math_fround(HEAPF32[$31>>2]);
 $103 = Math_fround($97 * $102);
 $104 = Math_fround($91 + $99);
 $105 = Math_fround($93 + $101);
 $106 = Math_fround($95 + $103);
 $107 = (($closest) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround(HEAPF32[$34>>2]);
 $110 = Math_fround($108 * $109);
 $111 = Math_fround(HEAPF32[$37>>2]);
 $112 = Math_fround($108 * $111);
 $113 = Math_fround(HEAPF32[$40>>2]);
 $114 = Math_fround($108 * $113);
 $115 = Math_fround($104 + $110);
 $116 = Math_fround($105 + $112);
 $117 = Math_fround($106 + $114);
 $118 = Math_fround(HEAPF32[$3>>2]);
 $119 = Math_fround($115 + $118);
 $120 = Math_fround(HEAPF32[$8>>2]);
 $121 = Math_fround($116 + $120);
 $122 = Math_fround(HEAPF32[$13>>2]);
 $123 = Math_fround($117 + $122);
 $124 = Math_fround($79 + $119);
 $125 = Math_fround($80 + $121);
 $126 = Math_fround($81 + $123);
 $127 = (($sweepHit) + 16|0);
 HEAPF32[$127>>2] = $124;
 $128 = (($sweepHit) + 20|0);
 HEAPF32[$128>>2] = $125;
 $129 = (($sweepHit) + 24|0);
 HEAPF32[$129>>2] = $126;
 $130 = HEAP16[$74>>1]|0;
 $131 = $130&65535;
 $132 = $131 | 1;
 $133 = $132&65535;
 HEAP16[$74>>1] = $133;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z23sweepCCTBox_CapsuleGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $boxWorldPose = 0, $capsule = 0, $closest = 0, $n = 0, $negDir = 0, $relBox = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $0 = sp + 152|0;
 $relBox = sp;
 $n = sp + 60|0;
 $negDir = sp + 72|0;
 $capsule = sp + 84|0;
 $boxWorldPose = sp + 112|0;
 $1 = sp + 168|0;
 $closest = sp + 140|0;
 $2 = Math_fround(HEAPF32[$pose>>2]);
 $3 = (($pose) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pose) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($pose) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($box) + 36|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($pose) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = (($box) + 40|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($pose) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = (($box) + 44|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($pose) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 - $22);
 $24 = Math_fround(HEAPF32[$box>>2]);
 HEAPF32[$relBox>>2] = $24;
 $25 = (($relBox) + 4|0);
 $26 = (($box) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($relBox) + 8|0);
 $29 = (($box) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($relBox) + 12|0);
 $32 = (($box) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($relBox) + 16|0);
 $35 = (($box) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 $37 = (($relBox) + 20|0);
 $38 = (($box) + 20|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$37>>2] = $39;
 $40 = (($relBox) + 24|0);
 $41 = (($box) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$40>>2] = $42;
 $43 = (($relBox) + 28|0);
 $44 = (($box) + 28|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 HEAPF32[$43>>2] = $45;
 $46 = (($relBox) + 32|0);
 $47 = (($box) + 32|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$46>>2] = $48;
 $49 = (($relBox) + 36|0);
 HEAPF32[$49>>2] = $13;
 $50 = (($relBox) + 40|0);
 HEAPF32[$50>>2] = $18;
 $51 = (($relBox) + 44|0);
 HEAPF32[$51>>2] = $23;
 $52 = (($relBox) + 48|0);
 $53 = (($box) + 48|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 HEAPF32[$52>>2] = $54;
 $55 = (($relBox) + 52|0);
 $56 = (($box) + 52|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 HEAPF32[$55>>2] = $57;
 $58 = (($relBox) + 56|0);
 $59 = (($box) + 56|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 HEAPF32[$58>>2] = $60;
 $61 = Math_fround(HEAPF32[$unitDir>>2]);
 $62 = Math_fround(-$61);
 $63 = (($unitDir) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(-$64);
 $66 = (($unitDir) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround(-$67);
 HEAPF32[$negDir>>2] = $62;
 $69 = (($negDir) + 4|0);
 HEAPF32[$69>>2] = $65;
 $70 = (($negDir) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = Math_fround($2 * Math_fround(2.0));
 $72 = Math_fround($8 * Math_fround(2.0));
 $73 = Math_fround($8 * $72);
 $74 = Math_fround($73 + Math_fround(-1.0));
 $75 = Math_fround($2 * $71);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($6 * $72);
 $78 = Math_fround($71 * $4);
 $79 = Math_fround($78 + $77);
 $80 = Math_fround($4 * $72);
 $81 = Math_fround($71 * $6);
 $82 = Math_fround($81 - $80);
 $83 = (($geom) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($76 * $84);
 $86 = Math_fround($79 * $84);
 $87 = Math_fround($82 * $84);
 $88 = Math_fround($85 + Math_fround(0.0));
 $89 = Math_fround($86 + Math_fround(0.0));
 $90 = Math_fround($87 + Math_fround(0.0));
 HEAPF32[$capsule>>2] = $88;
 $91 = (($capsule) + 4|0);
 HEAPF32[$91>>2] = $89;
 $92 = (($capsule) + 8|0);
 HEAPF32[$92>>2] = $90;
 $93 = Math_fround(Math_fround(0.0) - $85);
 $94 = Math_fround(Math_fround(0.0) - $86);
 $95 = Math_fround(Math_fround(0.0) - $87);
 $96 = (($capsule) + 12|0);
 HEAPF32[$96>>2] = $93;
 $97 = (($capsule) + 16|0);
 HEAPF32[$97>>2] = $94;
 $98 = (($capsule) + 20|0);
 HEAPF32[$98>>2] = $95;
 $99 = (($geom) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($capsule) + 24|0);
 HEAPF32[$101>>2] = $100;
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$relBox);
 $102 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$boxWorldPose>>2] = $102;
 $103 = (($boxWorldPose) + 4|0);
 $104 = (($0) + 4|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 HEAPF32[$103>>2] = $105;
 $106 = (($boxWorldPose) + 8|0);
 $107 = (($0) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 HEAPF32[$106>>2] = $108;
 $109 = (($boxWorldPose) + 12|0);
 $110 = (($0) + 12|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 HEAPF32[$109>>2] = $111;
 $112 = (($boxWorldPose) + 16|0);
 $113 = Math_fround(HEAPF32[$49>>2]);
 HEAPF32[$112>>2] = $113;
 $114 = (($boxWorldPose) + 20|0);
 $115 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$114>>2] = $115;
 $116 = (($boxWorldPose) + 24|0);
 $117 = Math_fround(HEAPF32[$51>>2]);
 HEAPF32[$116>>2] = $117;
 $118 = (($relBox) + 48|0);
 $119 = (($sweepHit) + 16|0);
 $120 = (($sweepHit) + 40|0);
 $121 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$1>>1] = $121;
 $122 = (__ZN5physx2Gu15sweepCapsuleBoxERKNS0_7CapsuleERKNS_11PxTransformERKNS_6PxVec3ES9_fRS7_RfSA_NS_7PxFlagsINS_9PxHitFlag4EnumEtEE($capsule,$boxWorldPose,$118,$negDir,$distance,$119,$120,$n,$1)|0);
 if (!($122)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $123 = Math_fround(HEAPF32[$n>>2]);
 $124 = Math_fround(-$123);
 $125 = (($n) + 4|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround(-$126);
 $128 = (($n) + 8|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround(-$129);
 $131 = (($sweepHit) + 28|0);
 HEAPF32[$131>>2] = $124;
 $132 = (($sweepHit) + 32|0);
 HEAPF32[$132>>2] = $127;
 $133 = (($sweepHit) + 36|0);
 HEAPF32[$133>>2] = $130;
 $134 = (($sweepHit) + 12|0);
 HEAP16[$134>>1] = 6;
 $135 = HEAP16[$hintFlags>>1]|0;
 $136 = $135 & 1;
 $137 = ($136<<16>>16)==(0);
 if ($137) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $138 = Math_fround(HEAPF32[$120>>2]);
 $139 = $138 != Math_fround(0.0);
 if (!($139)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $140 = (($relBox) + 36|0);
 $141 = Math_fround(HEAPF32[$unitDir>>2]);
 $142 = Math_fround($138 * $141);
 $143 = Math_fround(HEAPF32[$63>>2]);
 $144 = Math_fround($138 * $143);
 $145 = Math_fround(HEAPF32[$66>>2]);
 $146 = Math_fround($138 * $145);
 $147 = Math_fround(HEAPF32[$140>>2]);
 $148 = Math_fround($142 + $147);
 HEAPF32[$140>>2] = $148;
 $149 = Math_fround(HEAPF32[$50>>2]);
 $150 = Math_fround($144 + $149);
 HEAPF32[$50>>2] = $150;
 $151 = Math_fround(HEAPF32[$51>>2]);
 $152 = Math_fround($146 + $151);
 HEAPF32[$51>>2] = $152;
 $153 = (($capsule) + 12|0);
 (Math_fround(__ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($capsule,$153,$140,$118,$relBox,0,$closest)));
 $154 = Math_fround(HEAPF32[$closest>>2]);
 $155 = Math_fround(HEAPF32[$relBox>>2]);
 $156 = Math_fround($154 * $155);
 $157 = Math_fround(HEAPF32[$25>>2]);
 $158 = Math_fround($154 * $157);
 $159 = Math_fround(HEAPF32[$28>>2]);
 $160 = Math_fround($154 * $159);
 $161 = (($closest) + 4|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = Math_fround(HEAPF32[$31>>2]);
 $164 = Math_fround($162 * $163);
 $165 = Math_fround(HEAPF32[$34>>2]);
 $166 = Math_fround($162 * $165);
 $167 = Math_fround(HEAPF32[$37>>2]);
 $168 = Math_fround($162 * $167);
 $169 = Math_fround($156 + $164);
 $170 = Math_fround($158 + $166);
 $171 = Math_fround($160 + $168);
 $172 = (($closest) + 8|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround(HEAPF32[$40>>2]);
 $175 = Math_fround($173 * $174);
 $176 = Math_fround(HEAPF32[$43>>2]);
 $177 = Math_fround($173 * $176);
 $178 = Math_fround(HEAPF32[$46>>2]);
 $179 = Math_fround($173 * $178);
 $180 = Math_fround($169 + $175);
 $181 = Math_fround($170 + $177);
 $182 = Math_fround($171 + $179);
 $183 = Math_fround(HEAPF32[$49>>2]);
 $184 = Math_fround($180 + $183);
 $185 = Math_fround(HEAPF32[$50>>2]);
 $186 = Math_fround($181 + $185);
 $187 = Math_fround(HEAPF32[$51>>2]);
 $188 = Math_fround($182 + $187);
 $189 = Math_fround(HEAPF32[$11>>2]);
 $190 = Math_fround($184 + $189);
 $191 = Math_fround(HEAPF32[$16>>2]);
 $192 = Math_fround($186 + $191);
 $193 = Math_fround(HEAPF32[$21>>2]);
 $194 = Math_fround($188 + $193);
 HEAPF32[$119>>2] = $190;
 $195 = (($sweepHit) + 20|0);
 HEAPF32[$195>>2] = $192;
 $196 = (($sweepHit) + 24|0);
 HEAPF32[$196>>2] = $194;
 $197 = HEAP16[$134>>1]|0;
 $198 = $197&65535;
 $199 = $198 | 1;
 $200 = $199&65535;
 HEAP16[$134>>1] = $200;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z19sweepCCTBox_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $relBox = 0, $staticBox = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $relBox = sp + 60|0;
 $staticBox = sp;
 $0 = sp + 120|0;
 $1 = (($box) + 36|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($pose) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 - $4);
 $6 = (($box) + 40|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($pose) + 20|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 - $9);
 $11 = (($box) + 44|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($pose) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 - $14);
 $16 = Math_fround(HEAPF32[$box>>2]);
 HEAPF32[$relBox>>2] = $16;
 $17 = (($relBox) + 4|0);
 $18 = (($box) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$17>>2] = $19;
 $20 = (($relBox) + 8|0);
 $21 = (($box) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = (($relBox) + 12|0);
 $24 = (($box) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$23>>2] = $25;
 $26 = (($relBox) + 16|0);
 $27 = (($box) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$26>>2] = $28;
 $29 = (($relBox) + 20|0);
 $30 = (($box) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$29>>2] = $31;
 $32 = (($relBox) + 24|0);
 $33 = (($box) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$32>>2] = $34;
 $35 = (($relBox) + 28|0);
 $36 = (($box) + 28|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 HEAPF32[$35>>2] = $37;
 $38 = (($relBox) + 32|0);
 $39 = (($box) + 32|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 HEAPF32[$38>>2] = $40;
 $41 = (($relBox) + 36|0);
 HEAPF32[$41>>2] = $5;
 $42 = (($relBox) + 40|0);
 HEAPF32[$42>>2] = $10;
 $43 = (($relBox) + 44|0);
 HEAPF32[$43>>2] = $15;
 $44 = (($relBox) + 48|0);
 $45 = (($box) + 48|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 HEAPF32[$44>>2] = $46;
 $47 = (($relBox) + 52|0);
 $48 = (($box) + 52|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$47>>2] = $49;
 $50 = (($relBox) + 56|0);
 $51 = (($box) + 56|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 HEAPF32[$50>>2] = $52;
 $53 = (($geom) + 4|0);
 $54 = (($staticBox) + 36|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($staticBox) + 40|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($staticBox) + 44|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = Math_fround(HEAPF32[$53>>2]);
 $58 = (($staticBox) + 48|0);
 HEAPF32[$58>>2] = $57;
 $59 = (($geom) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($staticBox) + 52|0);
 HEAPF32[$61>>2] = $60;
 $62 = (($geom) + 12|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($staticBox) + 56|0);
 HEAPF32[$64>>2] = $63;
 $65 = Math_fround(HEAPF32[$pose>>2]);
 $66 = (($pose) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($pose) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($pose) + 12|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($65 + $65);
 $73 = Math_fround($67 + $67);
 $74 = Math_fround($69 + $69);
 $75 = Math_fround($65 * $72);
 $76 = Math_fround($67 * $73);
 $77 = Math_fround($69 * $74);
 $78 = Math_fround($72 * $67);
 $79 = Math_fround($72 * $69);
 $80 = Math_fround($72 * $71);
 $81 = Math_fround($73 * $69);
 $82 = Math_fround($73 * $71);
 $83 = Math_fround($74 * $71);
 $84 = Math_fround(Math_fround(1.0) - $76);
 $85 = Math_fround($84 - $77);
 $86 = Math_fround($78 + $83);
 $87 = Math_fround($79 - $82);
 $88 = Math_fround($78 - $83);
 $89 = Math_fround(Math_fround(1.0) - $75);
 $90 = Math_fround($89 - $77);
 $91 = Math_fround($81 + $80);
 $92 = Math_fround($79 + $82);
 $93 = Math_fround($81 - $80);
 $94 = Math_fround($89 - $76);
 HEAPF32[$staticBox>>2] = $85;
 $95 = (($staticBox) + 4|0);
 HEAPF32[$95>>2] = $86;
 $96 = (($staticBox) + 8|0);
 HEAPF32[$96>>2] = $87;
 $97 = (($staticBox) + 12|0);
 HEAPF32[$97>>2] = $88;
 $98 = (($staticBox) + 16|0);
 HEAPF32[$98>>2] = $90;
 $99 = (($staticBox) + 20|0);
 HEAPF32[$99>>2] = $91;
 $100 = (($staticBox) + 24|0);
 HEAPF32[$100>>2] = $92;
 $101 = (($staticBox) + 28|0);
 HEAPF32[$101>>2] = $93;
 $102 = (($staticBox) + 32|0);
 HEAPF32[$102>>2] = $94;
 $103 = (($sweepHit) + 16|0);
 $104 = (($sweepHit) + 28|0);
 $105 = (($sweepHit) + 40|0);
 $106 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$0>>1] = $106;
 $107 = (__ZN5physx2Gu11sweepBoxBoxERKNS0_3BoxES3_RKNS_6PxVec3EfRS4_S7_RfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($relBox,$staticBox,$unitDir,$distance,$103,$104,$105,$0)|0);
 if (!($107)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $108 = Math_fround(HEAPF32[$3>>2]);
 $109 = Math_fround(HEAPF32[$103>>2]);
 $110 = Math_fround($108 + $109);
 HEAPF32[$103>>2] = $110;
 $111 = Math_fround(HEAPF32[$8>>2]);
 $112 = (($sweepHit) + 20|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($111 + $113);
 HEAPF32[$112>>2] = $114;
 $115 = Math_fround(HEAPF32[$13>>2]);
 $116 = (($sweepHit) + 24|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($115 + $117);
 HEAPF32[$116>>2] = $118;
 $119 = (($sweepHit) + 12|0);
 HEAP16[$119>>1] = 7;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z27sweepCCTBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$tr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0);
 var $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0;
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $bounds = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0);
 var $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0), $hfUtil = 0, $phitmp = 0, $sweptBox = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 108|0;
 $sweptBox = sp;
 $bounds = sp + 64|0;
 $hfUtil = sp + 88|0;
 $1 = (($box) + 48|0);
 $2 = (($box) + 36|0);
 __ZN5physx2Gu15computeSweptBoxERNS0_3BoxERKNS_6PxVec3ES5_RKNS_7PxMat33ES5_f($sweptBox,$1,$2,$box,$unitDir,$distance);
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$sweptBox);
 $3 = Math_fround(HEAPF32[$0>>2]);
 $4 = (($0) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($0) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($sweptBox) + 36|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($sweptBox) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($sweptBox) + 44|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 + $3);
 $17 = Math_fround($5 + $5);
 $18 = Math_fround($7 + $7);
 $19 = Math_fround($3 * $16);
 $20 = Math_fround($5 * $17);
 $21 = Math_fround($7 * $18);
 $22 = Math_fround($16 * $5);
 $23 = Math_fround($16 * $7);
 $24 = Math_fround($16 * $9);
 $25 = Math_fround($17 * $7);
 $26 = Math_fround($17 * $9);
 $27 = Math_fround($18 * $9);
 $28 = Math_fround(Math_fround(1.0) - $20);
 $29 = Math_fround($28 - $21);
 $30 = Math_fround($22 + $27);
 $31 = Math_fround($23 - $26);
 $32 = Math_fround($22 - $27);
 $33 = Math_fround(Math_fround(1.0) - $19);
 $34 = Math_fround($33 - $21);
 $35 = Math_fround($25 + $24);
 $36 = Math_fround($23 + $26);
 $37 = Math_fround($25 - $24);
 $38 = Math_fround($33 - $20);
 $39 = (($sweptBox) + 48|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($29 * $40);
 $42 = Math_fround($30 * $40);
 $43 = Math_fround($31 * $40);
 $44 = (($sweptBox) + 52|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($32 * $45);
 $47 = Math_fround($34 * $45);
 $48 = Math_fround($35 * $45);
 $49 = (($sweptBox) + 56|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($36 * $50);
 $52 = Math_fround($37 * $50);
 $53 = Math_fround($38 * $50);
 $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($41)))));
 $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($46)))));
 $54 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
 $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($51)))));
 $55 = Math_fround($54 + $fabsf$i$i6$i$i);
 $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($42)))));
 $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($47)))));
 $56 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
 $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($52)))));
 $57 = Math_fround($56 + $fabsf$i$i3$i$i);
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($43)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($48)))));
 $58 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($53)))));
 $59 = Math_fround($58 + $fabsf$i$i$i$i);
 $60 = Math_fround($11 - $55);
 $61 = Math_fround($13 - $57);
 $62 = Math_fround($15 - $59);
 $63 = Math_fround($11 + $55);
 $64 = Math_fround($13 + $57);
 $65 = Math_fround($15 + $59);
 HEAPF32[$bounds>>2] = $60;
 $66 = (($bounds) + 4|0);
 HEAPF32[$66>>2] = $61;
 $67 = (($bounds) + 8|0);
 HEAPF32[$67>>2] = $62;
 $68 = (($bounds) + 12|0);
 HEAPF32[$68>>2] = $63;
 $69 = (($bounds) + 16|0);
 HEAPF32[$69>>2] = $64;
 $70 = (($bounds) + 20|0);
 HEAPF32[$70>>2] = $65;
 $71 = (($sweepHit) + 40|0);
 HEAPF32[$71>>2] = Math_fround(3.40282346638528859812E+38);
 HEAP32[$0>>2] = ((546136 + 8|0));
 $72 = (($0) + 96|0);
 HEAP16[$72>>1] = 0;
 $73 = (($hfUtil) + 12|0);
 $74 = (($geom) + 4|0);
 $75 = HEAP32[$74>>2]|0;
 HEAP32[$73>>2] = $75;
 $76 = (($hfUtil) + 16|0);
 HEAP32[$76>>2] = $geom;
 $77 = (($geom) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround(Math_fround(1.0) / $78);
 $80 = (($hfUtil) + 4|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($geom) + 12|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround(Math_fround(1.0) / $82);
 HEAPF32[$hfUtil>>2] = $83;
 $84 = (($geom) + 16|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround(Math_fround(1.0) / $85);
 $87 = (($hfUtil) + 8|0);
 HEAPF32[$87>>2] = $86;
 $88 = Math_fround(HEAPF32[$box>>2]);
 $89 = (($0) + 20|0);
 HEAPF32[$89>>2] = $88;
 $90 = (($box) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($0) + 24|0);
 HEAPF32[$92>>2] = $91;
 $93 = (($box) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($0) + 28|0);
 HEAPF32[$95>>2] = $94;
 $96 = (($box) + 12|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($0) + 32|0);
 HEAPF32[$98>>2] = $97;
 $99 = (($box) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($0) + 36|0);
 HEAPF32[$101>>2] = $100;
 $102 = (($box) + 20|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($0) + 40|0);
 HEAPF32[$104>>2] = $103;
 $105 = (($box) + 24|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($0) + 44|0);
 HEAPF32[$107>>2] = $106;
 $108 = (($box) + 28|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($0) + 48|0);
 HEAPF32[$110>>2] = $109;
 $111 = (($box) + 32|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($0) + 52|0);
 HEAPF32[$113>>2] = $112;
 $114 = (($box) + 36|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($0) + 56|0);
 HEAPF32[$116>>2] = $115;
 $117 = (($box) + 40|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($0) + 60|0);
 HEAPF32[$119>>2] = $118;
 $120 = (($box) + 44|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($0) + 64|0);
 HEAPF32[$122>>2] = $121;
 $123 = (($box) + 48|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($0) + 68|0);
 HEAPF32[$125>>2] = $124;
 $126 = (($box) + 52|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($0) + 72|0);
 HEAPF32[$128>>2] = $127;
 $129 = (($box) + 56|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($0) + 76|0);
 HEAPF32[$131>>2] = $130;
 $132 = Math_fround(HEAPF32[$unitDir>>2]);
 $133 = (($0) + 80|0);
 HEAPF32[$133>>2] = $132;
 $134 = (($unitDir) + 4|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($0) + 84|0);
 HEAPF32[$136>>2] = $135;
 $137 = (($unitDir) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($0) + 88|0);
 HEAPF32[$139>>2] = $138;
 $140 = (($0) + 92|0);
 HEAPF32[$140>>2] = $distance;
 $141 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$72>>1] = $141;
 $142 = (($0) + 4|0);
 HEAP32[$142>>2] = $hfUtil;
 $143 = (($0) + 16|0);
 HEAP8[$143>>0] = 0;
 $144 = (($0) + 8|0);
 HEAP32[$144>>2] = $pose;
 $145 = (($0) + 12|0);
 HEAP32[$145>>2] = $sweepHit;
 $146 = (($geom) + 20|0);
 $147 = HEAP8[$146>>0]|0;
 $148 = $147 & 2;
 $149 = ($148<<24>>24)==(0);
 if (!($149)) {
  $152 = 1;
  $151 = (($0) + 98|0);
  HEAP8[$151>>0] = $152;
  (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$pose,$bounds,1,$0)|0);
  $153 = HEAP8[$143>>0]|0;
  $154 = ($153<<24>>24)!=(0);
  STACKTOP = sp;return ($154|0);
 }
 $150 = ($141&65535) >>> 7;
 $$tr = $150&255;
 $phitmp = $$tr & 1;
 $152 = $phitmp;
 $151 = (($0) + 98|0);
 HEAP8[$151>>0] = $152;
 (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$pose,$bounds,1,$0)|0);
 $153 = HEAP8[$143>>0]|0;
 $154 = ($153<<24>>24)!=(0);
 STACKTOP = sp;return ($154|0);
}
function __Z20sweepCCTBoxTrianglesjPKN5physx10PxTriangleERKNS_13PxBoxGeometryERKNS_11PxTransformERKNS_6PxVec3EfRS9_SC_RfRjPKjfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($nbTris,$triangles,$boxGeom,$boxPose,$dir,$length,$_hit,$_normal,$_d,$_index,$cachedIndex,$inflation,$hintFlags) {
 $nbTris = $nbTris|0;
 $triangles = $triangles|0;
 $boxGeom = $boxGeom|0;
 $boxPose = $boxPose|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $_hit = $_hit|0;
 $_normal = $_normal|0;
 $_d = $_d|0;
 $_index = $_index|0;
 $cachedIndex = $cachedIndex|0;
 $inflation = Math_fround($inflation);
 $hintFlags = $hintFlags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0;
 var $9 = 0, $box = 0, $sweepHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $box = sp + 48|0;
 $sweepHit = sp;
 $0 = sp + 108|0;
 $1 = (($boxPose) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($box) + 36|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($boxPose) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($box) + 40|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($boxPose) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($box) + 44|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($boxGeom) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($box) + 48|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($boxGeom) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($box) + 52|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($boxGeom) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($box) + 56|0);
 HEAPF32[$18>>2] = $17;
 $19 = Math_fround(HEAPF32[$boxPose>>2]);
 $20 = (($boxPose) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($boxPose) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($boxPose) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($19 + $19);
 $27 = Math_fround($21 + $21);
 $28 = Math_fround($23 + $23);
 $29 = Math_fround($19 * $26);
 $30 = Math_fround($21 * $27);
 $31 = Math_fround($23 * $28);
 $32 = Math_fround($26 * $21);
 $33 = Math_fround($26 * $23);
 $34 = Math_fround($26 * $25);
 $35 = Math_fround($27 * $23);
 $36 = Math_fround($27 * $25);
 $37 = Math_fround($28 * $25);
 $38 = Math_fround(Math_fround(1.0) - $30);
 $39 = Math_fround($38 - $31);
 $40 = Math_fround($32 + $37);
 $41 = Math_fround($33 - $36);
 $42 = Math_fround($32 - $37);
 $43 = Math_fround(Math_fround(1.0) - $29);
 $44 = Math_fround($43 - $31);
 $45 = Math_fround($35 + $34);
 $46 = Math_fround($33 + $36);
 $47 = Math_fround($35 - $34);
 $48 = Math_fround($43 - $30);
 HEAPF32[$box>>2] = $39;
 $49 = (($box) + 4|0);
 HEAPF32[$49>>2] = $40;
 $50 = (($box) + 8|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($box) + 12|0);
 HEAPF32[$51>>2] = $42;
 $52 = (($box) + 16|0);
 HEAPF32[$52>>2] = $44;
 $53 = (($box) + 20|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($box) + 24|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($box) + 28|0);
 HEAPF32[$55>>2] = $47;
 $56 = (($box) + 32|0);
 HEAPF32[$56>>2] = $48;
 HEAP32[$sweepHit>>2] = 0;
 $57 = (($sweepHit) + 4|0);
 HEAP32[$57>>2] = 0;
 $58 = (($sweepHit) + 8|0);
 HEAP32[$58>>2] = -1;
 $59 = (($sweepHit) + 12|0);
 HEAP16[$59>>1] = 0;
 $60 = (($sweepHit) + 16|0);
 $61 = (($sweepHit) + 40|0);
 ;HEAP32[$60+0>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;HEAP32[$60+16>>2]=0|0;HEAP32[$60+20>>2]=0|0;
 HEAPF32[$61>>2] = Math_fround(3.40282346638528859812E+38);
 $62 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$0>>1] = $62;
 $63 = (__ZL19sweepBoxVsTrianglesjPKN5physx10PxTriangleERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEbPKj($nbTris,$triangles,$box,$dir,$length,$sweepHit,$0,0,$cachedIndex)|0);
 if (!($63)) {
  STACKTOP = sp;return ($63|0);
 }
 $64 = Math_fround(HEAPF32[$60>>2]);
 HEAPF32[$_hit>>2] = $64;
 $65 = (($sweepHit) + 20|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($_hit) + 4|0);
 HEAPF32[$67>>2] = $66;
 $68 = (($sweepHit) + 24|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($_hit) + 8|0);
 HEAPF32[$70>>2] = $69;
 $71 = (($sweepHit) + 28|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 HEAPF32[$_normal>>2] = $72;
 $73 = (($sweepHit) + 32|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($_normal) + 4|0);
 HEAPF32[$75>>2] = $74;
 $76 = (($sweepHit) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($_normal) + 8|0);
 HEAPF32[$78>>2] = $77;
 $79 = Math_fround(HEAPF32[$61>>2]);
 HEAPF32[$_d>>2] = $79;
 $80 = HEAP32[$58>>2]|0;
 HEAP32[$_index>>2] = $80;
 STACKTOP = sp;return ($63|0);
}
function __ZL19sweepBoxVsTrianglesjPKN5physx10PxTriangleERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEbPKj($nbTris,$triangles,$box,$unitDir,$distance,$sweepHit,$hintFlags,$isDoubleSided,$cachedIndex) {
 $nbTris = $nbTris|0;
 $triangles = $triangles|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $isDoubleSided = $isDoubleSided|0;
 $cachedIndex = $cachedIndex|0;
 var $$1 = 0, $$i$i = 0, $$pre = 0, $$pre46 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0);
 var $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0;
 var $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0;
 var $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0);
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = 0, $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0;
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $currentTriangle = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i4 = Math_fround(0), $fabsf$i$i5 = Math_fround(0);
 var $ii$044 = 0, $localDir = 0, $localMinDist$042 = Math_fround(0), $localMinDist$1 = Math_fround(0), $localMotion = 0, $oneOverMotion = 0, $or$cond$i = 0, $or$cond1$i = 0, $status$0$off043 = 0, $status$1$off0 = 0, $t = 0, $triangleIndex$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $localDir = sp + 64|0;
 $localMotion = sp;
 $oneOverMotion = sp + 12|0;
 $currentTriangle = sp + 24|0;
 $t = sp + 60|0;
 $0 = ($nbTris|0)==(0);
 if ($0) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $1 = Math_fround(HEAPF32[$box>>2]);
 $2 = (($box) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($box) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($box) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($box) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($box) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($box) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($box) + 28|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($box) + 32|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($box) + 36|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($box) + 40|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($box) + 44|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(-$19);
 $25 = Math_fround(-$21);
 $26 = Math_fround(-$23);
 $27 = Math_fround($1 * $24);
 $28 = Math_fround($3 * $25);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($5 * $26);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($7 * $24);
 $33 = Math_fround($9 * $25);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($11 * $26);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($13 * $24);
 $38 = Math_fround($15 * $25);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($17 * $26);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround(HEAPF32[$unitDir>>2]);
 $43 = Math_fround($1 * $42);
 $44 = Math_fround($7 * $42);
 $45 = Math_fround($13 * $42);
 $46 = (($unitDir) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($3 * $47);
 $49 = Math_fround($9 * $47);
 $50 = Math_fround($15 * $47);
 $51 = Math_fround($43 + $48);
 $52 = Math_fround($44 + $49);
 $53 = Math_fround($45 + $50);
 $54 = (($unitDir) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($5 * $55);
 $57 = Math_fround($11 * $55);
 $58 = Math_fround($17 * $55);
 $59 = Math_fround($51 + $56);
 $60 = Math_fround($52 + $57);
 $61 = Math_fround($53 + $58);
 HEAPF32[$localDir>>2] = $59;
 $62 = (($localDir) + 4|0);
 HEAPF32[$62>>2] = $60;
 $63 = (($localDir) + 8|0);
 HEAPF32[$63>>2] = $61;
 $64 = Math_fround($59 * $distance);
 $65 = Math_fround($60 * $distance);
 $66 = Math_fround($61 * $distance);
 HEAPF32[$localMotion>>2] = $64;
 $67 = (($localMotion) + 4|0);
 HEAPF32[$67>>2] = $65;
 $68 = (($localMotion) + 8|0);
 HEAPF32[$68>>2] = $66;
 $69 = (($sweepHit) + 40|0);
 HEAPF32[$69>>2] = $distance;
 $70 = $59 != Math_fround(0.0);
 if ($70) {
  $71 = Math_fround(Math_fround(1.0) / $64);
  $76 = $71;
 } else {
  $76 = Math_fround(0.0);
 }
 $72 = $60 != Math_fround(0.0);
 if ($72) {
  $73 = Math_fround(Math_fround(1.0) / $65);
  $78 = $73;
 } else {
  $78 = Math_fround(0.0);
 }
 $74 = $61 != Math_fround(0.0);
 if ($74) {
  $75 = Math_fround(Math_fround(1.0) / $66);
  $80 = $75;
 } else {
  $80 = Math_fround(0.0);
 }
 HEAPF32[$oneOverMotion>>2] = $76;
 $77 = (($oneOverMotion) + 4|0);
 HEAPF32[$77>>2] = $78;
 $79 = (($oneOverMotion) + 8|0);
 HEAPF32[$79>>2] = $80;
 $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($59)))));
 $81 = (($box) + 48|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($fabsf$i$i5 * $82);
 $fabsf$i$i4 = (Math_fround(Math_abs((Math_fround($60)))));
 $84 = (($box) + 52|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($fabsf$i$i4 * $85);
 $87 = Math_fround($83 + $86);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($61)))));
 $88 = (($box) + 56|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($fabsf$i$i * $89);
 $91 = Math_fround($87 + $90);
 $92 = Math_fround(HEAPF32[$18>>2]);
 $93 = Math_fround(HEAPF32[$unitDir>>2]);
 $94 = Math_fround($92 * $93);
 $95 = Math_fround(HEAPF32[$20>>2]);
 $96 = Math_fround(HEAPF32[$46>>2]);
 $97 = Math_fround($95 * $96);
 $98 = Math_fround($94 + $97);
 $99 = Math_fround(HEAPF32[$22>>2]);
 $100 = Math_fround(HEAPF32[$54>>2]);
 $101 = Math_fround($99 * $100);
 $102 = Math_fround($98 + $101);
 $103 = ($cachedIndex|0)==(0|0);
 if ($103) {
  $116 = 0;
 } else {
  $104 = HEAP32[$cachedIndex>>2]|0;
  $116 = $104;
 }
 $105 = (($currentTriangle) + 4|0);
 $106 = (($currentTriangle) + 8|0);
 $107 = (($currentTriangle) + 12|0);
 $108 = (($currentTriangle) + 16|0);
 $109 = (($currentTriangle) + 20|0);
 $110 = (($currentTriangle) + 24|0);
 $111 = (($currentTriangle) + 28|0);
 $112 = (($currentTriangle) + 32|0);
 $113 = (($sweepHit) + 8|0);
 $ii$044 = 0;$localMinDist$042 = Math_fround(1.0);$status$0$off043 = 0;
 while(1) {
  $114 = ($ii$044|0)==(0);
  if ($114) {
   $triangleIndex$0$i = $116;
  } else {
   $115 = ($ii$044|0)==($116|0);
   $$i$i = $115 ? 0 : $ii$044;
   $triangleIndex$0$i = $$i$i;
  }
  $117 = (($triangles) + (($triangleIndex$0$i*36)|0)|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  HEAPF32[$currentTriangle>>2] = $118;
  $119 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 4|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  HEAPF32[$105>>2] = $120;
  $121 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 8|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  HEAPF32[$106>>2] = $122;
  $123 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 12|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$107>>2] = $124;
  $125 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 16|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  HEAPF32[$108>>2] = $126;
  $127 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 20|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  HEAPF32[$109>>2] = $128;
  $129 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 24|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  HEAPF32[$110>>2] = $130;
  $131 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 28|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  HEAPF32[$111>>2] = $132;
  $133 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 32|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  HEAPF32[$112>>2] = $134;
  $135 = Math_fround($localMinDist$042 * $distance);
  $136 = Math_fround(HEAPF32[$unitDir>>2]);
  $137 = Math_fround($118 * $136);
  $138 = Math_fround(HEAPF32[$46>>2]);
  $139 = Math_fround($120 * $138);
  $140 = Math_fround($137 + $139);
  $141 = Math_fround(HEAPF32[$54>>2]);
  $142 = Math_fround($122 * $141);
  $143 = Math_fround($140 + $142);
  $144 = Math_fround($136 * $124);
  $145 = Math_fround($138 * $126);
  $146 = Math_fround($144 + $145);
  $147 = Math_fround($141 * $128);
  $148 = Math_fround($146 + $147);
  $149 = Math_fround($136 * $130);
  $150 = Math_fround($138 * $132);
  $151 = Math_fround($149 + $150);
  $152 = Math_fround($134 * $141);
  $153 = Math_fround($152 + $151);
  $154 = $143 < $148;
  $155 = $154 ? $143 : $148;
  $156 = $155 < $153;
  $157 = $156 ? $155 : $153;
  $158 = Math_fround($102 + $135);
  $159 = Math_fround($91 + $158);
  $160 = Math_fround($159 + Math_fround(0.00999999977648258209228));
  $161 = $157 > $160;
  if ($161) {
   $localMinDist$1 = $localMinDist$042;$status$1$off0 = $status$0$off043;
  } else {
   $162 = $143 < $102;
   $163 = $148 < $102;
   $or$cond$i = $162 & $163;
   $164 = $153 < $102;
   $or$cond1$i = $or$cond$i & $164;
   if ($or$cond1$i) {
    $localMinDist$1 = $localMinDist$042;$status$1$off0 = $status$0$off043;
   } else {
    $165 = Math_fround($1 * $118);
    $166 = Math_fround($7 * $118);
    $167 = Math_fround($13 * $118);
    $168 = Math_fround($3 * $120);
    $169 = Math_fround($9 * $120);
    $170 = Math_fround($15 * $120);
    $171 = Math_fround($165 + $168);
    $172 = Math_fround($166 + $169);
    $173 = Math_fround($167 + $170);
    $174 = Math_fround($5 * $122);
    $175 = Math_fround($11 * $122);
    $176 = Math_fround($17 * $122);
    $177 = Math_fround($171 + $174);
    $178 = Math_fround($172 + $175);
    $179 = Math_fround($173 + $176);
    $180 = Math_fround($31 + $177);
    $181 = Math_fround($36 + $178);
    $182 = Math_fround($41 + $179);
    HEAPF32[$currentTriangle>>2] = $180;
    HEAPF32[$105>>2] = $181;
    HEAPF32[$106>>2] = $182;
    $183 = Math_fround($1 * $124);
    $184 = Math_fround($7 * $124);
    $185 = Math_fround($13 * $124);
    $186 = Math_fround($3 * $126);
    $187 = Math_fround($9 * $126);
    $188 = Math_fround($15 * $126);
    $189 = Math_fround($183 + $186);
    $190 = Math_fround($184 + $187);
    $191 = Math_fround($185 + $188);
    $192 = Math_fround($5 * $128);
    $193 = Math_fround($11 * $128);
    $194 = Math_fround($17 * $128);
    $195 = Math_fround($189 + $192);
    $196 = Math_fround($190 + $193);
    $197 = Math_fround($191 + $194);
    $198 = Math_fround($31 + $195);
    $199 = Math_fround($36 + $196);
    $200 = Math_fround($41 + $197);
    HEAPF32[$107>>2] = $198;
    HEAPF32[$108>>2] = $199;
    HEAPF32[$109>>2] = $200;
    $201 = Math_fround($1 * $130);
    $202 = Math_fround($7 * $130);
    $203 = Math_fround($13 * $130);
    $204 = Math_fround($3 * $132);
    $205 = Math_fround($9 * $132);
    $206 = Math_fround($15 * $132);
    $207 = Math_fround($201 + $204);
    $208 = Math_fround($202 + $205);
    $209 = Math_fround($203 + $206);
    $210 = Math_fround($5 * $134);
    $211 = Math_fround($11 * $134);
    $212 = Math_fround($17 * $134);
    $213 = Math_fround($207 + $210);
    $214 = Math_fround($208 + $211);
    $215 = Math_fround($209 + $212);
    $216 = Math_fround($31 + $213);
    $217 = Math_fround($36 + $214);
    $218 = Math_fround($41 + $215);
    HEAPF32[$110>>2] = $216;
    HEAPF32[$111>>2] = $217;
    HEAPF32[$112>>2] = $218;
    HEAPF32[$t>>2] = Math_fround(3.40282346638528859812E+38);
    $219 = (__ZN5physx2Gu23triBoxSweepTestBoxSpaceERKNS_10PxTriangleERKNS_6PxVec3ES6_S6_fRfb($currentTriangle,$81,$localMotion,$oneOverMotion,$localMinDist$042,$t,$isDoubleSided)|0);
    $220 = ($219|0)==(0);
    if ($220) {
     $localMinDist$1 = $localMinDist$042;$status$1$off0 = $status$0$off043;
    } else {
     $221 = Math_fround(HEAPF32[$t>>2]);
     $222 = !($221 <= $localMinDist$042);
     if ($222) {
      $localMinDist$1 = $localMinDist$042;$status$1$off0 = $status$0$off043;
     } else {
      $223 = $221 == Math_fround(0.0);
      if ($223) {
       label = 18;
       break;
      }
      $234 = Math_fround($221 * $distance);
      HEAPF32[$69>>2] = $234;
      HEAP32[$113>>2] = $triangleIndex$0$i;
      $localMinDist$1 = $221;$status$1$off0 = 1;
     }
    }
   }
  }
  $235 = (($ii$044) + 1)|0;
  $236 = ($235>>>0)<($nbTris>>>0);
  if ($236) {
   $ii$044 = $235;$localMinDist$042 = $localMinDist$1;$status$0$off043 = $status$1$off0;
  } else {
   break;
  }
 }
 if ((label|0) == 18) {
  $224 = (($sweepHit) + 12|0);
  HEAP16[$224>>1] = 6;
  HEAPF32[$69>>2] = Math_fround(0.0);
  HEAP32[$113>>2] = $triangleIndex$0$i;
  $225 = Math_fround(HEAPF32[$unitDir>>2]);
  $226 = Math_fround(-$225);
  $227 = Math_fround(HEAPF32[$46>>2]);
  $228 = Math_fround(-$227);
  $229 = Math_fround(HEAPF32[$54>>2]);
  $230 = Math_fround(-$229);
  $231 = (($sweepHit) + 28|0);
  HEAPF32[$231>>2] = $226;
  $232 = (($sweepHit) + 32|0);
  HEAPF32[$232>>2] = $228;
  $233 = (($sweepHit) + 36|0);
  HEAPF32[$233>>2] = $230;
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 if (!($status$1$off0)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $237 = (($sweepHit) + 12|0);
 HEAP16[$237>>1] = 4;
 $238 = HEAP16[$hintFlags>>1]|0;
 $239 = $238 & 3;
 $240 = ($239<<16>>16)==(0);
 if ($240) {
  $324 = $238;
 } else {
  $241 = (($sweepHit) + 8|0);
  $242 = HEAP32[$241>>2]|0;
  $243 = (($triangles) + (($242*36)|0)|0);
  $244 = Math_fround(HEAPF32[$243>>2]);
  $245 = ((($triangles) + (($242*36)|0)|0) + 4|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = (($currentTriangle) + 4|0);
  $248 = ((($triangles) + (($242*36)|0)|0) + 8|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = (($currentTriangle) + 8|0);
  $251 = ((($triangles) + (($242*36)|0)|0) + 12|0);
  $252 = Math_fround(HEAPF32[$251>>2]);
  $253 = (($currentTriangle) + 12|0);
  $254 = ((($triangles) + (($242*36)|0)|0) + 16|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = (($currentTriangle) + 16|0);
  $257 = ((($triangles) + (($242*36)|0)|0) + 20|0);
  $258 = Math_fround(HEAPF32[$257>>2]);
  $259 = (($currentTriangle) + 20|0);
  $260 = ((($triangles) + (($242*36)|0)|0) + 24|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = (($currentTriangle) + 24|0);
  $263 = ((($triangles) + (($242*36)|0)|0) + 28|0);
  $264 = Math_fround(HEAPF32[$263>>2]);
  $265 = (($currentTriangle) + 28|0);
  $266 = ((($triangles) + (($242*36)|0)|0) + 32|0);
  $267 = Math_fround(HEAPF32[$266>>2]);
  $268 = (($currentTriangle) + 32|0);
  $269 = Math_fround($1 * $244);
  $270 = Math_fround($7 * $244);
  $271 = Math_fround($13 * $244);
  $272 = Math_fround($3 * $246);
  $273 = Math_fround($9 * $246);
  $274 = Math_fround($15 * $246);
  $275 = Math_fround($269 + $272);
  $276 = Math_fround($270 + $273);
  $277 = Math_fround($271 + $274);
  $278 = Math_fround($5 * $249);
  $279 = Math_fround($11 * $249);
  $280 = Math_fround($17 * $249);
  $281 = Math_fround($275 + $278);
  $282 = Math_fround($276 + $279);
  $283 = Math_fround($277 + $280);
  $284 = Math_fround($31 + $281);
  $285 = Math_fround($36 + $282);
  $286 = Math_fround($41 + $283);
  HEAPF32[$currentTriangle>>2] = $284;
  HEAPF32[$247>>2] = $285;
  HEAPF32[$250>>2] = $286;
  $287 = Math_fround($1 * $252);
  $288 = Math_fround($7 * $252);
  $289 = Math_fround($13 * $252);
  $290 = Math_fround($3 * $255);
  $291 = Math_fround($9 * $255);
  $292 = Math_fround($15 * $255);
  $293 = Math_fround($287 + $290);
  $294 = Math_fround($288 + $291);
  $295 = Math_fround($289 + $292);
  $296 = Math_fround($5 * $258);
  $297 = Math_fround($11 * $258);
  $298 = Math_fround($17 * $258);
  $299 = Math_fround($293 + $296);
  $300 = Math_fround($294 + $297);
  $301 = Math_fround($295 + $298);
  $302 = Math_fround($31 + $299);
  $303 = Math_fround($36 + $300);
  $304 = Math_fround($41 + $301);
  HEAPF32[$253>>2] = $302;
  HEAPF32[$256>>2] = $303;
  HEAPF32[$259>>2] = $304;
  $305 = Math_fround($1 * $261);
  $306 = Math_fround($7 * $261);
  $307 = Math_fround($13 * $261);
  $308 = Math_fround($3 * $264);
  $309 = Math_fround($9 * $264);
  $310 = Math_fround($15 * $264);
  $311 = Math_fround($305 + $308);
  $312 = Math_fround($306 + $309);
  $313 = Math_fround($307 + $310);
  $314 = Math_fround($5 * $267);
  $315 = Math_fround($11 * $267);
  $316 = Math_fround($17 * $267);
  $317 = Math_fround($311 + $314);
  $318 = Math_fround($312 + $315);
  $319 = Math_fround($313 + $316);
  $320 = Math_fround($31 + $317);
  $321 = Math_fround($36 + $318);
  $322 = Math_fround($41 + $319);
  HEAPF32[$262>>2] = $320;
  HEAPF32[$265>>2] = $321;
  HEAPF32[$268>>2] = $322;
  __ZN5physx2Gu17computeImpactDataERNS_10PxSweepHitERKNS0_3BoxERKNS_6PxVec3ES8_S8_RKNS_10PxTriangleE($sweepHit,$box,$localDir,$localMotion,$oneOverMotion,$currentTriangle);
  $$pre = HEAP16[$hintFlags>>1]|0;
  $324 = $$pre;
 }
 $323 = $324 & 2;
 $325 = ($323<<16>>16)==(0);
 if ($325) {
  $390 = $324;
 } else {
  $326 = (($sweepHit) + 28|0);
  $327 = Math_fround(HEAPF32[$326>>2]);
  $328 = Math_fround($327 * $327);
  $329 = (($sweepHit) + 32|0);
  $330 = Math_fround(HEAPF32[$329>>2]);
  $331 = Math_fround($330 * $330);
  $332 = Math_fround($328 + $331);
  $333 = (($sweepHit) + 36|0);
  $334 = Math_fround(HEAPF32[$333>>2]);
  $335 = Math_fround($334 * $334);
  $336 = Math_fround($332 + $335);
  $337 = (Math_fround(Math_sqrt((Math_fround($336)))));
  $338 = $337 > Math_fround(0.0);
  if ($338) {
   $339 = Math_fround(Math_fround(1.0) / $337);
   $340 = Math_fround($327 * $339);
   HEAPF32[$326>>2] = $340;
   $341 = Math_fround($330 * $339);
   HEAPF32[$329>>2] = $341;
   $342 = Math_fround($334 * $339);
   HEAPF32[$333>>2] = $342;
   $345 = $340;$348 = $341;$352 = $342;
  } else {
   $345 = $327;$348 = $330;$352 = $334;
  }
  $343 = Math_fround(HEAPF32[$localMotion>>2]);
  $344 = Math_fround($345 * $343);
  $346 = Math_fround(HEAPF32[$67>>2]);
  $347 = Math_fround($348 * $346);
  $349 = Math_fround($344 + $347);
  $350 = Math_fround(HEAPF32[$68>>2]);
  $351 = Math_fround($352 * $350);
  $353 = Math_fround($349 + $351);
  $354 = $353 > Math_fround(0.0);
  if ($354) {
   $355 = Math_fround(-$345);
   $356 = Math_fround(-$348);
   $357 = Math_fround(-$352);
   HEAPF32[$326>>2] = $355;
   HEAPF32[$329>>2] = $356;
   HEAPF32[$333>>2] = $357;
   $360 = $355;$367 = $356;$377 = $357;
  } else {
   $360 = $345;$367 = $348;$377 = $352;
  }
  $358 = Math_fround(HEAPF32[$box>>2]);
  $359 = Math_fround($360 * $358);
  $361 = Math_fround(HEAPF32[$2>>2]);
  $362 = Math_fround($360 * $361);
  $363 = Math_fround(HEAPF32[$4>>2]);
  $364 = Math_fround($360 * $363);
  $365 = Math_fround(HEAPF32[$6>>2]);
  $366 = Math_fround($367 * $365);
  $368 = Math_fround(HEAPF32[$8>>2]);
  $369 = Math_fround($367 * $368);
  $370 = Math_fround(HEAPF32[$10>>2]);
  $371 = Math_fround($367 * $370);
  $372 = Math_fround($359 + $366);
  $373 = Math_fround($362 + $369);
  $374 = Math_fround($364 + $371);
  $375 = Math_fround(HEAPF32[$12>>2]);
  $376 = Math_fround($377 * $375);
  $378 = Math_fround(HEAPF32[$14>>2]);
  $379 = Math_fround($377 * $378);
  $380 = Math_fround(HEAPF32[$16>>2]);
  $381 = Math_fround($377 * $380);
  $382 = Math_fround($372 + $376);
  $383 = Math_fround($373 + $379);
  $384 = Math_fround($374 + $381);
  HEAPF32[$326>>2] = $382;
  HEAPF32[$329>>2] = $383;
  HEAPF32[$333>>2] = $384;
  $385 = HEAP16[$237>>1]|0;
  $386 = $385&65535;
  $387 = $386 | 2;
  $388 = $387&65535;
  HEAP16[$237>>1] = $388;
  $$pre46 = HEAP16[$hintFlags>>1]|0;
  $390 = $$pre46;
 }
 $389 = $390 & 1;
 $391 = ($389<<16>>16)==(0);
 if ($391) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $392 = (($sweepHit) + 16|0);
 $393 = Math_fround(HEAPF32[$392>>2]);
 $394 = Math_fround(HEAPF32[$box>>2]);
 $395 = Math_fround($393 * $394);
 $396 = Math_fround(HEAPF32[$2>>2]);
 $397 = Math_fround($393 * $396);
 $398 = Math_fround(HEAPF32[$4>>2]);
 $399 = Math_fround($393 * $398);
 $400 = (($sweepHit) + 20|0);
 $401 = Math_fround(HEAPF32[$400>>2]);
 $402 = Math_fround(HEAPF32[$6>>2]);
 $403 = Math_fround($401 * $402);
 $404 = Math_fround(HEAPF32[$8>>2]);
 $405 = Math_fround($401 * $404);
 $406 = Math_fround(HEAPF32[$10>>2]);
 $407 = Math_fround($401 * $406);
 $408 = Math_fround($395 + $403);
 $409 = Math_fround($397 + $405);
 $410 = Math_fround($399 + $407);
 $411 = (($sweepHit) + 24|0);
 $412 = Math_fround(HEAPF32[$411>>2]);
 $413 = Math_fround(HEAPF32[$12>>2]);
 $414 = Math_fround($412 * $413);
 $415 = Math_fround(HEAPF32[$14>>2]);
 $416 = Math_fround($412 * $415);
 $417 = Math_fround(HEAPF32[$16>>2]);
 $418 = Math_fround($412 * $417);
 $419 = Math_fround($408 + $414);
 $420 = Math_fround($409 + $416);
 $421 = Math_fround($410 + $418);
 $422 = Math_fround(HEAPF32[$18>>2]);
 $423 = Math_fround($419 + $422);
 $424 = Math_fround(HEAPF32[$20>>2]);
 $425 = Math_fround($420 + $424);
 $426 = Math_fround(HEAPF32[$22>>2]);
 $427 = Math_fround($421 + $426);
 HEAPF32[$392>>2] = $423;
 HEAPF32[$400>>2] = $425;
 HEAPF32[$411>>2] = $427;
 $428 = HEAP16[$237>>1]|0;
 $429 = $428&65535;
 $430 = $429 | 1;
 $431 = $430&65535;
 HEAP16[$237>>1] = $431;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZZ27sweepCCTBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEfEN11LocalReportD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZ27sweepCCTBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEfEN11LocalReportD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZ27sweepCCTBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEfEN11LocalReport7onEventEjPj($this,$nb,$indices) {
 $this = $this|0;
 $nb = $nb|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $currentTriangle = 0, $exitcond = 0, $i$01 = 0, $sweepHit_ = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $currentTriangle = sp + 48|0;
 $sweepHit_ = sp;
 $0 = sp + 84|0;
 $1 = ($nb|0)==(0);
 if ($1) {
  STACKTOP = sp;return 1;
 }
 $2 = (($this) + 4|0);
 $3 = (($this) + 8|0);
 $4 = (($sweepHit_) + 4|0);
 $5 = (($sweepHit_) + 8|0);
 $6 = (($sweepHit_) + 12|0);
 $7 = (($sweepHit_) + 16|0);
 $8 = (($sweepHit_) + 40|0);
 $9 = (($this) + 20|0);
 $10 = (($this) + 80|0);
 $11 = (($this) + 92|0);
 $12 = (($this) + 96|0);
 $13 = (($this) + 98|0);
 $14 = (($this) + 12|0);
 $15 = (($sweepHit_) + 20|0);
 $16 = (($sweepHit_) + 24|0);
 $17 = (($sweepHit_) + 28|0);
 $18 = (($sweepHit_) + 32|0);
 $19 = (($sweepHit_) + 36|0);
 $20 = (($sweepHit_) + 44|0);
 $21 = (($this) + 16|0);
 $i$01 = 0;
 while(1) {
  $22 = (($indices) + ($i$01<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$2>>2]|0;
  $25 = HEAP32[$3>>2]|0;
  (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($24,$25,$currentTriangle,0,0,$23,1,1)|0);
  HEAP32[$sweepHit_>>2] = 0;
  HEAP32[$4>>2] = 0;
  HEAP32[$5>>2] = -1;
  HEAP16[$6>>1] = 0;
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;
  HEAPF32[$8>>2] = Math_fround(3.40282346638528859812E+38);
  $26 = Math_fround(HEAPF32[$11>>2]);
  $27 = HEAP16[$12>>1]|0;
  HEAP16[$0>>1] = $27;
  $28 = HEAP8[$13>>0]|0;
  $29 = ($28<<24>>24)!=(0);
  $30 = (__ZL19sweepBoxVsTrianglesjPKN5physx10PxTriangleERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEbPKj(1,$currentTriangle,$9,$10,$26,$sweepHit_,$0,$29,0)|0);
  if ($30) {
   $31 = Math_fround(HEAPF32[$8>>2]);
   $32 = HEAP32[$14>>2]|0;
   $33 = (($32) + 40|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = $31 < $34;
   if ($35) {
    ;HEAP32[$32+0>>2]=HEAP32[$sweepHit_+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$sweepHit_+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$sweepHit_+8>>2]|0;
    $36 = HEAP16[$6>>1]|0;
    $37 = (($32) + 12|0);
    HEAP16[$37>>1] = $36;
    $38 = Math_fround(HEAPF32[$7>>2]);
    $39 = (($32) + 16|0);
    HEAPF32[$39>>2] = $38;
    $40 = Math_fround(HEAPF32[$15>>2]);
    $41 = (($32) + 20|0);
    HEAPF32[$41>>2] = $40;
    $42 = Math_fround(HEAPF32[$16>>2]);
    $43 = (($32) + 24|0);
    HEAPF32[$43>>2] = $42;
    $44 = Math_fround(HEAPF32[$17>>2]);
    $45 = (($32) + 28|0);
    HEAPF32[$45>>2] = $44;
    $46 = Math_fround(HEAPF32[$18>>2]);
    $47 = (($32) + 32|0);
    HEAPF32[$47>>2] = $46;
    $48 = Math_fround(HEAPF32[$19>>2]);
    $49 = (($32) + 36|0);
    HEAPF32[$49>>2] = $48;
    $50 = Math_fround(HEAPF32[$8>>2]);
    HEAPF32[$33>>2] = $50;
    $51 = HEAP32[$20>>2]|0;
    $52 = (($32) + 44|0);
    HEAP32[$52>>2] = $51;
    $53 = HEAP32[$14>>2]|0;
    $54 = (($53) + 8|0);
    HEAP32[$54>>2] = $23;
    HEAP8[$21>>0] = 1;
   }
  }
  $55 = (($i$01) + 1)|0;
  $exitcond = ($55|0)==($nb|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $55;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu23computeBoxAroundCapsuleERKNS0_7CapsuleERNS0_3BoxE($capsule,$box) {
 $capsule = $capsule|0;
 $box = $box|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $8 = Math_fround(0), $9 = 0, $dir = 0, $right = 0, $up = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $dir = sp + 24|0;
 $right = sp;
 $up = sp + 12|0;
 $0 = Math_fround(HEAPF32[$capsule>>2]);
 $1 = (($capsule) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 $4 = (($capsule) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($capsule) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 $9 = (($capsule) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($capsule) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = Math_fround($3 * Math_fround(0.5));
 $15 = Math_fround($8 * Math_fround(0.5));
 $16 = Math_fround($13 * Math_fround(0.5));
 $17 = (($box) + 36|0);
 HEAPF32[$17>>2] = $14;
 $18 = (($box) + 40|0);
 HEAPF32[$18>>2] = $15;
 $19 = (($box) + 44|0);
 HEAPF32[$19>>2] = $16;
 $20 = (($capsule) + 12|0);
 $21 = Math_fround(HEAPF32[$capsule>>2]);
 $22 = Math_fround(HEAPF32[$20>>2]);
 $23 = Math_fround($21 - $22);
 $24 = Math_fround(HEAPF32[$4>>2]);
 $25 = Math_fround(HEAPF32[$6>>2]);
 $26 = Math_fround($24 - $25);
 $27 = Math_fround(HEAPF32[$9>>2]);
 $28 = Math_fround(HEAPF32[$11>>2]);
 $29 = Math_fround($27 - $28);
 $30 = Math_fround($23 * $23);
 $31 = Math_fround($26 * $26);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($29 * $29);
 $34 = Math_fround($32 + $33);
 $35 = (Math_fround(Math_sqrt((Math_fround($34)))));
 $36 = (($capsule) + 24|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 * Math_fround(0.5));
 $39 = Math_fround($37 + $38);
 $40 = (($box) + 48|0);
 HEAPF32[$40>>2] = $39;
 $41 = Math_fround(HEAPF32[$36>>2]);
 $42 = (($box) + 52|0);
 HEAPF32[$42>>2] = $41;
 $43 = Math_fround(HEAPF32[$36>>2]);
 $44 = (($box) + 56|0);
 HEAPF32[$44>>2] = $43;
 $45 = $35 == Math_fround(0.0);
 if ($45) {
  HEAPF32[$box>>2] = Math_fround(1.0);
  $46 = (($box) + 4|0);
  HEAPF32[$46>>2] = Math_fround(0.0);
  $47 = (($box) + 8|0);
  HEAPF32[$47>>2] = Math_fround(0.0);
  $48 = (($box) + 12|0);
  HEAPF32[$48>>2] = Math_fround(0.0);
  $49 = (($box) + 16|0);
  HEAPF32[$49>>2] = Math_fround(1.0);
  $50 = (($box) + 20|0);
  HEAPF32[$50>>2] = Math_fround(0.0);
  $51 = (($box) + 24|0);
  HEAPF32[$51>>2] = Math_fround(0.0);
  $52 = (($box) + 28|0);
  HEAPF32[$52>>2] = Math_fround(0.0);
  $53 = (($box) + 32|0);
  HEAPF32[$53>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd12computeBasisERKNS_6PxVec3ES3_RS1_S4_S4_($capsule,$20,$dir,$right,$up);
  $54 = Math_fround(HEAPF32[$dir>>2]);
  HEAPF32[$box>>2] = $54;
  $55 = (($dir) + 4|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($box) + 4|0);
  HEAPF32[$57>>2] = $56;
  $58 = (($dir) + 8|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($box) + 8|0);
  HEAPF32[$60>>2] = $59;
  $61 = Math_fround(HEAPF32[$right>>2]);
  $62 = (($box) + 12|0);
  HEAPF32[$62>>2] = $61;
  $63 = (($right) + 4|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($box) + 16|0);
  HEAPF32[$65>>2] = $64;
  $66 = (($right) + 8|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = (($box) + 20|0);
  HEAPF32[$68>>2] = $67;
  $69 = Math_fround(HEAPF32[$up>>2]);
  $70 = (($box) + 24|0);
  HEAPF32[$70>>2] = $69;
  $71 = (($up) + 4|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($box) + 28|0);
  HEAPF32[$73>>2] = $72;
  $74 = (($up) + 8|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = (($box) + 32|0);
  HEAPF32[$76>>2] = $75;
  STACKTOP = sp;return;
 }
}
function __ZN5physx6shdfnd12computeBasisERKNS_6PxVec3ES3_RS1_S4_S4_($p0,$p1,$dir,$right,$up) {
 $p0 = $p0|0;
 $p1 = $p1|0;
 $dir = $dir|0;
 $right = $right|0;
 $up = $up|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$p1>>2]);
 $1 = Math_fround(HEAPF32[$p0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($p1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($p0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($p1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($p0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 HEAPF32[$dir>>2] = $2;
 $13 = (($dir) + 4|0);
 HEAPF32[$13>>2] = $7;
 $14 = (($dir) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = Math_fround($2 * $2);
 $16 = Math_fround($7 * $7);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($12 * $12);
 $19 = Math_fround($18 + $17);
 $20 = (Math_fround(Math_sqrt((Math_fround($19)))));
 $21 = $20 > Math_fround(0.0);
 if ($21) {
  $22 = Math_fround(Math_fround(1.0) / $20);
  $23 = Math_fround($2 * $22);
  HEAPF32[$dir>>2] = $23;
  $24 = Math_fround($7 * $22);
  HEAPF32[$13>>2] = $24;
  $25 = Math_fround($12 * $22);
  HEAPF32[$14>>2] = $25;
  $26 = $24;$32 = $25;$34 = $23;
 } else {
  $26 = $7;$32 = $12;$34 = $2;
 }
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($26)))));
 $27 = $fabsf$i$i$i > Math_fround(0.999899983406066894531);
 if ($27) {
  HEAPF32[$right>>2] = Math_fround(1.0);
  $28 = (($right) + 4|0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  $29 = (($right) + 8|0);
  HEAPF32[$29>>2] = Math_fround(0.0);
  $53 = Math_fround(0.0);$56 = Math_fround(0.0);$59 = Math_fround(1.0);
 } else {
  $30 = Math_fround($26 * Math_fround(0.0));
  $31 = Math_fround($32 - $30);
  $33 = Math_fround($34 * Math_fround(0.0));
  $35 = Math_fround($32 * Math_fround(0.0));
  $36 = Math_fround($33 - $35);
  $37 = Math_fround($30 - $34);
  HEAPF32[$right>>2] = $31;
  $38 = (($right) + 4|0);
  HEAPF32[$38>>2] = $36;
  $39 = (($right) + 8|0);
  HEAPF32[$39>>2] = $37;
  $40 = Math_fround($31 * $31);
  $41 = Math_fround($36 * $36);
  $42 = Math_fround($40 + $41);
  $43 = Math_fround($37 * $37);
  $44 = Math_fround($43 + $42);
  $45 = (Math_fround(Math_sqrt((Math_fround($44)))));
  $46 = $45 > Math_fround(0.0);
  if ($46) {
   $47 = Math_fround(Math_fround(1.0) / $45);
   $48 = Math_fround($31 * $47);
   HEAPF32[$right>>2] = $48;
   $49 = Math_fround($36 * $47);
   HEAPF32[$38>>2] = $49;
   $50 = Math_fround($37 * $47);
   HEAPF32[$39>>2] = $50;
   $53 = $50;$56 = $49;$59 = $48;
  } else {
   $53 = $37;$56 = $36;$59 = $31;
  }
 }
 $51 = Math_fround(HEAPF32[$13>>2]);
 $52 = Math_fround($53 * $51);
 $54 = Math_fround(HEAPF32[$14>>2]);
 $55 = Math_fround($56 * $54);
 $57 = Math_fround($52 - $55);
 $58 = Math_fround($59 * $54);
 $60 = Math_fround(HEAPF32[$dir>>2]);
 $61 = Math_fround($53 * $60);
 $62 = Math_fround($58 - $61);
 $63 = Math_fround($56 * $60);
 $64 = Math_fround($59 * $51);
 $65 = Math_fround($63 - $64);
 HEAPF32[$up>>2] = $57;
 $66 = (($up) + 4|0);
 HEAPF32[$66>>2] = $62;
 $67 = (($up) + 8|0);
 HEAPF32[$67>>2] = $65;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu9ContainerC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAPF32[$2>>2] = Math_fround(2.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu9ContainerC2ERKS1_($this,$object) {
 $this = $this|0;
 $object = $object|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAPF32[$2>>2] = Math_fround(2.0);
 $3 = (($object) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 (__ZN5physx2Gu9Container7SetSizeEj($this,$4)|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($object) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $8 << 2;
 _memcpy(($5|0),($7|0),($9|0))|0;
 $10 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu9ContaineraSERKS1_($this,$object) {
 $this = $this|0;
 $object = $object|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($object) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 (__ZN5physx2Gu9Container7SetSizeEj($this,$1)|0);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($object) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $6 << 2;
 _memcpy(($3|0),($5|0),($7|0))|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($this) + 4|0);
 HEAP32[$9>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu9ContainerD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN5physx2Gu9Container5EmptyEv($this)|0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu9Container8ContainsEjPj($this,$entry,$location) {
 $this = $this|0;
 $entry = $entry|0;
 $location = $location|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (($this) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $i$02 = 0;
   while(1) {
    $7 = (($4) + ($i$02<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==($entry|0);
    $6 = (($i$02) + 1)|0;
    if ($9) {
     break;
    }
    $5 = ($6>>>0)<($1>>>0);
    if ($5) {
     $i$02 = $6;
    } else {
     $$0 = 0;
     break L1;
    }
   }
   $10 = ($location|0)==(0|0);
   if ($10) {
    $$0 = 1;
   } else {
    HEAP32[$location>>2] = $i$02;
    $$0 = 1;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($this,$max_entries,$entries,$allow_resize) {
 $this = $this|0;
 $max_entries = $max_entries|0;
 $entries = $entries|0;
 $allow_resize = $allow_resize|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $$pre = (($this) + 12|0);
 if (!($3)) {
  $4 = HEAP32[$$pre>>2]|0;
  $5 = ($4|0)>(-1);
  if ($5) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
   HEAP32[$1>>2] = 0;
  }
 }
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$this>>2] = $max_entries;
 HEAP32[$1>>2] = $entries;
 if ($allow_resize) {
  $7 = Math_fround(HEAPF32[$$pre>>2]);
  $8 = Math_fround(-$7);
  HEAPF32[$$pre>>2] = $8;
  STACKTOP = sp;return;
 } else {
  HEAP32[$$pre>>2] = -1;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu9Container6ResizeEj($this,$needed) {
 $this = $this|0;
 $needed = $needed|0;
 var $$ = 0, $$$i$i$i = 0, $$0 = 0, $$arith = 0, $$overflow = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0;
 var $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 $4 = (HEAP32[tempDoublePtr>>2]=$2,Math_fround(HEAPF32[tempDoublePtr>>2]));
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (Math_fround(Math_abs((Math_fround($4)))));
 $6 = $4 > Math_fround(0.0);
 $7 = HEAP32[$this>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $16 = 2;
 } else {
  $9 = (Math_fround(($7>>>0)));
  $10 = Math_fround($5 * $9);
  $11 = (~~(($10))>>>0);
  $16 = $11;
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($needed))|0;
 $15 = ($16>>>0)<($14>>>0);
 $$ = $15 ? $14 : $16;
 HEAP32[$this>>2] = $$;
 $$arith = $$<<2;
 $$overflow = ($$>>>0)>(1073741823);
 $17 = $$overflow ? -1 : $$arith;
 $18 = ($17|0)==(0);
 if ($18) {
  $30 = $13;$34 = 0;
 } else {
  $19 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (__Z15PxGetFoundationv()|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (FUNCTION_TABLE_ii[$26 & 4095]($23)|0);
  $$$i$i$i = $27 ? 546280 : 546248;
  $28 = (FUNCTION_TABLE_iiiiii[$22 & 255]($19,$17,$$$i$i$i,546160,89)|0);
  $$pre = HEAP32[$12>>2]|0;
  $30 = $$pre;$34 = $28;
 }
 $29 = ($30|0)==(0);
 if (!($29)) {
  $31 = (($this) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $30 << 2;
  _memcpy(($34|0),($32|0),($33|0))|0;
 }
 $35 = (($this) + 8|0);
 if ($6) {
  $36 = HEAP32[$35>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$36);
  HEAP32[$35>>2] = 0;
 }
 HEAP32[$35>>2] = $34;
 HEAPF32[$1>>2] = $5;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu9Container5EmptyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$5);
   HEAP32[$4>>2] = 0;
  }
  HEAP32[$this>>2] = 0;
 }
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Gu9Container7SetSizeEj($this,$nb) {
 $this = $this|0;
 $nb = $nb|0;
 var $$$i$i$i = 0, $$0 = 0, $$arith = 0, $$overflow = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (($this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$5);
   HEAP32[$4>>2] = 0;
  }
  HEAP32[$this>>2] = 0;
 }
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = ($nb|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$this>>2] = $nb;
 $$arith = $nb<<2;
 $$overflow = ($nb>>>0)>(1073741823);
 $9 = $$overflow ? -1 : $$arith;
 $10 = ($9|0)==(0);
 if ($10) {
  $22 = 0;
 } else {
  $11 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z15PxGetFoundationv()|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
  $$$i$i$i = $19 ? 546280 : 546248;
  $20 = (FUNCTION_TABLE_iiiiii[$14 & 255]($11,$9,$$$i$i$i,546160,144)|0);
  $22 = $20;
 }
 $21 = (($this) + 8|0);
 HEAP32[$21>>2] = $22;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_2Cm8Matrix34E($agg$result,$absPose) {
 $agg$result = $agg$result|0;
 $absPose = $absPose|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$absPose>>2]);
 $1 = (($absPose) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($absPose) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$agg$result>>2] = $0;
 $5 = (($agg$result) + 4|0);
 HEAPF32[$5>>2] = $2;
 $6 = (($agg$result) + 8|0);
 HEAPF32[$6>>2] = $4;
 $7 = (($agg$result) + 12|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($absPose) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($absPose) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($absPose) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($agg$result) + 16|0);
 HEAPF32[$14>>2] = $9;
 $15 = (($agg$result) + 20|0);
 HEAPF32[$15>>2] = $11;
 $16 = (($agg$result) + 24|0);
 HEAPF32[$16>>2] = $13;
 $17 = (($agg$result) + 28|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($absPose) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($absPose) + 28|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($absPose) + 32|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($agg$result) + 32|0);
 HEAPF32[$24>>2] = $19;
 $25 = (($agg$result) + 36|0);
 HEAPF32[$25>>2] = $21;
 $26 = (($agg$result) + 40|0);
 HEAPF32[$26>>2] = $23;
 $27 = (($agg$result) + 44|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($absPose) + 36|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($absPose) + 40|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($absPose) + 44|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($agg$result) + 48|0);
 HEAPF32[$34>>2] = $29;
 $35 = (($agg$result) + 52|0);
 HEAPF32[$35>>2] = $31;
 $36 = (($agg$result) + 56|0);
 HEAPF32[$36>>2] = $33;
 $37 = (($agg$result) + 60|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_11PxTransformE($agg$result,$tr) {
 $agg$result = $agg$result|0;
 $tr = $tr|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$tr>>2]);
 $1 = Math_fround($0 + $0);
 $2 = (($tr) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 + $3);
 $5 = (($tr) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 + $6);
 $8 = (($tr) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($1 * $9);
 $11 = Math_fround($4 * $9);
 $12 = Math_fround($9 * $7);
 $13 = Math_fround($0 * $1);
 $14 = Math_fround($0 * $4);
 $15 = Math_fround($0 * $7);
 $16 = Math_fround($3 * $4);
 $17 = Math_fround($3 * $7);
 $18 = Math_fround($6 * $7);
 $19 = Math_fround(Math_fround(1.0) - $16);
 $20 = Math_fround($19 - $18);
 $21 = Math_fround($14 + $12);
 $22 = Math_fround($15 - $11);
 $23 = Math_fround($14 - $12);
 $24 = Math_fround(Math_fround(1.0) - $13);
 $25 = Math_fround($24 - $18);
 $26 = Math_fround($17 + $10);
 $27 = Math_fround($15 + $11);
 $28 = Math_fround($17 - $10);
 $29 = Math_fround($24 - $16);
 $30 = (($tr) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($tr) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($tr) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 HEAPF32[$agg$result>>2] = $20;
 $36 = (($agg$result) + 4|0);
 HEAPF32[$36>>2] = $21;
 $37 = (($agg$result) + 8|0);
 HEAPF32[$37>>2] = $22;
 $38 = (($agg$result) + 12|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($agg$result) + 16|0);
 HEAPF32[$39>>2] = $23;
 $40 = (($agg$result) + 20|0);
 HEAPF32[$40>>2] = $25;
 $41 = (($agg$result) + 24|0);
 HEAPF32[$41>>2] = $26;
 $42 = (($agg$result) + 28|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($agg$result) + 32|0);
 HEAPF32[$43>>2] = $27;
 $44 = (($agg$result) + 36|0);
 HEAPF32[$44>>2] = $28;
 $45 = (($agg$result) + 40|0);
 HEAPF32[$45>>2] = $29;
 $46 = (($agg$result) + 44|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($agg$result) + 48|0);
 HEAPF32[$47>>2] = $31;
 $48 = (($agg$result) + 52|0);
 HEAPF32[$48>>2] = $33;
 $49 = (($agg$result) + 56|0);
 HEAPF32[$49>>2] = $35;
 $50 = (($agg$result) + 60|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Debug9visualizeERKNS_16PxSphereGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($geometry,$out,$absPose,$cullbox,$0,$1,$2,$3) {
 $geometry = $geometry|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $cullbox = $cullbox|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = Math_fround($2);
 $3 = $3|0;
 var $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0;
 var $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0);
 var $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0);
 var $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $m44 = 0;
 var $phitmp$i = 0, $rotPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $m44 = sp + 88|0;
 $4 = sp;
 $rotPose = sp + 8|0;
 $5 = sp + 72|0;
 $6 = sp + 80|0;
 $7 = $0 & 1073741824;
 $8 = ($7|0)==(0);
 $9 = (0)==(0);
 $10 = $8 & $9;
 if (!($10)) {
  $11 = (($geometry) + 4|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($absPose) + 36|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($14 - $12);
  $16 = (($absPose) + 40|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($17 - $12);
  $19 = (($absPose) + 44|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($20 - $12);
  $22 = Math_fround($12 + $17);
  $23 = Math_fround($12 + $20);
  $24 = (($cullbox) + 12|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = $15 > $25;
  if ($26) {
   STACKTOP = sp;return;
  }
  $27 = Math_fround($12 + $14);
  $28 = Math_fround(HEAPF32[$cullbox>>2]);
  $29 = $28 > $27;
  if ($29) {
   STACKTOP = sp;return;
  }
  $30 = (($cullbox) + 16|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = $18 > $31;
  if ($32) {
   STACKTOP = sp;return;
  }
  $33 = (($cullbox) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = $34 > $22;
  if ($35) {
   STACKTOP = sp;return;
  }
  $36 = (($cullbox) + 20|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = $21 > $37;
  if ($38) {
   STACKTOP = sp;return;
  }
  $39 = (($cullbox) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $phitmp$i = !($40 > $23);
  if (!($phitmp$i)) {
   STACKTOP = sp;return;
  }
 }
 $41 = $0 & 8192;
 $42 = ($41|0)==(0);
 $43 = (0)==(0);
 $44 = $42 & $43;
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = Math_fround(HEAPF32[$absPose>>2]);
 $46 = (($absPose) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($absPose) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$m44>>2] = $45;
 $50 = (($m44) + 4|0);
 HEAPF32[$50>>2] = $47;
 $51 = (($m44) + 8|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($m44) + 12|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($absPose) + 12|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($absPose) + 16|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($absPose) + 20|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($m44) + 16|0);
 HEAPF32[$59>>2] = $54;
 $60 = (($m44) + 20|0);
 HEAPF32[$60>>2] = $56;
 $61 = (($m44) + 24|0);
 HEAPF32[$61>>2] = $58;
 $62 = (($m44) + 28|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($absPose) + 24|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($absPose) + 28|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($absPose) + 32|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($m44) + 32|0);
 HEAPF32[$69>>2] = $64;
 $70 = (($m44) + 36|0);
 HEAPF32[$70>>2] = $66;
 $71 = (($m44) + 40|0);
 HEAPF32[$71>>2] = $68;
 $72 = (($m44) + 44|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($absPose) + 36|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($absPose) + 40|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($absPose) + 44|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($m44) + 48|0);
 HEAPF32[$79>>2] = $74;
 $80 = (($m44) + 52|0);
 HEAPF32[$80>>2] = $76;
 $81 = (($m44) + 56|0);
 HEAPF32[$81>>2] = $78;
 $82 = (($m44) + 60|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $84 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($83,$m44)|0);
 $85 = (($geometry) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 HEAP32[$4>>2] = 100;
 $87 = (($4) + 4|0);
 HEAPF32[$87>>2] = $86;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($84,$4)|0);
 $88 = Math_fround(HEAPF32[$m44>>2]);
 HEAPF32[$rotPose>>2] = $88;
 $89 = (($rotPose) + 4|0);
 $90 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$89>>2] = $90;
 $91 = (($rotPose) + 8|0);
 $92 = Math_fround(HEAPF32[$51>>2]);
 HEAPF32[$91>>2] = $92;
 $93 = (($rotPose) + 12|0);
 $94 = Math_fround(HEAPF32[$52>>2]);
 HEAPF32[$93>>2] = $94;
 $95 = (($rotPose) + 16|0);
 $96 = Math_fround(HEAPF32[$59>>2]);
 $97 = (($rotPose) + 20|0);
 $98 = Math_fround(HEAPF32[$60>>2]);
 $99 = (($rotPose) + 24|0);
 $100 = Math_fround(HEAPF32[$61>>2]);
 $101 = (($rotPose) + 28|0);
 $102 = Math_fround(HEAPF32[$62>>2]);
 $103 = (($rotPose) + 32|0);
 $104 = Math_fround(HEAPF32[$69>>2]);
 $105 = (($rotPose) + 36|0);
 $106 = Math_fround(HEAPF32[$70>>2]);
 $107 = (($rotPose) + 40|0);
 $108 = Math_fround(HEAPF32[$71>>2]);
 $109 = (($rotPose) + 44|0);
 $110 = Math_fround(HEAPF32[$72>>2]);
 $111 = (($rotPose) + 48|0);
 $112 = Math_fround(HEAPF32[$79>>2]);
 HEAPF32[$111>>2] = $112;
 $113 = (($rotPose) + 52|0);
 $114 = Math_fround(HEAPF32[$80>>2]);
 HEAPF32[$113>>2] = $114;
 $115 = (($rotPose) + 56|0);
 $116 = Math_fround(HEAPF32[$81>>2]);
 HEAPF32[$115>>2] = $116;
 $117 = (($rotPose) + 60|0);
 $118 = Math_fround(HEAPF32[$82>>2]);
 HEAPF32[$117>>2] = $118;
 HEAPF32[$103>>2] = $96;
 HEAPF32[$105>>2] = $98;
 HEAPF32[$107>>2] = $100;
 HEAPF32[$109>>2] = $102;
 $119 = Math_fround(-$104);
 $120 = Math_fround(-$106);
 $121 = Math_fround(-$108);
 $122 = Math_fround(-$110);
 HEAPF32[$95>>2] = $119;
 HEAPF32[$97>>2] = $120;
 HEAPF32[$99>>2] = $121;
 HEAPF32[$101>>2] = $122;
 $123 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $124 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($123,$rotPose)|0);
 $125 = Math_fround(HEAPF32[$85>>2]);
 HEAP32[$5>>2] = 100;
 $126 = (($5) + 4|0);
 HEAPF32[$126>>2] = $125;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($124,$5)|0);
 $127 = Math_fround(HEAPF32[$rotPose>>2]);
 $128 = Math_fround(HEAPF32[$89>>2]);
 $129 = Math_fround(HEAPF32[$91>>2]);
 $130 = Math_fround(HEAPF32[$93>>2]);
 $131 = Math_fround(HEAPF32[$103>>2]);
 $132 = Math_fround(HEAPF32[$105>>2]);
 $133 = Math_fround(HEAPF32[$107>>2]);
 $134 = Math_fround(HEAPF32[$109>>2]);
 HEAPF32[$103>>2] = $127;
 HEAPF32[$105>>2] = $128;
 HEAPF32[$107>>2] = $129;
 HEAPF32[$109>>2] = $130;
 $135 = Math_fround(-$131);
 $136 = Math_fround(-$132);
 $137 = Math_fround(-$133);
 $138 = Math_fround(-$134);
 HEAPF32[$rotPose>>2] = $135;
 HEAPF32[$89>>2] = $136;
 HEAPF32[$91>>2] = $137;
 HEAPF32[$93>>2] = $138;
 $139 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $140 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($139,$rotPose)|0);
 $141 = Math_fround(HEAPF32[$85>>2]);
 HEAP32[$6>>2] = 100;
 $142 = (($6) + 4|0);
 HEAPF32[$142>>2] = $141;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($140,$6)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Debug9visualizeERKNS_15PxPlaneGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($0,$out,$absPose,$1,$2,$3,$4,$5) {
 $0 = $0|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = Math_fround($4);
 $5 = $5|0;
 var $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0);
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0);
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $rotPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $rotPose = sp + 8|0;
 $6 = sp;
 $7 = $2 & 8192;
 $8 = ($7|0)==(0);
 $9 = (0)==(0);
 $10 = $8 & $9;
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = Math_fround(HEAPF32[$absPose>>2]);
 $12 = (($absPose) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($absPose) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($absPose) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($absPose) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($absPose) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($absPose) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($absPose) + 28|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($absPose) + 32|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($absPose) + 36|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($absPose) + 40|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($absPose) + 44|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($rotPose) + 4|0);
 $35 = (($rotPose) + 8|0);
 $36 = (($rotPose) + 12|0);
 $37 = (($rotPose) + 16|0);
 $38 = (($rotPose) + 20|0);
 $39 = (($rotPose) + 24|0);
 $40 = (($rotPose) + 28|0);
 $41 = (($rotPose) + 32|0);
 $42 = (($rotPose) + 36|0);
 $43 = (($rotPose) + 40|0);
 $44 = (($rotPose) + 44|0);
 $45 = (($rotPose) + 48|0);
 HEAPF32[$45>>2] = $29;
 $46 = (($rotPose) + 52|0);
 HEAPF32[$46>>2] = $31;
 $47 = (($rotPose) + 56|0);
 HEAPF32[$47>>2] = $33;
 $48 = (($rotPose) + 60|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = Math_fround(-$23);
 $50 = Math_fround(-$25);
 $51 = Math_fround(-$27);
 HEAPF32[$37>>2] = $49;
 HEAPF32[$38>>2] = $50;
 HEAPF32[$39>>2] = $51;
 HEAPF32[$40>>2] = Math_fround(-0.0);
 HEAPF32[$41>>2] = $11;
 HEAPF32[$42>>2] = $13;
 HEAPF32[$43>>2] = $15;
 HEAPF32[$44>>2] = Math_fround(0.0);
 $52 = Math_fround(-$17);
 $53 = Math_fround(-$19);
 $54 = Math_fround(-$21);
 HEAPF32[$rotPose>>2] = $52;
 HEAPF32[$34>>2] = $53;
 HEAPF32[$35>>2] = $54;
 HEAPF32[$36>>2] = Math_fround(-0.0);
 $55 = (($6) + 4|0);
 $56 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $57 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($56,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(4.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($57,$6)|0);
 $58 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $59 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($58,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(16.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($59,$6)|0);
 $60 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $61 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($60,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(36.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($61,$6)|0);
 $62 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $63 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($62,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(64.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($63,$6)|0);
 $64 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $65 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($64,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(100.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($65,$6)|0);
 $66 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $67 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($66,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(144.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($67,$6)|0);
 $68 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $69 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($68,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(196.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($69,$6)|0);
 $70 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $71 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($70,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(256.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($71,$6)|0);
 $72 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $73 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($72,$rotPose)|0);
 HEAP32[$6>>2] = 100;
 HEAPF32[$55>>2] = Math_fround(324.0);
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_11DebugCircleE($73,$6)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Debug9visualizeERKNS_17PxCapsuleGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($geometry,$out,$absPose,$cullbox,$0,$1,$2,$3) {
 $geometry = $geometry|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $cullbox = $cullbox|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = Math_fround($2);
 $3 = $3|0;
 var $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0);
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $0 & 1073741824;
 $5 = ($4|0)==(0);
 $6 = (0)==(0);
 $7 = $5 & $6;
 if (!($7)) {
  $8 = (($absPose) + 36|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($absPose) + 40|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($absPose) + 44|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($geometry) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround(-$15);
  $17 = (($geometry) + 4|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($16 - $18);
  $20 = Math_fround($9 + $19);
  $21 = Math_fround($11 + Math_fround(0.0));
  $22 = Math_fround($13 + Math_fround(0.0));
  $23 = (($cullbox) + 12|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = $20 > $24;
  if ($25) {
   STACKTOP = sp;return;
  }
  $26 = Math_fround($15 + $18);
  $27 = Math_fround($9 + $26);
  $28 = Math_fround(HEAPF32[$cullbox>>2]);
  $29 = $28 > $27;
  if ($29) {
   STACKTOP = sp;return;
  }
  $30 = (($cullbox) + 16|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = $21 > $31;
  if ($32) {
   STACKTOP = sp;return;
  }
  $33 = (($cullbox) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = $34 > $21;
  if ($35) {
   STACKTOP = sp;return;
  }
  $36 = (($cullbox) + 20|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = $22 > $37;
  if ($38) {
   STACKTOP = sp;return;
  }
  $39 = (($cullbox) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $phitmp$i = !($40 > $22);
  if (!($phitmp$i)) {
   STACKTOP = sp;return;
  }
 }
 $41 = $0 & 8192;
 $42 = ($41|0)==(0);
 $43 = (0)==(0);
 $44 = $42 & $43;
 if ($44) {
  STACKTOP = sp;return;
 }
 (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $45 = (($geometry) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($geometry) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 (__ZN5physx2Cm12RenderOutput13outputCapsuleEffRKNS0_8Matrix34E($out,$46,$48,$absPose)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Debug9visualizeERKNS_13PxBoxGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($geometry,$out,$absPose,$cullbox,$0,$1,$2,$3) {
 $geometry = $geometry|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $cullbox = $cullbox|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = Math_fround($2);
 $3 = $3|0;
 var $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0;
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $m44 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $m44 = sp + 32|0;
 $4 = sp;
 $5 = $0 & 1073741824;
 $6 = ($5|0)==(0);
 $7 = (0)==(0);
 $8 = $6 & $7;
 if (!($8)) {
  $9 = (($absPose) + 36|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($absPose) + 40|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($absPose) + 44|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($geometry) + 8|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($geometry) + 12|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($cullbox) + 12|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = $10 > $20;
  if ($21) {
   STACKTOP = sp;return;
  }
  $22 = (($geometry) + 4|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround(HEAPF32[$cullbox>>2]);
  $25 = $24 > $23;
  if ($25) {
   STACKTOP = sp;return;
  }
  $26 = (($cullbox) + 16|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = $12 > $27;
  if ($28) {
   STACKTOP = sp;return;
  }
  $29 = (($cullbox) + 4|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = $30 > $16;
  if ($31) {
   STACKTOP = sp;return;
  }
  $32 = (($cullbox) + 20|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = $14 > $33;
  if ($34) {
   STACKTOP = sp;return;
  }
  $35 = (($cullbox) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $phitmp$i = !($36 > $18);
  if (!($phitmp$i)) {
   STACKTOP = sp;return;
  }
 }
 $37 = $0 & 8192;
 $38 = ($37|0)==(0);
 $39 = (0)==(0);
 $40 = $38 & $39;
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = Math_fround(HEAPF32[$absPose>>2]);
 $42 = (($absPose) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($absPose) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 HEAPF32[$m44>>2] = $41;
 $46 = (($m44) + 4|0);
 HEAPF32[$46>>2] = $43;
 $47 = (($m44) + 8|0);
 HEAPF32[$47>>2] = $45;
 $48 = (($m44) + 12|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($absPose) + 12|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($absPose) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($absPose) + 20|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($m44) + 16|0);
 HEAPF32[$55>>2] = $50;
 $56 = (($m44) + 20|0);
 HEAPF32[$56>>2] = $52;
 $57 = (($m44) + 24|0);
 HEAPF32[$57>>2] = $54;
 $58 = (($m44) + 28|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($absPose) + 24|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($absPose) + 28|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($absPose) + 32|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($m44) + 32|0);
 HEAPF32[$65>>2] = $60;
 $66 = (($m44) + 36|0);
 HEAPF32[$66>>2] = $62;
 $67 = (($m44) + 40|0);
 HEAPF32[$67>>2] = $64;
 $68 = (($m44) + 44|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($absPose) + 36|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($absPose) + 40|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($absPose) + 44|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($m44) + 48|0);
 HEAPF32[$75>>2] = $70;
 $76 = (($m44) + 52|0);
 HEAPF32[$76>>2] = $72;
 $77 = (($m44) + 56|0);
 HEAPF32[$77>>2] = $74;
 $78 = (($m44) + 60|0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = (__ZN5physx2Cm12RenderOutputlsEj($out,-65281)|0);
 $80 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($79,$m44)|0);
 $81 = (($geometry) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround(-$82);
 $84 = (($geometry) + 8|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround(-$85);
 $87 = (($geometry) + 12|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround(-$88);
 HEAPF32[$4>>2] = $83;
 $90 = (($4) + 4|0);
 HEAPF32[$90>>2] = $86;
 $91 = (($4) + 8|0);
 HEAPF32[$91>>2] = $89;
 $92 = (($4) + 12|0);
 HEAPF32[$92>>2] = $82;
 $93 = (($4) + 16|0);
 HEAPF32[$93>>2] = $85;
 $94 = (($4) + 20|0);
 HEAPF32[$94>>2] = $88;
 $95 = (($4) + 24|0);
 HEAP8[$95>>0] = 1;
 (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_8DebugBoxE($80,$4)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Debug9visualizeERKNS_20PxConvexMeshGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($geometry,$out,$absPose,$cullbox,$0,$1,$fscale,$numMaterials) {
 $geometry = $geometry|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $cullbox = $cullbox|0;
 $0 = $0|0;
 $1 = $1|0;
 $fscale = Math_fround($fscale);
 $numMaterials = $numMaterials|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($geometry) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNK5physx2Gu10ConvexMesh14debugVisualizeERNS_2Cm12RenderOutputERKNS2_8Matrix34ERKNS_9PxBounds3Eyfj($3,$out,$absPose,$cullbox,$0,$1,$fscale,$numMaterials);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Debug9visualizeERKNS_22PxTriangleMeshGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($geometry,$out,$absPose,$cullbox,$0,$1,$fscale,$numMaterials) {
 $geometry = $geometry|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $cullbox = $cullbox|0;
 $0 = $0|0;
 $1 = $1|0;
 $fscale = Math_fround($fscale);
 $numMaterials = $numMaterials|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($geometry) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($geometry) + 4|0);
 __ZNK5physx2Gu12TriangleMesh14debugVisualizeERNS_2Cm12RenderOutputERKNS2_8Matrix34ERKNS_11PxMeshScaleERKNS_9PxBounds3Eyfj($3,$out,$absPose,$4,$cullbox,$0,$1,$fscale,$numMaterials);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Debug9visualizeERKNS_21PxHeightFieldGeometryERNS_2Cm12RenderOutputERKNS5_8Matrix34ERKNS_9PxBounds3Eyfj($hfGeometry,$out,$absPose,$cullbox,$0,$1,$2,$3) {
 $hfGeometry = $hfGeometry|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $cullbox = $cullbox|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = Math_fround($2);
 $3 = $3|0;
 var $$sink$i = 0, $$sink$in$i = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0;
 var $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0);
 var $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0);
 var $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0);
 var $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $boxGeometry = 0, $currentTriangle = 0, $exitcond = 0, $exitcond84 = 0, $exitcond85 = 0, $i$079 = 0, $i1$075 = 0;
 var $i3$073 = 0, $mat = 0, $midt = 0, $overflow = 0, $pose0 = 0, $pose1 = 0, $quat = 0, $segments$080 = 0, $segments2$074 = 0, $segments2$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $midt = sp + 40|0;
 $pose0 = sp + 208|0;
 $boxGeometry = sp + 192|0;
 $mat = sp + 104|0;
 $quat = sp + 144|0;
 $pose1 = sp + 160|0;
 $4 = sp + 240|0;
 $overflow = sp + 236|0;
 $currentTriangle = sp;
 $5 = sp + 237|0;
 $6 = sp + 238|0;
 $7 = sp + 239|0;
 $8 = (($hfGeometry) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $0 & 8192;
 $11 = ($10|0)==(0);
 $12 = (0)==(0);
 $13 = $11 & $12;
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = $0 & 1073741824;
 $15 = ($14|0)==(0);
 $16 = (0)==(0);
 $17 = $15 & $16;
 HEAPF32[$midt>>2] = Math_fround(1.0);
 $18 = (($midt) + 4|0);
 $19 = (($midt) + 20|0);
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($midt) + 24|0);
 $21 = (($midt) + 40|0);
 ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($midt) + 44|0);
 $23 = (($midt) + 60|0);
 ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($hfGeometry) + 8|0);
 $25 = (($hfGeometry) + 12|0);
 $26 = (($hfGeometry) + 16|0);
 $27 = (($9) + 16|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($9) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = Math_imul($30, $28)|0;
 $32 = $31 << 1;
 $33 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
 (__ZN5physx2Cm12RenderOutputlsEj($33,-256)|0);
 if (!($17)) {
  $34 = (($cullbox) + 12|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround(HEAPF32[$cullbox>>2]);
  $37 = Math_fround($35 + $36);
  $38 = (($cullbox) + 16|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($cullbox) + 4|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($39 + $41);
  $43 = (($cullbox) + 20|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($cullbox) + 8|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($44 + $46);
  $48 = Math_fround($37 * Math_fround(0.5));
  $49 = Math_fround($42 * Math_fround(0.5));
  $50 = Math_fround($47 * Math_fround(0.5));
  $51 = Math_fround($35 - $36);
  $52 = Math_fround($39 - $41);
  $53 = Math_fround($44 - $46);
  $54 = Math_fround($51 * Math_fround(0.5));
  $55 = Math_fround($52 * Math_fround(0.5));
  $56 = Math_fround($53 * Math_fround(0.5));
  HEAPF32[$pose0>>2] = Math_fround(0.0);
  $57 = (($pose0) + 4|0);
  HEAPF32[$57>>2] = Math_fround(0.0);
  $58 = (($pose0) + 8|0);
  HEAPF32[$58>>2] = Math_fround(0.0);
  $59 = (($pose0) + 12|0);
  HEAPF32[$59>>2] = Math_fround(1.0);
  $60 = (($pose0) + 16|0);
  HEAPF32[$60>>2] = $48;
  $61 = (($pose0) + 20|0);
  HEAPF32[$61>>2] = $49;
  $62 = (($pose0) + 24|0);
  HEAPF32[$62>>2] = $50;
  HEAP32[$boxGeometry>>2] = 3;
  $63 = (($boxGeometry) + 4|0);
  HEAPF32[$63>>2] = $54;
  $64 = (($boxGeometry) + 8|0);
  HEAPF32[$64>>2] = $55;
  $65 = (($boxGeometry) + 12|0);
  HEAPF32[$65>>2] = $56;
  $66 = Math_fround(HEAPF32[$absPose>>2]);
  HEAPF32[$mat>>2] = $66;
  $67 = (($mat) + 4|0);
  $68 = (($absPose) + 4|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  HEAPF32[$67>>2] = $69;
  $70 = (($mat) + 8|0);
  $71 = (($absPose) + 8|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  HEAPF32[$70>>2] = $72;
  $73 = (($mat) + 12|0);
  $74 = (($absPose) + 12|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  HEAPF32[$73>>2] = $75;
  $76 = (($mat) + 16|0);
  $77 = (($absPose) + 16|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  HEAPF32[$76>>2] = $78;
  $79 = (($mat) + 20|0);
  $80 = (($absPose) + 20|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  HEAPF32[$79>>2] = $81;
  $82 = (($mat) + 24|0);
  $83 = (($absPose) + 24|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$82>>2] = $84;
  $85 = (($mat) + 28|0);
  $86 = (($absPose) + 28|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  HEAPF32[$85>>2] = $87;
  $88 = (($mat) + 32|0);
  $89 = (($absPose) + 32|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  HEAPF32[$88>>2] = $90;
  __ZN5physx6PxQuatC2ERKNS_7PxMat33E($quat,$mat);
  $91 = Math_fround(HEAPF32[$quat>>2]);
  HEAPF32[$pose1>>2] = $91;
  $92 = (($pose1) + 4|0);
  $93 = (($quat) + 4|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  HEAPF32[$92>>2] = $94;
  $95 = (($pose1) + 8|0);
  $96 = (($quat) + 8|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  HEAPF32[$95>>2] = $97;
  $98 = (($pose1) + 12|0);
  $99 = (($quat) + 12|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  HEAPF32[$98>>2] = $100;
  $101 = (($pose1) + 16|0);
  $102 = (($absPose) + 36|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  HEAPF32[$101>>2] = $103;
  $104 = (($pose1) + 20|0);
  $105 = (($absPose) + 40|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  HEAPF32[$104>>2] = $106;
  $107 = (($pose1) + 24|0);
  $108 = (($absPose) + 44|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  HEAPF32[$107>>2] = $109;
  $110 = $31 << 3;
  $111 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($4,$110,546432,314)|0);
  HEAP8[$overflow>>0] = 0;
  $112 = (__ZN5physx11PxMeshQuery22findOverlapHeightFieldERKNS_10PxGeometryERKNS_11PxTransformERKNS_21PxHeightFieldGeometryES6_PjjjRb($boxGeometry,$pose0,$hfGeometry,$pose1,$111,$32,0,$overflow)|0);
  $113 = ($112*3)|0;
  $114 = (($out) + 100|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($115) + 16|0);
  $117 = (($115) + 20|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($118) + ($113))|0;
  __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($116,$119);
  $120 = ($112|0)==(0);
  if (!($120)) {
   $121 = HEAP32[$114>>2]|0;
   $122 = (($121) + 16|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($123) + ($118<<5)|0);
   $125 = (($currentTriangle) + 4|0);
   $126 = (($currentTriangle) + 8|0);
   $127 = (($currentTriangle) + 12|0);
   $128 = (($currentTriangle) + 16|0);
   $129 = (($currentTriangle) + 20|0);
   $130 = (($currentTriangle) + 24|0);
   $131 = (($currentTriangle) + 28|0);
   $132 = (($currentTriangle) + 32|0);
   $i$079 = 0;$segments$080 = $124;
   while(1) {
    $133 = (($111) + ($i$079<<2)|0);
    $134 = HEAP32[$133>>2]|0;
    __ZN5physx11PxMeshQuery11getTriangleERKNS_21PxHeightFieldGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($hfGeometry,$pose1,$134,$currentTriangle,0,0);
    $135 = HEAP32[$9>>2]|0;
    $136 = (($135) + 68|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = (FUNCTION_TABLE_iii[$137 & 4095]($9,$134)|0);
    $139 = (($138&65535) % 48)&-1;
    $140 = $139&65535;
    $141 = (546384 + ($140<<2)|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = Math_fround(HEAPF32[$currentTriangle>>2]);
    $144 = Math_fround(HEAPF32[$125>>2]);
    $145 = Math_fround(HEAPF32[$126>>2]);
    $146 = Math_fround(HEAPF32[$127>>2]);
    $147 = Math_fround(HEAPF32[$128>>2]);
    $148 = Math_fround(HEAPF32[$129>>2]);
    HEAPF32[$segments$080>>2] = $143;
    $149 = (($segments$080) + 4|0);
    HEAPF32[$149>>2] = $144;
    $150 = (($segments$080) + 8|0);
    HEAPF32[$150>>2] = $145;
    $151 = (($segments$080) + 12|0);
    HEAP32[$151>>2] = $142;
    $152 = (($segments$080) + 16|0);
    HEAPF32[$152>>2] = $146;
    $153 = (($segments$080) + 20|0);
    HEAPF32[$153>>2] = $147;
    $154 = (($segments$080) + 24|0);
    HEAPF32[$154>>2] = $148;
    $155 = (($segments$080) + 28|0);
    HEAP32[$155>>2] = $142;
    $156 = Math_fround(HEAPF32[$127>>2]);
    $157 = Math_fround(HEAPF32[$128>>2]);
    $158 = Math_fround(HEAPF32[$129>>2]);
    $159 = Math_fround(HEAPF32[$130>>2]);
    $160 = Math_fround(HEAPF32[$131>>2]);
    $161 = Math_fround(HEAPF32[$132>>2]);
    $162 = (($segments$080) + 32|0);
    HEAPF32[$162>>2] = $156;
    $163 = (($segments$080) + 36|0);
    HEAPF32[$163>>2] = $157;
    $164 = (($segments$080) + 40|0);
    HEAPF32[$164>>2] = $158;
    $165 = (($segments$080) + 44|0);
    HEAP32[$165>>2] = $142;
    $166 = (($segments$080) + 48|0);
    HEAPF32[$166>>2] = $159;
    $167 = (($segments$080) + 52|0);
    HEAPF32[$167>>2] = $160;
    $168 = (($segments$080) + 56|0);
    HEAPF32[$168>>2] = $161;
    $169 = (($segments$080) + 60|0);
    HEAP32[$169>>2] = $142;
    $170 = Math_fround(HEAPF32[$130>>2]);
    $171 = Math_fround(HEAPF32[$131>>2]);
    $172 = Math_fround(HEAPF32[$132>>2]);
    $173 = Math_fround(HEAPF32[$currentTriangle>>2]);
    $174 = Math_fround(HEAPF32[$125>>2]);
    $175 = Math_fround(HEAPF32[$126>>2]);
    $176 = (($segments$080) + 64|0);
    HEAPF32[$176>>2] = $170;
    $177 = (($segments$080) + 68|0);
    HEAPF32[$177>>2] = $171;
    $178 = (($segments$080) + 72|0);
    HEAPF32[$178>>2] = $172;
    $179 = (($segments$080) + 76|0);
    HEAP32[$179>>2] = $142;
    $180 = (($segments$080) + 80|0);
    HEAPF32[$180>>2] = $173;
    $181 = (($segments$080) + 84|0);
    HEAPF32[$181>>2] = $174;
    $182 = (($segments$080) + 88|0);
    HEAPF32[$182>>2] = $175;
    $183 = (($segments$080) + 92|0);
    HEAP32[$183>>2] = $142;
    $184 = (($segments$080) + 96|0);
    $185 = (($i$079) + 1)|0;
    $exitcond85 = ($185|0)==($112|0);
    if ($exitcond85) {
     break;
    } else {
     $i$079 = $185;$segments$080 = $184;
    }
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$111);
  STACKTOP = sp;return;
 }
 $186 = ($31*12)|0;
 $187 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($6,$186,546432,345)|0);
 $188 = ($31|0)==(0);
 if (!($188)) {
  $189 = HEAP32[$29>>2]|0;
  $190 = (($9) + 36|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = (($absPose) + 4|0);
  $193 = (($absPose) + 8|0);
  $194 = (($absPose) + 12|0);
  $195 = (($absPose) + 16|0);
  $196 = (($absPose) + 20|0);
  $197 = (($absPose) + 24|0);
  $198 = (($absPose) + 28|0);
  $199 = (($absPose) + 32|0);
  $200 = (($absPose) + 36|0);
  $201 = (($absPose) + 40|0);
  $202 = (($absPose) + 44|0);
  $i1$075 = 0;
  while(1) {
   $203 = (($i1$075>>>0) / ($189>>>0))&-1;
   $204 = (($i1$075>>>0) % ($189>>>0))&-1;
   $205 = (Math_fround(($203>>>0)));
   $206 = (($191) + ($i1$075<<2)|0);
   $207 = HEAP16[$206>>1]|0;
   $208 = (Math_fround(($207<<16>>16)));
   $209 = (Math_fround(($204>>>0)));
   $210 = Math_fround(HEAPF32[$25>>2]);
   $211 = Math_fround($205 * $210);
   $212 = Math_fround(HEAPF32[$24>>2]);
   $213 = Math_fround($208 * $212);
   $214 = Math_fround(HEAPF32[$26>>2]);
   $215 = Math_fround($209 * $214);
   $216 = Math_fround(HEAPF32[$absPose>>2]);
   $217 = Math_fround($211 * $216);
   $218 = Math_fround(HEAPF32[$192>>2]);
   $219 = Math_fround($211 * $218);
   $220 = Math_fround(HEAPF32[$193>>2]);
   $221 = Math_fround($211 * $220);
   $222 = Math_fround(HEAPF32[$194>>2]);
   $223 = Math_fround($213 * $222);
   $224 = Math_fround(HEAPF32[$195>>2]);
   $225 = Math_fround($213 * $224);
   $226 = Math_fround(HEAPF32[$196>>2]);
   $227 = Math_fround($213 * $226);
   $228 = Math_fround($217 + $223);
   $229 = Math_fround($219 + $225);
   $230 = Math_fround($221 + $227);
   $231 = Math_fround(HEAPF32[$197>>2]);
   $232 = Math_fround($215 * $231);
   $233 = Math_fround(HEAPF32[$198>>2]);
   $234 = Math_fround($215 * $233);
   $235 = Math_fround(HEAPF32[$199>>2]);
   $236 = Math_fround($215 * $235);
   $237 = Math_fround($228 + $232);
   $238 = Math_fround($229 + $234);
   $239 = Math_fround($230 + $236);
   $240 = Math_fround(HEAPF32[$200>>2]);
   $241 = Math_fround($237 + $240);
   $242 = Math_fround(HEAPF32[$201>>2]);
   $243 = Math_fround($238 + $242);
   $244 = Math_fround(HEAPF32[$202>>2]);
   $245 = Math_fround($239 + $244);
   $246 = (($187) + (($i1$075*12)|0)|0);
   HEAPF32[$246>>2] = $241;
   $247 = ((($187) + (($i1$075*12)|0)|0) + 4|0);
   HEAPF32[$247>>2] = $243;
   $248 = ((($187) + (($i1$075*12)|0)|0) + 8|0);
   HEAPF32[$248>>2] = $245;
   $249 = (($i1$075) + 1)|0;
   $exitcond84 = ($249|0)==($31|0);
   if ($exitcond84) {
    break;
   } else {
    $i1$075 = $249;
   }
  }
 }
 $250 = ($31*6)|0;
 $251 = (($out) + 100|0);
 $252 = HEAP32[$251>>2]|0;
 $253 = (($252) + 16|0);
 $254 = (($252) + 20|0);
 $255 = HEAP32[$254>>2]|0;
 $256 = (($255) + ($250))|0;
 __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($253,$256);
 $257 = ($32|0)==(0);
 if (!($257)) {
  $258 = HEAP32[$251>>2]|0;
  $259 = (($258) + 16|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = (($260) + ($255<<5)|0);
  $262 = (($9) + 36|0);
  $263 = $31 << 1;
  $i3$073 = 0;$segments2$074 = $261;
  while(1) {
   $264 = $i3$073 >>> 1;
   $265 = HEAP32[$29>>2]|0;
   $266 = (($264>>>0) / ($265>>>0))&-1;
   $267 = HEAP32[$27>>2]|0;
   $268 = (($267) + -1)|0;
   $269 = ($266>>>0)<($268>>>0);
   if ($269) {
    $270 = (($264>>>0) % ($265>>>0))&-1;
    $271 = (($265) + -1)|0;
    $272 = ($270>>>0)<($271>>>0);
    if ($272) {
     $273 = $i3$073 & 1;
     $274 = ($273|0)==(0);
     $275 = HEAP32[$262>>2]|0;
     if ($274) {
      $276 = ((($275) + ($264<<2)|0) + 2|0);
      $$sink$in$i = $276;
     } else {
      $277 = ((($275) + ($264<<2)|0) + 3|0);
      $$sink$in$i = $277;
     }
     $$sink$i = HEAP8[$$sink$in$i>>0]|0;
     $278 = $$sink$i & 127;
     $279 = ($278<<24>>24)==(127);
     if ($279) {
      $segments2$1 = $segments2$074;
     } else {
      $280 = ((($275) + ($264<<2)|0) + 2|0);
      $281 = HEAP8[$280>>0]|0;
      $282 = ($281<<24>>24)<(0);
      do {
       if ($282) {
        if ($274) {
         $283 = (($265) + ($264))|0;
         $284 = (($264) + 1)|0;
         $285 = (($284) + ($265))|0;
         $301 = $283;$308 = $264;$325 = $285;
         break;
        } else {
         $286 = (($264) + 1)|0;
         $287 = (($265) + ($286))|0;
         $301 = $286;$308 = $287;$325 = $264;
         break;
        }
       } else {
        $288 = (($264) + 1)|0;
        if ($274) {
         $289 = (($265) + ($264))|0;
         $301 = $264;$308 = $288;$325 = $289;
         break;
        } else {
         $290 = (($265) + ($288))|0;
         $291 = (($265) + ($264))|0;
         $301 = $290;$308 = $291;$325 = $288;
         break;
        }
       }
      } while(0);
      $292 = HEAP32[$9>>2]|0;
      $293 = (($292) + 68|0);
      $294 = HEAP32[$293>>2]|0;
      $295 = (FUNCTION_TABLE_iii[$294 & 4095]($9,$i3$073)|0);
      $296 = (($295&65535) % 48)&-1;
      $297 = $296&65535;
      $298 = (546384 + ($297<<2)|0);
      $299 = HEAP32[$298>>2]|0;
      $300 = (($187) + (($301*12)|0)|0);
      $302 = Math_fround(HEAPF32[$300>>2]);
      $303 = ((($187) + (($301*12)|0)|0) + 4|0);
      $304 = Math_fround(HEAPF32[$303>>2]);
      $305 = ((($187) + (($301*12)|0)|0) + 8|0);
      $306 = Math_fround(HEAPF32[$305>>2]);
      $307 = (($187) + (($308*12)|0)|0);
      $309 = Math_fround(HEAPF32[$307>>2]);
      $310 = ((($187) + (($308*12)|0)|0) + 4|0);
      $311 = Math_fround(HEAPF32[$310>>2]);
      $312 = ((($187) + (($308*12)|0)|0) + 8|0);
      $313 = Math_fround(HEAPF32[$312>>2]);
      HEAPF32[$segments2$074>>2] = $302;
      $314 = (($segments2$074) + 4|0);
      HEAPF32[$314>>2] = $304;
      $315 = (($segments2$074) + 8|0);
      HEAPF32[$315>>2] = $306;
      $316 = (($segments2$074) + 12|0);
      HEAP32[$316>>2] = $299;
      $317 = (($segments2$074) + 16|0);
      HEAPF32[$317>>2] = $309;
      $318 = (($segments2$074) + 20|0);
      HEAPF32[$318>>2] = $311;
      $319 = (($segments2$074) + 24|0);
      HEAPF32[$319>>2] = $313;
      $320 = (($segments2$074) + 28|0);
      HEAP32[$320>>2] = $299;
      $321 = Math_fround(HEAPF32[$307>>2]);
      $322 = Math_fround(HEAPF32[$310>>2]);
      $323 = Math_fround(HEAPF32[$312>>2]);
      $324 = (($187) + (($325*12)|0)|0);
      $326 = Math_fround(HEAPF32[$324>>2]);
      $327 = ((($187) + (($325*12)|0)|0) + 4|0);
      $328 = Math_fround(HEAPF32[$327>>2]);
      $329 = ((($187) + (($325*12)|0)|0) + 8|0);
      $330 = Math_fround(HEAPF32[$329>>2]);
      $331 = (($segments2$074) + 32|0);
      HEAPF32[$331>>2] = $321;
      $332 = (($segments2$074) + 36|0);
      HEAPF32[$332>>2] = $322;
      $333 = (($segments2$074) + 40|0);
      HEAPF32[$333>>2] = $323;
      $334 = (($segments2$074) + 44|0);
      HEAP32[$334>>2] = $299;
      $335 = (($segments2$074) + 48|0);
      HEAPF32[$335>>2] = $326;
      $336 = (($segments2$074) + 52|0);
      HEAPF32[$336>>2] = $328;
      $337 = (($segments2$074) + 56|0);
      HEAPF32[$337>>2] = $330;
      $338 = (($segments2$074) + 60|0);
      HEAP32[$338>>2] = $299;
      $339 = Math_fround(HEAPF32[$324>>2]);
      $340 = Math_fround(HEAPF32[$327>>2]);
      $341 = Math_fround(HEAPF32[$329>>2]);
      $342 = Math_fround(HEAPF32[$300>>2]);
      $343 = Math_fround(HEAPF32[$303>>2]);
      $344 = Math_fround(HEAPF32[$305>>2]);
      $345 = (($segments2$074) + 64|0);
      HEAPF32[$345>>2] = $339;
      $346 = (($segments2$074) + 68|0);
      HEAPF32[$346>>2] = $340;
      $347 = (($segments2$074) + 72|0);
      HEAPF32[$347>>2] = $341;
      $348 = (($segments2$074) + 76|0);
      HEAP32[$348>>2] = $299;
      $349 = (($segments2$074) + 80|0);
      HEAPF32[$349>>2] = $342;
      $350 = (($segments2$074) + 84|0);
      HEAPF32[$350>>2] = $343;
      $351 = (($segments2$074) + 88|0);
      HEAPF32[$351>>2] = $344;
      $352 = (($segments2$074) + 92|0);
      HEAP32[$352>>2] = $299;
      $353 = (($segments2$074) + 96|0);
      $segments2$1 = $353;
     }
    } else {
     $segments2$1 = $segments2$074;
    }
   } else {
    $segments2$1 = $segments2$074;
   }
   $354 = (($i3$073) + 1)|0;
   $exitcond = ($354|0)==($263|0);
   if ($exitcond) {
    break;
   } else {
    $i3$073 = $354;$segments2$074 = $segments2$1;
   }
  }
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($7,$187);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE8recreateEj($this,$size);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16computeBoxPointsERKNS_9PxBounds3EPNS_6PxVec3E($bounds,$pts) {
 $bounds = $bounds|0;
 $pts = $pts|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$bounds>>2]);
 $1 = (($bounds) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($bounds) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$pts>>2] = $0;
 $5 = (($pts) + 4|0);
 HEAPF32[$5>>2] = $2;
 $6 = (($pts) + 8|0);
 HEAPF32[$6>>2] = $4;
 $7 = (($bounds) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$1>>2]);
 $10 = Math_fround(HEAPF32[$3>>2]);
 $11 = (($pts) + 12|0);
 HEAPF32[$11>>2] = $8;
 $12 = (($pts) + 16|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($pts) + 20|0);
 HEAPF32[$13>>2] = $10;
 $14 = Math_fround(HEAPF32[$7>>2]);
 $15 = (($bounds) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$3>>2]);
 $18 = (($pts) + 24|0);
 HEAPF32[$18>>2] = $14;
 $19 = (($pts) + 28|0);
 HEAPF32[$19>>2] = $16;
 $20 = (($pts) + 32|0);
 HEAPF32[$20>>2] = $17;
 $21 = Math_fround(HEAPF32[$bounds>>2]);
 $22 = Math_fround(HEAPF32[$15>>2]);
 $23 = Math_fround(HEAPF32[$3>>2]);
 $24 = (($pts) + 36|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($pts) + 40|0);
 HEAPF32[$25>>2] = $22;
 $26 = (($pts) + 44|0);
 HEAPF32[$26>>2] = $23;
 $27 = Math_fround(HEAPF32[$bounds>>2]);
 $28 = Math_fround(HEAPF32[$1>>2]);
 $29 = (($bounds) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($pts) + 48|0);
 HEAPF32[$31>>2] = $27;
 $32 = (($pts) + 52|0);
 HEAPF32[$32>>2] = $28;
 $33 = (($pts) + 56|0);
 HEAPF32[$33>>2] = $30;
 $34 = Math_fround(HEAPF32[$7>>2]);
 $35 = Math_fround(HEAPF32[$1>>2]);
 $36 = Math_fround(HEAPF32[$29>>2]);
 $37 = (($pts) + 60|0);
 HEAPF32[$37>>2] = $34;
 $38 = (($pts) + 64|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($pts) + 68|0);
 HEAPF32[$39>>2] = $36;
 $40 = Math_fround(HEAPF32[$7>>2]);
 $41 = Math_fround(HEAPF32[$15>>2]);
 $42 = Math_fround(HEAPF32[$29>>2]);
 $43 = (($pts) + 72|0);
 HEAPF32[$43>>2] = $40;
 $44 = (($pts) + 76|0);
 HEAPF32[$44>>2] = $41;
 $45 = (($pts) + 80|0);
 HEAPF32[$45>>2] = $42;
 $46 = Math_fround(HEAPF32[$bounds>>2]);
 $47 = Math_fround(HEAPF32[$15>>2]);
 $48 = Math_fround(HEAPF32[$29>>2]);
 $49 = (($pts) + 84|0);
 HEAPF32[$49>>2] = $46;
 $50 = (($pts) + 88|0);
 HEAPF32[$50>>2] = $47;
 $51 = (($pts) + 92|0);
 HEAPF32[$51>>2] = $48;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($agg$result,$pose) {
 $agg$result = $agg$result|0;
 $pose = $pose|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$pose>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($pose) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($pose) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($pose) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($pose) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = (($pose) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $15);
 $25 = Math_fround($21 + $24);
 $26 = (($pose) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($18 * $27);
 $29 = Math_fround($25 + $28);
 $30 = Math_fround(-$29);
 HEAPF32[$agg$result>>2] = $8;
 $31 = (($agg$result) + 4|0);
 HEAPF32[$31>>2] = $15;
 $32 = (($agg$result) + 8|0);
 HEAPF32[$32>>2] = $18;
 $33 = (($agg$result) + 12|0);
 HEAPF32[$33>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19getCapsuleTransformERKNS0_7CapsuleERf($agg$result,$capsule,$halfHeight) {
 $agg$result = $agg$result|0;
 $capsule = $capsule|0;
 $halfHeight = $halfHeight|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0;
 var $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $x = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $x = sp + 16|0;
 $0 = sp;
 $1 = (($capsule) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(HEAPF32[$capsule>>2]);
 $4 = Math_fround($2 - $3);
 $5 = (($capsule) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($capsule) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($capsule) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($capsule) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * Math_fround(0.5));
 $16 = Math_fround($9 * Math_fround(0.5));
 $17 = Math_fround($14 * Math_fround(0.5));
 $18 = Math_fround($15 + $3);
 $19 = Math_fround($16 + $8);
 $20 = Math_fround($17 + $13);
 $21 = (($agg$result) + 16|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($agg$result) + 20|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($agg$result) + 24|0);
 HEAPF32[$23>>2] = $20;
 $24 = Math_fround($4 * $4);
 $25 = Math_fround($9 * $9);
 $26 = Math_fround($24 + $25);
 $27 = Math_fround($14 * $14);
 $28 = Math_fround($26 + $27);
 $29 = (Math_fround(Math_sqrt((Math_fround($28)))));
 $30 = $29 > Math_fround(0.0);
 if ($30) {
  $31 = Math_fround(Math_fround(1.0) / $29);
  $32 = Math_fround($4 * $31);
  $33 = Math_fround($9 * $31);
  $34 = Math_fround($14 * $31);
  $37 = $32;$40 = $34;$42 = $33;
 } else {
  $37 = $4;$40 = $14;$42 = $9;
 }
 $35 = Math_fround($29 * Math_fround(0.5));
 HEAPF32[$halfHeight>>2] = $35;
 $36 = $35 > Math_fround(1.1920928955078125E-7);
 if (!($36)) {
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $87 = (($agg$result) + 4|0);
  HEAPF32[$87>>2] = Math_fround(0.0);
  $88 = (($agg$result) + 8|0);
  HEAPF32[$88>>2] = Math_fround(0.0);
  $89 = (($agg$result) + 12|0);
  HEAPF32[$89>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($37)))));
 $38 = $fabsf$i$i$i < Math_fround(0.707106769084930419921);
 if ($38) {
  $39 = Math_fround(-$40);
  $44 = Math_fround(0.0);$46 = $39;$49 = $42;
 } else {
  $41 = Math_fround(-$42);
  $44 = $41;$46 = $37;$49 = Math_fround(0.0);
 }
 $43 = Math_fround($44 * $44);
 $45 = Math_fround($46 * $46);
 $47 = Math_fround($45 + $43);
 $48 = Math_fround($49 * $49);
 $50 = Math_fround($48 + $47);
 $51 = (Math_fround(Math_sqrt((Math_fround($50)))));
 $52 = $51 > Math_fround(0.0);
 if ($52) {
  $53 = Math_fround(Math_fround(1.0) / $51);
  $54 = Math_fround($44 * $53);
  $55 = Math_fround($46 * $53);
  $56 = Math_fround($49 * $53);
  $58 = $56;$60 = $55;$63 = $54;
 } else {
  $58 = $49;$60 = $46;$63 = $44;
 }
 $57 = Math_fround($42 * $58);
 $59 = Math_fround($40 * $60);
 $61 = Math_fround($57 - $59);
 $62 = Math_fround($40 * $63);
 $64 = Math_fround($37 * $58);
 $65 = Math_fround($62 - $64);
 $66 = Math_fround($37 * $60);
 $67 = Math_fround($42 * $63);
 $68 = Math_fround($66 - $67);
 HEAPF32[$x>>2] = $37;
 $69 = (($x) + 4|0);
 HEAPF32[$69>>2] = $42;
 $70 = (($x) + 8|0);
 HEAPF32[$70>>2] = $40;
 $71 = (($x) + 12|0);
 HEAPF32[$71>>2] = $63;
 $72 = (($x) + 16|0);
 HEAPF32[$72>>2] = $60;
 $73 = (($x) + 20|0);
 HEAPF32[$73>>2] = $58;
 $74 = (($x) + 24|0);
 HEAPF32[$74>>2] = $61;
 $75 = (($x) + 28|0);
 HEAPF32[$75>>2] = $65;
 $76 = (($x) + 32|0);
 HEAPF32[$76>>2] = $68;
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$x);
 $77 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$agg$result>>2] = $77;
 $78 = (($0) + 4|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($agg$result) + 4|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($0) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($agg$result) + 8|0);
 HEAPF32[$83>>2] = $82;
 $84 = (($0) + 12|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($agg$result) + 12|0);
 HEAPF32[$86>>2] = $85;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu27computeBoundsAroundVerticesERNS_9PxBounds3EjPKNS_6PxVec3E($bounds,$nbVerts,$verts) {
 $bounds = $bounds|0;
 $nbVerts = $nbVerts|0;
 $verts = $verts|0;
 var $$012 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$bounds>>2] = Math_fround(8.50705866596322149529E+37);
 $0 = (($bounds) + 4|0);
 HEAPF32[$0>>2] = Math_fround(8.50705866596322149529E+37);
 $1 = (($bounds) + 8|0);
 HEAPF32[$1>>2] = Math_fround(8.50705866596322149529E+37);
 $2 = (($bounds) + 12|0);
 HEAPF32[$2>>2] = Math_fround(-8.50705866596322149529E+37);
 $3 = (($bounds) + 16|0);
 HEAPF32[$3>>2] = Math_fround(-8.50705866596322149529E+37);
 $4 = (($bounds) + 20|0);
 HEAPF32[$4>>2] = Math_fround(-8.50705866596322149529E+37);
 $5 = ($nbVerts|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $$012 = $nbVerts;$$03 = $verts;$10 = Math_fround(8.50705866596322149529E+37);$15 = Math_fround(8.50705866596322149529E+37);$20 = Math_fround(8.50705866596322149529E+37);$24 = Math_fround(-8.50705866596322149529E+37);$28 = Math_fround(-8.50705866596322149529E+37);$32 = Math_fround(-8.50705866596322149529E+37);
 }
 while(1) {
  $6 = (($$012) + -1)|0;
  $7 = (($$03) + 12|0);
  $8 = Math_fround(HEAPF32[$$03>>2]);
  $9 = $10 < $8;
  $11 = $9 ? $10 : $8;
  $12 = (($$03) + 4|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = $15 < $13;
  $16 = $14 ? $15 : $13;
  $17 = (($$03) + 8|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = $20 < $18;
  $21 = $19 ? $20 : $18;
  HEAPF32[$bounds>>2] = $11;
  HEAPF32[$0>>2] = $16;
  HEAPF32[$1>>2] = $21;
  $22 = Math_fround(HEAPF32[$$03>>2]);
  $23 = $24 > $22;
  $25 = $23 ? $24 : $22;
  $26 = Math_fround(HEAPF32[$12>>2]);
  $27 = $28 > $26;
  $29 = $27 ? $28 : $26;
  $30 = Math_fround(HEAPF32[$17>>2]);
  $31 = $32 > $30;
  $33 = $31 ? $32 : $30;
  HEAPF32[$2>>2] = $25;
  HEAPF32[$3>>2] = $29;
  HEAPF32[$4>>2] = $33;
  $34 = ($6|0)==(0);
  if ($34) {
   break;
  } else {
   $$012 = $6;$$03 = $7;$10 = $11;$15 = $16;$20 = $21;$24 = $25;$28 = $29;$32 = $33;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15computeSweptBoxERNS0_3BoxERKNS_6PxVec3ES5_RKNS_7PxMat33ES5_f($dest,$extents,$center,$rot,$unitDir,$distance) {
 $dest = $dest|0;
 $extents = $extents|0;
 $center = $center|0;
 $rot = $rot|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dd = 0, $dmax$0 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i$1 = Math_fround(0), $fabsf$i$i$2 = Math_fround(0), $fabsf$i$i3 = Math_fround(0), $fabsf$i$i3$1 = Math_fround(0), $fabsf$i$i3$2 = Math_fround(0), $fabsf$i$i4 = Math_fround(0), $fabsf$i$i5 = Math_fround(0), $fabsf$i$i5$1 = Math_fround(0);
 var $fabsf$i$i5$2 = Math_fround(0), $fabsf$i$i6 = Math_fround(0), $fabsf$i$i7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dd = sp;
 $0 = (($unitDir) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$rot>>2]);
 $3 = Math_fround(HEAPF32[$unitDir>>2]);
 $4 = Math_fround($2 * $3);
 $5 = (($rot) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($1 * $6);
 $8 = Math_fround($4 + $7);
 $9 = (($rot) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($unitDir) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $fabsf$i$i4 = (Math_fround(Math_abs((Math_fround($14)))));
 HEAPF32[$dd>>2] = $fabsf$i$i4;
 $15 = (($rot) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $3);
 $18 = (($rot) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $1);
 $21 = Math_fround($17 + $20);
 $22 = (($rot) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $12);
 $25 = Math_fround($21 + $24);
 $fabsf$i$i6 = (Math_fround(Math_abs((Math_fround($25)))));
 $26 = (($dd) + 4|0);
 HEAPF32[$26>>2] = $fabsf$i$i6;
 $27 = (($rot) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $3);
 $30 = (($rot) + 28|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $1);
 $33 = Math_fround($29 + $32);
 $34 = (($rot) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * $12);
 $37 = Math_fround($33 + $36);
 $fabsf$i$i7 = (Math_fround(Math_abs((Math_fround($37)))));
 $38 = (($dd) + 8|0);
 HEAPF32[$38>>2] = $fabsf$i$i7;
 $39 = $fabsf$i$i6 > $fabsf$i$i4;
 $40 = $39&1;
 $41 = $40 ^ 1;
 $dmax$0 = $39 ? $fabsf$i$i6 : $fabsf$i$i4;
 $42 = $fabsf$i$i7 > $dmax$0;
 $43 = $42 ? 0 : $41;
 $44 = $42 ? 1 : 2;
 $45 = (($dd) + ($44<<2)|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($dd) + ($43<<2)|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = $46 < $48;
 $50 = $49 ? $44 : $43;
 $51 = (($rot) + (($50*12)|0)|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = ((($rot) + (($50*12)|0)|0) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = ((($rot) + (($50*12)|0)|0) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($52 * $3);
 $58 = Math_fround($54 * $1);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($56 * $12);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($3 * $61);
 $63 = Math_fround($61 * $1);
 $64 = Math_fround($61 * $12);
 $65 = Math_fround($52 - $62);
 $66 = Math_fround($54 - $63);
 $67 = Math_fround($56 - $64);
 $68 = Math_fround($65 * $65);
 $69 = Math_fround($66 * $66);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($67 * $67);
 $72 = Math_fround($70 + $71);
 $73 = (Math_fround(Math_sqrt((Math_fround($72)))));
 $74 = $73 > Math_fround(0.0);
 if ($74) {
  $75 = Math_fround(Math_fround(1.0) / $73);
  $76 = Math_fround($65 * $75);
  $77 = Math_fround($66 * $75);
  $78 = Math_fround($67 * $75);
  $80 = $78;$82 = $77;$85 = $76;
 } else {
  $80 = $67;$82 = $66;$85 = $65;
 }
 $79 = Math_fround($80 * $1);
 $81 = Math_fround($82 * $12);
 $83 = Math_fround($79 - $81);
 $84 = Math_fround($85 * $12);
 $86 = Math_fround($80 * $3);
 $87 = Math_fround($84 - $86);
 $88 = Math_fround($82 * $3);
 $89 = Math_fround($85 * $1);
 $90 = Math_fround($88 - $89);
 HEAPF32[$dest>>2] = $3;
 $91 = Math_fround(HEAPF32[$0>>2]);
 $92 = (($dest) + 4|0);
 HEAPF32[$92>>2] = $91;
 $93 = Math_fround(HEAPF32[$11>>2]);
 $94 = (($dest) + 8|0);
 HEAPF32[$94>>2] = $93;
 $95 = (($dest) + 12|0);
 HEAPF32[$95>>2] = $85;
 $96 = (($dest) + 16|0);
 HEAPF32[$96>>2] = $82;
 $97 = (($dest) + 20|0);
 HEAPF32[$97>>2] = $80;
 $98 = (($dest) + 24|0);
 HEAPF32[$98>>2] = $83;
 $99 = (($dest) + 28|0);
 HEAPF32[$99>>2] = $87;
 $100 = (($dest) + 32|0);
 HEAPF32[$100>>2] = $90;
 $101 = Math_fround(HEAPF32[$unitDir>>2]);
 $102 = Math_fround($85 * $101);
 $103 = Math_fround(HEAPF32[$0>>2]);
 $104 = Math_fround($82 * $103);
 $105 = Math_fround($102 + $104);
 $106 = Math_fround(HEAPF32[$11>>2]);
 $107 = Math_fround($80 * $106);
 $108 = Math_fround($105 + $107);
 $109 = Math_fround($108 * $distance);
 $110 = Math_fround($83 * $101);
 $111 = Math_fround($87 * $103);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround($90 * $106);
 $114 = Math_fround($112 + $113);
 $115 = Math_fround($114 * $distance);
 $116 = (($extents) + 4|0);
 $117 = (($extents) + 8|0);
 $118 = (($dest) + 48|0);
 $119 = Math_fround($distance * Math_fround(0.5));
 $120 = Math_fround(HEAPF32[$rot>>2]);
 $121 = Math_fround($120 * $3);
 $122 = Math_fround(HEAPF32[$5>>2]);
 $123 = Math_fround($122 * $91);
 $124 = Math_fround($121 + $123);
 $125 = Math_fround(HEAPF32[$9>>2]);
 $126 = Math_fround($125 * $93);
 $127 = Math_fround($124 + $126);
 $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($127)))));
 $128 = Math_fround(HEAPF32[$extents>>2]);
 $129 = Math_fround($fabsf$i$i5 * $128);
 $130 = Math_fround($119 + $129);
 $131 = Math_fround(HEAPF32[$15>>2]);
 $132 = Math_fround($3 * $131);
 $133 = Math_fround(HEAPF32[$18>>2]);
 $134 = Math_fround($91 * $133);
 $135 = Math_fround($132 + $134);
 $136 = Math_fround(HEAPF32[$22>>2]);
 $137 = Math_fround($93 * $136);
 $138 = Math_fround($135 + $137);
 $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($138)))));
 $139 = Math_fround(HEAPF32[$116>>2]);
 $140 = Math_fround($fabsf$i$i3 * $139);
 $141 = Math_fround($130 + $140);
 $142 = Math_fround(HEAPF32[$27>>2]);
 $143 = Math_fround($3 * $142);
 $144 = Math_fround(HEAPF32[$30>>2]);
 $145 = Math_fround($91 * $144);
 $146 = Math_fround($143 + $145);
 $147 = Math_fround(HEAPF32[$34>>2]);
 $148 = Math_fround($93 * $147);
 $149 = Math_fround($146 + $148);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($149)))));
 $150 = Math_fround(HEAPF32[$117>>2]);
 $151 = Math_fround($fabsf$i$i * $150);
 $152 = Math_fround($141 + $151);
 HEAPF32[$118>>2] = $152;
 $153 = Math_fround($109 * Math_fround(0.5));
 $154 = Math_fround(HEAPF32[$rot>>2]);
 $155 = Math_fround($154 * $85);
 $156 = Math_fround(HEAPF32[$5>>2]);
 $157 = Math_fround($156 * $82);
 $158 = Math_fround($155 + $157);
 $159 = Math_fround(HEAPF32[$9>>2]);
 $160 = Math_fround($159 * $80);
 $161 = Math_fround($158 + $160);
 $fabsf$i$i5$1 = (Math_fround(Math_abs((Math_fround($161)))));
 $162 = Math_fround(HEAPF32[$extents>>2]);
 $163 = Math_fround($fabsf$i$i5$1 * $162);
 $164 = Math_fround($153 + $163);
 $165 = Math_fround(HEAPF32[$15>>2]);
 $166 = Math_fround($85 * $165);
 $167 = Math_fround(HEAPF32[$18>>2]);
 $168 = Math_fround($82 * $167);
 $169 = Math_fround($166 + $168);
 $170 = Math_fround(HEAPF32[$22>>2]);
 $171 = Math_fround($80 * $170);
 $172 = Math_fround($169 + $171);
 $fabsf$i$i3$1 = (Math_fround(Math_abs((Math_fround($172)))));
 $173 = Math_fround(HEAPF32[$116>>2]);
 $174 = Math_fround($fabsf$i$i3$1 * $173);
 $175 = Math_fround($164 + $174);
 $176 = Math_fround(HEAPF32[$27>>2]);
 $177 = Math_fround($85 * $176);
 $178 = Math_fround(HEAPF32[$30>>2]);
 $179 = Math_fround($82 * $178);
 $180 = Math_fround($177 + $179);
 $181 = Math_fround(HEAPF32[$34>>2]);
 $182 = Math_fround($80 * $181);
 $183 = Math_fround($180 + $182);
 $fabsf$i$i$1 = (Math_fround(Math_abs((Math_fround($183)))));
 $184 = Math_fround(HEAPF32[$117>>2]);
 $185 = Math_fround($fabsf$i$i$1 * $184);
 $186 = Math_fround($175 + $185);
 $187 = (($118) + 4|0);
 HEAPF32[$187>>2] = $186;
 $188 = Math_fround($115 * Math_fround(0.5));
 $189 = Math_fround(HEAPF32[$rot>>2]);
 $190 = (($dest) + 24|0);
 $191 = Math_fround(HEAPF32[$190>>2]);
 $192 = Math_fround($189 * $191);
 $193 = Math_fround(HEAPF32[$5>>2]);
 $194 = (($dest) + 28|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = Math_fround($193 * $195);
 $197 = Math_fround($192 + $196);
 $198 = Math_fround(HEAPF32[$9>>2]);
 $199 = (($dest) + 32|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = Math_fround($198 * $200);
 $202 = Math_fround($197 + $201);
 $fabsf$i$i5$2 = (Math_fround(Math_abs((Math_fround($202)))));
 $203 = Math_fround(HEAPF32[$extents>>2]);
 $204 = Math_fround($fabsf$i$i5$2 * $203);
 $205 = Math_fround($188 + $204);
 $206 = Math_fround(HEAPF32[$15>>2]);
 $207 = Math_fround($191 * $206);
 $208 = Math_fround(HEAPF32[$18>>2]);
 $209 = Math_fround($195 * $208);
 $210 = Math_fround($207 + $209);
 $211 = Math_fround(HEAPF32[$22>>2]);
 $212 = Math_fround($200 * $211);
 $213 = Math_fround($210 + $212);
 $fabsf$i$i3$2 = (Math_fround(Math_abs((Math_fround($213)))));
 $214 = Math_fround(HEAPF32[$116>>2]);
 $215 = Math_fround($fabsf$i$i3$2 * $214);
 $216 = Math_fround($205 + $215);
 $217 = Math_fround(HEAPF32[$27>>2]);
 $218 = Math_fround($191 * $217);
 $219 = Math_fround(HEAPF32[$30>>2]);
 $220 = Math_fround($195 * $219);
 $221 = Math_fround($218 + $220);
 $222 = Math_fround(HEAPF32[$34>>2]);
 $223 = Math_fround($200 * $222);
 $224 = Math_fround($221 + $223);
 $fabsf$i$i$2 = (Math_fround(Math_abs((Math_fround($224)))));
 $225 = Math_fround(HEAPF32[$117>>2]);
 $226 = Math_fround($fabsf$i$i$2 * $225);
 $227 = Math_fround($216 + $226);
 $228 = (($118) + 8|0);
 HEAPF32[$228>>2] = $227;
 $229 = Math_fround(HEAPF32[$unitDir>>2]);
 $230 = Math_fround($229 * $distance);
 $231 = Math_fround(HEAPF32[$0>>2]);
 $232 = Math_fround($231 * $distance);
 $233 = Math_fround(HEAPF32[$11>>2]);
 $234 = Math_fround($233 * $distance);
 $235 = Math_fround($230 * Math_fround(0.5));
 $236 = Math_fround($232 * Math_fround(0.5));
 $237 = Math_fround($234 * Math_fround(0.5));
 $238 = Math_fround(HEAPF32[$center>>2]);
 $239 = Math_fround($235 + $238);
 $240 = (($center) + 4|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = Math_fround($236 + $241);
 $243 = (($center) + 8|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = Math_fround($237 + $244);
 $246 = (($dest) + 36|0);
 HEAPF32[$246>>2] = $239;
 $247 = (($dest) + 40|0);
 HEAPF32[$247>>2] = $242;
 $248 = (($dest) + 44|0);
 HEAPF32[$248>>2] = $245;
 STACKTOP = sp;return;
}
function __ZN5physx15PxGeometryQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_RNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($unitDir,$distance,$geom0,$pose0,$geom1,$pose1,$sweepHit,$hitFlags,$inflation) {
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $geom0 = $geom0|0;
 $pose0 = $pose0|0;
 $geom1 = $geom1|0;
 $pose1 = $pose1|0;
 $sweepHit = $sweepHit|0;
 $hitFlags = $hitFlags|0;
 $inflation = Math_fround($inflation);
 var $$2 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = Math_fround(0);
 var $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $box = 0, $worldCapsule = 0, $worldCapsule1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $worldCapsule = sp + 88|0;
 $0 = sp + 124|0;
 $worldCapsule1 = sp + 60|0;
 $1 = sp + 122|0;
 $2 = sp + 126|0;
 $box = sp;
 $3 = sp + 118|0;
 $4 = sp + 120|0;
 $5 = sp + 116|0;
 $6 = HEAP32[$geom0>>2]|0;
 if ((($6|0) == 2)) {
  $26 = Math_fround(HEAPF32[$pose0>>2]);
  $27 = Math_fround($26 * Math_fround(2.0));
  $28 = (($pose0) + 12|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($29 * Math_fround(2.0));
  $31 = Math_fround($29 * $30);
  $32 = Math_fround($31 + Math_fround(-1.0));
  $33 = Math_fround($26 * $27);
  $34 = Math_fround($33 + $32);
  $35 = (($pose0) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($36 * $30);
  $38 = (($pose0) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($27 * $39);
  $41 = Math_fround($37 + $40);
  $42 = Math_fround($30 * $39);
  $43 = Math_fround($27 * $36);
  $44 = Math_fround($43 - $42);
  $45 = (($geom0) + 8|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($46 * $34);
  $48 = Math_fround($46 * $41);
  $49 = Math_fround($46 * $44);
  $50 = (($pose0) + 16|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($51 + $47);
  $53 = (($pose0) + 20|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($54 + $48);
  $56 = (($pose0) + 24|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($49 + $57);
  HEAPF32[$worldCapsule1>>2] = $52;
  $59 = (($worldCapsule1) + 4|0);
  HEAPF32[$59>>2] = $55;
  $60 = (($worldCapsule1) + 8|0);
  HEAPF32[$60>>2] = $58;
  $61 = Math_fround($51 - $47);
  $62 = Math_fround($54 - $48);
  $63 = Math_fround($57 - $49);
  $64 = (($worldCapsule1) + 12|0);
  HEAPF32[$64>>2] = $61;
  $65 = (($worldCapsule1) + 16|0);
  HEAPF32[$65>>2] = $62;
  $66 = (($worldCapsule1) + 20|0);
  HEAPF32[$66>>2] = $63;
  $67 = (($geom0) + 4|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($worldCapsule1) + 24|0);
  HEAPF32[$69>>2] = $68;
  $70 = HEAP16[$hitFlags>>1]|0;
  $71 = $70 & 256;
  $72 = ($71<<16>>16)==(0);
  $73 = HEAP32[$geom1>>2]|0;
  if ($72) {
   $77 = (548608 + ($73<<2)|0);
   $78 = HEAP32[$77>>2]|0;
   HEAP16[$2>>1] = $70;
   $79 = (FUNCTION_TABLE_iiiiifiif[$78 & 31]($geom1,$pose1,$worldCapsule1,$unitDir,$distance,$sweepHit,$2,$inflation)|0);
   $$2 = $79;
   STACKTOP = sp;return ($$2|0);
  } else {
   $74 = ((548608 + ($73<<2)|0) + 28|0);
   $75 = HEAP32[$74>>2]|0;
   HEAP16[$1>>1] = $70;
   $76 = (FUNCTION_TABLE_iiiiifiif[$75 & 31]($geom1,$pose1,$worldCapsule1,$unitDir,$distance,$sweepHit,$1,$inflation)|0);
   $$2 = $76;
   STACKTOP = sp;return ($$2|0);
  }
 } else if ((($6|0) == 4)) {
  $146 = HEAP32[$geom1>>2]|0;
  $147 = ((548608 + ($146<<2)|0) + 112|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = HEAP16[$hitFlags>>1]|0;
  HEAP16[$5>>1] = $149;
  $150 = (FUNCTION_TABLE_iiiiiifiif[$148 & 7]($geom1,$pose1,$geom0,$pose0,$unitDir,$distance,$sweepHit,$5,$inflation)|0);
  $$2 = $150;
  STACKTOP = sp;return ($$2|0);
 } else if ((($6|0) == 3)) {
  $80 = (($geom0) + 4|0);
  $81 = (($pose0) + 16|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = (($box) + 36|0);
  HEAPF32[$83>>2] = $82;
  $84 = (($pose0) + 20|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = (($box) + 40|0);
  HEAPF32[$86>>2] = $85;
  $87 = (($pose0) + 24|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (($box) + 44|0);
  HEAPF32[$89>>2] = $88;
  $90 = Math_fround(HEAPF32[$80>>2]);
  $91 = (($box) + 48|0);
  HEAPF32[$91>>2] = $90;
  $92 = (($geom0) + 8|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = (($box) + 52|0);
  HEAPF32[$94>>2] = $93;
  $95 = (($geom0) + 12|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = (($box) + 56|0);
  HEAPF32[$97>>2] = $96;
  $98 = Math_fround(HEAPF32[$pose0>>2]);
  $99 = (($pose0) + 4|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($pose0) + 8|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = (($pose0) + 12|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = Math_fround($98 + $98);
  $106 = Math_fround($100 + $100);
  $107 = Math_fround($102 + $102);
  $108 = Math_fround($98 * $105);
  $109 = Math_fround($100 * $106);
  $110 = Math_fround($102 * $107);
  $111 = Math_fround($105 * $100);
  $112 = Math_fround($105 * $102);
  $113 = Math_fround($105 * $104);
  $114 = Math_fround($106 * $102);
  $115 = Math_fround($106 * $104);
  $116 = Math_fround($107 * $104);
  $117 = Math_fround(Math_fround(1.0) - $109);
  $118 = Math_fround($117 - $110);
  $119 = Math_fround($111 + $116);
  $120 = Math_fround($112 - $115);
  $121 = Math_fround($111 - $116);
  $122 = Math_fround(Math_fround(1.0) - $108);
  $123 = Math_fround($122 - $110);
  $124 = Math_fround($114 + $113);
  $125 = Math_fround($112 + $115);
  $126 = Math_fround($114 - $113);
  $127 = Math_fround($122 - $109);
  HEAPF32[$box>>2] = $118;
  $128 = (($box) + 4|0);
  HEAPF32[$128>>2] = $119;
  $129 = (($box) + 8|0);
  HEAPF32[$129>>2] = $120;
  $130 = (($box) + 12|0);
  HEAPF32[$130>>2] = $121;
  $131 = (($box) + 16|0);
  HEAPF32[$131>>2] = $123;
  $132 = (($box) + 20|0);
  HEAPF32[$132>>2] = $124;
  $133 = (($box) + 24|0);
  HEAPF32[$133>>2] = $125;
  $134 = (($box) + 28|0);
  HEAPF32[$134>>2] = $126;
  $135 = (($box) + 32|0);
  HEAPF32[$135>>2] = $127;
  $136 = HEAP16[$hitFlags>>1]|0;
  $137 = $136 & 256;
  $138 = ($137<<16>>16)==(0);
  $139 = HEAP32[$geom1>>2]|0;
  if ($138) {
   $143 = ((548608 + ($139<<2)|0) + 56|0);
   $144 = HEAP32[$143>>2]|0;
   HEAP16[$4>>1] = $136;
   $145 = (FUNCTION_TABLE_iiiiifiif[$144 & 31]($geom1,$pose1,$box,$unitDir,$distance,$sweepHit,$4,$inflation)|0);
   $$2 = $145;
   STACKTOP = sp;return ($$2|0);
  } else {
   $140 = ((548608 + ($139<<2)|0) + 84|0);
   $141 = HEAP32[$140>>2]|0;
   HEAP16[$3>>1] = $136;
   $142 = (FUNCTION_TABLE_iiiiifiif[$141 & 31]($geom1,$pose1,$box,$unitDir,$distance,$sweepHit,$3,$inflation)|0);
   $$2 = $142;
   STACKTOP = sp;return ($$2|0);
  }
 } else if ((($6|0) == 0)) {
  $7 = (($geom0) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($pose0) + 16|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$worldCapsule>>2] = $10;
  $11 = (($worldCapsule) + 4|0);
  $12 = (($pose0) + 20|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $13;
  $14 = (($worldCapsule) + 8|0);
  $15 = (($pose0) + 24|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$14>>2] = $16;
  $17 = (($worldCapsule) + 12|0);
  HEAPF32[$17>>2] = $10;
  $18 = (($worldCapsule) + 16|0);
  HEAPF32[$18>>2] = $13;
  $19 = (($worldCapsule) + 20|0);
  HEAPF32[$19>>2] = $16;
  $20 = (($worldCapsule) + 24|0);
  HEAPF32[$20>>2] = $8;
  $21 = HEAP32[$geom1>>2]|0;
  $22 = (548608 + ($21<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP16[$hitFlags>>1]|0;
  HEAP16[$0>>1] = $24;
  $25 = (FUNCTION_TABLE_iiiiifiif[$23 & 31]($geom1,$pose1,$worldCapsule,$unitDir,$distance,$sweepHit,$0,$inflation)|0);
  $$2 = $25;
  STACKTOP = sp;return ($$2|0);
 } else {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 return 0|0;
}
function __ZN5physx15PxGeometryQuery7overlapERKNS_10PxGeometryERKNS_11PxTransformES3_S6_($geom0,$pose0,$geom1,$pose1) {
 $geom0 = $geom0|0;
 $pose0 = $pose0|0;
 $geom1 = $geom1|0;
 $pose1 = $pose1|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$geom0>>2]|0;
 $1 = HEAP32[$geom1>>2]|0;
 $2 = ($0|0)>($1|0);
 if ($2) {
  $3 = ((548024 + (($1*28)|0)|0) + ($0<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (FUNCTION_TABLE_iiiiii[$4 & 255]($geom1,$pose1,$geom0,$pose0,0)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 } else {
  $6 = ((548024 + (($0*28)|0)|0) + ($1<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_iiiiii[$7 & 255]($geom0,$pose0,$geom1,$pose1,0)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx15PxGeometryQuery7raycastERKNS_6PxVec3ES3_RKNS_10PxGeometryERKNS_11PxTransformEfNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEb($rayOrigin,$rayDir,$geom,$pose,$maxDist,$hitFlags,$maxHits,$rayHits,$anyHit) {
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $geom = $geom|0;
 $pose = $pose|0;
 $maxDist = Math_fround($maxDist);
 $hitFlags = $hitFlags|0;
 $maxHits = $maxHits|0;
 $rayHits = $rayHits|0;
 $anyHit = $anyHit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$geom>>2]|0;
 $2 = (548376 + ($1<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$hitFlags>>1]|0;
 HEAP16[$0>>1] = $4;
 $5 = (FUNCTION_TABLE_iiiiifiiiiii[$3 & 7]($geom,$pose,$rayOrigin,$rayDir,$maxDist,$0,$maxHits,$rayHits,$anyHit,0,0)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx15PxGeometryQuery14getWorldBoundsERKNS_10PxGeometryERKNS_11PxTransformEf($agg$result,$geom,$pose,$inflation) {
 $agg$result = $agg$result|0;
 $geom = $geom|0;
 $pose = $pose|0;
 $inflation = Math_fround($inflation);
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $gu = 0, $result = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $gu = sp + 24|0;
 $result = sp;
 HEAP32[$gu>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($gu,$geom);
 __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($gu,$result,$pose,Math_fround(0.0),0);
 $0 = Math_fround(HEAPF32[$result>>2]);
 $1 = (($result) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 $4 = (($result) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($result) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 $9 = (($result) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($result) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = Math_fround($3 * Math_fround(0.5));
 $15 = Math_fround($8 * Math_fround(0.5));
 $16 = Math_fround($13 * Math_fround(0.5));
 $17 = Math_fround($2 - $0);
 $18 = Math_fround($7 - $5);
 $19 = Math_fround($12 - $10);
 $20 = Math_fround($17 * Math_fround(0.5));
 $21 = Math_fround($18 * Math_fround(0.5));
 $22 = Math_fround($19 * Math_fround(0.5));
 $23 = Math_fround($20 * $inflation);
 $24 = Math_fround($21 * $inflation);
 $25 = Math_fround($22 * $inflation);
 $26 = Math_fround($14 - $23);
 $27 = Math_fround($15 - $24);
 $28 = Math_fround($16 - $25);
 $29 = Math_fround($14 + $23);
 $30 = Math_fround($15 + $24);
 $31 = Math_fround($16 + $25);
 HEAPF32[$agg$result>>2] = $26;
 $32 = (($agg$result) + 4|0);
 HEAPF32[$32>>2] = $27;
 $33 = (($agg$result) + 8|0);
 HEAPF32[$33>>2] = $28;
 $34 = (($agg$result) + 12|0);
 HEAPF32[$34>>2] = $29;
 $35 = (($agg$result) + 16|0);
 HEAPF32[$35>>2] = $30;
 $36 = (($agg$result) + 20|0);
 HEAPF32[$36>>2] = $31;
 STACKTOP = sp;return;
}
function __ZN5physx15PxGeometryQuery18computePenetrationERNS_6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES6_S9_($mtd,$depth,$geom0,$pose0,$geom1,$pose1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $pose0 = $pose0|0;
 $geom1 = $geom1|0;
 $pose1 = $pose1|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$geom0>>2]|0;
 $1 = HEAP32[$geom1>>2]|0;
 $2 = ($0|0)>($1|0);
 if (!($2)) {
  $14 = ((546512 + (($0*28)|0)|0) + ($1<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_iiiiiii[$15 & 255]($mtd,$depth,$geom0,$pose0,$geom1,$pose1)|0);
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ((546512 + (($1*28)|0)|0) + ($0<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiii[$4 & 255]($mtd,$depth,$geom1,$pose1,$geom0,$pose0)|0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = Math_fround(HEAPF32[$mtd>>2]);
 $7 = Math_fround(-$6);
 $8 = (($mtd) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(-$9);
 $11 = (($mtd) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(-$12);
 HEAPF32[$mtd>>2] = $7;
 HEAPF32[$8>>2] = $10;
 HEAPF32[$11>>2] = $13;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($this,$g) {
 $this = $this|0;
 $g = $g|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$g>>2]|0;
 switch ($0|0) {
 case 5:  {
  HEAP32[$this>>2] = (5);
  $47 = (($g) + 4|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($this) + 4|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($g) + 8|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($this) + 8|0);
  HEAPF32[$52>>2] = $51;
  $53 = (($g) + 12|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($this) + 12|0);
  HEAPF32[$55>>2] = $54;
  $56 = (($g) + 16|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($this) + 16|0);
  HEAPF32[$58>>2] = $57;
  $59 = (($g) + 20|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($this) + 20|0);
  HEAPF32[$61>>2] = $60;
  $62 = (($g) + 24|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($this) + 24|0);
  HEAPF32[$64>>2] = $63;
  $65 = (($g) + 28|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = (($this) + 28|0);
  HEAPF32[$67>>2] = $66;
  $68 = (($this) + 32|0);
  $69 = (($g) + 32|0);
  $70 = $69;
  $71 = $70;
  $72 = HEAPU8[$71>>0]|(HEAPU8[$71+1>>0]<<8)|(HEAPU8[$71+2>>0]<<16)|(HEAPU8[$71+3>>0]<<24);
  $73 = (($70) + 4)|0;
  $74 = $73;
  $75 = HEAPU8[$74>>0]|(HEAPU8[$74+1>>0]<<8)|(HEAPU8[$74+2>>0]<<16)|(HEAPU8[$74+3>>0]<<24);
  $76 = $68;
  $77 = $76;
  HEAP8[$77>>0]=$72&255;HEAP8[$77+1>>0]=($72>>8)&255;HEAP8[$77+2>>0]=($72>>16)&255;HEAP8[$77+3>>0]=$72>>24;
  $78 = (($76) + 4)|0;
  $79 = $78;
  HEAP8[$79>>0]=$75&255;HEAP8[$79+1>>0]=($75>>8)&255;HEAP8[$79+2>>0]=($75>>16)&255;HEAP8[$79+3>>0]=$75>>24;
  $80 = $75;
  $81 = (($80) + 16|0);
  $82 = (($this) + 40|0);
  HEAP32[$82>>2] = $81;
  $83 = (($80) + 176|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($this) + 44|0);
  HEAP32[$85>>2] = $84;
  $86 = (($this) + 48|0);
  $87 = $86;
  $88 = $87;
  HEAP32[$88>>2] = 0;
  $89 = (($87) + 4)|0;
  $90 = $89;
  HEAP32[$90>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 2:  {
  ;HEAP32[$this+0>>2]=HEAP32[$g+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$g+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$g+8>>2]|0;
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  HEAP32[$this>>2] = (4);
  $21 = (($g) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($this) + 4|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($g) + 8|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($this) + 8|0);
  HEAPF32[$26>>2] = $25;
  $27 = (($g) + 12|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($this) + 12|0);
  HEAPF32[$29>>2] = $28;
  $30 = (($g) + 16|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($this) + 16|0);
  HEAPF32[$32>>2] = $31;
  $33 = (($g) + 20|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($this) + 20|0);
  HEAPF32[$35>>2] = $34;
  $36 = (($g) + 24|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($this) + 24|0);
  HEAPF32[$38>>2] = $37;
  $39 = (($g) + 28|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($this) + 28|0);
  HEAPF32[$41>>2] = $40;
  $42 = (($g) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($this) + 32|0);
  HEAP32[$44>>2] = $43;
  $45 = (($43) + 16|0);
  $46 = (($this) + 36|0);
  HEAP32[$46>>2] = $45;
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  $10 = $g;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + 4)|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = $this;
  $17 = $16;
  HEAP32[$17>>2] = $12;
  $18 = (($16) + 4)|0;
  $19 = $18;
  HEAP32[$19>>2] = $15;
  $20 = (($this) + 8|0);
  HEAPF32[$20>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  HEAP32[$this>>2] = (1);
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  ;HEAP32[$this+0>>2]=HEAP32[$g+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$g+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$g+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$g+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$g+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$g+20>>2]|0;
  $91 = (($this) + 4|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (($92) + 16|0);
  $94 = (($this) + 24|0);
  HEAP32[$94>>2] = $93;
  $95 = (($this) + 28|0);
  $96 = $95;
  $97 = $96;
  HEAP32[$97>>2] = 0;
  $98 = (($96) + 4)|0;
  $99 = $98;
  HEAP32[$99>>2] = 0;
  STACKTOP = sp;return;
  break;
 }
 case 3:  {
  HEAP32[$this>>2] = (3);
  $1 = (($g) + 4|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $3 = (($this) + 4|0);
  HEAPF32[$3>>2] = $2;
  $4 = (($g) + 8|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($this) + 8|0);
  HEAPF32[$6>>2] = $5;
  $7 = (($g) + 12|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($this) + 12|0);
  HEAPF32[$9>>2] = $8;
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZN5physx2Gu24computeMTD_SphereCapsuleERNS_6PxVec3ERfRKNS0_6SphereERKNS0_7CapsuleE($mtd,$depth,$sphere,$capsule) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $sphere = $sphere|0;
 $capsule = $capsule|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $u = sp;
 $0 = (($sphere) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($capsule) + 24|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = (($capsule) + 12|0);
 $6 = (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($capsule,$5,$sphere,$u)));
 $7 = Math_fround($4 * $4);
 $8 = $6 > $7;
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = Math_fround(HEAPF32[$u>>2]);
 $10 = (($capsule) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(HEAPF32[$capsule>>2]);
 $13 = Math_fround($11 - $12);
 $14 = (($capsule) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($capsule) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = (($capsule) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($capsule) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 - $22);
 $24 = Math_fround($9 * $13);
 $25 = Math_fround($9 * $18);
 $26 = Math_fround($9 * $23);
 $27 = Math_fround($12 + $24);
 $28 = Math_fround($17 + $25);
 $29 = Math_fround($22 + $26);
 $30 = Math_fround(HEAPF32[$sphere>>2]);
 $31 = Math_fround($30 - $27);
 $32 = (($sphere) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 - $28);
 $35 = (($sphere) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 - $29);
 $38 = Math_fround($31 * $31);
 $39 = Math_fround($34 * $34);
 $40 = Math_fround($38 + $39);
 $41 = Math_fround($37 * $37);
 $42 = Math_fround($40 + $41);
 $43 = (Math_fround(Math_sqrt((Math_fround($42)))));
 $44 = $42 < Math_fround(9.99999997475242707878E-7);
 if ($44) {
  HEAPF32[$mtd>>2] = Math_fround(1.0);
  $45 = (($mtd) + 4|0);
  HEAPF32[$45>>2] = Math_fround(0.0);
  $46 = (($mtd) + 8|0);
  HEAPF32[$46>>2] = Math_fround(0.0);
 } else {
  $47 = Math_fround(Math_fround(1.0) / $43);
  $48 = Math_fround($31 * $47);
  $49 = Math_fround($34 * $47);
  $50 = Math_fround($37 * $47);
  HEAPF32[$mtd>>2] = $48;
  $51 = (($mtd) + 4|0);
  HEAPF32[$51>>2] = $49;
  $52 = (($mtd) + 8|0);
  HEAPF32[$52>>2] = $50;
 }
 $53 = Math_fround($4 - $43);
 $54 = $53 > Math_fround(0.0);
 $55 = $54 ? $53 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $55;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu20computeMTD_SphereBoxERNS_6PxVec3ERfRKNS0_6SphereERKNS0_3BoxE($mtd,$depth,$sphere,$box) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $sphere = $sphere|0;
 $box = $box|0;
 var $$0 = 0, $$mux$i = Math_fround(0), $$pn = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = 0;
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0);
 var $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0;
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge$i = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $outside$0$off0$i = 0, $outside$1$off0$i = 0, $phitmp$i = Math_fround(0), $phitmp26$i = Math_fround(0), $storemerge = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($sphere) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$box);
 $3 = Math_fround(HEAPF32[$0>>2]);
 $4 = (($0) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($0) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($box) + 36|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($box) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($box) + 44|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$sphere>>2]);
 $17 = Math_fround($16 - $11);
 $18 = (($sphere) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 - $13);
 $21 = (($sphere) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 - $15);
 $24 = Math_fround($17 * Math_fround(2.0));
 $25 = Math_fround($20 * Math_fround(2.0));
 $26 = Math_fround($23 * Math_fround(2.0));
 $27 = Math_fround($9 * $9);
 $28 = Math_fround($27 + Math_fround(-0.5));
 $29 = Math_fround($3 * $24);
 $30 = Math_fround($5 * $25);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($7 * $26);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround($28 * $24);
 $35 = Math_fround($5 * $26);
 $36 = Math_fround($7 * $25);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($9 * $37);
 $39 = Math_fround($34 - $38);
 $40 = Math_fround($3 * $33);
 $41 = Math_fround($40 + $39);
 $42 = Math_fround($28 * $25);
 $43 = Math_fround($7 * $24);
 $44 = Math_fround($3 * $26);
 $45 = Math_fround($43 - $44);
 $46 = Math_fround($9 * $45);
 $47 = Math_fround($42 - $46);
 $48 = Math_fround($5 * $33);
 $49 = Math_fround($48 + $47);
 $50 = Math_fround($28 * $26);
 $51 = Math_fround($3 * $25);
 $52 = Math_fround($5 * $24);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($9 * $53);
 $55 = Math_fround($50 - $54);
 $56 = Math_fround($7 * $33);
 $57 = Math_fround($55 + $56);
 $58 = (($box) + 48|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround(-$59);
 $61 = $41 < $60;
 if ($61) {
  $74 = $60;$outside$0$off0$i = 1;
 } else {
  $62 = $41 > $59;
  if ($62) {
   $74 = $59;$outside$0$off0$i = 1;
  } else {
   $74 = $41;$outside$0$off0$i = 0;
  }
 }
 $63 = (($box) + 52|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(-$64);
 $66 = $49 < $65;
 if ($66) {
  $76 = $65;$outside$1$off0$i = 1;
 } else {
  $67 = $49 > $64;
  if ($67) {
   $76 = $64;$outside$1$off0$i = 1;
  } else {
   $76 = $49;$outside$1$off0$i = $outside$0$off0$i;
  }
 }
 $68 = (($box) + 56|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround(-$69);
 $71 = $57 < $70;
 if ($71) {
  $78 = $70;
  label = 9;
 } else {
  $72 = $57 > $69;
  $brmerge$i = $72 | $outside$1$off0$i;
  $$mux$i = $72 ? $69 : $57;
  if ($brmerge$i) {
   $78 = $$mux$i;
   label = 9;
  } else {
   $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($74)))));
   $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($76)))));
   $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($57)))));
   $131 = Math_fround($59 - $fabsf$i$i4$i);
   $132 = Math_fround($64 - $fabsf$i$i3$i);
   $133 = Math_fround($69 - $fabsf$i$i$i);
   $134 = $132 < $131;
   do {
    if ($134) {
     $135 = $132 < $133;
     if ($135) {
      $136 = $76 > Math_fround(0.0);
      $137 = Math_fround(-$132);
      HEAPF32[$depth>>2] = $137;
      $phitmp26$i = $136 ? Math_fround(2.0) : Math_fround(-2.0);
      $148 = Math_fround(0.0);$150 = Math_fround(0.0);$152 = $phitmp26$i;
      break;
     } else {
      $138 = $57 > Math_fround(0.0);
      $139 = $138 ? Math_fround(1.0) : Math_fround(-1.0);
      $140 = Math_fround(-$133);
      HEAPF32[$depth>>2] = $140;
      $148 = $139;$150 = Math_fround(0.0);$152 = Math_fround(0.0);
      break;
     }
    } else {
     $141 = $131 < $133;
     if ($141) {
      $142 = $74 > Math_fround(0.0);
      $143 = Math_fround(-$131);
      HEAPF32[$depth>>2] = $143;
      $phitmp$i = $142 ? Math_fround(2.0) : Math_fround(-2.0);
      $148 = Math_fround(0.0);$150 = $phitmp$i;$152 = Math_fround(0.0);
      break;
     } else {
      $144 = $57 > Math_fround(0.0);
      $145 = $144 ? Math_fround(1.0) : Math_fround(-1.0);
      $146 = Math_fround(-$133);
      HEAPF32[$depth>>2] = $146;
      $148 = $145;$150 = Math_fround(0.0);$152 = Math_fround(0.0);
      break;
     }
    }
   } while(0);
   $147 = Math_fround($148 * Math_fround(2.0));
   $149 = Math_fround($3 * $150);
   $151 = Math_fround($5 * $152);
   $153 = Math_fround($151 + $149);
   $154 = Math_fround($7 * $147);
   $155 = Math_fround($154 + $153);
   $156 = Math_fround($28 * $150);
   $157 = Math_fround($5 * $147);
   $158 = Math_fround($7 * $152);
   $159 = Math_fround($157 - $158);
   $160 = Math_fround($9 * $159);
   $161 = Math_fround($156 + $160);
   $162 = Math_fround($3 * $155);
   $163 = Math_fround($161 + $162);
   $164 = Math_fround($28 * $152);
   $165 = Math_fround($7 * $150);
   $166 = Math_fround($3 * $147);
   $167 = Math_fround($165 - $166);
   $168 = Math_fround($9 * $167);
   $169 = Math_fround($164 + $168);
   $170 = Math_fround($5 * $155);
   $171 = Math_fround($170 + $169);
   $172 = Math_fround($28 * $147);
   $173 = Math_fround($3 * $152);
   $174 = Math_fround($5 * $150);
   $175 = Math_fround($173 - $174);
   $176 = Math_fround($9 * $175);
   $177 = Math_fround($172 + $176);
   $178 = Math_fround($7 * $155);
   $179 = Math_fround($177 + $178);
   HEAPF32[$mtd>>2] = $163;
   $180 = (($mtd) + 4|0);
   HEAPF32[$180>>2] = $171;
   $181 = (($mtd) + 8|0);
   HEAPF32[$181>>2] = $179;
   $182 = Math_fround(HEAPF32[$depth>>2]);
   $$pn = $182;
  }
 }
 do {
  if ((label|0) == 9) {
   $73 = Math_fround($74 * Math_fround(2.0));
   $75 = Math_fround($76 * Math_fround(2.0));
   $77 = Math_fround($78 * Math_fround(2.0));
   $79 = Math_fround($3 * $73);
   $80 = Math_fround($5 * $75);
   $81 = Math_fround($79 + $80);
   $82 = Math_fround($7 * $77);
   $83 = Math_fround($81 + $82);
   $84 = Math_fround($28 * $73);
   $85 = Math_fround($5 * $77);
   $86 = Math_fround($7 * $75);
   $87 = Math_fround($85 - $86);
   $88 = Math_fround($9 * $87);
   $89 = Math_fround($84 + $88);
   $90 = Math_fround($3 * $83);
   $91 = Math_fround($90 + $89);
   $92 = Math_fround($28 * $75);
   $93 = Math_fround($7 * $73);
   $94 = Math_fround($3 * $77);
   $95 = Math_fround($93 - $94);
   $96 = Math_fround($9 * $95);
   $97 = Math_fround($92 + $96);
   $98 = Math_fround($5 * $83);
   $99 = Math_fround($98 + $97);
   $100 = Math_fround($28 * $77);
   $101 = Math_fround($3 * $75);
   $102 = Math_fround($5 * $73);
   $103 = Math_fround($101 - $102);
   $104 = Math_fround($9 * $103);
   $105 = Math_fround($104 + $100);
   $106 = Math_fround($7 * $83);
   $107 = Math_fround($105 + $106);
   $108 = Math_fround($17 - $91);
   $109 = Math_fround($20 - $99);
   $110 = Math_fround($23 - $107);
   HEAPF32[$mtd>>2] = $108;
   $111 = (($mtd) + 4|0);
   HEAPF32[$111>>2] = $109;
   $112 = (($mtd) + 8|0);
   HEAPF32[$112>>2] = $110;
   $113 = Math_fround($108 * $108);
   $114 = Math_fround($109 * $109);
   $115 = Math_fround($113 + $114);
   $116 = Math_fround($110 * $110);
   $117 = Math_fround($116 + $115);
   $118 = Math_fround($2 + Math_fround(0.0));
   $119 = Math_fround($118 * $118);
   $120 = $117 > $119;
   if ($120) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $121 = (Math_fround(Math_sqrt((Math_fround($117)))));
    $122 = Math_fround(Math_fround(1.0) / $121);
    HEAPF32[$depth>>2] = $122;
    $123 = Math_fround(HEAPF32[$mtd>>2]);
    $124 = Math_fround($122 * $123);
    HEAPF32[$mtd>>2] = $124;
    $125 = Math_fround(HEAPF32[$111>>2]);
    $126 = Math_fround($122 * $125);
    HEAPF32[$111>>2] = $126;
    $127 = Math_fround(HEAPF32[$112>>2]);
    $128 = Math_fround($122 * $127);
    HEAPF32[$112>>2] = $128;
    $129 = Math_fround(HEAPF32[$depth>>2]);
    $130 = Math_fround($117 * $129);
    $$pn = $130;
    break;
   }
  }
 } while(0);
 $storemerge = Math_fround($$pn - $2);
 $183 = Math_fround(-$storemerge);
 $184 = $storemerge < Math_fround(-0.0);
 $185 = $184 ? $183 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $185;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu25computeMTD_CapsuleCapsuleERNS_6PxVec3ERfRKNS0_7CapsuleES6_($mtd,$depth,$capsule0,$capsule1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $capsule0 = $capsule0|0;
 $capsule1 = $capsule1|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $s = 0, $t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $s = sp + 4|0;
 $t = sp;
 $0 = (Math_fround(__ZN5physx2Gu30distanceSegmentSegmentSquared2ERKNS0_7SegmentES3_PfS4_($capsule0,$capsule1,$s,$t)));
 $1 = (($capsule0) + 24|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($capsule1) + 24|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 + $4);
 $6 = Math_fround($5 * $5);
 $7 = $0 > $6;
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = Math_fround(HEAPF32[$s>>2]);
 $9 = (($capsule0) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$capsule0>>2]);
 $12 = Math_fround($10 - $11);
 $13 = (($capsule0) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($capsule0) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 - $16);
 $18 = (($capsule0) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($capsule0) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($19 - $21);
 $23 = Math_fround($8 * $12);
 $24 = Math_fround($8 * $17);
 $25 = Math_fround($8 * $22);
 $26 = Math_fround($11 + $23);
 $27 = Math_fround($16 + $24);
 $28 = Math_fround($21 + $25);
 $29 = Math_fround(HEAPF32[$t>>2]);
 $30 = (($capsule1) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(HEAPF32[$capsule1>>2]);
 $33 = Math_fround($31 - $32);
 $34 = (($capsule1) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($capsule1) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 - $37);
 $39 = (($capsule1) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($capsule1) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 - $42);
 $44 = Math_fround($29 * $33);
 $45 = Math_fround($29 * $38);
 $46 = Math_fround($29 * $43);
 $47 = Math_fround($32 + $44);
 $48 = Math_fround($37 + $45);
 $49 = Math_fround($42 + $46);
 $50 = Math_fround($26 - $47);
 $51 = Math_fround($27 - $48);
 $52 = Math_fround($28 - $49);
 $53 = Math_fround($50 * $50);
 $54 = Math_fround($51 * $51);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($52 * $52);
 $57 = Math_fround($55 + $56);
 $58 = (Math_fround(Math_sqrt((Math_fround($57)))));
 $59 = $57 < Math_fround(9.99999997475242707878E-7);
 if ($59) {
  HEAPF32[$mtd>>2] = Math_fround(1.0);
  $60 = (($mtd) + 4|0);
  HEAPF32[$60>>2] = Math_fround(0.0);
  $61 = (($mtd) + 8|0);
  HEAPF32[$61>>2] = Math_fround(0.0);
 } else {
  $62 = Math_fround(Math_fround(1.0) / $58);
  $63 = Math_fround($50 * $62);
  $64 = Math_fround($51 * $62);
  $65 = Math_fround($52 * $62);
  HEAPF32[$mtd>>2] = $63;
  $66 = (($mtd) + 4|0);
  HEAPF32[$66>>2] = $64;
  $67 = (($mtd) + 8|0);
  HEAPF32[$67>>2] = $65;
 }
 $68 = Math_fround($5 - $58);
 $69 = $68 > Math_fround(0.0);
 $70 = $69 ? $68 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $70;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu21computeMTD_CapsuleBoxERNS_6PxVec3ERfRKNS0_7CapsuleERKNS0_3BoxE($mtd,$depth,$capsule,$box) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $capsule = $capsule|0;
 $box = $box|0;
 var $$0 = 0, $$idx$i = 0, $$idx$val$i = Math_fround(0), $$idx10$i = 0, $$idx10$val$i = Math_fround(0), $$idx3$i = 0, $$idx3$val$i = Math_fround(0), $$idx4$i = 0, $$idx4$val$i = Math_fround(0), $$idx8$i = 0, $$idx8$val$i = Math_fround(0), $$idx9$i = 0, $$idx9$val$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0;
 var $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0;
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0.0, $148 = 0, $149 = 0.0, $15 = Math_fround(0), $150 = 0, $151 = 0.0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0;
 var $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0);
 var $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $PenDepth$034$i = Math_fround(0), $PenDepth$1$i = Math_fround(0), $PenDepth$224$i = Math_fround(0), $PenDepth$3$i = Math_fround(0), $d$i = 0, $d2$i = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $i$035$i = 0;
 var $i1$025$i = 0, $onBox = 0, $t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $d$i = sp + 20|0;
 $d2$i = sp;
 $t = sp + 4|0;
 $onBox = sp + 8|0;
 $0 = (($capsule) + 12|0);
 $1 = (($box) + 36|0);
 $2 = (($box) + 48|0);
 $3 = (Math_fround(__ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($capsule,$0,$1,$2,$box,$t,$onBox)));
 $4 = (($capsule) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $5);
 $7 = $3 > $6;
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = $3 != Math_fround(0.0);
 if ($8) {
  $9 = Math_fround(HEAPF32[$t>>2]);
  $10 = (($capsule) + 12|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround(HEAPF32[$capsule>>2]);
  $13 = Math_fround($11 - $12);
  $14 = (($capsule) + 16|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($capsule) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($15 - $17);
  $19 = (($capsule) + 20|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($capsule) + 8|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($20 - $22);
  $24 = Math_fround($9 * $13);
  $25 = Math_fround($9 * $18);
  $26 = Math_fround($9 * $23);
  $27 = Math_fround($12 + $24);
  $28 = Math_fround($17 + $25);
  $29 = Math_fround($22 + $26);
  $30 = Math_fround(HEAPF32[$onBox>>2]);
  $31 = Math_fround(HEAPF32[$box>>2]);
  $32 = Math_fround($30 * $31);
  $33 = (($box) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($30 * $34);
  $36 = (($box) + 8|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($30 * $37);
  $39 = (($onBox) + 4|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($box) + 12|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($40 * $42);
  $44 = (($box) + 16|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($40 * $45);
  $47 = (($box) + 20|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($40 * $48);
  $50 = Math_fround($32 + $43);
  $51 = Math_fround($35 + $46);
  $52 = Math_fround($38 + $49);
  $53 = (($onBox) + 8|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($box) + 24|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($54 * $56);
  $58 = (($box) + 28|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($54 * $59);
  $61 = (($box) + 32|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = Math_fround($54 * $62);
  $64 = Math_fround($50 + $57);
  $65 = Math_fround($51 + $60);
  $66 = Math_fround($52 + $63);
  $67 = Math_fround(HEAPF32[$1>>2]);
  $68 = Math_fround($64 + $67);
  $69 = (($box) + 40|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($65 + $70);
  $72 = (($box) + 44|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($66 + $73);
  HEAPF32[$onBox>>2] = $68;
  HEAPF32[$39>>2] = $71;
  HEAPF32[$53>>2] = $74;
  $75 = Math_fround($27 - $68);
  $76 = Math_fround($28 - $71);
  $77 = Math_fround($29 - $74);
  $78 = Math_fround($75 * $75);
  $79 = Math_fround($76 * $76);
  $80 = Math_fround($78 + $79);
  $81 = Math_fround($77 * $77);
  $82 = Math_fround($81 + $80);
  $83 = (Math_fround(Math_sqrt((Math_fround($82)))));
  $84 = $83 != Math_fround(0.0);
  if ($84) {
   $85 = Math_fround(Math_fround(1.0) / $83);
   $86 = Math_fround($75 * $85);
   $87 = Math_fround($76 * $85);
   $88 = Math_fround($77 * $85);
   HEAPF32[$mtd>>2] = $86;
   $89 = (($mtd) + 4|0);
   HEAPF32[$89>>2] = $87;
   $90 = (($mtd) + 8|0);
   HEAPF32[$90>>2] = $88;
   $91 = Math_fround(HEAPF32[$4>>2]);
   $92 = (Math_fround(Math_sqrt((Math_fround($3)))));
   $93 = Math_fround($91 - $92);
   $94 = $93 > Math_fround(0.0);
   $95 = $94 ? $93 : Math_fround(0.0);
   HEAPF32[$depth>>2] = $95;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $208 = Math_fround(0.0);$209 = Math_fround(0.0);$210 = Math_fround(0.0);$PenDepth$034$i = Math_fround(3.40282346638528859812E+38);$i$035$i = 0;
 while(1) {
  $$idx$i = (($box) + (($i$035$i*12)|0)|0);
  $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
  $$idx3$i = ((($box) + (($i$035$i*12)|0)|0) + 4|0);
  $$idx3$val$i = Math_fround(HEAPF32[$$idx3$i>>2]);
  $$idx4$i = ((($box) + (($i$035$i*12)|0)|0) + 8|0);
  $$idx4$val$i = Math_fround(HEAPF32[$$idx4$i>>2]);
  $96 = (__ZL11PxcTestAxisRKN5physx6PxVec3ERKNS_2Gu7SegmentEfRKNS3_3BoxERf($$idx$val$i,$$idx3$val$i,$$idx4$val$i,$capsule,$5,$box,$d$i)|0);
  if (!($96)) {
   $$0 = 0;
   label = 28;
   break;
  }
  $97 = Math_fround(HEAPF32[$d$i>>2]);
  $98 = $97 < $PenDepth$034$i;
  if ($98) {
   $99 = Math_fround(HEAPF32[$$idx$i>>2]);
   $100 = Math_fround(HEAPF32[$$idx3$i>>2]);
   $101 = Math_fround(HEAPF32[$$idx4$i>>2]);
   $211 = $101;$212 = $100;$213 = $99;$PenDepth$1$i = $97;
  } else {
   $211 = $210;$212 = $209;$213 = $208;$PenDepth$1$i = $PenDepth$034$i;
  }
  $102 = (($i$035$i) + 1)|0;
  $103 = ($102>>>0)<(3);
  if ($103) {
   $208 = $213;$209 = $212;$210 = $211;$PenDepth$034$i = $PenDepth$1$i;$i$035$i = $102;
  } else {
   break;
  }
 }
 if ((label|0) == 28) {
  STACKTOP = sp;return ($$0|0);
 }
 $104 = (($capsule) + 12|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround(HEAPF32[$capsule>>2]);
 $107 = Math_fround($105 - $106);
 $108 = (($capsule) + 16|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($capsule) + 4|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($109 - $111);
 $113 = (($capsule) + 20|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($capsule) + 8|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($114 - $116);
 $118 = Math_fround($107 * $107);
 $119 = Math_fround($112 * $112);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($117 * $117);
 $122 = Math_fround($120 + $121);
 $123 = $122 > Math_fround(0.0);
 if ($123) {
  $124 = (Math_fround(Math_sqrt((Math_fround($122)))));
  $125 = Math_fround(Math_fround(1.0) / $124);
  $126 = Math_fround($107 * $125);
  $127 = Math_fround($112 * $125);
  $128 = Math_fround($117 * $125);
  $132 = $127;$136 = $128;$142 = $126;
 } else {
  $132 = Math_fround(0.0);$136 = Math_fround(0.0);$142 = Math_fround(0.0);
 }
 $214 = $213;$215 = $212;$216 = $211;$PenDepth$224$i = $PenDepth$1$i;$i1$025$i = 0;
 while(1) {
  $129 = ((($box) + (($i1$025$i*12)|0)|0) + 8|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($132 * $130);
  $133 = ((($box) + (($i1$025$i*12)|0)|0) + 4|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($136 * $134);
  $137 = Math_fround($131 - $135);
  $138 = (($box) + (($i1$025$i*12)|0)|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($136 * $139);
  $141 = Math_fround($142 * $130);
  $143 = Math_fround($140 - $141);
  $144 = Math_fround($142 * $134);
  $145 = Math_fround($132 * $139);
  $146 = Math_fround($144 - $145);
  $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($137)))));
  $147 = +$fabsf$i$i$i$i;
  $148 = $147 > 9.99999999999999954748E-7;
  if ($148) {
   label = 16;
  } else {
   $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($143)))));
   $149 = +$fabsf$i$i1$i$i;
   $150 = $149 > 9.99999999999999954748E-7;
   if ($150) {
    label = 16;
   } else {
    $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($146)))));
    $151 = +$fabsf$i$i2$i$i;
    $152 = $151 > 9.99999999999999954748E-7;
    if ($152) {
     label = 16;
    } else {
     $188 = $214;$190 = $215;$193 = $216;$PenDepth$3$i = $PenDepth$224$i;
    }
   }
  }
  if ((label|0) == 16) {
   label = 0;
   $153 = Math_fround($137 * $137);
   $154 = Math_fround($143 * $143);
   $155 = Math_fround($153 + $154);
   $156 = Math_fround($146 * $146);
   $157 = Math_fround($156 + $155);
   $158 = $157 > Math_fround(0.0);
   if ($158) {
    $159 = (Math_fround(Math_sqrt((Math_fround($157)))));
    $160 = Math_fround(Math_fround(1.0) / $159);
    $161 = Math_fround($137 * $160);
    $162 = Math_fround($143 * $160);
    $163 = Math_fround($146 * $160);
    $164 = $161;$165 = $162;$166 = $163;
   } else {
    $164 = Math_fround(0.0);$165 = Math_fround(0.0);$166 = Math_fround(0.0);
   }
   $167 = (__ZL11PxcTestAxisRKN5physx6PxVec3ERKNS_2Gu7SegmentEfRKNS3_3BoxERf($164,$165,$166,$capsule,$5,$box,$d2$i)|0);
   if (!($167)) {
    $$0 = 0;
    label = 28;
    break;
   }
   $168 = Math_fround(HEAPF32[$d2$i>>2]);
   $169 = $168 < $PenDepth$224$i;
   if ($169) {
    $188 = $164;$190 = $165;$193 = $166;$PenDepth$3$i = $168;
   } else {
    $188 = $214;$190 = $215;$193 = $216;$PenDepth$3$i = $PenDepth$224$i;
   }
  }
  $170 = (($i1$025$i) + 1)|0;
  $171 = ($170>>>0)<(3);
  if ($171) {
   $214 = $188;$215 = $190;$216 = $193;$PenDepth$224$i = $PenDepth$3$i;$i1$025$i = $170;
  } else {
   break;
  }
 }
 if ((label|0) == 28) {
  STACKTOP = sp;return ($$0|0);
 }
 $172 = Math_fround(HEAPF32[$capsule>>2]);
 $173 = Math_fround(HEAPF32[$104>>2]);
 $174 = Math_fround($172 + $173);
 $175 = Math_fround(HEAPF32[$110>>2]);
 $176 = Math_fround(HEAPF32[$108>>2]);
 $177 = Math_fround($175 + $176);
 $178 = Math_fround(HEAPF32[$115>>2]);
 $179 = Math_fround(HEAPF32[$113>>2]);
 $180 = Math_fround($178 + $179);
 $181 = Math_fround($174 * Math_fround(0.5));
 $182 = Math_fround($177 * Math_fround(0.5));
 $183 = Math_fround($180 * Math_fround(0.5));
 $$idx8$i = (($box) + 36|0);
 $$idx8$val$i = Math_fround(HEAPF32[$$idx8$i>>2]);
 $$idx9$i = (($box) + 40|0);
 $$idx9$val$i = Math_fround(HEAPF32[$$idx9$i>>2]);
 $$idx10$i = (($box) + 44|0);
 $$idx10$val$i = Math_fround(HEAPF32[$$idx10$i>>2]);
 $184 = Math_fround($181 - $$idx8$val$i);
 $185 = Math_fround($182 - $$idx9$val$i);
 $186 = Math_fround($183 - $$idx10$val$i);
 $187 = Math_fround($188 * $184);
 $189 = Math_fround($190 * $185);
 $191 = Math_fround($187 + $189);
 $192 = Math_fround($193 * $186);
 $194 = Math_fround($191 + $192);
 $195 = $194 < Math_fround(0.0);
 if ($195) {
  $196 = Math_fround(-$188);
  $197 = Math_fround(-$190);
  $198 = Math_fround(-$193);
  $203 = $196;$205 = $197;$207 = $198;
 } else {
  $203 = $188;$205 = $190;$207 = $193;
 }
 $199 = ($depth|0)==(0|0);
 if (!($199)) {
  $200 = $PenDepth$3$i > Math_fround(0.0);
  $201 = $200 ? $PenDepth$3$i : Math_fround(0.0);
  HEAPF32[$depth>>2] = $201;
 }
 $202 = ($mtd|0)==(0|0);
 if ($202) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$mtd>>2] = $203;
 $204 = (($mtd) + 4|0);
 HEAPF32[$204>>2] = $205;
 $206 = (($mtd) + 8|0);
 HEAPF32[$206>>2] = $207;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu17computeMTD_BoxBoxERNS_6PxVec3ERfRKNS0_3BoxES6_($_mtd,$_depth,$box0,$box1) {
 $_mtd = $_mtd|0;
 $_depth = $_depth|0;
 $box0 = $box0|0;
 $box1 = $box1|0;
 var $$0 = 0, $$idx = 0, $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $$idx3 = 0, $$idx3$val = Math_fround(0), $$idx4 = 0, $$idx4$val = Math_fround(0), $$idx5 = 0, $$idx5$val = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $9 = 0, $cross = 0;
 var $depth = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $i$09 = 0, $j$011 = 0, $mtd = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $mtd = sp + 16|0;
 $depth = sp;
 $cross = sp + 4|0;
 HEAPF32[$depth>>2] = Math_fround(3.40282346638528859812E+38);
 $0 = (__ZL14testBoxBoxAxisRN5physx6PxVec3ERfRKS0_RKNS_2Gu3BoxES8_($mtd,$depth,$box0,$box0,$box1)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($box0) + 12|0);
 $2 = (__ZL14testBoxBoxAxisRN5physx6PxVec3ERfRKS0_RKNS_2Gu3BoxES8_($mtd,$depth,$1,$box0,$box1)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($box0) + 24|0);
 $4 = (__ZL14testBoxBoxAxisRN5physx6PxVec3ERfRKS0_RKNS_2Gu3BoxES8_($mtd,$depth,$3,$box0,$box1)|0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__ZL14testBoxBoxAxisRN5physx6PxVec3ERfRKS0_RKNS_2Gu3BoxES8_($mtd,$depth,$box1,$box0,$box1)|0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($box1) + 12|0);
 $7 = (__ZL14testBoxBoxAxisRN5physx6PxVec3ERfRKS0_RKNS_2Gu3BoxES8_($mtd,$depth,$6,$box0,$box1)|0);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($box1) + 24|0);
 $9 = (__ZL14testBoxBoxAxisRN5physx6PxVec3ERfRKS0_RKNS_2Gu3BoxES8_($mtd,$depth,$8,$box0,$box1)|0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($cross) + 4|0);
 $11 = (($cross) + 8|0);
 $j$011 = 0;
 L19: while(1) {
  $12 = ((($box1) + (($j$011*12)|0)|0) + 8|0);
  $13 = ((($box1) + (($j$011*12)|0)|0) + 4|0);
  $14 = (($box1) + (($j$011*12)|0)|0);
  $i$09 = 0;
  while(1) {
   $15 = ((($box0) + (($i$09*12)|0)|0) + 4|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround(HEAPF32[$12>>2]);
   $18 = Math_fround($16 * $17);
   $19 = ((($box0) + (($i$09*12)|0)|0) + 8|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround(HEAPF32[$13>>2]);
   $22 = Math_fround($20 * $21);
   $23 = Math_fround($18 - $22);
   $24 = Math_fround(HEAPF32[$14>>2]);
   $25 = Math_fround($20 * $24);
   $26 = (($box0) + (($i$09*12)|0)|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($17 * $27);
   $29 = Math_fround($25 - $28);
   $30 = Math_fround($21 * $27);
   $31 = Math_fround($16 * $24);
   $32 = Math_fround($30 - $31);
   HEAPF32[$cross>>2] = $23;
   HEAPF32[$10>>2] = $29;
   HEAPF32[$11>>2] = $32;
   $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($23)))));
   $33 = +$fabsf$i$i$i;
   $34 = $33 > 9.99999999999999954748E-7;
   if ($34) {
    label = 12;
   } else {
    $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($29)))));
    $35 = +$fabsf$i$i1$i;
    $36 = $35 > 9.99999999999999954748E-7;
    if ($36) {
     label = 12;
    } else {
     $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($32)))));
     $37 = +$fabsf$i$i2$i;
     $38 = $37 > 9.99999999999999954748E-7;
     if ($38) {
      label = 12;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    $39 = Math_fround($23 * $23);
    $40 = Math_fround($29 * $29);
    $41 = Math_fround($39 + $40);
    $42 = Math_fround($32 * $32);
    $43 = Math_fround($41 + $42);
    $44 = $43 > Math_fround(0.0);
    if ($44) {
     $45 = (Math_fround(Math_sqrt((Math_fround($43)))));
     $46 = Math_fround(Math_fround(1.0) / $45);
     $47 = Math_fround($23 * $46);
     $48 = Math_fround($29 * $46);
     $49 = Math_fround($32 * $46);
     $50 = $47;$51 = $48;$52 = $49;
    } else {
     $50 = Math_fround(0.0);$51 = Math_fround(0.0);$52 = Math_fround(0.0);
    }
    HEAPF32[$cross>>2] = $50;
    HEAPF32[$10>>2] = $51;
    HEAPF32[$11>>2] = $52;
    $53 = (__ZL14testBoxBoxAxisRN5physx6PxVec3ERfRKS0_RKNS_2Gu3BoxES8_($mtd,$depth,$cross,$box0,$box1)|0);
    if (!($53)) {
     $$0 = 0;
     label = 20;
     break L19;
    }
   }
   $54 = (($i$09) + 1)|0;
   $55 = ($54>>>0)<(3);
   if ($55) {
    $i$09 = $54;
   } else {
    break;
   }
  }
  $56 = (($j$011) + 1)|0;
  $57 = ($56>>>0)<(3);
  if ($57) {
   $j$011 = $56;
  } else {
   break;
  }
 }
 if ((label|0) == 20) {
  STACKTOP = sp;return ($$0|0);
 }
 $$idx = (($box1) + 36|0);
 $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
 $$idx1 = (($box1) + 40|0);
 $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
 $$idx2 = (($box1) + 44|0);
 $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
 $$idx3 = (($box0) + 36|0);
 $$idx3$val = Math_fround(HEAPF32[$$idx3>>2]);
 $$idx4 = (($box0) + 40|0);
 $$idx4$val = Math_fround(HEAPF32[$$idx4>>2]);
 $$idx5 = (($box0) + 44|0);
 $$idx5$val = Math_fround(HEAPF32[$$idx5>>2]);
 $58 = Math_fround($$idx$val - $$idx3$val);
 $59 = Math_fround($$idx1$val - $$idx4$val);
 $60 = Math_fround($$idx2$val - $$idx5$val);
 $61 = Math_fround(HEAPF32[$mtd>>2]);
 $62 = Math_fround($58 * $61);
 $63 = (($mtd) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($59 * $64);
 $66 = Math_fround($62 + $65);
 $67 = (($mtd) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($60 * $68);
 $70 = Math_fround($66 + $69);
 $71 = $70 < Math_fround(0.0);
 if ($71) {
  $72 = Math_fround(-$61);
  $73 = Math_fround(-$64);
  $74 = Math_fround(-$68);
  HEAPF32[$mtd>>2] = $72;
  HEAPF32[$63>>2] = $73;
  HEAPF32[$67>>2] = $74;
  $76 = $72;$78 = $73;$80 = $74;
 } else {
  $76 = $61;$78 = $64;$80 = $68;
 }
 $75 = Math_fround(-$76);
 $77 = Math_fround(-$78);
 $79 = Math_fround(-$80);
 HEAPF32[$_mtd>>2] = $75;
 $81 = (($_mtd) + 4|0);
 HEAPF32[$81>>2] = $77;
 $82 = (($_mtd) + 8|0);
 HEAPF32[$82>>2] = $79;
 $83 = Math_fround(HEAPF32[$depth>>2]);
 $84 = $83 > Math_fround(0.0);
 $85 = $84 ? $83 : Math_fround(0.0);
 HEAPF32[$_depth>>2] = $85;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL14testBoxBoxAxisRN5physx6PxVec3ERfRKS0_RKNS_2Gu3BoxES8_($mtd,$depth,$axis,$box0,$box1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $axis = $axis|0;
 $box0 = $box0|0;
 $box1 = $box1|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0);
 var $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0;
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $axis$idx$val = Math_fround(0), $axis$idx1 = 0, $axis$idx1$val = Math_fround(0), $axis$idx2 = 0, $axis$idx2$val = Math_fround(0), $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i$i8$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i1$i7$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i2$i6$i = Math_fround(0), $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $axis$idx$val = Math_fround(HEAPF32[$axis>>2]);
 $axis$idx1 = (($axis) + 4|0);
 $axis$idx1$val = Math_fround(HEAPF32[$axis$idx1>>2]);
 $axis$idx2 = (($axis) + 8|0);
 $axis$idx2$val = Math_fround(HEAPF32[$axis$idx2>>2]);
 $0 = (($box0) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($axis$idx$val * $1);
 $3 = (($box0) + 40|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($axis$idx1$val * $4);
 $6 = Math_fround($2 + $5);
 $7 = (($box0) + 44|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($axis$idx2$val * $8);
 $10 = Math_fround($6 + $9);
 $11 = Math_fround(HEAPF32[$box0>>2]);
 $12 = Math_fround($axis$idx$val * $11);
 $13 = (($box0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($axis$idx1$val * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($box0) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($axis$idx2$val * $18);
 $20 = Math_fround($16 + $19);
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($20)))));
 $21 = (($box0) + 48|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($fabsf$i$i2$i$i * $22);
 $24 = (($box0) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($axis$idx$val * $25);
 $27 = (($box0) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($axis$idx1$val * $28);
 $30 = Math_fround($26 + $29);
 $31 = (($box0) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($axis$idx2$val * $32);
 $34 = Math_fround($30 + $33);
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($34)))));
 $35 = (($box0) + 52|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($fabsf$i$i1$i$i * $36);
 $38 = Math_fround($23 + $37);
 $39 = (($box0) + 24|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($axis$idx$val * $40);
 $42 = (($box0) + 28|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($axis$idx1$val * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($box0) + 32|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($axis$idx2$val * $47);
 $49 = Math_fround($45 + $48);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($49)))));
 $50 = (($box0) + 56|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($fabsf$i$i$i$i * $51);
 $53 = Math_fround($38 + $52);
 $54 = Math_fround($10 - $53);
 $55 = Math_fround($10 + $53);
 $56 = (($box1) + 36|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($axis$idx$val * $57);
 $59 = (($box1) + 40|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($axis$idx1$val * $60);
 $62 = Math_fround($58 + $61);
 $63 = (($box1) + 44|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($axis$idx2$val * $64);
 $66 = Math_fround($62 + $65);
 $67 = Math_fround(HEAPF32[$box1>>2]);
 $68 = Math_fround($axis$idx$val * $67);
 $69 = (($box1) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($axis$idx1$val * $70);
 $72 = Math_fround($68 + $71);
 $73 = (($box1) + 8|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($axis$idx2$val * $74);
 $76 = Math_fround($72 + $75);
 $fabsf$i$i2$i6$i = (Math_fround(Math_abs((Math_fround($76)))));
 $77 = (($box1) + 48|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($fabsf$i$i2$i6$i * $78);
 $80 = (($box1) + 12|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($axis$idx$val * $81);
 $83 = (($box1) + 16|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($axis$idx1$val * $84);
 $86 = Math_fround($82 + $85);
 $87 = (($box1) + 20|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($axis$idx2$val * $88);
 $90 = Math_fround($86 + $89);
 $fabsf$i$i1$i7$i = (Math_fround(Math_abs((Math_fround($90)))));
 $91 = (($box1) + 52|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($fabsf$i$i1$i7$i * $92);
 $94 = Math_fround($79 + $93);
 $95 = (($box1) + 24|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($axis$idx$val * $96);
 $98 = (($box1) + 28|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($axis$idx1$val * $99);
 $101 = Math_fround($97 + $100);
 $102 = (($box1) + 32|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($axis$idx2$val * $103);
 $105 = Math_fround($101 + $104);
 $fabsf$i$i$i8$i = (Math_fround(Math_abs((Math_fround($105)))));
 $106 = (($box1) + 56|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($fabsf$i$i$i8$i * $107);
 $109 = Math_fround($94 + $108);
 $110 = Math_fround($66 - $109);
 $111 = Math_fround($66 + $109);
 $112 = $55 < $110;
 $113 = $111 < $54;
 $or$cond$i = $112 | $113;
 if ($or$cond$i) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $114 = Math_fround($55 - $110);
 $115 = Math_fround($111 - $54);
 $116 = $114 < $115;
 $117 = $116 ? $114 : $115;
 $118 = Math_fround(HEAPF32[$depth>>2]);
 $119 = $117 < $118;
 if (!($119)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$depth>>2] = $117;
 $120 = Math_fround(HEAPF32[$axis>>2]);
 HEAPF32[$mtd>>2] = $120;
 $121 = Math_fround(HEAPF32[$axis$idx1>>2]);
 $122 = (($mtd) + 4|0);
 HEAPF32[$122>>2] = $121;
 $123 = Math_fround(HEAPF32[$axis$idx2>>2]);
 $124 = (($mtd) + 8|0);
 HEAPF32[$124>>2] = $123;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z19pointConvexDistanceRN5physx6PxVec3ES1_RfRKS0_PKNS_2Gu10ConvexMeshERKNS_11PxMeshScaleERKNS_11PxTransformE($normal_,$closestPoint_,$sqDistance,$pt,$convexMesh,$meshScale,$convexPose) {
 $normal_ = $normal_|0;
 $closestPoint_ = $closestPoint_|0;
 $sqDistance = $sqDistance|0;
 $pt = $pt|0;
 $convexMesh = $convexMesh|0;
 $meshScale = $meshScale|0;
 $convexPose = $convexPose|0;
 var $$sroa$110 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $aToB = 0, $capsule = 0, $closA = 0, $closB = 0, $convexHull = 0, $normalV = 0, $sqDist = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $zero$sroa$1$i$i$i = sp + 556|0;
 $0 = sp + 528|0;
 $zeroV = sp + 512|0;
 $closA = sp + 496|0;
 $closB = sp + 480|0;
 $normalV = sp + 464|0;
 $sqDist = sp + 448|0;
 $vScale = sp + 288|0;
 $vQuat = sp + 272|0;
 $convexHull = sp + 64|0;
 $aToB = sp;
 $capsule = sp + 304|0;
 $$sroa$110 = sp + 544|0;
 $1 = Math_fround(HEAPF32[$pt>>2]);
 $2 = (($pt) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($pt) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $6 = (($convexMesh) + 16|0);
 $7 = Math_fround(HEAPF32[$meshScale>>2]);
 $8 = (($meshScale) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($meshScale) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$vScale>>2] = $7;
 $12 = (($vScale) + 4|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($vScale) + 8|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($vScale) + 12|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($meshScale) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($15) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($15) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($15) + 12|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$vQuat>>2] = $16;
 $23 = (($vQuat) + 4|0);
 HEAPF32[$23>>2] = $18;
 $24 = (($vQuat) + 8|0);
 HEAPF32[$24>>2] = $20;
 $25 = (($vQuat) + 12|0);
 HEAPF32[$25>>2] = $22;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$6,$zeroV,$vScale,$vQuat);
 $26 = Math_fround(HEAPF32[$convexPose>>2]);
 $27 = Math_fround(-$26);
 $28 = (($convexPose) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround(-$29);
 $31 = (($convexPose) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(-$32);
 $34 = (($convexPose) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($convexPose) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($1 - $37);
 $39 = (($convexPose) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($3 - $40);
 $42 = (($convexPose) + 24|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($5 - $43);
 $45 = Math_fround($38 * Math_fround(2.0));
 $46 = Math_fround($41 * Math_fround(2.0));
 $47 = Math_fround($44 * Math_fround(2.0));
 $48 = Math_fround($35 * $35);
 $49 = Math_fround($48 + Math_fround(-0.5));
 $50 = Math_fround($45 * $27);
 $51 = Math_fround($46 * $30);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($47 * $33);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($49 * $45);
 $56 = Math_fround($47 * $30);
 $57 = Math_fround($46 * $33);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($35 * $58);
 $60 = Math_fround($55 + $59);
 $61 = Math_fround($54 * $27);
 $62 = Math_fround($61 + $60);
 $63 = Math_fround($49 * $46);
 $64 = Math_fround($45 * $33);
 $65 = Math_fround($47 * $27);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround($35 * $66);
 $68 = Math_fround($63 + $67);
 $69 = Math_fround($54 * $30);
 $70 = Math_fround($69 + $68);
 $71 = Math_fround($49 * $47);
 $72 = Math_fround($46 * $27);
 $73 = Math_fround($45 * $30);
 $74 = Math_fround($72 - $73);
 $75 = Math_fround($35 * $74);
 $76 = Math_fround($71 + $75);
 $77 = Math_fround($54 * $33);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($35 * Math_fround(0.0));
 $80 = Math_fround($79 - $26);
 $81 = Math_fround($29 * Math_fround(-0.0));
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($32 * Math_fround(-0.0));
 $84 = Math_fround($82 - $83);
 $85 = Math_fround($79 - $29);
 $86 = Math_fround($83 + $85);
 $87 = Math_fround($26 * Math_fround(-0.0));
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($79 - $32);
 $90 = Math_fround($87 + $89);
 $91 = Math_fround($90 - $81);
 $92 = Math_fround($35 - $87);
 $93 = Math_fround($92 - $81);
 $94 = Math_fround($93 - $83);
 $95 = (($aToB) + 48|0);
 HEAPF32[$95>>2] = $62;
 $96 = (($aToB) + 52|0);
 HEAPF32[$96>>2] = $70;
 $97 = (($aToB) + 56|0);
 HEAPF32[$97>>2] = $78;
 $98 = (($aToB) + 60|0);
 HEAPF32[$98>>2] = Math_fround(0.0);
 $99 = Math_fround($84 + $84);
 $100 = Math_fround($88 + $88);
 $101 = Math_fround($91 + $91);
 $102 = Math_fround($84 * $99);
 $103 = Math_fround($88 * $100);
 $104 = Math_fround($91 * $101);
 $105 = Math_fround($88 * $99);
 $106 = Math_fround($91 * $99);
 $107 = Math_fround($94 * $99);
 $108 = Math_fround($91 * $100);
 $109 = Math_fround($94 * $100);
 $110 = Math_fround($94 * $101);
 $111 = Math_fround(Math_fround(1.0) - $102);
 $112 = Math_fround(Math_fround(1.0) - $103);
 $113 = Math_fround($112 - $104);
 $114 = Math_fround($105 + $110);
 $115 = Math_fround($106 - $109);
 $116 = Math_fround($105 - $110);
 $117 = Math_fround($111 - $104);
 $118 = Math_fround($108 + $107);
 $119 = Math_fround($106 + $109);
 $120 = Math_fround($108 - $107);
 $121 = Math_fround($111 - $103);
 HEAPF32[$aToB>>2] = $113;
 $122 = (($aToB) + 4|0);
 HEAPF32[$122>>2] = $114;
 $123 = (($aToB) + 8|0);
 HEAPF32[$123>>2] = $115;
 $124 = (($aToB) + 12|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = (($aToB) + 16|0);
 HEAPF32[$125>>2] = $116;
 $126 = (($aToB) + 20|0);
 HEAPF32[$126>>2] = $117;
 $127 = (($aToB) + 24|0);
 HEAPF32[$127>>2] = $118;
 $128 = (($aToB) + 28|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 $129 = (($aToB) + 32|0);
 HEAPF32[$129>>2] = $119;
 $130 = (($aToB) + 36|0);
 HEAPF32[$130>>2] = $120;
 $131 = (($aToB) + 40|0);
 HEAPF32[$131>>2] = $121;
 $132 = (($aToB) + 44|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = (($capsule) + 64|0);
 ;HEAP32[$capsule+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$capsule+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$capsule+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$capsule+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $134 = (($capsule) + 80|0);
 HEAP32[$134>>2] = 4;
 $135 = (($capsule) + 16|0);
 $136 = (($capsule) + 20|0);
 $137 = (($capsule) + 32|0);
 $138 = (($capsule) + 36|0);
 $139 = (($capsule) + 48|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($capsule) + 52|0);
 ;HEAP32[$140+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$140+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$140+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $141 = (($capsule) + 128|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 $142 = (($capsule) + 132|0);
 ;HEAP32[$142+0>>2]=HEAP32[$$sroa$110+0>>2]|0;HEAP32[$142+4>>2]=HEAP32[$$sroa$110+4>>2]|0;HEAP32[$142+8>>2]=HEAP32[$$sroa$110+8>>2]|0;
 $143 = Math_fround(HEAPF32[$zeroV>>2]);
 $144 = (($zeroV) + 4|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($zeroV) + 8|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = Math_fround($143 + $143);
 $149 = Math_fround($145 + $145);
 $150 = Math_fround($147 + $147);
 $151 = (($capsule) + 96|0);
 HEAPF32[$151>>2] = $148;
 $152 = (($capsule) + 100|0);
 HEAPF32[$152>>2] = $149;
 $153 = (($capsule) + 104|0);
 HEAPF32[$153>>2] = $150;
 $154 = (($capsule) + 108|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 $155 = Math_fround($143 - $143);
 $156 = Math_fround($145 - $145);
 $157 = Math_fround($147 - $147);
 $158 = (($capsule) + 112|0);
 HEAPF32[$158>>2] = $155;
 $159 = (($capsule) + 116|0);
 HEAPF32[$159>>2] = $156;
 $160 = (($capsule) + 120|0);
 HEAPF32[$160>>2] = $157;
 $161 = (($capsule) + 124|0);
 HEAPF32[$161>>2] = Math_fround(0.0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 ;HEAP32[$136+0>>2]=HEAP32[$$sroa$110+0>>2]|0;HEAP32[$136+4>>2]=HEAP32[$$sroa$110+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$$sroa$110+8>>2]|0;
 HEAPF32[$137>>2] = Math_fround(0.0);
 ;HEAP32[$138+0>>2]=HEAP32[$$sroa$110+0>>2]|0;HEAP32[$138+4>>2]=HEAP32[$$sroa$110+4>>2]|0;HEAP32[$138+8>>2]=HEAP32[$$sroa$110+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$133+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$133+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$133+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$133+12>>2]=HEAP32[$0+12>>2]|0;
 $162 = (__ZN5physx2Gu11GJKRelativeERKNS0_8CapsuleVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERNS8_5Vec3VESD_SD_RNS8_6FloatVE($capsule,$convexHull,$aToB,$closA,$closB,$normalV,$sqDist)|0);
 $163 = ($162|0)==(1);
 if ($163) {
  HEAPF32[$sqDistance>>2] = Math_fround(0.0);
  STACKTOP = sp;return ($163|0);
 } else {
  $164 = Math_fround(HEAPF32[$sqDist>>2]);
  HEAPF32[$sqDistance>>2] = $164;
  $165 = Math_fround(HEAPF32[$normalV>>2]);
  $166 = (($normalV) + 4|0);
  $167 = Math_fround(HEAPF32[$166>>2]);
  $168 = (($normalV) + 8|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  HEAPF32[$normal_>>2] = $165;
  $170 = (($normal_) + 4|0);
  HEAPF32[$170>>2] = $167;
  $171 = (($normal_) + 8|0);
  HEAPF32[$171>>2] = $169;
  $172 = Math_fround(HEAPF32[$closB>>2]);
  $173 = (($closB) + 4|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = (($closB) + 8|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  HEAPF32[$closestPoint_>>2] = $172;
  $177 = (($closestPoint_) + 4|0);
  HEAPF32[$177>>2] = $174;
  $178 = (($closestPoint_) + 8|0);
  HEAPF32[$178>>2] = $176;
  $179 = Math_fround(HEAPF32[$normal_>>2]);
  $180 = Math_fround($179 * Math_fround(2.0));
  $181 = Math_fround(HEAPF32[$170>>2]);
  $182 = Math_fround($181 * Math_fround(2.0));
  $183 = Math_fround(HEAPF32[$171>>2]);
  $184 = Math_fround($183 * Math_fround(2.0));
  $185 = Math_fround(HEAPF32[$34>>2]);
  $186 = Math_fround($185 * $185);
  $187 = Math_fround($186 + Math_fround(-0.5));
  $188 = Math_fround(HEAPF32[$convexPose>>2]);
  $189 = Math_fround($180 * $188);
  $190 = Math_fround(HEAPF32[$28>>2]);
  $191 = Math_fround($182 * $190);
  $192 = Math_fround($189 + $191);
  $193 = Math_fround(HEAPF32[$31>>2]);
  $194 = Math_fround($184 * $193);
  $195 = Math_fround($192 + $194);
  $196 = Math_fround($180 * $187);
  $197 = Math_fround($184 * $190);
  $198 = Math_fround($182 * $193);
  $199 = Math_fround($197 - $198);
  $200 = Math_fround($185 * $199);
  $201 = Math_fround($196 + $200);
  $202 = Math_fround($188 * $195);
  $203 = Math_fround($202 + $201);
  $204 = Math_fround($182 * $187);
  $205 = Math_fround($180 * $193);
  $206 = Math_fround($184 * $188);
  $207 = Math_fround($205 - $206);
  $208 = Math_fround($185 * $207);
  $209 = Math_fround($204 + $208);
  $210 = Math_fround($190 * $195);
  $211 = Math_fround($210 + $209);
  $212 = Math_fround($184 * $187);
  $213 = Math_fround($182 * $188);
  $214 = Math_fround($180 * $190);
  $215 = Math_fround($213 - $214);
  $216 = Math_fround($185 * $215);
  $217 = Math_fround($212 + $216);
  $218 = Math_fround($193 * $195);
  $219 = Math_fround($217 + $218);
  HEAPF32[$normal_>>2] = $203;
  HEAPF32[$170>>2] = $211;
  HEAPF32[$171>>2] = $219;
  $220 = Math_fround(HEAPF32[$closestPoint_>>2]);
  $221 = Math_fround($220 * Math_fround(2.0));
  $222 = Math_fround(HEAPF32[$177>>2]);
  $223 = Math_fround($222 * Math_fround(2.0));
  $224 = Math_fround(HEAPF32[$178>>2]);
  $225 = Math_fround($224 * Math_fround(2.0));
  $226 = Math_fround(HEAPF32[$34>>2]);
  $227 = Math_fround($226 * $226);
  $228 = Math_fround($227 + Math_fround(-0.5));
  $229 = Math_fround(HEAPF32[$convexPose>>2]);
  $230 = Math_fround($221 * $229);
  $231 = Math_fround(HEAPF32[$28>>2]);
  $232 = Math_fround($223 * $231);
  $233 = Math_fround($230 + $232);
  $234 = Math_fround(HEAPF32[$31>>2]);
  $235 = Math_fround($225 * $234);
  $236 = Math_fround($233 + $235);
  $237 = Math_fround($221 * $228);
  $238 = Math_fround($225 * $231);
  $239 = Math_fround($223 * $234);
  $240 = Math_fround($238 - $239);
  $241 = Math_fround($226 * $240);
  $242 = Math_fround($237 + $241);
  $243 = Math_fround($229 * $236);
  $244 = Math_fround($243 + $242);
  $245 = Math_fround($223 * $228);
  $246 = Math_fround($221 * $234);
  $247 = Math_fround($225 * $229);
  $248 = Math_fround($246 - $247);
  $249 = Math_fround($226 * $248);
  $250 = Math_fround($245 + $249);
  $251 = Math_fround($231 * $236);
  $252 = Math_fround($251 + $250);
  $253 = Math_fround($225 * $228);
  $254 = Math_fround($223 * $229);
  $255 = Math_fround($221 * $231);
  $256 = Math_fround($254 - $255);
  $257 = Math_fround($226 * $256);
  $258 = Math_fround($253 + $257);
  $259 = Math_fround($234 * $236);
  $260 = Math_fround($258 + $259);
  $261 = Math_fround(HEAPF32[$36>>2]);
  $262 = Math_fround($261 + $244);
  $263 = Math_fround(HEAPF32[$39>>2]);
  $264 = Math_fround($263 + $252);
  $265 = Math_fround(HEAPF32[$42>>2]);
  $266 = Math_fround($265 + $260);
  HEAPF32[$closestPoint_>>2] = $262;
  HEAPF32[$177>>2] = $264;
  HEAPF32[$178>>2] = $266;
  STACKTOP = sp;return ($163|0);
 }
 return 0|0;
}
function __ZN5physx2Gu23computeMTD_SphereConvexERNS_6PxVec3ERfRKNS0_6SphereERKNS_20PxConvexMeshGeometryERKNS_11PxTransformE($mtd,$depth,$sphere,$convexGeom,$convexPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $sphere = $sphere|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $d2 = 0, $dmax$0$ph = Math_fround(0), $dummy = 0, $nbPolygons$0 = 0, $nbPolygons$0$ph = 0, $polygons$0 = 0, $polygons$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $d2 = sp + 12|0;
 $dummy = sp;
 $0 = (($convexGeom) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($convexGeom) + 4|0);
 $3 = (__Z19pointConvexDistanceRN5physx6PxVec3ES1_RfRKS0_PKNS_2Gu10ConvexMeshERKNS_11PxMeshScaleERKNS_11PxTransformE($mtd,$dummy,$d2,$sphere,$1,$2,$convexPose)|0);
 if (!($3)) {
  $4 = Math_fround(HEAPF32[$d2>>2]);
  $5 = (($sphere) + 12|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($6 * $6);
  $8 = $4 > $7;
  if ($8) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $9 = (Math_fround(Math_sqrt((Math_fround($4)))));
  $10 = Math_fround($6 - $9);
  $11 = $10 > Math_fround(0.0);
  $12 = $11 ? $10 : Math_fround(0.0);
  HEAPF32[$depth>>2] = $12;
  $13 = Math_fround(HEAPF32[$mtd>>2]);
  $14 = Math_fround(-$13);
  $15 = (($mtd) + 4|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround(-$16);
  $18 = (($mtd) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround(-$19);
  HEAPF32[$mtd>>2] = $14;
  HEAPF32[$15>>2] = $17;
  HEAPF32[$18>>2] = $20;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($1) + 55|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22&255;
 $24 = (($1) + 56|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = Math_fround(HEAPF32[$sphere>>2]);
 $27 = (($convexPose) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($26 - $28);
 $30 = (($sphere) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($convexPose) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($31 - $33);
 $35 = (($sphere) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($convexPose) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 - $38);
 $40 = Math_fround($29 * Math_fround(2.0));
 $41 = Math_fround($34 * Math_fround(2.0));
 $42 = Math_fround($39 * Math_fround(2.0));
 $43 = (($convexPose) + 12|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 * $44);
 $46 = Math_fround($45 + Math_fround(-0.5));
 $47 = Math_fround(HEAPF32[$convexPose>>2]);
 $48 = Math_fround($40 * $47);
 $49 = (($convexPose) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($41 * $50);
 $52 = Math_fround($48 + $51);
 $53 = (($convexPose) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($42 * $54);
 $56 = Math_fround($52 + $55);
 $57 = Math_fround($40 * $46);
 $58 = Math_fround($42 * $50);
 $59 = Math_fround($41 * $54);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($44 * $60);
 $62 = Math_fround($57 - $61);
 $63 = Math_fround($47 * $56);
 $64 = Math_fround($63 + $62);
 $65 = Math_fround($41 * $46);
 $66 = Math_fround($40 * $54);
 $67 = Math_fround($42 * $47);
 $68 = Math_fround($66 - $67);
 $69 = Math_fround($44 * $68);
 $70 = Math_fround($65 - $69);
 $71 = Math_fround($50 * $56);
 $72 = Math_fround($71 + $70);
 $73 = Math_fround($42 * $46);
 $74 = Math_fround($41 * $47);
 $75 = Math_fround($40 * $50);
 $76 = Math_fround($74 - $75);
 $77 = Math_fround($44 * $76);
 $78 = Math_fround($73 - $77);
 $79 = Math_fround($54 * $56);
 $80 = Math_fround($78 + $79);
 $81 = (($mtd) + 4|0);
 $82 = (($mtd) + 8|0);
 $dmax$0$ph = Math_fround(-3.40282346638528859812E+38);$nbPolygons$0$ph = $23;$polygons$0$ph = $25;
 L8: while(1) {
  $nbPolygons$0 = $nbPolygons$0$ph;$polygons$0 = $polygons$0$ph;
  while(1) {
   $83 = (($nbPolygons$0) + -1)|0;
   $84 = ($nbPolygons$0|0)==(0);
   if ($84) {
    break L8;
   }
   $85 = (($polygons$0) + 20|0);
   $86 = Math_fround(HEAPF32[$polygons$0>>2]);
   $87 = Math_fround($64 * $86);
   $88 = (($polygons$0) + 4|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = Math_fround($72 * $89);
   $91 = Math_fround($87 + $90);
   $92 = (($polygons$0) + 8|0);
   $93 = Math_fround(HEAPF32[$92>>2]);
   $94 = Math_fround($80 * $93);
   $95 = Math_fround($91 + $94);
   $96 = (($polygons$0) + 12|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = Math_fround($97 + $95);
   $99 = $98 > $dmax$0$ph;
   if ($99) {
    break;
   } else {
    $nbPolygons$0 = $83;$polygons$0 = $85;
   }
  }
  $100 = Math_fround($86 * Math_fround(2.0));
  $101 = Math_fround($89 * Math_fround(2.0));
  $102 = Math_fround($93 * Math_fround(2.0));
  $103 = Math_fround(HEAPF32[$43>>2]);
  $104 = Math_fround($103 * $103);
  $105 = Math_fround($104 + Math_fround(-0.5));
  $106 = Math_fround(HEAPF32[$convexPose>>2]);
  $107 = Math_fround($100 * $106);
  $108 = Math_fround(HEAPF32[$49>>2]);
  $109 = Math_fround($101 * $108);
  $110 = Math_fround($107 + $109);
  $111 = Math_fround(HEAPF32[$53>>2]);
  $112 = Math_fround($102 * $111);
  $113 = Math_fround($110 + $112);
  $114 = Math_fround($100 * $105);
  $115 = Math_fround($102 * $108);
  $116 = Math_fround($101 * $111);
  $117 = Math_fround($115 - $116);
  $118 = Math_fround($103 * $117);
  $119 = Math_fround($114 + $118);
  $120 = Math_fround($106 * $113);
  $121 = Math_fround($120 + $119);
  $122 = Math_fround($101 * $105);
  $123 = Math_fround($100 * $111);
  $124 = Math_fround($102 * $106);
  $125 = Math_fround($123 - $124);
  $126 = Math_fround($103 * $125);
  $127 = Math_fround($122 + $126);
  $128 = Math_fround($108 * $113);
  $129 = Math_fround($128 + $127);
  $130 = Math_fround($102 * $105);
  $131 = Math_fround($101 * $106);
  $132 = Math_fround($100 * $108);
  $133 = Math_fround($131 - $132);
  $134 = Math_fround($103 * $133);
  $135 = Math_fround($130 + $134);
  $136 = Math_fround($111 * $113);
  $137 = Math_fround($135 + $136);
  HEAPF32[$mtd>>2] = $121;
  HEAPF32[$81>>2] = $129;
  HEAPF32[$82>>2] = $137;
  $dmax$0$ph = $98;$nbPolygons$0$ph = $83;$polygons$0$ph = $85;
 }
 $138 = (($sphere) + 12|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($139 - $dmax$0$ph);
 $141 = $140 > Math_fround(0.0);
 $142 = $141 ? $140 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $142;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu24computeMTD_CapsuleConvexERNS_6PxVec3ERfRKNS0_7CapsuleERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES9_($mtd,$depth,$capsule,$capsulePose,$convexGeom,$convexPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $capsule = $capsule|0;
 $capsulePose = $capsulePose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $capsuleRadius$sroa$1 = 0, $capsuleV = 0, $convexHullV = 0, $normal = 0, $penetrationDepth = 0, $transf1 = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 624|0;
 $zero$sroa$1$i$i$i = sp + 528|0;
 $0 = sp + 464|0;
 $capsuleRadius$sroa$1 = sp + 600|0;
 $zeroV = sp + 448|0;
 $vScale = sp + 432|0;
 $vQuat = sp + 416|0;
 $convexHullV = sp + 64|0;
 $transf1 = sp + 32|0;
 $normal = sp + 16|0;
 $penetrationDepth = sp;
 $capsuleV = sp + 272|0;
 $1 = (($capsule) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(HEAPF32[$capsule>>2]);
 $4 = Math_fround($2 - $3);
 $5 = (($capsule) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($capsule) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($capsule) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($capsule) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * $4);
 $16 = Math_fround($9 * $9);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($14 * $14);
 $19 = Math_fround($17 + $18);
 $20 = (Math_fround(Math_sqrt((Math_fround($19)))));
 $21 = Math_fround($20 * Math_fround(0.5));
 $22 = (($capsule) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $24 = (($convexGeom) + 32|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 16|0);
 $27 = (($convexGeom) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($convexGeom) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($convexGeom) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$vScale>>2] = $28;
 $33 = (($vScale) + 4|0);
 HEAPF32[$33>>2] = $30;
 $34 = (($vScale) + 8|0);
 HEAPF32[$34>>2] = $32;
 $35 = (($vScale) + 12|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($convexGeom) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($36) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($36) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($36) + 12|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$vQuat>>2] = $37;
 $44 = (($vQuat) + 4|0);
 HEAPF32[$44>>2] = $39;
 $45 = (($vQuat) + 8|0);
 HEAPF32[$45>>2] = $41;
 $46 = (($vQuat) + 12|0);
 HEAPF32[$46>>2] = $43;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHullV,$26,$zeroV,$vScale,$vQuat);
 $47 = Math_fround(HEAPF32[$capsulePose>>2]);
 $48 = (($capsulePose) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($capsulePose) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($capsulePose) + 12|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($capsulePose) + 16|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($54) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($54) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround(HEAPF32[$convexPose>>2]);
 $61 = (($convexPose) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($convexPose) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($convexPose) + 12|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($convexPose) + 16|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($67) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($67) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 HEAPF32[$transf1>>2] = $60;
 $73 = (($transf1) + 4|0);
 HEAPF32[$73>>2] = $62;
 $74 = (($transf1) + 8|0);
 HEAPF32[$74>>2] = $64;
 $75 = (($transf1) + 12|0);
 HEAPF32[$75>>2] = $66;
 $76 = (($transf1) + 16|0);
 HEAPF32[$76>>2] = $68;
 $77 = (($transf1) + 20|0);
 HEAPF32[$77>>2] = $70;
 $78 = (($transf1) + 24|0);
 HEAPF32[$78>>2] = $72;
 $79 = (($transf1) + 28|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = Math_fround(-$60);
 $81 = Math_fround(-$62);
 $82 = Math_fround(-$64);
 $83 = Math_fround($55 - $68);
 $84 = Math_fround($57 - $70);
 $85 = Math_fround($59 - $72);
 $86 = Math_fround($66 * $66);
 $87 = Math_fround($86 + Math_fround(-0.5));
 $88 = Math_fround($87 * $83);
 $89 = Math_fround($87 * $84);
 $90 = Math_fround($87 * $85);
 $91 = Math_fround($85 * $81);
 $92 = Math_fround($84 * $82);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($83 * $82);
 $95 = Math_fround($85 * $80);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($84 * $80);
 $98 = Math_fround($83 * $81);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($66 * $93);
 $101 = Math_fround($66 * $96);
 $102 = Math_fround($66 * $99);
 $103 = Math_fround($88 + $100);
 $104 = Math_fround($89 + $101);
 $105 = Math_fround($90 + $102);
 $106 = Math_fround($83 * $80);
 $107 = Math_fround($84 * $81);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($85 * $82);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($110 * $80);
 $112 = Math_fround($110 * $81);
 $113 = Math_fround($110 * $82);
 $114 = Math_fround($111 + $103);
 $115 = Math_fround($112 + $104);
 $116 = Math_fround($105 + $113);
 $117 = Math_fround($114 * Math_fround(2.0));
 $118 = Math_fround($115 * Math_fround(2.0));
 $119 = Math_fround($116 * Math_fround(2.0));
 $120 = Math_fround($53 * $66);
 $121 = Math_fround($47 * $80);
 $122 = Math_fround($49 * $81);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($51 * $82);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($120 - $125);
 $127 = Math_fround($53 * $80);
 $128 = Math_fround($53 * $81);
 $129 = Math_fround($53 * $82);
 $130 = Math_fround($47 * $66);
 $131 = Math_fround($49 * $66);
 $132 = Math_fround($51 * $66);
 $133 = Math_fround($51 * $81);
 $134 = Math_fround($49 * $82);
 $135 = Math_fround($133 - $134);
 $136 = Math_fround($47 * $82);
 $137 = Math_fround($51 * $80);
 $138 = Math_fround($136 - $137);
 $139 = Math_fround($49 * $80);
 $140 = Math_fround($47 * $81);
 $141 = Math_fround($139 - $140);
 $142 = Math_fround($127 + $130);
 $143 = Math_fround($128 + $131);
 $144 = Math_fround($132 + $129);
 $145 = Math_fround($135 + $142);
 $146 = Math_fround($138 + $143);
 $147 = Math_fround($141 + $144);
 $148 = Math_fround($145 + $145);
 $149 = Math_fround($146 + $146);
 $150 = Math_fround($147 + $147);
 $151 = Math_fround($145 * $148);
 $152 = Math_fround($146 * $149);
 $153 = Math_fround($147 * $150);
 $154 = Math_fround($146 * $148);
 $155 = Math_fround($147 * $148);
 $156 = Math_fround($126 * $148);
 $157 = Math_fround($147 * $149);
 $158 = Math_fround($126 * $149);
 $159 = Math_fround($126 * $150);
 $160 = Math_fround(Math_fround(1.0) - $151);
 $161 = Math_fround(Math_fround(1.0) - $152);
 $162 = Math_fround($161 - $153);
 $163 = Math_fround($154 + $159);
 $164 = Math_fround($155 - $158);
 $165 = Math_fround($154 - $159);
 $166 = Math_fround($160 - $153);
 $167 = Math_fround($157 + $156);
 $168 = Math_fround($155 + $158);
 $169 = Math_fround($157 - $156);
 $170 = Math_fround($160 - $152);
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penetrationDepth>>2] = Math_fround(0.0);
 $171 = Math_fround($21 * Math_fround(0.0));
 $172 = Math_fround($21 * $162);
 $173 = Math_fround($171 * $165);
 $174 = Math_fround($173 + $172);
 $175 = Math_fround($171 * $168);
 $176 = Math_fround($175 + $174);
 $177 = Math_fround($21 * $163);
 $178 = Math_fround($171 * $166);
 $179 = Math_fround($177 + $178);
 $180 = Math_fround($171 * $169);
 $181 = Math_fround($180 + $179);
 $182 = Math_fround($21 * $164);
 $183 = Math_fround($171 * $167);
 $184 = Math_fround($182 + $183);
 $185 = Math_fround($171 * $170);
 $186 = Math_fround($184 + $185);
 $187 = (($capsuleV) + 64|0);
 HEAPF32[$capsuleV>>2] = $117;
 $188 = (($capsuleV) + 4|0);
 HEAPF32[$188>>2] = $118;
 $189 = (($capsuleV) + 8|0);
 HEAPF32[$189>>2] = $119;
 $190 = (($capsuleV) + 12|0);
 HEAPF32[$190>>2] = Math_fround(0.0);
 $191 = (($capsuleV) + 80|0);
 HEAP32[$191>>2] = 4;
 $192 = (($capsuleV) + 16|0);
 $193 = (($capsuleV) + 20|0);
 $194 = (($capsuleV) + 32|0);
 $195 = (($capsuleV) + 36|0);
 $196 = (($capsuleV) + 48|0);
 HEAPF32[$196>>2] = Math_fround(0.0);
 $197 = (($capsuleV) + 52|0);
 ;HEAP32[$197+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$197+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$197+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $198 = (($capsuleV) + 128|0);
 HEAPF32[$198>>2] = $23;
 $199 = (($capsuleV) + 132|0);
 ;HEAP32[$199+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$199+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$199+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $200 = Math_fround($117 + $176);
 $201 = Math_fround($118 + $181);
 $202 = Math_fround($119 + $186);
 $203 = (($capsuleV) + 96|0);
 HEAPF32[$203>>2] = $200;
 $204 = (($capsuleV) + 100|0);
 HEAPF32[$204>>2] = $201;
 $205 = (($capsuleV) + 104|0);
 HEAPF32[$205>>2] = $202;
 $206 = (($capsuleV) + 108|0);
 HEAPF32[$206>>2] = Math_fround(0.0);
 $207 = Math_fround($117 - $176);
 $208 = Math_fround($118 - $181);
 $209 = Math_fround($119 - $186);
 $210 = (($capsuleV) + 112|0);
 HEAPF32[$210>>2] = $207;
 $211 = (($capsuleV) + 116|0);
 HEAPF32[$211>>2] = $208;
 $212 = (($capsuleV) + 120|0);
 HEAPF32[$212>>2] = $209;
 $213 = (($capsuleV) + 124|0);
 HEAPF32[$213>>2] = Math_fround(0.0);
 HEAPF32[$192>>2] = $23;
 ;HEAP32[$193+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$193+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$193+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$194>>2] = $23;
 ;HEAP32[$195+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$195+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$195+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$187+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$187+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$187+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$187+12>>2]=HEAP32[$0+12>>2]|0;
 $214 = Math_fround(HEAPF32[$27>>2]);
 $215 = $214 == Math_fround(1.0);
 if ($215) {
  $216 = Math_fround(HEAPF32[$29>>2]);
  $217 = $216 == Math_fround(1.0);
  if ($217) {
   $218 = Math_fround(HEAPF32[$31>>2]);
   $219 = $218 == Math_fround(1.0);
   $220 = $219;
  } else {
   $220 = 0;
  }
 } else {
  $220 = 0;
 }
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHullV,$220,$zero$sroa$1$i$i$i);
 $221 = (($convexHullV) + 96|0);
 $222 = (($convexHullV) + 144|0);
 $223 = (($0) + 32|0);
 HEAP32[$223>>2] = $transf1;
 $224 = (($0) + 36|0);
 HEAP32[$224>>2] = $221;
 $225 = (($0) + 40|0);
 HEAP32[$225>>2] = $222;
 $226 = (($0) + 44|0);
 $227 = $220&1;
 HEAP8[$226>>0] = $227;
 if ($220) {
  HEAP32[$0>>2] = ((546744 + 8|0));
  $228 = (($0) + 48|0);
  HEAP32[$228>>2] = $convexHullV;
 } else {
  HEAP32[$0>>2] = ((546712 + 8|0));
  $229 = (($0) + 48|0);
  HEAP32[$229>>2] = $convexHullV;
 }
 $230 = (__ZN5physx2Gu10computeMTDERKNS0_8CapsuleVERNS0_13PolygonalDataEPNS0_12SupportLocalERNS_6shdfnd3aos6FloatVERNS9_5Vec3VE($capsuleV,$zero$sroa$1$i$i$i,$0,$penetrationDepth,$normal)|0);
 if (!($230)) {
  STACKTOP = sp;return ($230|0);
 }
 $231 = Math_fround(HEAPF32[$penetrationDepth>>2]);
 $232 = $231 > Math_fround(0.0);
 $233 = $232 ? $231 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $233;
 $234 = Math_fround(HEAPF32[$normal>>2]);
 $235 = (($normal) + 4|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = (($normal) + 8|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 HEAPF32[$mtd>>2] = $234;
 $239 = (($mtd) + 4|0);
 HEAPF32[$239>>2] = $236;
 $240 = (($mtd) + 8|0);
 HEAPF32[$240>>2] = $238;
 STACKTOP = sp;return ($230|0);
}
function __ZN5physx2Gu20computeMTD_BoxConvexERNS_6PxVec3ERfRKNS0_3BoxERKNS_20PxConvexMeshGeometryERKNS_11PxTransformE($mtd,$depth,$box,$convexGeom,$convexPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $box = $box|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$sroa$1$i$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0;
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0);
 var $97 = 0, $98 = 0, $99 = Math_fround(0), $boxV = 0, $buff$i = 0, $convexHullV = 0, $identity$i = 0, $map0$i = 0, $normal = 0, $penetrationDepth = 0, $polyData1$i = 0, $transf0 = 0, $transf1 = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1072|0;
 $$sroa$1$i$i$i = sp + 336|0;
 $zero$sroa$1$i$i$i = sp + 776|0;
 $polyData1$i = sp + 704|0;
 $identity$i = sp + 656|0;
 $map0$i = sp + 592|0;
 $buff$i = sp + 1008|0;
 $zeroV = sp + 576|0;
 $boxV = sp + 416|0;
 $vScale = sp + 320|0;
 $vQuat = sp + 304|0;
 $convexHullV = sp + 96|0;
 $transf0 = sp + 64|0;
 $transf1 = sp + 32|0;
 $normal = sp + 16|0;
 $penetrationDepth = sp;
 $0 = sp + 996|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($$sroa$1$i$i$i,$box);
 $1 = Math_fround(HEAPF32[$$sroa$1$i$i$i>>2]);
 $2 = (($$sroa$1$i$i$i) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($$sroa$1$i$i$i) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($$sroa$1$i$i$i) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($box) + 36|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($box) + 40|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($box) + 44|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($box) + 48|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($box) + 52|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($box) + 56|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($boxV) + 64|0);
 ;HEAP32[$boxV+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$boxV+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$boxV+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$boxV+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $21 = (($boxV) + 80|0);
 HEAP32[$21>>2] = 3;
 $22 = (($boxV) + 16|0);
 $23 = (($boxV) + 20|0);
 ;HEAP32[$23+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $24 = (($boxV) + 32|0);
 $25 = (($boxV) + 36|0);
 $26 = (($boxV) + 48|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($boxV) + 52|0);
 ;HEAP32[$27+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$20+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $28 = (($boxV) + 144|0);
 HEAPF32[$28>>2] = $15;
 $29 = (($boxV) + 148|0);
 HEAPF32[$29>>2] = $17;
 $30 = (($boxV) + 152|0);
 HEAPF32[$30>>2] = $19;
 $31 = (($boxV) + 156|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = !($15 <= $17);
 $$$i26$i$i$i = $32 ? $17 : $15;
 $33 = !($$$i26$i$i$i <= $19);
 $34 = $33 ? $19 : $$$i26$i$i$i;
 $35 = !($15 >= $17);
 $$$i23$i$i$i = $35 ? $17 : $15;
 $36 = !($$$i23$i$i$i >= $19);
 $37 = $36 ? $19 : $$$i23$i$i$i;
 $38 = Math_fround($34 * Math_fround(0.150000005960464477539));
 $39 = Math_fround($37 * Math_fround(0.0299999993294477462769));
 $40 = $38 > $39;
 $$$i12$i$i$i = $40 ? $38 : $39;
 $41 = $34 > $$$i12$i$i$i;
 $$$i$i$i$i = $41 ? $$$i12$i$i$i : $34;
 HEAPF32[$22>>2] = $$$i$i$i$i;
 ;HEAP32[$23+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $42 = Math_fround($34 * Math_fround(0.0500000007450580596924));
 HEAPF32[$24>>2] = $42;
 ;HEAP32[$25+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $43 = (($convexGeom) + 32|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 16|0);
 $46 = (($convexGeom) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($46) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($46) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$vScale>>2] = $47;
 $52 = (($vScale) + 4|0);
 HEAPF32[$52>>2] = $49;
 $53 = (($vScale) + 8|0);
 HEAPF32[$53>>2] = $51;
 $54 = (($vScale) + 12|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($convexGeom) + 16|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($55) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($55) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($55) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 HEAPF32[$vQuat>>2] = $56;
 $63 = (($vQuat) + 4|0);
 HEAPF32[$63>>2] = $58;
 $64 = (($vQuat) + 8|0);
 HEAPF32[$64>>2] = $60;
 $65 = (($vQuat) + 12|0);
 HEAPF32[$65>>2] = $62;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHullV,$45,$zeroV,$vScale,$vQuat);
 $66 = Math_fround(HEAPF32[$convexPose>>2]);
 $67 = (($convexPose) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($convexPose) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($convexPose) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($convexPose) + 16|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($73) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($73) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 HEAPF32[$transf0>>2] = $1;
 $79 = (($transf0) + 4|0);
 HEAPF32[$79>>2] = $3;
 $80 = (($transf0) + 8|0);
 HEAPF32[$80>>2] = $5;
 $81 = (($transf0) + 12|0);
 HEAPF32[$81>>2] = $7;
 $82 = (($transf0) + 16|0);
 HEAPF32[$82>>2] = $9;
 $83 = (($transf0) + 20|0);
 HEAPF32[$83>>2] = $11;
 $84 = (($transf0) + 24|0);
 HEAPF32[$84>>2] = $13;
 $85 = (($transf0) + 28|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 HEAPF32[$transf1>>2] = $66;
 $86 = (($transf1) + 4|0);
 HEAPF32[$86>>2] = $68;
 $87 = (($transf1) + 8|0);
 HEAPF32[$87>>2] = $70;
 $88 = (($transf1) + 12|0);
 HEAPF32[$88>>2] = $72;
 $89 = (($transf1) + 16|0);
 HEAPF32[$89>>2] = $74;
 $90 = (($transf1) + 20|0);
 HEAPF32[$90>>2] = $76;
 $91 = (($transf1) + 24|0);
 HEAPF32[$91>>2] = $78;
 $92 = (($transf1) + 28|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penetrationDepth>>2] = Math_fround(0.0);
 $93 = Math_fround(HEAPF32[$46>>2]);
 $94 = $93 == Math_fround(1.0);
 if ($94) {
  $95 = (($convexGeom) + 8|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = $96 == Math_fround(1.0);
  if ($97) {
   $98 = (($convexGeom) + 12|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $100 = $99 == Math_fround(1.0);
   $107 = $100;
  } else {
   $107 = 0;
  }
 } else {
  $107 = 0;
 }
 $101 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$0>>2] = $101;
 $102 = (($0) + 4|0);
 $103 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$102>>2] = $103;
 $104 = (($0) + 8|0);
 $105 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$104>>2] = $105;
 __ZN5physx2Gu15PCMPolygonalBoxC2ERKNS_6PxVec3E($zero$sroa$1$i$i$i,$0);
 __ZNK5physx2Gu15PCMPolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($zero$sroa$1$i$i$i,$$sroa$1$i$i$i);
 $106 = (($$sroa$1$i$i$i) + 32|0);
 HEAP32[$106>>2] = 554136;
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHullV,$107,$polyData1$i);
 HEAPF32[$identity$i>>2] = Math_fround(1.0);
 $108 = (($identity$i) + 4|0);
 $109 = (($identity$i) + 20|0);
 ;HEAP32[$108+0>>2]=0|0;HEAP32[$108+4>>2]=0|0;HEAP32[$108+8>>2]=0|0;HEAP32[$108+12>>2]=0|0;
 HEAPF32[$109>>2] = Math_fround(1.0);
 $110 = (($identity$i) + 24|0);
 $111 = (($identity$i) + 40|0);
 ;HEAP32[$110+0>>2]=0|0;HEAP32[$110+4>>2]=0|0;HEAP32[$110+8>>2]=0|0;HEAP32[$110+12>>2]=0|0;
 HEAPF32[$111>>2] = Math_fround(1.0);
 $112 = (($identity$i) + 44|0);
 HEAPF32[$112>>2] = Math_fround(0.0);
 $113 = (($map0$i) + 32|0);
 HEAP32[$113>>2] = $transf0;
 $114 = (($map0$i) + 36|0);
 HEAP32[$114>>2] = $identity$i;
 $115 = (($map0$i) + 40|0);
 HEAP32[$115>>2] = $identity$i;
 $116 = (($map0$i) + 44|0);
 HEAP8[$116>>0] = 1;
 HEAP32[$map0$i>>2] = ((546776 + 8|0));
 $117 = (($map0$i) + 48|0);
 HEAP32[$117>>2] = $boxV;
 $118 = (($convexHullV) + 96|0);
 $119 = (($convexHullV) + 144|0);
 $120 = (($buff$i) + 32|0);
 HEAP32[$120>>2] = $transf1;
 $121 = (($buff$i) + 36|0);
 HEAP32[$121>>2] = $118;
 $122 = (($buff$i) + 40|0);
 HEAP32[$122>>2] = $119;
 $123 = (($buff$i) + 44|0);
 $124 = $107&1;
 HEAP8[$123>>0] = $124;
 if ($107) {
  HEAP32[$buff$i>>2] = ((546744 + 8|0));
  $125 = (($buff$i) + 48|0);
  HEAP32[$125>>2] = $convexHullV;
 } else {
  HEAP32[$buff$i>>2] = ((546712 + 8|0));
  $126 = (($buff$i) + 48|0);
  HEAP32[$126>>2] = $convexHullV;
 }
 $127 = (__ZN5physx2Gu10computeMTDERNS0_13PolygonalDataES2_PNS0_12SupportLocalES4_RNS_6shdfnd3aos6FloatVERNS6_5Vec3VE($$sroa$1$i$i$i,$polyData1$i,$map0$i,$buff$i,$penetrationDepth,$normal)|0);
 if (!($127)) {
  STACKTOP = sp;return ($127|0);
 }
 $128 = Math_fround(HEAPF32[$penetrationDepth>>2]);
 $129 = $128 > Math_fround(0.0);
 $130 = $129 ? $128 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $130;
 $131 = Math_fround(HEAPF32[$normal>>2]);
 $132 = (($normal) + 4|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($normal) + 8|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 HEAPF32[$mtd>>2] = $131;
 $136 = (($mtd) + 4|0);
 HEAPF32[$136>>2] = $133;
 $137 = (($mtd) + 8|0);
 HEAPF32[$137>>2] = $135;
 STACKTOP = sp;return ($127|0);
}
function __ZN5physx2Gu23computeMTD_ConvexConvexERNS_6PxVec3ERfRKNS_20PxConvexMeshGeometryERKNS_11PxTransformES6_S9_($mtd,$depth,$convexGeom0,$convexPose0,$convexGeom1,$convexPose1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $convexGeom0 = $convexGeom0|0;
 $convexPose0 = $convexPose0|0;
 $convexGeom1 = $convexGeom1|0;
 $convexPose1 = $convexPose1|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0;
 var $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0);
 var $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $buff0$i = 0, $buff1$i = 0, $convexHullV0 = 0, $convexHullV1 = 0, $normal = 0, $penetrationDepth = 0, $polyData0$i = 0, $polyData1$i = 0, $transf0 = 0, $transf1 = 0, $vQuat0 = 0;
 var $vQuat1 = 0, $vScale0 = 0, $vScale1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 864|0;
 $polyData0$i = sp + 728|0;
 $polyData1$i = sp + 656|0;
 $buff0$i = sp + 592|0;
 $buff1$i = sp + 800|0;
 $zeroV = sp + 576|0;
 $vScale0 = sp + 560|0;
 $vQuat0 = sp + 544|0;
 $convexHullV0 = sp + 336|0;
 $vScale1 = sp + 304|0;
 $vQuat1 = sp + 288|0;
 $convexHullV1 = sp + 80|0;
 $transf0 = sp + 48|0;
 $transf1 = sp + 16|0;
 $normal = sp;
 $penetrationDepth = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $0 = (($convexGeom0) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = (($convexGeom0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($convexGeom0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($convexGeom0) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$vScale0>>2] = $4;
 $9 = (($vScale0) + 4|0);
 HEAPF32[$9>>2] = $6;
 $10 = (($vScale0) + 8|0);
 HEAPF32[$10>>2] = $8;
 $11 = (($vScale0) + 12|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($convexGeom0) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($12) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($12) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$vQuat0>>2] = $13;
 $20 = (($vQuat0) + 4|0);
 HEAPF32[$20>>2] = $15;
 $21 = (($vQuat0) + 8|0);
 HEAPF32[$21>>2] = $17;
 $22 = (($vQuat0) + 12|0);
 HEAPF32[$22>>2] = $19;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHullV0,$2,$zeroV,$vScale0,$vQuat0);
 $23 = (($convexGeom1) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 16|0);
 $26 = (($convexGeom1) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($convexGeom1) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($convexGeom1) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$vScale1>>2] = $27;
 $32 = (($vScale1) + 4|0);
 HEAPF32[$32>>2] = $29;
 $33 = (($vScale1) + 8|0);
 HEAPF32[$33>>2] = $31;
 $34 = (($vScale1) + 12|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($convexGeom1) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($35) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($35) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($35) + 12|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$vQuat1>>2] = $36;
 $43 = (($vQuat1) + 4|0);
 HEAPF32[$43>>2] = $38;
 $44 = (($vQuat1) + 8|0);
 HEAPF32[$44>>2] = $40;
 $45 = (($vQuat1) + 12|0);
 HEAPF32[$45>>2] = $42;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHullV1,$25,$zeroV,$vScale1,$vQuat1);
 $46 = Math_fround(HEAPF32[$convexPose0>>2]);
 $47 = (($convexPose0) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($convexPose0) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($convexPose0) + 12|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($convexPose0) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($53) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($53) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround(HEAPF32[$convexPose1>>2]);
 $60 = (($convexPose1) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($convexPose1) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($convexPose1) + 12|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($convexPose1) + 16|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($66) + 4|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($66) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 HEAPF32[$transf0>>2] = $46;
 $72 = (($transf0) + 4|0);
 HEAPF32[$72>>2] = $48;
 $73 = (($transf0) + 8|0);
 HEAPF32[$73>>2] = $50;
 $74 = (($transf0) + 12|0);
 HEAPF32[$74>>2] = $52;
 $75 = (($transf0) + 16|0);
 HEAPF32[$75>>2] = $54;
 $76 = (($transf0) + 20|0);
 HEAPF32[$76>>2] = $56;
 $77 = (($transf0) + 24|0);
 HEAPF32[$77>>2] = $58;
 $78 = (($transf0) + 28|0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 HEAPF32[$transf1>>2] = $59;
 $79 = (($transf1) + 4|0);
 HEAPF32[$79>>2] = $61;
 $80 = (($transf1) + 8|0);
 HEAPF32[$80>>2] = $63;
 $81 = (($transf1) + 12|0);
 HEAPF32[$81>>2] = $65;
 $82 = (($transf1) + 16|0);
 HEAPF32[$82>>2] = $67;
 $83 = (($transf1) + 20|0);
 HEAPF32[$83>>2] = $69;
 $84 = (($transf1) + 24|0);
 HEAPF32[$84>>2] = $71;
 $85 = (($transf1) + 28|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penetrationDepth>>2] = Math_fround(0.0);
 $86 = Math_fround(HEAPF32[$3>>2]);
 $87 = $86 == Math_fround(1.0);
 if ($87) {
  $88 = Math_fround(HEAPF32[$5>>2]);
  $89 = $88 == Math_fround(1.0);
  if ($89) {
   $90 = Math_fround(HEAPF32[$7>>2]);
   $91 = $90 == Math_fround(1.0);
   $98 = $91;
  } else {
   $98 = 0;
  }
 } else {
  $98 = 0;
 }
 $92 = Math_fround(HEAPF32[$26>>2]);
 $93 = $92 == Math_fround(1.0);
 if ($93) {
  $94 = Math_fround(HEAPF32[$28>>2]);
  $95 = $94 == Math_fround(1.0);
  if ($95) {
   $96 = Math_fround(HEAPF32[$30>>2]);
   $97 = $96 == Math_fround(1.0);
   $99 = $97;
  } else {
   $99 = 0;
  }
 } else {
  $99 = 0;
 }
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHullV0,$98,$polyData0$i);
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHullV1,$99,$polyData1$i);
 $100 = (($convexHullV0) + 96|0);
 $101 = (($convexHullV0) + 144|0);
 $102 = (($buff0$i) + 32|0);
 HEAP32[$102>>2] = $transf0;
 $103 = (($buff0$i) + 36|0);
 HEAP32[$103>>2] = $100;
 $104 = (($buff0$i) + 40|0);
 HEAP32[$104>>2] = $101;
 $105 = (($buff0$i) + 44|0);
 $106 = $98&1;
 HEAP8[$105>>0] = $106;
 if ($98) {
  HEAP32[$buff0$i>>2] = ((546744 + 8|0));
  $107 = (($buff0$i) + 48|0);
  HEAP32[$107>>2] = $convexHullV0;
 } else {
  HEAP32[$buff0$i>>2] = ((546712 + 8|0));
  $108 = (($buff0$i) + 48|0);
  HEAP32[$108>>2] = $convexHullV0;
 }
 $109 = (($convexHullV1) + 96|0);
 $110 = (($convexHullV1) + 144|0);
 $111 = (($buff1$i) + 32|0);
 HEAP32[$111>>2] = $transf1;
 $112 = (($buff1$i) + 36|0);
 HEAP32[$112>>2] = $109;
 $113 = (($buff1$i) + 40|0);
 HEAP32[$113>>2] = $110;
 $114 = (($buff1$i) + 44|0);
 $115 = $99&1;
 HEAP8[$114>>0] = $115;
 if ($99) {
  HEAP32[$buff1$i>>2] = ((546744 + 8|0));
  $116 = (($buff1$i) + 48|0);
  HEAP32[$116>>2] = $convexHullV1;
 } else {
  HEAP32[$buff1$i>>2] = ((546712 + 8|0));
  $117 = (($buff1$i) + 48|0);
  HEAP32[$117>>2] = $convexHullV1;
 }
 $118 = (__ZN5physx2Gu10computeMTDERNS0_13PolygonalDataES2_PNS0_12SupportLocalES4_RNS_6shdfnd3aos6FloatVERNS6_5Vec3VE($polyData0$i,$polyData1$i,$buff0$i,$buff1$i,$penetrationDepth,$normal)|0);
 if (!($118)) {
  STACKTOP = sp;return ($118|0);
 }
 $119 = Math_fround(HEAPF32[$penetrationDepth>>2]);
 $120 = $119 > Math_fround(0.0);
 $121 = $120 ? $119 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $121;
 $122 = Math_fround(HEAPF32[$normal>>2]);
 $123 = (($normal) + 4|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($normal) + 8|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 HEAPF32[$mtd>>2] = $122;
 $127 = (($mtd) + 4|0);
 HEAPF32[$127>>2] = $124;
 $128 = (($mtd) + 8|0);
 HEAPF32[$128>>2] = $126;
 STACKTOP = sp;return ($118|0);
}
function __ZN5physx2Gu19computeMTD_PlaneBoxERNS_6PxVec3ERfRKNS_7PxPlaneERKNS0_3BoxE($mtd,$depth,$plane,$box) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $plane = $plane|0;
 $box = $box|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $14 = Math_fround(0);
 var $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0;
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $pts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $pts = sp;
 $0 = (($box) + 36|0);
 $1 = (($box) + 48|0);
 $2 = (($box) + 12|0);
 $3 = (($box) + 24|0);
 __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($pts,$0,$1,$box,$2,$3);
 $4 = Math_fround(HEAPF32[$pts>>2]);
 $5 = Math_fround(HEAPF32[$plane>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($pts) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($plane) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = Math_fround($6 + $11);
 $13 = (($pts) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($plane) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = Math_fround($12 + $17);
 $19 = (($plane) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 + $18);
 $22 = (($pts) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $5);
 $25 = (($pts) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $10);
 $28 = Math_fround($24 + $27);
 $29 = (($pts) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $16);
 $32 = Math_fround($28 + $31);
 $33 = Math_fround($20 + $32);
 $34 = $21 < $33;
 $35 = $34 ? $21 : $33;
 $36 = (($pts) + 24|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * $5);
 $39 = (($pts) + 28|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($40 * $10);
 $42 = Math_fround($38 + $41);
 $43 = (($pts) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 * $16);
 $46 = Math_fround($42 + $45);
 $47 = Math_fround($20 + $46);
 $48 = $35 < $47;
 $49 = $48 ? $35 : $47;
 $50 = (($pts) + 36|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $5);
 $53 = (($pts) + 40|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 * $10);
 $56 = Math_fround($52 + $55);
 $57 = (($pts) + 44|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 * $16);
 $60 = Math_fround($56 + $59);
 $61 = Math_fround($20 + $60);
 $62 = $49 < $61;
 $63 = $62 ? $49 : $61;
 $64 = (($pts) + 48|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 * $5);
 $67 = (($pts) + 52|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 * $10);
 $70 = Math_fround($66 + $69);
 $71 = (($pts) + 56|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 * $16);
 $74 = Math_fround($70 + $73);
 $75 = Math_fround($20 + $74);
 $76 = $63 < $75;
 $77 = $76 ? $63 : $75;
 $78 = (($pts) + 60|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 * $5);
 $81 = (($pts) + 64|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 * $10);
 $84 = Math_fround($80 + $83);
 $85 = (($pts) + 68|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 * $16);
 $88 = Math_fround($84 + $87);
 $89 = Math_fround($20 + $88);
 $90 = $77 < $89;
 $91 = $90 ? $77 : $89;
 $92 = (($pts) + 72|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($93 * $5);
 $95 = (($pts) + 76|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($96 * $10);
 $98 = Math_fround($94 + $97);
 $99 = (($pts) + 80|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 * $16);
 $102 = Math_fround($98 + $101);
 $103 = Math_fround($20 + $102);
 $104 = $91 < $103;
 $105 = $104 ? $91 : $103;
 $106 = (($pts) + 84|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($107 * $5);
 $109 = (($pts) + 88|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($110 * $10);
 $112 = Math_fround($108 + $111);
 $113 = (($pts) + 92|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($114 * $16);
 $116 = Math_fround($112 + $115);
 $117 = Math_fround($20 + $116);
 $118 = $105 < $117;
 $119 = $118 ? $105 : $117;
 $120 = $119 > Math_fround(0.0);
 if ($120) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $121 = Math_fround(HEAPF32[$plane>>2]);
 $122 = Math_fround(-$121);
 $123 = Math_fround(HEAPF32[$9>>2]);
 $124 = Math_fround(-$123);
 $125 = Math_fround(HEAPF32[$15>>2]);
 $126 = Math_fround(-$125);
 HEAPF32[$mtd>>2] = $122;
 $127 = (($mtd) + 4|0);
 HEAPF32[$127>>2] = $124;
 $128 = (($mtd) + 8|0);
 HEAPF32[$128>>2] = $126;
 $129 = Math_fround(-$119);
 $130 = $119 < Math_fround(-0.0);
 $131 = $130 ? $129 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $131;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22computeMTD_PlaneConvexERNS_6PxVec3ERfRKNS_7PxPlaneERKNS_20PxConvexMeshGeometryERKNS_11PxTransformE($mtd,$depth,$plane,$convexGeom,$convexPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $plane = $plane|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $dmin$0$lcssa = Math_fround(0), $dmin$07 = Math_fround(0), $exitcond = 0, $i$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($convexGeom) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 54|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = (($1) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 55|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = (($5) + (($8*20)|0)|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * Math_fround(2.0));
 $12 = ((($5) + (($8*20)|0)|0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * Math_fround(2.0));
 $15 = ((($5) + (($8*20)|0)|0) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * Math_fround(2.0));
 $18 = (($convexPose) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $19);
 $21 = Math_fround($20 + Math_fround(-0.5));
 $22 = Math_fround(HEAPF32[$convexPose>>2]);
 $23 = Math_fround($11 * $22);
 $24 = (($convexPose) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($convexPose) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($17 * $29);
 $31 = Math_fround($27 + $30);
 $32 = Math_fround($11 * $21);
 $33 = Math_fround($17 * $25);
 $34 = Math_fround($14 * $29);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($19 * $35);
 $37 = Math_fround($32 + $36);
 $38 = Math_fround($22 * $31);
 $39 = Math_fround($38 + $37);
 $40 = Math_fround($14 * $21);
 $41 = Math_fround($11 * $29);
 $42 = Math_fround($17 * $22);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($19 * $43);
 $45 = Math_fround($40 + $44);
 $46 = Math_fround($25 * $31);
 $47 = Math_fround($46 + $45);
 $48 = Math_fround($17 * $21);
 $49 = Math_fround($14 * $22);
 $50 = Math_fround($11 * $25);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($19 * $51);
 $53 = Math_fround($48 + $52);
 $54 = Math_fround($29 * $31);
 $55 = Math_fround($53 + $54);
 $56 = (($convexPose) + 16|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 + $39);
 $59 = (($convexPose) + 20|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 + $47);
 $62 = (($convexPose) + 24|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 + $55);
 $65 = Math_fround(HEAPF32[$plane>>2]);
 $66 = Math_fround($65 * $58);
 $67 = (($plane) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 * $61);
 $70 = Math_fround($66 + $69);
 $71 = (($plane) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($64 * $72);
 $74 = Math_fround($73 + $70);
 $75 = (($plane) + 12|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($76 + $74);
 $78 = ($3&255)>(1);
 if ($78) {
  $79 = $3&255;
  $dmin$07 = $77;$i$08 = 1;
  while(1) {
   $80 = (($9) + (($i$08*12)|0)|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   $82 = Math_fround($81 * Math_fround(2.0));
   $83 = ((($9) + (($i$08*12)|0)|0) + 4|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   $85 = Math_fround($84 * Math_fround(2.0));
   $86 = ((($9) + (($i$08*12)|0)|0) + 8|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = Math_fround($87 * Math_fround(2.0));
   $89 = Math_fround($82 * $22);
   $90 = Math_fround($85 * $25);
   $91 = Math_fround($89 + $90);
   $92 = Math_fround($88 * $29);
   $93 = Math_fround($91 + $92);
   $94 = Math_fround($82 * $21);
   $95 = Math_fround($88 * $25);
   $96 = Math_fround($85 * $29);
   $97 = Math_fround($95 - $96);
   $98 = Math_fround($19 * $97);
   $99 = Math_fround($94 + $98);
   $100 = Math_fround($22 * $93);
   $101 = Math_fround($100 + $99);
   $102 = Math_fround($85 * $21);
   $103 = Math_fround($82 * $29);
   $104 = Math_fround($88 * $22);
   $105 = Math_fround($103 - $104);
   $106 = Math_fround($19 * $105);
   $107 = Math_fround($102 + $106);
   $108 = Math_fround($25 * $93);
   $109 = Math_fround($108 + $107);
   $110 = Math_fround($88 * $21);
   $111 = Math_fround($85 * $22);
   $112 = Math_fround($82 * $25);
   $113 = Math_fround($111 - $112);
   $114 = Math_fround($19 * $113);
   $115 = Math_fround($110 + $114);
   $116 = Math_fround($29 * $93);
   $117 = Math_fround($115 + $116);
   $118 = Math_fround($57 + $101);
   $119 = Math_fround($60 + $109);
   $120 = Math_fround($63 + $117);
   $121 = Math_fround($65 * $118);
   $122 = Math_fround($68 * $119);
   $123 = Math_fround($121 + $122);
   $124 = Math_fround($120 * $72);
   $125 = Math_fround($124 + $123);
   $126 = Math_fround($76 + $125);
   $127 = $dmin$07 < $126;
   $128 = $127 ? $dmin$07 : $126;
   $129 = (($i$08) + 1)|0;
   $exitcond = ($129|0)==($79|0);
   if ($exitcond) {
    $dmin$0$lcssa = $128;
    break;
   } else {
    $dmin$07 = $128;$i$08 = $129;
   }
  }
 } else {
  $dmin$0$lcssa = $77;
 }
 $130 = $dmin$0$lcssa > Math_fround(0.0);
 if ($130) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $131 = Math_fround(-$65);
 $132 = Math_fround(-$68);
 $133 = Math_fround(-$72);
 HEAPF32[$mtd>>2] = $131;
 $134 = (($mtd) + 4|0);
 HEAPF32[$134>>2] = $132;
 $135 = (($mtd) + 8|0);
 HEAPF32[$135>>2] = $133;
 $136 = Math_fround(-$dmin$0$lcssa);
 $137 = $dmin$0$lcssa < Math_fround(-0.0);
 $138 = $137 ? $136 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $138;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu21computeMTD_SphereMeshERNS_6PxVec3ERfRKNS0_6SphereERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformE($mtd,$depth,$sphere,$meshGeom,$meshPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $sphere = $sphere|0;
 $meshGeom = $meshGeom|0;
 $meshPose = $meshPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = Math_fround(0);
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cache = 0, $contactBuffer = 0, $shape0 = 0, $shape1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4272|0;
 $shape0 = sp + 4216|0;
 $0 = sp + 4176|0;
 $shape1 = sp + 4112|0;
 $cache = sp + 4168|0;
 $contactBuffer = sp;
 $1 = sp + 4184|0;
 $2 = sp + 4212|0;
 HEAP32[$shape0>>2] = (-1);
 $3 = (($sphere) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAP32[$0>>2] = 0;
 $5 = (($0) + 4|0);
 HEAPF32[$5>>2] = $4;
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape0,$0);
 HEAP32[$shape1>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape1,$meshGeom);
 HEAP32[$cache>>2] = 0;
 $6 = (($contactBuffer) + 4096|0);
 HEAP32[$6>>2] = 0;
 $7 = (($contactBuffer) + 4100|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $8 = (($1) + 4|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($1) + 8|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($1) + 12|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($1) + 16|0);
 $12 = Math_fround(HEAPF32[$sphere>>2]);
 HEAPF32[$11>>2] = $12;
 $13 = (($1) + 20|0);
 $14 = (($sphere) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$13>>2] = $15;
 $16 = (($1) + 24|0);
 $17 = (($sphere) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $18;
 HEAPF32[$2>>2] = Math_fround(0.0);
 $19 = (__ZN5physx2Gu17contactSphereMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$1,$meshPose,$2,$cache,$contactBuffer)|0);
 if (!($19)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$6>>2]|0;
 $21 = (__ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$20,$contactBuffer)|0);
 if (!($21)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = HEAP32[$6>>2]|0;
 $23 = ($22|0)!=(0);
 $$0 = $23;
 STACKTOP = sp;return ($$0|0);
}
function __ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$nbContacts,$contacts) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $nbContacts = $nbContacts|0;
 $contacts = $contacts|0;
 var $$0 = 0, $$idx = 0, $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0);
 var $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $exitcond = 0, $i$020 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nbContacts|0)==(0);
 if ($0) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $10 = Math_fround(0.0);$13 = Math_fround(0.0);$16 = Math_fround(0.0);$19 = Math_fround(0.0);$22 = Math_fround(0.0);$7 = Math_fround(0.0);$i$020 = 0;
 }
 while(1) {
  $1 = ((($contacts) + ($i$020<<6)|0) + 12|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $$idx = (($contacts) + ($i$020<<6)|0);
  $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
  $$idx1 = ((($contacts) + ($i$020<<6)|0) + 4|0);
  $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
  $$idx2 = ((($contacts) + ($i$020<<6)|0) + 8|0);
  $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
  $3 = Math_fround($2 * $$idx$val);
  $4 = Math_fround($2 * $$idx1$val);
  $5 = Math_fround($2 * $$idx2$val);
  $6 = $7 < $3;
  $8 = $6 ? $7 : $3;
  $9 = $10 < $4;
  $11 = $9 ? $10 : $4;
  $12 = $13 < $5;
  $14 = $12 ? $13 : $5;
  $15 = $16 > $3;
  $17 = $15 ? $16 : $3;
  $18 = $19 > $4;
  $20 = $18 ? $19 : $4;
  $21 = $22 > $5;
  $23 = $21 ? $22 : $5;
  $24 = (($i$020) + 1)|0;
  $exitcond = ($24|0)==($nbContacts|0);
  if ($exitcond) {
   break;
  } else {
   $10 = $11;$13 = $14;$16 = $17;$19 = $20;$22 = $23;$7 = $8;$i$020 = $24;
  }
 }
 $25 = $8 == Math_fround(0.0);
 $26 = $25 ? $17 : $8;
 $27 = $11 == Math_fround(0.0);
 $28 = $27 ? $20 : $11;
 $29 = $14 == Math_fround(0.0);
 $30 = $29 ? $23 : $14;
 $31 = $17 == Math_fround(0.0);
 $32 = $31 ? $8 : $17;
 $33 = $20 == Math_fround(0.0);
 $34 = $33 ? $11 : $20;
 $35 = $23 == Math_fround(0.0);
 $36 = $35 ? $14 : $23;
 $37 = Math_fround($26 + $32);
 $38 = Math_fround($28 + $34);
 $39 = Math_fround($30 + $36);
 $40 = Math_fround($37 * Math_fround(0.5));
 $41 = Math_fround($38 * Math_fround(0.5));
 $42 = Math_fround($39 * Math_fround(0.5));
 $43 = Math_fround($40 * $40);
 $44 = Math_fround($41 * $41);
 $45 = Math_fround($44 + $43);
 $46 = Math_fround($42 * $42);
 $47 = Math_fround($46 + $45);
 $48 = $47 < Math_fround(1.00000001335143196002E-10);
 if ($48) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = $47 > Math_fround(0.0);
 $50 = (Math_fround(Math_sqrt((Math_fround($47)))));
 if ($49) {
  $51 = Math_fround(Math_fround(1.0) / $50);
  $52 = Math_fround($40 * $51);
  $53 = Math_fround($41 * $51);
  $54 = Math_fround($42 * $51);
  $56 = $52;$58 = $53;$60 = $54;
 } else {
  $56 = Math_fround(0.0);$58 = Math_fround(0.0);$60 = Math_fround(0.0);
 }
 $55 = Math_fround(-$56);
 $57 = Math_fround(-$58);
 $59 = Math_fround(-$60);
 HEAPF32[$mtd>>2] = $55;
 $61 = (($mtd) + 4|0);
 HEAPF32[$61>>2] = $57;
 $62 = (($mtd) + 8|0);
 HEAPF32[$62>>2] = $59;
 HEAPF32[$depth>>2] = $50;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22computeMTD_CapsuleMeshERNS_6PxVec3ERfRKNS0_7CapsuleERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformE($mtd,$depth,$capsule,$meshGeom,$meshPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $capsule = $capsule|0;
 $meshGeom = $meshGeom|0;
 $meshPose = $meshPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cache = 0, $capsuleTransform = 0, $contactBuffer = 0, $halfHeight = 0;
 var $shape0 = 0, $shape1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4288|0;
 $halfHeight = sp + 4276|0;
 $capsuleTransform = sp + 4244|0;
 $shape0 = sp + 4112|0;
 $0 = sp + 4168|0;
 $shape1 = sp + 4184|0;
 $cache = sp + 4240|0;
 $contactBuffer = sp;
 $1 = sp + 4272|0;
 $2 = (($capsule) + 12|0);
 __ZN5physx22PxTransformFromSegmentERKNS_6PxVec3ES2_Pf($capsuleTransform,$capsule,$2,$halfHeight);
 HEAP32[$shape0>>2] = (-1);
 $3 = (($capsule) + 24|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$halfHeight>>2]);
 HEAP32[$0>>2] = 2;
 $6 = (($0) + 4|0);
 HEAPF32[$6>>2] = $4;
 $7 = (($0) + 8|0);
 HEAPF32[$7>>2] = $5;
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape0,$0);
 HEAP32[$shape1>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape1,$meshGeom);
 HEAP32[$cache>>2] = 0;
 $8 = (($contactBuffer) + 4096|0);
 HEAP32[$8>>2] = 0;
 $9 = (($contactBuffer) + 4100|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $10 = (__ZN5physx2Gu18contactCapsuleMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$capsuleTransform,$meshPose,$1,$cache,$contactBuffer)|0);
 if (!($10)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$8>>2]|0;
 $12 = (__ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$11,$contactBuffer)|0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[$8>>2]|0;
 $14 = ($13|0)!=(0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18computeMTD_BoxMeshERNS_6PxVec3ERfRKNS0_3BoxERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformE($mtd,$depth,$box,$meshGeom,$meshPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $box = $box|0;
 $meshGeom = $meshGeom|0;
 $meshPose = $meshPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $boxPose = 0;
 var $cache = 0, $contactBuffer = 0, $shape0 = 0, $shape1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4304|0;
 $boxPose = sp + 4268|0;
 $0 = sp + 4248|0;
 $shape0 = sp + 4112|0;
 $1 = sp + 4168|0;
 $shape1 = sp + 4184|0;
 $cache = sp + 4240|0;
 $contactBuffer = sp;
 $2 = sp + 4264|0;
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$box);
 $3 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$boxPose>>2] = $3;
 $4 = (($boxPose) + 4|0);
 $5 = (($0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($boxPose) + 8|0);
 $8 = (($0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($boxPose) + 12|0);
 $11 = (($0) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$10>>2] = $12;
 $13 = (($boxPose) + 16|0);
 $14 = (($box) + 36|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$13>>2] = $15;
 $16 = (($boxPose) + 20|0);
 $17 = (($box) + 40|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $18;
 $19 = (($boxPose) + 24|0);
 $20 = (($box) + 44|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 HEAP32[$shape0>>2] = (-1);
 $22 = (($box) + 48|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($box) + 52|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($box) + 56|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAP32[$1>>2] = 3;
 $28 = (($1) + 4|0);
 HEAPF32[$28>>2] = $23;
 $29 = (($1) + 8|0);
 HEAPF32[$29>>2] = $25;
 $30 = (($1) + 12|0);
 HEAPF32[$30>>2] = $27;
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape0,$1);
 HEAP32[$shape1>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape1,$meshGeom);
 HEAP32[$cache>>2] = 0;
 $31 = (($contactBuffer) + 4096|0);
 HEAP32[$31>>2] = 0;
 $32 = (($contactBuffer) + 4100|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $33 = (__ZN5physx2Gu14contactBoxMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$boxPose,$meshPose,$2,$cache,$contactBuffer)|0);
 if (!($33)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = HEAP32[$31>>2]|0;
 $35 = (__ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$34,$contactBuffer)|0);
 if (!($35)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = HEAP32[$31>>2]|0;
 $37 = ($36|0)!=(0);
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu28computeMTD_SphereHeightFieldERNS_6PxVec3ERfRKNS0_6SphereERKNS_21PxHeightFieldGeometryERKNS_11PxTransformE($mtd,$depth,$sphere,$meshGeom,$meshPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $sphere = $sphere|0;
 $meshGeom = $meshGeom|0;
 $meshPose = $meshPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cache = 0, $contactBuffer = 0, $shape0 = 0, $shape1 = 0, $spherePose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4272|0;
 $shape0 = sp + 4216|0;
 $0 = sp + 4176|0;
 $shape1 = sp + 4112|0;
 $cache = sp + 4168|0;
 $contactBuffer = sp;
 $spherePose = sp + 4184|0;
 $1 = sp + 4212|0;
 HEAP32[$shape0>>2] = (-1);
 $2 = (($sphere) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAP32[$0>>2] = 0;
 $4 = (($0) + 4|0);
 HEAPF32[$4>>2] = $3;
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape0,$0);
 HEAP32[$shape1>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape1,$meshGeom);
 HEAP32[$cache>>2] = 0;
 $5 = (($contactBuffer) + 4096|0);
 HEAP32[$5>>2] = 0;
 $6 = (($contactBuffer) + 4100|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 HEAPF32[$spherePose>>2] = Math_fround(0.0);
 $7 = (($spherePose) + 4|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($spherePose) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($spherePose) + 12|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($spherePose) + 16|0);
 $11 = Math_fround(HEAPF32[$sphere>>2]);
 HEAPF32[$10>>2] = $11;
 $12 = (($spherePose) + 20|0);
 $13 = (($sphere) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$12>>2] = $14;
 $15 = (($spherePose) + 24|0);
 $16 = (($sphere) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$15>>2] = $17;
 HEAPF32[$1>>2] = Math_fround(0.0);
 $18 = (__ZN5physx2Gu24contactSphereHeightFieldERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$spherePose,$meshPose,$1,$cache,$contactBuffer)|0);
 if (!($18)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = HEAP32[$5>>2]|0;
 $20 = (__ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$19,$contactBuffer)|0);
 if (!($20)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = HEAP32[$5>>2]|0;
 $22 = ($21|0)!=(0);
 $$0 = $22;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29computeMTD_CapsuleHeightFieldERNS_6PxVec3ERfRKNS0_7CapsuleERKNS_21PxHeightFieldGeometryERKNS_11PxTransformE($mtd,$depth,$capsule,$meshGeom,$meshPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $capsule = $capsule|0;
 $meshGeom = $meshGeom|0;
 $meshPose = $meshPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cache = 0, $capsuleTransform = 0, $contactBuffer = 0, $halfHeight = 0;
 var $shape0 = 0, $shape1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4288|0;
 $halfHeight = sp + 4276|0;
 $capsuleTransform = sp + 4244|0;
 $shape0 = sp + 4112|0;
 $0 = sp + 4168|0;
 $shape1 = sp + 4184|0;
 $cache = sp + 4240|0;
 $contactBuffer = sp;
 $1 = sp + 4272|0;
 $2 = (($capsule) + 12|0);
 __ZN5physx22PxTransformFromSegmentERKNS_6PxVec3ES2_Pf($capsuleTransform,$capsule,$2,$halfHeight);
 HEAP32[$shape0>>2] = (-1);
 $3 = (($capsule) + 24|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$halfHeight>>2]);
 HEAP32[$0>>2] = 2;
 $6 = (($0) + 4|0);
 HEAPF32[$6>>2] = $4;
 $7 = (($0) + 8|0);
 HEAPF32[$7>>2] = $5;
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape0,$0);
 HEAP32[$shape1>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape1,$meshGeom);
 HEAP32[$cache>>2] = 0;
 $8 = (($contactBuffer) + 4096|0);
 HEAP32[$8>>2] = 0;
 $9 = (($contactBuffer) + 4100|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $10 = (__ZN5physx2Gu25contactCapsuleHeightfieldERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$capsuleTransform,$meshPose,$1,$cache,$contactBuffer)|0);
 if (!($10)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$8>>2]|0;
 $12 = (__ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$11,$contactBuffer)|0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[$8>>2]|0;
 $14 = ($13|0)!=(0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu25computeMTD_BoxHeightFieldERNS_6PxVec3ERfRKNS0_3BoxERKNS_21PxHeightFieldGeometryERKNS_11PxTransformE($mtd,$depth,$box,$meshGeom,$meshPose) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $box = $box|0;
 $meshGeom = $meshGeom|0;
 $meshPose = $meshPose|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $boxPose = 0;
 var $cache = 0, $contactBuffer = 0, $shape0 = 0, $shape1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4304|0;
 $boxPose = sp + 4268|0;
 $0 = sp + 4248|0;
 $shape0 = sp + 4112|0;
 $1 = sp + 4168|0;
 $shape1 = sp + 4184|0;
 $cache = sp + 4240|0;
 $contactBuffer = sp;
 $2 = sp + 4264|0;
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$box);
 $3 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$boxPose>>2] = $3;
 $4 = (($boxPose) + 4|0);
 $5 = (($0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($boxPose) + 8|0);
 $8 = (($0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($boxPose) + 12|0);
 $11 = (($0) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$10>>2] = $12;
 $13 = (($boxPose) + 16|0);
 $14 = (($box) + 36|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$13>>2] = $15;
 $16 = (($boxPose) + 20|0);
 $17 = (($box) + 40|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $18;
 $19 = (($boxPose) + 24|0);
 $20 = (($box) + 44|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 HEAP32[$shape0>>2] = (-1);
 $22 = (($box) + 48|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($box) + 52|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($box) + 56|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAP32[$1>>2] = 3;
 $28 = (($1) + 4|0);
 HEAPF32[$28>>2] = $23;
 $29 = (($1) + 8|0);
 HEAPF32[$29>>2] = $25;
 $30 = (($1) + 12|0);
 HEAPF32[$30>>2] = $27;
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape0,$1);
 HEAP32[$shape1>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape1,$meshGeom);
 HEAP32[$cache>>2] = 0;
 $31 = (($contactBuffer) + 4096|0);
 HEAP32[$31>>2] = 0;
 $32 = (($contactBuffer) + 4100|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $33 = (__ZN5physx2Gu21contactBoxHeightfieldERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$boxPose,$meshPose,$2,$cache,$contactBuffer)|0);
 if (!($33)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = HEAP32[$31>>2]|0;
 $35 = (__ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$34,$contactBuffer)|0);
 if (!($35)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = HEAP32[$31>>2]|0;
 $37 = ($36|0)!=(0);
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function __ZL28GeomMTDCallback_SphereSphereRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $$0$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0;
 var $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($geom0) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($transform0) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($transform0) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($transform0) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($geom1) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($transform1) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($transform1) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 - $11);
 $17 = Math_fround($5 - $13);
 $18 = Math_fround($7 - $15);
 $19 = Math_fround($16 * $16);
 $20 = Math_fround($17 * $17);
 $21 = Math_fround($19 + $20);
 $22 = Math_fround($18 * $18);
 $23 = Math_fround($21 + $22);
 $24 = Math_fround($1 + $9);
 $25 = Math_fround($24 * $24);
 $26 = $23 > $25;
 if ($26) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $27 = (Math_fround(Math_sqrt((Math_fround($23)))));
 $28 = $23 < Math_fround(9.99999997475242707878E-7);
 if ($28) {
  HEAPF32[$mtd>>2] = Math_fround(1.0);
  $29 = (($mtd) + 4|0);
  HEAPF32[$29>>2] = Math_fround(0.0);
  $30 = (($mtd) + 8|0);
  HEAPF32[$30>>2] = Math_fround(0.0);
 } else {
  $31 = Math_fround(Math_fround(1.0) / $27);
  $32 = Math_fround($16 * $31);
  $33 = Math_fround($17 * $31);
  $34 = Math_fround($18 * $31);
  HEAPF32[$mtd>>2] = $32;
  $35 = (($mtd) + 4|0);
  HEAPF32[$35>>2] = $33;
  $36 = (($mtd) + 8|0);
  HEAPF32[$36>>2] = $34;
 }
 $37 = Math_fround($24 - $27);
 $38 = $37 > Math_fround(0.0);
 $39 = $38 ? $37 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $39;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZL27GeomMTDCallback_SpherePlaneRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($geom0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($transform0) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($transform0) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform0) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($0,$transform1);
 $9 = Math_fround(HEAPF32[$0>>2]);
 $10 = Math_fround($4 * $9);
 $11 = (($0) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($6 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($0) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($8 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($0) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 + $18);
 $22 = $21 > $2;
 if ($22) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAPF32[$mtd>>2] = $9;
 $23 = (($mtd) + 4|0);
 HEAPF32[$23>>2] = $12;
 $24 = (($mtd) + 8|0);
 HEAPF32[$24>>2] = $16;
 $25 = Math_fround($2 - $21);
 $26 = $25 > Math_fround(0.0);
 $27 = $26 ? $25 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $27;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZL29GeomMTDCallback_SphereCapsuleRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $capsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $capsule = sp + 16|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$transform1>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($transform1) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = Math_fround($4 * $5);
 $7 = Math_fround($6 + Math_fround(-1.0));
 $8 = Math_fround($1 * $2);
 $9 = Math_fround($8 + $7);
 $10 = (($transform1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $5);
 $13 = (($transform1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($2 * $14);
 $16 = Math_fround($12 + $15);
 $17 = Math_fround($5 * $14);
 $18 = Math_fround($2 * $11);
 $19 = Math_fround($18 - $17);
 $20 = (($geom1) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $9);
 $23 = Math_fround($21 * $16);
 $24 = Math_fround($21 * $19);
 $25 = (($transform1) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + $22);
 $28 = (($transform1) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 + $23);
 $31 = (($transform1) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 + $32);
 HEAPF32[$capsule>>2] = $27;
 $34 = (($capsule) + 4|0);
 HEAPF32[$34>>2] = $30;
 $35 = (($capsule) + 8|0);
 HEAPF32[$35>>2] = $33;
 $36 = Math_fround($26 - $22);
 $37 = Math_fround($29 - $23);
 $38 = Math_fround($32 - $24);
 $39 = (($capsule) + 12|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($capsule) + 16|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($capsule) + 20|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($geom1) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($capsule) + 24|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($geom0) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($transform0) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$0>>2] = $48;
 $49 = (($0) + 4|0);
 $50 = (($transform0) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$49>>2] = $51;
 $52 = (($0) + 8|0);
 $53 = (($transform0) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 HEAPF32[$52>>2] = $54;
 $55 = (($0) + 12|0);
 HEAPF32[$55>>2] = $46;
 $56 = (__ZN5physx2Gu24computeMTD_SphereCapsuleERNS_6PxVec3ERfRKNS0_6SphereERKNS0_7CapsuleE($mtd,$depth,$0,$capsule)|0);
 STACKTOP = sp;return ($56|0);
}
function __ZL25GeomMTDCallback_SphereBoxRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $obb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $obb = sp + 16|0;
 $0 = sp;
 $1 = (($geom1) + 4|0);
 $2 = (($transform1) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($obb) + 36|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($transform1) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($obb) + 40|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($transform1) + 24|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($obb) + 44|0);
 HEAPF32[$10>>2] = $9;
 $11 = Math_fround(HEAPF32[$1>>2]);
 $12 = (($obb) + 48|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($geom1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($obb) + 52|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($geom1) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($obb) + 56|0);
 HEAPF32[$18>>2] = $17;
 $19 = Math_fround(HEAPF32[$transform1>>2]);
 $20 = (($transform1) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transform1) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($transform1) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($19 + $19);
 $27 = Math_fround($21 + $21);
 $28 = Math_fround($23 + $23);
 $29 = Math_fround($19 * $26);
 $30 = Math_fround($21 * $27);
 $31 = Math_fround($23 * $28);
 $32 = Math_fround($26 * $21);
 $33 = Math_fround($26 * $23);
 $34 = Math_fround($26 * $25);
 $35 = Math_fround($27 * $23);
 $36 = Math_fround($27 * $25);
 $37 = Math_fround($28 * $25);
 $38 = Math_fround(Math_fround(1.0) - $30);
 $39 = Math_fround($38 - $31);
 $40 = Math_fround($32 + $37);
 $41 = Math_fround($33 - $36);
 $42 = Math_fround($32 - $37);
 $43 = Math_fround(Math_fround(1.0) - $29);
 $44 = Math_fround($43 - $31);
 $45 = Math_fround($35 + $34);
 $46 = Math_fround($33 + $36);
 $47 = Math_fround($35 - $34);
 $48 = Math_fround($43 - $30);
 HEAPF32[$obb>>2] = $39;
 $49 = (($obb) + 4|0);
 HEAPF32[$49>>2] = $40;
 $50 = (($obb) + 8|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($obb) + 12|0);
 HEAPF32[$51>>2] = $42;
 $52 = (($obb) + 16|0);
 HEAPF32[$52>>2] = $44;
 $53 = (($obb) + 20|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($obb) + 24|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($obb) + 28|0);
 HEAPF32[$55>>2] = $47;
 $56 = (($obb) + 32|0);
 HEAPF32[$56>>2] = $48;
 $57 = (($geom0) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($transform0) + 16|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 HEAPF32[$0>>2] = $60;
 $61 = (($0) + 4|0);
 $62 = (($transform0) + 20|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 HEAPF32[$61>>2] = $63;
 $64 = (($0) + 8|0);
 $65 = (($transform0) + 24|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 HEAPF32[$64>>2] = $66;
 $67 = (($0) + 12|0);
 HEAPF32[$67>>2] = $58;
 $68 = (__ZN5physx2Gu20computeMTD_SphereBoxERNS_6PxVec3ERfRKNS0_6SphereERKNS0_3BoxE($mtd,$depth,$0,$obb)|0);
 STACKTOP = sp;return ($68|0);
}
function __ZL28GeomMTDCallback_SphereConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($geom0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($transform0) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$0>>2] = $4;
 $5 = (($0) + 4|0);
 $6 = (($transform0) + 20|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 $8 = (($0) + 8|0);
 $9 = (($transform0) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $10;
 $11 = (($0) + 12|0);
 HEAPF32[$11>>2] = $2;
 $12 = (__ZN5physx2Gu23computeMTD_SphereConvexERNS_6PxVec3ERfRKNS0_6SphereERKNS_20PxConvexMeshGeometryERKNS_11PxTransformE($mtd,$depth,$0,$geom1,$transform1)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZL26GeomMTDCallback_SphereMeshRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($geom0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($transform0) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$0>>2] = $4;
 $5 = (($0) + 4|0);
 $6 = (($transform0) + 20|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$5>>2] = $7;
 $8 = (($0) + 8|0);
 $9 = (($transform0) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $10;
 $11 = (($0) + 12|0);
 HEAPF32[$11>>2] = $2;
 $12 = (__ZN5physx2Gu21computeMTD_SphereMeshERNS_6PxVec3ERfRKNS0_6SphereERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformE($mtd,$depth,$0,$geom1,$transform1)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZL33GeomMTDCallback_SphereHeightFieldRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $sphere = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $sphere = sp;
 $0 = (($geom0) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($transform0) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$sphere>>2] = $3;
 $4 = (($sphere) + 4|0);
 $5 = (($transform0) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($sphere) + 8|0);
 $8 = (($transform0) + 24|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($sphere) + 12|0);
 HEAPF32[$10>>2] = $1;
 $11 = (__ZN5physx2Gu28computeMTD_SphereHeightFieldERNS_6PxVec3ERfRKNS0_6SphereERKNS_21PxHeightFieldGeometryERKNS_11PxTransformE($mtd,$depth,$sphere,$geom1,$transform1)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZL28GeomMTDCallback_NotSupportedRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZL28GeomMTDCallback_PlaneCapsuleRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $$0$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$transform1>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($transform1) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = Math_fround($4 * $5);
 $7 = Math_fround($6 + Math_fround(-1.0));
 $8 = Math_fround($1 * $2);
 $9 = Math_fround($8 + $7);
 $10 = (($transform1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $5);
 $13 = (($transform1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($2 * $14);
 $16 = Math_fround($12 + $15);
 $17 = Math_fround($5 * $14);
 $18 = Math_fround($2 * $11);
 $19 = Math_fround($18 - $17);
 $20 = (($geom1) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $9);
 $23 = Math_fround($21 * $16);
 $24 = Math_fround($21 * $19);
 $25 = (($transform1) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + $22);
 $28 = (($transform1) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 + $23);
 $31 = (($transform1) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 + $32);
 $34 = Math_fround($26 - $22);
 $35 = Math_fround($29 - $23);
 $36 = Math_fround($32 - $24);
 $37 = (($geom1) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($0,$transform0);
 $39 = Math_fround(HEAPF32[$0>>2]);
 $40 = Math_fround($27 * $39);
 $41 = (($0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($30 * $42);
 $44 = Math_fround($40 + $43);
 $45 = (($0) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($33 * $46);
 $48 = Math_fround($44 + $47);
 $49 = (($0) + 12|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($50 + $48);
 $52 = Math_fround($34 * $39);
 $53 = Math_fround($35 * $42);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($36 * $46);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($50 + $56);
 $58 = $51 < $57;
 $59 = $58 ? $51 : $57;
 $60 = Math_fround($59 - $38);
 $61 = $60 > Math_fround(0.0);
 if ($61) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $62 = Math_fround(-$39);
 $63 = Math_fround(-$42);
 $64 = Math_fround(-$46);
 HEAPF32[$mtd>>2] = $62;
 $65 = (($mtd) + 4|0);
 HEAPF32[$65>>2] = $63;
 $66 = (($mtd) + 8|0);
 HEAPF32[$66>>2] = $64;
 $67 = Math_fround(-$60);
 $68 = $60 < Math_fround(-0.0);
 $69 = $68 ? $67 : Math_fround(0.0);
 HEAPF32[$depth>>2] = $69;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZL24GeomMTDCallback_PlaneBoxRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $obb = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $obb = sp + 16|0;
 $0 = sp;
 $1 = (($geom1) + 4|0);
 $2 = (($transform1) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($obb) + 36|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($transform1) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($obb) + 40|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($transform1) + 24|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($obb) + 44|0);
 HEAPF32[$10>>2] = $9;
 $11 = Math_fround(HEAPF32[$1>>2]);
 $12 = (($obb) + 48|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($geom1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($obb) + 52|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($geom1) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($obb) + 56|0);
 HEAPF32[$18>>2] = $17;
 $19 = Math_fround(HEAPF32[$transform1>>2]);
 $20 = (($transform1) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transform1) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($transform1) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($19 + $19);
 $27 = Math_fround($21 + $21);
 $28 = Math_fround($23 + $23);
 $29 = Math_fround($19 * $26);
 $30 = Math_fround($21 * $27);
 $31 = Math_fround($23 * $28);
 $32 = Math_fround($26 * $21);
 $33 = Math_fround($26 * $23);
 $34 = Math_fround($26 * $25);
 $35 = Math_fround($27 * $23);
 $36 = Math_fround($27 * $25);
 $37 = Math_fround($28 * $25);
 $38 = Math_fround(Math_fround(1.0) - $30);
 $39 = Math_fround($38 - $31);
 $40 = Math_fround($32 + $37);
 $41 = Math_fround($33 - $36);
 $42 = Math_fround($32 - $37);
 $43 = Math_fround(Math_fround(1.0) - $29);
 $44 = Math_fround($43 - $31);
 $45 = Math_fround($35 + $34);
 $46 = Math_fround($33 + $36);
 $47 = Math_fround($35 - $34);
 $48 = Math_fround($43 - $30);
 HEAPF32[$obb>>2] = $39;
 $49 = (($obb) + 4|0);
 HEAPF32[$49>>2] = $40;
 $50 = (($obb) + 8|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($obb) + 12|0);
 HEAPF32[$51>>2] = $42;
 $52 = (($obb) + 16|0);
 HEAPF32[$52>>2] = $44;
 $53 = (($obb) + 20|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($obb) + 24|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($obb) + 28|0);
 HEAPF32[$55>>2] = $47;
 $56 = (($obb) + 32|0);
 HEAPF32[$56>>2] = $48;
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($0,$transform0);
 $57 = (__ZN5physx2Gu19computeMTD_PlaneBoxERNS_6PxVec3ERfRKNS_7PxPlaneERKNS0_3BoxE($mtd,$depth,$0,$obb)|0);
 STACKTOP = sp;return ($57|0);
}
function __ZL27GeomMTDCallback_PlaneConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($0,$transform0);
 $1 = (__ZN5physx2Gu22computeMTD_PlaneConvexERNS_6PxVec3ERfRKNS_7PxPlaneERKNS_20PxConvexMeshGeometryERKNS_11PxTransformE($mtd,$depth,$0,$geom1,$transform1)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL30GeomMTDCallback_CapsuleCapsuleRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $9 = 0, $capsule0 = 0, $capsule1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $capsule0 = sp + 28|0;
 $capsule1 = sp;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($transform0) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($transform0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($geom0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = Math_fround($20 * $15);
 $23 = Math_fround($20 * $18);
 $24 = (($transform0) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $21);
 $27 = (($transform0) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + $22);
 $30 = (($transform0) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($23 + $31);
 HEAPF32[$capsule0>>2] = $26;
 $33 = (($capsule0) + 4|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($capsule0) + 8|0);
 HEAPF32[$34>>2] = $32;
 $35 = Math_fround($25 - $21);
 $36 = Math_fround($28 - $22);
 $37 = Math_fround($31 - $23);
 $38 = (($capsule0) + 12|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($capsule0) + 16|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($capsule0) + 20|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($geom0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($capsule0) + 24|0);
 HEAPF32[$43>>2] = $42;
 $44 = Math_fround(HEAPF32[$transform1>>2]);
 $45 = Math_fround($44 * Math_fround(2.0));
 $46 = (($transform1) + 12|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 * Math_fround(2.0));
 $49 = Math_fround($47 * $48);
 $50 = Math_fround($49 + Math_fround(-1.0));
 $51 = Math_fround($44 * $45);
 $52 = Math_fround($51 + $50);
 $53 = (($transform1) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 * $48);
 $56 = (($transform1) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($45 * $57);
 $59 = Math_fround($55 + $58);
 $60 = Math_fround($48 * $57);
 $61 = Math_fround($45 * $54);
 $62 = Math_fround($61 - $60);
 $63 = (($geom1) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 * $52);
 $66 = Math_fround($64 * $59);
 $67 = Math_fround($64 * $62);
 $68 = (($transform1) + 16|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $65);
 $71 = (($transform1) + 20|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 + $66);
 $74 = (($transform1) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($67 + $75);
 HEAPF32[$capsule1>>2] = $70;
 $77 = (($capsule1) + 4|0);
 HEAPF32[$77>>2] = $73;
 $78 = (($capsule1) + 8|0);
 HEAPF32[$78>>2] = $76;
 $79 = Math_fround($69 - $65);
 $80 = Math_fround($72 - $66);
 $81 = Math_fround($75 - $67);
 $82 = (($capsule1) + 12|0);
 HEAPF32[$82>>2] = $79;
 $83 = (($capsule1) + 16|0);
 HEAPF32[$83>>2] = $80;
 $84 = (($capsule1) + 20|0);
 HEAPF32[$84>>2] = $81;
 $85 = (($geom1) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($capsule1) + 24|0);
 HEAPF32[$87>>2] = $86;
 $88 = (__ZN5physx2Gu25computeMTD_CapsuleCapsuleERNS_6PxVec3ERfRKNS0_7CapsuleES6_($mtd,$depth,$capsule0,$capsule1)|0);
 STACKTOP = sp;return ($88|0);
}
function __ZL26GeomMTDCallback_CapsuleBoxRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $capsule = 0, $obb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $capsule = sp + 60|0;
 $obb = sp;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($transform0) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($transform0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($geom0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = Math_fround($20 * $15);
 $23 = Math_fround($20 * $18);
 $24 = (($transform0) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $21);
 $27 = (($transform0) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + $22);
 $30 = (($transform0) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($23 + $31);
 HEAPF32[$capsule>>2] = $26;
 $33 = (($capsule) + 4|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($capsule) + 8|0);
 HEAPF32[$34>>2] = $32;
 $35 = Math_fround($25 - $21);
 $36 = Math_fround($28 - $22);
 $37 = Math_fround($31 - $23);
 $38 = (($capsule) + 12|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($capsule) + 16|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($capsule) + 20|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($geom0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($capsule) + 24|0);
 HEAPF32[$43>>2] = $42;
 $44 = (($geom1) + 4|0);
 $45 = (($transform1) + 16|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($obb) + 36|0);
 HEAPF32[$47>>2] = $46;
 $48 = (($transform1) + 20|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($obb) + 40|0);
 HEAPF32[$50>>2] = $49;
 $51 = (($transform1) + 24|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($obb) + 44|0);
 HEAPF32[$53>>2] = $52;
 $54 = Math_fround(HEAPF32[$44>>2]);
 $55 = (($obb) + 48|0);
 HEAPF32[$55>>2] = $54;
 $56 = (($geom1) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($obb) + 52|0);
 HEAPF32[$58>>2] = $57;
 $59 = (($geom1) + 12|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($obb) + 56|0);
 HEAPF32[$61>>2] = $60;
 $62 = Math_fround(HEAPF32[$transform1>>2]);
 $63 = (($transform1) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($transform1) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($transform1) + 12|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($62 + $62);
 $70 = Math_fround($64 + $64);
 $71 = Math_fround($66 + $66);
 $72 = Math_fround($62 * $69);
 $73 = Math_fround($64 * $70);
 $74 = Math_fround($66 * $71);
 $75 = Math_fround($69 * $64);
 $76 = Math_fround($69 * $66);
 $77 = Math_fround($69 * $68);
 $78 = Math_fround($70 * $66);
 $79 = Math_fround($70 * $68);
 $80 = Math_fround($71 * $68);
 $81 = Math_fround(Math_fround(1.0) - $73);
 $82 = Math_fround($81 - $74);
 $83 = Math_fround($75 + $80);
 $84 = Math_fround($76 - $79);
 $85 = Math_fround($75 - $80);
 $86 = Math_fround(Math_fround(1.0) - $72);
 $87 = Math_fround($86 - $74);
 $88 = Math_fround($78 + $77);
 $89 = Math_fround($76 + $79);
 $90 = Math_fround($78 - $77);
 $91 = Math_fround($86 - $73);
 HEAPF32[$obb>>2] = $82;
 $92 = (($obb) + 4|0);
 HEAPF32[$92>>2] = $83;
 $93 = (($obb) + 8|0);
 HEAPF32[$93>>2] = $84;
 $94 = (($obb) + 12|0);
 HEAPF32[$94>>2] = $85;
 $95 = (($obb) + 16|0);
 HEAPF32[$95>>2] = $87;
 $96 = (($obb) + 20|0);
 HEAPF32[$96>>2] = $88;
 $97 = (($obb) + 24|0);
 HEAPF32[$97>>2] = $89;
 $98 = (($obb) + 28|0);
 HEAPF32[$98>>2] = $90;
 $99 = (($obb) + 32|0);
 HEAPF32[$99>>2] = $91;
 $100 = (__ZN5physx2Gu21computeMTD_CapsuleBoxERNS_6PxVec3ERfRKNS0_7CapsuleERKNS0_3BoxE($mtd,$depth,$capsule,$obb)|0);
 STACKTOP = sp;return ($100|0);
}
function __ZL29GeomMTDCallback_CapsuleConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $capsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $capsule = sp;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($transform0) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($transform0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($geom0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = Math_fround($20 * $15);
 $23 = Math_fround($20 * $18);
 $24 = (($transform0) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $21);
 $27 = (($transform0) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + $22);
 $30 = (($transform0) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($23 + $31);
 HEAPF32[$capsule>>2] = $26;
 $33 = (($capsule) + 4|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($capsule) + 8|0);
 HEAPF32[$34>>2] = $32;
 $35 = Math_fround($25 - $21);
 $36 = Math_fround($28 - $22);
 $37 = Math_fround($31 - $23);
 $38 = (($capsule) + 12|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($capsule) + 16|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($capsule) + 20|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($geom0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($capsule) + 24|0);
 HEAPF32[$43>>2] = $42;
 $44 = (__ZN5physx2Gu24computeMTD_CapsuleConvexERNS_6PxVec3ERfRKNS0_7CapsuleERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES9_($mtd,$depth,$capsule,$transform0,$geom1,$transform1)|0);
 STACKTOP = sp;return ($44|0);
}
function __ZL27GeomMTDCallback_CapsuleMeshRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $capsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $capsule = sp;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($transform0) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($transform0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($geom0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = Math_fround($20 * $15);
 $23 = Math_fround($20 * $18);
 $24 = (($transform0) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $21);
 $27 = (($transform0) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + $22);
 $30 = (($transform0) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($23 + $31);
 HEAPF32[$capsule>>2] = $26;
 $33 = (($capsule) + 4|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($capsule) + 8|0);
 HEAPF32[$34>>2] = $32;
 $35 = Math_fround($25 - $21);
 $36 = Math_fround($28 - $22);
 $37 = Math_fround($31 - $23);
 $38 = (($capsule) + 12|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($capsule) + 16|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($capsule) + 20|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($geom0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($capsule) + 24|0);
 HEAPF32[$43>>2] = $42;
 $44 = (__ZN5physx2Gu22computeMTD_CapsuleMeshERNS_6PxVec3ERfRKNS0_7CapsuleERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformE($mtd,$depth,$capsule,$geom1,$transform1)|0);
 STACKTOP = sp;return ($44|0);
}
function __ZL34GeomMTDCallback_CapsuleHeightFieldRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $capsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $capsule = sp;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($transform0) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($transform0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($geom0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = Math_fround($20 * $15);
 $23 = Math_fround($20 * $18);
 $24 = (($transform0) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $21);
 $27 = (($transform0) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + $22);
 $30 = (($transform0) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($23 + $31);
 HEAPF32[$capsule>>2] = $26;
 $33 = (($capsule) + 4|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($capsule) + 8|0);
 HEAPF32[$34>>2] = $32;
 $35 = Math_fround($25 - $21);
 $36 = Math_fround($28 - $22);
 $37 = Math_fround($31 - $23);
 $38 = (($capsule) + 12|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($capsule) + 16|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($capsule) + 20|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($geom0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($capsule) + 24|0);
 HEAPF32[$43>>2] = $42;
 $44 = (__ZN5physx2Gu29computeMTD_CapsuleHeightFieldERNS_6PxVec3ERfRKNS0_7CapsuleERKNS_21PxHeightFieldGeometryERKNS_11PxTransformE($mtd,$depth,$capsule,$geom1,$transform1)|0);
 STACKTOP = sp;return ($44|0);
}
function __ZL22GeomMTDCallback_BoxBoxRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0;
 var $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $obb0 = 0, $obb1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $obb0 = sp + 60|0;
 $obb1 = sp;
 $0 = (($geom0) + 4|0);
 $1 = (($transform0) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($obb0) + 36|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($transform0) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($obb0) + 40|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($transform0) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($obb0) + 44|0);
 HEAPF32[$9>>2] = $8;
 $10 = Math_fround(HEAPF32[$0>>2]);
 $11 = (($obb0) + 48|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($geom0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($obb0) + 52|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($geom0) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($obb0) + 56|0);
 HEAPF32[$17>>2] = $16;
 $18 = Math_fround(HEAPF32[$transform0>>2]);
 $19 = (($transform0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($18 + $18);
 $26 = Math_fround($20 + $20);
 $27 = Math_fround($22 + $22);
 $28 = Math_fround($18 * $25);
 $29 = Math_fround($20 * $26);
 $30 = Math_fround($22 * $27);
 $31 = Math_fround($25 * $20);
 $32 = Math_fround($25 * $22);
 $33 = Math_fround($25 * $24);
 $34 = Math_fround($26 * $22);
 $35 = Math_fround($26 * $24);
 $36 = Math_fround($27 * $24);
 $37 = Math_fround(Math_fround(1.0) - $29);
 $38 = Math_fround($37 - $30);
 $39 = Math_fround($31 + $36);
 $40 = Math_fround($32 - $35);
 $41 = Math_fround($31 - $36);
 $42 = Math_fround(Math_fround(1.0) - $28);
 $43 = Math_fround($42 - $30);
 $44 = Math_fround($34 + $33);
 $45 = Math_fround($32 + $35);
 $46 = Math_fround($34 - $33);
 $47 = Math_fround($42 - $29);
 HEAPF32[$obb0>>2] = $38;
 $48 = (($obb0) + 4|0);
 HEAPF32[$48>>2] = $39;
 $49 = (($obb0) + 8|0);
 HEAPF32[$49>>2] = $40;
 $50 = (($obb0) + 12|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($obb0) + 16|0);
 HEAPF32[$51>>2] = $43;
 $52 = (($obb0) + 20|0);
 HEAPF32[$52>>2] = $44;
 $53 = (($obb0) + 24|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($obb0) + 28|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($obb0) + 32|0);
 HEAPF32[$55>>2] = $47;
 $56 = (($geom1) + 4|0);
 $57 = (($transform1) + 16|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($obb1) + 36|0);
 HEAPF32[$59>>2] = $58;
 $60 = (($transform1) + 20|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($obb1) + 40|0);
 HEAPF32[$62>>2] = $61;
 $63 = (($transform1) + 24|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($obb1) + 44|0);
 HEAPF32[$65>>2] = $64;
 $66 = Math_fround(HEAPF32[$56>>2]);
 $67 = (($obb1) + 48|0);
 HEAPF32[$67>>2] = $66;
 $68 = (($geom1) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($obb1) + 52|0);
 HEAPF32[$70>>2] = $69;
 $71 = (($geom1) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($obb1) + 56|0);
 HEAPF32[$73>>2] = $72;
 $74 = Math_fround(HEAPF32[$transform1>>2]);
 $75 = (($transform1) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($transform1) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($transform1) + 12|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($74 + $74);
 $82 = Math_fround($76 + $76);
 $83 = Math_fround($78 + $78);
 $84 = Math_fround($74 * $81);
 $85 = Math_fround($76 * $82);
 $86 = Math_fround($78 * $83);
 $87 = Math_fround($81 * $76);
 $88 = Math_fround($81 * $78);
 $89 = Math_fround($81 * $80);
 $90 = Math_fround($82 * $78);
 $91 = Math_fround($82 * $80);
 $92 = Math_fround($83 * $80);
 $93 = Math_fround(Math_fround(1.0) - $85);
 $94 = Math_fround($93 - $86);
 $95 = Math_fround($87 + $92);
 $96 = Math_fround($88 - $91);
 $97 = Math_fround($87 - $92);
 $98 = Math_fround(Math_fround(1.0) - $84);
 $99 = Math_fround($98 - $86);
 $100 = Math_fround($90 + $89);
 $101 = Math_fround($88 + $91);
 $102 = Math_fround($90 - $89);
 $103 = Math_fround($98 - $85);
 HEAPF32[$obb1>>2] = $94;
 $104 = (($obb1) + 4|0);
 HEAPF32[$104>>2] = $95;
 $105 = (($obb1) + 8|0);
 HEAPF32[$105>>2] = $96;
 $106 = (($obb1) + 12|0);
 HEAPF32[$106>>2] = $97;
 $107 = (($obb1) + 16|0);
 HEAPF32[$107>>2] = $99;
 $108 = (($obb1) + 20|0);
 HEAPF32[$108>>2] = $100;
 $109 = (($obb1) + 24|0);
 HEAPF32[$109>>2] = $101;
 $110 = (($obb1) + 28|0);
 HEAPF32[$110>>2] = $102;
 $111 = (($obb1) + 32|0);
 HEAPF32[$111>>2] = $103;
 $112 = (__ZN5physx2Gu17computeMTD_BoxBoxERNS_6PxVec3ERfRKNS0_3BoxES6_($mtd,$depth,$obb0,$obb1)|0);
 STACKTOP = sp;return ($112|0);
}
function __ZL25GeomMTDCallback_BoxConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $obb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $obb = sp;
 $0 = (($geom0) + 4|0);
 $1 = (($transform0) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($obb) + 36|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($transform0) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($obb) + 40|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($transform0) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($obb) + 44|0);
 HEAPF32[$9>>2] = $8;
 $10 = Math_fround(HEAPF32[$0>>2]);
 $11 = (($obb) + 48|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($geom0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($obb) + 52|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($geom0) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($obb) + 56|0);
 HEAPF32[$17>>2] = $16;
 $18 = Math_fround(HEAPF32[$transform0>>2]);
 $19 = (($transform0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($18 + $18);
 $26 = Math_fround($20 + $20);
 $27 = Math_fround($22 + $22);
 $28 = Math_fround($18 * $25);
 $29 = Math_fround($20 * $26);
 $30 = Math_fround($22 * $27);
 $31 = Math_fround($25 * $20);
 $32 = Math_fround($25 * $22);
 $33 = Math_fround($25 * $24);
 $34 = Math_fround($26 * $22);
 $35 = Math_fround($26 * $24);
 $36 = Math_fround($27 * $24);
 $37 = Math_fround(Math_fround(1.0) - $29);
 $38 = Math_fround($37 - $30);
 $39 = Math_fround($31 + $36);
 $40 = Math_fround($32 - $35);
 $41 = Math_fround($31 - $36);
 $42 = Math_fround(Math_fround(1.0) - $28);
 $43 = Math_fround($42 - $30);
 $44 = Math_fround($34 + $33);
 $45 = Math_fround($32 + $35);
 $46 = Math_fround($34 - $33);
 $47 = Math_fround($42 - $29);
 HEAPF32[$obb>>2] = $38;
 $48 = (($obb) + 4|0);
 HEAPF32[$48>>2] = $39;
 $49 = (($obb) + 8|0);
 HEAPF32[$49>>2] = $40;
 $50 = (($obb) + 12|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($obb) + 16|0);
 HEAPF32[$51>>2] = $43;
 $52 = (($obb) + 20|0);
 HEAPF32[$52>>2] = $44;
 $53 = (($obb) + 24|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($obb) + 28|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($obb) + 32|0);
 HEAPF32[$55>>2] = $47;
 $56 = (__ZN5physx2Gu20computeMTD_BoxConvexERNS_6PxVec3ERfRKNS0_3BoxERKNS_20PxConvexMeshGeometryERKNS_11PxTransformE($mtd,$depth,$obb,$geom1,$transform1)|0);
 STACKTOP = sp;return ($56|0);
}
function __ZL23GeomMTDCallback_BoxMeshRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $obb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $obb = sp;
 $0 = (($geom0) + 4|0);
 $1 = (($transform0) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($obb) + 36|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($transform0) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($obb) + 40|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($transform0) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($obb) + 44|0);
 HEAPF32[$9>>2] = $8;
 $10 = Math_fround(HEAPF32[$0>>2]);
 $11 = (($obb) + 48|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($geom0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($obb) + 52|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($geom0) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($obb) + 56|0);
 HEAPF32[$17>>2] = $16;
 $18 = Math_fround(HEAPF32[$transform0>>2]);
 $19 = (($transform0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($18 + $18);
 $26 = Math_fround($20 + $20);
 $27 = Math_fround($22 + $22);
 $28 = Math_fround($18 * $25);
 $29 = Math_fround($20 * $26);
 $30 = Math_fround($22 * $27);
 $31 = Math_fround($25 * $20);
 $32 = Math_fround($25 * $22);
 $33 = Math_fround($25 * $24);
 $34 = Math_fround($26 * $22);
 $35 = Math_fround($26 * $24);
 $36 = Math_fround($27 * $24);
 $37 = Math_fround(Math_fround(1.0) - $29);
 $38 = Math_fround($37 - $30);
 $39 = Math_fround($31 + $36);
 $40 = Math_fround($32 - $35);
 $41 = Math_fround($31 - $36);
 $42 = Math_fround(Math_fround(1.0) - $28);
 $43 = Math_fround($42 - $30);
 $44 = Math_fround($34 + $33);
 $45 = Math_fround($32 + $35);
 $46 = Math_fround($34 - $33);
 $47 = Math_fround($42 - $29);
 HEAPF32[$obb>>2] = $38;
 $48 = (($obb) + 4|0);
 HEAPF32[$48>>2] = $39;
 $49 = (($obb) + 8|0);
 HEAPF32[$49>>2] = $40;
 $50 = (($obb) + 12|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($obb) + 16|0);
 HEAPF32[$51>>2] = $43;
 $52 = (($obb) + 20|0);
 HEAPF32[$52>>2] = $44;
 $53 = (($obb) + 24|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($obb) + 28|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($obb) + 32|0);
 HEAPF32[$55>>2] = $47;
 $56 = (__ZN5physx2Gu18computeMTD_BoxMeshERNS_6PxVec3ERfRKNS0_3BoxERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformE($mtd,$depth,$obb,$geom1,$transform1)|0);
 STACKTOP = sp;return ($56|0);
}
function __ZL30GeomMTDCallback_BoxHeightFieldRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $obb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $obb = sp;
 $0 = (($geom0) + 4|0);
 $1 = (($transform0) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($obb) + 36|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($transform0) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($obb) + 40|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($transform0) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($obb) + 44|0);
 HEAPF32[$9>>2] = $8;
 $10 = Math_fround(HEAPF32[$0>>2]);
 $11 = (($obb) + 48|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($geom0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($obb) + 52|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($geom0) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($obb) + 56|0);
 HEAPF32[$17>>2] = $16;
 $18 = Math_fround(HEAPF32[$transform0>>2]);
 $19 = (($transform0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($18 + $18);
 $26 = Math_fround($20 + $20);
 $27 = Math_fround($22 + $22);
 $28 = Math_fround($18 * $25);
 $29 = Math_fround($20 * $26);
 $30 = Math_fround($22 * $27);
 $31 = Math_fround($25 * $20);
 $32 = Math_fround($25 * $22);
 $33 = Math_fround($25 * $24);
 $34 = Math_fround($26 * $22);
 $35 = Math_fround($26 * $24);
 $36 = Math_fround($27 * $24);
 $37 = Math_fround(Math_fround(1.0) - $29);
 $38 = Math_fround($37 - $30);
 $39 = Math_fround($31 + $36);
 $40 = Math_fround($32 - $35);
 $41 = Math_fround($31 - $36);
 $42 = Math_fround(Math_fround(1.0) - $28);
 $43 = Math_fround($42 - $30);
 $44 = Math_fround($34 + $33);
 $45 = Math_fround($32 + $35);
 $46 = Math_fround($34 - $33);
 $47 = Math_fround($42 - $29);
 HEAPF32[$obb>>2] = $38;
 $48 = (($obb) + 4|0);
 HEAPF32[$48>>2] = $39;
 $49 = (($obb) + 8|0);
 HEAPF32[$49>>2] = $40;
 $50 = (($obb) + 12|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($obb) + 16|0);
 HEAPF32[$51>>2] = $43;
 $52 = (($obb) + 20|0);
 HEAPF32[$52>>2] = $44;
 $53 = (($obb) + 24|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($obb) + 28|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($obb) + 32|0);
 HEAPF32[$55>>2] = $47;
 $56 = (__ZN5physx2Gu25computeMTD_BoxHeightFieldERNS_6PxVec3ERfRKNS0_3BoxERKNS_21PxHeightFieldGeometryERKNS_11PxTransformE($mtd,$depth,$obb,$geom1,$transform1)|0);
 STACKTOP = sp;return ($56|0);
}
function __ZL28GeomMTDCallback_ConvexConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu23computeMTD_ConvexConvexERNS_6PxVec3ERfRKNS_20PxConvexMeshGeometryERKNS_11PxTransformES6_S9_($mtd,$depth,$geom0,$transform0,$geom1,$transform1)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL26GeomMTDCallback_ConvexMeshRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $cache$i = 0, $contactBuffer$i = 0, $shape0$i = 0, $shape1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4240|0;
 $shape0$i = sp + 4184|0;
 $shape1$i = sp + 4120|0;
 $cache$i = sp + 4112|0;
 $contactBuffer$i = sp;
 $0 = sp + 4176|0;
 HEAP32[$shape0$i>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape0$i,$geom0);
 HEAP32[$shape1$i>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape1$i,$geom1);
 HEAP32[$cache$i>>2] = 0;
 $1 = (($contactBuffer$i) + 4096|0);
 HEAP32[$1>>2] = 0;
 $2 = (($contactBuffer$i) + 4100|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $3 = (__ZN5physx2Gu17contactConvexMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0$i,$shape1$i,$transform0,$transform1,$0,$cache$i,$contactBuffer$i)|0);
 if (!($3)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $4 = HEAP32[$1>>2]|0;
 $5 = (__ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$4,$contactBuffer$i)|0);
 if (!($5)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)!=(0);
 $$0$i = $7;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZL33GeomMTDCallback_ConvexHeightFieldRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_($mtd,$depth,$geom0,$transform0,$geom1,$transform1) {
 $mtd = $mtd|0;
 $depth = $depth|0;
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $cache$i = 0, $contactBuffer$i = 0, $shape0$i = 0, $shape1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4240|0;
 $shape0$i = sp + 4184|0;
 $shape1$i = sp + 4120|0;
 $cache$i = sp + 4112|0;
 $contactBuffer$i = sp;
 $0 = sp + 4176|0;
 HEAP32[$shape0$i>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape0$i,$geom0);
 HEAP32[$shape1$i>>2] = (-1);
 __ZN5physx2Gu13GeometryUnion3setERKNS_10PxGeometryE($shape1$i,$geom1);
 HEAP32[$cache$i>>2] = 0;
 $1 = (($contactBuffer$i) + 4096|0);
 HEAP32[$1>>2] = 0;
 $2 = (($contactBuffer$i) + 4100|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $3 = (__ZN5physx2Gu24contactConvexHeightfieldERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0$i,$shape1$i,$transform0,$transform1,$0,$cache$i,$contactBuffer$i)|0);
 if (!($3)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $4 = HEAP32[$1>>2]|0;
 $5 = (__ZL15processContactsRN5physx6PxVec3ERfjPKNS_2Gu12ContactPointE($mtd,$depth,$4,$contactBuffer$i)|0);
 if (!($5)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)!=(0);
 $$0$i = $7;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5physx2Gu16SupportLocalImplINS0_11ConvexHullVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16SupportLocalImplINS0_11ConvexHullVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($agg$result,$1,$dir);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERNS5_6FloatVESA_($this,$dir,$min,$max) {
 $this = $this|0;
 $dir = $dir|0;
 $min = $min|0;
 $max = $max|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZNK5physx2Gu11ConvexHullV19supportVertexMinMaxERKNS_6shdfnd3aos5Vec3VERNS3_6FloatVES8_($1,$dir,$min,$max);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_11ConvexHullVEE13populateVertsEPKhjPKNS_6PxVec3EPNS_6shdfnd3aos5Vec3VE($this,$inds,$numInds,$originalVerts,$verts) {
 $this = $this|0;
 $inds = $inds|0;
 $numInds = $numInds|0;
 $originalVerts = $originalVerts|0;
 $verts = $verts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$010$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($numInds|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 96|0);
 $4 = (($1) + 112|0);
 $5 = (($1) + 128|0);
 $6 = (($1) + 100|0);
 $7 = (($1) + 116|0);
 $8 = (($1) + 132|0);
 $9 = (($1) + 104|0);
 $10 = (($1) + 120|0);
 $11 = (($1) + 136|0);
 $i$010$i = 0;
 while(1) {
  $12 = (($inds) + ($i$010$i)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = (($originalVerts) + (($14*12)|0)|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = ((($originalVerts) + (($14*12)|0)|0) + 4|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = ((($originalVerts) + (($14*12)|0)|0) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround(HEAPF32[$3>>2]);
  $22 = Math_fround($16 * $21);
  $23 = Math_fround(HEAPF32[$4>>2]);
  $24 = Math_fround($18 * $23);
  $25 = Math_fround($22 + $24);
  $26 = Math_fround(HEAPF32[$5>>2]);
  $27 = Math_fround($20 * $26);
  $28 = Math_fround($25 + $27);
  $29 = Math_fround(HEAPF32[$6>>2]);
  $30 = Math_fround($16 * $29);
  $31 = Math_fround(HEAPF32[$7>>2]);
  $32 = Math_fround($18 * $31);
  $33 = Math_fround($30 + $32);
  $34 = Math_fround(HEAPF32[$8>>2]);
  $35 = Math_fround($20 * $34);
  $36 = Math_fround($33 + $35);
  $37 = Math_fround(HEAPF32[$9>>2]);
  $38 = Math_fround($16 * $37);
  $39 = Math_fround(HEAPF32[$10>>2]);
  $40 = Math_fround($18 * $39);
  $41 = Math_fround($38 + $40);
  $42 = Math_fround(HEAPF32[$11>>2]);
  $43 = Math_fround($20 * $42);
  $44 = Math_fround($41 + $43);
  $45 = (($verts) + ($i$010$i<<4)|0);
  HEAPF32[$45>>2] = $28;
  $46 = ((($verts) + ($i$010$i<<4)|0) + 4|0);
  HEAPF32[$46>>2] = $36;
  $47 = ((($verts) + ($i$010$i<<4)|0) + 8|0);
  HEAPF32[$47>>2] = $44;
  $48 = ((($verts) + ($i$010$i<<4)|0) + 12|0);
  HEAPF32[$48>>2] = Math_fround(0.0);
  $49 = (($i$010$i) + 1)|0;
  $exitcond$i = ($49|0)==($numInds|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$010$i = $49;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu11ConvexHullV19supportVertexMinMaxERKNS_6shdfnd3aos5Vec3VERNS3_6FloatVES8_($this,$_dir,$min,$max) {
 $this = $this|0;
 $_dir = $_dir|0;
 $min = $min|0;
 $max = $max|0;
 var $$sroa$1 = 0, $$sroa$117 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0);
 var $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0;
 var $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $dir = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $dir = sp + 16|0;
 $0 = sp;
 $$sroa$117 = sp + 44|0;
 $$sroa$1 = sp + 32|0;
 $1 = (($this) + 196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZNK5physx2Gu11ConvexHullV22BruteForceSearchMinMaxERKNS_6shdfnd3aos5Vec3VERNS3_6FloatVES8_($this,$_dir,$min,$max);
  STACKTOP = sp;return;
 } else {
  $4 = Math_fround(HEAPF32[$_dir>>2]);
  $5 = (($_dir) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($_dir) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($this) + 96|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround($4 * $10);
  $12 = (($this) + 100|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($6 * $13);
  $15 = Math_fround($11 + $14);
  $16 = (($this) + 104|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($8 * $17);
  $19 = Math_fround($15 + $18);
  $20 = (($this) + 112|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($4 * $21);
  $23 = (($this) + 116|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($6 * $24);
  $26 = Math_fround($22 + $25);
  $27 = (($this) + 120|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround($8 * $28);
  $30 = Math_fround($26 + $29);
  $31 = (($this) + 128|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($4 * $32);
  $34 = (($this) + 132|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($6 * $35);
  $37 = Math_fround($33 + $36);
  $38 = (($this) + 136|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($8 * $39);
  $41 = Math_fround($37 + $40);
  HEAPF32[$dir>>2] = $19;
  $42 = (($dir) + 4|0);
  HEAPF32[$42>>2] = $30;
  $43 = (($dir) + 8|0);
  HEAPF32[$43>>2] = $41;
  $44 = (($dir) + 12|0);
  HEAPF32[$44>>2] = Math_fround(0.0);
  $45 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$dir)|0);
  $46 = Math_fround(HEAPF32[$dir>>2]);
  $47 = Math_fround(HEAPF32[$42>>2]);
  $48 = Math_fround(HEAPF32[$43>>2]);
  $49 = Math_fround(-$46);
  $50 = Math_fround(-$47);
  $51 = Math_fround(-$48);
  HEAPF32[$0>>2] = $49;
  $52 = (($0) + 4|0);
  HEAPF32[$52>>2] = $50;
  $53 = (($0) + 8|0);
  HEAPF32[$53>>2] = $51;
  $54 = (($0) + 12|0);
  HEAPF32[$54>>2] = Math_fround(0.0);
  $55 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$0)|0);
  $56 = (($this) + 200|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($57) + (($45*12)|0)|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($57) + (($45*12)|0)|0) + 4|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = ((($57) + (($45*12)|0)|0) + 8|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround(HEAPF32[$9>>2]);
  $65 = Math_fround($59 * $64);
  $66 = Math_fround(HEAPF32[$20>>2]);
  $67 = Math_fround($61 * $66);
  $68 = Math_fround($65 + $67);
  $69 = Math_fround(HEAPF32[$31>>2]);
  $70 = Math_fround($63 * $69);
  $71 = Math_fround($68 + $70);
  $72 = Math_fround(HEAPF32[$12>>2]);
  $73 = Math_fround($59 * $72);
  $74 = Math_fround(HEAPF32[$23>>2]);
  $75 = Math_fround($61 * $74);
  $76 = Math_fround($73 + $75);
  $77 = Math_fround(HEAPF32[$34>>2]);
  $78 = Math_fround($63 * $77);
  $79 = Math_fround($76 + $78);
  $80 = Math_fround(HEAPF32[$16>>2]);
  $81 = Math_fround($59 * $80);
  $82 = Math_fround(HEAPF32[$27>>2]);
  $83 = Math_fround($61 * $82);
  $84 = Math_fround($81 + $83);
  $85 = Math_fround(HEAPF32[$38>>2]);
  $86 = Math_fround($63 * $85);
  $87 = Math_fround($84 + $86);
  $88 = (($57) + (($55*12)|0)|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = ((($57) + (($55*12)|0)|0) + 4|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = ((($57) + (($55*12)|0)|0) + 8|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = Math_fround($64 * $89);
  $95 = Math_fround($66 * $91);
  $96 = Math_fround($94 + $95);
  $97 = Math_fround($69 * $93);
  $98 = Math_fround($96 + $97);
  $99 = Math_fround($72 * $89);
  $100 = Math_fround($74 * $91);
  $101 = Math_fround($99 + $100);
  $102 = Math_fround($77 * $93);
  $103 = Math_fround($101 + $102);
  $104 = Math_fround($80 * $89);
  $105 = Math_fround($82 * $91);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($85 * $93);
  $108 = Math_fround($106 + $107);
  $109 = Math_fround(HEAPF32[$_dir>>2]);
  $110 = Math_fround(HEAPF32[$5>>2]);
  $111 = Math_fround(HEAPF32[$7>>2]);
  $112 = Math_fround($109 * $98);
  $113 = Math_fround($110 * $103);
  $114 = Math_fround($112 + $113);
  $115 = Math_fround($108 * $111);
  $116 = Math_fround($114 + $115);
  HEAPF32[$min>>2] = $116;
  $117 = (($min) + 4|0);
  ;HEAP32[$117+0>>2]=HEAP32[$$sroa$117+0>>2]|0;HEAP32[$117+4>>2]=HEAP32[$$sroa$117+4>>2]|0;HEAP32[$117+8>>2]=HEAP32[$$sroa$117+8>>2]|0;
  $118 = Math_fround(HEAPF32[$_dir>>2]);
  $119 = Math_fround(HEAPF32[$5>>2]);
  $120 = Math_fround(HEAPF32[$7>>2]);
  $121 = Math_fround($71 * $118);
  $122 = Math_fround($79 * $119);
  $123 = Math_fround($121 + $122);
  $124 = Math_fround($87 * $120);
  $125 = Math_fround($123 + $124);
  HEAPF32[$max>>2] = $125;
  $126 = (($max) + 4|0);
  ;HEAP32[$126+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$126+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$126+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$_dir) {
 $this = $this|0;
 $_dir = $_dir|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $9 = 0, $a$050 = 0, $exitcond = 0, $index$0 = 0, $index$151 = 0, $index$2 = 0, $smallBitMap = 0, $tmp$i = 0, $tmp1$i = 0, $u$i = 0, $v$i = 0, $vertexSpaceDirection = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $u$i = sp + 52|0;
 $v$i = sp;
 $smallBitMap = sp + 8|0;
 $vertexSpaceDirection = sp + 40|0;
 $0 = (($this) + 196|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 ;HEAP32[$smallBitMap+0>>2]=0|0;HEAP32[$smallBitMap+4>>2]=0|0;HEAP32[$smallBitMap+8>>2]=0|0;HEAP32[$smallBitMap+12>>2]=0|0;HEAP32[$smallBitMap+16>>2]=0|0;HEAP32[$smallBitMap+20>>2]=0|0;HEAP32[$smallBitMap+24>>2]=0|0;HEAP32[$smallBitMap+28>>2]=0|0;
 $6 = Math_fround(HEAPF32[$_dir>>2]);
 $7 = (($_dir) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($_dir) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$vertexSpaceDirection>>2] = $6;
 $11 = (($vertexSpaceDirection) + 4|0);
 HEAPF32[$11>>2] = $8;
 $12 = (($vertexSpaceDirection) + 8|0);
 HEAPF32[$12>>2] = $10;
 $13 = HEAP16[$1>>1]|0;
 $14 = $13&65535;
 $15 = (__ZN5physx13CubemapLookupERKNS_6PxVec3ERfS3_($vertexSpaceDirection,$u$i,$v$i)|0);
 $16 = (($14) + -1)|0;
 $17 = (Math_fround(($16>>>0)));
 $18 = Math_fround($17 * Math_fround(0.5));
 $19 = Math_fround(HEAPF32[$u$i>>2]);
 $20 = Math_fround($19 + Math_fround(1.0));
 $21 = Math_fround($18 * $20);
 $22 = Math_fround(HEAPF32[$v$i>>2]);
 $23 = Math_fround($22 + Math_fround(1.0));
 $24 = Math_fround($18 * $23);
 $25 = Math_imul($15, $14)|0;
 $26 = Math_fround($21 + Math_fround(0.5));
 $27 = (~~(($26))>>>0);
 $28 = Math_fround($24 + Math_fround(0.5));
 $29 = (~~(($28))>>>0);
 $tmp$i = (($27) + ($25))|0;
 $tmp1$i = Math_imul($tmp$i, $14)|0;
 $30 = (($tmp1$i) + ($29))|0;
 $31 = HEAP32[$0>>2]|0;
 $32 = (($31) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + ($30)|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = (($this) + 200|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + (($36*12)|0)|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = ((($38) + (($36*12)|0)|0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = ((($38) + (($36*12)|0)|0) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround(HEAPF32[$_dir>>2]);
 $46 = Math_fround(HEAPF32[$7>>2]);
 $47 = Math_fround(HEAPF32[$9>>2]);
 $48 = Math_fround($40 * $45);
 $49 = Math_fround($42 * $46);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($44 * $47);
 $52 = Math_fround($50 + $51);
 $87 = $52;$index$0 = $36;
 while(1) {
  $53 = (($3) + ($index$0<<2)|0);
  $54 = HEAP16[$53>>1]|0;
  $55 = ((($3) + ($index$0<<2)|0) + 2|0);
  $56 = HEAP16[$55>>1]|0;
  $57 = $56&65535;
  $58 = ($54<<16>>16)==(0);
  if ($58) {
   label = 9;
   break;
  }
  $59 = $54&65535;
  $76 = $87;$a$050 = 0;$index$151 = $index$0;
  while(1) {
   $60 = (($a$050) + ($57))|0;
   $61 = (($5) + ($60)|0);
   $62 = HEAP8[$61>>0]|0;
   $63 = $62&255;
   $64 = (($38) + (($63*12)|0)|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = ((($38) + (($63*12)|0)|0) + 4|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = ((($38) + (($63*12)|0)|0) + 8|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($65 * $45);
   $71 = Math_fround($67 * $46);
   $72 = Math_fround($70 + $71);
   $73 = Math_fround($69 * $47);
   $74 = Math_fround($72 + $73);
   $75 = $74 > $76;
   if ($75) {
    $77 = $63 >>> 5;
    $78 = $63 & 31;
    $79 = 1 << $78;
    $80 = (($smallBitMap) + ($77<<2)|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = $81 & $79;
    $83 = ($82|0)==(0);
    if ($83) {
     $84 = $81 | $79;
     HEAP32[$80>>2] = $84;
     $88 = $74;$index$2 = $63;
    } else {
     $88 = $76;$index$2 = $index$151;
    }
   } else {
    $88 = $76;$index$2 = $index$151;
   }
   $85 = (($a$050) + 1)|0;
   $exitcond = ($85|0)==($59|0);
   if ($exitcond) {
    break;
   } else {
    $76 = $88;$a$050 = $85;$index$151 = $index$2;
   }
  }
  $86 = ($index$2|0)==($index$0|0);
  if ($86) {
   label = 9;
   break;
  } else {
   $87 = $88;$index$0 = $index$2;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return ($index$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu11ConvexHullV22BruteForceSearchMinMaxERKNS_6shdfnd3aos5Vec3VERNS3_6FloatVES8_($this,$dir,$min,$max) {
 $this = $this|0;
 $dir = $dir|0;
 $min = $min|0;
 $max = $max|0;
 var $$$i = Math_fround(0), $$$i75$lcssa = Math_fround(0), $$$i7576 = Math_fround(0), $$$i8 = Math_fround(0), $$lcssa = Math_fround(0), $$sroa$1 = 0, $$sroa$120 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0;
 var $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = Math_fround(0), $_max$sroa$1 = 0, $_min$sroa$1 = 0, $i$077 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_max$sroa$1 = sp + 36|0;
 $_min$sroa$1 = sp;
 $$sroa$120 = sp + 12|0;
 $$sroa$1 = sp + 24|0;
 $0 = (($this) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$dir>>2]);
 $8 = (($dir) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($dir) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($2 * $7);
 $13 = Math_fround($4 * $9);
 $14 = Math_fround($12 + $13);
 $15 = Math_fround($6 * $11);
 $16 = Math_fround($14 + $15);
 ;HEAP32[$_min$sroa$1+0>>2]=HEAP32[$_max$sroa$1+0>>2]|0;HEAP32[$_min$sroa$1+4>>2]=HEAP32[$_max$sroa$1+4>>2]|0;HEAP32[$_min$sroa$1+8>>2]=HEAP32[$_max$sroa$1+8>>2]|0;
 $17 = (($this) + 204|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18&255)>(1);
 if (!($19)) {
  $$$i75$lcssa = $16;$$lcssa = $16;
  HEAPF32[$min>>2] = $$$i75$lcssa;
  $77 = (($min) + 4|0);
  ;HEAP32[$77+0>>2]=HEAP32[$_min$sroa$1+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$_min$sroa$1+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$_min$sroa$1+8>>2]|0;
  HEAPF32[$max>>2] = $$lcssa;
  $78 = (($max) + 4|0);
  ;HEAP32[$78+0>>2]=HEAP32[$_max$sroa$1+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$_max$sroa$1+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$_max$sroa$1+8>>2]|0;
  STACKTOP = sp;return;
 }
 $20 = (($this) + 96|0);
 $21 = (($this) + 112|0);
 $22 = (($this) + 128|0);
 $23 = (($this) + 100|0);
 $24 = (($this) + 116|0);
 $25 = (($this) + 132|0);
 $26 = (($this) + 104|0);
 $27 = (($this) + 120|0);
 $28 = (($this) + 136|0);
 $$$i7576 = $16;$30 = $1;$71 = $16;$i$077 = 1;
 while(1) {
  $$sum = (($i$077) + 10)|0;
  $29 = ((($30) + (($$sum*12)|0)|0) + 8|0);
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + (($i$077*12)|0)|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = ((($31) + (($i$077*12)|0)|0) + 4|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = ((($31) + (($i$077*12)|0)|0) + 8|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround(HEAPF32[$20>>2]);
  $39 = Math_fround($33 * $38);
  $40 = Math_fround(HEAPF32[$21>>2]);
  $41 = Math_fround($35 * $40);
  $42 = Math_fround($39 + $41);
  $43 = Math_fround(HEAPF32[$22>>2]);
  $44 = Math_fround($37 * $43);
  $45 = Math_fround($42 + $44);
  $46 = Math_fround(HEAPF32[$23>>2]);
  $47 = Math_fround($33 * $46);
  $48 = Math_fround(HEAPF32[$24>>2]);
  $49 = Math_fround($35 * $48);
  $50 = Math_fround($47 + $49);
  $51 = Math_fround(HEAPF32[$25>>2]);
  $52 = Math_fround($37 * $51);
  $53 = Math_fround($50 + $52);
  $54 = Math_fround(HEAPF32[$26>>2]);
  $55 = Math_fround($33 * $54);
  $56 = Math_fround(HEAPF32[$27>>2]);
  $57 = Math_fround($35 * $56);
  $58 = Math_fround($55 + $57);
  $59 = Math_fround(HEAPF32[$28>>2]);
  $60 = Math_fround($37 * $59);
  $61 = Math_fround($58 + $60);
  $62 = Math_fround(HEAPF32[$dir>>2]);
  $63 = Math_fround(HEAPF32[$8>>2]);
  $64 = Math_fround(HEAPF32[$10>>2]);
  $65 = Math_fround($45 * $62);
  $66 = Math_fround($53 * $63);
  $67 = Math_fround($65 + $66);
  $68 = Math_fround($61 * $64);
  $69 = Math_fround($67 + $68);
  $70 = $69 > $71;
  $$$i8 = $70 ? $69 : $71;
  ;HEAP32[$_max$sroa$1+0>>2]=HEAP32[$$sroa$120+0>>2]|0;HEAP32[$_max$sroa$1+4>>2]=HEAP32[$$sroa$120+4>>2]|0;HEAP32[$_max$sroa$1+8>>2]=HEAP32[$$sroa$120+8>>2]|0;
  $72 = $69 > $$$i7576;
  $$$i = $72 ? $$$i7576 : $69;
  ;HEAP32[$_min$sroa$1+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$_min$sroa$1+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$_min$sroa$1+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
  $73 = (($i$077) + 1)|0;
  $74 = HEAP8[$17>>0]|0;
  $75 = $74&255;
  $76 = ($73>>>0)<($75>>>0);
  if ($76) {
   $$$i7576 = $$$i;$30 = $31;$71 = $$$i8;$i$077 = $73;
  } else {
   $$$i75$lcssa = $$$i;$$lcssa = $$$i8;
   break;
  }
 }
 HEAPF32[$min>>2] = $$$i75$lcssa;
 $77 = (($min) + 4|0);
 ;HEAP32[$77+0>>2]=HEAP32[$_min$sroa$1+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$_min$sroa$1+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$_min$sroa$1+8>>2]|0;
 HEAPF32[$max>>2] = $$lcssa;
 $78 = (($max) + 4|0);
 ;HEAP32[$78+0>>2]=HEAP32[$_max$sroa$1+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$_max$sroa$1+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$_max$sroa$1+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $$0$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$sum$i$i = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0;
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_dir = 0;
 var $i$041$i$i = 0, $maxIndex$040$i$i = 0, $maxIndex$1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_dir = sp;
 $0 = Math_fround(HEAPF32[$dir>>2]);
 $1 = (($dir) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($dir) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 96|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 * $6);
 $8 = (($this) + 100|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($2 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($this) + 104|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($4 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (($this) + 112|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($0 * $17);
 $19 = (($this) + 116|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($2 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($this) + 120|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($4 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($this) + 128|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($0 * $28);
 $30 = (($this) + 132|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($2 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($this) + 136|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($4 * $35);
 $37 = Math_fround($33 + $36);
 HEAPF32[$_dir>>2] = $15;
 $38 = (($_dir) + 4|0);
 HEAPF32[$38>>2] = $26;
 $39 = (($_dir) + 8|0);
 HEAPF32[$39>>2] = $37;
 $40 = (($_dir) + 12|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($this) + 196|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $45 = (($this) + 200|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($this) + 204|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48&255)>(1);
  if ($49) {
   $50 = (($46) + 4|0);
   $51 = (($46) + 8|0);
   $52 = Math_fround(HEAPF32[$50>>2]);
   $53 = Math_fround(HEAPF32[$46>>2]);
   $54 = Math_fround($26 * $52);
   $55 = Math_fround($15 * $53);
   $56 = Math_fround(HEAPF32[$51>>2]);
   $57 = Math_fround($37 * $56);
   $58 = Math_fround($54 + $55);
   $59 = Math_fround($58 + $57);
   $61 = $46;$75 = $59;$i$041$i$i = 1;$maxIndex$040$i$i = 0;
   while(1) {
    $$sum$i$i = (($i$041$i$i) + 10)|0;
    $60 = ((($61) + (($$sum$i$i*12)|0)|0) + 8|0);
    $62 = HEAP32[$45>>2]|0;
    $63 = (($62) + (($i$041$i$i*12)|0)|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = ((($62) + (($i$041$i$i*12)|0)|0) + 4|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($62) + (($i$041$i$i*12)|0)|0) + 8|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = Math_fround($64 * $15);
    $70 = Math_fround($66 * $26);
    $71 = Math_fround($69 + $70);
    $72 = Math_fround($68 * $37);
    $73 = Math_fround($71 + $72);
    $74 = $73 > $75;
    $76 = $74 ? $73 : $75;
    $maxIndex$1$i$i = $74 ? $i$041$i$i : $maxIndex$040$i$i;
    $77 = (($i$041$i$i) + 1)|0;
    $78 = HEAP8[$47>>0]|0;
    $79 = $78&255;
    $80 = ($77>>>0)<($79>>>0);
    if ($80) {
     $61 = $62;$75 = $76;$i$041$i$i = $77;$maxIndex$040$i$i = $maxIndex$1$i$i;
    } else {
     $$0$i = $maxIndex$1$i$i;$82 = $62;
     break;
    }
   }
  } else {
   $$0$i = 0;$82 = $46;
  }
 } else {
  $44 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$_dir)|0);
  $$phi$trans$insert = (($this) + 200|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$0$i = $44;$82 = $$pre;
 }
 $81 = (($82) + (($$0$i*12)|0)|0);
 $83 = Math_fround(HEAPF32[$81>>2]);
 $84 = ((($82) + (($$0$i*12)|0)|0) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = ((($82) + (($$0$i*12)|0)|0) + 8|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround(HEAPF32[$5>>2]);
 $89 = Math_fround($83 * $88);
 $90 = Math_fround(HEAPF32[$16>>2]);
 $91 = Math_fround($85 * $90);
 $92 = Math_fround($89 + $91);
 $93 = Math_fround(HEAPF32[$27>>2]);
 $94 = Math_fround($87 * $93);
 $95 = Math_fround($92 + $94);
 $96 = Math_fround(HEAPF32[$8>>2]);
 $97 = Math_fround($83 * $96);
 $98 = Math_fround(HEAPF32[$19>>2]);
 $99 = Math_fround($85 * $98);
 $100 = Math_fround($97 + $99);
 $101 = Math_fround(HEAPF32[$30>>2]);
 $102 = Math_fround($87 * $101);
 $103 = Math_fround($100 + $102);
 $104 = Math_fround(HEAPF32[$12>>2]);
 $105 = Math_fround($83 * $104);
 $106 = Math_fround(HEAPF32[$23>>2]);
 $107 = Math_fround($85 * $106);
 $108 = Math_fround($105 + $107);
 $109 = Math_fround(HEAPF32[$34>>2]);
 $110 = Math_fround($87 * $109);
 $111 = Math_fround($108 + $110);
 HEAPF32[$agg$result>>2] = $95;
 $112 = (($agg$result) + 4|0);
 HEAPF32[$112>>2] = $103;
 $113 = (($agg$result) + 8|0);
 HEAPF32[$113>>2] = $111;
 $114 = (($agg$result) + 12|0);
 HEAPF32[$114>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEE9doSupportERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$041$i$i$i = 0, $maxIndex$040$i$i$i = 0, $maxIndex$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 196|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $6 = (($1) + 200|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($dir) + 4|0);
  $9 = (($dir) + 8|0);
  $10 = (($1) + 204|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11&255)>(1);
  if ($12) {
   $13 = (($7) + 4|0);
   $14 = Math_fround(HEAPF32[$8>>2]);
   $15 = Math_fround(HEAPF32[$dir>>2]);
   $16 = (($7) + 8|0);
   $17 = Math_fround(HEAPF32[$13>>2]);
   $18 = Math_fround(HEAPF32[$7>>2]);
   $19 = Math_fround($14 * $17);
   $20 = Math_fround($15 * $18);
   $21 = Math_fround(HEAPF32[$9>>2]);
   $22 = Math_fround(HEAPF32[$16>>2]);
   $23 = Math_fround($21 * $22);
   $24 = Math_fround($19 + $20);
   $25 = Math_fround($24 + $23);
   $27 = $7;$44 = $25;$i$041$i$i$i = 1;$maxIndex$040$i$i$i = 0;
   while(1) {
    $$sum$i$i$i = (($i$041$i$i$i) + 10)|0;
    $26 = ((($27) + (($$sum$i$i$i*12)|0)|0) + 8|0);
    $28 = HEAP32[$6>>2]|0;
    $29 = (($28) + (($i$041$i$i$i*12)|0)|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = ((($28) + (($i$041$i$i$i*12)|0)|0) + 4|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = ((($28) + (($i$041$i$i$i*12)|0)|0) + 8|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = Math_fround(HEAPF32[$dir>>2]);
    $36 = Math_fround(HEAPF32[$8>>2]);
    $37 = Math_fround(HEAPF32[$9>>2]);
    $38 = Math_fround($30 * $35);
    $39 = Math_fround($32 * $36);
    $40 = Math_fround($38 + $39);
    $41 = Math_fround($34 * $37);
    $42 = Math_fround($40 + $41);
    $43 = $42 > $44;
    $45 = $43 ? $42 : $44;
    $maxIndex$1$i$i$i = $43 ? $i$041$i$i$i : $maxIndex$040$i$i$i;
    $46 = (($i$041$i$i$i) + 1)|0;
    $47 = HEAP8[$10>>0]|0;
    $48 = $47&255;
    $49 = ($46>>>0)<($48>>>0);
    if ($49) {
     $27 = $28;$44 = $45;$i$041$i$i$i = $46;$maxIndex$040$i$i$i = $maxIndex$1$i$i$i;
    } else {
     $$0$i$i = $maxIndex$1$i$i$i;$51 = $28;
     break;
    }
   }
  } else {
   $$0$i$i = 0;$51 = $7;
  }
 } else {
  $5 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($1,$dir)|0);
  $$phi$trans$insert$i = (($1) + 200|0);
  $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
  $$0$i$i = $5;$51 = $$pre$i;
 }
 $50 = (($51) + (($$0$i$i*12)|0)|0);
 $52 = Math_fround(HEAPF32[$50>>2]);
 $53 = ((($51) + (($$0$i$i*12)|0)|0) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = ((($51) + (($$0$i$i*12)|0)|0) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 HEAPF32[$agg$result>>2] = $52;
 $57 = (($agg$result) + 4|0);
 HEAPF32[$57>>2] = $54;
 $58 = (($agg$result) + 8|0);
 HEAPF32[$58>>2] = $56;
 $59 = (($agg$result) + 12|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEE9doSupportERKNS_6shdfnd3aos5Vec3VERNS5_6FloatVESA_($this,$dir,$min,$max) {
 $this = $this|0;
 $dir = $dir|0;
 $min = $min|0;
 $max = $max|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZNK5physx2Gu18ConvexHullNoScaleV19supportVertexMinMaxERKNS_6shdfnd3aos5Vec3VERNS3_6FloatVES8_($1,$dir,$min,$max);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEE13populateVertsEPKhjPKNS_6PxVec3EPNS_6shdfnd3aos5Vec3VE($this,$inds,$numInds,$originalVerts,$verts) {
 $this = $this|0;
 $inds = $inds|0;
 $numInds = $numInds|0;
 $originalVerts = $originalVerts|0;
 $verts = $verts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numInds|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i$01$i = 0;
 }
 while(1) {
  $1 = (($inds) + ($i$01$i)|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = $2&255;
  $4 = (($originalVerts) + (($3*12)|0)|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = ((($originalVerts) + (($3*12)|0)|0) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = ((($originalVerts) + (($3*12)|0)|0) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($verts) + ($i$01$i<<4)|0);
  HEAPF32[$10>>2] = $5;
  $11 = ((($verts) + ($i$01$i<<4)|0) + 4|0);
  HEAPF32[$11>>2] = $7;
  $12 = ((($verts) + ($i$01$i<<4)|0) + 8|0);
  HEAPF32[$12>>2] = $9;
  $13 = ((($verts) + ($i$01$i<<4)|0) + 12|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = (($i$01$i) + 1)|0;
  $exitcond$i = ($14|0)==($numInds|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $14;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu18ConvexHullNoScaleV19supportVertexMinMaxERKNS_6shdfnd3aos5Vec3VERNS3_6FloatVES8_($this,$dir,$min,$max) {
 $this = $this|0;
 $dir = $dir|0;
 $min = $min|0;
 $max = $max|0;
 var $$$i$i = Math_fround(0), $$$i65$lcssa$i = Math_fround(0), $$$i6566$i = Math_fround(0), $$$i8$i = Math_fround(0), $$lcssa$i = Math_fround(0), $$sroa$1 = 0, $$sroa$1$i = 0, $$sroa$111 = 0, $$sroa$118$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0);
 var $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0;
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0);
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $_max$sroa$1$i = 0, $_min$sroa$1$i = 0, $i$067$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $_max$sroa$1$i = sp + 76|0;
 $_min$sroa$1$i = sp + 40|0;
 $$sroa$118$i = sp + 16|0;
 $$sroa$1$i = sp + 28|0;
 $0 = sp;
 $$sroa$111 = sp + 52|0;
 $$sroa$1 = sp + 64|0;
 $1 = (($this) + 196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$dir)|0);
  $5 = Math_fround(HEAPF32[$dir>>2]);
  $6 = (($dir) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($dir) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround(-$5);
  $11 = Math_fround(-$7);
  $12 = Math_fround(-$9);
  HEAPF32[$0>>2] = $10;
  $13 = (($0) + 4|0);
  HEAPF32[$13>>2] = $11;
  $14 = (($0) + 8|0);
  HEAPF32[$14>>2] = $12;
  $15 = (($0) + 12|0);
  HEAPF32[$15>>2] = Math_fround(0.0);
  $16 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$0)|0);
  $17 = (($this) + 200|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + (($4*12)|0)|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = ((($18) + (($4*12)|0)|0) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = ((($18) + (($4*12)|0)|0) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($18) + (($16*12)|0)|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = ((($18) + (($16*12)|0)|0) + 4|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = ((($18) + (($16*12)|0)|0) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround(HEAPF32[$dir>>2]);
  $32 = Math_fround(HEAPF32[$6>>2]);
  $33 = Math_fround(HEAPF32[$8>>2]);
  $34 = Math_fround($26 * $31);
  $35 = Math_fround($28 * $32);
  $36 = Math_fround($34 + $35);
  $37 = Math_fround($30 * $33);
  $38 = Math_fround($36 + $37);
  HEAPF32[$min>>2] = $38;
  $39 = (($min) + 4|0);
  ;HEAP32[$39+0>>2]=HEAP32[$$sroa$111+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$$sroa$111+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$$sroa$111+8>>2]|0;
  $40 = Math_fround(HEAPF32[$dir>>2]);
  $41 = Math_fround(HEAPF32[$6>>2]);
  $42 = Math_fround(HEAPF32[$8>>2]);
  $43 = Math_fround($20 * $40);
  $44 = Math_fround($22 * $41);
  $45 = Math_fround($43 + $44);
  $46 = Math_fround($24 * $42);
  $47 = Math_fround($45 + $46);
  HEAPF32[$max>>2] = $47;
  $48 = (($max) + 4|0);
  ;HEAP32[$48+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$48+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$48+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
  STACKTOP = sp;return;
 }
 $49 = (($this) + 200|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($50) + 4|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($50) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround(HEAPF32[$dir>>2]);
 $57 = (($dir) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($dir) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($51 * $56);
 $62 = Math_fround($53 * $58);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($55 * $60);
 $65 = Math_fround($63 + $64);
 ;HEAP32[$_min$sroa$1$i+0>>2]=HEAP32[$_max$sroa$1$i+0>>2]|0;HEAP32[$_min$sroa$1$i+4>>2]=HEAP32[$_max$sroa$1$i+4>>2]|0;HEAP32[$_min$sroa$1$i+8>>2]=HEAP32[$_max$sroa$1$i+8>>2]|0;
 $66 = (($this) + 204|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = ($67&255)>(1);
 if ($68) {
  $$$i6566$i = $65;$70 = $50;$87 = $65;$i$067$i = 1;
  while(1) {
   $$sum$i = (($i$067$i) + 10)|0;
   $69 = ((($70) + (($$sum$i*12)|0)|0) + 8|0);
   $71 = HEAP32[$49>>2]|0;
   $72 = (($71) + (($i$067$i*12)|0)|0);
   $73 = Math_fround(HEAPF32[$72>>2]);
   $74 = ((($71) + (($i$067$i*12)|0)|0) + 4|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = ((($71) + (($i$067$i*12)|0)|0) + 8|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = Math_fround(HEAPF32[$dir>>2]);
   $79 = Math_fround(HEAPF32[$57>>2]);
   $80 = Math_fround(HEAPF32[$59>>2]);
   $81 = Math_fround($73 * $78);
   $82 = Math_fround($75 * $79);
   $83 = Math_fround($81 + $82);
   $84 = Math_fround($77 * $80);
   $85 = Math_fround($83 + $84);
   $86 = $85 > $87;
   $$$i8$i = $86 ? $85 : $87;
   ;HEAP32[$_max$sroa$1$i+0>>2]=HEAP32[$$sroa$118$i+0>>2]|0;HEAP32[$_max$sroa$1$i+4>>2]=HEAP32[$$sroa$118$i+4>>2]|0;HEAP32[$_max$sroa$1$i+8>>2]=HEAP32[$$sroa$118$i+8>>2]|0;
   $88 = $85 > $$$i6566$i;
   $$$i$i = $88 ? $$$i6566$i : $85;
   ;HEAP32[$_min$sroa$1$i+0>>2]=HEAP32[$$sroa$1$i+0>>2]|0;HEAP32[$_min$sroa$1$i+4>>2]=HEAP32[$$sroa$1$i+4>>2]|0;HEAP32[$_min$sroa$1$i+8>>2]=HEAP32[$$sroa$1$i+8>>2]|0;
   $89 = (($i$067$i) + 1)|0;
   $90 = HEAP8[$66>>0]|0;
   $91 = $90&255;
   $92 = ($89>>>0)<($91>>>0);
   if ($92) {
    $$$i6566$i = $$$i$i;$70 = $71;$87 = $$$i8$i;$i$067$i = $89;
   } else {
    $$$i65$lcssa$i = $$$i$i;$$lcssa$i = $$$i8$i;
    break;
   }
  }
 } else {
  $$$i65$lcssa$i = $65;$$lcssa$i = $65;
 }
 HEAPF32[$min>>2] = $$$i65$lcssa$i;
 $93 = (($min) + 4|0);
 ;HEAP32[$93+0>>2]=HEAP32[$_min$sroa$1$i+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$_min$sroa$1$i+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$_min$sroa$1$i+8>>2]|0;
 HEAPF32[$max>>2] = $$lcssa$i;
 $94 = (($max) + 4|0);
 ;HEAP32[$94+0>>2]=HEAP32[$_max$sroa$1$i+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$_max$sroa$1$i+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$_max$sroa$1$i+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16SupportLocalImplINS0_4BoxVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16SupportLocalImplINS0_4BoxVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $4 > Math_fround(0.0);
 $10 = $6 > Math_fround(0.0);
 $11 = $8 > Math_fround(0.0);
 $12 = (($3) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$12+12>>2]|0;
 $13 = (($3) + 144|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($3) + 148|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($3) + 152|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(-$14);
 $20 = Math_fround(-$16);
 $21 = Math_fround(-$18);
 HEAPF32[$0>>2] = $19;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $21;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $b$a$i$i = $9 ? $1 : $0;
 $25 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $10 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $26 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $11 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $27 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$agg$result>>2] = $25;
 $28 = (($agg$result) + 4|0);
 HEAPF32[$28>>2] = $26;
 $29 = (($agg$result) + 8|0);
 HEAPF32[$29>>2] = $27;
 $30 = (($agg$result) + 12|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERNS5_6FloatVESA_($this,$dir,$min,$max) {
 $this = $this|0;
 $dir = $dir|0;
 $min = $min|0;
 $max = $max|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $$sroa$1$i = 0, $$sroa$119$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0;
 var $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0;
 var $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 16|0;
 $1 = sp;
 $$sroa$119$i = sp + 44|0;
 $$sroa$1$i = sp + 32|0;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $4 > Math_fround(0.0);
 $10 = $6 > Math_fround(0.0);
 $11 = $8 > Math_fround(0.0);
 $12 = (($3) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$12+12>>2]|0;
 $13 = (($3) + 144|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($3) + 148|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($3) + 152|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(-$14);
 $20 = Math_fround(-$16);
 $21 = Math_fround(-$18);
 HEAPF32[$0>>2] = $19;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $21;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $b$a$i$i = $9 ? $1 : $0;
 $25 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $10 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $26 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $11 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $27 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $28 = Math_fround($4 * $25);
 $29 = Math_fround($6 * $26);
 $30 = Math_fround($28 + $29);
 $31 = Math_fround($8 * $27);
 $32 = Math_fround($30 + $31);
 HEAPF32[$max>>2] = $32;
 $33 = (($max) + 4|0);
 ;HEAP32[$33+0>>2]=HEAP32[$$sroa$119$i+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$$sroa$119$i+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$$sroa$119$i+8>>2]|0;
 $34 = Math_fround(-$32);
 HEAPF32[$min>>2] = $34;
 $35 = (($min) + 4|0);
 ;HEAP32[$35+0>>2]=HEAP32[$$sroa$1$i+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$$sroa$1$i+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$$sroa$1$i+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_4BoxVEE13populateVertsEPKhjPKNS_6PxVec3EPNS_6shdfnd3aos5Vec3VE($this,$inds,$numInds,$originalVerts,$verts) {
 $this = $this|0;
 $inds = $inds|0;
 $numInds = $numInds|0;
 $originalVerts = $originalVerts|0;
 $verts = $verts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numInds|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i$01$i = 0;
 }
 while(1) {
  $1 = (($inds) + ($i$01$i)|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = $2&255;
  $4 = (($originalVerts) + (($3*12)|0)|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = ((($originalVerts) + (($3*12)|0)|0) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = ((($originalVerts) + (($3*12)|0)|0) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($verts) + ($i$01$i<<4)|0);
  HEAPF32[$10>>2] = $5;
  $11 = ((($verts) + ($i$01$i<<4)|0) + 4|0);
  HEAPF32[$11>>2] = $7;
  $12 = ((($verts) + ($i$01$i<<4)|0) + 8|0);
  HEAPF32[$12>>2] = $9;
  $13 = ((($verts) + ($i$01$i<<4)|0) + 12|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = (($i$01$i) + 1)|0;
  $exitcond$i = ($14|0)==($numInds|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $14;
  }
 }
 STACKTOP = sp;return;
}
function __ZL11PxcTestAxisRKN5physx6PxVec3ERKNS_2Gu7SegmentEfRKNS3_3BoxERf($axis$0$0$val,$axis$0$1$val,$axis$0$2$val,$segment,$radius,$box,$depth) {
 $axis$0$0$val = Math_fround($axis$0$0$val);
 $axis$0$1$val = Math_fround($axis$0$1$val);
 $axis$0$2$val = Math_fround($axis$0$2$val);
 $segment = $segment|0;
 $radius = Math_fround($radius);
 $box = $box|0;
 $depth = $depth|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $9 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$segment>>2]);
 $1 = Math_fround($0 * $axis$0$0$val);
 $2 = (($segment) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $axis$0$1$val);
 $5 = Math_fround($1 + $4);
 $6 = (($segment) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $axis$0$2$val);
 $9 = Math_fround($5 + $8);
 $10 = (($segment) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $axis$0$0$val);
 $13 = (($segment) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $axis$0$1$val);
 $16 = Math_fround($12 + $15);
 $17 = (($segment) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * $axis$0$2$val);
 $20 = Math_fround($16 + $19);
 $21 = $9 > $20;
 $22 = $21 ? $20 : $9;
 $23 = $21 ? $9 : $20;
 $24 = Math_fround($22 - $radius);
 $25 = Math_fround($23 + $radius);
 $26 = (($box) + 36|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 * $axis$0$0$val);
 $29 = (($box) + 40|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $axis$0$1$val);
 $32 = Math_fround($28 + $31);
 $33 = (($box) + 44|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $axis$0$2$val);
 $36 = Math_fround($32 + $35);
 $37 = Math_fround(HEAPF32[$box>>2]);
 $38 = Math_fround($37 * $axis$0$0$val);
 $39 = (($box) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($40 * $axis$0$1$val);
 $42 = Math_fround($38 + $41);
 $43 = (($box) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 * $axis$0$2$val);
 $46 = Math_fround($42 + $45);
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($46)))));
 $47 = (($box) + 48|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($fabsf$i$i2$i * $48);
 $50 = (($box) + 12|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $axis$0$0$val);
 $53 = (($box) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 * $axis$0$1$val);
 $56 = Math_fround($52 + $55);
 $57 = (($box) + 20|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 * $axis$0$2$val);
 $60 = Math_fround($56 + $59);
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($60)))));
 $61 = (($box) + 52|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($fabsf$i$i1$i * $62);
 $64 = Math_fround($49 + $63);
 $65 = (($box) + 24|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $axis$0$0$val);
 $68 = (($box) + 28|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 * $axis$0$1$val);
 $71 = Math_fround($67 + $70);
 $72 = (($box) + 32|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 * $axis$0$2$val);
 $75 = Math_fround($71 + $74);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($75)))));
 $76 = (($box) + 56|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($fabsf$i$i$i * $77);
 $79 = Math_fround($64 + $78);
 $80 = Math_fround($36 - $79);
 $81 = Math_fround($36 + $79);
 $82 = $25 < $80;
 $83 = $81 < $24;
 $or$cond = $82 | $83;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $84 = Math_fround($25 - $80);
 $85 = Math_fround($81 - $24);
 $86 = $84 < $85;
 $87 = $86 ? $84 : $85;
 HEAPF32[$depth>>2] = $87;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13GuMeshFactoryD0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx13GuMeshFactoryD2Ev($this);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZN5physx13GuMeshFactoryD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, $or$cond$i$i1 = 0, $or$cond$i$i2 = 0, $or$cond$i$i3 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((546808 + 8|0));
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)!=(0);
 $4 = ($1|0)>(-1);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 44|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$11 & 4095]($8,$6);
  }
 }
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14|0)!=(0);
 $16 = ($13|0)>(-1);
 $or$cond$i$i1 = $15 & $16;
 if ($or$cond$i$i1) {
  $17 = (($this) + 32|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   $20 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($20,$18);
  }
 }
 $24 = (($this) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26|0)!=(0);
 $28 = ($25|0)>(-1);
 $or$cond$i$i2 = $27 & $28;
 if ($or$cond$i$i2) {
  $29 = (($this) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($32,$30);
  }
 }
 $36 = (($this) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38|0)!=(0);
 $40 = ($37|0)>(-1);
 $or$cond$i$i3 = $39 & $40;
 if ($or$cond$i$i3) {
  $41 = (($this) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if (!($43)) {
   $44 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($44,$42);
  }
 }
 $48 = (($this) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 __ZN5physx6shdfnd9MutexImplD2Ev($49);
 $50 = HEAP32[$48>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $52 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 FUNCTION_TABLE_vii[$55 & 4095]($52,$50);
 STACKTOP = sp;return;
}
function __ZN5physx13GuMeshFactory7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 8|0);
  while(1) {
   $8 = HEAP32[$3>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vi[$11 & 4095]($9);
   $12 = HEAP32[$0>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   }
  }
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($this) + 20|0);
  while(1) {
   $18 = HEAP32[$7>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vi[$21 & 4095]($19);
   $22 = HEAP32[$4>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    break;
   }
  }
 }
 $14 = (($this) + 36|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = (($this) + 32|0);
  while(1) {
   $24 = HEAP32[$17>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$26>>2]|0;
   FUNCTION_TABLE_vi[$27 & 4095]($25);
   $28 = HEAP32[$14>>2]|0;
   $29 = ($28|0)==(0);
   if ($29) {
    break;
   }
  }
 }
 $30 = ($this|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$this>>2]|0;
 $32 = (($31) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vi[$33 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN5physx13GuMeshFactory15addTriangleMeshEPNS_2Gu12TriangleMeshEb($this,$np,$lock) {
 $this = $this|0;
 $np = $np|0;
 $lock = $lock|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = (($this) + 4|0);
 $3 = $lock ? $2 : 0;
 HEAP32[$0>>2] = $np;
 $4 = ($np|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 if ($lock) {
  $5 = HEAP32[$3>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($5);
 }
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $9 = (($this) + 16|0);
 if ($8) {
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & 2147483584;
  $12 = ($11>>>0)<(64);
  if ($12) {
   __ZN5physx6shdfnd5ArrayIPNS_2Gu12TriangleMeshENS0_19ReflectionAllocatorIS4_EEE8recreateEj($1,64);
   $$pre$i = HEAP32[$6>>2]|0;
   $16 = $$pre$i;
  } else {
   $16 = 0;
  }
 } else {
  $16 = $7;
 }
 $13 = HEAP32[$9>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14>>>0)>($16>>>0);
 if ($15) {
  $17 = HEAP32[$1>>2]|0;
  $18 = (($17) + ($16<<2)|0);
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   HEAP32[$18>>2] = $np;
  }
  $20 = (($16) + 1)|0;
  HEAP32[$6>>2] = $20;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Gu12TriangleMeshENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
 }
 if (!($lock)) {
  STACKTOP = sp;return;
 }
 $21 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($21);
 STACKTOP = sp;return;
}
function __ZN5physx13GuMeshFactory18createTriangleMeshERNS_13PxInputStreamE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 547640 : 546984;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,240,$$$i$i$i,546824,123)|0);
 __ZN5physx2Gu12TriangleMeshC2Ev($9);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($9) + 224|0);
 HEAP32[$11>>2] = $this;
 $12 = (__ZN5physx2Gu12TriangleMesh4loadERNS_13PxInputStreamE($9,$desc)|0);
 if ($12) {
  __ZN5physx13GuMeshFactory15addTriangleMeshEPNS_2Gu12TriangleMeshEb($this,$9,1);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($9) + 8|0);
 $14 = (($9) + 12|0);
 $15 = (__ZN5physx6shdfnd15atomicDecrementEPVi($14)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = HEAP32[$13>>2]|0;
 $18 = (($17) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 4095]($13);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13GuMeshFactory18removeTriangleMeshERNS_14PxTriangleMeshE($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0 = 0;
  } else {
   $5 = (($this) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $i$04 = 0;
   while(1) {
    $9 = (($6) + ($i$04<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($m|0);
    $8 = (($i$04) + 1)|0;
    if ($11) {
     break;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $i$04 = $8;
    } else {
     $$0 = 0;
     break L1;
    }
   }
   $12 = (($3) + -1)|0;
   HEAP32[$2>>2] = $12;
   $13 = (($6) + ($12<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$9>>2] = $14;
   $$0 = 1;
  }
 } while(0);
 $15 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($15);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx13GuMeshFactory19getNbTriangleMeshesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13GuMeshFactory17getTriangleMeshesEPPNS_14PxTriangleMeshEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($startIndex))|0;
 $3 = ($2|0)<(0);
 $4 = $3 ? 0 : $2;
 $5 = ($4>>>0)<($bufferSize>>>0);
 $6 = $5 ? $4 : $bufferSize;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 8|0);
 $9 = $bufferSize ^ -1;
 $10 = ($2|0)>(0);
 $$op = $2 ^ -1;
 $11 = $10 ? $$op : -1;
 $12 = ($11>>>0)<($9>>>0);
 $umax = $12 ? $9 : $11;
 $13 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $14 = (($i$01) + ($startIndex))|0;
  $15 = HEAP32[$8>>2]|0;
  $16 = (($15) + ($14<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($userBuffer) + ($i$01<<2)|0);
  HEAP32[$18>>2] = $17;
  $19 = (($i$01) + 1)|0;
  $exitcond = ($19|0)==($13|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $19;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx13GuMeshFactory13addConvexMeshEPNS_2Gu10ConvexMeshEb($this,$np,$lock) {
 $this = $this|0;
 $np = $np|0;
 $lock = $lock|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 $2 = (($this) + 4|0);
 $3 = $lock ? $2 : 0;
 HEAP32[$0>>2] = $np;
 $4 = ($np|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 if ($lock) {
  $5 = HEAP32[$3>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($5);
 }
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $9 = (($this) + 28|0);
 if ($8) {
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & 2147483584;
  $12 = ($11>>>0)<(64);
  if ($12) {
   __ZN5physx6shdfnd5ArrayIPNS_2Gu10ConvexMeshENS0_19ReflectionAllocatorIS4_EEE8recreateEj($1,64);
   $$pre$i = HEAP32[$6>>2]|0;
   $16 = $$pre$i;
  } else {
   $16 = 0;
  }
 } else {
  $16 = $7;
 }
 $13 = HEAP32[$9>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14>>>0)>($16>>>0);
 if ($15) {
  $17 = HEAP32[$1>>2]|0;
  $18 = (($17) + ($16<<2)|0);
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   HEAP32[$18>>2] = $np;
  }
  $20 = (($16) + 1)|0;
  HEAP32[$6>>2] = $20;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Gu10ConvexMeshENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
 }
 if (!($lock)) {
  STACKTOP = sp;return;
 }
 $21 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($21);
 STACKTOP = sp;return;
}
function __ZN5physx13GuMeshFactory16createConvexMeshERNS_13PxInputStreamE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 547400 : 546984;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,132,$$$i$i$i,546824,182)|0);
 __ZN5physx2Gu10ConvexMeshC2Ev($9);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($9) + 128|0);
 HEAP32[$11>>2] = $this;
 $12 = (__ZN5physx2Gu10ConvexMesh4loadERNS_13PxInputStreamE($9,$desc)|0);
 if ($12) {
  __ZN5physx13GuMeshFactory13addConvexMeshEPNS_2Gu10ConvexMeshEb($this,$9,1);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($9) + 8|0);
 $14 = (($9) + 12|0);
 $15 = (__ZN5physx6shdfnd15atomicDecrementEPVi($14)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = HEAP32[$13>>2]|0;
 $18 = (($17) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 4095]($13);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13GuMeshFactory16removeConvexMeshERNS_12PxConvexMeshE($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0 = 0;
  } else {
   $5 = (($this) + 20|0);
   $6 = HEAP32[$5>>2]|0;
   $i$04 = 0;
   while(1) {
    $9 = (($6) + ($i$04<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($m|0);
    $8 = (($i$04) + 1)|0;
    if ($11) {
     break;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $i$04 = $8;
    } else {
     $$0 = 0;
     break L1;
    }
   }
   $12 = (($3) + -1)|0;
   HEAP32[$2>>2] = $12;
   $13 = (($6) + ($12<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$9>>2] = $14;
   $$0 = 1;
  }
 } while(0);
 $15 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($15);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx13GuMeshFactory17getNbConvexMeshesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13GuMeshFactory15getConvexMeshesEPPNS_12PxConvexMeshEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($startIndex))|0;
 $3 = ($2|0)<(0);
 $4 = $3 ? 0 : $2;
 $5 = ($4>>>0)<($bufferSize>>>0);
 $6 = $5 ? $4 : $bufferSize;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 20|0);
 $9 = $bufferSize ^ -1;
 $10 = ($2|0)>(0);
 $$op = $2 ^ -1;
 $11 = $10 ? $$op : -1;
 $12 = ($11>>>0)<($9>>>0);
 $umax = $12 ? $9 : $11;
 $13 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $14 = (($i$01) + ($startIndex))|0;
  $15 = HEAP32[$8>>2]|0;
  $16 = (($15) + ($14<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($userBuffer) + ($i$01<<2)|0);
  HEAP32[$18>>2] = $17;
  $19 = (($i$01) + 1)|0;
  $exitcond = ($19|0)==($13|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $19;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx13GuMeshFactory14addHeightFieldEPNS_2Gu11HeightFieldEb($this,$np,$lock) {
 $this = $this|0;
 $np = $np|0;
 $lock = $lock|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = (($this) + 4|0);
 $3 = $lock ? $2 : 0;
 HEAP32[$0>>2] = $np;
 $4 = ($np|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 if ($lock) {
  $5 = HEAP32[$3>>2]|0;
  __ZN5physx6shdfnd9MutexImpl4lockEv($5);
 }
 $6 = (($this) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $9 = (($this) + 40|0);
 if ($8) {
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & 2147483584;
  $12 = ($11>>>0)<(64);
  if ($12) {
   __ZN5physx6shdfnd5ArrayIPNS_2Gu11HeightFieldENS0_19ReflectionAllocatorIS4_EEE8recreateEj($1,64);
   $$pre$i = HEAP32[$6>>2]|0;
   $16 = $$pre$i;
  } else {
   $16 = 0;
  }
 } else {
  $16 = $7;
 }
 $13 = HEAP32[$9>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14>>>0)>($16>>>0);
 if ($15) {
  $17 = HEAP32[$1>>2]|0;
  $18 = (($17) + ($16<<2)|0);
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   HEAP32[$18>>2] = $np;
  }
  $20 = (($16) + 1)|0;
  HEAP32[$6>>2] = $20;
 } else {
  (__ZN5physx6shdfnd5ArrayIPNS_2Gu11HeightFieldENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($1,$0)|0);
 }
 if (!($lock)) {
  STACKTOP = sp;return;
 }
 $21 = HEAP32[$3>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($21);
 STACKTOP = sp;return;
}
function __ZN5physx13GuMeshFactory17createHeightFieldERKNS_17PxHeightFieldDescE($this,$desc) {
 $this = $this|0;
 $desc = $desc|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 547152 : 546984;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,116,$$$i$i$i,546824,243)|0);
 __ZN5physx2Gu11HeightFieldC2EPNS_13GuMeshFactoryE($9,$this);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (__ZN5physx2Gu11HeightField12loadFromDescERKNS_17PxHeightFieldDescEb($9,$desc,1)|0);
 if ($11) {
  __ZN5physx13GuMeshFactory14addHeightFieldEPNS_2Gu11HeightFieldEb($this,$9,1);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($9) + 8|0);
 $13 = (($9) + 12|0);
 $14 = (__ZN5physx6shdfnd15atomicDecrementEPVi($13)|0);
 $15 = ($14|0)==(0);
 if (!($15)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($12);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13GuMeshFactory17createHeightFieldERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i$i = $8 ? 547152 : 546984;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,116,$$$i$i$i,546824,259)|0);
 __ZN5physx2Gu11HeightFieldC2EPNS_13GuMeshFactoryE($9,$this);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (__ZN5physx2Gu11HeightField4loadERNS_13PxInputStreamE($9,$stream)|0);
 if ($11) {
  __ZN5physx13GuMeshFactory14addHeightFieldEPNS_2Gu11HeightFieldEb($this,$9,1);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($9) + 8|0);
 $13 = (($9) + 12|0);
 $14 = (__ZN5physx6shdfnd15atomicDecrementEPVi($13)|0);
 $15 = ($14|0)==(0);
 if (!($15)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($12);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13GuMeshFactory17removeHeightFieldERNS_13PxHeightFieldE($this,$hf) {
 $this = $this|0;
 $hf = $hf|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl4lockEv($1);
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $$0 = 0;
  } else {
   $5 = (($this) + 32|0);
   $6 = HEAP32[$5>>2]|0;
   $i$04 = 0;
   while(1) {
    $9 = (($6) + ($i$04<<2)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($hf|0);
    $8 = (($i$04) + 1)|0;
    if ($11) {
     break;
    }
    $7 = ($8>>>0)<($3>>>0);
    if ($7) {
     $i$04 = $8;
    } else {
     $$0 = 0;
     break L1;
    }
   }
   $12 = (($3) + -1)|0;
   HEAP32[$2>>2] = $12;
   $13 = (($6) + ($12<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$9>>2] = $14;
   $$0 = 1;
  }
 } while(0);
 $15 = HEAP32[$0>>2]|0;
 __ZN5physx6shdfnd9MutexImpl6unlockEv($15);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx13GuMeshFactory17getNbHeightFieldsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx13GuMeshFactory15getHeightFieldsEPPNS_13PxHeightFieldEjj($this,$userBuffer,$bufferSize,$startIndex) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 $startIndex = $startIndex|0;
 var $$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($startIndex))|0;
 $3 = ($2|0)<(0);
 $4 = $3 ? 0 : $2;
 $5 = ($4>>>0)<($bufferSize>>>0);
 $6 = $5 ? $4 : $bufferSize;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($this) + 32|0);
 $9 = $bufferSize ^ -1;
 $10 = ($2|0)>(0);
 $$op = $2 ^ -1;
 $11 = $10 ? $$op : -1;
 $12 = ($11>>>0)<($9>>>0);
 $umax = $12 ? $9 : $11;
 $13 = $umax ^ -1;
 $i$01 = 0;
 while(1) {
  $14 = (($i$01) + ($startIndex))|0;
  $15 = HEAP32[$8>>2]|0;
  $16 = (($15) + ($14<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($userBuffer) + ($i$01<<2)|0);
  HEAP32[$18>>2] = $17;
  $19 = (($i$01) + 1)|0;
  $exitcond = ($19|0)==($13|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $19;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZN5physx13GuMeshFactory18addFactoryListenerERNS_21GuMeshFactoryListenerE($this,$listener) {
 $this = $this|0;
 $listener = $listener|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 44|0);
 HEAP32[$0>>2] = $listener;
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if (!($7)) {
  (__ZN5physx6shdfnd5ArrayIPNS_21GuMeshFactoryListenerENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($1,$0)|0);
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  HEAP32[$9>>2] = $listener;
 }
 $11 = (($6) + 1)|0;
 HEAP32[$5>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($this,$base,$typeID,$memRelease) {
 $this = $this|0;
 $base = $base|0;
 $typeID = $typeID|0;
 $memRelease = $memRelease|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $idx$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 44|0);
 $idx$01$i = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($idx$01$i<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_viiii[$9 & 511]($6,$base,$typeID,$memRelease);
  $10 = (($idx$01$i) + 1)|0;
  $exitcond$i = ($10|0)==($1|0);
  if ($exitcond$i) {
   break;
  } else {
   $idx$01$i = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_21GuMeshFactoryListenerENS0_19ReflectionAllocatorIS3_EEE15growAndPushBackERKS3_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 547016 : 546984;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,546904,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Gu11HeightFieldENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 547272 : 546984;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,546904,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Gu11HeightFieldENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 547272 : 546984;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,546904,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Gu10ConvexMeshENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 547520 : 546984;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,546904,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Gu10ConvexMeshENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 547520 : 546984;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,546904,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd5ArrayIPNS_2Gu12TriangleMeshENS0_19ReflectionAllocatorIS4_EEE15growAndPushBackERKS4_($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $$$i = 0, $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = ($2|0)==(0);
 $4 = $1 << 1;
 $$$i = $3 ? 1 : $4;
 $5 = ($$$i|0)==(0);
 if ($5) {
  $21 = 0;
 } else {
  $6 = $$$i << 2;
  $7 = ($6|0)==(0);
  if ($7) {
   $21 = 0;
  } else {
   $8 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z15PxGetFoundationv()|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
   $$$i$i$i = $16 ? 547760 : 546984;
   $17 = (FUNCTION_TABLE_iiiiii[$11 & 255]($8,$6,$$$i$i$i,546904,558)|0);
   $21 = $17;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($21) + ($19<<2)|0);
 $22 = ($19|0)>(0);
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $$012$i = $21;$$03$i = $23;
  while(1) {
   $24 = ($$012$i|0)==(0|0);
   if (!($24)) {
    $25 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $25;
   }
   $26 = (($$012$i) + 4|0);
   $27 = (($$03$i) + 4|0);
   $28 = ($26>>>0)<($20>>>0);
   if ($28) {
    $$012$i = $26;$$03$i = $27;
   } else {
    break;
   }
  }
 }
 $29 = ($20|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$a>>2]|0;
  HEAP32[$20>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)>(-1);
 if ($32) {
  $33 = HEAP32[$this>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $40 = $19;
  } else {
   $35 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$38 & 4095]($35,$33);
   $$pre = HEAP32[$18>>2]|0;
   $40 = $$pre;
  }
 } else {
  $40 = $19;
 }
 HEAP32[$this>>2] = $21;
 HEAP32[$0>>2] = $$$i;
 $39 = (($40) + 1)|0;
 HEAP32[$18>>2] = $39;
 $41 = (($21) + ($40<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN5physx6shdfnd5ArrayIPNS_2Gu12TriangleMeshENS0_19ReflectionAllocatorIS4_EEE8recreateEj($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $$$i$i$i = 0, $$012$i = 0, $$03$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($capacity|0)==(0);
 if ($0) {
  $16 = 0;
 } else {
  $1 = $capacity << 2;
  $2 = ($1|0)==(0);
  if ($2) {
   $16 = 0;
  } else {
   $3 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__Z15PxGetFoundationv()|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
   $$$i$i$i = $11 ? 547760 : 546984;
   $12 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$1,$$$i$i$i,546904,558)|0);
   $16 = $12;
  }
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + ($14<<2)|0);
 $17 = ($14|0)>(0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $$012$i = $16;$$03$i = $18;
  while(1) {
   $19 = ($$012$i|0)==(0|0);
   if (!($19)) {
    $20 = HEAP32[$$03$i>>2]|0;
    HEAP32[$$012$i>>2] = $20;
   }
   $21 = (($$012$i) + 4|0);
   $22 = (($$03$i) + 4|0);
   $23 = ($21>>>0)<($15>>>0);
   if ($23) {
    $$012$i = $21;$$03$i = $22;
   } else {
    break;
   }
  }
 }
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  HEAP32[$this>>2] = $16;
  HEAP32[$24>>2] = $capacity;
  STACKTOP = sp;return;
 }
 $29 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($29,$27);
 HEAP32[$this>>2] = $16;
 HEAP32[$24>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu13GeometryUnion13computeBoundsERNS_9PxBounds3ERKNS_11PxTransformEfPKS2_($this,$bounds,$pose,$contactOffset,$localSpaceBounds) {
 $this = $this|0;
 $bounds = $bounds|0;
 $pose = $pose|0;
 $contactOffset = Math_fround($contactOffset);
 $localSpaceBounds = $localSpaceBounds|0;
 var $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0);
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0;
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0);
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0;
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0;
 var $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $extents10 = 0, $extents15 = 0, $extents6 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i$1 = Math_fround(0), $fabsf$i$i$2 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0);
 var $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $origin = 0, $origin14 = 0, $origin9 = 0, $scale = 0, $thickness$0 = Math_fround(0), $thickness$0$in = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $vararg_buffer = sp;
 $origin = sp + 92|0;
 $extents6 = sp + 4|0;
 $origin9 = sp + 16|0;
 $extents10 = sp + 28|0;
 $scale = sp + 40|0;
 $origin14 = sp + 68|0;
 $extents15 = sp + 80|0;
 $0 = HEAP32[$this>>2]|0;
 switch ($0|0) {
 case 3:  {
  $76 = Math_fround(HEAPF32[$pose>>2]);
  $77 = (($pose) + 4|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($pose) + 8|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (($pose) + 12|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($76 + $76);
  $84 = Math_fround($78 + $78);
  $85 = Math_fround($80 + $80);
  $86 = Math_fround($76 * $83);
  $87 = Math_fround($78 * $84);
  $88 = Math_fround($80 * $85);
  $89 = Math_fround($83 * $78);
  $90 = Math_fround($83 * $80);
  $91 = Math_fround($83 * $82);
  $92 = Math_fround($84 * $80);
  $93 = Math_fround($84 * $82);
  $94 = Math_fround($85 * $82);
  $95 = Math_fround(Math_fround(1.0) - $87);
  $96 = Math_fround($95 - $88);
  $97 = Math_fround($89 + $94);
  $98 = Math_fround($90 - $93);
  $99 = Math_fround($89 - $94);
  $100 = Math_fround(Math_fround(1.0) - $86);
  $101 = Math_fround($100 - $88);
  $102 = Math_fround($92 + $91);
  $103 = Math_fround($90 + $93);
  $104 = Math_fround($92 - $91);
  $105 = Math_fround($100 - $87);
  $106 = (($this) + 4|0);
  $$idx$val = Math_fround(HEAPF32[$106>>2]);
  $$idx1 = (($this) + 8|0);
  $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
  $$idx2 = (($this) + 12|0);
  $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
  $107 = Math_fround($$idx$val * $96);
  $108 = Math_fround($$idx$val * $97);
  $109 = Math_fround($$idx$val * $98);
  $110 = Math_fround($99 * $$idx1$val);
  $111 = Math_fround($101 * $$idx1$val);
  $112 = Math_fround($102 * $$idx1$val);
  $113 = Math_fround($103 * $$idx2$val);
  $114 = Math_fround($104 * $$idx2$val);
  $115 = Math_fround($105 * $$idx2$val);
  $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($107)))));
  $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($110)))));
  $116 = Math_fround($fabsf$i$i3$i + $fabsf$i$i4$i);
  $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($113)))));
  $117 = Math_fround($116 + $fabsf$i$i5$i);
  $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($108)))));
  $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($111)))));
  $118 = Math_fround($fabsf$i$i6$i + $fabsf$i$i7$i);
  $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($114)))));
  $119 = Math_fround($118 + $fabsf$i$i8$i);
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($109)))));
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($112)))));
  $120 = Math_fround($fabsf$i$i2$i + $fabsf$i$i1$i);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($115)))));
  $121 = Math_fround($120 + $fabsf$i$i$i);
  $122 = (($pose) + 16|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = Math_fround($123 - $117);
  $125 = (($pose) + 20|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = Math_fround($126 - $119);
  $128 = (($pose) + 24|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = Math_fround($129 - $121);
  $131 = Math_fround($124 - $contactOffset);
  $132 = Math_fround($127 - $contactOffset);
  $133 = Math_fround($130 - $contactOffset);
  HEAPF32[$bounds>>2] = $131;
  $134 = (($bounds) + 4|0);
  HEAPF32[$134>>2] = $132;
  $135 = (($bounds) + 8|0);
  HEAPF32[$135>>2] = $133;
  $136 = Math_fround(HEAPF32[$122>>2]);
  $137 = Math_fround($117 + $136);
  $138 = Math_fround(HEAPF32[$125>>2]);
  $139 = Math_fround($119 + $138);
  $140 = Math_fround(HEAPF32[$128>>2]);
  $141 = Math_fround($121 + $140);
  $142 = Math_fround($137 + $contactOffset);
  $143 = Math_fround($139 + $contactOffset);
  $144 = Math_fround($141 + $contactOffset);
  $145 = (($bounds) + 12|0);
  HEAPF32[$145>>2] = $142;
  $146 = (($bounds) + 16|0);
  HEAPF32[$146>>2] = $143;
  $147 = (($bounds) + 20|0);
  HEAPF32[$147>>2] = $144;
  STACKTOP = sp;return;
  break;
 }
 case 2:  {
  $24 = Math_fround(HEAPF32[$pose>>2]);
  $25 = Math_fround($24 * Math_fround(2.0));
  $26 = (($pose) + 12|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($27 * Math_fround(2.0));
  $29 = Math_fround($27 * $28);
  $30 = Math_fround($29 + Math_fround(-1.0));
  $31 = Math_fround($24 * $25);
  $32 = Math_fround($31 + $30);
  $33 = (($pose) + 8|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($34 * $28);
  $36 = (($pose) + 4|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($25 * $37);
  $39 = Math_fround($35 + $38);
  $40 = Math_fround($28 * $37);
  $41 = Math_fround($25 * $34);
  $42 = Math_fround($41 - $40);
  $43 = (($this) + 8|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($this) + 4|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($32)))));
  $47 = Math_fround($fabsf$i$i * $44);
  $48 = Math_fround($47 + $46);
  $49 = Math_fround($48 + $contactOffset);
  $fabsf$i$i$1 = (Math_fround(Math_abs((Math_fround($39)))));
  $50 = Math_fround($fabsf$i$i$1 * $44);
  $51 = Math_fround($50 + $46);
  $52 = Math_fround($51 + $contactOffset);
  $fabsf$i$i$2 = (Math_fround(Math_abs((Math_fround($42)))));
  $53 = Math_fround($fabsf$i$i$2 * $44);
  $54 = Math_fround($53 + $46);
  $55 = Math_fround($54 + $contactOffset);
  $56 = (($pose) + 16|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($57 - $49);
  $59 = (($pose) + 20|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($60 - $52);
  $62 = (($pose) + 24|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($63 - $55);
  HEAPF32[$bounds>>2] = $58;
  $65 = (($bounds) + 4|0);
  HEAPF32[$65>>2] = $61;
  $66 = (($bounds) + 8|0);
  HEAPF32[$66>>2] = $64;
  $67 = Math_fround(HEAPF32[$56>>2]);
  $68 = Math_fround($67 + $49);
  $69 = Math_fround(HEAPF32[$59>>2]);
  $70 = Math_fround($69 + $52);
  $71 = Math_fround(HEAPF32[$62>>2]);
  $72 = Math_fround($71 + $55);
  $73 = (($bounds) + 12|0);
  HEAPF32[$73>>2] = $68;
  $74 = (($bounds) + 16|0);
  HEAPF32[$74>>2] = $70;
  $75 = (($bounds) + 20|0);
  HEAPF32[$75>>2] = $72;
  STACKTOP = sp;return;
  break;
 }
 case 6:  {
  $213 = (($this) + 12|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = (($this) + 8|0);
  $216 = Math_fround(HEAPF32[$215>>2]);
  $217 = (($this) + 16|0);
  $218 = Math_fround(HEAPF32[$217>>2]);
  HEAPF32[$scale>>2] = $214;
  $219 = (($scale) + 4|0);
  HEAPF32[$219>>2] = $216;
  $220 = (($scale) + 8|0);
  HEAPF32[$220>>2] = $218;
  $221 = (($scale) + 12|0);
  HEAPF32[$221>>2] = Math_fround(0.0);
  $222 = (($scale) + 16|0);
  HEAPF32[$222>>2] = Math_fround(0.0);
  $223 = (($scale) + 20|0);
  HEAPF32[$223>>2] = Math_fround(0.0);
  $224 = (($scale) + 24|0);
  HEAPF32[$224>>2] = Math_fround(1.0);
  $225 = ($localSpaceBounds|0)==(0|0);
  if ($225) {
   $228 = (($this) + 24|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = (($229) + 40|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$230,$scale,$origin14,$extents15);
   $$pn = $229;
  } else {
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$localSpaceBounds,$scale,$origin14,$extents15);
   $226 = (($this) + 24|0);
   $227 = HEAP32[$226>>2]|0;
   $$pn = $227;
  }
  $thickness$0$in = (($$pn) + 24|0);
  $thickness$0 = Math_fround(HEAPF32[$thickness$0$in>>2]);
  $231 = Math_fround(HEAPF32[$origin14>>2]);
  $232 = Math_fround(HEAPF32[$extents15>>2]);
  $233 = Math_fround($231 - $232);
  $234 = (($origin14) + 4|0);
  $235 = Math_fround(HEAPF32[$234>>2]);
  $236 = (($extents15) + 4|0);
  $237 = Math_fround(HEAPF32[$236>>2]);
  $238 = Math_fround($235 - $237);
  $239 = (($origin14) + 8|0);
  $240 = Math_fround(HEAPF32[$239>>2]);
  $241 = (($extents15) + 8|0);
  $242 = Math_fround(HEAPF32[$241>>2]);
  $243 = Math_fround($240 - $242);
  $244 = Math_fround($233 - $contactOffset);
  $245 = Math_fround($238 - $contactOffset);
  $246 = Math_fround($243 - $contactOffset);
  HEAPF32[$bounds>>2] = $244;
  $247 = (($bounds) + 4|0);
  HEAPF32[$247>>2] = $245;
  $248 = (($bounds) + 8|0);
  HEAPF32[$248>>2] = $246;
  $249 = Math_fround($231 + $232);
  $250 = Math_fround($235 + $237);
  $251 = Math_fround($240 + $242);
  $252 = Math_fround($249 + $contactOffset);
  $253 = Math_fround($250 + $contactOffset);
  $254 = Math_fround($251 + $contactOffset);
  $255 = (($bounds) + 12|0);
  HEAPF32[$255>>2] = $252;
  $256 = (($bounds) + 16|0);
  HEAPF32[$256>>2] = $253;
  $257 = (($bounds) + 20|0);
  HEAPF32[$257>>2] = $254;
  $258 = $thickness$0 < Math_fround(0.0);
  if ($258) {
   $259 = Math_fround($thickness$0 + $245);
   HEAPF32[$247>>2] = $259;
   STACKTOP = sp;return;
  } else {
   $260 = Math_fround($thickness$0 + $253);
   HEAPF32[$256>>2] = $260;
   STACKTOP = sp;return;
  }
  break;
 }
 case 1:  {
  __ZL18computePlaneBoundsRN5physx9PxBounds3ERKNS_11PxTransformEf($bounds,$pose,$contactOffset);
  STACKTOP = sp;return;
  break;
 }
 case 5:  {
  $180 = ($localSpaceBounds|0)==(0|0);
  if ($180) {
   $182 = (($this) + 40|0);
   $183 = HEAP32[$182>>2]|0;
   $184 = (($183) + 128|0);
   $185 = (($this) + 4|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$184,$185,$origin9,$extents10);
  } else {
   $181 = (($this) + 4|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$localSpaceBounds,$181,$origin9,$extents10);
  }
  $186 = Math_fround(HEAPF32[$origin9>>2]);
  $187 = Math_fround(HEAPF32[$extents10>>2]);
  $188 = Math_fround($186 - $187);
  $189 = (($origin9) + 4|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($extents10) + 4|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = Math_fround($190 - $192);
  $194 = (($origin9) + 8|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($extents10) + 8|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = Math_fround($195 - $197);
  $199 = Math_fround($188 - $contactOffset);
  $200 = Math_fround($193 - $contactOffset);
  $201 = Math_fround($198 - $contactOffset);
  HEAPF32[$bounds>>2] = $199;
  $202 = (($bounds) + 4|0);
  HEAPF32[$202>>2] = $200;
  $203 = (($bounds) + 8|0);
  HEAPF32[$203>>2] = $201;
  $204 = Math_fround($186 + $187);
  $205 = Math_fround($190 + $192);
  $206 = Math_fround($195 + $197);
  $207 = Math_fround($204 + $contactOffset);
  $208 = Math_fround($205 + $contactOffset);
  $209 = Math_fround($206 + $contactOffset);
  $210 = (($bounds) + 12|0);
  HEAPF32[$210>>2] = $207;
  $211 = (($bounds) + 16|0);
  HEAPF32[$211>>2] = $208;
  $212 = (($bounds) + 20|0);
  HEAPF32[$212>>2] = $209;
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  $148 = ($localSpaceBounds|0)==(0|0);
  if ($148) {
   $150 = (($this) + 36|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (($this) + 4|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$151,$152,$origin,$extents6);
  } else {
   $149 = (($this) + 4|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$localSpaceBounds,$149,$origin,$extents6);
  }
  $153 = Math_fround(HEAPF32[$origin>>2]);
  $154 = Math_fround(HEAPF32[$extents6>>2]);
  $155 = Math_fround($153 - $154);
  $156 = (($origin) + 4|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = (($extents6) + 4|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = Math_fround($157 - $159);
  $161 = (($origin) + 8|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = (($extents6) + 8|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = Math_fround($162 - $164);
  $166 = Math_fround($155 - $contactOffset);
  $167 = Math_fround($160 - $contactOffset);
  $168 = Math_fround($165 - $contactOffset);
  HEAPF32[$bounds>>2] = $166;
  $169 = (($bounds) + 4|0);
  HEAPF32[$169>>2] = $167;
  $170 = (($bounds) + 8|0);
  HEAPF32[$170>>2] = $168;
  $171 = Math_fround($153 + $154);
  $172 = Math_fround($157 + $159);
  $173 = Math_fround($162 + $164);
  $174 = Math_fround($171 + $contactOffset);
  $175 = Math_fround($172 + $contactOffset);
  $176 = Math_fround($173 + $contactOffset);
  $177 = (($bounds) + 12|0);
  HEAPF32[$177>>2] = $174;
  $178 = (($bounds) + 16|0);
  HEAPF32[$178>>2] = $175;
  $179 = (($bounds) + 20|0);
  HEAPF32[$179>>2] = $176;
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  $1 = (($this) + 4|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $3 = Math_fround($2 + $contactOffset);
  $4 = (($pose) + 16|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = Math_fround($5 - $3);
  $7 = (($pose) + 20|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround($8 - $3);
  $10 = (($pose) + 24|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($11 - $3);
  HEAPF32[$bounds>>2] = $6;
  $13 = (($bounds) + 4|0);
  HEAPF32[$13>>2] = $9;
  $14 = (($bounds) + 8|0);
  HEAPF32[$14>>2] = $12;
  $15 = Math_fround(HEAPF32[$4>>2]);
  $16 = Math_fround($3 + $15);
  $17 = Math_fround(HEAPF32[$7>>2]);
  $18 = Math_fround($3 + $17);
  $19 = Math_fround(HEAPF32[$10>>2]);
  $20 = Math_fround($3 + $19);
  $21 = (($bounds) + 12|0);
  HEAPF32[$21>>2] = $16;
  $22 = (($bounds) + 16|0);
  HEAPF32[$22>>2] = $18;
  $23 = (($bounds) + 20|0);
  HEAPF32[$23>>2] = $20;
  STACKTOP = sp;return;
  break;
 }
 default: {
  $261 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($261,32,547888,314,547968,$vararg_buffer);
  STACKTOP = sp;return;
 }
 }
}
function __ZL18computePlaneBoundsRN5physx9PxBounds3ERKNS_11PxTransformEf($bounds,$pose,$contactOffset) {
 $bounds = $bounds|0;
 $pose = $pose|0;
 $contactOffset = Math_fround($contactOffset);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i6 = Math_fround(0), $fabsf$i$i7 = Math_fround(0);
 var $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$pose>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($pose) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($pose) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($pose) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($pose) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = (($pose) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($15 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($pose) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($18 * $27);
 $29 = Math_fround($25 + $28);
 $30 = Math_fround(-$29);
 $fabsf$i$i7 = (Math_fround(Math_abs((Math_fround($8)))));
 $fabsf$i$i6 = (Math_fround(Math_abs((Math_fround($15)))));
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($18)))));
 $31 = $fabsf$i$i7 > Math_fround(0.999998986721038818359);
 $32 = $fabsf$i$i6 < Math_fround(9.99999997475242707878E-7);
 $or$cond = $31 & $32;
 $33 = $fabsf$i$i < Math_fround(9.99999997475242707878E-7);
 $or$cond1 = $or$cond & $33;
 do {
  if ($or$cond1) {
   $34 = $8 > Math_fround(0.0);
   if ($34) {
    $41 = Math_fround(-8.50705866596322149529E+37);$43 = Math_fround(-8.50705866596322149529E+37);$45 = Math_fround(-8.50705866596322149529E+37);$49 = $29;$51 = Math_fround(8.50705866596322149529E+37);$53 = Math_fround(8.50705866596322149529E+37);
   } else {
    $41 = $30;$43 = Math_fround(-8.50705866596322149529E+37);$45 = Math_fround(-8.50705866596322149529E+37);$49 = Math_fround(8.50705866596322149529E+37);$51 = Math_fround(8.50705866596322149529E+37);$53 = Math_fround(8.50705866596322149529E+37);
   }
  } else {
   $35 = $fabsf$i$i7 < Math_fround(9.99999997475242707878E-7);
   $36 = $fabsf$i$i6 > Math_fround(0.999998986721038818359);
   $or$cond2 = $35 & $36;
   $or$cond3 = $or$cond2 & $33;
   if ($or$cond3) {
    $37 = $15 > Math_fround(0.0);
    if ($37) {
     $41 = Math_fround(-8.50705866596322149529E+37);$43 = Math_fround(-8.50705866596322149529E+37);$45 = Math_fround(-8.50705866596322149529E+37);$49 = Math_fround(8.50705866596322149529E+37);$51 = $29;$53 = Math_fround(8.50705866596322149529E+37);
     break;
    }
    $41 = Math_fround(-8.50705866596322149529E+37);$43 = $30;$45 = Math_fround(-8.50705866596322149529E+37);$49 = Math_fround(8.50705866596322149529E+37);$51 = Math_fround(8.50705866596322149529E+37);$53 = Math_fround(8.50705866596322149529E+37);
    break;
   }
   $or$cond4 = $35 & $32;
   $38 = $fabsf$i$i > Math_fround(0.999998986721038818359);
   $or$cond5 = $or$cond4 & $38;
   if ($or$cond5) {
    $39 = $18 > Math_fround(0.0);
    if ($39) {
     $41 = Math_fround(-8.50705866596322149529E+37);$43 = Math_fround(-8.50705866596322149529E+37);$45 = Math_fround(-8.50705866596322149529E+37);$49 = Math_fround(8.50705866596322149529E+37);$51 = Math_fround(8.50705866596322149529E+37);$53 = $29;
    } else {
     $41 = Math_fround(-8.50705866596322149529E+37);$43 = Math_fround(-8.50705866596322149529E+37);$45 = $30;$49 = Math_fround(8.50705866596322149529E+37);$51 = Math_fround(8.50705866596322149529E+37);$53 = Math_fround(8.50705866596322149529E+37);
    }
   } else {
    $41 = Math_fround(-8.50705866596322149529E+37);$43 = Math_fround(-8.50705866596322149529E+37);$45 = Math_fround(-8.50705866596322149529E+37);$49 = Math_fround(8.50705866596322149529E+37);$51 = Math_fround(8.50705866596322149529E+37);$53 = Math_fround(8.50705866596322149529E+37);
   }
  }
 } while(0);
 $40 = Math_fround($41 - $contactOffset);
 $42 = Math_fround($43 - $contactOffset);
 $44 = Math_fround($45 - $contactOffset);
 HEAPF32[$bounds>>2] = $40;
 $46 = (($bounds) + 4|0);
 HEAPF32[$46>>2] = $42;
 $47 = (($bounds) + 8|0);
 HEAPF32[$47>>2] = $44;
 $48 = Math_fround($49 + $contactOffset);
 $50 = Math_fround($51 + $contactOffset);
 $52 = Math_fround($53 + $contactOffset);
 $54 = (($bounds) + 12|0);
 HEAPF32[$54>>2] = $48;
 $55 = (($bounds) + 16|0);
 HEAPF32[$55>>2] = $50;
 $56 = (($bounds) + 20|0);
 HEAPF32[$56>>2] = $52;
 STACKTOP = sp;return;
}
function __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$localSpaceBounds,$meshScale,$origin,$extent) {
 $pose = $pose|0;
 $localSpaceBounds = $localSpaceBounds|0;
 $meshScale = $meshScale|0;
 $origin = $origin|0;
 $extent = $extent|0;
 var $$phi$trans$insert$i = 0, $$pre$i = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0;
 var $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0);
 var $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i$i$i = Math_fround(0), $fabsf$i$i$i$i10$i = Math_fround(0), $fabsf$i$i1$i$i$i = Math_fround(0), $fabsf$i$i1$i$i9$i = Math_fround(0), $fabsf$i$i2$i$i$i = Math_fround(0), $fabsf$i$i2$i$i8$i = Math_fround(0), $fabsf$i$i3$i$i$i = Math_fround(0), $fabsf$i$i3$i$i2$i = Math_fround(0), $fabsf$i$i4$i$i$i = Math_fround(0), $fabsf$i$i4$i$i3$i = Math_fround(0), $fabsf$i$i5$i$i$i = Math_fround(0), $fabsf$i$i5$i$i4$i = Math_fround(0), $fabsf$i$i6$i$i$i = Math_fround(0);
 var $fabsf$i$i6$i$i5$i = Math_fround(0), $fabsf$i$i7$i$i$i = Math_fround(0), $fabsf$i$i7$i$i6$i = Math_fround(0), $fabsf$i$i8$i$i$i = Math_fround(0), $fabsf$i$i8$i$i7$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$meshScale>>2]);
 $1 = $0 == Math_fround(1.0);
 if ($1) {
  $2 = (($meshScale) + 4|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = $3 == Math_fround(1.0);
  if ($4) {
   $5 = (($meshScale) + 8|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = $6 == Math_fround(1.0);
   if ($7) {
    $8 = Math_fround(HEAPF32[$pose>>2]);
    $9 = Math_fround($8 + $8);
    $10 = (($pose) + 4|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    $12 = Math_fround($11 + $11);
    $13 = (($pose) + 8|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $15 = Math_fround($14 + $14);
    $16 = (($pose) + 12|0);
    $17 = Math_fround(HEAPF32[$16>>2]);
    $18 = Math_fround($9 * $17);
    $19 = Math_fround($12 * $17);
    $20 = Math_fround($17 * $15);
    $21 = Math_fround($8 * $9);
    $22 = Math_fround($8 * $12);
    $23 = Math_fround($8 * $15);
    $24 = Math_fround($11 * $12);
    $25 = Math_fround($11 * $15);
    $26 = Math_fround($14 * $15);
    $27 = Math_fround(Math_fround(1.0) - $24);
    $28 = Math_fround($27 - $26);
    $29 = Math_fround($22 + $20);
    $30 = Math_fround($23 - $19);
    $31 = Math_fround($22 - $20);
    $32 = Math_fround(Math_fround(1.0) - $21);
    $33 = Math_fround($32 - $26);
    $34 = Math_fround($25 + $18);
    $35 = Math_fround($23 + $19);
    $36 = Math_fround($25 - $18);
    $37 = Math_fround($32 - $24);
    $38 = (($pose) + 16|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = (($pose) + 20|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = (($pose) + 24|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = Math_fround(HEAPF32[$localSpaceBounds>>2]);
    $45 = (($localSpaceBounds) + 12|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = Math_fround($44 + $46);
    $48 = (($localSpaceBounds) + 4|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = (($localSpaceBounds) + 16|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = Math_fround($49 + $51);
    $53 = (($localSpaceBounds) + 8|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = (($localSpaceBounds) + 20|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = Math_fround($54 + $56);
    $58 = Math_fround($47 * Math_fround(0.5));
    $59 = Math_fround($52 * Math_fround(0.5));
    $60 = Math_fround($57 * Math_fround(0.5));
    $61 = Math_fround($28 * $58);
    $62 = Math_fround($29 * $58);
    $63 = Math_fround($30 * $58);
    $64 = Math_fround($31 * $59);
    $65 = Math_fround($33 * $59);
    $66 = Math_fround($34 * $59);
    $67 = Math_fround($61 + $64);
    $68 = Math_fround($62 + $65);
    $69 = Math_fround($63 + $66);
    $70 = Math_fround($35 * $60);
    $71 = Math_fround($36 * $60);
    $72 = Math_fround($37 * $60);
    $73 = Math_fround($67 + $70);
    $74 = Math_fround($68 + $71);
    $75 = Math_fround($69 + $72);
    $76 = Math_fround($39 + $73);
    $77 = Math_fround($41 + $74);
    $78 = Math_fround($43 + $75);
    HEAPF32[$origin>>2] = $76;
    $79 = (($origin) + 4|0);
    HEAPF32[$79>>2] = $77;
    $80 = (($origin) + 8|0);
    HEAPF32[$80>>2] = $78;
    $81 = Math_fround(HEAPF32[$45>>2]);
    $82 = Math_fround(HEAPF32[$localSpaceBounds>>2]);
    $83 = Math_fround($81 - $82);
    $84 = Math_fround(HEAPF32[$50>>2]);
    $85 = Math_fround(HEAPF32[$48>>2]);
    $86 = Math_fround($84 - $85);
    $87 = Math_fround(HEAPF32[$55>>2]);
    $88 = Math_fround(HEAPF32[$53>>2]);
    $89 = Math_fround($87 - $88);
    $90 = Math_fround($83 * Math_fround(0.5));
    $91 = Math_fround($86 * Math_fround(0.5));
    $92 = Math_fround($89 * Math_fround(0.5));
    $93 = Math_fround($28 * $90);
    $94 = Math_fround($29 * $90);
    $95 = Math_fround($30 * $90);
    $96 = Math_fround($31 * $91);
    $97 = Math_fround($33 * $91);
    $98 = Math_fround($34 * $91);
    $99 = Math_fround($35 * $92);
    $100 = Math_fround($36 * $92);
    $101 = Math_fround($37 * $92);
    $fabsf$i$i3$i$i2$i = (Math_fround(Math_abs((Math_fround($93)))));
    $fabsf$i$i4$i$i3$i = (Math_fround(Math_abs((Math_fround($96)))));
    $102 = Math_fround($fabsf$i$i3$i$i2$i + $fabsf$i$i4$i$i3$i);
    $fabsf$i$i5$i$i4$i = (Math_fround(Math_abs((Math_fround($99)))));
    $103 = Math_fround($102 + $fabsf$i$i5$i$i4$i);
    HEAPF32[$extent>>2] = $103;
    $fabsf$i$i6$i$i5$i = (Math_fround(Math_abs((Math_fround($94)))));
    $fabsf$i$i7$i$i6$i = (Math_fround(Math_abs((Math_fround($97)))));
    $104 = Math_fround($fabsf$i$i6$i$i5$i + $fabsf$i$i7$i$i6$i);
    $fabsf$i$i8$i$i7$i = (Math_fround(Math_abs((Math_fround($100)))));
    $105 = Math_fround($104 + $fabsf$i$i8$i$i7$i);
    $106 = (($extent) + 4|0);
    HEAPF32[$106>>2] = $105;
    $fabsf$i$i2$i$i8$i = (Math_fround(Math_abs((Math_fround($95)))));
    $fabsf$i$i1$i$i9$i = (Math_fround(Math_abs((Math_fround($98)))));
    $107 = Math_fround($fabsf$i$i2$i$i8$i + $fabsf$i$i1$i$i9$i);
    $fabsf$i$i$i$i10$i = (Math_fround(Math_abs((Math_fround($101)))));
    $108 = Math_fround($107 + $fabsf$i$i$i$i10$i);
    $109 = (($extent) + 8|0);
    HEAPF32[$109>>2] = $108;
    STACKTOP = sp;return;
   } else {
    $175 = $3;
   }
  } else {
   $175 = $3;
  }
 } else {
  $$phi$trans$insert$i = (($meshScale) + 4|0);
  $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
  $175 = $$pre$i;
 }
 $110 = Math_fround(HEAPF32[$pose>>2]);
 $111 = (($pose) + 4|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($pose) + 8|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($pose) + 12|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($110 + $110);
 $118 = Math_fround($112 + $112);
 $119 = Math_fround($114 + $114);
 $120 = Math_fround($110 * $117);
 $121 = Math_fround($112 * $118);
 $122 = Math_fround($114 * $119);
 $123 = Math_fround($117 * $112);
 $124 = Math_fround($117 * $114);
 $125 = Math_fround($117 * $116);
 $126 = Math_fround($118 * $114);
 $127 = Math_fround($118 * $116);
 $128 = Math_fround($119 * $116);
 $129 = Math_fround(Math_fround(1.0) - $121);
 $130 = Math_fround($129 - $122);
 $131 = Math_fround($123 + $128);
 $132 = Math_fround($124 - $127);
 $133 = Math_fround($123 - $128);
 $134 = Math_fround(Math_fround(1.0) - $120);
 $135 = Math_fround($134 - $122);
 $136 = Math_fround($126 + $125);
 $137 = Math_fround($124 + $127);
 $138 = Math_fround($126 - $125);
 $139 = Math_fround($134 - $121);
 $140 = (($meshScale) + 12|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($meshScale) + 16|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($meshScale) + 20|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($meshScale) + 24|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = Math_fround($141 + $141);
 $149 = Math_fround($143 + $143);
 $150 = Math_fround($145 + $145);
 $151 = Math_fround($141 * $148);
 $152 = Math_fround($143 * $149);
 $153 = Math_fround($145 * $150);
 $154 = Math_fround($148 * $143);
 $155 = Math_fround($148 * $145);
 $156 = Math_fround($148 * $147);
 $157 = Math_fround($149 * $145);
 $158 = Math_fround($149 * $147);
 $159 = Math_fround($150 * $147);
 $160 = Math_fround(Math_fround(1.0) - $152);
 $161 = Math_fround($160 - $153);
 $162 = Math_fround($154 + $159);
 $163 = Math_fround($155 - $158);
 $164 = Math_fround($154 - $159);
 $165 = Math_fround(Math_fround(1.0) - $151);
 $166 = Math_fround($165 - $153);
 $167 = Math_fround($157 + $156);
 $168 = Math_fround($155 + $158);
 $169 = Math_fround($157 - $156);
 $170 = Math_fround($165 - $152);
 $171 = Math_fround($0 * $161);
 $172 = Math_fround($0 * $164);
 $173 = Math_fround($0 * $168);
 $174 = Math_fround($175 * $162);
 $176 = Math_fround($175 * $166);
 $177 = Math_fround($175 * $169);
 $178 = (($meshScale) + 8|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround($179 * $163);
 $181 = Math_fround($179 * $167);
 $182 = Math_fround($170 * $179);
 $183 = Math_fround($161 * $171);
 $184 = Math_fround($161 * $172);
 $185 = Math_fround($161 * $173);
 $186 = Math_fround($162 * $174);
 $187 = Math_fround($162 * $176);
 $188 = Math_fround($162 * $177);
 $189 = Math_fround($183 + $186);
 $190 = Math_fround($184 + $187);
 $191 = Math_fround($185 + $188);
 $192 = Math_fround($163 * $180);
 $193 = Math_fround($163 * $181);
 $194 = Math_fround($163 * $182);
 $195 = Math_fround($192 + $189);
 $196 = Math_fround($193 + $190);
 $197 = Math_fround($194 + $191);
 $198 = Math_fround($164 * $171);
 $199 = Math_fround($164 * $172);
 $200 = Math_fround($164 * $173);
 $201 = Math_fround($166 * $174);
 $202 = Math_fround($166 * $176);
 $203 = Math_fround($166 * $177);
 $204 = Math_fround($198 + $201);
 $205 = Math_fround($199 + $202);
 $206 = Math_fround($200 + $203);
 $207 = Math_fround($167 * $180);
 $208 = Math_fround($167 * $181);
 $209 = Math_fround($167 * $182);
 $210 = Math_fround($207 + $204);
 $211 = Math_fround($208 + $205);
 $212 = Math_fround($209 + $206);
 $213 = Math_fround($168 * $171);
 $214 = Math_fround($168 * $172);
 $215 = Math_fround($168 * $173);
 $216 = Math_fround($169 * $174);
 $217 = Math_fround($169 * $176);
 $218 = Math_fround($169 * $177);
 $219 = Math_fround($213 + $216);
 $220 = Math_fround($214 + $217);
 $221 = Math_fround($215 + $218);
 $222 = Math_fround($170 * $180);
 $223 = Math_fround($170 * $181);
 $224 = Math_fround($170 * $182);
 $225 = Math_fround($222 + $219);
 $226 = Math_fround($223 + $220);
 $227 = Math_fround($224 + $221);
 $228 = Math_fround($130 * $195);
 $229 = Math_fround($131 * $195);
 $230 = Math_fround($132 * $195);
 $231 = Math_fround($133 * $196);
 $232 = Math_fround($135 * $196);
 $233 = Math_fround($136 * $196);
 $234 = Math_fround($228 + $231);
 $235 = Math_fround($229 + $232);
 $236 = Math_fround($230 + $233);
 $237 = Math_fround($137 * $197);
 $238 = Math_fround($138 * $197);
 $239 = Math_fround($139 * $197);
 $240 = Math_fround($237 + $234);
 $241 = Math_fround($238 + $235);
 $242 = Math_fround($239 + $236);
 $243 = Math_fround($130 * $210);
 $244 = Math_fround($131 * $210);
 $245 = Math_fround($132 * $210);
 $246 = Math_fround($133 * $211);
 $247 = Math_fround($135 * $211);
 $248 = Math_fround($136 * $211);
 $249 = Math_fround($243 + $246);
 $250 = Math_fround($244 + $247);
 $251 = Math_fround($245 + $248);
 $252 = Math_fround($137 * $212);
 $253 = Math_fround($138 * $212);
 $254 = Math_fround($139 * $212);
 $255 = Math_fround($252 + $249);
 $256 = Math_fround($253 + $250);
 $257 = Math_fround($254 + $251);
 $258 = Math_fround($130 * $225);
 $259 = Math_fround($131 * $225);
 $260 = Math_fround($132 * $225);
 $261 = Math_fround($133 * $226);
 $262 = Math_fround($135 * $226);
 $263 = Math_fround($136 * $226);
 $264 = Math_fround($258 + $261);
 $265 = Math_fround($259 + $262);
 $266 = Math_fround($260 + $263);
 $267 = Math_fround($137 * $227);
 $268 = Math_fround($138 * $227);
 $269 = Math_fround($139 * $227);
 $270 = Math_fround($267 + $264);
 $271 = Math_fround($268 + $265);
 $272 = Math_fround($269 + $266);
 $273 = (($pose) + 16|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 $275 = (($pose) + 20|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 $277 = (($pose) + 24|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = Math_fround(HEAPF32[$localSpaceBounds>>2]);
 $280 = (($localSpaceBounds) + 12|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = Math_fround($279 + $281);
 $283 = (($localSpaceBounds) + 4|0);
 $284 = Math_fround(HEAPF32[$283>>2]);
 $285 = (($localSpaceBounds) + 16|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = Math_fround($284 + $286);
 $288 = (($localSpaceBounds) + 8|0);
 $289 = Math_fround(HEAPF32[$288>>2]);
 $290 = (($localSpaceBounds) + 20|0);
 $291 = Math_fround(HEAPF32[$290>>2]);
 $292 = Math_fround($289 + $291);
 $293 = Math_fround($282 * Math_fround(0.5));
 $294 = Math_fround($287 * Math_fround(0.5));
 $295 = Math_fround($292 * Math_fround(0.5));
 $296 = Math_fround($293 * $240);
 $297 = Math_fround($293 * $241);
 $298 = Math_fround($293 * $242);
 $299 = Math_fround($255 * $294);
 $300 = Math_fround($256 * $294);
 $301 = Math_fround($257 * $294);
 $302 = Math_fround($296 + $299);
 $303 = Math_fround($297 + $300);
 $304 = Math_fround($298 + $301);
 $305 = Math_fround($270 * $295);
 $306 = Math_fround($271 * $295);
 $307 = Math_fround($272 * $295);
 $308 = Math_fround($302 + $305);
 $309 = Math_fround($303 + $306);
 $310 = Math_fround($304 + $307);
 $311 = Math_fround($274 + $308);
 $312 = Math_fround($276 + $309);
 $313 = Math_fround($278 + $310);
 HEAPF32[$origin>>2] = $311;
 $314 = (($origin) + 4|0);
 HEAPF32[$314>>2] = $312;
 $315 = (($origin) + 8|0);
 HEAPF32[$315>>2] = $313;
 $316 = Math_fround(HEAPF32[$280>>2]);
 $317 = Math_fround(HEAPF32[$localSpaceBounds>>2]);
 $318 = Math_fround($316 - $317);
 $319 = Math_fround(HEAPF32[$285>>2]);
 $320 = Math_fround(HEAPF32[$283>>2]);
 $321 = Math_fround($319 - $320);
 $322 = Math_fround(HEAPF32[$290>>2]);
 $323 = Math_fround(HEAPF32[$288>>2]);
 $324 = Math_fround($322 - $323);
 $325 = Math_fround($318 * Math_fround(0.5));
 $326 = Math_fround($321 * Math_fround(0.5));
 $327 = Math_fround($324 * Math_fround(0.5));
 $328 = Math_fround($240 * $325);
 $329 = Math_fround($241 * $325);
 $330 = Math_fround($242 * $325);
 $331 = Math_fround($255 * $326);
 $332 = Math_fround($256 * $326);
 $333 = Math_fround($257 * $326);
 $334 = Math_fround($270 * $327);
 $335 = Math_fround($271 * $327);
 $336 = Math_fround($272 * $327);
 $fabsf$i$i3$i$i$i = (Math_fround(Math_abs((Math_fround($328)))));
 $fabsf$i$i4$i$i$i = (Math_fround(Math_abs((Math_fround($331)))));
 $337 = Math_fround($fabsf$i$i3$i$i$i + $fabsf$i$i4$i$i$i);
 $fabsf$i$i5$i$i$i = (Math_fround(Math_abs((Math_fround($334)))));
 $338 = Math_fround($337 + $fabsf$i$i5$i$i$i);
 HEAPF32[$extent>>2] = $338;
 $fabsf$i$i6$i$i$i = (Math_fround(Math_abs((Math_fround($329)))));
 $fabsf$i$i7$i$i$i = (Math_fround(Math_abs((Math_fround($332)))));
 $339 = Math_fround($fabsf$i$i6$i$i$i + $fabsf$i$i7$i$i$i);
 $fabsf$i$i8$i$i$i = (Math_fround(Math_abs((Math_fround($335)))));
 $340 = Math_fround($339 + $fabsf$i$i8$i$i$i);
 $341 = (($extent) + 4|0);
 HEAPF32[$341>>2] = $340;
 $fabsf$i$i2$i$i$i = (Math_fround(Math_abs((Math_fround($330)))));
 $fabsf$i$i1$i$i$i = (Math_fround(Math_abs((Math_fround($333)))));
 $342 = Math_fround($fabsf$i$i2$i$i$i + $fabsf$i$i1$i$i$i);
 $fabsf$i$i$i$i$i = (Math_fround(Math_abs((Math_fround($336)))));
 $343 = Math_fround($342 + $fabsf$i$i$i$i$i);
 $344 = (($extent) + 8|0);
 HEAPF32[$344>>2] = $343;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu13GeometryUnion29computeBoundsWithCCDThresholdERNS_6PxVec3ES3_RKNS_11PxTransformEPKNS_9PxBounds3E($this,$origin,$extent,$pose,$localSpaceBounds) {
 $this = $this|0;
 $origin = $origin|0;
 $extent = $extent|0;
 $pose = $pose|0;
 $localSpaceBounds = $localSpaceBounds|0;
 var $$0 = Math_fround(0), $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0;
 var $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0);
 var $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $bounds = 0;
 var $fabsf$i$i = Math_fround(0), $fabsf$i$i$1 = Math_fround(0), $fabsf$i$i$2 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $scale = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer = sp;
 $bounds = sp + 32|0;
 $scale = sp + 4|0;
 $0 = HEAP32[$this>>2]|0;
 switch ($0|0) {
 case 2:  {
  $42 = (($pose) + 16|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  HEAPF32[$origin>>2] = $43;
  $44 = (($pose) + 20|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($origin) + 4|0);
  HEAPF32[$46>>2] = $45;
  $47 = (($pose) + 24|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($origin) + 8|0);
  HEAPF32[$49>>2] = $48;
  $50 = Math_fround(HEAPF32[$pose>>2]);
  $51 = Math_fround($50 * Math_fround(2.0));
  $52 = (($pose) + 12|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($53 * Math_fround(2.0));
  $55 = Math_fround($53 * $54);
  $56 = Math_fround($55 + Math_fround(-1.0));
  $57 = Math_fround($50 * $51);
  $58 = Math_fround($57 + $56);
  $59 = (($pose) + 8|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($60 * $54);
  $62 = (($pose) + 4|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($51 * $63);
  $65 = Math_fround($61 + $64);
  $66 = Math_fround($54 * $63);
  $67 = Math_fround($51 * $60);
  $68 = Math_fround($67 - $66);
  $69 = (($this) + 8|0);
  $70 = (($this) + 4|0);
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($58)))));
  $71 = Math_fround(HEAPF32[$69>>2]);
  $72 = Math_fround($fabsf$i$i * $71);
  $73 = Math_fround(HEAPF32[$70>>2]);
  $74 = Math_fround($72 + $73);
  HEAPF32[$extent>>2] = $74;
  $fabsf$i$i$1 = (Math_fround(Math_abs((Math_fround($65)))));
  $75 = Math_fround(HEAPF32[$69>>2]);
  $76 = Math_fround($fabsf$i$i$1 * $75);
  $77 = Math_fround(HEAPF32[$70>>2]);
  $78 = Math_fround($76 + $77);
  $79 = (($extent) + 4|0);
  HEAPF32[$79>>2] = $78;
  $fabsf$i$i$2 = (Math_fround(Math_abs((Math_fround($68)))));
  $80 = Math_fround(HEAPF32[$69>>2]);
  $81 = Math_fround($fabsf$i$i$2 * $80);
  $82 = Math_fround(HEAPF32[$70>>2]);
  $83 = Math_fround($81 + $82);
  $84 = (($extent) + 8|0);
  HEAPF32[$84>>2] = $83;
  $85 = Math_fround(HEAPF32[$70>>2]);
  $86 = Math_fround($85 * Math_fround(0.75));
  $$0 = $86;
  STACKTOP = sp;return (Math_fround($$0));
  break;
 }
 case 6:  {
  $176 = (($this) + 12|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = (($this) + 8|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = (($this) + 16|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  HEAPF32[$scale>>2] = $177;
  $182 = (($scale) + 4|0);
  HEAPF32[$182>>2] = $179;
  $183 = (($scale) + 8|0);
  HEAPF32[$183>>2] = $181;
  $184 = (($scale) + 12|0);
  HEAPF32[$184>>2] = Math_fround(0.0);
  $185 = (($scale) + 16|0);
  HEAPF32[$185>>2] = Math_fround(0.0);
  $186 = (($scale) + 20|0);
  HEAPF32[$186>>2] = Math_fround(0.0);
  $187 = (($scale) + 24|0);
  HEAPF32[$187>>2] = Math_fround(1.0);
  $188 = ($localSpaceBounds|0)==(0|0);
  if ($188) {
   $189 = (($this) + 24|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = (($190) + 40|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$191,$scale,$origin,$extent);
   $$0 = Math_fround(0.0);
   STACKTOP = sp;return (Math_fround($$0));
  } else {
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$localSpaceBounds,$scale,$origin,$extent);
   $$0 = Math_fround(0.0);
   STACKTOP = sp;return (Math_fround($$0));
  }
  break;
 }
 case 4:  {
  $151 = (($this) + 36|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = ($localSpaceBounds|0)==(0|0);
  if ($153) {
   $155 = (($this) + 4|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$152,$155,$origin,$extent);
  } else {
   $154 = (($this) + 4|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$localSpaceBounds,$154,$origin,$extent);
  }
  $156 = (($this) + 12|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = (($this) + 4|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = (($this) + 8|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = $159 < $161;
  $163 = $162 ? $159 : $161;
  $164 = $157 < $163;
  $165 = $164 ? $157 : $163;
  $166 = (($152) + 48|0);
  $167 = Math_fround(HEAPF32[$166>>2]);
  $168 = Math_fround($167 * $165);
  $169 = Math_fround($168 * Math_fround(0.75));
  $$0 = $169;
  STACKTOP = sp;return (Math_fround($$0));
  break;
 }
 case 0:  {
  $1 = (($pose) + 16|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$origin>>2] = $2;
  $3 = (($pose) + 20|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($origin) + 4|0);
  HEAPF32[$5>>2] = $4;
  $6 = (($pose) + 24|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($origin) + 8|0);
  HEAPF32[$8>>2] = $7;
  $9 = (($this) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$extent>>2] = $10;
  $11 = (($extent) + 4|0);
  HEAPF32[$11>>2] = $10;
  $12 = (($extent) + 8|0);
  HEAPF32[$12>>2] = $10;
  $13 = Math_fround(HEAPF32[$9>>2]);
  $14 = Math_fround($13 * Math_fround(0.75));
  $$0 = $14;
  STACKTOP = sp;return (Math_fround($$0));
  break;
 }
 case 3:  {
  $87 = Math_fround(HEAPF32[$pose>>2]);
  $88 = (($pose) + 4|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = (($pose) + 8|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = (($pose) + 12|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = Math_fround($87 + $87);
  $95 = Math_fround($89 + $89);
  $96 = Math_fround($91 + $91);
  $97 = Math_fround($87 * $94);
  $98 = Math_fround($89 * $95);
  $99 = Math_fround($91 * $96);
  $100 = Math_fround($94 * $89);
  $101 = Math_fround($94 * $91);
  $102 = Math_fround($94 * $93);
  $103 = Math_fround($95 * $91);
  $104 = Math_fround($95 * $93);
  $105 = Math_fround($96 * $93);
  $106 = Math_fround(Math_fround(1.0) - $98);
  $107 = Math_fround($106 - $99);
  $108 = Math_fround($100 + $105);
  $109 = Math_fround($101 - $104);
  $110 = Math_fround($100 - $105);
  $111 = Math_fround(Math_fround(1.0) - $97);
  $112 = Math_fround($111 - $99);
  $113 = Math_fround($103 + $102);
  $114 = Math_fround($101 + $104);
  $115 = Math_fround($103 - $102);
  $116 = Math_fround($111 - $98);
  $117 = (($this) + 4|0);
  $$idx$val = Math_fround(HEAPF32[$117>>2]);
  $$idx1 = (($this) + 8|0);
  $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
  $$idx2 = (($this) + 12|0);
  $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
  $118 = Math_fround($$idx$val * $107);
  $119 = Math_fround($$idx$val * $108);
  $120 = Math_fround($$idx$val * $109);
  $121 = Math_fround($110 * $$idx1$val);
  $122 = Math_fround($112 * $$idx1$val);
  $123 = Math_fround($113 * $$idx1$val);
  $124 = Math_fround($114 * $$idx2$val);
  $125 = Math_fround($115 * $$idx2$val);
  $126 = Math_fround($116 * $$idx2$val);
  $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($118)))));
  $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($121)))));
  $127 = Math_fround($fabsf$i$i3$i + $fabsf$i$i4$i);
  $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($124)))));
  $128 = Math_fround($127 + $fabsf$i$i5$i);
  HEAPF32[$extent>>2] = $128;
  $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($119)))));
  $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($122)))));
  $129 = Math_fround($fabsf$i$i6$i + $fabsf$i$i7$i);
  $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($125)))));
  $130 = Math_fround($129 + $fabsf$i$i8$i);
  $131 = (($extent) + 4|0);
  HEAPF32[$131>>2] = $130;
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($120)))));
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($123)))));
  $132 = Math_fround($fabsf$i$i2$i + $fabsf$i$i1$i);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($126)))));
  $133 = Math_fround($132 + $fabsf$i$i$i);
  $134 = (($extent) + 8|0);
  HEAPF32[$134>>2] = $133;
  $135 = (($pose) + 16|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  HEAPF32[$origin>>2] = $136;
  $137 = (($pose) + 20|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = (($origin) + 4|0);
  HEAPF32[$139>>2] = $138;
  $140 = (($pose) + 24|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = (($origin) + 8|0);
  HEAPF32[$142>>2] = $141;
  $143 = Math_fround(HEAPF32[$117>>2]);
  $144 = Math_fround(HEAPF32[$$idx1>>2]);
  $145 = $143 < $144;
  $146 = $145 ? $143 : $144;
  $147 = Math_fround(HEAPF32[$$idx2>>2]);
  $148 = $146 < $147;
  $149 = $148 ? $146 : $147;
  $150 = Math_fround($149 * Math_fround(0.75));
  $$0 = $150;
  STACKTOP = sp;return (Math_fround($$0));
  break;
 }
 case 1:  {
  __ZL18computePlaneBoundsRN5physx9PxBounds3ERKNS_11PxTransformEf($bounds,$pose,Math_fround(0.0));
  $15 = Math_fround(HEAPF32[$bounds>>2]);
  $16 = (($bounds) + 12|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($15 + $17);
  $19 = (($bounds) + 4|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($bounds) + 16|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($20 + $22);
  $24 = (($bounds) + 8|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($bounds) + 20|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($25 + $27);
  $29 = Math_fround($18 * Math_fround(0.5));
  $30 = Math_fround($23 * Math_fround(0.5));
  $31 = Math_fround($28 * Math_fround(0.5));
  HEAPF32[$origin>>2] = $29;
  $32 = (($origin) + 4|0);
  HEAPF32[$32>>2] = $30;
  $33 = (($origin) + 8|0);
  HEAPF32[$33>>2] = $31;
  $34 = Math_fround($17 - $15);
  $35 = Math_fround($22 - $20);
  $36 = Math_fround($27 - $25);
  $37 = Math_fround($34 * Math_fround(0.5));
  $38 = Math_fround($35 * Math_fround(0.5));
  $39 = Math_fround($36 * Math_fround(0.5));
  HEAPF32[$extent>>2] = $37;
  $40 = (($extent) + 4|0);
  HEAPF32[$40>>2] = $38;
  $41 = (($extent) + 8|0);
  HEAPF32[$41>>2] = $39;
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
  break;
 }
 case 5:  {
  $170 = ($localSpaceBounds|0)==(0|0);
  if ($170) {
   $172 = (($this) + 40|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = (($173) + 128|0);
   $175 = (($this) + 4|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$174,$175,$origin,$extent);
   $$0 = Math_fround(0.0);
   STACKTOP = sp;return (Math_fround($$0));
  } else {
   $171 = (($this) + 4|0);
   __ZL17computeMeshBoundsRKN5physx11PxTransformEPKNS_9PxBounds3ERKNS_11PxMeshScaleERNS_6PxVec3ESA_($pose,$localSpaceBounds,$171,$origin,$extent);
   $$0 = Math_fround(0.0);
   STACKTOP = sp;return (Math_fround($$0));
  }
  break;
 }
 default: {
  $192 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($192,32,547888,449,547968,$vararg_buffer);
  $$0 = Math_fround(3.40282346638528859812E+38);
  STACKTOP = sp;return (Math_fround($$0));
 }
 }
 return Math_fround(0);
}
function __ZN5physx2Gu18intersectSphereBoxERKNS0_6SphereERKNS0_3BoxE($sphere,$box) {
 $sphere = $sphere|0;
 $box = $box|0;
 var $$0 = 0, $$mux = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0;
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0;
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $brmerge = 0, $outside$0$off0 = 0, $outside$1$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$sphere>>2]);
 $1 = (($box) + 36|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 - $2);
 $4 = (($sphere) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($box) + 40|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($sphere) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($box) + 44|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = Math_fround(HEAPF32[$box>>2]);
 $15 = Math_fround($3 * $14);
 $16 = (($box) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($8 * $17);
 $19 = Math_fround($15 + $18);
 $20 = (($box) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($13 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($box) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($3 * $25);
 $27 = (($box) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($8 * $28);
 $30 = Math_fround($26 + $29);
 $31 = (($box) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($13 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($box) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($3 * $36);
 $38 = (($box) + 28|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($8 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($box) + 32|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($13 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($box) + 48|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround(-$47);
 $49 = $23 < $48;
 if ($49) {
  $62 = $48;$outside$0$off0 = 1;
 } else {
  $50 = $23 > $47;
  if ($50) {
   $62 = $47;$outside$0$off0 = 1;
  } else {
   $62 = $23;$outside$0$off0 = 0;
  }
 }
 $51 = (($box) + 52|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(-$52);
 $54 = $34 < $53;
 if ($54) {
  $66 = $53;$outside$1$off0 = 1;
 } else {
  $55 = $34 > $52;
  if ($55) {
   $66 = $52;$outside$1$off0 = 1;
  } else {
   $66 = $34;$outside$1$off0 = $outside$0$off0;
  }
 }
 $56 = (($box) + 56|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround(-$57);
 $59 = $45 < $58;
 if ($59) {
  $73 = $58;
  label = 9;
 } else {
  $60 = $45 > $57;
  $brmerge = $60 | $outside$1$off0;
  $$mux = $60 ? $57 : $45;
  if ($brmerge) {
   $73 = $$mux;
   label = 9;
  }
 }
 if ((label|0) == 9) {
  $61 = Math_fround($62 * $14);
  $63 = Math_fround($62 * $17);
  $64 = Math_fround($62 * $21);
  $65 = Math_fround($66 * $25);
  $67 = Math_fround($66 * $28);
  $68 = Math_fround($66 * $32);
  $69 = Math_fround($61 + $65);
  $70 = Math_fround($63 + $67);
  $71 = Math_fround($64 + $68);
  $72 = Math_fround($73 * $36);
  $74 = Math_fround($73 * $39);
  $75 = Math_fround($73 * $43);
  $76 = Math_fround($69 + $72);
  $77 = Math_fround($70 + $74);
  $78 = Math_fround($71 + $75);
  $79 = Math_fround($3 - $76);
  $80 = Math_fround($8 - $77);
  $81 = Math_fround($13 - $78);
  $82 = Math_fround($79 * $79);
  $83 = Math_fround($80 * $80);
  $84 = Math_fround($82 + $83);
  $85 = Math_fround($81 * $81);
  $86 = Math_fround($84 + $85);
  $87 = (($sphere) + 12|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($88 * $88);
  $90 = $86 > $89;
  if ($90) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu21intersectSphereConvexERKNS0_6SphereERKNS0_10ConvexMeshERKNS_11PxMeshScaleERKNS_11PxTransformEPNS_6PxVec3E($sphere,$mesh,$meshScale,$convexGlobalPose,$0) {
 $sphere = $sphere|0;
 $mesh = $mesh|0;
 $meshScale = $meshScale|0;
 $convexGlobalPose = $convexGlobalPose|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0;
 var $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0;
 var $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $capsule = 0, $contactA = 0, $contactB = 0, $convexHull = 0, $normal = 0, $sphereRadius$sroa$1 = 0, $sqDist = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $zero$sroa$1$i$i$i = sp + 480|0;
 $1 = sp + 464|0;
 $zeroV = sp + 448|0;
 $sphereRadius$sroa$1 = sp + 492|0;
 $vScale = sp + 432|0;
 $vQuat = sp + 416|0;
 $convexHull = sp + 208|0;
 $capsule = sp + 48|0;
 $contactA = sp + 32|0;
 $contactB = sp + 16|0;
 $normal = sp;
 $sqDist = sp + 192|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $2 = (($mesh) + 16|0);
 $3 = (($sphere) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$meshScale>>2]);
 $6 = (($meshScale) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($meshScale) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$vScale>>2] = $5;
 $10 = (($vScale) + 4|0);
 HEAPF32[$10>>2] = $7;
 $11 = (($vScale) + 8|0);
 HEAPF32[$11>>2] = $9;
 $12 = (($vScale) + 12|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($meshScale) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($13) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($13) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($13) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$vQuat>>2] = $14;
 $21 = (($vQuat) + 4|0);
 HEAPF32[$21>>2] = $16;
 $22 = (($vQuat) + 8|0);
 HEAPF32[$22>>2] = $18;
 $23 = (($vQuat) + 12|0);
 HEAPF32[$23>>2] = $20;
 $24 = Math_fround(HEAPF32[$sphere>>2]);
 $25 = (($sphere) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($sphere) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$convexGlobalPose>>2]);
 $30 = Math_fround(-$29);
 $31 = (($convexGlobalPose) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(-$32);
 $34 = (($convexGlobalPose) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround(-$35);
 $37 = (($convexGlobalPose) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($convexGlobalPose) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($24 - $40);
 $42 = (($convexGlobalPose) + 20|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($26 - $43);
 $45 = (($convexGlobalPose) + 24|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($28 - $46);
 $48 = Math_fround($41 * Math_fround(2.0));
 $49 = Math_fround($44 * Math_fround(2.0));
 $50 = Math_fround($47 * Math_fround(2.0));
 $51 = Math_fround($38 * $38);
 $52 = Math_fround($51 + Math_fround(-0.5));
 $53 = Math_fround($48 * $30);
 $54 = Math_fround($49 * $33);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($50 * $36);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($52 * $48);
 $59 = Math_fround($50 * $33);
 $60 = Math_fround($49 * $36);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($38 * $61);
 $63 = Math_fround($58 + $62);
 $64 = Math_fround($57 * $30);
 $65 = Math_fround($64 + $63);
 $66 = Math_fround($52 * $49);
 $67 = Math_fround($48 * $36);
 $68 = Math_fround($50 * $30);
 $69 = Math_fround($67 - $68);
 $70 = Math_fround($38 * $69);
 $71 = Math_fround($66 + $70);
 $72 = Math_fround($57 * $33);
 $73 = Math_fround($72 + $71);
 $74 = Math_fround($52 * $50);
 $75 = Math_fround($49 * $30);
 $76 = Math_fround($48 * $33);
 $77 = Math_fround($75 - $76);
 $78 = Math_fround($38 * $77);
 $79 = Math_fround($74 + $78);
 $80 = Math_fround($57 * $36);
 $81 = Math_fround($79 + $80);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$2,$zeroV,$vScale,$vQuat);
 $82 = (($capsule) + 64|0);
 $83 = (($capsule) + 80|0);
 HEAP32[$83>>2] = 4;
 $84 = (($capsule) + 16|0);
 $85 = (($capsule) + 20|0);
 $86 = (($capsule) + 32|0);
 $87 = (($capsule) + 36|0);
 $88 = (($capsule) + 48|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($capsule) + 52|0);
 ;HEAP32[$89+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 HEAPF32[$capsule>>2] = $65;
 $90 = (($capsule) + 4|0);
 HEAPF32[$90>>2] = $73;
 $91 = (($capsule) + 8|0);
 HEAPF32[$91>>2] = $81;
 $92 = (($capsule) + 12|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $93 = (($capsule) + 128|0);
 HEAPF32[$93>>2] = $4;
 $94 = (($capsule) + 132|0);
 ;HEAP32[$94+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 $95 = (($capsule) + 96|0);
 HEAPF32[$95>>2] = $65;
 $96 = (($capsule) + 100|0);
 HEAPF32[$96>>2] = $73;
 $97 = (($capsule) + 104|0);
 HEAPF32[$97>>2] = $81;
 $98 = (($capsule) + 108|0);
 HEAPF32[$98>>2] = Math_fround(0.0);
 $99 = (($capsule) + 112|0);
 HEAPF32[$99>>2] = $65;
 $100 = (($capsule) + 116|0);
 HEAPF32[$100>>2] = $73;
 $101 = (($capsule) + 120|0);
 HEAPF32[$101>>2] = $81;
 $102 = (($capsule) + 124|0);
 HEAPF32[$102>>2] = Math_fround(0.0);
 HEAPF32[$84>>2] = $4;
 ;HEAP32[$85+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 HEAPF32[$86>>2] = $4;
 ;HEAP32[$87+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 ;HEAP32[$1+0>>2]=4294967295|0;HEAP32[$1+4>>2]=4294967295|0;HEAP32[$1+8>>2]=4294967295|0;HEAP32[$1+12>>2]=4294967295|0;
 ;HEAP32[$82+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$82+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$82+12>>2]=HEAP32[$1+12>>2]|0;
 $103 = (__ZN5physx2Gu8GJKLocalERKNS0_8CapsuleVERKNS0_11ConvexHullVERNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVE($capsule,$convexHull,$contactA,$contactB,$normal,$sqDist)|0);
 $104 = ($103|0)==(1);
 if ($104) {
  $108 = 1;
  STACKTOP = sp;return ($108|0);
 }
 $105 = Math_fround($4 * $4);
 $106 = Math_fround(HEAPF32[$sqDist>>2]);
 $107 = $105 >= $106;
 $108 = $107;
 STACKTOP = sp;return ($108|0);
}
function __ZN5physx2Gu22intersectCapsuleConvexERKNS_17PxCapsuleGeometryERKNS_11PxTransformERKNS0_10ConvexMeshERKNS_11PxMeshScaleES6_PNS_6PxVec3E($capsGeom,$capsGlobalPose,$mesh,$meshScale,$convexGlobalPose,$0) {
 $capsGeom = $capsGeom|0;
 $capsGlobalPose = $capsGlobalPose|0;
 $mesh = $mesh|0;
 $meshScale = $meshScale|0;
 $convexGlobalPose = $convexGlobalPose|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0);
 var $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0);
 var $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0);
 var $19 = 0, $190 = 0, $191 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0;
 var $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $capsule = 0, $capsuleRadius$sroa$1 = 0, $contactA = 0, $contactB = 0, $convexHull = 0, $normal = 0, $sqDist = 0, $vQuat = 0, $vScale = 0;
 var $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $zero$sroa$1$i$i$i = sp + 480|0;
 $1 = sp + 464|0;
 $zeroV = sp + 448|0;
 $capsuleRadius$sroa$1 = sp + 492|0;
 $vScale = sp + 432|0;
 $vQuat = sp + 416|0;
 $convexHull = sp + 208|0;
 $capsule = sp + 48|0;
 $contactA = sp + 32|0;
 $contactB = sp + 16|0;
 $normal = sp;
 $sqDist = sp + 192|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $2 = (($mesh) + 16|0);
 $3 = (($capsGeom) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($capsGeom) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$meshScale>>2]);
 $8 = (($meshScale) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($meshScale) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$vScale>>2] = $7;
 $12 = (($vScale) + 4|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($vScale) + 8|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($vScale) + 12|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($meshScale) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($15) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($15) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($15) + 12|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$vQuat>>2] = $16;
 $23 = (($vQuat) + 4|0);
 HEAPF32[$23>>2] = $18;
 $24 = (($vQuat) + 8|0);
 HEAPF32[$24>>2] = $20;
 $25 = (($vQuat) + 12|0);
 HEAPF32[$25>>2] = $22;
 $26 = Math_fround(HEAPF32[$convexGlobalPose>>2]);
 $27 = Math_fround(-$26);
 $28 = (($convexGlobalPose) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround(-$29);
 $31 = (($convexGlobalPose) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(-$32);
 $34 = (($convexGlobalPose) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($capsGlobalPose) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($convexGlobalPose) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($37 - $39);
 $41 = (($capsGlobalPose) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($convexGlobalPose) + 20|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($42 - $44);
 $46 = (($capsGlobalPose) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($convexGlobalPose) + 24|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($47 - $49);
 $51 = Math_fround($40 * Math_fround(2.0));
 $52 = Math_fround($45 * Math_fround(2.0));
 $53 = Math_fround($50 * Math_fround(2.0));
 $54 = Math_fround($35 * $35);
 $55 = Math_fround($54 + Math_fround(-0.5));
 $56 = Math_fround($51 * $27);
 $57 = Math_fround($52 * $30);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($53 * $33);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($55 * $51);
 $62 = Math_fround($53 * $30);
 $63 = Math_fround($52 * $33);
 $64 = Math_fround($62 - $63);
 $65 = Math_fround($35 * $64);
 $66 = Math_fround($61 + $65);
 $67 = Math_fround($60 * $27);
 $68 = Math_fround($67 + $66);
 $69 = Math_fround($55 * $52);
 $70 = Math_fround($51 * $33);
 $71 = Math_fround($53 * $27);
 $72 = Math_fround($70 - $71);
 $73 = Math_fround($35 * $72);
 $74 = Math_fround($69 + $73);
 $75 = Math_fround($60 * $30);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($55 * $53);
 $78 = Math_fround($52 * $27);
 $79 = Math_fround($51 * $30);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($35 * $80);
 $82 = Math_fround($77 + $81);
 $83 = Math_fround($60 * $33);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround(HEAPF32[$capsGlobalPose>>2]);
 $86 = Math_fround($35 * $85);
 $87 = (($capsGlobalPose) + 12|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($88 * $27);
 $90 = Math_fround($86 + $89);
 $91 = (($capsGlobalPose) + 8|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($92 * $30);
 $94 = Math_fround($90 + $93);
 $95 = (($capsGlobalPose) + 4|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($96 * $33);
 $98 = Math_fround($94 - $97);
 $99 = Math_fround($35 * $96);
 $100 = Math_fround($88 * $30);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($85 * $33);
 $103 = Math_fround($102 + $101);
 $104 = Math_fround($92 * $27);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($35 * $92);
 $107 = Math_fround($88 * $33);
 $108 = Math_fround($107 + $106);
 $109 = Math_fround($96 * $27);
 $110 = Math_fround($109 + $108);
 $111 = Math_fround($85 * $30);
 $112 = Math_fround($110 - $111);
 $113 = Math_fround($35 * $88);
 $114 = Math_fround($85 * $27);
 $115 = Math_fround($113 - $114);
 $116 = Math_fround($96 * $30);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($92 * $33);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($98 + $98);
 $121 = Math_fround($105 + $105);
 $122 = Math_fround($112 + $112);
 $123 = Math_fround($98 * $120);
 $124 = Math_fround($105 * $121);
 $125 = Math_fround($112 * $122);
 $126 = Math_fround($120 * $105);
 $127 = Math_fround($120 * $112);
 $128 = Math_fround($120 * $119);
 $129 = Math_fround($112 * $121);
 $130 = Math_fround($119 * $121);
 $131 = Math_fround($119 * $122);
 $132 = Math_fround(Math_fround(1.0) - $123);
 $133 = Math_fround(Math_fround(1.0) - $124);
 $134 = Math_fround($133 - $125);
 $135 = Math_fround($126 + $131);
 $136 = Math_fround($127 - $130);
 $137 = Math_fround($126 - $131);
 $138 = Math_fround($132 - $125);
 $139 = Math_fround($128 + $129);
 $140 = Math_fround($127 + $130);
 $141 = Math_fround($129 - $128);
 $142 = Math_fround($132 - $124);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$2,$zeroV,$vScale,$vQuat);
 $143 = Math_fround($4 * Math_fround(0.0));
 $144 = Math_fround($4 * $134);
 $145 = Math_fround($143 * $137);
 $146 = Math_fround($145 + $144);
 $147 = Math_fround($143 * $140);
 $148 = Math_fround($147 + $146);
 $149 = Math_fround($4 * $135);
 $150 = Math_fround($143 * $138);
 $151 = Math_fround($149 + $150);
 $152 = Math_fround($143 * $141);
 $153 = Math_fround($151 + $152);
 $154 = Math_fround($4 * $136);
 $155 = Math_fround($143 * $139);
 $156 = Math_fround($154 + $155);
 $157 = Math_fround($143 * $142);
 $158 = Math_fround($157 + $156);
 $159 = (($capsule) + 64|0);
 HEAPF32[$capsule>>2] = $68;
 $160 = (($capsule) + 4|0);
 HEAPF32[$160>>2] = $76;
 $161 = (($capsule) + 8|0);
 HEAPF32[$161>>2] = $84;
 $162 = (($capsule) + 12|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 $163 = (($capsule) + 80|0);
 HEAP32[$163>>2] = 4;
 $164 = (($capsule) + 16|0);
 $165 = (($capsule) + 20|0);
 $166 = (($capsule) + 32|0);
 $167 = (($capsule) + 36|0);
 $168 = (($capsule) + 48|0);
 HEAPF32[$168>>2] = Math_fround(0.0);
 $169 = (($capsule) + 52|0);
 ;HEAP32[$169+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$169+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$169+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $170 = (($capsule) + 128|0);
 HEAPF32[$170>>2] = $6;
 $171 = (($capsule) + 132|0);
 ;HEAP32[$171+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$171+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$171+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $172 = Math_fround($68 + $148);
 $173 = Math_fround($76 + $153);
 $174 = Math_fround($84 + $158);
 $175 = (($capsule) + 96|0);
 HEAPF32[$175>>2] = $172;
 $176 = (($capsule) + 100|0);
 HEAPF32[$176>>2] = $173;
 $177 = (($capsule) + 104|0);
 HEAPF32[$177>>2] = $174;
 $178 = (($capsule) + 108|0);
 HEAPF32[$178>>2] = Math_fround(0.0);
 $179 = Math_fround($68 - $148);
 $180 = Math_fround($76 - $153);
 $181 = Math_fround($84 - $158);
 $182 = (($capsule) + 112|0);
 HEAPF32[$182>>2] = $179;
 $183 = (($capsule) + 116|0);
 HEAPF32[$183>>2] = $180;
 $184 = (($capsule) + 120|0);
 HEAPF32[$184>>2] = $181;
 $185 = (($capsule) + 124|0);
 HEAPF32[$185>>2] = Math_fround(0.0);
 HEAPF32[$164>>2] = $6;
 ;HEAP32[$165+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$166>>2] = $6;
 ;HEAP32[$167+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$1+0>>2]=4294967295|0;HEAP32[$1+4>>2]=4294967295|0;HEAP32[$1+8>>2]=4294967295|0;HEAP32[$1+12>>2]=4294967295|0;
 ;HEAP32[$159+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$159+12>>2]=HEAP32[$1+12>>2]|0;
 $186 = (__ZN5physx2Gu8GJKLocalERKNS0_8CapsuleVERKNS0_11ConvexHullVERNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVE($capsule,$convexHull,$contactA,$contactB,$normal,$sqDist)|0);
 $187 = ($186|0)==(1);
 if ($187) {
  $191 = 1;
  STACKTOP = sp;return ($191|0);
 }
 $188 = Math_fround($6 * $6);
 $189 = Math_fround(HEAPF32[$sqDist>>2]);
 $190 = $188 >= $189;
 $191 = $190;
 STACKTOP = sp;return ($191|0);
}
function __ZN5physx2Gu18intersectBoxConvexERKNS_13PxBoxGeometryERKNS_11PxTransformERKNS0_10ConvexMeshERKNS_11PxMeshScaleES6_PNS_6PxVec3E($boxGeom,$boxGlobalPose,$mesh,$meshScale,$convexGlobalPose,$0) {
 $boxGeom = $boxGeom|0;
 $boxGlobalPose = $boxGlobalPose|0;
 $mesh = $mesh|0;
 $meshScale = $meshScale|0;
 $convexGlobalPose = $convexGlobalPose|0;
 $0 = $0|0;
 var $$$i$i$i$i = Math_fround(0), $$$i$i8 = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$sroa$1$i$i$i = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0);
 var $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0);
 var $201 = 0, $202 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0;
 var $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $box = 0, $contactA = 0, $contactB = 0, $convexHull = 0, $normal = 0, $sqDist = 0, $sqTolerance = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 592|0;
 $$sroa$1$i$i$i = sp + 560|0;
 $zero$sroa$1$i$i$i = sp + 576|0;
 $zeroV = sp + 544|0;
 $vScale = sp + 528|0;
 $vQuat = sp + 512|0;
 $aToB = sp + 448|0;
 $convexHull = sp + 240|0;
 $box = sp + 64|0;
 $sqTolerance = sp + 48|0;
 $contactA = sp + 32|0;
 $contactB = sp + 16|0;
 $normal = sp;
 $sqDist = sp + 224|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $1 = (($mesh) + 16|0);
 $2 = Math_fround(HEAPF32[$meshScale>>2]);
 $3 = (($meshScale) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($meshScale) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$vScale>>2] = $2;
 $7 = (($vScale) + 4|0);
 HEAPF32[$7>>2] = $4;
 $8 = (($vScale) + 8|0);
 HEAPF32[$8>>2] = $6;
 $9 = (($vScale) + 12|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($meshScale) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($10) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($10) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($10) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$vQuat>>2] = $11;
 $18 = (($vQuat) + 4|0);
 HEAPF32[$18>>2] = $13;
 $19 = (($vQuat) + 8|0);
 HEAPF32[$19>>2] = $15;
 $20 = (($vQuat) + 12|0);
 HEAPF32[$20>>2] = $17;
 $21 = (($boxGeom) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($boxGeom) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($boxGeom) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(HEAPF32[$convexGlobalPose>>2]);
 $28 = Math_fround(-$27);
 $29 = (($convexGlobalPose) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround(-$30);
 $32 = (($convexGlobalPose) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround(-$33);
 $35 = (($convexGlobalPose) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($boxGlobalPose) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($convexGlobalPose) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 - $40);
 $42 = (($boxGlobalPose) + 20|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($convexGlobalPose) + 20|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 - $45);
 $47 = (($boxGlobalPose) + 24|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($convexGlobalPose) + 24|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($48 - $50);
 $52 = Math_fround($41 * Math_fround(2.0));
 $53 = Math_fround($46 * Math_fround(2.0));
 $54 = Math_fround($51 * Math_fround(2.0));
 $55 = Math_fround($36 * $36);
 $56 = Math_fround($55 + Math_fround(-0.5));
 $57 = Math_fround($52 * $28);
 $58 = Math_fround($53 * $31);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($54 * $34);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($56 * $52);
 $63 = Math_fround($54 * $31);
 $64 = Math_fround($53 * $34);
 $65 = Math_fround($63 - $64);
 $66 = Math_fround($36 * $65);
 $67 = Math_fround($62 + $66);
 $68 = Math_fround($61 * $28);
 $69 = Math_fround($68 + $67);
 $70 = Math_fround($56 * $53);
 $71 = Math_fround($52 * $34);
 $72 = Math_fround($54 * $28);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($36 * $73);
 $75 = Math_fround($70 + $74);
 $76 = Math_fround($61 * $31);
 $77 = Math_fround($76 + $75);
 $78 = Math_fround($56 * $54);
 $79 = Math_fround($53 * $28);
 $80 = Math_fround($52 * $31);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($36 * $81);
 $83 = Math_fround($78 + $82);
 $84 = Math_fround($61 * $34);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround(HEAPF32[$boxGlobalPose>>2]);
 $87 = Math_fround($36 * $86);
 $88 = (($boxGlobalPose) + 12|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($89 * $28);
 $91 = Math_fround($87 + $90);
 $92 = (($boxGlobalPose) + 8|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($93 * $31);
 $95 = Math_fround($91 + $94);
 $96 = (($boxGlobalPose) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 * $34);
 $99 = Math_fround($95 - $98);
 $100 = Math_fround($36 * $97);
 $101 = Math_fround($89 * $31);
 $102 = Math_fround($101 + $100);
 $103 = Math_fround($86 * $34);
 $104 = Math_fround($103 + $102);
 $105 = Math_fround($93 * $28);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($36 * $93);
 $108 = Math_fround($89 * $34);
 $109 = Math_fround($108 + $107);
 $110 = Math_fround($97 * $28);
 $111 = Math_fround($110 + $109);
 $112 = Math_fround($86 * $31);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($36 * $89);
 $115 = Math_fround($86 * $28);
 $116 = Math_fround($114 - $115);
 $117 = Math_fround($97 * $31);
 $118 = Math_fround($116 - $117);
 $119 = Math_fround($93 * $34);
 $120 = Math_fround($118 - $119);
 $121 = (($aToB) + 48|0);
 HEAPF32[$121>>2] = $69;
 $122 = (($aToB) + 52|0);
 HEAPF32[$122>>2] = $77;
 $123 = (($aToB) + 56|0);
 HEAPF32[$123>>2] = $85;
 $124 = (($aToB) + 60|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = Math_fround($99 + $99);
 $126 = Math_fround($106 + $106);
 $127 = Math_fround($113 + $113);
 $128 = Math_fround($99 * $125);
 $129 = Math_fround($106 * $126);
 $130 = Math_fround($113 * $127);
 $131 = Math_fround($125 * $106);
 $132 = Math_fround($125 * $113);
 $133 = Math_fround($125 * $120);
 $134 = Math_fround($113 * $126);
 $135 = Math_fround($120 * $126);
 $136 = Math_fround($120 * $127);
 $137 = Math_fround(Math_fround(1.0) - $128);
 $138 = Math_fround(Math_fround(1.0) - $129);
 $139 = Math_fround($138 - $130);
 $140 = Math_fround($131 + $136);
 $141 = Math_fround($132 - $135);
 $142 = Math_fround($131 - $136);
 $143 = Math_fround($137 - $130);
 $144 = Math_fround($133 + $134);
 $145 = Math_fround($132 + $135);
 $146 = Math_fround($134 - $133);
 $147 = Math_fround($137 - $129);
 HEAPF32[$aToB>>2] = $139;
 $148 = (($aToB) + 4|0);
 HEAPF32[$148>>2] = $140;
 $149 = (($aToB) + 8|0);
 HEAPF32[$149>>2] = $141;
 $150 = (($aToB) + 12|0);
 HEAPF32[$150>>2] = Math_fround(0.0);
 $151 = (($aToB) + 16|0);
 HEAPF32[$151>>2] = $142;
 $152 = (($aToB) + 20|0);
 HEAPF32[$152>>2] = $143;
 $153 = (($aToB) + 24|0);
 HEAPF32[$153>>2] = $144;
 $154 = (($aToB) + 28|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 $155 = (($aToB) + 32|0);
 HEAPF32[$155>>2] = $145;
 $156 = (($aToB) + 36|0);
 HEAPF32[$156>>2] = $146;
 $157 = (($aToB) + 40|0);
 HEAPF32[$157>>2] = $147;
 $158 = (($aToB) + 44|0);
 HEAPF32[$158>>2] = Math_fround(0.0);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$1,$zeroV,$vScale,$vQuat);
 $159 = (($box) + 64|0);
 ;HEAP32[$box+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $160 = (($box) + 80|0);
 HEAP32[$160>>2] = 3;
 $161 = (($box) + 16|0);
 $162 = (($box) + 20|0);
 ;HEAP32[$162+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $163 = (($box) + 32|0);
 $164 = (($box) + 36|0);
 $165 = (($box) + 48|0);
 HEAPF32[$165>>2] = Math_fround(0.0);
 $166 = (($box) + 52|0);
 ;HEAP32[$166+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$166+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$166+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$159+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$159+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $167 = (($box) + 144|0);
 HEAPF32[$167>>2] = $22;
 $168 = (($box) + 148|0);
 HEAPF32[$168>>2] = $24;
 $169 = (($box) + 152|0);
 HEAPF32[$169>>2] = $26;
 $170 = (($box) + 156|0);
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = !($22 <= $24);
 $$$i26$i$i$i = $171 ? $24 : $22;
 $172 = !($$$i26$i$i$i <= $26);
 $173 = $172 ? $26 : $$$i26$i$i$i;
 $174 = !($22 >= $24);
 $$$i23$i$i$i = $174 ? $24 : $22;
 $175 = !($$$i23$i$i$i >= $26);
 $176 = $175 ? $26 : $$$i23$i$i$i;
 $177 = Math_fround($173 * Math_fround(0.150000005960464477539));
 $178 = Math_fround($176 * Math_fround(0.0299999993294477462769));
 $179 = $177 > $178;
 $$$i12$i$i$i = $179 ? $177 : $178;
 $180 = $173 > $$$i12$i$i$i;
 $$$i$i$i$i = $180 ? $$$i12$i$i$i : $173;
 HEAPF32[$161>>2] = $$$i$i$i$i;
 ;HEAP32[$162+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $181 = Math_fround($173 * Math_fround(0.0500000007450580596924));
 HEAPF32[$163>>2] = $181;
 ;HEAP32[$164+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$164+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $182 = (($mesh) + 68|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = (($mesh) + 72|0);
 $185 = Math_fround(HEAPF32[$184>>2]);
 $186 = (($mesh) + 76|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = Math_fround(HEAPF32[$vScale>>2]);
 $189 = Math_fround(HEAPF32[$7>>2]);
 $190 = Math_fround(HEAPF32[$8>>2]);
 $191 = Math_fround($183 * $188);
 $192 = Math_fround($185 * $189);
 $193 = Math_fround($187 * $190);
 $194 = !($191 <= $192);
 $$$i$i8 = $194 ? $192 : $191;
 $195 = !($$$i$i8 <= $193);
 $196 = $195 ? $193 : $$$i$i8;
 $197 = Math_fround($196 * Math_fround(0.00999999977648258209228));
 $198 = Math_fround($173 * Math_fround(0.00999999977648258209228));
 $199 = Math_fround($198 + $197);
 $200 = Math_fround($199 * $199);
 HEAPF32[$sqTolerance>>2] = $200;
 $201 = (__ZN5physx2Gu22GJKRelativeTesselationERKNS0_4BoxVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERNS8_5Vec3VESG_SG_RSC_($box,$convexHull,$aToB,$sqTolerance,$contactA,$contactB,$normal,$sqDist)|0);
 $202 = ($201|0)==(1);
 STACKTOP = sp;return ($202|0);
}
function __ZL32GeomOverlapCallback_SphereSphereRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transform1) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($transform0) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($transform1) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform0) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($transform1) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform0) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * $4);
 $16 = Math_fround($9 * $9);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($14 * $14);
 $19 = Math_fround($17 + $18);
 $20 = (($geom0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($geom1) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 + $23);
 $25 = Math_fround($24 * $24);
 $26 = $19 <= $25;
 STACKTOP = sp;return ($26|0);
}
function __ZL31GeomOverlapCallback_SpherePlaneRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($0,$transform1);
 $1 = (($transform0) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(HEAPF32[$0>>2]);
 $4 = Math_fround($2 * $3);
 $5 = (($transform0) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = Math_fround($4 + $9);
 $11 = (($transform0) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($0) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 * $14);
 $16 = Math_fround($10 + $15);
 $17 = (($0) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 + $16);
 $20 = (($geom0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = $19 <= $21;
 STACKTOP = sp;return ($22|0);
}
function __ZL33GeomOverlapCallback_SphereCapsuleRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $segment = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $segment = sp;
 $0 = Math_fround(HEAPF32[$transform1>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($transform1) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($transform1) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($transform1) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($geom1) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = Math_fround($20 * $15);
 $23 = Math_fround($20 * $18);
 $24 = (($transform1) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $21);
 $27 = (($transform1) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + $22);
 $30 = (($transform1) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($23 + $31);
 HEAPF32[$segment>>2] = $26;
 $33 = (($segment) + 4|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($segment) + 8|0);
 HEAPF32[$34>>2] = $32;
 $35 = Math_fround($25 - $21);
 $36 = Math_fround($28 - $22);
 $37 = Math_fround($31 - $23);
 $38 = (($segment) + 12|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($segment) + 16|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($segment) + 20|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($geom0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($geom1) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($42 + $44);
 $46 = (($transform0) + 16|0);
 $47 = (($segment) + 12|0);
 $48 = (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($segment,$47,$46,0)));
 $49 = Math_fround($45 * $45);
 $50 = $48 <= $49;
 STACKTOP = sp;return ($50|0);
}
function __ZL29GeomOverlapCallback_SphereBoxRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $obb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $obb = sp + 16|0;
 $0 = sp;
 $1 = (($geom1) + 4|0);
 $2 = (($transform1) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($obb) + 36|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($transform1) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($obb) + 40|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($transform1) + 24|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($obb) + 44|0);
 HEAPF32[$10>>2] = $9;
 $11 = Math_fround(HEAPF32[$1>>2]);
 $12 = (($obb) + 48|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($geom1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($obb) + 52|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($geom1) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($obb) + 56|0);
 HEAPF32[$18>>2] = $17;
 $19 = Math_fround(HEAPF32[$transform1>>2]);
 $20 = (($transform1) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transform1) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($transform1) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($19 + $19);
 $27 = Math_fround($21 + $21);
 $28 = Math_fround($23 + $23);
 $29 = Math_fround($19 * $26);
 $30 = Math_fround($21 * $27);
 $31 = Math_fround($23 * $28);
 $32 = Math_fround($26 * $21);
 $33 = Math_fround($26 * $23);
 $34 = Math_fround($26 * $25);
 $35 = Math_fround($27 * $23);
 $36 = Math_fround($27 * $25);
 $37 = Math_fround($28 * $25);
 $38 = Math_fround(Math_fround(1.0) - $30);
 $39 = Math_fround($38 - $31);
 $40 = Math_fround($32 + $37);
 $41 = Math_fround($33 - $36);
 $42 = Math_fround($32 - $37);
 $43 = Math_fround(Math_fround(1.0) - $29);
 $44 = Math_fround($43 - $31);
 $45 = Math_fround($35 + $34);
 $46 = Math_fround($33 + $36);
 $47 = Math_fround($35 - $34);
 $48 = Math_fround($43 - $30);
 HEAPF32[$obb>>2] = $39;
 $49 = (($obb) + 4|0);
 HEAPF32[$49>>2] = $40;
 $50 = (($obb) + 8|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($obb) + 12|0);
 HEAPF32[$51>>2] = $42;
 $52 = (($obb) + 16|0);
 HEAPF32[$52>>2] = $44;
 $53 = (($obb) + 20|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($obb) + 24|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($obb) + 28|0);
 HEAPF32[$55>>2] = $47;
 $56 = (($obb) + 32|0);
 HEAPF32[$56>>2] = $48;
 $57 = (($geom0) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($transform0) + 16|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 HEAPF32[$0>>2] = $60;
 $61 = (($0) + 4|0);
 $62 = (($transform0) + 20|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 HEAPF32[$61>>2] = $63;
 $64 = (($0) + 8|0);
 $65 = (($transform0) + 24|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 HEAPF32[$64>>2] = $66;
 $67 = (($0) + 12|0);
 HEAPF32[$67>>2] = $58;
 $68 = (__ZN5physx2Gu18intersectSphereBoxERKNS0_6SphereERKNS0_3BoxE($0,$obb)|0);
 STACKTOP = sp;return ($68|0);
}
function __ZL32GeomOverlapCallback_SphereConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $$$i = 0, $$not = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($geom1) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($cache|0)==(0|0);
 if ($3) {
  $26 = Math_fround(0.0);$28 = Math_fround(0.0);$30 = Math_fround(1.0);
 } else {
  $4 = (($cache) + 12|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = ($5<<16>>16)==(2);
  $$$i = $6 ? $cache : 0;
  $7 = ($$$i|0)==(0|0);
  if ($7) {
   $26 = Math_fround(0.0);$28 = Math_fround(0.0);$30 = Math_fround(1.0);
  } else {
   $8 = Math_fround(HEAPF32[$$$i>>2]);
   $9 = (($$$i) + 4|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = (($$$i) + 8|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $26 = $8;$28 = $10;$30 = $12;
  }
 }
 $13 = (($geom0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($transform0) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$0>>2] = $16;
 $17 = (($0) + 4|0);
 $18 = (($transform0) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$17>>2] = $19;
 $20 = (($0) + 8|0);
 $21 = (($transform0) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $22;
 $23 = (($0) + 12|0);
 HEAPF32[$23>>2] = $14;
 $24 = (($geom1) + 4|0);
 $25 = (__ZN5physx2Gu21intersectSphereConvexERKNS0_6SphereERKNS0_10ConvexMeshERKNS_11PxMeshScaleERKNS_11PxTransformEPNS_6PxVec3E($0,$2,$24,$transform1,0)|0);
 $$not = $25 ^ 1;
 $brmerge = $3 | $$not;
 if (!($brmerge)) {
  HEAPF32[$cache>>2] = $26;
  $27 = (($cache) + 4|0);
  HEAPF32[$27>>2] = $28;
  $29 = (($cache) + 8|0);
  HEAPF32[$29>>2] = $30;
 }
 if ($3) {
  STACKTOP = sp;return ($25|0);
 }
 $31 = (($cache) + 12|0);
 if ($25) {
  HEAP16[$31>>1] = 2;
  STACKTOP = sp;return ($25|0);
 } else {
  HEAP16[$31>>1] = 0;
  STACKTOP = sp;return ($25|0);
 }
 return 0|0;
}
function __ZL43GeomOverlapCallback_HeightfieldUnregisteredRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($0,8,548224,991,548304,$vararg_buffer);
 STACKTOP = sp;return 0;
}
function __ZL30GeomOverlapCallback_PlanePlaneRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZL32GeomOverlapCallback_PlaneCapsuleRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $$0$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0);
 var $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$transform1>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($transform1) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = Math_fround($4 * $5);
 $7 = Math_fround($6 + Math_fround(-1.0));
 $8 = Math_fround($1 * $2);
 $9 = Math_fround($8 + $7);
 $10 = (($transform1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $5);
 $13 = (($transform1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($2 * $14);
 $16 = Math_fround($12 + $15);
 $17 = Math_fround($5 * $14);
 $18 = Math_fround($2 * $11);
 $19 = Math_fround($18 - $17);
 $20 = (($geom1) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $9);
 $23 = Math_fround($21 * $16);
 $24 = Math_fround($21 * $19);
 $25 = (($transform1) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + $22);
 $28 = (($transform1) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 + $23);
 $31 = (($transform1) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 + $32);
 $34 = (($geom1) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($0,$transform0);
 $36 = Math_fround(HEAPF32[$0>>2]);
 $37 = Math_fround($27 * $36);
 $38 = (($0) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($30 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($0) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($33 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($0) + 12|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 + $45);
 $49 = !($48 <= $35);
 if (!($49)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $50 = Math_fround($32 - $24);
 $51 = Math_fround($29 - $23);
 $52 = Math_fround($26 - $22);
 $53 = Math_fround($52 * $36);
 $54 = Math_fround($51 * $39);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($50 * $43);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($47 + $57);
 $not$$i = $58 <= $35;
 $$0$i = $not$$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZL28GeomOverlapCallback_PlaneBoxRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = Math_fround(0), $vx$08 = 0, $vy$06 = 0, $vz$04 = 0, $worldPlane = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $worldPlane = sp;
 $0 = Math_fround(HEAPF32[$transform1>>2]);
 $1 = Math_fround($0 + $0);
 $2 = (($transform1) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 + $3);
 $5 = (($transform1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 + $6);
 $8 = (($transform1) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($1 * $9);
 $11 = Math_fround($4 * $9);
 $12 = Math_fround($9 * $7);
 $13 = Math_fround($0 * $1);
 $14 = Math_fround($0 * $4);
 $15 = Math_fround($0 * $7);
 $16 = Math_fround($3 * $4);
 $17 = Math_fround($3 * $7);
 $18 = Math_fround($6 * $7);
 $19 = Math_fround(Math_fround(1.0) - $16);
 $20 = Math_fround($19 - $18);
 $21 = Math_fround($14 + $12);
 $22 = Math_fround($15 - $11);
 $23 = Math_fround($14 - $12);
 $24 = Math_fround(Math_fround(1.0) - $13);
 $25 = Math_fround($24 - $18);
 $26 = Math_fround($17 + $10);
 $27 = Math_fround($15 + $11);
 $28 = Math_fround($17 - $10);
 $29 = Math_fround($24 - $16);
 $30 = (($transform1) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($transform1) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($transform1) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($worldPlane,$transform0);
 $36 = (($geom1) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($geom1) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($geom1) + 12|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround(HEAPF32[$worldPlane>>2]);
 $43 = (($worldPlane) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($worldPlane) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($worldPlane) + 12|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $vx$08 = -1;
 L1: while(1) {
  $49 = (Math_fround(($vx$08|0)));
  $50 = Math_fround($49 * $37);
  $51 = Math_fround($20 * $50);
  $52 = Math_fround($21 * $50);
  $53 = Math_fround($22 * $50);
  $vy$06 = -1;
  while(1) {
   $54 = (Math_fround(($vy$06|0)));
   $55 = Math_fround($54 * $39);
   $56 = Math_fround($23 * $55);
   $57 = Math_fround($25 * $55);
   $58 = Math_fround($26 * $55);
   $59 = Math_fround($51 + $56);
   $60 = Math_fround($52 + $57);
   $61 = Math_fround($53 + $58);
   $vz$04 = -1;
   while(1) {
    $64 = (Math_fround(($vz$04|0)));
    $65 = Math_fround($64 * $41);
    $66 = Math_fround($27 * $65);
    $67 = Math_fround($28 * $65);
    $68 = Math_fround($29 * $65);
    $69 = Math_fround($59 + $66);
    $70 = Math_fround($60 + $67);
    $71 = Math_fround($61 + $68);
    $72 = Math_fround($31 + $69);
    $73 = Math_fround($33 + $70);
    $74 = Math_fround($35 + $71);
    $75 = Math_fround($42 * $72);
    $76 = Math_fround($44 * $73);
    $77 = Math_fround($75 + $76);
    $78 = Math_fround($46 * $74);
    $79 = Math_fround($78 + $77);
    $80 = Math_fround($48 + $79);
    $81 = !($80 <= Math_fround(0.0));
    if (!($81)) {
     $$0 = 1;
     label = 8;
     break L1;
    }
    $62 = (($vz$04) + 2)|0;
    $63 = ($vz$04|0)<(0);
    if ($63) {
     $vz$04 = $62;
    } else {
     break;
    }
   }
   $82 = (($vy$06) + 2)|0;
   $83 = ($vy$06|0)<(0);
   if ($83) {
    $vy$06 = $82;
   } else {
    break;
   }
  }
  $84 = (($vx$08) + 2)|0;
  $85 = ($vx$08|0)<(0);
  if ($85) {
   $vx$08 = $84;
  } else {
   $$0 = 0;
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL31GeomOverlapCallback_PlaneConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $$sum$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0);
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = 0;
 var $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0);
 var $327 = Math_fround(0), $328 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $MaxID$i = 0, $MinID$i = 0, $NbVerts$01$i = 0, $Verts$05$i = 0, $min_$0$lcssa$i13 = Math_fround(0);
 var $min_$02$i = Math_fround(0), $plane2convex = 0, $shapeSpacePlane = 0, $tmp$i$i = 0, $tmp1$i$i = 0, $u$i$i = 0, $v$i$i = 0, $vertexSpaceDir$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $u$i$i = sp + 80|0;
 $v$i$i = sp;
 $vertexSpaceDir$i = sp + 4|0;
 $MinID$i = sp + 16|0;
 $MaxID$i = sp + 20|0;
 $0 = sp + 24|0;
 $plane2convex = sp + 36|0;
 $shapeSpacePlane = sp + 64|0;
 $1 = (($geom1) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($transform1) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($transform1) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform1) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($4 * Math_fround(-2.0));
 $10 = Math_fround($6 * Math_fround(-2.0));
 $11 = Math_fround($8 * Math_fround(-2.0));
 $12 = (($transform1) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $13);
 $15 = Math_fround($14 + Math_fround(-0.5));
 $16 = Math_fround(HEAPF32[$transform1>>2]);
 $17 = Math_fround($9 * $16);
 $18 = (($transform1) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($10 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (($transform1) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($11 * $23);
 $25 = Math_fround($21 + $24);
 $26 = Math_fround($9 * $15);
 $27 = Math_fround($11 * $19);
 $28 = Math_fround($10 * $23);
 $29 = Math_fround($27 - $28);
 $30 = Math_fround($13 * $29);
 $31 = Math_fround($26 - $30);
 $32 = Math_fround($16 * $25);
 $33 = Math_fround($32 + $31);
 $34 = Math_fround($10 * $15);
 $35 = Math_fround($9 * $23);
 $36 = Math_fround($11 * $16);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($13 * $37);
 $39 = Math_fround($34 - $38);
 $40 = Math_fround($19 * $25);
 $41 = Math_fround($40 + $39);
 $42 = Math_fround($11 * $15);
 $43 = Math_fround($10 * $16);
 $44 = Math_fround($9 * $19);
 $45 = Math_fround($43 - $44);
 $46 = Math_fround($13 * $45);
 $47 = Math_fround($42 - $46);
 $48 = Math_fround($23 * $25);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround(-$16);
 $51 = Math_fround(-$19);
 $52 = Math_fround(-$23);
 $53 = (($transform0) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 * Math_fround(2.0));
 $56 = (($transform0) + 20|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 * Math_fround(2.0));
 $59 = (($transform0) + 24|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 * Math_fround(2.0));
 $62 = Math_fround($55 * $50);
 $63 = Math_fround($58 * $51);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($61 * $52);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($15 * $55);
 $68 = Math_fround($61 * $51);
 $69 = Math_fround($58 * $52);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($13 * $70);
 $72 = Math_fround($67 + $71);
 $73 = Math_fround($66 * $50);
 $74 = Math_fround($73 + $72);
 $75 = Math_fround($15 * $58);
 $76 = Math_fround($55 * $52);
 $77 = Math_fround($61 * $50);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($13 * $78);
 $80 = Math_fround($75 + $79);
 $81 = Math_fround($66 * $51);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($15 * $61);
 $84 = Math_fround($58 * $50);
 $85 = Math_fround($55 * $51);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($13 * $86);
 $88 = Math_fround($83 + $87);
 $89 = Math_fround($66 * $52);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround($33 + $74);
 $92 = Math_fround($41 + $82);
 $93 = Math_fround($49 + $90);
 $94 = Math_fround(HEAPF32[$transform0>>2]);
 $95 = Math_fround($13 * $94);
 $96 = (($transform0) + 12|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 * $50);
 $99 = Math_fround($95 + $98);
 $100 = (($transform0) + 8|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($101 * $51);
 $103 = Math_fround($99 + $102);
 $104 = (($transform0) + 4|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($105 * $52);
 $107 = Math_fround($103 - $106);
 $108 = Math_fround($13 * $105);
 $109 = Math_fround($97 * $51);
 $110 = Math_fround($109 + $108);
 $111 = Math_fround($94 * $52);
 $112 = Math_fround($111 + $110);
 $113 = Math_fround($101 * $50);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($13 * $101);
 $116 = Math_fround($97 * $52);
 $117 = Math_fround($116 + $115);
 $118 = Math_fround($105 * $50);
 $119 = Math_fround($118 + $117);
 $120 = Math_fround($94 * $51);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($13 * $97);
 $123 = Math_fround($94 * $50);
 $124 = Math_fround($122 - $123);
 $125 = Math_fround($105 * $51);
 $126 = Math_fround($124 - $125);
 $127 = Math_fround($101 * $52);
 $128 = Math_fround($126 - $127);
 HEAPF32[$plane2convex>>2] = $107;
 $129 = (($plane2convex) + 4|0);
 HEAPF32[$129>>2] = $114;
 $130 = (($plane2convex) + 8|0);
 HEAPF32[$130>>2] = $121;
 $131 = (($plane2convex) + 12|0);
 HEAPF32[$131>>2] = $128;
 $132 = (($plane2convex) + 16|0);
 HEAPF32[$132>>2] = $91;
 $133 = (($plane2convex) + 20|0);
 HEAPF32[$133>>2] = $92;
 $134 = (($plane2convex) + 24|0);
 HEAPF32[$134>>2] = $93;
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($shapeSpacePlane,$plane2convex);
 $135 = (($2) + 16|0);
 $136 = (($geom1) + 4|0);
 $137 = (($geom1) + 16|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($geom1) + 20|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($geom1) + 24|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($geom1) + 28|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround($138 + $138);
 $146 = Math_fround($140 + $140);
 $147 = Math_fround($142 + $142);
 $148 = Math_fround($138 * $145);
 $149 = Math_fround($140 * $146);
 $150 = Math_fround($142 * $147);
 $151 = Math_fround($145 * $140);
 $152 = Math_fround($145 * $142);
 $153 = Math_fround($145 * $144);
 $154 = Math_fround($146 * $142);
 $155 = Math_fround($146 * $144);
 $156 = Math_fround($147 * $144);
 $157 = Math_fround(Math_fround(1.0) - $149);
 $158 = Math_fround($157 - $150);
 $159 = Math_fround($151 + $156);
 $160 = Math_fround($152 - $155);
 $161 = Math_fround($151 - $156);
 $162 = Math_fround(Math_fround(1.0) - $148);
 $163 = Math_fround($162 - $150);
 $164 = Math_fround($154 + $153);
 $165 = Math_fround($152 + $155);
 $166 = Math_fround($154 - $153);
 $167 = Math_fround($162 - $149);
 $168 = Math_fround(HEAPF32[$136>>2]);
 $169 = Math_fround($168 * $158);
 $170 = Math_fround($168 * $161);
 $171 = Math_fround($168 * $165);
 $172 = (($geom1) + 8|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround($159 * $173);
 $175 = Math_fround($163 * $173);
 $176 = Math_fround($166 * $173);
 $177 = (($geom1) + 12|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = Math_fround($160 * $178);
 $180 = Math_fround($164 * $178);
 $181 = Math_fround($167 * $178);
 $182 = Math_fround($158 * $169);
 $183 = Math_fround($158 * $170);
 $184 = Math_fround($158 * $171);
 $185 = Math_fround($159 * $174);
 $186 = Math_fround($159 * $175);
 $187 = Math_fround($159 * $176);
 $188 = Math_fround($182 + $185);
 $189 = Math_fround($183 + $186);
 $190 = Math_fround($184 + $187);
 $191 = Math_fround($160 * $179);
 $192 = Math_fround($160 * $180);
 $193 = Math_fround($160 * $181);
 $194 = Math_fround($188 + $191);
 $195 = Math_fround($189 + $192);
 $196 = Math_fround($190 + $193);
 $197 = Math_fround($161 * $169);
 $198 = Math_fround($161 * $170);
 $199 = Math_fround($161 * $171);
 $200 = Math_fround($163 * $174);
 $201 = Math_fround($163 * $175);
 $202 = Math_fround($163 * $176);
 $203 = Math_fround($197 + $200);
 $204 = Math_fround($198 + $201);
 $205 = Math_fround($199 + $202);
 $206 = Math_fround($164 * $179);
 $207 = Math_fround($164 * $180);
 $208 = Math_fround($164 * $181);
 $209 = Math_fround($203 + $206);
 $210 = Math_fround($204 + $207);
 $211 = Math_fround($205 + $208);
 $212 = Math_fround($165 * $169);
 $213 = Math_fround($165 * $170);
 $214 = Math_fround($165 * $171);
 $215 = Math_fround($166 * $174);
 $216 = Math_fround($166 * $175);
 $217 = Math_fround($166 * $176);
 $218 = Math_fround($212 + $215);
 $219 = Math_fround($213 + $216);
 $220 = Math_fround($214 + $217);
 $221 = Math_fround($167 * $179);
 $222 = Math_fround($167 * $180);
 $223 = Math_fround($167 * $181);
 $224 = Math_fround($218 + $221);
 $225 = Math_fround($219 + $222);
 $226 = Math_fround($220 + $223);
 $$idx$val = Math_fround(HEAPF32[$shapeSpacePlane>>2]);
 $$idx1 = (($shapeSpacePlane) + 4|0);
 $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
 $$idx2 = (($shapeSpacePlane) + 8|0);
 $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
 $227 = Math_fround($$idx$val * $194);
 $228 = Math_fround($$idx$val * $195);
 $229 = Math_fround($$idx$val * $196);
 $230 = Math_fround($$idx1$val * $209);
 $231 = Math_fround($$idx1$val * $210);
 $232 = Math_fround($$idx1$val * $211);
 $233 = Math_fround($227 + $230);
 $234 = Math_fround($228 + $231);
 $235 = Math_fround($229 + $232);
 $236 = Math_fround($224 * $$idx2$val);
 $237 = Math_fround($225 * $$idx2$val);
 $238 = Math_fround($226 * $$idx2$val);
 $239 = Math_fround($236 + $233);
 $240 = Math_fround($237 + $234);
 $241 = Math_fround($238 + $235);
 HEAPF32[$vertexSpaceDir$i>>2] = $239;
 $242 = (($vertexSpaceDir$i) + 4|0);
 HEAPF32[$242>>2] = $240;
 $243 = (($vertexSpaceDir$i) + 8|0);
 HEAPF32[$243>>2] = $241;
 $244 = (($2) + 56|0);
 $245 = HEAP32[$244>>2]|0;
 $246 = (($135) + 39|0);
 $247 = HEAP8[$246>>0]|0;
 $248 = $247&255;
 $249 = (($245) + (($248*20)|0)|0);
 $250 = (($2) + 60|0);
 $251 = HEAP32[$250>>2]|0;
 $252 = ($251|0)==(0|0);
 if (!($252)) {
  $271 = HEAP16[$251>>1]|0;
  $272 = $271&65535;
  $273 = (__ZN5physx13CubemapLookupERKNS_6PxVec3ERfS3_($vertexSpaceDir$i,$u$i$i,$v$i$i)|0);
  $274 = (($272) + -1)|0;
  $275 = (Math_fround(($274>>>0)));
  $276 = Math_fround($275 * Math_fround(0.5));
  $277 = Math_fround(HEAPF32[$u$i$i>>2]);
  $278 = Math_fround($277 + Math_fround(1.0));
  $279 = Math_fround($276 * $278);
  $280 = Math_fround(HEAPF32[$v$i$i>>2]);
  $281 = Math_fround($280 + Math_fround(1.0));
  $282 = Math_fround($276 * $281);
  $283 = Math_imul($273, $272)|0;
  $284 = Math_fround($279 + Math_fround(0.5));
  $285 = (~~(($284))>>>0);
  $286 = Math_fround($282 + Math_fround(0.5));
  $287 = (~~(($286))>>>0);
  $tmp$i$i = (($285) + ($283))|0;
  $tmp1$i$i = Math_imul($tmp$i$i, $272)|0;
  $288 = (($tmp1$i$i) + ($287))|0;
  $289 = HEAP32[$250>>2]|0;
  $290 = (($289) + 4|0);
  $291 = HEAP32[$290>>2]|0;
  $292 = (($291) + ($288)|0);
  $293 = HEAP8[$292>>0]|0;
  $294 = $293&255;
  HEAP32[$MinID$i>>2] = $294;
  $295 = (($289) + 2|0);
  $296 = HEAP16[$295>>1]|0;
  $297 = $296&65535;
  $$sum$i = (($297) + ($288))|0;
  $298 = (($291) + ($$sum$i)|0);
  $299 = HEAP8[$298>>0]|0;
  $300 = $299&255;
  HEAP32[$MaxID$i>>2] = $300;
  $301 = Math_fround(HEAPF32[$vertexSpaceDir$i>>2]);
  $302 = Math_fround(-$301);
  $303 = Math_fround(HEAPF32[$242>>2]);
  $304 = Math_fround(-$303);
  $305 = Math_fround(HEAPF32[$243>>2]);
  $306 = Math_fround(-$305);
  HEAPF32[$0>>2] = $302;
  $307 = (($0) + 4|0);
  HEAPF32[$307>>2] = $304;
  $308 = (($0) + 8|0);
  HEAPF32[$308>>2] = $306;
  __ZN5physx11localSearchERjRKNS_6PxVec3EPS2_PKNS_2Gu16BigConvexRawDataE($MinID$i,$0,$249,$289);
  $309 = HEAP32[$250>>2]|0;
  __ZN5physx11localSearchERjRKNS_6PxVec3EPS2_PKNS_2Gu16BigConvexRawDataE($MaxID$i,$vertexSpaceDir$i,$249,$309);
  $310 = HEAP32[$MinID$i>>2]|0;
  $311 = (($249) + (($310*12)|0)|0);
  $312 = Math_fround(HEAPF32[$311>>2]);
  $313 = Math_fround(HEAPF32[$vertexSpaceDir$i>>2]);
  $314 = Math_fround($312 * $313);
  $315 = ((($249) + (($310*12)|0)|0) + 4|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = Math_fround(HEAPF32[$242>>2]);
  $318 = Math_fround($316 * $317);
  $319 = Math_fround($314 + $318);
  $320 = ((($249) + (($310*12)|0)|0) + 8|0);
  $321 = Math_fround(HEAPF32[$320>>2]);
  $322 = Math_fround(HEAPF32[$243>>2]);
  $323 = Math_fround($321 * $322);
  $324 = Math_fround($319 + $323);
  $min_$0$lcssa$i13 = $324;
  $325 = (($shapeSpacePlane) + 12|0);
  $326 = Math_fround(HEAPF32[$325>>2]);
  $327 = Math_fround(-$326);
  $328 = $min_$0$lcssa$i13 <= $327;
  STACKTOP = sp;return ($328|0);
 }
 $253 = (($2) + 54|0);
 $254 = HEAP8[$253>>0]|0;
 $255 = $254&255;
 $NbVerts$01$i = $255;$Verts$05$i = $249;$min_$02$i = Math_fround(3.40282346638528859812E+38);
 while(1) {
  $256 = (($NbVerts$01$i) + -1)|0;
  $257 = Math_fround(HEAPF32[$Verts$05$i>>2]);
  $258 = Math_fround($239 * $257);
  $259 = (($Verts$05$i) + 4|0);
  $260 = Math_fround(HEAPF32[$259>>2]);
  $261 = Math_fround($240 * $260);
  $262 = Math_fround($258 + $261);
  $263 = (($Verts$05$i) + 8|0);
  $264 = Math_fround(HEAPF32[$263>>2]);
  $265 = Math_fround($241 * $264);
  $266 = Math_fround($262 + $265);
  $267 = $min_$02$i < $266;
  $268 = $267 ? $min_$02$i : $266;
  $269 = (($Verts$05$i) + 12|0);
  $270 = ($256|0)==(0);
  if ($270) {
   $min_$0$lcssa$i13 = $268;
   break;
  } else {
   $NbVerts$01$i = $256;$Verts$05$i = $269;$min_$02$i = $268;
  }
 }
 $325 = (($shapeSpacePlane) + 12|0);
 $326 = Math_fround(HEAPF32[$325>>2]);
 $327 = Math_fround(-$326);
 $328 = $min_$0$lcssa$i13 <= $327;
 STACKTOP = sp;return ($328|0);
}
function __ZL29GeomOverlapCallback_PlaneMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZL34GeomOverlapCallback_CapsuleCapsuleRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $segment1 = 0, $segment2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 $segment1 = sp + 16|0;
 $segment2 = sp + 40|0;
 $2 = Math_fround(HEAPF32[$transform0>>2]);
 $3 = Math_fround($2 * Math_fround(2.0));
 $4 = (($transform0) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = Math_fround($5 * $6);
 $8 = Math_fround($7 + Math_fround(-1.0));
 $9 = Math_fround($2 * $3);
 $10 = Math_fround($9 + $8);
 $11 = (($transform0) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $6);
 $14 = (($transform0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 * $15);
 $17 = Math_fround($13 + $16);
 $18 = Math_fround($6 * $15);
 $19 = Math_fround($3 * $12);
 $20 = Math_fround($19 - $18);
 $21 = (($geom0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $10);
 $24 = Math_fround($22 * $17);
 $25 = Math_fround($22 * $20);
 $26 = (($transform0) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 + $23);
 $29 = (($transform0) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $24);
 $32 = (($transform0) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($25 + $33);
 HEAPF32[$segment1>>2] = $28;
 $35 = (($segment1) + 4|0);
 HEAPF32[$35>>2] = $31;
 $36 = (($segment1) + 8|0);
 HEAPF32[$36>>2] = $34;
 $37 = Math_fround($27 - $23);
 $38 = Math_fround($30 - $24);
 $39 = Math_fround($33 - $25);
 $40 = (($segment1) + 12|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($segment1) + 16|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($segment1) + 20|0);
 HEAPF32[$42>>2] = $39;
 $43 = Math_fround(HEAPF32[$transform1>>2]);
 $44 = Math_fround($43 * Math_fround(2.0));
 $45 = (($transform1) + 12|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 * Math_fround(2.0));
 $48 = Math_fround($46 * $47);
 $49 = Math_fround($48 + Math_fround(-1.0));
 $50 = Math_fround($43 * $44);
 $51 = Math_fround($50 + $49);
 $52 = (($transform1) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 * $47);
 $55 = (($transform1) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($44 * $56);
 $58 = Math_fround($54 + $57);
 $59 = Math_fround($47 * $56);
 $60 = Math_fround($44 * $53);
 $61 = Math_fround($60 - $59);
 $62 = (($geom1) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $51);
 $65 = Math_fround($63 * $58);
 $66 = Math_fround($63 * $61);
 $67 = (($transform1) + 16|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 + $64);
 $70 = (($transform1) + 20|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 + $65);
 $73 = (($transform1) + 24|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($66 + $74);
 HEAPF32[$segment2>>2] = $69;
 $76 = (($segment2) + 4|0);
 HEAPF32[$76>>2] = $72;
 $77 = (($segment2) + 8|0);
 HEAPF32[$77>>2] = $75;
 $78 = Math_fround($68 - $64);
 $79 = Math_fround($71 - $65);
 $80 = Math_fround($74 - $66);
 $81 = (($segment2) + 12|0);
 HEAPF32[$81>>2] = $78;
 $82 = (($segment2) + 16|0);
 HEAPF32[$82>>2] = $79;
 $83 = (($segment2) + 20|0);
 HEAPF32[$83>>2] = $80;
 $84 = Math_fround($37 - $28);
 $85 = Math_fround($38 - $31);
 $86 = Math_fround($39 - $34);
 HEAPF32[$0>>2] = $84;
 $87 = (($0) + 4|0);
 HEAPF32[$87>>2] = $85;
 $88 = (($0) + 8|0);
 HEAPF32[$88>>2] = $86;
 $89 = Math_fround($78 - $69);
 $90 = Math_fround($79 - $72);
 $91 = Math_fround($80 - $75);
 HEAPF32[$1>>2] = $89;
 $92 = (($1) + 4|0);
 HEAPF32[$92>>2] = $90;
 $93 = (($1) + 8|0);
 HEAPF32[$93>>2] = $91;
 $94 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($segment1,$0,$segment2,$1,0,0)));
 $95 = (($geom0) + 4|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($geom1) + 4|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($96 + $98);
 $100 = Math_fround($99 * $99);
 $101 = $94 <= $100;
 STACKTOP = sp;return ($101|0);
}
function __ZL30GeomOverlapCallback_CapsuleBoxRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $12 = Math_fround(0);
 var $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0;
 var $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $obb = 0, $segment = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $segment = sp + 96|0;
 $obb = sp;
 $0 = sp + 64|0;
 $1 = sp + 80|0;
 $2 = Math_fround(HEAPF32[$transform0>>2]);
 $3 = Math_fround($2 * Math_fround(2.0));
 $4 = (($transform0) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = Math_fround($5 * $6);
 $8 = Math_fround($7 + Math_fround(-1.0));
 $9 = Math_fround($2 * $3);
 $10 = Math_fround($9 + $8);
 $11 = (($transform0) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $6);
 $14 = (($transform0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 * $15);
 $17 = Math_fround($13 + $16);
 $18 = Math_fround($6 * $15);
 $19 = Math_fround($3 * $12);
 $20 = Math_fround($19 - $18);
 $21 = (($geom0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $10);
 $24 = Math_fround($22 * $17);
 $25 = Math_fround($22 * $20);
 $26 = (($transform0) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 + $23);
 $29 = (($transform0) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $24);
 $32 = (($transform0) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($25 + $33);
 HEAPF32[$segment>>2] = $28;
 $35 = (($segment) + 4|0);
 HEAPF32[$35>>2] = $31;
 $36 = (($segment) + 8|0);
 HEAPF32[$36>>2] = $34;
 $37 = Math_fround($27 - $23);
 $38 = Math_fround($30 - $24);
 $39 = Math_fround($33 - $25);
 $40 = (($segment) + 12|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($segment) + 16|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($segment) + 20|0);
 HEAPF32[$42>>2] = $39;
 $43 = (($transform1) + 16|0);
 $44 = (($geom1) + 4|0);
 $45 = Math_fround(HEAPF32[$43>>2]);
 $46 = (($obb) + 36|0);
 HEAPF32[$46>>2] = $45;
 $47 = (($transform1) + 20|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($obb) + 40|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($transform1) + 24|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($obb) + 44|0);
 HEAPF32[$52>>2] = $51;
 $53 = Math_fround(HEAPF32[$44>>2]);
 $54 = (($obb) + 48|0);
 HEAPF32[$54>>2] = $53;
 $55 = (($geom1) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($obb) + 52|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($geom1) + 12|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($obb) + 56|0);
 HEAPF32[$60>>2] = $59;
 $61 = Math_fround(HEAPF32[$transform1>>2]);
 $62 = (($transform1) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($transform1) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($transform1) + 12|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($61 + $61);
 $69 = Math_fround($63 + $63);
 $70 = Math_fround($65 + $65);
 $71 = Math_fround($61 * $68);
 $72 = Math_fround($63 * $69);
 $73 = Math_fround($65 * $70);
 $74 = Math_fround($68 * $63);
 $75 = Math_fround($68 * $65);
 $76 = Math_fround($68 * $67);
 $77 = Math_fround($69 * $65);
 $78 = Math_fround($69 * $67);
 $79 = Math_fround($70 * $67);
 $80 = Math_fround(Math_fround(1.0) - $72);
 $81 = Math_fround($80 - $73);
 $82 = Math_fround($74 + $79);
 $83 = Math_fround($75 - $78);
 $84 = Math_fround($74 - $79);
 $85 = Math_fround(Math_fround(1.0) - $71);
 $86 = Math_fround($85 - $73);
 $87 = Math_fround($77 + $76);
 $88 = Math_fround($75 + $78);
 $89 = Math_fround($77 - $76);
 $90 = Math_fround($85 - $72);
 HEAPF32[$obb>>2] = $81;
 $91 = (($obb) + 4|0);
 HEAPF32[$91>>2] = $82;
 $92 = (($obb) + 8|0);
 HEAPF32[$92>>2] = $83;
 $93 = (($obb) + 12|0);
 HEAPF32[$93>>2] = $84;
 $94 = (($obb) + 16|0);
 HEAPF32[$94>>2] = $86;
 $95 = (($obb) + 20|0);
 HEAPF32[$95>>2] = $87;
 $96 = (($obb) + 24|0);
 HEAPF32[$96>>2] = $88;
 $97 = (($obb) + 28|0);
 HEAPF32[$97>>2] = $89;
 $98 = (($obb) + 32|0);
 HEAPF32[$98>>2] = $90;
 $99 = (($geom0) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 HEAPF32[$0>>2] = $28;
 $101 = (($0) + 4|0);
 HEAPF32[$101>>2] = $31;
 $102 = (($0) + 8|0);
 HEAPF32[$102>>2] = $34;
 $103 = (($0) + 12|0);
 HEAPF32[$103>>2] = $100;
 $104 = (__ZN5physx2Gu18intersectSphereBoxERKNS0_6SphereERKNS0_3BoxE($0,$obb)|0);
 if ($104) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$1>>2] = $37;
 $105 = (($1) + 4|0);
 HEAPF32[$105>>2] = $38;
 $106 = (($1) + 8|0);
 HEAPF32[$106>>2] = $39;
 $107 = (($1) + 12|0);
 HEAPF32[$107>>2] = $100;
 $108 = (__ZN5physx2Gu18intersectSphereBoxERKNS0_6SphereERKNS0_3BoxE($1,$obb)|0);
 if ($108) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $109 = (($segment) + 12|0);
 $110 = (Math_fround(__ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($segment,$109,$43,$44,$obb,0,0)));
 $111 = Math_fround(HEAPF32[$99>>2]);
 $112 = Math_fround($111 * $111);
 $113 = $110 <= $112;
 $$0 = $113;
 STACKTOP = sp;return ($$0|0);
}
function __ZL33GeomOverlapCallback_CapsuleConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $$$i = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0);
 var $8 = 0, $9 = Math_fround(0), $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($geom1) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($cache|0)==(0|0);
 if ($2) {
  $14 = Math_fround(0.0);$16 = Math_fround(0.0);$18 = Math_fround(1.0);
 } else {
  $3 = (($cache) + 12|0);
  $4 = HEAP16[$3>>1]|0;
  $5 = ($4<<16>>16)==(2);
  $$$i = $5 ? $cache : 0;
  $6 = ($$$i|0)==(0|0);
  if ($6) {
   $14 = Math_fround(0.0);$16 = Math_fround(0.0);$18 = Math_fround(1.0);
  } else {
   $7 = Math_fround(HEAPF32[$$$i>>2]);
   $8 = (($$$i) + 4|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = (($$$i) + 8|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $14 = $7;$16 = $9;$18 = $11;
  }
 }
 $12 = (($geom1) + 4|0);
 $13 = (__ZN5physx2Gu22intersectCapsuleConvexERKNS_17PxCapsuleGeometryERKNS_11PxTransformERKNS0_10ConvexMeshERKNS_11PxMeshScaleES6_PNS_6PxVec3E($geom0,$transform0,$1,$12,$transform1,0)|0);
 $$not = $13 ^ 1;
 $brmerge = $2 | $$not;
 if (!($brmerge)) {
  HEAPF32[$cache>>2] = $14;
  $15 = (($cache) + 4|0);
  HEAPF32[$15>>2] = $16;
  $17 = (($cache) + 8|0);
  HEAPF32[$17>>2] = $18;
 }
 if ($2) {
  STACKTOP = sp;return ($13|0);
 }
 $19 = (($cache) + 12|0);
 if ($13) {
  HEAP16[$19>>1] = 2;
  STACKTOP = sp;return ($13|0);
 } else {
  HEAP16[$19>>1] = 0;
  STACKTOP = sp;return ($13|0);
 }
 return 0|0;
}
function __ZL26GeomOverlapCallback_BoxBoxRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 36|0;
 $1 = sp;
 $2 = (($geom0) + 4|0);
 $3 = (($transform0) + 16|0);
 $4 = Math_fround(HEAPF32[$transform0>>2]);
 $5 = (($transform0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform0) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($transform0) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($4 + $4);
 $12 = Math_fround($6 + $6);
 $13 = Math_fround($8 + $8);
 $14 = Math_fround($4 * $11);
 $15 = Math_fround($6 * $12);
 $16 = Math_fround($8 * $13);
 $17 = Math_fround($11 * $6);
 $18 = Math_fround($11 * $8);
 $19 = Math_fround($11 * $10);
 $20 = Math_fround($12 * $8);
 $21 = Math_fround($12 * $10);
 $22 = Math_fround($13 * $10);
 $23 = Math_fround(Math_fround(1.0) - $15);
 $24 = Math_fround($23 - $16);
 $25 = Math_fround($17 + $22);
 $26 = Math_fround($18 - $21);
 HEAPF32[$0>>2] = $24;
 $27 = (($0) + 4|0);
 HEAPF32[$27>>2] = $25;
 $28 = (($0) + 8|0);
 HEAPF32[$28>>2] = $26;
 $29 = Math_fround($17 - $22);
 $30 = Math_fround(Math_fround(1.0) - $14);
 $31 = Math_fround($30 - $16);
 $32 = Math_fround($20 + $19);
 $33 = (($0) + 12|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($0) + 16|0);
 HEAPF32[$34>>2] = $31;
 $35 = (($0) + 20|0);
 HEAPF32[$35>>2] = $32;
 $36 = Math_fround($18 + $21);
 $37 = Math_fround($20 - $19);
 $38 = Math_fround($30 - $15);
 $39 = (($0) + 24|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($0) + 28|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($0) + 32|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($geom1) + 4|0);
 $43 = (($transform1) + 16|0);
 $44 = Math_fround(HEAPF32[$transform1>>2]);
 $45 = (($transform1) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($transform1) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($transform1) + 12|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($44 + $44);
 $52 = Math_fround($46 + $46);
 $53 = Math_fround($48 + $48);
 $54 = Math_fround($44 * $51);
 $55 = Math_fround($46 * $52);
 $56 = Math_fround($48 * $53);
 $57 = Math_fround($51 * $46);
 $58 = Math_fround($51 * $48);
 $59 = Math_fround($51 * $50);
 $60 = Math_fround($52 * $48);
 $61 = Math_fround($52 * $50);
 $62 = Math_fround($53 * $50);
 $63 = Math_fround(Math_fround(1.0) - $55);
 $64 = Math_fround($63 - $56);
 $65 = Math_fround($57 + $62);
 $66 = Math_fround($58 - $61);
 HEAPF32[$1>>2] = $64;
 $67 = (($1) + 4|0);
 HEAPF32[$67>>2] = $65;
 $68 = (($1) + 8|0);
 HEAPF32[$68>>2] = $66;
 $69 = Math_fround($57 - $62);
 $70 = Math_fround(Math_fround(1.0) - $54);
 $71 = Math_fround($70 - $56);
 $72 = Math_fround($60 + $59);
 $73 = (($1) + 12|0);
 HEAPF32[$73>>2] = $69;
 $74 = (($1) + 16|0);
 HEAPF32[$74>>2] = $71;
 $75 = (($1) + 20|0);
 HEAPF32[$75>>2] = $72;
 $76 = Math_fround($58 + $61);
 $77 = Math_fround($60 - $59);
 $78 = Math_fround($70 - $55);
 $79 = (($1) + 24|0);
 HEAPF32[$79>>2] = $76;
 $80 = (($1) + 28|0);
 HEAPF32[$80>>2] = $77;
 $81 = (($1) + 32|0);
 HEAPF32[$81>>2] = $78;
 $82 = (__ZN5physx2Gu15intersectOBBOBBERKNS_6PxVec3ES3_RKNS_7PxMat33ES3_S3_S6_b($2,$3,$0,$42,$43,$1,1)|0);
 STACKTOP = sp;return ($82|0);
}
function __ZL29GeomOverlapCallback_BoxConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $$$i = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0);
 var $8 = 0, $9 = Math_fround(0), $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($geom1) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($cache|0)==(0|0);
 if ($2) {
  $14 = Math_fround(0.0);$16 = Math_fround(0.0);$18 = Math_fround(1.0);
 } else {
  $3 = (($cache) + 12|0);
  $4 = HEAP16[$3>>1]|0;
  $5 = ($4<<16>>16)==(2);
  $$$i = $5 ? $cache : 0;
  $6 = ($$$i|0)==(0|0);
  if ($6) {
   $14 = Math_fround(0.0);$16 = Math_fround(0.0);$18 = Math_fround(1.0);
  } else {
   $7 = Math_fround(HEAPF32[$$$i>>2]);
   $8 = (($$$i) + 4|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = (($$$i) + 8|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $14 = $7;$16 = $9;$18 = $11;
  }
 }
 $12 = (($geom1) + 4|0);
 $13 = (__ZN5physx2Gu18intersectBoxConvexERKNS_13PxBoxGeometryERKNS_11PxTransformERKNS0_10ConvexMeshERKNS_11PxMeshScaleES6_PNS_6PxVec3E($geom0,$transform0,$1,$12,$transform1,0)|0);
 $$not = $13 ^ 1;
 $brmerge = $2 | $$not;
 if (!($brmerge)) {
  HEAPF32[$cache>>2] = $14;
  $15 = (($cache) + 4|0);
  HEAPF32[$15>>2] = $16;
  $17 = (($cache) + 8|0);
  HEAPF32[$17>>2] = $18;
 }
 if ($2) {
  STACKTOP = sp;return ($13|0);
 }
 $19 = (($cache) + 12|0);
 if ($13) {
  HEAP16[$19>>1] = 2;
  STACKTOP = sp;return ($13|0);
 } else {
  HEAP16[$19>>1] = 0;
  STACKTOP = sp;return ($13|0);
 }
 return 0|0;
}
function __ZL32GeomOverlapCallback_ConvexConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $$$i$i = Math_fround(0), $$$i$i8 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0;
 var $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0);
 var $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0;
 var $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $contactA = 0;
 var $contactB = 0, $convexHull0 = 0, $convexHull1 = 0, $normal = 0, $sqDist = 0, $sqTolerance = 0, $vQuat0 = 0, $vQuat1 = 0, $vScale0 = 0, $vScale1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 640|0;
 $zeroV = sp + 624|0;
 $vScale0 = sp + 608|0;
 $vQuat0 = sp + 592|0;
 $vScale1 = sp + 576|0;
 $vQuat1 = sp + 560|0;
 $aToB = sp + 496|0;
 $convexHull0 = sp + 288|0;
 $convexHull1 = sp + 64|0;
 $sqTolerance = sp + 48|0;
 $contactA = sp + 32|0;
 $contactB = sp + 16|0;
 $normal = sp;
 $sqDist = sp + 272|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $0 = (($geom0) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($geom1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 16|0);
 $5 = (($3) + 16|0);
 $6 = (($geom0) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($geom0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($geom0) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$vScale0>>2] = $7;
 $12 = (($vScale0) + 4|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($vScale0) + 8|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($vScale0) + 12|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($geom0) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($geom0) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($geom0) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($geom0) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$vQuat0>>2] = $16;
 $23 = (($vQuat0) + 4|0);
 HEAPF32[$23>>2] = $18;
 $24 = (($vQuat0) + 8|0);
 HEAPF32[$24>>2] = $20;
 $25 = (($vQuat0) + 12|0);
 HEAPF32[$25>>2] = $22;
 $26 = (($geom1) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($geom1) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($geom1) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$vScale1>>2] = $27;
 $32 = (($vScale1) + 4|0);
 HEAPF32[$32>>2] = $29;
 $33 = (($vScale1) + 8|0);
 HEAPF32[$33>>2] = $31;
 $34 = (($vScale1) + 12|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($geom1) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($geom1) + 20|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($geom1) + 24|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($geom1) + 28|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$vQuat1>>2] = $36;
 $43 = (($vQuat1) + 4|0);
 HEAPF32[$43>>2] = $38;
 $44 = (($vQuat1) + 8|0);
 HEAPF32[$44>>2] = $40;
 $45 = (($vQuat1) + 12|0);
 HEAPF32[$45>>2] = $42;
 $46 = Math_fround(HEAPF32[$transform0>>2]);
 $47 = (($transform0) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($transform0) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($transform0) + 12|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($transform0) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($53) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($53) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround(HEAPF32[$transform1>>2]);
 $60 = (($transform1) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($transform1) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($transform1) + 12|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($transform1) + 16|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($66) + 4|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($66) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround(-$59);
 $73 = Math_fround(-$61);
 $74 = Math_fround(-$63);
 $75 = Math_fround($54 - $67);
 $76 = Math_fround($56 - $69);
 $77 = Math_fround($58 - $71);
 $78 = Math_fround($65 * $65);
 $79 = Math_fround($78 + Math_fround(-0.5));
 $80 = Math_fround($79 * $75);
 $81 = Math_fround($79 * $76);
 $82 = Math_fround($79 * $77);
 $83 = Math_fround($77 * $73);
 $84 = Math_fround($76 * $74);
 $85 = Math_fround($83 - $84);
 $86 = Math_fround($75 * $74);
 $87 = Math_fround($77 * $72);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($76 * $72);
 $90 = Math_fround($75 * $73);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($65 * $85);
 $93 = Math_fround($65 * $88);
 $94 = Math_fround($65 * $91);
 $95 = Math_fround($80 + $92);
 $96 = Math_fround($81 + $93);
 $97 = Math_fround($82 + $94);
 $98 = Math_fround($75 * $72);
 $99 = Math_fround($76 * $73);
 $100 = Math_fround($98 + $99);
 $101 = Math_fround($77 * $74);
 $102 = Math_fround($100 + $101);
 $103 = Math_fround($102 * $72);
 $104 = Math_fround($102 * $73);
 $105 = Math_fround($102 * $74);
 $106 = Math_fround($103 + $95);
 $107 = Math_fround($104 + $96);
 $108 = Math_fround($97 + $105);
 $109 = Math_fround($106 * Math_fround(2.0));
 $110 = Math_fround($107 * Math_fround(2.0));
 $111 = Math_fround($108 * Math_fround(2.0));
 $112 = Math_fround($52 * $65);
 $113 = Math_fround($46 * $72);
 $114 = Math_fround($48 * $73);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($50 * $74);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($112 - $117);
 $119 = Math_fround($52 * $72);
 $120 = Math_fround($52 * $73);
 $121 = Math_fround($52 * $74);
 $122 = Math_fround($46 * $65);
 $123 = Math_fround($48 * $65);
 $124 = Math_fround($50 * $65);
 $125 = Math_fround($50 * $73);
 $126 = Math_fround($48 * $74);
 $127 = Math_fround($125 - $126);
 $128 = Math_fround($46 * $74);
 $129 = Math_fround($50 * $72);
 $130 = Math_fround($128 - $129);
 $131 = Math_fround($48 * $72);
 $132 = Math_fround($46 * $73);
 $133 = Math_fround($131 - $132);
 $134 = Math_fround($119 + $122);
 $135 = Math_fround($120 + $123);
 $136 = Math_fround($124 + $121);
 $137 = Math_fround($127 + $134);
 $138 = Math_fround($130 + $135);
 $139 = Math_fround($133 + $136);
 $140 = (($aToB) + 48|0);
 HEAPF32[$140>>2] = $109;
 $141 = (($aToB) + 52|0);
 HEAPF32[$141>>2] = $110;
 $142 = (($aToB) + 56|0);
 HEAPF32[$142>>2] = $111;
 $143 = (($aToB) + 60|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = Math_fround($137 + $137);
 $145 = Math_fround($138 + $138);
 $146 = Math_fround($139 + $139);
 $147 = Math_fround($137 * $144);
 $148 = Math_fround($138 * $145);
 $149 = Math_fround($139 * $146);
 $150 = Math_fround($138 * $144);
 $151 = Math_fround($139 * $144);
 $152 = Math_fround($118 * $144);
 $153 = Math_fround($139 * $145);
 $154 = Math_fround($118 * $145);
 $155 = Math_fround($118 * $146);
 $156 = Math_fround(Math_fround(1.0) - $147);
 $157 = Math_fround(Math_fround(1.0) - $148);
 $158 = Math_fround($157 - $149);
 $159 = Math_fround($150 + $155);
 $160 = Math_fround($151 - $154);
 $161 = Math_fround($150 - $155);
 $162 = Math_fround($156 - $149);
 $163 = Math_fround($153 + $152);
 $164 = Math_fround($151 + $154);
 $165 = Math_fround($153 - $152);
 $166 = Math_fround($156 - $148);
 HEAPF32[$aToB>>2] = $158;
 $167 = (($aToB) + 4|0);
 HEAPF32[$167>>2] = $159;
 $168 = (($aToB) + 8|0);
 HEAPF32[$168>>2] = $160;
 $169 = (($aToB) + 12|0);
 HEAPF32[$169>>2] = Math_fround(0.0);
 $170 = (($aToB) + 16|0);
 HEAPF32[$170>>2] = $161;
 $171 = (($aToB) + 20|0);
 HEAPF32[$171>>2] = $162;
 $172 = (($aToB) + 24|0);
 HEAPF32[$172>>2] = $163;
 $173 = (($aToB) + 28|0);
 HEAPF32[$173>>2] = Math_fround(0.0);
 $174 = (($aToB) + 32|0);
 HEAPF32[$174>>2] = $164;
 $175 = (($aToB) + 36|0);
 HEAPF32[$175>>2] = $165;
 $176 = (($aToB) + 40|0);
 HEAPF32[$176>>2] = $166;
 $177 = (($aToB) + 44|0);
 HEAPF32[$177>>2] = Math_fround(0.0);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull0,$4,$zeroV,$vScale0,$vQuat0);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull1,$5,$zeroV,$vScale1,$vQuat1);
 $178 = (($1) + 68|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = (($1) + 72|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = (($1) + 76|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = Math_fround(HEAPF32[$vScale0>>2]);
 $185 = Math_fround(HEAPF32[$12>>2]);
 $186 = Math_fround(HEAPF32[$13>>2]);
 $187 = Math_fround($179 * $184);
 $188 = Math_fround($181 * $185);
 $189 = Math_fround($183 * $186);
 $190 = !($187 <= $188);
 $$$i$i8 = $190 ? $188 : $187;
 $191 = !($$$i$i8 <= $189);
 $192 = $191 ? $189 : $$$i$i8;
 $193 = Math_fround($192 * Math_fround(0.00999999977648258209228));
 $194 = (($3) + 68|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = (($3) + 72|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = (($3) + 76|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = Math_fround(HEAPF32[$vScale1>>2]);
 $201 = Math_fround(HEAPF32[$32>>2]);
 $202 = Math_fround(HEAPF32[$33>>2]);
 $203 = Math_fround($195 * $200);
 $204 = Math_fround($197 * $201);
 $205 = Math_fround($199 * $202);
 $206 = !($203 <= $204);
 $$$i$i = $206 ? $204 : $203;
 $207 = !($$$i$i <= $205);
 $208 = $207 ? $205 : $$$i$i;
 $209 = Math_fround($208 * Math_fround(0.00999999977648258209228));
 $210 = Math_fround($193 + $209);
 $211 = Math_fround($210 * $210);
 HEAPF32[$sqTolerance>>2] = $211;
 $212 = (__ZN5physx2Gu22GJKRelativeTesselationERKNS0_11ConvexHullVES3_RKNS_6shdfnd3aos15PsMatTransformVERKNS5_6FloatVERNS5_5Vec3VESD_SD_RS9_($convexHull0,$convexHull1,$aToB,$sqTolerance,$contactA,$contactB,$normal,$sqDist)|0);
 $213 = ($212|0)==(1);
 $214 = ($cache|0)==(0|0);
 if ($214) {
  STACKTOP = sp;return ($213|0);
 }
 $215 = (($cache) + 12|0);
 if ($213) {
  HEAP16[$215>>1] = 2;
  STACKTOP = sp;return ($213|0);
 } else {
  HEAP16[$215>>1] = 0;
  STACKTOP = sp;return ($213|0);
 }
 return 0|0;
}
function __ZL28GeomOverlapCallback_MeshMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5physx2Gu25GetGeomOverlapMethodTableEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (548024|0);
}
function __ZN5physx2Gu20registerHeightFieldsEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[((548024 + 24|0))>>2] = 185;
 HEAP32[((548024 + 52|0))>>2] = 186;
 HEAP32[((548024 + 80|0))>>2] = 187;
 HEAP32[((548024 + 108|0))>>2] = 188;
 HEAP32[((548024 + 136|0))>>2] = 189;
 HEAP32[((548024 + 164|0))>>2] = 190;
 HEAP32[((548024 + 192|0))>>2] = 191;
 STACKTOP = sp;return;
}
function __ZL35GeomOverlapCallback_MeshHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZL42GeomOverlapCallback_HeightfieldHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z11raycast_boxRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_($geom,$pose,$rayOrigin,$rayDir,$maxDist,$hintFlags,$maxHits,$hits,$anyHit,$hitCB,$userData) {
 $geom = $geom|0;
 $pose = $pose|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxDist = Math_fround($maxDist);
 $hintFlags = $hintFlags|0;
 $maxHits = $maxHits|0;
 $hits = $hits|0;
 $anyHit = $anyHit|0;
 $hitCB = $hitCB|0;
 $userData = $userData|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0;
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $dimensions = 0, $localDir = 0, $localImpact = 0, $localOrigin = 0, $n = 0, $or$cond = 0, $or$cond16 = 0, $t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $localOrigin = sp + 64|0;
 $localDir = sp;
 $localImpact = sp + 12|0;
 $t = sp + 24|0;
 $dimensions = sp + 28|0;
 $0 = sp + 40|0;
 $n = sp + 52|0;
 $1 = Math_fround(HEAPF32[$rayOrigin>>2]);
 $2 = (($pose) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($rayOrigin) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($pose) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($rayOrigin) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($pose) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($localOrigin) + 4|0);
 $16 = (($localOrigin) + 8|0);
 $17 = Math_fround($4 * Math_fround(2.0));
 $18 = Math_fround($9 * Math_fround(2.0));
 $19 = Math_fround($14 * Math_fround(2.0));
 $20 = (($pose) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $21);
 $23 = Math_fround($22 + Math_fround(-0.5));
 $24 = Math_fround(HEAPF32[$pose>>2]);
 $25 = Math_fround($17 * $24);
 $26 = (($pose) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($18 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($pose) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($19 * $31);
 $33 = Math_fround($29 + $32);
 $34 = Math_fround($17 * $23);
 $35 = Math_fround($19 * $27);
 $36 = Math_fround($18 * $31);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($21 * $37);
 $39 = Math_fround($34 - $38);
 $40 = Math_fround($24 * $33);
 $41 = Math_fround($40 + $39);
 $42 = Math_fround($18 * $23);
 $43 = Math_fround($17 * $31);
 $44 = Math_fround($19 * $24);
 $45 = Math_fround($43 - $44);
 $46 = Math_fround($21 * $45);
 $47 = Math_fround($42 - $46);
 $48 = Math_fround($27 * $33);
 $49 = Math_fround($48 + $47);
 $50 = Math_fround($19 * $23);
 $51 = Math_fround($18 * $24);
 $52 = Math_fround($17 * $27);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($21 * $53);
 $55 = Math_fround($50 - $54);
 $56 = Math_fround($31 * $33);
 $57 = Math_fround($55 + $56);
 HEAPF32[$localOrigin>>2] = $41;
 HEAPF32[$15>>2] = $49;
 HEAPF32[$16>>2] = $57;
 $58 = Math_fround(HEAPF32[$rayDir>>2]);
 $59 = Math_fround($58 * Math_fround(2.0));
 $60 = (($rayDir) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 * Math_fround(2.0));
 $63 = (($rayDir) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 * Math_fround(2.0));
 $66 = Math_fround($59 * $24);
 $67 = Math_fround($62 * $27);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($65 * $31);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($59 * $23);
 $72 = Math_fround($65 * $27);
 $73 = Math_fround($62 * $31);
 $74 = Math_fround($72 - $73);
 $75 = Math_fround($21 * $74);
 $76 = Math_fround($71 - $75);
 $77 = Math_fround($24 * $70);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($62 * $23);
 $80 = Math_fround($59 * $31);
 $81 = Math_fround($65 * $24);
 $82 = Math_fround($80 - $81);
 $83 = Math_fround($21 * $82);
 $84 = Math_fround($79 - $83);
 $85 = Math_fround($27 * $70);
 $86 = Math_fround($85 + $84);
 $87 = Math_fround($65 * $23);
 $88 = Math_fround($62 * $24);
 $89 = Math_fround($59 * $27);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($21 * $90);
 $92 = Math_fround($87 - $91);
 $93 = Math_fround($31 * $70);
 $94 = Math_fround($92 + $93);
 HEAPF32[$localDir>>2] = $78;
 $95 = (($localDir) + 4|0);
 HEAPF32[$95>>2] = $86;
 $96 = (($localDir) + 8|0);
 HEAPF32[$96>>2] = $94;
 $97 = (($geom) + 4|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 HEAPF32[$dimensions>>2] = $98;
 $99 = (($dimensions) + 4|0);
 $100 = (($geom) + 8|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 HEAPF32[$99>>2] = $101;
 $102 = (($dimensions) + 8|0);
 $103 = (($geom) + 12|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 HEAPF32[$102>>2] = $104;
 $105 = Math_fround(-$98);
 $106 = Math_fround(-$101);
 $107 = Math_fround(-$104);
 HEAPF32[$0>>2] = $105;
 $108 = (($0) + 4|0);
 HEAPF32[$108>>2] = $106;
 $109 = (($0) + 8|0);
 HEAPF32[$109>>2] = $107;
 $110 = (__ZN5physx2Gu17rayAABBIntersect2ERKNS_6PxVec3ES3_S3_S3_RS1_Rf($0,$dimensions,$localOrigin,$localDir,$localImpact,$t)|0);
 $111 = ($110|0)==(0);
 $112 = Math_fround(HEAPF32[$t>>2]);
 $113 = $112 > $maxDist;
 $or$cond = $111 | $113;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $114 = (($hits) + 40|0);
 HEAPF32[$114>>2] = $112;
 $115 = (($hits) + 8|0);
 HEAP32[$115>>2] = -1;
 $116 = (($hits) + 44|0);
 HEAPF32[$116>>2] = Math_fround(0.0);
 $117 = (($hits) + 48|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 $118 = HEAP16[$hintFlags>>1]|0;
 $119 = $118 & 1;
 $120 = ($119<<16>>16)!=(0);
 $121 = $112 != Math_fround(0.0);
 $or$cond16 = $120 & $121;
 if ($or$cond16) {
  $122 = Math_fround(HEAPF32[$localImpact>>2]);
  $123 = Math_fround($122 * Math_fround(2.0));
  $124 = (($localImpact) + 4|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = Math_fround($125 * Math_fround(2.0));
  $127 = (($localImpact) + 8|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = Math_fround($128 * Math_fround(2.0));
  $130 = Math_fround(HEAPF32[$20>>2]);
  $131 = Math_fround($130 * $130);
  $132 = Math_fround($131 + Math_fround(-0.5));
  $133 = Math_fround(HEAPF32[$pose>>2]);
  $134 = Math_fround($123 * $133);
  $135 = Math_fround(HEAPF32[$26>>2]);
  $136 = Math_fround($126 * $135);
  $137 = Math_fround($134 + $136);
  $138 = Math_fround(HEAPF32[$30>>2]);
  $139 = Math_fround($129 * $138);
  $140 = Math_fround($137 + $139);
  $141 = Math_fround($123 * $132);
  $142 = Math_fround($129 * $135);
  $143 = Math_fround($126 * $138);
  $144 = Math_fround($142 - $143);
  $145 = Math_fround($130 * $144);
  $146 = Math_fround($141 + $145);
  $147 = Math_fround($133 * $140);
  $148 = Math_fround($147 + $146);
  $149 = Math_fround($126 * $132);
  $150 = Math_fround($123 * $138);
  $151 = Math_fround($129 * $133);
  $152 = Math_fround($150 - $151);
  $153 = Math_fround($130 * $152);
  $154 = Math_fround($149 + $153);
  $155 = Math_fround($135 * $140);
  $156 = Math_fround($155 + $154);
  $157 = Math_fround($129 * $132);
  $158 = Math_fround($126 * $133);
  $159 = Math_fround($123 * $135);
  $160 = Math_fround($158 - $159);
  $161 = Math_fround($130 * $160);
  $162 = Math_fround($157 + $161);
  $163 = Math_fround($138 * $140);
  $164 = Math_fround($162 + $163);
  $165 = Math_fround(HEAPF32[$2>>2]);
  $166 = Math_fround($165 + $148);
  $167 = Math_fround(HEAPF32[$7>>2]);
  $168 = Math_fround($167 + $156);
  $169 = Math_fround(HEAPF32[$12>>2]);
  $170 = Math_fround($169 + $164);
  $171 = (($hits) + 16|0);
  HEAPF32[$171>>2] = $166;
  $172 = (($hits) + 20|0);
  HEAPF32[$172>>2] = $168;
  $173 = (($hits) + 24|0);
  HEAPF32[$173>>2] = $170;
  $177 = 5;
 } else {
  $177 = 4;
 }
 $174 = $118 & 2;
 $175 = ($174<<16>>16)==(0);
 do {
  if ($175) {
   $242 = (($hits) + 28|0);
   HEAPF32[$242>>2] = Math_fround(0.0);
   $243 = (($hits) + 32|0);
   HEAPF32[$243>>2] = Math_fround(0.0);
   $244 = (($hits) + 36|0);
   HEAPF32[$244>>2] = Math_fround(0.0);
   $246 = $177;
  } else {
   $176 = $177&65535;
   $178 = $176 | 2;
   $179 = $178&65535;
   $180 = $112 == Math_fround(0.0);
   if ($180) {
    $181 = Math_fround(HEAPF32[$rayDir>>2]);
    $182 = Math_fround(-$181);
    $183 = Math_fround(HEAPF32[$60>>2]);
    $184 = Math_fround(-$183);
    $185 = Math_fround(HEAPF32[$63>>2]);
    $186 = Math_fround(-$185);
    $187 = (($hits) + 28|0);
    HEAPF32[$187>>2] = $182;
    $188 = (($hits) + 32|0);
    HEAPF32[$188>>2] = $184;
    $189 = (($hits) + 36|0);
    HEAPF32[$189>>2] = $186;
    $246 = $179;
    break;
   } else {
    $190 = (($110) + -1)|0;
    HEAPF32[$n>>2] = Math_fround(0.0);
    $191 = (($n) + 4|0);
    HEAPF32[$191>>2] = Math_fround(0.0);
    $192 = (($n) + 8|0);
    HEAPF32[$192>>2] = Math_fround(0.0);
    $193 = (($localImpact) + ($190<<2)|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = $194 > Math_fround(0.0);
    $196 = $195 ? Math_fround(1.0) : Math_fround(-1.0);
    $197 = (($n) + ($190<<2)|0);
    HEAPF32[$197>>2] = $196;
    $198 = Math_fround(HEAPF32[$n>>2]);
    $199 = Math_fround($198 * Math_fround(2.0));
    $200 = Math_fround(HEAPF32[$191>>2]);
    $201 = Math_fround($200 * Math_fround(2.0));
    $202 = Math_fround(HEAPF32[$192>>2]);
    $203 = Math_fround($202 * Math_fround(2.0));
    $204 = Math_fround(HEAPF32[$20>>2]);
    $205 = Math_fround($204 * $204);
    $206 = Math_fround($205 + Math_fround(-0.5));
    $207 = Math_fround(HEAPF32[$pose>>2]);
    $208 = Math_fround($199 * $207);
    $209 = Math_fround(HEAPF32[$26>>2]);
    $210 = Math_fround($201 * $209);
    $211 = Math_fround($208 + $210);
    $212 = Math_fround(HEAPF32[$30>>2]);
    $213 = Math_fround($203 * $212);
    $214 = Math_fround($211 + $213);
    $215 = Math_fround($199 * $206);
    $216 = Math_fround($203 * $209);
    $217 = Math_fround($201 * $212);
    $218 = Math_fround($216 - $217);
    $219 = Math_fround($204 * $218);
    $220 = Math_fround($215 + $219);
    $221 = Math_fround($207 * $214);
    $222 = Math_fround($221 + $220);
    $223 = Math_fround($201 * $206);
    $224 = Math_fround($199 * $212);
    $225 = Math_fround($203 * $207);
    $226 = Math_fround($224 - $225);
    $227 = Math_fround($204 * $226);
    $228 = Math_fround($223 + $227);
    $229 = Math_fround($209 * $214);
    $230 = Math_fround($229 + $228);
    $231 = Math_fround($203 * $206);
    $232 = Math_fround($201 * $207);
    $233 = Math_fround($199 * $209);
    $234 = Math_fround($232 - $233);
    $235 = Math_fround($204 * $234);
    $236 = Math_fround($231 + $235);
    $237 = Math_fround($212 * $214);
    $238 = Math_fround($236 + $237);
    $239 = (($hits) + 28|0);
    HEAPF32[$239>>2] = $222;
    $240 = (($hits) + 32|0);
    HEAPF32[$240>>2] = $230;
    $241 = (($hits) + 36|0);
    HEAPF32[$241>>2] = $238;
    $246 = $179;
    break;
   }
  }
 } while(0);
 $245 = (($hits) + 12|0);
 HEAP16[$245>>1] = $246;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z14raycast_sphereRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_($geom,$pose,$rayOrigin,$rayDir,$maxDist,$hintFlags,$maxHits,$hits,$anyHit,$hitCB,$userData) {
 $geom = $geom|0;
 $pose = $pose|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxDist = Math_fround($maxDist);
 $hintFlags = $hintFlags|0;
 $maxHits = $maxHits|0;
 $hits = $hits|0;
 $anyHit = $anyHit|0;
 $hitCB = $hitCB|0;
 $userData = $userData|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($pose) + 16|0);
 $1 = (($geom) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($hits) + 40|0);
 $4 = (($hits) + 16|0);
 $5 = (__ZN5physx2Gu18intersectRaySphereERKNS_6PxVec3ES3_fS3_fRfPS1_($rayOrigin,$rayDir,$maxDist,$0,$2,$3,$4)|0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($hits) + 8|0);
 HEAP32[$6>>2] = -1;
 $7 = (($hits) + 44|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($hits) + 48|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = Math_fround(HEAPF32[$3>>2]);
 $10 = $9 != Math_fround(0.0);
 $11 = $10 ? 5 : 4;
 $12 = HEAP16[$hintFlags>>1]|0;
 $13 = $12 & 2;
 $14 = ($13<<16>>16)==(0);
 if ($14) {
  $56 = (($hits) + 28|0);
  HEAPF32[$56>>2] = Math_fround(0.0);
  $57 = (($hits) + 32|0);
  HEAPF32[$57>>2] = Math_fround(0.0);
  $58 = (($hits) + 36|0);
  HEAPF32[$58>>2] = Math_fround(0.0);
  $60 = $11;
 } else {
  $15 = $9 == Math_fround(0.0);
  $16 = (($hits) + 28|0);
  if ($15) {
   $17 = Math_fround(HEAPF32[$rayDir>>2]);
   $18 = Math_fround(-$17);
   $19 = (($rayDir) + 4|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround(-$20);
   $22 = (($rayDir) + 8|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround(-$23);
   HEAPF32[$16>>2] = $18;
   $25 = (($hits) + 32|0);
   HEAPF32[$25>>2] = $21;
   $26 = (($hits) + 36|0);
   HEAPF32[$26>>2] = $24;
  } else {
   $27 = Math_fround(HEAPF32[$4>>2]);
   $28 = Math_fround(HEAPF32[$0>>2]);
   $29 = Math_fround($27 - $28);
   $30 = (($hits) + 20|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = (($pose) + 20|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = Math_fround($31 - $33);
   $35 = (($hits) + 24|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = (($pose) + 24|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($36 - $38);
   HEAPF32[$16>>2] = $29;
   $40 = (($hits) + 32|0);
   HEAPF32[$40>>2] = $34;
   $41 = (($hits) + 36|0);
   HEAPF32[$41>>2] = $39;
   $42 = Math_fround($29 * $29);
   $43 = Math_fround($34 * $34);
   $44 = Math_fround($42 + $43);
   $45 = Math_fround($39 * $39);
   $46 = Math_fround($45 + $44);
   $47 = (Math_fround(Math_sqrt((Math_fround($46)))));
   $48 = $47 > Math_fround(0.0);
   if ($48) {
    $49 = Math_fround(Math_fround(1.0) / $47);
    $50 = Math_fround($29 * $49);
    HEAPF32[$16>>2] = $50;
    $51 = Math_fround($34 * $49);
    HEAPF32[$40>>2] = $51;
    $52 = Math_fround($39 * $49);
    HEAPF32[$41>>2] = $52;
   }
  }
  $53 = $11&65535;
  $54 = $53 | 2;
  $55 = $54&65535;
  $60 = $55;
 }
 $59 = (($hits) + 12|0);
 HEAP16[$59>>1] = $60;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z15raycast_capsuleRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_($geom,$pose,$rayOrigin,$rayDir,$maxDist,$hintFlags,$maxHits,$hits,$anyHit,$hitCB,$userData) {
 $geom = $geom|0;
 $pose = $pose|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxDist = Math_fround($maxDist);
 $hintFlags = $hintFlags|0;
 $maxHits = $maxHits|0;
 $hits = $hits|0;
 $anyHit = $anyHit|0;
 $hitCB = $hitCB|0;
 $userData = $userData|0;
 var $$ = Math_fround(0), $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0;
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $capsule = 0;
 var $capsuleT = 0, $or$cond = 0, $s = 0, $t$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $capsule = sp + 12|0;
 $s = sp;
 $capsuleT = sp + 8|0;
 $0 = Math_fround(HEAPF32[$pose>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($pose) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround($3 * $4);
 $6 = Math_fround($5 + Math_fround(-1.0));
 $7 = Math_fround($0 * $1);
 $8 = Math_fround($7 + $6);
 $9 = (($pose) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $4);
 $12 = (($pose) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($1 * $13);
 $15 = Math_fround($11 + $14);
 $16 = Math_fround($4 * $13);
 $17 = Math_fround($1 * $10);
 $18 = Math_fround($17 - $16);
 $19 = (($geom) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $8);
 $22 = Math_fround($20 * $15);
 $23 = Math_fround($20 * $18);
 $24 = (($pose) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $21);
 $27 = (($pose) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + $22);
 $30 = (($pose) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($23 + $31);
 HEAPF32[$capsule>>2] = $26;
 $33 = (($capsule) + 4|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($capsule) + 8|0);
 HEAPF32[$34>>2] = $32;
 $35 = Math_fround($25 - $21);
 $36 = Math_fround($28 - $22);
 $37 = Math_fround($31 - $23);
 $38 = (($capsule) + 12|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($capsule) + 16|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($capsule) + 20|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($geom) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($capsule) + 24|0);
 HEAPF32[$43>>2] = $42;
 $44 = (__ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($rayOrigin,$rayDir,$capsule,$s)|0);
 if ((($44|0) == 1)) {
  $45 = Math_fround(HEAPF32[$s>>2]);
  $t$0 = $45;
 } else if ((($44|0) == 0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $46 = Math_fround(HEAPF32[$s>>2]);
  $47 = $46 < Math_fround(-9.99999997475242707878E-7);
  $48 = (($s) + 4|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = $49 < Math_fround(-9.99999997475242707878E-7);
  $or$cond = $47 & $50;
  if ($or$cond) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $51 = $46 < $49;
  $$ = $51 ? $46 : $49;
  $52 = $$ < Math_fround(0.0);
  if ($52) {
   $t$0 = Math_fround(0.0);
  } else {
   $t$0 = $$;
  }
 }
 $53 = $t$0 > $maxDist;
 if ($53) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $54 = $t$0 != Math_fround(0.0);
 $55 = $54 ? 5 : 4;
 $56 = (($hits) + 16|0);
 $57 = Math_fround(HEAPF32[$rayDir>>2]);
 $58 = Math_fround($t$0 * $57);
 $59 = (($rayDir) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($t$0 * $60);
 $62 = (($rayDir) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($t$0 * $63);
 $65 = Math_fround(HEAPF32[$rayOrigin>>2]);
 $66 = Math_fround($58 + $65);
 $67 = (($rayOrigin) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($61 + $68);
 $70 = (($rayOrigin) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($64 + $71);
 HEAPF32[$56>>2] = $66;
 $73 = (($hits) + 20|0);
 HEAPF32[$73>>2] = $69;
 $74 = (($hits) + 24|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($hits) + 40|0);
 HEAPF32[$75>>2] = $t$0;
 $76 = (($hits) + 8|0);
 HEAP32[$76>>2] = -1;
 $77 = (($hits) + 44|0);
 HEAPF32[$77>>2] = Math_fround(0.0);
 $78 = (($hits) + 48|0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = HEAP16[$hintFlags>>1]|0;
 $80 = $79 & 2;
 $81 = ($80<<16>>16)==(0);
 do {
  if ($81) {
   $132 = (($hits) + 28|0);
   HEAPF32[$132>>2] = Math_fround(0.0);
   $133 = (($hits) + 32|0);
   HEAPF32[$133>>2] = Math_fround(0.0);
   $134 = (($hits) + 36|0);
   HEAPF32[$134>>2] = Math_fround(0.0);
   $136 = $55;
  } else {
   $82 = $55&65535;
   $83 = $82 | 2;
   $84 = $83&65535;
   $85 = $t$0 == Math_fround(0.0);
   if ($85) {
    $86 = Math_fround(HEAPF32[$rayDir>>2]);
    $87 = Math_fround(-$86);
    $88 = Math_fround(HEAPF32[$59>>2]);
    $89 = Math_fround(-$88);
    $90 = Math_fround(HEAPF32[$62>>2]);
    $91 = Math_fround(-$90);
    $92 = (($hits) + 28|0);
    HEAPF32[$92>>2] = $87;
    $93 = (($hits) + 32|0);
    HEAPF32[$93>>2] = $89;
    $94 = (($hits) + 36|0);
    HEAPF32[$94>>2] = $91;
    $136 = $84;
    break;
   }
   $95 = (($capsule) + 12|0);
   (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($capsule,$95,$56,$capsuleT)));
   $96 = Math_fround(HEAPF32[$capsuleT>>2]);
   $97 = Math_fround(HEAPF32[$38>>2]);
   $98 = Math_fround(HEAPF32[$capsule>>2]);
   $99 = Math_fround($97 - $98);
   $100 = Math_fround(HEAPF32[$39>>2]);
   $101 = Math_fround(HEAPF32[$33>>2]);
   $102 = Math_fround($100 - $101);
   $103 = Math_fround(HEAPF32[$40>>2]);
   $104 = Math_fround(HEAPF32[$34>>2]);
   $105 = Math_fround($103 - $104);
   $106 = Math_fround($96 * $99);
   $107 = Math_fround($96 * $102);
   $108 = Math_fround($96 * $105);
   $109 = Math_fround($98 + $106);
   $110 = Math_fround($101 + $107);
   $111 = Math_fround($104 + $108);
   $112 = (($hits) + 28|0);
   $113 = (($hits) + 32|0);
   $114 = (($hits) + 36|0);
   $115 = Math_fround(HEAPF32[$56>>2]);
   $116 = Math_fround($115 - $109);
   $117 = Math_fround(HEAPF32[$73>>2]);
   $118 = Math_fround($117 - $110);
   $119 = Math_fround(HEAPF32[$74>>2]);
   $120 = Math_fround($119 - $111);
   HEAPF32[$112>>2] = $116;
   HEAPF32[$113>>2] = $118;
   HEAPF32[$114>>2] = $120;
   $121 = Math_fround($116 * $116);
   $122 = Math_fround($118 * $118);
   $123 = Math_fround($121 + $122);
   $124 = Math_fround($120 * $120);
   $125 = Math_fround($124 + $123);
   $126 = (Math_fround(Math_sqrt((Math_fround($125)))));
   $127 = $126 > Math_fround(0.0);
   if ($127) {
    $128 = Math_fround(Math_fround(1.0) / $126);
    $129 = Math_fround($116 * $128);
    HEAPF32[$112>>2] = $129;
    $130 = Math_fround($118 * $128);
    HEAPF32[$113>>2] = $130;
    $131 = Math_fround($120 * $128);
    HEAPF32[$114>>2] = $131;
    $136 = $84;
   } else {
    $136 = $84;
   }
  }
 } while(0);
 $135 = (($hits) + 12|0);
 HEAP16[$135>>1] = $136;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z13raycast_planeRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_($geom,$pose,$rayOrigin,$rayDir,$maxDist,$hintFlags,$maxHits,$hits,$anyHit,$hitCB,$userData) {
 $geom = $geom|0;
 $pose = $pose|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxDist = Math_fround($maxDist);
 $hintFlags = $hintFlags|0;
 $maxHits = $maxHits|0;
 $hits = $hits|0;
 $anyHit = $anyHit|0;
 $hitCB = $hitCB|0;
 $userData = $userData|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $or$cond = 0, $or$cond$i = 0, $plane = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $plane = sp;
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($plane,$pose);
 $0 = Math_fround(HEAPF32[$rayDir>>2]);
 $1 = Math_fround(HEAPF32[$plane>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($rayDir) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($plane) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($rayDir) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($plane) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = !($14 >= Math_fround(0.0));
 if (!($15)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = +$14;
 $17 = $16 > -9.99999999999999954748E-8;
 $18 = $16 < 9.99999999999999954748E-8;
 $or$cond$i = $17 & $18;
 if ($or$cond$i) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = Math_fround(HEAPF32[$rayOrigin>>2]);
 $20 = Math_fround($1 * $19);
 $21 = (($rayOrigin) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($6 * $22);
 $24 = Math_fround($20 + $23);
 $25 = (($rayOrigin) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($12 * $26);
 $28 = Math_fround($24 + $27);
 $29 = (($plane) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $28);
 $32 = Math_fround(-$31);
 $33 = Math_fround($32 / $14);
 $34 = Math_fround($0 * $33);
 $35 = Math_fround($4 * $33);
 $36 = Math_fround($10 * $33);
 $37 = Math_fround($19 + $34);
 $38 = Math_fround($22 + $35);
 $39 = Math_fround($26 + $36);
 $40 = (($hits) + 16|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($hits) + 20|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($hits) + 24|0);
 HEAPF32[$42>>2] = $39;
 $43 = $33 < Math_fround(0.0);
 $44 = $33 > $maxDist;
 $or$cond = $43 | $44;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($hits) + 40|0);
 HEAPF32[$45>>2] = $33;
 $46 = (($hits) + 8|0);
 HEAP32[$46>>2] = -1;
 $47 = (($hits) + 44|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($hits) + 48|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($hits) + 12|0);
 HEAP16[$49>>1] = 5;
 $50 = (($hits) + 28|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($hits) + 32|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($hits) + 36|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = HEAP16[$hintFlags>>1]|0;
 $54 = $53 & 2;
 $55 = ($54<<16>>16)==(0);
 if ($55) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$50>>2] = $1;
 HEAPF32[$51>>2] = $6;
 HEAPF32[$52>>2] = $12;
 HEAP16[$49>>1] = 7;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z18raycast_convexMeshRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_($geom,$pose,$rayOrigin,$rayDir,$maxDist,$hintFlags,$maxHits,$hits,$anyHit,$hitCB,$userData) {
 $geom = $geom|0;
 $pose = $pose|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxDist = Math_fround($maxDist);
 $hintFlags = $hintFlags|0;
 $maxHits = $maxHits|0;
 $hits = $hits|0;
 $anyHit = $anyHit|0;
 $hitCB = $hitCB|0;
 $userData = $userData|0;
 var $$0 = 0, $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0;
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0);
 var $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0);
 var $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0);
 var $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0);
 var $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0);
 var $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0);
 var $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0);
 var $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0;
 var $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0;
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $bestPolygonIndex$038 = 0, $bestPolygonIndex$1 = 0, $bestVertSpacePlane$037 = 0, $bestVertSpacePlane$1 = 0, $currentIndex$039 = 0, $earlyestExit$040 = Math_fround(0), $earlyestExit$1 = Math_fround(0), $latestEntry$041 = Math_fround(0), $latestEntry$1 = Math_fround(0), $not$ = 0, $or$cond = 0, $originInsideAllPlanes$0$off042 = 0, $originInsideAllPlanes$1$off0 = 0, $polys$043 = 0, $world2vertexSkew = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $world2vertexSkew = sp + 56|0;
 $0 = sp;
 $1 = sp + 28|0;
 $2 = (($geom) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($geom) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(Math_fround(1.0) / $5);
 $7 = (($geom) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(Math_fround(1.0) / $8);
 $10 = (($geom) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(Math_fround(1.0) / $11);
 HEAPF32[$0>>2] = $6;
 $13 = (($0) + 4|0);
 HEAPF32[$13>>2] = $9;
 $14 = (($0) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($geom) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($0) + 12|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($geom) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($0) + 16|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($geom) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($0) + 20|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($geom) + 28|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($0) + 24|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($pose) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($pose) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($pose) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($28 * Math_fround(-2.0));
 $34 = Math_fround($30 * Math_fround(-2.0));
 $35 = Math_fround($32 * Math_fround(-2.0));
 $36 = (($pose) + 12|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * $37);
 $39 = Math_fround($38 + Math_fround(-0.5));
 $40 = Math_fround(HEAPF32[$pose>>2]);
 $41 = Math_fround($33 * $40);
 $42 = (($pose) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($34 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($pose) + 8|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($35 * $47);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround($33 * $39);
 $51 = Math_fround($35 * $43);
 $52 = Math_fround($34 * $47);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($37 * $53);
 $55 = Math_fround($50 - $54);
 $56 = Math_fround($40 * $49);
 $57 = Math_fround($56 + $55);
 $58 = Math_fround($34 * $39);
 $59 = Math_fround($33 * $47);
 $60 = Math_fround($35 * $40);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($37 * $61);
 $63 = Math_fround($58 - $62);
 $64 = Math_fround($43 * $49);
 $65 = Math_fround($64 + $63);
 $66 = Math_fround($35 * $39);
 $67 = Math_fround($34 * $40);
 $68 = Math_fround($33 * $43);
 $69 = Math_fround($67 - $68);
 $70 = Math_fround($37 * $69);
 $71 = Math_fround($66 - $70);
 $72 = Math_fround($47 * $49);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround(-$40);
 $75 = Math_fround(-$43);
 $76 = Math_fround(-$47);
 HEAPF32[$1>>2] = $74;
 $77 = (($1) + 4|0);
 HEAPF32[$77>>2] = $75;
 $78 = (($1) + 8|0);
 HEAPF32[$78>>2] = $76;
 $79 = (($1) + 12|0);
 HEAPF32[$79>>2] = $37;
 $80 = (($1) + 16|0);
 HEAPF32[$80>>2] = $57;
 $81 = (($1) + 20|0);
 HEAPF32[$81>>2] = $65;
 $82 = (($1) + 24|0);
 HEAPF32[$82>>2] = $73;
 __ZN5physxmlERKNS_11PxMeshScaleERKNS_11PxTransformE($world2vertexSkew,$0,$1);
 $83 = (($3) + 55|0);
 $84 = HEAP8[$83>>0]|0;
 $85 = Math_fround(HEAPF32[$rayOrigin>>2]);
 $86 = Math_fround(HEAPF32[$world2vertexSkew>>2]);
 $87 = Math_fround($85 * $86);
 $88 = (($world2vertexSkew) + 4|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($85 * $89);
 $91 = (($world2vertexSkew) + 8|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($85 * $92);
 $94 = (($rayOrigin) + 4|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($world2vertexSkew) + 12|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($95 * $97);
 $99 = (($world2vertexSkew) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($95 * $100);
 $102 = (($world2vertexSkew) + 20|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($95 * $103);
 $105 = Math_fround($87 + $98);
 $106 = Math_fround($90 + $101);
 $107 = Math_fround($93 + $104);
 $108 = (($rayOrigin) + 8|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($world2vertexSkew) + 24|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($109 * $111);
 $113 = (($world2vertexSkew) + 28|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($109 * $114);
 $116 = (($world2vertexSkew) + 32|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($109 * $117);
 $119 = Math_fround($105 + $112);
 $120 = Math_fround($106 + $115);
 $121 = Math_fround($107 + $118);
 $122 = (($world2vertexSkew) + 36|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($119 + $123);
 $125 = (($world2vertexSkew) + 40|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($120 + $126);
 $128 = (($world2vertexSkew) + 44|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($121 + $129);
 $131 = Math_fround(HEAPF32[$rayDir>>2]);
 $132 = Math_fround($86 * $131);
 $133 = Math_fround($89 * $131);
 $134 = Math_fround($92 * $131);
 $135 = (($rayDir) + 4|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($97 * $136);
 $138 = Math_fround($100 * $136);
 $139 = Math_fround($103 * $136);
 $140 = Math_fround($132 + $137);
 $141 = Math_fround($133 + $138);
 $142 = Math_fround($134 + $139);
 $143 = (($rayDir) + 8|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround($111 * $144);
 $146 = Math_fround($114 * $144);
 $147 = Math_fround($117 * $144);
 $148 = Math_fround($140 + $145);
 $149 = Math_fround($141 + $146);
 $150 = Math_fround($142 + $147);
 $151 = ($84<<24>>24)==(0);
 if (!($151)) {
  $152 = (($3) + 56|0);
  $153 = $84&255;
  $154 = HEAP32[$152>>2]|0;
  $$in = $153;$bestPolygonIndex$038 = 0;$bestVertSpacePlane$037 = 0;$currentIndex$039 = 0;$earlyestExit$040 = Math_fround(3.40282346638528859812E+38);$latestEntry$041 = Math_fround(-3.40282346638528859812E+38);$originInsideAllPlanes$0$off042 = 1;$polys$043 = $154;
  L3: while(1) {
   $155 = (($$in) + -1)|0;
   $156 = (($polys$043) + 20|0);
   $157 = Math_fround(HEAPF32[$polys$043>>2]);
   $158 = Math_fround($124 * $157);
   $159 = (($polys$043) + 4|0);
   $160 = Math_fround(HEAPF32[$159>>2]);
   $161 = Math_fround($127 * $160);
   $162 = Math_fround($158 + $161);
   $163 = (($polys$043) + 8|0);
   $164 = Math_fround(HEAPF32[$163>>2]);
   $165 = Math_fround($130 * $164);
   $166 = Math_fround($162 + $165);
   $167 = (($polys$043) + 12|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = Math_fround($168 + $166);
   $170 = Math_fround($148 * $157);
   $171 = Math_fround($149 * $160);
   $172 = Math_fround($170 + $171);
   $173 = Math_fround($150 * $164);
   $174 = Math_fround($172 + $173);
   $175 = Math_fround(-$169);
   $176 = Math_fround($175 / $174);
   $177 = $169 > Math_fround(0.0);
   $not$ = $177 ^ 1;
   $originInsideAllPlanes$1$off0 = $originInsideAllPlanes$0$off042 & $not$;
   $178 = $174 > Math_fround(1.00000001168609742308E-7);
   do {
    if ($178) {
     $179 = $earlyestExit$040 < $176;
     $180 = $179 ? $earlyestExit$040 : $176;
     $bestPolygonIndex$1 = $bestPolygonIndex$038;$bestVertSpacePlane$1 = $bestVertSpacePlane$037;$earlyestExit$1 = $180;$latestEntry$1 = $latestEntry$041;
    } else {
     $181 = $174 < Math_fround(-1.00000001168609742308E-7);
     if (!($181)) {
      if ($177) {
       $$0 = 0;
       label = 23;
       break L3;
      } else {
       $bestPolygonIndex$1 = $bestPolygonIndex$038;$bestVertSpacePlane$1 = $bestVertSpacePlane$037;$earlyestExit$1 = $earlyestExit$040;$latestEntry$1 = $latestEntry$041;
       break;
      }
     }
     $182 = $176 > $latestEntry$041;
     if ($182) {
      $bestPolygonIndex$1 = $currentIndex$039;$bestVertSpacePlane$1 = $polys$043;$earlyestExit$1 = $earlyestExit$040;$latestEntry$1 = $176;
     } else {
      $bestPolygonIndex$1 = $bestPolygonIndex$038;$bestVertSpacePlane$1 = $bestVertSpacePlane$037;$earlyestExit$1 = $earlyestExit$040;$latestEntry$1 = $latestEntry$041;
     }
    }
   } while(0);
   $183 = (($currentIndex$039) + 1)|0;
   $184 = ($155|0)==(0);
   if ($184) {
    break;
   } else {
    $$in = $155;$bestPolygonIndex$038 = $bestPolygonIndex$1;$bestVertSpacePlane$037 = $bestVertSpacePlane$1;$currentIndex$039 = $183;$earlyestExit$040 = $earlyestExit$1;$latestEntry$041 = $latestEntry$1;$originInsideAllPlanes$0$off042 = $originInsideAllPlanes$1$off0;$polys$043 = $156;
   }
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$0|0);
  }
  if (!($originInsideAllPlanes$1$off0)) {
   $205 = $latestEntry$1 < $earlyestExit$1;
   $206 = $latestEntry$1 > Math_fround(0.0);
   $or$cond = $205 & $206;
   if (!($or$cond)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $207 = Math_fround($maxDist + Math_fround(-9.99999974737875163555E-6));
   $208 = $latestEntry$1 < $207;
   if (!($208)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $209 = HEAP16[$hintFlags>>1]|0;
   $210 = $209 & 1;
   $211 = ($210<<16>>16)==(0);
   if ($211) {
    $372 = $209;$375 = 4;
   } else {
    $212 = Math_fround($148 * $latestEntry$1);
    $213 = Math_fround($149 * $latestEntry$1);
    $214 = Math_fround($150 * $latestEntry$1);
    $215 = Math_fround($124 + $212);
    $216 = Math_fround($127 + $213);
    $217 = Math_fround($130 + $214);
    $218 = Math_fround(HEAPF32[$15>>2]);
    $219 = Math_fround(HEAPF32[$18>>2]);
    $220 = Math_fround(HEAPF32[$21>>2]);
    $221 = Math_fround(HEAPF32[$24>>2]);
    $222 = Math_fround($218 + $218);
    $223 = Math_fround($219 + $219);
    $224 = Math_fround($220 + $220);
    $225 = Math_fround($218 * $222);
    $226 = Math_fround($219 * $223);
    $227 = Math_fround($220 * $224);
    $228 = Math_fround($222 * $219);
    $229 = Math_fround($222 * $220);
    $230 = Math_fround($222 * $221);
    $231 = Math_fround($223 * $220);
    $232 = Math_fround($223 * $221);
    $233 = Math_fround($224 * $221);
    $234 = Math_fround(Math_fround(1.0) - $226);
    $235 = Math_fround($234 - $227);
    $236 = Math_fround($228 + $233);
    $237 = Math_fround($229 - $232);
    $238 = Math_fround($228 - $233);
    $239 = Math_fround(Math_fround(1.0) - $225);
    $240 = Math_fround($239 - $227);
    $241 = Math_fround($231 + $230);
    $242 = Math_fround($229 + $232);
    $243 = Math_fround($231 - $230);
    $244 = Math_fround($239 - $226);
    $245 = Math_fround(HEAPF32[$4>>2]);
    $246 = Math_fround($245 * $235);
    $247 = Math_fround($245 * $238);
    $248 = Math_fround($245 * $242);
    $249 = Math_fround(HEAPF32[$7>>2]);
    $250 = Math_fround($236 * $249);
    $251 = Math_fround($240 * $249);
    $252 = Math_fround($243 * $249);
    $253 = Math_fround(HEAPF32[$10>>2]);
    $254 = Math_fround($237 * $253);
    $255 = Math_fround($241 * $253);
    $256 = Math_fround($244 * $253);
    $257 = Math_fround($235 * $246);
    $258 = Math_fround($235 * $247);
    $259 = Math_fround($235 * $248);
    $260 = Math_fround($236 * $250);
    $261 = Math_fround($236 * $251);
    $262 = Math_fround($236 * $252);
    $263 = Math_fround($257 + $260);
    $264 = Math_fround($258 + $261);
    $265 = Math_fround($259 + $262);
    $266 = Math_fround($237 * $254);
    $267 = Math_fround($237 * $255);
    $268 = Math_fround($237 * $256);
    $269 = Math_fround($263 + $266);
    $270 = Math_fround($264 + $267);
    $271 = Math_fround($265 + $268);
    $272 = Math_fround($238 * $246);
    $273 = Math_fround($238 * $247);
    $274 = Math_fround($238 * $248);
    $275 = Math_fround($240 * $250);
    $276 = Math_fround($240 * $251);
    $277 = Math_fround($240 * $252);
    $278 = Math_fround($272 + $275);
    $279 = Math_fround($273 + $276);
    $280 = Math_fround($274 + $277);
    $281 = Math_fround($241 * $254);
    $282 = Math_fround($241 * $255);
    $283 = Math_fround($241 * $256);
    $284 = Math_fround($278 + $281);
    $285 = Math_fround($279 + $282);
    $286 = Math_fround($280 + $283);
    $287 = Math_fround($242 * $246);
    $288 = Math_fround($242 * $247);
    $289 = Math_fround($242 * $248);
    $290 = Math_fround($243 * $250);
    $291 = Math_fround($243 * $251);
    $292 = Math_fround($243 * $252);
    $293 = Math_fround($287 + $290);
    $294 = Math_fround($288 + $291);
    $295 = Math_fround($289 + $292);
    $296 = Math_fround($244 * $254);
    $297 = Math_fround($244 * $255);
    $298 = Math_fround($244 * $256);
    $299 = Math_fround($293 + $296);
    $300 = Math_fround($294 + $297);
    $301 = Math_fround($295 + $298);
    $302 = Math_fround($215 * $269);
    $303 = Math_fround($215 * $270);
    $304 = Math_fround($215 * $271);
    $305 = Math_fround($216 * $284);
    $306 = Math_fround($216 * $285);
    $307 = Math_fround($216 * $286);
    $308 = Math_fround($302 + $305);
    $309 = Math_fround($303 + $306);
    $310 = Math_fround($304 + $307);
    $311 = Math_fround($217 * $299);
    $312 = Math_fround($217 * $300);
    $313 = Math_fround($217 * $301);
    $314 = Math_fround($311 + $308);
    $315 = Math_fround($312 + $309);
    $316 = Math_fround($313 + $310);
    $317 = Math_fround($314 * Math_fround(2.0));
    $318 = Math_fround($315 * Math_fround(2.0));
    $319 = Math_fround($316 * Math_fround(2.0));
    $320 = Math_fround(HEAPF32[$36>>2]);
    $321 = Math_fround($320 * $320);
    $322 = Math_fround($321 + Math_fround(-0.5));
    $323 = Math_fround(HEAPF32[$pose>>2]);
    $324 = Math_fround($323 * $317);
    $325 = Math_fround(HEAPF32[$42>>2]);
    $326 = Math_fround($325 * $318);
    $327 = Math_fround($324 + $326);
    $328 = Math_fround(HEAPF32[$46>>2]);
    $329 = Math_fround($328 * $319);
    $330 = Math_fround($329 + $327);
    $331 = Math_fround($322 * $317);
    $332 = Math_fround($325 * $319);
    $333 = Math_fround($328 * $318);
    $334 = Math_fround($332 - $333);
    $335 = Math_fround($320 * $334);
    $336 = Math_fround($331 + $335);
    $337 = Math_fround($323 * $330);
    $338 = Math_fround($337 + $336);
    $339 = Math_fround($322 * $318);
    $340 = Math_fround($328 * $317);
    $341 = Math_fround($323 * $319);
    $342 = Math_fround($340 - $341);
    $343 = Math_fround($320 * $342);
    $344 = Math_fround($339 + $343);
    $345 = Math_fround($325 * $330);
    $346 = Math_fround($345 + $344);
    $347 = Math_fround($322 * $319);
    $348 = Math_fround($323 * $318);
    $349 = Math_fround($325 * $317);
    $350 = Math_fround($348 - $349);
    $351 = Math_fround($320 * $350);
    $352 = Math_fround($347 + $351);
    $353 = Math_fround($328 * $330);
    $354 = Math_fround($352 + $353);
    $355 = Math_fround(HEAPF32[$27>>2]);
    $356 = Math_fround($355 + $338);
    $357 = Math_fround(HEAPF32[$29>>2]);
    $358 = Math_fround($357 + $346);
    $359 = Math_fround(HEAPF32[$31>>2]);
    $360 = Math_fround($359 + $354);
    $361 = (($hits) + 16|0);
    HEAPF32[$361>>2] = $356;
    $362 = (($hits) + 20|0);
    HEAPF32[$362>>2] = $358;
    $363 = (($hits) + 24|0);
    HEAPF32[$363>>2] = $360;
    $$pre = HEAP16[$hintFlags>>1]|0;
    $372 = $$pre;$375 = 5;
   }
   $364 = (($hits) + 40|0);
   HEAPF32[$364>>2] = $latestEntry$1;
   $365 = (($hits) + 8|0);
   HEAP32[$365>>2] = $bestPolygonIndex$1;
   $366 = (($hits) + 44|0);
   HEAPF32[$366>>2] = Math_fround(0.0);
   $367 = (($hits) + 48|0);
   HEAPF32[$367>>2] = Math_fround(0.0);
   $368 = (($hits) + 28|0);
   HEAPF32[$368>>2] = Math_fround(0.0);
   $369 = (($hits) + 32|0);
   HEAPF32[$369>>2] = Math_fround(0.0);
   $370 = (($hits) + 36|0);
   HEAPF32[$370>>2] = Math_fround(0.0);
   $371 = $372 & 2;
   $373 = ($371<<16>>16)==(0);
   if ($373) {
    $419 = $375;
   } else {
    $374 = $375&65535;
    $376 = $374 | 2;
    $377 = $376&65535;
    $378 = Math_fround(HEAPF32[$world2vertexSkew>>2]);
    $379 = Math_fround(HEAPF32[$bestVertSpacePlane$1>>2]);
    $380 = Math_fround($378 * $379);
    $381 = Math_fround(HEAPF32[$88>>2]);
    $382 = (($bestVertSpacePlane$1) + 4|0);
    $383 = Math_fround(HEAPF32[$382>>2]);
    $384 = Math_fround($381 * $383);
    $385 = Math_fround($380 + $384);
    $386 = Math_fround(HEAPF32[$91>>2]);
    $387 = (($bestVertSpacePlane$1) + 8|0);
    $388 = Math_fround(HEAPF32[$387>>2]);
    $389 = Math_fround($386 * $388);
    $390 = Math_fround($385 + $389);
    $391 = Math_fround(HEAPF32[$96>>2]);
    $392 = Math_fround($379 * $391);
    $393 = Math_fround(HEAPF32[$99>>2]);
    $394 = Math_fround($383 * $393);
    $395 = Math_fround($392 + $394);
    $396 = Math_fround(HEAPF32[$102>>2]);
    $397 = Math_fround($388 * $396);
    $398 = Math_fround($395 + $397);
    $399 = Math_fround(HEAPF32[$110>>2]);
    $400 = Math_fround($379 * $399);
    $401 = Math_fround(HEAPF32[$113>>2]);
    $402 = Math_fround($383 * $401);
    $403 = Math_fround($400 + $402);
    $404 = Math_fround(HEAPF32[$116>>2]);
    $405 = Math_fround($388 * $404);
    $406 = Math_fround($403 + $405);
    HEAPF32[$368>>2] = $390;
    HEAPF32[$369>>2] = $398;
    HEAPF32[$370>>2] = $406;
    $407 = Math_fround($390 * $390);
    $408 = Math_fround($398 * $398);
    $409 = Math_fround($407 + $408);
    $410 = Math_fround($406 * $406);
    $411 = Math_fround($410 + $409);
    $412 = (Math_fround(Math_sqrt((Math_fround($411)))));
    $413 = $412 > Math_fround(0.0);
    if ($413) {
     $414 = Math_fround(Math_fround(1.0) / $412);
     $415 = Math_fround($390 * $414);
     HEAPF32[$368>>2] = $415;
     $416 = Math_fround($398 * $414);
     HEAPF32[$369>>2] = $416;
     $417 = Math_fround($406 * $414);
     HEAPF32[$370>>2] = $417;
     $419 = $377;
    } else {
     $419 = $377;
    }
   }
   $418 = (($hits) + 12|0);
   HEAP16[$418>>1] = $419;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $185 = (($hits) + 40|0);
 HEAPF32[$185>>2] = Math_fround(0.0);
 $186 = (($hits) + 8|0);
 HEAP32[$186>>2] = -1;
 $187 = (($hits) + 44|0);
 HEAPF32[$187>>2] = Math_fround(0.0);
 $188 = (($hits) + 48|0);
 HEAPF32[$188>>2] = Math_fround(0.0);
 $189 = HEAP16[$hintFlags>>1]|0;
 $190 = $189 & 2;
 $191 = ($190<<16>>16)==(0);
 $192 = (($hits) + 28|0);
 if ($191) {
  HEAPF32[$192>>2] = Math_fround(0.0);
  $201 = (($hits) + 32|0);
  HEAPF32[$201>>2] = Math_fround(0.0);
  $202 = (($hits) + 36|0);
  HEAPF32[$202>>2] = Math_fround(0.0);
  $204 = 4;
 } else {
  $193 = Math_fround(HEAPF32[$rayDir>>2]);
  $194 = Math_fround(-$193);
  $195 = Math_fround(HEAPF32[$135>>2]);
  $196 = Math_fround(-$195);
  $197 = Math_fround(HEAPF32[$143>>2]);
  $198 = Math_fround(-$197);
  HEAPF32[$192>>2] = $194;
  $199 = (($hits) + 32|0);
  HEAPF32[$199>>2] = $196;
  $200 = (($hits) + 36|0);
  HEAPF32[$200>>2] = $198;
  $204 = 6;
 }
 $203 = (($hits) + 12|0);
 HEAP16[$203>>1] = $204;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z20raycast_triangleMeshRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_($geom,$pose,$rayOrigin,$rayDir,$maxDist,$hintFlags,$maxHits,$hits,$anyHit,$hitCB,$userData) {
 $geom = $geom|0;
 $pose = $pose|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxDist = Math_fround($maxDist);
 $hintFlags = $hintFlags|0;
 $maxHits = $maxHits|0;
 $hits = $hits|0;
 $anyHit = $anyHit|0;
 $hitCB = $hitCB|0;
 $userData = $userData|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0);
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0;
 var $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $callback = 0, $dir = 0, $hmd = 0, $or$cond = 0, $or$cond13 = 0, $orig = 0, $world2vertexSkew = 0, $world2vertexSkewP$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $orig = sp + 232|0;
 $dir = sp;
 $world2vertexSkew = sp + 16|0;
 $0 = sp + 64|0;
 $1 = sp + 112|0;
 $2 = sp + 140|0;
 $callback = sp + 168|0;
 $hmd = sp + 220|0;
 $3 = (($geom) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($geom) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $6 == Math_fround(1.0);
 $8 = (($geom) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = $9 == Math_fround(1.0);
 $or$cond13 = $7 & $10;
 if ($or$cond13) {
  $11 = (($geom) + 12|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = $12 == Math_fround(1.0);
  if ($13) {
   $14 = Math_fround(HEAPF32[$rayOrigin>>2]);
   $15 = (($pose) + 16|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($14 - $16);
   $18 = (($rayOrigin) + 4|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = (($pose) + 20|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = Math_fround($19 - $21);
   $23 = (($rayOrigin) + 8|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = (($pose) + 24|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = Math_fround($24 - $26);
   $28 = Math_fround($17 * Math_fround(2.0));
   $29 = Math_fround($22 * Math_fround(2.0));
   $30 = Math_fround($27 * Math_fround(2.0));
   $31 = (($pose) + 12|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = Math_fround($32 * $32);
   $34 = Math_fround($33 + Math_fround(-0.5));
   $35 = Math_fround(HEAPF32[$pose>>2]);
   $36 = Math_fround($28 * $35);
   $37 = (($pose) + 4|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($29 * $38);
   $40 = Math_fround($36 + $39);
   $41 = (($pose) + 8|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = Math_fround($30 * $42);
   $44 = Math_fround($40 + $43);
   $45 = Math_fround($28 * $34);
   $46 = Math_fround($30 * $38);
   $47 = Math_fround($29 * $42);
   $48 = Math_fround($46 - $47);
   $49 = Math_fround($32 * $48);
   $50 = Math_fround($45 - $49);
   $51 = Math_fround($35 * $44);
   $52 = Math_fround($51 + $50);
   $53 = Math_fround($29 * $34);
   $54 = Math_fround($28 * $42);
   $55 = Math_fround($30 * $35);
   $56 = Math_fround($54 - $55);
   $57 = Math_fround($32 * $56);
   $58 = Math_fround($53 - $57);
   $59 = Math_fround($38 * $44);
   $60 = Math_fround($59 + $58);
   $61 = Math_fround($30 * $34);
   $62 = Math_fround($29 * $35);
   $63 = Math_fround($28 * $38);
   $64 = Math_fround($62 - $63);
   $65 = Math_fround($32 * $64);
   $66 = Math_fround($61 - $65);
   $67 = Math_fround($42 * $44);
   $68 = Math_fround($66 + $67);
   HEAPF32[$orig>>2] = $52;
   $69 = (($orig) + 4|0);
   HEAPF32[$69>>2] = $60;
   $70 = (($orig) + 8|0);
   HEAPF32[$70>>2] = $68;
   $71 = Math_fround(HEAPF32[$rayDir>>2]);
   $72 = Math_fround($71 * Math_fround(2.0));
   $73 = (($rayDir) + 4|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = Math_fround($74 * Math_fround(2.0));
   $76 = (($rayDir) + 8|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = Math_fround($77 * Math_fround(2.0));
   $79 = Math_fround($72 * $35);
   $80 = Math_fround($75 * $38);
   $81 = Math_fround($79 + $80);
   $82 = Math_fround($78 * $42);
   $83 = Math_fround($81 + $82);
   $84 = Math_fround($72 * $34);
   $85 = Math_fround($78 * $38);
   $86 = Math_fround($75 * $42);
   $87 = Math_fround($85 - $86);
   $88 = Math_fround($32 * $87);
   $89 = Math_fround($84 - $88);
   $90 = Math_fround($35 * $83);
   $91 = Math_fround($90 + $89);
   $92 = Math_fround($75 * $34);
   $93 = Math_fround($72 * $42);
   $94 = Math_fround($78 * $35);
   $95 = Math_fround($93 - $94);
   $96 = Math_fround($32 * $95);
   $97 = Math_fround($92 - $96);
   $98 = Math_fround($38 * $83);
   $99 = Math_fround($98 + $97);
   $100 = Math_fround($78 * $34);
   $101 = Math_fround($75 * $35);
   $102 = Math_fround($72 * $38);
   $103 = Math_fround($101 - $102);
   $104 = Math_fround($32 * $103);
   $105 = Math_fround($100 - $104);
   $106 = Math_fround($42 * $83);
   $107 = Math_fround($105 + $106);
   HEAPF32[$dir>>2] = $91;
   $108 = (($dir) + 4|0);
   HEAPF32[$108>>2] = $99;
   $109 = (($dir) + 8|0);
   HEAPF32[$109>>2] = $107;
   $world2vertexSkewP$0 = 0;
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $110 = Math_fround(Math_fround(1.0) / $6);
  $111 = Math_fround(Math_fround(1.0) / $9);
  $112 = (($geom) + 12|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround(Math_fround(1.0) / $113);
  HEAPF32[$1>>2] = $110;
  $115 = (($1) + 4|0);
  HEAPF32[$115>>2] = $111;
  $116 = (($1) + 8|0);
  HEAPF32[$116>>2] = $114;
  $117 = (($geom) + 16|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = (($1) + 12|0);
  HEAPF32[$119>>2] = $118;
  $120 = (($geom) + 20|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = (($1) + 16|0);
  HEAPF32[$122>>2] = $121;
  $123 = (($geom) + 24|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = (($1) + 20|0);
  HEAPF32[$125>>2] = $124;
  $126 = (($geom) + 28|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = (($1) + 24|0);
  HEAPF32[$128>>2] = $127;
  $129 = (($pose) + 16|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = (($pose) + 20|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($pose) + 24|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($130 * Math_fround(-2.0));
  $136 = Math_fround($132 * Math_fround(-2.0));
  $137 = Math_fround($134 * Math_fround(-2.0));
  $138 = (($pose) + 12|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($139 * $139);
  $141 = Math_fround($140 + Math_fround(-0.5));
  $142 = Math_fround(HEAPF32[$pose>>2]);
  $143 = Math_fround($135 * $142);
  $144 = (($pose) + 4|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = Math_fround($136 * $145);
  $147 = Math_fround($143 + $146);
  $148 = (($pose) + 8|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = Math_fround($137 * $149);
  $151 = Math_fround($147 + $150);
  $152 = Math_fround($135 * $141);
  $153 = Math_fround($137 * $145);
  $154 = Math_fround($136 * $149);
  $155 = Math_fround($153 - $154);
  $156 = Math_fround($139 * $155);
  $157 = Math_fround($152 - $156);
  $158 = Math_fround($142 * $151);
  $159 = Math_fround($158 + $157);
  $160 = Math_fround($136 * $141);
  $161 = Math_fround($135 * $149);
  $162 = Math_fround($137 * $142);
  $163 = Math_fround($161 - $162);
  $164 = Math_fround($139 * $163);
  $165 = Math_fround($160 - $164);
  $166 = Math_fround($145 * $151);
  $167 = Math_fround($166 + $165);
  $168 = Math_fround($137 * $141);
  $169 = Math_fround($136 * $142);
  $170 = Math_fround($135 * $145);
  $171 = Math_fround($169 - $170);
  $172 = Math_fround($139 * $171);
  $173 = Math_fround($168 - $172);
  $174 = Math_fround($149 * $151);
  $175 = Math_fround($173 + $174);
  $176 = Math_fround(-$142);
  $177 = Math_fround(-$145);
  $178 = Math_fround(-$149);
  HEAPF32[$2>>2] = $176;
  $179 = (($2) + 4|0);
  HEAPF32[$179>>2] = $177;
  $180 = (($2) + 8|0);
  HEAPF32[$180>>2] = $178;
  $181 = (($2) + 12|0);
  HEAPF32[$181>>2] = $139;
  $182 = (($2) + 16|0);
  HEAPF32[$182>>2] = $159;
  $183 = (($2) + 20|0);
  HEAPF32[$183>>2] = $167;
  $184 = (($2) + 24|0);
  HEAPF32[$184>>2] = $175;
  __ZN5physxmlERKNS_11PxMeshScaleERKNS_11PxTransformE($0,$1,$2);
  $185 = Math_fround(HEAPF32[$0>>2]);
  HEAPF32[$world2vertexSkew>>2] = $185;
  $186 = (($0) + 4|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = (($world2vertexSkew) + 4|0);
  HEAPF32[$188>>2] = $187;
  $189 = (($0) + 8|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($world2vertexSkew) + 8|0);
  HEAPF32[$191>>2] = $190;
  $192 = (($0) + 12|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($world2vertexSkew) + 12|0);
  HEAPF32[$194>>2] = $193;
  $195 = (($0) + 16|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = (($world2vertexSkew) + 16|0);
  HEAPF32[$197>>2] = $196;
  $198 = (($0) + 20|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = (($world2vertexSkew) + 20|0);
  HEAPF32[$200>>2] = $199;
  $201 = (($0) + 24|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($world2vertexSkew) + 24|0);
  HEAPF32[$203>>2] = $202;
  $204 = (($0) + 28|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = (($world2vertexSkew) + 28|0);
  HEAPF32[$206>>2] = $205;
  $207 = (($0) + 32|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = (($world2vertexSkew) + 32|0);
  HEAPF32[$209>>2] = $208;
  $210 = (($0) + 36|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = (($world2vertexSkew) + 36|0);
  HEAPF32[$212>>2] = $211;
  $213 = (($0) + 40|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = (($world2vertexSkew) + 40|0);
  HEAPF32[$215>>2] = $214;
  $216 = (($0) + 44|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($world2vertexSkew) + 44|0);
  HEAPF32[$218>>2] = $217;
  $219 = Math_fround(HEAPF32[$rayOrigin>>2]);
  $220 = Math_fround($219 * $185);
  $221 = Math_fround($219 * $187);
  $222 = Math_fround($219 * $190);
  $223 = (($rayOrigin) + 4|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = Math_fround($224 * $193);
  $226 = Math_fround($224 * $196);
  $227 = Math_fround($224 * $199);
  $228 = Math_fround($220 + $225);
  $229 = Math_fround($221 + $226);
  $230 = Math_fround($222 + $227);
  $231 = (($rayOrigin) + 8|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = Math_fround($232 * $202);
  $234 = Math_fround($232 * $205);
  $235 = Math_fround($232 * $208);
  $236 = Math_fround($228 + $233);
  $237 = Math_fround($229 + $234);
  $238 = Math_fround($230 + $235);
  $239 = Math_fround($236 + $211);
  $240 = Math_fround($237 + $214);
  $241 = Math_fround($217 + $238);
  HEAPF32[$orig>>2] = $239;
  $242 = (($orig) + 4|0);
  HEAPF32[$242>>2] = $240;
  $243 = (($orig) + 8|0);
  HEAPF32[$243>>2] = $241;
  $244 = Math_fround(HEAPF32[$rayDir>>2]);
  $245 = Math_fround($244 * $185);
  $246 = Math_fround($244 * $187);
  $247 = Math_fround($244 * $190);
  $248 = (($rayDir) + 4|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = Math_fround($249 * $193);
  $251 = Math_fround($249 * $196);
  $252 = Math_fround($249 * $199);
  $253 = Math_fround($245 + $250);
  $254 = Math_fround($246 + $251);
  $255 = Math_fround($247 + $252);
  $256 = (($rayDir) + 8|0);
  $257 = Math_fround(HEAPF32[$256>>2]);
  $258 = Math_fround($257 * $202);
  $259 = Math_fround($257 * $205);
  $260 = Math_fround($257 * $208);
  $261 = Math_fround($253 + $258);
  $262 = Math_fround($254 + $259);
  $263 = Math_fround($255 + $260);
  HEAPF32[$dir>>2] = $261;
  $264 = (($dir) + 4|0);
  HEAPF32[$264>>2] = $262;
  $265 = (($dir) + 8|0);
  HEAPF32[$265>>2] = $263;
  $world2vertexSkewP$0 = $world2vertexSkew;
 }
 $266 = (($geom) + 32|0);
 $267 = HEAP8[$266>>0]|0;
 $268 = $267 & 2;
 $269 = ($268<<24>>24)==(0);
 $270 = ($hitCB|0)!=(0|0);
 $271 = ($maxHits>>>0)>(1);
 $or$cond = $270 | $271;
 if ($or$cond) {
  $277 = 2;
 } else {
  $272 = $anyHit&1;
  $273 = $272 ^ 1;
  $277 = $273;
 }
 $274 = HEAP16[$hintFlags>>1]|0;
 $275 = $274&65535;
 $276 = (($callback) + 4|0);
 HEAP32[$276>>2] = $277;
 HEAP32[$callback>>2] = ((548408 + 8|0));
 $278 = (($callback) + 8|0);
 HEAP32[$278>>2] = $hits;
 $279 = (($callback) + 12|0);
 HEAP32[$279>>2] = 0;
 $280 = (($callback) + 16|0);
 HEAP32[$280>>2] = $maxHits;
 $281 = (($callback) + 20|0);
 HEAP32[$281>>2] = $5;
 $282 = (($callback) + 24|0);
 HEAP32[$282>>2] = $pose;
 $283 = (($callback) + 28|0);
 HEAP32[$283>>2] = $world2vertexSkewP$0;
 $284 = (($callback) + 32|0);
 HEAP32[$284>>2] = $275;
 $285 = (($callback) + 36|0);
 HEAP32[$285>>2] = $hitCB;
 $286 = (($callback) + 40|0);
 HEAP32[$286>>2] = $userData;
 $287 = (($callback) + 44|0);
 HEAP32[$287>>2] = $rayDir;
 $288 = (($callback) + 48|0);
 $$lobit = ($268&255) >>> 1;
 HEAP8[$288>>0] = $$lobit;
 $289 = (($callback) + 49|0);
 HEAP8[$289>>0] = 0;
 if (!($269)) {
  $299 = 1;
  $292 = (($4) + 32|0);
  $293 = HEAP32[$292>>2]|0;
  HEAP32[$hmd>>2] = $293;
  $294 = (($4) + 48|0);
  $295 = (($hmd) + 4|0);
  HEAP32[$295>>2] = $294;
  $296 = (($4) + 36|0);
  $297 = Math_fround(HEAPF32[$296>>2]);
  $298 = (($hmd) + 8|0);
  HEAPF32[$298>>2] = $297;
  __ZN5physx2Gu15MeshRayCollider7collideILi0ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($orig,$dir,$maxDist,$299,$hmd,$callback,0);
  $300 = HEAP32[$279>>2]|0;
  STACKTOP = sp;return ($300|0);
 }
 $290 = $274 & 128;
 $291 = ($290<<16>>16)!=(0);
 $299 = $291;
 $292 = (($4) + 32|0);
 $293 = HEAP32[$292>>2]|0;
 HEAP32[$hmd>>2] = $293;
 $294 = (($4) + 48|0);
 $295 = (($hmd) + 4|0);
 HEAP32[$295>>2] = $294;
 $296 = (($4) + 36|0);
 $297 = Math_fround(HEAPF32[$296>>2]);
 $298 = (($hmd) + 8|0);
 HEAPF32[$298>>2] = $297;
 __ZN5physx2Gu15MeshRayCollider7collideILi0ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($orig,$dir,$maxDist,$299,$hmd,$callback,0);
 $300 = HEAP32[$279>>2]|0;
 STACKTOP = sp;return ($300|0);
}
function __ZN23RayMeshColliderCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z19raycast_heightFieldRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_($geom,$pose,$rayOrigin,$rayDir,$maxDist,$hintFlags,$maxHits,$hits,$anyHit,$hitCB,$userData) {
 $geom = $geom|0;
 $pose = $pose|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxDist = Math_fround($maxDist);
 $hintFlags = $hintFlags|0;
 $maxHits = $maxHits|0;
 $hits = $hits|0;
 $anyHit = $anyHit|0;
 $hitCB = $hitCB|0;
 $userData = $userData|0;
 var $$0 = 0, $$c = 0, $$c12 = 0, $$pre = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0;
 var $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $callback = 0, $hfUtil = 0, $localRayOrig = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $localRayOrig = sp + 64|0;
 $hfUtil = sp;
 $callback = sp + 20|0;
 $0 = sp + 40|0;
 $1 = sp + 52|0;
 $2 = (($geom) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($hits) + 12|0);
 HEAP16[$4>>1] = 0;
 $5 = (($pose) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($pose) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($pose) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($6 * Math_fround(-2.0));
 $12 = Math_fround($8 * Math_fround(-2.0));
 $13 = Math_fround($10 * Math_fround(-2.0));
 $14 = (($pose) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $15);
 $17 = Math_fround($16 + Math_fround(-0.5));
 $18 = Math_fround(HEAPF32[$pose>>2]);
 $19 = Math_fround($11 * $18);
 $20 = (($pose) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($12 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($pose) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($13 * $25);
 $27 = Math_fround($23 + $26);
 $28 = Math_fround($11 * $17);
 $29 = Math_fround($13 * $21);
 $30 = Math_fround($12 * $25);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround($15 * $31);
 $33 = Math_fround($28 - $32);
 $34 = Math_fround($18 * $27);
 $35 = Math_fround($34 + $33);
 $36 = Math_fround($12 * $17);
 $37 = Math_fround($11 * $25);
 $38 = Math_fround($13 * $18);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($15 * $39);
 $41 = Math_fround($36 - $40);
 $42 = Math_fround($21 * $27);
 $43 = Math_fround($42 + $41);
 $44 = Math_fround($13 * $17);
 $45 = Math_fround($12 * $18);
 $46 = Math_fround($11 * $21);
 $47 = Math_fround($45 - $46);
 $48 = Math_fround($15 * $47);
 $49 = Math_fround($44 - $48);
 $50 = Math_fround($25 * $27);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround(-$18);
 $53 = Math_fround(-$21);
 $54 = Math_fround(-$25);
 $55 = Math_fround(HEAPF32[$rayOrigin>>2]);
 $56 = Math_fround($55 * Math_fround(2.0));
 $57 = (($rayOrigin) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 * Math_fround(2.0));
 $60 = (($rayOrigin) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 * Math_fround(2.0));
 $63 = Math_fround($56 * $52);
 $64 = Math_fround($59 * $53);
 $65 = Math_fround($63 + $64);
 $66 = Math_fround($62 * $54);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($17 * $56);
 $69 = Math_fround($62 * $53);
 $70 = Math_fround($59 * $54);
 $71 = Math_fround($69 - $70);
 $72 = Math_fround($15 * $71);
 $73 = Math_fround($68 + $72);
 $74 = Math_fround($67 * $52);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($17 * $59);
 $77 = Math_fround($56 * $54);
 $78 = Math_fround($62 * $52);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($15 * $79);
 $81 = Math_fround($76 + $80);
 $82 = Math_fround($67 * $53);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($17 * $62);
 $85 = Math_fround($59 * $52);
 $86 = Math_fround($56 * $53);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($15 * $87);
 $89 = Math_fround($84 + $88);
 $90 = Math_fround($67 * $54);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($35 + $75);
 $93 = Math_fround($43 + $83);
 $94 = Math_fround($51 + $91);
 HEAPF32[$localRayOrig>>2] = $92;
 $95 = (($localRayOrig) + 4|0);
 HEAPF32[$95>>2] = $93;
 $96 = (($localRayOrig) + 8|0);
 HEAPF32[$96>>2] = $94;
 $97 = Math_fround(HEAPF32[$rayDir>>2]);
 $98 = Math_fround($97 * Math_fround(2.0));
 $99 = (($rayDir) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 * Math_fround(2.0));
 $102 = (($rayDir) + 8|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($103 * Math_fround(2.0));
 $105 = Math_fround($98 * $52);
 $106 = Math_fround($101 * $53);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($104 * $54);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($17 * $98);
 $111 = Math_fround($104 * $53);
 $112 = Math_fround($101 * $54);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($15 * $113);
 $115 = Math_fround($110 + $114);
 $116 = Math_fround($109 * $52);
 $117 = Math_fround($116 + $115);
 $118 = Math_fround($17 * $101);
 $119 = Math_fround($98 * $54);
 $120 = Math_fround($104 * $52);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($15 * $121);
 $123 = Math_fround($118 + $122);
 $124 = Math_fround($109 * $53);
 $125 = Math_fround($124 + $123);
 $126 = Math_fround($17 * $104);
 $127 = Math_fround($101 * $52);
 $128 = Math_fround($98 * $53);
 $129 = Math_fround($127 - $128);
 $130 = Math_fround($15 * $129);
 $131 = Math_fround($126 + $130);
 $132 = Math_fround($109 * $54);
 $133 = Math_fround($131 + $132);
 $134 = HEAP32[$2>>2]|0;
 $$c = $3;
 HEAP32[$2>>2] = $$c;
 $135 = (($hfUtil) + 12|0);
 HEAP32[$135>>2] = $3;
 $136 = (($hfUtil) + 16|0);
 HEAP32[$136>>2] = $geom;
 $137 = (($geom) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround(Math_fround(1.0) / $138);
 $140 = (($hfUtil) + 4|0);
 HEAPF32[$140>>2] = $139;
 $141 = (($geom) + 12|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround(Math_fround(1.0) / $142);
 HEAPF32[$hfUtil>>2] = $143;
 $144 = (($geom) + 16|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround(Math_fround(1.0) / $145);
 $147 = (($hfUtil) + 8|0);
 HEAPF32[$147>>2] = $146;
 $148 = (($callback) + 16|0);
 HEAP8[$148>>0] = 0;
 $149 = Math_fround($117 * $117);
 $150 = Math_fround($125 * $125);
 $151 = Math_fround($149 + $150);
 $152 = Math_fround($133 * $133);
 $153 = Math_fround($152 + $151);
 $154 = (Math_fround(Math_sqrt((Math_fround($153)))));
 $155 = $154 < Math_fround(9.99999968265522538896E-21);
 if ($155) {
  $163 = $117;$165 = $125;$167 = $133;
 } else {
  $156 = Math_fround(Math_fround(1.0) / $154);
  $157 = Math_fround($117 * $156);
  $158 = Math_fround($125 * $156);
  $159 = Math_fround($133 * $156);
  $163 = $157;$165 = $158;$167 = $159;
 }
 $160 = $maxDist < Math_fround(1.0E+10);
 $161 = $160 ? $maxDist : Math_fround(1.0E+10);
 $162 = Math_fround($161 * $163);
 $164 = Math_fround($161 * $165);
 $166 = Math_fround($161 * $167);
 $168 = Math_fround($92 + $162);
 $169 = Math_fround($164 + $93);
 $170 = Math_fround($166 + $94);
 HEAPF32[$0>>2] = $168;
 $171 = (($0) + 4|0);
 HEAPF32[$171>>2] = $169;
 $172 = (($0) + 8|0);
 HEAPF32[$172>>2] = $170;
 __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS0_15RayCastCallbackELb0ELb0ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$localRayOrig,$0,$callback,0);
 $173 = HEAP8[$148>>0]|0;
 $174 = ($173<<24>>24)==(0);
 if ($174) {
  $$0 = 0;
  $$c12 = $134;
  HEAP32[$2>>2] = $$c12;
  STACKTOP = sp;return ($$0|0);
 }
 $175 = (($callback) + 12|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = (($hits) + 8|0);
 HEAP32[$177>>2] = $176;
 $178 = Math_fround(HEAPF32[$callback>>2]);
 $179 = (($callback) + 8|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = HEAP32[$135>>2]|0;
 $182 = Math_fround(HEAPF32[$hfUtil>>2]);
 $183 = Math_fround($178 * $182);
 $184 = Math_fround(HEAPF32[$147>>2]);
 $185 = Math_fround($180 * $184);
 $186 = Math_fround(HEAPF32[$140>>2]);
 __ZNK5physx2Gu11HeightField10getNormal_Efffff($1,$181,$183,$185,$182,$186,$184);
 $187 = Math_fround(HEAPF32[$1>>2]);
 $188 = Math_fround($187 * Math_fround(2.0));
 $189 = (($1) + 4|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = Math_fround($190 * Math_fround(2.0));
 $192 = (($1) + 8|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = Math_fround($193 * Math_fround(2.0));
 $195 = Math_fround(HEAPF32[$14>>2]);
 $196 = Math_fround($195 * $195);
 $197 = Math_fround($196 + Math_fround(-0.5));
 $198 = Math_fround(HEAPF32[$pose>>2]);
 $199 = Math_fround($188 * $198);
 $200 = Math_fround(HEAPF32[$20>>2]);
 $201 = Math_fround($191 * $200);
 $202 = Math_fround($199 + $201);
 $203 = Math_fround(HEAPF32[$24>>2]);
 $204 = Math_fround($194 * $203);
 $205 = Math_fround($202 + $204);
 $206 = Math_fround($188 * $197);
 $207 = Math_fround($194 * $200);
 $208 = Math_fround($191 * $203);
 $209 = Math_fround($207 - $208);
 $210 = Math_fround($195 * $209);
 $211 = Math_fround($206 + $210);
 $212 = Math_fround($198 * $205);
 $213 = Math_fround($212 + $211);
 $214 = Math_fround($191 * $197);
 $215 = Math_fround($188 * $203);
 $216 = Math_fround($194 * $198);
 $217 = Math_fround($215 - $216);
 $218 = Math_fround($195 * $217);
 $219 = Math_fround($214 + $218);
 $220 = Math_fround($200 * $205);
 $221 = Math_fround($220 + $219);
 $222 = Math_fround($194 * $197);
 $223 = Math_fround($191 * $198);
 $224 = Math_fround($188 * $200);
 $225 = Math_fround($223 - $224);
 $226 = Math_fround($195 * $225);
 $227 = Math_fround($222 + $226);
 $228 = Math_fround($203 * $205);
 $229 = Math_fround($227 + $228);
 $230 = Math_fround($213 * $213);
 $231 = Math_fround($221 * $221);
 $232 = Math_fround($230 + $231);
 $233 = Math_fround($229 * $229);
 $234 = Math_fround($233 + $232);
 $235 = (Math_fround(Math_sqrt((Math_fround($234)))));
 $236 = $235 > Math_fround(0.0);
 if ($236) {
  $237 = Math_fround(Math_fround(1.0) / $235);
  $238 = Math_fround($213 * $237);
  $239 = Math_fround($221 * $237);
  $240 = Math_fround($229 * $237);
  $245 = $238;$247 = $239;$249 = $240;
 } else {
  $245 = $213;$247 = $221;$249 = $229;
 }
 $241 = HEAP16[$hintFlags>>1]|0;
 $242 = $241 & 2;
 $243 = ($242<<16>>16)==(0);
 if ($243) {
  $255 = $241;
 } else {
  $244 = (($hits) + 28|0);
  HEAPF32[$244>>2] = $245;
  $246 = (($hits) + 32|0);
  HEAPF32[$246>>2] = $247;
  $248 = (($hits) + 36|0);
  HEAPF32[$248>>2] = $249;
  $250 = HEAP16[$4>>1]|0;
  $251 = $250&65535;
  $252 = $251 | 2;
  $253 = $252&65535;
  HEAP16[$4>>1] = $253;
  $$pre = HEAP16[$hintFlags>>1]|0;
  $255 = $$pre;
 }
 $254 = $255 & 4;
 $256 = ($254<<16>>16)==(0);
 if ($256) {
  $276 = $255;
 } else {
  $257 = Math_fround(HEAPF32[$localRayOrig>>2]);
  $258 = Math_fround($178 - $257);
  $259 = (($callback) + 4|0);
  $260 = Math_fround(HEAPF32[$259>>2]);
  $261 = Math_fround(HEAPF32[$95>>2]);
  $262 = Math_fround($260 - $261);
  $263 = Math_fround(HEAPF32[$96>>2]);
  $264 = Math_fround($180 - $263);
  $265 = Math_fround($117 * $258);
  $266 = Math_fround($125 * $262);
  $267 = Math_fround($265 + $266);
  $268 = Math_fround($133 * $264);
  $269 = Math_fround($267 + $268);
  $270 = (($hits) + 40|0);
  HEAPF32[$270>>2] = $269;
  $271 = HEAP16[$4>>1]|0;
  $272 = $271&65535;
  $273 = $272 | 4;
  $274 = $273&65535;
  HEAP16[$4>>1] = $274;
  $$pre13 = HEAP16[$hintFlags>>1]|0;
  $276 = $$pre13;
 }
 $275 = $276 & 1;
 $277 = ($275<<16>>16)==(0);
 if ($277) {
  $$0 = 1;
  $$c12 = $134;
  HEAP32[$2>>2] = $$c12;
  STACKTOP = sp;return ($$0|0);
 }
 $278 = Math_fround($178 * Math_fround(2.0));
 $279 = (($callback) + 4|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = Math_fround($280 * Math_fround(2.0));
 $282 = Math_fround($180 * Math_fround(2.0));
 $283 = Math_fround(HEAPF32[$14>>2]);
 $284 = Math_fround($283 * $283);
 $285 = Math_fround($284 + Math_fround(-0.5));
 $286 = Math_fround(HEAPF32[$pose>>2]);
 $287 = Math_fround($278 * $286);
 $288 = Math_fround(HEAPF32[$20>>2]);
 $289 = Math_fround($281 * $288);
 $290 = Math_fround($287 + $289);
 $291 = Math_fround(HEAPF32[$24>>2]);
 $292 = Math_fround($282 * $291);
 $293 = Math_fround($290 + $292);
 $294 = Math_fround($278 * $285);
 $295 = Math_fround($282 * $288);
 $296 = Math_fround($281 * $291);
 $297 = Math_fround($295 - $296);
 $298 = Math_fround($283 * $297);
 $299 = Math_fround($294 + $298);
 $300 = Math_fround($286 * $293);
 $301 = Math_fround($300 + $299);
 $302 = Math_fround($281 * $285);
 $303 = Math_fround($278 * $291);
 $304 = Math_fround($282 * $286);
 $305 = Math_fround($303 - $304);
 $306 = Math_fround($283 * $305);
 $307 = Math_fround($302 + $306);
 $308 = Math_fround($288 * $293);
 $309 = Math_fround($308 + $307);
 $310 = Math_fround($282 * $285);
 $311 = Math_fround($281 * $286);
 $312 = Math_fround($278 * $288);
 $313 = Math_fround($311 - $312);
 $314 = Math_fround($283 * $313);
 $315 = Math_fround($310 + $314);
 $316 = Math_fround($291 * $293);
 $317 = Math_fround($315 + $316);
 $318 = Math_fround(HEAPF32[$5>>2]);
 $319 = Math_fround($318 + $301);
 $320 = Math_fround(HEAPF32[$7>>2]);
 $321 = Math_fround($320 + $309);
 $322 = Math_fround(HEAPF32[$9>>2]);
 $323 = Math_fround($322 + $317);
 $324 = (($hits) + 16|0);
 HEAPF32[$324>>2] = $319;
 $325 = (($hits) + 20|0);
 HEAPF32[$325>>2] = $321;
 $326 = (($hits) + 24|0);
 HEAPF32[$326>>2] = $323;
 $327 = HEAP16[$4>>1]|0;
 $328 = $327&65535;
 $329 = $328 | 1;
 $330 = $329&65535;
 HEAP16[$4>>1] = $330;
 $$0 = 1;
 $$c12 = $134;
 HEAP32[$2>>2] = $$c12;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS0_15RayCastCallbackELb0ELb0ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($this,$aP0,$aP1,$aCallback,$overlapObjectExtent) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $aCallback = $aCallback|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 var $$sink = Math_fround(0), $$sink1 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0;
 var $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0);
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = 0;
 var $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0);
 var $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0);
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0;
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $du$0 = Math_fround(0);
 var $duhvNorm = 0, $dv$0 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i5 = Math_fround(0), $fabsf$i$i8 = Math_fround(0), $fabsf$i$i9 = Math_fround(0), $h = 0, $hLinePrev$0 = Math_fround(0), $hit0$0$off0 = 0, $hit1$0$off0 = 0, $localBounds = 0, $or$cond = 0, $or$cond$not = 0, $or$cond20 = 0, $or$cond21 = 0, $or$cond22 = 0, $or$cond23 = 0, $or$cond4 = 0, $or$cond4$not = 0, $p00 = 0;
 var $p00$p01 = 0, $p01 = 0, $p01$p11 = 0, $p10 = 0, $p10$p00 = 0, $p11 = 0, $p11$p10 = 0, $rayDir = 0, $tfar = 0, $tnear = 0, $triT0 = 0, $triT1 = 0, $triU = 0, $triV = 0, $tu$0 = Math_fround(0), $tu$1 = Math_fround(0), $tv$0 = Math_fround(0), $tv$1 = Math_fround(0), $uhv0 = 0, $ui$0 = 0;
 var $ui$1 = 0, $uif$0 = Math_fround(0), $uif$1 = Math_fround(0), $vi$0 = 0, $vi$1 = 0, $vif$0 = Math_fround(0), $vif$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $localBounds = sp + 128|0;
 $rayDir = sp + 112|0;
 $tnear = sp + 108|0;
 $tfar = sp + 104|0;
 $uhv0 = sp + 92|0;
 $duhvNorm = sp + 80|0;
 $h = sp + 64|0;
 $triU = sp + 60|0;
 $triV = sp + 52|0;
 $p00 = sp + 40|0;
 $p01 = sp + 28|0;
 $p10 = sp + 16|0;
 $p11 = sp + 4|0;
 $triT0 = sp;
 $triT1 = sp + 56|0;
 __ZNK5physx2Gu15HeightFieldUtil18computeLocalBoundsERNS_9PxBounds3E($this,$localBounds);
 $0 = Math_fround(HEAPF32[$aP1>>2]);
 $1 = Math_fround(HEAPF32[$aP0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($aP1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($aP0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($aP1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($aP0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 HEAPF32[$rayDir>>2] = $2;
 $13 = (($rayDir) + 4|0);
 HEAPF32[$13>>2] = $7;
 $14 = (($rayDir) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($localBounds) + 12|0);
 $16 = (__ZN5physx2Gu17intersectRayAABB2ERKNS_6PxVec3ES3_S3_S3_fRfS4_($localBounds,$15,$aP0,$rayDir,Math_fround(1.0),$tnear,$tfar)|0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 12|0);
 $18 = Math_fround(HEAPF32[$tnear>>2]);
 $19 = Math_fround(HEAPF32[$rayDir>>2]);
 $20 = Math_fround($18 * $19);
 $21 = Math_fround(HEAPF32[$13>>2]);
 $22 = Math_fround($18 * $21);
 $23 = Math_fround(HEAPF32[$14>>2]);
 $24 = Math_fround($18 * $23);
 $25 = Math_fround(HEAPF32[$aP0>>2]);
 $26 = Math_fround($20 + $25);
 $27 = Math_fround(HEAPF32[$5>>2]);
 $28 = Math_fround($22 + $27);
 $29 = Math_fround(HEAPF32[$10>>2]);
 $30 = Math_fround($24 + $29);
 $31 = Math_fround(HEAPF32[$tfar>>2]);
 $32 = Math_fround($19 * $31);
 $33 = Math_fround($21 * $31);
 $34 = Math_fround($23 * $31);
 $35 = Math_fround($25 + $32);
 $36 = Math_fround($27 + $33);
 $37 = Math_fround($29 + $34);
 $38 = (($this) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($39) + 16|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($39) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = HEAP32[$17>>2]|0;
 $47 = (($46) + 20|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 16|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = Math_fround(HEAPF32[$this>>2]);
 $52 = (($this) + 8|0);
 $53 = (($50) + -1)|0;
 $54 = (Math_fround(($53|0)));
 $55 = Math_fround($54 * Math_fround(0.999999880790710449218));
 $56 = (($48) + -1)|0;
 $57 = (Math_fround(($56|0)));
 $58 = Math_fround($57 * Math_fround(0.999999880790710449218));
 $59 = Math_fround($26 * $51);
 $60 = $59 > Math_fround(1.00000001168609742308E-7);
 $61 = $60 ? $59 : Math_fround(1.00000001168609742308E-7);
 $62 = Math_fround($55 + Math_fround(0.0));
 $63 = $61 < $62;
 $64 = $63 ? $61 : $62;
 $65 = Math_fround(HEAPF32[$52>>2]);
 $66 = Math_fround($30 * $65);
 $67 = $66 > Math_fround(1.00000001168609742308E-7);
 $68 = $67 ? $66 : Math_fround(1.00000001168609742308E-7);
 $69 = Math_fround($58 + Math_fround(0.0));
 $70 = $68 < $69;
 $71 = $70 ? $68 : $69;
 $72 = Math_fround($35 * $51);
 $73 = $72 > Math_fround(1.00000001168609742308E-7);
 $74 = $73 ? $72 : Math_fround(1.00000001168609742308E-7);
 $75 = $74 < $62;
 $76 = $75 ? $74 : $62;
 $77 = Math_fround($37 * $65);
 $78 = $77 > Math_fround(1.00000001168609742308E-7);
 $79 = $78 ? $77 : Math_fround(1.00000001168609742308E-7);
 $80 = $79 < $69;
 $81 = $80 ? $79 : $69;
 $82 = Math_fround($76 - $64);
 $83 = Math_fround($81 - $71);
 $84 = Math_fround($36 - $28);
 $85 = $82 >= Math_fround(0.0);
 $86 = $85 ? Math_fround(1.0) : Math_fround(-1.0);
 $87 = $83 >= Math_fround(0.0);
 $88 = $87 ? Math_fround(1.0) : Math_fround(-1.0);
 $89 = (~~(($86)));
 $90 = (~~(($88)));
 $fabsf$i$i9 = (Math_fround(Math_abs((Math_fround($82)))));
 $91 = $fabsf$i$i9 < Math_fround(1.00000001335143196002E-10);
 if ($91) {
  $92 = Math_fround($86 * Math_fround(1.00000001335143196002E-10));
  $du$0 = $92;
 } else {
  $du$0 = $82;
 }
 $fabsf$i$i8 = (Math_fround(Math_abs((Math_fround($83)))));
 $93 = $fabsf$i$i8 < Math_fround(1.00000001335143196002E-10);
 if ($93) {
  $94 = Math_fround($88 * Math_fround(1.00000001335143196002E-10));
  $dv$0 = $94;
 } else {
  $dv$0 = $83;
 }
 HEAPF32[$uhv0>>2] = $59;
 $95 = (($uhv0) + 4|0);
 HEAPF32[$95>>2] = $28;
 $96 = (($uhv0) + 8|0);
 HEAPF32[$96>>2] = $66;
 $97 = Math_fround($35 - $26);
 $98 = Math_fround($97 * $51);
 $99 = Math_fround($37 - $30);
 $100 = Math_fround($99 * $65);
 $101 = Math_fround($98 * $98);
 $102 = Math_fround($84 * $84);
 $103 = Math_fround($102 + $101);
 $104 = Math_fround($100 * $100);
 $105 = Math_fround($103 + $104);
 $106 = (Math_fround(Math_sqrt((Math_fround($105)))));
 HEAPF32[$duhvNorm>>2] = $98;
 $107 = (($duhvNorm) + 4|0);
 HEAPF32[$107>>2] = $84;
 $108 = (($duhvNorm) + 8|0);
 HEAPF32[$108>>2] = $100;
 $109 = $106 > Math_fround(9.99999968265522538896E-21);
 if ($109) {
  $110 = Math_fround(Math_fround(1.0) / $106);
  $111 = Math_fround($110 * $98);
  HEAPF32[$duhvNorm>>2] = $111;
  $112 = Math_fround($110 * $84);
  HEAPF32[$107>>2] = $112;
  $113 = Math_fround($110 * $100);
  HEAPF32[$108>>2] = $113;
 }
 $114 = $du$0 > Math_fround(0.0);
 if ($114) {
  $115 = (Math_fround(Math_floor((Math_fround($64)))));
  $$sink = $115;
 } else {
  $116 = (Math_fround(Math_ceil((Math_fround($64)))));
  $$sink = $116;
 }
 $117 = (~~(($$sink)));
 $118 = $dv$0 > Math_fround(0.0);
 if ($118) {
  $119 = (Math_fround(Math_floor((Math_fround($71)))));
  $$sink1 = $119;
 } else {
  $120 = (Math_fround(Math_ceil((Math_fround($71)))));
  $$sink1 = $120;
 }
 $121 = (~~(($$sink1)));
 if ($114) {
  $122 = (Math_fround(Math_ceil((Math_fround($64)))));
  $123 = $122 == $64;
  if ($123) {
   $124 = Math_fround($122 + Math_fround(1.0));
   $135 = $124;
  } else {
   $135 = $122;
  }
 } else {
  $125 = (Math_fround(Math_floor((Math_fround($64)))));
  $126 = $125 == $64;
  if ($126) {
   $127 = Math_fround($125 + Math_fround(-1.0));
   $135 = $127;
  } else {
   $135 = $125;
  }
 }
 if ($118) {
  $128 = (Math_fround(Math_ceil((Math_fround($71)))));
  $129 = $128 == $71;
  if ($129) {
   $130 = Math_fround($128 + Math_fround(1.0));
   $138 = $130;
  } else {
   $138 = $128;
  }
 } else {
  $131 = (Math_fround(Math_floor((Math_fround($71)))));
  $132 = $131 == $71;
  if ($132) {
   $133 = Math_fround($131 + Math_fround(-1.0));
   $138 = $133;
  } else {
   $138 = $131;
  }
 }
 $134 = Math_fround($135 - $64);
 $136 = Math_fround($134 / $du$0);
 $137 = Math_fround($138 - $71);
 $139 = Math_fround($137 / $dv$0);
 $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($du$0)))));
 $140 = Math_fround(Math_fround(1.0) / $fabsf$i$i5);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($dv$0)))));
 $141 = Math_fround(Math_fround(1.0) / $fabsf$i$i);
 $142 = (Math_fround(($117|0)));
 $143 = (Math_fround(($121|0)));
 $144 = (1 - ($89))|0;
 $145 = (1 - ($90))|0;
 $146 = (($145|0) / 2)&-1;
 $147 = Math_fround($84 * Math_fround(0.0));
 $148 = Math_fround($28 + $147);
 $149 = (($46) + 36|0);
 $150 = (($h) + 4|0);
 $151 = (($h) + 8|0);
 $152 = (($h) + 12|0);
 $153 = (Math_fround(($50|0)));
 $154 = (Math_fround(($48|0)));
 $155 = (($146) + ($144))|0;
 $156 = (($h) + ($155<<2)|0);
 $157 = (($144) + 1)|0;
 $158 = (($157) - ($146))|0;
 $159 = (($h) + ($158<<2)|0);
 $160 = (2 - ($144))|0;
 $161 = (($160) + ($146))|0;
 $162 = (($h) + ($161<<2)|0);
 $163 = (3 - ($144))|0;
 $164 = (($163) - ($146))|0;
 $165 = (($h) + ($164<<2)|0);
 $166 = (($p00) + 4|0);
 $167 = (($p00) + 8|0);
 $168 = (($p01) + 4|0);
 $169 = (($p01) + 8|0);
 $170 = (($p10) + 4|0);
 $171 = (($p10) + 8|0);
 $172 = (($p11) + 4|0);
 $173 = (($p11) + 8|0);
 $174 = Math_fround($106 + Math_fround(9.99999974737875163555E-5));
 $hLinePrev$0 = $148;$tu$0 = $136;$tv$0 = $139;$ui$0 = $117;$uif$0 = $142;$vi$0 = $121;$vif$0 = $143;
 while(1) {
  $175 = $tu$0 < $tv$0;
  $176 = $175 ? $tu$0 : $tv$0;
  $177 = Math_fround($84 * $176);
  $178 = Math_fround($28 + $177);
  $179 = Math_imul($ui$0, $48)|0;
  $180 = (($179) + ($vi$0))|0;
  $181 = (($ui$0) + ($89))|0;
  $182 = Math_imul($181, $48)|0;
  $183 = (($182) + ($vi$0))|0;
  $184 = HEAP32[$149>>2]|0;
  $185 = (($184) + ($180<<2)|0);
  $186 = HEAP16[$185>>1]|0;
  $187 = (Math_fround(($186<<16>>16)));
  $188 = Math_fround($45 * $187);
  HEAPF32[$h>>2] = $188;
  $189 = (($180) + ($90))|0;
  $190 = (($184) + ($189<<2)|0);
  $191 = HEAP16[$190>>1]|0;
  $192 = (Math_fround(($191<<16>>16)));
  $193 = Math_fround($45 * $192);
  HEAPF32[$150>>2] = $193;
  $194 = (($184) + ($183<<2)|0);
  $195 = HEAP16[$194>>1]|0;
  $196 = (Math_fround(($195<<16>>16)));
  $197 = Math_fround($45 * $196);
  HEAPF32[$151>>2] = $197;
  $198 = (($183) + ($90))|0;
  $199 = (($184) + ($198<<2)|0);
  $200 = HEAP16[$199>>1]|0;
  $201 = (Math_fround(($200<<16>>16)));
  $202 = Math_fround($45 * $201);
  HEAPF32[$152>>2] = $202;
  $203 = $188 < $193;
  $204 = $203 ? $188 : $193;
  $205 = $197 < $202;
  $206 = $205 ? $197 : $202;
  $207 = $188 > $193;
  $208 = $207 ? $188 : $193;
  $209 = $197 > $202;
  $210 = $209 ? $197 : $202;
  $211 = $208 > $210;
  $212 = $211 ? $208 : $210;
  $213 = $hLinePrev$0 < $178;
  $214 = $213 ? $hLinePrev$0 : $178;
  $215 = Math_fround($214 + Math_fround(-9.99999974737875163555E-5));
  $216 = $215 > $212;
  if (!($216)) {
   $217 = $hLinePrev$0 > $178;
   $218 = $204 < $206;
   $219 = $217 ? $hLinePrev$0 : $178;
   $220 = $218 ? $204 : $206;
   $221 = Math_fround($219 + Math_fround(9.99999974737875163555E-5));
   $222 = $221 < $220;
   if (!($222)) {
    $223 = Math_fround(HEAPF32[$156>>2]);
    $224 = Math_fround(HEAPF32[$159>>2]);
    $225 = Math_fround(HEAPF32[$162>>2]);
    $226 = Math_fround(HEAPF32[$165>>2]);
    $227 = Math_fround($86 + $uif$0);
    $228 = $uif$0 < $227;
    $229 = $228 ? $uif$0 : $227;
    $230 = $uif$0 > $227;
    $231 = $230 ? $uif$0 : $227;
    $232 = Math_fround($88 + $vif$0);
    $233 = $vif$0 < $232;
    $234 = $233 ? $vif$0 : $232;
    $235 = $vif$0 > $232;
    $236 = $235 ? $vif$0 : $232;
    HEAPF32[$p00>>2] = $229;
    HEAPF32[$166>>2] = $223;
    HEAPF32[$167>>2] = $234;
    HEAPF32[$p01>>2] = $229;
    HEAPF32[$168>>2] = $224;
    HEAPF32[$169>>2] = $236;
    HEAPF32[$p10>>2] = $231;
    HEAPF32[$170>>2] = $225;
    HEAPF32[$171>>2] = $234;
    HEAPF32[$p11>>2] = $231;
    HEAPF32[$172>>2] = $226;
    HEAPF32[$173>>2] = $236;
    $237 = ($181|0)<($ui$0|0);
    $238 = $237 ? $181 : $ui$0;
    $239 = (($vi$0) + ($90))|0;
    $240 = ($239|0)<($vi$0|0);
    $241 = $240 ? $239 : $vi$0;
    $242 = Math_imul($238, $48)|0;
    $243 = (($242) + ($241))|0;
    $244 = ((($184) + ($243<<2)|0) + 2|0);
    $245 = HEAP8[$244>>0]|0;
    $246 = ($245<<24>>24)<(0);
    $p00$p01 = $246 ? $p00 : $p01;
    $p01$p11 = $246 ? $p01 : $p11;
    $p10$p00 = $246 ? $p10 : $p00;
    $p11$p10 = $246 ? $p11 : $p10;
    HEAPF32[$triT0>>2] = Math_fround(3.40282346638528859812E+38);
    HEAPF32[$triT1>>2] = Math_fround(3.40282346638528859812E+38);
    $247 = (__ZN5physx2Gu29intersectRayTriangleNoCullingERKNS_6PxVec3ES3_S3_S3_S3_RfS4_S4_f($uhv0,$duhvNorm,$p10$p00,$p00$p01,$p11$p10,$triT0,$triU,$triV,Math_fround(9.99999974737875163555E-5))|0);
    $248 = Math_fround(HEAPF32[$triT0>>2]);
    $249 = $248 >= Math_fround(-9.99999974737875163555E-5);
    $or$cond = $247 & $249;
    $or$cond$not = $or$cond ^ 1;
    $250 = !($248 <= $174);
    $or$cond20 = $250 | $or$cond$not;
    if ($or$cond20) {
     label = 29;
    } else {
     $251 = HEAP32[$149>>2]|0;
     $252 = ((($251) + ($243<<2)|0) + 2|0);
     $253 = HEAP8[$252>>0]|0;
     $254 = $253 & 127;
     $255 = ($254<<24>>24)==(127);
     if ($255) {
      label = 29;
     } else {
      $hit0$0$off0 = 1;
     }
    }
    if ((label|0) == 29) {
     label = 0;
     HEAPF32[$triT0>>2] = Math_fround(3.40282346638528859812E+38);
     $hit0$0$off0 = 0;
    }
    $256 = (__ZN5physx2Gu29intersectRayTriangleNoCullingERKNS_6PxVec3ES3_S3_S3_S3_RfS4_S4_f($uhv0,$duhvNorm,$p01$p11,$p11$p10,$p00$p01,$triT1,$triU,$triV,Math_fround(9.99999974737875163555E-5))|0);
    $257 = Math_fround(HEAPF32[$triT1>>2]);
    $258 = $257 >= Math_fround(-9.99999974737875163555E-5);
    $or$cond4 = $256 & $258;
    $or$cond4$not = $or$cond4 ^ 1;
    $259 = !($257 <= $174);
    $or$cond21 = $259 | $or$cond4$not;
    if ($or$cond21) {
     label = 32;
    } else {
     $260 = HEAP32[$149>>2]|0;
     $261 = ((($260) + ($243<<2)|0) + 3|0);
     $262 = HEAP8[$261>>0]|0;
     $263 = $262 & 127;
     $264 = ($263<<24>>24)==(127);
     if ($264) {
      label = 32;
     } else {
      $267 = $257;$hit1$0$off0 = 1;
     }
    }
    if ((label|0) == 32) {
     label = 0;
     HEAPF32[$triT1>>2] = Math_fround(3.40282346638528859812E+38);
     $267 = Math_fround(3.40282346638528859812E+38);$hit1$0$off0 = 0;
    }
    if ($hit0$0$off0) {
     $265 = Math_fround(HEAPF32[$triT0>>2]);
     $266 = !($265 <= $267);
     if (!($266)) {
      label = 35;
      break;
     }
    }
    if ($hit1$0$off0) {
     $284 = Math_fround(HEAPF32[$triT0>>2]);
     $285 = !($267 <= $284);
     if (!($285)) {
      label = 38;
      break;
     }
    }
   }
  }
  if ($175) {
   $303 = (($181) + ($89))|0;
   $304 = (Math_fround(($303|0)));
   $305 = !($304 < Math_fround(0.0));
   $306 = !($304 >= $153);
   $or$cond22 = $305 & $306;
   if (!($or$cond22)) {
    label = 45;
    break;
   }
   $307 = Math_fround($86 + $uif$0);
   $308 = Math_fround($140 + $tu$0);
   $tu$1 = $308;$tv$1 = $tv$0;$ui$1 = $181;$uif$1 = $307;$vi$1 = $vi$0;$vif$1 = $vif$0;
  } else {
   $309 = (($vi$0) + ($90))|0;
   $310 = (($309) + ($90))|0;
   $311 = (Math_fround(($310|0)));
   $312 = !($311 < Math_fround(0.0));
   $313 = !($311 >= $154);
   $or$cond23 = $312 & $313;
   if (!($or$cond23)) {
    label = 45;
    break;
   }
   $314 = Math_fround($88 + $vif$0);
   $315 = Math_fround($141 + $tv$0);
   $tu$1 = $tu$0;$tv$1 = $315;$ui$1 = $ui$0;$uif$1 = $uif$0;$vi$1 = $309;$vif$1 = $314;
  }
  $316 = $176 < Math_fround(0.999899983406066894531);
  if ($316) {
   $hLinePrev$0 = $178;$tu$0 = $tu$1;$tv$0 = $tv$1;$ui$0 = $ui$1;$uif$0 = $uif$1;$vi$0 = $vi$1;$vif$0 = $vif$1;
  } else {
   label = 45;
   break;
  }
 }
 if ((label|0) == 35) {
  $268 = Math_fround(HEAPF32[$duhvNorm>>2]);
  $269 = Math_fround($265 * $268);
  $270 = Math_fround($64 + $269);
  $271 = Math_fround($41 * $270);
  $272 = Math_fround(HEAPF32[$107>>2]);
  $273 = Math_fround($265 * $272);
  $274 = Math_fround($28 + $273);
  $275 = Math_fround(HEAPF32[$108>>2]);
  $276 = Math_fround($265 * $275);
  $277 = Math_fround($71 + $276);
  $278 = Math_fround($43 * $277);
  $279 = $243 << 1;
  HEAPF32[$aCallback>>2] = $271;
  $280 = (($aCallback) + 4|0);
  HEAPF32[$280>>2] = $274;
  $281 = (($aCallback) + 8|0);
  HEAPF32[$281>>2] = $278;
  $282 = (($aCallback) + 12|0);
  HEAP32[$282>>2] = $279;
  $283 = (($aCallback) + 16|0);
  HEAP8[$283>>0] = 1;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 38) {
  $286 = Math_fround(HEAPF32[$duhvNorm>>2]);
  $287 = Math_fround($267 * $286);
  $288 = Math_fround($64 + $287);
  $289 = Math_fround($41 * $288);
  $290 = Math_fround(HEAPF32[$107>>2]);
  $291 = Math_fround($267 * $290);
  $292 = Math_fround($28 + $291);
  $293 = Math_fround(HEAPF32[$108>>2]);
  $294 = Math_fround($267 * $293);
  $295 = Math_fround($71 + $294);
  $296 = Math_fround($43 * $295);
  $297 = $243 << 1;
  $298 = $297 | 1;
  HEAPF32[$aCallback>>2] = $289;
  $299 = (($aCallback) + 4|0);
  HEAPF32[$299>>2] = $292;
  $300 = (($aCallback) + 8|0);
  HEAPF32[$300>>2] = $296;
  $301 = (($aCallback) + 12|0);
  HEAP32[$301>>2] = $298;
  $302 = (($aCallback) + 16|0);
  HEAP8[$302>>0] = 1;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 45) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu19GetRaycastFuncTableEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (548376|0);
}
function __ZN23RayMeshColliderCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$lHit,$lp0,$lp1,$lp2,$0,$1) {
 $this = $this|0;
 $lHit = $lHit|0;
 $lp0 = $lp0|0;
 $lp1 = $lp1|0;
 $lp2 = $lp2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$lcssa = 0, $$phi$trans$insert = 0, $$pre = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0;
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0;
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0.0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $hit = 0, $i$043 = 0, $lp0$idx$val = Math_fround(0), $lp0$idx5 = 0, $lp0$idx5$val = Math_fround(0), $lp0$idx6 = 0, $lp0$idx6$val = Math_fround(0), $lp1$idx$val = Math_fround(0), $lp1$idx3 = 0, $lp1$idx3$val = Math_fround(0), $lp1$idx4 = 0, $lp1$idx4$val = Math_fround(0), $lp2$idx$val = Math_fround(0);
 var $lp2$idx1 = 0, $lp2$idx1$val = Math_fround(0), $lp2$idx2 = 0, $lp2$idx2$val = Math_fround(0), $storemerge = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $hit = sp;
 $2 = (($lHit) + 44|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($lHit) + 48|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(Math_fround(1.0) - $3);
 $7 = Math_fround($6 - $5);
 $lp0$idx$val = Math_fround(HEAPF32[$lp0>>2]);
 $lp0$idx5 = (($lp0) + 4|0);
 $lp0$idx5$val = Math_fround(HEAPF32[$lp0$idx5>>2]);
 $lp0$idx6 = (($lp0) + 8|0);
 $lp0$idx6$val = Math_fround(HEAPF32[$lp0$idx6>>2]);
 $8 = Math_fround($7 * $lp0$idx$val);
 $9 = Math_fround($7 * $lp0$idx5$val);
 $10 = Math_fround($7 * $lp0$idx6$val);
 $lp1$idx$val = Math_fround(HEAPF32[$lp1>>2]);
 $lp1$idx3 = (($lp1) + 4|0);
 $lp1$idx3$val = Math_fround(HEAPF32[$lp1$idx3>>2]);
 $lp1$idx4 = (($lp1) + 8|0);
 $lp1$idx4$val = Math_fround(HEAPF32[$lp1$idx4>>2]);
 $11 = Math_fround($3 * $lp1$idx$val);
 $12 = Math_fround($3 * $lp1$idx3$val);
 $13 = Math_fround($3 * $lp1$idx4$val);
 $14 = Math_fround($8 + $11);
 $15 = Math_fround($9 + $12);
 $16 = Math_fround($10 + $13);
 $lp2$idx$val = Math_fround(HEAPF32[$lp2>>2]);
 $lp2$idx1 = (($lp2) + 4|0);
 $lp2$idx1$val = Math_fround(HEAPF32[$lp2$idx1>>2]);
 $lp2$idx2 = (($lp2) + 8|0);
 $lp2$idx2$val = Math_fround(HEAPF32[$lp2$idx2>>2]);
 $17 = Math_fround($5 * $lp2$idx$val);
 $18 = Math_fround($5 * $lp2$idx1$val);
 $19 = Math_fround($5 * $lp2$idx2$val);
 $20 = Math_fround($14 + $17);
 $21 = Math_fround($15 + $18);
 $22 = Math_fround($16 + $19);
 ;HEAP32[$hit+0>>2]=HEAP32[$lHit+0>>2]|0;HEAP32[$hit+4>>2]=HEAP32[$lHit+4>>2]|0;HEAP32[$hit+8>>2]=HEAP32[$lHit+8>>2]|0;
 $23 = (($lHit) + 12|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = (($hit) + 12|0);
 HEAP16[$25>>1] = $24;
 $26 = (($hit) + 16|0);
 $27 = (($lHit) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$26>>2] = $28;
 $29 = (($hit) + 20|0);
 $30 = (($lHit) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$29>>2] = $31;
 $32 = (($hit) + 24|0);
 $33 = (($lHit) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$32>>2] = $34;
 $35 = (($hit) + 28|0);
 $36 = (($lHit) + 28|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 HEAPF32[$35>>2] = $37;
 $38 = (($hit) + 32|0);
 $39 = (($lHit) + 32|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 HEAPF32[$38>>2] = $40;
 $41 = (($hit) + 36|0);
 $42 = (($lHit) + 36|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$41>>2] = $43;
 $44 = (($hit) + 40|0);
 $45 = (($lHit) + 40|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 HEAPF32[$44>>2] = $46;
 $47 = (($hit) + 44|0);
 ;HEAP32[$47+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$47+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$47+16>>2]=HEAP32[$2+16>>2]|0;
 $48 = (($this) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 20|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = Math_fround($20 * Math_fround(2.0));
 $53 = Math_fround($21 * Math_fround(2.0));
 $54 = Math_fround($22 * Math_fround(2.0));
 $55 = (($51) + 24|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 * $56);
 $58 = Math_fround($57 + Math_fround(-0.5));
 $59 = (($51) + 12|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($52 * $60);
 $62 = (($51) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($53 * $63);
 $65 = Math_fround($61 + $64);
 $66 = (($51) + 20|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($54 * $67);
 $69 = Math_fround($65 + $68);
 $70 = Math_fround($52 * $58);
 $71 = Math_fround($54 * $63);
 $72 = Math_fround($53 * $67);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($56 * $73);
 $75 = Math_fround($70 + $74);
 $76 = Math_fround($60 * $69);
 $77 = Math_fround($76 + $75);
 $78 = Math_fround($53 * $58);
 $79 = Math_fround($52 * $67);
 $80 = Math_fround($54 * $60);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($56 * $81);
 $83 = Math_fround($78 + $82);
 $84 = Math_fround($63 * $69);
 $85 = Math_fround($84 + $83);
 $86 = Math_fround($54 * $58);
 $87 = Math_fround($53 * $60);
 $88 = Math_fround($52 * $63);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($56 * $89);
 $91 = Math_fround($86 + $90);
 $92 = Math_fround($67 * $69);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround(HEAPF32[$51>>2]);
 $95 = Math_fround($94 * $77);
 $96 = (($51) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 * $85);
 $99 = (($51) + 8|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 * $93);
 $102 = Math_fround($95 * Math_fround(2.0));
 $103 = Math_fround($98 * Math_fround(2.0));
 $104 = Math_fround($101 * Math_fround(2.0));
 $105 = Math_fround($60 * $102);
 $106 = Math_fround($63 * $103);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($67 * $104);
 $109 = Math_fround($108 + $107);
 $110 = Math_fround($58 * $102);
 $111 = Math_fround($63 * $104);
 $112 = Math_fround($67 * $103);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($56 * $113);
 $115 = Math_fround($110 - $114);
 $116 = Math_fround($60 * $109);
 $117 = Math_fround($116 + $115);
 $118 = Math_fround($58 * $103);
 $119 = Math_fround($67 * $102);
 $120 = Math_fround($60 * $104);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($56 * $121);
 $123 = Math_fround($118 - $122);
 $124 = Math_fround($63 * $109);
 $125 = Math_fround($124 + $123);
 $126 = Math_fround($58 * $104);
 $127 = Math_fround($60 * $103);
 $128 = Math_fround($63 * $102);
 $129 = Math_fround($127 - $128);
 $130 = Math_fround($56 * $129);
 $131 = Math_fround($126 - $130);
 $132 = Math_fround($67 * $109);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround($117 * Math_fround(2.0));
 $135 = Math_fround($125 * Math_fround(2.0));
 $136 = Math_fround($133 * Math_fround(2.0));
 $137 = (($49) + 12|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($138 * $138);
 $140 = Math_fround($139 + Math_fround(-0.5));
 $141 = Math_fround(HEAPF32[$49>>2]);
 $142 = Math_fround($141 * $134);
 $143 = (($49) + 4|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround($144 * $135);
 $146 = Math_fround($142 + $145);
 $147 = (($49) + 8|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = Math_fround($148 * $136);
 $150 = Math_fround($149 + $146);
 $151 = Math_fround($140 * $134);
 $152 = Math_fround($144 * $136);
 $153 = Math_fround($148 * $135);
 $154 = Math_fround($152 - $153);
 $155 = Math_fround($138 * $154);
 $156 = Math_fround($151 + $155);
 $157 = Math_fround($141 * $150);
 $158 = Math_fround($157 + $156);
 $159 = Math_fround($140 * $135);
 $160 = Math_fround($148 * $134);
 $161 = Math_fround($141 * $136);
 $162 = Math_fround($160 - $161);
 $163 = Math_fround($138 * $162);
 $164 = Math_fround($159 + $163);
 $165 = Math_fround($144 * $150);
 $166 = Math_fround($165 + $164);
 $167 = Math_fround($140 * $136);
 $168 = Math_fround($141 * $135);
 $169 = Math_fround($144 * $134);
 $170 = Math_fround($168 - $169);
 $171 = Math_fround($138 * $170);
 $172 = Math_fround($167 + $171);
 $173 = Math_fround($148 * $150);
 $174 = Math_fround($172 + $173);
 $175 = (($49) + 16|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = Math_fround($176 + $158);
 $178 = (($49) + 20|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround($179 + $166);
 $181 = (($49) + 24|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = Math_fround($182 + $174);
 HEAPF32[$26>>2] = $177;
 HEAPF32[$29>>2] = $180;
 HEAPF32[$32>>2] = $183;
 HEAP16[$25>>1] = 13;
 HEAPF32[$35>>2] = Math_fround(0.0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $184 = (($this) + 32|0);
 $185 = HEAP32[$184>>2]|0;
 $186 = $185 & 2;
 $187 = ($186|0)==(0);
 if (!($187)) {
  $188 = Math_fround(HEAPF32[$lp1>>2]);
  $189 = Math_fround(HEAPF32[$lp0>>2]);
  $190 = Math_fround($188 - $189);
  $191 = Math_fround(HEAPF32[$lp1$idx3>>2]);
  $192 = Math_fround(HEAPF32[$lp0$idx5>>2]);
  $193 = Math_fround($191 - $192);
  $194 = Math_fround(HEAPF32[$lp1$idx4>>2]);
  $195 = Math_fround(HEAPF32[$lp0$idx6>>2]);
  $196 = Math_fround($194 - $195);
  $197 = Math_fround(HEAPF32[$lp2>>2]);
  $198 = Math_fround($197 - $189);
  $199 = Math_fround(HEAPF32[$lp2$idx1>>2]);
  $200 = Math_fround($199 - $192);
  $201 = Math_fround(HEAPF32[$lp2$idx2>>2]);
  $202 = Math_fround($201 - $195);
  $203 = Math_fround($193 * $202);
  $204 = Math_fround($196 * $200);
  $205 = Math_fround($203 - $204);
  $206 = Math_fround($196 * $198);
  $207 = Math_fround($190 * $202);
  $208 = Math_fround($206 - $207);
  $209 = Math_fround($190 * $200);
  $210 = Math_fround($193 * $198);
  $211 = Math_fround($209 - $210);
  $212 = (($this) + 28|0);
  $213 = HEAP32[$212>>2]|0;
  $214 = ($213|0)==(0|0);
  if ($214) {
   $247 = HEAP32[$48>>2]|0;
   $248 = Math_fround($205 * Math_fround(2.0));
   $249 = Math_fround($208 * Math_fround(2.0));
   $250 = Math_fround($211 * Math_fround(2.0));
   $251 = (($247) + 12|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = Math_fround($252 * $252);
   $254 = Math_fround($253 + Math_fround(-0.5));
   $255 = Math_fround(HEAPF32[$247>>2]);
   $256 = Math_fround($248 * $255);
   $257 = (($247) + 4|0);
   $258 = Math_fround(HEAPF32[$257>>2]);
   $259 = Math_fround($249 * $258);
   $260 = Math_fround($256 + $259);
   $261 = (($247) + 8|0);
   $262 = Math_fround(HEAPF32[$261>>2]);
   $263 = Math_fround($250 * $262);
   $264 = Math_fround($260 + $263);
   $265 = Math_fround($248 * $254);
   $266 = Math_fround($250 * $258);
   $267 = Math_fround($249 * $262);
   $268 = Math_fround($266 - $267);
   $269 = Math_fround($252 * $268);
   $270 = Math_fround($265 + $269);
   $271 = Math_fround($255 * $264);
   $272 = Math_fround($271 + $270);
   $273 = Math_fround($249 * $254);
   $274 = Math_fround($248 * $262);
   $275 = Math_fround($250 * $255);
   $276 = Math_fround($274 - $275);
   $277 = Math_fround($252 * $276);
   $278 = Math_fround($273 + $277);
   $279 = Math_fround($258 * $264);
   $280 = Math_fround($279 + $278);
   $281 = Math_fround($250 * $254);
   $282 = Math_fround($249 * $255);
   $283 = Math_fround($248 * $258);
   $284 = Math_fround($282 - $283);
   $285 = Math_fround($252 * $284);
   $286 = Math_fround($281 + $285);
   $287 = Math_fround($262 * $264);
   $288 = Math_fround($286 + $287);
   HEAPF32[$35>>2] = $272;
   HEAPF32[$38>>2] = $280;
   HEAPF32[$41>>2] = $288;
   $290 = $272;$292 = $280;$storemerge = $288;
  } else {
   $215 = Math_fround(HEAPF32[$213>>2]);
   $216 = Math_fround($205 * $215);
   $217 = (($213) + 4|0);
   $218 = Math_fround(HEAPF32[$217>>2]);
   $219 = Math_fround($208 * $218);
   $220 = Math_fround($216 + $219);
   $221 = (($213) + 8|0);
   $222 = Math_fround(HEAPF32[$221>>2]);
   $223 = Math_fround($211 * $222);
   $224 = Math_fround($220 + $223);
   $225 = (($213) + 12|0);
   $226 = Math_fround(HEAPF32[$225>>2]);
   $227 = Math_fround($205 * $226);
   $228 = (($213) + 16|0);
   $229 = Math_fround(HEAPF32[$228>>2]);
   $230 = Math_fround($208 * $229);
   $231 = Math_fround($227 + $230);
   $232 = (($213) + 20|0);
   $233 = Math_fround(HEAPF32[$232>>2]);
   $234 = Math_fround($211 * $233);
   $235 = Math_fround($231 + $234);
   $236 = (($213) + 24|0);
   $237 = Math_fround(HEAPF32[$236>>2]);
   $238 = Math_fround($205 * $237);
   $239 = (($213) + 28|0);
   $240 = Math_fround(HEAPF32[$239>>2]);
   $241 = Math_fround($208 * $240);
   $242 = Math_fround($238 + $241);
   $243 = (($213) + 32|0);
   $244 = Math_fround(HEAPF32[$243>>2]);
   $245 = Math_fround($211 * $244);
   $246 = Math_fround($242 + $245);
   HEAPF32[$35>>2] = $224;
   HEAPF32[$38>>2] = $235;
   $290 = $224;$292 = $235;$storemerge = $246;
  }
  HEAPF32[$41>>2] = $storemerge;
  $289 = Math_fround($290 * $290);
  $291 = Math_fround($292 * $292);
  $293 = Math_fround($289 + $291);
  $294 = Math_fround($storemerge * $storemerge);
  $295 = Math_fround($294 + $293);
  $296 = (Math_fround(Math_sqrt((Math_fround($295)))));
  $297 = $296 > Math_fround(0.0);
  if ($297) {
   $298 = Math_fround(Math_fround(1.0) / $296);
   $299 = Math_fround($290 * $298);
   HEAPF32[$35>>2] = $299;
   $300 = Math_fround($292 * $298);
   HEAPF32[$38>>2] = $300;
   $301 = Math_fround($storemerge * $298);
   HEAPF32[$41>>2] = $301;
   $309 = $299;$313 = $300;$318 = $301;
  } else {
   $309 = $290;$313 = $292;$318 = $storemerge;
  }
  $302 = (($this) + 48|0);
  $303 = HEAP8[$302>>0]|0;
  $304 = ($303<<24>>24)==(0);
  if (!($304)) {
   $305 = (($this) + 44|0);
   $306 = HEAP32[$305>>2]|0;
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = Math_fround($309 * $307);
   $310 = (($306) + 4|0);
   $311 = Math_fround(HEAPF32[$310>>2]);
   $312 = Math_fround($313 * $311);
   $314 = Math_fround($308 + $312);
   $315 = (($306) + 8|0);
   $316 = Math_fround(HEAPF32[$315>>2]);
   $317 = Math_fround($318 * $316);
   $319 = Math_fround($314 + $317);
   $320 = $319 > Math_fround(0.0);
   if ($320) {
    $321 = Math_fround(-$309);
    $322 = Math_fround(-$313);
    $323 = Math_fround(-$318);
    HEAPF32[$35>>2] = $321;
    HEAPF32[$38>>2] = $322;
    HEAPF32[$41>>2] = $323;
   }
  }
  HEAP16[$25>>1] = 15;
 }
 $324 = (($this) + 36|0);
 $325 = HEAP32[$324>>2]|0;
 $326 = ($325|0)==(0|0);
 if (!($326)) {
  $327 = (($this) + 40|0);
  $328 = HEAP32[$327>>2]|0;
  $329 = (FUNCTION_TABLE_iii[$325 & 4095]($hit,$328)|0);
  $$0 = $329;
  STACKTOP = sp;return ($$0|0);
 }
 $330 = (($this) + 12|0);
 $331 = HEAP32[$330>>2]|0;
 $332 = (($this) + 16|0);
 $333 = HEAP32[$332>>2]|0;
 $334 = ($331|0)==($333|0);
 if ($334) {
  $337 = (($this) + 49|0);
  HEAP8[$337>>0] = 1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $335 = ($331|0)==(0);
 $$phi$trans$insert = (($this) + 8|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 L23: do {
  if ($335) {
   $$lcssa = 0;
  } else {
   $336 = Math_fround(HEAPF32[$44>>2]);
   $i$043 = 0;
   while(1) {
    $340 = ((($$pre) + ($i$043<<6)|0) + 40|0);
    $341 = Math_fround(HEAPF32[$340>>2]);
    $342 = Math_fround($341 - $336);
    $343 = (Math_fround(Math_abs((Math_fround($342)))));
    $344 = +$343;
    $345 = $344 < 1.00000000000000004792E-4;
    $339 = (($i$043) + 1)|0;
    if ($345) {
     $$0 = 1;
     break;
    }
    $338 = ($339>>>0)<($331>>>0);
    if ($338) {
     $i$043 = $339;
    } else {
     $$lcssa = $331;
     break L23;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $346 = (($$lcssa) + 1)|0;
 HEAP32[$330>>2] = $346;
 $347 = (($$pre) + ($$lcssa<<6)|0);
 ;HEAP32[$347+0>>2]=HEAP32[$hit+0>>2]|0;HEAP32[$347+4>>2]=HEAP32[$hit+4>>2]|0;HEAP32[$347+8>>2]=HEAP32[$hit+8>>2]|0;
 $348 = HEAP16[$25>>1]|0;
 $349 = ((($$pre) + ($$lcssa<<6)|0) + 12|0);
 HEAP16[$349>>1] = $348;
 $350 = Math_fround(HEAPF32[$26>>2]);
 $351 = ((($$pre) + ($$lcssa<<6)|0) + 16|0);
 HEAPF32[$351>>2] = $350;
 $352 = Math_fround(HEAPF32[$29>>2]);
 $353 = ((($$pre) + ($$lcssa<<6)|0) + 20|0);
 HEAPF32[$353>>2] = $352;
 $354 = Math_fround(HEAPF32[$32>>2]);
 $355 = ((($$pre) + ($$lcssa<<6)|0) + 24|0);
 HEAPF32[$355>>2] = $354;
 $356 = Math_fround(HEAPF32[$35>>2]);
 $357 = ((($$pre) + ($$lcssa<<6)|0) + 28|0);
 HEAPF32[$357>>2] = $356;
 $358 = Math_fround(HEAPF32[$38>>2]);
 $359 = ((($$pre) + ($$lcssa<<6)|0) + 32|0);
 HEAPF32[$359>>2] = $358;
 $360 = Math_fround(HEAPF32[$41>>2]);
 $361 = ((($$pre) + ($$lcssa<<6)|0) + 36|0);
 HEAPF32[$361>>2] = $360;
 $362 = Math_fround(HEAPF32[$44>>2]);
 $363 = ((($$pre) + ($$lcssa<<6)|0) + 40|0);
 HEAPF32[$363>>2] = $362;
 $364 = ((($$pre) + ($$lcssa<<6)|0) + 44|0);
 ;HEAP32[$364+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$364+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$364+8>>2]=HEAP32[$47+8>>2]|0;HEAP32[$364+12>>2]=HEAP32[$47+12>>2]|0;HEAP32[$364+16>>2]=HEAP32[$47+16>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN23RayMeshColliderCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu9RadixSortC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((548432 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (($this) + 32|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;
 HEAP8[$1>>0] = 1;
 HEAP32[$0>>2] = -2147483648;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu9RadixSortD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu9RadixSortD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu9RadixSort4SortEPKjjNS0_9RadixHintE($this,$input,$nb,$hint) {
 $this = $this|0;
 $input = $input|0;
 $nb = $nb|0;
 $hint = $hint|0;
 var $$not = 0, $$phi$trans$insert = 0, $$phi$trans$insert126 = 0, $$pre = 0, $$pre121 = 0, $$pre122 = 0, $$pre123 = 0, $$pre124 = 0, $$pre125 = 0, $$pre127 = 0, $$sum = 0, $$sum$i = 0, $$sum1 = 0, $$sum1112 = 0, $$sum1314 = 0, $$sum1516 = 0, $$sum1718 = 0, $$sum1920 = 0, $$sum2 = 0, $$sum2122 = 0;
 var $$sum2324 = 0, $$sum2526 = 0, $$sum2728 = 0, $$sum2930 = 0, $$sum3132 = 0, $$sum3334 = 0, $$sum34 = 0, $$sum3536 = 0, $$sum3738 = 0, $$sum43 = 0, $$sum44 = 0, $$sum45 = 0, $$sum56 = 0, $$sum78 = 0, $$sum910 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Indices$079 = 0, $Indices14$099 = 0, $Indices23$053 = 0, $NbNegativeValues$064 = 0, $NbNegativeValues$1 = 0;
 var $PrevVal$071 = 0, $PrevVal1$078 = 0, $PrevVal1$078$phi = 0, $PrevVal11$093 = 0, $PrevVal11$093$phi = 0, $PrevVal15$0100 = 0, $PrevVal15$0100$phi = 0, $Running10$092 = 0, $brmerge = 0, $exitcond = 0, $exitcond103 = 0, $exitcond104 = 0, $exitcond105 = 0, $exitcond106 = 0, $exitcond107 = 0, $exitcond108 = 0, $exitcond112 = 0, $i$046 = 0, $i13$084 = 0, $i18$065 = 0;
 var $i19$051 = 0, $i20$047 = 0, $i21$049 = 0, $i22$055 = 0, $j$058 = 0, $or$cond = 0, $or$cond39 = 0, $p$073 = 0, $p$180 = 0, $p$2$ph = 0, $p$268 = 0, $p3$198 = 0, $p3$2$ph = 0, $p3$288 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($input|0)==(0|0);
 $1 = ($nb|0)==(0);
 $or$cond = $0 | $1;
 $2 = ($nb|0)<(0);
 $or$cond39 = $or$cond | $2;
 if ($or$cond39) {
  STACKTOP = sp;return ($this|0);
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 HEAP32[$3>>2] = $5;
 $6 = ($hint|0)==(1);
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 _memset(($8|0),0,4096)|0;
 $9 = (($input) + ($nb<<2)|0);
 $10 = HEAP32[$7>>2]|0;
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)<(0);
 if ($6) {
  L31: do {
   if ($13) {
    $14 = ($9|0)==($input|0);
    if (!($14)) {
     $15 = HEAP32[$input>>2]|0;
     $PrevVal$071 = $15;$p$073 = $input;
     while(1) {
      $16 = HEAP32[$p$073>>2]|0;
      $17 = ($16>>>0)<($PrevVal$071>>>0);
      if ($17) {
       $p$2$ph = $p$073;
       break L31;
      }
      $18 = (($p$073) + 4|0);
      $19 = (($p$073) + 1|0);
      $20 = $16 & 255;
      $21 = (($10) + ($20<<2)|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($22) + 1)|0;
      HEAP32[$21>>2] = $23;
      $24 = (($p$073) + 2|0);
      $25 = HEAP8[$19>>0]|0;
      $26 = $25&255;
      $$sum3334 = $26 | 256;
      $27 = (($10) + ($$sum3334<<2)|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($28) + 1)|0;
      HEAP32[$27>>2] = $29;
      $30 = (($p$073) + 3|0);
      $31 = HEAP8[$24>>0]|0;
      $32 = $31&255;
      $$sum3536 = $32 | 512;
      $33 = (($10) + ($$sum3536<<2)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($34) + 1)|0;
      HEAP32[$33>>2] = $35;
      $36 = HEAP8[$30>>0]|0;
      $37 = $36&255;
      $$sum3738 = $37 | 768;
      $38 = (($10) + ($$sum3738<<2)|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = (($39) + 1)|0;
      HEAP32[$38>>2] = $40;
      $41 = ($18|0)==($9|0);
      if ($41) {
       break;
      } else {
       $PrevVal$071 = $16;$p$073 = $18;
      }
     }
    }
    $42 = (($this) + 28|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 1)|0;
    HEAP32[$42>>2] = $44;
    $45 = (($this) + 8|0);
    $46 = HEAP32[$45>>2]|0;
    $i$046 = 0;
    while(1) {
     $47 = (($46) + ($i$046<<2)|0);
     HEAP32[$47>>2] = $i$046;
     $48 = (($i$046) + 1)|0;
     $exitcond = ($48|0)==($nb|0);
     if ($exitcond) {
      break;
     } else {
      $i$046 = $48;
     }
    }
    STACKTOP = sp;return ($this|0);
   } else {
    $49 = (($this) + 8|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($9|0)==($input|0);
    L33: do {
     if (!($51)) {
      $52 = HEAP32[$50>>2]|0;
      $53 = (($input) + ($52<<2)|0);
      $54 = HEAP32[$53>>2]|0;
      $56 = $54;$Indices$079 = $50;$PrevVal1$078 = $54;$p$180 = $input;
      while(1) {
       $55 = ($56>>>0)<($PrevVal1$078>>>0);
       if ($55) {
        $p$2$ph = $p$180;
        break L31;
       }
       $58 = (($Indices$079) + 4|0);
       $59 = (($p$180) + 1|0);
       $60 = HEAP8[$p$180>>0]|0;
       $61 = $60&255;
       $62 = (($10) + ($61<<2)|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = (($63) + 1)|0;
       HEAP32[$62>>2] = $64;
       $65 = (($p$180) + 2|0);
       $66 = HEAP8[$59>>0]|0;
       $67 = $66&255;
       $$sum2728 = $67 | 256;
       $68 = (($10) + ($$sum2728<<2)|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = (($69) + 1)|0;
       HEAP32[$68>>2] = $70;
       $71 = (($p$180) + 3|0);
       $72 = HEAP8[$65>>0]|0;
       $73 = $72&255;
       $$sum2930 = $73 | 512;
       $74 = (($10) + ($$sum2930<<2)|0);
       $75 = HEAP32[$74>>2]|0;
       $76 = (($75) + 1)|0;
       HEAP32[$74>>2] = $76;
       $77 = (($p$180) + 4|0);
       $78 = HEAP8[$71>>0]|0;
       $79 = $78&255;
       $$sum3132 = $79 | 768;
       $80 = (($10) + ($$sum3132<<2)|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = (($81) + 1)|0;
       HEAP32[$80>>2] = $82;
       $83 = ($77|0)==($9|0);
       if ($83) {
        break L33;
       }
       $$pre121 = HEAP32[$58>>2]|0;
       $$phi$trans$insert = (($input) + ($$pre121<<2)|0);
       $$pre122 = HEAP32[$$phi$trans$insert>>2]|0;
       $PrevVal1$078$phi = $56;$56 = $$pre122;$Indices$079 = $58;$p$180 = $77;$PrevVal1$078 = $PrevVal1$078$phi;
      }
     }
    } while(0);
    $84 = (($this) + 28|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($85) + 1)|0;
    HEAP32[$84>>2] = $86;
    STACKTOP = sp;return ($this|0);
   }
  } while(0);
  $57 = ($p$2$ph|0)==($9|0);
  if (!($57)) {
   $p$268 = $p$2$ph;
   while(1) {
    $87 = (($p$268) + 1|0);
    $88 = HEAP8[$p$268>>0]|0;
    $89 = $88&255;
    $90 = (($10) + ($89<<2)|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($91) + 1)|0;
    HEAP32[$90>>2] = $92;
    $93 = (($p$268) + 2|0);
    $94 = HEAP8[$87>>0]|0;
    $95 = $94&255;
    $$sum2122 = $95 | 256;
    $96 = (($10) + ($$sum2122<<2)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($97) + 1)|0;
    HEAP32[$96>>2] = $98;
    $99 = (($p$268) + 3|0);
    $100 = HEAP8[$93>>0]|0;
    $101 = $100&255;
    $$sum2324 = $101 | 512;
    $102 = (($10) + ($$sum2324<<2)|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($103) + 1)|0;
    HEAP32[$102>>2] = $104;
    $105 = (($p$268) + 4|0);
    $106 = HEAP8[$99>>0]|0;
    $107 = $106&255;
    $$sum2526 = $107 | 768;
    $108 = (($10) + ($$sum2526<<2)|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($109) + 1)|0;
    HEAP32[$108>>2] = $110;
    $111 = ($105|0)==($9|0);
    if ($111) {
     break;
    } else {
     $p$268 = $105;
    }
   }
  }
 } else {
  L6: do {
   if ($13) {
    $112 = ($9|0)==($input|0);
    L8: do {
     if (!($112)) {
      $113 = HEAP32[$input>>2]|0;
      $115 = $113;$PrevVal11$093 = $113;$Running10$092 = $input;
      while(1) {
       $114 = ($115|0)<($PrevVal11$093|0);
       if ($114) {
        $p3$2$ph = $Running10$092;
        break L6;
       }
       $116 = (($Running10$092) + 4|0);
       $117 = (($Running10$092) + 1|0);
       $118 = $115 & 255;
       $119 = (($10) + ($118<<2)|0);
       $120 = HEAP32[$119>>2]|0;
       $121 = (($120) + 1)|0;
       HEAP32[$119>>2] = $121;
       $122 = (($Running10$092) + 2|0);
       $123 = HEAP8[$117>>0]|0;
       $124 = $123&255;
       $$sum1516 = $124 | 256;
       $125 = (($10) + ($$sum1516<<2)|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = (($126) + 1)|0;
       HEAP32[$125>>2] = $127;
       $128 = (($Running10$092) + 3|0);
       $129 = HEAP8[$122>>0]|0;
       $130 = $129&255;
       $$sum1718 = $130 | 512;
       $131 = (($10) + ($$sum1718<<2)|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = (($132) + 1)|0;
       HEAP32[$131>>2] = $133;
       $134 = HEAP8[$128>>0]|0;
       $135 = $134&255;
       $$sum1920 = $135 | 768;
       $136 = (($10) + ($$sum1920<<2)|0);
       $137 = HEAP32[$136>>2]|0;
       $138 = (($137) + 1)|0;
       HEAP32[$136>>2] = $138;
       $139 = ($116|0)==($9|0);
       if ($139) {
        break L8;
       }
       $$pre124 = HEAP32[$116>>2]|0;
       $PrevVal11$093$phi = $115;$115 = $$pre124;$Running10$092 = $116;$PrevVal11$093 = $PrevVal11$093$phi;
      }
     }
    } while(0);
    $140 = (($this) + 28|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (($141) + 1)|0;
    HEAP32[$140>>2] = $142;
    $143 = (($this) + 8|0);
    $144 = HEAP32[$143>>2]|0;
    $i13$084 = 0;
    while(1) {
     $145 = (($144) + ($i13$084<<2)|0);
     HEAP32[$145>>2] = $i13$084;
     $146 = (($i13$084) + 1)|0;
     $exitcond112 = ($146|0)==($nb|0);
     if ($exitcond112) {
      break;
     } else {
      $i13$084 = $146;
     }
    }
    STACKTOP = sp;return ($this|0);
   } else {
    $147 = (($this) + 8|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ($9|0)==($input|0);
    L19: do {
     if (!($149)) {
      $150 = HEAP32[$148>>2]|0;
      $151 = (($input) + ($150<<2)|0);
      $152 = HEAP32[$151>>2]|0;
      $154 = $152;$Indices14$099 = $148;$PrevVal15$0100 = $152;$p3$198 = $input;
      while(1) {
       $153 = ($154|0)<($PrevVal15$0100|0);
       if ($153) {
        $p3$2$ph = $p3$198;
        break L6;
       }
       $156 = (($Indices14$099) + 4|0);
       $157 = (($p3$198) + 1|0);
       $158 = HEAP8[$p3$198>>0]|0;
       $159 = $158&255;
       $160 = (($10) + ($159<<2)|0);
       $161 = HEAP32[$160>>2]|0;
       $162 = (($161) + 1)|0;
       HEAP32[$160>>2] = $162;
       $163 = (($p3$198) + 2|0);
       $164 = HEAP8[$157>>0]|0;
       $165 = $164&255;
       $$sum910 = $165 | 256;
       $166 = (($10) + ($$sum910<<2)|0);
       $167 = HEAP32[$166>>2]|0;
       $168 = (($167) + 1)|0;
       HEAP32[$166>>2] = $168;
       $169 = (($p3$198) + 3|0);
       $170 = HEAP8[$163>>0]|0;
       $171 = $170&255;
       $$sum1112 = $171 | 512;
       $172 = (($10) + ($$sum1112<<2)|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = (($173) + 1)|0;
       HEAP32[$172>>2] = $174;
       $175 = (($p3$198) + 4|0);
       $176 = HEAP8[$169>>0]|0;
       $177 = $176&255;
       $$sum1314 = $177 | 768;
       $178 = (($10) + ($$sum1314<<2)|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = (($179) + 1)|0;
       HEAP32[$178>>2] = $180;
       $181 = ($175|0)==($9|0);
       if ($181) {
        break L19;
       }
       $$pre125 = HEAP32[$156>>2]|0;
       $$phi$trans$insert126 = (($input) + ($$pre125<<2)|0);
       $$pre127 = HEAP32[$$phi$trans$insert126>>2]|0;
       $PrevVal15$0100$phi = $154;$154 = $$pre127;$Indices14$099 = $156;$p3$198 = $175;$PrevVal15$0100 = $PrevVal15$0100$phi;
      }
     }
    } while(0);
    $182 = (($this) + 28|0);
    $183 = HEAP32[$182>>2]|0;
    $184 = (($183) + 1)|0;
    HEAP32[$182>>2] = $184;
    STACKTOP = sp;return ($this|0);
   }
  } while(0);
  $155 = ($p3$2$ph|0)==($9|0);
  if (!($155)) {
   $p3$288 = $p3$2$ph;
   while(1) {
    $185 = (($p3$288) + 1|0);
    $186 = HEAP8[$p3$288>>0]|0;
    $187 = $186&255;
    $188 = (($10) + ($187<<2)|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = (($189) + 1)|0;
    HEAP32[$188>>2] = $190;
    $191 = (($p3$288) + 2|0);
    $192 = HEAP8[$185>>0]|0;
    $193 = $192&255;
    $$sum34 = $193 | 256;
    $194 = (($10) + ($$sum34<<2)|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = (($195) + 1)|0;
    HEAP32[$194>>2] = $196;
    $197 = (($p3$288) + 3|0);
    $198 = HEAP8[$191>>0]|0;
    $199 = $198&255;
    $$sum56 = $199 | 512;
    $200 = (($10) + ($$sum56<<2)|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = (($201) + 1)|0;
    HEAP32[$200>>2] = $202;
    $203 = (($p3$288) + 4|0);
    $204 = HEAP8[$197>>0]|0;
    $205 = $204&255;
    $$sum78 = $205 | 768;
    $206 = (($10) + ($$sum78<<2)|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = (($207) + 1)|0;
    HEAP32[$206>>2] = $208;
    $209 = ($203|0)==($9|0);
    if ($209) {
     break;
    } else {
     $p3$288 = $203;
    }
   }
  }
 }
 $210 = ($hint|0)==(0);
 if ($210) {
  $NbNegativeValues$064 = 0;$i18$065 = 128;
  while(1) {
   $$sum2 = (($i18$065) + 768)|0;
   $211 = (($10) + ($$sum2<<2)|0);
   $212 = HEAP32[$211>>2]|0;
   $213 = (($212) + ($NbNegativeValues$064))|0;
   $214 = (($i18$065) + 1)|0;
   $exitcond108 = ($214|0)==(256);
   if ($exitcond108) {
    $NbNegativeValues$1 = $213;
    break;
   } else {
    $NbNegativeValues$064 = $213;$i18$065 = $214;
   }
  }
 } else {
  $NbNegativeValues$1 = 0;
 }
 $215 = (($this) + 20|0);
 $216 = (($this) + 12|0);
 $217 = (($this) + 8|0);
 $223 = $10;$j$058 = 0;
 while(1) {
  $218 = $j$058 << 8;
  $219 = (($input) + ($j$058)|0);
  $220 = HEAP8[$219>>0]|0;
  $221 = $220&255;
  $$sum$i = $221 | $218;
  $222 = (($223) + ($$sum$i<<2)|0);
  $224 = HEAP32[$222>>2]|0;
  $225 = ($224|0)==($nb|0);
  if (!($225)) {
   $226 = (($223) + ($218<<2)|0);
   $227 = ($226|0)==(0|0);
   if (!($227)) {
    $228 = HEAP32[$215>>2]|0;
    $$not = ($j$058|0)!=(3);
    $brmerge = $$not | $6;
    $229 = HEAP32[$216>>2]|0;
    if ($brmerge) {
     HEAP32[$228>>2] = $229;
     $234 = $229;$i19$051 = 1;
     while(1) {
      $230 = (($i19$051) + -1)|0;
      $$sum45 = (($230) + ($218))|0;
      $231 = (($223) + ($$sum45<<2)|0);
      $232 = HEAP32[$231>>2]|0;
      $233 = (($234) + ($232<<2)|0);
      $235 = (($228) + ($i19$051<<2)|0);
      HEAP32[$235>>2] = $233;
      $236 = (($i19$051) + 1)|0;
      $exitcond105 = ($236|0)==(256);
      if ($exitcond105) {
       break;
      } else {
       $234 = $233;$i19$051 = $236;
      }
     }
    } else {
     $237 = (($229) + ($NbNegativeValues$1<<2)|0);
     HEAP32[$228>>2] = $237;
     $242 = $237;$i20$047 = 1;
     while(1) {
      $238 = (($i20$047) + -1)|0;
      $$sum44 = (($238) + ($218))|0;
      $239 = (($223) + ($$sum44<<2)|0);
      $240 = HEAP32[$239>>2]|0;
      $241 = (($242) + ($240<<2)|0);
      $243 = (($228) + ($i20$047<<2)|0);
      HEAP32[$243>>2] = $241;
      $244 = (($i20$047) + 1)|0;
      $exitcond103 = ($244|0)==(128);
      if ($exitcond103) {
       break;
      } else {
       $242 = $241;$i20$047 = $244;
      }
     }
     $245 = HEAP32[$216>>2]|0;
     $246 = (($228) + 512|0);
     HEAP32[$246>>2] = $245;
     $251 = $245;$i21$049 = 129;
     while(1) {
      $247 = (($i21$049) + -1)|0;
      $$sum43 = (($247) + ($218))|0;
      $248 = (($223) + ($$sum43<<2)|0);
      $249 = HEAP32[$248>>2]|0;
      $250 = (($251) + ($249<<2)|0);
      $252 = (($228) + ($i21$049<<2)|0);
      HEAP32[$252>>2] = $250;
      $253 = (($i21$049) + 1)|0;
      $exitcond104 = ($253|0)==(256);
      if ($exitcond104) {
       break;
      } else {
       $251 = $250;$i21$049 = $253;
      }
     }
    }
    $254 = HEAP32[$11>>2]|0;
    $255 = ($254|0)<(0);
    if ($255) {
     $i22$055 = 0;
     while(1) {
      $256 = $i22$055 << 2;
      $$sum1 = (($256) + ($j$058))|0;
      $257 = (($input) + ($$sum1)|0);
      $258 = HEAP8[$257>>0]|0;
      $259 = $258&255;
      $260 = (($228) + ($259<<2)|0);
      $261 = HEAP32[$260>>2]|0;
      $262 = (($261) + 4|0);
      HEAP32[$260>>2] = $262;
      HEAP32[$261>>2] = $i22$055;
      $263 = (($i22$055) + 1)|0;
      $exitcond106 = ($263|0)==($nb|0);
      if ($exitcond106) {
       break;
      } else {
       $i22$055 = $263;
      }
     }
     $$pre = HEAP32[$11>>2]|0;
     $264 = $$pre & 2147483647;
     HEAP32[$11>>2] = $264;
    } else {
     $265 = HEAP32[$217>>2]|0;
     $266 = (($265) + ($nb<<2)|0);
     $Indices23$053 = $265;
     while(1) {
      $267 = (($Indices23$053) + 4|0);
      $268 = HEAP32[$Indices23$053>>2]|0;
      $269 = $268 << 2;
      $$sum = (($269) + ($j$058))|0;
      $270 = (($input) + ($$sum)|0);
      $271 = HEAP8[$270>>0]|0;
      $272 = $271&255;
      $273 = (($228) + ($272<<2)|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = (($274) + 4|0);
      HEAP32[$273>>2] = $275;
      HEAP32[$274>>2] = $268;
      $276 = ($267|0)==($266|0);
      if ($276) {
       break;
      } else {
       $Indices23$053 = $267;
      }
     }
    }
    $277 = HEAP32[$217>>2]|0;
    $278 = HEAP32[$216>>2]|0;
    HEAP32[$217>>2] = $278;
    HEAP32[$216>>2] = $277;
   }
  }
  $279 = (($j$058) + 1)|0;
  $exitcond107 = ($279|0)==(4);
  if ($exitcond107) {
   break;
  }
  $$pre123 = HEAP32[$7>>2]|0;
  $223 = $$pre123;$j$058 = $279;
 }
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Gu9RadixSort4SortEPKfj($this,$input2,$nb) {
 $this = $this|0;
 $input2 = $input2|0;
 $nb = $nb|0;
 var $$0$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre90 = 0, $$pre91 = 0, $$pre95 = 0, $$pre96 = Math_fround(0), $$pre97 = 0, $$sum = 0, $$sum$i = 0, $$sum1 = 0, $$sum1112 = 0, $$sum1314 = 0, $$sum1516 = 0, $$sum1718 = 0, $$sum1920 = 0, $$sum2 = 0, $$sum34 = 0, $$sum56 = 0, $$sum78 = 0;
 var $$sum910 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Indices$072 = 0, $Indices7$026 = 0, $NbNegativeValues$058 = 0;
 var $PrevVal$064 = Math_fround(0), $PrevVal1$071 = Math_fround(0), $PrevVal1$071$phi = Math_fround(0), $exitcond = 0, $exitcond76 = 0, $exitcond77 = 0, $exitcond78 = 0, $exitcond79 = 0, $exitcond80 = 0, $exitcond81 = 0, $exitcond82 = 0, $exitcond83 = 0, $exitcond84 = 0, $exitcond85 = 0, $exitcond86 = 0, $i$023 = 0, $i10$040 = 0, $i11$041 = 0, $i12$047 = 0, $i13$043 = 0;
 var $i16$035 = 0, $i17$032 = 0, $i4$057 = 0, $i5$024 = 0, $i6$028 = 0, $i9$038 = 0, $j$052 = 0, $or$cond = 0, $or$cond21 = 0, $p$066 = 0, $p$173 = 0, $p$2$ph = 0, $p$260 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($input2|0)==(0|0);
 $1 = ($nb|0)==(0);
 $or$cond = $0 | $1;
 $2 = ($nb|0)<(0);
 $or$cond21 = $or$cond | $2;
 if ($or$cond21) {
  STACKTOP = sp;return ($this|0);
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 HEAP32[$3>>2] = $5;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 _memset(($7|0),0,4096)|0;
 $8 = (($input2) + ($nb<<2)|0);
 $9 = HEAP32[$6>>2]|0;
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)<(0);
 L4: do {
  if ($12) {
   $13 = ($8|0)==($input2|0);
   if (!($13)) {
    $14 = Math_fround(HEAPF32[$input2>>2]);
    $PrevVal$064 = $14;$p$066 = $input2;
    while(1) {
     $15 = Math_fround(HEAPF32[$p$066>>2]);
     $16 = $15 < $PrevVal$064;
     if ($16) {
      $p$2$ph = $p$066;
      break L4;
     }
     $17 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
     $18 = (($p$066) + 4|0);
     $19 = (($p$066) + 1|0);
     $20 = $17 & 255;
     $21 = (($9) + ($20<<2)|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($22) + 1)|0;
     HEAP32[$21>>2] = $23;
     $24 = (($p$066) + 2|0);
     $25 = HEAP8[$19>>0]|0;
     $26 = $25&255;
     $$sum1516 = $26 | 256;
     $27 = (($9) + ($$sum1516<<2)|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($28) + 1)|0;
     HEAP32[$27>>2] = $29;
     $30 = (($p$066) + 3|0);
     $31 = HEAP8[$24>>0]|0;
     $32 = $31&255;
     $$sum1718 = $32 | 512;
     $33 = (($9) + ($$sum1718<<2)|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 1)|0;
     HEAP32[$33>>2] = $35;
     $36 = HEAP8[$30>>0]|0;
     $37 = $36&255;
     $$sum1920 = $37 | 768;
     $38 = (($9) + ($$sum1920<<2)|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + 1)|0;
     HEAP32[$38>>2] = $40;
     $41 = ($18|0)==($8|0);
     if ($41) {
      break;
     } else {
      $PrevVal$064 = $15;$p$066 = $18;
     }
    }
   }
   $42 = (($this) + 28|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($43) + 1)|0;
   HEAP32[$42>>2] = $44;
   $45 = (($this) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $i$023 = 0;
   while(1) {
    $47 = (($46) + ($i$023<<2)|0);
    HEAP32[$47>>2] = $i$023;
    $48 = (($i$023) + 1)|0;
    $exitcond = ($48|0)==($nb|0);
    if ($exitcond) {
     break;
    } else {
     $i$023 = $48;
    }
   }
   STACKTOP = sp;return ($this|0);
  } else {
   $49 = (($this) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($8|0)==($input2|0);
   L16: do {
    if (!($51)) {
     $52 = HEAP32[$50>>2]|0;
     $53 = (($input2) + ($52<<2)|0);
     $54 = Math_fround(HEAPF32[$53>>2]);
     $56 = $54;$Indices$072 = $50;$PrevVal1$071 = $54;$p$173 = $input2;
     while(1) {
      $55 = $56 < $PrevVal1$071;
      if ($55) {
       $p$2$ph = $p$173;
       break L4;
      }
      $58 = (($Indices$072) + 4|0);
      $59 = (($p$173) + 1|0);
      $60 = HEAP8[$p$173>>0]|0;
      $61 = $60&255;
      $62 = (($9) + ($61<<2)|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 1)|0;
      HEAP32[$62>>2] = $64;
      $65 = (($p$173) + 2|0);
      $66 = HEAP8[$59>>0]|0;
      $67 = $66&255;
      $$sum910 = $67 | 256;
      $68 = (($9) + ($$sum910<<2)|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($69) + 1)|0;
      HEAP32[$68>>2] = $70;
      $71 = (($p$173) + 3|0);
      $72 = HEAP8[$65>>0]|0;
      $73 = $72&255;
      $$sum1112 = $73 | 512;
      $74 = (($9) + ($$sum1112<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($75) + 1)|0;
      HEAP32[$74>>2] = $76;
      $77 = (($p$173) + 4|0);
      $78 = HEAP8[$71>>0]|0;
      $79 = $78&255;
      $$sum1314 = $79 | 768;
      $80 = (($9) + ($$sum1314<<2)|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = (($81) + 1)|0;
      HEAP32[$80>>2] = $82;
      $83 = ($77|0)==($8|0);
      if ($83) {
       break L16;
      }
      $$pre95 = HEAP32[$58>>2]|0;
      $$phi$trans$insert = (($input2) + ($$pre95<<2)|0);
      $$pre96 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
      $PrevVal1$071$phi = $56;$56 = $$pre96;$Indices$072 = $58;$p$173 = $77;$PrevVal1$071 = $PrevVal1$071$phi;
     }
    }
   } while(0);
   $84 = (($this) + 28|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($85) + 1)|0;
   HEAP32[$84>>2] = $86;
   STACKTOP = sp;return ($this|0);
  }
 } while(0);
 $57 = ($p$2$ph|0)==($8|0);
 if ($57) {
  $NbNegativeValues$058 = 0;$i4$057 = 128;
 } else {
  $p$260 = $p$2$ph;
  while(1) {
   $87 = (($p$260) + 1|0);
   $88 = HEAP8[$p$260>>0]|0;
   $89 = $88&255;
   $90 = (($9) + ($89<<2)|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($91) + 1)|0;
   HEAP32[$90>>2] = $92;
   $93 = (($p$260) + 2|0);
   $94 = HEAP8[$87>>0]|0;
   $95 = $94&255;
   $$sum34 = $95 | 256;
   $96 = (($9) + ($$sum34<<2)|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($97) + 1)|0;
   HEAP32[$96>>2] = $98;
   $99 = (($p$260) + 3|0);
   $100 = HEAP8[$93>>0]|0;
   $101 = $100&255;
   $$sum56 = $101 | 512;
   $102 = (($9) + ($$sum56<<2)|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (($103) + 1)|0;
   HEAP32[$102>>2] = $104;
   $105 = (($p$260) + 4|0);
   $106 = HEAP8[$99>>0]|0;
   $107 = $106&255;
   $$sum78 = $107 | 768;
   $108 = (($9) + ($$sum78<<2)|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = (($109) + 1)|0;
   HEAP32[$108>>2] = $110;
   $111 = ($105|0)==($8|0);
   if ($111) {
    $NbNegativeValues$058 = 0;$i4$057 = 128;
    break;
   } else {
    $p$260 = $105;
   }
  }
 }
 while(1) {
  $$sum2 = (($i4$057) + 768)|0;
  $116 = (($9) + ($$sum2<<2)|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = (($117) + ($NbNegativeValues$058))|0;
  $119 = (($i4$057) + 1)|0;
  $exitcond86 = ($119|0)==(256);
  if ($exitcond86) {
   break;
  } else {
   $NbNegativeValues$058 = $118;$i4$057 = $119;
  }
 }
 $112 = (($this) + 20|0);
 $113 = (($this) + 12|0);
 $114 = (($this) + 8|0);
 $115 = (($nb) + -1)|0;
 $125 = $9;$j$052 = 0;
 while(1) {
  $120 = $j$052 << 8;
  $121 = (($input2) + ($j$052)|0);
  $122 = HEAP8[$121>>0]|0;
  $123 = $122&255;
  $$sum$i = $123 | $120;
  $124 = (($125) + ($$sum$i<<2)|0);
  $126 = HEAP32[$124>>2]|0;
  $127 = ($126|0)==($nb|0);
  if ($127) {
   $$0$i = 0;
  } else {
   $128 = (($125) + ($120<<2)|0);
   $$0$i = $128;
  }
  $129 = ($j$052|0)==(3);
  $130 = ($$0$i|0)!=(0|0);
  do {
   if ($129) {
    if (!($130)) {
     $218 = ($122<<24>>24)<(0);
     if (!($218)) {
      break;
     }
     $219 = HEAP32[$10>>2]|0;
     $220 = ($219|0)<(0);
     if ($220) {
      $221 = HEAP32[$113>>2]|0;
      $i16$035 = 0;
      while(1) {
       $224 = (($115) - ($i16$035))|0;
       $225 = (($221) + ($i16$035<<2)|0);
       HEAP32[$225>>2] = $224;
       $226 = (($i16$035) + 1)|0;
       $exitcond79 = ($226|0)==($nb|0);
       if ($exitcond79) {
        break;
       } else {
        $i16$035 = $226;
       }
      }
      $$pre90 = HEAP32[$10>>2]|0;
      $227 = $$pre90 & 2147483647;
      HEAP32[$10>>2] = $227;
     } else {
      $222 = HEAP32[$114>>2]|0;
      $223 = HEAP32[$113>>2]|0;
      $i17$032 = 0;
      while(1) {
       $228 = (($115) - ($i17$032))|0;
       $229 = (($222) + ($228<<2)|0);
       $230 = HEAP32[$229>>2]|0;
       $231 = (($223) + ($i17$032<<2)|0);
       HEAP32[$231>>2] = $230;
       $232 = (($i17$032) + 1)|0;
       $exitcond78 = ($232|0)==($nb|0);
       if ($exitcond78) {
        break;
       } else {
        $i17$032 = $232;
       }
      }
     }
     $233 = HEAP32[$114>>2]|0;
     $234 = HEAP32[$113>>2]|0;
     HEAP32[$114>>2] = $234;
     HEAP32[$113>>2] = $233;
     break;
    }
    $165 = HEAP32[$112>>2]|0;
    $166 = HEAP32[$113>>2]|0;
    $167 = (($166) + ($118<<2)|0);
    HEAP32[$165>>2] = $167;
    $172 = $167;$i9$038 = 1;
    while(1) {
     $168 = (($i9$038) + -1)|0;
     $169 = (($$0$i) + ($168<<2)|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = (($172) + ($170<<2)|0);
     $173 = (($165) + ($i9$038<<2)|0);
     HEAP32[$173>>2] = $171;
     $174 = (($i9$038) + 1)|0;
     $exitcond80 = ($174|0)==(128);
     if ($exitcond80) {
      break;
     } else {
      $172 = $171;$i9$038 = $174;
     }
    }
    $175 = HEAP32[$113>>2]|0;
    $176 = (($165) + 1020|0);
    HEAP32[$176>>2] = $175;
    $i10$040 = 0;
    while(1) {
     $177 = (255 - ($i10$040))|0;
     $178 = (($165) + ($177<<2)|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = (($$0$i) + ($177<<2)|0);
     $181 = HEAP32[$180>>2]|0;
     $182 = (($179) + ($181<<2)|0);
     $183 = (254 - ($i10$040))|0;
     $184 = (($165) + ($183<<2)|0);
     HEAP32[$184>>2] = $182;
     $185 = (($i10$040) + 1)|0;
     $exitcond81 = ($185|0)==(127);
     if ($exitcond81) {
      $i11$041 = 128;
      break;
     } else {
      $i10$040 = $185;
     }
    }
    while(1) {
     $186 = (($$0$i) + ($i11$041<<2)|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = (($165) + ($i11$041<<2)|0);
     $189 = HEAP32[$188>>2]|0;
     $190 = (($189) + ($187<<2)|0);
     HEAP32[$188>>2] = $190;
     $191 = (($i11$041) + 1)|0;
     $exitcond82 = ($191|0)==(256);
     if ($exitcond82) {
      break;
     } else {
      $i11$041 = $191;
     }
    }
    $192 = HEAP32[$10>>2]|0;
    $193 = ($192|0)<(0);
    if ($193) {
     $i12$047 = 0;
     while(1) {
      $194 = (($input2) + ($i12$047<<2)|0);
      $195 = HEAP32[$194>>2]|0;
      $196 = $195 >>> 24;
      $197 = ($195|0)>(-1);
      $198 = (($165) + ($196<<2)|0);
      $199 = HEAP32[$198>>2]|0;
      if ($197) {
       $200 = (($199) + 4|0);
       HEAP32[$198>>2] = $200;
       HEAP32[$199>>2] = $i12$047;
      } else {
       $201 = (($199) + -4|0);
       HEAP32[$198>>2] = $201;
       HEAP32[$201>>2] = $i12$047;
      }
      $202 = (($i12$047) + 1)|0;
      $exitcond84 = ($202|0)==($nb|0);
      if ($exitcond84) {
       break;
      } else {
       $i12$047 = $202;
      }
     }
     $$pre = HEAP32[$10>>2]|0;
     $203 = $$pre & 2147483647;
     HEAP32[$10>>2] = $203;
    } else {
     $204 = HEAP32[$114>>2]|0;
     $i13$043 = 0;
     while(1) {
      $205 = (($204) + ($i13$043<<2)|0);
      $206 = HEAP32[$205>>2]|0;
      $207 = (($input2) + ($206<<2)|0);
      $208 = HEAP32[$207>>2]|0;
      $209 = $208 >>> 24;
      $210 = ($208|0)>(-1);
      $211 = (($165) + ($209<<2)|0);
      $212 = HEAP32[$211>>2]|0;
      if ($210) {
       $213 = (($212) + 4|0);
       HEAP32[$211>>2] = $213;
       HEAP32[$212>>2] = $206;
      } else {
       $214 = (($212) + -4|0);
       HEAP32[$211>>2] = $214;
       HEAP32[$214>>2] = $206;
      }
      $215 = (($i13$043) + 1)|0;
      $exitcond83 = ($215|0)==($nb|0);
      if ($exitcond83) {
       break;
      } else {
       $i13$043 = $215;
      }
     }
    }
    $216 = HEAP32[$114>>2]|0;
    $217 = HEAP32[$113>>2]|0;
    HEAP32[$114>>2] = $217;
    HEAP32[$113>>2] = $216;
   } else {
    if ($130) {
     $131 = HEAP32[$112>>2]|0;
     $132 = HEAP32[$113>>2]|0;
     HEAP32[$131>>2] = $132;
     $137 = $132;$i5$024 = 1;
     while(1) {
      $133 = (($i5$024) + -1)|0;
      $134 = (($$0$i) + ($133<<2)|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = (($137) + ($135<<2)|0);
      $138 = (($131) + ($i5$024<<2)|0);
      HEAP32[$138>>2] = $136;
      $139 = (($i5$024) + 1)|0;
      $exitcond76 = ($139|0)==(256);
      if ($exitcond76) {
       break;
      } else {
       $137 = $136;$i5$024 = $139;
      }
     }
     $140 = HEAP32[$10>>2]|0;
     $141 = ($140|0)<(0);
     if ($141) {
      $i6$028 = 0;
      while(1) {
       $142 = $i6$028 << 2;
       $$sum1 = (($142) + ($j$052))|0;
       $143 = (($input2) + ($$sum1)|0);
       $144 = HEAP8[$143>>0]|0;
       $145 = $144&255;
       $146 = (($131) + ($145<<2)|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = (($147) + 4|0);
       HEAP32[$146>>2] = $148;
       HEAP32[$147>>2] = $i6$028;
       $149 = (($i6$028) + 1)|0;
       $exitcond77 = ($149|0)==($nb|0);
       if ($exitcond77) {
        break;
       } else {
        $i6$028 = $149;
       }
      }
      $$pre91 = HEAP32[$10>>2]|0;
      $150 = $$pre91 & 2147483647;
      HEAP32[$10>>2] = $150;
     } else {
      $151 = HEAP32[$114>>2]|0;
      $152 = (($151) + ($nb<<2)|0);
      $Indices7$026 = $151;
      while(1) {
       $153 = (($Indices7$026) + 4|0);
       $154 = HEAP32[$Indices7$026>>2]|0;
       $155 = $154 << 2;
       $$sum = (($155) + ($j$052))|0;
       $156 = (($input2) + ($$sum)|0);
       $157 = HEAP8[$156>>0]|0;
       $158 = $157&255;
       $159 = (($131) + ($158<<2)|0);
       $160 = HEAP32[$159>>2]|0;
       $161 = (($160) + 4|0);
       HEAP32[$159>>2] = $161;
       HEAP32[$160>>2] = $154;
       $162 = ($153|0)==($152|0);
       if ($162) {
        break;
       } else {
        $Indices7$026 = $153;
       }
      }
     }
     $163 = HEAP32[$114>>2]|0;
     $164 = HEAP32[$113>>2]|0;
     HEAP32[$114>>2] = $164;
     HEAP32[$113>>2] = $163;
    }
   }
  } while(0);
  $235 = (($j$052) + 1)|0;
  $exitcond85 = ($235|0)==(4);
  if ($exitcond85) {
   break;
  }
  $$pre97 = HEAP32[$6>>2]|0;
  $125 = $$pre97;$j$052 = $235;
 }
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Gu9RadixSort10SetBuffersEPjS2_S2_PS2_($this,$ranks0,$ranks1,$histogram1024,$links256) {
 $this = $this|0;
 $ranks0 = $ranks0|0;
 $ranks1 = $ranks1|0;
 $histogram1024 = $histogram1024|0;
 $links256 = $links256|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ranks0|0)==(0|0);
 $1 = ($ranks1|0)==(0|0);
 $or$cond = $0 | $1;
 $2 = ($histogram1024|0)==(0|0);
 $or$cond1 = $or$cond | $2;
 $3 = ($links256|0)==(0|0);
 $or$cond2 = $or$cond1 | $3;
 if ($or$cond2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = $ranks0;
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = $ranks1;
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = $histogram1024;
 $7 = (($this) + 20|0);
 HEAP32[$7>>2] = $links256;
 $8 = (($this) + 32|0);
 HEAP8[$8>>0] = 0;
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 | -2147483648;
 HEAP32[$9>>2] = $11;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu17RadixSortBufferedC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx2Gu9RadixSortC2Ev($this);
 HEAP32[$this>>2] = ((548448 + 8|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Gu17RadixSortBufferedD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 HEAP32[$this>>2] = ((548448 + 8|0));
 $2 = (($this) + 32|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
 HEAP32[$5>>2] = 0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$8);
 HEAP32[$7>>2] = 0;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu17RadixSortBufferedD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 HEAP32[$this>>2] = ((548448 + 8|0));
 $2 = (($this) + 32|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
 HEAP32[$5>>2] = 0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$8);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu17RadixSortBuffered4SortEPKjjNS0_9RadixHintE($this,$input,$nb,$hint) {
 $this = $this|0;
 $input = $input|0;
 $nb = $nb|0;
 $hint = $hint|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $histogram = 0, $links = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5136|0;
 $0 = sp + 5123|0;
 $1 = sp + 5122|0;
 $2 = sp + 5121|0;
 $3 = sp + 5120|0;
 $histogram = sp;
 $links = sp + 4096|0;
 $4 = ($input|0)==(0|0);
 $5 = ($nb|0)==(0);
 $or$cond = $4 | $5;
 $6 = ($nb|0)<(0);
 $or$cond1 = $or$cond | $6;
 if ($or$cond1) {
  STACKTOP = sp;return ($this|0);
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9|0)==($nb|0);
 if (!($10)) {
  $11 = ($9>>>0)<($nb>>>0);
  if ($11) {
   $12 = (($this) + 32|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if (!($14)) {
    $15 = (($this) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$16);
    HEAP32[$15>>2] = 0;
    $17 = (($this) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$18);
    HEAP32[$17>>2] = 0;
    $19 = $nb << 2;
    $20 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$19,548464,70)|0);
    HEAP32[$17>>2] = $20;
    $21 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$19,548464,71)|0);
    HEAP32[$15>>2] = $21;
   }
  }
  $22 = $nb | -2147483648;
  HEAP32[$7>>2] = $22;
 }
 $23 = (($this) + 16|0);
 HEAP32[$23>>2] = $histogram;
 $24 = (($this) + 20|0);
 HEAP32[$24>>2] = $links;
 (__ZN5physx2Gu9RadixSort4SortEPKjjNS0_9RadixHintE($this,$input,$nb,$hint)|0);
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx2Gu17RadixSortBuffered4SortEPKfj($this,$input2,$nb) {
 $this = $this|0;
 $input2 = $input2|0;
 $nb = $nb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $histogram = 0, $links = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5136|0;
 $0 = sp + 5123|0;
 $1 = sp + 5122|0;
 $2 = sp + 5121|0;
 $3 = sp + 5120|0;
 $histogram = sp;
 $links = sp + 4096|0;
 $4 = ($input2|0)==(0|0);
 $5 = ($nb|0)==(0);
 $or$cond = $4 | $5;
 $6 = ($nb|0)<(0);
 $or$cond1 = $or$cond | $6;
 if ($or$cond1) {
  STACKTOP = sp;return ($this|0);
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9|0)==($nb|0);
 if (!($10)) {
  $11 = ($9>>>0)<($nb>>>0);
  if ($11) {
   $12 = (($this) + 32|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if (!($14)) {
    $15 = (($this) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$16);
    HEAP32[$15>>2] = 0;
    $17 = (($this) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$18);
    HEAP32[$17>>2] = 0;
    $19 = $nb << 2;
    $20 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$19,548464,70)|0);
    HEAP32[$17>>2] = $20;
    $21 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($3,$19,548464,71)|0);
    HEAP32[$15>>2] = $21;
   }
  }
  $22 = $nb | -2147483648;
  HEAP32[$7>>2] = $22;
 }
 $23 = (($this) + 16|0);
 HEAP32[$23>>2] = $histogram;
 $24 = (($this) + 20|0);
 HEAP32[$24>>2] = $links;
 (__ZN5physx2Gu9RadixSort4SortEPKfj($this,$input2,$nb)|0);
 STACKTOP = sp;return ($this|0);
}
function __ZN5physx10writeChunkEaaaaRNS_14PxOutputStreamE($a,$b,$c,$d,$stream) {
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $d = $d|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 HEAP8[$0>>0] = $a;
 HEAP8[$1>>0] = $b;
 HEAP8[$2>>0] = $c;
 HEAP8[$3>>0] = $d;
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$0,1)|0);
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$1,1)|0);
 $8 = HEAP32[$stream>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$2,1)|0);
 $10 = HEAP32[$stream>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$11 & 2047]($stream,$3,1)|0);
 STACKTOP = sp;return;
}
function __ZN5physx9readChunkERaS0_S0_S0_RNS_13PxInputStreamE($a,$b,$c,$d,$stream) {
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $d = $d|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$a,1)|0);
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$b,1)|0);
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$c,1)|0);
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$d,1)|0);
 STACKTOP = sp;return;
}
function __ZN5physx8readWordEbRNS_13PxInputStreamE($mismatch,$stream) {
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $d = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $d = sp;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$d,2)|0);
 if (!($mismatch)) {
  $7 = HEAP16[$d>>1]|0;
  STACKTOP = sp;return ($7|0);
 }
 $2 = HEAP16[$d>>1]|0;
 $3 = $2&255;
 $4 = (($d) + 1|0);
 $5 = ($2&65535) >>> 8;
 $6 = $5&255;
 HEAP8[$d>>0] = $6;
 HEAP8[$4>>0] = $3;
 $7 = HEAP16[$d>>1]|0;
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx9readDwordEbRNS_13PxInputStreamE($mismatch,$stream) {
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $d = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $d = sp;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$d,4)|0);
 if (!($mismatch)) {
  $14 = HEAP32[$d>>2]|0;
  STACKTOP = sp;return ($14|0);
 }
 $2 = HEAP32[$d>>2]|0;
 $3 = $2&65535;
 $4 = $2&255;
 $5 = (($d) + 3|0);
 $6 = $2 >>> 24;
 $7 = $6&255;
 HEAP8[$d>>0] = $7;
 HEAP8[$5>>0] = $4;
 $8 = (($d) + 1|0);
 $9 = ($3&65535) >>> 8;
 $10 = $9&255;
 $11 = (($d) + 2|0);
 $12 = $2 >>> 16;
 $13 = $12&255;
 HEAP8[$8>>0] = $13;
 HEAP8[$11>>0] = $10;
 $14 = HEAP32[$d>>2]|0;
 STACKTOP = sp;return ($14|0);
}
function __ZN5physx9readFloatEbRNS_13PxInputStreamE($mismatch,$stream) {
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $d = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $d = sp;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$d,4)|0);
 if (!($mismatch)) {
  $14 = Math_fround(HEAPF32[$d>>2]);
  STACKTOP = sp;return (Math_fround($14));
 }
 $2 = HEAP32[$d>>2]|0;
 $3 = $2&65535;
 $4 = $2&255;
 $5 = (($d) + 3|0);
 $6 = $2 >>> 24;
 $7 = $6&255;
 HEAP8[$d>>0] = $7;
 HEAP8[$5>>0] = $4;
 $8 = (($d) + 1|0);
 $9 = ($3&65535) >>> 8;
 $10 = $9&255;
 $11 = (($d) + 2|0);
 $12 = $2 >>> 16;
 $13 = $12&255;
 HEAP8[$8>>0] = $13;
 HEAP8[$11>>0] = $10;
 $14 = Math_fround(HEAPF32[$d>>2]);
 STACKTOP = sp;return (Math_fround($14));
}
function __ZN5physx9writeWordEtbRNS_14PxOutputStreamE($value,$mismatch,$stream) {
 $value = $value|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP16[$0>>1] = $value;
 if ($mismatch) {
  $1 = ($value&65535) >>> 8;
  $2 = $1&255;
  $3 = $value&255;
  $4 = (($0) + 1|0);
  HEAP8[$0>>0] = $2;
  HEAP8[$4>>0] = $3;
  $$pre$phiZ2D = $0;
 } else {
  $$pre$phiZ2D = $0;
 }
 $5 = HEAP32[$stream>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_iiii[$6 & 2047]($stream,$$pre$phiZ2D,2)|0);
 STACKTOP = sp;return;
}
function __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($value,$mismatch,$stream) {
 $value = $value|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $value;
 if ($mismatch) {
  $1 = $value >>> 16;
  $2 = $value >>> 8;
  $3 = $value >>> 24;
  $4 = $1&255;
  $5 = $2&255;
  $6 = $3&255;
  $7 = $value&255;
  $8 = (($0) + 3|0);
  HEAP8[$0>>0] = $6;
  HEAP8[$8>>0] = $7;
  $9 = (($0) + 1|0);
  $10 = (($0) + 2|0);
  HEAP8[$9>>0] = $4;
  HEAP8[$10>>0] = $5;
  $$pre$phiZ2D = $0;
 } else {
  $$pre$phiZ2D = $0;
 }
 $11 = HEAP32[$stream>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$$pre$phiZ2D,4)|0);
 STACKTOP = sp;return;
}
function __ZN5physx10writeFloatEfbRNS_14PxOutputStreamE($value,$mismatch,$stream) {
 $value = Math_fround($value);
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAPF32[$0>>2] = $value;
 $1 = (HEAPF32[tempDoublePtr>>2]=$value,HEAP32[tempDoublePtr>>2]|0);
 if ($mismatch) {
  $2 = $1 >>> 16;
  $3 = $1 >>> 8;
  $4 = $1 >>> 24;
  $5 = $2&255;
  $6 = $3&255;
  $7 = $4&255;
  $8 = $1&255;
  $9 = (($0) + 3|0);
  HEAP8[$0>>0] = $7;
  HEAP8[$9>>0] = $8;
  $10 = (($0) + 1|0);
  $11 = (($0) + 2|0);
  HEAP8[$10>>0] = $5;
  HEAP8[$11>>0] = $6;
  $$pre$phiZ2D = $0;
 } else {
  $$pre$phiZ2D = $0;
 }
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$$pre$phiZ2D,4)|0);
 STACKTOP = sp;return;
}
function __ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($dest,$nbFloats,$mismatch,$stream) {
 $dest = $dest|0;
 $nbFloats = $nbFloats|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $mismatch$not = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = $nbFloats << 2;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$dest,$2)|0);
 $mismatch$not = $mismatch ^ 1;
 $3 = ($nbFloats|0)==(0);
 $or$cond = $3 | $mismatch$not;
 if ($or$cond) {
  STACKTOP = sp;return 1;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $4 = (($dest) + ($i$01<<2)|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = (($4) + 3|0);
  $7 = HEAP8[$6>>0]|0;
  HEAP8[$4>>0] = $7;
  HEAP8[$6>>0] = $5;
  $8 = (($4) + 1|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = (($4) + 2|0);
  $11 = HEAP8[$10>>0]|0;
  HEAP8[$8>>0] = $11;
  HEAP8[$10>>0] = $9;
  $12 = (($i$01) + 1)|0;
  $exitcond = ($12|0)==($nbFloats|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $12;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN5physx15writeWordBufferEPKtjbRNS_14PxOutputStreamE($src,$nb,$mismatch,$stream) {
 $src = $src|0;
 $nb = $nb|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$02 = 0, $$02$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $w = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $w = sp;
 $0 = (($nb) + -1)|0;
 $1 = ($nb|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($w) + 1|0);
 if ($mismatch) {
  $$02$us = $src;$11 = $0;
  while(1) {
   $3 = (($$02$us) + 2|0);
   $4 = HEAP16[$$02$us>>1]|0;
   HEAP16[$w>>1] = $4;
   $5 = ($4&65535) >>> 8;
   $6 = $5&255;
   $7 = $4&255;
   HEAP8[$w>>0] = $6;
   HEAP8[$2>>0] = $7;
   $8 = HEAP32[$stream>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   (FUNCTION_TABLE_iiii[$9 & 2047]($stream,$w,2)|0);
   $10 = (($11) + -1)|0;
   $12 = ($11|0)==(0);
   if ($12) {
    break;
   } else {
    $$02$us = $3;$11 = $10;
   }
  }
  STACKTOP = sp;return;
 } else {
  $$02 = $src;$18 = $0;
  while(1) {
   $13 = (($$02) + 2|0);
   $14 = HEAP16[$$02>>1]|0;
   HEAP16[$w>>1] = $14;
   $15 = HEAP32[$stream>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   (FUNCTION_TABLE_iiii[$16 & 2047]($stream,$w,2)|0);
   $17 = (($18) + -1)|0;
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   } else {
    $$02 = $13;$18 = $17;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($src,$nb,$mismatch,$stream) {
 $src = $src|0;
 $nb = $nb|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$02 = 0, $$02$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $f = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $f = sp;
 $0 = (($nb) + -1)|0;
 $1 = ($nb|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($f) + 3|0);
 $3 = (($f) + 1|0);
 $4 = (($f) + 2|0);
 if ($mismatch) {
  $$02$us = $src;$18 = $0;
  while(1) {
   $5 = (($$02$us) + 4|0);
   $6 = Math_fround(HEAPF32[$$02$us>>2]);
   HEAPF32[$f>>2] = $6;
   $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
   $8 = $7 >>> 16;
   $9 = $7 >>> 8;
   $10 = $7 >>> 24;
   $11 = $8&255;
   $12 = $9&255;
   $13 = $10&255;
   $14 = $7&255;
   HEAP8[$f>>0] = $13;
   HEAP8[$2>>0] = $14;
   HEAP8[$3>>0] = $11;
   HEAP8[$4>>0] = $12;
   $15 = HEAP32[$stream>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   (FUNCTION_TABLE_iiii[$16 & 2047]($stream,$f,4)|0);
   $17 = (($18) + -1)|0;
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   } else {
    $$02$us = $5;$18 = $17;
   }
  }
  STACKTOP = sp;return;
 } else {
  $$02 = $src;$25 = $0;
  while(1) {
   $20 = (($$02) + 4|0);
   $21 = Math_fround(HEAPF32[$$02>>2]);
   HEAPF32[$f>>2] = $21;
   $22 = HEAP32[$stream>>2]|0;
   $23 = HEAP32[$22>>2]|0;
   (FUNCTION_TABLE_iiii[$23 & 2047]($stream,$f,4)|0);
   $24 = (($25) + -1)|0;
   $26 = ($25|0)==(0);
   if ($26) {
    break;
   } else {
    $$02 = $20;$25 = $24;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN5physx11writeHeaderEaaaajbRNS_14PxOutputStreamE($a,$b,$c,$d,$version,$mismatch,$stream) {
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $d = $d|0;
 $version = $version|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 6|0;
 $2 = sp + 4|0;
 $3 = sp + 5|0;
 $4 = $mismatch&1;
 $$ = $4 ^ 1;
 HEAP8[$0>>0] = 78;
 HEAP8[$1>>0] = 88;
 HEAP8[$2>>0] = 83;
 HEAP8[$3>>0] = $$;
 $5 = HEAP32[$stream>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_iiii[$6 & 2047]($stream,$0,1)|0);
 $7 = HEAP32[$stream>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 (FUNCTION_TABLE_iiii[$8 & 2047]($stream,$1,1)|0);
 $9 = HEAP32[$stream>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_iiii[$10 & 2047]($stream,$2,1)|0);
 $11 = HEAP32[$stream>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$3,1)|0);
 HEAP8[$0>>0] = $a;
 HEAP8[$1>>0] = $b;
 HEAP8[$2>>0] = $c;
 HEAP8[$3>>0] = $d;
 $13 = HEAP32[$stream>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 (FUNCTION_TABLE_iiii[$14 & 2047]($stream,$0,1)|0);
 $15 = HEAP32[$stream>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 (FUNCTION_TABLE_iiii[$16 & 2047]($stream,$1,1)|0);
 $17 = HEAP32[$stream>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_iiii[$18 & 2047]($stream,$2,1)|0);
 $19 = HEAP32[$stream>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_iiii[$20 & 2047]($stream,$3,1)|0);
 HEAP32[$0>>2] = $version;
 if (!($mismatch)) {
  $31 = HEAP32[$stream>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  (FUNCTION_TABLE_iiii[$32 & 2047]($stream,$0,4)|0);
  STACKTOP = sp;return 1;
 }
 $21 = $version >>> 16;
 $22 = $version >>> 8;
 $23 = $version >>> 24;
 $24 = $21&255;
 $25 = $22&255;
 $26 = $23&255;
 $27 = $version&255;
 $28 = (($0) + 3|0);
 HEAP8[$0>>0] = $26;
 HEAP8[$28>>0] = $27;
 $29 = (($0) + 1|0);
 $30 = (($0) + 2|0);
 HEAP8[$29>>0] = $24;
 HEAP8[$30>>0] = $25;
 $31 = HEAP32[$stream>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 (FUNCTION_TABLE_iiii[$32 & 2047]($stream,$0,4)|0);
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu11WriteHeaderEhhhhjbRNS_14PxOutputStreamE($a,$b,$c,$d,$version,$mismatch,$stream) {
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $d = $d|0;
 $version = $version|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 6|0;
 $2 = sp + 4|0;
 $3 = sp + 5|0;
 $4 = $mismatch&1;
 $$ = $4 ^ 1;
 HEAP8[$0>>0] = 73;
 HEAP8[$1>>0] = 67;
 HEAP8[$2>>0] = 69;
 HEAP8[$3>>0] = $$;
 $5 = HEAP32[$stream>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_iiii[$6 & 2047]($stream,$0,1)|0);
 $7 = HEAP32[$stream>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 (FUNCTION_TABLE_iiii[$8 & 2047]($stream,$1,1)|0);
 $9 = HEAP32[$stream>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 (FUNCTION_TABLE_iiii[$10 & 2047]($stream,$2,1)|0);
 $11 = HEAP32[$stream>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$3,1)|0);
 HEAP8[$0>>0] = $a;
 HEAP8[$1>>0] = $b;
 HEAP8[$2>>0] = $c;
 HEAP8[$3>>0] = $d;
 $13 = HEAP32[$stream>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 (FUNCTION_TABLE_iiii[$14 & 2047]($stream,$0,1)|0);
 $15 = HEAP32[$stream>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 (FUNCTION_TABLE_iiii[$16 & 2047]($stream,$1,1)|0);
 $17 = HEAP32[$stream>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_iiii[$18 & 2047]($stream,$2,1)|0);
 $19 = HEAP32[$stream>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_iiii[$20 & 2047]($stream,$3,1)|0);
 HEAP32[$0>>2] = $version;
 if (!($mismatch)) {
  $31 = HEAP32[$stream>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  (FUNCTION_TABLE_iiii[$32 & 2047]($stream,$0,4)|0);
  STACKTOP = sp;return 1;
 }
 $21 = $version >>> 16;
 $22 = $version >>> 8;
 $23 = $version >>> 24;
 $24 = $21&255;
 $25 = $22&255;
 $26 = $23&255;
 $27 = $version&255;
 $28 = (($0) + 3|0);
 HEAP8[$0>>0] = $26;
 HEAP8[$28>>0] = $27;
 $29 = (($0) + 1|0);
 $30 = (($0) + 2|0);
 HEAP8[$29>>0] = $24;
 HEAP8[$30>>0] = $25;
 $31 = HEAP32[$stream>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 (FUNCTION_TABLE_iiii[$32 & 2047]($stream,$0,4)|0);
 STACKTOP = sp;return 1;
}
function __ZN5physx10readHeaderEaaaaRjRbRNS_13PxInputStreamE($a_,$b_,$c_,$d_,$version,$mismatch,$stream) {
 $a_ = $a_|0;
 $b_ = $b_|0;
 $c_ = $c_|0;
 $d_ = $d_|0;
 $version = $version|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a = 0, $b = 0, $c = 0, $d = 0, $d$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $d$i = sp;
 $a = sp + 7|0;
 $b = sp + 4|0;
 $c = sp + 5|0;
 $d = sp + 6|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$a,1)|0);
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$b,1)|0);
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$c,1)|0);
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$d,1)|0);
 $8 = HEAP8[$a>>0]|0;
 $9 = ($8<<24>>24)==(78);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP8[$b>>0]|0;
 $11 = ($10<<24>>24)==(88);
 if (!($11)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP8[$c>>0]|0;
 $13 = ($12<<24>>24)==(83);
 if (!($13)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = HEAP8[$d>>0]|0;
 $15 = $14 & 1;
 $16 = $15 ^ 1;
 HEAP8[$mismatch>>0] = $16;
 $17 = HEAP32[$stream>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_iiii[$18 & 2047]($stream,$a,1)|0);
 $19 = HEAP32[$stream>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_iiii[$20 & 2047]($stream,$b,1)|0);
 $21 = HEAP32[$stream>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 (FUNCTION_TABLE_iiii[$22 & 2047]($stream,$c,1)|0);
 $23 = HEAP32[$stream>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 (FUNCTION_TABLE_iiii[$24 & 2047]($stream,$d,1)|0);
 $25 = HEAP8[$a>>0]|0;
 $26 = ($25<<24>>24)==($a_<<24>>24);
 if (!($26)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = HEAP8[$b>>0]|0;
 $28 = ($27<<24>>24)==($b_<<24>>24);
 if (!($28)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = HEAP8[$c>>0]|0;
 $30 = ($29<<24>>24)==($c_<<24>>24);
 if (!($30)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = HEAP8[$d>>0]|0;
 $32 = ($31<<24>>24)==($d_<<24>>24);
 if (!($32)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP8[$mismatch>>0]|0;
 $34 = ($33<<24>>24)==(0);
 $35 = HEAP32[$stream>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 (FUNCTION_TABLE_iiii[$36 & 2047]($stream,$d$i,4)|0);
 if (!($34)) {
  $37 = HEAP32[$d$i>>2]|0;
  $38 = $37&65535;
  $39 = $37&255;
  $40 = (($d$i) + 3|0);
  $41 = $37 >>> 24;
  $42 = $41&255;
  HEAP8[$d$i>>0] = $42;
  HEAP8[$40>>0] = $39;
  $43 = (($d$i) + 1|0);
  $44 = ($38&65535) >>> 8;
  $45 = $44&255;
  $46 = (($d$i) + 2|0);
  $47 = $37 >>> 16;
  $48 = $47&255;
  HEAP8[$43>>0] = $48;
  HEAP8[$46>>0] = $45;
 }
 $49 = HEAP32[$d$i>>2]|0;
 HEAP32[$version>>2] = $49;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu10ReadHeaderEhhhhRjRbRNS_13PxInputStreamE($a_,$b_,$c_,$d_,$version,$mismatch,$stream) {
 $a_ = $a_|0;
 $b_ = $b_|0;
 $c_ = $c_|0;
 $d_ = $d_|0;
 $version = $version|0;
 $mismatch = $mismatch|0;
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a = 0;
 var $b = 0, $c = 0, $d = 0, $d$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $d$i = sp;
 $a = sp + 7|0;
 $b = sp + 4|0;
 $c = sp + 5|0;
 $d = sp + 6|0;
 $0 = HEAP32[$stream>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (FUNCTION_TABLE_iiii[$1 & 2047]($stream,$a,1)|0);
 $2 = HEAP32[$stream>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$b,1)|0);
 $4 = HEAP32[$stream>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($stream,$c,1)|0);
 $6 = HEAP32[$stream>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$d,1)|0);
 $8 = HEAP8[$a>>0]|0;
 $9 = ($8<<24>>24)==(73);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP8[$b>>0]|0;
 $11 = ($10<<24>>24)==(67);
 if (!($11)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP8[$c>>0]|0;
 $13 = ($12<<24>>24)==(69);
 if (!($13)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = HEAP8[$d>>0]|0;
 $15 = $14 & 1;
 $16 = $15 ^ 1;
 HEAP8[$mismatch>>0] = $16;
 $17 = HEAP32[$stream>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_iiii[$18 & 2047]($stream,$a,1)|0);
 $19 = HEAP32[$stream>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 (FUNCTION_TABLE_iiii[$20 & 2047]($stream,$b,1)|0);
 $21 = HEAP32[$stream>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 (FUNCTION_TABLE_iiii[$22 & 2047]($stream,$c,1)|0);
 $23 = HEAP32[$stream>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 (FUNCTION_TABLE_iiii[$24 & 2047]($stream,$d,1)|0);
 $25 = HEAP8[$a>>0]|0;
 $26 = $25 << 24 >> 24;
 $27 = $a_&255;
 $28 = ($26|0)==($27|0);
 if (!($28)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = HEAP8[$b>>0]|0;
 $30 = $29 << 24 >> 24;
 $31 = $b_&255;
 $32 = ($30|0)==($31|0);
 if (!($32)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP8[$c>>0]|0;
 $34 = $33 << 24 >> 24;
 $35 = $c_&255;
 $36 = ($34|0)==($35|0);
 if (!($36)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = HEAP8[$d>>0]|0;
 $38 = $37 << 24 >> 24;
 $39 = $d_&255;
 $40 = ($38|0)==($39|0);
 if (!($40)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = HEAP8[$mismatch>>0]|0;
 $42 = ($41<<24>>24)==(0);
 $43 = HEAP32[$stream>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 (FUNCTION_TABLE_iiii[$44 & 2047]($stream,$d$i,4)|0);
 if (!($42)) {
  $45 = HEAP32[$d$i>>2]|0;
  $46 = $45&65535;
  $47 = $45&255;
  $48 = (($d$i) + 3|0);
  $49 = $45 >>> 24;
  $50 = $49&255;
  HEAP8[$d$i>>0] = $50;
  HEAP8[$48>>0] = $47;
  $51 = (($d$i) + 1|0);
  $52 = ($46&65535) >>> 8;
  $53 = $52&255;
  $54 = (($d$i) + 2|0);
  $55 = $45 >>> 16;
  $56 = $55&255;
  HEAP8[$51>>0] = $56;
  HEAP8[$54>>0] = $53;
 }
 $57 = HEAP32[$d$i>>2]|0;
 HEAP32[$version>>2] = $57;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx15computeMaxIndexEPKjj($indices,$nbIndices) {
 $indices = $indices|0;
 $nbIndices = $nbIndices|0;
 var $$012 = 0, $$04 = 0, $$maxIndex$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $maxIndex$0$lcssa = 0, $maxIndex$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nbIndices|0)==(0);
 if ($0) {
  $maxIndex$0$lcssa = 0;
  STACKTOP = sp;return ($maxIndex$0$lcssa|0);
 } else {
  $$012 = $nbIndices;$$04 = $indices;$maxIndex$03 = 0;
 }
 while(1) {
  $1 = (($$012) + -1)|0;
  $2 = (($$04) + 4|0);
  $3 = HEAP32[$$04>>2]|0;
  $4 = ($3>>>0)>($maxIndex$03>>>0);
  $$maxIndex$0 = $4 ? $3 : $maxIndex$03;
  $5 = ($1|0)==(0);
  if ($5) {
   $maxIndex$0$lcssa = $$maxIndex$0;
   break;
  } else {
   $$012 = $1;$$04 = $2;$maxIndex$03 = $$maxIndex$0;
  }
 }
 STACKTOP = sp;return ($maxIndex$0$lcssa|0);
}
function __ZN5physx15computeMaxIndexEPKtj($indices,$nbIndices) {
 $indices = $indices|0;
 $nbIndices = $nbIndices|0;
 var $$012 = 0, $$04 = 0, $$maxIndex$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $maxIndex$0$lcssa = 0, $maxIndex$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nbIndices|0)==(0);
 if ($0) {
  $maxIndex$0$lcssa = 0;
  STACKTOP = sp;return ($maxIndex$0$lcssa|0);
 } else {
  $$012 = $nbIndices;$$04 = $indices;$maxIndex$03 = 0;
 }
 while(1) {
  $1 = (($$012) + -1)|0;
  $2 = (($$04) + 2|0);
  $3 = HEAP16[$$04>>1]|0;
  $4 = ($3&65535)>($maxIndex$03&65535);
  $$maxIndex$0 = $4 ? $3 : $maxIndex$03;
  $5 = ($1|0)==(0);
  if ($5) {
   $maxIndex$0$lcssa = $$maxIndex$0;
   break;
  } else {
   $$012 = $1;$$04 = $2;$maxIndex$03 = $$maxIndex$0;
  }
 }
 STACKTOP = sp;return ($maxIndex$0$lcssa|0);
}
function __ZN5physx12storeIndicesEjjPKjRNS_14PxOutputStreamEb($maxIndex,$nbIndices,$indices,$stream,$platformMismatch) {
 $maxIndex = $maxIndex|0;
 $nbIndices = $nbIndices|0;
 $indices = $indices|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 var $$02$i$i = 0, $$02$us$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $exitcond = 0, $exitcond8 = 0, $exitcond9 = 0;
 var $i$01 = 0, $i1$04 = 0, $i1$04$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $data = sp + 4|0;
 $1 = ($maxIndex>>>0)<(256);
 if ($1) {
  $2 = ($nbIndices|0)==(0);
  if ($2) {
   STACKTOP = sp;return;
  }
  $i$01 = 0;
  while(1) {
   $3 = (($indices) + ($i$01<<2)|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = $4&255;
   HEAP8[$data>>0] = $5;
   $6 = HEAP32[$stream>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   (FUNCTION_TABLE_iiii[$7 & 2047]($stream,$data,1)|0);
   $8 = (($i$01) + 1)|0;
   $exitcond = ($8|0)==($nbIndices|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $8;
   }
  }
  STACKTOP = sp;return;
 }
 $9 = ($maxIndex>>>0)<(65536);
 if ($9) {
  $10 = ($nbIndices|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  }
  $11 = (($0) + 1|0);
  if ($platformMismatch) {
   $i1$04$us = 0;
   while(1) {
    $12 = (($indices) + ($i1$04$us<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = $13&65535;
    HEAP16[$0>>1] = $14;
    $15 = ($14&65535) >>> 8;
    $16 = $15&255;
    $17 = $13&255;
    HEAP8[$0>>0] = $16;
    HEAP8[$11>>0] = $17;
    $18 = HEAP32[$stream>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    (FUNCTION_TABLE_iiii[$19 & 2047]($stream,$0,2)|0);
    $20 = (($i1$04$us) + 1)|0;
    $exitcond9 = ($20|0)==($nbIndices|0);
    if ($exitcond9) {
     break;
    } else {
     $i1$04$us = $20;
    }
   }
   STACKTOP = sp;return;
  } else {
   $i1$04 = 0;
   while(1) {
    $21 = (($indices) + ($i1$04<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = $22&65535;
    HEAP16[$0>>1] = $23;
    $24 = HEAP32[$stream>>2]|0;
    $25 = HEAP32[$24>>2]|0;
    (FUNCTION_TABLE_iiii[$25 & 2047]($stream,$0,2)|0);
    $26 = (($i1$04) + 1)|0;
    $exitcond8 = ($26|0)==($nbIndices|0);
    if ($exitcond8) {
     break;
    } else {
     $i1$04 = $26;
    }
   }
   STACKTOP = sp;return;
  }
 } else {
  $27 = (($nbIndices) + -1)|0;
  $28 = ($nbIndices|0)==(0);
  if ($28) {
   STACKTOP = sp;return;
  }
  $29 = (($0) + 3|0);
  $30 = (($0) + 1|0);
  $31 = (($0) + 2|0);
  if ($platformMismatch) {
   $$02$us$i$i = $indices;$45 = $27;
   while(1) {
    $32 = (($$02$us$i$i) + 4|0);
    $33 = Math_fround(HEAPF32[$$02$us$i$i>>2]);
    HEAPF32[$0>>2] = $33;
    $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
    $35 = $34 >>> 16;
    $36 = $34 >>> 8;
    $37 = $34 >>> 24;
    $38 = $35&255;
    $39 = $36&255;
    $40 = $37&255;
    $41 = $34&255;
    HEAP8[$0>>0] = $40;
    HEAP8[$29>>0] = $41;
    HEAP8[$30>>0] = $38;
    HEAP8[$31>>0] = $39;
    $42 = HEAP32[$stream>>2]|0;
    $43 = HEAP32[$42>>2]|0;
    (FUNCTION_TABLE_iiii[$43 & 2047]($stream,$0,4)|0);
    $44 = (($45) + -1)|0;
    $46 = ($45|0)==(0);
    if ($46) {
     break;
    } else {
     $$02$us$i$i = $32;$45 = $44;
    }
   }
   STACKTOP = sp;return;
  } else {
   $$02$i$i = $indices;$52 = $27;
   while(1) {
    $47 = (($$02$i$i) + 4|0);
    $48 = Math_fround(HEAPF32[$$02$i$i>>2]);
    HEAPF32[$0>>2] = $48;
    $49 = HEAP32[$stream>>2]|0;
    $50 = HEAP32[$49>>2]|0;
    (FUNCTION_TABLE_iiii[$50 & 2047]($stream,$0,4)|0);
    $51 = (($52) + -1)|0;
    $53 = ($52|0)==(0);
    if ($53) {
     break;
    } else {
     $$02$i$i = $47;$52 = $51;
    }
   }
   STACKTOP = sp;return;
  }
 }
}
function __ZN5physx11readIndicesEjjPjRNS_13PxInputStreamEb($maxIndex,$nbIndices,$indices,$stream,$platformMismatch) {
 $maxIndex = $maxIndex|0;
 $nbIndices = $nbIndices|0;
 $indices = $indices|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $d$i = 0, $data = 0, $exitcond = 0, $exitcond$i$i = 0, $exitcond7 = 0, $exitcond8 = 0, $i$01 = 0, $i$01$i$i = 0, $i1$04 = 0, $i1$04$us = 0, $mismatch$not$i$i = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $d$i = sp;
 $data = sp + 2|0;
 $0 = ($maxIndex>>>0)<(256);
 if ($0) {
  $1 = ($nbIndices|0)==(0);
  if ($1) {
   STACKTOP = sp;return;
  }
  $i$01 = 0;
  while(1) {
   $2 = HEAP32[$stream>>2]|0;
   $3 = HEAP32[$2>>2]|0;
   (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$data,1)|0);
   $4 = HEAP8[$data>>0]|0;
   $5 = $4&255;
   $6 = (($indices) + ($i$01<<2)|0);
   HEAP32[$6>>2] = $5;
   $7 = (($i$01) + 1)|0;
   $exitcond = ($7|0)==($nbIndices|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $7;
   }
  }
  STACKTOP = sp;return;
 }
 $8 = ($maxIndex>>>0)<(65536);
 if (!($8)) {
  $27 = HEAP32[$stream>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $nbIndices << 2;
  (FUNCTION_TABLE_iiii[$28 & 2047]($stream,$indices,$29)|0);
  $mismatch$not$i$i = $platformMismatch ^ 1;
  $30 = ($nbIndices|0)==(0);
  $or$cond$i$i = $30 | $mismatch$not$i$i;
  if ($or$cond$i$i) {
   STACKTOP = sp;return;
  } else {
   $i$01$i$i = 0;
  }
  while(1) {
   $31 = (($indices) + ($i$01$i$i<<2)|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = (($31) + 3|0);
   $34 = HEAP8[$33>>0]|0;
   HEAP8[$31>>0] = $34;
   HEAP8[$33>>0] = $32;
   $35 = (($31) + 1|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = (($31) + 2|0);
   $38 = HEAP8[$37>>0]|0;
   HEAP8[$35>>0] = $38;
   HEAP8[$37>>0] = $36;
   $39 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($39|0)==($nbIndices|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $39;
   }
  }
  STACKTOP = sp;return;
 }
 $9 = ($nbIndices|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($d$i) + 1|0);
 if ($platformMismatch) {
  $i1$04$us = 0;
  while(1) {
   $11 = HEAP32[$stream>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   (FUNCTION_TABLE_iiii[$12 & 2047]($stream,$d$i,2)|0);
   $13 = HEAP16[$d$i>>1]|0;
   $14 = $13&255;
   $15 = ($13&65535) >>> 8;
   $16 = $15&255;
   HEAP8[$d$i>>0] = $16;
   HEAP8[$10>>0] = $14;
   $17 = HEAP16[$d$i>>1]|0;
   $18 = $17&65535;
   $19 = (($indices) + ($i1$04$us<<2)|0);
   HEAP32[$19>>2] = $18;
   $20 = (($i1$04$us) + 1)|0;
   $exitcond8 = ($20|0)==($nbIndices|0);
   if ($exitcond8) {
    break;
   } else {
    $i1$04$us = $20;
   }
  }
  STACKTOP = sp;return;
 } else {
  $i1$04 = 0;
  while(1) {
   $21 = HEAP32[$stream>>2]|0;
   $22 = HEAP32[$21>>2]|0;
   (FUNCTION_TABLE_iiii[$22 & 2047]($stream,$d$i,2)|0);
   $23 = HEAP16[$d$i>>1]|0;
   $24 = $23&65535;
   $25 = (($indices) + ($i1$04<<2)|0);
   HEAP32[$25>>2] = $24;
   $26 = (($i1$04) + 1)|0;
   $exitcond7 = ($26|0)==($nbIndices|0);
   if ($exitcond7) {
    break;
   } else {
    $i1$04 = $26;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu12StoreIndicesEtjPKtRNS_14PxOutputStreamEb($maxIndex,$nbIndices,$indices,$stream,$platformMismatch) {
 $maxIndex = $maxIndex|0;
 $nbIndices = $nbIndices|0;
 $indices = $indices|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $exitcond = 0;
 var $exitcond6 = 0, $i$01 = 0, $i1$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $data = sp + 2|0;
 $1 = ($maxIndex&65535)<(256);
 $2 = ($nbIndices|0)==(0);
 if ($1) {
  if ($2) {
   STACKTOP = sp;return;
  }
  $i$01 = 0;
  while(1) {
   $4 = (($indices) + ($i$01<<1)|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = $5&255;
   HEAP8[$data>>0] = $6;
   $7 = HEAP32[$stream>>2]|0;
   $8 = HEAP32[$7>>2]|0;
   (FUNCTION_TABLE_iiii[$8 & 2047]($stream,$data,1)|0);
   $9 = (($i$01) + 1)|0;
   $exitcond = ($9|0)==($nbIndices|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $9;
   }
  }
  STACKTOP = sp;return;
 }
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($0) + 1|0);
 $i1$04 = 0;
 while(1) {
  $10 = (($indices) + ($i1$04<<1)|0);
  $11 = HEAP16[$10>>1]|0;
  HEAP16[$0>>1] = $11;
  if ($platformMismatch) {
   $12 = ($11&65535) >>> 8;
   $13 = $12&255;
   $14 = $11&255;
   HEAP8[$0>>0] = $13;
   HEAP8[$3>>0] = $14;
  }
  $15 = HEAP32[$stream>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  (FUNCTION_TABLE_iiii[$16 & 2047]($stream,$0,2)|0);
  $17 = (($i1$04) + 1)|0;
  $exitcond6 = ($17|0)==($nbIndices|0);
  if ($exitcond6) {
   break;
  } else {
   $i1$04 = $17;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11ReadIndicesEtjPtRNS_13PxInputStreamEb($maxIndex,$nbIndices,$indices,$stream,$platformMismatch) {
 $maxIndex = $maxIndex|0;
 $nbIndices = $nbIndices|0;
 $indices = $indices|0;
 $stream = $stream|0;
 $platformMismatch = $platformMismatch|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $exitcond$i = 0, $i$01 = 0, $i$01$i = 0, $mismatch$not$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($maxIndex&65535)<(256);
 if ($0) {
  $1 = STACKTOP; STACKTOP = STACKTOP + ((((1*$nbIndices)|0)+15)&-16)|0;;
  $2 = HEAP32[$stream>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  (FUNCTION_TABLE_iiii[$3 & 2047]($stream,$1,$nbIndices)|0);
  $4 = ($nbIndices|0)==(0);
  if ($4) {
   STACKTOP = sp;return;
  } else {
   $i$01 = 0;
  }
  while(1) {
   $5 = (($1) + ($i$01)|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = $6&255;
   $8 = (($indices) + ($i$01<<1)|0);
   HEAP16[$8>>1] = $7;
   $9 = (($i$01) + 1)|0;
   $exitcond = ($9|0)==($nbIndices|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $9;
   }
  }
  STACKTOP = sp;return;
 }
 $10 = $nbIndices << 1;
 $11 = STACKTOP; STACKTOP = STACKTOP + ((((1*$10)|0)+15)&-16)|0;;
 $12 = HEAP32[$stream>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 (FUNCTION_TABLE_iiii[$13 & 2047]($stream,$11,$10)|0);
 $mismatch$not$i = $platformMismatch ^ 1;
 $14 = ($nbIndices|0)==(0);
 $or$cond$i = $14 | $mismatch$not$i;
 if (!($or$cond$i)) {
  $i$01$i = 0;
  while(1) {
   $15 = (($11) + ($i$01$i<<1)|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = (($15) + 1|0);
   $18 = HEAP8[$17>>0]|0;
   HEAP8[$15>>0] = $18;
   HEAP8[$17>>0] = $16;
   $19 = (($i$01$i) + 1)|0;
   $exitcond$i = ($19|0)==($nbIndices|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $19;
   }
  }
 }
 if ($14) {
  STACKTOP = sp;return;
 }
 $20 = $nbIndices << 1;
 _memcpy(($indices|0),($11|0),($20|0))|0;
 STACKTOP = sp;return;
}
function __Z12calculateMTDRKN5physx2Gu8CapsuleVERKNS_6shdfnd3aos6FloatVEbPK11MTDTrianglejjPNS0_21MeshPersistentContactERjRNS5_5Vec3VESG_SG_SE_RS6_($capsuleV,$inflatedRadiusV,$isDoubleSide,$triangles,$nbTriangles,$startIndex,$manifoldContacts,$numContacts,$normal,$closestA,$closestB,$faceIndex,$mtd) {
 $capsuleV = $capsuleV|0;
 $inflatedRadiusV = $inflatedRadiusV|0;
 $isDoubleSide = $isDoubleSide|0;
 $triangles = $triangles|0;
 $nbTriangles = $nbTriangles|0;
 $startIndex = $startIndex|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $faceIndex = $faceIndex|0;
 $mtd = $mtd|0;
 var $$lcssa$i = Math_fround(0), $$lcssa$i$us = Math_fround(0), $$lcssa$i54 = Math_fround(0), $$lcssa$i54$us = Math_fround(0), $$lcssa$i56$lcssa = Math_fround(0), $$lcssa$i5657 = Math_fround(0), $$lcssa$i5657$us = Math_fround(0), $$sroa$1$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0;
 var $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0);
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0;
 var $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0);
 var $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $deepest$sroa$1$i = 0, $deepestPen$sroa$1 = 0, $exitcond = 0;
 var $exitcond$i = 0, $exitcond$i$us = 0, $exitcond63 = 0, $hadContacts$0$off0$lcssa = 0, $hadContacts$0$off060 = 0, $hadContacts$0$off060$us = 0, $hadContacts$1$off0 = 0, $hadContacts$1$off0$us = 0, $index$0$lcssa$i = 0, $index$0$lcssa$i$us = 0, $index$030$i = 0, $index$030$i$us = 0, $index$1$i = 0, $index$1$i$us = 0, $j$058 = 0, $j$058$us = 0, $k$031$i = 0, $k$031$i$us = 0, $pen$sroa$1$i = 0, $triangleV = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 144|0;
 $$sroa$1$i$i = sp + 196|0;
 $deepest$sroa$1$i = sp + 184|0;
 $pen$sroa$1$i = sp + 160|0;
 $deepestPen$sroa$1 = sp + 172|0;
 $triangleV = sp;
 $1 = Math_fround(HEAPF32[$mtd>>2]);
 $2 = (($mtd) + 4|0);
 ;HEAP32[$deepestPen$sroa$1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$deepestPen$sroa$1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$deepestPen$sroa$1+8>>2]=HEAP32[$2+8>>2]|0;
 $3 = ($nbTriangles|0)==(0);
 if ($3) {
  $$lcssa$i56$lcssa = $1;$hadContacts$0$off0$lcssa = 0;
  HEAPF32[$mtd>>2] = $$lcssa$i56$lcssa;
  ;HEAP32[$2+0>>2]=HEAP32[$deepestPen$sroa$1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$deepestPen$sroa$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$deepestPen$sroa$1+8>>2]|0;
  STACKTOP = sp;return ($hadContacts$0$off0$lcssa|0);
 }
 $4 = (($triangleV) + 64|0);
 $5 = (($triangleV) + 80|0);
 $6 = (($triangleV) + 16|0);
 $7 = (($triangleV) + 20|0);
 $8 = (($triangleV) + 32|0);
 $9 = (($triangleV) + 36|0);
 $10 = (($triangleV) + 48|0);
 $11 = (($triangleV) + 52|0);
 $12 = (($triangleV) + 96|0);
 $13 = (($triangleV) + 100|0);
 $14 = (($triangleV) + 104|0);
 $15 = (($triangleV) + 108|0);
 $16 = (($triangleV) + 112|0);
 $17 = (($triangleV) + 116|0);
 $18 = (($triangleV) + 120|0);
 $19 = (($triangleV) + 124|0);
 $20 = (($triangleV) + 128|0);
 $21 = (($triangleV) + 132|0);
 $22 = (($triangleV) + 136|0);
 $23 = (($triangleV) + 140|0);
 $24 = (($manifoldContacts) + 44|0);
 $25 = (($normal) + 4|0);
 $26 = (($normal) + 8|0);
 $27 = (($normal) + 12|0);
 $28 = (($capsuleV) + 4|0);
 $29 = (($capsuleV) + 8|0);
 if ($isDoubleSide) {
  $$lcssa$i5657$us = $1;$hadContacts$0$off060$us = 0;$j$058$us = 0;
  while(1) {
   HEAP32[$numContacts>>2] = 0;
   HEAP32[$5>>2] = 7;
   HEAPF32[$10>>2] = Math_fround(0.0);
   ;HEAP32[$11+0>>2]=HEAP32[$deepest$sroa$1$i+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$deepest$sroa$1$i+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$deepest$sroa$1$i+8>>2]|0;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$0+12>>2]|0;
   HEAPF32[$6>>2] = Math_fround(0.0199999995529651641846);
   ;HEAP32[$7+0>>2]=HEAP32[$pen$sroa$1$i+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$pen$sroa$1$i+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$pen$sroa$1$i+8>>2]|0;
   HEAPF32[$8>>2] = Math_fround(3.40282346638528859812E+38);
   ;HEAP32[$9+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
   $30 = (($triangles) + (($j$058$us*40)|0)|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = ((($triangles) + (($j$058$us*40)|0)|0) + 4|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = ((($triangles) + (($j$058$us*40)|0)|0) + 8|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   HEAPF32[$12>>2] = $31;
   HEAPF32[$13>>2] = $33;
   HEAPF32[$14>>2] = $35;
   HEAPF32[$15>>2] = Math_fround(0.0);
   $36 = ((($triangles) + (($j$058$us*40)|0)|0) + 12|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = ((($triangles) + (($j$058$us*40)|0)|0) + 16|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = ((($triangles) + (($j$058$us*40)|0)|0) + 20|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   HEAPF32[$16>>2] = $37;
   HEAPF32[$17>>2] = $39;
   HEAPF32[$18>>2] = $41;
   HEAPF32[$19>>2] = Math_fround(0.0);
   $42 = ((($triangles) + (($j$058$us*40)|0)|0) + 24|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = ((($triangles) + (($j$058$us*40)|0)|0) + 28|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = ((($triangles) + (($j$058$us*40)|0)|0) + 32|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   HEAPF32[$20>>2] = $43;
   HEAPF32[$21>>2] = $45;
   HEAPF32[$22>>2] = $47;
   HEAPF32[$23>>2] = Math_fround(0.0);
   $48 = ((($triangles) + (($j$058$us*40)|0)|0) + 36|0);
   $49 = HEAP8[$48>>0]|0;
   $50 = (($j$058$us) + ($startIndex))|0;
   (__ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration15processTriangleERKNS0_9TriangleVEjRKNS0_8CapsuleVERKNS_6shdfnd3aos6FloatVEhPNS0_21MeshPersistentContactERj($triangleV,$50,$capsuleV,$inflatedRadiusV,$49,$manifoldContacts,$numContacts)|0);
   $51 = HEAP32[$numContacts>>2]|0;
   $52 = ($51|0)==(0);
   if ($52) {
    $$lcssa$i54$us = $$lcssa$i5657$us;$hadContacts$1$off0$us = $hadContacts$0$off060$us;
   } else {
    $53 = Math_fround(HEAPF32[$24>>2]);
    $54 = ($51>>>0)>(1);
    if ($54) {
     $58 = $53;$index$030$i$us = 0;$k$031$i$us = 1;
     while(1) {
      $55 = ((($manifoldContacts) + ($k$031$i$us<<6)|0) + 44|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      $57 = $58 > $56;
      if ($57) {
       ;HEAP32[$deepest$sroa$1$i+0>>2]=HEAP32[$pen$sroa$1$i+0>>2]|0;HEAP32[$deepest$sroa$1$i+4>>2]=HEAP32[$pen$sroa$1$i+4>>2]|0;HEAP32[$deepest$sroa$1$i+8>>2]=HEAP32[$pen$sroa$1$i+8>>2]|0;
       $147 = $56;$index$1$i$us = $k$031$i$us;
      } else {
       $147 = $58;$index$1$i$us = $index$030$i$us;
      }
      $59 = (($k$031$i$us) + 1)|0;
      $exitcond$i$us = ($59|0)==($51|0);
      if ($exitcond$i$us) {
       $$lcssa$i$us = $147;$index$0$lcssa$i$us = $index$1$i$us;
       break;
      } else {
       $58 = $147;$index$030$i$us = $index$1$i$us;$k$031$i$us = $59;
      }
     }
    } else {
     $$lcssa$i$us = $53;$index$0$lcssa$i$us = 0;
    }
    $60 = $$lcssa$i5657$us > $$lcssa$i$us;
    if ($60) {
     HEAP32[$faceIndex>>2] = $50;
     ;HEAP32[$deepestPen$sroa$1+0>>2]=HEAP32[$deepest$sroa$1$i+0>>2]|0;HEAP32[$deepestPen$sroa$1+4>>2]=HEAP32[$deepest$sroa$1$i+4>>2]|0;HEAP32[$deepestPen$sroa$1+8>>2]=HEAP32[$deepest$sroa$1$i+8>>2]|0;
     $61 = ((($manifoldContacts) + ($index$0$lcssa$i$us<<6)|0) + 32|0);
     $62 = Math_fround(HEAPF32[$61>>2]);
     $63 = ((($manifoldContacts) + ($index$0$lcssa$i$us<<6)|0) + 36|0);
     $64 = Math_fround(HEAPF32[$63>>2]);
     $65 = ((($manifoldContacts) + ($index$0$lcssa$i$us<<6)|0) + 40|0);
     $66 = Math_fround(HEAPF32[$65>>2]);
     HEAPF32[$normal>>2] = $62;
     HEAPF32[$25>>2] = $64;
     HEAPF32[$26>>2] = $66;
     HEAPF32[$27>>2] = Math_fround(0.0);
     $67 = ((($manifoldContacts) + ($index$0$lcssa$i$us<<6)|0) + 16|0);
     ;HEAP32[$closestA+0>>2]=HEAP32[$67+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$67+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$67+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$67+12>>2]|0;
     $68 = (($manifoldContacts) + ($index$0$lcssa$i$us<<6)|0);
     ;HEAP32[$closestB+0>>2]=HEAP32[$68+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$68+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$68+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$68+12>>2]|0;
     $$lcssa$i54$us = $$lcssa$i$us;$hadContacts$1$off0$us = 1;
    } else {
     $$lcssa$i54$us = $$lcssa$i5657$us;$hadContacts$1$off0$us = 1;
    }
   }
   $69 = (($j$058$us) + 1)|0;
   $exitcond63 = ($69|0)==($nbTriangles|0);
   if ($exitcond63) {
    $$lcssa$i56$lcssa = $$lcssa$i54$us;$hadContacts$0$off0$lcssa = $hadContacts$1$off0$us;
    break;
   } else {
    $$lcssa$i5657$us = $$lcssa$i54$us;$hadContacts$0$off060$us = $hadContacts$1$off0$us;$j$058$us = $69;
   }
  }
  HEAPF32[$mtd>>2] = $$lcssa$i56$lcssa;
  ;HEAP32[$2+0>>2]=HEAP32[$deepestPen$sroa$1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$deepestPen$sroa$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$deepestPen$sroa$1+8>>2]|0;
  STACKTOP = sp;return ($hadContacts$0$off0$lcssa|0);
 } else {
  $$lcssa$i5657 = $1;$hadContacts$0$off060 = 0;$j$058 = 0;
 }
 while(1) {
  HEAP32[$numContacts>>2] = 0;
  HEAP32[$5>>2] = 7;
  HEAPF32[$10>>2] = Math_fround(0.0);
  ;HEAP32[$11+0>>2]=HEAP32[$deepest$sroa$1$i+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$deepest$sroa$1$i+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$deepest$sroa$1$i+8>>2]|0;
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$0+12>>2]|0;
  HEAPF32[$6>>2] = Math_fround(0.0199999995529651641846);
  ;HEAP32[$7+0>>2]=HEAP32[$pen$sroa$1$i+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$pen$sroa$1$i+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$pen$sroa$1$i+8>>2]|0;
  HEAPF32[$8>>2] = Math_fround(3.40282346638528859812E+38);
  ;HEAP32[$9+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
  $70 = (($triangles) + (($j$058*40)|0)|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = ((($triangles) + (($j$058*40)|0)|0) + 4|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = ((($triangles) + (($j$058*40)|0)|0) + 8|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  HEAPF32[$12>>2] = $71;
  HEAPF32[$13>>2] = $73;
  HEAPF32[$14>>2] = $75;
  HEAPF32[$15>>2] = Math_fround(0.0);
  $76 = ((($triangles) + (($j$058*40)|0)|0) + 12|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = ((($triangles) + (($j$058*40)|0)|0) + 16|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = ((($triangles) + (($j$058*40)|0)|0) + 20|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  HEAPF32[$16>>2] = $77;
  HEAPF32[$17>>2] = $79;
  HEAPF32[$18>>2] = $81;
  HEAPF32[$19>>2] = Math_fround(0.0);
  $82 = ((($triangles) + (($j$058*40)|0)|0) + 24|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = ((($triangles) + (($j$058*40)|0)|0) + 28|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = ((($triangles) + (($j$058*40)|0)|0) + 32|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  HEAPF32[$20>>2] = $83;
  HEAPF32[$21>>2] = $85;
  HEAPF32[$22>>2] = $87;
  HEAPF32[$23>>2] = Math_fround(0.0);
  $88 = Math_fround($77 - $71);
  $89 = Math_fround($79 - $73);
  $90 = Math_fround($81 - $75);
  $91 = Math_fround($83 - $71);
  $92 = Math_fround($85 - $73);
  $93 = Math_fround($87 - $75);
  $94 = Math_fround($89 * $93);
  $95 = Math_fround($90 * $92);
  $96 = Math_fround($94 - $95);
  $97 = Math_fround($90 * $91);
  $98 = Math_fround($88 * $93);
  $99 = Math_fround($97 - $98);
  $100 = Math_fround($88 * $92);
  $101 = Math_fround($89 * $91);
  $102 = Math_fround($100 - $101);
  $103 = Math_fround($96 * $96);
  $104 = Math_fround($99 * $99);
  $105 = Math_fround($103 + $104);
  $106 = Math_fround($102 * $102);
  $107 = Math_fround($106 + $105);
  $108 = (Math_fround(Math_sqrt((Math_fround($107)))));
  $109 = Math_fround(Math_fround(1.0) / $108);
  $110 = Math_fround(HEAPF32[$28>>2]);
  $111 = Math_fround(HEAPF32[$capsuleV>>2]);
  $112 = Math_fround($110 - $73);
  $113 = Math_fround($111 - $71);
  $114 = Math_fround(HEAPF32[$29>>2]);
  $115 = Math_fround($109 * $99);
  $116 = Math_fround($109 * $96);
  $117 = Math_fround($115 * $112);
  $118 = Math_fround($116 * $113);
  $119 = Math_fround($114 - $75);
  $120 = Math_fround($102 * $109);
  $121 = Math_fround($120 * $119);
  $122 = Math_fround($117 + $118);
  $123 = Math_fround($122 + $121);
  $124 = $123 < Math_fround(0.0);
  if ($124) {
   $$lcssa$i54 = $$lcssa$i5657;$hadContacts$1$off0 = $hadContacts$0$off060;
  } else {
   $125 = ((($triangles) + (($j$058*40)|0)|0) + 36|0);
   $126 = HEAP8[$125>>0]|0;
   $127 = (($j$058) + ($startIndex))|0;
   (__ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration15processTriangleERKNS0_9TriangleVEjRKNS0_8CapsuleVERKNS_6shdfnd3aos6FloatVEhPNS0_21MeshPersistentContactERj($triangleV,$127,$capsuleV,$inflatedRadiusV,$126,$manifoldContacts,$numContacts)|0);
   $128 = HEAP32[$numContacts>>2]|0;
   $129 = ($128|0)==(0);
   if ($129) {
    $$lcssa$i54 = $$lcssa$i5657;$hadContacts$1$off0 = $hadContacts$0$off060;
   } else {
    $130 = Math_fround(HEAPF32[$24>>2]);
    $131 = ($128>>>0)>(1);
    if ($131) {
     $135 = $130;$index$030$i = 0;$k$031$i = 1;
     while(1) {
      $132 = ((($manifoldContacts) + ($k$031$i<<6)|0) + 44|0);
      $133 = Math_fround(HEAPF32[$132>>2]);
      $134 = $135 > $133;
      if ($134) {
       ;HEAP32[$deepest$sroa$1$i+0>>2]=HEAP32[$pen$sroa$1$i+0>>2]|0;HEAP32[$deepest$sroa$1$i+4>>2]=HEAP32[$pen$sroa$1$i+4>>2]|0;HEAP32[$deepest$sroa$1$i+8>>2]=HEAP32[$pen$sroa$1$i+8>>2]|0;
       $148 = $133;$index$1$i = $k$031$i;
      } else {
       $148 = $135;$index$1$i = $index$030$i;
      }
      $136 = (($k$031$i) + 1)|0;
      $exitcond$i = ($136|0)==($128|0);
      if ($exitcond$i) {
       $$lcssa$i = $148;$index$0$lcssa$i = $index$1$i;
       break;
      } else {
       $135 = $148;$index$030$i = $index$1$i;$k$031$i = $136;
      }
     }
    } else {
     $$lcssa$i = $130;$index$0$lcssa$i = 0;
    }
    $137 = $$lcssa$i5657 > $$lcssa$i;
    if ($137) {
     HEAP32[$faceIndex>>2] = $127;
     ;HEAP32[$deepestPen$sroa$1+0>>2]=HEAP32[$deepest$sroa$1$i+0>>2]|0;HEAP32[$deepestPen$sroa$1+4>>2]=HEAP32[$deepest$sroa$1$i+4>>2]|0;HEAP32[$deepestPen$sroa$1+8>>2]=HEAP32[$deepest$sroa$1$i+8>>2]|0;
     $138 = ((($manifoldContacts) + ($index$0$lcssa$i<<6)|0) + 32|0);
     $139 = Math_fround(HEAPF32[$138>>2]);
     $140 = ((($manifoldContacts) + ($index$0$lcssa$i<<6)|0) + 36|0);
     $141 = Math_fround(HEAPF32[$140>>2]);
     $142 = ((($manifoldContacts) + ($index$0$lcssa$i<<6)|0) + 40|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     HEAPF32[$normal>>2] = $139;
     HEAPF32[$25>>2] = $141;
     HEAPF32[$26>>2] = $143;
     HEAPF32[$27>>2] = Math_fround(0.0);
     $144 = ((($manifoldContacts) + ($index$0$lcssa$i<<6)|0) + 16|0);
     ;HEAP32[$closestA+0>>2]=HEAP32[$144+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$144+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$144+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$144+12>>2]|0;
     $145 = (($manifoldContacts) + ($index$0$lcssa$i<<6)|0);
     ;HEAP32[$closestB+0>>2]=HEAP32[$145+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$145+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$145+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$145+12>>2]|0;
     $$lcssa$i54 = $$lcssa$i;$hadContacts$1$off0 = 1;
    } else {
     $$lcssa$i54 = $$lcssa$i5657;$hadContacts$1$off0 = 1;
    }
   }
  }
  $146 = (($j$058) + 1)|0;
  $exitcond = ($146|0)==($nbTriangles|0);
  if ($exitcond) {
   $$lcssa$i56$lcssa = $$lcssa$i54;$hadContacts$0$off0$lcssa = $hadContacts$1$off0;
   break;
  } else {
   $$lcssa$i5657 = $$lcssa$i54;$hadContacts$0$off060 = $hadContacts$1$off0;$j$058 = $146;
  }
 }
 HEAPF32[$mtd>>2] = $$lcssa$i56$lcssa;
 ;HEAP32[$2+0>>2]=HEAP32[$deepestPen$sroa$1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$deepestPen$sroa$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$deepestPen$sroa$1+8>>2]|0;
 STACKTOP = sp;return ($hadContacts$0$off0$lcssa|0);
}
function __ZN5physx2Gu30computeCapsule_TriangleMeshMTDERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformERNS0_8CapsuleVEffbRNS_10PxSweepHitE($triMeshGeom,$pose,$capsuleV,$inflatedRadius,$distance,$isDoubleSided,$hit) {
 $triMeshGeom = $triMeshGeom|0;
 $pose = $pose|0;
 $capsuleV = $capsuleV|0;
 $inflatedRadius = Math_fround($inflatedRadius);
 $distance = Math_fround($distance);
 $isDoubleSided = $isDoubleSided|0;
 $hit = $hit|0;
 var $$3 = 0, $$hadContacts$0$off0 = 0, $$sroa$173 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0);
 var $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$0186 = 0, $capsuleBox = 0, $closestA = 0, $closestB = 0, $exitcond = 0, $foundInitial$0$off0191 = 0, $foundInitial$3$off0 = 0, $hadContacts$0$off0185 = 0, $i$0190 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$op = 0, $inflatedCapsule = 0, $inflatedRadiusV = 0, $k$0184 = 0;
 var $manifoldContacts = 0, $mtd = 0, $normal = 0, $numContacts = 0, $tempContainer = 0, $triangleIndex = 0, $triangles = 0, $vertexToWorldSkew = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6144|0;
 $manifoldContacts = sp + 16|0;
 $numContacts = sp + 6068|0;
 $inflatedRadiusV = sp + 4160|0;
 $vertexToWorldSkew = sp + 6080|0;
 $tempContainer = sp + 6128|0;
 $closestA = sp + 4128|0;
 $closestB = sp + 4112|0;
 $normal = sp + 4144|0;
 $triangleIndex = sp + 6072|0;
 $mtd = sp;
 $inflatedCapsule = sp + 6040|0;
 $capsuleBox = sp + 5468|0;
 $$sroa$173 = sp + 5456|0;
 $triangles = sp + 4176|0;
 $0 = (($triMeshGeom) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 168|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$numContacts>>2] = 0;
 $4 = Math_fround($inflatedRadius * Math_fround(1.14999997615814208984));
 HEAPF32[$inflatedRadiusV>>2] = $4;
 $5 = (($triMeshGeom) + 4|0);
 __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($vertexToWorldSkew,$pose,$5);
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $6 = sp + 5528|0;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,128,$6,1);
 $7 = (($closestA) + 4|0);
 $8 = (($closestA) + 8|0);
 ;HEAP32[$closestA+0>>2]=0|0;HEAP32[$closestA+4>>2]=0|0;HEAP32[$closestA+8>>2]=0|0;HEAP32[$closestA+12>>2]=0|0;
 ;HEAP32[$closestB+0>>2]=0|0;HEAP32[$closestB+4>>2]=0|0;HEAP32[$closestB+8>>2]=0|0;HEAP32[$closestB+12>>2]=0|0;
 $9 = (($normal) + 4|0);
 $10 = (($normal) + 8|0);
 $11 = (($normal) + 12|0);
 ;HEAP32[$normal+0>>2]=0|0;HEAP32[$normal+4>>2]=0|0;HEAP32[$normal+8>>2]=0|0;HEAP32[$normal+12>>2]=0|0;
 HEAP32[$triangleIndex>>2] = 268435455;
 $12 = (($tempContainer) + 4|0);
 $13 = (($capsuleV) + 96|0);
 $14 = (($capsuleV) + 100|0);
 $15 = (($capsuleV) + 104|0);
 $16 = (($capsuleV) + 108|0);
 $17 = (($inflatedCapsule) + 4|0);
 $18 = (($inflatedCapsule) + 8|0);
 $19 = (($capsuleV) + 112|0);
 $20 = (($capsuleV) + 116|0);
 $21 = (($capsuleV) + 120|0);
 $22 = (($capsuleV) + 124|0);
 $23 = (($inflatedCapsule) + 12|0);
 $24 = (($inflatedCapsule) + 16|0);
 $25 = (($inflatedCapsule) + 20|0);
 $26 = (($inflatedCapsule) + 24|0);
 $27 = (($tempContainer) + 8|0);
 $28 = (($mtd) + 4|0);
 $29 = (($capsuleV) + 128|0);
 $30 = (($hit) + 40|0);
 $31 = (($hit) + 16|0);
 $32 = (($hit) + 20|0);
 $33 = (($hit) + 24|0);
 $34 = (($hit) + 28|0);
 $35 = (($hit) + 32|0);
 $36 = (($hit) + 36|0);
 $37 = (($hit) + 8|0);
 $38 = (($capsuleV) + 4|0);
 $39 = (($capsuleV) + 8|0);
 $40 = (($capsuleV) + 12|0);
 $93 = Math_fround(0.0);$95 = Math_fround(0.0);$97 = Math_fround(0.0);$foundInitial$0$off0191 = 0;$i$0190 = 0;
 while(1) {
  $41 = HEAP32[$12>>2]|0;
  $42 = ($41|0)==(0);
  if (!($42)) {
   HEAP32[$12>>2] = 0;
  }
  $43 = Math_fround(HEAPF32[$13>>2]);
  $44 = Math_fround(HEAPF32[$14>>2]);
  $45 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$inflatedCapsule>>2] = $43;
  HEAPF32[$17>>2] = $44;
  HEAPF32[$18>>2] = $45;
  $46 = Math_fround(HEAPF32[$19>>2]);
  $47 = Math_fround(HEAPF32[$20>>2]);
  $48 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$23>>2] = $46;
  HEAPF32[$24>>2] = $47;
  HEAPF32[$25>>2] = $48;
  HEAPF32[$26>>2] = $inflatedRadius;
  __ZN5physx2Gu23computeBoxAroundCapsuleERKNS0_7CapsuleERNS0_3BoxE($inflatedCapsule,$capsuleBox);
  __ZL13midPhaseQueryRKN5physx22PxTriangleMeshGeometryERKNS_11PxTransformERNS_2Gu3BoxERNS6_9ContainerE($triMeshGeom,$pose,$capsuleBox,$tempContainer);
  $49 = HEAP32[$12>>2]|0;
  $50 = ($49|0)==(0);
  if ($50) {
   $119 = $93;$121 = $95;$124 = $97;$foundInitial$3$off0 = $foundInitial$0$off0191;
   break;
  }
  $51 = HEAP32[$27>>2]|0;
  $52 = (($49) + 31)|0;
  HEAPF32[$mtd>>2] = Math_fround(3.40282346638528859812E+38);
  ;HEAP32[$28+0>>2]=HEAP32[$$sroa$173+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$$sroa$173+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$$sroa$173+8>>2]|0;
  $53 = $52 >>> 5;
  $54 = ($53|0)==(0);
  if ($54) {
   $119 = $93;$121 = $95;$124 = $97;$foundInitial$3$off0 = $foundInitial$0$off0191;
   break;
  }
  $55 = $49 ^ -1;
  $a$0186 = 0;$hadContacts$0$off0185 = 0;$indvars$iv = $55;
  while(1) {
   $56 = ($indvars$iv>>>0)>(4294967263);
   $indvars$iv$op = $indvars$iv ^ -1;
   $57 = $56 ? $indvars$iv$op : 32;
   $58 = $a$0186 << 5;
   $59 = (($49) - ($58))|0;
   $60 = ($59>>>0)<(32);
   $61 = $60 ? $59 : 32;
   $62 = ($61|0)==(0);
   if (!($62)) {
    $k$0184 = 0;
    while(1) {
     $63 = (($k$0184) + ($58))|0;
     $64 = (($51) + ($63<<2)|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (($triangles) + (($k$0184*40)|0)|0);
     $67 = HEAP32[$0>>2]|0;
     __ZNK5physx2Gu12TriangleMesh20computeWorldTriangleERNS_10PxTriangleEjRKNS_2Cm8Matrix34EPjS8_($67,$66,$65,$vertexToWorldSkew,0,0);
     $68 = (($3) + ($65)|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = ((($triangles) + (($k$0184*40)|0)|0) + 36|0);
     HEAP8[$70>>0] = $69;
     $71 = (($k$0184) + 1)|0;
     $exitcond = ($71|0)==($57|0);
     if ($exitcond) {
      break;
     } else {
      $k$0184 = $71;
     }
    }
   }
   $72 = (__Z12calculateMTDRKN5physx2Gu8CapsuleVERKNS_6shdfnd3aos6FloatVEbPK11MTDTrianglejjPNS0_21MeshPersistentContactERjRNS5_5Vec3VESG_SG_SE_RS6_($capsuleV,$inflatedRadiusV,$isDoubleSided,$triangles,$61,$58,$manifoldContacts,$numContacts,$normal,$closestA,$closestB,$triangleIndex,$mtd)|0);
   $$hadContacts$0$off0 = $72 | $hadContacts$0$off0185;
   $73 = (($a$0186) + 1)|0;
   $74 = ($73>>>0)<($53>>>0);
   $indvars$iv$next = (($indvars$iv) + 32)|0;
   if ($74) {
    $a$0186 = $73;$hadContacts$0$off0185 = $$hadContacts$0$off0;$indvars$iv = $indvars$iv$next;
   } else {
    break;
   }
  }
  if (!($$hadContacts$0$off0)) {
   $119 = $93;$121 = $95;$124 = $97;$foundInitial$3$off0 = $foundInitial$0$off0191;
   break;
  }
  $75 = HEAP32[$triangleIndex>>2]|0;
  $76 = (($51) + ($75<<2)|0);
  $77 = HEAP32[$76>>2]|0;
  HEAP32[$triangleIndex>>2] = $77;
  $78 = Math_fround(HEAPF32[$mtd>>2]);
  $79 = Math_fround(HEAPF32[$29>>2]);
  $80 = Math_fround($78 - $79);
  $81 = !($80 <= Math_fround(0.0));
  if ($81) {
   label = 12;
   break;
  }
  $83 = Math_fround(HEAPF32[$capsuleV>>2]);
  $84 = Math_fround(HEAPF32[$38>>2]);
  $85 = Math_fround(HEAPF32[$39>>2]);
  $86 = Math_fround(HEAPF32[$normal>>2]);
  $87 = Math_fround(HEAPF32[$9>>2]);
  $88 = Math_fround(HEAPF32[$10>>2]);
  $89 = Math_fround($80 * $86);
  $90 = Math_fround($80 * $87);
  $91 = Math_fround($80 * $88);
  $92 = Math_fround($93 - $89);
  $94 = Math_fround($95 - $90);
  $96 = Math_fround($97 - $91);
  $98 = Math_fround($83 - $89);
  $99 = Math_fround($84 - $90);
  $100 = Math_fround($85 - $91);
  $101 = Math_fround($98 - $83);
  $102 = Math_fround($99 - $84);
  $103 = Math_fround($100 - $85);
  HEAPF32[$capsuleV>>2] = $98;
  HEAPF32[$38>>2] = $99;
  HEAPF32[$39>>2] = $100;
  HEAPF32[$40>>2] = Math_fround(0.0);
  $104 = Math_fround(HEAPF32[$13>>2]);
  $105 = Math_fround(HEAPF32[$14>>2]);
  $106 = Math_fround(HEAPF32[$15>>2]);
  $107 = Math_fround($101 + $104);
  $108 = Math_fround($102 + $105);
  $109 = Math_fround($103 + $106);
  HEAPF32[$13>>2] = $107;
  HEAPF32[$14>>2] = $108;
  HEAPF32[$15>>2] = $109;
  HEAPF32[$16>>2] = Math_fround(0.0);
  $110 = Math_fround(HEAPF32[$19>>2]);
  $111 = Math_fround(HEAPF32[$20>>2]);
  $112 = Math_fround(HEAPF32[$21>>2]);
  $113 = Math_fround($101 + $110);
  $114 = Math_fround($102 + $111);
  $115 = Math_fround($103 + $112);
  HEAPF32[$19>>2] = $113;
  HEAPF32[$20>>2] = $114;
  HEAPF32[$21>>2] = $115;
  HEAPF32[$22>>2] = Math_fround(0.0);
  $116 = (($i$0190) + 1)|0;
  $117 = ($116>>>0)<(4);
  if ($117) {
   $93 = $92;$95 = $94;$97 = $96;$foundInitial$0$off0191 = 1;$i$0190 = $116;
  } else {
   $119 = $92;$121 = $94;$124 = $96;$foundInitial$3$off0 = 1;
   break;
  }
 }
 if ((label|0) == 12) {
  $82 = ($i$0190|0)==(0);
  if ($82) {
   HEAPF32[$30>>2] = Math_fround(0.0);
   $136 = Math_fround(HEAPF32[$closestA>>2]);
   $137 = Math_fround(HEAPF32[$7>>2]);
   $138 = Math_fround(HEAPF32[$8>>2]);
   HEAPF32[$31>>2] = $136;
   HEAPF32[$32>>2] = $137;
   HEAPF32[$33>>2] = $138;
   $139 = Math_fround(HEAPF32[$normal>>2]);
   $140 = Math_fround(HEAPF32[$9>>2]);
   $141 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$34>>2] = $139;
   HEAPF32[$35>>2] = $140;
   HEAPF32[$36>>2] = $141;
   HEAP32[$37>>2] = $77;
   $$3 = 1;
   __ZN5physx2Gu9ContainerD2Ev($tempContainer);
   STACKTOP = sp;return ($$3|0);
  } else {
   $119 = $93;$121 = $95;$124 = $97;$foundInitial$3$off0 = 1;
  }
 }
 $118 = Math_fround($119 * $119);
 $120 = Math_fround($121 * $121);
 $122 = Math_fround($120 + $118);
 $123 = Math_fround($124 * $124);
 $125 = Math_fround($123 + $122);
 $126 = (Math_fround(Math_sqrt((Math_fround($125)))));
 $127 = Math_fround(Math_fround(1.0) / $126);
 $128 = Math_fround($119 * $127);
 $129 = Math_fround($121 * $127);
 $130 = Math_fround($124 * $127);
 HEAPF32[$normal>>2] = $128;
 HEAPF32[$9>>2] = $129;
 HEAPF32[$10>>2] = $130;
 HEAPF32[$11>>2] = Math_fround(0.0);
 if (!($foundInitial$3$off0)) {
  $$3 = 0;
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return ($$3|0);
 }
 $131 = Math_fround(-$126);
 HEAPF32[$30>>2] = $131;
 $132 = Math_fround(HEAPF32[$closestA>>2]);
 $133 = Math_fround(HEAPF32[$7>>2]);
 $134 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$31>>2] = $132;
 HEAPF32[$32>>2] = $133;
 HEAPF32[$33>>2] = $134;
 HEAPF32[$34>>2] = $128;
 HEAPF32[$35>>2] = $129;
 HEAPF32[$36>>2] = $130;
 $135 = HEAP32[$triangleIndex>>2]|0;
 HEAP32[$37>>2] = $135;
 $$3 = 1;
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return ($$3|0);
}
function __ZL13midPhaseQueryRKN5physx22PxTriangleMeshGeometryERKNS_11PxTransformERNS_2Gu3BoxERNS6_9ContainerE($triMeshGeom,$pose,$bound,$tempContainer) {
 $triMeshGeom = $triMeshGeom|0;
 $pose = $pose|0;
 $bound = $bound|0;
 $tempContainer = $tempContainer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $callback = 0;
 var $hmd = 0, $meshScaling = 0, $vertexSpaceBox = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $meshScaling = sp + 88|0;
 $vertexSpaceBox = sp;
 $hmd = sp + 60|0;
 $callback = sp + 72|0;
 $0 = (($triMeshGeom) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($triMeshGeom) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $3 == Math_fround(1.0);
 if ($4) {
  $5 = (($triMeshGeom) + 8|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = $6 == Math_fround(1.0);
  if ($7) {
   $8 = (($triMeshGeom) + 12|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = $9 == Math_fround(1.0);
   $38 = $10;
  } else {
   $38 = 0;
  }
 } else {
  $38 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $11 = (($meshScaling) + 4|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($meshScaling) + 8|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($meshScaling) + 12|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($meshScaling) + 16|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($meshScaling) + 20|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($meshScaling) + 24|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($meshScaling) + 28|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($meshScaling) + 32|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($meshScaling) + 36|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($meshScaling) + 40|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($meshScaling) + 44|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($meshScaling) + 48|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($meshScaling) + 52|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($meshScaling) + 56|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($meshScaling) + 60|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($meshScaling) + 64|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($meshScaling) + 68|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 if (!($38)) {
  $28 = (($triMeshGeom) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$2,$28);
 }
 __ZN5physx2Gu21computeVertexSpaceOBBERNS0_3BoxERKS1_RKNS_11PxTransformERKNS_11PxMeshScaleE($vertexSpaceBox,$bound,$pose,$2);
 $29 = (($1) + 32|0);
 $30 = HEAP32[$29>>2]|0;
 HEAP32[$hmd>>2] = $30;
 $31 = (($1) + 48|0);
 $32 = (($hmd) + 4|0);
 HEAP32[$32>>2] = $31;
 $33 = (($1) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($hmd) + 8|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($callback) + 4|0);
 HEAP32[$36>>2] = 2;
 HEAP32[$callback>>2] = ((548584 + 8|0));
 $37 = (($callback) + 8|0);
 HEAP32[$37>>2] = $tempContainer;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($vertexSpaceBox,1,$hmd,$callback,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29computeCapsule_HeightFieldMTDERKNS_21PxHeightFieldGeometryERKNS_11PxTransformERNS0_8CapsuleVEffbjRNS_10PxSweepHitE($heightFieldGeom,$pose,$capsuleV,$inflatedRadius,$distance,$isDoubleSided,$flags,$hit) {
 $heightFieldGeom = $heightFieldGeom|0;
 $pose = $pose|0;
 $capsuleV = $capsuleV|0;
 $inflatedRadius = Math_fround($inflatedRadius);
 $distance = Math_fround($distance);
 $isDoubleSided = $isDoubleSided|0;
 $flags = $flags|0;
 $hit = $hit|0;
 var $$3 = 0, $$hadContacts$0$off0 = 0, $$sroa$173 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $a$0186 = 0, $bounds = 0, $capsuleBox = 0, $closestA = 0, $closestB = 0, $exitcond = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0), $foundInitial$0$off0191 = 0, $foundInitial$3$off0 = 0, $hadContacts$0$off0185 = 0;
 var $hfUtil = 0, $i$0190 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$op = 0, $inflatedCapsule = 0, $inflatedRadiusV = 0, $k$0184 = 0, $manifoldContacts = 0, $mtd = 0, $normal = 0, $numContacts = 0, $tempContainer = 0, $triangleIndex = 0, $triangles = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6160|0;
 $0 = sp + 6144|0;
 $manifoldContacts = sp + 80|0;
 $numContacts = sp + 6136|0;
 $inflatedRadiusV = sp + 64|0;
 $tempContainer = sp + 6120|0;
 $hfUtil = sp + 6100|0;
 $closestA = sp + 32|0;
 $closestB = sp + 16|0;
 $normal = sp + 48|0;
 $triangleIndex = sp + 4720|0;
 $mtd = sp;
 $inflatedCapsule = sp + 4176|0;
 $capsuleBox = sp + 4724|0;
 $bounds = sp + 6064|0;
 $$sroa$173 = sp + 6088|0;
 $triangles = sp + 4784|0;
 HEAP32[$numContacts>>2] = 0;
 $1 = Math_fround($inflatedRadius * Math_fround(1.00999999046325683594));
 HEAPF32[$inflatedRadiusV>>2] = $1;
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $2 = sp + 4208|0;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,128,$2,1);
 $3 = (($hfUtil) + 12|0);
 $4 = (($heightFieldGeom) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 $6 = (($hfUtil) + 16|0);
 HEAP32[$6>>2] = $heightFieldGeom;
 $7 = (($heightFieldGeom) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(Math_fround(1.0) / $8);
 $10 = (($hfUtil) + 4|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($heightFieldGeom) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(Math_fround(1.0) / $12);
 HEAPF32[$hfUtil>>2] = $13;
 $14 = (($heightFieldGeom) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(Math_fround(1.0) / $15);
 $17 = (($hfUtil) + 8|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($closestA) + 4|0);
 $19 = (($closestA) + 8|0);
 ;HEAP32[$closestA+0>>2]=0|0;HEAP32[$closestA+4>>2]=0|0;HEAP32[$closestA+8>>2]=0|0;HEAP32[$closestA+12>>2]=0|0;
 ;HEAP32[$closestB+0>>2]=0|0;HEAP32[$closestB+4>>2]=0|0;HEAP32[$closestB+8>>2]=0|0;HEAP32[$closestB+12>>2]=0|0;
 $20 = (($normal) + 4|0);
 $21 = (($normal) + 8|0);
 $22 = (($normal) + 12|0);
 ;HEAP32[$normal+0>>2]=0|0;HEAP32[$normal+4>>2]=0|0;HEAP32[$normal+8>>2]=0|0;HEAP32[$normal+12>>2]=0|0;
 HEAP32[$triangleIndex>>2] = 268435455;
 $23 = (($tempContainer) + 4|0);
 $24 = (($capsuleV) + 96|0);
 $25 = (($capsuleV) + 100|0);
 $26 = (($capsuleV) + 104|0);
 $27 = (($capsuleV) + 108|0);
 $28 = (($inflatedCapsule) + 4|0);
 $29 = (($inflatedCapsule) + 8|0);
 $30 = (($capsuleV) + 112|0);
 $31 = (($capsuleV) + 116|0);
 $32 = (($capsuleV) + 120|0);
 $33 = (($capsuleV) + 124|0);
 $34 = (($inflatedCapsule) + 12|0);
 $35 = (($inflatedCapsule) + 16|0);
 $36 = (($inflatedCapsule) + 20|0);
 $37 = (($inflatedCapsule) + 24|0);
 $38 = (($0) + 4|0);
 $39 = (($0) + 8|0);
 $40 = (($0) + 12|0);
 $41 = (($capsuleBox) + 36|0);
 $42 = (($capsuleBox) + 40|0);
 $43 = (($capsuleBox) + 44|0);
 $44 = (($capsuleBox) + 48|0);
 $45 = (($capsuleBox) + 52|0);
 $46 = (($capsuleBox) + 56|0);
 $47 = (($bounds) + 4|0);
 $48 = (($bounds) + 8|0);
 $49 = (($bounds) + 12|0);
 $50 = (($bounds) + 16|0);
 $51 = (($bounds) + 20|0);
 $52 = (($0) + 4|0);
 $53 = (($tempContainer) + 8|0);
 $54 = (($mtd) + 4|0);
 $55 = (($capsuleV) + 128|0);
 $56 = (($hit) + 40|0);
 $57 = (($hit) + 16|0);
 $58 = (($hit) + 20|0);
 $59 = (($hit) + 24|0);
 $60 = (($hit) + 28|0);
 $61 = (($hit) + 32|0);
 $62 = (($hit) + 36|0);
 $63 = (($hit) + 8|0);
 $64 = (($capsuleV) + 4|0);
 $65 = (($capsuleV) + 8|0);
 $66 = (($capsuleV) + 12|0);
 $170 = Math_fround(0.0);$172 = Math_fround(0.0);$174 = Math_fround(0.0);$foundInitial$0$off0191 = 0;$i$0190 = 0;
 while(1) {
  $67 = HEAP32[$23>>2]|0;
  $68 = ($67|0)==(0);
  if (!($68)) {
   HEAP32[$23>>2] = 0;
  }
  $69 = Math_fround(HEAPF32[$24>>2]);
  $70 = Math_fround(HEAPF32[$25>>2]);
  $71 = Math_fround(HEAPF32[$26>>2]);
  HEAPF32[$inflatedCapsule>>2] = $69;
  HEAPF32[$28>>2] = $70;
  HEAPF32[$29>>2] = $71;
  $72 = Math_fround(HEAPF32[$30>>2]);
  $73 = Math_fround(HEAPF32[$31>>2]);
  $74 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$34>>2] = $72;
  HEAPF32[$35>>2] = $73;
  HEAPF32[$36>>2] = $74;
  HEAPF32[$37>>2] = $inflatedRadius;
  __ZN5physx2Gu23computeBoxAroundCapsuleERKNS0_7CapsuleERNS0_3BoxE($inflatedCapsule,$capsuleBox);
  __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$capsuleBox);
  $75 = Math_fround(HEAPF32[$0>>2]);
  $76 = Math_fround(HEAPF32[$38>>2]);
  $77 = Math_fround(HEAPF32[$39>>2]);
  $78 = Math_fround(HEAPF32[$40>>2]);
  $79 = Math_fround(HEAPF32[$41>>2]);
  $80 = Math_fround(HEAPF32[$42>>2]);
  $81 = Math_fround(HEAPF32[$43>>2]);
  $82 = Math_fround($75 + $75);
  $83 = Math_fround($76 + $76);
  $84 = Math_fround($77 + $77);
  $85 = Math_fround($75 * $82);
  $86 = Math_fround($76 * $83);
  $87 = Math_fround($77 * $84);
  $88 = Math_fround($82 * $76);
  $89 = Math_fround($82 * $77);
  $90 = Math_fround($82 * $78);
  $91 = Math_fround($83 * $77);
  $92 = Math_fround($83 * $78);
  $93 = Math_fround($84 * $78);
  $94 = Math_fround(Math_fround(1.0) - $86);
  $95 = Math_fround($94 - $87);
  $96 = Math_fround($88 + $93);
  $97 = Math_fround($89 - $92);
  $98 = Math_fround($88 - $93);
  $99 = Math_fround(Math_fround(1.0) - $85);
  $100 = Math_fround($99 - $87);
  $101 = Math_fround($91 + $90);
  $102 = Math_fround($89 + $92);
  $103 = Math_fround($91 - $90);
  $104 = Math_fround($99 - $86);
  $105 = Math_fround(HEAPF32[$44>>2]);
  $106 = Math_fround($95 * $105);
  $107 = Math_fround($96 * $105);
  $108 = Math_fround($97 * $105);
  $109 = Math_fround(HEAPF32[$45>>2]);
  $110 = Math_fround($98 * $109);
  $111 = Math_fround($100 * $109);
  $112 = Math_fround($101 * $109);
  $113 = Math_fround(HEAPF32[$46>>2]);
  $114 = Math_fround($102 * $113);
  $115 = Math_fround($103 * $113);
  $116 = Math_fround($104 * $113);
  $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($106)))));
  $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($110)))));
  $117 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
  $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($114)))));
  $118 = Math_fround($117 + $fabsf$i$i6$i$i);
  $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($107)))));
  $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($111)))));
  $119 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
  $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($115)))));
  $120 = Math_fround($119 + $fabsf$i$i3$i$i);
  $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($108)))));
  $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($112)))));
  $121 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
  $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($116)))));
  $122 = Math_fround($121 + $fabsf$i$i$i$i);
  $123 = Math_fround($79 - $118);
  $124 = Math_fround($80 - $120);
  $125 = Math_fround($81 - $122);
  $126 = Math_fround($79 + $118);
  $127 = Math_fround($80 + $120);
  $128 = Math_fround($81 + $122);
  HEAPF32[$bounds>>2] = $123;
  HEAPF32[$47>>2] = $124;
  HEAPF32[$48>>2] = $125;
  HEAPF32[$49>>2] = $126;
  HEAPF32[$50>>2] = $127;
  HEAPF32[$51>>2] = $128;
  HEAP32[$0>>2] = ((548560 + 8|0));
  HEAP32[$52>>2] = $tempContainer;
  (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$pose,$bounds,$flags,$0)|0);
  $129 = HEAP32[$23>>2]|0;
  $130 = ($129|0)==(0);
  if ($130) {
   $196 = $170;$198 = $172;$201 = $174;$foundInitial$3$off0 = $foundInitial$0$off0191;
   break;
  }
  $131 = HEAP32[$53>>2]|0;
  $132 = (($129) + 31)|0;
  HEAPF32[$mtd>>2] = Math_fround(3.40282346638528859812E+38);
  ;HEAP32[$54+0>>2]=HEAP32[$$sroa$173+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$$sroa$173+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$$sroa$173+8>>2]|0;
  $133 = $132 >>> 5;
  $134 = ($133|0)==(0);
  if ($134) {
   $196 = $170;$198 = $172;$201 = $174;$foundInitial$3$off0 = $foundInitial$0$off0191;
   break;
  }
  $135 = $129 ^ -1;
  $a$0186 = 0;$hadContacts$0$off0185 = 0;$indvars$iv = $135;
  while(1) {
   $136 = ($indvars$iv>>>0)>(4294967263);
   $indvars$iv$op = $indvars$iv ^ -1;
   $137 = $136 ? $indvars$iv$op : 32;
   $138 = $a$0186 << 5;
   $139 = (($129) - ($138))|0;
   $140 = ($139>>>0)<(32);
   $141 = $140 ? $139 : 32;
   $142 = ($141|0)==(0);
   if (!($142)) {
    $k$0184 = 0;
    while(1) {
     $143 = (($k$0184) + ($138))|0;
     $144 = (($131) + ($143<<2)|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = (($triangles) + (($k$0184*40)|0)|0);
     (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($hfUtil,$pose,$146,0,0,$145,1,1)|0);
     $147 = ((($triangles) + (($k$0184*40)|0)|0) + 36|0);
     HEAP8[$147>>0] = 56;
     $148 = (($k$0184) + 1)|0;
     $exitcond = ($148|0)==($137|0);
     if ($exitcond) {
      break;
     } else {
      $k$0184 = $148;
     }
    }
   }
   $149 = (__Z12calculateMTDRKN5physx2Gu8CapsuleVERKNS_6shdfnd3aos6FloatVEbPK11MTDTrianglejjPNS0_21MeshPersistentContactERjRNS5_5Vec3VESG_SG_SE_RS6_($capsuleV,$inflatedRadiusV,$isDoubleSided,$triangles,$141,$138,$manifoldContacts,$numContacts,$normal,$closestA,$closestB,$triangleIndex,$mtd)|0);
   $$hadContacts$0$off0 = $149 | $hadContacts$0$off0185;
   $150 = (($a$0186) + 1)|0;
   $151 = ($150>>>0)<($133>>>0);
   $indvars$iv$next = (($indvars$iv) + 32)|0;
   if ($151) {
    $a$0186 = $150;$hadContacts$0$off0185 = $$hadContacts$0$off0;$indvars$iv = $indvars$iv$next;
   } else {
    break;
   }
  }
  if (!($$hadContacts$0$off0)) {
   $196 = $170;$198 = $172;$201 = $174;$foundInitial$3$off0 = $foundInitial$0$off0191;
   break;
  }
  $152 = HEAP32[$triangleIndex>>2]|0;
  $153 = (($131) + ($152<<2)|0);
  $154 = HEAP32[$153>>2]|0;
  HEAP32[$triangleIndex>>2] = $154;
  $155 = Math_fround(HEAPF32[$mtd>>2]);
  $156 = Math_fround(HEAPF32[$55>>2]);
  $157 = Math_fround($155 - $156);
  $158 = !($157 <= Math_fround(0.0));
  if ($158) {
   label = 12;
   break;
  }
  $160 = Math_fround(HEAPF32[$capsuleV>>2]);
  $161 = Math_fround(HEAPF32[$64>>2]);
  $162 = Math_fround(HEAPF32[$65>>2]);
  $163 = Math_fround(HEAPF32[$normal>>2]);
  $164 = Math_fround(HEAPF32[$20>>2]);
  $165 = Math_fround(HEAPF32[$21>>2]);
  $166 = Math_fround($157 * $163);
  $167 = Math_fround($157 * $164);
  $168 = Math_fround($157 * $165);
  $169 = Math_fround($170 - $166);
  $171 = Math_fround($172 - $167);
  $173 = Math_fround($174 - $168);
  $175 = Math_fround($160 - $166);
  $176 = Math_fround($161 - $167);
  $177 = Math_fround($162 - $168);
  $178 = Math_fround($175 - $160);
  $179 = Math_fround($176 - $161);
  $180 = Math_fround($177 - $162);
  HEAPF32[$capsuleV>>2] = $175;
  HEAPF32[$64>>2] = $176;
  HEAPF32[$65>>2] = $177;
  HEAPF32[$66>>2] = Math_fround(0.0);
  $181 = Math_fround(HEAPF32[$24>>2]);
  $182 = Math_fround(HEAPF32[$25>>2]);
  $183 = Math_fround(HEAPF32[$26>>2]);
  $184 = Math_fround($178 + $181);
  $185 = Math_fround($179 + $182);
  $186 = Math_fround($180 + $183);
  HEAPF32[$24>>2] = $184;
  HEAPF32[$25>>2] = $185;
  HEAPF32[$26>>2] = $186;
  HEAPF32[$27>>2] = Math_fround(0.0);
  $187 = Math_fround(HEAPF32[$30>>2]);
  $188 = Math_fround(HEAPF32[$31>>2]);
  $189 = Math_fround(HEAPF32[$32>>2]);
  $190 = Math_fround($178 + $187);
  $191 = Math_fround($179 + $188);
  $192 = Math_fround($180 + $189);
  HEAPF32[$30>>2] = $190;
  HEAPF32[$31>>2] = $191;
  HEAPF32[$32>>2] = $192;
  HEAPF32[$33>>2] = Math_fround(0.0);
  $193 = (($i$0190) + 1)|0;
  $194 = ($193>>>0)<(4);
  if ($194) {
   $170 = $169;$172 = $171;$174 = $173;$foundInitial$0$off0191 = 1;$i$0190 = $193;
  } else {
   $196 = $169;$198 = $171;$201 = $173;$foundInitial$3$off0 = 1;
   break;
  }
 }
 if ((label|0) == 12) {
  $159 = ($i$0190|0)==(0);
  if ($159) {
   HEAPF32[$56>>2] = Math_fround(0.0);
   $213 = Math_fround(HEAPF32[$closestA>>2]);
   $214 = Math_fround(HEAPF32[$18>>2]);
   $215 = Math_fround(HEAPF32[$19>>2]);
   HEAPF32[$57>>2] = $213;
   HEAPF32[$58>>2] = $214;
   HEAPF32[$59>>2] = $215;
   $216 = Math_fround(HEAPF32[$normal>>2]);
   $217 = Math_fround(HEAPF32[$20>>2]);
   $218 = Math_fround(HEAPF32[$21>>2]);
   HEAPF32[$60>>2] = $216;
   HEAPF32[$61>>2] = $217;
   HEAPF32[$62>>2] = $218;
   HEAP32[$63>>2] = $154;
   $$3 = 1;
   __ZN5physx2Gu9ContainerD2Ev($tempContainer);
   STACKTOP = sp;return ($$3|0);
  } else {
   $196 = $170;$198 = $172;$201 = $174;$foundInitial$3$off0 = 1;
  }
 }
 $195 = Math_fround($196 * $196);
 $197 = Math_fround($198 * $198);
 $199 = Math_fround($197 + $195);
 $200 = Math_fround($201 * $201);
 $202 = Math_fround($200 + $199);
 $203 = (Math_fround(Math_sqrt((Math_fround($202)))));
 $204 = Math_fround(Math_fround(1.0) / $203);
 $205 = Math_fround($196 * $204);
 $206 = Math_fround($198 * $204);
 $207 = Math_fround($201 * $204);
 HEAPF32[$normal>>2] = $205;
 HEAPF32[$20>>2] = $206;
 HEAPF32[$21>>2] = $207;
 HEAPF32[$22>>2] = Math_fround(0.0);
 if (!($foundInitial$3$off0)) {
  $$3 = 0;
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return ($$3|0);
 }
 $208 = Math_fround(-$203);
 HEAPF32[$56>>2] = $208;
 $209 = Math_fround(HEAPF32[$closestA>>2]);
 $210 = Math_fround(HEAPF32[$18>>2]);
 $211 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$57>>2] = $209;
 HEAPF32[$58>>2] = $210;
 HEAPF32[$59>>2] = $211;
 HEAPF32[$60>>2] = $205;
 HEAPF32[$61>>2] = $206;
 HEAPF32[$62>>2] = $207;
 $212 = HEAP32[$triangleIndex>>2]|0;
 HEAP32[$63>>2] = $212;
 $$3 = 1;
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return ($$3|0);
}
function __ZN5physx2Gu26computeBox_TriangleMeshMTDERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformERKNS0_3BoxES6_ffbRNS_10PxSweepHitE($triMeshGeom,$pose,$_box,$boxTransform,$inflation,$distance,$isDoubleSided,$hit) {
 $triMeshGeom = $triMeshGeom|0;
 $pose = $pose|0;
 $_box = $_box|0;
 $boxTransform = $boxTransform|0;
 $inflation = Math_fround($inflation);
 $distance = Math_fround($distance);
 $isDoubleSided = $isDoubleSided|0;
 $hit = $hit|0;
 var $$$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$2 = 0, $$hadContacts$0$off0 = 0, $$lcssa$i$i = Math_fround(0), $$lcssa$i3$i = Math_fround(0), $$lcssa$i4$lcssa$i = Math_fround(0), $$lcssa$i45$i = Math_fround(0), $$sroa$173 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0);
 var $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0);
 var $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0);
 var $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0);
 var $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0;
 var $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = Math_fround(0);
 var $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = 0, $321 = Math_fround(0);
 var $322 = 0, $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0;
 var $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0);
 var $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0);
 var $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0);
 var $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0;
 var $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0);
 var $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0);
 var $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0);
 var $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0);
 var $502 = 0, $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = 0, $51 = Math_fround(0), $510 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0;
 var $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $a$0217 = 0, $box = 0, $boxMap = 0, $boxTransformV = 0, $boxV = 0, $deepestPen$sroa$1$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i$i = 0, $foundInitial$0$off0230 = 0, $foundInitial$2$off0 = 0, $hadContacts$0$off0$lcssa$i = 0, $hadContacts$0$off0216 = 0, $hadContacts$0$off07$i = 0, $hadContacts$1$off0$i = 0, $i$0229 = 0, $identity = 0, $index$0$lcssa$i$i = 0;
 var $index$030$i$i = 0, $index$1$i$i = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$op = 0, $inflationV = 0, $j$06$i = 0, $k$0200 = 0, $k$031$i$i = 0, $manifoldContacts = 0, $meshToConvex = 0, $meshToWorldSkew = 0, $mtd$sroa$1 = 0, $numContacts = 0, $pen$sroa$1$i$i = 0, $polyBox = 0, $polyData = 0, $tempContainer = 0, $triangles = 0, $vref0$0$i = 0;
 var $vref1$0$i = 0, $vref2$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6768|0;
 $0 = sp + 4480|0;
 $pen$sroa$1$i$i = sp + 6536|0;
 $deepestPen$sroa$1$i = sp + 6524|0;
 $manifoldContacts = sp + 336|0;
 $numContacts = sp + 6520|0;
 $tempContainer = sp + 6504|0;
 $box = sp + 6440|0;
 $inflationV = sp + 160|0;
 $boxV = sp;
 $polyData = sp + 6368|0;
 $polyBox = sp + 6548|0;
 $identity = sp + 4432|0;
 $meshToWorldSkew = sp + 5008|0;
 $boxTransformV = sp + 304|0;
 $mtd$sroa$1 = sp + 6352|0;
 $boxMap = sp + 176|0;
 $meshToConvex = sp + 240|0;
 $$sroa$173 = sp + 5056|0;
 $triangles = sp + 5072|0;
 $1 = (($triMeshGeom) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 168|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$numContacts>>2] = 0;
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $5 = sp + 4496|0;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,128,$5,1);
 $6 = Math_fround(HEAPF32[$_box>>2]);
 HEAPF32[$box>>2] = $6;
 $7 = (($box) + 4|0);
 $8 = (($_box) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($box) + 8|0);
 $11 = (($_box) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$10>>2] = $12;
 $13 = (($box) + 12|0);
 $14 = (($_box) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$13>>2] = $15;
 $16 = (($box) + 16|0);
 $17 = (($_box) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $18;
 $19 = (($box) + 20|0);
 $20 = (($_box) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$19>>2] = $21;
 $22 = (($box) + 24|0);
 $23 = (($_box) + 24|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$22>>2] = $24;
 $25 = (($box) + 28|0);
 $26 = (($_box) + 28|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($box) + 32|0);
 $29 = (($_box) + 32|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($box) + 36|0);
 $32 = (($_box) + 36|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($box) + 40|0);
 $35 = (($_box) + 40|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 $37 = (($box) + 44|0);
 $38 = (($_box) + 44|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$37>>2] = $39;
 $40 = (($box) + 48|0);
 $41 = (($_box) + 48|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($box) + 52|0);
 $44 = (($_box) + 52|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($box) + 56|0);
 $47 = (($_box) + 56|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround(HEAPF32[$boxTransform>>2]);
 $50 = (($boxTransform) + 4|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($boxTransform) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($boxTransform) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($boxTransform) + 16|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($56) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($56) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = !($42 <= $45);
 $$$i$i = $62 ? $45 : $42;
 $63 = !($$$i$i <= $48);
 $64 = $63 ? $48 : $$$i$i;
 $65 = Math_fround($64 * Math_fround(0.150000005960464477539));
 $66 = Math_fround($65 + $inflation);
 HEAPF32[$inflationV>>2] = $66;
 $67 = Math_fround($42 + $66);
 HEAPF32[$40>>2] = $67;
 $68 = Math_fround($45 + $66);
 HEAPF32[$43>>2] = $68;
 $69 = Math_fround($48 + $66);
 HEAPF32[$46>>2] = $69;
 $70 = (($boxV) + 64|0);
 $71 = (($boxV) + 80|0);
 ;HEAP32[$boxV+0>>2]=0|0;HEAP32[$boxV+4>>2]=0|0;HEAP32[$boxV+8>>2]=0|0;HEAP32[$boxV+12>>2]=0|0;
 HEAP32[$71>>2] = 3;
 $72 = (($boxV) + 16|0);
 $73 = (($boxV) + 20|0);
 ;HEAP32[$73+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
 $74 = (($boxV) + 32|0);
 $75 = (($boxV) + 36|0);
 $76 = (($boxV) + 48|0);
 HEAPF32[$76>>2] = Math_fround(0.0);
 $77 = (($boxV) + 52|0);
 ;HEAP32[$77+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$70+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$70+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$70+12>>2]=HEAP32[$0+12>>2]|0;
 $78 = (($boxV) + 144|0);
 HEAPF32[$78>>2] = $42;
 $79 = (($boxV) + 148|0);
 HEAPF32[$79>>2] = $45;
 $80 = (($boxV) + 152|0);
 HEAPF32[$80>>2] = $48;
 $81 = (($boxV) + 156|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 $82 = !($42 >= $45);
 $$$i23$i$i$i = $82 ? $45 : $42;
 $83 = !($$$i23$i$i$i >= $48);
 $84 = $83 ? $48 : $$$i23$i$i$i;
 $85 = Math_fround($84 * Math_fround(0.0299999993294477462769));
 $86 = $65 > $85;
 $$$i12$i$i$i = $86 ? $65 : $85;
 $87 = $64 > $$$i12$i$i$i;
 $$$i$i$i$i = $87 ? $$$i12$i$i$i : $64;
 HEAPF32[$72>>2] = $$$i$i$i$i;
 ;HEAP32[$73+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
 $88 = Math_fround($64 * Math_fround(0.0500000007450580596924));
 HEAPF32[$74>>2] = $88;
 ;HEAP32[$75+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$0+8>>2]|0;
 $89 = Math_fround(HEAPF32[$31>>2]);
 $90 = Math_fround(HEAPF32[$34>>2]);
 $91 = Math_fround(HEAPF32[$37>>2]);
 $92 = (($_box) + 48|0);
 __ZN5physx2Gu15PCMPolygonalBoxC2ERKNS_6PxVec3E($polyBox,$92);
 __ZNK5physx2Gu15PCMPolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($polyBox,$polyData);
 HEAPF32[$identity>>2] = Math_fround(1.0);
 $93 = (($identity) + 4|0);
 $94 = (($identity) + 20|0);
 ;HEAP32[$93+0>>2]=0|0;HEAP32[$93+4>>2]=0|0;HEAP32[$93+8>>2]=0|0;HEAP32[$93+12>>2]=0|0;
 HEAPF32[$94>>2] = Math_fround(1.0);
 $95 = (($identity) + 24|0);
 $96 = (($identity) + 40|0);
 ;HEAP32[$95+0>>2]=0|0;HEAP32[$95+4>>2]=0|0;HEAP32[$95+8>>2]=0|0;HEAP32[$95+12>>2]=0|0;
 HEAPF32[$96>>2] = Math_fround(1.0);
 $97 = (($identity) + 44|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 $98 = (($triMeshGeom) + 4|0);
 __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($meshToWorldSkew,$pose,$98);
 HEAPF32[$boxTransformV>>2] = $49;
 $99 = (($boxTransformV) + 4|0);
 HEAPF32[$99>>2] = $51;
 $100 = (($boxTransformV) + 8|0);
 HEAPF32[$100>>2] = $53;
 $101 = (($boxTransformV) + 12|0);
 HEAPF32[$101>>2] = $55;
 $102 = (($boxTransformV) + 16|0);
 HEAPF32[$102>>2] = $57;
 $103 = (($boxTransformV) + 20|0);
 HEAPF32[$103>>2] = $59;
 $104 = (($boxTransformV) + 24|0);
 HEAPF32[$104>>2] = $61;
 $105 = (($boxTransformV) + 28|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = (($tempContainer) + 4|0);
 $107 = (($boxMap) + 32|0);
 $108 = (($boxMap) + 36|0);
 $109 = (($boxMap) + 40|0);
 $110 = (($boxMap) + 44|0);
 $111 = (($boxMap) + 48|0);
 $112 = (($boxMap) + 16|0);
 $113 = Math_fround(HEAPF32[$meshToWorldSkew>>2]);
 $114 = (($meshToWorldSkew) + 4|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($meshToWorldSkew) + 8|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($meshToWorldSkew) + 12|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($meshToWorldSkew) + 16|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($meshToWorldSkew) + 20|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($meshToWorldSkew) + 24|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($meshToWorldSkew) + 28|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($meshToWorldSkew) + 32|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = (($meshToWorldSkew) + 36|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($meshToWorldSkew) + 40|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($meshToWorldSkew) + 44|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($meshToConvex) + 48|0);
 $137 = (($meshToConvex) + 52|0);
 $138 = (($meshToConvex) + 56|0);
 $139 = (($meshToConvex) + 60|0);
 $140 = (($meshToConvex) + 4|0);
 $141 = (($meshToConvex) + 8|0);
 $142 = (($meshToConvex) + 12|0);
 $143 = (($meshToConvex) + 16|0);
 $144 = (($meshToConvex) + 20|0);
 $145 = (($meshToConvex) + 24|0);
 $146 = (($meshToConvex) + 28|0);
 $147 = (($meshToConvex) + 32|0);
 $148 = (($meshToConvex) + 36|0);
 $149 = (($meshToConvex) + 40|0);
 $150 = (($meshToConvex) + 44|0);
 $151 = (($tempContainer) + 8|0);
 $152 = (($hit) + 40|0);
 $153 = (($hit) + 16|0);
 $154 = (($hit) + 20|0);
 $155 = (($hit) + 24|0);
 $156 = (($hit) + 28|0);
 $157 = (($hit) + 32|0);
 $158 = (($hit) + 36|0);
 $159 = (($hit) + 8|0);
 $160 = (($manifoldContacts) + 44|0);
 $161 = (($2) + 172|0);
 $162 = (($2) + 28|0);
 $163 = (($2) + 24|0);
 $168 = $89;$169 = $90;$170 = $91;$450 = Math_fround(0.0);$452 = Math_fround(0.0);$454 = Math_fround(0.0);$478 = 268435455;$479 = Math_fround(0.0);$480 = Math_fround(0.0);$481 = Math_fround(0.0);$482 = Math_fround(0.0);$483 = Math_fround(0.0);$484 = Math_fround(0.0);$485 = Math_fround(0.0);$486 = Math_fround(0.0);$487 = Math_fround(0.0);$foundInitial$0$off0230 = 0;$i$0229 = 0;
 while(1) {
  $164 = HEAP32[$106>>2]|0;
  $165 = ($164|0)==(0);
  if (!($165)) {
   HEAP32[$106>>2] = 0;
  }
  __ZL13midPhaseQueryRKN5physx22PxTriangleMeshGeometryERKNS_11PxTransformERNS_2Gu3BoxERNS6_9ContainerE($triMeshGeom,$pose,$box,$tempContainer);
  $166 = HEAP32[$106>>2]|0;
  $167 = ($166|0)==(0);
  if ($167) {
   $461 = $450;$463 = $452;$466 = $454;$474 = $479;$475 = $480;$476 = $481;$477 = $478;$foundInitial$2$off0 = $foundInitial$0$off0230;
   break;
  }
  HEAPF32[$102>>2] = $168;
  HEAPF32[$103>>2] = $169;
  HEAPF32[$104>>2] = $170;
  HEAPF32[$105>>2] = Math_fround(0.0);
  HEAP32[$107>>2] = $boxTransformV;
  HEAP32[$108>>2] = $identity;
  HEAP32[$109>>2] = $identity;
  HEAP8[$110>>0] = 1;
  HEAP32[$boxMap>>2] = ((546776 + 8|0));
  HEAP32[$111>>2] = $boxV;
  ;HEAP32[$112+0>>2]=0|0;HEAP32[$112+4>>2]=0|0;HEAP32[$112+8>>2]=0|0;HEAP32[$112+12>>2]=0|0;
  $171 = Math_fround(HEAPF32[$box>>2]);
  $172 = Math_fround(HEAPF32[$7>>2]);
  $173 = Math_fround(HEAPF32[$10>>2]);
  $174 = Math_fround(HEAPF32[$13>>2]);
  $175 = Math_fround(HEAPF32[$16>>2]);
  $176 = Math_fround(HEAPF32[$19>>2]);
  $177 = Math_fround(HEAPF32[$22>>2]);
  $178 = Math_fround(HEAPF32[$25>>2]);
  $179 = Math_fround(HEAPF32[$28>>2]);
  $180 = Math_fround(HEAPF32[$31>>2]);
  $181 = Math_fround(HEAPF32[$34>>2]);
  $182 = Math_fround(HEAPF32[$37>>2]);
  $183 = Math_fround(-$180);
  $184 = Math_fround(-$181);
  $185 = Math_fround(-$182);
  $186 = Math_fround($171 * $183);
  $187 = Math_fround($172 * $184);
  $188 = Math_fround($186 + $187);
  $189 = Math_fround($173 * $185);
  $190 = Math_fround($188 + $189);
  $191 = Math_fround($174 * $183);
  $192 = Math_fround($175 * $184);
  $193 = Math_fround($191 + $192);
  $194 = Math_fround($176 * $185);
  $195 = Math_fround($193 + $194);
  $196 = Math_fround($177 * $183);
  $197 = Math_fround($178 * $184);
  $198 = Math_fround($196 + $197);
  $199 = Math_fround($179 * $185);
  $200 = Math_fround($198 + $199);
  $201 = Math_fround($171 * $113);
  $202 = Math_fround($174 * $113);
  $203 = Math_fround($177 * $113);
  $204 = Math_fround($172 * $115);
  $205 = Math_fround($175 * $115);
  $206 = Math_fround($178 * $115);
  $207 = Math_fround($201 + $204);
  $208 = Math_fround($202 + $205);
  $209 = Math_fround($203 + $206);
  $210 = Math_fround($173 * $117);
  $211 = Math_fround($176 * $117);
  $212 = Math_fround($179 * $117);
  $213 = Math_fround($207 + $210);
  $214 = Math_fround($208 + $211);
  $215 = Math_fround($209 + $212);
  $216 = Math_fround($171 * $119);
  $217 = Math_fround($174 * $119);
  $218 = Math_fround($177 * $119);
  $219 = Math_fround($172 * $121);
  $220 = Math_fround($175 * $121);
  $221 = Math_fround($178 * $121);
  $222 = Math_fround($216 + $219);
  $223 = Math_fround($217 + $220);
  $224 = Math_fround($218 + $221);
  $225 = Math_fround($173 * $123);
  $226 = Math_fround($176 * $123);
  $227 = Math_fround($179 * $123);
  $228 = Math_fround($222 + $225);
  $229 = Math_fround($223 + $226);
  $230 = Math_fround($224 + $227);
  $231 = Math_fround($171 * $125);
  $232 = Math_fround($174 * $125);
  $233 = Math_fround($177 * $125);
  $234 = Math_fround($172 * $127);
  $235 = Math_fround($175 * $127);
  $236 = Math_fround($178 * $127);
  $237 = Math_fround($231 + $234);
  $238 = Math_fround($232 + $235);
  $239 = Math_fround($233 + $236);
  $240 = Math_fround($173 * $129);
  $241 = Math_fround($176 * $129);
  $242 = Math_fround($179 * $129);
  $243 = Math_fround($237 + $240);
  $244 = Math_fround($238 + $241);
  $245 = Math_fround($239 + $242);
  $246 = Math_fround($171 * $131);
  $247 = Math_fround($174 * $131);
  $248 = Math_fround($177 * $131);
  $249 = Math_fround($172 * $133);
  $250 = Math_fround($175 * $133);
  $251 = Math_fround($178 * $133);
  $252 = Math_fround($246 + $249);
  $253 = Math_fround($247 + $250);
  $254 = Math_fround($248 + $251);
  $255 = Math_fround($173 * $135);
  $256 = Math_fround($176 * $135);
  $257 = Math_fround($179 * $135);
  $258 = Math_fround($252 + $255);
  $259 = Math_fround($253 + $256);
  $260 = Math_fround($254 + $257);
  $261 = Math_fround($190 + $258);
  $262 = Math_fround($195 + $259);
  $263 = Math_fround($200 + $260);
  HEAPF32[$136>>2] = $261;
  HEAPF32[$137>>2] = $262;
  HEAPF32[$138>>2] = $263;
  HEAPF32[$139>>2] = Math_fround(0.0);
  HEAPF32[$meshToConvex>>2] = $213;
  HEAPF32[$140>>2] = $214;
  HEAPF32[$141>>2] = $215;
  HEAPF32[$142>>2] = Math_fround(0.0);
  HEAPF32[$143>>2] = $228;
  HEAPF32[$144>>2] = $229;
  HEAPF32[$145>>2] = $230;
  HEAPF32[$146>>2] = Math_fround(0.0);
  HEAPF32[$147>>2] = $243;
  HEAPF32[$148>>2] = $244;
  HEAPF32[$149>>2] = $245;
  HEAPF32[$150>>2] = Math_fround(0.0);
  $264 = HEAP32[$151>>2]|0;
  $265 = (($166) + 31)|0;
  ;HEAP32[$mtd$sroa$1+0>>2]=HEAP32[$$sroa$173+0>>2]|0;HEAP32[$mtd$sroa$1+4>>2]=HEAP32[$$sroa$173+4>>2]|0;HEAP32[$mtd$sroa$1+8>>2]=HEAP32[$$sroa$173+8>>2]|0;
  $266 = $265 >>> 5;
  $267 = ($266|0)==(0);
  if ($267) {
   $461 = $450;$463 = $452;$466 = $454;$474 = $479;$475 = $480;$476 = $481;$477 = $478;$foundInitial$2$off0 = $foundInitial$0$off0230;
   break;
  }
  $268 = $166 ^ -1;
  $488 = Math_fround(3.40282346638528859812E+38);$489 = $478;$490 = $482;$491 = $483;$492 = $484;$493 = $485;$494 = $486;$495 = $487;$a$0217 = 0;$hadContacts$0$off0216 = 0;$indvars$iv = $268;
  while(1) {
   $269 = ($indvars$iv>>>0)>(4294967263);
   $indvars$iv$op = $indvars$iv ^ -1;
   $270 = $269 ? $indvars$iv$op : 32;
   $271 = $a$0217 << 5;
   $272 = (($166) - ($271))|0;
   $273 = ($272>>>0)<(32);
   $274 = $273 ? $272 : 32;
   $275 = ($274|0)==(0);
   if ($275) {
    ;HEAP32[$deepestPen$sroa$1$i+0>>2]=HEAP32[$mtd$sroa$1+0>>2]|0;HEAP32[$deepestPen$sroa$1$i+4>>2]=HEAP32[$mtd$sroa$1+4>>2]|0;HEAP32[$deepestPen$sroa$1$i+8>>2]=HEAP32[$mtd$sroa$1+8>>2]|0;
    $$lcssa$i4$lcssa$i = $488;$360 = $489;$369 = $490;$371 = $491;$373 = $492;$407 = $493;$409 = $494;$411 = $495;$hadContacts$0$off0$lcssa$i = 0;
   } else {
    $k$0200 = 0;
    while(1) {
     $276 = (($k$0200) + ($271))|0;
     $277 = (($264) + ($276<<2)|0);
     $278 = HEAP32[$277>>2]|0;
     $279 = HEAP8[$161>>0]|0;
     $280 = $279 & 2;
     $281 = ($280<<24>>24)==(0);
     $282 = HEAP32[$162>>2]|0;
     if ($281) {
      $292 = (($282) + (($278*12)|0)|0);
      $293 = HEAP32[$292>>2]|0;
      $294 = ((($282) + (($278*12)|0)|0) + 4|0);
      $295 = HEAP32[$294>>2]|0;
      $296 = ((($282) + (($278*12)|0)|0) + 8|0);
      $297 = HEAP32[$296>>2]|0;
      $vref0$0$i = $293;$vref1$0$i = $295;$vref2$0$i = $297;
     } else {
      $283 = (($282) + (($278*6)|0)|0);
      $284 = HEAP16[$283>>1]|0;
      $285 = $284&65535;
      $286 = ((($282) + (($278*6)|0)|0) + 2|0);
      $287 = HEAP16[$286>>1]|0;
      $288 = $287&65535;
      $289 = ((($282) + (($278*6)|0)|0) + 4|0);
      $290 = HEAP16[$289>>1]|0;
      $291 = $290&65535;
      $vref0$0$i = $285;$vref1$0$i = $288;$vref2$0$i = $291;
     }
     $298 = HEAP32[$163>>2]|0;
     $299 = (($298) + (($vref0$0$i*12)|0)|0);
     $300 = Math_fround(HEAPF32[$299>>2]);
     $301 = (($triangles) + (($k$0200*40)|0)|0);
     HEAPF32[$301>>2] = $300;
     $302 = ((($298) + (($vref0$0$i*12)|0)|0) + 4|0);
     $303 = Math_fround(HEAPF32[$302>>2]);
     $304 = ((($triangles) + (($k$0200*40)|0)|0) + 4|0);
     HEAPF32[$304>>2] = $303;
     $305 = ((($298) + (($vref0$0$i*12)|0)|0) + 8|0);
     $306 = Math_fround(HEAPF32[$305>>2]);
     $307 = ((($triangles) + (($k$0200*40)|0)|0) + 8|0);
     HEAPF32[$307>>2] = $306;
     $308 = (($298) + (($vref1$0$i*12)|0)|0);
     $309 = Math_fround(HEAPF32[$308>>2]);
     $310 = ((($triangles) + (($k$0200*40)|0)|0) + 12|0);
     HEAPF32[$310>>2] = $309;
     $311 = ((($298) + (($vref1$0$i*12)|0)|0) + 4|0);
     $312 = Math_fround(HEAPF32[$311>>2]);
     $313 = ((($triangles) + (($k$0200*40)|0)|0) + 16|0);
     HEAPF32[$313>>2] = $312;
     $314 = ((($298) + (($vref1$0$i*12)|0)|0) + 8|0);
     $315 = Math_fround(HEAPF32[$314>>2]);
     $316 = ((($triangles) + (($k$0200*40)|0)|0) + 20|0);
     HEAPF32[$316>>2] = $315;
     $317 = (($298) + (($vref2$0$i*12)|0)|0);
     $318 = Math_fround(HEAPF32[$317>>2]);
     $319 = ((($triangles) + (($k$0200*40)|0)|0) + 24|0);
     HEAPF32[$319>>2] = $318;
     $320 = ((($298) + (($vref2$0$i*12)|0)|0) + 4|0);
     $321 = Math_fround(HEAPF32[$320>>2]);
     $322 = ((($triangles) + (($k$0200*40)|0)|0) + 28|0);
     HEAPF32[$322>>2] = $321;
     $323 = ((($298) + (($vref2$0$i*12)|0)|0) + 8|0);
     $324 = Math_fround(HEAPF32[$323>>2]);
     $325 = ((($triangles) + (($k$0200*40)|0)|0) + 32|0);
     HEAPF32[$325>>2] = $324;
     $326 = (($4) + ($278)|0);
     $327 = HEAP8[$326>>0]|0;
     $328 = ((($triangles) + (($k$0200*40)|0)|0) + 36|0);
     HEAP8[$328>>0] = $327;
     $329 = (($k$0200) + 1)|0;
     $exitcond = ($329|0)==($270|0);
     if ($exitcond) {
      break;
     } else {
      $k$0200 = $329;
     }
    }
    ;HEAP32[$deepestPen$sroa$1$i+0>>2]=HEAP32[$mtd$sroa$1+0>>2]|0;HEAP32[$deepestPen$sroa$1$i+4>>2]=HEAP32[$mtd$sroa$1+4>>2]|0;HEAP32[$deepestPen$sroa$1$i+8>>2]=HEAP32[$mtd$sroa$1+8>>2]|0;
    if ($275) {
     $$lcssa$i4$lcssa$i = $488;$360 = $489;$369 = $490;$371 = $491;$373 = $492;$407 = $493;$409 = $494;$411 = $495;$hadContacts$0$off0$lcssa$i = 0;
    } else {
     $$lcssa$i45$i = $488;$496 = $495;$497 = $494;$498 = $493;$499 = $492;$500 = $491;$501 = $490;$502 = $489;$hadContacts$0$off07$i = 0;$j$06$i = 0;
     while(1) {
      HEAP32[$numContacts>>2] = 0;
      $330 = ((($triangles) + (($j$06$i*40)|0)|0) + 36|0);
      $331 = HEAP8[$330>>0]|0;
      $332 = (($triangles) + (($j$06$i*40)|0)|0);
      $333 = (($j$06$i) + ($271))|0;
      (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration15processTriangleERKNS0_13PolygonalDataEPNS0_12SupportLocalEPKNS_6PxVec3EjhRKNS_6shdfnd3aos6FloatVEbRKNSB_12PsTransformVERKNSB_15PsMatTransformVEPNS0_21MeshPersistentContactERj($polyData,$boxMap,$332,$333,$331,$inflationV,$isDoubleSided,$boxTransformV,$meshToConvex,$manifoldContacts,$numContacts)|0);
      $334 = HEAP32[$numContacts>>2]|0;
      $335 = ($334|0)==(0);
      if ($335) {
       $$lcssa$i3$i = $$lcssa$i45$i;$503 = $496;$504 = $497;$505 = $498;$506 = $499;$507 = $500;$508 = $501;$509 = $502;$hadContacts$1$off0$i = $hadContacts$0$off07$i;
      } else {
       $336 = Math_fround(HEAPF32[$160>>2]);
       $337 = ($334>>>0)>(1);
       if ($337) {
        $341 = $336;$index$030$i$i = 0;$k$031$i$i = 1;
        while(1) {
         $338 = ((($manifoldContacts) + ($k$031$i$i<<6)|0) + 44|0);
         $339 = Math_fround(HEAPF32[$338>>2]);
         $340 = $341 > $339;
         if ($340) {
          ;HEAP32[$0+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
          $510 = $339;$index$1$i$i = $k$031$i$i;
         } else {
          $510 = $341;$index$1$i$i = $index$030$i$i;
         }
         $342 = (($k$031$i$i) + 1)|0;
         $exitcond$i$i = ($342|0)==($334|0);
         if ($exitcond$i$i) {
          $$lcssa$i$i = $510;$index$0$lcssa$i$i = $index$1$i$i;
          break;
         } else {
          $341 = $510;$index$030$i$i = $index$1$i$i;$k$031$i$i = $342;
         }
        }
       } else {
        $$lcssa$i$i = $336;$index$0$lcssa$i$i = 0;
       }
       $343 = $$lcssa$i45$i > $$lcssa$i$i;
       if ($343) {
        ;HEAP32[$deepestPen$sroa$1$i+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$deepestPen$sroa$1$i+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$deepestPen$sroa$1$i+8>>2]=HEAP32[$0+8>>2]|0;
        $344 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 32|0);
        $345 = Math_fround(HEAPF32[$344>>2]);
        $346 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 36|0);
        $347 = Math_fround(HEAPF32[$346>>2]);
        $348 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 40|0);
        $349 = Math_fround(HEAPF32[$348>>2]);
        $350 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 16|0);
        $351 = Math_fround(HEAPF32[$350>>2]);
        $352 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 20|0);
        $353 = Math_fround(HEAPF32[$352>>2]);
        $354 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 24|0);
        $355 = Math_fround(HEAPF32[$354>>2]);
        $$lcssa$i3$i = $$lcssa$i$i;$503 = $355;$504 = $353;$505 = $351;$506 = $349;$507 = $347;$508 = $345;$509 = $333;$hadContacts$1$off0$i = 1;
       } else {
        $$lcssa$i3$i = $$lcssa$i45$i;$503 = $496;$504 = $497;$505 = $498;$506 = $499;$507 = $500;$508 = $501;$509 = $502;$hadContacts$1$off0$i = 1;
       }
      }
      $356 = (($j$06$i) + 1)|0;
      $exitcond$i = ($356|0)==($274|0);
      if ($exitcond$i) {
       $$lcssa$i4$lcssa$i = $$lcssa$i3$i;$360 = $509;$369 = $508;$371 = $507;$373 = $506;$407 = $505;$409 = $504;$411 = $503;$hadContacts$0$off0$lcssa$i = $hadContacts$1$off0$i;
       break;
      } else {
       $$lcssa$i45$i = $$lcssa$i3$i;$496 = $503;$497 = $504;$498 = $505;$499 = $506;$500 = $507;$501 = $508;$502 = $509;$hadContacts$0$off07$i = $hadContacts$1$off0$i;$j$06$i = $356;
      }
     }
    }
   }
   ;HEAP32[$mtd$sroa$1+0>>2]=HEAP32[$deepestPen$sroa$1$i+0>>2]|0;HEAP32[$mtd$sroa$1+4>>2]=HEAP32[$deepestPen$sroa$1$i+4>>2]|0;HEAP32[$mtd$sroa$1+8>>2]=HEAP32[$deepestPen$sroa$1$i+8>>2]|0;
   $$hadContacts$0$off0 = $hadContacts$0$off0$lcssa$i | $hadContacts$0$off0216;
   $357 = (($a$0217) + 1)|0;
   $358 = ($357>>>0)<($266>>>0);
   $indvars$iv$next = (($indvars$iv) + 32)|0;
   if ($358) {
    $488 = $$lcssa$i4$lcssa$i;$489 = $360;$490 = $369;$491 = $371;$492 = $373;$493 = $407;$494 = $409;$495 = $411;$a$0217 = $357;$hadContacts$0$off0216 = $$hadContacts$0$off0;$indvars$iv = $indvars$iv$next;
   } else {
    break;
   }
  }
  if (!($$hadContacts$0$off0)) {
   $461 = $450;$463 = $452;$466 = $454;$474 = $479;$475 = $480;$476 = $481;$477 = $360;$foundInitial$2$off0 = $foundInitial$0$off0230;
   break;
  }
  $359 = (($264) + ($360<<2)|0);
  $361 = HEAP32[$359>>2]|0;
  $362 = Math_fround(HEAPF32[$boxTransformV>>2]);
  $363 = Math_fround(HEAPF32[$99>>2]);
  $364 = Math_fround(HEAPF32[$100>>2]);
  $365 = Math_fround(HEAPF32[$101>>2]);
  $366 = Math_fround($365 * $365);
  $367 = Math_fround($366 + Math_fround(-0.5));
  $368 = Math_fround($369 * $367);
  $370 = Math_fround($371 * $367);
  $372 = Math_fround($373 * $367);
  $374 = Math_fround($373 * $363);
  $375 = Math_fround($371 * $364);
  $376 = Math_fround($374 - $375);
  $377 = Math_fround($369 * $364);
  $378 = Math_fround($373 * $362);
  $379 = Math_fround($377 - $378);
  $380 = Math_fround($371 * $362);
  $381 = Math_fround($369 * $363);
  $382 = Math_fround($380 - $381);
  $383 = Math_fround($365 * $376);
  $384 = Math_fround($365 * $379);
  $385 = Math_fround($365 * $382);
  $386 = Math_fround($383 + $368);
  $387 = Math_fround($384 + $370);
  $388 = Math_fround($385 + $372);
  $389 = Math_fround($369 * $362);
  $390 = Math_fround($371 * $363);
  $391 = Math_fround($389 + $390);
  $392 = Math_fround($373 * $364);
  $393 = Math_fround($391 + $392);
  $394 = Math_fround($362 * $393);
  $395 = Math_fround($363 * $393);
  $396 = Math_fround($364 * $393);
  $397 = Math_fround($394 + $386);
  $398 = Math_fround($395 + $387);
  $399 = Math_fround($396 + $388);
  $400 = Math_fround($397 * Math_fround(2.0));
  $401 = Math_fround($398 * Math_fround(2.0));
  $402 = Math_fround($399 * Math_fround(2.0));
  $403 = Math_fround(HEAPF32[$102>>2]);
  $404 = Math_fround(HEAPF32[$103>>2]);
  $405 = Math_fround(HEAPF32[$104>>2]);
  $406 = Math_fround($407 * $367);
  $408 = Math_fround($409 * $367);
  $410 = Math_fround($411 * $367);
  $412 = Math_fround($411 * $363);
  $413 = Math_fround($409 * $364);
  $414 = Math_fround($412 - $413);
  $415 = Math_fround($407 * $364);
  $416 = Math_fround($411 * $362);
  $417 = Math_fround($415 - $416);
  $418 = Math_fround($409 * $362);
  $419 = Math_fround($407 * $363);
  $420 = Math_fround($418 - $419);
  $421 = Math_fround($365 * $414);
  $422 = Math_fround($365 * $417);
  $423 = Math_fround($365 * $420);
  $424 = Math_fround($421 + $406);
  $425 = Math_fround($422 + $408);
  $426 = Math_fround($423 + $410);
  $427 = Math_fround($407 * $362);
  $428 = Math_fround($409 * $363);
  $429 = Math_fround($427 + $428);
  $430 = Math_fround($411 * $364);
  $431 = Math_fround($429 + $430);
  $432 = Math_fround($362 * $431);
  $433 = Math_fround($363 * $431);
  $434 = Math_fround($364 * $431);
  $435 = Math_fround($432 + $424);
  $436 = Math_fround($433 + $425);
  $437 = Math_fround($434 + $426);
  $438 = Math_fround($435 * Math_fround(2.0));
  $439 = Math_fround($436 * Math_fround(2.0));
  $440 = Math_fround($437 * Math_fround(2.0));
  $441 = Math_fround($403 + $438);
  $442 = Math_fround($404 + $439);
  $443 = Math_fround($405 + $440);
  $444 = !($$lcssa$i4$lcssa$i <= Math_fround(0.0));
  if ($444) {
   label = 25;
   break;
  }
  $446 = Math_fround($$lcssa$i4$lcssa$i * $400);
  $447 = Math_fround($$lcssa$i4$lcssa$i * $401);
  $448 = Math_fround($$lcssa$i4$lcssa$i * $402);
  $449 = Math_fround($450 - $446);
  $451 = Math_fround($452 - $447);
  $453 = Math_fround($454 - $448);
  $455 = Math_fround($168 - $446);
  $456 = Math_fround($169 - $447);
  $457 = Math_fround($170 - $448);
  HEAPF32[$31>>2] = $455;
  HEAPF32[$34>>2] = $456;
  HEAPF32[$37>>2] = $457;
  $458 = (($i$0229) + 1)|0;
  $459 = ($458>>>0)<(4);
  if ($459) {
   $168 = $455;$169 = $456;$170 = $457;$450 = $449;$452 = $451;$454 = $453;$478 = $361;$479 = $441;$480 = $442;$481 = $443;$482 = $369;$483 = $371;$484 = $373;$485 = $407;$486 = $409;$487 = $411;$foundInitial$0$off0230 = 1;$i$0229 = $458;
  } else {
   $461 = $449;$463 = $451;$466 = $453;$474 = $441;$475 = $442;$476 = $443;$477 = $361;$foundInitial$2$off0 = 1;
   break;
  }
 }
 if ((label|0) == 25) {
  $445 = ($i$0229|0)==(0);
  if ($445) {
   HEAPF32[$152>>2] = Math_fround(0.0);
   HEAPF32[$153>>2] = $441;
   HEAPF32[$154>>2] = $442;
   HEAPF32[$155>>2] = $443;
   HEAPF32[$156>>2] = $400;
   HEAPF32[$157>>2] = $401;
   HEAPF32[$158>>2] = $402;
   HEAP32[$159>>2] = $361;
   $$2 = 1;
   __ZN5physx2Gu9ContainerD2Ev($tempContainer);
   STACKTOP = sp;return ($$2|0);
  } else {
   $461 = $450;$463 = $452;$466 = $454;$474 = $441;$475 = $442;$476 = $443;$477 = $361;$foundInitial$2$off0 = 1;
  }
 }
 $460 = Math_fround($461 * $461);
 $462 = Math_fround($463 * $463);
 $464 = Math_fround($462 + $460);
 $465 = Math_fround($466 * $466);
 $467 = Math_fround($465 + $464);
 $468 = (Math_fround(Math_sqrt((Math_fround($467)))));
 $469 = Math_fround(Math_fround(1.0) / $468);
 if (!($foundInitial$2$off0)) {
  $$2 = 0;
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return ($$2|0);
 }
 $470 = Math_fround(-$468);
 $471 = Math_fround($466 * $469);
 $472 = Math_fround($463 * $469);
 $473 = Math_fround($461 * $469);
 HEAPF32[$152>>2] = $470;
 HEAPF32[$153>>2] = $474;
 HEAPF32[$154>>2] = $475;
 HEAPF32[$155>>2] = $476;
 HEAPF32[$156>>2] = $473;
 HEAPF32[$157>>2] = $472;
 HEAPF32[$158>>2] = $471;
 HEAP32[$159>>2] = $477;
 $$2 = 1;
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return ($$2|0);
}
function __ZN5physx2Gu25computeBox_HeightFieldMTDERKNS_21PxHeightFieldGeometryERKNS_11PxTransformERKNS0_3BoxES6_ffbjRNS_10PxSweepHitE($heightFieldGeom,$pose,$_box,$boxTransform,$inflation,$distance,$isDoubleSided,$flags,$hit) {
 $heightFieldGeom = $heightFieldGeom|0;
 $pose = $pose|0;
 $_box = $_box|0;
 $boxTransform = $boxTransform|0;
 $inflation = Math_fround($inflation);
 $distance = Math_fround($distance);
 $isDoubleSided = $isDoubleSided|0;
 $flags = $flags|0;
 $hit = $hit|0;
 var $$$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$2 = 0, $$hadContacts$0$off0 = 0, $$lcssa$i$i = Math_fround(0), $$lcssa$i3$i = Math_fround(0), $$lcssa$i4$lcssa$i = Math_fround(0), $$lcssa$i45$i = Math_fround(0), $$sroa$173 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0;
 var $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0);
 var $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0);
 var $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0);
 var $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0;
 var $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0);
 var $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0);
 var $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0);
 var $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0);
 var $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0;
 var $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0);
 var $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0);
 var $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0;
 var $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0);
 var $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0);
 var $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = 0, $48 = 0, $480 = 0, $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0);
 var $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = 0, $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0);
 var $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = 0, $513 = 0, $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0;
 var $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = 0, $538 = Math_fround(0);
 var $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0;
 var $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $a$0221 = 0, $bounds = 0, $box = 0;
 var $boxMap = 0, $boxTransformV = 0, $boxV = 0, $deepest$sroa$1$i$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i$i = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0), $foundInitial$0$off0234 = 0, $foundInitial$2$off0 = 0, $hadContacts$0$off0$lcssa$i = 0, $hadContacts$0$off0220 = 0;
 var $hadContacts$0$off07$i = 0, $hadContacts$1$off0$i = 0, $hfUtil = 0, $i$0233 = 0, $identity = 0, $index$0$lcssa$i$i = 0, $index$030$i$i = 0, $index$1$i$i = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$op = 0, $inflationV = 0, $j$06$i = 0, $k$0204 = 0, $k$031$i$i = 0, $manifoldContacts = 0, $meshToConvex = 0, $mtd$sroa$1 = 0, $numContacts = 0, $pen$sroa$1$i$i = 0;
 var $polyBox = 0, $polyData = 0, $tempContainer = 0, $triangles = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6768|0;
 $0 = sp + 224|0;
 $deepest$sroa$1$i$i = sp + 6680|0;
 $pen$sroa$1$i$i = sp + 6668|0;
 $manifoldContacts = sp + 400|0;
 $numContacts = sp + 6664|0;
 $tempContainer = sp + 6648|0;
 $hfUtil = sp + 6628|0;
 $box = sp + 6568|0;
 $inflationV = sp + 208|0;
 $boxV = sp + 48|0;
 $polyData = sp + 6696|0;
 $polyBox = sp + 5024|0;
 $identity = sp;
 $boxTransformV = sp + 304|0;
 $mtd$sroa$1 = sp + 6528|0;
 $bounds = sp + 6544|0;
 $boxMap = sp + 240|0;
 $meshToConvex = sp + 336|0;
 $$sroa$173 = sp + 4496|0;
 $triangles = sp + 5248|0;
 HEAP32[$numContacts>>2] = 0;
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $1 = sp + 4512|0;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,128,$1,1);
 $2 = (($hfUtil) + 12|0);
 $3 = (($heightFieldGeom) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = (($hfUtil) + 16|0);
 HEAP32[$5>>2] = $heightFieldGeom;
 $6 = (($heightFieldGeom) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(Math_fround(1.0) / $7);
 $9 = (($hfUtil) + 4|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($heightFieldGeom) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(Math_fround(1.0) / $11);
 HEAPF32[$hfUtil>>2] = $12;
 $13 = (($heightFieldGeom) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(Math_fround(1.0) / $14);
 $16 = (($hfUtil) + 8|0);
 HEAPF32[$16>>2] = $15;
 $17 = Math_fround(HEAPF32[$_box>>2]);
 HEAPF32[$box>>2] = $17;
 $18 = (($box) + 4|0);
 $19 = (($_box) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$18>>2] = $20;
 $21 = (($box) + 8|0);
 $22 = (($_box) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 HEAPF32[$21>>2] = $23;
 $24 = (($box) + 12|0);
 $25 = (($_box) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 HEAPF32[$24>>2] = $26;
 $27 = (($box) + 16|0);
 $28 = (($_box) + 16|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$27>>2] = $29;
 $30 = (($box) + 20|0);
 $31 = (($_box) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$30>>2] = $32;
 $33 = (($box) + 24|0);
 $34 = (($_box) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 HEAPF32[$33>>2] = $35;
 $36 = (($box) + 28|0);
 $37 = (($_box) + 28|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 HEAPF32[$36>>2] = $38;
 $39 = (($box) + 32|0);
 $40 = (($_box) + 32|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 HEAPF32[$39>>2] = $41;
 $42 = (($box) + 36|0);
 $43 = (($_box) + 36|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 HEAPF32[$42>>2] = $44;
 $45 = (($box) + 40|0);
 $46 = (($_box) + 40|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$45>>2] = $47;
 $48 = (($box) + 44|0);
 $49 = (($_box) + 44|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 HEAPF32[$48>>2] = $50;
 $51 = (($box) + 48|0);
 $52 = (($_box) + 48|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($box) + 52|0);
 $55 = (($_box) + 52|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($box) + 56|0);
 $58 = (($_box) + 56|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround(HEAPF32[$boxTransform>>2]);
 $61 = (($boxTransform) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($boxTransform) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($boxTransform) + 12|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($boxTransform) + 16|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($67) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($67) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = !($53 <= $56);
 $$$i$i = $73 ? $56 : $53;
 $74 = !($$$i$i <= $59);
 $75 = $74 ? $59 : $$$i$i;
 $76 = Math_fround($75 * Math_fround(0.150000005960464477539));
 $77 = Math_fround($76 + $inflation);
 HEAPF32[$inflationV>>2] = $77;
 $78 = Math_fround($53 + $77);
 HEAPF32[$51>>2] = $78;
 $79 = Math_fround($56 + $77);
 HEAPF32[$54>>2] = $79;
 $80 = Math_fround($59 + $77);
 HEAPF32[$57>>2] = $80;
 $81 = (($boxV) + 64|0);
 $82 = (($boxV) + 80|0);
 ;HEAP32[$boxV+0>>2]=0|0;HEAP32[$boxV+4>>2]=0|0;HEAP32[$boxV+8>>2]=0|0;HEAP32[$boxV+12>>2]=0|0;
 HEAP32[$82>>2] = 3;
 $83 = (($boxV) + 16|0);
 $84 = (($boxV) + 20|0);
 ;HEAP32[$84+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
 $85 = (($boxV) + 32|0);
 $86 = (($boxV) + 36|0);
 $87 = (($boxV) + 48|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($boxV) + 52|0);
 ;HEAP32[$88+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$81+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$81+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$81+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$81+12>>2]=HEAP32[$0+12>>2]|0;
 $89 = (($boxV) + 144|0);
 HEAPF32[$89>>2] = $53;
 $90 = (($boxV) + 148|0);
 HEAPF32[$90>>2] = $56;
 $91 = (($boxV) + 152|0);
 HEAPF32[$91>>2] = $59;
 $92 = (($boxV) + 156|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $93 = !($53 >= $56);
 $$$i23$i$i$i = $93 ? $56 : $53;
 $94 = !($$$i23$i$i$i >= $59);
 $95 = $94 ? $59 : $$$i23$i$i$i;
 $96 = Math_fround($95 * Math_fround(0.0299999993294477462769));
 $97 = $76 > $96;
 $$$i12$i$i$i = $97 ? $76 : $96;
 $98 = $75 > $$$i12$i$i$i;
 $$$i$i$i$i = $98 ? $$$i12$i$i$i : $75;
 HEAPF32[$83>>2] = $$$i$i$i$i;
 ;HEAP32[$84+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
 $99 = Math_fround($75 * Math_fround(0.0500000007450580596924));
 HEAPF32[$85>>2] = $99;
 ;HEAP32[$86+0>>2]=HEAP32[$deepest$sroa$1$i$i+0>>2]|0;HEAP32[$86+4>>2]=HEAP32[$deepest$sroa$1$i$i+4>>2]|0;HEAP32[$86+8>>2]=HEAP32[$deepest$sroa$1$i$i+8>>2]|0;
 $100 = Math_fround(HEAPF32[$42>>2]);
 $101 = Math_fround(HEAPF32[$45>>2]);
 $102 = Math_fround(HEAPF32[$48>>2]);
 $103 = (($_box) + 48|0);
 __ZN5physx2Gu15PCMPolygonalBoxC2ERKNS_6PxVec3E($polyBox,$103);
 __ZNK5physx2Gu15PCMPolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($polyBox,$polyData);
 HEAPF32[$identity>>2] = Math_fround(1.0);
 $104 = (($identity) + 4|0);
 $105 = (($identity) + 20|0);
 ;HEAP32[$104+0>>2]=0|0;HEAP32[$104+4>>2]=0|0;HEAP32[$104+8>>2]=0|0;HEAP32[$104+12>>2]=0|0;
 HEAPF32[$105>>2] = Math_fround(1.0);
 $106 = (($identity) + 24|0);
 $107 = (($identity) + 40|0);
 ;HEAP32[$106+0>>2]=0|0;HEAP32[$106+4>>2]=0|0;HEAP32[$106+8>>2]=0|0;HEAP32[$106+12>>2]=0|0;
 HEAPF32[$107>>2] = Math_fround(1.0);
 $108 = (($identity) + 44|0);
 HEAPF32[$108>>2] = Math_fround(0.0);
 $109 = Math_fround(HEAPF32[$pose>>2]);
 $110 = Math_fround($109 + $109);
 $111 = (($pose) + 4|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($112 + $112);
 $114 = (($pose) + 8|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($115 + $115);
 $117 = (($pose) + 12|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = Math_fround($110 * $118);
 $120 = Math_fround($113 * $118);
 $121 = Math_fround($118 * $116);
 $122 = Math_fround($109 * $110);
 $123 = Math_fround($109 * $113);
 $124 = Math_fround($109 * $116);
 $125 = Math_fround($112 * $113);
 $126 = Math_fround($112 * $116);
 $127 = Math_fround($115 * $116);
 $128 = Math_fround(Math_fround(1.0) - $125);
 $129 = Math_fround($128 - $127);
 $130 = Math_fround($123 + $121);
 $131 = Math_fround($124 - $120);
 $132 = Math_fround($123 - $121);
 $133 = Math_fround(Math_fround(1.0) - $122);
 $134 = Math_fround($133 - $127);
 $135 = Math_fround($126 + $119);
 $136 = Math_fround($124 + $120);
 $137 = Math_fround($126 - $119);
 $138 = Math_fround($133 - $125);
 $139 = (($pose) + 16|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($pose) + 20|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($pose) + 24|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 HEAPF32[$boxTransformV>>2] = $60;
 $145 = (($boxTransformV) + 4|0);
 HEAPF32[$145>>2] = $62;
 $146 = (($boxTransformV) + 8|0);
 HEAPF32[$146>>2] = $64;
 $147 = (($boxTransformV) + 12|0);
 HEAPF32[$147>>2] = $66;
 $148 = (($boxTransformV) + 16|0);
 HEAPF32[$148>>2] = $68;
 $149 = (($boxTransformV) + 20|0);
 HEAPF32[$149>>2] = $70;
 $150 = (($boxTransformV) + 24|0);
 HEAPF32[$150>>2] = $72;
 $151 = (($boxTransformV) + 28|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = (($tempContainer) + 4|0);
 $153 = (($0) + 4|0);
 $154 = (($0) + 8|0);
 $155 = (($0) + 12|0);
 $156 = (($bounds) + 4|0);
 $157 = (($bounds) + 8|0);
 $158 = (($bounds) + 12|0);
 $159 = (($bounds) + 16|0);
 $160 = (($bounds) + 20|0);
 $161 = (($0) + 4|0);
 $162 = (($boxMap) + 32|0);
 $163 = (($boxMap) + 36|0);
 $164 = (($boxMap) + 40|0);
 $165 = (($boxMap) + 44|0);
 $166 = (($boxMap) + 48|0);
 $167 = (($boxMap) + 16|0);
 $168 = (($meshToConvex) + 48|0);
 $169 = (($meshToConvex) + 52|0);
 $170 = (($meshToConvex) + 56|0);
 $171 = (($meshToConvex) + 60|0);
 $172 = (($meshToConvex) + 4|0);
 $173 = (($meshToConvex) + 8|0);
 $174 = (($meshToConvex) + 12|0);
 $175 = (($meshToConvex) + 16|0);
 $176 = (($meshToConvex) + 20|0);
 $177 = (($meshToConvex) + 24|0);
 $178 = (($meshToConvex) + 28|0);
 $179 = (($meshToConvex) + 32|0);
 $180 = (($meshToConvex) + 36|0);
 $181 = (($meshToConvex) + 40|0);
 $182 = (($meshToConvex) + 44|0);
 $183 = (($tempContainer) + 8|0);
 $184 = (($hit) + 40|0);
 $185 = (($hit) + 16|0);
 $186 = (($hit) + 20|0);
 $187 = (($hit) + 24|0);
 $188 = (($hit) + 28|0);
 $189 = (($hit) + 32|0);
 $190 = (($hit) + 36|0);
 $191 = (($hit) + 8|0);
 $192 = (($manifoldContacts) + 44|0);
 $251 = $100;$252 = $101;$253 = $102;$485 = Math_fround(0.0);$487 = Math_fround(0.0);$489 = Math_fround(0.0);$513 = 268435455;$514 = Math_fround(0.0);$515 = Math_fround(0.0);$516 = Math_fround(0.0);$517 = Math_fround(0.0);$518 = Math_fround(0.0);$519 = Math_fround(0.0);$520 = Math_fround(0.0);$521 = Math_fround(0.0);$522 = Math_fround(0.0);$foundInitial$0$off0234 = 0;$i$0233 = 0;
 while(1) {
  $193 = HEAP32[$152>>2]|0;
  $194 = ($193|0)==(0);
  if (!($194)) {
   HEAP32[$152>>2] = 0;
  }
  __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$box);
  $195 = Math_fround(HEAPF32[$0>>2]);
  $196 = Math_fround(HEAPF32[$153>>2]);
  $197 = Math_fround(HEAPF32[$154>>2]);
  $198 = Math_fround(HEAPF32[$155>>2]);
  $199 = Math_fround(HEAPF32[$42>>2]);
  $200 = Math_fround(HEAPF32[$45>>2]);
  $201 = Math_fround(HEAPF32[$48>>2]);
  $202 = Math_fround($195 + $195);
  $203 = Math_fround($196 + $196);
  $204 = Math_fround($197 + $197);
  $205 = Math_fround($195 * $202);
  $206 = Math_fround($196 * $203);
  $207 = Math_fround($197 * $204);
  $208 = Math_fround($202 * $196);
  $209 = Math_fround($202 * $197);
  $210 = Math_fround($202 * $198);
  $211 = Math_fround($203 * $197);
  $212 = Math_fround($203 * $198);
  $213 = Math_fround($204 * $198);
  $214 = Math_fround(Math_fround(1.0) - $206);
  $215 = Math_fround($214 - $207);
  $216 = Math_fround($208 + $213);
  $217 = Math_fround($209 - $212);
  $218 = Math_fround($208 - $213);
  $219 = Math_fround(Math_fround(1.0) - $205);
  $220 = Math_fround($219 - $207);
  $221 = Math_fround($211 + $210);
  $222 = Math_fround($209 + $212);
  $223 = Math_fround($211 - $210);
  $224 = Math_fround($219 - $206);
  $225 = Math_fround(HEAPF32[$51>>2]);
  $226 = Math_fround($215 * $225);
  $227 = Math_fround($216 * $225);
  $228 = Math_fround($217 * $225);
  $229 = Math_fround(HEAPF32[$54>>2]);
  $230 = Math_fround($218 * $229);
  $231 = Math_fround($220 * $229);
  $232 = Math_fround($221 * $229);
  $233 = Math_fround(HEAPF32[$57>>2]);
  $234 = Math_fround($222 * $233);
  $235 = Math_fround($223 * $233);
  $236 = Math_fround($224 * $233);
  $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($226)))));
  $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($230)))));
  $237 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
  $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($234)))));
  $238 = Math_fround($237 + $fabsf$i$i6$i$i);
  $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($227)))));
  $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($231)))));
  $239 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
  $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($235)))));
  $240 = Math_fround($239 + $fabsf$i$i3$i$i);
  $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($228)))));
  $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($232)))));
  $241 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
  $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($236)))));
  $242 = Math_fround($241 + $fabsf$i$i$i$i);
  $243 = Math_fround($199 - $238);
  $244 = Math_fround($200 - $240);
  $245 = Math_fround($201 - $242);
  $246 = Math_fround($199 + $238);
  $247 = Math_fround($200 + $240);
  $248 = Math_fround($201 + $242);
  HEAPF32[$bounds>>2] = $243;
  HEAPF32[$156>>2] = $244;
  HEAPF32[$157>>2] = $245;
  HEAPF32[$158>>2] = $246;
  HEAPF32[$159>>2] = $247;
  HEAPF32[$160>>2] = $248;
  HEAP32[$0>>2] = ((548560 + 8|0));
  HEAP32[$161>>2] = $tempContainer;
  (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$pose,$bounds,$flags,$0)|0);
  $249 = HEAP32[$152>>2]|0;
  $250 = ($249|0)==(0);
  if ($250) {
   $496 = $485;$498 = $487;$501 = $489;$509 = $514;$510 = $515;$511 = $516;$512 = $513;$foundInitial$2$off0 = $foundInitial$0$off0234;
   break;
  }
  HEAPF32[$148>>2] = $251;
  HEAPF32[$149>>2] = $252;
  HEAPF32[$150>>2] = $253;
  HEAPF32[$151>>2] = Math_fround(0.0);
  HEAP32[$162>>2] = $boxTransformV;
  HEAP32[$163>>2] = $identity;
  HEAP32[$164>>2] = $identity;
  HEAP8[$165>>0] = 1;
  HEAP32[$boxMap>>2] = ((546776 + 8|0));
  HEAP32[$166>>2] = $boxV;
  ;HEAP32[$167+0>>2]=0|0;HEAP32[$167+4>>2]=0|0;HEAP32[$167+8>>2]=0|0;HEAP32[$167+12>>2]=0|0;
  $254 = Math_fround(HEAPF32[$box>>2]);
  $255 = Math_fround(HEAPF32[$18>>2]);
  $256 = Math_fround(HEAPF32[$21>>2]);
  $257 = Math_fround(HEAPF32[$24>>2]);
  $258 = Math_fround(HEAPF32[$27>>2]);
  $259 = Math_fround(HEAPF32[$30>>2]);
  $260 = Math_fround(HEAPF32[$33>>2]);
  $261 = Math_fround(HEAPF32[$36>>2]);
  $262 = Math_fround(HEAPF32[$39>>2]);
  $263 = Math_fround(HEAPF32[$42>>2]);
  $264 = Math_fround(HEAPF32[$45>>2]);
  $265 = Math_fround(HEAPF32[$48>>2]);
  $266 = Math_fround(-$263);
  $267 = Math_fround(-$264);
  $268 = Math_fround(-$265);
  $269 = Math_fround($254 * $266);
  $270 = Math_fround($255 * $267);
  $271 = Math_fround($269 + $270);
  $272 = Math_fround($256 * $268);
  $273 = Math_fround($271 + $272);
  $274 = Math_fround($257 * $266);
  $275 = Math_fround($258 * $267);
  $276 = Math_fround($274 + $275);
  $277 = Math_fround($259 * $268);
  $278 = Math_fround($276 + $277);
  $279 = Math_fround($260 * $266);
  $280 = Math_fround($261 * $267);
  $281 = Math_fround($279 + $280);
  $282 = Math_fround($262 * $268);
  $283 = Math_fround($281 + $282);
  $284 = Math_fround($129 * $254);
  $285 = Math_fround($129 * $257);
  $286 = Math_fround($129 * $260);
  $287 = Math_fround($130 * $255);
  $288 = Math_fround($130 * $258);
  $289 = Math_fround($130 * $261);
  $290 = Math_fround($284 + $287);
  $291 = Math_fround($285 + $288);
  $292 = Math_fround($286 + $289);
  $293 = Math_fround($131 * $256);
  $294 = Math_fround($131 * $259);
  $295 = Math_fround($131 * $262);
  $296 = Math_fround($290 + $293);
  $297 = Math_fround($291 + $294);
  $298 = Math_fround($292 + $295);
  $299 = Math_fround($132 * $254);
  $300 = Math_fround($132 * $257);
  $301 = Math_fround($132 * $260);
  $302 = Math_fround($134 * $255);
  $303 = Math_fround($134 * $258);
  $304 = Math_fround($134 * $261);
  $305 = Math_fround($299 + $302);
  $306 = Math_fround($300 + $303);
  $307 = Math_fround($301 + $304);
  $308 = Math_fround($135 * $256);
  $309 = Math_fround($135 * $259);
  $310 = Math_fround($135 * $262);
  $311 = Math_fround($305 + $308);
  $312 = Math_fround($306 + $309);
  $313 = Math_fround($307 + $310);
  $314 = Math_fround($136 * $254);
  $315 = Math_fround($136 * $257);
  $316 = Math_fround($136 * $260);
  $317 = Math_fround($137 * $255);
  $318 = Math_fround($137 * $258);
  $319 = Math_fround($137 * $261);
  $320 = Math_fround($314 + $317);
  $321 = Math_fround($315 + $318);
  $322 = Math_fround($316 + $319);
  $323 = Math_fround($138 * $256);
  $324 = Math_fround($138 * $259);
  $325 = Math_fround($138 * $262);
  $326 = Math_fround($320 + $323);
  $327 = Math_fround($321 + $324);
  $328 = Math_fround($322 + $325);
  $329 = Math_fround($140 * $254);
  $330 = Math_fround($140 * $257);
  $331 = Math_fround($140 * $260);
  $332 = Math_fround($142 * $255);
  $333 = Math_fround($142 * $258);
  $334 = Math_fround($142 * $261);
  $335 = Math_fround($329 + $332);
  $336 = Math_fround($330 + $333);
  $337 = Math_fround($331 + $334);
  $338 = Math_fround($144 * $256);
  $339 = Math_fround($144 * $259);
  $340 = Math_fround($144 * $262);
  $341 = Math_fround($335 + $338);
  $342 = Math_fround($336 + $339);
  $343 = Math_fround($337 + $340);
  $344 = Math_fround($341 + $273);
  $345 = Math_fround($342 + $278);
  $346 = Math_fround($343 + $283);
  HEAPF32[$168>>2] = $344;
  HEAPF32[$169>>2] = $345;
  HEAPF32[$170>>2] = $346;
  HEAPF32[$171>>2] = Math_fround(0.0);
  HEAPF32[$meshToConvex>>2] = $296;
  HEAPF32[$172>>2] = $297;
  HEAPF32[$173>>2] = $298;
  HEAPF32[$174>>2] = Math_fround(0.0);
  HEAPF32[$175>>2] = $311;
  HEAPF32[$176>>2] = $312;
  HEAPF32[$177>>2] = $313;
  HEAPF32[$178>>2] = Math_fround(0.0);
  HEAPF32[$179>>2] = $326;
  HEAPF32[$180>>2] = $327;
  HEAPF32[$181>>2] = $328;
  HEAPF32[$182>>2] = Math_fround(0.0);
  $347 = HEAP32[$183>>2]|0;
  $348 = (($249) + 31)|0;
  ;HEAP32[$mtd$sroa$1+0>>2]=HEAP32[$$sroa$173+0>>2]|0;HEAP32[$mtd$sroa$1+4>>2]=HEAP32[$$sroa$173+4>>2]|0;HEAP32[$mtd$sroa$1+8>>2]=HEAP32[$$sroa$173+8>>2]|0;
  $349 = $348 >>> 5;
  $350 = ($349|0)==(0);
  if ($350) {
   $496 = $485;$498 = $487;$501 = $489;$509 = $514;$510 = $515;$511 = $516;$512 = $513;$foundInitial$2$off0 = $foundInitial$0$off0234;
   break;
  }
  $351 = $249 ^ -1;
  $523 = Math_fround(3.40282346638528859812E+38);$524 = $513;$525 = $517;$526 = $518;$527 = $519;$528 = $520;$529 = $521;$530 = $522;$a$0221 = 0;$hadContacts$0$off0220 = 0;$indvars$iv = $351;
  while(1) {
   $352 = ($indvars$iv>>>0)>(4294967263);
   $indvars$iv$op = $indvars$iv ^ -1;
   $353 = $352 ? $indvars$iv$op : 32;
   $354 = $a$0221 << 5;
   $355 = (($249) - ($354))|0;
   $356 = ($355>>>0)<(32);
   $357 = $356 ? $355 : 32;
   $358 = ($357|0)==(0);
   if ($358) {
    ;HEAP32[$0+0>>2]=HEAP32[$mtd$sroa$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$mtd$sroa$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$mtd$sroa$1+8>>2]|0;
    $$lcssa$i4$lcssa$i = $523;$395 = $524;$404 = $525;$406 = $526;$408 = $527;$442 = $528;$444 = $529;$446 = $530;$hadContacts$0$off0$lcssa$i = 0;
   } else {
    $k$0204 = 0;
    while(1) {
     $359 = (($k$0204) + ($354))|0;
     $360 = (($347) + ($359<<2)|0);
     $361 = HEAP32[$360>>2]|0;
     $362 = (($triangles) + (($k$0204*40)|0)|0);
     (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($hfUtil,$pose,$362,0,0,$361,0,0)|0);
     $363 = ((($triangles) + (($k$0204*40)|0)|0) + 36|0);
     HEAP8[$363>>0] = 56;
     $364 = (($k$0204) + 1)|0;
     $exitcond = ($364|0)==($353|0);
     if ($exitcond) {
      break;
     } else {
      $k$0204 = $364;
     }
    }
    ;HEAP32[$0+0>>2]=HEAP32[$mtd$sroa$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$mtd$sroa$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$mtd$sroa$1+8>>2]|0;
    if ($358) {
     $$lcssa$i4$lcssa$i = $523;$395 = $524;$404 = $525;$406 = $526;$408 = $527;$442 = $528;$444 = $529;$446 = $530;$hadContacts$0$off0$lcssa$i = 0;
    } else {
     $$lcssa$i45$i = $523;$531 = $530;$532 = $529;$533 = $528;$534 = $527;$535 = $526;$536 = $525;$537 = $524;$hadContacts$0$off07$i = 0;$j$06$i = 0;
     while(1) {
      HEAP32[$numContacts>>2] = 0;
      $365 = ((($triangles) + (($j$06$i*40)|0)|0) + 36|0);
      $366 = HEAP8[$365>>0]|0;
      $367 = (($triangles) + (($j$06$i*40)|0)|0);
      $368 = (($j$06$i) + ($354))|0;
      (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration15processTriangleERKNS0_13PolygonalDataEPNS0_12SupportLocalEPKNS_6PxVec3EjhRKNS_6shdfnd3aos6FloatVEbRKNSB_12PsTransformVERKNSB_15PsMatTransformVEPNS0_21MeshPersistentContactERj($polyData,$boxMap,$367,$368,$366,$inflationV,$isDoubleSided,$boxTransformV,$meshToConvex,$manifoldContacts,$numContacts)|0);
      $369 = HEAP32[$numContacts>>2]|0;
      $370 = ($369|0)==(0);
      if ($370) {
       $$lcssa$i3$i = $$lcssa$i45$i;$538 = $531;$539 = $532;$540 = $533;$541 = $534;$542 = $535;$543 = $536;$544 = $537;$hadContacts$1$off0$i = $hadContacts$0$off07$i;
      } else {
       $371 = Math_fround(HEAPF32[$192>>2]);
       $372 = ($369>>>0)>(1);
       if ($372) {
        $376 = $371;$index$030$i$i = 0;$k$031$i$i = 1;
        while(1) {
         $373 = ((($manifoldContacts) + ($k$031$i$i<<6)|0) + 44|0);
         $374 = Math_fround(HEAPF32[$373>>2]);
         $375 = $376 > $374;
         if ($375) {
          ;HEAP32[$deepest$sroa$1$i$i+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$deepest$sroa$1$i$i+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$deepest$sroa$1$i$i+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
          $545 = $374;$index$1$i$i = $k$031$i$i;
         } else {
          $545 = $376;$index$1$i$i = $index$030$i$i;
         }
         $377 = (($k$031$i$i) + 1)|0;
         $exitcond$i$i = ($377|0)==($369|0);
         if ($exitcond$i$i) {
          $$lcssa$i$i = $545;$index$0$lcssa$i$i = $index$1$i$i;
          break;
         } else {
          $376 = $545;$index$030$i$i = $index$1$i$i;$k$031$i$i = $377;
         }
        }
       } else {
        $$lcssa$i$i = $371;$index$0$lcssa$i$i = 0;
       }
       $378 = $$lcssa$i45$i > $$lcssa$i$i;
       if ($378) {
        ;HEAP32[$0+0>>2]=HEAP32[$deepest$sroa$1$i$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$deepest$sroa$1$i$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$deepest$sroa$1$i$i+8>>2]|0;
        $379 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 32|0);
        $380 = Math_fround(HEAPF32[$379>>2]);
        $381 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 36|0);
        $382 = Math_fround(HEAPF32[$381>>2]);
        $383 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 40|0);
        $384 = Math_fround(HEAPF32[$383>>2]);
        $385 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 16|0);
        $386 = Math_fround(HEAPF32[$385>>2]);
        $387 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 20|0);
        $388 = Math_fround(HEAPF32[$387>>2]);
        $389 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 24|0);
        $390 = Math_fround(HEAPF32[$389>>2]);
        $$lcssa$i3$i = $$lcssa$i$i;$538 = $390;$539 = $388;$540 = $386;$541 = $384;$542 = $382;$543 = $380;$544 = $368;$hadContacts$1$off0$i = 1;
       } else {
        $$lcssa$i3$i = $$lcssa$i45$i;$538 = $531;$539 = $532;$540 = $533;$541 = $534;$542 = $535;$543 = $536;$544 = $537;$hadContacts$1$off0$i = 1;
       }
      }
      $391 = (($j$06$i) + 1)|0;
      $exitcond$i = ($391|0)==($357|0);
      if ($exitcond$i) {
       $$lcssa$i4$lcssa$i = $$lcssa$i3$i;$395 = $544;$404 = $543;$406 = $542;$408 = $541;$442 = $540;$444 = $539;$446 = $538;$hadContacts$0$off0$lcssa$i = $hadContacts$1$off0$i;
       break;
      } else {
       $$lcssa$i45$i = $$lcssa$i3$i;$531 = $538;$532 = $539;$533 = $540;$534 = $541;$535 = $542;$536 = $543;$537 = $544;$hadContacts$0$off07$i = $hadContacts$1$off0$i;$j$06$i = $391;
      }
     }
    }
   }
   ;HEAP32[$mtd$sroa$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$mtd$sroa$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$mtd$sroa$1+8>>2]=HEAP32[$0+8>>2]|0;
   $$hadContacts$0$off0 = $hadContacts$0$off0$lcssa$i | $hadContacts$0$off0220;
   $392 = (($a$0221) + 1)|0;
   $393 = ($392>>>0)<($349>>>0);
   $indvars$iv$next = (($indvars$iv) + 32)|0;
   if ($393) {
    $523 = $$lcssa$i4$lcssa$i;$524 = $395;$525 = $404;$526 = $406;$527 = $408;$528 = $442;$529 = $444;$530 = $446;$a$0221 = $392;$hadContacts$0$off0220 = $$hadContacts$0$off0;$indvars$iv = $indvars$iv$next;
   } else {
    break;
   }
  }
  if (!($$hadContacts$0$off0)) {
   $496 = $485;$498 = $487;$501 = $489;$509 = $514;$510 = $515;$511 = $516;$512 = $395;$foundInitial$2$off0 = $foundInitial$0$off0234;
   break;
  }
  $394 = (($347) + ($395<<2)|0);
  $396 = HEAP32[$394>>2]|0;
  $397 = Math_fround(HEAPF32[$boxTransformV>>2]);
  $398 = Math_fround(HEAPF32[$145>>2]);
  $399 = Math_fround(HEAPF32[$146>>2]);
  $400 = Math_fround(HEAPF32[$147>>2]);
  $401 = Math_fround($400 * $400);
  $402 = Math_fround($401 + Math_fround(-0.5));
  $403 = Math_fround($404 * $402);
  $405 = Math_fround($406 * $402);
  $407 = Math_fround($408 * $402);
  $409 = Math_fround($408 * $398);
  $410 = Math_fround($406 * $399);
  $411 = Math_fround($409 - $410);
  $412 = Math_fround($404 * $399);
  $413 = Math_fround($408 * $397);
  $414 = Math_fround($412 - $413);
  $415 = Math_fround($406 * $397);
  $416 = Math_fround($404 * $398);
  $417 = Math_fround($415 - $416);
  $418 = Math_fround($400 * $411);
  $419 = Math_fround($400 * $414);
  $420 = Math_fround($400 * $417);
  $421 = Math_fround($418 + $403);
  $422 = Math_fround($419 + $405);
  $423 = Math_fround($420 + $407);
  $424 = Math_fround($404 * $397);
  $425 = Math_fround($406 * $398);
  $426 = Math_fround($424 + $425);
  $427 = Math_fround($408 * $399);
  $428 = Math_fround($426 + $427);
  $429 = Math_fround($397 * $428);
  $430 = Math_fround($398 * $428);
  $431 = Math_fround($399 * $428);
  $432 = Math_fround($429 + $421);
  $433 = Math_fround($430 + $422);
  $434 = Math_fround($431 + $423);
  $435 = Math_fround($432 * Math_fround(2.0));
  $436 = Math_fround($433 * Math_fround(2.0));
  $437 = Math_fround($434 * Math_fround(2.0));
  $438 = Math_fround(HEAPF32[$148>>2]);
  $439 = Math_fround(HEAPF32[$149>>2]);
  $440 = Math_fround(HEAPF32[$150>>2]);
  $441 = Math_fround($442 * $402);
  $443 = Math_fround($444 * $402);
  $445 = Math_fround($446 * $402);
  $447 = Math_fround($446 * $398);
  $448 = Math_fround($444 * $399);
  $449 = Math_fround($447 - $448);
  $450 = Math_fround($442 * $399);
  $451 = Math_fround($446 * $397);
  $452 = Math_fround($450 - $451);
  $453 = Math_fround($444 * $397);
  $454 = Math_fround($442 * $398);
  $455 = Math_fround($453 - $454);
  $456 = Math_fround($400 * $449);
  $457 = Math_fround($400 * $452);
  $458 = Math_fround($400 * $455);
  $459 = Math_fround($456 + $441);
  $460 = Math_fround($457 + $443);
  $461 = Math_fround($458 + $445);
  $462 = Math_fround($442 * $397);
  $463 = Math_fround($444 * $398);
  $464 = Math_fround($462 + $463);
  $465 = Math_fround($446 * $399);
  $466 = Math_fround($464 + $465);
  $467 = Math_fround($397 * $466);
  $468 = Math_fround($398 * $466);
  $469 = Math_fround($399 * $466);
  $470 = Math_fround($467 + $459);
  $471 = Math_fround($468 + $460);
  $472 = Math_fround($469 + $461);
  $473 = Math_fround($470 * Math_fround(2.0));
  $474 = Math_fround($471 * Math_fround(2.0));
  $475 = Math_fround($472 * Math_fround(2.0));
  $476 = Math_fround($438 + $473);
  $477 = Math_fround($439 + $474);
  $478 = Math_fround($440 + $475);
  $479 = !($$lcssa$i4$lcssa$i <= Math_fround(0.0));
  if ($479) {
   label = 22;
   break;
  }
  $481 = Math_fround($$lcssa$i4$lcssa$i * $435);
  $482 = Math_fround($$lcssa$i4$lcssa$i * $436);
  $483 = Math_fround($$lcssa$i4$lcssa$i * $437);
  $484 = Math_fround($485 - $481);
  $486 = Math_fround($487 - $482);
  $488 = Math_fround($489 - $483);
  $490 = Math_fround($251 - $481);
  $491 = Math_fround($252 - $482);
  $492 = Math_fround($253 - $483);
  HEAPF32[$42>>2] = $490;
  HEAPF32[$45>>2] = $491;
  HEAPF32[$48>>2] = $492;
  $493 = (($i$0233) + 1)|0;
  $494 = ($493>>>0)<(4);
  if ($494) {
   $251 = $490;$252 = $491;$253 = $492;$485 = $484;$487 = $486;$489 = $488;$513 = $396;$514 = $476;$515 = $477;$516 = $478;$517 = $404;$518 = $406;$519 = $408;$520 = $442;$521 = $444;$522 = $446;$foundInitial$0$off0234 = 1;$i$0233 = $493;
  } else {
   $496 = $484;$498 = $486;$501 = $488;$509 = $476;$510 = $477;$511 = $478;$512 = $396;$foundInitial$2$off0 = 1;
   break;
  }
 }
 if ((label|0) == 22) {
  $480 = ($i$0233|0)==(0);
  if ($480) {
   HEAPF32[$184>>2] = Math_fround(0.0);
   HEAPF32[$185>>2] = $476;
   HEAPF32[$186>>2] = $477;
   HEAPF32[$187>>2] = $478;
   HEAPF32[$188>>2] = $435;
   HEAPF32[$189>>2] = $436;
   HEAPF32[$190>>2] = $437;
   HEAP32[$191>>2] = $396;
   $$2 = 1;
   __ZN5physx2Gu9ContainerD2Ev($tempContainer);
   STACKTOP = sp;return ($$2|0);
  } else {
   $496 = $485;$498 = $487;$501 = $489;$509 = $476;$510 = $477;$511 = $478;$512 = $396;$foundInitial$2$off0 = 1;
  }
 }
 $495 = Math_fround($496 * $496);
 $497 = Math_fround($498 * $498);
 $499 = Math_fround($497 + $495);
 $500 = Math_fround($501 * $501);
 $502 = Math_fround($500 + $499);
 $503 = (Math_fround(Math_sqrt((Math_fround($502)))));
 $504 = Math_fround(Math_fround(1.0) / $503);
 if (!($foundInitial$2$off0)) {
  $$2 = 0;
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return ($$2|0);
 }
 $505 = Math_fround(-$503);
 $506 = Math_fround($501 * $504);
 $507 = Math_fround($498 * $504);
 $508 = Math_fround($496 * $504);
 HEAPF32[$184>>2] = $505;
 HEAPF32[$185>>2] = $509;
 HEAPF32[$186>>2] = $510;
 HEAPF32[$187>>2] = $511;
 HEAPF32[$188>>2] = $508;
 HEAPF32[$189>>2] = $507;
 HEAPF32[$190>>2] = $506;
 HEAP32[$191>>2] = $512;
 $$2 = 1;
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return ($$2|0);
}
function __ZN5physx2Gu29computeConvex_TriangleMeshMTDERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES6_ffbRNS_10PxSweepHitE($triMeshGeom,$pose,$convexGeom,$convexPose,$inflation,$distance,$isDoubleSided,$hit) {
 $triMeshGeom = $triMeshGeom|0;
 $pose = $pose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $inflation = Math_fround($inflation);
 $distance = Math_fround($distance);
 $isDoubleSided = $isDoubleSided|0;
 $hit = $hit|0;
 var $$$i$i = Math_fround(0), $$3 = 0, $$hadContacts$0$off0 = 0, $$lcssa$i$i = Math_fround(0), $$lcssa$i3$i = Math_fround(0), $$lcssa$i4$lcssa$i = Math_fround(0), $$lcssa$i45$i = Math_fround(0), $$pre = Math_fround(0), $$pre252 = Math_fround(0), $$pre253 = Math_fround(0), $$pre254 = Math_fround(0), $$pre255 = Math_fround(0), $$pre256 = Math_fround(0), $$pre257 = Math_fround(0), $$pre258 = Math_fround(0), $$pre259 = Math_fround(0), $$pre260 = Math_fround(0), $$sroa$176 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0;
 var $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = Math_fround(0);
 var $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0;
 var $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0);
 var $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0;
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0);
 var $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0);
 var $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0);
 var $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0);
 var $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0;
 var $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = Math_fround(0), $421 = 0, $422 = 0, $423 = Math_fround(0);
 var $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = 0, $458 = 0, $459 = Math_fround(0), $46 = 0;
 var $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0);
 var $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0);
 var $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0);
 var $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0);
 var $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0;
 var $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = 0, $559 = 0, $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0);
 var $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0);
 var $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = 0, $592 = 0, $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = 0, $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0);
 var $604 = 0, $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0);
 var $622 = Math_fround(0), $623 = Math_fround(0), $624 = 0, $625 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0;
 var $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $a$0224 = 0, $convexBuff = 0, $convexHull = 0, $convexScaling = 0, $convexTransformV = 0, $deepest$sroa$1$i$i = 0, $deepestPen$sroa$1$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i$i = 0, $foundInitial$0$off0237 = 0, $foundInitial$3$off0 = 0, $hadContacts$0$off0$lcssa$i = 0, $hadContacts$0$off0223 = 0, $hadContacts$0$off07$i = 0, $hadContacts$1$off0$i = 0;
 var $hullOBB = 0, $i$0236 = 0, $index$0$lcssa$i$i = 0, $index$030$i$i = 0, $index$1$i$i = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$op = 0, $inflationV = 0, $j$06$i = 0, $k$0207 = 0, $k$031$i$i = 0, $manifoldContacts = 0, $meshScaling = 0, $meshToConvexV = 0, $meshToWorldSkew = 0, $mtd$sroa$1 = 0, $numContacts = 0, $pen$sroa$1$i$i = 0, $polyData = 0;
 var $storemerge = 0, $tempContainer = 0, $tempConvexPose = 0, $triangles = 0, $vQuat = 0, $vScale = 0, $vref0$0$i = 0, $vref1$0$i = 0, $vref2$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6256|0;
 $deepest$sroa$1$i$i = sp + 6236|0;
 $pen$sroa$1$i$i = sp + 6224|0;
 $deepestPen$sroa$1$i = sp + 6212|0;
 $manifoldContacts = sp + 368|0;
 $numContacts = sp + 6208|0;
 $meshScaling = sp + 6136|0;
 $convexScaling = sp + 6064|0;
 $convexTransformV = sp + 320|0;
 $vScale = sp + 352|0;
 $vQuat = sp + 288|0;
 $convexHull = sp + 80|0;
 $0 = sp + 304|0;
 $convexBuff = sp + 16|0;
 $inflationV = sp;
 $tempContainer = sp + 4528|0;
 $meshToWorldSkew = sp + 4560|0;
 $polyData = sp + 4608|0;
 $mtd$sroa$1 = sp + 6048|0;
 $tempConvexPose = sp + 6020|0;
 $hullOBB = sp + 5960|0;
 $meshToConvexV = sp + 4464|0;
 $$sroa$176 = sp + 4544|0;
 $triangles = sp + 4680|0;
 $1 = (($triMeshGeom) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($convexGeom) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 168|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$numContacts>>2] = 0;
 $7 = (($triMeshGeom) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $8 == Math_fround(1.0);
 if ($9) {
  $10 = (($triMeshGeom) + 8|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = $11 == Math_fround(1.0);
  if ($12) {
   $13 = (($triMeshGeom) + 12|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = $14 == Math_fround(1.0);
   $592 = $15;
  } else {
   $592 = 0;
  }
 } else {
  $592 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $16 = (($meshScaling) + 4|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($meshScaling) + 8|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($meshScaling) + 12|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($meshScaling) + 16|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($meshScaling) + 20|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($meshScaling) + 24|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($meshScaling) + 28|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($meshScaling) + 32|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($meshScaling) + 36|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($meshScaling) + 40|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($meshScaling) + 44|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($meshScaling) + 48|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($meshScaling) + 52|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($meshScaling) + 56|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($meshScaling) + 60|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($meshScaling) + 64|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($meshScaling) + 68|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 if (!($592)) {
  $33 = (($triMeshGeom) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$7,$33);
 }
 $34 = (($4) + 16|0);
 $35 = (($convexGeom) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = $36 == Math_fround(1.0);
 if ($37) {
  $38 = (($convexGeom) + 8|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = $39 == Math_fround(1.0);
  if ($40) {
   $41 = (($convexGeom) + 12|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = $42 == Math_fround(1.0);
   $149 = $43;
  } else {
   $149 = 0;
  }
 } else {
  $149 = 0;
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $44 = (($convexScaling) + 4|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($convexScaling) + 8|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($convexScaling) + 12|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($convexScaling) + 16|0);
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (($convexScaling) + 20|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($convexScaling) + 24|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($convexScaling) + 28|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($convexScaling) + 32|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 $52 = (($convexScaling) + 36|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($convexScaling) + 40|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($convexScaling) + 44|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($convexScaling) + 48|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($convexScaling) + 52|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($convexScaling) + 56|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($convexScaling) + 60|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($convexScaling) + 64|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($convexScaling) + 68|0);
 HEAPF32[$60>>2] = Math_fround(1.0);
 if ($149) {
  $116 = $36;$65 = Math_fround(1.0);$67 = Math_fround(0.0);$69 = Math_fround(0.0);$73 = Math_fround(0.0);$75 = Math_fround(1.0);$77 = Math_fround(0.0);$84 = Math_fround(0.0);$86 = Math_fround(0.0);$88 = Math_fround(1.0);
 } else {
  $61 = (($convexGeom) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$35,$61);
  $$pre = Math_fround(HEAPF32[$convexScaling>>2]);
  $$pre252 = Math_fround(HEAPF32[$44>>2]);
  $$pre253 = Math_fround(HEAPF32[$45>>2]);
  $$pre254 = Math_fround(HEAPF32[$46>>2]);
  $$pre255 = Math_fround(HEAPF32[$47>>2]);
  $$pre256 = Math_fround(HEAPF32[$48>>2]);
  $$pre257 = Math_fround(HEAPF32[$49>>2]);
  $$pre258 = Math_fround(HEAPF32[$50>>2]);
  $$pre259 = Math_fround(HEAPF32[$51>>2]);
  $$pre260 = Math_fround(HEAPF32[$35>>2]);
  $116 = $$pre260;$65 = $$pre;$67 = $$pre252;$69 = $$pre253;$73 = $$pre254;$75 = $$pre255;$77 = $$pre256;$84 = $$pre257;$86 = $$pre258;$88 = $$pre259;
 }
 $62 = (($4) + 40|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $65);
 $66 = Math_fround($63 * $67);
 $68 = Math_fround($63 * $69);
 $70 = (($4) + 44|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $73);
 $74 = Math_fround($71 * $75);
 $76 = Math_fround($71 * $77);
 $78 = Math_fround($64 + $72);
 $79 = Math_fround($66 + $74);
 $80 = Math_fround($68 + $76);
 $81 = (($4) + 48|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 * $84);
 $85 = Math_fround($82 * $86);
 $87 = Math_fround($82 * $88);
 $89 = Math_fround($78 + $83);
 $90 = Math_fround($79 + $85);
 $91 = Math_fround($80 + $87);
 $92 = Math_fround(HEAPF32[$convexPose>>2]);
 $93 = (($convexPose) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($convexPose) + 8|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($convexPose) + 12|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($convexPose) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($99) + 4|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($99) + 8|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 HEAPF32[$convexTransformV>>2] = $92;
 $105 = (($convexTransformV) + 4|0);
 HEAPF32[$105>>2] = $94;
 $106 = (($convexTransformV) + 8|0);
 HEAPF32[$106>>2] = $96;
 $107 = (($convexTransformV) + 12|0);
 HEAPF32[$107>>2] = $98;
 $108 = (($convexTransformV) + 16|0);
 HEAPF32[$108>>2] = $100;
 $109 = (($convexTransformV) + 20|0);
 HEAPF32[$109>>2] = $102;
 $110 = (($convexTransformV) + 24|0);
 HEAPF32[$110>>2] = $104;
 $111 = (($convexTransformV) + 28|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = (($convexGeom) + 8|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($convexGeom) + 12|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 HEAPF32[$vScale>>2] = $116;
 $117 = (($vScale) + 4|0);
 HEAPF32[$117>>2] = $113;
 $118 = (($vScale) + 8|0);
 HEAPF32[$118>>2] = $115;
 $119 = (($vScale) + 12|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($convexGeom) + 16|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($120) + 4|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($120) + 8|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($120) + 12|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 HEAPF32[$vQuat>>2] = $121;
 $128 = (($vQuat) + 4|0);
 HEAPF32[$128>>2] = $123;
 $129 = (($vQuat) + 8|0);
 HEAPF32[$129>>2] = $125;
 $130 = (($vQuat) + 12|0);
 HEAPF32[$130>>2] = $127;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$34,$0,$vScale,$vQuat);
 $131 = (($4) + 68|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($4) + 72|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($4) + 76|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround(HEAPF32[$vScale>>2]);
 $138 = Math_fround(HEAPF32[$117>>2]);
 $139 = Math_fround(HEAPF32[$118>>2]);
 $140 = Math_fround($132 * $137);
 $141 = Math_fround($134 * $138);
 $142 = Math_fround($136 * $139);
 $143 = !($140 <= $141);
 $$$i$i = $143 ? $141 : $140;
 $144 = !($$$i$i <= $142);
 $145 = $144 ? $142 : $$$i$i;
 $146 = Math_fround($145 * Math_fround(0.25));
 $147 = Math_fround($146 + $inflation);
 HEAPF32[$inflationV>>2] = $147;
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $148 = STACKTOP; STACKTOP = STACKTOP + 512|0;;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,128,$148,1);
 __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($meshToWorldSkew,$pose,$7);
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHull,$149,$polyData);
 $150 = Math_fround(HEAPF32[$convexPose>>2]);
 HEAPF32[$tempConvexPose>>2] = $150;
 $151 = (($tempConvexPose) + 4|0);
 $152 = (($convexPose) + 4|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 HEAPF32[$151>>2] = $153;
 $154 = (($tempConvexPose) + 8|0);
 $155 = (($convexPose) + 8|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 HEAPF32[$154>>2] = $156;
 $157 = (($tempConvexPose) + 12|0);
 $158 = (($convexPose) + 12|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 HEAPF32[$157>>2] = $159;
 $160 = (($tempConvexPose) + 16|0);
 $161 = Math_fround(HEAPF32[$99>>2]);
 HEAPF32[$160>>2] = $161;
 $162 = (($tempConvexPose) + 20|0);
 $163 = (($convexPose) + 20|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 HEAPF32[$162>>2] = $164;
 $165 = (($tempConvexPose) + 24|0);
 $166 = (($convexPose) + 24|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 HEAPF32[$165>>2] = $167;
 $168 = (($tempContainer) + 4|0);
 $169 = (($convexHull) + 96|0);
 $170 = (($convexHull) + 144|0);
 $171 = (($convexBuff) + 32|0);
 $172 = (($convexBuff) + 36|0);
 $173 = (($convexBuff) + 40|0);
 $174 = (($convexBuff) + 44|0);
 $175 = $149&1;
 $176 = (($convexBuff) + 48|0);
 $177 = (($convexBuff) + 16|0);
 $178 = (($convexBuff) + 20|0);
 $179 = (($convexBuff) + 24|0);
 $180 = (($convexBuff) + 28|0);
 $181 = (($hullOBB) + 48|0);
 $182 = (($hullOBB) + 52|0);
 $183 = (($hullOBB) + 56|0);
 $184 = Math_fround(HEAPF32[$meshToWorldSkew>>2]);
 $185 = (($meshToWorldSkew) + 4|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($meshToWorldSkew) + 8|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($meshToWorldSkew) + 12|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($meshToWorldSkew) + 16|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($meshToWorldSkew) + 20|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($meshToWorldSkew) + 24|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($meshToWorldSkew) + 28|0);
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = (($meshToWorldSkew) + 32|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = (($meshToWorldSkew) + 36|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($meshToWorldSkew) + 40|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = (($meshToWorldSkew) + 44|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = (($meshToConvexV) + 48|0);
 $208 = (($meshToConvexV) + 52|0);
 $209 = (($meshToConvexV) + 56|0);
 $210 = (($meshToConvexV) + 60|0);
 $211 = (($meshToConvexV) + 4|0);
 $212 = (($meshToConvexV) + 8|0);
 $213 = (($meshToConvexV) + 12|0);
 $214 = (($meshToConvexV) + 16|0);
 $215 = (($meshToConvexV) + 20|0);
 $216 = (($meshToConvexV) + 24|0);
 $217 = (($meshToConvexV) + 28|0);
 $218 = (($meshToConvexV) + 32|0);
 $219 = (($meshToConvexV) + 36|0);
 $220 = (($meshToConvexV) + 40|0);
 $221 = (($meshToConvexV) + 44|0);
 $222 = (($tempContainer) + 8|0);
 $223 = (($hit) + 40|0);
 $224 = (($hit) + 16|0);
 $225 = (($hit) + 20|0);
 $226 = (($hit) + 24|0);
 $227 = (($hit) + 28|0);
 $228 = (($hit) + 32|0);
 $229 = (($hit) + 36|0);
 $230 = (($hit) + 8|0);
 $231 = (($manifoldContacts) + 44|0);
 $232 = (($2) + 172|0);
 $233 = (($2) + 28|0);
 $234 = (($2) + 24|0);
 $237 = $100;$238 = $102;$239 = $104;$564 = Math_fround(0.0);$566 = Math_fround(0.0);$568 = Math_fround(0.0);$593 = Math_fround(0.0);$594 = Math_fround(0.0);$595 = Math_fround(0.0);$596 = 268435455;$597 = Math_fround(0.0);$598 = Math_fround(0.0);$599 = Math_fround(0.0);$600 = Math_fround(0.0);$601 = Math_fround(0.0);$602 = Math_fround(0.0);$foundInitial$0$off0237 = 0;$i$0236 = 0;
 while(1) {
  $235 = HEAP32[$168>>2]|0;
  $236 = ($235|0)==(0);
  if (!($236)) {
   HEAP32[$168>>2] = 0;
  }
  HEAPF32[$160>>2] = $237;
  HEAPF32[$162>>2] = $238;
  HEAPF32[$165>>2] = $239;
  HEAPF32[$108>>2] = $237;
  HEAPF32[$109>>2] = $238;
  HEAPF32[$110>>2] = $239;
  HEAPF32[$111>>2] = Math_fround(0.0);
  HEAP32[$171>>2] = $convexTransformV;
  HEAP32[$172>>2] = $169;
  HEAP32[$173>>2] = $170;
  HEAP8[$174>>0] = $175;
  $storemerge = $149 ? ((546744 + 8|0)) : ((546712 + 8|0));
  HEAP32[$convexBuff>>2] = $storemerge;
  HEAP32[$176>>2] = $convexHull;
  HEAPF32[$177>>2] = $89;
  HEAPF32[$178>>2] = $90;
  HEAPF32[$179>>2] = $91;
  HEAPF32[$180>>2] = Math_fround(0.0);
  __ZN5physx2Gu22computeOBBAroundConvexERNS0_3BoxERKNS_20PxConvexMeshGeometryEPKNS_12PxConvexMeshERKNS_11PxTransformE($hullOBB,$convexGeom,$4,$tempConvexPose);
  $240 = Math_fround(HEAPF32[$181>>2]);
  $241 = Math_fround($147 + $240);
  HEAPF32[$181>>2] = $241;
  $242 = Math_fround(HEAPF32[$182>>2]);
  $243 = Math_fround($147 + $242);
  HEAPF32[$182>>2] = $243;
  $244 = Math_fround(HEAPF32[$183>>2]);
  $245 = Math_fround($147 + $244);
  HEAPF32[$183>>2] = $245;
  __ZL13midPhaseQueryRKN5physx22PxTriangleMeshGeometryERKNS_11PxTransformERNS_2Gu3BoxERNS6_9ContainerE($triMeshGeom,$pose,$hullOBB,$tempContainer);
  $246 = HEAP32[$168>>2]|0;
  $247 = ($246|0)==(0);
  if ($247) {
   $575 = $564;$577 = $566;$580 = $568;$588 = $593;$589 = $594;$590 = $595;$591 = $596;$foundInitial$3$off0 = $foundInitial$0$off0237;
   break;
  }
  $248 = Math_fround(HEAPF32[$160>>2]);
  $249 = Math_fround(HEAPF32[$162>>2]);
  $250 = Math_fround(HEAPF32[$165>>2]);
  $251 = Math_fround($248 * Math_fround(-2.0));
  $252 = Math_fround($249 * Math_fround(-2.0));
  $253 = Math_fround($250 * Math_fround(-2.0));
  $254 = Math_fround(HEAPF32[$157>>2]);
  $255 = Math_fround($254 * $254);
  $256 = Math_fround($255 + Math_fround(-0.5));
  $257 = Math_fround(HEAPF32[$tempConvexPose>>2]);
  $258 = Math_fround($251 * $257);
  $259 = Math_fround(HEAPF32[$151>>2]);
  $260 = Math_fround($252 * $259);
  $261 = Math_fround($258 + $260);
  $262 = Math_fround(HEAPF32[$154>>2]);
  $263 = Math_fround($253 * $262);
  $264 = Math_fround($261 + $263);
  $265 = Math_fround($251 * $256);
  $266 = Math_fround($253 * $259);
  $267 = Math_fround($252 * $262);
  $268 = Math_fround($266 - $267);
  $269 = Math_fround($254 * $268);
  $270 = Math_fround($265 - $269);
  $271 = Math_fround($257 * $264);
  $272 = Math_fround($271 + $270);
  $273 = Math_fround($252 * $256);
  $274 = Math_fround($251 * $262);
  $275 = Math_fround($253 * $257);
  $276 = Math_fround($274 - $275);
  $277 = Math_fround($254 * $276);
  $278 = Math_fround($273 - $277);
  $279 = Math_fround($259 * $264);
  $280 = Math_fround($279 + $278);
  $281 = Math_fround($253 * $256);
  $282 = Math_fround($252 * $257);
  $283 = Math_fround($251 * $259);
  $284 = Math_fround($282 - $283);
  $285 = Math_fround($254 * $284);
  $286 = Math_fround($281 - $285);
  $287 = Math_fround($262 * $264);
  $288 = Math_fround($286 + $287);
  $289 = Math_fround(-$257);
  $290 = Math_fround(-$259);
  $291 = Math_fround(-$262);
  $292 = Math_fround($289 - $257);
  $293 = Math_fround($290 - $259);
  $294 = Math_fround($291 - $262);
  $295 = Math_fround($254 * $292);
  $296 = Math_fround($254 * $293);
  $297 = Math_fround($254 * $294);
  $298 = Math_fround($292 * $289);
  $299 = Math_fround($293 * $289);
  $300 = Math_fround($294 * $289);
  $301 = Math_fround($293 * $290);
  $302 = Math_fround($294 * $290);
  $303 = Math_fround($294 * $291);
  $304 = Math_fround(Math_fround(1.0) - $301);
  $305 = Math_fround($304 - $303);
  $306 = Math_fround($299 + $297);
  $307 = Math_fround($300 - $296);
  $308 = Math_fround($299 - $297);
  $309 = Math_fround(Math_fround(1.0) - $298);
  $310 = Math_fround($309 - $303);
  $311 = Math_fround($295 + $302);
  $312 = Math_fround($296 + $300);
  $313 = Math_fround($302 - $295);
  $314 = Math_fround($309 - $301);
  $315 = Math_fround($184 * $305);
  $316 = Math_fround($184 * $306);
  $317 = Math_fround($184 * $307);
  $318 = Math_fround($186 * $308);
  $319 = Math_fround($186 * $310);
  $320 = Math_fround($186 * $311);
  $321 = Math_fround($315 + $318);
  $322 = Math_fround($316 + $319);
  $323 = Math_fround($317 + $320);
  $324 = Math_fround($188 * $312);
  $325 = Math_fround($188 * $313);
  $326 = Math_fround($188 * $314);
  $327 = Math_fround($324 + $321);
  $328 = Math_fround($325 + $322);
  $329 = Math_fround($326 + $323);
  $330 = Math_fround($305 * $190);
  $331 = Math_fround($306 * $190);
  $332 = Math_fround($307 * $190);
  $333 = Math_fround($308 * $192);
  $334 = Math_fround($310 * $192);
  $335 = Math_fround($311 * $192);
  $336 = Math_fround($330 + $333);
  $337 = Math_fround($331 + $334);
  $338 = Math_fround($332 + $335);
  $339 = Math_fround($312 * $194);
  $340 = Math_fround($313 * $194);
  $341 = Math_fround($314 * $194);
  $342 = Math_fround($336 + $339);
  $343 = Math_fround($337 + $340);
  $344 = Math_fround($338 + $341);
  $345 = Math_fround($305 * $196);
  $346 = Math_fround($306 * $196);
  $347 = Math_fround($307 * $196);
  $348 = Math_fround($308 * $198);
  $349 = Math_fround($310 * $198);
  $350 = Math_fround($311 * $198);
  $351 = Math_fround($345 + $348);
  $352 = Math_fround($346 + $349);
  $353 = Math_fround($347 + $350);
  $354 = Math_fround($312 * $200);
  $355 = Math_fround($313 * $200);
  $356 = Math_fround($314 * $200);
  $357 = Math_fround($351 + $354);
  $358 = Math_fround($352 + $355);
  $359 = Math_fround($353 + $356);
  $360 = Math_fround($305 * $202);
  $361 = Math_fround($306 * $202);
  $362 = Math_fround($307 * $202);
  $363 = Math_fround($308 * $204);
  $364 = Math_fround($310 * $204);
  $365 = Math_fround($311 * $204);
  $366 = Math_fround($360 + $363);
  $367 = Math_fround($361 + $364);
  $368 = Math_fround($362 + $365);
  $369 = Math_fround($312 * $206);
  $370 = Math_fround($313 * $206);
  $371 = Math_fround($314 * $206);
  $372 = Math_fround($366 + $369);
  $373 = Math_fround($367 + $370);
  $374 = Math_fround($368 + $371);
  $375 = Math_fround($272 + $372);
  $376 = Math_fround($280 + $373);
  $377 = Math_fround($288 + $374);
  HEAPF32[$207>>2] = $375;
  HEAPF32[$208>>2] = $376;
  HEAPF32[$209>>2] = $377;
  HEAPF32[$210>>2] = Math_fround(0.0);
  HEAPF32[$meshToConvexV>>2] = $327;
  HEAPF32[$211>>2] = $328;
  HEAPF32[$212>>2] = $329;
  HEAPF32[$213>>2] = Math_fround(0.0);
  HEAPF32[$214>>2] = $342;
  HEAPF32[$215>>2] = $343;
  HEAPF32[$216>>2] = $344;
  HEAPF32[$217>>2] = Math_fround(0.0);
  HEAPF32[$218>>2] = $357;
  HEAPF32[$219>>2] = $358;
  HEAPF32[$220>>2] = $359;
  HEAPF32[$221>>2] = Math_fround(0.0);
  $378 = HEAP32[$222>>2]|0;
  $379 = (($246) + 31)|0;
  ;HEAP32[$mtd$sroa$1+0>>2]=HEAP32[$$sroa$176+0>>2]|0;HEAP32[$mtd$sroa$1+4>>2]=HEAP32[$$sroa$176+4>>2]|0;HEAP32[$mtd$sroa$1+8>>2]=HEAP32[$$sroa$176+8>>2]|0;
  $380 = $379 >>> 5;
  $381 = ($380|0)==(0);
  if ($381) {
   $575 = $564;$577 = $566;$580 = $568;$588 = $593;$589 = $594;$590 = $595;$591 = $596;$foundInitial$3$off0 = $foundInitial$0$off0237;
   break;
  }
  $382 = $246 ^ -1;
  $603 = Math_fround(3.40282346638528859812E+38);$604 = $596;$605 = $597;$606 = $598;$607 = $599;$608 = $600;$609 = $601;$610 = $602;$a$0224 = 0;$hadContacts$0$off0223 = 0;$indvars$iv = $382;
  while(1) {
   $383 = ($indvars$iv>>>0)>(4294967263);
   $indvars$iv$op = $indvars$iv ^ -1;
   $384 = $383 ? $indvars$iv$op : 32;
   $385 = $a$0224 << 5;
   $386 = (($246) - ($385))|0;
   $387 = ($386>>>0)<(32);
   $388 = $387 ? $386 : 32;
   $389 = ($388|0)==(0);
   if ($389) {
    ;HEAP32[$deepestPen$sroa$1$i+0>>2]=HEAP32[$mtd$sroa$1+0>>2]|0;HEAP32[$deepestPen$sroa$1$i+4>>2]=HEAP32[$mtd$sroa$1+4>>2]|0;HEAP32[$deepestPen$sroa$1$i+8>>2]=HEAP32[$mtd$sroa$1+8>>2]|0;
    $$lcssa$i4$lcssa$i = $603;$474 = $604;$483 = $605;$485 = $606;$487 = $607;$521 = $608;$523 = $609;$525 = $610;$hadContacts$0$off0$lcssa$i = 0;
   } else {
    $k$0207 = 0;
    while(1) {
     $390 = (($k$0207) + ($385))|0;
     $391 = (($378) + ($390<<2)|0);
     $392 = HEAP32[$391>>2]|0;
     $393 = HEAP8[$232>>0]|0;
     $394 = $393 & 2;
     $395 = ($394<<24>>24)==(0);
     $396 = HEAP32[$233>>2]|0;
     if ($395) {
      $406 = (($396) + (($392*12)|0)|0);
      $407 = HEAP32[$406>>2]|0;
      $408 = ((($396) + (($392*12)|0)|0) + 4|0);
      $409 = HEAP32[$408>>2]|0;
      $410 = ((($396) + (($392*12)|0)|0) + 8|0);
      $411 = HEAP32[$410>>2]|0;
      $vref0$0$i = $407;$vref1$0$i = $409;$vref2$0$i = $411;
     } else {
      $397 = (($396) + (($392*6)|0)|0);
      $398 = HEAP16[$397>>1]|0;
      $399 = $398&65535;
      $400 = ((($396) + (($392*6)|0)|0) + 2|0);
      $401 = HEAP16[$400>>1]|0;
      $402 = $401&65535;
      $403 = ((($396) + (($392*6)|0)|0) + 4|0);
      $404 = HEAP16[$403>>1]|0;
      $405 = $404&65535;
      $vref0$0$i = $399;$vref1$0$i = $402;$vref2$0$i = $405;
     }
     $412 = HEAP32[$234>>2]|0;
     $413 = (($412) + (($vref0$0$i*12)|0)|0);
     $414 = Math_fround(HEAPF32[$413>>2]);
     $415 = (($triangles) + (($k$0207*40)|0)|0);
     HEAPF32[$415>>2] = $414;
     $416 = ((($412) + (($vref0$0$i*12)|0)|0) + 4|0);
     $417 = Math_fround(HEAPF32[$416>>2]);
     $418 = ((($triangles) + (($k$0207*40)|0)|0) + 4|0);
     HEAPF32[$418>>2] = $417;
     $419 = ((($412) + (($vref0$0$i*12)|0)|0) + 8|0);
     $420 = Math_fround(HEAPF32[$419>>2]);
     $421 = ((($triangles) + (($k$0207*40)|0)|0) + 8|0);
     HEAPF32[$421>>2] = $420;
     $422 = (($412) + (($vref1$0$i*12)|0)|0);
     $423 = Math_fround(HEAPF32[$422>>2]);
     $424 = ((($triangles) + (($k$0207*40)|0)|0) + 12|0);
     HEAPF32[$424>>2] = $423;
     $425 = ((($412) + (($vref1$0$i*12)|0)|0) + 4|0);
     $426 = Math_fround(HEAPF32[$425>>2]);
     $427 = ((($triangles) + (($k$0207*40)|0)|0) + 16|0);
     HEAPF32[$427>>2] = $426;
     $428 = ((($412) + (($vref1$0$i*12)|0)|0) + 8|0);
     $429 = Math_fround(HEAPF32[$428>>2]);
     $430 = ((($triangles) + (($k$0207*40)|0)|0) + 20|0);
     HEAPF32[$430>>2] = $429;
     $431 = (($412) + (($vref2$0$i*12)|0)|0);
     $432 = Math_fround(HEAPF32[$431>>2]);
     $433 = ((($triangles) + (($k$0207*40)|0)|0) + 24|0);
     HEAPF32[$433>>2] = $432;
     $434 = ((($412) + (($vref2$0$i*12)|0)|0) + 4|0);
     $435 = Math_fround(HEAPF32[$434>>2]);
     $436 = ((($triangles) + (($k$0207*40)|0)|0) + 28|0);
     HEAPF32[$436>>2] = $435;
     $437 = ((($412) + (($vref2$0$i*12)|0)|0) + 8|0);
     $438 = Math_fround(HEAPF32[$437>>2]);
     $439 = ((($triangles) + (($k$0207*40)|0)|0) + 32|0);
     HEAPF32[$439>>2] = $438;
     $440 = (($6) + ($392)|0);
     $441 = HEAP8[$440>>0]|0;
     $442 = ((($triangles) + (($k$0207*40)|0)|0) + 36|0);
     HEAP8[$442>>0] = $441;
     $443 = (($k$0207) + 1)|0;
     $exitcond = ($443|0)==($384|0);
     if ($exitcond) {
      break;
     } else {
      $k$0207 = $443;
     }
    }
    ;HEAP32[$deepestPen$sroa$1$i+0>>2]=HEAP32[$mtd$sroa$1+0>>2]|0;HEAP32[$deepestPen$sroa$1$i+4>>2]=HEAP32[$mtd$sroa$1+4>>2]|0;HEAP32[$deepestPen$sroa$1$i+8>>2]=HEAP32[$mtd$sroa$1+8>>2]|0;
    if ($389) {
     $$lcssa$i4$lcssa$i = $603;$474 = $604;$483 = $605;$485 = $606;$487 = $607;$521 = $608;$523 = $609;$525 = $610;$hadContacts$0$off0$lcssa$i = 0;
    } else {
     $$lcssa$i45$i = $603;$611 = $610;$612 = $609;$613 = $608;$614 = $607;$615 = $606;$616 = $605;$617 = $604;$hadContacts$0$off07$i = 0;$j$06$i = 0;
     while(1) {
      HEAP32[$numContacts>>2] = 0;
      $444 = ((($triangles) + (($j$06$i*40)|0)|0) + 36|0);
      $445 = HEAP8[$444>>0]|0;
      $446 = (($triangles) + (($j$06$i*40)|0)|0);
      $447 = (($j$06$i) + ($385))|0;
      (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration15processTriangleERKNS0_13PolygonalDataEPNS0_12SupportLocalEPKNS_6PxVec3EjhRKNS_6shdfnd3aos6FloatVEbRKNSB_12PsTransformVERKNSB_15PsMatTransformVEPNS0_21MeshPersistentContactERj($polyData,$convexBuff,$446,$447,$445,$inflationV,$isDoubleSided,$convexTransformV,$meshToConvexV,$manifoldContacts,$numContacts)|0);
      $448 = HEAP32[$numContacts>>2]|0;
      $449 = ($448|0)==(0);
      if ($449) {
       $$lcssa$i3$i = $$lcssa$i45$i;$618 = $611;$619 = $612;$620 = $613;$621 = $614;$622 = $615;$623 = $616;$624 = $617;$hadContacts$1$off0$i = $hadContacts$0$off07$i;
      } else {
       $450 = Math_fround(HEAPF32[$231>>2]);
       $451 = ($448>>>0)>(1);
       if ($451) {
        $455 = $450;$index$030$i$i = 0;$k$031$i$i = 1;
        while(1) {
         $452 = ((($manifoldContacts) + ($k$031$i$i<<6)|0) + 44|0);
         $453 = Math_fround(HEAPF32[$452>>2]);
         $454 = $455 > $453;
         if ($454) {
          ;HEAP32[$deepest$sroa$1$i$i+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$deepest$sroa$1$i$i+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$deepest$sroa$1$i$i+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
          $625 = $453;$index$1$i$i = $k$031$i$i;
         } else {
          $625 = $455;$index$1$i$i = $index$030$i$i;
         }
         $456 = (($k$031$i$i) + 1)|0;
         $exitcond$i$i = ($456|0)==($448|0);
         if ($exitcond$i$i) {
          $$lcssa$i$i = $625;$index$0$lcssa$i$i = $index$1$i$i;
          break;
         } else {
          $455 = $625;$index$030$i$i = $index$1$i$i;$k$031$i$i = $456;
         }
        }
       } else {
        $$lcssa$i$i = $450;$index$0$lcssa$i$i = 0;
       }
       $457 = $$lcssa$i45$i > $$lcssa$i$i;
       if ($457) {
        ;HEAP32[$deepestPen$sroa$1$i+0>>2]=HEAP32[$deepest$sroa$1$i$i+0>>2]|0;HEAP32[$deepestPen$sroa$1$i+4>>2]=HEAP32[$deepest$sroa$1$i$i+4>>2]|0;HEAP32[$deepestPen$sroa$1$i+8>>2]=HEAP32[$deepest$sroa$1$i$i+8>>2]|0;
        $458 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 32|0);
        $459 = Math_fround(HEAPF32[$458>>2]);
        $460 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 36|0);
        $461 = Math_fround(HEAPF32[$460>>2]);
        $462 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 40|0);
        $463 = Math_fround(HEAPF32[$462>>2]);
        $464 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 16|0);
        $465 = Math_fround(HEAPF32[$464>>2]);
        $466 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 20|0);
        $467 = Math_fround(HEAPF32[$466>>2]);
        $468 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 24|0);
        $469 = Math_fround(HEAPF32[$468>>2]);
        $$lcssa$i3$i = $$lcssa$i$i;$618 = $469;$619 = $467;$620 = $465;$621 = $463;$622 = $461;$623 = $459;$624 = $447;$hadContacts$1$off0$i = 1;
       } else {
        $$lcssa$i3$i = $$lcssa$i45$i;$618 = $611;$619 = $612;$620 = $613;$621 = $614;$622 = $615;$623 = $616;$624 = $617;$hadContacts$1$off0$i = 1;
       }
      }
      $470 = (($j$06$i) + 1)|0;
      $exitcond$i = ($470|0)==($388|0);
      if ($exitcond$i) {
       $$lcssa$i4$lcssa$i = $$lcssa$i3$i;$474 = $624;$483 = $623;$485 = $622;$487 = $621;$521 = $620;$523 = $619;$525 = $618;$hadContacts$0$off0$lcssa$i = $hadContacts$1$off0$i;
       break;
      } else {
       $$lcssa$i45$i = $$lcssa$i3$i;$611 = $618;$612 = $619;$613 = $620;$614 = $621;$615 = $622;$616 = $623;$617 = $624;$hadContacts$0$off07$i = $hadContacts$1$off0$i;$j$06$i = $470;
      }
     }
    }
   }
   ;HEAP32[$mtd$sroa$1+0>>2]=HEAP32[$deepestPen$sroa$1$i+0>>2]|0;HEAP32[$mtd$sroa$1+4>>2]=HEAP32[$deepestPen$sroa$1$i+4>>2]|0;HEAP32[$mtd$sroa$1+8>>2]=HEAP32[$deepestPen$sroa$1$i+8>>2]|0;
   $$hadContacts$0$off0 = $hadContacts$0$off0$lcssa$i | $hadContacts$0$off0223;
   $471 = (($a$0224) + 1)|0;
   $472 = ($471>>>0)<($380>>>0);
   $indvars$iv$next = (($indvars$iv) + 32)|0;
   if ($472) {
    $603 = $$lcssa$i4$lcssa$i;$604 = $474;$605 = $483;$606 = $485;$607 = $487;$608 = $521;$609 = $523;$610 = $525;$a$0224 = $471;$hadContacts$0$off0223 = $$hadContacts$0$off0;$indvars$iv = $indvars$iv$next;
   } else {
    break;
   }
  }
  if (!($$hadContacts$0$off0)) {
   $575 = $564;$577 = $566;$580 = $568;$588 = $593;$589 = $594;$590 = $595;$591 = $474;$foundInitial$3$off0 = $foundInitial$0$off0237;
   break;
  }
  $473 = (($378) + ($474<<2)|0);
  $475 = HEAP32[$473>>2]|0;
  $476 = Math_fround(HEAPF32[$convexTransformV>>2]);
  $477 = Math_fround(HEAPF32[$105>>2]);
  $478 = Math_fround(HEAPF32[$106>>2]);
  $479 = Math_fround(HEAPF32[$107>>2]);
  $480 = Math_fround($479 * $479);
  $481 = Math_fround($480 + Math_fround(-0.5));
  $482 = Math_fround($483 * $481);
  $484 = Math_fround($485 * $481);
  $486 = Math_fround($487 * $481);
  $488 = Math_fround($487 * $477);
  $489 = Math_fround($485 * $478);
  $490 = Math_fround($488 - $489);
  $491 = Math_fround($483 * $478);
  $492 = Math_fround($487 * $476);
  $493 = Math_fround($491 - $492);
  $494 = Math_fround($485 * $476);
  $495 = Math_fround($483 * $477);
  $496 = Math_fround($494 - $495);
  $497 = Math_fround($479 * $490);
  $498 = Math_fround($479 * $493);
  $499 = Math_fround($479 * $496);
  $500 = Math_fround($497 + $482);
  $501 = Math_fround($498 + $484);
  $502 = Math_fround($499 + $486);
  $503 = Math_fround($483 * $476);
  $504 = Math_fround($485 * $477);
  $505 = Math_fround($503 + $504);
  $506 = Math_fround($487 * $478);
  $507 = Math_fround($505 + $506);
  $508 = Math_fround($476 * $507);
  $509 = Math_fround($477 * $507);
  $510 = Math_fround($478 * $507);
  $511 = Math_fround($508 + $500);
  $512 = Math_fround($509 + $501);
  $513 = Math_fround($510 + $502);
  $514 = Math_fround($511 * Math_fround(2.0));
  $515 = Math_fround($512 * Math_fround(2.0));
  $516 = Math_fround($513 * Math_fround(2.0));
  $517 = Math_fround(HEAPF32[$108>>2]);
  $518 = Math_fround(HEAPF32[$109>>2]);
  $519 = Math_fround(HEAPF32[$110>>2]);
  $520 = Math_fround($521 * $481);
  $522 = Math_fround($523 * $481);
  $524 = Math_fround($525 * $481);
  $526 = Math_fround($525 * $477);
  $527 = Math_fround($523 * $478);
  $528 = Math_fround($526 - $527);
  $529 = Math_fround($521 * $478);
  $530 = Math_fround($525 * $476);
  $531 = Math_fround($529 - $530);
  $532 = Math_fround($523 * $476);
  $533 = Math_fround($521 * $477);
  $534 = Math_fround($532 - $533);
  $535 = Math_fround($479 * $528);
  $536 = Math_fround($479 * $531);
  $537 = Math_fround($479 * $534);
  $538 = Math_fround($535 + $520);
  $539 = Math_fround($536 + $522);
  $540 = Math_fround($537 + $524);
  $541 = Math_fround($521 * $476);
  $542 = Math_fround($523 * $477);
  $543 = Math_fround($541 + $542);
  $544 = Math_fround($525 * $478);
  $545 = Math_fround($543 + $544);
  $546 = Math_fround($476 * $545);
  $547 = Math_fround($477 * $545);
  $548 = Math_fround($478 * $545);
  $549 = Math_fround($546 + $538);
  $550 = Math_fround($547 + $539);
  $551 = Math_fround($548 + $540);
  $552 = Math_fround($549 * Math_fround(2.0));
  $553 = Math_fround($550 * Math_fround(2.0));
  $554 = Math_fround($551 * Math_fround(2.0));
  $555 = Math_fround($517 + $552);
  $556 = Math_fround($518 + $553);
  $557 = Math_fround($519 + $554);
  $558 = !($$lcssa$i4$lcssa$i <= Math_fround(0.0));
  if ($558) {
   label = 35;
   break;
  }
  $560 = Math_fround($$lcssa$i4$lcssa$i * $514);
  $561 = Math_fround($$lcssa$i4$lcssa$i * $515);
  $562 = Math_fround($$lcssa$i4$lcssa$i * $516);
  $563 = Math_fround($564 - $560);
  $565 = Math_fround($566 - $561);
  $567 = Math_fround($568 - $562);
  $569 = Math_fround($237 - $560);
  $570 = Math_fround($238 - $561);
  $571 = Math_fround($239 - $562);
  $572 = (($i$0236) + 1)|0;
  $573 = ($572>>>0)<(2);
  if ($573) {
   $237 = $569;$238 = $570;$239 = $571;$564 = $563;$566 = $565;$568 = $567;$593 = $555;$594 = $556;$595 = $557;$596 = $475;$597 = $483;$598 = $485;$599 = $487;$600 = $521;$601 = $523;$602 = $525;$foundInitial$0$off0237 = 1;$i$0236 = $572;
  } else {
   $575 = $563;$577 = $565;$580 = $567;$588 = $555;$589 = $556;$590 = $557;$591 = $475;$foundInitial$3$off0 = 1;
   break;
  }
 }
 if ((label|0) == 35) {
  $559 = ($i$0236|0)==(0);
  if ($559) {
   HEAPF32[$223>>2] = Math_fround(0.0);
   HEAPF32[$224>>2] = $555;
   HEAPF32[$225>>2] = $556;
   HEAPF32[$226>>2] = $557;
   HEAPF32[$227>>2] = $514;
   HEAPF32[$228>>2] = $515;
   HEAPF32[$229>>2] = $516;
   HEAP32[$230>>2] = $475;
   $$3 = 1;
   __ZN5physx2Gu9ContainerD2Ev($tempContainer);
   STACKTOP = sp;return ($$3|0);
  } else {
   $575 = $564;$577 = $566;$580 = $568;$588 = $555;$589 = $556;$590 = $557;$591 = $475;$foundInitial$3$off0 = 1;
  }
 }
 $574 = Math_fround($575 * $575);
 $576 = Math_fround($577 * $577);
 $578 = Math_fround($576 + $574);
 $579 = Math_fround($580 * $580);
 $581 = Math_fround($579 + $578);
 $582 = (Math_fround(Math_sqrt((Math_fround($581)))));
 $583 = Math_fround(Math_fround(1.0) / $582);
 if (!($foundInitial$3$off0)) {
  $$3 = 0;
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return ($$3|0);
 }
 $584 = Math_fround(-$582);
 $585 = Math_fround($580 * $583);
 $586 = Math_fround($577 * $583);
 $587 = Math_fround($575 * $583);
 HEAPF32[$223>>2] = $584;
 HEAPF32[$224>>2] = $588;
 HEAPF32[$225>>2] = $589;
 HEAPF32[$226>>2] = $590;
 HEAPF32[$227>>2] = $587;
 HEAPF32[$228>>2] = $586;
 HEAPF32[$229>>2] = $585;
 HEAP32[$230>>2] = $591;
 $$3 = 1;
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return ($$3|0);
}
function __ZN5physx2Gu28computeConvex_HeightFieldMTDERKNS_21PxHeightFieldGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES6_ffbjRNS_10PxSweepHitE($heightFieldGeom,$pose,$convexGeom,$convexPose,$inflation,$distance,$isDoubleSided,$flags,$hit) {
 $heightFieldGeom = $heightFieldGeom|0;
 $pose = $pose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $inflation = Math_fround($inflation);
 $distance = Math_fround($distance);
 $isDoubleSided = $isDoubleSided|0;
 $flags = $flags|0;
 $hit = $hit|0;
 var $$$i$i = Math_fround(0), $$3 = 0, $$hadContacts$0$off0 = 0, $$lcssa$i$i = Math_fround(0), $$lcssa$i3$i = Math_fround(0), $$lcssa$i4$lcssa$i = Math_fround(0), $$lcssa$i45$i = Math_fround(0), $$pre = Math_fround(0), $$pre251 = Math_fround(0), $$pre252 = Math_fround(0), $$pre253 = Math_fround(0), $$pre254 = Math_fround(0), $$pre255 = Math_fround(0), $$pre256 = Math_fround(0), $$pre257 = Math_fround(0), $$pre258 = Math_fround(0), $$pre259 = Math_fround(0), $$sroa$175 = 0, $0 = 0, $1 = 0;
 var $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0);
 var $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0;
 var $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0;
 var $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0);
 var $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0);
 var $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0;
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0);
 var $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0);
 var $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0);
 var $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0);
 var $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0;
 var $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0);
 var $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0);
 var $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0);
 var $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = 0, $458 = 0, $459 = Math_fround(0), $46 = Math_fround(0);
 var $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0);
 var $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0);
 var $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0);
 var $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0);
 var $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0);
 var $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0);
 var $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0);
 var $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = 0, $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = 0;
 var $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = 0, $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0);
 var $622 = Math_fround(0), $623 = 0, $624 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0;
 var $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0);
 var $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $a$0223 = 0, $bounds = 0, $convexBuff = 0, $convexHull = 0, $convexScaling = 0, $convexTransformV = 0, $deepest$sroa$1$i$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i$i = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i6$i = Math_fround(0);
 var $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $foundInitial$0$off0236 = 0, $foundInitial$3$off0 = 0, $hadContacts$0$off0$lcssa$i = 0, $hadContacts$0$off0222 = 0, $hadContacts$0$off07$i = 0, $hadContacts$1$off0$i = 0, $hfUtil = 0, $hullOBB = 0, $i$0235 = 0, $index$0$lcssa$i$i = 0, $index$030$i$i = 0, $index$1$i$i = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$op = 0, $inflationV = 0, $j$06$i = 0, $k$0206 = 0;
 var $k$031$i$i = 0, $localReport$i = 0, $manifoldContacts = 0, $meshToConvexV = 0, $mtd$sroa$1 = 0, $numContacts = 0, $pen$sroa$1$i$i = 0, $polyData = 0, $storemerge = 0, $tempContainer = 0, $tempConvexPose = 0, $triangles = 0, $vQuat = 0, $vScale = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6176|0;
 $localReport$i = sp + 6152|0;
 $deepest$sroa$1$i$i = sp + 6140|0;
 $pen$sroa$1$i$i = sp + 6128|0;
 $hfUtil = sp + 6108|0;
 $zeroV = sp + 352|0;
 $manifoldContacts = sp + 368|0;
 $numContacts = sp + 6104|0;
 $convexScaling = sp + 6032|0;
 $convexTransformV = sp + 112|0;
 $vScale = sp + 96|0;
 $vQuat = sp + 80|0;
 $convexHull = sp + 144|0;
 $convexBuff = sp + 16|0;
 $inflationV = sp;
 $tempContainer = sp + 4528|0;
 $polyData = sp + 5824|0;
 $mtd$sroa$1 = sp + 5908|0;
 $tempConvexPose = sp + 5944|0;
 $hullOBB = sp + 5972|0;
 $bounds = sp + 5920|0;
 $meshToConvexV = sp + 4464|0;
 $$sroa$175 = sp + 5896|0;
 $triangles = sp + 4544|0;
 $0 = (($hfUtil) + 12|0);
 $1 = (($heightFieldGeom) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($hfUtil) + 16|0);
 HEAP32[$3>>2] = $heightFieldGeom;
 $4 = (($heightFieldGeom) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(Math_fround(1.0) / $5);
 $7 = (($hfUtil) + 4|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($heightFieldGeom) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(Math_fround(1.0) / $9);
 HEAPF32[$hfUtil>>2] = $10;
 $11 = (($heightFieldGeom) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(Math_fround(1.0) / $12);
 $14 = (($hfUtil) + 8|0);
 HEAPF32[$14>>2] = $13;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAP32[$numContacts>>2] = 0;
 $15 = (($convexGeom) + 32|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 16|0);
 $18 = (($convexGeom) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = $19 == Math_fround(1.0);
 if ($20) {
  $21 = (($convexGeom) + 8|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = $22 == Math_fround(1.0);
  if ($23) {
   $24 = (($convexGeom) + 12|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = $25 == Math_fround(1.0);
   $137 = $26;
  } else {
   $137 = 0;
  }
 } else {
  $137 = 0;
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $27 = (($convexScaling) + 4|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($convexScaling) + 8|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($convexScaling) + 12|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($convexScaling) + 16|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($convexScaling) + 20|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($convexScaling) + 24|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($convexScaling) + 28|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($convexScaling) + 32|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (($convexScaling) + 36|0);
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($convexScaling) + 40|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($convexScaling) + 44|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($convexScaling) + 48|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($convexScaling) + 52|0);
 HEAPF32[$39>>2] = Math_fround(1.0);
 $40 = (($convexScaling) + 56|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($convexScaling) + 60|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($convexScaling) + 64|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($convexScaling) + 68|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 if ($137) {
  $48 = Math_fround(1.0);$50 = Math_fround(0.0);$52 = Math_fround(0.0);$56 = Math_fround(0.0);$58 = Math_fround(1.0);$60 = Math_fround(0.0);$67 = Math_fround(0.0);$69 = Math_fround(0.0);$71 = Math_fround(1.0);$99 = $19;
 } else {
  $44 = (($convexGeom) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$18,$44);
  $$pre = Math_fround(HEAPF32[$convexScaling>>2]);
  $$pre251 = Math_fround(HEAPF32[$27>>2]);
  $$pre252 = Math_fround(HEAPF32[$28>>2]);
  $$pre253 = Math_fround(HEAPF32[$29>>2]);
  $$pre254 = Math_fround(HEAPF32[$30>>2]);
  $$pre255 = Math_fround(HEAPF32[$31>>2]);
  $$pre256 = Math_fround(HEAPF32[$32>>2]);
  $$pre257 = Math_fround(HEAPF32[$33>>2]);
  $$pre258 = Math_fround(HEAPF32[$34>>2]);
  $$pre259 = Math_fround(HEAPF32[$18>>2]);
  $48 = $$pre;$50 = $$pre251;$52 = $$pre252;$56 = $$pre253;$58 = $$pre254;$60 = $$pre255;$67 = $$pre256;$69 = $$pre257;$71 = $$pre258;$99 = $$pre259;
 }
 $45 = (($16) + 40|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 * $48);
 $49 = Math_fround($46 * $50);
 $51 = Math_fround($46 * $52);
 $53 = (($16) + 44|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 * $56);
 $57 = Math_fround($54 * $58);
 $59 = Math_fround($54 * $60);
 $61 = Math_fround($47 + $55);
 $62 = Math_fround($49 + $57);
 $63 = Math_fround($51 + $59);
 $64 = (($16) + 48|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 * $67);
 $68 = Math_fround($65 * $69);
 $70 = Math_fround($65 * $71);
 $72 = Math_fround($61 + $66);
 $73 = Math_fround($62 + $68);
 $74 = Math_fround($63 + $70);
 $75 = Math_fround(HEAPF32[$convexPose>>2]);
 $76 = (($convexPose) + 4|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($convexPose) + 8|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($convexPose) + 12|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($convexPose) + 16|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($82) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($82) + 8|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 HEAPF32[$convexTransformV>>2] = $75;
 $88 = (($convexTransformV) + 4|0);
 HEAPF32[$88>>2] = $77;
 $89 = (($convexTransformV) + 8|0);
 HEAPF32[$89>>2] = $79;
 $90 = (($convexTransformV) + 12|0);
 HEAPF32[$90>>2] = $81;
 $91 = (($convexTransformV) + 16|0);
 HEAPF32[$91>>2] = $83;
 $92 = (($convexTransformV) + 20|0);
 HEAPF32[$92>>2] = $85;
 $93 = (($convexTransformV) + 24|0);
 HEAPF32[$93>>2] = $87;
 $94 = (($convexTransformV) + 28|0);
 HEAPF32[$94>>2] = Math_fround(0.0);
 $95 = (($convexGeom) + 8|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($convexGeom) + 12|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 HEAPF32[$vScale>>2] = $99;
 $100 = (($vScale) + 4|0);
 HEAPF32[$100>>2] = $96;
 $101 = (($vScale) + 8|0);
 HEAPF32[$101>>2] = $98;
 $102 = (($vScale) + 12|0);
 HEAPF32[$102>>2] = Math_fround(0.0);
 $103 = (($convexGeom) + 16|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($103) + 4|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($103) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($103) + 12|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 HEAPF32[$vQuat>>2] = $104;
 $111 = (($vQuat) + 4|0);
 HEAPF32[$111>>2] = $106;
 $112 = (($vQuat) + 8|0);
 HEAPF32[$112>>2] = $108;
 $113 = (($vQuat) + 12|0);
 HEAPF32[$113>>2] = $110;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$17,$zeroV,$vScale,$vQuat);
 $114 = (($16) + 68|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($16) + 72|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($16) + 76|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround(HEAPF32[$vScale>>2]);
 $121 = Math_fround(HEAPF32[$100>>2]);
 $122 = Math_fround(HEAPF32[$101>>2]);
 $123 = Math_fround($115 * $120);
 $124 = Math_fround($117 * $121);
 $125 = Math_fround($119 * $122);
 $126 = !($123 <= $124);
 $$$i$i = $126 ? $124 : $123;
 $127 = !($$$i$i <= $125);
 $128 = $127 ? $125 : $$$i$i;
 $129 = Math_fround($128 * Math_fround(0.25));
 $130 = Math_fround($129 + $inflation);
 HEAPF32[$inflationV>>2] = $130;
 __ZN5physx2Gu9ContainerC2Ev($tempContainer);
 $131 = STACKTOP; STACKTOP = STACKTOP + 512|0;;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($tempContainer,128,$131,1);
 $132 = Math_fround(HEAPF32[$zeroV>>2]);
 $133 = (($zeroV) + 4|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($zeroV) + 8|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHull,$137,$polyData);
 $138 = Math_fround(HEAPF32[$convexPose>>2]);
 HEAPF32[$tempConvexPose>>2] = $138;
 $139 = (($tempConvexPose) + 4|0);
 $140 = (($convexPose) + 4|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 HEAPF32[$139>>2] = $141;
 $142 = (($tempConvexPose) + 8|0);
 $143 = (($convexPose) + 8|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 HEAPF32[$142>>2] = $144;
 $145 = (($tempConvexPose) + 12|0);
 $146 = (($convexPose) + 12|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 HEAPF32[$145>>2] = $147;
 $148 = (($tempConvexPose) + 16|0);
 $149 = Math_fround(HEAPF32[$82>>2]);
 HEAPF32[$148>>2] = $149;
 $150 = (($tempConvexPose) + 20|0);
 $151 = (($convexPose) + 20|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 HEAPF32[$150>>2] = $152;
 $153 = (($tempConvexPose) + 24|0);
 $154 = (($convexPose) + 24|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 HEAPF32[$153>>2] = $155;
 $156 = Math_fround(HEAPF32[$pose>>2]);
 $157 = Math_fround($156 + $156);
 $158 = (($pose) + 4|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = Math_fround($159 + $159);
 $161 = (($pose) + 8|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = Math_fround($162 + $162);
 $164 = (($pose) + 12|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = Math_fround($157 * $165);
 $167 = Math_fround($160 * $165);
 $168 = Math_fround($165 * $163);
 $169 = Math_fround($156 * $157);
 $170 = Math_fround($156 * $160);
 $171 = Math_fround($156 * $163);
 $172 = Math_fround($159 * $160);
 $173 = Math_fround($159 * $163);
 $174 = Math_fround($162 * $163);
 $175 = Math_fround(Math_fround(1.0) - $172);
 $176 = Math_fround($175 - $174);
 $177 = Math_fround($170 + $168);
 $178 = Math_fround($171 - $167);
 $179 = Math_fround($170 - $168);
 $180 = Math_fround(Math_fround(1.0) - $169);
 $181 = Math_fround($180 - $174);
 $182 = Math_fround($173 + $166);
 $183 = Math_fround($171 + $167);
 $184 = Math_fround($173 - $166);
 $185 = Math_fround($180 - $172);
 $186 = (($pose) + 16|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = (($pose) + 20|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = (($pose) + 24|0);
 $191 = Math_fround(HEAPF32[$190>>2]);
 $192 = (($tempContainer) + 4|0);
 $193 = (($convexHull) + 96|0);
 $194 = (($convexHull) + 144|0);
 $195 = (($convexBuff) + 32|0);
 $196 = (($convexBuff) + 36|0);
 $197 = (($convexBuff) + 40|0);
 $198 = (($convexBuff) + 44|0);
 $199 = $137&1;
 $200 = (($convexBuff) + 48|0);
 $201 = (($convexBuff) + 16|0);
 $202 = (($convexBuff) + 20|0);
 $203 = (($convexBuff) + 24|0);
 $204 = (($convexBuff) + 28|0);
 $205 = (($hullOBB) + 48|0);
 $206 = (($hullOBB) + 52|0);
 $207 = (($hullOBB) + 56|0);
 $208 = (($hullOBB) + 4|0);
 $209 = (($hullOBB) + 8|0);
 $210 = (($hullOBB) + 12|0);
 $211 = (($hullOBB) + 16|0);
 $212 = (($hullOBB) + 20|0);
 $213 = (($hullOBB) + 24|0);
 $214 = (($hullOBB) + 28|0);
 $215 = (($hullOBB) + 32|0);
 $216 = (($hullOBB) + 36|0);
 $217 = (($hullOBB) + 40|0);
 $218 = (($hullOBB) + 44|0);
 $219 = (($bounds) + 4|0);
 $220 = (($bounds) + 8|0);
 $221 = (($bounds) + 12|0);
 $222 = (($bounds) + 16|0);
 $223 = (($bounds) + 20|0);
 $224 = (($localReport$i) + 4|0);
 $225 = (($meshToConvexV) + 48|0);
 $226 = (($meshToConvexV) + 52|0);
 $227 = (($meshToConvexV) + 56|0);
 $228 = (($meshToConvexV) + 60|0);
 $229 = (($meshToConvexV) + 4|0);
 $230 = (($meshToConvexV) + 8|0);
 $231 = (($meshToConvexV) + 12|0);
 $232 = (($meshToConvexV) + 16|0);
 $233 = (($meshToConvexV) + 20|0);
 $234 = (($meshToConvexV) + 24|0);
 $235 = (($meshToConvexV) + 28|0);
 $236 = (($meshToConvexV) + 32|0);
 $237 = (($meshToConvexV) + 36|0);
 $238 = (($meshToConvexV) + 40|0);
 $239 = (($meshToConvexV) + 44|0);
 $240 = (($tempContainer) + 8|0);
 $241 = (($hit) + 40|0);
 $242 = (($hit) + 16|0);
 $243 = (($hit) + 20|0);
 $244 = (($hit) + 24|0);
 $245 = (($hit) + 28|0);
 $246 = (($hit) + 32|0);
 $247 = (($hit) + 36|0);
 $248 = (($hit) + 8|0);
 $249 = (($manifoldContacts) + 44|0);
 $252 = $83;$253 = $85;$254 = $87;$564 = $132;$566 = $134;$568 = $136;$592 = 268435455;$593 = $132;$594 = $134;$595 = $136;$596 = $132;$597 = $134;$598 = $136;$599 = $132;$600 = $134;$601 = $136;$foundInitial$0$off0236 = 0;$i$0235 = 0;
 while(1) {
  $250 = HEAP32[$192>>2]|0;
  $251 = ($250|0)==(0);
  if (!($251)) {
   HEAP32[$192>>2] = 0;
  }
  HEAPF32[$148>>2] = $252;
  HEAPF32[$150>>2] = $253;
  HEAPF32[$153>>2] = $254;
  HEAPF32[$91>>2] = $252;
  HEAPF32[$92>>2] = $253;
  HEAPF32[$93>>2] = $254;
  HEAPF32[$94>>2] = Math_fround(0.0);
  HEAP32[$195>>2] = $convexTransformV;
  HEAP32[$196>>2] = $193;
  HEAP32[$197>>2] = $194;
  HEAP8[$198>>0] = $199;
  $storemerge = $137 ? ((546744 + 8|0)) : ((546712 + 8|0));
  HEAP32[$convexBuff>>2] = $storemerge;
  HEAP32[$200>>2] = $convexHull;
  HEAPF32[$201>>2] = $72;
  HEAPF32[$202>>2] = $73;
  HEAPF32[$203>>2] = $74;
  HEAPF32[$204>>2] = Math_fround(0.0);
  __ZN5physx2Gu22computeOBBAroundConvexERNS0_3BoxERKNS_20PxConvexMeshGeometryEPKNS_12PxConvexMeshERKNS_11PxTransformE($hullOBB,$convexGeom,$16,$tempConvexPose);
  $255 = Math_fround(HEAPF32[$205>>2]);
  $256 = Math_fround($130 + $255);
  HEAPF32[$205>>2] = $256;
  $257 = Math_fround(HEAPF32[$206>>2]);
  $258 = Math_fround($130 + $257);
  HEAPF32[$206>>2] = $258;
  $259 = Math_fround(HEAPF32[$207>>2]);
  $260 = Math_fround($130 + $259);
  HEAPF32[$207>>2] = $260;
  $261 = Math_fround(HEAPF32[$hullOBB>>2]);
  $262 = Math_fround($256 * $261);
  $263 = Math_fround(HEAPF32[$208>>2]);
  $264 = Math_fround($256 * $263);
  $265 = Math_fround(HEAPF32[$209>>2]);
  $266 = Math_fround($256 * $265);
  $267 = Math_fround(HEAPF32[$210>>2]);
  $268 = Math_fround($258 * $267);
  $269 = Math_fround(HEAPF32[$211>>2]);
  $270 = Math_fround($258 * $269);
  $271 = Math_fround(HEAPF32[$212>>2]);
  $272 = Math_fround($258 * $271);
  $273 = Math_fround(HEAPF32[$213>>2]);
  $274 = Math_fround($260 * $273);
  $275 = Math_fround(HEAPF32[$214>>2]);
  $276 = Math_fround($260 * $275);
  $277 = Math_fround(HEAPF32[$215>>2]);
  $278 = Math_fround($260 * $277);
  $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($262)))));
  $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($268)))));
  $279 = Math_fround($fabsf$i$i4$i + $fabsf$i$i5$i);
  $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($274)))));
  $280 = Math_fround($279 + $fabsf$i$i6$i);
  $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($264)))));
  $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($270)))));
  $281 = Math_fround($fabsf$i$i7$i + $fabsf$i$i8$i);
  $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($276)))));
  $282 = Math_fround($281 + $fabsf$i$i3$i);
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($266)))));
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($272)))));
  $283 = Math_fround($fabsf$i$i2$i + $fabsf$i$i1$i);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($278)))));
  $284 = Math_fround($283 + $fabsf$i$i$i);
  $285 = Math_fround(HEAPF32[$216>>2]);
  $286 = Math_fround($285 - $280);
  $287 = Math_fround(HEAPF32[$217>>2]);
  $288 = Math_fround($287 - $282);
  $289 = Math_fround(HEAPF32[$218>>2]);
  $290 = Math_fround($289 - $284);
  $291 = Math_fround($280 + $285);
  $292 = Math_fround($282 + $287);
  $293 = Math_fround($284 + $289);
  HEAPF32[$bounds>>2] = $286;
  HEAPF32[$219>>2] = $288;
  HEAPF32[$220>>2] = $290;
  HEAPF32[$221>>2] = $291;
  HEAPF32[$222>>2] = $292;
  HEAPF32[$223>>2] = $293;
  HEAP32[$localReport$i>>2] = ((548560 + 8|0));
  HEAP32[$224>>2] = $tempContainer;
  (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$pose,$bounds,$flags,$localReport$i)|0);
  $294 = HEAP32[$192>>2]|0;
  $295 = ($294|0)==(0);
  if ($295) {
   $575 = $564;$577 = $566;$580 = $568;$588 = $593;$589 = $594;$590 = $595;$591 = $592;$foundInitial$3$off0 = $foundInitial$0$off0236;
   break;
  }
  $296 = Math_fround(HEAPF32[$148>>2]);
  $297 = Math_fround(HEAPF32[$150>>2]);
  $298 = Math_fround(HEAPF32[$153>>2]);
  $299 = Math_fround($296 * Math_fround(-2.0));
  $300 = Math_fround($297 * Math_fround(-2.0));
  $301 = Math_fround($298 * Math_fround(-2.0));
  $302 = Math_fround(HEAPF32[$145>>2]);
  $303 = Math_fround($302 * $302);
  $304 = Math_fround($303 + Math_fround(-0.5));
  $305 = Math_fround(HEAPF32[$tempConvexPose>>2]);
  $306 = Math_fround($299 * $305);
  $307 = Math_fround(HEAPF32[$139>>2]);
  $308 = Math_fround($300 * $307);
  $309 = Math_fround($306 + $308);
  $310 = Math_fround(HEAPF32[$142>>2]);
  $311 = Math_fround($301 * $310);
  $312 = Math_fround($309 + $311);
  $313 = Math_fround($299 * $304);
  $314 = Math_fround($301 * $307);
  $315 = Math_fround($300 * $310);
  $316 = Math_fround($314 - $315);
  $317 = Math_fround($302 * $316);
  $318 = Math_fround($313 - $317);
  $319 = Math_fround($305 * $312);
  $320 = Math_fround($319 + $318);
  $321 = Math_fround($300 * $304);
  $322 = Math_fround($299 * $310);
  $323 = Math_fround($301 * $305);
  $324 = Math_fround($322 - $323);
  $325 = Math_fround($302 * $324);
  $326 = Math_fround($321 - $325);
  $327 = Math_fround($307 * $312);
  $328 = Math_fround($327 + $326);
  $329 = Math_fround($301 * $304);
  $330 = Math_fround($300 * $305);
  $331 = Math_fround($299 * $307);
  $332 = Math_fround($330 - $331);
  $333 = Math_fround($302 * $332);
  $334 = Math_fround($329 - $333);
  $335 = Math_fround($310 * $312);
  $336 = Math_fround($334 + $335);
  $337 = Math_fround(-$305);
  $338 = Math_fround(-$307);
  $339 = Math_fround(-$310);
  $340 = Math_fround($337 - $305);
  $341 = Math_fround($338 - $307);
  $342 = Math_fround($339 - $310);
  $343 = Math_fround($302 * $340);
  $344 = Math_fround($302 * $341);
  $345 = Math_fround($302 * $342);
  $346 = Math_fround($340 * $337);
  $347 = Math_fround($341 * $337);
  $348 = Math_fround($342 * $337);
  $349 = Math_fround($341 * $338);
  $350 = Math_fround($342 * $338);
  $351 = Math_fround($342 * $339);
  $352 = Math_fround(Math_fround(1.0) - $349);
  $353 = Math_fround($352 - $351);
  $354 = Math_fround($347 + $345);
  $355 = Math_fround($348 - $344);
  $356 = Math_fround($347 - $345);
  $357 = Math_fround(Math_fround(1.0) - $346);
  $358 = Math_fround($357 - $351);
  $359 = Math_fround($343 + $350);
  $360 = Math_fround($344 + $348);
  $361 = Math_fround($350 - $343);
  $362 = Math_fround($357 - $349);
  $363 = Math_fround($176 * $353);
  $364 = Math_fround($176 * $354);
  $365 = Math_fround($176 * $355);
  $366 = Math_fround($177 * $356);
  $367 = Math_fround($177 * $358);
  $368 = Math_fround($177 * $359);
  $369 = Math_fround($363 + $366);
  $370 = Math_fround($364 + $367);
  $371 = Math_fround($365 + $368);
  $372 = Math_fround($178 * $360);
  $373 = Math_fround($178 * $361);
  $374 = Math_fround($178 * $362);
  $375 = Math_fround($372 + $369);
  $376 = Math_fround($373 + $370);
  $377 = Math_fround($374 + $371);
  $378 = Math_fround($179 * $353);
  $379 = Math_fround($179 * $354);
  $380 = Math_fround($179 * $355);
  $381 = Math_fround($181 * $356);
  $382 = Math_fround($181 * $358);
  $383 = Math_fround($181 * $359);
  $384 = Math_fround($378 + $381);
  $385 = Math_fround($379 + $382);
  $386 = Math_fround($380 + $383);
  $387 = Math_fround($182 * $360);
  $388 = Math_fround($182 * $361);
  $389 = Math_fround($182 * $362);
  $390 = Math_fround($387 + $384);
  $391 = Math_fround($388 + $385);
  $392 = Math_fround($389 + $386);
  $393 = Math_fround($183 * $353);
  $394 = Math_fround($183 * $354);
  $395 = Math_fround($183 * $355);
  $396 = Math_fround($184 * $356);
  $397 = Math_fround($184 * $358);
  $398 = Math_fround($184 * $359);
  $399 = Math_fround($393 + $396);
  $400 = Math_fround($394 + $397);
  $401 = Math_fround($395 + $398);
  $402 = Math_fround($185 * $360);
  $403 = Math_fround($185 * $361);
  $404 = Math_fround($185 * $362);
  $405 = Math_fround($402 + $399);
  $406 = Math_fround($403 + $400);
  $407 = Math_fround($404 + $401);
  $408 = Math_fround($187 * $353);
  $409 = Math_fround($187 * $354);
  $410 = Math_fround($187 * $355);
  $411 = Math_fround($189 * $356);
  $412 = Math_fround($189 * $358);
  $413 = Math_fround($189 * $359);
  $414 = Math_fround($408 + $411);
  $415 = Math_fround($409 + $412);
  $416 = Math_fround($410 + $413);
  $417 = Math_fround($191 * $360);
  $418 = Math_fround($191 * $361);
  $419 = Math_fround($191 * $362);
  $420 = Math_fround($417 + $414);
  $421 = Math_fround($418 + $415);
  $422 = Math_fround($419 + $416);
  $423 = Math_fround($320 + $420);
  $424 = Math_fround($328 + $421);
  $425 = Math_fround($336 + $422);
  HEAPF32[$225>>2] = $423;
  HEAPF32[$226>>2] = $424;
  HEAPF32[$227>>2] = $425;
  HEAPF32[$228>>2] = Math_fround(0.0);
  HEAPF32[$meshToConvexV>>2] = $375;
  HEAPF32[$229>>2] = $376;
  HEAPF32[$230>>2] = $377;
  HEAPF32[$231>>2] = Math_fround(0.0);
  HEAPF32[$232>>2] = $390;
  HEAPF32[$233>>2] = $391;
  HEAPF32[$234>>2] = $392;
  HEAPF32[$235>>2] = Math_fround(0.0);
  HEAPF32[$236>>2] = $405;
  HEAPF32[$237>>2] = $406;
  HEAPF32[$238>>2] = $407;
  HEAPF32[$239>>2] = Math_fround(0.0);
  $426 = HEAP32[$240>>2]|0;
  $427 = (($294) + 31)|0;
  ;HEAP32[$mtd$sroa$1+0>>2]=HEAP32[$$sroa$175+0>>2]|0;HEAP32[$mtd$sroa$1+4>>2]=HEAP32[$$sroa$175+4>>2]|0;HEAP32[$mtd$sroa$1+8>>2]=HEAP32[$$sroa$175+8>>2]|0;
  $428 = $427 >>> 5;
  $429 = ($428|0)==(0);
  if ($429) {
   $575 = $564;$577 = $566;$580 = $568;$588 = $593;$589 = $594;$590 = $595;$591 = $592;$foundInitial$3$off0 = $foundInitial$0$off0236;
   break;
  }
  $430 = $294 ^ -1;
  $602 = Math_fround(3.40282346638528859812E+38);$603 = $592;$604 = $596;$605 = $597;$606 = $598;$607 = $599;$608 = $600;$609 = $601;$a$0223 = 0;$hadContacts$0$off0222 = 0;$indvars$iv = $430;
  while(1) {
   $431 = ($indvars$iv>>>0)>(4294967263);
   $indvars$iv$op = $indvars$iv ^ -1;
   $432 = $431 ? $indvars$iv$op : 32;
   $433 = $a$0223 << 5;
   $434 = (($294) - ($433))|0;
   $435 = ($434>>>0)<(32);
   $436 = $435 ? $434 : 32;
   $437 = ($436|0)==(0);
   if ($437) {
    ;HEAP32[$localReport$i+0>>2]=HEAP32[$mtd$sroa$1+0>>2]|0;HEAP32[$localReport$i+4>>2]=HEAP32[$mtd$sroa$1+4>>2]|0;HEAP32[$localReport$i+8>>2]=HEAP32[$mtd$sroa$1+8>>2]|0;
    $$lcssa$i4$lcssa$i = $602;$474 = $603;$483 = $604;$485 = $605;$487 = $606;$521 = $607;$523 = $608;$525 = $609;$hadContacts$0$off0$lcssa$i = 0;
   } else {
    $k$0206 = 0;
    while(1) {
     $438 = (($k$0206) + ($433))|0;
     $439 = (($426) + ($438<<2)|0);
     $440 = HEAP32[$439>>2]|0;
     $441 = (($triangles) + (($k$0206*40)|0)|0);
     (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($hfUtil,$pose,$441,0,0,$440,0,0)|0);
     $442 = ((($triangles) + (($k$0206*40)|0)|0) + 36|0);
     HEAP8[$442>>0] = 56;
     $443 = (($k$0206) + 1)|0;
     $exitcond = ($443|0)==($432|0);
     if ($exitcond) {
      break;
     } else {
      $k$0206 = $443;
     }
    }
    ;HEAP32[$localReport$i+0>>2]=HEAP32[$mtd$sroa$1+0>>2]|0;HEAP32[$localReport$i+4>>2]=HEAP32[$mtd$sroa$1+4>>2]|0;HEAP32[$localReport$i+8>>2]=HEAP32[$mtd$sroa$1+8>>2]|0;
    if ($437) {
     $$lcssa$i4$lcssa$i = $602;$474 = $603;$483 = $604;$485 = $605;$487 = $606;$521 = $607;$523 = $608;$525 = $609;$hadContacts$0$off0$lcssa$i = 0;
    } else {
     $$lcssa$i45$i = $602;$610 = $609;$611 = $608;$612 = $607;$613 = $606;$614 = $605;$615 = $604;$616 = $603;$hadContacts$0$off07$i = 0;$j$06$i = 0;
     while(1) {
      HEAP32[$numContacts>>2] = 0;
      $444 = ((($triangles) + (($j$06$i*40)|0)|0) + 36|0);
      $445 = HEAP8[$444>>0]|0;
      $446 = (($triangles) + (($j$06$i*40)|0)|0);
      $447 = (($j$06$i) + ($433))|0;
      (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration15processTriangleERKNS0_13PolygonalDataEPNS0_12SupportLocalEPKNS_6PxVec3EjhRKNS_6shdfnd3aos6FloatVEbRKNSB_12PsTransformVERKNSB_15PsMatTransformVEPNS0_21MeshPersistentContactERj($polyData,$convexBuff,$446,$447,$445,$inflationV,$isDoubleSided,$convexTransformV,$meshToConvexV,$manifoldContacts,$numContacts)|0);
      $448 = HEAP32[$numContacts>>2]|0;
      $449 = ($448|0)==(0);
      if ($449) {
       $$lcssa$i3$i = $$lcssa$i45$i;$617 = $610;$618 = $611;$619 = $612;$620 = $613;$621 = $614;$622 = $615;$623 = $616;$hadContacts$1$off0$i = $hadContacts$0$off07$i;
      } else {
       $450 = Math_fround(HEAPF32[$249>>2]);
       $451 = ($448>>>0)>(1);
       if ($451) {
        $455 = $450;$index$030$i$i = 0;$k$031$i$i = 1;
        while(1) {
         $452 = ((($manifoldContacts) + ($k$031$i$i<<6)|0) + 44|0);
         $453 = Math_fround(HEAPF32[$452>>2]);
         $454 = $455 > $453;
         if ($454) {
          ;HEAP32[$deepest$sroa$1$i$i+0>>2]=HEAP32[$pen$sroa$1$i$i+0>>2]|0;HEAP32[$deepest$sroa$1$i$i+4>>2]=HEAP32[$pen$sroa$1$i$i+4>>2]|0;HEAP32[$deepest$sroa$1$i$i+8>>2]=HEAP32[$pen$sroa$1$i$i+8>>2]|0;
          $624 = $453;$index$1$i$i = $k$031$i$i;
         } else {
          $624 = $455;$index$1$i$i = $index$030$i$i;
         }
         $456 = (($k$031$i$i) + 1)|0;
         $exitcond$i$i = ($456|0)==($448|0);
         if ($exitcond$i$i) {
          $$lcssa$i$i = $624;$index$0$lcssa$i$i = $index$1$i$i;
          break;
         } else {
          $455 = $624;$index$030$i$i = $index$1$i$i;$k$031$i$i = $456;
         }
        }
       } else {
        $$lcssa$i$i = $450;$index$0$lcssa$i$i = 0;
       }
       $457 = $$lcssa$i45$i > $$lcssa$i$i;
       if ($457) {
        ;HEAP32[$localReport$i+0>>2]=HEAP32[$deepest$sroa$1$i$i+0>>2]|0;HEAP32[$localReport$i+4>>2]=HEAP32[$deepest$sroa$1$i$i+4>>2]|0;HEAP32[$localReport$i+8>>2]=HEAP32[$deepest$sroa$1$i$i+8>>2]|0;
        $458 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 32|0);
        $459 = Math_fround(HEAPF32[$458>>2]);
        $460 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 36|0);
        $461 = Math_fround(HEAPF32[$460>>2]);
        $462 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 40|0);
        $463 = Math_fround(HEAPF32[$462>>2]);
        $464 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 16|0);
        $465 = Math_fround(HEAPF32[$464>>2]);
        $466 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 20|0);
        $467 = Math_fround(HEAPF32[$466>>2]);
        $468 = ((($manifoldContacts) + ($index$0$lcssa$i$i<<6)|0) + 24|0);
        $469 = Math_fround(HEAPF32[$468>>2]);
        $$lcssa$i3$i = $$lcssa$i$i;$617 = $469;$618 = $467;$619 = $465;$620 = $463;$621 = $461;$622 = $459;$623 = $447;$hadContacts$1$off0$i = 1;
       } else {
        $$lcssa$i3$i = $$lcssa$i45$i;$617 = $610;$618 = $611;$619 = $612;$620 = $613;$621 = $614;$622 = $615;$623 = $616;$hadContacts$1$off0$i = 1;
       }
      }
      $470 = (($j$06$i) + 1)|0;
      $exitcond$i = ($470|0)==($436|0);
      if ($exitcond$i) {
       $$lcssa$i4$lcssa$i = $$lcssa$i3$i;$474 = $623;$483 = $622;$485 = $621;$487 = $620;$521 = $619;$523 = $618;$525 = $617;$hadContacts$0$off0$lcssa$i = $hadContacts$1$off0$i;
       break;
      } else {
       $$lcssa$i45$i = $$lcssa$i3$i;$610 = $617;$611 = $618;$612 = $619;$613 = $620;$614 = $621;$615 = $622;$616 = $623;$hadContacts$0$off07$i = $hadContacts$1$off0$i;$j$06$i = $470;
      }
     }
    }
   }
   ;HEAP32[$mtd$sroa$1+0>>2]=HEAP32[$localReport$i+0>>2]|0;HEAP32[$mtd$sroa$1+4>>2]=HEAP32[$localReport$i+4>>2]|0;HEAP32[$mtd$sroa$1+8>>2]=HEAP32[$localReport$i+8>>2]|0;
   $$hadContacts$0$off0 = $hadContacts$0$off0$lcssa$i | $hadContacts$0$off0222;
   $471 = (($a$0223) + 1)|0;
   $472 = ($471>>>0)<($428>>>0);
   $indvars$iv$next = (($indvars$iv) + 32)|0;
   if ($472) {
    $602 = $$lcssa$i4$lcssa$i;$603 = $474;$604 = $483;$605 = $485;$606 = $487;$607 = $521;$608 = $523;$609 = $525;$a$0223 = $471;$hadContacts$0$off0222 = $$hadContacts$0$off0;$indvars$iv = $indvars$iv$next;
   } else {
    break;
   }
  }
  if (!($$hadContacts$0$off0)) {
   $575 = $564;$577 = $566;$580 = $568;$588 = $593;$589 = $594;$590 = $595;$591 = $474;$foundInitial$3$off0 = $foundInitial$0$off0236;
   break;
  }
  $473 = (($426) + ($474<<2)|0);
  $475 = HEAP32[$473>>2]|0;
  $476 = Math_fround(HEAPF32[$convexTransformV>>2]);
  $477 = Math_fround(HEAPF32[$88>>2]);
  $478 = Math_fround(HEAPF32[$89>>2]);
  $479 = Math_fround(HEAPF32[$90>>2]);
  $480 = Math_fround($479 * $479);
  $481 = Math_fround($480 + Math_fround(-0.5));
  $482 = Math_fround($483 * $481);
  $484 = Math_fround($485 * $481);
  $486 = Math_fround($487 * $481);
  $488 = Math_fround($487 * $477);
  $489 = Math_fround($485 * $478);
  $490 = Math_fround($488 - $489);
  $491 = Math_fround($483 * $478);
  $492 = Math_fround($487 * $476);
  $493 = Math_fround($491 - $492);
  $494 = Math_fround($485 * $476);
  $495 = Math_fround($483 * $477);
  $496 = Math_fround($494 - $495);
  $497 = Math_fround($479 * $490);
  $498 = Math_fround($479 * $493);
  $499 = Math_fround($479 * $496);
  $500 = Math_fround($497 + $482);
  $501 = Math_fround($498 + $484);
  $502 = Math_fround($499 + $486);
  $503 = Math_fround($483 * $476);
  $504 = Math_fround($485 * $477);
  $505 = Math_fround($503 + $504);
  $506 = Math_fround($487 * $478);
  $507 = Math_fround($505 + $506);
  $508 = Math_fround($476 * $507);
  $509 = Math_fround($477 * $507);
  $510 = Math_fround($478 * $507);
  $511 = Math_fround($508 + $500);
  $512 = Math_fround($509 + $501);
  $513 = Math_fround($510 + $502);
  $514 = Math_fround($511 * Math_fround(2.0));
  $515 = Math_fround($512 * Math_fround(2.0));
  $516 = Math_fround($513 * Math_fround(2.0));
  $517 = Math_fround(HEAPF32[$91>>2]);
  $518 = Math_fround(HEAPF32[$92>>2]);
  $519 = Math_fround(HEAPF32[$93>>2]);
  $520 = Math_fround($521 * $481);
  $522 = Math_fround($523 * $481);
  $524 = Math_fround($525 * $481);
  $526 = Math_fround($525 * $477);
  $527 = Math_fround($523 * $478);
  $528 = Math_fround($526 - $527);
  $529 = Math_fround($521 * $478);
  $530 = Math_fround($525 * $476);
  $531 = Math_fround($529 - $530);
  $532 = Math_fround($523 * $476);
  $533 = Math_fround($521 * $477);
  $534 = Math_fround($532 - $533);
  $535 = Math_fround($479 * $528);
  $536 = Math_fround($479 * $531);
  $537 = Math_fround($479 * $534);
  $538 = Math_fround($535 + $520);
  $539 = Math_fround($536 + $522);
  $540 = Math_fround($537 + $524);
  $541 = Math_fround($521 * $476);
  $542 = Math_fround($523 * $477);
  $543 = Math_fround($541 + $542);
  $544 = Math_fround($525 * $478);
  $545 = Math_fround($543 + $544);
  $546 = Math_fround($476 * $545);
  $547 = Math_fround($477 * $545);
  $548 = Math_fround($478 * $545);
  $549 = Math_fround($546 + $538);
  $550 = Math_fround($547 + $539);
  $551 = Math_fround($548 + $540);
  $552 = Math_fround($549 * Math_fround(2.0));
  $553 = Math_fround($550 * Math_fround(2.0));
  $554 = Math_fround($551 * Math_fround(2.0));
  $555 = Math_fround($517 + $552);
  $556 = Math_fround($518 + $553);
  $557 = Math_fround($519 + $554);
  $558 = !($$lcssa$i4$lcssa$i <= Math_fround(0.0));
  if ($558) {
   label = 27;
   break;
  }
  $560 = Math_fround($$lcssa$i4$lcssa$i * $514);
  $561 = Math_fround($$lcssa$i4$lcssa$i * $515);
  $562 = Math_fround($$lcssa$i4$lcssa$i * $516);
  $563 = Math_fround($564 - $560);
  $565 = Math_fround($566 - $561);
  $567 = Math_fround($568 - $562);
  $569 = Math_fround($252 - $560);
  $570 = Math_fround($253 - $561);
  $571 = Math_fround($254 - $562);
  $572 = (($i$0235) + 1)|0;
  $573 = ($572>>>0)<(2);
  if ($573) {
   $252 = $569;$253 = $570;$254 = $571;$564 = $563;$566 = $565;$568 = $567;$592 = $475;$593 = $555;$594 = $556;$595 = $557;$596 = $483;$597 = $485;$598 = $487;$599 = $521;$600 = $523;$601 = $525;$foundInitial$0$off0236 = 1;$i$0235 = $572;
  } else {
   $575 = $563;$577 = $565;$580 = $567;$588 = $555;$589 = $556;$590 = $557;$591 = $475;$foundInitial$3$off0 = 1;
   break;
  }
 }
 if ((label|0) == 27) {
  $559 = ($i$0235|0)==(0);
  if ($559) {
   HEAPF32[$241>>2] = Math_fround(0.0);
   HEAPF32[$242>>2] = $555;
   HEAPF32[$243>>2] = $556;
   HEAPF32[$244>>2] = $557;
   HEAPF32[$245>>2] = $514;
   HEAPF32[$246>>2] = $515;
   HEAPF32[$247>>2] = $516;
   HEAP32[$248>>2] = $475;
   $$3 = 1;
   __ZN5physx2Gu9ContainerD2Ev($tempContainer);
   STACKTOP = sp;return ($$3|0);
  } else {
   $575 = $564;$577 = $566;$580 = $568;$588 = $555;$589 = $556;$590 = $557;$591 = $475;$foundInitial$3$off0 = 1;
  }
 }
 $574 = Math_fround($575 * $575);
 $576 = Math_fround($577 * $577);
 $578 = Math_fround($576 + $574);
 $579 = Math_fround($580 * $580);
 $581 = Math_fround($579 + $578);
 $582 = (Math_fround(Math_sqrt((Math_fround($581)))));
 $583 = Math_fround(Math_fround(1.0) / $582);
 if (!($foundInitial$3$off0)) {
  $$3 = 0;
  __ZN5physx2Gu9ContainerD2Ev($tempContainer);
  STACKTOP = sp;return ($$3|0);
 }
 $584 = Math_fround(-$582);
 $585 = Math_fround($580 * $583);
 $586 = Math_fround($577 * $583);
 $587 = Math_fround($575 * $583);
 HEAPF32[$241>>2] = $584;
 HEAPF32[$242>>2] = $588;
 HEAPF32[$243>>2] = $589;
 HEAPF32[$244>>2] = $590;
 HEAPF32[$245>>2] = $587;
 HEAPF32[$246>>2] = $586;
 HEAPF32[$247>>2] = $585;
 HEAP32[$248>>2] = $591;
 $$3 = 1;
 __ZN5physx2Gu9ContainerD2Ev($tempContainer);
 STACKTOP = sp;return ($$3|0);
}
function __ZN5physx2Gu23computeSphere_SphereMTDERKNS0_6SphereES3_RNS_10PxSweepHitE($sphere0,$sphere1,$hit) {
 $sphere0 = $sphere0|0;
 $sphere1 = $sphere1|0;
 $hit = $hit|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$sphere1>>2]);
 $1 = Math_fround(HEAPF32[$sphere0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($sphere1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($sphere0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($sphere1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($sphere0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround($2 * $2);
 $14 = Math_fround($7 * $7);
 $15 = Math_fround($13 + $14);
 $16 = Math_fround($12 * $12);
 $17 = Math_fround($15 + $16);
 $18 = (($sphere0) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($sphere1) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($19 + $21);
 $23 = (Math_fround(Math_sqrt((Math_fround($17)))));
 $24 = Math_fround(Math_fround(1.0) / $23);
 $25 = Math_fround($2 * $24);
 $26 = Math_fround($7 * $24);
 $27 = Math_fround($12 * $24);
 $28 = (($hit) + 28|0);
 HEAPF32[$28>>2] = $25;
 $29 = (($hit) + 32|0);
 HEAPF32[$29>>2] = $26;
 $30 = (($hit) + 36|0);
 HEAPF32[$30>>2] = $27;
 $31 = Math_fround($23 - $22);
 $32 = (($hit) + 40|0);
 HEAPF32[$32>>2] = $31;
 $33 = Math_fround(HEAPF32[$18>>2]);
 $34 = Math_fround($33 * $25);
 $35 = Math_fround($33 * $26);
 $36 = Math_fround($33 * $27);
 $37 = Math_fround(HEAPF32[$sphere0>>2]);
 $38 = Math_fround($34 + $37);
 $39 = Math_fround(HEAPF32[$5>>2]);
 $40 = Math_fround($35 + $39);
 $41 = Math_fround(HEAPF32[$10>>2]);
 $42 = Math_fround($36 + $41);
 $43 = (($hit) + 16|0);
 HEAPF32[$43>>2] = $38;
 $44 = (($hit) + 20|0);
 HEAPF32[$44>>2] = $40;
 $45 = (($hit) + 24|0);
 HEAPF32[$45>>2] = $42;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu24computeSphere_CapsuleMTDERKNS0_6SphereERKNS0_7CapsuleERNS_10PxSweepHitE($sphere,$capsule,$hit) {
 $sphere = $sphere|0;
 $capsule = $capsule|0;
 $hit = $hit|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $u = sp;
 $0 = (($sphere) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($capsule) + 24|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = (($capsule) + 12|0);
 (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($capsule,$5,$sphere,$u)));
 $6 = Math_fround(HEAPF32[$u>>2]);
 $7 = (($capsule) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$capsule>>2]);
 $10 = Math_fround($8 - $9);
 $11 = (($capsule) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($capsule) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 - $14);
 $16 = (($capsule) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($capsule) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 - $19);
 $21 = Math_fround($6 * $10);
 $22 = Math_fround($6 * $15);
 $23 = Math_fround($6 * $20);
 $24 = Math_fround($9 + $21);
 $25 = Math_fround($14 + $22);
 $26 = Math_fround($19 + $23);
 $27 = Math_fround(HEAPF32[$sphere>>2]);
 $28 = Math_fround($24 - $27);
 $29 = (($sphere) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($25 - $30);
 $32 = (($sphere) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($26 - $33);
 $35 = Math_fround($28 * $28);
 $36 = Math_fround($31 * $31);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($34 * $34);
 $39 = Math_fround($37 + $38);
 $40 = (Math_fround(Math_sqrt((Math_fround($39)))));
 $41 = Math_fround(Math_fround(1.0) / $40);
 $42 = Math_fround($28 * $41);
 $43 = Math_fround($31 * $41);
 $44 = Math_fround($34 * $41);
 $45 = (($hit) + 28|0);
 HEAPF32[$45>>2] = $42;
 $46 = (($hit) + 32|0);
 HEAPF32[$46>>2] = $43;
 $47 = (($hit) + 36|0);
 HEAPF32[$47>>2] = $44;
 $48 = Math_fround($40 - $4);
 $49 = (($hit) + 40|0);
 HEAPF32[$49>>2] = $48;
 $50 = Math_fround(HEAPF32[$0>>2]);
 $51 = Math_fround($50 * $42);
 $52 = Math_fround($50 * $43);
 $53 = Math_fround($50 * $44);
 $54 = Math_fround(HEAPF32[$sphere>>2]);
 $55 = Math_fround($51 + $54);
 $56 = Math_fround(HEAPF32[$29>>2]);
 $57 = Math_fround($52 + $56);
 $58 = Math_fround(HEAPF32[$32>>2]);
 $59 = Math_fround($53 + $58);
 $60 = (($hit) + 16|0);
 HEAPF32[$60>>2] = $55;
 $61 = (($hit) + 20|0);
 HEAPF32[$61>>2] = $57;
 $62 = (($hit) + 24|0);
 HEAPF32[$62>>2] = $59;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu25computeCapsule_CapsuleMTDERKNS0_7CapsuleES3_RNS_10PxSweepHitE($capsule0,$capsule1,$hit) {
 $capsule0 = $capsule0|0;
 $capsule1 = $capsule1|0;
 $hit = $hit|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $s = 0, $t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $s = sp + 4|0;
 $t = sp;
 (Math_fround(__ZN5physx2Gu30distanceSegmentSegmentSquared2ERKNS0_7SegmentES3_PfS4_($capsule0,$capsule1,$s,$t)));
 $0 = (($capsule0) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($capsule1) + 24|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = Math_fround(HEAPF32[$s>>2]);
 $6 = (($capsule0) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(HEAPF32[$capsule0>>2]);
 $9 = Math_fround($7 - $8);
 $10 = (($capsule0) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($capsule0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($capsule0) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($capsule0) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = Math_fround($5 * $9);
 $21 = Math_fround($5 * $14);
 $22 = Math_fround($5 * $19);
 $23 = Math_fround($8 + $20);
 $24 = Math_fround($13 + $21);
 $25 = Math_fround($18 + $22);
 $26 = Math_fround(HEAPF32[$t>>2]);
 $27 = (($capsule1) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$capsule1>>2]);
 $30 = Math_fround($28 - $29);
 $31 = (($capsule1) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($capsule1) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($32 - $34);
 $36 = (($capsule1) + 20|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($capsule1) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($37 - $39);
 $41 = Math_fround($26 * $30);
 $42 = Math_fround($26 * $35);
 $43 = Math_fround($26 * $40);
 $44 = Math_fround($29 + $41);
 $45 = Math_fround($34 + $42);
 $46 = Math_fround($39 + $43);
 $47 = Math_fround($23 - $44);
 $48 = Math_fround($24 - $45);
 $49 = Math_fround($25 - $46);
 $50 = Math_fround($47 * $47);
 $51 = Math_fround($48 * $48);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($49 * $49);
 $54 = Math_fround($52 + $53);
 $55 = (Math_fround(Math_sqrt((Math_fround($54)))));
 $56 = Math_fround(Math_fround(1.0) / $55);
 $57 = Math_fround($47 * $56);
 $58 = Math_fround($56 * $48);
 $59 = Math_fround($56 * $49);
 $60 = (($hit) + 28|0);
 HEAPF32[$60>>2] = $57;
 $61 = (($hit) + 32|0);
 HEAPF32[$61>>2] = $58;
 $62 = (($hit) + 36|0);
 HEAPF32[$62>>2] = $59;
 $63 = Math_fround($55 - $4);
 $64 = (($hit) + 40|0);
 HEAPF32[$64>>2] = $63;
 $65 = Math_fround(HEAPF32[$2>>2]);
 $66 = Math_fround($65 * $57);
 $67 = Math_fround($65 * $58);
 $68 = Math_fround($65 * $59);
 $69 = Math_fround($44 + $66);
 $70 = Math_fround($45 + $67);
 $71 = Math_fround($46 + $68);
 $72 = (($hit) + 16|0);
 HEAPF32[$72>>2] = $69;
 $73 = (($hit) + 20|0);
 HEAPF32[$73>>2] = $70;
 $74 = (($hit) + 24|0);
 HEAPF32[$74>>2] = $71;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu23computePlane_CapsuleMTDERKNS_7PxPlaneERKNS0_7CapsuleERNS_10PxSweepHitE($plane,$capsule,$hit) {
 $plane = $plane|0;
 $capsule = $capsule|0;
 $hit = $hit|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $dmin$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$capsule>>2]);
 $1 = Math_fround(HEAPF32[$plane>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($capsule) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($plane) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($capsule) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($plane) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($plane) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + $14);
 $18 = (($capsule) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($1 * $19);
 $21 = (($capsule) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($6 * $22);
 $24 = Math_fround($20 + $23);
 $25 = (($capsule) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($12 * $26);
 $28 = Math_fround($24 + $27);
 $29 = Math_fround($16 + $28);
 $30 = $17 < $29;
 if ($30) {
  $44 = $0;$46 = $4;$48 = $10;$dmin$0 = $17;
 } else {
  $44 = $19;$46 = $22;$48 = $26;$dmin$0 = $29;
 }
 $31 = (($hit) + 28|0);
 HEAPF32[$31>>2] = $1;
 $32 = Math_fround(HEAPF32[$5>>2]);
 $33 = (($hit) + 32|0);
 HEAPF32[$33>>2] = $32;
 $34 = Math_fround(HEAPF32[$11>>2]);
 $35 = (($hit) + 36|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($capsule) + 24|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($dmin$0 - $37);
 $39 = (($hit) + 40|0);
 HEAPF32[$39>>2] = $38;
 $40 = Math_fround($dmin$0 * $1);
 $41 = Math_fround($dmin$0 * $32);
 $42 = Math_fround($dmin$0 * $34);
 $43 = Math_fround($44 - $40);
 $45 = Math_fround($46 - $41);
 $47 = Math_fround($48 - $42);
 $49 = (($hit) + 16|0);
 HEAPF32[$49>>2] = $43;
 $50 = (($hit) + 20|0);
 HEAPF32[$50>>2] = $45;
 $51 = (($hit) + 24|0);
 HEAPF32[$51>>2] = $47;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu19computePlane_BoxMTDERKNS_7PxPlaneERKNS0_3BoxERNS_10PxSweepHitE($plane,$box,$hit) {
 $plane = $plane|0;
 $box = $box|0;
 $hit = $hit|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0);
 var $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0;
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $dmin$1 = Math_fround(0), $dmin$1$1 = Math_fround(0);
 var $dmin$1$2 = Math_fround(0), $dmin$1$3 = Math_fround(0), $dmin$1$4 = Math_fround(0), $dmin$1$5 = Math_fround(0), $dmin$1$6 = Math_fround(0), $index$1 = 0, $index$1$1 = 0, $index$1$2 = 0, $index$1$3 = 0, $index$1$4 = 0, $index$1$5 = 0, $index$1$6 = 0, $pts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $pts = sp;
 $0 = (($box) + 36|0);
 $1 = (($box) + 48|0);
 $2 = (($box) + 12|0);
 $3 = (($box) + 24|0);
 __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($pts,$0,$1,$box,$2,$3);
 $4 = Math_fround(HEAPF32[$pts>>2]);
 $5 = Math_fround(HEAPF32[$plane>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($pts) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($plane) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = Math_fround($6 + $11);
 $13 = (($pts) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($plane) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = Math_fround($12 + $17);
 $19 = (($plane) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 + $18);
 $22 = (($pts) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $5);
 $25 = (($pts) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $10);
 $28 = Math_fround($24 + $27);
 $29 = (($pts) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $16);
 $32 = Math_fround($28 + $31);
 $33 = Math_fround($20 + $32);
 $34 = $21 > $33;
 $index$1 = $34&1;
 $dmin$1 = $34 ? $33 : $21;
 $35 = (($pts) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * $5);
 $38 = (($pts) + 28|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $10);
 $41 = Math_fround($37 + $40);
 $42 = (($pts) + 32|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $16);
 $45 = Math_fround($41 + $44);
 $46 = Math_fround($20 + $45);
 $47 = $dmin$1 > $46;
 $index$1$1 = $47 ? 2 : $index$1;
 $dmin$1$1 = $47 ? $46 : $dmin$1;
 $48 = (($pts) + 36|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * $5);
 $51 = (($pts) + 40|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 * $10);
 $54 = Math_fround($50 + $53);
 $55 = (($pts) + 44|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 * $16);
 $58 = Math_fround($54 + $57);
 $59 = Math_fround($20 + $58);
 $60 = $dmin$1$1 > $59;
 $index$1$2 = $60 ? 3 : $index$1$1;
 $dmin$1$2 = $60 ? $59 : $dmin$1$1;
 $61 = (($pts) + 48|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * $5);
 $64 = (($pts) + 52|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 * $10);
 $67 = Math_fround($63 + $66);
 $68 = (($pts) + 56|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 * $16);
 $71 = Math_fround($67 + $70);
 $72 = Math_fround($20 + $71);
 $73 = $dmin$1$2 > $72;
 $index$1$3 = $73 ? 4 : $index$1$2;
 $dmin$1$3 = $73 ? $72 : $dmin$1$2;
 $74 = (($pts) + 60|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 * $5);
 $77 = (($pts) + 64|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($78 * $10);
 $80 = Math_fround($76 + $79);
 $81 = (($pts) + 68|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 * $16);
 $84 = Math_fround($80 + $83);
 $85 = Math_fround($20 + $84);
 $86 = $dmin$1$3 > $85;
 $index$1$4 = $86 ? 5 : $index$1$3;
 $dmin$1$4 = $86 ? $85 : $dmin$1$3;
 $87 = (($pts) + 72|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($88 * $5);
 $90 = (($pts) + 76|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 * $10);
 $93 = Math_fround($89 + $92);
 $94 = (($pts) + 80|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($95 * $16);
 $97 = Math_fround($93 + $96);
 $98 = Math_fround($20 + $97);
 $99 = $dmin$1$4 > $98;
 $index$1$5 = $99 ? 6 : $index$1$4;
 $dmin$1$5 = $99 ? $98 : $dmin$1$4;
 $100 = (($pts) + 84|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($101 * $5);
 $103 = (($pts) + 88|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($104 * $10);
 $106 = Math_fround($102 + $105);
 $107 = (($pts) + 92|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($108 * $16);
 $110 = Math_fround($106 + $109);
 $111 = Math_fround($20 + $110);
 $112 = $dmin$1$5 > $111;
 $index$1$6 = $112 ? 7 : $index$1$5;
 $dmin$1$6 = $112 ? $111 : $dmin$1$5;
 $113 = Math_fround(HEAPF32[$plane>>2]);
 $114 = (($hit) + 28|0);
 HEAPF32[$114>>2] = $113;
 $115 = Math_fround(HEAPF32[$9>>2]);
 $116 = (($hit) + 32|0);
 HEAPF32[$116>>2] = $115;
 $117 = Math_fround(HEAPF32[$15>>2]);
 $118 = (($hit) + 36|0);
 HEAPF32[$118>>2] = $117;
 $119 = (($hit) + 40|0);
 HEAPF32[$119>>2] = $dmin$1$6;
 $120 = Math_fround(HEAPF32[$plane>>2]);
 $121 = Math_fround($dmin$1$6 * $120);
 $122 = Math_fround(HEAPF32[$9>>2]);
 $123 = Math_fround($dmin$1$6 * $122);
 $124 = Math_fround(HEAPF32[$15>>2]);
 $125 = Math_fround($dmin$1$6 * $124);
 $126 = (($pts) + (($index$1$6*12)|0)|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = Math_fround($127 - $121);
 $129 = ((($pts) + (($index$1$6*12)|0)|0) + 4|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = Math_fround($130 - $123);
 $132 = ((($pts) + (($index$1$6*12)|0)|0) + 8|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($133 - $125);
 $135 = (($hit) + 16|0);
 HEAPF32[$135>>2] = $128;
 $136 = (($hit) + 20|0);
 HEAPF32[$136>>2] = $131;
 $137 = (($hit) + 24|0);
 HEAPF32[$137>>2] = $134;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu22computePlane_ConvexMTDERKNS_7PxPlaneERKNS_20PxConvexMeshGeometryERKNS_11PxTransformERNS_10PxSweepHitE($plane,$convexGeom,$convexPose,$hit) {
 $plane = $plane|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $hit = $hit|0;
 var $$lcssa = Math_fround(0), $$lcssa10 = Math_fround(0), $$lcssa11 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0;
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = 0;
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $convexScaling = 0, $dmin$0$lcssa = Math_fround(0), $dmin$013 = Math_fround(0), $dmin$1 = Math_fround(0), $exitcond = 0, $i$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $convexScaling = sp;
 $0 = (($convexGeom) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($convexGeom) + 4|0);
 $3 = (($convexGeom) + 16|0);
 __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$2,$3);
 $4 = (($1) + 54|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = (($1) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 55|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = (($7) + (($10*20)|0)|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(HEAPF32[$convexScaling>>2]);
 $14 = Math_fround($12 * $13);
 $15 = (($convexScaling) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($12 * $16);
 $18 = (($convexScaling) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($12 * $19);
 $21 = ((($7) + (($10*20)|0)|0) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($convexScaling) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 * $24);
 $26 = (($convexScaling) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($22 * $27);
 $29 = (($convexScaling) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($22 * $30);
 $32 = Math_fround($14 + $25);
 $33 = Math_fround($17 + $28);
 $34 = Math_fround($20 + $31);
 $35 = ((($7) + (($10*20)|0)|0) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($convexScaling) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 * $38);
 $40 = (($convexScaling) + 28|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($36 * $41);
 $43 = (($convexScaling) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($36 * $44);
 $46 = Math_fround($32 + $39);
 $47 = Math_fround($33 + $42);
 $48 = Math_fround($34 + $45);
 $49 = Math_fround($46 * Math_fround(2.0));
 $50 = Math_fround($47 * Math_fround(2.0));
 $51 = Math_fround($48 * Math_fround(2.0));
 $52 = (($convexPose) + 12|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 * $53);
 $55 = Math_fround($54 + Math_fround(-0.5));
 $56 = Math_fround(HEAPF32[$convexPose>>2]);
 $57 = Math_fround($49 * $56);
 $58 = (($convexPose) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($50 * $59);
 $61 = Math_fround($57 + $60);
 $62 = (($convexPose) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($51 * $63);
 $65 = Math_fround($61 + $64);
 $66 = Math_fround($49 * $55);
 $67 = Math_fround($51 * $59);
 $68 = Math_fround($50 * $63);
 $69 = Math_fround($67 - $68);
 $70 = Math_fround($53 * $69);
 $71 = Math_fround($66 + $70);
 $72 = Math_fround($56 * $65);
 $73 = Math_fround($72 + $71);
 $74 = Math_fround($50 * $55);
 $75 = Math_fround($49 * $63);
 $76 = Math_fround($56 * $51);
 $77 = Math_fround($75 - $76);
 $78 = Math_fround($53 * $77);
 $79 = Math_fround($74 + $78);
 $80 = Math_fround($59 * $65);
 $81 = Math_fround($80 + $79);
 $82 = Math_fround($51 * $55);
 $83 = Math_fround($50 * $56);
 $84 = Math_fround($49 * $59);
 $85 = Math_fround($83 - $84);
 $86 = Math_fround($53 * $85);
 $87 = Math_fround($82 + $86);
 $88 = Math_fround($63 * $65);
 $89 = Math_fround($87 + $88);
 $90 = (($convexPose) + 16|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 + $73);
 $93 = (($convexPose) + 20|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 + $81);
 $96 = (($convexPose) + 24|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 + $89);
 $99 = Math_fround(HEAPF32[$plane>>2]);
 $100 = Math_fround($99 * $92);
 $101 = (($plane) + 4|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($102 * $95);
 $104 = Math_fround($100 + $103);
 $105 = (($plane) + 8|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($98 * $106);
 $108 = Math_fround($107 + $104);
 $109 = (($plane) + 12|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($110 + $108);
 $112 = ($5&255)>(1);
 if (!($112)) {
  $$lcssa = $98;$$lcssa10 = $95;$$lcssa11 = $92;$dmin$0$lcssa = $111;
  $180 = (($hit) + 28|0);
  HEAPF32[$180>>2] = $99;
  $181 = Math_fround(HEAPF32[$101>>2]);
  $182 = (($hit) + 32|0);
  HEAPF32[$182>>2] = $181;
  $183 = Math_fround(HEAPF32[$105>>2]);
  $184 = (($hit) + 36|0);
  HEAPF32[$184>>2] = $183;
  $185 = (($hit) + 40|0);
  HEAPF32[$185>>2] = $dmin$0$lcssa;
  $186 = Math_fround(HEAPF32[$plane>>2]);
  $187 = Math_fround($dmin$0$lcssa * $186);
  $188 = Math_fround(HEAPF32[$101>>2]);
  $189 = Math_fround($dmin$0$lcssa * $188);
  $190 = Math_fround(HEAPF32[$105>>2]);
  $191 = Math_fround($dmin$0$lcssa * $190);
  $192 = Math_fround($$lcssa11 - $187);
  $193 = Math_fround($$lcssa10 - $189);
  $194 = Math_fround($$lcssa - $191);
  $195 = (($hit) + 16|0);
  HEAPF32[$195>>2] = $192;
  $196 = (($hit) + 20|0);
  HEAPF32[$196>>2] = $193;
  $197 = (($hit) + 24|0);
  HEAPF32[$197>>2] = $194;
  STACKTOP = sp;return 1;
 }
 $113 = Math_fround(HEAPF32[$convexScaling>>2]);
 $114 = Math_fround(HEAPF32[$15>>2]);
 $115 = $5&255;
 $198 = $92;$199 = $95;$200 = $98;$dmin$013 = $111;$i$012 = 1;
 while(1) {
  $116 = (($11) + (($i$012*12)|0)|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = Math_fround($117 * $113);
  $119 = Math_fround($117 * $114);
  $120 = Math_fround($117 * $19);
  $121 = ((($11) + (($i$012*12)|0)|0) + 4|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround($122 * $24);
  $124 = Math_fround($122 * $27);
  $125 = Math_fround($122 * $30);
  $126 = Math_fround($118 + $123);
  $127 = Math_fround($119 + $124);
  $128 = Math_fround($120 + $125);
  $129 = ((($11) + (($i$012*12)|0)|0) + 8|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($130 * $38);
  $132 = Math_fround($130 * $41);
  $133 = Math_fround($130 * $44);
  $134 = Math_fround($126 + $131);
  $135 = Math_fround($127 + $132);
  $136 = Math_fround($128 + $133);
  $137 = Math_fround($134 * Math_fround(2.0));
  $138 = Math_fround($135 * Math_fround(2.0));
  $139 = Math_fround($136 * Math_fround(2.0));
  $140 = Math_fround($137 * $56);
  $141 = Math_fround($138 * $59);
  $142 = Math_fround($140 + $141);
  $143 = Math_fround($139 * $63);
  $144 = Math_fround($142 + $143);
  $145 = Math_fround($137 * $55);
  $146 = Math_fround($139 * $59);
  $147 = Math_fround($138 * $63);
  $148 = Math_fround($146 - $147);
  $149 = Math_fround($53 * $148);
  $150 = Math_fround($145 + $149);
  $151 = Math_fround($56 * $144);
  $152 = Math_fround($151 + $150);
  $153 = Math_fround($138 * $55);
  $154 = Math_fround($137 * $63);
  $155 = Math_fround($56 * $139);
  $156 = Math_fround($154 - $155);
  $157 = Math_fround($53 * $156);
  $158 = Math_fround($153 + $157);
  $159 = Math_fround($59 * $144);
  $160 = Math_fround($159 + $158);
  $161 = Math_fround($139 * $55);
  $162 = Math_fround($138 * $56);
  $163 = Math_fround($137 * $59);
  $164 = Math_fround($162 - $163);
  $165 = Math_fround($53 * $164);
  $166 = Math_fround($161 + $165);
  $167 = Math_fround($63 * $144);
  $168 = Math_fround($166 + $167);
  $169 = Math_fround($91 + $152);
  $170 = Math_fround($94 + $160);
  $171 = Math_fround($97 + $168);
  $172 = Math_fround($99 * $169);
  $173 = Math_fround($102 * $170);
  $174 = Math_fround($172 + $173);
  $175 = Math_fround($171 * $106);
  $176 = Math_fround($175 + $174);
  $177 = Math_fround($110 + $176);
  $178 = $dmin$013 > $177;
  if ($178) {
   $201 = $171;$202 = $170;$203 = $169;$dmin$1 = $177;
  } else {
   $201 = $200;$202 = $199;$203 = $198;$dmin$1 = $dmin$013;
  }
  $179 = (($i$012) + 1)|0;
  $exitcond = ($179|0)==($115|0);
  if ($exitcond) {
   $$lcssa = $201;$$lcssa10 = $202;$$lcssa11 = $203;$dmin$0$lcssa = $dmin$1;
   break;
  } else {
   $198 = $203;$199 = $202;$200 = $201;$dmin$013 = $dmin$1;$i$012 = $179;
  }
 }
 $180 = (($hit) + 28|0);
 HEAPF32[$180>>2] = $99;
 $181 = Math_fround(HEAPF32[$101>>2]);
 $182 = (($hit) + 32|0);
 HEAPF32[$182>>2] = $181;
 $183 = Math_fround(HEAPF32[$105>>2]);
 $184 = (($hit) + 36|0);
 HEAPF32[$184>>2] = $183;
 $185 = (($hit) + 40|0);
 HEAPF32[$185>>2] = $dmin$0$lcssa;
 $186 = Math_fround(HEAPF32[$plane>>2]);
 $187 = Math_fround($dmin$0$lcssa * $186);
 $188 = Math_fround(HEAPF32[$101>>2]);
 $189 = Math_fround($dmin$0$lcssa * $188);
 $190 = Math_fround(HEAPF32[$105>>2]);
 $191 = Math_fround($dmin$0$lcssa * $190);
 $192 = Math_fround($$lcssa11 - $187);
 $193 = Math_fround($$lcssa10 - $189);
 $194 = Math_fround($$lcssa - $191);
 $195 = (($hit) + 16|0);
 HEAPF32[$195>>2] = $192;
 $196 = (($hit) + 20|0);
 HEAPF32[$196>>2] = $193;
 $197 = (($hit) + 24|0);
 HEAPF32[$197>>2] = $194;
 STACKTOP = sp;return 1;
}
function __ZN24MidPhaseQueryLocalReportD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN24MidPhaseQueryLocalReportD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN24MidPhaseQueryLocalReport7onEventEjPj($this,$nb,$indices) {
 $this = $this|0;
 $nb = $nb|0;
 $indices = $indices|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nb|0)==(0);
 if ($0) {
  STACKTOP = sp;return 1;
 }
 $1 = (($this) + 4|0);
 $i$01 = 0;
 while(1) {
  $2 = (($indices) + ($i$01<<2)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$1>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$4>>2]|0;
  $8 = ($6|0)==($7|0);
  if ($8) {
   (__ZN5physx2Gu9Container6ResizeEj($4,1)|0);
   $$pre$i = HEAP32[$5>>2]|0;
   $10 = $$pre$i;
  } else {
   $10 = $6;
  }
  $9 = (($10) + 1)|0;
  HEAP32[$5>>2] = $9;
  $11 = (($4) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($10<<2)|0);
  HEAP32[$13>>2] = $3;
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($nb|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $14;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZNK5physx2Gu12TriangleMesh20computeWorldTriangleERNS_10PxTriangleEjRKNS_2Cm8Matrix34EPjS8_($this,$worldTri,$triangleIndex,$worldMatrix,$vertexIndices,$adjacencyIndices) {
 $this = $this|0;
 $worldTri = $worldTri|0;
 $triangleIndex = $triangleIndex|0;
 $worldMatrix = $worldMatrix|0;
 $vertexIndices = $vertexIndices|0;
 $adjacencyIndices = $adjacencyIndices|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $vref0$0 = 0, $vref1$0 = 0, $vref2$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 172|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 2;
 $3 = ($2<<24>>24)==(0);
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 if ($3) {
  $15 = (($5) + (($triangleIndex*12)|0)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($5) + (($triangleIndex*12)|0)|0) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($5) + (($triangleIndex*12)|0)|0) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $vref0$0 = $16;$vref1$0 = $18;$vref2$0 = $20;
 } else {
  $6 = (($5) + (($triangleIndex*6)|0)|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = $7&65535;
  $9 = ((($5) + (($triangleIndex*6)|0)|0) + 2|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = $10&65535;
  $12 = ((($5) + (($triangleIndex*6)|0)|0) + 4|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $vref0$0 = $8;$vref1$0 = $11;$vref2$0 = $14;
 }
 $21 = (($this) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + (($vref0$0*12)|0)|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(HEAPF32[$worldMatrix>>2]);
 $26 = Math_fround($24 * $25);
 $27 = (($worldMatrix) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($24 * $28);
 $30 = (($worldMatrix) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($24 * $31);
 $33 = ((($22) + (($vref0$0*12)|0)|0) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($worldMatrix) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 * $36);
 $38 = (($worldMatrix) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($34 * $39);
 $41 = (($worldMatrix) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($34 * $42);
 $44 = Math_fround($26 + $37);
 $45 = Math_fround($29 + $40);
 $46 = Math_fround($32 + $43);
 $47 = ((($22) + (($vref0$0*12)|0)|0) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($worldMatrix) + 24|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($48 * $50);
 $52 = (($worldMatrix) + 28|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($48 * $53);
 $55 = (($worldMatrix) + 32|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($48 * $56);
 $58 = Math_fround($44 + $51);
 $59 = Math_fround($45 + $54);
 $60 = Math_fround($46 + $57);
 $61 = (($worldMatrix) + 36|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($58 + $62);
 $64 = (($worldMatrix) + 40|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($59 + $65);
 $67 = (($worldMatrix) + 44|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($60 + $68);
 HEAPF32[$worldTri>>2] = $63;
 $70 = (($worldTri) + 4|0);
 HEAPF32[$70>>2] = $66;
 $71 = (($worldTri) + 8|0);
 HEAPF32[$71>>2] = $69;
 $72 = (($22) + (($vref1$0*12)|0)|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround(HEAPF32[$worldMatrix>>2]);
 $75 = Math_fround($73 * $74);
 $76 = Math_fround(HEAPF32[$27>>2]);
 $77 = Math_fround($73 * $76);
 $78 = Math_fround(HEAPF32[$30>>2]);
 $79 = Math_fround($73 * $78);
 $80 = ((($22) + (($vref1$0*12)|0)|0) + 4|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround(HEAPF32[$35>>2]);
 $83 = Math_fround($81 * $82);
 $84 = Math_fround(HEAPF32[$38>>2]);
 $85 = Math_fround($81 * $84);
 $86 = Math_fround(HEAPF32[$41>>2]);
 $87 = Math_fround($81 * $86);
 $88 = Math_fround($75 + $83);
 $89 = Math_fround($77 + $85);
 $90 = Math_fround($79 + $87);
 $91 = ((($22) + (($vref1$0*12)|0)|0) + 8|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround(HEAPF32[$49>>2]);
 $94 = Math_fround($92 * $93);
 $95 = Math_fround(HEAPF32[$52>>2]);
 $96 = Math_fround($92 * $95);
 $97 = Math_fround(HEAPF32[$55>>2]);
 $98 = Math_fround($92 * $97);
 $99 = Math_fround($88 + $94);
 $100 = Math_fround($89 + $96);
 $101 = Math_fround($90 + $98);
 $102 = Math_fround(HEAPF32[$61>>2]);
 $103 = Math_fround($99 + $102);
 $104 = Math_fround(HEAPF32[$64>>2]);
 $105 = Math_fround($100 + $104);
 $106 = Math_fround(HEAPF32[$67>>2]);
 $107 = Math_fround($101 + $106);
 $108 = (($worldTri) + 12|0);
 HEAPF32[$108>>2] = $103;
 $109 = (($worldTri) + 16|0);
 HEAPF32[$109>>2] = $105;
 $110 = (($worldTri) + 20|0);
 HEAPF32[$110>>2] = $107;
 $111 = (($22) + (($vref2$0*12)|0)|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround(HEAPF32[$worldMatrix>>2]);
 $114 = Math_fround($112 * $113);
 $115 = Math_fround(HEAPF32[$27>>2]);
 $116 = Math_fround($112 * $115);
 $117 = Math_fround(HEAPF32[$30>>2]);
 $118 = Math_fround($112 * $117);
 $119 = ((($22) + (($vref2$0*12)|0)|0) + 4|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround(HEAPF32[$35>>2]);
 $122 = Math_fround($120 * $121);
 $123 = Math_fround(HEAPF32[$38>>2]);
 $124 = Math_fround($120 * $123);
 $125 = Math_fround(HEAPF32[$41>>2]);
 $126 = Math_fround($120 * $125);
 $127 = Math_fround($114 + $122);
 $128 = Math_fround($116 + $124);
 $129 = Math_fround($118 + $126);
 $130 = ((($22) + (($vref2$0*12)|0)|0) + 8|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround(HEAPF32[$49>>2]);
 $133 = Math_fround($131 * $132);
 $134 = Math_fround(HEAPF32[$52>>2]);
 $135 = Math_fround($131 * $134);
 $136 = Math_fround(HEAPF32[$55>>2]);
 $137 = Math_fround($131 * $136);
 $138 = Math_fround($127 + $133);
 $139 = Math_fround($128 + $135);
 $140 = Math_fround($129 + $137);
 $141 = Math_fround(HEAPF32[$61>>2]);
 $142 = Math_fround($138 + $141);
 $143 = Math_fround(HEAPF32[$64>>2]);
 $144 = Math_fround($139 + $143);
 $145 = Math_fround(HEAPF32[$67>>2]);
 $146 = Math_fround($140 + $145);
 $147 = (($worldTri) + 24|0);
 HEAPF32[$147>>2] = $142;
 $148 = (($worldTri) + 28|0);
 HEAPF32[$148>>2] = $144;
 $149 = (($worldTri) + 32|0);
 HEAPF32[$149>>2] = $146;
 $150 = ($vertexIndices|0)==(0|0);
 if (!($150)) {
  HEAP32[$vertexIndices>>2] = $vref0$0;
  $151 = (($vertexIndices) + 4|0);
  HEAP32[$151>>2] = $vref1$0;
  $152 = (($vertexIndices) + 8|0);
  HEAP32[$152>>2] = $vref2$0;
 }
 $153 = ($adjacencyIndices|0)==(0|0);
 if ($153) {
  STACKTOP = sp;return;
 }
 $154 = (($this) + 184|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = ($155|0)==(0|0);
 if ($156) {
  HEAP32[$adjacencyIndices>>2] = -1;
  $168 = (($adjacencyIndices) + 4|0);
  HEAP32[$168>>2] = -1;
  $169 = (($adjacencyIndices) + 8|0);
  HEAP32[$169>>2] = -1;
  STACKTOP = sp;return;
 } else {
  $157 = ($triangleIndex*3)|0;
  $158 = (($155) + ($157<<2)|0);
  $159 = HEAP32[$158>>2]|0;
  HEAP32[$adjacencyIndices>>2] = $159;
  $160 = (($157) + 1)|0;
  $161 = (($155) + ($160<<2)|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = (($adjacencyIndices) + 4|0);
  HEAP32[$163>>2] = $162;
  $164 = (($157) + 2)|0;
  $165 = (($155) + ($164<<2)|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = (($adjacencyIndices) + 8|0);
  HEAP32[$167>>2] = $166;
  STACKTOP = sp;return;
 }
}
function __ZN25MeshMTDGenerationCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN25MeshMTDGenerationCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$hit,$0,$1,$2,$3,$4) {
 $this = $this|0;
 $hit = $hit|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 var $$pre$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($hit) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$6>>2]|0;
 $12 = ($10|0)==($11|0);
 if ($12) {
  (__ZN5physx2Gu9Container6ResizeEj($6,1)|0);
  $$pre$i = HEAP32[$9>>2]|0;
  $14 = $$pre$i;
 } else {
  $14 = $10;
 }
 $13 = (($14) + 1)|0;
 HEAP32[$9>>2] = $13;
 $15 = (($6) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14<<2)|0);
 HEAP32[$17>>2] = $8;
 STACKTOP = sp;return 1;
}
function __ZN25MeshMTDGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __Z23sweepCapsule_SphereGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$lss,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $lss = $lss|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0;
 var $9 = 0, $sphere = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $sphere = sp + 32|0;
 $0 = sp;
 $1 = sp + 48|0;
 $2 = sp + 16|0;
 $3 = (($geom) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 + $inflation);
 $6 = (($pose) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$sphere>>2] = $7;
 $8 = (($sphere) + 4|0);
 $9 = (($pose) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $10;
 $11 = (($sphere) + 8|0);
 $12 = (($pose) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$11>>2] = $13;
 $14 = (($sphere) + 12|0);
 HEAPF32[$14>>2] = $5;
 $15 = Math_fround(HEAPF32[$unitDir>>2]);
 $16 = Math_fround(-$15);
 $17 = (($unitDir) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(-$18);
 $20 = (($unitDir) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(-$21);
 HEAPF32[$0>>2] = $16;
 $23 = (($0) + 4|0);
 HEAPF32[$23>>2] = $19;
 $24 = (($0) + 8|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($sweepHit) + 40|0);
 $26 = (($sweepHit) + 16|0);
 $27 = (($sweepHit) + 28|0);
 $28 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$1>>1] = $28;
 $29 = (__ZN5physx2Gu18sweepSphereCapsuleERKNS0_6SphereERKNS0_7CapsuleERKNS_6PxVec3EfRfRS7_SB_NS_7PxFlagsINS_9PxHitFlag4EnumEtEE($sphere,$lss,$0,$distance,$25,$26,$27,$1)|0);
 if (!($29)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = HEAP16[$hintFlags>>1]|0;
 $31 = $30 & 512;
 $32 = ($31<<16>>16)==(0);
 if ($32) {
  $57 = Math_fround(HEAPF32[$25>>2]);
  $58 = $57 != Math_fround(0.0);
  $59 = (($sweepHit) + 12|0);
  if ($58) {
   HEAP16[$59>>1] = 7;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   HEAP16[$59>>1] = 6;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $33 = (($sweepHit) + 12|0);
 HEAP16[$33>>1] = 7;
 $34 = Math_fround(HEAPF32[$25>>2]);
 $35 = $34 == Math_fround(0.0);
 if (!($35)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = Math_fround(HEAPF32[$lss>>2]);
 $37 = (($lss) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = $36 == $38;
 if ($39) {
  $40 = (($lss) + 4|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($lss) + 16|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = $41 == $43;
  if ($44) {
   $45 = (($lss) + 8|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($lss) + 20|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = $46 == $48;
   if ($49) {
    $50 = (($lss) + 24|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    HEAPF32[$2>>2] = $36;
    $52 = (($2) + 4|0);
    HEAPF32[$52>>2] = $41;
    $53 = (($2) + 8|0);
    HEAPF32[$53>>2] = $46;
    $54 = (($2) + 12|0);
    HEAPF32[$54>>2] = $51;
    $55 = (__ZN5physx2Gu23computeSphere_SphereMTDERKNS0_6SphereES3_RNS_10PxSweepHitE($sphere,$2,$sweepHit)|0);
    $$0 = $55;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $56 = (__ZN5physx2Gu24computeSphere_CapsuleMTDERKNS0_6SphereERKNS0_7CapsuleERNS_10PxSweepHitE($sphere,$lss,$sweepHit)|0);
 $$0 = $56;
 STACKTOP = sp;return ($$0|0);
}
function __Z22sweepCapsule_PlaneGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$lss,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $lss = $lss|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0;
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $dir$idx$val$i = Math_fround(0);
 var $dir$idx1$val$i = Math_fround(0), $dir$idx2$val$i = Math_fround(0), $index$1$1 = 0, $minDp$1 = Math_fround(0), $minDp$1$1 = Math_fround(0), $or$cond = 0, $or$cond$i = 0, $pts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $pts = sp;
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($0,$pose);
 $1 = (($lss) + 24|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($2 + $inflation);
 $4 = (($sweepHit) + 8|0);
 HEAP32[$4>>2] = -1;
 $5 = Math_fround(HEAPF32[$lss>>2]);
 HEAPF32[$pts>>2] = $5;
 $6 = (($lss) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($pts) + 4|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($lss) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($pts) + 8|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($lss) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($pts) + 12|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($lss) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($pts) + 16|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($lss) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($pts) + 20|0);
 HEAPF32[$20>>2] = $19;
 $21 = Math_fround(HEAPF32[$0>>2]);
 $22 = (($0) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($0) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($5 * $21);
 $27 = Math_fround($7 * $23);
 $28 = Math_fround($26 + $27);
 $29 = Math_fround($10 * $25);
 $30 = Math_fround($28 + $29);
 $31 = $30 < Math_fround(3.40282346638528859812E+38);
 $minDp$1 = $31 ? $30 : Math_fround(3.40282346638528859812E+38);
 $32 = Math_fround($13 * $21);
 $33 = Math_fround($16 * $23);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($19 * $25);
 $36 = Math_fround($34 + $35);
 $37 = $36 < $minDp$1;
 $minDp$1$1 = $37 ? $36 : $minDp$1;
 $index$1$1 = $37&1;
 $38 = HEAP16[$hintFlags>>1]|0;
 $39 = $38&65535;
 $40 = $39 & 512;
 $41 = ($40|0)==(0);
 if ($41) {
  $48 = $39 & 16;
  $49 = ($48|0)==(0);
  if ($49) {
   $50 = (($0) + 12|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = Math_fround($3 - $51);
   $53 = !($minDp$1$1 <= $52);
   if (!($53)) {
    $54 = (($sweepHit) + 12|0);
    HEAP16[$54>>1] = 6;
    $55 = (($sweepHit) + 40|0);
    HEAPF32[$55>>2] = Math_fround(0.0);
    $56 = Math_fround(HEAPF32[$unitDir>>2]);
    $57 = Math_fround(-$56);
    $58 = (($unitDir) + 4|0);
    $59 = Math_fround(HEAPF32[$58>>2]);
    $60 = Math_fround(-$59);
    $61 = (($unitDir) + 8|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = Math_fround(-$62);
    $64 = (($sweepHit) + 28|0);
    HEAPF32[$64>>2] = $57;
    $65 = (($sweepHit) + 32|0);
    HEAPF32[$65>>2] = $60;
    $66 = (($sweepHit) + 36|0);
    HEAPF32[$66>>2] = $63;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } else {
  $42 = (($0) + 12|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($3 - $43);
  $45 = !($minDp$1$1 <= $44);
  if (!($45)) {
   $46 = (($sweepHit) + 12|0);
   HEAP16[$46>>1] = 7;
   $47 = (__ZN5physx2Gu23computePlane_CapsuleMTDERKNS_7PxPlaneERKNS0_7CapsuleERNS_10PxSweepHitE($0,$lss,$sweepHit)|0);
   $$0 = $47;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $67 = Math_fround($3 * $21);
 $68 = Math_fround($3 * $23);
 $69 = Math_fround($3 * $25);
 $70 = (($pts) + (($index$1$1*12)|0)|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 - $67);
 $73 = ((($pts) + (($index$1$1*12)|0)|0) + 4|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($74 - $68);
 $76 = ((($pts) + (($index$1$1*12)|0)|0) + 8|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 - $69);
 $79 = Math_fround(HEAPF32[$unitDir>>2]);
 $80 = Math_fround($79 * $21);
 $81 = (($unitDir) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 * $23);
 $84 = Math_fround($80 + $83);
 $85 = (($unitDir) + 8|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 * $25);
 $88 = Math_fround($84 + $87);
 $89 = +$88;
 $90 = $89 > -9.99999999999999954748E-8;
 $91 = $89 < 9.99999999999999954748E-8;
 $or$cond$i = $90 & $91;
 if ($or$cond$i) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $92 = (($sweepHit) + 40|0);
 $93 = Math_fround($72 * $21);
 $94 = Math_fround($75 * $23);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($78 * $25);
 $97 = Math_fround($95 + $96);
 $98 = (($0) + 12|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($97 + $99);
 $101 = Math_fround(-$100);
 $102 = Math_fround($101 / $88);
 HEAPF32[$92>>2] = $102;
 $dir$idx$val$i = Math_fround(HEAPF32[$unitDir>>2]);
 $dir$idx1$val$i = Math_fround(HEAPF32[$81>>2]);
 $dir$idx2$val$i = Math_fround(HEAPF32[$85>>2]);
 $103 = Math_fround($102 * $dir$idx$val$i);
 $104 = Math_fround($102 * $dir$idx1$val$i);
 $105 = Math_fround($102 * $dir$idx2$val$i);
 $106 = Math_fround($72 + $103);
 $107 = Math_fround($75 + $104);
 $108 = Math_fround($78 + $105);
 $109 = (($sweepHit) + 16|0);
 HEAPF32[$109>>2] = $106;
 $110 = (($sweepHit) + 20|0);
 HEAPF32[$110>>2] = $107;
 $111 = (($sweepHit) + 24|0);
 HEAPF32[$111>>2] = $108;
 $112 = !($102 > Math_fround(0.0));
 $113 = !($102 <= $distance);
 $or$cond = $112 | $113;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $114 = (($sweepHit) + 28|0);
 HEAPF32[$114>>2] = $21;
 $115 = (($sweepHit) + 32|0);
 HEAPF32[$115>>2] = $23;
 $116 = (($sweepHit) + 36|0);
 HEAPF32[$116>>2] = $25;
 $117 = (($sweepHit) + 12|0);
 HEAP16[$117>>1] = 7;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z24sweepCapsule_CapsuleGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$lss,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $lss = $lss|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $$not = 0, $$not1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0);
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $brmerge = 0, $outFlags = 0, $staticCapsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $staticCapsule = sp + 12|0;
 $outFlags = sp + 40|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$pose>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($pose) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = Math_fround($4 * $5);
 $7 = Math_fround($6 + Math_fround(-1.0));
 $8 = Math_fround($1 * $2);
 $9 = Math_fround($8 + $7);
 $10 = (($pose) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $5);
 $13 = (($pose) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($2 * $14);
 $16 = Math_fround($12 + $15);
 $17 = Math_fround($5 * $14);
 $18 = Math_fround($2 * $11);
 $19 = Math_fround($18 - $17);
 $20 = (($geom) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $9);
 $23 = Math_fround($21 * $16);
 $24 = Math_fround($21 * $19);
 $25 = (($pose) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + $22);
 $28 = (($pose) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 + $23);
 $31 = (($pose) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 + $32);
 HEAPF32[$staticCapsule>>2] = $27;
 $34 = (($staticCapsule) + 4|0);
 HEAPF32[$34>>2] = $30;
 $35 = (($staticCapsule) + 8|0);
 HEAPF32[$35>>2] = $33;
 $36 = Math_fround($26 - $22);
 $37 = Math_fround($29 - $23);
 $38 = Math_fround($32 - $24);
 $39 = (($staticCapsule) + 12|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($staticCapsule) + 16|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($staticCapsule) + 20|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($geom) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($staticCapsule) + 24|0);
 $45 = Math_fround($43 + $inflation);
 HEAPF32[$44>>2] = $45;
 $46 = HEAP16[$hintFlags>>1]|0;
 $47 = Math_fround(HEAPF32[$unitDir>>2]);
 $48 = Math_fround(-$47);
 $49 = (($unitDir) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround(-$50);
 $52 = (($unitDir) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround(-$53);
 HEAPF32[$0>>2] = $48;
 $55 = (($0) + 4|0);
 HEAPF32[$55>>2] = $51;
 $56 = (($0) + 8|0);
 HEAPF32[$56>>2] = $54;
 $57 = (($sweepHit) + 40|0);
 $58 = (($sweepHit) + 16|0);
 $59 = (($sweepHit) + 28|0);
 $60 = $46&65535;
 $61 = (__ZN5physx2Gu19sweepCapsuleCapsuleERKNS0_7CapsuleES3_RKNS_6PxVec3EfRfRS4_S8_jRt($lss,$staticCapsule,$0,$distance,$57,$58,$59,$60,$outFlags)|0);
 if (!($61)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $62 = $46 & 512;
 $63 = HEAP16[$outFlags>>1]|0;
 $64 = (($sweepHit) + 12|0);
 HEAP16[$64>>1] = $63;
 $65 = Math_fround(HEAPF32[$57>>2]);
 $$not = $65 != Math_fround(0.0);
 $$not1 = ($62<<16>>16)==(0);
 $brmerge = $$not | $$not1;
 if ($brmerge) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = $63&65535;
 $67 = $66 | 1;
 $68 = $67&65535;
 HEAP16[$64>>1] = $68;
 $69 = (__ZN5physx2Gu25computeCapsule_CapsuleMTDERKNS0_7CapsuleES3_RNS_10PxSweepHitE($lss,$staticCapsule,$sweepHit)|0);
 $$0 = $69;
 STACKTOP = sp;return ($$0|0);
}
function __Z23sweepCapsule_ConvexGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$lss,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $lss = $lss|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $$idx$phi$trans$insert = 0, $$idx$val = Math_fround(0), $$idx$val$pre = Math_fround(0), $$idx1$phi$trans$insert = 0, $$idx1$val = Math_fround(0), $$idx1$val$pre = Math_fround(0), $$idx2$phi$trans$insert = 0, $$idx2$val = Math_fround(0), $$idx2$val$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0);
 var $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0);
 var $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0);
 var $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0);
 var $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0);
 var $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0);
 var $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0);
 var $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = 0;
 var $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0);
 var $396 = Math_fround(0), $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0);
 var $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0);
 var $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0);
 var $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_capsuleHalfHeight = 0, $capTransform = 0, $capsule = 0, $capsuleRadius$sroa$1 = 0, $closestA = 0, $dir = 0, $nbPolys = 0, $normal = 0, $toi = 0, $unitDir$idx$val = Math_fround(0), $unitDir$idx3$val = Math_fround(0);
 var $unitDir$idx4$val = Math_fround(0), $vQuat = 0, $vScale = 0, $zero = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $zero$sroa$1$i$i$i = sp + 240|0;
 $0 = sp + 480|0;
 $nbPolys = sp + 496|0;
 $_capsuleHalfHeight = sp + 500|0;
 $capTransform = sp + 516|0;
 $zeroV = sp + 464|0;
 $zero = sp + 448|0;
 $capsuleRadius$sroa$1 = sp + 504|0;
 $vScale = sp + 208|0;
 $vQuat = sp + 192|0;
 $capsule = sp + 48|0;
 $dir = sp + 32|0;
 $toi = sp + 16|0;
 $closestA = sp;
 $normal = sp + 224|0;
 $1 = (($geom) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = (($3) + 39|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 HEAP32[$nbPolys>>2] = $6;
 HEAPF32[$_capsuleHalfHeight>>2] = Math_fround(0.0);
 __ZN5physx2Gu19getCapsuleTransformERKNS0_7CapsuleERf($capTransform,$lss,$_capsuleHalfHeight);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 $7 = Math_fround(HEAPF32[$unitDir>>2]);
 $8 = (($unitDir) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($unitDir) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(HEAPF32[$capTransform>>2]);
 $13 = (($capTransform) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($capTransform) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($capTransform) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($capTransform) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($19) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($19) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(HEAPF32[$pose>>2]);
 $26 = (($pose) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($pose) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($pose) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($pose) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($32) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($32) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround(-$25);
 $39 = Math_fround(-$27);
 $40 = Math_fround(-$29);
 $41 = Math_fround($20 - $33);
 $42 = Math_fround($22 - $35);
 $43 = Math_fround($24 - $37);
 $44 = Math_fround($31 * $31);
 $45 = Math_fround($44 + Math_fround(-0.5));
 $46 = Math_fround($45 * $41);
 $47 = Math_fround($45 * $42);
 $48 = Math_fround($45 * $43);
 $49 = Math_fround($43 * $39);
 $50 = Math_fround($42 * $40);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($41 * $40);
 $53 = Math_fround($43 * $38);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($42 * $38);
 $56 = Math_fround($41 * $39);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($31 * $51);
 $59 = Math_fround($31 * $54);
 $60 = Math_fround($31 * $57);
 $61 = Math_fround($46 + $58);
 $62 = Math_fround($47 + $59);
 $63 = Math_fround($48 + $60);
 $64 = Math_fround($41 * $38);
 $65 = Math_fround($42 * $39);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($43 * $40);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($68 * $38);
 $70 = Math_fround($68 * $39);
 $71 = Math_fround($68 * $40);
 $72 = Math_fround($69 + $61);
 $73 = Math_fround($70 + $62);
 $74 = Math_fround($63 + $71);
 $75 = Math_fround($72 * Math_fround(2.0));
 $76 = Math_fround($73 * Math_fround(2.0));
 $77 = Math_fround($74 * Math_fround(2.0));
 $78 = Math_fround($18 * $31);
 $79 = Math_fround($12 * $38);
 $80 = Math_fround($14 * $39);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($16 * $40);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($78 - $83);
 $85 = Math_fround($18 * $38);
 $86 = Math_fround($18 * $39);
 $87 = Math_fround($18 * $40);
 $88 = Math_fround($12 * $31);
 $89 = Math_fround($14 * $31);
 $90 = Math_fround($16 * $31);
 $91 = Math_fround($16 * $39);
 $92 = Math_fround($14 * $40);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($12 * $40);
 $95 = Math_fround($16 * $38);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($14 * $38);
 $98 = Math_fround($12 * $39);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($85 + $88);
 $101 = Math_fround($86 + $89);
 $102 = Math_fround($90 + $87);
 $103 = Math_fround($93 + $100);
 $104 = Math_fround($96 + $101);
 $105 = Math_fround($99 + $102);
 $106 = Math_fround($103 + $103);
 $107 = Math_fround($104 + $104);
 $108 = Math_fround($105 + $105);
 $109 = Math_fround($103 * $106);
 $110 = Math_fround($104 * $107);
 $111 = Math_fround($105 * $108);
 $112 = Math_fround($104 * $106);
 $113 = Math_fround($105 * $106);
 $114 = Math_fround($84 * $106);
 $115 = Math_fround($105 * $107);
 $116 = Math_fround($84 * $107);
 $117 = Math_fround($84 * $108);
 $118 = Math_fround(Math_fround(1.0) - $109);
 $119 = Math_fround(Math_fround(1.0) - $110);
 $120 = Math_fround($119 - $111);
 $121 = Math_fround($112 + $117);
 $122 = Math_fround($113 - $116);
 $123 = Math_fround($112 - $117);
 $124 = Math_fround($118 - $111);
 $125 = Math_fround($115 + $114);
 $126 = Math_fround($113 + $116);
 $127 = Math_fround($115 - $114);
 $128 = Math_fround($118 - $110);
 $129 = Math_fround(HEAPF32[$_capsuleHalfHeight>>2]);
 $130 = (($lss) + 24|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($geom) + 4|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($geom) + 8|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($geom) + 12|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 HEAPF32[$vScale>>2] = $133;
 $138 = (($vScale) + 4|0);
 HEAPF32[$138>>2] = $135;
 $139 = (($vScale) + 8|0);
 HEAPF32[$139>>2] = $137;
 $140 = (($vScale) + 12|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $141 = (($geom) + 16|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($geom) + 20|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = (($geom) + 24|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($geom) + 28|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 HEAPF32[$vQuat>>2] = $142;
 $149 = (($vQuat) + 4|0);
 HEAPF32[$149>>2] = $144;
 $150 = (($vQuat) + 8|0);
 HEAPF32[$150>>2] = $146;
 $151 = (($vQuat) + 12|0);
 HEAPF32[$151>>2] = $148;
 $152 = Math_fround($129 * Math_fround(0.0));
 $153 = Math_fround($129 * $120);
 $154 = Math_fround($152 * $123);
 $155 = Math_fround($154 + $153);
 $156 = Math_fround($152 * $126);
 $157 = Math_fround($156 + $155);
 $158 = Math_fround($129 * $121);
 $159 = Math_fround($152 * $124);
 $160 = Math_fround($158 + $159);
 $161 = Math_fround($152 * $127);
 $162 = Math_fround($161 + $160);
 $163 = Math_fround($129 * $122);
 $164 = Math_fround($152 * $125);
 $165 = Math_fround($163 + $164);
 $166 = Math_fround($152 * $128);
 $167 = Math_fround($165 + $166);
 $168 = (($capsule) + 64|0);
 HEAPF32[$capsule>>2] = $75;
 $169 = (($capsule) + 4|0);
 HEAPF32[$169>>2] = $76;
 $170 = (($capsule) + 8|0);
 HEAPF32[$170>>2] = $77;
 $171 = (($capsule) + 12|0);
 HEAPF32[$171>>2] = Math_fround(0.0);
 $172 = (($capsule) + 80|0);
 HEAP32[$172>>2] = 4;
 $173 = (($capsule) + 16|0);
 $174 = (($capsule) + 20|0);
 $175 = (($capsule) + 32|0);
 $176 = (($capsule) + 36|0);
 $177 = (($capsule) + 48|0);
 HEAPF32[$177>>2] = Math_fround(0.0);
 $178 = (($capsule) + 52|0);
 ;HEAP32[$178+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$178+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$178+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $179 = (($capsule) + 128|0);
 HEAPF32[$179>>2] = $131;
 $180 = (($capsule) + 132|0);
 ;HEAP32[$180+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$180+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$180+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $181 = Math_fround($75 + $157);
 $182 = Math_fround($76 + $162);
 $183 = Math_fround($77 + $167);
 $184 = (($capsule) + 96|0);
 HEAPF32[$184>>2] = $181;
 $185 = (($capsule) + 100|0);
 HEAPF32[$185>>2] = $182;
 $186 = (($capsule) + 104|0);
 HEAPF32[$186>>2] = $183;
 $187 = (($capsule) + 108|0);
 HEAPF32[$187>>2] = Math_fround(0.0);
 $188 = Math_fround($75 - $157);
 $189 = Math_fround($76 - $162);
 $190 = Math_fround($77 - $167);
 $191 = (($capsule) + 112|0);
 HEAPF32[$191>>2] = $188;
 $192 = (($capsule) + 116|0);
 HEAPF32[$192>>2] = $189;
 $193 = (($capsule) + 120|0);
 HEAPF32[$193>>2] = $190;
 $194 = (($capsule) + 124|0);
 HEAPF32[$194>>2] = Math_fround(0.0);
 HEAPF32[$173>>2] = $131;
 ;HEAP32[$174+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$174+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$174+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$175>>2] = $131;
 ;HEAP32[$176+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$176+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$176+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$168+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$168+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$168+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$168+12>>2]=HEAP32[$0+12>>2]|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($zero$sroa$1$i$i$i,$3,$zeroV,$vScale,$vQuat);
 $195 = Math_fround($7 * $distance);
 $196 = Math_fround($9 * $distance);
 $197 = Math_fround($11 * $distance);
 $198 = Math_fround(-$195);
 $199 = Math_fround(-$196);
 $200 = Math_fround(-$197);
 $201 = Math_fround($45 * $198);
 $202 = Math_fround($45 * $199);
 $203 = Math_fround($45 * $200);
 $204 = Math_fround($27 * $200);
 $205 = Math_fround($29 * $199);
 $206 = Math_fround($204 - $205);
 $207 = Math_fround($29 * $198);
 $208 = Math_fround($25 * $200);
 $209 = Math_fround($207 - $208);
 $210 = Math_fround($25 * $199);
 $211 = Math_fround($27 * $198);
 $212 = Math_fround($210 - $211);
 $213 = Math_fround($31 * $206);
 $214 = Math_fround($31 * $209);
 $215 = Math_fround($31 * $212);
 $216 = Math_fround($201 - $213);
 $217 = Math_fround($202 - $214);
 $218 = Math_fround($203 - $215);
 $219 = Math_fround($25 * $198);
 $220 = Math_fround($27 * $199);
 $221 = Math_fround($219 + $220);
 $222 = Math_fround($29 * $200);
 $223 = Math_fround($221 + $222);
 $224 = Math_fround($25 * $223);
 $225 = Math_fround($27 * $223);
 $226 = Math_fround($29 * $223);
 $227 = Math_fround($224 + $216);
 $228 = Math_fround($225 + $217);
 $229 = Math_fround($226 + $218);
 $230 = Math_fround($227 * Math_fround(2.0));
 $231 = Math_fround($228 * Math_fround(2.0));
 $232 = Math_fround($229 * Math_fround(2.0));
 HEAPF32[$dir>>2] = $230;
 $233 = (($dir) + 4|0);
 HEAPF32[$233>>2] = $231;
 $234 = (($dir) + 8|0);
 HEAPF32[$234>>2] = $232;
 $235 = (($dir) + 12|0);
 HEAPF32[$235>>2] = Math_fround(0.0);
 $236 = HEAP16[$hintFlags>>1]|0;
 $237 = $236 & 512;
 $238 = ($237<<16>>16)!=(0);
 $239 = Math_fround(HEAPF32[$130>>2]);
 $240 = Math_fround($239 + $inflation);
 $241 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_8CapsuleVERNS0_11ConvexHullVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($capsule,$zero$sroa$1$i$i$i,$zero,$zeroV,$dir,$toi,$normal,$closestA,$240,$238)|0);
 if (!($241)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $242 = (($sweepHit) + 12|0);
 HEAP16[$242>>1] = 6;
 $243 = Math_fround(HEAPF32[$zero>>2]);
 $244 = Math_fround(HEAPF32[$toi>>2]);
 $245 = !($243 >= $244);
 do {
  if ($245) {
   HEAP16[$242>>1] = 7;
   $356 = Math_fround(HEAPF32[$closestA>>2]);
   $357 = (($closestA) + 4|0);
   $358 = Math_fround(HEAPF32[$357>>2]);
   $359 = (($closestA) + 8|0);
   $360 = Math_fround(HEAPF32[$359>>2]);
   $361 = Math_fround($45 * $356);
   $362 = Math_fround($45 * $358);
   $363 = Math_fround($45 * $360);
   $364 = Math_fround($27 * $360);
   $365 = Math_fround($29 * $358);
   $366 = Math_fround($364 - $365);
   $367 = Math_fround($29 * $356);
   $368 = Math_fround($25 * $360);
   $369 = Math_fround($367 - $368);
   $370 = Math_fround($25 * $358);
   $371 = Math_fround($27 * $356);
   $372 = Math_fround($370 - $371);
   $373 = Math_fround($31 * $366);
   $374 = Math_fround($31 * $369);
   $375 = Math_fround($31 * $372);
   $376 = Math_fround($361 + $373);
   $377 = Math_fround($362 + $374);
   $378 = Math_fround($363 + $375);
   $379 = Math_fround($25 * $356);
   $380 = Math_fround($27 * $358);
   $381 = Math_fround($379 + $380);
   $382 = Math_fround($29 * $360);
   $383 = Math_fround($381 + $382);
   $384 = Math_fround($25 * $383);
   $385 = Math_fround($27 * $383);
   $386 = Math_fround($29 * $383);
   $387 = Math_fround($384 + $376);
   $388 = Math_fround($385 + $377);
   $389 = Math_fround($378 + $386);
   $390 = Math_fround($387 * Math_fround(2.0));
   $391 = Math_fround($388 * Math_fround(2.0));
   $392 = Math_fround($389 * Math_fround(2.0));
   $393 = Math_fround($33 + $390);
   $394 = Math_fround($35 + $391);
   $395 = Math_fround($37 + $392);
   $396 = Math_fround($244 * $distance);
   $397 = Math_fround(HEAPF32[$normal>>2]);
   $398 = (($normal) + 4|0);
   $399 = Math_fround(HEAPF32[$398>>2]);
   $400 = (($normal) + 8|0);
   $401 = Math_fround(HEAPF32[$400>>2]);
   $402 = Math_fround($45 * $397);
   $403 = Math_fround($45 * $399);
   $404 = Math_fround($45 * $401);
   $405 = Math_fround($27 * $401);
   $406 = Math_fround($29 * $399);
   $407 = Math_fround($405 - $406);
   $408 = Math_fround($29 * $397);
   $409 = Math_fround($25 * $401);
   $410 = Math_fround($408 - $409);
   $411 = Math_fround($25 * $399);
   $412 = Math_fround($27 * $397);
   $413 = Math_fround($411 - $412);
   $414 = Math_fround($31 * $407);
   $415 = Math_fround($31 * $410);
   $416 = Math_fround($31 * $413);
   $417 = Math_fround($402 + $414);
   $418 = Math_fround($403 + $415);
   $419 = Math_fround($404 + $416);
   $420 = Math_fround($25 * $397);
   $421 = Math_fround($27 * $399);
   $422 = Math_fround($420 + $421);
   $423 = Math_fround($29 * $401);
   $424 = Math_fround($422 + $423);
   $425 = Math_fround($25 * $424);
   $426 = Math_fround($27 * $424);
   $427 = Math_fround($29 * $424);
   $428 = Math_fround($425 + $417);
   $429 = Math_fround($426 + $418);
   $430 = Math_fround($419 + $427);
   $431 = Math_fround($428 * Math_fround(2.0));
   $432 = Math_fround($429 * Math_fround(2.0));
   $433 = Math_fround($430 * Math_fround(2.0));
   $434 = Math_fround($431 * $431);
   $435 = Math_fround($432 * $432);
   $436 = Math_fround($434 + $435);
   $437 = Math_fround($433 * $433);
   $438 = Math_fround($437 + $436);
   $439 = (Math_fround(Math_sqrt((Math_fround($438)))));
   $440 = Math_fround(Math_fround(1.0) / $439);
   $441 = Math_fround($440 * $431);
   $442 = Math_fround($440 * $432);
   $443 = Math_fround($440 * $433);
   $444 = Math_fround($7 * $396);
   $445 = Math_fround($9 * $396);
   $446 = Math_fround($11 * $396);
   $447 = Math_fround($444 + $393);
   $448 = Math_fround($445 + $394);
   $449 = Math_fround($446 + $395);
   $450 = (($sweepHit) + 28|0);
   HEAPF32[$450>>2] = $441;
   $451 = (($sweepHit) + 32|0);
   HEAPF32[$451>>2] = $442;
   $452 = (($sweepHit) + 36|0);
   HEAPF32[$452>>2] = $443;
   $453 = (($sweepHit) + 16|0);
   HEAPF32[$453>>2] = $447;
   $454 = (($sweepHit) + 20|0);
   HEAPF32[$454>>2] = $448;
   $455 = (($sweepHit) + 24|0);
   HEAPF32[$455>>2] = $449;
   $456 = (($sweepHit) + 40|0);
   HEAPF32[$456>>2] = $396;
   $$idx$val = $447;$$idx1$val = $448;$$idx2$val = $449;
  } else {
   if ($238) {
    HEAP16[$242>>1] = 7;
    $246 = Math_fround(HEAPF32[$normal>>2]);
    $247 = (($normal) + 4|0);
    $248 = Math_fround(HEAPF32[$247>>2]);
    $249 = (($normal) + 8|0);
    $250 = Math_fround(HEAPF32[$249>>2]);
    $251 = Math_fround($45 * $246);
    $252 = Math_fround($45 * $248);
    $253 = Math_fround($45 * $250);
    $254 = Math_fround($27 * $250);
    $255 = Math_fround($29 * $248);
    $256 = Math_fround($254 - $255);
    $257 = Math_fround($29 * $246);
    $258 = Math_fround($25 * $250);
    $259 = Math_fround($257 - $258);
    $260 = Math_fround($25 * $248);
    $261 = Math_fround($27 * $246);
    $262 = Math_fround($260 - $261);
    $263 = Math_fround($31 * $256);
    $264 = Math_fround($31 * $259);
    $265 = Math_fround($31 * $262);
    $266 = Math_fround($251 + $263);
    $267 = Math_fround($252 + $264);
    $268 = Math_fround($253 + $265);
    $269 = Math_fround($25 * $246);
    $270 = Math_fround($27 * $248);
    $271 = Math_fround($269 + $270);
    $272 = Math_fround($29 * $250);
    $273 = Math_fround($271 + $272);
    $274 = Math_fround($25 * $273);
    $275 = Math_fround($27 * $273);
    $276 = Math_fround($29 * $273);
    $277 = Math_fround($274 + $266);
    $278 = Math_fround($275 + $267);
    $279 = Math_fround($268 + $276);
    $280 = Math_fround($277 * Math_fround(2.0));
    $281 = Math_fround($278 * Math_fround(2.0));
    $282 = Math_fround($279 * Math_fround(2.0));
    $283 = Math_fround($280 * $280);
    $284 = Math_fround($281 * $281);
    $285 = Math_fround($283 + $284);
    $286 = Math_fround($282 * $282);
    $287 = Math_fround($286 + $285);
    $288 = (Math_fround(Math_sqrt((Math_fround($287)))));
    $289 = Math_fround(Math_fround(1.0) / $288);
    $290 = Math_fround($289 * $280);
    $291 = Math_fround($289 * $281);
    $292 = Math_fround($289 * $282);
    $293 = Math_fround(HEAPF32[$closestA>>2]);
    $294 = (($closestA) + 4|0);
    $295 = Math_fround(HEAPF32[$294>>2]);
    $296 = (($closestA) + 8|0);
    $297 = Math_fround(HEAPF32[$296>>2]);
    $298 = Math_fround($45 * $293);
    $299 = Math_fround($45 * $295);
    $300 = Math_fround($45 * $297);
    $301 = Math_fround($27 * $297);
    $302 = Math_fround($29 * $295);
    $303 = Math_fround($301 - $302);
    $304 = Math_fround($29 * $293);
    $305 = Math_fround($25 * $297);
    $306 = Math_fround($304 - $305);
    $307 = Math_fround($25 * $295);
    $308 = Math_fround($27 * $293);
    $309 = Math_fround($307 - $308);
    $310 = Math_fround($31 * $303);
    $311 = Math_fround($31 * $306);
    $312 = Math_fround($31 * $309);
    $313 = Math_fround($298 + $310);
    $314 = Math_fround($299 + $311);
    $315 = Math_fround($300 + $312);
    $316 = Math_fround($25 * $293);
    $317 = Math_fround($27 * $295);
    $318 = Math_fround($316 + $317);
    $319 = Math_fround($29 * $297);
    $320 = Math_fround($318 + $319);
    $321 = Math_fround($25 * $320);
    $322 = Math_fround($27 * $320);
    $323 = Math_fround($29 * $320);
    $324 = Math_fround($321 + $313);
    $325 = Math_fround($322 + $314);
    $326 = Math_fround($315 + $323);
    $327 = Math_fround($324 * Math_fround(2.0));
    $328 = Math_fround($325 * Math_fround(2.0));
    $329 = Math_fround($326 * Math_fround(2.0));
    $330 = Math_fround($33 + $327);
    $331 = Math_fround($35 + $328);
    $332 = Math_fround($37 + $329);
    $333 = Math_fround($244 * $290);
    $334 = Math_fround($244 * $291);
    $335 = Math_fround($244 * $292);
    $336 = Math_fround($330 - $333);
    $337 = Math_fround($331 - $334);
    $338 = Math_fround($332 - $335);
    $339 = (($sweepHit) + 28|0);
    HEAPF32[$339>>2] = $290;
    $340 = (($sweepHit) + 32|0);
    HEAPF32[$340>>2] = $291;
    $341 = (($sweepHit) + 36|0);
    HEAPF32[$341>>2] = $292;
    $342 = (($sweepHit) + 16|0);
    HEAPF32[$342>>2] = $336;
    $343 = (($sweepHit) + 20|0);
    HEAPF32[$343>>2] = $337;
    $344 = (($sweepHit) + 24|0);
    HEAPF32[$344>>2] = $338;
    $345 = (($sweepHit) + 40|0);
    HEAPF32[$345>>2] = $244;
    $$idx$val = $336;$$idx1$val = $337;$$idx2$val = $338;
    break;
   } else {
    $346 = (($sweepHit) + 40|0);
    HEAPF32[$346>>2] = Math_fround(0.0);
    $347 = Math_fround(HEAPF32[$unitDir>>2]);
    $348 = Math_fround(-$347);
    $349 = Math_fround(HEAPF32[$8>>2]);
    $350 = Math_fround(-$349);
    $351 = Math_fround(HEAPF32[$10>>2]);
    $352 = Math_fround(-$351);
    $353 = (($sweepHit) + 28|0);
    HEAPF32[$353>>2] = $348;
    $354 = (($sweepHit) + 32|0);
    HEAPF32[$354>>2] = $350;
    $355 = (($sweepHit) + 36|0);
    HEAPF32[$355>>2] = $352;
    $$idx$phi$trans$insert = (($sweepHit) + 16|0);
    $$idx$val$pre = Math_fround(HEAPF32[$$idx$phi$trans$insert>>2]);
    $$idx1$phi$trans$insert = (($sweepHit) + 20|0);
    $$idx1$val$pre = Math_fround(HEAPF32[$$idx1$phi$trans$insert>>2]);
    $$idx2$phi$trans$insert = (($sweepHit) + 24|0);
    $$idx2$val$pre = Math_fround(HEAPF32[$$idx2$phi$trans$insert>>2]);
    $$idx$val = $$idx$val$pre;$$idx1$val = $$idx1$val$pre;$$idx2$val = $$idx2$val$pre;
    break;
   }
  }
 } while(0);
 $unitDir$idx$val = Math_fround(HEAPF32[$unitDir>>2]);
 $unitDir$idx3$val = Math_fround(HEAPF32[$8>>2]);
 $unitDir$idx4$val = Math_fround(HEAPF32[$10>>2]);
 $457 = (__ZL23computeSweepConvexPlaneRKN5physx20PxConvexMeshGeometryEPNS_2Gu14ConvexHullDataERKjRKNS_11PxTransformERKNS_6PxVec3ESD_($geom,$3,$nbPolys,$pose,$$idx$val,$$idx1$val,$$idx2$val,$unitDir$idx$val,$unitDir$idx3$val,$unitDir$idx4$val)|0);
 $458 = (($sweepHit) + 8|0);
 HEAP32[$458>>2] = $457;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL23computeSweepConvexPlaneRKN5physx20PxConvexMeshGeometryEPNS_2Gu14ConvexHullDataERKjRKNS_11PxTransformERKNS_6PxVec3ESD_($convexGeom,$hullData,$nbPolys,$pose,$impact_$0$0$val,$impact_$0$1$val,$impact_$0$2$val,$unitDir$0$0$val,$unitDir$0$1$val,$unitDir$0$2$val) {
 $convexGeom = $convexGeom|0;
 $hullData = $hullData|0;
 $nbPolys = $nbPolys|0;
 $pose = $pose|0;
 $impact_$0$0$val = Math_fround($impact_$0$0$val);
 $impact_$0$1$val = Math_fround($impact_$0$1$val);
 $impact_$0$2$val = Math_fround($impact_$0$2$val);
 $unitDir$0$0$val = Math_fround($unitDir$0$0$val);
 $unitDir$0$1$val = Math_fround($unitDir$0$1$val);
 $unitDir$0$2$val = Math_fround($unitDir$0$2$val);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0;
 var $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $j$01 = 0, $minD$02 = Math_fround(0), $minD$1 = Math_fround(0), $minIndex$0$lcssa = 0, $minIndex$03 = 0, $minIndex$1 = 0, $scaling = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $scaling = sp;
 $0 = Math_fround($unitDir$0$0$val * Math_fround(0.00999999977648258209228));
 $1 = Math_fround($unitDir$0$1$val * Math_fround(0.00999999977648258209228));
 $2 = Math_fround($unitDir$0$2$val * Math_fround(0.00999999977648258209228));
 $3 = Math_fround($impact_$0$0$val - $0);
 $4 = Math_fround($impact_$0$1$val - $1);
 $5 = Math_fround($impact_$0$2$val - $2);
 $6 = (($pose) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($3 - $7);
 $9 = (($pose) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($4 - $10);
 $12 = (($pose) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($5 - $13);
 $15 = Math_fround($8 * Math_fround(2.0));
 $16 = Math_fround($11 * Math_fround(2.0));
 $17 = Math_fround($14 * Math_fround(2.0));
 $18 = (($pose) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $19);
 $21 = Math_fround($20 + Math_fround(-0.5));
 $22 = Math_fround(HEAPF32[$pose>>2]);
 $23 = Math_fround($15 * $22);
 $24 = (($pose) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($16 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($pose) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($17 * $29);
 $31 = Math_fround($27 + $30);
 $32 = Math_fround($15 * $21);
 $33 = Math_fround($17 * $25);
 $34 = Math_fround($16 * $29);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($19 * $35);
 $37 = Math_fround($32 - $36);
 $38 = Math_fround($22 * $31);
 $39 = Math_fround($38 + $37);
 $40 = Math_fround($16 * $21);
 $41 = Math_fround($15 * $29);
 $42 = Math_fround($17 * $22);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($19 * $43);
 $45 = Math_fround($40 - $44);
 $46 = Math_fround($25 * $31);
 $47 = Math_fround($46 + $45);
 $48 = Math_fround($17 * $21);
 $49 = Math_fround($16 * $22);
 $50 = Math_fround($15 * $25);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($19 * $51);
 $53 = Math_fround($48 - $52);
 $54 = Math_fround($29 * $31);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($unitDir$0$0$val * Math_fround(2.0));
 $57 = Math_fround($unitDir$0$1$val * Math_fround(2.0));
 $58 = Math_fround($unitDir$0$2$val * Math_fround(2.0));
 $59 = Math_fround($56 * $22);
 $60 = Math_fround($57 * $25);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($58 * $29);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($56 * $21);
 $65 = Math_fround($58 * $25);
 $66 = Math_fround($57 * $29);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($19 * $67);
 $69 = Math_fround($64 - $68);
 $70 = Math_fround($22 * $63);
 $71 = Math_fround($70 + $69);
 $72 = Math_fround($57 * $21);
 $73 = Math_fround($56 * $29);
 $74 = Math_fround($58 * $22);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($19 * $75);
 $77 = Math_fround($72 - $76);
 $78 = Math_fround($25 * $63);
 $79 = Math_fround($78 + $77);
 $80 = Math_fround($58 * $21);
 $81 = Math_fround($57 * $22);
 $82 = Math_fround($56 * $25);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($19 * $83);
 $85 = Math_fround($80 - $84);
 $86 = Math_fround($29 * $63);
 $87 = Math_fround($85 + $86);
 $88 = (($convexGeom) + 4|0);
 $89 = (($convexGeom) + 16|0);
 __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($scaling,$88,$89);
 $90 = HEAP32[$nbPolys>>2]|0;
 $91 = ($90|0)==(0);
 if ($91) {
  $minIndex$0$lcssa = 0;
  STACKTOP = sp;return ($minIndex$0$lcssa|0);
 }
 $92 = (($hullData) + 40|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($scaling) + 36|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($scaling) + 40|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($scaling) + 44|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($scaling) + 48|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($scaling) + 52|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($scaling) + 56|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($scaling) + 60|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($scaling) + 64|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($scaling) + 68|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $j$01 = 0;$minD$02 = Math_fround(3.40282346638528859812E+38);$minIndex$03 = 0;
 while(1) {
  $112 = ((($93) + (($j$01*20)|0)|0) + 12|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = (($93) + (($j$01*20)|0)|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($95 * $115);
  $117 = ((($93) + (($j$01*20)|0)|0) + 4|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = Math_fround($97 * $118);
  $120 = Math_fround($116 + $119);
  $121 = ((($93) + (($j$01*20)|0)|0) + 8|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround($99 * $122);
  $124 = Math_fround($120 + $123);
  $125 = Math_fround($115 * $101);
  $126 = Math_fround($118 * $103);
  $127 = Math_fround($125 + $126);
  $128 = Math_fround($122 * $105);
  $129 = Math_fround($127 + $128);
  $130 = Math_fround($115 * $107);
  $131 = Math_fround($118 * $109);
  $132 = Math_fround($130 + $131);
  $133 = Math_fround($122 * $111);
  $134 = Math_fround($132 + $133);
  $135 = Math_fround($124 * $124);
  $136 = Math_fround($129 * $129);
  $137 = Math_fround($135 + $136);
  $138 = Math_fround($134 * $134);
  $139 = Math_fround($137 + $138);
  $140 = (Math_fround(Math_sqrt((Math_fround($139)))));
  $141 = Math_fround(Math_fround(1.0) / $140);
  $142 = Math_fround($124 * $141);
  $143 = Math_fround($129 * $141);
  $144 = Math_fround($134 * $141);
  $145 = Math_fround($113 * $141);
  $146 = Math_fround($39 * $142);
  $147 = Math_fround($47 * $143);
  $148 = Math_fround($146 + $147);
  $149 = Math_fround($55 * $144);
  $150 = Math_fround($149 + $148);
  $151 = Math_fround($145 + $150);
  $152 = $151 < Math_fround(0.0);
  if ($152) {
   $minD$1 = $minD$02;$minIndex$1 = $minIndex$03;
  } else {
   $153 = Math_fround($71 * $142);
   $154 = Math_fround($79 * $143);
   $155 = Math_fround($153 + $154);
   $156 = Math_fround($87 * $144);
   $157 = Math_fround($156 + $155);
   $158 = Math_fround($157 * Math_fround(0.00999999977648258209228));
   $159 = Math_fround($151 + $158);
   $160 = $159 < $minD$02;
   if ($160) {
    $minD$1 = $159;$minIndex$1 = $j$01;
   } else {
    $minD$1 = $minD$02;$minIndex$1 = $minIndex$03;
   }
  }
  $161 = (($j$01) + 1)|0;
  $162 = ($161>>>0)<($90>>>0);
  if ($162) {
   $j$01 = $161;$minD$02 = $minD$1;$minIndex$03 = $minIndex$1;
  } else {
   $minIndex$0$lcssa = $minIndex$1;
   break;
  }
 }
 STACKTOP = sp;return ($minIndex$0$lcssa|0);
}
function __Z18sweepBox_PlaneGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0;
 var $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0.0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0;
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $boxPts = 0, $dir$idx$val$i = Math_fround(0), $dir$idx1$val$i = Math_fround(0), $dir$idx2$val$i = Math_fround(0), $index$1$1 = 0, $index$1$2 = 0, $index$1$3 = 0, $index$1$4 = 0, $index$1$5 = 0, $index$1$6 = 0, $index$1$7 = 0, $minDp$1 = Math_fround(0), $minDp$1$1 = Math_fround(0), $minDp$1$2 = Math_fround(0), $minDp$1$3 = Math_fround(0), $minDp$1$4 = Math_fround(0), $minDp$1$5 = Math_fround(0);
 var $minDp$1$6 = Math_fround(0), $minDp$1$7 = Math_fround(0), $or$cond = 0, $or$cond$i = 0, $worldPlane = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $worldPlane = sp + 96|0;
 $boxPts = sp;
 $0 = (($sweepHit) + 8|0);
 HEAP32[$0>>2] = -1;
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($worldPlane,$pose);
 $1 = (($worldPlane) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($2 - $inflation);
 HEAPF32[$1>>2] = $3;
 $4 = (($box) + 36|0);
 $5 = (($box) + 48|0);
 $6 = (($box) + 12|0);
 $7 = (($box) + 24|0);
 __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($boxPts,$4,$5,$box,$6,$7);
 $8 = Math_fround(HEAPF32[$worldPlane>>2]);
 $9 = (($worldPlane) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($worldPlane) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(HEAPF32[$boxPts>>2]);
 $14 = Math_fround($13 * $8);
 $15 = (($boxPts) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $10);
 $18 = Math_fround($14 + $17);
 $19 = (($boxPts) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $12);
 $22 = Math_fround($18 + $21);
 $23 = $22 < Math_fround(3.40282346638528859812E+38);
 $minDp$1 = $23 ? $22 : Math_fround(3.40282346638528859812E+38);
 $24 = (($boxPts) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $8);
 $27 = (($boxPts) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $10);
 $30 = Math_fround($26 + $29);
 $31 = (($boxPts) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $12);
 $34 = Math_fround($30 + $33);
 $35 = $34 < $minDp$1;
 $minDp$1$1 = $35 ? $34 : $minDp$1;
 $index$1$1 = $35&1;
 $36 = (($boxPts) + 24|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * $8);
 $39 = (($boxPts) + 28|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($40 * $10);
 $42 = Math_fround($38 + $41);
 $43 = (($boxPts) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 * $12);
 $46 = Math_fround($42 + $45);
 $47 = $46 < $minDp$1$1;
 $minDp$1$2 = $47 ? $46 : $minDp$1$1;
 $index$1$2 = $47 ? 2 : $index$1$1;
 $48 = (($boxPts) + 36|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * $8);
 $51 = (($boxPts) + 40|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 * $10);
 $54 = Math_fround($50 + $53);
 $55 = (($boxPts) + 44|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 * $12);
 $58 = Math_fround($54 + $57);
 $59 = $58 < $minDp$1$2;
 $minDp$1$3 = $59 ? $58 : $minDp$1$2;
 $index$1$3 = $59 ? 3 : $index$1$2;
 $60 = (($boxPts) + 48|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 * $8);
 $63 = (($boxPts) + 52|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 * $10);
 $66 = Math_fround($62 + $65);
 $67 = (($boxPts) + 56|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 * $12);
 $70 = Math_fround($66 + $69);
 $71 = $70 < $minDp$1$3;
 $minDp$1$4 = $71 ? $70 : $minDp$1$3;
 $index$1$4 = $71 ? 4 : $index$1$3;
 $72 = (($boxPts) + 60|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 * $8);
 $75 = (($boxPts) + 64|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($76 * $10);
 $78 = Math_fround($74 + $77);
 $79 = (($boxPts) + 68|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($80 * $12);
 $82 = Math_fround($78 + $81);
 $83 = $82 < $minDp$1$4;
 $minDp$1$5 = $83 ? $82 : $minDp$1$4;
 $index$1$5 = $83 ? 5 : $index$1$4;
 $84 = (($boxPts) + 72|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($85 * $8);
 $87 = (($boxPts) + 76|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($88 * $10);
 $90 = Math_fround($86 + $89);
 $91 = (($boxPts) + 80|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($92 * $12);
 $94 = Math_fround($90 + $93);
 $95 = $94 < $minDp$1$5;
 $minDp$1$6 = $95 ? $94 : $minDp$1$5;
 $index$1$6 = $95 ? 6 : $index$1$5;
 $96 = (($boxPts) + 84|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 * $8);
 $99 = (($boxPts) + 88|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 * $10);
 $102 = Math_fround($98 + $101);
 $103 = (($boxPts) + 92|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($104 * $12);
 $106 = Math_fround($102 + $105);
 $107 = $106 < $minDp$1$6;
 $minDp$1$7 = $107 ? $106 : $minDp$1$6;
 $index$1$7 = $107 ? 7 : $index$1$6;
 $108 = HEAP16[$hintFlags>>1]|0;
 $109 = $108&65535;
 $110 = $109 & 512;
 $111 = ($110|0)==(0);
 if ($111) {
  $117 = $109 & 16;
  $118 = ($117|0)==(0);
  if ($118) {
   $119 = Math_fround(HEAPF32[$1>>2]);
   $120 = Math_fround(-$119);
   $121 = !($minDp$1$7 <= $120);
   if (!($121)) {
    $122 = (($sweepHit) + 12|0);
    HEAP16[$122>>1] = 6;
    $123 = (($sweepHit) + 40|0);
    HEAPF32[$123>>2] = Math_fround(0.0);
    $124 = Math_fround(HEAPF32[$unitDir>>2]);
    $125 = Math_fround(-$124);
    $126 = (($unitDir) + 4|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = Math_fround(-$127);
    $129 = (($unitDir) + 8|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $131 = Math_fround(-$130);
    $132 = (($sweepHit) + 28|0);
    HEAPF32[$132>>2] = $125;
    $133 = (($sweepHit) + 32|0);
    HEAPF32[$133>>2] = $128;
    $134 = (($sweepHit) + 36|0);
    HEAPF32[$134>>2] = $131;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } else {
  $112 = Math_fround(HEAPF32[$1>>2]);
  $113 = Math_fround(-$112);
  $114 = !($minDp$1$7 <= $113);
  if (!($114)) {
   $115 = (($sweepHit) + 12|0);
   HEAP16[$115>>1] = 7;
   $116 = (__ZN5physx2Gu19computePlane_BoxMTDERKNS_7PxPlaneERKNS0_3BoxERNS_10PxSweepHitE($worldPlane,$box,$sweepHit)|0);
   $$0 = $116;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $135 = Math_fround(HEAPF32[$unitDir>>2]);
 $136 = Math_fround(HEAPF32[$worldPlane>>2]);
 $137 = Math_fround($135 * $136);
 $138 = (($unitDir) + 4|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround(HEAPF32[$9>>2]);
 $141 = Math_fround($139 * $140);
 $142 = Math_fround($137 + $141);
 $143 = (($unitDir) + 8|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround(HEAPF32[$11>>2]);
 $146 = Math_fround($144 * $145);
 $147 = Math_fround($142 + $146);
 $148 = +$147;
 $149 = $148 > -9.99999999999999954748E-8;
 $150 = $148 < 9.99999999999999954748E-8;
 $or$cond$i = $149 & $150;
 if ($or$cond$i) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $151 = (($sweepHit) + 40|0);
 $152 = (($boxPts) + (($index$1$7*12)|0)|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = Math_fround($136 * $153);
 $155 = ((($boxPts) + (($index$1$7*12)|0)|0) + 4|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = Math_fround($140 * $156);
 $158 = Math_fround($154 + $157);
 $159 = ((($boxPts) + (($index$1$7*12)|0)|0) + 8|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = Math_fround($145 * $160);
 $162 = Math_fround($158 + $161);
 $163 = Math_fround(HEAPF32[$1>>2]);
 $164 = Math_fround($163 + $162);
 $165 = Math_fround(-$164);
 $166 = Math_fround($165 / $147);
 HEAPF32[$151>>2] = $166;
 $dir$idx$val$i = Math_fround(HEAPF32[$unitDir>>2]);
 $dir$idx1$val$i = Math_fround(HEAPF32[$138>>2]);
 $dir$idx2$val$i = Math_fround(HEAPF32[$143>>2]);
 $167 = Math_fround($166 * $dir$idx$val$i);
 $168 = Math_fround($166 * $dir$idx1$val$i);
 $169 = Math_fround($166 * $dir$idx2$val$i);
 $170 = Math_fround($167 + $153);
 $171 = Math_fround($168 + $156);
 $172 = Math_fround($169 + $160);
 $173 = (($sweepHit) + 16|0);
 HEAPF32[$173>>2] = $170;
 $174 = (($sweepHit) + 20|0);
 HEAPF32[$174>>2] = $171;
 $175 = (($sweepHit) + 24|0);
 HEAPF32[$175>>2] = $172;
 $176 = !($166 > Math_fround(0.0));
 $177 = !($166 <= $distance);
 $or$cond = $176 | $177;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $178 = (($sweepHit) + 28|0);
 HEAPF32[$178>>2] = $136;
 $179 = (($sweepHit) + 32|0);
 HEAPF32[$179>>2] = $140;
 $180 = (($sweepHit) + 36|0);
 HEAPF32[$180>>2] = $145;
 $181 = (($sweepHit) + 12|0);
 HEAP16[$181>>1] = 7;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z19sweepBox_ConvexGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = 0, $$idx$phi$trans$insert = 0, $$idx$val = Math_fround(0), $$idx$val$pre = Math_fround(0), $$idx1$phi$trans$insert = 0, $$idx1$val = Math_fround(0), $$idx1$val$pre = Math_fround(0), $$idx2$phi$trans$insert = 0, $$idx2$val = Math_fround(0), $$idx2$val$pre = Math_fround(0), $$sroa$1$i$i$i = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0);
 var $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0);
 var $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0);
 var $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0);
 var $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0);
 var $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0);
 var $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0);
 var $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0;
 var $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0;
 var $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0);
 var $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0;
 var $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0);
 var $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0);
 var $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $boxV = 0, $closestA = 0, $dir = 0, $nbPolys = 0, $normal = 0, $toi = 0, $unitDir$idx$val = Math_fround(0), $unitDir$idx3$val = Math_fround(0), $unitDir$idx4$val = Math_fround(0), $vQuat = 0;
 var $vScale = 0, $zero = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $$sroa$1$i$i$i = sp + 352|0;
 $zero$sroa$1$i$i$i = sp + 560|0;
 $nbPolys = sp + 572|0;
 $zeroV = sp + 336|0;
 $zero = sp + 320|0;
 $aToB = sp + 256|0;
 $vScale = sp + 240|0;
 $vQuat = sp + 208|0;
 $boxV = sp + 48|0;
 $dir = sp + 32|0;
 $toi = sp + 16|0;
 $closestA = sp;
 $normal = sp + 224|0;
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($$sroa$1$i$i$i,$box);
 $0 = Math_fround(HEAPF32[$$sroa$1$i$i$i>>2]);
 $1 = (($$sroa$1$i$i$i) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($$sroa$1$i$i$i) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($$sroa$1$i$i$i) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($box) + 36|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($box) + 40|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($box) + 44|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($geom) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 16|0);
 $16 = (($15) + 39|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 HEAP32[$nbPolys>>2] = $18;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 $19 = Math_fround(HEAPF32[$pose>>2]);
 $20 = (($pose) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($pose) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($pose) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($pose) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($26) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($26) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(-$19);
 $33 = Math_fround(-$21);
 $34 = Math_fround(-$23);
 $35 = Math_fround($8 - $27);
 $36 = Math_fround($10 - $29);
 $37 = Math_fround($12 - $31);
 $38 = Math_fround($25 * $25);
 $39 = Math_fround($38 + Math_fround(-0.5));
 $40 = Math_fround($39 * $35);
 $41 = Math_fround($39 * $36);
 $42 = Math_fround($39 * $37);
 $43 = Math_fround($37 * $33);
 $44 = Math_fround($36 * $34);
 $45 = Math_fround($43 - $44);
 $46 = Math_fround($35 * $34);
 $47 = Math_fround($37 * $32);
 $48 = Math_fround($46 - $47);
 $49 = Math_fround($36 * $32);
 $50 = Math_fround($35 * $33);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($25 * $45);
 $53 = Math_fround($25 * $48);
 $54 = Math_fround($25 * $51);
 $55 = Math_fround($40 + $52);
 $56 = Math_fround($41 + $53);
 $57 = Math_fround($42 + $54);
 $58 = Math_fround($35 * $32);
 $59 = Math_fround($36 * $33);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($37 * $34);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($62 * $32);
 $64 = Math_fround($62 * $33);
 $65 = Math_fround($62 * $34);
 $66 = Math_fround($63 + $55);
 $67 = Math_fround($64 + $56);
 $68 = Math_fround($57 + $65);
 $69 = Math_fround($66 * Math_fround(2.0));
 $70 = Math_fround($67 * Math_fround(2.0));
 $71 = Math_fround($68 * Math_fround(2.0));
 $72 = Math_fround($6 * $25);
 $73 = Math_fround($0 * $32);
 $74 = Math_fround($2 * $33);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($4 * $34);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($72 - $77);
 $79 = Math_fround($6 * $32);
 $80 = Math_fround($6 * $33);
 $81 = Math_fround($6 * $34);
 $82 = Math_fround($0 * $25);
 $83 = Math_fround($2 * $25);
 $84 = Math_fround($4 * $25);
 $85 = Math_fround($4 * $33);
 $86 = Math_fround($2 * $34);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($0 * $34);
 $89 = Math_fround($4 * $32);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($2 * $32);
 $92 = Math_fround($0 * $33);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($79 + $82);
 $95 = Math_fround($80 + $83);
 $96 = Math_fround($84 + $81);
 $97 = Math_fround($87 + $94);
 $98 = Math_fround($90 + $95);
 $99 = Math_fround($93 + $96);
 $100 = (($aToB) + 48|0);
 HEAPF32[$100>>2] = $69;
 $101 = (($aToB) + 52|0);
 HEAPF32[$101>>2] = $70;
 $102 = (($aToB) + 56|0);
 HEAPF32[$102>>2] = $71;
 $103 = (($aToB) + 60|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = Math_fround($97 + $97);
 $105 = Math_fround($98 + $98);
 $106 = Math_fround($99 + $99);
 $107 = Math_fround($97 * $104);
 $108 = Math_fround($98 * $105);
 $109 = Math_fround($99 * $106);
 $110 = Math_fround($98 * $104);
 $111 = Math_fround($99 * $104);
 $112 = Math_fround($78 * $104);
 $113 = Math_fround($99 * $105);
 $114 = Math_fround($78 * $105);
 $115 = Math_fround($78 * $106);
 $116 = Math_fround(Math_fround(1.0) - $107);
 $117 = Math_fround(Math_fround(1.0) - $108);
 $118 = Math_fround($117 - $109);
 $119 = Math_fround($110 + $115);
 $120 = Math_fround($111 - $114);
 $121 = Math_fround($110 - $115);
 $122 = Math_fround($116 - $109);
 $123 = Math_fround($113 + $112);
 $124 = Math_fround($111 + $114);
 $125 = Math_fround($113 - $112);
 $126 = Math_fround($116 - $108);
 HEAPF32[$aToB>>2] = $118;
 $127 = (($aToB) + 4|0);
 HEAPF32[$127>>2] = $119;
 $128 = (($aToB) + 8|0);
 HEAPF32[$128>>2] = $120;
 $129 = (($aToB) + 12|0);
 HEAPF32[$129>>2] = Math_fround(0.0);
 $130 = (($aToB) + 16|0);
 HEAPF32[$130>>2] = $121;
 $131 = (($aToB) + 20|0);
 HEAPF32[$131>>2] = $122;
 $132 = (($aToB) + 24|0);
 HEAPF32[$132>>2] = $123;
 $133 = (($aToB) + 28|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = (($aToB) + 32|0);
 HEAPF32[$134>>2] = $124;
 $135 = (($aToB) + 36|0);
 HEAPF32[$135>>2] = $125;
 $136 = (($aToB) + 40|0);
 HEAPF32[$136>>2] = $126;
 $137 = (($aToB) + 44|0);
 HEAPF32[$137>>2] = Math_fround(0.0);
 $138 = (($box) + 48|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = (($box) + 52|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($box) + 56|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($geom) + 4|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($geom) + 8|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = (($geom) + 12|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 HEAPF32[$vScale>>2] = $145;
 $150 = (($vScale) + 4|0);
 HEAPF32[$150>>2] = $147;
 $151 = (($vScale) + 8|0);
 HEAPF32[$151>>2] = $149;
 $152 = (($vScale) + 12|0);
 HEAPF32[$152>>2] = Math_fround(0.0);
 $153 = (($geom) + 16|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($geom) + 20|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($geom) + 24|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($geom) + 28|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 HEAPF32[$vQuat>>2] = $154;
 $161 = (($vQuat) + 4|0);
 HEAPF32[$161>>2] = $156;
 $162 = (($vQuat) + 8|0);
 HEAPF32[$162>>2] = $158;
 $163 = (($vQuat) + 12|0);
 HEAPF32[$163>>2] = $160;
 $164 = (($boxV) + 64|0);
 ;HEAP32[$boxV+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$boxV+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$boxV+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$boxV+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $165 = (($boxV) + 80|0);
 HEAP32[$165>>2] = 3;
 $166 = (($boxV) + 16|0);
 $167 = (($boxV) + 20|0);
 ;HEAP32[$167+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $168 = (($boxV) + 32|0);
 $169 = (($boxV) + 36|0);
 $170 = (($boxV) + 48|0);
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = (($boxV) + 52|0);
 ;HEAP32[$171+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$171+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$171+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$164+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$164+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$164+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $172 = (($boxV) + 144|0);
 HEAPF32[$172>>2] = $139;
 $173 = (($boxV) + 148|0);
 HEAPF32[$173>>2] = $141;
 $174 = (($boxV) + 152|0);
 HEAPF32[$174>>2] = $143;
 $175 = (($boxV) + 156|0);
 HEAPF32[$175>>2] = Math_fround(0.0);
 $176 = !($139 <= $141);
 $$$i26$i$i$i = $176 ? $141 : $139;
 $177 = !($$$i26$i$i$i <= $143);
 $178 = $177 ? $143 : $$$i26$i$i$i;
 $179 = !($139 >= $141);
 $$$i23$i$i$i = $179 ? $141 : $139;
 $180 = !($$$i23$i$i$i >= $143);
 $181 = $180 ? $143 : $$$i23$i$i$i;
 $182 = Math_fround($178 * Math_fround(0.150000005960464477539));
 $183 = Math_fround($181 * Math_fround(0.0299999993294477462769));
 $184 = $182 > $183;
 $$$i12$i$i$i = $184 ? $182 : $183;
 $185 = $178 > $$$i12$i$i$i;
 $$$i$i$i$i = $185 ? $$$i12$i$i$i : $178;
 HEAPF32[$166>>2] = $$$i$i$i$i;
 ;HEAP32[$167+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $186 = Math_fround($178 * Math_fround(0.0500000007450580596924));
 HEAPF32[$168>>2] = $186;
 ;HEAP32[$169+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$169+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$169+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($$sroa$1$i$i$i,$15,$zeroV,$vScale,$vQuat);
 $187 = Math_fround(HEAPF32[$unitDir>>2]);
 $188 = (($unitDir) + 4|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = (($unitDir) + 8|0);
 $191 = Math_fround(HEAPF32[$190>>2]);
 $192 = Math_fround($187 * $distance);
 $193 = Math_fround($189 * $distance);
 $194 = Math_fround($191 * $distance);
 $195 = Math_fround(-$192);
 $196 = Math_fround(-$193);
 $197 = Math_fround(-$194);
 $198 = Math_fround($39 * $195);
 $199 = Math_fround($39 * $196);
 $200 = Math_fround($39 * $197);
 $201 = Math_fround($21 * $197);
 $202 = Math_fround($23 * $196);
 $203 = Math_fround($201 - $202);
 $204 = Math_fround($23 * $195);
 $205 = Math_fround($19 * $197);
 $206 = Math_fround($204 - $205);
 $207 = Math_fround($19 * $196);
 $208 = Math_fround($21 * $195);
 $209 = Math_fround($207 - $208);
 $210 = Math_fround($25 * $203);
 $211 = Math_fround($25 * $206);
 $212 = Math_fround($25 * $209);
 $213 = Math_fround($198 - $210);
 $214 = Math_fround($199 - $211);
 $215 = Math_fround($200 - $212);
 $216 = Math_fround($19 * $195);
 $217 = Math_fround($21 * $196);
 $218 = Math_fround($216 + $217);
 $219 = Math_fround($23 * $197);
 $220 = Math_fround($218 + $219);
 $221 = Math_fround($19 * $220);
 $222 = Math_fround($21 * $220);
 $223 = Math_fround($23 * $220);
 $224 = Math_fround($221 + $213);
 $225 = Math_fround($222 + $214);
 $226 = Math_fround($215 + $223);
 $227 = Math_fround($224 * Math_fround(2.0));
 $228 = Math_fround($225 * Math_fround(2.0));
 $229 = Math_fround($226 * Math_fround(2.0));
 HEAPF32[$dir>>2] = $227;
 $230 = (($dir) + 4|0);
 HEAPF32[$230>>2] = $228;
 $231 = (($dir) + 8|0);
 HEAPF32[$231>>2] = $229;
 $232 = (($dir) + 12|0);
 HEAPF32[$232>>2] = Math_fround(0.0);
 $233 = HEAP16[$hintFlags>>1]|0;
 $234 = $233 & 512;
 $235 = ($234<<16>>16)!=(0);
 $236 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_4BoxVERNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($boxV,$$sroa$1$i$i$i,$aToB,$zero,$zeroV,$dir,$toi,$normal,$closestA,$inflation,$235)|0);
 if (!($236)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $237 = Math_fround(HEAPF32[$closestA>>2]);
 $238 = (($closestA) + 4|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($closestA) + 8|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = Math_fround($39 * $237);
 $243 = Math_fround($39 * $239);
 $244 = Math_fround($39 * $241);
 $245 = Math_fround($21 * $241);
 $246 = Math_fround($23 * $239);
 $247 = Math_fround($245 - $246);
 $248 = Math_fround($23 * $237);
 $249 = Math_fround($19 * $241);
 $250 = Math_fround($248 - $249);
 $251 = Math_fround($19 * $239);
 $252 = Math_fround($21 * $237);
 $253 = Math_fround($251 - $252);
 $254 = Math_fround($25 * $247);
 $255 = Math_fround($25 * $250);
 $256 = Math_fround($25 * $253);
 $257 = Math_fround($242 + $254);
 $258 = Math_fround($243 + $255);
 $259 = Math_fround($244 + $256);
 $260 = Math_fround($19 * $237);
 $261 = Math_fround($21 * $239);
 $262 = Math_fround($260 + $261);
 $263 = Math_fround($23 * $241);
 $264 = Math_fround($262 + $263);
 $265 = Math_fround($19 * $264);
 $266 = Math_fround($21 * $264);
 $267 = Math_fround($23 * $264);
 $268 = Math_fround($265 + $257);
 $269 = Math_fround($266 + $258);
 $270 = Math_fround($259 + $267);
 $271 = Math_fround($268 * Math_fround(2.0));
 $272 = Math_fround($269 * Math_fround(2.0));
 $273 = Math_fround($270 * Math_fround(2.0));
 $274 = Math_fround($27 + $271);
 $275 = Math_fround($29 + $272);
 $276 = Math_fround($31 + $273);
 $277 = (($sweepHit) + 12|0);
 HEAP16[$277>>1] = 6;
 $278 = Math_fround(HEAPF32[$zero>>2]);
 $279 = Math_fround(HEAPF32[$toi>>2]);
 $280 = !($278 >= $279);
 do {
  if ($280) {
   HEAP16[$277>>1] = 7;
   $351 = Math_fround(HEAPF32[$normal>>2]);
   $352 = (($normal) + 4|0);
   $353 = Math_fround(HEAPF32[$352>>2]);
   $354 = (($normal) + 8|0);
   $355 = Math_fround(HEAPF32[$354>>2]);
   $356 = Math_fround($39 * $351);
   $357 = Math_fround($39 * $353);
   $358 = Math_fround($39 * $355);
   $359 = Math_fround($21 * $355);
   $360 = Math_fround($23 * $353);
   $361 = Math_fround($359 - $360);
   $362 = Math_fround($23 * $351);
   $363 = Math_fround($19 * $355);
   $364 = Math_fround($362 - $363);
   $365 = Math_fround($19 * $353);
   $366 = Math_fround($21 * $351);
   $367 = Math_fround($365 - $366);
   $368 = Math_fround($25 * $361);
   $369 = Math_fround($25 * $364);
   $370 = Math_fround($25 * $367);
   $371 = Math_fround($356 + $368);
   $372 = Math_fround($357 + $369);
   $373 = Math_fround($358 + $370);
   $374 = Math_fround($19 * $351);
   $375 = Math_fround($21 * $353);
   $376 = Math_fround($374 + $375);
   $377 = Math_fround($23 * $355);
   $378 = Math_fround($376 + $377);
   $379 = Math_fround($19 * $378);
   $380 = Math_fround($21 * $378);
   $381 = Math_fround($23 * $378);
   $382 = Math_fround($379 + $371);
   $383 = Math_fround($380 + $372);
   $384 = Math_fround($373 + $381);
   $385 = Math_fround($382 * Math_fround(2.0));
   $386 = Math_fround($383 * Math_fround(2.0));
   $387 = Math_fround($384 * Math_fround(2.0));
   $388 = Math_fround($385 * $385);
   $389 = Math_fround($386 * $386);
   $390 = Math_fround($388 + $389);
   $391 = Math_fround($387 * $387);
   $392 = Math_fround($391 + $390);
   $393 = (Math_fround(Math_sqrt((Math_fround($392)))));
   $394 = Math_fround(Math_fround(1.0) / $393);
   $395 = Math_fround($394 * $385);
   $396 = Math_fround($394 * $386);
   $397 = Math_fround($394 * $387);
   $398 = Math_fround($279 * $distance);
   $399 = Math_fround($187 * $398);
   $400 = Math_fround($189 * $398);
   $401 = Math_fround($191 * $398);
   $402 = Math_fround($274 + $399);
   $403 = Math_fround($275 + $400);
   $404 = Math_fround($276 + $401);
   $405 = (($sweepHit) + 28|0);
   HEAPF32[$405>>2] = $395;
   $406 = (($sweepHit) + 32|0);
   HEAPF32[$406>>2] = $396;
   $407 = (($sweepHit) + 36|0);
   HEAPF32[$407>>2] = $397;
   $408 = (($sweepHit) + 16|0);
   HEAPF32[$408>>2] = $402;
   $409 = (($sweepHit) + 20|0);
   HEAPF32[$409>>2] = $403;
   $410 = (($sweepHit) + 24|0);
   HEAPF32[$410>>2] = $404;
   $411 = (($sweepHit) + 40|0);
   HEAPF32[$411>>2] = $398;
   $$idx$val = $402;$$idx1$val = $403;$$idx2$val = $404;
  } else {
   if ($235) {
    HEAP16[$277>>1] = 7;
    $281 = Math_fround(HEAPF32[$normal>>2]);
    $282 = (($normal) + 4|0);
    $283 = Math_fround(HEAPF32[$282>>2]);
    $284 = (($normal) + 8|0);
    $285 = Math_fround(HEAPF32[$284>>2]);
    $286 = Math_fround($39 * $281);
    $287 = Math_fround($39 * $283);
    $288 = Math_fround($39 * $285);
    $289 = Math_fround($21 * $285);
    $290 = Math_fround($23 * $283);
    $291 = Math_fround($289 - $290);
    $292 = Math_fround($23 * $281);
    $293 = Math_fround($19 * $285);
    $294 = Math_fround($292 - $293);
    $295 = Math_fround($19 * $283);
    $296 = Math_fround($21 * $281);
    $297 = Math_fround($295 - $296);
    $298 = Math_fround($25 * $291);
    $299 = Math_fround($25 * $294);
    $300 = Math_fround($25 * $297);
    $301 = Math_fround($286 + $298);
    $302 = Math_fround($287 + $299);
    $303 = Math_fround($288 + $300);
    $304 = Math_fround($19 * $281);
    $305 = Math_fround($21 * $283);
    $306 = Math_fround($304 + $305);
    $307 = Math_fround($23 * $285);
    $308 = Math_fround($306 + $307);
    $309 = Math_fround($19 * $308);
    $310 = Math_fround($21 * $308);
    $311 = Math_fround($23 * $308);
    $312 = Math_fround($309 + $301);
    $313 = Math_fround($310 + $302);
    $314 = Math_fround($303 + $311);
    $315 = Math_fround($312 * Math_fround(2.0));
    $316 = Math_fround($313 * Math_fround(2.0));
    $317 = Math_fround($314 * Math_fround(2.0));
    $318 = Math_fround($315 * $315);
    $319 = Math_fround($316 * $316);
    $320 = Math_fround($318 + $319);
    $321 = Math_fround($317 * $317);
    $322 = Math_fround($321 + $320);
    $323 = (Math_fround(Math_sqrt((Math_fround($322)))));
    $324 = Math_fround(Math_fround(1.0) / $323);
    $325 = Math_fround($324 * $315);
    $326 = Math_fround($324 * $316);
    $327 = Math_fround($324 * $317);
    $328 = Math_fround($279 * $325);
    $329 = Math_fround($279 * $326);
    $330 = Math_fround($279 * $327);
    $331 = Math_fround($274 - $328);
    $332 = Math_fround($275 - $329);
    $333 = Math_fround($276 - $330);
    $334 = (($sweepHit) + 28|0);
    HEAPF32[$334>>2] = $325;
    $335 = (($sweepHit) + 32|0);
    HEAPF32[$335>>2] = $326;
    $336 = (($sweepHit) + 36|0);
    HEAPF32[$336>>2] = $327;
    $337 = (($sweepHit) + 16|0);
    HEAPF32[$337>>2] = $331;
    $338 = (($sweepHit) + 20|0);
    HEAPF32[$338>>2] = $332;
    $339 = (($sweepHit) + 24|0);
    HEAPF32[$339>>2] = $333;
    $340 = (($sweepHit) + 40|0);
    HEAPF32[$340>>2] = $279;
    $$idx$val = $331;$$idx1$val = $332;$$idx2$val = $333;
    break;
   } else {
    $341 = (($sweepHit) + 40|0);
    HEAPF32[$341>>2] = Math_fround(0.0);
    $342 = Math_fround(HEAPF32[$unitDir>>2]);
    $343 = Math_fround(-$342);
    $344 = Math_fround(HEAPF32[$188>>2]);
    $345 = Math_fround(-$344);
    $346 = Math_fround(HEAPF32[$190>>2]);
    $347 = Math_fround(-$346);
    $348 = (($sweepHit) + 28|0);
    HEAPF32[$348>>2] = $343;
    $349 = (($sweepHit) + 32|0);
    HEAPF32[$349>>2] = $345;
    $350 = (($sweepHit) + 36|0);
    HEAPF32[$350>>2] = $347;
    $$idx$phi$trans$insert = (($sweepHit) + 16|0);
    $$idx$val$pre = Math_fround(HEAPF32[$$idx$phi$trans$insert>>2]);
    $$idx1$phi$trans$insert = (($sweepHit) + 20|0);
    $$idx1$val$pre = Math_fround(HEAPF32[$$idx1$phi$trans$insert>>2]);
    $$idx2$phi$trans$insert = (($sweepHit) + 24|0);
    $$idx2$val$pre = Math_fround(HEAPF32[$$idx2$phi$trans$insert>>2]);
    $$idx$val = $$idx$val$pre;$$idx1$val = $$idx1$val$pre;$$idx2$val = $$idx2$val$pre;
    break;
   }
  }
 } while(0);
 $unitDir$idx$val = Math_fround(HEAPF32[$unitDir>>2]);
 $unitDir$idx3$val = Math_fround(HEAPF32[$188>>2]);
 $unitDir$idx4$val = Math_fround(HEAPF32[$190>>2]);
 $412 = (__ZL23computeSweepConvexPlaneRKN5physx20PxConvexMeshGeometryEPNS_2Gu14ConvexHullDataERKjRKNS_11PxTransformERKNS_6PxVec3ESD_($geom,$15,$nbPolys,$pose,$$idx$val,$$idx1$val,$$idx2$val,$unitDir$idx$val,$unitDir$idx3$val,$unitDir$idx4$val)|0);
 $413 = (($sweepHit) + 8|0);
 HEAP32[$413>>2] = $412;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu21SweepCapsuleTrianglesEjPKNS_10PxTriangleERKNS_17PxCapsuleGeometryERKNS_11PxTransformERKNS_6PxVec3EfPKjRSA_SF_RfRjfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($nbTris,$triangles,$capsuleGeom,$capsulePose,$dir,$length,$cachedIndex,$hit,$normal,$d,$index,$inflation,$hintFlags) {
 $nbTris = $nbTris|0;
 $triangles = $triangles|0;
 $capsuleGeom = $capsuleGeom|0;
 $capsulePose = $capsulePose|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $cachedIndex = $cachedIndex|0;
 $hit = $hit|0;
 $normal = $normal|0;
 $d = $d|0;
 $index = $index|0;
 $inflation = Math_fround($inflation);
 $hintFlags = $hintFlags|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $capsule = 0, $capsuleBox = 0, $sweptBounds = 0, $unused = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $capsule = sp + 120|0;
 $capsuleBox = sp;
 $sweptBounds = sp + 60|0;
 $unused = sp + 150|0;
 $0 = sp + 148|0;
 $1 = Math_fround(HEAPF32[$capsulePose>>2]);
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = (($capsulePose) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = Math_fround($4 * $5);
 $7 = Math_fround($6 + Math_fround(-1.0));
 $8 = Math_fround($1 * $2);
 $9 = Math_fround($8 + $7);
 $10 = (($capsulePose) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $5);
 $13 = (($capsulePose) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($2 * $14);
 $16 = Math_fround($12 + $15);
 $17 = Math_fround($5 * $14);
 $18 = Math_fround($2 * $11);
 $19 = Math_fround($18 - $17);
 $20 = (($capsuleGeom) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $9);
 $23 = Math_fround($21 * $16);
 $24 = Math_fround($21 * $19);
 $25 = (($capsulePose) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + $22);
 $28 = (($capsulePose) + 20|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 + $23);
 $31 = (($capsulePose) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 + $32);
 HEAPF32[$capsule>>2] = $27;
 $34 = (($capsule) + 4|0);
 HEAPF32[$34>>2] = $30;
 $35 = (($capsule) + 8|0);
 HEAPF32[$35>>2] = $33;
 $36 = Math_fround($26 - $22);
 $37 = Math_fround($29 - $23);
 $38 = Math_fround($32 - $24);
 $39 = (($capsule) + 12|0);
 HEAPF32[$39>>2] = $36;
 $40 = (($capsule) + 16|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($capsule) + 20|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($capsuleGeom) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($capsule) + 24|0);
 $45 = Math_fround($43 + $inflation);
 HEAPF32[$44>>2] = $45;
 __ZN5physx2Gu23computeBoxAroundCapsuleERKNS0_7CapsuleERNS0_3BoxE($capsule,$capsuleBox);
 $46 = (($capsuleBox) + 48|0);
 $47 = (($capsuleBox) + 36|0);
 __ZN5physx2Gu15computeSweptBoxERNS0_3BoxERKNS_6PxVec3ES5_RKNS_7PxMat33ES5_f($sweptBounds,$46,$47,$capsuleBox,$dir,$length);
 HEAP16[$unused>>1] = 0;
 $48 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$0>>1] = $48;
 $49 = (__ZN5physx2Gu21sweepCapsuleTrianglesEjPKNS_10PxTriangleERKNS0_7CapsuleERKNS_6PxVec3EfPKjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEERfRS7_SI_RjSF_bPKNS0_3BoxE($nbTris,$triangles,$capsule,$dir,$length,$cachedIndex,$unused,$d,$normal,$hit,$index,$0,0,$sweptBounds)|0);
 STACKTOP = sp;return ($49|0);
}
function __Z22sweepConvex_SphereGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$convexGeom,$convexPose,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0;
 var $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $capsule = 0, $closestA = 0, $convexHull = 0, $dir = 0, $normal = 0, $sphereRadius$sroa$1 = 0, $toi = 0, $vQuat = 0, $vScale = 0, $zero = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $zero$sroa$1$i$i$i = sp + 508|0;
 $0 = sp + 480|0;
 $zeroV = sp + 464|0;
 $zero = sp + 448|0;
 $vScale = sp + 432|0;
 $vQuat = sp + 416|0;
 $sphereRadius$sroa$1 = sp + 496|0;
 $dir = sp + 368|0;
 $convexHull = sp + 160|0;
 $capsule = sp + 16|0;
 $toi = sp;
 $closestA = sp + 384|0;
 $normal = sp + 400|0;
 $1 = (($convexGeom) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 $4 = (($convexGeom) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($4) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($4) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$vScale>>2] = $5;
 $10 = (($vScale) + 4|0);
 HEAPF32[$10>>2] = $7;
 $11 = (($vScale) + 8|0);
 HEAPF32[$11>>2] = $9;
 $12 = (($vScale) + 12|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($convexGeom) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($13) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($13) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($13) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$vQuat>>2] = $14;
 $21 = (($vQuat) + 4|0);
 HEAPF32[$21>>2] = $16;
 $22 = (($vQuat) + 8|0);
 HEAPF32[$22>>2] = $18;
 $23 = (($vQuat) + 12|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($geom) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($pose) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($26) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($26) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(HEAPF32[$convexPose>>2]);
 $33 = (($convexPose) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($convexPose) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($convexPose) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($convexPose) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($39) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($39) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround(-$32);
 $46 = Math_fround(-$34);
 $47 = Math_fround(-$36);
 $48 = Math_fround($27 - $40);
 $49 = Math_fround($29 - $42);
 $50 = Math_fround($31 - $44);
 $51 = Math_fround($38 * $38);
 $52 = Math_fround($51 + Math_fround(-0.5));
 $53 = Math_fround($52 * $48);
 $54 = Math_fround($52 * $49);
 $55 = Math_fround($52 * $50);
 $56 = Math_fround($50 * $46);
 $57 = Math_fround($49 * $47);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($48 * $47);
 $60 = Math_fround($50 * $45);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($49 * $45);
 $63 = Math_fround($48 * $46);
 $64 = Math_fround($62 - $63);
 $65 = Math_fround($38 * $58);
 $66 = Math_fround($38 * $61);
 $67 = Math_fround($38 * $64);
 $68 = Math_fround($53 + $65);
 $69 = Math_fround($54 + $66);
 $70 = Math_fround($55 + $67);
 $71 = Math_fround($48 * $45);
 $72 = Math_fround($49 * $46);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($50 * $47);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($75 * $45);
 $77 = Math_fround($75 * $46);
 $78 = Math_fround($75 * $47);
 $79 = Math_fround($76 + $68);
 $80 = Math_fround($77 + $69);
 $81 = Math_fround($70 + $78);
 $82 = Math_fround($79 * Math_fround(2.0));
 $83 = Math_fround($80 * Math_fround(2.0));
 $84 = Math_fround($81 * Math_fround(2.0));
 $85 = Math_fround(HEAPF32[$unitDir>>2]);
 $86 = (($unitDir) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($unitDir) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($85 * $distance);
 $91 = Math_fround($87 * $distance);
 $92 = Math_fround($89 * $distance);
 $93 = Math_fround($52 * $90);
 $94 = Math_fround($52 * $91);
 $95 = Math_fround($52 * $92);
 $96 = Math_fround($34 * $92);
 $97 = Math_fround($36 * $91);
 $98 = Math_fround($96 - $97);
 $99 = Math_fround($36 * $90);
 $100 = Math_fround($32 * $92);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($32 * $91);
 $103 = Math_fround($34 * $90);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($38 * $98);
 $106 = Math_fround($38 * $101);
 $107 = Math_fround($38 * $104);
 $108 = Math_fround($93 - $105);
 $109 = Math_fround($94 - $106);
 $110 = Math_fround($95 - $107);
 $111 = Math_fround($32 * $90);
 $112 = Math_fround($34 * $91);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($36 * $92);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($32 * $115);
 $117 = Math_fround($34 * $115);
 $118 = Math_fround($36 * $115);
 $119 = Math_fround($116 + $108);
 $120 = Math_fround($117 + $109);
 $121 = Math_fround($110 + $118);
 $122 = Math_fround($119 * Math_fround(2.0));
 $123 = Math_fround($120 * Math_fround(2.0));
 $124 = Math_fround($121 * Math_fround(2.0));
 HEAPF32[$dir>>2] = $122;
 $125 = (($dir) + 4|0);
 HEAPF32[$125>>2] = $123;
 $126 = (($dir) + 8|0);
 HEAPF32[$126>>2] = $124;
 $127 = (($dir) + 12|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$3,$zeroV,$vScale,$vQuat);
 $128 = (($capsule) + 64|0);
 $129 = (($capsule) + 80|0);
 HEAP32[$129>>2] = 4;
 $130 = (($capsule) + 16|0);
 $131 = (($capsule) + 20|0);
 $132 = (($capsule) + 32|0);
 $133 = (($capsule) + 36|0);
 $134 = (($capsule) + 48|0);
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = (($capsule) + 52|0);
 ;HEAP32[$135+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$135+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$135+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 HEAPF32[$capsule>>2] = $82;
 $136 = (($capsule) + 4|0);
 HEAPF32[$136>>2] = $83;
 $137 = (($capsule) + 8|0);
 HEAPF32[$137>>2] = $84;
 $138 = (($capsule) + 12|0);
 HEAPF32[$138>>2] = Math_fround(0.0);
 $139 = (($capsule) + 128|0);
 HEAPF32[$139>>2] = $25;
 $140 = (($capsule) + 132|0);
 ;HEAP32[$140+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$140+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$140+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 $141 = (($capsule) + 96|0);
 HEAPF32[$141>>2] = $82;
 $142 = (($capsule) + 100|0);
 HEAPF32[$142>>2] = $83;
 $143 = (($capsule) + 104|0);
 HEAPF32[$143>>2] = $84;
 $144 = (($capsule) + 108|0);
 HEAPF32[$144>>2] = Math_fround(0.0);
 $145 = (($capsule) + 112|0);
 HEAPF32[$145>>2] = $82;
 $146 = (($capsule) + 116|0);
 HEAPF32[$146>>2] = $83;
 $147 = (($capsule) + 120|0);
 HEAPF32[$147>>2] = $84;
 $148 = (($capsule) + 124|0);
 HEAPF32[$148>>2] = Math_fround(0.0);
 HEAPF32[$130>>2] = $25;
 ;HEAP32[$131+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$131+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$131+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 HEAPF32[$132>>2] = $25;
 ;HEAP32[$133+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$133+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$133+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$128+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$128+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$128+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$128+12>>2]=HEAP32[$0+12>>2]|0;
 $149 = HEAP16[$hintFlags>>1]|0;
 $150 = $149 & 512;
 $151 = ($150<<16>>16)!=(0);
 $152 = Math_fround(HEAPF32[$24>>2]);
 $153 = Math_fround($152 + $inflation);
 $154 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_8CapsuleVERNS0_11ConvexHullVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($capsule,$convexHull,$zero,$zeroV,$dir,$toi,$normal,$closestA,$153,$151)|0);
 if (!($154)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $155 = (($sweepHit) + 8|0);
 HEAP32[$155>>2] = -1;
 $156 = Math_fround(HEAPF32[$closestA>>2]);
 $157 = (($closestA) + 4|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($closestA) + 8|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = Math_fround($52 * $156);
 $162 = Math_fround($52 * $158);
 $163 = Math_fround($52 * $160);
 $164 = Math_fround($34 * $160);
 $165 = Math_fround($36 * $158);
 $166 = Math_fround($164 - $165);
 $167 = Math_fround($36 * $156);
 $168 = Math_fround($32 * $160);
 $169 = Math_fround($167 - $168);
 $170 = Math_fround($32 * $158);
 $171 = Math_fround($34 * $156);
 $172 = Math_fround($170 - $171);
 $173 = Math_fround($38 * $166);
 $174 = Math_fround($38 * $169);
 $175 = Math_fround($38 * $172);
 $176 = Math_fround($161 + $173);
 $177 = Math_fround($162 + $174);
 $178 = Math_fround($163 + $175);
 $179 = Math_fround($32 * $156);
 $180 = Math_fround($34 * $158);
 $181 = Math_fround($179 + $180);
 $182 = Math_fround($36 * $160);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround($32 * $183);
 $185 = Math_fround($34 * $183);
 $186 = Math_fround($36 * $183);
 $187 = Math_fround($184 + $176);
 $188 = Math_fround($185 + $177);
 $189 = Math_fround($178 + $186);
 $190 = Math_fround($187 * Math_fround(2.0));
 $191 = Math_fround($188 * Math_fround(2.0));
 $192 = Math_fround($189 * Math_fround(2.0));
 $193 = Math_fround($40 + $190);
 $194 = Math_fround($42 + $191);
 $195 = Math_fround($44 + $192);
 $196 = (($sweepHit) + 12|0);
 HEAP16[$196>>1] = 6;
 $197 = Math_fround(HEAPF32[$zero>>2]);
 $198 = Math_fround(HEAPF32[$toi>>2]);
 $199 = !($197 >= $198);
 if ($199) {
  HEAP16[$196>>1] = 7;
  $267 = Math_fround(HEAPF32[$normal>>2]);
  $268 = (($normal) + 4|0);
  $269 = Math_fround(HEAPF32[$268>>2]);
  $270 = (($normal) + 8|0);
  $271 = Math_fround(HEAPF32[$270>>2]);
  $272 = Math_fround($52 * $267);
  $273 = Math_fround($52 * $269);
  $274 = Math_fround($52 * $271);
  $275 = Math_fround($34 * $271);
  $276 = Math_fround($36 * $269);
  $277 = Math_fround($275 - $276);
  $278 = Math_fround($36 * $267);
  $279 = Math_fround($32 * $271);
  $280 = Math_fround($278 - $279);
  $281 = Math_fround($32 * $269);
  $282 = Math_fround($34 * $267);
  $283 = Math_fround($281 - $282);
  $284 = Math_fround($38 * $277);
  $285 = Math_fround($38 * $280);
  $286 = Math_fround($38 * $283);
  $287 = Math_fround($272 + $284);
  $288 = Math_fround($273 + $285);
  $289 = Math_fround($274 + $286);
  $290 = Math_fround($32 * $267);
  $291 = Math_fround($34 * $269);
  $292 = Math_fround($290 + $291);
  $293 = Math_fround($36 * $271);
  $294 = Math_fround($292 + $293);
  $295 = Math_fround($32 * $294);
  $296 = Math_fround($34 * $294);
  $297 = Math_fround($36 * $294);
  $298 = Math_fround($295 + $287);
  $299 = Math_fround($296 + $288);
  $300 = Math_fround($289 + $297);
  $301 = Math_fround($298 * Math_fround(2.0));
  $302 = Math_fround($299 * Math_fround(2.0));
  $303 = Math_fround($300 * Math_fround(2.0));
  $304 = Math_fround($301 * $301);
  $305 = Math_fround($302 * $302);
  $306 = Math_fround($304 + $305);
  $307 = Math_fround($303 * $303);
  $308 = Math_fround($307 + $306);
  $309 = (Math_fround(Math_sqrt((Math_fround($308)))));
  $310 = Math_fround(Math_fround(1.0) / $309);
  $311 = Math_fround($310 * $301);
  $312 = Math_fround($310 * $302);
  $313 = Math_fround($310 * $303);
  $314 = Math_fround(-$311);
  $315 = Math_fround(-$312);
  $316 = Math_fround(-$313);
  $317 = Math_fround($198 * $distance);
  $318 = (($sweepHit) + 28|0);
  HEAPF32[$318>>2] = $314;
  $319 = (($sweepHit) + 32|0);
  HEAPF32[$319>>2] = $315;
  $320 = (($sweepHit) + 36|0);
  HEAPF32[$320>>2] = $316;
  $321 = (($sweepHit) + 16|0);
  HEAPF32[$321>>2] = $193;
  $322 = (($sweepHit) + 20|0);
  HEAPF32[$322>>2] = $194;
  $323 = (($sweepHit) + 24|0);
  HEAPF32[$323>>2] = $195;
  $324 = (($sweepHit) + 40|0);
  HEAPF32[$324>>2] = $317;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($151) {
  HEAP16[$196>>1] = 7;
  $200 = Math_fround(HEAPF32[$normal>>2]);
  $201 = (($normal) + 4|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($normal) + 8|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = Math_fround($52 * $200);
  $206 = Math_fround($52 * $202);
  $207 = Math_fround($52 * $204);
  $208 = Math_fround($34 * $204);
  $209 = Math_fround($36 * $202);
  $210 = Math_fround($208 - $209);
  $211 = Math_fround($36 * $200);
  $212 = Math_fround($32 * $204);
  $213 = Math_fround($211 - $212);
  $214 = Math_fround($32 * $202);
  $215 = Math_fround($34 * $200);
  $216 = Math_fround($214 - $215);
  $217 = Math_fround($38 * $210);
  $218 = Math_fround($38 * $213);
  $219 = Math_fround($38 * $216);
  $220 = Math_fround($205 + $217);
  $221 = Math_fround($206 + $218);
  $222 = Math_fround($207 + $219);
  $223 = Math_fround($32 * $200);
  $224 = Math_fround($34 * $202);
  $225 = Math_fround($223 + $224);
  $226 = Math_fround($36 * $204);
  $227 = Math_fround($225 + $226);
  $228 = Math_fround($32 * $227);
  $229 = Math_fround($34 * $227);
  $230 = Math_fround($36 * $227);
  $231 = Math_fround($228 + $220);
  $232 = Math_fround($229 + $221);
  $233 = Math_fround($222 + $230);
  $234 = Math_fround($231 * Math_fround(2.0));
  $235 = Math_fround($232 * Math_fround(2.0));
  $236 = Math_fround($233 * Math_fround(2.0));
  $237 = Math_fround($234 * $234);
  $238 = Math_fround($235 * $235);
  $239 = Math_fround($237 + $238);
  $240 = Math_fround($236 * $236);
  $241 = Math_fround($240 + $239);
  $242 = (Math_fround(Math_sqrt((Math_fround($241)))));
  $243 = Math_fround(Math_fround(1.0) / $242);
  $244 = Math_fround($243 * $234);
  $245 = Math_fround($243 * $235);
  $246 = Math_fround($243 * $236);
  $247 = Math_fround(-$244);
  $248 = Math_fround(-$245);
  $249 = Math_fround(-$246);
  $250 = (($sweepHit) + 28|0);
  HEAPF32[$250>>2] = $247;
  $251 = (($sweepHit) + 32|0);
  HEAPF32[$251>>2] = $248;
  $252 = (($sweepHit) + 36|0);
  HEAPF32[$252>>2] = $249;
  $253 = (($sweepHit) + 16|0);
  HEAPF32[$253>>2] = $193;
  $254 = (($sweepHit) + 20|0);
  HEAPF32[$254>>2] = $194;
  $255 = (($sweepHit) + 24|0);
  HEAPF32[$255>>2] = $195;
  $256 = (($sweepHit) + 40|0);
  HEAPF32[$256>>2] = $198;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $257 = (($sweepHit) + 40|0);
  HEAPF32[$257>>2] = Math_fround(0.0);
  $258 = Math_fround(HEAPF32[$unitDir>>2]);
  $259 = Math_fround(-$258);
  $260 = Math_fround(HEAPF32[$86>>2]);
  $261 = Math_fround(-$260);
  $262 = Math_fround(HEAPF32[$88>>2]);
  $263 = Math_fround(-$262);
  $264 = (($sweepHit) + 28|0);
  HEAPF32[$264>>2] = $259;
  $265 = (($sweepHit) + 32|0);
  HEAPF32[$265>>2] = $261;
  $266 = (($sweepHit) + 36|0);
  HEAPF32[$266>>2] = $263;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z21sweepConvex_PlaneGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$convexGeom,$convexPose,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $$in = 0, $$pre = Math_fround(0), $$pre55 = Math_fround(0), $$pre56 = Math_fround(0), $$pre57 = Math_fround(0), $$pre58 = Math_fround(0), $$pre59 = Math_fround(0), $$pre60 = Math_fround(0), $$pre61 = Math_fround(0), $$pre62 = Math_fround(0), $$pre63 = Math_fround(0), $$pre64 = Math_fround(0), $$pre65 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0);
 var $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $16 = Math_fround(0);
 var $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $convexScaling = 0, $hullVertices$0$ph34 = 0, $hullVertices$026 = 0, $or$cond = 0, $or$cond$i = 0, $plane = 0, $status$0$off0$ph35 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $convexScaling = sp + 16|0;
 $plane = sp;
 $0 = (($convexGeom) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = (($sweepHit) + 8|0);
 HEAP32[$3>>2] = -1;
 $4 = (($1) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 39|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = (($1) + 54|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = HEAP16[$hintFlags>>1]|0;
 $11 = $10 & 512;
 $12 = ($11<<16>>16)==(0);
 $13 = (($convexGeom) + 4|0);
 $14 = (($convexGeom) + 16|0);
 __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$13,$14);
 __ZN5physx2Gu8getPlaneERKNS_11PxTransformE($plane,$pose);
 $15 = (($plane) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 - $inflation);
 HEAPF32[$15>>2] = $17;
 $18 = (($sweepHit) + 40|0);
 HEAPF32[$18>>2] = $distance;
 $19 = ($9<<24>>24)==(0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = $7&255;
 $21 = $9&255;
 $22 = (($5) + (($20*20)|0)|0);
 $23 = (($convexScaling) + 4|0);
 $24 = (($convexScaling) + 8|0);
 $25 = (($convexScaling) + 12|0);
 $26 = (($convexScaling) + 16|0);
 $27 = (($convexScaling) + 20|0);
 $28 = (($convexScaling) + 24|0);
 $29 = (($convexScaling) + 28|0);
 $30 = (($convexScaling) + 32|0);
 $31 = (($convexPose) + 12|0);
 $32 = (($convexPose) + 4|0);
 $33 = (($convexPose) + 8|0);
 $34 = (($convexPose) + 16|0);
 $35 = (($convexPose) + 20|0);
 $36 = (($convexPose) + 24|0);
 $37 = (($unitDir) + 4|0);
 $38 = (($plane) + 4|0);
 $39 = (($unitDir) + 8|0);
 $40 = (($plane) + 8|0);
 $41 = (($sweepHit) + 12|0);
 $42 = (($sweepHit) + 16|0);
 $43 = (($sweepHit) + 20|0);
 $44 = (($sweepHit) + 24|0);
 $45 = (($sweepHit) + 28|0);
 $46 = (($sweepHit) + 32|0);
 $47 = (($sweepHit) + 36|0);
 $$pre = Math_fround(HEAPF32[$convexScaling>>2]);
 $$pre55 = Math_fround(HEAPF32[$23>>2]);
 $$pre56 = Math_fround(HEAPF32[$24>>2]);
 $$pre57 = Math_fround(HEAPF32[$25>>2]);
 $$pre58 = Math_fround(HEAPF32[$26>>2]);
 $$pre59 = Math_fround(HEAPF32[$27>>2]);
 $$pre60 = Math_fround(HEAPF32[$28>>2]);
 $$pre61 = Math_fround(HEAPF32[$29>>2]);
 $$pre62 = Math_fround(HEAPF32[$30>>2]);
 $$pre63 = Math_fround(HEAPF32[$plane>>2]);
 $$pre64 = Math_fround(HEAPF32[$38>>2]);
 $$pre65 = Math_fround(HEAPF32[$40>>2]);
 $$in = $21;$145 = $distance;$hullVertices$0$ph34 = $22;$status$0$off0$ph35 = 0;
 L4: while(1) {
  $48 = (($$in) + -1)|0;
  $49 = Math_fround(HEAPF32[$31>>2]);
  $50 = Math_fround($49 * $49);
  $51 = Math_fround($50 + Math_fround(-0.5));
  $52 = Math_fround(HEAPF32[$convexPose>>2]);
  $53 = Math_fround(HEAPF32[$32>>2]);
  $54 = Math_fround(HEAPF32[$33>>2]);
  $55 = Math_fround(HEAPF32[$34>>2]);
  $56 = Math_fround(HEAPF32[$35>>2]);
  $57 = Math_fround(HEAPF32[$36>>2]);
  $58 = Math_fround(HEAPF32[$unitDir>>2]);
  $59 = Math_fround($58 * $$pre63);
  $60 = Math_fround(HEAPF32[$37>>2]);
  $61 = Math_fround($60 * $$pre64);
  $62 = Math_fround($59 + $61);
  $63 = Math_fround(HEAPF32[$39>>2]);
  $64 = Math_fround($63 * $$pre65);
  $65 = Math_fround($62 + $64);
  $66 = +$65;
  $67 = $66 > -9.99999999999999954748E-8;
  $68 = $66 < 9.99999999999999954748E-8;
  $or$cond$i = $67 & $68;
  if ($or$cond$i) {
   $70 = $48;
   label = 4;
   break;
  } else {
   $147 = $48;$hullVertices$026 = $hullVertices$0$ph34;
  }
  while(1) {
   $72 = (($hullVertices$026) + 12|0);
   $73 = Math_fround(HEAPF32[$hullVertices$026>>2]);
   $74 = Math_fround($73 * $$pre);
   $75 = Math_fround($73 * $$pre55);
   $76 = Math_fround($73 * $$pre56);
   $77 = (($hullVertices$026) + 4|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = Math_fround($78 * $$pre57);
   $80 = Math_fround($78 * $$pre58);
   $81 = Math_fround($78 * $$pre59);
   $82 = Math_fround($74 + $79);
   $83 = Math_fround($75 + $80);
   $84 = Math_fround($76 + $81);
   $85 = (($hullVertices$026) + 8|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   $87 = Math_fround($86 * $$pre60);
   $88 = Math_fround($86 * $$pre61);
   $89 = Math_fround($86 * $$pre62);
   $90 = Math_fround($82 + $87);
   $91 = Math_fround($83 + $88);
   $92 = Math_fround($84 + $89);
   $93 = Math_fround($90 * Math_fround(2.0));
   $94 = Math_fround($91 * Math_fround(2.0));
   $95 = Math_fround($92 * Math_fround(2.0));
   $96 = Math_fround($93 * $52);
   $97 = Math_fround($94 * $53);
   $98 = Math_fround($96 + $97);
   $99 = Math_fround($95 * $54);
   $100 = Math_fround($98 + $99);
   $101 = Math_fround($93 * $51);
   $102 = Math_fround($95 * $53);
   $103 = Math_fround($94 * $54);
   $104 = Math_fround($102 - $103);
   $105 = Math_fround($49 * $104);
   $106 = Math_fround($101 + $105);
   $107 = Math_fround($52 * $100);
   $108 = Math_fround($107 + $106);
   $109 = Math_fround($94 * $51);
   $110 = Math_fround($93 * $54);
   $111 = Math_fround($52 * $95);
   $112 = Math_fround($110 - $111);
   $113 = Math_fround($49 * $112);
   $114 = Math_fround($109 + $113);
   $115 = Math_fround($53 * $100);
   $116 = Math_fround($115 + $114);
   $117 = Math_fround($95 * $51);
   $118 = Math_fround($94 * $52);
   $119 = Math_fround($93 * $53);
   $120 = Math_fround($118 - $119);
   $121 = Math_fround($49 * $120);
   $122 = Math_fround($117 + $121);
   $123 = Math_fround($54 * $100);
   $124 = Math_fround($122 + $123);
   $125 = Math_fround($55 + $108);
   $126 = Math_fround($56 + $116);
   $127 = Math_fround($57 + $124);
   $128 = Math_fround($$pre63 * $125);
   $129 = Math_fround($126 * $$pre64);
   $130 = Math_fround($128 + $129);
   $131 = Math_fround($127 * $$pre65);
   $132 = Math_fround($130 + $131);
   $133 = Math_fround($132 + $17);
   $134 = Math_fround(-$133);
   $135 = Math_fround($134 / $65);
   $136 = Math_fround($58 * $135);
   $137 = Math_fround($60 * $135);
   $138 = Math_fround($63 * $135);
   $139 = Math_fround($125 + $136);
   $140 = Math_fround($126 + $137);
   $141 = Math_fround($127 + $138);
   $142 = !($133 <= Math_fround(0.0));
   if (!($142)) {
    label = 9;
    break L4;
   }
   $143 = !($135 > Math_fround(0.0));
   $144 = !($135 <= $145);
   $or$cond = $143 | $144;
   if (!($or$cond)) {
    break;
   }
   $146 = (($147) + -1)|0;
   $148 = ($147|0)==(0);
   if ($148) {
    $$0 = $status$0$off0$ph35;
    label = 12;
    break L4;
   } else {
    $147 = $146;$hullVertices$026 = $72;
   }
  }
  HEAPF32[$18>>2] = $135;
  HEAP16[$41>>1] = 7;
  HEAPF32[$42>>2] = $139;
  HEAPF32[$43>>2] = $140;
  HEAPF32[$44>>2] = $141;
  HEAPF32[$45>>2] = $$pre63;
  HEAPF32[$46>>2] = $$pre64;
  HEAPF32[$47>>2] = $$pre65;
  $149 = ($147|0)==(0);
  if ($149) {
   $$0 = 1;
   label = 12;
   break;
  } else {
   $$in = $147;$145 = $135;$hullVertices$0$ph34 = $72;$status$0$off0$ph35 = 1;
  }
 }
 if ((label|0) == 4) {
  while(1) {
   label = 0;
   $69 = (($70) + -1)|0;
   $71 = ($70|0)==(0);
   if ($71) {
    $$0 = $status$0$off0$ph35;
    break;
   } else {
    $70 = $69;
    label = 4;
   }
  }
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 9) {
  if ($12) {
   HEAPF32[$18>>2] = Math_fround(0.0);
   HEAP16[$41>>1] = 6;
   $151 = Math_fround(HEAPF32[$unitDir>>2]);
   $152 = Math_fround(-$151);
   $153 = Math_fround(HEAPF32[$37>>2]);
   $154 = Math_fround(-$153);
   $155 = Math_fround(HEAPF32[$39>>2]);
   $156 = Math_fround(-$155);
   HEAPF32[$45>>2] = $152;
   HEAPF32[$46>>2] = $154;
   HEAPF32[$47>>2] = $156;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   HEAP16[$41>>1] = 7;
   $150 = (__ZN5physx2Gu22computePlane_ConvexMTDERKNS_7PxPlaneERKNS_20PxConvexMeshGeometryERKNS_11PxTransformERNS_10PxSweepHitE($plane,$convexGeom,$convexPose,$sweepHit)|0);
   $$0 = $150;
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 12) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z23sweepConvex_CapsuleGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$convexGeom,$convexPose,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $9 = Math_fround(0), $capsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $capsule = sp + 12|0;
 $0 = sp;
 $1 = sp + 40|0;
 $2 = Math_fround(HEAPF32[$pose>>2]);
 $3 = Math_fround($2 * Math_fround(2.0));
 $4 = (($pose) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = Math_fround($5 * $6);
 $8 = Math_fround($7 + Math_fround(-1.0));
 $9 = Math_fround($2 * $3);
 $10 = Math_fround($9 + $8);
 $11 = (($pose) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $6);
 $14 = (($pose) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 * $15);
 $17 = Math_fround($13 + $16);
 $18 = Math_fround($6 * $15);
 $19 = Math_fround($3 * $12);
 $20 = Math_fround($19 - $18);
 $21 = (($geom) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $10);
 $24 = Math_fround($22 * $17);
 $25 = Math_fround($22 * $20);
 $26 = (($pose) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 + $23);
 $29 = (($pose) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $24);
 $32 = (($pose) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($25 + $33);
 HEAPF32[$capsule>>2] = $28;
 $35 = (($capsule) + 4|0);
 HEAPF32[$35>>2] = $31;
 $36 = (($capsule) + 8|0);
 HEAPF32[$36>>2] = $34;
 $37 = Math_fround($27 - $23);
 $38 = Math_fround($30 - $24);
 $39 = Math_fround($33 - $25);
 $40 = (($capsule) + 12|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($capsule) + 16|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($capsule) + 20|0);
 HEAPF32[$42>>2] = $39;
 $43 = (($geom) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($capsule) + 24|0);
 HEAPF32[$45>>2] = $44;
 $46 = Math_fround(HEAPF32[$unitDir>>2]);
 $47 = Math_fround(-$46);
 $48 = (($unitDir) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround(-$49);
 $51 = (($unitDir) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(-$52);
 HEAPF32[$0>>2] = $47;
 $54 = (($0) + 4|0);
 HEAPF32[$54>>2] = $50;
 $55 = (($0) + 8|0);
 HEAPF32[$55>>2] = $53;
 $56 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$1>>1] = $56;
 $57 = (__Z23sweepCapsule_ConvexGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($convexGeom,$convexPose,$capsule,$0,$distance,$sweepHit,$1,$inflation)|0);
 if (!($57)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $58 = (($sweepHit) + 40|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround(HEAPF32[$unitDir>>2]);
 $61 = Math_fround($59 * $60);
 $62 = Math_fround(HEAPF32[$48>>2]);
 $63 = Math_fround($59 * $62);
 $64 = Math_fround(HEAPF32[$51>>2]);
 $65 = Math_fround($59 * $64);
 $66 = (($sweepHit) + 16|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($61 + $67);
 HEAPF32[$66>>2] = $68;
 $69 = (($sweepHit) + 20|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($63 + $70);
 HEAPF32[$69>>2] = $71;
 $72 = (($sweepHit) + 24|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($65 + $73);
 HEAPF32[$72>>2] = $74;
 $75 = (($sweepHit) + 28|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround(-$76);
 $78 = (($sweepHit) + 32|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround(-$79);
 $81 = (($sweepHit) + 36|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround(-$82);
 HEAPF32[$75>>2] = $77;
 HEAPF32[$78>>2] = $80;
 HEAPF32[$81>>2] = $83;
 $84 = (($sweepHit) + 8|0);
 HEAP32[$84>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z19sweepConvex_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$convexGeom,$convexPose,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $box = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $box = sp + 12|0;
 $0 = sp;
 $1 = sp + 72|0;
 $2 = (($geom) + 4|0);
 $3 = (($pose) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($box) + 36|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($pose) + 20|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($box) + 40|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($pose) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($box) + 44|0);
 HEAPF32[$11>>2] = $10;
 $12 = Math_fround(HEAPF32[$2>>2]);
 $13 = (($box) + 48|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($geom) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($box) + 52|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($geom) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($box) + 56|0);
 HEAPF32[$19>>2] = $18;
 $20 = Math_fround(HEAPF32[$pose>>2]);
 $21 = (($pose) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($pose) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($pose) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($20 + $20);
 $28 = Math_fround($22 + $22);
 $29 = Math_fround($24 + $24);
 $30 = Math_fround($20 * $27);
 $31 = Math_fround($22 * $28);
 $32 = Math_fround($24 * $29);
 $33 = Math_fround($27 * $22);
 $34 = Math_fround($27 * $24);
 $35 = Math_fround($27 * $26);
 $36 = Math_fround($28 * $24);
 $37 = Math_fround($28 * $26);
 $38 = Math_fround($29 * $26);
 $39 = Math_fround(Math_fround(1.0) - $31);
 $40 = Math_fround($39 - $32);
 $41 = Math_fround($33 + $38);
 $42 = Math_fround($34 - $37);
 $43 = Math_fround($33 - $38);
 $44 = Math_fround(Math_fround(1.0) - $30);
 $45 = Math_fround($44 - $32);
 $46 = Math_fround($36 + $35);
 $47 = Math_fround($34 + $37);
 $48 = Math_fround($36 - $35);
 $49 = Math_fround($44 - $31);
 HEAPF32[$box>>2] = $40;
 $50 = (($box) + 4|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($box) + 8|0);
 HEAPF32[$51>>2] = $42;
 $52 = (($box) + 12|0);
 HEAPF32[$52>>2] = $43;
 $53 = (($box) + 16|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($box) + 20|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($box) + 24|0);
 HEAPF32[$55>>2] = $47;
 $56 = (($box) + 28|0);
 HEAPF32[$56>>2] = $48;
 $57 = (($box) + 32|0);
 HEAPF32[$57>>2] = $49;
 $58 = Math_fround(HEAPF32[$unitDir>>2]);
 $59 = Math_fround(-$58);
 $60 = (($unitDir) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround(-$61);
 $63 = (($unitDir) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(-$64);
 HEAPF32[$0>>2] = $59;
 $66 = (($0) + 4|0);
 HEAPF32[$66>>2] = $62;
 $67 = (($0) + 8|0);
 HEAPF32[$67>>2] = $65;
 $68 = HEAP16[$hintFlags>>1]|0;
 HEAP16[$1>>1] = $68;
 $69 = (__Z19sweepBox_ConvexGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($convexGeom,$convexPose,$box,$0,$distance,$sweepHit,$1,$inflation)|0);
 if (!($69)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $70 = (($sweepHit) + 40|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround(HEAPF32[$unitDir>>2]);
 $73 = Math_fround($71 * $72);
 $74 = Math_fround(HEAPF32[$60>>2]);
 $75 = Math_fround($71 * $74);
 $76 = Math_fround(HEAPF32[$63>>2]);
 $77 = Math_fround($71 * $76);
 $78 = (($sweepHit) + 16|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($73 + $79);
 HEAPF32[$78>>2] = $80;
 $81 = (($sweepHit) + 20|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($75 + $82);
 HEAPF32[$81>>2] = $83;
 $84 = (($sweepHit) + 24|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($77 + $85);
 HEAPF32[$84>>2] = $86;
 $87 = (($sweepHit) + 28|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround(-$88);
 $90 = (($sweepHit) + 32|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround(-$91);
 $93 = (($sweepHit) + 36|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround(-$94);
 HEAPF32[$87>>2] = $89;
 HEAPF32[$90>>2] = $92;
 HEAPF32[$93>>2] = $95;
 $96 = (($sweepHit) + 8|0);
 HEAP32[$96>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z22sweepConvex_ConvexGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$convexGeom,$convexPose,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $$idx$phi$trans$insert = 0, $$idx$val = Math_fround(0), $$idx$val$pre = Math_fround(0), $$idx1$phi$trans$insert = 0, $$idx1$val = Math_fround(0), $$idx1$val$pre = Math_fround(0), $$idx2$phi$trans$insert = 0, $$idx2$val = Math_fround(0), $$idx2$val$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0);
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0);
 var $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0);
 var $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0);
 var $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0);
 var $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0);
 var $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0);
 var $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0);
 var $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0;
 var $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0);
 var $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0);
 var $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0);
 var $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0);
 var $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $closestA = 0, $convexHull = 0, $dir = 0, $nbPolys = 0, $normal = 0, $otherConvexHull = 0, $otherVQuat = 0, $otherVScale = 0, $toi = 0, $unitDir$idx$val = Math_fround(0);
 var $unitDir$idx3$val = Math_fround(0), $unitDir$idx4$val = Math_fround(0), $vQuat = 0, $vScale = 0, $zero = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 656|0;
 $nbPolys = sp + 640|0;
 $zeroV = sp + 624|0;
 $zero = sp + 608|0;
 $otherVScale = sp + 592|0;
 $otherVQuat = sp + 576|0;
 $vScale = sp + 560|0;
 $vQuat = sp + 544|0;
 $dir = sp + 528|0;
 $aToB = sp + 448|0;
 $otherConvexHull = sp + 240|0;
 $convexHull = sp + 32|0;
 $toi = sp + 16|0;
 $closestA = sp;
 $normal = sp + 512|0;
 $0 = (($geom) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($convexGeom) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 16|0);
 $5 = (($4) + 39|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 HEAP32[$nbPolys>>2] = $7;
 $8 = (($1) + 16|0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 $9 = (($geom) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($geom) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($geom) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$otherVScale>>2] = $10;
 $15 = (($otherVScale) + 4|0);
 HEAPF32[$15>>2] = $12;
 $16 = (($otherVScale) + 8|0);
 HEAPF32[$16>>2] = $14;
 $17 = (($otherVScale) + 12|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($geom) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($geom) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($geom) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($geom) + 28|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$otherVQuat>>2] = $19;
 $26 = (($otherVQuat) + 4|0);
 HEAPF32[$26>>2] = $21;
 $27 = (($otherVQuat) + 8|0);
 HEAPF32[$27>>2] = $23;
 $28 = (($otherVQuat) + 12|0);
 HEAPF32[$28>>2] = $25;
 $29 = (($convexGeom) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($29) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($29) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$vScale>>2] = $30;
 $35 = (($vScale) + 4|0);
 HEAPF32[$35>>2] = $32;
 $36 = (($vScale) + 8|0);
 HEAPF32[$36>>2] = $34;
 $37 = (($vScale) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($convexGeom) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($38) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($38) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($38) + 12|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 HEAPF32[$vQuat>>2] = $39;
 $46 = (($vQuat) + 4|0);
 HEAPF32[$46>>2] = $41;
 $47 = (($vQuat) + 8|0);
 HEAPF32[$47>>2] = $43;
 $48 = (($vQuat) + 12|0);
 HEAPF32[$48>>2] = $45;
 $49 = Math_fround(HEAPF32[$pose>>2]);
 $50 = (($pose) + 4|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($pose) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($pose) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($pose) + 16|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($56) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($56) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround(HEAPF32[$convexPose>>2]);
 $63 = (($convexPose) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($convexPose) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($convexPose) + 12|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($convexPose) + 16|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($69) + 4|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($69) + 8|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround(HEAPF32[$unitDir>>2]);
 $76 = (($unitDir) + 4|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($unitDir) + 8|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($75 * $distance);
 $81 = Math_fround($77 * $distance);
 $82 = Math_fround($79 * $distance);
 $83 = Math_fround($68 * $68);
 $84 = Math_fround($83 + Math_fround(-0.5));
 $85 = Math_fround($84 * $80);
 $86 = Math_fround($84 * $81);
 $87 = Math_fround($84 * $82);
 $88 = Math_fround($64 * $82);
 $89 = Math_fround($66 * $81);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($66 * $80);
 $92 = Math_fround($62 * $82);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($62 * $81);
 $95 = Math_fround($64 * $80);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($68 * $90);
 $98 = Math_fround($68 * $93);
 $99 = Math_fround($68 * $96);
 $100 = Math_fround($85 - $97);
 $101 = Math_fround($86 - $98);
 $102 = Math_fround($87 - $99);
 $103 = Math_fround($62 * $80);
 $104 = Math_fround($64 * $81);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($66 * $82);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($62 * $107);
 $109 = Math_fround($64 * $107);
 $110 = Math_fround($66 * $107);
 $111 = Math_fround($108 + $100);
 $112 = Math_fround($109 + $101);
 $113 = Math_fround($102 + $110);
 $114 = Math_fround($111 * Math_fround(2.0));
 $115 = Math_fround($112 * Math_fround(2.0));
 $116 = Math_fround($113 * Math_fround(2.0));
 HEAPF32[$dir>>2] = $114;
 $117 = (($dir) + 4|0);
 HEAPF32[$117>>2] = $115;
 $118 = (($dir) + 8|0);
 HEAPF32[$118>>2] = $116;
 $119 = (($dir) + 12|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = Math_fround(-$62);
 $121 = Math_fround(-$64);
 $122 = Math_fround(-$66);
 $123 = Math_fround($57 - $70);
 $124 = Math_fround($59 - $72);
 $125 = Math_fround($61 - $74);
 $126 = Math_fround($84 * $123);
 $127 = Math_fround($84 * $124);
 $128 = Math_fround($84 * $125);
 $129 = Math_fround($125 * $121);
 $130 = Math_fround($124 * $122);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($123 * $122);
 $133 = Math_fround($125 * $120);
 $134 = Math_fround($132 - $133);
 $135 = Math_fround($124 * $120);
 $136 = Math_fround($123 * $121);
 $137 = Math_fround($135 - $136);
 $138 = Math_fround($68 * $131);
 $139 = Math_fround($68 * $134);
 $140 = Math_fround($68 * $137);
 $141 = Math_fround($126 + $138);
 $142 = Math_fround($127 + $139);
 $143 = Math_fround($128 + $140);
 $144 = Math_fround($123 * $120);
 $145 = Math_fround($124 * $121);
 $146 = Math_fround($144 + $145);
 $147 = Math_fround($125 * $122);
 $148 = Math_fround($146 + $147);
 $149 = Math_fround($148 * $120);
 $150 = Math_fround($148 * $121);
 $151 = Math_fround($148 * $122);
 $152 = Math_fround($149 + $141);
 $153 = Math_fround($150 + $142);
 $154 = Math_fround($143 + $151);
 $155 = Math_fround($152 * Math_fround(2.0));
 $156 = Math_fround($153 * Math_fround(2.0));
 $157 = Math_fround($154 * Math_fround(2.0));
 $158 = Math_fround($55 * $68);
 $159 = Math_fround($49 * $120);
 $160 = Math_fround($51 * $121);
 $161 = Math_fround($159 + $160);
 $162 = Math_fround($53 * $122);
 $163 = Math_fround($161 + $162);
 $164 = Math_fround($158 - $163);
 $165 = Math_fround($55 * $120);
 $166 = Math_fround($55 * $121);
 $167 = Math_fround($55 * $122);
 $168 = Math_fround($49 * $68);
 $169 = Math_fround($51 * $68);
 $170 = Math_fround($53 * $68);
 $171 = Math_fround($53 * $121);
 $172 = Math_fround($51 * $122);
 $173 = Math_fround($171 - $172);
 $174 = Math_fround($49 * $122);
 $175 = Math_fround($53 * $120);
 $176 = Math_fround($174 - $175);
 $177 = Math_fround($51 * $120);
 $178 = Math_fround($49 * $121);
 $179 = Math_fround($177 - $178);
 $180 = Math_fround($165 + $168);
 $181 = Math_fround($166 + $169);
 $182 = Math_fround($170 + $167);
 $183 = Math_fround($173 + $180);
 $184 = Math_fround($176 + $181);
 $185 = Math_fround($179 + $182);
 $186 = (($aToB) + 48|0);
 HEAPF32[$186>>2] = $155;
 $187 = (($aToB) + 52|0);
 HEAPF32[$187>>2] = $156;
 $188 = (($aToB) + 56|0);
 HEAPF32[$188>>2] = $157;
 $189 = (($aToB) + 60|0);
 HEAPF32[$189>>2] = Math_fround(0.0);
 $190 = Math_fround($183 + $183);
 $191 = Math_fround($184 + $184);
 $192 = Math_fround($185 + $185);
 $193 = Math_fround($183 * $190);
 $194 = Math_fround($184 * $191);
 $195 = Math_fround($185 * $192);
 $196 = Math_fround($184 * $190);
 $197 = Math_fround($185 * $190);
 $198 = Math_fround($164 * $190);
 $199 = Math_fround($185 * $191);
 $200 = Math_fround($164 * $191);
 $201 = Math_fround($164 * $192);
 $202 = Math_fround(Math_fround(1.0) - $193);
 $203 = Math_fround(Math_fround(1.0) - $194);
 $204 = Math_fround($203 - $195);
 $205 = Math_fround($196 + $201);
 $206 = Math_fround($197 - $200);
 $207 = Math_fround($196 - $201);
 $208 = Math_fround($202 - $195);
 $209 = Math_fround($199 + $198);
 $210 = Math_fround($197 + $200);
 $211 = Math_fround($199 - $198);
 $212 = Math_fround($202 - $194);
 HEAPF32[$aToB>>2] = $204;
 $213 = (($aToB) + 4|0);
 HEAPF32[$213>>2] = $205;
 $214 = (($aToB) + 8|0);
 HEAPF32[$214>>2] = $206;
 $215 = (($aToB) + 12|0);
 HEAPF32[$215>>2] = Math_fround(0.0);
 $216 = (($aToB) + 16|0);
 HEAPF32[$216>>2] = $207;
 $217 = (($aToB) + 20|0);
 HEAPF32[$217>>2] = $208;
 $218 = (($aToB) + 24|0);
 HEAPF32[$218>>2] = $209;
 $219 = (($aToB) + 28|0);
 HEAPF32[$219>>2] = Math_fround(0.0);
 $220 = (($aToB) + 32|0);
 HEAPF32[$220>>2] = $210;
 $221 = (($aToB) + 36|0);
 HEAPF32[$221>>2] = $211;
 $222 = (($aToB) + 40|0);
 HEAPF32[$222>>2] = $212;
 $223 = (($aToB) + 44|0);
 HEAPF32[$223>>2] = Math_fround(0.0);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($otherConvexHull,$8,$zeroV,$otherVScale,$otherVQuat);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$4,$zeroV,$vScale,$vQuat);
 $224 = HEAP16[$hintFlags>>1]|0;
 $225 = $224 & 512;
 $226 = ($225<<16>>16)!=(0);
 $227 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_11ConvexHullVES2_RKNS_6shdfnd3aos15PsMatTransformVERKNS4_6FloatVERKNS4_5Vec3VESD_RS8_RSB_SF_fb($otherConvexHull,$convexHull,$aToB,$zero,$zeroV,$dir,$toi,$normal,$closestA,$inflation,$226)|0);
 if (!($227)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $228 = (($sweepHit) + 12|0);
 HEAP16[$228>>1] = 6;
 $229 = Math_fround(HEAPF32[$zero>>2]);
 $230 = Math_fround(HEAPF32[$toi>>2]);
 $231 = !($229 >= $230);
 do {
  if ($231) {
   HEAP16[$228>>1] = 7;
   $339 = Math_fround(HEAPF32[$closestA>>2]);
   $340 = (($closestA) + 4|0);
   $341 = Math_fround(HEAPF32[$340>>2]);
   $342 = (($closestA) + 8|0);
   $343 = Math_fround(HEAPF32[$342>>2]);
   $344 = Math_fround($84 * $339);
   $345 = Math_fround($84 * $341);
   $346 = Math_fround($84 * $343);
   $347 = Math_fround($64 * $343);
   $348 = Math_fround($66 * $341);
   $349 = Math_fround($347 - $348);
   $350 = Math_fround($66 * $339);
   $351 = Math_fround($62 * $343);
   $352 = Math_fround($350 - $351);
   $353 = Math_fround($62 * $341);
   $354 = Math_fround($64 * $339);
   $355 = Math_fround($353 - $354);
   $356 = Math_fround($68 * $349);
   $357 = Math_fround($68 * $352);
   $358 = Math_fround($68 * $355);
   $359 = Math_fround($344 + $356);
   $360 = Math_fround($345 + $357);
   $361 = Math_fround($346 + $358);
   $362 = Math_fround($62 * $339);
   $363 = Math_fround($64 * $341);
   $364 = Math_fround($362 + $363);
   $365 = Math_fround($66 * $343);
   $366 = Math_fround($364 + $365);
   $367 = Math_fround($62 * $366);
   $368 = Math_fround($64 * $366);
   $369 = Math_fround($66 * $366);
   $370 = Math_fround($367 + $359);
   $371 = Math_fround($368 + $360);
   $372 = Math_fround($361 + $369);
   $373 = Math_fround($370 * Math_fround(2.0));
   $374 = Math_fround($371 * Math_fround(2.0));
   $375 = Math_fround($372 * Math_fround(2.0));
   $376 = Math_fround($70 + $373);
   $377 = Math_fround($72 + $374);
   $378 = Math_fround($74 + $375);
   $379 = Math_fround(HEAPF32[$normal>>2]);
   $380 = (($normal) + 4|0);
   $381 = Math_fround(HEAPF32[$380>>2]);
   $382 = (($normal) + 8|0);
   $383 = Math_fround(HEAPF32[$382>>2]);
   $384 = Math_fround($84 * $379);
   $385 = Math_fround($84 * $381);
   $386 = Math_fround($84 * $383);
   $387 = Math_fround($64 * $383);
   $388 = Math_fround($66 * $381);
   $389 = Math_fround($387 - $388);
   $390 = Math_fround($66 * $379);
   $391 = Math_fround($62 * $383);
   $392 = Math_fround($390 - $391);
   $393 = Math_fround($62 * $381);
   $394 = Math_fround($64 * $379);
   $395 = Math_fround($393 - $394);
   $396 = Math_fround($68 * $389);
   $397 = Math_fround($68 * $392);
   $398 = Math_fround($68 * $395);
   $399 = Math_fround($384 + $396);
   $400 = Math_fround($385 + $397);
   $401 = Math_fround($386 + $398);
   $402 = Math_fround($62 * $379);
   $403 = Math_fround($64 * $381);
   $404 = Math_fround($402 + $403);
   $405 = Math_fround($66 * $383);
   $406 = Math_fround($404 + $405);
   $407 = Math_fround($62 * $406);
   $408 = Math_fround($64 * $406);
   $409 = Math_fround($66 * $406);
   $410 = Math_fround($407 + $399);
   $411 = Math_fround($408 + $400);
   $412 = Math_fround($401 + $409);
   $413 = Math_fround($410 * Math_fround(2.0));
   $414 = Math_fround($411 * Math_fround(2.0));
   $415 = Math_fround($412 * Math_fround(2.0));
   $416 = Math_fround($413 * $413);
   $417 = Math_fround($414 * $414);
   $418 = Math_fround($416 + $417);
   $419 = Math_fround($415 * $415);
   $420 = Math_fround($419 + $418);
   $421 = (Math_fround(Math_sqrt((Math_fround($420)))));
   $422 = Math_fround(Math_fround(1.0) / $421);
   $423 = Math_fround($422 * $413);
   $424 = Math_fround($422 * $414);
   $425 = Math_fround($422 * $415);
   $426 = Math_fround(-$423);
   $427 = Math_fround(-$424);
   $428 = Math_fround(-$425);
   $429 = Math_fround($230 * $distance);
   $430 = (($sweepHit) + 28|0);
   HEAPF32[$430>>2] = $426;
   $431 = (($sweepHit) + 32|0);
   HEAPF32[$431>>2] = $427;
   $432 = (($sweepHit) + 36|0);
   HEAPF32[$432>>2] = $428;
   $433 = (($sweepHit) + 16|0);
   HEAPF32[$433>>2] = $376;
   $434 = (($sweepHit) + 20|0);
   HEAPF32[$434>>2] = $377;
   $435 = (($sweepHit) + 24|0);
   HEAPF32[$435>>2] = $378;
   $436 = (($sweepHit) + 40|0);
   HEAPF32[$436>>2] = $429;
   $$idx$val = $376;$$idx1$val = $377;$$idx2$val = $378;
  } else {
   if ($226) {
    HEAP16[$228>>1] = 7;
    $232 = Math_fround(HEAPF32[$closestA>>2]);
    $233 = (($closestA) + 4|0);
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = (($closestA) + 8|0);
    $236 = Math_fround(HEAPF32[$235>>2]);
    $237 = Math_fround($84 * $232);
    $238 = Math_fround($84 * $234);
    $239 = Math_fround($84 * $236);
    $240 = Math_fround($64 * $236);
    $241 = Math_fround($66 * $234);
    $242 = Math_fround($240 - $241);
    $243 = Math_fround($66 * $232);
    $244 = Math_fround($62 * $236);
    $245 = Math_fround($243 - $244);
    $246 = Math_fround($62 * $234);
    $247 = Math_fround($64 * $232);
    $248 = Math_fround($246 - $247);
    $249 = Math_fround($68 * $242);
    $250 = Math_fround($68 * $245);
    $251 = Math_fround($68 * $248);
    $252 = Math_fround($237 + $249);
    $253 = Math_fround($238 + $250);
    $254 = Math_fround($239 + $251);
    $255 = Math_fround($62 * $232);
    $256 = Math_fround($64 * $234);
    $257 = Math_fround($255 + $256);
    $258 = Math_fround($66 * $236);
    $259 = Math_fround($257 + $258);
    $260 = Math_fround($62 * $259);
    $261 = Math_fround($64 * $259);
    $262 = Math_fround($66 * $259);
    $263 = Math_fround($260 + $252);
    $264 = Math_fround($261 + $253);
    $265 = Math_fround($254 + $262);
    $266 = Math_fround($263 * Math_fround(2.0));
    $267 = Math_fround($264 * Math_fround(2.0));
    $268 = Math_fround($265 * Math_fround(2.0));
    $269 = Math_fround($70 + $266);
    $270 = Math_fround($72 + $267);
    $271 = Math_fround($74 + $268);
    $272 = Math_fround(HEAPF32[$normal>>2]);
    $273 = (($normal) + 4|0);
    $274 = Math_fround(HEAPF32[$273>>2]);
    $275 = (($normal) + 8|0);
    $276 = Math_fround(HEAPF32[$275>>2]);
    $277 = Math_fround($84 * $272);
    $278 = Math_fround($84 * $274);
    $279 = Math_fround($84 * $276);
    $280 = Math_fround($64 * $276);
    $281 = Math_fround($66 * $274);
    $282 = Math_fround($280 - $281);
    $283 = Math_fround($66 * $272);
    $284 = Math_fround($62 * $276);
    $285 = Math_fround($283 - $284);
    $286 = Math_fround($62 * $274);
    $287 = Math_fround($64 * $272);
    $288 = Math_fround($286 - $287);
    $289 = Math_fround($68 * $282);
    $290 = Math_fround($68 * $285);
    $291 = Math_fround($68 * $288);
    $292 = Math_fround($277 + $289);
    $293 = Math_fround($278 + $290);
    $294 = Math_fround($279 + $291);
    $295 = Math_fround($62 * $272);
    $296 = Math_fround($64 * $274);
    $297 = Math_fround($295 + $296);
    $298 = Math_fround($66 * $276);
    $299 = Math_fround($297 + $298);
    $300 = Math_fround($62 * $299);
    $301 = Math_fround($64 * $299);
    $302 = Math_fround($66 * $299);
    $303 = Math_fround($300 + $292);
    $304 = Math_fround($301 + $293);
    $305 = Math_fround($294 + $302);
    $306 = Math_fround($303 * Math_fround(2.0));
    $307 = Math_fround($304 * Math_fround(2.0));
    $308 = Math_fround($305 * Math_fround(2.0));
    $309 = Math_fround($306 * $306);
    $310 = Math_fround($307 * $307);
    $311 = Math_fround($309 + $310);
    $312 = Math_fround($308 * $308);
    $313 = Math_fround($312 + $311);
    $314 = (Math_fround(Math_sqrt((Math_fround($313)))));
    $315 = Math_fround(Math_fround(1.0) / $314);
    $316 = Math_fround($315 * $306);
    $317 = Math_fround($315 * $307);
    $318 = Math_fround($315 * $308);
    $319 = Math_fround(-$316);
    $320 = Math_fround(-$317);
    $321 = Math_fround(-$318);
    $322 = (($sweepHit) + 28|0);
    HEAPF32[$322>>2] = $319;
    $323 = (($sweepHit) + 32|0);
    HEAPF32[$323>>2] = $320;
    $324 = (($sweepHit) + 36|0);
    HEAPF32[$324>>2] = $321;
    $325 = (($sweepHit) + 16|0);
    HEAPF32[$325>>2] = $269;
    $326 = (($sweepHit) + 20|0);
    HEAPF32[$326>>2] = $270;
    $327 = (($sweepHit) + 24|0);
    HEAPF32[$327>>2] = $271;
    $328 = (($sweepHit) + 40|0);
    HEAPF32[$328>>2] = $230;
    $$idx$val = $269;$$idx1$val = $270;$$idx2$val = $271;
    break;
   } else {
    $329 = (($sweepHit) + 40|0);
    HEAPF32[$329>>2] = Math_fround(0.0);
    $330 = Math_fround(HEAPF32[$unitDir>>2]);
    $331 = Math_fround(-$330);
    $332 = Math_fround(HEAPF32[$76>>2]);
    $333 = Math_fround(-$332);
    $334 = Math_fround(HEAPF32[$78>>2]);
    $335 = Math_fround(-$334);
    $336 = (($sweepHit) + 28|0);
    HEAPF32[$336>>2] = $331;
    $337 = (($sweepHit) + 32|0);
    HEAPF32[$337>>2] = $333;
    $338 = (($sweepHit) + 36|0);
    HEAPF32[$338>>2] = $335;
    $$idx$phi$trans$insert = (($sweepHit) + 16|0);
    $$idx$val$pre = Math_fround(HEAPF32[$$idx$phi$trans$insert>>2]);
    $$idx1$phi$trans$insert = (($sweepHit) + 20|0);
    $$idx1$val$pre = Math_fround(HEAPF32[$$idx1$phi$trans$insert>>2]);
    $$idx2$phi$trans$insert = (($sweepHit) + 24|0);
    $$idx2$val$pre = Math_fround(HEAPF32[$$idx2$phi$trans$insert>>2]);
    $$idx$val = $$idx$val$pre;$$idx1$val = $$idx1$val$pre;$$idx2$val = $$idx2$val$pre;
    break;
   }
  }
 } while(0);
 $unitDir$idx$val = Math_fround(HEAPF32[$unitDir>>2]);
 $unitDir$idx3$val = Math_fround(HEAPF32[$76>>2]);
 $unitDir$idx4$val = Math_fround(HEAPF32[$78>>2]);
 $437 = (__ZL23computeSweepConvexPlaneRKN5physx20PxConvexMeshGeometryEPNS_2Gu14ConvexHullDataERKjRKNS_11PxTransformERKNS_6PxVec3ESD_($convexGeom,$4,$nbPolys,$pose,$$idx$val,$$idx1$val,$$idx2$val,$unitDir$idx$val,$unitDir$idx3$val,$unitDir$idx4$val)|0);
 $438 = (($sweepHit) + 8|0);
 HEAP32[$438>>2] = $437;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z20sweepCapsule_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$lss,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $lss = $lss|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0;
 var $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0);
 var $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0);
 var $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0);
 var $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_capsuleHalfHeight = 0, $box = 0, $capTransform = 0, $capsule = 0, $capsuleRadius$sroa$1 = 0, $closestA = 0, $dir = 0, $normal = 0, $toi = 0, $zero = 0, $zero$sroa$1$i$i$i38 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $zero$sroa$1$i$i$i38 = sp + 368|0;
 $0 = sp + 416|0;
 $zero = sp + 384|0;
 $zeroV = sp + 400|0;
 $_capsuleHalfHeight = sp + 432|0;
 $capTransform = sp + 448|0;
 $capsuleRadius$sroa$1 = sp + 436|0;
 $box = sp + 192|0;
 $capsule = sp + 48|0;
 $dir = sp + 32|0;
 $toi = sp + 16|0;
 $closestA = sp;
 $normal = sp + 352|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $1 = (($geom) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($geom) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($geom) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$unitDir>>2]);
 $8 = (($unitDir) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($unitDir) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$_capsuleHalfHeight>>2] = Math_fround(0.0);
 __ZN5physx2Gu19getCapsuleTransformERKNS0_7CapsuleERf($capTransform,$lss,$_capsuleHalfHeight);
 $12 = Math_fround(HEAPF32[$capTransform>>2]);
 $13 = (($capTransform) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($capTransform) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($capTransform) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($capTransform) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($19) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($19) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(HEAPF32[$pose>>2]);
 $26 = (($pose) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($pose) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($pose) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($pose) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($32) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($32) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround(-$25);
 $39 = Math_fround(-$27);
 $40 = Math_fround(-$29);
 $41 = Math_fround($20 - $33);
 $42 = Math_fround($22 - $35);
 $43 = Math_fround($24 - $37);
 $44 = Math_fround($31 * $31);
 $45 = Math_fround($44 + Math_fround(-0.5));
 $46 = Math_fround($45 * $41);
 $47 = Math_fround($45 * $42);
 $48 = Math_fround($45 * $43);
 $49 = Math_fround($43 * $39);
 $50 = Math_fround($42 * $40);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($41 * $40);
 $53 = Math_fround($43 * $38);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($42 * $38);
 $56 = Math_fround($41 * $39);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($31 * $51);
 $59 = Math_fround($31 * $54);
 $60 = Math_fround($31 * $57);
 $61 = Math_fround($46 + $58);
 $62 = Math_fround($47 + $59);
 $63 = Math_fround($48 + $60);
 $64 = Math_fround($41 * $38);
 $65 = Math_fround($42 * $39);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($43 * $40);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($68 * $38);
 $70 = Math_fround($68 * $39);
 $71 = Math_fround($68 * $40);
 $72 = Math_fround($69 + $61);
 $73 = Math_fround($70 + $62);
 $74 = Math_fround($63 + $71);
 $75 = Math_fround($72 * Math_fround(2.0));
 $76 = Math_fround($73 * Math_fround(2.0));
 $77 = Math_fround($74 * Math_fround(2.0));
 $78 = Math_fround($18 * $31);
 $79 = Math_fround($12 * $38);
 $80 = Math_fround($14 * $39);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($16 * $40);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($78 - $83);
 $85 = Math_fround($18 * $38);
 $86 = Math_fround($18 * $39);
 $87 = Math_fround($18 * $40);
 $88 = Math_fround($12 * $31);
 $89 = Math_fround($14 * $31);
 $90 = Math_fround($16 * $31);
 $91 = Math_fround($16 * $39);
 $92 = Math_fround($14 * $40);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($12 * $40);
 $95 = Math_fround($16 * $38);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($14 * $38);
 $98 = Math_fround($12 * $39);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($85 + $88);
 $101 = Math_fround($86 + $89);
 $102 = Math_fround($90 + $87);
 $103 = Math_fround($93 + $100);
 $104 = Math_fround($96 + $101);
 $105 = Math_fround($99 + $102);
 $106 = Math_fround($103 + $103);
 $107 = Math_fround($104 + $104);
 $108 = Math_fround($105 + $105);
 $109 = Math_fround($103 * $106);
 $110 = Math_fround($104 * $107);
 $111 = Math_fround($105 * $108);
 $112 = Math_fround($104 * $106);
 $113 = Math_fround($105 * $106);
 $114 = Math_fround($84 * $106);
 $115 = Math_fround($105 * $107);
 $116 = Math_fround($84 * $107);
 $117 = Math_fround($84 * $108);
 $118 = Math_fround(Math_fround(1.0) - $109);
 $119 = Math_fround(Math_fround(1.0) - $110);
 $120 = Math_fround($119 - $111);
 $121 = Math_fround($112 + $117);
 $122 = Math_fround($113 - $116);
 $123 = Math_fround($112 - $117);
 $124 = Math_fround($118 - $111);
 $125 = Math_fround($115 + $114);
 $126 = Math_fround($113 + $116);
 $127 = Math_fround($115 - $114);
 $128 = Math_fround($118 - $110);
 $129 = Math_fround(HEAPF32[$_capsuleHalfHeight>>2]);
 $130 = (($lss) + 24|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($box) + 64|0);
 ;HEAP32[$box+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $133 = (($box) + 80|0);
 HEAP32[$133>>2] = 3;
 $134 = (($box) + 16|0);
 $135 = (($box) + 20|0);
 ;HEAP32[$135+0>>2]=HEAP32[$zero$sroa$1$i$i$i38+0>>2]|0;HEAP32[$135+4>>2]=HEAP32[$zero$sroa$1$i$i$i38+4>>2]|0;HEAP32[$135+8>>2]=HEAP32[$zero$sroa$1$i$i$i38+8>>2]|0;
 $136 = (($box) + 32|0);
 $137 = (($box) + 36|0);
 $138 = (($box) + 48|0);
 HEAPF32[$138>>2] = Math_fround(0.0);
 $139 = (($box) + 52|0);
 ;HEAP32[$139+0>>2]=HEAP32[$zero$sroa$1$i$i$i38+0>>2]|0;HEAP32[$139+4>>2]=HEAP32[$zero$sroa$1$i$i$i38+4>>2]|0;HEAP32[$139+8>>2]=HEAP32[$zero$sroa$1$i$i$i38+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$132+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$132+12>>2]=HEAP32[$0+12>>2]|0;
 $140 = (($box) + 144|0);
 HEAPF32[$140>>2] = $2;
 $141 = (($box) + 148|0);
 HEAPF32[$141>>2] = $4;
 $142 = (($box) + 152|0);
 HEAPF32[$142>>2] = $6;
 $143 = (($box) + 156|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = !($2 <= $4);
 $$$i26$i$i$i = $144 ? $4 : $2;
 $145 = !($$$i26$i$i$i <= $6);
 $146 = $145 ? $6 : $$$i26$i$i$i;
 $147 = !($2 >= $4);
 $$$i23$i$i$i = $147 ? $4 : $2;
 $148 = !($$$i23$i$i$i >= $6);
 $149 = $148 ? $6 : $$$i23$i$i$i;
 $150 = Math_fround($146 * Math_fround(0.150000005960464477539));
 $151 = Math_fround($149 * Math_fround(0.0299999993294477462769));
 $152 = $150 > $151;
 $$$i12$i$i$i = $152 ? $150 : $151;
 $153 = $146 > $$$i12$i$i$i;
 $$$i$i$i$i = $153 ? $$$i12$i$i$i : $146;
 HEAPF32[$134>>2] = $$$i$i$i$i;
 ;HEAP32[$135+0>>2]=HEAP32[$zero$sroa$1$i$i$i38+0>>2]|0;HEAP32[$135+4>>2]=HEAP32[$zero$sroa$1$i$i$i38+4>>2]|0;HEAP32[$135+8>>2]=HEAP32[$zero$sroa$1$i$i$i38+8>>2]|0;
 $154 = Math_fround($146 * Math_fround(0.0500000007450580596924));
 HEAPF32[$136>>2] = $154;
 ;HEAP32[$137+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$137+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$137+8>>2]=HEAP32[$0+8>>2]|0;
 $155 = Math_fround($129 * Math_fround(0.0));
 $156 = Math_fround($129 * $120);
 $157 = Math_fround($155 * $123);
 $158 = Math_fround($157 + $156);
 $159 = Math_fround($155 * $126);
 $160 = Math_fround($159 + $158);
 $161 = Math_fround($129 * $121);
 $162 = Math_fround($155 * $124);
 $163 = Math_fround($161 + $162);
 $164 = Math_fround($155 * $127);
 $165 = Math_fround($164 + $163);
 $166 = Math_fround($129 * $122);
 $167 = Math_fround($155 * $125);
 $168 = Math_fround($166 + $167);
 $169 = Math_fround($155 * $128);
 $170 = Math_fround($168 + $169);
 $171 = (($capsule) + 64|0);
 HEAPF32[$capsule>>2] = $75;
 $172 = (($capsule) + 4|0);
 HEAPF32[$172>>2] = $76;
 $173 = (($capsule) + 8|0);
 HEAPF32[$173>>2] = $77;
 $174 = (($capsule) + 12|0);
 HEAPF32[$174>>2] = Math_fround(0.0);
 $175 = (($capsule) + 80|0);
 HEAP32[$175>>2] = 4;
 $176 = (($capsule) + 16|0);
 $177 = (($capsule) + 20|0);
 $178 = (($capsule) + 32|0);
 $179 = (($capsule) + 36|0);
 $180 = (($capsule) + 48|0);
 HEAPF32[$180>>2] = Math_fround(0.0);
 $181 = (($capsule) + 52|0);
 ;HEAP32[$181+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$181+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$0+8>>2]|0;
 $182 = (($capsule) + 128|0);
 HEAPF32[$182>>2] = $131;
 $183 = (($capsule) + 132|0);
 ;HEAP32[$183+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$183+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$183+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $184 = Math_fround($75 + $160);
 $185 = Math_fround($76 + $165);
 $186 = Math_fround($77 + $170);
 $187 = (($capsule) + 96|0);
 HEAPF32[$187>>2] = $184;
 $188 = (($capsule) + 100|0);
 HEAPF32[$188>>2] = $185;
 $189 = (($capsule) + 104|0);
 HEAPF32[$189>>2] = $186;
 $190 = (($capsule) + 108|0);
 HEAPF32[$190>>2] = Math_fround(0.0);
 $191 = Math_fround($75 - $160);
 $192 = Math_fround($76 - $165);
 $193 = Math_fround($77 - $170);
 $194 = (($capsule) + 112|0);
 HEAPF32[$194>>2] = $191;
 $195 = (($capsule) + 116|0);
 HEAPF32[$195>>2] = $192;
 $196 = (($capsule) + 120|0);
 HEAPF32[$196>>2] = $193;
 $197 = (($capsule) + 124|0);
 HEAPF32[$197>>2] = Math_fround(0.0);
 HEAPF32[$176>>2] = $131;
 ;HEAP32[$177+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$177+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$177+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$178>>2] = $131;
 ;HEAP32[$179+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$179+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$179+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$zero$sroa$1$i$i$i38+0>>2]=4294967295|0;HEAP32[$zero$sroa$1$i$i$i38+4>>2]=4294967295|0;HEAP32[$zero$sroa$1$i$i$i38+8>>2]=4294967295|0;HEAP32[$zero$sroa$1$i$i$i38+12>>2]=4294967295|0;
 ;HEAP32[$171+0>>2]=HEAP32[$zero$sroa$1$i$i$i38+0>>2]|0;HEAP32[$171+4>>2]=HEAP32[$zero$sroa$1$i$i$i38+4>>2]|0;HEAP32[$171+8>>2]=HEAP32[$zero$sroa$1$i$i$i38+8>>2]|0;HEAP32[$171+12>>2]=HEAP32[$zero$sroa$1$i$i$i38+12>>2]|0;
 $198 = Math_fround($7 * $distance);
 $199 = Math_fround($9 * $distance);
 $200 = Math_fround($11 * $distance);
 $201 = Math_fround(-$198);
 $202 = Math_fround(-$199);
 $203 = Math_fround(-$200);
 $204 = Math_fround($45 * $201);
 $205 = Math_fround($45 * $202);
 $206 = Math_fround($45 * $203);
 $207 = Math_fround($27 * $203);
 $208 = Math_fround($29 * $202);
 $209 = Math_fround($207 - $208);
 $210 = Math_fround($29 * $201);
 $211 = Math_fround($25 * $203);
 $212 = Math_fround($210 - $211);
 $213 = Math_fround($25 * $202);
 $214 = Math_fround($27 * $201);
 $215 = Math_fround($213 - $214);
 $216 = Math_fround($31 * $209);
 $217 = Math_fround($31 * $212);
 $218 = Math_fround($31 * $215);
 $219 = Math_fround($204 - $216);
 $220 = Math_fround($205 - $217);
 $221 = Math_fround($206 - $218);
 $222 = Math_fround($25 * $201);
 $223 = Math_fround($27 * $202);
 $224 = Math_fround($222 + $223);
 $225 = Math_fround($29 * $203);
 $226 = Math_fround($224 + $225);
 $227 = Math_fround($25 * $226);
 $228 = Math_fround($27 * $226);
 $229 = Math_fround($29 * $226);
 $230 = Math_fround($227 + $219);
 $231 = Math_fround($228 + $220);
 $232 = Math_fround($229 + $221);
 $233 = Math_fround($230 * Math_fround(2.0));
 $234 = Math_fround($231 * Math_fround(2.0));
 $235 = Math_fround($232 * Math_fround(2.0));
 HEAPF32[$dir>>2] = $233;
 $236 = (($dir) + 4|0);
 HEAPF32[$236>>2] = $234;
 $237 = (($dir) + 8|0);
 HEAPF32[$237>>2] = $235;
 $238 = (($dir) + 12|0);
 HEAPF32[$238>>2] = Math_fround(0.0);
 $239 = HEAP16[$hintFlags>>1]|0;
 $240 = $239 & 512;
 $241 = ($240<<16>>16)!=(0);
 HEAPF32[$toi>>2] = Math_fround(3.40282346638528859812E+38);
 $242 = Math_fround(HEAPF32[$130>>2]);
 $243 = Math_fround($242 + $inflation);
 $244 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_8CapsuleVERNS0_4BoxVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($capsule,$box,$zero,$zeroV,$dir,$toi,$normal,$closestA,$243,$241)|0);
 if (!($244)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $245 = (($sweepHit) + 12|0);
 HEAP16[$245>>1] = 6;
 $246 = Math_fround(HEAPF32[$zero>>2]);
 $247 = Math_fround(HEAPF32[$toi>>2]);
 $248 = !($246 >= $247);
 if ($248) {
  HEAP16[$245>>1] = 7;
  $349 = Math_fround(HEAPF32[$closestA>>2]);
  $350 = (($closestA) + 4|0);
  $351 = Math_fround(HEAPF32[$350>>2]);
  $352 = (($closestA) + 8|0);
  $353 = Math_fround(HEAPF32[$352>>2]);
  $354 = Math_fround($45 * $349);
  $355 = Math_fround($45 * $351);
  $356 = Math_fround($45 * $353);
  $357 = Math_fround($27 * $353);
  $358 = Math_fround($29 * $351);
  $359 = Math_fround($357 - $358);
  $360 = Math_fround($29 * $349);
  $361 = Math_fround($25 * $353);
  $362 = Math_fround($360 - $361);
  $363 = Math_fround($25 * $351);
  $364 = Math_fround($27 * $349);
  $365 = Math_fround($363 - $364);
  $366 = Math_fround($31 * $359);
  $367 = Math_fround($31 * $362);
  $368 = Math_fround($31 * $365);
  $369 = Math_fround($354 + $366);
  $370 = Math_fround($355 + $367);
  $371 = Math_fround($356 + $368);
  $372 = Math_fround($25 * $349);
  $373 = Math_fround($27 * $351);
  $374 = Math_fround($372 + $373);
  $375 = Math_fround($29 * $353);
  $376 = Math_fround($374 + $375);
  $377 = Math_fround($25 * $376);
  $378 = Math_fround($27 * $376);
  $379 = Math_fround($29 * $376);
  $380 = Math_fround($377 + $369);
  $381 = Math_fround($378 + $370);
  $382 = Math_fround($371 + $379);
  $383 = Math_fround($380 * Math_fround(2.0));
  $384 = Math_fround($381 * Math_fround(2.0));
  $385 = Math_fround($382 * Math_fround(2.0));
  $386 = Math_fround($33 + $383);
  $387 = Math_fround($35 + $384);
  $388 = Math_fround($37 + $385);
  $389 = Math_fround(HEAPF32[$normal>>2]);
  $390 = (($normal) + 4|0);
  $391 = Math_fround(HEAPF32[$390>>2]);
  $392 = (($normal) + 8|0);
  $393 = Math_fround(HEAPF32[$392>>2]);
  $394 = Math_fround($45 * $389);
  $395 = Math_fround($45 * $391);
  $396 = Math_fround($45 * $393);
  $397 = Math_fround($27 * $393);
  $398 = Math_fround($29 * $391);
  $399 = Math_fround($397 - $398);
  $400 = Math_fround($29 * $389);
  $401 = Math_fround($25 * $393);
  $402 = Math_fround($400 - $401);
  $403 = Math_fround($25 * $391);
  $404 = Math_fround($27 * $389);
  $405 = Math_fround($403 - $404);
  $406 = Math_fround($31 * $399);
  $407 = Math_fround($31 * $402);
  $408 = Math_fround($31 * $405);
  $409 = Math_fround($394 + $406);
  $410 = Math_fround($395 + $407);
  $411 = Math_fround($396 + $408);
  $412 = Math_fround($25 * $389);
  $413 = Math_fround($27 * $391);
  $414 = Math_fround($412 + $413);
  $415 = Math_fround($29 * $393);
  $416 = Math_fround($414 + $415);
  $417 = Math_fround($25 * $416);
  $418 = Math_fround($27 * $416);
  $419 = Math_fround($29 * $416);
  $420 = Math_fround($417 + $409);
  $421 = Math_fround($418 + $410);
  $422 = Math_fround($411 + $419);
  $423 = Math_fround($420 * Math_fround(2.0));
  $424 = Math_fround($421 * Math_fround(2.0));
  $425 = Math_fround($422 * Math_fround(2.0));
  $426 = Math_fround($247 * $distance);
  $427 = Math_fround($7 * $426);
  $428 = Math_fround($9 * $426);
  $429 = Math_fround($11 * $426);
  $430 = Math_fround($427 + $386);
  $431 = Math_fround($428 + $387);
  $432 = Math_fround($429 + $388);
  $433 = (($sweepHit) + 28|0);
  HEAPF32[$433>>2] = $423;
  $434 = (($sweepHit) + 32|0);
  HEAPF32[$434>>2] = $424;
  $435 = (($sweepHit) + 36|0);
  HEAPF32[$435>>2] = $425;
  $436 = (($sweepHit) + 16|0);
  HEAPF32[$436>>2] = $430;
  $437 = (($sweepHit) + 20|0);
  HEAPF32[$437>>2] = $431;
  $438 = (($sweepHit) + 24|0);
  HEAPF32[$438>>2] = $432;
  $439 = (($sweepHit) + 40|0);
  HEAPF32[$439>>2] = $426;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($241) {
  HEAP16[$245>>1] = 7;
  $249 = Math_fround(HEAPF32[$closestA>>2]);
  $250 = (($closestA) + 4|0);
  $251 = Math_fround(HEAPF32[$250>>2]);
  $252 = (($closestA) + 8|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = Math_fround($45 * $249);
  $255 = Math_fround($45 * $251);
  $256 = Math_fround($45 * $253);
  $257 = Math_fround($27 * $253);
  $258 = Math_fround($29 * $251);
  $259 = Math_fround($257 - $258);
  $260 = Math_fround($29 * $249);
  $261 = Math_fround($25 * $253);
  $262 = Math_fround($260 - $261);
  $263 = Math_fround($25 * $251);
  $264 = Math_fround($27 * $249);
  $265 = Math_fround($263 - $264);
  $266 = Math_fround($31 * $259);
  $267 = Math_fround($31 * $262);
  $268 = Math_fround($31 * $265);
  $269 = Math_fround($254 + $266);
  $270 = Math_fround($255 + $267);
  $271 = Math_fround($256 + $268);
  $272 = Math_fround($25 * $249);
  $273 = Math_fround($27 * $251);
  $274 = Math_fround($272 + $273);
  $275 = Math_fround($29 * $253);
  $276 = Math_fround($274 + $275);
  $277 = Math_fround($25 * $276);
  $278 = Math_fround($27 * $276);
  $279 = Math_fround($29 * $276);
  $280 = Math_fround($277 + $269);
  $281 = Math_fround($278 + $270);
  $282 = Math_fround($271 + $279);
  $283 = Math_fround($280 * Math_fround(2.0));
  $284 = Math_fround($281 * Math_fround(2.0));
  $285 = Math_fround($282 * Math_fround(2.0));
  $286 = Math_fround($33 + $283);
  $287 = Math_fround($35 + $284);
  $288 = Math_fround($37 + $285);
  $289 = Math_fround(HEAPF32[$normal>>2]);
  $290 = (($normal) + 4|0);
  $291 = Math_fround(HEAPF32[$290>>2]);
  $292 = (($normal) + 8|0);
  $293 = Math_fround(HEAPF32[$292>>2]);
  $294 = Math_fround($45 * $289);
  $295 = Math_fround($45 * $291);
  $296 = Math_fround($45 * $293);
  $297 = Math_fround($27 * $293);
  $298 = Math_fround($29 * $291);
  $299 = Math_fround($297 - $298);
  $300 = Math_fround($29 * $289);
  $301 = Math_fround($25 * $293);
  $302 = Math_fround($300 - $301);
  $303 = Math_fround($25 * $291);
  $304 = Math_fround($27 * $289);
  $305 = Math_fround($303 - $304);
  $306 = Math_fround($31 * $299);
  $307 = Math_fround($31 * $302);
  $308 = Math_fround($31 * $305);
  $309 = Math_fround($294 + $306);
  $310 = Math_fround($295 + $307);
  $311 = Math_fround($296 + $308);
  $312 = Math_fround($25 * $289);
  $313 = Math_fround($27 * $291);
  $314 = Math_fround($312 + $313);
  $315 = Math_fround($29 * $293);
  $316 = Math_fround($314 + $315);
  $317 = Math_fround($25 * $316);
  $318 = Math_fround($27 * $316);
  $319 = Math_fround($29 * $316);
  $320 = Math_fround($317 + $309);
  $321 = Math_fround($318 + $310);
  $322 = Math_fround($311 + $319);
  $323 = Math_fround($320 * Math_fround(2.0));
  $324 = Math_fround($321 * Math_fround(2.0));
  $325 = Math_fround($322 * Math_fround(2.0));
  $326 = Math_fround($247 * $323);
  $327 = Math_fround($247 * $324);
  $328 = Math_fround($247 * $325);
  $329 = Math_fround($286 - $326);
  $330 = Math_fround($287 - $327);
  $331 = Math_fround($288 - $328);
  $332 = (($sweepHit) + 16|0);
  HEAPF32[$332>>2] = $329;
  $333 = (($sweepHit) + 20|0);
  HEAPF32[$333>>2] = $330;
  $334 = (($sweepHit) + 24|0);
  HEAPF32[$334>>2] = $331;
  $335 = (($sweepHit) + 28|0);
  HEAPF32[$335>>2] = $323;
  $336 = (($sweepHit) + 32|0);
  HEAPF32[$336>>2] = $324;
  $337 = (($sweepHit) + 36|0);
  HEAPF32[$337>>2] = $325;
  $338 = (($sweepHit) + 40|0);
  HEAPF32[$338>>2] = $247;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $339 = (($sweepHit) + 40|0);
  HEAPF32[$339>>2] = Math_fround(0.0);
  $340 = Math_fround(HEAPF32[$unitDir>>2]);
  $341 = Math_fround(-$340);
  $342 = Math_fround(HEAPF32[$8>>2]);
  $343 = Math_fround(-$342);
  $344 = Math_fround(HEAPF32[$10>>2]);
  $345 = Math_fround(-$344);
  $346 = (($sweepHit) + 28|0);
  HEAPF32[$346>>2] = $341;
  $347 = (($sweepHit) + 32|0);
  HEAPF32[$347>>2] = $343;
  $348 = (($sweepHit) + 36|0);
  HEAPF32[$348>>2] = $345;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z19sweepBox_SphereGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0;
 var $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $boxV = 0, $capsuleV = 0, $closestA = 0, $dir = 0;
 var $normal = 0, $sphereRadius$sroa$1 = 0, $toi = 0, $zero = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $0 = sp + 416|0;
 $1 = sp + 400|0;
 $zero = sp + 384|0;
 $zeroV = sp + 368|0;
 $sphereRadius$sroa$1 = sp + 432|0;
 $boxV = sp + 208|0;
 $capsuleV = sp + 48|0;
 $dir = sp + 32|0;
 $toi = sp + 16|0;
 $closestA = sp;
 $normal = sp + 192|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $2 = (($box) + 48|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($box) + 52|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($box) + 56|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(HEAPF32[$unitDir>>2]);
 $9 = (($unitDir) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($unitDir) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($geom) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$box);
 $15 = Math_fround(HEAPF32[$0>>2]);
 $16 = (($0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($0) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($box) + 36|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($box) + 40|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($box) + 44|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($pose) + 16|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($28) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($28) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround(-$15);
 $35 = Math_fround(-$17);
 $36 = Math_fround(-$19);
 $37 = Math_fround($29 - $23);
 $38 = Math_fround($31 - $25);
 $39 = Math_fround($33 - $27);
 $40 = Math_fround($21 * $21);
 $41 = Math_fround($40 + Math_fround(-0.5));
 $42 = Math_fround($41 * $37);
 $43 = Math_fround($41 * $38);
 $44 = Math_fround($41 * $39);
 $45 = Math_fround($39 * $35);
 $46 = Math_fround($38 * $36);
 $47 = Math_fround($45 - $46);
 $48 = Math_fround($37 * $36);
 $49 = Math_fround($39 * $34);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($38 * $34);
 $52 = Math_fround($37 * $35);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($21 * $47);
 $55 = Math_fround($21 * $50);
 $56 = Math_fround($21 * $53);
 $57 = Math_fround($42 + $54);
 $58 = Math_fround($43 + $55);
 $59 = Math_fround($44 + $56);
 $60 = Math_fround($37 * $34);
 $61 = Math_fround($38 * $35);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($39 * $36);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($64 * $34);
 $66 = Math_fround($64 * $35);
 $67 = Math_fround($64 * $36);
 $68 = Math_fround($65 + $57);
 $69 = Math_fround($66 + $58);
 $70 = Math_fround($59 + $67);
 $71 = Math_fround($68 * Math_fround(2.0));
 $72 = Math_fround($69 * Math_fround(2.0));
 $73 = Math_fround($70 * Math_fround(2.0));
 $74 = (($boxV) + 64|0);
 ;HEAP32[$boxV+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$boxV+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$boxV+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$boxV+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $75 = (($boxV) + 80|0);
 HEAP32[$75>>2] = 3;
 $76 = (($boxV) + 16|0);
 $77 = (($boxV) + 20|0);
 ;HEAP32[$77+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$0+8>>2]|0;
 $78 = (($boxV) + 32|0);
 $79 = (($boxV) + 36|0);
 $80 = (($boxV) + 48|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 $81 = (($boxV) + 52|0);
 ;HEAP32[$81+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$81+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$81+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 ;HEAP32[$74+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$1+12>>2]|0;
 $82 = (($boxV) + 144|0);
 HEAPF32[$82>>2] = $3;
 $83 = (($boxV) + 148|0);
 HEAPF32[$83>>2] = $5;
 $84 = (($boxV) + 152|0);
 HEAPF32[$84>>2] = $7;
 $85 = (($boxV) + 156|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 $86 = !($3 <= $5);
 $$$i26$i$i$i = $86 ? $5 : $3;
 $87 = !($$$i26$i$i$i <= $7);
 $88 = $87 ? $7 : $$$i26$i$i$i;
 $89 = !($3 >= $5);
 $$$i23$i$i$i = $89 ? $5 : $3;
 $90 = !($$$i23$i$i$i >= $7);
 $91 = $90 ? $7 : $$$i23$i$i$i;
 $92 = Math_fround($88 * Math_fround(0.150000005960464477539));
 $93 = Math_fround($91 * Math_fround(0.0299999993294477462769));
 $94 = $92 > $93;
 $$$i12$i$i$i = $94 ? $92 : $93;
 $95 = $88 > $$$i12$i$i$i;
 $$$i$i$i$i = $95 ? $$$i12$i$i$i : $88;
 HEAPF32[$76>>2] = $$$i$i$i$i;
 ;HEAP32[$77+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$0+8>>2]|0;
 $96 = Math_fround($88 * Math_fround(0.0500000007450580596924));
 HEAPF32[$78>>2] = $96;
 ;HEAP32[$79+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$1+8>>2]|0;
 $97 = (($capsuleV) + 64|0);
 $98 = (($capsuleV) + 80|0);
 HEAP32[$98>>2] = 4;
 $99 = (($capsuleV) + 16|0);
 $100 = (($capsuleV) + 20|0);
 $101 = (($capsuleV) + 32|0);
 $102 = (($capsuleV) + 36|0);
 $103 = (($capsuleV) + 48|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($capsuleV) + 52|0);
 ;HEAP32[$104+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$1+8>>2]|0;
 HEAPF32[$capsuleV>>2] = $71;
 $105 = (($capsuleV) + 4|0);
 HEAPF32[$105>>2] = $72;
 $106 = (($capsuleV) + 8|0);
 HEAPF32[$106>>2] = $73;
 $107 = (($capsuleV) + 12|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($capsuleV) + 128|0);
 HEAPF32[$108>>2] = $14;
 $109 = (($capsuleV) + 132|0);
 ;HEAP32[$109+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$109+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 $110 = (($capsuleV) + 96|0);
 HEAPF32[$110>>2] = $71;
 $111 = (($capsuleV) + 100|0);
 HEAPF32[$111>>2] = $72;
 $112 = (($capsuleV) + 104|0);
 HEAPF32[$112>>2] = $73;
 $113 = (($capsuleV) + 108|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = (($capsuleV) + 112|0);
 HEAPF32[$114>>2] = $71;
 $115 = (($capsuleV) + 116|0);
 HEAPF32[$115>>2] = $72;
 $116 = (($capsuleV) + 120|0);
 HEAPF32[$116>>2] = $73;
 $117 = (($capsuleV) + 124|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 HEAPF32[$99>>2] = $14;
 ;HEAP32[$100+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$100+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$100+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 HEAPF32[$101>>2] = $14;
 ;HEAP32[$102+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$97+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$97+12>>2]=HEAP32[$0+12>>2]|0;
 $118 = Math_fround($8 * $distance);
 $119 = Math_fround($10 * $distance);
 $120 = Math_fround($12 * $distance);
 $121 = Math_fround($118 * $41);
 $122 = Math_fround($119 * $41);
 $123 = Math_fround($120 * $41);
 $124 = Math_fround($120 * $17);
 $125 = Math_fround($119 * $19);
 $126 = Math_fround($124 - $125);
 $127 = Math_fround($118 * $19);
 $128 = Math_fround($120 * $15);
 $129 = Math_fround($127 - $128);
 $130 = Math_fround($119 * $15);
 $131 = Math_fround($118 * $17);
 $132 = Math_fround($130 - $131);
 $133 = Math_fround($21 * $126);
 $134 = Math_fround($21 * $129);
 $135 = Math_fround($21 * $132);
 $136 = Math_fround($121 - $133);
 $137 = Math_fround($122 - $134);
 $138 = Math_fround($123 - $135);
 $139 = Math_fround($118 * $15);
 $140 = Math_fround($119 * $17);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($120 * $19);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround($15 * $143);
 $145 = Math_fround($17 * $143);
 $146 = Math_fround($19 * $143);
 $147 = Math_fround($144 + $136);
 $148 = Math_fround($145 + $137);
 $149 = Math_fround($146 + $138);
 $150 = Math_fround($147 * Math_fround(2.0));
 $151 = Math_fround($148 * Math_fround(2.0));
 $152 = Math_fround($149 * Math_fround(2.0));
 HEAPF32[$dir>>2] = $150;
 $153 = (($dir) + 4|0);
 HEAPF32[$153>>2] = $151;
 $154 = (($dir) + 8|0);
 HEAPF32[$154>>2] = $152;
 $155 = (($dir) + 12|0);
 HEAPF32[$155>>2] = Math_fround(0.0);
 $156 = HEAP16[$hintFlags>>1]|0;
 $157 = $156 & 512;
 $158 = ($157<<16>>16)!=(0);
 $159 = Math_fround(HEAPF32[$13>>2]);
 $160 = Math_fround($159 + $inflation);
 $161 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_8CapsuleVERNS0_4BoxVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($capsuleV,$boxV,$zero,$zeroV,$dir,$toi,$normal,$closestA,$160,$158)|0);
 if (!($161)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $162 = (($sweepHit) + 12|0);
 HEAP16[$162>>1] = 6;
 $163 = Math_fround(HEAPF32[$zero>>2]);
 $164 = Math_fround(HEAPF32[$toi>>2]);
 $165 = !($163 >= $164);
 if ($165) {
  HEAP16[$162>>1] = 7;
  $263 = Math_fround(HEAPF32[$closestA>>2]);
  $264 = (($closestA) + 4|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = (($closestA) + 8|0);
  $267 = Math_fround(HEAPF32[$266>>2]);
  $268 = Math_fround($41 * $263);
  $269 = Math_fround($41 * $265);
  $270 = Math_fround($41 * $267);
  $271 = Math_fround($17 * $267);
  $272 = Math_fround($19 * $265);
  $273 = Math_fround($271 - $272);
  $274 = Math_fround($19 * $263);
  $275 = Math_fround($15 * $267);
  $276 = Math_fround($274 - $275);
  $277 = Math_fround($15 * $265);
  $278 = Math_fround($17 * $263);
  $279 = Math_fround($277 - $278);
  $280 = Math_fround($21 * $273);
  $281 = Math_fround($21 * $276);
  $282 = Math_fround($21 * $279);
  $283 = Math_fround($268 + $280);
  $284 = Math_fround($269 + $281);
  $285 = Math_fround($270 + $282);
  $286 = Math_fround($15 * $263);
  $287 = Math_fround($17 * $265);
  $288 = Math_fround($286 + $287);
  $289 = Math_fround($19 * $267);
  $290 = Math_fround($288 + $289);
  $291 = Math_fround($15 * $290);
  $292 = Math_fround($17 * $290);
  $293 = Math_fround($19 * $290);
  $294 = Math_fround($291 + $283);
  $295 = Math_fround($292 + $284);
  $296 = Math_fround($285 + $293);
  $297 = Math_fround($294 * Math_fround(2.0));
  $298 = Math_fround($295 * Math_fround(2.0));
  $299 = Math_fround($296 * Math_fround(2.0));
  $300 = Math_fround($23 + $297);
  $301 = Math_fround($25 + $298);
  $302 = Math_fround($27 + $299);
  $303 = Math_fround(HEAPF32[$normal>>2]);
  $304 = (($normal) + 4|0);
  $305 = Math_fround(HEAPF32[$304>>2]);
  $306 = (($normal) + 8|0);
  $307 = Math_fround(HEAPF32[$306>>2]);
  $308 = Math_fround($41 * $303);
  $309 = Math_fround($41 * $305);
  $310 = Math_fround($41 * $307);
  $311 = Math_fround($17 * $307);
  $312 = Math_fround($19 * $305);
  $313 = Math_fround($311 - $312);
  $314 = Math_fround($19 * $303);
  $315 = Math_fround($15 * $307);
  $316 = Math_fround($314 - $315);
  $317 = Math_fround($15 * $305);
  $318 = Math_fround($17 * $303);
  $319 = Math_fround($317 - $318);
  $320 = Math_fround($21 * $313);
  $321 = Math_fround($21 * $316);
  $322 = Math_fround($21 * $319);
  $323 = Math_fround($308 + $320);
  $324 = Math_fround($309 + $321);
  $325 = Math_fround($310 + $322);
  $326 = Math_fround($15 * $303);
  $327 = Math_fround($17 * $305);
  $328 = Math_fround($326 + $327);
  $329 = Math_fround($19 * $307);
  $330 = Math_fround($328 + $329);
  $331 = Math_fround($15 * $330);
  $332 = Math_fround($17 * $330);
  $333 = Math_fround($19 * $330);
  $334 = Math_fround($331 + $323);
  $335 = Math_fround($332 + $324);
  $336 = Math_fround($325 + $333);
  $337 = Math_fround($334 * Math_fround(2.0));
  $338 = Math_fround($335 * Math_fround(2.0));
  $339 = Math_fround($336 * Math_fround(2.0));
  $340 = Math_fround(-$337);
  $341 = Math_fround(-$338);
  $342 = Math_fround(-$339);
  $343 = Math_fround($164 * $distance);
  $344 = (($sweepHit) + 28|0);
  HEAPF32[$344>>2] = $340;
  $345 = (($sweepHit) + 32|0);
  HEAPF32[$345>>2] = $341;
  $346 = (($sweepHit) + 36|0);
  HEAPF32[$346>>2] = $342;
  $347 = (($sweepHit) + 16|0);
  HEAPF32[$347>>2] = $300;
  $348 = (($sweepHit) + 20|0);
  HEAPF32[$348>>2] = $301;
  $349 = (($sweepHit) + 24|0);
  HEAPF32[$349>>2] = $302;
  $350 = (($sweepHit) + 40|0);
  HEAPF32[$350>>2] = $343;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($158) {
  HEAP16[$162>>1] = 7;
  $166 = Math_fround(HEAPF32[$closestA>>2]);
  $167 = (($closestA) + 4|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($closestA) + 8|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround($41 * $166);
  $172 = Math_fround($41 * $168);
  $173 = Math_fround($41 * $170);
  $174 = Math_fround($17 * $170);
  $175 = Math_fround($19 * $168);
  $176 = Math_fround($174 - $175);
  $177 = Math_fround($19 * $166);
  $178 = Math_fround($15 * $170);
  $179 = Math_fround($177 - $178);
  $180 = Math_fround($15 * $168);
  $181 = Math_fround($17 * $166);
  $182 = Math_fround($180 - $181);
  $183 = Math_fround($21 * $176);
  $184 = Math_fround($21 * $179);
  $185 = Math_fround($21 * $182);
  $186 = Math_fround($171 + $183);
  $187 = Math_fround($172 + $184);
  $188 = Math_fround($173 + $185);
  $189 = Math_fround($15 * $166);
  $190 = Math_fround($17 * $168);
  $191 = Math_fround($189 + $190);
  $192 = Math_fround($19 * $170);
  $193 = Math_fround($191 + $192);
  $194 = Math_fround($15 * $193);
  $195 = Math_fround($17 * $193);
  $196 = Math_fround($19 * $193);
  $197 = Math_fround($194 + $186);
  $198 = Math_fround($195 + $187);
  $199 = Math_fround($188 + $196);
  $200 = Math_fround($197 * Math_fround(2.0));
  $201 = Math_fround($198 * Math_fround(2.0));
  $202 = Math_fround($199 * Math_fround(2.0));
  $203 = Math_fround($23 + $200);
  $204 = Math_fround($25 + $201);
  $205 = Math_fround($27 + $202);
  $206 = Math_fround(HEAPF32[$normal>>2]);
  $207 = (($normal) + 4|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = (($normal) + 8|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $211 = Math_fround($41 * $206);
  $212 = Math_fround($41 * $208);
  $213 = Math_fround($41 * $210);
  $214 = Math_fround($17 * $210);
  $215 = Math_fround($19 * $208);
  $216 = Math_fround($214 - $215);
  $217 = Math_fround($19 * $206);
  $218 = Math_fround($15 * $210);
  $219 = Math_fround($217 - $218);
  $220 = Math_fround($15 * $208);
  $221 = Math_fround($17 * $206);
  $222 = Math_fround($220 - $221);
  $223 = Math_fround($21 * $216);
  $224 = Math_fround($21 * $219);
  $225 = Math_fround($21 * $222);
  $226 = Math_fround($211 + $223);
  $227 = Math_fround($212 + $224);
  $228 = Math_fround($213 + $225);
  $229 = Math_fround($15 * $206);
  $230 = Math_fround($17 * $208);
  $231 = Math_fround($229 + $230);
  $232 = Math_fround($19 * $210);
  $233 = Math_fround($231 + $232);
  $234 = Math_fround($15 * $233);
  $235 = Math_fround($17 * $233);
  $236 = Math_fround($19 * $233);
  $237 = Math_fround($234 + $226);
  $238 = Math_fround($235 + $227);
  $239 = Math_fround($228 + $236);
  $240 = Math_fround($237 * Math_fround(2.0));
  $241 = Math_fround($238 * Math_fround(2.0));
  $242 = Math_fround($239 * Math_fround(2.0));
  $243 = Math_fround(-$240);
  $244 = Math_fround(-$241);
  $245 = Math_fround(-$242);
  $246 = (($sweepHit) + 28|0);
  HEAPF32[$246>>2] = $243;
  $247 = (($sweepHit) + 32|0);
  HEAPF32[$247>>2] = $244;
  $248 = (($sweepHit) + 36|0);
  HEAPF32[$248>>2] = $245;
  $249 = (($sweepHit) + 16|0);
  HEAPF32[$249>>2] = $203;
  $250 = (($sweepHit) + 20|0);
  HEAPF32[$250>>2] = $204;
  $251 = (($sweepHit) + 24|0);
  HEAPF32[$251>>2] = $205;
  $252 = (($sweepHit) + 40|0);
  HEAPF32[$252>>2] = $164;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $253 = (($sweepHit) + 40|0);
  HEAPF32[$253>>2] = Math_fround(0.0);
  $254 = Math_fround(HEAPF32[$unitDir>>2]);
  $255 = Math_fround(-$254);
  $256 = Math_fround(HEAPF32[$9>>2]);
  $257 = Math_fround(-$256);
  $258 = Math_fround(HEAPF32[$11>>2]);
  $259 = Math_fround(-$258);
  $260 = (($sweepHit) + 28|0);
  HEAPF32[$260>>2] = $255;
  $261 = (($sweepHit) + 32|0);
  HEAPF32[$261>>2] = $257;
  $262 = (($sweepHit) + 36|0);
  HEAPF32[$262>>2] = $259;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z20sweepBox_CapsuleGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0;
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = Math_fround(0);
 var $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0;
 var $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0);
 var $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $boxV = 0, $capsuleRadius$sroa$1 = 0;
 var $capsuleV = 0, $closestA = 0, $dir = 0, $normal = 0, $toi = 0, $zero = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $0 = sp + 416|0;
 $1 = sp + 400|0;
 $capsuleRadius$sroa$1 = sp + 432|0;
 $zero = sp + 384|0;
 $zeroV = sp + 368|0;
 $boxV = sp + 208|0;
 $capsuleV = sp + 48|0;
 $dir = sp + 32|0;
 $toi = sp + 16|0;
 $closestA = sp;
 $normal = sp + 192|0;
 $2 = (($geom) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($geom) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$zero>>2] = Math_fround(0.0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $6 = (($box) + 48|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($box) + 52|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($box) + 56|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(HEAPF32[$unitDir>>2]);
 $13 = (($unitDir) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($unitDir) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$box);
 $17 = Math_fround(HEAPF32[$0>>2]);
 $18 = (($0) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($0) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($0) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($box) + 36|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($box) + 40|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($box) + 44|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround(HEAPF32[$pose>>2]);
 $31 = (($pose) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($pose) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($pose) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($pose) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($37) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($37) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround(-$17);
 $44 = Math_fround(-$19);
 $45 = Math_fround(-$21);
 $46 = Math_fround($38 - $25);
 $47 = Math_fround($40 - $27);
 $48 = Math_fround($42 - $29);
 $49 = Math_fround($23 * $23);
 $50 = Math_fround($49 + Math_fround(-0.5));
 $51 = Math_fround($50 * $46);
 $52 = Math_fround($50 * $47);
 $53 = Math_fround($50 * $48);
 $54 = Math_fround($48 * $44);
 $55 = Math_fround($47 * $45);
 $56 = Math_fround($54 - $55);
 $57 = Math_fround($46 * $45);
 $58 = Math_fround($48 * $43);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($47 * $43);
 $61 = Math_fround($46 * $44);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($23 * $56);
 $64 = Math_fround($23 * $59);
 $65 = Math_fround($23 * $62);
 $66 = Math_fround($51 + $63);
 $67 = Math_fround($52 + $64);
 $68 = Math_fround($53 + $65);
 $69 = Math_fround($46 * $43);
 $70 = Math_fround($47 * $44);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($48 * $45);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($73 * $43);
 $75 = Math_fround($73 * $44);
 $76 = Math_fround($73 * $45);
 $77 = Math_fround($74 + $66);
 $78 = Math_fround($75 + $67);
 $79 = Math_fround($68 + $76);
 $80 = Math_fround($77 * Math_fround(2.0));
 $81 = Math_fround($78 * Math_fround(2.0));
 $82 = Math_fround($79 * Math_fround(2.0));
 $83 = Math_fround($23 * $36);
 $84 = Math_fround($30 * $43);
 $85 = Math_fround($32 * $44);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($34 * $45);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($83 - $88);
 $90 = Math_fround($36 * $43);
 $91 = Math_fround($36 * $44);
 $92 = Math_fround($36 * $45);
 $93 = Math_fround($23 * $30);
 $94 = Math_fround($23 * $32);
 $95 = Math_fround($23 * $34);
 $96 = Math_fround($34 * $44);
 $97 = Math_fround($32 * $45);
 $98 = Math_fround($96 - $97);
 $99 = Math_fround($30 * $45);
 $100 = Math_fround($34 * $43);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($32 * $43);
 $103 = Math_fround($30 * $44);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($93 + $90);
 $106 = Math_fround($94 + $91);
 $107 = Math_fround($95 + $92);
 $108 = Math_fround($98 + $105);
 $109 = Math_fround($101 + $106);
 $110 = Math_fround($104 + $107);
 $111 = Math_fround($108 + $108);
 $112 = Math_fround($109 + $109);
 $113 = Math_fround($110 + $110);
 $114 = Math_fround($108 * $111);
 $115 = Math_fround($109 * $112);
 $116 = Math_fround($110 * $113);
 $117 = Math_fround($109 * $111);
 $118 = Math_fround($110 * $111);
 $119 = Math_fround($89 * $111);
 $120 = Math_fround($110 * $112);
 $121 = Math_fround($89 * $112);
 $122 = Math_fround($89 * $113);
 $123 = Math_fround(Math_fround(1.0) - $114);
 $124 = Math_fround(Math_fround(1.0) - $115);
 $125 = Math_fround($124 - $116);
 $126 = Math_fround($117 + $122);
 $127 = Math_fround($118 - $121);
 $128 = Math_fround($117 - $122);
 $129 = Math_fround($123 - $116);
 $130 = Math_fround($120 + $119);
 $131 = Math_fround($118 + $121);
 $132 = Math_fround($120 - $119);
 $133 = Math_fround($123 - $115);
 $134 = (($boxV) + 64|0);
 ;HEAP32[$boxV+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$boxV+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$boxV+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$boxV+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $135 = (($boxV) + 80|0);
 HEAP32[$135>>2] = 3;
 $136 = (($boxV) + 16|0);
 $137 = (($boxV) + 20|0);
 ;HEAP32[$137+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$137+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$137+8>>2]=HEAP32[$0+8>>2]|0;
 $138 = (($boxV) + 32|0);
 $139 = (($boxV) + 36|0);
 $140 = (($boxV) + 48|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $141 = (($boxV) + 52|0);
 ;HEAP32[$141+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$141+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$141+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 ;HEAP32[$134+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$134+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$134+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$134+12>>2]=HEAP32[$1+12>>2]|0;
 $142 = (($boxV) + 144|0);
 HEAPF32[$142>>2] = $7;
 $143 = (($boxV) + 148|0);
 HEAPF32[$143>>2] = $9;
 $144 = (($boxV) + 152|0);
 HEAPF32[$144>>2] = $11;
 $145 = (($boxV) + 156|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = !($7 <= $9);
 $$$i26$i$i$i = $146 ? $9 : $7;
 $147 = !($$$i26$i$i$i <= $11);
 $148 = $147 ? $11 : $$$i26$i$i$i;
 $149 = !($7 >= $9);
 $$$i23$i$i$i = $149 ? $9 : $7;
 $150 = !($$$i23$i$i$i >= $11);
 $151 = $150 ? $11 : $$$i23$i$i$i;
 $152 = Math_fround($148 * Math_fround(0.150000005960464477539));
 $153 = Math_fround($151 * Math_fround(0.0299999993294477462769));
 $154 = $152 > $153;
 $$$i12$i$i$i = $154 ? $152 : $153;
 $155 = $148 > $$$i12$i$i$i;
 $$$i$i$i$i = $155 ? $$$i12$i$i$i : $148;
 HEAPF32[$136>>2] = $$$i$i$i$i;
 ;HEAP32[$137+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$137+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$137+8>>2]=HEAP32[$0+8>>2]|0;
 $156 = Math_fround($148 * Math_fround(0.0500000007450580596924));
 HEAPF32[$138>>2] = $156;
 ;HEAP32[$139+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$139+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$139+8>>2]=HEAP32[$1+8>>2]|0;
 $157 = Math_fround($3 * Math_fround(0.0));
 $158 = Math_fround($3 * $125);
 $159 = Math_fround($157 * $128);
 $160 = Math_fround($159 + $158);
 $161 = Math_fround($157 * $131);
 $162 = Math_fround($161 + $160);
 $163 = Math_fround($3 * $126);
 $164 = Math_fround($157 * $129);
 $165 = Math_fround($163 + $164);
 $166 = Math_fround($157 * $132);
 $167 = Math_fround($166 + $165);
 $168 = Math_fround($3 * $127);
 $169 = Math_fround($157 * $130);
 $170 = Math_fround($168 + $169);
 $171 = Math_fround($157 * $133);
 $172 = Math_fround($170 + $171);
 $173 = (($capsuleV) + 64|0);
 HEAPF32[$capsuleV>>2] = $80;
 $174 = (($capsuleV) + 4|0);
 HEAPF32[$174>>2] = $81;
 $175 = (($capsuleV) + 8|0);
 HEAPF32[$175>>2] = $82;
 $176 = (($capsuleV) + 12|0);
 HEAPF32[$176>>2] = Math_fround(0.0);
 $177 = (($capsuleV) + 80|0);
 HEAP32[$177>>2] = 4;
 $178 = (($capsuleV) + 16|0);
 $179 = (($capsuleV) + 20|0);
 $180 = (($capsuleV) + 32|0);
 $181 = (($capsuleV) + 36|0);
 $182 = (($capsuleV) + 48|0);
 HEAPF32[$182>>2] = Math_fround(0.0);
 $183 = (($capsuleV) + 52|0);
 ;HEAP32[$183+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$183+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$183+8>>2]=HEAP32[$1+8>>2]|0;
 $184 = (($capsuleV) + 128|0);
 HEAPF32[$184>>2] = $5;
 $185 = (($capsuleV) + 132|0);
 ;HEAP32[$185+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$185+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$185+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 $186 = Math_fround($80 + $162);
 $187 = Math_fround($81 + $167);
 $188 = Math_fround($82 + $172);
 $189 = (($capsuleV) + 96|0);
 HEAPF32[$189>>2] = $186;
 $190 = (($capsuleV) + 100|0);
 HEAPF32[$190>>2] = $187;
 $191 = (($capsuleV) + 104|0);
 HEAPF32[$191>>2] = $188;
 $192 = (($capsuleV) + 108|0);
 HEAPF32[$192>>2] = Math_fround(0.0);
 $193 = Math_fround($80 - $162);
 $194 = Math_fround($81 - $167);
 $195 = Math_fround($82 - $172);
 $196 = (($capsuleV) + 112|0);
 HEAPF32[$196>>2] = $193;
 $197 = (($capsuleV) + 116|0);
 HEAPF32[$197>>2] = $194;
 $198 = (($capsuleV) + 120|0);
 HEAPF32[$198>>2] = $195;
 $199 = (($capsuleV) + 124|0);
 HEAPF32[$199>>2] = Math_fround(0.0);
 HEAPF32[$178>>2] = $5;
 ;HEAP32[$179+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$179+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$179+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 HEAPF32[$180>>2] = $5;
 ;HEAP32[$181+0>>2]=HEAP32[$capsuleRadius$sroa$1+0>>2]|0;HEAP32[$181+4>>2]=HEAP32[$capsuleRadius$sroa$1+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$capsuleRadius$sroa$1+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$173+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$173+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$173+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$173+12>>2]=HEAP32[$0+12>>2]|0;
 $200 = Math_fround($12 * $distance);
 $201 = Math_fround($14 * $distance);
 $202 = Math_fround($16 * $distance);
 $203 = Math_fround($200 * $50);
 $204 = Math_fround($201 * $50);
 $205 = Math_fround($202 * $50);
 $206 = Math_fround($202 * $19);
 $207 = Math_fround($201 * $21);
 $208 = Math_fround($206 - $207);
 $209 = Math_fround($200 * $21);
 $210 = Math_fround($202 * $17);
 $211 = Math_fround($209 - $210);
 $212 = Math_fround($201 * $17);
 $213 = Math_fround($200 * $19);
 $214 = Math_fround($212 - $213);
 $215 = Math_fround($23 * $208);
 $216 = Math_fround($23 * $211);
 $217 = Math_fround($23 * $214);
 $218 = Math_fround($203 - $215);
 $219 = Math_fround($204 - $216);
 $220 = Math_fround($205 - $217);
 $221 = Math_fround($200 * $17);
 $222 = Math_fround($201 * $19);
 $223 = Math_fround($221 + $222);
 $224 = Math_fround($202 * $21);
 $225 = Math_fround($223 + $224);
 $226 = Math_fround($17 * $225);
 $227 = Math_fround($19 * $225);
 $228 = Math_fround($21 * $225);
 $229 = Math_fround($226 + $218);
 $230 = Math_fround($227 + $219);
 $231 = Math_fround($228 + $220);
 $232 = Math_fround($229 * Math_fround(2.0));
 $233 = Math_fround($230 * Math_fround(2.0));
 $234 = Math_fround($231 * Math_fround(2.0));
 HEAPF32[$dir>>2] = $232;
 $235 = (($dir) + 4|0);
 HEAPF32[$235>>2] = $233;
 $236 = (($dir) + 8|0);
 HEAPF32[$236>>2] = $234;
 $237 = (($dir) + 12|0);
 HEAPF32[$237>>2] = Math_fround(0.0);
 $238 = HEAP16[$hintFlags>>1]|0;
 $239 = $238 & 512;
 $240 = ($239<<16>>16)!=(0);
 $241 = Math_fround(HEAPF32[$4>>2]);
 $242 = Math_fround($241 + $inflation);
 $243 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_8CapsuleVERNS0_4BoxVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($capsuleV,$boxV,$zero,$zeroV,$dir,$toi,$normal,$closestA,$242,$240)|0);
 if (!($243)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $244 = (($sweepHit) + 12|0);
 HEAP16[$244>>1] = 6;
 $245 = Math_fround(HEAPF32[$zero>>2]);
 $246 = Math_fround(HEAPF32[$toi>>2]);
 $247 = !($245 >= $246);
 if ($247) {
  HEAP16[$244>>1] = 7;
  $345 = Math_fround(HEAPF32[$closestA>>2]);
  $346 = (($closestA) + 4|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  $348 = (($closestA) + 8|0);
  $349 = Math_fround(HEAPF32[$348>>2]);
  $350 = Math_fround($50 * $345);
  $351 = Math_fround($50 * $347);
  $352 = Math_fround($50 * $349);
  $353 = Math_fround($19 * $349);
  $354 = Math_fround($21 * $347);
  $355 = Math_fround($353 - $354);
  $356 = Math_fround($21 * $345);
  $357 = Math_fround($17 * $349);
  $358 = Math_fround($356 - $357);
  $359 = Math_fround($17 * $347);
  $360 = Math_fround($19 * $345);
  $361 = Math_fround($359 - $360);
  $362 = Math_fround($23 * $355);
  $363 = Math_fround($23 * $358);
  $364 = Math_fround($23 * $361);
  $365 = Math_fround($350 + $362);
  $366 = Math_fround($351 + $363);
  $367 = Math_fround($352 + $364);
  $368 = Math_fround($17 * $345);
  $369 = Math_fround($19 * $347);
  $370 = Math_fround($368 + $369);
  $371 = Math_fround($21 * $349);
  $372 = Math_fround($370 + $371);
  $373 = Math_fround($17 * $372);
  $374 = Math_fround($19 * $372);
  $375 = Math_fround($21 * $372);
  $376 = Math_fround($373 + $365);
  $377 = Math_fround($374 + $366);
  $378 = Math_fround($367 + $375);
  $379 = Math_fround($376 * Math_fround(2.0));
  $380 = Math_fround($377 * Math_fround(2.0));
  $381 = Math_fround($378 * Math_fround(2.0));
  $382 = Math_fround($25 + $379);
  $383 = Math_fround($27 + $380);
  $384 = Math_fround($29 + $381);
  $385 = Math_fround(HEAPF32[$normal>>2]);
  $386 = (($normal) + 4|0);
  $387 = Math_fround(HEAPF32[$386>>2]);
  $388 = (($normal) + 8|0);
  $389 = Math_fround(HEAPF32[$388>>2]);
  $390 = Math_fround($50 * $385);
  $391 = Math_fround($50 * $387);
  $392 = Math_fround($50 * $389);
  $393 = Math_fround($19 * $389);
  $394 = Math_fround($21 * $387);
  $395 = Math_fround($393 - $394);
  $396 = Math_fround($21 * $385);
  $397 = Math_fround($17 * $389);
  $398 = Math_fround($396 - $397);
  $399 = Math_fround($17 * $387);
  $400 = Math_fround($19 * $385);
  $401 = Math_fround($399 - $400);
  $402 = Math_fround($23 * $395);
  $403 = Math_fround($23 * $398);
  $404 = Math_fround($23 * $401);
  $405 = Math_fround($390 + $402);
  $406 = Math_fround($391 + $403);
  $407 = Math_fround($392 + $404);
  $408 = Math_fround($17 * $385);
  $409 = Math_fround($19 * $387);
  $410 = Math_fround($408 + $409);
  $411 = Math_fround($21 * $389);
  $412 = Math_fround($410 + $411);
  $413 = Math_fround($17 * $412);
  $414 = Math_fround($19 * $412);
  $415 = Math_fround($21 * $412);
  $416 = Math_fround($413 + $405);
  $417 = Math_fround($414 + $406);
  $418 = Math_fround($407 + $415);
  $419 = Math_fround($416 * Math_fround(2.0));
  $420 = Math_fround($417 * Math_fround(2.0));
  $421 = Math_fround($418 * Math_fround(2.0));
  $422 = Math_fround($246 * $distance);
  $423 = Math_fround(-$419);
  $424 = Math_fround(-$420);
  $425 = Math_fround(-$421);
  $426 = (($sweepHit) + 28|0);
  HEAPF32[$426>>2] = $423;
  $427 = (($sweepHit) + 32|0);
  HEAPF32[$427>>2] = $424;
  $428 = (($sweepHit) + 36|0);
  HEAPF32[$428>>2] = $425;
  $429 = (($sweepHit) + 16|0);
  HEAPF32[$429>>2] = $382;
  $430 = (($sweepHit) + 20|0);
  HEAPF32[$430>>2] = $383;
  $431 = (($sweepHit) + 24|0);
  HEAPF32[$431>>2] = $384;
  $432 = (($sweepHit) + 40|0);
  HEAPF32[$432>>2] = $422;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($240) {
  HEAP16[$244>>1] = 7;
  $248 = Math_fround(HEAPF32[$closestA>>2]);
  $249 = (($closestA) + 4|0);
  $250 = Math_fround(HEAPF32[$249>>2]);
  $251 = (($closestA) + 8|0);
  $252 = Math_fround(HEAPF32[$251>>2]);
  $253 = Math_fround($50 * $248);
  $254 = Math_fround($50 * $250);
  $255 = Math_fround($50 * $252);
  $256 = Math_fround($19 * $252);
  $257 = Math_fround($21 * $250);
  $258 = Math_fround($256 - $257);
  $259 = Math_fround($21 * $248);
  $260 = Math_fround($17 * $252);
  $261 = Math_fround($259 - $260);
  $262 = Math_fround($17 * $250);
  $263 = Math_fround($19 * $248);
  $264 = Math_fround($262 - $263);
  $265 = Math_fround($23 * $258);
  $266 = Math_fround($23 * $261);
  $267 = Math_fround($23 * $264);
  $268 = Math_fround($253 + $265);
  $269 = Math_fround($254 + $266);
  $270 = Math_fround($255 + $267);
  $271 = Math_fround($17 * $248);
  $272 = Math_fround($19 * $250);
  $273 = Math_fround($271 + $272);
  $274 = Math_fround($21 * $252);
  $275 = Math_fround($273 + $274);
  $276 = Math_fround($17 * $275);
  $277 = Math_fround($19 * $275);
  $278 = Math_fround($21 * $275);
  $279 = Math_fround($276 + $268);
  $280 = Math_fround($277 + $269);
  $281 = Math_fround($270 + $278);
  $282 = Math_fround($279 * Math_fround(2.0));
  $283 = Math_fround($280 * Math_fround(2.0));
  $284 = Math_fround($281 * Math_fround(2.0));
  $285 = Math_fround($25 + $282);
  $286 = Math_fround($27 + $283);
  $287 = Math_fround($29 + $284);
  $288 = Math_fround(HEAPF32[$normal>>2]);
  $289 = (($normal) + 4|0);
  $290 = Math_fround(HEAPF32[$289>>2]);
  $291 = (($normal) + 8|0);
  $292 = Math_fround(HEAPF32[$291>>2]);
  $293 = Math_fround($50 * $288);
  $294 = Math_fround($50 * $290);
  $295 = Math_fround($50 * $292);
  $296 = Math_fround($19 * $292);
  $297 = Math_fround($21 * $290);
  $298 = Math_fround($296 - $297);
  $299 = Math_fround($21 * $288);
  $300 = Math_fround($17 * $292);
  $301 = Math_fround($299 - $300);
  $302 = Math_fround($17 * $290);
  $303 = Math_fround($19 * $288);
  $304 = Math_fround($302 - $303);
  $305 = Math_fround($23 * $298);
  $306 = Math_fround($23 * $301);
  $307 = Math_fround($23 * $304);
  $308 = Math_fround($293 + $305);
  $309 = Math_fround($294 + $306);
  $310 = Math_fround($295 + $307);
  $311 = Math_fround($17 * $288);
  $312 = Math_fround($19 * $290);
  $313 = Math_fround($311 + $312);
  $314 = Math_fround($21 * $292);
  $315 = Math_fround($313 + $314);
  $316 = Math_fround($17 * $315);
  $317 = Math_fround($19 * $315);
  $318 = Math_fround($21 * $315);
  $319 = Math_fround($316 + $308);
  $320 = Math_fround($317 + $309);
  $321 = Math_fround($310 + $318);
  $322 = Math_fround($319 * Math_fround(2.0));
  $323 = Math_fround($320 * Math_fround(2.0));
  $324 = Math_fround($321 * Math_fround(2.0));
  $325 = Math_fround(-$322);
  $326 = Math_fround(-$323);
  $327 = Math_fround(-$324);
  $328 = (($sweepHit) + 28|0);
  HEAPF32[$328>>2] = $325;
  $329 = (($sweepHit) + 32|0);
  HEAPF32[$329>>2] = $326;
  $330 = (($sweepHit) + 36|0);
  HEAPF32[$330>>2] = $327;
  $331 = (($sweepHit) + 16|0);
  HEAPF32[$331>>2] = $285;
  $332 = (($sweepHit) + 20|0);
  HEAPF32[$332>>2] = $286;
  $333 = (($sweepHit) + 24|0);
  HEAPF32[$333>>2] = $287;
  $334 = (($sweepHit) + 40|0);
  HEAPF32[$334>>2] = $246;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $335 = (($sweepHit) + 40|0);
  HEAPF32[$335>>2] = Math_fround(0.0);
  $336 = Math_fround(HEAPF32[$unitDir>>2]);
  $337 = Math_fround(-$336);
  $338 = Math_fround(HEAPF32[$13>>2]);
  $339 = Math_fround(-$338);
  $340 = Math_fround(HEAPF32[$15>>2]);
  $341 = Math_fround(-$340);
  $342 = (($sweepHit) + 28|0);
  HEAPF32[$342>>2] = $337;
  $343 = (($sweepHit) + 32|0);
  HEAPF32[$343>>2] = $339;
  $344 = (($sweepHit) + 36|0);
  HEAPF32[$344>>2] = $341;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z16sweepBox_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$$i$i$i$i = Math_fround(0), $$$i$i$i$i33 = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i12$i$i$i32 = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i23$i$i$i31 = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$$i26$i$i$i30 = Math_fround(0), $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0);
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0);
 var $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0);
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0;
 var $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0);
 var $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0);
 var $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0);
 var $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0;
 var $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0);
 var $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0);
 var $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0);
 var $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0);
 var $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $box0 = 0, $box1 = 0, $closestA = 0;
 var $dir = 0, $normal = 0, $toi = 0, $zero = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 480|0;
 $zero$sroa$1$i$i$i = sp + 496|0;
 $zero = sp + 464|0;
 $zeroV = sp + 448|0;
 $aToB = sp + 384|0;
 $box0 = sp + 224|0;
 $box1 = sp + 48|0;
 $dir = sp + 32|0;
 $toi = sp + 16|0;
 $closestA = sp;
 $normal = sp + 208|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $1 = (($geom) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($geom) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($geom) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($box) + 48|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($box) + 52|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($box) + 56|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(HEAPF32[$unitDir>>2]);
 $14 = (($unitDir) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($unitDir) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$box);
 $18 = Math_fround(HEAPF32[$0>>2]);
 $19 = (($0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($box) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($box) + 40|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($box) + 44|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround(HEAPF32[$pose>>2]);
 $32 = (($pose) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($pose) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($pose) + 12|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($pose) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($38) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($38) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(-$18);
 $45 = Math_fround(-$20);
 $46 = Math_fround(-$22);
 $47 = Math_fround($39 - $26);
 $48 = Math_fround($41 - $28);
 $49 = Math_fround($43 - $30);
 $50 = Math_fround($24 * $24);
 $51 = Math_fround($50 + Math_fround(-0.5));
 $52 = Math_fround($51 * $47);
 $53 = Math_fround($51 * $48);
 $54 = Math_fround($51 * $49);
 $55 = Math_fround($49 * $45);
 $56 = Math_fround($48 * $46);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($47 * $46);
 $59 = Math_fround($49 * $44);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($48 * $44);
 $62 = Math_fround($47 * $45);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($24 * $57);
 $65 = Math_fround($24 * $60);
 $66 = Math_fround($24 * $63);
 $67 = Math_fround($52 + $64);
 $68 = Math_fround($53 + $65);
 $69 = Math_fround($54 + $66);
 $70 = Math_fround($47 * $44);
 $71 = Math_fround($48 * $45);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($49 * $46);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($74 * $44);
 $76 = Math_fround($74 * $45);
 $77 = Math_fround($74 * $46);
 $78 = Math_fround($75 + $67);
 $79 = Math_fround($76 + $68);
 $80 = Math_fround($69 + $77);
 $81 = Math_fround($78 * Math_fround(2.0));
 $82 = Math_fround($79 * Math_fround(2.0));
 $83 = Math_fround($80 * Math_fround(2.0));
 $84 = Math_fround($24 * $37);
 $85 = Math_fround($31 * $44);
 $86 = Math_fround($33 * $45);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($35 * $46);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($84 - $89);
 $91 = Math_fround($37 * $44);
 $92 = Math_fround($37 * $45);
 $93 = Math_fround($37 * $46);
 $94 = Math_fround($24 * $31);
 $95 = Math_fround($24 * $33);
 $96 = Math_fround($24 * $35);
 $97 = Math_fround($35 * $45);
 $98 = Math_fround($33 * $46);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($31 * $46);
 $101 = Math_fround($35 * $44);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($33 * $44);
 $104 = Math_fround($31 * $45);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($94 + $91);
 $107 = Math_fround($95 + $92);
 $108 = Math_fround($96 + $93);
 $109 = Math_fround($99 + $106);
 $110 = Math_fround($102 + $107);
 $111 = Math_fround($105 + $108);
 $112 = (($aToB) + 48|0);
 HEAPF32[$112>>2] = $81;
 $113 = (($aToB) + 52|0);
 HEAPF32[$113>>2] = $82;
 $114 = (($aToB) + 56|0);
 HEAPF32[$114>>2] = $83;
 $115 = (($aToB) + 60|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = Math_fround($109 + $109);
 $117 = Math_fround($110 + $110);
 $118 = Math_fround($111 + $111);
 $119 = Math_fround($109 * $116);
 $120 = Math_fround($110 * $117);
 $121 = Math_fround($111 * $118);
 $122 = Math_fround($110 * $116);
 $123 = Math_fround($111 * $116);
 $124 = Math_fround($90 * $116);
 $125 = Math_fround($111 * $117);
 $126 = Math_fround($90 * $117);
 $127 = Math_fround($90 * $118);
 $128 = Math_fround(Math_fround(1.0) - $119);
 $129 = Math_fround(Math_fround(1.0) - $120);
 $130 = Math_fround($129 - $121);
 $131 = Math_fround($122 + $127);
 $132 = Math_fround($123 - $126);
 $133 = Math_fround($122 - $127);
 $134 = Math_fround($128 - $121);
 $135 = Math_fround($125 + $124);
 $136 = Math_fround($123 + $126);
 $137 = Math_fround($125 - $124);
 $138 = Math_fround($128 - $120);
 HEAPF32[$aToB>>2] = $130;
 $139 = (($aToB) + 4|0);
 HEAPF32[$139>>2] = $131;
 $140 = (($aToB) + 8|0);
 HEAPF32[$140>>2] = $132;
 $141 = (($aToB) + 12|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 $142 = (($aToB) + 16|0);
 HEAPF32[$142>>2] = $133;
 $143 = (($aToB) + 20|0);
 HEAPF32[$143>>2] = $134;
 $144 = (($aToB) + 24|0);
 HEAPF32[$144>>2] = $135;
 $145 = (($aToB) + 28|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = (($aToB) + 32|0);
 HEAPF32[$146>>2] = $136;
 $147 = (($aToB) + 36|0);
 HEAPF32[$147>>2] = $137;
 $148 = (($aToB) + 40|0);
 HEAPF32[$148>>2] = $138;
 $149 = (($aToB) + 44|0);
 HEAPF32[$149>>2] = Math_fround(0.0);
 $150 = (($box0) + 64|0);
 ;HEAP32[$box0+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box0+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box0+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box0+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $151 = (($box0) + 80|0);
 HEAP32[$151>>2] = 3;
 $152 = (($box0) + 16|0);
 $153 = (($box0) + 20|0);
 ;HEAP32[$153+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$153+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$153+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $154 = (($box0) + 32|0);
 $155 = (($box0) + 36|0);
 $156 = (($box0) + 48|0);
 HEAPF32[$156>>2] = Math_fround(0.0);
 $157 = (($box0) + 52|0);
 ;HEAP32[$157+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$150+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$150+12>>2]=HEAP32[$0+12>>2]|0;
 $158 = (($box0) + 144|0);
 HEAPF32[$158>>2] = $2;
 $159 = (($box0) + 148|0);
 HEAPF32[$159>>2] = $4;
 $160 = (($box0) + 152|0);
 HEAPF32[$160>>2] = $6;
 $161 = (($box0) + 156|0);
 HEAPF32[$161>>2] = Math_fround(0.0);
 $162 = !($2 <= $4);
 $$$i26$i$i$i30 = $162 ? $4 : $2;
 $163 = !($$$i26$i$i$i30 <= $6);
 $164 = $163 ? $6 : $$$i26$i$i$i30;
 $165 = !($2 >= $4);
 $$$i23$i$i$i31 = $165 ? $4 : $2;
 $166 = !($$$i23$i$i$i31 >= $6);
 $167 = $166 ? $6 : $$$i23$i$i$i31;
 $168 = Math_fround($164 * Math_fround(0.150000005960464477539));
 $169 = Math_fround($167 * Math_fround(0.0299999993294477462769));
 $170 = $168 > $169;
 $$$i12$i$i$i32 = $170 ? $168 : $169;
 $171 = $164 > $$$i12$i$i$i32;
 $$$i$i$i$i33 = $171 ? $$$i12$i$i$i32 : $164;
 HEAPF32[$152>>2] = $$$i$i$i$i33;
 ;HEAP32[$153+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$153+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$153+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $172 = Math_fround($164 * Math_fround(0.0500000007450580596924));
 HEAPF32[$154>>2] = $172;
 ;HEAP32[$155+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$0+8>>2]|0;
 $173 = (($box1) + 64|0);
 ;HEAP32[$box1+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box1+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box1+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box1+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $174 = (($box1) + 80|0);
 HEAP32[$174>>2] = 3;
 $175 = (($box1) + 16|0);
 $176 = (($box1) + 20|0);
 ;HEAP32[$176+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$176+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$176+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $177 = (($box1) + 32|0);
 $178 = (($box1) + 36|0);
 $179 = (($box1) + 48|0);
 HEAPF32[$179>>2] = Math_fround(0.0);
 $180 = (($box1) + 52|0);
 ;HEAP32[$180+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$180+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$180+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$173+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$173+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$173+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$173+12>>2]=HEAP32[$0+12>>2]|0;
 $181 = (($box1) + 144|0);
 HEAPF32[$181>>2] = $8;
 $182 = (($box1) + 148|0);
 HEAPF32[$182>>2] = $10;
 $183 = (($box1) + 152|0);
 HEAPF32[$183>>2] = $12;
 $184 = (($box1) + 156|0);
 HEAPF32[$184>>2] = Math_fround(0.0);
 $185 = !($8 <= $10);
 $$$i26$i$i$i = $185 ? $10 : $8;
 $186 = !($$$i26$i$i$i <= $12);
 $187 = $186 ? $12 : $$$i26$i$i$i;
 $188 = !($8 >= $10);
 $$$i23$i$i$i = $188 ? $10 : $8;
 $189 = !($$$i23$i$i$i >= $12);
 $190 = $189 ? $12 : $$$i23$i$i$i;
 $191 = Math_fround($187 * Math_fround(0.150000005960464477539));
 $192 = Math_fround($190 * Math_fround(0.0299999993294477462769));
 $193 = $191 > $192;
 $$$i12$i$i$i = $193 ? $191 : $192;
 $194 = $187 > $$$i12$i$i$i;
 $$$i$i$i$i = $194 ? $$$i12$i$i$i : $187;
 HEAPF32[$175>>2] = $$$i$i$i$i;
 ;HEAP32[$176+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$176+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$176+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $195 = Math_fround($187 * Math_fround(0.0500000007450580596924));
 HEAPF32[$177>>2] = $195;
 ;HEAP32[$178+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$178+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$178+8>>2]=HEAP32[$0+8>>2]|0;
 $196 = Math_fround($13 * $distance);
 $197 = Math_fround($15 * $distance);
 $198 = Math_fround($17 * $distance);
 $199 = Math_fround($196 * $51);
 $200 = Math_fround($197 * $51);
 $201 = Math_fround($198 * $51);
 $202 = Math_fround($198 * $20);
 $203 = Math_fround($197 * $22);
 $204 = Math_fround($202 - $203);
 $205 = Math_fround($196 * $22);
 $206 = Math_fround($198 * $18);
 $207 = Math_fround($205 - $206);
 $208 = Math_fround($197 * $18);
 $209 = Math_fround($196 * $20);
 $210 = Math_fround($208 - $209);
 $211 = Math_fround($24 * $204);
 $212 = Math_fround($24 * $207);
 $213 = Math_fround($24 * $210);
 $214 = Math_fround($199 - $211);
 $215 = Math_fround($200 - $212);
 $216 = Math_fround($201 - $213);
 $217 = Math_fround($196 * $18);
 $218 = Math_fround($197 * $20);
 $219 = Math_fround($217 + $218);
 $220 = Math_fround($198 * $22);
 $221 = Math_fround($219 + $220);
 $222 = Math_fround($18 * $221);
 $223 = Math_fround($20 * $221);
 $224 = Math_fround($22 * $221);
 $225 = Math_fround($222 + $214);
 $226 = Math_fround($223 + $215);
 $227 = Math_fround($224 + $216);
 $228 = Math_fround($225 * Math_fround(2.0));
 $229 = Math_fround($226 * Math_fround(2.0));
 $230 = Math_fround($227 * Math_fround(2.0));
 HEAPF32[$dir>>2] = $228;
 $231 = (($dir) + 4|0);
 HEAPF32[$231>>2] = $229;
 $232 = (($dir) + 8|0);
 HEAPF32[$232>>2] = $230;
 $233 = (($dir) + 12|0);
 HEAPF32[$233>>2] = Math_fround(0.0);
 $234 = HEAP16[$hintFlags>>1]|0;
 $235 = $234 & 512;
 $236 = ($235<<16>>16)!=(0);
 $237 = (__ZN5physx2Gu18GJKRelativeRayCastERNS0_4BoxVES2_RKNS_6shdfnd3aos15PsMatTransformVERKNS4_6FloatVERKNS4_5Vec3VESD_RS8_RSB_SF_fb($box0,$box1,$aToB,$zero,$zeroV,$dir,$toi,$normal,$closestA,$inflation,$236)|0);
 if (!($237)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $238 = (($sweepHit) + 12|0);
 HEAP16[$238>>1] = 6;
 $239 = Math_fround(HEAPF32[$zero>>2]);
 $240 = Math_fround(HEAPF32[$toi>>2]);
 $241 = !($239 >= $240);
 if ($241) {
  HEAP16[$238>>1] = 7;
  $349 = Math_fround(HEAPF32[$closestA>>2]);
  $350 = (($closestA) + 4|0);
  $351 = Math_fround(HEAPF32[$350>>2]);
  $352 = (($closestA) + 8|0);
  $353 = Math_fround(HEAPF32[$352>>2]);
  $354 = Math_fround($51 * $349);
  $355 = Math_fround($51 * $351);
  $356 = Math_fround($51 * $353);
  $357 = Math_fround($20 * $353);
  $358 = Math_fround($22 * $351);
  $359 = Math_fround($357 - $358);
  $360 = Math_fround($22 * $349);
  $361 = Math_fround($18 * $353);
  $362 = Math_fround($360 - $361);
  $363 = Math_fround($18 * $351);
  $364 = Math_fround($20 * $349);
  $365 = Math_fround($363 - $364);
  $366 = Math_fround($24 * $359);
  $367 = Math_fround($24 * $362);
  $368 = Math_fround($24 * $365);
  $369 = Math_fround($354 + $366);
  $370 = Math_fround($355 + $367);
  $371 = Math_fround($356 + $368);
  $372 = Math_fround($18 * $349);
  $373 = Math_fround($20 * $351);
  $374 = Math_fround($372 + $373);
  $375 = Math_fround($22 * $353);
  $376 = Math_fround($374 + $375);
  $377 = Math_fround($18 * $376);
  $378 = Math_fround($20 * $376);
  $379 = Math_fround($22 * $376);
  $380 = Math_fround($377 + $369);
  $381 = Math_fround($378 + $370);
  $382 = Math_fround($371 + $379);
  $383 = Math_fround($380 * Math_fround(2.0));
  $384 = Math_fround($381 * Math_fround(2.0));
  $385 = Math_fround($382 * Math_fround(2.0));
  $386 = Math_fround($26 + $383);
  $387 = Math_fround($28 + $384);
  $388 = Math_fround($30 + $385);
  $389 = Math_fround(HEAPF32[$normal>>2]);
  $390 = (($normal) + 4|0);
  $391 = Math_fround(HEAPF32[$390>>2]);
  $392 = (($normal) + 8|0);
  $393 = Math_fround(HEAPF32[$392>>2]);
  $394 = Math_fround($51 * $389);
  $395 = Math_fround($51 * $391);
  $396 = Math_fround($51 * $393);
  $397 = Math_fround($20 * $393);
  $398 = Math_fround($22 * $391);
  $399 = Math_fround($397 - $398);
  $400 = Math_fround($22 * $389);
  $401 = Math_fround($18 * $393);
  $402 = Math_fround($400 - $401);
  $403 = Math_fround($18 * $391);
  $404 = Math_fround($20 * $389);
  $405 = Math_fround($403 - $404);
  $406 = Math_fround($24 * $399);
  $407 = Math_fround($24 * $402);
  $408 = Math_fround($24 * $405);
  $409 = Math_fround($394 + $406);
  $410 = Math_fround($395 + $407);
  $411 = Math_fround($396 + $408);
  $412 = Math_fround($18 * $389);
  $413 = Math_fround($20 * $391);
  $414 = Math_fround($412 + $413);
  $415 = Math_fround($22 * $393);
  $416 = Math_fround($414 + $415);
  $417 = Math_fround($18 * $416);
  $418 = Math_fround($20 * $416);
  $419 = Math_fround($22 * $416);
  $420 = Math_fround($417 + $409);
  $421 = Math_fround($418 + $410);
  $422 = Math_fround($411 + $419);
  $423 = Math_fround($420 * Math_fround(2.0));
  $424 = Math_fround($421 * Math_fround(2.0));
  $425 = Math_fround($422 * Math_fround(2.0));
  $426 = Math_fround($423 * $423);
  $427 = Math_fround($424 * $424);
  $428 = Math_fround($426 + $427);
  $429 = Math_fround($425 * $425);
  $430 = Math_fround($429 + $428);
  $431 = (Math_fround(Math_sqrt((Math_fround($430)))));
  $432 = Math_fround(Math_fround(1.0) / $431);
  $433 = Math_fround($432 * $423);
  $434 = Math_fround($432 * $424);
  $435 = Math_fround($432 * $425);
  $436 = Math_fround($240 * $distance);
  $437 = Math_fround(-$433);
  $438 = Math_fround(-$434);
  $439 = Math_fround(-$435);
  $440 = (($sweepHit) + 28|0);
  HEAPF32[$440>>2] = $437;
  $441 = (($sweepHit) + 32|0);
  HEAPF32[$441>>2] = $438;
  $442 = (($sweepHit) + 36|0);
  HEAPF32[$442>>2] = $439;
  $443 = (($sweepHit) + 16|0);
  HEAPF32[$443>>2] = $386;
  $444 = (($sweepHit) + 20|0);
  HEAPF32[$444>>2] = $387;
  $445 = (($sweepHit) + 24|0);
  HEAPF32[$445>>2] = $388;
  $446 = (($sweepHit) + 40|0);
  HEAPF32[$446>>2] = $436;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($236) {
  HEAP16[$238>>1] = 7;
  $242 = Math_fround(HEAPF32[$closestA>>2]);
  $243 = (($closestA) + 4|0);
  $244 = Math_fround(HEAPF32[$243>>2]);
  $245 = (($closestA) + 8|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround($51 * $242);
  $248 = Math_fround($51 * $244);
  $249 = Math_fround($51 * $246);
  $250 = Math_fround($20 * $246);
  $251 = Math_fround($22 * $244);
  $252 = Math_fround($250 - $251);
  $253 = Math_fround($22 * $242);
  $254 = Math_fround($18 * $246);
  $255 = Math_fround($253 - $254);
  $256 = Math_fround($18 * $244);
  $257 = Math_fround($20 * $242);
  $258 = Math_fround($256 - $257);
  $259 = Math_fround($24 * $252);
  $260 = Math_fround($24 * $255);
  $261 = Math_fround($24 * $258);
  $262 = Math_fround($247 + $259);
  $263 = Math_fround($248 + $260);
  $264 = Math_fround($249 + $261);
  $265 = Math_fround($18 * $242);
  $266 = Math_fround($20 * $244);
  $267 = Math_fround($265 + $266);
  $268 = Math_fround($22 * $246);
  $269 = Math_fround($267 + $268);
  $270 = Math_fround($18 * $269);
  $271 = Math_fround($20 * $269);
  $272 = Math_fround($22 * $269);
  $273 = Math_fround($270 + $262);
  $274 = Math_fround($271 + $263);
  $275 = Math_fround($264 + $272);
  $276 = Math_fround($273 * Math_fround(2.0));
  $277 = Math_fround($274 * Math_fround(2.0));
  $278 = Math_fround($275 * Math_fround(2.0));
  $279 = Math_fround($26 + $276);
  $280 = Math_fround($28 + $277);
  $281 = Math_fround($30 + $278);
  $282 = Math_fround(HEAPF32[$normal>>2]);
  $283 = (($normal) + 4|0);
  $284 = Math_fround(HEAPF32[$283>>2]);
  $285 = (($normal) + 8|0);
  $286 = Math_fround(HEAPF32[$285>>2]);
  $287 = Math_fround($51 * $282);
  $288 = Math_fround($51 * $284);
  $289 = Math_fround($51 * $286);
  $290 = Math_fround($20 * $286);
  $291 = Math_fround($22 * $284);
  $292 = Math_fround($290 - $291);
  $293 = Math_fround($22 * $282);
  $294 = Math_fround($18 * $286);
  $295 = Math_fround($293 - $294);
  $296 = Math_fround($18 * $284);
  $297 = Math_fround($20 * $282);
  $298 = Math_fround($296 - $297);
  $299 = Math_fround($24 * $292);
  $300 = Math_fround($24 * $295);
  $301 = Math_fround($24 * $298);
  $302 = Math_fround($287 + $299);
  $303 = Math_fround($288 + $300);
  $304 = Math_fround($289 + $301);
  $305 = Math_fround($18 * $282);
  $306 = Math_fround($20 * $284);
  $307 = Math_fround($305 + $306);
  $308 = Math_fround($22 * $286);
  $309 = Math_fround($307 + $308);
  $310 = Math_fround($18 * $309);
  $311 = Math_fround($20 * $309);
  $312 = Math_fround($22 * $309);
  $313 = Math_fround($310 + $302);
  $314 = Math_fround($311 + $303);
  $315 = Math_fround($304 + $312);
  $316 = Math_fround($313 * Math_fround(2.0));
  $317 = Math_fround($314 * Math_fround(2.0));
  $318 = Math_fround($315 * Math_fround(2.0));
  $319 = Math_fround($316 * $316);
  $320 = Math_fround($317 * $317);
  $321 = Math_fround($319 + $320);
  $322 = Math_fround($318 * $318);
  $323 = Math_fround($322 + $321);
  $324 = (Math_fround(Math_sqrt((Math_fround($323)))));
  $325 = Math_fround(Math_fround(1.0) / $324);
  $326 = Math_fround($325 * $316);
  $327 = Math_fround($325 * $317);
  $328 = Math_fround($325 * $318);
  $329 = Math_fround(-$326);
  $330 = Math_fround(-$327);
  $331 = Math_fround(-$328);
  $332 = (($sweepHit) + 28|0);
  HEAPF32[$332>>2] = $329;
  $333 = (($sweepHit) + 32|0);
  HEAPF32[$333>>2] = $330;
  $334 = (($sweepHit) + 36|0);
  HEAPF32[$334>>2] = $331;
  $335 = (($sweepHit) + 16|0);
  HEAPF32[$335>>2] = $279;
  $336 = (($sweepHit) + 20|0);
  HEAPF32[$336>>2] = $280;
  $337 = (($sweepHit) + 24|0);
  HEAPF32[$337>>2] = $281;
  $338 = (($sweepHit) + 40|0);
  HEAPF32[$338>>2] = $240;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $339 = (($sweepHit) + 40|0);
  HEAPF32[$339>>2] = Math_fround(0.0);
  $340 = Math_fround(HEAPF32[$unitDir>>2]);
  $341 = Math_fround(-$340);
  $342 = Math_fround(HEAPF32[$14>>2]);
  $343 = Math_fround(-$342);
  $344 = Math_fround(HEAPF32[$16>>2]);
  $345 = Math_fround(-$344);
  $346 = (($sweepHit) + 28|0);
  HEAPF32[$346>>2] = $341;
  $347 = (($sweepHit) + 32|0);
  HEAPF32[$347>>2] = $343;
  $348 = (($sweepHit) + 36|0);
  HEAPF32[$348>>2] = $345;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu17SweepBoxTrianglesEjPKNS_10PxTriangleERKNS_13PxBoxGeometryERKNS_11PxTransformERKNS_6PxVec3EfRSA_SD_RfRjPKjfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($nbTris,$triangles,$boxGeom,$boxPose,$dir,$length,$_hit,$_normal,$_d,$_index,$cachedIndex,$inflation,$hintFlags) {
 $nbTris = $nbTris|0;
 $triangles = $triangles|0;
 $boxGeom = $boxGeom|0;
 $boxPose = $boxPose|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $_hit = $_hit|0;
 $_normal = $_normal|0;
 $_d = $_d|0;
 $_index = $_index|0;
 $cachedIndex = $cachedIndex|0;
 $inflation = Math_fround($inflation);
 $hintFlags = $hintFlags|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$$i57 = Math_fround(0), $$1$i$i = Math_fround(0), $$4 = 0, $$i$i = 0, $$sroa$1$i$i = 0, $$sroa$113$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0;
 var $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0;
 var $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0);
 var $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0);
 var $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0);
 var $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0);
 var $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0);
 var $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0);
 var $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0);
 var $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0);
 var $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0);
 var $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0);
 var $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0);
 var $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0);
 var $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $boxLocalMotion = 0, $boxV = 0, $closestA = 0, $ii$0438 = 0, $lambda = 0, $minTriangleIndex$0439 = 0, $minTriangleIndex$3 = 0;
 var $normal = 0, $not$ = 0, $status$0$off0437 = 0, $status$3$off0 = 0, $triangleIndex$0$i = 0, $triangleV = 0, $zero = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0;
 $0 = sp + 416|0;
 $1 = sp + 400|0;
 $$sroa$113$i$i = sp + 432|0;
 $$sroa$1$i$i = sp + 444|0;
 $zero = sp + 384|0;
 $zeroV = sp + 368|0;
 $boxV = sp + 208|0;
 $boxLocalMotion = sp + 176|0;
 $triangleV = sp + 32|0;
 $lambda = sp + 16|0;
 $closestA = sp;
 $normal = sp + 192|0;
 $2 = ($nbTris|0)==(0);
 if ($2) {
  $$4 = 0;
  STACKTOP = sp;return ($$4|0);
 }
 $3 = (($boxPose) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($boxPose) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($boxPose) + 24|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($boxGeom) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($boxGeom) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($boxGeom) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$boxPose>>2]);
 $16 = (($boxPose) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($boxPose) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($boxPose) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($15 + $15);
 $23 = Math_fround($17 + $17);
 $24 = Math_fround($19 + $19);
 $25 = Math_fround($15 * $22);
 $26 = Math_fround($17 * $23);
 $27 = Math_fround($19 * $24);
 $28 = Math_fround($22 * $17);
 $29 = Math_fround($22 * $19);
 $30 = Math_fround($22 * $21);
 $31 = Math_fround($23 * $19);
 $32 = Math_fround($23 * $21);
 $33 = Math_fround($24 * $21);
 $34 = Math_fround(Math_fround(1.0) - $26);
 $35 = Math_fround($34 - $27);
 $36 = Math_fround($28 + $33);
 $37 = Math_fround($29 - $32);
 $38 = Math_fround($28 - $33);
 $39 = Math_fround(Math_fround(1.0) - $25);
 $40 = Math_fround($39 - $27);
 $41 = Math_fround($31 + $30);
 $42 = Math_fround($29 + $32);
 $43 = Math_fround($31 - $30);
 $44 = Math_fround($39 - $26);
 $45 = Math_fround(-$4);
 $46 = Math_fround(-$6);
 $47 = Math_fround(-$8);
 $48 = Math_fround($35 * $45);
 $49 = Math_fround($36 * $46);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($37 * $47);
 $52 = Math_fround($51 + $50);
 $53 = Math_fround($38 * $45);
 $54 = Math_fround($40 * $46);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($41 * $47);
 $57 = Math_fround($56 + $55);
 $58 = Math_fround($42 * $45);
 $59 = Math_fround($43 * $46);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($44 * $47);
 $62 = Math_fround($61 + $60);
 $63 = Math_fround(HEAPF32[$dir>>2]);
 $64 = Math_fround($63 * $35);
 $65 = Math_fround($63 * $38);
 $66 = Math_fround($63 * $42);
 $67 = (($dir) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 * $36);
 $70 = Math_fround($68 * $40);
 $71 = Math_fround($68 * $43);
 $72 = Math_fround($64 + $69);
 $73 = Math_fround($65 + $70);
 $74 = Math_fround($66 + $71);
 $75 = (($dir) + 8|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($37 * $76);
 $78 = Math_fround($41 * $76);
 $79 = Math_fround($44 * $76);
 $80 = Math_fround($72 + $77);
 $81 = Math_fround($73 + $78);
 $82 = Math_fround($74 + $79);
 $83 = Math_fround($80 * $length);
 $84 = Math_fround($81 * $length);
 $85 = Math_fround($82 * $length);
 HEAPF32[$zero>>2] = Math_fround(0.0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $86 = Math_fround(-$80);
 $87 = Math_fround(-$81);
 $88 = Math_fround(-$82);
 $89 = $80 > $86;
 $$$i$i = $89 ? $80 : $86;
 $90 = $81 > $87;
 $91 = $90 ? $81 : $87;
 $92 = $82 > $88;
 $$1$i$i = $92 ? $82 : $88;
 $93 = Math_fround($10 * $$$i$i);
 $94 = Math_fround($12 * $91);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($14 * $$1$i$i);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($97 + $inflation);
 $99 = (($boxV) + 64|0);
 ;HEAP32[$boxV+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$boxV+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$boxV+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$boxV+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $100 = (($boxV) + 80|0);
 HEAP32[$100>>2] = 3;
 $101 = (($boxV) + 16|0);
 $102 = (($boxV) + 20|0);
 ;HEAP32[$102+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 $103 = (($boxV) + 32|0);
 $104 = (($boxV) + 36|0);
 $105 = (($boxV) + 48|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = (($boxV) + 52|0);
 ;HEAP32[$106+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$99+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$0+12>>2]|0;
 $107 = (($boxV) + 144|0);
 HEAPF32[$107>>2] = $10;
 $108 = (($boxV) + 148|0);
 HEAPF32[$108>>2] = $12;
 $109 = (($boxV) + 152|0);
 HEAPF32[$109>>2] = $14;
 $110 = (($boxV) + 156|0);
 HEAPF32[$110>>2] = Math_fround(0.0);
 $111 = !($10 <= $12);
 $$$i26$i$i$i = $111 ? $12 : $10;
 $112 = !($$$i26$i$i$i <= $14);
 $113 = $112 ? $14 : $$$i26$i$i$i;
 $114 = !($10 >= $12);
 $$$i23$i$i$i = $114 ? $12 : $10;
 $115 = !($$$i23$i$i$i >= $14);
 $116 = $115 ? $14 : $$$i23$i$i$i;
 $117 = Math_fround($113 * Math_fround(0.150000005960464477539));
 $118 = Math_fround($116 * Math_fround(0.0299999993294477462769));
 $119 = $117 > $118;
 $$$i12$i$i$i = $119 ? $117 : $118;
 $120 = $113 > $$$i12$i$i$i;
 $$$i$i$i$i = $120 ? $$$i12$i$i$i : $113;
 HEAPF32[$101>>2] = $$$i$i$i$i;
 ;HEAP32[$102+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 $121 = Math_fround($113 * Math_fround(0.0500000007450580596924));
 HEAPF32[$103>>2] = $121;
 ;HEAP32[$104+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$0+8>>2]|0;
 HEAPF32[$boxLocalMotion>>2] = $83;
 $122 = (($boxLocalMotion) + 4|0);
 HEAPF32[$122>>2] = $84;
 $123 = (($boxLocalMotion) + 8|0);
 HEAPF32[$123>>2] = $85;
 $124 = (($boxLocalMotion) + 12|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = Math_fround(HEAPF32[$boxPose>>2]);
 $126 = (($boxPose) + 4|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($boxPose) + 8|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = (($boxPose) + 12|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround(HEAPF32[$3>>2]);
 $133 = (($3) + 4|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($3) + 8|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = ($cachedIndex|0)==(0|0);
 if ($137) {
  $168 = 0;
 } else {
  $138 = HEAP32[$cachedIndex>>2]|0;
  $168 = $138;
 }
 $139 = (($triangleV) + 64|0);
 $140 = (($triangleV) + 80|0);
 $141 = (($triangleV) + 16|0);
 $142 = (($triangleV) + 20|0);
 $143 = (($triangleV) + 32|0);
 $144 = (($triangleV) + 36|0);
 $145 = (($triangleV) + 48|0);
 $146 = (($triangleV) + 52|0);
 $147 = (($triangleV) + 4|0);
 $148 = (($triangleV) + 8|0);
 $149 = (($triangleV) + 12|0);
 $150 = (($triangleV) + 96|0);
 $151 = (($triangleV) + 100|0);
 $152 = (($triangleV) + 104|0);
 $153 = (($triangleV) + 108|0);
 $154 = (($triangleV) + 112|0);
 $155 = (($triangleV) + 116|0);
 $156 = (($triangleV) + 120|0);
 $157 = (($triangleV) + 124|0);
 $158 = (($triangleV) + 128|0);
 $159 = (($triangleV) + 132|0);
 $160 = (($triangleV) + 136|0);
 $161 = (($triangleV) + 140|0);
 $162 = (($closestA) + 4|0);
 $163 = (($closestA) + 8|0);
 $164 = (($normal) + 4|0);
 $165 = (($normal) + 8|0);
 $284 = $length;$495 = Math_fround(0.0);$496 = Math_fround(0.0);$497 = Math_fround(0.0);$498 = Math_fround(0.0);$499 = Math_fround(0.0);$500 = Math_fround(0.0);$ii$0438 = 0;$minTriangleIndex$0439 = 0;$status$0$off0437 = 0;
 while(1) {
  $166 = ($ii$0438|0)==(0);
  if ($166) {
   $triangleIndex$0$i = $168;
  } else {
   $167 = ($ii$0438|0)==($168|0);
   $$i$i = $167 ? 0 : $ii$0438;
   $triangleIndex$0$i = $$i$i;
  }
  $169 = (($triangles) + (($triangleIndex$0$i*36)|0)|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 4|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 8|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 12|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 16|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 20|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 24|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 28|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 32|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = Math_fround($35 * $170);
  $188 = Math_fround($36 * $172);
  $189 = Math_fround($187 + $188);
  $190 = Math_fround($37 * $174);
  $191 = Math_fround($189 + $190);
  $192 = Math_fround($38 * $170);
  $193 = Math_fround($40 * $172);
  $194 = Math_fround($192 + $193);
  $195 = Math_fround($41 * $174);
  $196 = Math_fround($194 + $195);
  $197 = Math_fround($42 * $170);
  $198 = Math_fround($43 * $172);
  $199 = Math_fround($197 + $198);
  $200 = Math_fround($44 * $174);
  $201 = Math_fround($199 + $200);
  $202 = Math_fround($52 + $191);
  $203 = Math_fround($57 + $196);
  $204 = Math_fround($62 + $201);
  $205 = Math_fround($35 * $176);
  $206 = Math_fround($36 * $178);
  $207 = Math_fround($205 + $206);
  $208 = Math_fround($37 * $180);
  $209 = Math_fround($207 + $208);
  $210 = Math_fround($38 * $176);
  $211 = Math_fround($40 * $178);
  $212 = Math_fround($210 + $211);
  $213 = Math_fround($41 * $180);
  $214 = Math_fround($212 + $213);
  $215 = Math_fround($42 * $176);
  $216 = Math_fround($43 * $178);
  $217 = Math_fround($215 + $216);
  $218 = Math_fround($44 * $180);
  $219 = Math_fround($217 + $218);
  $220 = Math_fround($52 + $209);
  $221 = Math_fround($57 + $214);
  $222 = Math_fround($62 + $219);
  $223 = Math_fround($35 * $182);
  $224 = Math_fround($36 * $184);
  $225 = Math_fround($223 + $224);
  $226 = Math_fround($37 * $186);
  $227 = Math_fround($225 + $226);
  $228 = Math_fround($38 * $182);
  $229 = Math_fround($40 * $184);
  $230 = Math_fround($228 + $229);
  $231 = Math_fround($41 * $186);
  $232 = Math_fround($230 + $231);
  $233 = Math_fround($42 * $182);
  $234 = Math_fround($43 * $184);
  $235 = Math_fround($233 + $234);
  $236 = Math_fround($44 * $186);
  $237 = Math_fround($235 + $236);
  $238 = Math_fround($52 + $227);
  $239 = Math_fround($57 + $232);
  $240 = Math_fround($62 + $237);
  $241 = Math_fround($238 - $220);
  $242 = Math_fround($239 - $221);
  $243 = Math_fround($240 - $222);
  $244 = Math_fround($202 - $220);
  $245 = Math_fround($203 - $221);
  $246 = Math_fround($204 - $222);
  $247 = Math_fround($246 * $242);
  $248 = Math_fround($245 * $243);
  $249 = Math_fround($247 - $248);
  $250 = Math_fround($244 * $243);
  $251 = Math_fround($246 * $241);
  $252 = Math_fround($250 - $251);
  $253 = Math_fround($245 * $241);
  $254 = Math_fround($244 * $242);
  $255 = Math_fround($253 - $254);
  $256 = Math_fround(HEAPF32[$boxLocalMotion>>2]);
  $257 = Math_fround(HEAPF32[$122>>2]);
  $258 = Math_fround(HEAPF32[$123>>2]);
  $259 = Math_fround($256 * $249);
  $260 = Math_fround($257 * $252);
  $261 = Math_fround($259 + $260);
  $262 = Math_fround($258 * $255);
  $263 = Math_fround($262 + $261);
  $264 = Math_fround(HEAPF32[$zero>>2]);
  $265 = !($263 >= $264);
  if ($265) {
   $266 = Math_fround($80 * $202);
   $267 = Math_fround($81 * $203);
   $268 = Math_fround($266 + $267);
   $269 = Math_fround($82 * $204);
   $270 = Math_fround($269 + $268);
   $271 = Math_fround($80 * $220);
   $272 = Math_fround($81 * $221);
   $273 = Math_fround($271 + $272);
   $274 = Math_fround($82 * $222);
   $275 = Math_fround($274 + $273);
   $276 = Math_fround($80 * $238);
   $277 = Math_fround($81 * $239);
   $278 = Math_fround($276 + $277);
   $279 = Math_fround($82 * $240);
   $280 = Math_fround($279 + $278);
   $281 = $275 > $280;
   $$$i57 = $281 ? $280 : $275;
   $282 = $270 > $$$i57;
   $$$i = $282 ? $$$i57 : $270;
   $283 = Math_fround($98 + $284);
   $not$ = !($$$i > $283);
   if ($not$) {
    HEAP32[$140>>2] = 7;
    HEAPF32[$145>>2] = Math_fround(0.0);
    ;HEAP32[$146+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$0+8>>2]|0;
    ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
    ;HEAP32[$139+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$139+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$139+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$139+12>>2]=HEAP32[$1+12>>2]|0;
    $285 = Math_fround($202 + $220);
    $286 = Math_fround($203 + $221);
    $287 = Math_fround($204 + $222);
    $288 = Math_fround($285 + $238);
    $289 = Math_fround($286 + $239);
    $290 = Math_fround($287 + $240);
    $291 = Math_fround($288 * Math_fround(0.333332985639572143555));
    $292 = Math_fround($289 * Math_fround(0.333332985639572143555));
    $293 = Math_fround($290 * Math_fround(0.333332985639572143555));
    HEAPF32[$triangleV>>2] = $291;
    HEAPF32[$147>>2] = $292;
    HEAPF32[$148>>2] = $293;
    HEAPF32[$149>>2] = Math_fround(0.0);
    HEAPF32[$150>>2] = $202;
    HEAPF32[$151>>2] = $203;
    HEAPF32[$152>>2] = $204;
    HEAPF32[$153>>2] = Math_fround(0.0);
    HEAPF32[$154>>2] = $220;
    HEAPF32[$155>>2] = $221;
    HEAPF32[$156>>2] = $222;
    HEAPF32[$157>>2] = Math_fround(0.0);
    HEAPF32[$158>>2] = $238;
    HEAPF32[$159>>2] = $239;
    HEAPF32[$160>>2] = $240;
    HEAPF32[$161>>2] = Math_fround(0.0);
    HEAPF32[$141>>2] = Math_fround(0.0);
    ;HEAP32[$142+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$142+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$142+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
    HEAPF32[$143>>2] = Math_fround(3.40282346638528859812E+38);
    ;HEAP32[$144+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
    $294 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_9TriangleVERNS0_4BoxVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($triangleV,$boxV,$zero,$zeroV,$boxLocalMotion,$lambda,$normal,$closestA,$inflation,0)|0);
    if ($294) {
     $295 = Math_fround(HEAPF32[$zero>>2]);
     $296 = Math_fround(HEAPF32[$lambda>>2]);
     $297 = !($295 >= $296);
     if (!($297)) {
      label = 12;
      break;
     }
     $298 = Math_fround($284 * $296);
     $299 = Math_fround($80 * $298);
     $300 = Math_fround($81 * $298);
     $301 = Math_fround($82 * $298);
     HEAPF32[$boxLocalMotion>>2] = $299;
     HEAPF32[$122>>2] = $300;
     HEAPF32[$123>>2] = $301;
     HEAPF32[$124>>2] = Math_fround(0.0);
     $302 = Math_fround(HEAPF32[$closestA>>2]);
     $303 = Math_fround(HEAPF32[$162>>2]);
     $304 = Math_fround(HEAPF32[$163>>2]);
     $305 = Math_fround(HEAPF32[$normal>>2]);
     $306 = Math_fround(HEAPF32[$164>>2]);
     $307 = Math_fround(HEAPF32[$165>>2]);
     $405 = $305;$407 = $306;$409 = $307;$453 = $302;$455 = $303;$457 = $304;$494 = $298;$minTriangleIndex$3 = $triangleIndex$0$i;$status$3$off0 = 1;
    } else {
     $405 = $495;$407 = $496;$409 = $497;$453 = $498;$455 = $499;$457 = $500;$494 = $284;$minTriangleIndex$3 = $minTriangleIndex$0439;$status$3$off0 = $status$0$off0437;
    }
   } else {
    $405 = $495;$407 = $496;$409 = $497;$453 = $498;$455 = $499;$457 = $500;$494 = $284;$minTriangleIndex$3 = $minTriangleIndex$0439;$status$3$off0 = $status$0$off0437;
   }
  } else {
   $405 = $495;$407 = $496;$409 = $497;$453 = $498;$455 = $499;$457 = $500;$494 = $284;$minTriangleIndex$3 = $minTriangleIndex$0439;$status$3$off0 = $status$0$off0437;
  }
  $400 = (($ii$0438) + 1)|0;
  $401 = ($400>>>0)<($nbTris>>>0);
  if ($401) {
   $284 = $494;$495 = $405;$496 = $407;$497 = $409;$498 = $453;$499 = $455;$500 = $457;$ii$0438 = $400;$minTriangleIndex$0439 = $minTriangleIndex$3;$status$0$off0437 = $status$3$off0;
  } else {
   break;
  }
 }
 if ((label|0) == 12) {
  $308 = Math_fround(HEAPF32[$normal>>2]);
  $309 = Math_fround(HEAPF32[$164>>2]);
  $310 = Math_fround(HEAPF32[$165>>2]);
  $311 = Math_fround($131 * $131);
  $312 = Math_fround($311 + Math_fround(-0.5));
  $313 = Math_fround($312 * $308);
  $314 = Math_fround($312 * $309);
  $315 = Math_fround($312 * $310);
  $316 = Math_fround($127 * $310);
  $317 = Math_fround($129 * $309);
  $318 = Math_fround($316 - $317);
  $319 = Math_fround($129 * $308);
  $320 = Math_fround($125 * $310);
  $321 = Math_fround($319 - $320);
  $322 = Math_fround($125 * $309);
  $323 = Math_fround($127 * $308);
  $324 = Math_fround($322 - $323);
  $325 = Math_fround($131 * $318);
  $326 = Math_fround($131 * $321);
  $327 = Math_fround($131 * $324);
  $328 = Math_fround($313 + $325);
  $329 = Math_fround($314 + $326);
  $330 = Math_fround($315 + $327);
  $331 = Math_fround($125 * $308);
  $332 = Math_fround($127 * $309);
  $333 = Math_fround($331 + $332);
  $334 = Math_fround($129 * $310);
  $335 = Math_fround($333 + $334);
  $336 = Math_fround($125 * $335);
  $337 = Math_fround($127 * $335);
  $338 = Math_fround($129 * $335);
  $339 = Math_fround($336 + $328);
  $340 = Math_fround($337 + $329);
  $341 = Math_fround($330 + $338);
  $342 = Math_fround($339 * Math_fround(2.0));
  $343 = Math_fround($340 * Math_fround(2.0));
  $344 = Math_fround($341 * Math_fround(2.0));
  $345 = Math_fround($342 * $342);
  $346 = Math_fround($343 * $343);
  $347 = Math_fround($345 + $346);
  $348 = Math_fround($344 * $344);
  $349 = Math_fround($348 + $347);
  $350 = (Math_fround(Math_sqrt((Math_fround($349)))));
  $351 = Math_fround(Math_fround(1.0) / $350);
  $352 = Math_fround($351 * $342);
  $353 = Math_fround($351 * $343);
  $354 = Math_fround($351 * $344);
  $355 = Math_fround(-$352);
  $356 = Math_fround(-$353);
  $357 = Math_fround(-$354);
  $358 = Math_fround(HEAPF32[$closestA>>2]);
  $359 = Math_fround(HEAPF32[$162>>2]);
  $360 = Math_fround(HEAPF32[$163>>2]);
  $361 = Math_fround($312 * $358);
  $362 = Math_fround($312 * $359);
  $363 = Math_fround($312 * $360);
  $364 = Math_fround($127 * $360);
  $365 = Math_fround($129 * $359);
  $366 = Math_fround($364 - $365);
  $367 = Math_fround($129 * $358);
  $368 = Math_fround($125 * $360);
  $369 = Math_fround($367 - $368);
  $370 = Math_fround($125 * $359);
  $371 = Math_fround($127 * $358);
  $372 = Math_fround($370 - $371);
  $373 = Math_fround($131 * $366);
  $374 = Math_fround($131 * $369);
  $375 = Math_fround($131 * $372);
  $376 = Math_fround($361 + $373);
  $377 = Math_fround($362 + $374);
  $378 = Math_fround($363 + $375);
  $379 = Math_fround($125 * $358);
  $380 = Math_fround($127 * $359);
  $381 = Math_fround($379 + $380);
  $382 = Math_fround($129 * $360);
  $383 = Math_fround($381 + $382);
  $384 = Math_fround($125 * $383);
  $385 = Math_fround($127 * $383);
  $386 = Math_fround($129 * $383);
  $387 = Math_fround($384 + $376);
  $388 = Math_fround($385 + $377);
  $389 = Math_fround($378 + $386);
  $390 = Math_fround($387 * Math_fround(2.0));
  $391 = Math_fround($388 * Math_fround(2.0));
  $392 = Math_fround($389 * Math_fround(2.0));
  $393 = Math_fround($132 + $390);
  $394 = Math_fround($134 + $391);
  $395 = Math_fround($136 + $392);
  HEAPF32[$_d>>2] = Math_fround(0.0);
  HEAP32[$_index>>2] = $triangleIndex$0$i;
  HEAPF32[$_normal>>2] = $355;
  $396 = (($_normal) + 4|0);
  HEAPF32[$396>>2] = $356;
  $397 = (($_normal) + 8|0);
  HEAPF32[$397>>2] = $357;
  HEAPF32[$_hit>>2] = $393;
  $398 = (($_hit) + 4|0);
  HEAPF32[$398>>2] = $394;
  $399 = (($_hit) + 8|0);
  HEAPF32[$399>>2] = $395;
  $$4 = 1;
  STACKTOP = sp;return ($$4|0);
 }
 if (!($status$3$off0)) {
  $$4 = 0;
  STACKTOP = sp;return ($$4|0);
 }
 HEAP32[$_index>>2] = $minTriangleIndex$3;
 $402 = Math_fround($131 * $131);
 $403 = Math_fround($402 + Math_fround(-0.5));
 $404 = Math_fround($403 * $405);
 $406 = Math_fround($403 * $407);
 $408 = Math_fround($403 * $409);
 $410 = Math_fround($127 * $409);
 $411 = Math_fround($129 * $407);
 $412 = Math_fround($410 - $411);
 $413 = Math_fround($129 * $405);
 $414 = Math_fround($125 * $409);
 $415 = Math_fround($413 - $414);
 $416 = Math_fround($125 * $407);
 $417 = Math_fround($127 * $405);
 $418 = Math_fround($416 - $417);
 $419 = Math_fround($131 * $412);
 $420 = Math_fround($131 * $415);
 $421 = Math_fround($131 * $418);
 $422 = Math_fround($404 + $419);
 $423 = Math_fround($406 + $420);
 $424 = Math_fround($408 + $421);
 $425 = Math_fround($125 * $405);
 $426 = Math_fround($127 * $407);
 $427 = Math_fround($426 + $425);
 $428 = Math_fround($129 * $409);
 $429 = Math_fround($428 + $427);
 $430 = Math_fround($125 * $429);
 $431 = Math_fround($127 * $429);
 $432 = Math_fround($129 * $429);
 $433 = Math_fround($422 + $430);
 $434 = Math_fround($431 + $423);
 $435 = Math_fround($424 + $432);
 $436 = Math_fround($433 * Math_fround(2.0));
 $437 = Math_fround($434 * Math_fround(2.0));
 $438 = Math_fround($435 * Math_fround(2.0));
 $439 = Math_fround($436 * $436);
 $440 = Math_fround($437 * $437);
 $441 = Math_fround($439 + $440);
 $442 = Math_fround($438 * $438);
 $443 = Math_fround($442 + $441);
 $444 = (Math_fround(Math_sqrt((Math_fround($443)))));
 $445 = Math_fround(Math_fround(1.0) / $444);
 $446 = Math_fround($436 * $445);
 $447 = Math_fround($437 * $445);
 $448 = Math_fround($438 * $445);
 $449 = Math_fround(-$446);
 $450 = Math_fround(-$447);
 $451 = Math_fround(-$448);
 $452 = Math_fround($403 * $453);
 $454 = Math_fround($403 * $455);
 $456 = Math_fround($403 * $457);
 $458 = Math_fround($127 * $457);
 $459 = Math_fround($129 * $455);
 $460 = Math_fround($458 - $459);
 $461 = Math_fround($129 * $453);
 $462 = Math_fround($125 * $457);
 $463 = Math_fround($461 - $462);
 $464 = Math_fround($125 * $455);
 $465 = Math_fround($127 * $453);
 $466 = Math_fround($464 - $465);
 $467 = Math_fround($131 * $460);
 $468 = Math_fround($131 * $463);
 $469 = Math_fround($131 * $466);
 $470 = Math_fround($452 + $467);
 $471 = Math_fround($454 + $468);
 $472 = Math_fround($456 + $469);
 $473 = Math_fround($125 * $453);
 $474 = Math_fround($127 * $455);
 $475 = Math_fround($474 + $473);
 $476 = Math_fround($129 * $457);
 $477 = Math_fround($476 + $475);
 $478 = Math_fround($125 * $477);
 $479 = Math_fround($127 * $477);
 $480 = Math_fround($129 * $477);
 $481 = Math_fround($470 + $478);
 $482 = Math_fround($479 + $471);
 $483 = Math_fround($472 + $480);
 $484 = Math_fround($481 * Math_fround(2.0));
 $485 = Math_fround($482 * Math_fround(2.0));
 $486 = Math_fround($483 * Math_fround(2.0));
 $487 = Math_fround($132 + $484);
 $488 = Math_fround($134 + $485);
 $489 = Math_fround($136 + $486);
 HEAPF32[$_normal>>2] = $449;
 $490 = (($_normal) + 4|0);
 HEAPF32[$490>>2] = $450;
 $491 = (($_normal) + 8|0);
 HEAPF32[$491>>2] = $451;
 HEAPF32[$_hit>>2] = $487;
 $492 = (($_hit) + 4|0);
 HEAPF32[$492>>2] = $488;
 $493 = (($_hit) + 8|0);
 HEAPF32[$493>>2] = $489;
 HEAPF32[$_d>>2] = $494;
 $$4 = 1;
 STACKTOP = sp;return ($$4|0);
}
function __ZN5physx2Gu17GetGeomSweepFuncsEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (548608|0);
}
function __ZN5physx2Gu18contactCapsuleMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0);
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $callback = 0, $hmd = 0, $meshCapsule = 0;
 var $meshScaling = 0, $queryBox = 0, $queryCapsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1104|0;
 $meshScaling = sp + 1024|0;
 $meshCapsule = sp;
 $queryCapsule = sp + 24|0;
 $callback = sp + 52|0;
 $queryBox = sp + 952|0;
 $hmd = sp + 1012|0;
 $0 = (($shape1) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == Math_fround(1.0);
 if ($2) {
  $3 = (($shape1) + 8|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(1.0);
  if ($5) {
   $6 = (($shape1) + 12|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 == Math_fround(1.0);
   $178 = $8;
  } else {
   $178 = 0;
  }
 } else {
  $178 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $9 = (($meshScaling) + 4|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($meshScaling) + 8|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($meshScaling) + 12|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($meshScaling) + 16|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($meshScaling) + 20|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($meshScaling) + 24|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($meshScaling) + 28|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($meshScaling) + 32|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($meshScaling) + 36|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($meshScaling) + 40|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($meshScaling) + 44|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($meshScaling) + 48|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($meshScaling) + 52|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($meshScaling) + 56|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($meshScaling) + 60|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($meshScaling) + 64|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($meshScaling) + 68|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 if (!($178)) {
  $26 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$0,$26);
 }
 $27 = Math_fround(HEAPF32[$transform0>>2]);
 $28 = Math_fround($27 * Math_fround(2.0));
 $29 = (($transform0) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * Math_fround(2.0));
 $32 = Math_fround($30 * $31);
 $33 = Math_fround($32 + Math_fround(-1.0));
 $34 = Math_fround($27 * $28);
 $35 = Math_fround($34 + $33);
 $36 = (($transform0) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * $31);
 $39 = (($transform0) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($28 * $40);
 $42 = Math_fround($38 + $41);
 $43 = Math_fround($31 * $40);
 $44 = Math_fround($28 * $37);
 $45 = Math_fround($44 - $43);
 $46 = (($shape0) + 8|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 * $35);
 $49 = Math_fround($47 * $42);
 $50 = Math_fround($47 * $45);
 $51 = (($transform0) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 + $48);
 $54 = (($transform0) + 20|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 + $49);
 $57 = (($transform0) + 24|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($50 + $58);
 $60 = Math_fround($52 - $48);
 $61 = Math_fround($55 - $49);
 $62 = Math_fround($58 - $50);
 $63 = (($shape0) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(HEAPF32[$contactDistance>>2]);
 $66 = Math_fround($64 + $65);
 $67 = (($transform1) + 16|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($53 - $68);
 $70 = (($transform1) + 20|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($56 - $71);
 $73 = (($transform1) + 24|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($59 - $74);
 $76 = Math_fround($69 * Math_fround(2.0));
 $77 = Math_fround($72 * Math_fround(2.0));
 $78 = Math_fround($75 * Math_fround(2.0));
 $79 = (($transform1) + 12|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($80 * $80);
 $82 = Math_fround($81 + Math_fround(-0.5));
 $83 = Math_fround(HEAPF32[$transform1>>2]);
 $84 = Math_fround($76 * $83);
 $85 = (($transform1) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($77 * $86);
 $88 = Math_fround($84 + $87);
 $89 = (($transform1) + 8|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($78 * $90);
 $92 = Math_fround($88 + $91);
 $93 = Math_fround($76 * $82);
 $94 = Math_fround($78 * $86);
 $95 = Math_fround($77 * $90);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($80 * $96);
 $98 = Math_fround($93 - $97);
 $99 = Math_fround($83 * $92);
 $100 = Math_fround($99 + $98);
 $101 = Math_fround($77 * $82);
 $102 = Math_fround($76 * $90);
 $103 = Math_fround($78 * $83);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($80 * $104);
 $106 = Math_fround($101 - $105);
 $107 = Math_fround($86 * $92);
 $108 = Math_fround($107 + $106);
 $109 = Math_fround($78 * $82);
 $110 = Math_fround($77 * $83);
 $111 = Math_fround($76 * $86);
 $112 = Math_fround($110 - $111);
 $113 = Math_fround($80 * $112);
 $114 = Math_fround($109 - $113);
 $115 = Math_fround($90 * $92);
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($60 - $68);
 $118 = Math_fround($61 - $71);
 $119 = Math_fround($62 - $74);
 $120 = Math_fround($117 * Math_fround(2.0));
 $121 = Math_fround($118 * Math_fround(2.0));
 $122 = Math_fround($119 * Math_fround(2.0));
 $123 = Math_fround($120 * $83);
 $124 = Math_fround($121 * $86);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($122 * $90);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround($120 * $82);
 $129 = Math_fround($122 * $86);
 $130 = Math_fround($121 * $90);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($80 * $131);
 $133 = Math_fround($128 - $132);
 $134 = Math_fround($83 * $127);
 $135 = Math_fround($134 + $133);
 $136 = Math_fround($121 * $82);
 $137 = Math_fround($120 * $90);
 $138 = Math_fround($122 * $83);
 $139 = Math_fround($137 - $138);
 $140 = Math_fround($80 * $139);
 $141 = Math_fround($136 - $140);
 $142 = Math_fround($86 * $127);
 $143 = Math_fround($142 + $141);
 $144 = Math_fround($122 * $82);
 $145 = Math_fround($121 * $83);
 $146 = Math_fround($120 * $86);
 $147 = Math_fround($145 - $146);
 $148 = Math_fround($80 * $147);
 $149 = Math_fround($144 - $148);
 $150 = Math_fround($90 * $127);
 $151 = Math_fround($149 + $150);
 HEAPF32[$meshCapsule>>2] = $100;
 $152 = (($meshCapsule) + 4|0);
 HEAPF32[$152>>2] = $108;
 $153 = (($meshCapsule) + 8|0);
 HEAPF32[$153>>2] = $116;
 $154 = (($meshCapsule) + 12|0);
 HEAPF32[$154>>2] = $135;
 $155 = (($meshCapsule) + 16|0);
 HEAPF32[$155>>2] = $143;
 $156 = (($meshCapsule) + 20|0);
 HEAPF32[$156>>2] = $151;
 HEAPF32[$queryCapsule>>2] = $100;
 $157 = (($queryCapsule) + 4|0);
 HEAPF32[$157>>2] = $108;
 $158 = (($queryCapsule) + 8|0);
 HEAPF32[$158>>2] = $116;
 $159 = (($queryCapsule) + 12|0);
 HEAPF32[$159>>2] = $135;
 $160 = (($queryCapsule) + 16|0);
 HEAPF32[$160>>2] = $143;
 $161 = (($queryCapsule) + 20|0);
 HEAPF32[$161>>2] = $151;
 $162 = (($queryCapsule) + 24|0);
 HEAPF32[$162>>2] = $66;
 $163 = (($shape1) + 40|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = Math_fround(HEAPF32[$contactDistance>>2]);
 $166 = Math_fround(HEAPF32[$63>>2]);
 $167 = (($callback) + 4|0);
 HEAP32[$167>>2] = 2;
 HEAP32[$callback>>2] = ((548800 + 8|0));
 $168 = (($callback) + 8|0);
 HEAP32[$168>>2] = $contactBuffer;
 $169 = (($callback) + 12|0);
 HEAP32[$169>>2] = $transform1;
 $170 = (($callback) + 16|0);
 HEAP32[$170>>2] = $meshCapsule;
 $171 = (($callback) + 20|0);
 HEAPF32[$171>>2] = $66;
 $172 = (($callback) + 24|0);
 HEAPF32[$172>>2] = $165;
 $173 = (($callback) + 28|0);
 HEAPF32[$173>>2] = $166;
 $174 = (($callback) + 32|0);
 HEAP32[$174>>2] = $shape1;
 $175 = (($callback) + 36|0);
 HEAP32[$175>>2] = $meshScaling;
 $176 = (($callback) + 40|0);
 $177 = $178&1;
 HEAP8[$176>>0] = $177;
 $179 = (($callback) + 892|0);
 HEAP32[$179>>2] = 0;
 $180 = (($callback) + 896|0);
 HEAP32[$180>>2] = $164;
 __ZN5physx2Gu3Box6createERKNS0_7CapsuleE($queryBox,$queryCapsule);
 if (!($178)) {
  $181 = (($queryBox) + 36|0);
  $182 = (($queryBox) + 48|0);
  __ZNK5physx2Cm23FastVertex2ShapeScaling20transformQueryBoundsERNS_6PxVec3ES3_RNS_7PxMat33E($meshScaling,$181,$182,$queryBox);
 }
 $183 = (($164) + 16|0);
 $184 = HEAP32[$183>>2]|0;
 HEAP32[$hmd>>2] = $184;
 $185 = (($164) + 32|0);
 $186 = (($hmd) + 4|0);
 HEAP32[$186>>2] = $185;
 $187 = (($164) + 20|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($hmd) + 8|0);
 HEAPF32[$189>>2] = $188;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($queryBox,1,$hmd,$callback,1);
 $190 = HEAP32[$179>>2]|0;
 $191 = ($190|0)==(0);
 if ($191) {
  $194 = (($contactBuffer) + 4096|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = ($195|0)!=(0);
  STACKTOP = sp;return ($196|0);
 }
 $192 = (($callback) + 44|0);
 $193 = (($callback) + 8|0);
 (__ZN18ContactCapsuleMesh20processTriangleCacheILj16EEEbRN5physx2Gu13TriangleCacheIXT_EEE($193,$192)|0);
 HEAP32[$179>>2] = 0;
 $194 = (($contactBuffer) + 4096|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = ($195|0)!=(0);
 STACKTOP = sp;return ($196|0);
}
function __ZNK5physx2Cm23FastVertex2ShapeScaling20transformQueryBoundsERNS_6PxVec3ES3_RNS_7PxMat33E($this,$center,$extents,$basis) {
 $this = $this|0;
 $center = $center|0;
 $extents = $extents|0;
 $basis = $basis|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0);
 var $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$extents>>2]);
 $2 = Math_fround(HEAPF32[$basis>>2]);
 $3 = Math_fround($1 * $2);
 $4 = (($basis) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($1 * $5);
 $7 = (($basis) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($1 * $8);
 $10 = (($this) + 36|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($3 * $11);
 $13 = (($this) + 40|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($3 * $14);
 $16 = (($this) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($3 * $17);
 $19 = (($this) + 48|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($6 * $20);
 $22 = (($this) + 52|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($6 * $23);
 $25 = (($this) + 56|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($6 * $26);
 $28 = Math_fround($12 + $21);
 $29 = Math_fround($15 + $24);
 $30 = Math_fround($18 + $27);
 $31 = (($this) + 60|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($9 * $32);
 $34 = (($this) + 64|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($9 * $35);
 $37 = (($this) + 68|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($9 * $38);
 $40 = Math_fround($28 + $33);
 $41 = Math_fround($29 + $36);
 $42 = Math_fround($30 + $39);
 HEAPF32[$basis>>2] = $40;
 HEAPF32[$4>>2] = $41;
 HEAPF32[$7>>2] = $42;
 $43 = (($extents) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($basis) + 12|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($44 * $46);
 $48 = (($basis) + 16|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($44 * $49);
 $51 = (($basis) + 20|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($44 * $52);
 $54 = Math_fround(HEAPF32[$10>>2]);
 $55 = Math_fround($47 * $54);
 $56 = Math_fround(HEAPF32[$13>>2]);
 $57 = Math_fround($47 * $56);
 $58 = Math_fround(HEAPF32[$16>>2]);
 $59 = Math_fround($47 * $58);
 $60 = Math_fround(HEAPF32[$19>>2]);
 $61 = Math_fround($50 * $60);
 $62 = Math_fround(HEAPF32[$22>>2]);
 $63 = Math_fround($50 * $62);
 $64 = Math_fround(HEAPF32[$25>>2]);
 $65 = Math_fround($50 * $64);
 $66 = Math_fround($55 + $61);
 $67 = Math_fround($57 + $63);
 $68 = Math_fround($59 + $65);
 $69 = Math_fround(HEAPF32[$31>>2]);
 $70 = Math_fround($53 * $69);
 $71 = Math_fround(HEAPF32[$34>>2]);
 $72 = Math_fround($53 * $71);
 $73 = Math_fround(HEAPF32[$37>>2]);
 $74 = Math_fround($53 * $73);
 $75 = Math_fround($66 + $70);
 $76 = Math_fround($67 + $72);
 $77 = Math_fround($68 + $74);
 HEAPF32[$45>>2] = $75;
 HEAPF32[$48>>2] = $76;
 HEAPF32[$51>>2] = $77;
 $78 = (($extents) + 8|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($basis) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($79 * $81);
 $83 = (($basis) + 28|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($79 * $84);
 $86 = (($basis) + 32|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($79 * $87);
 $89 = Math_fround(HEAPF32[$10>>2]);
 $90 = Math_fround($82 * $89);
 $91 = Math_fround(HEAPF32[$13>>2]);
 $92 = Math_fround($82 * $91);
 $93 = Math_fround(HEAPF32[$16>>2]);
 $94 = Math_fround($82 * $93);
 $95 = Math_fround(HEAPF32[$19>>2]);
 $96 = Math_fround($85 * $95);
 $97 = Math_fround(HEAPF32[$22>>2]);
 $98 = Math_fround($85 * $97);
 $99 = Math_fround(HEAPF32[$25>>2]);
 $100 = Math_fround($85 * $99);
 $101 = Math_fround($90 + $96);
 $102 = Math_fround($92 + $98);
 $103 = Math_fround($94 + $100);
 $104 = Math_fround(HEAPF32[$31>>2]);
 $105 = Math_fround($88 * $104);
 $106 = Math_fround(HEAPF32[$34>>2]);
 $107 = Math_fround($88 * $106);
 $108 = Math_fround(HEAPF32[$37>>2]);
 $109 = Math_fround($88 * $108);
 $110 = Math_fround($101 + $105);
 $111 = Math_fround($102 + $107);
 $112 = Math_fround($103 + $109);
 HEAPF32[$80>>2] = $110;
 HEAPF32[$83>>2] = $111;
 HEAPF32[$86>>2] = $112;
 $113 = Math_fround(HEAPF32[$center>>2]);
 $114 = Math_fround(HEAPF32[$10>>2]);
 $115 = Math_fround($113 * $114);
 $116 = Math_fround(HEAPF32[$13>>2]);
 $117 = Math_fround($113 * $116);
 $118 = Math_fround(HEAPF32[$16>>2]);
 $119 = Math_fround($113 * $118);
 $120 = (($center) + 4|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround(HEAPF32[$19>>2]);
 $123 = Math_fround($121 * $122);
 $124 = Math_fround(HEAPF32[$22>>2]);
 $125 = Math_fround($121 * $124);
 $126 = Math_fround(HEAPF32[$25>>2]);
 $127 = Math_fround($121 * $126);
 $128 = Math_fround($115 + $123);
 $129 = Math_fround($117 + $125);
 $130 = Math_fround($119 + $127);
 $131 = (($center) + 8|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround(HEAPF32[$31>>2]);
 $134 = Math_fround($132 * $133);
 $135 = Math_fround(HEAPF32[$34>>2]);
 $136 = Math_fround($132 * $135);
 $137 = Math_fround(HEAPF32[$37>>2]);
 $138 = Math_fround($132 * $137);
 $139 = Math_fround($128 + $134);
 $140 = Math_fround($129 + $136);
 $141 = Math_fround($130 + $138);
 HEAPF32[$center>>2] = $139;
 HEAPF32[$120>>2] = $140;
 HEAPF32[$131>>2] = $141;
 __ZN5physx6shdfnd19optimizeBoundingBoxERNS_7PxMat33E($0,$basis);
 $142 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$extents>>2] = $142;
 $143 = (($0) + 4|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 HEAPF32[$43>>2] = $144;
 $145 = (($0) + 8|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 HEAPF32[$78>>2] = $146;
 STACKTOP = sp;return;
}
function __ZN26ContactCapsuleMeshCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25contactCapsuleHeightfieldERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0;
 var $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $bounds = 0, $callback = 0, $hfUtil = 0, $meshCapsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $meshCapsule = sp + 136|0;
 $hfUtil = sp;
 $callback = sp + 24|0;
 $bounds = sp + 56|0;
 $0 = sp + 80|0;
 $1 = sp + 104|0;
 $2 = Math_fround(HEAPF32[$transform0>>2]);
 $3 = Math_fround($2 * Math_fround(2.0));
 $4 = (($transform0) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = Math_fround($5 * $6);
 $8 = Math_fround($7 + Math_fround(-1.0));
 $9 = Math_fround($2 * $3);
 $10 = Math_fround($9 + $8);
 $11 = (($transform0) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $6);
 $14 = (($transform0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 * $15);
 $17 = Math_fround($13 + $16);
 $18 = Math_fround($6 * $15);
 $19 = Math_fround($3 * $12);
 $20 = Math_fround($19 - $18);
 $21 = (($shape0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $10);
 $24 = Math_fround($22 * $17);
 $25 = Math_fround($22 * $20);
 $26 = (($transform0) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 + $23);
 $29 = (($transform0) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $24);
 $32 = (($transform0) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($25 + $33);
 $35 = Math_fround($27 - $23);
 $36 = Math_fround($30 - $24);
 $37 = Math_fround($33 - $25);
 $38 = (($shape0) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround(HEAPF32[$contactDistance>>2]);
 $41 = Math_fround($39 + $40);
 $42 = (($transform1) + 16|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($28 - $43);
 $45 = (($transform1) + 20|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($31 - $46);
 $48 = (($transform1) + 24|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($34 - $49);
 $51 = Math_fround($44 * Math_fround(2.0));
 $52 = Math_fround($47 * Math_fround(2.0));
 $53 = Math_fround($50 * Math_fround(2.0));
 $54 = (($transform1) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * $55);
 $57 = Math_fround($56 + Math_fround(-0.5));
 $58 = Math_fround(HEAPF32[$transform1>>2]);
 $59 = Math_fround($51 * $58);
 $60 = (($transform1) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($52 * $61);
 $63 = Math_fround($59 + $62);
 $64 = (($transform1) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($53 * $65);
 $67 = Math_fround($63 + $66);
 $68 = Math_fround($51 * $57);
 $69 = Math_fround($53 * $61);
 $70 = Math_fround($52 * $65);
 $71 = Math_fround($69 - $70);
 $72 = Math_fround($55 * $71);
 $73 = Math_fround($68 - $72);
 $74 = Math_fround($58 * $67);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($52 * $57);
 $77 = Math_fround($51 * $65);
 $78 = Math_fround($53 * $58);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($55 * $79);
 $81 = Math_fround($76 - $80);
 $82 = Math_fround($61 * $67);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($53 * $57);
 $85 = Math_fround($52 * $58);
 $86 = Math_fround($51 * $61);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($55 * $87);
 $89 = Math_fround($84 - $88);
 $90 = Math_fround($65 * $67);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($35 - $43);
 $93 = Math_fround($36 - $46);
 $94 = Math_fround($37 - $49);
 $95 = Math_fround($92 * Math_fround(2.0));
 $96 = Math_fround($93 * Math_fround(2.0));
 $97 = Math_fround($94 * Math_fround(2.0));
 $98 = Math_fround($95 * $58);
 $99 = Math_fround($96 * $61);
 $100 = Math_fround($98 + $99);
 $101 = Math_fround($97 * $65);
 $102 = Math_fround($100 + $101);
 $103 = Math_fround($95 * $57);
 $104 = Math_fround($97 * $61);
 $105 = Math_fround($96 * $65);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($55 * $106);
 $108 = Math_fround($103 - $107);
 $109 = Math_fround($58 * $102);
 $110 = Math_fround($109 + $108);
 $111 = Math_fround($96 * $57);
 $112 = Math_fround($95 * $65);
 $113 = Math_fround($97 * $58);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($55 * $114);
 $116 = Math_fround($111 - $115);
 $117 = Math_fround($61 * $102);
 $118 = Math_fround($117 + $116);
 $119 = Math_fround($97 * $57);
 $120 = Math_fround($96 * $58);
 $121 = Math_fround($95 * $61);
 $122 = Math_fround($120 - $121);
 $123 = Math_fround($55 * $122);
 $124 = Math_fround($119 - $123);
 $125 = Math_fround($65 * $102);
 $126 = Math_fround($124 + $125);
 HEAPF32[$meshCapsule>>2] = $75;
 $127 = (($meshCapsule) + 4|0);
 HEAPF32[$127>>2] = $83;
 $128 = (($meshCapsule) + 8|0);
 HEAPF32[$128>>2] = $91;
 $129 = (($meshCapsule) + 12|0);
 HEAPF32[$129>>2] = $110;
 $130 = (($meshCapsule) + 16|0);
 HEAPF32[$130>>2] = $118;
 $131 = (($meshCapsule) + 20|0);
 HEAPF32[$131>>2] = $126;
 $132 = (($shape1) + 4|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (($hfUtil) + 12|0);
 HEAP32[$134>>2] = $133;
 $135 = (($hfUtil) + 16|0);
 HEAP32[$135>>2] = $shape1;
 $136 = (($shape1) + 8|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround(Math_fround(1.0) / $137);
 $139 = (($hfUtil) + 4|0);
 HEAPF32[$139>>2] = $138;
 $140 = (($shape1) + 12|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = Math_fround(Math_fround(1.0) / $141);
 HEAPF32[$hfUtil>>2] = $142;
 $143 = (($shape1) + 16|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround(Math_fround(1.0) / $144);
 $146 = (($hfUtil) + 8|0);
 HEAPF32[$146>>2] = $145;
 $147 = Math_fround(HEAPF32[$contactDistance>>2]);
 $148 = Math_fround(HEAPF32[$38>>2]);
 HEAP32[$callback>>2] = ((548752 + 8|0));
 $149 = (($callback) + 4|0);
 HEAP32[$149>>2] = $contactBuffer;
 $150 = (($callback) + 8|0);
 HEAP32[$150>>2] = $transform1;
 $151 = (($callback) + 12|0);
 HEAP32[$151>>2] = $meshCapsule;
 $152 = (($callback) + 16|0);
 HEAPF32[$152>>2] = $41;
 $153 = (($callback) + 20|0);
 HEAPF32[$153>>2] = $147;
 $154 = (($callback) + 24|0);
 HEAPF32[$154>>2] = $148;
 $155 = (($callback) + 28|0);
 HEAP32[$155>>2] = $hfUtil;
 $156 = Math_fround(HEAPF32[$21>>2]);
 $157 = Math_fround($41 + $156);
 $158 = (($bounds) + 12|0);
 HEAPF32[$158>>2] = $157;
 $159 = (($bounds) + 16|0);
 HEAPF32[$159>>2] = $41;
 $160 = (($bounds) + 20|0);
 HEAPF32[$160>>2] = $41;
 $161 = Math_fround(-$157);
 $162 = Math_fround(-$41);
 HEAPF32[$bounds>>2] = $161;
 $163 = (($bounds) + 4|0);
 HEAPF32[$163>>2] = $162;
 $164 = (($bounds) + 8|0);
 HEAPF32[$164>>2] = $162;
 $165 = Math_fround(HEAPF32[$transform1>>2]);
 $166 = Math_fround(-$165);
 $167 = Math_fround(HEAPF32[$60>>2]);
 $168 = Math_fround(-$167);
 $169 = Math_fround(HEAPF32[$64>>2]);
 $170 = Math_fround(-$169);
 $171 = Math_fround(HEAPF32[$54>>2]);
 $172 = Math_fround(HEAPF32[$26>>2]);
 $173 = Math_fround(HEAPF32[$42>>2]);
 $174 = Math_fround($172 - $173);
 $175 = Math_fround(HEAPF32[$29>>2]);
 $176 = Math_fround(HEAPF32[$45>>2]);
 $177 = Math_fround($175 - $176);
 $178 = Math_fround(HEAPF32[$32>>2]);
 $179 = Math_fround(HEAPF32[$48>>2]);
 $180 = Math_fround($178 - $179);
 $181 = Math_fround($174 * Math_fround(2.0));
 $182 = Math_fround($177 * Math_fround(2.0));
 $183 = Math_fround($180 * Math_fround(2.0));
 $184 = Math_fround($171 * $171);
 $185 = Math_fround($184 + Math_fround(-0.5));
 $186 = Math_fround($181 * $166);
 $187 = Math_fround($182 * $168);
 $188 = Math_fround($186 + $187);
 $189 = Math_fround($183 * $170);
 $190 = Math_fround($188 + $189);
 $191 = Math_fround($185 * $181);
 $192 = Math_fround($183 * $168);
 $193 = Math_fround($182 * $170);
 $194 = Math_fround($192 - $193);
 $195 = Math_fround($171 * $194);
 $196 = Math_fround($191 + $195);
 $197 = Math_fround($190 * $166);
 $198 = Math_fround($197 + $196);
 $199 = Math_fround($185 * $182);
 $200 = Math_fround($181 * $170);
 $201 = Math_fround($183 * $166);
 $202 = Math_fround($200 - $201);
 $203 = Math_fround($171 * $202);
 $204 = Math_fround($199 + $203);
 $205 = Math_fround($190 * $168);
 $206 = Math_fround($205 + $204);
 $207 = Math_fround($185 * $183);
 $208 = Math_fround($182 * $166);
 $209 = Math_fround($181 * $168);
 $210 = Math_fround($208 - $209);
 $211 = Math_fround($171 * $210);
 $212 = Math_fround($207 + $211);
 $213 = Math_fround($190 * $170);
 $214 = Math_fround($212 + $213);
 $215 = Math_fround(HEAPF32[$transform0>>2]);
 $216 = Math_fround($171 * $215);
 $217 = Math_fround(HEAPF32[$4>>2]);
 $218 = Math_fround($217 * $166);
 $219 = Math_fround($216 + $218);
 $220 = Math_fround(HEAPF32[$11>>2]);
 $221 = Math_fround($220 * $168);
 $222 = Math_fround($219 + $221);
 $223 = Math_fround(HEAPF32[$14>>2]);
 $224 = Math_fround($223 * $170);
 $225 = Math_fround($222 - $224);
 $226 = Math_fround($171 * $223);
 $227 = Math_fround($217 * $168);
 $228 = Math_fround($227 + $226);
 $229 = Math_fround($215 * $170);
 $230 = Math_fround($229 + $228);
 $231 = Math_fround($220 * $166);
 $232 = Math_fround($230 - $231);
 $233 = Math_fround($171 * $220);
 $234 = Math_fround($217 * $170);
 $235 = Math_fround($234 + $233);
 $236 = Math_fround($223 * $166);
 $237 = Math_fround($236 + $235);
 $238 = Math_fround($215 * $168);
 $239 = Math_fround($237 - $238);
 $240 = Math_fround($171 * $217);
 $241 = Math_fround($215 * $166);
 $242 = Math_fround($240 - $241);
 $243 = Math_fround($223 * $168);
 $244 = Math_fround($242 - $243);
 $245 = Math_fround($220 * $170);
 $246 = Math_fround($244 - $245);
 HEAPF32[$1>>2] = $225;
 $247 = (($1) + 4|0);
 HEAPF32[$247>>2] = $232;
 $248 = (($1) + 8|0);
 HEAPF32[$248>>2] = $239;
 $249 = (($1) + 12|0);
 HEAPF32[$249>>2] = $246;
 $250 = (($1) + 16|0);
 HEAPF32[$250>>2] = $198;
 $251 = (($1) + 20|0);
 HEAPF32[$251>>2] = $206;
 $252 = (($1) + 24|0);
 HEAPF32[$252>>2] = $214;
 __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($0,$1,$bounds);
 $253 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$bounds>>2] = $253;
 $254 = (($0) + 4|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 HEAPF32[$163>>2] = $255;
 $256 = (($0) + 8|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 HEAPF32[$164>>2] = $257;
 $258 = (($0) + 12|0);
 $259 = Math_fround(HEAPF32[$258>>2]);
 HEAPF32[$158>>2] = $259;
 $260 = (($0) + 16|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 HEAPF32[$159>>2] = $261;
 $262 = (($0) + 20|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 HEAPF32[$160>>2] = $263;
 (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$transform1,$bounds,0,$callback)|0);
 $264 = (($contactBuffer) + 4096|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = ($265|0)!=(0);
 STACKTOP = sp;return ($266|0);
}
function __ZN43CapsuleHeightfieldContactGenerationCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN43CapsuleHeightfieldContactGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN43CapsuleHeightfieldContactGenerationCallback7onEventEjPj($this,$nb,$indices) {
 $this = $this|0;
 $nb = $nb|0;
 $indices = $indices|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $a$02 = 0, $adjInds = 0, $adjTri = 0, $cache = 0, $currentTriangle = 0, $exitcond = 0, $i$04 = 0, $inds$05 = 0, $inds$1$lcssa = 0, $inds$13 = 0, $nbTrigs$06 = 0, $scevgep$sum = 0, $scevgep10 = 0, $triFlags$01 = 0;
 var $triFlags$2 = 0, $vertIndices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 960|0;
 $cache = sp + 96|0;
 $vertIndices = sp;
 $currentTriangle = sp + 12|0;
 $adjInds = sp + 48|0;
 $adjTri = sp + 60|0;
 $0 = (($cache) + 848|0);
 HEAP32[$0>>2] = 0;
 $1 = (($nb) + 15)|0;
 $2 = $1 >>> 4;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 4|0);
 $5 = (($this) + 28|0);
 $6 = (($this) + 8|0);
 $7 = (($currentTriangle) + 12|0);
 $8 = (($currentTriangle) + 16|0);
 $9 = (($currentTriangle) + 4|0);
 $10 = (($currentTriangle) + 20|0);
 $11 = (($currentTriangle) + 8|0);
 $12 = (($currentTriangle) + 24|0);
 $13 = (($currentTriangle) + 28|0);
 $14 = (($currentTriangle) + 32|0);
 $15 = (($adjTri) + 12|0);
 $16 = (($adjTri) + 16|0);
 $17 = (($adjTri) + 4|0);
 $18 = (($adjTri) + 20|0);
 $19 = (($adjTri) + 8|0);
 $20 = (($adjTri) + 24|0);
 $21 = (($adjTri) + 28|0);
 $22 = (($adjTri) + 32|0);
 $23 = (($vertIndices) + 4|0);
 $24 = (($vertIndices) + 8|0);
 $i$04 = 0;$inds$05 = $indices;$nbTrigs$06 = $nb;
 while(1) {
  HEAP32[$0>>2] = 0;
  $25 = ($nbTrigs$06>>>0)<(16);
  $26 = $25 ? $nbTrigs$06 : 16;
  $27 = (($nbTrigs$06) - ($26))|0;
  $28 = ($26|0)==(0);
  if ($28) {
   $inds$1$lcssa = $inds$05;
  } else {
   $29 = ($nbTrigs$06>>>0)<(16);
   $$in = $26;$inds$13 = $inds$05;
   while(1) {
    $30 = (($$in) + -1)|0;
    $31 = (($inds$13) + 4|0);
    $32 = HEAP32[$inds$13>>2]|0;
    $33 = HEAP32[$5>>2]|0;
    $34 = HEAP32[$6>>2]|0;
    (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($33,$34,$currentTriangle,$vertIndices,$adjInds,$32,0,0)|0);
    $35 = Math_fround(HEAPF32[$7>>2]);
    $36 = Math_fround(HEAPF32[$currentTriangle>>2]);
    $37 = Math_fround($35 - $36);
    $38 = Math_fround(HEAPF32[$8>>2]);
    $39 = Math_fround(HEAPF32[$9>>2]);
    $40 = Math_fround($38 - $39);
    $41 = Math_fround(HEAPF32[$10>>2]);
    $42 = Math_fround(HEAPF32[$11>>2]);
    $43 = Math_fround($41 - $42);
    $44 = Math_fround(HEAPF32[$12>>2]);
    $45 = Math_fround($44 - $36);
    $46 = Math_fround(HEAPF32[$13>>2]);
    $47 = Math_fround($46 - $39);
    $48 = Math_fround(HEAPF32[$14>>2]);
    $49 = Math_fround($48 - $42);
    $50 = Math_fround($40 * $49);
    $51 = Math_fround($43 * $47);
    $52 = Math_fround($50 - $51);
    $53 = Math_fround($43 * $45);
    $54 = Math_fround($37 * $49);
    $55 = Math_fround($53 - $54);
    $56 = Math_fround($37 * $47);
    $57 = Math_fround($40 * $45);
    $58 = Math_fround($56 - $57);
    $59 = Math_fround($52 * $52);
    $60 = Math_fround($55 * $55);
    $61 = Math_fround($59 + $60);
    $62 = Math_fround($58 * $58);
    $63 = Math_fround($62 + $61);
    $64 = (Math_fround(Math_sqrt((Math_fround($63)))));
    $65 = $64 > Math_fround(0.0);
    if ($65) {
     $66 = Math_fround(Math_fround(1.0) / $64);
     $67 = Math_fround($52 * $66);
     $68 = Math_fround($55 * $66);
     $69 = Math_fround($58 * $66);
     $130 = $67;$133 = $68;$137 = $69;
    } else {
     $130 = $52;$133 = $55;$137 = $58;
    }
    $a$02 = 0;$triFlags$01 = 0;
    while(1) {
     $70 = (($adjInds) + ($a$02<<2)|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(-1);
     if ($72) {
      $145 = (($a$02) + 3)|0;
      $146 = 1 << $145;
      $147 = $triFlags$01&255;
      $148 = $146 | $147;
      $149 = $148&255;
      $triFlags$2 = $149;
     } else {
      $73 = HEAP32[$5>>2]|0;
      $74 = HEAP32[$6>>2]|0;
      (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($73,$74,$adjTri,0,0,$71,0,0)|0);
      $75 = Math_fround(HEAPF32[$15>>2]);
      $76 = Math_fround(HEAPF32[$adjTri>>2]);
      $77 = Math_fround($75 - $76);
      $78 = Math_fround(HEAPF32[$16>>2]);
      $79 = Math_fround(HEAPF32[$17>>2]);
      $80 = Math_fround($78 - $79);
      $81 = Math_fround(HEAPF32[$18>>2]);
      $82 = Math_fround(HEAPF32[$19>>2]);
      $83 = Math_fround($81 - $82);
      $84 = Math_fround(HEAPF32[$20>>2]);
      $85 = Math_fround($84 - $76);
      $86 = Math_fround(HEAPF32[$21>>2]);
      $87 = Math_fround($86 - $79);
      $88 = Math_fround(HEAPF32[$22>>2]);
      $89 = Math_fround($88 - $82);
      $90 = Math_fround($80 * $89);
      $91 = Math_fround($83 * $87);
      $92 = Math_fround($90 - $91);
      $93 = Math_fround($83 * $85);
      $94 = Math_fround($77 * $89);
      $95 = Math_fround($93 - $94);
      $96 = Math_fround($77 * $87);
      $97 = Math_fround($80 * $85);
      $98 = Math_fround($96 - $97);
      $99 = (548776 + ($a$02)|0);
      $100 = HEAP8[$99>>0]|0;
      $101 = $100&255;
      $102 = (($currentTriangle) + (($101*12)|0)|0);
      $103 = Math_fround(HEAPF32[$102>>2]);
      $104 = Math_fround($103 - $76);
      $105 = ((($currentTriangle) + (($101*12)|0)|0) + 4|0);
      $106 = Math_fround(HEAPF32[$105>>2]);
      $107 = Math_fround($106 - $79);
      $108 = ((($currentTriangle) + (($101*12)|0)|0) + 8|0);
      $109 = Math_fround(HEAPF32[$108>>2]);
      $110 = Math_fround($109 - $82);
      $111 = Math_fround($92 * $104);
      $112 = Math_fround($95 * $107);
      $113 = Math_fround($111 + $112);
      $114 = Math_fround($98 * $110);
      $115 = Math_fround($113 + $114);
      $116 = $115 < Math_fround(0.0);
      if ($116) {
       $117 = Math_fround($92 * $92);
       $118 = Math_fround($95 * $95);
       $119 = Math_fround($117 + $118);
       $120 = Math_fround($98 * $98);
       $121 = Math_fround($120 + $119);
       $122 = (Math_fround(Math_sqrt((Math_fround($121)))));
       $123 = $122 > Math_fround(0.0);
       if ($123) {
        $124 = Math_fround(Math_fround(1.0) / $122);
        $125 = Math_fround($92 * $124);
        $126 = Math_fround($95 * $124);
        $127 = Math_fround($98 * $124);
        $129 = $125;$132 = $126;$136 = $127;
       } else {
        $129 = $92;$132 = $95;$136 = $98;
       }
       $128 = Math_fround($130 * $129);
       $131 = Math_fround($133 * $132);
       $134 = Math_fround($131 + $128);
       $135 = Math_fround($137 * $136);
       $138 = Math_fround($135 + $134);
       $139 = $138 < Math_fround(0.999000012874603271484);
       if ($139) {
        $140 = (($a$02) + 3)|0;
        $141 = 1 << $140;
        $142 = $triFlags$01&255;
        $143 = $141 | $142;
        $144 = $143&255;
        $triFlags$2 = $144;
       } else {
        $triFlags$2 = $triFlags$01;
       }
      } else {
       $triFlags$2 = $triFlags$01;
      }
     }
     $150 = (($a$02) + 1)|0;
     $exitcond = ($150|0)==(3);
     if ($exitcond) {
      break;
     } else {
      $a$02 = $150;$triFlags$01 = $triFlags$2;
     }
    }
    $151 = HEAP32[$0>>2]|0;
    $152 = (($151) + 1)|0;
    HEAP32[$0>>2] = $152;
    $153 = ($151*3)|0;
    $154 = Math_fround(HEAPF32[$currentTriangle>>2]);
    $155 = (($cache) + (($153*12)|0)|0);
    HEAPF32[$155>>2] = $154;
    $156 = Math_fround(HEAPF32[$9>>2]);
    $157 = ((($cache) + (($153*12)|0)|0) + 4|0);
    HEAPF32[$157>>2] = $156;
    $158 = Math_fround(HEAPF32[$11>>2]);
    $159 = ((($cache) + (($153*12)|0)|0) + 8|0);
    HEAPF32[$159>>2] = $158;
    $160 = (($153) + 1)|0;
    $161 = Math_fround(HEAPF32[$7>>2]);
    $162 = (($cache) + (($160*12)|0)|0);
    HEAPF32[$162>>2] = $161;
    $163 = Math_fround(HEAPF32[$8>>2]);
    $164 = ((($cache) + (($160*12)|0)|0) + 4|0);
    HEAPF32[$164>>2] = $163;
    $165 = Math_fround(HEAPF32[$10>>2]);
    $166 = ((($cache) + (($160*12)|0)|0) + 8|0);
    HEAPF32[$166>>2] = $165;
    $167 = (($153) + 2)|0;
    $168 = Math_fround(HEAPF32[$12>>2]);
    $169 = (($cache) + (($167*12)|0)|0);
    HEAPF32[$169>>2] = $168;
    $170 = Math_fround(HEAPF32[$13>>2]);
    $171 = ((($cache) + (($167*12)|0)|0) + 4|0);
    HEAPF32[$171>>2] = $170;
    $172 = Math_fround(HEAPF32[$14>>2]);
    $173 = ((($cache) + (($167*12)|0)|0) + 8|0);
    HEAPF32[$173>>2] = $172;
    $174 = HEAP32[$vertIndices>>2]|0;
    $175 = ((($cache) + ($153<<2)|0) + 576|0);
    HEAP32[$175>>2] = $174;
    $176 = HEAP32[$23>>2]|0;
    $177 = ((($cache) + ($160<<2)|0) + 576|0);
    HEAP32[$177>>2] = $176;
    $178 = HEAP32[$24>>2]|0;
    $179 = ((($cache) + ($167<<2)|0) + 576|0);
    HEAP32[$179>>2] = $178;
    $180 = ((($cache) + ($151<<2)|0) + 768|0);
    HEAP32[$180>>2] = $32;
    $181 = ((($cache) + ($151)|0) + 832|0);
    HEAP8[$181>>0] = $triFlags$2;
    $182 = ($30|0)==(0);
    if ($182) {
     break;
    } else {
     $$in = $30;$inds$13 = $31;
    }
   }
   $scevgep$sum = $29 ? $nbTrigs$06 : 16;
   $scevgep10 = (($inds$05) + ($scevgep$sum<<2)|0);
   $inds$1$lcssa = $scevgep10;
  }
  (__ZN18ContactCapsuleMesh20processTriangleCacheILj16EEEbRN5physx2Gu13TriangleCacheIXT_EEE($4,$cache)|0);
  $183 = (($i$04) + 1)|0;
  $184 = ($183>>>0)<($2>>>0);
  if ($184) {
   $i$04 = $183;$inds$05 = $inds$1$lcssa;$nbTrigs$06 = $27;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN18ContactCapsuleMesh20processTriangleCacheILj16EEEbRN5physx2Gu13TriangleCacheIXT_EEE($this,$cache) {
 $this = $this|0;
 $cache = $cache|0;
 var $$in = 0, $$pre$i = Math_fround(0), $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre19$i = Math_fround(0), $$pre20$i = Math_fround(0), $$pre21$i = Math_fround(0), $$pre22$i = Math_fround(0), $$pre23$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0);
 var $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0;
 var $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0);
 var $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0;
 var $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0);
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0;
 var $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0);
 var $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0);
 var $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0);
 var $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0;
 var $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0);
 var $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = 0;
 var $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0);
 var $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = 0, $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0;
 var $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0);
 var $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = 0;
 var $487 = Math_fround(0), $488 = 0, $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0);
 var $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = Math_fround(0), $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = Math_fround(0), $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0);
 var $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = 0.0, $547 = 0, $548 = 0.0, $549 = 0, $55 = 0, $550 = 0.0, $551 = 0, $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = 0, $558 = Math_fround(0);
 var $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = 0;
 var $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = Math_fround(0), $593 = 0, $594 = Math_fround(0);
 var $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $600 = 0, $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = 0, $605 = 0, $606 = Math_fround(0), $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = Math_fround(0), $610 = 0, $611 = Math_fround(0);
 var $612 = 0, $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0;
 var $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = 0, $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0);
 var $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = 0, $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0);
 var $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0);
 var $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = 0, $697 = 0, $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0);
 var $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0;
 var $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $SepAxis$i = 0;
 var $bc = 0, $be = 0, $dist$i3$i = 0, $edgeFlags$012 = 0, $exitcond$i$i = 0, $exitcond$i7$i = 0, $fabsf$i$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i$i = Math_fround(0), $fabsf$i$i2$i$i$i = Math_fround(0), $i$01$i$i = 0, $i$01$i6$i = 0, $i$017$i$i = 0, $ip$i4$i = 0, $meshAbsPose = 0, $normal$i = 0, $or$cond$i = 0, $or$cond$i1 = 0, $s0$i1$i = 0, $s1$i2$i = 0, $t$i = 0;
 var $triInds$013 = 0, $triVerts = 0, $u$i = 0, $v$i = 0, $verts$014 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $s0$i1$i = sp + 208|0;
 $s1$i2$i = sp + 196|0;
 $dist$i3$i = sp + 192|0;
 $ip$i4$i = sp + 180|0;
 $0 = sp + 168|0;
 $t$i = sp + 164|0;
 $u$i = sp + 160|0;
 $v$i = sp + 156|0;
 $1 = sp + 144|0;
 $2 = sp + 96|0;
 $normal$i = sp + 84|0;
 $SepAxis$i = sp + 72|0;
 $meshAbsPose = sp + 24|0;
 $bc = sp + 12|0;
 $be = sp;
 $triVerts = sp + 108|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 + $5);
 $7 = (($4) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 + $8);
 $10 = (($4) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 + $11);
 $13 = (($4) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($6 * $14);
 $16 = Math_fround($9 * $14);
 $17 = Math_fround($14 * $12);
 $18 = Math_fround($5 * $6);
 $19 = Math_fround($5 * $9);
 $20 = Math_fround($5 * $12);
 $21 = Math_fround($8 * $9);
 $22 = Math_fround($8 * $12);
 $23 = Math_fround($11 * $12);
 $24 = Math_fround(Math_fround(1.0) - $21);
 $25 = Math_fround($24 - $23);
 HEAPF32[$meshAbsPose>>2] = $25;
 $26 = Math_fround($19 + $17);
 $27 = (($meshAbsPose) + 4|0);
 HEAPF32[$27>>2] = $26;
 $28 = Math_fround($20 - $16);
 $29 = (($meshAbsPose) + 8|0);
 HEAPF32[$29>>2] = $28;
 $30 = Math_fround($19 - $17);
 $31 = (($meshAbsPose) + 12|0);
 HEAPF32[$31>>2] = $30;
 $32 = Math_fround(Math_fround(1.0) - $18);
 $33 = Math_fround($32 - $23);
 $34 = (($meshAbsPose) + 16|0);
 HEAPF32[$34>>2] = $33;
 $35 = Math_fround($22 + $15);
 $36 = (($meshAbsPose) + 20|0);
 HEAPF32[$36>>2] = $35;
 $37 = Math_fround($20 + $16);
 $38 = (($meshAbsPose) + 24|0);
 HEAPF32[$38>>2] = $37;
 $39 = Math_fround($22 - $15);
 $40 = (($meshAbsPose) + 28|0);
 HEAPF32[$40>>2] = $39;
 $41 = Math_fround($32 - $21);
 $42 = (($meshAbsPose) + 32|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($meshAbsPose) + 36|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($meshAbsPose) + 40|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($meshAbsPose) + 44|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($4) + 16|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$43>>2] = $47;
 $48 = (($4) + 20|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$44>>2] = $49;
 $50 = (($4) + 24|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$45>>2] = $51;
 $52 = (($this) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($53) + 12|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($54 + $56);
 $58 = (($53) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($53) + 16|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($59 + $61);
 $63 = (($53) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($53) + 20|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($64 + $66);
 $68 = Math_fround($57 * Math_fround(0.5));
 $69 = Math_fround($62 * Math_fround(0.5));
 $70 = Math_fround($67 * Math_fround(0.5));
 HEAPF32[$bc>>2] = $68;
 $71 = (($bc) + 4|0);
 HEAPF32[$71>>2] = $69;
 $72 = (($bc) + 8|0);
 HEAPF32[$72>>2] = $70;
 $73 = Math_fround(HEAPF32[$53>>2]);
 $74 = Math_fround(HEAPF32[$55>>2]);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround(HEAPF32[$58>>2]);
 $77 = Math_fround(HEAPF32[$60>>2]);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround(HEAPF32[$63>>2]);
 $80 = Math_fround(HEAPF32[$65>>2]);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($75 * Math_fround(0.5));
 $83 = Math_fround($78 * Math_fround(0.5));
 $84 = Math_fround($81 * Math_fround(0.5));
 $85 = (($be) + 4|0);
 $86 = (($be) + 8|0);
 $87 = (Math_fround(Math_abs((Math_fround($82)))));
 $88 = (($this) + 12|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($87 + $89);
 HEAPF32[$be>>2] = $90;
 $91 = (Math_fround(Math_abs((Math_fround($83)))));
 $92 = Math_fround($91 + $89);
 HEAPF32[$85>>2] = $92;
 $93 = (Math_fround(Math_abs((Math_fround($84)))));
 $94 = Math_fround($93 + $89);
 HEAPF32[$86>>2] = $94;
 $95 = (($cache) + 848|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96|0)==(0);
 if ($97) {
  STACKTOP = sp;return 1;
 }
 $98 = (($cache) + 832|0);
 $99 = (($cache) + 768|0);
 $100 = (($triVerts) + 4|0);
 $101 = (($triVerts) + 8|0);
 $102 = (($triVerts) + 12|0);
 $103 = (($triVerts) + 16|0);
 $104 = (($triVerts) + 20|0);
 $105 = (($triVerts) + 24|0);
 $106 = (($triVerts) + 28|0);
 $107 = (($triVerts) + 32|0);
 $108 = (($this) + 20|0);
 $109 = (($this) + 16|0);
 $110 = (($triVerts) + 12|0);
 $111 = (($1) + 4|0);
 $112 = (($1) + 8|0);
 $113 = (($triVerts) + 24|0);
 $114 = (($2) + 4|0);
 $115 = (($2) + 8|0);
 $116 = (($s0$i1$i) + 4|0);
 $117 = (($s0$i1$i) + 8|0);
 $118 = (($normal$i) + 4|0);
 $119 = (($normal$i) + 8|0);
 $120 = (($s0$i1$i) + 4|0);
 $121 = (($s0$i1$i) + 8|0);
 $122 = (($s1$i2$i) + 4|0);
 $123 = (($s1$i2$i) + 8|0);
 $124 = (($ip$i4$i) + 4|0);
 $125 = (($ip$i4$i) + 8|0);
 $126 = (($SepAxis$i) + 4|0);
 $127 = (($SepAxis$i) + 8|0);
 $128 = (($s0$i1$i) + 4|0);
 $129 = (($s0$i1$i) + 8|0);
 $130 = (($s1$i2$i) + 4|0);
 $131 = (($s1$i2$i) + 8|0);
 $132 = (($0) + 4|0);
 $133 = (($0) + 8|0);
 $134 = (($ip$i4$i) + 4|0);
 $135 = (($ip$i4$i) + 8|0);
 $$in = $96;$edgeFlags$012 = $98;$triInds$013 = $99;$verts$014 = $cache;
 while(1) {
  $136 = (($$in) + -1)|0;
  $137 = HEAP32[$triInds$013>>2]|0;
  $138 = (($triInds$013) + 4|0);
  $139 = Math_fround(HEAPF32[$verts$014>>2]);
  HEAPF32[$triVerts>>2] = $139;
  $140 = (($verts$014) + 4|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  HEAPF32[$100>>2] = $141;
  $142 = (($verts$014) + 8|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  HEAPF32[$101>>2] = $143;
  $144 = (($verts$014) + 12|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  HEAPF32[$102>>2] = $145;
  $146 = (($verts$014) + 16|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  HEAPF32[$103>>2] = $147;
  $148 = (($verts$014) + 20|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  HEAPF32[$104>>2] = $149;
  $150 = (($verts$014) + 24|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  HEAPF32[$105>>2] = $151;
  $152 = (($verts$014) + 28|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  HEAPF32[$106>>2] = $153;
  $154 = (($verts$014) + 32|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  HEAPF32[$107>>2] = $155;
  $156 = (($verts$014) + 36|0);
  $157 = (($edgeFlags$012) + 1|0);
  $158 = HEAP8[$edgeFlags$012>>0]|0;
  $159 = (__ZN5physx2Gu20intersectTriangleBoxERKNS_6PxVec3ES3_S3_S3_S3_($bc,$be,$triVerts,$102,$105)|0);
  $160 = ($159|0)==(0);
  L6: do {
   if (!($160)) {
    $162 = HEAP32[$52>>2]|0;
    $163 = Math_fround(HEAPF32[$108>>2]);
    $164 = HEAP32[$this>>2]|0;
    $165 = Math_fround(HEAPF32[$109>>2]);
    $166 = Math_fround(HEAPF32[$110>>2]);
    $167 = Math_fround(HEAPF32[$triVerts>>2]);
    $168 = Math_fround($166 - $167);
    $169 = Math_fround(HEAPF32[$103>>2]);
    $170 = Math_fround(HEAPF32[$100>>2]);
    $171 = Math_fround($169 - $170);
    $172 = Math_fround(HEAPF32[$104>>2]);
    $173 = Math_fround(HEAPF32[$101>>2]);
    $174 = Math_fround($172 - $173);
    HEAPF32[$1>>2] = $168;
    HEAPF32[$111>>2] = $171;
    HEAPF32[$112>>2] = $174;
    $175 = Math_fround(HEAPF32[$113>>2]);
    $176 = Math_fround($175 - $167);
    $177 = Math_fround(HEAPF32[$106>>2]);
    $178 = Math_fround($177 - $170);
    $179 = Math_fround(HEAPF32[$107>>2]);
    $180 = Math_fround($179 - $173);
    HEAPF32[$2>>2] = $176;
    HEAPF32[$114>>2] = $178;
    HEAPF32[$115>>2] = $180;
    $181 = (($162) + 12|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = Math_fround(HEAPF32[$162>>2]);
    $184 = Math_fround($182 - $183);
    $185 = (($162) + 16|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = (($162) + 4|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = Math_fround($186 - $188);
    $190 = (($162) + 20|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = (($162) + 8|0);
    $193 = Math_fround(HEAPF32[$192>>2]);
    $194 = Math_fround($191 - $193);
    HEAPF32[$s0$i1$i>>2] = $184;
    HEAPF32[$116>>2] = $189;
    HEAPF32[$117>>2] = $194;
    $195 = (Math_fround(__ZN5physx2Gu30distanceSegmentTriangleSquaredERKNS_6PxVec3ES3_S3_S3_S3_PfS4_S4_($162,$s0$i1$i,$triVerts,$1,$2,$t$i,$u$i,$v$i)));
    $196 = Math_fround($163 + $165);
    $197 = Math_fround($196 * $196);
    $198 = !($195 >= $197);
    if ($198) {
     $199 = Math_fround(HEAPF32[$110>>2]);
     $200 = Math_fround(HEAPF32[$triVerts>>2]);
     $201 = Math_fround($199 - $200);
     $202 = Math_fround(HEAPF32[$103>>2]);
     $203 = Math_fround(HEAPF32[$100>>2]);
     $204 = Math_fround($202 - $203);
     $205 = Math_fround(HEAPF32[$104>>2]);
     $206 = Math_fround(HEAPF32[$101>>2]);
     $207 = Math_fround($205 - $206);
     $208 = Math_fround(HEAPF32[$113>>2]);
     $209 = Math_fround($208 - $200);
     $210 = Math_fround(HEAPF32[$106>>2]);
     $211 = Math_fround($210 - $203);
     $212 = Math_fround(HEAPF32[$107>>2]);
     $213 = Math_fround($212 - $206);
     $214 = Math_fround($204 * $213);
     $215 = Math_fround($207 * $211);
     $216 = Math_fround($214 - $215);
     $217 = Math_fround($207 * $209);
     $218 = Math_fround($201 * $213);
     $219 = Math_fround($217 - $218);
     $220 = Math_fround($201 * $211);
     $221 = Math_fround($204 * $209);
     $222 = Math_fround($220 - $221);
     $223 = Math_fround($216 * $216);
     $224 = Math_fround($219 * $219);
     $225 = Math_fround($223 + $224);
     $226 = Math_fround($222 * $222);
     $227 = Math_fround($226 + $225);
     $228 = $227 > Math_fround(0.0);
     if ($228) {
      $229 = (Math_fround(Math_sqrt((Math_fround($227)))));
      $230 = Math_fround(Math_fround(1.0) / $229);
      $231 = Math_fround($216 * $230);
      $232 = Math_fround($219 * $230);
      $233 = Math_fround($222 * $230);
      $235 = $231;$237 = $232;$240 = $233;
     } else {
      $235 = Math_fround(0.0);$237 = Math_fround(0.0);$240 = Math_fround(0.0);
     }
     $234 = Math_fround($200 * $235);
     $236 = Math_fround($203 * $237);
     $238 = Math_fround($236 + $234);
     $239 = Math_fround($206 * $240);
     $241 = Math_fround($239 + $238);
     $242 = Math_fround(HEAPF32[$162>>2]);
     $243 = Math_fround(HEAPF32[$181>>2]);
     $244 = Math_fround($242 + $243);
     $245 = Math_fround(HEAPF32[$187>>2]);
     $246 = Math_fround(HEAPF32[$185>>2]);
     $247 = Math_fround($245 + $246);
     $248 = Math_fround(HEAPF32[$192>>2]);
     $249 = Math_fround(HEAPF32[$190>>2]);
     $250 = Math_fround($248 + $249);
     $251 = Math_fround($244 * Math_fround(0.5));
     $252 = Math_fround($247 * Math_fround(0.5));
     $253 = Math_fround($250 * Math_fround(0.5));
     $254 = Math_fround($235 * $251);
     $255 = Math_fround($237 * $252);
     $256 = Math_fround($254 + $255);
     $257 = Math_fround($240 * $253);
     $258 = Math_fround($256 + $257);
     $259 = Math_fround($258 - $241);
     $260 = $259 < Math_fround(0.0);
     if (!($260)) {
      $261 = $195 > Math_fround(0.00100000004749745130539);
      if ($261) {
       $262 = Math_fround(HEAPF32[$u$i>>2]);
       $263 = Math_fround(HEAPF32[$v$i>>2]);
       $264 = (__ZN5physx2Gu12selectNormalEhff($158,$262,$263)|0);
       if ($264) {
        HEAPF32[$normal$i>>2] = $235;
        HEAPF32[$118>>2] = $237;
        HEAPF32[$119>>2] = $240;
        $$pre$i = Math_fround(HEAPF32[$162>>2]);
        $$pre19$i = Math_fround(HEAPF32[$187>>2]);
        $$pre20$i = Math_fround(HEAPF32[$192>>2]);
        $$pre21$i = Math_fround(HEAPF32[$181>>2]);
        $$pre22$i = Math_fround(HEAPF32[$185>>2]);
        $$pre23$i = Math_fround(HEAPF32[$190>>2]);
        $323 = $$pre$i;$324 = $$pre19$i;$325 = $$pre20$i;$326 = $$pre21$i;$327 = $$pre22$i;$328 = $$pre23$i;
       } else {
        $265 = Math_fround(HEAPF32[$u$i>>2]);
        $266 = Math_fround(HEAPF32[$v$i>>2]);
        $267 = Math_fround(Math_fround(1.0) - $265);
        $268 = Math_fround($267 - $266);
        $269 = Math_fround(HEAPF32[$triVerts>>2]);
        $270 = Math_fround($268 * $269);
        $271 = Math_fround(HEAPF32[$110>>2]);
        $272 = Math_fround($265 * $271);
        $273 = Math_fround($270 + $272);
        $274 = Math_fround(HEAPF32[$113>>2]);
        $275 = Math_fround($266 * $274);
        $276 = Math_fround($273 + $275);
        $277 = Math_fround(HEAPF32[$100>>2]);
        $278 = Math_fround($268 * $277);
        $279 = Math_fround(HEAPF32[$103>>2]);
        $280 = Math_fround($265 * $279);
        $281 = Math_fround($278 + $280);
        $282 = Math_fround(HEAPF32[$106>>2]);
        $283 = Math_fround($266 * $282);
        $284 = Math_fround($281 + $283);
        $285 = Math_fround(HEAPF32[$101>>2]);
        $286 = Math_fround($268 * $285);
        $287 = Math_fround(HEAPF32[$104>>2]);
        $288 = Math_fround($265 * $287);
        $289 = Math_fround($286 + $288);
        $290 = Math_fround(HEAPF32[$107>>2]);
        $291 = Math_fround($266 * $290);
        $292 = Math_fround($289 + $291);
        $293 = Math_fround(HEAPF32[$t$i>>2]);
        $294 = Math_fround(HEAPF32[$181>>2]);
        $295 = Math_fround(HEAPF32[$162>>2]);
        $296 = Math_fround($294 - $295);
        $297 = Math_fround(HEAPF32[$185>>2]);
        $298 = Math_fround(HEAPF32[$187>>2]);
        $299 = Math_fround($297 - $298);
        $300 = Math_fround(HEAPF32[$190>>2]);
        $301 = Math_fround(HEAPF32[$192>>2]);
        $302 = Math_fround($300 - $301);
        $303 = Math_fround($293 * $296);
        $304 = Math_fround($293 * $299);
        $305 = Math_fround($293 * $302);
        $306 = Math_fround($295 + $303);
        $307 = Math_fround($298 + $304);
        $308 = Math_fround($301 + $305);
        $309 = Math_fround($306 - $276);
        $310 = Math_fround($307 - $284);
        $311 = Math_fround($308 - $292);
        HEAPF32[$normal$i>>2] = $309;
        HEAPF32[$118>>2] = $310;
        HEAPF32[$119>>2] = $311;
        $312 = Math_fround($309 * $309);
        $313 = Math_fround($310 * $310);
        $314 = Math_fround($312 + $313);
        $315 = Math_fround($311 * $311);
        $316 = Math_fround($314 + $315);
        $317 = (Math_fround(Math_sqrt((Math_fround($316)))));
        $318 = $317 == Math_fround(0.0);
        if ($318) {
         break;
        }
        $319 = Math_fround(Math_fround(1.0) / $317);
        $320 = Math_fround($309 * $319);
        $321 = Math_fround($310 * $319);
        $322 = Math_fround($311 * $319);
        HEAPF32[$normal$i>>2] = $320;
        HEAPF32[$118>>2] = $321;
        HEAPF32[$119>>2] = $322;
        $323 = $295;$324 = $298;$325 = $301;$326 = $294;$327 = $297;$328 = $300;
       }
       HEAPF32[$s0$i1$i>>2] = $323;
       HEAPF32[$120>>2] = $324;
       HEAPF32[$121>>2] = $325;
       HEAPF32[$s1$i2$i>>2] = $326;
       HEAPF32[$122>>2] = $327;
       HEAPF32[$123>>2] = $328;
       $329 = Math_fround($326 - $323);
       $330 = Math_fround($327 - $324);
       $331 = Math_fround($328 - $325);
       $332 = Math_fround($329 * $329);
       $333 = Math_fround($330 * $330);
       $334 = Math_fround($333 + $332);
       $335 = Math_fround($331 * $331);
       $336 = Math_fround($335 + $334);
       $337 = (Math_fround(Math_sqrt((Math_fround($336)))));
       $338 = $337 > Math_fround(0.0);
       if ($338) {
        $339 = Math_fround(Math_fround(0.00999999977648258209228) / $337);
        $340 = Math_fround($329 * $339);
        $341 = Math_fround($330 * $339);
        $342 = Math_fround($331 * $339);
        $343 = Math_fround($323 - $340);
        HEAPF32[$s0$i1$i>>2] = $343;
        $344 = Math_fround($324 - $341);
        HEAPF32[$120>>2] = $344;
        $345 = Math_fround($325 - $342);
        HEAPF32[$121>>2] = $345;
        $346 = Math_fround($326 + $340);
        HEAPF32[$s1$i2$i>>2] = $346;
        $347 = Math_fround($327 + $341);
        HEAPF32[$122>>2] = $347;
        $348 = Math_fround($328 + $342);
        HEAPF32[$123>>2] = $348;
       }
       $349 = (($164) + 4096|0);
       $i$01$i6$i = 0;
       while(1) {
        $350 = (($triVerts) + (($i$01$i6$i*12)|0)|0);
        $351 = (($i$01$i6$i) + 1)|0;
        $352 = $i$01$i6$i >>> 1;
        $353 = (($351) + ($352))|0;
        $354 = $353 & 3;
        $355 = (($triVerts) + (($354*12)|0)|0);
        $356 = (__ZN5physx2Gu17intersectEdgeEdgeERKNS_6PxVec3ES3_S3_S3_S3_RfRS1_($350,$355,$normal$i,$s0$i1$i,$s1$i2$i,$dist$i3$i,$ip$i4$i)|0);
        if ($356) {
         $357 = Math_fround(HEAPF32[$dist$i3$i>>2]);
         $358 = $357 < $196;
         if ($358) {
          $359 = Math_fround(HEAPF32[$ip$i4$i>>2]);
          $360 = Math_fround(HEAPF32[$meshAbsPose>>2]);
          $361 = Math_fround($359 * $360);
          $362 = Math_fround(HEAPF32[$27>>2]);
          $363 = Math_fround($359 * $362);
          $364 = Math_fround(HEAPF32[$29>>2]);
          $365 = Math_fround($359 * $364);
          $366 = Math_fround(HEAPF32[$124>>2]);
          $367 = Math_fround(HEAPF32[$31>>2]);
          $368 = Math_fround($366 * $367);
          $369 = Math_fround(HEAPF32[$34>>2]);
          $370 = Math_fround($366 * $369);
          $371 = Math_fround(HEAPF32[$36>>2]);
          $372 = Math_fround($366 * $371);
          $373 = Math_fround($361 + $368);
          $374 = Math_fround($363 + $370);
          $375 = Math_fround($365 + $372);
          $376 = Math_fround(HEAPF32[$125>>2]);
          $377 = Math_fround(HEAPF32[$38>>2]);
          $378 = Math_fround($376 * $377);
          $379 = Math_fround(HEAPF32[$40>>2]);
          $380 = Math_fround($376 * $379);
          $381 = Math_fround(HEAPF32[$42>>2]);
          $382 = Math_fround($376 * $381);
          $383 = Math_fround($373 + $378);
          $384 = Math_fround($374 + $380);
          $385 = Math_fround($375 + $382);
          $386 = Math_fround(HEAPF32[$43>>2]);
          $387 = Math_fround($383 + $386);
          $388 = Math_fround(HEAPF32[$44>>2]);
          $389 = Math_fround($384 + $388);
          $390 = Math_fround(HEAPF32[$45>>2]);
          $391 = Math_fround($385 + $390);
          HEAPF32[$ip$i4$i>>2] = $387;
          HEAPF32[$124>>2] = $389;
          HEAPF32[$125>>2] = $391;
          $392 = Math_fround(HEAPF32[$normal$i>>2]);
          $393 = Math_fround(HEAPF32[$118>>2]);
          $394 = Math_fround(HEAPF32[$119>>2]);
          $395 = HEAP32[$349>>2]|0;
          $396 = ($395>>>0)>(63);
          if (!($396)) {
           $397 = Math_fround($371 * $393);
           $398 = Math_fround($369 * $393);
           $399 = Math_fround($367 * $393);
           $400 = Math_fround($364 * $392);
           $401 = Math_fround($362 * $392);
           $402 = Math_fround($360 * $392);
           $403 = Math_fround($381 * $394);
           $404 = Math_fround($379 * $394);
           $405 = Math_fround($377 * $394);
           $406 = Math_fround($400 + $397);
           $407 = Math_fround($401 + $398);
           $408 = Math_fround($402 + $399);
           $409 = Math_fround($357 - $163);
           $410 = Math_fround($406 + $403);
           $411 = Math_fround($407 + $404);
           $412 = Math_fround($408 + $405);
           $413 = (($395) + 1)|0;
           HEAP32[$349>>2] = $413;
           $414 = (($164) + ($395<<6)|0);
           HEAPF32[$414>>2] = $412;
           $415 = ((($164) + ($395<<6)|0) + 4|0);
           HEAPF32[$415>>2] = $411;
           $416 = ((($164) + ($395<<6)|0) + 8|0);
           HEAPF32[$416>>2] = $410;
           $417 = ((($164) + ($395<<6)|0) + 16|0);
           HEAPF32[$417>>2] = $387;
           $418 = ((($164) + ($395<<6)|0) + 20|0);
           HEAPF32[$418>>2] = $389;
           $419 = ((($164) + ($395<<6)|0) + 24|0);
           HEAPF32[$419>>2] = $391;
           $420 = ((($164) + ($395<<6)|0) + 12|0);
           HEAPF32[$420>>2] = $409;
           $421 = ((($164) + ($395<<6)|0) + 48|0);
           HEAP32[$421>>2] = -1;
           $422 = ((($164) + ($395<<6)|0) + 52|0);
           HEAP32[$422>>2] = $137;
          }
         }
        }
        $exitcond$i7$i = ($351|0)==(3);
        if ($exitcond$i7$i) {
         break;
        } else {
         $i$01$i6$i = $351;
        }
       }
       __ZL21PxcGenerateVFContactsRKN5physx2Cm8Matrix34ERNS_2Gu13ContactBufferERKNS4_7SegmentEfPKNS_6PxVec3ERSB_jf($meshAbsPose,$164,$162,$163,$triVerts,$normal$i,$137,$165);
       break;
      }
      $423 = Math_fround($200 - $199);
      $424 = Math_fround($203 - $202);
      $425 = Math_fround($206 - $205);
      $426 = Math_fround($200 - $208);
      $427 = Math_fround($203 - $210);
      $428 = Math_fround($206 - $212);
      $429 = Math_fround($424 * $428);
      $430 = Math_fround($425 * $427);
      $431 = Math_fround($429 - $430);
      $432 = Math_fround($425 * $426);
      $433 = Math_fround($423 * $428);
      $434 = Math_fround($432 - $433);
      $435 = Math_fround($423 * $427);
      $436 = Math_fround($424 * $426);
      $437 = Math_fround($435 - $436);
      $438 = Math_fround($431 * $431);
      $439 = Math_fround($434 * $434);
      $440 = Math_fround($438 + $439);
      $441 = Math_fround($437 * $437);
      $442 = Math_fround($441 + $440);
      $443 = $442 > Math_fround(0.0);
      if ($443) {
       $444 = (Math_fround(Math_sqrt((Math_fround($442)))));
       $445 = Math_fround(Math_fround(1.0) / $444);
       $446 = Math_fround($431 * $445);
       $447 = Math_fround($434 * $445);
       $448 = Math_fround($437 * $445);
       $450 = $446;$452 = $447;$455 = $448;
      } else {
       $450 = Math_fround(0.0);$452 = Math_fround(0.0);$455 = Math_fround(0.0);
      }
      $449 = Math_fround($450 * $242);
      $451 = Math_fround($452 * $245);
      $453 = Math_fround($449 + $451);
      $454 = Math_fround($455 * $248);
      $456 = Math_fround($453 + $454);
      $457 = Math_fround($450 * $243);
      $458 = Math_fround($452 * $246);
      $459 = Math_fround($457 + $458);
      $460 = Math_fround($455 * $249);
      $461 = Math_fround($459 + $460);
      $462 = $456 > $461;
      $463 = $462 ? $461 : $456;
      $464 = $462 ? $456 : $461;
      $465 = Math_fround($463 - $196);
      $466 = Math_fround($196 + $464);
      $467 = Math_fround($450 * $200);
      $468 = Math_fround($452 * $203);
      $469 = Math_fround($467 + $468);
      $470 = Math_fround($455 * $206);
      $471 = Math_fround($469 + $470);
      $472 = Math_fround($450 * $199);
      $473 = Math_fround($452 * $202);
      $474 = Math_fround($472 + $473);
      $475 = Math_fround($455 * $205);
      $476 = Math_fround($474 + $475);
      $477 = $471 < $476;
      $478 = $477 ? $471 : $476;
      $479 = $471 > $476;
      $480 = $479 ? $471 : $476;
      $481 = Math_fround($450 * $208);
      $482 = Math_fround($452 * $210);
      $483 = Math_fround($481 + $482);
      $484 = Math_fround($455 * $212);
      $485 = Math_fround($483 + $484);
      $486 = $478 < $485;
      $487 = $486 ? $478 : $485;
      $488 = $480 > $485;
      $489 = $488 ? $480 : $485;
      $490 = $466 < $487;
      $491 = $489 < $465;
      $or$cond$i = $490 | $491;
      if (!($or$cond$i)) {
       $492 = Math_fround($466 - $487);
       $493 = Math_fround($489 - $465);
       $494 = $492 < $493;
       $495 = $494 ? $492 : $493;
       $496 = Math_fround($243 - $242);
       $497 = Math_fround($246 - $245);
       $498 = Math_fround($249 - $248);
       $499 = Math_fround($496 * $496);
       $500 = Math_fround($497 * $497);
       $501 = Math_fround($499 + $500);
       $502 = Math_fround($498 * $498);
       $503 = Math_fround($501 + $502);
       $504 = $503 > Math_fround(0.0);
       if ($504) {
        $505 = (Math_fround(Math_sqrt((Math_fround($503)))));
        $506 = Math_fround(Math_fround(1.0) / $505);
        $507 = Math_fround($496 * $506);
        $508 = Math_fround($497 * $506);
        $509 = Math_fround($498 * $506);
        $535 = $508;$537 = $509;$541 = $507;
       } else {
        $535 = Math_fround(0.0);$537 = Math_fround(0.0);$541 = Math_fround(0.0);
       }
       $510 = $158&255;
       $611 = $495;$726 = $450;$727 = $452;$728 = $455;$i$017$i$i = 0;
       while(1) {
        $511 = (548784 + ($i$017$i$i<<2)|0);
        $512 = HEAP32[$511>>2]|0;
        $513 = $512 & $510;
        $514 = ($513|0)==(0);
        do {
         if ($514) {
          $$pre$i$i = (($i$017$i$i) + 1)|0;
          $$pre$phi$i$iZ2D = $$pre$i$i;$626 = $726;$628 = $727;$631 = $728;$729 = $611;
         } else {
          $515 = (($triVerts) + (($i$017$i$i*12)|0)|0);
          $516 = Math_fround(HEAPF32[$515>>2]);
          $517 = ((($triVerts) + (($i$017$i$i*12)|0)|0) + 4|0);
          $518 = Math_fround(HEAPF32[$517>>2]);
          $519 = ((($triVerts) + (($i$017$i$i*12)|0)|0) + 8|0);
          $520 = Math_fround(HEAPF32[$519>>2]);
          $521 = (($i$017$i$i) + 1)|0;
          $522 = $i$017$i$i >>> 1;
          $523 = (($521) + ($522))|0;
          $524 = $523 & 3;
          $525 = (($triVerts) + (($524*12)|0)|0);
          $526 = Math_fround(HEAPF32[$525>>2]);
          $527 = ((($triVerts) + (($524*12)|0)|0) + 4|0);
          $528 = Math_fround(HEAPF32[$527>>2]);
          $529 = ((($triVerts) + (($524*12)|0)|0) + 8|0);
          $530 = Math_fround(HEAPF32[$529>>2]);
          $531 = Math_fround($516 - $526);
          $532 = Math_fround($518 - $528);
          $533 = Math_fround($520 - $530);
          $534 = Math_fround($535 * $533);
          $536 = Math_fround($537 * $532);
          $538 = Math_fround($534 - $536);
          $539 = Math_fround($537 * $531);
          $540 = Math_fround($541 * $533);
          $542 = Math_fround($539 - $540);
          $543 = Math_fround($541 * $532);
          $544 = Math_fround($535 * $531);
          $545 = Math_fround($543 - $544);
          $fabsf$i$i$i$i$i = (Math_fround(Math_abs((Math_fround($538)))));
          $546 = +$fabsf$i$i$i$i$i;
          $547 = $546 > 9.99999999999999954748E-7;
          if (!($547)) {
           $fabsf$i$i1$i$i$i = (Math_fround(Math_abs((Math_fround($542)))));
           $548 = +$fabsf$i$i1$i$i$i;
           $549 = $548 > 9.99999999999999954748E-7;
           if (!($549)) {
            $fabsf$i$i2$i$i$i = (Math_fround(Math_abs((Math_fround($545)))));
            $550 = +$fabsf$i$i2$i$i$i;
            $551 = $550 > 9.99999999999999954748E-7;
            if (!($551)) {
             $$pre$phi$i$iZ2D = $521;$626 = $726;$628 = $727;$631 = $728;$729 = $611;
             break;
            }
           }
          }
          $552 = Math_fround($538 * $538);
          $553 = Math_fround($542 * $542);
          $554 = Math_fround($552 + $553);
          $555 = Math_fround($545 * $545);
          $556 = Math_fround($555 + $554);
          $557 = $556 > Math_fround(0.0);
          if ($557) {
           $558 = (Math_fround(Math_sqrt((Math_fround($556)))));
           $559 = Math_fround(Math_fround(1.0) / $558);
           $560 = Math_fround($538 * $559);
           $561 = Math_fround($542 * $559);
           $562 = Math_fround($545 * $559);
           $564 = $560;$566 = $561;$569 = $562;
          } else {
           $564 = Math_fround(0.0);$566 = Math_fround(0.0);$569 = Math_fround(0.0);
          }
          $563 = Math_fround($564 * $242);
          $565 = Math_fround($566 * $245);
          $567 = Math_fround($563 + $565);
          $568 = Math_fround($569 * $248);
          $570 = Math_fround($567 + $568);
          $571 = Math_fround($564 * $243);
          $572 = Math_fround($566 * $246);
          $573 = Math_fround($571 + $572);
          $574 = Math_fround($569 * $249);
          $575 = Math_fround($573 + $574);
          $576 = $570 > $575;
          $577 = $576 ? $575 : $570;
          $578 = $576 ? $570 : $575;
          $579 = Math_fround($577 - $196);
          $580 = Math_fround($196 + $578);
          $581 = Math_fround($564 * $200);
          $582 = Math_fround($566 * $203);
          $583 = Math_fround($581 + $582);
          $584 = Math_fround($569 * $206);
          $585 = Math_fround($583 + $584);
          $586 = Math_fround($564 * $199);
          $587 = Math_fround($566 * $202);
          $588 = Math_fround($586 + $587);
          $589 = Math_fround($569 * $205);
          $590 = Math_fround($588 + $589);
          $591 = $585 < $590;
          $592 = $591 ? $585 : $590;
          $593 = $585 > $590;
          $594 = $593 ? $585 : $590;
          $595 = Math_fround($564 * $208);
          $596 = Math_fround($566 * $210);
          $597 = Math_fround($595 + $596);
          $598 = Math_fround($569 * $212);
          $599 = Math_fround($597 + $598);
          $600 = $592 < $599;
          $601 = $600 ? $592 : $599;
          $602 = $594 > $599;
          $603 = $602 ? $594 : $599;
          $604 = $580 < $601;
          $605 = $603 < $579;
          $or$cond$i1 = $604 | $605;
          if ($or$cond$i1) {
           break L6;
          }
          $606 = Math_fround($580 - $601);
          $607 = Math_fround($603 - $579);
          $608 = $606 < $607;
          $609 = $608 ? $606 : $607;
          $610 = $609 < $611;
          if ($610) {
           $$pre$phi$i$iZ2D = $521;$626 = $564;$628 = $566;$631 = $569;$729 = $609;
          } else {
           $$pre$phi$i$iZ2D = $521;$626 = $726;$628 = $727;$631 = $728;$729 = $611;
          }
         }
        } while(0);
        $612 = ($$pre$phi$i$iZ2D>>>0)<(3);
        if ($612) {
         $611 = $729;$726 = $626;$727 = $628;$728 = $631;$i$017$i$i = $$pre$phi$i$iZ2D;
        } else {
         break;
        }
       }
       $613 = Math_fround($200 + $199);
       $614 = Math_fround($203 + $202);
       $615 = Math_fround($206 + $205);
       $616 = Math_fround($613 + $208);
       $617 = Math_fround($614 + $210);
       $618 = Math_fround($615 + $212);
       $619 = Math_fround($616 * Math_fround(0.333333343267440795898));
       $620 = Math_fround($617 * Math_fround(0.333333343267440795898));
       $621 = Math_fround($618 * Math_fround(0.333333343267440795898));
       $622 = Math_fround($251 - $619);
       $623 = Math_fround($252 - $620);
       $624 = Math_fround($253 - $621);
       $625 = Math_fround($626 * $622);
       $627 = Math_fround($628 * $623);
       $629 = Math_fround($625 + $627);
       $630 = Math_fround($631 * $624);
       $632 = Math_fround($629 + $630);
       $633 = $632 < Math_fround(0.0);
       if ($633) {
        $634 = Math_fround(-$626);
        $635 = Math_fround(-$628);
        $636 = Math_fround(-$631);
        $637 = $634;$638 = $635;$639 = $636;
       } else {
        $637 = $626;$638 = $628;$639 = $631;
       }
       HEAPF32[$SepAxis$i>>2] = $637;
       HEAPF32[$126>>2] = $638;
       HEAPF32[$127>>2] = $639;
       HEAPF32[$s0$i1$i>>2] = $242;
       HEAPF32[$128>>2] = $245;
       HEAPF32[$129>>2] = $248;
       HEAPF32[$s1$i2$i>>2] = $243;
       HEAPF32[$130>>2] = $246;
       HEAPF32[$131>>2] = $249;
       $640 = (Math_fround(Math_sqrt((Math_fround($503)))));
       $641 = $640 > Math_fround(0.0);
       if ($641) {
        $642 = Math_fround(Math_fround(0.00999999977648258209228) / $640);
        $643 = Math_fround($496 * $642);
        $644 = Math_fround($497 * $642);
        $645 = Math_fround($498 * $642);
        $646 = Math_fround($242 - $643);
        HEAPF32[$s0$i1$i>>2] = $646;
        $647 = Math_fround($245 - $644);
        HEAPF32[$128>>2] = $647;
        $648 = Math_fround($248 - $645);
        HEAPF32[$129>>2] = $648;
        $649 = Math_fround($243 + $643);
        HEAPF32[$s1$i2$i>>2] = $649;
        $650 = Math_fround($246 + $644);
        HEAPF32[$130>>2] = $650;
        $651 = Math_fround($249 + $645);
        HEAPF32[$131>>2] = $651;
       }
       $652 = (($164) + 4096|0);
       $653 = Math_fround(-$637);
       $654 = Math_fround(-$638);
       $655 = Math_fround(-$639);
       $i$01$i$i = 0;
       while(1) {
        $656 = (($triVerts) + (($i$01$i$i*12)|0)|0);
        $657 = (($i$01$i$i) + 1)|0;
        $658 = $i$01$i$i >>> 1;
        $659 = (($657) + ($658))|0;
        $660 = $659 & 3;
        $661 = (($triVerts) + (($660*12)|0)|0);
        HEAPF32[$0>>2] = $653;
        HEAPF32[$132>>2] = $654;
        HEAPF32[$133>>2] = $655;
        $662 = (__ZN5physx2Gu17intersectEdgeEdgeERKNS_6PxVec3ES3_S3_S3_S3_RfRS1_($656,$661,$0,$s0$i1$i,$s1$i2$i,$dist$i3$i,$ip$i4$i)|0);
        if ($662) {
         $663 = Math_fround(HEAPF32[$ip$i4$i>>2]);
         $664 = Math_fround(HEAPF32[$meshAbsPose>>2]);
         $665 = Math_fround($663 * $664);
         $666 = Math_fround(HEAPF32[$27>>2]);
         $667 = Math_fround($663 * $666);
         $668 = Math_fround(HEAPF32[$29>>2]);
         $669 = Math_fround($663 * $668);
         $670 = Math_fround(HEAPF32[$134>>2]);
         $671 = Math_fround(HEAPF32[$31>>2]);
         $672 = Math_fround($670 * $671);
         $673 = Math_fround(HEAPF32[$34>>2]);
         $674 = Math_fround($670 * $673);
         $675 = Math_fround(HEAPF32[$36>>2]);
         $676 = Math_fround($670 * $675);
         $677 = Math_fround($665 + $672);
         $678 = Math_fround($667 + $674);
         $679 = Math_fround($669 + $676);
         $680 = Math_fround(HEAPF32[$135>>2]);
         $681 = Math_fround(HEAPF32[$38>>2]);
         $682 = Math_fround($680 * $681);
         $683 = Math_fround(HEAPF32[$40>>2]);
         $684 = Math_fround($680 * $683);
         $685 = Math_fround(HEAPF32[$42>>2]);
         $686 = Math_fround($680 * $685);
         $687 = Math_fround($677 + $682);
         $688 = Math_fround($678 + $684);
         $689 = Math_fround($679 + $686);
         $690 = Math_fround(HEAPF32[$43>>2]);
         $691 = Math_fround($687 + $690);
         $692 = Math_fround(HEAPF32[$44>>2]);
         $693 = Math_fround($688 + $692);
         $694 = Math_fround(HEAPF32[$45>>2]);
         $695 = Math_fround($689 + $694);
         HEAPF32[$ip$i4$i>>2] = $691;
         HEAPF32[$134>>2] = $693;
         HEAPF32[$135>>2] = $695;
         $696 = HEAP32[$652>>2]|0;
         $697 = ($696>>>0)>(63);
         if (!($697)) {
          $698 = Math_fround(HEAPF32[$dist$i3$i>>2]);
          $699 = Math_fround($638 * $675);
          $700 = Math_fround($638 * $673);
          $701 = Math_fround($638 * $671);
          $702 = Math_fround($637 * $668);
          $703 = Math_fround($637 * $666);
          $704 = Math_fround($637 * $664);
          $705 = Math_fround($163 + $698);
          $706 = Math_fround($639 * $685);
          $707 = Math_fround($639 * $683);
          $708 = Math_fround($639 * $681);
          $709 = Math_fround($702 + $699);
          $710 = Math_fround($703 + $700);
          $711 = Math_fround($704 + $701);
          $712 = Math_fround(-$705);
          $713 = Math_fround($709 + $706);
          $714 = Math_fround($710 + $707);
          $715 = Math_fround($711 + $708);
          $716 = (($696) + 1)|0;
          HEAP32[$652>>2] = $716;
          $717 = (($164) + ($696<<6)|0);
          HEAPF32[$717>>2] = $715;
          $718 = ((($164) + ($696<<6)|0) + 4|0);
          HEAPF32[$718>>2] = $714;
          $719 = ((($164) + ($696<<6)|0) + 8|0);
          HEAPF32[$719>>2] = $713;
          $720 = ((($164) + ($696<<6)|0) + 16|0);
          HEAPF32[$720>>2] = $691;
          $721 = ((($164) + ($696<<6)|0) + 20|0);
          HEAPF32[$721>>2] = $693;
          $722 = ((($164) + ($696<<6)|0) + 24|0);
          HEAPF32[$722>>2] = $695;
          $723 = ((($164) + ($696<<6)|0) + 12|0);
          HEAPF32[$723>>2] = $712;
          $724 = ((($164) + ($696<<6)|0) + 48|0);
          HEAP32[$724>>2] = -1;
          $725 = ((($164) + ($696<<6)|0) + 52|0);
          HEAP32[$725>>2] = $137;
         }
        }
        $exitcond$i$i = ($657|0)==(3);
        if ($exitcond$i$i) {
         break;
        } else {
         $i$01$i$i = $657;
        }
       }
       __ZL21PxcGenerateVFContactsRKN5physx2Cm8Matrix34ERNS_2Gu13ContactBufferERKNS4_7SegmentEfPKNS_6PxVec3ERSB_jf($meshAbsPose,$164,$162,$163,$triVerts,$SepAxis$i,$137,$165);
      }
     }
    }
   }
  } while(0);
  $161 = ($136|0)==(0);
  if ($161) {
   break;
  } else {
   $$in = $136;$edgeFlags$012 = $157;$triInds$013 = $138;$verts$014 = $156;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZL21PxcGenerateVFContactsRKN5physx2Cm8Matrix34ERNS_2Gu13ContactBufferERKNS4_7SegmentEfPKNS_6PxVec3ERSB_jf($meshAbsPose,$contactBuffer,$segment,$radius,$triVerts,$normal,$triangleIndex,$contactDistance) {
 $meshAbsPose = $meshAbsPose|0;
 $contactBuffer = $contactBuffer|0;
 $segment = $segment|0;
 $radius = Math_fround($radius);
 $triVerts = $triVerts|0;
 $normal = $normal|0;
 $triangleIndex = $triangleIndex|0;
 $contactDistance = Math_fround($contactDistance);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond = 0, $i$06 = 0, $normal$idx$val = Math_fround(0), $normal$idx1$val = Math_fround(0), $normal$idx2$val = Math_fround(0), $t = 0, $u = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $t = sp + 20|0;
 $u = sp;
 $v = sp + 4|0;
 $0 = sp + 8|0;
 $1 = (($normal) + 4|0);
 $2 = (($normal) + 8|0);
 $3 = (($0) + 4|0);
 $4 = (($0) + 8|0);
 $5 = (($triVerts) + 12|0);
 $6 = (($triVerts) + 24|0);
 $7 = Math_fround($radius + $contactDistance);
 $8 = (($meshAbsPose) + 4|0);
 $9 = (($meshAbsPose) + 8|0);
 $10 = (($meshAbsPose) + 12|0);
 $11 = (($meshAbsPose) + 16|0);
 $12 = (($meshAbsPose) + 20|0);
 $13 = (($meshAbsPose) + 24|0);
 $14 = (($meshAbsPose) + 28|0);
 $15 = (($meshAbsPose) + 32|0);
 $16 = (($contactBuffer) + 4096|0);
 $17 = (($meshAbsPose) + 44|0);
 $18 = (($meshAbsPose) + 40|0);
 $19 = (($meshAbsPose) + 36|0);
 $i$06 = 0;
 while(1) {
  $20 = (($segment) + (($i$06*12)|0)|0);
  $21 = Math_fround(HEAPF32[$normal>>2]);
  $22 = Math_fround(-$21);
  $23 = Math_fround(HEAPF32[$1>>2]);
  $24 = Math_fround(-$23);
  $25 = Math_fround(HEAPF32[$2>>2]);
  $26 = Math_fround(-$25);
  HEAPF32[$0>>2] = $22;
  HEAPF32[$3>>2] = $24;
  HEAPF32[$4>>2] = $26;
  $27 = (__ZN5physx2Gu27intersectRayTriangleCullingERKNS_6PxVec3ES3_S3_S3_S3_RfS4_S4_f($20,$0,$triVerts,$5,$6,$t,$u,$v,Math_fround(0.0))|0);
  if ($27) {
   $28 = Math_fround(HEAPF32[$t>>2]);
   $29 = $28 < $7;
   if ($29) {
    $normal$idx$val = Math_fround(HEAPF32[$normal>>2]);
    $normal$idx1$val = Math_fround(HEAPF32[$1>>2]);
    $normal$idx2$val = Math_fround(HEAPF32[$2>>2]);
    $30 = Math_fround($28 * $normal$idx$val);
    $31 = Math_fround($28 * $normal$idx1$val);
    $32 = Math_fround($28 * $normal$idx2$val);
    $33 = Math_fround(HEAPF32[$20>>2]);
    $34 = Math_fround($33 - $30);
    $35 = ((($segment) + (($i$06*12)|0)|0) + 4|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = Math_fround($36 - $31);
    $38 = ((($segment) + (($i$06*12)|0)|0) + 8|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = Math_fround($39 - $32);
    $41 = Math_fround(HEAPF32[$meshAbsPose>>2]);
    $42 = Math_fround(HEAPF32[$8>>2]);
    $43 = Math_fround(HEAPF32[$9>>2]);
    $44 = Math_fround(HEAPF32[$10>>2]);
    $45 = Math_fround(HEAPF32[$11>>2]);
    $46 = Math_fround(HEAPF32[$12>>2]);
    $47 = Math_fround(HEAPF32[$13>>2]);
    $48 = Math_fround(HEAPF32[$14>>2]);
    $49 = Math_fround(HEAPF32[$15>>2]);
    $50 = HEAP32[$16>>2]|0;
    $51 = ($50>>>0)>(63);
    if (!($51)) {
     $52 = Math_fround($37 * $46);
     $53 = Math_fround($37 * $45);
     $54 = Math_fround($37 * $44);
     $55 = Math_fround($34 * $43);
     $56 = Math_fround($34 * $42);
     $57 = Math_fround($34 * $41);
     $58 = Math_fround($46 * $normal$idx1$val);
     $59 = Math_fround($45 * $normal$idx1$val);
     $60 = Math_fround($44 * $normal$idx1$val);
     $61 = Math_fround($43 * $normal$idx$val);
     $62 = Math_fround($42 * $normal$idx$val);
     $63 = Math_fround($41 * $normal$idx$val);
     $64 = Math_fround($40 * $49);
     $65 = Math_fround($40 * $48);
     $66 = Math_fround($40 * $47);
     $67 = Math_fround($55 + $52);
     $68 = Math_fround($56 + $53);
     $69 = Math_fround($57 + $54);
     $70 = Math_fround($49 * $normal$idx2$val);
     $71 = Math_fround($48 * $normal$idx2$val);
     $72 = Math_fround($47 * $normal$idx2$val);
     $73 = Math_fround($61 + $58);
     $74 = Math_fround($62 + $59);
     $75 = Math_fround($63 + $60);
     $76 = Math_fround(HEAPF32[$17>>2]);
     $77 = Math_fround(HEAPF32[$18>>2]);
     $78 = Math_fround(HEAPF32[$19>>2]);
     $79 = Math_fround($67 + $64);
     $80 = Math_fround($68 + $65);
     $81 = Math_fround($69 + $66);
     $82 = Math_fround($28 - $radius);
     $83 = Math_fround($73 + $70);
     $84 = Math_fround($74 + $71);
     $85 = Math_fround($75 + $72);
     $86 = Math_fround($79 + $76);
     $87 = Math_fround($80 + $77);
     $88 = Math_fround($81 + $78);
     $89 = (($50) + 1)|0;
     HEAP32[$16>>2] = $89;
     $90 = (($contactBuffer) + ($50<<6)|0);
     HEAPF32[$90>>2] = $85;
     $91 = ((($contactBuffer) + ($50<<6)|0) + 4|0);
     HEAPF32[$91>>2] = $84;
     $92 = ((($contactBuffer) + ($50<<6)|0) + 8|0);
     HEAPF32[$92>>2] = $83;
     $93 = ((($contactBuffer) + ($50<<6)|0) + 16|0);
     HEAPF32[$93>>2] = $88;
     $94 = ((($contactBuffer) + ($50<<6)|0) + 20|0);
     HEAPF32[$94>>2] = $87;
     $95 = ((($contactBuffer) + ($50<<6)|0) + 24|0);
     HEAPF32[$95>>2] = $86;
     $96 = ((($contactBuffer) + ($50<<6)|0) + 12|0);
     HEAPF32[$96>>2] = $82;
     $97 = ((($contactBuffer) + ($50<<6)|0) + 48|0);
     HEAP32[$97>>2] = -1;
     $98 = ((($contactBuffer) + ($50<<6)|0) + 52|0);
     HEAP32[$98>>2] = $triangleIndex;
    }
   }
  }
  $99 = (($i$06) + 1)|0;
  $exitcond = ($99|0)==(2);
  if ($exitcond) {
   break;
  } else {
   $i$06 = $99;
  }
 }
 STACKTOP = sp;return;
}
function __ZN26ContactCapsuleMeshCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$hit,$v0,$v1,$v2,$0,$vInds) {
 $this = $this|0;
 $hit = $hit|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 $0 = $0|0;
 $vInds = $vInds|0;
 var $$phi$trans$insert11 = 0, $$phi$trans$insert13 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert17 = 0, $$phi$trans$insert19 = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert7 = 0, $$phi$trans$insert9 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre12 = Math_fround(0), $$pre14 = Math_fround(0), $$pre16 = Math_fround(0), $$pre18 = Math_fround(0), $$pre20 = Math_fround(0), $$pre22 = Math_fround(0), $$pre8 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0;
 var $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0;
 var $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0;
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0;
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $extraData$0 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $v = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $27 = (($this) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = Math_fround(HEAPF32[$v0>>2]);
  $30 = Math_fround(HEAPF32[$28>>2]);
  $31 = Math_fround($29 * $30);
  $32 = (($28) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($29 * $33);
  $35 = (($28) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($29 * $36);
  $38 = (($v0) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($28) + 12|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($39 * $41);
  $43 = (($28) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($39 * $44);
  $46 = (($28) + 20|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($39 * $47);
  $49 = Math_fround($31 + $42);
  $50 = Math_fround($34 + $45);
  $51 = Math_fround($37 + $48);
  $52 = (($v0) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($28) + 24|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($53 * $55);
  $57 = (($28) + 28|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($53 * $58);
  $60 = (($28) + 32|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($53 * $61);
  $63 = Math_fround($49 + $56);
  $64 = Math_fround($50 + $59);
  $65 = Math_fround($51 + $62);
  HEAPF32[$v>>2] = $63;
  $66 = (($v) + 4|0);
  HEAPF32[$66>>2] = $64;
  $67 = (($v) + 8|0);
  HEAPF32[$67>>2] = $65;
  $68 = Math_fround(HEAPF32[$v1>>2]);
  $69 = Math_fround(HEAPF32[$28>>2]);
  $70 = Math_fround($68 * $69);
  $71 = Math_fround(HEAPF32[$32>>2]);
  $72 = Math_fround($68 * $71);
  $73 = Math_fround(HEAPF32[$35>>2]);
  $74 = Math_fround($68 * $73);
  $75 = (($v1) + 4|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround(HEAPF32[$40>>2]);
  $78 = Math_fround($76 * $77);
  $79 = Math_fround(HEAPF32[$43>>2]);
  $80 = Math_fround($76 * $79);
  $81 = Math_fround(HEAPF32[$46>>2]);
  $82 = Math_fround($76 * $81);
  $83 = Math_fround($70 + $78);
  $84 = Math_fround($72 + $80);
  $85 = Math_fround($74 + $82);
  $86 = (($v1) + 8|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = Math_fround(HEAPF32[$54>>2]);
  $89 = Math_fround($87 * $88);
  $90 = Math_fround(HEAPF32[$57>>2]);
  $91 = Math_fround($87 * $90);
  $92 = Math_fround(HEAPF32[$60>>2]);
  $93 = Math_fround($87 * $92);
  $94 = Math_fround($83 + $89);
  $95 = Math_fround($84 + $91);
  $96 = Math_fround($85 + $93);
  $97 = (($v) + 12|0);
  HEAPF32[$97>>2] = $94;
  $98 = (($v) + 16|0);
  HEAPF32[$98>>2] = $95;
  $99 = (($v) + 20|0);
  HEAPF32[$99>>2] = $96;
  $100 = Math_fround(HEAPF32[$v2>>2]);
  $101 = Math_fround(HEAPF32[$28>>2]);
  $102 = Math_fround($100 * $101);
  $103 = Math_fround(HEAPF32[$32>>2]);
  $104 = Math_fround($100 * $103);
  $105 = Math_fround(HEAPF32[$35>>2]);
  $106 = Math_fround($100 * $105);
  $107 = (($v2) + 4|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround(HEAPF32[$40>>2]);
  $110 = Math_fround($108 * $109);
  $111 = Math_fround(HEAPF32[$43>>2]);
  $112 = Math_fround($108 * $111);
  $113 = Math_fround(HEAPF32[$46>>2]);
  $114 = Math_fround($108 * $113);
  $115 = Math_fround($102 + $110);
  $116 = Math_fround($104 + $112);
  $117 = Math_fround($106 + $114);
  $118 = (($v2) + 8|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround(HEAPF32[$54>>2]);
  $121 = Math_fround($119 * $120);
  $122 = Math_fround(HEAPF32[$57>>2]);
  $123 = Math_fround($119 * $122);
  $124 = Math_fround(HEAPF32[$60>>2]);
  $125 = Math_fround($119 * $124);
  $126 = Math_fround($115 + $121);
  $127 = Math_fround($116 + $123);
  $128 = Math_fround($117 + $125);
  $129 = (($v) + 24|0);
  HEAPF32[$129>>2] = $126;
  $130 = (($v) + 28|0);
  HEAPF32[$130>>2] = $127;
  $131 = (($v) + 32|0);
  HEAPF32[$131>>2] = $128;
  $181 = $128;$182 = $127;$183 = $126;$184 = $96;$185 = $95;$186 = $94;$187 = $65;$188 = $64;$189 = $63;
 } else {
  $4 = Math_fround(HEAPF32[$v0>>2]);
  HEAPF32[$v>>2] = $4;
  $5 = (($v0) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($v) + 4|0);
  HEAPF32[$7>>2] = $6;
  $8 = (($v0) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($v) + 8|0);
  HEAPF32[$10>>2] = $9;
  $11 = Math_fround(HEAPF32[$v1>>2]);
  $12 = (($v) + 12|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($v1) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($v) + 16|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($v1) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($v) + 20|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround(HEAPF32[$v2>>2]);
  $20 = (($v) + 24|0);
  HEAPF32[$20>>2] = $19;
  $21 = (($v2) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($v) + 28|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($v2) + 8|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($v) + 32|0);
  HEAPF32[$26>>2] = $25;
  $181 = $25;$182 = $22;$183 = $19;$184 = $17;$185 = $14;$186 = $11;$187 = $9;$188 = $6;$189 = $4;
 }
 $132 = (($hit) + 8|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (($this) + 896|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($135) + 152|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($137|0)==(0|0);
 if ($138) {
  $extraData$0 = 56;
 } else {
  $139 = $137;
  $140 = (($139) + ($133))|0;
  $141 = $140;
  $142 = HEAP8[$141>>0]|0;
  $extraData$0 = $142;
 }
 $143 = (($this) + 892|0);
 $144 = HEAP32[$143>>2]|0;
 $145 = ($144|0)==(16);
 if (!($145)) {
  $149 = $144;$152 = $189;$154 = $188;$156 = $187;$159 = $186;$161 = $185;$163 = $184;$166 = $183;$168 = $182;$170 = $181;
  $148 = (($149) + 1)|0;
  HEAP32[$143>>2] = $148;
  $150 = ($149*3)|0;
  $151 = ((($this) + (($150*12)|0)|0) + 44|0);
  HEAPF32[$151>>2] = $152;
  $153 = ((($this) + (($150*12)|0)|0) + 48|0);
  HEAPF32[$153>>2] = $154;
  $155 = ((($this) + (($150*12)|0)|0) + 52|0);
  HEAPF32[$155>>2] = $156;
  $157 = (($150) + 1)|0;
  $158 = ((($this) + (($157*12)|0)|0) + 44|0);
  HEAPF32[$158>>2] = $159;
  $160 = ((($this) + (($157*12)|0)|0) + 48|0);
  HEAPF32[$160>>2] = $161;
  $162 = ((($this) + (($157*12)|0)|0) + 52|0);
  HEAPF32[$162>>2] = $163;
  $164 = (($150) + 2)|0;
  $165 = ((($this) + (($164*12)|0)|0) + 44|0);
  HEAPF32[$165>>2] = $166;
  $167 = ((($this) + (($164*12)|0)|0) + 48|0);
  HEAPF32[$167>>2] = $168;
  $169 = ((($this) + (($164*12)|0)|0) + 52|0);
  HEAPF32[$169>>2] = $170;
  $171 = HEAP32[$vInds>>2]|0;
  $172 = ((($this) + ($150<<2)|0) + 620|0);
  HEAP32[$172>>2] = $171;
  $173 = (($vInds) + 4|0);
  $174 = HEAP32[$173>>2]|0;
  $175 = ((($this) + ($157<<2)|0) + 620|0);
  HEAP32[$175>>2] = $174;
  $176 = (($vInds) + 8|0);
  $177 = HEAP32[$176>>2]|0;
  $178 = ((($this) + ($164<<2)|0) + 620|0);
  HEAP32[$178>>2] = $177;
  $179 = ((($this) + ($149<<2)|0) + 812|0);
  HEAP32[$179>>2] = $133;
  $180 = ((($this) + ($149)|0) + 876|0);
  HEAP8[$180>>0] = $extraData$0;
  STACKTOP = sp;return 1;
 }
 $146 = (($this) + 44|0);
 $147 = (($this) + 8|0);
 (__ZN18ContactCapsuleMesh20processTriangleCacheILj16EEEbRN5physx2Gu13TriangleCacheIXT_EEE($147,$146)|0);
 HEAP32[$143>>2] = 0;
 $$pre = Math_fround(HEAPF32[$v>>2]);
 $$phi$trans$insert7 = (($v) + 4|0);
 $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
 $$phi$trans$insert9 = (($v) + 8|0);
 $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert9>>2]);
 $$phi$trans$insert11 = (($v) + 12|0);
 $$pre12 = Math_fround(HEAPF32[$$phi$trans$insert11>>2]);
 $$phi$trans$insert13 = (($v) + 16|0);
 $$pre14 = Math_fround(HEAPF32[$$phi$trans$insert13>>2]);
 $$phi$trans$insert15 = (($v) + 20|0);
 $$pre16 = Math_fround(HEAPF32[$$phi$trans$insert15>>2]);
 $$phi$trans$insert17 = (($v) + 24|0);
 $$pre18 = Math_fround(HEAPF32[$$phi$trans$insert17>>2]);
 $$phi$trans$insert19 = (($v) + 28|0);
 $$pre20 = Math_fround(HEAPF32[$$phi$trans$insert19>>2]);
 $$phi$trans$insert21 = (($v) + 32|0);
 $$pre22 = Math_fround(HEAPF32[$$phi$trans$insert21>>2]);
 $149 = 0;$152 = $$pre;$154 = $$pre8;$156 = $$pre10;$159 = $$pre12;$161 = $$pre14;$163 = $$pre16;$166 = $$pre18;$168 = $$pre20;$170 = $$pre22;
 $148 = (($149) + 1)|0;
 HEAP32[$143>>2] = $148;
 $150 = ($149*3)|0;
 $151 = ((($this) + (($150*12)|0)|0) + 44|0);
 HEAPF32[$151>>2] = $152;
 $153 = ((($this) + (($150*12)|0)|0) + 48|0);
 HEAPF32[$153>>2] = $154;
 $155 = ((($this) + (($150*12)|0)|0) + 52|0);
 HEAPF32[$155>>2] = $156;
 $157 = (($150) + 1)|0;
 $158 = ((($this) + (($157*12)|0)|0) + 44|0);
 HEAPF32[$158>>2] = $159;
 $160 = ((($this) + (($157*12)|0)|0) + 48|0);
 HEAPF32[$160>>2] = $161;
 $162 = ((($this) + (($157*12)|0)|0) + 52|0);
 HEAPF32[$162>>2] = $163;
 $164 = (($150) + 2)|0;
 $165 = ((($this) + (($164*12)|0)|0) + 44|0);
 HEAPF32[$165>>2] = $166;
 $167 = ((($this) + (($164*12)|0)|0) + 48|0);
 HEAPF32[$167>>2] = $168;
 $169 = ((($this) + (($164*12)|0)|0) + 52|0);
 HEAPF32[$169>>2] = $170;
 $171 = HEAP32[$vInds>>2]|0;
 $172 = ((($this) + ($150<<2)|0) + 620|0);
 HEAP32[$172>>2] = $171;
 $173 = (($vInds) + 4|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ((($this) + ($157<<2)|0) + 620|0);
 HEAP32[$175>>2] = $174;
 $176 = (($vInds) + 8|0);
 $177 = HEAP32[$176>>2]|0;
 $178 = ((($this) + ($164<<2)|0) + 620|0);
 HEAP32[$178>>2] = $177;
 $179 = ((($this) + ($149<<2)|0) + 812|0);
 HEAP32[$179>>2] = $133;
 $180 = ((($this) + ($149)|0) + 876|0);
 HEAP8[$180>>0] = $extraData$0;
 STACKTOP = sp;return 1;
}
function __ZN26ContactCapsuleMeshCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29ConvexVsMeshContactGenerationC2ERNS0_9ContainerERKNS_11PxTransformES6_RKNS0_13PolygonalDataERKNS_2Cm8Matrix34ESD_RKNSA_23FastVertex2ShapeScalingEfbfS6_S6_RNS0_13ContactBufferE($this,$delayedContacts,$t0to1,$t1to0,$polyData0,$world0,$world1,$convexScaling,$contactDistance,$idtConvexScale,$cCCDEpsilon,$transform0,$transform1,$contactBuffer) {
 $this = $this|0;
 $delayedContacts = $delayedContacts|0;
 $t0to1 = $t0to1|0;
 $t1to0 = $t1to0|0;
 $polyData0 = $polyData0|0;
 $world0 = $world0|0;
 $world1 = $world1|0;
 $convexScaling = $convexScaling|0;
 $contactDistance = Math_fround($contactDistance);
 $idtConvexScale = $idtConvexScale|0;
 $cCCDEpsilon = Math_fround($cCCDEpsilon);
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactBuffer = $contactBuffer|0;
 var $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0);
 var $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0;
 var $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0);
 var $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0);
 var $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $scevgep$i$i = 0;
 var $scevgep$i$i1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $delayedContacts;
 $0 = (($this) + 1284|0);
 HEAP32[$0>>2] = 0;
 $scevgep$i$i = (($this) + 1156|0);
 dest=$scevgep$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=255|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $1 = (($this) + 2056|0);
 HEAP32[$1>>2] = 0;
 $scevgep$i$i1 = (($this) + 1928|0);
 dest=$scevgep$i$i1+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=255|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $2 = Math_fround(HEAPF32[$t0to1>>2]);
 $3 = Math_fround($2 + $2);
 $4 = (($t0to1) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 + $5);
 $7 = (($t0to1) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 + $8);
 $10 = (($t0to1) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($3 * $11);
 $13 = Math_fround($6 * $11);
 $14 = Math_fround($11 * $9);
 $15 = Math_fround($2 * $3);
 $16 = Math_fround($2 * $6);
 $17 = Math_fround($2 * $9);
 $18 = Math_fround($5 * $6);
 $19 = Math_fround($5 * $9);
 $20 = Math_fround($8 * $9);
 $21 = Math_fround(Math_fround(1.0) - $18);
 $22 = Math_fround($21 - $20);
 $23 = (($this) + 2060|0);
 HEAPF32[$23>>2] = $22;
 $24 = Math_fround($16 + $14);
 $25 = (($this) + 2064|0);
 HEAPF32[$25>>2] = $24;
 $26 = Math_fround($17 - $13);
 $27 = (($this) + 2068|0);
 HEAPF32[$27>>2] = $26;
 $28 = Math_fround($16 - $14);
 $29 = (($this) + 2072|0);
 HEAPF32[$29>>2] = $28;
 $30 = Math_fround(Math_fround(1.0) - $15);
 $31 = Math_fround($30 - $20);
 $32 = (($this) + 2076|0);
 HEAPF32[$32>>2] = $31;
 $33 = Math_fround($19 + $12);
 $34 = (($this) + 2080|0);
 HEAPF32[$34>>2] = $33;
 $35 = Math_fround($17 + $13);
 $36 = (($this) + 2084|0);
 HEAPF32[$36>>2] = $35;
 $37 = Math_fround($19 - $12);
 $38 = (($this) + 2088|0);
 HEAPF32[$38>>2] = $37;
 $39 = Math_fround($30 - $18);
 $40 = (($this) + 2092|0);
 HEAPF32[$40>>2] = $39;
 $41 = (($this) + 2096|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($this) + 2100|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($this) + 2104|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($t0to1) + 16|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 HEAPF32[$41>>2] = $45;
 $46 = (($t0to1) + 20|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$42>>2] = $47;
 $48 = (($t0to1) + 24|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$43>>2] = $49;
 $50 = Math_fround(HEAPF32[$t1to0>>2]);
 $51 = Math_fround($50 + $50);
 $52 = (($t1to0) + 4|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 + $53);
 $55 = (($t1to0) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 + $56);
 $58 = (($t1to0) + 12|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($51 * $59);
 $61 = Math_fround($54 * $59);
 $62 = Math_fround($59 * $57);
 $63 = Math_fround($50 * $51);
 $64 = Math_fround($50 * $54);
 $65 = Math_fround($50 * $57);
 $66 = Math_fround($53 * $54);
 $67 = Math_fround($53 * $57);
 $68 = Math_fround($56 * $57);
 $69 = Math_fround(Math_fround(1.0) - $66);
 $70 = Math_fround($69 - $68);
 $71 = (($this) + 2108|0);
 HEAPF32[$71>>2] = $70;
 $72 = Math_fround($64 + $62);
 $73 = (($this) + 2112|0);
 HEAPF32[$73>>2] = $72;
 $74 = Math_fround($65 - $61);
 $75 = (($this) + 2116|0);
 HEAPF32[$75>>2] = $74;
 $76 = Math_fround($64 - $62);
 $77 = (($this) + 2120|0);
 HEAPF32[$77>>2] = $76;
 $78 = Math_fround(Math_fround(1.0) - $63);
 $79 = Math_fround($78 - $68);
 $80 = (($this) + 2124|0);
 HEAPF32[$80>>2] = $79;
 $81 = Math_fround($67 + $60);
 $82 = (($this) + 2128|0);
 HEAPF32[$82>>2] = $81;
 $83 = Math_fround($65 + $61);
 $84 = (($this) + 2132|0);
 HEAPF32[$84>>2] = $83;
 $85 = Math_fround($67 - $60);
 $86 = (($this) + 2136|0);
 HEAPF32[$86>>2] = $85;
 $87 = Math_fround($78 - $66);
 $88 = (($this) + 2140|0);
 HEAPF32[$88>>2] = $87;
 $89 = (($this) + 2144|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 $90 = (($this) + 2148|0);
 HEAPF32[$90>>2] = Math_fround(0.0);
 $91 = (($this) + 2152|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($t1to0) + 16|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 HEAPF32[$89>>2] = $93;
 $94 = (($t1to0) + 20|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 HEAPF32[$90>>2] = $95;
 $96 = (($t1to0) + 24|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 HEAPF32[$91>>2] = $97;
 $98 = (($this) + 2180|0);
 HEAP32[$98>>2] = $polyData0;
 $99 = (($this) + 2184|0);
 HEAP32[$99>>2] = $world0;
 $100 = (($this) + 2188|0);
 HEAP32[$100>>2] = $world1;
 $101 = (($this) + 2192|0);
 HEAP32[$101>>2] = $convexScaling;
 $102 = (($this) + 2196|0);
 HEAPF32[$102>>2] = $contactDistance;
 $103 = (($this) + 2201|0);
 $104 = $idtConvexScale&1;
 HEAP8[$103>>0] = $104;
 $105 = (($this) + 2204|0);
 HEAPF32[$105>>2] = $cCCDEpsilon;
 $106 = (($this) + 2208|0);
 HEAP32[$106>>2] = $transform0;
 $107 = (($this) + 2212|0);
 HEAP32[$107>>2] = $transform1;
 $108 = (($this) + 2216|0);
 HEAP32[$108>>2] = $contactBuffer;
 $109 = (($delayedContacts) + 4|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = ($110|0)==(0);
 if ($111) {
  $114 = $polyData0;$151 = $world0;
 } else {
  HEAP32[$109>>2] = 0;
  $$pre = HEAP32[$98>>2]|0;
  $$pre5 = HEAP32[$99>>2]|0;
  $114 = $$pre;$151 = $$pre5;
 }
 $112 = (($this) + 2220|0);
 HEAP8[$112>>0] = 0;
 $113 = Math_fround(HEAPF32[$114>>2]);
 $115 = Math_fround(HEAPF32[$23>>2]);
 $116 = Math_fround($113 * $115);
 $117 = Math_fround(HEAPF32[$25>>2]);
 $118 = Math_fround($113 * $117);
 $119 = Math_fround(HEAPF32[$27>>2]);
 $120 = Math_fround($113 * $119);
 $121 = (($114) + 4|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround(HEAPF32[$29>>2]);
 $124 = Math_fround($122 * $123);
 $125 = Math_fround(HEAPF32[$32>>2]);
 $126 = Math_fround($122 * $125);
 $127 = Math_fround(HEAPF32[$34>>2]);
 $128 = Math_fround($122 * $127);
 $129 = Math_fround($116 + $124);
 $130 = Math_fround($118 + $126);
 $131 = Math_fround($120 + $128);
 $132 = (($114) + 8|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround(HEAPF32[$36>>2]);
 $135 = Math_fround($133 * $134);
 $136 = Math_fround(HEAPF32[$38>>2]);
 $137 = Math_fround($133 * $136);
 $138 = Math_fround(HEAPF32[$40>>2]);
 $139 = Math_fround($133 * $138);
 $140 = Math_fround($129 + $135);
 $141 = Math_fround($130 + $137);
 $142 = Math_fround($131 + $139);
 $143 = Math_fround($140 + $45);
 $144 = Math_fround($141 + $47);
 $145 = Math_fround($142 + $49);
 $146 = (($this) + 2156|0);
 HEAPF32[$146>>2] = $143;
 $147 = (($this) + 2160|0);
 HEAPF32[$147>>2] = $144;
 $148 = (($this) + 2164|0);
 HEAPF32[$148>>2] = $145;
 $149 = Math_fround(HEAPF32[$114>>2]);
 $150 = Math_fround(HEAPF32[$151>>2]);
 $152 = Math_fround($149 * $150);
 $153 = (($151) + 4|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = Math_fround($149 * $154);
 $156 = (($151) + 8|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = Math_fround($149 * $157);
 $159 = Math_fround(HEAPF32[$121>>2]);
 $160 = (($151) + 12|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = Math_fround($159 * $161);
 $163 = (($151) + 16|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = Math_fround($159 * $164);
 $166 = (($151) + 20|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = Math_fround($159 * $167);
 $169 = Math_fround($152 + $162);
 $170 = Math_fround($155 + $165);
 $171 = Math_fround($158 + $168);
 $172 = Math_fround(HEAPF32[$132>>2]);
 $173 = (($151) + 24|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = Math_fround($172 * $174);
 $176 = (($151) + 28|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = Math_fround($172 * $177);
 $179 = (($151) + 32|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = Math_fround($172 * $180);
 $182 = Math_fround($169 + $175);
 $183 = Math_fround($170 + $178);
 $184 = Math_fround($171 + $181);
 $185 = (($151) + 36|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = Math_fround($182 + $186);
 $188 = (($151) + 40|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = Math_fround($183 + $189);
 $191 = (($151) + 44|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = Math_fround($184 + $192);
 $194 = (($this) + 2168|0);
 HEAPF32[$194>>2] = $187;
 $195 = (($this) + 2172|0);
 HEAPF32[$195>>2] = $190;
 $196 = (($this) + 2176|0);
 HEAPF32[$196>>2] = $193;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29ConvexVsMeshContactGeneration16generateContactsERKNS_7PxPlaneEPKNS_6PxVec3ERS6_RS5_fj($this,$localPlane,$localPoints,$triCenter,$groupAxis,$groupMinDepth,$index) {
 $this = $this|0;
 $localPlane = $localPlane|0;
 $localPoints = $localPoints|0;
 $triCenter = $triCenter|0;
 $groupAxis = $groupAxis|0;
 $groupMinDepth = Math_fround($groupMinDepth);
 $index = $index|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0;
 var $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = Math_fround(0), $330 = 0;
 var $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0);
 var $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0);
 var $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0);
 var $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0);
 var $511 = 0, $512 = Math_fround(0), $513 = 0, $514 = Math_fround(0), $515 = 0, $516 = Math_fround(0), $517 = Math_fround(0), $518 = 0, $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = 0, $546 = Math_fround(0), $547 = 0;
 var $548 = Math_fround(0), $549 = 0, $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $RotT0 = 0, $RotT1 = 0, $contactGenPositionShiftVec = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i1 = Math_fround(0), $hullNormalWorld = 0, $m0to1_ = 0, $m1to0_ = 0, $scaledVertices0 = 0, $shapeSpacePlane0 = 0, $stackIndices0 = 0, $triNormalWorld = 0, $world0_ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $0 = sp + 288|0;
 $shapeSpacePlane0 = sp + 272|0;
 $hullNormalWorld = sp + 256|0;
 $triNormalWorld = sp + 244|0;
 $contactGenPositionShiftVec = sp + 232|0;
 $world0_ = sp + 184|0;
 $m0to1_ = sp + 136|0;
 $m1to0_ = sp + 48|0;
 $scaledVertices0 = sp + 40|0;
 $stackIndices0 = sp + 36|0;
 $RotT0 = sp;
 $RotT1 = sp + 96|0;
 $1 = (($this) + 2188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$triCenter>>2]);
 $4 = Math_fround(HEAPF32[$2>>2]);
 $5 = Math_fround($3 * $4);
 $6 = (($2) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($3 * $7);
 $9 = (($2) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($3 * $10);
 $12 = (($triCenter) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($2) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 * $15);
 $17 = (($2) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($13 * $18);
 $20 = (($2) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($13 * $21);
 $23 = Math_fround($5 + $16);
 $24 = Math_fround($8 + $19);
 $25 = Math_fround($11 + $22);
 $26 = (($triCenter) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($2) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($27 * $29);
 $31 = (($2) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($27 * $32);
 $34 = (($2) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($27 * $35);
 $37 = Math_fround($23 + $30);
 $38 = Math_fround($24 + $33);
 $39 = Math_fround($25 + $36);
 $40 = (($2) + 36|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($37 + $41);
 $43 = (($2) + 40|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($38 + $44);
 $46 = (($2) + 44|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($39 + $47);
 $49 = (($this) + 2168|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($50 - $42);
 $52 = (($this) + 2172|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 - $45);
 $55 = (($this) + 2176|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 - $48);
 $58 = Math_fround(HEAPF32[$groupAxis>>2]);
 $59 = Math_fround($51 * $58);
 $60 = (($groupAxis) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($54 * $61);
 $63 = Math_fround($59 + $62);
 $64 = (($groupAxis) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($57 * $65);
 $67 = Math_fround($63 + $66);
 $68 = $67 < Math_fround(0.0);
 if ($68) {
  $69 = Math_fround(-$58);
  $70 = Math_fround(-$61);
  $71 = Math_fround(-$65);
  HEAPF32[$groupAxis>>2] = $69;
  HEAPF32[$60>>2] = $70;
  HEAPF32[$64>>2] = $71;
  $81 = $69;$83 = $70;$85 = $71;
 } else {
  $81 = $58;$83 = $61;$85 = $65;
 }
 $72 = (($this) + 2180|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73) + 68|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($this) + 2192|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($this) + 2184|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = Math_fround(-$81);
 $82 = Math_fround(-$83);
 $84 = Math_fround(-$85);
 $86 = Math_fround(HEAPF32[$79>>2]);
 $87 = Math_fround($86 * $80);
 $88 = (($79) + 4|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($89 * $82);
 $91 = Math_fround($87 + $90);
 $92 = (($79) + 8|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($93 * $84);
 $95 = Math_fround($91 + $94);
 $96 = (($79) + 12|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 * $80);
 $99 = (($79) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 * $82);
 $102 = Math_fround($98 + $101);
 $103 = (($79) + 20|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($104 * $84);
 $106 = Math_fround($102 + $105);
 $107 = (($79) + 24|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($108 * $80);
 $110 = (($79) + 28|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($111 * $82);
 $113 = Math_fround($109 + $112);
 $114 = (($79) + 32|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($115 * $84);
 $117 = Math_fround($113 + $116);
 HEAPF32[$0>>2] = $95;
 $118 = (($0) + 4|0);
 HEAPF32[$118>>2] = $106;
 $119 = (($0) + 8|0);
 HEAPF32[$119>>2] = $117;
 $120 = (FUNCTION_TABLE_iiii[$75 & 2047]($73,$77,$0)|0);
 $121 = HEAP32[$72>>2]|0;
 $122 = (($121) + 24|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($123) + (($120*20)|0)|0);
 $125 = (($this) + 2201|0);
 $126 = HEAP8[$125>>0]|0;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  $141 = HEAP32[$76>>2]|0;
  $142 = ((($123) + (($120*20)|0)|0) + 12|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = (($shapeSpacePlane0) + 12|0);
  $145 = (($141) + 36|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = Math_fround(HEAPF32[$124>>2]);
  $148 = Math_fround($146 * $147);
  $149 = (($141) + 40|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $151 = ((($123) + (($120*20)|0)|0) + 4|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = Math_fround($150 * $152);
  $154 = Math_fround($148 + $153);
  $155 = (($141) + 44|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = ((($123) + (($120*20)|0)|0) + 8|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = Math_fround($156 * $158);
  $160 = Math_fround($154 + $159);
  $161 = (($141) + 48|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($147 * $162);
  $164 = (($141) + 52|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  $166 = Math_fround($152 * $165);
  $167 = Math_fround($163 + $166);
  $168 = (($141) + 56|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = Math_fround($158 * $169);
  $171 = Math_fround($167 + $170);
  $172 = (($141) + 60|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($147 * $173);
  $175 = (($141) + 64|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = Math_fround($152 * $176);
  $178 = Math_fround($174 + $177);
  $179 = (($141) + 68|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = Math_fround($158 * $180);
  $182 = Math_fround($178 + $181);
  $183 = Math_fround($160 * $160);
  $184 = Math_fround($171 * $171);
  $185 = Math_fround($183 + $184);
  $186 = Math_fround($182 * $182);
  $187 = Math_fround($185 + $186);
  $188 = (Math_fround(Math_sqrt((Math_fround($187)))));
  $189 = Math_fround(Math_fround(1.0) / $188);
  $190 = Math_fround($160 * $189);
  $191 = Math_fround($171 * $189);
  $192 = Math_fround($182 * $189);
  HEAPF32[$shapeSpacePlane0>>2] = $190;
  $193 = (($shapeSpacePlane0) + 4|0);
  HEAPF32[$193>>2] = $191;
  $194 = (($shapeSpacePlane0) + 8|0);
  HEAPF32[$194>>2] = $192;
  $195 = Math_fround($143 * $189);
  HEAPF32[$144>>2] = $195;
  $199 = $190;$209 = $191;$222 = $192;
 } else {
  $128 = HEAP32[$124>>2]|0;
  HEAP32[$shapeSpacePlane0>>2] = $128;
  $129 = ((($123) + (($120*20)|0)|0) + 4|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($shapeSpacePlane0) + 4|0);
  HEAP32[$131>>2] = $130;
  $132 = ((($123) + (($120*20)|0)|0) + 8|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = (($shapeSpacePlane0) + 8|0);
  HEAP32[$134>>2] = $133;
  $135 = ((($123) + (($120*20)|0)|0) + 12|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = (($shapeSpacePlane0) + 12|0);
  HEAP32[$137>>2] = $136;
  $138 = (HEAP32[tempDoublePtr>>2]=$128,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $139 = (HEAP32[tempDoublePtr>>2]=$130,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $140 = (HEAP32[tempDoublePtr>>2]=$133,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $199 = $138;$209 = $139;$222 = $140;
 }
 $196 = HEAP32[$78>>2]|0;
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = Math_fround($199 * $197);
 $200 = (($196) + 4|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = Math_fround($199 * $201);
 $203 = (($196) + 8|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = Math_fround($199 * $204);
 $206 = (($196) + 12|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = Math_fround($209 * $207);
 $210 = (($196) + 16|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = Math_fround($209 * $211);
 $213 = (($196) + 20|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = Math_fround($209 * $214);
 $216 = Math_fround($198 + $208);
 $217 = Math_fround($202 + $212);
 $218 = Math_fround($205 + $215);
 $219 = (($196) + 24|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = Math_fround($222 * $220);
 $223 = (($196) + 28|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = Math_fround($222 * $224);
 $226 = (($196) + 32|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 $228 = Math_fround($222 * $227);
 $229 = Math_fround($216 + $221);
 $230 = Math_fround($217 + $225);
 $231 = Math_fround($218 + $228);
 HEAPF32[$hullNormalWorld>>2] = $229;
 $232 = (($hullNormalWorld) + 4|0);
 HEAPF32[$232>>2] = $230;
 $233 = (($hullNormalWorld) + 8|0);
 HEAPF32[$233>>2] = $231;
 $234 = Math_fround(HEAPF32[$groupAxis>>2]);
 $235 = Math_fround($229 * $234);
 $236 = Math_fround(HEAPF32[$60>>2]);
 $237 = Math_fround($230 * $236);
 $238 = Math_fround($235 + $237);
 $239 = Math_fround(HEAPF32[$64>>2]);
 $240 = Math_fround($231 * $239);
 $241 = Math_fround($238 + $240);
 $fabsf$i$i1 = (Math_fround(Math_abs((Math_fround($241)))));
 $242 = HEAP32[$1>>2]|0;
 $243 = Math_fround(HEAPF32[$localPlane>>2]);
 $244 = Math_fround(HEAPF32[$242>>2]);
 $245 = Math_fround($243 * $244);
 $246 = (($242) + 4|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = Math_fround($243 * $247);
 $249 = (($242) + 8|0);
 $250 = Math_fround(HEAPF32[$249>>2]);
 $251 = Math_fround($243 * $250);
 $252 = (($localPlane) + 4|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = (($242) + 12|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = Math_fround($253 * $255);
 $257 = (($242) + 16|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 $259 = Math_fround($253 * $258);
 $260 = (($242) + 20|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = Math_fround($253 * $261);
 $263 = Math_fround($245 + $256);
 $264 = Math_fround($248 + $259);
 $265 = Math_fround($251 + $262);
 $266 = (($localPlane) + 8|0);
 $267 = Math_fround(HEAPF32[$266>>2]);
 $268 = (($242) + 24|0);
 $269 = Math_fround(HEAPF32[$268>>2]);
 $270 = Math_fround($267 * $269);
 $271 = (($242) + 28|0);
 $272 = Math_fround(HEAPF32[$271>>2]);
 $273 = Math_fround($267 * $272);
 $274 = (($242) + 32|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = Math_fround($267 * $275);
 $277 = Math_fround($263 + $270);
 $278 = Math_fround($264 + $273);
 $279 = Math_fround($265 + $276);
 HEAPF32[$triNormalWorld>>2] = $277;
 $280 = (($triNormalWorld) + 4|0);
 HEAPF32[$280>>2] = $278;
 $281 = (($triNormalWorld) + 8|0);
 HEAPF32[$281>>2] = $279;
 $282 = Math_fround($277 * $234);
 $283 = Math_fround($278 * $236);
 $284 = Math_fround($282 + $283);
 $285 = Math_fround($279 * $239);
 $286 = Math_fround($284 + $285);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($286)))));
 $287 = $fabsf$i$i1 > $fabsf$i$i;
 $288 = Math_fround(-$groupMinDepth);
 $289 = $groupMinDepth <= Math_fround(-0.0);
 $290 = $289 ? $288 : Math_fround(0.0);
 $291 = (($this) + 2204|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = Math_fround($290 + $292);
 $294 = Math_fround($234 * $293);
 $295 = Math_fround($236 * $293);
 $296 = Math_fround($239 * $293);
 HEAPF32[$contactGenPositionShiftVec>>2] = $294;
 $297 = (($contactGenPositionShiftVec) + 4|0);
 HEAPF32[$297>>2] = $295;
 $298 = (($contactGenPositionShiftVec) + 8|0);
 HEAPF32[$298>>2] = $296;
 $299 = HEAP32[$78>>2]|0;
 $300 = Math_fround(HEAPF32[$299>>2]);
 HEAPF32[$world0_>>2] = $300;
 $301 = (($299) + 4|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = (($world0_) + 4|0);
 HEAPF32[$303>>2] = $302;
 $304 = (($299) + 8|0);
 $305 = Math_fround(HEAPF32[$304>>2]);
 $306 = (($world0_) + 8|0);
 HEAPF32[$306>>2] = $305;
 $307 = (($299) + 12|0);
 $308 = Math_fround(HEAPF32[$307>>2]);
 $309 = (($world0_) + 12|0);
 HEAPF32[$309>>2] = $308;
 $310 = (($299) + 16|0);
 $311 = Math_fround(HEAPF32[$310>>2]);
 $312 = (($world0_) + 16|0);
 HEAPF32[$312>>2] = $311;
 $313 = (($299) + 20|0);
 $314 = Math_fround(HEAPF32[$313>>2]);
 $315 = (($world0_) + 20|0);
 HEAPF32[$315>>2] = $314;
 $316 = (($299) + 24|0);
 $317 = Math_fround(HEAPF32[$316>>2]);
 $318 = (($world0_) + 24|0);
 HEAPF32[$318>>2] = $317;
 $319 = (($299) + 28|0);
 $320 = Math_fround(HEAPF32[$319>>2]);
 $321 = (($world0_) + 28|0);
 HEAPF32[$321>>2] = $320;
 $322 = (($299) + 32|0);
 $323 = Math_fround(HEAPF32[$322>>2]);
 $324 = (($world0_) + 32|0);
 HEAPF32[$324>>2] = $323;
 $325 = (($299) + 36|0);
 $326 = Math_fround(HEAPF32[$325>>2]);
 $327 = (($world0_) + 36|0);
 HEAPF32[$327>>2] = $326;
 $328 = (($299) + 40|0);
 $329 = Math_fround(HEAPF32[$328>>2]);
 $330 = (($world0_) + 40|0);
 HEAPF32[$330>>2] = $329;
 $331 = (($299) + 44|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = (($world0_) + 44|0);
 HEAPF32[$333>>2] = $332;
 $334 = (($this) + 2208|0);
 $335 = HEAP32[$334>>2]|0;
 $336 = Math_fround(HEAPF32[$335>>2]);
 $337 = (($335) + 4|0);
 $338 = Math_fround(HEAPF32[$337>>2]);
 $339 = (($335) + 8|0);
 $340 = Math_fround(HEAPF32[$339>>2]);
 $341 = (($335) + 12|0);
 $342 = Math_fround(HEAPF32[$341>>2]);
 $343 = Math_fround($326 - $294);
 HEAPF32[$327>>2] = $343;
 $344 = Math_fround($329 - $295);
 HEAPF32[$330>>2] = $344;
 $345 = Math_fround($332 - $296);
 HEAPF32[$333>>2] = $345;
 $346 = (($this) + 2212|0);
 $347 = HEAP32[$346>>2]|0;
 $348 = Math_fround(HEAPF32[$347>>2]);
 $349 = Math_fround(-$348);
 $350 = (($347) + 4|0);
 $351 = Math_fround(HEAPF32[$350>>2]);
 $352 = Math_fround(-$351);
 $353 = (($347) + 8|0);
 $354 = Math_fround(HEAPF32[$353>>2]);
 $355 = Math_fround(-$354);
 $356 = (($347) + 12|0);
 $357 = Math_fround(HEAPF32[$356>>2]);
 $358 = (($347) + 16|0);
 $359 = Math_fround(HEAPF32[$358>>2]);
 $360 = Math_fround($343 - $359);
 $361 = (($347) + 20|0);
 $362 = Math_fround(HEAPF32[$361>>2]);
 $363 = Math_fround($344 - $362);
 $364 = (($347) + 24|0);
 $365 = Math_fround(HEAPF32[$364>>2]);
 $366 = Math_fround($345 - $365);
 $367 = Math_fround($360 * Math_fround(2.0));
 $368 = Math_fround($363 * Math_fround(2.0));
 $369 = Math_fround($366 * Math_fround(2.0));
 $370 = Math_fround($357 * $357);
 $371 = Math_fround($370 + Math_fround(-0.5));
 $372 = Math_fround($367 * $349);
 $373 = Math_fround($368 * $352);
 $374 = Math_fround($372 + $373);
 $375 = Math_fround($369 * $355);
 $376 = Math_fround($374 + $375);
 $377 = Math_fround($371 * $367);
 $378 = Math_fround($369 * $352);
 $379 = Math_fround($368 * $355);
 $380 = Math_fround($378 - $379);
 $381 = Math_fround($357 * $380);
 $382 = Math_fround($377 + $381);
 $383 = Math_fround($376 * $349);
 $384 = Math_fround($383 + $382);
 $385 = Math_fround($371 * $368);
 $386 = Math_fround($367 * $355);
 $387 = Math_fround($369 * $349);
 $388 = Math_fround($386 - $387);
 $389 = Math_fround($357 * $388);
 $390 = Math_fround($385 + $389);
 $391 = Math_fround($376 * $352);
 $392 = Math_fround($391 + $390);
 $393 = Math_fround($371 * $369);
 $394 = Math_fround($368 * $349);
 $395 = Math_fround($367 * $352);
 $396 = Math_fround($394 - $395);
 $397 = Math_fround($357 * $396);
 $398 = Math_fround($393 + $397);
 $399 = Math_fround($376 * $355);
 $400 = Math_fround($398 + $399);
 $401 = Math_fround($336 * $357);
 $402 = Math_fround($342 * $349);
 $403 = Math_fround($402 + $401);
 $404 = Math_fround($340 * $352);
 $405 = Math_fround($404 + $403);
 $406 = Math_fround($338 * $355);
 $407 = Math_fround($405 - $406);
 $408 = Math_fround($338 * $357);
 $409 = Math_fround($342 * $352);
 $410 = Math_fround($409 + $408);
 $411 = Math_fround($336 * $355);
 $412 = Math_fround($411 + $410);
 $413 = Math_fround($340 * $349);
 $414 = Math_fround($412 - $413);
 $415 = Math_fround($340 * $357);
 $416 = Math_fround($342 * $355);
 $417 = Math_fround($416 + $415);
 $418 = Math_fround($338 * $349);
 $419 = Math_fround($418 + $417);
 $420 = Math_fround($336 * $352);
 $421 = Math_fround($419 - $420);
 $422 = Math_fround($342 * $357);
 $423 = Math_fround($336 * $349);
 $424 = Math_fround($422 - $423);
 $425 = Math_fround($338 * $352);
 $426 = Math_fround($424 - $425);
 $427 = Math_fround($340 * $355);
 $428 = Math_fround($426 - $427);
 $429 = Math_fround(-$336);
 $430 = Math_fround(-$338);
 $431 = Math_fround(-$340);
 $432 = Math_fround($359 - $343);
 $433 = Math_fround($362 - $344);
 $434 = Math_fround($365 - $345);
 $435 = Math_fround($432 * Math_fround(2.0));
 $436 = Math_fround($433 * Math_fround(2.0));
 $437 = Math_fround($434 * Math_fround(2.0));
 $438 = Math_fround($342 * $342);
 $439 = Math_fround($438 + Math_fround(-0.5));
 $440 = Math_fround($435 * $429);
 $441 = Math_fround($436 * $430);
 $442 = Math_fround($440 + $441);
 $443 = Math_fround($437 * $431);
 $444 = Math_fround($442 + $443);
 $445 = Math_fround($439 * $435);
 $446 = Math_fround($437 * $430);
 $447 = Math_fround($436 * $431);
 $448 = Math_fround($446 - $447);
 $449 = Math_fround($342 * $448);
 $450 = Math_fround($445 + $449);
 $451 = Math_fround($444 * $429);
 $452 = Math_fround($451 + $450);
 $453 = Math_fround($439 * $436);
 $454 = Math_fround($435 * $431);
 $455 = Math_fround($437 * $429);
 $456 = Math_fround($454 - $455);
 $457 = Math_fround($342 * $456);
 $458 = Math_fround($453 + $457);
 $459 = Math_fround($444 * $430);
 $460 = Math_fround($459 + $458);
 $461 = Math_fround($439 * $437);
 $462 = Math_fround($436 * $429);
 $463 = Math_fround($435 * $430);
 $464 = Math_fround($462 - $463);
 $465 = Math_fround($342 * $464);
 $466 = Math_fround($461 + $465);
 $467 = Math_fround($444 * $431);
 $468 = Math_fround($466 + $467);
 $469 = Math_fround($342 * $348);
 $470 = Math_fround($357 * $429);
 $471 = Math_fround($469 + $470);
 $472 = Math_fround($354 * $430);
 $473 = Math_fround($472 + $471);
 $474 = Math_fround($351 * $431);
 $475 = Math_fround($473 - $474);
 $476 = Math_fround($342 * $351);
 $477 = Math_fround($357 * $430);
 $478 = Math_fround($476 + $477);
 $479 = Math_fround($348 * $431);
 $480 = Math_fround($479 + $478);
 $481 = Math_fround($354 * $429);
 $482 = Math_fround($480 - $481);
 $483 = Math_fround($342 * $354);
 $484 = Math_fround($357 * $431);
 $485 = Math_fround($483 + $484);
 $486 = Math_fround($351 * $429);
 $487 = Math_fround($486 + $485);
 $488 = Math_fround($348 * $430);
 $489 = Math_fround($487 - $488);
 $490 = Math_fround($348 * $429);
 $491 = Math_fround($422 - $490);
 $492 = Math_fround($351 * $430);
 $493 = Math_fround($491 - $492);
 $494 = Math_fround($354 * $431);
 $495 = Math_fround($493 - $494);
 $496 = Math_fround($407 + $407);
 $497 = Math_fround($414 + $414);
 $498 = Math_fround($421 + $421);
 $499 = Math_fround($428 * $496);
 $500 = Math_fround($428 * $497);
 $501 = Math_fround($428 * $498);
 $502 = Math_fround($407 * $496);
 $503 = Math_fround($407 * $497);
 $504 = Math_fround($407 * $498);
 $505 = Math_fround($414 * $497);
 $506 = Math_fround($414 * $498);
 $507 = Math_fround($421 * $498);
 $508 = Math_fround(Math_fround(1.0) - $505);
 $509 = Math_fround($508 - $507);
 HEAPF32[$m0to1_>>2] = $509;
 $510 = Math_fround($503 + $501);
 $511 = (($m0to1_) + 4|0);
 HEAPF32[$511>>2] = $510;
 $512 = Math_fround($504 - $500);
 $513 = (($m0to1_) + 8|0);
 HEAPF32[$513>>2] = $512;
 $514 = Math_fround($503 - $501);
 $515 = (($m0to1_) + 12|0);
 HEAPF32[$515>>2] = $514;
 $516 = Math_fround(Math_fround(1.0) - $502);
 $517 = Math_fround($516 - $507);
 $518 = (($m0to1_) + 16|0);
 HEAPF32[$518>>2] = $517;
 $519 = Math_fround($506 + $499);
 $520 = (($m0to1_) + 20|0);
 HEAPF32[$520>>2] = $519;
 $521 = Math_fround($504 + $500);
 $522 = (($m0to1_) + 24|0);
 HEAPF32[$522>>2] = $521;
 $523 = Math_fround($506 - $499);
 $524 = (($m0to1_) + 28|0);
 HEAPF32[$524>>2] = $523;
 $525 = Math_fround($516 - $505);
 $526 = (($m0to1_) + 32|0);
 HEAPF32[$526>>2] = $525;
 $527 = (($m0to1_) + 36|0);
 $528 = (($m0to1_) + 40|0);
 $529 = (($m0to1_) + 44|0);
 HEAPF32[$527>>2] = $384;
 HEAPF32[$528>>2] = $392;
 HEAPF32[$529>>2] = $400;
 $530 = Math_fround($475 + $475);
 $531 = Math_fround($482 + $482);
 $532 = Math_fround($489 + $489);
 $533 = Math_fround($495 * $530);
 $534 = Math_fround($495 * $531);
 $535 = Math_fround($495 * $532);
 $536 = Math_fround($475 * $530);
 $537 = Math_fround($475 * $531);
 $538 = Math_fround($475 * $532);
 $539 = Math_fround($482 * $531);
 $540 = Math_fround($482 * $532);
 $541 = Math_fround($489 * $532);
 $542 = Math_fround(Math_fround(1.0) - $539);
 $543 = Math_fround($542 - $541);
 HEAPF32[$m1to0_>>2] = $543;
 $544 = Math_fround($537 + $535);
 $545 = (($m1to0_) + 4|0);
 HEAPF32[$545>>2] = $544;
 $546 = Math_fround($538 - $534);
 $547 = (($m1to0_) + 8|0);
 HEAPF32[$547>>2] = $546;
 $548 = Math_fround($537 - $535);
 $549 = (($m1to0_) + 12|0);
 HEAPF32[$549>>2] = $548;
 $550 = Math_fround(Math_fround(1.0) - $536);
 $551 = Math_fround($550 - $541);
 $552 = (($m1to0_) + 16|0);
 HEAPF32[$552>>2] = $551;
 $553 = Math_fround($540 + $533);
 $554 = (($m1to0_) + 20|0);
 HEAPF32[$554>>2] = $553;
 $555 = Math_fround($538 + $534);
 $556 = (($m1to0_) + 24|0);
 HEAPF32[$556>>2] = $555;
 $557 = Math_fround($540 - $533);
 $558 = (($m1to0_) + 28|0);
 HEAPF32[$558>>2] = $557;
 $559 = Math_fround($550 - $539);
 $560 = (($m1to0_) + 32|0);
 HEAPF32[$560>>2] = $559;
 $561 = (($m1to0_) + 36|0);
 $562 = (($m1to0_) + 40|0);
 $563 = (($m1to0_) + 44|0);
 HEAPF32[$561>>2] = $452;
 HEAPF32[$562>>2] = $460;
 HEAPF32[$563>>2] = $468;
 $564 = HEAP8[$125>>0]|0;
 $565 = ($564<<24>>24)==(0);
 $566 = ((($123) + (($120*20)|0)|0) + 18|0);
 if ($565) {
  $567 = HEAP8[$566>>0]|0;
  $568 = $567&255;
  $569 = ($568*12)|0;
  $570 = STACKTOP; STACKTOP = STACKTOP + ((((1*$569)|0)+15)&-16)|0;;
  $571 = $567&255;
  $572 = STACKTOP; STACKTOP = STACKTOP + ((((1*$571)|0)+15)&-16)|0;;
  $586 = $570;$587 = $572;
 } else {
  $586 = 0;$587 = 0;
 }
 $573 = ($564<<24>>24)!=(0);
 $574 = HEAP32[$72>>2]|0;
 $575 = (($574) + 28|0);
 $576 = HEAP32[$575>>2]|0;
 $577 = (($574) + 32|0);
 $578 = HEAP32[$577>>2]|0;
 $579 = ((($123) + (($120*20)|0)|0) + 16|0);
 $580 = HEAP16[$579>>1]|0;
 $581 = $580&65535;
 $582 = (($578) + ($581)|0);
 $583 = HEAP8[$566>>0]|0;
 $584 = $583&255;
 $585 = HEAP32[$76>>2]|0;
 __ZN5physx2Gu15getScaledConvexERPNS_6PxVec3ERPhS2_S4_bPKS1_PKhjRKNS_2Cm23FastVertex2ShapeScalingE($scaledVertices0,$stackIndices0,$586,$587,$573,$576,$582,$584,$585);
 __ZN5physx2Gu23findRotationMatrixFromZERKNS_6PxVec3E($RotT0,$shapeSpacePlane0);
 __ZN5physx2Gu23findRotationMatrixFromZERKNS_6PxVec3E($RotT1,$localPlane);
 if ($287) {
  $588 = HEAP8[$566>>0]|0;
  $589 = $588&255;
  $590 = HEAP32[$scaledVertices0>>2]|0;
  $591 = HEAP32[$stackIndices0>>2]|0;
  $592 = HEAP32[$1>>2]|0;
  $593 = (($this) + 2216|0);
  $594 = HEAP32[$593>>2]|0;
  $595 = (__ZN5physx2Gu24contactPolygonPolygonExtEjPKNS_6PxVec3EPKhRKNS_2Cm8Matrix34ERKNS_7PxPlaneERKNS_7PxMat33EjS3_S5_S9_SC_SF_RS2_S9_S9_jjRNS0_13ContactBufferEbSG_f($589,$590,$591,$world0_,$shapeSpacePlane0,$RotT0,3,$localPoints,548824,$592,$localPlane,$RotT1,$hullNormalWorld,$m0to1_,$m1to0_,-1,$index,$594,1,$contactGenPositionShiftVec,$293)|0);
  if ($595) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $596 = HEAP32[$1>>2]|0;
  $597 = HEAP8[$566>>0]|0;
  $598 = $597&255;
  $599 = HEAP32[$scaledVertices0>>2]|0;
  $600 = HEAP32[$stackIndices0>>2]|0;
  $601 = (($this) + 2216|0);
  $602 = HEAP32[$601>>2]|0;
  $603 = (__ZN5physx2Gu24contactPolygonPolygonExtEjPKNS_6PxVec3EPKhRKNS_2Cm8Matrix34ERKNS_7PxPlaneERKNS_7PxMat33EjS3_S5_S9_SC_SF_RS2_S9_S9_jjRNS0_13ContactBufferEbSG_f(3,$localPoints,548824,$596,$localPlane,$RotT1,$598,$599,$600,$world0_,$shapeSpacePlane0,$RotT0,$triNormalWorld,$m1to0_,$m0to1_,-1,$index,$602,0,$contactGenPositionShiftVec,$293)|0);
  if ($603) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29ConvexVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($this,$verts,$triangleIndex,$triFlags,$vertInds) {
 $this = $this|0;
 $verts = $verts|0;
 $triangleIndex = $triangleIndex|0;
 $triFlags = $triFlags|0;
 $vertInds = $vertInds|0;
 var $$0 = 0, $$pr = 0, $$pr$pre = 0, $$pr25$pr = 0, $$pr25$pr$pre = 0, $$pre$i = 0, $$sum = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum30 = 0, $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum38 = 0;
 var $$sum39 = 0, $$sum40 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0);
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0);
 var $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0);
 var $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0);
 var $277 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0;
 var $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0);
 var $faceContact = 0, $groupAxis = 0, $groupMinDepth = 0, $localPlane = 0, $nextInd$0$i = 0, $nextInd$0$i15 = 0, $nextInd$0$i7 = 0, $nextInd$02$i = 0, $nextInd$02$i11 = 0, $nextInd$02$i3 = 0, $nextInd$03$i = 0, $nextInd$03$i14 = 0, $nextInd$03$i6 = 0, $triCenter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $localPlane = sp + 56|0;
 $triCenter = sp;
 $groupAxis = sp + 12|0;
 $groupMinDepth = sp + 24|0;
 $faceContact = sp + 72|0;
 $0 = sp + 40|0;
 $1 = sp + 48|0;
 $2 = sp + 32|0;
 $3 = (($verts) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$verts>>2]);
 $6 = Math_fround($4 - $5);
 $7 = (($verts) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($verts) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 - $10);
 $12 = (($verts) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($verts) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = (($verts) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 - $5);
 $20 = (($verts) + 28|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 - $10);
 $23 = (($verts) + 32|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 - $15);
 $26 = Math_fround($11 * $25);
 $27 = Math_fround($16 * $22);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($16 * $19);
 $30 = Math_fround($6 * $25);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround($6 * $22);
 $33 = Math_fround($11 * $19);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($28 * $28);
 $36 = Math_fround($31 * $31);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($34 * $34);
 $39 = Math_fround($38 + $37);
 $40 = $39 > Math_fround(0.0);
 if ($40) {
  $41 = (Math_fround(Math_sqrt((Math_fround($39)))));
  $42 = Math_fround(Math_fround(1.0) / $41);
  $43 = Math_fround($28 * $42);
  $44 = Math_fround($31 * $42);
  $45 = Math_fround($34 * $42);
  $46 = $43;$48 = $44;$50 = $45;
 } else {
  $46 = Math_fround(0.0);$48 = Math_fround(0.0);$50 = Math_fround(0.0);
 }
 HEAPF32[$localPlane>>2] = $46;
 $47 = (($localPlane) + 4|0);
 HEAPF32[$47>>2] = $48;
 $49 = (($localPlane) + 8|0);
 HEAPF32[$49>>2] = $50;
 $51 = Math_fround($46 * $5);
 $52 = Math_fround($48 * $10);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($50 * $15);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround(-$55);
 $57 = (($localPlane) + 12|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($this) + 2156|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 * $46);
 $61 = (($this) + 2160|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * $48);
 $64 = Math_fround($60 + $63);
 $65 = (($this) + 2164|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $50);
 $68 = Math_fround($64 + $67);
 $69 = Math_fround($68 - $55);
 $70 = $69 < Math_fround(0.0);
 if ($70) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = Math_fround($5 + $4);
 $72 = Math_fround($10 + $8);
 $73 = Math_fround($15 + $13);
 $74 = Math_fround($71 + $18);
 $75 = Math_fround($72 + $21);
 $76 = Math_fround($73 + $24);
 $77 = Math_fround($74 * Math_fround(0.333333343267440795898));
 $78 = Math_fround($75 * Math_fround(0.333333343267440795898));
 $79 = Math_fround($76 * Math_fround(0.333333343267440795898));
 HEAPF32[$triCenter>>2] = $77;
 $80 = (($triCenter) + 4|0);
 HEAPF32[$80>>2] = $78;
 $81 = (($triCenter) + 8|0);
 HEAPF32[$81>>2] = $79;
 $82 = (($this) + 2108|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($77 * $83);
 $85 = (($this) + 2112|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($77 * $86);
 $88 = (($this) + 2116|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($77 * $89);
 $91 = (($this) + 2120|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($78 * $92);
 $94 = (($this) + 2124|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($78 * $95);
 $97 = (($this) + 2128|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($78 * $98);
 $100 = Math_fround($84 + $93);
 $101 = Math_fround($87 + $96);
 $102 = Math_fround($90 + $99);
 $103 = (($this) + 2132|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($79 * $104);
 $106 = (($this) + 2136|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($79 * $107);
 $109 = (($this) + 2140|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($79 * $110);
 $112 = Math_fround($100 + $105);
 $113 = Math_fround($101 + $108);
 $114 = Math_fround($102 + $111);
 $115 = (($this) + 2144|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($112 + $116);
 $118 = (($this) + 2148|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($113 + $119);
 $121 = (($this) + 2152|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround($114 + $122);
 $124 = (($this) + 2180|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = (($this) + 2188|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = (($this) + 2060|0);
 $129 = (($this) + 2192|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (($this) + 2196|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($this) + 2201|0);
 $134 = HEAP8[$133>>0]|0;
 $135 = ($134<<24>>24)!=(0);
 $136 = (__ZL18triangleConvexTestRKN5physx2Gu13PolygonalDataEhjPKNS_6PxVec3ERKNS_7PxPlaneERS5_RKNS_2Cm8Matrix34ESE_SE_SE_RKNSB_23FastVertex2ShapeScalingEfRS4_RfRbb($125,$triFlags,$verts,$localPlane,$117,$120,$123,$127,$128,$82,$130,$132,$groupAxis,$groupMinDepth,$faceContact,$135)|0);
 if (!($136)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $137 = HEAP8[$faceContact>>0]|0;
 $138 = ($137<<24>>24)==(0);
 if ($138) {
  $231 = HEAP32[$this>>2]|0;
  $232 = (($231) + 4|0);
  $233 = HEAP32[$232>>2]|0;
  $234 = (($233) + 17)|0;
  $235 = HEAP32[$231>>2]|0;
  $236 = ($234>>>0)>($235>>>0);
  if ($236) {
   (__ZN5physx2Gu9Container6ResizeEj($231,17)|0);
   $$pre$i = HEAP32[$232>>2]|0;
   $240 = $$pre$i;
  } else {
   $240 = $233;
  }
  $237 = (($231) + 8|0);
  $238 = HEAP32[$237>>2]|0;
  $239 = (($238) + ($240<<2)|0);
  $241 = (($240) + 17)|0;
  HEAP32[$232>>2] = $241;
  HEAP32[$239>>2] = $triangleIndex;
  $$sum = (($240) + 1)|0;
  $242 = (($238) + ($$sum<<2)|0);
  $243 = Math_fround(HEAPF32[$verts>>2]);
  HEAPF32[$242>>2] = $243;
  $244 = Math_fround(HEAPF32[$9>>2]);
  $$sum26 = (($240) + 2)|0;
  $245 = (($238) + ($$sum26<<2)|0);
  HEAPF32[$245>>2] = $244;
  $246 = Math_fround(HEAPF32[$14>>2]);
  $$sum27 = (($240) + 3)|0;
  $247 = (($238) + ($$sum27<<2)|0);
  HEAPF32[$247>>2] = $246;
  $$sum28 = (($240) + 4)|0;
  $248 = (($238) + ($$sum28<<2)|0);
  $249 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$248>>2] = $249;
  $250 = Math_fround(HEAPF32[$7>>2]);
  $$sum29 = (($240) + 5)|0;
  $251 = (($238) + ($$sum29<<2)|0);
  HEAPF32[$251>>2] = $250;
  $252 = Math_fround(HEAPF32[$12>>2]);
  $$sum30 = (($240) + 6)|0;
  $253 = (($238) + ($$sum30<<2)|0);
  HEAPF32[$253>>2] = $252;
  $$sum31 = (($240) + 7)|0;
  $254 = (($238) + ($$sum31<<2)|0);
  $255 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$254>>2] = $255;
  $256 = Math_fround(HEAPF32[$20>>2]);
  $$sum32 = (($240) + 8)|0;
  $257 = (($238) + ($$sum32<<2)|0);
  HEAPF32[$257>>2] = $256;
  $258 = Math_fround(HEAPF32[$23>>2]);
  $$sum33 = (($240) + 9)|0;
  $259 = (($238) + ($$sum33<<2)|0);
  HEAPF32[$259>>2] = $258;
  $260 = HEAP32[$vertInds>>2]|0;
  $$sum34 = (($240) + 10)|0;
  $261 = (($238) + ($$sum34<<2)|0);
  HEAP32[$261>>2] = $260;
  $262 = (($vertInds) + 4|0);
  $263 = HEAP32[$262>>2]|0;
  $$sum35 = (($240) + 11)|0;
  $264 = (($238) + ($$sum35<<2)|0);
  HEAP32[$264>>2] = $263;
  $265 = (($vertInds) + 8|0);
  $266 = HEAP32[$265>>2]|0;
  $$sum36 = (($240) + 12)|0;
  $267 = (($238) + ($$sum36<<2)|0);
  HEAP32[$267>>2] = $266;
  $$sum37 = (($240) + 13)|0;
  $268 = (($238) + ($$sum37<<2)|0);
  $269 = Math_fround(HEAPF32[$groupAxis>>2]);
  HEAPF32[$268>>2] = $269;
  $270 = (($groupAxis) + 4|0);
  $271 = Math_fround(HEAPF32[$270>>2]);
  $$sum38 = (($240) + 14)|0;
  $272 = (($238) + ($$sum38<<2)|0);
  HEAPF32[$272>>2] = $271;
  $273 = (($groupAxis) + 8|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $$sum39 = (($240) + 15)|0;
  $275 = (($238) + ($$sum39<<2)|0);
  HEAPF32[$275>>2] = $274;
  $276 = Math_fround(HEAPF32[$groupMinDepth>>2]);
  $$sum40 = (($240) + 16)|0;
  $277 = (($238) + ($$sum40<<2)|0);
  HEAPF32[$277>>2] = $276;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $139 = Math_fround(HEAPF32[$groupMinDepth>>2]);
 $140 = (__ZNK5physx2Gu29ConvexVsMeshContactGeneration16generateContactsERKNS_7PxPlaneEPKNS_6PxVec3ERS6_RS5_fj($this,$localPlane,$verts,$triCenter,$groupAxis,$139,$triangleIndex)|0);
 if (!($140)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $141 = (($this) + 2220|0);
 HEAP8[$141>>0] = 1;
 $142 = (($this) + 4|0);
 $143 = HEAP32[$vertInds>>2]|0;
 $144 = (($vertInds) + 4|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = ($143>>>0)<($145>>>0);
 $147 = $146 ? $143 : $145;
 HEAP32[$0>>2] = $147;
 $148 = $146 ? $145 : $143;
 $149 = (($0) + 4|0);
 HEAP32[$149>>2] = $148;
 (__ZN5physx2Gu8CacheMapINS0_10CachedEdgeELj128EE7addDataERKS2_($142,$0)|0);
 $150 = HEAP32[$vertInds>>2]|0;
 $151 = (($vertInds) + 8|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = ($150>>>0)<($152>>>0);
 $154 = $153 ? $150 : $152;
 HEAP32[$1>>2] = $154;
 $155 = $153 ? $152 : $150;
 $156 = (($1) + 4|0);
 HEAP32[$156>>2] = $155;
 (__ZN5physx2Gu8CacheMapINS0_10CachedEdgeELj128EE7addDataERKS2_($142,$1)|0);
 $157 = HEAP32[$144>>2]|0;
 $158 = HEAP32[$151>>2]|0;
 $159 = ($157>>>0)<($158>>>0);
 $160 = $159 ? $157 : $158;
 HEAP32[$2>>2] = $160;
 $161 = $159 ? $158 : $157;
 $162 = (($2) + 4|0);
 HEAP32[$162>>2] = $161;
 (__ZN5physx2Gu8CacheMapINS0_10CachedEdgeELj128EE7addDataERKS2_($142,$2)|0);
 $163 = HEAP32[$vertInds>>2]|0;
 $164 = (($this) + 2056|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = ($165|0)==(128);
 if ($166) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $167 = $163 & 127;
 $168 = ((($this) + ($167)|0) + 1928|0);
 $nextInd$02$i11 = HEAP8[$168>>0]|0;
 $169 = ($nextInd$02$i11<<24>>24)==(-1);
 L23: do {
  if ($169) {
   $178 = $165&255;
   HEAP8[$168>>0] = $178;
   label = 14;
  } else {
   $170 = $nextInd$02$i11&255;
   $172 = $170;$nextInd$03$i14 = $nextInd$02$i11;
   while(1) {
    $171 = ((($this) + ($172<<2)|0) + 1288|0);
    $173 = HEAP32[$171>>2]|0;
    $174 = ($173|0)==($163|0);
    if ($174) {
     $$pr = $165;
     break L23;
    }
    $175 = ((($this) + ($172)|0) + 1800|0);
    $nextInd$0$i15 = HEAP8[$175>>0]|0;
    $176 = $nextInd$0$i15&255;
    $177 = ($nextInd$0$i15<<24>>24)==(-1);
    if ($177) {
     break;
    } else {
     $172 = $176;$nextInd$03$i14 = $nextInd$0$i15;
    }
   }
   $179 = $165&255;
   $180 = $nextInd$03$i14&255;
   $181 = ((($this) + ($180)|0) + 1800|0);
   HEAP8[$181>>0] = $179;
   label = 14;
  }
 } while(0);
 if ((label|0) == 14) {
  $182 = HEAP32[$164>>2]|0;
  $183 = ((($this) + ($182)|0) + 1800|0);
  HEAP8[$183>>0] = -1;
  $184 = HEAP32[$164>>2]|0;
  $185 = (($184) + 1)|0;
  HEAP32[$164>>2] = $185;
  $186 = ((($this) + ($184<<2)|0) + 1288|0);
  HEAP32[$186>>2] = $163;
  $$pr$pre = HEAP32[$164>>2]|0;
  $$pr = $$pr$pre;
 }
 $187 = HEAP32[$144>>2]|0;
 $188 = ($$pr|0)==(128);
 if ($188) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $189 = $187 & 127;
 $190 = ((($this) + ($189)|0) + 1928|0);
 $nextInd$02$i3 = HEAP8[$190>>0]|0;
 $191 = ($nextInd$02$i3<<24>>24)==(-1);
 L36: do {
  if ($191) {
   $200 = $$pr&255;
   HEAP8[$190>>0] = $200;
   label = 22;
  } else {
   $192 = $nextInd$02$i3&255;
   $194 = $192;$nextInd$03$i6 = $nextInd$02$i3;
   while(1) {
    $193 = ((($this) + ($194<<2)|0) + 1288|0);
    $195 = HEAP32[$193>>2]|0;
    $196 = ($195|0)==($187|0);
    if ($196) {
     $$pr25$pr = $$pr;
     break L36;
    }
    $197 = ((($this) + ($194)|0) + 1800|0);
    $nextInd$0$i7 = HEAP8[$197>>0]|0;
    $198 = $nextInd$0$i7&255;
    $199 = ($nextInd$0$i7<<24>>24)==(-1);
    if ($199) {
     break;
    } else {
     $194 = $198;$nextInd$03$i6 = $nextInd$0$i7;
    }
   }
   $201 = $$pr&255;
   $202 = $nextInd$03$i6&255;
   $203 = ((($this) + ($202)|0) + 1800|0);
   HEAP8[$203>>0] = $201;
   label = 22;
  }
 } while(0);
 if ((label|0) == 22) {
  $204 = HEAP32[$164>>2]|0;
  $205 = ((($this) + ($204)|0) + 1800|0);
  HEAP8[$205>>0] = -1;
  $206 = HEAP32[$164>>2]|0;
  $207 = (($206) + 1)|0;
  HEAP32[$164>>2] = $207;
  $208 = ((($this) + ($206<<2)|0) + 1288|0);
  HEAP32[$208>>2] = $187;
  $$pr25$pr$pre = HEAP32[$164>>2]|0;
  $$pr25$pr = $$pr25$pr$pre;
 }
 $209 = HEAP32[$151>>2]|0;
 $210 = ($$pr25$pr|0)==(128);
 if ($210) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $211 = $209 & 127;
 $212 = ((($this) + ($211)|0) + 1928|0);
 $nextInd$02$i = HEAP8[$212>>0]|0;
 $213 = ($nextInd$02$i<<24>>24)==(-1);
 do {
  if ($213) {
   $222 = $$pr25$pr&255;
   HEAP8[$212>>0] = $222;
  } else {
   $214 = $nextInd$02$i&255;
   $216 = $214;$nextInd$03$i = $nextInd$02$i;
   while(1) {
    $215 = ((($this) + ($216<<2)|0) + 1288|0);
    $217 = HEAP32[$215>>2]|0;
    $218 = ($217|0)==($209|0);
    if ($218) {
     $$0 = 1;
     label = 34;
     break;
    }
    $219 = ((($this) + ($216)|0) + 1800|0);
    $nextInd$0$i = HEAP8[$219>>0]|0;
    $220 = $nextInd$0$i&255;
    $221 = ($nextInd$0$i<<24>>24)==(-1);
    if ($221) {
     label = 29;
     break;
    } else {
     $216 = $220;$nextInd$03$i = $nextInd$0$i;
    }
   }
   if ((label|0) == 29) {
    $223 = $$pr25$pr&255;
    $224 = $nextInd$03$i&255;
    $225 = ((($this) + ($224)|0) + 1800|0);
    HEAP8[$225>>0] = $223;
    break;
   }
   else if ((label|0) == 34) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $226 = HEAP32[$164>>2]|0;
 $227 = ((($this) + ($226)|0) + 1800|0);
 HEAP8[$227>>0] = -1;
 $228 = HEAP32[$164>>2]|0;
 $229 = (($228) + 1)|0;
 HEAP32[$164>>2] = $229;
 $230 = ((($this) + ($228<<2)|0) + 1288|0);
 HEAP32[$230>>2] = $209;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL18triangleConvexTestRKN5physx2Gu13PolygonalDataEhjPKNS_6PxVec3ERKNS_7PxPlaneERS5_RKNS_2Cm8Matrix34ESE_SE_SE_RKNSB_23FastVertex2ShapeScalingEfRS4_RfRbb($polyData0,$triFlags,$localPoints,$localPlane,$groupCenterHull$0$0$val,$groupCenterHull$0$1$val,$groupCenterHull$0$2$val,$world1,$m0to1,$m1to0,$convexScaling,$contactDistance,$groupAxis,$groupMinDepth,$faceContact,$idtConvexScale) {
 $polyData0 = $polyData0|0;
 $triFlags = $triFlags|0;
 $localPoints = $localPoints|0;
 $localPlane = $localPlane|0;
 $groupCenterHull$0$0$val = Math_fround($groupCenterHull$0$0$val);
 $groupCenterHull$0$1$val = Math_fround($groupCenterHull$0$1$val);
 $groupCenterHull$0$2$val = Math_fround($groupCenterHull$0$2$val);
 $world1 = $world1|0;
 $m0to1 = $m0to1|0;
 $m1to0 = $m1to0|0;
 $convexScaling = $convexScaling|0;
 $contactDistance = Math_fround($contactDistance);
 $groupAxis = $groupAxis|0;
 $groupMinDepth = $groupMinDepth|0;
 $faceContact = $faceContact|0;
 $idtConvexScale = $idtConvexScale|0;
 var $$$i = 0, $$0 = 0, $$0$i = 0, $$0239$i = 0, $$in$i = 0, $$in41$i = 0, $$in67$i = 0, $$phi$trans$insert45$i = 0, $$phi$trans$insert47$i = 0, $$pre = Math_fround(0), $$pre$pre$i = 0, $$pre100 = Math_fround(0), $$pre43$i = Math_fround(0), $$pre46$i = Math_fround(0), $$pre48$i = Math_fround(0), $$pre52$i = Math_fround(0), $$pre54$i = Math_fround(0), $$pre58$i = Math_fround(0), $$pre60$i = Math_fround(0), $$pre64$i = Math_fround(0);
 var $$pre66 = Math_fround(0), $$pre66$i = Math_fround(0), $$pre67 = Math_fround(0), $$pre68 = Math_fround(0), $$pre69 = Math_fround(0), $$pre70 = Math_fround(0), $$pre71 = Math_fround(0), $$pre72 = Math_fround(0), $$pre73 = Math_fround(0), $$pre74 = Math_fround(0), $$pre75 = Math_fround(0), $$pre76 = Math_fround(0), $$pre77 = Math_fround(0), $$pre78 = Math_fround(0), $$pre79 = Math_fround(0), $$pre80 = Math_fround(0), $$pre81 = Math_fround(0), $$pre82 = Math_fround(0), $$pre83 = Math_fround(0), $$pre84 = Math_fround(0);
 var $$pre85 = Math_fround(0), $$pre86 = Math_fround(0), $$pre87 = Math_fround(0), $$pre88 = Math_fround(0), $$pre89 = Math_fround(0), $$pre90 = Math_fround(0), $$pre91 = Math_fround(0), $$pre92 = Math_fround(0), $$pre93 = Math_fround(0), $$pre94 = Math_fround(0), $$pre95 = Math_fround(0), $$pre96 = Math_fround(0), $$pre97 = Math_fround(0), $$pre98 = Math_fround(0), $$pre99 = Math_fround(0), $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0);
 var $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = Math_fround(0), $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = Math_fround(0), $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0);
 var $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = Math_fround(0), $1040 = 0.0, $1041 = 0, $1042 = 0.0, $1043 = 0, $1044 = 0.0, $1045 = 0, $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = 0, $1052 = Math_fround(0), $1053 = Math_fround(0);
 var $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = 0, $1058 = 0, $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = Math_fround(0);
 var $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0), $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = 0;
 var $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = 0, $1093 = 0, $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0);
 var $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = 0, $1116 = 0, $1117 = 0, $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0);
 var $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0), $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = 0, $114 = Math_fround(0), $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0;
 var $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = 0, $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = Math_fround(0), $1160 = Math_fround(0), $1161 = Math_fround(0);
 var $1162 = Math_fround(0), $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = 0, $1169 = Math_fround(0), $117 = Math_fround(0), $1170 = Math_fround(0), $1171 = Math_fround(0), $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = Math_fround(0), $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = Math_fround(0);
 var $1180 = Math_fround(0), $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0), $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = Math_fround(0), $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = Math_fround(0), $1190 = 0, $1191 = Math_fround(0), $1192 = 0, $1193 = Math_fround(0), $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = Math_fround(0), $1197 = Math_fround(0), $1198 = Math_fround(0);
 var $1199 = 0, $12 = 0, $120 = Math_fround(0), $1200 = Math_fround(0), $1201 = 0, $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = Math_fround(0), $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = Math_fround(0), $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = 0, $1210 = Math_fround(0), $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0;
 var $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = Math_fround(0), $1220 = 0, $1221 = 0, $1222 = 0, $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = Math_fround(0), $1229 = Math_fround(0), $123 = 0, $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = 0, $1233 = Math_fround(0);
 var $1234 = Math_fround(0), $1235 = Math_fround(0), $1236 = Math_fround(0), $1237 = Math_fround(0), $1238 = 0, $1239 = Math_fround(0), $124 = Math_fround(0), $1240 = Math_fround(0), $1241 = 0, $1242 = 0, $1243 = Math_fround(0), $1244 = Math_fround(0), $1245 = Math_fround(0), $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = Math_fround(0), $1250 = Math_fround(0), $1251 = Math_fround(0);
 var $1252 = Math_fround(0), $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = 0, $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = 0, $1263 = Math_fround(0), $1264 = 0, $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = Math_fround(0);
 var $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = 0, $1275 = Math_fround(0), $1276 = 0, $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = 0, $1280 = 0, $1281 = Math_fround(0), $1282 = Math_fround(0), $1283 = 0, $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = 0, $1287 = Math_fround(0), $1288 = 0;
 var $1289 = Math_fround(0), $129 = Math_fround(0), $1290 = Math_fround(0), $1291 = Math_fround(0), $1292 = Math_fround(0), $1293 = 0, $1294 = Math_fround(0), $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = Math_fround(0), $1298 = 0, $1299 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $1300 = Math_fround(0), $1301 = 0, $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = 0, $1305 = Math_fround(0);
 var $1306 = Math_fround(0), $1307 = Math_fround(0), $1308 = 0, $1309 = Math_fround(0), $131 = 0, $1310 = Math_fround(0), $1311 = 0, $1312 = Math_fround(0), $1313 = Math_fround(0), $1314 = Math_fround(0), $1315 = Math_fround(0), $1316 = Math_fround(0), $1317 = 0, $1318 = Math_fround(0), $1319 = Math_fround(0), $132 = Math_fround(0), $1320 = Math_fround(0), $1321 = 0, $1322 = Math_fround(0), $1323 = Math_fround(0);
 var $1324 = 0, $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = 0, $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = Math_fround(0), $1340 = Math_fround(0), $1341 = Math_fround(0);
 var $1342 = Math_fround(0), $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = Math_fround(0), $136 = 0;
 var $1360 = Math_fround(0), $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = 0, $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = 0, $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0);
 var $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0);
 var $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0);
 var $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0);
 var $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0);
 var $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0;
 var $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0);
 var $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0);
 var $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0);
 var $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0), $449 = 0;
 var $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0);
 var $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0);
 var $486 = 0, $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0);
 var $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0);
 var $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0);
 var $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0);
 var $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = 0, $575 = Math_fround(0);
 var $576 = 0, $577 = Math_fround(0), $578 = Math_fround(0), $579 = 0, $58 = Math_fround(0), $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = 0, $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = 0, $605 = Math_fround(0), $606 = 0, $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = 0;
 var $611 = Math_fround(0), $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = 0, $622 = Math_fround(0), $623 = 0, $624 = Math_fround(0), $625 = 0, $626 = Math_fround(0), $627 = Math_fround(0), $628 = 0, $629 = Math_fround(0);
 var $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = 0, $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = 0, $637 = Math_fround(0), $638 = 0, $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = 0, $643 = Math_fround(0), $644 = Math_fround(0), $645 = 0, $646 = Math_fround(0), $647 = Math_fround(0);
 var $648 = 0, $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = 0, $653 = Math_fround(0), $654 = 0, $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = 0, $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0), $664 = Math_fround(0), $665 = 0;
 var $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = 0, $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = 0, $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = 0, $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = 0, $683 = Math_fround(0);
 var $684 = Math_fround(0), $685 = 0, $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = 0, $692 = 0, $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = 0, $697 = Math_fround(0), $698 = Math_fround(0), $699 = 0, $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0);
 var $701 = Math_fround(0), $702 = 0, $703 = Math_fround(0), $704 = 0, $705 = Math_fround(0), $706 = Math_fround(0), $707 = 0, $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = 0, $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0, $717 = Math_fround(0), $718 = 0, $719 = Math_fround(0);
 var $72 = Math_fround(0), $720 = Math_fround(0), $721 = 0, $722 = Math_fround(0), $723 = Math_fround(0), $724 = 0, $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = 0, $733 = Math_fround(0), $734 = Math_fround(0), $735 = 0, $736 = Math_fround(0), $737 = Math_fround(0);
 var $738 = 0, $739 = Math_fround(0), $74 = Math_fround(0), $740 = Math_fround(0), $741 = 0, $742 = Math_fround(0), $743 = Math_fround(0), $744 = 0, $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = 0, $751 = Math_fround(0), $752 = Math_fround(0), $753 = 0, $754 = Math_fround(0), $755 = Math_fround(0);
 var $756 = 0, $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = Math_fround(0), $760 = Math_fround(0), $761 = Math_fround(0), $762 = 0, $763 = Math_fround(0), $764 = 0, $765 = Math_fround(0), $766 = Math_fround(0), $767 = 0, $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = 0, $772 = Math_fround(0), $773 = Math_fround(0);
 var $774 = Math_fround(0), $775 = Math_fround(0), $776 = 0, $777 = 0, $778 = 0, $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = 0, $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0);
 var $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = 0, $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = Math_fround(0), $809 = Math_fround(0);
 var $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = 0, $818 = Math_fround(0), $819 = Math_fround(0), $82 = Math_fround(0), $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = 0;
 var $828 = 0, $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = Math_fround(0), $84 = Math_fround(0), $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0);
 var $846 = Math_fround(0), $847 = Math_fround(0), $848 = 0, $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = 0, $859 = 0, $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0);
 var $864 = Math_fround(0), $865 = 0, $866 = 0, $867 = 0, $868 = Math_fround(0), $869 = Math_fround(0), $87 = 0, $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0);
 var $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $900 = Math_fround(0), $901 = 0, $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = 0, $91 = Math_fround(0), $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0;
 var $918 = 0, $919 = 0, $92 = Math_fround(0), $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0;
 var $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = Math_fround(0), $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = Math_fround(0), $950 = Math_fround(0), $951 = Math_fround(0), $952 = 0, $953 = Math_fround(0);
 var $954 = Math_fround(0), $955 = Math_fround(0), $956 = 0, $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = Math_fround(0), $960 = Math_fround(0), $961 = 0, $962 = 0, $963 = Math_fround(0), $964 = Math_fround(0), $965 = 0, $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = 0, $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0);
 var $972 = Math_fround(0), $973 = Math_fround(0), $974 = 0, $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = Math_fround(0), $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = Math_fround(0);
 var $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $axes$033$i = 0, $edges$037$i = 0, $exitcond$i = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $hullIndices$027$i = 0, $hullIndices$1$i = 0, $hullIndices$234$i = 0, $hullIndices$3$i = 0;
 var $hullIndices$4$i = 0, $i$026$i = 0, $i$026$i10 = 0, $i$026$i11 = 0, $i$026$i12 = 0, $i$026$i13 = 0, $i$026$i14 = 0, $i$026$i16 = 0, $i$026$i17 = 0, $i$026$i7 = 0, $i$026$i8 = 0, $i$026$i9 = 0, $i1$032$i = 0, $i13$020$i = 0, $i7$016$i = 0, $j$034$i = 0, $max0$i = 0, $max0$i$i = 0, $min0$i = 0, $min0$i$i = 0;
 var $nbTriangleAxes$0$i = 0, $nbTriangleAxes$1$i = 0, $nbTriangleAxes$2$i = 0, $not$$i$i = 0, $storemerge = 0, $storemerge$i = Math_fround(0), $storemerge68$i = Math_fround(0), $storemerge69$i = Math_fround(0), $triangleInHullSpace$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3168|0;
 $min0$i = sp + 3132|0;
 $max0$i = sp;
 $min0$i$i = sp + 3076|0;
 $max0$i$i = sp + 3080|0;
 $0 = sp + 3084|0;
 $triangleInHullSpace$i = sp + 3096|0;
 $1 = (($polyData0) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 2;
 $4 = STACKTOP; STACKTOP = STACKTOP + ((((1*$3)|0)+15)&-16)|0;;
 $5 = (($polyData0) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($polyData0) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($m0to1) + 36|0);
 L1: do {
  if ($idtConvexScale) {
   $10 = ($2|0)==(0);
   if ($10) {
    $1330 = Math_fround(0.0);$1331 = Math_fround(0.0);$1332 = Math_fround(0.0);$651 = Math_fround(3.40282346638528859812E+38);$913 = 0;$i$026$i12 = -1;
   } else {
    $11 = (($m0to1) + 4|0);
    $12 = (($m0to1) + 8|0);
    $13 = (($m0to1) + 12|0);
    $14 = (($m0to1) + 16|0);
    $15 = (($m0to1) + 20|0);
    $16 = (($m0to1) + 24|0);
    $17 = (($m0to1) + 28|0);
    $18 = (($m0to1) + 32|0);
    $19 = (($m0to1) + 40|0);
    $20 = (($m0to1) + 44|0);
    $21 = (($localPoints) + 4|0);
    $22 = (($localPoints) + 8|0);
    $23 = (($localPoints) + 12|0);
    $24 = (($localPoints) + 16|0);
    $25 = (($localPoints) + 20|0);
    $26 = (($localPoints) + 24|0);
    $27 = (($localPoints) + 28|0);
    $28 = (($localPoints) + 32|0);
    $1333 = Math_fround(0.0);$1334 = Math_fround(0.0);$1335 = Math_fround(0.0);$134 = Math_fround(3.40282346638528859812E+38);$hullIndices$027$i = $4;$i$026$i = 0;$i$026$i11 = -1;
    while(1) {
     $29 = (($6) + (($i$026$i*20)|0)|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     $31 = Math_fround($30 * $groupCenterHull$0$0$val);
     $32 = ((($6) + (($i$026$i*20)|0)|0) + 4|0);
     $33 = Math_fround(HEAPF32[$32>>2]);
     $34 = Math_fround($33 * $groupCenterHull$0$1$val);
     $35 = Math_fround($31 + $34);
     $36 = ((($6) + (($i$026$i*20)|0)|0) + 8|0);
     $37 = Math_fround(HEAPF32[$36>>2]);
     $38 = Math_fround($37 * $groupCenterHull$0$2$val);
     $39 = Math_fround($35 + $38);
     $40 = ((($6) + (($i$026$i*20)|0)|0) + 12|0);
     $41 = Math_fround(HEAPF32[$40>>2]);
     $42 = Math_fround($41 + $39);
     $43 = $42 < Math_fround(0.0);
     if ($43) {
      $1336 = $134;$1337 = $1333;$1338 = $1334;$1339 = $1335;$hullIndices$1$i = $hullIndices$027$i;$i$026$i10 = $i$026$i11;
     } else {
      $44 = (($hullIndices$027$i) + 4|0);
      HEAP32[$hullIndices$027$i>>2] = $i$026$i;
      $45 = Math_fround(HEAPF32[$m0to1>>2]);
      $46 = Math_fround($30 * $45);
      $47 = Math_fround(HEAPF32[$11>>2]);
      $48 = Math_fround($30 * $47);
      $49 = Math_fround(HEAPF32[$12>>2]);
      $50 = Math_fround($30 * $49);
      $51 = Math_fround(HEAPF32[$13>>2]);
      $52 = Math_fround($33 * $51);
      $53 = Math_fround(HEAPF32[$14>>2]);
      $54 = Math_fround($33 * $53);
      $55 = Math_fround(HEAPF32[$15>>2]);
      $56 = Math_fround($33 * $55);
      $57 = Math_fround($46 + $52);
      $58 = Math_fround($48 + $54);
      $59 = Math_fround($50 + $56);
      $60 = Math_fround(HEAPF32[$16>>2]);
      $61 = Math_fround($37 * $60);
      $62 = Math_fround(HEAPF32[$17>>2]);
      $63 = Math_fround($37 * $62);
      $64 = Math_fround(HEAPF32[$18>>2]);
      $65 = Math_fround($37 * $64);
      $66 = Math_fround($57 + $61);
      $67 = Math_fround($58 + $63);
      $68 = Math_fround($59 + $65);
      $69 = Math_fround(HEAPF32[$9>>2]);
      $70 = Math_fround($66 * $69);
      $71 = Math_fround(HEAPF32[$19>>2]);
      $72 = Math_fround($67 * $71);
      $73 = Math_fround($70 + $72);
      $74 = Math_fround(HEAPF32[$20>>2]);
      $75 = Math_fround($68 * $74);
      $76 = Math_fround($73 + $75);
      $77 = ((($6) + (($i$026$i*20)|0)|0) + 19|0);
      $78 = HEAP8[$77>>0]|0;
      $79 = $78&255;
      $80 = (($8) + (($79*12)|0)|0);
      $81 = Math_fround(HEAPF32[$80>>2]);
      $82 = Math_fround($30 * $81);
      $83 = ((($8) + (($79*12)|0)|0) + 4|0);
      $84 = Math_fround(HEAPF32[$83>>2]);
      $85 = Math_fround($33 * $84);
      $86 = Math_fround($82 + $85);
      $87 = ((($8) + (($79*12)|0)|0) + 8|0);
      $88 = Math_fround(HEAPF32[$87>>2]);
      $89 = Math_fround($37 * $88);
      $90 = Math_fround($86 + $89);
      $91 = Math_fround($76 + $90);
      $92 = Math_fround($76 - $41);
      $93 = Math_fround(HEAPF32[$localPoints>>2]);
      $94 = Math_fround($66 * $93);
      $95 = Math_fround(HEAPF32[$21>>2]);
      $96 = Math_fround($67 * $95);
      $97 = Math_fround($94 + $96);
      $98 = Math_fround(HEAPF32[$22>>2]);
      $99 = Math_fround($68 * $98);
      $100 = Math_fround($97 + $99);
      $101 = Math_fround(HEAPF32[$23>>2]);
      $102 = Math_fround($66 * $101);
      $103 = Math_fround(HEAPF32[$24>>2]);
      $104 = Math_fround($67 * $103);
      $105 = Math_fround($102 + $104);
      $106 = Math_fround(HEAPF32[$25>>2]);
      $107 = Math_fround($68 * $106);
      $108 = Math_fround($105 + $107);
      $109 = $100 < $108;
      $110 = $109 ? $100 : $108;
      $111 = $100 > $108;
      $112 = $111 ? $100 : $108;
      $113 = Math_fround(HEAPF32[$26>>2]);
      $114 = Math_fround($66 * $113);
      $115 = Math_fround(HEAPF32[$27>>2]);
      $116 = Math_fround($67 * $115);
      $117 = Math_fround($114 + $116);
      $118 = Math_fround(HEAPF32[$28>>2]);
      $119 = Math_fround($68 * $118);
      $120 = Math_fround($117 + $119);
      $121 = $110 < $120;
      $122 = $121 ? $110 : $120;
      $123 = $112 > $120;
      $124 = $123 ? $112 : $120;
      $125 = Math_fround($92 + $contactDistance);
      $126 = $125 < $122;
      if ($126) {
       $$0 = 0;
       label = 89;
       break;
      }
      $127 = Math_fround($124 + $contactDistance);
      $128 = $127 < $91;
      if ($128) {
       $$0 = 0;
       label = 89;
       break;
      }
      $129 = Math_fround($92 - $122);
      $130 = Math_fround($124 - $91);
      $131 = $129 < $130;
      $132 = $131 ? $129 : $130;
      $133 = $132 < $134;
      if ($133) {
       $1336 = $132;$1337 = $68;$1338 = $67;$1339 = $66;$hullIndices$1$i = $44;$i$026$i10 = $i$026$i;
      } else {
       $1336 = $134;$1337 = $1333;$1338 = $1334;$1339 = $1335;$hullIndices$1$i = $44;$i$026$i10 = $i$026$i11;
      }
     }
     $135 = (($i$026$i) + 1)|0;
     $136 = ($135>>>0)<($2>>>0);
     if ($136) {
      $1333 = $1337;$1334 = $1338;$1335 = $1339;$134 = $1336;$hullIndices$027$i = $hullIndices$1$i;$i$026$i = $135;$i$026$i11 = $i$026$i10;
     } else {
      $1340 = $1336;$1341 = $1337;$1342 = $1338;$1343 = $1339;$hullIndices$4$i = $hullIndices$1$i;$i$026$i7 = $i$026$i10;
      label = 20;
      break L1;
     }
    }
    if ((label|0) == 89) {
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   $137 = (($convexScaling) + 36|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   $139 = Math_fround($138 * $groupCenterHull$0$0$val);
   $140 = (($convexScaling) + 40|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = Math_fround($141 * $groupCenterHull$0$0$val);
   $143 = (($convexScaling) + 44|0);
   $144 = Math_fround(HEAPF32[$143>>2]);
   $145 = Math_fround($144 * $groupCenterHull$0$0$val);
   $146 = (($convexScaling) + 48|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = Math_fround($147 * $groupCenterHull$0$1$val);
   $149 = (($convexScaling) + 52|0);
   $150 = Math_fround(HEAPF32[$149>>2]);
   $151 = Math_fround($150 * $groupCenterHull$0$1$val);
   $152 = (($convexScaling) + 56|0);
   $153 = Math_fround(HEAPF32[$152>>2]);
   $154 = Math_fround($153 * $groupCenterHull$0$1$val);
   $155 = Math_fround($139 + $148);
   $156 = Math_fround($142 + $151);
   $157 = Math_fround($145 + $154);
   $158 = (($convexScaling) + 60|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = Math_fround($159 * $groupCenterHull$0$2$val);
   $161 = (($convexScaling) + 64|0);
   $162 = Math_fround(HEAPF32[$161>>2]);
   $163 = Math_fround($162 * $groupCenterHull$0$2$val);
   $164 = (($convexScaling) + 68|0);
   $165 = Math_fround(HEAPF32[$164>>2]);
   $166 = Math_fround($165 * $groupCenterHull$0$2$val);
   $167 = Math_fround($155 + $160);
   $168 = Math_fround($156 + $163);
   $169 = Math_fround($157 + $166);
   $170 = ($2|0)==(0);
   if ($170) {
    $1330 = Math_fround(0.0);$1331 = Math_fround(0.0);$1332 = Math_fround(0.0);$651 = Math_fround(3.40282346638528859812E+38);$913 = 0;$i$026$i12 = -1;
   } else {
    $171 = (($m0to1) + 4|0);
    $172 = (($m0to1) + 8|0);
    $173 = (($m0to1) + 12|0);
    $174 = (($m0to1) + 16|0);
    $175 = (($m0to1) + 20|0);
    $176 = (($m0to1) + 24|0);
    $177 = (($m0to1) + 28|0);
    $178 = (($m0to1) + 32|0);
    $179 = (($m0to1) + 40|0);
    $180 = (($m0to1) + 44|0);
    $181 = (($localPoints) + 4|0);
    $182 = (($localPoints) + 8|0);
    $183 = (($localPoints) + 12|0);
    $184 = (($localPoints) + 16|0);
    $185 = (($localPoints) + 20|0);
    $186 = (($localPoints) + 24|0);
    $187 = (($localPoints) + 28|0);
    $188 = (($localPoints) + 32|0);
    $1344 = Math_fround(0.0);$1345 = Math_fround(0.0);$1346 = Math_fround(0.0);$325 = Math_fround(3.40282346638528859812E+38);$hullIndices$234$i = $4;$i$026$i8 = -1;$i1$032$i = 0;
    while(1) {
     $189 = (($6) + (($i1$032$i*20)|0)|0);
     $190 = Math_fround(HEAPF32[$189>>2]);
     $191 = Math_fround($167 * $190);
     $192 = ((($6) + (($i1$032$i*20)|0)|0) + 4|0);
     $193 = Math_fround(HEAPF32[$192>>2]);
     $194 = Math_fround($168 * $193);
     $195 = Math_fround($191 + $194);
     $196 = ((($6) + (($i1$032$i*20)|0)|0) + 8|0);
     $197 = Math_fround(HEAPF32[$196>>2]);
     $198 = Math_fround($169 * $197);
     $199 = Math_fround($195 + $198);
     $200 = ((($6) + (($i1$032$i*20)|0)|0) + 12|0);
     $201 = Math_fround(HEAPF32[$200>>2]);
     $202 = Math_fround($201 + $199);
     $203 = $202 < Math_fround(0.0);
     if ($203) {
      $1347 = $325;$1348 = $1344;$1349 = $1345;$1350 = $1346;$hullIndices$3$i = $hullIndices$234$i;$i$026$i9 = $i$026$i8;
     } else {
      $204 = Math_fround($190 * $138);
      $205 = Math_fround($190 * $141);
      $206 = Math_fround($190 * $144);
      $207 = Math_fround($193 * $147);
      $208 = Math_fround($193 * $150);
      $209 = Math_fround($193 * $153);
      $210 = Math_fround($204 + $207);
      $211 = Math_fround($205 + $208);
      $212 = Math_fround($206 + $209);
      $213 = Math_fround($197 * $159);
      $214 = Math_fround($197 * $162);
      $215 = Math_fround($197 * $165);
      $216 = Math_fround($210 + $213);
      $217 = Math_fround($211 + $214);
      $218 = Math_fround($212 + $215);
      $219 = Math_fround($216 * $216);
      $220 = Math_fround($217 * $217);
      $221 = Math_fround($219 + $220);
      $222 = Math_fround($218 * $218);
      $223 = Math_fround($221 + $222);
      $224 = (Math_fround(Math_sqrt((Math_fround($223)))));
      $225 = $224 > Math_fround(0.0);
      $226 = Math_fround(Math_fround(1.0) / $224);
      if ($225) {
       $227 = Math_fround($216 * $226);
       $228 = Math_fround($217 * $226);
       $229 = Math_fround($218 * $226);
       $233 = $227;$240 = $228;$250 = $229;
      } else {
       $233 = $216;$240 = $217;$250 = $218;
      }
      $230 = (($hullIndices$234$i) + 4|0);
      HEAP32[$hullIndices$234$i>>2] = $i1$032$i;
      $231 = Math_fround(HEAPF32[$m0to1>>2]);
      $232 = Math_fround($233 * $231);
      $234 = Math_fround(HEAPF32[$171>>2]);
      $235 = Math_fround($233 * $234);
      $236 = Math_fround(HEAPF32[$172>>2]);
      $237 = Math_fround($233 * $236);
      $238 = Math_fround(HEAPF32[$173>>2]);
      $239 = Math_fround($240 * $238);
      $241 = Math_fround(HEAPF32[$174>>2]);
      $242 = Math_fround($240 * $241);
      $243 = Math_fround(HEAPF32[$175>>2]);
      $244 = Math_fround($240 * $243);
      $245 = Math_fround($232 + $239);
      $246 = Math_fround($235 + $242);
      $247 = Math_fround($237 + $244);
      $248 = Math_fround(HEAPF32[$176>>2]);
      $249 = Math_fround($250 * $248);
      $251 = Math_fround(HEAPF32[$177>>2]);
      $252 = Math_fround($250 * $251);
      $253 = Math_fround(HEAPF32[$178>>2]);
      $254 = Math_fround($250 * $253);
      $255 = Math_fround($245 + $249);
      $256 = Math_fround($246 + $252);
      $257 = Math_fround($247 + $254);
      $258 = Math_fround(HEAPF32[$9>>2]);
      $259 = Math_fround($255 * $258);
      $260 = Math_fround(HEAPF32[$179>>2]);
      $261 = Math_fround($256 * $260);
      $262 = Math_fround($259 + $261);
      $263 = Math_fround(HEAPF32[$180>>2]);
      $264 = Math_fround($257 * $263);
      $265 = Math_fround($262 + $264);
      $266 = ((($6) + (($i1$032$i*20)|0)|0) + 19|0);
      $267 = HEAP8[$266>>0]|0;
      $268 = $267&255;
      $269 = (($8) + (($268*12)|0)|0);
      $270 = Math_fround(HEAPF32[$269>>2]);
      $271 = Math_fround($190 * $270);
      $272 = ((($8) + (($268*12)|0)|0) + 4|0);
      $273 = Math_fround(HEAPF32[$272>>2]);
      $274 = Math_fround($193 * $273);
      $275 = Math_fround($271 + $274);
      $276 = ((($8) + (($268*12)|0)|0) + 8|0);
      $277 = Math_fround(HEAPF32[$276>>2]);
      $278 = Math_fround($197 * $277);
      $279 = Math_fround($275 + $278);
      $280 = Math_fround($226 * $279);
      $281 = Math_fround($265 + $280);
      $282 = Math_fround($201 * $226);
      $283 = Math_fround($265 - $282);
      $284 = Math_fround(HEAPF32[$localPoints>>2]);
      $285 = Math_fround($255 * $284);
      $286 = Math_fround(HEAPF32[$181>>2]);
      $287 = Math_fround($256 * $286);
      $288 = Math_fround($285 + $287);
      $289 = Math_fround(HEAPF32[$182>>2]);
      $290 = Math_fround($257 * $289);
      $291 = Math_fround($288 + $290);
      $292 = Math_fround(HEAPF32[$183>>2]);
      $293 = Math_fround($255 * $292);
      $294 = Math_fround(HEAPF32[$184>>2]);
      $295 = Math_fround($256 * $294);
      $296 = Math_fround($293 + $295);
      $297 = Math_fround(HEAPF32[$185>>2]);
      $298 = Math_fround($257 * $297);
      $299 = Math_fround($296 + $298);
      $300 = $291 < $299;
      $301 = $300 ? $291 : $299;
      $302 = $291 > $299;
      $303 = $302 ? $291 : $299;
      $304 = Math_fround(HEAPF32[$186>>2]);
      $305 = Math_fround($255 * $304);
      $306 = Math_fround(HEAPF32[$187>>2]);
      $307 = Math_fround($256 * $306);
      $308 = Math_fround($305 + $307);
      $309 = Math_fround(HEAPF32[$188>>2]);
      $310 = Math_fround($257 * $309);
      $311 = Math_fround($308 + $310);
      $312 = $301 < $311;
      $313 = $312 ? $301 : $311;
      $314 = $303 > $311;
      $315 = $314 ? $303 : $311;
      $316 = Math_fround($283 + $contactDistance);
      $317 = $316 < $313;
      if ($317) {
       $$0 = 0;
       label = 89;
       break;
      }
      $318 = Math_fround($315 + $contactDistance);
      $319 = $318 < $281;
      if ($319) {
       $$0 = 0;
       label = 89;
       break;
      }
      $320 = Math_fround($283 - $313);
      $321 = Math_fround($315 - $281);
      $322 = $320 < $321;
      $323 = $322 ? $320 : $321;
      $324 = $323 < $325;
      if ($324) {
       $1347 = $323;$1348 = $257;$1349 = $256;$1350 = $255;$hullIndices$3$i = $230;$i$026$i9 = $i1$032$i;
      } else {
       $1347 = $325;$1348 = $1344;$1349 = $1345;$1350 = $1346;$hullIndices$3$i = $230;$i$026$i9 = $i$026$i8;
      }
     }
     $326 = (($i1$032$i) + 1)|0;
     $327 = ($326>>>0)<($2>>>0);
     if ($327) {
      $1344 = $1348;$1345 = $1349;$1346 = $1350;$325 = $1347;$hullIndices$234$i = $hullIndices$3$i;$i$026$i8 = $i$026$i9;$i1$032$i = $326;
     } else {
      $1340 = $1347;$1341 = $1348;$1342 = $1349;$1343 = $1350;$hullIndices$4$i = $hullIndices$3$i;$i$026$i7 = $i$026$i9;
      label = 20;
      break L1;
     }
    }
    if ((label|0) == 89) {
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 L31: do {
  if ((label|0) == 20) {
   $328 = $hullIndices$4$i;
   $329 = $4;
   $330 = (($328) - ($329))|0;
   $331 = $330 >> 2;
   $332 = ($i$026$i7|0)==(-1);
   if ($332) {
    $333 = ($2|0)==(0);
    if ($idtConvexScale) {
     if ($333) {
      $1330 = $1341;$1331 = $1342;$1332 = $1343;$651 = $1340;$913 = 0;$i$026$i12 = -1;
      break;
     }
     $361 = (($m0to1) + 4|0);
     $362 = (($m0to1) + 8|0);
     $363 = (($m0to1) + 12|0);
     $364 = (($m0to1) + 16|0);
     $365 = (($m0to1) + 20|0);
     $366 = (($m0to1) + 24|0);
     $367 = (($m0to1) + 28|0);
     $368 = (($m0to1) + 32|0);
     $369 = (($m0to1) + 40|0);
     $370 = (($m0to1) + 44|0);
     $371 = (($localPoints) + 4|0);
     $372 = (($localPoints) + 8|0);
     $373 = (($localPoints) + 12|0);
     $374 = (($localPoints) + 16|0);
     $375 = (($localPoints) + 20|0);
     $376 = (($localPoints) + 24|0);
     $377 = (($localPoints) + 28|0);
     $378 = (($localPoints) + 32|0);
     $$pre71 = Math_fround(HEAPF32[$m0to1>>2]);
     $$pre72 = Math_fround(HEAPF32[$361>>2]);
     $$pre73 = Math_fround(HEAPF32[$362>>2]);
     $$pre74 = Math_fround(HEAPF32[$363>>2]);
     $$pre75 = Math_fround(HEAPF32[$364>>2]);
     $$pre76 = Math_fround(HEAPF32[$365>>2]);
     $$pre77 = Math_fround(HEAPF32[$366>>2]);
     $$pre78 = Math_fround(HEAPF32[$367>>2]);
     $$pre79 = Math_fround(HEAPF32[$368>>2]);
     $$pre80 = Math_fround(HEAPF32[$9>>2]);
     $$pre81 = Math_fround(HEAPF32[$369>>2]);
     $$pre82 = Math_fround(HEAPF32[$370>>2]);
     $$pre83 = Math_fround(HEAPF32[$localPoints>>2]);
     $$pre84 = Math_fround(HEAPF32[$371>>2]);
     $$pre85 = Math_fround(HEAPF32[$372>>2]);
     $$pre86 = Math_fround(HEAPF32[$373>>2]);
     $$pre87 = Math_fround(HEAPF32[$374>>2]);
     $$pre88 = Math_fround(HEAPF32[$375>>2]);
     $$pre89 = Math_fround(HEAPF32[$376>>2]);
     $$pre90 = Math_fround(HEAPF32[$377>>2]);
     $$pre91 = Math_fround(HEAPF32[$378>>2]);
     $1354 = $1341;$1355 = $1342;$1356 = $1343;$455 = $1340;$i$026$i17 = -1;$i7$016$i = 0;
     while(1) {
      $379 = (($6) + (($i7$016$i*20)|0)|0);
      $380 = Math_fround(HEAPF32[$379>>2]);
      $381 = Math_fround($380 * $$pre71);
      $382 = Math_fround($380 * $$pre72);
      $383 = Math_fround($380 * $$pre73);
      $384 = ((($6) + (($i7$016$i*20)|0)|0) + 4|0);
      $385 = Math_fround(HEAPF32[$384>>2]);
      $386 = Math_fround($385 * $$pre74);
      $387 = Math_fround($385 * $$pre75);
      $388 = Math_fround($385 * $$pre76);
      $389 = Math_fround($381 + $386);
      $390 = Math_fround($382 + $387);
      $391 = Math_fround($383 + $388);
      $392 = ((($6) + (($i7$016$i*20)|0)|0) + 8|0);
      $393 = Math_fround(HEAPF32[$392>>2]);
      $394 = Math_fround($393 * $$pre77);
      $395 = Math_fround($393 * $$pre78);
      $396 = Math_fround($393 * $$pre79);
      $397 = Math_fround($389 + $394);
      $398 = Math_fround($390 + $395);
      $399 = Math_fround($391 + $396);
      $400 = Math_fround($397 * $$pre80);
      $401 = Math_fround($398 * $$pre81);
      $402 = Math_fround($400 + $401);
      $403 = Math_fround($399 * $$pre82);
      $404 = Math_fround($402 + $403);
      $405 = ((($6) + (($i7$016$i*20)|0)|0) + 19|0);
      $406 = HEAP8[$405>>0]|0;
      $407 = $406&255;
      $408 = (($8) + (($407*12)|0)|0);
      $409 = Math_fround(HEAPF32[$408>>2]);
      $410 = Math_fround($380 * $409);
      $411 = ((($8) + (($407*12)|0)|0) + 4|0);
      $412 = Math_fround(HEAPF32[$411>>2]);
      $413 = Math_fround($385 * $412);
      $414 = Math_fround($410 + $413);
      $415 = ((($8) + (($407*12)|0)|0) + 8|0);
      $416 = Math_fround(HEAPF32[$415>>2]);
      $417 = Math_fround($393 * $416);
      $418 = Math_fround($414 + $417);
      $419 = Math_fround($404 + $418);
      $420 = ((($6) + (($i7$016$i*20)|0)|0) + 12|0);
      $421 = Math_fround(HEAPF32[$420>>2]);
      $422 = Math_fround($404 - $421);
      $423 = Math_fround($397 * $$pre83);
      $424 = Math_fround($398 * $$pre84);
      $425 = Math_fround($423 + $424);
      $426 = Math_fround($399 * $$pre85);
      $427 = Math_fround($425 + $426);
      $428 = Math_fround($397 * $$pre86);
      $429 = Math_fround($398 * $$pre87);
      $430 = Math_fround($428 + $429);
      $431 = Math_fround($399 * $$pre88);
      $432 = Math_fround($430 + $431);
      $433 = $427 < $432;
      $434 = $433 ? $427 : $432;
      $435 = $427 > $432;
      $436 = $435 ? $427 : $432;
      $437 = Math_fround($397 * $$pre89);
      $438 = Math_fround($398 * $$pre90);
      $439 = Math_fround($437 + $438);
      $440 = Math_fround($399 * $$pre91);
      $441 = Math_fround($439 + $440);
      $442 = $434 < $441;
      $443 = $442 ? $434 : $441;
      $444 = $436 > $441;
      $445 = $444 ? $436 : $441;
      $446 = Math_fround($422 + $contactDistance);
      $447 = $446 < $443;
      if ($447) {
       $$0 = 0;
       label = 89;
       break;
      }
      $448 = Math_fround($445 + $contactDistance);
      $449 = $448 < $419;
      if ($449) {
       $$0 = 0;
       label = 89;
       break;
      }
      $450 = Math_fround($422 - $443);
      $451 = Math_fround($445 - $419);
      $452 = $450 < $451;
      $453 = $452 ? $450 : $451;
      $454 = $453 < $455;
      if ($454) {
       $1357 = $453;$1358 = $399;$1359 = $398;$1360 = $397;$i$026$i16 = $i7$016$i;
      } else {
       $1357 = $455;$1358 = $1354;$1359 = $1355;$1360 = $1356;$i$026$i16 = $i$026$i17;
      }
      $456 = (($4) + ($i7$016$i<<2)|0);
      HEAP32[$456>>2] = $i7$016$i;
      $457 = (($i7$016$i) + 1)|0;
      $458 = ($457>>>0)<($2>>>0);
      if ($458) {
       $1354 = $1358;$1355 = $1359;$1356 = $1360;$455 = $1357;$i$026$i17 = $i$026$i16;$i7$016$i = $457;
      } else {
       $1330 = $1358;$1331 = $1359;$1332 = $1360;$651 = $1357;$913 = $2;$i$026$i12 = $i$026$i16;
       break L31;
      }
     }
     if ((label|0) == 89) {
      STACKTOP = sp;return ($$0|0);
     }
    }
    if ($333) {
     $1330 = $1341;$1331 = $1342;$1332 = $1343;$651 = $1340;$913 = 0;$i$026$i12 = -1;
    } else {
     $334 = (($convexScaling) + 36|0);
     $335 = (($convexScaling) + 40|0);
     $336 = (($convexScaling) + 44|0);
     $337 = (($convexScaling) + 48|0);
     $338 = (($convexScaling) + 52|0);
     $339 = (($convexScaling) + 56|0);
     $340 = (($convexScaling) + 60|0);
     $341 = (($convexScaling) + 64|0);
     $342 = (($convexScaling) + 68|0);
     $343 = (($m0to1) + 4|0);
     $344 = (($m0to1) + 8|0);
     $345 = (($m0to1) + 12|0);
     $346 = (($m0to1) + 16|0);
     $347 = (($m0to1) + 20|0);
     $348 = (($m0to1) + 24|0);
     $349 = (($m0to1) + 28|0);
     $350 = (($m0to1) + 32|0);
     $351 = (($m0to1) + 40|0);
     $352 = (($m0to1) + 44|0);
     $353 = (($localPoints) + 4|0);
     $354 = (($localPoints) + 8|0);
     $355 = (($localPoints) + 12|0);
     $356 = (($localPoints) + 16|0);
     $357 = (($localPoints) + 20|0);
     $358 = (($localPoints) + 24|0);
     $359 = (($localPoints) + 28|0);
     $360 = (($localPoints) + 32|0);
     $$pre92 = Math_fround(HEAPF32[$334>>2]);
     $$pre93 = Math_fround(HEAPF32[$335>>2]);
     $$pre94 = Math_fround(HEAPF32[$336>>2]);
     $$pre95 = Math_fround(HEAPF32[$337>>2]);
     $$pre96 = Math_fround(HEAPF32[$338>>2]);
     $$pre97 = Math_fround(HEAPF32[$339>>2]);
     $$pre98 = Math_fround(HEAPF32[$340>>2]);
     $$pre99 = Math_fround(HEAPF32[$341>>2]);
     $$pre100 = Math_fround(HEAPF32[$342>>2]);
     $1351 = $1341;$1352 = $1342;$1353 = $1343;$587 = $1340;$i$026$i14 = -1;$i13$020$i = 0;
     while(1) {
      $459 = (($6) + (($i13$020$i*20)|0)|0);
      $460 = Math_fround(HEAPF32[$459>>2]);
      $461 = Math_fround($460 * $$pre92);
      $462 = Math_fround($460 * $$pre93);
      $463 = Math_fround($460 * $$pre94);
      $464 = ((($6) + (($i13$020$i*20)|0)|0) + 4|0);
      $465 = Math_fround(HEAPF32[$464>>2]);
      $466 = Math_fround($465 * $$pre95);
      $467 = Math_fround($465 * $$pre96);
      $468 = Math_fround($465 * $$pre97);
      $469 = Math_fround($461 + $466);
      $470 = Math_fround($462 + $467);
      $471 = Math_fround($463 + $468);
      $472 = ((($6) + (($i13$020$i*20)|0)|0) + 8|0);
      $473 = Math_fround(HEAPF32[$472>>2]);
      $474 = Math_fround($473 * $$pre98);
      $475 = Math_fround($473 * $$pre99);
      $476 = Math_fround($473 * $$pre100);
      $477 = Math_fround($469 + $474);
      $478 = Math_fround($470 + $475);
      $479 = Math_fround($471 + $476);
      $480 = Math_fround($477 * $477);
      $481 = Math_fround($478 * $478);
      $482 = Math_fround($480 + $481);
      $483 = Math_fround($479 * $479);
      $484 = Math_fround($482 + $483);
      $485 = (Math_fround(Math_sqrt((Math_fround($484)))));
      $486 = $485 > Math_fround(0.0);
      $487 = Math_fround(Math_fround(1.0) / $485);
      if ($486) {
       $488 = Math_fround($477 * $487);
       $489 = Math_fround($478 * $487);
       $490 = Math_fround($479 * $487);
       $493 = $488;$500 = $489;$510 = $490;
      } else {
       $493 = $477;$500 = $478;$510 = $479;
      }
      $491 = Math_fround(HEAPF32[$m0to1>>2]);
      $492 = Math_fround($493 * $491);
      $494 = Math_fround(HEAPF32[$343>>2]);
      $495 = Math_fround($493 * $494);
      $496 = Math_fround(HEAPF32[$344>>2]);
      $497 = Math_fround($493 * $496);
      $498 = Math_fround(HEAPF32[$345>>2]);
      $499 = Math_fround($500 * $498);
      $501 = Math_fround(HEAPF32[$346>>2]);
      $502 = Math_fround($500 * $501);
      $503 = Math_fround(HEAPF32[$347>>2]);
      $504 = Math_fround($500 * $503);
      $505 = Math_fround($492 + $499);
      $506 = Math_fround($495 + $502);
      $507 = Math_fround($497 + $504);
      $508 = Math_fround(HEAPF32[$348>>2]);
      $509 = Math_fround($510 * $508);
      $511 = Math_fround(HEAPF32[$349>>2]);
      $512 = Math_fround($510 * $511);
      $513 = Math_fround(HEAPF32[$350>>2]);
      $514 = Math_fround($510 * $513);
      $515 = Math_fround($505 + $509);
      $516 = Math_fround($506 + $512);
      $517 = Math_fround($507 + $514);
      $518 = Math_fround(HEAPF32[$9>>2]);
      $519 = Math_fround($515 * $518);
      $520 = Math_fround(HEAPF32[$351>>2]);
      $521 = Math_fround($516 * $520);
      $522 = Math_fround($519 + $521);
      $523 = Math_fround(HEAPF32[$352>>2]);
      $524 = Math_fround($517 * $523);
      $525 = Math_fround($522 + $524);
      $526 = ((($6) + (($i13$020$i*20)|0)|0) + 19|0);
      $527 = HEAP8[$526>>0]|0;
      $528 = $527&255;
      $529 = (($8) + (($528*12)|0)|0);
      $530 = Math_fround(HEAPF32[$529>>2]);
      $531 = Math_fround($460 * $530);
      $532 = ((($8) + (($528*12)|0)|0) + 4|0);
      $533 = Math_fround(HEAPF32[$532>>2]);
      $534 = Math_fround($465 * $533);
      $535 = Math_fround($531 + $534);
      $536 = ((($8) + (($528*12)|0)|0) + 8|0);
      $537 = Math_fround(HEAPF32[$536>>2]);
      $538 = Math_fround($473 * $537);
      $539 = Math_fround($535 + $538);
      $540 = Math_fround($487 * $539);
      $541 = Math_fround($525 + $540);
      $542 = ((($6) + (($i13$020$i*20)|0)|0) + 12|0);
      $543 = Math_fround(HEAPF32[$542>>2]);
      $544 = Math_fround($487 * $543);
      $545 = Math_fround($525 - $544);
      $546 = Math_fround(HEAPF32[$localPoints>>2]);
      $547 = Math_fround($515 * $546);
      $548 = Math_fround(HEAPF32[$353>>2]);
      $549 = Math_fround($516 * $548);
      $550 = Math_fround($547 + $549);
      $551 = Math_fround(HEAPF32[$354>>2]);
      $552 = Math_fround($517 * $551);
      $553 = Math_fround($550 + $552);
      $554 = Math_fround(HEAPF32[$355>>2]);
      $555 = Math_fround($515 * $554);
      $556 = Math_fround(HEAPF32[$356>>2]);
      $557 = Math_fround($516 * $556);
      $558 = Math_fround($555 + $557);
      $559 = Math_fround(HEAPF32[$357>>2]);
      $560 = Math_fround($517 * $559);
      $561 = Math_fround($558 + $560);
      $562 = $553 < $561;
      $563 = $562 ? $553 : $561;
      $564 = $553 > $561;
      $565 = $564 ? $553 : $561;
      $566 = Math_fround(HEAPF32[$358>>2]);
      $567 = Math_fround($515 * $566);
      $568 = Math_fround(HEAPF32[$359>>2]);
      $569 = Math_fround($516 * $568);
      $570 = Math_fround($567 + $569);
      $571 = Math_fround(HEAPF32[$360>>2]);
      $572 = Math_fround($517 * $571);
      $573 = Math_fround($570 + $572);
      $574 = $563 < $573;
      $575 = $574 ? $563 : $573;
      $576 = $565 > $573;
      $577 = $576 ? $565 : $573;
      $578 = Math_fround($545 + $contactDistance);
      $579 = $578 < $575;
      if ($579) {
       $$0 = 0;
       label = 89;
       break;
      }
      $580 = Math_fround($577 + $contactDistance);
      $581 = $580 < $541;
      if ($581) {
       $$0 = 0;
       label = 89;
       break;
      }
      $582 = Math_fround($545 - $575);
      $583 = Math_fround($577 - $541);
      $584 = $582 < $583;
      $585 = $584 ? $582 : $583;
      $586 = $585 < $587;
      if ($586) {
       $1361 = $585;$1362 = $517;$1363 = $516;$1364 = $515;$i$026$i13 = $i13$020$i;
      } else {
       $1361 = $587;$1362 = $1351;$1363 = $1352;$1364 = $1353;$i$026$i13 = $i$026$i14;
      }
      $588 = (($4) + ($i13$020$i<<2)|0);
      HEAP32[$588>>2] = $i13$020$i;
      $589 = (($i13$020$i) + 1)|0;
      $590 = ($589>>>0)<($2>>>0);
      if ($590) {
       $1351 = $1362;$1352 = $1363;$1353 = $1364;$587 = $1361;$i$026$i14 = $i$026$i13;$i13$020$i = $589;
      } else {
       $1330 = $1362;$1331 = $1363;$1332 = $1364;$651 = $1361;$913 = $2;$i$026$i12 = $i$026$i13;
       break L31;
      }
     }
     if ((label|0) == 89) {
      STACKTOP = sp;return ($$0|0);
     }
    }
   } else {
    $1330 = $1341;$1331 = $1342;$1332 = $1343;$651 = $1340;$913 = $331;$i$026$i12 = $i$026$i7;
   }
  }
 } while(0);
 HEAPF32[$groupAxis>>2] = Math_fround(0.0);
 $591 = (($groupAxis) + 4|0);
 HEAPF32[$591>>2] = Math_fround(0.0);
 $592 = (($groupAxis) + 8|0);
 HEAPF32[$592>>2] = Math_fround(0.0);
 HEAPF32[$groupMinDepth>>2] = Math_fround(3.40282346638528859812E+38);
 $593 = (($polyData0) + 64|0);
 $594 = HEAP32[$593>>2]|0;
 FUNCTION_TABLE_viiiiii[$594 & 255]($polyData0,$localPlane,$m0to1,$convexScaling,$min0$i,$max0$i);
 $595 = Math_fround(HEAPF32[$localPoints>>2]);
 $596 = Math_fround(HEAPF32[$localPlane>>2]);
 $597 = Math_fround($595 * $596);
 $598 = (($localPoints) + 4|0);
 $599 = Math_fround(HEAPF32[$598>>2]);
 $600 = (($localPlane) + 4|0);
 $601 = Math_fround(HEAPF32[$600>>2]);
 $602 = Math_fround($599 * $601);
 $603 = Math_fround($597 + $602);
 $604 = (($localPoints) + 8|0);
 $605 = Math_fround(HEAPF32[$604>>2]);
 $606 = (($localPlane) + 8|0);
 $607 = Math_fround(HEAPF32[$606>>2]);
 $608 = Math_fround($605 * $607);
 $609 = Math_fround($603 + $608);
 $610 = (($localPoints) + 12|0);
 $611 = Math_fround(HEAPF32[$610>>2]);
 $612 = Math_fround($596 * $611);
 $613 = (($localPoints) + 16|0);
 $614 = Math_fround(HEAPF32[$613>>2]);
 $615 = Math_fround($601 * $614);
 $616 = Math_fround($612 + $615);
 $617 = (($localPoints) + 20|0);
 $618 = Math_fround(HEAPF32[$617>>2]);
 $619 = Math_fround($607 * $618);
 $620 = Math_fround($616 + $619);
 $621 = $609 < $620;
 $622 = $621 ? $609 : $620;
 $623 = $609 > $620;
 $624 = $623 ? $609 : $620;
 $625 = (($localPoints) + 24|0);
 $626 = Math_fround(HEAPF32[$625>>2]);
 $627 = Math_fround($596 * $626);
 $628 = (($localPoints) + 28|0);
 $629 = Math_fround(HEAPF32[$628>>2]);
 $630 = Math_fround($601 * $629);
 $631 = Math_fround($627 + $630);
 $632 = (($localPoints) + 32|0);
 $633 = Math_fround(HEAPF32[$632>>2]);
 $634 = Math_fround($607 * $633);
 $635 = Math_fround($631 + $634);
 $636 = $622 < $635;
 $637 = $636 ? $622 : $635;
 $638 = $624 > $635;
 $639 = $638 ? $624 : $635;
 $640 = Math_fround(HEAPF32[$max0$i>>2]);
 $641 = Math_fround($640 + $contactDistance);
 $642 = $641 < $637;
 if ($642) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $643 = Math_fround($639 + $contactDistance);
 $644 = Math_fround(HEAPF32[$min0$i>>2]);
 $645 = $643 < $644;
 if ($645) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $646 = Math_fround($640 - $637);
 $647 = Math_fround($639 - $644);
 $648 = $646 < $647;
 $649 = $648 ? $646 : $647;
 $650 = Math_fround($651 + Math_fround(9.99999974737875163555E-5));
 $652 = $649 < $650;
 if ($652) {
  $655 = $649;$658 = $596;$668 = $601;$681 = $607;$storemerge = 1;
 } else {
  $655 = $651;$658 = $1332;$668 = $1331;$681 = $1330;$storemerge = 0;
 }
 HEAP8[$faceContact>>0] = $storemerge;
 $653 = Math_fround(HEAPF32[$groupMinDepth>>2]);
 $654 = $655 < $653;
 if ($654) {
  HEAPF32[$groupMinDepth>>2] = $655;
  $656 = Math_fround(HEAPF32[$world1>>2]);
  $657 = Math_fround($658 * $656);
  $659 = (($world1) + 4|0);
  $660 = Math_fround(HEAPF32[$659>>2]);
  $661 = Math_fround($658 * $660);
  $662 = (($world1) + 8|0);
  $663 = Math_fround(HEAPF32[$662>>2]);
  $664 = Math_fround($658 * $663);
  $665 = (($world1) + 12|0);
  $666 = Math_fround(HEAPF32[$665>>2]);
  $667 = Math_fround($668 * $666);
  $669 = (($world1) + 16|0);
  $670 = Math_fround(HEAPF32[$669>>2]);
  $671 = Math_fround($668 * $670);
  $672 = (($world1) + 20|0);
  $673 = Math_fround(HEAPF32[$672>>2]);
  $674 = Math_fround($668 * $673);
  $675 = Math_fround($657 + $667);
  $676 = Math_fround($661 + $671);
  $677 = Math_fround($664 + $674);
  $678 = (($world1) + 24|0);
  $679 = Math_fround(HEAPF32[$678>>2]);
  $680 = Math_fround($681 * $679);
  $682 = (($world1) + 28|0);
  $683 = Math_fround(HEAPF32[$682>>2]);
  $684 = Math_fround($681 * $683);
  $685 = (($world1) + 32|0);
  $686 = Math_fround(HEAPF32[$685>>2]);
  $687 = Math_fround($681 * $686);
  $688 = Math_fround($675 + $680);
  $689 = Math_fround($676 + $684);
  $690 = Math_fround($677 + $687);
  HEAPF32[$groupAxis>>2] = $688;
  HEAPF32[$591>>2] = $689;
  HEAPF32[$592>>2] = $690;
 }
 $691 = HEAP32[$5>>2]|0;
 $692 = (($691) + (($i$026$i12*20)|0)|0);
 $693 = Math_fround(HEAPF32[$692>>2]);
 $694 = Math_fround(HEAPF32[$m1to0>>2]);
 $695 = Math_fround($693 * $694);
 $696 = (($m1to0) + 4|0);
 $697 = Math_fround(HEAPF32[$696>>2]);
 $698 = Math_fround($693 * $697);
 $699 = (($m1to0) + 8|0);
 $700 = Math_fround(HEAPF32[$699>>2]);
 $701 = Math_fround($693 * $700);
 $702 = ((($691) + (($i$026$i12*20)|0)|0) + 4|0);
 $703 = Math_fround(HEAPF32[$702>>2]);
 $704 = (($m1to0) + 12|0);
 $705 = Math_fround(HEAPF32[$704>>2]);
 $706 = Math_fround($703 * $705);
 $707 = (($m1to0) + 16|0);
 $708 = Math_fround(HEAPF32[$707>>2]);
 $709 = Math_fround($703 * $708);
 $710 = (($m1to0) + 20|0);
 $711 = Math_fround(HEAPF32[$710>>2]);
 $712 = Math_fround($703 * $711);
 $713 = Math_fround($695 + $706);
 $714 = Math_fround($698 + $709);
 $715 = Math_fround($701 + $712);
 $716 = ((($691) + (($i$026$i12*20)|0)|0) + 8|0);
 $717 = Math_fround(HEAPF32[$716>>2]);
 $718 = (($m1to0) + 24|0);
 $719 = Math_fround(HEAPF32[$718>>2]);
 $720 = Math_fround($717 * $719);
 $721 = (($m1to0) + 28|0);
 $722 = Math_fround(HEAPF32[$721>>2]);
 $723 = Math_fround($717 * $722);
 $724 = (($m1to0) + 32|0);
 $725 = Math_fround(HEAPF32[$724>>2]);
 $726 = Math_fround($717 * $725);
 $727 = Math_fround($713 + $720);
 $728 = Math_fround($714 + $723);
 $729 = Math_fround($715 + $726);
 $730 = Math_fround(HEAPF32[$convexScaling>>2]);
 $731 = Math_fround($727 * $730);
 $732 = (($convexScaling) + 4|0);
 $733 = Math_fround(HEAPF32[$732>>2]);
 $734 = Math_fround($727 * $733);
 $735 = (($convexScaling) + 8|0);
 $736 = Math_fround(HEAPF32[$735>>2]);
 $737 = Math_fround($727 * $736);
 $738 = (($convexScaling) + 12|0);
 $739 = Math_fround(HEAPF32[$738>>2]);
 $740 = Math_fround($728 * $739);
 $741 = (($convexScaling) + 16|0);
 $742 = Math_fround(HEAPF32[$741>>2]);
 $743 = Math_fround($728 * $742);
 $744 = (($convexScaling) + 20|0);
 $745 = Math_fround(HEAPF32[$744>>2]);
 $746 = Math_fround($728 * $745);
 $747 = Math_fround($731 + $740);
 $748 = Math_fround($734 + $743);
 $749 = Math_fround($737 + $746);
 $750 = (($convexScaling) + 24|0);
 $751 = Math_fround(HEAPF32[$750>>2]);
 $752 = Math_fround($729 * $751);
 $753 = (($convexScaling) + 28|0);
 $754 = Math_fround(HEAPF32[$753>>2]);
 $755 = Math_fround($729 * $754);
 $756 = (($convexScaling) + 32|0);
 $757 = Math_fround(HEAPF32[$756>>2]);
 $758 = Math_fround($729 * $757);
 $759 = Math_fround($747 + $752);
 $760 = Math_fround($748 + $755);
 $761 = Math_fround($749 + $758);
 $762 = ((($691) + (($i$026$i12*20)|0)|0) + 12|0);
 $763 = Math_fround(HEAPF32[$762>>2]);
 $764 = (($m1to0) + 36|0);
 $765 = Math_fround(HEAPF32[$764>>2]);
 $766 = Math_fround($727 * $765);
 $767 = (($m1to0) + 40|0);
 $768 = Math_fround(HEAPF32[$767>>2]);
 $769 = Math_fround($728 * $768);
 $770 = Math_fround($766 + $769);
 $771 = (($m1to0) + 44|0);
 $772 = Math_fround(HEAPF32[$771>>2]);
 $773 = Math_fround($729 * $772);
 $774 = Math_fround($770 + $773);
 $775 = Math_fround($763 - $774);
 $776 = $triFlags&255;
 $777 = $776 & 8;
 $778 = ($777|0)==(0);
 do {
  if ($778) {
   $nbTriangleAxes$0$i = 0;
  } else {
   $779 = Math_fround(HEAPF32[$localPoints>>2]);
   $780 = Math_fround($759 * $779);
   $781 = Math_fround(HEAPF32[$598>>2]);
   $782 = Math_fround($760 * $781);
   $783 = Math_fround($780 + $782);
   $784 = Math_fround(HEAPF32[$604>>2]);
   $785 = Math_fround($761 * $784);
   $786 = Math_fround($783 + $785);
   $787 = Math_fround($775 + $786);
   $788 = !($787 <= $contactDistance);
   $789 = Math_fround(HEAPF32[$610>>2]);
   if ($788) {
    $790 = Math_fround($759 * $789);
    $791 = Math_fround(HEAPF32[$613>>2]);
    $792 = Math_fround($760 * $791);
    $793 = Math_fround($790 + $792);
    $794 = Math_fround(HEAPF32[$617>>2]);
    $795 = Math_fround($761 * $794);
    $796 = Math_fround($793 + $795);
    $797 = Math_fround($775 + $796);
    $798 = !($797 <= $contactDistance);
    if ($798) {
     $nbTriangleAxes$0$i = 0;
     break;
    } else {
     $801 = $791;$803 = $794;
    }
   } else {
    $$pre64$i = Math_fround(HEAPF32[$613>>2]);
    $$pre66$i = Math_fround(HEAPF32[$617>>2]);
    $801 = $$pre64$i;$803 = $$pre66$i;
   }
   $799 = Math_fround($779 - $789);
   $800 = Math_fround($781 - $801);
   $802 = Math_fround($784 - $803);
   HEAPF32[$min0$i>>2] = $799;
   $804 = (($min0$i) + 4|0);
   HEAPF32[$804>>2] = $800;
   $805 = (($min0$i) + 8|0);
   HEAPF32[$805>>2] = $802;
   $nbTriangleAxes$0$i = 1;
  }
 } while(0);
 $806 = $776 & 16;
 $807 = ($806|0)==(0);
 do {
  if ($807) {
   $nbTriangleAxes$1$i = $nbTriangleAxes$0$i;
  } else {
   $808 = Math_fround(HEAPF32[$610>>2]);
   $809 = Math_fround($759 * $808);
   $810 = Math_fround(HEAPF32[$613>>2]);
   $811 = Math_fround($760 * $810);
   $812 = Math_fround($809 + $811);
   $813 = Math_fround(HEAPF32[$617>>2]);
   $814 = Math_fround($761 * $813);
   $815 = Math_fround($812 + $814);
   $816 = Math_fround($775 + $815);
   $817 = !($816 <= $contactDistance);
   $818 = Math_fround(HEAPF32[$625>>2]);
   if ($817) {
    $819 = Math_fround($759 * $818);
    $820 = Math_fround(HEAPF32[$628>>2]);
    $821 = Math_fround($760 * $820);
    $822 = Math_fround($819 + $821);
    $823 = Math_fround(HEAPF32[$632>>2]);
    $824 = Math_fround($761 * $823);
    $825 = Math_fround($822 + $824);
    $826 = Math_fround($775 + $825);
    $827 = !($826 <= $contactDistance);
    if ($827) {
     $nbTriangleAxes$1$i = $nbTriangleAxes$0$i;
     break;
    } else {
     $831 = $820;$833 = $823;
    }
   } else {
    $$pre58$i = Math_fround(HEAPF32[$628>>2]);
    $$pre60$i = Math_fround(HEAPF32[$632>>2]);
    $831 = $$pre58$i;$833 = $$pre60$i;
   }
   $828 = (($nbTriangleAxes$0$i) + 1)|0;
   $829 = Math_fround($808 - $818);
   $830 = Math_fround($810 - $831);
   $832 = Math_fround($813 - $833);
   $834 = (($min0$i) + (($nbTriangleAxes$0$i*12)|0)|0);
   HEAPF32[$834>>2] = $829;
   $835 = ((($min0$i) + (($nbTriangleAxes$0$i*12)|0)|0) + 4|0);
   HEAPF32[$835>>2] = $830;
   $836 = ((($min0$i) + (($nbTriangleAxes$0$i*12)|0)|0) + 8|0);
   HEAPF32[$836>>2] = $832;
   $nbTriangleAxes$1$i = $828;
  }
 } while(0);
 $837 = $776 & 32;
 $838 = ($837|0)==(0);
 do {
  if ($838) {
   $nbTriangleAxes$2$i = $nbTriangleAxes$1$i;
  } else {
   $839 = Math_fround(HEAPF32[$625>>2]);
   $840 = Math_fround($759 * $839);
   $841 = Math_fround(HEAPF32[$628>>2]);
   $842 = Math_fround($760 * $841);
   $843 = Math_fround($840 + $842);
   $844 = Math_fround(HEAPF32[$632>>2]);
   $845 = Math_fround($761 * $844);
   $846 = Math_fround($843 + $845);
   $847 = Math_fround($775 + $846);
   $848 = !($847 <= $contactDistance);
   $849 = Math_fround(HEAPF32[$localPoints>>2]);
   if ($848) {
    $850 = Math_fround($759 * $849);
    $851 = Math_fround(HEAPF32[$598>>2]);
    $852 = Math_fround($760 * $851);
    $853 = Math_fround($850 + $852);
    $854 = Math_fround(HEAPF32[$604>>2]);
    $855 = Math_fround($761 * $854);
    $856 = Math_fround($853 + $855);
    $857 = Math_fround($775 + $856);
    $858 = !($857 <= $contactDistance);
    if ($858) {
     $nbTriangleAxes$2$i = $nbTriangleAxes$1$i;
     break;
    } else {
     $862 = $851;$864 = $854;
    }
   } else {
    $$pre52$i = Math_fround(HEAPF32[$598>>2]);
    $$pre54$i = Math_fround(HEAPF32[$604>>2]);
    $862 = $$pre52$i;$864 = $$pre54$i;
   }
   $859 = (($nbTriangleAxes$1$i) + 1)|0;
   $860 = Math_fround($839 - $849);
   $861 = Math_fround($841 - $862);
   $863 = Math_fround($844 - $864);
   $865 = (($min0$i) + (($nbTriangleAxes$1$i*12)|0)|0);
   HEAPF32[$865>>2] = $860;
   $866 = ((($min0$i) + (($nbTriangleAxes$1$i*12)|0)|0) + 4|0);
   HEAPF32[$866>>2] = $861;
   $867 = ((($min0$i) + (($nbTriangleAxes$1$i*12)|0)|0) + 8|0);
   HEAPF32[$867>>2] = $863;
   $nbTriangleAxes$2$i = $859;
  }
 } while(0);
 $868 = Math_fround(HEAPF32[$localPlane>>2]);
 $869 = Math_fround($694 * $868);
 $870 = Math_fround($697 * $868);
 $871 = Math_fround($700 * $868);
 $872 = Math_fround(HEAPF32[$600>>2]);
 $873 = Math_fround($705 * $872);
 $874 = Math_fround($708 * $872);
 $875 = Math_fround($711 * $872);
 $876 = Math_fround($869 + $873);
 $877 = Math_fround($870 + $874);
 $878 = Math_fround($871 + $875);
 $879 = Math_fround(HEAPF32[$606>>2]);
 $880 = Math_fround($719 * $879);
 $881 = Math_fround($722 * $879);
 $882 = Math_fround($725 * $879);
 $883 = Math_fround($876 + $880);
 $884 = Math_fround($877 + $881);
 $885 = Math_fround($878 + $882);
 $886 = Math_fround($730 * $883);
 $887 = Math_fround($733 * $883);
 $888 = Math_fround($736 * $883);
 $889 = Math_fround($739 * $884);
 $890 = Math_fround($742 * $884);
 $891 = Math_fround($745 * $884);
 $892 = Math_fround($886 + $889);
 $893 = Math_fround($887 + $890);
 $894 = Math_fround($888 + $891);
 $895 = Math_fround($751 * $885);
 $896 = Math_fround($754 * $885);
 $897 = Math_fround($757 * $885);
 $898 = Math_fround($895 + $892);
 $899 = Math_fround($896 + $893);
 $900 = Math_fround($897 + $894);
 $901 = (($localPlane) + 12|0);
 $902 = Math_fround(HEAPF32[$901>>2]);
 $903 = Math_fround($765 * $883);
 $904 = Math_fround($768 * $884);
 $905 = Math_fround($903 + $904);
 $906 = Math_fround($772 * $885);
 $907 = Math_fround($906 + $905);
 $908 = Math_fround($902 - $907);
 $909 = HEAP32[$7>>2]|0;
 HEAP32[$max0$i>>2] = 0;
 $910 = (($polyData0) + 32|0);
 $911 = HEAP32[$910>>2]|0;
 $912 = ($913|0)==(0);
 L96: do {
  if ($912) {
   label = 76;
  } else {
   $914 = ($nbTriangleAxes$2$i|0)==(0);
   $915 = (($m0to1) + 4|0);
   $916 = (($m0to1) + 8|0);
   $917 = (($m0to1) + 12|0);
   $918 = (($m0to1) + 16|0);
   $919 = (($m0to1) + 20|0);
   $920 = (($m0to1) + 24|0);
   $921 = (($m0to1) + 28|0);
   $922 = (($m0to1) + 32|0);
   $923 = (($0) + 4|0);
   $924 = (($0) + 8|0);
   if ($914) {
    label = 76;
   } else {
    $$0239$i = $4;$$in67$i = $913;
    while(1) {
     $927 = (($$in67$i) + -1)|0;
     $928 = HEAP32[$$0239$i>>2]|0;
     $929 = ((($691) + (($928*20)|0)|0) + 16|0);
     $930 = HEAP16[$929>>1]|0;
     $931 = $930&65535;
     $932 = ((($691) + (($928*20)|0)|0) + 18|0);
     $$in$i = $nbTriangleAxes$2$i;$edges$037$i = $min0$i;
     while(1) {
      $934 = (($$in$i) + -1)|0;
      $935 = (($edges$037$i) + 12|0);
      $936 = HEAP8[$932>>0]|0;
      $937 = $936&255;
      $938 = ($936<<24>>24)==(0);
      if (!($938)) {
       $939 = (($edges$037$i) + 8|0);
       $940 = (($edges$037$i) + 4|0);
       $j$034$i = 0;
       while(1) {
        $941 = (($j$034$i) + 1)|0;
        $942 = ($941>>>0)>=($937>>>0);
        $$$i = $942 ? 0 : $941;
        $$sum$i = (($j$034$i) + ($931))|0;
        $943 = (($911) + ($$sum$i)|0);
        $944 = HEAP8[$943>>0]|0;
        $945 = $944&255;
        $$sum1$i = (($$$i) + ($931))|0;
        $946 = (($911) + ($$sum1$i)|0);
        $947 = HEAP8[$946>>0]|0;
        $948 = $947&255;
        $949 = (($909) + (($945*12)|0)|0);
        $950 = Math_fround(HEAPF32[$949>>2]);
        $951 = Math_fround($898 * $950);
        $952 = ((($909) + (($945*12)|0)|0) + 4|0);
        $953 = Math_fround(HEAPF32[$952>>2]);
        $954 = Math_fround($899 * $953);
        $955 = Math_fround($951 + $954);
        $956 = ((($909) + (($945*12)|0)|0) + 8|0);
        $957 = Math_fround(HEAPF32[$956>>2]);
        $958 = Math_fround($900 * $957);
        $959 = Math_fround($955 + $958);
        $960 = Math_fround($908 + $959);
        $961 = !($960 <= $contactDistance);
        $962 = (($909) + (($948*12)|0)|0);
        $963 = Math_fround(HEAPF32[$962>>2]);
        if ($961) {
         $964 = Math_fround($898 * $963);
         $965 = ((($909) + (($948*12)|0)|0) + 4|0);
         $966 = Math_fround(HEAPF32[$965>>2]);
         $967 = Math_fround($899 * $966);
         $968 = Math_fround($964 + $967);
         $969 = ((($909) + (($948*12)|0)|0) + 8|0);
         $970 = Math_fround(HEAPF32[$969>>2]);
         $971 = Math_fround($900 * $970);
         $972 = Math_fround($968 + $971);
         $973 = Math_fround($908 + $972);
         $974 = !($973 <= $contactDistance);
         if (!($974)) {
          $977 = $966;$979 = $970;
          label = 69;
         }
        } else {
         $$phi$trans$insert45$i = ((($909) + (($948*12)|0)|0) + 4|0);
         $$pre46$i = Math_fround(HEAPF32[$$phi$trans$insert45$i>>2]);
         $$phi$trans$insert47$i = ((($909) + (($948*12)|0)|0) + 8|0);
         $$pre48$i = Math_fround(HEAPF32[$$phi$trans$insert47$i>>2]);
         $977 = $$pre46$i;$979 = $$pre48$i;
         label = 69;
        }
        L109: do {
         if ((label|0) == 69) {
          label = 0;
          $975 = Math_fround($950 - $963);
          $976 = Math_fround($953 - $977);
          $978 = Math_fround($957 - $979);
          $980 = Math_fround(HEAPF32[$convexScaling>>2]);
          $981 = Math_fround($975 * $980);
          $982 = Math_fround(HEAPF32[$732>>2]);
          $983 = Math_fround($975 * $982);
          $984 = Math_fround(HEAPF32[$735>>2]);
          $985 = Math_fround($975 * $984);
          $986 = Math_fround(HEAPF32[$738>>2]);
          $987 = Math_fround($976 * $986);
          $988 = Math_fround(HEAPF32[$741>>2]);
          $989 = Math_fround($976 * $988);
          $990 = Math_fround(HEAPF32[$744>>2]);
          $991 = Math_fround($976 * $990);
          $992 = Math_fround($981 + $987);
          $993 = Math_fround($983 + $989);
          $994 = Math_fround($985 + $991);
          $995 = Math_fround(HEAPF32[$750>>2]);
          $996 = Math_fround($978 * $995);
          $997 = Math_fround(HEAPF32[$753>>2]);
          $998 = Math_fround($978 * $997);
          $999 = Math_fround(HEAPF32[$756>>2]);
          $1000 = Math_fround($978 * $999);
          $1001 = Math_fround($992 + $996);
          $1002 = Math_fround($993 + $998);
          $1003 = Math_fround($994 + $1000);
          $1004 = Math_fround(HEAPF32[$m0to1>>2]);
          $1005 = Math_fround($1001 * $1004);
          $1006 = Math_fround(HEAPF32[$915>>2]);
          $1007 = Math_fround($1001 * $1006);
          $1008 = Math_fround(HEAPF32[$916>>2]);
          $1009 = Math_fround($1001 * $1008);
          $1010 = Math_fround(HEAPF32[$917>>2]);
          $1011 = Math_fround($1002 * $1010);
          $1012 = Math_fround(HEAPF32[$918>>2]);
          $1013 = Math_fround($1002 * $1012);
          $1014 = Math_fround(HEAPF32[$919>>2]);
          $1015 = Math_fround($1002 * $1014);
          $1016 = Math_fround($1005 + $1011);
          $1017 = Math_fround($1007 + $1013);
          $1018 = Math_fround($1009 + $1015);
          $1019 = Math_fround(HEAPF32[$920>>2]);
          $1020 = Math_fround($1003 * $1019);
          $1021 = Math_fround(HEAPF32[$921>>2]);
          $1022 = Math_fround($1003 * $1021);
          $1023 = Math_fround(HEAPF32[$922>>2]);
          $1024 = Math_fround($1003 * $1023);
          $1025 = Math_fround($1016 + $1020);
          $1026 = Math_fround($1017 + $1022);
          $1027 = Math_fround($1018 + $1024);
          $1028 = Math_fround(HEAPF32[$939>>2]);
          $1029 = Math_fround($1026 * $1028);
          $1030 = Math_fround(HEAPF32[$940>>2]);
          $1031 = Math_fround($1027 * $1030);
          $1032 = Math_fround($1029 - $1031);
          $1033 = Math_fround(HEAPF32[$edges$037$i>>2]);
          $1034 = Math_fround($1027 * $1033);
          $1035 = Math_fround($1025 * $1028);
          $1036 = Math_fround($1034 - $1035);
          $1037 = Math_fround($1025 * $1030);
          $1038 = Math_fround($1026 * $1033);
          $1039 = Math_fround($1037 - $1038);
          $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($1032)))));
          $1040 = +$fabsf$i$i$i$i;
          $1041 = $1040 > 9.99999999999999954748E-7;
          do {
           if (!($1041)) {
            $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($1036)))));
            $1042 = +$fabsf$i$i1$i$i;
            $1043 = $1042 > 9.99999999999999954748E-7;
            if ($1043) {
             break;
            }
            $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($1039)))));
            $1044 = +$fabsf$i$i2$i$i;
            $1045 = $1044 > 9.99999999999999954748E-7;
            if (!($1045)) {
             break L109;
            }
           }
          } while(0);
          $1046 = Math_fround($1032 * $1032);
          $1047 = Math_fround($1036 * $1036);
          $1048 = Math_fround($1046 + $1047);
          $1049 = Math_fround($1039 * $1039);
          $1050 = Math_fround($1049 + $1048);
          $1051 = $1050 > Math_fround(0.0);
          if ($1051) {
           $1052 = (Math_fround(Math_sqrt((Math_fround($1050)))));
           $1053 = Math_fround(Math_fround(1.0) / $1052);
           $1054 = Math_fround($1032 * $1053);
           $1055 = Math_fround($1036 * $1053);
           $1056 = Math_fround($1039 * $1053);
           $storemerge$i = $1056;$storemerge68$i = $1055;$storemerge69$i = $1054;
          } else {
           $storemerge$i = Math_fround(0.0);$storemerge68$i = Math_fround(0.0);$storemerge69$i = Math_fround(0.0);
          }
          HEAPF32[$0>>2] = $storemerge69$i;
          HEAPF32[$923>>2] = $storemerge68$i;
          HEAPF32[$924>>2] = $storemerge$i;
          (__ZN5physx2Gu14SeparatingAxes7addAxisERKNS_6PxVec3E($max0$i,$0)|0);
         }
        } while(0);
        $exitcond$i = ($941|0)==($937|0);
        if ($exitcond$i) {
         break;
        } else {
         $j$034$i = $941;
        }
       }
      }
      $933 = ($934|0)==(0);
      if ($933) {
       break;
      } else {
       $$in$i = $934;$edges$037$i = $935;
      }
     }
     $925 = (($$0239$i) + 4|0);
     $926 = ($927|0)==(0);
     if ($926) {
      break;
     } else {
      $$0239$i = $925;$$in67$i = $927;
     }
    }
    $$pre$pre$i = HEAP32[$max0$i>>2]|0;
    $1057 = ($$pre$pre$i|0)==(0);
    if ($1057) {
     $$0$i = 1;$1294 = Math_fround(3.40282346638528859812E+38);$1297 = $658;$1307 = $668;$1320 = $681;$1365 = $triangleInHullSpace$i;
    } else {
     $1058 = (($max0$i) + 4|0);
     $1059 = Math_fround(HEAPF32[$localPoints>>2]);
     $1060 = Math_fround(HEAPF32[$m1to0>>2]);
     $1061 = Math_fround($1059 * $1060);
     $1062 = Math_fround(HEAPF32[$696>>2]);
     $1063 = Math_fround($1059 * $1062);
     $1064 = Math_fround(HEAPF32[$699>>2]);
     $1065 = Math_fround($1059 * $1064);
     $1066 = Math_fround(HEAPF32[$598>>2]);
     $1067 = Math_fround(HEAPF32[$704>>2]);
     $1068 = Math_fround($1066 * $1067);
     $1069 = Math_fround(HEAPF32[$707>>2]);
     $1070 = Math_fround($1066 * $1069);
     $1071 = Math_fround(HEAPF32[$710>>2]);
     $1072 = Math_fround($1066 * $1071);
     $1073 = Math_fround($1061 + $1068);
     $1074 = Math_fround($1063 + $1070);
     $1075 = Math_fround($1065 + $1072);
     $1076 = Math_fround(HEAPF32[$604>>2]);
     $1077 = Math_fround(HEAPF32[$718>>2]);
     $1078 = Math_fround($1076 * $1077);
     $1079 = Math_fround(HEAPF32[$721>>2]);
     $1080 = Math_fround($1076 * $1079);
     $1081 = Math_fround(HEAPF32[$724>>2]);
     $1082 = Math_fround($1076 * $1081);
     $1083 = Math_fround($1073 + $1078);
     $1084 = Math_fround($1074 + $1080);
     $1085 = Math_fround($1075 + $1082);
     $1086 = Math_fround(HEAPF32[$764>>2]);
     $1087 = Math_fround($1083 + $1086);
     $1088 = Math_fround(HEAPF32[$767>>2]);
     $1089 = Math_fround($1084 + $1088);
     $1090 = Math_fround(HEAPF32[$771>>2]);
     $1091 = Math_fround($1085 + $1090);
     HEAPF32[$triangleInHullSpace$i>>2] = $1087;
     $1092 = (($triangleInHullSpace$i) + 4|0);
     HEAPF32[$1092>>2] = $1089;
     $1093 = (($triangleInHullSpace$i) + 8|0);
     HEAPF32[$1093>>2] = $1091;
     $1094 = Math_fround(HEAPF32[$610>>2]);
     $1095 = Math_fround($1060 * $1094);
     $1096 = Math_fround($1062 * $1094);
     $1097 = Math_fround($1064 * $1094);
     $1098 = Math_fround(HEAPF32[$613>>2]);
     $1099 = Math_fround($1067 * $1098);
     $1100 = Math_fround($1069 * $1098);
     $1101 = Math_fround($1071 * $1098);
     $1102 = Math_fround($1095 + $1099);
     $1103 = Math_fround($1096 + $1100);
     $1104 = Math_fround($1097 + $1101);
     $1105 = Math_fround(HEAPF32[$617>>2]);
     $1106 = Math_fround($1077 * $1105);
     $1107 = Math_fround($1079 * $1105);
     $1108 = Math_fround($1081 * $1105);
     $1109 = Math_fround($1102 + $1106);
     $1110 = Math_fround($1103 + $1107);
     $1111 = Math_fround($1104 + $1108);
     $1112 = Math_fround($1086 + $1109);
     $1113 = Math_fround($1088 + $1110);
     $1114 = Math_fround($1090 + $1111);
     $1115 = (($triangleInHullSpace$i) + 12|0);
     HEAPF32[$1115>>2] = $1112;
     $1116 = (($triangleInHullSpace$i) + 16|0);
     HEAPF32[$1116>>2] = $1113;
     $1117 = (($triangleInHullSpace$i) + 20|0);
     HEAPF32[$1117>>2] = $1114;
     $1118 = Math_fround(HEAPF32[$625>>2]);
     $1119 = Math_fround($1060 * $1118);
     $1120 = Math_fround($1062 * $1118);
     $1121 = Math_fround($1064 * $1118);
     $1122 = Math_fround(HEAPF32[$628>>2]);
     $1123 = Math_fround($1067 * $1122);
     $1124 = Math_fround($1069 * $1122);
     $1125 = Math_fround($1071 * $1122);
     $1126 = Math_fround($1119 + $1123);
     $1127 = Math_fround($1120 + $1124);
     $1128 = Math_fround($1121 + $1125);
     $1129 = Math_fround(HEAPF32[$632>>2]);
     $1130 = Math_fround($1077 * $1129);
     $1131 = Math_fround($1079 * $1129);
     $1132 = Math_fround($1081 * $1129);
     $1133 = Math_fround($1126 + $1130);
     $1134 = Math_fround($1127 + $1131);
     $1135 = Math_fround($1128 + $1132);
     $1136 = Math_fround($1086 + $1133);
     $1137 = Math_fround($1088 + $1134);
     $1138 = Math_fround($1090 + $1135);
     $1139 = (($triangleInHullSpace$i) + 24|0);
     HEAPF32[$1139>>2] = $1136;
     $1140 = (($triangleInHullSpace$i) + 28|0);
     HEAPF32[$1140>>2] = $1137;
     $1141 = (($triangleInHullSpace$i) + 32|0);
     HEAPF32[$1141>>2] = $1138;
     $1142 = (($polyData0) + 4|0);
     $1143 = (($polyData0) + 8|0);
     $1144 = (($polyData0) + 44|0);
     $1145 = (($polyData0) + 48|0);
     $1146 = (($polyData0) + 52|0);
     $1147 = (($polyData0) + 40|0);
     $$in41$i = $$pre$pre$i;$1160 = $1067;$1162 = $1069;$1164 = $1071;$1171 = $1077;$1173 = $1079;$1175 = $1081;$1180 = $1087;$1240 = Math_fround(3.40282346638528859812E+38);$1366 = $681;$1367 = $668;$1368 = $658;$axes$033$i = $1058;
     while(1) {
      $1148 = (($$in41$i) + -1)|0;
      $1149 = (($axes$033$i) + 12|0);
      $1150 = Math_fround(HEAPF32[$axes$033$i>>2]);
      $1151 = Math_fround(HEAPF32[$m1to0>>2]);
      $1152 = Math_fround($1150 * $1151);
      $1153 = Math_fround(HEAPF32[$696>>2]);
      $1154 = Math_fround($1150 * $1153);
      $1155 = Math_fround(HEAPF32[$699>>2]);
      $1156 = Math_fround($1150 * $1155);
      $1157 = (($axes$033$i) + 4|0);
      $1158 = Math_fround(HEAPF32[$1157>>2]);
      $1159 = Math_fround($1158 * $1160);
      $1161 = Math_fround($1158 * $1162);
      $1163 = Math_fround($1158 * $1164);
      $1165 = Math_fround($1152 + $1159);
      $1166 = Math_fround($1154 + $1161);
      $1167 = Math_fround($1156 + $1163);
      $1168 = (($axes$033$i) + 8|0);
      $1169 = Math_fround(HEAPF32[$1168>>2]);
      $1170 = Math_fround($1169 * $1171);
      $1172 = Math_fround($1169 * $1173);
      $1174 = Math_fround($1169 * $1175);
      $1176 = Math_fround($1165 + $1170);
      $1177 = Math_fround($1166 + $1172);
      $1178 = Math_fround($1167 + $1174);
      $1179 = Math_fround($1180 * $1176);
      $1181 = Math_fround($1177 * $1089);
      $1182 = Math_fround($1179 + $1181);
      $1183 = Math_fround($1178 * $1091);
      $1184 = Math_fround($1182 + $1183);
      $1185 = Math_fround($1176 * $1112);
      $1186 = Math_fround($1177 * $1113);
      $1187 = Math_fround($1185 + $1186);
      $1188 = Math_fround($1178 * $1114);
      $1189 = Math_fround($1187 + $1188);
      $1190 = $1184 < $1189;
      $1191 = $1190 ? $1184 : $1189;
      $1192 = $1184 > $1189;
      $1193 = $1192 ? $1184 : $1189;
      $1194 = Math_fround($1176 * $1136);
      $1195 = Math_fround($1177 * $1137);
      $1196 = Math_fround($1194 + $1195);
      $1197 = Math_fround($1178 * $1138);
      $1198 = Math_fround($1196 + $1197);
      $1199 = $1191 < $1198;
      $1200 = $1199 ? $1191 : $1198;
      $1201 = $1193 > $1198;
      $1202 = $1201 ? $1193 : $1198;
      $1203 = Math_fround(HEAPF32[$polyData0>>2]);
      $1204 = Math_fround($1176 * $1203);
      $1205 = Math_fround(HEAPF32[$1142>>2]);
      $1206 = Math_fround($1177 * $1205);
      $1207 = Math_fround($1204 + $1206);
      $1208 = Math_fround(HEAPF32[$1143>>2]);
      $1209 = Math_fround($1178 * $1208);
      $1210 = Math_fround($1207 + $1209);
      $1211 = HEAP32[$1144>>2]|0;
      $1212 = (HEAPF32[tempDoublePtr>>2]=$1176,HEAP32[tempDoublePtr>>2]|0);
      $1213 = $1212 & -2147483648;
      $1214 = $1211 | $1213;
      $1215 = HEAP32[$1145>>2]|0;
      $1216 = (HEAPF32[tempDoublePtr>>2]=$1177,HEAP32[tempDoublePtr>>2]|0);
      $1217 = $1216 & -2147483648;
      $1218 = $1215 | $1217;
      $1219 = HEAP32[$1146>>2]|0;
      $1220 = (HEAPF32[tempDoublePtr>>2]=$1178,HEAP32[tempDoublePtr>>2]|0);
      $1221 = $1220 & -2147483648;
      $1222 = $1219 | $1221;
      $1223 = (HEAP32[tempDoublePtr>>2]=$1214,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $1224 = Math_fround($1176 * $1223);
      $1225 = (HEAP32[tempDoublePtr>>2]=$1218,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $1226 = Math_fround($1177 * $1225);
      $1227 = Math_fround($1224 + $1226);
      $1228 = (HEAP32[tempDoublePtr>>2]=$1222,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $1229 = Math_fround($1178 * $1228);
      $1230 = Math_fround($1227 + $1229);
      $1231 = Math_fround(HEAPF32[$1147>>2]);
      $1232 = $1230 > $1231;
      $1233 = $1232 ? $1230 : $1231;
      $1234 = Math_fround($1210 - $1233);
      $1235 = Math_fround($1210 + $1233);
      $1236 = Math_fround($1235 - $1200);
      $1237 = Math_fround($1202 - $1234);
      $1238 = $1236 < $1237;
      $1239 = $1238 ? $1236 : $1237;
      $not$$i$i = !($1239 > $1240);
      if ($not$$i$i) {
       $1242 = HEAP32[$593>>2]|0;
       FUNCTION_TABLE_viiiiii[$1242 & 255]($polyData0,$axes$033$i,$m0to1,$convexScaling,$min0$i$i,$max0$i$i);
       $1243 = Math_fround(HEAPF32[$localPoints>>2]);
       $1244 = Math_fround(HEAPF32[$axes$033$i>>2]);
       $1245 = Math_fround($1243 * $1244);
       $1246 = Math_fround(HEAPF32[$598>>2]);
       $1247 = Math_fround(HEAPF32[$1157>>2]);
       $1248 = Math_fround($1246 * $1247);
       $1249 = Math_fround($1245 + $1248);
       $1250 = Math_fround(HEAPF32[$604>>2]);
       $1251 = Math_fround(HEAPF32[$1168>>2]);
       $1252 = Math_fround($1250 * $1251);
       $1253 = Math_fround($1249 + $1252);
       $1254 = Math_fround(HEAPF32[$610>>2]);
       $1255 = Math_fround($1244 * $1254);
       $1256 = Math_fround(HEAPF32[$613>>2]);
       $1257 = Math_fround($1247 * $1256);
       $1258 = Math_fround($1255 + $1257);
       $1259 = Math_fround(HEAPF32[$617>>2]);
       $1260 = Math_fround($1251 * $1259);
       $1261 = Math_fround($1258 + $1260);
       $1262 = $1253 < $1261;
       $1263 = $1262 ? $1253 : $1261;
       $1264 = $1253 > $1261;
       $1265 = $1264 ? $1253 : $1261;
       $1266 = Math_fround(HEAPF32[$625>>2]);
       $1267 = Math_fround($1244 * $1266);
       $1268 = Math_fround(HEAPF32[$628>>2]);
       $1269 = Math_fround($1247 * $1268);
       $1270 = Math_fround($1267 + $1269);
       $1271 = Math_fround(HEAPF32[$632>>2]);
       $1272 = Math_fround($1251 * $1271);
       $1273 = Math_fround($1270 + $1272);
       $1274 = $1263 < $1273;
       $1275 = $1274 ? $1263 : $1273;
       $1276 = $1265 > $1273;
       $1277 = $1276 ? $1265 : $1273;
       $1278 = Math_fround(HEAPF32[$max0$i$i>>2]);
       $1279 = Math_fround($1278 + $contactDistance);
       $1280 = $1279 < $1275;
       if ($1280) {
        $$0$i = 0;$1294 = $1240;$1297 = $1368;$1307 = $1367;$1320 = $1366;$1365 = $triangleInHullSpace$i;
        break L96;
       }
       $1281 = Math_fround($1277 + $contactDistance);
       $1282 = Math_fround(HEAPF32[$min0$i$i>>2]);
       $1283 = $1281 < $1282;
       if ($1283) {
        $$0$i = 0;$1294 = $1240;$1297 = $1368;$1307 = $1367;$1320 = $1366;$1365 = $triangleInHullSpace$i;
        break L96;
       }
       $1284 = Math_fround($1278 - $1275);
       $1285 = Math_fround($1277 - $1282);
       $1286 = $1284 < $1285;
       $1287 = $1286 ? $1284 : $1285;
       $1288 = $1287 < $1240;
       if ($1288) {
        $1289 = Math_fround(HEAPF32[$axes$033$i>>2]);
        $1290 = Math_fround(HEAPF32[$1157>>2]);
        $1291 = Math_fround(HEAPF32[$1168>>2]);
        $1369 = $1291;$1370 = $1290;$1371 = $1289;$1372 = $1287;
       } else {
        $1369 = $1366;$1370 = $1367;$1371 = $1368;$1372 = $1240;
       }
      } else {
       $1369 = $1366;$1370 = $1367;$1371 = $1368;$1372 = $1240;
      }
      $1241 = ($1148|0)==(0);
      if ($1241) {
       $$0$i = 1;$1294 = $1372;$1297 = $1371;$1307 = $1370;$1320 = $1369;$1365 = $triangleInHullSpace$i;
       break L96;
      }
      $$pre43$i = Math_fround(HEAPF32[$triangleInHullSpace$i>>2]);
      $$pre = Math_fround(HEAPF32[$704>>2]);
      $$pre66 = Math_fround(HEAPF32[$707>>2]);
      $$pre67 = Math_fround(HEAPF32[$710>>2]);
      $$pre68 = Math_fround(HEAPF32[$718>>2]);
      $$pre69 = Math_fround(HEAPF32[$721>>2]);
      $$pre70 = Math_fround(HEAPF32[$724>>2]);
      $$in41$i = $1148;$1160 = $$pre;$1162 = $$pre66;$1164 = $$pre67;$1171 = $$pre68;$1173 = $$pre69;$1175 = $$pre70;$1180 = $$pre43$i;$1240 = $1372;$1366 = $1369;$1367 = $1370;$1368 = $1371;$axes$033$i = $1149;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 76) {
  $$0$i = 1;$1294 = Math_fround(3.40282346638528859812E+38);$1297 = $658;$1307 = $668;$1320 = $681;$1365 = $triangleInHullSpace$i;
 }
 if (!($$0$i)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1292 = Math_fround(HEAPF32[$groupMinDepth>>2]);
 $1293 = $1294 < $1292;
 if (!($1293)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$groupMinDepth>>2] = $1294;
 $1295 = Math_fround(HEAPF32[$world1>>2]);
 $1296 = Math_fround($1297 * $1295);
 $1298 = (($world1) + 4|0);
 $1299 = Math_fround(HEAPF32[$1298>>2]);
 $1300 = Math_fround($1297 * $1299);
 $1301 = (($world1) + 8|0);
 $1302 = Math_fround(HEAPF32[$1301>>2]);
 $1303 = Math_fround($1297 * $1302);
 $1304 = (($world1) + 12|0);
 $1305 = Math_fround(HEAPF32[$1304>>2]);
 $1306 = Math_fround($1307 * $1305);
 $1308 = (($world1) + 16|0);
 $1309 = Math_fround(HEAPF32[$1308>>2]);
 $1310 = Math_fround($1307 * $1309);
 $1311 = (($world1) + 20|0);
 $1312 = Math_fround(HEAPF32[$1311>>2]);
 $1313 = Math_fround($1307 * $1312);
 $1314 = Math_fround($1296 + $1306);
 $1315 = Math_fround($1300 + $1310);
 $1316 = Math_fround($1303 + $1313);
 $1317 = (($world1) + 24|0);
 $1318 = Math_fround(HEAPF32[$1317>>2]);
 $1319 = Math_fround($1320 * $1318);
 $1321 = (($world1) + 28|0);
 $1322 = Math_fround(HEAPF32[$1321>>2]);
 $1323 = Math_fround($1320 * $1322);
 $1324 = (($world1) + 32|0);
 $1325 = Math_fround(HEAPF32[$1324>>2]);
 $1326 = Math_fround($1320 * $1325);
 $1327 = Math_fround($1314 + $1319);
 $1328 = Math_fround($1315 + $1323);
 $1329 = Math_fround($1316 + $1326);
 HEAPF32[$groupAxis>>2] = $1327;
 HEAPF32[$591>>2] = $1328;
 HEAPF32[$592>>2] = $1329;
 HEAP8[$faceContact>>0] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu8CacheMapINS0_10CachedEdgeELj128EE7addDataERKS2_($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $nextInd$0 = 0, $nextInd$02 = 0, $nextInd$03 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(128);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$data>>2]|0;
 $4 = $3 << 16;
 $5 = (($data) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4 | $6;
 $8 = $7 << 15;
 $9 = $8 ^ -1;
 $10 = (($7) + ($9))|0;
 $11 = $10 >>> 10;
 $12 = $11 ^ $10;
 $13 = ($12*9)|0;
 $14 = $13 >>> 6;
 $15 = $14 ^ $13;
 $16 = $15 << 11;
 $17 = $16 ^ -1;
 $18 = (($15) + ($17))|0;
 $19 = $18 >>> 16;
 $20 = $19 ^ $18;
 $21 = $20 & 127;
 $22 = ((($this) + ($21)|0) + 1152|0);
 $nextInd$02 = HEAP8[$22>>0]|0;
 $23 = ($nextInd$02<<24>>24)==(-1);
 if ($23) {
  $24 = $1&255;
  $37 = $24;
  label = 9;
 } else {
  $25 = $nextInd$02&255;
  $27 = $25;$nextInd$03 = $nextInd$02;
  while(1) {
   $26 = (($this) + ($27<<3)|0);
   $28 = HEAP32[$26>>2]|0;
   $29 = ($28|0)==($3|0);
   if ($29) {
    $30 = ((($this) + ($27<<3)|0) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==($6|0);
    if ($32) {
     $$0 = 0;
     label = 12;
     break;
    }
   }
   $33 = ((($this) + ($27)|0) + 1024|0);
   $nextInd$0 = HEAP8[$33>>0]|0;
   $34 = $nextInd$0&255;
   $35 = ($nextInd$0<<24>>24)==(-1);
   if ($35) {
    break;
   } else {
    $27 = $34;$nextInd$03 = $nextInd$0;
   }
  }
  if ((label|0) == 12) {
   STACKTOP = sp;return ($$0|0);
  }
  $36 = $1&255;
  if ($23) {
   $37 = $36;
   label = 9;
  } else {
   $38 = $nextInd$03&255;
   $39 = ((($this) + ($38)|0) + 1024|0);
   HEAP8[$39>>0] = $36;
  }
 }
 if ((label|0) == 9) {
  HEAP8[$22>>0] = $37;
 }
 $40 = HEAP32[$0>>2]|0;
 $41 = ((($this) + ($40)|0) + 1024|0);
 HEAP8[$41>>0] = -1;
 $42 = HEAP32[$0>>2]|0;
 $43 = (($42) + 1)|0;
 HEAP32[$0>>2] = $43;
 $44 = (($this) + ($42<<3)|0);
 $45 = $data;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($45) + 4)|0;
 $49 = $48;
 $50 = HEAP32[$49>>2]|0;
 $51 = $44;
 $52 = $51;
 HEAP32[$52>>2] = $47;
 $53 = (($51) + 4)|0;
 $54 = $53;
 HEAP32[$54>>2] = $50;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29ConvexVsMeshContactGeneration20generateLastContactsEv($this) {
 $this = $this|0;
 var $$$i = 0, $$1$i = 0, $$2$i = 0, $$3$i = 0, $$4$i = 0, $$5$i = 0, $$6$i = 0, $$7$i = 0, $$8$i = 0, $$9$i = 0, $$idx = 0, $$idx$val = Math_fround(0), $$idx7 = 0, $$idx7$val = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0);
 var $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0);
 var $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0;
 var $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0);
 var $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fc$0$i = 0, $groupAxis = 0;
 var $i$068 = 0, $index$0$i = 0, $index$0$i12 = 0, $index$0$i19 = 0, $index$0$i25 = 0, $index$0$i29 = 0, $index$0$i34 = 0, $index$01$i = 0, $index$01$i16 = 0, $index$01$i23 = 0, $index$01$i27 = 0, $index$01$i32 = 0, $index$01$i9 = 0, $localPlane = 0, $triCenter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $localPlane = sp + 24|0;
 $triCenter = sp;
 $groupAxis = sp + 12|0;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2>>>0) / 17)&-1;
 $5 = (($0) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($2>>>0)>(16);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $$idx = (($this) + 2156|0);
 $$idx7 = (($this) + 2160|0);
 $$idx8 = (($this) + 2164|0);
 $8 = (($localPlane) + 4|0);
 $9 = (($localPlane) + 8|0);
 $10 = (($localPlane) + 12|0);
 $11 = (($triCenter) + 4|0);
 $12 = (($triCenter) + 8|0);
 $13 = (($groupAxis) + 4|0);
 $14 = (($groupAxis) + 8|0);
 $15 = (($this) + 2220|0);
 $i$068 = 0;
 while(1) {
  $16 = (($6) + (($i$068*68)|0)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($6) + (($i$068*68)|0)|0) + 40|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($6) + (($i$068*68)|0)|0) + 44|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($6) + (($i$068*68)|0)|0) + 48|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($6) + (($i$068*68)|0)|0) + 4|0);
  $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
  $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
  $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
  $25 = ((($6) + (($i$068*68)|0)|0) + 16|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround(HEAPF32[$24>>2]);
  $28 = Math_fround($26 - $27);
  $29 = ((($6) + (($i$068*68)|0)|0) + 20|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = ((($6) + (($i$068*68)|0)|0) + 8|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($30 - $32);
  $34 = ((($6) + (($i$068*68)|0)|0) + 24|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = ((($6) + (($i$068*68)|0)|0) + 12|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($35 - $37);
  $39 = ((($6) + (($i$068*68)|0)|0) + 28|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($40 - $27);
  $42 = ((($6) + (($i$068*68)|0)|0) + 32|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($43 - $32);
  $45 = ((($6) + (($i$068*68)|0)|0) + 36|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($46 - $37);
  $48 = Math_fround($27 - $$idx$val);
  $49 = Math_fround($32 - $$idx7$val);
  $50 = Math_fround($37 - $$idx8$val);
  $51 = Math_fround($28 * $28);
  $52 = Math_fround($33 * $33);
  $53 = Math_fround($51 + $52);
  $54 = Math_fround($38 * $38);
  $55 = Math_fround($53 + $54);
  $56 = Math_fround($28 * $41);
  $57 = Math_fround($33 * $44);
  $58 = Math_fround($56 + $57);
  $59 = Math_fround($38 * $47);
  $60 = Math_fround($58 + $59);
  $61 = Math_fround($41 * $41);
  $62 = Math_fround($44 * $44);
  $63 = Math_fround($61 + $62);
  $64 = Math_fround($47 * $47);
  $65 = Math_fround($63 + $64);
  $66 = Math_fround($48 * $28);
  $67 = Math_fround($49 * $33);
  $68 = Math_fround($66 + $67);
  $69 = Math_fround($50 * $38);
  $70 = Math_fround($68 + $69);
  $71 = Math_fround($48 * $41);
  $72 = Math_fround($49 * $44);
  $73 = Math_fround($71 + $72);
  $74 = Math_fround($50 * $47);
  $75 = Math_fround($73 + $74);
  $76 = Math_fround($55 * $65);
  $77 = Math_fround($60 * $60);
  $78 = Math_fround($76 - $77);
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($78)))));
  $79 = Math_fround($60 * $75);
  $80 = Math_fround($70 * $65);
  $81 = Math_fround($79 - $80);
  $82 = Math_fround($70 * $60);
  $83 = Math_fround($55 * $75);
  $84 = Math_fround($82 - $83);
  $85 = Math_fround($81 + $84);
  $86 = !($85 <= $fabsf$i$i$i);
  $87 = $81 < Math_fround(0.0);
  do {
   if ($86) {
    if ($87) {
     $102 = Math_fround($70 + $60);
     $103 = Math_fround($65 + $75);
     $104 = $103 > $102;
     if ($104) {
      $105 = Math_fround($103 - $102);
      $106 = Math_fround($60 * Math_fround(2.0));
      $107 = Math_fround($55 - $106);
      $108 = Math_fround($65 + $107);
      $109 = !($105 >= $108);
      $$5$i = $109 ? 4 : 1;
      $fc$0$i = $$5$i;
      label = 29;
      break;
     }
     $110 = !($103 <= Math_fround(0.0));
     if (!($110)) {
      label = 38;
      break;
     }
     $111 = !($75 >= Math_fround(0.0));
     $$6$i = $111 ? 5 : 0;
     $fc$0$i = $$6$i;
     label = 29;
     break;
    }
    $112 = $84 < Math_fround(0.0);
    if (!($112)) {
     $123 = Math_fround($65 + $75);
     $124 = Math_fround($123 - $60);
     $125 = Math_fround($124 - $70);
     $126 = !($125 <= Math_fround(0.0));
     if (!($126)) {
      label = 38;
      break;
     }
     $127 = Math_fround($60 * Math_fround(2.0));
     $128 = Math_fround($55 - $127);
     $129 = Math_fround($65 + $128);
     $130 = !($125 >= $129);
     $$9$i = $130 ? 4 : 1;
     $fc$0$i = $$9$i;
     label = 29;
     break;
    }
    $113 = Math_fround($60 + $75);
    $114 = Math_fround($55 + $70);
    $115 = $114 > $113;
    if ($115) {
     $116 = Math_fround($114 - $113);
     $117 = Math_fround($60 * Math_fround(2.0));
     $118 = Math_fround($55 - $117);
     $119 = Math_fround($65 + $118);
     $120 = !($116 >= $119);
     $$7$i = $120 ? 4 : 2;
     $fc$0$i = $$7$i;
     label = 29;
     break;
    }
    $121 = !($114 <= Math_fround(0.0));
    if ($121) {
     $122 = !($70 >= Math_fround(0.0));
     $$8$i = $122 ? 3 : 0;
     $fc$0$i = $$8$i;
     label = 29;
    } else {
     label = 34;
    }
   } else {
    $88 = $84 < Math_fround(0.0);
    if (!($87)) {
     if (!($88)) {
      $101 = $78 == Math_fround(0.0);
      $$4$i = $101 ? 0 : 6;
      $fc$0$i = $$4$i;
      label = 29;
      break;
     }
     $98 = !($70 >= Math_fround(0.0));
     if (!($98)) {
      label = 30;
      break;
     }
     $99 = Math_fround(-$70);
     $100 = !($55 <= $99);
     $$3$i = $100 ? 3 : 1;
     $fc$0$i = $$3$i;
     label = 29;
     break;
    }
    if (!($88)) {
     $95 = !($75 >= Math_fround(0.0));
     if (!($95)) {
      label = 30;
      break;
     }
     $96 = Math_fround(-$75);
     $97 = !($65 <= $96);
     $$2$i = $97 ? 5 : 2;
     $fc$0$i = $$2$i;
     label = 29;
     break;
    }
    $89 = $70 < Math_fround(0.0);
    if ($89) {
     $90 = Math_fround(-$70);
     $91 = !($55 <= $90);
     $$$i = $91 ? 3 : 1;
     $fc$0$i = $$$i;
     label = 29;
     break;
    }
    $92 = !($75 >= Math_fround(0.0));
    if ($92) {
     $93 = Math_fround(-$75);
     $94 = !($65 <= $93);
     $$1$i = $94 ? 5 : 2;
     $fc$0$i = $$1$i;
     label = 29;
    } else {
     label = 30;
    }
   }
  } while(0);
  L42: do {
   if ((label|0) == 29) {
    label = 0;
    switch ($fc$0$i|0) {
    case 3:  {
     $164 = ($19>>>0)<($21>>>0);
     $165 = $164 ? $19 : $21;
     $166 = $164 ? $21 : $19;
     $167 = $165 << 16;
     $168 = $167 | $166;
     $169 = $168 << 15;
     $170 = $169 ^ -1;
     $171 = (($168) + ($170))|0;
     $172 = $171 >>> 10;
     $173 = $172 ^ $171;
     $174 = ($173*9)|0;
     $175 = $174 >>> 6;
     $176 = $175 ^ $174;
     $177 = $176 << 11;
     $178 = $177 ^ -1;
     $179 = (($176) + ($178))|0;
     $180 = $179 >>> 16;
     $181 = $180 ^ $179;
     $182 = $181 & 127;
     $183 = ((($this) + ($182)|0) + 1156|0);
     $index$01$i16 = HEAP8[$183>>0]|0;
     $184 = ($index$01$i16<<24>>24)==(-1);
     if ($184) {
      label = 57;
      break L42;
     }
     $185 = $index$01$i16&255;
     $187 = $185;
     while(1) {
      $186 = ((($this) + ($187<<3)|0) + 4|0);
      $188 = HEAP32[$186>>2]|0;
      $189 = ($188|0)==($165|0);
      if ($189) {
       $190 = ((($this) + ($187<<3)|0) + 8|0);
       $191 = HEAP32[$190>>2]|0;
       $192 = ($191|0)==($166|0);
       if ($192) {
        break L42;
       }
      }
      $193 = ((($this) + ($187)|0) + 1028|0);
      $index$0$i19 = HEAP8[$193>>0]|0;
      $194 = $index$0$i19&255;
      $195 = ($index$0$i19<<24>>24)==(-1);
      if ($195) {
       label = 57;
       break;
      } else {
       $187 = $194;
      }
     }
     break;
    }
    case 6:  {
     label = 57;
     break L42;
     break;
    }
    case 0:  {
     label = 30;
     break L42;
     break;
    }
    case 5:  {
     $228 = ($19>>>0)<($23>>>0);
     $229 = $228 ? $19 : $23;
     $230 = $228 ? $23 : $19;
     $231 = $229 << 16;
     $232 = $231 | $230;
     $233 = $232 << 15;
     $234 = $233 ^ -1;
     $235 = (($232) + ($234))|0;
     $236 = $235 >>> 10;
     $237 = $236 ^ $235;
     $238 = ($237*9)|0;
     $239 = $238 >>> 6;
     $240 = $239 ^ $238;
     $241 = $240 << 11;
     $242 = $241 ^ -1;
     $243 = (($240) + ($242))|0;
     $244 = $243 >>> 16;
     $245 = $244 ^ $243;
     $246 = $245 & 127;
     $247 = ((($this) + ($246)|0) + 1156|0);
     $index$01$i = HEAP8[$247>>0]|0;
     $248 = ($index$01$i<<24>>24)==(-1);
     if ($248) {
      label = 57;
      break L42;
     }
     $249 = $index$01$i&255;
     $251 = $249;
     while(1) {
      $250 = ((($this) + ($251<<3)|0) + 4|0);
      $252 = HEAP32[$250>>2]|0;
      $253 = ($252|0)==($229|0);
      if ($253) {
       $254 = ((($this) + ($251<<3)|0) + 8|0);
       $255 = HEAP32[$254>>2]|0;
       $256 = ($255|0)==($230|0);
       if ($256) {
        break L42;
       }
      }
      $257 = ((($this) + ($251)|0) + 1028|0);
      $index$0$i = HEAP8[$257>>0]|0;
      $258 = $index$0$i&255;
      $259 = ($index$0$i<<24>>24)==(-1);
      if ($259) {
       label = 57;
       break;
      } else {
       $251 = $258;
      }
     }
     break;
    }
    case 4:  {
     $196 = ($21>>>0)<($23>>>0);
     $197 = $196 ? $21 : $23;
     $198 = $196 ? $23 : $21;
     $199 = $197 << 16;
     $200 = $199 | $198;
     $201 = $200 << 15;
     $202 = $201 ^ -1;
     $203 = (($200) + ($202))|0;
     $204 = $203 >>> 10;
     $205 = $204 ^ $203;
     $206 = ($205*9)|0;
     $207 = $206 >>> 6;
     $208 = $207 ^ $206;
     $209 = $208 << 11;
     $210 = $209 ^ -1;
     $211 = (($208) + ($210))|0;
     $212 = $211 >>> 16;
     $213 = $212 ^ $211;
     $214 = $213 & 127;
     $215 = ((($this) + ($214)|0) + 1156|0);
     $index$01$i9 = HEAP8[$215>>0]|0;
     $216 = ($index$01$i9<<24>>24)==(-1);
     if ($216) {
      label = 57;
      break L42;
     }
     $217 = $index$01$i9&255;
     $219 = $217;
     while(1) {
      $218 = ((($this) + ($219<<3)|0) + 4|0);
      $220 = HEAP32[$218>>2]|0;
      $221 = ($220|0)==($197|0);
      if ($221) {
       $222 = ((($this) + ($219<<3)|0) + 8|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = ($223|0)==($198|0);
       if ($224) {
        break L42;
       }
      }
      $225 = ((($this) + ($219)|0) + 1028|0);
      $index$0$i12 = HEAP8[$225>>0]|0;
      $226 = $index$0$i12&255;
      $227 = ($index$0$i12<<24>>24)==(-1);
      if ($227) {
       label = 57;
       break;
      } else {
       $219 = $226;
      }
     }
     break;
    }
    case 1:  {
     label = 34;
     break L42;
     break;
    }
    case 2:  {
     label = 38;
     break L42;
     break;
    }
    default: {
     break L42;
    }
    }
   }
  } while(0);
  L66: do {
   if ((label|0) == 30) {
    label = 0;
    $131 = $19 & 127;
    $132 = ((($this) + ($131)|0) + 1928|0);
    $index$01$i32 = HEAP8[$132>>0]|0;
    $133 = ($index$01$i32<<24>>24)==(-1);
    if ($133) {
     label = 57;
    } else {
     $134 = $index$01$i32&255;
     $136 = $134;
     while(1) {
      $135 = ((($this) + ($136<<2)|0) + 1288|0);
      $137 = HEAP32[$135>>2]|0;
      $138 = ($137|0)==($19|0);
      if ($138) {
       break L66;
      }
      $139 = ((($this) + ($136)|0) + 1800|0);
      $index$0$i34 = HEAP8[$139>>0]|0;
      $140 = $index$0$i34&255;
      $141 = ($index$0$i34<<24>>24)==(-1);
      if ($141) {
       label = 57;
       break;
      } else {
       $136 = $140;
      }
     }
    }
   }
   else if ((label|0) == 34) {
    label = 0;
    $142 = $21 & 127;
    $143 = ((($this) + ($142)|0) + 1928|0);
    $index$01$i27 = HEAP8[$143>>0]|0;
    $144 = ($index$01$i27<<24>>24)==(-1);
    if ($144) {
     label = 57;
    } else {
     $145 = $index$01$i27&255;
     $147 = $145;
     while(1) {
      $146 = ((($this) + ($147<<2)|0) + 1288|0);
      $148 = HEAP32[$146>>2]|0;
      $149 = ($148|0)==($21|0);
      if ($149) {
       break L66;
      }
      $150 = ((($this) + ($147)|0) + 1800|0);
      $index$0$i29 = HEAP8[$150>>0]|0;
      $151 = $index$0$i29&255;
      $152 = ($index$0$i29<<24>>24)==(-1);
      if ($152) {
       label = 57;
       break;
      } else {
       $147 = $151;
      }
     }
    }
   }
   else if ((label|0) == 38) {
    label = 0;
    $153 = $23 & 127;
    $154 = ((($this) + ($153)|0) + 1928|0);
    $index$01$i23 = HEAP8[$154>>0]|0;
    $155 = ($index$01$i23<<24>>24)==(-1);
    if ($155) {
     label = 57;
    } else {
     $156 = $index$01$i23&255;
     $158 = $156;
     while(1) {
      $157 = ((($this) + ($158<<2)|0) + 1288|0);
      $159 = HEAP32[$157>>2]|0;
      $160 = ($159|0)==($23|0);
      if ($160) {
       break L66;
      }
      $161 = ((($this) + ($158)|0) + 1800|0);
      $index$0$i25 = HEAP8[$161>>0]|0;
      $162 = $index$0$i25&255;
      $163 = ($index$0$i25<<24>>24)==(-1);
      if ($163) {
       label = 57;
       break;
      } else {
       $158 = $162;
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 57) {
   label = 0;
   $260 = Math_fround($33 * $47);
   $261 = Math_fround($38 * $44);
   $262 = Math_fround($260 - $261);
   $263 = Math_fround($38 * $41);
   $264 = Math_fround($28 * $47);
   $265 = Math_fround($263 - $264);
   $266 = Math_fround($28 * $44);
   $267 = Math_fround($33 * $41);
   $268 = Math_fround($266 - $267);
   $269 = Math_fround($262 * $262);
   $270 = Math_fround($265 * $265);
   $271 = Math_fround($269 + $270);
   $272 = Math_fround($268 * $268);
   $273 = Math_fround($272 + $271);
   $274 = $273 > Math_fround(0.0);
   if ($274) {
    $275 = (Math_fround(Math_sqrt((Math_fround($273)))));
    $276 = Math_fround(Math_fround(1.0) / $275);
    $277 = Math_fround($262 * $276);
    $278 = Math_fround($265 * $276);
    $279 = Math_fround($268 * $276);
    $280 = $277;$281 = $278;$282 = $279;
   } else {
    $280 = Math_fround(0.0);$281 = Math_fround(0.0);$282 = Math_fround(0.0);
   }
   HEAPF32[$localPlane>>2] = $280;
   HEAPF32[$8>>2] = $281;
   HEAPF32[$9>>2] = $282;
   $283 = Math_fround(HEAPF32[$24>>2]);
   $284 = Math_fround($280 * $283);
   $285 = Math_fround(HEAPF32[$31>>2]);
   $286 = Math_fround($281 * $285);
   $287 = Math_fround($284 + $286);
   $288 = Math_fround(HEAPF32[$36>>2]);
   $289 = Math_fround($282 * $288);
   $290 = Math_fround($287 + $289);
   $291 = Math_fround(-$290);
   HEAPF32[$10>>2] = $291;
   $292 = Math_fround(HEAPF32[$24>>2]);
   $293 = Math_fround(HEAPF32[$25>>2]);
   $294 = Math_fround($292 + $293);
   $295 = Math_fround(HEAPF32[$31>>2]);
   $296 = Math_fround(HEAPF32[$29>>2]);
   $297 = Math_fround($295 + $296);
   $298 = Math_fround(HEAPF32[$36>>2]);
   $299 = Math_fround(HEAPF32[$34>>2]);
   $300 = Math_fround($298 + $299);
   $301 = Math_fround(HEAPF32[$39>>2]);
   $302 = Math_fround($294 + $301);
   $303 = Math_fround(HEAPF32[$42>>2]);
   $304 = Math_fround($297 + $303);
   $305 = Math_fround(HEAPF32[$45>>2]);
   $306 = Math_fround($300 + $305);
   $307 = Math_fround($302 * Math_fround(0.333333343267440795898));
   $308 = Math_fround($304 * Math_fround(0.333333343267440795898));
   $309 = Math_fround($306 * Math_fround(0.333333343267440795898));
   HEAPF32[$triCenter>>2] = $307;
   HEAPF32[$11>>2] = $308;
   HEAPF32[$12>>2] = $309;
   $310 = ((($6) + (($i$068*68)|0)|0) + 52|0);
   $311 = Math_fround(HEAPF32[$310>>2]);
   HEAPF32[$groupAxis>>2] = $311;
   $312 = ((($6) + (($i$068*68)|0)|0) + 56|0);
   $313 = Math_fround(HEAPF32[$312>>2]);
   HEAPF32[$13>>2] = $313;
   $314 = ((($6) + (($i$068*68)|0)|0) + 60|0);
   $315 = Math_fround(HEAPF32[$314>>2]);
   HEAPF32[$14>>2] = $315;
   $316 = ((($6) + (($i$068*68)|0)|0) + 64|0);
   $317 = Math_fround(HEAPF32[$316>>2]);
   $318 = (__ZNK5physx2Gu29ConvexVsMeshContactGeneration16generateContactsERKNS_7PxPlaneEPKNS_6PxVec3ERS6_RS5_fj($this,$localPlane,$24,$triCenter,$groupAxis,$317,$17)|0);
   if ($318) {
    HEAP8[$15>>0] = 1;
   }
  }
  $319 = (($i$068) + 1)|0;
  $320 = ($319>>>0)<($4>>>0);
  if ($320) {
   $i$068 = $319;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu17contactConvexMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $convexScaling = 0, $hullAABB = 0, $meshScaling = 0, $polyData0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $meshScaling = sp + 168|0;
 $convexScaling = sp;
 $hullAABB = sp + 72|0;
 $polyData0 = sp + 96|0;
 $0 = (($shape1) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == Math_fround(1.0);
 if ($2) {
  $3 = (($shape1) + 8|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(1.0);
  if ($5) {
   $6 = (($shape1) + 12|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 == Math_fround(1.0);
   $46 = $8;
  } else {
   $46 = 0;
  }
 } else {
  $46 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $9 = (($meshScaling) + 4|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($meshScaling) + 8|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($meshScaling) + 12|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($meshScaling) + 16|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($meshScaling) + 20|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($meshScaling) + 24|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($meshScaling) + 28|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($meshScaling) + 32|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($meshScaling) + 36|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($meshScaling) + 40|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($meshScaling) + 44|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($meshScaling) + 48|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($meshScaling) + 52|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($meshScaling) + 56|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($meshScaling) + 60|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($meshScaling) + 64|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($meshScaling) + 68|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 if (!($46)) {
  $26 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$0,$26);
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $27 = (($convexScaling) + 4|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($convexScaling) + 8|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($convexScaling) + 12|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($convexScaling) + 16|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($convexScaling) + 20|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($convexScaling) + 24|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($convexScaling) + 28|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($convexScaling) + 32|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (($convexScaling) + 36|0);
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($convexScaling) + 40|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($convexScaling) + 44|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($convexScaling) + 48|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($convexScaling) + 52|0);
 HEAPF32[$39>>2] = Math_fround(1.0);
 $40 = (($convexScaling) + 56|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($convexScaling) + 60|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($convexScaling) + 64|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($convexScaling) + 68|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 $44 = (__ZN5physx2Gu13getConvexDataERKNS0_13GeometryUnionERNS_2Cm23FastVertex2ShapeScalingERNS_9PxBounds3ERNS0_13PolygonalDataE($shape0,$convexScaling,$hullAABB,$polyData0)|0);
 $45 = Math_fround(HEAPF32[$contactDistance>>2]);
 $47 = (__ZL16contactHullMesh2RKN5physx2Gu13PolygonalDataERKNS_9PxBounds3ERKNS_24PxTriangleMeshGeometryLLERKNS_11PxTransformESC_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESI_bb($polyData0,$hullAABB,$shape1,$transform0,$transform1,$45,$contactBuffer,$convexScaling,$meshScaling,$44,$46)|0);
 STACKTOP = sp;return ($47|0);
}
function __ZL16contactHullMesh2RKN5physx2Gu13PolygonalDataERKNS_9PxBounds3ERKNS_24PxTriangleMeshGeometryLLERKNS_11PxTransformESC_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESI_bb($polyData0,$hullAABB,$shape1,$transform0,$transform1,$contactDistance,$contactBuffer,$convexScaling,$meshScaling,$idtConvexScale,$idtMeshScale) {
 $polyData0 = $polyData0|0;
 $hullAABB = $hullAABB|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = Math_fround($contactDistance);
 $contactBuffer = $contactBuffer|0;
 $convexScaling = $convexScaling|0;
 $meshScaling = $meshScaling|0;
 $idtConvexScale = $idtConvexScale|0;
 $idtMeshScale = $idtMeshScale|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0;
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $blockCallback = 0, $count$01$i$i = 0, $delayedContacts = 0, $edgeFlags$05$i$i = 0, $hmd = 0, $hullOBB = 0, $t0to1 = 0;
 var $t1to0 = 0, $triInds$04$i$i = 0, $vertInds$03$i$i = 0, $verts$02$i$i = 0, $world0 = 0, $world1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 7808|0;
 $world0 = sp + 7760|0;
 $world1 = sp + 7712|0;
 $t0to1 = sp + 7680|0;
 $t1to0 = sp + 7652|0;
 $hullOBB = sp + 7592|0;
 $hmd = sp + 3224|0;
 $delayedContacts = sp + 3208|0;
 $blockCallback = sp;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = Math_fround($0 + $0);
 $2 = (($transform0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 + $3);
 $5 = (($transform0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 + $6);
 $8 = (($transform0) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($1 * $9);
 $11 = Math_fround($4 * $9);
 $12 = Math_fround($9 * $7);
 $13 = Math_fround($0 * $1);
 $14 = Math_fround($0 * $4);
 $15 = Math_fround($0 * $7);
 $16 = Math_fround($3 * $4);
 $17 = Math_fround($3 * $7);
 $18 = Math_fround($6 * $7);
 $19 = Math_fround(Math_fround(1.0) - $16);
 $20 = Math_fround($19 - $18);
 HEAPF32[$world0>>2] = $20;
 $21 = Math_fround($14 + $12);
 $22 = (($world0) + 4|0);
 HEAPF32[$22>>2] = $21;
 $23 = Math_fround($15 - $11);
 $24 = (($world0) + 8|0);
 HEAPF32[$24>>2] = $23;
 $25 = Math_fround($14 - $12);
 $26 = (($world0) + 12|0);
 HEAPF32[$26>>2] = $25;
 $27 = Math_fround(Math_fround(1.0) - $13);
 $28 = Math_fround($27 - $18);
 $29 = (($world0) + 16|0);
 HEAPF32[$29>>2] = $28;
 $30 = Math_fround($17 + $10);
 $31 = (($world0) + 20|0);
 HEAPF32[$31>>2] = $30;
 $32 = Math_fround($15 + $11);
 $33 = (($world0) + 24|0);
 HEAPF32[$33>>2] = $32;
 $34 = Math_fround($17 - $10);
 $35 = (($world0) + 28|0);
 HEAPF32[$35>>2] = $34;
 $36 = Math_fround($27 - $16);
 $37 = (($world0) + 32|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($world0) + 36|0);
 $39 = (($world0) + 40|0);
 $40 = (($world0) + 44|0);
 $41 = (($transform0) + 16|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$38>>2] = $42;
 $43 = (($transform0) + 20|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 HEAPF32[$39>>2] = $44;
 $45 = (($transform0) + 24|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 HEAPF32[$40>>2] = $46;
 $47 = Math_fround(HEAPF32[$transform1>>2]);
 $48 = Math_fround($47 + $47);
 $49 = (($transform1) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($50 + $50);
 $52 = (($transform1) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 + $53);
 $55 = (($transform1) + 12|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($48 * $56);
 $58 = Math_fround($51 * $56);
 $59 = Math_fround($56 * $54);
 $60 = Math_fround($47 * $48);
 $61 = Math_fround($47 * $51);
 $62 = Math_fround($47 * $54);
 $63 = Math_fround($50 * $51);
 $64 = Math_fround($50 * $54);
 $65 = Math_fround($53 * $54);
 $66 = Math_fround(Math_fround(1.0) - $63);
 $67 = Math_fround($66 - $65);
 HEAPF32[$world1>>2] = $67;
 $68 = Math_fround($61 + $59);
 $69 = (($world1) + 4|0);
 HEAPF32[$69>>2] = $68;
 $70 = Math_fround($62 - $58);
 $71 = (($world1) + 8|0);
 HEAPF32[$71>>2] = $70;
 $72 = Math_fround($61 - $59);
 $73 = (($world1) + 12|0);
 HEAPF32[$73>>2] = $72;
 $74 = Math_fround(Math_fround(1.0) - $60);
 $75 = Math_fround($74 - $65);
 $76 = (($world1) + 16|0);
 HEAPF32[$76>>2] = $75;
 $77 = Math_fround($64 + $57);
 $78 = (($world1) + 20|0);
 HEAPF32[$78>>2] = $77;
 $79 = Math_fround($62 + $58);
 $80 = (($world1) + 24|0);
 HEAPF32[$80>>2] = $79;
 $81 = Math_fround($64 - $57);
 $82 = (($world1) + 28|0);
 HEAPF32[$82>>2] = $81;
 $83 = Math_fround($74 - $63);
 $84 = (($world1) + 32|0);
 HEAPF32[$84>>2] = $83;
 $85 = (($world1) + 36|0);
 $86 = (($world1) + 40|0);
 $87 = (($world1) + 44|0);
 $88 = (($transform1) + 16|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 HEAPF32[$85>>2] = $89;
 $90 = (($transform1) + 20|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 HEAPF32[$86>>2] = $91;
 $92 = (($transform1) + 24|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 HEAPF32[$87>>2] = $93;
 $94 = Math_fround(-$47);
 $95 = Math_fround(-$50);
 $96 = Math_fround(-$53);
 $97 = Math_fround($42 - $89);
 $98 = Math_fround($44 - $91);
 $99 = Math_fround($46 - $93);
 $100 = Math_fround($97 * Math_fround(2.0));
 $101 = Math_fround($98 * Math_fround(2.0));
 $102 = Math_fround($99 * Math_fround(2.0));
 $103 = Math_fround($56 * $56);
 $104 = Math_fround($103 + Math_fround(-0.5));
 $105 = Math_fround($100 * $94);
 $106 = Math_fround($101 * $95);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($102 * $96);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($104 * $100);
 $111 = Math_fround($102 * $95);
 $112 = Math_fround($101 * $96);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($56 * $113);
 $115 = Math_fround($110 + $114);
 $116 = Math_fround($109 * $94);
 $117 = Math_fround($116 + $115);
 $118 = Math_fround($104 * $101);
 $119 = Math_fround($100 * $96);
 $120 = Math_fround($102 * $94);
 $121 = Math_fround($119 - $120);
 $122 = Math_fround($56 * $121);
 $123 = Math_fround($118 + $122);
 $124 = Math_fround($109 * $95);
 $125 = Math_fround($124 + $123);
 $126 = Math_fround($104 * $102);
 $127 = Math_fround($101 * $94);
 $128 = Math_fround($100 * $95);
 $129 = Math_fround($127 - $128);
 $130 = Math_fround($56 * $129);
 $131 = Math_fround($126 + $130);
 $132 = Math_fround($109 * $96);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround(HEAPF32[$transform0>>2]);
 $135 = Math_fround($56 * $134);
 $136 = Math_fround(HEAPF32[$8>>2]);
 $137 = Math_fround($136 * $94);
 $138 = Math_fround($135 + $137);
 $139 = Math_fround(HEAPF32[$5>>2]);
 $140 = Math_fround($139 * $95);
 $141 = Math_fround($138 + $140);
 $142 = Math_fround(HEAPF32[$2>>2]);
 $143 = Math_fround($142 * $96);
 $144 = Math_fround($141 - $143);
 $145 = Math_fround($56 * $142);
 $146 = Math_fround($136 * $95);
 $147 = Math_fround($146 + $145);
 $148 = Math_fround($134 * $96);
 $149 = Math_fround($148 + $147);
 $150 = Math_fround($139 * $94);
 $151 = Math_fround($149 - $150);
 $152 = Math_fround($56 * $139);
 $153 = Math_fround($136 * $96);
 $154 = Math_fround($153 + $152);
 $155 = Math_fround($142 * $94);
 $156 = Math_fround($155 + $154);
 $157 = Math_fround($134 * $95);
 $158 = Math_fround($156 - $157);
 $159 = Math_fround($56 * $136);
 $160 = Math_fround($134 * $94);
 $161 = Math_fround($159 - $160);
 $162 = Math_fround($142 * $95);
 $163 = Math_fround($161 - $162);
 $164 = Math_fround($139 * $96);
 $165 = Math_fround($163 - $164);
 HEAPF32[$t0to1>>2] = $144;
 $166 = (($t0to1) + 4|0);
 HEAPF32[$166>>2] = $151;
 $167 = (($t0to1) + 8|0);
 HEAPF32[$167>>2] = $158;
 $168 = (($t0to1) + 12|0);
 HEAPF32[$168>>2] = $165;
 $169 = (($t0to1) + 16|0);
 HEAPF32[$169>>2] = $117;
 $170 = (($t0to1) + 20|0);
 HEAPF32[$170>>2] = $125;
 $171 = (($t0to1) + 24|0);
 HEAPF32[$171>>2] = $133;
 $172 = Math_fround(-$134);
 $173 = Math_fround(-$142);
 $174 = Math_fround(-$139);
 $175 = Math_fround(HEAPF32[$41>>2]);
 $176 = Math_fround($89 - $175);
 $177 = Math_fround(HEAPF32[$43>>2]);
 $178 = Math_fround($91 - $177);
 $179 = Math_fround(HEAPF32[$45>>2]);
 $180 = Math_fround($93 - $179);
 $181 = Math_fround($176 * Math_fround(2.0));
 $182 = Math_fround($178 * Math_fround(2.0));
 $183 = Math_fround($180 * Math_fround(2.0));
 $184 = Math_fround($136 * $136);
 $185 = Math_fround($184 + Math_fround(-0.5));
 $186 = Math_fround($181 * $172);
 $187 = Math_fround($182 * $173);
 $188 = Math_fround($186 + $187);
 $189 = Math_fround($183 * $174);
 $190 = Math_fround($188 + $189);
 $191 = Math_fround($185 * $181);
 $192 = Math_fround($183 * $173);
 $193 = Math_fround($182 * $174);
 $194 = Math_fround($192 - $193);
 $195 = Math_fround($136 * $194);
 $196 = Math_fround($191 + $195);
 $197 = Math_fround($190 * $172);
 $198 = Math_fround($197 + $196);
 $199 = Math_fround($185 * $182);
 $200 = Math_fround($181 * $174);
 $201 = Math_fround($183 * $172);
 $202 = Math_fround($200 - $201);
 $203 = Math_fround($136 * $202);
 $204 = Math_fround($199 + $203);
 $205 = Math_fround($190 * $173);
 $206 = Math_fround($205 + $204);
 $207 = Math_fround($185 * $183);
 $208 = Math_fround($182 * $172);
 $209 = Math_fround($181 * $173);
 $210 = Math_fround($208 - $209);
 $211 = Math_fround($136 * $210);
 $212 = Math_fround($207 + $211);
 $213 = Math_fround($190 * $174);
 $214 = Math_fround($212 + $213);
 $215 = Math_fround(HEAPF32[$transform1>>2]);
 $216 = Math_fround($136 * $215);
 $217 = Math_fround(HEAPF32[$55>>2]);
 $218 = Math_fround($217 * $172);
 $219 = Math_fround($216 + $218);
 $220 = Math_fround(HEAPF32[$52>>2]);
 $221 = Math_fround($220 * $173);
 $222 = Math_fround($219 + $221);
 $223 = Math_fround(HEAPF32[$49>>2]);
 $224 = Math_fround($223 * $174);
 $225 = Math_fround($222 - $224);
 $226 = Math_fround($136 * $223);
 $227 = Math_fround($217 * $173);
 $228 = Math_fround($227 + $226);
 $229 = Math_fround($215 * $174);
 $230 = Math_fround($229 + $228);
 $231 = Math_fround($220 * $172);
 $232 = Math_fround($230 - $231);
 $233 = Math_fround($136 * $220);
 $234 = Math_fround($217 * $174);
 $235 = Math_fround($234 + $233);
 $236 = Math_fround($223 * $172);
 $237 = Math_fround($236 + $235);
 $238 = Math_fround($215 * $173);
 $239 = Math_fround($237 - $238);
 $240 = Math_fround($136 * $217);
 $241 = Math_fround($215 * $172);
 $242 = Math_fround($240 - $241);
 $243 = Math_fround($223 * $173);
 $244 = Math_fround($242 - $243);
 $245 = Math_fround($220 * $174);
 $246 = Math_fround($244 - $245);
 HEAPF32[$t1to0>>2] = $225;
 $247 = (($t1to0) + 4|0);
 HEAPF32[$247>>2] = $232;
 $248 = (($t1to0) + 8|0);
 HEAPF32[$248>>2] = $239;
 $249 = (($t1to0) + 12|0);
 HEAPF32[$249>>2] = $246;
 $250 = (($t1to0) + 16|0);
 HEAPF32[$250>>2] = $198;
 $251 = (($t1to0) + 20|0);
 HEAPF32[$251>>2] = $206;
 $252 = (($t1to0) + 24|0);
 HEAPF32[$252>>2] = $214;
 __ZN5physx2Gu14computeHullOBBERNS0_3BoxERKNS_9PxBounds3EfRKNS_11PxTransformERKNS_2Cm8Matrix34ESC_RKNS9_23FastVertex2ShapeScalingEb($hullOBB,$hullAABB,$contactDistance,$transform0,$world0,$world1,$meshScaling,$idtMeshScale);
 $253 = (($shape1) + 40|0);
 $254 = HEAP32[$253>>2]|0;
 $255 = (($254) + 16|0);
 $256 = HEAP32[$255>>2]|0;
 HEAP32[$hmd>>2] = $256;
 $257 = (($254) + 32|0);
 $258 = (($hmd) + 4|0);
 HEAP32[$258>>2] = $257;
 $259 = (($254) + 20|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = (($hmd) + 8|0);
 HEAPF32[$261>>2] = $260;
 __ZN5physx2Gu9ContainerC2Ev($delayedContacts);
 $262 = sp + 3240|0;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($delayedContacts,1088,$262,1);
 $263 = (($254) + 152|0);
 $264 = HEAP32[$263>>2]|0;
 $265 = (($contactBuffer) + 4100|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = (($blockCallback) + 4|0);
 HEAP32[$267>>2] = 2;
 HEAP32[$blockCallback>>2] = ((548864 + 8|0));
 $268 = (($blockCallback) + 856|0);
 HEAP32[$268>>2] = 0;
 $269 = (($blockCallback) + 860|0);
 __ZN5physx2Gu29ConvexVsMeshContactGenerationC2ERNS0_9ContainerERKNS_11PxTransformES6_RKNS0_13PolygonalDataERKNS_2Cm8Matrix34ESD_RKNSA_23FastVertex2ShapeScalingEfbfS6_S6_RNS0_13ContactBufferE($269,$delayedContacts,$t0to1,$t1to0,$polyData0,$world0,$world1,$convexScaling,$contactDistance,$idtConvexScale,$266,$transform0,$transform1,$contactBuffer);
 $270 = (($blockCallback) + 3084|0);
 HEAP32[$270>>2] = $meshScaling;
 $271 = (($blockCallback) + 3088|0);
 HEAP32[$271>>2] = $264;
 $272 = (($blockCallback) + 3092|0);
 $273 = $idtMeshScale&1;
 HEAP8[$272>>0] = $273;
 $274 = (($blockCallback) + 3096|0);
 HEAP32[$274>>2] = $254;
 $275 = (($blockCallback) + 3100|0);
 __ZN5physx2Gu15OBBTriangleTestC2ERKNS0_3BoxE($275,$hullOBB);
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($hullOBB,0,$hmd,$blockCallback,1);
 $276 = HEAP32[$268>>2]|0;
 $277 = ($276|0)==(0);
 if ($277) {
  __ZN5physx2Gu29ConvexVsMeshContactGeneration20generateLastContactsEv($269);
  $290 = (($blockCallback) + 3080|0);
  $291 = HEAP8[$290>>0]|0;
  $292 = ($291<<24>>24)!=(0);
  __ZN5physx2Gu9ContainerD2Ev($delayedContacts);
  STACKTOP = sp;return ($292|0);
 }
 $278 = (($blockCallback) + 840|0);
 $279 = (($blockCallback) + 776|0);
 $280 = (($blockCallback) + 584|0);
 $281 = (($blockCallback) + 8|0);
 $count$01$i$i = $276;$edgeFlags$05$i$i = $278;$triInds$04$i$i = $279;$vertInds$03$i$i = $280;$verts$02$i$i = $281;
 while(1) {
  $282 = (($count$01$i$i) + -1)|0;
  $283 = HEAP32[$triInds$04$i$i>>2]|0;
  $284 = HEAP8[$edgeFlags$05$i$i>>0]|0;
  (__ZN5physx2Gu29ConvexVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($269,$verts$02$i$i,$283,$284,$vertInds$03$i$i)|0);
  $285 = (($verts$02$i$i) + 36|0);
  $286 = (($vertInds$03$i$i) + 12|0);
  $287 = (($triInds$04$i$i) + 4|0);
  $288 = (($edgeFlags$05$i$i) + 1|0);
  $289 = ($282|0)==(0);
  if ($289) {
   break;
  } else {
   $count$01$i$i = $282;$edgeFlags$05$i$i = $288;$triInds$04$i$i = $287;$vertInds$03$i$i = $286;$verts$02$i$i = $285;
  }
 }
 HEAP32[$268>>2] = 0;
 __ZN5physx2Gu29ConvexVsMeshContactGeneration20generateLastContactsEv($269);
 $290 = (($blockCallback) + 3080|0);
 $291 = HEAP8[$290>>0]|0;
 $292 = ($291<<24>>24)!=(0);
 __ZN5physx2Gu9ContainerD2Ev($delayedContacts);
 STACKTOP = sp;return ($292|0);
}
function __ZN5physx2Gu14contactBoxMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $7 = Math_fround(0), $8 = Math_fround(0);
 var $9 = 0, $hullAABB = 0, $idtScaling = 0, $meshScaling = 0, $polyBox = 0, $polyData0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0;
 $polyData0 = sp + 392|0;
 $polyBox = sp;
 $hullAABB = sp + 224|0;
 $meshScaling = sp + 248|0;
 $idtScaling = sp + 320|0;
 $0 = (($shape0) + 4|0);
 __ZN5physx2Gu12PolygonalBoxC2ERKNS_6PxVec3E($polyBox,$0);
 __ZNK5physx2Gu12PolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($polyBox,$polyData0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(-$1);
 $3 = (($shape0) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$4);
 $6 = (($shape0) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(-$7);
 HEAPF32[$hullAABB>>2] = $2;
 $9 = (($hullAABB) + 4|0);
 HEAPF32[$9>>2] = $5;
 $10 = (($hullAABB) + 8|0);
 HEAPF32[$10>>2] = $8;
 $11 = (($hullAABB) + 12|0);
 HEAPF32[$11>>2] = $1;
 $12 = (($hullAABB) + 16|0);
 HEAPF32[$12>>2] = $4;
 $13 = (($hullAABB) + 20|0);
 HEAPF32[$13>>2] = $7;
 $14 = (($shape1) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = $15 == Math_fround(1.0);
 if ($16) {
  $17 = (($shape1) + 8|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = $18 == Math_fround(1.0);
  if ($19) {
   $20 = (($shape1) + 12|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = $21 == Math_fround(1.0);
   $59 = $22;
  } else {
   $59 = 0;
  }
 } else {
  $59 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $23 = (($meshScaling) + 4|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($meshScaling) + 8|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($meshScaling) + 12|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($meshScaling) + 16|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($meshScaling) + 20|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($meshScaling) + 24|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($meshScaling) + 28|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($meshScaling) + 32|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($meshScaling) + 36|0);
 HEAPF32[$31>>2] = Math_fround(1.0);
 $32 = (($meshScaling) + 40|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($meshScaling) + 44|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($meshScaling) + 48|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($meshScaling) + 52|0);
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($meshScaling) + 56|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($meshScaling) + 60|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($meshScaling) + 64|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($meshScaling) + 68|0);
 HEAPF32[$39>>2] = Math_fround(1.0);
 if (!($59)) {
  $40 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$14,$40);
 }
 HEAPF32[$idtScaling>>2] = Math_fround(1.0);
 $41 = (($idtScaling) + 4|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($idtScaling) + 8|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($idtScaling) + 12|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($idtScaling) + 16|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 $45 = (($idtScaling) + 20|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($idtScaling) + 24|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($idtScaling) + 28|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($idtScaling) + 32|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($idtScaling) + 36|0);
 HEAPF32[$49>>2] = Math_fround(1.0);
 $50 = (($idtScaling) + 40|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($idtScaling) + 44|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($idtScaling) + 48|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($idtScaling) + 52|0);
 HEAPF32[$53>>2] = Math_fround(1.0);
 $54 = (($idtScaling) + 56|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($idtScaling) + 60|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($idtScaling) + 64|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($idtScaling) + 68|0);
 HEAPF32[$57>>2] = Math_fround(1.0);
 $58 = Math_fround(HEAPF32[$contactDistance>>2]);
 $60 = (__ZL16contactHullMesh2RKN5physx2Gu13PolygonalDataERKNS_9PxBounds3ERKNS_24PxTriangleMeshGeometryLLERKNS_11PxTransformESC_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESI_bb($polyData0,$hullAABB,$shape1,$transform0,$transform1,$58,$contactBuffer,$idtScaling,$meshScaling,1,$59)|0);
 STACKTOP = sp;return ($60|0);
}
function __ZN5physx2Gu24contactConvexHeightfieldERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $convexScaling = 0, $hullAABB = 0, $polyData0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $convexScaling = sp + 96|0;
 $hullAABB = sp;
 $polyData0 = sp + 24|0;
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $0 = (($convexScaling) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($convexScaling) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($convexScaling) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($convexScaling) + 16|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($convexScaling) + 20|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($convexScaling) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($convexScaling) + 28|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($convexScaling) + 32|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($convexScaling) + 36|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($convexScaling) + 40|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($convexScaling) + 44|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($convexScaling) + 48|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($convexScaling) + 52|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($convexScaling) + 56|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($convexScaling) + 60|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($convexScaling) + 64|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($convexScaling) + 68|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (__ZN5physx2Gu13getConvexDataERKNS0_13GeometryUnionERNS_2Cm23FastVertex2ShapeScalingERNS_9PxBounds3ERNS0_13PolygonalDataE($shape0,$convexScaling,$hullAABB,$polyData0)|0);
 $18 = Math_fround(HEAPF32[$contactDistance>>2]);
 $19 = Math_fround(HEAPF32[$hullAABB>>2]);
 $20 = Math_fround($19 - $18);
 HEAPF32[$hullAABB>>2] = $20;
 $21 = (($hullAABB) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 - $18);
 HEAPF32[$21>>2] = $23;
 $24 = (($hullAABB) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 - $18);
 HEAPF32[$24>>2] = $26;
 $27 = (($hullAABB) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($18 + $28);
 HEAPF32[$27>>2] = $29;
 $30 = (($hullAABB) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($18 + $31);
 HEAPF32[$30>>2] = $32;
 $33 = (($hullAABB) + 20|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($18 + $34);
 HEAPF32[$33>>2] = $35;
 $36 = (__ZL23contactHullHeightfield2RKN5physx2Gu13PolygonalDataERKNS_9PxBounds3ERKNS_21PxHeightFieldGeometryERKNS_11PxTransformESC_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingEb($polyData0,$hullAABB,$shape1,$transform0,$transform1,$18,$contactBuffer,$convexScaling,$17)|0);
 STACKTOP = sp;return ($36|0);
}
function __ZL23contactHullHeightfield2RKN5physx2Gu13PolygonalDataERKNS_9PxBounds3ERKNS_21PxHeightFieldGeometryERKNS_11PxTransformESC_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingEb($polyData0,$hullAABB,$shape1,$transform0,$transform1,$contactDistance,$contactBuffer,$convexScaling,$idtConvexScale) {
 $polyData0 = $polyData0|0;
 $hullAABB = $hullAABB|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = Math_fround($contactDistance);
 $contactBuffer = $contactBuffer|0;
 $convexScaling = $convexScaling|0;
 $idtConvexScale = $idtConvexScale|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $28 = Math_fround(0), $29 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0;
 var $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0;
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $blockCallback = 0, $delayedContacts = 0, $hfUtil = 0;
 var $t0to1 = 0, $t1to0 = 0, $world0 = 0, $world1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6800|0;
 $hfUtil = sp + 6776|0;
 $world0 = sp + 6728|0;
 $world1 = sp + 6680|0;
 $t0to1 = sp + 6652|0;
 $t1to0 = sp + 6624|0;
 $delayedContacts = sp + 2256|0;
 $blockCallback = sp + 24|0;
 $0 = sp;
 $1 = (($shape1) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($hfUtil) + 12|0);
 HEAP32[$3>>2] = $2;
 $4 = (($hfUtil) + 16|0);
 HEAP32[$4>>2] = $shape1;
 $5 = (($shape1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(Math_fround(1.0) / $6);
 $8 = (($hfUtil) + 4|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($shape1) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(Math_fround(1.0) / $10);
 HEAPF32[$hfUtil>>2] = $11;
 $12 = (($shape1) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(Math_fround(1.0) / $13);
 $15 = (($hfUtil) + 8|0);
 HEAPF32[$15>>2] = $14;
 $16 = Math_fround(HEAPF32[$transform0>>2]);
 $17 = Math_fround($16 + $16);
 $18 = (($transform0) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 + $19);
 $21 = (($transform0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 + $22);
 $24 = (($transform0) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($17 * $25);
 $27 = Math_fround($20 * $25);
 $28 = Math_fround($25 * $23);
 $29 = Math_fround($16 * $17);
 $30 = Math_fround($16 * $20);
 $31 = Math_fround($16 * $23);
 $32 = Math_fround($19 * $20);
 $33 = Math_fround($19 * $23);
 $34 = Math_fround($22 * $23);
 $35 = Math_fround(Math_fround(1.0) - $32);
 $36 = Math_fround($35 - $34);
 HEAPF32[$world0>>2] = $36;
 $37 = Math_fround($30 + $28);
 $38 = (($world0) + 4|0);
 HEAPF32[$38>>2] = $37;
 $39 = Math_fround($31 - $27);
 $40 = (($world0) + 8|0);
 HEAPF32[$40>>2] = $39;
 $41 = Math_fround($30 - $28);
 $42 = (($world0) + 12|0);
 HEAPF32[$42>>2] = $41;
 $43 = Math_fround(Math_fround(1.0) - $29);
 $44 = Math_fround($43 - $34);
 $45 = (($world0) + 16|0);
 HEAPF32[$45>>2] = $44;
 $46 = Math_fround($33 + $26);
 $47 = (($world0) + 20|0);
 HEAPF32[$47>>2] = $46;
 $48 = Math_fround($31 + $27);
 $49 = (($world0) + 24|0);
 HEAPF32[$49>>2] = $48;
 $50 = Math_fround($33 - $26);
 $51 = (($world0) + 28|0);
 HEAPF32[$51>>2] = $50;
 $52 = Math_fround($43 - $32);
 $53 = (($world0) + 32|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($world0) + 36|0);
 $55 = (($world0) + 40|0);
 $56 = (($world0) + 44|0);
 $57 = (($transform0) + 16|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 HEAPF32[$54>>2] = $58;
 $59 = (($transform0) + 20|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 HEAPF32[$55>>2] = $60;
 $61 = (($transform0) + 24|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 HEAPF32[$56>>2] = $62;
 $63 = Math_fround(HEAPF32[$transform1>>2]);
 $64 = Math_fround($63 + $63);
 $65 = (($transform1) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 + $66);
 $68 = (($transform1) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $69);
 $71 = (($transform1) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($64 * $72);
 $74 = Math_fround($67 * $72);
 $75 = Math_fround($72 * $70);
 $76 = Math_fround($63 * $64);
 $77 = Math_fround($63 * $67);
 $78 = Math_fround($63 * $70);
 $79 = Math_fround($66 * $67);
 $80 = Math_fround($66 * $70);
 $81 = Math_fround($69 * $70);
 $82 = Math_fround(Math_fround(1.0) - $79);
 $83 = Math_fround($82 - $81);
 HEAPF32[$world1>>2] = $83;
 $84 = Math_fround($77 + $75);
 $85 = (($world1) + 4|0);
 HEAPF32[$85>>2] = $84;
 $86 = Math_fround($78 - $74);
 $87 = (($world1) + 8|0);
 HEAPF32[$87>>2] = $86;
 $88 = Math_fround($77 - $75);
 $89 = (($world1) + 12|0);
 HEAPF32[$89>>2] = $88;
 $90 = Math_fround(Math_fround(1.0) - $76);
 $91 = Math_fround($90 - $81);
 $92 = (($world1) + 16|0);
 HEAPF32[$92>>2] = $91;
 $93 = Math_fround($80 + $73);
 $94 = (($world1) + 20|0);
 HEAPF32[$94>>2] = $93;
 $95 = Math_fround($78 + $74);
 $96 = (($world1) + 24|0);
 HEAPF32[$96>>2] = $95;
 $97 = Math_fround($80 - $73);
 $98 = (($world1) + 28|0);
 HEAPF32[$98>>2] = $97;
 $99 = Math_fround($90 - $79);
 $100 = (($world1) + 32|0);
 HEAPF32[$100>>2] = $99;
 $101 = (($world1) + 36|0);
 $102 = (($world1) + 40|0);
 $103 = (($world1) + 44|0);
 $104 = (($transform1) + 16|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 HEAPF32[$101>>2] = $105;
 $106 = (($transform1) + 20|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 HEAPF32[$102>>2] = $107;
 $108 = (($transform1) + 24|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 HEAPF32[$103>>2] = $109;
 $110 = Math_fround(-$63);
 $111 = Math_fround(-$66);
 $112 = Math_fround(-$69);
 $113 = Math_fround($58 - $105);
 $114 = Math_fround($60 - $107);
 $115 = Math_fround($62 - $109);
 $116 = Math_fround($113 * Math_fround(2.0));
 $117 = Math_fround($114 * Math_fround(2.0));
 $118 = Math_fround($115 * Math_fround(2.0));
 $119 = Math_fround($72 * $72);
 $120 = Math_fround($119 + Math_fround(-0.5));
 $121 = Math_fround($116 * $110);
 $122 = Math_fround($117 * $111);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($118 * $112);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($120 * $116);
 $127 = Math_fround($118 * $111);
 $128 = Math_fround($117 * $112);
 $129 = Math_fround($127 - $128);
 $130 = Math_fround($72 * $129);
 $131 = Math_fround($126 + $130);
 $132 = Math_fround($125 * $110);
 $133 = Math_fround($132 + $131);
 $134 = Math_fround($120 * $117);
 $135 = Math_fround($116 * $112);
 $136 = Math_fround($118 * $110);
 $137 = Math_fround($135 - $136);
 $138 = Math_fround($72 * $137);
 $139 = Math_fround($134 + $138);
 $140 = Math_fround($125 * $111);
 $141 = Math_fround($140 + $139);
 $142 = Math_fround($120 * $118);
 $143 = Math_fround($117 * $110);
 $144 = Math_fround($116 * $111);
 $145 = Math_fround($143 - $144);
 $146 = Math_fround($72 * $145);
 $147 = Math_fround($142 + $146);
 $148 = Math_fround($125 * $112);
 $149 = Math_fround($147 + $148);
 $150 = Math_fround(HEAPF32[$transform0>>2]);
 $151 = Math_fround($72 * $150);
 $152 = Math_fround(HEAPF32[$24>>2]);
 $153 = Math_fround($152 * $110);
 $154 = Math_fround($151 + $153);
 $155 = Math_fround(HEAPF32[$21>>2]);
 $156 = Math_fround($155 * $111);
 $157 = Math_fround($154 + $156);
 $158 = Math_fround(HEAPF32[$18>>2]);
 $159 = Math_fround($158 * $112);
 $160 = Math_fround($157 - $159);
 $161 = Math_fround($72 * $158);
 $162 = Math_fround($152 * $111);
 $163 = Math_fround($162 + $161);
 $164 = Math_fround($150 * $112);
 $165 = Math_fround($164 + $163);
 $166 = Math_fround($155 * $110);
 $167 = Math_fround($165 - $166);
 $168 = Math_fround($72 * $155);
 $169 = Math_fround($152 * $112);
 $170 = Math_fround($169 + $168);
 $171 = Math_fround($158 * $110);
 $172 = Math_fround($171 + $170);
 $173 = Math_fround($150 * $111);
 $174 = Math_fround($172 - $173);
 $175 = Math_fround($72 * $152);
 $176 = Math_fround($150 * $110);
 $177 = Math_fround($175 - $176);
 $178 = Math_fround($158 * $111);
 $179 = Math_fround($177 - $178);
 $180 = Math_fround($155 * $112);
 $181 = Math_fround($179 - $180);
 HEAPF32[$t0to1>>2] = $160;
 $182 = (($t0to1) + 4|0);
 HEAPF32[$182>>2] = $167;
 $183 = (($t0to1) + 8|0);
 HEAPF32[$183>>2] = $174;
 $184 = (($t0to1) + 12|0);
 HEAPF32[$184>>2] = $181;
 $185 = (($t0to1) + 16|0);
 HEAPF32[$185>>2] = $133;
 $186 = (($t0to1) + 20|0);
 HEAPF32[$186>>2] = $141;
 $187 = (($t0to1) + 24|0);
 HEAPF32[$187>>2] = $149;
 $188 = Math_fround(-$150);
 $189 = Math_fround(-$158);
 $190 = Math_fround(-$155);
 $191 = Math_fround(HEAPF32[$57>>2]);
 $192 = Math_fround($105 - $191);
 $193 = Math_fround(HEAPF32[$59>>2]);
 $194 = Math_fround($107 - $193);
 $195 = Math_fround(HEAPF32[$61>>2]);
 $196 = Math_fround($109 - $195);
 $197 = Math_fround($192 * Math_fround(2.0));
 $198 = Math_fround($194 * Math_fround(2.0));
 $199 = Math_fround($196 * Math_fround(2.0));
 $200 = Math_fround($152 * $152);
 $201 = Math_fround($200 + Math_fround(-0.5));
 $202 = Math_fround($197 * $188);
 $203 = Math_fround($198 * $189);
 $204 = Math_fround($202 + $203);
 $205 = Math_fround($199 * $190);
 $206 = Math_fround($204 + $205);
 $207 = Math_fround($201 * $197);
 $208 = Math_fround($199 * $189);
 $209 = Math_fround($198 * $190);
 $210 = Math_fround($208 - $209);
 $211 = Math_fround($152 * $210);
 $212 = Math_fround($207 + $211);
 $213 = Math_fround($206 * $188);
 $214 = Math_fround($213 + $212);
 $215 = Math_fround($201 * $198);
 $216 = Math_fround($197 * $190);
 $217 = Math_fround($199 * $188);
 $218 = Math_fround($216 - $217);
 $219 = Math_fround($152 * $218);
 $220 = Math_fround($215 + $219);
 $221 = Math_fround($206 * $189);
 $222 = Math_fround($221 + $220);
 $223 = Math_fround($201 * $199);
 $224 = Math_fround($198 * $188);
 $225 = Math_fround($197 * $189);
 $226 = Math_fround($224 - $225);
 $227 = Math_fround($152 * $226);
 $228 = Math_fround($223 + $227);
 $229 = Math_fround($206 * $190);
 $230 = Math_fround($228 + $229);
 $231 = Math_fround(HEAPF32[$transform1>>2]);
 $232 = Math_fround($152 * $231);
 $233 = Math_fround(HEAPF32[$71>>2]);
 $234 = Math_fround($233 * $188);
 $235 = Math_fround($232 + $234);
 $236 = Math_fround(HEAPF32[$68>>2]);
 $237 = Math_fround($236 * $189);
 $238 = Math_fround($235 + $237);
 $239 = Math_fround(HEAPF32[$65>>2]);
 $240 = Math_fround($239 * $190);
 $241 = Math_fround($238 - $240);
 $242 = Math_fround($152 * $239);
 $243 = Math_fround($233 * $189);
 $244 = Math_fround($243 + $242);
 $245 = Math_fround($231 * $190);
 $246 = Math_fround($245 + $244);
 $247 = Math_fround($236 * $188);
 $248 = Math_fround($246 - $247);
 $249 = Math_fround($152 * $236);
 $250 = Math_fround($233 * $190);
 $251 = Math_fround($250 + $249);
 $252 = Math_fround($239 * $188);
 $253 = Math_fround($252 + $251);
 $254 = Math_fround($231 * $189);
 $255 = Math_fround($253 - $254);
 $256 = Math_fround($152 * $233);
 $257 = Math_fround($231 * $188);
 $258 = Math_fround($256 - $257);
 $259 = Math_fround($239 * $189);
 $260 = Math_fround($258 - $259);
 $261 = Math_fround($236 * $190);
 $262 = Math_fround($260 - $261);
 HEAPF32[$t1to0>>2] = $241;
 $263 = (($t1to0) + 4|0);
 HEAPF32[$263>>2] = $248;
 $264 = (($t1to0) + 8|0);
 HEAPF32[$264>>2] = $255;
 $265 = (($t1to0) + 12|0);
 HEAPF32[$265>>2] = $262;
 $266 = (($t1to0) + 16|0);
 HEAPF32[$266>>2] = $214;
 $267 = (($t1to0) + 20|0);
 HEAPF32[$267>>2] = $222;
 $268 = (($t1to0) + 24|0);
 HEAPF32[$268>>2] = $230;
 __ZN5physx2Gu9ContainerC2Ev($delayedContacts);
 $269 = sp + 2272|0;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($delayedContacts,1088,$269,1);
 $270 = (($contactBuffer) + 4100|0);
 $271 = Math_fround(HEAPF32[$270>>2]);
 HEAP32[$blockCallback>>2] = ((548832 + 8|0));
 $272 = (($blockCallback) + 4|0);
 __ZN5physx2Gu29ConvexVsMeshContactGenerationC2ERNS0_9ContainerERKNS_11PxTransformES6_RKNS0_13PolygonalDataERKNS_2Cm8Matrix34ESD_RKNSA_23FastVertex2ShapeScalingEfbfS6_S6_RNS0_13ContactBufferE($272,$delayedContacts,$t0to1,$t1to0,$polyData0,$world0,$world1,$convexScaling,$contactDistance,$idtConvexScale,$271,$transform0,$transform1,$contactBuffer);
 $273 = (($blockCallback) + 2228|0);
 HEAP32[$273>>2] = $hfUtil;
 __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($0,$t0to1,$hullAABB);
 (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$transform1,$0,0,$blockCallback)|0);
 __ZN5physx2Gu29ConvexVsMeshContactGeneration20generateLastContactsEv($272);
 $274 = (($blockCallback) + 2224|0);
 $275 = HEAP8[$274>>0]|0;
 $276 = ($275<<24>>24)!=(0);
 __ZN5physx2Gu9ContainerD2Ev($delayedContacts);
 STACKTOP = sp;return ($276|0);
}
function __ZN5physx2Gu21contactBoxHeightfieldERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $hullAABB = 0, $idtScaling = 0, $polyBox = 0, $polyData0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $polyData0 = sp + 320|0;
 $polyBox = sp;
 $hullAABB = sp + 224|0;
 $idtScaling = sp + 248|0;
 $0 = (($shape0) + 4|0);
 __ZN5physx2Gu12PolygonalBoxC2ERKNS_6PxVec3E($polyBox,$0);
 __ZNK5physx2Gu12PolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($polyBox,$polyData0);
 $1 = Math_fround(HEAPF32[$contactDistance>>2]);
 $2 = Math_fround(HEAPF32[$0>>2]);
 $3 = Math_fround($1 + $2);
 $4 = (($shape0) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($1 + $5);
 $7 = (($shape0) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($1 + $8);
 $10 = Math_fround(-$3);
 $11 = Math_fround(-$6);
 $12 = Math_fround(-$9);
 HEAPF32[$hullAABB>>2] = $10;
 $13 = (($hullAABB) + 4|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($hullAABB) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($hullAABB) + 12|0);
 HEAPF32[$15>>2] = $3;
 $16 = (($hullAABB) + 16|0);
 HEAPF32[$16>>2] = $6;
 $17 = (($hullAABB) + 20|0);
 HEAPF32[$17>>2] = $9;
 HEAPF32[$idtScaling>>2] = Math_fround(1.0);
 $18 = (($idtScaling) + 4|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($idtScaling) + 8|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($idtScaling) + 12|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($idtScaling) + 16|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($idtScaling) + 20|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($idtScaling) + 24|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($idtScaling) + 28|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($idtScaling) + 32|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($idtScaling) + 36|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($idtScaling) + 40|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($idtScaling) + 44|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($idtScaling) + 48|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($idtScaling) + 52|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($idtScaling) + 56|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($idtScaling) + 60|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($idtScaling) + 64|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($idtScaling) + 68|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (__ZL23contactHullHeightfield2RKN5physx2Gu13PolygonalDataERKNS_9PxBounds3ERKNS_21PxHeightFieldGeometryERKNS_11PxTransformESC_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingEb($polyData0,$hullAABB,$shape1,$transform0,$transform1,$1,$contactBuffer,$idtScaling,1)|0);
 STACKTOP = sp;return ($35|0);
}
function __ZN44ConvexVsHeightfieldContactGenerationCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN44ConvexVsHeightfieldContactGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN44ConvexVsHeightfieldContactGenerationCallback7onEventEjPj($this,$nb,$indices) {
 $this = $this|0;
 $nb = $nb|0;
 $indices = $indices|0;
 var $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0);
 var $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$02 = 0;
 var $adjInds = 0, $adjTri = 0, $b$04 = 0, $cache = 0, $count$01$i = 0, $currentTriangle = 0, $edgeFlags$05$i = 0, $exitcond = 0, $inds$05 = 0, $inds$1$lcssa12 = 0, $inds$13 = 0, $nbTrigs$06 = 0, $scevgep$sum = 0, $scevgep10 = 0, $triFlags$01 = 0, $triFlags$2 = 0, $triInds$04$i = 0, $vertIndices = 0, $vertInds$03$i = 0, $verts$02$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 960|0;
 $cache = sp + 96|0;
 $vertIndices = sp;
 $currentTriangle = sp + 12|0;
 $adjInds = sp + 48|0;
 $adjTri = sp + 60|0;
 $0 = (($cache) + 848|0);
 HEAP32[$0>>2] = 0;
 $1 = (($nb) + 15)|0;
 $2 = $1 >>> 4;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 4|0);
 $5 = (($cache) + 832|0);
 $6 = (($cache) + 768|0);
 $7 = (($cache) + 576|0);
 $8 = (($this) + 2228|0);
 $9 = (($this) + 2216|0);
 $10 = (($currentTriangle) + 12|0);
 $11 = (($currentTriangle) + 16|0);
 $12 = (($currentTriangle) + 4|0);
 $13 = (($currentTriangle) + 20|0);
 $14 = (($currentTriangle) + 8|0);
 $15 = (($currentTriangle) + 24|0);
 $16 = (($currentTriangle) + 28|0);
 $17 = (($currentTriangle) + 32|0);
 $18 = (($adjTri) + 12|0);
 $19 = (($adjTri) + 16|0);
 $20 = (($adjTri) + 4|0);
 $21 = (($adjTri) + 20|0);
 $22 = (($adjTri) + 8|0);
 $23 = (($adjTri) + 24|0);
 $24 = (($adjTri) + 28|0);
 $25 = (($adjTri) + 32|0);
 $26 = (($vertIndices) + 4|0);
 $27 = (($vertIndices) + 8|0);
 $b$04 = 0;$inds$05 = $indices;$nbTrigs$06 = $nb;
 while(1) {
  HEAP32[$0>>2] = 0;
  $28 = ($nbTrigs$06>>>0)<(16);
  $29 = $28 ? $nbTrigs$06 : 16;
  $30 = (($nbTrigs$06) - ($29))|0;
  $31 = ($29|0)==(0);
  L6: do {
   if ($31) {
    $inds$1$lcssa12 = $inds$05;
   } else {
    $32 = ($nbTrigs$06>>>0)<(16);
    $$in = $29;$inds$13 = $inds$05;
    while(1) {
     $33 = (($$in) + -1)|0;
     $34 = (($inds$13) + 4|0);
     $35 = HEAP32[$inds$13>>2]|0;
     $36 = HEAP32[$8>>2]|0;
     $37 = HEAP32[$9>>2]|0;
     (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($36,$37,$currentTriangle,$vertIndices,$adjInds,$35,0,0)|0);
     $38 = Math_fround(HEAPF32[$10>>2]);
     $39 = Math_fround(HEAPF32[$currentTriangle>>2]);
     $40 = Math_fround($38 - $39);
     $41 = Math_fround(HEAPF32[$11>>2]);
     $42 = Math_fround(HEAPF32[$12>>2]);
     $43 = Math_fround($41 - $42);
     $44 = Math_fround(HEAPF32[$13>>2]);
     $45 = Math_fround(HEAPF32[$14>>2]);
     $46 = Math_fround($44 - $45);
     $47 = Math_fround(HEAPF32[$15>>2]);
     $48 = Math_fround($47 - $39);
     $49 = Math_fround(HEAPF32[$16>>2]);
     $50 = Math_fround($49 - $42);
     $51 = Math_fround(HEAPF32[$17>>2]);
     $52 = Math_fround($51 - $45);
     $53 = Math_fround($43 * $52);
     $54 = Math_fround($46 * $50);
     $55 = Math_fround($53 - $54);
     $56 = Math_fround($46 * $48);
     $57 = Math_fround($40 * $52);
     $58 = Math_fround($56 - $57);
     $59 = Math_fround($40 * $50);
     $60 = Math_fround($43 * $48);
     $61 = Math_fround($59 - $60);
     $62 = Math_fround($55 * $55);
     $63 = Math_fround($58 * $58);
     $64 = Math_fround($62 + $63);
     $65 = Math_fround($61 * $61);
     $66 = Math_fround($65 + $64);
     $67 = (Math_fround(Math_sqrt((Math_fround($66)))));
     $68 = $67 > Math_fround(0.0);
     if ($68) {
      $69 = Math_fround(Math_fround(1.0) / $67);
      $70 = Math_fround($55 * $69);
      $71 = Math_fround($58 * $69);
      $72 = Math_fround($61 * $69);
      $133 = $70;$136 = $71;$140 = $72;
     } else {
      $133 = $55;$136 = $58;$140 = $61;
     }
     $a$02 = 0;$triFlags$01 = 0;
     while(1) {
      $73 = (($adjInds) + ($a$02<<2)|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($74|0)==(-1);
      if ($75) {
       $148 = (($a$02) + 3)|0;
       $149 = 1 << $148;
       $150 = $triFlags$01&255;
       $151 = $149 | $150;
       $152 = $151&255;
       $triFlags$2 = $152;
      } else {
       $76 = HEAP32[$8>>2]|0;
       $77 = HEAP32[$9>>2]|0;
       (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($76,$77,$adjTri,0,0,$74,0,0)|0);
       $78 = Math_fround(HEAPF32[$18>>2]);
       $79 = Math_fround(HEAPF32[$adjTri>>2]);
       $80 = Math_fround($78 - $79);
       $81 = Math_fround(HEAPF32[$19>>2]);
       $82 = Math_fround(HEAPF32[$20>>2]);
       $83 = Math_fround($81 - $82);
       $84 = Math_fround(HEAPF32[$21>>2]);
       $85 = Math_fround(HEAPF32[$22>>2]);
       $86 = Math_fround($84 - $85);
       $87 = Math_fround(HEAPF32[$23>>2]);
       $88 = Math_fround($87 - $79);
       $89 = Math_fround(HEAPF32[$24>>2]);
       $90 = Math_fround($89 - $82);
       $91 = Math_fround(HEAPF32[$25>>2]);
       $92 = Math_fround($91 - $85);
       $93 = Math_fround($83 * $92);
       $94 = Math_fround($86 * $90);
       $95 = Math_fround($93 - $94);
       $96 = Math_fround($86 * $88);
       $97 = Math_fround($80 * $92);
       $98 = Math_fround($96 - $97);
       $99 = Math_fround($80 * $90);
       $100 = Math_fround($83 * $88);
       $101 = Math_fround($99 - $100);
       $102 = (548856 + ($a$02)|0);
       $103 = HEAP8[$102>>0]|0;
       $104 = $103&255;
       $105 = (($currentTriangle) + (($104*12)|0)|0);
       $106 = Math_fround(HEAPF32[$105>>2]);
       $107 = Math_fround($106 - $79);
       $108 = ((($currentTriangle) + (($104*12)|0)|0) + 4|0);
       $109 = Math_fround(HEAPF32[$108>>2]);
       $110 = Math_fround($109 - $82);
       $111 = ((($currentTriangle) + (($104*12)|0)|0) + 8|0);
       $112 = Math_fround(HEAPF32[$111>>2]);
       $113 = Math_fround($112 - $85);
       $114 = Math_fround($95 * $107);
       $115 = Math_fround($98 * $110);
       $116 = Math_fround($114 + $115);
       $117 = Math_fround($101 * $113);
       $118 = Math_fround($116 + $117);
       $119 = $118 < Math_fround(0.0);
       if ($119) {
        $120 = Math_fround($95 * $95);
        $121 = Math_fround($98 * $98);
        $122 = Math_fround($120 + $121);
        $123 = Math_fround($101 * $101);
        $124 = Math_fround($123 + $122);
        $125 = (Math_fround(Math_sqrt((Math_fround($124)))));
        $126 = $125 > Math_fround(0.0);
        if ($126) {
         $127 = Math_fround(Math_fround(1.0) / $125);
         $128 = Math_fround($95 * $127);
         $129 = Math_fround($98 * $127);
         $130 = Math_fround($101 * $127);
         $132 = $128;$135 = $129;$139 = $130;
        } else {
         $132 = $95;$135 = $98;$139 = $101;
        }
        $131 = Math_fround($133 * $132);
        $134 = Math_fround($136 * $135);
        $137 = Math_fround($134 + $131);
        $138 = Math_fround($140 * $139);
        $141 = Math_fround($138 + $137);
        $142 = $141 < Math_fround(0.999000012874603271484);
        if ($142) {
         $143 = (($a$02) + 3)|0;
         $144 = 1 << $143;
         $145 = $triFlags$01&255;
         $146 = $144 | $145;
         $147 = $146&255;
         $triFlags$2 = $147;
        } else {
         $triFlags$2 = $triFlags$01;
        }
       } else {
        $triFlags$2 = $triFlags$01;
       }
      }
      $153 = (($a$02) + 1)|0;
      $exitcond = ($153|0)==(3);
      if ($exitcond) {
       break;
      } else {
       $a$02 = $153;$triFlags$01 = $triFlags$2;
      }
     }
     $154 = HEAP32[$0>>2]|0;
     $155 = (($154) + 1)|0;
     HEAP32[$0>>2] = $155;
     $156 = ($154*3)|0;
     $157 = Math_fround(HEAPF32[$currentTriangle>>2]);
     $158 = (($cache) + (($156*12)|0)|0);
     HEAPF32[$158>>2] = $157;
     $159 = Math_fround(HEAPF32[$12>>2]);
     $160 = ((($cache) + (($156*12)|0)|0) + 4|0);
     HEAPF32[$160>>2] = $159;
     $161 = Math_fround(HEAPF32[$14>>2]);
     $162 = ((($cache) + (($156*12)|0)|0) + 8|0);
     HEAPF32[$162>>2] = $161;
     $163 = (($156) + 1)|0;
     $164 = Math_fround(HEAPF32[$10>>2]);
     $165 = (($cache) + (($163*12)|0)|0);
     HEAPF32[$165>>2] = $164;
     $166 = Math_fround(HEAPF32[$11>>2]);
     $167 = ((($cache) + (($163*12)|0)|0) + 4|0);
     HEAPF32[$167>>2] = $166;
     $168 = Math_fround(HEAPF32[$13>>2]);
     $169 = ((($cache) + (($163*12)|0)|0) + 8|0);
     HEAPF32[$169>>2] = $168;
     $170 = (($156) + 2)|0;
     $171 = Math_fround(HEAPF32[$15>>2]);
     $172 = (($cache) + (($170*12)|0)|0);
     HEAPF32[$172>>2] = $171;
     $173 = Math_fround(HEAPF32[$16>>2]);
     $174 = ((($cache) + (($170*12)|0)|0) + 4|0);
     HEAPF32[$174>>2] = $173;
     $175 = Math_fround(HEAPF32[$17>>2]);
     $176 = ((($cache) + (($170*12)|0)|0) + 8|0);
     HEAPF32[$176>>2] = $175;
     $177 = HEAP32[$vertIndices>>2]|0;
     $178 = ((($cache) + ($156<<2)|0) + 576|0);
     HEAP32[$178>>2] = $177;
     $179 = HEAP32[$26>>2]|0;
     $180 = ((($cache) + ($163<<2)|0) + 576|0);
     HEAP32[$180>>2] = $179;
     $181 = HEAP32[$27>>2]|0;
     $182 = ((($cache) + ($170<<2)|0) + 576|0);
     HEAP32[$182>>2] = $181;
     $183 = ((($cache) + ($154<<2)|0) + 768|0);
     HEAP32[$183>>2] = $35;
     $184 = ((($cache) + ($154)|0) + 832|0);
     HEAP8[$184>>0] = $triFlags$2;
     $185 = ($33|0)==(0);
     if ($185) {
      break;
     } else {
      $$in = $33;$inds$13 = $34;
     }
    }
    $scevgep$sum = $32 ? $nbTrigs$06 : 16;
    $scevgep10 = (($inds$05) + ($scevgep$sum<<2)|0);
    $$pre = HEAP32[$0>>2]|0;
    $186 = ($$pre|0)==(0);
    if ($186) {
     $inds$1$lcssa12 = $scevgep10;
    } else {
     $count$01$i = $$pre;$edgeFlags$05$i = $5;$triInds$04$i = $6;$vertInds$03$i = $7;$verts$02$i = $cache;
     while(1) {
      $187 = (($count$01$i) + -1)|0;
      $188 = HEAP32[$triInds$04$i>>2]|0;
      $189 = HEAP8[$edgeFlags$05$i>>0]|0;
      (__ZN5physx2Gu29ConvexVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($4,$verts$02$i,$188,$189,$vertInds$03$i)|0);
      $190 = ($187|0)==(0);
      if ($190) {
       $inds$1$lcssa12 = $scevgep10;
       break L6;
      }
      $191 = (($edgeFlags$05$i) + 1|0);
      $192 = (($triInds$04$i) + 4|0);
      $193 = (($vertInds$03$i) + 12|0);
      $194 = (($verts$02$i) + 36|0);
      $count$01$i = $187;$edgeFlags$05$i = $191;$triInds$04$i = $192;$vertInds$03$i = $193;$verts$02$i = $194;
     }
    }
   }
  } while(0);
  $195 = (($b$04) + 1)|0;
  $196 = ($195>>>0)<($2>>>0);
  if ($196) {
   $b$04 = $195;$inds$05 = $inds$1$lcssa12;$nbTrigs$06 = $30;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN37ConvexVsMeshContactGenerationCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN37ConvexVsMeshContactGenerationCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$hit,$v0,$v1,$v2,$0,$vinds) {
 $this = $this|0;
 $hit = $hit|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 $0 = $0|0;
 $vinds = $vinds|0;
 var $$phi$trans$insert11 = 0, $$phi$trans$insert13 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert17 = 0, $$phi$trans$insert19 = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert7 = 0, $$phi$trans$insert9 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre12 = Math_fround(0), $$pre14 = Math_fround(0), $$pre16 = Math_fround(0), $$pre18 = Math_fround(0), $$pre20 = Math_fround(0), $$pre22 = Math_fround(0), $$pre8 = Math_fround(0), $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0;
 var $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0);
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $count$01$i = 0, $edgeFlags$05$i = 0, $triInds$04$i = 0, $vertInds$03$i = 0, $verts = 0;
 var $verts$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $verts = sp;
 $1 = (($this) + 3100|0);
 $2 = (__ZNK5physx2Gu15OBBTriangleTest10obbTriTestERKNS_6PxVec3ES4_S4_($1,$v0,$v1,$v2)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 3092|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $30 = (($this) + 3084|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = Math_fround(HEAPF32[$v0>>2]);
  $33 = Math_fround(HEAPF32[$31>>2]);
  $34 = Math_fround($32 * $33);
  $35 = (($31) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($32 * $36);
  $38 = (($31) + 8|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($32 * $39);
  $41 = (($v0) + 4|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($31) + 12|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($42 * $44);
  $46 = (($31) + 16|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($42 * $47);
  $49 = (($31) + 20|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($42 * $50);
  $52 = Math_fround($34 + $45);
  $53 = Math_fround($37 + $48);
  $54 = Math_fround($40 + $51);
  $55 = (($v0) + 8|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($31) + 24|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($56 * $58);
  $60 = (($31) + 28|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($56 * $61);
  $63 = (($31) + 32|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($56 * $64);
  $66 = Math_fround($52 + $59);
  $67 = Math_fround($53 + $62);
  $68 = Math_fround($54 + $65);
  HEAPF32[$verts>>2] = $66;
  $69 = (($verts) + 4|0);
  HEAPF32[$69>>2] = $67;
  $70 = (($verts) + 8|0);
  HEAPF32[$70>>2] = $68;
  $71 = Math_fround(HEAPF32[$v1>>2]);
  $72 = Math_fround(HEAPF32[$31>>2]);
  $73 = Math_fround($71 * $72);
  $74 = Math_fround(HEAPF32[$35>>2]);
  $75 = Math_fround($71 * $74);
  $76 = Math_fround(HEAPF32[$38>>2]);
  $77 = Math_fround($71 * $76);
  $78 = (($v1) + 4|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround(HEAPF32[$43>>2]);
  $81 = Math_fround($79 * $80);
  $82 = Math_fround(HEAPF32[$46>>2]);
  $83 = Math_fround($79 * $82);
  $84 = Math_fround(HEAPF32[$49>>2]);
  $85 = Math_fround($79 * $84);
  $86 = Math_fround($73 + $81);
  $87 = Math_fround($75 + $83);
  $88 = Math_fround($77 + $85);
  $89 = (($v1) + 8|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = Math_fround(HEAPF32[$57>>2]);
  $92 = Math_fround($90 * $91);
  $93 = Math_fround(HEAPF32[$60>>2]);
  $94 = Math_fround($90 * $93);
  $95 = Math_fround(HEAPF32[$63>>2]);
  $96 = Math_fround($90 * $95);
  $97 = Math_fround($86 + $92);
  $98 = Math_fround($87 + $94);
  $99 = Math_fround($88 + $96);
  $100 = (($verts) + 12|0);
  HEAPF32[$100>>2] = $97;
  $101 = (($verts) + 16|0);
  HEAPF32[$101>>2] = $98;
  $102 = (($verts) + 20|0);
  HEAPF32[$102>>2] = $99;
  $103 = Math_fround(HEAPF32[$v2>>2]);
  $104 = Math_fround(HEAPF32[$31>>2]);
  $105 = Math_fround($103 * $104);
  $106 = Math_fround(HEAPF32[$35>>2]);
  $107 = Math_fround($103 * $106);
  $108 = Math_fround(HEAPF32[$38>>2]);
  $109 = Math_fround($103 * $108);
  $110 = (($v2) + 4|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround(HEAPF32[$43>>2]);
  $113 = Math_fround($111 * $112);
  $114 = Math_fround(HEAPF32[$46>>2]);
  $115 = Math_fround($111 * $114);
  $116 = Math_fround(HEAPF32[$49>>2]);
  $117 = Math_fround($111 * $116);
  $118 = Math_fround($105 + $113);
  $119 = Math_fround($107 + $115);
  $120 = Math_fround($109 + $117);
  $121 = (($v2) + 8|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround(HEAPF32[$57>>2]);
  $124 = Math_fround($122 * $123);
  $125 = Math_fround(HEAPF32[$60>>2]);
  $126 = Math_fround($122 * $125);
  $127 = Math_fround(HEAPF32[$63>>2]);
  $128 = Math_fround($122 * $127);
  $129 = Math_fround($118 + $124);
  $130 = Math_fround($119 + $126);
  $131 = Math_fround($120 + $128);
  $132 = (($verts) + 24|0);
  HEAPF32[$132>>2] = $129;
  $133 = (($verts) + 28|0);
  HEAPF32[$133>>2] = $130;
  $134 = (($verts) + 32|0);
  HEAPF32[$134>>2] = $131;
  $190 = $131;$191 = $130;$192 = $129;$193 = $99;$194 = $98;$195 = $97;$196 = $68;$197 = $67;$198 = $66;
 } else {
  $7 = Math_fround(HEAPF32[$v0>>2]);
  HEAPF32[$verts>>2] = $7;
  $8 = (($v0) + 4|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($verts) + 4|0);
  HEAPF32[$10>>2] = $9;
  $11 = (($v0) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($verts) + 8|0);
  HEAPF32[$13>>2] = $12;
  $14 = Math_fround(HEAPF32[$v1>>2]);
  $15 = (($verts) + 12|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($v1) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($verts) + 16|0);
  HEAPF32[$18>>2] = $17;
  $19 = (($v1) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($verts) + 20|0);
  HEAPF32[$21>>2] = $20;
  $22 = Math_fround(HEAPF32[$v2>>2]);
  $23 = (($verts) + 24|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($v2) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($verts) + 28|0);
  HEAPF32[$26>>2] = $25;
  $27 = (($v2) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($verts) + 32|0);
  HEAPF32[$29>>2] = $28;
  $190 = $28;$191 = $25;$192 = $22;$193 = $20;$194 = $17;$195 = $14;$196 = $12;$197 = $9;$198 = $7;
 }
 $135 = (($hit) + 8|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = (($this) + 856|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = ($138|0)==(16);
 if ($139) {
  $140 = (($this) + 860|0);
  $141 = (($this) + 840|0);
  $142 = (($this) + 776|0);
  $143 = (($this) + 584|0);
  $144 = (($this) + 8|0);
  $count$01$i = 16;$edgeFlags$05$i = $141;$triInds$04$i = $142;$vertInds$03$i = $143;$verts$02$i = $144;
  while(1) {
   $145 = (($count$01$i) + -1)|0;
   $146 = HEAP32[$triInds$04$i>>2]|0;
   $147 = HEAP8[$edgeFlags$05$i>>0]|0;
   (__ZN5physx2Gu29ConvexVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($140,$verts$02$i,$146,$147,$vertInds$03$i)|0);
   $148 = (($verts$02$i) + 36|0);
   $149 = (($vertInds$03$i) + 12|0);
   $150 = (($triInds$04$i) + 4|0);
   $151 = (($edgeFlags$05$i) + 1|0);
   $152 = ($145|0)==(0);
   if ($152) {
    break;
   } else {
    $count$01$i = $145;$edgeFlags$05$i = $151;$triInds$04$i = $150;$vertInds$03$i = $149;$verts$02$i = $148;
   }
  }
  HEAP32[$137>>2] = 0;
  $$pre = Math_fround(HEAPF32[$verts>>2]);
  $$phi$trans$insert7 = (($verts) + 4|0);
  $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
  $$phi$trans$insert9 = (($verts) + 8|0);
  $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert9>>2]);
  $$phi$trans$insert11 = (($verts) + 12|0);
  $$pre12 = Math_fround(HEAPF32[$$phi$trans$insert11>>2]);
  $$phi$trans$insert13 = (($verts) + 16|0);
  $$pre14 = Math_fround(HEAPF32[$$phi$trans$insert13>>2]);
  $$phi$trans$insert15 = (($verts) + 20|0);
  $$pre16 = Math_fround(HEAPF32[$$phi$trans$insert15>>2]);
  $$phi$trans$insert17 = (($verts) + 24|0);
  $$pre18 = Math_fround(HEAPF32[$$phi$trans$insert17>>2]);
  $$phi$trans$insert19 = (($verts) + 28|0);
  $$pre20 = Math_fround(HEAPF32[$$phi$trans$insert19>>2]);
  $$phi$trans$insert21 = (($verts) + 32|0);
  $$pre22 = Math_fround(HEAPF32[$$phi$trans$insert21>>2]);
  $158 = 0;$161 = $$pre;$163 = $$pre8;$165 = $$pre10;$168 = $$pre12;$170 = $$pre14;$172 = $$pre16;$175 = $$pre18;$177 = $$pre20;$179 = $$pre22;
 } else {
  $158 = $138;$161 = $198;$163 = $197;$165 = $196;$168 = $195;$170 = $194;$172 = $193;$175 = $192;$177 = $191;$179 = $190;
 }
 $153 = (($this) + 3088|0);
 $154 = HEAP32[$153>>2]|0;
 $155 = (($154) + ($136)|0);
 $156 = HEAP8[$155>>0]|0;
 $157 = (($158) + 1)|0;
 HEAP32[$137>>2] = $157;
 $159 = ($158*3)|0;
 $160 = ((($this) + (($159*12)|0)|0) + 8|0);
 HEAPF32[$160>>2] = $161;
 $162 = ((($this) + (($159*12)|0)|0) + 12|0);
 HEAPF32[$162>>2] = $163;
 $164 = ((($this) + (($159*12)|0)|0) + 16|0);
 HEAPF32[$164>>2] = $165;
 $166 = (($159) + 1)|0;
 $167 = ((($this) + (($166*12)|0)|0) + 8|0);
 HEAPF32[$167>>2] = $168;
 $169 = ((($this) + (($166*12)|0)|0) + 12|0);
 HEAPF32[$169>>2] = $170;
 $171 = ((($this) + (($166*12)|0)|0) + 16|0);
 HEAPF32[$171>>2] = $172;
 $173 = (($159) + 2)|0;
 $174 = ((($this) + (($173*12)|0)|0) + 8|0);
 HEAPF32[$174>>2] = $175;
 $176 = ((($this) + (($173*12)|0)|0) + 12|0);
 HEAPF32[$176>>2] = $177;
 $178 = ((($this) + (($173*12)|0)|0) + 16|0);
 HEAPF32[$178>>2] = $179;
 $180 = HEAP32[$vinds>>2]|0;
 $181 = ((($this) + ($159<<2)|0) + 584|0);
 HEAP32[$181>>2] = $180;
 $182 = (($vinds) + 4|0);
 $183 = HEAP32[$182>>2]|0;
 $184 = ((($this) + ($166<<2)|0) + 584|0);
 HEAP32[$184>>2] = $183;
 $185 = (($vinds) + 8|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = ((($this) + ($173<<2)|0) + 584|0);
 HEAP32[$187>>2] = $186;
 $188 = ((($this) + ($158<<2)|0) + 776|0);
 HEAP32[$188>>2] = $136;
 $189 = ((($this) + ($158)|0) + 840|0);
 HEAP8[$189>>0] = $156;
 STACKTOP = sp;return 1;
}
function __ZN37ConvexVsMeshContactGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu23findRotationMatrixFromZERKNS_6PxVec3E($agg$result,$to) {
 $agg$result = $agg$result|0;
 $to = $to|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $fabsf$i$i = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($to) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($1)))));
 $2 = !($fabsf$i$i <= Math_fround(0.999899983406066894531));
 if ($2) {
  $34 = Math_fround(HEAPF32[$to>>2]);
  $35 = Math_fround(Math_fround(0.0) - $34);
  $36 = (($to) + 4|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround(Math_fround(1.0) - $37);
  $39 = Math_fround(Math_fround(0.0) - $1);
  $40 = Math_fround($35 * $35);
  $41 = Math_fround($38 * $38);
  $42 = Math_fround($40 + $41);
  $43 = Math_fround($39 * $39);
  $44 = Math_fround($43 + $42);
  $45 = Math_fround(Math_fround(2.0) / $44);
  $46 = Math_fround($35 * Math_fround(0.0));
  $47 = Math_fround($46 + $38);
  $48 = Math_fround($39 * Math_fround(-1.0));
  $49 = Math_fround($48 + $47);
  $50 = Math_fround($45 * $49);
  $51 = Math_fround($45 * $35);
  $52 = Math_fround($50 * $35);
  $53 = Math_fround($51 * $35);
  $54 = Math_fround($52 * Math_fround(0.0));
  $55 = Math_fround($54 - $53);
  $56 = Math_fround($51 * $38);
  $57 = Math_fround($52 - $56);
  $58 = (($agg$result) + 12|0);
  HEAPF32[$58>>2] = $57;
  $59 = Math_fround($51 * $39);
  $60 = Math_fround(Math_fround(0.0) - $59);
  $61 = Math_fround($52 * Math_fround(-1.0));
  $62 = Math_fround($61 + $60);
  $63 = (($agg$result) + 24|0);
  HEAPF32[$63>>2] = $62;
  $64 = Math_fround($55 + Math_fround(1.0));
  HEAPF32[$agg$result>>2] = $64;
  $65 = Math_fround($45 * $38);
  $66 = Math_fround($50 * $38);
  $67 = Math_fround($65 * $35);
  $68 = Math_fround($66 * Math_fround(0.0));
  $69 = Math_fround($68 - $67);
  $70 = (($agg$result) + 4|0);
  HEAPF32[$70>>2] = $69;
  $71 = Math_fround($65 * $38);
  $72 = Math_fround(Math_fround(-1.0) - $71);
  $73 = Math_fround($66 + $72);
  $74 = (($58) + 4|0);
  $75 = Math_fround($65 * $39);
  $76 = Math_fround(Math_fround(1.0) - $75);
  $77 = Math_fround($66 * Math_fround(-1.0));
  $78 = Math_fround($77 + $76);
  $79 = (($63) + 4|0);
  HEAPF32[$79>>2] = $78;
  $80 = Math_fround($73 + Math_fround(1.0));
  HEAPF32[$74>>2] = $80;
  $81 = Math_fround($45 * $39);
  $82 = Math_fround($50 * $39);
  $83 = Math_fround($81 * $35);
  $84 = Math_fround(Math_fround(0.0) - $83);
  $85 = Math_fround($82 * Math_fround(0.0));
  $86 = Math_fround($85 + $84);
  $87 = (($agg$result) + 8|0);
  HEAPF32[$87>>2] = $86;
  $88 = Math_fround($81 * $38);
  $89 = Math_fround(Math_fround(1.0) - $88);
  $90 = Math_fround($82 + $89);
  $91 = (($58) + 8|0);
  HEAPF32[$91>>2] = $90;
  $92 = Math_fround($81 * $39);
  $93 = Math_fround(Math_fround(-1.0) - $92);
  $94 = Math_fround($82 * Math_fround(-1.0));
  $95 = Math_fround($94 + $93);
  $96 = (($63) + 8|0);
  $97 = Math_fround($95 + Math_fround(1.0));
  HEAPF32[$96>>2] = $97;
  STACKTOP = sp;return;
 } else {
  $3 = (($to) + 4|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = Math_fround(-$4);
  $6 = Math_fround(HEAPF32[$to>>2]);
  $7 = Math_fround($1 + Math_fround(1.0));
  $8 = Math_fround(Math_fround(1.0) / $7);
  $9 = Math_fround($8 * $5);
  $10 = Math_fround($8 * Math_fround(0.0));
  $11 = Math_fround($6 * $9);
  $12 = Math_fround($9 * Math_fround(0.0));
  $13 = Math_fround($6 * $10);
  $14 = Math_fround($9 * $5);
  $15 = Math_fround($1 + $14);
  HEAPF32[$agg$result>>2] = $15;
  $16 = (($agg$result) + 12|0);
  HEAPF32[$16>>2] = $11;
  $17 = Math_fround($6 + $12);
  $18 = (($agg$result) + 24|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround($11 + Math_fround(0.0));
  $20 = (($agg$result) + 4|0);
  HEAPF32[$20>>2] = $19;
  $21 = Math_fround($6 * $8);
  $22 = Math_fround($6 * $21);
  $23 = Math_fround($1 + $22);
  $24 = (($16) + 4|0);
  HEAPF32[$24>>2] = $23;
  $25 = Math_fround($4 + $13);
  $26 = (($18) + 4|0);
  HEAPF32[$26>>2] = $25;
  $27 = Math_fround($12 - $6);
  $28 = (($agg$result) + 8|0);
  HEAPF32[$28>>2] = $27;
  $29 = Math_fround($13 - $4);
  $30 = (($16) + 8|0);
  HEAPF32[$30>>2] = $29;
  $31 = Math_fround($10 * Math_fround(0.0));
  $32 = Math_fround($1 + $31);
  $33 = (($18) + 8|0);
  HEAPF32[$33>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu24contactPolygonPolygonExtEjPKNS_6PxVec3EPKhRKNS_2Cm8Matrix34ERKNS_7PxPlaneERKNS_7PxMat33EjS3_S5_S9_SC_SF_RS2_S9_S9_jjRNS0_13ContactBufferEbSG_f($numVerts0,$vertices0,$indices0,$world0,$localPlane0,$rotT0,$numVerts1,$vertices1,$indices1,$world1,$localPlane1,$rotT1,$worldSepAxis,$transform0to1,$transform1to0,$polyIndex0,$polyIndex1,$contactBuffer,$flipNormal,$posShift,$sepShift) {
 $numVerts0 = $numVerts0|0;
 $vertices0 = $vertices0|0;
 $indices0 = $indices0|0;
 $world0 = $world0|0;
 $localPlane0 = $localPlane0|0;
 $rotT0 = $rotT0|0;
 $numVerts1 = $numVerts1|0;
 $vertices1 = $vertices1|0;
 $indices1 = $indices1|0;
 $world1 = $world1|0;
 $localPlane1 = $localPlane1|0;
 $rotT1 = $rotT1|0;
 $worldSepAxis = $worldSepAxis|0;
 $transform0to1 = $transform0to1|0;
 $transform1to0 = $transform1to0|0;
 $polyIndex0 = $polyIndex0|0;
 $polyIndex1 = $polyIndex1|0;
 $contactBuffer = $contactBuffer|0;
 $flipNormal = $flipNormal|0;
 $posShift = $posShift|0;
 $sepShift = Math_fround($sepShift);
 var $$ = 0, $$1 = 0, $$1$us = 0, $$2 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0.0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0);
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0);
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0;
 var $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0);
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0);
 var $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = Math_fround(0);
 var $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0);
 var $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = Math_fround(0), $490 = 0;
 var $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = Math_fround(0), $503 = Math_fround(0), $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = 0;
 var $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = Math_fround(0);
 var $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0);
 var $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0);
 var $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = 0, $586 = 0, $587 = 0, $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0);
 var $6 = Math_fround(0), $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = 0;
 var $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = 0, $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0);
 var $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = Math_fround(0), $650 = 0, $651 = 0, $652 = 0;
 var $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0;
 var $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = 0, $684 = Math_fround(0), $685 = 0, $686 = Math_fround(0), $687 = Math_fround(0), $688 = 0, $689 = Math_fround(0);
 var $69 = 0, $690 = 0, $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0);
 var $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = Math_fround(0), $717 = 0, $718 = 0, $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = 0, $722 = Math_fround(0), $723 = 0, $724 = Math_fround(0);
 var $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = 0, $729 = 0, $73 = Math_fround(0), $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = Math_fround(0), $740 = 0, $741 = 0, $742 = 0;
 var $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = Math_fround(0), $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0);
 var $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0);
 var $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = 0, $795 = 0, $796 = 0, $797 = Math_fround(0);
 var $798 = Math_fround(0), $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0;
 var $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = Math_fround(0), $830 = 0, $831 = 0, $832 = 0;
 var $833 = 0, $834 = 0, $835 = 0, $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0);
 var $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0);
 var $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = 0, $876 = 0, $877 = 0, $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = 0, $881 = 0, $882 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $NumIn$095 = 0, $NumIn$1 = 0, $NumIn$2 = 0, $NumIn$3$lcssa = 0, $NumIn$385 = 0, $NumIn$385$us = 0, $NumIn$4 = 0, $NumIn$4$us = 0, $brmerge = 0, $dist = 0, $exitcond = 0, $exitcond115 = 0, $exitcond116 = 0;
 var $exitcond117 = 0, $extract$t = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $i$092 = 0, $i1$082 = 0, $i1$082$us = 0, $i7$080 = 0, $i8$0$ph74 = 0, $i8$0$ph74$us = 0, $i8$071 = 0, $i8$071$us = 0, $indices = 0, $j$0$ph102 = 0, $j$078 = 0, $maxX = 0, $maxY = 0, $minX = 0, $minY = 0;
 var $nbCurrentContacts$093 = 0, $nbCurrentContacts$1 = 0, $nbCurrentContacts$283 = 0, $nbCurrentContacts$283$us = 0, $nbCurrentContacts$3 = 0, $nbCurrentContacts$3$us = 0, $notlhs = 0, $notrhs = 0, $or$cond$i = 0, $or$cond$not = 0, $p10 = 0, $plane = 0, $status$094 = 0, $status$1 = 0, $status$2$off0 = 0, $status$3$off0$lcssa = 0, $status$3$off084 = 0, $status$3$off084$us = 0, $status$4$off0 = 0, $status$4$off0$us = 0;
 var $status$5$off0 = 0, $status$8$off0$ph103 = 0, $status$9$off0$ph73 = 0, $status$9$off0$ph75 = 0, $status$9$off0$ph75$us = 0, $v1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $indices = sp + 64|0;
 $minX = sp + 60|0;
 $minY = sp + 56|0;
 $maxX = sp + 52|0;
 $maxY = sp + 48|0;
 $v1 = sp + 24|0;
 $plane = sp + 8|0;
 $dist = sp;
 $p10 = sp + 36|0;
 $0 = Math_fround(HEAPF32[$worldSepAxis>>2]);
 if ($flipNormal) {
  $1 = Math_fround(-$0);
  $2 = (($worldSepAxis) + 4|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = Math_fround(-$3);
  $5 = (($worldSepAxis) + 8|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround(-$6);
  $233 = $1;$235 = $4;$237 = $7;$27 = $3;$32 = $6;
 } else {
  $8 = (($worldSepAxis) + 4|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($worldSepAxis) + 8|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $233 = $0;$235 = $9;$237 = $11;$27 = $9;$32 = $11;
 }
 $12 = ($numVerts0>>>0)<($numVerts1>>>0);
 $13 = $12 ? $numVerts1 : $numVerts0;
 $14 = ($13*12)|0;
 $15 = STACKTOP; STACKTOP = STACKTOP + ((((1*$14)|0)+15)&-16)|0;;
 $16 = STACKTOP; STACKTOP = STACKTOP + ((((1*$numVerts0)|0)+15)&-16)|0;;
 $17 = STACKTOP; STACKTOP = STACKTOP + ((((1*$numVerts0)|0)+15)&-16)|0;;
 $18 = STACKTOP; STACKTOP = STACKTOP + ((((1*$numVerts1)|0)+15)&-16)|0;;
 $19 = STACKTOP; STACKTOP = STACKTOP + ((((1*$numVerts1)|0)+15)&-16)|0;;
 $20 = (($contactBuffer) + 4096|0);
 $21 = HEAP32[$20>>2]|0;
 HEAPF32[$minX>>2] = Math_fround(0.0);
 HEAPF32[$minY>>2] = Math_fround(0.0);
 HEAPF32[$maxX>>2] = Math_fround(0.0);
 HEAPF32[$maxY>>2] = Math_fround(0.0);
 $22 = Math_fround(HEAPF32[$world1>>2]);
 $23 = Math_fround($22 * $0);
 $24 = (($world1) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $27);
 $28 = Math_fround($23 + $26);
 $29 = (($world1) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $32);
 $33 = Math_fround($28 + $31);
 $34 = (($world1) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($0 * $35);
 $37 = (($world1) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($27 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($world1) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($32 * $42);
 $44 = Math_fround($40 + $43);
 $45 = (($world1) + 24|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($0 * $46);
 $48 = (($world1) + 28|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($27 * $49);
 $51 = Math_fround($47 + $50);
 $52 = (($world1) + 32|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($32 * $53);
 $55 = Math_fround($51 + $54);
 $56 = Math_fround(-$33);
 $57 = Math_fround(-$44);
 $58 = Math_fround(-$55);
 $59 = Math_fround(HEAPF32[$transform0to1>>2]);
 $60 = (($rotT1) + 4|0);
 $61 = (($transform0to1) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($rotT1) + 8|0);
 $64 = (($transform0to1) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($rotT1) + 12|0);
 $67 = (($rotT1) + 16|0);
 $68 = (($rotT1) + 20|0);
 $69 = (($rotT1) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($59 * $70);
 $72 = (($rotT1) + 28|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($62 * $73);
 $75 = Math_fround($71 + $74);
 $76 = (($rotT1) + 32|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($65 * $77);
 $79 = Math_fround($75 + $78);
 $80 = (($transform0to1) + 12|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($transform0to1) + 16|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($transform0to1) + 20|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($70 * $81);
 $87 = Math_fround($73 * $83);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($77 * $85);
 $90 = Math_fround($88 + $89);
 $91 = (($transform0to1) + 24|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($transform0to1) + 28|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($transform0to1) + 32|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($70 * $92);
 $98 = Math_fround($73 * $94);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($77 * $96);
 $101 = Math_fround($99 + $100);
 $102 = (($transform0to1) + 36|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($transform0to1) + 40|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($transform0to1) + 44|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($70 * $103);
 $109 = Math_fround($73 * $105);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($77 * $107);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround(HEAPF32[$localPlane1>>2]);
 $114 = Math_fround($113 * $56);
 $115 = (($localPlane1) + 4|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($116 * $57);
 $118 = Math_fround($114 + $117);
 $119 = (($localPlane1) + 8|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($120 * $58);
 $122 = Math_fround($118 + $121);
 $123 = ($numVerts1>>>0)>(2);
 if ($123) {
  $124 = +$122;
  $125 = !($124 >= 9.99999999999999954748E-8);
  if ($125) {
   label = 16;
  } else {
   $126 = Math_fround(Math_fround(1.0) / $122);
   $127 = (($localPlane1) + 12|0);
   $128 = Math_fround(HEAPF32[$127>>2]);
   $129 = Math_fround(-$128);
   __ZL17transformVerticesRfS_S_S_PfjPKN5physx6PxVec3EPKhRKNS1_7PxMat33E($minX,$minY,$maxX,$maxY,$15,$numVerts1,$vertices1,$indices1,$rotT1);
   $130 = ($numVerts0|0)==(0);
   if ($130) {
    $NumIn$2 = 0;$status$2$off0 = 0;
   } else {
    $131 = Math_fround(HEAPF32[$minX>>2]);
    $132 = Math_fround(HEAPF32[$minY>>2]);
    $133 = Math_fround(HEAPF32[$maxX>>2]);
    $134 = Math_fround(HEAPF32[$maxY>>2]);
    $135 = (($world0) + 4|0);
    $136 = (($world0) + 8|0);
    $137 = (($world0) + 12|0);
    $138 = (($world0) + 16|0);
    $139 = (($world0) + 20|0);
    $140 = (($world0) + 24|0);
    $141 = (($world0) + 28|0);
    $142 = (($world0) + 32|0);
    $143 = (($world0) + 36|0);
    $144 = (($world0) + 40|0);
    $145 = (($world0) + 44|0);
    $146 = (($posShift) + 4|0);
    $147 = (($posShift) + 8|0);
    $NumIn$095 = 0;$i$092 = 0;$nbCurrentContacts$093 = 0;$status$094 = 0;
    while(1) {
     $148 = (($indices0) + ($i$092)|0);
     $149 = HEAP8[$148>>0]|0;
     $150 = $149&255;
     $151 = (($vertices0) + (($150*12)|0)|0);
     $152 = Math_fround(HEAPF32[$151>>2]);
     $153 = Math_fround($79 * $152);
     $154 = ((($vertices0) + (($150*12)|0)|0) + 4|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = Math_fround($90 * $155);
     $157 = Math_fround($153 + $156);
     $158 = ((($vertices0) + (($150*12)|0)|0) + 8|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = Math_fround($101 * $159);
     $161 = Math_fround($157 + $160);
     $162 = Math_fround($112 + $161);
     $163 = Math_fround(HEAPF32[$transform0to1>>2]);
     $164 = Math_fround($152 * $163);
     $165 = Math_fround(HEAPF32[$61>>2]);
     $166 = Math_fround($152 * $165);
     $167 = Math_fround(HEAPF32[$64>>2]);
     $168 = Math_fround($152 * $167);
     $169 = Math_fround(HEAPF32[$80>>2]);
     $170 = Math_fround($155 * $169);
     $171 = Math_fround(HEAPF32[$82>>2]);
     $172 = Math_fround($155 * $171);
     $173 = Math_fround(HEAPF32[$84>>2]);
     $174 = Math_fround($155 * $173);
     $175 = Math_fround($164 + $170);
     $176 = Math_fround($166 + $172);
     $177 = Math_fround($168 + $174);
     $178 = Math_fround(HEAPF32[$91>>2]);
     $179 = Math_fround($159 * $178);
     $180 = Math_fround(HEAPF32[$93>>2]);
     $181 = Math_fround($159 * $180);
     $182 = Math_fround(HEAPF32[$95>>2]);
     $183 = Math_fround($159 * $182);
     $184 = Math_fround($175 + $179);
     $185 = Math_fround($176 + $181);
     $186 = Math_fround($177 + $183);
     $187 = Math_fround(HEAPF32[$102>>2]);
     $188 = Math_fround($184 + $187);
     $189 = Math_fround(HEAPF32[$104>>2]);
     $190 = Math_fround($185 + $189);
     $191 = Math_fround(HEAPF32[$106>>2]);
     $192 = Math_fround($186 + $191);
     $193 = Math_fround($128 + $162);
     $194 = Math_fround($126 * $193);
     $195 = Math_fround($194 * $56);
     $196 = Math_fround($194 * $57);
     $197 = Math_fround($194 * $58);
     $198 = Math_fround($188 - $195);
     $199 = Math_fround($190 - $196);
     $200 = Math_fround($192 - $197);
     $201 = Math_fround(HEAPF32[$rotT1>>2]);
     $202 = Math_fround($198 * $201);
     $203 = Math_fround(HEAPF32[$60>>2]);
     $204 = Math_fround($199 * $203);
     $205 = Math_fround($202 + $204);
     $206 = Math_fround(HEAPF32[$63>>2]);
     $207 = Math_fround($200 * $206);
     $208 = Math_fround($205 + $207);
     $209 = Math_fround(HEAPF32[$66>>2]);
     $210 = Math_fround($198 * $209);
     $211 = Math_fround(HEAPF32[$67>>2]);
     $212 = Math_fround($199 * $211);
     $213 = Math_fround($210 + $212);
     $214 = Math_fround(HEAPF32[$68>>2]);
     $215 = Math_fround($200 * $214);
     $216 = Math_fround($213 + $215);
     $217 = Math_fround($208 - $131);
     $218 = Math_fround($216 - $132);
     $219 = (($17) + ($i$092)|0);
     $220 = (__ZL31PointInConvexPolygon2D_OutCodesPKfjffffRh($15,$numVerts1,$217,$218,$133,$134,$219)|0);
     $221 = (($16) + ($i$092)|0);
     $222 = $220&1;
     HEAP8[$221>>0] = $222;
     if ($220) {
      $223 = (($NumIn$095) + 1)|0;
      $224 = $162 < $129;
      if ($224) {
       $225 = HEAP32[$20>>2]|0;
       $226 = ($225>>>0)>(63);
       if ($226) {
        $NumIn$1 = $223;$nbCurrentContacts$1 = $nbCurrentContacts$093;$status$1 = 1;
       } else {
        $227 = (($225) + 1)|0;
        HEAP32[$20>>2] = $227;
        $228 = (($contactBuffer) + ($225<<6)|0);
        $229 = ($228|0)==(0|0);
        if ($229) {
         $NumIn$1 = $223;$nbCurrentContacts$1 = $nbCurrentContacts$093;$status$1 = 1;
        } else {
         $230 = HEAP8[$148>>0]|0;
         $231 = (($nbCurrentContacts$093) + 1)|0;
         $232 = (($indices) + ($nbCurrentContacts$093)|0);
         HEAP8[$232>>0] = $230;
         HEAPF32[$228>>2] = $233;
         $234 = ((($contactBuffer) + ($225<<6)|0) + 4|0);
         HEAPF32[$234>>2] = $235;
         $236 = ((($contactBuffer) + ($225<<6)|0) + 8|0);
         HEAPF32[$236>>2] = $237;
         $238 = Math_fround(HEAPF32[$151>>2]);
         $239 = Math_fround(HEAPF32[$world0>>2]);
         $240 = Math_fround($238 * $239);
         $241 = Math_fround(HEAPF32[$135>>2]);
         $242 = Math_fround($238 * $241);
         $243 = Math_fround(HEAPF32[$136>>2]);
         $244 = Math_fround($238 * $243);
         $245 = Math_fround(HEAPF32[$154>>2]);
         $246 = Math_fround(HEAPF32[$137>>2]);
         $247 = Math_fround($245 * $246);
         $248 = Math_fround(HEAPF32[$138>>2]);
         $249 = Math_fround($245 * $248);
         $250 = Math_fround(HEAPF32[$139>>2]);
         $251 = Math_fround($245 * $250);
         $252 = Math_fround($240 + $247);
         $253 = Math_fround($242 + $249);
         $254 = Math_fround($244 + $251);
         $255 = Math_fround(HEAPF32[$158>>2]);
         $256 = Math_fround(HEAPF32[$140>>2]);
         $257 = Math_fround($255 * $256);
         $258 = Math_fround(HEAPF32[$141>>2]);
         $259 = Math_fround($255 * $258);
         $260 = Math_fround(HEAPF32[$142>>2]);
         $261 = Math_fround($255 * $260);
         $262 = Math_fround($252 + $257);
         $263 = Math_fround($253 + $259);
         $264 = Math_fround($254 + $261);
         $265 = Math_fround(HEAPF32[$143>>2]);
         $266 = Math_fround($262 + $265);
         $267 = Math_fround(HEAPF32[$144>>2]);
         $268 = Math_fround($263 + $267);
         $269 = Math_fround(HEAPF32[$145>>2]);
         $270 = Math_fround($264 + $269);
         if ($flipNormal) {
          $271 = Math_fround(HEAPF32[$posShift>>2]);
          $272 = Math_fround(HEAPF32[$146>>2]);
          $273 = Math_fround(HEAPF32[$147>>2]);
          $275 = $271;$277 = $272;$279 = $273;
         } else {
          $275 = Math_fround(0.0);$277 = Math_fround(0.0);$279 = Math_fround(0.0);
         }
         $274 = Math_fround($266 + $275);
         $276 = Math_fround($268 + $277);
         $278 = Math_fround($270 + $279);
         $280 = ((($contactBuffer) + ($225<<6)|0) + 16|0);
         HEAPF32[$280>>2] = $274;
         $281 = ((($contactBuffer) + ($225<<6)|0) + 20|0);
         HEAPF32[$281>>2] = $276;
         $282 = ((($contactBuffer) + ($225<<6)|0) + 24|0);
         HEAPF32[$282>>2] = $278;
         $283 = Math_fround($194 + $sepShift);
         $284 = ((($contactBuffer) + ($225<<6)|0) + 12|0);
         HEAPF32[$284>>2] = $283;
         $285 = ((($contactBuffer) + ($225<<6)|0) + 48|0);
         HEAP32[$285>>2] = $polyIndex0;
         $286 = ((($contactBuffer) + ($225<<6)|0) + 52|0);
         HEAP32[$286>>2] = $polyIndex1;
         $NumIn$1 = $223;$nbCurrentContacts$1 = $231;$status$1 = 1;
        }
       }
      } else {
       $NumIn$1 = $223;$nbCurrentContacts$1 = $nbCurrentContacts$093;$status$1 = $status$094;
      }
     } else {
      $NumIn$1 = $NumIn$095;$nbCurrentContacts$1 = $nbCurrentContacts$093;$status$1 = $status$094;
     }
     $287 = (($i$092) + 1)|0;
     $exitcond116 = ($287|0)==($numVerts0|0);
     if ($exitcond116) {
      break;
     } else {
      $NumIn$095 = $NumIn$1;$i$092 = $287;$nbCurrentContacts$093 = $nbCurrentContacts$1;$status$094 = $status$1;
     }
    }
    $288 = $status$1 & 1;
    $extract$t = ($288<<24>>24)!=(0);
    $NumIn$2 = $NumIn$1;$status$2$off0 = $extract$t;
   }
  }
 } else {
  label = 16;
 }
 if ((label|0) == 16) {
  _memset(($16|0),0,($numVerts0|0))|0;
  _memset(($17|0),0,($numVerts0|0))|0;
  $NumIn$2 = 0;$status$2$off0 = 0;
 }
 $289 = ($NumIn$2|0)==($numVerts0|0);
 __ZL21ContactReductionAllInRN5physx2Gu13ContactBufferEjjRKNS_7PxMat33EPKNS_6PxVec3EPKh($contactBuffer,$21,$NumIn$2,$rotT0,$vertices0,$indices);
 if ($289) {
  $$2 = $status$2$off0;
  STACKTOP = sp;return ($$2|0);
 }
 $290 = HEAP32[$20>>2]|0;
 $291 = Math_fround(HEAPF32[$rotT0>>2]);
 $292 = Math_fround(HEAPF32[$transform1to0>>2]);
 $293 = Math_fround($291 * $292);
 $294 = (($rotT0) + 4|0);
 $295 = Math_fround(HEAPF32[$294>>2]);
 $296 = (($transform1to0) + 4|0);
 $297 = Math_fround(HEAPF32[$296>>2]);
 $298 = Math_fround($295 * $297);
 $299 = Math_fround($293 + $298);
 $300 = (($rotT0) + 8|0);
 $301 = Math_fround(HEAPF32[$300>>2]);
 $302 = (($transform1to0) + 8|0);
 $303 = Math_fround(HEAPF32[$302>>2]);
 $304 = Math_fround($301 * $303);
 $305 = Math_fround($299 + $304);
 $306 = (($rotT0) + 12|0);
 $307 = Math_fround(HEAPF32[$306>>2]);
 $308 = Math_fround($292 * $307);
 $309 = (($rotT0) + 16|0);
 $310 = Math_fround(HEAPF32[$309>>2]);
 $311 = Math_fround($297 * $310);
 $312 = Math_fround($308 + $311);
 $313 = (($rotT0) + 20|0);
 $314 = Math_fround(HEAPF32[$313>>2]);
 $315 = Math_fround($303 * $314);
 $316 = Math_fround($312 + $315);
 $317 = (($rotT0) + 24|0);
 $318 = Math_fround(HEAPF32[$317>>2]);
 $319 = Math_fround($292 * $318);
 $320 = (($rotT0) + 28|0);
 $321 = Math_fround(HEAPF32[$320>>2]);
 $322 = Math_fround($297 * $321);
 $323 = Math_fround($319 + $322);
 $324 = (($rotT0) + 32|0);
 $325 = Math_fround(HEAPF32[$324>>2]);
 $326 = Math_fround($303 * $325);
 $327 = Math_fround($323 + $326);
 $328 = (($transform1to0) + 12|0);
 $329 = Math_fround(HEAPF32[$328>>2]);
 $330 = Math_fround($291 * $329);
 $331 = (($transform1to0) + 16|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = Math_fround($295 * $332);
 $334 = Math_fround($330 + $333);
 $335 = (($transform1to0) + 20|0);
 $336 = Math_fround(HEAPF32[$335>>2]);
 $337 = Math_fround($301 * $336);
 $338 = Math_fround($334 + $337);
 $339 = Math_fround($307 * $329);
 $340 = Math_fround($310 * $332);
 $341 = Math_fround($339 + $340);
 $342 = Math_fround($314 * $336);
 $343 = Math_fround($341 + $342);
 $344 = Math_fround($318 * $329);
 $345 = Math_fround($321 * $332);
 $346 = Math_fround($344 + $345);
 $347 = Math_fround($325 * $336);
 $348 = Math_fround($346 + $347);
 $349 = (($transform1to0) + 24|0);
 $350 = Math_fround(HEAPF32[$349>>2]);
 $351 = Math_fround($291 * $350);
 $352 = (($transform1to0) + 28|0);
 $353 = Math_fround(HEAPF32[$352>>2]);
 $354 = Math_fround($295 * $353);
 $355 = Math_fround($351 + $354);
 $356 = (($transform1to0) + 32|0);
 $357 = Math_fround(HEAPF32[$356>>2]);
 $358 = Math_fround($301 * $357);
 $359 = Math_fround($355 + $358);
 $360 = Math_fround($307 * $350);
 $361 = Math_fround($310 * $353);
 $362 = Math_fround($360 + $361);
 $363 = Math_fround($314 * $357);
 $364 = Math_fround($362 + $363);
 $365 = Math_fround($318 * $350);
 $366 = Math_fround($321 * $353);
 $367 = Math_fround($365 + $366);
 $368 = Math_fround($325 * $357);
 $369 = Math_fround($367 + $368);
 $370 = (($transform1to0) + 36|0);
 $371 = Math_fround(HEAPF32[$370>>2]);
 $372 = Math_fround($291 * $371);
 $373 = (($transform1to0) + 40|0);
 $374 = Math_fround(HEAPF32[$373>>2]);
 $375 = Math_fround($295 * $374);
 $376 = Math_fround($372 + $375);
 $377 = (($transform1to0) + 44|0);
 $378 = Math_fround(HEAPF32[$377>>2]);
 $379 = Math_fround($301 * $378);
 $380 = Math_fround($376 + $379);
 $381 = Math_fround($307 * $371);
 $382 = Math_fround($310 * $374);
 $383 = Math_fround($381 + $382);
 $384 = Math_fround($314 * $378);
 $385 = Math_fround($383 + $384);
 $386 = Math_fround($318 * $371);
 $387 = Math_fround($321 * $374);
 $388 = Math_fround($386 + $387);
 $389 = Math_fround($325 * $378);
 $390 = Math_fround($388 + $389);
 $391 = ($numVerts0>>>0)>(2);
 if ($391) {
  $392 = (($localPlane0) + 12|0);
  $393 = Math_fround(HEAPF32[$392>>2]);
  $394 = Math_fround(-$393);
  __ZL17transformVerticesRfS_S_S_PfjPKN5physx6PxVec3EPKhRKNS1_7PxMat33E($minX,$minY,$maxX,$maxY,$15,$numVerts0,$vertices0,$indices0,$rotT0);
  $395 = ($numVerts1|0)==(0);
  if ($395) {
   $NumIn$3$lcssa = 0;$status$3$off0$lcssa = $status$2$off0;
  } else {
   $396 = Math_fround(HEAPF32[$minX>>2]);
   $397 = Math_fround(HEAPF32[$minY>>2]);
   $398 = Math_fround(HEAPF32[$maxX>>2]);
   $399 = Math_fround(HEAPF32[$maxY>>2]);
   $400 = (($world1) + 36|0);
   $401 = (($world1) + 40|0);
   $402 = (($world1) + 44|0);
   $403 = (($posShift) + 4|0);
   $404 = (($posShift) + 8|0);
   if ($flipNormal) {
    $NumIn$385$us = 0;$i1$082$us = 0;$nbCurrentContacts$283$us = 0;$status$3$off084$us = $status$2$off0;
    while(1) {
     $405 = (($indices1) + ($i1$082$us)|0);
     $406 = HEAP8[$405>>0]|0;
     $407 = $406&255;
     $408 = (($vertices1) + (($407*12)|0)|0);
     $409 = Math_fround(HEAPF32[$408>>2]);
     $410 = Math_fround($305 * $409);
     $411 = ((($vertices1) + (($407*12)|0)|0) + 4|0);
     $412 = Math_fround(HEAPF32[$411>>2]);
     $413 = Math_fround($338 * $412);
     $414 = Math_fround($410 + $413);
     $415 = ((($vertices1) + (($407*12)|0)|0) + 8|0);
     $416 = Math_fround(HEAPF32[$415>>2]);
     $417 = Math_fround($359 * $416);
     $418 = Math_fround($414 + $417);
     $419 = Math_fround($380 + $418);
     $420 = Math_fround($316 * $409);
     $421 = Math_fround($343 * $412);
     $422 = Math_fround($420 + $421);
     $423 = Math_fround($364 * $416);
     $424 = Math_fround($422 + $423);
     $425 = Math_fround($385 + $424);
     $426 = Math_fround($419 - $396);
     $427 = Math_fround($425 - $397);
     $428 = (($19) + ($i1$082$us)|0);
     $429 = (__ZL31PointInConvexPolygon2D_OutCodesPKfjffffRh($15,$numVerts0,$426,$427,$398,$399,$428)|0);
     $430 = (($18) + ($i1$082$us)|0);
     $431 = $429&1;
     HEAP8[$430>>0] = $431;
     if ($429) {
      $432 = (($NumIn$385$us) + 1)|0;
      $433 = Math_fround(HEAPF32[$408>>2]);
      $434 = Math_fround($327 * $433);
      $435 = Math_fround(HEAPF32[$411>>2]);
      $436 = Math_fround($348 * $435);
      $437 = Math_fround($434 + $436);
      $438 = Math_fround(HEAPF32[$415>>2]);
      $439 = Math_fround($369 * $438);
      $440 = Math_fround($437 + $439);
      $441 = Math_fround($390 + $440);
      $442 = $441 < $394;
      if ($442) {
       $443 = HEAP32[$20>>2]|0;
       $444 = ($443>>>0)>(63);
       if ($444) {
        $NumIn$4$us = $432;$nbCurrentContacts$3$us = $nbCurrentContacts$283$us;$status$4$off0$us = 1;
       } else {
        $445 = (($443) + 1)|0;
        HEAP32[$20>>2] = $445;
        $446 = (($contactBuffer) + ($443<<6)|0);
        $447 = ($446|0)==(0|0);
        if ($447) {
         $NumIn$4$us = $432;$nbCurrentContacts$3$us = $nbCurrentContacts$283$us;$status$4$off0$us = 1;
        } else {
         $448 = HEAP8[$405>>0]|0;
         $449 = (($nbCurrentContacts$283$us) + 1)|0;
         $450 = (($indices) + ($nbCurrentContacts$283$us)|0);
         HEAP8[$450>>0] = $448;
         HEAPF32[$446>>2] = $233;
         $451 = ((($contactBuffer) + ($443<<6)|0) + 4|0);
         HEAPF32[$451>>2] = $235;
         $452 = ((($contactBuffer) + ($443<<6)|0) + 8|0);
         HEAPF32[$452>>2] = $237;
         $453 = Math_fround(HEAPF32[$408>>2]);
         $454 = Math_fround(HEAPF32[$world1>>2]);
         $455 = Math_fround($453 * $454);
         $456 = Math_fround(HEAPF32[$24>>2]);
         $457 = Math_fround($453 * $456);
         $458 = Math_fround(HEAPF32[$29>>2]);
         $459 = Math_fround($453 * $458);
         $460 = Math_fround(HEAPF32[$411>>2]);
         $461 = Math_fround(HEAPF32[$34>>2]);
         $462 = Math_fround($460 * $461);
         $463 = Math_fround(HEAPF32[$37>>2]);
         $464 = Math_fround($460 * $463);
         $465 = Math_fround(HEAPF32[$41>>2]);
         $466 = Math_fround($460 * $465);
         $467 = Math_fround($455 + $462);
         $468 = Math_fround($457 + $464);
         $469 = Math_fround($459 + $466);
         $470 = Math_fround(HEAPF32[$415>>2]);
         $471 = Math_fround(HEAPF32[$45>>2]);
         $472 = Math_fround($470 * $471);
         $473 = Math_fround(HEAPF32[$48>>2]);
         $474 = Math_fround($470 * $473);
         $475 = Math_fround(HEAPF32[$52>>2]);
         $476 = Math_fround($470 * $475);
         $477 = Math_fround($467 + $472);
         $478 = Math_fround($468 + $474);
         $479 = Math_fround($469 + $476);
         $480 = Math_fround(HEAPF32[$400>>2]);
         $481 = Math_fround($477 + $480);
         $482 = Math_fround(HEAPF32[$401>>2]);
         $483 = Math_fround($478 + $482);
         $484 = Math_fround(HEAPF32[$402>>2]);
         $485 = Math_fround($479 + $484);
         $486 = Math_fround($481 + Math_fround(0.0));
         $487 = Math_fround($483 + Math_fround(0.0));
         $488 = Math_fround($485 + Math_fround(0.0));
         $489 = ((($contactBuffer) + ($443<<6)|0) + 16|0);
         HEAPF32[$489>>2] = $486;
         $490 = ((($contactBuffer) + ($443<<6)|0) + 20|0);
         HEAPF32[$490>>2] = $487;
         $491 = ((($contactBuffer) + ($443<<6)|0) + 24|0);
         HEAPF32[$491>>2] = $488;
         $492 = Math_fround($393 + $441);
         $493 = Math_fround($492 + $sepShift);
         $494 = ((($contactBuffer) + ($443<<6)|0) + 12|0);
         HEAPF32[$494>>2] = $493;
         $495 = ((($contactBuffer) + ($443<<6)|0) + 48|0);
         HEAP32[$495>>2] = $polyIndex0;
         $496 = ((($contactBuffer) + ($443<<6)|0) + 52|0);
         HEAP32[$496>>2] = $polyIndex1;
         $NumIn$4$us = $432;$nbCurrentContacts$3$us = $449;$status$4$off0$us = 1;
        }
       }
      } else {
       $NumIn$4$us = $432;$nbCurrentContacts$3$us = $nbCurrentContacts$283$us;$status$4$off0$us = $status$3$off084$us;
      }
     } else {
      $NumIn$4$us = $NumIn$385$us;$nbCurrentContacts$3$us = $nbCurrentContacts$283$us;$status$4$off0$us = $status$3$off084$us;
     }
     $497 = (($i1$082$us) + 1)|0;
     $exitcond117 = ($497|0)==($numVerts1|0);
     if ($exitcond117) {
      $NumIn$3$lcssa = $NumIn$4$us;$status$3$off0$lcssa = $status$4$off0$us;
      break;
     } else {
      $NumIn$385$us = $NumIn$4$us;$i1$082$us = $497;$nbCurrentContacts$283$us = $nbCurrentContacts$3$us;$status$3$off084$us = $status$4$off0$us;
     }
    }
   } else {
    $NumIn$385 = 0;$i1$082 = 0;$nbCurrentContacts$283 = 0;$status$3$off084 = $status$2$off0;
    while(1) {
     $498 = (($indices1) + ($i1$082)|0);
     $499 = HEAP8[$498>>0]|0;
     $500 = $499&255;
     $501 = (($vertices1) + (($500*12)|0)|0);
     $502 = Math_fround(HEAPF32[$501>>2]);
     $503 = Math_fround($305 * $502);
     $504 = ((($vertices1) + (($500*12)|0)|0) + 4|0);
     $505 = Math_fround(HEAPF32[$504>>2]);
     $506 = Math_fround($338 * $505);
     $507 = Math_fround($503 + $506);
     $508 = ((($vertices1) + (($500*12)|0)|0) + 8|0);
     $509 = Math_fround(HEAPF32[$508>>2]);
     $510 = Math_fround($359 * $509);
     $511 = Math_fround($507 + $510);
     $512 = Math_fround($380 + $511);
     $513 = Math_fround($316 * $502);
     $514 = Math_fround($343 * $505);
     $515 = Math_fround($513 + $514);
     $516 = Math_fround($364 * $509);
     $517 = Math_fround($515 + $516);
     $518 = Math_fround($385 + $517);
     $519 = Math_fround($512 - $396);
     $520 = Math_fround($518 - $397);
     $521 = (($19) + ($i1$082)|0);
     $522 = (__ZL31PointInConvexPolygon2D_OutCodesPKfjffffRh($15,$numVerts0,$519,$520,$398,$399,$521)|0);
     $523 = (($18) + ($i1$082)|0);
     $524 = $522&1;
     HEAP8[$523>>0] = $524;
     if ($522) {
      $525 = (($NumIn$385) + 1)|0;
      $526 = Math_fround(HEAPF32[$501>>2]);
      $527 = Math_fround($327 * $526);
      $528 = Math_fround(HEAPF32[$504>>2]);
      $529 = Math_fround($348 * $528);
      $530 = Math_fround($527 + $529);
      $531 = Math_fround(HEAPF32[$508>>2]);
      $532 = Math_fround($369 * $531);
      $533 = Math_fround($530 + $532);
      $534 = Math_fround($390 + $533);
      $535 = $534 < $394;
      if ($535) {
       $536 = HEAP32[$20>>2]|0;
       $537 = ($536>>>0)>(63);
       if ($537) {
        $NumIn$4 = $525;$nbCurrentContacts$3 = $nbCurrentContacts$283;$status$4$off0 = 1;
       } else {
        $538 = (($536) + 1)|0;
        HEAP32[$20>>2] = $538;
        $539 = (($contactBuffer) + ($536<<6)|0);
        $540 = ($539|0)==(0|0);
        if ($540) {
         $NumIn$4 = $525;$nbCurrentContacts$3 = $nbCurrentContacts$283;$status$4$off0 = 1;
        } else {
         $541 = HEAP8[$498>>0]|0;
         $542 = (($nbCurrentContacts$283) + 1)|0;
         $543 = (($indices) + ($nbCurrentContacts$283)|0);
         HEAP8[$543>>0] = $541;
         HEAPF32[$539>>2] = $233;
         $544 = ((($contactBuffer) + ($536<<6)|0) + 4|0);
         HEAPF32[$544>>2] = $235;
         $545 = ((($contactBuffer) + ($536<<6)|0) + 8|0);
         HEAPF32[$545>>2] = $237;
         $546 = Math_fround(HEAPF32[$501>>2]);
         $547 = Math_fround(HEAPF32[$world1>>2]);
         $548 = Math_fround($546 * $547);
         $549 = Math_fround(HEAPF32[$24>>2]);
         $550 = Math_fround($546 * $549);
         $551 = Math_fround(HEAPF32[$29>>2]);
         $552 = Math_fround($546 * $551);
         $553 = Math_fround(HEAPF32[$504>>2]);
         $554 = Math_fround(HEAPF32[$34>>2]);
         $555 = Math_fround($553 * $554);
         $556 = Math_fround(HEAPF32[$37>>2]);
         $557 = Math_fround($553 * $556);
         $558 = Math_fround(HEAPF32[$41>>2]);
         $559 = Math_fround($553 * $558);
         $560 = Math_fround($548 + $555);
         $561 = Math_fround($550 + $557);
         $562 = Math_fround($552 + $559);
         $563 = Math_fround(HEAPF32[$508>>2]);
         $564 = Math_fround(HEAPF32[$45>>2]);
         $565 = Math_fround($563 * $564);
         $566 = Math_fround(HEAPF32[$48>>2]);
         $567 = Math_fround($563 * $566);
         $568 = Math_fround(HEAPF32[$52>>2]);
         $569 = Math_fround($563 * $568);
         $570 = Math_fround($560 + $565);
         $571 = Math_fround($561 + $567);
         $572 = Math_fround($562 + $569);
         $573 = Math_fround(HEAPF32[$400>>2]);
         $574 = Math_fround($570 + $573);
         $575 = Math_fround(HEAPF32[$401>>2]);
         $576 = Math_fround($571 + $575);
         $577 = Math_fround(HEAPF32[$402>>2]);
         $578 = Math_fround($572 + $577);
         $579 = Math_fround(HEAPF32[$posShift>>2]);
         $580 = Math_fround(HEAPF32[$403>>2]);
         $581 = Math_fround(HEAPF32[$404>>2]);
         $582 = Math_fround($574 + $579);
         $583 = Math_fround($576 + $580);
         $584 = Math_fround($578 + $581);
         $585 = ((($contactBuffer) + ($536<<6)|0) + 16|0);
         HEAPF32[$585>>2] = $582;
         $586 = ((($contactBuffer) + ($536<<6)|0) + 20|0);
         HEAPF32[$586>>2] = $583;
         $587 = ((($contactBuffer) + ($536<<6)|0) + 24|0);
         HEAPF32[$587>>2] = $584;
         $588 = Math_fround($393 + $534);
         $589 = Math_fround($588 + $sepShift);
         $590 = ((($contactBuffer) + ($536<<6)|0) + 12|0);
         HEAPF32[$590>>2] = $589;
         $591 = ((($contactBuffer) + ($536<<6)|0) + 48|0);
         HEAP32[$591>>2] = $polyIndex0;
         $592 = ((($contactBuffer) + ($536<<6)|0) + 52|0);
         HEAP32[$592>>2] = $polyIndex1;
         $NumIn$4 = $525;$nbCurrentContacts$3 = $542;$status$4$off0 = 1;
        }
       }
      } else {
       $NumIn$4 = $525;$nbCurrentContacts$3 = $nbCurrentContacts$283;$status$4$off0 = $status$3$off084;
      }
     } else {
      $NumIn$4 = $NumIn$385;$nbCurrentContacts$3 = $nbCurrentContacts$283;$status$4$off0 = $status$3$off084;
     }
     $593 = (($i1$082) + 1)|0;
     $exitcond115 = ($593|0)==($numVerts1|0);
     if ($exitcond115) {
      $NumIn$3$lcssa = $NumIn$4;$status$3$off0$lcssa = $status$4$off0;
      break;
     } else {
      $NumIn$385 = $NumIn$4;$i1$082 = $593;$nbCurrentContacts$283 = $nbCurrentContacts$3;$status$3$off084 = $status$4$off0;
     }
    }
   }
  }
  $594 = ($NumIn$3$lcssa|0)==($numVerts1|0);
  __ZL21ContactReductionAllInRN5physx2Gu13ContactBufferEjjRKNS_7PxMat33EPKNS_6PxVec3EPKh($contactBuffer,$290,$NumIn$3$lcssa,$rotT1,$vertices1,$indices);
  if ($594) {
   $$2 = $status$3$off0$lcssa;
   STACKTOP = sp;return ($$2|0);
  } else {
   $status$5$off0 = $status$3$off0$lcssa;
  }
 } else {
  _memset(($18|0),0,($numVerts1|0))|0;
  _memset(($19|0),0,($numVerts1|0))|0;
  $status$5$off0 = $status$2$off0;
 }
 $595 = ($numVerts1|0)==(0);
 if ($595) {
  $$2 = $status$5$off0;
  STACKTOP = sp;return ($$2|0);
 }
 $596 = Math_fround(HEAPF32[$transform1to0>>2]);
 $597 = Math_fround(HEAPF32[$296>>2]);
 $598 = Math_fround(HEAPF32[$302>>2]);
 $599 = Math_fround(HEAPF32[$328>>2]);
 $600 = Math_fround(HEAPF32[$331>>2]);
 $601 = Math_fround(HEAPF32[$335>>2]);
 $602 = Math_fround(HEAPF32[$349>>2]);
 $603 = Math_fround(HEAPF32[$352>>2]);
 $604 = Math_fround(HEAPF32[$356>>2]);
 $605 = Math_fround(HEAPF32[$370>>2]);
 $606 = Math_fround(HEAPF32[$373>>2]);
 $607 = Math_fround(HEAPF32[$377>>2]);
 $i7$080 = 0;
 while(1) {
  $608 = (($indices1) + ($i7$080)|0);
  $609 = HEAP8[$608>>0]|0;
  $610 = $609&255;
  $611 = (($vertices1) + (($610*12)|0)|0);
  $612 = Math_fround(HEAPF32[$611>>2]);
  $613 = Math_fround($612 * $596);
  $614 = Math_fround($612 * $597);
  $615 = Math_fround($612 * $598);
  $616 = ((($vertices1) + (($610*12)|0)|0) + 4|0);
  $617 = Math_fround(HEAPF32[$616>>2]);
  $618 = Math_fround($617 * $599);
  $619 = Math_fround($617 * $600);
  $620 = Math_fround($617 * $601);
  $621 = Math_fround($613 + $618);
  $622 = Math_fround($614 + $619);
  $623 = Math_fround($615 + $620);
  $624 = ((($vertices1) + (($610*12)|0)|0) + 8|0);
  $625 = Math_fround(HEAPF32[$624>>2]);
  $626 = Math_fround($625 * $602);
  $627 = Math_fround($625 * $603);
  $628 = Math_fround($625 * $604);
  $629 = Math_fround($621 + $626);
  $630 = Math_fround($622 + $627);
  $631 = Math_fround($623 + $628);
  $632 = Math_fround($629 + $605);
  $633 = Math_fround($630 + $606);
  $634 = Math_fround($631 + $607);
  $635 = (($15) + (($i7$080*12)|0)|0);
  HEAPF32[$635>>2] = $632;
  $636 = ((($15) + (($i7$080*12)|0)|0) + 4|0);
  HEAPF32[$636>>2] = $633;
  $637 = ((($15) + (($i7$080*12)|0)|0) + 8|0);
  HEAPF32[$637>>2] = $634;
  $638 = (($i7$080) + 1)|0;
  $exitcond = ($638|0)==($numVerts1|0);
  if ($exitcond) {
   break;
  } else {
   $i7$080 = $638;
  }
 }
 $notlhs = ($numVerts0>>>0)<(2);
 $notrhs = ($numVerts1>>>0)<(2);
 $or$cond$not = $notrhs | $notlhs;
 $brmerge = $or$cond$not | $595;
 if ($brmerge) {
  $$2 = $status$5$off0;
  STACKTOP = sp;return ($$2|0);
 }
 $639 = (($v1) + 4|0);
 $640 = (($v1) + 8|0);
 $641 = (($localPlane0) + 8|0);
 $642 = (($localPlane0) + 4|0);
 $643 = (($plane) + 4|0);
 $644 = (($plane) + 8|0);
 $645 = (($plane) + 12|0);
 $646 = ($numVerts0|0)==(0);
 $647 = (($world0) + 4|0);
 $648 = (($world0) + 8|0);
 $649 = (($p10) + 4|0);
 $650 = (($world0) + 12|0);
 $651 = (($world0) + 16|0);
 $652 = (($world0) + 20|0);
 $653 = (($p10) + 8|0);
 $654 = (($world0) + 24|0);
 $655 = (($world0) + 28|0);
 $656 = (($world0) + 32|0);
 $657 = (($world0) + 36|0);
 $658 = (($world0) + 40|0);
 $659 = (($world0) + 44|0);
 $660 = (($posShift) + 4|0);
 $661 = (($posShift) + 8|0);
 $j$0$ph102 = 0;$status$8$off0$ph103 = $status$5$off0;
 L61: while(1) {
  $j$078 = $j$0$ph102;
  while(1) {
   $663 = (($j$078) + 1)|0;
   $664 = ($663>>>0)>=($numVerts1>>>0);
   $$ = $664 ? 0 : $663;
   $665 = (($18) + ($j$078)|0);
   $666 = HEAP8[$665>>0]|0;
   $667 = ($666<<24>>24)==(0);
   if ($667) {
    label = 46;
   } else {
    $668 = (($18) + ($$)|0);
    $669 = HEAP8[$668>>0]|0;
    $670 = ($669<<24>>24)==(0);
    if ($670) {
     label = 46;
    }
   }
   if ((label|0) == 46) {
    label = 0;
    $672 = (($19) + ($j$078)|0);
    $673 = HEAP8[$672>>0]|0;
    $674 = (($19) + ($$)|0);
    $675 = HEAP8[$674>>0]|0;
    $676 = $675 & $673;
    $677 = ($676<<24>>24)==(0);
    if ($677) {
     break;
    }
   }
   $671 = ($663>>>0)<($numVerts1>>>0);
   if ($671) {
    $j$078 = $663;
   } else {
    $$2 = $status$8$off0$ph103;
    label = 72;
    break L61;
   }
  }
  $678 = (($15) + (($j$078*12)|0)|0);
  $679 = (($15) + (($$*12)|0)|0);
  $680 = Math_fround(HEAPF32[$679>>2]);
  $681 = Math_fround(HEAPF32[$678>>2]);
  $682 = Math_fround($680 - $681);
  $683 = ((($15) + (($$*12)|0)|0) + 4|0);
  $684 = Math_fround(HEAPF32[$683>>2]);
  $685 = ((($15) + (($j$078*12)|0)|0) + 4|0);
  $686 = Math_fround(HEAPF32[$685>>2]);
  $687 = Math_fround($684 - $686);
  $688 = ((($15) + (($$*12)|0)|0) + 8|0);
  $689 = Math_fround(HEAPF32[$688>>2]);
  $690 = ((($15) + (($j$078*12)|0)|0) + 8|0);
  $691 = Math_fround(HEAPF32[$690>>2]);
  $692 = Math_fround($689 - $691);
  HEAPF32[$v1>>2] = $682;
  HEAPF32[$639>>2] = $687;
  HEAPF32[$640>>2] = $692;
  $693 = Math_fround(HEAPF32[$641>>2]);
  $694 = Math_fround($687 * $693);
  $695 = Math_fround(HEAPF32[$642>>2]);
  $696 = Math_fround($692 * $695);
  $697 = Math_fround($694 - $696);
  $698 = Math_fround(HEAPF32[$localPlane0>>2]);
  $699 = Math_fround($692 * $698);
  $700 = Math_fround($693 * $682);
  $701 = Math_fround($699 - $700);
  $702 = Math_fround($695 * $682);
  $703 = Math_fround($687 * $698);
  $704 = Math_fround($702 - $703);
  $705 = Math_fround($697 * $681);
  $706 = Math_fround($701 * $686);
  $707 = Math_fround($705 + $706);
  $708 = Math_fround($704 * $691);
  $709 = Math_fround($707 + $708);
  $710 = Math_fround(-$709);
  HEAPF32[$plane>>2] = $697;
  HEAPF32[$643>>2] = $701;
  HEAPF32[$644>>2] = $704;
  HEAPF32[$645>>2] = $710;
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($697)))));
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($701)))));
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($704)))));
  $711 = $fabsf$i$i1$i > $fabsf$i$i$i;
  $712 = $fabsf$i$i1$i > $fabsf$i$i2$i;
  $or$cond$i = $711 & $712;
  if ($or$cond$i) {
   $715 = 2;$718 = 0;
  } else {
   $713 = $fabsf$i$i2$i > $fabsf$i$i$i;
   if ($713) {
    $715 = 0;$718 = 1;
   } else {
    $715 = 1;$718 = 2;
   }
  }
  $714 = (($v1) + ($715<<2)|0);
  $716 = Math_fround(HEAPF32[$714>>2]);
  $717 = (($localPlane0) + ($718<<2)|0);
  $719 = Math_fround(HEAPF32[$717>>2]);
  $720 = Math_fround($716 * $719);
  $721 = (($v1) + ($718<<2)|0);
  $722 = Math_fround(HEAPF32[$721>>2]);
  $723 = (($localPlane0) + ($715<<2)|0);
  $724 = Math_fround(HEAPF32[$723>>2]);
  $725 = Math_fround($722 * $724);
  $726 = Math_fround($720 - $725);
  $727 = Math_fround(Math_fround(1.0) / $726);
  L75: do {
   if ($646) {
    $status$9$off0$ph73 = $status$8$off0$ph103;
   } else {
    if ($flipNormal) {
     $i8$0$ph74$us = 0;$status$9$off0$ph75$us = $status$8$off0$ph103;
     while(1) {
      $i8$071$us = $i8$0$ph74$us;
      while(1) {
       $728 = (($i8$071$us) + 1)|0;
       $729 = ($728>>>0)>=($numVerts0>>>0);
       $$1$us = $729 ? 0 : $728;
       $730 = (($16) + ($i8$071$us)|0);
       $731 = HEAP8[$730>>0]|0;
       $732 = ($731<<24>>24)==(0);
       if ($732) {
        label = 55;
       } else {
        $733 = (($16) + ($$1$us)|0);
        $734 = HEAP8[$733>>0]|0;
        $735 = ($734<<24>>24)==(0);
        if ($735) {
         label = 55;
        }
       }
       if ((label|0) == 55) {
        label = 0;
        $736 = (($17) + ($i8$071$us)|0);
        $737 = HEAP8[$736>>0]|0;
        $738 = (($17) + ($$1$us)|0);
        $739 = HEAP8[$738>>0]|0;
        $740 = $739 & $737;
        $741 = ($740<<24>>24)==(0);
        if ($741) {
         $742 = (($indices0) + ($i8$071$us)|0);
         $743 = HEAP8[$742>>0]|0;
         $744 = $743&255;
         $745 = (($vertices0) + (($744*12)|0)|0);
         $746 = (($indices0) + ($$1$us)|0);
         $747 = HEAP8[$746>>0]|0;
         $748 = $747&255;
         $749 = (($vertices0) + (($748*12)|0)|0);
         $750 = (__Z22EdgeEdgeContactSpecialRKN5physx6PxVec3ERKNS_7PxPlaneES2_S2_S2_S2_S2_RfRS0_iif($v1,$plane,$678,$679,$localPlane0,$745,$749,$dist,$p10,$715,$718,$727)|0);
         if ($750) {
          break;
         }
        }
       }
       $802 = ($728>>>0)<($numVerts0>>>0);
       if ($802) {
        $i8$071$us = $728;
       } else {
        $status$9$off0$ph73 = $status$9$off0$ph75$us;
        break L75;
       }
      }
      $751 = HEAP32[$20>>2]|0;
      $752 = ($751>>>0)>(63);
      if (!($752)) {
       $753 = (($751) + 1)|0;
       HEAP32[$20>>2] = $753;
       $754 = (($contactBuffer) + ($751<<6)|0);
       $755 = ($754|0)==(0|0);
       if (!($755)) {
        HEAPF32[$754>>2] = $233;
        $756 = ((($contactBuffer) + ($751<<6)|0) + 4|0);
        HEAPF32[$756>>2] = $235;
        $757 = ((($contactBuffer) + ($751<<6)|0) + 8|0);
        HEAPF32[$757>>2] = $237;
        $758 = Math_fround(HEAPF32[$p10>>2]);
        $759 = Math_fround(HEAPF32[$world0>>2]);
        $760 = Math_fround($758 * $759);
        $761 = Math_fround(HEAPF32[$647>>2]);
        $762 = Math_fround($758 * $761);
        $763 = Math_fround(HEAPF32[$648>>2]);
        $764 = Math_fround($758 * $763);
        $765 = Math_fround(HEAPF32[$649>>2]);
        $766 = Math_fround(HEAPF32[$650>>2]);
        $767 = Math_fround($765 * $766);
        $768 = Math_fround(HEAPF32[$651>>2]);
        $769 = Math_fround($765 * $768);
        $770 = Math_fround(HEAPF32[$652>>2]);
        $771 = Math_fround($765 * $770);
        $772 = Math_fround($760 + $767);
        $773 = Math_fround($762 + $769);
        $774 = Math_fround($764 + $771);
        $775 = Math_fround(HEAPF32[$653>>2]);
        $776 = Math_fround(HEAPF32[$654>>2]);
        $777 = Math_fround($775 * $776);
        $778 = Math_fround(HEAPF32[$655>>2]);
        $779 = Math_fround($775 * $778);
        $780 = Math_fround(HEAPF32[$656>>2]);
        $781 = Math_fround($775 * $780);
        $782 = Math_fround($772 + $777);
        $783 = Math_fround($773 + $779);
        $784 = Math_fround($774 + $781);
        $785 = Math_fround(HEAPF32[$657>>2]);
        $786 = Math_fround($782 + $785);
        $787 = Math_fround(HEAPF32[$658>>2]);
        $788 = Math_fround($783 + $787);
        $789 = Math_fround(HEAPF32[$659>>2]);
        $790 = Math_fround($784 + $789);
        $791 = Math_fround($786 + Math_fround(0.0));
        $792 = Math_fround($788 + Math_fround(0.0));
        $793 = Math_fround($790 + Math_fround(0.0));
        $794 = ((($contactBuffer) + ($751<<6)|0) + 16|0);
        HEAPF32[$794>>2] = $791;
        $795 = ((($contactBuffer) + ($751<<6)|0) + 20|0);
        HEAPF32[$795>>2] = $792;
        $796 = ((($contactBuffer) + ($751<<6)|0) + 24|0);
        HEAPF32[$796>>2] = $793;
        $797 = Math_fround(HEAPF32[$dist>>2]);
        $798 = Math_fround($sepShift - $797);
        $799 = ((($contactBuffer) + ($751<<6)|0) + 12|0);
        HEAPF32[$799>>2] = $798;
        $800 = ((($contactBuffer) + ($751<<6)|0) + 48|0);
        HEAP32[$800>>2] = $polyIndex0;
        $801 = ((($contactBuffer) + ($751<<6)|0) + 52|0);
        HEAP32[$801>>2] = $polyIndex1;
       }
      }
      $803 = ($728>>>0)<($numVerts0>>>0);
      if ($803) {
       $i8$0$ph74$us = $728;$status$9$off0$ph75$us = 1;
      } else {
       $status$9$off0$ph73 = 1;
       break;
      }
     }
    } else {
     $i8$0$ph74 = 0;$status$9$off0$ph75 = $status$8$off0$ph103;
     while(1) {
      $i8$071 = $i8$0$ph74;
      while(1) {
       $804 = (($i8$071) + 1)|0;
       $805 = ($804>>>0)>=($numVerts0>>>0);
       $$1 = $805 ? 0 : $804;
       $806 = (($16) + ($i8$071)|0);
       $807 = HEAP8[$806>>0]|0;
       $808 = ($807<<24>>24)==(0);
       if ($808) {
        label = 66;
       } else {
        $809 = (($16) + ($$1)|0);
        $810 = HEAP8[$809>>0]|0;
        $811 = ($810<<24>>24)==(0);
        if ($811) {
         label = 66;
        }
       }
       if ((label|0) == 66) {
        label = 0;
        $813 = (($17) + ($i8$071)|0);
        $814 = HEAP8[$813>>0]|0;
        $815 = (($17) + ($$1)|0);
        $816 = HEAP8[$815>>0]|0;
        $817 = $816 & $814;
        $818 = ($817<<24>>24)==(0);
        if ($818) {
         $819 = (($indices0) + ($i8$071)|0);
         $820 = HEAP8[$819>>0]|0;
         $821 = $820&255;
         $822 = (($vertices0) + (($821*12)|0)|0);
         $823 = (($indices0) + ($$1)|0);
         $824 = HEAP8[$823>>0]|0;
         $825 = $824&255;
         $826 = (($vertices0) + (($825*12)|0)|0);
         $827 = (__Z22EdgeEdgeContactSpecialRKN5physx6PxVec3ERKNS_7PxPlaneES2_S2_S2_S2_S2_RfRS0_iif($v1,$plane,$678,$679,$localPlane0,$822,$826,$dist,$p10,$715,$718,$727)|0);
         if ($827) {
          break;
         }
        }
       }
       $812 = ($804>>>0)<($numVerts0>>>0);
       if ($812) {
        $i8$071 = $804;
       } else {
        $status$9$off0$ph73 = $status$9$off0$ph75;
        break L75;
       }
      }
      $828 = HEAP32[$20>>2]|0;
      $829 = ($828>>>0)>(63);
      if (!($829)) {
       $830 = (($828) + 1)|0;
       HEAP32[$20>>2] = $830;
       $831 = (($contactBuffer) + ($828<<6)|0);
       $832 = ($831|0)==(0|0);
       if (!($832)) {
        HEAPF32[$831>>2] = $233;
        $834 = ((($contactBuffer) + ($828<<6)|0) + 4|0);
        HEAPF32[$834>>2] = $235;
        $835 = ((($contactBuffer) + ($828<<6)|0) + 8|0);
        HEAPF32[$835>>2] = $237;
        $836 = Math_fround(HEAPF32[$p10>>2]);
        $837 = Math_fround(HEAPF32[$world0>>2]);
        $838 = Math_fround($836 * $837);
        $839 = Math_fround(HEAPF32[$647>>2]);
        $840 = Math_fround($836 * $839);
        $841 = Math_fround(HEAPF32[$648>>2]);
        $842 = Math_fround($836 * $841);
        $843 = Math_fround(HEAPF32[$649>>2]);
        $844 = Math_fround(HEAPF32[$650>>2]);
        $845 = Math_fround($843 * $844);
        $846 = Math_fround(HEAPF32[$651>>2]);
        $847 = Math_fround($843 * $846);
        $848 = Math_fround(HEAPF32[$652>>2]);
        $849 = Math_fround($843 * $848);
        $850 = Math_fround($838 + $845);
        $851 = Math_fround($840 + $847);
        $852 = Math_fround($842 + $849);
        $853 = Math_fround(HEAPF32[$653>>2]);
        $854 = Math_fround(HEAPF32[$654>>2]);
        $855 = Math_fround($853 * $854);
        $856 = Math_fround(HEAPF32[$655>>2]);
        $857 = Math_fround($853 * $856);
        $858 = Math_fround(HEAPF32[$656>>2]);
        $859 = Math_fround($853 * $858);
        $860 = Math_fround($850 + $855);
        $861 = Math_fround($851 + $857);
        $862 = Math_fround($852 + $859);
        $863 = Math_fround(HEAPF32[$657>>2]);
        $864 = Math_fround($860 + $863);
        $865 = Math_fround(HEAPF32[$658>>2]);
        $866 = Math_fround($861 + $865);
        $867 = Math_fround(HEAPF32[$659>>2]);
        $868 = Math_fround($862 + $867);
        $869 = Math_fround(HEAPF32[$posShift>>2]);
        $870 = Math_fround(HEAPF32[$660>>2]);
        $871 = Math_fround(HEAPF32[$661>>2]);
        $872 = Math_fround($864 + $869);
        $873 = Math_fround($866 + $870);
        $874 = Math_fround($868 + $871);
        $875 = ((($contactBuffer) + ($828<<6)|0) + 16|0);
        HEAPF32[$875>>2] = $872;
        $876 = ((($contactBuffer) + ($828<<6)|0) + 20|0);
        HEAPF32[$876>>2] = $873;
        $877 = ((($contactBuffer) + ($828<<6)|0) + 24|0);
        HEAPF32[$877>>2] = $874;
        $878 = Math_fround(HEAPF32[$dist>>2]);
        $879 = Math_fround($sepShift - $878);
        $880 = ((($contactBuffer) + ($828<<6)|0) + 12|0);
        HEAPF32[$880>>2] = $879;
        $881 = ((($contactBuffer) + ($828<<6)|0) + 48|0);
        HEAP32[$881>>2] = $polyIndex0;
        $882 = ((($contactBuffer) + ($828<<6)|0) + 52|0);
        HEAP32[$882>>2] = $polyIndex1;
       }
      }
      $833 = ($804>>>0)<($numVerts0>>>0);
      if ($833) {
       $i8$0$ph74 = $804;$status$9$off0$ph75 = 1;
      } else {
       $status$9$off0$ph73 = 1;
       break;
      }
     }
    }
   }
  } while(0);
  $662 = ($663>>>0)<($numVerts1>>>0);
  if ($662) {
   $j$0$ph102 = $663;$status$8$off0$ph103 = $status$9$off0$ph73;
  } else {
   $$2 = $status$9$off0$ph73;
   label = 72;
   break;
  }
 }
 if ((label|0) == 72) {
  STACKTOP = sp;return ($$2|0);
 }
 return 0|0;
}
function __ZL17transformVerticesRfS_S_S_PfjPKN5physx6PxVec3EPKhRKNS1_7PxMat33E($minX,$minY,$maxX,$maxY,$verts2D,$nb,$vertices,$indices,$RotT) {
 $minX = $minX|0;
 $minY = $minY|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 $verts2D = $verts2D|0;
 $nb = $nb|0;
 $vertices = $vertices|0;
 $indices = $indices|0;
 $RotT = $RotT|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $exitcond = 0, $exitcond16 = 0, $i$02 = 0, $i1$01 = 0, $lmaxX$0$lcssa = Math_fround(0), $lmaxX$04 = Math_fround(0), $lmaxY$0$lcssa = Math_fround(0), $lmaxY$03 = Math_fround(0), $lminX$0$lcssa = Math_fround(0);
 var $lminX$06 = Math_fround(0), $lminY$0$lcssa = Math_fround(0), $lminY$05 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nb|0)==(0);
 if ($0) {
  $lmaxX$0$lcssa = Math_fround(-3.40282346638528859812E+38);$lmaxY$0$lcssa = Math_fround(-3.40282346638528859812E+38);$lminX$0$lcssa = Math_fround(3.40282346638528859812E+38);$lminY$0$lcssa = Math_fround(3.40282346638528859812E+38);
 } else {
  $1 = (($RotT) + 4|0);
  $2 = (($RotT) + 8|0);
  $3 = (($RotT) + 12|0);
  $4 = (($RotT) + 16|0);
  $5 = (($RotT) + 20|0);
  $i$02 = 0;$lmaxX$04 = Math_fround(-3.40282346638528859812E+38);$lmaxY$03 = Math_fround(-3.40282346638528859812E+38);$lminX$06 = Math_fround(3.40282346638528859812E+38);$lminY$05 = Math_fround(3.40282346638528859812E+38);
  while(1) {
   $6 = (($indices) + ($i$02)|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = $7&255;
   $9 = Math_fround(HEAPF32[$RotT>>2]);
   $10 = (($vertices) + (($8*12)|0)|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = Math_fround($9 * $11);
   $13 = Math_fround(HEAPF32[$1>>2]);
   $14 = ((($vertices) + (($8*12)|0)|0) + 4|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($13 * $15);
   $17 = Math_fround($12 + $16);
   $18 = Math_fround(HEAPF32[$2>>2]);
   $19 = ((($vertices) + (($8*12)|0)|0) + 8|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround($18 * $20);
   $22 = Math_fround($17 + $21);
   $23 = Math_fround(HEAPF32[$3>>2]);
   $24 = Math_fround($11 * $23);
   $25 = Math_fround(HEAPF32[$4>>2]);
   $26 = Math_fround($15 * $25);
   $27 = Math_fround($24 + $26);
   $28 = Math_fround(HEAPF32[$5>>2]);
   $29 = Math_fround($20 * $28);
   $30 = Math_fround($27 + $29);
   $31 = $lminX$06 < $22;
   $32 = $31 ? $lminX$06 : $22;
   $33 = $lminY$05 < $30;
   $34 = $33 ? $lminY$05 : $30;
   $35 = $lmaxX$04 > $22;
   $36 = $35 ? $lmaxX$04 : $22;
   $37 = $lmaxY$03 > $30;
   $38 = $37 ? $lmaxY$03 : $30;
   $39 = $i$02 << 1;
   $40 = (($verts2D) + ($39<<2)|0);
   HEAPF32[$40>>2] = $22;
   $41 = $39 | 1;
   $42 = (($verts2D) + ($41<<2)|0);
   HEAPF32[$42>>2] = $30;
   $43 = (($i$02) + 1)|0;
   $exitcond16 = ($43|0)==($nb|0);
   if ($exitcond16) {
    $lmaxX$0$lcssa = $36;$lmaxY$0$lcssa = $38;$lminX$0$lcssa = $32;$lminY$0$lcssa = $34;
    break;
   } else {
    $i$02 = $43;$lmaxX$04 = $36;$lmaxY$03 = $38;$lminX$06 = $32;$lminY$05 = $34;
   }
  }
 }
 $44 = Math_fround($lmaxX$0$lcssa + $lminX$0$lcssa);
 $45 = Math_fround($44 * Math_fround(0.5));
 $46 = Math_fround($lmaxY$0$lcssa + $lminY$0$lcssa);
 $47 = Math_fround($46 * Math_fround(0.5));
 $48 = Math_fround($lminX$0$lcssa + Math_fround(-9.99999997475242707878E-7));
 $49 = Math_fround($lminY$0$lcssa + Math_fround(-9.99999997475242707878E-7));
 $50 = Math_fround($lmaxX$0$lcssa + Math_fround(9.99999997475242707878E-7));
 $51 = Math_fround($lmaxY$0$lcssa + Math_fround(9.99999997475242707878E-7));
 if ($0) {
  $69 = Math_fround($50 - $48);
  $70 = Math_fround($51 - $49);
  HEAPF32[$minX>>2] = $48;
  HEAPF32[$minY>>2] = $49;
  HEAPF32[$maxX>>2] = $69;
  HEAPF32[$maxY>>2] = $70;
  STACKTOP = sp;return;
 } else {
  $i1$01 = 0;
 }
 while(1) {
  $52 = $i1$01 << 1;
  $53 = (($verts2D) + ($52<<2)|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = $52 | 1;
  $56 = (($verts2D) + ($55<<2)|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($54 - $45);
  $59 = Math_fround($57 - $47);
  $60 = Math_fround($54 - $48);
  $61 = $58 >= Math_fround(0.0);
  $62 = $61 ? Math_fround(9.99999997475242707878E-7) : Math_fround(-9.99999997475242707878E-7);
  $63 = Math_fround($60 + $62);
  HEAPF32[$53>>2] = $63;
  $64 = Math_fround($57 - $49);
  $65 = $59 >= Math_fround(0.0);
  $66 = $65 ? Math_fround(9.99999997475242707878E-7) : Math_fround(-9.99999997475242707878E-7);
  $67 = Math_fround($64 + $66);
  HEAPF32[$56>>2] = $67;
  $68 = (($i1$01) + 1)|0;
  $exitcond = ($68|0)==($nb|0);
  if ($exitcond) {
   break;
  } else {
   $i1$01 = $68;
  }
 }
 $69 = Math_fround($50 - $48);
 $70 = Math_fround($51 - $49);
 HEAPF32[$minX>>2] = $48;
 HEAPF32[$minY>>2] = $49;
 HEAPF32[$maxX>>2] = $69;
 HEAPF32[$maxY>>2] = $70;
 STACKTOP = sp;return;
}
function __ZL31PointInConvexPolygon2D_OutCodesPKfjffffRh($pgon2D,$numVerts,$tx,$ty,$maxX,$maxY,$outCodes) {
 $pgon2D = $pgon2D|0;
 $numVerts = $numVerts|0;
 $tx = Math_fround($tx);
 $ty = Math_fround($ty);
 $maxX = Math_fround($maxX);
 $maxY = Math_fround($maxY);
 $outCodes = $outCodes|0;
 var $$0 = 0, $$in = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0;
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $InsideFlag$0$lcssa = 0, $InsideFlag$06 = 0, $InsideFlag$1 = 0, $ivtx0$04 = 0, $ivtx0$04$phi = 0, $ivtx1$03 = 0, $or$cond$i = 0, $or$cond1$i = 0;
 var $out$0 = 0, $out$1 = 0, $out$2 = 0, $out$3 = 0, $tmp = 0, $yflag0$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (HEAPF32[tempDoublePtr>>2]=$ty,HEAP32[tempDoublePtr>>2]|0);
 $1 = $tx < Math_fround(0.0);
 $out$0 = $1 ? 2 : 0;
 $2 = $ty < Math_fround(0.0);
 $3 = $out$0 | 8;
 $out$1 = $2 ? $3 : $out$0;
 $4 = $tx > $maxX;
 $5 = $4&1;
 $out$2 = $out$1 | $5;
 $6 = $ty > $maxY;
 $7 = $out$2 | 4;
 $out$3 = $6 ? $7 : $out$2;
 $8 = $out$3&255;
 HEAP8[$outCodes>>0] = $8;
 $9 = ($out$3|0)==(0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ($numVerts|0)==(3);
 if ($10) {
  $11 = Math_fround(HEAPF32[$pgon2D>>2]);
  $12 = (($pgon2D) + 4|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($pgon2D) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($15 - $11);
  $17 = (($pgon2D) + 12|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($18 - $13);
  $20 = (($pgon2D) + 16|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($21 - $11);
  $23 = (($pgon2D) + 20|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($24 - $13);
  $26 = Math_fround($16 * $16);
  $27 = Math_fround($19 * $19);
  $28 = Math_fround($26 + $27);
  $29 = Math_fround($16 * $22);
  $30 = Math_fround($19 * $25);
  $31 = Math_fround($29 + $30);
  $32 = Math_fround($22 * $22);
  $33 = Math_fround($25 * $25);
  $34 = Math_fround($32 + $33);
  $35 = Math_fround($28 * $34);
  $36 = Math_fround($31 * $31);
  $37 = Math_fround($35 - $36);
  $38 = Math_fround($tx - $11);
  $39 = Math_fround($ty - $13);
  $40 = Math_fround($38 * $16);
  $41 = Math_fround($39 * $19);
  $42 = Math_fround($40 + $41);
  $43 = Math_fround($38 * $22);
  $44 = Math_fround($39 * $25);
  $45 = Math_fround($43 + $44);
  $46 = Math_fround($42 * $34);
  $47 = Math_fround($45 * $31);
  $48 = Math_fround($46 - $47);
  $49 = Math_fround($28 * $45);
  $50 = Math_fround($42 * $31);
  $51 = Math_fround($49 - $50);
  $52 = Math_fround($48 + $51);
  $53 = Math_fround($52 - $37);
  $54 = $48 > Math_fround(0.0);
  $55 = $51 > Math_fround(0.0);
  $or$cond$i = $54 & $55;
  $56 = $53 < Math_fround(0.0);
  $or$cond1$i = $or$cond$i & $56;
  $$0 = $or$cond1$i;
  STACKTOP = sp;return ($$0|0);
 }
 $57 = $numVerts << 1;
 $58 = ($numVerts|0)==(0);
 L8: do {
  if ($58) {
   $InsideFlag$0$lcssa = 0;
  } else {
   $$sum = (($57) + -1)|0;
   $59 = (($pgon2D) + ($$sum<<2)|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($57) + -2)|0;
   $62 = ($60|0)>=($0|0);
   $63 = (($pgon2D) + ($61<<2)|0);
   $64 = $62&1;
   $$in = $numVerts;$InsideFlag$06 = 0;$ivtx0$04 = $63;$ivtx1$03 = $pgon2D;$yflag0$05 = $64;
   while(1) {
    $65 = (($$in) + -1)|0;
    $66 = (($ivtx1$03) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($67|0)>=($0|0);
    $69 = $68&1;
    $70 = ($yflag0$05|0)==($69|0);
    $71 = (HEAP32[tempDoublePtr>>2]=$67,Math_fround(HEAPF32[tempDoublePtr>>2]));
    if ($70) {
     $InsideFlag$1 = $InsideFlag$06;
    } else {
     $72 = Math_fround($71 - $ty);
     $73 = Math_fround(HEAPF32[$ivtx0$04>>2]);
     $74 = Math_fround(HEAPF32[$ivtx1$03>>2]);
     $75 = Math_fround($73 - $74);
     $76 = Math_fround($72 * $75);
     $77 = Math_fround($74 - $tx);
     $78 = (($ivtx0$04) + 4|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $80 = Math_fround($79 - $71);
     $81 = Math_fround($77 * $80);
     $82 = $76 > $81;
     $tmp = $82 ^ $68;
     if ($tmp) {
      $InsideFlag$1 = $InsideFlag$06;
     } else {
      $83 = ($InsideFlag$06|0)==(1);
      if ($83) {
       $$0 = 0;
       break;
      }
      $84 = (($InsideFlag$06) + 1)|0;
      $InsideFlag$1 = $84;
     }
    }
    $85 = (($ivtx1$03) + 8|0);
    $86 = ($65|0)==(0);
    if ($86) {
     $InsideFlag$0$lcssa = $InsideFlag$1;
     break L8;
    } else {
     $ivtx0$04$phi = $ivtx1$03;$$in = $65;$InsideFlag$06 = $InsideFlag$1;$ivtx1$03 = $85;$yflag0$05 = $69;$ivtx0$04 = $ivtx0$04$phi;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $87 = $InsideFlag$0$lcssa & 1;
 $88 = ($87|0)!=(0);
 $$0 = $88;
 STACKTOP = sp;return ($$0|0);
}
function __ZL21ContactReductionAllInRN5physx2Gu13ContactBufferEjjRKNS_7PxMat33EPKNS_6PxVec3EPKh($contactBuffer,$nbExistingContacts,$numIn,$rotT,$vertices,$indices) {
 $contactBuffer = $contactBuffer|0;
 $nbExistingContacts = $nbExistingContacts|0;
 $numIn = $numIn|0;
 $rotT = $rotT|0;
 $vertices = $vertices|0;
 $indices = $indices|0;
 var $$idx = 0, $$idx$val = Math_fround(0), $$idx18 = 0, $$idx18$val = Math_fround(0), $$indexMaxU$0 = 0, $$needsExtraPoint$0$off0 = 0, $$pre = Math_fround(0), $$pre68 = Math_fround(0), $$pre69 = Math_fround(0), $$pre70 = Math_fround(0), $$pre71 = Math_fround(0), $$pre72 = Math_fround(0), $$pre73 = Math_fround(0), $$pre74 = Math_fround(0), $$pre75 = Math_fround(0), $$pre76 = Math_fround(0), $$pre77 = Math_fround(0), $$pre78 = Math_fround(0), $$pre79 = Math_fround(0), $$pre80 = Math_fround(0);
 var $$pre81 = Math_fround(0), $$pre82 = Math_fround(0), $$sum = 0, $$sum1 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0;
 var $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0;
 var $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0);
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0;
 var $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0;
 var $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0;
 var $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $bestAxis$1 = 0, $bestAxis$1$1 = 0, $bestAxis$1$2 = 0, $bestAxis$1$3 = 0, $bestAxis$1$4 = 0, $bestAxis$1$5 = 0, $bestAxis$1$6 = 0, $deepestIndex$0$lcssa = 0, $deepestIndex$024 = 0, $deepestIndex$1 = 0, $deepestSeparation$025 = Math_fround(0), $deepestSeparation$1 = Math_fround(0), $dirs = 0, $dpmax = 0, $dpmaxu$033 = Math_fround(0), $dpmaxu$1 = Math_fround(0), $dpmaxv$035 = Math_fround(0), $dpmaxv$1 = Math_fround(0);
 var $dpmin = 0, $dpminu$032 = Math_fround(0), $dpminu$1 = Math_fround(0), $dpminv$034 = Math_fround(0), $dpminv$1 = Math_fround(0), $exitcond = 0, $exitcond60 = 0, $exitcond61 = 0, $exitcond62 = 0, $exitcond64 = 0, $exitcond65 = 0, $i$023 = 0, $i1$020 = 0, $i4$052 = 0, $i6$040 = 0, $i9$027 = 0, $index$022 = 0, $indexMaxU$0$lcssa = 0, $indexMaxU$037 = 0, $indexMaxU$1 = 0;
 var $indexMaxV$0$lcssa = 0, $indexMaxV$039 = 0, $indexMaxV$1 = 0, $indexMaxV$2 = 0, $indexMinU$0$lcssa = 0, $indexMinU$036 = 0, $indexMinU$1 = 0, $indexMinV$0$lcssa = 0, $indexMinV$038 = 0, $indexMinV$1 = 0, $indexMinV$2 = 0, $j$051 = 0, $maxVariance$1 = Math_fround(0), $maxVariance$1$1 = Math_fround(0), $maxVariance$1$2 = Math_fround(0), $maxVariance$1$3 = Math_fround(0), $maxVariance$1$4 = Math_fround(0), $maxVariance$1$5 = Math_fround(0), $needsExtraPoint$0$off021 = 0, $newCount$0$lcssa = 0;
 var $newCount$026 = 0, $newCount$1 = 0, $not$ = 0, $or$cond = 0, $or$cond10 = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond8 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $dirs = sp + 64|0;
 $dpmin = sp;
 $dpmax = sp + 32|0;
 $0 = (($contactBuffer) + 4096|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($nbExistingContacts))|0;
 $3 = ($2>>>0)<(5);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)==($numIn|0);
 if ($4) {
  $5 = ($numIn>>>0)>(1);
  if ($5) {
   $6 = ((($contactBuffer) + ($nbExistingContacts<<6)|0) + 12|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $deepestIndex$024 = 0;$deepestSeparation$025 = $7;$i$023 = 1;
   while(1) {
    $$sum7 = (($i$023) + ($nbExistingContacts))|0;
    $8 = ((($contactBuffer) + ($$sum7<<6)|0) + 12|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = $deepestSeparation$025 > $9;
    $deepestIndex$1 = $10 ? $i$023 : $deepestIndex$024;
    $deepestSeparation$1 = $10 ? $9 : $deepestSeparation$025;
    $11 = (($i$023) + 1)|0;
    $exitcond60 = ($11|0)==($numIn|0);
    if ($exitcond60) {
     $deepestIndex$0$lcssa = $deepestIndex$1;
     break;
    } else {
     $deepestIndex$024 = $deepestIndex$1;$deepestSeparation$025 = $deepestSeparation$1;$i$023 = $11;
    }
   }
  } else {
   $deepestIndex$0$lcssa = 0;
  }
  $12 = $numIn << 14;
  $13 = $12 & 1073725440;
  $i1$020 = 0;$index$022 = 0;$needsExtraPoint$0$off021 = 1;
  while(1) {
   $14 = $index$022 >>> 16;
   $$sum5 = (($i1$020) + ($nbExistingContacts))|0;
   $$sum6 = (($14) + ($nbExistingContacts))|0;
   $15 = (($contactBuffer) + ($$sum6<<6)|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = (($contactBuffer) + ($$sum5<<6)|0);
   HEAPF32[$17>>2] = $16;
   $18 = ((($contactBuffer) + ($$sum6<<6)|0) + 4|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = ((($contactBuffer) + ($$sum5<<6)|0) + 4|0);
   HEAPF32[$20>>2] = $19;
   $21 = ((($contactBuffer) + ($$sum6<<6)|0) + 8|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = ((($contactBuffer) + ($$sum5<<6)|0) + 8|0);
   HEAPF32[$23>>2] = $22;
   $24 = ((($contactBuffer) + ($$sum6<<6)|0) + 12|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = ((($contactBuffer) + ($$sum5<<6)|0) + 12|0);
   HEAPF32[$26>>2] = $25;
   $27 = ((($contactBuffer) + ($$sum6<<6)|0) + 16|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = ((($contactBuffer) + ($$sum5<<6)|0) + 16|0);
   HEAPF32[$29>>2] = $28;
   $30 = ((($contactBuffer) + ($$sum6<<6)|0) + 20|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = ((($contactBuffer) + ($$sum5<<6)|0) + 20|0);
   HEAPF32[$32>>2] = $31;
   $33 = ((($contactBuffer) + ($$sum6<<6)|0) + 24|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = ((($contactBuffer) + ($$sum5<<6)|0) + 24|0);
   HEAPF32[$35>>2] = $34;
   $36 = ((($contactBuffer) + ($$sum6<<6)|0) + 28|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = ((($contactBuffer) + ($$sum5<<6)|0) + 28|0);
   HEAPF32[$38>>2] = $37;
   $39 = ((($contactBuffer) + ($$sum6<<6)|0) + 32|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = ((($contactBuffer) + ($$sum5<<6)|0) + 32|0);
   HEAPF32[$41>>2] = $40;
   $42 = ((($contactBuffer) + ($$sum6<<6)|0) + 36|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = ((($contactBuffer) + ($$sum5<<6)|0) + 36|0);
   HEAPF32[$44>>2] = $43;
   $45 = ((($contactBuffer) + ($$sum6<<6)|0) + 40|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = ((($contactBuffer) + ($$sum5<<6)|0) + 40|0);
   HEAPF32[$47>>2] = $46;
   $48 = ((($contactBuffer) + ($$sum5<<6)|0) + 44|0);
   $49 = ((($contactBuffer) + ($$sum6<<6)|0) + 44|0);
   ;HEAP32[$48+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$48+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$48+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$48+12>>2]=HEAP32[$49+12>>2]|0;HEAP32[$48+16>>2]=HEAP32[$49+16>>2]|0;
   $not$ = ($14|0)!=($deepestIndex$0$lcssa|0);
   $$needsExtraPoint$0$off0 = $needsExtraPoint$0$off021 & $not$;
   $50 = (($index$022) + ($13))|0;
   $51 = (($i1$020) + 1)|0;
   $exitcond = ($51|0)==(4);
   if ($exitcond) {
    break;
   } else {
    $i1$020 = $51;$index$022 = $50;$needsExtraPoint$0$off021 = $$needsExtraPoint$0$off0;
   }
  }
  $$sum3 = (($nbExistingContacts) + 4)|0;
  if ($$needsExtraPoint$0$off0) {
   $$sum4 = (($deepestIndex$0$lcssa) + ($nbExistingContacts))|0;
   $52 = (($contactBuffer) + ($$sum4<<6)|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = (($contactBuffer) + ($$sum3<<6)|0);
   HEAPF32[$54>>2] = $53;
   $55 = ((($contactBuffer) + ($$sum4<<6)|0) + 4|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = ((($contactBuffer) + ($$sum3<<6)|0) + 4|0);
   HEAPF32[$57>>2] = $56;
   $58 = ((($contactBuffer) + ($$sum4<<6)|0) + 8|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = ((($contactBuffer) + ($$sum3<<6)|0) + 8|0);
   HEAPF32[$60>>2] = $59;
   $61 = ((($contactBuffer) + ($$sum4<<6)|0) + 12|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = ((($contactBuffer) + ($$sum3<<6)|0) + 12|0);
   HEAPF32[$63>>2] = $62;
   $64 = ((($contactBuffer) + ($$sum4<<6)|0) + 16|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = ((($contactBuffer) + ($$sum3<<6)|0) + 16|0);
   HEAPF32[$66>>2] = $65;
   $67 = ((($contactBuffer) + ($$sum4<<6)|0) + 20|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = ((($contactBuffer) + ($$sum3<<6)|0) + 20|0);
   HEAPF32[$69>>2] = $68;
   $70 = ((($contactBuffer) + ($$sum4<<6)|0) + 24|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = ((($contactBuffer) + ($$sum3<<6)|0) + 24|0);
   HEAPF32[$72>>2] = $71;
   $73 = ((($contactBuffer) + ($$sum4<<6)|0) + 28|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = ((($contactBuffer) + ($$sum3<<6)|0) + 28|0);
   HEAPF32[$75>>2] = $74;
   $76 = ((($contactBuffer) + ($$sum4<<6)|0) + 32|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = ((($contactBuffer) + ($$sum3<<6)|0) + 32|0);
   HEAPF32[$78>>2] = $77;
   $79 = ((($contactBuffer) + ($$sum4<<6)|0) + 36|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = ((($contactBuffer) + ($$sum3<<6)|0) + 36|0);
   HEAPF32[$81>>2] = $80;
   $82 = ((($contactBuffer) + ($$sum4<<6)|0) + 40|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = ((($contactBuffer) + ($$sum3<<6)|0) + 40|0);
   HEAPF32[$84>>2] = $83;
   $85 = ((($contactBuffer) + ($$sum3<<6)|0) + 44|0);
   $86 = ((($contactBuffer) + ($$sum4<<6)|0) + 44|0);
   ;HEAP32[$85+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$86+8>>2]|0;HEAP32[$85+12>>2]=HEAP32[$86+12>>2]|0;HEAP32[$85+16>>2]=HEAP32[$86+16>>2]|0;
   $87 = (($nbExistingContacts) + 5)|0;
   HEAP32[$0>>2] = $87;
   STACKTOP = sp;return;
  } else {
   HEAP32[$0>>2] = $$sum3;
   STACKTOP = sp;return;
  }
 }
 HEAPF32[$dirs>>2] = Math_fround(1.0);
 $88 = (($dirs) + 4|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($dirs) + 8|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 $90 = (($dirs) + 12|0);
 HEAPF32[$90>>2] = Math_fround(0.923879504203796386718);
 $91 = (($dirs) + 16|0);
 HEAPF32[$91>>2] = Math_fround(0.382683455944061279297);
 $92 = (($dirs) + 20|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $93 = (($dirs) + 24|0);
 HEAPF32[$93>>2] = Math_fround(0.707106769084930419921);
 $94 = (($dirs) + 28|0);
 HEAPF32[$94>>2] = Math_fround(0.707106769084930419921);
 $95 = (($dirs) + 32|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($dirs) + 36|0);
 HEAPF32[$96>>2] = Math_fround(0.382683426141738891602);
 $97 = (($dirs) + 40|0);
 HEAPF32[$97>>2] = Math_fround(0.923879504203796386718);
 $98 = (($dirs) + 44|0);
 HEAPF32[$98>>2] = Math_fround(0.0);
 $99 = (($dirs) + 48|0);
 HEAPF32[$99>>2] = Math_fround(-4.37113882867379288655E-8);
 $100 = (($dirs) + 52|0);
 HEAPF32[$100>>2] = Math_fround(1.0);
 $101 = (($dirs) + 56|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = (($dirs) + 60|0);
 HEAPF32[$102>>2] = Math_fround(-0.382683515548706054688);
 $103 = (($dirs) + 64|0);
 HEAPF32[$103>>2] = Math_fround(0.923879504203796386718);
 $104 = (($dirs) + 68|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($dirs) + 72|0);
 HEAPF32[$105>>2] = Math_fround(-0.707106769084930419921);
 $106 = (($dirs) + 76|0);
 HEAPF32[$106>>2] = Math_fround(0.707106769084930419921);
 $107 = (($dirs) + 80|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($dirs) + 84|0);
 HEAPF32[$108>>2] = Math_fround(-0.923879504203796386718);
 $109 = (($dirs) + 88|0);
 HEAPF32[$109>>2] = Math_fround(0.382683485746383666992);
 $110 = (($dirs) + 92|0);
 HEAPF32[$110>>2] = Math_fround(0.0);
 HEAPF32[$dpmin>>2] = Math_fround(3.40282346638528859812E+38);
 HEAPF32[$dpmax>>2] = Math_fround(-3.40282346638528859812E+38);
 $111 = (($dpmin) + 4|0);
 HEAPF32[$111>>2] = Math_fround(3.40282346638528859812E+38);
 $112 = (($dpmax) + 4|0);
 HEAPF32[$112>>2] = Math_fround(-3.40282346638528859812E+38);
 $113 = (($dpmin) + 8|0);
 HEAPF32[$113>>2] = Math_fround(3.40282346638528859812E+38);
 $114 = (($dpmax) + 8|0);
 HEAPF32[$114>>2] = Math_fround(-3.40282346638528859812E+38);
 $115 = (($dpmin) + 12|0);
 HEAPF32[$115>>2] = Math_fround(3.40282346638528859812E+38);
 $116 = (($dpmax) + 12|0);
 HEAPF32[$116>>2] = Math_fround(-3.40282346638528859812E+38);
 $117 = (($dpmin) + 16|0);
 HEAPF32[$117>>2] = Math_fround(3.40282346638528859812E+38);
 $118 = (($dpmax) + 16|0);
 HEAPF32[$118>>2] = Math_fround(-3.40282346638528859812E+38);
 $119 = (($dpmin) + 20|0);
 HEAPF32[$119>>2] = Math_fround(3.40282346638528859812E+38);
 $120 = (($dpmax) + 20|0);
 HEAPF32[$120>>2] = Math_fround(-3.40282346638528859812E+38);
 $121 = (($dpmin) + 24|0);
 HEAPF32[$121>>2] = Math_fround(3.40282346638528859812E+38);
 $122 = (($dpmax) + 24|0);
 HEAPF32[$122>>2] = Math_fround(-3.40282346638528859812E+38);
 $123 = (($dpmin) + 28|0);
 HEAPF32[$123>>2] = Math_fround(3.40282346638528859812E+38);
 $124 = (($dpmax) + 28|0);
 HEAPF32[$124>>2] = Math_fround(-3.40282346638528859812E+38);
 $125 = ($1|0)==($nbExistingContacts|0);
 if ($125) {
  $170 = Math_fround(3.40282346638528859812E+38);$171 = Math_fround(-3.40282346638528859812E+38);$173 = Math_fround(3.40282346638528859812E+38);$174 = Math_fround(-3.40282346638528859812E+38);$177 = Math_fround(3.40282346638528859812E+38);$178 = Math_fround(-3.40282346638528859812E+38);$181 = Math_fround(3.40282346638528859812E+38);$182 = Math_fround(-3.40282346638528859812E+38);$185 = Math_fround(3.40282346638528859812E+38);$186 = Math_fround(-3.40282346638528859812E+38);$189 = Math_fround(3.40282346638528859812E+38);$190 = Math_fround(-3.40282346638528859812E+38);$193 = Math_fround(3.40282346638528859812E+38);$194 = Math_fround(-3.40282346638528859812E+38);$197 = Math_fround(3.40282346638528859812E+38);$198 = Math_fround(-3.40282346638528859812E+38);
 } else {
  $126 = Math_fround(HEAPF32[$rotT>>2]);
  $127 = (($rotT) + 4|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = (($rotT) + 12|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = (($rotT) + 16|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($rotT) + 24|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($rotT) + 28|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $i4$052 = 0;
  while(1) {
   $137 = (($indices) + ($i4$052)|0);
   $138 = HEAP8[$137>>0]|0;
   $139 = $138&255;
   $140 = (($vertices) + (($139*12)|0)|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = Math_fround($141 * $126);
   $143 = Math_fround($141 * $128);
   $144 = ((($vertices) + (($139*12)|0)|0) + 4|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = Math_fround($145 * $130);
   $147 = Math_fround($145 * $132);
   $148 = Math_fround($142 + $146);
   $149 = Math_fround($143 + $147);
   $150 = ((($vertices) + (($139*12)|0)|0) + 8|0);
   $151 = Math_fround(HEAPF32[$150>>2]);
   $152 = Math_fround($151 * $134);
   $153 = Math_fround($151 * $136);
   $154 = Math_fround($148 + $152);
   $155 = Math_fround($149 + $153);
   $j$051 = 0;
   while(1) {
    $$idx = (($dirs) + (($j$051*12)|0)|0);
    $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
    $$idx18 = ((($dirs) + (($j$051*12)|0)|0) + 4|0);
    $$idx18$val = Math_fround(HEAPF32[$$idx18>>2]);
    $156 = Math_fround($154 * $$idx$val);
    $157 = Math_fround($155 * $$idx18$val);
    $158 = Math_fround($156 + $157);
    $159 = (($dpmin) + ($j$051<<2)|0);
    $160 = Math_fround(HEAPF32[$159>>2]);
    $161 = $160 < $158;
    $162 = $161 ? $160 : $158;
    HEAPF32[$159>>2] = $162;
    $163 = (($dpmax) + ($j$051<<2)|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = $164 > $158;
    $166 = $165 ? $164 : $158;
    HEAPF32[$163>>2] = $166;
    $167 = (($j$051) + 1)|0;
    $exitcond64 = ($167|0)==(8);
    if ($exitcond64) {
     break;
    } else {
     $j$051 = $167;
    }
   }
   $168 = (($i4$052) + 1)|0;
   $exitcond65 = ($168|0)==($2|0);
   if ($exitcond65) {
    break;
   } else {
    $i4$052 = $168;
   }
  }
  $$pre = Math_fround(HEAPF32[$dpmax>>2]);
  $$pre68 = Math_fround(HEAPF32[$dpmin>>2]);
  $$pre69 = Math_fround(HEAPF32[$112>>2]);
  $$pre70 = Math_fround(HEAPF32[$111>>2]);
  $$pre71 = Math_fround(HEAPF32[$114>>2]);
  $$pre72 = Math_fround(HEAPF32[$113>>2]);
  $$pre73 = Math_fround(HEAPF32[$116>>2]);
  $$pre74 = Math_fround(HEAPF32[$115>>2]);
  $$pre75 = Math_fround(HEAPF32[$118>>2]);
  $$pre76 = Math_fround(HEAPF32[$117>>2]);
  $$pre77 = Math_fround(HEAPF32[$120>>2]);
  $$pre78 = Math_fround(HEAPF32[$119>>2]);
  $$pre79 = Math_fround(HEAPF32[$122>>2]);
  $$pre80 = Math_fround(HEAPF32[$121>>2]);
  $$pre81 = Math_fround(HEAPF32[$124>>2]);
  $$pre82 = Math_fround(HEAPF32[$123>>2]);
  $170 = $$pre68;$171 = $$pre;$173 = $$pre70;$174 = $$pre69;$177 = $$pre72;$178 = $$pre71;$181 = $$pre74;$182 = $$pre73;$185 = $$pre76;$186 = $$pre75;$189 = $$pre78;$190 = $$pre77;$193 = $$pre80;$194 = $$pre79;$197 = $$pre82;$198 = $$pre81;
 }
 $169 = Math_fround($171 - $170);
 $172 = Math_fround($174 - $173);
 $175 = $172 > $169;
 $bestAxis$1 = $175&1;
 $maxVariance$1 = $175 ? $172 : $169;
 $176 = Math_fround($178 - $177);
 $179 = $176 > $maxVariance$1;
 $bestAxis$1$1 = $179 ? 2 : $bestAxis$1;
 $maxVariance$1$1 = $179 ? $176 : $maxVariance$1;
 $180 = Math_fround($182 - $181);
 $183 = $180 > $maxVariance$1$1;
 $bestAxis$1$2 = $183 ? 3 : $bestAxis$1$1;
 $maxVariance$1$2 = $183 ? $180 : $maxVariance$1$1;
 $184 = Math_fround($186 - $185);
 $187 = $184 > $maxVariance$1$2;
 $bestAxis$1$3 = $187 ? 4 : $bestAxis$1$2;
 $maxVariance$1$3 = $187 ? $184 : $maxVariance$1$2;
 $188 = Math_fround($190 - $189);
 $191 = $188 > $maxVariance$1$3;
 $bestAxis$1$4 = $191 ? 5 : $bestAxis$1$3;
 $maxVariance$1$4 = $191 ? $188 : $maxVariance$1$3;
 $192 = Math_fround($194 - $193);
 $195 = $192 > $maxVariance$1$4;
 $bestAxis$1$5 = $195 ? 6 : $bestAxis$1$4;
 $maxVariance$1$5 = $195 ? $192 : $maxVariance$1$4;
 $196 = Math_fround($198 - $197);
 $199 = $196 > $maxVariance$1$5;
 $bestAxis$1$6 = $199 ? 7 : $bestAxis$1$5;
 $200 = (($dirs) + (($bestAxis$1$6*12)|0)|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = ((($dirs) + (($bestAxis$1$6*12)|0)|0) + 4|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 if ($125) {
  $indexMaxU$0$lcssa = 0;$indexMaxV$0$lcssa = 0;$indexMinU$0$lcssa = 0;$indexMinV$0$lcssa = 0;
 } else {
  $204 = Math_fround(HEAPF32[$rotT>>2]);
  $205 = (($rotT) + 4|0);
  $206 = Math_fround(HEAPF32[$205>>2]);
  $207 = (($rotT) + 12|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = (($rotT) + 16|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $211 = (($rotT) + 24|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $213 = (($rotT) + 28|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $dpmaxu$033 = Math_fround(-3.40282346638528859812E+38);$dpmaxv$035 = Math_fround(-3.40282346638528859812E+38);$dpminu$032 = Math_fround(3.40282346638528859812E+38);$dpminv$034 = Math_fround(3.40282346638528859812E+38);$i6$040 = 0;$indexMaxU$037 = 0;$indexMaxV$039 = 0;$indexMinU$036 = 0;$indexMinV$038 = 0;
  while(1) {
   $215 = (($indices) + ($i6$040)|0);
   $216 = HEAP8[$215>>0]|0;
   $217 = $216&255;
   $218 = (($vertices) + (($217*12)|0)|0);
   $219 = Math_fround(HEAPF32[$218>>2]);
   $220 = Math_fround($219 * $204);
   $221 = Math_fround($219 * $206);
   $222 = ((($vertices) + (($217*12)|0)|0) + 4|0);
   $223 = Math_fround(HEAPF32[$222>>2]);
   $224 = Math_fround($223 * $208);
   $225 = Math_fround($223 * $210);
   $226 = Math_fround($220 + $224);
   $227 = Math_fround($221 + $225);
   $228 = ((($vertices) + (($217*12)|0)|0) + 8|0);
   $229 = Math_fround(HEAPF32[$228>>2]);
   $230 = Math_fround($229 * $212);
   $231 = Math_fround($229 * $214);
   $232 = Math_fround($226 + $230);
   $233 = Math_fround($227 + $231);
   $234 = Math_fround($201 * $232);
   $235 = Math_fround($203 * $233);
   $236 = Math_fround($234 + $235);
   $237 = Math_fround($203 * $232);
   $238 = Math_fround($201 * $233);
   $239 = Math_fround($238 - $237);
   $240 = $236 < $dpminu$032;
   $dpminu$1 = $240 ? $236 : $dpminu$032;
   $indexMinU$1 = $240 ? $i6$040 : $indexMinU$036;
   $241 = $236 > $dpmaxu$033;
   $dpmaxu$1 = $241 ? $236 : $dpmaxu$033;
   $indexMaxU$1 = $241 ? $i6$040 : $indexMaxU$037;
   $242 = $239 < $dpminv$034;
   $dpminv$1 = $242 ? $239 : $dpminv$034;
   $indexMinV$1 = $242 ? $i6$040 : $indexMinV$038;
   $243 = $239 > $dpmaxv$035;
   $dpmaxv$1 = $243 ? $239 : $dpmaxv$035;
   $indexMaxV$1 = $243 ? $i6$040 : $indexMaxV$039;
   $244 = (($i6$040) + 1)|0;
   $exitcond62 = ($244|0)==($2|0);
   if ($exitcond62) {
    $indexMaxU$0$lcssa = $indexMaxU$1;$indexMaxV$0$lcssa = $indexMaxV$1;$indexMinU$0$lcssa = $indexMinU$1;$indexMinV$0$lcssa = $indexMinV$1;
    break;
   } else {
    $dpmaxu$033 = $dpmaxu$1;$dpmaxv$035 = $dpmaxv$1;$dpminu$032 = $dpminu$1;$dpminv$034 = $dpminv$1;$i6$040 = $244;$indexMaxU$037 = $indexMaxU$1;$indexMaxV$039 = $indexMaxV$1;$indexMinU$036 = $indexMinU$1;$indexMinV$038 = $indexMinV$1;
   }
  }
 }
 $245 = ($indexMaxU$0$lcssa|0)==($indexMinU$0$lcssa|0);
 $$indexMaxU$0 = $245 ? -1 : $indexMaxU$0$lcssa;
 $246 = ($indexMinV$0$lcssa|0)==($indexMinU$0$lcssa|0);
 $247 = ($indexMinV$0$lcssa|0)==($$indexMaxU$0|0);
 $or$cond = $246 | $247;
 $indexMinV$2 = $or$cond ? -1 : $indexMinV$0$lcssa;
 $248 = ($indexMaxV$0$lcssa|0)==($indexMinU$0$lcssa|0);
 $249 = ($indexMaxV$0$lcssa|0)==($$indexMaxU$0|0);
 $or$cond8 = $248 | $249;
 $250 = ($indexMaxV$0$lcssa|0)==($indexMinV$2|0);
 $or$cond9 = $or$cond8 | $250;
 $indexMaxV$2 = $or$cond9 ? -1 : $indexMaxV$0$lcssa;
 if ($125) {
  $newCount$0$lcssa = 0;
 } else {
  $i9$027 = 0;$newCount$026 = 0;
  while(1) {
   $251 = ($i9$027|0)==($indexMinU$0$lcssa|0);
   $252 = ($i9$027|0)==($$indexMaxU$0|0);
   $or$cond10 = $251 | $252;
   $253 = ($i9$027|0)==($indexMinV$2|0);
   $or$cond11 = $or$cond10 | $253;
   $254 = ($i9$027|0)==($indexMaxV$2|0);
   $or$cond12 = $or$cond11 | $254;
   if ($or$cond12) {
    $255 = (($newCount$026) + 1)|0;
    $$sum = (($newCount$026) + ($nbExistingContacts))|0;
    $$sum1 = (($i9$027) + ($nbExistingContacts))|0;
    $256 = (($contactBuffer) + ($$sum1<<6)|0);
    $257 = Math_fround(HEAPF32[$256>>2]);
    $258 = (($contactBuffer) + ($$sum<<6)|0);
    HEAPF32[$258>>2] = $257;
    $259 = ((($contactBuffer) + ($$sum1<<6)|0) + 4|0);
    $260 = Math_fround(HEAPF32[$259>>2]);
    $261 = ((($contactBuffer) + ($$sum<<6)|0) + 4|0);
    HEAPF32[$261>>2] = $260;
    $262 = ((($contactBuffer) + ($$sum1<<6)|0) + 8|0);
    $263 = Math_fround(HEAPF32[$262>>2]);
    $264 = ((($contactBuffer) + ($$sum<<6)|0) + 8|0);
    HEAPF32[$264>>2] = $263;
    $265 = ((($contactBuffer) + ($$sum1<<6)|0) + 12|0);
    $266 = Math_fround(HEAPF32[$265>>2]);
    $267 = ((($contactBuffer) + ($$sum<<6)|0) + 12|0);
    HEAPF32[$267>>2] = $266;
    $268 = ((($contactBuffer) + ($$sum1<<6)|0) + 16|0);
    $269 = Math_fround(HEAPF32[$268>>2]);
    $270 = ((($contactBuffer) + ($$sum<<6)|0) + 16|0);
    HEAPF32[$270>>2] = $269;
    $271 = ((($contactBuffer) + ($$sum1<<6)|0) + 20|0);
    $272 = Math_fround(HEAPF32[$271>>2]);
    $273 = ((($contactBuffer) + ($$sum<<6)|0) + 20|0);
    HEAPF32[$273>>2] = $272;
    $274 = ((($contactBuffer) + ($$sum1<<6)|0) + 24|0);
    $275 = Math_fround(HEAPF32[$274>>2]);
    $276 = ((($contactBuffer) + ($$sum<<6)|0) + 24|0);
    HEAPF32[$276>>2] = $275;
    $277 = ((($contactBuffer) + ($$sum1<<6)|0) + 28|0);
    $278 = Math_fround(HEAPF32[$277>>2]);
    $279 = ((($contactBuffer) + ($$sum<<6)|0) + 28|0);
    HEAPF32[$279>>2] = $278;
    $280 = ((($contactBuffer) + ($$sum1<<6)|0) + 32|0);
    $281 = Math_fround(HEAPF32[$280>>2]);
    $282 = ((($contactBuffer) + ($$sum<<6)|0) + 32|0);
    HEAPF32[$282>>2] = $281;
    $283 = ((($contactBuffer) + ($$sum1<<6)|0) + 36|0);
    $284 = Math_fround(HEAPF32[$283>>2]);
    $285 = ((($contactBuffer) + ($$sum<<6)|0) + 36|0);
    HEAPF32[$285>>2] = $284;
    $286 = ((($contactBuffer) + ($$sum1<<6)|0) + 40|0);
    $287 = Math_fround(HEAPF32[$286>>2]);
    $288 = ((($contactBuffer) + ($$sum<<6)|0) + 40|0);
    HEAPF32[$288>>2] = $287;
    $289 = ((($contactBuffer) + ($$sum<<6)|0) + 44|0);
    $290 = ((($contactBuffer) + ($$sum1<<6)|0) + 44|0);
    ;HEAP32[$289+0>>2]=HEAP32[$290+0>>2]|0;HEAP32[$289+4>>2]=HEAP32[$290+4>>2]|0;HEAP32[$289+8>>2]=HEAP32[$290+8>>2]|0;HEAP32[$289+12>>2]=HEAP32[$290+12>>2]|0;HEAP32[$289+16>>2]=HEAP32[$290+16>>2]|0;
    $newCount$1 = $255;
   } else {
    $newCount$1 = $newCount$026;
   }
   $291 = (($i9$027) + 1)|0;
   $exitcond61 = ($291|0)==($2|0);
   if ($exitcond61) {
    $newCount$0$lcssa = $newCount$1;
    break;
   } else {
    $i9$027 = $291;$newCount$026 = $newCount$1;
   }
  }
 }
 $292 = (($newCount$0$lcssa) + ($nbExistingContacts))|0;
 HEAP32[$0>>2] = $292;
 STACKTOP = sp;return;
}
function __Z22EdgeEdgeContactSpecialRKN5physx6PxVec3ERKNS_7PxPlaneES2_S2_S2_S2_S2_RfRS0_iif($v1,$plane,$p1,$p2,$dir,$p3,$p4,$dist,$ip,$i,$j,$coeff) {
 $v1 = $v1|0;
 $plane = $plane|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $dir = $dir|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $dist = $dist|0;
 $ip = $ip|0;
 $i = $i|0;
 $j = $j|0;
 $coeff = Math_fround($coeff);
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0;
 var $dir$idx$val = Math_fround(0), $dir$idx1 = 0, $dir$idx1$val = Math_fround(0), $dir$idx2 = 0, $dir$idx2$val = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$p3>>2]);
 $1 = Math_fround(HEAPF32[$plane>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($p3) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($plane) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($p3) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($plane) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($plane) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + $14);
 $18 = Math_fround(HEAPF32[$p4>>2]);
 $19 = Math_fround($1 * $18);
 $20 = (($p4) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($6 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($p4) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($12 * $25);
 $27 = Math_fround($23 + $26);
 $28 = Math_fround($16 + $27);
 $29 = Math_fround($17 * $28);
 $30 = $29 > Math_fround(0.0);
 if ($30) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = Math_fround($18 - $0);
 $32 = Math_fround($21 - $4);
 $33 = Math_fround($25 - $10);
 $34 = Math_fround($31 * $1);
 $35 = Math_fround($32 * $6);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($33 * $12);
 $38 = Math_fround($36 + $37);
 $39 = $38 == Math_fround(0.0);
 if ($39) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = Math_fround($17 / $38);
 $41 = Math_fround($31 * $40);
 $42 = Math_fround($32 * $40);
 $43 = Math_fround($33 * $40);
 $44 = Math_fround($0 - $41);
 $45 = Math_fround($4 - $42);
 $46 = Math_fround($10 - $43);
 HEAPF32[$ip>>2] = $44;
 $47 = (($ip) + 4|0);
 HEAPF32[$47>>2] = $45;
 $48 = (($ip) + 8|0);
 HEAPF32[$48>>2] = $46;
 $49 = (($v1) + ($i<<2)|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($ip) + ($j<<2)|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($p1) + ($j<<2)|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($52 - $54);
 $56 = Math_fround($50 * $55);
 $57 = (($v1) + ($j<<2)|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($ip) + ($i<<2)|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($p1) + ($i<<2)|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($60 - $62);
 $64 = Math_fround($58 * $63);
 $65 = Math_fround($56 - $64);
 $66 = Math_fround($65 * $coeff);
 HEAPF32[$dist>>2] = $66;
 $67 = $66 < Math_fround(0.0);
 if ($67) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $dir$idx$val = Math_fround(HEAPF32[$dir>>2]);
 $dir$idx1 = (($dir) + 4|0);
 $dir$idx1$val = Math_fround(HEAPF32[$dir$idx1>>2]);
 $dir$idx2 = (($dir) + 8|0);
 $dir$idx2$val = Math_fround(HEAPF32[$dir$idx2>>2]);
 $68 = Math_fround($66 * $dir$idx$val);
 $69 = Math_fround($66 * $dir$idx1$val);
 $70 = Math_fround($66 * $dir$idx2$val);
 $71 = Math_fround(HEAPF32[$ip>>2]);
 $72 = Math_fround($71 - $68);
 HEAPF32[$ip>>2] = $72;
 $73 = Math_fround(HEAPF32[$47>>2]);
 $74 = Math_fround($73 - $69);
 HEAPF32[$47>>2] = $74;
 $75 = Math_fround(HEAPF32[$48>>2]);
 $76 = Math_fround($75 - $70);
 HEAPF32[$48>>2] = $76;
 $77 = Math_fround(HEAPF32[$p1>>2]);
 $78 = Math_fround($77 - $72);
 $79 = Math_fround(HEAPF32[$p2>>2]);
 $80 = Math_fround($79 - $72);
 $81 = Math_fround($78 * $80);
 $82 = (($p1) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($83 - $74);
 $85 = (($p2) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 - $74);
 $88 = Math_fround($84 * $87);
 $89 = Math_fround($81 + $88);
 $90 = (($p1) + 8|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 - $76);
 $93 = (($p2) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 - $76);
 $96 = Math_fround($92 * $95);
 $97 = Math_fround($89 + $96);
 $98 = $97 < Math_fround(0.0);
 $$0 = $98;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu17contactSphereMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$pre = Math_fround(0), $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre1 = Math_fround(0), $$pre10 = Math_fround(0), $$pre11 = Math_fround(0), $$pre12 = Math_fround(0), $$pre13 = Math_fround(0), $$pre14 = Math_fround(0), $$pre2 = Math_fround(0), $$pre3 = Math_fround(0), $$pre4 = Math_fround(0), $$pre5 = Math_fround(0), $$pre6 = Math_fround(0), $$pre7 = Math_fround(0), $$pre8 = Math_fround(0), $$pre9 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0;
 var $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0;
 var $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $callback = 0, $hmd = 0, $meshScaling = 0, $obb = 0, $obbCenter = 0, $obbExtents = 0, $obbRot = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i1$i$i = 0, $sphereCenterShape1Space = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6768|0;
 $meshScaling = sp + 6696|0;
 $sphereCenterShape1Space = sp;
 $callback = sp + 16|0;
 $hmd = sp + 6560|0;
 $obbCenter = sp + 6572|0;
 $obbExtents = sp + 6584|0;
 $obbRot = sp + 6596|0;
 $obb = sp + 6632|0;
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $0 = (($meshScaling) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($meshScaling) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($meshScaling) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($meshScaling) + 16|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($meshScaling) + 20|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($meshScaling) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($meshScaling) + 28|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($meshScaling) + 32|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($meshScaling) + 36|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($meshScaling) + 40|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($meshScaling) + 44|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($meshScaling) + 48|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($meshScaling) + 52|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($meshScaling) + 56|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($meshScaling) + 60|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($meshScaling) + 64|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($meshScaling) + 68|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($shape1) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = $18 == Math_fround(1.0);
 if ($19) {
  $20 = (($shape1) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = $21 == Math_fround(1.0);
  if ($22) {
   $23 = (($shape1) + 12|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = $24 == Math_fround(1.0);
   if ($25) {
    $106 = 1;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $26 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$17,$26);
  $106 = 0;
 }
 $27 = (($transform0) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($transform1) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 - $30);
 $32 = (($transform0) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($transform1) + 20|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 - $35);
 $37 = (($transform0) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($transform1) + 24|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 - $40);
 $42 = Math_fround($31 * Math_fround(2.0));
 $43 = Math_fround($36 * Math_fround(2.0));
 $44 = Math_fround($41 * Math_fround(2.0));
 $45 = (($transform1) + 12|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 * $46);
 $48 = Math_fround($47 + Math_fround(-0.5));
 $49 = Math_fround(HEAPF32[$transform1>>2]);
 $50 = Math_fround($42 * $49);
 $51 = (($transform1) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($43 * $52);
 $54 = Math_fround($50 + $53);
 $55 = (($transform1) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($44 * $56);
 $58 = Math_fround($54 + $57);
 $59 = Math_fround($42 * $48);
 $60 = Math_fround($44 * $52);
 $61 = Math_fround($43 * $56);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($46 * $62);
 $64 = Math_fround($59 - $63);
 $65 = Math_fround($49 * $58);
 $66 = Math_fround($65 + $64);
 $67 = Math_fround($43 * $48);
 $68 = Math_fround($42 * $56);
 $69 = Math_fround($44 * $49);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($46 * $70);
 $72 = Math_fround($67 - $71);
 $73 = Math_fround($52 * $58);
 $74 = Math_fround($73 + $72);
 $75 = Math_fround($44 * $48);
 $76 = Math_fround($43 * $49);
 $77 = Math_fround($42 * $52);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($46 * $78);
 $80 = Math_fround($75 - $79);
 $81 = Math_fround($56 * $58);
 $82 = Math_fround($80 + $81);
 HEAPF32[$sphereCenterShape1Space>>2] = $66;
 $83 = (($sphereCenterShape1Space) + 4|0);
 HEAPF32[$83>>2] = $74;
 $84 = (($sphereCenterShape1Space) + 8|0);
 HEAPF32[$84>>2] = $82;
 $85 = (($shape0) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround(HEAPF32[$contactDistance>>2]);
 $88 = Math_fround($86 + $87);
 $89 = (($shape1) + 40|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = (($callback) + 4|0);
 HEAP32[$91>>2] = 2;
 HEAP32[$callback>>2] = ((548936 + 8|0));
 $92 = (($callback) + 8|0);
 HEAP32[$92>>2] = ((548920 + 8|0));
 $93 = (($callback) + 12|0);
 HEAP32[$93>>2] = $shape0;
 $94 = (($callback) + 16|0);
 HEAP32[$94>>2] = $transform0;
 $95 = (($callback) + 20|0);
 HEAP32[$95>>2] = $transform1;
 $96 = (($callback) + 24|0);
 HEAP32[$96>>2] = $contactBuffer;
 $97 = (($callback) + 28|0);
 HEAP32[$97>>2] = $sphereCenterShape1Space;
 $98 = (($callback) + 32|0);
 HEAPF32[$98>>2] = $88;
 $99 = (($callback) + 36|0);
 HEAP32[$99>>2] = 0;
 $100 = (($callback) + 5288|0);
 HEAP32[$100>>2] = 0;
 $scevgep$i$i1$i$i = (($callback) + 5224|0);
 dest=$scevgep$i$i1$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $101 = (($callback) + 5676|0);
 HEAP32[$101>>2] = 0;
 $scevgep$i$i$i$i = (($callback) + 5612|0);
 dest=$scevgep$i$i$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $102 = (($callback) + 5680|0);
 HEAP32[$102>>2] = $90;
 $103 = (($callback) + 5684|0);
 HEAP32[$103>>2] = $meshScaling;
 $104 = (($callback) + 5688|0);
 $105 = $106&1;
 HEAP8[$104>>0] = $105;
 $107 = (($callback) + 6540|0);
 HEAP32[$107>>2] = 0;
 $108 = (($90) + 16|0);
 $109 = HEAP32[$108>>2]|0;
 HEAP32[$hmd>>2] = $109;
 $110 = (($90) + 32|0);
 $111 = (($hmd) + 4|0);
 HEAP32[$111>>2] = $110;
 $112 = (($90) + 20|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($hmd) + 8|0);
 HEAPF32[$114>>2] = $113;
 HEAPF32[$obbCenter>>2] = $66;
 $115 = (($obbCenter) + 4|0);
 HEAPF32[$115>>2] = $74;
 $116 = (($obbCenter) + 8|0);
 HEAPF32[$116>>2] = $82;
 HEAPF32[$obbExtents>>2] = $88;
 $117 = (($obbExtents) + 4|0);
 HEAPF32[$117>>2] = $88;
 $118 = (($obbExtents) + 8|0);
 HEAPF32[$118>>2] = $88;
 HEAPF32[$obbRot>>2] = Math_fround(1.0);
 $119 = (($obbRot) + 4|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($obbRot) + 8|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($obbRot) + 12|0);
 HEAPF32[$121>>2] = Math_fround(0.0);
 $122 = (($obbRot) + 16|0);
 HEAPF32[$122>>2] = Math_fround(1.0);
 $123 = (($obbRot) + 20|0);
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = (($obbRot) + 24|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = (($obbRot) + 28|0);
 HEAPF32[$125>>2] = Math_fround(0.0);
 $126 = (($obbRot) + 32|0);
 HEAPF32[$126>>2] = Math_fround(1.0);
 if ($106) {
  $127 = Math_fround(1.0);$129 = Math_fround(0.0);$131 = Math_fround(0.0);$133 = Math_fround(0.0);$135 = Math_fround(1.0);$137 = Math_fround(0.0);$139 = Math_fround(0.0);$141 = Math_fround(0.0);$143 = Math_fround(1.0);$145 = $66;$147 = $74;$149 = $82;$151 = $88;$153 = $88;$155 = $88;
 } else {
  __ZNK5physx2Cm23FastVertex2ShapeScaling20transformQueryBoundsERNS_6PxVec3ES3_RNS_7PxMat33E($meshScaling,$obbCenter,$obbExtents,$obbRot);
  $$pre = Math_fround(HEAPF32[$obbRot>>2]);
  $$pre1 = Math_fround(HEAPF32[$119>>2]);
  $$pre2 = Math_fround(HEAPF32[$120>>2]);
  $$pre3 = Math_fround(HEAPF32[$121>>2]);
  $$pre4 = Math_fround(HEAPF32[$122>>2]);
  $$pre5 = Math_fround(HEAPF32[$123>>2]);
  $$pre6 = Math_fround(HEAPF32[$124>>2]);
  $$pre7 = Math_fround(HEAPF32[$125>>2]);
  $$pre8 = Math_fround(HEAPF32[$126>>2]);
  $$pre9 = Math_fround(HEAPF32[$obbCenter>>2]);
  $$pre10 = Math_fround(HEAPF32[$115>>2]);
  $$pre11 = Math_fround(HEAPF32[$116>>2]);
  $$pre12 = Math_fround(HEAPF32[$obbExtents>>2]);
  $$pre13 = Math_fround(HEAPF32[$117>>2]);
  $$pre14 = Math_fround(HEAPF32[$118>>2]);
  $127 = $$pre;$129 = $$pre1;$131 = $$pre2;$133 = $$pre3;$135 = $$pre4;$137 = $$pre5;$139 = $$pre6;$141 = $$pre7;$143 = $$pre8;$145 = $$pre9;$147 = $$pre10;$149 = $$pre11;$151 = $$pre12;$153 = $$pre13;$155 = $$pre14;
 }
 HEAPF32[$obb>>2] = $127;
 $128 = (($obb) + 4|0);
 HEAPF32[$128>>2] = $129;
 $130 = (($obb) + 8|0);
 HEAPF32[$130>>2] = $131;
 $132 = (($obb) + 12|0);
 HEAPF32[$132>>2] = $133;
 $134 = (($obb) + 16|0);
 HEAPF32[$134>>2] = $135;
 $136 = (($obb) + 20|0);
 HEAPF32[$136>>2] = $137;
 $138 = (($obb) + 24|0);
 HEAPF32[$138>>2] = $139;
 $140 = (($obb) + 28|0);
 HEAPF32[$140>>2] = $141;
 $142 = (($obb) + 32|0);
 HEAPF32[$142>>2] = $143;
 $144 = (($obb) + 36|0);
 HEAPF32[$144>>2] = $145;
 $146 = (($obb) + 40|0);
 HEAPF32[$146>>2] = $147;
 $148 = (($obb) + 44|0);
 HEAPF32[$148>>2] = $149;
 $150 = (($obb) + 48|0);
 HEAPF32[$150>>2] = $151;
 $152 = (($obb) + 52|0);
 HEAPF32[$152>>2] = $153;
 $154 = (($obb) + 56|0);
 HEAPF32[$154>>2] = $155;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($obb,1,$hmd,$callback,1);
 $156 = HEAP32[$107>>2]|0;
 $157 = ($156|0)==(0);
 if ($157) {
  $$pre$i = (($callback) + 8|0);
  $$pre$phi$iZ2D = $$pre$i;
  __ZN12_GLOBAL__N_127SphereMeshContactGeneration20generateLastContactsEv($$pre$phi$iZ2D);
  $160 = (($contactBuffer) + 4096|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = ($161|0)!=(0);
  STACKTOP = sp;return ($162|0);
 } else {
  $158 = (($callback) + 5692|0);
  $159 = (($callback) + 8|0);
  __ZN12_GLOBAL__N_127SphereMeshContactGeneration20processTriangleCacheILj16EEEbRN5physx2Gu13TriangleCacheIXT_EEE($159,$158);
  HEAP32[$107>>2] = 0;
  $$pre$phi$iZ2D = $159;
  __ZN12_GLOBAL__N_127SphereMeshContactGeneration20generateLastContactsEv($$pre$phi$iZ2D);
  $160 = (($contactBuffer) + 4096|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = ($161|0)!=(0);
  STACKTOP = sp;return ($162|0);
 }
 return 0|0;
}
function __ZN5physx2Gu24contactSphereHeightFieldERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $blockCallback = 0, $bounds = 0, $hfUtil = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i1$i$i = 0, $sphereCenterShape1Space = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5744|0;
 $hfUtil = sp + 5720|0;
 $sphereCenterShape1Space = sp;
 $bounds = sp + 16|0;
 $blockCallback = sp + 40|0;
 $0 = (($shape1) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($hfUtil) + 12|0);
 HEAP32[$2>>2] = $1;
 $3 = (($hfUtil) + 16|0);
 HEAP32[$3>>2] = $shape1;
 $4 = (($shape1) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(Math_fround(1.0) / $5);
 $7 = (($hfUtil) + 4|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($shape1) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(Math_fround(1.0) / $9);
 HEAPF32[$hfUtil>>2] = $10;
 $11 = (($shape1) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(Math_fround(1.0) / $12);
 $14 = (($hfUtil) + 8|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($transform0) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transform1) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = (($transform0) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transform1) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 $25 = (($transform0) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($transform1) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($26 - $28);
 $30 = Math_fround($19 * Math_fround(2.0));
 $31 = Math_fround($24 * Math_fround(2.0));
 $32 = Math_fround($29 * Math_fround(2.0));
 $33 = (($transform1) + 12|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $34);
 $36 = Math_fround($35 + Math_fround(-0.5));
 $37 = Math_fround(HEAPF32[$transform1>>2]);
 $38 = Math_fround($30 * $37);
 $39 = (($transform1) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($31 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($transform1) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($32 * $44);
 $46 = Math_fround($42 + $45);
 $47 = Math_fround($30 * $36);
 $48 = Math_fround($32 * $40);
 $49 = Math_fround($31 * $44);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($34 * $50);
 $52 = Math_fround($47 - $51);
 $53 = Math_fround($37 * $46);
 $54 = Math_fround($53 + $52);
 $55 = Math_fround($31 * $36);
 $56 = Math_fround($30 * $44);
 $57 = Math_fround($32 * $37);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($34 * $58);
 $60 = Math_fround($55 - $59);
 $61 = Math_fround($40 * $46);
 $62 = Math_fround($61 + $60);
 $63 = Math_fround($32 * $36);
 $64 = Math_fround($31 * $37);
 $65 = Math_fround($30 * $40);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround($34 * $66);
 $68 = Math_fround($63 - $67);
 $69 = Math_fround($44 * $46);
 $70 = Math_fround($68 + $69);
 HEAPF32[$sphereCenterShape1Space>>2] = $54;
 $71 = (($sphereCenterShape1Space) + 4|0);
 HEAPF32[$71>>2] = $62;
 $72 = (($sphereCenterShape1Space) + 8|0);
 HEAPF32[$72>>2] = $70;
 $73 = (($shape0) + 4|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround(HEAPF32[$contactDistance>>2]);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($54 - $76);
 $78 = Math_fround($62 - $76);
 $79 = Math_fround($70 - $76);
 $80 = Math_fround($54 + $76);
 $81 = Math_fround($76 + $62);
 $82 = Math_fround($76 + $70);
 HEAPF32[$bounds>>2] = $77;
 $83 = (($bounds) + 4|0);
 HEAPF32[$83>>2] = $78;
 $84 = (($bounds) + 8|0);
 HEAPF32[$84>>2] = $79;
 $85 = (($bounds) + 12|0);
 HEAPF32[$85>>2] = $80;
 $86 = (($bounds) + 16|0);
 HEAPF32[$86>>2] = $81;
 $87 = (($bounds) + 20|0);
 HEAPF32[$87>>2] = $82;
 HEAP32[$blockCallback>>2] = ((548888 + 8|0));
 $88 = (($blockCallback) + 4|0);
 HEAP32[$88>>2] = ((548920 + 8|0));
 $89 = (($blockCallback) + 8|0);
 HEAP32[$89>>2] = $shape0;
 $90 = (($blockCallback) + 12|0);
 HEAP32[$90>>2] = $transform0;
 $91 = (($blockCallback) + 16|0);
 HEAP32[$91>>2] = $transform1;
 $92 = (($blockCallback) + 20|0);
 HEAP32[$92>>2] = $contactBuffer;
 $93 = (($blockCallback) + 24|0);
 HEAP32[$93>>2] = $sphereCenterShape1Space;
 $94 = (($blockCallback) + 28|0);
 HEAPF32[$94>>2] = $76;
 $95 = (($blockCallback) + 32|0);
 HEAP32[$95>>2] = 0;
 $96 = (($blockCallback) + 5284|0);
 HEAP32[$96>>2] = 0;
 $scevgep$i$i1$i$i = (($blockCallback) + 5220|0);
 dest=$scevgep$i$i1$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $97 = (($blockCallback) + 5672|0);
 HEAP32[$97>>2] = 0;
 $scevgep$i$i$i$i = (($blockCallback) + 5608|0);
 dest=$scevgep$i$i$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $98 = (($blockCallback) + 5676|0);
 HEAP32[$98>>2] = $hfUtil;
 (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$transform1,$bounds,0,$blockCallback)|0);
 $99 = (($blockCallback) + 4|0);
 __ZN12_GLOBAL__N_127SphereMeshContactGeneration20generateLastContactsEv($99);
 $100 = (($contactBuffer) + 4096|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($101|0)!=(0);
 STACKTOP = sp;return ($102|0);
}
function __ZN12_GLOBAL__N_127SphereMeshContactGeneration20generateLastContactsEv($this) {
 $this = $this|0;
 var $$$i = 0, $$$i23 = 0, $$$i36 = 0, $$0$i$i = 0, $$0$i$i19 = 0, $$0$i$i32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0);
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0;
 var $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0);
 var $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0);
 var $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0);
 var $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0);
 var $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = Math_fround(0);
 var $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $exitcond = 0, $i$01$i = 0, $i$01$i14 = 0, $i$01$i27 = 0, $i$077 = 0, $index$0$i = 0, $index$0$i$i = 0, $index$0$i$i18 = 0, $index$0$i$i31 = 0, $index$0$i44 = 0, $index$0$i49 = 0, $index$01$i = 0, $index$01$i$i = 0, $index$01$i$i15 = 0, $index$01$i$i28 = 0, $index$01$i42 = 0, $index$01$i47 = 0, $or$cond$i = 0, $or$cond$i20 = 0, $or$cond$i33 = 0;
 var $or$cond1$i = 0, $or$cond1$i22 = 0, $or$cond1$i35 = 0, $phitmp = Math_fround(0), $phitmp65 = Math_fround(0), $phitmp66 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4096|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 4|0);
 $8 = (($this) + 12|0);
 $9 = (($this) + 8|0);
 $10 = ($6|0)==(0);
 $i$077 = 0;
 while(1) {
  $11 = ((($this) + ($i$077<<6)|0) + 80|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($this) + ($i$077<<6)|0) + 84|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($this) + ($i$077<<6)|0) + 88|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($this) + ($i$077<<6)|0) + 92|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($this) + ($i$077<<6)|0) + 68|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = ((($this) + ($i$077<<6)|0) + 72|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (__ZN5physx2Gu18computeFeatureCodeEff($20,$22)|0);
  $24 = ((($this) + ($i$077<<6)|0) + 44|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($this) + ($i$077<<6)|0) + 32|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($25 - $27);
  $29 = ((($this) + ($i$077<<6)|0) + 48|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = ((($this) + ($i$077<<6)|0) + 36|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($30 - $32);
  $34 = ((($this) + ($i$077<<6)|0) + 52|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = ((($this) + ($i$077<<6)|0) + 40|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($35 - $37);
  $39 = ((($this) + ($i$077<<6)|0) + 56|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($40 - $27);
  $42 = ((($this) + ($i$077<<6)|0) + 60|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($43 - $32);
  $45 = ((($this) + ($i$077<<6)|0) + 64|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($46 - $37);
  $48 = Math_fround($33 * $47);
  $49 = Math_fround($38 * $44);
  $50 = Math_fround($48 - $49);
  $51 = Math_fround($38 * $41);
  $52 = Math_fround($28 * $47);
  $53 = Math_fround($51 - $52);
  $54 = Math_fround($28 * $44);
  $55 = Math_fround($33 * $41);
  $56 = Math_fround($54 - $55);
  $57 = Math_fround($50 * $50);
  $58 = Math_fround($53 * $53);
  $59 = Math_fround($57 + $58);
  $60 = Math_fround($56 * $56);
  $61 = Math_fround($60 + $59);
  $62 = $61 > Math_fround(0.0);
  if ($62) {
   $63 = (Math_fround(Math_sqrt((Math_fround($61)))));
   $64 = Math_fround(Math_fround(1.0) / $63);
   $65 = Math_fround($50 * $64);
   $66 = Math_fround($53 * $64);
   $67 = Math_fround($56 * $64);
   $129 = $65;$133 = $66;$138 = $67;
  } else {
   $129 = Math_fround(0.0);$133 = Math_fround(0.0);$138 = Math_fround(0.0);
  }
  L9: do {
   switch ($23|0) {
   case 2:  {
    $90 = $18 & 63;
    $91 = ((($this) + ($90)|0) + 5604|0);
    $index$01$i = HEAP8[$91>>0]|0;
    $92 = ($index$01$i<<24>>24)==(-1);
    if ($92) {
     label = 48;
    } else {
     $93 = $index$01$i&255;
     $95 = $93;
     while(1) {
      $94 = ((($this) + ($95<<2)|0) + 5284|0);
      $96 = HEAP32[$94>>2]|0;
      $97 = ($96|0)==($18|0);
      if ($97) {
       break L9;
      }
      $98 = ((($this) + ($95)|0) + 5540|0);
      $index$0$i = HEAP8[$98>>0]|0;
      $99 = $index$0$i&255;
      $100 = ($index$0$i<<24>>24)==(-1);
      if ($100) {
       label = 48;
       break;
      } else {
       $95 = $99;
      }
     }
    }
    break;
   }
   case 1:  {
    $79 = $16 & 63;
    $80 = ((($this) + ($79)|0) + 5604|0);
    $index$01$i42 = HEAP8[$80>>0]|0;
    $81 = ($index$01$i42<<24>>24)==(-1);
    if ($81) {
     label = 48;
    } else {
     $82 = $index$01$i42&255;
     $84 = $82;
     while(1) {
      $83 = ((($this) + ($84<<2)|0) + 5284|0);
      $85 = HEAP32[$83>>2]|0;
      $86 = ($85|0)==($16|0);
      if ($86) {
       break L9;
      }
      $87 = ((($this) + ($84)|0) + 5540|0);
      $index$0$i44 = HEAP8[$87>>0]|0;
      $88 = $index$0$i44&255;
      $89 = ($index$0$i44<<24>>24)==(-1);
      if ($89) {
       label = 48;
       break;
      } else {
       $84 = $88;
      }
     }
    }
    break;
   }
   case 0:  {
    $68 = $14 & 63;
    $69 = ((($this) + ($68)|0) + 5604|0);
    $index$01$i47 = HEAP8[$69>>0]|0;
    $70 = ($index$01$i47<<24>>24)==(-1);
    if ($70) {
     label = 48;
    } else {
     $71 = $index$01$i47&255;
     $73 = $71;
     while(1) {
      $72 = ((($this) + ($73<<2)|0) + 5284|0);
      $74 = HEAP32[$72>>2]|0;
      $75 = ($74|0)==($14|0);
      if ($75) {
       break L9;
      }
      $76 = ((($this) + ($73)|0) + 5540|0);
      $index$0$i49 = HEAP8[$76>>0]|0;
      $77 = $index$0$i49&255;
      $78 = ($index$0$i49<<24>>24)==(-1);
      if ($78) {
       label = 48;
       break;
      } else {
       $73 = $77;
      }
     }
    }
    break;
   }
   case 4:  {
    if ($10) {
     label = 48;
    } else {
     $i$01$i14 = 0;
     while(1) {
      $143 = ((($4) + ($i$01$i14<<6)|0) + 52|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = $144 & 63;
      $146 = ((($this) + ($145)|0) + 5216|0);
      $index$01$i$i15 = HEAP8[$146>>0]|0;
      $147 = ($index$01$i$i15<<24>>24)==(-1);
      L28: do {
       if ($147) {
        $$0$i$i19 = 0;
       } else {
        $148 = $index$01$i$i15&255;
        $150 = $148;
        while(1) {
         $149 = ((($this) + ($150<<4)|0) + 4128|0);
         $151 = HEAP32[$149>>2]|0;
         $152 = ($151|0)==($144|0);
         if ($152) {
          $$0$i$i19 = $149;
          break L28;
         }
         $153 = ((($this) + ($150)|0) + 5152|0);
         $index$0$i$i18 = HEAP8[$153>>0]|0;
         $154 = $index$0$i$i18&255;
         $155 = ($index$0$i$i18<<24>>24)==(-1);
         if ($155) {
          $$0$i$i19 = 0;
          break;
         } else {
          $150 = $154;
         }
        }
       }
      } while(0);
      $156 = (($$0$i$i19) + 4|0);
      $157 = HEAP32[$156>>2]|0;
      $158 = ($157|0)==($16|0);
      $159 = ($157|0)==($18|0);
      $or$cond$i20 = $158 | $159;
      if ($or$cond$i20) {
       label = 36;
      } else {
       $160 = (($$0$i$i19) + 8|0);
       $161 = HEAP32[$160>>2]|0;
       $162 = ($161|0)==($16|0);
       $163 = ($161|0)==($18|0);
       $or$cond1$i22 = $162 | $163;
       if ($or$cond1$i22) {
        label = 36;
       } else {
        $164 = (($$0$i$i19) + 12|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = ($165|0)==($16|0);
        $167 = ($165|0)==($18|0);
        $$$i23 = $166 | $167;
        if ($$$i23) {
         label = 36;
        }
       }
      }
      if ((label|0) == 36) {
       label = 0;
       $168 = (($4) + ($i$01$i14<<6)|0);
       $169 = Math_fround(HEAPF32[$168>>2]);
       $170 = Math_fround($129 * $169);
       $171 = ((($4) + ($i$01$i14<<6)|0) + 4|0);
       $172 = Math_fround(HEAPF32[$171>>2]);
       $173 = Math_fround($133 * $172);
       $174 = Math_fround($170 + $173);
       $175 = ((($4) + ($i$01$i14<<6)|0) + 8|0);
       $176 = Math_fround(HEAPF32[$175>>2]);
       $177 = Math_fround($138 * $176);
       $178 = Math_fround($174 + $177);
       $179 = $178 > Math_fround(0.949999988079071044921);
       if ($179) {
        break L9;
       }
      }
      $180 = (($i$01$i14) + 1)|0;
      $181 = ($180>>>0)<($6>>>0);
      if ($181) {
       $i$01$i14 = $180;
      } else {
       label = 48;
       break;
      }
     }
    }
    break;
   }
   case 3:  {
    if ($10) {
     label = 48;
    } else {
     $i$01$i27 = 0;
     while(1) {
      $101 = ((($4) + ($i$01$i27<<6)|0) + 52|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = $102 & 63;
      $104 = ((($this) + ($103)|0) + 5216|0);
      $index$01$i$i28 = HEAP8[$104>>0]|0;
      $105 = ($index$01$i$i28<<24>>24)==(-1);
      L43: do {
       if ($105) {
        $$0$i$i32 = 0;
       } else {
        $106 = $index$01$i$i28&255;
        $108 = $106;
        while(1) {
         $107 = ((($this) + ($108<<4)|0) + 4128|0);
         $109 = HEAP32[$107>>2]|0;
         $110 = ($109|0)==($102|0);
         if ($110) {
          $$0$i$i32 = $107;
          break L43;
         }
         $111 = ((($this) + ($108)|0) + 5152|0);
         $index$0$i$i31 = HEAP8[$111>>0]|0;
         $112 = $index$0$i$i31&255;
         $113 = ($index$0$i$i31<<24>>24)==(-1);
         if ($113) {
          $$0$i$i32 = 0;
          break;
         } else {
          $108 = $112;
         }
        }
       }
      } while(0);
      $114 = (($$0$i$i32) + 4|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ($115|0)==($14|0);
      $117 = ($115|0)==($16|0);
      $or$cond$i33 = $116 | $117;
      if ($or$cond$i33) {
       label = 26;
      } else {
       $118 = (($$0$i$i32) + 8|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==($14|0);
       $121 = ($119|0)==($16|0);
       $or$cond1$i35 = $120 | $121;
       if ($or$cond1$i35) {
        label = 26;
       } else {
        $122 = (($$0$i$i32) + 12|0);
        $123 = HEAP32[$122>>2]|0;
        $124 = ($123|0)==($14|0);
        $125 = ($123|0)==($16|0);
        $$$i36 = $124 | $125;
        if ($$$i36) {
         label = 26;
        }
       }
      }
      if ((label|0) == 26) {
       label = 0;
       $126 = (($4) + ($i$01$i27<<6)|0);
       $127 = Math_fround(HEAPF32[$126>>2]);
       $128 = Math_fround($129 * $127);
       $130 = ((($4) + ($i$01$i27<<6)|0) + 4|0);
       $131 = Math_fround(HEAPF32[$130>>2]);
       $132 = Math_fround($133 * $131);
       $134 = Math_fround($128 + $132);
       $135 = ((($4) + ($i$01$i27<<6)|0) + 8|0);
       $136 = Math_fround(HEAPF32[$135>>2]);
       $137 = Math_fround($138 * $136);
       $139 = Math_fround($134 + $137);
       $140 = $139 > Math_fround(0.949999988079071044921);
       if ($140) {
        break L9;
       }
      }
      $141 = (($i$01$i27) + 1)|0;
      $142 = ($141>>>0)<($6>>>0);
      if ($142) {
       $i$01$i27 = $141;
      } else {
       label = 48;
       break;
      }
     }
    }
    break;
   }
   case 5:  {
    if ($10) {
     label = 48;
    } else {
     $i$01$i = 0;
     while(1) {
      $182 = ((($4) + ($i$01$i<<6)|0) + 52|0);
      $183 = HEAP32[$182>>2]|0;
      $184 = $183 & 63;
      $185 = ((($this) + ($184)|0) + 5216|0);
      $index$01$i$i = HEAP8[$185>>0]|0;
      $186 = ($index$01$i$i<<24>>24)==(-1);
      L58: do {
       if ($186) {
        $$0$i$i = 0;
       } else {
        $187 = $index$01$i$i&255;
        $189 = $187;
        while(1) {
         $188 = ((($this) + ($189<<4)|0) + 4128|0);
         $190 = HEAP32[$188>>2]|0;
         $191 = ($190|0)==($183|0);
         if ($191) {
          $$0$i$i = $188;
          break L58;
         }
         $192 = ((($this) + ($189)|0) + 5152|0);
         $index$0$i$i = HEAP8[$192>>0]|0;
         $193 = $index$0$i$i&255;
         $194 = ($index$0$i$i<<24>>24)==(-1);
         if ($194) {
          $$0$i$i = 0;
          break;
         } else {
          $189 = $193;
         }
        }
       }
      } while(0);
      $195 = (($$0$i$i) + 4|0);
      $196 = HEAP32[$195>>2]|0;
      $197 = ($196|0)==($14|0);
      $198 = ($196|0)==($18|0);
      $or$cond$i = $197 | $198;
      if ($or$cond$i) {
       label = 46;
      } else {
       $199 = (($$0$i$i) + 8|0);
       $200 = HEAP32[$199>>2]|0;
       $201 = ($200|0)==($14|0);
       $202 = ($200|0)==($18|0);
       $or$cond1$i = $201 | $202;
       if ($or$cond1$i) {
        label = 46;
       } else {
        $203 = (($$0$i$i) + 12|0);
        $204 = HEAP32[$203>>2]|0;
        $205 = ($204|0)==($14|0);
        $206 = ($204|0)==($18|0);
        $$$i = $205 | $206;
        if ($$$i) {
         label = 46;
        }
       }
      }
      if ((label|0) == 46) {
       label = 0;
       $207 = (($4) + ($i$01$i<<6)|0);
       $208 = Math_fround(HEAPF32[$207>>2]);
       $209 = Math_fround($129 * $208);
       $210 = ((($4) + ($i$01$i<<6)|0) + 4|0);
       $211 = Math_fround(HEAPF32[$210>>2]);
       $212 = Math_fround($133 * $211);
       $213 = Math_fround($209 + $212);
       $214 = ((($4) + ($i$01$i<<6)|0) + 8|0);
       $215 = Math_fround(HEAPF32[$214>>2]);
       $216 = Math_fround($138 * $215);
       $217 = Math_fround($213 + $216);
       $218 = $217 > Math_fround(0.949999988079071044921);
       if ($218) {
        break L9;
       }
      }
      $219 = (($i$01$i) + 1)|0;
      $220 = ($219>>>0)<($6>>>0);
      if ($220) {
       $i$01$i = $219;
      } else {
       label = 48;
       break;
      }
     }
    }
    break;
   }
   default: {
   }
   }
  } while(0);
  if ((label|0) == 48) {
   label = 0;
   $221 = ((($this) + ($i$077<<6)|0) + 76|0);
   $222 = Math_fround(HEAPF32[$221>>2]);
   $223 = Math_fround(HEAPF32[$19>>2]);
   $224 = Math_fround(HEAPF32[$21>>2]);
   $225 = (Math_fround(Math_sqrt((Math_fround($222)))));
   $226 = HEAP32[$7>>2]|0;
   $227 = (($226) + 4|0);
   $228 = Math_fround(HEAPF32[$227>>2]);
   $229 = Math_fround($225 - $228);
   $230 = Math_fround(Math_fround(1.0) - $223);
   $231 = Math_fround($230 - $224);
   $232 = Math_fround($231 * $27);
   $233 = Math_fround($223 * $25);
   $234 = Math_fround($232 + $233);
   $235 = Math_fround($224 * $40);
   $236 = Math_fround($234 + $235);
   $237 = Math_fround($231 * $32);
   $238 = Math_fround($223 * $30);
   $239 = Math_fround($237 + $238);
   $240 = Math_fround($224 * $43);
   $241 = Math_fround($239 + $240);
   $242 = Math_fround($231 * $37);
   $243 = Math_fround($223 * $35);
   $244 = Math_fround($242 + $243);
   $245 = Math_fround($224 * $46);
   $246 = Math_fround($244 + $245);
   $247 = HEAP32[$8>>2]|0;
   $248 = Math_fround($236 * Math_fround(2.0));
   $249 = Math_fround($241 * Math_fround(2.0));
   $250 = Math_fround($246 * Math_fround(2.0));
   $251 = (($247) + 12|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = Math_fround($252 * $252);
   $254 = Math_fround($253 + Math_fround(-0.5));
   $255 = Math_fround(HEAPF32[$247>>2]);
   $256 = Math_fround($248 * $255);
   $257 = (($247) + 4|0);
   $258 = Math_fround(HEAPF32[$257>>2]);
   $259 = Math_fround($249 * $258);
   $260 = Math_fround($256 + $259);
   $261 = (($247) + 8|0);
   $262 = Math_fround(HEAPF32[$261>>2]);
   $263 = Math_fround($250 * $262);
   $264 = Math_fround($260 + $263);
   $265 = Math_fround($248 * $254);
   $266 = Math_fround($250 * $258);
   $267 = Math_fround($249 * $262);
   $268 = Math_fround($266 - $267);
   $269 = Math_fround($252 * $268);
   $270 = Math_fround($265 + $269);
   $271 = Math_fround($255 * $264);
   $272 = Math_fround($271 + $270);
   $273 = Math_fround($249 * $254);
   $274 = Math_fround($248 * $262);
   $275 = Math_fround($250 * $255);
   $276 = Math_fround($274 - $275);
   $277 = Math_fround($252 * $276);
   $278 = Math_fround($273 + $277);
   $279 = Math_fround($258 * $264);
   $280 = Math_fround($279 + $278);
   $281 = Math_fround($250 * $254);
   $282 = Math_fround($249 * $255);
   $283 = Math_fround($248 * $258);
   $284 = Math_fround($282 - $283);
   $285 = Math_fround($252 * $284);
   $286 = Math_fround($281 + $285);
   $287 = Math_fround($262 * $264);
   $288 = Math_fround($286 + $287);
   $289 = (($247) + 16|0);
   $290 = Math_fround(HEAPF32[$289>>2]);
   $291 = Math_fround($290 + $272);
   $292 = (($247) + 20|0);
   $293 = Math_fround(HEAPF32[$292>>2]);
   $294 = Math_fround($293 + $280);
   $295 = (($247) + 24|0);
   $296 = Math_fround(HEAPF32[$295>>2]);
   $297 = Math_fround($296 + $288);
   $298 = HEAP32[$9>>2]|0;
   $299 = (($298) + 16|0);
   $300 = Math_fround(HEAPF32[$299>>2]);
   $301 = Math_fround($300 - $291);
   $302 = (($298) + 20|0);
   $303 = Math_fround(HEAPF32[$302>>2]);
   $304 = Math_fround($303 - $294);
   $305 = (($298) + 24|0);
   $306 = Math_fround(HEAPF32[$305>>2]);
   $307 = Math_fround($306 - $297);
   $308 = Math_fround($301 * $301);
   $309 = Math_fround($304 * $304);
   $310 = Math_fround($308 + $309);
   $311 = Math_fround($307 * $307);
   $312 = Math_fround($310 + $311);
   $313 = (Math_fround(Math_sqrt((Math_fround($312)))));
   $314 = $313 < Math_fround(9.99999974737875163555E-5);
   if ($314) {
    if ($62) {
     $315 = (Math_fround(Math_sqrt((Math_fround($61)))));
     $316 = Math_fround(Math_fround(1.0) / $315);
     $317 = Math_fround($50 * $316);
     $318 = Math_fround($53 * $316);
     $319 = Math_fround($56 * $316);
     $phitmp = Math_fround($317 * Math_fround(2.0));
     $phitmp65 = Math_fround($318 * Math_fround(2.0));
     $phitmp66 = Math_fround($319 * Math_fround(2.0));
     $321 = $phitmp;$323 = $phitmp65;$326 = $phitmp66;
    } else {
     $321 = Math_fround(0.0);$323 = Math_fround(0.0);$326 = Math_fround(0.0);
    }
    $320 = Math_fround($321 * $255);
    $322 = Math_fround($323 * $258);
    $324 = Math_fround($320 + $322);
    $325 = Math_fround($326 * $262);
    $327 = Math_fround($324 + $325);
    $328 = Math_fround($321 * $254);
    $329 = Math_fround($326 * $258);
    $330 = Math_fround($323 * $262);
    $331 = Math_fround($329 - $330);
    $332 = Math_fround($252 * $331);
    $333 = Math_fround($328 + $332);
    $334 = Math_fround($255 * $327);
    $335 = Math_fround($334 + $333);
    $336 = Math_fround($323 * $254);
    $337 = Math_fround($321 * $262);
    $338 = Math_fround($326 * $255);
    $339 = Math_fround($337 - $338);
    $340 = Math_fround($252 * $339);
    $341 = Math_fround($336 + $340);
    $342 = Math_fround($258 * $327);
    $343 = Math_fround($342 + $341);
    $344 = Math_fround($326 * $254);
    $345 = Math_fround($323 * $255);
    $346 = Math_fround($321 * $258);
    $347 = Math_fround($345 - $346);
    $348 = Math_fround($252 * $347);
    $349 = Math_fround($344 + $348);
    $350 = Math_fround($262 * $327);
    $351 = Math_fround($349 + $350);
    $362 = $335;$364 = $343;$366 = $351;
   } else {
    $352 = Math_fround(Math_fround(1.0) / $313);
    $353 = Math_fround($301 * $352);
    $354 = Math_fround($304 * $352);
    $355 = Math_fround($307 * $352);
    $362 = $353;$364 = $354;$366 = $355;
   }
   $356 = HEAP32[$3>>2]|0;
   $357 = (($356) + 4096|0);
   $358 = HEAP32[$357>>2]|0;
   $359 = ($358>>>0)>(63);
   if (!($359)) {
    $360 = (($358) + 1)|0;
    HEAP32[$357>>2] = $360;
    $361 = (($356) + ($358<<6)|0);
    HEAPF32[$361>>2] = $362;
    $363 = ((($356) + ($358<<6)|0) + 4|0);
    HEAPF32[$363>>2] = $364;
    $365 = ((($356) + ($358<<6)|0) + 8|0);
    HEAPF32[$365>>2] = $366;
    $367 = ((($356) + ($358<<6)|0) + 16|0);
    HEAPF32[$367>>2] = $291;
    $368 = ((($356) + ($358<<6)|0) + 20|0);
    HEAPF32[$368>>2] = $294;
    $369 = ((($356) + ($358<<6)|0) + 24|0);
    HEAPF32[$369>>2] = $297;
    $370 = ((($356) + ($358<<6)|0) + 12|0);
    HEAPF32[$370>>2] = $229;
    $371 = ((($356) + ($358<<6)|0) + 48|0);
    HEAP32[$371>>2] = -1;
    $372 = ((($356) + ($358<<6)|0) + 52|0);
    HEAP32[$372>>2] = $12;
   }
  }
  $373 = (($i$077) + 1)|0;
  $exitcond = ($373|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$077 = $373;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_142SphereHeightfieldContactGenerationCallbackD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_127SphereMeshContactGenerationD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_142SphereHeightfieldContactGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_142SphereHeightfieldContactGenerationCallback7onEventEjPj($this,$nb,$indices) {
 $this = $this|0;
 $nb = $nb|0;
 $indices = $indices|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0;
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $a$02 = 0, $adjInds = 0, $adjTri = 0, $cache = 0, $currentTriangle = 0, $exitcond = 0, $i$04 = 0, $inds$05 = 0, $inds$1$lcssa = 0, $inds$13 = 0, $nbTrigs$06 = 0, $scevgep$sum = 0, $scevgep10 = 0, $triFlags$01 = 0, $triFlags$2 = 0;
 var $vertIndices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 960|0;
 $cache = sp + 96|0;
 $vertIndices = sp;
 $currentTriangle = sp + 12|0;
 $adjInds = sp + 48|0;
 $adjTri = sp + 60|0;
 $0 = (($cache) + 848|0);
 HEAP32[$0>>2] = 0;
 $1 = (($nb) + 15)|0;
 $2 = $1 >>> 4;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 4|0);
 $5 = (($currentTriangle) + 12|0);
 $6 = (($currentTriangle) + 16|0);
 $7 = (($currentTriangle) + 4|0);
 $8 = (($currentTriangle) + 20|0);
 $9 = (($currentTriangle) + 8|0);
 $10 = (($currentTriangle) + 24|0);
 $11 = (($currentTriangle) + 28|0);
 $12 = (($currentTriangle) + 32|0);
 $13 = (($this) + 5676|0);
 $14 = (($this) + 16|0);
 $15 = (($adjTri) + 12|0);
 $16 = (($adjTri) + 16|0);
 $17 = (($adjTri) + 4|0);
 $18 = (($adjTri) + 20|0);
 $19 = (($adjTri) + 8|0);
 $20 = (($adjTri) + 24|0);
 $21 = (($adjTri) + 28|0);
 $22 = (($adjTri) + 32|0);
 $23 = (($vertIndices) + 4|0);
 $24 = (($vertIndices) + 8|0);
 $i$04 = 0;$inds$05 = $indices;$nbTrigs$06 = $nb;
 while(1) {
  HEAP32[$0>>2] = 0;
  $25 = ($nbTrigs$06>>>0)<(16);
  $26 = $25 ? $nbTrigs$06 : 16;
  $27 = (($nbTrigs$06) - ($26))|0;
  $28 = ($26|0)==(0);
  if ($28) {
   $inds$1$lcssa = $inds$05;
  } else {
   $29 = ($nbTrigs$06>>>0)<(16);
   $$in = $26;$inds$13 = $inds$05;
   while(1) {
    $30 = (($$in) + -1)|0;
    $31 = (($inds$13) + 4|0);
    $32 = HEAP32[$inds$13>>2]|0;
    $33 = Math_fround(HEAPF32[$5>>2]);
    $34 = Math_fround($33 - Math_fround(0.0));
    $35 = Math_fround(HEAPF32[$6>>2]);
    $36 = Math_fround(HEAPF32[$7>>2]);
    $37 = Math_fround($35 - $36);
    $38 = Math_fround(HEAPF32[$8>>2]);
    $39 = Math_fround(HEAPF32[$9>>2]);
    $40 = Math_fround($38 - $39);
    $41 = Math_fround(HEAPF32[$10>>2]);
    $42 = Math_fround($41 - Math_fround(0.0));
    $43 = Math_fround(HEAPF32[$11>>2]);
    $44 = Math_fround($43 - $36);
    $45 = Math_fround(HEAPF32[$12>>2]);
    $46 = Math_fround($45 - $39);
    $47 = Math_fround($37 * $46);
    $48 = Math_fround($40 * $44);
    $49 = Math_fround($47 - $48);
    $50 = Math_fround($40 * $42);
    $51 = Math_fround($34 * $46);
    $52 = Math_fround($50 - $51);
    $53 = Math_fround($34 * $44);
    $54 = Math_fround($37 * $42);
    $55 = Math_fround($53 - $54);
    $56 = Math_fround($49 * $49);
    $57 = Math_fround($52 * $52);
    $58 = Math_fround($56 + $57);
    $59 = Math_fround($55 * $55);
    $60 = Math_fround($59 + $58);
    $61 = (Math_fround(Math_sqrt((Math_fround($60)))));
    $62 = $61 > Math_fround(0.0);
    if ($62) {
     $63 = Math_fround(Math_fround(1.0) / $61);
     $64 = Math_fround($49 * $63);
     $65 = Math_fround($52 * $63);
     $66 = Math_fround($55 * $63);
     $129 = $64;$132 = $65;$136 = $66;
    } else {
     $129 = $49;$132 = $52;$136 = $55;
    }
    $67 = HEAP32[$13>>2]|0;
    $68 = HEAP32[$14>>2]|0;
    (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($67,$68,$currentTriangle,$vertIndices,$adjInds,$32,0,0)|0);
    $a$02 = 0;$triFlags$01 = 0;
    while(1) {
     $69 = (($adjInds) + ($a$02<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==(-1);
     if ($71) {
      $144 = (($a$02) + 3)|0;
      $145 = 1 << $144;
      $146 = $triFlags$01&255;
      $147 = $145 | $146;
      $148 = $147&255;
      $triFlags$2 = $148;
     } else {
      $72 = HEAP32[$13>>2]|0;
      $73 = HEAP32[$14>>2]|0;
      (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($72,$73,$adjTri,0,0,$70,0,0)|0);
      $74 = Math_fround(HEAPF32[$15>>2]);
      $75 = Math_fround(HEAPF32[$adjTri>>2]);
      $76 = Math_fround($74 - $75);
      $77 = Math_fround(HEAPF32[$16>>2]);
      $78 = Math_fround(HEAPF32[$17>>2]);
      $79 = Math_fround($77 - $78);
      $80 = Math_fround(HEAPF32[$18>>2]);
      $81 = Math_fround(HEAPF32[$19>>2]);
      $82 = Math_fround($80 - $81);
      $83 = Math_fround(HEAPF32[$20>>2]);
      $84 = Math_fround($83 - $75);
      $85 = Math_fround(HEAPF32[$21>>2]);
      $86 = Math_fround($85 - $78);
      $87 = Math_fround(HEAPF32[$22>>2]);
      $88 = Math_fround($87 - $81);
      $89 = Math_fround($79 * $88);
      $90 = Math_fround($82 * $86);
      $91 = Math_fround($89 - $90);
      $92 = Math_fround($82 * $84);
      $93 = Math_fround($76 * $88);
      $94 = Math_fround($92 - $93);
      $95 = Math_fround($76 * $86);
      $96 = Math_fround($79 * $84);
      $97 = Math_fround($95 - $96);
      $98 = (548912 + ($a$02)|0);
      $99 = HEAP8[$98>>0]|0;
      $100 = $99&255;
      $101 = (($currentTriangle) + (($100*12)|0)|0);
      $102 = Math_fround(HEAPF32[$101>>2]);
      $103 = Math_fround($102 - $75);
      $104 = ((($currentTriangle) + (($100*12)|0)|0) + 4|0);
      $105 = Math_fround(HEAPF32[$104>>2]);
      $106 = Math_fround($105 - $78);
      $107 = ((($currentTriangle) + (($100*12)|0)|0) + 8|0);
      $108 = Math_fround(HEAPF32[$107>>2]);
      $109 = Math_fround($108 - $81);
      $110 = Math_fround($91 * $103);
      $111 = Math_fround($94 * $106);
      $112 = Math_fround($110 + $111);
      $113 = Math_fround($97 * $109);
      $114 = Math_fround($112 + $113);
      $115 = $114 < Math_fround(0.0);
      if ($115) {
       $116 = Math_fround($91 * $91);
       $117 = Math_fround($94 * $94);
       $118 = Math_fround($116 + $117);
       $119 = Math_fround($97 * $97);
       $120 = Math_fround($119 + $118);
       $121 = (Math_fround(Math_sqrt((Math_fround($120)))));
       $122 = $121 > Math_fround(0.0);
       if ($122) {
        $123 = Math_fround(Math_fround(1.0) / $121);
        $124 = Math_fround($91 * $123);
        $125 = Math_fround($94 * $123);
        $126 = Math_fround($97 * $123);
        $128 = $124;$131 = $125;$135 = $126;
       } else {
        $128 = $91;$131 = $94;$135 = $97;
       }
       $127 = Math_fround($129 * $128);
       $130 = Math_fround($132 * $131);
       $133 = Math_fround($130 + $127);
       $134 = Math_fround($136 * $135);
       $137 = Math_fround($134 + $133);
       $138 = $137 < Math_fround(0.999000012874603271484);
       if ($138) {
        $139 = (($a$02) + 3)|0;
        $140 = 1 << $139;
        $141 = $triFlags$01&255;
        $142 = $140 | $141;
        $143 = $142&255;
        $triFlags$2 = $143;
       } else {
        $triFlags$2 = $triFlags$01;
       }
      } else {
       $triFlags$2 = $triFlags$01;
      }
     }
     $149 = (($a$02) + 1)|0;
     $exitcond = ($149|0)==(3);
     if ($exitcond) {
      break;
     } else {
      $a$02 = $149;$triFlags$01 = $triFlags$2;
     }
    }
    $150 = HEAP32[$0>>2]|0;
    $151 = (($150) + 1)|0;
    HEAP32[$0>>2] = $151;
    $152 = ($150*3)|0;
    $153 = Math_fround(HEAPF32[$currentTriangle>>2]);
    $154 = (($cache) + (($152*12)|0)|0);
    HEAPF32[$154>>2] = $153;
    $155 = Math_fround(HEAPF32[$7>>2]);
    $156 = ((($cache) + (($152*12)|0)|0) + 4|0);
    HEAPF32[$156>>2] = $155;
    $157 = Math_fround(HEAPF32[$9>>2]);
    $158 = ((($cache) + (($152*12)|0)|0) + 8|0);
    HEAPF32[$158>>2] = $157;
    $159 = (($152) + 1)|0;
    $160 = Math_fround(HEAPF32[$5>>2]);
    $161 = (($cache) + (($159*12)|0)|0);
    HEAPF32[$161>>2] = $160;
    $162 = Math_fround(HEAPF32[$6>>2]);
    $163 = ((($cache) + (($159*12)|0)|0) + 4|0);
    HEAPF32[$163>>2] = $162;
    $164 = Math_fround(HEAPF32[$8>>2]);
    $165 = ((($cache) + (($159*12)|0)|0) + 8|0);
    HEAPF32[$165>>2] = $164;
    $166 = (($152) + 2)|0;
    $167 = Math_fround(HEAPF32[$10>>2]);
    $168 = (($cache) + (($166*12)|0)|0);
    HEAPF32[$168>>2] = $167;
    $169 = Math_fround(HEAPF32[$11>>2]);
    $170 = ((($cache) + (($166*12)|0)|0) + 4|0);
    HEAPF32[$170>>2] = $169;
    $171 = Math_fround(HEAPF32[$12>>2]);
    $172 = ((($cache) + (($166*12)|0)|0) + 8|0);
    HEAPF32[$172>>2] = $171;
    $173 = HEAP32[$vertIndices>>2]|0;
    $174 = ((($cache) + ($152<<2)|0) + 576|0);
    HEAP32[$174>>2] = $173;
    $175 = HEAP32[$23>>2]|0;
    $176 = ((($cache) + ($159<<2)|0) + 576|0);
    HEAP32[$176>>2] = $175;
    $177 = HEAP32[$24>>2]|0;
    $178 = ((($cache) + ($166<<2)|0) + 576|0);
    HEAP32[$178>>2] = $177;
    $179 = ((($cache) + ($150<<2)|0) + 768|0);
    HEAP32[$179>>2] = $32;
    $180 = ((($cache) + ($150)|0) + 832|0);
    HEAP8[$180>>0] = $triFlags$2;
    $181 = ($30|0)==(0);
    if ($181) {
     break;
    } else {
     $$in = $30;$inds$13 = $31;
    }
   }
   $scevgep$sum = $29 ? $nbTrigs$06 : 16;
   $scevgep10 = (($inds$05) + ($scevgep$sum<<2)|0);
   $inds$1$lcssa = $scevgep10;
  }
  __ZN12_GLOBAL__N_127SphereMeshContactGeneration20processTriangleCacheILj16EEEbRN5physx2Gu13TriangleCacheIXT_EEE($4,$cache);
  $182 = (($i$04) + 1)|0;
  $183 = ($182>>>0)<($2>>>0);
  if ($183) {
   $i$04 = $182;$inds$05 = $inds$1$lcssa;$nbTrigs$06 = $27;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN12_GLOBAL__N_127SphereMeshContactGeneration20processTriangleCacheILj16EEEbRN5physx2Gu13TriangleCacheIXT_EEE($this,$cache) {
 $this = $this|0;
 $cache = $cache|0;
 var $$pr = 0, $$pr$pre = 0, $$pr38$pr = 0, $$pr38$pr$pre = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0;
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = Math_fround(0), $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0);
 var $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$043 = 0, $cp = 0, $nbDelayed$0$lcssa = 0, $nbDelayed$047 = 0, $nbDelayed$1 = 0, $nextInd$0$i = 0, $nextInd$0$i15 = 0, $nextInd$0$i23 = 0;
 var $nextInd$0$i7 = 0, $nextInd$02$i = 0, $nextInd$02$i11 = 0, $nextInd$02$i19 = 0, $nextInd$02$i3 = 0, $nextInd$03$i = 0, $nextInd$03$i14 = 0, $nextInd$03$i22 = 0, $nextInd$03$i6 = 0, $phitmp = 0, $t = 0, $triIndex$046 = 0, $u = 0, $uu = 0, $v = 0, $v0 = 0, $v1 = 0, $v2 = 0, $vertIndex$044 = 0, $verts$045 = 0;
 var $vv = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $v0 = sp + 68|0;
 $v1 = sp + 56|0;
 $v2 = sp + 44|0;
 $uu = sp + 40|0;
 $vv = sp + 36|0;
 $cp = sp + 24|0;
 $t = sp + 8|0;
 $u = sp + 4|0;
 $v = sp;
 $0 = sp + 12|0;
 $1 = (($this) + 24|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($2 * $2);
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($cache) + 848|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $nbDelayed$0$lcssa = $5;
  HEAP32[$4>>2] = $nbDelayed$0$lcssa;
  STACKTOP = sp;return;
 }
 $9 = (($cache) + 576|0);
 $10 = (($cache) + 768|0);
 $11 = (($v0) + 4|0);
 $12 = (($v0) + 8|0);
 $13 = (($v1) + 4|0);
 $14 = (($v1) + 8|0);
 $15 = (($v2) + 4|0);
 $16 = (($v2) + 8|0);
 $17 = (($this) + 20|0);
 $18 = (($cp) + 4|0);
 $19 = (($cp) + 8|0);
 $20 = (($0) + 4|0);
 $21 = (($0) + 8|0);
 $22 = (($this) + 12|0);
 $23 = (($this) + 16|0);
 $24 = (($this) + 5280|0);
 $25 = (($this) + 5668|0);
 $26 = (($this) + 4|0);
 $a$043 = 1;$nbDelayed$047 = $5;$triIndex$046 = $10;$vertIndex$044 = $9;$verts$045 = $cache;
 while(1) {
  $27 = (($triIndex$046) + 4|0);
  $28 = HEAP32[$triIndex$046>>2]|0;
  $29 = Math_fround(HEAPF32[$verts$045>>2]);
  HEAPF32[$v0>>2] = $29;
  $30 = (($verts$045) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$11>>2] = $31;
  $32 = (($verts$045) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$12>>2] = $33;
  $34 = (($verts$045) + 12|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  HEAPF32[$v1>>2] = $35;
  $36 = (($verts$045) + 16|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  HEAPF32[$13>>2] = $37;
  $38 = (($verts$045) + 20|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[$14>>2] = $39;
  $40 = (($verts$045) + 36|0);
  $41 = (($verts$045) + 24|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$v2>>2] = $42;
  $43 = (($verts$045) + 28|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$15>>2] = $44;
  $45 = (($verts$045) + 32|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$16>>2] = $46;
  $47 = (($vertIndex$044) + 12|0);
  $48 = HEAP32[$17>>2]|0;
  __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp,$48,$v0,$v1,$v2,$uu,$vv);
  $49 = HEAP32[$17>>2]|0;
  $50 = Math_fround(HEAPF32[$cp>>2]);
  $51 = Math_fround(HEAPF32[$49>>2]);
  $52 = Math_fround($50 - $51);
  $53 = Math_fround(HEAPF32[$18>>2]);
  $54 = (($49) + 4|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($53 - $55);
  $57 = Math_fround(HEAPF32[$19>>2]);
  $58 = (($49) + 8|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($57 - $59);
  $61 = Math_fround($52 * $52);
  $62 = Math_fround($56 * $56);
  $63 = Math_fround($61 + $62);
  $64 = Math_fround($60 * $60);
  $65 = Math_fround($63 + $64);
  $66 = $65 < $3;
  L6: do {
   if ($66) {
    $67 = Math_fround(HEAPF32[$v1>>2]);
    $68 = Math_fround(HEAPF32[$v0>>2]);
    $69 = Math_fround($67 - $68);
    $70 = Math_fround(HEAPF32[$13>>2]);
    $71 = Math_fround(HEAPF32[$11>>2]);
    $72 = Math_fround($70 - $71);
    $73 = Math_fround(HEAPF32[$14>>2]);
    $74 = Math_fround(HEAPF32[$12>>2]);
    $75 = Math_fround($73 - $74);
    $76 = Math_fround(HEAPF32[$v2>>2]);
    $77 = Math_fround($76 - $68);
    $78 = Math_fround(HEAPF32[$15>>2]);
    $79 = Math_fround($78 - $71);
    $80 = Math_fround(HEAPF32[$16>>2]);
    $81 = Math_fround($80 - $74);
    $82 = Math_fround($72 * $81);
    $83 = Math_fround($75 * $79);
    $84 = Math_fround($82 - $83);
    $85 = Math_fround($75 * $77);
    $86 = Math_fround($69 * $81);
    $87 = Math_fround($85 - $86);
    $88 = Math_fround($69 * $79);
    $89 = Math_fround($72 * $77);
    $90 = Math_fround($88 - $89);
    $91 = Math_fround($68 * $84);
    $92 = Math_fround($71 * $87);
    $93 = Math_fround($91 + $92);
    $94 = Math_fround($74 * $90);
    $95 = Math_fround($94 + $93);
    $96 = Math_fround($51 * $84);
    $97 = Math_fround($55 * $87);
    $98 = Math_fround($96 + $97);
    $99 = Math_fround($59 * $90);
    $100 = Math_fround($99 + $98);
    $101 = $100 < $95;
    if ($101) {
     $nbDelayed$1 = $nbDelayed$047;
    } else {
     $102 = Math_fround($84 * $84);
     $103 = Math_fround($87 * $87);
     $104 = Math_fround($102 + $103);
     $105 = Math_fround($90 * $90);
     $106 = Math_fround($105 + $104);
     $107 = Math_fround(-$84);
     $108 = Math_fround(-$87);
     $109 = Math_fround(-$90);
     HEAPF32[$0>>2] = $107;
     HEAPF32[$20>>2] = $108;
     HEAPF32[$21>>2] = $109;
     $110 = (__ZN5physx2Gu27intersectRayTriangleCullingERKNS_6PxVec3ES3_S3_S3_S3_RfS4_S4_f($49,$0,$v0,$v1,$v2,$t,$u,$v,Math_fround(9.99999974737875163555E-5))|0);
     if ($110) {
      $111 = Math_fround(HEAPF32[$t>>2]);
      $112 = Math_fround($111 * $111);
      $113 = Math_fround($106 * $112);
      $114 = $113 < $3;
      if ($114) {
       $115 = HEAP32[$22>>2]|0;
       $116 = HEAP32[$17>>2]|0;
       $117 = Math_fround($84 * $111);
       $118 = Math_fround($87 * $111);
       $119 = Math_fround($90 * $111);
       $120 = Math_fround(HEAPF32[$116>>2]);
       $121 = Math_fround($120 - $117);
       $122 = (($116) + 4|0);
       $123 = Math_fround(HEAPF32[$122>>2]);
       $124 = Math_fround($123 - $118);
       $125 = (($116) + 8|0);
       $126 = Math_fround(HEAPF32[$125>>2]);
       $127 = Math_fround($126 - $119);
       $128 = Math_fround($121 * Math_fround(2.0));
       $129 = Math_fround($124 * Math_fround(2.0));
       $130 = Math_fround($127 * Math_fround(2.0));
       $131 = (($115) + 12|0);
       $132 = Math_fround(HEAPF32[$131>>2]);
       $133 = Math_fround($132 * $132);
       $134 = Math_fround($133 + Math_fround(-0.5));
       $135 = Math_fround(HEAPF32[$115>>2]);
       $136 = Math_fround($128 * $135);
       $137 = (($115) + 4|0);
       $138 = Math_fround(HEAPF32[$137>>2]);
       $139 = Math_fround($129 * $138);
       $140 = Math_fround($136 + $139);
       $141 = (($115) + 8|0);
       $142 = Math_fround(HEAPF32[$141>>2]);
       $143 = Math_fround($130 * $142);
       $144 = Math_fround($140 + $143);
       $145 = (Math_fround(Math_sqrt((Math_fround($106)))));
       $146 = Math_fround(Math_fround(1.0) / $145);
       $147 = Math_fround($84 * Math_fround(2.0));
       $148 = Math_fround($87 * Math_fround(2.0));
       $149 = Math_fround($90 * Math_fround(2.0));
       $150 = Math_fround($147 * $135);
       $151 = Math_fround($148 * $138);
       $152 = Math_fround($150 + $151);
       $153 = Math_fround($149 * $142);
       $154 = Math_fround($152 + $153);
       $155 = HEAP32[$23>>2]|0;
       $156 = (($155) + 4096|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = ($157>>>0)>(63);
       if (!($158)) {
        $159 = Math_fround($147 * $138);
        $160 = Math_fround($148 * $135);
        $161 = Math_fround($149 * $135);
        $162 = Math_fround($147 * $142);
        $163 = Math_fround($148 * $142);
        $164 = Math_fround($149 * $138);
        $165 = Math_fround($128 * $138);
        $166 = Math_fround($129 * $135);
        $167 = Math_fround($130 * $135);
        $168 = Math_fround($128 * $142);
        $169 = Math_fround($129 * $142);
        $170 = Math_fround($130 * $138);
        $171 = Math_fround($160 - $159);
        $172 = Math_fround($162 - $161);
        $173 = Math_fround($164 - $163);
        $174 = Math_fround($166 - $165);
        $175 = Math_fround($168 - $167);
        $176 = Math_fround($170 - $169);
        $177 = HEAP32[$26>>2]|0;
        $178 = Math_fround($132 * $171);
        $179 = Math_fround($149 * $134);
        $180 = Math_fround($132 * $172);
        $181 = Math_fround($148 * $134);
        $182 = Math_fround($132 * $173);
        $183 = Math_fround($147 * $134);
        $184 = Math_fround($132 * $174);
        $185 = Math_fround($130 * $134);
        $186 = Math_fround($132 * $175);
        $187 = Math_fround($129 * $134);
        $188 = Math_fround($132 * $176);
        $189 = Math_fround($128 * $134);
        $190 = (($177) + 4|0);
        $191 = Math_fround($142 * $154);
        $192 = Math_fround($179 + $178);
        $193 = Math_fround($138 * $154);
        $194 = Math_fround($181 + $180);
        $195 = Math_fround($135 * $154);
        $196 = Math_fround($183 + $182);
        $197 = (($115) + 24|0);
        $198 = (($115) + 20|0);
        $199 = (($115) + 16|0);
        $200 = Math_fround($142 * $144);
        $201 = Math_fround($185 + $184);
        $202 = Math_fround($138 * $144);
        $203 = Math_fround($187 + $186);
        $204 = Math_fround($135 * $144);
        $205 = Math_fround($189 + $188);
        $206 = Math_fround(HEAPF32[$190>>2]);
        $207 = Math_fround($111 * $145);
        $208 = Math_fround($192 + $191);
        $209 = Math_fround($193 + $194);
        $210 = Math_fround($195 + $196);
        $211 = Math_fround(HEAPF32[$197>>2]);
        $212 = Math_fround(HEAPF32[$198>>2]);
        $213 = Math_fround(HEAPF32[$199>>2]);
        $214 = Math_fround($201 + $200);
        $215 = Math_fround($202 + $203);
        $216 = Math_fround($204 + $205);
        $217 = Math_fround($207 - $206);
        $218 = Math_fround($146 * $208);
        $219 = Math_fround($146 * $209);
        $220 = Math_fround($146 * $210);
        $221 = Math_fround($214 + $211);
        $222 = Math_fround($215 + $212);
        $223 = Math_fround($216 + $213);
        $224 = (($157) + 1)|0;
        HEAP32[$156>>2] = $224;
        $225 = (($155) + ($157<<6)|0);
        HEAPF32[$225>>2] = $220;
        $226 = ((($155) + ($157<<6)|0) + 4|0);
        HEAPF32[$226>>2] = $219;
        $227 = ((($155) + ($157<<6)|0) + 8|0);
        HEAPF32[$227>>2] = $218;
        $228 = ((($155) + ($157<<6)|0) + 16|0);
        HEAPF32[$228>>2] = $223;
        $229 = ((($155) + ($157<<6)|0) + 20|0);
        HEAPF32[$229>>2] = $222;
        $230 = ((($155) + ($157<<6)|0) + 24|0);
        HEAPF32[$230>>2] = $221;
        $231 = ((($155) + ($157<<6)|0) + 12|0);
        HEAPF32[$231>>2] = $217;
        $232 = ((($155) + ($157<<6)|0) + 48|0);
        HEAP32[$232>>2] = -1;
        $233 = ((($155) + ($157<<6)|0) + 52|0);
        HEAP32[$233>>2] = $28;
       }
       $234 = HEAP32[$vertIndex$044>>2]|0;
       $235 = (($vertIndex$044) + 4|0);
       $236 = HEAP32[$235>>2]|0;
       $237 = (($vertIndex$044) + 8|0);
       $238 = HEAP32[$237>>2]|0;
       $239 = HEAP32[$24>>2]|0;
       $240 = ($239|0)==(64);
       L15: do {
        if ($240) {
         $267 = $234;
        } else {
         $241 = $28 & 63;
         $242 = ((($this) + ($241)|0) + 5216|0);
         $nextInd$02$i19 = HEAP8[$242>>0]|0;
         $243 = ($nextInd$02$i19<<24>>24)==(-1);
         if ($243) {
          $252 = $239&255;
          HEAP8[$242>>0] = $252;
         } else {
          $244 = $nextInd$02$i19&255;
          $246 = $244;$nextInd$03$i22 = $nextInd$02$i19;
          while(1) {
           $245 = ((($this) + ($246<<4)|0) + 4128|0);
           $247 = HEAP32[$245>>2]|0;
           $248 = ($247|0)==($28|0);
           if ($248) {
            $267 = $234;
            break L15;
           }
           $249 = ((($this) + ($246)|0) + 5152|0);
           $nextInd$0$i23 = HEAP8[$249>>0]|0;
           $250 = $nextInd$0$i23&255;
           $251 = ($nextInd$0$i23<<24>>24)==(-1);
           if ($251) {
            break;
           } else {
            $246 = $250;$nextInd$03$i22 = $nextInd$0$i23;
           }
          }
          $253 = $239&255;
          $254 = $nextInd$03$i22&255;
          $255 = ((($this) + ($254)|0) + 5152|0);
          HEAP8[$255>>0] = $253;
         }
         $256 = HEAP32[$24>>2]|0;
         $257 = ((($this) + ($256)|0) + 5152|0);
         HEAP8[$257>>0] = -1;
         $258 = HEAP32[$24>>2]|0;
         $259 = (($258) + 1)|0;
         HEAP32[$24>>2] = $259;
         $260 = ((($this) + ($258<<4)|0) + 4128|0);
         HEAP32[$260>>2] = $28;
         $261 = ((($this) + ($258<<4)|0) + 4132|0);
         HEAP32[$261>>2] = $234;
         $262 = ((($this) + ($258<<4)|0) + 4136|0);
         HEAP32[$262>>2] = $236;
         $263 = ((($this) + ($258<<4)|0) + 4140|0);
         HEAP32[$263>>2] = $238;
         $$pre = HEAP32[$vertIndex$044>>2]|0;
         $267 = $$pre;
        }
       } while(0);
       $264 = HEAP32[$25>>2]|0;
       $265 = ($264|0)==(64);
       if ($265) {
        $nbDelayed$1 = $nbDelayed$047;
        break;
       }
       $266 = $267 & 63;
       $268 = ((($this) + ($266)|0) + 5604|0);
       $nextInd$02$i11 = HEAP8[$268>>0]|0;
       $269 = ($nextInd$02$i11<<24>>24)==(-1);
       L27: do {
        if ($269) {
         $278 = $264&255;
         HEAP8[$268>>0] = $278;
         label = 24;
        } else {
         $270 = $nextInd$02$i11&255;
         $272 = $270;$nextInd$03$i14 = $nextInd$02$i11;
         while(1) {
          $271 = ((($this) + ($272<<2)|0) + 5284|0);
          $273 = HEAP32[$271>>2]|0;
          $274 = ($273|0)==($267|0);
          if ($274) {
           $$pr = $264;
           break L27;
          }
          $275 = ((($this) + ($272)|0) + 5540|0);
          $nextInd$0$i15 = HEAP8[$275>>0]|0;
          $276 = $nextInd$0$i15&255;
          $277 = ($nextInd$0$i15<<24>>24)==(-1);
          if ($277) {
           break;
          } else {
           $272 = $276;$nextInd$03$i14 = $nextInd$0$i15;
          }
         }
         $279 = $264&255;
         $280 = $nextInd$03$i14&255;
         $281 = ((($this) + ($280)|0) + 5540|0);
         HEAP8[$281>>0] = $279;
         label = 24;
        }
       } while(0);
       if ((label|0) == 24) {
        label = 0;
        $282 = HEAP32[$25>>2]|0;
        $283 = ((($this) + ($282)|0) + 5540|0);
        HEAP8[$283>>0] = -1;
        $284 = HEAP32[$25>>2]|0;
        $285 = (($284) + 1)|0;
        HEAP32[$25>>2] = $285;
        $286 = ((($this) + ($284<<2)|0) + 5284|0);
        HEAP32[$286>>2] = $267;
        $$pr$pre = HEAP32[$25>>2]|0;
        $$pr = $$pr$pre;
       }
       $287 = HEAP32[$235>>2]|0;
       $288 = ($$pr|0)==(64);
       if ($288) {
        $nbDelayed$1 = $nbDelayed$047;
        break;
       }
       $289 = $287 & 63;
       $290 = ((($this) + ($289)|0) + 5604|0);
       $nextInd$02$i3 = HEAP8[$290>>0]|0;
       $291 = ($nextInd$02$i3<<24>>24)==(-1);
       L38: do {
        if ($291) {
         $300 = $$pr&255;
         HEAP8[$290>>0] = $300;
         label = 32;
        } else {
         $292 = $nextInd$02$i3&255;
         $294 = $292;$nextInd$03$i6 = $nextInd$02$i3;
         while(1) {
          $293 = ((($this) + ($294<<2)|0) + 5284|0);
          $295 = HEAP32[$293>>2]|0;
          $296 = ($295|0)==($287|0);
          if ($296) {
           $$pr38$pr = $$pr;
           break L38;
          }
          $297 = ((($this) + ($294)|0) + 5540|0);
          $nextInd$0$i7 = HEAP8[$297>>0]|0;
          $298 = $nextInd$0$i7&255;
          $299 = ($nextInd$0$i7<<24>>24)==(-1);
          if ($299) {
           break;
          } else {
           $294 = $298;$nextInd$03$i6 = $nextInd$0$i7;
          }
         }
         $301 = $$pr&255;
         $302 = $nextInd$03$i6&255;
         $303 = ((($this) + ($302)|0) + 5540|0);
         HEAP8[$303>>0] = $301;
         label = 32;
        }
       } while(0);
       if ((label|0) == 32) {
        label = 0;
        $304 = HEAP32[$25>>2]|0;
        $305 = ((($this) + ($304)|0) + 5540|0);
        HEAP8[$305>>0] = -1;
        $306 = HEAP32[$25>>2]|0;
        $307 = (($306) + 1)|0;
        HEAP32[$25>>2] = $307;
        $308 = ((($this) + ($306<<2)|0) + 5284|0);
        HEAP32[$308>>2] = $287;
        $$pr38$pr$pre = HEAP32[$25>>2]|0;
        $$pr38$pr = $$pr38$pr$pre;
       }
       $309 = HEAP32[$237>>2]|0;
       $310 = ($$pr38$pr|0)==(64);
       if ($310) {
        $nbDelayed$1 = $nbDelayed$047;
        break;
       }
       $311 = $309 & 63;
       $312 = ((($this) + ($311)|0) + 5604|0);
       $nextInd$02$i = HEAP8[$312>>0]|0;
       $313 = ($nextInd$02$i<<24>>24)==(-1);
       if ($313) {
        $322 = $$pr38$pr&255;
        HEAP8[$312>>0] = $322;
       } else {
        $314 = $nextInd$02$i&255;
        $316 = $314;$nextInd$03$i = $nextInd$02$i;
        while(1) {
         $315 = ((($this) + ($316<<2)|0) + 5284|0);
         $317 = HEAP32[$315>>2]|0;
         $318 = ($317|0)==($309|0);
         if ($318) {
          $nbDelayed$1 = $nbDelayed$047;
          break L6;
         }
         $319 = ((($this) + ($316)|0) + 5540|0);
         $nextInd$0$i = HEAP8[$319>>0]|0;
         $320 = $nextInd$0$i&255;
         $321 = ($nextInd$0$i<<24>>24)==(-1);
         if ($321) {
          break;
         } else {
          $316 = $320;$nextInd$03$i = $nextInd$0$i;
         }
        }
        $323 = $$pr38$pr&255;
        $324 = $nextInd$03$i&255;
        $325 = ((($this) + ($324)|0) + 5540|0);
        HEAP8[$325>>0] = $323;
       }
       $326 = HEAP32[$25>>2]|0;
       $327 = ((($this) + ($326)|0) + 5540|0);
       HEAP8[$327>>0] = -1;
       $328 = HEAP32[$25>>2]|0;
       $329 = (($328) + 1)|0;
       HEAP32[$25>>2] = $329;
       $330 = ((($this) + ($328<<2)|0) + 5284|0);
       HEAP32[$330>>2] = $309;
       $nbDelayed$1 = $nbDelayed$047;
       break;
      }
     }
     $331 = ($nbDelayed$047>>>0)<(64);
     if ($331) {
      $332 = (($nbDelayed$047) + 1)|0;
      $333 = Math_fround(HEAPF32[$v0>>2]);
      $334 = ((($this) + ($nbDelayed$047<<6)|0) + 32|0);
      HEAPF32[$334>>2] = $333;
      $335 = Math_fround(HEAPF32[$11>>2]);
      $336 = ((($this) + ($nbDelayed$047<<6)|0) + 36|0);
      HEAPF32[$336>>2] = $335;
      $337 = Math_fround(HEAPF32[$12>>2]);
      $338 = ((($this) + ($nbDelayed$047<<6)|0) + 40|0);
      HEAPF32[$338>>2] = $337;
      $339 = Math_fround(HEAPF32[$v1>>2]);
      $340 = ((($this) + ($nbDelayed$047<<6)|0) + 44|0);
      HEAPF32[$340>>2] = $339;
      $341 = Math_fround(HEAPF32[$13>>2]);
      $342 = ((($this) + ($nbDelayed$047<<6)|0) + 48|0);
      HEAPF32[$342>>2] = $341;
      $343 = Math_fround(HEAPF32[$14>>2]);
      $344 = ((($this) + ($nbDelayed$047<<6)|0) + 52|0);
      HEAPF32[$344>>2] = $343;
      $345 = Math_fround(HEAPF32[$v2>>2]);
      $346 = ((($this) + ($nbDelayed$047<<6)|0) + 56|0);
      HEAPF32[$346>>2] = $345;
      $347 = Math_fround(HEAPF32[$15>>2]);
      $348 = ((($this) + ($nbDelayed$047<<6)|0) + 60|0);
      HEAPF32[$348>>2] = $347;
      $349 = Math_fround(HEAPF32[$16>>2]);
      $350 = ((($this) + ($nbDelayed$047<<6)|0) + 64|0);
      HEAPF32[$350>>2] = $349;
      $351 = HEAP32[$vertIndex$044>>2]|0;
      $352 = ((($this) + ($nbDelayed$047<<6)|0) + 84|0);
      HEAP32[$352>>2] = $351;
      $353 = (($vertIndex$044) + 4|0);
      $354 = HEAP32[$353>>2]|0;
      $355 = ((($this) + ($nbDelayed$047<<6)|0) + 88|0);
      HEAP32[$355>>2] = $354;
      $356 = (($vertIndex$044) + 8|0);
      $357 = HEAP32[$356>>2]|0;
      $358 = ((($this) + ($nbDelayed$047<<6)|0) + 92|0);
      HEAP32[$358>>2] = $357;
      $359 = Math_fround(HEAPF32[$uu>>2]);
      $360 = ((($this) + ($nbDelayed$047<<6)|0) + 68|0);
      HEAPF32[$360>>2] = $359;
      $361 = Math_fround(HEAPF32[$vv>>2]);
      $362 = ((($this) + ($nbDelayed$047<<6)|0) + 72|0);
      HEAPF32[$362>>2] = $361;
      $363 = ((($this) + ($nbDelayed$047<<6)|0) + 76|0);
      HEAPF32[$363>>2] = $65;
      $364 = ((($this) + ($nbDelayed$047<<6)|0) + 80|0);
      HEAP32[$364>>2] = $28;
      $nbDelayed$1 = $332;
     } else {
      $nbDelayed$1 = $nbDelayed$047;
     }
    }
   } else {
    $nbDelayed$1 = $nbDelayed$047;
   }
  } while(0);
  $365 = HEAP32[$6>>2]|0;
  $366 = ($a$043>>>0)<($365>>>0);
  if (!($366)) {
   $nbDelayed$0$lcssa = $nbDelayed$1;
   break;
  }
  $phitmp = (($a$043) + 1)|0;
  $a$043 = $phitmp;$nbDelayed$047 = $nbDelayed$1;$triIndex$046 = $27;$vertIndex$044 = $47;$verts$045 = $40;
 }
 HEAP32[$4>>2] = $nbDelayed$0$lcssa;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_127SphereMeshContactGenerationD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_135SphereMeshContactGenerationCallbackD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_135SphereMeshContactGenerationCallback10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj($this,$hit,$v0,$v1,$v2,$0,$vinds) {
 $this = $this|0;
 $hit = $hit|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 $0 = $0|0;
 $vinds = $vinds|0;
 var $$phi$trans$insert11 = 0, $$phi$trans$insert13 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert17 = 0, $$phi$trans$insert19 = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert7 = 0, $$phi$trans$insert9 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre12 = Math_fround(0), $$pre14 = Math_fround(0), $$pre16 = Math_fround(0), $$pre18 = Math_fround(0), $$pre20 = Math_fround(0), $$pre22 = Math_fround(0), $$pre8 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = 0;
 var $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = 0, $98 = 0, $99 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $v = sp;
 $1 = (($this) + 5688|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $27 = (($this) + 5684|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = Math_fround(HEAPF32[$v0>>2]);
  $30 = Math_fround(HEAPF32[$28>>2]);
  $31 = Math_fround($29 * $30);
  $32 = (($28) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($29 * $33);
  $35 = (($28) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($29 * $36);
  $38 = (($v0) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($28) + 12|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($39 * $41);
  $43 = (($28) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($39 * $44);
  $46 = (($28) + 20|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($39 * $47);
  $49 = Math_fround($31 + $42);
  $50 = Math_fround($34 + $45);
  $51 = Math_fround($37 + $48);
  $52 = (($v0) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($28) + 24|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($53 * $55);
  $57 = (($28) + 28|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($53 * $58);
  $60 = (($28) + 32|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($53 * $61);
  $63 = Math_fround($49 + $56);
  $64 = Math_fround($50 + $59);
  $65 = Math_fround($51 + $62);
  HEAPF32[$v>>2] = $63;
  $66 = (($v) + 4|0);
  HEAPF32[$66>>2] = $64;
  $67 = (($v) + 8|0);
  HEAPF32[$67>>2] = $65;
  $68 = Math_fround(HEAPF32[$v1>>2]);
  $69 = Math_fround(HEAPF32[$28>>2]);
  $70 = Math_fround($68 * $69);
  $71 = Math_fround(HEAPF32[$32>>2]);
  $72 = Math_fround($68 * $71);
  $73 = Math_fround(HEAPF32[$35>>2]);
  $74 = Math_fround($68 * $73);
  $75 = (($v1) + 4|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround(HEAPF32[$40>>2]);
  $78 = Math_fround($76 * $77);
  $79 = Math_fround(HEAPF32[$43>>2]);
  $80 = Math_fround($76 * $79);
  $81 = Math_fround(HEAPF32[$46>>2]);
  $82 = Math_fround($76 * $81);
  $83 = Math_fround($70 + $78);
  $84 = Math_fround($72 + $80);
  $85 = Math_fround($74 + $82);
  $86 = (($v1) + 8|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = Math_fround(HEAPF32[$54>>2]);
  $89 = Math_fround($87 * $88);
  $90 = Math_fround(HEAPF32[$57>>2]);
  $91 = Math_fround($87 * $90);
  $92 = Math_fround(HEAPF32[$60>>2]);
  $93 = Math_fround($87 * $92);
  $94 = Math_fround($83 + $89);
  $95 = Math_fround($84 + $91);
  $96 = Math_fround($85 + $93);
  $97 = (($v) + 12|0);
  HEAPF32[$97>>2] = $94;
  $98 = (($v) + 16|0);
  HEAPF32[$98>>2] = $95;
  $99 = (($v) + 20|0);
  HEAPF32[$99>>2] = $96;
  $100 = Math_fround(HEAPF32[$v2>>2]);
  $101 = Math_fround(HEAPF32[$28>>2]);
  $102 = Math_fround($100 * $101);
  $103 = Math_fround(HEAPF32[$32>>2]);
  $104 = Math_fround($100 * $103);
  $105 = Math_fround(HEAPF32[$35>>2]);
  $106 = Math_fround($100 * $105);
  $107 = (($v2) + 4|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround(HEAPF32[$40>>2]);
  $110 = Math_fround($108 * $109);
  $111 = Math_fround(HEAPF32[$43>>2]);
  $112 = Math_fround($108 * $111);
  $113 = Math_fround(HEAPF32[$46>>2]);
  $114 = Math_fround($108 * $113);
  $115 = Math_fround($102 + $110);
  $116 = Math_fround($104 + $112);
  $117 = Math_fround($106 + $114);
  $118 = (($v2) + 8|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround(HEAPF32[$54>>2]);
  $121 = Math_fround($119 * $120);
  $122 = Math_fround(HEAPF32[$57>>2]);
  $123 = Math_fround($119 * $122);
  $124 = Math_fround(HEAPF32[$60>>2]);
  $125 = Math_fround($119 * $124);
  $126 = Math_fround($115 + $121);
  $127 = Math_fround($116 + $123);
  $128 = Math_fround($117 + $125);
  $129 = (($v) + 24|0);
  HEAPF32[$129>>2] = $126;
  $130 = (($v) + 28|0);
  HEAPF32[$130>>2] = $127;
  $131 = (($v) + 32|0);
  HEAPF32[$131>>2] = $128;
  $178 = $128;$179 = $127;$180 = $126;$181 = $96;$182 = $95;$183 = $94;$184 = $65;$185 = $64;$186 = $63;
 } else {
  $4 = Math_fround(HEAPF32[$v0>>2]);
  HEAPF32[$v>>2] = $4;
  $5 = (($v0) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($v) + 4|0);
  HEAPF32[$7>>2] = $6;
  $8 = (($v0) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($v) + 8|0);
  HEAPF32[$10>>2] = $9;
  $11 = Math_fround(HEAPF32[$v1>>2]);
  $12 = (($v) + 12|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($v1) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($v) + 16|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($v1) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($v) + 20|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround(HEAPF32[$v2>>2]);
  $20 = (($v) + 24|0);
  HEAPF32[$20>>2] = $19;
  $21 = (($v2) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($v) + 28|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($v2) + 8|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($v) + 32|0);
  HEAPF32[$26>>2] = $25;
  $178 = $25;$179 = $22;$180 = $19;$181 = $17;$182 = $14;$183 = $11;$184 = $9;$185 = $6;$186 = $4;
 }
 $132 = (($hit) + 8|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (($this) + 5680|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($135) + 152|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (($137) + ($133)|0);
 $139 = HEAP8[$138>>0]|0;
 $140 = (($this) + 6540|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = ($141|0)==(16);
 if (!($142)) {
  $146 = $141;$149 = $186;$151 = $185;$153 = $184;$156 = $183;$158 = $182;$160 = $181;$163 = $180;$165 = $179;$167 = $178;
  $145 = (($146) + 1)|0;
  HEAP32[$140>>2] = $145;
  $147 = ($146*3)|0;
  $148 = ((($this) + (($147*12)|0)|0) + 5692|0);
  HEAPF32[$148>>2] = $149;
  $150 = ((($this) + (($147*12)|0)|0) + 5696|0);
  HEAPF32[$150>>2] = $151;
  $152 = ((($this) + (($147*12)|0)|0) + 5700|0);
  HEAPF32[$152>>2] = $153;
  $154 = (($147) + 1)|0;
  $155 = ((($this) + (($154*12)|0)|0) + 5692|0);
  HEAPF32[$155>>2] = $156;
  $157 = ((($this) + (($154*12)|0)|0) + 5696|0);
  HEAPF32[$157>>2] = $158;
  $159 = ((($this) + (($154*12)|0)|0) + 5700|0);
  HEAPF32[$159>>2] = $160;
  $161 = (($147) + 2)|0;
  $162 = ((($this) + (($161*12)|0)|0) + 5692|0);
  HEAPF32[$162>>2] = $163;
  $164 = ((($this) + (($161*12)|0)|0) + 5696|0);
  HEAPF32[$164>>2] = $165;
  $166 = ((($this) + (($161*12)|0)|0) + 5700|0);
  HEAPF32[$166>>2] = $167;
  $168 = HEAP32[$vinds>>2]|0;
  $169 = ((($this) + ($147<<2)|0) + 6268|0);
  HEAP32[$169>>2] = $168;
  $170 = (($vinds) + 4|0);
  $171 = HEAP32[$170>>2]|0;
  $172 = ((($this) + ($154<<2)|0) + 6268|0);
  HEAP32[$172>>2] = $171;
  $173 = (($vinds) + 8|0);
  $174 = HEAP32[$173>>2]|0;
  $175 = ((($this) + ($161<<2)|0) + 6268|0);
  HEAP32[$175>>2] = $174;
  $176 = ((($this) + ($146<<2)|0) + 6460|0);
  HEAP32[$176>>2] = $133;
  $177 = ((($this) + ($146)|0) + 6524|0);
  HEAP8[$177>>0] = $139;
  STACKTOP = sp;return 1;
 }
 $143 = (($this) + 5692|0);
 $144 = (($this) + 8|0);
 __ZN12_GLOBAL__N_127SphereMeshContactGeneration20processTriangleCacheILj16EEEbRN5physx2Gu13TriangleCacheIXT_EEE($144,$143);
 HEAP32[$140>>2] = 0;
 $$pre = Math_fround(HEAPF32[$v>>2]);
 $$phi$trans$insert7 = (($v) + 4|0);
 $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
 $$phi$trans$insert9 = (($v) + 8|0);
 $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert9>>2]);
 $$phi$trans$insert11 = (($v) + 12|0);
 $$pre12 = Math_fround(HEAPF32[$$phi$trans$insert11>>2]);
 $$phi$trans$insert13 = (($v) + 16|0);
 $$pre14 = Math_fround(HEAPF32[$$phi$trans$insert13>>2]);
 $$phi$trans$insert15 = (($v) + 20|0);
 $$pre16 = Math_fround(HEAPF32[$$phi$trans$insert15>>2]);
 $$phi$trans$insert17 = (($v) + 24|0);
 $$pre18 = Math_fround(HEAPF32[$$phi$trans$insert17>>2]);
 $$phi$trans$insert19 = (($v) + 28|0);
 $$pre20 = Math_fround(HEAPF32[$$phi$trans$insert19>>2]);
 $$phi$trans$insert21 = (($v) + 32|0);
 $$pre22 = Math_fround(HEAPF32[$$phi$trans$insert21>>2]);
 $146 = 0;$149 = $$pre;$151 = $$pre8;$153 = $$pre10;$156 = $$pre12;$158 = $$pre14;$160 = $$pre16;$163 = $$pre18;$165 = $$pre20;$167 = $$pre22;
 $145 = (($146) + 1)|0;
 HEAP32[$140>>2] = $145;
 $147 = ($146*3)|0;
 $148 = ((($this) + (($147*12)|0)|0) + 5692|0);
 HEAPF32[$148>>2] = $149;
 $150 = ((($this) + (($147*12)|0)|0) + 5696|0);
 HEAPF32[$150>>2] = $151;
 $152 = ((($this) + (($147*12)|0)|0) + 5700|0);
 HEAPF32[$152>>2] = $153;
 $154 = (($147) + 1)|0;
 $155 = ((($this) + (($154*12)|0)|0) + 5692|0);
 HEAPF32[$155>>2] = $156;
 $157 = ((($this) + (($154*12)|0)|0) + 5696|0);
 HEAPF32[$157>>2] = $158;
 $159 = ((($this) + (($154*12)|0)|0) + 5700|0);
 HEAPF32[$159>>2] = $160;
 $161 = (($147) + 2)|0;
 $162 = ((($this) + (($161*12)|0)|0) + 5692|0);
 HEAPF32[$162>>2] = $163;
 $164 = ((($this) + (($161*12)|0)|0) + 5696|0);
 HEAPF32[$164>>2] = $165;
 $166 = ((($this) + (($161*12)|0)|0) + 5700|0);
 HEAPF32[$166>>2] = $167;
 $168 = HEAP32[$vinds>>2]|0;
 $169 = ((($this) + ($147<<2)|0) + 6268|0);
 HEAP32[$169>>2] = $168;
 $170 = (($vinds) + 4|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = ((($this) + ($154<<2)|0) + 6268|0);
 HEAP32[$172>>2] = $171;
 $173 = (($vinds) + 8|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ((($this) + ($161<<2)|0) + 6268|0);
 HEAP32[$175>>2] = $174;
 $176 = ((($this) + ($146<<2)|0) + 6460|0);
 HEAP32[$176>>2] = $133;
 $177 = ((($this) + ($146)|0) + 6524|0);
 HEAP8[$177>>0] = $139;
 STACKTOP = sp;return 1;
}
function __ZN12_GLOBAL__N_135SphereMeshContactGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu18computeFeatureCodeEff($u,$v) {
 $u = Math_fround($u);
 $v = Math_fround($v);
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $u == Math_fround(0.0);
 do {
  if ($0) {
   $1 = $v == Math_fround(0.0);
   if ($1) {
    $$0 = 0;
   } else {
    $2 = $v == Math_fround(1.0);
    $$ = $2 ? 2 : 5;
    $$0 = $$;
   }
  } else {
   $3 = $u == Math_fround(1.0);
   $4 = $v == Math_fround(0.0);
   if ($3) {
    $$1 = $4 ? 1 : 7;
    $$0 = $$1;
    break;
   }
   if ($4) {
    $$0 = 3;
   } else {
    $5 = Math_fround($u + $v);
    $6 = !($5 >= Math_fround(0.999899983406066894531));
    $$2 = $6 ? 6 : 4;
    $$0 = $$2;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu12selectNormalEhff($data,$u,$v) {
 $data = $data|0;
 $u = Math_fround($u);
 $v = Math_fround($v);
 var $$$i = 0, $$0$i = 0, $$1$i = 0, $$2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $useFaceNormal$0$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $u == Math_fround(0.0);
 do {
  if ($0) {
   $1 = $v == Math_fround(0.0);
   if ($1) {
    label = 9;
   } else {
    $2 = $v == Math_fround(1.0);
    $$$i = $2 ? 2 : 5;
    $$0$i = $$$i;
    label = 8;
   }
  } else {
   $3 = $u == Math_fround(1.0);
   $4 = $v == Math_fround(0.0);
   if ($3) {
    $$1$i = $4 ? 1 : 7;
    $$0$i = $$1$i;
    label = 8;
    break;
   }
   if ($4) {
    label = 12;
   } else {
    $5 = Math_fround($u + $v);
    $6 = !($5 >= Math_fround(0.999899983406066894531));
    $$2$i = $6 ? 6 : 4;
    $$0$i = $$2$i;
    label = 8;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 8) {
   switch ($$0$i|0) {
   case 6:  {
    $useFaceNormal$0$off0 = 1;
    break L9;
    break;
   }
   case 0:  {
    label = 9;
    break L9;
    break;
   }
   case 2:  {
    $11 = $data & 48;
    $12 = ($11<<24>>24)==(0);
    $useFaceNormal$0$off0 = $12;
    break L9;
    break;
   }
   case 4:  {
    $15 = $data & 16;
    $16 = ($15<<24>>24)==(0);
    $useFaceNormal$0$off0 = $16;
    break L9;
    break;
   }
   case 1:  {
    $9 = $data & 24;
    $10 = ($9<<24>>24)==(0);
    $useFaceNormal$0$off0 = $10;
    break L9;
    break;
   }
   case 5:  {
    $17 = $data & 32;
    $18 = ($17<<24>>24)==(0);
    STACKTOP = sp;return ($18|0);
    break;
   }
   case 3:  {
    label = 12;
    break L9;
    break;
   }
   default: {
    $useFaceNormal$0$off0 = 0;
    break L9;
   }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $7 = $data & 40;
  $8 = ($7<<24>>24)==(0);
  $useFaceNormal$0$off0 = $8;
 }
 else if ((label|0) == 12) {
  $13 = $data & 8;
  $14 = ($13<<24>>24)==(0);
  $useFaceNormal$0$off0 = $14;
 }
 STACKTOP = sp;return ($useFaceNormal$0$off0|0);
}
function __ZN5physx2Gu14SeparatingAxes7addAxisERKNS_6PxVec3E($this,$axis) {
 $this = $this|0;
 $axis = $axis|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $axes$01 = 0, $fabsf$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ((($this) + (($0*12)|0)|0) + 4|0);
 $2 = ($0|0)>(0);
 L1: do {
  if ($2) {
   $3 = (($this) + 4|0);
   $4 = Math_fround(HEAPF32[$axis>>2]);
   $5 = (($axis) + 4|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = (($axis) + 8|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $axes$01 = $3;
   while(1) {
    $11 = Math_fround(HEAPF32[$axes$01>>2]);
    $12 = Math_fround($4 * $11);
    $13 = (($axes$01) + 4|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $15 = Math_fround($6 * $14);
    $16 = Math_fround($12 + $15);
    $17 = (($axes$01) + 8|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = Math_fround($8 * $18);
    $20 = Math_fround($16 + $19);
    $fabsf$i$i = (Math_fround(Math_abs((Math_fround($20)))));
    $21 = $fabsf$i$i > Math_fround(0.999899983406066894531);
    $10 = (($axes$01) + 12|0);
    if ($21) {
     $$0 = 0;
     break;
    }
    $9 = ($10>>>0)<($1>>>0);
    if ($9) {
     $axes$01 = $10;
    } else {
     break L1;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $22 = ($0>>>0)<(256);
 if (!($22)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = (($0) + 1)|0;
 HEAP32[$this>>2] = $23;
 $24 = Math_fround(HEAPF32[$axis>>2]);
 $25 = ((($this) + (($0*12)|0)|0) + 4|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($axis) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = ((($this) + (($0*12)|0)|0) + 8|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($axis) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = ((($this) + (($0*12)|0)|0) + 12|0);
 HEAPF32[$31>>2] = $30;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13BigConvexDataC2Ev($this) {
 $this = $this|0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$this+0|0; stop=dest+28|0; do { HEAP16[dest>>1]=0|0; dest=dest+2|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx13BigConvexDataD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 3|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$5);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (($this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$10);
  $11 = (($this) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$12);
  STACKTOP = sp;return;
 } else {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$7);
  STACKTOP = sp;return;
 }
}
function __ZN5physx13BigConvexData13CreateOffsetsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 2|0);
 HEAP16[$2>>1] = 0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>(1);
 if ($5) {
  $8 = 0;$i$01 = 1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $6 = (($i$01) + -1)|0;
  $7 = $8 & 65535;
  $9 = (($1) + ($6<<2)|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = $10&65535;
  $12 = (($11) + ($7))|0;
  $13 = $12&65535;
  $14 = ((($1) + ($i$01<<2)|0) + 2|0);
  HEAP16[$14>>1] = $13;
  $15 = (($i$01) + 1)|0;
  $16 = ($15>>>0)<($4>>>0);
  if ($16) {
   $8 = $12;$i$01 = $15;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx13BigConvexData5VLoadERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $Mismatch = 0;
 var $Version = 0, $exitcond = 0, $i$01 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $Version = sp;
 $Mismatch = sp + 6|0;
 $0 = sp + 4|0;
 $1 = sp + 5|0;
 $2 = (__ZN5physx2Gu10ReadHeaderEhhhhRjRbRNS_13PxInputStreamE(86,65,76,69,$Version,$Mismatch,$stream)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$Mismatch>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($4,$stream)|0);
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP8[$Mismatch>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($8,$stream)|0);
 $10 = (($this) + 12|0);
 HEAP32[$10>>2] = $9;
 $11 = (($this) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$12);
 $13 = HEAP32[$6>>2]|0;
 $14 = $13 << 2;
 $15 = (($14) + 12)|0;
 $16 = $15 & -16;
 $17 = HEAP32[$10>>2]|0;
 $18 = (($16) + ($17))|0;
 $19 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$18,548960,97)|0);
 HEAP32[$11>>2] = $19;
 $20 = (($this) + 16|0);
 HEAP32[$20>>2] = $19;
 $21 = (($19) + ($16)|0);
 $22 = (($this) + 20|0);
 HEAP32[$22>>2] = $21;
 $23 = HEAP8[$Mismatch>>0]|0;
 $24 = ($23<<24>>24)!=(0);
 $25 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($24,$stream)|0);
 $26 = $25&65535;
 $27 = HEAP32[$6>>2]|0;
 $28 = HEAP8[$Mismatch>>0]|0;
 $29 = ($28<<24>>24)!=(0);
 __ZN5physx2Gu11ReadIndicesEtjPtRNS_13PxInputStreamEb($26,$27,$19,$stream,$29);
 $30 = HEAP32[$6>>2]|0;
 $31 = ($30|0)==(0);
 if (!($31)) {
  $32 = HEAP32[$20>>2]|0;
  $i$01 = 0;
  while(1) {
   $33 = (($30) - ($i$01))|0;
   $34 = (($33) + -1)|0;
   $35 = (($19) + ($34<<1)|0);
   $36 = HEAP16[$35>>1]|0;
   $37 = (($32) + ($34<<2)|0);
   HEAP16[$37>>1] = $36;
   $38 = (($i$01) + 1)|0;
   $39 = ($38>>>0)<($30>>>0);
   if ($39) {
    $i$01 = $38;
   } else {
    break;
   }
  }
 }
 $40 = HEAP32[$stream>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$22>>2]|0;
 $43 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iiii[$41 & 2047]($stream,$42,$43)|0);
 $44 = HEAP32[$20>>2]|0;
 $45 = (($44) + 2|0);
 HEAP16[$45>>1] = 0;
 $46 = HEAP32[$6>>2]|0;
 $47 = ($46>>>0)>(1);
 if ($47) {
  $50 = 0;$i$01$i = 1;
 } else {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $48 = (($i$01$i) + -1)|0;
  $49 = $50 & 65535;
  $51 = (($44) + ($48<<2)|0);
  $52 = HEAP16[$51>>1]|0;
  $53 = $52&65535;
  $54 = (($53) + ($49))|0;
  $55 = $54&65535;
  $56 = ((($44) + ($i$01$i<<2)|0) + 2|0);
  HEAP16[$56>>1] = $55;
  $57 = (($i$01$i) + 1)|0;
  $exitcond = ($57|0)==($46|0);
  if ($exitcond) {
   $$0 = 1;
   break;
  } else {
   $50 = $54;$i$01$i = $57;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13BigConvexData4LoadERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $Mismatch = 0, $Version = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $Version = sp;
 $Mismatch = sp + 5|0;
 $0 = sp + 4|0;
 $1 = (__ZN5physx2Gu10ReadHeaderEhhhhRjRbRNS_13PxInputStreamE(83,85,80,77,$Version,$Mismatch,$stream)|0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__ZN5physx2Gu10ReadHeaderEhhhhRjRbRNS_13PxInputStreamE(71,65,85,83,$Version,$Mismatch,$stream)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$Mismatch>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($4,$stream)|0);
 $6 = $5&65535;
 HEAP16[$this>>1] = $6;
 $7 = HEAP8[$Mismatch>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($8,$stream)|0);
 $10 = $9&65535;
 $11 = (($this) + 2|0);
 HEAP16[$11>>1] = $10;
 $12 = $9 << 1;
 $13 = $12 & 131070;
 $14 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$13,548960,159)|0);
 $15 = (($this) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$stream>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP16[$11>>1]|0;
 $19 = $18&65535;
 $20 = $19 << 1;
 (FUNCTION_TABLE_iiii[$17 & 2047]($stream,$14,$20)|0);
 $21 = (__ZN5physx13BigConvexData5VLoadERNS_13PxInputStreamE($this,$stream)|0);
 $$0 = $21;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx13BigConvexData15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$stream>>2]|0;
  $4 = (($3) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($stream,16);
  $6 = HEAP32[$stream>>2]|0;
  $7 = (($6) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = (($this) + 2|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = $11&65535;
  $13 = $12 << 1;
  FUNCTION_TABLE_viii[$8 & 4095]($stream,$9,$13);
 }
 $14 = (($this) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$stream>>2]|0;
 $18 = (($17) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vii[$19 & 4095]($stream,16);
 $20 = (($this) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 << 2;
 $23 = (($22) + 12)|0;
 $24 = $23 & -16;
 $25 = (($this) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + ($26))|0;
 $28 = HEAP32[$stream>>2]|0;
 $29 = (($28) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_viii[$30 & 4095]($stream,$31,$27);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15getScaledConvexERPNS_6PxVec3ERPhS2_S4_bPKS1_PKhjRKNS_2Cm23FastVertex2ShapeScalingE($scaledVertices,$scaledIndices,$dstVertices,$dstIndices,$idtConvexScale,$srcVerts,$srcIndices,$nbVerts,$convexScaling) {
 $scaledVertices = $scaledVertices|0;
 $scaledIndices = $scaledIndices|0;
 $dstVertices = $dstVertices|0;
 $dstIndices = $dstIndices|0;
 $idtConvexScale = $idtConvexScale|0;
 $srcVerts = $srcVerts|0;
 $srcIndices = $srcIndices|0;
 $nbVerts = $nbVerts|0;
 $convexScaling = $convexScaling|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($idtConvexScale) {
  HEAP32[$scaledVertices>>2] = $srcVerts;
  HEAP32[$scaledIndices>>2] = $srcIndices;
  STACKTOP = sp;return;
 }
 HEAP32[$scaledIndices>>2] = $dstIndices;
 HEAP32[$scaledVertices>>2] = $dstVertices;
 $0 = ($nbVerts|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($convexScaling) + 4|0);
 $2 = (($convexScaling) + 8|0);
 $3 = (($convexScaling) + 12|0);
 $4 = (($convexScaling) + 16|0);
 $5 = (($convexScaling) + 20|0);
 $6 = (($convexScaling) + 24|0);
 $7 = (($convexScaling) + 28|0);
 $8 = (($convexScaling) + 32|0);
 $i$01 = 0;
 while(1) {
  $9 = $i$01&255;
  $10 = HEAP32[$scaledIndices>>2]|0;
  $11 = (($10) + ($i$01)|0);
  HEAP8[$11>>0] = $9;
  $12 = HEAP32[$scaledVertices>>2]|0;
  $13 = (($srcIndices) + ($i$01)|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = (($srcVerts) + (($15*12)|0)|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround(HEAPF32[$convexScaling>>2]);
  $19 = Math_fround($17 * $18);
  $20 = Math_fround(HEAPF32[$1>>2]);
  $21 = Math_fround($17 * $20);
  $22 = Math_fround(HEAPF32[$2>>2]);
  $23 = Math_fround($17 * $22);
  $24 = ((($srcVerts) + (($15*12)|0)|0) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround(HEAPF32[$3>>2]);
  $27 = Math_fround($25 * $26);
  $28 = Math_fround(HEAPF32[$4>>2]);
  $29 = Math_fround($25 * $28);
  $30 = Math_fround(HEAPF32[$5>>2]);
  $31 = Math_fround($25 * $30);
  $32 = Math_fround($19 + $27);
  $33 = Math_fround($21 + $29);
  $34 = Math_fround($23 + $31);
  $35 = ((($srcVerts) + (($15*12)|0)|0) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround(HEAPF32[$6>>2]);
  $38 = Math_fround($36 * $37);
  $39 = Math_fround(HEAPF32[$7>>2]);
  $40 = Math_fround($36 * $39);
  $41 = Math_fround(HEAPF32[$8>>2]);
  $42 = Math_fround($36 * $41);
  $43 = Math_fround($32 + $38);
  $44 = Math_fround($33 + $40);
  $45 = Math_fround($34 + $42);
  $46 = (($12) + (($i$01*12)|0)|0);
  HEAPF32[$46>>2] = $43;
  $47 = ((($12) + (($i$01*12)|0)|0) + 4|0);
  HEAPF32[$47>>2] = $44;
  $48 = ((($12) + (($i$01*12)|0)|0) + 8|0);
  HEAPF32[$48>>2] = $45;
  $49 = (($i$01) + 1)|0;
  $exitcond = ($49|0)==($nbVerts|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $49;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu13getConvexDataERKNS0_13GeometryUnionERNS_2Cm23FastVertex2ShapeScalingERNS_9PxBounds3ERNS0_13PolygonalDataE($shape,$scaling,$bounds,$polyData) {
 $shape = $shape|0;
 $scaling = $scaling|0;
 $bounds = $bounds|0;
 $polyData = $polyData|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0);
 var $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i$i$i9 = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i1$i$i8 = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i2$i$i7 = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i3$i$i6 = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i4$i$i1 = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i5$i$i2 = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i6$i$i3 = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i7$i$i4 = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0), $fabsf$i$i8$i$i5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == Math_fround(1.0);
 if ($2) {
  $3 = (($shape) + 8|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(1.0);
  if ($5) {
   $6 = (($shape) + 12|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 == Math_fround(1.0);
   if ($8) {
    $95 = (($shape) + 36|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = (($96) + 12|0);
    $99 = Math_fround(HEAPF32[$98>>2]);
    $100 = Math_fround($97 + $99);
    $101 = (($96) + 4|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $103 = (($96) + 16|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = Math_fround($102 + $104);
    $106 = (($96) + 8|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = (($96) + 20|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = Math_fround($107 + $109);
    $111 = Math_fround($100 * Math_fround(0.5));
    $112 = Math_fround($105 * Math_fround(0.5));
    $113 = Math_fround($110 * Math_fround(0.5));
    $114 = Math_fround(HEAPF32[$scaling>>2]);
    $115 = Math_fround($111 * $114);
    $116 = (($scaling) + 4|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = Math_fround($111 * $117);
    $119 = (($scaling) + 8|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = Math_fround($111 * $120);
    $122 = (($scaling) + 12|0);
    $123 = Math_fround(HEAPF32[$122>>2]);
    $124 = Math_fround($112 * $123);
    $125 = (($scaling) + 16|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = Math_fround($112 * $126);
    $128 = (($scaling) + 20|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = Math_fround($112 * $129);
    $131 = Math_fround($115 + $124);
    $132 = Math_fround($118 + $127);
    $133 = Math_fround($121 + $130);
    $134 = (($scaling) + 24|0);
    $135 = Math_fround(HEAPF32[$134>>2]);
    $136 = Math_fround($113 * $135);
    $137 = (($scaling) + 28|0);
    $138 = Math_fround(HEAPF32[$137>>2]);
    $139 = Math_fround($113 * $138);
    $140 = (($scaling) + 32|0);
    $141 = Math_fround(HEAPF32[$140>>2]);
    $142 = Math_fround($113 * $141);
    $143 = Math_fround($131 + $136);
    $144 = Math_fround($132 + $139);
    $145 = Math_fround($133 + $142);
    $146 = Math_fround($99 - $97);
    $147 = Math_fround($104 - $102);
    $148 = Math_fround($109 - $107);
    $149 = Math_fround($146 * Math_fround(0.5));
    $150 = Math_fround($147 * Math_fround(0.5));
    $151 = Math_fround($148 * Math_fround(0.5));
    $152 = Math_fround($149 * $114);
    $153 = Math_fround($149 * $117);
    $154 = Math_fround($149 * $120);
    $155 = Math_fround($150 * $123);
    $156 = Math_fround($150 * $126);
    $157 = Math_fround($150 * $129);
    $158 = Math_fround($151 * $135);
    $159 = Math_fround($151 * $138);
    $160 = Math_fround($151 * $141);
    $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($152)))));
    $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($155)))));
    $161 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
    $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($158)))));
    $162 = Math_fround($161 + $fabsf$i$i6$i$i);
    $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($153)))));
    $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($156)))));
    $163 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
    $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($159)))));
    $164 = Math_fround($163 + $fabsf$i$i3$i$i);
    $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($154)))));
    $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($157)))));
    $165 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
    $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($160)))));
    $166 = Math_fround($165 + $fabsf$i$i$i$i);
    $167 = Math_fround($143 - $162);
    $168 = Math_fround($144 - $164);
    $169 = Math_fround($145 - $166);
    $170 = Math_fround($143 + $162);
    $171 = Math_fround($144 + $164);
    $172 = Math_fround($145 + $166);
    HEAPF32[$bounds>>2] = $167;
    $173 = (($bounds) + 4|0);
    HEAPF32[$173>>2] = $168;
    $174 = (($bounds) + 8|0);
    HEAPF32[$174>>2] = $169;
    $175 = (($bounds) + 12|0);
    HEAPF32[$175>>2] = $170;
    $176 = (($bounds) + 16|0);
    HEAPF32[$176>>2] = $171;
    $177 = (($bounds) + 20|0);
    HEAPF32[$177>>2] = $172;
    $178 = HEAP32[$95>>2]|0;
    __ZN5physx2Gu23getPolygonalData_ConvexEPNS0_13PolygonalDataEPKNS0_14ConvexHullDataERKNS_2Cm23FastVertex2ShapeScalingE($polyData,$178,$scaling);
    $179 = 1;
    STACKTOP = sp;return ($179|0);
   }
  }
 }
 $9 = (($shape) + 16|0);
 __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($scaling,$0,$9);
 $10 = (($shape) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($11) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 + $14);
 $16 = (($11) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($11) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 + $19);
 $21 = (($11) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($11) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 + $24);
 $26 = Math_fround($15 * Math_fround(0.5));
 $27 = Math_fround($20 * Math_fround(0.5));
 $28 = Math_fround($25 * Math_fround(0.5));
 $29 = Math_fround(HEAPF32[$scaling>>2]);
 $30 = Math_fround($26 * $29);
 $31 = (($scaling) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($26 * $32);
 $34 = (($scaling) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($26 * $35);
 $37 = (($scaling) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($27 * $38);
 $40 = (($scaling) + 16|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($27 * $41);
 $43 = (($scaling) + 20|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($27 * $44);
 $46 = Math_fround($30 + $39);
 $47 = Math_fround($33 + $42);
 $48 = Math_fround($36 + $45);
 $49 = (($scaling) + 24|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($28 * $50);
 $52 = (($scaling) + 28|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($28 * $53);
 $55 = (($scaling) + 32|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($28 * $56);
 $58 = Math_fround($46 + $51);
 $59 = Math_fround($47 + $54);
 $60 = Math_fround($48 + $57);
 $61 = Math_fround($14 - $12);
 $62 = Math_fround($19 - $17);
 $63 = Math_fround($24 - $22);
 $64 = Math_fround($61 * Math_fround(0.5));
 $65 = Math_fround($62 * Math_fround(0.5));
 $66 = Math_fround($63 * Math_fround(0.5));
 $67 = Math_fround($64 * $29);
 $68 = Math_fround($64 * $32);
 $69 = Math_fround($64 * $35);
 $70 = Math_fround($65 * $38);
 $71 = Math_fround($65 * $41);
 $72 = Math_fround($65 * $44);
 $73 = Math_fround($66 * $50);
 $74 = Math_fround($66 * $53);
 $75 = Math_fround($66 * $56);
 $fabsf$i$i4$i$i1 = (Math_fround(Math_abs((Math_fround($67)))));
 $fabsf$i$i5$i$i2 = (Math_fround(Math_abs((Math_fround($70)))));
 $76 = Math_fround($fabsf$i$i4$i$i1 + $fabsf$i$i5$i$i2);
 $fabsf$i$i6$i$i3 = (Math_fround(Math_abs((Math_fround($73)))));
 $77 = Math_fround($76 + $fabsf$i$i6$i$i3);
 $fabsf$i$i7$i$i4 = (Math_fround(Math_abs((Math_fround($68)))));
 $fabsf$i$i8$i$i5 = (Math_fround(Math_abs((Math_fround($71)))));
 $78 = Math_fround($fabsf$i$i7$i$i4 + $fabsf$i$i8$i$i5);
 $fabsf$i$i3$i$i6 = (Math_fround(Math_abs((Math_fround($74)))));
 $79 = Math_fround($78 + $fabsf$i$i3$i$i6);
 $fabsf$i$i2$i$i7 = (Math_fround(Math_abs((Math_fround($69)))));
 $fabsf$i$i1$i$i8 = (Math_fround(Math_abs((Math_fround($72)))));
 $80 = Math_fround($fabsf$i$i2$i$i7 + $fabsf$i$i1$i$i8);
 $fabsf$i$i$i$i9 = (Math_fround(Math_abs((Math_fround($75)))));
 $81 = Math_fround($80 + $fabsf$i$i$i$i9);
 $82 = Math_fround($58 - $77);
 $83 = Math_fround($59 - $79);
 $84 = Math_fround($60 - $81);
 $85 = Math_fround($58 + $77);
 $86 = Math_fround($59 + $79);
 $87 = Math_fround($60 + $81);
 HEAPF32[$bounds>>2] = $82;
 $88 = (($bounds) + 4|0);
 HEAPF32[$88>>2] = $83;
 $89 = (($bounds) + 8|0);
 HEAPF32[$89>>2] = $84;
 $90 = (($bounds) + 12|0);
 HEAPF32[$90>>2] = $85;
 $91 = (($bounds) + 16|0);
 HEAPF32[$91>>2] = $86;
 $92 = (($bounds) + 20|0);
 HEAPF32[$92>>2] = $87;
 $93 = HEAP32[$10>>2]|0;
 __ZN5physx2Gu23getPolygonalData_ConvexEPNS0_13PolygonalDataEPKNS0_14ConvexHullDataERKNS_2Cm23FastVertex2ShapeScalingE($polyData,$93,$scaling);
 $94 = (($polyData) + 40|0);
 ;HEAP32[$94+0>>2]=0|0;HEAP32[$94+4>>2]=0|0;HEAP32[$94+8>>2]=0|0;HEAP32[$94+12>>2]=0|0;
 $179 = 0;
 STACKTOP = sp;return ($179|0);
}
function __ZN5physx2Gu21findUniqueConvexEdgesEjPNS0_10ConvexEdgeEjPKNS0_15HullPolygonDataEPKh($maxNbEdges,$edges,$numPolygons,$polygons,$vertexData) {
 $maxNbEdges = $maxNbEdges|0;
 $edges = $edges|0;
 $numPolygons = $numPolygons|0;
 $polygons = $polygons|0;
 $vertexData = $vertexData|0;
 var $$ = 0, $$0 = 0, $$0217 = 0, $$4 = 0, $$in = 0, $$in21 = 0, $$sum = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $a$010 = 0, $a$010$phi = 0, $b$011 = 0, $i$06 = 0, $nbEdges$016 = 0, $nbEdges$1$lcssa = 0, $nbEdges$19 = 0, $nbEdges$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numPolygons|0)==(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0217 = $polygons;$$in = $numPolygons;$nbEdges$016 = 0;
 }
 L3: while(1) {
  $2 = (($$in) + -1)|0;
  $3 = (($$0217) + 20|0);
  $4 = (($$0217) + 16|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = $5&65535;
  $7 = (($$0217) + 18|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = $8&255;
  $10 = ($8<<24>>24)==(0);
  if ($10) {
   $nbEdges$1$lcssa = $nbEdges$016;
  } else {
   $11 = (($9) + -1)|0;
   $12 = (($$0217) + 4|0);
   $13 = (($$0217) + 8|0);
   $$in21 = $9;$a$010 = $11;$b$011 = 0;$nbEdges$19 = $nbEdges$016;
   while(1) {
    $14 = (($$in21) + -1)|0;
    $$sum = (($a$010) + ($6))|0;
    $15 = (($vertexData) + ($$sum)|0);
    $16 = HEAP8[$15>>0]|0;
    $$sum3 = (($b$011) + ($6))|0;
    $17 = (($vertexData) + ($$sum3)|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18&255)<($16&255);
    $$ = $19 ? $18 : $16;
    $$4 = $19 ? $16 : $18;
    $20 = ($nbEdges$19|0)==(0);
    L9: do {
     if ($20) {
      label = 10;
     } else {
      $i$06 = 0;
      while(1) {
       $21 = (($edges) + ($i$06<<4)|0);
       $22 = HEAP8[$21>>0]|0;
       $23 = ($22<<24>>24)==($$<<24>>24);
       if ($23) {
        $24 = ((($edges) + ($i$06<<4)|0) + 1|0);
        $25 = HEAP8[$24>>0]|0;
        $26 = ($25<<24>>24)==($$4<<24>>24);
        if ($26) {
         break;
        }
       }
       $39 = (($i$06) + 1)|0;
       $40 = ($39>>>0)<($nbEdges$19>>>0);
       if ($40) {
        $i$06 = $39;
       } else {
        label = 10;
        break L9;
       }
      }
      $27 = Math_fround(HEAPF32[$$0217>>2]);
      $28 = ((($edges) + ($i$06<<4)|0) + 4|0);
      $29 = Math_fround(HEAPF32[$28>>2]);
      $30 = Math_fround($27 + $29);
      HEAPF32[$28>>2] = $30;
      $31 = Math_fround(HEAPF32[$12>>2]);
      $32 = ((($edges) + ($i$06<<4)|0) + 8|0);
      $33 = Math_fround(HEAPF32[$32>>2]);
      $34 = Math_fround($31 + $33);
      HEAPF32[$32>>2] = $34;
      $35 = Math_fround(HEAPF32[$13>>2]);
      $36 = ((($edges) + ($i$06<<4)|0) + 12|0);
      $37 = Math_fround(HEAPF32[$36>>2]);
      $38 = Math_fround($35 + $37);
      HEAPF32[$36>>2] = $38;
      $nbEdges$2 = $nbEdges$19;
     }
    } while(0);
    if ((label|0) == 10) {
     label = 0;
     $41 = ($nbEdges$19|0)==($maxNbEdges|0);
     if ($41) {
      $$0 = $maxNbEdges;
      label = 13;
      break L3;
     }
     $42 = (($edges) + ($nbEdges$19<<4)|0);
     HEAP8[$42>>0] = $$;
     $43 = ((($edges) + ($nbEdges$19<<4)|0) + 1|0);
     HEAP8[$43>>0] = $$4;
     $44 = Math_fround(HEAPF32[$$0217>>2]);
     $45 = ((($edges) + ($nbEdges$19<<4)|0) + 4|0);
     HEAPF32[$45>>2] = $44;
     $46 = Math_fround(HEAPF32[$12>>2]);
     $47 = ((($edges) + ($nbEdges$19<<4)|0) + 8|0);
     HEAPF32[$47>>2] = $46;
     $48 = Math_fround(HEAPF32[$13>>2]);
     $49 = ((($edges) + ($nbEdges$19<<4)|0) + 12|0);
     HEAPF32[$49>>2] = $48;
     $50 = (($nbEdges$19) + 1)|0;
     $nbEdges$2 = $50;
    }
    $51 = (($b$011) + 1)|0;
    $52 = ($14|0)==(0);
    if ($52) {
     $nbEdges$1$lcssa = $nbEdges$2;
     break;
    } else {
     $a$010$phi = $b$011;$$in21 = $14;$b$011 = $51;$nbEdges$19 = $nbEdges$2;$a$010 = $a$010$phi;
    }
   }
  }
  $1 = ($2|0)==(0);
  if ($1) {
   $$0 = $nbEdges$1$lcssa;
   label = 13;
   break;
  } else {
   $$0217 = $3;$$in = $2;$nbEdges$016 = $nbEdges$1$lcssa;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu10ConvexMesh14getPolygonDataEjRNS_13PxHullPolygonE($this,$i,$data) {
 $this = $this|0;
 $i = $i|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 55|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = ($2>>>0)>($i>>>0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + (($i*20)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$data>>2] = $7;
 $8 = ((($5) + (($i*20)|0)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($data) + 4|0);
 HEAPF32[$10>>2] = $9;
 $11 = ((($5) + (($i*20)|0)|0) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($data) + 8|0);
 HEAPF32[$13>>2] = $12;
 $14 = ((($5) + (($i*20)|0)|0) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($data) + 12|0);
 HEAPF32[$16>>2] = $15;
 $17 = ((($5) + (($i*20)|0)|0) + 18|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = (($data) + 16|0);
 HEAP16[$20>>1] = $19;
 $21 = ((($5) + (($i*20)|0)|0) + 16|0);
 $22 = HEAP16[$21>>1]|0;
 $23 = (($data) + 18|0);
 HEAP16[$23>>1] = $22;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu10ConvexMeshC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 2;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 HEAP32[$this>>2] = ((549600 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = ((424432 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 1;
 HEAP32[$this>>2] = ((549048 + 8|0));
 HEAP32[$2>>2] = ((549048 + 84|0));
 $4 = (($this) + 80|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 84|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 88|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 92|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($this) + 96|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 100|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 104|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 108|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($this) + 112|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 116|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($this) + 120|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($this) + 124|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($this) + 16|0);
 HEAPF32[$16>>2] = Math_fround(8.50705866596322149529E+37);
 $17 = (($this) + 20|0);
 HEAPF32[$17>>2] = Math_fround(8.50705866596322149529E+37);
 $18 = (($this) + 24|0);
 HEAPF32[$18>>2] = Math_fround(8.50705866596322149529E+37);
 $19 = (($this) + 28|0);
 HEAPF32[$19>>2] = Math_fround(-8.50705866596322149529E+37);
 $20 = (($this) + 32|0);
 HEAPF32[$20>>2] = Math_fround(-8.50705866596322149529E+37);
 $21 = (($this) + 36|0);
 HEAPF32[$21>>2] = Math_fround(-8.50705866596322149529E+37);
 $22 = (($this) + 40|0);
 dest=$22+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Gu10ConvexMeshD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 HEAP32[$this>>2] = ((549048 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = ((549048 + 84|0));
 $3 = (($this) + 6|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 1;
 $6 = ($5<<16>>16)==(0);
 if ($6) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
  STACKTOP = sp;return;
 }
 $7 = (($this) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$8);
 HEAP32[$7>>2] = 0;
 $9 = (($this) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  __ZN5physx13BigConvexDataD2Ev($10);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$10);
 }
 HEAP32[$9>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu10ConvexMeshD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + -8|0);
 HEAP32[$2>>2] = ((549048 + 8|0));
 $3 = (($2) + 8|0);
 HEAP32[$3>>2] = ((549048 + 84|0));
 $4 = (($2) + 6|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 & 1;
 $7 = ($6<<16>>16)==(0);
 if ($7) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
  STACKTOP = sp;return;
 }
 $8 = (($2) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$9);
 HEAP32[$8>>2] = 0;
 $10 = (($2) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  __ZN5physx13BigConvexDataD2Ev($11);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
 }
 HEAP32[$10>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$2);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu10ConvexMeshD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 HEAP32[$this>>2] = ((549048 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = ((549048 + 84|0));
 $3 = (($this) + 6|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 1;
 $6 = ($5<<16>>16)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$8);
 HEAP32[$7>>2] = 0;
 $9 = (($this) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  __ZN5physx13BigConvexDataD2Ev($10);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$10);
 }
 HEAP32[$9>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu10ConvexMeshD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (($this) + -8|0);
 HEAP32[$2>>2] = ((549048 + 8|0));
 $3 = (($2) + 8|0);
 HEAP32[$3>>2] = ((549048 + 84|0));
 $4 = (($2) + 6|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 & 1;
 $7 = ($6<<16>>16)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($2) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$9);
 HEAP32[$8>>2] = 0;
 $10 = (($2) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  __ZN5physx13BigConvexDataD2Ev($11);
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
 }
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu10ConvexMesh15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $bytesNeeded$0$i = 0, $tmp1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$stream>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($stream,16);
 $3 = (($this) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = (($this) + 55|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = ($8*20)|0;
 $10 = (($this) + 54|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = (($this) + 52|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = $14&65535;
 $16 = $15 << 1;
 $tmp1$i = ($12*15)|0;
 $17 = (($9) + ($5))|0;
 $18 = (($17) + ($tmp1$i))|0;
 $19 = (($18) + ($16))|0;
 $20 = $19 & 3;
 $21 = ($20|0)==(0);
 if ($21) {
  $bytesNeeded$0$i = $19;
 } else {
  $22 = (($19) + 4)|0;
  $23 = (($22) - ($20))|0;
  $bytesNeeded$0$i = $23;
 }
 $24 = HEAP32[$stream>>2]|0;
 $25 = (($24) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 56|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_viii[$26 & 4095]($stream,$28,$bytesNeeded$0$i);
 $29 = (($this) + 84|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$stream>>2]|0;
 $33 = (($32) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 FUNCTION_TABLE_vii[$34 & 4095]($stream,16);
 $35 = HEAP32[$stream>>2]|0;
 $36 = (($35) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_viii[$37 & 4095]($stream,$38,28);
 $39 = HEAP32[$29>>2]|0;
 __ZN5physx13BigConvexData15exportExtraDataERNS_22PxSerializationContextE($39,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu10ConvexMesh4loadERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$$i$i$i = 0, $$0 = 0, $$sum$i = 0, $$sum1$i = 0, $$sum2$i = 0, $$sum3$i = 0, $$sum4$i = 0, $$sum5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0;
 var $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Mismatch$i = 0, $a$06$i = 0, $bytesNeeded$0$i$i = 0, $i$09$i = 0, $mismatch = 0, $tmp = 0, $tmp$i = 0, $tmp1$i$i = 0;
 var $vararg_buffer = 0, $version = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer = sp;
 $Mismatch$i = sp + 67|0;
 $tmp$i = sp + 8|0;
 $0 = sp + 66|0;
 $1 = sp + 64|0;
 $version = sp + 24|0;
 $mismatch = sp + 65|0;
 $tmp = sp + 32|0;
 $2 = (__ZN5physx10readHeaderEaaaaRjRbRNS_13PxInputStreamE(67,86,88,77,$version,$mismatch,$stream)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$version>>2]|0;
 $4 = ($3>>>0)<(13);
 if ($4) {
  $5 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($5,32,549144,236,549232,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP8[$mismatch>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 (__ZN5physx9readDwordEbRNS_13PxInputStreamE($7,$stream)|0);
 $8 = (__ZN5physx2Gu10ReadHeaderEhhhhRjRbRNS_13PxInputStreamE(67,76,72,76,$vararg_buffer,$Mismatch$i,$stream)|0);
 if (!($8)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__ZN5physx2Gu10ReadHeaderEhhhhRjRbRNS_13PxInputStreamE(67,86,72,76,$vararg_buffer,$Mismatch$i,$stream)|0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP8[$Mismatch$i>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($tmp$i,4,$11,$stream)|0);
 $12 = HEAP32[$tmp$i>>2]|0;
 $13 = $12&255;
 $14 = (($this) + 54|0);
 HEAP8[$14>>0] = $13;
 $15 = (($tmp$i) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16&65535;
 $18 = (($this) + 52|0);
 HEAP16[$18>>1] = $17;
 $19 = (($tmp$i) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20&255;
 $22 = (($this) + 55|0);
 HEAP8[$22>>0] = $21;
 $23 = (($tmp$i) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $20 & 255;
 $26 = ($25*20)|0;
 $27 = $12 & 255;
 $28 = $16 << 1;
 $29 = $28 & 131070;
 $tmp1$i$i = ($27*15)|0;
 $30 = (($24) + ($tmp1$i$i))|0;
 $31 = (($30) + ($29))|0;
 $32 = (($31) + ($26))|0;
 $33 = $32 & 3;
 $34 = ($33|0)==(0);
 if ($34) {
  $bytesNeeded$0$i$i = $32;
 } else {
  $35 = (($32) + 4)|0;
  $36 = (($35) - ($33))|0;
  $bytesNeeded$0$i$i = $36;
 }
 $37 = (($this) + 56|0);
 $38 = HEAP32[$37>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$38);
 $39 = (($this) + 80|0);
 HEAP32[$39>>2] = $24;
 $40 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$bytesNeeded$0$i$i,549144,175)|0);
 HEAP32[$37>>2] = $40;
 $41 = HEAP8[$22>>0]|0;
 $42 = $41&255;
 $43 = ($42*20)|0;
 $44 = (($40) + ($43)|0);
 $45 = HEAP8[$14>>0]|0;
 $46 = $45&255;
 $47 = ($46*12)|0;
 $$sum$i = (($47) + ($43))|0;
 $48 = (($40) + ($$sum$i)|0);
 $49 = HEAP16[$18>>1]|0;
 $50 = $49&65535;
 $51 = $50 << 1;
 $$sum1$i = (($$sum$i) + ($51))|0;
 $52 = (($40) + ($$sum1$i)|0);
 $53 = ($46*3)|0;
 $$sum2$i = (($$sum1$i) + ($53))|0;
 $54 = (($40) + ($$sum2$i)|0);
 $55 = HEAP8[$Mismatch$i>>0]|0;
 $56 = ($55<<24>>24)!=(0);
 (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($44,$53,$56,$stream)|0);
 $57 = HEAP32[$vararg_buffer>>2]|0;
 $58 = ($57>>>0)<(6);
 if ($58) {
  $59 = HEAP8[$Mismatch$i>>0]|0;
  $60 = ($59<<24>>24)!=(0);
  (__ZN5physx8readWordEbRNS_13PxInputStreamE($60,$stream)|0);
 }
 $61 = HEAP32[$stream>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP32[$37>>2]|0;
 $64 = HEAP8[$22>>0]|0;
 $65 = $64&255;
 $66 = ($65*20)|0;
 (FUNCTION_TABLE_iiii[$62 & 2047]($stream,$63,$66)|0);
 $67 = HEAP8[$Mismatch$i>>0]|0;
 $68 = ($67<<24>>24)==(0);
 if (!($68)) {
  $69 = HEAP8[$22>>0]|0;
  $70 = ($69<<24>>24)==(0);
  if (!($70)) {
   $i$09$i = 0;
   while(1) {
    $71 = HEAP32[$37>>2]|0;
    $72 = (($71) + (($i$09$i*20)|0)|0);
    $73 = HEAP8[$72>>0]|0;
    $74 = (($72) + 3|0);
    $75 = HEAP8[$74>>0]|0;
    HEAP8[$72>>0] = $75;
    HEAP8[$74>>0] = $73;
    $76 = (($72) + 1|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = (($72) + 2|0);
    $79 = HEAP8[$78>>0]|0;
    HEAP8[$76>>0] = $79;
    HEAP8[$78>>0] = $77;
    $80 = ((($71) + (($i$09$i*20)|0)|0) + 4|0);
    $81 = HEAP8[$80>>0]|0;
    $82 = (($80) + 3|0);
    $83 = HEAP8[$82>>0]|0;
    HEAP8[$80>>0] = $83;
    HEAP8[$82>>0] = $81;
    $84 = (($80) + 1|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = (($80) + 2|0);
    $87 = HEAP8[$86>>0]|0;
    HEAP8[$84>>0] = $87;
    HEAP8[$86>>0] = $85;
    $88 = ((($71) + (($i$09$i*20)|0)|0) + 8|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = (($88) + 3|0);
    $91 = HEAP8[$90>>0]|0;
    HEAP8[$88>>0] = $91;
    HEAP8[$90>>0] = $89;
    $92 = (($88) + 1|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = (($88) + 2|0);
    $95 = HEAP8[$94>>0]|0;
    HEAP8[$92>>0] = $95;
    HEAP8[$94>>0] = $93;
    $96 = ((($71) + (($i$09$i*20)|0)|0) + 12|0);
    $97 = HEAP8[$96>>0]|0;
    $98 = (($96) + 3|0);
    $99 = HEAP8[$98>>0]|0;
    HEAP8[$96>>0] = $99;
    HEAP8[$98>>0] = $97;
    $100 = (($96) + 1|0);
    $101 = HEAP8[$100>>0]|0;
    $102 = (($96) + 2|0);
    $103 = HEAP8[$102>>0]|0;
    HEAP8[$100>>0] = $103;
    HEAP8[$102>>0] = $101;
    $104 = ((($71) + (($i$09$i*20)|0)|0) + 16|0);
    $105 = HEAP8[$104>>0]|0;
    $106 = (($104) + 1|0);
    $107 = HEAP8[$106>>0]|0;
    HEAP8[$104>>0] = $107;
    HEAP8[$106>>0] = $105;
    $108 = (($i$09$i) + 1)|0;
    $109 = HEAP8[$22>>0]|0;
    $110 = $109&255;
    $111 = ($108>>>0)<($110>>>0);
    if ($111) {
     $i$09$i = $108;
    } else {
     break;
    }
   }
  }
 }
 $112 = HEAP32[$stream>>2]|0;
 $113 = HEAP32[$112>>2]|0;
 (FUNCTION_TABLE_iiii[$113 & 2047]($stream,$54,$24)|0);
 $114 = HEAP32[$stream>>2]|0;
 $115 = HEAP32[$114>>2]|0;
 $116 = HEAP16[$18>>1]|0;
 $117 = $116&65535;
 $118 = $117 << 1;
 (FUNCTION_TABLE_iiii[$115 & 2047]($stream,$48,$118)|0);
 $119 = HEAP32[$vararg_buffer>>2]|0;
 $120 = ($119>>>0)<(7);
 if ($120) {
  $121 = HEAP8[$14>>0]|0;
  $122 = ($121<<24>>24)==(0);
  if (!($122)) {
   $123 = $$sum1$i | 1;
   $124 = (($$sum1$i) + 2)|0;
   $a$06$i = 0;
   while(1) {
    $125 = ($a$06$i*3)|0;
    $$sum3$i = (($125) + ($$sum1$i))|0;
    $126 = (($40) + ($$sum3$i)|0);
    HEAP8[$126>>0] = -1;
    $$sum4$i = (($125) + ($123))|0;
    $127 = (($40) + ($$sum4$i)|0);
    HEAP8[$127>>0] = -1;
    $$sum5$i = (($124) + ($125))|0;
    $128 = (($40) + ($$sum5$i)|0);
    HEAP8[$128>>0] = -1;
    $129 = (($a$06$i) + 1)|0;
    $130 = HEAP8[$14>>0]|0;
    $131 = $130&255;
    $132 = ($129>>>0)<($131>>>0);
    if ($132) {
     $a$06$i = $129;
    } else {
     break;
    }
   }
  }
 } else {
  $133 = HEAP32[$stream>>2]|0;
  $134 = HEAP32[$133>>2]|0;
  $135 = HEAP8[$14>>0]|0;
  $136 = $135&255;
  $137 = ($136*3)|0;
  (FUNCTION_TABLE_iiii[$134 & 2047]($stream,$52,$137)|0);
 }
 $138 = HEAP8[$mismatch>>0]|0;
 $139 = ($138<<24>>24)!=(0);
 (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($tmp,8,$139,$stream)|0);
 $140 = (($tmp) + 4|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($tmp) + 8|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($tmp) + 12|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($tmp) + 16|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = (($tmp) + 20|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($tmp) + 24|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = (($this) + 16|0);
 HEAPF32[$152>>2] = $141;
 $153 = (($this) + 20|0);
 HEAPF32[$153>>2] = $143;
 $154 = (($this) + 24|0);
 HEAPF32[$154>>2] = $145;
 $155 = (($this) + 28|0);
 HEAPF32[$155>>2] = $147;
 $156 = (($this) + 32|0);
 HEAPF32[$156>>2] = $149;
 $157 = (($this) + 36|0);
 HEAPF32[$157>>2] = $151;
 $158 = (($tmp) + 28|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($this) + 88|0);
 HEAPF32[$160>>2] = $159;
 $161 = $159 != Math_fround(-1.0);
 if ($161) {
  $162 = (($this) + 92|0);
  $163 = HEAP8[$mismatch>>0]|0;
  $164 = ($163<<24>>24)!=(0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($162,9,$164,$stream)|0);
  $165 = (($this) + 40|0);
  $166 = HEAP8[$mismatch>>0]|0;
  $167 = ($166<<24>>24)!=(0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($165,3,$167,$stream)|0);
 }
 $168 = HEAP8[$mismatch>>0]|0;
 $169 = ($168<<24>>24)!=(0);
 $170 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($169,$stream)));
 $171 = $170 != Math_fround(-1.0);
 if ($171) {
  $172 = (($this) + 84|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = ($173|0)==(0|0);
  if (!($174)) {
   __ZN5physx13BigConvexDataD2Ev($173);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$173);
  }
  HEAP32[$172>>2] = 0;
  $175 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $176 = HEAP32[$175>>2]|0;
  $177 = (($176) + 8|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (__Z15PxGetFoundationv()|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = (($180) + 24|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = (FUNCTION_TABLE_ii[$182 & 4095]($179)|0);
  $$$i$i$i = $183 ? 549480 : 549448;
  $184 = (FUNCTION_TABLE_iiiiii[$178 & 255]($175,28,$$$i$i$i,549144,269)|0);
  __ZN5physx13BigConvexDataC2Ev($184);
  HEAP32[$172>>2] = $184;
  $185 = ($184|0)==(0|0);
  if (!($185)) {
   (__ZN5physx13BigConvexData4LoadERNS_13PxInputStreamE($184,$stream)|0);
   $186 = HEAP32[$172>>2]|0;
   $187 = (($this) + 60|0);
   HEAP32[$187>>2] = $186;
  }
 }
 $188 = HEAP8[$mismatch>>0]|0;
 $189 = ($188<<24>>24)!=(0);
 $190 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($189,$stream)));
 $191 = (($this) + 64|0);
 HEAPF32[$191>>2] = $190;
 $192 = HEAP8[$mismatch>>0]|0;
 $193 = ($192<<24>>24)!=(0);
 $194 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($193,$stream)));
 $195 = (($this) + 68|0);
 HEAPF32[$195>>2] = $194;
 $196 = HEAP8[$mismatch>>0]|0;
 $197 = ($196<<24>>24)!=(0);
 $198 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($197,$stream)));
 $199 = (($this) + 72|0);
 HEAPF32[$199>>2] = $198;
 $200 = HEAP8[$mismatch>>0]|0;
 $201 = ($200<<24>>24)!=(0);
 $202 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($201,$stream)));
 $203 = (($this) + 76|0);
 HEAPF32[$203>>2] = $202;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu10ConvexMesh7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($1,$this,2,0);
 $2 = (($this) + 6|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & -3;
 HEAP16[$2>>1] = $4;
 $5 = (($this) + 8|0);
 $6 = (($this) + 12|0);
 $7 = (__ZN5physx6shdfnd15atomicDecrementEPVi($6)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$5>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$11 & 4095]($5);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu10ConvexMesh14onRefCountZeroEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bytesNeeded$0$i$i = 0, $tmp1$i$i = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2147483647;
 $3 = (($this) + 55|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ($5*20)|0;
 $7 = (($this) + 54|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = (($this) + 52|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = $11&65535;
 $13 = $12 << 1;
 $tmp1$i$i = ($9*15)|0;
 $14 = (($6) + ($2))|0;
 $15 = (($14) + ($tmp1$i$i))|0;
 $16 = (($15) + ($13))|0;
 $17 = $16 & 3;
 $18 = ($17|0)==(0);
 if ($18) {
  $bytesNeeded$0$i$i = $16;
 } else {
  $19 = (($16) + 4)|0;
  $20 = (($19) - ($17))|0;
  $bytesNeeded$0$i$i = $20;
 }
 $21 = ($bytesNeeded$0$i$i|0)==(0);
 $$pre = (($this) + 128|0);
 if (!($21)) {
  $22 = HEAP32[$$pre>>2]|0;
  $23 = (__ZN5physx13GuMeshFactory16removeConvexMeshERNS_12PxConvexMeshE($22,$this)|0);
  if (!($23)) {
   $34 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($34,8,549144,316,549392,$vararg_buffer);
   STACKTOP = sp;return;
  }
 }
 $24 = HEAP32[$$pre>>2]|0;
 $25 = (($this) + 6|0);
 $26 = HEAP16[$25>>1]|0;
 $27 = $26 & 1;
 $28 = ($27<<16>>16)==(0);
 $29 = HEAP32[$this>>2]|0;
 if ($28) {
  $32 = (($29) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_vi[$33 & 4095]($this);
 } else {
  $30 = (($29) + 16|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vi[$31 & 4095]($this);
 }
 __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($24,$this,2,1);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu10ConvexMesh14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 __ZN5physx2Gu10ConvexMesh14onRefCountZeroEv($0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu10ConvexMesh17getReferenceCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu10ConvexMesh18getMassInformationERfRNS_7PxMat33ERNS_6PxVec3E($this,$mass,$localInertia,$localCenterOfMass) {
 $this = $this|0;
 $mass = $mass|0;
 $localInertia = $localInertia|0;
 $localCenterOfMass = $localCenterOfMass|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$mass>>2] = $1;
 $2 = (($this) + 92|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$localInertia>>2] = $3;
 $4 = (($this) + 96|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($localInertia) + 4|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 100|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($localInertia) + 8|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($this) + 104|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($localInertia) + 12|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($this) + 108|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($localInertia) + 16|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($this) + 112|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($localInertia) + 20|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($this) + 116|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($localInertia) + 24|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($this) + 120|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($localInertia) + 28|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($this) + 124|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($localInertia) + 32|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($this) + 40|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$localCenterOfMass>>2] = $29;
 $30 = (($this) + 44|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($localCenterOfMass) + 4|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($this) + 48|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($localCenterOfMass) + 8|0);
 HEAPF32[$35>>2] = $34;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu10ConvexMesh14debugVisualizeERNS_2Cm12RenderOutputERKNS2_8Matrix34ERKNS_9PxBounds3Eyfj($this,$out,$absPose,$cullbox,$0,$1,$2,$3) {
 $this = $this|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $cullbox = $cullbox|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = Math_fround($2);
 $3 = $3|0;
 var $$lcssa = Math_fround(0), $$lcssa8 = Math_fround(0), $$lcssa9 = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert30 = 0, $$phi$trans$insert32 = 0, $$phi$trans$insert34 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre31 = Math_fround(0), $$pre33 = Math_fround(0), $$pre35 = Math_fround(0), $$pre36 = Math_fround(0), $$pre37 = Math_fround(0), $$pre38 = Math_fround(0), $$pre39 = Math_fround(0), $$pre40 = Math_fround(0), $$pre41 = Math_fround(0), $$pre42 = Math_fround(0);
 var $$pre43 = Math_fround(0), $$pre44 = Math_fround(0), $$pre45 = Math_fround(0), $$pre46 = Math_fround(0), $$pre47 = Math_fround(0), $$pre48 = Math_fround(0), $$pre49 = Math_fround(0), $$pre50 = Math_fround(0), $$pre51 = Math_fround(0), $$pre52 = Math_fround(0), $$pre53 = Math_fround(0), $$pre54 = Math_fround(0), $$pre55 = Math_fround(0), $$pre56 = Math_fround(0), $$pre57 = Math_fround(0), $$pre58 = Math_fround(0), $$pre59 = Math_fround(0), $$sum1$i = 0, $$sum1$i4 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0);
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0);
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0);
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0);
 var $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0);
 var $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0);
 var $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond29 = 0, $i$022 = 0, $i4$014 = 0, $indexBuffer$023 = 0, $indexBuffer2$013 = 0;
 var $j$018 = 0, $j6$010 = 0, $m44 = 0, $phitmp$i = 0, $tmp2$i = 0, $tmp2$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $4 = sp + 64|0;
 $m44 = sp;
 $5 = $0 & 1073741824;
 $6 = ($5|0)==(0);
 $7 = (0)==(0);
 $8 = $6 & $7;
 L1: do {
  if (!($8)) {
   $9 = (($this) + 56|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 55|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = $12&255;
   $14 = (($10) + (($13*20)|0)|0);
   $15 = ($12<<24>>24)==(0);
   if (!($15)) {
    $16 = (($this) + 52|0);
    $17 = (($this) + 54|0);
    $18 = HEAP16[$16>>1]|0;
    $19 = HEAP8[$17>>0]|0;
    $20 = $18&65535;
    $21 = $19&255;
    $tmp2$i = ($21*15)|0;
    $22 = $20 << 1;
    $23 = (($10) + (($13*20)|0)|0);
    $$sum1$i = (($22) + ($tmp2$i))|0;
    $24 = (($23) + ($$sum1$i)|0);
    $25 = (($absPose) + 36|0);
    $26 = (($absPose) + 40|0);
    $27 = (($absPose) + 44|0);
    $28 = (($cullbox) + 12|0);
    $29 = (($cullbox) + 4|0);
    $30 = (($cullbox) + 16|0);
    $31 = (($cullbox) + 8|0);
    $32 = (($cullbox) + 20|0);
    $i$022 = 0;$indexBuffer$023 = $24;
    L4: while(1) {
     $33 = ((($10) + (($i$022*20)|0)|0) + 18|0);
     $34 = HEAP8[$33>>0]|0;
     $35 = $34&255;
     $36 = ($34&255)>(1);
     if ($36) {
      $37 = Math_fround(HEAPF32[$25>>2]);
      $38 = Math_fround(HEAPF32[$26>>2]);
      $39 = Math_fround(HEAPF32[$27>>2]);
      $40 = Math_fround(HEAPF32[$cullbox>>2]);
      $j$018 = 1;
      while(1) {
       $43 = (($indexBuffer$023) + ($j$018)|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = $44&255;
       $46 = (($14) + (($45*12)|0)|0);
       $47 = Math_fround(HEAPF32[$46>>2]);
       $48 = Math_fround($37 + $47);
       $49 = ((($14) + (($45*12)|0)|0) + 4|0);
       $50 = Math_fround(HEAPF32[$49>>2]);
       $51 = Math_fround($38 + $50);
       $52 = ((($14) + (($45*12)|0)|0) + 8|0);
       $53 = Math_fround(HEAPF32[$52>>2]);
       $54 = Math_fround($39 + $53);
       $55 = $48 < $40;
       if ($55) {
        label = 33;
        break L4;
       }
       $56 = Math_fround(HEAPF32[$28>>2]);
       $57 = $48 > $56;
       if ($57) {
        label = 33;
        break L4;
       }
       $58 = Math_fround(HEAPF32[$29>>2]);
       $59 = $51 < $58;
       if ($59) {
        label = 33;
        break L4;
       }
       $60 = Math_fround(HEAPF32[$30>>2]);
       $61 = $51 > $60;
       if ($61) {
        label = 33;
        break L4;
       }
       $62 = Math_fround(HEAPF32[$31>>2]);
       $63 = $54 < $62;
       if ($63) {
        label = 33;
        break L4;
       }
       $64 = Math_fround(HEAPF32[$32>>2]);
       $phitmp$i = !($54 > $64);
       $42 = (($j$018) + 1)|0;
       if (!($phitmp$i)) {
        label = 33;
        break L4;
       }
       $41 = ($42>>>0)<($35>>>0);
       if ($41) {
        $j$018 = $42;
       } else {
        break;
       }
      }
     }
     $65 = (($indexBuffer$023) + ($35)|0);
     $66 = (($i$022) + 1)|0;
     $67 = ($66>>>0)<($13>>>0);
     if ($67) {
      $i$022 = $66;$indexBuffer$023 = $65;
     } else {
      break L1;
     }
    }
    if ((label|0) == 33) {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $68 = $0 & 8192;
 $69 = ($68|0)==(0);
 $70 = (0)==(0);
 $71 = $69 & $70;
 if ($71) {
  STACKTOP = sp;return;
 }
 $72 = (($this) + 56|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($this) + 55|0);
 $75 = HEAP8[$74>>0]|0;
 $76 = $75&255;
 $77 = (($73) + (($76*20)|0)|0);
 $78 = (($this) + 54|0);
 $79 = HEAP8[$78>>0]|0;
 $80 = (($this) + 52|0);
 $81 = HEAP16[$80>>1]|0;
 __ZN5physx2Gu5Debug16convertToPxMat44ERKNS_2Cm8Matrix34E($m44,$absPose);
 $82 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$m44)|0);
 (__ZN5physx2Cm12RenderOutputlsEj($82,-65281)|0);
 $83 = ($75<<24>>24)==(0);
 if ($83) {
  STACKTOP = sp;return;
 }
 $84 = $81&65535;
 $85 = $79&255;
 $tmp2$i3 = ($85*15)|0;
 $86 = $84 << 1;
 $87 = (($73) + (($76*20)|0)|0);
 $$sum1$i4 = (($86) + ($tmp2$i3))|0;
 $88 = (($87) + ($$sum1$i4)|0);
 $89 = (($m44) + 4|0);
 $90 = (($m44) + 8|0);
 $91 = (($m44) + 16|0);
 $92 = (($m44) + 20|0);
 $93 = (($m44) + 24|0);
 $94 = (($m44) + 32|0);
 $95 = (($m44) + 36|0);
 $96 = (($m44) + 40|0);
 $97 = (($m44) + 48|0);
 $98 = (($m44) + 52|0);
 $99 = (($m44) + 56|0);
 $100 = (($out) + 100|0);
 $101 = (($out) + 4|0);
 $102 = (($4) + 4|0);
 $103 = (($4) + 8|0);
 $104 = (($4) + 12|0);
 $105 = (($4) + 16|0);
 $106 = (($4) + 20|0);
 $107 = (($4) + 24|0);
 $108 = (($4) + 28|0);
 $109 = (($4) + 4|0);
 $110 = (($4) + 8|0);
 $111 = (($4) + 12|0);
 $112 = (($4) + 16|0);
 $113 = (($4) + 20|0);
 $114 = (($4) + 24|0);
 $115 = (($4) + 28|0);
 $i4$014 = 0;$indexBuffer2$013 = $88;
 while(1) {
  $116 = HEAP32[$72>>2]|0;
  $117 = ((($116) + (($i4$014*20)|0)|0) + 18|0);
  $118 = HEAP8[$117>>0]|0;
  $119 = $118&255;
  $120 = HEAP8[$indexBuffer2$013>>0]|0;
  $121 = $120&255;
  $122 = (($77) + (($121*12)|0)|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = ((($77) + (($121*12)|0)|0) + 4|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = ((($77) + (($121*12)|0)|0) + 8|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = Math_fround(HEAPF32[$m44>>2]);
  $129 = Math_fround($123 * $128);
  $130 = Math_fround(HEAPF32[$89>>2]);
  $131 = Math_fround($123 * $130);
  $132 = Math_fround(HEAPF32[$90>>2]);
  $133 = Math_fround($123 * $132);
  $134 = Math_fround(HEAPF32[$91>>2]);
  $135 = Math_fround($125 * $134);
  $136 = Math_fround(HEAPF32[$92>>2]);
  $137 = Math_fround($125 * $136);
  $138 = Math_fround(HEAPF32[$93>>2]);
  $139 = Math_fround($125 * $138);
  $140 = Math_fround($129 + $135);
  $141 = Math_fround($131 + $137);
  $142 = Math_fround($133 + $139);
  $143 = Math_fround(HEAPF32[$94>>2]);
  $144 = Math_fround($127 * $143);
  $145 = Math_fround(HEAPF32[$95>>2]);
  $146 = Math_fround($127 * $145);
  $147 = Math_fround(HEAPF32[$96>>2]);
  $148 = Math_fround($127 * $147);
  $149 = Math_fround($140 + $144);
  $150 = Math_fround($141 + $146);
  $151 = Math_fround($142 + $148);
  $152 = Math_fround(HEAPF32[$97>>2]);
  $153 = Math_fround(HEAPF32[$98>>2]);
  $154 = Math_fround(HEAPF32[$99>>2]);
  $155 = Math_fround($149 + $152);
  $156 = Math_fround($150 + $153);
  $157 = Math_fround($151 + $154);
  $158 = ($118&255)>(1);
  if ($158) {
   $169 = $128;$171 = $130;$173 = $132;$175 = $134;$177 = $136;$179 = $138;$184 = $143;$186 = $145;$188 = $147;$193 = $152;$195 = $153;$197 = $154;$200 = $155;$201 = $156;$202 = $157;$j6$010 = 1;
   while(1) {
    $159 = (($indexBuffer2$013) + ($j6$010)|0);
    $160 = HEAP8[$159>>0]|0;
    $161 = $160&255;
    $162 = (($77) + (($161*12)|0)|0);
    $163 = Math_fround(HEAPF32[$162>>2]);
    $164 = ((($77) + (($161*12)|0)|0) + 4|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = ((($77) + (($161*12)|0)|0) + 8|0);
    $167 = Math_fround(HEAPF32[$166>>2]);
    $168 = Math_fround($163 * $169);
    $170 = Math_fround($163 * $171);
    $172 = Math_fround($163 * $173);
    $174 = Math_fround($165 * $175);
    $176 = Math_fround($165 * $177);
    $178 = Math_fround($165 * $179);
    $180 = Math_fround($168 + $174);
    $181 = Math_fround($170 + $176);
    $182 = Math_fround($172 + $178);
    $183 = Math_fround($167 * $184);
    $185 = Math_fround($167 * $186);
    $187 = Math_fround($167 * $188);
    $189 = Math_fround($180 + $183);
    $190 = Math_fround($181 + $185);
    $191 = Math_fround($182 + $187);
    $192 = Math_fround($189 + $193);
    $194 = Math_fround($190 + $195);
    $196 = Math_fround($191 + $197);
    $198 = HEAP32[$100>>2]|0;
    $199 = (($198) + 16|0);
    HEAPF32[$4>>2] = $200;
    HEAPF32[$109>>2] = $201;
    HEAPF32[$110>>2] = $202;
    $203 = HEAP32[$101>>2]|0;
    HEAP32[$111>>2] = $203;
    HEAPF32[$112>>2] = $192;
    HEAPF32[$113>>2] = $194;
    HEAPF32[$114>>2] = $196;
    HEAP32[$115>>2] = $203;
    $204 = (($198) + 24|0);
    $205 = HEAP32[$204>>2]|0;
    $206 = $205 & 2147483647;
    $207 = (($198) + 20|0);
    $208 = HEAP32[$207>>2]|0;
    $209 = ($206>>>0)>($208>>>0);
    if ($209) {
     $210 = HEAP32[$199>>2]|0;
     $211 = (($210) + ($208<<5)|0);
     $212 = ($211|0)==(0|0);
     if ($212) {
      $221 = $208;
     } else {
      HEAPF32[$211>>2] = $200;
      $213 = ((($210) + ($208<<5)|0) + 4|0);
      HEAPF32[$213>>2] = $201;
      $214 = ((($210) + ($208<<5)|0) + 8|0);
      HEAPF32[$214>>2] = $202;
      $215 = ((($210) + ($208<<5)|0) + 12|0);
      HEAP32[$215>>2] = $203;
      $216 = ((($210) + ($208<<5)|0) + 16|0);
      HEAPF32[$216>>2] = $192;
      $217 = ((($210) + ($208<<5)|0) + 20|0);
      HEAPF32[$217>>2] = $194;
      $218 = ((($210) + ($208<<5)|0) + 24|0);
      HEAPF32[$218>>2] = $196;
      $219 = ((($210) + ($208<<5)|0) + 28|0);
      HEAP32[$219>>2] = $203;
      $$pre$i$i1 = HEAP32[$207>>2]|0;
      $221 = $$pre$i$i1;
     }
     $220 = (($221) + 1)|0;
     HEAP32[$207>>2] = $220;
    } else {
     (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($199,$4)|0);
    }
    $222 = (($j6$010) + 1)|0;
    $exitcond = ($222|0)==($119|0);
    if ($exitcond) {
     break;
    }
    $$pre48 = Math_fround(HEAPF32[$m44>>2]);
    $$pre49 = Math_fround(HEAPF32[$89>>2]);
    $$pre50 = Math_fround(HEAPF32[$90>>2]);
    $$pre51 = Math_fround(HEAPF32[$91>>2]);
    $$pre52 = Math_fround(HEAPF32[$92>>2]);
    $$pre53 = Math_fround(HEAPF32[$93>>2]);
    $$pre54 = Math_fround(HEAPF32[$94>>2]);
    $$pre55 = Math_fround(HEAPF32[$95>>2]);
    $$pre56 = Math_fround(HEAPF32[$96>>2]);
    $$pre57 = Math_fround(HEAPF32[$97>>2]);
    $$pre58 = Math_fround(HEAPF32[$98>>2]);
    $$pre59 = Math_fround(HEAPF32[$99>>2]);
    $169 = $$pre48;$171 = $$pre49;$173 = $$pre50;$175 = $$pre51;$177 = $$pre52;$179 = $$pre53;$184 = $$pre54;$186 = $$pre55;$188 = $$pre56;$193 = $$pre57;$195 = $$pre58;$197 = $$pre59;$200 = $192;$201 = $194;$202 = $196;$j6$010 = $222;
   }
   $$pre = HEAP8[$indexBuffer2$013>>0]|0;
   $$phi$trans$insert = $$pre&255;
   $$phi$trans$insert30 = (($77) + (($$phi$trans$insert*12)|0)|0);
   $$pre31 = Math_fround(HEAPF32[$$phi$trans$insert30>>2]);
   $$phi$trans$insert32 = ((($77) + (($$phi$trans$insert*12)|0)|0) + 4|0);
   $$pre33 = Math_fround(HEAPF32[$$phi$trans$insert32>>2]);
   $$phi$trans$insert34 = ((($77) + (($$phi$trans$insert*12)|0)|0) + 8|0);
   $$pre35 = Math_fround(HEAPF32[$$phi$trans$insert34>>2]);
   $$pre36 = Math_fround(HEAPF32[$m44>>2]);
   $$pre37 = Math_fround(HEAPF32[$89>>2]);
   $$pre38 = Math_fround(HEAPF32[$90>>2]);
   $$pre39 = Math_fround(HEAPF32[$91>>2]);
   $$pre40 = Math_fround(HEAPF32[$92>>2]);
   $$pre41 = Math_fround(HEAPF32[$93>>2]);
   $$pre42 = Math_fround(HEAPF32[$94>>2]);
   $$pre43 = Math_fround(HEAPF32[$95>>2]);
   $$pre44 = Math_fround(HEAPF32[$96>>2]);
   $$pre45 = Math_fround(HEAPF32[$97>>2]);
   $$pre46 = Math_fround(HEAPF32[$98>>2]);
   $$pre47 = Math_fround(HEAPF32[$99>>2]);
   $$lcssa = $196;$$lcssa8 = $194;$$lcssa9 = $192;$224 = $$pre36;$225 = $$pre31;$227 = $$pre37;$229 = $$pre38;$231 = $$pre39;$232 = $$pre33;$234 = $$pre40;$236 = $$pre41;$241 = $$pre42;$242 = $$pre35;$244 = $$pre43;$246 = $$pre44;$251 = $$pre45;$253 = $$pre46;$255 = $$pre47;
  } else {
   $$lcssa = $157;$$lcssa8 = $156;$$lcssa9 = $155;$224 = $128;$225 = $123;$227 = $130;$229 = $132;$231 = $134;$232 = $125;$234 = $136;$236 = $138;$241 = $143;$242 = $127;$244 = $145;$246 = $147;$251 = $152;$253 = $153;$255 = $154;
  }
  $223 = Math_fround($225 * $224);
  $226 = Math_fround($225 * $227);
  $228 = Math_fround($225 * $229);
  $230 = Math_fround($232 * $231);
  $233 = Math_fround($232 * $234);
  $235 = Math_fround($232 * $236);
  $237 = Math_fround($223 + $230);
  $238 = Math_fround($226 + $233);
  $239 = Math_fround($228 + $235);
  $240 = Math_fround($242 * $241);
  $243 = Math_fround($242 * $244);
  $245 = Math_fround($242 * $246);
  $247 = Math_fround($237 + $240);
  $248 = Math_fround($238 + $243);
  $249 = Math_fround($239 + $245);
  $250 = Math_fround($247 + $251);
  $252 = Math_fround($248 + $253);
  $254 = Math_fround($249 + $255);
  $256 = HEAP32[$100>>2]|0;
  $257 = (($256) + 16|0);
  HEAPF32[$4>>2] = $$lcssa9;
  HEAPF32[$102>>2] = $$lcssa8;
  HEAPF32[$103>>2] = $$lcssa;
  $258 = HEAP32[$101>>2]|0;
  HEAP32[$104>>2] = $258;
  HEAPF32[$105>>2] = $250;
  HEAPF32[$106>>2] = $252;
  HEAPF32[$107>>2] = $254;
  HEAP32[$108>>2] = $258;
  $259 = (($256) + 24|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = $260 & 2147483647;
  $262 = (($256) + 20|0);
  $263 = HEAP32[$262>>2]|0;
  $264 = ($261>>>0)>($263>>>0);
  if ($264) {
   $265 = HEAP32[$257>>2]|0;
   $266 = (($265) + ($263<<5)|0);
   $267 = ($266|0)==(0|0);
   if ($267) {
    $276 = $263;
   } else {
    HEAPF32[$266>>2] = $$lcssa9;
    $268 = ((($265) + ($263<<5)|0) + 4|0);
    HEAPF32[$268>>2] = $$lcssa8;
    $269 = ((($265) + ($263<<5)|0) + 8|0);
    HEAPF32[$269>>2] = $$lcssa;
    $270 = ((($265) + ($263<<5)|0) + 12|0);
    HEAP32[$270>>2] = $258;
    $271 = ((($265) + ($263<<5)|0) + 16|0);
    HEAPF32[$271>>2] = $250;
    $272 = ((($265) + ($263<<5)|0) + 20|0);
    HEAPF32[$272>>2] = $252;
    $273 = ((($265) + ($263<<5)|0) + 24|0);
    HEAPF32[$273>>2] = $254;
    $274 = ((($265) + ($263<<5)|0) + 28|0);
    HEAP32[$274>>2] = $258;
    $$pre$i$i = HEAP32[$262>>2]|0;
    $276 = $$pre$i$i;
   }
   $275 = (($276) + 1)|0;
   HEAP32[$262>>2] = $275;
  } else {
   (__ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE15growAndPushBackERKS2_($257,$4)|0);
  }
  $277 = (($i4$014) + 1)|0;
  $exitcond29 = ($277|0)==($76|0);
  if ($exitcond29) {
   break;
  }
  $278 = (($indexBuffer2$013) + ($119)|0);
  $i4$014 = $277;$indexBuffer2$013 = $278;
 }
 STACKTOP = sp;return;
}
function __ZN5physx12PxConvexMeshD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx12PxConvexMeshD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu14computeHullOBBERNS0_3BoxERKNS_9PxBounds3EfRKNS_11PxTransformERKNS_2Cm8Matrix34ESC_RKNS9_23FastVertex2ShapeScalingEb($hullOBB,$hullAABB,$offset,$transform0,$world0,$world1,$meshScaling,$idtScaleMesh) {
 $hullOBB = $hullOBB|0;
 $hullAABB = $hullAABB|0;
 $offset = Math_fround($offset);
 $transform0 = $transform0|0;
 $world0 = $world0|0;
 $world1 = $world1|0;
 $meshScaling = $meshScaling|0;
 $idtScaleMesh = $idtScaleMesh|0;
 var $$pre = Math_fround(0), $$pre34 = Math_fround(0), $$pre35 = Math_fround(0), $$pre36 = Math_fround(0), $$pre37 = Math_fround(0), $$pre38 = Math_fround(0), $$pre39 = Math_fround(0), $$pre40 = Math_fround(0), $$pre41 = Math_fround(0), $$pre42 = Math_fround(0), $$pre43 = Math_fround(0), $$pre44 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0;
 var $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0);
 var $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0);
 var $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0);
 var $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0;
 var $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0;
 var $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $center = 0, $extents = 0, $obbBasis = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $center = sp + 48|0;
 $extents = sp;
 $obbBasis = sp + 12|0;
 $0 = Math_fround(HEAPF32[$hullAABB>>2]);
 $1 = (($hullAABB) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 $4 = (($hullAABB) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($hullAABB) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 $9 = (($hullAABB) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($hullAABB) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = Math_fround($3 * Math_fround(0.5));
 $15 = Math_fround($8 * Math_fround(0.5));
 $16 = Math_fround($13 * Math_fround(0.5));
 $17 = Math_fround($14 * Math_fround(2.0));
 $18 = Math_fround($15 * Math_fround(2.0));
 $19 = Math_fround($16 * Math_fround(2.0));
 $20 = (($transform0) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $21);
 $23 = Math_fround($22 + Math_fround(-0.5));
 $24 = Math_fround(HEAPF32[$transform0>>2]);
 $25 = Math_fround($17 * $24);
 $26 = (($transform0) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($18 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($transform0) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($19 * $31);
 $33 = Math_fround($29 + $32);
 $34 = Math_fround($17 * $23);
 $35 = Math_fround($19 * $27);
 $36 = Math_fround($18 * $31);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($21 * $37);
 $39 = Math_fround($34 + $38);
 $40 = Math_fround($24 * $33);
 $41 = Math_fround($40 + $39);
 $42 = Math_fround($18 * $23);
 $43 = Math_fround($17 * $31);
 $44 = Math_fround($24 * $19);
 $45 = Math_fround($43 - $44);
 $46 = Math_fround($21 * $45);
 $47 = Math_fround($42 + $46);
 $48 = Math_fround($27 * $33);
 $49 = Math_fround($48 + $47);
 $50 = Math_fround($19 * $23);
 $51 = Math_fround($18 * $24);
 $52 = Math_fround($17 * $27);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($21 * $53);
 $55 = Math_fround($50 + $54);
 $56 = Math_fround($31 * $33);
 $57 = Math_fround($55 + $56);
 $58 = (($transform0) + 16|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 + $41);
 $61 = (($transform0) + 20|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 + $49);
 $64 = (($transform0) + 24|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 + $57);
 $67 = (($center) + 4|0);
 $68 = (($center) + 8|0);
 $69 = Math_fround($2 - $0);
 $70 = Math_fround($7 - $5);
 $71 = Math_fround($12 - $10);
 $72 = Math_fround($69 * Math_fround(0.5));
 $73 = Math_fround($70 * Math_fround(0.5));
 $74 = Math_fround($71 * Math_fround(0.5));
 $75 = (($extents) + 4|0);
 $76 = (($extents) + 8|0);
 $77 = Math_fround($72 + $offset);
 HEAPF32[$extents>>2] = $77;
 $78 = Math_fround($73 + $offset);
 HEAPF32[$75>>2] = $78;
 $79 = Math_fround($74 + $offset);
 HEAPF32[$76>>2] = $79;
 $80 = (($world1) + 36|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($60 - $81);
 $83 = (($world1) + 40|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($63 - $84);
 $86 = (($world1) + 44|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($66 - $87);
 $89 = Math_fround(HEAPF32[$world1>>2]);
 $90 = Math_fround($82 * $89);
 $91 = (($world1) + 4|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($85 * $92);
 $94 = Math_fround($90 + $93);
 $95 = (($world1) + 8|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($88 * $96);
 $98 = Math_fround($94 + $97);
 $99 = (($world1) + 12|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($82 * $100);
 $102 = (($world1) + 16|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($85 * $103);
 $105 = Math_fround($101 + $104);
 $106 = (($world1) + 20|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($88 * $107);
 $109 = Math_fround($105 + $108);
 $110 = (($world1) + 24|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($82 * $111);
 $113 = (($world1) + 28|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($85 * $114);
 $116 = Math_fround($112 + $115);
 $117 = (($world1) + 32|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = Math_fround($88 * $118);
 $120 = Math_fround($116 + $119);
 HEAPF32[$center>>2] = $98;
 HEAPF32[$67>>2] = $109;
 HEAPF32[$68>>2] = $120;
 $121 = Math_fround(HEAPF32[$world0>>2]);
 $122 = (($world0) + 4|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($world0) + 8|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($world0) + 12|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($world0) + 16|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = (($world0) + 20|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($world0) + 24|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($world0) + 28|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($world0) + 32|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($89 * $121);
 $139 = Math_fround($100 * $121);
 $140 = Math_fround($111 * $121);
 $141 = Math_fround($92 * $123);
 $142 = Math_fround($103 * $123);
 $143 = Math_fround($114 * $123);
 $144 = Math_fround($138 + $141);
 $145 = Math_fround($139 + $142);
 $146 = Math_fround($140 + $143);
 $147 = Math_fround($96 * $125);
 $148 = Math_fround($107 * $125);
 $149 = Math_fround($118 * $125);
 $150 = Math_fround($144 + $147);
 $151 = Math_fround($145 + $148);
 $152 = Math_fround($146 + $149);
 $153 = Math_fround($89 * $127);
 $154 = Math_fround($100 * $127);
 $155 = Math_fround($111 * $127);
 $156 = Math_fround($92 * $129);
 $157 = Math_fround($103 * $129);
 $158 = Math_fround($114 * $129);
 $159 = Math_fround($153 + $156);
 $160 = Math_fround($154 + $157);
 $161 = Math_fround($155 + $158);
 $162 = Math_fround($96 * $131);
 $163 = Math_fround($107 * $131);
 $164 = Math_fround($118 * $131);
 $165 = Math_fround($159 + $162);
 $166 = Math_fround($160 + $163);
 $167 = Math_fround($161 + $164);
 $168 = Math_fround($89 * $133);
 $169 = Math_fround($100 * $133);
 $170 = Math_fround($111 * $133);
 $171 = Math_fround($92 * $135);
 $172 = Math_fround($103 * $135);
 $173 = Math_fround($114 * $135);
 $174 = Math_fround($168 + $171);
 $175 = Math_fround($169 + $172);
 $176 = Math_fround($170 + $173);
 $177 = Math_fround($96 * $137);
 $178 = Math_fround($107 * $137);
 $179 = Math_fround($118 * $137);
 $180 = Math_fround($174 + $177);
 $181 = Math_fround($175 + $178);
 $182 = Math_fround($176 + $179);
 HEAPF32[$obbBasis>>2] = $150;
 $183 = (($obbBasis) + 4|0);
 HEAPF32[$183>>2] = $151;
 $184 = (($obbBasis) + 8|0);
 HEAPF32[$184>>2] = $152;
 $185 = (($obbBasis) + 12|0);
 HEAPF32[$185>>2] = $165;
 $186 = (($obbBasis) + 16|0);
 HEAPF32[$186>>2] = $166;
 $187 = (($obbBasis) + 20|0);
 HEAPF32[$187>>2] = $167;
 $188 = (($obbBasis) + 24|0);
 HEAPF32[$188>>2] = $180;
 $189 = (($obbBasis) + 28|0);
 HEAPF32[$189>>2] = $181;
 $190 = (($obbBasis) + 32|0);
 HEAPF32[$190>>2] = $182;
 if ($idtScaleMesh) {
  $192 = $98;$194 = $109;$196 = $120;$203 = $150;$205 = $151;$207 = $152;$209 = $165;$211 = $166;$213 = $167;$215 = $180;$217 = $181;$219 = $182;
  $191 = (($hullOBB) + 36|0);
  HEAPF32[$191>>2] = $192;
  $193 = (($hullOBB) + 40|0);
  HEAPF32[$193>>2] = $194;
  $195 = (($hullOBB) + 44|0);
  HEAPF32[$195>>2] = $196;
  $197 = Math_fround(HEAPF32[$extents>>2]);
  $198 = (($hullOBB) + 48|0);
  HEAPF32[$198>>2] = $197;
  $199 = Math_fround(HEAPF32[$75>>2]);
  $200 = (($hullOBB) + 52|0);
  HEAPF32[$200>>2] = $199;
  $201 = Math_fround(HEAPF32[$76>>2]);
  $202 = (($hullOBB) + 56|0);
  HEAPF32[$202>>2] = $201;
  HEAPF32[$hullOBB>>2] = $203;
  $204 = (($hullOBB) + 4|0);
  HEAPF32[$204>>2] = $205;
  $206 = (($hullOBB) + 8|0);
  HEAPF32[$206>>2] = $207;
  $208 = (($hullOBB) + 12|0);
  HEAPF32[$208>>2] = $209;
  $210 = (($hullOBB) + 16|0);
  HEAPF32[$210>>2] = $211;
  $212 = (($hullOBB) + 20|0);
  HEAPF32[$212>>2] = $213;
  $214 = (($hullOBB) + 24|0);
  HEAPF32[$214>>2] = $215;
  $216 = (($hullOBB) + 28|0);
  HEAPF32[$216>>2] = $217;
  $218 = (($hullOBB) + 32|0);
  HEAPF32[$218>>2] = $219;
  STACKTOP = sp;return;
 }
 __ZNK5physx2Cm23FastVertex2ShapeScaling20transformQueryBoundsERNS_6PxVec3ES3_RNS_7PxMat33E($meshScaling,$center,$extents,$obbBasis);
 $$pre = Math_fround(HEAPF32[$center>>2]);
 $$pre34 = Math_fround(HEAPF32[$67>>2]);
 $$pre35 = Math_fround(HEAPF32[$68>>2]);
 $$pre36 = Math_fround(HEAPF32[$obbBasis>>2]);
 $$pre37 = Math_fround(HEAPF32[$183>>2]);
 $$pre38 = Math_fround(HEAPF32[$184>>2]);
 $$pre39 = Math_fround(HEAPF32[$185>>2]);
 $$pre40 = Math_fround(HEAPF32[$186>>2]);
 $$pre41 = Math_fround(HEAPF32[$187>>2]);
 $$pre42 = Math_fround(HEAPF32[$188>>2]);
 $$pre43 = Math_fround(HEAPF32[$189>>2]);
 $$pre44 = Math_fround(HEAPF32[$190>>2]);
 $192 = $$pre;$194 = $$pre34;$196 = $$pre35;$203 = $$pre36;$205 = $$pre37;$207 = $$pre38;$209 = $$pre39;$211 = $$pre40;$213 = $$pre41;$215 = $$pre42;$217 = $$pre43;$219 = $$pre44;
 $191 = (($hullOBB) + 36|0);
 HEAPF32[$191>>2] = $192;
 $193 = (($hullOBB) + 40|0);
 HEAPF32[$193>>2] = $194;
 $195 = (($hullOBB) + 44|0);
 HEAPF32[$195>>2] = $196;
 $197 = Math_fround(HEAPF32[$extents>>2]);
 $198 = (($hullOBB) + 48|0);
 HEAPF32[$198>>2] = $197;
 $199 = Math_fround(HEAPF32[$75>>2]);
 $200 = (($hullOBB) + 52|0);
 HEAPF32[$200>>2] = $199;
 $201 = Math_fround(HEAPF32[$76>>2]);
 $202 = (($hullOBB) + 56|0);
 HEAPF32[$202>>2] = $201;
 HEAPF32[$hullOBB>>2] = $203;
 $204 = (($hullOBB) + 4|0);
 HEAPF32[$204>>2] = $205;
 $206 = (($hullOBB) + 8|0);
 HEAPF32[$206>>2] = $207;
 $208 = (($hullOBB) + 12|0);
 HEAPF32[$208>>2] = $209;
 $210 = (($hullOBB) + 16|0);
 HEAPF32[$210>>2] = $211;
 $212 = (($hullOBB) + 20|0);
 HEAPF32[$212>>2] = $213;
 $214 = (($hullOBB) + 24|0);
 HEAPF32[$214>>2] = $215;
 $216 = (($hullOBB) + 28|0);
 HEAPF32[$216>>2] = $217;
 $218 = (($hullOBB) + 32|0);
 HEAPF32[$218>>2] = $219;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu21computeVertexSpaceOBBERNS0_3BoxERKS1_RKNS_11PxTransformERKNS_11PxMeshScaleE($dst,$src,$meshPose,$meshScale) {
 $dst = $dst|0;
 $src = $src|0;
 $meshPose = $meshPose|0;
 $meshScale = $meshScale|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0;
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0;
 var $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0);
 var $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $invRot$i = 0, $vertexToWorldSkewRot = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $invRot$i = sp + 96|0;
 $vertexToWorldSkewRot = sp;
 $0 = sp + 36|0;
 $1 = Math_fround(HEAPF32[$meshPose>>2]);
 $2 = (($meshPose) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($meshPose) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($meshPose) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($1 + $1);
 $9 = Math_fround($3 + $3);
 $10 = Math_fround($5 + $5);
 $11 = Math_fround($1 * $8);
 $12 = Math_fround($3 * $9);
 $13 = Math_fround($5 * $10);
 $14 = Math_fround($8 * $3);
 $15 = Math_fround($8 * $5);
 $16 = Math_fround($8 * $7);
 $17 = Math_fround($9 * $5);
 $18 = Math_fround($9 * $7);
 $19 = Math_fround($10 * $7);
 $20 = Math_fround(Math_fround(1.0) - $12);
 $21 = Math_fround($20 - $13);
 $22 = Math_fround($14 + $19);
 $23 = Math_fround($15 - $18);
 $24 = Math_fround($14 - $19);
 $25 = Math_fround(Math_fround(1.0) - $11);
 $26 = Math_fround($25 - $13);
 $27 = Math_fround($17 + $16);
 $28 = Math_fround($15 + $18);
 $29 = Math_fround($17 - $16);
 $30 = Math_fround($25 - $12);
 $31 = (($meshScale) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($meshScale) + 16|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($meshScale) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($meshScale) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($32 + $32);
 $40 = Math_fround($34 + $34);
 $41 = Math_fround($36 + $36);
 $42 = Math_fround($32 * $39);
 $43 = Math_fround($34 * $40);
 $44 = Math_fround($36 * $41);
 $45 = Math_fround($39 * $34);
 $46 = Math_fround($39 * $36);
 $47 = Math_fround($39 * $38);
 $48 = Math_fround($40 * $36);
 $49 = Math_fround($40 * $38);
 $50 = Math_fround($41 * $38);
 $51 = Math_fround(Math_fround(1.0) - $43);
 $52 = Math_fround($51 - $44);
 $53 = Math_fround($45 + $50);
 $54 = Math_fround($46 - $49);
 $55 = Math_fround($45 - $50);
 $56 = Math_fround(Math_fround(1.0) - $42);
 $57 = Math_fround($56 - $44);
 $58 = Math_fround($48 + $47);
 $59 = Math_fround($46 + $49);
 $60 = Math_fround($48 - $47);
 $61 = Math_fround($56 - $43);
 $62 = Math_fround(HEAPF32[$meshScale>>2]);
 $63 = Math_fround($62 * $52);
 $64 = Math_fround($62 * $55);
 $65 = Math_fround($62 * $59);
 $66 = (($meshScale) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($53 * $67);
 $69 = Math_fround($57 * $67);
 $70 = Math_fround($60 * $67);
 $71 = (($meshScale) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($54 * $72);
 $74 = Math_fround($58 * $72);
 $75 = Math_fround($61 * $72);
 $76 = Math_fround($52 * $63);
 $77 = Math_fround($52 * $64);
 $78 = Math_fround($52 * $65);
 $79 = Math_fround($53 * $68);
 $80 = Math_fround($53 * $69);
 $81 = Math_fround($53 * $70);
 $82 = Math_fround($76 + $79);
 $83 = Math_fround($77 + $80);
 $84 = Math_fround($78 + $81);
 $85 = Math_fround($54 * $73);
 $86 = Math_fround($54 * $74);
 $87 = Math_fround($54 * $75);
 $88 = Math_fround($82 + $85);
 $89 = Math_fround($83 + $86);
 $90 = Math_fround($84 + $87);
 $91 = Math_fround($55 * $63);
 $92 = Math_fround($55 * $64);
 $93 = Math_fround($55 * $65);
 $94 = Math_fround($57 * $68);
 $95 = Math_fround($57 * $69);
 $96 = Math_fround($57 * $70);
 $97 = Math_fround($91 + $94);
 $98 = Math_fround($92 + $95);
 $99 = Math_fround($93 + $96);
 $100 = Math_fround($58 * $73);
 $101 = Math_fround($58 * $74);
 $102 = Math_fround($58 * $75);
 $103 = Math_fround($97 + $100);
 $104 = Math_fround($98 + $101);
 $105 = Math_fround($99 + $102);
 $106 = Math_fround($59 * $63);
 $107 = Math_fround($59 * $64);
 $108 = Math_fround($59 * $65);
 $109 = Math_fround($60 * $68);
 $110 = Math_fround($60 * $69);
 $111 = Math_fround($60 * $70);
 $112 = Math_fround($106 + $109);
 $113 = Math_fround($107 + $110);
 $114 = Math_fround($108 + $111);
 $115 = Math_fround($61 * $73);
 $116 = Math_fround($61 * $74);
 $117 = Math_fround($61 * $75);
 $118 = Math_fround($112 + $115);
 $119 = Math_fround($113 + $116);
 $120 = Math_fround($114 + $117);
 $121 = Math_fround($21 * $88);
 $122 = Math_fround($22 * $88);
 $123 = Math_fround($23 * $88);
 $124 = Math_fround($24 * $89);
 $125 = Math_fround($26 * $89);
 $126 = Math_fround($27 * $89);
 $127 = Math_fround($121 + $124);
 $128 = Math_fround($122 + $125);
 $129 = Math_fround($123 + $126);
 $130 = Math_fround($28 * $90);
 $131 = Math_fround($29 * $90);
 $132 = Math_fround($30 * $90);
 $133 = Math_fround($130 + $127);
 $134 = Math_fround($131 + $128);
 $135 = Math_fround($132 + $129);
 $136 = Math_fround($21 * $103);
 $137 = Math_fround($22 * $103);
 $138 = Math_fround($23 * $103);
 $139 = Math_fround($24 * $104);
 $140 = Math_fround($26 * $104);
 $141 = Math_fround($27 * $104);
 $142 = Math_fround($136 + $139);
 $143 = Math_fround($137 + $140);
 $144 = Math_fround($138 + $141);
 $145 = Math_fround($28 * $105);
 $146 = Math_fround($29 * $105);
 $147 = Math_fround($30 * $105);
 $148 = Math_fround($145 + $142);
 $149 = Math_fround($146 + $143);
 $150 = Math_fround($147 + $144);
 $151 = Math_fround($21 * $118);
 $152 = Math_fround($22 * $118);
 $153 = Math_fround($23 * $118);
 $154 = Math_fround($24 * $119);
 $155 = Math_fround($26 * $119);
 $156 = Math_fround($27 * $119);
 $157 = Math_fround($151 + $154);
 $158 = Math_fround($152 + $155);
 $159 = Math_fround($153 + $156);
 $160 = Math_fround($28 * $120);
 $161 = Math_fround($29 * $120);
 $162 = Math_fround($30 * $120);
 $163 = Math_fround($160 + $157);
 $164 = Math_fround($161 + $158);
 $165 = Math_fround($162 + $159);
 HEAPF32[$vertexToWorldSkewRot>>2] = $133;
 $166 = (($vertexToWorldSkewRot) + 4|0);
 HEAPF32[$166>>2] = $134;
 $167 = (($vertexToWorldSkewRot) + 8|0);
 HEAPF32[$167>>2] = $135;
 $168 = (($vertexToWorldSkewRot) + 12|0);
 HEAPF32[$168>>2] = $148;
 $169 = (($vertexToWorldSkewRot) + 16|0);
 HEAPF32[$169>>2] = $149;
 $170 = (($vertexToWorldSkewRot) + 20|0);
 HEAPF32[$170>>2] = $150;
 $171 = (($vertexToWorldSkewRot) + 24|0);
 HEAPF32[$171>>2] = $163;
 $172 = (($vertexToWorldSkewRot) + 28|0);
 HEAPF32[$172>>2] = $164;
 $173 = (($vertexToWorldSkewRot) + 32|0);
 HEAPF32[$173>>2] = $165;
 __ZNK5physx7PxMat3310getInverseEv($invRot$i,$vertexToWorldSkewRot);
 $174 = (($meshPose) + 16|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = Math_fround(-$175);
 $177 = (($meshPose) + 20|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = Math_fround(-$178);
 $180 = (($meshPose) + 24|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = Math_fround(-$181);
 $183 = Math_fround(HEAPF32[$invRot$i>>2]);
 $184 = Math_fround($183 * $176);
 $185 = (($invRot$i) + 4|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = Math_fround($186 * $176);
 $188 = (($invRot$i) + 8|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = Math_fround($189 * $176);
 $191 = (($invRot$i) + 12|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = Math_fround($192 * $179);
 $194 = (($invRot$i) + 16|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = Math_fround($195 * $179);
 $197 = (($invRot$i) + 20|0);
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = Math_fround($198 * $179);
 $200 = Math_fround($184 + $193);
 $201 = Math_fround($187 + $196);
 $202 = Math_fround($190 + $199);
 $203 = (($invRot$i) + 24|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = Math_fround($204 * $182);
 $206 = (($invRot$i) + 28|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = Math_fround($207 * $182);
 $209 = (($invRot$i) + 32|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = Math_fround($210 * $182);
 $212 = Math_fround($200 + $205);
 $213 = Math_fround($201 + $208);
 $214 = Math_fround($202 + $211);
 HEAPF32[$invRot$i>>2] = $183;
 $215 = (($invRot$i) + 4|0);
 HEAPF32[$215>>2] = $186;
 $216 = (($invRot$i) + 8|0);
 HEAPF32[$216>>2] = $189;
 $217 = (($invRot$i) + 12|0);
 HEAPF32[$217>>2] = $192;
 $218 = (($invRot$i) + 16|0);
 HEAPF32[$218>>2] = $195;
 $219 = (($invRot$i) + 20|0);
 HEAPF32[$219>>2] = $198;
 $220 = (($invRot$i) + 24|0);
 HEAPF32[$220>>2] = $204;
 $221 = (($invRot$i) + 28|0);
 HEAPF32[$221>>2] = $207;
 $222 = (($invRot$i) + 32|0);
 HEAPF32[$222>>2] = $210;
 $223 = (($invRot$i) + 36|0);
 HEAPF32[$223>>2] = $212;
 $224 = (($invRot$i) + 40|0);
 HEAPF32[$224>>2] = $213;
 $225 = (($invRot$i) + 44|0);
 HEAPF32[$225>>2] = $214;
 __ZN5physx9transformERKNS_2Cm8Matrix34ERKNS_2Gu3BoxE($0,$invRot$i,$src);
 $226 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$dst>>2] = $226;
 $227 = (($0) + 4|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 $229 = (($dst) + 4|0);
 HEAPF32[$229>>2] = $228;
 $230 = (($0) + 8|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($dst) + 8|0);
 HEAPF32[$232>>2] = $231;
 $233 = (($0) + 12|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = (($dst) + 12|0);
 HEAPF32[$235>>2] = $234;
 $236 = (($0) + 16|0);
 $237 = Math_fround(HEAPF32[$236>>2]);
 $238 = (($dst) + 16|0);
 HEAPF32[$238>>2] = $237;
 $239 = (($0) + 20|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 $241 = (($dst) + 20|0);
 HEAPF32[$241>>2] = $240;
 $242 = (($0) + 24|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($dst) + 24|0);
 HEAPF32[$244>>2] = $243;
 $245 = (($0) + 28|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = (($dst) + 28|0);
 HEAPF32[$247>>2] = $246;
 $248 = (($0) + 32|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = (($dst) + 32|0);
 HEAPF32[$250>>2] = $249;
 $251 = (($0) + 36|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 $253 = (($dst) + 36|0);
 HEAPF32[$253>>2] = $252;
 $254 = (($0) + 40|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = (($dst) + 40|0);
 HEAPF32[$256>>2] = $255;
 $257 = (($0) + 44|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 $259 = (($dst) + 44|0);
 HEAPF32[$259>>2] = $258;
 $260 = (($0) + 48|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = (($dst) + 48|0);
 HEAPF32[$262>>2] = $261;
 $263 = (($0) + 52|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = (($dst) + 52|0);
 HEAPF32[$265>>2] = $264;
 $266 = (($0) + 56|0);
 $267 = Math_fround(HEAPF32[$266>>2]);
 $268 = (($dst) + 56|0);
 HEAPF32[$268>>2] = $267;
 STACKTOP = sp;return;
}
function __ZN5physx9transformERKNS_2Cm8Matrix34ERKNS_2Gu3BoxE($agg$result,$transfo,$box) {
 $agg$result = $agg$result|0;
 $transfo = $transfo|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0;
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($box) + 48|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(HEAPF32[$box>>2]);
 $4 = Math_fround($2 * $3);
 $5 = (($box) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($2 * $6);
 $8 = (($box) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($2 * $9);
 $11 = Math_fround(HEAPF32[$transfo>>2]);
 $12 = Math_fround($4 * $11);
 $13 = (($transfo) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($4 * $14);
 $16 = (($transfo) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($4 * $17);
 $19 = (($transfo) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($7 * $20);
 $22 = (($transfo) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($7 * $23);
 $25 = (($transfo) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($7 * $26);
 $28 = Math_fround($12 + $21);
 $29 = Math_fround($15 + $24);
 $30 = Math_fround($18 + $27);
 $31 = (($transfo) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($10 * $32);
 $34 = (($transfo) + 28|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($10 * $35);
 $37 = (($transfo) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($10 * $38);
 $40 = Math_fround($28 + $33);
 $41 = Math_fround($29 + $36);
 $42 = Math_fround($30 + $39);
 HEAPF32[$agg$result>>2] = $40;
 $43 = (($agg$result) + 4|0);
 HEAPF32[$43>>2] = $41;
 $44 = (($agg$result) + 8|0);
 HEAPF32[$44>>2] = $42;
 $45 = (($box) + 52|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($box) + 12|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($46 * $48);
 $50 = (($box) + 16|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($46 * $51);
 $53 = (($box) + 20|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($46 * $54);
 $56 = Math_fround(HEAPF32[$transfo>>2]);
 $57 = Math_fround($49 * $56);
 $58 = Math_fround(HEAPF32[$13>>2]);
 $59 = Math_fround($49 * $58);
 $60 = Math_fround(HEAPF32[$16>>2]);
 $61 = Math_fround($49 * $60);
 $62 = Math_fround(HEAPF32[$19>>2]);
 $63 = Math_fround($52 * $62);
 $64 = Math_fround(HEAPF32[$22>>2]);
 $65 = Math_fround($52 * $64);
 $66 = Math_fround(HEAPF32[$25>>2]);
 $67 = Math_fround($52 * $66);
 $68 = Math_fround($57 + $63);
 $69 = Math_fround($59 + $65);
 $70 = Math_fround($61 + $67);
 $71 = Math_fround(HEAPF32[$31>>2]);
 $72 = Math_fround($55 * $71);
 $73 = Math_fround(HEAPF32[$34>>2]);
 $74 = Math_fround($55 * $73);
 $75 = Math_fround(HEAPF32[$37>>2]);
 $76 = Math_fround($55 * $75);
 $77 = Math_fround($68 + $72);
 $78 = Math_fround($69 + $74);
 $79 = Math_fround($70 + $76);
 $80 = (($agg$result) + 12|0);
 HEAPF32[$80>>2] = $77;
 $81 = (($agg$result) + 16|0);
 HEAPF32[$81>>2] = $78;
 $82 = (($agg$result) + 20|0);
 HEAPF32[$82>>2] = $79;
 $83 = (($box) + 56|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($box) + 24|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($84 * $86);
 $88 = (($box) + 28|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($84 * $89);
 $91 = (($box) + 32|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($84 * $92);
 $94 = Math_fround(HEAPF32[$transfo>>2]);
 $95 = Math_fround($87 * $94);
 $96 = Math_fround(HEAPF32[$13>>2]);
 $97 = Math_fround($87 * $96);
 $98 = Math_fround(HEAPF32[$16>>2]);
 $99 = Math_fround($87 * $98);
 $100 = Math_fround(HEAPF32[$19>>2]);
 $101 = Math_fround($90 * $100);
 $102 = Math_fround(HEAPF32[$22>>2]);
 $103 = Math_fround($90 * $102);
 $104 = Math_fround(HEAPF32[$25>>2]);
 $105 = Math_fround($90 * $104);
 $106 = Math_fround($95 + $101);
 $107 = Math_fround($97 + $103);
 $108 = Math_fround($99 + $105);
 $109 = Math_fround(HEAPF32[$31>>2]);
 $110 = Math_fround($93 * $109);
 $111 = Math_fround(HEAPF32[$34>>2]);
 $112 = Math_fround($93 * $111);
 $113 = Math_fround(HEAPF32[$37>>2]);
 $114 = Math_fround($93 * $113);
 $115 = Math_fround($106 + $110);
 $116 = Math_fround($107 + $112);
 $117 = Math_fround($108 + $114);
 $118 = (($agg$result) + 24|0);
 HEAPF32[$118>>2] = $115;
 $119 = (($agg$result) + 28|0);
 HEAPF32[$119>>2] = $116;
 $120 = (($agg$result) + 32|0);
 HEAPF32[$120>>2] = $117;
 $121 = (($box) + 36|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround(HEAPF32[$transfo>>2]);
 $124 = Math_fround($122 * $123);
 $125 = Math_fround(HEAPF32[$13>>2]);
 $126 = Math_fround($122 * $125);
 $127 = Math_fround(HEAPF32[$16>>2]);
 $128 = Math_fround($122 * $127);
 $129 = (($box) + 40|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = Math_fround(HEAPF32[$19>>2]);
 $132 = Math_fround($130 * $131);
 $133 = Math_fround(HEAPF32[$22>>2]);
 $134 = Math_fround($130 * $133);
 $135 = Math_fround(HEAPF32[$25>>2]);
 $136 = Math_fround($130 * $135);
 $137 = Math_fround($124 + $132);
 $138 = Math_fround($126 + $134);
 $139 = Math_fround($128 + $136);
 $140 = (($box) + 44|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = Math_fround(HEAPF32[$31>>2]);
 $143 = Math_fround($141 * $142);
 $144 = Math_fround(HEAPF32[$34>>2]);
 $145 = Math_fround($141 * $144);
 $146 = Math_fround(HEAPF32[$37>>2]);
 $147 = Math_fround($141 * $146);
 $148 = Math_fround($137 + $143);
 $149 = Math_fround($138 + $145);
 $150 = Math_fround($139 + $147);
 $151 = (($transfo) + 36|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = Math_fround($148 + $152);
 $154 = (($transfo) + 40|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = Math_fround($149 + $155);
 $157 = (($transfo) + 44|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround($150 + $158);
 $160 = (($agg$result) + 36|0);
 HEAPF32[$160>>2] = $153;
 $161 = (($agg$result) + 40|0);
 HEAPF32[$161>>2] = $156;
 $162 = (($agg$result) + 44|0);
 HEAPF32[$162>>2] = $159;
 __ZN5physx6shdfnd19optimizeBoundingBoxERNS_7PxMat33E($0,$agg$result);
 $163 = Math_fround(HEAPF32[$0>>2]);
 $164 = (($agg$result) + 48|0);
 HEAPF32[$164>>2] = $163;
 $165 = (($0) + 4|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = (($agg$result) + 52|0);
 HEAPF32[$167>>2] = $166;
 $168 = (($0) + 8|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($agg$result) + 56|0);
 HEAPF32[$170>>2] = $169;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu22computeOBBAroundConvexERNS0_3BoxERKNS_20PxConvexMeshGeometryEPKNS_12PxConvexMeshERKNS_11PxTransformE($obb,$convexGeom,$cm,$convexPose) {
 $obb = $obb|0;
 $convexGeom = $convexGeom|0;
 $cm = $cm|0;
 $convexPose = $convexPose|0;
 var $$phi$trans$insert = 0, $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0);
 var $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = Math_fround(0);
 var $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 60|0;
 $1 = sp;
 $2 = (($cm) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($cm) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($cm) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($cm) + 28|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($cm) + 32|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($cm) + 36|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($3 + $9);
 $15 = Math_fround($5 + $11);
 $16 = Math_fround($7 + $13);
 $17 = Math_fround($14 * Math_fround(0.5));
 $18 = Math_fround($15 * Math_fround(0.5));
 $19 = Math_fround($16 * Math_fround(0.5));
 $20 = Math_fround($9 - $3);
 $21 = Math_fround($11 - $5);
 $22 = Math_fround($13 - $7);
 $23 = Math_fround($20 * Math_fround(0.5));
 $24 = Math_fround($21 * Math_fround(0.5));
 $25 = Math_fround($22 * Math_fround(0.5));
 $26 = (($convexGeom) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = $27 == Math_fround(1.0);
 if ($28) {
  $29 = (($convexGeom) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = $30 == Math_fround(1.0);
  if ($31) {
   $32 = (($convexGeom) + 12|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = $33 == Math_fround(1.0);
   if ($34) {
    $35 = Math_fround(HEAPF32[$convexPose>>2]);
    $36 = Math_fround($35 + $35);
    $37 = (($convexPose) + 4|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = Math_fround($38 + $38);
    $40 = (($convexPose) + 8|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = Math_fround($41 + $41);
    $43 = (($convexPose) + 12|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = Math_fround($36 * $44);
    $46 = Math_fround($39 * $44);
    $47 = Math_fround($44 * $42);
    $48 = Math_fround($35 * $36);
    $49 = Math_fround($35 * $39);
    $50 = Math_fround($35 * $42);
    $51 = Math_fround($38 * $39);
    $52 = Math_fround($38 * $42);
    $53 = Math_fround($41 * $42);
    $54 = Math_fround(Math_fround(1.0) - $51);
    $55 = Math_fround($54 - $53);
    $56 = Math_fround($49 + $47);
    $57 = Math_fround($50 - $46);
    $58 = Math_fround($49 - $47);
    $59 = Math_fround(Math_fround(1.0) - $48);
    $60 = Math_fround($59 - $53);
    $61 = Math_fround($52 + $45);
    $62 = Math_fround($50 + $46);
    $63 = Math_fround($52 - $45);
    $64 = Math_fround($59 - $51);
    $65 = (($convexPose) + 16|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = (($convexPose) + 20|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = (($convexPose) + 24|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = (($obb) + 48|0);
    HEAPF32[$71>>2] = $23;
    $72 = (($obb) + 52|0);
    HEAPF32[$72>>2] = $24;
    $73 = (($obb) + 56|0);
    HEAPF32[$73>>2] = $25;
    $74 = Math_fround($17 * $55);
    $75 = Math_fround($17 * $56);
    $76 = Math_fround($17 * $57);
    $77 = Math_fround($18 * $58);
    $78 = Math_fround($18 * $60);
    $79 = Math_fround($18 * $61);
    $80 = Math_fround($74 + $77);
    $81 = Math_fround($75 + $78);
    $82 = Math_fround($76 + $79);
    $83 = Math_fround($19 * $62);
    $84 = Math_fround($19 * $63);
    $85 = Math_fround($19 * $64);
    $86 = Math_fround($83 + $80);
    $87 = Math_fround($84 + $81);
    $88 = Math_fround($85 + $82);
    $89 = Math_fround($66 + $86);
    $90 = Math_fround($68 + $87);
    $91 = Math_fround($70 + $88);
    $92 = (($obb) + 36|0);
    HEAPF32[$92>>2] = $89;
    $93 = (($obb) + 40|0);
    HEAPF32[$93>>2] = $90;
    $94 = (($obb) + 44|0);
    HEAPF32[$94>>2] = $91;
    $95 = Math_fround($58 * Math_fround(0.0));
    $96 = Math_fround($60 * Math_fround(0.0));
    $97 = Math_fround($61 * Math_fround(0.0));
    $98 = Math_fround($55 + $95);
    $99 = Math_fround($56 + $96);
    $100 = Math_fround($57 + $97);
    $101 = Math_fround($62 * Math_fround(0.0));
    $102 = Math_fround($63 * Math_fround(0.0));
    $103 = Math_fround($64 * Math_fround(0.0));
    $104 = Math_fround($101 + $98);
    $105 = Math_fround($102 + $99);
    $106 = Math_fround($103 + $100);
    $107 = Math_fround($55 * Math_fround(0.0));
    $108 = Math_fround($56 * Math_fround(0.0));
    $109 = Math_fround($57 * Math_fround(0.0));
    $110 = Math_fround($58 + $107);
    $111 = Math_fround($60 + $108);
    $112 = Math_fround($61 + $109);
    $113 = Math_fround($101 + $110);
    $114 = Math_fround($102 + $111);
    $115 = Math_fround($103 + $112);
    $116 = Math_fround($107 + $95);
    $117 = Math_fround($108 + $96);
    $118 = Math_fround($109 + $97);
    $119 = Math_fround($62 + $116);
    $120 = Math_fround($63 + $117);
    $121 = Math_fround($64 + $118);
    HEAPF32[$obb>>2] = $104;
    $122 = (($obb) + 4|0);
    HEAPF32[$122>>2] = $105;
    $123 = (($obb) + 8|0);
    HEAPF32[$123>>2] = $106;
    $124 = (($obb) + 12|0);
    HEAPF32[$124>>2] = $113;
    $125 = (($obb) + 16|0);
    HEAPF32[$125>>2] = $114;
    $126 = (($obb) + 20|0);
    HEAPF32[$126>>2] = $115;
    $127 = (($obb) + 24|0);
    HEAPF32[$127>>2] = $119;
    $128 = (($obb) + 28|0);
    HEAPF32[$128>>2] = $120;
    $129 = (($obb) + 32|0);
    HEAPF32[$129>>2] = $121;
    STACKTOP = sp;return;
   } else {
    $195 = $30;
   }
  } else {
   $195 = $30;
  }
 } else {
  $$phi$trans$insert = (($26) + 4|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $195 = $$pre;
 }
 $130 = Math_fround(HEAPF32[$convexPose>>2]);
 $131 = (($convexPose) + 4|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($convexPose) + 8|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($convexPose) + 12|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($130 + $130);
 $138 = Math_fround($132 + $132);
 $139 = Math_fround($134 + $134);
 $140 = Math_fround($130 * $137);
 $141 = Math_fround($132 * $138);
 $142 = Math_fround($134 * $139);
 $143 = Math_fround($137 * $132);
 $144 = Math_fround($137 * $134);
 $145 = Math_fround($137 * $136);
 $146 = Math_fround($138 * $134);
 $147 = Math_fround($138 * $136);
 $148 = Math_fround($139 * $136);
 $149 = Math_fround(Math_fround(1.0) - $141);
 $150 = Math_fround($149 - $142);
 $151 = Math_fround($143 + $148);
 $152 = Math_fround($144 - $147);
 $153 = Math_fround($143 - $148);
 $154 = Math_fround(Math_fround(1.0) - $140);
 $155 = Math_fround($154 - $142);
 $156 = Math_fround($146 + $145);
 $157 = Math_fround($144 + $147);
 $158 = Math_fround($146 - $145);
 $159 = Math_fround($154 - $141);
 $160 = (($convexGeom) + 16|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($convexGeom) + 20|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($convexGeom) + 24|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = (($convexGeom) + 28|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = Math_fround($161 + $161);
 $169 = Math_fround($163 + $163);
 $170 = Math_fround($165 + $165);
 $171 = Math_fround($161 * $168);
 $172 = Math_fround($163 * $169);
 $173 = Math_fround($165 * $170);
 $174 = Math_fround($168 * $163);
 $175 = Math_fround($168 * $165);
 $176 = Math_fround($168 * $167);
 $177 = Math_fround($169 * $165);
 $178 = Math_fround($169 * $167);
 $179 = Math_fround($170 * $167);
 $180 = Math_fround(Math_fround(1.0) - $172);
 $181 = Math_fround($180 - $173);
 $182 = Math_fround($174 + $179);
 $183 = Math_fround($175 - $178);
 $184 = Math_fround($174 - $179);
 $185 = Math_fround(Math_fround(1.0) - $171);
 $186 = Math_fround($185 - $173);
 $187 = Math_fround($177 + $176);
 $188 = Math_fround($175 + $178);
 $189 = Math_fround($177 - $176);
 $190 = Math_fround($185 - $172);
 $191 = Math_fround($27 * $181);
 $192 = Math_fround($27 * $184);
 $193 = Math_fround($27 * $188);
 $194 = Math_fround($182 * $195);
 $196 = Math_fround($186 * $195);
 $197 = Math_fround($189 * $195);
 $198 = (($26) + 8|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = Math_fround($183 * $199);
 $201 = Math_fround($187 * $199);
 $202 = Math_fround($190 * $199);
 $203 = Math_fround($181 * $191);
 $204 = Math_fround($181 * $192);
 $205 = Math_fround($181 * $193);
 $206 = Math_fround($182 * $194);
 $207 = Math_fround($182 * $196);
 $208 = Math_fround($182 * $197);
 $209 = Math_fround($203 + $206);
 $210 = Math_fround($204 + $207);
 $211 = Math_fround($205 + $208);
 $212 = Math_fround($183 * $200);
 $213 = Math_fround($183 * $201);
 $214 = Math_fround($183 * $202);
 $215 = Math_fround($209 + $212);
 $216 = Math_fround($210 + $213);
 $217 = Math_fround($211 + $214);
 $218 = Math_fround($184 * $191);
 $219 = Math_fround($184 * $192);
 $220 = Math_fround($184 * $193);
 $221 = Math_fround($186 * $194);
 $222 = Math_fround($186 * $196);
 $223 = Math_fround($186 * $197);
 $224 = Math_fround($218 + $221);
 $225 = Math_fround($219 + $222);
 $226 = Math_fround($220 + $223);
 $227 = Math_fround($187 * $200);
 $228 = Math_fround($187 * $201);
 $229 = Math_fround($187 * $202);
 $230 = Math_fround($224 + $227);
 $231 = Math_fround($225 + $228);
 $232 = Math_fround($226 + $229);
 $233 = Math_fround($188 * $191);
 $234 = Math_fround($188 * $192);
 $235 = Math_fround($188 * $193);
 $236 = Math_fround($189 * $194);
 $237 = Math_fround($189 * $196);
 $238 = Math_fround($189 * $197);
 $239 = Math_fround($233 + $236);
 $240 = Math_fround($234 + $237);
 $241 = Math_fround($235 + $238);
 $242 = Math_fround($190 * $200);
 $243 = Math_fround($190 * $201);
 $244 = Math_fround($190 * $202);
 $245 = Math_fround($239 + $242);
 $246 = Math_fround($240 + $243);
 $247 = Math_fround($241 + $244);
 $248 = Math_fround($150 * $215);
 $249 = Math_fround($151 * $215);
 $250 = Math_fround($152 * $215);
 $251 = Math_fround($153 * $216);
 $252 = Math_fround($155 * $216);
 $253 = Math_fround($156 * $216);
 $254 = Math_fround($248 + $251);
 $255 = Math_fround($249 + $252);
 $256 = Math_fround($250 + $253);
 $257 = Math_fround($157 * $217);
 $258 = Math_fround($158 * $217);
 $259 = Math_fround($159 * $217);
 $260 = Math_fround($257 + $254);
 $261 = Math_fround($258 + $255);
 $262 = Math_fround($259 + $256);
 $263 = Math_fround($150 * $230);
 $264 = Math_fround($151 * $230);
 $265 = Math_fround($152 * $230);
 $266 = Math_fround($153 * $231);
 $267 = Math_fround($155 * $231);
 $268 = Math_fround($156 * $231);
 $269 = Math_fround($263 + $266);
 $270 = Math_fround($264 + $267);
 $271 = Math_fround($265 + $268);
 $272 = Math_fround($157 * $232);
 $273 = Math_fround($158 * $232);
 $274 = Math_fround($159 * $232);
 $275 = Math_fround($272 + $269);
 $276 = Math_fround($273 + $270);
 $277 = Math_fround($274 + $271);
 $278 = Math_fround($150 * $245);
 $279 = Math_fround($151 * $245);
 $280 = Math_fround($152 * $245);
 $281 = Math_fround($153 * $246);
 $282 = Math_fround($155 * $246);
 $283 = Math_fround($156 * $246);
 $284 = Math_fround($278 + $281);
 $285 = Math_fround($279 + $282);
 $286 = Math_fround($280 + $283);
 $287 = Math_fround($157 * $247);
 $288 = Math_fround($158 * $247);
 $289 = Math_fround($159 * $247);
 $290 = Math_fround($287 + $284);
 $291 = Math_fround($288 + $285);
 $292 = Math_fround($289 + $286);
 $293 = (($convexPose) + 16|0);
 $294 = Math_fround(HEAPF32[$293>>2]);
 $295 = (($convexPose) + 20|0);
 $296 = Math_fround(HEAPF32[$295>>2]);
 $297 = (($convexPose) + 24|0);
 $298 = Math_fround(HEAPF32[$297>>2]);
 $299 = Math_fround($23 * Math_fround(0.0));
 $300 = Math_fround($23 * $260);
 $301 = Math_fround($23 * $261);
 $302 = Math_fround($23 * $262);
 $303 = Math_fround($299 * $275);
 $304 = Math_fround($299 * $276);
 $305 = Math_fround($299 * $277);
 $306 = Math_fround($300 + $303);
 $307 = Math_fround($301 + $304);
 $308 = Math_fround($302 + $305);
 $309 = Math_fround($299 * $290);
 $310 = Math_fround($299 * $291);
 $311 = Math_fround($299 * $292);
 $312 = Math_fround($309 + $306);
 $313 = Math_fround($310 + $307);
 $314 = Math_fround($311 + $308);
 HEAPF32[$1>>2] = $312;
 $315 = (($1) + 4|0);
 HEAPF32[$315>>2] = $313;
 $316 = (($1) + 8|0);
 HEAPF32[$316>>2] = $314;
 $317 = Math_fround($24 * Math_fround(0.0));
 $318 = Math_fround($317 * $260);
 $319 = Math_fround($317 * $261);
 $320 = Math_fround($317 * $262);
 $321 = Math_fround($24 * $275);
 $322 = Math_fround($24 * $276);
 $323 = Math_fround($24 * $277);
 $324 = Math_fround($318 + $321);
 $325 = Math_fround($319 + $322);
 $326 = Math_fround($320 + $323);
 $327 = Math_fround($317 * $290);
 $328 = Math_fround($317 * $291);
 $329 = Math_fround($317 * $292);
 $330 = Math_fround($327 + $324);
 $331 = Math_fround($328 + $325);
 $332 = Math_fround($329 + $326);
 $333 = (($1) + 12|0);
 HEAPF32[$333>>2] = $330;
 $334 = (($1) + 16|0);
 HEAPF32[$334>>2] = $331;
 $335 = (($1) + 20|0);
 HEAPF32[$335>>2] = $332;
 $336 = Math_fround($25 * Math_fround(0.0));
 $337 = Math_fround($336 * $260);
 $338 = Math_fround($336 * $261);
 $339 = Math_fround($336 * $262);
 $340 = Math_fround($336 * $275);
 $341 = Math_fround($336 * $276);
 $342 = Math_fround($336 * $277);
 $343 = Math_fround($337 + $340);
 $344 = Math_fround($338 + $341);
 $345 = Math_fround($339 + $342);
 $346 = Math_fround($25 * $290);
 $347 = Math_fround($25 * $291);
 $348 = Math_fround($25 * $292);
 $349 = Math_fround($346 + $343);
 $350 = Math_fround($347 + $344);
 $351 = Math_fround($348 + $345);
 $352 = (($1) + 24|0);
 HEAPF32[$352>>2] = $349;
 $353 = (($1) + 28|0);
 HEAPF32[$353>>2] = $350;
 $354 = (($1) + 32|0);
 HEAPF32[$354>>2] = $351;
 $355 = Math_fround($17 * $260);
 $356 = Math_fround($17 * $261);
 $357 = Math_fround($17 * $262);
 $358 = Math_fround($18 * $275);
 $359 = Math_fround($18 * $276);
 $360 = Math_fround($18 * $277);
 $361 = Math_fround($355 + $358);
 $362 = Math_fround($356 + $359);
 $363 = Math_fround($357 + $360);
 $364 = Math_fround($19 * $290);
 $365 = Math_fround($19 * $291);
 $366 = Math_fround($19 * $292);
 $367 = Math_fround($364 + $361);
 $368 = Math_fround($365 + $362);
 $369 = Math_fround($366 + $363);
 $370 = Math_fround($294 + $367);
 $371 = Math_fround($296 + $368);
 $372 = Math_fround($298 + $369);
 $373 = (($1) + 36|0);
 HEAPF32[$373>>2] = $370;
 $374 = (($1) + 40|0);
 HEAPF32[$374>>2] = $371;
 $375 = (($1) + 44|0);
 HEAPF32[$375>>2] = $372;
 __ZN5physx6shdfnd19optimizeBoundingBoxERNS_7PxMat33E($0,$1);
 $376 = Math_fround(HEAPF32[$0>>2]);
 $377 = (($1) + 48|0);
 HEAPF32[$377>>2] = $376;
 $378 = (($0) + 4|0);
 $379 = Math_fround(HEAPF32[$378>>2]);
 $380 = (($1) + 52|0);
 HEAPF32[$380>>2] = $379;
 $381 = (($0) + 8|0);
 $382 = Math_fround(HEAPF32[$381>>2]);
 $383 = (($1) + 56|0);
 HEAPF32[$383>>2] = $382;
 $384 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$obb>>2] = $384;
 $385 = Math_fround(HEAPF32[$315>>2]);
 $386 = (($obb) + 4|0);
 HEAPF32[$386>>2] = $385;
 $387 = Math_fround(HEAPF32[$316>>2]);
 $388 = (($obb) + 8|0);
 HEAPF32[$388>>2] = $387;
 $389 = Math_fround(HEAPF32[$333>>2]);
 $390 = (($obb) + 12|0);
 HEAPF32[$390>>2] = $389;
 $391 = Math_fround(HEAPF32[$334>>2]);
 $392 = (($obb) + 16|0);
 HEAPF32[$392>>2] = $391;
 $393 = Math_fround(HEAPF32[$335>>2]);
 $394 = (($obb) + 20|0);
 HEAPF32[$394>>2] = $393;
 $395 = Math_fround(HEAPF32[$352>>2]);
 $396 = (($obb) + 24|0);
 HEAPF32[$396>>2] = $395;
 $397 = Math_fround(HEAPF32[$353>>2]);
 $398 = (($obb) + 28|0);
 HEAPF32[$398>>2] = $397;
 $399 = Math_fround(HEAPF32[$354>>2]);
 $400 = (($obb) + 32|0);
 HEAPF32[$400>>2] = $399;
 $401 = Math_fround(HEAPF32[$373>>2]);
 $402 = (($obb) + 36|0);
 HEAPF32[$402>>2] = $401;
 $403 = Math_fround(HEAPF32[$374>>2]);
 $404 = (($obb) + 40|0);
 HEAPF32[$404>>2] = $403;
 $405 = Math_fround(HEAPF32[$375>>2]);
 $406 = (($obb) + 44|0);
 HEAPF32[$406>>2] = $405;
 $407 = (($obb) + 48|0);
 HEAPF32[$407>>2] = $376;
 $408 = (($obb) + 52|0);
 HEAPF32[$408>>2] = $379;
 $409 = (($obb) + 56|0);
 HEAPF32[$409>>2] = $382;
 STACKTOP = sp;return;
}
function __ZN5physx13CubemapLookupERKNS_6PxVec3ERfS3_($direction,$u,$v) {
 $direction = $direction|0;
 $u = $u|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $Index1$0 = 0, $Index2$0 = 0, $Index3$0 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i1 = Math_fround(0), $fabsf$i$i2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$direction>>2]);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($0)))));
 $1 = (($direction) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $fabsf$i$i1 = (Math_fround(Math_abs((Math_fround($2)))));
 $3 = (($direction) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($4)))));
 $5 = $fabsf$i$i1 > $fabsf$i$i;
 $6 = $fabsf$i$i1 > $fabsf$i$i2;
 $7 = $5 & $6;
 if ($7) {
  $Index1$0 = 1;$Index2$0 = 2;$Index3$0 = 0;
 } else {
  $8 = $fabsf$i$i2 > $fabsf$i$i;
  if ($8) {
   $Index1$0 = 2;$Index2$0 = 0;$Index3$0 = 1;
  } else {
   $Index1$0 = 0;$Index2$0 = 1;$Index3$0 = 2;
  }
 }
 $9 = (($direction) + ($Index1$0<<2)|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (Math_fround(Math_abs((Math_fround($10)))));
 $12 = Math_fround(Math_fround(1.0) / $11);
 $13 = (HEAPF32[tempDoublePtr>>2]=$10,HEAP32[tempDoublePtr>>2]|0);
 $14 = $13 >>> 31;
 $15 = (($direction) + ($Index2$0<<2)|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($12 * $16);
 HEAPF32[$u>>2] = $17;
 $18 = (($direction) + ($Index3$0<<2)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($12 * $19);
 HEAPF32[$v>>2] = $20;
 $21 = $Index1$0 << 1;
 $22 = $14 | $21;
 STACKTOP = sp;return ($22|0);
}
function __ZN5physx11localSearchERjRKNS_6PxVec3EPS2_PKNS_2Gu16BigConvexRawDataE($id,$dir,$verts,$val) {
 $id = $id|0;
 $dir = $dir|0;
 $verts = $verts|0;
 $val = $val|0;
 var $$in = 0, $$in13 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $MaxVal$0 = Math_fround(0), $MaxVal$1$ph11 = Math_fround(0);
 var $MaxVal$1$ph8 = Math_fround(0), $NextVtx$1$ph10 = 0, $NextVtx$1$ph6 = 0, $Run$0$ph9 = 0, $Run$04 = 0, $visited = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $visited = sp;
 ;HEAP32[$visited+0>>2]=0|0;HEAP32[$visited+4>>2]=0|0;HEAP32[$visited+8>>2]=0|0;HEAP32[$visited+12>>2]=0|0;HEAP32[$visited+16>>2]=0|0;HEAP32[$visited+20>>2]=0|0;HEAP32[$visited+24>>2]=0|0;HEAP32[$visited+28>>2]=0|0;
 $0 = (($val) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($val) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$id>>2]|0;
 $5 = Math_fround(HEAPF32[$dir>>2]);
 $6 = (($verts) + (($4*12)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = (($dir) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = ((($verts) + (($4*12)|0)|0) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($dir) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = ((($verts) + (($4*12)|0)|0) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 + $19);
 $22 = $4;$MaxVal$0 = $20;
 while(1) {
  $21 = (($1) + ($22<<2)|0);
  $23 = HEAP16[$21>>1]|0;
  $24 = ((($1) + ($22<<2)|0) + 2|0);
  $25 = HEAP16[$24>>1]|0;
  HEAP32[$id>>2] = $22;
  $26 = ($23<<16>>16)==(0);
  if ($26) {
   label = 10;
   break;
  }
  $27 = $25&65535;
  $28 = (($3) + ($27)|0);
  $$in = $23;$MaxVal$1$ph11 = $MaxVal$0;$NextVtx$1$ph10 = $22;$Run$0$ph9 = $28;
  L4: while(1) {
   $$in13 = $$in;$Run$04 = $Run$0$ph9;
   while(1) {
    $29 = (($$in13) + -1)<<16>>16;
    $30 = (($Run$04) + 1|0);
    $31 = HEAP8[$Run$04>>0]|0;
    $32 = $31&255;
    $33 = $32 >>> 5;
    $34 = (($visited) + ($33<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $32 & 31;
    $37 = 1 << $36;
    $38 = $37 & $35;
    $39 = ($38|0)==(0);
    if ($39) {
     $40 = $37 | $35;
     HEAP32[$34>>2] = $40;
     $41 = (($verts) + (($32*12)|0)|0);
     $42 = Math_fround(HEAPF32[$41>>2]);
     $43 = Math_fround($5 * $42);
     $44 = ((($verts) + (($32*12)|0)|0) + 4|0);
     $45 = Math_fround(HEAPF32[$44>>2]);
     $46 = Math_fround($10 * $45);
     $47 = Math_fround($43 + $46);
     $48 = ((($verts) + (($32*12)|0)|0) + 8|0);
     $49 = Math_fround(HEAPF32[$48>>2]);
     $50 = Math_fround($16 * $49);
     $51 = Math_fround($47 + $50);
     $52 = $51 > $MaxVal$1$ph11;
     if ($52) {
      break;
     }
    }
    $53 = ($29<<16>>16)==(0);
    if ($53) {
     $MaxVal$1$ph8 = $MaxVal$1$ph11;$NextVtx$1$ph6 = $NextVtx$1$ph10;
     break L4;
    } else {
     $$in13 = $29;$Run$04 = $30;
    }
   }
   $54 = ($29<<16>>16)==(0);
   if ($54) {
    $MaxVal$1$ph8 = $51;$NextVtx$1$ph6 = $32;
    break;
   } else {
    $$in = $29;$MaxVal$1$ph11 = $51;$NextVtx$1$ph10 = $32;$Run$0$ph9 = $30;
   }
  }
  $55 = ($NextVtx$1$ph6|0)==($22|0);
  if ($55) {
   label = 10;
   break;
  } else {
   $22 = $NextVtx$1$ph6;$MaxVal$0 = $MaxVal$1$ph8;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu23getPolygonalData_ConvexEPNS0_13PolygonalDataEPKNS0_14ConvexHullDataERKNS_2Cm23FastVertex2ShapeScalingE($dst,$src,$scaling) {
 $dst = $dst|0;
 $src = $src|0;
 $scaling = $scaling|0;
 var $$sum1$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0);
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = Math_fround(0), $_ZL28HullProjectionCB_SmallConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_$_ZL26HullProjectionCB_BigConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_ = 0, $tmp2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($src) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$scaling>>2]);
 $3 = Math_fround($1 * $2);
 $4 = (($scaling) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($1 * $5);
 $7 = (($scaling) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($1 * $8);
 $10 = (($src) + 28|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($scaling) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 * $13);
 $15 = (($scaling) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($11 * $16);
 $18 = (($scaling) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($11 * $19);
 $21 = Math_fround($3 + $14);
 $22 = Math_fround($6 + $17);
 $23 = Math_fround($9 + $20);
 $24 = (($src) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($scaling) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 * $27);
 $29 = (($scaling) + 28|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($25 * $30);
 $32 = (($scaling) + 32|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($25 * $33);
 $35 = Math_fround($21 + $28);
 $36 = Math_fround($22 + $31);
 $37 = Math_fround($23 + $34);
 HEAPF32[$dst>>2] = $35;
 $38 = (($dst) + 4|0);
 HEAPF32[$38>>2] = $36;
 $39 = (($dst) + 8|0);
 HEAPF32[$39>>2] = $37;
 $40 = (($src) + 38|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41&255;
 $43 = (($dst) + 12|0);
 HEAP32[$43>>2] = $42;
 $44 = (($src) + 39|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = $45&255;
 $47 = (($dst) + 16|0);
 HEAP32[$47>>2] = $46;
 $48 = (($src) + 36|0);
 $49 = HEAP16[$48>>1]|0;
 $50 = $49&65535;
 $51 = (($dst) + 20|0);
 HEAP32[$51>>2] = $50;
 $52 = (($src) + 40|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($dst) + 24|0);
 HEAP32[$54>>2] = $53;
 $55 = HEAP32[$52>>2]|0;
 $56 = HEAP8[$44>>0]|0;
 $57 = $56&255;
 $58 = (($55) + (($57*20)|0)|0);
 $59 = (($dst) + 28|0);
 HEAP32[$59>>2] = $58;
 $60 = HEAP32[$52>>2]|0;
 $61 = HEAP8[$44>>0]|0;
 $62 = $61&255;
 $63 = (($60) + (($62*20)|0)|0);
 $64 = HEAP8[$40>>0]|0;
 $65 = $64&255;
 $66 = $50 << 1;
 $tmp2$i = ($65*15)|0;
 $$sum1$i = (($66) + ($tmp2$i))|0;
 $67 = (($63) + ($$sum1$i)|0);
 $68 = (($dst) + 32|0);
 HEAP32[$68>>2] = $67;
 $69 = HEAP32[$52>>2]|0;
 $70 = HEAP8[$44>>0]|0;
 $71 = $70&255;
 $72 = (($69) + (($71*20)|0)|0);
 $73 = HEAP8[$40>>0]|0;
 $74 = $73&255;
 $75 = ($74*12)|0;
 $76 = (($72) + ($75)|0);
 $77 = (($dst) + 36|0);
 HEAP32[$77>>2] = $76;
 $78 = (($dst) + 40|0);
 $79 = (($src) + 48|0);
 ;HEAP32[$78+0>>2]=HEAP32[$79+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$79+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$79+8>>2]|0;HEAP32[$78+12>>2]=HEAP32[$79+12>>2]|0;
 $80 = (($src) + 44|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($dst) + 56|0);
 HEAP32[$82>>2] = $81;
 $83 = HEAP32[$80>>2]|0;
 $84 = ($83|0)==(0|0);
 $85 = (($dst) + 64|0);
 $_ZL28HullProjectionCB_SmallConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_$_ZL26HullProjectionCB_BigConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_ = $84 ? 94 : 95;
 HEAP32[$85>>2] = $_ZL28HullProjectionCB_SmallConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_$_ZL26HullProjectionCB_BigConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_;
 $86 = (($dst) + 68|0);
 HEAP32[$86>>2] = 1527;
 $87 = (($dst) + 60|0);
 HEAP32[$87>>2] = 2583;
 STACKTOP = sp;return;
}
function __ZL28HullProjectionCB_SmallConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_($data,$dir,$world,$scaling,$min,$max) {
 $data = $data|0;
 $dir = $dir|0;
 $world = $world|0;
 $scaling = $scaling|0;
 $min = $min|0;
 $max = $max|0;
 var $$012$i = 0, $$05$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0);
 var $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $maximum$0$lcssa$i = Math_fround(0), $maximum$04$i = Math_fround(0), $minimum$0$lcssa$i = Math_fround(0), $minimum$03$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$world>>2]);
 $3 = Math_fround(HEAPF32[$dir>>2]);
 $4 = Math_fround($2 * $3);
 $5 = (($world) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = Math_fround($4 + $9);
 $11 = (($world) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($dir) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 * $14);
 $16 = Math_fround($10 + $15);
 $17 = (($world) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($3 * $18);
 $20 = (($world) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($8 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($world) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($world) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($3 * $29);
 $31 = (($world) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($8 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($world) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($14 * $36);
 $38 = Math_fround($34 + $37);
 $39 = Math_fround(HEAPF32[$scaling>>2]);
 $40 = Math_fround($16 * $39);
 $41 = (($scaling) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($16 * $42);
 $44 = (($scaling) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($16 * $45);
 $47 = (($scaling) + 12|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($27 * $48);
 $50 = (($scaling) + 16|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($27 * $51);
 $53 = (($scaling) + 20|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($27 * $54);
 $56 = Math_fround($40 + $49);
 $57 = Math_fround($43 + $52);
 $58 = Math_fround($46 + $55);
 $59 = (($scaling) + 24|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($38 * $60);
 $62 = (($scaling) + 28|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($38 * $63);
 $65 = (($scaling) + 32|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($38 * $66);
 $68 = Math_fround($56 + $61);
 $69 = Math_fround($57 + $64);
 $70 = Math_fround($58 + $67);
 $71 = ($1|0)==(0);
 if ($71) {
  $maximum$0$lcssa$i = Math_fround(-3.40282346638528859812E+38);$minimum$0$lcssa$i = Math_fround(3.40282346638528859812E+38);
 } else {
  $72 = (($data) + 28|0);
  $73 = HEAP32[$72>>2]|0;
  $$012$i = $1;$$05$i = $73;$maximum$04$i = Math_fround(-3.40282346638528859812E+38);$minimum$03$i = Math_fround(3.40282346638528859812E+38);
  while(1) {
   $74 = (($$012$i) + -1)|0;
   $75 = (($$05$i) + 12|0);
   $76 = Math_fround(HEAPF32[$$05$i>>2]);
   $77 = Math_fround($68 * $76);
   $78 = (($$05$i) + 4|0);
   $79 = Math_fround(HEAPF32[$78>>2]);
   $80 = Math_fround($69 * $79);
   $81 = Math_fround($77 + $80);
   $82 = (($$05$i) + 8|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = Math_fround($70 * $83);
   $85 = Math_fround($81 + $84);
   $86 = $minimum$03$i < $85;
   $87 = $86 ? $minimum$03$i : $85;
   $88 = $maximum$04$i > $85;
   $89 = $88 ? $maximum$04$i : $85;
   $90 = ($74|0)==(0);
   if ($90) {
    $maximum$0$lcssa$i = $89;$minimum$0$lcssa$i = $87;
    break;
   } else {
    $$012$i = $74;$$05$i = $75;$maximum$04$i = $89;$minimum$03$i = $87;
   }
  }
 }
 HEAPF32[$min>>2] = $minimum$0$lcssa$i;
 HEAPF32[$max>>2] = $maximum$0$lcssa$i;
 $91 = (($world) + 36|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround(HEAPF32[$dir>>2]);
 $94 = Math_fround($92 * $93);
 $95 = (($world) + 40|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround(HEAPF32[$7>>2]);
 $98 = Math_fround($96 * $97);
 $99 = Math_fround($94 + $98);
 $100 = (($world) + 44|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround(HEAPF32[$13>>2]);
 $103 = Math_fround($101 * $102);
 $104 = Math_fround($99 + $103);
 $105 = Math_fround(HEAPF32[$min>>2]);
 $106 = Math_fround($105 + $104);
 HEAPF32[$min>>2] = $106;
 $107 = Math_fround(HEAPF32[$max>>2]);
 $108 = Math_fround($107 + $104);
 HEAPF32[$max>>2] = $108;
 STACKTOP = sp;return;
}
function __ZL26HullProjectionCB_BigConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_($data,$dir,$world,$scaling,$minimum,$maximum) {
 $data = $data|0;
 $dir = $dir|0;
 $world = $world|0;
 $scaling = $scaling|0;
 $minimum = $minimum|0;
 $maximum = $maximum|0;
 var $$$i = Math_fround(0), $$1$i = 0, $$pn$i = Math_fround(0), $$sum = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $19 = 0, $2 = 0;
 var $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $coeff$0$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $index$0$i = 0, $maxID = 0, $minID = 0, $or$cond$i = 0, $tmp$i = 0, $tmp4$i = 0, $ui$0$i = 0, $vertexSpaceDirection = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vertexSpaceDirection = sp + 32|0;
 $minID = sp;
 $maxID = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 20|0;
 $2 = (($data) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$world>>2]);
 $5 = Math_fround(HEAPF32[$dir>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($world) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($dir) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = Math_fround($6 + $11);
 $13 = (($world) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($dir) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = Math_fround($12 + $17);
 $19 = (($world) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($5 * $20);
 $22 = (($world) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($10 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($world) + 20|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($16 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($world) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($5 * $31);
 $33 = (($world) + 28|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($10 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($world) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($16 * $38);
 $40 = Math_fround($36 + $39);
 $41 = Math_fround(HEAPF32[$scaling>>2]);
 $42 = Math_fround($18 * $41);
 $43 = (($scaling) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($18 * $44);
 $46 = (($scaling) + 8|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($18 * $47);
 $49 = (($scaling) + 12|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($29 * $50);
 $52 = (($scaling) + 16|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($29 * $53);
 $55 = (($scaling) + 20|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($29 * $56);
 $58 = Math_fround($42 + $51);
 $59 = Math_fround($45 + $54);
 $60 = Math_fround($48 + $57);
 $61 = (($scaling) + 24|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($40 * $62);
 $64 = (($scaling) + 28|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($40 * $65);
 $67 = (($scaling) + 32|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($40 * $68);
 $70 = Math_fround($58 + $63);
 $71 = Math_fround($59 + $66);
 $72 = Math_fround($60 + $69);
 HEAPF32[$vertexSpaceDirection>>2] = $70;
 $73 = (($vertexSpaceDirection) + 4|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($vertexSpaceDirection) + 8|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($data) + 56|0);
 $76 = HEAP32[$75>>2]|0;
 HEAP32[$minID>>2] = 0;
 HEAP32[$maxID>>2] = 0;
 $77 = HEAP16[$76>>1]|0;
 $78 = $77&65535;
 $79 = Math_fround(-$70);
 $80 = Math_fround(-$71);
 $81 = Math_fround(-$72);
 HEAPF32[$0>>2] = $79;
 $82 = (($0) + 4|0);
 HEAPF32[$82>>2] = $80;
 $83 = (($0) + 8|0);
 HEAPF32[$83>>2] = $81;
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($79)))));
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($80)))));
 $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($81)))));
 $84 = $fabsf$i$i2$i > $fabsf$i$i$i;
 $85 = $fabsf$i$i2$i > $fabsf$i$i3$i;
 $or$cond$i = $84 & $85;
 if ($or$cond$i) {
  $$pn$i = $fabsf$i$i2$i;$index$0$i = 1;
 } else {
  $86 = $fabsf$i$i3$i > $fabsf$i$i$i;
  $$$i = $86 ? $fabsf$i$i3$i : $fabsf$i$i$i;
  $$1$i = $86 ? 2 : 0;
  $$pn$i = $$$i;$index$0$i = $$1$i;
 }
 $coeff$0$i = Math_fround(Math_fround(1.0) / $$pn$i);
 $87 = (($0) + ($index$0$i<<2)|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (HEAPF32[tempDoublePtr>>2]=$88,HEAP32[tempDoublePtr>>2]|0);
 $90 = $89 >>> 31;
 $91 = (($index$0$i) + 1)|0;
 $92 = $index$0$i >>> 1;
 $93 = (($91) + ($92))|0;
 $94 = $93 & 3;
 $95 = (($93) + 1)|0;
 $96 = $94 >>> 1;
 $97 = (($95) + ($96))|0;
 $98 = $97 & 3;
 $99 = (($0) + ($94<<2)|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($coeff$0$i * $100);
 $102 = (($0) + ($98<<2)|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($coeff$0$i * $103);
 $105 = $index$0$i << 1;
 $106 = $90 | $105;
 $107 = (($78) + -1)|0;
 $108 = (Math_fround(($107>>>0)));
 $109 = Math_fround($108 * Math_fround(0.5));
 $110 = Math_fround($101 + Math_fround(1.0));
 $111 = Math_fround($109 * $110);
 $112 = Math_fround($104 + Math_fround(1.0));
 $113 = Math_fround($109 * $112);
 $114 = (~~(($111))>>>0);
 $115 = (~~(($113))>>>0);
 $116 = (Math_fround(($114>>>0)));
 $117 = Math_fround($111 - $116);
 $118 = (Math_fround(($115>>>0)));
 $119 = Math_fround($113 - $118);
 $120 = $117 > Math_fround(0.5);
 $121 = $120&1;
 $122 = $119 > Math_fround(0.5);
 $123 = $122&1;
 $124 = Math_imul($106, $78)|0;
 $ui$0$i = (($114) + ($124))|0;
 $tmp$i = (($ui$0$i) + ($121))|0;
 $tmp4$i = Math_imul($tmp$i, $78)|0;
 $125 = (($123) + ($115))|0;
 $126 = (($125) + ($tmp4$i))|0;
 $127 = (($76) + 4|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = (($128) + ($126)|0);
 $130 = HEAP8[$129>>0]|0;
 $131 = $130&255;
 HEAP32[$minID>>2] = $131;
 $132 = (($76) + 2|0);
 $133 = HEAP16[$132>>1]|0;
 $134 = $133&65535;
 $$sum = (($126) + ($134))|0;
 $135 = (($128) + ($$sum)|0);
 $136 = HEAP8[$135>>0]|0;
 $137 = $136&255;
 HEAP32[$maxID>>2] = $137;
 HEAPF32[$1>>2] = $79;
 $138 = (($1) + 4|0);
 HEAPF32[$138>>2] = $80;
 $139 = (($1) + 8|0);
 HEAPF32[$139>>2] = $81;
 __ZN5physx11localSearchERjRKNS_6PxVec3EPS2_PKNS_2Gu16BigConvexRawDataE($minID,$1,$3,$76);
 __ZN5physx11localSearchERjRKNS_6PxVec3EPS2_PKNS_2Gu16BigConvexRawDataE($maxID,$vertexSpaceDirection,$3,$76);
 $140 = (($world) + 36|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = Math_fround(HEAPF32[$dir>>2]);
 $143 = Math_fround($141 * $142);
 $144 = (($world) + 40|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround(HEAPF32[$9>>2]);
 $147 = Math_fround($145 * $146);
 $148 = Math_fround($143 + $147);
 $149 = (($world) + 44|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = Math_fround(HEAPF32[$15>>2]);
 $152 = Math_fround($150 * $151);
 $153 = Math_fround($148 + $152);
 $154 = HEAP32[$minID>>2]|0;
 $155 = (($3) + (($154*12)|0)|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = Math_fround(HEAPF32[$vertexSpaceDirection>>2]);
 $158 = Math_fround($156 * $157);
 $159 = ((($3) + (($154*12)|0)|0) + 4|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = Math_fround(HEAPF32[$73>>2]);
 $162 = Math_fround($160 * $161);
 $163 = Math_fround($158 + $162);
 $164 = ((($3) + (($154*12)|0)|0) + 8|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = Math_fround(HEAPF32[$74>>2]);
 $167 = Math_fround($165 * $166);
 $168 = Math_fround($163 + $167);
 $169 = Math_fround($153 + $168);
 HEAPF32[$minimum>>2] = $169;
 $170 = HEAP32[$maxID>>2]|0;
 $171 = (($3) + (($170*12)|0)|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = Math_fround($172 * $157);
 $174 = ((($3) + (($170*12)|0)|0) + 4|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = Math_fround($175 * $161);
 $177 = Math_fround($173 + $176);
 $178 = ((($3) + (($170*12)|0)|0) + 8|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround($179 * $166);
 $181 = Math_fround($177 + $180);
 $182 = Math_fround($153 + $181);
 HEAPF32[$maximum>>2] = $182;
 STACKTOP = sp;return;
}
function __ZL26SelectClosestEdgeCB_ConvexRKN5physx2Gu13PolygonalDataERKNS_2Cm23FastVertex2ShapeScalingERKNS_6PxVec3E($data,$scaling,$localSpaceDirection) {
 $data = $data|0;
 $scaling = $scaling|0;
 $localSpaceDirection = $localSpaceDirection|0;
 var $$ = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $closest$0 = 0, $closest$0$lcssa$i = 0, $closest$01$i = 0, $closest$1$i = 0, $closestEdge$03 = 0, $closestEdge$1 = 0, $exitcond = 0, $exitcond$i = 0, $i$01 = 0, $i$02$i = 0, $maxDp$0$lcssa$i = Math_fround(0), $maxDp$03$i = Math_fround(0), $maxDp$1$i = Math_fround(0), $maxDpSq$02 = Math_fround(0), $maxDpSq$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$localSpaceDirection>>2]);
 $1 = Math_fround(HEAPF32[$scaling>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($scaling) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($0 * $4);
 $6 = (($scaling) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($0 * $7);
 $9 = (($localSpaceDirection) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($scaling) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = (($scaling) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($10 * $15);
 $17 = (($scaling) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($10 * $18);
 $20 = Math_fround($2 + $13);
 $21 = Math_fround($5 + $16);
 $22 = Math_fround($8 + $19);
 $23 = (($localSpaceDirection) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($scaling) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($24 * $26);
 $28 = (($scaling) + 28|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($24 * $29);
 $31 = (($scaling) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 * $32);
 $34 = Math_fround($20 + $27);
 $35 = Math_fround($21 + $30);
 $36 = Math_fround($22 + $33);
 $37 = (($data) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($data) + 16|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = Math_fround(HEAPF32[$38>>2]);
 $42 = Math_fround($34 * $41);
 $43 = (($38) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($35 * $44);
 $46 = Math_fround($42 + $45);
 $47 = (($38) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($36 * $48);
 $50 = Math_fround($46 + $49);
 $51 = ($40>>>0)>(1);
 if ($51) {
  $closest$01$i = 0;$i$02$i = 1;$maxDp$03$i = $50;
  while(1) {
   $52 = (($38) + (($i$02$i*20)|0)|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = Math_fround($34 * $53);
   $55 = ((($38) + (($i$02$i*20)|0)|0) + 4|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = Math_fround($35 * $56);
   $58 = Math_fround($54 + $57);
   $59 = ((($38) + (($i$02$i*20)|0)|0) + 8|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround($36 * $60);
   $62 = Math_fround($58 + $61);
   $63 = $62 > $maxDp$03$i;
   $closest$1$i = $63 ? $i$02$i : $closest$01$i;
   $maxDp$1$i = $63 ? $62 : $maxDp$03$i;
   $64 = (($i$02$i) + 1)|0;
   $exitcond$i = ($64|0)==($40|0);
   if ($exitcond$i) {
    $closest$0$lcssa$i = $closest$1$i;$maxDp$0$lcssa$i = $maxDp$1$i;
    break;
   } else {
    $closest$01$i = $closest$1$i;$i$02$i = $64;$maxDp$03$i = $maxDp$1$i;
   }
  }
 } else {
  $closest$0$lcssa$i = 0;$maxDp$0$lcssa$i = $50;
 }
 $65 = (($data) + 20|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($data) + 36|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($66|0)==(0);
 if ($69) {
  $closest$0 = $closest$0$lcssa$i;
  STACKTOP = sp;return ($closest$0|0);
 }
 $70 = Math_fround($maxDp$0$lcssa$i * $maxDp$0$lcssa$i);
 $closestEdge$03 = -1;$i$01 = 0;$maxDpSq$02 = $70;
 while(1) {
  $71 = $i$01 << 1;
  $72 = (($68) + ($71)|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = $71 | 1;
  $75 = (($68) + ($74)|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $73&255;
  $78 = $76&255;
  $79 = (($38) + (($77*20)|0)|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (($38) + (($78*20)|0)|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($80 + $82);
  $84 = ((($38) + (($77*20)|0)|0) + 4|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = ((($38) + (($78*20)|0)|0) + 4|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = Math_fround($85 + $87);
  $89 = ((($38) + (($77*20)|0)|0) + 8|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = ((($38) + (($78*20)|0)|0) + 8|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = Math_fround($90 + $92);
  $94 = Math_fround($83 * $83);
  $95 = Math_fround($88 * $88);
  $96 = Math_fround($94 + $95);
  $97 = Math_fround($93 * $93);
  $98 = Math_fround($96 + $97);
  $99 = Math_fround($34 * $83);
  $100 = Math_fround($35 * $88);
  $101 = Math_fround($99 + $100);
  $102 = Math_fround($36 * $93);
  $103 = Math_fround($101 + $102);
  $104 = !($103 >= Math_fround(0.0));
  if ($104) {
   $closestEdge$1 = $closestEdge$03;$maxDpSq$1 = $maxDpSq$02;
  } else {
   $105 = Math_fround($103 * $103);
   $106 = Math_fround($maxDpSq$02 * $98);
   $107 = $105 > $106;
   if ($107) {
    $108 = Math_fround($105 / $98);
    $closestEdge$1 = $i$01;$maxDpSq$1 = $108;
   } else {
    $closestEdge$1 = $closestEdge$03;$maxDpSq$1 = $maxDpSq$02;
   }
  }
  $109 = (($i$01) + 1)|0;
  $exitcond = ($109|0)==($66|0);
  if ($exitcond) {
   break;
  } else {
   $closestEdge$03 = $closestEdge$1;$i$01 = $109;$maxDpSq$02 = $maxDpSq$1;
  }
 }
 $110 = ($closestEdge$1|0)==(-1);
 if ($110) {
  $closest$0 = $closest$0$lcssa$i;
  STACKTOP = sp;return ($closest$0|0);
 }
 $111 = $closestEdge$1 << 1;
 $112 = (($68) + ($111)|0);
 $113 = HEAP8[$112>>0]|0;
 $114 = $113&255;
 $115 = $111 | 1;
 $116 = (($68) + ($115)|0);
 $117 = HEAP8[$116>>0]|0;
 $118 = $117&255;
 $119 = (($38) + (($114*20)|0)|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($34 * $120);
 $122 = ((($38) + (($114*20)|0)|0) + 4|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($35 * $123);
 $125 = Math_fround($121 + $124);
 $126 = ((($38) + (($114*20)|0)|0) + 8|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = Math_fround($36 * $127);
 $129 = Math_fround($125 + $128);
 $130 = (($38) + (($118*20)|0)|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($34 * $131);
 $133 = ((($38) + (($118*20)|0)|0) + 4|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($35 * $134);
 $136 = Math_fround($132 + $135);
 $137 = ((($38) + (($118*20)|0)|0) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($36 * $138);
 $140 = Math_fround($136 + $139);
 $141 = $129 > $140;
 $$ = $141 ? $114 : $118;
 $closest$0 = $$;
 STACKTOP = sp;return ($closest$0|0);
}
function __ZL15gHullPrefetchCBjPKN5physx6PxVec3E($numVerts,$verts) {
 $numVerts = $numVerts|0;
 $verts = $verts|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12PolygonalBoxC2ERKNS_6PxVec3E($this,$halfSide) {
 $this = $this|0;
 $halfSide = $halfSide|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $halfSide;
 $0 = Math_fround(HEAPF32[$halfSide>>2]);
 $1 = Math_fround(-$0);
 $2 = (($halfSide) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(-$3);
 $5 = (($halfSide) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 $8 = (($this) + 4|0);
 HEAPF32[$8>>2] = $1;
 $9 = (($this) + 8|0);
 HEAPF32[$9>>2] = $4;
 $10 = (($this) + 12|0);
 HEAPF32[$10>>2] = $7;
 $11 = (($this) + 16|0);
 HEAPF32[$11>>2] = $0;
 $12 = (($this) + 20|0);
 HEAPF32[$12>>2] = $4;
 $13 = (($this) + 24|0);
 HEAPF32[$13>>2] = $7;
 $14 = (($this) + 28|0);
 HEAPF32[$14>>2] = $0;
 $15 = (($this) + 32|0);
 HEAPF32[$15>>2] = $3;
 $16 = (($this) + 36|0);
 HEAPF32[$16>>2] = $7;
 $17 = (($this) + 40|0);
 HEAPF32[$17>>2] = $1;
 $18 = (($this) + 44|0);
 HEAPF32[$18>>2] = $3;
 $19 = (($this) + 48|0);
 HEAPF32[$19>>2] = $7;
 $20 = (($this) + 52|0);
 HEAPF32[$20>>2] = $1;
 $21 = (($this) + 56|0);
 HEAPF32[$21>>2] = $4;
 $22 = (($this) + 60|0);
 HEAPF32[$22>>2] = $6;
 $23 = (($this) + 64|0);
 HEAPF32[$23>>2] = $0;
 $24 = (($this) + 68|0);
 HEAPF32[$24>>2] = $4;
 $25 = (($this) + 72|0);
 HEAPF32[$25>>2] = $6;
 $26 = (($this) + 76|0);
 HEAPF32[$26>>2] = $0;
 $27 = (($this) + 80|0);
 HEAPF32[$27>>2] = $3;
 $28 = (($this) + 84|0);
 HEAPF32[$28>>2] = $6;
 $29 = (($this) + 88|0);
 HEAPF32[$29>>2] = $1;
 $30 = (($this) + 92|0);
 HEAPF32[$30>>2] = $3;
 $31 = (($this) + 96|0);
 HEAPF32[$31>>2] = $6;
 $32 = (($this) + 118|0);
 HEAP8[$32>>0] = 4;
 $33 = (($this) + 116|0);
 HEAP16[$33>>1] = 0;
 $34 = (($this) + 138|0);
 HEAP8[$34>>0] = 4;
 $35 = (($this) + 136|0);
 HEAP16[$35>>1] = 4;
 $36 = (($this) + 158|0);
 HEAP8[$36>>0] = 4;
 $37 = (($this) + 156|0);
 HEAP16[$37>>1] = 8;
 $38 = (($this) + 178|0);
 HEAP8[$38>>0] = 4;
 $39 = (($this) + 176|0);
 HEAP16[$39>>1] = 12;
 $40 = (($this) + 198|0);
 HEAP8[$40>>0] = 4;
 $41 = (($this) + 196|0);
 HEAP16[$41>>1] = 16;
 $42 = (($this) + 218|0);
 HEAP8[$42>>0] = 4;
 $43 = (($this) + 216|0);
 HEAP16[$43>>1] = 20;
 $44 = (($this) + 120|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 $45 = (($this) + 124|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($this) + 128|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = Math_fround(HEAPF32[$halfSide>>2]);
 $48 = Math_fround(-$47);
 $49 = (($this) + 132|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($this) + 160|0);
 HEAPF32[$50>>2] = Math_fround(-1.0);
 $51 = (($this) + 164|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($this) + 168|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = HEAP32[$this>>2]|0;
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround(-$54);
 $56 = (($this) + 172|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($this) + 139|0);
 HEAP8[$57>>0] = 0;
 $58 = (($this) + 179|0);
 HEAP8[$58>>0] = 1;
 $59 = (($this) + 180|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($this) + 184|0);
 HEAPF32[$60>>2] = Math_fround(1.0);
 $61 = (($this) + 188|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (($53) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(-$63);
 $65 = (($this) + 192|0);
 HEAPF32[$65>>2] = $64;
 $66 = (($this) + 200|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($this) + 204|0);
 HEAPF32[$67>>2] = Math_fround(-1.0);
 $68 = (($this) + 208|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = Math_fround(HEAPF32[$62>>2]);
 $70 = Math_fround(-$69);
 $71 = (($this) + 212|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($this) + 199|0);
 HEAP8[$72>>0] = 0;
 $73 = (($this) + 219|0);
 HEAP8[$73>>0] = 2;
 $74 = (($this) + 140|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($this) + 144|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($this) + 148|0);
 HEAPF32[$76>>2] = Math_fround(1.0);
 $77 = (($53) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround(-$78);
 $80 = (($this) + 152|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($this) + 100|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 $82 = (($this) + 104|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = (($this) + 108|0);
 HEAPF32[$83>>2] = Math_fround(-1.0);
 $84 = Math_fround(HEAPF32[$77>>2]);
 $85 = Math_fround(-$84);
 $86 = (($this) + 112|0);
 HEAPF32[$86>>2] = $85;
 $87 = (($this) + 159|0);
 HEAP8[$87>>0] = 0;
 $88 = (($this) + 119|0);
 HEAP8[$88>>0] = 4;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu12PolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($this,$dst) {
 $this = $this|0;
 $dst = $dst|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$dst>>2] = Math_fround(0.0);
 $0 = (($dst) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($dst) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($dst) + 12|0);
 HEAP32[$2>>2] = 8;
 $3 = (($dst) + 16|0);
 HEAP32[$3>>2] = 6;
 $4 = (($this) + 100|0);
 $5 = (($dst) + 24|0);
 HEAP32[$5>>2] = $4;
 $6 = (($dst) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 4|0);
 $8 = (($dst) + 28|0);
 HEAP32[$8>>2] = $7;
 $9 = (($dst) + 32|0);
 HEAP32[$9>>2] = 549936;
 $10 = (($dst) + 36|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = (($dst) + 56|0);
 HEAP32[$12>>2] = $11;
 $13 = (($dst) + 64|0);
 HEAP32[$13>>2] = 96;
 $14 = (($dst) + 68|0);
 HEAP32[$14>>2] = 1528;
 $15 = (($dst) + 60|0);
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZL20HullProjectionCB_BoxRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_($data,$dir,$world,$scaling,$minimum,$maximum) {
 $data = $data|0;
 $dir = $dir|0;
 $world = $world|0;
 $scaling = $scaling|0;
 $minimum = $minimum|0;
 $maximum = $maximum|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$world>>2]);
 $1 = Math_fround(HEAPF32[$dir>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($world) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($world) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($dir) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($world) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($1 * $16);
 $18 = (($world) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($6 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (($world) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($12 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($world) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($1 * $27);
 $29 = (($world) + 28|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($6 * $30);
 $32 = Math_fround($28 + $31);
 $33 = (($world) + 32|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($12 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($data) + 56|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround(-$39);
 $41 = $14 >= Math_fround(0.0);
 $42 = $41 ? $39 : $40;
 $43 = (($38) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround(-$44);
 $46 = $25 >= Math_fround(0.0);
 $47 = $46 ? $44 : $45;
 $48 = (($38) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround(-$49);
 $51 = $36 >= Math_fround(0.0);
 $52 = $51 ? $49 : $50;
 $53 = (($world) + 36|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($1 * $54);
 $56 = (($world) + 40|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($6 * $57);
 $59 = Math_fround($55 + $58);
 $60 = (($world) + 44|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($12 * $61);
 $63 = Math_fround($59 + $62);
 $64 = Math_fround($14 * $42);
 $65 = Math_fround($25 * $47);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($36 * $52);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($68 + $63);
 HEAPF32[$maximum>>2] = $69;
 $70 = Math_fround($63 - $68);
 HEAPF32[$minimum>>2] = $70;
 STACKTOP = sp;return;
}
function __ZL23SelectClosestEdgeCB_BoxRKN5physx2Gu13PolygonalDataERKNS_2Cm23FastVertex2ShapeScalingERKNS_6PxVec3E($data,$scaling,$localDirection) {
 $data = $data|0;
 $scaling = $scaling|0;
 $localDirection = $localDirection|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0;
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $closest$0 = 0, $closest$1$i = 0, $closest$1$i$1 = 0, $closest$1$i$2 = 0, $closest$1$i$3 = 0, $closest$1$i$4 = 0, $closestEdge$05 = 0, $closestEdge$1 = 0, $exitcond = 0, $i$04 = 0, $maxDp$1$i = Math_fround(0), $maxDp$1$i$1 = Math_fround(0), $maxDp$1$i$2 = Math_fround(0), $maxDp$1$i$3 = Math_fround(0), $maxDp$1$i$4 = Math_fround(0), $maxDp$1$i1 = Math_fround(0);
 var $maxDp$1$i23 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(HEAPF32[$localDirection>>2]);
 $4 = Math_fround($2 * $3);
 $5 = (($1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($localDirection) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = Math_fround($4 + $9);
 $11 = (($1) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($localDirection) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 * $14);
 $16 = Math_fround($10 + $15);
 $17 = (($1) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($3 * $18);
 $20 = (($1) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($8 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($1) + 28|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 * $25);
 $27 = Math_fround($23 + $26);
 $28 = $27 > $16;
 $closest$1$i = $28&1;
 $maxDp$1$i = $28 ? $27 : $16;
 $29 = (($1) + 40|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($3 * $30);
 $32 = (($1) + 44|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($8 * $33);
 $35 = Math_fround($31 + $34);
 $36 = (($1) + 48|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($14 * $37);
 $39 = Math_fround($35 + $38);
 $40 = $39 > $maxDp$1$i;
 $closest$1$i$1 = $40 ? 2 : $closest$1$i;
 $maxDp$1$i$1 = $40 ? $39 : $maxDp$1$i;
 $41 = (($1) + 60|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($3 * $42);
 $44 = (($1) + 64|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($8 * $45);
 $47 = Math_fround($43 + $46);
 $48 = (($1) + 68|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($14 * $49);
 $51 = Math_fround($47 + $50);
 $52 = $51 > $maxDp$1$i$1;
 $closest$1$i$2 = $52 ? 3 : $closest$1$i$1;
 $maxDp$1$i$2 = $52 ? $51 : $maxDp$1$i$1;
 $53 = (($1) + 80|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($3 * $54);
 $56 = (($1) + 84|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($8 * $57);
 $59 = Math_fround($55 + $58);
 $60 = (($1) + 88|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($14 * $61);
 $63 = Math_fround($59 + $62);
 $64 = $63 > $maxDp$1$i$2;
 $closest$1$i$3 = $64 ? 4 : $closest$1$i$2;
 $maxDp$1$i$3 = $64 ? $63 : $maxDp$1$i$2;
 $65 = (($1) + 100|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($3 * $66);
 $68 = (($1) + 104|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($8 * $69);
 $71 = Math_fround($67 + $70);
 $72 = (($1) + 108|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($14 * $73);
 $75 = Math_fround($71 + $74);
 $76 = $75 > $maxDp$1$i$3;
 $closest$1$i$4 = $76 ? 5 : $closest$1$i$3;
 $maxDp$1$i$4 = $76 ? $75 : $maxDp$1$i$3;
 $closestEdge$05 = -1;$i$04 = 0;$maxDp$1$i23 = $maxDp$1$i$4;
 while(1) {
  $77 = (549792 + (($i$04*12)|0)|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($78 * $3);
  $80 = ((549792 + (($i$04*12)|0)|0) + 4|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround($81 * $8);
  $83 = Math_fround($79 + $82);
  $84 = ((549792 + (($i$04*12)|0)|0) + 8|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($85 * $14);
  $87 = Math_fround($83 + $86);
  $88 = $87 > $maxDp$1$i23;
  $maxDp$1$i1 = $88 ? $87 : $maxDp$1$i23;
  $closestEdge$1 = $88 ? $i$04 : $closestEdge$05;
  $89 = (($i$04) + 1)|0;
  $exitcond = ($89|0)==(12);
  if ($exitcond) {
   break;
  } else {
   $closestEdge$05 = $closestEdge$1;$i$04 = $89;$maxDp$1$i23 = $maxDp$1$i1;
  }
 }
 $90 = ($closestEdge$1|0)==(-1);
 if ($90) {
  $closest$0 = $closest$1$i$4;
  STACKTOP = sp;return ($closest$0|0);
 }
 $91 = ((549960 + ($closestEdge$1<<3)|0) + 4|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (550056 + ($92)|0);
 $94 = HEAP8[$93>>0]|0;
 $95 = $94&255;
 $96 = (($92) + 1)|0;
 $97 = (550056 + ($96)|0);
 $98 = HEAP8[$97>>0]|0;
 $99 = $98&255;
 $100 = (($1) + (($95*20)|0)|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($101 * $3);
 $103 = ((($1) + (($95*20)|0)|0) + 4|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($104 * $8);
 $106 = Math_fround($102 + $105);
 $107 = ((($1) + (($95*20)|0)|0) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($108 * $14);
 $110 = Math_fround($106 + $109);
 $111 = (($1) + (($99*20)|0)|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($3 * $112);
 $114 = ((($1) + (($99*20)|0)|0) + 4|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($8 * $115);
 $117 = Math_fround($113 + $116);
 $118 = ((($1) + (($99*20)|0)|0) + 8|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($14 * $119);
 $121 = Math_fround($117 + $120);
 $122 = $110 > $121;
 $$ = $122 ? $95 : $99;
 $closest$0 = $$;
 STACKTOP = sp;return ($closest$0|0);
}
function __ZN5physx2Gu23distancePointBoxSquaredERKNS_6PxVec3ES3_S3_RKNS_7PxMat33EPS1_($point,$boxOrigin,$boxExtent,$boxBase,$boxParam) {
 $point = $point|0;
 $boxOrigin = $boxOrigin|0;
 $boxExtent = $boxExtent|0;
 $boxBase = $boxBase|0;
 $boxParam = $boxParam|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $9 = Math_fround(0), $sqrDistance$1 = Math_fround(0), $sqrDistance$1$1 = Math_fround(0), $sqrDistance$1$2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$point>>2]);
 $1 = Math_fround(HEAPF32[$boxOrigin>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($point) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($boxOrigin) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($point) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($boxOrigin) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$boxBase>>2]);
 $14 = Math_fround($2 * $13);
 $15 = (($boxBase) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($boxBase) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($12 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($boxBase) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($2 * $24);
 $26 = (($boxBase) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($7 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($boxBase) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($12 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($boxBase) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($2 * $35);
 $37 = (($boxBase) + 28|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($7 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($boxBase) + 32|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($12 * $42);
 $44 = Math_fround($40 + $43);
 $45 = Math_fround(HEAPF32[$boxExtent>>2]);
 $46 = Math_fround(-$45);
 $47 = $22 < $46;
 if ($47) {
  $48 = Math_fround($22 + $45);
  $49 = Math_fround($48 * $48);
  $50 = Math_fround($49 + Math_fround(0.0));
  $59 = $46;$sqrDistance$1 = $50;
 } else {
  $51 = $22 > $45;
  if ($51) {
   $52 = Math_fround($22 - $45);
   $53 = Math_fround($52 * $52);
   $54 = Math_fround($53 + Math_fround(0.0));
   $59 = $45;$sqrDistance$1 = $54;
  } else {
   $59 = $22;$sqrDistance$1 = Math_fround(0.0);
  }
 }
 $55 = (($boxExtent) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround(-$56);
 $58 = $33 < $57;
 if ($58) {
  $68 = Math_fround($33 + $56);
  $69 = Math_fround($68 * $68);
  $70 = Math_fround($sqrDistance$1 + $69);
  $61 = $57;$sqrDistance$1$1 = $70;
 } else {
  $64 = $33 > $56;
  if ($64) {
   $65 = Math_fround($33 - $56);
   $66 = Math_fround($65 * $65);
   $67 = Math_fround($sqrDistance$1 + $66);
   $61 = $56;$sqrDistance$1$1 = $67;
  } else {
   $61 = $33;$sqrDistance$1$1 = $sqrDistance$1;
  }
 }
 $71 = (($boxExtent) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround(-$72);
 $74 = $44 < $73;
 if ($74) {
  $79 = Math_fround($44 + $72);
  $80 = Math_fround($79 * $79);
  $81 = Math_fround($sqrDistance$1$1 + $80);
  $63 = $73;$sqrDistance$1$2 = $81;
 } else {
  $75 = $44 > $72;
  if ($75) {
   $76 = Math_fround($44 - $72);
   $77 = Math_fround($76 * $76);
   $78 = Math_fround($sqrDistance$1$1 + $77);
   $63 = $72;$sqrDistance$1$2 = $78;
  } else {
   $63 = $44;$sqrDistance$1$2 = $sqrDistance$1$1;
  }
 }
 $82 = ($boxParam|0)==(0|0);
 if ($82) {
  STACKTOP = sp;return (Math_fround($sqrDistance$1$2));
 }
 HEAPF32[$boxParam>>2] = $59;
 $60 = (($boxParam) + 4|0);
 HEAPF32[$60>>2] = $61;
 $62 = (($boxParam) + 8|0);
 HEAPF32[$62>>2] = $63;
 STACKTOP = sp;return (Math_fround($sqrDistance$1$2));
}
function __ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($p0,$p1,$point,$param) {
 $p0 = $p0|0;
 $p1 = $p1|0;
 $point = $point|0;
 $param = $param|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $fT$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$point>>2]);
 $1 = Math_fround(HEAPF32[$p0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($point) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($p0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($point) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($p0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$p1>>2]);
 $14 = Math_fround($13 - $1);
 $15 = (($p1) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 - $6);
 $18 = (($p1) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 - $11);
 $21 = Math_fround($2 * $14);
 $22 = Math_fround($7 * $17);
 $23 = Math_fround($21 + $22);
 $24 = Math_fround($12 * $20);
 $25 = Math_fround($23 + $24);
 $26 = !($25 <= Math_fround(0.0));
 do {
  if ($26) {
   $27 = Math_fround($14 * $14);
   $28 = Math_fround($17 * $17);
   $29 = Math_fround($27 + $28);
   $30 = Math_fround($20 * $20);
   $31 = Math_fround($29 + $30);
   $32 = !($25 >= $31);
   if ($32) {
    $36 = Math_fround($25 / $31);
    $37 = Math_fround($14 * $36);
    $38 = Math_fround($17 * $36);
    $39 = Math_fround($20 * $36);
    $40 = Math_fround($2 - $37);
    $41 = Math_fround($7 - $38);
    $42 = Math_fround($12 - $39);
    $45 = $40;$47 = $41;$50 = $42;$fT$0 = $36;
    break;
   } else {
    $33 = Math_fround($2 - $14);
    $34 = Math_fround($7 - $17);
    $35 = Math_fround($12 - $20);
    $45 = $33;$47 = $34;$50 = $35;$fT$0 = Math_fround(1.0);
    break;
   }
  } else {
   $45 = $2;$47 = $7;$50 = $12;$fT$0 = Math_fround(0.0);
  }
 } while(0);
 $43 = ($param|0)==(0|0);
 if ($43) {
  $44 = Math_fround($45 * $45);
  $46 = Math_fround($47 * $47);
  $48 = Math_fround($46 + $44);
  $49 = Math_fround($50 * $50);
  $51 = Math_fround($49 + $48);
  STACKTOP = sp;return (Math_fround($51));
 }
 HEAPF32[$param>>2] = $fT$0;
 $44 = Math_fround($45 * $45);
 $46 = Math_fround($47 * $47);
 $48 = Math_fround($46 + $44);
 $49 = Math_fround($50 * $50);
 $51 = Math_fround($49 + $48);
 STACKTOP = sp;return (Math_fround($51));
}
function __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($agg$result,$p,$a,$b,$c,$s,$t) {
 $agg$result = $agg$result|0;
 $p = $p|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $s = $s|0;
 $t = $t|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0);
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0;
 var $or$cond6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = Math_fround(HEAPF32[$a>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($b) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($a) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($b) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($a) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$c>>2]);
 $14 = Math_fround($13 - $1);
 $15 = (($c) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 - $6);
 $18 = (($c) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 - $11);
 $21 = Math_fround(HEAPF32[$p>>2]);
 $22 = Math_fround($21 - $1);
 $23 = (($p) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 - $6);
 $26 = (($p) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 - $11);
 $29 = Math_fround($2 * $22);
 $30 = Math_fround($7 * $25);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($12 * $28);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround($14 * $22);
 $35 = Math_fround($17 * $25);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($20 * $28);
 $38 = Math_fround($36 + $37);
 $39 = !($33 <= Math_fround(0.0));
 $40 = !($38 <= Math_fround(0.0));
 $or$cond = $39 | $40;
 if (!($or$cond)) {
  HEAPF32[$s>>2] = Math_fround(0.0);
  HEAPF32[$t>>2] = Math_fround(0.0);
  $41 = Math_fround(HEAPF32[$a>>2]);
  HEAPF32[$agg$result>>2] = $41;
  $42 = (($agg$result) + 4|0);
  $43 = Math_fround(HEAPF32[$5>>2]);
  HEAPF32[$42>>2] = $43;
  $44 = (($agg$result) + 8|0);
  $45 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$44>>2] = $45;
  STACKTOP = sp;return;
 }
 $46 = Math_fround($21 - $0);
 $47 = Math_fround($24 - $4);
 $48 = Math_fround($27 - $9);
 $49 = Math_fround($2 * $46);
 $50 = Math_fround($7 * $47);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($12 * $48);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($14 * $46);
 $55 = Math_fround($17 * $47);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($20 * $48);
 $58 = Math_fround($56 + $57);
 $59 = !($53 >= Math_fround(0.0));
 $60 = !($58 <= $53);
 $or$cond1 = $59 | $60;
 if (!($or$cond1)) {
  HEAPF32[$s>>2] = Math_fround(1.0);
  HEAPF32[$t>>2] = Math_fround(0.0);
  $61 = Math_fround(HEAPF32[$b>>2]);
  HEAPF32[$agg$result>>2] = $61;
  $62 = (($agg$result) + 4|0);
  $63 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$62>>2] = $63;
  $64 = (($agg$result) + 8|0);
  $65 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$64>>2] = $65;
  STACKTOP = sp;return;
 }
 $66 = Math_fround($33 * $58);
 $67 = Math_fround($53 * $38);
 $68 = Math_fround($66 - $67);
 $69 = !($68 <= Math_fround(0.0));
 $70 = !($33 >= Math_fround(0.0));
 $or$cond2 = $69 | $70;
 $71 = !($53 <= Math_fround(0.0));
 $or$cond3 = $or$cond2 | $71;
 if (!($or$cond3)) {
  $72 = Math_fround($33 - $53);
  $73 = Math_fround($33 / $72);
  HEAPF32[$s>>2] = $73;
  HEAPF32[$t>>2] = Math_fround(0.0);
  $74 = Math_fround($2 * $73);
  $75 = Math_fround($7 * $73);
  $76 = Math_fround($12 * $73);
  $77 = Math_fround(HEAPF32[$a>>2]);
  $78 = Math_fround($77 + $74);
  $79 = Math_fround(HEAPF32[$5>>2]);
  $80 = Math_fround($75 + $79);
  $81 = Math_fround(HEAPF32[$10>>2]);
  $82 = Math_fround($76 + $81);
  HEAPF32[$agg$result>>2] = $78;
  $83 = (($agg$result) + 4|0);
  HEAPF32[$83>>2] = $80;
  $84 = (($agg$result) + 8|0);
  HEAPF32[$84>>2] = $82;
  STACKTOP = sp;return;
 }
 $85 = Math_fround($21 - $13);
 $86 = Math_fround($24 - $16);
 $87 = Math_fround($27 - $19);
 $88 = Math_fround($2 * $85);
 $89 = Math_fround($7 * $86);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround($12 * $87);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($14 * $85);
 $94 = Math_fround($17 * $86);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($20 * $87);
 $97 = Math_fround($95 + $96);
 $98 = !($97 >= Math_fround(0.0));
 $99 = !($92 <= $97);
 $or$cond4 = $98 | $99;
 if (!($or$cond4)) {
  HEAPF32[$s>>2] = Math_fround(0.0);
  HEAPF32[$t>>2] = Math_fround(1.0);
  $100 = Math_fround(HEAPF32[$c>>2]);
  HEAPF32[$agg$result>>2] = $100;
  $101 = (($agg$result) + 4|0);
  $102 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$101>>2] = $102;
  $103 = (($agg$result) + 8|0);
  $104 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$103>>2] = $104;
  STACKTOP = sp;return;
 }
 $105 = Math_fround($92 * $38);
 $106 = Math_fround($33 * $97);
 $107 = Math_fround($105 - $106);
 $108 = !($107 <= Math_fround(0.0));
 $109 = !($38 >= Math_fround(0.0));
 $or$cond5 = $108 | $109;
 $110 = !($97 <= Math_fround(0.0));
 $or$cond6 = $or$cond5 | $110;
 if (!($or$cond6)) {
  $111 = Math_fround($38 - $97);
  $112 = Math_fround($38 / $111);
  HEAPF32[$s>>2] = Math_fround(0.0);
  HEAPF32[$t>>2] = $112;
  $113 = Math_fround($14 * $112);
  $114 = Math_fround($17 * $112);
  $115 = Math_fround($20 * $112);
  $116 = Math_fround(HEAPF32[$a>>2]);
  $117 = Math_fround($116 + $113);
  $118 = Math_fround(HEAPF32[$5>>2]);
  $119 = Math_fround($114 + $118);
  $120 = Math_fround(HEAPF32[$10>>2]);
  $121 = Math_fround($115 + $120);
  HEAPF32[$agg$result>>2] = $117;
  $122 = (($agg$result) + 4|0);
  HEAPF32[$122>>2] = $119;
  $123 = (($agg$result) + 8|0);
  HEAPF32[$123>>2] = $121;
  STACKTOP = sp;return;
 }
 $124 = Math_fround($53 * $97);
 $125 = Math_fround($92 * $58);
 $126 = Math_fround($124 - $125);
 $127 = !($126 <= Math_fround(0.0));
 if (!($127)) {
  $128 = Math_fround($58 - $53);
  $129 = !($128 >= Math_fround(0.0));
  if (!($129)) {
   $130 = Math_fround($92 - $97);
   $131 = !($130 >= Math_fround(0.0));
   if (!($131)) {
    $132 = Math_fround($128 + $130);
    $133 = Math_fround($128 / $132);
    $134 = Math_fround(Math_fround(1.0) - $133);
    HEAPF32[$s>>2] = $134;
    HEAPF32[$t>>2] = $133;
    $135 = Math_fround(HEAPF32[$c>>2]);
    $136 = Math_fround(HEAPF32[$b>>2]);
    $137 = Math_fround($135 - $136);
    $138 = Math_fround(HEAPF32[$15>>2]);
    $139 = Math_fround(HEAPF32[$3>>2]);
    $140 = Math_fround($138 - $139);
    $141 = Math_fround(HEAPF32[$18>>2]);
    $142 = Math_fround(HEAPF32[$8>>2]);
    $143 = Math_fround($141 - $142);
    $144 = Math_fround($133 * $137);
    $145 = Math_fround($133 * $140);
    $146 = Math_fround($133 * $143);
    $147 = Math_fround($136 + $144);
    $148 = Math_fround($139 + $145);
    $149 = Math_fround($142 + $146);
    HEAPF32[$agg$result>>2] = $147;
    $150 = (($agg$result) + 4|0);
    HEAPF32[$150>>2] = $148;
    $151 = (($agg$result) + 8|0);
    HEAPF32[$151>>2] = $149;
    STACKTOP = sp;return;
   }
  }
 }
 $152 = Math_fround($126 + $107);
 $153 = Math_fround($68 + $152);
 $154 = Math_fround(Math_fround(1.0) / $153);
 $155 = Math_fround($107 * $154);
 $156 = Math_fround($68 * $154);
 HEAPF32[$s>>2] = $155;
 HEAPF32[$t>>2] = $156;
 $157 = Math_fround($2 * $155);
 $158 = Math_fround($7 * $155);
 $159 = Math_fround($12 * $155);
 $160 = Math_fround(HEAPF32[$a>>2]);
 $161 = Math_fround($160 + $157);
 $162 = Math_fround(HEAPF32[$5>>2]);
 $163 = Math_fround($162 + $158);
 $164 = Math_fround(HEAPF32[$10>>2]);
 $165 = Math_fround($159 + $164);
 $166 = Math_fround($14 * $156);
 $167 = Math_fround($17 * $156);
 $168 = Math_fround($20 * $156);
 $169 = Math_fround($166 + $161);
 $170 = Math_fround($167 + $163);
 $171 = Math_fround($168 + $165);
 HEAPF32[$agg$result>>2] = $169;
 $172 = (($agg$result) + 4|0);
 HEAPF32[$172>>2] = $170;
 $173 = (($agg$result) + 8|0);
 HEAPF32[$173>>2] = $171;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu28distancePointTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_RNS2_6FloatVES7_RS3_($agg$result,$p,$a,$b,$c,$u,$v,$closestP) {
 $agg$result = $agg$result|0;
 $p = $p|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $u = $u|0;
 $v = $v|0;
 $closestP = $closestP|0;
 var $$not = 0, $$not1433 = 0, $$not1436 = 0, $$sroa$1438 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0);
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0;
 var $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge = 0, $brmerge1435 = 0, $brmerge1438 = 0, $one$sroa$1 = 0, $or$cond = 0, $or$cond1423 = 0, $or$cond1425 = 0, $phitmp = 0, $phitmp1439 = 0, $phitmp1440 = 0, $sScale$sroa$1 = 0;
 var $t$sroa$1 = 0, $tScale$sroa$1 = 0, $uScale$sroa$1 = 0, $w$sroa$1 = 0, $zero$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $zero$sroa$1 = sp + 84|0;
 $one$sroa$1 = sp;
 $sScale$sroa$1 = sp + 12|0;
 $uScale$sroa$1 = sp + 24|0;
 $$sroa$1438 = sp + 36|0;
 $tScale$sroa$1 = sp + 48|0;
 $t$sroa$1 = sp + 60|0;
 $w$sroa$1 = sp + 72|0;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($b) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($b) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$a>>2]);
 $6 = (($a) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($a) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($0 - $5);
 $11 = Math_fround($2 - $7);
 $12 = Math_fround($4 - $9);
 $13 = Math_fround(HEAPF32[$c>>2]);
 $14 = (($c) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($c) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($13 - $5);
 $19 = Math_fround($15 - $7);
 $20 = Math_fround($17 - $9);
 $21 = Math_fround($13 - $0);
 $22 = Math_fround($15 - $2);
 $23 = Math_fround($17 - $4);
 $24 = Math_fround(HEAPF32[$p>>2]);
 $25 = (($p) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($p) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($24 - $5);
 $30 = Math_fround($26 - $7);
 $31 = Math_fround($28 - $9);
 $32 = Math_fround($24 - $0);
 $33 = Math_fround($26 - $2);
 $34 = Math_fround($28 - $4);
 $35 = Math_fround($24 - $13);
 $36 = Math_fround($26 - $15);
 $37 = Math_fround($28 - $17);
 $38 = Math_fround($10 * $29);
 $39 = Math_fround($11 * $30);
 $40 = Math_fround($38 + $39);
 $41 = Math_fround($12 * $31);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($18 * $29);
 $44 = Math_fround($19 * $30);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($20 * $31);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($10 * $32);
 $49 = Math_fround($11 * $33);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($12 * $34);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($18 * $32);
 $54 = Math_fround($19 * $33);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($20 * $34);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($10 * $35);
 $59 = Math_fround($11 * $36);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($12 * $37);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($18 * $35);
 $64 = Math_fround($19 * $36);
 $65 = Math_fround($63 + $64);
 $66 = Math_fround($20 * $37);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($57 - $52);
 $69 = Math_fround($62 - $67);
 $70 = $42 < Math_fround(0.0);
 $71 = $47 < Math_fround(0.0);
 $or$cond = $70 & $71;
 if ($or$cond) {
  HEAPF32[$u>>2] = Math_fround(0.0);
  $72 = (($u) + 4|0);
  ;HEAP32[$72+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  HEAPF32[$v>>2] = Math_fround(0.0);
  $73 = (($v) + 4|0);
  ;HEAP32[$73+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  $74 = Math_fround(HEAPF32[$p>>2]);
  $75 = Math_fround(HEAPF32[$25>>2]);
  $76 = Math_fround(HEAPF32[$27>>2]);
  $77 = Math_fround(HEAPF32[$a>>2]);
  $78 = Math_fround(HEAPF32[$6>>2]);
  $79 = Math_fround(HEAPF32[$8>>2]);
  $80 = Math_fround($74 - $77);
  $81 = Math_fround($75 - $78);
  $82 = Math_fround($76 - $79);
  ;HEAP32[$closestP+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$closestP+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$closestP+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$closestP+12>>2]=HEAP32[$a+12>>2]|0;
  $83 = Math_fround($80 * $80);
  $84 = Math_fround($81 * $81);
  $85 = Math_fround($83 + $84);
  $86 = Math_fround($82 * $82);
  $87 = Math_fround($85 + $86);
  HEAPF32[$agg$result>>2] = $87;
  STACKTOP = sp;return;
 }
 $88 = !($52 >= Math_fround(0.0));
 $89 = !($52 >= $57);
 $or$cond1423 = $88 | $89;
 if (!($or$cond1423)) {
  HEAPF32[$u>>2] = Math_fround(1.0);
  $90 = (($u) + 4|0);
  ;HEAP32[$90+0>>2]=HEAP32[$one$sroa$1+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$one$sroa$1+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$one$sroa$1+8>>2]|0;
  HEAPF32[$v>>2] = Math_fround(0.0);
  $91 = (($v) + 4|0);
  ;HEAP32[$91+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  $92 = Math_fround(HEAPF32[$p>>2]);
  $93 = Math_fround(HEAPF32[$25>>2]);
  $94 = Math_fround(HEAPF32[$27>>2]);
  $95 = Math_fround(HEAPF32[$b>>2]);
  $96 = Math_fround(HEAPF32[$1>>2]);
  $97 = Math_fround(HEAPF32[$3>>2]);
  $98 = Math_fround($92 - $95);
  $99 = Math_fround($93 - $96);
  $100 = Math_fround($94 - $97);
  ;HEAP32[$closestP+0>>2]=HEAP32[$b+0>>2]|0;HEAP32[$closestP+4>>2]=HEAP32[$b+4>>2]|0;HEAP32[$closestP+8>>2]=HEAP32[$b+8>>2]|0;HEAP32[$closestP+12>>2]=HEAP32[$b+12>>2]|0;
  $101 = Math_fround($98 * $98);
  $102 = Math_fround($99 * $99);
  $103 = Math_fround($101 + $102);
  $104 = Math_fround($100 * $100);
  $105 = Math_fround($103 + $104);
  HEAPF32[$agg$result>>2] = $105;
  STACKTOP = sp;return;
 }
 $106 = !($67 >= Math_fround(0.0));
 $107 = !($67 >= $62);
 $or$cond1425 = $106 | $107;
 if (!($or$cond1425)) {
  HEAPF32[$u>>2] = Math_fround(0.0);
  $108 = (($u) + 4|0);
  ;HEAP32[$108+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$108+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$108+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  HEAPF32[$v>>2] = Math_fround(1.0);
  $109 = (($v) + 4|0);
  ;HEAP32[$109+0>>2]=HEAP32[$one$sroa$1+0>>2]|0;HEAP32[$109+4>>2]=HEAP32[$one$sroa$1+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$one$sroa$1+8>>2]|0;
  $110 = Math_fround(HEAPF32[$p>>2]);
  $111 = Math_fround(HEAPF32[$25>>2]);
  $112 = Math_fround(HEAPF32[$27>>2]);
  $113 = Math_fround(HEAPF32[$c>>2]);
  $114 = Math_fround(HEAPF32[$14>>2]);
  $115 = Math_fround(HEAPF32[$16>>2]);
  $116 = Math_fround($110 - $113);
  $117 = Math_fround($111 - $114);
  $118 = Math_fround($112 - $115);
  ;HEAP32[$closestP+0>>2]=HEAP32[$c+0>>2]|0;HEAP32[$closestP+4>>2]=HEAP32[$c+4>>2]|0;HEAP32[$closestP+8>>2]=HEAP32[$c+8>>2]|0;HEAP32[$closestP+12>>2]=HEAP32[$c+12>>2]|0;
  $119 = Math_fround($116 * $116);
  $120 = Math_fround($117 * $117);
  $121 = Math_fround($119 + $120);
  $122 = Math_fround($118 * $118);
  $123 = Math_fround($121 + $122);
  HEAPF32[$agg$result>>2] = $123;
  STACKTOP = sp;return;
 }
 $124 = Math_fround($42 * $57);
 $125 = Math_fround($52 * $47);
 $126 = Math_fround($124 - $125);
 $127 = !($42 >= Math_fround(0.0));
 if ($127) {
  $128 = 1;
 } else {
  $phitmp = !($52 < Math_fround(0.0));
  $128 = $phitmp;
 }
 $$not = !($126 < Math_fround(0.0));
 $brmerge = $$not | $128;
 if (!($brmerge)) {
  $129 = Math_fround($42 - $52);
  $130 = Math_fround($42 / $129);
  $131 = Math_fround($10 * $130);
  $132 = Math_fround($11 * $130);
  $133 = Math_fround($12 * $130);
  $134 = Math_fround($5 + $131);
  $135 = Math_fround($132 + $7);
  $136 = Math_fround($133 + $9);
  HEAPF32[$u>>2] = $130;
  $137 = (($u) + 4|0);
  ;HEAP32[$137+0>>2]=HEAP32[$sScale$sroa$1+0>>2]|0;HEAP32[$137+4>>2]=HEAP32[$sScale$sroa$1+4>>2]|0;HEAP32[$137+8>>2]=HEAP32[$sScale$sroa$1+8>>2]|0;
  HEAPF32[$v>>2] = Math_fround(0.0);
  $138 = (($v) + 4|0);
  ;HEAP32[$138+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$138+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$138+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  $139 = Math_fround(HEAPF32[$p>>2]);
  $140 = Math_fround(HEAPF32[$25>>2]);
  $141 = Math_fround(HEAPF32[$27>>2]);
  $142 = Math_fround($139 - $134);
  $143 = Math_fround($140 - $135);
  $144 = Math_fround($141 - $136);
  HEAPF32[$closestP>>2] = $134;
  $145 = (($closestP) + 4|0);
  HEAPF32[$145>>2] = $135;
  $146 = (($closestP) + 8|0);
  HEAPF32[$146>>2] = $136;
  $147 = (($closestP) + 12|0);
  HEAPF32[$147>>2] = Math_fround(0.0);
  $148 = Math_fround($142 * $142);
  $149 = Math_fround($143 * $143);
  $150 = Math_fround($148 + $149);
  $151 = Math_fround($144 * $144);
  $152 = Math_fround($150 + $151);
  HEAPF32[$agg$result>>2] = $152;
  STACKTOP = sp;return;
 }
 $153 = Math_fround($52 * $67);
 $154 = Math_fround($62 * $57);
 $155 = Math_fround($153 - $154);
 $156 = !($57 >= $52);
 if ($156) {
  $157 = 1;
 } else {
  $phitmp1439 = !($62 >= $67);
  $157 = $phitmp1439;
 }
 $$not1433 = !($155 < Math_fround(0.0));
 $brmerge1435 = $$not1433 | $157;
 if (!($brmerge1435)) {
  $158 = Math_fround($68 + $69);
  $159 = Math_fround($68 / $158);
  $160 = Math_fround($21 * $159);
  $161 = Math_fround($22 * $159);
  $162 = Math_fround($23 * $159);
  $163 = Math_fround($0 + $160);
  $164 = Math_fround($161 + $2);
  $165 = Math_fround($162 + $4);
  $166 = Math_fround(Math_fround(1.0) - $159);
  HEAPF32[$u>>2] = $166;
  $167 = (($u) + 4|0);
  ;HEAP32[$167+0>>2]=HEAP32[$$sroa$1438+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$$sroa$1438+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$$sroa$1438+8>>2]|0;
  HEAPF32[$v>>2] = $159;
  $168 = (($v) + 4|0);
  ;HEAP32[$168+0>>2]=HEAP32[$uScale$sroa$1+0>>2]|0;HEAP32[$168+4>>2]=HEAP32[$uScale$sroa$1+4>>2]|0;HEAP32[$168+8>>2]=HEAP32[$uScale$sroa$1+8>>2]|0;
  $169 = Math_fround(HEAPF32[$p>>2]);
  $170 = Math_fround(HEAPF32[$25>>2]);
  $171 = Math_fround(HEAPF32[$27>>2]);
  $172 = Math_fround($169 - $163);
  $173 = Math_fround($170 - $164);
  $174 = Math_fround($171 - $165);
  HEAPF32[$closestP>>2] = $163;
  $175 = (($closestP) + 4|0);
  HEAPF32[$175>>2] = $164;
  $176 = (($closestP) + 8|0);
  HEAPF32[$176>>2] = $165;
  $177 = (($closestP) + 12|0);
  HEAPF32[$177>>2] = Math_fround(0.0);
  $178 = Math_fround($172 * $172);
  $179 = Math_fround($173 * $173);
  $180 = Math_fround($178 + $179);
  $181 = Math_fround($174 * $174);
  $182 = Math_fround($180 + $181);
  HEAPF32[$agg$result>>2] = $182;
  STACKTOP = sp;return;
 }
 $183 = Math_fround($62 * $47);
 $184 = Math_fround($42 * $67);
 $185 = Math_fround($183 - $184);
 $186 = !($47 >= Math_fround(0.0));
 if ($186) {
  $187 = 1;
 } else {
  $phitmp1440 = !($67 < Math_fround(0.0));
  $187 = $phitmp1440;
 }
 $$not1436 = !($185 < Math_fround(0.0));
 $brmerge1438 = $$not1436 | $187;
 if ($brmerge1438) {
  $212 = Math_fround($185 + $126);
  $213 = Math_fround($155 + $212);
  $214 = Math_fround(Math_fround(1.0) / $213);
  $215 = Math_fround($185 * $214);
  $216 = Math_fround($126 * $214);
  $217 = Math_fround($10 * $215);
  $218 = Math_fround($11 * $215);
  $219 = Math_fround($12 * $215);
  $220 = Math_fround($18 * $216);
  $221 = Math_fround($19 * $216);
  $222 = Math_fround($20 * $216);
  $223 = Math_fround($217 + $220);
  $224 = Math_fround($218 + $221);
  $225 = Math_fround($219 + $222);
  $226 = Math_fround($5 + $223);
  $227 = Math_fround($7 + $224);
  $228 = Math_fround($9 + $225);
  HEAPF32[$u>>2] = $215;
  $229 = (($u) + 4|0);
  ;HEAP32[$229+0>>2]=HEAP32[$t$sroa$1+0>>2]|0;HEAP32[$229+4>>2]=HEAP32[$t$sroa$1+4>>2]|0;HEAP32[$229+8>>2]=HEAP32[$t$sroa$1+8>>2]|0;
  HEAPF32[$v>>2] = $216;
  $230 = (($v) + 4|0);
  ;HEAP32[$230+0>>2]=HEAP32[$w$sroa$1+0>>2]|0;HEAP32[$230+4>>2]=HEAP32[$w$sroa$1+4>>2]|0;HEAP32[$230+8>>2]=HEAP32[$w$sroa$1+8>>2]|0;
  HEAPF32[$closestP>>2] = $226;
  $231 = (($closestP) + 4|0);
  HEAPF32[$231>>2] = $227;
  $232 = (($closestP) + 8|0);
  HEAPF32[$232>>2] = $228;
  $233 = (($closestP) + 12|0);
  HEAPF32[$233>>2] = Math_fround(0.0);
  $234 = Math_fround(HEAPF32[$p>>2]);
  $235 = Math_fround(HEAPF32[$25>>2]);
  $236 = Math_fround(HEAPF32[$27>>2]);
  $237 = Math_fround($234 - $226);
  $238 = Math_fround($235 - $227);
  $239 = Math_fround($236 - $228);
  $240 = Math_fround($237 * $237);
  $241 = Math_fround($238 * $238);
  $242 = Math_fround($240 + $241);
  $243 = Math_fround($239 * $239);
  $244 = Math_fround($242 + $243);
  HEAPF32[$agg$result>>2] = $244;
  STACKTOP = sp;return;
 } else {
  $188 = Math_fround($47 - $67);
  $189 = Math_fround($47 / $188);
  $190 = Math_fround($18 * $189);
  $191 = Math_fround($19 * $189);
  $192 = Math_fround($20 * $189);
  $193 = Math_fround($5 + $190);
  $194 = Math_fround($191 + $7);
  $195 = Math_fround($192 + $9);
  HEAPF32[$u>>2] = Math_fround(0.0);
  $196 = (($u) + 4|0);
  ;HEAP32[$196+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$196+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$196+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  HEAPF32[$v>>2] = $189;
  $197 = (($v) + 4|0);
  ;HEAP32[$197+0>>2]=HEAP32[$tScale$sroa$1+0>>2]|0;HEAP32[$197+4>>2]=HEAP32[$tScale$sroa$1+4>>2]|0;HEAP32[$197+8>>2]=HEAP32[$tScale$sroa$1+8>>2]|0;
  $198 = Math_fround(HEAPF32[$p>>2]);
  $199 = Math_fround(HEAPF32[$25>>2]);
  $200 = Math_fround(HEAPF32[$27>>2]);
  $201 = Math_fround($198 - $193);
  $202 = Math_fround($199 - $194);
  $203 = Math_fround($200 - $195);
  HEAPF32[$closestP>>2] = $193;
  $204 = (($closestP) + 4|0);
  HEAPF32[$204>>2] = $194;
  $205 = (($closestP) + 8|0);
  HEAPF32[$205>>2] = $195;
  $206 = (($closestP) + 12|0);
  HEAPF32[$206>>2] = Math_fround(0.0);
  $207 = Math_fround($201 * $201);
  $208 = Math_fround($202 * $202);
  $209 = Math_fround($207 + $208);
  $210 = Math_fround($203 * $203);
  $211 = Math_fround($209 + $210);
  HEAPF32[$agg$result>>2] = $211;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($segmentPoint0,$segmentPoint1,$boxOrigin,$boxExtent,$boxBase,$segmentParam,$boxParam) {
 $segmentPoint0 = $segmentPoint0|0;
 $segmentPoint1 = $segmentPoint1|0;
 $boxOrigin = $boxOrigin|0;
 $boxExtent = $boxExtent|0;
 $boxBase = $boxBase|0;
 $segmentParam = $segmentParam|0;
 $boxParam = $boxParam|0;
 var $$0 = Math_fround(0), $$pre$i = Math_fround(0), $$pre$phi6$i$iZ2D = 0, $$pre$phi6$i6$iZ2D = 0, $$pre1$i$i = 0, $$pre1$i2$i = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0);
 var $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0;
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0;
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0;
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0;
 var $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0;
 var $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0;
 var $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $boxOrigin$idx$val = Math_fround(0), $boxOrigin$idx5 = 0, $boxOrigin$idx5$val = Math_fround(0), $boxOrigin$idx6 = 0;
 var $boxOrigin$idx6$val = Math_fround(0), $dir$i = 0, $kPmE$i$i = 0, $lp = 0, $pnt$i = 0, $sqrDistance$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $kPmE$i$i = sp + 32|0;
 $pnt$i = sp;
 $dir$i = sp + 12|0;
 $sqrDistance$i = sp + 24|0;
 $lp = sp + 28|0;
 $0 = Math_fround(HEAPF32[$segmentPoint1>>2]);
 $1 = Math_fround(HEAPF32[$segmentPoint0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($segmentPoint1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($segmentPoint0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($segmentPoint1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($segmentPoint0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $boxOrigin$idx$val = Math_fround(HEAPF32[$boxOrigin>>2]);
 $boxOrigin$idx5 = (($boxOrigin) + 4|0);
 $boxOrigin$idx5$val = Math_fround(HEAPF32[$boxOrigin$idx5>>2]);
 $boxOrigin$idx6 = (($boxOrigin) + 8|0);
 $boxOrigin$idx6$val = Math_fround(HEAPF32[$boxOrigin$idx6>>2]);
 $13 = Math_fround($1 - $boxOrigin$idx$val);
 $14 = Math_fround($6 - $boxOrigin$idx5$val);
 $15 = Math_fround($11 - $boxOrigin$idx6$val);
 $16 = Math_fround(HEAPF32[$boxBase>>2]);
 $17 = Math_fround($13 * $16);
 $18 = (($boxBase) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($14 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (($boxBase) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($15 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($boxBase) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($13 * $27);
 $29 = (($boxBase) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($14 * $30);
 $32 = Math_fround($28 + $31);
 $33 = (($boxBase) + 20|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($15 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($boxBase) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($13 * $38);
 $40 = (($boxBase) + 28|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($14 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (($boxBase) + 32|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($15 * $45);
 $47 = Math_fround($43 + $46);
 HEAPF32[$pnt$i>>2] = $25;
 $48 = (($pnt$i) + 4|0);
 HEAPF32[$48>>2] = $36;
 $49 = (($pnt$i) + 8|0);
 HEAPF32[$49>>2] = $47;
 $50 = Math_fround($2 * $16);
 $51 = Math_fround($7 * $19);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($12 * $23);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($2 * $27);
 $56 = Math_fround($7 * $30);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($12 * $34);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($2 * $38);
 $61 = Math_fround($7 * $41);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($12 * $45);
 $64 = Math_fround($62 + $63);
 HEAPF32[$dir$i>>2] = $54;
 $65 = (($dir$i) + 4|0);
 HEAPF32[$65>>2] = $59;
 $66 = (($dir$i) + 8|0);
 HEAPF32[$66>>2] = $64;
 $67 = $54 < Math_fround(0.0);
 if ($67) {
  $68 = Math_fround(-$25);
  HEAPF32[$pnt$i>>2] = $68;
  $69 = Math_fround(-$54);
  HEAPF32[$dir$i>>2] = $69;
  $211 = 1;$73 = $68;$85 = $69;
 } else {
  $211 = 0;$73 = $25;$85 = $54;
 }
 $70 = $59 < Math_fround(0.0);
 if ($70) {
  $224 = (($dir$i) + 4|0);
  $225 = (($pnt$i) + 4|0);
  $226 = Math_fround(-$36);
  HEAPF32[$225>>2] = $226;
  $227 = Math_fround(-$59);
  HEAPF32[$224>>2] = $227;
  $215 = 1;$77 = $226;$87 = $227;
 } else {
  $215 = 0;$77 = $36;$87 = $59;
 }
 $228 = $64 < Math_fround(0.0);
 if ($228) {
  $229 = (($dir$i) + 8|0);
  $230 = (($pnt$i) + 8|0);
  $231 = Math_fround(-$47);
  HEAPF32[$230>>2] = $231;
  $232 = Math_fround(-$64);
  HEAPF32[$229>>2] = $232;
  $220 = 1;$81 = $231;$90 = $232;
 } else {
  $220 = 0;$81 = $47;$90 = $64;
 }
 HEAPF32[$sqrDistance$i>>2] = Math_fround(0.0);
 $233 = $85 > Math_fround(0.0);
 $234 = $87 > Math_fround(0.0);
 $235 = $90 > Math_fround(0.0);
 do {
  if ($233) {
   if ($234) {
    if (!($235)) {
     __ZL5case0iiiRN5physx6PxVec3ERKS0_S3_PfRf(0,1,2,$pnt$i,$dir$i,$boxExtent,$lp,$sqrDistance$i);
     break;
    }
    $71 = Math_fround(HEAPF32[$boxExtent>>2]);
    $72 = Math_fround($73 - $71);
    $74 = (($boxExtent) + 4|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = Math_fround($77 - $75);
    $78 = (($boxExtent) + 8|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = Math_fround($81 - $79);
    HEAPF32[$kPmE$i$i>>2] = $72;
    $82 = (($kPmE$i$i) + 4|0);
    HEAPF32[$82>>2] = $76;
    $83 = (($kPmE$i$i) + 8|0);
    HEAPF32[$83>>2] = $80;
    $84 = Math_fround($85 * $76);
    $86 = Math_fround($87 * $72);
    $88 = !($86 >= $84);
    if ($88) {
     $93 = Math_fround($90 * $76);
     $94 = Math_fround($87 * $80);
     $95 = !($93 >= $94);
     if ($95) {
      __ZL4faceiiiRN5physx6PxVec3ERKS0_S3_S3_PfRf(2,0,1,$pnt$i,$dir$i,$boxExtent,$kPmE$i$i,$lp,$sqrDistance$i);
      break;
     } else {
      __ZL4faceiiiRN5physx6PxVec3ERKS0_S3_S3_PfRf(1,2,0,$pnt$i,$dir$i,$boxExtent,$kPmE$i$i,$lp,$sqrDistance$i);
      break;
     }
    } else {
     $89 = Math_fround($90 * $72);
     $91 = Math_fround($85 * $80);
     $92 = !($89 >= $91);
     if ($92) {
      __ZL4faceiiiRN5physx6PxVec3ERKS0_S3_S3_PfRf(2,0,1,$pnt$i,$dir$i,$boxExtent,$kPmE$i$i,$lp,$sqrDistance$i);
      break;
     } else {
      __ZL4faceiiiRN5physx6PxVec3ERKS0_S3_S3_PfRf(0,1,2,$pnt$i,$dir$i,$boxExtent,$kPmE$i$i,$lp,$sqrDistance$i);
      break;
     }
    }
   }
   if ($235) {
    __ZL5case0iiiRN5physx6PxVec3ERKS0_S3_PfRf(0,2,1,$pnt$i,$dir$i,$boxExtent,$lp,$sqrDistance$i);
    break;
   }
   $96 = Math_fround(HEAPF32[$boxExtent>>2]);
   $97 = Math_fround($96 - $73);
   $98 = Math_fround($97 / $85);
   HEAPF32[$lp>>2] = $98;
   HEAPF32[$pnt$i>>2] = $96;
   $99 = (($pnt$i) + 4|0);
   $100 = (($boxExtent) + 4|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = Math_fround(-$101);
   $103 = $77 < $102;
   if ($103) {
    $104 = Math_fround($77 + $101);
    $105 = Math_fround($104 * $104);
    $106 = Math_fround($105 + Math_fround(0.0));
    HEAPF32[$sqrDistance$i>>2] = $106;
    HEAPF32[$99>>2] = $102;
    $119 = $106;
   } else {
    $107 = $77 > $101;
    if ($107) {
     $108 = Math_fround($77 - $101);
     $109 = Math_fround($108 * $108);
     $110 = Math_fround($109 + Math_fround(0.0));
     HEAPF32[$sqrDistance$i>>2] = $110;
     HEAPF32[$99>>2] = $101;
     $119 = $110;
    } else {
     $119 = Math_fround(0.0);
    }
   }
   $111 = (($pnt$i) + 8|0);
   $112 = (($boxExtent) + 8|0);
   $113 = Math_fround(HEAPF32[$112>>2]);
   $114 = Math_fround(-$113);
   $115 = $81 < $114;
   if ($115) {
    $116 = Math_fround($81 + $113);
    $117 = Math_fround($116 * $116);
    $118 = Math_fround($119 + $117);
    HEAPF32[$sqrDistance$i>>2] = $118;
    HEAPF32[$111>>2] = $114;
    break;
   }
   $120 = $81 > $113;
   if ($120) {
    $121 = Math_fround($81 - $113);
    $122 = Math_fround($121 * $121);
    $123 = Math_fround($119 + $122);
    HEAPF32[$sqrDistance$i>>2] = $123;
    HEAPF32[$111>>2] = $113;
   }
  } else {
   if ($234) {
    if ($235) {
     __ZL5case0iiiRN5physx6PxVec3ERKS0_S3_PfRf(1,2,0,$pnt$i,$dir$i,$boxExtent,$lp,$sqrDistance$i);
     break;
    }
    $$pre1$i2$i = (($boxExtent) + 4|0);
    $124 = Math_fround(HEAPF32[$$pre1$i2$i>>2]);
    $125 = Math_fround($124 - $77);
    $126 = Math_fround($125 / $87);
    HEAPF32[$lp>>2] = $126;
    $$pre$phi6$i6$iZ2D = (($pnt$i) + 4|0);
    HEAPF32[$$pre$phi6$i6$iZ2D>>2] = $124;
    $127 = Math_fround(HEAPF32[$boxExtent>>2]);
    $128 = Math_fround(-$127);
    $129 = $73 < $128;
    if ($129) {
     $130 = Math_fround($73 + $127);
     $131 = Math_fround($130 * $130);
     $132 = Math_fround($131 + Math_fround(0.0));
     HEAPF32[$sqrDistance$i>>2] = $132;
     HEAPF32[$pnt$i>>2] = $128;
     $145 = $132;
    } else {
     $133 = $73 > $127;
     if ($133) {
      $134 = Math_fround($73 - $127);
      $135 = Math_fround($134 * $134);
      $136 = Math_fround($135 + Math_fround(0.0));
      HEAPF32[$sqrDistance$i>>2] = $136;
      HEAPF32[$pnt$i>>2] = $127;
      $145 = $136;
     } else {
      $145 = Math_fround(0.0);
     }
    }
    $137 = (($pnt$i) + 8|0);
    $138 = (($boxExtent) + 8|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = Math_fround(-$139);
    $141 = $81 < $140;
    if ($141) {
     $142 = Math_fround($81 + $139);
     $143 = Math_fround($142 * $142);
     $144 = Math_fround($145 + $143);
     HEAPF32[$sqrDistance$i>>2] = $144;
     HEAPF32[$137>>2] = $140;
     break;
    }
    $146 = $81 > $139;
    if (!($146)) {
     break;
    }
    $147 = Math_fround($81 - $139);
    $148 = Math_fround($147 * $147);
    $149 = Math_fround($145 + $148);
    HEAPF32[$sqrDistance$i>>2] = $149;
    HEAPF32[$137>>2] = $139;
    break;
   }
   if ($235) {
    $$pre1$i$i = (($boxExtent) + 8|0);
    $150 = Math_fround(HEAPF32[$$pre1$i$i>>2]);
    $151 = Math_fround($150 - $81);
    $152 = Math_fround($151 / $90);
    HEAPF32[$lp>>2] = $152;
    $$pre$phi6$i$iZ2D = (($pnt$i) + 8|0);
    HEAPF32[$$pre$phi6$i$iZ2D>>2] = $150;
    $153 = Math_fround(HEAPF32[$boxExtent>>2]);
    $154 = Math_fround(-$153);
    $155 = $73 < $154;
    if ($155) {
     $156 = Math_fround($73 + $153);
     $157 = Math_fround($156 * $156);
     $158 = Math_fround($157 + Math_fround(0.0));
     HEAPF32[$sqrDistance$i>>2] = $158;
     HEAPF32[$pnt$i>>2] = $154;
     $171 = $158;
    } else {
     $159 = $73 > $153;
     if ($159) {
      $160 = Math_fround($73 - $153);
      $161 = Math_fround($160 * $160);
      $162 = Math_fround($161 + Math_fround(0.0));
      HEAPF32[$sqrDistance$i>>2] = $162;
      HEAPF32[$pnt$i>>2] = $153;
      $171 = $162;
     } else {
      $171 = Math_fround(0.0);
     }
    }
    $163 = (($pnt$i) + 4|0);
    $164 = (($boxExtent) + 4|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = Math_fround(-$165);
    $167 = $77 < $166;
    if ($167) {
     $168 = Math_fround($77 + $165);
     $169 = Math_fround($168 * $168);
     $170 = Math_fround($171 + $169);
     HEAPF32[$sqrDistance$i>>2] = $170;
     HEAPF32[$163>>2] = $166;
     break;
    }
    $172 = $77 > $165;
    if (!($172)) {
     break;
    }
    $173 = Math_fround($77 - $165);
    $174 = Math_fround($173 * $173);
    $175 = Math_fround($171 + $174);
    HEAPF32[$sqrDistance$i>>2] = $175;
    HEAPF32[$163>>2] = $165;
    break;
   }
   $176 = Math_fround(HEAPF32[$boxExtent>>2]);
   $177 = Math_fround(-$176);
   $178 = $73 < $177;
   if ($178) {
    $179 = Math_fround($73 + $176);
    $180 = Math_fround($179 * $179);
    $181 = Math_fround($180 + Math_fround(0.0));
    HEAPF32[$sqrDistance$i>>2] = $181;
    HEAPF32[$pnt$i>>2] = $177;
    $193 = $181;
   } else {
    $182 = $73 > $176;
    if ($182) {
     $183 = Math_fround($73 - $176);
     $184 = Math_fround($183 * $183);
     $185 = Math_fround($184 + Math_fround(0.0));
     HEAPF32[$sqrDistance$i>>2] = $185;
     HEAPF32[$pnt$i>>2] = $176;
     $193 = $185;
    } else {
     $193 = Math_fround(0.0);
    }
   }
   $186 = (($boxExtent) + 4|0);
   $187 = Math_fround(HEAPF32[$186>>2]);
   $188 = Math_fround(-$187);
   $189 = $77 < $188;
   if ($189) {
    $190 = Math_fround($77 + $187);
    $191 = Math_fround($190 * $190);
    $192 = Math_fround($193 + $191);
    HEAPF32[$sqrDistance$i>>2] = $192;
    HEAPF32[$48>>2] = $188;
    $205 = $192;
   } else {
    $194 = $77 > $187;
    if ($194) {
     $195 = Math_fround($77 - $187);
     $196 = Math_fround($195 * $195);
     $197 = Math_fround($193 + $196);
     HEAPF32[$sqrDistance$i>>2] = $197;
     HEAPF32[$48>>2] = $187;
     $205 = $197;
    } else {
     $205 = $193;
    }
   }
   $198 = (($boxExtent) + 8|0);
   $199 = Math_fround(HEAPF32[$198>>2]);
   $200 = Math_fround(-$199);
   $201 = $81 < $200;
   if ($201) {
    $202 = Math_fround($81 + $199);
    $203 = Math_fround($202 * $202);
    $204 = Math_fround($205 + $203);
    HEAPF32[$sqrDistance$i>>2] = $204;
    HEAPF32[$49>>2] = $200;
   } else {
    $206 = $81 > $199;
    if ($206) {
     $207 = Math_fround($81 - $199);
     $208 = Math_fround($207 * $207);
     $209 = Math_fround($205 + $208);
     HEAPF32[$sqrDistance$i>>2] = $209;
     HEAPF32[$49>>2] = $199;
    }
   }
   HEAPF32[$lp>>2] = Math_fround(0.0);
  }
 } while(0);
 $210 = ($211<<24>>24)==(0);
 if (!($210)) {
  $212 = Math_fround(HEAPF32[$pnt$i>>2]);
  $213 = Math_fround(-$212);
  HEAPF32[$pnt$i>>2] = $213;
 }
 $214 = ($215<<24>>24)==(0);
 if (!($214)) {
  $216 = (($pnt$i) + 4|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = Math_fround(-$217);
  HEAPF32[$216>>2] = $218;
 }
 $219 = ($220<<24>>24)==(0);
 if ($219) {
  $$pre$i = Math_fround(HEAPF32[$49>>2]);
  $246 = $$pre$i;
 } else {
  $221 = (($pnt$i) + 8|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  $223 = Math_fround(-$222);
  HEAPF32[$221>>2] = $223;
  $246 = $223;
 }
 $236 = Math_fround(HEAPF32[$pnt$i>>2]);
 $237 = Math_fround(HEAPF32[$48>>2]);
 $238 = Math_fround(HEAPF32[$sqrDistance$i>>2]);
 $239 = Math_fround(HEAPF32[$lp>>2]);
 $240 = !($239 >= Math_fround(0.0));
 if ($240) {
  $248 = ($segmentParam|0)==(0|0);
  if (!($248)) {
   HEAPF32[$segmentParam>>2] = Math_fround(0.0);
  }
  $249 = (Math_fround(__ZN5physx2Gu23distancePointBoxSquaredERKNS_6PxVec3ES3_S3_RKNS_7PxMat33EPS1_($segmentPoint0,$boxOrigin,$boxExtent,$boxBase,$boxParam)));
  $$0 = $249;
  STACKTOP = sp;return (Math_fround($$0));
 }
 $241 = !($239 <= Math_fround(1.0));
 $242 = ($segmentParam|0)!=(0|0);
 if ($241) {
  if ($242) {
   HEAPF32[$segmentParam>>2] = Math_fround(1.0);
  }
  $247 = (Math_fround(__ZN5physx2Gu23distancePointBoxSquaredERKNS_6PxVec3ES3_S3_RKNS_7PxMat33EPS1_($segmentPoint1,$boxOrigin,$boxExtent,$boxBase,$boxParam)));
  $$0 = $247;
  STACKTOP = sp;return (Math_fround($$0));
 }
 if ($242) {
  HEAPF32[$segmentParam>>2] = $239;
 }
 $243 = ($boxParam|0)==(0|0);
 if ($243) {
  $$0 = $238;
  STACKTOP = sp;return (Math_fround($$0));
 }
 HEAPF32[$boxParam>>2] = $236;
 $244 = (($boxParam) + 4|0);
 HEAPF32[$244>>2] = $237;
 $245 = (($boxParam) + 8|0);
 HEAPF32[$245>>2] = $246;
 $$0 = $238;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZL5case0iiiRN5physx6PxVec3ERKS0_S3_PfRf($i0,$i1,$i2,$rkPnt,$rkDir,$extents,$pfLParam,$rfSqrDistance) {
 $i0 = $i0|0;
 $i1 = $i1|0;
 $i2 = $i2|0;
 $rkPnt = $rkPnt|0;
 $rkDir = $rkDir|0;
 $extents = $extents|0;
 $pfLParam = $pfLParam|0;
 $rfSqrDistance = $rfSqrDistance|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($rkPnt) + ($i0<<2)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($extents) + ($i0<<2)|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($rkPnt) + ($i1<<2)|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($extents) + ($i1<<2)|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($rkDir) + ($i1<<2)|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($4 * $11);
 $13 = (($rkDir) + ($i0<<2)|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($9 * $14);
 $16 = !($12 >= $15);
 do {
  if ($16) {
   HEAPF32[$5>>2] = $8;
   $49 = Math_fround(HEAPF32[$0>>2]);
   $50 = Math_fround(HEAPF32[$2>>2]);
   $51 = Math_fround($49 + $50);
   $52 = Math_fround(HEAPF32[$10>>2]);
   $53 = Math_fround($52 * $51);
   $54 = Math_fround($15 - $53);
   $55 = !($54 >= Math_fround(0.0));
   if ($55) {
    $75 = ($pfLParam|0)==(0|0);
    if ($75) {
     break;
    }
    $76 = Math_fround(Math_fround(1.0) / $52);
    $77 = Math_fround($15 * $76);
    $78 = Math_fround($49 - $77);
    HEAPF32[$0>>2] = $78;
    $79 = Math_fround($9 * $76);
    $80 = Math_fround(-$79);
    HEAPF32[$pfLParam>>2] = $80;
    break;
   } else {
    $56 = Math_fround(HEAPF32[$13>>2]);
    $57 = Math_fround($56 * $56);
    $58 = Math_fround($52 * $52);
    $59 = Math_fround($58 + $57);
    $60 = Math_fround(Math_fround(1.0) / $59);
    $61 = Math_fround($54 * $54);
    $62 = Math_fround($61 * $60);
    $63 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
    $64 = Math_fround($63 + $62);
    HEAPF32[$rfSqrDistance>>2] = $64;
    $65 = ($pfLParam|0)==(0|0);
    if ($65) {
     break;
    }
    $66 = Math_fround(HEAPF32[$2>>2]);
    $67 = Math_fround(-$66);
    HEAPF32[$0>>2] = $67;
    $68 = Math_fround(HEAPF32[$13>>2]);
    $69 = Math_fround($51 * $68);
    $70 = Math_fround(HEAPF32[$10>>2]);
    $71 = Math_fround($9 * $70);
    $72 = Math_fround($69 + $71);
    $73 = Math_fround($60 * $72);
    $74 = Math_fround(-$73);
    HEAPF32[$pfLParam>>2] = $74;
    break;
   }
  } else {
   HEAPF32[$0>>2] = $3;
   $17 = Math_fround(HEAPF32[$5>>2]);
   $18 = Math_fround(HEAPF32[$7>>2]);
   $19 = Math_fround($17 + $18);
   $20 = Math_fround(HEAPF32[$13>>2]);
   $21 = Math_fround($20 * $19);
   $22 = Math_fround($12 - $21);
   $23 = !($22 >= Math_fround(0.0));
   if ($23) {
    $43 = ($pfLParam|0)==(0|0);
    if ($43) {
     break;
    }
    $44 = Math_fround(Math_fround(1.0) / $20);
    $45 = Math_fround($12 * $44);
    $46 = Math_fround($17 - $45);
    HEAPF32[$5>>2] = $46;
    $47 = Math_fround($4 * $44);
    $48 = Math_fround(-$47);
    HEAPF32[$pfLParam>>2] = $48;
    break;
   } else {
    $24 = Math_fround($20 * $20);
    $25 = Math_fround(HEAPF32[$10>>2]);
    $26 = Math_fround($25 * $25);
    $27 = Math_fround($24 + $26);
    $28 = Math_fround(Math_fround(1.0) / $27);
    $29 = Math_fround($22 * $22);
    $30 = Math_fround($29 * $28);
    $31 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
    $32 = Math_fround($31 + $30);
    HEAPF32[$rfSqrDistance>>2] = $32;
    $33 = ($pfLParam|0)==(0|0);
    if ($33) {
     break;
    }
    $34 = Math_fround(HEAPF32[$7>>2]);
    $35 = Math_fround(-$34);
    HEAPF32[$5>>2] = $35;
    $36 = Math_fround(HEAPF32[$13>>2]);
    $37 = Math_fround($4 * $36);
    $38 = Math_fround(HEAPF32[$10>>2]);
    $39 = Math_fround($19 * $38);
    $40 = Math_fround($37 + $39);
    $41 = Math_fround($28 * $40);
    $42 = Math_fround(-$41);
    HEAPF32[$pfLParam>>2] = $42;
    break;
   }
  }
 } while(0);
 $81 = (($rkPnt) + ($i2<<2)|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($extents) + ($i2<<2)|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround(-$84);
 $86 = $82 < $85;
 if ($86) {
  $87 = Math_fround($82 + $84);
  $88 = Math_fround($87 * $87);
  $89 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
  $90 = Math_fround($88 + $89);
  HEAPF32[$rfSqrDistance>>2] = $90;
  $91 = Math_fround(HEAPF32[$83>>2]);
  $92 = Math_fround(-$91);
  HEAPF32[$81>>2] = $92;
  STACKTOP = sp;return;
 }
 $93 = $82 > $84;
 if (!($93)) {
  STACKTOP = sp;return;
 }
 $94 = Math_fround($82 - $84);
 $95 = Math_fround($94 * $94);
 $96 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
 $97 = Math_fround($95 + $96);
 HEAPF32[$rfSqrDistance>>2] = $97;
 $98 = Math_fround(HEAPF32[$83>>2]);
 HEAPF32[$81>>2] = $98;
 STACKTOP = sp;return;
}
function __ZL4faceiiiRN5physx6PxVec3ERKS0_S3_S3_PfRf($i0,$i1,$i2,$rkPnt,$rkDir,$extents,$rkPmE,$pfLParam,$rfSqrDistance) {
 $i0 = $i0|0;
 $i1 = $i1|0;
 $i2 = $i2|0;
 $rkPnt = $rkPnt|0;
 $rkDir = $rkDir|0;
 $extents = $extents|0;
 $rkPmE = $rkPmE|0;
 $pfLParam = $pfLParam|0;
 $rfSqrDistance = $rfSqrDistance|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0;
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $kPpE = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $kPpE = sp;
 $0 = (($rkPnt) + ($i1<<2)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($extents) + ($i1<<2)|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = (($kPpE) + ($i1<<2)|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($rkPnt) + ($i2<<2)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($extents) + ($i2<<2)|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 + $9);
 $11 = (($kPpE) + ($i2<<2)|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($rkDir) + ($i0<<2)|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$5>>2]);
 $15 = Math_fround($13 * $14);
 $16 = (($rkDir) + ($i1<<2)|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($rkPmE) + ($i0<<2)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = !($15 >= $20);
 $22 = Math_fround($13 * $10);
 $23 = (($rkDir) + ($i2<<2)|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($19 * $24);
 $26 = $22 >= $25;
 if (!($21)) {
  if ($26) {
   $27 = ($pfLParam|0)==(0|0);
   if ($27) {
    STACKTOP = sp;return;
   }
   $28 = (($extents) + ($i0<<2)|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = (($rkPnt) + ($i0<<2)|0);
   HEAPF32[$30>>2] = $29;
   $31 = Math_fround(HEAPF32[$12>>2]);
   $32 = Math_fround(Math_fround(1.0) / $31);
   $33 = Math_fround(HEAPF32[$16>>2]);
   $34 = Math_fround(HEAPF32[$18>>2]);
   $35 = Math_fround($33 * $34);
   $36 = Math_fround($32 * $35);
   $37 = Math_fround(HEAPF32[$0>>2]);
   $38 = Math_fround($37 - $36);
   HEAPF32[$0>>2] = $38;
   $39 = Math_fround(HEAPF32[$23>>2]);
   $40 = Math_fround(HEAPF32[$18>>2]);
   $41 = Math_fround($39 * $40);
   $42 = Math_fround($32 * $41);
   $43 = Math_fround(HEAPF32[$6>>2]);
   $44 = Math_fround($43 - $42);
   HEAPF32[$6>>2] = $44;
   $45 = Math_fround(HEAPF32[$18>>2]);
   $46 = Math_fround($32 * $45);
   $47 = Math_fround(-$46);
   HEAPF32[$pfLParam>>2] = $47;
   STACKTOP = sp;return;
  }
  $48 = Math_fround($13 * $13);
  $49 = Math_fround($24 * $24);
  $50 = Math_fround($48 + $49);
  $51 = Math_fround($14 * $50);
  $52 = Math_fround($13 * $19);
  $53 = Math_fround($10 * $24);
  $54 = Math_fround($52 + $53);
  $55 = Math_fround($17 * $54);
  $56 = Math_fround($51 - $55);
  $57 = Math_fround($50 * Math_fround(2.0));
  $58 = Math_fround($57 * $3);
  $59 = !($56 <= $58);
  if ($59) {
   $86 = Math_fround($17 * $17);
   $87 = Math_fround($86 + $50);
   $88 = (($rkPmE) + ($i1<<2)|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = Math_fround($17 * $89);
   $91 = Math_fround($52 + $90);
   $92 = Math_fround($53 + $91);
   $93 = Math_fround(-$92);
   $94 = Math_fround($93 / $87);
   $95 = Math_fround($19 * $19);
   $96 = Math_fround($89 * $89);
   $97 = Math_fround($95 + $96);
   $98 = Math_fround($10 * $10);
   $99 = Math_fround($98 + $97);
   $100 = Math_fround($94 * $92);
   $101 = Math_fround($99 + $100);
   $102 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
   $103 = Math_fround($102 + $101);
   HEAPF32[$rfSqrDistance>>2] = $103;
   $104 = ($pfLParam|0)==(0|0);
   if ($104) {
    STACKTOP = sp;return;
   }
   HEAPF32[$pfLParam>>2] = $94;
   $105 = (($extents) + ($i0<<2)|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = (($rkPnt) + ($i0<<2)|0);
   HEAPF32[$107>>2] = $106;
   $108 = Math_fround(HEAPF32[$2>>2]);
   HEAPF32[$0>>2] = $108;
   $109 = Math_fround(HEAPF32[$8>>2]);
   $110 = Math_fround(-$109);
   HEAPF32[$6>>2] = $110;
   STACKTOP = sp;return;
  } else {
   $60 = Math_fround($56 / $50);
   $61 = Math_fround($17 * $17);
   $62 = Math_fround($61 + $50);
   $63 = Math_fround($14 - $60);
   $64 = Math_fround($17 * $63);
   $65 = Math_fround($52 + $64);
   $66 = Math_fround($53 + $65);
   $67 = Math_fround(-$66);
   $68 = Math_fround($67 / $62);
   $69 = Math_fround($19 * $19);
   $70 = Math_fround($63 * $63);
   $71 = Math_fround($69 + $70);
   $72 = Math_fround($10 * $10);
   $73 = Math_fround($72 + $71);
   $74 = Math_fround($68 * $66);
   $75 = Math_fround($73 + $74);
   $76 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
   $77 = Math_fround($76 + $75);
   HEAPF32[$rfSqrDistance>>2] = $77;
   $78 = ($pfLParam|0)==(0|0);
   if ($78) {
    STACKTOP = sp;return;
   }
   HEAPF32[$pfLParam>>2] = $68;
   $79 = (($extents) + ($i0<<2)|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = (($rkPnt) + ($i0<<2)|0);
   HEAPF32[$81>>2] = $80;
   $82 = Math_fround(HEAPF32[$2>>2]);
   $83 = Math_fround($60 - $82);
   HEAPF32[$0>>2] = $83;
   $84 = Math_fround(HEAPF32[$8>>2]);
   $85 = Math_fround(-$84);
   HEAPF32[$6>>2] = $85;
   STACKTOP = sp;return;
  }
 }
 $111 = Math_fround($13 * $13);
 if ($26) {
  $112 = Math_fround($17 * $17);
  $113 = Math_fround($111 + $112);
  $114 = Math_fround($10 * $113);
  $115 = Math_fround($13 * $19);
  $116 = Math_fround($14 * $17);
  $117 = Math_fround($116 + $115);
  $118 = Math_fround($24 * $117);
  $119 = Math_fround($114 - $118);
  $120 = Math_fround($113 * Math_fround(2.0));
  $121 = Math_fround($120 * $9);
  $122 = !($119 <= $121);
  if ($122) {
   $148 = Math_fround($24 * $24);
   $149 = Math_fround($113 + $148);
   $150 = (($rkPmE) + ($i2<<2)|0);
   $151 = Math_fround(HEAPF32[$150>>2]);
   $152 = Math_fround($24 * $151);
   $153 = Math_fround($117 + $152);
   $154 = Math_fround(-$153);
   $155 = Math_fround($154 / $149);
   $156 = Math_fround($19 * $19);
   $157 = Math_fround($14 * $14);
   $158 = Math_fround($157 + $156);
   $159 = Math_fround($151 * $151);
   $160 = Math_fround($158 + $159);
   $161 = Math_fround($155 * $153);
   $162 = Math_fround($160 + $161);
   $163 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
   $164 = Math_fround($163 + $162);
   HEAPF32[$rfSqrDistance>>2] = $164;
   $165 = ($pfLParam|0)==(0|0);
   if ($165) {
    STACKTOP = sp;return;
   }
   HEAPF32[$pfLParam>>2] = $155;
   $166 = (($extents) + ($i0<<2)|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = (($rkPnt) + ($i0<<2)|0);
   HEAPF32[$168>>2] = $167;
   $169 = Math_fround(HEAPF32[$2>>2]);
   $170 = Math_fround(-$169);
   HEAPF32[$0>>2] = $170;
   $171 = Math_fround(HEAPF32[$8>>2]);
   HEAPF32[$6>>2] = $171;
   STACKTOP = sp;return;
  } else {
   $123 = Math_fround($119 / $113);
   $124 = Math_fround($24 * $24);
   $125 = Math_fround($113 + $124);
   $126 = Math_fround($10 - $123);
   $127 = Math_fround($24 * $126);
   $128 = Math_fround($117 + $127);
   $129 = Math_fround(-$128);
   $130 = Math_fround($129 / $125);
   $131 = Math_fround($19 * $19);
   $132 = Math_fround($14 * $14);
   $133 = Math_fround($132 + $131);
   $134 = Math_fround($126 * $126);
   $135 = Math_fround($133 + $134);
   $136 = Math_fround($130 * $128);
   $137 = Math_fround($135 + $136);
   $138 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
   $139 = Math_fround($138 + $137);
   HEAPF32[$rfSqrDistance>>2] = $139;
   $140 = ($pfLParam|0)==(0|0);
   if ($140) {
    STACKTOP = sp;return;
   }
   HEAPF32[$pfLParam>>2] = $130;
   $141 = (($extents) + ($i0<<2)|0);
   $142 = Math_fround(HEAPF32[$141>>2]);
   $143 = (($rkPnt) + ($i0<<2)|0);
   HEAPF32[$143>>2] = $142;
   $144 = Math_fround(HEAPF32[$2>>2]);
   $145 = Math_fround(-$144);
   HEAPF32[$0>>2] = $145;
   $146 = Math_fround(HEAPF32[$8>>2]);
   $147 = Math_fround($123 - $146);
   HEAPF32[$6>>2] = $147;
   STACKTOP = sp;return;
  }
 }
 $172 = Math_fround($24 * $24);
 $173 = Math_fround($111 + $172);
 $174 = Math_fround($14 * $173);
 $175 = Math_fround($13 * $19);
 $176 = Math_fround($10 * $24);
 $177 = Math_fround($175 + $176);
 $178 = Math_fround($17 * $177);
 $179 = Math_fround($174 - $178);
 $180 = !($179 >= Math_fround(0.0));
 if (!($180)) {
  $181 = Math_fround($173 * Math_fround(2.0));
  $182 = Math_fround($181 * $3);
  $183 = !($179 <= $182);
  if ($183) {
   $210 = Math_fround($17 * $17);
   $211 = Math_fround($210 + $173);
   $212 = (($rkPmE) + ($i1<<2)|0);
   $213 = Math_fround(HEAPF32[$212>>2]);
   $214 = Math_fround($17 * $213);
   $215 = Math_fround($175 + $214);
   $216 = Math_fround($176 + $215);
   $217 = Math_fround(-$216);
   $218 = Math_fround($217 / $211);
   $219 = Math_fround($19 * $19);
   $220 = Math_fround($213 * $213);
   $221 = Math_fround($219 + $220);
   $222 = Math_fround($10 * $10);
   $223 = Math_fround($222 + $221);
   $224 = Math_fround($218 * $216);
   $225 = Math_fround($223 + $224);
   $226 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
   $227 = Math_fround($226 + $225);
   HEAPF32[$rfSqrDistance>>2] = $227;
   $228 = ($pfLParam|0)==(0|0);
   if ($228) {
    STACKTOP = sp;return;
   }
   HEAPF32[$pfLParam>>2] = $218;
   $229 = (($extents) + ($i0<<2)|0);
   $230 = Math_fround(HEAPF32[$229>>2]);
   $231 = (($rkPnt) + ($i0<<2)|0);
   HEAPF32[$231>>2] = $230;
   $232 = Math_fround(HEAPF32[$2>>2]);
   HEAPF32[$0>>2] = $232;
   $233 = Math_fround(HEAPF32[$8>>2]);
   $234 = Math_fround(-$233);
   HEAPF32[$6>>2] = $234;
   STACKTOP = sp;return;
  } else {
   $184 = Math_fround($179 / $173);
   $185 = Math_fround($17 * $17);
   $186 = Math_fround($185 + $173);
   $187 = Math_fround($14 - $184);
   $188 = Math_fround($17 * $187);
   $189 = Math_fround($175 + $188);
   $190 = Math_fround($176 + $189);
   $191 = Math_fround(-$190);
   $192 = Math_fround($191 / $186);
   $193 = Math_fround($19 * $19);
   $194 = Math_fround($187 * $187);
   $195 = Math_fround($193 + $194);
   $196 = Math_fround($10 * $10);
   $197 = Math_fround($196 + $195);
   $198 = Math_fround($192 * $190);
   $199 = Math_fround($197 + $198);
   $200 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
   $201 = Math_fround($200 + $199);
   HEAPF32[$rfSqrDistance>>2] = $201;
   $202 = ($pfLParam|0)==(0|0);
   if ($202) {
    STACKTOP = sp;return;
   }
   HEAPF32[$pfLParam>>2] = $192;
   $203 = (($extents) + ($i0<<2)|0);
   $204 = Math_fround(HEAPF32[$203>>2]);
   $205 = (($rkPnt) + ($i0<<2)|0);
   HEAPF32[$205>>2] = $204;
   $206 = Math_fround(HEAPF32[$2>>2]);
   $207 = Math_fround($184 - $206);
   HEAPF32[$0>>2] = $207;
   $208 = Math_fround(HEAPF32[$8>>2]);
   $209 = Math_fround(-$208);
   HEAPF32[$6>>2] = $209;
   STACKTOP = sp;return;
  }
 }
 $235 = Math_fround($17 * $17);
 $236 = Math_fround($111 + $235);
 $237 = Math_fround($10 * $236);
 $238 = Math_fround($14 * $17);
 $239 = Math_fround($238 + $175);
 $240 = Math_fround($24 * $239);
 $241 = Math_fround($237 - $240);
 $242 = !($241 >= Math_fround(0.0));
 if ($242) {
  $293 = Math_fround($236 + $172);
  $294 = Math_fround($239 + $176);
  $295 = Math_fround(-$294);
  $296 = Math_fround($295 / $293);
  $297 = Math_fround($19 * $19);
  $298 = Math_fround($14 * $14);
  $299 = Math_fround($298 + $297);
  $300 = Math_fround($10 * $10);
  $301 = Math_fround($300 + $299);
  $302 = Math_fround($294 * $296);
  $303 = Math_fround($301 + $302);
  $304 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
  $305 = Math_fround($304 + $303);
  HEAPF32[$rfSqrDistance>>2] = $305;
  $306 = ($pfLParam|0)==(0|0);
  if ($306) {
   STACKTOP = sp;return;
  }
  HEAPF32[$pfLParam>>2] = $296;
  $307 = (($extents) + ($i0<<2)|0);
  $308 = Math_fround(HEAPF32[$307>>2]);
  $309 = (($rkPnt) + ($i0<<2)|0);
  HEAPF32[$309>>2] = $308;
  $310 = Math_fround(HEAPF32[$2>>2]);
  $311 = Math_fround(-$310);
  HEAPF32[$0>>2] = $311;
  $312 = Math_fround(HEAPF32[$8>>2]);
  $313 = Math_fround(-$312);
  HEAPF32[$6>>2] = $313;
  STACKTOP = sp;return;
 }
 $243 = Math_fround($236 * Math_fround(2.0));
 $244 = Math_fround($243 * $9);
 $245 = !($241 <= $244);
 if ($245) {
  $270 = Math_fround($236 + $172);
  $271 = (($rkPmE) + ($i2<<2)|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = Math_fround($24 * $272);
  $274 = Math_fround($239 + $273);
  $275 = Math_fround(-$274);
  $276 = Math_fround($275 / $270);
  $277 = Math_fround($19 * $19);
  $278 = Math_fround($14 * $14);
  $279 = Math_fround($278 + $277);
  $280 = Math_fround($272 * $272);
  $281 = Math_fround($279 + $280);
  $282 = Math_fround($276 * $274);
  $283 = Math_fround($281 + $282);
  $284 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
  $285 = Math_fround($284 + $283);
  HEAPF32[$rfSqrDistance>>2] = $285;
  $286 = ($pfLParam|0)==(0|0);
  if ($286) {
   STACKTOP = sp;return;
  }
  HEAPF32[$pfLParam>>2] = $276;
  $287 = (($extents) + ($i0<<2)|0);
  $288 = Math_fround(HEAPF32[$287>>2]);
  $289 = (($rkPnt) + ($i0<<2)|0);
  HEAPF32[$289>>2] = $288;
  $290 = Math_fround(HEAPF32[$2>>2]);
  $291 = Math_fround(-$290);
  HEAPF32[$0>>2] = $291;
  $292 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$6>>2] = $292;
  STACKTOP = sp;return;
 } else {
  $246 = Math_fround($241 / $236);
  $247 = Math_fround($236 + $172);
  $248 = Math_fround($10 - $246);
  $249 = Math_fround($24 * $248);
  $250 = Math_fround($239 + $249);
  $251 = Math_fround(-$250);
  $252 = Math_fround($251 / $247);
  $253 = Math_fround($19 * $19);
  $254 = Math_fround($14 * $14);
  $255 = Math_fround($254 + $253);
  $256 = Math_fround($248 * $248);
  $257 = Math_fround($255 + $256);
  $258 = Math_fround($252 * $250);
  $259 = Math_fround($257 + $258);
  $260 = Math_fround(HEAPF32[$rfSqrDistance>>2]);
  $261 = Math_fround($260 + $259);
  HEAPF32[$rfSqrDistance>>2] = $261;
  $262 = ($pfLParam|0)==(0|0);
  if ($262) {
   STACKTOP = sp;return;
  }
  HEAPF32[$pfLParam>>2] = $252;
  $263 = (($extents) + ($i0<<2)|0);
  $264 = Math_fround(HEAPF32[$263>>2]);
  $265 = (($rkPnt) + ($i0<<2)|0);
  HEAPF32[$265>>2] = $264;
  $266 = Math_fround(HEAPF32[$2>>2]);
  $267 = Math_fround(-$266);
  HEAPF32[$0>>2] = $267;
  $268 = Math_fround(HEAPF32[$8>>2]);
  $269 = Math_fround($246 - $268);
  HEAPF32[$6>>2] = $269;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin0,$extent0,$origin1,$extent1,$s,$t) {
 $origin0 = $origin0|0;
 $extent0 = $extent0|0;
 $origin1 = $origin1|0;
 $extent1 = $extent1|0;
 $s = $s|0;
 $t = $t|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = 0, $296 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fS$0 = Math_fround(0), $fSqrDist$0 = Math_fround(0), $fT$0 = Math_fround(0);
 var $fabsf$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$origin0>>2]);
 $1 = Math_fround(HEAPF32[$origin1>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($origin0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($origin1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($origin0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($origin1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$extent0>>2]);
 $14 = Math_fround($13 * $13);
 $15 = (($extent0) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($extent0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $20);
 $22 = Math_fround($18 + $21);
 $23 = Math_fround(HEAPF32[$extent1>>2]);
 $24 = Math_fround($13 * $23);
 $25 = (($extent1) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($16 * $26);
 $28 = Math_fround($24 + $27);
 $29 = (($extent1) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($20 * $30);
 $32 = Math_fround($28 + $31);
 $33 = Math_fround(-$32);
 $34 = Math_fround($23 * $23);
 $35 = Math_fround($26 * $26);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($30 * $30);
 $38 = Math_fround($36 + $37);
 $39 = Math_fround($2 * $13);
 $40 = Math_fround($7 * $16);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($12 * $20);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($2 * $2);
 $45 = Math_fround($7 * $7);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($12 * $12);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($22 * $38);
 $50 = Math_fround($32 * $32);
 $51 = Math_fround($49 - $50);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($51)))));
 $52 = !($fabsf$i$i >= Math_fround(0.00999999977648258209228));
 do {
  if ($52) {
   $237 = $32 < Math_fround(-0.0);
   if ($237) {
    $238 = !($43 >= Math_fround(0.0));
    if (!($238)) {
     $fS$0 = Math_fround(0.0);$fSqrDist$0 = $48;$fT$0 = Math_fround(0.0);
     break;
    }
    $239 = Math_fround(-$43);
    $240 = !($22 >= $239);
    if (!($240)) {
     $241 = Math_fround($239 / $22);
     $242 = Math_fround($43 * $241);
     $243 = Math_fround($48 + $242);
     $fS$0 = $241;$fSqrDist$0 = $243;$fT$0 = Math_fround(0.0);
     break;
    }
    $244 = Math_fround($2 * $23);
    $245 = Math_fround($7 * $26);
    $246 = Math_fround($244 + $245);
    $247 = Math_fround($12 * $30);
    $248 = Math_fround($246 + $247);
    $249 = Math_fround($22 + $43);
    $250 = !($249 <= $32);
    if ($250) {
     $257 = Math_fround(-$248);
     $258 = Math_fround(-$249);
     $259 = Math_fround($258 / $33);
     $260 = Math_fround($43 * Math_fround(2.0));
     $261 = Math_fround($22 + $260);
     $262 = Math_fround($48 + $261);
     $263 = Math_fround($38 * $259);
     $264 = Math_fround($257 - $32);
     $265 = Math_fround($264 * Math_fround(2.0));
     $266 = Math_fround($265 + $263);
     $267 = Math_fround($259 * $266);
     $268 = Math_fround($262 + $267);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $268;$fT$0 = $259;
     break;
    } else {
     $251 = Math_fround($22 + $38);
     $252 = Math_fround($48 + $251);
     $253 = Math_fround($43 - $32);
     $254 = Math_fround($253 - $248);
     $255 = Math_fround($254 * Math_fround(2.0));
     $256 = Math_fround($252 + $255);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $256;$fT$0 = Math_fround(1.0);
     break;
    }
   }
   $269 = Math_fround(-$43);
   $270 = !($22 <= $269);
   if (!($270)) {
    $271 = Math_fround($43 * Math_fround(2.0));
    $272 = Math_fround($22 + $271);
    $273 = Math_fround($48 + $272);
    $fS$0 = Math_fround(1.0);$fSqrDist$0 = $273;$fT$0 = Math_fround(0.0);
    break;
   }
   $274 = !($43 <= Math_fround(0.0));
   if (!($274)) {
    $275 = Math_fround($269 / $22);
    $276 = Math_fround($43 * $275);
    $277 = Math_fround($48 + $276);
    $fS$0 = $275;$fSqrDist$0 = $277;$fT$0 = Math_fround(0.0);
    break;
   }
   $278 = Math_fround($2 * $23);
   $279 = Math_fround($7 * $26);
   $280 = Math_fround($278 + $279);
   $281 = Math_fround($12 * $30);
   $282 = Math_fround($280 + $281);
   $283 = !($43 >= $32);
   if ($283) {
    $287 = Math_fround($269 / $33);
    $288 = Math_fround($282 * Math_fround(-2.0));
    $289 = Math_fround($38 * $287);
    $290 = Math_fround($288 + $289);
    $291 = Math_fround($287 * $290);
    $292 = Math_fround($48 + $291);
    $fS$0 = Math_fround(0.0);$fSqrDist$0 = $292;$fT$0 = $287;
    break;
   } else {
    $284 = Math_fround($282 * Math_fround(-2.0));
    $285 = Math_fround($38 + $284);
    $286 = Math_fround($48 + $285);
    $fS$0 = Math_fround(0.0);$fSqrDist$0 = $286;$fT$0 = Math_fround(1.0);
    break;
   }
  } else {
   $53 = Math_fround($2 * $23);
   $54 = Math_fround($7 * $26);
   $55 = Math_fround($53 + $54);
   $56 = Math_fround($12 * $30);
   $57 = Math_fround($55 + $56);
   $58 = Math_fround(-$57);
   $59 = Math_fround($32 * $57);
   $60 = Math_fround($43 * $38);
   $61 = Math_fround($59 - $60);
   $62 = Math_fround($43 * $33);
   $63 = Math_fround($22 * $58);
   $64 = Math_fround($62 - $63);
   $65 = !($61 >= Math_fround(0.0));
   if ($65) {
    $187 = !($64 >= Math_fround(0.0));
    if ($187) {
     $220 = $43 < Math_fround(0.0);
     if ($220) {
      $221 = Math_fround(-$43);
      $222 = !($22 <= $221);
      if ($222) {
       $226 = Math_fround($221 / $22);
       $227 = Math_fround($43 * $226);
       $228 = Math_fround($48 + $227);
       $fS$0 = $226;$fSqrDist$0 = $228;$fT$0 = Math_fround(0.0);
       break;
      } else {
       $223 = Math_fround($43 * Math_fround(2.0));
       $224 = Math_fround($22 + $223);
       $225 = Math_fround($48 + $224);
       $fS$0 = Math_fround(1.0);$fSqrDist$0 = $225;$fT$0 = Math_fround(0.0);
       break;
      }
     }
     $229 = !($57 <= Math_fround(-0.0));
     if (!($229)) {
      $fS$0 = Math_fround(0.0);$fSqrDist$0 = $48;$fT$0 = Math_fround(0.0);
      break;
     }
     $230 = !($57 >= $38);
     if ($230) {
      $234 = Math_fround($57 / $38);
      $235 = Math_fround($234 * $58);
      $236 = Math_fround($48 + $235);
      $fS$0 = Math_fround(0.0);$fSqrDist$0 = $236;$fT$0 = $234;
      break;
     } else {
      $231 = Math_fround($57 * Math_fround(-2.0));
      $232 = Math_fround($38 + $231);
      $233 = Math_fround($48 + $232);
      $fS$0 = Math_fround(0.0);$fSqrDist$0 = $233;$fT$0 = Math_fround(1.0);
      break;
     }
    }
    $188 = !($64 <= $fabsf$i$i);
    if (!($188)) {
     $189 = !($57 <= Math_fround(-0.0));
     if (!($189)) {
      $fS$0 = Math_fround(0.0);$fSqrDist$0 = $48;$fT$0 = Math_fround(0.0);
      break;
     }
     $190 = !($57 >= $38);
     if ($190) {
      $194 = Math_fround($57 / $38);
      $195 = Math_fround($194 * $58);
      $196 = Math_fround($48 + $195);
      $fS$0 = Math_fround(0.0);$fSqrDist$0 = $196;$fT$0 = $194;
      break;
     } else {
      $191 = Math_fround($57 * Math_fround(-2.0));
      $192 = Math_fround($38 + $191);
      $193 = Math_fround($48 + $192);
      $fS$0 = Math_fround(0.0);$fSqrDist$0 = $193;$fT$0 = Math_fround(1.0);
      break;
     }
    }
    $197 = Math_fround($43 - $32);
    $198 = $197 < Math_fround(0.0);
    if ($198) {
     $199 = Math_fround(-$197);
     $200 = !($22 <= $199);
     if ($200) {
      $206 = Math_fround($199 / $22);
      $207 = Math_fround($197 * $206);
      $208 = Math_fround($38 + $207);
      $209 = Math_fround($57 * Math_fround(-2.0));
      $210 = Math_fround($209 + $208);
      $211 = Math_fround($48 + $210);
      $fS$0 = $206;$fSqrDist$0 = $211;$fT$0 = Math_fround(1.0);
      break;
     } else {
      $201 = Math_fround($22 + $38);
      $202 = Math_fround($48 + $201);
      $203 = Math_fround($197 - $57);
      $204 = Math_fround($203 * Math_fround(2.0));
      $205 = Math_fround($202 + $204);
      $fS$0 = Math_fround(1.0);$fSqrDist$0 = $205;$fT$0 = Math_fround(1.0);
      break;
     }
    }
    $212 = !($57 <= Math_fround(-0.0));
    if (!($212)) {
     $fS$0 = Math_fround(0.0);$fSqrDist$0 = $48;$fT$0 = Math_fround(0.0);
     break;
    }
    $213 = !($57 >= $38);
    if ($213) {
     $217 = Math_fround($57 / $38);
     $218 = Math_fround($217 * $58);
     $219 = Math_fround($48 + $218);
     $fS$0 = Math_fround(0.0);$fSqrDist$0 = $219;$fT$0 = $217;
     break;
    } else {
     $214 = Math_fround($57 * Math_fround(-2.0));
     $215 = Math_fround($38 + $214);
     $216 = Math_fround($48 + $215);
     $fS$0 = Math_fround(0.0);$fSqrDist$0 = $216;$fT$0 = Math_fround(1.0);
     break;
    }
   }
   $66 = !($61 <= $fabsf$i$i);
   $67 = !($64 >= Math_fround(0.0));
   if (!($66)) {
    if ($67) {
     $104 = !($43 >= Math_fround(0.0));
     if (!($104)) {
      $fS$0 = Math_fround(0.0);$fSqrDist$0 = $48;$fT$0 = Math_fround(0.0);
      break;
     }
     $105 = Math_fround(-$43);
     $106 = !($22 <= $105);
     if ($106) {
      $110 = Math_fround($105 / $22);
      $111 = Math_fround($43 * $110);
      $112 = Math_fround($48 + $111);
      $fS$0 = $110;$fSqrDist$0 = $112;$fT$0 = Math_fround(0.0);
      break;
     } else {
      $107 = Math_fround($43 * Math_fround(2.0));
      $108 = Math_fround($22 + $107);
      $109 = Math_fround($48 + $108);
      $fS$0 = Math_fround(1.0);$fSqrDist$0 = $109;$fT$0 = Math_fround(0.0);
      break;
     }
    }
    $68 = !($64 <= $fabsf$i$i);
    if (!($68)) {
     $69 = Math_fround(Math_fround(1.0) / $fabsf$i$i);
     $70 = Math_fround($61 * $69);
     $71 = Math_fround($64 * $69);
     $72 = Math_fround($22 * $70);
     $73 = Math_fround($71 * $33);
     $74 = Math_fround($72 + $73);
     $75 = Math_fround($43 * Math_fround(2.0));
     $76 = Math_fround($75 + $74);
     $77 = Math_fround($70 * $76);
     $78 = Math_fround($70 * $33);
     $79 = Math_fround($38 * $71);
     $80 = Math_fround($78 + $79);
     $81 = Math_fround($57 * Math_fround(-2.0));
     $82 = Math_fround($81 + $80);
     $83 = Math_fround($71 * $82);
     $84 = Math_fround($77 + $83);
     $85 = Math_fround($48 + $84);
     $fS$0 = $70;$fSqrDist$0 = $85;$fT$0 = $71;
     break;
    }
    $86 = Math_fround($43 - $32);
    $87 = !($86 >= Math_fround(0.0));
    if (!($87)) {
     $88 = Math_fround($57 * Math_fround(-2.0));
     $89 = Math_fround($38 + $88);
     $90 = Math_fround($48 + $89);
     $fS$0 = Math_fround(0.0);$fSqrDist$0 = $90;$fT$0 = Math_fround(1.0);
     break;
    }
    $91 = Math_fround(-$86);
    $92 = !($22 <= $91);
    if ($92) {
     $98 = Math_fround($91 / $22);
     $99 = Math_fround($86 * $98);
     $100 = Math_fround($38 + $99);
     $101 = Math_fround($57 * Math_fround(-2.0));
     $102 = Math_fround($101 + $100);
     $103 = Math_fround($48 + $102);
     $fS$0 = $98;$fSqrDist$0 = $103;$fT$0 = Math_fround(1.0);
     break;
    } else {
     $93 = Math_fround($22 + $38);
     $94 = Math_fround($48 + $93);
     $95 = Math_fround($86 - $57);
     $96 = Math_fround($95 * Math_fround(2.0));
     $97 = Math_fround($94 + $96);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $97;$fT$0 = Math_fround(1.0);
     break;
    }
   }
   if ($67) {
    $163 = Math_fround(-$43);
    $164 = $22 > $163;
    if ($164) {
     $165 = !($43 >= Math_fround(0.0));
     if (!($165)) {
      $fS$0 = Math_fround(0.0);$fSqrDist$0 = $48;$fT$0 = Math_fround(0.0);
      break;
     }
     $166 = Math_fround($163 / $22);
     $167 = Math_fround($43 * $166);
     $168 = Math_fround($48 + $167);
     $fS$0 = $166;$fSqrDist$0 = $168;$fT$0 = Math_fround(0.0);
     break;
    }
    $169 = Math_fround($58 - $32);
    $170 = !($169 >= Math_fround(0.0));
    if (!($170)) {
     $171 = Math_fround($43 * Math_fround(2.0));
     $172 = Math_fround($22 + $171);
     $173 = Math_fround($48 + $172);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $173;$fT$0 = Math_fround(0.0);
     break;
    }
    $174 = Math_fround(-$169);
    $175 = !($38 <= $174);
    if ($175) {
     $181 = Math_fround($174 / $38);
     $182 = Math_fround($169 * $181);
     $183 = Math_fround($22 + $182);
     $184 = Math_fround($43 * Math_fround(2.0));
     $185 = Math_fround($184 + $183);
     $186 = Math_fround($48 + $185);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $186;$fT$0 = $181;
     break;
    } else {
     $176 = Math_fround($22 + $38);
     $177 = Math_fround($48 + $176);
     $178 = Math_fround($43 + $169);
     $179 = Math_fround($178 * Math_fround(2.0));
     $180 = Math_fround($177 + $179);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $180;$fT$0 = Math_fround(1.0);
     break;
    }
   }
   $113 = !($64 <= $fabsf$i$i);
   if (!($113)) {
    $114 = Math_fround($58 - $32);
    $115 = !($114 >= Math_fround(0.0));
    if (!($115)) {
     $116 = Math_fround($43 * Math_fround(2.0));
     $117 = Math_fround($22 + $116);
     $118 = Math_fround($48 + $117);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $118;$fT$0 = Math_fround(0.0);
     break;
    }
    $119 = Math_fround(-$114);
    $120 = !($38 <= $119);
    if ($120) {
     $126 = Math_fround($119 / $38);
     $127 = Math_fround($114 * $126);
     $128 = Math_fround($22 + $127);
     $129 = Math_fround($43 * Math_fround(2.0));
     $130 = Math_fround($129 + $128);
     $131 = Math_fround($48 + $130);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $131;$fT$0 = $126;
     break;
    } else {
     $121 = Math_fround($22 + $38);
     $122 = Math_fround($48 + $121);
     $123 = Math_fround($43 + $114);
     $124 = Math_fround($123 * Math_fround(2.0));
     $125 = Math_fround($122 + $124);
     $fS$0 = Math_fround(1.0);$fSqrDist$0 = $125;$fT$0 = Math_fround(1.0);
     break;
    }
   }
   $132 = Math_fround($43 - $32);
   $133 = Math_fround(-$132);
   $134 = !($22 >= $133);
   if (!($134)) {
    $135 = !($132 >= Math_fround(0.0));
    if ($135) {
     $139 = Math_fround($133 / $22);
     $140 = Math_fround($132 * $139);
     $141 = Math_fround($38 + $140);
     $142 = Math_fround($57 * Math_fround(-2.0));
     $143 = Math_fround($142 + $141);
     $144 = Math_fround($48 + $143);
     $fS$0 = $139;$fSqrDist$0 = $144;$fT$0 = Math_fround(1.0);
     break;
    } else {
     $136 = Math_fround($57 * Math_fround(-2.0));
     $137 = Math_fround($38 + $136);
     $138 = Math_fround($48 + $137);
     $fS$0 = Math_fround(0.0);$fSqrDist$0 = $138;$fT$0 = Math_fround(1.0);
     break;
    }
   }
   $145 = Math_fround($58 - $32);
   $146 = !($145 >= Math_fround(0.0));
   if (!($146)) {
    $147 = Math_fround($43 * Math_fround(2.0));
    $148 = Math_fround($22 + $147);
    $149 = Math_fround($48 + $148);
    $fS$0 = Math_fround(1.0);$fSqrDist$0 = $149;$fT$0 = Math_fround(0.0);
    break;
   }
   $150 = Math_fround(-$145);
   $151 = !($38 <= $150);
   if ($151) {
    $157 = Math_fround($150 / $38);
    $158 = Math_fround($145 * $157);
    $159 = Math_fround($22 + $158);
    $160 = Math_fround($43 * Math_fround(2.0));
    $161 = Math_fround($160 + $159);
    $162 = Math_fround($48 + $161);
    $fS$0 = Math_fround(1.0);$fSqrDist$0 = $162;$fT$0 = $157;
    break;
   } else {
    $152 = Math_fround($22 + $38);
    $153 = Math_fround($48 + $152);
    $154 = Math_fround($43 + $145);
    $155 = Math_fround($154 * Math_fround(2.0));
    $156 = Math_fround($153 + $155);
    $fS$0 = Math_fround(1.0);$fSqrDist$0 = $156;$fT$0 = Math_fround(1.0);
    break;
   }
  }
 } while(0);
 $293 = ($s|0)==(0|0);
 if (!($293)) {
  HEAPF32[$s>>2] = $fS$0;
 }
 $294 = ($t|0)==(0|0);
 if ($294) {
  $295 = $fSqrDist$0 < Math_fround(0.0);
  $296 = $295 ? Math_fround(0.0) : $fSqrDist$0;
  STACKTOP = sp;return (Math_fround($296));
 }
 HEAPF32[$t>>2] = $fT$0;
 $295 = $fSqrDist$0 < Math_fround(0.0);
 $296 = $295 ? Math_fround(0.0) : $fSqrDist$0;
 STACKTOP = sp;return (Math_fround($296));
}
function __ZN5physx2Gu30distanceSegmentSegmentSquared2ERKNS0_7SegmentES3_PfS4_($segment0,$segment1,$param0,$param1) {
 $segment0 = $segment0|0;
 $segment1 = $segment1|0;
 $param0 = $param0|0;
 $param1 = $param1|0;
 var $$pn$i = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0;
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0;
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0;
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0;
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fLambda$0$i = Math_fround(0), $fS0$0$i = Math_fround(0), $fS1$0$i = Math_fround(0), $fSqrDist$0$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $length0$0 = Math_fround(0), $length1$0 = Math_fround(0), $oneOverLength0$0 = Math_fround(0), $oneOverLength1$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$segment0>>2]);
 $1 = (($segment0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($segment0) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$segment1>>2]);
 $6 = (($segment1) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($segment1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($segment0) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 - $0);
 $13 = (($segment0) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 - $2);
 $16 = (($segment0) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 - $4);
 $19 = (($segment1) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 - $5);
 $22 = (($segment1) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 - $7);
 $25 = (($segment1) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 - $9);
 $28 = Math_fround($12 * Math_fround(0.5));
 $29 = Math_fround($15 * Math_fround(0.5));
 $30 = Math_fround($18 * Math_fround(0.5));
 $31 = Math_fround($0 + $28);
 $32 = Math_fround($2 + $29);
 $33 = Math_fround($4 + $30);
 $34 = Math_fround($12 * $12);
 $35 = Math_fround($15 * $15);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($18 * $18);
 $38 = Math_fround($36 + $37);
 $39 = (Math_fround(Math_sqrt((Math_fround($38)))));
 $40 = $39 != Math_fround(0.0);
 if ($40) {
  $41 = Math_fround(Math_fround(1.0) / $39);
  $42 = Math_fround($12 * $41);
  $43 = Math_fround($15 * $41);
  $44 = Math_fround($18 * $41);
  $45 = Math_fround($39 * Math_fround(0.5));
  $69 = $42;$72 = $43;$76 = $44;$length0$0 = $45;$oneOverLength0$0 = $41;
 } else {
  $69 = $12;$72 = $15;$76 = $18;$length0$0 = $39;$oneOverLength0$0 = Math_fround(0.0);
 }
 $46 = Math_fround($21 * Math_fround(0.5));
 $47 = Math_fround($24 * Math_fround(0.5));
 $48 = Math_fround($27 * Math_fround(0.5));
 $49 = Math_fround($5 + $46);
 $50 = Math_fround($7 + $47);
 $51 = Math_fround($9 + $48);
 $52 = Math_fround($21 * $21);
 $53 = Math_fround($24 * $24);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($27 * $27);
 $56 = Math_fround($54 + $55);
 $57 = (Math_fround(Math_sqrt((Math_fround($56)))));
 $58 = $57 != Math_fround(0.0);
 if ($58) {
  $59 = Math_fround(Math_fround(1.0) / $57);
  $60 = Math_fround($21 * $59);
  $61 = Math_fround($24 * $59);
  $62 = Math_fround($27 * $59);
  $63 = Math_fround($57 * Math_fround(0.5));
  $68 = $60;$71 = $61;$75 = $62;$length1$0 = $63;$oneOverLength1$0 = $59;
 } else {
  $68 = $21;$71 = $24;$75 = $27;$length1$0 = $57;$oneOverLength1$0 = Math_fround(0.0);
 }
 $64 = Math_fround($31 - $49);
 $65 = Math_fround($32 - $50);
 $66 = Math_fround($33 - $51);
 $67 = Math_fround($69 * $68);
 $70 = Math_fround($72 * $71);
 $73 = Math_fround($70 + $67);
 $74 = Math_fround($76 * $75);
 $77 = Math_fround($74 + $73);
 $78 = Math_fround(-$77);
 $79 = Math_fround($64 * $69);
 $80 = Math_fround($65 * $72);
 $81 = Math_fround($80 + $79);
 $82 = Math_fround($66 * $76);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($64 * $68);
 $85 = Math_fround($65 * $71);
 $86 = Math_fround($85 + $84);
 $87 = Math_fround($66 * $75);
 $88 = Math_fround($87 + $86);
 $89 = Math_fround($64 * $64);
 $90 = Math_fround($65 * $65);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($66 * $66);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($77 * $77);
 $95 = Math_fround(Math_fround(1.0) - $94);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($95)))));
 $96 = !($fabsf$i$i$i >= Math_fround(9.99999997475242707878E-7));
 do {
  if ($96) {
   $401 = Math_fround($length0$0 + $length1$0);
   $402 = $77 < Math_fround(-0.0);
   $403 = $402 ? Math_fround(-1.0) : Math_fround(1.0);
   $404 = Math_fround(-$83);
   $405 = $83 > $401;
   if ($405) {
    $406 = Math_fround(-$401);
    $fLambda$0$i = $406;
   } else {
    $407 = $401 < $404;
    if ($407) {
     $fLambda$0$i = $401;
    } else {
     $fLambda$0$i = $404;
    }
   }
   $408 = Math_fround($83 * $403);
   $409 = Math_fround($length1$0 * $408);
   $410 = Math_fround($409 / $401);
   $411 = Math_fround($403 * $410);
   $412 = Math_fround($fLambda$0$i + $411);
   $413 = Math_fround($83 * Math_fround(2.0));
   $414 = Math_fround($413 + $fLambda$0$i);
   $415 = Math_fround($fLambda$0$i * $414);
   $$pn$i = $415;$fS0$0$i = $412;$fS1$0$i = $410;
  } else {
   $97 = Math_fround($77 * $88);
   $98 = Math_fround($97 - $83);
   $99 = Math_fround($83 * $78);
   $100 = Math_fround($88 + $99);
   $101 = Math_fround($length0$0 * $fabsf$i$i$i);
   $102 = Math_fround($length1$0 * $fabsf$i$i$i);
   $103 = Math_fround(-$101);
   $104 = !($98 >= $103);
   if ($104) {
    $286 = Math_fround(-$102);
    $287 = !($100 >= $286);
    if ($287) {
     $358 = Math_fround(-$length1$0);
     $359 = Math_fround($length1$0 * $77);
     $360 = Math_fround($83 + $359);
     $361 = Math_fround(-$360);
     $362 = $length0$0 < $361;
     if ($362) {
      $363 = Math_fround($360 * Math_fround(-2.0));
      $364 = Math_fround($length0$0 - $363);
      $365 = Math_fround($length0$0 * $364);
      $366 = Math_fround($88 * Math_fround(-2.0));
      $367 = Math_fround($366 - $length1$0);
      $368 = Math_fround($367 * $358);
      $369 = Math_fround($368 + $365);
      $$pn$i = $369;$fS0$0$i = $length0$0;$fS1$0$i = $358;
      break;
     }
     $370 = Math_fround(-$length0$0);
     $371 = !($360 <= $length0$0);
     if (!($371)) {
      $372 = Math_fround($360 * $361);
      $373 = Math_fround($88 * Math_fround(-2.0));
      $374 = Math_fround($373 - $length1$0);
      $375 = Math_fround($374 * $358);
      $376 = Math_fround($375 + $372);
      $$pn$i = $376;$fS0$0$i = $361;$fS1$0$i = $358;
      break;
     }
     $377 = Math_fround($length0$0 * $77);
     $378 = Math_fround($377 - $88);
     $379 = Math_fround(-$378);
     $380 = $378 > $length1$0;
     if ($380) {
      $381 = Math_fround($378 * Math_fround(-2.0));
      $382 = Math_fround($358 - $381);
      $383 = Math_fround($382 * $358);
      $384 = Math_fround($83 * Math_fround(2.0));
      $385 = Math_fround($384 - $length0$0);
      $386 = Math_fround($385 * $370);
      $387 = Math_fround($386 + $383);
      $$pn$i = $387;$fS0$0$i = $370;$fS1$0$i = $358;
      break;
     }
     $388 = !($length1$0 >= $379);
     if ($388) {
      $394 = Math_fround($378 * Math_fround(-2.0));
      $395 = Math_fround($length1$0 - $394);
      $396 = Math_fround($length1$0 * $395);
      $397 = Math_fround($83 * Math_fround(2.0));
      $398 = Math_fround($397 - $length0$0);
      $399 = Math_fround($398 * $370);
      $400 = Math_fround($399 + $396);
      $$pn$i = $400;$fS0$0$i = $370;$fS1$0$i = $length1$0;
      break;
     } else {
      $389 = Math_fround($378 * $379);
      $390 = Math_fround($83 * Math_fround(2.0));
      $391 = Math_fround($390 - $length0$0);
      $392 = Math_fround($391 * $370);
      $393 = Math_fround($392 + $389);
      $$pn$i = $393;$fS0$0$i = $370;$fS1$0$i = $379;
      break;
     }
    }
    $288 = !($100 <= $102);
    if (!($288)) {
     $289 = Math_fround(-$length0$0);
     $290 = Math_fround($length0$0 * $77);
     $291 = Math_fround($290 - $88);
     $292 = Math_fround(-$291);
     $293 = Math_fround(-$length1$0);
     $294 = $291 > $length1$0;
     if ($294) {
      $295 = Math_fround($291 * Math_fround(-2.0));
      $296 = Math_fround($293 - $295);
      $297 = Math_fround($296 * $293);
      $298 = Math_fround($83 * Math_fround(2.0));
      $299 = Math_fround($298 - $length0$0);
      $300 = Math_fround($299 * $289);
      $301 = Math_fround($300 + $297);
      $$pn$i = $301;$fS0$0$i = $289;$fS1$0$i = $293;
      break;
     }
     $302 = !($length1$0 >= $292);
     if ($302) {
      $308 = Math_fround($291 * Math_fround(-2.0));
      $309 = Math_fround($length1$0 - $308);
      $310 = Math_fround($length1$0 * $309);
      $311 = Math_fround($83 * Math_fround(2.0));
      $312 = Math_fround($311 - $length0$0);
      $313 = Math_fround($312 * $289);
      $314 = Math_fround($313 + $310);
      $$pn$i = $314;$fS0$0$i = $289;$fS1$0$i = $length1$0;
      break;
     } else {
      $303 = Math_fround($291 * $292);
      $304 = Math_fround($83 * Math_fround(2.0));
      $305 = Math_fround($304 - $length0$0);
      $306 = Math_fround($305 * $289);
      $307 = Math_fround($306 + $303);
      $$pn$i = $307;$fS0$0$i = $289;$fS1$0$i = $292;
      break;
     }
    }
    $315 = Math_fround($length1$0 * $78);
    $316 = Math_fround($83 + $315);
    $317 = Math_fround(-$316);
    $318 = $length0$0 < $317;
    if ($318) {
     $319 = Math_fround($316 * Math_fround(-2.0));
     $320 = Math_fround($length0$0 - $319);
     $321 = Math_fround($length0$0 * $320);
     $322 = Math_fround($88 * Math_fround(-2.0));
     $323 = Math_fround($length1$0 + $322);
     $324 = Math_fround($length1$0 * $323);
     $325 = Math_fround($324 + $321);
     $$pn$i = $325;$fS0$0$i = $length0$0;$fS1$0$i = $length1$0;
     break;
    }
    $326 = Math_fround(-$length0$0);
    $327 = !($316 <= $length0$0);
    if (!($327)) {
     $328 = Math_fround($316 * $317);
     $329 = Math_fround($88 * Math_fround(-2.0));
     $330 = Math_fround($length1$0 + $329);
     $331 = Math_fround($length1$0 * $330);
     $332 = Math_fround($331 + $328);
     $$pn$i = $332;$fS0$0$i = $317;$fS1$0$i = $length1$0;
     break;
    }
    $333 = Math_fround($length0$0 * $77);
    $334 = Math_fround($333 - $88);
    $335 = Math_fround(-$334);
    $336 = Math_fround(-$length1$0);
    $337 = $334 > $length1$0;
    if ($337) {
     $338 = Math_fround($334 * Math_fround(-2.0));
     $339 = Math_fround($336 - $338);
     $340 = Math_fround($339 * $336);
     $341 = Math_fround($83 * Math_fround(2.0));
     $342 = Math_fround($341 - $length0$0);
     $343 = Math_fround($342 * $326);
     $344 = Math_fround($343 + $340);
     $$pn$i = $344;$fS0$0$i = $326;$fS1$0$i = $336;
     break;
    }
    $345 = !($length1$0 >= $335);
    if ($345) {
     $351 = Math_fround($334 * Math_fround(-2.0));
     $352 = Math_fround($length1$0 - $351);
     $353 = Math_fround($length1$0 * $352);
     $354 = Math_fround($83 * Math_fround(2.0));
     $355 = Math_fround($354 - $length0$0);
     $356 = Math_fround($355 * $326);
     $357 = Math_fround($356 + $353);
     $$pn$i = $357;$fS0$0$i = $326;$fS1$0$i = $length1$0;
     break;
    } else {
     $346 = Math_fround($334 * $335);
     $347 = Math_fround($83 * Math_fround(2.0));
     $348 = Math_fround($347 - $length0$0);
     $349 = Math_fround($348 * $326);
     $350 = Math_fround($349 + $346);
     $$pn$i = $350;$fS0$0$i = $326;$fS1$0$i = $335;
     break;
    }
   }
   $105 = !($98 <= $101);
   $106 = Math_fround(-$102);
   $107 = $100 >= $106;
   if (!($105)) {
    if (!($107)) {
     $148 = Math_fround(-$length1$0);
     $149 = Math_fround($length1$0 * $77);
     $150 = Math_fround($83 + $149);
     $151 = Math_fround(-$150);
     $152 = Math_fround(-$length0$0);
     $153 = $150 > $length0$0;
     if ($153) {
      $154 = Math_fround($150 * Math_fround(-2.0));
      $155 = Math_fround($152 - $154);
      $156 = Math_fround($155 * $152);
      $157 = Math_fround($88 * Math_fround(-2.0));
      $158 = Math_fround($157 - $length1$0);
      $159 = Math_fround($158 * $148);
      $160 = Math_fround($159 + $156);
      $$pn$i = $160;$fS0$0$i = $152;$fS1$0$i = $148;
      break;
     }
     $161 = !($length0$0 >= $151);
     if ($161) {
      $167 = Math_fround($150 * Math_fround(-2.0));
      $168 = Math_fround($length0$0 - $167);
      $169 = Math_fround($length0$0 * $168);
      $170 = Math_fround($88 * Math_fround(-2.0));
      $171 = Math_fround($170 - $length1$0);
      $172 = Math_fround($171 * $148);
      $173 = Math_fround($172 + $169);
      $$pn$i = $173;$fS0$0$i = $length0$0;$fS1$0$i = $148;
      break;
     } else {
      $162 = Math_fround($150 * $151);
      $163 = Math_fround($88 * Math_fround(-2.0));
      $164 = Math_fround($163 - $length1$0);
      $165 = Math_fround($164 * $148);
      $166 = Math_fround($165 + $162);
      $$pn$i = $166;$fS0$0$i = $151;$fS1$0$i = $148;
      break;
     }
    }
    $108 = !($100 <= $102);
    if (!($108)) {
     $109 = Math_fround(Math_fround(1.0) / $fabsf$i$i$i);
     $110 = Math_fround($98 * $109);
     $111 = Math_fround($100 * $109);
     $112 = Math_fround($111 * $78);
     $113 = Math_fround($110 + $112);
     $114 = Math_fround($83 * Math_fround(2.0));
     $115 = Math_fround($114 + $113);
     $116 = Math_fround($110 * $115);
     $117 = Math_fround($110 * $78);
     $118 = Math_fround($111 + $117);
     $119 = Math_fround($88 * Math_fround(-2.0));
     $120 = Math_fround($119 + $118);
     $121 = Math_fround($111 * $120);
     $122 = Math_fround($116 + $121);
     $$pn$i = $122;$fS0$0$i = $110;$fS1$0$i = $111;
     break;
    }
    $123 = Math_fround($length1$0 * $78);
    $124 = Math_fround($83 + $123);
    $125 = Math_fround(-$124);
    $126 = Math_fround(-$length0$0);
    $127 = $124 > $length0$0;
    if ($127) {
     $128 = Math_fround($124 * Math_fround(-2.0));
     $129 = Math_fround($126 - $128);
     $130 = Math_fround($129 * $126);
     $131 = Math_fround($88 * Math_fround(-2.0));
     $132 = Math_fround($length1$0 + $131);
     $133 = Math_fround($length1$0 * $132);
     $134 = Math_fround($133 + $130);
     $$pn$i = $134;$fS0$0$i = $126;$fS1$0$i = $length1$0;
     break;
    }
    $135 = !($length0$0 >= $125);
    if ($135) {
     $141 = Math_fround($124 * Math_fround(-2.0));
     $142 = Math_fround($length0$0 - $141);
     $143 = Math_fround($length0$0 * $142);
     $144 = Math_fround($88 * Math_fround(-2.0));
     $145 = Math_fround($length1$0 + $144);
     $146 = Math_fround($length1$0 * $145);
     $147 = Math_fround($146 + $143);
     $$pn$i = $147;$fS0$0$i = $length0$0;$fS1$0$i = $length1$0;
     break;
    } else {
     $136 = Math_fround($124 * $125);
     $137 = Math_fround($88 * Math_fround(-2.0));
     $138 = Math_fround($length1$0 + $137);
     $139 = Math_fround($length1$0 * $138);
     $140 = Math_fround($139 + $136);
     $$pn$i = $140;$fS0$0$i = $125;$fS1$0$i = $length1$0;
     break;
    }
   }
   if (!($107)) {
    $243 = Math_fround(-$length1$0);
    $244 = Math_fround($length1$0 * $77);
    $245 = Math_fround($83 + $244);
    $246 = Math_fround(-$245);
    $247 = Math_fround(-$length0$0);
    $248 = $245 > $length0$0;
    if ($248) {
     $249 = Math_fround($245 * Math_fround(-2.0));
     $250 = Math_fround($247 - $249);
     $251 = Math_fround($250 * $247);
     $252 = Math_fround($88 * Math_fround(-2.0));
     $253 = Math_fround($252 - $length1$0);
     $254 = Math_fround($253 * $243);
     $255 = Math_fround($254 + $251);
     $$pn$i = $255;$fS0$0$i = $247;$fS1$0$i = $243;
     break;
    }
    $256 = !($length0$0 >= $246);
    if (!($256)) {
     $257 = Math_fround($245 * $246);
     $258 = Math_fround($88 * Math_fround(-2.0));
     $259 = Math_fround($258 - $length1$0);
     $260 = Math_fround($259 * $243);
     $261 = Math_fround($260 + $257);
     $$pn$i = $261;$fS0$0$i = $246;$fS1$0$i = $243;
     break;
    }
    $262 = Math_fround($length0$0 * $78);
    $263 = Math_fround($262 - $88);
    $264 = Math_fround(-$263);
    $265 = $length1$0 < $264;
    if ($265) {
     $266 = Math_fround($263 * Math_fround(-2.0));
     $267 = Math_fround($length1$0 - $266);
     $268 = Math_fround($length1$0 * $267);
     $269 = Math_fround($83 * Math_fround(2.0));
     $270 = Math_fround($length0$0 + $269);
     $271 = Math_fround($length0$0 * $270);
     $272 = Math_fround($271 + $268);
     $$pn$i = $272;$fS0$0$i = $length0$0;$fS1$0$i = $length1$0;
     break;
    }
    $273 = !($263 <= $length1$0);
    if ($273) {
     $279 = Math_fround($263 * Math_fround(-2.0));
     $280 = Math_fround($243 - $279);
     $281 = Math_fround($280 * $243);
     $282 = Math_fround($83 * Math_fround(2.0));
     $283 = Math_fround($length0$0 + $282);
     $284 = Math_fround($length0$0 * $283);
     $285 = Math_fround($284 + $281);
     $$pn$i = $285;$fS0$0$i = $length0$0;$fS1$0$i = $243;
     break;
    } else {
     $274 = Math_fround($263 * $264);
     $275 = Math_fround($83 * Math_fround(2.0));
     $276 = Math_fround($length0$0 + $275);
     $277 = Math_fround($length0$0 * $276);
     $278 = Math_fround($277 + $274);
     $$pn$i = $278;$fS0$0$i = $length0$0;$fS1$0$i = $264;
     break;
    }
   }
   $174 = !($100 <= $102);
   if (!($174)) {
    $175 = Math_fround($length0$0 * $78);
    $176 = Math_fround($175 - $88);
    $177 = Math_fround(-$176);
    $178 = Math_fround(-$length1$0);
    $179 = $176 > $length1$0;
    if ($179) {
     $180 = Math_fround($176 * Math_fround(-2.0));
     $181 = Math_fround($178 - $180);
     $182 = Math_fround($181 * $178);
     $183 = Math_fround($83 * Math_fround(2.0));
     $184 = Math_fround($length0$0 + $183);
     $185 = Math_fround($length0$0 * $184);
     $186 = Math_fround($185 + $182);
     $$pn$i = $186;$fS0$0$i = $length0$0;$fS1$0$i = $178;
     break;
    }
    $187 = !($length1$0 >= $177);
    if ($187) {
     $193 = Math_fround($176 * Math_fround(-2.0));
     $194 = Math_fround($length1$0 - $193);
     $195 = Math_fround($length1$0 * $194);
     $196 = Math_fround($83 * Math_fround(2.0));
     $197 = Math_fround($length0$0 + $196);
     $198 = Math_fround($length0$0 * $197);
     $199 = Math_fround($198 + $195);
     $$pn$i = $199;$fS0$0$i = $length0$0;$fS1$0$i = $length1$0;
     break;
    } else {
     $188 = Math_fround($176 * $177);
     $189 = Math_fround($83 * Math_fround(2.0));
     $190 = Math_fround($length0$0 + $189);
     $191 = Math_fround($length0$0 * $190);
     $192 = Math_fround($191 + $188);
     $$pn$i = $192;$fS0$0$i = $length0$0;$fS1$0$i = $177;
     break;
    }
   }
   $200 = Math_fround($length1$0 * $78);
   $201 = Math_fround($83 + $200);
   $202 = Math_fround(-$201);
   $203 = Math_fround(-$length0$0);
   $204 = $201 > $length0$0;
   if ($204) {
    $205 = Math_fround($201 * Math_fround(-2.0));
    $206 = Math_fround($203 - $205);
    $207 = Math_fround($206 * $203);
    $208 = Math_fround($88 * Math_fround(-2.0));
    $209 = Math_fround($length1$0 + $208);
    $210 = Math_fround($length1$0 * $209);
    $211 = Math_fround($210 + $207);
    $$pn$i = $211;$fS0$0$i = $203;$fS1$0$i = $length1$0;
    break;
   }
   $212 = !($length0$0 >= $202);
   if (!($212)) {
    $213 = Math_fround($201 * $202);
    $214 = Math_fround($88 * Math_fround(-2.0));
    $215 = Math_fround($length1$0 + $214);
    $216 = Math_fround($length1$0 * $215);
    $217 = Math_fround($216 + $213);
    $$pn$i = $217;$fS0$0$i = $202;$fS1$0$i = $length1$0;
    break;
   }
   $218 = Math_fround($length0$0 * $78);
   $219 = Math_fround($218 - $88);
   $220 = Math_fround(-$219);
   $221 = Math_fround(-$length1$0);
   $222 = $219 > $length1$0;
   if ($222) {
    $223 = Math_fround($219 * Math_fround(-2.0));
    $224 = Math_fround($221 - $223);
    $225 = Math_fround($224 * $221);
    $226 = Math_fround($83 * Math_fround(2.0));
    $227 = Math_fround($length0$0 + $226);
    $228 = Math_fround($length0$0 * $227);
    $229 = Math_fround($228 + $225);
    $$pn$i = $229;$fS0$0$i = $length0$0;$fS1$0$i = $221;
    break;
   }
   $230 = !($length1$0 >= $220);
   if ($230) {
    $236 = Math_fround($219 * Math_fround(-2.0));
    $237 = Math_fround($length1$0 - $236);
    $238 = Math_fround($length1$0 * $237);
    $239 = Math_fround($83 * Math_fround(2.0));
    $240 = Math_fround($length0$0 + $239);
    $241 = Math_fround($length0$0 * $240);
    $242 = Math_fround($241 + $238);
    $$pn$i = $242;$fS0$0$i = $length0$0;$fS1$0$i = $length1$0;
    break;
   } else {
    $231 = Math_fround($219 * $220);
    $232 = Math_fround($83 * Math_fround(2.0));
    $233 = Math_fround($length0$0 + $232);
    $234 = Math_fround($length0$0 * $233);
    $235 = Math_fround($234 + $231);
    $$pn$i = $235;$fS0$0$i = $length0$0;$fS1$0$i = $220;
    break;
   }
  }
 } while(0);
 $fSqrDist$0$i = Math_fround($93 + $$pn$i);
 $416 = ($param0|0)==(0|0);
 if (!($416)) {
  HEAPF32[$param0>>2] = $fS0$0$i;
 }
 $417 = ($param1|0)==(0|0);
 if (!($417)) {
  HEAPF32[$param1>>2] = $fS1$0$i;
 }
 $418 = $fSqrDist$0$i < Math_fround(0.0);
 $419 = $418 ? Math_fround(0.0) : $fSqrDist$0$i;
 if (!($416)) {
  if ($40) {
   $420 = Math_fround(HEAPF32[$param0>>2]);
   $421 = Math_fround($length0$0 + $420);
   $422 = Math_fround($oneOverLength0$0 * $421);
   $423 = $422;
  } else {
   $423 = Math_fround(0.0);
  }
  HEAPF32[$param0>>2] = $423;
 }
 if ($417) {
  STACKTOP = sp;return (Math_fround($419));
 }
 if ($58) {
  $424 = Math_fround(HEAPF32[$param1>>2]);
  $425 = Math_fround($length1$0 + $424);
  $426 = Math_fround($oneOverLength1$0 * $425);
  $427 = $426;
 } else {
  $427 = Math_fround(0.0);
 }
 HEAPF32[$param1>>2] = $427;
 STACKTOP = sp;return (Math_fround($419));
}
function __ZN5physx2Gu30distanceSegmentSegmentSquared4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_S5_S5_S5_S5_RNS2_5Vec4VES7_($agg$result,$p,$d0,$p02,$d02,$p12,$d12,$p22,$d22,$p32,$d32,$s,$t) {
 $agg$result = $agg$result|0;
 $p = $p|0;
 $d0 = $d0|0;
 $p02 = $p02|0;
 $d02 = $d02|0;
 $p12 = $p12|0;
 $d12 = $d12|0;
 $p22 = $p22|0;
 $d22 = $d22|0;
 $p32 = $p32|0;
 $d32 = $d32|0;
 $s = $s|0;
 $t = $t|0;
 var $$$i$i = Math_fround(0), $$$i$i138 = Math_fround(0), $$$i$i98 = Math_fround(0), $$$i8$i = Math_fround(0), $$$i8$i100 = Math_fround(0), $$$i8$i140 = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i$i139 = Math_fround(0), $$1$i$i99 = Math_fround(0), $$1$i9$i = Math_fround(0), $$1$i9$i101 = Math_fround(0), $$1$i9$i141 = Math_fround(0), $$in1$i = 0, $$in1$i123 = 0, $$in2$i = 0, $$in2$i125 = 0, $$in3$i = 0, $$in3$i127 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0);
 var $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0);
 var $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0);
 var $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0);
 var $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0);
 var $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0);
 var $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0;
 var $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0);
 var $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0;
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0);
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0);
 var $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0);
 var $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0);
 var $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0);
 var $352 = 0, $353 = 0, $354 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0;
 var $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn4$i122 = 0, $a$pn6$i126 = 0, $b$a$i = 0, $b$a$i120 = 0, $b$a7$i124 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = Math_fround(HEAPF32[$d0>>2]);
 $5 = (($d0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($d0) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$p>>2]);
 $10 = (($p) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($p) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$d02>>2]);
 $15 = (($d02) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($d02) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(HEAPF32[$d12>>2]);
 $20 = (($d12) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($d12) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(HEAPF32[$d22>>2]);
 $25 = (($d22) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($d22) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$d32>>2]);
 $30 = (($d32) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($d32) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround(HEAPF32[$p02>>2]);
 $35 = (($p02) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($p02) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(HEAPF32[$p12>>2]);
 $40 = (($p12) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($p12) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(HEAPF32[$p22>>2]);
 $45 = (($p22) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($p22) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround(HEAPF32[$p32>>2]);
 $50 = (($p32) + 4|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($p32) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($9 - $34);
 $55 = Math_fround($9 - $39);
 $56 = Math_fround($9 - $44);
 $57 = Math_fround($9 - $49);
 $58 = Math_fround($11 - $36);
 $59 = Math_fround($11 - $41);
 $60 = Math_fround($11 - $46);
 $61 = Math_fround($11 - $51);
 $62 = Math_fround($13 - $38);
 $63 = Math_fround($13 - $43);
 $64 = Math_fround($13 - $48);
 $65 = Math_fround($13 - $53);
 $66 = Math_fround($4 * $4);
 $67 = Math_fround($6 * $6);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($8 * $8);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($16 * $16);
 $72 = Math_fround($21 * $21);
 $73 = Math_fround($26 * $26);
 $74 = Math_fround($31 * $31);
 $75 = Math_fround($14 * $14);
 $76 = Math_fround($19 * $19);
 $77 = Math_fround($24 * $24);
 $78 = Math_fround($29 * $29);
 $79 = Math_fround($75 + $71);
 $80 = Math_fround($76 + $72);
 $81 = Math_fround($77 + $73);
 $82 = Math_fround($78 + $74);
 $83 = Math_fround($18 * $18);
 $84 = Math_fround($23 * $23);
 $85 = Math_fround($28 * $28);
 $86 = Math_fround($33 * $33);
 $87 = Math_fround($83 + $79);
 $88 = Math_fround($84 + $80);
 $89 = Math_fround($85 + $81);
 $90 = Math_fround($86 + $82);
 $91 = Math_fround($6 * $16);
 $92 = Math_fround($6 * $21);
 $93 = Math_fround($6 * $26);
 $94 = Math_fround($6 * $31);
 $95 = Math_fround($4 * $14);
 $96 = Math_fround($4 * $19);
 $97 = Math_fround($4 * $24);
 $98 = Math_fround($4 * $29);
 $99 = Math_fround($95 + $91);
 $100 = Math_fround($96 + $92);
 $101 = Math_fround($97 + $93);
 $102 = Math_fround($98 + $94);
 $103 = Math_fround($8 * $18);
 $104 = Math_fround($8 * $23);
 $105 = Math_fround($8 * $28);
 $106 = Math_fround($8 * $33);
 $107 = Math_fround($103 + $99);
 $108 = Math_fround($104 + $100);
 $109 = Math_fround($105 + $101);
 $110 = Math_fround($106 + $102);
 $111 = Math_fround($6 * $58);
 $112 = Math_fround($6 * $59);
 $113 = Math_fround($6 * $60);
 $114 = Math_fround($6 * $61);
 $115 = Math_fround($4 * $54);
 $116 = Math_fround($4 * $55);
 $117 = Math_fround($4 * $56);
 $118 = Math_fround($4 * $57);
 $119 = Math_fround($115 + $111);
 $120 = Math_fround($116 + $112);
 $121 = Math_fround($117 + $113);
 $122 = Math_fround($118 + $114);
 $123 = Math_fround($8 * $62);
 $124 = Math_fround($8 * $63);
 $125 = Math_fround($8 * $64);
 $126 = Math_fround($8 * $65);
 $127 = Math_fround($123 + $119);
 $128 = Math_fround($124 + $120);
 $129 = Math_fround($125 + $121);
 $130 = Math_fround($126 + $122);
 $131 = Math_fround($16 * $58);
 $132 = Math_fround($21 * $59);
 $133 = Math_fround($26 * $60);
 $134 = Math_fround($31 * $61);
 $135 = Math_fround($14 * $54);
 $136 = Math_fround($19 * $55);
 $137 = Math_fround($24 * $56);
 $138 = Math_fround($29 * $57);
 $139 = Math_fround($135 + $131);
 $140 = Math_fround($136 + $132);
 $141 = Math_fround($137 + $133);
 $142 = Math_fround($138 + $134);
 $143 = Math_fround($18 * $62);
 $144 = Math_fround($23 * $63);
 $145 = Math_fround($28 * $64);
 $146 = Math_fround($33 * $65);
 $147 = Math_fround($143 + $139);
 $148 = Math_fround($144 + $140);
 $149 = Math_fround($145 + $141);
 $150 = Math_fround($146 + $142);
 $151 = Math_fround(Math_fround(1.0) / $70);
 $152 = Math_fround(Math_fround(1.0) / $87);
 $153 = Math_fround(Math_fround(1.0) / $88);
 $154 = Math_fround(Math_fround(1.0) / $89);
 $155 = Math_fround(Math_fround(1.0) / $90);
 $156 = Math_fround($87 * $70);
 $157 = Math_fround($88 * $70);
 $158 = Math_fround($89 * $70);
 $159 = Math_fround($90 * $70);
 $160 = Math_fround($107 * $107);
 $161 = Math_fround($108 * $108);
 $162 = Math_fround($109 * $109);
 $163 = Math_fround($110 * $110);
 $164 = Math_fround($156 - $160);
 $165 = Math_fround($157 - $161);
 $166 = Math_fround($158 - $162);
 $167 = Math_fround($159 - $163);
 $168 = Math_fround($107 * $147);
 $169 = Math_fround($108 * $148);
 $170 = Math_fround($109 * $149);
 $171 = Math_fround($110 * $150);
 $172 = Math_fround($87 * $127);
 $173 = Math_fround($88 * $128);
 $174 = Math_fround($89 * $129);
 $175 = Math_fround($90 * $130);
 $176 = Math_fround($168 - $172);
 $177 = Math_fround($169 - $173);
 $178 = Math_fround($170 - $174);
 $179 = Math_fround($171 - $175);
 $180 = Math_fround($176 / $164);
 $181 = Math_fround($177 / $165);
 $182 = Math_fround($178 / $166);
 $183 = Math_fround($179 / $167);
 $184 = $180 < Math_fround(1.0);
 $$$i$i138 = $184 ? $180 : Math_fround(1.0);
 $185 = $181 < Math_fround(1.0);
 $186 = $185 ? $181 : Math_fround(1.0);
 $187 = $182 < Math_fround(1.0);
 $$1$i$i139 = $187 ? $182 : Math_fround(1.0);
 $188 = $183 < Math_fround(1.0);
 $189 = $188 ? $183 : Math_fround(1.0);
 $190 = $$$i$i138 > Math_fround(0.0);
 $$$i8$i140 = $190 ? $$$i$i138 : Math_fround(0.0);
 $191 = $186 > Math_fround(0.0);
 $192 = $191 ? $186 : Math_fround(0.0);
 $193 = $$1$i$i139 > Math_fround(0.0);
 $$1$i9$i141 = $193 ? $$1$i$i139 : Math_fround(0.0);
 $194 = $189 > Math_fround(0.0);
 $195 = $194 ? $189 : Math_fround(0.0);
 $196 = $164 <= Math_fround(1.1920928955078125E-7);
 $197 = $165 <= Math_fround(1.1920928955078125E-7);
 $198 = $166 <= Math_fround(1.1920928955078125E-7);
 $199 = $167 <= Math_fround(1.1920928955078125E-7);
 HEAPF32[$1>>2] = Math_fround(0.5);
 $200 = (($1) + 4|0);
 HEAPF32[$200>>2] = Math_fround(0.5);
 $201 = (($1) + 8|0);
 HEAPF32[$201>>2] = Math_fround(0.5);
 $202 = (($1) + 12|0);
 HEAPF32[$202>>2] = Math_fround(0.5);
 HEAPF32[$0>>2] = $$$i8$i140;
 $203 = (($0) + 4|0);
 HEAPF32[$203>>2] = $192;
 $204 = (($0) + 8|0);
 HEAPF32[$204>>2] = $$1$i9$i141;
 $205 = (($0) + 12|0);
 HEAPF32[$205>>2] = $195;
 $b$a$i120 = $196 ? $1 : $0;
 $206 = Math_fround(HEAPF32[$b$a$i120>>2]);
 $a$pn4$i122 = $197 ? $1 : $0;
 $$in1$i123 = (($a$pn4$i122) + 4|0);
 $207 = Math_fround(HEAPF32[$$in1$i123>>2]);
 $b$a7$i124 = $198 ? $1 : $0;
 $$in2$i125 = (($b$a7$i124) + 8|0);
 $208 = Math_fround(HEAPF32[$$in2$i125>>2]);
 $a$pn6$i126 = $199 ? $1 : $0;
 $$in3$i127 = (($a$pn6$i126) + 12|0);
 $209 = Math_fround(HEAPF32[$$in3$i127>>2]);
 $210 = Math_fround($107 * $206);
 $211 = Math_fround($108 * $207);
 $212 = Math_fround($109 * $208);
 $213 = Math_fround($110 * $209);
 $214 = Math_fround($147 + $210);
 $215 = Math_fround($148 + $211);
 $216 = Math_fround($149 + $212);
 $217 = Math_fround($150 + $213);
 $218 = Math_fround($152 * $214);
 $219 = Math_fround($153 * $215);
 $220 = Math_fround($154 * $216);
 $221 = Math_fround($155 * $217);
 $222 = $218 < Math_fround(1.0);
 $$$i$i98 = $222 ? $218 : Math_fround(1.0);
 $223 = $219 < Math_fround(1.0);
 $224 = $223 ? $219 : Math_fround(1.0);
 $225 = $220 < Math_fround(1.0);
 $$1$i$i99 = $225 ? $220 : Math_fround(1.0);
 $226 = $221 < Math_fround(1.0);
 $227 = $226 ? $221 : Math_fround(1.0);
 $228 = $$$i$i98 > Math_fround(0.0);
 $$$i8$i100 = $228 ? $$$i$i98 : Math_fround(0.0);
 $229 = $224 > Math_fround(0.0);
 $230 = $229 ? $224 : Math_fround(0.0);
 $231 = $$1$i$i99 > Math_fround(0.0);
 $$1$i9$i101 = $231 ? $$1$i$i99 : Math_fround(0.0);
 $232 = $227 > Math_fround(0.0);
 $233 = $232 ? $227 : Math_fround(0.0);
 $234 = Math_fround($107 * $$$i8$i100);
 $235 = Math_fround($108 * $230);
 $236 = Math_fround($109 * $$1$i9$i101);
 $237 = Math_fround($110 * $233);
 $238 = Math_fround($234 - $127);
 $239 = Math_fround($235 - $128);
 $240 = Math_fround($236 - $129);
 $241 = Math_fround($237 - $130);
 $242 = Math_fround($151 * $238);
 $243 = Math_fround($151 * $239);
 $244 = Math_fround($151 * $240);
 $245 = Math_fround($151 * $241);
 $246 = $70 <= Math_fround(1.1920928955078125E-7);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 $247 = $242 < Math_fround(1.0);
 $$$i$i = $247 ? $242 : Math_fround(1.0);
 $248 = $243 < Math_fround(1.0);
 $249 = $248 ? $243 : Math_fround(1.0);
 $250 = $244 < Math_fround(1.0);
 $$1$i$i = $250 ? $244 : Math_fround(1.0);
 $251 = $245 < Math_fround(1.0);
 $252 = $251 ? $245 : Math_fround(1.0);
 $253 = $$$i$i > Math_fround(0.0);
 $$$i8$i = $253 ? $$$i$i : Math_fround(0.0);
 $254 = $249 > Math_fround(0.0);
 $255 = $254 ? $249 : Math_fround(0.0);
 $256 = $$1$i$i > Math_fround(0.0);
 $$1$i9$i = $256 ? $$1$i$i : Math_fround(0.0);
 $257 = $252 > Math_fround(0.0);
 $258 = $257 ? $252 : Math_fround(0.0);
 HEAPF32[$2>>2] = $$$i8$i;
 $259 = (($2) + 4|0);
 HEAPF32[$259>>2] = $255;
 $260 = (($2) + 8|0);
 HEAPF32[$260>>2] = $$1$i9$i;
 $261 = (($2) + 12|0);
 HEAPF32[$261>>2] = $258;
 $b$a$i = $246 ? $3 : $2;
 $262 = Math_fround(HEAPF32[$b$a$i>>2]);
 $$in1$i = (($b$a$i) + 4|0);
 $263 = Math_fround(HEAPF32[$$in1$i>>2]);
 $$in2$i = (($b$a$i) + 8|0);
 $264 = Math_fround(HEAPF32[$$in2$i>>2]);
 $$in3$i = (($b$a$i) + 12|0);
 $265 = Math_fround(HEAPF32[$$in3$i>>2]);
 HEAPF32[$s>>2] = $262;
 $266 = (($s) + 4|0);
 HEAPF32[$266>>2] = $263;
 $267 = (($s) + 8|0);
 HEAPF32[$267>>2] = $264;
 $268 = (($s) + 12|0);
 HEAPF32[$268>>2] = $265;
 HEAPF32[$t>>2] = $$$i8$i100;
 $269 = (($t) + 4|0);
 HEAPF32[$269>>2] = $230;
 $270 = (($t) + 8|0);
 HEAPF32[$270>>2] = $$1$i9$i101;
 $271 = (($t) + 12|0);
 HEAPF32[$271>>2] = $233;
 $272 = Math_fround($4 * $262);
 $273 = Math_fround($4 * $263);
 $274 = Math_fround($4 * $264);
 $275 = Math_fround($4 * $265);
 $276 = Math_fround($9 + $272);
 $277 = Math_fround($9 + $273);
 $278 = Math_fround($9 + $274);
 $279 = Math_fround($9 + $275);
 $280 = Math_fround($6 * $262);
 $281 = Math_fround($6 * $263);
 $282 = Math_fround($6 * $264);
 $283 = Math_fround($6 * $265);
 $284 = Math_fround($11 + $280);
 $285 = Math_fround($11 + $281);
 $286 = Math_fround($11 + $282);
 $287 = Math_fround($11 + $283);
 $288 = Math_fround($8 * $262);
 $289 = Math_fround($8 * $263);
 $290 = Math_fround($8 * $264);
 $291 = Math_fround($8 * $265);
 $292 = Math_fround($13 + $288);
 $293 = Math_fround($13 + $289);
 $294 = Math_fround($13 + $290);
 $295 = Math_fround($13 + $291);
 $296 = Math_fround($14 * $$$i8$i100);
 $297 = Math_fround($19 * $230);
 $298 = Math_fround($24 * $$1$i9$i101);
 $299 = Math_fround($29 * $233);
 $300 = Math_fround($34 + $296);
 $301 = Math_fround($39 + $297);
 $302 = Math_fround($44 + $298);
 $303 = Math_fround($49 + $299);
 $304 = Math_fround($16 * $$$i8$i100);
 $305 = Math_fround($21 * $230);
 $306 = Math_fround($26 * $$1$i9$i101);
 $307 = Math_fround($31 * $233);
 $308 = Math_fround($36 + $304);
 $309 = Math_fround($41 + $305);
 $310 = Math_fround($46 + $306);
 $311 = Math_fround($51 + $307);
 $312 = Math_fround($18 * $$$i8$i100);
 $313 = Math_fround($23 * $230);
 $314 = Math_fround($28 * $$1$i9$i101);
 $315 = Math_fround($33 * $233);
 $316 = Math_fround($38 + $312);
 $317 = Math_fround($43 + $313);
 $318 = Math_fround($48 + $314);
 $319 = Math_fround($53 + $315);
 $320 = Math_fround($276 - $300);
 $321 = Math_fround($277 - $301);
 $322 = Math_fround($278 - $302);
 $323 = Math_fround($279 - $303);
 $324 = Math_fround($284 - $308);
 $325 = Math_fround($285 - $309);
 $326 = Math_fround($286 - $310);
 $327 = Math_fround($287 - $311);
 $328 = Math_fround($292 - $316);
 $329 = Math_fround($293 - $317);
 $330 = Math_fround($294 - $318);
 $331 = Math_fround($295 - $319);
 $332 = Math_fround($328 * $328);
 $333 = Math_fround($329 * $329);
 $334 = Math_fround($330 * $330);
 $335 = Math_fround($331 * $331);
 $336 = Math_fround($324 * $324);
 $337 = Math_fround($325 * $325);
 $338 = Math_fround($326 * $326);
 $339 = Math_fround($327 * $327);
 $340 = Math_fround($336 + $332);
 $341 = Math_fround($337 + $333);
 $342 = Math_fround($338 + $334);
 $343 = Math_fround($339 + $335);
 $344 = Math_fround($320 * $320);
 $345 = Math_fround($321 * $321);
 $346 = Math_fround($322 * $322);
 $347 = Math_fround($323 * $323);
 $348 = Math_fround($344 + $340);
 $349 = Math_fround($345 + $341);
 $350 = Math_fround($346 + $342);
 $351 = Math_fround($347 + $343);
 HEAPF32[$agg$result>>2] = $348;
 $352 = (($agg$result) + 4|0);
 HEAPF32[$352>>2] = $349;
 $353 = (($agg$result) + 8|0);
 HEAPF32[$353>>2] = $350;
 $354 = (($agg$result) + 12|0);
 HEAPF32[$354>>2] = $351;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu30distanceSegmentTriangleSquaredERKNS_6PxVec3ES3_S3_S3_S3_PfS4_S4_($origin,$dir,$p0,$triEdge0,$triEdge1,$t,$u,$v) {
 $origin = $origin|0;
 $dir = $dir|0;
 $p0 = $p0|0;
 $triEdge0 = $triEdge0|0;
 $triEdge1 = $triEdge1|0;
 $t = $t|0;
 $u = $u|0;
 $v = $v|0;
 var $$0 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $1000 = 0, $1001 = 0, $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0), $1011 = 0, $1012 = 0, $1013 = Math_fround(0);
 var $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = 0, $102 = Math_fround(0), $1020 = 0, $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = 0, $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = Math_fround(0), $1030 = 0, $1031 = Math_fround(0);
 var $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = 0, $104 = Math_fround(0), $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = 0, $105 = Math_fround(0);
 var $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0);
 var $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = 0, $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0), $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = 0, $1082 = 0, $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0);
 var $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = 0, $109 = Math_fround(0), $1090 = 0, $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = 0, $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = 0, $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0);
 var $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = 0, $111 = Math_fround(0), $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = 0, $1117 = 0, $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0);
 var $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = 0, $1128 = 0, $1129 = Math_fround(0), $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = 0, $1136 = 0, $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = Math_fround(0);
 var $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = 0, $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = 0, $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = 0, $1156 = 0, $1157 = Math_fround(0), $1158 = 0;
 var $1159 = Math_fround(0), $116 = Math_fround(0), $1160 = 0, $1161 = Math_fround(0), $1162 = 0, $1163 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0.0, $142 = 0.0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0);
 var $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0);
 var $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0);
 var $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0);
 var $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = 0, $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0);
 var $472 = Math_fround(0), $473 = Math_fround(0), $474 = 0, $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = 0, $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0;
 var $490 = Math_fround(0), $491 = 0, $492 = 0, $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = 0, $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0);
 var $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = 0, $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0;
 var $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = 0, $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = Math_fround(0), $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = Math_fround(0), $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0;
 var $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0);
 var $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = 0, $588 = Math_fround(0), $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0);
 var $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = Math_fround(0);
 var $616 = Math_fround(0), $617 = Math_fround(0), $618 = 0, $619 = 0, $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = 0, $624 = 0, $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = 0, $633 = Math_fround(0);
 var $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = 0, $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0);
 var $652 = Math_fround(0), $653 = 0, $654 = 0, $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = 0, $665 = 0, $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0;
 var $670 = Math_fround(0), $671 = Math_fround(0), $672 = 0, $673 = 0, $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = 0, $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = 0, $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0);
 var $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = 0, $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = 0, $703 = 0, $704 = Math_fround(0), $705 = Math_fround(0);
 var $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = 0, $714 = 0, $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = 0, $722 = 0, $723 = Math_fround(0);
 var $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = 0, $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = 0, $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = 0, $757 = 0, $758 = Math_fround(0), $759 = Math_fround(0), $76 = Math_fround(0);
 var $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = 0, $768 = 0, $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = 0, $776 = 0, $777 = Math_fround(0), $778 = Math_fround(0);
 var $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = 0, $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = 0, $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = 0, $796 = Math_fround(0);
 var $797 = Math_fround(0), $798 = Math_fround(0), $799 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $800 = 0, $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = 0, $805 = 0, $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0);
 var $814 = Math_fround(0), $815 = Math_fround(0), $816 = 0, $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = Math_fround(0), $820 = 0, $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = 0, $83 = Math_fround(0), $830 = 0, $831 = 0;
 var $832 = 0, $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0;
 var $850 = Math_fround(0), $851 = Math_fround(0), $852 = 0, $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = 0, $864 = 0, $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0);
 var $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = 0, $875 = 0, $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = 0, $883 = 0, $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0);
 var $887 = Math_fround(0), $888 = Math_fround(0), $889 = 0, $89 = 0, $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = 0, $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0), $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = Math_fround(0), $920 = Math_fround(0), $921 = Math_fround(0);
 var $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = 0, $928 = Math_fround(0), $929 = Math_fround(0), $93 = Math_fround(0), $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = 0, $939 = 0, $94 = Math_fround(0);
 var $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = 0, $95 = Math_fround(0), $950 = 0, $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = 0, $958 = 0;
 var $959 = Math_fround(0), $96 = Math_fround(0), $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = 0, $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = 0, $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0);
 var $977 = 0, $978 = Math_fround(0), $979 = Math_fround(0), $98 = Math_fround(0), $980 = Math_fround(0), $981 = 0, $982 = 0, $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = 0, $987 = 0, $988 = Math_fround(0), $989 = Math_fround(0), $99 = Math_fround(0), $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0);
 var $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $cp$i80 = 0, $fR = 0, $fR0 = 0, $fS = 0, $fS0 = 0, $fSqrDist$0 = Math_fround(0), $fSqrDist$1 = Math_fround(0), $fSqrDist$2 = Math_fround(0), $fSqrDist$3 = Math_fround(0), $fSqrDist$4 = Math_fround(0), $fSqrDist$5 = Math_fround(0), $fSqrDist$6 = Math_fround(0), $fSqrDist$7 = Math_fround(0), $fSqrDist$8 = Math_fround(0), $fSqrDist$9 = Math_fround(0);
 var $fT = 0, $fT0 = 0, $kPt = 0, $kTriSegDir = 0, $kTriSegOrig = 0, $pt0$i76 = 0, $pt1$i77 = 0, $s$i78 = 0, $t$i79 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $pt0$i76 = sp + 92|0;
 $pt1$i77 = sp + 80|0;
 $s$i78 = sp + 76|0;
 $t$i79 = sp + 72|0;
 $cp$i80 = sp + 60|0;
 $kTriSegOrig = sp + 48|0;
 $kTriSegDir = sp + 36|0;
 $kPt = sp + 24|0;
 $fR = sp + 16|0;
 $fS = sp + 12|0;
 $fT = sp + 8|0;
 $fR0 = sp + 4|0;
 $fS0 = sp;
 $fT0 = sp + 20|0;
 $0 = Math_fround(HEAPF32[$dir>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($dir) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($dir) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = $9 < Math_fround(9.9999999600419720025E-13);
 if ($10) {
  $11 = ($t|0)==(0|0);
  if (!($11)) {
   HEAPF32[$t>>2] = Math_fround(0.0);
  }
  $12 = Math_fround(HEAPF32[$triEdge0>>2]);
  $13 = Math_fround(HEAPF32[$p0>>2]);
  $14 = Math_fround($12 + $13);
  $15 = (($triEdge0) + 4|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($p0) + 4|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($16 + $18);
  $20 = (($triEdge0) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($p0) + 8|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($21 + $23);
  HEAPF32[$pt0$i76>>2] = $14;
  $25 = (($pt0$i76) + 4|0);
  HEAPF32[$25>>2] = $19;
  $26 = (($pt0$i76) + 8|0);
  HEAPF32[$26>>2] = $24;
  $27 = Math_fround(HEAPF32[$triEdge1>>2]);
  $28 = Math_fround($13 + $27);
  $29 = (($triEdge1) + 4|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($18 + $30);
  $32 = (($triEdge1) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($23 + $33);
  HEAPF32[$pt1$i77>>2] = $28;
  $35 = (($pt1$i77) + 4|0);
  HEAPF32[$35>>2] = $31;
  $36 = (($pt1$i77) + 8|0);
  HEAPF32[$36>>2] = $34;
  __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
  $37 = ($u|0)==(0|0);
  if (!($37)) {
   $38 = Math_fround(HEAPF32[$s$i78>>2]);
   HEAPF32[$u>>2] = $38;
  }
  $39 = ($v|0)==(0|0);
  if (!($39)) {
   $40 = Math_fround(HEAPF32[$t$i79>>2]);
   HEAPF32[$v>>2] = $40;
  }
  $41 = Math_fround(HEAPF32[$cp$i80>>2]);
  $42 = Math_fround(HEAPF32[$origin>>2]);
  $43 = Math_fround($41 - $42);
  $44 = (($cp$i80) + 4|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($origin) + 4|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($45 - $47);
  $49 = (($cp$i80) + 8|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = (($origin) + 8|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = Math_fround($50 - $52);
  $54 = Math_fround($43 * $43);
  $55 = Math_fround($48 * $48);
  $56 = Math_fround($54 + $55);
  $57 = Math_fround($53 * $53);
  $58 = Math_fround($56 + $57);
  $$0 = $58;
  STACKTOP = sp;return (Math_fround($$0));
 }
 $59 = Math_fround(HEAPF32[$p0>>2]);
 $60 = Math_fround(HEAPF32[$origin>>2]);
 $61 = Math_fround($59 - $60);
 $62 = (($p0) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($origin) + 4|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($63 - $65);
 $67 = (($p0) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($origin) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($68 - $70);
 $72 = Math_fround(HEAPF32[$triEdge0>>2]);
 $73 = Math_fround($0 * $72);
 $74 = (($triEdge0) + 4|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($3 * $75);
 $77 = Math_fround($73 + $76);
 $78 = (($triEdge0) + 8|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($7 * $79);
 $81 = Math_fround($77 + $80);
 $82 = Math_fround(-$81);
 $83 = Math_fround(HEAPF32[$triEdge1>>2]);
 $84 = Math_fround($0 * $83);
 $85 = (($triEdge1) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($3 * $86);
 $88 = Math_fround($84 + $87);
 $89 = (($triEdge1) + 8|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($7 * $90);
 $92 = Math_fround($88 + $91);
 $93 = Math_fround(-$92);
 $94 = Math_fround($72 * $72);
 $95 = Math_fround($75 * $75);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($79 * $79);
 $98 = Math_fround($96 + $97);
 $99 = Math_fround($72 * $83);
 $100 = Math_fround($75 * $86);
 $101 = Math_fround($99 + $100);
 $102 = Math_fround($79 * $90);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($83 * $83);
 $105 = Math_fround($86 * $86);
 $106 = Math_fround($104 + $105);
 $107 = Math_fround($90 * $90);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($98 * $108);
 $110 = Math_fround($103 * $103);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($103 * $93);
 $113 = Math_fround($108 * $82);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($103 * $82);
 $116 = Math_fround($98 * $93);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($75 * $90);
 $119 = Math_fround($79 * $86);
 $120 = Math_fround($118 - $119);
 $121 = Math_fround($79 * $83);
 $122 = Math_fround($72 * $90);
 $123 = Math_fround($121 - $122);
 $124 = Math_fround($72 * $86);
 $125 = Math_fround($75 * $83);
 $126 = Math_fround($124 - $125);
 $127 = Math_fround($0 * $120);
 $128 = Math_fround($3 * $123);
 $129 = Math_fround($127 + $128);
 $130 = Math_fround($7 * $126);
 $131 = Math_fround($130 + $129);
 $132 = Math_fround($131 * $131);
 $133 = +$132;
 $134 = +$9;
 $135 = $134 * 9.99999999999999954748E-7;
 $136 = Math_fround($120 * $120);
 $137 = Math_fround($123 * $123);
 $138 = Math_fround($136 + $137);
 $139 = Math_fround($126 * $126);
 $140 = Math_fround($139 + $138);
 $141 = +$140;
 $142 = $135 * $141;
 $143 = !($133 >= $142);
 do {
  if ($143) {
   HEAPF32[$kTriSegOrig>>2] = $59;
   $1040 = (($kTriSegOrig) + 4|0);
   HEAPF32[$1040>>2] = $63;
   $1041 = (($kTriSegOrig) + 8|0);
   HEAPF32[$1041>>2] = $68;
   HEAPF32[$kTriSegDir>>2] = $72;
   $1042 = (($kTriSegDir) + 4|0);
   HEAPF32[$1042>>2] = $75;
   $1043 = (($kTriSegDir) + 8|0);
   HEAPF32[$1043>>2] = $79;
   $1044 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fS)));
   HEAPF32[$fT>>2] = Math_fround(0.0);
   $1045 = Math_fround(HEAPF32[$triEdge1>>2]);
   HEAPF32[$kTriSegDir>>2] = $1045;
   $1046 = Math_fround(HEAPF32[$85>>2]);
   HEAPF32[$1042>>2] = $1046;
   $1047 = Math_fround(HEAPF32[$89>>2]);
   HEAPF32[$1043>>2] = $1047;
   $1048 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fT0)));
   HEAPF32[$fS0>>2] = Math_fround(0.0);
   $1049 = $1048 < $1044;
   if ($1049) {
    $1050 = Math_fround(HEAPF32[$fR0>>2]);
    HEAPF32[$fR>>2] = $1050;
    HEAPF32[$fS>>2] = Math_fround(0.0);
    $1051 = Math_fround(HEAPF32[$fT0>>2]);
    HEAPF32[$fT>>2] = $1051;
    $fSqrDist$6 = $1048;
   } else {
    $fSqrDist$6 = $1044;
   }
   $1052 = Math_fround(HEAPF32[$p0>>2]);
   $1053 = Math_fround(HEAPF32[$triEdge0>>2]);
   $1054 = Math_fround($1052 + $1053);
   $1055 = Math_fround(HEAPF32[$62>>2]);
   $1056 = Math_fround(HEAPF32[$74>>2]);
   $1057 = Math_fround($1055 + $1056);
   $1058 = Math_fround(HEAPF32[$67>>2]);
   $1059 = Math_fround(HEAPF32[$78>>2]);
   $1060 = Math_fround($1058 + $1059);
   HEAPF32[$kTriSegOrig>>2] = $1054;
   HEAPF32[$1040>>2] = $1057;
   HEAPF32[$1041>>2] = $1060;
   $1061 = Math_fround(HEAPF32[$triEdge1>>2]);
   $1062 = Math_fround($1061 - $1053);
   $1063 = Math_fround(HEAPF32[$85>>2]);
   $1064 = Math_fround($1063 - $1056);
   $1065 = Math_fround(HEAPF32[$89>>2]);
   $1066 = Math_fround($1065 - $1059);
   HEAPF32[$kTriSegDir>>2] = $1062;
   HEAPF32[$1042>>2] = $1064;
   HEAPF32[$1043>>2] = $1066;
   $1067 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fT0)));
   $1068 = Math_fround(HEAPF32[$fT0>>2]);
   $1069 = Math_fround(Math_fround(1.0) - $1068);
   HEAPF32[$fS0>>2] = $1069;
   $1070 = $1067 < $fSqrDist$6;
   if ($1070) {
    $1071 = Math_fround(HEAPF32[$fR0>>2]);
    HEAPF32[$fR>>2] = $1071;
    HEAPF32[$fS>>2] = $1069;
    HEAPF32[$fT>>2] = $1068;
    $fSqrDist$7 = $1067;
   } else {
    $fSqrDist$7 = $fSqrDist$6;
   }
   $1072 = Math_fround(HEAPF32[$triEdge0>>2]);
   $1073 = Math_fround(HEAPF32[$p0>>2]);
   $1074 = Math_fround($1072 + $1073);
   $1075 = Math_fround(HEAPF32[$74>>2]);
   $1076 = Math_fround(HEAPF32[$62>>2]);
   $1077 = Math_fround($1075 + $1076);
   $1078 = Math_fround(HEAPF32[$78>>2]);
   $1079 = Math_fround(HEAPF32[$67>>2]);
   $1080 = Math_fround($1078 + $1079);
   HEAPF32[$pt0$i76>>2] = $1074;
   $1081 = (($pt0$i76) + 4|0);
   HEAPF32[$1081>>2] = $1077;
   $1082 = (($pt0$i76) + 8|0);
   HEAPF32[$1082>>2] = $1080;
   $1083 = Math_fround(HEAPF32[$triEdge1>>2]);
   $1084 = Math_fround($1073 + $1083);
   $1085 = Math_fround(HEAPF32[$85>>2]);
   $1086 = Math_fround($1076 + $1085);
   $1087 = Math_fround(HEAPF32[$89>>2]);
   $1088 = Math_fround($1079 + $1087);
   HEAPF32[$pt1$i77>>2] = $1084;
   $1089 = (($pt1$i77) + 4|0);
   HEAPF32[$1089>>2] = $1086;
   $1090 = (($pt1$i77) + 8|0);
   HEAPF32[$1090>>2] = $1088;
   __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
   $1091 = Math_fround(HEAPF32[$s$i78>>2]);
   HEAPF32[$fS0>>2] = $1091;
   $1092 = Math_fround(HEAPF32[$t$i79>>2]);
   HEAPF32[$fT0>>2] = $1092;
   $1093 = Math_fround(HEAPF32[$cp$i80>>2]);
   $1094 = Math_fround(HEAPF32[$origin>>2]);
   $1095 = Math_fround($1093 - $1094);
   $1096 = (($cp$i80) + 4|0);
   $1097 = Math_fround(HEAPF32[$1096>>2]);
   $1098 = Math_fround(HEAPF32[$64>>2]);
   $1099 = Math_fround($1097 - $1098);
   $1100 = (($cp$i80) + 8|0);
   $1101 = Math_fround(HEAPF32[$1100>>2]);
   $1102 = Math_fround(HEAPF32[$69>>2]);
   $1103 = Math_fround($1101 - $1102);
   $1104 = Math_fround($1095 * $1095);
   $1105 = Math_fround($1099 * $1099);
   $1106 = Math_fround($1104 + $1105);
   $1107 = Math_fround($1103 * $1103);
   $1108 = Math_fround($1106 + $1107);
   HEAPF32[$fR0>>2] = Math_fround(0.0);
   $1109 = $1108 < $fSqrDist$7;
   if ($1109) {
    HEAPF32[$fR>>2] = Math_fround(0.0);
    HEAPF32[$fS>>2] = $1091;
    HEAPF32[$fT>>2] = $1092;
    $fSqrDist$8 = $1108;
   } else {
    $fSqrDist$8 = $fSqrDist$7;
   }
   $1110 = Math_fround(HEAPF32[$dir>>2]);
   $1111 = Math_fround($1094 + $1110);
   $1112 = Math_fround(HEAPF32[$2>>2]);
   $1113 = Math_fround($1098 + $1112);
   $1114 = Math_fround(HEAPF32[$6>>2]);
   $1115 = Math_fround($1102 + $1114);
   HEAPF32[$kPt>>2] = $1111;
   $1116 = (($kPt) + 4|0);
   HEAPF32[$1116>>2] = $1113;
   $1117 = (($kPt) + 8|0);
   HEAPF32[$1117>>2] = $1115;
   $1118 = Math_fround(HEAPF32[$triEdge0>>2]);
   $1119 = Math_fround(HEAPF32[$p0>>2]);
   $1120 = Math_fround($1118 + $1119);
   $1121 = Math_fround(HEAPF32[$74>>2]);
   $1122 = Math_fround(HEAPF32[$62>>2]);
   $1123 = Math_fround($1121 + $1122);
   $1124 = Math_fround(HEAPF32[$78>>2]);
   $1125 = Math_fround(HEAPF32[$67>>2]);
   $1126 = Math_fround($1124 + $1125);
   HEAPF32[$pt0$i76>>2] = $1120;
   $1127 = (($pt0$i76) + 4|0);
   HEAPF32[$1127>>2] = $1123;
   $1128 = (($pt0$i76) + 8|0);
   HEAPF32[$1128>>2] = $1126;
   $1129 = Math_fround(HEAPF32[$triEdge1>>2]);
   $1130 = Math_fround($1119 + $1129);
   $1131 = Math_fround(HEAPF32[$85>>2]);
   $1132 = Math_fround($1122 + $1131);
   $1133 = Math_fround(HEAPF32[$89>>2]);
   $1134 = Math_fround($1125 + $1133);
   HEAPF32[$pt1$i77>>2] = $1130;
   $1135 = (($pt1$i77) + 4|0);
   HEAPF32[$1135>>2] = $1132;
   $1136 = (($pt1$i77) + 8|0);
   HEAPF32[$1136>>2] = $1134;
   __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$kPt,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
   $1137 = Math_fround(HEAPF32[$s$i78>>2]);
   HEAPF32[$fS0>>2] = $1137;
   $1138 = Math_fround(HEAPF32[$t$i79>>2]);
   HEAPF32[$fT0>>2] = $1138;
   $1139 = Math_fround(HEAPF32[$cp$i80>>2]);
   $1140 = Math_fround(HEAPF32[$kPt>>2]);
   $1141 = Math_fround($1139 - $1140);
   $1142 = (($cp$i80) + 4|0);
   $1143 = Math_fround(HEAPF32[$1142>>2]);
   $1144 = Math_fround(HEAPF32[$1116>>2]);
   $1145 = Math_fround($1143 - $1144);
   $1146 = (($cp$i80) + 8|0);
   $1147 = Math_fround(HEAPF32[$1146>>2]);
   $1148 = Math_fround(HEAPF32[$1117>>2]);
   $1149 = Math_fround($1147 - $1148);
   $1150 = Math_fround($1141 * $1141);
   $1151 = Math_fround($1145 * $1145);
   $1152 = Math_fround($1150 + $1151);
   $1153 = Math_fround($1149 * $1149);
   $1154 = Math_fround($1152 + $1153);
   HEAPF32[$fR0>>2] = Math_fround(1.0);
   $1155 = $1154 < $fSqrDist$8;
   if ($1155) {
    HEAPF32[$fR>>2] = Math_fround(1.0);
    HEAPF32[$fS>>2] = $1137;
    HEAPF32[$fT>>2] = $1138;
    $fSqrDist$9 = $1154;
   } else {
    $fSqrDist$9 = $fSqrDist$8;
   }
  } else {
   $144 = Math_fround($66 * $86);
   $145 = Math_fround($61 * $83);
   $146 = Math_fround($66 * $75);
   $147 = Math_fround($61 * $72);
   $148 = Math_fround($3 * $66);
   $149 = Math_fround($0 * $61);
   $150 = Math_fround($71 * $90);
   $151 = Math_fround($145 + $144);
   $152 = Math_fround($71 * $79);
   $153 = Math_fround($147 + $146);
   $154 = Math_fround($7 * $71);
   $155 = Math_fround($149 + $148);
   $156 = Math_fround($151 + $150);
   $157 = Math_fround($153 + $152);
   $158 = Math_fround($155 + $154);
   $159 = Math_fround($114 * $82);
   $160 = Math_fround($9 * $111);
   $161 = Math_fround($117 * $93);
   $162 = Math_fround($160 + $159);
   $163 = Math_fround($161 + $162);
   $164 = Math_fround($9 * $108);
   $165 = Math_fround($92 * $92);
   $166 = Math_fround($164 - $165);
   $167 = Math_fround($81 * $92);
   $168 = Math_fround($9 * $103);
   $169 = Math_fround($167 - $168);
   $170 = Math_fround($9 * $98);
   $171 = Math_fround($81 * $81);
   $172 = Math_fround($170 - $171);
   $173 = Math_fround(Math_fround(1.0) / $163);
   $174 = Math_fround($158 * $173);
   $175 = Math_fround($157 * $173);
   $176 = Math_fround(-$175);
   $177 = Math_fround($156 * $173);
   $178 = Math_fround(-$177);
   $179 = Math_fround($111 * $174);
   $180 = Math_fround($114 * $176);
   $181 = Math_fround($179 + $180);
   $182 = Math_fround($117 * $178);
   $183 = Math_fround($182 + $181);
   HEAPF32[$fR>>2] = $183;
   $184 = Math_fround($114 * $174);
   $185 = Math_fround($166 * $176);
   $186 = Math_fround($184 + $185);
   $187 = Math_fround($169 * $178);
   $188 = Math_fround($187 + $186);
   HEAPF32[$fS>>2] = $188;
   $189 = Math_fround($117 * $174);
   $190 = Math_fround($169 * $176);
   $191 = Math_fround($189 + $190);
   $192 = Math_fround($172 * $178);
   $193 = Math_fround($192 + $191);
   HEAPF32[$fT>>2] = $193;
   $194 = $183 < Math_fround(0.0);
   if ($194) {
    $195 = Math_fround($193 + $188);
    $196 = !($195 <= Math_fround(1.0));
    $197 = $188 < Math_fround(0.0);
    if ($196) {
     if ($197) {
      HEAPF32[$kTriSegOrig>>2] = $59;
      $361 = (($kTriSegOrig) + 4|0);
      HEAPF32[$361>>2] = $63;
      $362 = (($kTriSegOrig) + 8|0);
      HEAPF32[$362>>2] = $68;
      HEAPF32[$kTriSegDir>>2] = $83;
      $363 = (($kTriSegDir) + 4|0);
      HEAPF32[$363>>2] = $86;
      $364 = (($kTriSegDir) + 8|0);
      HEAPF32[$364>>2] = $90;
      $365 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
      HEAPF32[$fS>>2] = Math_fround(0.0);
      $366 = Math_fround(HEAPF32[$p0>>2]);
      $367 = Math_fround(HEAPF32[$triEdge0>>2]);
      $368 = Math_fround($366 + $367);
      $369 = Math_fround(HEAPF32[$62>>2]);
      $370 = Math_fround(HEAPF32[$74>>2]);
      $371 = Math_fround($369 + $370);
      $372 = Math_fround(HEAPF32[$67>>2]);
      $373 = Math_fround(HEAPF32[$78>>2]);
      $374 = Math_fround($372 + $373);
      HEAPF32[$kTriSegOrig>>2] = $368;
      HEAPF32[$361>>2] = $371;
      HEAPF32[$362>>2] = $374;
      $375 = Math_fround(HEAPF32[$triEdge1>>2]);
      $376 = Math_fround($375 - $367);
      $377 = Math_fround(HEAPF32[$85>>2]);
      $378 = Math_fround($377 - $370);
      $379 = Math_fround(HEAPF32[$89>>2]);
      $380 = Math_fround($379 - $373);
      HEAPF32[$kTriSegDir>>2] = $376;
      HEAPF32[$363>>2] = $378;
      HEAPF32[$364>>2] = $380;
      $381 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fT0)));
      $382 = Math_fround(HEAPF32[$fT0>>2]);
      $383 = Math_fround(Math_fround(1.0) - $382);
      HEAPF32[$fS0>>2] = $383;
      $384 = $381 < $365;
      if ($384) {
       $385 = Math_fround(HEAPF32[$fR0>>2]);
       HEAPF32[$fR>>2] = $385;
       HEAPF32[$fS>>2] = $383;
       HEAPF32[$fT>>2] = $382;
       $fSqrDist$1 = $381;
      } else {
       $fSqrDist$1 = $365;
      }
      $386 = Math_fround(HEAPF32[$triEdge0>>2]);
      $387 = Math_fround(HEAPF32[$p0>>2]);
      $388 = Math_fround($386 + $387);
      $389 = Math_fround(HEAPF32[$74>>2]);
      $390 = Math_fround(HEAPF32[$62>>2]);
      $391 = Math_fround($389 + $390);
      $392 = Math_fround(HEAPF32[$78>>2]);
      $393 = Math_fround(HEAPF32[$67>>2]);
      $394 = Math_fround($392 + $393);
      HEAPF32[$pt0$i76>>2] = $388;
      $395 = (($pt0$i76) + 4|0);
      HEAPF32[$395>>2] = $391;
      $396 = (($pt0$i76) + 8|0);
      HEAPF32[$396>>2] = $394;
      $397 = Math_fround(HEAPF32[$triEdge1>>2]);
      $398 = Math_fround($387 + $397);
      $399 = Math_fround(HEAPF32[$85>>2]);
      $400 = Math_fround($390 + $399);
      $401 = Math_fround(HEAPF32[$89>>2]);
      $402 = Math_fround($393 + $401);
      HEAPF32[$pt1$i77>>2] = $398;
      $403 = (($pt1$i77) + 4|0);
      HEAPF32[$403>>2] = $400;
      $404 = (($pt1$i77) + 8|0);
      HEAPF32[$404>>2] = $402;
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
      $405 = Math_fround(HEAPF32[$s$i78>>2]);
      HEAPF32[$fS0>>2] = $405;
      $406 = Math_fround(HEAPF32[$t$i79>>2]);
      HEAPF32[$fT0>>2] = $406;
      $407 = Math_fround(HEAPF32[$cp$i80>>2]);
      $408 = Math_fround(HEAPF32[$origin>>2]);
      $409 = Math_fround($407 - $408);
      $410 = (($cp$i80) + 4|0);
      $411 = Math_fround(HEAPF32[$410>>2]);
      $412 = Math_fround(HEAPF32[$64>>2]);
      $413 = Math_fround($411 - $412);
      $414 = (($cp$i80) + 8|0);
      $415 = Math_fround(HEAPF32[$414>>2]);
      $416 = Math_fround(HEAPF32[$69>>2]);
      $417 = Math_fround($415 - $416);
      $418 = Math_fround($409 * $409);
      $419 = Math_fround($413 * $413);
      $420 = Math_fround($418 + $419);
      $421 = Math_fround($417 * $417);
      $422 = Math_fround($420 + $421);
      HEAPF32[$fR0>>2] = Math_fround(0.0);
      $423 = $422 < $fSqrDist$1;
      if (!($423)) {
       $fSqrDist$9 = $fSqrDist$1;
       break;
      }
      HEAPF32[$fR>>2] = Math_fround(0.0);
      HEAPF32[$fS>>2] = $405;
      HEAPF32[$fT>>2] = $406;
      $fSqrDist$9 = $422;
      break;
     }
     $424 = $193 < Math_fround(0.0);
     if (!($424)) {
      $488 = Math_fround($59 + $72);
      $489 = Math_fround($63 + $75);
      $490 = Math_fround($68 + $79);
      HEAPF32[$kTriSegOrig>>2] = $488;
      $491 = (($kTriSegOrig) + 4|0);
      HEAPF32[$491>>2] = $489;
      $492 = (($kTriSegOrig) + 8|0);
      HEAPF32[$492>>2] = $490;
      $493 = Math_fround($83 - $72);
      $494 = Math_fround($86 - $75);
      $495 = Math_fround($90 - $79);
      HEAPF32[$kTriSegDir>>2] = $493;
      $496 = (($kTriSegDir) + 4|0);
      HEAPF32[$496>>2] = $494;
      $497 = (($kTriSegDir) + 8|0);
      HEAPF32[$497>>2] = $495;
      $498 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
      $499 = Math_fround(HEAPF32[$fT>>2]);
      $500 = Math_fround(Math_fround(1.0) - $499);
      HEAPF32[$fS>>2] = $500;
      $501 = Math_fround(HEAPF32[$triEdge0>>2]);
      $502 = Math_fround(HEAPF32[$p0>>2]);
      $503 = Math_fround($501 + $502);
      $504 = Math_fround(HEAPF32[$74>>2]);
      $505 = Math_fround(HEAPF32[$62>>2]);
      $506 = Math_fround($504 + $505);
      $507 = Math_fround(HEAPF32[$78>>2]);
      $508 = Math_fround(HEAPF32[$67>>2]);
      $509 = Math_fround($507 + $508);
      HEAPF32[$pt0$i76>>2] = $503;
      $510 = (($pt0$i76) + 4|0);
      HEAPF32[$510>>2] = $506;
      $511 = (($pt0$i76) + 8|0);
      HEAPF32[$511>>2] = $509;
      $512 = Math_fround(HEAPF32[$triEdge1>>2]);
      $513 = Math_fround($502 + $512);
      $514 = Math_fround(HEAPF32[$85>>2]);
      $515 = Math_fround($505 + $514);
      $516 = Math_fround(HEAPF32[$89>>2]);
      $517 = Math_fround($508 + $516);
      HEAPF32[$pt1$i77>>2] = $513;
      $518 = (($pt1$i77) + 4|0);
      HEAPF32[$518>>2] = $515;
      $519 = (($pt1$i77) + 8|0);
      HEAPF32[$519>>2] = $517;
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
      $520 = Math_fround(HEAPF32[$s$i78>>2]);
      HEAPF32[$fS0>>2] = $520;
      $521 = Math_fround(HEAPF32[$t$i79>>2]);
      HEAPF32[$fT0>>2] = $521;
      $522 = Math_fround(HEAPF32[$cp$i80>>2]);
      $523 = Math_fround(HEAPF32[$origin>>2]);
      $524 = Math_fround($522 - $523);
      $525 = (($cp$i80) + 4|0);
      $526 = Math_fround(HEAPF32[$525>>2]);
      $527 = Math_fround(HEAPF32[$64>>2]);
      $528 = Math_fround($526 - $527);
      $529 = (($cp$i80) + 8|0);
      $530 = Math_fround(HEAPF32[$529>>2]);
      $531 = Math_fround(HEAPF32[$69>>2]);
      $532 = Math_fround($530 - $531);
      $533 = Math_fround($524 * $524);
      $534 = Math_fround($528 * $528);
      $535 = Math_fround($533 + $534);
      $536 = Math_fround($532 * $532);
      $537 = Math_fround($535 + $536);
      HEAPF32[$fR0>>2] = Math_fround(0.0);
      $538 = $537 < $498;
      if (!($538)) {
       $fSqrDist$9 = $498;
       break;
      }
      HEAPF32[$fR>>2] = Math_fround(0.0);
      HEAPF32[$fS>>2] = $520;
      HEAPF32[$fT>>2] = $521;
      $fSqrDist$9 = $537;
      break;
     }
     HEAPF32[$kTriSegOrig>>2] = $59;
     $425 = (($kTriSegOrig) + 4|0);
     HEAPF32[$425>>2] = $63;
     $426 = (($kTriSegOrig) + 8|0);
     HEAPF32[$426>>2] = $68;
     HEAPF32[$kTriSegDir>>2] = $72;
     $427 = (($kTriSegDir) + 4|0);
     HEAPF32[$427>>2] = $75;
     $428 = (($kTriSegDir) + 8|0);
     HEAPF32[$428>>2] = $79;
     $429 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fS)));
     HEAPF32[$fT>>2] = Math_fround(0.0);
     $430 = Math_fround(HEAPF32[$p0>>2]);
     $431 = Math_fround(HEAPF32[$triEdge0>>2]);
     $432 = Math_fround($430 + $431);
     $433 = Math_fround(HEAPF32[$62>>2]);
     $434 = Math_fround(HEAPF32[$74>>2]);
     $435 = Math_fround($433 + $434);
     $436 = Math_fround(HEAPF32[$67>>2]);
     $437 = Math_fround(HEAPF32[$78>>2]);
     $438 = Math_fround($436 + $437);
     HEAPF32[$kTriSegOrig>>2] = $432;
     HEAPF32[$425>>2] = $435;
     HEAPF32[$426>>2] = $438;
     $439 = Math_fround(HEAPF32[$triEdge1>>2]);
     $440 = Math_fround($439 - $431);
     $441 = Math_fround(HEAPF32[$85>>2]);
     $442 = Math_fround($441 - $434);
     $443 = Math_fround(HEAPF32[$89>>2]);
     $444 = Math_fround($443 - $437);
     HEAPF32[$kTriSegDir>>2] = $440;
     HEAPF32[$427>>2] = $442;
     HEAPF32[$428>>2] = $444;
     $445 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fT0)));
     $446 = Math_fround(HEAPF32[$fT0>>2]);
     $447 = Math_fround(Math_fround(1.0) - $446);
     HEAPF32[$fS0>>2] = $447;
     $448 = $445 < $429;
     if ($448) {
      $449 = Math_fround(HEAPF32[$fR0>>2]);
      HEAPF32[$fR>>2] = $449;
      HEAPF32[$fS>>2] = $447;
      HEAPF32[$fT>>2] = $446;
      $fSqrDist$2 = $445;
     } else {
      $fSqrDist$2 = $429;
     }
     $450 = Math_fround(HEAPF32[$triEdge0>>2]);
     $451 = Math_fround(HEAPF32[$p0>>2]);
     $452 = Math_fround($450 + $451);
     $453 = Math_fround(HEAPF32[$74>>2]);
     $454 = Math_fround(HEAPF32[$62>>2]);
     $455 = Math_fround($453 + $454);
     $456 = Math_fround(HEAPF32[$78>>2]);
     $457 = Math_fround(HEAPF32[$67>>2]);
     $458 = Math_fround($456 + $457);
     HEAPF32[$pt0$i76>>2] = $452;
     $459 = (($pt0$i76) + 4|0);
     HEAPF32[$459>>2] = $455;
     $460 = (($pt0$i76) + 8|0);
     HEAPF32[$460>>2] = $458;
     $461 = Math_fround(HEAPF32[$triEdge1>>2]);
     $462 = Math_fround($451 + $461);
     $463 = Math_fround(HEAPF32[$85>>2]);
     $464 = Math_fround($454 + $463);
     $465 = Math_fround(HEAPF32[$89>>2]);
     $466 = Math_fround($457 + $465);
     HEAPF32[$pt1$i77>>2] = $462;
     $467 = (($pt1$i77) + 4|0);
     HEAPF32[$467>>2] = $464;
     $468 = (($pt1$i77) + 8|0);
     HEAPF32[$468>>2] = $466;
     __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
     $469 = Math_fround(HEAPF32[$s$i78>>2]);
     HEAPF32[$fS0>>2] = $469;
     $470 = Math_fround(HEAPF32[$t$i79>>2]);
     HEAPF32[$fT0>>2] = $470;
     $471 = Math_fround(HEAPF32[$cp$i80>>2]);
     $472 = Math_fround(HEAPF32[$origin>>2]);
     $473 = Math_fround($471 - $472);
     $474 = (($cp$i80) + 4|0);
     $475 = Math_fround(HEAPF32[$474>>2]);
     $476 = Math_fround(HEAPF32[$64>>2]);
     $477 = Math_fround($475 - $476);
     $478 = (($cp$i80) + 8|0);
     $479 = Math_fround(HEAPF32[$478>>2]);
     $480 = Math_fround(HEAPF32[$69>>2]);
     $481 = Math_fround($479 - $480);
     $482 = Math_fround($473 * $473);
     $483 = Math_fround($477 * $477);
     $484 = Math_fround($482 + $483);
     $485 = Math_fround($481 * $481);
     $486 = Math_fround($484 + $485);
     HEAPF32[$fR0>>2] = Math_fround(0.0);
     $487 = $486 < $fSqrDist$2;
     if (!($487)) {
      $fSqrDist$9 = $fSqrDist$2;
      break;
     }
     HEAPF32[$fR>>2] = Math_fround(0.0);
     HEAPF32[$fS>>2] = $469;
     HEAPF32[$fT>>2] = $470;
     $fSqrDist$9 = $486;
     break;
    } else {
     $198 = $193 < Math_fround(0.0);
     if (!($197)) {
      if (!($198)) {
       $333 = Math_fround($72 + $59);
       $334 = Math_fround($75 + $63);
       $335 = Math_fround($79 + $68);
       HEAPF32[$pt0$i76>>2] = $333;
       $336 = (($pt0$i76) + 4|0);
       HEAPF32[$336>>2] = $334;
       $337 = (($pt0$i76) + 8|0);
       HEAPF32[$337>>2] = $335;
       $338 = Math_fround($59 + $83);
       $339 = Math_fround($63 + $86);
       $340 = Math_fround($68 + $90);
       HEAPF32[$pt1$i77>>2] = $338;
       $341 = (($pt1$i77) + 4|0);
       HEAPF32[$341>>2] = $339;
       $342 = (($pt1$i77) + 8|0);
       HEAPF32[$342>>2] = $340;
       __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
       $343 = Math_fround(HEAPF32[$s$i78>>2]);
       HEAPF32[$fS>>2] = $343;
       $344 = Math_fround(HEAPF32[$t$i79>>2]);
       HEAPF32[$fT>>2] = $344;
       $345 = Math_fround(HEAPF32[$cp$i80>>2]);
       $346 = Math_fround(HEAPF32[$origin>>2]);
       $347 = Math_fround($345 - $346);
       $348 = (($cp$i80) + 4|0);
       $349 = Math_fround(HEAPF32[$348>>2]);
       $350 = Math_fround(HEAPF32[$64>>2]);
       $351 = Math_fround($349 - $350);
       $352 = (($cp$i80) + 8|0);
       $353 = Math_fround(HEAPF32[$352>>2]);
       $354 = Math_fround(HEAPF32[$69>>2]);
       $355 = Math_fround($353 - $354);
       $356 = Math_fround($347 * $347);
       $357 = Math_fround($351 * $351);
       $358 = Math_fround($356 + $357);
       $359 = Math_fround($355 * $355);
       $360 = Math_fround($358 + $359);
       HEAPF32[$fR>>2] = Math_fround(0.0);
       $fSqrDist$9 = $360;
       break;
      }
      HEAPF32[$kTriSegOrig>>2] = $59;
      $290 = (($kTriSegOrig) + 4|0);
      HEAPF32[$290>>2] = $63;
      $291 = (($kTriSegOrig) + 8|0);
      HEAPF32[$291>>2] = $68;
      HEAPF32[$kTriSegDir>>2] = $72;
      $292 = (($kTriSegDir) + 4|0);
      HEAPF32[$292>>2] = $75;
      $293 = (($kTriSegDir) + 8|0);
      HEAPF32[$293>>2] = $79;
      $294 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fS)));
      HEAPF32[$fT>>2] = Math_fround(0.0);
      $295 = Math_fround(HEAPF32[$triEdge0>>2]);
      $296 = Math_fround(HEAPF32[$p0>>2]);
      $297 = Math_fround($295 + $296);
      $298 = Math_fround(HEAPF32[$74>>2]);
      $299 = Math_fround(HEAPF32[$62>>2]);
      $300 = Math_fround($298 + $299);
      $301 = Math_fround(HEAPF32[$78>>2]);
      $302 = Math_fround(HEAPF32[$67>>2]);
      $303 = Math_fround($301 + $302);
      HEAPF32[$pt0$i76>>2] = $297;
      $304 = (($pt0$i76) + 4|0);
      HEAPF32[$304>>2] = $300;
      $305 = (($pt0$i76) + 8|0);
      HEAPF32[$305>>2] = $303;
      $306 = Math_fround(HEAPF32[$triEdge1>>2]);
      $307 = Math_fround($296 + $306);
      $308 = Math_fround(HEAPF32[$85>>2]);
      $309 = Math_fround($299 + $308);
      $310 = Math_fround(HEAPF32[$89>>2]);
      $311 = Math_fround($302 + $310);
      HEAPF32[$pt1$i77>>2] = $307;
      $312 = (($pt1$i77) + 4|0);
      HEAPF32[$312>>2] = $309;
      $313 = (($pt1$i77) + 8|0);
      HEAPF32[$313>>2] = $311;
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
      $314 = Math_fround(HEAPF32[$s$i78>>2]);
      HEAPF32[$fS0>>2] = $314;
      $315 = Math_fround(HEAPF32[$t$i79>>2]);
      HEAPF32[$fT0>>2] = $315;
      $316 = Math_fround(HEAPF32[$cp$i80>>2]);
      $317 = Math_fround(HEAPF32[$origin>>2]);
      $318 = Math_fround($316 - $317);
      $319 = (($cp$i80) + 4|0);
      $320 = Math_fround(HEAPF32[$319>>2]);
      $321 = Math_fround(HEAPF32[$64>>2]);
      $322 = Math_fround($320 - $321);
      $323 = (($cp$i80) + 8|0);
      $324 = Math_fround(HEAPF32[$323>>2]);
      $325 = Math_fround(HEAPF32[$69>>2]);
      $326 = Math_fround($324 - $325);
      $327 = Math_fround($318 * $318);
      $328 = Math_fround($322 * $322);
      $329 = Math_fround($327 + $328);
      $330 = Math_fround($326 * $326);
      $331 = Math_fround($329 + $330);
      HEAPF32[$fR0>>2] = Math_fround(0.0);
      $332 = $331 < $294;
      if (!($332)) {
       $fSqrDist$9 = $294;
       break;
      }
      HEAPF32[$fR>>2] = Math_fround(0.0);
      HEAPF32[$fS>>2] = $314;
      HEAPF32[$fT>>2] = $315;
      $fSqrDist$9 = $331;
      break;
     }
     HEAPF32[$kTriSegOrig>>2] = $59;
     $199 = (($kTriSegOrig) + 4|0);
     HEAPF32[$199>>2] = $63;
     $200 = (($kTriSegOrig) + 8|0);
     HEAPF32[$200>>2] = $68;
     HEAPF32[$kTriSegDir>>2] = $83;
     $201 = (($kTriSegDir) + 4|0);
     HEAPF32[$201>>2] = $86;
     $202 = (($kTriSegDir) + 8|0);
     HEAPF32[$202>>2] = $90;
     $203 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
     HEAPF32[$fS>>2] = Math_fround(0.0);
     if (!($198)) {
      $252 = Math_fround(HEAPF32[$triEdge0>>2]);
      $253 = Math_fround(HEAPF32[$p0>>2]);
      $254 = Math_fround($252 + $253);
      $255 = Math_fround(HEAPF32[$74>>2]);
      $256 = Math_fround(HEAPF32[$62>>2]);
      $257 = Math_fround($255 + $256);
      $258 = Math_fround(HEAPF32[$78>>2]);
      $259 = Math_fround(HEAPF32[$67>>2]);
      $260 = Math_fround($258 + $259);
      HEAPF32[$pt0$i76>>2] = $254;
      $261 = (($pt0$i76) + 4|0);
      HEAPF32[$261>>2] = $257;
      $262 = (($pt0$i76) + 8|0);
      HEAPF32[$262>>2] = $260;
      $263 = Math_fround(HEAPF32[$triEdge1>>2]);
      $264 = Math_fround($253 + $263);
      $265 = Math_fround(HEAPF32[$85>>2]);
      $266 = Math_fround($256 + $265);
      $267 = Math_fround(HEAPF32[$89>>2]);
      $268 = Math_fround($259 + $267);
      HEAPF32[$pt1$i77>>2] = $264;
      $269 = (($pt1$i77) + 4|0);
      HEAPF32[$269>>2] = $266;
      $270 = (($pt1$i77) + 8|0);
      HEAPF32[$270>>2] = $268;
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
      $271 = Math_fround(HEAPF32[$s$i78>>2]);
      HEAPF32[$fS0>>2] = $271;
      $272 = Math_fround(HEAPF32[$t$i79>>2]);
      HEAPF32[$fT0>>2] = $272;
      $273 = Math_fround(HEAPF32[$cp$i80>>2]);
      $274 = Math_fround(HEAPF32[$origin>>2]);
      $275 = Math_fround($273 - $274);
      $276 = (($cp$i80) + 4|0);
      $277 = Math_fround(HEAPF32[$276>>2]);
      $278 = Math_fround(HEAPF32[$64>>2]);
      $279 = Math_fround($277 - $278);
      $280 = (($cp$i80) + 8|0);
      $281 = Math_fround(HEAPF32[$280>>2]);
      $282 = Math_fround(HEAPF32[$69>>2]);
      $283 = Math_fround($281 - $282);
      $284 = Math_fround($275 * $275);
      $285 = Math_fround($279 * $279);
      $286 = Math_fround($284 + $285);
      $287 = Math_fround($283 * $283);
      $288 = Math_fround($286 + $287);
      HEAPF32[$fR0>>2] = Math_fround(0.0);
      $289 = $288 < $203;
      if (!($289)) {
       $fSqrDist$9 = $203;
       break;
      }
      HEAPF32[$fR>>2] = Math_fround(0.0);
      HEAPF32[$fS>>2] = $271;
      HEAPF32[$fT>>2] = $272;
      $fSqrDist$9 = $288;
      break;
     }
     $204 = Math_fround(HEAPF32[$p0>>2]);
     HEAPF32[$kTriSegOrig>>2] = $204;
     $205 = Math_fround(HEAPF32[$62>>2]);
     HEAPF32[$199>>2] = $205;
     $206 = Math_fround(HEAPF32[$67>>2]);
     HEAPF32[$200>>2] = $206;
     $207 = Math_fround(HEAPF32[$triEdge0>>2]);
     HEAPF32[$kTriSegDir>>2] = $207;
     $208 = Math_fround(HEAPF32[$74>>2]);
     HEAPF32[$201>>2] = $208;
     $209 = Math_fround(HEAPF32[$78>>2]);
     HEAPF32[$202>>2] = $209;
     $210 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fS0)));
     HEAPF32[$fT0>>2] = Math_fround(0.0);
     $211 = $210 < $203;
     if ($211) {
      $212 = Math_fround(HEAPF32[$fR0>>2]);
      HEAPF32[$fR>>2] = $212;
      $213 = Math_fround(HEAPF32[$fS0>>2]);
      HEAPF32[$fS>>2] = $213;
      HEAPF32[$fT>>2] = Math_fround(0.0);
      $fSqrDist$0 = $210;
     } else {
      $fSqrDist$0 = $203;
     }
     $214 = Math_fround(HEAPF32[$triEdge0>>2]);
     $215 = Math_fround(HEAPF32[$p0>>2]);
     $216 = Math_fround($214 + $215);
     $217 = Math_fround(HEAPF32[$74>>2]);
     $218 = Math_fround(HEAPF32[$62>>2]);
     $219 = Math_fround($217 + $218);
     $220 = Math_fround(HEAPF32[$78>>2]);
     $221 = Math_fround(HEAPF32[$67>>2]);
     $222 = Math_fround($220 + $221);
     HEAPF32[$pt0$i76>>2] = $216;
     $223 = (($pt0$i76) + 4|0);
     HEAPF32[$223>>2] = $219;
     $224 = (($pt0$i76) + 8|0);
     HEAPF32[$224>>2] = $222;
     $225 = Math_fround(HEAPF32[$triEdge1>>2]);
     $226 = Math_fround($215 + $225);
     $227 = Math_fround(HEAPF32[$85>>2]);
     $228 = Math_fround($218 + $227);
     $229 = Math_fround(HEAPF32[$89>>2]);
     $230 = Math_fround($221 + $229);
     HEAPF32[$pt1$i77>>2] = $226;
     $231 = (($pt1$i77) + 4|0);
     HEAPF32[$231>>2] = $228;
     $232 = (($pt1$i77) + 8|0);
     HEAPF32[$232>>2] = $230;
     __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$origin,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
     $233 = Math_fround(HEAPF32[$s$i78>>2]);
     HEAPF32[$fS0>>2] = $233;
     $234 = Math_fround(HEAPF32[$t$i79>>2]);
     HEAPF32[$fT0>>2] = $234;
     $235 = Math_fround(HEAPF32[$cp$i80>>2]);
     $236 = Math_fround(HEAPF32[$origin>>2]);
     $237 = Math_fround($235 - $236);
     $238 = (($cp$i80) + 4|0);
     $239 = Math_fround(HEAPF32[$238>>2]);
     $240 = Math_fround(HEAPF32[$64>>2]);
     $241 = Math_fround($239 - $240);
     $242 = (($cp$i80) + 8|0);
     $243 = Math_fround(HEAPF32[$242>>2]);
     $244 = Math_fround(HEAPF32[$69>>2]);
     $245 = Math_fround($243 - $244);
     $246 = Math_fround($237 * $237);
     $247 = Math_fround($241 * $241);
     $248 = Math_fround($246 + $247);
     $249 = Math_fround($245 * $245);
     $250 = Math_fround($248 + $249);
     HEAPF32[$fR0>>2] = Math_fround(0.0);
     $251 = $250 < $fSqrDist$0;
     if (!($251)) {
      $fSqrDist$9 = $fSqrDist$0;
      break;
     }
     HEAPF32[$fR>>2] = Math_fround(0.0);
     HEAPF32[$fS>>2] = $233;
     HEAPF32[$fT>>2] = $234;
     $fSqrDist$9 = $250;
     break;
    }
   }
   $539 = !($183 <= Math_fround(1.0));
   $540 = Math_fround($193 + $188);
   $541 = $540 <= Math_fround(1.0);
   $542 = $188 < Math_fround(0.0);
   if (!($539)) {
    if ($541) {
     $543 = $193 < Math_fround(0.0);
     if (!($542)) {
      if (!($543)) {
       $fSqrDist$9 = Math_fround(0.0);
       break;
      }
      HEAPF32[$kTriSegOrig>>2] = $59;
      $559 = (($kTriSegOrig) + 4|0);
      HEAPF32[$559>>2] = $63;
      $560 = (($kTriSegOrig) + 8|0);
      HEAPF32[$560>>2] = $68;
      HEAPF32[$kTriSegDir>>2] = $72;
      $561 = (($kTriSegDir) + 4|0);
      HEAPF32[$561>>2] = $75;
      $562 = (($kTriSegDir) + 8|0);
      HEAPF32[$562>>2] = $79;
      $563 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fS)));
      HEAPF32[$fT>>2] = Math_fround(0.0);
      $fSqrDist$9 = $563;
      break;
     }
     HEAPF32[$kTriSegOrig>>2] = $59;
     $544 = (($kTriSegOrig) + 4|0);
     HEAPF32[$544>>2] = $63;
     $545 = (($kTriSegOrig) + 8|0);
     HEAPF32[$545>>2] = $68;
     HEAPF32[$kTriSegDir>>2] = $83;
     $546 = (($kTriSegDir) + 4|0);
     HEAPF32[$546>>2] = $86;
     $547 = (($kTriSegDir) + 8|0);
     HEAPF32[$547>>2] = $90;
     $548 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
     HEAPF32[$fS>>2] = Math_fround(0.0);
     if (!($543)) {
      $fSqrDist$9 = $548;
      break;
     }
     $549 = Math_fround(HEAPF32[$p0>>2]);
     HEAPF32[$kTriSegOrig>>2] = $549;
     $550 = Math_fround(HEAPF32[$62>>2]);
     HEAPF32[$544>>2] = $550;
     $551 = Math_fround(HEAPF32[$67>>2]);
     HEAPF32[$545>>2] = $551;
     $552 = Math_fround(HEAPF32[$triEdge0>>2]);
     HEAPF32[$kTriSegDir>>2] = $552;
     $553 = Math_fround(HEAPF32[$74>>2]);
     HEAPF32[$546>>2] = $553;
     $554 = Math_fround(HEAPF32[$78>>2]);
     HEAPF32[$547>>2] = $554;
     $555 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fS0)));
     HEAPF32[$fT0>>2] = Math_fround(0.0);
     $556 = $555 < $548;
     if (!($556)) {
      $fSqrDist$9 = $548;
      break;
     }
     $557 = Math_fround(HEAPF32[$fR0>>2]);
     HEAPF32[$fR>>2] = $557;
     $558 = Math_fround(HEAPF32[$fS0>>2]);
     HEAPF32[$fS>>2] = $558;
     HEAPF32[$fT>>2] = Math_fround(0.0);
     $fSqrDist$9 = $555;
     break;
    }
    if ($542) {
     HEAPF32[$kTriSegOrig>>2] = $59;
     $564 = (($kTriSegOrig) + 4|0);
     HEAPF32[$564>>2] = $63;
     $565 = (($kTriSegOrig) + 8|0);
     HEAPF32[$565>>2] = $68;
     HEAPF32[$kTriSegDir>>2] = $83;
     $566 = (($kTriSegDir) + 4|0);
     HEAPF32[$566>>2] = $86;
     $567 = (($kTriSegDir) + 8|0);
     HEAPF32[$567>>2] = $90;
     $568 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
     HEAPF32[$fS>>2] = Math_fround(0.0);
     $569 = Math_fround(HEAPF32[$p0>>2]);
     $570 = Math_fround(HEAPF32[$triEdge0>>2]);
     $571 = Math_fround($569 + $570);
     $572 = Math_fround(HEAPF32[$62>>2]);
     $573 = Math_fround(HEAPF32[$74>>2]);
     $574 = Math_fround($572 + $573);
     $575 = Math_fround(HEAPF32[$67>>2]);
     $576 = Math_fround(HEAPF32[$78>>2]);
     $577 = Math_fround($575 + $576);
     HEAPF32[$kTriSegOrig>>2] = $571;
     HEAPF32[$564>>2] = $574;
     HEAPF32[$565>>2] = $577;
     $578 = Math_fround(HEAPF32[$triEdge1>>2]);
     $579 = Math_fround($578 - $570);
     $580 = Math_fround(HEAPF32[$85>>2]);
     $581 = Math_fround($580 - $573);
     $582 = Math_fround(HEAPF32[$89>>2]);
     $583 = Math_fround($582 - $576);
     HEAPF32[$kTriSegDir>>2] = $579;
     HEAPF32[$566>>2] = $581;
     HEAPF32[$567>>2] = $583;
     $584 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fT0)));
     $585 = Math_fround(HEAPF32[$fT0>>2]);
     $586 = Math_fround(Math_fround(1.0) - $585);
     HEAPF32[$fS0>>2] = $586;
     $587 = $584 < $568;
     if (!($587)) {
      $fSqrDist$9 = $568;
      break;
     }
     $588 = Math_fround(HEAPF32[$fR0>>2]);
     HEAPF32[$fR>>2] = $588;
     HEAPF32[$fS>>2] = $586;
     HEAPF32[$fT>>2] = $585;
     $fSqrDist$9 = $584;
     break;
    }
    $589 = $193 < Math_fround(0.0);
    if (!($589)) {
     $615 = Math_fround($59 + $72);
     $616 = Math_fround($63 + $75);
     $617 = Math_fround($68 + $79);
     HEAPF32[$kTriSegOrig>>2] = $615;
     $618 = (($kTriSegOrig) + 4|0);
     HEAPF32[$618>>2] = $616;
     $619 = (($kTriSegOrig) + 8|0);
     HEAPF32[$619>>2] = $617;
     $620 = Math_fround($83 - $72);
     $621 = Math_fround($86 - $75);
     $622 = Math_fround($90 - $79);
     HEAPF32[$kTriSegDir>>2] = $620;
     $623 = (($kTriSegDir) + 4|0);
     HEAPF32[$623>>2] = $621;
     $624 = (($kTriSegDir) + 8|0);
     HEAPF32[$624>>2] = $622;
     $625 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
     $626 = Math_fround(HEAPF32[$fT>>2]);
     $627 = Math_fround(Math_fround(1.0) - $626);
     HEAPF32[$fS>>2] = $627;
     $fSqrDist$9 = $625;
     break;
    }
    HEAPF32[$kTriSegOrig>>2] = $59;
    $590 = (($kTriSegOrig) + 4|0);
    HEAPF32[$590>>2] = $63;
    $591 = (($kTriSegOrig) + 8|0);
    HEAPF32[$591>>2] = $68;
    HEAPF32[$kTriSegDir>>2] = $72;
    $592 = (($kTriSegDir) + 4|0);
    HEAPF32[$592>>2] = $75;
    $593 = (($kTriSegDir) + 8|0);
    HEAPF32[$593>>2] = $79;
    $594 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fS)));
    HEAPF32[$fT>>2] = Math_fround(0.0);
    $595 = Math_fround(HEAPF32[$p0>>2]);
    $596 = Math_fround(HEAPF32[$triEdge0>>2]);
    $597 = Math_fround($595 + $596);
    $598 = Math_fround(HEAPF32[$62>>2]);
    $599 = Math_fround(HEAPF32[$74>>2]);
    $600 = Math_fround($598 + $599);
    $601 = Math_fround(HEAPF32[$67>>2]);
    $602 = Math_fround(HEAPF32[$78>>2]);
    $603 = Math_fround($601 + $602);
    HEAPF32[$kTriSegOrig>>2] = $597;
    HEAPF32[$590>>2] = $600;
    HEAPF32[$591>>2] = $603;
    $604 = Math_fround(HEAPF32[$triEdge1>>2]);
    $605 = Math_fround($604 - $596);
    $606 = Math_fround(HEAPF32[$85>>2]);
    $607 = Math_fround($606 - $599);
    $608 = Math_fround(HEAPF32[$89>>2]);
    $609 = Math_fround($608 - $602);
    HEAPF32[$kTriSegDir>>2] = $605;
    HEAPF32[$592>>2] = $607;
    HEAPF32[$593>>2] = $609;
    $610 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fT0)));
    $611 = Math_fround(HEAPF32[$fT0>>2]);
    $612 = Math_fround(Math_fround(1.0) - $611);
    HEAPF32[$fS0>>2] = $612;
    $613 = $610 < $594;
    if (!($613)) {
     $fSqrDist$9 = $594;
     break;
    }
    $614 = Math_fround(HEAPF32[$fR0>>2]);
    HEAPF32[$fR>>2] = $614;
    HEAPF32[$fS>>2] = $612;
    HEAPF32[$fT>>2] = $611;
    $fSqrDist$9 = $610;
    break;
   }
   if ($541) {
    $628 = $193 < Math_fround(0.0);
    if (!($542)) {
     if (!($628)) {
      $796 = Math_fround($60 + $0);
      $797 = Math_fround($65 + $3);
      $798 = Math_fround($70 + $7);
      HEAPF32[$kPt>>2] = $796;
      $799 = (($kPt) + 4|0);
      HEAPF32[$799>>2] = $797;
      $800 = (($kPt) + 8|0);
      HEAPF32[$800>>2] = $798;
      $801 = Math_fround($72 + $59);
      $802 = Math_fround($75 + $63);
      $803 = Math_fround($79 + $68);
      HEAPF32[$pt0$i76>>2] = $801;
      $804 = (($pt0$i76) + 4|0);
      HEAPF32[$804>>2] = $802;
      $805 = (($pt0$i76) + 8|0);
      HEAPF32[$805>>2] = $803;
      $806 = Math_fround($59 + $83);
      $807 = Math_fround($63 + $86);
      $808 = Math_fround($68 + $90);
      HEAPF32[$pt1$i77>>2] = $806;
      $809 = (($pt1$i77) + 4|0);
      HEAPF32[$809>>2] = $807;
      $810 = (($pt1$i77) + 8|0);
      HEAPF32[$810>>2] = $808;
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$kPt,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
      $811 = Math_fround(HEAPF32[$s$i78>>2]);
      HEAPF32[$fS>>2] = $811;
      $812 = Math_fround(HEAPF32[$t$i79>>2]);
      HEAPF32[$fT>>2] = $812;
      $813 = Math_fround(HEAPF32[$cp$i80>>2]);
      $814 = Math_fround(HEAPF32[$kPt>>2]);
      $815 = Math_fround($813 - $814);
      $816 = (($cp$i80) + 4|0);
      $817 = Math_fround(HEAPF32[$816>>2]);
      $818 = Math_fround(HEAPF32[$799>>2]);
      $819 = Math_fround($817 - $818);
      $820 = (($cp$i80) + 8|0);
      $821 = Math_fround(HEAPF32[$820>>2]);
      $822 = Math_fround(HEAPF32[$800>>2]);
      $823 = Math_fround($821 - $822);
      $824 = Math_fround($815 * $815);
      $825 = Math_fround($819 * $819);
      $826 = Math_fround($824 + $825);
      $827 = Math_fround($823 * $823);
      $828 = Math_fround($826 + $827);
      HEAPF32[$fR>>2] = Math_fround(1.0);
      $fSqrDist$9 = $828;
      break;
     }
     HEAPF32[$kTriSegOrig>>2] = $59;
     $742 = (($kTriSegOrig) + 4|0);
     HEAPF32[$742>>2] = $63;
     $743 = (($kTriSegOrig) + 8|0);
     HEAPF32[$743>>2] = $68;
     HEAPF32[$kTriSegDir>>2] = $72;
     $744 = (($kTriSegDir) + 4|0);
     HEAPF32[$744>>2] = $75;
     $745 = (($kTriSegDir) + 8|0);
     HEAPF32[$745>>2] = $79;
     $746 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fS)));
     HEAPF32[$fT>>2] = Math_fround(0.0);
     $747 = Math_fround(HEAPF32[$origin>>2]);
     $748 = Math_fround(HEAPF32[$dir>>2]);
     $749 = Math_fround($747 + $748);
     $750 = Math_fround(HEAPF32[$64>>2]);
     $751 = Math_fround(HEAPF32[$2>>2]);
     $752 = Math_fround($750 + $751);
     $753 = Math_fround(HEAPF32[$69>>2]);
     $754 = Math_fround(HEAPF32[$6>>2]);
     $755 = Math_fround($753 + $754);
     HEAPF32[$kPt>>2] = $749;
     $756 = (($kPt) + 4|0);
     HEAPF32[$756>>2] = $752;
     $757 = (($kPt) + 8|0);
     HEAPF32[$757>>2] = $755;
     $758 = Math_fround(HEAPF32[$triEdge0>>2]);
     $759 = Math_fround(HEAPF32[$p0>>2]);
     $760 = Math_fround($758 + $759);
     $761 = Math_fround(HEAPF32[$74>>2]);
     $762 = Math_fround(HEAPF32[$62>>2]);
     $763 = Math_fround($761 + $762);
     $764 = Math_fround(HEAPF32[$78>>2]);
     $765 = Math_fround(HEAPF32[$67>>2]);
     $766 = Math_fround($764 + $765);
     HEAPF32[$pt0$i76>>2] = $760;
     $767 = (($pt0$i76) + 4|0);
     HEAPF32[$767>>2] = $763;
     $768 = (($pt0$i76) + 8|0);
     HEAPF32[$768>>2] = $766;
     $769 = Math_fround(HEAPF32[$triEdge1>>2]);
     $770 = Math_fround($759 + $769);
     $771 = Math_fround(HEAPF32[$85>>2]);
     $772 = Math_fround($762 + $771);
     $773 = Math_fround(HEAPF32[$89>>2]);
     $774 = Math_fround($765 + $773);
     HEAPF32[$pt1$i77>>2] = $770;
     $775 = (($pt1$i77) + 4|0);
     HEAPF32[$775>>2] = $772;
     $776 = (($pt1$i77) + 8|0);
     HEAPF32[$776>>2] = $774;
     __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$kPt,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
     $777 = Math_fround(HEAPF32[$s$i78>>2]);
     HEAPF32[$fS0>>2] = $777;
     $778 = Math_fround(HEAPF32[$t$i79>>2]);
     HEAPF32[$fT0>>2] = $778;
     $779 = Math_fround(HEAPF32[$cp$i80>>2]);
     $780 = Math_fround(HEAPF32[$kPt>>2]);
     $781 = Math_fround($779 - $780);
     $782 = (($cp$i80) + 4|0);
     $783 = Math_fround(HEAPF32[$782>>2]);
     $784 = Math_fround(HEAPF32[$756>>2]);
     $785 = Math_fround($783 - $784);
     $786 = (($cp$i80) + 8|0);
     $787 = Math_fround(HEAPF32[$786>>2]);
     $788 = Math_fround(HEAPF32[$757>>2]);
     $789 = Math_fround($787 - $788);
     $790 = Math_fround($781 * $781);
     $791 = Math_fround($785 * $785);
     $792 = Math_fround($790 + $791);
     $793 = Math_fround($789 * $789);
     $794 = Math_fround($792 + $793);
     HEAPF32[$fR0>>2] = Math_fround(1.0);
     $795 = $794 < $746;
     if (!($795)) {
      $fSqrDist$9 = $746;
      break;
     }
     HEAPF32[$fR>>2] = Math_fround(1.0);
     HEAPF32[$fS>>2] = $777;
     HEAPF32[$fT>>2] = $778;
     $fSqrDist$9 = $794;
     break;
    }
    HEAPF32[$kTriSegOrig>>2] = $59;
    $629 = (($kTriSegOrig) + 4|0);
    HEAPF32[$629>>2] = $63;
    $630 = (($kTriSegOrig) + 8|0);
    HEAPF32[$630>>2] = $68;
    HEAPF32[$kTriSegDir>>2] = $83;
    $631 = (($kTriSegDir) + 4|0);
    HEAPF32[$631>>2] = $86;
    $632 = (($kTriSegDir) + 8|0);
    HEAPF32[$632>>2] = $90;
    $633 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
    HEAPF32[$fS>>2] = Math_fround(0.0);
    if (!($628)) {
     $693 = Math_fround(HEAPF32[$origin>>2]);
     $694 = Math_fround(HEAPF32[$dir>>2]);
     $695 = Math_fround($693 + $694);
     $696 = Math_fround(HEAPF32[$64>>2]);
     $697 = Math_fround(HEAPF32[$2>>2]);
     $698 = Math_fround($696 + $697);
     $699 = Math_fround(HEAPF32[$69>>2]);
     $700 = Math_fround(HEAPF32[$6>>2]);
     $701 = Math_fround($699 + $700);
     HEAPF32[$kPt>>2] = $695;
     $702 = (($kPt) + 4|0);
     HEAPF32[$702>>2] = $698;
     $703 = (($kPt) + 8|0);
     HEAPF32[$703>>2] = $701;
     $704 = Math_fround(HEAPF32[$triEdge0>>2]);
     $705 = Math_fround(HEAPF32[$p0>>2]);
     $706 = Math_fround($704 + $705);
     $707 = Math_fround(HEAPF32[$74>>2]);
     $708 = Math_fround(HEAPF32[$62>>2]);
     $709 = Math_fround($707 + $708);
     $710 = Math_fround(HEAPF32[$78>>2]);
     $711 = Math_fround(HEAPF32[$67>>2]);
     $712 = Math_fround($710 + $711);
     HEAPF32[$pt0$i76>>2] = $706;
     $713 = (($pt0$i76) + 4|0);
     HEAPF32[$713>>2] = $709;
     $714 = (($pt0$i76) + 8|0);
     HEAPF32[$714>>2] = $712;
     $715 = Math_fround(HEAPF32[$triEdge1>>2]);
     $716 = Math_fround($705 + $715);
     $717 = Math_fround(HEAPF32[$85>>2]);
     $718 = Math_fround($708 + $717);
     $719 = Math_fround(HEAPF32[$89>>2]);
     $720 = Math_fround($711 + $719);
     HEAPF32[$pt1$i77>>2] = $716;
     $721 = (($pt1$i77) + 4|0);
     HEAPF32[$721>>2] = $718;
     $722 = (($pt1$i77) + 8|0);
     HEAPF32[$722>>2] = $720;
     __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$kPt,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
     $723 = Math_fround(HEAPF32[$s$i78>>2]);
     HEAPF32[$fS0>>2] = $723;
     $724 = Math_fround(HEAPF32[$t$i79>>2]);
     HEAPF32[$fT0>>2] = $724;
     $725 = Math_fround(HEAPF32[$cp$i80>>2]);
     $726 = Math_fround(HEAPF32[$kPt>>2]);
     $727 = Math_fround($725 - $726);
     $728 = (($cp$i80) + 4|0);
     $729 = Math_fround(HEAPF32[$728>>2]);
     $730 = Math_fround(HEAPF32[$702>>2]);
     $731 = Math_fround($729 - $730);
     $732 = (($cp$i80) + 8|0);
     $733 = Math_fround(HEAPF32[$732>>2]);
     $734 = Math_fround(HEAPF32[$703>>2]);
     $735 = Math_fround($733 - $734);
     $736 = Math_fround($727 * $727);
     $737 = Math_fround($731 * $731);
     $738 = Math_fround($736 + $737);
     $739 = Math_fround($735 * $735);
     $740 = Math_fround($738 + $739);
     HEAPF32[$fR0>>2] = Math_fround(1.0);
     $741 = $740 < $633;
     if (!($741)) {
      $fSqrDist$9 = $633;
      break;
     }
     HEAPF32[$fR>>2] = Math_fround(1.0);
     HEAPF32[$fS>>2] = $723;
     HEAPF32[$fT>>2] = $724;
     $fSqrDist$9 = $740;
     break;
    }
    $634 = Math_fround(HEAPF32[$p0>>2]);
    HEAPF32[$kTriSegOrig>>2] = $634;
    $635 = Math_fround(HEAPF32[$62>>2]);
    HEAPF32[$629>>2] = $635;
    $636 = Math_fround(HEAPF32[$67>>2]);
    HEAPF32[$630>>2] = $636;
    $637 = Math_fround(HEAPF32[$triEdge0>>2]);
    HEAPF32[$kTriSegDir>>2] = $637;
    $638 = Math_fround(HEAPF32[$74>>2]);
    HEAPF32[$631>>2] = $638;
    $639 = Math_fround(HEAPF32[$78>>2]);
    HEAPF32[$632>>2] = $639;
    $640 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fS0)));
    HEAPF32[$fT0>>2] = Math_fround(0.0);
    $641 = $640 < $633;
    if ($641) {
     $642 = Math_fround(HEAPF32[$fR0>>2]);
     HEAPF32[$fR>>2] = $642;
     $643 = Math_fround(HEAPF32[$fS0>>2]);
     HEAPF32[$fS>>2] = $643;
     HEAPF32[$fT>>2] = Math_fround(0.0);
     $fSqrDist$3 = $640;
    } else {
     $fSqrDist$3 = $633;
    }
    $644 = Math_fround(HEAPF32[$origin>>2]);
    $645 = Math_fround(HEAPF32[$dir>>2]);
    $646 = Math_fround($644 + $645);
    $647 = Math_fround(HEAPF32[$64>>2]);
    $648 = Math_fround(HEAPF32[$2>>2]);
    $649 = Math_fround($647 + $648);
    $650 = Math_fround(HEAPF32[$69>>2]);
    $651 = Math_fround(HEAPF32[$6>>2]);
    $652 = Math_fround($650 + $651);
    HEAPF32[$kPt>>2] = $646;
    $653 = (($kPt) + 4|0);
    HEAPF32[$653>>2] = $649;
    $654 = (($kPt) + 8|0);
    HEAPF32[$654>>2] = $652;
    $655 = Math_fround(HEAPF32[$triEdge0>>2]);
    $656 = Math_fround(HEAPF32[$p0>>2]);
    $657 = Math_fround($655 + $656);
    $658 = Math_fround(HEAPF32[$74>>2]);
    $659 = Math_fround(HEAPF32[$62>>2]);
    $660 = Math_fround($658 + $659);
    $661 = Math_fround(HEAPF32[$78>>2]);
    $662 = Math_fround(HEAPF32[$67>>2]);
    $663 = Math_fround($661 + $662);
    HEAPF32[$pt0$i76>>2] = $657;
    $664 = (($pt0$i76) + 4|0);
    HEAPF32[$664>>2] = $660;
    $665 = (($pt0$i76) + 8|0);
    HEAPF32[$665>>2] = $663;
    $666 = Math_fround(HEAPF32[$triEdge1>>2]);
    $667 = Math_fround($656 + $666);
    $668 = Math_fround(HEAPF32[$85>>2]);
    $669 = Math_fround($659 + $668);
    $670 = Math_fround(HEAPF32[$89>>2]);
    $671 = Math_fround($662 + $670);
    HEAPF32[$pt1$i77>>2] = $667;
    $672 = (($pt1$i77) + 4|0);
    HEAPF32[$672>>2] = $669;
    $673 = (($pt1$i77) + 8|0);
    HEAPF32[$673>>2] = $671;
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$kPt,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
    $674 = Math_fround(HEAPF32[$s$i78>>2]);
    HEAPF32[$fS0>>2] = $674;
    $675 = Math_fround(HEAPF32[$t$i79>>2]);
    HEAPF32[$fT0>>2] = $675;
    $676 = Math_fround(HEAPF32[$cp$i80>>2]);
    $677 = Math_fround(HEAPF32[$kPt>>2]);
    $678 = Math_fround($676 - $677);
    $679 = (($cp$i80) + 4|0);
    $680 = Math_fround(HEAPF32[$679>>2]);
    $681 = Math_fround(HEAPF32[$653>>2]);
    $682 = Math_fround($680 - $681);
    $683 = (($cp$i80) + 8|0);
    $684 = Math_fround(HEAPF32[$683>>2]);
    $685 = Math_fround(HEAPF32[$654>>2]);
    $686 = Math_fround($684 - $685);
    $687 = Math_fround($678 * $678);
    $688 = Math_fround($682 * $682);
    $689 = Math_fround($687 + $688);
    $690 = Math_fround($686 * $686);
    $691 = Math_fround($689 + $690);
    HEAPF32[$fR0>>2] = Math_fround(1.0);
    $692 = $691 < $fSqrDist$3;
    if (!($692)) {
     $fSqrDist$9 = $fSqrDist$3;
     break;
    }
    HEAPF32[$fR>>2] = Math_fround(1.0);
    HEAPF32[$fS>>2] = $674;
    HEAPF32[$fT>>2] = $675;
    $fSqrDist$9 = $691;
    break;
   } else {
    if ($542) {
     HEAPF32[$kTriSegOrig>>2] = $59;
     $829 = (($kTriSegOrig) + 4|0);
     HEAPF32[$829>>2] = $63;
     $830 = (($kTriSegOrig) + 8|0);
     HEAPF32[$830>>2] = $68;
     HEAPF32[$kTriSegDir>>2] = $83;
     $831 = (($kTriSegDir) + 4|0);
     HEAPF32[$831>>2] = $86;
     $832 = (($kTriSegDir) + 8|0);
     HEAPF32[$832>>2] = $90;
     $833 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
     HEAPF32[$fS>>2] = Math_fround(0.0);
     $834 = Math_fround(HEAPF32[$p0>>2]);
     $835 = Math_fround(HEAPF32[$triEdge0>>2]);
     $836 = Math_fround($834 + $835);
     $837 = Math_fround(HEAPF32[$62>>2]);
     $838 = Math_fround(HEAPF32[$74>>2]);
     $839 = Math_fround($837 + $838);
     $840 = Math_fround(HEAPF32[$67>>2]);
     $841 = Math_fround(HEAPF32[$78>>2]);
     $842 = Math_fround($840 + $841);
     HEAPF32[$kTriSegOrig>>2] = $836;
     HEAPF32[$829>>2] = $839;
     HEAPF32[$830>>2] = $842;
     $843 = Math_fround(HEAPF32[$triEdge1>>2]);
     $844 = Math_fround($843 - $835);
     $845 = Math_fround(HEAPF32[$85>>2]);
     $846 = Math_fround($845 - $838);
     $847 = Math_fround(HEAPF32[$89>>2]);
     $848 = Math_fround($847 - $841);
     HEAPF32[$kTriSegDir>>2] = $844;
     HEAPF32[$831>>2] = $846;
     HEAPF32[$832>>2] = $848;
     $849 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fT0)));
     $850 = Math_fround(HEAPF32[$fT0>>2]);
     $851 = Math_fround(Math_fround(1.0) - $850);
     HEAPF32[$fS0>>2] = $851;
     $852 = $849 < $833;
     if ($852) {
      $853 = Math_fround(HEAPF32[$fR0>>2]);
      HEAPF32[$fR>>2] = $853;
      HEAPF32[$fS>>2] = $851;
      HEAPF32[$fT>>2] = $850;
      $fSqrDist$4 = $849;
     } else {
      $fSqrDist$4 = $833;
     }
     $854 = Math_fround(HEAPF32[$origin>>2]);
     $855 = Math_fround(HEAPF32[$dir>>2]);
     $856 = Math_fround($854 + $855);
     $857 = Math_fround(HEAPF32[$64>>2]);
     $858 = Math_fround(HEAPF32[$2>>2]);
     $859 = Math_fround($857 + $858);
     $860 = Math_fround(HEAPF32[$69>>2]);
     $861 = Math_fround(HEAPF32[$6>>2]);
     $862 = Math_fround($860 + $861);
     HEAPF32[$kPt>>2] = $856;
     $863 = (($kPt) + 4|0);
     HEAPF32[$863>>2] = $859;
     $864 = (($kPt) + 8|0);
     HEAPF32[$864>>2] = $862;
     $865 = Math_fround(HEAPF32[$triEdge0>>2]);
     $866 = Math_fround(HEAPF32[$p0>>2]);
     $867 = Math_fround($865 + $866);
     $868 = Math_fround(HEAPF32[$74>>2]);
     $869 = Math_fround(HEAPF32[$62>>2]);
     $870 = Math_fround($868 + $869);
     $871 = Math_fround(HEAPF32[$78>>2]);
     $872 = Math_fround(HEAPF32[$67>>2]);
     $873 = Math_fround($871 + $872);
     HEAPF32[$pt0$i76>>2] = $867;
     $874 = (($pt0$i76) + 4|0);
     HEAPF32[$874>>2] = $870;
     $875 = (($pt0$i76) + 8|0);
     HEAPF32[$875>>2] = $873;
     $876 = Math_fround(HEAPF32[$triEdge1>>2]);
     $877 = Math_fround($866 + $876);
     $878 = Math_fround(HEAPF32[$85>>2]);
     $879 = Math_fround($869 + $878);
     $880 = Math_fround(HEAPF32[$89>>2]);
     $881 = Math_fround($872 + $880);
     HEAPF32[$pt1$i77>>2] = $877;
     $882 = (($pt1$i77) + 4|0);
     HEAPF32[$882>>2] = $879;
     $883 = (($pt1$i77) + 8|0);
     HEAPF32[$883>>2] = $881;
     __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$kPt,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
     $884 = Math_fround(HEAPF32[$s$i78>>2]);
     HEAPF32[$fS0>>2] = $884;
     $885 = Math_fround(HEAPF32[$t$i79>>2]);
     HEAPF32[$fT0>>2] = $885;
     $886 = Math_fround(HEAPF32[$cp$i80>>2]);
     $887 = Math_fround(HEAPF32[$kPt>>2]);
     $888 = Math_fround($886 - $887);
     $889 = (($cp$i80) + 4|0);
     $890 = Math_fround(HEAPF32[$889>>2]);
     $891 = Math_fround(HEAPF32[$863>>2]);
     $892 = Math_fround($890 - $891);
     $893 = (($cp$i80) + 8|0);
     $894 = Math_fround(HEAPF32[$893>>2]);
     $895 = Math_fround(HEAPF32[$864>>2]);
     $896 = Math_fround($894 - $895);
     $897 = Math_fround($888 * $888);
     $898 = Math_fround($892 * $892);
     $899 = Math_fround($897 + $898);
     $900 = Math_fround($896 * $896);
     $901 = Math_fround($899 + $900);
     HEAPF32[$fR0>>2] = Math_fround(1.0);
     $902 = $901 < $fSqrDist$4;
     if (!($902)) {
      $fSqrDist$9 = $fSqrDist$4;
      break;
     }
     HEAPF32[$fR>>2] = Math_fround(1.0);
     HEAPF32[$fS>>2] = $884;
     HEAPF32[$fT>>2] = $885;
     $fSqrDist$9 = $901;
     break;
    }
    $903 = $193 < Math_fround(0.0);
    if (!($903)) {
     $978 = Math_fround($59 + $72);
     $979 = Math_fround($63 + $75);
     $980 = Math_fround($68 + $79);
     HEAPF32[$kTriSegOrig>>2] = $978;
     $981 = (($kTriSegOrig) + 4|0);
     HEAPF32[$981>>2] = $979;
     $982 = (($kTriSegOrig) + 8|0);
     HEAPF32[$982>>2] = $980;
     $983 = Math_fround($83 - $72);
     $984 = Math_fround($86 - $75);
     $985 = Math_fround($90 - $79);
     HEAPF32[$kTriSegDir>>2] = $983;
     $986 = (($kTriSegDir) + 4|0);
     HEAPF32[$986>>2] = $984;
     $987 = (($kTriSegDir) + 8|0);
     HEAPF32[$987>>2] = $985;
     $988 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fT)));
     $989 = Math_fround(HEAPF32[$fT>>2]);
     $990 = Math_fround(Math_fround(1.0) - $989);
     HEAPF32[$fS>>2] = $990;
     $991 = Math_fround(HEAPF32[$origin>>2]);
     $992 = Math_fround(HEAPF32[$dir>>2]);
     $993 = Math_fround($991 + $992);
     $994 = Math_fround(HEAPF32[$64>>2]);
     $995 = Math_fround(HEAPF32[$2>>2]);
     $996 = Math_fround($994 + $995);
     $997 = Math_fround(HEAPF32[$69>>2]);
     $998 = Math_fround(HEAPF32[$6>>2]);
     $999 = Math_fround($997 + $998);
     HEAPF32[$kPt>>2] = $993;
     $1000 = (($kPt) + 4|0);
     HEAPF32[$1000>>2] = $996;
     $1001 = (($kPt) + 8|0);
     HEAPF32[$1001>>2] = $999;
     $1002 = Math_fround(HEAPF32[$triEdge0>>2]);
     $1003 = Math_fround(HEAPF32[$p0>>2]);
     $1004 = Math_fround($1002 + $1003);
     $1005 = Math_fround(HEAPF32[$74>>2]);
     $1006 = Math_fround(HEAPF32[$62>>2]);
     $1007 = Math_fround($1005 + $1006);
     $1008 = Math_fround(HEAPF32[$78>>2]);
     $1009 = Math_fround(HEAPF32[$67>>2]);
     $1010 = Math_fround($1008 + $1009);
     HEAPF32[$pt0$i76>>2] = $1004;
     $1011 = (($pt0$i76) + 4|0);
     HEAPF32[$1011>>2] = $1007;
     $1012 = (($pt0$i76) + 8|0);
     HEAPF32[$1012>>2] = $1010;
     $1013 = Math_fround(HEAPF32[$triEdge1>>2]);
     $1014 = Math_fround($1003 + $1013);
     $1015 = Math_fround(HEAPF32[$85>>2]);
     $1016 = Math_fround($1006 + $1015);
     $1017 = Math_fround(HEAPF32[$89>>2]);
     $1018 = Math_fround($1009 + $1017);
     HEAPF32[$pt1$i77>>2] = $1014;
     $1019 = (($pt1$i77) + 4|0);
     HEAPF32[$1019>>2] = $1016;
     $1020 = (($pt1$i77) + 8|0);
     HEAPF32[$1020>>2] = $1018;
     __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$kPt,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
     $1021 = Math_fround(HEAPF32[$s$i78>>2]);
     HEAPF32[$fS0>>2] = $1021;
     $1022 = Math_fround(HEAPF32[$t$i79>>2]);
     HEAPF32[$fT0>>2] = $1022;
     $1023 = Math_fround(HEAPF32[$cp$i80>>2]);
     $1024 = Math_fround(HEAPF32[$kPt>>2]);
     $1025 = Math_fround($1023 - $1024);
     $1026 = (($cp$i80) + 4|0);
     $1027 = Math_fround(HEAPF32[$1026>>2]);
     $1028 = Math_fround(HEAPF32[$1000>>2]);
     $1029 = Math_fround($1027 - $1028);
     $1030 = (($cp$i80) + 8|0);
     $1031 = Math_fround(HEAPF32[$1030>>2]);
     $1032 = Math_fround(HEAPF32[$1001>>2]);
     $1033 = Math_fround($1031 - $1032);
     $1034 = Math_fround($1025 * $1025);
     $1035 = Math_fround($1029 * $1029);
     $1036 = Math_fround($1034 + $1035);
     $1037 = Math_fround($1033 * $1033);
     $1038 = Math_fround($1036 + $1037);
     HEAPF32[$fR0>>2] = Math_fround(1.0);
     $1039 = $1038 < $988;
     if (!($1039)) {
      $fSqrDist$9 = $988;
      break;
     }
     HEAPF32[$fR>>2] = Math_fround(1.0);
     HEAPF32[$fS>>2] = $1021;
     HEAPF32[$fT>>2] = $1022;
     $fSqrDist$9 = $1038;
     break;
    }
    HEAPF32[$kTriSegOrig>>2] = $59;
    $904 = (($kTriSegOrig) + 4|0);
    HEAPF32[$904>>2] = $63;
    $905 = (($kTriSegOrig) + 8|0);
    HEAPF32[$905>>2] = $68;
    HEAPF32[$kTriSegDir>>2] = $72;
    $906 = (($kTriSegDir) + 4|0);
    HEAPF32[$906>>2] = $75;
    $907 = (($kTriSegDir) + 8|0);
    HEAPF32[$907>>2] = $79;
    $908 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR,$fS)));
    HEAPF32[$fT>>2] = Math_fround(0.0);
    $909 = Math_fround(HEAPF32[$p0>>2]);
    $910 = Math_fround(HEAPF32[$triEdge0>>2]);
    $911 = Math_fround($909 + $910);
    $912 = Math_fround(HEAPF32[$62>>2]);
    $913 = Math_fround(HEAPF32[$74>>2]);
    $914 = Math_fround($912 + $913);
    $915 = Math_fround(HEAPF32[$67>>2]);
    $916 = Math_fround(HEAPF32[$78>>2]);
    $917 = Math_fround($915 + $916);
    HEAPF32[$kTriSegOrig>>2] = $911;
    HEAPF32[$904>>2] = $914;
    HEAPF32[$905>>2] = $917;
    $918 = Math_fround(HEAPF32[$triEdge1>>2]);
    $919 = Math_fround($918 - $910);
    $920 = Math_fround(HEAPF32[$85>>2]);
    $921 = Math_fround($920 - $913);
    $922 = Math_fround(HEAPF32[$89>>2]);
    $923 = Math_fround($922 - $916);
    HEAPF32[$kTriSegDir>>2] = $919;
    HEAPF32[$906>>2] = $921;
    HEAPF32[$907>>2] = $923;
    $924 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($origin,$dir,$kTriSegOrig,$kTriSegDir,$fR0,$fT0)));
    $925 = Math_fround(HEAPF32[$fT0>>2]);
    $926 = Math_fround(Math_fround(1.0) - $925);
    HEAPF32[$fS0>>2] = $926;
    $927 = $924 < $908;
    if ($927) {
     $928 = Math_fround(HEAPF32[$fR0>>2]);
     HEAPF32[$fR>>2] = $928;
     HEAPF32[$fS>>2] = $926;
     HEAPF32[$fT>>2] = $925;
     $fSqrDist$5 = $924;
    } else {
     $fSqrDist$5 = $908;
    }
    $929 = Math_fround(HEAPF32[$origin>>2]);
    $930 = Math_fround(HEAPF32[$dir>>2]);
    $931 = Math_fround($929 + $930);
    $932 = Math_fround(HEAPF32[$64>>2]);
    $933 = Math_fround(HEAPF32[$2>>2]);
    $934 = Math_fround($932 + $933);
    $935 = Math_fround(HEAPF32[$69>>2]);
    $936 = Math_fround(HEAPF32[$6>>2]);
    $937 = Math_fround($935 + $936);
    HEAPF32[$kPt>>2] = $931;
    $938 = (($kPt) + 4|0);
    HEAPF32[$938>>2] = $934;
    $939 = (($kPt) + 8|0);
    HEAPF32[$939>>2] = $937;
    $940 = Math_fround(HEAPF32[$triEdge0>>2]);
    $941 = Math_fround(HEAPF32[$p0>>2]);
    $942 = Math_fround($940 + $941);
    $943 = Math_fround(HEAPF32[$74>>2]);
    $944 = Math_fround(HEAPF32[$62>>2]);
    $945 = Math_fround($943 + $944);
    $946 = Math_fround(HEAPF32[$78>>2]);
    $947 = Math_fround(HEAPF32[$67>>2]);
    $948 = Math_fround($946 + $947);
    HEAPF32[$pt0$i76>>2] = $942;
    $949 = (($pt0$i76) + 4|0);
    HEAPF32[$949>>2] = $945;
    $950 = (($pt0$i76) + 8|0);
    HEAPF32[$950>>2] = $948;
    $951 = Math_fround(HEAPF32[$triEdge1>>2]);
    $952 = Math_fround($941 + $951);
    $953 = Math_fround(HEAPF32[$85>>2]);
    $954 = Math_fround($944 + $953);
    $955 = Math_fround(HEAPF32[$89>>2]);
    $956 = Math_fround($947 + $955);
    HEAPF32[$pt1$i77>>2] = $952;
    $957 = (($pt1$i77) + 4|0);
    HEAPF32[$957>>2] = $954;
    $958 = (($pt1$i77) + 8|0);
    HEAPF32[$958>>2] = $956;
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($cp$i80,$kPt,$p0,$pt0$i76,$pt1$i77,$s$i78,$t$i79);
    $959 = Math_fround(HEAPF32[$s$i78>>2]);
    HEAPF32[$fS0>>2] = $959;
    $960 = Math_fround(HEAPF32[$t$i79>>2]);
    HEAPF32[$fT0>>2] = $960;
    $961 = Math_fround(HEAPF32[$cp$i80>>2]);
    $962 = Math_fround(HEAPF32[$kPt>>2]);
    $963 = Math_fround($961 - $962);
    $964 = (($cp$i80) + 4|0);
    $965 = Math_fround(HEAPF32[$964>>2]);
    $966 = Math_fround(HEAPF32[$938>>2]);
    $967 = Math_fround($965 - $966);
    $968 = (($cp$i80) + 8|0);
    $969 = Math_fround(HEAPF32[$968>>2]);
    $970 = Math_fround(HEAPF32[$939>>2]);
    $971 = Math_fround($969 - $970);
    $972 = Math_fround($963 * $963);
    $973 = Math_fround($967 * $967);
    $974 = Math_fround($972 + $973);
    $975 = Math_fround($971 * $971);
    $976 = Math_fround($974 + $975);
    HEAPF32[$fR0>>2] = Math_fround(1.0);
    $977 = $976 < $fSqrDist$5;
    if (!($977)) {
     $fSqrDist$9 = $fSqrDist$5;
     break;
    }
    HEAPF32[$fR>>2] = Math_fround(1.0);
    HEAPF32[$fS>>2] = $959;
    HEAPF32[$fT>>2] = $960;
    $fSqrDist$9 = $976;
    break;
   }
  }
 } while(0);
 $1156 = ($t|0)==(0|0);
 if (!($1156)) {
  $1157 = Math_fround(HEAPF32[$fR>>2]);
  HEAPF32[$t>>2] = $1157;
 }
 $1158 = ($u|0)==(0|0);
 if (!($1158)) {
  $1159 = Math_fround(HEAPF32[$fS>>2]);
  HEAPF32[$u>>2] = $1159;
 }
 $1160 = ($v|0)==(0|0);
 if (!($1160)) {
  $1161 = Math_fround(HEAPF32[$fT>>2]);
  HEAPF32[$v>>2] = $1161;
 }
 $1162 = $fSqrDist$9 < Math_fround(0.0);
 $1163 = $1162 ? Math_fround(0.0) : $fSqrDist$9;
 $$0 = $1163;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5physx2Gu30distanceSegmentTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_RS3_S6_($agg$result,$p,$q,$a,$b,$c,$closest0,$closest1) {
 $agg$result = $agg$result|0;
 $p = $p|0;
 $q = $q|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $closest0 = $closest0|0;
 $closest1 = $closest1|0;
 var $$$$i = 0, $$$$i215 = 0, $$$$i414 = 0, $$$i = 0, $$$i214 = 0, $$$i413 = 0, $$in1$i = 0, $$in1$i115 = 0, $$in1$i127 = 0, $$in1$i143 = 0, $$in1$i155 = 0, $$in1$i23 = 0, $$in1$i276 = 0, $$in1$i288 = 0, $$in1$i300 = 0, $$in1$i312 = 0, $$in1$i35 = 0, $$in1$i47 = 0, $$in1$i59 = 0, $$in1$i71 = 0;
 var $$in1$i87 = 0, $$in1$i99 = 0, $$in2$i = 0, $$in2$i101 = 0, $$in2$i117 = 0, $$in2$i129 = 0, $$in2$i145 = 0, $$in2$i157 = 0, $$in2$i25 = 0, $$in2$i278 = 0, $$in2$i290 = 0, $$in2$i302 = 0, $$in2$i314 = 0, $$in2$i37 = 0, $$in2$i49 = 0, $$in2$i61 = 0, $$in2$i73 = 0, $$in2$i89 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0);
 var $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0);
 var $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0);
 var $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0);
 var $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0);
 var $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0);
 var $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0);
 var $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0);
 var $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0);
 var $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0);
 var $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = 0;
 var $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0);
 var $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn3$i = 0, $a$pn3$i275 = 0, $a$pn3$i287 = 0, $a$pn3$i299 = 0, $a$pn3$i311 = 0, $a$pn3$i46 = 0, $ab = 0, $ac = 0, $b$a$i = 0, $b$a$i112 = 0, $b$a$i124 = 0, $b$a$i140 = 0, $b$a$i152 = 0, $b$a$i20 = 0, $b$a$i273 = 0, $b$a$i285 = 0;
 var $b$a$i297 = 0, $b$a$i309 = 0, $b$a$i32 = 0, $b$a$i44 = 0, $b$a$i56 = 0, $b$a$i68 = 0, $b$a$i84 = 0, $b$a$i96 = 0, $b$a5$i = 0, $b$a5$i277 = 0, $b$a5$i289 = 0, $b$a5$i301 = 0, $b$a5$i313 = 0, $b$a5$i48 = 0, $bc = 0, $closestP30 = 0, $closestP40 = 0, $not$$$$i215 = 0, $not$$$$i2151870 = 0, $not$$$$i2151871 = 0;
 var $not$$i = 0, $not$$i212 = 0, $not$$i411 = 0, $not$169$i = 0, $not$169$i213 = 0, $not$169$i412 = 0, $phitmp = 0, $phitmp1865 = 0, $phitmp1865$ = 0, $phitmp1865$1868 = 0, $phitmp1865$1869 = 0, $pq = 0, $sqDist44 = 0, $t40 = 0, $t41 = 0, $zero$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 672|0;
 $0 = sp + 560|0;
 $1 = sp + 512|0;
 $2 = sp + 528|0;
 $3 = sp + 544|0;
 $4 = sp + 576|0;
 $5 = sp + 592|0;
 $6 = sp + 608|0;
 $7 = sp + 624|0;
 $8 = sp + 640|0;
 $9 = sp + 496|0;
 $10 = sp + 480|0;
 $11 = sp + 464|0;
 $12 = sp + 448|0;
 $13 = sp + 432|0;
 $14 = sp + 416|0;
 $15 = sp + 400|0;
 $16 = sp + 384|0;
 $17 = sp + 368|0;
 $18 = sp + 352|0;
 $19 = sp + 336|0;
 $20 = sp + 144|0;
 $21 = sp + 128|0;
 $22 = sp + 112|0;
 $23 = sp + 96|0;
 $24 = sp + 80|0;
 $25 = sp + 64|0;
 $26 = sp + 32|0;
 $27 = sp + 16|0;
 $28 = sp;
 $29 = sp + 48|0;
 $30 = sp + 160|0;
 $31 = sp + 176|0;
 $zero$sroa$1 = sp + 656|0;
 $pq = sp + 192|0;
 $ab = sp + 208|0;
 $ac = sp + 224|0;
 $bc = sp + 240|0;
 $t40 = sp + 256|0;
 $t41 = sp + 272|0;
 $sqDist44 = sp + 288|0;
 $closestP30 = sp + 304|0;
 $closestP40 = sp + 320|0;
 $32 = Math_fround(HEAPF32[$q>>2]);
 $33 = (($q) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($q) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$p>>2]);
 $38 = (($p) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($p) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($32 - $37);
 $43 = Math_fround($34 - $39);
 $44 = Math_fround($36 - $41);
 HEAPF32[$pq>>2] = $42;
 $45 = (($pq) + 4|0);
 HEAPF32[$45>>2] = $43;
 $46 = (($pq) + 8|0);
 HEAPF32[$46>>2] = $44;
 $47 = (($pq) + 12|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = Math_fround(HEAPF32[$b>>2]);
 $49 = (($b) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($b) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(HEAPF32[$a>>2]);
 $54 = (($a) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($a) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($48 - $53);
 $59 = Math_fround($50 - $55);
 $60 = Math_fround($52 - $57);
 HEAPF32[$ab>>2] = $58;
 $61 = (($ab) + 4|0);
 HEAPF32[$61>>2] = $59;
 $62 = (($ab) + 8|0);
 HEAPF32[$62>>2] = $60;
 $63 = (($ab) + 12|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = Math_fround(HEAPF32[$c>>2]);
 $65 = (($c) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($c) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($64 - $53);
 $70 = Math_fround($66 - $55);
 $71 = Math_fround($68 - $57);
 HEAPF32[$ac>>2] = $69;
 $72 = (($ac) + 4|0);
 HEAPF32[$72>>2] = $70;
 $73 = (($ac) + 8|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($ac) + 12|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = Math_fround($64 - $48);
 $76 = Math_fround($66 - $50);
 $77 = Math_fround($68 - $52);
 HEAPF32[$bc>>2] = $75;
 $78 = (($bc) + 4|0);
 HEAPF32[$78>>2] = $76;
 $79 = (($bc) + 8|0);
 HEAPF32[$79>>2] = $77;
 $80 = (($bc) + 12|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 $81 = Math_fround($37 - $53);
 $82 = Math_fround($39 - $55);
 $83 = Math_fround($41 - $57);
 $84 = Math_fround($32 - $53);
 $85 = Math_fround($34 - $55);
 $86 = Math_fround($36 - $57);
 $87 = Math_fround($58 * $58);
 $88 = Math_fround($59 * $59);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($60 * $60);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($58 * $69);
 $93 = Math_fround($59 * $70);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($60 * $71);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($69 * $69);
 $98 = Math_fround($70 * $70);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($71 * $71);
 $101 = Math_fround($99 + $100);
 $102 = Math_fround($91 * $101);
 $103 = Math_fround($96 * $96);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround(Math_fround(1.0) / $104);
 $106 = Math_fround($59 * $71);
 $107 = Math_fround($60 * $70);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($60 * $69);
 $110 = Math_fround($58 * $71);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($58 * $70);
 $113 = Math_fround($59 * $69);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($108 * $108);
 $116 = Math_fround($111 * $111);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($114 * $114);
 $119 = Math_fround($118 + $117);
 $120 = (Math_fround(Math_sqrt((Math_fround($119)))));
 $121 = Math_fround(Math_fround(1.0) / $120);
 $122 = Math_fround($108 * $121);
 $123 = Math_fround($111 * $121);
 $124 = Math_fround($114 * $121);
 $125 = Math_fround($81 * $122);
 $126 = Math_fround($82 * $123);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround($83 * $124);
 $129 = Math_fround($128 + $127);
 $130 = Math_fround($129 * $129);
 $131 = Math_fround($84 * $122);
 $132 = Math_fround($85 * $123);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround($86 * $124);
 $135 = Math_fround($134 + $133);
 $136 = Math_fround($135 * $135);
 $137 = Math_fround($129 * $135);
 $138 = $137 < Math_fround(0.0);
 if ($138) {
  $139 = Math_fround(HEAPF32[$pq>>2]);
  $140 = Math_fround(HEAPF32[$45>>2]);
  $141 = Math_fround(HEAPF32[$46>>2]);
  $142 = Math_fround($122 * $139);
  $143 = Math_fround($123 * $140);
  $144 = Math_fround($142 + $143);
  $145 = Math_fround($124 * $141);
  $146 = Math_fround($144 + $145);
  $147 = Math_fround(Math_fround(1.0) / $146);
  $148 = Math_fround($129 * $147);
  $149 = Math_fround(-$148);
  $150 = Math_fround(HEAPF32[$p>>2]);
  $151 = Math_fround(HEAPF32[$38>>2]);
  $152 = Math_fround(HEAPF32[$40>>2]);
  $153 = Math_fround($139 * $149);
  $154 = Math_fround($140 * $149);
  $155 = Math_fround($141 * $149);
  $156 = Math_fround($153 + $150);
  $157 = Math_fround($154 + $151);
  $158 = Math_fround($155 + $152);
  $159 = Math_fround(HEAPF32[$a>>2]);
  $160 = Math_fround(HEAPF32[$54>>2]);
  $161 = Math_fround(HEAPF32[$56>>2]);
  $162 = Math_fround($156 - $159);
  $163 = Math_fround($157 - $160);
  $164 = Math_fround($158 - $161);
  $165 = Math_fround($162 * $58);
  $166 = Math_fround($163 * $59);
  $167 = Math_fround($165 + $166);
  $168 = Math_fround($164 * $60);
  $169 = Math_fround($167 + $168);
  $170 = Math_fround($162 * $69);
  $171 = Math_fround($163 * $70);
  $172 = Math_fround($170 + $171);
  $173 = Math_fround($164 * $71);
  $174 = Math_fround($172 + $173);
  $175 = Math_fround($101 * $169);
  $176 = Math_fround($96 * $174);
  $177 = Math_fround($175 - $176);
  $178 = Math_fround($105 * $177);
  $179 = Math_fround($91 * $174);
  $180 = Math_fround($96 * $169);
  $181 = Math_fround($179 - $180);
  $182 = Math_fround($105 * $181);
  $183 = $178 <= Math_fround(1.0);
  $not$$i411 = $178 >= Math_fround(0.0);
  $184 = $183 & $not$$i411;
  $185 = $182 <= Math_fround(1.0);
  $not$169$i412 = $182 >= Math_fround(0.0);
  $186 = $185 & $not$169$i412;
  $187 = Math_fround($178 + $182);
  $188 = $187 < Math_fround(1.0);
  $$$i413 = $188 & $186;
  $$$$i414 = $$$i413 & $184;
  if ($$$$i414) {
   HEAPF32[$closest1>>2] = $156;
   $189 = (($closest1) + 4|0);
   HEAPF32[$189>>2] = $157;
   $190 = (($closest1) + 8|0);
   HEAPF32[$190>>2] = $158;
   $191 = (($closest1) + 12|0);
   HEAPF32[$191>>2] = Math_fround(0.0);
   ;HEAP32[$closest0+0>>2]=HEAP32[$closest1+0>>2]|0;HEAP32[$closest0+4>>2]=HEAP32[$closest1+4>>2]|0;HEAP32[$closest0+8>>2]=HEAP32[$closest1+8>>2]|0;HEAP32[$closest0+12>>2]=HEAP32[$closest1+12>>2]|0;
   HEAPF32[$agg$result>>2] = Math_fround(0.0);
   $192 = (($agg$result) + 4|0);
   ;HEAP32[$192+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$192+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$192+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
   STACKTOP = sp;return;
  }
 }
 __ZN5physx2Gu30distanceSegmentSegmentSquared4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_S5_S5_S5_S5_RNS2_5Vec4VES7_($sqDist44,$p,$pq,$a,$ab,$b,$bc,$a,$ac,$a,$ab,$t40,$t41);
 $193 = Math_fround(HEAPF32[$t40>>2]);
 $194 = (($t40) + 4|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = (($t40) + 8|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = Math_fround(HEAPF32[$t41>>2]);
 $199 = (($t41) + 4|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = (($t41) + 8|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = Math_fround(HEAPF32[$sqDist44>>2]);
 $204 = (($sqDist44) + 4|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($sqDist44) + 8|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = Math_fround(HEAPF32[$pq>>2]);
 $209 = Math_fround(HEAPF32[$45>>2]);
 $210 = Math_fround(HEAPF32[$46>>2]);
 $211 = Math_fround(HEAPF32[$p>>2]);
 $212 = Math_fround(HEAPF32[$38>>2]);
 $213 = Math_fround(HEAPF32[$40>>2]);
 $214 = Math_fround($193 * $208);
 $215 = Math_fround($193 * $209);
 $216 = Math_fround($193 * $210);
 $217 = Math_fround($214 + $211);
 $218 = Math_fround($215 + $212);
 $219 = Math_fround($216 + $213);
 $220 = Math_fround(HEAPF32[$ab>>2]);
 $221 = Math_fround(HEAPF32[$61>>2]);
 $222 = Math_fround(HEAPF32[$62>>2]);
 $223 = Math_fround(HEAPF32[$a>>2]);
 $224 = Math_fround(HEAPF32[$54>>2]);
 $225 = Math_fround(HEAPF32[$56>>2]);
 $226 = Math_fround($198 * $220);
 $227 = Math_fround($198 * $221);
 $228 = Math_fround($198 * $222);
 $229 = Math_fround($226 + $223);
 $230 = Math_fround($227 + $224);
 $231 = Math_fround($228 + $225);
 $232 = Math_fround($195 * $208);
 $233 = Math_fround($195 * $209);
 $234 = Math_fround($195 * $210);
 $235 = Math_fround($232 + $211);
 $236 = Math_fround($233 + $212);
 $237 = Math_fround($234 + $213);
 $238 = Math_fround(HEAPF32[$bc>>2]);
 $239 = Math_fround(HEAPF32[$78>>2]);
 $240 = Math_fround(HEAPF32[$79>>2]);
 $241 = Math_fround(HEAPF32[$b>>2]);
 $242 = Math_fround(HEAPF32[$49>>2]);
 $243 = Math_fround(HEAPF32[$51>>2]);
 $244 = Math_fround($200 * $238);
 $245 = Math_fround($200 * $239);
 $246 = Math_fround($200 * $240);
 $247 = Math_fround($244 + $241);
 $248 = Math_fround($245 + $242);
 $249 = Math_fround($246 + $243);
 $250 = Math_fround($197 * $208);
 $251 = Math_fround($197 * $209);
 $252 = Math_fround($197 * $210);
 $253 = Math_fround($250 + $211);
 $254 = Math_fround($251 + $212);
 $255 = Math_fround($252 + $213);
 $256 = Math_fround(HEAPF32[$ac>>2]);
 $257 = Math_fround(HEAPF32[$72>>2]);
 $258 = Math_fround(HEAPF32[$73>>2]);
 $259 = Math_fround($202 * $256);
 $260 = Math_fround($202 * $257);
 $261 = Math_fround($202 * $258);
 $262 = Math_fround($259 + $223);
 $263 = Math_fround($260 + $224);
 $264 = Math_fround($261 + $225);
 $265 = $205 > $203;
 if ($265) {
  $266 = $207 > $203;
  $267 = $266 << 31 >> 31;
  $272 = $267;
 } else {
  $272 = 0;
 }
 $268 = !($203 >= $205);
 if ($268) {
  $270 = 1;
 } else {
  $phitmp = !($207 > $205);
  $270 = $phitmp;
 }
 $269 = $270 ? $207 : $205;
 $271 = ($272|0)==(0);
 $273 = $271 ? $269 : $203;
 HEAPF32[$1>>2] = $235;
 $274 = (($1) + 4|0);
 HEAPF32[$274>>2] = $236;
 $275 = (($1) + 8|0);
 HEAPF32[$275>>2] = $237;
 $276 = (($1) + 12|0);
 HEAPF32[$276>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = $253;
 $277 = (($0) + 4|0);
 HEAPF32[$277>>2] = $254;
 $278 = (($0) + 8|0);
 HEAPF32[$278>>2] = $255;
 $279 = (($0) + 12|0);
 HEAPF32[$279>>2] = Math_fround(0.0);
 $b$a$i309 = $270 ? $0 : $1;
 $280 = Math_fround(HEAPF32[$b$a$i309>>2]);
 $a$pn3$i311 = $270 ? $0 : $1;
 $$in1$i312 = (($a$pn3$i311) + 4|0);
 $281 = Math_fround(HEAPF32[$$in1$i312>>2]);
 $b$a5$i313 = $270 ? $0 : $1;
 $$in2$i314 = (($b$a5$i313) + 8|0);
 $282 = Math_fround(HEAPF32[$$in2$i314>>2]);
 HEAPF32[$3>>2] = $217;
 $283 = (($3) + 4|0);
 HEAPF32[$283>>2] = $218;
 $284 = (($3) + 8|0);
 HEAPF32[$284>>2] = $219;
 $285 = (($3) + 12|0);
 HEAPF32[$285>>2] = Math_fround(0.0);
 HEAPF32[$2>>2] = $280;
 $286 = (($2) + 4|0);
 HEAPF32[$286>>2] = $281;
 $287 = (($2) + 8|0);
 HEAPF32[$287>>2] = $282;
 $288 = (($2) + 12|0);
 HEAPF32[$288>>2] = Math_fround(0.0);
 $b$a$i297 = $271 ? $2 : $3;
 $289 = Math_fround(HEAPF32[$b$a$i297>>2]);
 $290 = ($272|0)==(0);
 $a$pn3$i299 = $290 ? $2 : $3;
 $$in1$i300 = (($a$pn3$i299) + 4|0);
 $291 = Math_fround(HEAPF32[$$in1$i300>>2]);
 $292 = ($272|0)==(0);
 $b$a5$i301 = $292 ? $2 : $3;
 $$in2$i302 = (($b$a5$i301) + 8|0);
 $293 = Math_fround(HEAPF32[$$in2$i302>>2]);
 HEAPF32[$5>>2] = $247;
 $294 = (($5) + 4|0);
 HEAPF32[$294>>2] = $248;
 $295 = (($5) + 8|0);
 HEAPF32[$295>>2] = $249;
 $296 = (($5) + 12|0);
 HEAPF32[$296>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $262;
 $297 = (($4) + 4|0);
 HEAPF32[$297>>2] = $263;
 $298 = (($4) + 8|0);
 HEAPF32[$298>>2] = $264;
 $299 = (($4) + 12|0);
 HEAPF32[$299>>2] = Math_fround(0.0);
 $b$a$i285 = $270 ? $4 : $5;
 $300 = Math_fround(HEAPF32[$b$a$i285>>2]);
 $a$pn3$i287 = $270 ? $4 : $5;
 $$in1$i288 = (($a$pn3$i287) + 4|0);
 $301 = Math_fround(HEAPF32[$$in1$i288>>2]);
 $b$a5$i289 = $270 ? $4 : $5;
 $$in2$i290 = (($b$a5$i289) + 8|0);
 $302 = Math_fround(HEAPF32[$$in2$i290>>2]);
 HEAPF32[$7>>2] = $229;
 $303 = (($7) + 4|0);
 HEAPF32[$303>>2] = $230;
 $304 = (($7) + 8|0);
 HEAPF32[$304>>2] = $231;
 $305 = (($7) + 12|0);
 HEAPF32[$305>>2] = Math_fround(0.0);
 HEAPF32[$6>>2] = $300;
 $306 = (($6) + 4|0);
 HEAPF32[$306>>2] = $301;
 $307 = (($6) + 8|0);
 HEAPF32[$307>>2] = $302;
 $308 = (($6) + 12|0);
 HEAPF32[$308>>2] = Math_fround(0.0);
 $b$a$i273 = $271 ? $6 : $7;
 $309 = Math_fround(HEAPF32[$b$a$i273>>2]);
 $a$pn3$i275 = $290 ? $6 : $7;
 $$in1$i276 = (($a$pn3$i275) + 4|0);
 $310 = Math_fround(HEAPF32[$$in1$i276>>2]);
 $b$a5$i277 = $292 ? $6 : $7;
 $$in2$i278 = (($b$a5$i277) + 8|0);
 $311 = Math_fround(HEAPF32[$$in2$i278>>2]);
 $312 = Math_fround(HEAPF32[$p>>2]);
 $313 = Math_fround(HEAPF32[$38>>2]);
 $314 = Math_fround(HEAPF32[$40>>2]);
 $315 = Math_fround($122 * $129);
 $316 = Math_fround($123 * $129);
 $317 = Math_fround($124 * $129);
 $318 = Math_fround($312 - $315);
 $319 = Math_fround($313 - $316);
 $320 = Math_fround($314 - $317);
 ;HEAP32[$closestP30+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$closestP30+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$closestP30+8>>2]=HEAP32[$p+8>>2]|0;HEAP32[$closestP30+12>>2]=HEAP32[$p+12>>2]|0;
 $321 = Math_fround(HEAPF32[$a>>2]);
 $322 = Math_fround(HEAPF32[$54>>2]);
 $323 = Math_fround(HEAPF32[$56>>2]);
 $324 = Math_fround($318 - $321);
 $325 = Math_fround($319 - $322);
 $326 = Math_fround($320 - $323);
 $327 = Math_fround(HEAPF32[$ab>>2]);
 $328 = Math_fround(HEAPF32[$61>>2]);
 $329 = Math_fround(HEAPF32[$62>>2]);
 $330 = Math_fround($324 * $327);
 $331 = Math_fround($325 * $328);
 $332 = Math_fround($330 + $331);
 $333 = Math_fround($326 * $329);
 $334 = Math_fround($332 + $333);
 $335 = Math_fround(HEAPF32[$ac>>2]);
 $336 = Math_fround(HEAPF32[$72>>2]);
 $337 = Math_fround(HEAPF32[$73>>2]);
 $338 = Math_fround($324 * $335);
 $339 = Math_fround($325 * $336);
 $340 = Math_fround($338 + $339);
 $341 = Math_fround($326 * $337);
 $342 = Math_fround($340 + $341);
 $343 = Math_fround($101 * $334);
 $344 = Math_fround($96 * $342);
 $345 = Math_fround($343 - $344);
 $346 = Math_fround($105 * $345);
 $347 = Math_fround($91 * $342);
 $348 = Math_fround($96 * $334);
 $349 = Math_fround($347 - $348);
 $350 = Math_fround($105 * $349);
 $351 = $346 <= Math_fround(1.0);
 $not$$i212 = $346 >= Math_fround(0.0);
 $352 = $351 & $not$$i212;
 $353 = $350 <= Math_fround(1.0);
 $not$169$i213 = $350 >= Math_fround(0.0);
 $354 = $353 & $not$169$i213;
 $355 = Math_fround($346 + $350);
 $356 = $355 < Math_fround(1.0);
 $$$i214 = $356 & $354;
 $$$$i215 = $$$i214 & $352;
 $357 = Math_fround(HEAPF32[$q>>2]);
 $358 = Math_fround(HEAPF32[$33>>2]);
 $359 = Math_fround(HEAPF32[$35>>2]);
 $360 = Math_fround($122 * $135);
 $361 = Math_fround($123 * $135);
 $362 = Math_fround($124 * $135);
 $363 = Math_fround($357 - $360);
 $364 = Math_fround($358 - $361);
 $365 = Math_fround($359 - $362);
 ;HEAP32[$closestP40+0>>2]=HEAP32[$q+0>>2]|0;HEAP32[$closestP40+4>>2]=HEAP32[$q+4>>2]|0;HEAP32[$closestP40+8>>2]=HEAP32[$q+8>>2]|0;HEAP32[$closestP40+12>>2]=HEAP32[$q+12>>2]|0;
 $366 = Math_fround($363 - $321);
 $367 = Math_fround($364 - $322);
 $368 = Math_fround($365 - $323);
 $369 = Math_fround($366 * $327);
 $370 = Math_fround($367 * $328);
 $371 = Math_fround($369 + $370);
 $372 = Math_fround($368 * $329);
 $373 = Math_fround($371 + $372);
 $374 = Math_fround($366 * $335);
 $375 = Math_fround($367 * $336);
 $376 = Math_fround($374 + $375);
 $377 = Math_fround($368 * $337);
 $378 = Math_fround($376 + $377);
 $379 = Math_fround($101 * $373);
 $380 = Math_fround($96 * $378);
 $381 = Math_fround($379 - $380);
 $382 = Math_fround($105 * $381);
 $383 = Math_fround($91 * $378);
 $384 = Math_fround($96 * $373);
 $385 = Math_fround($383 - $384);
 $386 = Math_fround($105 * $385);
 $387 = $382 <= Math_fround(1.0);
 $not$$i = $382 >= Math_fround(0.0);
 $388 = $387 & $not$$i;
 $389 = $386 <= Math_fround(1.0);
 $not$169$i = $386 >= Math_fround(0.0);
 $390 = $389 & $not$169$i;
 $391 = Math_fround($382 + $386);
 $392 = $391 < Math_fround(1.0);
 $$$i = $392 & $390;
 $$$$i = $$$i & $388;
 $393 = $273 > $130;
 ;HEAP32[$9+0>>2]=HEAP32[$closestP30+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$closestP30+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$closestP30+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$closestP30+12>>2]|0;
 HEAPF32[$8>>2] = $289;
 $394 = (($8) + 4|0);
 HEAPF32[$394>>2] = $291;
 $395 = (($8) + 8|0);
 HEAPF32[$395>>2] = $293;
 $396 = (($8) + 12|0);
 HEAPF32[$396>>2] = Math_fround(0.0);
 $b$a$i152 = $393 ? $9 : $8;
 $397 = Math_fround(HEAPF32[$b$a$i152>>2]);
 $$in1$i155 = (($b$a$i152) + 4|0);
 $398 = Math_fround(HEAPF32[$$in1$i155>>2]);
 $$in2$i157 = (($b$a$i152) + 8|0);
 $399 = Math_fround(HEAPF32[$$in2$i157>>2]);
 HEAPF32[$11>>2] = $318;
 $400 = (($11) + 4|0);
 HEAPF32[$400>>2] = $319;
 $401 = (($11) + 8|0);
 HEAPF32[$401>>2] = $320;
 $402 = (($11) + 12|0);
 HEAPF32[$402>>2] = Math_fround(0.0);
 HEAPF32[$10>>2] = $309;
 $403 = (($10) + 4|0);
 HEAPF32[$403>>2] = $310;
 $404 = (($10) + 8|0);
 HEAPF32[$404>>2] = $311;
 $405 = (($10) + 12|0);
 HEAPF32[$405>>2] = Math_fround(0.0);
 $b$a$i140 = $393 ? $11 : $10;
 $406 = Math_fround(HEAPF32[$b$a$i140>>2]);
 $$in1$i143 = (($b$a$i140) + 4|0);
 $407 = Math_fround(HEAPF32[$$in1$i143>>2]);
 $$in2$i145 = (($b$a$i140) + 8|0);
 $408 = Math_fround(HEAPF32[$$in2$i145>>2]);
 $409 = $273 > $136;
 ;HEAP32[$13+0>>2]=HEAP32[$q+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$q+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$q+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$q+12>>2]|0;
 HEAPF32[$12>>2] = $289;
 $410 = (($12) + 4|0);
 HEAPF32[$410>>2] = $291;
 $411 = (($12) + 8|0);
 HEAPF32[$411>>2] = $293;
 $412 = (($12) + 12|0);
 HEAPF32[$412>>2] = Math_fround(0.0);
 $b$a$i124 = $409 ? $13 : $12;
 $413 = Math_fround(HEAPF32[$b$a$i124>>2]);
 $$in1$i127 = (($b$a$i124) + 4|0);
 $414 = Math_fround(HEAPF32[$$in1$i127>>2]);
 $$in2$i129 = (($b$a$i124) + 8|0);
 $415 = Math_fround(HEAPF32[$$in2$i129>>2]);
 HEAPF32[$15>>2] = $363;
 $416 = (($15) + 4|0);
 HEAPF32[$416>>2] = $364;
 $417 = (($15) + 8|0);
 HEAPF32[$417>>2] = $365;
 $418 = (($15) + 12|0);
 HEAPF32[$418>>2] = Math_fround(0.0);
 HEAPF32[$14>>2] = $309;
 $419 = (($14) + 4|0);
 HEAPF32[$419>>2] = $310;
 $420 = (($14) + 8|0);
 HEAPF32[$420>>2] = $311;
 $421 = (($14) + 12|0);
 HEAPF32[$421>>2] = Math_fround(0.0);
 $b$a$i112 = $409 ? $15 : $14;
 $422 = Math_fround(HEAPF32[$b$a$i112>>2]);
 $$in1$i115 = (($b$a$i112) + 4|0);
 $423 = Math_fround(HEAPF32[$$in1$i115>>2]);
 $$in2$i117 = (($b$a$i112) + 8|0);
 $424 = Math_fround(HEAPF32[$$in2$i117>>2]);
 $425 = $136 > $130;
 ;HEAP32[$17+0>>2]=HEAP32[$closestP30+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$closestP30+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$closestP30+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$closestP30+12>>2]|0;
 ;HEAP32[$16+0>>2]=HEAP32[$closestP40+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$closestP40+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$closestP40+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$closestP40+12>>2]|0;
 $b$a$i96 = $425 ? $17 : $16;
 $426 = Math_fround(HEAPF32[$b$a$i96>>2]);
 $$in1$i99 = (($b$a$i96) + 4|0);
 $427 = Math_fround(HEAPF32[$$in1$i99>>2]);
 $$in2$i101 = (($b$a$i96) + 8|0);
 $428 = Math_fround(HEAPF32[$$in2$i101>>2]);
 HEAPF32[$19>>2] = $318;
 $429 = (($19) + 4|0);
 HEAPF32[$429>>2] = $319;
 $430 = (($19) + 8|0);
 HEAPF32[$430>>2] = $320;
 $431 = (($19) + 12|0);
 HEAPF32[$431>>2] = Math_fround(0.0);
 HEAPF32[$18>>2] = $363;
 $432 = (($18) + 4|0);
 HEAPF32[$432>>2] = $364;
 $433 = (($18) + 8|0);
 HEAPF32[$433>>2] = $365;
 $434 = (($18) + 12|0);
 HEAPF32[$434>>2] = Math_fround(0.0);
 $b$a$i84 = $425 ? $19 : $18;
 $435 = Math_fround(HEAPF32[$b$a$i84>>2]);
 $$in1$i87 = (($b$a$i84) + 4|0);
 $436 = Math_fround(HEAPF32[$$in1$i87>>2]);
 $$in2$i89 = (($b$a$i84) + 8|0);
 $437 = Math_fround(HEAPF32[$$in2$i89>>2]);
 $phitmp1865 = $$$$i ^ 1;
 $not$$$$i215 = $$$$i215 ^ 1;
 $phitmp1865$ = $not$$$$i215 | $phitmp1865;
 $not$$$$i2151870 = $$$$i215 ^ 1;
 $phitmp1865$1868 = $not$$$$i2151870 | $phitmp1865;
 $not$$$$i2151871 = $$$$i215 ^ 1;
 $phitmp1865$1869 = $not$$$$i2151871 | $phitmp1865;
 HEAPF32[$21>>2] = $413;
 $438 = (($21) + 4|0);
 HEAPF32[$438>>2] = $414;
 $439 = (($21) + 8|0);
 HEAPF32[$439>>2] = $415;
 $440 = (($21) + 12|0);
 HEAPF32[$440>>2] = Math_fround(0.0);
 HEAPF32[$20>>2] = $289;
 $441 = (($20) + 4|0);
 HEAPF32[$441>>2] = $291;
 $442 = (($20) + 8|0);
 HEAPF32[$442>>2] = $293;
 $443 = (($20) + 12|0);
 HEAPF32[$443>>2] = Math_fround(0.0);
 $b$a$i68 = $$$$i ? $21 : $20;
 $444 = Math_fround(HEAPF32[$b$a$i68>>2]);
 $$in1$i71 = (($b$a$i68) + 4|0);
 $445 = Math_fround(HEAPF32[$$in1$i71>>2]);
 $$in2$i73 = (($b$a$i68) + 8|0);
 $446 = Math_fround(HEAPF32[$$in2$i73>>2]);
 HEAPF32[$23>>2] = $397;
 $447 = (($23) + 4|0);
 HEAPF32[$447>>2] = $398;
 $448 = (($23) + 8|0);
 HEAPF32[$448>>2] = $399;
 $449 = (($23) + 12|0);
 HEAPF32[$449>>2] = Math_fround(0.0);
 HEAPF32[$22>>2] = $444;
 $450 = (($22) + 4|0);
 HEAPF32[$450>>2] = $445;
 $451 = (($22) + 8|0);
 HEAPF32[$451>>2] = $446;
 $452 = (($22) + 12|0);
 HEAPF32[$452>>2] = Math_fround(0.0);
 $b$a$i56 = $$$$i215 ? $23 : $22;
 $453 = Math_fround(HEAPF32[$b$a$i56>>2]);
 $$in1$i59 = (($b$a$i56) + 4|0);
 $454 = Math_fround(HEAPF32[$$in1$i59>>2]);
 $$in2$i61 = (($b$a$i56) + 8|0);
 $455 = Math_fround(HEAPF32[$$in2$i61>>2]);
 HEAPF32[$25>>2] = $426;
 $456 = (($25) + 4|0);
 HEAPF32[$456>>2] = $427;
 $457 = (($25) + 8|0);
 HEAPF32[$457>>2] = $428;
 $458 = (($25) + 12|0);
 HEAPF32[$458>>2] = Math_fround(0.0);
 HEAPF32[$24>>2] = $453;
 $459 = (($24) + 4|0);
 HEAPF32[$459>>2] = $454;
 $460 = (($24) + 8|0);
 HEAPF32[$460>>2] = $455;
 $461 = (($24) + 12|0);
 HEAPF32[$461>>2] = Math_fround(0.0);
 $b$a$i44 = $phitmp1865$1868 ? $24 : $25;
 $462 = Math_fround(HEAPF32[$b$a$i44>>2]);
 $a$pn3$i46 = $phitmp1865$1869 ? $24 : $25;
 $$in1$i47 = (($a$pn3$i46) + 4|0);
 $463 = Math_fround(HEAPF32[$$in1$i47>>2]);
 $b$a5$i48 = $phitmp1865$ ? $24 : $25;
 $$in2$i49 = (($b$a5$i48) + 8|0);
 $464 = Math_fround(HEAPF32[$$in2$i49>>2]);
 HEAPF32[$27>>2] = $422;
 $465 = (($27) + 4|0);
 HEAPF32[$465>>2] = $423;
 $466 = (($27) + 8|0);
 HEAPF32[$466>>2] = $424;
 $467 = (($27) + 12|0);
 HEAPF32[$467>>2] = Math_fround(0.0);
 HEAPF32[$26>>2] = $309;
 $468 = (($26) + 4|0);
 HEAPF32[$468>>2] = $310;
 $469 = (($26) + 8|0);
 HEAPF32[$469>>2] = $311;
 $470 = (($26) + 12|0);
 HEAPF32[$470>>2] = Math_fround(0.0);
 $b$a$i32 = $$$$i ? $27 : $26;
 $471 = Math_fround(HEAPF32[$b$a$i32>>2]);
 $$in1$i35 = (($b$a$i32) + 4|0);
 $472 = Math_fround(HEAPF32[$$in1$i35>>2]);
 $$in2$i37 = (($b$a$i32) + 8|0);
 $473 = Math_fround(HEAPF32[$$in2$i37>>2]);
 HEAPF32[$29>>2] = $406;
 $474 = (($29) + 4|0);
 HEAPF32[$474>>2] = $407;
 $475 = (($29) + 8|0);
 HEAPF32[$475>>2] = $408;
 $476 = (($29) + 12|0);
 HEAPF32[$476>>2] = Math_fround(0.0);
 HEAPF32[$28>>2] = $471;
 $477 = (($28) + 4|0);
 HEAPF32[$477>>2] = $472;
 $478 = (($28) + 8|0);
 HEAPF32[$478>>2] = $473;
 $479 = (($28) + 12|0);
 HEAPF32[$479>>2] = Math_fround(0.0);
 $b$a$i20 = $$$$i215 ? $29 : $28;
 $480 = Math_fround(HEAPF32[$b$a$i20>>2]);
 $$in1$i23 = (($b$a$i20) + 4|0);
 $481 = Math_fround(HEAPF32[$$in1$i23>>2]);
 $$in2$i25 = (($b$a$i20) + 8|0);
 $482 = Math_fround(HEAPF32[$$in2$i25>>2]);
 HEAPF32[$31>>2] = $435;
 $483 = (($31) + 4|0);
 HEAPF32[$483>>2] = $436;
 $484 = (($31) + 8|0);
 HEAPF32[$484>>2] = $437;
 $485 = (($31) + 12|0);
 HEAPF32[$485>>2] = Math_fround(0.0);
 HEAPF32[$30>>2] = $480;
 $486 = (($30) + 4|0);
 HEAPF32[$486>>2] = $481;
 $487 = (($30) + 8|0);
 HEAPF32[$487>>2] = $482;
 $488 = (($30) + 12|0);
 HEAPF32[$488>>2] = Math_fround(0.0);
 $b$a$i = $phitmp1865$1868 ? $30 : $31;
 $489 = Math_fround(HEAPF32[$b$a$i>>2]);
 $a$pn3$i = $phitmp1865$1869 ? $30 : $31;
 $$in1$i = (($a$pn3$i) + 4|0);
 $490 = Math_fround(HEAPF32[$$in1$i>>2]);
 $b$a5$i = $phitmp1865$ ? $30 : $31;
 $$in2$i = (($b$a5$i) + 8|0);
 $491 = Math_fround(HEAPF32[$$in2$i>>2]);
 $492 = Math_fround($489 - $462);
 $493 = Math_fround($490 - $463);
 $494 = Math_fround($491 - $464);
 HEAPF32[$closest0>>2] = $462;
 $495 = (($closest0) + 4|0);
 HEAPF32[$495>>2] = $463;
 $496 = (($closest0) + 8|0);
 HEAPF32[$496>>2] = $464;
 $497 = (($closest0) + 12|0);
 HEAPF32[$497>>2] = Math_fround(0.0);
 HEAPF32[$closest1>>2] = $489;
 $498 = (($closest1) + 4|0);
 HEAPF32[$498>>2] = $490;
 $499 = (($closest1) + 8|0);
 HEAPF32[$499>>2] = $491;
 $500 = (($closest1) + 12|0);
 HEAPF32[$500>>2] = Math_fround(0.0);
 $501 = Math_fround($492 * $492);
 $502 = Math_fround($493 * $493);
 $503 = Math_fround($501 + $502);
 $504 = Math_fround($494 * $494);
 $505 = Math_fround($503 + $504);
 HEAPF32[$agg$result>>2] = $505;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11sweepBoxBoxERKNS0_3BoxES3_RKNS_6PxVec3EfRS4_S7_RfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($box0,$box1,$dir,$length,$hit,$normal,$t,$hintFlags) {
 $box0 = $box0|0;
 $box1 = $box1|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $hit = $hit|0;
 $normal = $normal|0;
 $t = $t|0;
 $hintFlags = $hintFlags|0;
 var $$1 = 0, $$pre = Math_fround(0), $$pre$phi68Z2D = 0, $$pre$phi70Z2D = 0, $$pre$phi72Z2D = 0, $$pre$phiZ2D = 0, $$pre63 = Math_fround(0), $$pre64 = Math_fround(0), $$pre66 = 0, $$pre67 = 0, $$pre69 = 0, $$pre71 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0);
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0;
 var $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0);
 var $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0);
 var $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0);
 var $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0;
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0);
 var $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0);
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0;
 var $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0);
 var $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0);
 var $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0);
 var $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = 0, $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = 0;
 var $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0), $429 = 0;
 var $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0);
 var $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = 0;
 var $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = 0, $482 = 0, $483 = 0;
 var $484 = 0, $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = 0, $489 = Math_fround(0), $49 = 0, $490 = 0, $491 = Math_fround(0), $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = 0;
 var $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0);
 var $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = 0, $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0);
 var $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0);
 var $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = 0, $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0);
 var $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = 0, $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $Dist = 0, $Max0 = 0, $Max1 = 0, $Min0 = 0, $Min1 = 0, $MinDist$057 = Math_fround(0), $MinDist$1 = Math_fround(0), $MinDist$254 = Math_fround(0), $MinDist$3 = Math_fround(0), $MinDist$446 = Math_fround(0), $MinDist$543 = Math_fround(0), $MinDist$6 = Math_fround(0), $MinDist$7 = Math_fround(0), $boxVertices0 = 0, $boxVertices1 = 0, $col$056 = 0, $col$1 = 0, $col$253 = 0;
 var $col$3 = 0, $col$445 = 0, $col$542 = 0, $col$6 = 0, $col$7 = 0, $dir$idx$val = Math_fround(0), $dir$idx2$val = Math_fround(0), $dir$idx3$val = Math_fround(0), $dir$idx4$val = Math_fround(0), $dir$idx5$val = Math_fround(0), $dir$idx6$val = Math_fround(0), $edgeNormals0 = 0, $edgeNormals1 = 0, $exitcond = 0, $exitcond58 = 0, $exitcond59 = 0, $exitcond60 = 0, $exitcond61 = 0, $exitcond62 = 0, $i$055 = 0;
 var $i1$052 = 0, $i5$051 = 0, $i6$049 = 0, $i7$047 = 0, $ip = 0, $j$044 = 0, $localDir1 = 0, $or$cond = 0, $or$cond1 = 0, $p1 = 0, $p2 = 0, $p3 = 0, $p4 = 0, $tfar = 0, $tfar3 = 0, $tnear = 0, $tnear2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 672|0;
 $boxVertices0 = sp + 568|0;
 $boxVertices1 = sp + 472|0;
 $Min0 = sp + 456|0;
 $Max0 = sp + 444|0;
 $tnear = sp + 440|0;
 $tfar = sp + 436|0;
 $0 = sp + 424|0;
 $1 = sp + 412|0;
 $Min1 = sp + 400|0;
 $Max1 = sp + 388|0;
 $localDir1 = sp + 376|0;
 $tnear2 = sp + 372|0;
 $tfar3 = sp + 304|0;
 $2 = sp;
 $edgeNormals0 = sp + 16|0;
 $edgeNormals1 = sp + 160|0;
 $p1 = sp + 308|0;
 $p2 = sp + 320|0;
 $p3 = sp + 332|0;
 $p4 = sp + 344|0;
 $Dist = sp + 356|0;
 $ip = sp + 360|0;
 $3 = HEAP16[$hintFlags>>1]|0;
 $4 = $3 & 16;
 $5 = ($4<<16>>16)==(0);
 if ($5) {
  $6 = (($box0) + 48|0);
  $7 = (($box0) + 36|0);
  $8 = (($box1) + 48|0);
  $9 = (($box1) + 36|0);
  $10 = (__ZN5physx2Gu15intersectOBBOBBERKNS_6PxVec3ES3_RKNS_7PxMat33ES3_S3_S6_b($6,$7,$box0,$8,$9,$box1,1)|0);
  if ($10) {
   HEAPF32[$t>>2] = Math_fround(0.0);
   $11 = Math_fround(HEAPF32[$dir>>2]);
   $12 = Math_fround(-$11);
   $13 = (($dir) + 4|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = Math_fround(-$14);
   $16 = (($dir) + 8|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround(-$17);
   HEAPF32[$normal>>2] = $12;
   $19 = (($normal) + 4|0);
   HEAPF32[$19>>2] = $15;
   $20 = (($normal) + 8|0);
   HEAPF32[$20>>2] = $18;
   $21 = Math_fround(HEAPF32[$7>>2]);
   HEAPF32[$hit>>2] = $21;
   $22 = (($box0) + 40|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = (($hit) + 4|0);
   HEAPF32[$24>>2] = $23;
   $25 = (($box0) + 44|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = (($hit) + 8|0);
   HEAPF32[$27>>2] = $26;
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  } else {
   $$pre$phi68Z2D = $6;$$pre$phi70Z2D = $9;$$pre$phi72Z2D = $8;$$pre$phiZ2D = $7;
  }
 } else {
  $$pre66 = (($box0) + 36|0);
  $$pre67 = (($box0) + 48|0);
  $$pre69 = (($box1) + 36|0);
  $$pre71 = (($box1) + 48|0);
  $$pre$phi68Z2D = $$pre67;$$pre$phi70Z2D = $$pre69;$$pre$phi72Z2D = $$pre71;$$pre$phiZ2D = $$pre66;
 }
 $28 = (($box0) + 12|0);
 $29 = (($box0) + 24|0);
 __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($boxVertices0,$$pre$phiZ2D,$$pre$phi68Z2D,$box0,$28,$29);
 $30 = (($box1) + 12|0);
 $31 = (($box1) + 24|0);
 __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($boxVertices1,$$pre$phi70Z2D,$$pre$phi72Z2D,$box1,$30,$31);
 $32 = Math_fround(HEAPF32[$$pre$phi68Z2D>>2]);
 $33 = Math_fround(-$32);
 $34 = (($box0) + 52|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround(-$35);
 $37 = (($box0) + 56|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(-$38);
 HEAPF32[$Min0>>2] = $33;
 $40 = (($Min0) + 4|0);
 HEAPF32[$40>>2] = $36;
 $41 = (($Min0) + 8|0);
 HEAPF32[$41>>2] = $39;
 HEAPF32[$Max0>>2] = $32;
 $42 = (($Max0) + 4|0);
 HEAPF32[$42>>2] = $35;
 $43 = (($Max0) + 8|0);
 HEAPF32[$43>>2] = $38;
 $44 = Math_fround(HEAPF32[$box0>>2]);
 $45 = (($box0) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($box0) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($box0) + 12|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($box0) + 16|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($box0) + 20|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($box0) + 24|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($box0) + 28|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($box0) + 32|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($box0) + 36|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($box0) + 40|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($box0) + 44|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround(-$62);
 $68 = Math_fround(-$64);
 $69 = Math_fround(-$66);
 $70 = Math_fround($44 * $67);
 $71 = Math_fround($46 * $68);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($48 * $69);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($50 * $67);
 $76 = Math_fround($52 * $68);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($54 * $69);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($56 * $67);
 $81 = Math_fround($58 * $68);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($60 * $69);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround(HEAPF32[$dir>>2]);
 $86 = Math_fround($44 * $85);
 $87 = Math_fround($50 * $85);
 $88 = Math_fround($56 * $85);
 $89 = (($dir) + 4|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($46 * $90);
 $92 = Math_fround($52 * $90);
 $93 = Math_fround($58 * $90);
 $94 = Math_fround($86 + $91);
 $95 = Math_fround($87 + $92);
 $96 = Math_fround($88 + $93);
 $97 = (($dir) + 8|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($48 * $98);
 $100 = Math_fround($54 * $98);
 $101 = Math_fround($60 * $98);
 $102 = Math_fround($94 + $99);
 $103 = Math_fround($95 + $100);
 $104 = Math_fround($96 + $101);
 $105 = (($0) + 4|0);
 $106 = (($0) + 8|0);
 $107 = Math_fround(-$102);
 $108 = Math_fround(-$103);
 $109 = Math_fround(-$104);
 $110 = (($1) + 4|0);
 $111 = (($1) + 8|0);
 $112 = (($normal) + 4|0);
 $113 = (($normal) + 8|0);
 $114 = (($hit) + 4|0);
 $115 = (($hit) + 8|0);
 $MinDist$057 = $length;$col$056 = -1;$i$055 = 0;
 while(1) {
  $116 = (($boxVertices1) + (($i$055*12)|0)|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = Math_fround($44 * $117);
  $119 = Math_fround($50 * $117);
  $120 = Math_fround($56 * $117);
  $121 = ((($boxVertices1) + (($i$055*12)|0)|0) + 4|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround($46 * $122);
  $124 = Math_fround($52 * $122);
  $125 = Math_fround($58 * $122);
  $126 = Math_fround($118 + $123);
  $127 = Math_fround($119 + $124);
  $128 = Math_fround($120 + $125);
  $129 = ((($boxVertices1) + (($i$055*12)|0)|0) + 8|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($48 * $130);
  $132 = Math_fround($54 * $130);
  $133 = Math_fround($60 * $130);
  $134 = Math_fround($126 + $131);
  $135 = Math_fround($127 + $132);
  $136 = Math_fround($128 + $133);
  $137 = Math_fround($74 + $134);
  $138 = Math_fround($79 + $135);
  $139 = Math_fround($84 + $136);
  HEAPF32[$0>>2] = $137;
  HEAPF32[$105>>2] = $138;
  HEAPF32[$106>>2] = $139;
  HEAPF32[$1>>2] = $107;
  HEAPF32[$110>>2] = $108;
  HEAPF32[$111>>2] = $109;
  $140 = (__ZN5physx2Gu16intersectRayAABBERKNS_6PxVec3ES3_S3_S3_RfS4_($Min0,$Max0,$0,$1,$tnear,$tfar)|0);
  $141 = ($140|0)==(-1);
  if ($141) {
   $MinDist$1 = $MinDist$057;$col$1 = $col$056;
  } else {
   $142 = Math_fround(HEAPF32[$tnear>>2]);
   $143 = $142 < Math_fround(0.0);
   $144 = !($142 <= $MinDist$057);
   $or$cond = $143 | $144;
   if ($or$cond) {
    $MinDist$1 = $MinDist$057;$col$1 = $col$056;
   } else {
    $145 = (550080 + (($140*12)|0)|0);
    $146 = Math_fround(HEAPF32[$145>>2]);
    $147 = Math_fround(HEAPF32[$box0>>2]);
    $148 = Math_fround($146 * $147);
    $149 = Math_fround(HEAPF32[$45>>2]);
    $150 = Math_fround($146 * $149);
    $151 = Math_fround(HEAPF32[$47>>2]);
    $152 = Math_fround($146 * $151);
    $153 = ((550080 + (($140*12)|0)|0) + 4|0);
    $154 = Math_fround(HEAPF32[$153>>2]);
    $155 = Math_fround(HEAPF32[$49>>2]);
    $156 = Math_fround($154 * $155);
    $157 = Math_fround(HEAPF32[$51>>2]);
    $158 = Math_fround($154 * $157);
    $159 = Math_fround(HEAPF32[$53>>2]);
    $160 = Math_fround($154 * $159);
    $161 = Math_fround($148 + $156);
    $162 = Math_fround($150 + $158);
    $163 = Math_fround($152 + $160);
    $164 = ((550080 + (($140*12)|0)|0) + 8|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = Math_fround(HEAPF32[$55>>2]);
    $167 = Math_fround($165 * $166);
    $168 = Math_fround(HEAPF32[$57>>2]);
    $169 = Math_fround($165 * $168);
    $170 = Math_fround(HEAPF32[$59>>2]);
    $171 = Math_fround($165 * $170);
    $172 = Math_fround($161 + $167);
    $173 = Math_fround($162 + $169);
    $174 = Math_fround($163 + $171);
    HEAPF32[$normal>>2] = $172;
    HEAPF32[$112>>2] = $173;
    HEAPF32[$113>>2] = $174;
    $175 = Math_fround(HEAPF32[$116>>2]);
    HEAPF32[$hit>>2] = $175;
    $176 = Math_fround(HEAPF32[$121>>2]);
    HEAPF32[$114>>2] = $176;
    $177 = Math_fround(HEAPF32[$129>>2]);
    HEAPF32[$115>>2] = $177;
    $MinDist$1 = $142;$col$1 = 0;
   }
  }
  $178 = (($i$055) + 1)|0;
  $exitcond62 = ($178|0)==(8);
  if ($exitcond62) {
   break;
  } else {
   $MinDist$057 = $MinDist$1;$col$056 = $col$1;$i$055 = $178;
  }
 }
 $179 = Math_fround(HEAPF32[$$pre$phi72Z2D>>2]);
 $180 = Math_fround(-$179);
 $181 = (($box1) + 52|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = Math_fround(-$182);
 $184 = (($box1) + 56|0);
 $185 = Math_fround(HEAPF32[$184>>2]);
 $186 = Math_fround(-$185);
 HEAPF32[$Min1>>2] = $180;
 $187 = (($Min1) + 4|0);
 HEAPF32[$187>>2] = $183;
 $188 = (($Min1) + 8|0);
 HEAPF32[$188>>2] = $186;
 HEAPF32[$Max1>>2] = $179;
 $189 = (($Max1) + 4|0);
 HEAPF32[$189>>2] = $182;
 $190 = (($Max1) + 8|0);
 HEAPF32[$190>>2] = $185;
 $191 = Math_fround(HEAPF32[$box1>>2]);
 $192 = (($box1) + 4|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($box1) + 8|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = (($box1) + 12|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = (($box1) + 16|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($box1) + 20|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = (($box1) + 24|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = (($box1) + 28|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($box1) + 32|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = (($box1) + 36|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = (($box1) + 40|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = (($box1) + 44|0);
 $213 = Math_fround(HEAPF32[$212>>2]);
 $214 = Math_fround(-$209);
 $215 = Math_fround(-$211);
 $216 = Math_fround(-$213);
 $217 = Math_fround($191 * $214);
 $218 = Math_fround($193 * $215);
 $219 = Math_fround($217 + $218);
 $220 = Math_fround($195 * $216);
 $221 = Math_fround($219 + $220);
 $222 = Math_fround($197 * $214);
 $223 = Math_fround($199 * $215);
 $224 = Math_fround($222 + $223);
 $225 = Math_fround($201 * $216);
 $226 = Math_fround($224 + $225);
 $227 = Math_fround($203 * $214);
 $228 = Math_fround($205 * $215);
 $229 = Math_fround($227 + $228);
 $230 = Math_fround($207 * $216);
 $231 = Math_fround($229 + $230);
 $232 = Math_fround(HEAPF32[$dir>>2]);
 $233 = Math_fround($191 * $232);
 $234 = Math_fround($197 * $232);
 $235 = Math_fround($203 * $232);
 $236 = Math_fround(HEAPF32[$89>>2]);
 $237 = Math_fround($193 * $236);
 $238 = Math_fround($199 * $236);
 $239 = Math_fround($205 * $236);
 $240 = Math_fround($233 + $237);
 $241 = Math_fround($234 + $238);
 $242 = Math_fround($235 + $239);
 $243 = Math_fround(HEAPF32[$97>>2]);
 $244 = Math_fround($195 * $243);
 $245 = Math_fround($201 * $243);
 $246 = Math_fround($207 * $243);
 $247 = Math_fround($240 + $244);
 $248 = Math_fround($241 + $245);
 $249 = Math_fround($242 + $246);
 HEAPF32[$localDir1>>2] = $247;
 $250 = (($localDir1) + 4|0);
 HEAPF32[$250>>2] = $248;
 $251 = (($localDir1) + 8|0);
 HEAPF32[$251>>2] = $249;
 $252 = (($2) + 4|0);
 $253 = (($2) + 8|0);
 $MinDist$254 = $MinDist$1;$col$253 = $col$1;$i1$052 = 0;
 while(1) {
  $254 = (($boxVertices0) + (($i1$052*12)|0)|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = Math_fround($191 * $255);
  $257 = Math_fround($197 * $255);
  $258 = Math_fround($203 * $255);
  $259 = ((($boxVertices0) + (($i1$052*12)|0)|0) + 4|0);
  $260 = Math_fround(HEAPF32[$259>>2]);
  $261 = Math_fround($193 * $260);
  $262 = Math_fround($199 * $260);
  $263 = Math_fround($205 * $260);
  $264 = Math_fround($256 + $261);
  $265 = Math_fround($257 + $262);
  $266 = Math_fround($258 + $263);
  $267 = ((($boxVertices0) + (($i1$052*12)|0)|0) + 8|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = Math_fround($195 * $268);
  $270 = Math_fround($201 * $268);
  $271 = Math_fround($207 * $268);
  $272 = Math_fround($264 + $269);
  $273 = Math_fround($265 + $270);
  $274 = Math_fround($266 + $271);
  $275 = Math_fround($221 + $272);
  $276 = Math_fround($226 + $273);
  $277 = Math_fround($231 + $274);
  HEAPF32[$2>>2] = $275;
  HEAPF32[$252>>2] = $276;
  HEAPF32[$253>>2] = $277;
  $278 = (__ZN5physx2Gu16intersectRayAABBERKNS_6PxVec3ES3_S3_S3_RfS4_($Min1,$Max1,$2,$localDir1,$tnear2,$tfar3)|0);
  $279 = ($278|0)==(-1);
  if ($279) {
   $MinDist$3 = $MinDist$254;$col$3 = $col$253;
  } else {
   $280 = Math_fround(HEAPF32[$tnear2>>2]);
   $281 = $280 < Math_fround(0.0);
   $282 = !($280 <= $MinDist$254);
   $or$cond1 = $281 | $282;
   if ($or$cond1) {
    $MinDist$3 = $MinDist$254;$col$3 = $col$253;
   } else {
    $283 = (550080 + (($278*12)|0)|0);
    $284 = Math_fround(HEAPF32[$283>>2]);
    $285 = Math_fround(-$284);
    $286 = ((550080 + (($278*12)|0)|0) + 4|0);
    $287 = Math_fround(HEAPF32[$286>>2]);
    $288 = Math_fround(-$287);
    $289 = ((550080 + (($278*12)|0)|0) + 8|0);
    $290 = Math_fround(HEAPF32[$289>>2]);
    $291 = Math_fround(-$290);
    $292 = Math_fround(HEAPF32[$box1>>2]);
    $293 = Math_fround($292 * $285);
    $294 = Math_fround(HEAPF32[$192>>2]);
    $295 = Math_fround($294 * $285);
    $296 = Math_fround(HEAPF32[$194>>2]);
    $297 = Math_fround($296 * $285);
    $298 = Math_fround(HEAPF32[$196>>2]);
    $299 = Math_fround($298 * $288);
    $300 = Math_fround(HEAPF32[$198>>2]);
    $301 = Math_fround($300 * $288);
    $302 = Math_fround(HEAPF32[$200>>2]);
    $303 = Math_fround($302 * $288);
    $304 = Math_fround($293 + $299);
    $305 = Math_fround($295 + $301);
    $306 = Math_fround($297 + $303);
    $307 = Math_fround(HEAPF32[$202>>2]);
    $308 = Math_fround($307 * $291);
    $309 = Math_fround(HEAPF32[$204>>2]);
    $310 = Math_fround($309 * $291);
    $311 = Math_fround(HEAPF32[$206>>2]);
    $312 = Math_fround($311 * $291);
    $313 = Math_fround($304 + $308);
    $314 = Math_fround($305 + $310);
    $315 = Math_fround($306 + $312);
    HEAPF32[$normal>>2] = $313;
    HEAPF32[$112>>2] = $314;
    HEAPF32[$113>>2] = $315;
    $dir$idx4$val = Math_fround(HEAPF32[$dir>>2]);
    $dir$idx5$val = Math_fround(HEAPF32[$89>>2]);
    $dir$idx6$val = Math_fround(HEAPF32[$97>>2]);
    $316 = Math_fround($280 * $dir$idx4$val);
    $317 = Math_fround($280 * $dir$idx5$val);
    $318 = Math_fround($280 * $dir$idx6$val);
    $319 = Math_fround(HEAPF32[$254>>2]);
    $320 = Math_fround($316 + $319);
    $321 = Math_fround(HEAPF32[$259>>2]);
    $322 = Math_fround($317 + $321);
    $323 = Math_fround(HEAPF32[$267>>2]);
    $324 = Math_fround($318 + $323);
    HEAPF32[$hit>>2] = $320;
    HEAPF32[$114>>2] = $322;
    HEAPF32[$115>>2] = $324;
    $MinDist$3 = $280;$col$3 = 1;
   }
  }
  $325 = (($i1$052) + 1)|0;
  $exitcond61 = ($325|0)==(8);
  if ($exitcond61) {
   break;
  } else {
   $MinDist$254 = $MinDist$3;$col$253 = $col$3;$i1$052 = $325;
  }
 }
 $326 = (__ZN5physx2Gu11getBoxEdgesEv()|0);
 $327 = (__ZN5physx2Gu11getBoxEdgesEv()|0);
 $328 = Math_fround(HEAPF32[$box0>>2]);
 $329 = Math_fround(HEAPF32[$45>>2]);
 $330 = Math_fround(HEAPF32[$47>>2]);
 $331 = Math_fround(HEAPF32[$49>>2]);
 $332 = Math_fround(HEAPF32[$51>>2]);
 $333 = Math_fround(HEAPF32[$53>>2]);
 $334 = Math_fround(HEAPF32[$55>>2]);
 $335 = Math_fround(HEAPF32[$57>>2]);
 $336 = Math_fround(HEAPF32[$59>>2]);
 $i5$051 = 0;
 while(1) {
  $346 = (550152 + (($i5$051*12)|0)|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  $348 = Math_fround($347 * $328);
  $349 = Math_fround($347 * $329);
  $350 = Math_fround($347 * $330);
  $351 = ((550152 + (($i5$051*12)|0)|0) + 4|0);
  $352 = Math_fround(HEAPF32[$351>>2]);
  $353 = Math_fround($352 * $331);
  $354 = Math_fround($352 * $332);
  $355 = Math_fround($352 * $333);
  $356 = Math_fround($348 + $353);
  $357 = Math_fround($349 + $354);
  $358 = Math_fround($350 + $355);
  $359 = ((550152 + (($i5$051*12)|0)|0) + 8|0);
  $360 = Math_fround(HEAPF32[$359>>2]);
  $361 = Math_fround($360 * $334);
  $362 = Math_fround($360 * $335);
  $363 = Math_fround($360 * $336);
  $364 = Math_fround($356 + $361);
  $365 = Math_fround($357 + $362);
  $366 = Math_fround($358 + $363);
  $367 = (($edgeNormals0) + (($i5$051*12)|0)|0);
  HEAPF32[$367>>2] = $364;
  $368 = ((($edgeNormals0) + (($i5$051*12)|0)|0) + 4|0);
  HEAPF32[$368>>2] = $365;
  $369 = ((($edgeNormals0) + (($i5$051*12)|0)|0) + 8|0);
  HEAPF32[$369>>2] = $366;
  $370 = (($i5$051) + 1)|0;
  $exitcond60 = ($370|0)==(12);
  if ($exitcond60) {
   break;
  } else {
   $i5$051 = $370;
  }
 }
 $337 = Math_fround(HEAPF32[$box1>>2]);
 $338 = Math_fround(HEAPF32[$192>>2]);
 $339 = Math_fround(HEAPF32[$194>>2]);
 $340 = Math_fround(HEAPF32[$196>>2]);
 $341 = Math_fround(HEAPF32[$198>>2]);
 $342 = Math_fround(HEAPF32[$200>>2]);
 $343 = Math_fround(HEAPF32[$202>>2]);
 $344 = Math_fround(HEAPF32[$204>>2]);
 $345 = Math_fround(HEAPF32[$206>>2]);
 $i6$049 = 0;
 while(1) {
  $381 = (550152 + (($i6$049*12)|0)|0);
  $382 = Math_fround(HEAPF32[$381>>2]);
  $383 = Math_fround($382 * $337);
  $384 = Math_fround($382 * $338);
  $385 = Math_fround($382 * $339);
  $386 = ((550152 + (($i6$049*12)|0)|0) + 4|0);
  $387 = Math_fround(HEAPF32[$386>>2]);
  $388 = Math_fround($387 * $340);
  $389 = Math_fround($387 * $341);
  $390 = Math_fround($387 * $342);
  $391 = Math_fround($383 + $388);
  $392 = Math_fround($384 + $389);
  $393 = Math_fround($385 + $390);
  $394 = ((550152 + (($i6$049*12)|0)|0) + 8|0);
  $395 = Math_fround(HEAPF32[$394>>2]);
  $396 = Math_fround($395 * $343);
  $397 = Math_fround($395 * $344);
  $398 = Math_fround($395 * $345);
  $399 = Math_fround($391 + $396);
  $400 = Math_fround($392 + $397);
  $401 = Math_fround($393 + $398);
  $402 = (($edgeNormals1) + (($i6$049*12)|0)|0);
  HEAPF32[$402>>2] = $399;
  $403 = ((($edgeNormals1) + (($i6$049*12)|0)|0) + 4|0);
  HEAPF32[$403>>2] = $400;
  $404 = ((($edgeNormals1) + (($i6$049*12)|0)|0) + 8|0);
  HEAPF32[$404>>2] = $401;
  $405 = (($i6$049) + 1)|0;
  $exitcond59 = ($405|0)==(12);
  if ($exitcond59) {
   break;
  } else {
   $i6$049 = $405;
  }
 }
 $371 = (($p1) + 4|0);
 $372 = (($p1) + 8|0);
 $373 = (($p2) + 4|0);
 $374 = (($p2) + 8|0);
 $375 = (($p3) + 4|0);
 $376 = (($p3) + 8|0);
 $377 = (($p4) + 4|0);
 $378 = (($p4) + 8|0);
 $379 = (($ip) + 4|0);
 $380 = (($ip) + 8|0);
 $MinDist$446 = $MinDist$3;$col$445 = $col$3;$i7$047 = 0;
 while(1) {
  $406 = (($edgeNormals0) + (($i7$047*12)|0)|0);
  $407 = Math_fround(HEAPF32[$406>>2]);
  $408 = Math_fround(HEAPF32[$dir>>2]);
  $409 = Math_fround($407 * $408);
  $410 = ((($edgeNormals0) + (($i7$047*12)|0)|0) + 4|0);
  $411 = Math_fround(HEAPF32[$410>>2]);
  $412 = Math_fround(HEAPF32[$89>>2]);
  $413 = Math_fround($411 * $412);
  $414 = Math_fround($409 + $413);
  $415 = ((($edgeNormals0) + (($i7$047*12)|0)|0) + 8|0);
  $416 = Math_fround(HEAPF32[$415>>2]);
  $417 = Math_fround(HEAPF32[$97>>2]);
  $418 = Math_fround($416 * $417);
  $419 = Math_fround($414 + $418);
  $420 = !($419 >= Math_fround(0.0));
  L29: do {
   if ($420) {
    $MinDist$7 = $MinDist$446;$col$7 = $col$445;
   } else {
    $421 = $i7$047 << 1;
    $422 = (($326) + ($421)|0);
    $423 = HEAP8[$422>>0]|0;
    $424 = $423&255;
    $425 = (($boxVertices0) + (($424*12)|0)|0);
    $426 = Math_fround(HEAPF32[$425>>2]);
    HEAPF32[$p1>>2] = $426;
    $427 = ((($boxVertices0) + (($424*12)|0)|0) + 4|0);
    $428 = Math_fround(HEAPF32[$427>>2]);
    HEAPF32[$371>>2] = $428;
    $429 = ((($boxVertices0) + (($424*12)|0)|0) + 8|0);
    $430 = Math_fround(HEAPF32[$429>>2]);
    HEAPF32[$372>>2] = $430;
    $431 = $421 | 1;
    $432 = (($326) + ($431)|0);
    $433 = HEAP8[$432>>0]|0;
    $434 = $433&255;
    $435 = (($boxVertices0) + (($434*12)|0)|0);
    $436 = Math_fround(HEAPF32[$435>>2]);
    HEAPF32[$p2>>2] = $436;
    $437 = ((($boxVertices0) + (($434*12)|0)|0) + 4|0);
    $438 = Math_fround(HEAPF32[$437>>2]);
    HEAPF32[$373>>2] = $438;
    $439 = ((($boxVertices0) + (($434*12)|0)|0) + 8|0);
    $440 = Math_fround(HEAPF32[$439>>2]);
    HEAPF32[$374>>2] = $440;
    $441 = Math_fround($436 - $426);
    $442 = Math_fround($438 - $428);
    $443 = Math_fround($440 - $430);
    $444 = Math_fround($441 * $441);
    $445 = Math_fround($442 * $442);
    $446 = Math_fround($444 + $445);
    $447 = Math_fround($443 * $443);
    $448 = Math_fround($446 + $447);
    $449 = (Math_fround(Math_sqrt((Math_fround($448)))));
    $450 = $449 > Math_fround(0.0);
    if ($450) {
     $451 = Math_fround(Math_fround(0.00999999977648258209228) / $449);
     $452 = Math_fround($441 * $451);
     $453 = Math_fround($442 * $451);
     $454 = Math_fround($443 * $451);
     $455 = Math_fround($426 - $452);
     HEAPF32[$p1>>2] = $455;
     $456 = Math_fround($428 - $453);
     HEAPF32[$371>>2] = $456;
     $457 = Math_fround($430 - $454);
     HEAPF32[$372>>2] = $457;
     $458 = Math_fround($452 + $436);
     HEAPF32[$p2>>2] = $458;
     $459 = Math_fround($453 + $438);
     HEAPF32[$373>>2] = $459;
     $460 = Math_fround($454 + $440);
     HEAPF32[$374>>2] = $460;
     $464 = $408;$468 = $412;$473 = $417;$MinDist$543 = $MinDist$446;$col$542 = $col$445;$j$044 = 0;
    } else {
     $464 = $408;$468 = $412;$473 = $417;$MinDist$543 = $MinDist$446;$col$542 = $col$445;$j$044 = 0;
    }
    while(1) {
     $461 = (($edgeNormals1) + (($j$044*12)|0)|0);
     $462 = Math_fround(HEAPF32[$461>>2]);
     $463 = Math_fround($462 * $464);
     $465 = ((($edgeNormals1) + (($j$044*12)|0)|0) + 4|0);
     $466 = Math_fround(HEAPF32[$465>>2]);
     $467 = Math_fround($466 * $468);
     $469 = Math_fround($463 + $467);
     $470 = ((($edgeNormals1) + (($j$044*12)|0)|0) + 8|0);
     $471 = Math_fround(HEAPF32[$470>>2]);
     $472 = Math_fround($471 * $473);
     $474 = Math_fround($469 + $472);
     $475 = !($474 >= Math_fround(0.0));
     if ($475) {
      $476 = Math_fround($462 * $407);
      $477 = Math_fround($466 * $411);
      $478 = Math_fround($476 + $477);
      $479 = Math_fround($471 * $416);
      $480 = Math_fround($478 + $479);
      $481 = !($480 >= Math_fround(0.0));
      if ($481) {
       $482 = $j$044 << 1;
       $483 = (($327) + ($482)|0);
       $484 = HEAP8[$483>>0]|0;
       $485 = $484&255;
       $486 = (($boxVertices1) + (($485*12)|0)|0);
       $487 = Math_fround(HEAPF32[$486>>2]);
       HEAPF32[$p3>>2] = $487;
       $488 = ((($boxVertices1) + (($485*12)|0)|0) + 4|0);
       $489 = Math_fround(HEAPF32[$488>>2]);
       HEAPF32[$375>>2] = $489;
       $490 = ((($boxVertices1) + (($485*12)|0)|0) + 8|0);
       $491 = Math_fround(HEAPF32[$490>>2]);
       HEAPF32[$376>>2] = $491;
       $492 = $482 | 1;
       $493 = (($327) + ($492)|0);
       $494 = HEAP8[$493>>0]|0;
       $495 = $494&255;
       $496 = (($boxVertices1) + (($495*12)|0)|0);
       $497 = Math_fround(HEAPF32[$496>>2]);
       HEAPF32[$p4>>2] = $497;
       $498 = ((($boxVertices1) + (($495*12)|0)|0) + 4|0);
       $499 = Math_fround(HEAPF32[$498>>2]);
       HEAPF32[$377>>2] = $499;
       $500 = ((($boxVertices1) + (($495*12)|0)|0) + 8|0);
       $501 = Math_fround(HEAPF32[$500>>2]);
       HEAPF32[$378>>2] = $501;
       $502 = Math_fround($497 - $487);
       $503 = Math_fround($499 - $489);
       $504 = Math_fround($501 - $491);
       $505 = Math_fround($502 * $502);
       $506 = Math_fround($503 * $503);
       $507 = Math_fround($505 + $506);
       $508 = Math_fround($504 * $504);
       $509 = Math_fround($507 + $508);
       $510 = (Math_fround(Math_sqrt((Math_fround($509)))));
       $511 = $510 > Math_fround(0.0);
       if ($511) {
        $512 = Math_fround(Math_fround(0.00999999977648258209228) / $510);
        $513 = Math_fround($502 * $512);
        $514 = Math_fround($503 * $512);
        $515 = Math_fround($504 * $512);
        $516 = Math_fround($487 - $513);
        HEAPF32[$p3>>2] = $516;
        $517 = Math_fround($489 - $514);
        HEAPF32[$375>>2] = $517;
        $518 = Math_fround($491 - $515);
        HEAPF32[$376>>2] = $518;
        $519 = Math_fround($513 + $497);
        HEAPF32[$p4>>2] = $519;
        $520 = Math_fround($514 + $499);
        HEAPF32[$377>>2] = $520;
        $521 = Math_fround($515 + $501);
        HEAPF32[$378>>2] = $521;
       }
       $522 = (__ZN5physx2Gu17intersectEdgeEdgeERKNS_6PxVec3ES3_S3_S3_S3_RfRS1_($p1,$p2,$dir,$p3,$p4,$Dist,$ip)|0);
       if ($522) {
        $523 = Math_fround(HEAPF32[$Dist>>2]);
        $524 = !($523 <= $MinDist$543);
        if ($524) {
         $MinDist$6 = $MinDist$543;$col$6 = $col$542;
        } else {
         $dir$idx$val = Math_fround(HEAPF32[$dir>>2]);
         $dir$idx2$val = Math_fround(HEAPF32[$89>>2]);
         $dir$idx3$val = Math_fround(HEAPF32[$97>>2]);
         $525 = Math_fround($523 * $dir$idx$val);
         $526 = Math_fround($523 * $dir$idx2$val);
         $527 = Math_fround($523 * $dir$idx3$val);
         $528 = Math_fround(HEAPF32[$ip>>2]);
         $529 = Math_fround($525 + $528);
         $530 = Math_fround(HEAPF32[$379>>2]);
         $531 = Math_fround($526 + $530);
         $532 = Math_fround(HEAPF32[$380>>2]);
         $533 = Math_fround($527 + $532);
         HEAPF32[$hit>>2] = $529;
         HEAPF32[$114>>2] = $531;
         HEAPF32[$115>>2] = $533;
         $534 = Math_fround(HEAPF32[$p1>>2]);
         $535 = Math_fround(HEAPF32[$p2>>2]);
         $536 = Math_fround($534 - $535);
         $537 = Math_fround(HEAPF32[$371>>2]);
         $538 = Math_fround(HEAPF32[$373>>2]);
         $539 = Math_fround($537 - $538);
         $540 = Math_fround(HEAPF32[$372>>2]);
         $541 = Math_fround(HEAPF32[$374>>2]);
         $542 = Math_fround($540 - $541);
         $543 = Math_fround(HEAPF32[$p3>>2]);
         $544 = Math_fround(HEAPF32[$p4>>2]);
         $545 = Math_fround($543 - $544);
         $546 = Math_fround(HEAPF32[$375>>2]);
         $547 = Math_fround(HEAPF32[$377>>2]);
         $548 = Math_fround($546 - $547);
         $549 = Math_fround(HEAPF32[$376>>2]);
         $550 = Math_fround(HEAPF32[$378>>2]);
         $551 = Math_fround($549 - $550);
         $552 = Math_fround($539 * $551);
         $553 = Math_fround($542 * $548);
         $554 = Math_fround($552 - $553);
         $555 = Math_fround($542 * $545);
         $556 = Math_fround($536 * $551);
         $557 = Math_fround($555 - $556);
         $558 = Math_fround($536 * $548);
         $559 = Math_fround($539 * $545);
         $560 = Math_fround($558 - $559);
         HEAPF32[$normal>>2] = $554;
         HEAPF32[$112>>2] = $557;
         HEAPF32[$113>>2] = $560;
         $561 = Math_fround($554 * $554);
         $562 = Math_fround($557 * $557);
         $563 = Math_fround($561 + $562);
         $564 = Math_fround($560 * $560);
         $565 = Math_fround($564 + $563);
         $566 = (Math_fround(Math_sqrt((Math_fround($565)))));
         $567 = $566 > Math_fround(0.0);
         if ($567) {
          $568 = Math_fround(Math_fround(1.0) / $566);
          $569 = Math_fround($554 * $568);
          HEAPF32[$normal>>2] = $569;
          $570 = Math_fround($557 * $568);
          HEAPF32[$112>>2] = $570;
          $571 = Math_fround($560 * $568);
          HEAPF32[$113>>2] = $571;
          $574 = $569;$577 = $570;$581 = $571;
         } else {
          $574 = $554;$577 = $557;$581 = $560;
         }
         $572 = Math_fround(HEAPF32[$dir>>2]);
         $573 = Math_fround($574 * $572);
         $575 = Math_fround(HEAPF32[$89>>2]);
         $576 = Math_fround($577 * $575);
         $578 = Math_fround($573 + $576);
         $579 = Math_fround(HEAPF32[$97>>2]);
         $580 = Math_fround($581 * $579);
         $582 = Math_fround($578 + $580);
         $583 = $582 > Math_fround(0.0);
         if ($583) {
          $584 = Math_fround(-$574);
          $585 = Math_fround(-$577);
          $586 = Math_fround(-$581);
          HEAPF32[$normal>>2] = $584;
          HEAPF32[$112>>2] = $585;
          HEAPF32[$113>>2] = $586;
          $MinDist$6 = $523;$col$6 = 2;
         } else {
          $MinDist$6 = $523;$col$6 = 2;
         }
        }
       } else {
        $MinDist$6 = $MinDist$543;$col$6 = $col$542;
       }
      } else {
       $MinDist$6 = $MinDist$543;$col$6 = $col$542;
      }
     } else {
      $MinDist$6 = $MinDist$543;$col$6 = $col$542;
     }
     $587 = (($j$044) + 1)|0;
     $exitcond = ($587|0)==(12);
     if ($exitcond) {
      $MinDist$7 = $MinDist$6;$col$7 = $col$6;
      break L29;
     }
     $$pre = Math_fround(HEAPF32[$dir>>2]);
     $$pre63 = Math_fround(HEAPF32[$89>>2]);
     $$pre64 = Math_fround(HEAPF32[$97>>2]);
     $464 = $$pre;$468 = $$pre63;$473 = $$pre64;$MinDist$543 = $MinDist$6;$col$542 = $col$6;$j$044 = $587;
    }
   }
  } while(0);
  $588 = (($i7$047) + 1)|0;
  $exitcond58 = ($588|0)==(12);
  if ($exitcond58) {
   break;
  } else {
   $MinDist$446 = $MinDist$7;$col$445 = $col$7;$i7$047 = $588;
  }
 }
 $589 = ($col$7|0)==(-1);
 if ($589) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 HEAPF32[$t>>2] = $MinDist$7;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx2Gu14sweepBoxSphereERKNS0_3BoxEfRKNS_6PxVec3ES6_fRfRS4_NS_7PxFlagsINS_9PxHitFlag4EnumEtEE($box,$sphereRadius,$spherePos,$dir,$length,$min_dist,$normal,$hintFlags) {
 $box = $box|0;
 $sphereRadius = Math_fround($sphereRadius);
 $spherePos = $spherePos|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $min_dist = $min_dist|0;
 $normal = $normal|0;
 $hintFlags = $hintFlags|0;
 var $$ = Math_fround(0), $$0 = 0, $$pre$phi45Z2D = 0, $$pre$phi47Z2D = 0, $$pre$phiZ2D = 0, $$pre44 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0;
 var $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0;
 var $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0;
 var $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0);
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0;
 var $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0);
 var $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0);
 var $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0);
 var $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0);
 var $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $MinDist$042 = Math_fround(0), $MinDist$1 = Math_fround(0);
 var $MinDist$2 = Math_fround(0), $MinDist$3 = Math_fround(0), $MinDist$4 = Math_fround(0), $Status$0$off041 = 0, $Status$1$off0 = 0, $Status$2$off0 = 0, $Status$3$off0 = 0, $Status$4$off0 = 0, $boxPts = 0, $capsule = 0, $dir$idx$val = Math_fround(0), $dir$idx16 = 0, $dir$idx16$val = Math_fround(0), $dir$idx17 = 0, $dir$idx17$val = Math_fround(0), $edges$043 = 0, $exitcond = 0, $i$040 = 0, $ip = 0, $localDir = 0;
 var $localPt = 0, $or$cond = 0, $or$cond13 = 0, $or$cond14 = 0, $or$cond15 = 0, $s = 0, $storemerge = Math_fround(0), $t = 0, $tfar = 0, $tnear = 0, $worldBox0 = 0, $worldBox1 = 0, $worldBox2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $0 = sp + 400|0;
 $boxPts = sp + 304|0;
 $capsule = sp + 272|0;
 $s = sp + 264|0;
 $t = sp + 260|0;
 $ip = sp + 248|0;
 $localPt = sp + 236|0;
 $worldBox0 = sp + 176|0;
 $worldBox1 = sp + 116|0;
 $worldBox2 = sp + 44|0;
 $localDir = sp + 32|0;
 $tnear = sp + 28|0;
 $tfar = sp + 24|0;
 $1 = sp + 12|0;
 $2 = sp;
 $3 = sp + 104|0;
 $4 = HEAP16[$hintFlags>>1]|0;
 $5 = $4 & 16;
 $6 = ($5<<16>>16)==(0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$spherePos>>2]);
  HEAPF32[$0>>2] = $7;
  $8 = (($0) + 4|0);
  $9 = (($spherePos) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$8>>2] = $10;
  $11 = (($0) + 8|0);
  $12 = (($spherePos) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $13;
  $14 = (($0) + 12|0);
  HEAPF32[$14>>2] = $sphereRadius;
  $15 = (__ZN5physx2Gu18intersectSphereBoxERKNS0_6SphereERKNS0_3BoxE($0,$box)|0);
  if ($15) {
   HEAPF32[$min_dist>>2] = Math_fround(0.0);
   $16 = Math_fround(HEAPF32[$dir>>2]);
   $17 = Math_fround(-$16);
   $18 = (($dir) + 4|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround(-$19);
   $21 = (($dir) + 8|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = Math_fround(-$22);
   HEAPF32[$normal>>2] = $17;
   $24 = (($normal) + 4|0);
   HEAPF32[$24>>2] = $20;
   $25 = (($normal) + 8|0);
   HEAPF32[$25>>2] = $23;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$pre$phi45Z2D = $9;$$pre$phi47Z2D = $12;$$pre$phiZ2D = $spherePos;
  }
 } else {
  $$pre44 = (($spherePos) + 4|0);
  $$pre46 = (($spherePos) + 8|0);
  $$pre$phi45Z2D = $$pre44;$$pre$phi47Z2D = $$pre46;$$pre$phiZ2D = $spherePos;
 }
 $26 = (($box) + 36|0);
 $27 = (($box) + 48|0);
 $28 = (($box) + 12|0);
 $29 = (($box) + 24|0);
 __ZN5physx2Gu16computeOBBPointsEPNS_6PxVec3ERKS1_S4_S4_S4_S4_($boxPts,$26,$27,$box,$28,$29);
 $30 = (__ZN5physx2Gu11getBoxEdgesEv()|0);
 $31 = (($capsule) + 4|0);
 $32 = (($capsule) + 8|0);
 $33 = (($capsule) + 12|0);
 $34 = (($capsule) + 16|0);
 $35 = (($capsule) + 20|0);
 $36 = (($capsule) + 24|0);
 $dir$idx16 = (($dir) + 4|0);
 $dir$idx17 = (($dir) + 8|0);
 $37 = (($ip) + 4|0);
 $38 = (($ip) + 8|0);
 $39 = (($capsule) + 12|0);
 $40 = (($normal) + 4|0);
 $41 = (($normal) + 8|0);
 $42 = (($s) + 4|0);
 $MinDist$042 = $length;$Status$0$off041 = 0;$edges$043 = $30;$i$040 = 0;
 while(1) {
  $43 = (($edges$043) + 1|0);
  $44 = HEAP8[$edges$043>>0]|0;
  $45 = (($edges$043) + 2|0);
  $46 = HEAP8[$43>>0]|0;
  $47 = $44&255;
  $48 = $46&255;
  $49 = (($boxPts) + (($47*12)|0)|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$capsule>>2] = $50;
  $51 = ((($boxPts) + (($47*12)|0)|0) + 4|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  HEAPF32[$31>>2] = $52;
  $53 = ((($boxPts) + (($47*12)|0)|0) + 8|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  HEAPF32[$32>>2] = $54;
  $55 = (($boxPts) + (($48*12)|0)|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$33>>2] = $56;
  $57 = ((($boxPts) + (($48*12)|0)|0) + 4|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$34>>2] = $58;
  $59 = ((($boxPts) + (($48*12)|0)|0) + 8|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  HEAPF32[$35>>2] = $60;
  HEAPF32[$36>>2] = $sphereRadius;
  $61 = (__ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($spherePos,$dir,$capsule,$s)|0);
  $62 = ($61|0)==(0);
  if ($62) {
   $MinDist$1 = $MinDist$042;$Status$1$off0 = $Status$0$off041;
  } else {
   $63 = ($61|0)==(1);
   $64 = Math_fround(HEAPF32[$s>>2]);
   if ($63) {
    $storemerge = $64;
   } else {
    $65 = Math_fround(HEAPF32[$42>>2]);
    $66 = $64 < $65;
    $$ = $66 ? $64 : $65;
    $storemerge = $$;
   }
   HEAPF32[$t>>2] = $storemerge;
   $67 = !($storemerge >= Math_fround(0.0));
   $68 = !($storemerge <= $MinDist$042);
   $or$cond = $67 | $68;
   if ($or$cond) {
    $MinDist$1 = $MinDist$042;$Status$1$off0 = $Status$0$off041;
   } else {
    $dir$idx$val = Math_fround(HEAPF32[$dir>>2]);
    $dir$idx16$val = Math_fround(HEAPF32[$dir$idx16>>2]);
    $dir$idx17$val = Math_fround(HEAPF32[$dir$idx17>>2]);
    $69 = Math_fround($storemerge * $dir$idx$val);
    $70 = Math_fround($storemerge * $dir$idx16$val);
    $71 = Math_fround($storemerge * $dir$idx17$val);
    $72 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
    $73 = Math_fround($69 + $72);
    $74 = Math_fround(HEAPF32[$$pre$phi45Z2D>>2]);
    $75 = Math_fround($70 + $74);
    $76 = Math_fround(HEAPF32[$$pre$phi47Z2D>>2]);
    $77 = Math_fround($71 + $76);
    HEAPF32[$ip>>2] = $73;
    HEAPF32[$37>>2] = $75;
    HEAPF32[$38>>2] = $77;
    (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($capsule,$39,$ip,$t)));
    $78 = Math_fround(HEAPF32[$t>>2]);
    $79 = Math_fround(HEAPF32[$33>>2]);
    $80 = Math_fround(HEAPF32[$capsule>>2]);
    $81 = Math_fround($79 - $80);
    $82 = Math_fround(HEAPF32[$34>>2]);
    $83 = Math_fround(HEAPF32[$31>>2]);
    $84 = Math_fround($82 - $83);
    $85 = Math_fround(HEAPF32[$35>>2]);
    $86 = Math_fround(HEAPF32[$32>>2]);
    $87 = Math_fround($85 - $86);
    $88 = Math_fround($78 * $81);
    $89 = Math_fround($78 * $84);
    $90 = Math_fround($78 * $87);
    $91 = Math_fround($80 + $88);
    $92 = Math_fround($83 + $89);
    $93 = Math_fround($86 + $90);
    $94 = Math_fround(HEAPF32[$ip>>2]);
    $95 = Math_fround($91 - $94);
    $96 = Math_fround(HEAPF32[$37>>2]);
    $97 = Math_fround($92 - $96);
    $98 = Math_fround(HEAPF32[$38>>2]);
    $99 = Math_fround($93 - $98);
    HEAPF32[$normal>>2] = $95;
    HEAPF32[$40>>2] = $97;
    HEAPF32[$41>>2] = $99;
    $100 = Math_fround($95 * $95);
    $101 = Math_fround($97 * $97);
    $102 = Math_fround($100 + $101);
    $103 = Math_fround($99 * $99);
    $104 = Math_fround($103 + $102);
    $105 = (Math_fround(Math_sqrt((Math_fround($104)))));
    $106 = $105 > Math_fround(0.0);
    if ($106) {
     $107 = Math_fround(Math_fround(1.0) / $105);
     $108 = Math_fround($95 * $107);
     HEAPF32[$normal>>2] = $108;
     $109 = Math_fround($97 * $107);
     HEAPF32[$40>>2] = $109;
     $110 = Math_fround($99 * $107);
     HEAPF32[$41>>2] = $110;
     $MinDist$1 = $storemerge;$Status$1$off0 = 1;
    } else {
     $MinDist$1 = $storemerge;$Status$1$off0 = 1;
    }
   }
  }
  $111 = (($i$040) + 1)|0;
  $exitcond = ($111|0)==(12);
  if ($exitcond) {
   break;
  } else {
   $MinDist$042 = $MinDist$1;$Status$0$off041 = $Status$1$off0;$edges$043 = $45;$i$040 = $111;
  }
 }
 $112 = Math_fround(HEAPF32[$box>>2]);
 $113 = (($box) + 4|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($box) + 8|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (($box) + 12|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($box) + 16|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($box) + 20|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($box) + 24|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($box) + 28|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($box) + 32|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($box) + 36|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($box) + 40|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($box) + 44|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $136 = Math_fround($135 - $130);
 $137 = Math_fround(HEAPF32[$$pre$phi45Z2D>>2]);
 $138 = Math_fround($137 - $132);
 $139 = Math_fround(HEAPF32[$$pre$phi47Z2D>>2]);
 $140 = Math_fround($139 - $134);
 $141 = Math_fround($112 * $136);
 $142 = Math_fround($114 * $138);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround($116 * $140);
 $145 = Math_fround($143 + $144);
 $146 = Math_fround($118 * $136);
 $147 = Math_fround($120 * $138);
 $148 = Math_fround($146 + $147);
 $149 = Math_fround($122 * $140);
 $150 = Math_fround($148 + $149);
 $151 = Math_fround($124 * $136);
 $152 = Math_fround($126 * $138);
 $153 = Math_fround($151 + $152);
 $154 = Math_fround($128 * $140);
 $155 = Math_fround($153 + $154);
 HEAPF32[$localPt>>2] = $145;
 $156 = (($localPt) + 4|0);
 HEAPF32[$156>>2] = $150;
 $157 = (($localPt) + 8|0);
 HEAPF32[$157>>2] = $155;
 HEAPF32[$worldBox0>>2] = $112;
 $158 = (($worldBox0) + 4|0);
 HEAPF32[$158>>2] = $114;
 $159 = (($worldBox0) + 8|0);
 HEAPF32[$159>>2] = $116;
 $160 = (($worldBox0) + 12|0);
 HEAPF32[$160>>2] = $118;
 $161 = (($worldBox0) + 16|0);
 HEAPF32[$161>>2] = $120;
 $162 = (($worldBox0) + 20|0);
 HEAPF32[$162>>2] = $122;
 $163 = (($worldBox0) + 24|0);
 HEAPF32[$163>>2] = $124;
 $164 = (($worldBox0) + 28|0);
 HEAPF32[$164>>2] = $126;
 $165 = (($worldBox0) + 32|0);
 HEAPF32[$165>>2] = $128;
 $166 = (($worldBox0) + 36|0);
 HEAPF32[$166>>2] = $130;
 $167 = (($worldBox0) + 40|0);
 HEAPF32[$167>>2] = $132;
 $168 = (($worldBox0) + 44|0);
 HEAPF32[$168>>2] = $134;
 $169 = (($box) + 48|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = (($worldBox0) + 52|0);
 $172 = (($box) + 52|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 HEAPF32[$171>>2] = $173;
 $174 = (($worldBox0) + 56|0);
 $175 = (($box) + 56|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 HEAPF32[$174>>2] = $176;
 HEAPF32[$worldBox1>>2] = $112;
 $177 = (($worldBox1) + 4|0);
 HEAPF32[$177>>2] = $114;
 $178 = (($worldBox1) + 8|0);
 HEAPF32[$178>>2] = $116;
 $179 = (($worldBox1) + 12|0);
 HEAPF32[$179>>2] = $118;
 $180 = (($worldBox1) + 16|0);
 HEAPF32[$180>>2] = $120;
 $181 = (($worldBox1) + 20|0);
 HEAPF32[$181>>2] = $122;
 $182 = (($worldBox1) + 24|0);
 HEAPF32[$182>>2] = $124;
 $183 = (($worldBox1) + 28|0);
 HEAPF32[$183>>2] = $126;
 $184 = (($worldBox1) + 32|0);
 HEAPF32[$184>>2] = $128;
 $185 = (($worldBox1) + 36|0);
 HEAPF32[$185>>2] = $130;
 $186 = (($worldBox1) + 40|0);
 HEAPF32[$186>>2] = $132;
 $187 = (($worldBox1) + 44|0);
 HEAPF32[$187>>2] = $134;
 $188 = (($worldBox1) + 48|0);
 HEAPF32[$188>>2] = $170;
 $189 = (($worldBox1) + 52|0);
 $190 = (($worldBox1) + 56|0);
 HEAPF32[$190>>2] = $176;
 $191 = Math_fround(HEAPF32[$box>>2]);
 HEAPF32[$worldBox2>>2] = $191;
 $192 = (($worldBox2) + 4|0);
 $193 = Math_fround(HEAPF32[$113>>2]);
 HEAPF32[$192>>2] = $193;
 $194 = (($worldBox2) + 8|0);
 $195 = Math_fround(HEAPF32[$115>>2]);
 HEAPF32[$194>>2] = $195;
 $196 = (($worldBox2) + 12|0);
 $197 = Math_fround(HEAPF32[$117>>2]);
 HEAPF32[$196>>2] = $197;
 $198 = (($worldBox2) + 16|0);
 $199 = Math_fround(HEAPF32[$119>>2]);
 HEAPF32[$198>>2] = $199;
 $200 = (($worldBox2) + 20|0);
 $201 = Math_fround(HEAPF32[$121>>2]);
 HEAPF32[$200>>2] = $201;
 $202 = (($worldBox2) + 24|0);
 $203 = Math_fround(HEAPF32[$123>>2]);
 HEAPF32[$202>>2] = $203;
 $204 = (($worldBox2) + 28|0);
 $205 = Math_fround(HEAPF32[$125>>2]);
 HEAPF32[$204>>2] = $205;
 $206 = (($worldBox2) + 32|0);
 $207 = Math_fround(HEAPF32[$127>>2]);
 HEAPF32[$206>>2] = $207;
 $208 = (($worldBox2) + 36|0);
 $209 = Math_fround(HEAPF32[$129>>2]);
 HEAPF32[$208>>2] = $209;
 $210 = (($worldBox2) + 40|0);
 $211 = Math_fround(HEAPF32[$131>>2]);
 HEAPF32[$210>>2] = $211;
 $212 = (($worldBox2) + 44|0);
 $213 = Math_fround(HEAPF32[$133>>2]);
 HEAPF32[$212>>2] = $213;
 $214 = (($worldBox2) + 48|0);
 HEAPF32[$214>>2] = $170;
 $215 = (($worldBox2) + 52|0);
 HEAPF32[$215>>2] = $173;
 $216 = (($worldBox2) + 56|0);
 $217 = (($worldBox0) + 48|0);
 $218 = Math_fround($170 + $sphereRadius);
 HEAPF32[$217>>2] = $218;
 $219 = (($worldBox1) + 48|0);
 $220 = Math_fround($173 + $sphereRadius);
 HEAPF32[$189>>2] = $220;
 $221 = (($worldBox2) + 48|0);
 $222 = Math_fround($176 + $sphereRadius);
 HEAPF32[$216>>2] = $222;
 $223 = Math_fround(HEAPF32[$dir>>2]);
 $224 = Math_fround($191 * $223);
 $225 = Math_fround(HEAPF32[$dir$idx16>>2]);
 $226 = Math_fround($193 * $225);
 $227 = Math_fround($224 + $226);
 $228 = Math_fround(HEAPF32[$dir$idx17>>2]);
 $229 = Math_fround($195 * $228);
 $230 = Math_fround($227 + $229);
 $231 = Math_fround($223 * $197);
 $232 = Math_fround($225 * $199);
 $233 = Math_fround($231 + $232);
 $234 = Math_fround($228 * $201);
 $235 = Math_fround($233 + $234);
 $236 = Math_fround($223 * $203);
 $237 = Math_fround($225 * $205);
 $238 = Math_fround($236 + $237);
 $239 = Math_fround($228 * $207);
 $240 = Math_fround($238 + $239);
 HEAPF32[$localDir>>2] = $230;
 $241 = (($localDir) + 4|0);
 HEAPF32[$241>>2] = $235;
 $242 = (($localDir) + 8|0);
 HEAPF32[$242>>2] = $240;
 $243 = Math_fround(-$218);
 $244 = Math_fround(HEAPF32[$171>>2]);
 $245 = Math_fround(-$244);
 $246 = Math_fround(HEAPF32[$174>>2]);
 $247 = Math_fround(-$246);
 HEAPF32[$1>>2] = $243;
 $248 = (($1) + 4|0);
 HEAPF32[$248>>2] = $245;
 $249 = (($1) + 8|0);
 HEAPF32[$249>>2] = $247;
 $250 = (__ZN5physx2Gu16intersectRayAABBERKNS_6PxVec3ES3_S3_S3_RfS4_($1,$217,$localPt,$localDir,$tnear,$tfar)|0);
 $251 = ($250|0)==(-1);
 if ($251) {
  $MinDist$2 = $MinDist$1;$Status$2$off0 = $Status$1$off0;
 } else {
  $252 = Math_fround(HEAPF32[$tnear>>2]);
  $253 = !($252 >= Math_fround(0.0));
  $254 = !($252 <= $MinDist$1);
  $or$cond13 = $253 | $254;
  if ($or$cond13) {
   $MinDist$2 = $MinDist$1;$Status$2$off0 = $Status$1$off0;
  } else {
   $255 = (550296 + (($250*12)|0)|0);
   $256 = Math_fround(HEAPF32[$255>>2]);
   $257 = Math_fround(HEAPF32[$box>>2]);
   $258 = Math_fround($256 * $257);
   $259 = Math_fround(HEAPF32[$113>>2]);
   $260 = Math_fround($256 * $259);
   $261 = Math_fround(HEAPF32[$115>>2]);
   $262 = Math_fround($256 * $261);
   $263 = ((550296 + (($250*12)|0)|0) + 4|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = Math_fround(HEAPF32[$117>>2]);
   $266 = Math_fround($264 * $265);
   $267 = Math_fround(HEAPF32[$119>>2]);
   $268 = Math_fround($264 * $267);
   $269 = Math_fround(HEAPF32[$121>>2]);
   $270 = Math_fround($264 * $269);
   $271 = Math_fround($258 + $266);
   $272 = Math_fround($260 + $268);
   $273 = Math_fround($262 + $270);
   $274 = ((550296 + (($250*12)|0)|0) + 8|0);
   $275 = Math_fround(HEAPF32[$274>>2]);
   $276 = Math_fround(HEAPF32[$123>>2]);
   $277 = Math_fround($275 * $276);
   $278 = Math_fround(HEAPF32[$125>>2]);
   $279 = Math_fround($275 * $278);
   $280 = Math_fround(HEAPF32[$127>>2]);
   $281 = Math_fround($275 * $280);
   $282 = Math_fround($271 + $277);
   $283 = Math_fround($272 + $279);
   $284 = Math_fround($273 + $281);
   HEAPF32[$normal>>2] = $282;
   HEAPF32[$40>>2] = $283;
   HEAPF32[$41>>2] = $284;
   $MinDist$2 = $252;$Status$2$off0 = 1;
  }
 }
 $285 = Math_fround(HEAPF32[$219>>2]);
 $286 = Math_fround(-$285);
 $287 = Math_fround(HEAPF32[$189>>2]);
 $288 = Math_fround(-$287);
 $289 = Math_fround(HEAPF32[$190>>2]);
 $290 = Math_fround(-$289);
 HEAPF32[$2>>2] = $286;
 $291 = (($2) + 4|0);
 HEAPF32[$291>>2] = $288;
 $292 = (($2) + 8|0);
 HEAPF32[$292>>2] = $290;
 $293 = (__ZN5physx2Gu16intersectRayAABBERKNS_6PxVec3ES3_S3_S3_RfS4_($2,$219,$localPt,$localDir,$tnear,$tfar)|0);
 $294 = ($293|0)==(-1);
 if ($294) {
  $MinDist$3 = $MinDist$2;$Status$3$off0 = $Status$2$off0;
 } else {
  $295 = Math_fround(HEAPF32[$tnear>>2]);
  $296 = !($295 >= Math_fround(0.0));
  $297 = !($295 <= $MinDist$2);
  $or$cond14 = $296 | $297;
  if ($or$cond14) {
   $MinDist$3 = $MinDist$2;$Status$3$off0 = $Status$2$off0;
  } else {
   $298 = (550296 + (($293*12)|0)|0);
   $299 = Math_fround(HEAPF32[$298>>2]);
   $300 = Math_fround(HEAPF32[$box>>2]);
   $301 = Math_fround($299 * $300);
   $302 = Math_fround(HEAPF32[$113>>2]);
   $303 = Math_fround($299 * $302);
   $304 = Math_fround(HEAPF32[$115>>2]);
   $305 = Math_fround($299 * $304);
   $306 = ((550296 + (($293*12)|0)|0) + 4|0);
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = Math_fround(HEAPF32[$117>>2]);
   $309 = Math_fround($307 * $308);
   $310 = Math_fround(HEAPF32[$119>>2]);
   $311 = Math_fround($307 * $310);
   $312 = Math_fround(HEAPF32[$121>>2]);
   $313 = Math_fround($307 * $312);
   $314 = Math_fround($301 + $309);
   $315 = Math_fround($303 + $311);
   $316 = Math_fround($305 + $313);
   $317 = ((550296 + (($293*12)|0)|0) + 8|0);
   $318 = Math_fround(HEAPF32[$317>>2]);
   $319 = Math_fround(HEAPF32[$123>>2]);
   $320 = Math_fround($318 * $319);
   $321 = Math_fround(HEAPF32[$125>>2]);
   $322 = Math_fround($318 * $321);
   $323 = Math_fround(HEAPF32[$127>>2]);
   $324 = Math_fround($318 * $323);
   $325 = Math_fround($314 + $320);
   $326 = Math_fround($315 + $322);
   $327 = Math_fround($316 + $324);
   HEAPF32[$normal>>2] = $325;
   HEAPF32[$40>>2] = $326;
   HEAPF32[$41>>2] = $327;
   $MinDist$3 = $295;$Status$3$off0 = 1;
  }
 }
 $328 = Math_fround(HEAPF32[$221>>2]);
 $329 = Math_fround(-$328);
 $330 = Math_fround(HEAPF32[$215>>2]);
 $331 = Math_fround(-$330);
 $332 = Math_fround(HEAPF32[$216>>2]);
 $333 = Math_fround(-$332);
 HEAPF32[$3>>2] = $329;
 $334 = (($3) + 4|0);
 HEAPF32[$334>>2] = $331;
 $335 = (($3) + 8|0);
 HEAPF32[$335>>2] = $333;
 $336 = (__ZN5physx2Gu16intersectRayAABBERKNS_6PxVec3ES3_S3_S3_RfS4_($3,$221,$localPt,$localDir,$tnear,$tfar)|0);
 $337 = ($336|0)==(-1);
 if ($337) {
  $MinDist$4 = $MinDist$3;$Status$4$off0 = $Status$3$off0;
 } else {
  $338 = Math_fround(HEAPF32[$tnear>>2]);
  $339 = !($338 >= Math_fround(0.0));
  $340 = !($338 <= $MinDist$3);
  $or$cond15 = $339 | $340;
  if ($or$cond15) {
   $MinDist$4 = $MinDist$3;$Status$4$off0 = $Status$3$off0;
  } else {
   $341 = (550296 + (($336*12)|0)|0);
   $342 = Math_fround(HEAPF32[$341>>2]);
   $343 = Math_fround(HEAPF32[$box>>2]);
   $344 = Math_fround($342 * $343);
   $345 = Math_fround(HEAPF32[$113>>2]);
   $346 = Math_fround($342 * $345);
   $347 = Math_fround(HEAPF32[$115>>2]);
   $348 = Math_fround($342 * $347);
   $349 = ((550296 + (($336*12)|0)|0) + 4|0);
   $350 = Math_fround(HEAPF32[$349>>2]);
   $351 = Math_fround(HEAPF32[$117>>2]);
   $352 = Math_fround($350 * $351);
   $353 = Math_fround(HEAPF32[$119>>2]);
   $354 = Math_fround($350 * $353);
   $355 = Math_fround(HEAPF32[$121>>2]);
   $356 = Math_fround($350 * $355);
   $357 = Math_fround($344 + $352);
   $358 = Math_fround($346 + $354);
   $359 = Math_fround($348 + $356);
   $360 = ((550296 + (($336*12)|0)|0) + 8|0);
   $361 = Math_fround(HEAPF32[$360>>2]);
   $362 = Math_fround(HEAPF32[$123>>2]);
   $363 = Math_fround($361 * $362);
   $364 = Math_fround(HEAPF32[$125>>2]);
   $365 = Math_fround($361 * $364);
   $366 = Math_fround(HEAPF32[$127>>2]);
   $367 = Math_fround($361 * $366);
   $368 = Math_fround($357 + $363);
   $369 = Math_fround($358 + $365);
   $370 = Math_fround($359 + $367);
   HEAPF32[$normal>>2] = $368;
   HEAPF32[$40>>2] = $369;
   HEAPF32[$41>>2] = $370;
   $MinDist$4 = $338;$Status$4$off0 = 1;
  }
 }
 HEAPF32[$min_dist>>2] = $MinDist$4;
 $$0 = $Status$4$off0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu16sweepBoxTriangleERKNS_10PxTriangleERKNS_9PxBounds3EPKNS_6PxVec3EPKNS0_11FatEdgeDataERS8_SD_RS7_SE_Rf($tri,$box,$boxVertices,$fatEdges,$motion,$oneOverMotion,$hit,$normal,$d) {
 $tri = $tri|0;
 $box = $box|0;
 $boxVertices = $boxVertices|0;
 $fatEdges = $fatEdges|0;
 $motion = $motion|0;
 $oneOverMotion = $oneOverMotion|0;
 $hit = $hit|0;
 $normal = $normal|0;
 $d = $d|0;
 var $$ = 0, $$$i = 0, $$0$i30 = 0, $$1 = 0, $$2$i = Math_fround(0), $$3$i = Math_fround(0), $$4$i = Math_fround(0), $$4$i$us = Math_fround(0), $$5$i = Math_fround(0), $$5$i$us = Math_fround(0), $$6$i = 0, $$6$i$us = 0, $$idx = 0, $$idx$val = Math_fround(0), $$idx21 = 0, $$idx21$val = Math_fround(0), $$idx22 = 0, $$idx22$val = Math_fround(0), $$idx23 = 0, $$idx23$val = Math_fround(0);
 var $$idx24 = 0, $$idx24$val = Math_fround(0), $$idx25 = 0, $$idx25$val = Math_fround(0), $$idx26 = 0, $$idx26$val = Math_fround(0), $$idx6 = 0, $$idx6$val = Math_fround(0), $$idx7 = 0, $$idx7$val = Math_fround(0), $$not = 0, $$phi$trans$insert4$i = 0, $$phi$trans$insert4$i$us = 0, $$pre = 0, $$pre136 = 0, $$pre3$i = Math_fround(0), $$pre3$i$us = Math_fround(0), $$pre5$i = Math_fround(0), $$pre5$i$us = Math_fround(0), $$pre7$i = Math_fround(0);
 var $$pre7$i$us = Math_fround(0), $$ret$4$i = 0, $$ret$4$i$us = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0);
 var $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0;
 var $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0;
 var $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = Math_fround(0);
 var $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0;
 var $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0;
 var $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0);
 var $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0;
 var $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0);
 var $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = 0, $419 = Math_fround(0);
 var $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0);
 var $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = 0, $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $MinDist$0$ = Math_fround(0), $MinDist$0103 = Math_fround(0), $MinDist$1 = Math_fround(0), $MinDist$253 = Math_fround(0), $MinDist$3$lcssa = Math_fround(0), $MinDist$397 = Math_fround(0), $MinDist$397$us = Math_fround(0), $MinDist$4 = Math_fround(0), $MinDist$4$us = Math_fround(0);
 var $MinDist$592 = Math_fround(0), $MinDist$6$ph$ph89 = Math_fround(0), $MinDist$8 = Math_fround(0), $by$0$i = 0, $by$0$i$us = 0, $col$0$ = 0, $col$0102 = 0, $col$1 = 0, $col$252 = 0, $col$3$lcssa = 0, $col$396 = 0, $col$396$us = 0, $col$4 = 0, $col$4$us = 0, $col$591 = 0, $col$6$ph$ph88 = 0, $col$8 = 0, $dir$idx$val$i = Math_fround(0), $dir$idx1$val$i = Math_fround(0), $dir$idx2$val$i = Math_fround(0);
 var $exitcond = 0, $exitcond133 = 0, $exitcond134 = 0, $exitcond135 = 0, $fabsf$i = Math_fround(0), $fabsf$i27 = Math_fround(0), $fabsf$i28 = Math_fround(0), $hitIndex$0$i$0 = 0, $hitIndex$0101 = 0, $hitIndex$1 = 0, $i$099 = 0, $i1$094 = 0, $i1$094$us = 0, $i2$090 = 0, $ip = 0, $j$0$ph$ph87 = 0, $j$069 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$us = 0;
 var $or$cond$i29 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond3$us = 0, $or$cond5 = 0, $p1 = 0, $ret$1$i = 0, $ret$1$i$us = 0, $ret$2$i = 0, $ret$2$i$us = 0, $ret$3$i = 0, $ret$3$i$us = 0, $ret$4$i = 0, $ret$4$i$us = 0, $t1y$0$i = Math_fround(0), $t1y$0$i$us = Math_fround(0), $t1y$0$i46 = Math_fround(0), $t1y$0$i46$us = Math_fround(0), $t1y$0$i47 = Math_fround(0), $t1y$0$i47$us = Math_fround(0);
 var $t1y$0$i48 = Math_fround(0), $t1y$0$i48$us = Math_fround(0), $t1y$0$i49 = Math_fround(0), $t1y$0$i49$us = Math_fround(0), $t2y$0$i = Math_fround(0), $t2y$0$i$us = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p1 = sp + 12|0;
 $ip = sp;
 $0 = (($tri) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$tri>>2]);
 $3 = Math_fround($1 - $2);
 $4 = (($tri) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($tri) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($tri) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($tri) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = (($tri) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 - $2);
 $17 = (($tri) + 28|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 - $7);
 $20 = (($tri) + 32|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 - $12);
 $23 = Math_fround($8 * $22);
 $24 = Math_fround($13 * $19);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($13 * $16);
 $27 = Math_fround($3 * $22);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($3 * $19);
 $30 = Math_fround($8 * $16);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround(HEAPF32[$motion>>2]);
 $33 = Math_fround($32 * $25);
 $34 = (($motion) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * $28);
 $37 = Math_fround($33 + $36);
 $38 = (($motion) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($31 * $39);
 $41 = Math_fround($40 + $37);
 $42 = !($41 >= Math_fround(0.0));
 if (!($42)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $43 = Math_fround($1 + $2);
 $44 = Math_fround($5 + $7);
 $45 = Math_fround($10 + $12);
 $46 = Math_fround($43 + $15);
 $47 = Math_fround($44 + $18);
 $48 = Math_fround($45 + $21);
 $49 = Math_fround($46 * Math_fround(0.333333343267440795898));
 $50 = Math_fround($47 * Math_fround(0.333333343267440795898));
 $51 = Math_fround($48 * Math_fround(0.333333343267440795898));
 $52 = Math_fround($2 - $49);
 $53 = Math_fround($7 - $50);
 $54 = Math_fround($12 - $51);
 $55 = Math_fround($52 * Math_fround(0.0199999995529651641846));
 $56 = Math_fround($53 * Math_fround(0.0199999995529651641846));
 $57 = Math_fround($54 * Math_fround(0.0199999995529651641846));
 $58 = Math_fround($2 + $55);
 $59 = Math_fround($7 + $56);
 $60 = Math_fround($12 + $57);
 $61 = Math_fround($1 - $49);
 $62 = Math_fround($5 - $50);
 $63 = Math_fround($10 - $51);
 $64 = Math_fround($61 * Math_fround(0.0199999995529651641846));
 $65 = Math_fround($62 * Math_fround(0.0199999995529651641846));
 $66 = Math_fround($63 * Math_fround(0.0199999995529651641846));
 $67 = Math_fround($1 + $64);
 $68 = Math_fround($5 + $65);
 $69 = Math_fround($10 + $66);
 $70 = Math_fround($15 - $49);
 $71 = Math_fround($18 - $50);
 $72 = Math_fround($21 - $51);
 $73 = Math_fround($70 * Math_fround(0.0199999995529651641846));
 $74 = Math_fround($71 * Math_fround(0.0199999995529651641846));
 $75 = Math_fround($72 * Math_fround(0.0199999995529651641846));
 $76 = Math_fround($15 + $73);
 $77 = Math_fround($18 + $74);
 $78 = Math_fround($21 + $75);
 $79 = Math_fround(HEAPF32[$d>>2]);
 $80 = Math_fround(-$32);
 $81 = Math_fround(-$35);
 $82 = Math_fround(-$39);
 $83 = Math_fround(HEAPF32[$oneOverMotion>>2]);
 $84 = Math_fround(-$83);
 $85 = (($oneOverMotion) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround(-$86);
 $88 = (($oneOverMotion) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround(-$89);
 $91 = Math_fround($67 - $58);
 $92 = Math_fround($68 - $59);
 $93 = Math_fround($69 - $60);
 $94 = Math_fround($76 - $58);
 $95 = Math_fround($77 - $59);
 $96 = Math_fround($78 - $60);
 $97 = Math_fround($35 * $96);
 $98 = Math_fround($39 * $95);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($39 * $94);
 $101 = Math_fround($32 * $96);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($32 * $95);
 $104 = Math_fround($35 * $94);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($91 * $99);
 $107 = Math_fround($92 * $102);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($93 * $105);
 $110 = Math_fround($109 + $108);
 $111 = $110 != Math_fround(0.0);
 if ($111) {
  $112 = Math_fround(Math_fround(1.0) / $110);
  $159 = $112;
 } else {
  $159 = Math_fround(0.0);
 }
 $113 = !($110 >= Math_fround(9.99999974737875163555E-6));
 if ($113) {
  $MinDist$253 = $79;$col$252 = -1;
 } else {
  $446 = Math_fround(0.0);$MinDist$0103 = $79;$col$0102 = -1;$hitIndex$0101 = 0;$i$099 = 0;
  while(1) {
   $114 = (550440 + (($i$099*12)|0)|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = Math_fround($25 * $115);
   $117 = ((550440 + (($i$099*12)|0)|0) + 4|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = Math_fround($28 * $118);
   $120 = Math_fround($116 + $119);
   $121 = ((550440 + (($i$099*12)|0)|0) + 8|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = Math_fround($31 * $122);
   $124 = Math_fround($120 + $123);
   $125 = !($124 >= Math_fround(0.0));
   if ($125) {
    $$idx = (($boxVertices) + (($i$099*12)|0)|0);
    $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
    $$idx6 = ((($boxVertices) + (($i$099*12)|0)|0) + 4|0);
    $$idx6$val = Math_fround(HEAPF32[$$idx6>>2]);
    $$idx7 = ((($boxVertices) + (($i$099*12)|0)|0) + 8|0);
    $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
    $126 = Math_fround($$idx$val - $58);
    $127 = Math_fround($$idx6$val - $59);
    $128 = Math_fround($$idx7$val - $60);
    $129 = Math_fround($99 * $126);
    $130 = Math_fround($102 * $127);
    $131 = Math_fround($129 + $130);
    $132 = Math_fround($105 * $128);
    $133 = Math_fround($131 + $132);
    $134 = $133 < Math_fround(0.0);
    $135 = $133 > $110;
    $or$cond$i29 = $134 | $135;
    if ($or$cond$i29) {
     $$0$i30 = 1;$161 = $446;
    } else {
     $136 = Math_fround($93 * $127);
     $137 = Math_fround($92 * $128);
     $138 = Math_fround($136 - $137);
     $139 = Math_fround($91 * $128);
     $140 = Math_fround($93 * $126);
     $141 = Math_fround($139 - $140);
     $142 = Math_fround($92 * $126);
     $143 = Math_fround($91 * $127);
     $144 = Math_fround($142 - $143);
     $145 = Math_fround($138 * $32);
     $146 = Math_fround($141 * $35);
     $147 = Math_fround($145 + $146);
     $148 = Math_fround($144 * $39);
     $149 = Math_fround($147 + $148);
     $150 = $149 < Math_fround(0.0);
     if ($150) {
      $$0$i30 = 1;$161 = $446;
     } else {
      $151 = Math_fround($133 + $149);
      $152 = $151 > $110;
      if ($152) {
       $$0$i30 = 1;$161 = $446;
      } else {
       $153 = Math_fround($94 * $138);
       $154 = Math_fround($95 * $141);
       $155 = Math_fround($153 + $154);
       $156 = Math_fround($96 * $144);
       $157 = Math_fround($156 + $155);
       $158 = Math_fround($159 * $157);
       $$0$i30 = 0;$161 = $158;
      }
     }
    }
    $160 = $161 < Math_fround(0.0);
    $or$cond = $$0$i30 | $160;
    $162 = $161 > $MinDist$0103;
    $or$cond2 = $or$cond | $162;
    $hitIndex$0$i$0 = $or$cond2 ? $hitIndex$0101 : $i$099;
    $col$0$ = $or$cond2 ? $col$0102 : 0;
    $MinDist$0$ = $or$cond2 ? $MinDist$0103 : $161;
    $447 = $161;$MinDist$1 = $MinDist$0$;$col$1 = $col$0$;$hitIndex$1 = $hitIndex$0$i$0;
   } else {
    $447 = $446;$MinDist$1 = $MinDist$0103;$col$1 = $col$0102;$hitIndex$1 = $hitIndex$0101;
   }
   $163 = (($i$099) + 1)|0;
   $exitcond134 = ($163|0)==(8);
   if ($exitcond134) {
    break;
   } else {
    $446 = $447;$MinDist$0103 = $MinDist$1;$col$0102 = $col$1;$hitIndex$0101 = $hitIndex$1;$i$099 = $163;
   }
  }
  $164 = ($col$1|0)==(0);
  if ($164) {
   $165 = Math_fround($MinDist$1 * $32);
   $166 = Math_fround($MinDist$1 * $35);
   $167 = Math_fround($MinDist$1 * $39);
   $168 = (($boxVertices) + (($hitIndex$1*12)|0)|0);
   $169 = Math_fround(HEAPF32[$168>>2]);
   $170 = Math_fround($165 + $169);
   $171 = ((($boxVertices) + (($hitIndex$1*12)|0)|0) + 4|0);
   $172 = Math_fround(HEAPF32[$171>>2]);
   $173 = Math_fround($166 + $172);
   $174 = ((($boxVertices) + (($hitIndex$1*12)|0)|0) + 8|0);
   $175 = Math_fround(HEAPF32[$174>>2]);
   $176 = Math_fround($167 + $175);
   HEAPF32[$hit>>2] = $170;
   $177 = (($hit) + 4|0);
   HEAPF32[$177>>2] = $173;
   $178 = (($hit) + 8|0);
   HEAPF32[$178>>2] = $176;
   HEAPF32[$normal>>2] = $25;
   $179 = (($normal) + 4|0);
   HEAPF32[$179>>2] = $28;
   $180 = (($normal) + 8|0);
   HEAPF32[$180>>2] = $31;
   $MinDist$253 = $MinDist$1;$col$252 = 0;
  } else {
   $MinDist$253 = $MinDist$1;$col$252 = $col$1;
  }
 }
 $fabsf$i28 = (Math_fround(Math_abs((Math_fround($80)))));
 $181 = $fabsf$i28 < Math_fround(1.1920928955078125E-7);
 $fabsf$i27 = (Math_fround(Math_abs((Math_fround($81)))));
 $182 = $fabsf$i27 < Math_fround(1.1920928955078125E-7);
 $fabsf$i = (Math_fround(Math_abs((Math_fround($82)))));
 $183 = $fabsf$i < Math_fround(1.1920928955078125E-7);
 $184 = (($box) + 12|0);
 $185 = (($box) + 4|0);
 $186 = (($box) + 16|0);
 $187 = (($box) + 8|0);
 $188 = (($box) + 20|0);
 $189 = (($normal) + 4|0);
 $190 = (($normal) + 8|0);
 $191 = (($hit) + 4|0);
 $192 = (($hit) + 8|0);
 if ($181) {
  $MinDist$397$us = $MinDist$253;$col$396$us = $col$252;$i1$094$us = 0;
  while(1) {
   $193 = (($tri) + (($i1$094$us*12)|0)|0);
   $194 = Math_fround(HEAPF32[$193>>2]);
   $195 = Math_fround(HEAPF32[$box>>2]);
   $196 = $194 < $195;
   do {
    if ($196) {
     $MinDist$4$us = $MinDist$397$us;$col$4$us = $col$396$us;
    } else {
     $197 = Math_fround(HEAPF32[$184>>2]);
     $198 = $194 > $197;
     if ($198) {
      $MinDist$4$us = $MinDist$397$us;$col$4$us = $col$396$us;
     } else {
      if ($182) {
       $199 = ((($tri) + (($i1$094$us*12)|0)|0) + 4|0);
       $200 = Math_fround(HEAPF32[$199>>2]);
       $201 = Math_fround(HEAPF32[$185>>2]);
       $202 = $200 < $201;
       if ($202) {
        $MinDist$4$us = $MinDist$397$us;$col$4$us = $col$396$us;
        break;
       }
       $203 = Math_fround(HEAPF32[$186>>2]);
       $204 = $200 > $203;
       if ($204) {
        $MinDist$4$us = $MinDist$397$us;$col$4$us = $col$396$us;
        break;
       }
      }
      if ($183) {
       $205 = ((($tri) + (($i1$094$us*12)|0)|0) + 8|0);
       $206 = Math_fround(HEAPF32[$205>>2]);
       $207 = Math_fround(HEAPF32[$187>>2]);
       $208 = $206 < $207;
       if ($208) {
        $MinDist$4$us = $MinDist$397$us;$col$4$us = $col$396$us;
        break;
       }
       $209 = Math_fround(HEAPF32[$188>>2]);
       $210 = $206 > $209;
       if ($210) {
        $MinDist$4$us = $MinDist$397$us;$col$4$us = $col$396$us;
        break;
       } else {
        $220 = $206;$221 = $207;$224 = $209;
       }
      } else {
       $$pre3$i$us = Math_fround(HEAPF32[$187>>2]);
       $$phi$trans$insert4$i$us = ((($tri) + (($i1$094$us*12)|0)|0) + 8|0);
       $$pre5$i$us = Math_fround(HEAPF32[$$phi$trans$insert4$i$us>>2]);
       $$pre7$i$us = Math_fround(HEAPF32[$188>>2]);
       $220 = $$pre5$i$us;$221 = $$pre3$i$us;$224 = $$pre7$i$us;
      }
      $211 = Math_fround(HEAPF32[$185>>2]);
      $212 = ((($tri) + (($i1$094$us*12)|0)|0) + 4|0);
      $213 = Math_fround(HEAPF32[$212>>2]);
      $214 = Math_fround($211 - $213);
      $215 = Math_fround($214 * $87);
      $216 = Math_fround(HEAPF32[$186>>2]);
      $217 = Math_fround($216 - $213);
      $218 = Math_fround($217 * $87);
      $219 = Math_fround($221 - $220);
      $222 = Math_fround($219 * $90);
      $223 = Math_fround($224 - $220);
      $225 = Math_fround($223 * $90);
      $226 = $215 > $218;
      $t1y$0$i$us = $226 ? $218 : $215;
      $t2y$0$i$us = $226 ? $215 : $218;
      $227 = $222 > $225;
      $$4$i$us = $227 ? $225 : $222;
      $$5$i$us = $227 ? $222 : $225;
      $$6$i$us = $227 ? 5 : 2;
      if ($182) {
       $233 = Math_fround(3.40282346638528859812E+38);$ret$2$i$us = -1;$t1y$0$i49$us = Math_fround(-3.40282346638528859812E+38);
      } else {
       $by$0$i$us = $226 ? 4 : 1;
       $228 = $t1y$0$i$us > Math_fround(-3.40282346638528859812E+38);
       $t1y$0$i48$us = $228 ? $t1y$0$i$us : Math_fround(-3.40282346638528859812E+38);
       $ret$1$i$us = $228 ? $by$0$i$us : -1;
       $229 = $t2y$0$i$us > Math_fround(3.40282346638528859812E+38);
       $230 = $229 ? Math_fround(3.40282346638528859812E+38) : $t2y$0$i$us;
       $233 = $230;$ret$2$i$us = $ret$1$i$us;$t1y$0$i49$us = $t1y$0$i48$us;
      }
      if ($183) {
       $236 = $233;$ret$4$i$us = $ret$2$i$us;$t1y$0$i46$us = $t1y$0$i49$us;
      } else {
       $231 = $$4$i$us > $t1y$0$i49$us;
       $t1y$0$i47$us = $231 ? $$4$i$us : $t1y$0$i49$us;
       $ret$3$i$us = $231 ? $$6$i$us : $ret$2$i$us;
       $232 = $233 < $$5$i$us;
       $234 = $232 ? $233 : $$5$i$us;
       $236 = $234;$ret$4$i$us = $ret$3$i$us;$t1y$0$i46$us = $t1y$0$i47$us;
      }
      $235 = $t1y$0$i46$us > $236;
      $237 = $236 < Math_fround(1.1920928955078125E-7);
      $or$cond$i$us = $235 | $237;
      $$ret$4$i$us = $or$cond$i$us ? -1 : $ret$4$i$us;
      $238 = ($$ret$4$i$us|0)==(-1);
      if ($238) {
       $MinDist$4$us = $MinDist$397$us;$col$4$us = $col$396$us;
      } else {
       $239 = $t1y$0$i46$us < Math_fround(0.0);
       $240 = !($t1y$0$i46$us <= $MinDist$397$us);
       $or$cond3$us = $239 | $240;
       if ($or$cond3$us) {
        $MinDist$4$us = $MinDist$397$us;$col$4$us = $col$396$us;
       } else {
        $241 = (550368 + (($$ret$4$i$us*12)|0)|0);
        $242 = Math_fround(HEAPF32[$241>>2]);
        HEAPF32[$normal>>2] = $242;
        $243 = ((550368 + (($$ret$4$i$us*12)|0)|0) + 4|0);
        $244 = Math_fround(HEAPF32[$243>>2]);
        HEAPF32[$189>>2] = $244;
        $245 = ((550368 + (($$ret$4$i$us*12)|0)|0) + 8|0);
        $246 = Math_fround(HEAPF32[$245>>2]);
        HEAPF32[$190>>2] = $246;
        $247 = Math_fround(HEAPF32[$193>>2]);
        HEAPF32[$hit>>2] = $247;
        $248 = Math_fround(HEAPF32[$212>>2]);
        HEAPF32[$191>>2] = $248;
        $249 = ((($tri) + (($i1$094$us*12)|0)|0) + 8|0);
        $250 = Math_fround(HEAPF32[$249>>2]);
        HEAPF32[$192>>2] = $250;
        $MinDist$4$us = $t1y$0$i46$us;$col$4$us = 1;
       }
      }
     }
    }
   } while(0);
   $251 = (($i1$094$us) + 1)|0;
   $exitcond135 = ($251|0)==(3);
   if ($exitcond135) {
    $MinDist$3$lcssa = $MinDist$4$us;$col$3$lcssa = $col$4$us;
    break;
   } else {
    $MinDist$397$us = $MinDist$4$us;$col$396$us = $col$4$us;$i1$094$us = $251;
   }
  }
 } else {
  $MinDist$397 = $MinDist$253;$col$396 = $col$252;$i1$094 = 0;
  while(1) {
   if ($182) {
    $256 = ((($tri) + (($i1$094*12)|0)|0) + 4|0);
    $257 = Math_fround(HEAPF32[$256>>2]);
    $258 = Math_fround(HEAPF32[$185>>2]);
    $259 = $257 < $258;
    if ($259) {
     $MinDist$4 = $MinDist$397;$col$4 = $col$396;
    } else {
     $260 = Math_fround(HEAPF32[$186>>2]);
     $261 = $257 > $260;
     if ($261) {
      $MinDist$4 = $MinDist$397;$col$4 = $col$396;
     } else {
      label = 36;
     }
    }
   } else {
    label = 36;
   }
   do {
    if ((label|0) == 36) {
     label = 0;
     if ($183) {
      $262 = ((($tri) + (($i1$094*12)|0)|0) + 8|0);
      $263 = Math_fround(HEAPF32[$262>>2]);
      $264 = Math_fround(HEAPF32[$187>>2]);
      $265 = $263 < $264;
      if ($265) {
       $MinDist$4 = $MinDist$397;$col$4 = $col$396;
       break;
      }
      $266 = Math_fround(HEAPF32[$188>>2]);
      $267 = $263 > $266;
      if ($267) {
       $MinDist$4 = $MinDist$397;$col$4 = $col$396;
       break;
      } else {
       $285 = $263;$286 = $264;$289 = $266;
      }
     } else {
      $$pre3$i = Math_fround(HEAPF32[$187>>2]);
      $$phi$trans$insert4$i = ((($tri) + (($i1$094*12)|0)|0) + 8|0);
      $$pre5$i = Math_fround(HEAPF32[$$phi$trans$insert4$i>>2]);
      $$pre7$i = Math_fround(HEAPF32[$188>>2]);
      $285 = $$pre5$i;$286 = $$pre3$i;$289 = $$pre7$i;
     }
     $268 = Math_fround(HEAPF32[$box>>2]);
     $269 = (($tri) + (($i1$094*12)|0)|0);
     $270 = Math_fround(HEAPF32[$269>>2]);
     $271 = Math_fround($268 - $270);
     $272 = Math_fround($271 * $84);
     $273 = Math_fround(HEAPF32[$184>>2]);
     $274 = Math_fround($273 - $270);
     $275 = Math_fround($274 * $84);
     $276 = Math_fround(HEAPF32[$185>>2]);
     $277 = ((($tri) + (($i1$094*12)|0)|0) + 4|0);
     $278 = Math_fround(HEAPF32[$277>>2]);
     $279 = Math_fround($276 - $278);
     $280 = Math_fround($279 * $87);
     $281 = Math_fround(HEAPF32[$186>>2]);
     $282 = Math_fround($281 - $278);
     $283 = Math_fround($282 * $87);
     $284 = Math_fround($286 - $285);
     $287 = Math_fround($284 * $90);
     $288 = Math_fround($289 - $285);
     $290 = Math_fround($288 * $90);
     $291 = $272 > $275;
     $$$i = $291 ? 3 : 0;
     $$2$i = $291 ? $272 : $275;
     $$3$i = $291 ? $275 : $272;
     $292 = $280 > $283;
     $t1y$0$i = $292 ? $283 : $280;
     $t2y$0$i = $292 ? $280 : $283;
     $293 = $287 > $290;
     $$4$i = $293 ? $290 : $287;
     $$5$i = $293 ? $287 : $290;
     $$6$i = $293 ? 5 : 2;
     if ($182) {
      $299 = $$2$i;$ret$2$i = $$$i;$t1y$0$i49 = $$3$i;
     } else {
      $by$0$i = $292 ? 4 : 1;
      $294 = $t1y$0$i > $$3$i;
      $t1y$0$i48 = $294 ? $t1y$0$i : $$3$i;
      $ret$1$i = $294 ? $by$0$i : $$$i;
      $295 = $$2$i < $t2y$0$i;
      $296 = $295 ? $$2$i : $t2y$0$i;
      $299 = $296;$ret$2$i = $ret$1$i;$t1y$0$i49 = $t1y$0$i48;
     }
     if ($183) {
      $302 = $299;$ret$4$i = $ret$2$i;$t1y$0$i46 = $t1y$0$i49;
     } else {
      $297 = $$4$i > $t1y$0$i49;
      $t1y$0$i47 = $297 ? $$4$i : $t1y$0$i49;
      $ret$3$i = $297 ? $$6$i : $ret$2$i;
      $298 = $299 < $$5$i;
      $300 = $298 ? $299 : $$5$i;
      $302 = $300;$ret$4$i = $ret$3$i;$t1y$0$i46 = $t1y$0$i47;
     }
     $301 = $t1y$0$i46 > $302;
     $303 = $302 < Math_fround(1.1920928955078125E-7);
     $or$cond$i = $301 | $303;
     $$ret$4$i = $or$cond$i ? -1 : $ret$4$i;
     $304 = ($$ret$4$i|0)==(-1);
     if ($304) {
      $MinDist$4 = $MinDist$397;$col$4 = $col$396;
     } else {
      $305 = $t1y$0$i46 < Math_fround(0.0);
      $306 = !($t1y$0$i46 <= $MinDist$397);
      $or$cond3 = $305 | $306;
      if ($or$cond3) {
       $MinDist$4 = $MinDist$397;$col$4 = $col$396;
      } else {
       $307 = (550368 + (($$ret$4$i*12)|0)|0);
       $308 = Math_fround(HEAPF32[$307>>2]);
       HEAPF32[$normal>>2] = $308;
       $309 = ((550368 + (($$ret$4$i*12)|0)|0) + 4|0);
       $310 = Math_fround(HEAPF32[$309>>2]);
       HEAPF32[$189>>2] = $310;
       $311 = ((550368 + (($$ret$4$i*12)|0)|0) + 8|0);
       $312 = Math_fround(HEAPF32[$311>>2]);
       HEAPF32[$190>>2] = $312;
       $313 = Math_fround(HEAPF32[$269>>2]);
       HEAPF32[$hit>>2] = $313;
       $314 = Math_fround(HEAPF32[$277>>2]);
       HEAPF32[$191>>2] = $314;
       $315 = ((($tri) + (($i1$094*12)|0)|0) + 8|0);
       $316 = Math_fround(HEAPF32[$315>>2]);
       HEAPF32[$192>>2] = $316;
       $MinDist$4 = $t1y$0$i46;$col$4 = 1;
      }
     }
    }
   } while(0);
   $317 = (($i1$094) + 1)|0;
   $exitcond133 = ($317|0)==(3);
   if ($exitcond133) {
    $MinDist$3$lcssa = $MinDist$4;$col$3$lcssa = $col$4;
    break;
   } else {
    $MinDist$397 = $MinDist$4;$col$396 = $col$4;$i1$094 = $317;
   }
  }
 }
 $252 = (($p1) + 4|0);
 $253 = (($p1) + 8|0);
 $254 = (($ip) + 4|0);
 $255 = (($ip) + 8|0);
 $MinDist$592 = $MinDist$3$lcssa;$col$591 = $col$3$lcssa;$i2$090 = 0;
 while(1) {
  $318 = ((($fatEdges) + (($i2$090*68)|0)|0) + 64|0);
  $319 = HEAP32[$318>>2]|0;
  $320 = ($319|0)<(0);
  L69: do {
   if ($320) {
    $MinDist$8 = $MinDist$592;$col$8 = $col$591;
   } else {
    $321 = ((($fatEdges) + (($i2$090*68)|0)|0) + 16|0);
    $322 = Math_fround(HEAPF32[$321>>2]);
    HEAPF32[$p1>>2] = $322;
    $323 = ((($fatEdges) + (($i2$090*68)|0)|0) + 20|0);
    $324 = Math_fround(HEAPF32[$323>>2]);
    HEAPF32[$252>>2] = $324;
    $325 = ((($fatEdges) + (($i2$090*68)|0)|0) + 24|0);
    $326 = Math_fround(HEAPF32[$325>>2]);
    HEAPF32[$253>>2] = $326;
    $327 = ((($fatEdges) + (($i2$090*68)|0)|0) + 28|0);
    $328 = Math_fround(HEAPF32[$327>>2]);
    $329 = ((($fatEdges) + (($i2$090*68)|0)|0) + 32|0);
    $330 = Math_fround(HEAPF32[$329>>2]);
    $331 = ((($fatEdges) + (($i2$090*68)|0)|0) + 36|0);
    $332 = Math_fround(HEAPF32[$331>>2]);
    $333 = ((($fatEdges) + (($i2$090*68)|0)|0) + 52|0);
    $334 = ((($fatEdges) + (($i2$090*68)|0)|0) + 56|0);
    $335 = ((($fatEdges) + (($i2$090*68)|0)|0) + 60|0);
    $336 = (($fatEdges) + (($i2$090*68)|0)|0);
    $337 = ((($fatEdges) + (($i2$090*68)|0)|0) + 4|0);
    $338 = ((($fatEdges) + (($i2$090*68)|0)|0) + 8|0);
    $339 = ((($fatEdges) + (($i2$090*68)|0)|0) + 12|0);
    $340 = ((($fatEdges) + (($i2$090*68)|0)|0) + 44|0);
    $341 = ((($fatEdges) + (($i2$090*68)|0)|0) + 48|0);
    $$pre = HEAP32[$333>>2]|0;
    $$pre136 = HEAP32[$334>>2]|0;
    $MinDist$6$ph$ph89 = $MinDist$592;$col$6$ph$ph88 = $col$591;$j$0$ph$ph87 = 0;
    while(1) {
     $342 = Math_fround(HEAPF32[$335>>2]);
     $343 = Math_fround(HEAPF32[$336>>2]);
     $344 = Math_fround(HEAPF32[$337>>2]);
     $345 = Math_fround(HEAPF32[$338>>2]);
     $346 = Math_fround(HEAPF32[$339>>2]);
     $j$069 = $j$0$ph$ph87;
     while(1) {
      $347 = (($j$069) + 1)|0;
      $348 = ($347|0)==(3);
      $$ = $348 ? 0 : $347;
      $$idx21 = (($tri) + (($j$069*12)|0)|0);
      $$idx21$val = Math_fround(HEAPF32[$$idx21>>2]);
      $$idx22 = ((($tri) + (($j$069*12)|0)|0) + 4|0);
      $$idx22$val = Math_fround(HEAPF32[$$idx22>>2]);
      $$idx23 = ((($tri) + (($j$069*12)|0)|0) + 8|0);
      $$idx23$val = Math_fround(HEAPF32[$$idx23>>2]);
      $$idx24 = (($tri) + (($$*12)|0)|0);
      $$idx24$val = Math_fround(HEAPF32[$$idx24>>2]);
      $$idx25 = ((($tri) + (($$*12)|0)|0) + 4|0);
      $$idx25$val = Math_fround(HEAPF32[$$idx25>>2]);
      $$idx26 = ((($tri) + (($$*12)|0)|0) + 8|0);
      $$idx26$val = Math_fround(HEAPF32[$$idx26>>2]);
      $349 = Math_fround($$idx21$val * $343);
      $350 = Math_fround($$idx22$val * $344);
      $351 = Math_fround($349 + $350);
      $352 = Math_fround($$idx23$val * $345);
      $353 = Math_fround($351 + $352);
      $354 = Math_fround($346 + $353);
      $355 = Math_fround($$idx24$val * $343);
      $356 = Math_fround($$idx25$val * $344);
      $357 = Math_fround($355 + $356);
      $358 = Math_fround($$idx26$val * $345);
      $359 = Math_fround($357 + $358);
      $360 = Math_fround($346 + $359);
      $361 = Math_fround($354 * $360);
      $362 = $361 > Math_fround(0.0);
      if (!($362)) {
       $364 = Math_fround($$idx24$val - $$idx21$val);
       $365 = Math_fround($$idx25$val - $$idx22$val);
       $366 = Math_fround($$idx26$val - $$idx23$val);
       $367 = Math_fround($364 * $343);
       $368 = Math_fround($365 * $344);
       $369 = Math_fround($367 + $368);
       $370 = Math_fround($366 * $345);
       $371 = Math_fround($369 + $370);
       $372 = $371 == Math_fround(0.0);
       if (!($372)) {
        $373 = Math_fround($354 / $371);
        $374 = Math_fround($364 * $373);
        $375 = Math_fround($365 * $373);
        $376 = Math_fround($366 * $373);
        $377 = Math_fround($$idx21$val - $374);
        $378 = Math_fround($$idx22$val - $375);
        $379 = Math_fround($$idx23$val - $376);
        HEAPF32[$ip>>2] = $377;
        HEAPF32[$254>>2] = $378;
        HEAPF32[$255>>2] = $379;
        $380 = ((($fatEdges) + (($i2$090*68)|0)|0) + 40|0);
        $381 = (($380) + ($$pre<<2)|0);
        $382 = Math_fround(HEAPF32[$381>>2]);
        $383 = (($ip) + ($$pre136<<2)|0);
        $384 = Math_fround(HEAPF32[$383>>2]);
        $385 = (($p1) + ($$pre136<<2)|0);
        $386 = Math_fround(HEAPF32[$385>>2]);
        $387 = Math_fround($384 - $386);
        $388 = Math_fround($382 * $387);
        $389 = (($380) + ($$pre136<<2)|0);
        $390 = Math_fround(HEAPF32[$389>>2]);
        $391 = (($ip) + ($$pre<<2)|0);
        $392 = Math_fround(HEAPF32[$391>>2]);
        $393 = (($p1) + ($$pre<<2)|0);
        $394 = Math_fround(HEAPF32[$393>>2]);
        $395 = Math_fround($392 - $394);
        $396 = Math_fround($390 * $395);
        $397 = Math_fround($388 - $396);
        $398 = Math_fround($342 * $397);
        $399 = $398 < Math_fround(0.0);
        if (!($399)) {
         $dir$idx$val$i = Math_fround(HEAPF32[$motion>>2]);
         $dir$idx1$val$i = Math_fround(HEAPF32[$34>>2]);
         $dir$idx2$val$i = Math_fround(HEAPF32[$38>>2]);
         $400 = Math_fround($398 * $dir$idx$val$i);
         $401 = Math_fround($398 * $dir$idx1$val$i);
         $402 = Math_fround($398 * $dir$idx2$val$i);
         $403 = Math_fround($377 - $400);
         HEAPF32[$ip>>2] = $403;
         $404 = Math_fround($378 - $401);
         HEAPF32[$254>>2] = $404;
         $405 = Math_fround($379 - $402);
         HEAPF32[$255>>2] = $405;
         $406 = Math_fround($322 - $403);
         $407 = Math_fround($328 - $403);
         $408 = Math_fround($407 * $406);
         $409 = Math_fround($324 - $404);
         $410 = Math_fround($330 - $404);
         $411 = Math_fround($410 * $409);
         $412 = Math_fround($408 + $411);
         $413 = Math_fround($326 - $405);
         $414 = Math_fround($332 - $405);
         $415 = Math_fround($414 * $413);
         $416 = Math_fround($412 + $415);
         $$not = !($416 < Math_fround(0.0));
         $417 = !($398 <= $MinDist$6$ph$ph89);
         $or$cond5 = $$not | $417;
         if (!($or$cond5)) {
          break;
         }
        }
        $418 = ($347>>>0)<(3);
        if ($418) {
         $j$069 = $347;
         continue;
        } else {
         $MinDist$8 = $MinDist$6$ph$ph89;$col$8 = $col$6$ph$ph88;
         break L69;
        }
       }
      }
      $363 = ($347>>>0)<(3);
      if ($363) {
       $j$069 = $347;
      } else {
       $MinDist$8 = $MinDist$6$ph$ph89;$col$8 = $col$6$ph$ph88;
       break L69;
      }
     }
     $419 = Math_fround($$idx21$val - $$idx24$val);
     $420 = Math_fround($$idx22$val - $$idx25$val);
     $421 = Math_fround($$idx23$val - $$idx26$val);
     $422 = Math_fround(HEAPF32[$340>>2]);
     $423 = Math_fround($422 * $421);
     $424 = Math_fround(HEAPF32[$341>>2]);
     $425 = Math_fround($420 * $424);
     $426 = Math_fround($423 - $425);
     $427 = Math_fround($419 * $424);
     $428 = Math_fround(HEAPF32[$380>>2]);
     $429 = Math_fround($421 * $428);
     $430 = Math_fround($427 - $429);
     $431 = Math_fround($420 * $428);
     $432 = Math_fround($419 * $422);
     $433 = Math_fround($431 - $432);
     HEAPF32[$normal>>2] = $426;
     HEAPF32[$189>>2] = $430;
     HEAPF32[$190>>2] = $433;
     $434 = Math_fround(HEAPF32[$motion>>2]);
     $435 = Math_fround($398 * $434);
     $436 = Math_fround(HEAPF32[$34>>2]);
     $437 = Math_fround($398 * $436);
     $438 = Math_fround(HEAPF32[$38>>2]);
     $439 = Math_fround($398 * $438);
     $440 = Math_fround($435 + $403);
     $441 = Math_fround($437 + $404);
     $442 = Math_fround($439 + $405);
     HEAPF32[$hit>>2] = $440;
     HEAPF32[$191>>2] = $441;
     HEAPF32[$192>>2] = $442;
     $443 = ($347>>>0)<(3);
     if ($443) {
      $MinDist$6$ph$ph89 = $398;$col$6$ph$ph88 = 2;$j$0$ph$ph87 = $347;
     } else {
      $MinDist$8 = $398;$col$8 = 2;
      break;
     }
    }
   }
  } while(0);
  $444 = (($i2$090) + 1)|0;
  $exitcond = ($444|0)==(12);
  if ($exitcond) {
   break;
  } else {
   $MinDist$592 = $MinDist$8;$col$591 = $col$8;$i2$090 = $444;
  }
 }
 $445 = ($col$8|0)==(-1);
 if ($445) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 HEAPF32[$d>>2] = $MinDist$8;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx2Gu23triBoxSweepTestBoxSpaceERKNS_10PxTriangleERKNS_6PxVec3ES6_S6_fRfb($tri,$extents,$dir,$oneOverDir,$tmax,$toi,$isDoubleSided) {
 $tri = $tri|0;
 $extents = $extents|0;
 $dir = $dir|0;
 $oneOverDir = $oneOverDir|0;
 $tmax = Math_fround($tmax);
 $toi = $toi|0;
 $isDoubleSided = $isDoubleSided|0;
 var $$$i = 0, $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert1 = 0, $$pre = Math_fround(0), $$pre$i = Math_fround(0), $$pre2 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0;
 var $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0);
 var $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0);
 var $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0);
 var $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0);
 var $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0);
 var $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0);
 var $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $bValidMTD$i = 0, $extents$idx$val$i = Math_fround(0), $extents$idx1$val$i = Math_fround(0), $extents$idx10$val$i = Math_fround(0), $extents$idx11$val$i = Math_fround(0), $extents$idx12$val$i = Math_fround(0), $extents$idx15$val$i = Math_fround(0), $extents$idx16$i = 0, $extents$idx16$val$i = Math_fround(0), $extents$idx17$i = 0, $extents$idx17$val$i = Math_fround(0), $extents$idx2$val$i = Math_fround(0), $extents$idx5$val$i = Math_fround(0), $extents$idx6$val$i = Math_fround(0);
 var $extents$idx7$val$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i20$i = Math_fround(0), $fabsf$i$i23$i = Math_fround(0), $i$029$i = 0, $storemerge$i = Math_fround(0), $tfirst$i = 0, $tlast$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $bValidMTD$i = sp + 8|0;
 $tfirst$i = sp;
 $tlast$i = sp + 4|0;
 $0 = (($tri) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$tri>>2]);
 $3 = Math_fround($1 - $2);
 $4 = (($tri) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($tri) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($tri) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($tri) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = (($tri) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 - $2);
 $17 = (($tri) + 28|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 - $7);
 $20 = (($tri) + 32|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 - $12);
 $23 = Math_fround($8 * $22);
 $24 = Math_fround($13 * $19);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($13 * $16);
 $27 = Math_fround($3 * $22);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($3 * $19);
 $30 = Math_fround($8 * $16);
 $31 = Math_fround($29 - $30);
 if (!($isDoubleSided)) {
  $32 = Math_fround(HEAPF32[$dir>>2]);
  $33 = Math_fround($25 * $32);
  $34 = (($dir) + 4|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($28 * $35);
  $37 = Math_fround($33 + $36);
  $38 = (($dir) + 8|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($31 * $39);
  $41 = Math_fround($37 + $40);
  $42 = !($41 >= Math_fround(0.0));
  if (!($42)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP8[$bValidMTD$i>>0] = 1;
 HEAPF32[$toi>>2] = $tmax;
 HEAPF32[$tfirst$i>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[$tlast$i>>2] = Math_fround(3.40282346638528859812E+38);
 $extents$idx15$val$i = Math_fround(HEAPF32[$extents>>2]);
 $extents$idx16$i = (($extents) + 4|0);
 $extents$idx16$val$i = Math_fround(HEAPF32[$extents$idx16$i>>2]);
 $extents$idx17$i = (($extents) + 8|0);
 $extents$idx17$val$i = Math_fround(HEAPF32[$extents$idx17$i>>2]);
 $43 = (__ZL8testAxisRKN5physx10PxTriangleERKNS_6PxVec3ES5_S5_RbRfS7_($tri,$extents$idx15$val$i,$extents$idx16$val$i,$extents$idx17$val$i,$dir,$25,$28,$31,$bValidMTD$i,$tfirst$i,$tlast$i)|0);
 $44 = ($43|0)==(0);
 if ($44) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = Math_fround(HEAPF32[$oneOverDir>>2]);
 $46 = Math_fround(HEAPF32[$tri>>2]);
 $47 = Math_fround(HEAPF32[$0>>2]);
 $48 = Math_fround(HEAPF32[$14>>2]);
 $49 = $46 < $47;
 $50 = $49 ? $46 : $47;
 $51 = $46 > $47;
 $52 = $51 ? $46 : $47;
 $53 = $50 < $48;
 $54 = $53 ? $50 : $48;
 $55 = $52 > $48;
 $56 = $55 ? $52 : $48;
 $57 = Math_fround(HEAPF32[$extents>>2]);
 $58 = Math_fround(-$57);
 $59 = Math_fround($58 - $56);
 $60 = Math_fround($57 - $54);
 $61 = !($59 <= Math_fround(0.0));
 if ($61) {
  $64 = 0;
 } else {
  $62 = $60 >= Math_fround(0.0);
  $64 = $62;
 }
 $63 = $64&1;
 $65 = HEAP8[$bValidMTD$i>>0]|0;
 $66 = $65&255;
 $67 = $66 & $63;
 $68 = $67&255;
 HEAP8[$bValidMTD$i>>0] = $68;
 $69 = Math_fround(HEAPF32[$dir>>2]);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($69)))));
 $70 = $fabsf$i$i$i < Math_fround(9.99999997475242707878E-7);
 do {
  if ($70) {
   if (!($64)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $71 = Math_fround($45 * Math_fround(-1.0));
   $72 = Math_fround($71 * $59);
   $73 = Math_fround($71 * $60);
   $74 = $72 < $73;
   $75 = $74 ? $72 : $73;
   $76 = $72 > $73;
   $77 = $76 ? $72 : $73;
   $78 = Math_fround(HEAPF32[$tlast$i>>2]);
   $79 = $75 > $78;
   if ($79) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $80 = Math_fround(HEAPF32[$tfirst$i>>2]);
   $81 = $77 < $80;
   if ($81) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $82 = $77 < $78;
    $83 = $82 ? $77 : $78;
    HEAPF32[$tlast$i>>2] = $83;
    $84 = $75 > $80;
    $85 = $84 ? $75 : $80;
    HEAPF32[$tfirst$i>>2] = $85;
    break;
   }
  }
 } while(0);
 $86 = (($oneOverDir) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($tri) + 4|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($0) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($14) + 4|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = $89 < $91;
 $95 = $94 ? $89 : $91;
 $96 = $89 > $91;
 $97 = $96 ? $89 : $91;
 $98 = $95 < $93;
 $99 = $98 ? $95 : $93;
 $100 = $97 > $93;
 $101 = $100 ? $97 : $93;
 $102 = (($extents) + 4|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround(-$103);
 $105 = Math_fround($104 - $101);
 $106 = Math_fround($103 - $99);
 $107 = !($105 <= Math_fround(0.0));
 if ($107) {
  $110 = 0;
 } else {
  $108 = $106 >= Math_fround(0.0);
  $110 = $108;
 }
 $109 = $110&1;
 $111 = $109 & $67;
 $112 = $111&255;
 HEAP8[$bValidMTD$i>>0] = $112;
 $113 = (($dir) + 4|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $fabsf$i$i20$i = (Math_fround(Math_abs((Math_fround($114)))));
 $115 = $fabsf$i$i20$i < Math_fround(9.99999997475242707878E-7);
 do {
  if ($115) {
   if (!($110)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $116 = Math_fround($87 * Math_fround(-1.0));
   $117 = Math_fround($116 * $105);
   $118 = Math_fround($116 * $106);
   $119 = $117 < $118;
   $120 = $119 ? $117 : $118;
   $121 = $117 > $118;
   $122 = $121 ? $117 : $118;
   $123 = Math_fround(HEAPF32[$tlast$i>>2]);
   $124 = $120 > $123;
   if ($124) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $125 = Math_fround(HEAPF32[$tfirst$i>>2]);
   $126 = $122 < $125;
   if ($126) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $127 = $122 < $123;
    $128 = $127 ? $122 : $123;
    HEAPF32[$tlast$i>>2] = $128;
    $129 = $120 > $125;
    $130 = $129 ? $120 : $125;
    HEAPF32[$tfirst$i>>2] = $130;
    break;
   }
  }
 } while(0);
 $131 = (($oneOverDir) + 8|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($tri) + 8|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($0) + 8|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($14) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = $134 < $136;
 $140 = $139 ? $134 : $136;
 $141 = $134 > $136;
 $142 = $141 ? $134 : $136;
 $143 = $140 < $138;
 $144 = $143 ? $140 : $138;
 $145 = $142 > $138;
 $146 = $145 ? $142 : $138;
 $147 = (($extents) + 8|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = Math_fround(-$148);
 $150 = Math_fround($149 - $146);
 $151 = Math_fround($148 - $144);
 $152 = !($150 <= Math_fround(0.0));
 if ($152) {
  $155 = 0;
 } else {
  $153 = $151 >= Math_fround(0.0);
  $155 = $153;
 }
 $154 = $155&1;
 $156 = $154 & $111;
 $157 = $156&255;
 HEAP8[$bValidMTD$i>>0] = $157;
 $158 = (($dir) + 8|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $fabsf$i$i23$i = (Math_fround(Math_abs((Math_fround($159)))));
 $160 = $fabsf$i$i23$i < Math_fround(9.99999997475242707878E-7);
 do {
  if ($160) {
   if ($155) {
    $181 = $46;$185 = $89;$189 = $134;$i$029$i = 0;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $161 = Math_fround($132 * Math_fround(-1.0));
   $162 = Math_fround($161 * $150);
   $163 = Math_fround($161 * $151);
   $164 = $162 < $163;
   $165 = $164 ? $162 : $163;
   $166 = $162 > $163;
   $167 = $166 ? $162 : $163;
   $168 = Math_fround(HEAPF32[$tlast$i>>2]);
   $169 = $165 > $168;
   if ($169) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $170 = Math_fround(HEAPF32[$tfirst$i>>2]);
   $171 = $167 < $170;
   if ($171) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $172 = $167 < $168;
    $173 = $172 ? $167 : $168;
    HEAPF32[$tlast$i>>2] = $173;
    $174 = $165 > $170;
    $175 = $174 ? $165 : $170;
    HEAPF32[$tfirst$i>>2] = $175;
    $181 = $46;$185 = $89;$189 = $134;$i$029$i = 0;
    break;
   }
  }
 } while(0);
 while(1) {
  $176 = (($i$029$i) + 1)|0;
  $177 = ($i$029$i>>>0)>(1);
  $$$i = $177 ? 0 : $176;
  $178 = (($tri) + (($$$i*12)|0)|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = Math_fround($179 - $181);
  $182 = ((($tri) + (($$$i*12)|0)|0) + 4|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = Math_fround($183 - $185);
  $186 = ((($tri) + (($$$i*12)|0)|0) + 8|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = Math_fround($187 - $189);
  $190 = Math_fround($188 * $188);
  $191 = Math_fround($190 + Math_fround(0.0));
  $192 = Math_fround($184 * $184);
  $193 = Math_fround($192 + $191);
  $194 = !($193 >= Math_fround(9.99999997475242707878E-7));
  if (!($194)) {
   $195 = Math_fround(-$188);
   $extents$idx10$val$i = Math_fround(HEAPF32[$extents>>2]);
   $extents$idx11$val$i = Math_fround(HEAPF32[$extents$idx16$i>>2]);
   $extents$idx12$val$i = Math_fround(HEAPF32[$extents$idx17$i>>2]);
   $196 = (__ZL8testAxisRKN5physx10PxTriangleERKNS_6PxVec3ES5_S5_RbRfS7_($tri,$extents$idx10$val$i,$extents$idx11$val$i,$extents$idx12$val$i,$dir,Math_fround(0.0),$195,$184,$bValidMTD$i,$tfirst$i,$tlast$i)|0);
   $197 = ($196|0)==(0);
   if ($197) {
    $$0 = 0;
    label = 38;
    break;
   }
  }
  $198 = Math_fround($180 * $180);
  $199 = Math_fround($198 + $191);
  $200 = !($199 >= Math_fround(9.99999997475242707878E-7));
  if (!($200)) {
   $201 = Math_fround(-$180);
   $extents$idx5$val$i = Math_fround(HEAPF32[$extents>>2]);
   $extents$idx6$val$i = Math_fround(HEAPF32[$extents$idx16$i>>2]);
   $extents$idx7$val$i = Math_fround(HEAPF32[$extents$idx17$i>>2]);
   $202 = (__ZL8testAxisRKN5physx10PxTriangleERKNS_6PxVec3ES5_S5_RbRfS7_($tri,$extents$idx5$val$i,$extents$idx6$val$i,$extents$idx7$val$i,$dir,$188,Math_fround(0.0),$201,$bValidMTD$i,$tfirst$i,$tlast$i)|0);
   $203 = ($202|0)==(0);
   if ($203) {
    $$0 = 0;
    label = 38;
    break;
   }
  }
  $204 = Math_fround($198 + $192);
  $205 = Math_fround($204 + Math_fround(0.0));
  $206 = !($205 >= Math_fround(9.99999997475242707878E-7));
  if (!($206)) {
   $207 = Math_fround(-$184);
   $extents$idx$val$i = Math_fround(HEAPF32[$extents>>2]);
   $extents$idx1$val$i = Math_fround(HEAPF32[$extents$idx16$i>>2]);
   $extents$idx2$val$i = Math_fround(HEAPF32[$extents$idx17$i>>2]);
   $208 = (__ZL8testAxisRKN5physx10PxTriangleERKNS_6PxVec3ES5_S5_RbRfS7_($tri,$extents$idx$val$i,$extents$idx1$val$i,$extents$idx2$val$i,$dir,$207,$180,Math_fround(0.0),$bValidMTD$i,$tfirst$i,$tlast$i)|0);
   $209 = ($208|0)==(0);
   if ($209) {
    $$0 = 0;
    label = 38;
    break;
   }
  }
  $210 = ($176>>>0)<(3);
  if (!($210)) {
   label = 33;
   break;
  }
  $$phi$trans$insert$i = (($tri) + (($176*12)|0)|0);
  $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
  $$phi$trans$insert = ((($tri) + (($176*12)|0)|0) + 4|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$phi$trans$insert1 = ((($tri) + (($176*12)|0)|0) + 8|0);
  $$pre2 = Math_fround(HEAPF32[$$phi$trans$insert1>>2]);
  $181 = $$pre$i;$185 = $$pre;$189 = $$pre2;$i$029$i = $176;
 }
 if ((label|0) == 33) {
  $211 = Math_fround(HEAPF32[$tfirst$i>>2]);
  $212 = $211 > $tmax;
  if ($212) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $213 = Math_fround(HEAPF32[$tlast$i>>2]);
  $214 = $213 < Math_fround(0.0);
  if ($214) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $215 = !($211 <= Math_fround(0.0));
  if ($215) {
   $storemerge$i = $211;
  } else {
   $216 = HEAP8[$bValidMTD$i>>0]|0;
   $217 = ($216<<24>>24)==(0);
   if ($217) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $storemerge$i = Math_fround(0.0);
   }
  }
  HEAPF32[$toi>>2] = $storemerge$i;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 38) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL8testAxisRKN5physx10PxTriangleERKNS_6PxVec3ES5_S5_RbRfS7_($tri,$extents$0$0$val,$extents$0$1$val,$extents$0$2$val,$dir,$axis$0$0$val,$axis$0$1$val,$axis$0$2$val,$bValidMTD,$tfirst,$tlast) {
 $tri = $tri|0;
 $extents$0$0$val = Math_fround($extents$0$0$val);
 $extents$0$1$val = Math_fround($extents$0$1$val);
 $extents$0$2$val = Math_fround($extents$0$2$val);
 $dir = $dir|0;
 $axis$0$0$val = Math_fround($axis$0$0$val);
 $axis$0$1$val = Math_fround($axis$0$1$val);
 $axis$0$2$val = Math_fround($axis$0$2$val);
 $bValidMTD = $bValidMTD|0;
 $tfirst = $tfirst|0;
 $tlast = $tlast|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $9 = Math_fround(0), $fabsf$i = Math_fround(0), $fabsf$i1 = Math_fround(0), $fabsf$i2 = Math_fround(0), $fabsf$i3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$tri>>2]);
 $1 = Math_fround($0 * $axis$0$0$val);
 $2 = (($tri) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $axis$0$1$val);
 $5 = Math_fround($1 + $4);
 $6 = (($tri) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $axis$0$2$val);
 $9 = Math_fround($5 + $8);
 $10 = (($tri) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $axis$0$0$val);
 $13 = (($tri) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $axis$0$1$val);
 $16 = Math_fround($12 + $15);
 $17 = (($tri) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * $axis$0$2$val);
 $20 = Math_fround($16 + $19);
 $21 = (($tri) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $axis$0$0$val);
 $24 = (($tri) + 28|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $axis$0$1$val);
 $27 = Math_fround($23 + $26);
 $28 = (($tri) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $axis$0$2$val);
 $31 = Math_fround($27 + $30);
 $32 = $9 < $20;
 $33 = $32 ? $9 : $20;
 $34 = $9 > $20;
 $35 = $34 ? $9 : $20;
 $36 = $33 < $31;
 $37 = $36 ? $33 : $31;
 $38 = $35 > $31;
 $39 = $38 ? $35 : $31;
 $fabsf$i3 = (Math_fround(Math_abs((Math_fround($axis$0$0$val)))));
 $40 = Math_fround($fabsf$i3 * $extents$0$0$val);
 $fabsf$i2 = (Math_fround(Math_abs((Math_fround($axis$0$1$val)))));
 $41 = Math_fround($fabsf$i2 * $extents$0$1$val);
 $42 = Math_fround($40 + $41);
 $fabsf$i1 = (Math_fround(Math_abs((Math_fround($axis$0$2$val)))));
 $43 = Math_fround($fabsf$i1 * $extents$0$2$val);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround(-$44);
 $46 = Math_fround($45 - $39);
 $47 = Math_fround($44 - $37);
 $48 = !($46 <= Math_fround(0.0));
 if ($48) {
  $51 = 0;
 } else {
  $49 = $47 >= Math_fround(0.0);
  $51 = $49;
 }
 $50 = $51&1;
 $52 = HEAP8[$bValidMTD>>0]|0;
 $53 = $52&255;
 $54 = $53 & $50;
 $55 = $54&255;
 HEAP8[$bValidMTD>>0] = $55;
 $56 = Math_fround(HEAPF32[$dir>>2]);
 $57 = Math_fround($56 * $axis$0$0$val);
 $58 = (($dir) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 * $axis$0$1$val);
 $61 = Math_fround($57 + $60);
 $62 = (($dir) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $axis$0$2$val);
 $65 = Math_fround($61 + $64);
 $fabsf$i = (Math_fround(Math_abs((Math_fround($65)))));
 $66 = $fabsf$i < Math_fround(9.99999997475242707878E-7);
 if ($66) {
  $$0 = $50;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = Math_fround(Math_fround(-1.0) / $65);
 $68 = Math_fround($46 * $67);
 $69 = Math_fround($47 * $67);
 $70 = $68 < $69;
 $71 = $70 ? $68 : $69;
 $72 = $68 > $69;
 $73 = $72 ? $68 : $69;
 $74 = Math_fround(HEAPF32[$tlast>>2]);
 $75 = $71 > $74;
 if ($75) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $76 = Math_fround(HEAPF32[$tfirst>>2]);
 $77 = $73 < $76;
 if ($77) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = $73 < $74;
 $79 = $78 ? $73 : $74;
 HEAPF32[$tlast>>2] = $79;
 $80 = Math_fround(HEAPF32[$tfirst>>2]);
 $81 = $71 > $80;
 $82 = $81 ? $71 : $80;
 HEAPF32[$tfirst>>2] = $82;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15sweepCapsuleBoxERKNS0_7CapsuleERKNS_11PxTransformERKNS_6PxVec3ES9_fRS7_RfSA_NS_7PxFlagsINS_9PxHitFlag4EnumEtEE($capsule,$boxWorldPose,$boxDim,$dir,$length,$hit,$min_dist,$normal,$hintFlags) {
 $capsule = $capsule|0;
 $boxWorldPose = $boxWorldPose|0;
 $boxDim = $boxDim|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $hit = $hit|0;
 $min_dist = $min_dist|0;
 $normal = $normal|0;
 $hintFlags = $hintFlags|0;
 var $$0 = 0, $$014$i$i = 0, $$023$i$i = 0, $$13$i$i = 0, $$2$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0);
 var $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0;
 var $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0);
 var $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0;
 var $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0);
 var $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = Math_fround(0);
 var $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0);
 var $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0);
 var $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = 0;
 var $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0);
 var $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = 0, $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0);
 var $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0);
 var $580 = 0, $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = 0, $594 = 0, $595 = 0, $596 = Math_fround(0), $597 = 0, $598 = Math_fround(0);
 var $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = 0, $601 = Math_fround(0), $602 = 0, $603 = 0, $604 = Math_fround(0), $605 = 0, $606 = 0, $607 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $MinDist$0 = Math_fround(0), $Status$0$off0 = 0, $aabb = 0, $boxTris$i = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond8$i = 0;
 var $fakeIDs$i = 0, $i$01$i$i = 0, $i$07$i = 0, $i$07$us$i = 0, $md = 0, $n = 0, $p$i = 0, $trash = 0, $triangles = 0, $unused = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 992|0;
 $boxTris$i = sp + 24|0;
 $p$i = sp + 880|0;
 $fakeIDs$i = sp + 544|0;
 $0 = sp + 504|0;
 $aabb = sp + 480|0;
 $triangles = sp + 456|0;
 $1 = sp + 978|0;
 $n = sp + 8|0;
 $md = sp + 4|0;
 $trash = sp;
 $unused = sp + 976|0;
 $2 = sp + 464|0;
 $3 = HEAP16[$hintFlags>>1]|0;
 $4 = $3 & 16;
 $5 = ($4<<16>>16)==(0);
 if ($5) {
  $6 = (($capsule) + 12|0);
  $7 = (($boxWorldPose) + 16|0);
  $8 = Math_fround(HEAPF32[$boxWorldPose>>2]);
  $9 = (($boxWorldPose) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($boxWorldPose) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($boxWorldPose) + 12|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($8 + $8);
  $16 = Math_fround($10 + $10);
  $17 = Math_fround($12 + $12);
  $18 = Math_fround($8 * $15);
  $19 = Math_fround($10 * $16);
  $20 = Math_fround($12 * $17);
  $21 = Math_fround($15 * $10);
  $22 = Math_fround($15 * $12);
  $23 = Math_fround($15 * $14);
  $24 = Math_fround($16 * $12);
  $25 = Math_fround($16 * $14);
  $26 = Math_fround($17 * $14);
  $27 = Math_fround(Math_fround(1.0) - $19);
  $28 = Math_fround($27 - $20);
  $29 = Math_fround($21 + $26);
  $30 = Math_fround($22 - $25);
  HEAPF32[$0>>2] = $28;
  $31 = (($0) + 4|0);
  HEAPF32[$31>>2] = $29;
  $32 = (($0) + 8|0);
  HEAPF32[$32>>2] = $30;
  $33 = Math_fround($21 - $26);
  $34 = Math_fround(Math_fround(1.0) - $18);
  $35 = Math_fround($34 - $20);
  $36 = Math_fround($24 + $23);
  $37 = (($0) + 12|0);
  HEAPF32[$37>>2] = $33;
  $38 = (($0) + 16|0);
  HEAPF32[$38>>2] = $35;
  $39 = (($0) + 20|0);
  HEAPF32[$39>>2] = $36;
  $40 = Math_fround($22 + $25);
  $41 = Math_fround($24 - $23);
  $42 = Math_fround($34 - $19);
  $43 = (($0) + 24|0);
  HEAPF32[$43>>2] = $40;
  $44 = (($0) + 28|0);
  HEAPF32[$44>>2] = $41;
  $45 = (($0) + 32|0);
  HEAPF32[$45>>2] = $42;
  $46 = (Math_fround(__ZN5physx2Gu25distanceSegmentBoxSquaredERKNS_6PxVec3ES3_S3_S3_RKNS_7PxMat33EPfPS1_($capsule,$6,$7,$boxDim,$0,0,0)));
  $47 = (($capsule) + 24|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($48 * $48);
  $50 = $46 < $49;
  if ($50) {
   HEAPF32[$min_dist>>2] = Math_fround(0.0);
   $51 = Math_fround(HEAPF32[$dir>>2]);
   $52 = Math_fround(-$51);
   $53 = (($dir) + 4|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = Math_fround(-$54);
   $56 = (($dir) + 8|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround(-$57);
   HEAPF32[$normal>>2] = $52;
   $59 = (($normal) + 4|0);
   HEAPF32[$59>>2] = $55;
   $60 = (($normal) + 8|0);
   HEAPF32[$60>>2] = $58;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $61 = (($capsule) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround(HEAPF32[$capsule>>2]);
 $64 = Math_fround($62 - $63);
 $65 = (($capsule) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($capsule) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($66 - $68);
 $70 = (($capsule) + 20|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($capsule) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($71 - $73);
 $75 = Math_fround($64 * Math_fround(0.5));
 $76 = Math_fround($69 * Math_fround(0.5));
 $77 = Math_fround($74 * Math_fround(0.5));
 $78 = Math_fround(HEAPF32[$boxDim>>2]);
 $79 = Math_fround(-$78);
 $80 = (($boxDim) + 4|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround(-$81);
 $83 = (($boxDim) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround(-$84);
 HEAPF32[$aabb>>2] = $79;
 $86 = (($aabb) + 4|0);
 HEAPF32[$86>>2] = $82;
 $87 = (($aabb) + 8|0);
 HEAPF32[$87>>2] = $85;
 $88 = (($aabb) + 12|0);
 HEAPF32[$88>>2] = $78;
 $89 = (($aabb) + 16|0);
 HEAPF32[$89>>2] = $81;
 $90 = (($aabb) + 20|0);
 HEAPF32[$90>>2] = $84;
 $91 = (($triangles) + 4|0);
 HEAP8[$91>>0] = 1;
 $92 = (__ZN5physx6shdfnd13TempAllocator8allocateEjPKci($1,3024,550536,230)|0);
 HEAP32[$triangles>>2] = $92;
 __ZN5physx2Gu16computeBoxPointsERKNS_9PxBounds3EPNS_6PxVec3E($aabb,$p$i);
 $93 = ($boxWorldPose|0)==(0|0);
 if ($93) {
  $i$07$us$i = 0;
  while(1) {
   $109 = ($i$07$us$i*3)|0;
   $110 = (550632 + ($109)|0);
   $111 = HEAP8[$110>>0]|0;
   $112 = (($109) + 1)|0;
   $113 = (550632 + ($112)|0);
   $114 = HEAP8[$113>>0]|0;
   $115 = (($109) + 2)|0;
   $116 = (550632 + ($115)|0);
   $117 = HEAP8[$116>>0]|0;
   $118 = $111&255;
   $119 = (($p$i) + (($118*12)|0)|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = ((($p$i) + (($118*12)|0)|0) + 4|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = ((($p$i) + (($118*12)|0)|0) + 8|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = $114&255;
   $126 = (($p$i) + (($125*12)|0)|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = ((($p$i) + (($125*12)|0)|0) + 4|0);
   $129 = Math_fround(HEAPF32[$128>>2]);
   $130 = ((($p$i) + (($125*12)|0)|0) + 8|0);
   $131 = Math_fround(HEAPF32[$130>>2]);
   $132 = $117&255;
   $133 = (($p$i) + (($132*12)|0)|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = ((($p$i) + (($132*12)|0)|0) + 4|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = ((($p$i) + (($132*12)|0)|0) + 8|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   $139 = (($boxTris$i) + (($i$07$us$i*36)|0)|0);
   HEAPF32[$139>>2] = $120;
   $140 = ((($boxTris$i) + (($i$07$us$i*36)|0)|0) + 4|0);
   HEAPF32[$140>>2] = $122;
   $141 = ((($boxTris$i) + (($i$07$us$i*36)|0)|0) + 8|0);
   HEAPF32[$141>>2] = $124;
   $142 = ((($boxTris$i) + (($i$07$us$i*36)|0)|0) + 12|0);
   HEAPF32[$142>>2] = $127;
   $143 = ((($boxTris$i) + (($i$07$us$i*36)|0)|0) + 16|0);
   HEAPF32[$143>>2] = $129;
   $144 = ((($boxTris$i) + (($i$07$us$i*36)|0)|0) + 20|0);
   HEAPF32[$144>>2] = $131;
   $145 = ((($boxTris$i) + (($i$07$us$i*36)|0)|0) + 24|0);
   HEAPF32[$145>>2] = $134;
   $146 = ((($boxTris$i) + (($i$07$us$i*36)|0)|0) + 28|0);
   HEAPF32[$146>>2] = $136;
   $147 = ((($boxTris$i) + (($i$07$us$i*36)|0)|0) + 32|0);
   HEAPF32[$147>>2] = $138;
   $148 = (($i$07$us$i) + 1)|0;
   $exitcond8$i = ($148|0)==(12);
   if ($exitcond8$i) {
    break;
   } else {
    $i$07$us$i = $148;
   }
  }
 } else {
  $94 = (($boxWorldPose) + 24|0);
  $95 = (($boxWorldPose) + 20|0);
  $96 = (($boxWorldPose) + 16|0);
  $97 = (($boxWorldPose) + 8|0);
  $98 = (($boxWorldPose) + 4|0);
  $99 = (($boxWorldPose) + 12|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($100 * $100);
  $102 = Math_fround($101 + Math_fround(-0.5));
  $103 = Math_fround(HEAPF32[$boxWorldPose>>2]);
  $104 = Math_fround(HEAPF32[$98>>2]);
  $105 = Math_fround(HEAPF32[$97>>2]);
  $106 = Math_fround(HEAPF32[$96>>2]);
  $107 = Math_fround(HEAPF32[$95>>2]);
  $108 = Math_fround(HEAPF32[$94>>2]);
  $i$07$i = 0;
  while(1) {
   $149 = ($i$07$i*3)|0;
   $150 = (550632 + ($149)|0);
   $151 = HEAP8[$150>>0]|0;
   $152 = (($149) + 1)|0;
   $153 = (550632 + ($152)|0);
   $154 = HEAP8[$153>>0]|0;
   $155 = (($149) + 2)|0;
   $156 = (550632 + ($155)|0);
   $157 = HEAP8[$156>>0]|0;
   $158 = $151&255;
   $159 = (($p$i) + (($158*12)|0)|0);
   $160 = Math_fround(HEAPF32[$159>>2]);
   $161 = ((($p$i) + (($158*12)|0)|0) + 4|0);
   $162 = Math_fround(HEAPF32[$161>>2]);
   $163 = ((($p$i) + (($158*12)|0)|0) + 8|0);
   $164 = Math_fround(HEAPF32[$163>>2]);
   $165 = $154&255;
   $166 = (($p$i) + (($165*12)|0)|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = ((($p$i) + (($165*12)|0)|0) + 4|0);
   $169 = Math_fround(HEAPF32[$168>>2]);
   $170 = ((($p$i) + (($165*12)|0)|0) + 8|0);
   $171 = Math_fround(HEAPF32[$170>>2]);
   $172 = $157&255;
   $173 = (($p$i) + (($172*12)|0)|0);
   $174 = Math_fround(HEAPF32[$173>>2]);
   $175 = ((($p$i) + (($172*12)|0)|0) + 4|0);
   $176 = Math_fround(HEAPF32[$175>>2]);
   $177 = ((($p$i) + (($172*12)|0)|0) + 8|0);
   $178 = Math_fround(HEAPF32[$177>>2]);
   $179 = Math_fround($160 * Math_fround(2.0));
   $180 = Math_fround($162 * Math_fround(2.0));
   $181 = Math_fround($164 * Math_fround(2.0));
   $182 = Math_fround($179 * $103);
   $183 = Math_fround($180 * $104);
   $184 = Math_fround($182 + $183);
   $185 = Math_fround($181 * $105);
   $186 = Math_fround($184 + $185);
   $187 = Math_fround($179 * $102);
   $188 = Math_fround($181 * $104);
   $189 = Math_fround($180 * $105);
   $190 = Math_fround($188 - $189);
   $191 = Math_fround($100 * $190);
   $192 = Math_fround($187 + $191);
   $193 = Math_fround($103 * $186);
   $194 = Math_fround($193 + $192);
   $195 = Math_fround($180 * $102);
   $196 = Math_fround($179 * $105);
   $197 = Math_fround($181 * $103);
   $198 = Math_fround($196 - $197);
   $199 = Math_fround($100 * $198);
   $200 = Math_fround($195 + $199);
   $201 = Math_fround($104 * $186);
   $202 = Math_fround($201 + $200);
   $203 = Math_fround($181 * $102);
   $204 = Math_fround($180 * $103);
   $205 = Math_fround($179 * $104);
   $206 = Math_fround($204 - $205);
   $207 = Math_fround($100 * $206);
   $208 = Math_fround($203 + $207);
   $209 = Math_fround($105 * $186);
   $210 = Math_fround($208 + $209);
   $211 = Math_fround($106 + $194);
   $212 = Math_fround($107 + $202);
   $213 = Math_fround($108 + $210);
   $214 = Math_fround($167 * Math_fround(2.0));
   $215 = Math_fround($169 * Math_fround(2.0));
   $216 = Math_fround($171 * Math_fround(2.0));
   $217 = Math_fround($214 * $103);
   $218 = Math_fround($215 * $104);
   $219 = Math_fround($217 + $218);
   $220 = Math_fround($216 * $105);
   $221 = Math_fround($219 + $220);
   $222 = Math_fround($214 * $102);
   $223 = Math_fround($216 * $104);
   $224 = Math_fround($215 * $105);
   $225 = Math_fround($223 - $224);
   $226 = Math_fround($100 * $225);
   $227 = Math_fround($222 + $226);
   $228 = Math_fround($103 * $221);
   $229 = Math_fround($228 + $227);
   $230 = Math_fround($215 * $102);
   $231 = Math_fround($214 * $105);
   $232 = Math_fround($216 * $103);
   $233 = Math_fround($231 - $232);
   $234 = Math_fround($100 * $233);
   $235 = Math_fround($230 + $234);
   $236 = Math_fround($104 * $221);
   $237 = Math_fround($236 + $235);
   $238 = Math_fround($216 * $102);
   $239 = Math_fround($215 * $103);
   $240 = Math_fround($214 * $104);
   $241 = Math_fround($239 - $240);
   $242 = Math_fround($100 * $241);
   $243 = Math_fround($238 + $242);
   $244 = Math_fround($105 * $221);
   $245 = Math_fround($243 + $244);
   $246 = Math_fround($106 + $229);
   $247 = Math_fround($107 + $237);
   $248 = Math_fround($108 + $245);
   $249 = Math_fround($174 * Math_fround(2.0));
   $250 = Math_fround($176 * Math_fround(2.0));
   $251 = Math_fround($178 * Math_fround(2.0));
   $252 = Math_fround($249 * $103);
   $253 = Math_fround($250 * $104);
   $254 = Math_fround($252 + $253);
   $255 = Math_fround($251 * $105);
   $256 = Math_fround($254 + $255);
   $257 = Math_fround($249 * $102);
   $258 = Math_fround($251 * $104);
   $259 = Math_fround($250 * $105);
   $260 = Math_fround($258 - $259);
   $261 = Math_fround($100 * $260);
   $262 = Math_fround($257 + $261);
   $263 = Math_fround($103 * $256);
   $264 = Math_fround($263 + $262);
   $265 = Math_fround($250 * $102);
   $266 = Math_fround($249 * $105);
   $267 = Math_fround($251 * $103);
   $268 = Math_fround($266 - $267);
   $269 = Math_fround($100 * $268);
   $270 = Math_fround($265 + $269);
   $271 = Math_fround($104 * $256);
   $272 = Math_fround($271 + $270);
   $273 = Math_fround($251 * $102);
   $274 = Math_fround($250 * $103);
   $275 = Math_fround($249 * $104);
   $276 = Math_fround($274 - $275);
   $277 = Math_fround($100 * $276);
   $278 = Math_fround($273 + $277);
   $279 = Math_fround($105 * $256);
   $280 = Math_fround($278 + $279);
   $281 = Math_fround($106 + $264);
   $282 = Math_fround($107 + $272);
   $283 = Math_fround($108 + $280);
   $284 = (($boxTris$i) + (($i$07$i*36)|0)|0);
   HEAPF32[$284>>2] = $211;
   $285 = ((($boxTris$i) + (($i$07$i*36)|0)|0) + 4|0);
   HEAPF32[$285>>2] = $212;
   $286 = ((($boxTris$i) + (($i$07$i*36)|0)|0) + 8|0);
   HEAPF32[$286>>2] = $213;
   $287 = ((($boxTris$i) + (($i$07$i*36)|0)|0) + 12|0);
   HEAPF32[$287>>2] = $246;
   $288 = ((($boxTris$i) + (($i$07$i*36)|0)|0) + 16|0);
   HEAPF32[$288>>2] = $247;
   $289 = ((($boxTris$i) + (($i$07$i*36)|0)|0) + 20|0);
   HEAPF32[$289>>2] = $248;
   $290 = ((($boxTris$i) + (($i$07$i*36)|0)|0) + 24|0);
   HEAPF32[$290>>2] = $281;
   $291 = ((($boxTris$i) + (($i$07$i*36)|0)|0) + 28|0);
   HEAPF32[$291>>2] = $282;
   $292 = ((($boxTris$i) + (($i$07$i*36)|0)|0) + 32|0);
   HEAPF32[$292>>2] = $283;
   $293 = (($i$07$i) + 1)|0;
   $exitcond$i = ($293|0)==(12);
   if ($exitcond$i) {
    break;
   } else {
    $i$07$i = $293;
   }
  }
 }
 $294 = (($dir) + 4|0);
 $295 = (($dir) + 8|0);
 $$014$i$i = $92;$$023$i$i = $fakeIDs$i;$i$01$i$i = 0;
 while(1) {
  $296 = ((($boxTris$i) + (($i$01$i$i*36)|0)|0) + 12|0);
  $297 = Math_fround(HEAPF32[$296>>2]);
  $298 = (($boxTris$i) + (($i$01$i$i*36)|0)|0);
  $299 = Math_fround(HEAPF32[$298>>2]);
  $300 = Math_fround($297 - $299);
  $301 = ((($boxTris$i) + (($i$01$i$i*36)|0)|0) + 16|0);
  $302 = Math_fround(HEAPF32[$301>>2]);
  $303 = ((($boxTris$i) + (($i$01$i$i*36)|0)|0) + 4|0);
  $304 = Math_fround(HEAPF32[$303>>2]);
  $305 = Math_fround($302 - $304);
  $306 = ((($boxTris$i) + (($i$01$i$i*36)|0)|0) + 20|0);
  $307 = Math_fround(HEAPF32[$306>>2]);
  $308 = ((($boxTris$i) + (($i$01$i$i*36)|0)|0) + 8|0);
  $309 = Math_fround(HEAPF32[$308>>2]);
  $310 = Math_fround($307 - $309);
  $311 = ((($boxTris$i) + (($i$01$i$i*36)|0)|0) + 24|0);
  $312 = Math_fround(HEAPF32[$311>>2]);
  $313 = Math_fround($312 - $299);
  $314 = ((($boxTris$i) + (($i$01$i$i*36)|0)|0) + 28|0);
  $315 = Math_fround(HEAPF32[$314>>2]);
  $316 = Math_fround($315 - $304);
  $317 = ((($boxTris$i) + (($i$01$i$i*36)|0)|0) + 32|0);
  $318 = Math_fround(HEAPF32[$317>>2]);
  $319 = Math_fround($318 - $309);
  $320 = Math_fround($305 * $319);
  $321 = Math_fround($310 * $316);
  $322 = Math_fround($320 - $321);
  $323 = Math_fround($310 * $313);
  $324 = Math_fround($300 * $319);
  $325 = Math_fround($323 - $324);
  $326 = Math_fround($300 * $316);
  $327 = Math_fround($305 * $313);
  $328 = Math_fround($326 - $327);
  $329 = Math_fround(HEAPF32[$dir>>2]);
  $330 = Math_fround($329 * $322);
  $331 = Math_fround(HEAPF32[$294>>2]);
  $332 = Math_fround($331 * $325);
  $333 = Math_fround($330 + $332);
  $334 = Math_fround(HEAPF32[$295>>2]);
  $335 = Math_fround($328 * $334);
  $336 = Math_fround($335 + $333);
  $337 = $336 > Math_fround(0.0);
  if ($337) {
   $$13$i$i = $$023$i$i;$$2$i$i = $$014$i$i;
  } else {
   $338 = Math_fround($75 + $299);
   $339 = Math_fround($76 + $304);
   $340 = Math_fround($77 + $309);
   $341 = Math_fround($75 + $297);
   $342 = Math_fround($76 + $302);
   $343 = Math_fround($77 + $307);
   $344 = Math_fround($75 + $312);
   $345 = Math_fround($76 + $315);
   $346 = Math_fround($77 + $318);
   $347 = Math_fround($299 - $75);
   $348 = Math_fround($304 - $76);
   $349 = Math_fround($309 - $77);
   $350 = Math_fround($297 - $75);
   $351 = Math_fround($302 - $76);
   $352 = Math_fround($307 - $77);
   $353 = Math_fround($312 - $75);
   $354 = Math_fround($315 - $76);
   $355 = Math_fround($318 - $77);
   $356 = Math_fround($75 * $322);
   $357 = Math_fround($76 * $325);
   $358 = Math_fround($356 + $357);
   $359 = Math_fround($77 * $328);
   $360 = Math_fround($359 + $358);
   $361 = !($360 >= Math_fround(0.0));
   if ($361) {
    HEAPF32[$$014$i$i>>2] = $347;
    $370 = (($$014$i$i) + 4|0);
    HEAPF32[$370>>2] = $348;
    $371 = (($$014$i$i) + 8|0);
    HEAPF32[$371>>2] = $349;
    $372 = (($$014$i$i) + 12|0);
    HEAPF32[$372>>2] = $350;
    $373 = (($$014$i$i) + 16|0);
    HEAPF32[$373>>2] = $351;
    $374 = (($$014$i$i) + 20|0);
    HEAPF32[$374>>2] = $352;
    $375 = (($$014$i$i) + 24|0);
    HEAPF32[$375>>2] = $353;
    $376 = (($$014$i$i) + 28|0);
    HEAPF32[$376>>2] = $354;
    $377 = (($$014$i$i) + 32|0);
    HEAPF32[$377>>2] = $355;
   } else {
    HEAPF32[$$014$i$i>>2] = $338;
    $362 = (($$014$i$i) + 4|0);
    HEAPF32[$362>>2] = $339;
    $363 = (($$014$i$i) + 8|0);
    HEAPF32[$363>>2] = $340;
    $364 = (($$014$i$i) + 12|0);
    HEAPF32[$364>>2] = $341;
    $365 = (($$014$i$i) + 16|0);
    HEAPF32[$365>>2] = $342;
    $366 = (($$014$i$i) + 20|0);
    HEAPF32[$366>>2] = $343;
    $367 = (($$014$i$i) + 24|0);
    HEAPF32[$367>>2] = $344;
    $368 = (($$014$i$i) + 28|0);
    HEAPF32[$368>>2] = $345;
    $369 = (($$014$i$i) + 32|0);
    HEAPF32[$369>>2] = $346;
   }
   $378 = (($$023$i$i) + 4|0);
   HEAP32[$$023$i$i>>2] = $i$01$i$i;
   $379 = (($$014$i$i) + 36|0);
   HEAPF32[$379>>2] = $350;
   $380 = (($$014$i$i) + 40|0);
   HEAPF32[$380>>2] = $351;
   $381 = (($$014$i$i) + 44|0);
   HEAPF32[$381>>2] = $352;
   $382 = (($$014$i$i) + 48|0);
   HEAPF32[$382>>2] = $341;
   $383 = (($$014$i$i) + 52|0);
   HEAPF32[$383>>2] = $342;
   $384 = (($$014$i$i) + 56|0);
   HEAPF32[$384>>2] = $343;
   $385 = (($$014$i$i) + 60|0);
   HEAPF32[$385>>2] = $344;
   $386 = (($$014$i$i) + 64|0);
   HEAPF32[$386>>2] = $345;
   $387 = (($$014$i$i) + 68|0);
   HEAPF32[$387>>2] = $346;
   $388 = Math_fround($341 - $350);
   $389 = Math_fround($342 - $351);
   $390 = Math_fround($343 - $352);
   $391 = Math_fround($344 - $350);
   $392 = Math_fround($345 - $351);
   $393 = Math_fround($346 - $352);
   $394 = Math_fround($389 * $393);
   $395 = Math_fround($390 * $392);
   $396 = Math_fround($394 - $395);
   $397 = Math_fround($390 * $391);
   $398 = Math_fround($388 * $393);
   $399 = Math_fround($397 - $398);
   $400 = Math_fround($388 * $392);
   $401 = Math_fround($389 * $391);
   $402 = Math_fround($400 - $401);
   $403 = Math_fround(HEAPF32[$dir>>2]);
   $404 = Math_fround($396 * $403);
   $405 = Math_fround(HEAPF32[$294>>2]);
   $406 = Math_fround($399 * $405);
   $407 = Math_fround($404 + $406);
   $408 = Math_fround(HEAPF32[$295>>2]);
   $409 = Math_fround($402 * $408);
   $410 = Math_fround($409 + $407);
   $411 = $410 > Math_fround(0.0);
   if ($411) {
    HEAPF32[$382>>2] = $344;
    HEAPF32[$383>>2] = $345;
    HEAPF32[$384>>2] = $346;
    HEAPF32[$385>>2] = $341;
    HEAPF32[$386>>2] = $342;
    HEAPF32[$387>>2] = $343;
   }
   $412 = (($$023$i$i) + 8|0);
   HEAP32[$378>>2] = $i$01$i$i;
   $413 = (($$014$i$i) + 72|0);
   HEAPF32[$413>>2] = $350;
   $414 = (($$014$i$i) + 76|0);
   HEAPF32[$414>>2] = $351;
   $415 = (($$014$i$i) + 80|0);
   HEAPF32[$415>>2] = $352;
   $416 = (($$014$i$i) + 84|0);
   HEAPF32[$416>>2] = $344;
   $417 = (($$014$i$i) + 88|0);
   HEAPF32[$417>>2] = $345;
   $418 = (($$014$i$i) + 92|0);
   HEAPF32[$418>>2] = $346;
   $419 = (($$014$i$i) + 96|0);
   HEAPF32[$419>>2] = $353;
   $420 = (($$014$i$i) + 100|0);
   HEAPF32[$420>>2] = $354;
   $421 = (($$014$i$i) + 104|0);
   HEAPF32[$421>>2] = $355;
   $422 = Math_fround($353 - $350);
   $423 = Math_fround($354 - $351);
   $424 = Math_fround($355 - $352);
   $425 = Math_fround($392 * $424);
   $426 = Math_fround($423 * $393);
   $427 = Math_fround($425 - $426);
   $428 = Math_fround($422 * $393);
   $429 = Math_fround($391 * $424);
   $430 = Math_fround($428 - $429);
   $431 = Math_fround($391 * $423);
   $432 = Math_fround($422 * $392);
   $433 = Math_fround($431 - $432);
   $434 = Math_fround(HEAPF32[$dir>>2]);
   $435 = Math_fround($427 * $434);
   $436 = Math_fround(HEAPF32[$294>>2]);
   $437 = Math_fround($430 * $436);
   $438 = Math_fround($435 + $437);
   $439 = Math_fround(HEAPF32[$295>>2]);
   $440 = Math_fround($433 * $439);
   $441 = Math_fround($440 + $438);
   $442 = $441 > Math_fround(0.0);
   if ($442) {
    HEAPF32[$416>>2] = $353;
    HEAPF32[$417>>2] = $354;
    HEAPF32[$418>>2] = $355;
    HEAPF32[$419>>2] = $344;
    HEAPF32[$420>>2] = $345;
    HEAPF32[$421>>2] = $346;
   }
   $443 = (($$023$i$i) + 12|0);
   HEAP32[$412>>2] = $i$01$i$i;
   $444 = (($$014$i$i) + 108|0);
   HEAPF32[$444>>2] = $347;
   $445 = (($$014$i$i) + 112|0);
   HEAPF32[$445>>2] = $348;
   $446 = (($$014$i$i) + 116|0);
   HEAPF32[$446>>2] = $349;
   $447 = (($$014$i$i) + 120|0);
   HEAPF32[$447>>2] = $353;
   $448 = (($$014$i$i) + 124|0);
   HEAPF32[$448>>2] = $354;
   $449 = (($$014$i$i) + 128|0);
   HEAPF32[$449>>2] = $355;
   $450 = (($$014$i$i) + 132|0);
   HEAPF32[$450>>2] = $344;
   $451 = (($$014$i$i) + 136|0);
   HEAPF32[$451>>2] = $345;
   $452 = (($$014$i$i) + 140|0);
   HEAPF32[$452>>2] = $346;
   $453 = Math_fround($353 - $347);
   $454 = Math_fround($354 - $348);
   $455 = Math_fround($355 - $349);
   $456 = Math_fround($344 - $347);
   $457 = Math_fround($345 - $348);
   $458 = Math_fround($346 - $349);
   $459 = Math_fround($454 * $458);
   $460 = Math_fround($457 * $455);
   $461 = Math_fround($459 - $460);
   $462 = Math_fround($456 * $455);
   $463 = Math_fround($453 * $458);
   $464 = Math_fround($462 - $463);
   $465 = Math_fround($453 * $457);
   $466 = Math_fround($456 * $454);
   $467 = Math_fround($465 - $466);
   $468 = Math_fround(HEAPF32[$dir>>2]);
   $469 = Math_fround($461 * $468);
   $470 = Math_fround(HEAPF32[$294>>2]);
   $471 = Math_fround($464 * $470);
   $472 = Math_fround($469 + $471);
   $473 = Math_fround(HEAPF32[$295>>2]);
   $474 = Math_fround($467 * $473);
   $475 = Math_fround($474 + $472);
   $476 = $475 > Math_fround(0.0);
   if ($476) {
    HEAPF32[$447>>2] = $344;
    HEAPF32[$448>>2] = $345;
    HEAPF32[$449>>2] = $346;
    HEAPF32[$450>>2] = $353;
    HEAPF32[$451>>2] = $354;
    HEAPF32[$452>>2] = $355;
   }
   $477 = (($$023$i$i) + 16|0);
   HEAP32[$443>>2] = $i$01$i$i;
   $478 = (($$014$i$i) + 144|0);
   HEAPF32[$478>>2] = $347;
   $479 = (($$014$i$i) + 148|0);
   HEAPF32[$479>>2] = $348;
   $480 = (($$014$i$i) + 152|0);
   HEAPF32[$480>>2] = $349;
   $481 = (($$014$i$i) + 156|0);
   HEAPF32[$481>>2] = $344;
   $482 = (($$014$i$i) + 160|0);
   HEAPF32[$482>>2] = $345;
   $483 = (($$014$i$i) + 164|0);
   HEAPF32[$483>>2] = $346;
   $484 = (($$014$i$i) + 168|0);
   HEAPF32[$484>>2] = $338;
   $485 = (($$014$i$i) + 172|0);
   HEAPF32[$485>>2] = $339;
   $486 = (($$014$i$i) + 176|0);
   HEAPF32[$486>>2] = $340;
   $487 = Math_fround($338 - $347);
   $488 = Math_fround($339 - $348);
   $489 = Math_fround($340 - $349);
   $490 = Math_fround($489 * $457);
   $491 = Math_fround($488 * $458);
   $492 = Math_fround($490 - $491);
   $493 = Math_fround($487 * $458);
   $494 = Math_fround($489 * $456);
   $495 = Math_fround($493 - $494);
   $496 = Math_fround($488 * $456);
   $497 = Math_fround($487 * $457);
   $498 = Math_fround($496 - $497);
   $499 = Math_fround(HEAPF32[$dir>>2]);
   $500 = Math_fround($492 * $499);
   $501 = Math_fround(HEAPF32[$294>>2]);
   $502 = Math_fround($495 * $501);
   $503 = Math_fround($500 + $502);
   $504 = Math_fround(HEAPF32[$295>>2]);
   $505 = Math_fround($498 * $504);
   $506 = Math_fround($505 + $503);
   $507 = $506 > Math_fround(0.0);
   if ($507) {
    HEAPF32[$481>>2] = $338;
    HEAPF32[$482>>2] = $339;
    HEAPF32[$483>>2] = $340;
    HEAPF32[$484>>2] = $344;
    HEAPF32[$485>>2] = $345;
    HEAPF32[$486>>2] = $346;
   }
   $508 = (($$023$i$i) + 20|0);
   HEAP32[$477>>2] = $i$01$i$i;
   $509 = (($$014$i$i) + 180|0);
   HEAPF32[$509>>2] = $338;
   $510 = (($$014$i$i) + 184|0);
   HEAPF32[$510>>2] = $339;
   $511 = (($$014$i$i) + 188|0);
   HEAPF32[$511>>2] = $340;
   $512 = (($$014$i$i) + 192|0);
   HEAPF32[$512>>2] = $341;
   $513 = (($$014$i$i) + 196|0);
   HEAPF32[$513>>2] = $342;
   $514 = (($$014$i$i) + 200|0);
   HEAPF32[$514>>2] = $343;
   $515 = (($$014$i$i) + 204|0);
   HEAPF32[$515>>2] = $350;
   $516 = (($$014$i$i) + 208|0);
   HEAPF32[$516>>2] = $351;
   $517 = (($$014$i$i) + 212|0);
   HEAPF32[$517>>2] = $352;
   $518 = Math_fround($341 - $338);
   $519 = Math_fround($342 - $339);
   $520 = Math_fround($343 - $340);
   $521 = Math_fround($350 - $338);
   $522 = Math_fround($351 - $339);
   $523 = Math_fround($352 - $340);
   $524 = Math_fround($519 * $523);
   $525 = Math_fround($522 * $520);
   $526 = Math_fround($524 - $525);
   $527 = Math_fround($521 * $520);
   $528 = Math_fround($518 * $523);
   $529 = Math_fround($527 - $528);
   $530 = Math_fround($518 * $522);
   $531 = Math_fround($521 * $519);
   $532 = Math_fround($530 - $531);
   $533 = Math_fround(HEAPF32[$dir>>2]);
   $534 = Math_fround($526 * $533);
   $535 = Math_fround(HEAPF32[$294>>2]);
   $536 = Math_fround($529 * $535);
   $537 = Math_fround($534 + $536);
   $538 = Math_fround(HEAPF32[$295>>2]);
   $539 = Math_fround($532 * $538);
   $540 = Math_fround($539 + $537);
   $541 = $540 > Math_fround(0.0);
   if ($541) {
    HEAPF32[$512>>2] = $350;
    HEAPF32[$513>>2] = $351;
    HEAPF32[$514>>2] = $352;
    HEAPF32[$515>>2] = $341;
    HEAPF32[$516>>2] = $342;
    HEAPF32[$517>>2] = $343;
   }
   $542 = (($$023$i$i) + 24|0);
   HEAP32[$508>>2] = $i$01$i$i;
   $543 = (($$014$i$i) + 216|0);
   HEAPF32[$543>>2] = $338;
   $544 = (($$014$i$i) + 220|0);
   HEAPF32[$544>>2] = $339;
   $545 = (($$014$i$i) + 224|0);
   HEAPF32[$545>>2] = $340;
   $546 = (($$014$i$i) + 228|0);
   HEAPF32[$546>>2] = $350;
   $547 = (($$014$i$i) + 232|0);
   HEAPF32[$547>>2] = $351;
   $548 = (($$014$i$i) + 236|0);
   HEAPF32[$548>>2] = $352;
   $549 = (($$014$i$i) + 240|0);
   HEAPF32[$549>>2] = $347;
   $550 = (($$014$i$i) + 244|0);
   HEAPF32[$550>>2] = $348;
   $551 = (($$014$i$i) + 248|0);
   HEAPF32[$551>>2] = $349;
   $552 = Math_fround($347 - $338);
   $553 = Math_fround($348 - $339);
   $554 = Math_fround($349 - $340);
   $555 = Math_fround($522 * $554);
   $556 = Math_fround($553 * $523);
   $557 = Math_fround($555 - $556);
   $558 = Math_fround($552 * $523);
   $559 = Math_fround($521 * $554);
   $560 = Math_fround($558 - $559);
   $561 = Math_fround($521 * $553);
   $562 = Math_fround($552 * $522);
   $563 = Math_fround($561 - $562);
   $564 = Math_fround(HEAPF32[$dir>>2]);
   $565 = Math_fround($557 * $564);
   $566 = Math_fround(HEAPF32[$294>>2]);
   $567 = Math_fround($560 * $566);
   $568 = Math_fround($565 + $567);
   $569 = Math_fround(HEAPF32[$295>>2]);
   $570 = Math_fround($563 * $569);
   $571 = Math_fround($570 + $568);
   $572 = $571 > Math_fround(0.0);
   if ($572) {
    HEAPF32[$546>>2] = $347;
    HEAPF32[$547>>2] = $348;
    HEAPF32[$548>>2] = $349;
    HEAPF32[$549>>2] = $350;
    HEAPF32[$550>>2] = $351;
    HEAPF32[$551>>2] = $352;
   }
   $573 = (($$014$i$i) + 252|0);
   $574 = (($$023$i$i) + 28|0);
   HEAP32[$542>>2] = $i$01$i$i;
   $$13$i$i = $574;$$2$i$i = $573;
  }
  $575 = (($i$01$i$i) + 1)|0;
  $exitcond$i$i = ($575|0)==(12);
  if ($exitcond$i$i) {
   break;
  } else {
   $$014$i$i = $$2$i$i;$$023$i$i = $$13$i$i;$i$01$i$i = $575;
  }
 }
 $576 = $$13$i$i;
 $577 = $fakeIDs$i;
 $578 = (($576) - ($577))|0;
 $579 = $578 >> 2;
 HEAP16[$unused>>1] = 0;
 $580 = HEAP32[$triangles>>2]|0;
 $581 = Math_fround(HEAPF32[$capsule>>2]);
 $582 = Math_fround(HEAPF32[$61>>2]);
 $583 = Math_fround($581 + $582);
 $584 = Math_fround(HEAPF32[$67>>2]);
 $585 = Math_fround(HEAPF32[$65>>2]);
 $586 = Math_fround($584 + $585);
 $587 = Math_fround(HEAPF32[$72>>2]);
 $588 = Math_fround(HEAPF32[$70>>2]);
 $589 = Math_fround($587 + $588);
 $590 = Math_fround($583 * Math_fround(0.5));
 $591 = Math_fround($586 * Math_fround(0.5));
 $592 = Math_fround($589 * Math_fround(0.5));
 HEAPF32[$2>>2] = $590;
 $593 = (($2) + 4|0);
 HEAPF32[$593>>2] = $591;
 $594 = (($2) + 8|0);
 HEAPF32[$594>>2] = $592;
 $595 = (($capsule) + 24|0);
 $596 = Math_fround(HEAPF32[$595>>2]);
 $597 = (__ZN5physx2Gu20sweepSphereTrianglesEjPKNS_10PxTriangleERKNS_6PxVec3EfS6_fPKjRS4_S9_RfRjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEEb($579,$580,$2,$596,$dir,$length,0,$hit,$n,$md,$trash,$unused,0)|0);
 if ($597) {
  $598 = Math_fround(HEAPF32[$md>>2]);
  $599 = Math_fround(HEAPF32[$n>>2]);
  HEAPF32[$normal>>2] = $599;
  $600 = (($n) + 4|0);
  $601 = Math_fround(HEAPF32[$600>>2]);
  $602 = (($normal) + 4|0);
  HEAPF32[$602>>2] = $601;
  $603 = (($n) + 8|0);
  $604 = Math_fround(HEAPF32[$603>>2]);
  $605 = (($normal) + 8|0);
  HEAPF32[$605>>2] = $604;
  $MinDist$0 = $598;$Status$0$off0 = 1;
 } else {
  $MinDist$0 = $length;$Status$0$off0 = 0;
 }
 $606 = HEAP8[$91>>0]|0;
 $607 = ($606<<24>>24)==(0);
 if (!($607)) {
  __ZN5physx6shdfnd13TempAllocator10deallocateEPv($triangles,$580);
 }
 HEAPF32[$min_dist>>2] = $MinDist$0;
 $$0 = $Status$0$off0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19sweepCapsuleCapsuleERKNS0_7CapsuleES3_RKNS_6PxVec3EfRfRS4_S8_jRt($lss0,$lss1,$dir,$length,$min_dist,$ip,$normal,$inHintFlags,$outHintFlags) {
 $lss0 = $lss0|0;
 $lss1 = $lss1|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $min_dist = $min_dist|0;
 $ip = $ip|0;
 $normal = $normal|0;
 $inHintFlags = $inHintFlags|0;
 $outHintFlags = $outHintFlags|0;
 var $$ = Math_fround(0), $$$1 = Math_fround(0), $$$2 = Math_fround(0), $$$3 = Math_fround(0), $$0 = 0, $$length = Math_fround(0), $$length122 = Math_fround(0), $$pre$phi132Z2D = 0, $$pre$phi134Z2D = 0, $$pre$phiZ2D = 0, $$pre133 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0);
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0);
 var $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0;
 var $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0);
 var $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0;
 var $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0);
 var $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0);
 var $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0);
 var $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0);
 var $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0;
 var $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0);
 var $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0);
 var $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = Math_fround(0), $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0;
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0;
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $Caps = 0;
 var $MinDist$1$w$0 = Math_fround(0), $MinDist$1$w$0$1 = Math_fround(0), $MinDist$1$w$0$2 = Math_fround(0), $MinDist$1$w$0$3 = Math_fround(0), $MinDist$2 = Math_fround(0), $MinDist$2$1 = Math_fround(0), $MinDist$2$2 = Math_fround(0), $MinDist$3125 = Math_fround(0), $Status$1$off0$$1 = 0, $Status$1$off0$$2 = 0, $Status$1$off0$$3 = 0, $Status$2$off0 = 0, $Status$2$off0$1 = 0, $Status$2$off0$2 = 0, $center = 0, $center$idx$val = Math_fround(0), $center$idx11$val = Math_fround(0), $center$idx12$val = Math_fround(0), $dir$idx25$val = Math_fround(0), $dir$idx26$val = Math_fround(0);
 var $dir$idx27$val = Math_fround(0), $edge1 = 0, $not$or$cond9 = 0, $not$or$cond9$1 = 0, $not$or$cond9$1$demorgan = 0, $not$or$cond9$2 = 0, $not$or$cond9$2$demorgan = 0, $not$or$cond9$3 = 0, $not$or$cond9$3$demorgan = 0, $not$or$cond9$demorgan = 0, $or$cond = 0, $or$cond$i = 0, $or$cond1$i = 0, $or$cond135 = 0, $or$cond8 = 0, $or$cond9 = 0, $or$cond9$1 = 0, $or$cond9$2 = 0, $or$cond9$3 = 0, $s = 0;
 var $w$0 = Math_fround(0), $w$0$1 = Math_fround(0), $w$0$2 = Math_fround(0), $w$0$3 = Math_fround(0), $x = 0, $x$idx$val = Math_fround(0), $x$idx21 = 0, $x$idx21$val = Math_fround(0), $x$idx22 = 0, $x$idx22$val = Math_fround(0), $y = 0, $y$idx$val = Math_fround(0), $y$idx19 = 0, $y$idx19$val = Math_fround(0), $y$idx20 = 0, $y$idx20$val = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $center = sp + 156|0;
 $Caps = sp;
 $s = sp + 112|0;
 $edge1 = sp + 120|0;
 $x = sp + 132|0;
 $y = sp + 144|0;
 $0 = (($lss0) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($lss1) + 24|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 $5 = Math_fround(HEAPF32[$lss1>>2]);
 $6 = (($lss1) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 $9 = (($lss1) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($lss1) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = (($lss1) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($lss1) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 + $17);
 $19 = Math_fround($8 * Math_fround(0.5));
 $20 = Math_fround($13 * Math_fround(0.5));
 $21 = Math_fround($18 * Math_fround(0.5));
 HEAPF32[$center>>2] = $19;
 $22 = (($center) + 4|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($center) + 8|0);
 HEAPF32[$23>>2] = $21;
 $24 = $inHintFlags & 16;
 $25 = ($24|0)==(0);
 L1: do {
  if ($25) {
   $26 = Math_fround(HEAPF32[$lss0>>2]);
   $27 = (($lss0) + 12|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = $26 == $28;
   if ($29) {
    $30 = (($lss0) + 4|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = (($lss0) + 16|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = $31 == $33;
    if ($34) {
     $35 = (($lss0) + 8|0);
     $36 = Math_fround(HEAPF32[$35>>2]);
     $37 = (($lss0) + 20|0);
     $38 = Math_fround(HEAPF32[$37>>2]);
     $39 = $36 == $38;
     if ($39) {
      $40 = (($lss1) + 12|0);
      $41 = (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($lss1,$40,$lss0,0)));
      $42 = Math_fround($4 * $4);
      $43 = $41 < $42;
      if (!($43)) {
       $$pre$phi132Z2D = $lss0;$$pre$phi134Z2D = $27;$$pre$phiZ2D = $lss1;
       break;
      }
     } else {
      label = 7;
     }
    } else {
     label = 7;
    }
   } else {
    label = 7;
   }
   do {
    if ((label|0) == 7) {
     $44 = $5 == $7;
     $45 = $10 == $12;
     $or$cond = $44 & $45;
     $46 = $15 == $17;
     $or$cond135 = $or$cond & $46;
     if ($or$cond135) {
      $47 = (($lss0) + 12|0);
      $48 = (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($lss0,$47,$lss1,0)));
      $49 = Math_fround($4 * $4);
      $50 = $48 < $49;
      if ($50) {
       break;
      } else {
       $$pre$phi132Z2D = $lss0;$$pre$phi134Z2D = $27;$$pre$phiZ2D = $lss1;
       break L1;
      }
     } else {
      $51 = (Math_fround(__ZN5physx2Gu30distanceSegmentSegmentSquared2ERKNS0_7SegmentES3_PfS4_($lss0,$lss1,0,0)));
      $52 = Math_fround($4 * $4);
      $53 = $51 < $52;
      if ($53) {
       break;
      } else {
       $$pre$phi132Z2D = $lss0;$$pre$phi134Z2D = $27;$$pre$phiZ2D = $lss1;
       break L1;
      }
     }
    }
   } while(0);
   HEAPF32[$min_dist>>2] = Math_fround(0.0);
   $54 = Math_fround(HEAPF32[$dir>>2]);
   $55 = Math_fround(-$54);
   $56 = (($dir) + 4|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround(-$57);
   $59 = (($dir) + 8|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround(-$60);
   HEAPF32[$normal>>2] = $55;
   $62 = (($normal) + 4|0);
   HEAPF32[$62>>2] = $58;
   $63 = (($normal) + 8|0);
   HEAPF32[$63>>2] = $61;
   HEAP16[$outHintFlags>>1] = 6;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$pre133 = (($lss0) + 12|0);
   $$pre$phi132Z2D = $lss0;$$pre$phi134Z2D = $$pre133;$$pre$phiZ2D = $lss1;
  }
 } while(0);
 $64 = Math_fround(HEAPF32[$6>>2]);
 $65 = Math_fround(HEAPF32[$lss1>>2]);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround(HEAPF32[$11>>2]);
 $68 = Math_fround(HEAPF32[$9>>2]);
 $69 = Math_fround($67 - $68);
 $70 = Math_fround(HEAPF32[$16>>2]);
 $71 = Math_fround(HEAPF32[$14>>2]);
 $72 = Math_fround($70 - $71);
 $73 = Math_fround($66 * Math_fround(0.5));
 $74 = Math_fround($69 * Math_fround(0.5));
 $75 = Math_fround($72 * Math_fround(0.5));
 $76 = Math_fround(HEAPF32[$$pre$phi132Z2D>>2]);
 $77 = Math_fround($76 - $73);
 $78 = (($lss0) + 4|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 - $74);
 $81 = (($lss0) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 - $75);
 $84 = Math_fround(HEAPF32[$$pre$phi134Z2D>>2]);
 $85 = Math_fround($84 - $73);
 $86 = (($lss0) + 16|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($87 - $74);
 $89 = (($lss0) + 20|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($90 - $75);
 $92 = Math_fround($73 + $76);
 $93 = Math_fround($74 + $79);
 $94 = Math_fround($75 + $82);
 $95 = Math_fround($73 + $84);
 $96 = Math_fround($74 + $87);
 $97 = Math_fround($75 + $90);
 $98 = Math_fround($95 - $92);
 $99 = Math_fround($96 - $93);
 $100 = Math_fround($97 - $94);
 $101 = Math_fround($85 - $92);
 $102 = Math_fround($88 - $93);
 $103 = Math_fround($91 - $94);
 $104 = Math_fround($99 * $103);
 $105 = Math_fround($102 * $100);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($101 * $100);
 $108 = Math_fround($98 * $103);
 $109 = Math_fround($107 - $108);
 $110 = Math_fround($98 * $102);
 $111 = Math_fround($101 * $99);
 $112 = Math_fround($110 - $111);
 $113 = Math_fround($106 * $106);
 $114 = Math_fround($109 * $109);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($112 * $112);
 $117 = Math_fround($116 + $115);
 $118 = (Math_fround(Math_sqrt((Math_fround($117)))));
 $119 = $118 > Math_fround(0.0);
 if ($119) {
  $120 = Math_fround(Math_fround(1.0) / $118);
  $121 = Math_fround($106 * $120);
  $122 = Math_fround($109 * $120);
  $123 = Math_fround($112 * $120);
  $126 = $121;$130 = $122;$135 = $123;
 } else {
  $126 = $106;$130 = $109;$135 = $112;
 }
 $124 = Math_fround(HEAPF32[$dir>>2]);
 $125 = Math_fround($126 * $124);
 $127 = (($dir) + 4|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($130 * $128);
 $131 = Math_fround($125 + $129);
 $132 = (($dir) + 8|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($135 * $133);
 $136 = Math_fround($131 + $134);
 $137 = !($136 >= Math_fround(0.0));
 $138 = Math_fround($4 * $126);
 $139 = Math_fround($4 * $130);
 $140 = Math_fround($4 * $135);
 if ($137) {
  $150 = Math_fround($77 + $138);
  $151 = Math_fround($80 + $139);
  $152 = Math_fround($83 + $140);
  $153 = Math_fround($85 + $138);
  $154 = Math_fround($88 + $139);
  $155 = Math_fround($91 + $140);
  $156 = Math_fround($95 + $138);
  $157 = Math_fround($96 + $139);
  $158 = Math_fround($97 + $140);
  $160 = $153;$161 = $150;$163 = $154;$164 = $151;$166 = $155;$167 = $152;$169 = $156;$171 = $157;$173 = $158;
 } else {
  $141 = Math_fround($77 - $138);
  $142 = Math_fround($80 - $139);
  $143 = Math_fround($83 - $140);
  $144 = Math_fround($85 - $138);
  $145 = Math_fround($88 - $139);
  $146 = Math_fround($91 - $140);
  $147 = Math_fround($95 - $138);
  $148 = Math_fround($96 - $139);
  $149 = Math_fround($97 - $140);
  $160 = $144;$161 = $147;$163 = $145;$164 = $148;$166 = $146;$167 = $149;$169 = $141;$171 = $142;$173 = $143;
 }
 $159 = Math_fround($161 - $160);
 $162 = Math_fround($164 - $163);
 $165 = Math_fround($167 - $166);
 $168 = Math_fround($169 - $160);
 $170 = Math_fround($171 - $163);
 $172 = Math_fround($173 - $166);
 $174 = Math_fround($172 * $128);
 $175 = Math_fround($170 * $133);
 $176 = Math_fround($174 - $175);
 $177 = Math_fround($168 * $133);
 $178 = Math_fround($172 * $124);
 $179 = Math_fround($177 - $178);
 $180 = Math_fround($170 * $124);
 $181 = Math_fround($168 * $128);
 $182 = Math_fround($180 - $181);
 $183 = Math_fround($159 * $176);
 $184 = Math_fround($162 * $179);
 $185 = Math_fround($183 + $184);
 $186 = Math_fround($165 * $182);
 $187 = Math_fround($186 + $185);
 $188 = $187 < Math_fround(9.99999974737875163555E-6);
 if ($188) {
  $$length122 = $length;
  label = 20;
 } else {
  $center$idx12$val = Math_fround(HEAPF32[$23>>2]);
  $center$idx11$val = Math_fround(HEAPF32[$22>>2]);
  $center$idx$val = Math_fround(HEAPF32[$center>>2]);
  $189 = Math_fround($center$idx$val - $160);
  $190 = Math_fround($center$idx11$val - $163);
  $191 = Math_fround($center$idx12$val - $166);
  $192 = Math_fround($176 * $189);
  $193 = Math_fround($179 * $190);
  $194 = Math_fround($193 + $192);
  $195 = Math_fround($182 * $191);
  $196 = Math_fround($195 + $194);
  $197 = $196 < Math_fround(0.0);
  $198 = $196 > $187;
  $or$cond$i = $197 | $198;
  if ($or$cond$i) {
   $$length122 = $length;
   label = 20;
  } else {
   $199 = Math_fround($165 * $190);
   $200 = Math_fround($162 * $191);
   $201 = Math_fround($199 - $200);
   $202 = Math_fround($159 * $191);
   $203 = Math_fround($165 * $189);
   $204 = Math_fround($202 - $203);
   $205 = Math_fround($162 * $189);
   $206 = Math_fround($159 * $190);
   $207 = Math_fround($205 - $206);
   $208 = Math_fround($124 * $201);
   $209 = Math_fround($128 * $204);
   $210 = Math_fround($208 + $209);
   $211 = Math_fround($133 * $207);
   $212 = Math_fround($211 + $210);
   $213 = $212 < Math_fround(0.0);
   $214 = $212 > $187;
   $or$cond1$i = $213 | $214;
   if ($or$cond1$i) {
    $$length122 = $length;
    label = 20;
   } else {
    $215 = Math_fround($168 * $201);
    $216 = Math_fround($170 * $204);
    $217 = Math_fround($215 + $216);
    $218 = Math_fround($172 * $207);
    $219 = Math_fround($218 + $217);
    $220 = Math_fround(Math_fround(1.0) / $187);
    $221 = Math_fround($219 * $220);
    $222 = $221 >= Math_fround(0.0);
    $223 = $221 < $length;
    $or$cond8 = $222 & $223;
    $$length = $or$cond8 ? $221 : $length;
    if ($or$cond8) {
     $MinDist$3125 = $$length;
    } else {
     $$length122 = $$length;
     label = 20;
    }
   }
  }
 }
 do {
  if ((label|0) == 20) {
   HEAPF32[$Caps>>2] = $77;
   $224 = (($Caps) + 4|0);
   HEAPF32[$224>>2] = $80;
   $225 = (($Caps) + 8|0);
   HEAPF32[$225>>2] = $83;
   $226 = (($Caps) + 12|0);
   HEAPF32[$226>>2] = $85;
   $227 = (($Caps) + 16|0);
   HEAPF32[$227>>2] = $88;
   $228 = (($Caps) + 20|0);
   HEAPF32[$228>>2] = $91;
   $229 = (($Caps) + 24|0);
   HEAPF32[$229>>2] = $4;
   $230 = (($Caps) + 28|0);
   HEAPF32[$230>>2] = $85;
   $231 = (($Caps) + 32|0);
   HEAPF32[$231>>2] = $88;
   $232 = (($Caps) + 36|0);
   HEAPF32[$232>>2] = $91;
   $233 = (($Caps) + 40|0);
   HEAPF32[$233>>2] = $95;
   $234 = (($Caps) + 44|0);
   HEAPF32[$234>>2] = $96;
   $235 = (($Caps) + 48|0);
   HEAPF32[$235>>2] = $97;
   $236 = (($Caps) + 52|0);
   HEAPF32[$236>>2] = $4;
   $237 = (($Caps) + 56|0);
   HEAPF32[$237>>2] = $95;
   $238 = (($Caps) + 60|0);
   HEAPF32[$238>>2] = $96;
   $239 = (($Caps) + 64|0);
   HEAPF32[$239>>2] = $97;
   $240 = (($Caps) + 68|0);
   HEAPF32[$240>>2] = $92;
   $241 = (($Caps) + 72|0);
   HEAPF32[$241>>2] = $93;
   $242 = (($Caps) + 76|0);
   HEAPF32[$242>>2] = $94;
   $243 = (($Caps) + 80|0);
   HEAPF32[$243>>2] = $4;
   $244 = (($Caps) + 84|0);
   HEAPF32[$244>>2] = $77;
   $245 = (($Caps) + 88|0);
   HEAPF32[$245>>2] = $80;
   $246 = (($Caps) + 92|0);
   HEAPF32[$246>>2] = $83;
   $247 = (($Caps) + 96|0);
   HEAPF32[$247>>2] = $92;
   $248 = (($Caps) + 100|0);
   HEAPF32[$248>>2] = $93;
   $249 = (($Caps) + 104|0);
   HEAPF32[$249>>2] = $94;
   $250 = (($Caps) + 108|0);
   HEAPF32[$250>>2] = $4;
   $251 = (($s) + 4|0);
   $252 = (__ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($center,$dir,$Caps,$s)|0);
   $253 = ($252|0)==(0);
   if ($253) {
    $MinDist$2 = $$length122;$Status$2$off0 = 0;
   } else {
    $254 = ($252|0)==(1);
    $255 = Math_fround(HEAPF32[$s>>2]);
    if ($254) {
     $w$0 = $255;
    } else {
     $256 = Math_fround(HEAPF32[$251>>2]);
     $257 = $255 < $256;
     $$ = $257 ? $255 : $256;
     $w$0 = $$;
    }
    $258 = !($w$0 >= Math_fround(0.0));
    $259 = !($w$0 <= $$length122);
    $or$cond9 = $258 | $259;
    $not$or$cond9$demorgan = $258 | $259;
    $not$or$cond9 = $not$or$cond9$demorgan ^ 1;
    $MinDist$1$w$0 = $or$cond9 ? $$length122 : $w$0;
    $MinDist$2 = $MinDist$1$w$0;$Status$2$off0 = $not$or$cond9;
   }
   $260 = (($Caps) + 28|0);
   $261 = (__ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($center,$dir,$260,$s)|0);
   $262 = ($261|0)==(0);
   if ($262) {
    $MinDist$2$1 = $MinDist$2;$Status$2$off0$1 = $Status$2$off0;
   } else {
    $404 = ($261|0)==(1);
    $405 = Math_fround(HEAPF32[$s>>2]);
    if ($404) {
     $w$0$1 = $405;
    } else {
     $406 = Math_fround(HEAPF32[$251>>2]);
     $407 = $405 < $406;
     $$$1 = $407 ? $405 : $406;
     $w$0$1 = $$$1;
    }
    $408 = !($w$0$1 >= Math_fround(0.0));
    $409 = !($w$0$1 <= $MinDist$2);
    $or$cond9$1 = $408 | $409;
    $not$or$cond9$1$demorgan = $408 | $409;
    $not$or$cond9$1 = $not$or$cond9$1$demorgan ^ 1;
    $Status$1$off0$$1 = $Status$2$off0 | $not$or$cond9$1;
    $MinDist$1$w$0$1 = $or$cond9$1 ? $MinDist$2 : $w$0$1;
    $MinDist$2$1 = $MinDist$1$w$0$1;$Status$2$off0$1 = $Status$1$off0$$1;
   }
   $410 = (($Caps) + 56|0);
   $411 = (__ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($center,$dir,$410,$s)|0);
   $412 = ($411|0)==(0);
   if ($412) {
    $MinDist$2$2 = $MinDist$2$1;$Status$2$off0$2 = $Status$2$off0$1;
   } else {
    $413 = ($411|0)==(1);
    $414 = Math_fround(HEAPF32[$s>>2]);
    if ($413) {
     $w$0$2 = $414;
    } else {
     $415 = Math_fround(HEAPF32[$251>>2]);
     $416 = $414 < $415;
     $$$2 = $416 ? $414 : $415;
     $w$0$2 = $$$2;
    }
    $417 = !($w$0$2 >= Math_fround(0.0));
    $418 = !($w$0$2 <= $MinDist$2$1);
    $or$cond9$2 = $417 | $418;
    $not$or$cond9$2$demorgan = $417 | $418;
    $not$or$cond9$2 = $not$or$cond9$2$demorgan ^ 1;
    $Status$1$off0$$2 = $Status$2$off0$1 | $not$or$cond9$2;
    $MinDist$1$w$0$2 = $or$cond9$2 ? $MinDist$2$1 : $w$0$2;
    $MinDist$2$2 = $MinDist$1$w$0$2;$Status$2$off0$2 = $Status$1$off0$$2;
   }
   $419 = (($Caps) + 84|0);
   $420 = (__ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($center,$dir,$419,$s)|0);
   $421 = ($420|0)==(0);
   if ($421) {
    if ($Status$2$off0$2) {
     $MinDist$3125 = $MinDist$2$2;
     break;
    } else {
     $$0 = 0;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $422 = ($420|0)==(1);
   $423 = Math_fround(HEAPF32[$s>>2]);
   if ($422) {
    $w$0$3 = $423;
   } else {
    $424 = Math_fround(HEAPF32[$251>>2]);
    $425 = $423 < $424;
    $$$3 = $425 ? $423 : $424;
    $w$0$3 = $$$3;
   }
   $426 = !($w$0$3 >= Math_fround(0.0));
   $427 = !($w$0$3 <= $MinDist$2$2);
   $or$cond9$3 = $426 | $427;
   $not$or$cond9$3$demorgan = $426 | $427;
   $not$or$cond9$3 = $not$or$cond9$3$demorgan ^ 1;
   $Status$1$off0$$3 = $Status$2$off0$2 | $not$or$cond9$3;
   $MinDist$1$w$0$3 = $or$cond9$3 ? $MinDist$2$2 : $w$0$3;
   if ($Status$1$off0$$3) {
    $MinDist$3125 = $MinDist$1$w$0$3;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP16[$outHintFlags>>1] = 4;
 $263 = $inHintFlags & 3;
 $264 = ($263|0)==(0);
 if (!($264)) {
  $dir$idx25$val = Math_fround(HEAPF32[$dir>>2]);
  $dir$idx26$val = Math_fround(HEAPF32[$127>>2]);
  $dir$idx27$val = Math_fround(HEAPF32[$132>>2]);
  $265 = Math_fround($MinDist$3125 * $dir$idx25$val);
  $266 = Math_fround($MinDist$3125 * $dir$idx26$val);
  $267 = Math_fround($MinDist$3125 * $dir$idx27$val);
  $268 = Math_fround(HEAPF32[$$pre$phi132Z2D>>2]);
  $269 = Math_fround($268 - $265);
  $270 = Math_fround(HEAPF32[$78>>2]);
  $271 = Math_fround($270 - $266);
  $272 = Math_fround(HEAPF32[$81>>2]);
  $273 = Math_fround($272 - $267);
  $274 = Math_fround(HEAPF32[$$pre$phi134Z2D>>2]);
  $275 = Math_fround($274 - $265);
  $276 = Math_fround(HEAPF32[$86>>2]);
  $277 = Math_fround($276 - $266);
  $278 = Math_fround(HEAPF32[$89>>2]);
  $279 = Math_fround($278 - $267);
  $280 = Math_fround($275 - $269);
  $281 = Math_fround($277 - $271);
  $282 = Math_fround($279 - $273);
  $283 = Math_fround(HEAPF32[$6>>2]);
  $284 = Math_fround(HEAPF32[$lss1>>2]);
  $285 = Math_fround($283 - $284);
  $286 = Math_fround(HEAPF32[$11>>2]);
  $287 = Math_fround(HEAPF32[$9>>2]);
  $288 = Math_fround($286 - $287);
  $289 = Math_fround(HEAPF32[$16>>2]);
  $290 = Math_fround(HEAPF32[$14>>2]);
  $291 = Math_fround($289 - $290);
  HEAPF32[$edge1>>2] = $285;
  $292 = (($edge1) + 4|0);
  HEAPF32[$292>>2] = $288;
  $293 = (($edge1) + 8|0);
  HEAPF32[$293>>2] = $291;
  __ZL12edgeEdgeDistRN5physx6PxVec3ES1_RKS0_S3_S3_S3_($x,$y,$269,$271,$273,$280,$281,$282,$$pre$phiZ2D,$edge1);
  $294 = $inHintFlags & 2;
  $295 = ($294|0)==(0);
  if (!($295)) {
   $296 = Math_fround(HEAPF32[$x>>2]);
   $297 = Math_fround(HEAPF32[$y>>2]);
   $298 = Math_fround($296 - $297);
   $299 = (($x) + 4|0);
   $300 = Math_fround(HEAPF32[$299>>2]);
   $301 = (($y) + 4|0);
   $302 = Math_fround(HEAPF32[$301>>2]);
   $303 = Math_fround($300 - $302);
   $304 = (($x) + 8|0);
   $305 = Math_fround(HEAPF32[$304>>2]);
   $306 = (($y) + 8|0);
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = Math_fround($305 - $307);
   HEAPF32[$normal>>2] = $298;
   $309 = (($normal) + 4|0);
   HEAPF32[$309>>2] = $303;
   $310 = (($normal) + 8|0);
   HEAPF32[$310>>2] = $308;
   $311 = Math_fround($298 * $298);
   $312 = Math_fround($303 * $303);
   $313 = Math_fround($311 + $312);
   $314 = Math_fround($308 * $308);
   $315 = Math_fround($314 + $313);
   $316 = (Math_fround(Math_sqrt((Math_fround($315)))));
   $317 = $316 > Math_fround(0.0);
   if ($317) {
    $318 = Math_fround(Math_fround(1.0) / $316);
    $319 = Math_fround($298 * $318);
    HEAPF32[$normal>>2] = $319;
    $320 = Math_fround($303 * $318);
    HEAPF32[$309>>2] = $320;
    $321 = Math_fround($308 * $318);
    HEAPF32[$310>>2] = $321;
   }
   $322 = $316 < Math_fround(0.00100000004749745130539);
   if ($322) {
    $323 = Math_fround(HEAPF32[$292>>2]);
    $324 = Math_fround($282 * $323);
    $325 = Math_fround(HEAPF32[$293>>2]);
    $326 = Math_fround($281 * $325);
    $327 = Math_fround($324 - $326);
    $328 = Math_fround($280 * $325);
    $329 = Math_fround(HEAPF32[$edge1>>2]);
    $330 = Math_fround($282 * $329);
    $331 = Math_fround($328 - $330);
    $332 = Math_fround($281 * $329);
    $333 = Math_fround($280 * $323);
    $334 = Math_fround($332 - $333);
    HEAPF32[$normal>>2] = $327;
    HEAPF32[$309>>2] = $331;
    HEAPF32[$310>>2] = $334;
    $335 = Math_fround($327 * $327);
    $336 = Math_fround($331 * $331);
    $337 = Math_fround($335 + $336);
    $338 = Math_fround($334 * $334);
    $339 = Math_fround($338 + $337);
    $340 = (Math_fround(Math_sqrt((Math_fround($339)))));
    $341 = $340 > Math_fround(0.0);
    if ($341) {
     $342 = Math_fround(Math_fround(1.0) / $340);
     $343 = Math_fround($327 * $342);
     HEAPF32[$normal>>2] = $343;
     $344 = Math_fround($331 * $342);
     HEAPF32[$309>>2] = $344;
     $345 = Math_fround($334 * $342);
     HEAPF32[$310>>2] = $345;
    }
    $346 = $340 < Math_fround(0.00100000004749745130539);
    if ($346) {
     $347 = Math_fround(HEAPF32[$$pre$phi134Z2D>>2]);
     $348 = Math_fround(HEAPF32[$$pre$phi132Z2D>>2]);
     $349 = Math_fround($347 - $348);
     $350 = Math_fround(HEAPF32[$86>>2]);
     $351 = Math_fround(HEAPF32[$78>>2]);
     $352 = Math_fround($350 - $351);
     $353 = Math_fround(HEAPF32[$89>>2]);
     $354 = Math_fround(HEAPF32[$81>>2]);
     $355 = Math_fround($353 - $354);
     __ZL12edgeEdgeDistRN5physx6PxVec3ES1_RKS0_S3_S3_S3_($x,$y,$348,$351,$354,$349,$352,$355,$$pre$phiZ2D,$edge1);
     $356 = Math_fround(HEAPF32[$x>>2]);
     $357 = Math_fround(HEAPF32[$y>>2]);
     $358 = Math_fround($356 - $357);
     $359 = Math_fround(HEAPF32[$299>>2]);
     $360 = Math_fround(HEAPF32[$301>>2]);
     $361 = Math_fround($359 - $360);
     $362 = Math_fround(HEAPF32[$304>>2]);
     $363 = Math_fround(HEAPF32[$306>>2]);
     $364 = Math_fround($362 - $363);
     HEAPF32[$normal>>2] = $358;
     HEAPF32[$309>>2] = $361;
     HEAPF32[$310>>2] = $364;
     $365 = Math_fround($358 * $358);
     $366 = Math_fround($361 * $361);
     $367 = Math_fround($365 + $366);
     $368 = Math_fround($364 * $364);
     $369 = Math_fround($368 + $367);
     $370 = (Math_fround(Math_sqrt((Math_fround($369)))));
     $371 = $370 > Math_fround(0.0);
     if ($371) {
      $372 = Math_fround(Math_fround(1.0) / $370);
      $373 = Math_fround($358 * $372);
      HEAPF32[$normal>>2] = $373;
      $374 = Math_fround($361 * $372);
      HEAPF32[$309>>2] = $374;
      $375 = Math_fround($364 * $372);
      HEAPF32[$310>>2] = $375;
     }
    }
   }
   $376 = HEAP16[$outHintFlags>>1]|0;
   $377 = $376&65535;
   $378 = $377 | 2;
   $379 = $378&65535;
   HEAP16[$outHintFlags>>1] = $379;
  }
  $380 = $inHintFlags & 1;
  $381 = ($380|0)==(0);
  if (!($381)) {
   $382 = Math_fround(HEAPF32[$2>>2]);
   $x$idx$val = Math_fround(HEAPF32[$x>>2]);
   $x$idx21 = (($x) + 4|0);
   $x$idx21$val = Math_fround(HEAPF32[$x$idx21>>2]);
   $x$idx22 = (($x) + 8|0);
   $x$idx22$val = Math_fround(HEAPF32[$x$idx22>>2]);
   $383 = Math_fround($382 * $x$idx$val);
   $384 = Math_fround($382 * $x$idx21$val);
   $385 = Math_fround($382 * $x$idx22$val);
   $386 = Math_fround(HEAPF32[$0>>2]);
   $y$idx$val = Math_fround(HEAPF32[$y>>2]);
   $y$idx19 = (($y) + 4|0);
   $y$idx19$val = Math_fround(HEAPF32[$y$idx19>>2]);
   $y$idx20 = (($y) + 8|0);
   $y$idx20$val = Math_fround(HEAPF32[$y$idx20>>2]);
   $387 = Math_fround($386 * $y$idx$val);
   $388 = Math_fround($386 * $y$idx19$val);
   $389 = Math_fround($386 * $y$idx20$val);
   $390 = Math_fround($383 + $387);
   $391 = Math_fround($384 + $388);
   $392 = Math_fround($385 + $389);
   $393 = Math_fround($382 + $386);
   $394 = Math_fround(Math_fround(1.0) / $393);
   $395 = Math_fround($390 * $394);
   $396 = Math_fround($394 * $391);
   $397 = Math_fround($394 * $392);
   HEAPF32[$ip>>2] = $395;
   $398 = (($ip) + 4|0);
   HEAPF32[$398>>2] = $396;
   $399 = (($ip) + 8|0);
   HEAPF32[$399>>2] = $397;
   $400 = HEAP16[$outHintFlags>>1]|0;
   $401 = $400&65535;
   $402 = $401 | 1;
   $403 = $402&65535;
   HEAP16[$outHintFlags>>1] = $403;
  }
 }
 HEAPF32[$min_dist>>2] = $MinDist$3125;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL12edgeEdgeDistRN5physx6PxVec3ES1_RKS0_S3_S3_S3_($x,$y,$p$0$0$val,$p$0$1$val,$p$0$2$val,$a$0$0$val,$a$0$1$val,$a$0$2$val,$q,$b) {
 $x = $x|0;
 $y = $y|0;
 $p$0$0$val = Math_fround($p$0$0$val);
 $p$0$1$val = Math_fround($p$0$1$val);
 $p$0$2$val = Math_fround($p$0$2$val);
 $a$0$0$val = Math_fround($a$0$0$val);
 $a$0$1$val = Math_fround($a$0$1$val);
 $a$0$2$val = Math_fround($a$0$2$val);
 $q = $q|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $9 = Math_fround(0), $t$0 = Math_fround(0), $t$1 = Math_fround(0), $u$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$q>>2]);
 $1 = Math_fround($0 - $p$0$0$val);
 $2 = (($q) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 - $p$0$1$val);
 $5 = (($q) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 - $p$0$2$val);
 $8 = Math_fround($a$0$0$val * $a$0$0$val);
 $9 = Math_fround($a$0$1$val * $a$0$1$val);
 $10 = Math_fround($8 + $9);
 $11 = Math_fround($a$0$2$val * $a$0$2$val);
 $12 = Math_fround($10 + $11);
 $13 = Math_fround(HEAPF32[$b>>2]);
 $14 = Math_fround($13 * $13);
 $15 = (($b) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($b) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $20);
 $22 = Math_fround($18 + $21);
 $23 = Math_fround($13 * $a$0$0$val);
 $24 = Math_fround($16 * $a$0$1$val);
 $25 = Math_fround($23 + $24);
 $26 = Math_fround($20 * $a$0$2$val);
 $27 = Math_fround($25 + $26);
 $28 = Math_fround($1 * $a$0$0$val);
 $29 = Math_fround($4 * $a$0$1$val);
 $30 = Math_fround($28 + $29);
 $31 = Math_fround($7 * $a$0$2$val);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($1 * $13);
 $34 = Math_fround($4 * $16);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($7 * $20);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($12 * $22);
 $39 = Math_fround($27 * $27);
 $40 = Math_fround($38 - $39);
 $41 = $40 != Math_fround(0.0);
 if ($41) {
  $42 = Math_fround($32 * $22);
  $43 = Math_fround($37 * $27);
  $44 = Math_fround($42 - $43);
  $45 = Math_fround($44 / $40);
  $46 = $45 < Math_fround(0.0);
  if ($46) {
   $t$0 = Math_fround(0.0);
  } else {
   $47 = $45 > Math_fround(1.0);
   if ($47) {
    $t$0 = Math_fround(1.0);
   } else {
    $t$0 = $45;
   }
  }
 } else {
  $t$0 = Math_fround(0.0);
 }
 $48 = $22 != Math_fround(0.0);
 do {
  if ($48) {
   $49 = Math_fround($27 * $t$0);
   $50 = Math_fround($49 - $37);
   $51 = Math_fround($50 / $22);
   $52 = $51 < Math_fround(0.0);
   if ($52) {
    $53 = $12 != Math_fround(0.0);
    if (!($53)) {
     $t$1 = Math_fround(0.0);$u$0 = Math_fround(0.0);
     break;
    }
    $54 = Math_fround($32 / $12);
    $55 = $54 < Math_fround(0.0);
    if ($55) {
     $t$1 = Math_fround(0.0);$u$0 = Math_fround(0.0);
     break;
    }
    $56 = $54 > Math_fround(1.0);
    if (!($56)) {
     $t$1 = $54;$u$0 = Math_fround(0.0);
     break;
    }
    $t$1 = Math_fround(1.0);$u$0 = Math_fround(0.0);
    break;
   }
   $57 = $51 > Math_fround(1.0);
   if ($57) {
    $58 = $12 != Math_fround(0.0);
    if ($58) {
     $59 = Math_fround($32 + $27);
     $60 = Math_fround($59 / $12);
     $61 = $60 < Math_fround(0.0);
     if ($61) {
      $t$1 = Math_fround(0.0);$u$0 = Math_fround(1.0);
     } else {
      $62 = $60 > Math_fround(1.0);
      if ($62) {
       $t$1 = Math_fround(1.0);$u$0 = Math_fround(1.0);
      } else {
       $t$1 = $60;$u$0 = Math_fround(1.0);
      }
     }
    } else {
     $t$1 = Math_fround(0.0);$u$0 = Math_fround(1.0);
    }
   } else {
    $t$1 = $t$0;$u$0 = $51;
   }
  } else {
   $63 = $12 != Math_fround(0.0);
   if ($63) {
    $64 = Math_fround($32 / $12);
    $65 = $64 < Math_fround(0.0);
    if ($65) {
     $t$1 = Math_fround(0.0);$u$0 = Math_fround(0.0);
    } else {
     $66 = $64 > Math_fround(1.0);
     if ($66) {
      $t$1 = Math_fround(1.0);$u$0 = Math_fround(0.0);
     } else {
      $t$1 = $64;$u$0 = Math_fround(0.0);
     }
    }
   } else {
    $t$1 = Math_fround(0.0);$u$0 = Math_fround(0.0);
   }
  }
 } while(0);
 $67 = Math_fround($t$1 * $a$0$0$val);
 $68 = Math_fround($t$1 * $a$0$1$val);
 $69 = Math_fround($t$1 * $a$0$2$val);
 $70 = Math_fround($67 + $p$0$0$val);
 $71 = Math_fround($68 + $p$0$1$val);
 $72 = Math_fround($69 + $p$0$2$val);
 HEAPF32[$x>>2] = $70;
 $73 = (($x) + 4|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($x) + 8|0);
 HEAPF32[$74>>2] = $72;
 $75 = Math_fround(HEAPF32[$b>>2]);
 $76 = Math_fround($u$0 * $75);
 $77 = Math_fround(HEAPF32[$15>>2]);
 $78 = Math_fround($u$0 * $77);
 $79 = Math_fround(HEAPF32[$19>>2]);
 $80 = Math_fround($u$0 * $79);
 $81 = Math_fround(HEAPF32[$q>>2]);
 $82 = Math_fround($76 + $81);
 $83 = Math_fround(HEAPF32[$2>>2]);
 $84 = Math_fround($78 + $83);
 $85 = Math_fround(HEAPF32[$5>>2]);
 $86 = Math_fround($80 + $85);
 HEAPF32[$y>>2] = $82;
 $87 = (($y) + 4|0);
 HEAPF32[$87>>2] = $84;
 $88 = (($y) + 8|0);
 HEAPF32[$88>>2] = $86;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu21sweepCapsuleTrianglesEjPKNS_10PxTriangleERKNS0_7CapsuleERKNS_6PxVec3EfPKjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEERfRS7_SI_RjSF_bPKNS0_3BoxE($nbTris,$triangles,$capsule,$unitDir,$distance,$cachedIndex,$outFlags,$t,$normal,$hit,$hitIndex,$hintFlags,$isDoubleSided,$cullBox) {
 $nbTris = $nbTris|0;
 $triangles = $triangles|0;
 $capsule = $capsule|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $cachedIndex = $cachedIndex|0;
 $outFlags = $outFlags|0;
 $t = $t|0;
 $normal = $normal|0;
 $hit = $hit|0;
 $hitIndex = $hitIndex|0;
 $hintFlags = $hintFlags|0;
 $isDoubleSided = $isDoubleSided|0;
 $cullBox = $cullBox|0;
 var $$1 = 0, $$i$i = 0, $$not$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert116 = 0, $$phi$trans$insert121 = 0, $$phi$trans$insert123 = 0, $$pre$pre = Math_fround(0), $$pre104 = Math_fround(0), $$pre105 = Math_fround(0), $$pre106 = Math_fround(0), $$pre107 = Math_fround(0), $$pre108 = Math_fround(0), $$pre109 = Math_fround(0), $$pre110 = Math_fround(0), $$pre111 = Math_fround(0), $$pre112 = Math_fround(0), $$pre113 = Math_fround(0), $$pre114 = Math_fround(0), $$pre115 = Math_fround(0);
 var $$pre117 = Math_fround(0), $$pre118 = Math_fround(0), $$pre120 = Math_fround(0), $$pre122 = Math_fround(0), $$pre124 = Math_fround(0), $$pre90$pre = Math_fround(0), $$pre91$pre = Math_fround(0), $$pre92$pre = Math_fround(0), $$pre93$pre = Math_fround(0), $$pre94$pre = Math_fround(0), $$pre95 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0);
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0);
 var $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0);
 var $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0);
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0);
 var $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0;
 var $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0);
 var $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0);
 var $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0);
 var $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0);
 var $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0;
 var $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0);
 var $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0);
 var $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0);
 var $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0;
 var $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0;
 var $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0);
 var $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0);
 var $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0);
 var $575 = Math_fround(0), $576 = 0, $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0);
 var $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = 0, $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0);
 var $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = 0, $628 = Math_fround(0);
 var $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = 0, $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = 0, $646 = 0;
 var $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = 0, $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = 0, $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = 0, $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0), $664 = Math_fround(0);
 var $665 = 0, $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = 0, $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = 0, $674 = Math_fround(0), $675 = Math_fround(0), $676 = 0, $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = 0, $681 = Math_fround(0), $682 = Math_fround(0);
 var $683 = Math_fround(0), $684 = 0, $685 = Math_fround(0), $686 = Math_fround(0), $687 = 0, $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = 0, $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = 0, $696 = Math_fround(0), $697 = 0, $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0;
 var $700 = Math_fround(0), $701 = Math_fround(0), $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = 0, $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = 0, $718 = Math_fround(0);
 var $719 = 0, $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = 0, $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0);
 var $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = 0, $744 = 0, $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = 0, $749 = 0, $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0);
 var $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = Math_fround(0), $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = 0, $764 = 0, $765 = 0, $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = 0;
 var $773 = 0, $774 = 0, $775 = 0, $776 = Math_fround(0), $777 = 0, $778 = Math_fround(0), $779 = 0, $78 = 0, $780 = Math_fround(0), $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = Math_fround(0), $786 = 0, $787 = Math_fround(0), $788 = 0, $789 = Math_fround(0), $79 = Math_fround(0), $790 = 0;
 var $791 = 0, $792 = 0, $793 = 0, $794 = Math_fround(0), $795 = 0, $796 = Math_fround(0), $797 = 0, $798 = Math_fround(0), $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = Math_fround(0), $803 = 0, $804 = Math_fround(0), $805 = 0, $806 = Math_fround(0), $807 = 0, $808 = 0;
 var $809 = Math_fround(0), $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0;
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $bestTri = 0, $capsuleCenter = 0, $center = 0, $currentDistance$i = 0, $exitcond = 0, $exitcond87 = 0, $extrudedTris = 0, $extrudedTrisNormals = 0, $fabsf$i$i = Math_fround(0), $i$0$lcssa79 = 0, $i$080 = 0, $i$080$us = 0, $ii$076 = 0, $initIndex$0$i = 0, $j$073 = 0;
 var $or$cond$i = 0, $or$cond$i$i = 0, $or$cond1$i$i = 0, $phitmp = 0, $pointOnSeg = 0, $pointOnTri = 0, $segmentExtent = 0, $sphereCenter = 0, $storemerge = Math_fround(0), $storemerge125 = Math_fround(0), $storemerge126 = Math_fround(0), $tmp = 0, $triangleIndex$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 624|0;
 $currentDistance$i = sp + 608|0;
 $capsuleCenter = sp + 596|0;
 $segmentExtent = sp + 584|0;
 $0 = sp + 572|0;
 $1 = sp + 560|0;
 $sphereCenter = sp + 548|0;
 $extrudedTris = sp + 296|0;
 $extrudedTrisNormals = sp + 212|0;
 $bestTri = sp + 176|0;
 $tmp = sp + 140|0;
 $center = sp + 128|0;
 $pointOnSeg = sp;
 $pointOnTri = sp + 16|0;
 $2 = sp + 32|0;
 $3 = sp + 48|0;
 $4 = sp + 80|0;
 $5 = sp + 96|0;
 $6 = sp + 112|0;
 $7 = sp + 64|0;
 $8 = ($nbTris|0)==(0);
 if ($8) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $9 = Math_fround(HEAPF32[$capsule>>2]);
 $10 = (($capsule) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 + $11);
 $13 = (($capsule) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($capsule) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 + $16);
 $18 = (($capsule) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($capsule) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($19 + $21);
 $23 = Math_fround($12 * Math_fround(0.5));
 $24 = Math_fround($17 * Math_fround(0.5));
 $25 = Math_fround($22 * Math_fround(0.5));
 HEAPF32[$capsuleCenter>>2] = $23;
 $26 = (($capsuleCenter) + 4|0);
 HEAPF32[$26>>2] = $24;
 $27 = (($capsuleCenter) + 8|0);
 HEAPF32[$27>>2] = $25;
 $28 = HEAP16[$hintFlags>>1]|0;
 $29 = $28 & 16;
 $30 = ($29<<16>>16)==(0);
 do {
  if ($30) {
   $31 = Math_fround($11 - $9);
   $32 = Math_fround($16 - $14);
   $33 = Math_fround($21 - $19);
   HEAPF32[$segmentExtent>>2] = $31;
   $34 = (($segmentExtent) + 4|0);
   HEAPF32[$34>>2] = $32;
   $35 = (($segmentExtent) + 8|0);
   HEAPF32[$35>>2] = $33;
   $36 = (($capsule) + 24|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = Math_fround($37 * $37);
   $39 = (($0) + 4|0);
   $40 = (($0) + 8|0);
   $41 = (($1) + 4|0);
   $42 = (($1) + 8|0);
   $43 = (($unitDir) + 4|0);
   $44 = (($unitDir) + 8|0);
   L6: do {
    if ($isDoubleSided) {
     $i$080$us = 0;
     while(1) {
      $45 = (($triangles) + (($i$080$us*36)|0)|0);
      $46 = ((($triangles) + (($i$080$us*36)|0)|0) + 12|0);
      $47 = Math_fround(HEAPF32[$46>>2]);
      $48 = Math_fround(HEAPF32[$45>>2]);
      $49 = Math_fround($47 - $48);
      $50 = ((($triangles) + (($i$080$us*36)|0)|0) + 16|0);
      $51 = Math_fround(HEAPF32[$50>>2]);
      $52 = ((($triangles) + (($i$080$us*36)|0)|0) + 4|0);
      $53 = Math_fround(HEAPF32[$52>>2]);
      $54 = Math_fround($51 - $53);
      $55 = ((($triangles) + (($i$080$us*36)|0)|0) + 20|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      $57 = ((($triangles) + (($i$080$us*36)|0)|0) + 8|0);
      $58 = Math_fround(HEAPF32[$57>>2]);
      $59 = Math_fround($56 - $58);
      HEAPF32[$0>>2] = $49;
      HEAPF32[$39>>2] = $54;
      HEAPF32[$40>>2] = $59;
      $60 = ((($triangles) + (($i$080$us*36)|0)|0) + 24|0);
      $61 = Math_fround(HEAPF32[$60>>2]);
      $62 = Math_fround($61 - $48);
      $63 = ((($triangles) + (($i$080$us*36)|0)|0) + 28|0);
      $64 = Math_fround(HEAPF32[$63>>2]);
      $65 = Math_fround($64 - $53);
      $66 = ((($triangles) + (($i$080$us*36)|0)|0) + 32|0);
      $67 = Math_fround(HEAPF32[$66>>2]);
      $68 = Math_fround($67 - $58);
      HEAPF32[$1>>2] = $62;
      HEAPF32[$41>>2] = $65;
      HEAPF32[$42>>2] = $68;
      $69 = (Math_fround(__ZN5physx2Gu30distanceSegmentTriangleSquaredERKNS_6PxVec3ES3_S3_S3_S3_PfS4_S4_($capsule,$segmentExtent,$45,$0,$1,0,0,0)));
      $70 = !($69 <= $38);
      if (!($70)) {
       $i$0$lcssa79 = $i$080$us;
       break L6;
      }
      $71 = (($i$080$us) + 1)|0;
      $72 = ($71>>>0)<($nbTris>>>0);
      if ($72) {
       $i$080$us = $71;
      } else {
       label = 10;
       break;
      }
     }
    } else {
     $i$080 = 0;
     while(1) {
      $73 = (($triangles) + (($i$080*36)|0)|0);
      $74 = ((($triangles) + (($i$080*36)|0)|0) + 12|0);
      $75 = Math_fround(HEAPF32[$74>>2]);
      $76 = Math_fround(HEAPF32[$73>>2]);
      $77 = Math_fround($75 - $76);
      $78 = ((($triangles) + (($i$080*36)|0)|0) + 16|0);
      $79 = Math_fround(HEAPF32[$78>>2]);
      $80 = ((($triangles) + (($i$080*36)|0)|0) + 4|0);
      $81 = Math_fround(HEAPF32[$80>>2]);
      $82 = Math_fround($79 - $81);
      $83 = ((($triangles) + (($i$080*36)|0)|0) + 20|0);
      $84 = Math_fround(HEAPF32[$83>>2]);
      $85 = ((($triangles) + (($i$080*36)|0)|0) + 8|0);
      $86 = Math_fround(HEAPF32[$85>>2]);
      $87 = Math_fround($84 - $86);
      $88 = ((($triangles) + (($i$080*36)|0)|0) + 24|0);
      $89 = Math_fround(HEAPF32[$88>>2]);
      $90 = Math_fround($89 - $76);
      $91 = ((($triangles) + (($i$080*36)|0)|0) + 28|0);
      $92 = Math_fround(HEAPF32[$91>>2]);
      $93 = Math_fround($92 - $81);
      $94 = ((($triangles) + (($i$080*36)|0)|0) + 32|0);
      $95 = Math_fround(HEAPF32[$94>>2]);
      $96 = Math_fround($95 - $86);
      $97 = Math_fround($82 * $90);
      $98 = Math_fround($77 * $93);
      $99 = Math_fround($77 * $96);
      $100 = Math_fround($87 * $90);
      $101 = Math_fround($87 * $93);
      $102 = Math_fround($82 * $96);
      $103 = Math_fround($98 - $97);
      $104 = Math_fround($100 - $99);
      $105 = Math_fround($102 - $101);
      $106 = Math_fround(HEAPF32[$unitDir>>2]);
      $107 = Math_fround($105 * $106);
      $108 = Math_fround(HEAPF32[$43>>2]);
      $109 = Math_fround($104 * $108);
      $110 = Math_fround($107 + $109);
      $111 = Math_fround(HEAPF32[$44>>2]);
      $112 = Math_fround($103 * $111);
      $113 = Math_fround($110 + $112);
      $114 = $113 > Math_fround(0.0);
      if (!($114)) {
       HEAPF32[$0>>2] = $77;
       HEAPF32[$39>>2] = $82;
       HEAPF32[$40>>2] = $87;
       HEAPF32[$1>>2] = $90;
       HEAPF32[$41>>2] = $93;
       HEAPF32[$42>>2] = $96;
       $115 = (Math_fround(__ZN5physx2Gu30distanceSegmentTriangleSquaredERKNS_6PxVec3ES3_S3_S3_S3_PfS4_S4_($capsule,$segmentExtent,$73,$0,$1,0,0,0)));
       $116 = !($115 <= $38);
       if (!($116)) {
        $i$0$lcssa79 = $i$080;
        break L6;
       }
      }
      $125 = (($i$080) + 1)|0;
      $126 = ($125>>>0)<($nbTris>>>0);
      if ($126) {
       $i$080 = $125;
      } else {
       label = 10;
       break;
      }
     }
    }
   } while(0);
   if ((label|0) == 10) {
    $$pre$pre = Math_fround(HEAPF32[$capsule>>2]);
    $$pre90$pre = Math_fround(HEAPF32[$10>>2]);
    $$pre91$pre = Math_fround(HEAPF32[$13>>2]);
    $$pre92$pre = Math_fround(HEAPF32[$15>>2]);
    $$pre93$pre = Math_fround(HEAPF32[$18>>2]);
    $$pre94$pre = Math_fround(HEAPF32[$20>>2]);
    $128 = $$pre90$pre;$129 = $$pre$pre;$131 = $$pre92$pre;$132 = $$pre91$pre;$134 = $$pre94$pre;$135 = $$pre93$pre;
    break;
   }
   HEAP32[$hitIndex>>2] = $i$0$lcssa79;
   HEAPF32[$t>>2] = Math_fround(0.0);
   $117 = Math_fround(HEAPF32[$unitDir>>2]);
   $118 = Math_fround(-$117);
   $119 = Math_fround(HEAPF32[$43>>2]);
   $120 = Math_fround(-$119);
   $121 = Math_fround(HEAPF32[$44>>2]);
   $122 = Math_fround(-$121);
   HEAPF32[$normal>>2] = $118;
   $123 = (($normal) + 4|0);
   HEAPF32[$123>>2] = $120;
   $124 = (($normal) + 8|0);
   HEAPF32[$124>>2] = $122;
   HEAP16[$outFlags>>1] = 6;
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  } else {
   $128 = $11;$129 = $9;$131 = $16;$132 = $14;$134 = $21;$135 = $19;
  }
 } while(0);
 $127 = Math_fround($129 - $128);
 $130 = Math_fround($132 - $131);
 $133 = Math_fround($135 - $134);
 $136 = Math_fround($127 * Math_fround(0.5));
 $137 = Math_fround($130 * Math_fround(0.5));
 $138 = Math_fround($133 * Math_fround(0.5));
 $139 = Math_fround($136 * $136);
 $140 = Math_fround($137 * $137);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($138 * $138);
 $143 = Math_fround($141 + $142);
 $144 = (Math_fround(Math_sqrt((Math_fround($143)))));
 $145 = $144 != Math_fround(0.0);
 if ($145) {
  $146 = Math_fround(Math_fround(1.0) / $144);
  $147 = Math_fround($136 * $146);
  $148 = Math_fround($137 * $146);
  $149 = Math_fround($138 * $146);
  $150 = Math_fround(HEAPF32[$unitDir>>2]);
  $151 = Math_fround($147 * $150);
  $152 = (($unitDir) + 4|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  $154 = Math_fround($148 * $153);
  $155 = Math_fround($151 + $154);
  $156 = (($unitDir) + 8|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = Math_fround($149 * $157);
  $159 = Math_fround($155 + $158);
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($159)))));
  $160 = $fabsf$i$i < Math_fround(0.999989986419677734375);
  if ($160) {
   HEAP32[$hitIndex>>2] = -1;
   $178 = ($cachedIndex|0)==(0|0);
   if ($178) {
    $initIndex$0$i = 0;
   } else {
    $179 = HEAP32[$cachedIndex>>2]|0;
    $initIndex$0$i = $179;
   }
   $180 = (($capsule) + 24|0);
   $181 = Math_fround(HEAPF32[$180>>2]);
   $182 = Math_fround(HEAPF32[$capsuleCenter>>2]);
   $183 = Math_fround($182 * $150);
   $184 = Math_fround(HEAPF32[$26>>2]);
   $185 = Math_fround($184 * $153);
   $186 = Math_fround($183 + $185);
   $187 = Math_fround(HEAPF32[$27>>2]);
   $188 = Math_fround($187 * $157);
   $189 = Math_fround($186 + $188);
   $190 = ($cullBox|0)==(0|0);
   $191 = (($extrudedTris) + 4|0);
   $192 = (($extrudedTris) + 8|0);
   $193 = (($extrudedTris) + 12|0);
   $194 = (($extrudedTris) + 16|0);
   $195 = (($extrudedTris) + 20|0);
   $196 = (($extrudedTris) + 24|0);
   $197 = (($extrudedTris) + 28|0);
   $198 = (($extrudedTris) + 32|0);
   $199 = (($extrudedTrisNormals) + 4|0);
   $200 = (($extrudedTrisNormals) + 8|0);
   $201 = (($extrudedTris) + 36|0);
   $202 = (($extrudedTris) + 40|0);
   $203 = (($extrudedTris) + 44|0);
   $204 = (($extrudedTris) + 48|0);
   $205 = (($extrudedTris) + 52|0);
   $206 = (($extrudedTris) + 56|0);
   $207 = (($extrudedTris) + 60|0);
   $208 = (($extrudedTris) + 64|0);
   $209 = (($extrudedTris) + 68|0);
   $210 = (($extrudedTrisNormals) + 12|0);
   $211 = (($extrudedTrisNormals) + 16|0);
   $212 = (($extrudedTrisNormals) + 20|0);
   $213 = (($extrudedTris) + 72|0);
   $214 = (($extrudedTris) + 76|0);
   $215 = (($extrudedTris) + 80|0);
   $216 = (($extrudedTris) + 84|0);
   $217 = (($extrudedTris) + 88|0);
   $218 = (($extrudedTris) + 92|0);
   $219 = (($extrudedTris) + 96|0);
   $220 = (($extrudedTris) + 100|0);
   $221 = (($extrudedTris) + 104|0);
   $222 = (($extrudedTrisNormals) + 24|0);
   $223 = (($extrudedTrisNormals) + 28|0);
   $224 = (($extrudedTrisNormals) + 32|0);
   $225 = (($extrudedTris) + 108|0);
   $226 = (($extrudedTris) + 112|0);
   $227 = (($extrudedTris) + 116|0);
   $228 = (($extrudedTris) + 120|0);
   $229 = (($extrudedTris) + 124|0);
   $230 = (($extrudedTris) + 128|0);
   $231 = (($extrudedTris) + 132|0);
   $232 = (($extrudedTris) + 136|0);
   $233 = (($extrudedTris) + 140|0);
   $234 = (($extrudedTrisNormals) + 36|0);
   $235 = (($extrudedTrisNormals) + 40|0);
   $236 = (($extrudedTrisNormals) + 44|0);
   $237 = (($extrudedTris) + 144|0);
   $238 = (($extrudedTris) + 148|0);
   $239 = (($extrudedTris) + 152|0);
   $240 = (($extrudedTris) + 156|0);
   $241 = (($extrudedTris) + 160|0);
   $242 = (($extrudedTris) + 164|0);
   $243 = (($extrudedTris) + 168|0);
   $244 = (($extrudedTris) + 172|0);
   $245 = (($extrudedTris) + 176|0);
   $246 = (($extrudedTrisNormals) + 48|0);
   $247 = (($extrudedTrisNormals) + 52|0);
   $248 = (($extrudedTrisNormals) + 56|0);
   $249 = (($extrudedTris) + 180|0);
   $250 = (($extrudedTris) + 184|0);
   $251 = (($extrudedTris) + 188|0);
   $252 = (($extrudedTris) + 192|0);
   $253 = (($extrudedTris) + 196|0);
   $254 = (($extrudedTris) + 200|0);
   $255 = (($extrudedTris) + 204|0);
   $256 = (($extrudedTris) + 208|0);
   $257 = (($extrudedTris) + 212|0);
   $258 = (($extrudedTrisNormals) + 60|0);
   $259 = (($extrudedTrisNormals) + 64|0);
   $260 = (($extrudedTrisNormals) + 68|0);
   $261 = (($extrudedTris) + 216|0);
   $262 = (($extrudedTris) + 220|0);
   $263 = (($extrudedTris) + 224|0);
   $264 = (($extrudedTris) + 228|0);
   $265 = (($extrudedTris) + 232|0);
   $266 = (($extrudedTris) + 236|0);
   $267 = (($extrudedTris) + 240|0);
   $268 = (($extrudedTris) + 244|0);
   $269 = (($extrudedTris) + 248|0);
   $270 = (($extrudedTrisNormals) + 72|0);
   $271 = (($extrudedTrisNormals) + 76|0);
   $272 = (($extrudedTrisNormals) + 80|0);
   $273 = (($bestTri) + 4|0);
   $274 = (($bestTri) + 8|0);
   $275 = (($bestTri) + 12|0);
   $276 = (($bestTri) + 16|0);
   $277 = (($bestTri) + 20|0);
   $278 = (($bestTri) + 24|0);
   $279 = (($bestTri) + 28|0);
   $280 = (($bestTri) + 32|0);
   $281 = (($cullBox) + 36|0);
   $282 = (($cullBox) + 40|0);
   $283 = (($cullBox) + 44|0);
   $284 = (($cullBox) + 4|0);
   $285 = (($cullBox) + 8|0);
   $286 = (($cullBox) + 12|0);
   $287 = (($cullBox) + 16|0);
   $288 = (($cullBox) + 20|0);
   $289 = (($cullBox) + 24|0);
   $290 = (($cullBox) + 28|0);
   $291 = (($cullBox) + 32|0);
   $292 = (($tmp) + 4|0);
   $293 = (($tmp) + 8|0);
   $294 = (($tmp) + 12|0);
   $295 = (($tmp) + 16|0);
   $296 = (($tmp) + 20|0);
   $297 = (($tmp) + 24|0);
   $298 = (($tmp) + 28|0);
   $299 = (($tmp) + 32|0);
   $300 = (($center) + 4|0);
   $301 = (($center) + 8|0);
   $302 = (($cullBox) + 48|0);
   $809 = Math_fround(0.0);$810 = $distance;$ii$076 = 0;
   while(1) {
    $303 = ($ii$076|0)==(0);
    if ($303) {
     $triangleIndex$0$i = $initIndex$0$i;
    } else {
     $304 = ($ii$076|0)==($initIndex$0$i|0);
     $$i$i = $304 ? 0 : $ii$076;
     $triangleIndex$0$i = $$i$i;
    }
    $305 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 12|0);
    $306 = Math_fround(HEAPF32[$305>>2]);
    $307 = (($triangles) + (($triangleIndex$0$i*36)|0)|0);
    $308 = Math_fround(HEAPF32[$307>>2]);
    $309 = Math_fround($306 - $308);
    $310 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 16|0);
    $311 = Math_fround(HEAPF32[$310>>2]);
    $312 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 4|0);
    $313 = Math_fround(HEAPF32[$312>>2]);
    $314 = Math_fround($311 - $313);
    $315 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 20|0);
    $316 = Math_fround(HEAPF32[$315>>2]);
    $317 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 8|0);
    $318 = Math_fround(HEAPF32[$317>>2]);
    $319 = Math_fround($316 - $318);
    $320 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 24|0);
    $321 = Math_fround(HEAPF32[$320>>2]);
    $322 = Math_fround($321 - $308);
    $323 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 28|0);
    $324 = Math_fround(HEAPF32[$323>>2]);
    $325 = Math_fround($324 - $313);
    $326 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 32|0);
    $327 = Math_fround(HEAPF32[$326>>2]);
    $328 = Math_fround($327 - $318);
    $329 = Math_fround($314 * $328);
    $330 = Math_fround($319 * $325);
    $331 = Math_fround($329 - $330);
    $332 = Math_fround($319 * $322);
    $333 = Math_fround($309 * $328);
    $334 = Math_fround($332 - $333);
    $335 = Math_fround($309 * $325);
    $336 = Math_fround($314 * $322);
    $337 = Math_fround($335 - $336);
    if ($isDoubleSided) {
     label = 22;
    } else {
     $338 = Math_fround(HEAPF32[$unitDir>>2]);
     $339 = Math_fround($331 * $338);
     $340 = Math_fround(HEAPF32[$152>>2]);
     $341 = Math_fround($334 * $340);
     $342 = Math_fround($339 + $341);
     $343 = Math_fround(HEAPF32[$156>>2]);
     $344 = Math_fround($337 * $343);
     $345 = Math_fround($342 + $344);
     $346 = $345 > Math_fround(0.0);
     if ($346) {
      $746 = $809;$747 = $810;
     } else {
      label = 22;
     }
    }
    L33: do {
     if ((label|0) == 22) {
      label = 0;
      if ($190) {
       $416 = $308;$418 = $313;$420 = $318;$422 = $306;$424 = $311;$426 = $316;$428 = $321;$430 = $324;$432 = $327;
      } else {
       $347 = Math_fround(HEAPF32[$281>>2]);
       $348 = Math_fround($308 - $347);
       $349 = Math_fround(HEAPF32[$282>>2]);
       $350 = Math_fround($313 - $349);
       $351 = Math_fround(HEAPF32[$283>>2]);
       $352 = Math_fround($318 - $351);
       $353 = Math_fround(HEAPF32[$cullBox>>2]);
       $354 = Math_fround($348 * $353);
       $355 = Math_fround(HEAPF32[$284>>2]);
       $356 = Math_fround($350 * $355);
       $357 = Math_fround($354 + $356);
       $358 = Math_fround(HEAPF32[$285>>2]);
       $359 = Math_fround($352 * $358);
       $360 = Math_fround($357 + $359);
       $361 = Math_fround(HEAPF32[$286>>2]);
       $362 = Math_fround($348 * $361);
       $363 = Math_fround(HEAPF32[$287>>2]);
       $364 = Math_fround($350 * $363);
       $365 = Math_fround($362 + $364);
       $366 = Math_fround(HEAPF32[$288>>2]);
       $367 = Math_fround($352 * $366);
       $368 = Math_fround($365 + $367);
       $369 = Math_fround(HEAPF32[$289>>2]);
       $370 = Math_fround($348 * $369);
       $371 = Math_fround(HEAPF32[$290>>2]);
       $372 = Math_fround($350 * $371);
       $373 = Math_fround($370 + $372);
       $374 = Math_fround(HEAPF32[$291>>2]);
       $375 = Math_fround($352 * $374);
       $376 = Math_fround($373 + $375);
       HEAPF32[$tmp>>2] = $360;
       HEAPF32[$292>>2] = $368;
       HEAPF32[$293>>2] = $376;
       $377 = Math_fround($306 - $347);
       $378 = Math_fround($311 - $349);
       $379 = Math_fround($316 - $351);
       $380 = Math_fround($377 * $353);
       $381 = Math_fround($378 * $355);
       $382 = Math_fround($380 + $381);
       $383 = Math_fround($379 * $358);
       $384 = Math_fround($382 + $383);
       $385 = Math_fround($377 * $361);
       $386 = Math_fround($378 * $363);
       $387 = Math_fround($385 + $386);
       $388 = Math_fround($379 * $366);
       $389 = Math_fround($387 + $388);
       $390 = Math_fround($377 * $369);
       $391 = Math_fround($378 * $371);
       $392 = Math_fround($390 + $391);
       $393 = Math_fround($379 * $374);
       $394 = Math_fround($392 + $393);
       HEAPF32[$294>>2] = $384;
       HEAPF32[$295>>2] = $389;
       HEAPF32[$296>>2] = $394;
       $395 = Math_fround($321 - $347);
       $396 = Math_fround($324 - $349);
       $397 = Math_fround($327 - $351);
       $398 = Math_fround($395 * $353);
       $399 = Math_fround($396 * $355);
       $400 = Math_fround($398 + $399);
       $401 = Math_fround($397 * $358);
       $402 = Math_fround($400 + $401);
       $403 = Math_fround($395 * $361);
       $404 = Math_fround($396 * $363);
       $405 = Math_fround($403 + $404);
       $406 = Math_fround($397 * $366);
       $407 = Math_fround($405 + $406);
       $408 = Math_fround($395 * $369);
       $409 = Math_fround($396 * $371);
       $410 = Math_fround($408 + $409);
       $411 = Math_fround($397 * $374);
       $412 = Math_fround($410 + $411);
       HEAPF32[$297>>2] = $402;
       HEAPF32[$298>>2] = $407;
       HEAPF32[$299>>2] = $412;
       HEAPF32[$center>>2] = Math_fround(0.0);
       HEAPF32[$300>>2] = Math_fround(0.0);
       HEAPF32[$301>>2] = Math_fround(0.0);
       $413 = (__ZN5physx2Gu20intersectTriangleBoxERKNS_6PxVec3ES3_S3_S3_S3_($center,$302,$tmp,$294,$297)|0);
       $414 = ($413|0)==(0);
       if ($414) {
        $746 = $809;$747 = $810;
        break;
       }
       $$pre104 = Math_fround(HEAPF32[$307>>2]);
       $$pre105 = Math_fround(HEAPF32[$312>>2]);
       $$pre106 = Math_fround(HEAPF32[$317>>2]);
       $$pre107 = Math_fround(HEAPF32[$305>>2]);
       $$pre108 = Math_fround(HEAPF32[$310>>2]);
       $$pre109 = Math_fround(HEAPF32[$315>>2]);
       $$pre110 = Math_fround(HEAPF32[$320>>2]);
       $$pre111 = Math_fround(HEAPF32[$323>>2]);
       $$pre112 = Math_fround(HEAPF32[$326>>2]);
       $416 = $$pre104;$418 = $$pre105;$420 = $$pre106;$422 = $$pre107;$424 = $$pre108;$426 = $$pre109;$428 = $$pre110;$430 = $$pre111;$432 = $$pre112;
      }
      $415 = Math_fround($136 + $416);
      $417 = Math_fround($137 + $418);
      $419 = Math_fround($138 + $420);
      $421 = Math_fround($136 + $422);
      $423 = Math_fround($137 + $424);
      $425 = Math_fround($138 + $426);
      $427 = Math_fround($136 + $428);
      $429 = Math_fround($137 + $430);
      $431 = Math_fround($138 + $432);
      $433 = Math_fround($416 - $136);
      $434 = Math_fround($418 - $137);
      $435 = Math_fround($420 - $138);
      $436 = Math_fround($422 - $136);
      $437 = Math_fround($424 - $137);
      $438 = Math_fround($426 - $138);
      $439 = Math_fround($428 - $136);
      $440 = Math_fround($430 - $137);
      $441 = Math_fround($432 - $138);
      $442 = Math_fround($136 * $331);
      $443 = Math_fround($137 * $334);
      $444 = Math_fround($442 + $443);
      $445 = Math_fround($138 * $337);
      $446 = Math_fround($445 + $444);
      $447 = !($446 >= Math_fround(0.0));
      if ($447) {
       HEAPF32[$extrudedTris>>2] = $433;
       HEAPF32[$191>>2] = $434;
       HEAPF32[$192>>2] = $435;
       HEAPF32[$193>>2] = $436;
       HEAPF32[$194>>2] = $437;
       HEAPF32[$195>>2] = $438;
       HEAPF32[$196>>2] = $439;
       HEAPF32[$197>>2] = $440;
       HEAPF32[$198>>2] = $441;
       $463 = Math_fround($436 - $433);
       $464 = Math_fround($437 - $434);
       $465 = Math_fround($438 - $435);
       $466 = Math_fround($439 - $433);
       $467 = Math_fround($440 - $434);
       $468 = Math_fround($441 - $435);
       $469 = Math_fround($464 * $468);
       $470 = Math_fround($465 * $467);
       $471 = Math_fround($469 - $470);
       $472 = Math_fround($465 * $466);
       $473 = Math_fround($463 * $468);
       $474 = Math_fround($472 - $473);
       $475 = Math_fround($463 * $467);
       $476 = Math_fround($464 * $466);
       $477 = Math_fround($475 - $476);
       $storemerge = $477;$storemerge125 = $474;$storemerge126 = $471;
      } else {
       HEAPF32[$extrudedTris>>2] = $415;
       HEAPF32[$191>>2] = $417;
       HEAPF32[$192>>2] = $419;
       HEAPF32[$193>>2] = $421;
       HEAPF32[$194>>2] = $423;
       HEAPF32[$195>>2] = $425;
       HEAPF32[$196>>2] = $427;
       HEAPF32[$197>>2] = $429;
       HEAPF32[$198>>2] = $431;
       $448 = Math_fround($421 - $415);
       $449 = Math_fround($423 - $417);
       $450 = Math_fround($425 - $419);
       $451 = Math_fround($427 - $415);
       $452 = Math_fround($429 - $417);
       $453 = Math_fround($431 - $419);
       $454 = Math_fround($449 * $453);
       $455 = Math_fround($450 * $452);
       $456 = Math_fround($454 - $455);
       $457 = Math_fround($450 * $451);
       $458 = Math_fround($448 * $453);
       $459 = Math_fround($457 - $458);
       $460 = Math_fround($448 * $452);
       $461 = Math_fround($449 * $451);
       $462 = Math_fround($460 - $461);
       $storemerge = $462;$storemerge125 = $459;$storemerge126 = $456;
      }
      HEAPF32[$extrudedTrisNormals>>2] = $storemerge126;
      HEAPF32[$199>>2] = $storemerge125;
      HEAPF32[$200>>2] = $storemerge;
      HEAPF32[$201>>2] = $436;
      HEAPF32[$202>>2] = $437;
      HEAPF32[$203>>2] = $438;
      HEAPF32[$204>>2] = $421;
      HEAPF32[$205>>2] = $423;
      HEAPF32[$206>>2] = $425;
      HEAPF32[$207>>2] = $427;
      HEAPF32[$208>>2] = $429;
      HEAPF32[$209>>2] = $431;
      $478 = Math_fround($421 - $436);
      $479 = Math_fround($423 - $437);
      $480 = Math_fround($425 - $438);
      $481 = Math_fround($427 - $436);
      $482 = Math_fround($429 - $437);
      $483 = Math_fround($431 - $438);
      $484 = Math_fround($479 * $483);
      $485 = Math_fround($480 * $482);
      $486 = Math_fround($484 - $485);
      $487 = Math_fround($480 * $481);
      $488 = Math_fround($478 * $483);
      $489 = Math_fround($487 - $488);
      $490 = Math_fround($478 * $482);
      $491 = Math_fround($479 * $481);
      $492 = Math_fround($490 - $491);
      $493 = Math_fround(HEAPF32[$unitDir>>2]);
      $494 = Math_fround($493 * $486);
      $495 = Math_fround(HEAPF32[$152>>2]);
      $496 = Math_fround($495 * $489);
      $497 = Math_fround($494 + $496);
      $498 = Math_fround(HEAPF32[$156>>2]);
      $499 = Math_fround($492 * $498);
      $500 = Math_fround($499 + $497);
      $501 = $500 > Math_fround(0.0);
      if ($501) {
       HEAPF32[$204>>2] = $427;
       HEAPF32[$205>>2] = $429;
       HEAPF32[$206>>2] = $431;
       HEAPF32[$207>>2] = $421;
       HEAPF32[$208>>2] = $423;
       HEAPF32[$209>>2] = $425;
       $502 = Math_fround(-$486);
       $503 = Math_fround(-$489);
       $504 = Math_fround(-$492);
       $505 = $502;$506 = $503;$507 = $504;
      } else {
       $505 = $486;$506 = $489;$507 = $492;
      }
      HEAPF32[$210>>2] = $505;
      HEAPF32[$211>>2] = $506;
      HEAPF32[$212>>2] = $507;
      HEAPF32[$213>>2] = $436;
      HEAPF32[$214>>2] = $437;
      HEAPF32[$215>>2] = $438;
      HEAPF32[$216>>2] = $427;
      HEAPF32[$217>>2] = $429;
      HEAPF32[$218>>2] = $431;
      HEAPF32[$219>>2] = $439;
      HEAPF32[$220>>2] = $440;
      HEAPF32[$221>>2] = $441;
      $508 = Math_fround($439 - $436);
      $509 = Math_fround($440 - $437);
      $510 = Math_fround($441 - $438);
      $511 = Math_fround($482 * $510);
      $512 = Math_fround($483 * $509);
      $513 = Math_fround($511 - $512);
      $514 = Math_fround($483 * $508);
      $515 = Math_fround($481 * $510);
      $516 = Math_fround($514 - $515);
      $517 = Math_fround($481 * $509);
      $518 = Math_fround($482 * $508);
      $519 = Math_fround($517 - $518);
      $520 = Math_fround($493 * $513);
      $521 = Math_fround($495 * $516);
      $522 = Math_fround($520 + $521);
      $523 = Math_fround($519 * $498);
      $524 = Math_fround($523 + $522);
      $525 = $524 > Math_fround(0.0);
      if ($525) {
       HEAPF32[$216>>2] = $439;
       HEAPF32[$217>>2] = $440;
       HEAPF32[$218>>2] = $441;
       HEAPF32[$219>>2] = $427;
       HEAPF32[$220>>2] = $429;
       HEAPF32[$221>>2] = $431;
       $526 = Math_fround(-$513);
       $527 = Math_fround(-$516);
       $528 = Math_fround(-$519);
       $529 = $526;$530 = $527;$531 = $528;
      } else {
       $529 = $513;$530 = $516;$531 = $519;
      }
      HEAPF32[$222>>2] = $529;
      HEAPF32[$223>>2] = $530;
      HEAPF32[$224>>2] = $531;
      HEAPF32[$225>>2] = $433;
      HEAPF32[$226>>2] = $434;
      HEAPF32[$227>>2] = $435;
      HEAPF32[$228>>2] = $439;
      HEAPF32[$229>>2] = $440;
      HEAPF32[$230>>2] = $441;
      HEAPF32[$231>>2] = $427;
      HEAPF32[$232>>2] = $429;
      HEAPF32[$233>>2] = $431;
      $532 = Math_fround($439 - $433);
      $533 = Math_fround($440 - $434);
      $534 = Math_fround($441 - $435);
      $535 = Math_fround($427 - $433);
      $536 = Math_fround($429 - $434);
      $537 = Math_fround($431 - $435);
      $538 = Math_fround($533 * $537);
      $539 = Math_fround($534 * $536);
      $540 = Math_fround($538 - $539);
      $541 = Math_fround($534 * $535);
      $542 = Math_fround($532 * $537);
      $543 = Math_fround($541 - $542);
      $544 = Math_fround($532 * $536);
      $545 = Math_fround($533 * $535);
      $546 = Math_fround($544 - $545);
      $547 = Math_fround($493 * $540);
      $548 = Math_fround($495 * $543);
      $549 = Math_fround($547 + $548);
      $550 = Math_fround($546 * $498);
      $551 = Math_fround($550 + $549);
      $552 = $551 > Math_fround(0.0);
      if ($552) {
       HEAPF32[$228>>2] = $427;
       HEAPF32[$229>>2] = $429;
       HEAPF32[$230>>2] = $431;
       HEAPF32[$231>>2] = $439;
       HEAPF32[$232>>2] = $440;
       HEAPF32[$233>>2] = $441;
       $553 = Math_fround(-$540);
       $554 = Math_fround(-$543);
       $555 = Math_fround(-$546);
       $556 = $553;$557 = $554;$558 = $555;
      } else {
       $556 = $540;$557 = $543;$558 = $546;
      }
      HEAPF32[$234>>2] = $556;
      HEAPF32[$235>>2] = $557;
      HEAPF32[$236>>2] = $558;
      HEAPF32[$237>>2] = $433;
      HEAPF32[$238>>2] = $434;
      HEAPF32[$239>>2] = $435;
      HEAPF32[$240>>2] = $427;
      HEAPF32[$241>>2] = $429;
      HEAPF32[$242>>2] = $431;
      HEAPF32[$243>>2] = $415;
      HEAPF32[$244>>2] = $417;
      HEAPF32[$245>>2] = $419;
      $559 = Math_fround($415 - $433);
      $560 = Math_fround($417 - $434);
      $561 = Math_fround($419 - $435);
      $562 = Math_fround($536 * $561);
      $563 = Math_fround($537 * $560);
      $564 = Math_fround($562 - $563);
      $565 = Math_fround($537 * $559);
      $566 = Math_fround($535 * $561);
      $567 = Math_fround($565 - $566);
      $568 = Math_fround($535 * $560);
      $569 = Math_fround($536 * $559);
      $570 = Math_fround($568 - $569);
      $571 = Math_fround($493 * $564);
      $572 = Math_fround($495 * $567);
      $573 = Math_fround($571 + $572);
      $574 = Math_fround($570 * $498);
      $575 = Math_fround($574 + $573);
      $576 = $575 > Math_fround(0.0);
      if ($576) {
       HEAPF32[$240>>2] = $415;
       HEAPF32[$241>>2] = $417;
       HEAPF32[$242>>2] = $419;
       HEAPF32[$243>>2] = $427;
       HEAPF32[$244>>2] = $429;
       HEAPF32[$245>>2] = $431;
       $577 = Math_fround(-$564);
       $578 = Math_fround(-$567);
       $579 = Math_fround(-$570);
       $580 = $577;$581 = $578;$582 = $579;
      } else {
       $580 = $564;$581 = $567;$582 = $570;
      }
      HEAPF32[$246>>2] = $580;
      HEAPF32[$247>>2] = $581;
      HEAPF32[$248>>2] = $582;
      HEAPF32[$249>>2] = $415;
      HEAPF32[$250>>2] = $417;
      HEAPF32[$251>>2] = $419;
      HEAPF32[$252>>2] = $421;
      HEAPF32[$253>>2] = $423;
      HEAPF32[$254>>2] = $425;
      HEAPF32[$255>>2] = $436;
      HEAPF32[$256>>2] = $437;
      HEAPF32[$257>>2] = $438;
      $583 = Math_fround($421 - $415);
      $584 = Math_fround($423 - $417);
      $585 = Math_fround($425 - $419);
      $586 = Math_fround($436 - $415);
      $587 = Math_fround($437 - $417);
      $588 = Math_fround($438 - $419);
      $589 = Math_fround($584 * $588);
      $590 = Math_fround($585 * $587);
      $591 = Math_fround($589 - $590);
      $592 = Math_fround($585 * $586);
      $593 = Math_fround($583 * $588);
      $594 = Math_fround($592 - $593);
      $595 = Math_fround($583 * $587);
      $596 = Math_fround($584 * $586);
      $597 = Math_fround($595 - $596);
      $598 = Math_fround($493 * $591);
      $599 = Math_fround($495 * $594);
      $600 = Math_fround($598 + $599);
      $601 = Math_fround($597 * $498);
      $602 = Math_fround($601 + $600);
      $603 = $602 > Math_fround(0.0);
      if ($603) {
       HEAPF32[$252>>2] = $436;
       HEAPF32[$253>>2] = $437;
       HEAPF32[$254>>2] = $438;
       HEAPF32[$255>>2] = $421;
       HEAPF32[$256>>2] = $423;
       HEAPF32[$257>>2] = $425;
       $604 = Math_fround(-$591);
       $605 = Math_fround(-$594);
       $606 = Math_fround(-$597);
       $607 = $604;$608 = $605;$609 = $606;
      } else {
       $607 = $591;$608 = $594;$609 = $597;
      }
      HEAPF32[$258>>2] = $607;
      HEAPF32[$259>>2] = $608;
      HEAPF32[$260>>2] = $609;
      HEAPF32[$261>>2] = $415;
      HEAPF32[$262>>2] = $417;
      HEAPF32[$263>>2] = $419;
      HEAPF32[$264>>2] = $436;
      HEAPF32[$265>>2] = $437;
      HEAPF32[$266>>2] = $438;
      HEAPF32[$267>>2] = $433;
      HEAPF32[$268>>2] = $434;
      HEAPF32[$269>>2] = $435;
      $610 = Math_fround($433 - $415);
      $611 = Math_fround($434 - $417);
      $612 = Math_fround($435 - $419);
      $613 = Math_fround($587 * $612);
      $614 = Math_fround($588 * $611);
      $615 = Math_fround($613 - $614);
      $616 = Math_fround($588 * $610);
      $617 = Math_fround($586 * $612);
      $618 = Math_fround($616 - $617);
      $619 = Math_fround($586 * $611);
      $620 = Math_fround($587 * $610);
      $621 = Math_fround($619 - $620);
      $622 = Math_fround($493 * $615);
      $623 = Math_fround($495 * $618);
      $624 = Math_fround($622 + $623);
      $625 = Math_fround($621 * $498);
      $626 = Math_fround($625 + $624);
      $627 = $626 > Math_fround(0.0);
      if ($627) {
       HEAPF32[$264>>2] = $433;
       HEAPF32[$265>>2] = $434;
       HEAPF32[$266>>2] = $435;
       HEAPF32[$267>>2] = $436;
       HEAPF32[$268>>2] = $437;
       HEAPF32[$269>>2] = $438;
       $628 = Math_fround(-$615);
       $629 = Math_fround(-$618);
       $630 = Math_fround(-$621);
       $631 = $628;$632 = $629;$633 = $630;
      } else {
       $631 = $615;$632 = $618;$633 = $621;
      }
      HEAPF32[$270>>2] = $631;
      HEAPF32[$271>>2] = $632;
      HEAPF32[$272>>2] = $633;
      $634 = Math_fround($331 * $331);
      $635 = Math_fround($334 * $334);
      $636 = Math_fround($634 + $635);
      $637 = Math_fround($337 * $337);
      $638 = Math_fround($637 + $636);
      $639 = (Math_fround(Math_sqrt((Math_fround($638)))));
      $640 = $639 > Math_fround(0.0);
      if ($640) {
       $641 = Math_fround(Math_fround(1.0) / $639);
       $642 = Math_fround($331 * $641);
       $643 = Math_fround($334 * $641);
       $644 = Math_fround($337 * $641);
       $722 = $642;$725 = $643;$729 = $644;
      } else {
       $722 = $331;$725 = $334;$729 = $337;
      }
      $649 = $493;$652 = $495;$653 = $storemerge125;$657 = $498;$658 = $storemerge;$661 = $810;$811 = $809;$j$073 = 0;
      while(1) {
       $645 = (($extrudedTris) + (($j$073*36)|0)|0);
       $646 = (($extrudedTrisNormals) + (($j$073*12)|0)|0);
       $647 = Math_fround(HEAPF32[$646>>2]);
       $648 = Math_fround($647 * $649);
       $650 = ((($extrudedTrisNormals) + (($j$073*12)|0)|0) + 4|0);
       $651 = Math_fround($653 * $652);
       $654 = Math_fround($648 + $651);
       $655 = ((($extrudedTrisNormals) + (($j$073*12)|0)|0) + 8|0);
       $656 = Math_fround($658 * $657);
       $659 = Math_fround($654 + $656);
       $660 = $659 > Math_fround(0.0);
       do {
        if ($660) {
         $812 = $661;$813 = $811;
        } else {
         $662 = (__ZN5physx2Gu13coarseCullingERKNS_6PxVec3ES3_ffRKNS_10PxTriangleE($capsuleCenter,$unitDir,$661,$181,$645)|0);
         if (!($662)) {
          $812 = $661;$813 = $811;
          break;
         }
         $663 = Math_fround(HEAPF32[$645>>2]);
         $664 = Math_fround($649 * $663);
         $665 = ((($extrudedTris) + (($j$073*36)|0)|0) + 4|0);
         $666 = Math_fround(HEAPF32[$665>>2]);
         $667 = Math_fround($652 * $666);
         $668 = Math_fround($664 + $667);
         $669 = ((($extrudedTris) + (($j$073*36)|0)|0) + 8|0);
         $670 = Math_fround(HEAPF32[$669>>2]);
         $671 = Math_fround($657 * $670);
         $672 = Math_fround($668 + $671);
         $673 = ((($extrudedTris) + (($j$073*36)|0)|0) + 12|0);
         $674 = Math_fround(HEAPF32[$673>>2]);
         $675 = Math_fround($649 * $674);
         $676 = ((($extrudedTris) + (($j$073*36)|0)|0) + 16|0);
         $677 = Math_fround(HEAPF32[$676>>2]);
         $678 = Math_fround($652 * $677);
         $679 = Math_fround($675 + $678);
         $680 = ((($extrudedTris) + (($j$073*36)|0)|0) + 20|0);
         $681 = Math_fround(HEAPF32[$680>>2]);
         $682 = Math_fround($657 * $681);
         $683 = Math_fround($679 + $682);
         $684 = ((($extrudedTris) + (($j$073*36)|0)|0) + 24|0);
         $685 = Math_fround(HEAPF32[$684>>2]);
         $686 = Math_fround($649 * $685);
         $687 = ((($extrudedTris) + (($j$073*36)|0)|0) + 28|0);
         $688 = Math_fround(HEAPF32[$687>>2]);
         $689 = Math_fround($652 * $688);
         $690 = Math_fround($686 + $689);
         $691 = ((($extrudedTris) + (($j$073*36)|0)|0) + 32|0);
         $692 = Math_fround(HEAPF32[$691>>2]);
         $693 = Math_fround($657 * $692);
         $694 = Math_fround($690 + $693);
         $695 = $672 < $683;
         $696 = $695 ? $672 : $683;
         $697 = $696 < $694;
         $698 = $697 ? $696 : $694;
         $699 = Math_fround($189 + $661);
         $700 = Math_fround($181 + $699);
         $701 = Math_fround($700 + Math_fround(0.00999999977648258209228));
         $702 = $698 > $701;
         if ($702) {
          $812 = $661;$813 = $811;
          break;
         }
         $703 = $672 < $189;
         $704 = $683 < $189;
         $or$cond$i$i = $703 & $704;
         $705 = $694 < $189;
         $or$cond1$i$i = $or$cond$i$i & $705;
         if ($or$cond1$i$i) {
          $812 = $661;$813 = $811;
          break;
         }
         $706 = Math_fround($647 * $647);
         $707 = Math_fround($653 * $653);
         $708 = Math_fround($706 + $707);
         $709 = Math_fround($658 * $658);
         $710 = Math_fround($708 + $709);
         $711 = (Math_fround(Math_sqrt((Math_fround($710)))));
         $712 = $711 == Math_fround(0.0);
         if ($712) {
          $812 = $661;$813 = $811;
          break;
         }
         $713 = Math_fround(Math_fround(1.0) / $711);
         $714 = Math_fround($647 * $713);
         HEAPF32[$646>>2] = $714;
         $715 = Math_fround($713 * $653);
         HEAPF32[$650>>2] = $715;
         $716 = Math_fround($713 * $658);
         HEAPF32[$655>>2] = $716;
         HEAPF32[$currentDistance$i>>2] = Math_fround(1.0E+4);
         $717 = (__ZN5physx2Gu14sweepTriSphereERKNS_10PxTriangleERKNS_6PxVec3ES6_fS6_Rf($645,$646,$capsuleCenter,$181,$unitDir,$currentDistance$i)|0);
         $$not$i = $717 ^ 1;
         $718 = Math_fround(HEAPF32[$currentDistance$i>>2]);
         $719 = $718 > $distance;
         $or$cond$i = $719 | $$not$i;
         if ($or$cond$i) {
          $812 = $661;$813 = $811;
          break;
         }
         $720 = Math_fround(HEAPF32[$unitDir>>2]);
         $721 = Math_fround($722 * $720);
         $723 = Math_fround(HEAPF32[$152>>2]);
         $724 = Math_fround($725 * $723);
         $726 = Math_fround($721 + $724);
         $727 = Math_fround(HEAPF32[$156>>2]);
         $728 = Math_fround($729 * $727);
         $730 = Math_fround($726 + $728);
         $731 = Math_fround($730 * Math_fround(0.00999999977648258209228));
         $732 = Math_fround($718 + $731);
         HEAPF32[$currentDistance$i>>2] = $732;
         $733 = $732 > $661;
         if ($733) {
          $812 = $661;$813 = $811;
          break;
         }
         HEAP32[$hitIndex>>2] = $triangleIndex$0$i;
         $734 = Math_fround(HEAPF32[$645>>2]);
         HEAPF32[$bestTri>>2] = $734;
         $735 = Math_fround(HEAPF32[$665>>2]);
         HEAPF32[$273>>2] = $735;
         $736 = Math_fround(HEAPF32[$669>>2]);
         HEAPF32[$274>>2] = $736;
         $737 = Math_fround(HEAPF32[$673>>2]);
         HEAPF32[$275>>2] = $737;
         $738 = Math_fround(HEAPF32[$676>>2]);
         HEAPF32[$276>>2] = $738;
         $739 = Math_fround(HEAPF32[$680>>2]);
         HEAPF32[$277>>2] = $739;
         $740 = Math_fround(HEAPF32[$684>>2]);
         HEAPF32[$278>>2] = $740;
         $741 = Math_fround(HEAPF32[$687>>2]);
         HEAPF32[$279>>2] = $741;
         $742 = Math_fround(HEAPF32[$691>>2]);
         HEAPF32[$280>>2] = $742;
         $812 = $732;$813 = $731;
        }
       } while(0);
       $743 = (($j$073) + 1)|0;
       $exitcond = ($743|0)==(7);
       if ($exitcond) {
        $746 = $813;$747 = $812;
        break L33;
       }
       $$pre113 = Math_fround(HEAPF32[$unitDir>>2]);
       $$phi$trans$insert = ((($extrudedTrisNormals) + (($743*12)|0)|0) + 4|0);
       $$pre114 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
       $$pre115 = Math_fround(HEAPF32[$152>>2]);
       $$phi$trans$insert116 = ((($extrudedTrisNormals) + (($743*12)|0)|0) + 8|0);
       $$pre117 = Math_fround(HEAPF32[$$phi$trans$insert116>>2]);
       $$pre118 = Math_fround(HEAPF32[$156>>2]);
       $649 = $$pre113;$652 = $$pre115;$653 = $$pre114;$657 = $$pre118;$658 = $$pre117;$661 = $812;$811 = $813;$j$073 = $743;
      }
     }
    } while(0);
    $744 = (($ii$076) + 1)|0;
    $exitcond87 = ($744|0)==($nbTris|0);
    if ($exitcond87) {
     break;
    } else {
     $809 = $746;$810 = $747;$ii$076 = $744;
    }
   }
   $$pre95 = HEAP32[$hitIndex>>2]|0;
   $phitmp = ($$pre95|0)==(-1);
   if ($phitmp) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $745 = Math_fround($747 - $746);
   HEAPF32[$t>>2] = $745;
   __ZN5physx2Gu17computeImpactDataERNS_6PxVec3ES2_RKS1_S4_fRKNS_10PxTriangleE($hit,$normal,$capsuleCenter,$unitDir,$745,$bestTri);
   $748 = HEAP32[$hitIndex>>2]|0;
   $749 = ($748|0)==(-1);
   if ($749) {
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
   $750 = Math_fround(HEAPF32[$t>>2]);
   $751 = Math_fround(HEAPF32[$unitDir>>2]);
   $752 = Math_fround($750 * $751);
   $753 = Math_fround(HEAPF32[$152>>2]);
   $754 = Math_fround($750 * $753);
   $755 = Math_fround(HEAPF32[$156>>2]);
   $756 = Math_fround($750 * $755);
   $757 = Math_fround(HEAPF32[$capsule>>2]);
   $758 = Math_fround($752 + $757);
   $759 = Math_fround(HEAPF32[$13>>2]);
   $760 = Math_fround($754 + $759);
   $761 = Math_fround(HEAPF32[$18>>2]);
   $762 = Math_fround($756 + $761);
   HEAPF32[$2>>2] = $758;
   $763 = (($2) + 4|0);
   HEAPF32[$763>>2] = $760;
   $764 = (($2) + 8|0);
   HEAPF32[$764>>2] = $762;
   $765 = (($2) + 12|0);
   HEAPF32[$765>>2] = Math_fround(0.0);
   $766 = Math_fround(HEAPF32[$10>>2]);
   $767 = Math_fround($752 + $766);
   $768 = Math_fround(HEAPF32[$15>>2]);
   $769 = Math_fround($754 + $768);
   $770 = Math_fround(HEAPF32[$20>>2]);
   $771 = Math_fround($756 + $770);
   HEAPF32[$3>>2] = $767;
   $772 = (($3) + 4|0);
   HEAPF32[$772>>2] = $769;
   $773 = (($3) + 8|0);
   HEAPF32[$773>>2] = $771;
   $774 = (($3) + 12|0);
   HEAPF32[$774>>2] = Math_fround(0.0);
   $775 = (($triangles) + (($748*36)|0)|0);
   $776 = Math_fround(HEAPF32[$775>>2]);
   $777 = ((($triangles) + (($748*36)|0)|0) + 4|0);
   $778 = Math_fround(HEAPF32[$777>>2]);
   $779 = ((($triangles) + (($748*36)|0)|0) + 8|0);
   $780 = Math_fround(HEAPF32[$779>>2]);
   HEAPF32[$4>>2] = $776;
   $781 = (($4) + 4|0);
   HEAPF32[$781>>2] = $778;
   $782 = (($4) + 8|0);
   HEAPF32[$782>>2] = $780;
   $783 = (($4) + 12|0);
   HEAPF32[$783>>2] = Math_fround(0.0);
   $784 = ((($triangles) + (($748*36)|0)|0) + 12|0);
   $785 = Math_fround(HEAPF32[$784>>2]);
   $786 = ((($triangles) + (($748*36)|0)|0) + 16|0);
   $787 = Math_fround(HEAPF32[$786>>2]);
   $788 = ((($triangles) + (($748*36)|0)|0) + 20|0);
   $789 = Math_fround(HEAPF32[$788>>2]);
   HEAPF32[$5>>2] = $785;
   $790 = (($5) + 4|0);
   HEAPF32[$790>>2] = $787;
   $791 = (($5) + 8|0);
   HEAPF32[$791>>2] = $789;
   $792 = (($5) + 12|0);
   HEAPF32[$792>>2] = Math_fround(0.0);
   $793 = ((($triangles) + (($748*36)|0)|0) + 24|0);
   $794 = Math_fround(HEAPF32[$793>>2]);
   $795 = ((($triangles) + (($748*36)|0)|0) + 28|0);
   $796 = Math_fround(HEAPF32[$795>>2]);
   $797 = ((($triangles) + (($748*36)|0)|0) + 32|0);
   $798 = Math_fround(HEAPF32[$797>>2]);
   HEAPF32[$6>>2] = $794;
   $799 = (($6) + 4|0);
   HEAPF32[$799>>2] = $796;
   $800 = (($6) + 8|0);
   HEAPF32[$800>>2] = $798;
   $801 = (($6) + 12|0);
   HEAPF32[$801>>2] = Math_fround(0.0);
   __ZN5physx2Gu30distanceSegmentTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_RS3_S6_($7,$2,$3,$4,$5,$6,$pointOnSeg,$pointOnTri);
   $802 = Math_fround(HEAPF32[$pointOnTri>>2]);
   $803 = (($pointOnTri) + 4|0);
   $804 = Math_fround(HEAPF32[$803>>2]);
   $805 = (($pointOnTri) + 8|0);
   $806 = Math_fround(HEAPF32[$805>>2]);
   HEAPF32[$hit>>2] = $802;
   $807 = (($hit) + 4|0);
   HEAPF32[$807>>2] = $804;
   $808 = (($hit) + 8|0);
   HEAPF32[$808>>2] = $806;
   HEAP16[$outFlags>>1] = 7;
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  } else {
   $162 = $150;$164 = $153;$166 = $157;
  }
 } else {
  $$pre120 = Math_fround(HEAPF32[$unitDir>>2]);
  $$phi$trans$insert121 = (($unitDir) + 4|0);
  $$pre122 = Math_fround(HEAPF32[$$phi$trans$insert121>>2]);
  $$phi$trans$insert123 = (($unitDir) + 8|0);
  $$pre124 = Math_fround(HEAPF32[$$phi$trans$insert123>>2]);
  $162 = $$pre120;$164 = $$pre122;$166 = $$pre124;
 }
 $161 = Math_fround($144 * $162);
 $163 = Math_fround($144 * $164);
 $165 = Math_fround($144 * $166);
 $167 = Math_fround(HEAPF32[$capsuleCenter>>2]);
 $168 = Math_fround($161 + $167);
 $169 = Math_fround(HEAPF32[$26>>2]);
 $170 = Math_fround($163 + $169);
 $171 = Math_fround(HEAPF32[$27>>2]);
 $172 = Math_fround($165 + $171);
 HEAPF32[$sphereCenter>>2] = $168;
 $173 = (($sphereCenter) + 4|0);
 HEAPF32[$173>>2] = $170;
 $174 = (($sphereCenter) + 8|0);
 HEAPF32[$174>>2] = $172;
 $175 = (($capsule) + 24|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = (__ZN5physx2Gu20sweepSphereTrianglesEjPKNS_10PxTriangleERKNS_6PxVec3EfS6_fPKjRS4_S9_RfRjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEEb($nbTris,$triangles,$sphereCenter,$176,$unitDir,$distance,$cachedIndex,$hit,$normal,$t,$hitIndex,$outFlags,$isDoubleSided)|0);
 $$1 = $177;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx2Gu13coarseCullingERKNS_6PxVec3ES3_ffRKNS_10PxTriangleE($center,$dir,$t,$radius,$tri) {
 $center = $center|0;
 $dir = $dir|0;
 $t = Math_fround($t);
 $radius = Math_fround($radius);
 $tri = $tri|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$tri>>2]);
 $1 = (($tri) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 $4 = (($tri) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($tri) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 $9 = (($tri) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($tri) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = (($tri) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 + $15);
 $17 = (($tri) + 28|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($8 + $18);
 $20 = (($tri) + 32|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($13 + $21);
 $23 = Math_fround($16 * Math_fround(0.333333343267440795898));
 $24 = Math_fround($19 * Math_fround(0.333333343267440795898));
 $25 = Math_fround($22 * Math_fround(0.333333343267440795898));
 $26 = Math_fround(HEAPF32[$center>>2]);
 $27 = Math_fround($23 - $26);
 $28 = (($center) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($24 - $29);
 $31 = (($center) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($25 - $32);
 $34 = Math_fround(HEAPF32[$dir>>2]);
 $35 = Math_fround($27 * $34);
 $36 = (($dir) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($30 * $37);
 $39 = Math_fround($35 + $38);
 $40 = (($dir) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($33 * $41);
 $43 = Math_fround($39 + $42);
 $44 = $43 > Math_fround(0.0);
 $45 = $44 ? $43 : Math_fround(0.0);
 $46 = $45 < $t;
 $47 = $46 ? $45 : $t;
 $48 = Math_fround($34 * $47);
 $49 = Math_fround($37 * $47);
 $50 = Math_fround($41 * $47);
 $51 = Math_fround($27 - $48);
 $52 = Math_fround($30 - $49);
 $53 = Math_fround($33 - $50);
 $54 = Math_fround($51 * $51);
 $55 = Math_fround($52 * $52);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($53 * $53);
 $58 = Math_fround($57 + $56);
 $59 = (Math_fround(Math_sqrt((Math_fround($58)))));
 $60 = Math_fround($59 - $radius);
 $61 = Math_fround($60 + Math_fround(-9.99999974737875163555E-5));
 $62 = $61 < Math_fround(0.0);
 if ($62) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = Math_fround($61 * $61);
 $64 = Math_fround($23 - $0);
 $65 = Math_fround($24 - $5);
 $66 = Math_fround($25 - $10);
 $67 = Math_fround($64 * $64);
 $68 = Math_fround($65 * $65);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround($66 * $66);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($23 - $2);
 $73 = Math_fround($24 - $7);
 $74 = Math_fround($25 - $12);
 $75 = Math_fround($72 * $72);
 $76 = Math_fround($73 * $73);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($74 * $74);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($23 - $15);
 $81 = Math_fround($24 - $18);
 $82 = Math_fround($25 - $21);
 $83 = Math_fround($80 * $80);
 $84 = Math_fround($81 * $81);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($82 * $82);
 $87 = Math_fround($85 + $86);
 $88 = $71 > $79;
 $89 = $88 ? $71 : $79;
 $90 = $89 > $87;
 $91 = $90 ? $89 : $87;
 $not$ = $63 <= $91;
 $$0 = $not$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18sweepSphereCapsuleERKNS0_6SphereERKNS0_7CapsuleERKNS_6PxVec3EfRfRS7_SB_NS_7PxFlagsINS_9PxHitFlag4EnumEtEE($sphere,$lss,$dir,$length,$d,$ip,$nrm,$hintFlags) {
 $sphere = $sphere|0;
 $lss = $lss|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $d = $d|0;
 $ip = $ip|0;
 $nrm = $nrm|0;
 $hintFlags = $hintFlags|0;
 var $$ = Math_fround(0), $$1 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0;
 var $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0);
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $Inflated = 0, $dir$idx$val = Math_fround(0), $dir$idx1 = 0, $dir$idx1$val = Math_fround(0), $dir$idx2 = 0, $dir$idx2$val = Math_fround(0), $or$cond = 0, $or$cond23 = 0, $s = 0, $t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 44|0;
 $Inflated = sp;
 $s = sp + 32|0;
 $t = sp + 40|0;
 $1 = (($lss) + 24|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($sphere) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 + $4);
 $6 = HEAP16[$hintFlags>>1]|0;
 $7 = $6 & 16;
 $8 = ($7<<16>>16)==(0);
 if ($8) {
  $9 = (($lss) + 12|0);
  $10 = (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($lss,$9,$sphere,0)));
  $11 = Math_fround($5 * $5);
  $12 = $10 < $11;
  if ($12) {
   HEAPF32[$d>>2] = Math_fround(0.0);
   $13 = Math_fround(HEAPF32[$dir>>2]);
   $14 = Math_fround(-$13);
   $15 = (($dir) + 4|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround(-$16);
   $18 = (($dir) + 8|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround(-$19);
   HEAPF32[$nrm>>2] = $14;
   $21 = (($nrm) + 4|0);
   HEAPF32[$21>>2] = $17;
   $22 = (($nrm) + 8|0);
   HEAPF32[$22>>2] = $20;
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $23 = Math_fround(HEAPF32[$lss>>2]);
 $24 = (($lss) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = $23 == $25;
 $27 = (($lss) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($lss) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = $28 == $30;
 $or$cond23 = $26 & $31;
 if ($or$cond23) {
  $32 = (($lss) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($lss) + 20|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = $33 == $35;
  if ($36) {
   $37 = Math_fround(HEAPF32[$3>>2]);
   $38 = Math_fround(HEAPF32[$1>>2]);
   $39 = Math_fround(HEAPF32[$dir>>2]);
   $40 = (($dir) + 4|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = (($dir) + 8|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = Math_fround($39 * $length);
   $45 = Math_fround(-$44);
   $46 = Math_fround($41 * $length);
   $47 = Math_fround(-$46);
   $48 = Math_fround($43 * $length);
   $49 = Math_fround(-$48);
   HEAPF32[$0>>2] = $45;
   $50 = (($0) + 4|0);
   HEAPF32[$50>>2] = $47;
   $51 = (($0) + 8|0);
   HEAPF32[$51>>2] = $49;
   $52 = (__ZN5physx2Gu17sweepSphereSphereERKNS_6PxVec3EfS3_fS3_RfRS1_($sphere,$37,$lss,$38,$0,$d,$nrm)|0);
   if (!($52)) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $53 = Math_fround(HEAPF32[$d>>2]);
   $54 = Math_fround($53 * $length);
   HEAPF32[$d>>2] = $54;
   $55 = Math_fround(HEAPF32[$3>>2]);
   $56 = Math_fround(HEAPF32[$nrm>>2]);
   $57 = Math_fround($55 * $56);
   $58 = (($nrm) + 4|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = Math_fround($55 * $59);
   $61 = (($nrm) + 8|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = Math_fround($55 * $62);
   $64 = Math_fround(HEAPF32[$sphere>>2]);
   $65 = Math_fround($57 + $64);
   $66 = (($sphere) + 4|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = Math_fround($60 + $67);
   $69 = (($sphere) + 8|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = Math_fround($63 + $70);
   HEAPF32[$ip>>2] = $65;
   $72 = (($ip) + 4|0);
   HEAPF32[$72>>2] = $68;
   $73 = (($ip) + 8|0);
   HEAPF32[$73>>2] = $71;
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 HEAPF32[$Inflated>>2] = $23;
 $74 = (($Inflated) + 4|0);
 HEAPF32[$74>>2] = $28;
 $75 = (($Inflated) + 8|0);
 $76 = (($lss) + 8|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 HEAPF32[$75>>2] = $77;
 $78 = (($Inflated) + 12|0);
 HEAPF32[$78>>2] = $25;
 $79 = (($Inflated) + 16|0);
 HEAPF32[$79>>2] = $30;
 $80 = (($Inflated) + 20|0);
 $81 = (($lss) + 20|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 HEAPF32[$80>>2] = $82;
 $83 = (($Inflated) + 24|0);
 HEAPF32[$83>>2] = $5;
 $84 = (__ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($sphere,$dir,$Inflated,$s)|0);
 $85 = ($84|0)==(0);
 if ($85) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $86 = ($84|0)==(1);
 $87 = Math_fround(HEAPF32[$s>>2]);
 if ($86) {
  $91 = $87;
 } else {
  $88 = (($s) + 4|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = $87 < $89;
  $$ = $90 ? $87 : $89;
  $91 = $$;
 }
 HEAPF32[$t>>2] = $91;
 $92 = !($91 >= Math_fround(0.0));
 $93 = !($91 <= $length);
 $or$cond = $92 | $93;
 if ($or$cond) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 HEAPF32[$d>>2] = $91;
 $dir$idx$val = Math_fround(HEAPF32[$dir>>2]);
 $dir$idx1 = (($dir) + 4|0);
 $dir$idx1$val = Math_fround(HEAPF32[$dir$idx1>>2]);
 $dir$idx2 = (($dir) + 8|0);
 $dir$idx2$val = Math_fround(HEAPF32[$dir$idx2>>2]);
 $94 = Math_fround($91 * $dir$idx$val);
 $95 = Math_fround($91 * $dir$idx1$val);
 $96 = Math_fround($91 * $dir$idx2$val);
 $97 = Math_fround(HEAPF32[$Inflated>>2]);
 $98 = Math_fround($97 - $94);
 HEAPF32[$Inflated>>2] = $98;
 $99 = Math_fround(HEAPF32[$74>>2]);
 $100 = Math_fround($99 - $95);
 HEAPF32[$74>>2] = $100;
 $101 = Math_fround(HEAPF32[$75>>2]);
 $102 = Math_fround($101 - $96);
 HEAPF32[$75>>2] = $102;
 $103 = Math_fround(HEAPF32[$78>>2]);
 $104 = Math_fround($103 - $94);
 HEAPF32[$78>>2] = $104;
 $105 = Math_fround(HEAPF32[$79>>2]);
 $106 = Math_fround($105 - $95);
 HEAPF32[$79>>2] = $106;
 $107 = Math_fround(HEAPF32[$80>>2]);
 $108 = Math_fround($107 - $96);
 HEAPF32[$80>>2] = $108;
 $109 = (($Inflated) + 12|0);
 (Math_fround(__ZN5physx2Gu27distancePointSegmentSquaredERKNS_6PxVec3ES3_S3_Pf($Inflated,$109,$sphere,$t)));
 $110 = Math_fround(HEAPF32[$t>>2]);
 $111 = Math_fround(HEAPF32[$78>>2]);
 $112 = Math_fround(HEAPF32[$Inflated>>2]);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround(HEAPF32[$79>>2]);
 $115 = Math_fround(HEAPF32[$74>>2]);
 $116 = Math_fround($114 - $115);
 $117 = Math_fround(HEAPF32[$80>>2]);
 $118 = Math_fround(HEAPF32[$75>>2]);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($110 * $113);
 $121 = Math_fround($110 * $116);
 $122 = Math_fround($110 * $119);
 $123 = Math_fround($112 + $120);
 $124 = Math_fround($115 + $121);
 $125 = Math_fround($118 + $122);
 HEAPF32[$ip>>2] = $123;
 $126 = (($ip) + 4|0);
 HEAPF32[$126>>2] = $124;
 $127 = (($ip) + 8|0);
 HEAPF32[$127>>2] = $125;
 $128 = Math_fround(HEAPF32[$sphere>>2]);
 $129 = Math_fround($123 - $128);
 $130 = (($sphere) + 4|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($124 - $131);
 $133 = (($sphere) + 8|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($125 - $134);
 HEAPF32[$nrm>>2] = $129;
 $136 = (($nrm) + 4|0);
 HEAPF32[$136>>2] = $132;
 $137 = (($nrm) + 8|0);
 HEAPF32[$137>>2] = $135;
 $138 = Math_fround($129 * $129);
 $139 = Math_fround($132 * $132);
 $140 = Math_fround($138 + $139);
 $141 = Math_fround($135 * $135);
 $142 = Math_fround($141 + $140);
 $143 = (Math_fround(Math_sqrt((Math_fround($142)))));
 $144 = $143 > Math_fround(0.0);
 if ($144) {
  $145 = Math_fround(Math_fround(1.0) / $143);
  $146 = Math_fround($129 * $145);
  HEAPF32[$nrm>>2] = $146;
  $147 = Math_fround($132 * $145);
  HEAPF32[$136>>2] = $147;
  $148 = Math_fround($135 * $145);
  HEAPF32[$137>>2] = $148;
  $151 = $146;$153 = $147;$155 = $148;
 } else {
  $151 = $129;$153 = $132;$155 = $135;
 }
 $149 = Math_fround(HEAPF32[$1>>2]);
 $150 = Math_fround($149 * $151);
 $152 = Math_fround($149 * $153);
 $154 = Math_fround($149 * $155);
 $156 = Math_fround(HEAPF32[$ip>>2]);
 $157 = Math_fround($156 - $150);
 HEAPF32[$ip>>2] = $157;
 $158 = Math_fround(HEAPF32[$126>>2]);
 $159 = Math_fround($158 - $152);
 HEAPF32[$126>>2] = $159;
 $160 = Math_fround(HEAPF32[$127>>2]);
 $161 = Math_fround($160 - $154);
 HEAPF32[$127>>2] = $161;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx2Gu17sweepSphereSphereERKNS_6PxVec3EfS3_fS3_RfRS1_($center0,$radius0,$center1,$radius1,$motion,$d,$nrm) {
 $center0 = $center0|0;
 $radius0 = Math_fround($radius0);
 $center1 = $center1|0;
 $radius1 = Math_fround($radius1);
 $motion = $motion|0;
 $d = $d|0;
 $nrm = $nrm|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0);
 var $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $center0$idx$val = Math_fround(0), $center0$idx1 = 0, $center0$idx1$val = Math_fround(0), $center0$idx2 = 0, $center0$idx2$val = Math_fround(0), $motion$idx$val = Math_fround(0), $motion$idx10$val = Math_fround(0), $motion$idx11$val = Math_fround(0), $or$cond = 0, $or$cond$i = 0, $storemerge = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$center1>>2]);
 $1 = Math_fround(HEAPF32[$motion>>2]);
 $2 = Math_fround($0 + $1);
 $3 = (($center1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($motion) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 + $6);
 $8 = (($center1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($motion) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 + $11);
 $center0$idx$val = Math_fround(HEAPF32[$center0>>2]);
 $center0$idx1 = (($center0) + 4|0);
 $center0$idx1$val = Math_fround(HEAPF32[$center0$idx1>>2]);
 $center0$idx2 = (($center0) + 8|0);
 $center0$idx2$val = Math_fround(HEAPF32[$center0$idx2>>2]);
 $13 = Math_fround($center0$idx$val - $center0$idx$val);
 $14 = Math_fround($center0$idx1$val - $center0$idx1$val);
 $15 = Math_fround($center0$idx2$val - $center0$idx2$val);
 $16 = Math_fround($2 - $0);
 $17 = Math_fround($7 - $4);
 $18 = Math_fround($12 - $9);
 $19 = Math_fround($0 - $center0$idx$val);
 $20 = Math_fround($4 - $center0$idx1$val);
 $21 = Math_fround($9 - $center0$idx2$val);
 $22 = Math_fround($16 - $13);
 $23 = Math_fround($17 - $14);
 $24 = Math_fround($18 - $15);
 $25 = Math_fround($radius0 + $radius1);
 $26 = Math_fround($22 * $22);
 $27 = Math_fround($23 * $23);
 $28 = Math_fround($26 + $27);
 $29 = Math_fround($24 * $24);
 $30 = Math_fround($28 + $29);
 $31 = Math_fround($19 * $22);
 $32 = Math_fround($20 * $23);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround($21 * $24);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($35 * Math_fround(2.0));
 $37 = Math_fround($19 * $19);
 $38 = Math_fround($20 * $20);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($21 * $21);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($25 * $25);
 $43 = Math_fround($41 - $42);
 $44 = $43 <= Math_fround(0.0);
 $45 = $30 == Math_fround(0.0);
 $or$cond$i = $44 | $45;
 if ($or$cond$i) {
  HEAPF32[$d>>2] = Math_fround(0.0);
  label = 6;
 } else {
  $46 = Math_fround($36 * $36);
  $47 = Math_fround($30 * Math_fround(4.0));
  $48 = Math_fround($43 * $47);
  $49 = Math_fround($46 - $48);
  $50 = !($49 >= Math_fround(0.0));
  if ($50) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $51 = (Math_fround(Math_sqrt((Math_fround($49)))));
  $52 = Math_fround($30 * Math_fround(2.0));
  $53 = Math_fround(Math_fround(1.0) / $52);
  $54 = Math_fround(-$36);
  $55 = Math_fround($51 - $36);
  $56 = Math_fround($55 * $53);
  $57 = Math_fround($54 - $51);
  $58 = Math_fround($57 * $53);
  $59 = $56 > $58;
  $storemerge = $59 ? $58 : $56;
  $60 = $59 ? $56 : $58;
  HEAPF32[$d>>2] = $storemerge;
  $61 = $60 < Math_fround(0.0);
  $62 = $storemerge > Math_fround(1.0);
  $or$cond = $61 | $62;
  if ($or$cond) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $63 = $storemerge == Math_fround(0.0);
  if ($63) {
   label = 6;
  } else {
   $motion$idx$val = Math_fround(HEAPF32[$motion>>2]);
   $motion$idx10$val = Math_fround(HEAPF32[$5>>2]);
   $motion$idx11$val = Math_fround(HEAPF32[$10>>2]);
   $72 = Math_fround($storemerge * $motion$idx$val);
   $73 = Math_fround($storemerge * $motion$idx10$val);
   $74 = Math_fround($storemerge * $motion$idx11$val);
   $75 = Math_fround(HEAPF32[$center1>>2]);
   $76 = Math_fround($72 + $75);
   $77 = Math_fround(HEAPF32[$3>>2]);
   $78 = Math_fround($73 + $77);
   $79 = Math_fround(HEAPF32[$8>>2]);
   $80 = Math_fround($74 + $79);
   $81 = Math_fround(HEAPF32[$center0>>2]);
   $82 = Math_fround($76 - $81);
   $83 = Math_fround(HEAPF32[$center0$idx1>>2]);
   $84 = Math_fround($78 - $83);
   $85 = Math_fround(HEAPF32[$center0$idx2>>2]);
   $86 = Math_fround($80 - $85);
   HEAPF32[$nrm>>2] = $82;
   $87 = (($nrm) + 4|0);
   HEAPF32[$87>>2] = $84;
   $88 = (($nrm) + 8|0);
   HEAPF32[$88>>2] = $86;
   $90 = $82;$92 = $84;$95 = $86;
  }
 }
 if ((label|0) == 6) {
  $64 = Math_fround(HEAPF32[$motion>>2]);
  $65 = Math_fround(-$64);
  $66 = Math_fround(HEAPF32[$5>>2]);
  $67 = Math_fround(-$66);
  $68 = Math_fround(HEAPF32[$10>>2]);
  $69 = Math_fround(-$68);
  HEAPF32[$nrm>>2] = $65;
  $70 = (($nrm) + 4|0);
  HEAPF32[$70>>2] = $67;
  $71 = (($nrm) + 8|0);
  HEAPF32[$71>>2] = $69;
  $90 = $65;$92 = $67;$95 = $69;
 }
 $89 = Math_fround($90 * $90);
 $91 = Math_fround($92 * $92);
 $93 = Math_fround($89 + $91);
 $94 = Math_fround($95 * $95);
 $96 = Math_fround($93 + $94);
 $97 = (Math_fround(Math_sqrt((Math_fround($96)))));
 $98 = $97 > Math_fround(0.0);
 if (!($98)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $99 = (($nrm) + 8|0);
 $100 = (($nrm) + 4|0);
 $101 = Math_fround(Math_fround(1.0) / $97);
 $102 = Math_fround($90 * $101);
 HEAPF32[$nrm>>2] = $102;
 $103 = Math_fround($92 * $101);
 HEAPF32[$100>>2] = $103;
 $104 = Math_fround($95 * $101);
 HEAPF32[$99>>2] = $104;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu14sweepTriSphereERKNS_10PxTriangleERKNS_6PxVec3ES6_fS6_Rf($tri,$normal,$center,$radius,$dir,$min_dist) {
 $tri = $tri|0;
 $normal = $normal|0;
 $center = $center|0;
 $radius = Math_fround($radius);
 $dir = $dir|0;
 $min_dist = $min_dist|0;
 var $$ = Math_fround(0), $$1 = 0, $$idx10 = 0, $$idx10$val = Math_fround(0), $$idx11 = 0, $$idx11$val = Math_fround(0), $$idx12 = 0, $$idx12$val = Math_fround(0), $$idx13 = 0, $$idx13$val = Math_fround(0), $$idx14 = 0, $$idx14$val = Math_fround(0), $$idx6$val = Math_fround(0), $$idx7 = 0, $$idx7$val = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0), $$idx9 = 0, $$idx9$val = Math_fround(0), $$mux = 0;
 var $$mux75 = 0, $$not = 0, $$not74 = 0, $$ph = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0);
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0;
 var $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0;
 var $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge = 0, $capsule = 0, $e0$0 = 0, $e0$0$ph = 0, $or$cond$i = 0, $or$cond2$i = 0, $or$cond3$i = 0, $or$cond5$i = 0;
 var $s = 0, $t3 = 0, $t4$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $t3 = sp + 40|0;
 $capsule = sp;
 $s = sp + 32|0;
 $0 = Math_fround(HEAPF32[$normal>>2]);
 $1 = Math_fround($0 * $radius);
 $2 = (($normal) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $radius);
 $5 = (($normal) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $radius);
 $8 = Math_fround(HEAPF32[$dir>>2]);
 $9 = Math_fround($1 * $8);
 $10 = (($dir) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($4 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (($dir) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($7 * $15);
 $17 = Math_fround($13 + $16);
 $18 = !($17 >= Math_fround(0.0));
 if ($18) {
  $50 = $7;$52 = $4;$54 = $1;
 } else {
  $19 = Math_fround(-$1);
  $20 = Math_fround(-$4);
  $21 = Math_fround(-$7);
  $50 = $21;$52 = $20;$54 = $19;
 }
 $$idx6$val = Math_fround(HEAPF32[$tri>>2]);
 $$idx7 = (($tri) + 4|0);
 $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
 $$idx8 = (($tri) + 8|0);
 $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
 $$idx9 = (($tri) + 12|0);
 $$idx9$val = Math_fround(HEAPF32[$$idx9>>2]);
 $$idx10 = (($tri) + 16|0);
 $$idx10$val = Math_fround(HEAPF32[$$idx10>>2]);
 $$idx11 = (($tri) + 20|0);
 $$idx11$val = Math_fround(HEAPF32[$$idx11>>2]);
 $$idx12 = (($tri) + 24|0);
 $$idx12$val = Math_fround(HEAPF32[$$idx12>>2]);
 $$idx13 = (($tri) + 28|0);
 $$idx13$val = Math_fround(HEAPF32[$$idx13>>2]);
 $$idx14 = (($tri) + 32|0);
 $$idx14$val = Math_fround(HEAPF32[$$idx14>>2]);
 $22 = Math_fround($$idx9$val - $$idx6$val);
 $23 = Math_fround($$idx10$val - $$idx7$val);
 $24 = Math_fround($$idx11$val - $$idx8$val);
 $25 = Math_fround($$idx12$val - $$idx6$val);
 $26 = Math_fround($$idx13$val - $$idx7$val);
 $27 = Math_fround($$idx14$val - $$idx8$val);
 $28 = Math_fround($27 * $11);
 $29 = Math_fround($26 * $15);
 $30 = Math_fround($28 - $29);
 $31 = Math_fround($25 * $15);
 $32 = Math_fround($27 * $8);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($26 * $8);
 $35 = Math_fround($25 * $11);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($22 * $30);
 $38 = Math_fround($23 * $33);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($24 * $36);
 $41 = Math_fround($40 + $39);
 $42 = $41 > Math_fround(-9.99999974737875163555E-6);
 $43 = $41 < Math_fround(9.99999974737875163555E-6);
 $or$cond$i = $42 & $43;
 if ($or$cond$i) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $44 = (($center) + 8|0);
 $45 = (($center) + 4|0);
 $46 = Math_fround(HEAPF32[$44>>2]);
 $47 = Math_fround(HEAPF32[$45>>2]);
 $48 = Math_fround(HEAPF32[$center>>2]);
 $49 = Math_fround($46 - $50);
 $51 = Math_fround($47 - $52);
 $53 = Math_fround($48 - $54);
 $55 = Math_fround(Math_fround(1.0) / $41);
 $56 = Math_fround($53 - $$idx6$val);
 $57 = Math_fround($51 - $$idx7$val);
 $58 = Math_fround($49 - $$idx8$val);
 $59 = Math_fround($30 * $56);
 $60 = Math_fround($33 * $57);
 $61 = Math_fround($60 + $59);
 $62 = Math_fround($36 * $58);
 $63 = Math_fround($62 + $61);
 $64 = Math_fround($55 * $63);
 $65 = Math_fround($24 * $57);
 $66 = Math_fround($23 * $58);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($22 * $58);
 $69 = Math_fround($24 * $56);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($23 * $56);
 $72 = Math_fround($22 * $57);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($8 * $67);
 $75 = Math_fround($11 * $70);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($15 * $73);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($55 * $78);
 $80 = $64 < Math_fround(0.0);
 $81 = $64 > Math_fround(1.0);
 $or$cond2$i = $80 | $81;
 $82 = $79 < Math_fround(0.0);
 $or$cond3$i = $or$cond2$i | $82;
 $83 = Math_fround($64 + $79);
 $84 = $83 > Math_fround(1.0);
 $or$cond5$i = $or$cond3$i | $84;
 if (!($or$cond5$i)) {
  $85 = Math_fround($25 * $67);
  $86 = Math_fround($26 * $70);
  $87 = Math_fround($85 + $86);
  $88 = Math_fround($27 * $73);
  $89 = Math_fround($88 + $87);
  $90 = Math_fround($55 * $89);
  $91 = $90 < Math_fround(0.0);
  if ($91) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  HEAPF32[$min_dist>>2] = $90;
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 do {
  if ($80) {
   if ($82) {
    $92 = Math_fround($64 * $$idx9$val);
    $93 = Math_fround($64 * $$idx10$val);
    $94 = Math_fround($64 * $$idx11$val);
    $95 = Math_fround($79 * $$idx12$val);
    $96 = Math_fround($79 * $$idx13$val);
    $97 = Math_fround($79 * $$idx14$val);
    $98 = Math_fround($92 + $95);
    $99 = Math_fround($93 + $96);
    $100 = Math_fround($94 + $97);
    $101 = Math_fround(Math_fround(1.0) - $64);
    $102 = Math_fround($101 - $79);
    $103 = Math_fround($102 * $$idx6$val);
    $104 = Math_fround($102 * $$idx7$val);
    $105 = Math_fround($102 * $$idx8$val);
    $106 = Math_fround($98 + $103);
    $107 = Math_fround($99 + $104);
    $108 = Math_fround($100 + $105);
    $109 = Math_fround($$idx6$val - $$idx9$val);
    $110 = Math_fround($$idx7$val - $$idx10$val);
    $111 = Math_fround($$idx8$val - $$idx11$val);
    $112 = Math_fround($109 * $109);
    $113 = Math_fround($110 * $110);
    $114 = Math_fround($112 + $113);
    $115 = Math_fround($111 * $111);
    $116 = Math_fround($114 + $115);
    $117 = Math_fround($106 - $$idx9$val);
    $118 = Math_fround($107 - $$idx10$val);
    $119 = Math_fround($108 - $$idx11$val);
    $120 = Math_fround($109 * $117);
    $121 = Math_fround($110 * $118);
    $122 = Math_fround($120 + $121);
    $123 = Math_fround($111 * $119);
    $124 = Math_fround($122 + $123);
    $125 = $124 < $116;
    if ($125) {
     $$ph = 1;$e0$0$ph = 0;
     break;
    }
    $126 = Math_fround($$idx6$val - $$idx12$val);
    $127 = Math_fround($$idx7$val - $$idx13$val);
    $128 = Math_fround($$idx8$val - $$idx14$val);
    $129 = Math_fround($126 * $126);
    $130 = Math_fround($127 * $127);
    $131 = Math_fround($129 + $130);
    $132 = Math_fround($128 * $128);
    $133 = Math_fround($131 + $132);
    $134 = Math_fround($106 - $$idx12$val);
    $135 = Math_fround($107 - $$idx13$val);
    $136 = Math_fround($108 - $$idx14$val);
    $137 = Math_fround($126 * $134);
    $138 = Math_fround($127 * $135);
    $139 = Math_fround($137 + $138);
    $140 = Math_fround($128 * $136);
    $141 = Math_fround($139 + $140);
    $142 = $141 < $133;
    if ($142) {
     $$ph = 2;$e0$0$ph = 0;
     break;
    } else {
     $e0$0 = 0;
     label = 17;
     break;
    }
   }
   if ($84) {
    $143 = Math_fround($64 * $$idx9$val);
    $144 = Math_fround($64 * $$idx10$val);
    $145 = Math_fround($64 * $$idx11$val);
    $146 = Math_fround($79 * $$idx12$val);
    $147 = Math_fround($79 * $$idx13$val);
    $148 = Math_fround($79 * $$idx14$val);
    $149 = Math_fround($143 + $146);
    $150 = Math_fround($144 + $147);
    $151 = Math_fround($145 + $148);
    $152 = Math_fround(Math_fround(1.0) - $64);
    $153 = Math_fround($152 - $79);
    $154 = Math_fround($153 * $$idx6$val);
    $155 = Math_fround($153 * $$idx7$val);
    $156 = Math_fround($153 * $$idx8$val);
    $157 = Math_fround($149 + $154);
    $158 = Math_fround($150 + $155);
    $159 = Math_fround($151 + $156);
    $160 = Math_fround($25 * $25);
    $161 = Math_fround($26 * $26);
    $162 = Math_fround($160 + $161);
    $163 = Math_fround($27 * $27);
    $164 = Math_fround($162 + $163);
    $165 = Math_fround($157 - $$idx6$val);
    $166 = Math_fround($158 - $$idx7$val);
    $167 = Math_fround($159 - $$idx8$val);
    $168 = Math_fround($25 * $165);
    $169 = Math_fround($26 * $166);
    $170 = Math_fround($168 + $169);
    $171 = Math_fround($27 * $167);
    $172 = Math_fround($170 + $171);
    $173 = $172 < $164;
    if ($173) {
     $$ph = 0;$e0$0$ph = 2;
    } else {
     $174 = Math_fround($$idx12$val - $$idx9$val);
     $175 = Math_fround($$idx13$val - $$idx10$val);
     $176 = Math_fround($$idx14$val - $$idx11$val);
     $177 = Math_fround($174 * $174);
     $178 = Math_fround($175 * $175);
     $179 = Math_fround($177 + $178);
     $180 = Math_fround($176 * $176);
     $181 = Math_fround($179 + $180);
     $182 = Math_fround($157 - $$idx9$val);
     $183 = Math_fround($158 - $$idx10$val);
     $184 = Math_fround($159 - $$idx11$val);
     $185 = Math_fround($174 * $182);
     $186 = Math_fround($175 * $183);
     $187 = Math_fround($185 + $186);
     $188 = Math_fround($176 * $184);
     $189 = Math_fround($187 + $188);
     $190 = $189 < $181;
     if ($190) {
      $$ph = 1;$e0$0$ph = 2;
     } else {
      $e0$0 = 2;
      label = 17;
     }
    }
   } else {
    $$ph = 2;$e0$0$ph = 0;
   }
  } else {
   $$not = $82 ^ 1;
   $$not74 = $84 ^ 1;
   $brmerge = $$not | $$not74;
   $$mux = $82 ? 1 : 2;
   $$mux75 = $$not&1;
   if ($brmerge) {
    $$ph = $$mux;$e0$0$ph = $$mux75;
   } else {
    $191 = Math_fround($64 * $$idx9$val);
    $192 = Math_fround($64 * $$idx10$val);
    $193 = Math_fround($64 * $$idx11$val);
    $194 = Math_fround($79 * $$idx12$val);
    $195 = Math_fround($79 * $$idx13$val);
    $196 = Math_fround($79 * $$idx14$val);
    $197 = Math_fround($191 + $194);
    $198 = Math_fround($192 + $195);
    $199 = Math_fround($193 + $196);
    $200 = Math_fround(Math_fround(1.0) - $64);
    $201 = Math_fround($200 - $79);
    $202 = Math_fround($201 * $$idx6$val);
    $203 = Math_fround($201 * $$idx7$val);
    $204 = Math_fround($201 * $$idx8$val);
    $205 = Math_fround($197 + $202);
    $206 = Math_fround($198 + $203);
    $207 = Math_fround($199 + $204);
    $208 = Math_fround($22 * $22);
    $209 = Math_fround($23 * $23);
    $210 = Math_fround($208 + $209);
    $211 = Math_fround($24 * $24);
    $212 = Math_fround($210 + $211);
    $213 = Math_fround($205 - $$idx6$val);
    $214 = Math_fround($206 - $$idx7$val);
    $215 = Math_fround($207 - $$idx8$val);
    $216 = Math_fround($22 * $213);
    $217 = Math_fround($23 * $214);
    $218 = Math_fround($216 + $217);
    $219 = Math_fround($24 * $215);
    $220 = Math_fround($218 + $219);
    $221 = $220 < $212;
    if ($221) {
     $$ph = 0;$e0$0$ph = 1;
    } else {
     $222 = Math_fround($$idx9$val - $$idx12$val);
     $223 = Math_fround($$idx10$val - $$idx13$val);
     $224 = Math_fround($$idx11$val - $$idx14$val);
     $225 = Math_fround($222 * $222);
     $226 = Math_fround($223 * $223);
     $227 = Math_fround($225 + $226);
     $228 = Math_fround($224 * $224);
     $229 = Math_fround($227 + $228);
     $230 = Math_fround($205 - $$idx12$val);
     $231 = Math_fround($206 - $$idx13$val);
     $232 = Math_fround($207 - $$idx14$val);
     $233 = Math_fround($222 * $230);
     $234 = Math_fround($223 * $231);
     $235 = Math_fround($233 + $234);
     $236 = Math_fround($224 * $232);
     $237 = Math_fround($235 + $236);
     $238 = $237 < $229;
     if ($238) {
      $$ph = 2;$e0$0$ph = 1;
     } else {
      $e0$0 = 1;
      label = 17;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $239 = (($tri) + (($e0$0*12)|0)|0);
  $240 = (__ZN5physx2Gu18intersectRaySphereERKNS_6PxVec3ES3_fS3_fRfPS1_($center,$dir,Math_fround(3.40282346638528859812E+38),$239,$radius,$t3,0)|0);
  if (!($240)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $241 = Math_fround(HEAPF32[$t3>>2]);
  HEAPF32[$min_dist>>2] = $241;
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $242 = (($tri) + (($e0$0$ph*12)|0)|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 HEAPF32[$capsule>>2] = $243;
 $244 = (($capsule) + 4|0);
 $245 = ((($tri) + (($e0$0$ph*12)|0)|0) + 4|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 HEAPF32[$244>>2] = $246;
 $247 = (($capsule) + 8|0);
 $248 = ((($tri) + (($e0$0$ph*12)|0)|0) + 8|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 HEAPF32[$247>>2] = $249;
 $250 = (($capsule) + 12|0);
 $251 = (($tri) + (($$ph*12)|0)|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 HEAPF32[$250>>2] = $252;
 $253 = (($capsule) + 16|0);
 $254 = ((($tri) + (($$ph*12)|0)|0) + 4|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 HEAPF32[$253>>2] = $255;
 $256 = (($capsule) + 20|0);
 $257 = ((($tri) + (($$ph*12)|0)|0) + 8|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 HEAPF32[$256>>2] = $258;
 $259 = (($capsule) + 24|0);
 HEAPF32[$259>>2] = $radius;
 $260 = (__ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($center,$dir,$capsule,$s)|0);
 $261 = ($260|0)==(0);
 if ($261) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $262 = ($260|0)==(1);
 $263 = Math_fround(HEAPF32[$s>>2]);
 if ($262) {
  $t4$0 = $263;
 } else {
  $264 = (($s) + 4|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = $263 < $265;
  $$ = $266 ? $263 : $265;
  $t4$0 = $$;
 }
 $267 = !($t4$0 >= Math_fround(0.0));
 if ($267) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 HEAPF32[$min_dist>>2] = $t4$0;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx2Gu20sweepSphereTrianglesEjPKNS_10PxTriangleERKNS_6PxVec3EfS6_fPKjRS4_S9_RfRjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEEb($nbTris,$triangles,$center,$radius,$unitDir,$distance,$cachedIndex,$_hit,$_normal,$_t,$_index,$_outFlags,$isDoubleSided) {
 $nbTris = $nbTris|0;
 $triangles = $triangles|0;
 $center = $center|0;
 $radius = Math_fround($radius);
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $cachedIndex = $cachedIndex|0;
 $_hit = $_hit|0;
 $_normal = $_normal|0;
 $_t = $_t|0;
 $_index = $_index|0;
 $_outFlags = $_outFlags|0;
 $isDoubleSided = $isDoubleSided|0;
 var $$0 = 0, $$i$i = 0, $$i$i$us = 0, $$not$i = 0, $$not$i$us = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0;
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0;
 var $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0);
 var $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0;
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $currentDistance$i = 0, $exitcond = 0, $exitcond15 = 0, $hit = 0, $ii$08 = 0, $ii$08$us = 0, $initIndex$0$i = 0, $normal = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i$i$us = 0, $or$cond$i$us = 0, $or$cond1$i$i = 0, $or$cond1$i$i$us = 0;
 var $split = Math_fround(0), $split10 = 0, $split9 = Math_fround(0), $triNormal = 0, $triangleIndex$0$i = 0, $triangleIndex$0$i$us = 0, $triangleIndex$0$i37 = 0, $triangleIndex$0$i37$us = 0, $triangleIndex$0$i4 = 0, $triangleIndex$0$i4$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $currentDistance$i = sp + 36|0;
 $triNormal = sp;
 $hit = sp + 12|0;
 $normal = sp + 24|0;
 $0 = ($nbTris|0)==(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($cachedIndex|0)==(0|0);
 if ($1) {
  $initIndex$0$i = 0;
 } else {
  $2 = HEAP32[$cachedIndex>>2]|0;
  $initIndex$0$i = $2;
 }
 $3 = Math_fround(HEAPF32[$center>>2]);
 $4 = Math_fround(HEAPF32[$unitDir>>2]);
 $5 = Math_fround($3 * $4);
 $6 = (($center) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($unitDir) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 * $9);
 $11 = Math_fround($5 + $10);
 $12 = (($center) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($unitDir) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 * $15);
 $17 = Math_fround($11 + $16);
 $18 = (($triNormal) + 4|0);
 $19 = (($triNormal) + 8|0);
 if ($isDoubleSided) {
  $23 = $distance;$235 = Math_fround(0.0);$ii$08$us = 0;$triangleIndex$0$i37$us = -1;
  while(1) {
   $20 = ($ii$08$us|0)==(0);
   if ($20) {
    $triangleIndex$0$i$us = $initIndex$0$i;
   } else {
    $21 = ($ii$08$us|0)==($initIndex$0$i|0);
    $$i$i$us = $21 ? 0 : $ii$08$us;
    $triangleIndex$0$i$us = $$i$i$us;
   }
   $22 = (($triangles) + (($triangleIndex$0$i$us*36)|0)|0);
   $24 = (__ZN5physx2Gu13coarseCullingERKNS_6PxVec3ES3_ffRKNS_10PxTriangleE($center,$unitDir,$23,$radius,$22)|0);
   if ($24) {
    $25 = Math_fround(HEAPF32[$22>>2]);
    $26 = Math_fround(HEAPF32[$unitDir>>2]);
    $27 = Math_fround($25 * $26);
    $28 = ((($triangles) + (($triangleIndex$0$i$us*36)|0)|0) + 4|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = Math_fround(HEAPF32[$8>>2]);
    $31 = Math_fround($29 * $30);
    $32 = Math_fround($27 + $31);
    $33 = ((($triangles) + (($triangleIndex$0$i$us*36)|0)|0) + 8|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = Math_fround(HEAPF32[$14>>2]);
    $36 = Math_fround($34 * $35);
    $37 = Math_fround($32 + $36);
    $38 = ((($triangles) + (($triangleIndex$0$i$us*36)|0)|0) + 12|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = Math_fround($26 * $39);
    $41 = ((($triangles) + (($triangleIndex$0$i$us*36)|0)|0) + 16|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = Math_fround($30 * $42);
    $44 = Math_fround($40 + $43);
    $45 = ((($triangles) + (($triangleIndex$0$i$us*36)|0)|0) + 20|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = Math_fround($35 * $46);
    $48 = Math_fround($44 + $47);
    $49 = ((($triangles) + (($triangleIndex$0$i$us*36)|0)|0) + 24|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = Math_fround($26 * $50);
    $52 = ((($triangles) + (($triangleIndex$0$i$us*36)|0)|0) + 28|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = Math_fround($30 * $53);
    $55 = Math_fround($51 + $54);
    $56 = ((($triangles) + (($triangleIndex$0$i$us*36)|0)|0) + 32|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = Math_fround($35 * $57);
    $59 = Math_fround($55 + $58);
    $60 = $37 < $48;
    $61 = $60 ? $37 : $48;
    $62 = $61 < $59;
    $63 = $62 ? $61 : $59;
    $64 = Math_fround($17 + $23);
    $65 = Math_fround($64 + $radius);
    $66 = Math_fround($65 + Math_fround(0.00999999977648258209228));
    $67 = $63 > $66;
    if ($67) {
     $237 = $23;$238 = $235;$triangleIndex$0$i4$us = $triangleIndex$0$i37$us;
    } else {
     $68 = $37 < $17;
     $69 = $48 < $17;
     $or$cond$i$i$us = $68 & $69;
     $70 = $59 < $17;
     $or$cond1$i$i$us = $or$cond$i$i$us & $70;
     if ($or$cond1$i$i$us) {
      $237 = $23;$238 = $235;$triangleIndex$0$i4$us = $triangleIndex$0$i37$us;
     } else {
      $71 = Math_fround($39 - $25);
      $72 = Math_fround($42 - $29);
      $73 = Math_fround($46 - $34);
      $74 = Math_fround($50 - $25);
      $75 = Math_fround($53 - $29);
      $76 = Math_fround($57 - $34);
      $77 = Math_fround($72 * $76);
      $78 = Math_fround($73 * $75);
      $79 = Math_fround($77 - $78);
      $80 = Math_fround($73 * $74);
      $81 = Math_fround($71 * $76);
      $82 = Math_fround($80 - $81);
      $83 = Math_fround($71 * $75);
      $84 = Math_fround($72 * $74);
      $85 = Math_fround($83 - $84);
      HEAPF32[$triNormal>>2] = $79;
      HEAPF32[$18>>2] = $82;
      HEAPF32[$19>>2] = $85;
      $86 = Math_fround($79 * $79);
      $87 = Math_fround($82 * $82);
      $88 = Math_fround($86 + $87);
      $89 = Math_fround($85 * $85);
      $90 = Math_fround($89 + $88);
      $91 = (Math_fround(Math_sqrt((Math_fround($90)))));
      $92 = Math_fround($91 * Math_fround(0.5));
      $93 = $92 == Math_fround(0.0);
      if ($93) {
       $237 = $23;$238 = $235;$triangleIndex$0$i4$us = $triangleIndex$0$i37$us;
      } else {
       $94 = Math_fround(Math_fround(1.0) / $91);
       $95 = Math_fround($94 * $79);
       HEAPF32[$triNormal>>2] = $95;
       $96 = Math_fround($94 * $82);
       HEAPF32[$18>>2] = $96;
       $97 = Math_fround($94 * $85);
       HEAPF32[$19>>2] = $97;
       HEAPF32[$currentDistance$i>>2] = Math_fround(1.0E+4);
       $98 = (__ZN5physx2Gu14sweepTriSphereERKNS_10PxTriangleERKNS_6PxVec3ES6_fS6_Rf($22,$triNormal,$center,$radius,$unitDir,$currentDistance$i)|0);
       $$not$i$us = $98 ^ 1;
       $99 = Math_fround(HEAPF32[$currentDistance$i>>2]);
       $100 = $99 > $distance;
       $or$cond$i$us = $100 | $$not$i$us;
       if ($or$cond$i$us) {
        $237 = $23;$238 = $235;$triangleIndex$0$i4$us = $triangleIndex$0$i37$us;
       } else {
        $101 = Math_fround(HEAPF32[$triNormal>>2]);
        $102 = Math_fround(HEAPF32[$unitDir>>2]);
        $103 = Math_fround($101 * $102);
        $104 = Math_fround(HEAPF32[$18>>2]);
        $105 = Math_fround(HEAPF32[$8>>2]);
        $106 = Math_fround($104 * $105);
        $107 = Math_fround($103 + $106);
        $108 = Math_fround(HEAPF32[$19>>2]);
        $109 = Math_fround(HEAPF32[$14>>2]);
        $110 = Math_fround($108 * $109);
        $111 = Math_fround($107 + $110);
        $112 = Math_fround($111 * Math_fround(0.00999999977648258209228));
        $113 = Math_fround($99 + $112);
        HEAPF32[$currentDistance$i>>2] = $113;
        $114 = $113 > $23;
        if ($114) {
         $237 = $23;$238 = $235;$triangleIndex$0$i4$us = $triangleIndex$0$i37$us;
        } else {
         $237 = $113;$238 = $112;$triangleIndex$0$i4$us = $triangleIndex$0$i$us;
        }
       }
      }
     }
    }
   } else {
    $237 = $23;$238 = $235;$triangleIndex$0$i4$us = $triangleIndex$0$i37$us;
   }
   $115 = (($ii$08$us) + 1)|0;
   $exitcond15 = ($115|0)==($nbTris|0);
   if ($exitcond15) {
    $split = $238;$split10 = $triangleIndex$0$i4$us;$split9 = $237;
    break;
   } else {
    $23 = $237;$235 = $238;$ii$08$us = $115;$triangleIndex$0$i37$us = $triangleIndex$0$i4$us;
   }
  }
 } else {
  $119 = $distance;$236 = Math_fround(0.0);$ii$08 = 0;$triangleIndex$0$i37 = -1;
  while(1) {
   $116 = ($ii$08|0)==(0);
   if ($116) {
    $triangleIndex$0$i = $initIndex$0$i;
   } else {
    $117 = ($ii$08|0)==($initIndex$0$i|0);
    $$i$i = $117 ? 0 : $ii$08;
    $triangleIndex$0$i = $$i$i;
   }
   $118 = (($triangles) + (($triangleIndex$0$i*36)|0)|0);
   $120 = (__ZN5physx2Gu13coarseCullingERKNS_6PxVec3ES3_ffRKNS_10PxTriangleE($center,$unitDir,$119,$radius,$118)|0);
   if ($120) {
    $121 = Math_fround(HEAPF32[$118>>2]);
    $122 = Math_fround(HEAPF32[$unitDir>>2]);
    $123 = Math_fround($121 * $122);
    $124 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 4|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = Math_fround(HEAPF32[$8>>2]);
    $127 = Math_fround($125 * $126);
    $128 = Math_fround($123 + $127);
    $129 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 8|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $131 = Math_fround(HEAPF32[$14>>2]);
    $132 = Math_fround($130 * $131);
    $133 = Math_fround($128 + $132);
    $134 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 12|0);
    $135 = Math_fround(HEAPF32[$134>>2]);
    $136 = Math_fround($122 * $135);
    $137 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 16|0);
    $138 = Math_fround(HEAPF32[$137>>2]);
    $139 = Math_fround($126 * $138);
    $140 = Math_fround($136 + $139);
    $141 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 20|0);
    $142 = Math_fround(HEAPF32[$141>>2]);
    $143 = Math_fround($131 * $142);
    $144 = Math_fround($140 + $143);
    $145 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 24|0);
    $146 = Math_fround(HEAPF32[$145>>2]);
    $147 = Math_fround($122 * $146);
    $148 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 28|0);
    $149 = Math_fround(HEAPF32[$148>>2]);
    $150 = Math_fround($126 * $149);
    $151 = Math_fround($147 + $150);
    $152 = ((($triangles) + (($triangleIndex$0$i*36)|0)|0) + 32|0);
    $153 = Math_fround(HEAPF32[$152>>2]);
    $154 = Math_fround($131 * $153);
    $155 = Math_fround($151 + $154);
    $156 = $133 < $144;
    $157 = $156 ? $133 : $144;
    $158 = $157 < $155;
    $159 = $158 ? $157 : $155;
    $160 = Math_fround($17 + $119);
    $161 = Math_fround($160 + $radius);
    $162 = Math_fround($161 + Math_fround(0.00999999977648258209228));
    $163 = $159 > $162;
    if ($163) {
     $239 = $119;$240 = $236;$triangleIndex$0$i4 = $triangleIndex$0$i37;
    } else {
     $164 = $133 < $17;
     $165 = $144 < $17;
     $or$cond$i$i = $164 & $165;
     $166 = $155 < $17;
     $or$cond1$i$i = $or$cond$i$i & $166;
     if ($or$cond1$i$i) {
      $239 = $119;$240 = $236;$triangleIndex$0$i4 = $triangleIndex$0$i37;
     } else {
      $167 = Math_fround($135 - $121);
      $168 = Math_fround($138 - $125);
      $169 = Math_fround($142 - $130);
      $170 = Math_fround($146 - $121);
      $171 = Math_fround($149 - $125);
      $172 = Math_fround($153 - $130);
      $173 = Math_fround($168 * $172);
      $174 = Math_fround($169 * $171);
      $175 = Math_fround($173 - $174);
      $176 = Math_fround($169 * $170);
      $177 = Math_fround($167 * $172);
      $178 = Math_fround($176 - $177);
      $179 = Math_fround($167 * $171);
      $180 = Math_fround($168 * $170);
      $181 = Math_fround($179 - $180);
      HEAPF32[$triNormal>>2] = $175;
      HEAPF32[$18>>2] = $178;
      HEAPF32[$19>>2] = $181;
      $182 = Math_fround($175 * $175);
      $183 = Math_fround($178 * $178);
      $184 = Math_fround($182 + $183);
      $185 = Math_fround($181 * $181);
      $186 = Math_fround($185 + $184);
      $187 = (Math_fround(Math_sqrt((Math_fround($186)))));
      $188 = Math_fround($187 * Math_fround(0.5));
      $189 = $188 == Math_fround(0.0);
      if ($189) {
       $239 = $119;$240 = $236;$triangleIndex$0$i4 = $triangleIndex$0$i37;
      } else {
       $190 = Math_fround($175 * $122);
       $191 = Math_fround($178 * $126);
       $192 = Math_fround($190 + $191);
       $193 = Math_fround($181 * $131);
       $194 = Math_fround($192 + $193);
       $195 = $194 > Math_fround(0.0);
       if ($195) {
        $239 = $119;$240 = $236;$triangleIndex$0$i4 = $triangleIndex$0$i37;
       } else {
        $196 = Math_fround(Math_fround(1.0) / $187);
        $197 = Math_fround($196 * $175);
        HEAPF32[$triNormal>>2] = $197;
        $198 = Math_fround($196 * $178);
        HEAPF32[$18>>2] = $198;
        $199 = Math_fround($196 * $181);
        HEAPF32[$19>>2] = $199;
        HEAPF32[$currentDistance$i>>2] = Math_fround(1.0E+4);
        $200 = (__ZN5physx2Gu14sweepTriSphereERKNS_10PxTriangleERKNS_6PxVec3ES6_fS6_Rf($118,$triNormal,$center,$radius,$unitDir,$currentDistance$i)|0);
        $$not$i = $200 ^ 1;
        $201 = Math_fround(HEAPF32[$currentDistance$i>>2]);
        $202 = $201 > $distance;
        $or$cond$i = $202 | $$not$i;
        if ($or$cond$i) {
         $239 = $119;$240 = $236;$triangleIndex$0$i4 = $triangleIndex$0$i37;
        } else {
         $203 = Math_fround(HEAPF32[$triNormal>>2]);
         $204 = Math_fround(HEAPF32[$unitDir>>2]);
         $205 = Math_fround($203 * $204);
         $206 = Math_fround(HEAPF32[$18>>2]);
         $207 = Math_fround(HEAPF32[$8>>2]);
         $208 = Math_fround($206 * $207);
         $209 = Math_fround($205 + $208);
         $210 = Math_fround(HEAPF32[$19>>2]);
         $211 = Math_fround(HEAPF32[$14>>2]);
         $212 = Math_fround($210 * $211);
         $213 = Math_fround($209 + $212);
         $214 = Math_fround($213 * Math_fround(0.00999999977648258209228));
         $215 = Math_fround($201 + $214);
         HEAPF32[$currentDistance$i>>2] = $215;
         $216 = $215 > $119;
         if ($216) {
          $239 = $119;$240 = $236;$triangleIndex$0$i4 = $triangleIndex$0$i37;
         } else {
          $239 = $215;$240 = $214;$triangleIndex$0$i4 = $triangleIndex$0$i;
         }
        }
       }
      }
     }
    }
   } else {
    $239 = $119;$240 = $236;$triangleIndex$0$i4 = $triangleIndex$0$i37;
   }
   $217 = (($ii$08) + 1)|0;
   $exitcond = ($217|0)==($nbTris|0);
   if ($exitcond) {
    $split = $240;$split10 = $triangleIndex$0$i4;$split9 = $239;
    break;
   } else {
    $119 = $239;$236 = $240;$ii$08 = $217;$triangleIndex$0$i37 = $triangleIndex$0$i4;
   }
  }
 }
 $218 = ($split10|0)==(-1);
 if ($218) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $219 = Math_fround($split9 - $split);
 $220 = (($triangles) + (($split10*36)|0)|0);
 __ZN5physx2Gu17computeImpactDataERNS_6PxVec3ES2_RKS1_S4_fRKNS_10PxTriangleE($hit,$normal,$center,$unitDir,$219,$220);
 $221 = Math_fround(HEAPF32[$hit>>2]);
 HEAPF32[$_hit>>2] = $221;
 $222 = (($hit) + 4|0);
 $223 = Math_fround(HEAPF32[$222>>2]);
 $224 = (($_hit) + 4|0);
 HEAPF32[$224>>2] = $223;
 $225 = (($hit) + 8|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = (($_hit) + 8|0);
 HEAPF32[$227>>2] = $226;
 $228 = Math_fround(HEAPF32[$normal>>2]);
 HEAPF32[$_normal>>2] = $228;
 $229 = (($normal) + 4|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = (($_normal) + 4|0);
 HEAPF32[$231>>2] = $230;
 $232 = (($normal) + 8|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = (($_normal) + 8|0);
 HEAPF32[$234>>2] = $233;
 HEAPF32[$_t>>2] = $219;
 HEAP32[$_index>>2] = $split10;
 HEAP16[$_outFlags>>1] = 7;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu17computeImpactDataERNS_6PxVec3ES2_RKS1_S4_fRKNS_10PxTriangleE($hit,$normal,$center,$dir,$t,$tri) {
 $hit = $hit|0;
 $normal = $normal|0;
 $center = $center|0;
 $dir = $dir|0;
 $t = Math_fround($t);
 $tri = $tri|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $newSphereCenter = 0, $u = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $newSphereCenter = sp + 20|0;
 $u = sp;
 $v = sp + 4|0;
 $0 = sp + 8|0;
 $1 = Math_fround(HEAPF32[$dir>>2]);
 $2 = Math_fround($1 * $t);
 $3 = (($dir) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $t);
 $6 = (($dir) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $t);
 $9 = Math_fround(HEAPF32[$center>>2]);
 $10 = Math_fround($2 + $9);
 $11 = (($center) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($5 + $12);
 $14 = (($center) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($8 + $15);
 HEAPF32[$newSphereCenter>>2] = $10;
 $17 = (($newSphereCenter) + 4|0);
 HEAPF32[$17>>2] = $13;
 $18 = (($newSphereCenter) + 8|0);
 HEAPF32[$18>>2] = $16;
 $19 = (($tri) + 12|0);
 $20 = (($tri) + 24|0);
 __ZN5physx2Gu22closestPtPointTriangleERKNS_6PxVec3ES3_S3_S3_RfS4_($0,$newSphereCenter,$tri,$19,$20,$u,$v);
 $21 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$hit>>2] = $21;
 $22 = (($0) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($hit) + 4|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($0) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($hit) + 8|0);
 HEAPF32[$27>>2] = $26;
 $28 = Math_fround(HEAPF32[$newSphereCenter>>2]);
 $29 = Math_fround($28 - $21);
 $30 = Math_fround(HEAPF32[$17>>2]);
 $31 = Math_fround($30 - $23);
 $32 = Math_fround(HEAPF32[$18>>2]);
 $33 = Math_fround($32 - $26);
 HEAPF32[$normal>>2] = $29;
 $34 = (($normal) + 4|0);
 HEAPF32[$34>>2] = $31;
 $35 = (($normal) + 8|0);
 HEAPF32[$35>>2] = $33;
 $36 = Math_fround($29 * $29);
 $37 = Math_fround($31 * $31);
 $38 = Math_fround($36 + $37);
 $39 = Math_fround($33 * $33);
 $40 = Math_fround($39 + $38);
 $41 = (Math_fround(Math_sqrt((Math_fround($40)))));
 $42 = $41 > Math_fround(0.0);
 if ($42) {
  $43 = Math_fround(Math_fround(1.0) / $41);
  $44 = Math_fround($29 * $43);
  HEAPF32[$normal>>2] = $44;
  $45 = Math_fround($31 * $43);
  HEAPF32[$34>>2] = $45;
  $46 = Math_fround($33 * $43);
  HEAPF32[$35>>2] = $46;
 }
 $47 = $41 < Math_fround(0.00100000004749745130539);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (($tri) + 12|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround(HEAPF32[$tri>>2]);
 $51 = Math_fround($49 - $50);
 $52 = (($tri) + 16|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($tri) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($53 - $55);
 $57 = (($tri) + 20|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($tri) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($58 - $60);
 $62 = (($tri) + 24|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 - $50);
 $65 = (($tri) + 28|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 - $55);
 $68 = (($tri) + 32|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 - $60);
 $71 = Math_fround($56 * $70);
 $72 = Math_fround($61 * $67);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($61 * $64);
 $75 = Math_fround($51 * $70);
 $76 = Math_fround($74 - $75);
 $77 = Math_fround($51 * $67);
 $78 = Math_fround($56 * $64);
 $79 = Math_fround($77 - $78);
 HEAPF32[$normal>>2] = $73;
 HEAPF32[$34>>2] = $76;
 HEAPF32[$35>>2] = $79;
 $80 = Math_fround($73 * $73);
 $81 = Math_fround($76 * $76);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($79 * $79);
 $84 = Math_fround($83 + $82);
 $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
 $86 = $85 > Math_fround(0.0);
 if (!($86)) {
  STACKTOP = sp;return;
 }
 $87 = Math_fround(Math_fround(1.0) / $85);
 $88 = Math_fround($73 * $87);
 HEAPF32[$normal>>2] = $88;
 $89 = Math_fround($76 * $87);
 HEAPF32[$34>>2] = $89;
 $90 = Math_fround($79 * $87);
 HEAPF32[$35>>2] = $90;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu17computeImpactDataERNS_10PxSweepHitERKNS0_3BoxERKNS_6PxVec3ES8_S8_RKNS_10PxTriangleE($sweepHit,$box,$localDir,$localMotion,$oneOverMotion,$currentTriangle) {
 $sweepHit = $sweepHit|0;
 $box = $box|0;
 $localDir = $localDir|0;
 $localMotion = $localMotion|0;
 $oneOverMotion = $oneOverMotion|0;
 $currentTriangle = $currentTriangle|0;
 var $$$i$i$i$i$i = Math_fround(0), $$$i12$i$i$i$i = Math_fround(0), $$$i23$i$i$i$i = Math_fround(0), $$$i26$i$i$i$i = Math_fround(0), $$sroa$1$i$i$i = 0, $$sroa$1$i$i$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = 0;
 var $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0);
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $aabb = 0, $boxVertices = 0, $closestA$i = 0, $closestB$i = 0, $edges$03$i = 0, $exitcond$i = 0;
 var $fabsf$i$i$i = Math_fround(0), $fabsf$i1$i$i = Math_fround(0), $fabsf$i2$i$i = Math_fround(0), $fatEdges = 0, $i$04$i = 0, $normalV$i = 0, $or$cond$i$i = 0, $sqDistV$i = 0, $t = 0, $triangleV$i = 0, $v1$i = 0, $zero$sroa$1$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1360|0;
 $v1$i = sp + 32|0;
 $$sroa$1$i$i$i = sp + 224|0;
 $$sroa$1$i$i$i$i = sp + 384|0;
 $zero$sroa$1$i$i$i$i = sp + 1340|0;
 $triangleV$i = sp + 48|0;
 $closestA$i = sp + 192|0;
 $closestB$i = sp + 208|0;
 $normalV$i = sp + 16|0;
 $sqDistV$i = sp;
 $aabb = sp + 400|0;
 $boxVertices = sp + 424|0;
 $fatEdges = sp + 520|0;
 $t = sp + 1336|0;
 $0 = (($box) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(-$1);
 $3 = (($box) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$4);
 $6 = (($box) + 56|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(-$7);
 HEAPF32[$aabb>>2] = $2;
 $9 = (($aabb) + 4|0);
 HEAPF32[$9>>2] = $5;
 $10 = (($aabb) + 8|0);
 HEAPF32[$10>>2] = $8;
 $11 = (($aabb) + 12|0);
 HEAPF32[$11>>2] = $1;
 $12 = (($aabb) + 16|0);
 HEAPF32[$12>>2] = $4;
 $13 = (($aabb) + 20|0);
 HEAPF32[$13>>2] = $7;
 __ZN5physx2Gu16computeBoxPointsERKNS_9PxBounds3EPNS_6PxVec3E($aabb,$boxVertices);
 $14 = (__ZN5physx2Gu11getBoxEdgesEv()|0);
 $15 = (($localMotion) + 4|0);
 $16 = (($localMotion) + 8|0);
 $17 = (($v1$i) + 4|0);
 $18 = (($v1$i) + 8|0);
 $edges$03$i = $14;$i$04$i = 0;
 while(1) {
  $19 = (($edges$03$i) + 1|0);
  $20 = HEAP8[$edges$03$i>>0]|0;
  $21 = $20&255;
  $22 = (($boxVertices) + (($21*12)|0)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = ((($boxVertices) + (($21*12)|0)|0) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($boxVertices) + (($21*12)|0)|0) + 8|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($edges$03$i) + 2|0);
  $29 = HEAP8[$19>>0]|0;
  $30 = $29&255;
  $31 = (($boxVertices) + (($30*12)|0)|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = ((($boxVertices) + (($30*12)|0)|0) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = ((($boxVertices) + (($30*12)|0)|0) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($32 - $23);
  $38 = Math_fround($34 - $25);
  $39 = Math_fround($36 - $27);
  $40 = Math_fround($37 * $37);
  $41 = Math_fround($38 * $38);
  $42 = Math_fround($40 + $41);
  $43 = Math_fround($39 * $39);
  $44 = Math_fround($42 + $43);
  $45 = (Math_fround(Math_sqrt((Math_fround($44)))));
  $46 = $45 > Math_fround(0.0);
  if ($46) {
   $47 = Math_fround(Math_fround(0.00999999977648258209228) / $45);
   $48 = Math_fround($37 * $47);
   $49 = Math_fround($38 * $47);
   $50 = Math_fround($39 * $47);
   $51 = Math_fround($23 - $48);
   $52 = Math_fround($25 - $49);
   $53 = Math_fround($27 - $50);
   $54 = Math_fround($32 + $48);
   $55 = Math_fround($34 + $49);
   $56 = Math_fround($36 + $50);
   $73 = $51;$74 = $54;$76 = $52;$77 = $55;$79 = $53;$80 = $56;
  } else {
   $73 = $23;$74 = $32;$76 = $25;$77 = $34;$79 = $27;$80 = $36;
  }
  $57 = (550672 + (($i$04$i*12)|0)|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround(HEAPF32[$localMotion>>2]);
  $60 = Math_fround($58 * $59);
  $61 = ((550672 + (($i$04$i*12)|0)|0) + 4|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = Math_fround(HEAPF32[$15>>2]);
  $64 = Math_fround($62 * $63);
  $65 = Math_fround($60 + $64);
  $66 = ((550672 + (($i$04$i*12)|0)|0) + 8|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround(HEAPF32[$16>>2]);
  $69 = Math_fround($67 * $68);
  $70 = Math_fround($65 + $69);
  $71 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 64|0);
  HEAPF32[$71>>2] = $70;
  $72 = Math_fround($74 - $73);
  $75 = Math_fround($77 - $76);
  $78 = Math_fround($80 - $79);
  HEAPF32[$v1$i>>2] = $72;
  HEAPF32[$17>>2] = $75;
  HEAPF32[$18>>2] = $78;
  $81 = Math_fround($75 * $68);
  $82 = Math_fround($78 * $63);
  $83 = Math_fround($81 - $82);
  $84 = Math_fround($78 * $59);
  $85 = Math_fround($72 * $68);
  $86 = Math_fround($84 - $85);
  $87 = Math_fround($72 * $63);
  $88 = Math_fround($75 * $59);
  $89 = Math_fround($87 - $88);
  $90 = (($fatEdges) + (($i$04$i*68)|0)|0);
  HEAPF32[$90>>2] = $83;
  $91 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 4|0);
  HEAPF32[$91>>2] = $86;
  $92 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 8|0);
  HEAPF32[$92>>2] = $89;
  $93 = Math_fround($73 * $83);
  $94 = Math_fround($76 * $86);
  $95 = Math_fround($93 + $94);
  $96 = Math_fround($79 * $89);
  $97 = Math_fround($96 + $95);
  $98 = Math_fround(-$97);
  $99 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 12|0);
  HEAPF32[$99>>2] = $98;
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($83)))));
  $fabsf$i1$i$i = (Math_fround(Math_abs((Math_fround($86)))));
  $fabsf$i2$i$i = (Math_fround(Math_abs((Math_fround($89)))));
  $100 = $fabsf$i1$i$i > $fabsf$i$i$i;
  $101 = $fabsf$i1$i$i > $fabsf$i2$i$i;
  $or$cond$i$i = $100 & $101;
  if ($or$cond$i$i) {
   $104 = 2;$107 = 0;
  } else {
   $102 = $fabsf$i2$i$i > $fabsf$i$i$i;
   if ($102) {
    $104 = 0;$107 = 1;
   } else {
    $104 = 1;$107 = 2;
   }
  }
  $103 = (($v1$i) + ($104<<2)|0);
  $105 = Math_fround(HEAPF32[$103>>2]);
  $106 = (($localMotion) + ($107<<2)|0);
  $108 = Math_fround(HEAPF32[$106>>2]);
  $109 = Math_fround($105 * $108);
  $110 = (($v1$i) + ($107<<2)|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = (($localMotion) + ($104<<2)|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($111 * $113);
  $115 = Math_fround($109 - $114);
  $116 = Math_fround(Math_fround(1.0) / $115);
  $117 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 60|0);
  HEAPF32[$117>>2] = $116;
  $118 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 16|0);
  HEAPF32[$118>>2] = $73;
  $119 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 20|0);
  HEAPF32[$119>>2] = $76;
  $120 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 24|0);
  HEAPF32[$120>>2] = $79;
  $121 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 28|0);
  HEAPF32[$121>>2] = $74;
  $122 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 32|0);
  HEAPF32[$122>>2] = $77;
  $123 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 36|0);
  HEAPF32[$123>>2] = $80;
  $124 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 40|0);
  HEAPF32[$124>>2] = $72;
  $125 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 44|0);
  HEAPF32[$125>>2] = $75;
  $126 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 48|0);
  HEAPF32[$126>>2] = $78;
  $127 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 52|0);
  HEAP32[$127>>2] = $104;
  $128 = ((($fatEdges) + (($i$04$i*68)|0)|0) + 56|0);
  HEAP32[$128>>2] = $107;
  $129 = (($i$04$i) + 1)|0;
  $exitcond$i = ($129|0)==(12);
  if ($exitcond$i) {
   break;
  } else {
   $edges$03$i = $28;$i$04$i = $129;
  }
 }
 HEAPF32[$t>>2] = Math_fround(3.40282346638528859812E+38);
 $130 = (($sweepHit) + 16|0);
 $131 = (($sweepHit) + 28|0);
 $132 = (__ZN5physx2Gu16sweepBoxTriangleERKNS_10PxTriangleERKNS_9PxBounds3EPKNS_6PxVec3EPKNS0_11FatEdgeDataERS8_SD_RS7_SE_Rf($currentTriangle,$aabb,$boxVertices,$fatEdges,$localMotion,$oneOverMotion,$130,$131,$t)|0);
 if ($132) {
  STACKTOP = sp;return;
 }
 $133 = (($sweepHit) + 40|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround(HEAPF32[$localDir>>2]);
 $136 = Math_fround($134 * $135);
 $137 = (($localDir) + 4|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($134 * $138);
 $140 = (($localDir) + 8|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = Math_fround($134 * $141);
 $143 = Math_fround($135 * Math_fround(0.100000001490116119385));
 $144 = Math_fround($138 * Math_fround(0.100000001490116119385));
 $145 = Math_fround($141 * Math_fround(0.100000001490116119385));
 $146 = Math_fround($136 - $143);
 $147 = Math_fround($139 - $144);
 $148 = Math_fround($142 - $145);
 $149 = Math_fround(HEAPF32[$currentTriangle>>2]);
 $150 = Math_fround($149 - $146);
 $151 = (($currentTriangle) + 4|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = Math_fround($152 - $147);
 $154 = (($currentTriangle) + 8|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = Math_fround($155 - $148);
 $157 = (($currentTriangle) + 12|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround($158 - $146);
 $160 = (($currentTriangle) + 16|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = Math_fround($161 - $147);
 $163 = (($currentTriangle) + 20|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = Math_fround($164 - $148);
 $166 = (($currentTriangle) + 24|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = Math_fround($167 - $146);
 $169 = (($currentTriangle) + 28|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = Math_fround($170 - $147);
 $172 = (($currentTriangle) + 32|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround($173 - $148);
 $175 = (($triangleV$i) + 64|0);
 $176 = (($triangleV$i) + 80|0);
 HEAP32[$176>>2] = 7;
 $177 = (($triangleV$i) + 16|0);
 $178 = (($triangleV$i) + 20|0);
 $179 = (($triangleV$i) + 32|0);
 $180 = (($triangleV$i) + 36|0);
 $181 = (($triangleV$i) + 48|0);
 HEAPF32[$181>>2] = Math_fround(0.0);
 $182 = (($triangleV$i) + 52|0);
 ;HEAP32[$182+0>>2]=HEAP32[$$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$182+4>>2]=HEAP32[$$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$182+8>>2]=HEAP32[$$sroa$1$i$i$i$i+8>>2]|0;
 ;HEAP32[$v1$i+0>>2]=0|0;HEAP32[$v1$i+4>>2]=0|0;HEAP32[$v1$i+8>>2]=0|0;HEAP32[$v1$i+12>>2]=0|0;
 ;HEAP32[$175+0>>2]=HEAP32[$v1$i+0>>2]|0;HEAP32[$175+4>>2]=HEAP32[$v1$i+4>>2]|0;HEAP32[$175+8>>2]=HEAP32[$v1$i+8>>2]|0;HEAP32[$175+12>>2]=HEAP32[$v1$i+12>>2]|0;
 $183 = Math_fround($150 + $159);
 $184 = Math_fround($153 + $162);
 $185 = Math_fround($156 + $165);
 $186 = Math_fround($183 + $168);
 $187 = Math_fround($184 + $171);
 $188 = Math_fround($185 + $174);
 $189 = Math_fround($186 * Math_fround(0.333332985639572143555));
 $190 = Math_fround($187 * Math_fround(0.333332985639572143555));
 $191 = Math_fround($188 * Math_fround(0.333332985639572143555));
 HEAPF32[$triangleV$i>>2] = $189;
 $192 = (($triangleV$i) + 4|0);
 HEAPF32[$192>>2] = $190;
 $193 = (($triangleV$i) + 8|0);
 HEAPF32[$193>>2] = $191;
 $194 = (($triangleV$i) + 12|0);
 HEAPF32[$194>>2] = Math_fround(0.0);
 $195 = (($triangleV$i) + 96|0);
 HEAPF32[$195>>2] = $150;
 $196 = (($triangleV$i) + 100|0);
 HEAPF32[$196>>2] = $153;
 $197 = (($triangleV$i) + 104|0);
 HEAPF32[$197>>2] = $156;
 $198 = (($triangleV$i) + 108|0);
 HEAPF32[$198>>2] = Math_fround(0.0);
 $199 = (($triangleV$i) + 112|0);
 HEAPF32[$199>>2] = $159;
 $200 = (($triangleV$i) + 116|0);
 HEAPF32[$200>>2] = $162;
 $201 = (($triangleV$i) + 120|0);
 HEAPF32[$201>>2] = $165;
 $202 = (($triangleV$i) + 124|0);
 HEAPF32[$202>>2] = Math_fround(0.0);
 $203 = (($triangleV$i) + 128|0);
 HEAPF32[$203>>2] = $168;
 $204 = (($triangleV$i) + 132|0);
 HEAPF32[$204>>2] = $171;
 $205 = (($triangleV$i) + 136|0);
 HEAPF32[$205>>2] = $174;
 $206 = (($triangleV$i) + 140|0);
 HEAPF32[$206>>2] = Math_fround(0.0);
 HEAPF32[$177>>2] = Math_fround(0.0);
 ;HEAP32[$178+0>>2]=HEAP32[$zero$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$178+4>>2]=HEAP32[$zero$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$178+8>>2]=HEAP32[$zero$sroa$1$i$i$i$i+8>>2]|0;
 HEAPF32[$179>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$180+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$180+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$180+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $207 = Math_fround(HEAPF32[$0>>2]);
 $208 = Math_fround(HEAPF32[$3>>2]);
 $209 = Math_fround(HEAPF32[$6>>2]);
 $210 = (($$sroa$1$i$i$i) + 64|0);
 $211 = (($$sroa$1$i$i$i) + 80|0);
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 HEAP32[$211>>2] = 3;
 $212 = (($$sroa$1$i$i$i) + 16|0);
 $213 = (($$sroa$1$i$i$i) + 20|0);
 ;HEAP32[$213+0>>2]=HEAP32[$zero$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$213+4>>2]=HEAP32[$zero$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$zero$sroa$1$i$i$i$i+8>>2]|0;
 $214 = (($$sroa$1$i$i$i) + 32|0);
 $215 = (($$sroa$1$i$i$i) + 36|0);
 $216 = (($$sroa$1$i$i$i) + 48|0);
 HEAPF32[$216>>2] = Math_fround(0.0);
 $217 = (($$sroa$1$i$i$i) + 52|0);
 ;HEAP32[$217+0>>2]=HEAP32[$zero$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$217+4>>2]=HEAP32[$zero$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$217+8>>2]=HEAP32[$zero$sroa$1$i$i$i$i+8>>2]|0;
 ;HEAP32[$v1$i+0>>2]=0|0;HEAP32[$v1$i+4>>2]=0|0;HEAP32[$v1$i+8>>2]=0|0;HEAP32[$v1$i+12>>2]=0|0;
 ;HEAP32[$210+0>>2]=HEAP32[$v1$i+0>>2]|0;HEAP32[$210+4>>2]=HEAP32[$v1$i+4>>2]|0;HEAP32[$210+8>>2]=HEAP32[$v1$i+8>>2]|0;HEAP32[$210+12>>2]=HEAP32[$v1$i+12>>2]|0;
 $218 = (($$sroa$1$i$i$i) + 144|0);
 HEAPF32[$218>>2] = $207;
 $219 = (($$sroa$1$i$i$i) + 148|0);
 HEAPF32[$219>>2] = $208;
 $220 = (($$sroa$1$i$i$i) + 152|0);
 HEAPF32[$220>>2] = $209;
 $221 = (($$sroa$1$i$i$i) + 156|0);
 HEAPF32[$221>>2] = Math_fround(0.0);
 $222 = !($207 <= $208);
 $$$i26$i$i$i$i = $222 ? $208 : $207;
 $223 = !($$$i26$i$i$i$i <= $209);
 $224 = $223 ? $209 : $$$i26$i$i$i$i;
 $225 = !($207 >= $208);
 $$$i23$i$i$i$i = $225 ? $208 : $207;
 $226 = !($$$i23$i$i$i$i >= $209);
 $227 = $226 ? $209 : $$$i23$i$i$i$i;
 $228 = Math_fround($224 * Math_fround(0.150000005960464477539));
 $229 = Math_fround($227 * Math_fround(0.0299999993294477462769));
 $230 = $228 > $229;
 $$$i12$i$i$i$i = $230 ? $228 : $229;
 $231 = $224 > $$$i12$i$i$i$i;
 $$$i$i$i$i$i = $231 ? $$$i12$i$i$i$i : $224;
 HEAPF32[$212>>2] = $$$i$i$i$i$i;
 ;HEAP32[$213+0>>2]=HEAP32[$zero$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$213+4>>2]=HEAP32[$zero$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$zero$sroa$1$i$i$i$i+8>>2]|0;
 $232 = Math_fround($224 * Math_fround(0.0500000007450580596924));
 HEAPF32[$214>>2] = $232;
 ;HEAP32[$215+0>>2]=HEAP32[$$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$215+4>>2]=HEAP32[$$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$215+8>>2]=HEAP32[$$sroa$1$i$i$i$i+8>>2]|0;
 $233 = (($$sroa$1$i$i$i) + 96|0);
 HEAPF32[$233>>2] = Math_fround(1.0);
 $234 = (($$sroa$1$i$i$i) + 100|0);
 $235 = (($$sroa$1$i$i$i) + 116|0);
 ;HEAP32[$234+0>>2]=0|0;HEAP32[$234+4>>2]=0|0;HEAP32[$234+8>>2]=0|0;HEAP32[$234+12>>2]=0|0;
 HEAPF32[$235>>2] = Math_fround(1.0);
 $236 = (($$sroa$1$i$i$i) + 120|0);
 $237 = (($$sroa$1$i$i$i) + 136|0);
 ;HEAP32[$236+0>>2]=0|0;HEAP32[$236+4>>2]=0|0;HEAP32[$236+8>>2]=0|0;HEAP32[$236+12>>2]=0|0;
 HEAPF32[$237>>2] = Math_fround(1.0);
 $238 = (($$sroa$1$i$i$i) + 140|0);
 HEAPF32[$238>>2] = Math_fround(0.0);
 $239 = (__ZN5physx2Gu8GJKLocalERKNS0_9TriangleVERKNS0_4BoxVERNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVE($triangleV$i,$$sroa$1$i$i$i,$closestA$i,$closestB$i,$normalV$i,$sqDistV$i)|0);
 $240 = ($239|0)==(0);
 if ($240) {
  $241 = Math_fround(HEAPF32[$closestB$i>>2]);
  $242 = (($closestB$i) + 4|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = (($closestB$i) + 8|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = Math_fround(HEAPF32[$normalV$i>>2]);
  $247 = (($normalV$i) + 4|0);
  $248 = Math_fround(HEAPF32[$247>>2]);
  $249 = (($normalV$i) + 8|0);
  $250 = Math_fround(HEAPF32[$249>>2]);
  $251 = Math_fround(HEAPF32[$133>>2]);
  $252 = Math_fround(HEAPF32[$localDir>>2]);
  $253 = Math_fround($251 * $252);
  $254 = Math_fround(HEAPF32[$137>>2]);
  $255 = Math_fround($251 * $254);
  $256 = Math_fround(HEAPF32[$140>>2]);
  $257 = Math_fround($251 * $256);
  $258 = Math_fround($241 + $253);
  $259 = Math_fround($243 + $255);
  $260 = Math_fround($245 + $257);
  $261 = (($sweepHit) + 16|0);
  HEAPF32[$261>>2] = $258;
  $262 = (($sweepHit) + 20|0);
  HEAPF32[$262>>2] = $259;
  $263 = (($sweepHit) + 24|0);
  HEAPF32[$263>>2] = $260;
  $264 = Math_fround(-$246);
  $265 = Math_fround(-$248);
  $266 = Math_fround(-$250);
  $267 = (($sweepHit) + 28|0);
  HEAPF32[$267>>2] = $264;
  $268 = (($sweepHit) + 32|0);
  HEAPF32[$268>>2] = $265;
  $269 = (($sweepHit) + 36|0);
  HEAPF32[$269>>2] = $266;
  STACKTOP = sp;return;
 } else {
  $270 = (($box) + 36|0);
  $271 = Math_fround(HEAPF32[$270>>2]);
  $272 = (($sweepHit) + 16|0);
  HEAPF32[$272>>2] = $271;
  $273 = (($box) + 40|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = (($sweepHit) + 20|0);
  HEAPF32[$275>>2] = $274;
  $276 = (($box) + 44|0);
  $277 = Math_fround(HEAPF32[$276>>2]);
  $278 = (($sweepHit) + 24|0);
  HEAPF32[$278>>2] = $277;
  $279 = Math_fround(HEAPF32[$localDir>>2]);
  $280 = Math_fround(-$279);
  $281 = Math_fround(HEAPF32[$137>>2]);
  $282 = Math_fround(-$281);
  $283 = Math_fround(HEAPF32[$140>>2]);
  $284 = Math_fround(-$283);
  $285 = (($sweepHit) + 28|0);
  HEAPF32[$285>>2] = $280;
  $286 = (($sweepHit) + 32|0);
  HEAPF32[$286>>2] = $282;
  $287 = (($sweepHit) + 36|0);
  HEAPF32[$287>>2] = $284;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$pair,$aInd,$bInd,$_size,$contactA,$contactB,$normal,$penetrationDepth,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $pair = $pair|0;
 $aInd = $aInd|0;
 $bInd = $bInd|0;
 $_size = $_size|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i51 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i52 = Math_fround(0), $$ph = 0, $$ph245 = Math_fround(0), $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0;
 var $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0;
 var $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0);
 var $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0;
 var $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_initialSearchDir = 0, $closA = 0, $closB = 0, $epa = 0, $exitcond = 0;
 var $i$0250 = 0, $size = 0, $support = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 7152|0;
 $zeroV = sp + 7120|0;
 $size = sp + 7136|0;
 $A = sp + 7056|0;
 $B = sp + 6992|0;
 $Q = sp + 6928|0;
 $v = sp + 6912|0;
 $support = sp + 6896|0;
 $closA = sp + 64|0;
 $closB = sp + 48|0;
 $0 = sp + 32|0;
 $_initialSearchDir = sp + 16|0;
 $1 = sp;
 $epa = sp + 80|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $2 = $_size&255;
 HEAP32[$size>>2] = $2;
 $3 = (($a) + 32|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($b) + 32|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $4 > $6;
 $$$i = $7 ? $6 : $4;
 $8 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $9 = Math_fround($8 * $8);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $10 = ($_size<<24>>24)==(0);
 if ($10) {
  $128 = HEAP32[$pair>>2]|0;
  $129 = (($128) + 16|0);
  $130 = HEAP32[$129>>2]|0;
  FUNCTION_TABLE_vii[$130 & 4095]($_initialSearchDir,$pair);
  $131 = (($v) + 4|0);
  $132 = (($v) + 8|0);
  $133 = (($v) + 12|0);
  HEAPF32[$v>>2] = Math_fround(1.0);
  HEAPF32[$131>>2] = Math_fround(0.0);
  HEAPF32[$132>>2] = Math_fround(0.0);
  HEAPF32[$133>>2] = Math_fround(0.0);
  $$ph = 1;$$ph245 = Math_fround(3.40282346638528859812E+38);
 } else {
  $i$0250 = 0;
  while(1) {
   $11 = HEAP32[$pair>>2]|0;
   $12 = (($11) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($aInd) + ($i$0250)|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = $15&255;
   $17 = (($bInd) + ($i$0250)|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = $18&255;
   $20 = (($A) + ($i$0250<<4)|0);
   $21 = (($B) + ($i$0250<<4)|0);
   $22 = (($Q) + ($i$0250<<4)|0);
   FUNCTION_TABLE_viiiiii[$13 & 255]($pair,$16,$19,$20,$21,$22);
   $23 = (($i$0250) + 1)|0;
   $exitcond = ($23|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $i$0250 = $23;
   }
  }
  $$pre = HEAP32[$size>>2]|0;
  $24 = (($2) + -1)|0;
  $25 = (($A) + ($24<<4)|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = ((($A) + ($24<<4)|0) + 4|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = ((($A) + ($24<<4)|0) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = ((($A) + ($24<<4)|0) + 12|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($B) + ($24<<4)|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = ((($B) + ($24<<4)|0) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = ((($B) + ($24<<4)|0) + 8|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = ((($B) + ($24<<4)|0) + 12|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($26 - $34);
  $42 = Math_fround($28 - $36);
  $43 = Math_fround($30 - $38);
  HEAPF32[$support>>2] = $41;
  $44 = (($support) + 4|0);
  HEAPF32[$44>>2] = $42;
  $45 = (($support) + 8|0);
  HEAPF32[$45>>2] = $43;
  $46 = (($support) + 12|0);
  HEAPF32[$46>>2] = Math_fround(0.0);
  do {
   if ((($$pre|0) == 1)) {
    HEAPF32[$closA>>2] = $26;
    $47 = (($closA) + 4|0);
    HEAPF32[$47>>2] = $28;
    $48 = (($closA) + 8|0);
    HEAPF32[$48>>2] = $30;
    $49 = (($closA) + 12|0);
    HEAPF32[$49>>2] = $32;
    HEAPF32[$closB>>2] = $34;
    $50 = (($closB) + 4|0);
    HEAPF32[$50>>2] = $36;
    $51 = (($closB) + 8|0);
    HEAPF32[$51>>2] = $38;
    $52 = (($closB) + 12|0);
    HEAPF32[$52>>2] = $40;
    ;HEAP32[$0+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$support+12>>2]|0;
   } else if ((($$pre|0) == 3)) {
    $116 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($0,$Q,$116,$support,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($$pre|0) == 2)) {
    $53 = Math_fround(HEAPF32[$Q>>2]);
    $54 = (($Q) + 4|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = (($Q) + 8|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = Math_fround($41 - $53);
    $59 = Math_fround($42 - $55);
    $60 = Math_fround($43 - $57);
    $61 = Math_fround($58 * $58);
    $62 = Math_fround($59 * $59);
    $63 = Math_fround($61 + $62);
    $64 = Math_fround($60 * $60);
    $65 = Math_fround($63 + $64);
    $66 = $65 == Math_fround(0.0);
    if ($66) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$0+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $67 = Math_fround($55 * $59);
     $68 = Math_fround(-$67);
     $69 = Math_fround($53 * $58);
     $70 = Math_fround($68 - $69);
     $71 = Math_fround($57 * $60);
     $72 = Math_fround($70 - $71);
     $73 = Math_fround(HEAPF32[$A>>2]);
     $74 = (($A) + 4|0);
     $75 = Math_fround(HEAPF32[$74>>2]);
     $76 = (($A) + 8|0);
     $77 = Math_fround(HEAPF32[$76>>2]);
     $78 = Math_fround($26 - $73);
     $79 = Math_fround($28 - $75);
     $80 = Math_fround($30 - $77);
     $81 = Math_fround(HEAPF32[$B>>2]);
     $82 = (($B) + 4|0);
     $83 = Math_fround(HEAPF32[$82>>2]);
     $84 = (($B) + 8|0);
     $85 = Math_fround(HEAPF32[$84>>2]);
     $86 = Math_fround($34 - $81);
     $87 = Math_fround($36 - $83);
     $88 = Math_fround($38 - $85);
     $89 = Math_fround($72 / $65);
     $90 = $89 > Math_fround(1.0);
     $$$i$i$i51 = $90 ? Math_fround(1.0) : $89;
     $91 = $$$i$i$i51 > Math_fround(0.0);
     $$$i8$i$i52 = $91 ? $$$i$i$i51 : Math_fround(0.0);
     $92 = Math_fround($78 * $$$i8$i$i52);
     $93 = Math_fround($79 * $$$i8$i$i52);
     $94 = Math_fround($80 * $$$i8$i$i52);
     $95 = Math_fround($73 + $92);
     $96 = Math_fround($75 + $93);
     $97 = Math_fround($77 + $94);
     $98 = Math_fround($86 * $$$i8$i$i52);
     $99 = Math_fround($87 * $$$i8$i$i52);
     $100 = Math_fround($88 * $$$i8$i$i52);
     $101 = Math_fround($81 + $98);
     $102 = Math_fround($83 + $99);
     $103 = Math_fround($85 + $100);
     HEAPF32[$closA>>2] = $95;
     $104 = (($closA) + 4|0);
     HEAPF32[$104>>2] = $96;
     $105 = (($closA) + 8|0);
     HEAPF32[$105>>2] = $97;
     $106 = (($closA) + 12|0);
     HEAPF32[$106>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $101;
     $107 = (($closB) + 4|0);
     HEAPF32[$107>>2] = $102;
     $108 = (($closB) + 8|0);
     HEAPF32[$108>>2] = $103;
     $109 = (($closB) + 12|0);
     HEAPF32[$109>>2] = Math_fround(0.0);
     $110 = Math_fround($95 - $101);
     $111 = Math_fround($96 - $102);
     $112 = Math_fround($97 - $103);
     HEAPF32[$0>>2] = $110;
     $113 = (($0) + 4|0);
     HEAPF32[$113>>2] = $111;
     $114 = (($0) + 8|0);
     HEAPF32[$114>>2] = $112;
     $115 = (($0) + 12|0);
     HEAPF32[$115>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($$pre|0) == 4)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($0,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$0+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$support+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$0+12>>2]|0;
  $117 = Math_fround(HEAPF32[$v>>2]);
  $118 = (($v) + 4|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = (($v) + 8|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = Math_fround($117 * $117);
  $123 = Math_fround($119 * $119);
  $124 = Math_fround($122 + $123);
  $125 = Math_fround($121 * $121);
  $126 = Math_fround($124 + $125);
  $127 = $126 > $9;
  $$ph = $127;$$ph245 = $126;
 }
 if (!($$ph)) {
  HEAP32[$epa>>2] = 0;
  $238 = (($epa) + 6672|0);
  HEAP32[$238>>2] = 0;
  $239 = (($epa) + 6804|0);
  HEAP8[$239>>0] = 0;
  $240 = (($epa) + 6805|0);
  HEAP8[$240>>0] = 0;
  $241 = (($epa) + 6806|0);
  HEAP8[$241>>0] = 0;
  $242 = HEAP32[$size>>2]|0;
  $243 = (__ZN5physx2Gu3EPA16PenetrationDepthERKNS0_7ConvexVES4_PNS0_17EPASupportMapPairEPKNS_6shdfnd3aos5Vec3VESB_SB_iRS9_SC_SC_RNS8_6FloatVEb($epa,$a,$b,$pair,0,$A,$B,$242,$contactA,$contactB,$normal,$penetrationDepth,$takeCoreShape)|0);
  STACKTOP = sp;return ($243|0);
 }
 $134 = (($v) + 4|0);
 $135 = (($v) + 8|0);
 $136 = (($Q) + 4|0);
 $137 = (($Q) + 8|0);
 $138 = (($A) + 4|0);
 $139 = (($A) + 8|0);
 $140 = (($B) + 4|0);
 $141 = (($B) + 8|0);
 $142 = (($closA) + 4|0);
 $143 = (($closA) + 8|0);
 $144 = (($closA) + 12|0);
 $145 = (($closB) + 4|0);
 $146 = (($closB) + 8|0);
 $147 = (($closB) + 12|0);
 $148 = (($1) + 4|0);
 $149 = (($1) + 8|0);
 $150 = (($1) + 12|0);
 $151 = (($Q) + 16|0);
 $237 = $$ph245;
 while(1) {
  $152 = HEAP32[$pair>>2]|0;
  $153 = (($152) + 12|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = HEAP32[$size>>2]|0;
  $156 = (($A) + ($155<<4)|0);
  $157 = (($B) + ($155<<4)|0);
  $158 = (($Q) + ($155<<4)|0);
  FUNCTION_TABLE_viiiii[$154 & 255]($pair,$v,$156,$157,$158);
  $159 = HEAP32[$size>>2]|0;
  $160 = (($159) + 1)|0;
  HEAP32[$size>>2] = $160;
  $161 = (($Q) + ($159<<4)|0);
  $162 = (($A) + ($159<<4)|0);
  $163 = (($B) + ($159<<4)|0);
  do {
   if ((($159|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$162+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$162+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$162+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$162+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$163+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$163+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$163+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$163+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$161+12>>2]|0;
   } else if ((($159|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($1,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($159|0) == 2)) {
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($1,$Q,$151,$161,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($159|0) == 1)) {
    $164 = Math_fround(HEAPF32[$Q>>2]);
    $165 = Math_fround(HEAPF32[$136>>2]);
    $166 = Math_fround(HEAPF32[$137>>2]);
    $167 = Math_fround(HEAPF32[$161>>2]);
    $168 = (($Q) + 20|0);
    $169 = Math_fround(HEAPF32[$168>>2]);
    $170 = (($Q) + 24|0);
    $171 = Math_fround(HEAPF32[$170>>2]);
    $172 = Math_fround($167 - $164);
    $173 = Math_fround($169 - $165);
    $174 = Math_fround($171 - $166);
    $175 = Math_fround($172 * $172);
    $176 = Math_fround($173 * $173);
    $177 = Math_fround($175 + $176);
    $178 = Math_fround($174 * $174);
    $179 = Math_fround($177 + $178);
    $180 = $179 == Math_fround(0.0);
    if ($180) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $181 = Math_fround($165 * $173);
     $182 = Math_fround(-$181);
     $183 = Math_fround($164 * $172);
     $184 = Math_fround($182 - $183);
     $185 = Math_fround($166 * $174);
     $186 = Math_fround($184 - $185);
     $187 = Math_fround(HEAPF32[$162>>2]);
     $188 = (($A) + 20|0);
     $189 = Math_fround(HEAPF32[$188>>2]);
     $190 = (($A) + 24|0);
     $191 = Math_fround(HEAPF32[$190>>2]);
     $192 = Math_fround(HEAPF32[$A>>2]);
     $193 = Math_fround(HEAPF32[$138>>2]);
     $194 = Math_fround(HEAPF32[$139>>2]);
     $195 = Math_fround($187 - $192);
     $196 = Math_fround($189 - $193);
     $197 = Math_fround($191 - $194);
     $198 = Math_fround(HEAPF32[$163>>2]);
     $199 = (($B) + 20|0);
     $200 = Math_fround(HEAPF32[$199>>2]);
     $201 = (($B) + 24|0);
     $202 = Math_fround(HEAPF32[$201>>2]);
     $203 = Math_fround(HEAPF32[$B>>2]);
     $204 = Math_fround(HEAPF32[$140>>2]);
     $205 = Math_fround(HEAPF32[$141>>2]);
     $206 = Math_fround($198 - $203);
     $207 = Math_fround($200 - $204);
     $208 = Math_fround($202 - $205);
     $209 = Math_fround($186 / $179);
     $210 = $209 > Math_fround(1.0);
     $$$i$i$i = $210 ? Math_fround(1.0) : $209;
     $211 = $$$i$i$i > Math_fround(0.0);
     $$$i8$i$i = $211 ? $$$i$i$i : Math_fround(0.0);
     $212 = Math_fround($195 * $$$i8$i$i);
     $213 = Math_fround($196 * $$$i8$i$i);
     $214 = Math_fround($197 * $$$i8$i$i);
     $215 = Math_fround($192 + $212);
     $216 = Math_fround($193 + $213);
     $217 = Math_fround($194 + $214);
     $218 = Math_fround($206 * $$$i8$i$i);
     $219 = Math_fround($207 * $$$i8$i$i);
     $220 = Math_fround($208 * $$$i8$i$i);
     $221 = Math_fround($203 + $218);
     $222 = Math_fround($204 + $219);
     $223 = Math_fround($205 + $220);
     HEAPF32[$closA>>2] = $215;
     HEAPF32[$142>>2] = $216;
     HEAPF32[$143>>2] = $217;
     HEAPF32[$144>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $221;
     HEAPF32[$145>>2] = $222;
     HEAPF32[$146>>2] = $223;
     HEAPF32[$147>>2] = Math_fround(0.0);
     $224 = Math_fround($215 - $221);
     $225 = Math_fround($216 - $222);
     $226 = Math_fround($217 - $223);
     HEAPF32[$1>>2] = $224;
     HEAPF32[$148>>2] = $225;
     HEAPF32[$149>>2] = $226;
     HEAPF32[$150>>2] = Math_fround(0.0);
     break;
    }
   } else {
    ;HEAP32[$1+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$161+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$1+12>>2]|0;
  $227 = Math_fround(HEAPF32[$v>>2]);
  $228 = Math_fround(HEAPF32[$134>>2]);
  $229 = Math_fround(HEAPF32[$135>>2]);
  $230 = Math_fround($227 * $227);
  $231 = Math_fround($228 * $228);
  $232 = Math_fround($230 + $231);
  $233 = Math_fround($229 * $229);
  $234 = Math_fround($232 + $233);
  $235 = $234 > $9;
  if (!($235)) {
   label = 26;
   break;
  }
  $236 = $237 > $234;
  if ($236) {
   $237 = $234;
  } else {
   label = 26;
   break;
  }
 }
 if ((label|0) == 26) {
  HEAP32[$epa>>2] = 0;
  $238 = (($epa) + 6672|0);
  HEAP32[$238>>2] = 0;
  $239 = (($epa) + 6804|0);
  HEAP8[$239>>0] = 0;
  $240 = (($epa) + 6805|0);
  HEAP8[$240>>0] = 0;
  $241 = (($epa) + 6806|0);
  HEAP8[$241>>0] = 0;
  $242 = HEAP32[$size>>2]|0;
  $243 = (__ZN5physx2Gu3EPA16PenetrationDepthERKNS0_7ConvexVES4_PNS0_17EPASupportMapPairEPKNS_6shdfnd3aos5Vec3VESB_SB_iRS9_SC_SC_RNS8_6FloatVEb($epa,$a,$b,$pair,0,$A,$B,$242,$contactA,$contactB,$normal,$penetrationDepth,$takeCoreShape)|0);
  STACKTOP = sp;return ($243|0);
 }
 return 0|0;
}
function __ZN5physx2Gu3EPA16PenetrationDepthERKNS0_7ConvexVES4_PNS0_17EPASupportMapPairEPKNS_6shdfnd3aos5Vec3VESB_SB_iRS9_SC_SC_RNS8_6FloatVEb($this,$a,$b,$pair,$0,$A,$B,$size,$pa,$pb,$normal,$penDepth,$takeCoreShape) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 $pair = $pair|0;
 $0 = $0|0;
 $A = $A|0;
 $B = $B|0;
 $size = $size|0;
 $pa = $pa|0;
 $pb = $pb|0;
 $normal = $normal|0;
 $penDepth = $penDepth|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$$i = Math_fround(0), $$$i240 = Math_fround(0), $$$i241 = Math_fround(0), $$$i61 = Math_fround(0), $$0 = 0, $$demorgan = 0, $$pre = Math_fround(0), $$sroa$179 = 0, $$sum = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0);
 var $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0;
 var $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0;
 var $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0);
 var $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0;
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0);
 var $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0);
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0);
 var $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0);
 var $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0);
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0);
 var $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = Math_fround(0), $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0);
 var $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = 0, $480 = Math_fround(0), $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = 0, $486 = Math_fround(0), $487 = 0;
 var $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = Math_fround(0), $497 = 0, $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0);
 var $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0);
 var $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = Math_fround(0), $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = Math_fround(0), $567 = 0, $568 = Math_fround(0), $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = Math_fround(0), $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = Math_fround(0);
 var $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = Math_fround(0), $583 = 0, $584 = Math_fround(0), $585 = 0, $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = Math_fround(0), $592 = 0, $593 = Math_fround(0), $594 = 0, $595 = Math_fround(0);
 var $596 = 0, $597 = Math_fround(0), $598 = 0, $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = 0, $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = 0, $605 = Math_fround(0), $606 = 0, $607 = Math_fround(0), $608 = 0, $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = Math_fround(0), $612 = 0;
 var $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0);
 var $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = 0, $645 = 0, $646 = 0, $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0);
 var $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = 0, $654 = 0, $655 = 0, $656 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_max = 0, $_pa = 0, $_pa1 = 0, $_pa3 = 0, $_pa5 = 0, $_pb = 0, $_pb2 = 0, $_pb4 = 0, $_pb6 = 0, $a$01$i = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i35 = Math_fround(0), $i$0$lcssa$i = 0, $i$01$i = 0, $i$0247 = 0;
 var $indvars$iv$i = 0, $inflated_lower_bound2 = 0, $inflated_upper_bound2 = 0, $lastFacet$0$lcssa = 0, $lastFacet$0246 = 0, $numVertsLocal = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $q = 0, $tempa = 0, $tempb = 0, $zero = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $zero = sp + 240|0;
 $_max = sp + 224|0;
 $numVertsLocal = sp + 256|0;
 $inflated_upper_bound2 = sp + 208|0;
 $tempa = sp + 192|0;
 $tempb = sp + 176|0;
 $q = sp + 160|0;
 $1 = sp + 144|0;
 $_pa = sp + 48|0;
 $_pb = sp;
 $$sroa$179 = sp + 260|0;
 $inflated_lower_bound2 = sp + 16|0;
 $_pa1 = sp + 32|0;
 $_pb2 = sp + 64|0;
 $_pa3 = sp + 80|0;
 $_pb4 = sp + 96|0;
 $_pa5 = sp + 112|0;
 $_pb6 = sp + 128|0;
 $2 = (($this) + 2320|0);
 $3 = (($this) + 2448|0);
 HEAPF32[$zero>>2] = Math_fround(0.0);
 HEAPF32[$_max>>2] = Math_fround(3.40282346638528859812E+38);
 $4 = (($this) + 272|0);
 ;HEAP32[$4+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$A+12>>2]|0;
 $5 = (($this) + 288|0);
 $6 = (($A) + 16|0);
 ;HEAP32[$5+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$6+12>>2]|0;
 $7 = (($this) + 304|0);
 $8 = (($A) + 32|0);
 ;HEAP32[$7+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$8+12>>2]|0;
 $9 = (($this) + 320|0);
 $10 = (($A) + 48|0);
 ;HEAP32[$9+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$10+12>>2]|0;
 $11 = (($this) + 1296|0);
 ;HEAP32[$11+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$B+12>>2]|0;
 $12 = (($this) + 1312|0);
 $13 = (($B) + 16|0);
 ;HEAP32[$12+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$13+12>>2]|0;
 $14 = (($this) + 1328|0);
 $15 = (($B) + 32|0);
 ;HEAP32[$14+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$15+12>>2]|0;
 $16 = (($this) + 1344|0);
 $17 = (($B) + 48|0);
 ;HEAP32[$16+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$17+12>>2]|0;
 HEAP32[$numVertsLocal>>2] = 0;
 HEAP32[$this>>2] = 0;
 do {
  if ((($size|0) == 3)) {
   $19 = (__ZN5physx2Gu3EPA14expandTriangleERKNS0_7ConvexVES4_PNS0_17EPASupportMapPairERi($this,0,0,$pair,$numVertsLocal)|0);
   if ($19) {
    $656 = Math_fround(3.40282346638528859812E+38);
   } else {
    $$0 = 4;
    STACKTOP = sp;return ($$0|0);
   }
  } else if ((($size|0) == 2)) {
   $18 = (__ZN5physx2Gu3EPA13expandSegmentERKNS0_7ConvexVES4_PNS0_17EPASupportMapPairERi($this,$a,$b,$pair,$numVertsLocal)|0);
   if ($18) {
    $656 = Math_fround(3.40282346638528859812E+38);
   } else {
    $$0 = 4;
    STACKTOP = sp;return ($$0|0);
   }
  } else if ((($size|0) == 4)) {
   $20 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,0,1,2,$zero,$_max)|0);
   $21 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,0,3,1,$zero,$_max)|0);
   $22 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,0,2,3,$zero,$_max)|0);
   $23 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,1,3,2,$zero,$_max)|0);
   $24 = ($20|0)==(0|0);
   $25 = ($21|0)==(0|0);
   $or$cond = $24 | $25;
   $26 = ($22|0)==(0|0);
   $or$cond1 = $or$cond | $26;
   $27 = ($23|0)==(0|0);
   $or$cond2 = $or$cond1 | $27;
   if ($or$cond2) {
    $$0 = 4;
    STACKTOP = sp;return ($$0|0);
   }
   $28 = HEAP32[$this>>2]|0;
   $29 = ($28|0)==(0);
   if ($29) {
    $$0 = 4;
    STACKTOP = sp;return ($$0|0);
   } else {
    $30 = (($20) + 40|0);
    HEAP32[$30>>2] = $21;
    $31 = (($20) + 52|0);
    HEAP8[$31>>0] = 2;
    $32 = (($21) + 48|0);
    HEAP32[$32>>2] = $20;
    $33 = (($21) + 54|0);
    HEAP8[$33>>0] = 0;
    $34 = (($20) + 44|0);
    HEAP32[$34>>2] = $23;
    $35 = (($20) + 53|0);
    HEAP8[$35>>0] = 2;
    $36 = (($23) + 48|0);
    HEAP32[$36>>2] = $20;
    $37 = (($23) + 54|0);
    HEAP8[$37>>0] = 1;
    $38 = (($20) + 48|0);
    HEAP32[$38>>2] = $22;
    $39 = (($20) + 54|0);
    HEAP8[$39>>0] = 0;
    $40 = (($22) + 40|0);
    HEAP32[$40>>2] = $20;
    $41 = (($22) + 52|0);
    HEAP8[$41>>0] = 2;
    $42 = (($21) + 40|0);
    HEAP32[$42>>2] = $22;
    $43 = (($21) + 52|0);
    HEAP8[$43>>0] = 2;
    $44 = (($22) + 48|0);
    HEAP32[$44>>2] = $21;
    $45 = (($22) + 54|0);
    HEAP8[$45>>0] = 0;
    $46 = (($21) + 44|0);
    HEAP32[$46>>2] = $23;
    $47 = (($21) + 53|0);
    HEAP8[$47>>0] = 0;
    $48 = (($23) + 40|0);
    HEAP32[$48>>2] = $21;
    $49 = (($23) + 52|0);
    HEAP8[$49>>0] = 1;
    $50 = (($22) + 44|0);
    HEAP32[$50>>2] = $23;
    $51 = (($22) + 53|0);
    HEAP8[$51>>0] = 1;
    $52 = (($23) + 44|0);
    HEAP32[$52>>2] = $22;
    $53 = (($23) + 53|0);
    HEAP8[$53>>0] = 1;
    HEAP32[$numVertsLocal>>2] = 4;
    $$pre = Math_fround(HEAPF32[$_max>>2]);
    $656 = $$pre;
    break;
   }
  } else if ((($size|0) == 1)) {
   $$0 = 4;
   STACKTOP = sp;return ($$0|0);
  } else {
   $656 = Math_fround(3.40282346638528859812E+38);
  }
 } while(0);
 ;HEAP32[$inflated_upper_bound2+0>>2]=HEAP32[$_max+0>>2]|0;HEAP32[$inflated_upper_bound2+4>>2]=HEAP32[$_max+4>>2]|0;HEAP32[$inflated_upper_bound2+8>>2]=HEAP32[$_max+8>>2]|0;HEAP32[$inflated_upper_bound2+12>>2]=HEAP32[$_max+12>>2]|0;
 $54 = (($this) + 6676|0);
 $55 = (($this) + 6806|0);
 $56 = (($this) + 4|0);
 $57 = (($this) + 6416|0);
 $58 = (($this) + 6544|0);
 $59 = (($this) + 6672|0);
 $60 = (($1) + 4|0);
 $61 = (($1) + 8|0);
 $62 = (($1) + 12|0);
 $63 = (($q) + 4|0);
 $64 = (($q) + 8|0);
 $65 = (($inflated_upper_bound2) + 4|0);
 $66 = (($this) + 6420|0);
 $67 = (($this) + 6804|0);
 $68 = (($this) + 6805|0);
 $$$i241 = $656;
 L15: while(1) {
  $69 = HEAP8[$55>>0]|0;
  $70 = ($69<<24>>24)==(0);
  if (!($70)) {
   $71 = $69&255;
   $a$01$i = $69;$indvars$iv$i = $71;
   while(1) {
    $72 = (($indvars$iv$i) + -1)|0;
    $73 = ((($this) + ($72)|0) + 6740|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = HEAP8[$67>>0]|0;
    $77 = $76&255;
    $78 = (($77) + -1)|0;
    $79 = ($75|0)==($78|0);
    if ($79) {
     $80 = (($76) + -1)<<24>>24;
     HEAP8[$67>>0] = $80;
    } else {
     $81 = HEAP8[$68>>0]|0;
     $82 = (($81) + 1)<<24>>24;
     HEAP8[$68>>0] = $82;
     $83 = $81&255;
     $84 = ((($this) + ($83)|0) + 6676|0);
     HEAP8[$84>>0] = $74;
    }
    $85 = (($a$01$i) + -1)<<24>>24;
    $86 = ($85<<24>>24)==(0);
    if ($86) {
     break;
    } else {
     $a$01$i = $85;$indvars$iv$i = $72;
    }
   }
  }
  HEAP8[$55>>0] = 0;
  $87 = HEAP32[$this>>2]|0;
  $88 = (($87) + -1)|0;
  HEAP32[$this>>2] = $88;
  $89 = HEAP32[$56>>2]|0;
  $90 = ((($this) + ($88<<2)|0) + 4|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($88|0)>(1);
  L26: do {
   if ($92) {
    $93 = (($91) + 12|0);
    $94 = HEAP32[$93>>2]|0;
    $96 = 1;$i$01$i = 0;
    while(1) {
     $95 = (($96) + 1)|0;
     $97 = ($95|0)<($88|0);
     $98 = ((($this) + ($95<<2)|0) + 4|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ((($this) + ($96<<2)|0) + 4|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (($99) + 12|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = (($101) + 12|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = ($103>>>0)<($105>>>0);
     $107 = $97 & $106;
     $108 = $107&1;
     $109 = (($108) + ($96))|0;
     $110 = ((($this) + ($109<<2)|0) + 4|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = (($111) + 12|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = ($113>>>0)<($94>>>0);
     if (!($114)) {
      $i$0$lcssa$i = $i$01$i;
      break L26;
     }
     $115 = ((($this) + ($i$01$i<<2)|0) + 4|0);
     HEAP32[$115>>2] = $111;
     $116 = $109 << 1;
     $117 = $116 | 1;
     $118 = ($117|0)<($88|0);
     if ($118) {
      $96 = $117;$i$01$i = $109;
     } else {
      $i$0$lcssa$i = $109;
      break;
     }
    }
   } else {
    $i$0$lcssa$i = 0;
   }
  } while(0);
  $119 = ((($this) + ($i$0$lcssa$i<<2)|0) + 4|0);
  HEAP32[$119>>2] = $91;
  $120 = (($89) + 59|0);
  HEAP8[$120>>0] = 0;
  $121 = (($89) + 58|0);
  $122 = HEAP8[$121>>0]|0;
  $123 = ($122<<24>>24)==(0);
  if ($123) {
   $124 = (($89) + 12|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = Math_fround(HEAPF32[$89>>2]);
   $127 = (($89) + 4|0);
   $128 = Math_fround(HEAPF32[$127>>2]);
   $129 = (($89) + 8|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = HEAP32[$pair>>2]|0;
   $132 = (($131) + 12|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = Math_fround(-$126);
   $135 = Math_fround(-$128);
   $136 = Math_fround(-$130);
   HEAPF32[$1>>2] = $134;
   HEAPF32[$60>>2] = $135;
   HEAPF32[$61>>2] = $136;
   HEAPF32[$62>>2] = Math_fround(0.0);
   FUNCTION_TABLE_viiiii[$133 & 255]($pair,$1,$tempa,$tempb,$q);
   $137 = HEAP32[$numVertsLocal>>2]|0;
   $$sum = (($137) + 8)|0;
   $138 = ((($this) + ($$sum<<4)|0) + 272|0);
   $139 = ((($this) + ($$sum<<4)|0) + 1296|0);
   $140 = Math_fround(HEAPF32[$q>>2]);
   $141 = Math_fround(HEAPF32[$63>>2]);
   $142 = Math_fround(HEAPF32[$64>>2]);
   $143 = Math_fround($126 * $140);
   $144 = Math_fround($128 * $141);
   $145 = Math_fround($143 + $144);
   $146 = Math_fround($130 * $142);
   $147 = Math_fround($145 + $146);
   $148 = Math_fround($147 * $147);
   $149 = $148 < Math_fround(9.99999997475242707878E-7);
   $$$i61 = $149 ? Math_fround(9.99999997475242707878E-7) : $148;
   $150 = Math_fround($$$i61 / $125);
   $151 = $$$i241 > $150;
   $$$i = $151 ? $150 : $$$i241;
   $152 = (($89) + 16|0);
   $153 = Math_fround($125 - $$$i);
   $fabsf$i$i$i35 = (Math_fround(Math_abs((Math_fround($153)))));
   $154 = !($fabsf$i$i$i35 <= Math_fround(9.99999997475242707878E-7));
   if (!($154)) {
    label = 21;
    break;
   }
   $155 = (($152) + 4|0);
   $156 = (($152) + 8|0);
   $157 = Math_fround(HEAPF32[$155>>2]);
   $158 = Math_fround(HEAPF32[$152>>2]);
   $159 = Math_fround($141 * $157);
   $160 = Math_fround($140 * $158);
   $161 = Math_fround(HEAPF32[$156>>2]);
   $162 = (($89) + 28|0);
   $163 = Math_fround($142 * $161);
   $164 = Math_fround($159 + $160);
   $165 = Math_fround(HEAPF32[$162>>2]);
   $166 = Math_fround($164 + $163);
   $167 = Math_fround($166 - $165);
   $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($167)))));
   $168 = !($fabsf$i$i$i <= Math_fround(9.99999997475242707878E-7));
   if (!($168)) {
    label = 21;
    break;
   }
   $260 = ((($this) + ($137<<4)|0) + 272|0);
   ;HEAP32[$260+0>>2]=HEAP32[$tempa+0>>2]|0;HEAP32[$260+4>>2]=HEAP32[$tempa+4>>2]|0;HEAP32[$260+8>>2]=HEAP32[$tempa+8>>2]|0;HEAP32[$260+12>>2]=HEAP32[$tempa+12>>2]|0;
   $261 = ((($this) + ($137<<4)|0) + 1296|0);
   ;HEAP32[$261+0>>2]=HEAP32[$tempb+0>>2]|0;HEAP32[$261+4>>2]=HEAP32[$tempb+4>>2]|0;HEAP32[$261+8>>2]=HEAP32[$tempb+8>>2]|0;HEAP32[$261+12>>2]=HEAP32[$tempb+12>>2]|0;
   $262 = (($137) + 1)|0;
   HEAP32[$numVertsLocal>>2] = $262;
   $263 = Math_fround($$$i + Math_fround(9.99999905104687059065E-9));
   HEAPF32[$inflated_upper_bound2>>2] = $263;
   ;HEAP32[$65+0>>2]=HEAP32[$$sroa$179+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$$sroa$179+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$$sroa$179+8>>2]|0;
   $264 = Math_fround($125 + Math_fround(-9.99999905104687059065E-9));
   HEAPF32[$inflated_lower_bound2>>2] = $264;
   HEAP32[$59>>2] = 0;
   HEAP8[$121>>0] = 1;
   $265 = (($89) + 40|0);
   $266 = HEAP32[$265>>2]|0;
   $267 = (($89) + 52|0);
   $268 = HEAP8[$267>>0]|0;
   $269 = $268 << 24 >> 24;
   __ZN5physx2Gu5Facet10silhouetteEjRKNS_6shdfnd3aos5Vec3VERNS0_10EdgeBufferERNS0_15EPAFacetManagerE($266,$269,$q,$57,$54);
   $270 = (($89) + 44|0);
   $271 = HEAP32[$270>>2]|0;
   $272 = (($89) + 53|0);
   $273 = HEAP8[$272>>0]|0;
   $274 = $273 << 24 >> 24;
   __ZN5physx2Gu5Facet10silhouetteEjRKNS_6shdfnd3aos5Vec3VERNS0_10EdgeBufferERNS0_15EPAFacetManagerE($271,$274,$q,$57,$54);
   $275 = (($89) + 48|0);
   $276 = HEAP32[$275>>2]|0;
   $277 = (($89) + 54|0);
   $278 = HEAP8[$277>>0]|0;
   $279 = $278 << 24 >> 24;
   __ZN5physx2Gu5Facet10silhouetteEjRKNS_6shdfnd3aos5Vec3VERNS0_10EdgeBufferERNS0_15EPAFacetManagerE($276,$279,$q,$57,$54);
   $280 = HEAP32[$59>>2]|0;
   $281 = ($280|0)==(0);
   if ($281) {
    $$0 = 4;
    label = 41;
    break;
   }
   $282 = HEAP32[$57>>2]|0;
   $283 = HEAP32[$66>>2]|0;
   $284 = (550816 + ($283<<2)|0);
   $285 = HEAP32[$284>>2]|0;
   $286 = ((($282) + ($285)|0) + 55|0);
   $287 = HEAP8[$286>>0]|0;
   $288 = $287 << 24 >> 24;
   $289 = ((($282) + ($283)|0) + 55|0);
   $290 = HEAP8[$289>>0]|0;
   $291 = $290 << 24 >> 24;
   $292 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,$288,$291,$137,$inflated_lower_bound2,$inflated_upper_bound2)|0);
   $293 = ($292|0)==(0|0);
   if ($293) {
    label = 24;
    break;
   }
   $385 = HEAP32[$57>>2]|0;
   $386 = HEAP32[$66>>2]|0;
   $387 = (($292) + 40|0);
   HEAP32[$387>>2] = $385;
   $388 = $386&255;
   $389 = (($292) + 52|0);
   HEAP8[$389>>0] = $388;
   $390 = ((($385) + ($386<<2)|0) + 40|0);
   HEAP32[$390>>2] = $292;
   $391 = ((($385) + ($386)|0) + 52|0);
   HEAP8[$391>>0] = 0;
   $392 = HEAP32[$59>>2]|0;
   $393 = ($392>>>0)>(1);
   if ($393) {
    $i$0247 = 1;$lastFacet$0246 = $292;
    while(1) {
     $396 = ((($this) + ($i$0247<<3)|0) + 6416|0);
     $397 = HEAP32[$396>>2]|0;
     $398 = ((($this) + ($i$0247<<3)|0) + 6420|0);
     $399 = HEAP32[$398>>2]|0;
     $400 = (550816 + ($399<<2)|0);
     $401 = HEAP32[$400>>2]|0;
     $402 = ((($397) + ($401)|0) + 55|0);
     $403 = HEAP8[$402>>0]|0;
     $404 = $403 << 24 >> 24;
     $405 = ((($397) + ($399)|0) + 55|0);
     $406 = HEAP8[$405>>0]|0;
     $407 = $406 << 24 >> 24;
     $408 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,$404,$407,$137,$inflated_lower_bound2,$inflated_upper_bound2)|0);
     $409 = ($408|0)==(0|0);
     if ($409) {
      label = 33;
      break L15;
     }
     $410 = HEAP32[$396>>2]|0;
     $411 = HEAP32[$398>>2]|0;
     $412 = (($408) + 40|0);
     HEAP32[$412>>2] = $410;
     $413 = $411&255;
     $414 = (($408) + 52|0);
     HEAP8[$414>>0] = $413;
     $415 = ((($410) + ($411<<2)|0) + 40|0);
     HEAP32[$415>>2] = $408;
     $416 = ((($410) + ($411)|0) + 52|0);
     HEAP8[$416>>0] = 0;
     $417 = (($408) + 55|0);
     $418 = HEAP8[$417>>0]|0;
     $419 = (550816 + ($411<<2)|0);
     $420 = HEAP32[$419>>2]|0;
     $421 = ((($410) + ($420)|0) + 55|0);
     $422 = HEAP8[$421>>0]|0;
     $423 = ($418<<24>>24)==($422<<24>>24);
     if ($423) {
      $424 = (($408) + 56|0);
      $425 = HEAP8[$424>>0]|0;
      $426 = ((($410) + ($411)|0) + 55|0);
      $427 = HEAP8[$426>>0]|0;
      $428 = ($425<<24>>24)==($427<<24>>24);
      $443 = $428;
     } else {
      $443 = 0;
     }
     $429 = (($408) + 48|0);
     HEAP32[$429>>2] = $lastFacet$0246;
     $430 = (($408) + 54|0);
     HEAP8[$430>>0] = 1;
     $431 = (($lastFacet$0246) + 44|0);
     HEAP32[$431>>2] = $408;
     $432 = (($lastFacet$0246) + 53|0);
     HEAP8[$432>>0] = 2;
     $433 = (($408) + 57|0);
     $434 = HEAP8[$433>>0]|0;
     $435 = (($lastFacet$0246) + 57|0);
     $436 = HEAP8[$435>>0]|0;
     $437 = ($434<<24>>24)==($436<<24>>24);
     if ($437) {
      $438 = HEAP8[$417>>0]|0;
      $439 = (($lastFacet$0246) + 56|0);
      $440 = HEAP8[$439>>0]|0;
      $441 = ($438<<24>>24)==($440<<24>>24);
      $446 = $441;
     } else {
      $446 = 0;
     }
     $442 = $443&1;
     $444 = $442 ^ 1;
     $445 = $446&1;
     $447 = $445 ^ 1;
     $448 = $447 | $444;
     $449 = ($448|0)==(0);
     $395 = (($i$0247) + 1)|0;
     if (!($449)) {
      label = 33;
      break L15;
     }
     $394 = ($395>>>0)<($392>>>0);
     if ($394) {
      $i$0247 = $395;$lastFacet$0246 = $408;
     } else {
      $lastFacet$0$lcssa = $408;
      break;
     }
    }
   } else {
    $lastFacet$0$lcssa = $292;
   }
   $541 = (($292) + 48|0);
   HEAP32[$541>>2] = $lastFacet$0$lcssa;
   $542 = (($292) + 54|0);
   HEAP8[$542>>0] = 1;
   $543 = (($lastFacet$0$lcssa) + 44|0);
   HEAP32[$543>>2] = $292;
   $544 = (($lastFacet$0$lcssa) + 53|0);
   HEAP8[$544>>0] = 2;
   $$$i240 = $$$i;
  } else {
   $$$i240 = $$$i241;
  }
  $545 = (($89) + 60|0);
  $546 = HEAP8[$545>>0]|0;
  $547 = $546&255;
  $548 = HEAP8[$67>>0]|0;
  $549 = $548&255;
  $550 = (($549) + -1)|0;
  $551 = ($547|0)==($550|0);
  if ($551) {
   $552 = (($548) + -1)<<24>>24;
   HEAP8[$67>>0] = $552;
  } else {
   $553 = HEAP8[$68>>0]|0;
   $554 = (($553) + 1)<<24>>24;
   HEAP8[$68>>0] = $554;
   $555 = $553&255;
   $556 = ((($this) + ($555)|0) + 6676|0);
   HEAP8[$556>>0] = $546;
  }
  $557 = HEAP32[$this>>2]|0;
  $558 = ($557|0)>(0);
  if (!($558)) {
   label = 40;
   break;
  }
  $559 = HEAP32[$56>>2]|0;
  $560 = (($559) + 12|0);
  $561 = Math_fround(HEAPF32[$560>>2]);
  $562 = $$$i240 >= $561;
  $563 = HEAP32[$numVertsLocal>>2]|0;
  $564 = ($563|0)!=(64);
  $$demorgan = $562 & $564;
  if ($$demorgan) {
   $$$i241 = $$$i240;
  } else {
   label = 40;
   break;
  }
 }
 if ((label|0) == 21) {
  $169 = (($89) + 32|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = (($89) + 36|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = (($89) + 55|0);
  $174 = HEAP8[$173>>0]|0;
  $175 = $174 << 24 >> 24;
  $176 = ((($this) + ($175<<4)|0) + 272|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = ((($this) + ($175<<4)|0) + 276|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = ((($this) + ($175<<4)|0) + 280|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = (($89) + 56|0);
  $183 = HEAP8[$182>>0]|0;
  $184 = $183 << 24 >> 24;
  $185 = ((($this) + ($184<<4)|0) + 272|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = ((($this) + ($184<<4)|0) + 276|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = ((($this) + ($184<<4)|0) + 280|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($89) + 57|0);
  $192 = HEAP8[$191>>0]|0;
  $193 = $192 << 24 >> 24;
  $194 = ((($this) + ($193<<4)|0) + 272|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = ((($this) + ($193<<4)|0) + 276|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = ((($this) + ($193<<4)|0) + 280|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = ((($this) + ($175<<4)|0) + 1296|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = ((($this) + ($175<<4)|0) + 1300|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = ((($this) + ($175<<4)|0) + 1304|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = ((($this) + ($184<<4)|0) + 1296|0);
  $207 = Math_fround(HEAPF32[$206>>2]);
  $208 = ((($this) + ($184<<4)|0) + 1300|0);
  $209 = Math_fround(HEAPF32[$208>>2]);
  $210 = ((($this) + ($184<<4)|0) + 1304|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = ((($this) + ($193<<4)|0) + 1296|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = ((($this) + ($193<<4)|0) + 1300|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = ((($this) + ($193<<4)|0) + 1304|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = Math_fround($186 - $177);
  $219 = Math_fround($188 - $179);
  $220 = Math_fround($190 - $181);
  $221 = Math_fround($170 * $218);
  $222 = Math_fround($170 * $219);
  $223 = Math_fround($170 * $220);
  $224 = Math_fround($195 - $177);
  $225 = Math_fround($197 - $179);
  $226 = Math_fround($199 - $181);
  $227 = Math_fround($172 * $224);
  $228 = Math_fround($172 * $225);
  $229 = Math_fround($172 * $226);
  $230 = Math_fround($207 - $201);
  $231 = Math_fround($209 - $203);
  $232 = Math_fround($211 - $205);
  $233 = Math_fround($170 * $230);
  $234 = Math_fround($170 * $231);
  $235 = Math_fround($170 * $232);
  $236 = Math_fround($213 - $201);
  $237 = Math_fround($215 - $203);
  $238 = Math_fround($217 - $205);
  $239 = Math_fround($172 * $236);
  $240 = Math_fround($172 * $237);
  $241 = Math_fround($172 * $238);
  $242 = Math_fround($221 + $227);
  $243 = Math_fround($222 + $228);
  $244 = Math_fround($223 + $229);
  $245 = Math_fround($177 + $242);
  $246 = Math_fround($179 + $243);
  $247 = Math_fround($181 + $244);
  HEAPF32[$_pa>>2] = $245;
  $248 = (($_pa) + 4|0);
  HEAPF32[$248>>2] = $246;
  $249 = (($_pa) + 8|0);
  HEAPF32[$249>>2] = $247;
  $250 = (($_pa) + 12|0);
  HEAPF32[$250>>2] = Math_fround(0.0);
  $251 = Math_fround($233 + $239);
  $252 = Math_fround($234 + $240);
  $253 = Math_fround($235 + $241);
  $254 = Math_fround($201 + $251);
  $255 = Math_fround($203 + $252);
  $256 = Math_fround($205 + $253);
  HEAPF32[$_pb>>2] = $254;
  $257 = (($_pb) + 4|0);
  HEAPF32[$257>>2] = $255;
  $258 = (($_pb) + 8|0);
  HEAPF32[$258>>2] = $256;
  $259 = (($_pb) + 12|0);
  HEAPF32[$259>>2] = Math_fround(0.0);
  __ZN5physx2GuL27calculateContactInformationERKNS_6shdfnd3aos5Vec3VES5_RKNS0_7ConvexVES8_RS3_S9_S9_RNS2_6FloatVEb($_pa,$_pb,$a,$b,$pa,$pb,$normal,$penDepth,$takeCoreShape);
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 24) {
  $294 = (($89) + 32|0);
  $295 = Math_fround(HEAPF32[$294>>2]);
  $296 = (($89) + 36|0);
  $297 = Math_fround(HEAPF32[$296>>2]);
  $298 = (($89) + 55|0);
  $299 = HEAP8[$298>>0]|0;
  $300 = $299 << 24 >> 24;
  $301 = ((($this) + ($300<<4)|0) + 272|0);
  $302 = Math_fround(HEAPF32[$301>>2]);
  $303 = ((($this) + ($300<<4)|0) + 276|0);
  $304 = Math_fround(HEAPF32[$303>>2]);
  $305 = ((($this) + ($300<<4)|0) + 280|0);
  $306 = Math_fround(HEAPF32[$305>>2]);
  $307 = (($89) + 56|0);
  $308 = HEAP8[$307>>0]|0;
  $309 = $308 << 24 >> 24;
  $310 = ((($this) + ($309<<4)|0) + 272|0);
  $311 = Math_fround(HEAPF32[$310>>2]);
  $312 = ((($this) + ($309<<4)|0) + 276|0);
  $313 = Math_fround(HEAPF32[$312>>2]);
  $314 = ((($this) + ($309<<4)|0) + 280|0);
  $315 = Math_fround(HEAPF32[$314>>2]);
  $316 = (($89) + 57|0);
  $317 = HEAP8[$316>>0]|0;
  $318 = $317 << 24 >> 24;
  $319 = ((($this) + ($318<<4)|0) + 272|0);
  $320 = Math_fround(HEAPF32[$319>>2]);
  $321 = ((($this) + ($318<<4)|0) + 276|0);
  $322 = Math_fround(HEAPF32[$321>>2]);
  $323 = ((($this) + ($318<<4)|0) + 280|0);
  $324 = Math_fround(HEAPF32[$323>>2]);
  $325 = ((($this) + ($300<<4)|0) + 1296|0);
  $326 = Math_fround(HEAPF32[$325>>2]);
  $327 = ((($this) + ($300<<4)|0) + 1300|0);
  $328 = Math_fround(HEAPF32[$327>>2]);
  $329 = ((($this) + ($300<<4)|0) + 1304|0);
  $330 = Math_fround(HEAPF32[$329>>2]);
  $331 = ((($this) + ($309<<4)|0) + 1296|0);
  $332 = Math_fround(HEAPF32[$331>>2]);
  $333 = ((($this) + ($309<<4)|0) + 1300|0);
  $334 = Math_fround(HEAPF32[$333>>2]);
  $335 = ((($this) + ($309<<4)|0) + 1304|0);
  $336 = Math_fround(HEAPF32[$335>>2]);
  $337 = ((($this) + ($318<<4)|0) + 1296|0);
  $338 = Math_fround(HEAPF32[$337>>2]);
  $339 = ((($this) + ($318<<4)|0) + 1300|0);
  $340 = Math_fround(HEAPF32[$339>>2]);
  $341 = ((($this) + ($318<<4)|0) + 1304|0);
  $342 = Math_fround(HEAPF32[$341>>2]);
  $343 = Math_fround($311 - $302);
  $344 = Math_fround($313 - $304);
  $345 = Math_fround($315 - $306);
  $346 = Math_fround($295 * $343);
  $347 = Math_fround($295 * $344);
  $348 = Math_fround($295 * $345);
  $349 = Math_fround($320 - $302);
  $350 = Math_fround($322 - $304);
  $351 = Math_fround($324 - $306);
  $352 = Math_fround($297 * $349);
  $353 = Math_fround($297 * $350);
  $354 = Math_fround($297 * $351);
  $355 = Math_fround($332 - $326);
  $356 = Math_fround($334 - $328);
  $357 = Math_fround($336 - $330);
  $358 = Math_fround($295 * $355);
  $359 = Math_fround($295 * $356);
  $360 = Math_fround($295 * $357);
  $361 = Math_fround($338 - $326);
  $362 = Math_fround($340 - $328);
  $363 = Math_fround($342 - $330);
  $364 = Math_fround($297 * $361);
  $365 = Math_fround($297 * $362);
  $366 = Math_fround($297 * $363);
  $367 = Math_fround($346 + $352);
  $368 = Math_fround($347 + $353);
  $369 = Math_fround($348 + $354);
  $370 = Math_fround($302 + $367);
  $371 = Math_fround($304 + $368);
  $372 = Math_fround($306 + $369);
  HEAPF32[$_pa1>>2] = $370;
  $373 = (($_pa1) + 4|0);
  HEAPF32[$373>>2] = $371;
  $374 = (($_pa1) + 8|0);
  HEAPF32[$374>>2] = $372;
  $375 = (($_pa1) + 12|0);
  HEAPF32[$375>>2] = Math_fround(0.0);
  $376 = Math_fround($358 + $364);
  $377 = Math_fround($359 + $365);
  $378 = Math_fround($360 + $366);
  $379 = Math_fround($326 + $376);
  $380 = Math_fround($328 + $377);
  $381 = Math_fround($330 + $378);
  HEAPF32[$_pb2>>2] = $379;
  $382 = (($_pb2) + 4|0);
  HEAPF32[$382>>2] = $380;
  $383 = (($_pb2) + 8|0);
  HEAPF32[$383>>2] = $381;
  $384 = (($_pb2) + 12|0);
  HEAPF32[$384>>2] = Math_fround(0.0);
  __ZN5physx2GuL27calculateContactInformationERKNS_6shdfnd3aos5Vec3VES5_RKNS0_7ConvexVES8_RS3_S9_S9_RNS2_6FloatVEb($_pa1,$_pb2,$a,$b,$pa,$pb,$normal,$penDepth,$takeCoreShape);
  $$0 = 5;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  $450 = (($89) + 32|0);
  $451 = Math_fround(HEAPF32[$450>>2]);
  $452 = (($89) + 36|0);
  $453 = Math_fround(HEAPF32[$452>>2]);
  $454 = (($89) + 55|0);
  $455 = HEAP8[$454>>0]|0;
  $456 = $455 << 24 >> 24;
  $457 = ((($this) + ($456<<4)|0) + 272|0);
  $458 = Math_fround(HEAPF32[$457>>2]);
  $459 = ((($this) + ($456<<4)|0) + 276|0);
  $460 = Math_fround(HEAPF32[$459>>2]);
  $461 = ((($this) + ($456<<4)|0) + 280|0);
  $462 = Math_fround(HEAPF32[$461>>2]);
  $463 = (($89) + 56|0);
  $464 = HEAP8[$463>>0]|0;
  $465 = $464 << 24 >> 24;
  $466 = ((($this) + ($465<<4)|0) + 272|0);
  $467 = Math_fround(HEAPF32[$466>>2]);
  $468 = ((($this) + ($465<<4)|0) + 276|0);
  $469 = Math_fround(HEAPF32[$468>>2]);
  $470 = ((($this) + ($465<<4)|0) + 280|0);
  $471 = Math_fround(HEAPF32[$470>>2]);
  $472 = (($89) + 57|0);
  $473 = HEAP8[$472>>0]|0;
  $474 = $473 << 24 >> 24;
  $475 = ((($this) + ($474<<4)|0) + 272|0);
  $476 = Math_fround(HEAPF32[$475>>2]);
  $477 = ((($this) + ($474<<4)|0) + 276|0);
  $478 = Math_fround(HEAPF32[$477>>2]);
  $479 = ((($this) + ($474<<4)|0) + 280|0);
  $480 = Math_fround(HEAPF32[$479>>2]);
  $481 = ((($this) + ($456<<4)|0) + 1296|0);
  $482 = Math_fround(HEAPF32[$481>>2]);
  $483 = ((($this) + ($456<<4)|0) + 1300|0);
  $484 = Math_fround(HEAPF32[$483>>2]);
  $485 = ((($this) + ($456<<4)|0) + 1304|0);
  $486 = Math_fround(HEAPF32[$485>>2]);
  $487 = ((($this) + ($465<<4)|0) + 1296|0);
  $488 = Math_fround(HEAPF32[$487>>2]);
  $489 = ((($this) + ($465<<4)|0) + 1300|0);
  $490 = Math_fround(HEAPF32[$489>>2]);
  $491 = ((($this) + ($465<<4)|0) + 1304|0);
  $492 = Math_fround(HEAPF32[$491>>2]);
  $493 = ((($this) + ($474<<4)|0) + 1296|0);
  $494 = Math_fround(HEAPF32[$493>>2]);
  $495 = ((($this) + ($474<<4)|0) + 1300|0);
  $496 = Math_fround(HEAPF32[$495>>2]);
  $497 = ((($this) + ($474<<4)|0) + 1304|0);
  $498 = Math_fround(HEAPF32[$497>>2]);
  $499 = Math_fround($467 - $458);
  $500 = Math_fround($469 - $460);
  $501 = Math_fround($471 - $462);
  $502 = Math_fround($451 * $499);
  $503 = Math_fround($451 * $500);
  $504 = Math_fround($451 * $501);
  $505 = Math_fround($476 - $458);
  $506 = Math_fround($478 - $460);
  $507 = Math_fround($480 - $462);
  $508 = Math_fround($453 * $505);
  $509 = Math_fround($453 * $506);
  $510 = Math_fround($453 * $507);
  $511 = Math_fround($488 - $482);
  $512 = Math_fround($490 - $484);
  $513 = Math_fround($492 - $486);
  $514 = Math_fround($451 * $511);
  $515 = Math_fround($451 * $512);
  $516 = Math_fround($451 * $513);
  $517 = Math_fround($494 - $482);
  $518 = Math_fround($496 - $484);
  $519 = Math_fround($498 - $486);
  $520 = Math_fround($453 * $517);
  $521 = Math_fround($453 * $518);
  $522 = Math_fround($453 * $519);
  $523 = Math_fround($502 + $508);
  $524 = Math_fround($503 + $509);
  $525 = Math_fround($504 + $510);
  $526 = Math_fround($458 + $523);
  $527 = Math_fround($460 + $524);
  $528 = Math_fround($462 + $525);
  HEAPF32[$_pa3>>2] = $526;
  $529 = (($_pa3) + 4|0);
  HEAPF32[$529>>2] = $527;
  $530 = (($_pa3) + 8|0);
  HEAPF32[$530>>2] = $528;
  $531 = (($_pa3) + 12|0);
  HEAPF32[$531>>2] = Math_fround(0.0);
  $532 = Math_fround($514 + $520);
  $533 = Math_fround($515 + $521);
  $534 = Math_fround($516 + $522);
  $535 = Math_fround($482 + $532);
  $536 = Math_fround($484 + $533);
  $537 = Math_fround($486 + $534);
  HEAPF32[$_pb4>>2] = $535;
  $538 = (($_pb4) + 4|0);
  HEAPF32[$538>>2] = $536;
  $539 = (($_pb4) + 8|0);
  HEAPF32[$539>>2] = $537;
  $540 = (($_pb4) + 12|0);
  HEAPF32[$540>>2] = Math_fround(0.0);
  __ZN5physx2GuL27calculateContactInformationERKNS_6shdfnd3aos5Vec3VES5_RKNS0_7ConvexVES8_RS3_S9_S9_RNS2_6FloatVEb($_pa3,$_pb4,$a,$b,$pa,$pb,$normal,$penDepth,$takeCoreShape);
  $$0 = 5;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 40) {
  $565 = (($89) + 32|0);
  $566 = Math_fround(HEAPF32[$565>>2]);
  $567 = (($89) + 36|0);
  $568 = Math_fround(HEAPF32[$567>>2]);
  $569 = (($89) + 55|0);
  $570 = HEAP8[$569>>0]|0;
  $571 = $570 << 24 >> 24;
  $572 = ((($this) + ($571<<4)|0) + 272|0);
  $573 = Math_fround(HEAPF32[$572>>2]);
  $574 = ((($this) + ($571<<4)|0) + 276|0);
  $575 = Math_fround(HEAPF32[$574>>2]);
  $576 = ((($this) + ($571<<4)|0) + 280|0);
  $577 = Math_fround(HEAPF32[$576>>2]);
  $578 = (($89) + 56|0);
  $579 = HEAP8[$578>>0]|0;
  $580 = $579 << 24 >> 24;
  $581 = ((($this) + ($580<<4)|0) + 272|0);
  $582 = Math_fround(HEAPF32[$581>>2]);
  $583 = ((($this) + ($580<<4)|0) + 276|0);
  $584 = Math_fround(HEAPF32[$583>>2]);
  $585 = ((($this) + ($580<<4)|0) + 280|0);
  $586 = Math_fround(HEAPF32[$585>>2]);
  $587 = (($89) + 57|0);
  $588 = HEAP8[$587>>0]|0;
  $589 = $588 << 24 >> 24;
  $590 = ((($this) + ($589<<4)|0) + 272|0);
  $591 = Math_fround(HEAPF32[$590>>2]);
  $592 = ((($this) + ($589<<4)|0) + 276|0);
  $593 = Math_fround(HEAPF32[$592>>2]);
  $594 = ((($this) + ($589<<4)|0) + 280|0);
  $595 = Math_fround(HEAPF32[$594>>2]);
  $596 = ((($this) + ($571<<4)|0) + 1296|0);
  $597 = Math_fround(HEAPF32[$596>>2]);
  $598 = ((($this) + ($571<<4)|0) + 1300|0);
  $599 = Math_fround(HEAPF32[$598>>2]);
  $600 = ((($this) + ($571<<4)|0) + 1304|0);
  $601 = Math_fround(HEAPF32[$600>>2]);
  $602 = ((($this) + ($580<<4)|0) + 1296|0);
  $603 = Math_fround(HEAPF32[$602>>2]);
  $604 = ((($this) + ($580<<4)|0) + 1300|0);
  $605 = Math_fround(HEAPF32[$604>>2]);
  $606 = ((($this) + ($580<<4)|0) + 1304|0);
  $607 = Math_fround(HEAPF32[$606>>2]);
  $608 = ((($this) + ($589<<4)|0) + 1296|0);
  $609 = Math_fround(HEAPF32[$608>>2]);
  $610 = ((($this) + ($589<<4)|0) + 1300|0);
  $611 = Math_fround(HEAPF32[$610>>2]);
  $612 = ((($this) + ($589<<4)|0) + 1304|0);
  $613 = Math_fround(HEAPF32[$612>>2]);
  $614 = Math_fround($582 - $573);
  $615 = Math_fround($584 - $575);
  $616 = Math_fround($586 - $577);
  $617 = Math_fround($566 * $614);
  $618 = Math_fround($566 * $615);
  $619 = Math_fround($566 * $616);
  $620 = Math_fround($591 - $573);
  $621 = Math_fround($593 - $575);
  $622 = Math_fround($595 - $577);
  $623 = Math_fround($568 * $620);
  $624 = Math_fround($568 * $621);
  $625 = Math_fround($568 * $622);
  $626 = Math_fround($603 - $597);
  $627 = Math_fround($605 - $599);
  $628 = Math_fround($607 - $601);
  $629 = Math_fround($566 * $626);
  $630 = Math_fround($566 * $627);
  $631 = Math_fround($566 * $628);
  $632 = Math_fround($609 - $597);
  $633 = Math_fround($611 - $599);
  $634 = Math_fround($613 - $601);
  $635 = Math_fround($568 * $632);
  $636 = Math_fround($568 * $633);
  $637 = Math_fround($568 * $634);
  $638 = Math_fround($617 + $623);
  $639 = Math_fround($618 + $624);
  $640 = Math_fround($619 + $625);
  $641 = Math_fround($573 + $638);
  $642 = Math_fround($575 + $639);
  $643 = Math_fround($577 + $640);
  HEAPF32[$_pa5>>2] = $641;
  $644 = (($_pa5) + 4|0);
  HEAPF32[$644>>2] = $642;
  $645 = (($_pa5) + 8|0);
  HEAPF32[$645>>2] = $643;
  $646 = (($_pa5) + 12|0);
  HEAPF32[$646>>2] = Math_fround(0.0);
  $647 = Math_fround($629 + $635);
  $648 = Math_fround($630 + $636);
  $649 = Math_fround($631 + $637);
  $650 = Math_fround($597 + $647);
  $651 = Math_fround($599 + $648);
  $652 = Math_fround($601 + $649);
  HEAPF32[$_pb6>>2] = $650;
  $653 = (($_pb6) + 4|0);
  HEAPF32[$653>>2] = $651;
  $654 = (($_pb6) + 8|0);
  HEAPF32[$654>>2] = $652;
  $655 = (($_pb6) + 12|0);
  HEAPF32[$655>>2] = Math_fround(0.0);
  __ZN5physx2GuL27calculateContactInformationERKNS_6shdfnd3aos5Vec3VES5_RKNS0_7ConvexVES8_RS3_S9_S9_RNS2_6FloatVEb($_pa5,$_pb6,$a,$b,$pa,$pb,$normal,$penDepth,$takeCoreShape);
  $$0 = 5;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 41) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,$i0,$i1,$i2,$lower2,$upper2) {
 $this = $this|0;
 $i0 = $i0|0;
 $i1 = $i1|0;
 $i2 = $i2|0;
 $lower2 = $lower2|0;
 $upper2 = $upper2|0;
 var $$0 = 0, $$0$i = 0, $$in$i = 0, $$in$in$i = 0, $$sink$in$lcssa$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $b1 = 0, $con = 0, $or$cond = 0, $or$cond5 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $b1 = sp + 16|0;
 $con = sp;
 $0 = (($this) + 6804|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = (($this) + 6805|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (($2) - ($5))|0;
 $7 = ($6>>>0)<(64);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ($4<<24>>24)==(0);
 if ($8) {
  $14 = (($1) + 1)<<24>>24;
  HEAP8[$0>>0] = $14;
  $$0$i = $1;
 } else {
  $9 = (($5) + 255)|0;
  $10 = (($4) + -1)<<24>>24;
  HEAP8[$3>>0] = $10;
  $11 = $9 & 255;
  $12 = ((($this) + ($11)|0) + 6676|0);
  $13 = HEAP8[$12>>0]|0;
  $$0$i = $13;
 }
 $15 = $$0$i&255;
 $16 = ((($this) + ($15<<6)|0) + 2320|0);
 $$sum = (($15) + 2)|0;
 $17 = ((($this) + ($$sum<<6)|0) + 2320|0);
 $18 = ((($this) + ($15<<6)|0) + 2332|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($this) + ($15<<6)|0) + 2352|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = ((($this) + ($15<<6)|0) + 2356|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = ((($this) + ($15<<6)|0) + 2378|0);
 HEAP8[$21>>0] = 0;
 $22 = ((($this) + ($15<<6)|0) + 2379|0);
 HEAP8[$22>>0] = 0;
 $23 = $i0&255;
 $24 = ((($this) + ($15<<6)|0) + 2375|0);
 HEAP8[$24>>0] = $23;
 $25 = $i1&255;
 $26 = ((($this) + ($15<<6)|0) + 2376|0);
 HEAP8[$26>>0] = $25;
 $27 = $i2&255;
 $28 = ((($this) + ($15<<6)|0) + 2377|0);
 HEAP8[$28>>0] = $27;
 $29 = ((($this) + ($15<<6)|0) + 2368|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($this) + ($15<<6)|0) + 2364|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($this) + ($15<<6)|0) + 2360|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($this) + ($15<<6)|0) + 2374|0);
 HEAP8[$32>>0] = -1;
 $33 = ((($this) + ($15<<6)|0) + 2373|0);
 HEAP8[$33>>0] = -1;
 $34 = ((($this) + ($15<<6)|0) + 2372|0);
 HEAP8[$34>>0] = -1;
 $35 = ((($this) + ($15<<6)|0) + 2380|0);
 HEAP8[$35>>0] = $$0$i;
 $36 = (($this) + 272|0);
 $37 = (($this) + 1296|0);
 __ZN5physx2Gu5Facet8isValid2EjjjPKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES9_Ri($con,$16,$i0,$i1,$i2,$36,$37,$lower2,$upper2,$b1);
 $38 = HEAP32[$con>>2]|0;
 $39 = (($con) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($con) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($38|0)==(-1);
 $44 = ($40|0)==(-1);
 $or$cond = $43 & $44;
 $45 = ($42|0)==(-1);
 $or$cond5 = $or$cond & $45;
 if ($or$cond5) {
  $46 = (($con) + 12|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(-1);
  if ($48) {
   $49 = HEAP32[$this>>2]|0;
   $50 = ($49|0)==(0);
   L11: do {
    if ($50) {
     $$sink$in$lcssa$i = 0;
    } else {
     $51 = HEAP32[$18>>2]|0;
     $$in$in$i = $49;
     while(1) {
      $$in$i = (($$in$in$i) + -1)|0;
      $52 = $$in$i >> 1;
      $53 = ((($this) + ($52<<2)|0) + 4|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($56>>>0)>($51>>>0);
      if (!($57)) {
       $$sink$in$lcssa$i = $$in$in$i;
       break L11;
      }
      $58 = ((($this) + ($$in$in$i<<2)|0) + 4|0);
      HEAP32[$58>>2] = $54;
      $59 = ($52|0)==(0);
      if ($59) {
       $$sink$in$lcssa$i = 0;
       break;
      } else {
       $$in$in$i = $52;
      }
     }
    }
   } while(0);
   $60 = ((($this) + ($$sink$in$lcssa$i<<2)|0) + 4|0);
   HEAP32[$60>>2] = $16;
   $61 = HEAP32[$this>>2]|0;
   $62 = (($61) + 1)|0;
   HEAP32[$this>>2] = $62;
   $storemerge = 1;
  } else {
   $storemerge = 0;
  }
 } else {
  $storemerge = 0;
 }
 HEAP8[$22>>0] = $storemerge;
 $63 = HEAP32[$b1>>2]|0;
 $64 = ($63|0)!=(0);
 $65 = $64 ? $16 : 0;
 $$0 = $65;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu5Facet8isValid2EjjjPKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES9_Ri($agg$result,$this,$i0,$i1,$i2,$aBuf,$bBuf,$lower,$upper,$b1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $i0 = $i0|0;
 $i1 = $i1|0;
 $i2 = $i2|0;
 $aBuf = $aBuf|0;
 $bBuf = $bBuf|0;
 $lower = $lower|0;
 $upper = $upper|0;
 $b1 = $b1|0;
 var $$ = 0, $$621 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0);
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0);
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0);
 var $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $not$ = 0, $not$622 = 0, $not$623 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($aBuf) + ($i0<<4)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = ((($aBuf) + ($i0<<4)|0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = ((($aBuf) + ($i0<<4)|0) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($aBuf) + ($i1<<4)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($aBuf) + ($i1<<4)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($aBuf) + ($i1<<4)|0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($aBuf) + ($i2<<4)|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = ((($aBuf) + ($i2<<4)|0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = ((($aBuf) + ($i2<<4)|0) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($bBuf) + ($i0<<4)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($bBuf) + ($i0<<4)|0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = ((($bBuf) + ($i0<<4)|0) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($bBuf) + ($i1<<4)|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = ((($bBuf) + ($i1<<4)|0) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = ((($bBuf) + ($i1<<4)|0) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($bBuf) + ($i2<<4)|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = ((($bBuf) + ($i2<<4)|0) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = ((($bBuf) + ($i2<<4)|0) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($1 - $19);
 $37 = Math_fround($3 - $21);
 $38 = Math_fround($5 - $23);
 $39 = Math_fround($7 - $25);
 $40 = Math_fround($9 - $27);
 $41 = Math_fround($11 - $29);
 $42 = Math_fround($13 - $31);
 $43 = Math_fround($15 - $33);
 $44 = Math_fround($17 - $35);
 $45 = Math_fround($39 - $36);
 $46 = Math_fround($40 - $37);
 $47 = Math_fround($41 - $38);
 $48 = Math_fround($42 - $36);
 $49 = Math_fround($43 - $37);
 $50 = Math_fround($44 - $38);
 $51 = Math_fround($46 * $50);
 $52 = Math_fround($47 * $49);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($47 * $48);
 $55 = Math_fround($45 * $50);
 $56 = Math_fround($54 - $55);
 $57 = Math_fround($45 * $49);
 $58 = Math_fround($46 * $48);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($36 * $53);
 $61 = Math_fround($37 * $56);
 $62 = Math_fround($38 * $59);
 $63 = Math_fround($45 * $45);
 $64 = Math_fround($46 * $46);
 $65 = Math_fround($47 * $47);
 $66 = Math_fround($45 * $48);
 $67 = Math_fround($46 * $49);
 $68 = Math_fround($47 * $50);
 $69 = Math_fround($48 * $48);
 $70 = Math_fround($49 * $49);
 $71 = Math_fround($50 * $50);
 $72 = Math_fround($60 + $61);
 $73 = Math_fround($63 + $64);
 $74 = Math_fround($66 + $67);
 $75 = Math_fround($69 + $70);
 $76 = Math_fround($62 + $72);
 $77 = Math_fround($73 + $65);
 $78 = Math_fround($74 + $68);
 $79 = Math_fround($75 + $71);
 $80 = (($this) + 28|0);
 HEAPF32[$80>>2] = $76;
 $81 = (($this) + 16|0);
 HEAPF32[$81>>2] = $53;
 $82 = (($this) + 20|0);
 HEAPF32[$82>>2] = $56;
 $83 = (($this) + 24|0);
 HEAPF32[$83>>2] = $59;
 $84 = Math_fround($36 * $45);
 $85 = Math_fround($37 * $46);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($38 * $47);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($36 * $48);
 $90 = Math_fround($37 * $49);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($38 * $50);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($77 * $79);
 $95 = Math_fround($78 * $78);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround(Math_fround(1.0) / $96);
 $98 = Math_fround($93 * $78);
 $99 = Math_fround($88 * $79);
 $100 = Math_fround($98 - $99);
 $101 = Math_fround($88 * $78);
 $102 = Math_fround($77 * $93);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($48 * $103);
 $105 = Math_fround($49 * $103);
 $106 = Math_fround($50 * $103);
 $107 = Math_fround($45 * $100);
 $108 = Math_fround($46 * $100);
 $109 = Math_fround($47 * $100);
 $110 = Math_fround($107 + $104);
 $111 = Math_fround($108 + $105);
 $112 = Math_fround($109 + $106);
 $113 = Math_fround($97 * $110);
 $114 = Math_fround($97 * $111);
 $115 = Math_fround($97 * $112);
 $116 = Math_fround($36 + $113);
 $117 = Math_fround($37 + $114);
 $118 = Math_fround($38 + $115);
 $119 = Math_fround($116 * $116);
 $120 = Math_fround($117 * $117);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($118 * $118);
 $123 = Math_fround($122 + $121);
 $124 = (($this) + 12|0);
 HEAPF32[$124>>2] = $123;
 HEAPF32[$this>>2] = $116;
 $125 = (($this) + 4|0);
 HEAPF32[$125>>2] = $117;
 $126 = (($this) + 8|0);
 HEAPF32[$126>>2] = $118;
 $127 = $96 >= Math_fround(-1.1920928955078125E-7);
 $128 = $127&1;
 HEAP32[$b1>>2] = $128;
 $129 = $100 > Math_fround(-1.1920928955078125E-7);
 $130 = $103 > Math_fround(-1.1920928955078125E-7);
 if ($130) {
  $131 = Math_fround($100 + $103);
  $132 = $96 > $131;
  $134 = $132;
 } else {
  $134 = 0;
 }
 $133 = $134 << 31 >> 31;
 $135 = $129 ? $133 : 0;
 $136 = $129 & $134;
 $137 = Math_fround($97 * $100);
 $138 = (($this) + 32|0);
 HEAPF32[$138>>2] = $137;
 $139 = Math_fround($97 * $103);
 $140 = (($this) + 36|0);
 HEAPF32[$140>>2] = $139;
 $141 = Math_fround(HEAPF32[$lower>>2]);
 $142 = !($123 >= $141);
 if ($142) {
  $145 = 0;
  $not$ = ($135|0)!=(0);
  $$ = $145 & $not$;
  $146 = $$ << 31 >> 31;
  $not$622 = ($135|0)!=(0);
  $147 = $145 & $not$622;
  $148 = $147 << 31 >> 31;
  $not$623 = ($135|0)!=(0);
  $$621 = $145 & $not$623;
  $149 = $$621 << 31 >> 31;
  $150 = $145 & $136;
  $151 = $150 << 31 >> 31;
  HEAP32[$agg$result>>2] = $146;
  $152 = (($agg$result) + 4|0);
  HEAP32[$152>>2] = $148;
  $153 = (($agg$result) + 8|0);
  HEAP32[$153>>2] = $149;
  $154 = (($agg$result) + 12|0);
  HEAP32[$154>>2] = $151;
  STACKTOP = sp;return;
 }
 $143 = Math_fround(HEAPF32[$upper>>2]);
 $144 = $143 >= $123;
 $145 = $144;
 $not$ = ($135|0)!=(0);
 $$ = $145 & $not$;
 $146 = $$ << 31 >> 31;
 $not$622 = ($135|0)!=(0);
 $147 = $145 & $not$622;
 $148 = $147 << 31 >> 31;
 $not$623 = ($135|0)!=(0);
 $$621 = $145 & $not$623;
 $149 = $$621 << 31 >> 31;
 $150 = $145 & $136;
 $151 = $150 << 31 >> 31;
 HEAP32[$agg$result>>2] = $146;
 $152 = (($agg$result) + 4|0);
 HEAP32[$152>>2] = $148;
 $153 = (($agg$result) + 8|0);
 HEAP32[$153>>2] = $149;
 $154 = (($agg$result) + 12|0);
 HEAP32[$154>>2] = $151;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5Facet10silhouetteEjRKNS_6shdfnd3aos5Vec3VERNS0_10EdgeBufferERNS0_15EPAFacetManagerE($this,$_index,$w,$edgeBuffer,$manager) {
 $this = $this|0;
 $_index = $_index|0;
 $w = $w|0;
 $edgeBuffer = $edgeBuffer|0;
 $manager = $manager|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $next_facet$0$be = 0, $next_facet$020 = 0, $next_index$0$be = 0, $next_index$019 = 0, $size$0$be = 0, $size$021 = 0, $stack = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $stack = sp;
 $0 = (($w) + 4|0);
 $1 = (($w) + 8|0);
 $2 = (($edgeBuffer) + 256|0);
 $3 = (($manager) + 130|0);
 $50 = 0;$next_facet$020 = $this;$next_index$019 = $_index;$size$021 = 1;
 while(1) {
  $4 = (($next_facet$020) + 58|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  do {
   if ($6) {
    $14 = Math_fround(HEAPF32[$next_facet$020>>2]);
    $15 = (($next_facet$020) + 4|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = (($next_facet$020) + 8|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = Math_fround(HEAPF32[$w>>2]);
    $20 = Math_fround(HEAPF32[$0>>2]);
    $21 = Math_fround(HEAPF32[$1>>2]);
    $22 = Math_fround($14 * $19);
    $23 = Math_fround($16 * $20);
    $24 = Math_fround($22 + $23);
    $25 = Math_fround($18 * $21);
    $26 = Math_fround($24 + $25);
    $27 = (($next_facet$020) + 12|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = $28 > $26;
    if ($29) {
     $30 = HEAP32[$2>>2]|0;
     $31 = (($30) + 1)|0;
     HEAP32[$2>>2] = $31;
     $32 = (($edgeBuffer) + ($30<<3)|0);
     HEAP32[$32>>2] = $next_facet$020;
     $33 = ((($edgeBuffer) + ($30<<3)|0) + 4|0);
     HEAP32[$33>>2] = $next_index$019;
     $34 = (($size$021) + -2)|0;
     $35 = ($34|0)<(0);
     $36 = $35 ? 0 : $34;
     $37 = (($stack) + ($36<<3)|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ((($stack) + ($36<<3)|0) + 4|0);
     $40 = HEAP32[$39>>2]|0;
     $next_facet$0$be = $38;$next_index$0$be = $40;$size$0$be = $50;
     break;
    }
    HEAP8[$4>>0] = 1;
    $43 = (550816 + ($next_index$019<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (550816 + ($44<<2)|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ((($next_facet$020) + ($46<<2)|0) + 40|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($stack) + ($50<<3)|0);
    HEAP32[$49>>2] = $48;
    $51 = ((($next_facet$020) + ($46)|0) + 52|0);
    $52 = HEAP8[$51>>0]|0;
    $53 = $52 << 24 >> 24;
    $54 = ((($stack) + ($50<<3)|0) + 4|0);
    HEAP32[$54>>2] = $53;
    $55 = (($size$021) + 1)|0;
    $56 = ((($next_facet$020) + ($44<<2)|0) + 40|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ((($next_facet$020) + ($44)|0) + 52|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59 << 24 >> 24;
    $61 = (($next_facet$020) + 59|0);
    $62 = HEAP8[$61>>0]|0;
    $63 = ($62<<24>>24)==(0);
    if ($63) {
     $64 = (($next_facet$020) + 60|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = HEAP8[$3>>0]|0;
     $67 = (($66) + 1)<<24>>24;
     HEAP8[$3>>0] = $67;
     $68 = $66&255;
     $69 = ((($manager) + ($68)|0) + 64|0);
     HEAP8[$69>>0] = $65;
     $next_facet$0$be = $57;$next_index$0$be = $60;$size$0$be = $55;
    } else {
     $next_facet$0$be = $57;$next_index$0$be = $60;$size$0$be = $55;
    }
   } else {
    $7 = (($size$021) + -2)|0;
    $8 = ($7|0)<(0);
    $9 = $8 ? 0 : $7;
    $10 = (($stack) + ($9<<3)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($stack) + ($9<<3)|0) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $next_facet$0$be = $11;$next_index$0$be = $13;$size$0$be = $50;
   }
  } while(0);
  $41 = (($size$0$be) + -1)|0;
  $42 = ($size$0$be|0)==(0);
  if ($42) {
   break;
  } else {
   $50 = $41;$next_facet$020 = $next_facet$0$be;$next_index$019 = $next_index$0$be;$size$021 = $size$0$be;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu3EPA13expandSegmentERKNS0_7ConvexVES4_PNS0_17EPASupportMapPairERi($this,$a,$b,$pair,$numVerts) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 $pair = $pair|0;
 $numVerts = $numVerts|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aux1 = 0, $aux2 = 0, $aux3 = 0, $q0 = 0, $q1 = 0, $q2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $aux1 = sp + 80|0;
 $q0 = sp;
 $aux2 = sp + 16|0;
 $q1 = sp + 32|0;
 $aux3 = sp + 48|0;
 $q2 = sp + 64|0;
 $0 = (($this) + 272|0);
 $1 = (($this) + 272|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 276|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 280|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 1296|0);
 $8 = (($this) + 1296|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 1300|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 1304|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($2 - $9);
 $15 = Math_fround($4 - $11);
 $16 = Math_fround($6 - $13);
 $17 = (($this) + 288|0);
 $18 = (($this) + 288|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 292|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 296|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 1312|0);
 $25 = (($this) + 1312|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 1316|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 1320|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($19 - $26);
 $32 = Math_fround($21 - $28);
 $33 = Math_fround($23 - $30);
 $34 = Math_fround($14 - $31);
 $35 = Math_fround($15 - $32);
 $36 = Math_fround($16 - $33);
 $37 = Math_fround($34 * $34);
 $38 = Math_fround($35 * $35);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($36 * $36);
 $41 = Math_fround($39 + $40);
 $42 = (Math_fround(Math_sqrt((Math_fround($41)))));
 $43 = Math_fround(Math_fround(1.0) / $42);
 $44 = Math_fround($34 * $43);
 $45 = Math_fround($35 * $43);
 $46 = Math_fround($36 * $43);
 $47 = Math_fround($44 * $44);
 $48 = Math_fround($45 * $45);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($46 * $46);
 $51 = Math_fround($50 + $49);
 $52 = Math_fround($46 * $51);
 $53 = Math_fround($45 * $51);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($44 * $51);
 $56 = Math_fround($55 - $52);
 $57 = Math_fround($53 - $55);
 $58 = Math_fround($54 * $54);
 $59 = Math_fround($56 * $56);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($57 * $57);
 $62 = Math_fround($61 + $60);
 $63 = (Math_fround(Math_sqrt((Math_fround($62)))));
 $64 = Math_fround(Math_fround(1.0) / $63);
 $65 = Math_fround($64 * $54);
 $66 = Math_fround($64 * $56);
 $67 = Math_fround($64 * $57);
 $68 = Math_fround($45 * $67);
 $69 = Math_fround($46 * $66);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($46 * $65);
 $72 = Math_fround($44 * $67);
 $73 = Math_fround($71 - $72);
 $74 = Math_fround($44 * $66);
 $75 = Math_fround($45 * $65);
 $76 = Math_fround($74 - $75);
 HEAPF32[$aux1>>2] = $70;
 $77 = (($aux1) + 4|0);
 HEAPF32[$77>>2] = $73;
 $78 = (($aux1) + 8|0);
 HEAPF32[$78>>2] = $76;
 $79 = (($aux1) + 12|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = HEAP32[$pair>>2]|0;
 $81 = (($80) + 12|0);
 $82 = HEAP32[$81>>2]|0;
 FUNCTION_TABLE_viiiii[$82 & 255]($pair,$aux1,$0,$7,$q0);
 $83 = Math_fround($44 * Math_fround(0.866025388240814208984));
 $84 = Math_fround($45 * Math_fround(0.866025388240814208984));
 $85 = Math_fround($46 * Math_fround(0.866025388240814208984));
 $86 = Math_fround(HEAPF32[$aux1>>2]);
 $87 = Math_fround(HEAPF32[$77>>2]);
 $88 = Math_fround(HEAPF32[$78>>2]);
 $89 = Math_fround($86 * Math_fround(-0.25));
 $90 = Math_fround($87 * Math_fround(-0.25));
 $91 = Math_fround($88 * Math_fround(-0.25));
 $92 = Math_fround($84 * $88);
 $93 = Math_fround($85 * $87);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($85 * $86);
 $96 = Math_fround($83 * $88);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($83 * $87);
 $99 = Math_fround($84 * $86);
 $100 = Math_fround($98 - $99);
 $101 = Math_fround($94 * Math_fround(-0.5));
 $102 = Math_fround($97 * Math_fround(-0.5));
 $103 = Math_fround($100 * Math_fround(-0.5));
 $104 = Math_fround($89 + $101);
 $105 = Math_fround($90 + $102);
 $106 = Math_fround($91 + $103);
 $107 = Math_fround($83 * $86);
 $108 = Math_fround($84 * $87);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($85 * $88);
 $111 = Math_fround($109 + $110);
 $112 = Math_fround($83 * $111);
 $113 = Math_fround($84 * $111);
 $114 = Math_fround($85 * $111);
 $115 = Math_fround($112 + $104);
 $116 = Math_fround($113 + $105);
 $117 = Math_fround($106 + $114);
 $118 = Math_fround($115 * Math_fround(2.0));
 $119 = Math_fround($116 * Math_fround(2.0));
 $120 = Math_fround($117 * Math_fround(2.0));
 $121 = Math_fround($118 * $118);
 $122 = Math_fround($119 * $119);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($120 * $120);
 $125 = Math_fround($124 + $123);
 $126 = (Math_fround(Math_sqrt((Math_fround($125)))));
 $127 = Math_fround(Math_fround(1.0) / $126);
 $128 = Math_fround($127 * $118);
 $129 = Math_fround($127 * $119);
 $130 = Math_fround($127 * $120);
 HEAPF32[$aux2>>2] = $128;
 $131 = (($aux2) + 4|0);
 HEAPF32[$131>>2] = $129;
 $132 = (($aux2) + 8|0);
 HEAPF32[$132>>2] = $130;
 $133 = (($aux2) + 12|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = HEAP32[$pair>>2]|0;
 $135 = (($134) + 12|0);
 $136 = HEAP32[$135>>2]|0;
 FUNCTION_TABLE_viiiii[$136 & 255]($pair,$aux2,$17,$24,$q1);
 $137 = Math_fround(HEAPF32[$aux2>>2]);
 $138 = Math_fround(HEAPF32[$131>>2]);
 $139 = Math_fround(HEAPF32[$132>>2]);
 $140 = Math_fround($137 * Math_fround(-0.25));
 $141 = Math_fround($138 * Math_fround(-0.25));
 $142 = Math_fround($139 * Math_fround(-0.25));
 $143 = Math_fround($84 * $139);
 $144 = Math_fround($85 * $138);
 $145 = Math_fround($143 - $144);
 $146 = Math_fround($85 * $137);
 $147 = Math_fround($83 * $139);
 $148 = Math_fround($146 - $147);
 $149 = Math_fround($83 * $138);
 $150 = Math_fround($84 * $137);
 $151 = Math_fround($149 - $150);
 $152 = Math_fround($145 * Math_fround(-0.5));
 $153 = Math_fround($148 * Math_fround(-0.5));
 $154 = Math_fround($151 * Math_fround(-0.5));
 $155 = Math_fround($140 + $152);
 $156 = Math_fround($141 + $153);
 $157 = Math_fround($142 + $154);
 $158 = Math_fround($83 * $137);
 $159 = Math_fround($84 * $138);
 $160 = Math_fround($158 + $159);
 $161 = Math_fround($85 * $139);
 $162 = Math_fround($160 + $161);
 $163 = Math_fround($83 * $162);
 $164 = Math_fround($84 * $162);
 $165 = Math_fround($85 * $162);
 $166 = Math_fround($163 + $155);
 $167 = Math_fround($164 + $156);
 $168 = Math_fround($157 + $165);
 $169 = Math_fround($166 * Math_fround(2.0));
 $170 = Math_fround($167 * Math_fround(2.0));
 $171 = Math_fround($168 * Math_fround(2.0));
 $172 = Math_fround($169 * $169);
 $173 = Math_fround($170 * $170);
 $174 = Math_fround($172 + $173);
 $175 = Math_fround($171 * $171);
 $176 = Math_fround($175 + $174);
 $177 = (Math_fround(Math_sqrt((Math_fround($176)))));
 $178 = Math_fround(Math_fround(1.0) / $177);
 $179 = Math_fround($178 * $169);
 $180 = Math_fround($178 * $170);
 $181 = Math_fround($178 * $171);
 HEAPF32[$aux3>>2] = $179;
 $182 = (($aux3) + 4|0);
 HEAPF32[$182>>2] = $180;
 $183 = (($aux3) + 8|0);
 HEAPF32[$183>>2] = $181;
 $184 = (($aux3) + 12|0);
 HEAPF32[$184>>2] = Math_fround(0.0);
 $185 = HEAP32[$pair>>2]|0;
 $186 = (($185) + 12|0);
 $187 = HEAP32[$186>>2]|0;
 $188 = (($this) + 304|0);
 $189 = (($this) + 1328|0);
 FUNCTION_TABLE_viiiii[$187 & 255]($pair,$aux3,$188,$189,$q2);
 $190 = (__ZN5physx2Gu3EPA14expandTriangleERKNS0_7ConvexVES4_PNS0_17EPASupportMapPairERi($this,0,0,$pair,$numVerts)|0);
 STACKTOP = sp;return ($190|0);
}
function __ZN5physx2Gu3EPA14expandTriangleERKNS0_7ConvexVES4_PNS0_17EPASupportMapPairERi($this,$0,$1,$pair,$numVerts) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $pair = $pair|0;
 $numVerts = $numVerts|0;
 var $$0 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = Math_fround(0);
 var $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = Math_fround(0), $190 = 0, $191 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0;
 var $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0;
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0;
 var $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $a3 = 0, $a4 = 0, $b3 = 0, $b4 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i77 = Math_fround(0), $nvv = 0, $q0 = 0, $q1 = 0;
 var $q2 = 0, $q3 = 0, $q4 = 0, $vv = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $2 = sp + 192|0;
 $3 = sp + 176|0;
 $q0 = sp + 160|0;
 $q1 = sp + 144|0;
 $q2 = sp + 128|0;
 $vv = sp + 112|0;
 $nvv = sp + 96|0;
 $a3 = sp + 64|0;
 $b3 = sp + 48|0;
 $q3 = sp + 32|0;
 $a4 = sp + 16|0;
 $b4 = sp;
 $q4 = sp + 80|0;
 $4 = (($this) + 272|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 276|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 280|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 284|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 1296|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 1300|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 1304|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 1308|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 288|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 292|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 296|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 300|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($this) + 1312|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($this) + 1316|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 1320|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 1324|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($this) + 304|0);
 $37 = (($this) + 304|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($this) + 308|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 312|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 316|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($this) + 1328|0);
 $46 = (($this) + 1328|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($this) + 1332|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($this) + 1336|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($this) + 1340|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($5 - $13);
 $55 = Math_fround($7 - $15);
 $56 = Math_fround($9 - $17);
 HEAPF32[$q0>>2] = $54;
 $57 = (($q0) + 4|0);
 HEAPF32[$57>>2] = $55;
 $58 = (($q0) + 8|0);
 HEAPF32[$58>>2] = $56;
 $59 = (($q0) + 12|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = Math_fround($21 - $29);
 $61 = Math_fround($23 - $31);
 $62 = Math_fround($25 - $33);
 HEAPF32[$q1>>2] = $60;
 $63 = (($q1) + 4|0);
 HEAPF32[$63>>2] = $61;
 $64 = (($q1) + 8|0);
 HEAPF32[$64>>2] = $62;
 $65 = (($q1) + 12|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 $66 = Math_fround($38 - $47);
 $67 = Math_fround($40 - $49);
 $68 = Math_fround($42 - $51);
 HEAPF32[$q2>>2] = $66;
 $69 = (($q2) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($q2) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($q2) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = Math_fround($60 - $54);
 $73 = Math_fround($61 - $55);
 $74 = Math_fround($62 - $56);
 $75 = Math_fround($66 - $54);
 $76 = Math_fround($67 - $55);
 $77 = Math_fround($68 - $56);
 $78 = Math_fround($73 * $77);
 $79 = Math_fround($74 * $76);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($74 * $75);
 $82 = Math_fround($72 * $77);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($72 * $76);
 $85 = Math_fround($73 * $75);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($80 * $80);
 $88 = Math_fround($83 * $83);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($86 * $86);
 $91 = Math_fround($90 + $89);
 $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
 $93 = Math_fround(Math_fround(1.0) / $92);
 $94 = Math_fround($93 * $80);
 $95 = Math_fround($93 * $83);
 $96 = Math_fround($86 * $93);
 HEAPF32[$vv>>2] = $94;
 $97 = (($vv) + 4|0);
 HEAPF32[$97>>2] = $95;
 $98 = (($vv) + 8|0);
 HEAPF32[$98>>2] = $96;
 $99 = (($vv) + 12|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = Math_fround(-$94);
 $101 = Math_fround(-$95);
 $102 = Math_fround(-$96);
 HEAPF32[$nvv>>2] = $100;
 $103 = (($nvv) + 4|0);
 HEAPF32[$103>>2] = $101;
 $104 = (($nvv) + 8|0);
 HEAPF32[$104>>2] = $102;
 $105 = (($nvv) + 12|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = Math_fround($94 * $54);
 $107 = Math_fround($95 * $55);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($96 * $56);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround(-$110);
 $112 = HEAP32[$pair>>2]|0;
 $113 = (($112) + 12|0);
 $114 = HEAP32[$113>>2]|0;
 FUNCTION_TABLE_viiiii[$114 & 255]($pair,$vv,$a3,$b3,$q3);
 $115 = Math_fround(HEAPF32[$vv>>2]);
 $116 = Math_fround(HEAPF32[$97>>2]);
 $117 = Math_fround(HEAPF32[$98>>2]);
 $118 = Math_fround(HEAPF32[$q3>>2]);
 $119 = (($q3) + 4|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($q3) + 8|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround($115 * $118);
 $124 = Math_fround($116 * $120);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($117 * $122);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround($127 - $110);
 $fabsf$i$i$i77 = (Math_fround(Math_abs((Math_fround($128)))));
 $129 = !($fabsf$i$i$i77 >= Math_fround(9.99999974737875163555E-5));
 if (!($129)) {
  $130 = Math_fround($128 * $111);
  $131 = !($130 >= Math_fround(0.0));
  if (!($131)) {
   __ZN5physx2Gu20PointOutsideOfPlane4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_($2,$q0,$q1,$q2,$q3);
   $132 = HEAP32[$2>>2]|0;
   $133 = ($132|0)==(0);
   if ($133) {
    $134 = (($2) + 4|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = ($135|0)==(0);
    if ($136) {
     $137 = (($2) + 8|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = ($138|0)==(0);
     if ($139) {
      $140 = (($2) + 12|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = ($141|0)==(0);
      if ($142) {
       $143 = (($this) + 320|0);
       ;HEAP32[$143+0>>2]=HEAP32[$a3+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$a3+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$a3+8>>2]|0;HEAP32[$143+12>>2]=HEAP32[$a3+12>>2]|0;
       $144 = (($this) + 1344|0);
       ;HEAP32[$144+0>>2]=HEAP32[$b3+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$b3+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$b3+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$b3+12>>2]|0;
       $145 = (__ZN5physx2Gu3EPA16addInitialFacet4Ev($this)|0);
       if (!($145)) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       HEAP32[$numVerts>>2] = 4;
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
   ;HEAP32[$36+0>>2]=HEAP32[$a3+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$a3+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$a3+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$a3+12>>2]|0;
   ;HEAP32[$45+0>>2]=HEAP32[$b3+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$b3+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$b3+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$b3+12>>2]|0;
   $146 = (__ZN5physx2Gu3EPA6expandERKNS_6shdfnd3aos5Vec3VES6_S6_PNS0_17EPASupportMapPairERi($this,$q0,$q1,$q3,$pair,$numVerts)|0);
   if ($146) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAPF32[$20>>2] = $38;
   HEAPF32[$22>>2] = $40;
   HEAPF32[$24>>2] = $42;
   HEAPF32[$26>>2] = $44;
   HEAPF32[$28>>2] = $47;
   HEAPF32[$30>>2] = $49;
   HEAPF32[$32>>2] = $51;
   HEAPF32[$34>>2] = $53;
   $147 = (__ZN5physx2Gu3EPA6expandERKNS_6shdfnd3aos5Vec3VES6_S6_PNS0_17EPASupportMapPairERi($this,$q0,$q2,$q3,$pair,$numVerts)|0);
   if ($147) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAPF32[$4>>2] = $21;
   HEAPF32[$6>>2] = $23;
   HEAPF32[$8>>2] = $25;
   HEAPF32[$10>>2] = $27;
   HEAPF32[$12>>2] = $29;
   HEAPF32[$14>>2] = $31;
   HEAPF32[$16>>2] = $33;
   HEAPF32[$18>>2] = $35;
   $148 = (__ZN5physx2Gu3EPA6expandERKNS_6shdfnd3aos5Vec3VES6_S6_PNS0_17EPASupportMapPairERi($this,$q1,$q2,$q3,$pair,$numVerts)|0);
   if ($148) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $149 = HEAP32[$pair>>2]|0;
 $150 = (($149) + 12|0);
 $151 = HEAP32[$150>>2]|0;
 FUNCTION_TABLE_viiiii[$151 & 255]($pair,$nvv,$a4,$b4,$q4);
 $152 = Math_fround(HEAPF32[$vv>>2]);
 $153 = Math_fround(HEAPF32[$97>>2]);
 $154 = Math_fround(HEAPF32[$98>>2]);
 $155 = Math_fround(HEAPF32[$q4>>2]);
 $156 = (($q4) + 4|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = (($q4) + 8|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = Math_fround($152 * $155);
 $161 = Math_fround($153 * $157);
 $162 = Math_fround($160 + $161);
 $163 = Math_fround($154 * $159);
 $164 = Math_fround($162 + $163);
 $165 = Math_fround($164 - $110);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($165)))));
 $166 = !($fabsf$i$i$i >= Math_fround(9.99999974737875163555E-5));
 if (!($166)) {
  $167 = Math_fround($165 * $111);
  $168 = !($167 >= Math_fround(0.0));
  if (!($168)) {
   HEAPF32[$4>>2] = $5;
   HEAPF32[$6>>2] = $7;
   HEAPF32[$8>>2] = $9;
   HEAPF32[$10>>2] = $11;
   HEAPF32[$20>>2] = $21;
   HEAPF32[$22>>2] = $23;
   HEAPF32[$24>>2] = $25;
   HEAPF32[$26>>2] = $27;
   HEAPF32[$37>>2] = $38;
   HEAPF32[$39>>2] = $40;
   HEAPF32[$41>>2] = $42;
   HEAPF32[$43>>2] = $44;
   HEAPF32[$12>>2] = $13;
   HEAPF32[$14>>2] = $15;
   HEAPF32[$16>>2] = $17;
   HEAPF32[$18>>2] = $19;
   HEAPF32[$28>>2] = $29;
   HEAPF32[$30>>2] = $31;
   HEAPF32[$32>>2] = $33;
   HEAPF32[$34>>2] = $35;
   HEAPF32[$46>>2] = $47;
   HEAPF32[$48>>2] = $49;
   HEAPF32[$50>>2] = $51;
   HEAPF32[$52>>2] = $53;
   __ZN5physx2Gu20PointOutsideOfPlane4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_($3,$q0,$q1,$q2,$q4);
   $169 = HEAP32[$3>>2]|0;
   $170 = ($169|0)==(0);
   if ($170) {
    $171 = (($3) + 4|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = ($172|0)==(0);
    if ($173) {
     $174 = (($3) + 8|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = ($175|0)==(0);
     if ($176) {
      $177 = (($3) + 12|0);
      $178 = HEAP32[$177>>2]|0;
      $179 = ($178|0)==(0);
      if ($179) {
       $180 = (($this) + 320|0);
       ;HEAP32[$180+0>>2]=HEAP32[$a4+0>>2]|0;HEAP32[$180+4>>2]=HEAP32[$a4+4>>2]|0;HEAP32[$180+8>>2]=HEAP32[$a4+8>>2]|0;HEAP32[$180+12>>2]=HEAP32[$a4+12>>2]|0;
       $181 = (($this) + 1344|0);
       ;HEAP32[$181+0>>2]=HEAP32[$b4+0>>2]|0;HEAP32[$181+4>>2]=HEAP32[$b4+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$b4+8>>2]|0;HEAP32[$181+12>>2]=HEAP32[$b4+12>>2]|0;
       $182 = (__ZN5physx2Gu3EPA16addInitialFacet4Ev($this)|0);
       if (!($182)) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       HEAP32[$numVerts>>2] = 4;
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
   ;HEAP32[$36+0>>2]=HEAP32[$a4+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$a4+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$a4+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$a4+12>>2]|0;
   ;HEAP32[$45+0>>2]=HEAP32[$b4+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$b4+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$b4+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$b4+12>>2]|0;
   $183 = (__ZN5physx2Gu3EPA6expandERKNS_6shdfnd3aos5Vec3VES6_S6_PNS0_17EPASupportMapPairERi($this,$q0,$q1,$q4,$pair,$numVerts)|0);
   if ($183) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAPF32[$20>>2] = $38;
   HEAPF32[$22>>2] = $40;
   HEAPF32[$24>>2] = $42;
   HEAPF32[$26>>2] = $44;
   HEAPF32[$28>>2] = $47;
   HEAPF32[$30>>2] = $49;
   HEAPF32[$32>>2] = $51;
   HEAPF32[$34>>2] = $53;
   $184 = (__ZN5physx2Gu3EPA6expandERKNS_6shdfnd3aos5Vec3VES6_S6_PNS0_17EPASupportMapPairERi($this,$q0,$q2,$q4,$pair,$numVerts)|0);
   if ($184) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAPF32[$4>>2] = $21;
   HEAPF32[$6>>2] = $23;
   HEAPF32[$8>>2] = $25;
   HEAPF32[$10>>2] = $27;
   HEAPF32[$12>>2] = $29;
   HEAPF32[$14>>2] = $31;
   HEAPF32[$16>>2] = $33;
   HEAPF32[$18>>2] = $35;
   $185 = (__ZN5physx2Gu3EPA6expandERKNS_6shdfnd3aos5Vec3VES6_S6_PNS0_17EPASupportMapPairERi($this,$q1,$q2,$q4,$pair,$numVerts)|0);
   if ($185) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $186 = $110 == Math_fround(-0.0);
 if (!($186)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$4>>2] = $5;
 HEAPF32[$6>>2] = $7;
 HEAPF32[$8>>2] = $9;
 HEAPF32[$10>>2] = $11;
 HEAPF32[$20>>2] = $21;
 HEAPF32[$22>>2] = $23;
 HEAPF32[$24>>2] = $25;
 HEAPF32[$26>>2] = $27;
 HEAPF32[$37>>2] = $38;
 HEAPF32[$39>>2] = $40;
 HEAPF32[$41>>2] = $42;
 HEAPF32[$43>>2] = $44;
 HEAPF32[$12>>2] = $13;
 HEAPF32[$14>>2] = $15;
 HEAPF32[$16>>2] = $17;
 HEAPF32[$18>>2] = $19;
 HEAPF32[$28>>2] = $29;
 HEAPF32[$30>>2] = $31;
 HEAPF32[$32>>2] = $33;
 HEAPF32[$34>>2] = $35;
 HEAPF32[$46>>2] = $47;
 HEAPF32[$48>>2] = $49;
 HEAPF32[$50>>2] = $51;
 HEAPF32[$52>>2] = $53;
 $187 = (($this) + 320|0);
 ;HEAP32[$187+0>>2]=HEAP32[$a3+0>>2]|0;HEAP32[$187+4>>2]=HEAP32[$a3+4>>2]|0;HEAP32[$187+8>>2]=HEAP32[$a3+8>>2]|0;HEAP32[$187+12>>2]=HEAP32[$a3+12>>2]|0;
 $188 = (($this) + 1344|0);
 ;HEAP32[$188+0>>2]=HEAP32[$b3+0>>2]|0;HEAP32[$188+4>>2]=HEAP32[$b3+4>>2]|0;HEAP32[$188+8>>2]=HEAP32[$b3+8>>2]|0;HEAP32[$188+12>>2]=HEAP32[$b3+12>>2]|0;
 $189 = (($this) + 336|0);
 ;HEAP32[$189+0>>2]=HEAP32[$a4+0>>2]|0;HEAP32[$189+4>>2]=HEAP32[$a4+4>>2]|0;HEAP32[$189+8>>2]=HEAP32[$a4+8>>2]|0;HEAP32[$189+12>>2]=HEAP32[$a4+12>>2]|0;
 $190 = (($this) + 1360|0);
 ;HEAP32[$190+0>>2]=HEAP32[$b4+0>>2]|0;HEAP32[$190+4>>2]=HEAP32[$b4+4>>2]|0;HEAP32[$190+8>>2]=HEAP32[$b4+8>>2]|0;HEAP32[$190+12>>2]=HEAP32[$b4+12>>2]|0;
 $191 = (__ZN5physx2Gu3EPA16addInitialFacet5Ev($this)|0);
 if (!($191)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$numVerts>>2] = 5;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu3EPA16addInitialFacet4Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_max = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $zero = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $zero = sp + 16|0;
 $_max = sp;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 HEAPF32[$_max>>2] = Math_fround(3.40282346638528859812E+38);
 $0 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,0,1,2,$zero,$_max)|0);
 $1 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,0,3,1,$zero,$_max)|0);
 $2 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,0,2,3,$zero,$_max)|0);
 $3 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,1,3,2,$zero,$_max)|0);
 $4 = ($0|0)==(0|0);
 $5 = ($1|0)==(0|0);
 $or$cond = $4 | $5;
 $6 = ($2|0)==(0|0);
 $or$cond1 = $or$cond | $6;
 $7 = ($3|0)==(0|0);
 $or$cond2 = $or$cond1 | $7;
 if ($or$cond2) {
  STACKTOP = sp;return 0;
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return 0;
 } else {
  $10 = (($0) + 40|0);
  HEAP32[$10>>2] = $1;
  $11 = (($0) + 52|0);
  HEAP8[$11>>0] = 2;
  $12 = (($1) + 48|0);
  HEAP32[$12>>2] = $0;
  $13 = (($1) + 54|0);
  HEAP8[$13>>0] = 0;
  $14 = (($0) + 44|0);
  HEAP32[$14>>2] = $3;
  $15 = (($0) + 53|0);
  HEAP8[$15>>0] = 2;
  $16 = (($3) + 48|0);
  HEAP32[$16>>2] = $0;
  $17 = (($3) + 54|0);
  HEAP8[$17>>0] = 1;
  $18 = (($0) + 48|0);
  HEAP32[$18>>2] = $2;
  $19 = (($0) + 54|0);
  HEAP8[$19>>0] = 0;
  $20 = (($2) + 40|0);
  HEAP32[$20>>2] = $0;
  $21 = (($2) + 52|0);
  HEAP8[$21>>0] = 2;
  $22 = (($1) + 40|0);
  HEAP32[$22>>2] = $2;
  $23 = (($1) + 52|0);
  HEAP8[$23>>0] = 2;
  $24 = (($2) + 48|0);
  HEAP32[$24>>2] = $1;
  $25 = (($2) + 54|0);
  HEAP8[$25>>0] = 0;
  $26 = (($1) + 44|0);
  HEAP32[$26>>2] = $3;
  $27 = (($1) + 53|0);
  HEAP8[$27>>0] = 0;
  $28 = (($3) + 40|0);
  HEAP32[$28>>2] = $1;
  $29 = (($3) + 52|0);
  HEAP8[$29>>0] = 1;
  $30 = (($2) + 44|0);
  HEAP32[$30>>2] = $3;
  $31 = (($2) + 53|0);
  HEAP8[$31>>0] = 1;
  $32 = (($3) + 44|0);
  HEAP32[$32>>2] = $2;
  $33 = (($3) + 53|0);
  HEAP8[$33>>0] = 1;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5physx2Gu3EPA16addInitialFacet5Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_max = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond4 = 0, $zero = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $zero = sp + 16|0;
 $_max = sp;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 HEAPF32[$_max>>2] = Math_fround(3.40282346638528859812E+38);
 $0 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,0,3,2,$zero,$_max)|0);
 $1 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,1,3,0,$zero,$_max)|0);
 $2 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,2,3,1,$zero,$_max)|0);
 $3 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,2,4,0,$zero,$_max)|0);
 $4 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,0,4,1,$zero,$_max)|0);
 $5 = (__ZN5physx2Gu3EPA8addFacetEjjjRKNS_6shdfnd3aos6FloatVES6_($this,1,4,2,$zero,$_max)|0);
 $6 = ($0|0)==(0|0);
 $7 = ($1|0)==(0|0);
 $or$cond = $6 | $7;
 $8 = ($2|0)==(0|0);
 $or$cond1 = $or$cond | $8;
 $9 = ($3|0)==(0|0);
 $or$cond2 = $or$cond1 | $9;
 $10 = ($4|0)==(0|0);
 $or$cond3 = $or$cond2 | $10;
 $11 = ($5|0)==(0|0);
 $or$cond4 = $or$cond3 | $11;
 if ($or$cond4) {
  STACKTOP = sp;return 0;
 }
 $12 = HEAP32[$this>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  STACKTOP = sp;return 0;
 } else {
  $14 = (($0) + 40|0);
  HEAP32[$14>>2] = $1;
  $15 = (($0) + 52|0);
  HEAP8[$15>>0] = 1;
  $16 = (($1) + 44|0);
  HEAP32[$16>>2] = $0;
  $17 = (($1) + 53|0);
  HEAP8[$17>>0] = 0;
  $18 = (($0) + 44|0);
  HEAP32[$18>>2] = $2;
  $19 = (($0) + 53|0);
  HEAP8[$19>>0] = 0;
  $20 = (($2) + 40|0);
  HEAP32[$20>>2] = $0;
  $21 = (($2) + 52|0);
  HEAP8[$21>>0] = 1;
  $22 = (($0) + 48|0);
  HEAP32[$22>>2] = $3;
  $23 = (($0) + 54|0);
  HEAP8[$23>>0] = 2;
  $24 = (($3) + 48|0);
  HEAP32[$24>>2] = $0;
  $25 = (($3) + 54|0);
  HEAP8[$25>>0] = 2;
  $26 = (($1) + 40|0);
  HEAP32[$26>>2] = $2;
  $27 = (($1) + 52|0);
  HEAP8[$27>>0] = 1;
  $28 = (($2) + 44|0);
  HEAP32[$28>>2] = $1;
  $29 = (($2) + 53|0);
  HEAP8[$29>>0] = 0;
  $30 = (($1) + 48|0);
  HEAP32[$30>>2] = $4;
  $31 = (($1) + 54|0);
  HEAP8[$31>>0] = 2;
  $32 = (($4) + 48|0);
  HEAP32[$32>>2] = $1;
  $33 = (($4) + 54|0);
  HEAP8[$33>>0] = 2;
  $34 = (($2) + 48|0);
  HEAP32[$34>>2] = $5;
  $35 = (($2) + 54|0);
  HEAP8[$35>>0] = 2;
  $36 = (($5) + 48|0);
  HEAP32[$36>>2] = $2;
  $37 = (($5) + 54|0);
  HEAP8[$37>>0] = 2;
  $38 = (($3) + 40|0);
  HEAP32[$38>>2] = $5;
  $39 = (($3) + 52|0);
  HEAP8[$39>>0] = 1;
  $40 = (($5) + 44|0);
  HEAP32[$40>>2] = $3;
  $41 = (($5) + 53|0);
  HEAP8[$41>>0] = 0;
  $42 = (($3) + 44|0);
  HEAP32[$42>>2] = $4;
  $43 = (($3) + 53|0);
  HEAP8[$43>>0] = 0;
  $44 = (($4) + 40|0);
  HEAP32[$44>>2] = $3;
  $45 = (($4) + 52|0);
  HEAP8[$45>>0] = 1;
  $46 = (($4) + 44|0);
  HEAP32[$46>>2] = $5;
  $47 = (($4) + 53|0);
  HEAP8[$47>>0] = 0;
  $48 = (($5) + 40|0);
  HEAP32[$48>>2] = $4;
  $49 = (($5) + 52|0);
  HEAP8[$49>>0] = 1;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5physx2Gu3EPA6expandERKNS_6shdfnd3aos5Vec3VES6_S6_PNS0_17EPASupportMapPairERi($this,$q0,$q1,$q2,$pair,$numVerts) {
 $this = $this|0;
 $q0 = $q0|0;
 $q1 = $q1|0;
 $q2 = $q2|0;
 $pair = $pair|0;
 $numVerts = $numVerts|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0;
 var $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a3 = 0, $a4 = 0, $b3 = 0, $b4 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i59 = Math_fround(0), $n = 0, $nn = 0, $q3 = 0, $q4 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 144|0;
 $1 = sp + 128|0;
 $n = sp + 112|0;
 $nn = sp + 96|0;
 $a3 = sp + 80|0;
 $b3 = sp + 64|0;
 $q3 = sp + 32|0;
 $a4 = sp + 16|0;
 $b4 = sp;
 $q4 = sp + 48|0;
 $2 = Math_fround(HEAPF32[$q1>>2]);
 $3 = (($q1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($q1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$q0>>2]);
 $8 = (($q0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($q0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($2 - $7);
 $13 = Math_fround($4 - $9);
 $14 = Math_fround($6 - $11);
 $15 = Math_fround(HEAPF32[$q2>>2]);
 $16 = (($q2) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($q2) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($15 - $7);
 $21 = Math_fround($17 - $9);
 $22 = Math_fround($19 - $11);
 $23 = Math_fround($13 * $22);
 $24 = Math_fround($14 * $21);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($14 * $20);
 $27 = Math_fround($12 * $22);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($12 * $21);
 $30 = Math_fround($13 * $20);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround($25 * $25);
 $33 = Math_fround($28 * $28);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($31 * $31);
 $36 = Math_fround($35 + $34);
 $37 = (Math_fround(Math_sqrt((Math_fround($36)))));
 $38 = Math_fround(Math_fround(1.0) / $37);
 $39 = Math_fround($38 * $25);
 $40 = Math_fround($38 * $28);
 $41 = Math_fround($31 * $38);
 HEAPF32[$n>>2] = $39;
 $42 = (($n) + 4|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($n) + 8|0);
 HEAPF32[$43>>2] = $41;
 $44 = (($n) + 12|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = Math_fround(-$39);
 $46 = Math_fround(-$40);
 $47 = Math_fround(-$41);
 HEAPF32[$nn>>2] = $45;
 $48 = (($nn) + 4|0);
 HEAPF32[$48>>2] = $46;
 $49 = (($nn) + 8|0);
 HEAPF32[$49>>2] = $47;
 $50 = (($nn) + 12|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = HEAP32[$pair>>2]|0;
 $52 = (($51) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_viiiii[$53 & 255]($pair,$n,$a3,$b3,$q3);
 $54 = Math_fround(HEAPF32[$n>>2]);
 $55 = Math_fround(HEAPF32[$42>>2]);
 $56 = Math_fround(HEAPF32[$43>>2]);
 $57 = Math_fround(HEAPF32[$q0>>2]);
 $58 = Math_fround(HEAPF32[$8>>2]);
 $59 = Math_fround(HEAPF32[$10>>2]);
 $60 = Math_fround($54 * $57);
 $61 = Math_fround($55 * $58);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($56 * $59);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround(-$64);
 $66 = Math_fround(HEAPF32[$q3>>2]);
 $67 = (($q3) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($q3) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($54 * $66);
 $72 = Math_fround($55 * $68);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($56 * $70);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($75 - $64);
 $fabsf$i$i$i59 = (Math_fround(Math_abs((Math_fround($76)))));
 $77 = !($fabsf$i$i$i59 >= Math_fround(1.1920928955078125E-7));
 if (!($77)) {
  $78 = Math_fround($76 * $65);
  $79 = $78 > Math_fround(0.0);
  if ($79) {
   __ZN5physx2Gu20PointOutsideOfPlane4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_($0,$q0,$q1,$q2,$q3);
   $80 = HEAP32[$0>>2]|0;
   $81 = ($80|0)==(0);
   if ($81) {
    $82 = (($0) + 4|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($83|0)==(0);
    if ($84) {
     $85 = (($0) + 8|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86|0)==(0);
     if ($87) {
      $88 = (($0) + 12|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($89|0)==(0);
      if ($90) {
       $91 = (($this) + 320|0);
       ;HEAP32[$91+0>>2]=HEAP32[$a3+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$a3+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$a3+8>>2]|0;HEAP32[$91+12>>2]=HEAP32[$a3+12>>2]|0;
       $92 = (($this) + 1344|0);
       ;HEAP32[$92+0>>2]=HEAP32[$b3+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$b3+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$b3+8>>2]|0;HEAP32[$92+12>>2]=HEAP32[$b3+12>>2]|0;
       $93 = (__ZN5physx2Gu3EPA16addInitialFacet4Ev($this)|0);
       if (!($93)) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       HEAP32[$numVerts>>2] = 4;
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $94 = HEAP32[$pair>>2]|0;
 $95 = (($94) + 12|0);
 $96 = HEAP32[$95>>2]|0;
 FUNCTION_TABLE_viiiii[$96 & 255]($pair,$nn,$a4,$b4,$q4);
 $97 = Math_fround(HEAPF32[$n>>2]);
 $98 = Math_fround(HEAPF32[$42>>2]);
 $99 = Math_fround(HEAPF32[$43>>2]);
 $100 = Math_fround(HEAPF32[$q4>>2]);
 $101 = (($q4) + 4|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($q4) + 8|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($97 * $100);
 $106 = Math_fround($98 * $102);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($99 * $104);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($109 - $64);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($110)))));
 $111 = !($fabsf$i$i$i >= Math_fround(1.1920928955078125E-7));
 if ($111) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $112 = Math_fround($110 * $65);
 $113 = $112 > Math_fround(0.0);
 if (!($113)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx2Gu20PointOutsideOfPlane4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_($1,$q0,$q1,$q2,$q4);
 $114 = HEAP32[$1>>2]|0;
 $115 = ($114|0)==(0);
 if (!($115)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $116 = (($1) + 4|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ($117|0)==(0);
 if (!($118)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $119 = (($1) + 8|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($120|0)==(0);
 if (!($121)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $122 = (($1) + 12|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ($123|0)==(0);
 if (!($124)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $125 = (($this) + 320|0);
 ;HEAP32[$125+0>>2]=HEAP32[$a4+0>>2]|0;HEAP32[$125+4>>2]=HEAP32[$a4+4>>2]|0;HEAP32[$125+8>>2]=HEAP32[$a4+8>>2]|0;HEAP32[$125+12>>2]=HEAP32[$a4+12>>2]|0;
 $126 = (($this) + 1344|0);
 ;HEAP32[$126+0>>2]=HEAP32[$b4+0>>2]|0;HEAP32[$126+4>>2]=HEAP32[$b4+4>>2]|0;HEAP32[$126+8>>2]=HEAP32[$b4+8>>2]|0;HEAP32[$126+12>>2]=HEAP32[$b4+12>>2]|0;
 $127 = (__ZN5physx2Gu3EPA16addInitialFacet4Ev($this)|0);
 if (!($127)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$numVerts>>2] = 4;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2GuL27calculateContactInformationERKNS_6shdfnd3aos5Vec3VES5_RKNS0_7ConvexVES8_RS3_S9_S9_RNS2_6FloatVEb($_pa,$_pb,$a,$b,$pa,$pb,$normal,$penDepth,$takeCoreShape) {
 $_pa = $_pa|0;
 $_pb = $_pb|0;
 $a = $a|0;
 $b = $b|0;
 $pa = $pa|0;
 $pb = $pb|0;
 $normal = $normal|0;
 $penDepth = $penDepth|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$sroa$159 = 0, $$sroa$197 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$sroa$197 = sp + 12|0;
 $$sroa$159 = sp;
 if ($takeCoreShape) {
  ;HEAP32[$pa+0>>2]=HEAP32[$_pa+0>>2]|0;HEAP32[$pa+4>>2]=HEAP32[$_pa+4>>2]|0;HEAP32[$pa+8>>2]=HEAP32[$_pa+8>>2]|0;HEAP32[$pa+12>>2]=HEAP32[$_pa+12>>2]|0;
  ;HEAP32[$pb+0>>2]=HEAP32[$_pb+0>>2]|0;HEAP32[$pb+4>>2]=HEAP32[$_pb+4>>2]|0;HEAP32[$pb+8>>2]=HEAP32[$_pb+8>>2]|0;HEAP32[$pb+12>>2]=HEAP32[$_pb+12>>2]|0;
  $0 = Math_fround(HEAPF32[$_pb>>2]);
  $1 = (($_pb) + 4|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $3 = (($_pb) + 8|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = Math_fround(HEAPF32[$_pa>>2]);
  $6 = (($_pa) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($_pa) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($0 - $5);
  $11 = Math_fround($2 - $7);
  $12 = Math_fround($4 - $9);
  $13 = Math_fround($10 * $10);
  $14 = Math_fround($11 * $11);
  $15 = Math_fround($13 + $14);
  $16 = Math_fround($12 * $12);
  $17 = Math_fround($15 + $16);
  $18 = (Math_fround(Math_sqrt((Math_fround($17)))));
  $19 = Math_fround(Math_fround(1.0) / $18);
  $20 = Math_fround($10 * $19);
  $21 = Math_fround($11 * $19);
  $22 = Math_fround($12 * $19);
  HEAPF32[$normal>>2] = $20;
  $23 = (($normal) + 4|0);
  HEAPF32[$23>>2] = $21;
  $24 = (($normal) + 8|0);
  HEAPF32[$24>>2] = $22;
  $25 = (($normal) + 12|0);
  HEAPF32[$25>>2] = Math_fround(0.0);
  $26 = Math_fround(-$18);
  HEAPF32[$penDepth>>2] = $26;
  $27 = (($penDepth) + 4|0);
  ;HEAP32[$27+0>>2]=HEAP32[$$sroa$197+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$$sroa$197+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$$sroa$197+8>>2]|0;
  STACKTOP = sp;return;
 } else {
  $28 = (($a) + 64|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($b) + 64|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = Math_fround(HEAPF32[$_pb>>2]);
  $33 = (($_pb) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($_pb) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround(HEAPF32[$_pa>>2]);
  $38 = (($_pa) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($_pa) + 8|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($32 - $37);
  $43 = Math_fround($34 - $39);
  $44 = Math_fround($36 - $41);
  $45 = Math_fround($42 * $42);
  $46 = Math_fround($43 * $43);
  $47 = Math_fround($45 + $46);
  $48 = Math_fround($44 * $44);
  $49 = Math_fround($47 + $48);
  $50 = (Math_fround(Math_sqrt((Math_fround($49)))));
  $51 = Math_fround(Math_fround(1.0) / $50);
  $52 = Math_fround($42 * $51);
  $53 = Math_fround($43 * $51);
  $54 = Math_fround($44 * $51);
  $55 = (($a) + 16|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = ($29|0)==(0);
  $58 = $57 ? Math_fround(0.0) : $56;
  $59 = (($b) + 16|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = ($31|0)==(0);
  $62 = $61 ? Math_fround(0.0) : $60;
  $63 = Math_fround($58 + $62);
  $64 = Math_fround($52 * $58);
  $65 = Math_fround($53 * $58);
  $66 = Math_fround($54 * $58);
  $67 = Math_fround($37 - $64);
  $68 = Math_fround($39 - $65);
  $69 = Math_fround($41 - $66);
  HEAPF32[$pa>>2] = $67;
  $70 = (($pa) + 4|0);
  HEAPF32[$70>>2] = $68;
  $71 = (($pa) + 8|0);
  HEAPF32[$71>>2] = $69;
  $72 = (($pa) + 12|0);
  HEAPF32[$72>>2] = Math_fround(0.0);
  $73 = Math_fround(HEAPF32[$_pb>>2]);
  $74 = Math_fround(HEAPF32[$33>>2]);
  $75 = Math_fround(HEAPF32[$35>>2]);
  $76 = Math_fround($52 * $62);
  $77 = Math_fround($53 * $62);
  $78 = Math_fround($54 * $62);
  $79 = Math_fround($76 + $73);
  $80 = Math_fround($77 + $74);
  $81 = Math_fround($78 + $75);
  HEAPF32[$pb>>2] = $79;
  $82 = (($pb) + 4|0);
  HEAPF32[$82>>2] = $80;
  $83 = (($pb) + 8|0);
  HEAPF32[$83>>2] = $81;
  $84 = (($pb) + 12|0);
  HEAPF32[$84>>2] = Math_fround(0.0);
  $85 = Math_fround($50 + $63);
  $86 = Math_fround(-$85);
  HEAPF32[$penDepth>>2] = $86;
  $87 = (($penDepth) + 4|0);
  ;HEAP32[$87+0>>2]=HEAP32[$$sroa$159+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$$sroa$159+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$$sroa$159+8>>2]|0;
  HEAPF32[$normal>>2] = $52;
  $88 = (($normal) + 4|0);
  HEAPF32[$88>>2] = $53;
  $89 = (($normal) + 8|0);
  HEAPF32[$89>>2] = $54;
  $90 = (($normal) + 12|0);
  HEAPF32[$90>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu20PointOutsideOfPlane4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_($agg$result,$_a,$_b,$_c,$_d) {
 $agg$result = $agg$result|0;
 $_a = $_a|0;
 $_b = $_b|0;
 $_c = $_c|0;
 $_d = $_d|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0);
 var $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$_b>>2]);
 $1 = (($_b) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($_b) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$_a>>2]);
 $6 = (($_a) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($_a) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($0 - $5);
 $11 = Math_fround($2 - $7);
 $12 = Math_fround($4 - $9);
 $13 = Math_fround(HEAPF32[$_c>>2]);
 $14 = (($_c) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($_c) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($13 - $5);
 $19 = Math_fround($15 - $7);
 $20 = Math_fround($17 - $9);
 $21 = Math_fround(HEAPF32[$_d>>2]);
 $22 = (($_d) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($_d) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($21 - $5);
 $27 = Math_fround($23 - $7);
 $28 = Math_fround($25 - $9);
 $29 = Math_fround($21 - $0);
 $30 = Math_fround($23 - $2);
 $31 = Math_fround($25 - $4);
 $32 = Math_fround($13 - $0);
 $33 = Math_fround($15 - $2);
 $34 = Math_fround($17 - $4);
 $35 = Math_fround($11 * $20);
 $36 = Math_fround($12 * $19);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($12 * $18);
 $39 = Math_fround($10 * $20);
 $40 = Math_fround($38 - $39);
 $41 = Math_fround($10 * $19);
 $42 = Math_fround($11 * $18);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($19 * $28);
 $45 = Math_fround($20 * $27);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($20 * $26);
 $48 = Math_fround($18 * $28);
 $49 = Math_fround($47 - $48);
 $50 = Math_fround($18 * $27);
 $51 = Math_fround($19 * $26);
 $52 = Math_fround($50 - $51);
 $53 = Math_fround($12 * $27);
 $54 = Math_fround($11 * $28);
 $55 = Math_fround($53 - $54);
 $56 = Math_fround($10 * $28);
 $57 = Math_fround($12 * $26);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($11 * $26);
 $60 = Math_fround($10 * $27);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($34 * $30);
 $63 = Math_fround($33 * $31);
 $64 = Math_fround($62 - $63);
 $65 = Math_fround($32 * $31);
 $66 = Math_fround($34 * $29);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($33 * $29);
 $69 = Math_fround($32 * $30);
 $70 = Math_fround($68 - $69);
 $71 = Math_fround($5 * $37);
 $72 = Math_fround($7 * $40);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($9 * $43);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($5 * $46);
 $77 = Math_fround($7 * $49);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($9 * $52);
 $80 = Math_fround($79 + $78);
 $81 = Math_fround($5 * $55);
 $82 = Math_fround($7 * $58);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($9 * $61);
 $85 = Math_fround($84 + $83);
 $86 = Math_fround($5 * $64);
 $87 = Math_fround($7 * $67);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($9 * $70);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($21 * $37);
 $92 = Math_fround($23 * $40);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($43 * $25);
 $95 = Math_fround($94 + $93);
 $96 = Math_fround($0 * $46);
 $97 = Math_fround($2 * $49);
 $98 = Math_fround($96 + $97);
 $99 = Math_fround($4 * $52);
 $100 = Math_fround($99 + $98);
 $101 = Math_fround($13 * $55);
 $102 = Math_fround($15 * $58);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($17 * $61);
 $105 = Math_fround($104 + $103);
 $106 = Math_fround($0 * $64);
 $107 = Math_fround($2 * $67);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($4 * $70);
 $110 = Math_fround($109 + $108);
 $111 = Math_fround($75 * $95);
 $112 = Math_fround($80 * $100);
 $113 = Math_fround($85 * $105);
 $114 = Math_fround($110 * $90);
 $115 = $111 >= Math_fround(-9.99999997475242707878E-7);
 $116 = $115 << 31 >> 31;
 $117 = $112 >= Math_fround(-9.99999997475242707878E-7);
 $118 = $117 << 31 >> 31;
 $119 = $113 >= Math_fround(-9.99999997475242707878E-7);
 $120 = $119 << 31 >> 31;
 $121 = $114 >= Math_fround(-9.99999997475242707878E-7);
 $122 = $121 << 31 >> 31;
 HEAP32[$agg$result>>2] = $116;
 $123 = (($agg$result) + 4|0);
 HEAP32[$123>>2] = $118;
 $124 = (($agg$result) + 8|0);
 HEAP32[$124>>2] = $120;
 $125 = (($agg$result) + 12|0);
 HEAP32[$125>>2] = $122;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($agg$result,$a,$b,$c,$Q,$A,$B,$size,$closestA,$closestB) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $Q = $Q|0;
 $A = $A|0;
 $B = $B|0;
 $size = $size|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 var $$$$not = 0, $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$not = 0, $$1$i$i = Math_fround(0), $$1722 = 0, $$1722$ = 0, $$1723 = 0, $$1724$$not = 0, $$1724$not = 0, $$1725 = 0, $$1725$ = 0, $$1728 = 0, $$in1$i = 0, $$in1$i114 = 0, $$in1$i126 = 0, $$in1$i138 = 0, $$in1$i150 = 0, $$in1$i162 = 0, $$in1$i200 = 0;
 var $$in1$i342 = 0, $$in1$i354 = 0, $$in1$i366 = 0, $$in1$i378 = 0, $$in2$i = 0, $$in2$i116 = 0, $$in2$i128 = 0, $$in2$i140 = 0, $$in2$i152 = 0, $$in2$i164 = 0, $$in2$i201 = 0, $$in2$i344 = 0, $$in2$i356 = 0, $$in2$i368 = 0, $$in2$i380 = 0, $$in3$i = 0, $$not = 0, $$not1726 = 0, $$not1739 = 0, $$not1739$demorgan = 0;
 var $$not1740 = 0, $$not1749 = 0, $$not1750 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = Math_fround(0);
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0);
 var $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0;
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0);
 var $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0;
 var $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0);
 var $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $a$pn3$i = 0, $a$pn3$i113 = 0;
 var $a$pn3$i125 = 0, $a$pn3$i137 = 0, $a$pn3$i149 = 0, $a$pn3$i161 = 0, $a$pn3$i341 = 0, $a$pn3$i353 = 0, $a$pn3$i365 = 0, $a$pn3$i377 = 0, $a$pn4$i = 0, $a$pn6$i = 0, $b$a$i103 = 0, $b$a$i111 = 0, $b$a$i123 = 0, $b$a$i135 = 0, $b$a$i147 = 0, $b$a$i159 = 0, $b$a$i198 = 0, $b$a$i339 = 0, $b$a$i351 = 0, $b$a$i363 = 0;
 var $b$a$i375 = 0, $b$a5$i = 0, $b$a5$i115 = 0, $b$a5$i127 = 0, $b$a5$i139 = 0, $b$a5$i151 = 0, $b$a5$i163 = 0, $b$a5$i343 = 0, $b$a5$i355 = 0, $b$a5$i367 = 0, $b$a5$i379 = 0, $b$a7$i = 0, $brmerge = 0, $brmerge1727 = 0, $not$ = 0, $not$1730 = 0, $not$1735 = 0, $not$1743 = 0, $not$1747 = 0, $not$1755 = 0;
 var $not$1756 = 0, $not$1757 = 0, $not$1761 = 0, $not$1762 = 0, $phitmp = 0, $phitmp1758 = 0, $phitmp1758$demorgan = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $0 = sp + 336|0;
 $1 = sp + 320|0;
 $2 = sp + 304|0;
 $3 = sp + 288|0;
 $4 = sp + 272|0;
 $5 = sp + 256|0;
 $6 = sp + 240|0;
 $7 = sp + 224|0;
 $8 = sp + 208|0;
 $9 = sp + 192|0;
 $10 = sp + 176|0;
 $11 = sp + 160|0;
 $12 = sp + 48|0;
 $13 = sp;
 $14 = sp + 16|0;
 $15 = sp + 32|0;
 $16 = sp + 64|0;
 $17 = sp + 80|0;
 $18 = sp + 96|0;
 $19 = sp + 112|0;
 $20 = sp + 128|0;
 $21 = sp + 144|0;
 HEAP32[$size>>2] = 3;
 $22 = Math_fround(HEAPF32[$b>>2]);
 $23 = (($b) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($b) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(HEAPF32[$a>>2]);
 $28 = (($a) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($a) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($22 - $27);
 $33 = Math_fround($24 - $29);
 $34 = Math_fround($26 - $31);
 $35 = Math_fround(HEAPF32[$c>>2]);
 $36 = (($c) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($c) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($35 - $27);
 $41 = Math_fround($37 - $29);
 $42 = Math_fround($39 - $31);
 $43 = Math_fround($35 - $22);
 $44 = Math_fround($37 - $24);
 $45 = Math_fround($39 - $26);
 $46 = Math_fround($40 * $40);
 $47 = Math_fround($41 * $41);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($42 * $42);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($43 * $43);
 $52 = Math_fround($44 * $44);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($45 * $45);
 $55 = Math_fround($53 + $54);
 $56 = $50 > $55;
 $$$i = $56 ? $55 : $50;
 $57 = !($$$i <= Math_fround(1.1920928955078125E-7));
 if (!($57)) {
  HEAP32[$size>>2] = 2;
  __ZN5physx2Gu21closestPtPointSegmentEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($agg$result,$Q,$A,$B,$size,$closestA,$closestB);
  STACKTOP = sp;return;
 }
 $58 = Math_fround(-$27);
 $59 = Math_fround(-$29);
 $60 = Math_fround(-$31);
 $61 = Math_fround(-$22);
 $62 = Math_fround(-$24);
 $63 = Math_fround(-$26);
 $64 = Math_fround(-$35);
 $65 = Math_fround(-$37);
 $66 = Math_fround(-$39);
 $67 = Math_fround($32 * $58);
 $68 = Math_fround($33 * $59);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround($34 * $60);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($40 * $58);
 $73 = Math_fround($41 * $59);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($42 * $60);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($32 * $61);
 $78 = Math_fround($33 * $62);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($34 * $63);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($40 * $61);
 $83 = Math_fround($41 * $62);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($42 * $63);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($32 * $64);
 $88 = Math_fround($33 * $65);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($34 * $66);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($40 * $64);
 $93 = Math_fround($41 * $65);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($42 * $66);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($86 - $81);
 $98 = Math_fround($91 - $96);
 $99 = !($71 <= Math_fround(0.0));
 $100 = $76 <= Math_fround(0.0);
 $101 = !($81 >= Math_fround(0.0));
 $102 = $81 >= $86;
 $103 = $96 >= $91;
 $104 = $100 << 31 >> 31;
 $105 = $99 ? 0 : $104;
 $not$1761 = $99 ^ 1;
 $106 = $100 & $not$1761;
 if ($101) {
  $111 = 1;$113 = 0;
 } else {
  $phitmp = $102 ^ 1;
  $111 = $phitmp;$113 = $102;
 }
 $not$ = $96 >= Math_fround(0.0);
 $107 = $103 & $not$;
 $108 = ($105|0)==(0);
 $109 = ($105|0)==(0);
 $110 = ($105|0)==(0);
 $$not1739$demorgan = $103 & $not$;
 $$not1739 = $$not1739$demorgan ^ 1;
 $$$not = $111 & $$not1739;
 $$$$not = $108 & $$$not;
 $$not1740 = $111 & $$not1739;
 $$not = $109 & $$not1740;
 $brmerge = $$$$not | $$not;
 if (!($brmerge)) {
  $not$1730 = $111 ^ 1;
  $112 = $107 | $113;
  $114 = $112 | $106;
  $$1722 = $107 | $not$1730;
  $not$1735 = $110 ^ 1;
  $$1722$ = $$1722 | $not$1735;
  $$1723 = $$1722$ & $114;
  if ($$1723) {
   ;HEAP32[$3+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$A+12>>2]|0;
   $115 = (($A) + 16|0);
   ;HEAP32[$1+0>>2]=HEAP32[$115+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$115+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$115+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$115+12>>2]|0;
   $116 = (($A) + 32|0);
   ;HEAP32[$0+0>>2]=HEAP32[$116+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$116+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$116+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$116+12>>2]|0;
   $b$a$i375 = $111 ? $0 : $1;
   $117 = Math_fround(HEAPF32[$b$a$i375>>2]);
   $a$pn3$i377 = $111 ? $0 : $1;
   $$in1$i378 = (($a$pn3$i377) + 4|0);
   $118 = Math_fround(HEAPF32[$$in1$i378>>2]);
   $b$a5$i379 = $111 ? $0 : $1;
   $$in2$i380 = (($b$a5$i379) + 8|0);
   $119 = Math_fround(HEAPF32[$$in2$i380>>2]);
   HEAPF32[$2>>2] = $117;
   $120 = (($2) + 4|0);
   HEAPF32[$120>>2] = $118;
   $121 = (($2) + 8|0);
   HEAPF32[$121>>2] = $119;
   $122 = (($2) + 12|0);
   HEAPF32[$122>>2] = Math_fround(0.0);
   $b$a$i363 = $108 ? $2 : $3;
   $123 = Math_fround(HEAPF32[$b$a$i363>>2]);
   $a$pn3$i365 = $109 ? $2 : $3;
   $$in1$i366 = (($a$pn3$i365) + 4|0);
   $124 = Math_fround(HEAPF32[$$in1$i366>>2]);
   $b$a5$i367 = $110 ? $2 : $3;
   $$in2$i368 = (($b$a5$i367) + 8|0);
   $125 = Math_fround(HEAPF32[$$in2$i368>>2]);
   ;HEAP32[$7+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$B+12>>2]|0;
   $126 = (($B) + 16|0);
   ;HEAP32[$5+0>>2]=HEAP32[$126+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$126+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$126+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$126+12>>2]|0;
   $127 = (($B) + 32|0);
   ;HEAP32[$4+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$127+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$127+12>>2]|0;
   $b$a$i351 = $111 ? $4 : $5;
   $128 = Math_fround(HEAPF32[$b$a$i351>>2]);
   $a$pn3$i353 = $111 ? $4 : $5;
   $$in1$i354 = (($a$pn3$i353) + 4|0);
   $129 = Math_fround(HEAPF32[$$in1$i354>>2]);
   $b$a5$i355 = $111 ? $4 : $5;
   $$in2$i356 = (($b$a5$i355) + 8|0);
   $130 = Math_fround(HEAPF32[$$in2$i356>>2]);
   HEAPF32[$6>>2] = $128;
   $131 = (($6) + 4|0);
   HEAPF32[$131>>2] = $129;
   $132 = (($6) + 8|0);
   HEAPF32[$132>>2] = $130;
   $133 = (($6) + 12|0);
   HEAPF32[$133>>2] = Math_fround(0.0);
   $b$a$i339 = $108 ? $6 : $7;
   $134 = Math_fround(HEAPF32[$b$a$i339>>2]);
   $a$pn3$i341 = $109 ? $6 : $7;
   $$in1$i342 = (($a$pn3$i341) + 4|0);
   $135 = Math_fround(HEAPF32[$$in1$i342>>2]);
   $b$a5$i343 = $110 ? $6 : $7;
   $$in2$i344 = (($b$a5$i343) + 8|0);
   $136 = Math_fround(HEAPF32[$$in2$i344>>2]);
   HEAPF32[$closestA>>2] = $123;
   $137 = (($closestA) + 4|0);
   HEAPF32[$137>>2] = $124;
   $138 = (($closestA) + 8|0);
   HEAPF32[$138>>2] = $125;
   $139 = (($closestA) + 12|0);
   HEAPF32[$139>>2] = Math_fround(0.0);
   HEAPF32[$closestB>>2] = $134;
   $140 = (($closestB) + 4|0);
   HEAPF32[$140>>2] = $135;
   $141 = (($closestB) + 8|0);
   HEAPF32[$141>>2] = $136;
   $142 = (($closestB) + 12|0);
   HEAPF32[$142>>2] = Math_fround(0.0);
   $143 = Math_fround($123 - $134);
   $144 = Math_fround($124 - $135);
   $145 = Math_fround($125 - $136);
   HEAPF32[$agg$result>>2] = $143;
   $146 = (($agg$result) + 4|0);
   HEAPF32[$146>>2] = $144;
   $147 = (($agg$result) + 8|0);
   HEAPF32[$147>>2] = $145;
   $148 = (($agg$result) + 12|0);
   HEAPF32[$148>>2] = Math_fround(0.0);
   STACKTOP = sp;return;
  }
 }
 $149 = Math_fround($81 * $96);
 $150 = Math_fround($86 * $91);
 $151 = Math_fround($149 - $150);
 $152 = Math_fround($76 * $91);
 $153 = Math_fround($71 * $96);
 $154 = Math_fround($152 - $153);
 $155 = Math_fround($71 * $86);
 $156 = Math_fround($76 * $81);
 $157 = Math_fround($155 - $156);
 $158 = !($157 <= Math_fround(0.0));
 $159 = !($71 >= Math_fround(0.0));
 $160 = !($151 <= Math_fround(0.0));
 $161 = $91 >= $96;
 $162 = $96 <= Math_fround(0.0);
 if ($159) {
  $165 = 0;
 } else {
  $163 = $81 <= Math_fround(0.0);
  $165 = $163;
 }
 $164 = $165 << 31 >> 31;
 $166 = $158 ? 0 : $164;
 $not$1762 = $158 ^ 1;
 $167 = $165 & $not$1762;
 $not$1755 = $86 >= $81;
 if ($160) {
  $204 = 1;$206 = 0;
 } else {
  $168 = $161 & $not$1755;
  $phitmp1758$demorgan = $161 & $not$1755;
  $phitmp1758 = $phitmp1758$demorgan ^ 1;
  $204 = $phitmp1758;$206 = $168;
 }
 $not$1756 = $76 >= Math_fround(0.0);
 $169 = $162 & $not$1756;
 $not$1757 = $154 <= Math_fround(0.0);
 $170 = $169 & $not$1757;
 $171 = Math_fround($71 - $81);
 $172 = Math_fround($97 + $98);
 $173 = Math_fround($76 - $96);
 $174 = Math_fround($157 + $154);
 $175 = Math_fround($151 + $174);
 $176 = Math_fround(-$171);
 $177 = Math_fround(-$172);
 $178 = Math_fround(-$173);
 $179 = Math_fround(-$175);
 $180 = $171 > $176;
 $$$i$i = $180 ? $171 : $176;
 $181 = $172 > $177;
 $182 = $181 ? $172 : $177;
 $183 = $173 > $178;
 $$1$i$i = $183 ? $173 : $178;
 $184 = $175 > $179;
 $185 = $184 ? $175 : $179;
 $186 = $$$i$i > Math_fround(1.1920928955078125E-7);
 $187 = $182 > Math_fround(1.1920928955078125E-7);
 $188 = $$1$i$i > Math_fround(1.1920928955078125E-7);
 $189 = $185 > Math_fround(1.1920928955078125E-7);
 $190 = Math_fround(Math_fround(1.0) / $171);
 $191 = Math_fround(Math_fround(1.0) / $172);
 $192 = Math_fround(Math_fround(1.0) / $173);
 $193 = Math_fround(Math_fround(1.0) / $175);
 HEAPF32[$9>>2] = $190;
 $194 = (($9) + 4|0);
 HEAPF32[$194>>2] = $191;
 $195 = (($9) + 8|0);
 HEAPF32[$195>>2] = $192;
 $196 = (($9) + 12|0);
 HEAPF32[$196>>2] = $193;
 $b$a$i198 = $186 ? $9 : $8;
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
 $197 = Math_fround(HEAPF32[$b$a$i198>>2]);
 $a$pn4$i = $187 ? $9 : $8;
 $$in1$i200 = (($a$pn4$i) + 4|0);
 $198 = Math_fround(HEAPF32[$$in1$i200>>2]);
 $b$a7$i = $188 ? $9 : $8;
 $$in2$i201 = (($b$a7$i) + 8|0);
 $199 = Math_fround(HEAPF32[$$in2$i201>>2]);
 $a$pn6$i = $189 ? $9 : $8;
 $$in3$i = (($a$pn6$i) + 12|0);
 $200 = Math_fround(HEAPF32[$$in3$i>>2]);
 $201 = ($166|0)==(0);
 $202 = ($166|0)==(0);
 $203 = ($166|0)==(0);
 $$not1749 = $170 ^ 1;
 $$1724$not = $204 & $$not1749;
 $$1724$$not = $201 & $$1724$not;
 $$not1750 = $204 & $$not1749;
 $$not1726 = $202 & $$not1750;
 $brmerge1727 = $$1724$$not | $$not1726;
 if (!($brmerge1727)) {
  $not$1743 = $204 ^ 1;
  $205 = $170 | $206;
  $207 = $205 | $167;
  $$1725 = $170 | $not$1743;
  $not$1747 = $203 ^ 1;
  $$1725$ = $$1725 | $not$1747;
  $$1728 = $$1725$ & $207;
  if ($$1728) {
   $208 = Math_fround($71 * $197);
   $209 = Math_fround($97 * $198);
   $210 = Math_fround($76 * $199);
   $211 = (($A) + 16|0);
   ;HEAP32[$11+0>>2]=HEAP32[$211+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$211+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$211+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$211+12>>2]|0;
   $212 = (($A) + 32|0);
   ;HEAP32[$10+0>>2]=HEAP32[$212+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$212+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$212+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$212+12>>2]|0;
   $b$a$i159 = $201 ? $10 : $11;
   $213 = Math_fround(HEAPF32[$b$a$i159>>2]);
   $a$pn3$i161 = $202 ? $10 : $11;
   $$in1$i162 = (($a$pn3$i161) + 4|0);
   $214 = Math_fround(HEAPF32[$$in1$i162>>2]);
   $b$a5$i163 = $203 ? $10 : $11;
   $$in2$i164 = (($b$a5$i163) + 8|0);
   $215 = Math_fround(HEAPF32[$$in2$i164>>2]);
   $216 = (($B) + 16|0);
   ;HEAP32[$13+0>>2]=HEAP32[$216+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$216+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$216+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$216+12>>2]|0;
   $217 = (($B) + 32|0);
   ;HEAP32[$12+0>>2]=HEAP32[$217+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$217+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$217+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$217+12>>2]|0;
   $b$a$i147 = $201 ? $12 : $13;
   $218 = Math_fround(HEAPF32[$b$a$i147>>2]);
   $a$pn3$i149 = $202 ? $12 : $13;
   $$in1$i150 = (($a$pn3$i149) + 4|0);
   $219 = Math_fround(HEAPF32[$$in1$i150>>2]);
   $b$a5$i151 = $203 ? $12 : $13;
   $$in2$i152 = (($b$a5$i151) + 8|0);
   $220 = Math_fround(HEAPF32[$$in2$i152>>2]);
   ;HEAP32[$17+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$A+12>>2]|0;
   ;HEAP32[$15+0>>2]=HEAP32[$211+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$211+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$211+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$211+12>>2]|0;
   ;HEAP32[$14+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$A+12>>2]|0;
   $b$a$i135 = $204 ? $14 : $15;
   $221 = Math_fround(HEAPF32[$b$a$i135>>2]);
   $a$pn3$i137 = $204 ? $14 : $15;
   $$in1$i138 = (($a$pn3$i137) + 4|0);
   $222 = Math_fround(HEAPF32[$$in1$i138>>2]);
   $b$a5$i139 = $204 ? $14 : $15;
   $$in2$i140 = (($b$a5$i139) + 8|0);
   $223 = Math_fround(HEAPF32[$$in2$i140>>2]);
   HEAPF32[$16>>2] = $221;
   $224 = (($16) + 4|0);
   HEAPF32[$224>>2] = $222;
   $225 = (($16) + 8|0);
   HEAPF32[$225>>2] = $223;
   $226 = (($16) + 12|0);
   HEAPF32[$226>>2] = Math_fround(0.0);
   $b$a$i123 = $201 ? $16 : $17;
   $227 = Math_fround(HEAPF32[$b$a$i123>>2]);
   $a$pn3$i125 = $202 ? $16 : $17;
   $$in1$i126 = (($a$pn3$i125) + 4|0);
   $228 = Math_fround(HEAPF32[$$in1$i126>>2]);
   $b$a5$i127 = $203 ? $16 : $17;
   $$in2$i128 = (($b$a5$i127) + 8|0);
   $229 = Math_fround(HEAPF32[$$in2$i128>>2]);
   ;HEAP32[$21+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$B+12>>2]|0;
   ;HEAP32[$19+0>>2]=HEAP32[$216+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$216+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$216+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$216+12>>2]|0;
   ;HEAP32[$18+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$B+12>>2]|0;
   $b$a$i111 = $204 ? $18 : $19;
   $230 = Math_fround(HEAPF32[$b$a$i111>>2]);
   $a$pn3$i113 = $204 ? $18 : $19;
   $$in1$i114 = (($a$pn3$i113) + 4|0);
   $231 = Math_fround(HEAPF32[$$in1$i114>>2]);
   $b$a5$i115 = $204 ? $18 : $19;
   $$in2$i116 = (($b$a5$i115) + 8|0);
   $232 = Math_fround(HEAPF32[$$in2$i116>>2]);
   HEAPF32[$20>>2] = $230;
   $233 = (($20) + 4|0);
   HEAPF32[$233>>2] = $231;
   $234 = (($20) + 8|0);
   HEAPF32[$234>>2] = $232;
   $235 = (($20) + 12|0);
   HEAPF32[$235>>2] = Math_fround(0.0);
   $b$a$i103 = $201 ? $20 : $21;
   $236 = Math_fround(HEAPF32[$b$a$i103>>2]);
   $a$pn3$i = $202 ? $20 : $21;
   $$in1$i = (($a$pn3$i) + 4|0);
   $237 = Math_fround(HEAPF32[$$in1$i>>2]);
   $b$a5$i = $203 ? $20 : $21;
   $$in2$i = (($b$a5$i) + 8|0);
   $238 = Math_fround(HEAPF32[$$in2$i>>2]);
   $239 = Math_fround($213 - $227);
   $240 = Math_fround($214 - $228);
   $241 = Math_fround($215 - $229);
   $242 = Math_fround($218 - $236);
   $243 = Math_fround($219 - $237);
   $244 = Math_fround($220 - $238);
   $245 = $204 ? $210 : $209;
   $246 = $201 ? $245 : $208;
   $247 = Math_fround($246 * $239);
   $248 = Math_fround($246 * $240);
   $249 = Math_fround($246 * $241);
   $250 = Math_fround($227 + $247);
   $251 = Math_fround($228 + $248);
   $252 = Math_fround($229 + $249);
   $253 = Math_fround($246 * $242);
   $254 = Math_fround($246 * $243);
   $255 = Math_fround($246 * $244);
   $256 = Math_fround($236 + $253);
   $257 = Math_fround($237 + $254);
   $258 = Math_fround($238 + $255);
   HEAPF32[$closestA>>2] = $250;
   $259 = (($closestA) + 4|0);
   HEAPF32[$259>>2] = $251;
   $260 = (($closestA) + 8|0);
   HEAPF32[$260>>2] = $252;
   $261 = (($closestA) + 12|0);
   HEAPF32[$261>>2] = Math_fround(0.0);
   HEAPF32[$closestB>>2] = $256;
   $262 = (($closestB) + 4|0);
   HEAPF32[$262>>2] = $257;
   $263 = (($closestB) + 8|0);
   HEAPF32[$263>>2] = $258;
   $264 = (($closestB) + 12|0);
   HEAPF32[$264>>2] = Math_fround(0.0);
   $265 = Math_fround($250 - $256);
   $266 = Math_fround($251 - $257);
   $267 = Math_fround($252 - $258);
   HEAPF32[$agg$result>>2] = $265;
   $268 = (($agg$result) + 4|0);
   HEAPF32[$268>>2] = $266;
   $269 = (($agg$result) + 8|0);
   HEAPF32[$269>>2] = $267;
   $270 = (($agg$result) + 12|0);
   HEAPF32[$270>>2] = Math_fround(0.0);
   STACKTOP = sp;return;
  }
 }
 $271 = (($A) + 16|0);
 $272 = Math_fround(HEAPF32[$271>>2]);
 $273 = (($A) + 20|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 $275 = (($A) + 24|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 $277 = Math_fround(HEAPF32[$A>>2]);
 $278 = (($A) + 4|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = (($A) + 8|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = Math_fround($272 - $277);
 $283 = Math_fround($274 - $279);
 $284 = Math_fround($276 - $281);
 $285 = (($A) + 32|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = (($A) + 36|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $289 = (($A) + 40|0);
 $290 = Math_fround(HEAPF32[$289>>2]);
 $291 = Math_fround($286 - $277);
 $292 = Math_fround($288 - $279);
 $293 = Math_fround($290 - $281);
 $294 = (($B) + 16|0);
 $295 = Math_fround(HEAPF32[$294>>2]);
 $296 = (($B) + 20|0);
 $297 = Math_fround(HEAPF32[$296>>2]);
 $298 = (($B) + 24|0);
 $299 = Math_fround(HEAPF32[$298>>2]);
 $300 = Math_fround(HEAPF32[$B>>2]);
 $301 = (($B) + 4|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = (($B) + 8|0);
 $304 = Math_fround(HEAPF32[$303>>2]);
 $305 = Math_fround($295 - $300);
 $306 = Math_fround($297 - $302);
 $307 = Math_fround($299 - $304);
 $308 = (($B) + 32|0);
 $309 = Math_fround(HEAPF32[$308>>2]);
 $310 = (($B) + 36|0);
 $311 = Math_fround(HEAPF32[$310>>2]);
 $312 = (($B) + 40|0);
 $313 = Math_fround(HEAPF32[$312>>2]);
 $314 = Math_fround($309 - $300);
 $315 = Math_fround($311 - $302);
 $316 = Math_fround($313 - $304);
 $317 = Math_fround($154 * $200);
 $318 = Math_fround($157 * $200);
 $319 = Math_fround($318 * $291);
 $320 = Math_fround($318 * $292);
 $321 = Math_fround($318 * $293);
 $322 = Math_fround($318 * $314);
 $323 = Math_fround($318 * $315);
 $324 = Math_fround($318 * $316);
 $325 = Math_fround($317 * $282);
 $326 = Math_fround($317 * $283);
 $327 = Math_fround($317 * $284);
 $328 = Math_fround($325 + $319);
 $329 = Math_fround($326 + $320);
 $330 = Math_fround($327 + $321);
 $331 = Math_fround($328 + $277);
 $332 = Math_fround($329 + $279);
 $333 = Math_fround($330 + $281);
 $334 = Math_fround($317 * $305);
 $335 = Math_fround($317 * $306);
 $336 = Math_fround($317 * $307);
 $337 = Math_fround($334 + $322);
 $338 = Math_fround($335 + $323);
 $339 = Math_fround($336 + $324);
 $340 = Math_fround($337 + $300);
 $341 = Math_fround($338 + $302);
 $342 = Math_fround($339 + $304);
 HEAPF32[$closestA>>2] = $331;
 $343 = (($closestA) + 4|0);
 HEAPF32[$343>>2] = $332;
 $344 = (($closestA) + 8|0);
 HEAPF32[$344>>2] = $333;
 $345 = (($closestA) + 12|0);
 HEAPF32[$345>>2] = Math_fround(0.0);
 HEAPF32[$closestB>>2] = $340;
 $346 = (($closestB) + 4|0);
 HEAPF32[$346>>2] = $341;
 $347 = (($closestB) + 8|0);
 HEAPF32[$347>>2] = $342;
 $348 = (($closestB) + 12|0);
 HEAPF32[$348>>2] = Math_fround(0.0);
 $349 = Math_fround($331 - $340);
 $350 = Math_fround($332 - $341);
 $351 = Math_fround($333 - $342);
 HEAPF32[$agg$result>>2] = $349;
 $352 = (($agg$result) + 4|0);
 HEAPF32[$352>>2] = $350;
 $353 = (($agg$result) + 8|0);
 HEAPF32[$353>>2] = $351;
 $354 = (($agg$result) + 12|0);
 HEAPF32[$354>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu21closestPtPointSegmentEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($agg$result,$Q,$A,$B,$size,$closestA,$closestB) {
 $agg$result = $agg$result|0;
 $Q = $Q|0;
 $A = $A|0;
 $B = $B|0;
 $size = $size|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 var $$$i$i = Math_fround(0), $$$i8$i = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0;
 var $8 = Math_fround(0), $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$Q>>2]);
 $1 = (($Q) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($Q) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($Q) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($Q) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($Q) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($6 - $0);
 $12 = Math_fround($8 - $2);
 $13 = Math_fround($10 - $4);
 $14 = Math_fround($11 * $11);
 $15 = Math_fround($12 * $12);
 $16 = Math_fround($14 + $15);
 $17 = Math_fround($13 * $13);
 $18 = Math_fround($16 + $17);
 $19 = Math_fround($0 * $11);
 $20 = Math_fround($2 * $12);
 $21 = Math_fround(-$20);
 $22 = Math_fround($21 - $19);
 $23 = Math_fround($4 * $13);
 $24 = Math_fround($22 - $23);
 $25 = $18 == Math_fround(0.0);
 $26 = Math_fround($24 / $18);
 $27 = $26 > Math_fround(1.0);
 $$$i$i = $27 ? Math_fround(1.0) : $26;
 $28 = $$$i$i > Math_fround(0.0);
 $$$i8$i = $28 ? $$$i$i : Math_fround(0.0);
 $29 = $25 ? Math_fround(0.0) : $$$i8$i;
 if ($25) {
  HEAP32[$size>>2] = 1;
  ;HEAP32[$closestA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$A+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$B+12>>2]|0;
  ;HEAP32[$agg$result+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$Q+12>>2]|0;
  STACKTOP = sp;return;
 } else {
  $30 = (($B) + 8|0);
  $31 = (($B) + 4|0);
  $32 = (($A) + 8|0);
  $33 = (($A) + 4|0);
  $34 = (($B) + 24|0);
  $35 = (($B) + 20|0);
  $36 = (($B) + 16|0);
  $37 = (($A) + 24|0);
  $38 = (($A) + 20|0);
  $39 = (($A) + 16|0);
  $40 = Math_fround(HEAPF32[$30>>2]);
  $41 = Math_fround(HEAPF32[$31>>2]);
  $42 = Math_fround(HEAPF32[$B>>2]);
  $43 = Math_fround(HEAPF32[$34>>2]);
  $44 = Math_fround(HEAPF32[$35>>2]);
  $45 = Math_fround(HEAPF32[$36>>2]);
  $46 = Math_fround(HEAPF32[$32>>2]);
  $47 = Math_fround(HEAPF32[$33>>2]);
  $48 = Math_fround(HEAPF32[$A>>2]);
  $49 = Math_fround(HEAPF32[$37>>2]);
  $50 = Math_fround(HEAPF32[$38>>2]);
  $51 = Math_fround(HEAPF32[$39>>2]);
  $52 = Math_fround($43 - $40);
  $53 = Math_fround($44 - $41);
  $54 = Math_fround($45 - $42);
  $55 = Math_fround($49 - $46);
  $56 = Math_fround($50 - $47);
  $57 = Math_fround($51 - $48);
  $58 = Math_fround($29 * $57);
  $59 = Math_fround($29 * $56);
  $60 = Math_fround($29 * $55);
  $61 = Math_fround($48 + $58);
  $62 = Math_fround($59 + $47);
  $63 = Math_fround($60 + $46);
  $64 = Math_fround($29 * $54);
  $65 = Math_fround($29 * $53);
  $66 = Math_fround($29 * $52);
  $67 = Math_fround($64 + $42);
  $68 = Math_fround($65 + $41);
  $69 = Math_fround($66 + $40);
  HEAPF32[$closestA>>2] = $61;
  $70 = (($closestA) + 4|0);
  HEAPF32[$70>>2] = $62;
  $71 = (($closestA) + 8|0);
  HEAPF32[$71>>2] = $63;
  $72 = (($closestA) + 12|0);
  HEAPF32[$72>>2] = Math_fround(0.0);
  HEAPF32[$closestB>>2] = $67;
  $73 = (($closestB) + 4|0);
  HEAPF32[$73>>2] = $68;
  $74 = (($closestB) + 8|0);
  HEAPF32[$74>>2] = $69;
  $75 = (($closestB) + 12|0);
  HEAPF32[$75>>2] = Math_fround(0.0);
  $76 = Math_fround($61 - $67);
  $77 = Math_fround($62 - $68);
  $78 = Math_fround($63 - $69);
  HEAPF32[$agg$result>>2] = $76;
  $79 = (($agg$result) + 4|0);
  HEAPF32[$79>>2] = $77;
  $80 = (($agg$result) + 8|0);
  HEAPF32[$80>>2] = $78;
  $81 = (($agg$result) + 12|0);
  HEAPF32[$81>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu19EPALocalPenetrationERKNS0_8CapsuleVERKNS0_4BoxVERNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEPhSD_Rhb($a,$b,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $supportMap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $supportMap = sp;
 $0 = (($supportMap) + 4|0);
 HEAP8[$0>>0] = 0;
 HEAP32[$supportMap>>2] = ((551024 + 8|0));
 $1 = (($supportMap) + 8|0);
 HEAP32[$1>>2] = $a;
 $2 = (($supportMap) + 12|0);
 HEAP32[$2>>2] = $b;
 $3 = HEAP8[$_size>>0]|0;
 $4 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$3,$contactA,$contactB,$normal,$penetrationDepth,$takeCoreShape)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu22EPARelativePenetrationERKNS0_4BoxVES3_RKNS_6shdfnd3aos15PsMatTransformVERNS5_5Vec3VESA_SA_RNS5_6FloatVEPhSD_Rhb($a,$b,$aToB,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $supportMap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $supportMap = sp;
 $0 = (($supportMap) + 4|0);
 HEAP8[$0>>0] = 0;
 HEAP32[$supportMap>>2] = ((550896 + 8|0));
 $1 = (($supportMap) + 8|0);
 HEAP32[$1>>2] = $a;
 $2 = (($supportMap) + 12|0);
 HEAP32[$2>>2] = $b;
 $3 = (($supportMap) + 16|0);
 HEAP32[$3>>2] = $aToB;
 $4 = HEAP8[$_size>>0]|0;
 $5 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$4,$contactA,$contactB,$normal,$penetrationDepth,$takeCoreShape)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_ED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_ED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_ED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_E18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES7_S7_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 200|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + (($indexA*12)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($5) + (($indexA*12)|0)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($5) + (($indexA*12)|0)|0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($3) + 96|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($7 * $13);
 $15 = (($3) + 112|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($9 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($3) + 128|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($11 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($3) + 100|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($7 * $24);
 $26 = (($3) + 116|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($9 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($3) + 132|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($11 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($3) + 104|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($7 * $35);
 $37 = (($3) + 120|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($9 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($3) + 136|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($11 * $42);
 $44 = Math_fround($40 + $43);
 $45 = (($1) + 48|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($1) + 52|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($1) + 56|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround(HEAPF32[$1>>2]);
 $52 = Math_fround($22 * $51);
 $53 = (($1) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($33 * $54);
 $56 = Math_fround($52 + $55);
 $57 = (($1) + 32|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($44 * $58);
 $60 = Math_fround($56 + $59);
 $61 = (($1) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($22 * $62);
 $64 = (($1) + 20|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($33 * $65);
 $67 = Math_fround($63 + $66);
 $68 = (($1) + 36|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($44 * $69);
 $71 = Math_fround($67 + $70);
 $72 = (($1) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($22 * $73);
 $75 = (($1) + 24|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($33 * $76);
 $78 = Math_fround($74 + $77);
 $79 = (($1) + 40|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($44 * $80);
 $82 = Math_fround($78 + $81);
 $83 = Math_fround($46 + $60);
 $84 = Math_fround($48 + $71);
 $85 = Math_fround($50 + $82);
 $86 = (($this) + 12|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($87) + 200|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + (($indexB*12)|0)|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = ((($89) + (($indexB*12)|0)|0) + 4|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = ((($89) + (($indexB*12)|0)|0) + 8|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($87) + 96|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($91 * $97);
 $99 = (($87) + 112|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($93 * $100);
 $102 = Math_fround($98 + $101);
 $103 = (($87) + 128|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($95 * $104);
 $106 = Math_fround($102 + $105);
 $107 = (($87) + 100|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($91 * $108);
 $110 = (($87) + 116|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($93 * $111);
 $113 = Math_fround($109 + $112);
 $114 = (($87) + 132|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($95 * $115);
 $117 = Math_fround($113 + $116);
 $118 = (($87) + 104|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($91 * $119);
 $121 = (($87) + 120|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround($93 * $122);
 $124 = Math_fround($120 + $123);
 $125 = (($87) + 136|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($95 * $126);
 $128 = Math_fround($124 + $127);
 HEAPF32[$supportA>>2] = $83;
 $129 = (($supportA) + 4|0);
 HEAPF32[$129>>2] = $84;
 $130 = (($supportA) + 8|0);
 HEAPF32[$130>>2] = $85;
 $131 = (($supportA) + 12|0);
 HEAPF32[$131>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $106;
 $132 = (($supportB) + 4|0);
 HEAPF32[$132>>2] = $117;
 $133 = (($supportB) + 8|0);
 HEAPF32[$133>>2] = $128;
 $134 = (($supportB) + 12|0);
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = Math_fround($83 - $106);
 $136 = Math_fround($84 - $117);
 $137 = Math_fround($85 - $128);
 HEAPF32[$support>>2] = $135;
 $138 = (($support) + 4|0);
 HEAPF32[$138>>2] = $136;
 $139 = (($support) + 8|0);
 HEAPF32[$139>>2] = $137;
 $140 = (($support) + 12|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_E9doSupportERKNS_6shdfnd3aos5Vec3VERS6_S9_S9_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0;
 var $99 = 0, $_dir$i = 0, $_sb = 0, $maxPoint$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_dir$i = sp + 32|0;
 $maxPoint$i = sp;
 $_sb = sp + 16|0;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$dir>>2]);
 $3 = (($dir) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($dir) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$2);
 $8 = Math_fround(-$4);
 $9 = Math_fround(-$6);
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $7);
 $14 = (($11) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $8);
 $17 = Math_fround($13 + $16);
 $18 = (($11) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $9);
 $21 = Math_fround($17 + $20);
 $22 = (($11) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $7);
 $25 = (($11) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $8);
 $28 = Math_fround($24 + $27);
 $29 = (($11) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $9);
 $32 = Math_fround($28 + $31);
 $33 = (($11) + 32|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $7);
 $36 = (($11) + 36|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * $8);
 $39 = Math_fround($35 + $38);
 $40 = (($11) + 40|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 * $9);
 $43 = Math_fround($39 + $42);
 HEAPF32[$_dir$i>>2] = $21;
 $44 = (($_dir$i) + 4|0);
 HEAPF32[$44>>2] = $32;
 $45 = (($_dir$i) + 8|0);
 HEAPF32[$45>>2] = $43;
 $46 = (($_dir$i) + 12|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($maxPoint$i,$1,$_dir$i);
 $47 = (($11) + 48|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($11) + 52|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($11) + 56|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(HEAPF32[$maxPoint$i>>2]);
 $54 = (($maxPoint$i) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($maxPoint$i) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround(HEAPF32[$11>>2]);
 $59 = Math_fround($53 * $58);
 $60 = Math_fround(HEAPF32[$22>>2]);
 $61 = Math_fround($55 * $60);
 $62 = Math_fround($59 + $61);
 $63 = Math_fround(HEAPF32[$33>>2]);
 $64 = Math_fround($57 * $63);
 $65 = Math_fround($62 + $64);
 $66 = Math_fround(HEAPF32[$14>>2]);
 $67 = Math_fround($53 * $66);
 $68 = Math_fround(HEAPF32[$25>>2]);
 $69 = Math_fround($55 * $68);
 $70 = Math_fround($67 + $69);
 $71 = Math_fround(HEAPF32[$36>>2]);
 $72 = Math_fround($57 * $71);
 $73 = Math_fround($70 + $72);
 $74 = Math_fround(HEAPF32[$18>>2]);
 $75 = Math_fround($53 * $74);
 $76 = Math_fround(HEAPF32[$29>>2]);
 $77 = Math_fround($55 * $76);
 $78 = Math_fround($75 + $77);
 $79 = Math_fround(HEAPF32[$40>>2]);
 $80 = Math_fround($57 * $79);
 $81 = Math_fround($78 + $80);
 $82 = Math_fround($48 + $65);
 $83 = Math_fround($50 + $73);
 $84 = Math_fround($52 + $81);
 $85 = (($this) + 12|0);
 $86 = HEAP32[$85>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($_sb,$86,$dir);
 HEAPF32[$supportA>>2] = $82;
 $87 = (($supportA) + 4|0);
 HEAPF32[$87>>2] = $83;
 $88 = (($supportA) + 8|0);
 HEAPF32[$88>>2] = $84;
 $89 = (($supportA) + 12|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 ;HEAP32[$supportB+0>>2]=HEAP32[$_sb+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$_sb+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$_sb+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$_sb+12>>2]|0;
 $90 = Math_fround(HEAPF32[$_sb>>2]);
 $91 = (($_sb) + 4|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($_sb) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($82 - $90);
 $96 = Math_fround($83 - $92);
 $97 = Math_fround($84 - $94);
 HEAPF32[$support>>2] = $95;
 $98 = (($support) + 4|0);
 HEAPF32[$98>>2] = $96;
 $99 = (($support) + 8|0);
 HEAPF32[$99>>2] = $97;
 $100 = (($support) + 12|0);
 HEAPF32[$100>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_E6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0);
 var $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (549664 + ($indexA<<4)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((549664 + ($indexA<<4)|0) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((549664 + ($indexA<<4)|0) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($5) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$12+12>>2]|0;
 $13 = (($5) + 144|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($5) + 148|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($5) + 152|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(-$14);
 $20 = Math_fround(-$16);
 $21 = Math_fround(-$18);
 HEAPF32[$0>>2] = $19;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $21;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = ($7|0)==(0);
 $b$a$i$i = $25 ? $0 : $1;
 $26 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $27 = ($9|0)==(0);
 $a$pn3$i$i = $27 ? $0 : $1;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $28 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $29 = ($11|0)==(0);
 $b$a5$i$i = $29 ? $0 : $1;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $30 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $31 = (($3) + 48|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($3) + 52|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($3) + 56|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$3>>2]);
 $38 = Math_fround($26 * $37);
 $39 = (($3) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($28 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($3) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($30 * $44);
 $46 = Math_fround($42 + $45);
 $47 = (($3) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($26 * $48);
 $50 = (($3) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($28 * $51);
 $53 = Math_fround($49 + $52);
 $54 = (($3) + 36|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($30 * $55);
 $57 = Math_fround($53 + $56);
 $58 = (($3) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($26 * $59);
 $61 = (($3) + 24|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($28 * $62);
 $64 = Math_fround($60 + $63);
 $65 = (($3) + 40|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($30 * $66);
 $68 = Math_fround($64 + $67);
 $69 = Math_fround($32 + $46);
 $70 = Math_fround($34 + $57);
 $71 = Math_fround($36 + $68);
 $72 = (($this) + 12|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73) + 200|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($75) + (($indexB*12)|0)|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = ((($75) + (($indexB*12)|0)|0) + 4|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = ((($75) + (($indexB*12)|0)|0) + 8|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($73) + 96|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($77 * $83);
 $85 = (($73) + 112|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($79 * $86);
 $88 = Math_fround($84 + $87);
 $89 = (($73) + 128|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($81 * $90);
 $92 = Math_fround($88 + $91);
 $93 = (($73) + 100|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($77 * $94);
 $96 = (($73) + 116|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($79 * $97);
 $99 = Math_fround($95 + $98);
 $100 = (($73) + 132|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($81 * $101);
 $103 = Math_fround($99 + $102);
 $104 = (($73) + 104|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($77 * $105);
 $107 = (($73) + 120|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($79 * $108);
 $110 = Math_fround($106 + $109);
 $111 = (($73) + 136|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($81 * $112);
 $114 = Math_fround($110 + $113);
 HEAPF32[$supportA>>2] = $69;
 $115 = (($supportA) + 4|0);
 HEAPF32[$115>>2] = $70;
 $116 = (($supportA) + 8|0);
 HEAPF32[$116>>2] = $71;
 $117 = (($supportA) + 12|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $92;
 $118 = (($supportB) + 4|0);
 HEAPF32[$118>>2] = $103;
 $119 = (($supportB) + 8|0);
 HEAPF32[$119>>2] = $114;
 $120 = (($supportB) + 12|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = Math_fround($69 - $92);
 $122 = Math_fround($70 - $103);
 $123 = Math_fround($71 - $114);
 HEAPF32[$support>>2] = $121;
 $124 = (($support) + 4|0);
 HEAPF32[$124>>2] = $122;
 $125 = (($support) + 8|0);
 HEAPF32[$125>>2] = $123;
 $126 = (($support) + 12|0);
 HEAPF32[$126>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i$i = 0, $$in2$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $_sb = 0, $a$pn3$i$i$i = 0, $b$a$i$i$i = 0, $b$a5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $_sb = sp + 16|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$6);
 $11 = Math_fround(-$8);
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $9);
 $16 = (($13) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $10);
 $19 = Math_fround($15 + $18);
 $20 = (($13) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $11);
 $23 = Math_fround($19 + $22);
 $24 = (($13) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $9);
 $27 = (($13) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $10);
 $30 = Math_fround($26 + $29);
 $31 = (($13) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $11);
 $34 = Math_fround($30 + $33);
 $35 = (($13) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * $9);
 $38 = (($13) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $10);
 $41 = Math_fround($37 + $40);
 $42 = (($13) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $11);
 $45 = Math_fround($41 + $44);
 $46 = $23 > Math_fround(0.0);
 $47 = $34 > Math_fround(0.0);
 $48 = $45 > Math_fround(0.0);
 $49 = (($3) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$49+12>>2]|0;
 $50 = (($3) + 144|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($3) + 148|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($3) + 152|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround(-$51);
 $57 = Math_fround(-$53);
 $58 = Math_fround(-$55);
 HEAPF32[$0>>2] = $56;
 $59 = (($0) + 4|0);
 HEAPF32[$59>>2] = $57;
 $60 = (($0) + 8|0);
 HEAPF32[$60>>2] = $58;
 $61 = (($0) + 12|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $b$a$i$i$i = $46 ? $1 : $0;
 $62 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
 $a$pn3$i$i$i = $47 ? $1 : $0;
 $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
 $63 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
 $b$a5$i$i$i = $48 ? $1 : $0;
 $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
 $64 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
 $65 = (($13) + 48|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($13) + 52|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($13) + 56|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($14 * $62);
 $72 = Math_fround($25 * $63);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($36 * $64);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($17 * $62);
 $77 = Math_fround($28 * $63);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($39 * $64);
 $80 = Math_fround($78 + $79);
 $81 = Math_fround($21 * $62);
 $82 = Math_fround($32 * $63);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($43 * $64);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($75 + $66);
 $87 = Math_fround($80 + $68);
 $88 = Math_fround($85 + $70);
 $89 = (($this) + 12|0);
 $90 = HEAP32[$89>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($_sb,$90,$dir);
 HEAPF32[$supportA>>2] = $86;
 $91 = (($supportA) + 4|0);
 HEAPF32[$91>>2] = $87;
 $92 = (($supportA) + 8|0);
 HEAPF32[$92>>2] = $88;
 $93 = (($supportA) + 12|0);
 HEAPF32[$93>>2] = Math_fround(0.0);
 ;HEAP32[$supportB+0>>2]=HEAP32[$_sb+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$_sb+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$_sb+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$_sb+12>>2]|0;
 $94 = Math_fround(HEAPF32[$_sb>>2]);
 $95 = (($_sb) + 4|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($_sb) + 8|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($86 - $94);
 $100 = Math_fround($87 - $96);
 $101 = Math_fround($88 - $98);
 HEAPF32[$support>>2] = $99;
 $102 = (($support) + 4|0);
 HEAPF32[$102>>2] = $100;
 $103 = (($support) + 8|0);
 HEAPF32[$103>>2] = $101;
 $104 = (($support) + 12|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_ED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_E18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES7_S7_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in1$i$i7 = 0, $$in2$i$i = 0, $$in2$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0;
 var $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0);
 var $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $a$pn3$i$i = 0, $a$pn3$i$i6 = 0, $b$a$i$i = 0, $b$a$i$i4 = 0, $b$a5$i$i = 0;
 var $b$a5$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (549664 + ($indexA<<4)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((549664 + ($indexA<<4)|0) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((549664 + ($indexA<<4)|0) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($5) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$12+12>>2]|0;
 $13 = (($5) + 144|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($5) + 148|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($5) + 152|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(-$14);
 $20 = Math_fround(-$16);
 $21 = Math_fround(-$18);
 HEAPF32[$0>>2] = $19;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $21;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = ($7|0)==(0);
 $b$a$i$i = $25 ? $0 : $1;
 $26 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $27 = ($9|0)==(0);
 $a$pn3$i$i = $27 ? $0 : $1;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $28 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $29 = ($11|0)==(0);
 $b$a5$i$i = $29 ? $0 : $1;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $30 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $31 = (($3) + 48|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($3) + 52|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($3) + 56|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$3>>2]);
 $38 = Math_fround($26 * $37);
 $39 = (($3) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($28 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($3) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($30 * $44);
 $46 = Math_fround($42 + $45);
 $47 = (($3) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($26 * $48);
 $50 = (($3) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($28 * $51);
 $53 = Math_fround($49 + $52);
 $54 = (($3) + 36|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($30 * $55);
 $57 = Math_fround($53 + $56);
 $58 = (($3) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($26 * $59);
 $61 = (($3) + 24|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($28 * $62);
 $64 = Math_fround($60 + $63);
 $65 = (($3) + 40|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($30 * $66);
 $68 = Math_fround($64 + $67);
 $69 = Math_fround($32 + $46);
 $70 = Math_fround($34 + $57);
 $71 = Math_fround($36 + $68);
 $72 = (($this) + 12|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (549664 + ($indexB<<4)|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ((549664 + ($indexB<<4)|0) + 4|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ((549664 + ($indexB<<4)|0) + 8|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($73) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$80+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$80+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$80+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$80+12>>2]|0;
 $81 = (($73) + 144|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($73) + 148|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($73) + 152|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround(-$82);
 $88 = Math_fround(-$84);
 $89 = Math_fround(-$86);
 HEAPF32[$0>>2] = $87;
 $90 = (($0) + 4|0);
 HEAPF32[$90>>2] = $88;
 $91 = (($0) + 8|0);
 HEAPF32[$91>>2] = $89;
 $92 = (($0) + 12|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $93 = ($75|0)==(0);
 $b$a$i$i4 = $93 ? $0 : $1;
 $94 = Math_fround(HEAPF32[$b$a$i$i4>>2]);
 $95 = ($77|0)==(0);
 $a$pn3$i$i6 = $95 ? $0 : $1;
 $$in1$i$i7 = (($a$pn3$i$i6) + 4|0);
 $96 = Math_fround(HEAPF32[$$in1$i$i7>>2]);
 $97 = ($79|0)==(0);
 $b$a5$i$i8 = $97 ? $0 : $1;
 $$in2$i$i9 = (($b$a5$i$i8) + 8|0);
 $98 = Math_fround(HEAPF32[$$in2$i$i9>>2]);
 HEAPF32[$supportA>>2] = $69;
 $99 = (($supportA) + 4|0);
 HEAPF32[$99>>2] = $70;
 $100 = (($supportA) + 8|0);
 HEAPF32[$100>>2] = $71;
 $101 = (($supportA) + 12|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $94;
 $102 = (($supportB) + 4|0);
 HEAPF32[$102>>2] = $96;
 $103 = (($supportB) + 8|0);
 HEAPF32[$103>>2] = $98;
 $104 = (($supportB) + 12|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = Math_fround($69 - $94);
 $106 = Math_fround($70 - $96);
 $107 = Math_fround($71 - $98);
 HEAPF32[$support>>2] = $105;
 $108 = (($support) + 4|0);
 HEAPF32[$108>>2] = $106;
 $109 = (($support) + 8|0);
 HEAPF32[$109>>2] = $107;
 $110 = (($support) + 12|0);
 HEAPF32[$110>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_E9doSupportERKNS_6shdfnd3aos5Vec3VERS6_S9_S9_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in1$i$i$i = 0, $$in2$i$i = 0, $$in2$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0);
 var $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0;
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $a$pn3$i$i = 0, $a$pn3$i$i$i = 0, $b$a$i$i = 0, $b$a$i$i$i = 0, $b$a5$i$i = 0, $b$a5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$6);
 $11 = Math_fround(-$8);
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $9);
 $16 = (($13) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $10);
 $19 = Math_fround($15 + $18);
 $20 = (($13) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $11);
 $23 = Math_fround($19 + $22);
 $24 = (($13) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $9);
 $27 = (($13) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $10);
 $30 = Math_fround($26 + $29);
 $31 = (($13) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $11);
 $34 = Math_fround($30 + $33);
 $35 = (($13) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * $9);
 $38 = (($13) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $10);
 $41 = Math_fround($37 + $40);
 $42 = (($13) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $11);
 $45 = Math_fround($41 + $44);
 $46 = $23 > Math_fround(0.0);
 $47 = $34 > Math_fround(0.0);
 $48 = $45 > Math_fround(0.0);
 $49 = (($3) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$49+12>>2]|0;
 $50 = (($3) + 144|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($3) + 148|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($3) + 152|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround(-$51);
 $57 = Math_fround(-$53);
 $58 = Math_fround(-$55);
 HEAPF32[$0>>2] = $56;
 $59 = (($0) + 4|0);
 HEAPF32[$59>>2] = $57;
 $60 = (($0) + 8|0);
 HEAPF32[$60>>2] = $58;
 $61 = (($0) + 12|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $b$a$i$i$i = $46 ? $1 : $0;
 $62 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
 $a$pn3$i$i$i = $47 ? $1 : $0;
 $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
 $63 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
 $b$a5$i$i$i = $48 ? $1 : $0;
 $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
 $64 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
 $65 = (($13) + 48|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($13) + 52|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($13) + 56|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($14 * $62);
 $72 = Math_fround($25 * $63);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($36 * $64);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($17 * $62);
 $77 = Math_fround($28 * $63);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($39 * $64);
 $80 = Math_fround($78 + $79);
 $81 = Math_fround($21 * $62);
 $82 = Math_fround($32 * $63);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($43 * $64);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($75 + $66);
 $87 = Math_fround($80 + $68);
 $88 = Math_fround($85 + $70);
 $89 = (($this) + 12|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = Math_fround(HEAPF32[$dir>>2]);
 $92 = Math_fround(HEAPF32[$5>>2]);
 $93 = Math_fround(HEAPF32[$7>>2]);
 $94 = $91 > Math_fround(0.0);
 $95 = $92 > Math_fround(0.0);
 $96 = $93 > Math_fround(0.0);
 $97 = (($90) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$97+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$97+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$97+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$97+12>>2]|0;
 $98 = (($90) + 144|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($90) + 148|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($90) + 152|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround(-$99);
 $105 = Math_fround(-$101);
 $106 = Math_fround(-$103);
 HEAPF32[$0>>2] = $104;
 $107 = (($0) + 4|0);
 HEAPF32[$107>>2] = $105;
 $108 = (($0) + 8|0);
 HEAPF32[$108>>2] = $106;
 $109 = (($0) + 12|0);
 HEAPF32[$109>>2] = Math_fround(0.0);
 $b$a$i$i = $94 ? $1 : $0;
 $110 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $95 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $111 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $96 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $112 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $86;
 $113 = (($supportA) + 4|0);
 HEAPF32[$113>>2] = $87;
 $114 = (($supportA) + 8|0);
 HEAPF32[$114>>2] = $88;
 $115 = (($supportA) + 12|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $110;
 $116 = (($supportB) + 4|0);
 HEAPF32[$116>>2] = $111;
 $117 = (($supportB) + 8|0);
 HEAPF32[$117>>2] = $112;
 $118 = (($supportB) + 12|0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 $119 = Math_fround($86 - $110);
 $120 = Math_fround($87 - $111);
 $121 = Math_fround($88 - $112);
 HEAPF32[$support>>2] = $119;
 $122 = (($support) + 4|0);
 HEAPF32[$122>>2] = $120;
 $123 = (($support) + 8|0);
 HEAPF32[$123>>2] = $121;
 $124 = (($support) + 12|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_E6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + ($indexA<<4)|0) + 96|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = ((($1) + ($indexA<<4)|0) + 100|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = ((($1) + ($indexA<<4)|0) + 104|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($1) + ($indexA<<4)|0) + 108|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 200|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + (($indexB*12)|0)|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = ((($13) + (($indexB*12)|0)|0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = ((($13) + (($indexB*12)|0)|0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($11) + 96|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($15 * $21);
 $23 = (($11) + 112|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($17 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($11) + 128|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($19 * $28);
 $30 = Math_fround($26 + $29);
 $31 = (($11) + 100|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($15 * $32);
 $34 = (($11) + 116|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($17 * $35);
 $37 = Math_fround($33 + $36);
 $38 = (($11) + 132|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($19 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($11) + 104|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($15 * $43);
 $45 = (($11) + 120|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($17 * $46);
 $48 = Math_fround($44 + $47);
 $49 = (($11) + 136|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($19 * $50);
 $52 = Math_fround($48 + $51);
 HEAPF32[$supportA>>2] = $3;
 $53 = (($supportA) + 4|0);
 HEAPF32[$53>>2] = $5;
 $54 = (($supportA) + 8|0);
 HEAPF32[$54>>2] = $7;
 $55 = (($supportA) + 12|0);
 HEAPF32[$55>>2] = $9;
 HEAPF32[$supportB>>2] = $30;
 $56 = (($supportB) + 4|0);
 HEAPF32[$56>>2] = $41;
 $57 = (($supportB) + 8|0);
 HEAPF32[$57>>2] = $52;
 $58 = (($supportB) + 12|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = Math_fround($3 - $30);
 $60 = Math_fround($5 - $41);
 $61 = Math_fround($7 - $52);
 HEAPF32[$support>>2] = $59;
 $62 = (($support) + 4|0);
 HEAPF32[$62>>2] = $60;
 $63 = (($support) + 8|0);
 HEAPF32[$63>>2] = $61;
 $64 = (($support) + 12|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in1$i19$i = 0, $$in2$i$i = 0, $$in2$i21$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $_sb = 0, $b$a$i16$i = 0, $phitmp164$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $_sb = sp + 48|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_fround(HEAPF32[$dir>>2]);
 $7 = (($dir) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($dir) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(-$6);
 $12 = Math_fround(-$8);
 $13 = Math_fround(-$10);
 $14 = (($5) + 96|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($5) + 100|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($5) + 104|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($5) + 108|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($5) + 112|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($5) + 116|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($5) + 120|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($5) + 124|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($5) + 128|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($5) + 132|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($5) + 136|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($5) + 140|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($15 * $11);
 $39 = Math_fround($17 * $12);
 $40 = Math_fround($38 + $39);
 $41 = Math_fround($19 * $13);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($23 * $11);
 $44 = Math_fround($25 * $12);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($27 * $13);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($31 * $11);
 $49 = Math_fround($33 * $12);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($35 * $13);
 $52 = Math_fround($50 + $51);
 $53 = $42 > $47;
 if ($53) {
  $54 = $42 > $52;
  $phitmp164$i = $54 ? $3 : $2;
  $72 = $phitmp164$i;
 } else {
  $72 = $2;
 }
 $55 = $47 > $52;
 HEAPF32[$1>>2] = $23;
 $56 = (($1) + 4|0);
 HEAPF32[$56>>2] = $25;
 $57 = (($1) + 8|0);
 HEAPF32[$57>>2] = $27;
 $58 = (($1) + 12|0);
 HEAPF32[$58>>2] = $29;
 HEAPF32[$0>>2] = $31;
 $59 = (($0) + 4|0);
 HEAPF32[$59>>2] = $33;
 $60 = (($0) + 8|0);
 HEAPF32[$60>>2] = $35;
 $61 = (($0) + 12|0);
 HEAPF32[$61>>2] = $37;
 $b$a$i16$i = $55 ? $1 : $0;
 $62 = Math_fround(HEAPF32[$b$a$i16$i>>2]);
 $$in1$i19$i = (($b$a$i16$i) + 4|0);
 $63 = Math_fround(HEAPF32[$$in1$i19$i>>2]);
 $$in2$i21$i = (($b$a$i16$i) + 8|0);
 $64 = Math_fround(HEAPF32[$$in2$i21$i>>2]);
 HEAPF32[$3>>2] = $15;
 $65 = (($3) + 4|0);
 HEAPF32[$65>>2] = $17;
 $66 = (($3) + 8|0);
 HEAPF32[$66>>2] = $19;
 $67 = (($3) + 12|0);
 HEAPF32[$67>>2] = $21;
 HEAPF32[$2>>2] = $62;
 $68 = (($2) + 4|0);
 HEAPF32[$68>>2] = $63;
 $69 = (($2) + 8|0);
 HEAPF32[$69>>2] = $64;
 $70 = (($2) + 12|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = Math_fround(HEAPF32[$72>>2]);
 $$in1$i$i = (($72) + 4|0);
 $73 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $$in2$i$i = (($72) + 8|0);
 $74 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $75 = (($this) + 12|0);
 $76 = HEAP32[$75>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($_sb,$76,$dir);
 HEAPF32[$supportA>>2] = $71;
 $77 = (($supportA) + 4|0);
 HEAPF32[$77>>2] = $73;
 $78 = (($supportA) + 8|0);
 HEAPF32[$78>>2] = $74;
 $79 = (($supportA) + 12|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 ;HEAP32[$supportB+0>>2]=HEAP32[$_sb+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$_sb+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$_sb+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$_sb+12>>2]|0;
 $80 = Math_fround(HEAPF32[$_sb>>2]);
 $81 = (($_sb) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($_sb) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($71 - $80);
 $86 = Math_fround($73 - $82);
 $87 = Math_fround($74 - $84);
 HEAPF32[$support>>2] = $85;
 $88 = (($support) + 4|0);
 HEAPF32[$88>>2] = $86;
 $89 = (($support) + 8|0);
 HEAPF32[$89>>2] = $87;
 $90 = (($support) + 12|0);
 HEAPF32[$90>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($8) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($8) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($2 - $9);
 $15 = Math_fround($4 - $11);
 $16 = Math_fround($6 - $13);
 HEAPF32[$agg$result>>2] = $14;
 $17 = (($agg$result) + 4|0);
 HEAPF32[$17>>2] = $15;
 $18 = (($agg$result) + 8|0);
 HEAPF32[$18>>2] = $16;
 $19 = (($agg$result) + 12|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + ($indexA<<4)|0) + 96|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = ((($3) + ($indexA<<4)|0) + 100|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($3) + ($indexA<<4)|0) + 104|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($3) + ($indexA<<4)|0) + 108|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (549664 + ($indexB<<4)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((549664 + ($indexB<<4)|0) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((549664 + ($indexB<<4)|0) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($13) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$20+12>>2]|0;
 $21 = (($13) + 144|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($13) + 148|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($13) + 152|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(-$22);
 $28 = Math_fround(-$24);
 $29 = Math_fround(-$26);
 HEAPF32[$0>>2] = $27;
 $30 = (($0) + 4|0);
 HEAPF32[$30>>2] = $28;
 $31 = (($0) + 8|0);
 HEAPF32[$31>>2] = $29;
 $32 = (($0) + 12|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = ($15|0)==(0);
 $b$a$i$i = $33 ? $0 : $1;
 $34 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $35 = ($17|0)==(0);
 $a$pn3$i$i = $35 ? $0 : $1;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $36 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $37 = ($19|0)==(0);
 $b$a5$i$i = $37 ? $0 : $1;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $38 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $5;
 $39 = (($supportA) + 4|0);
 HEAPF32[$39>>2] = $7;
 $40 = (($supportA) + 8|0);
 HEAPF32[$40>>2] = $9;
 $41 = (($supportA) + 12|0);
 HEAPF32[$41>>2] = $11;
 HEAPF32[$supportB>>2] = $34;
 $42 = (($supportB) + 4|0);
 HEAPF32[$42>>2] = $36;
 $43 = (($supportB) + 8|0);
 HEAPF32[$43>>2] = $38;
 $44 = (($supportB) + 12|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = Math_fround($5 - $34);
 $46 = Math_fround($7 - $36);
 $47 = Math_fround($9 - $38);
 HEAPF32[$support>>2] = $45;
 $48 = (($support) + 4|0);
 HEAPF32[$48>>2] = $46;
 $49 = (($support) + 8|0);
 HEAPF32[$49>>2] = $47;
 $50 = (($support) + 12|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in1$i$i7 = 0, $$in1$i19$i = 0, $$in2$i$i = 0, $$in2$i$i8 = 0, $$in2$i21$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0);
 var $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0);
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a$i16$i = 0, $b$a5$i$i = 0, $phitmp164$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_fround(HEAPF32[$dir>>2]);
 $7 = (($dir) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($dir) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(-$6);
 $12 = Math_fround(-$8);
 $13 = Math_fround(-$10);
 $14 = (($5) + 96|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($5) + 100|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($5) + 104|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($5) + 108|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($5) + 112|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($5) + 116|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($5) + 120|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($5) + 124|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($5) + 128|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($5) + 132|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($5) + 136|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($5) + 140|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($15 * $11);
 $39 = Math_fround($17 * $12);
 $40 = Math_fround($38 + $39);
 $41 = Math_fround($19 * $13);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($23 * $11);
 $44 = Math_fround($25 * $12);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($27 * $13);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($31 * $11);
 $49 = Math_fround($33 * $12);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($35 * $13);
 $52 = Math_fround($50 + $51);
 $53 = $42 > $47;
 if ($53) {
  $54 = $42 > $52;
  $phitmp164$i = $54 ? $3 : $2;
  $72 = $phitmp164$i;
 } else {
  $72 = $2;
 }
 $55 = $47 > $52;
 HEAPF32[$1>>2] = $23;
 $56 = (($1) + 4|0);
 HEAPF32[$56>>2] = $25;
 $57 = (($1) + 8|0);
 HEAPF32[$57>>2] = $27;
 $58 = (($1) + 12|0);
 HEAPF32[$58>>2] = $29;
 HEAPF32[$0>>2] = $31;
 $59 = (($0) + 4|0);
 HEAPF32[$59>>2] = $33;
 $60 = (($0) + 8|0);
 HEAPF32[$60>>2] = $35;
 $61 = (($0) + 12|0);
 HEAPF32[$61>>2] = $37;
 $b$a$i16$i = $55 ? $1 : $0;
 $62 = Math_fround(HEAPF32[$b$a$i16$i>>2]);
 $$in1$i19$i = (($b$a$i16$i) + 4|0);
 $63 = Math_fround(HEAPF32[$$in1$i19$i>>2]);
 $$in2$i21$i = (($b$a$i16$i) + 8|0);
 $64 = Math_fround(HEAPF32[$$in2$i21$i>>2]);
 HEAPF32[$3>>2] = $15;
 $65 = (($3) + 4|0);
 HEAPF32[$65>>2] = $17;
 $66 = (($3) + 8|0);
 HEAPF32[$66>>2] = $19;
 $67 = (($3) + 12|0);
 HEAPF32[$67>>2] = $21;
 HEAPF32[$2>>2] = $62;
 $68 = (($2) + 4|0);
 HEAPF32[$68>>2] = $63;
 $69 = (($2) + 8|0);
 HEAPF32[$69>>2] = $64;
 $70 = (($2) + 12|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = Math_fround(HEAPF32[$72>>2]);
 $$in1$i$i7 = (($72) + 4|0);
 $73 = Math_fround(HEAPF32[$$in1$i$i7>>2]);
 $$in2$i$i8 = (($72) + 8|0);
 $74 = Math_fround(HEAPF32[$$in2$i$i8>>2]);
 $75 = (($this) + 12|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = $6 > Math_fround(0.0);
 $78 = $8 > Math_fround(0.0);
 $79 = $10 > Math_fround(0.0);
 $80 = (($76) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$80+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$80+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$80+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$80+12>>2]|0;
 $81 = (($76) + 144|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($76) + 148|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($76) + 152|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround(-$82);
 $88 = Math_fround(-$84);
 $89 = Math_fround(-$86);
 HEAPF32[$0>>2] = $87;
 $90 = (($0) + 4|0);
 HEAPF32[$90>>2] = $88;
 $91 = (($0) + 8|0);
 HEAPF32[$91>>2] = $89;
 $92 = (($0) + 12|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $b$a$i$i = $77 ? $1 : $0;
 $93 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $78 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $94 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $79 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $95 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $71;
 $96 = (($supportA) + 4|0);
 HEAPF32[$96>>2] = $73;
 $97 = (($supportA) + 8|0);
 HEAPF32[$97>>2] = $74;
 $98 = (($supportA) + 12|0);
 HEAPF32[$98>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $93;
 $99 = (($supportB) + 4|0);
 HEAPF32[$99>>2] = $94;
 $100 = (($supportB) + 8|0);
 HEAPF32[$100>>2] = $95;
 $101 = (($supportB) + 12|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = Math_fround($71 - $93);
 $103 = Math_fround($73 - $94);
 $104 = Math_fround($74 - $95);
 HEAPF32[$support>>2] = $102;
 $105 = (($support) + 4|0);
 HEAPF32[$105>>2] = $103;
 $106 = (($support) + 8|0);
 HEAPF32[$106>>2] = $104;
 $107 = (($support) + 12|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($8) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($8) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($2 - $9);
 $15 = Math_fround($4 - $11);
 $16 = Math_fround($6 - $13);
 HEAPF32[$agg$result>>2] = $14;
 $17 = (($agg$result) + 4|0);
 HEAPF32[$17>>2] = $15;
 $18 = (($agg$result) + 8|0);
 HEAPF32[$18>>2] = $16;
 $19 = (($agg$result) + 12|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (1 - ($indexA))|0;
 $3 = (($1) + 96|0);
 $4 = (($3) + ($2<<4)|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = ((($3) + ($2<<4)|0) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($3) + ($2<<4)|0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($3) + ($2<<4)|0) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 200|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + (($indexB*12)|0)|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = ((($15) + (($indexB*12)|0)|0) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($15) + (($indexB*12)|0)|0) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($13) + 96|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($17 * $23);
 $25 = (($13) + 112|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($19 * $26);
 $28 = Math_fround($24 + $27);
 $29 = (($13) + 128|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($21 * $30);
 $32 = Math_fround($28 + $31);
 $33 = (($13) + 100|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($17 * $34);
 $36 = (($13) + 116|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($19 * $37);
 $39 = Math_fround($35 + $38);
 $40 = (($13) + 132|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($21 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (($13) + 104|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($17 * $45);
 $47 = (($13) + 120|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($19 * $48);
 $50 = Math_fround($46 + $49);
 $51 = (($13) + 136|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($21 * $52);
 $54 = Math_fround($50 + $53);
 HEAPF32[$supportA>>2] = $5;
 $55 = (($supportA) + 4|0);
 HEAPF32[$55>>2] = $7;
 $56 = (($supportA) + 8|0);
 HEAPF32[$56>>2] = $9;
 $57 = (($supportA) + 12|0);
 HEAPF32[$57>>2] = $11;
 HEAPF32[$supportB>>2] = $32;
 $58 = (($supportB) + 4|0);
 HEAPF32[$58>>2] = $43;
 $59 = (($supportB) + 8|0);
 HEAPF32[$59>>2] = $54;
 $60 = (($supportB) + 12|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = Math_fround($5 - $32);
 $62 = Math_fround($7 - $43);
 $63 = Math_fround($9 - $54);
 HEAPF32[$support>>2] = $61;
 $64 = (($support) + 4|0);
 HEAPF32[$64>>2] = $62;
 $65 = (($support) + 8|0);
 HEAPF32[$65>>2] = $63;
 $66 = (($support) + 12|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $_sb = 0, $b$a$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $_sb = sp + 16|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$6);
 $11 = Math_fround(-$8);
 $12 = (($3) + 96|0);
 $13 = (($3) + 96|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($3) + 100|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($3) + 104|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($14 * $9);
 $20 = Math_fround($16 * $10);
 $21 = Math_fround($19 + $20);
 $22 = Math_fround($18 * $11);
 $23 = Math_fround($21 + $22);
 $24 = (($3) + 112|0);
 $25 = (($3) + 112|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($3) + 116|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($3) + 120|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($26 * $9);
 $32 = Math_fround($28 * $10);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround($30 * $11);
 $35 = Math_fround($33 + $34);
 $36 = $23 > $35;
 ;HEAP32[$1+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$12+12>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$24+12>>2]|0;
 $b$a$i$i = $36 ? $1 : $0;
 $37 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $$in1$i$i = (($b$a$i$i) + 4|0);
 $38 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $$in2$i$i = (($b$a$i$i) + 8|0);
 $39 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $40 = (($this) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($_sb,$41,$dir);
 HEAPF32[$supportA>>2] = $37;
 $42 = (($supportA) + 4|0);
 HEAPF32[$42>>2] = $38;
 $43 = (($supportA) + 8|0);
 HEAPF32[$43>>2] = $39;
 $44 = (($supportA) + 12|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 ;HEAP32[$supportB+0>>2]=HEAP32[$_sb+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$_sb+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$_sb+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$_sb+12>>2]|0;
 $45 = Math_fround(HEAPF32[$_sb>>2]);
 $46 = (($_sb) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($_sb) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($37 - $45);
 $51 = Math_fround($38 - $47);
 $52 = Math_fround($39 - $49);
 HEAPF32[$support>>2] = $50;
 $53 = (($support) + 4|0);
 HEAPF32[$53>>2] = $51;
 $54 = (($support) + 8|0);
 HEAPF32[$54>>2] = $52;
 $55 = (($support) + 12|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($8) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($8) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($2 - $9);
 $15 = Math_fround($4 - $11);
 $16 = Math_fround($6 - $13);
 HEAPF32[$agg$result>>2] = $14;
 $17 = (($agg$result) + 4|0);
 HEAPF32[$17>>2] = $15;
 $18 = (($agg$result) + 8|0);
 HEAPF32[$18>>2] = $16;
 $19 = (($agg$result) + 12|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (1 - ($indexA))|0;
 $5 = (($3) + 96|0);
 $6 = (($5) + ($4<<4)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($5) + ($4<<4)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($5) + ($4<<4)|0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = ((($5) + ($4<<4)|0) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (549664 + ($indexB<<4)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((549664 + ($indexB<<4)|0) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((549664 + ($indexB<<4)|0) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($15) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$22+12>>2]|0;
 $23 = (($15) + 144|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($15) + 148|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($15) + 152|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(-$24);
 $30 = Math_fround(-$26);
 $31 = Math_fround(-$28);
 HEAPF32[$0>>2] = $29;
 $32 = (($0) + 4|0);
 HEAPF32[$32>>2] = $30;
 $33 = (($0) + 8|0);
 HEAPF32[$33>>2] = $31;
 $34 = (($0) + 12|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = ($17|0)==(0);
 $b$a$i$i = $35 ? $0 : $1;
 $36 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $37 = ($19|0)==(0);
 $a$pn3$i$i = $37 ? $0 : $1;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $38 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $39 = ($21|0)==(0);
 $b$a5$i$i = $39 ? $0 : $1;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $40 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $7;
 $41 = (($supportA) + 4|0);
 HEAPF32[$41>>2] = $9;
 $42 = (($supportA) + 8|0);
 HEAPF32[$42>>2] = $11;
 $43 = (($supportA) + 12|0);
 HEAPF32[$43>>2] = $13;
 HEAPF32[$supportB>>2] = $36;
 $44 = (($supportB) + 4|0);
 HEAPF32[$44>>2] = $38;
 $45 = (($supportB) + 8|0);
 HEAPF32[$45>>2] = $40;
 $46 = (($supportB) + 12|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = Math_fround($7 - $36);
 $48 = Math_fround($9 - $38);
 $49 = Math_fround($11 - $40);
 HEAPF32[$support>>2] = $47;
 $50 = (($support) + 4|0);
 HEAPF32[$50>>2] = $48;
 $51 = (($support) + 8|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($support) + 12|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in1$i$i8 = 0, $$in2$i$i = 0, $$in2$i$i9 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a$i$i6 = 0;
 var $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$6);
 $11 = Math_fround(-$8);
 $12 = (($3) + 96|0);
 $13 = (($3) + 96|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($3) + 100|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($3) + 104|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($14 * $9);
 $20 = Math_fround($16 * $10);
 $21 = Math_fround($19 + $20);
 $22 = Math_fround($18 * $11);
 $23 = Math_fround($21 + $22);
 $24 = (($3) + 112|0);
 $25 = (($3) + 112|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($3) + 116|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($3) + 120|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($26 * $9);
 $32 = Math_fround($28 * $10);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround($30 * $11);
 $35 = Math_fround($33 + $34);
 $36 = $23 > $35;
 ;HEAP32[$1+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$12+12>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$24+12>>2]|0;
 $b$a$i$i6 = $36 ? $1 : $0;
 $37 = Math_fround(HEAPF32[$b$a$i$i6>>2]);
 $$in1$i$i8 = (($b$a$i$i6) + 4|0);
 $38 = Math_fround(HEAPF32[$$in1$i$i8>>2]);
 $$in2$i$i9 = (($b$a$i$i6) + 8|0);
 $39 = Math_fround(HEAPF32[$$in2$i$i9>>2]);
 $40 = (($this) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $4 > Math_fround(0.0);
 $43 = $6 > Math_fround(0.0);
 $44 = $8 > Math_fround(0.0);
 $45 = (($41) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$45+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$45+12>>2]|0;
 $46 = (($41) + 144|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($41) + 148|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($41) + 152|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround(-$47);
 $53 = Math_fround(-$49);
 $54 = Math_fround(-$51);
 HEAPF32[$0>>2] = $52;
 $55 = (($0) + 4|0);
 HEAPF32[$55>>2] = $53;
 $56 = (($0) + 8|0);
 HEAPF32[$56>>2] = $54;
 $57 = (($0) + 12|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $b$a$i$i = $42 ? $1 : $0;
 $58 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $43 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $59 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $44 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $60 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $37;
 $61 = (($supportA) + 4|0);
 HEAPF32[$61>>2] = $38;
 $62 = (($supportA) + 8|0);
 HEAPF32[$62>>2] = $39;
 $63 = (($supportA) + 12|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $58;
 $64 = (($supportB) + 4|0);
 HEAPF32[$64>>2] = $59;
 $65 = (($supportB) + 8|0);
 HEAPF32[$65>>2] = $60;
 $66 = (($supportB) + 12|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = Math_fround($37 - $58);
 $68 = Math_fround($38 - $59);
 $69 = Math_fround($39 - $60);
 HEAPF32[$support>>2] = $67;
 $70 = (($support) + 4|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($support) + 8|0);
 HEAPF32[$71>>2] = $69;
 $72 = (($support) + 12|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($8) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($8) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($2 - $9);
 $15 = Math_fround($4 - $11);
 $16 = Math_fround($6 - $13);
 HEAPF32[$agg$result>>2] = $14;
 $17 = (($agg$result) + 4|0);
 HEAPF32[$17>>2] = $15;
 $18 = (($agg$result) + 8|0);
 HEAPF32[$18>>2] = $16;
 $19 = (($agg$result) + 12|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19gjkRelativeFallbackERKNS0_7ConvexVES3_PNS0_10SupportMapES5_RKNS_6shdfnd3aos5Vec3VERS8_SB_SB_RNS7_6FloatVE($a,$b,$map1,$map2,$initialDir,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $map1 = $map1|0;
 $map2 = $map2|0;
 $initialDir = $initialDir|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $$$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i29 = 0, $$in1$i98 = 0, $$in2$i = 0, $$in2$i100 = 0, $$in2$i31 = 0, $$not = 0, $$not382 = 0, $$sroa$1106 = 0, $$sroa$1144 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0;
 var $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0);
 var $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $b$a$i18 = 0, $b$a$i26 = 0, $b$a$i95 = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closB = 0, $closBB = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportA = 0, $supportB = 0, $tempIndices$i = 0, $v = 0, $zeroV = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $0 = sp + 160|0;
 $1 = sp + 288|0;
 $tempIndices$i = sp + 464|0;
 $2 = sp + 176|0;
 $3 = sp + 192|0;
 $4 = sp + 448|0;
 $5 = sp + 208|0;
 $Q = sp + 224|0;
 $A = sp + 304|0;
 $B = sp + 384|0;
 $zeroV = sp + 368|0;
 $size = sp + 512|0;
 $v = sp + 144|0;
 $closA = sp + 48|0;
 $closB = sp;
 $sDist$sroa$1 = sp + 500|0;
 $closAA = sp + 16|0;
 $closBB = sp + 32|0;
 $supportA = sp + 64|0;
 $6 = sp + 80|0;
 $supportB = sp + 96|0;
 $support = sp + 112|0;
 $7 = sp + 128|0;
 $$sroa$1144 = sp + 488|0;
 $$sroa$1106 = sp + 476|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAP32[$size>>2] = 0;
 $8 = Math_fround(HEAPF32[$initialDir>>2]);
 $9 = (($initialDir) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($initialDir) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($8 * $8);
 $14 = Math_fround($10 * $10);
 $15 = Math_fround($13 + $14);
 $16 = Math_fround($12 * $12);
 $17 = Math_fround($15 + $16);
 $18 = $17 > Math_fround(0.0);
 ;HEAP32[$1+0>>2]=HEAP32[$initialDir+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$initialDir+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$initialDir+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$initialDir+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $19 = (($0) + 4|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($0) + 8|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($0) + 12|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $b$a$i95 = $18 ? $1 : $0;
 $22 = Math_fround(HEAPF32[$b$a$i95>>2]);
 $$in1$i98 = (($b$a$i95) + 4|0);
 $23 = Math_fround(HEAPF32[$$in1$i98>>2]);
 $$in2$i100 = (($b$a$i95) + 8|0);
 $24 = Math_fround(HEAPF32[$$in2$i100>>2]);
 HEAPF32[$v>>2] = $22;
 $25 = (($v) + 4|0);
 HEAPF32[$25>>2] = $23;
 $26 = (($v) + 8|0);
 HEAPF32[$26>>2] = $24;
 $27 = (($v) + 12|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($a) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($b) + 32|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = $29 > $31;
 $$$i = $32 ? $31 : $29;
 $33 = Math_fround($$$i * Math_fround(0.00999999977648258209228));
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closAA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closBB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closBB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closBB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closBB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $34 = (($6) + 4|0);
 $35 = (($6) + 8|0);
 $36 = (($6) + 12|0);
 $37 = (($supportA) + 4|0);
 $38 = (($supportA) + 8|0);
 $39 = (($supportB) + 4|0);
 $40 = (($supportB) + 8|0);
 $41 = (($support) + 4|0);
 $42 = (($support) + 8|0);
 $43 = (($support) + 12|0);
 $48 = $22;$50 = $23;$52 = $24;$79 = Math_fround(3.40282346638528859812E+38);
 while(1) {
  ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closBB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closBB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closBB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closBB+12>>2]=HEAP32[$closB+12>>2]|0;
  $44 = HEAP32[$map1>>2]|0;
  $45 = (($44) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = Math_fround(-$48);
  $49 = Math_fround(-$50);
  $51 = Math_fround(-$52);
  HEAPF32[$6>>2] = $47;
  HEAPF32[$34>>2] = $49;
  HEAPF32[$35>>2] = $51;
  HEAPF32[$36>>2] = Math_fround(0.0);
  FUNCTION_TABLE_viii[$46 & 4095]($supportA,$map1,$6);
  $53 = HEAP32[$map2>>2]|0;
  $54 = (($53) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  FUNCTION_TABLE_viii[$55 & 4095]($supportB,$map2,$v);
  $56 = Math_fround(HEAPF32[$supportA>>2]);
  $57 = Math_fround(HEAPF32[$37>>2]);
  $58 = Math_fround(HEAPF32[$38>>2]);
  $59 = Math_fround(HEAPF32[$supportB>>2]);
  $60 = Math_fround(HEAPF32[$39>>2]);
  $61 = Math_fround(HEAPF32[$40>>2]);
  $62 = Math_fround($56 - $59);
  $63 = Math_fround($57 - $60);
  $64 = Math_fround($58 - $61);
  HEAPF32[$support>>2] = $62;
  HEAPF32[$41>>2] = $63;
  HEAPF32[$42>>2] = $64;
  HEAPF32[$43>>2] = Math_fround(0.0);
  $65 = HEAP32[$size>>2]|0;
  $66 = (($A) + ($65<<4)|0);
  ;HEAP32[$66+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$66+12>>2]=HEAP32[$supportA+12>>2]|0;
  $67 = (($B) + ($65<<4)|0);
  ;HEAP32[$67+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$67+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$67+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$67+12>>2]=HEAP32[$supportB+12>>2]|0;
  $68 = (($65) + 1)|0;
  HEAP32[$size>>2] = $68;
  $69 = (($Q) + ($65<<4)|0);
  ;HEAP32[$69+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$69+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$69+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$69+12>>2]=HEAP32[$support+12>>2]|0;
  $70 = Math_fround(HEAPF32[$v>>2]);
  $71 = Math_fround(HEAPF32[$25>>2]);
  $72 = Math_fround(HEAPF32[$26>>2]);
  $73 = Math_fround($70 * $62);
  $74 = Math_fround($71 * $63);
  $75 = Math_fround($73 + $74);
  $76 = Math_fround($72 * $64);
  $77 = Math_fround($75 + $76);
  $78 = Math_fround($79 - $77);
  $80 = Math_fround($79 * Math_fround(2.24999996135011315346E-4));
  $81 = $80 > $78;
  if ($81) {
   label = 3;
   break;
  }
  if ((($65|0) == 0)) {
   ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
   ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
   ;HEAP32[$7+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$support+12>>2]|0;
  } else if ((($65|0) == 3)) {
   __ZN5physx2Gu36closestPtPointTetrahedronTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($7,$Q,$A,$B,$size,$closA,$closB);
  } else if ((($65|0) == 1)) {
   __ZN5physx2Gu32closestPtPointSegmentTesselationERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_RjRS3_S7_($7,$Q,$support,$A,$supportA,$B,$supportB,$size,$closA,$closB);
  } else if ((($65|0) == 2)) {
   ;HEAP32[$tempIndices$i+0>>2]=HEAP32[551056+0>>2]|0;HEAP32[$tempIndices$i+4>>2]=HEAP32[551056+4>>2]|0;HEAP32[$tempIndices$i+8>>2]=HEAP32[551056+8>>2]|0;
   __ZN5physx2Gu33closestPtPointTriangleTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_PjRjRS3_S7_($7,$Q,$A,$B,$tempIndices$i,$size,$closA,$closB);
  } else {
   ;HEAP32[$7+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$support+12>>2]|0;
  }
  ;HEAP32[$v+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$7+12>>2]|0;
  $109 = Math_fround(HEAPF32[$v>>2]);
  $110 = Math_fround(HEAPF32[$25>>2]);
  $111 = Math_fround(HEAPF32[$26>>2]);
  $112 = Math_fround($109 * $109);
  $113 = Math_fround($110 * $110);
  $114 = Math_fround($112 + $113);
  $115 = Math_fround($111 * $111);
  $116 = Math_fround($114 + $115);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1144+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1144+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1144+8>>2]|0;
  $117 = $79 > $116;
  $$not = !($116 > $33);
  $$not382 = $117 ^ 1;
  $brmerge = $$not | $$not382;
  if ($brmerge) {
   label = 11;
   break;
  } else {
   $48 = $109;$50 = $110;$52 = $111;$79 = $116;
  }
 }
 if ((label|0) == 3) {
  $82 = Math_fround(HEAPF32[$closB>>2]);
  $83 = (($closB) + 4|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = (($closB) + 8|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround(HEAPF32[$closA>>2]);
  $88 = (($closA) + 4|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = (($closA) + 8|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($82 - $87);
  $93 = Math_fround($84 - $89);
  $94 = Math_fround($86 - $91);
  $95 = Math_fround($92 * $92);
  $96 = Math_fround($93 * $93);
  $97 = Math_fround($95 + $96);
  $98 = Math_fround($94 * $94);
  $99 = Math_fround($97 + $98);
  $100 = (Math_fround(Math_sqrt((Math_fround($99)))));
  $101 = Math_fround(Math_fround(1.0) / $100);
  $102 = Math_fround($92 * $101);
  $103 = Math_fround($93 * $101);
  $104 = Math_fround($94 * $101);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  HEAPF32[$sqDist>>2] = $79;
  $105 = (($sqDist) + 4|0);
  ;HEAP32[$105+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$105+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$105+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
  HEAPF32[$normal>>2] = $102;
  $106 = (($normal) + 4|0);
  HEAPF32[$106>>2] = $103;
  $107 = (($normal) + 8|0);
  HEAPF32[$107>>2] = $104;
  $108 = (($normal) + 12|0);
  HEAPF32[$108>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 11) {
  ;HEAP32[$3+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$closAA+12>>2]|0;
  $b$a$i26 = $117 ? $3 : $2;
  $118 = Math_fround(HEAPF32[$b$a$i26>>2]);
  $$in1$i29 = (($b$a$i26) + 4|0);
  $119 = Math_fround(HEAPF32[$$in1$i29>>2]);
  $$in2$i31 = (($b$a$i26) + 8|0);
  $120 = Math_fround(HEAPF32[$$in2$i31>>2]);
  HEAPF32[$closA>>2] = $118;
  $121 = (($closA) + 4|0);
  HEAPF32[$121>>2] = $119;
  $122 = (($closA) + 8|0);
  HEAPF32[$122>>2] = $120;
  $123 = (($closA) + 12|0);
  HEAPF32[$123>>2] = Math_fround(0.0);
  ;HEAP32[$5+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$closB+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$closBB+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$closBB+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$closBB+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$closBB+12>>2]|0;
  $b$a$i18 = $117 ? $5 : $4;
  $124 = Math_fround(HEAPF32[$b$a$i18>>2]);
  $$in1$i = (($b$a$i18) + 4|0);
  $125 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i18) + 8|0);
  $126 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$closB>>2] = $124;
  $127 = (($closB) + 4|0);
  HEAPF32[$127>>2] = $125;
  $128 = (($closB) + 8|0);
  HEAPF32[$128>>2] = $126;
  $129 = (($closB) + 12|0);
  HEAPF32[$129>>2] = Math_fround(0.0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  $130 = Math_fround($124 - $118);
  $131 = Math_fround($125 - $119);
  $132 = Math_fround($126 - $120);
  $133 = Math_fround($130 * $130);
  $134 = Math_fround($131 * $131);
  $135 = Math_fround($133 + $134);
  $136 = Math_fround($132 * $132);
  $137 = Math_fround($135 + $136);
  $138 = (Math_fround(Math_sqrt((Math_fround($137)))));
  $139 = Math_fround(Math_fround(1.0) / $138);
  $140 = Math_fround($130 * $139);
  $141 = Math_fround($131 * $139);
  $142 = Math_fround($132 * $139);
  HEAPF32[$normal>>2] = $140;
  $143 = (($normal) + 4|0);
  HEAPF32[$143>>2] = $141;
  $144 = (($normal) + 8|0);
  HEAPF32[$144>>2] = $142;
  $145 = (($normal) + 12|0);
  HEAPF32[$145>>2] = Math_fround(0.0);
  $146 = $117 ? $116 : $79;
  HEAPF32[$sqDist>>2] = $146;
  $147 = (($sqDist) + 4|0);
  ;HEAP32[$147+0>>2]=HEAP32[$$sroa$1106+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$$sroa$1106+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$$sroa$1106+8>>2]|0;
  $148 = $117 ? 1 : 3;
  $$0 = $148;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu19GJKLocalPenetrationERKNS0_8CapsuleVERKNS0_4BoxVERKNS_6shdfnd3aos6FloatVERNS8_5Vec3VESD_SD_RS9_PhSF_Rhb($a,$b,$contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $contactDist = $contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_4BoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_4BoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$ = 0, $$$1070 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i246 = Math_fround(0), $$$i10571104 = Math_fround(0), $$$i204 = Math_fround(0), $$$i245 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i247 = Math_fround(0), $$0 = 0, $$1066 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i$i = 0, $$in1$i$i256 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i$i = 0, $$in2$i$i258 = 0;
 var $$ph1078 = Math_fround(0), $$ph1079 = 0, $$ph1083 = Math_fround(0), $$ph1084 = Math_fround(0), $$ph1085 = Math_fround(0), $$pre = Math_fround(0), $$pre1127 = Math_fround(0), $$pre1128 = Math_fround(0), $$sroa$1282 = 0, $$sroa$1290 = 0, $$sroa$1356 = 0, $$sroa$1358 = 0, $$sroa$1368 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0);
 var $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0;
 var $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0;
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0;
 var $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0;
 var $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = Math_fround(0);
 var $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0);
 var $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0);
 var $375 = Math_fround(0), $376 = 0, $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0;
 var $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0);
 var $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = Math_fround(0), $482 = 0;
 var $483 = Math_fround(0), $484 = Math_fround(0), $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = Math_fround(0), $503 = 0, $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = 0, $513 = 0, $514 = 0, $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0);
 var $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = 0, $534 = 0, $535 = Math_fround(0), $536 = Math_fround(0);
 var $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = 0, $542 = 0, $543 = 0, $544 = Math_fround(0), $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0;
 var $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0;
 var $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $a$pn3$i$i = 0;
 var $a$pn3$i$i255 = 0, $aInd = 0, $b$a$i$i = 0, $b$a$i$i$i = 0, $b$a$i$i253 = 0, $b$a$i218 = 0, $b$a5$i$i = 0, $b$a5$i$i257 = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i143 = 0, $exitcond$i64 = 0, $i$01$i = 0, $i$01$i142 = 0, $i$01$i63 = 0, $i$01106 = 0, $lastA = 0;
 var $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp1074 = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportA = 0, $supportB = 0, $tempClosA = 0, $tempClosB = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 592|0;
 $0 = sp + 80|0;
 $1 = sp + 384|0;
 $2 = sp + 432|0;
 $3 = sp + 368|0;
 $zeroV = sp + 448|0;
 $closA = sp + 416|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 556|0;
 $minDist$sroa$1 = sp + 544|0;
 $tempClosA = sp + 352|0;
 $tempClosB = sp + 64|0;
 $Q = sp;
 $A = sp + 128|0;
 $B = sp + 288|0;
 $aInd = sp + 528|0;
 $bInd = sp + 568|0;
 $supportA = sp + 112|0;
 $supportB = sp + 192|0;
 $support = sp + 208|0;
 $size = sp + 488|0;
 $lastQ = sp + 224|0;
 $lastA = sp + 240|0;
 $lastB = sp + 256|0;
 $4 = sp + 272|0;
 $$sroa$1368 = sp + 476|0;
 $$sroa$1358 = sp + 464|0;
 $5 = sp + 96|0;
 $$sroa$1356 = sp + 516|0;
 $$sroa$1290 = sp + 492|0;
 $$sroa$1282 = sp + 504|0;
 $6 = Math_fround(HEAPF32[$_contactDist>>2]);
 $7 = (($a) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($b) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i245 = $15 ? $14 : $12;
 $16 = Math_fround($$$i245 * Math_fround(0.100000001490116119385));
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $17 = Math_fround($8 + $10);
 $18 = Math_fround($6 + $17);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 ;HEAP32[$tempClosA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$tempClosB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $19 = Math_fround($16 * $16);
 $20 = Math_fround($18 * $18);
 ;HEAP32[$supportA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$supportB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$support+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAP32[$size>>2] = 0;
 $21 = HEAP8[$_size>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $168 = Math_fround(HEAPF32[$a>>2]);
  $169 = (($a) + 4|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = (($a) + 8|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = Math_fround(HEAPF32[$b>>2]);
  $174 = (($b) + 4|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (($b) + 8|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround($168 - $173);
  $179 = Math_fround($170 - $175);
  $180 = Math_fround($172 - $177);
  $181 = Math_fround($178 * $178);
  $182 = Math_fround($179 * $179);
  $183 = Math_fround($181 + $182);
  $184 = Math_fround($180 * $180);
  $185 = Math_fround($183 + $184);
  $186 = $185 > Math_fround(0.0);
  HEAPF32[$3>>2] = $178;
  $187 = (($3) + 4|0);
  HEAPF32[$187>>2] = $179;
  $188 = (($3) + 8|0);
  HEAPF32[$188>>2] = $180;
  $189 = (($3) + 12|0);
  HEAPF32[$189>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = Math_fround(1.0);
  $190 = (($2) + 4|0);
  HEAPF32[$190>>2] = Math_fround(0.0);
  $191 = (($2) + 8|0);
  HEAPF32[$191>>2] = Math_fround(0.0);
  $192 = (($2) + 12|0);
  HEAPF32[$192>>2] = Math_fround(0.0);
  $b$a$i218 = $186 ? $3 : $2;
  $193 = Math_fround(HEAPF32[$b$a$i218>>2]);
  $$in1$i = (($b$a$i218) + 4|0);
  $194 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i218) + 8|0);
  $195 = Math_fround(HEAPF32[$$in2$i>>2]);
  $$ph1078 = Math_fround(3.40282346638528859812E+38);$$ph1079 = 1;$$ph1083 = $195;$$ph1084 = $194;$$ph1085 = $193;
 } else {
  ;HEAP32[$lastQ+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$zeroV+12>>2]|0;
  $23 = (($a) + 96|0);
  $24 = (($b) + 144|0);
  $25 = (($b) + 144|0);
  $26 = (($b) + 148|0);
  $27 = (($b) + 152|0);
  $28 = (($0) + 4|0);
  $29 = (($0) + 8|0);
  $30 = (($0) + 12|0);
  $31 = (($supportB) + 4|0);
  $32 = (($supportB) + 8|0);
  $33 = (($supportB) + 12|0);
  $34 = (($supportA) + 4|0);
  $35 = (($supportA) + 8|0);
  $36 = (($support) + 4|0);
  $37 = (($support) + 8|0);
  $38 = (($support) + 12|0);
  $$pre = Math_fround(HEAPF32[$25>>2]);
  $$pre1127 = Math_fround(HEAPF32[$26>>2]);
  $$pre1128 = Math_fround(HEAPF32[$27>>2]);
  $71 = 0;$i$01106 = 0;
  while(1) {
   $39 = (($aIndices) + ($i$01106)|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40&255;
   $42 = (($aInd) + ($i$01106<<2)|0);
   HEAP32[$42>>2] = $41;
   $43 = (($bIndices) + ($i$01106)|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = $44&255;
   $46 = (($bInd) + ($i$01106<<2)|0);
   HEAP32[$46>>2] = $45;
   $47 = (1 - ($41))|0;
   $48 = (($23) + ($47<<4)|0);
   ;HEAP32[$supportA+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$48+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$48+12>>2]|0;
   $49 = (549664 + ($45<<4)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ((549664 + ($45<<4)|0) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((549664 + ($45<<4)|0) + 8|0);
   $54 = HEAP32[$53>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$24+12>>2]|0;
   $55 = Math_fround(-$$pre);
   $56 = Math_fround(-$$pre1127);
   $57 = Math_fround(-$$pre1128);
   HEAPF32[$0>>2] = $55;
   HEAPF32[$28>>2] = $56;
   HEAPF32[$29>>2] = $57;
   HEAPF32[$30>>2] = Math_fround(0.0);
   $58 = ($50|0)==(0);
   $b$a$i$i253 = $58 ? $0 : $1;
   $59 = Math_fround(HEAPF32[$b$a$i$i253>>2]);
   $60 = ($52|0)==(0);
   $a$pn3$i$i255 = $60 ? $0 : $1;
   $$in1$i$i256 = (($a$pn3$i$i255) + 4|0);
   $61 = Math_fround(HEAPF32[$$in1$i$i256>>2]);
   $62 = ($54|0)==(0);
   $b$a5$i$i257 = $62 ? $0 : $1;
   $$in2$i$i258 = (($b$a5$i$i257) + 8|0);
   $63 = Math_fround(HEAPF32[$$in2$i$i258>>2]);
   HEAPF32[$supportB>>2] = $59;
   HEAPF32[$31>>2] = $61;
   HEAPF32[$32>>2] = $63;
   HEAPF32[$33>>2] = Math_fround(0.0);
   $64 = Math_fround(HEAPF32[$supportA>>2]);
   $65 = Math_fround(HEAPF32[$34>>2]);
   $66 = Math_fround(HEAPF32[$35>>2]);
   $67 = Math_fround($64 - $59);
   $68 = Math_fround($65 - $61);
   $69 = Math_fround($66 - $63);
   HEAPF32[$support>>2] = $67;
   HEAPF32[$36>>2] = $68;
   HEAPF32[$37>>2] = $69;
   HEAPF32[$38>>2] = Math_fround(0.0);
   $70 = (($A) + ($71<<4)|0);
   ;HEAP32[$lastA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$supportA+12>>2]|0;
   ;HEAP32[$70+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$70+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$70+12>>2]=HEAP32[$supportA+12>>2]|0;
   $72 = (($B) + ($71<<4)|0);
   ;HEAP32[$lastB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$supportB+12>>2]|0;
   ;HEAP32[$72+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$72+12>>2]=HEAP32[$supportB+12>>2]|0;
   $73 = (($71) + 1)|0;
   $74 = (($Q) + ($71<<4)|0);
   ;HEAP32[$lastQ+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$support+12>>2]|0;
   ;HEAP32[$74+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$support+12>>2]|0;
   $75 = (($i$01106) + 1)|0;
   $76 = $21&255;
   $77 = ($75>>>0)<($76>>>0);
   if ($77) {
    $71 = $73;$i$01106 = $75;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $73;
  do {
   if ((($71|0) == 2)) {
    $156 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$156,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($71|0) == 1)) {
    $78 = Math_fround(HEAPF32[$Q>>2]);
    $79 = (($Q) + 4|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = (($Q) + 8|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround(HEAPF32[$lastQ>>2]);
    $84 = (($lastQ) + 4|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = (($lastQ) + 8|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = Math_fround($83 - $78);
    $89 = Math_fround($85 - $80);
    $90 = Math_fround($87 - $82);
    $91 = Math_fround($88 * $88);
    $92 = Math_fround($89 * $89);
    $93 = Math_fround($91 + $92);
    $94 = Math_fround($90 * $90);
    $95 = Math_fround($93 + $94);
    $96 = $95 == Math_fround(0.0);
    if ($96) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $97 = Math_fround($80 * $89);
     $98 = Math_fround(-$97);
     $99 = Math_fround($78 * $88);
     $100 = Math_fround($98 - $99);
     $101 = Math_fround($82 * $90);
     $102 = Math_fround($100 - $101);
     $103 = Math_fround(HEAPF32[$lastA>>2]);
     $104 = (($lastA) + 4|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = (($lastA) + 8|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = Math_fround(HEAPF32[$A>>2]);
     $109 = (($A) + 4|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = (($A) + 8|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = Math_fround($103 - $108);
     $114 = Math_fround($105 - $110);
     $115 = Math_fround($107 - $112);
     $116 = Math_fround(HEAPF32[$lastB>>2]);
     $117 = (($lastB) + 4|0);
     $118 = Math_fround(HEAPF32[$117>>2]);
     $119 = (($lastB) + 8|0);
     $120 = Math_fround(HEAPF32[$119>>2]);
     $121 = Math_fround(HEAPF32[$B>>2]);
     $122 = (($B) + 4|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     $124 = (($B) + 8|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     $126 = Math_fround($116 - $121);
     $127 = Math_fround($118 - $123);
     $128 = Math_fround($120 - $125);
     $129 = Math_fround($102 / $95);
     $130 = $129 > Math_fround(1.0);
     $$$i$i$i246 = $130 ? Math_fround(1.0) : $129;
     $131 = $$$i$i$i246 > Math_fround(0.0);
     $$$i8$i$i247 = $131 ? $$$i$i$i246 : Math_fround(0.0);
     $132 = Math_fround($113 * $$$i8$i$i247);
     $133 = Math_fround($114 * $$$i8$i$i247);
     $134 = Math_fround($115 * $$$i8$i$i247);
     $135 = Math_fround($108 + $132);
     $136 = Math_fround($110 + $133);
     $137 = Math_fround($112 + $134);
     $138 = Math_fround($126 * $$$i8$i$i247);
     $139 = Math_fround($127 * $$$i8$i$i247);
     $140 = Math_fround($128 * $$$i8$i$i247);
     $141 = Math_fround($121 + $138);
     $142 = Math_fround($123 + $139);
     $143 = Math_fround($125 + $140);
     HEAPF32[$closA>>2] = $135;
     $144 = (($closA) + 4|0);
     HEAPF32[$144>>2] = $136;
     $145 = (($closA) + 8|0);
     HEAPF32[$145>>2] = $137;
     $146 = (($closA) + 12|0);
     HEAPF32[$146>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $141;
     $147 = (($closB) + 4|0);
     HEAPF32[$147>>2] = $142;
     $148 = (($closB) + 8|0);
     HEAPF32[$148>>2] = $143;
     $149 = (($closB) + 12|0);
     HEAPF32[$149>>2] = Math_fround(0.0);
     $150 = Math_fround($135 - $141);
     $151 = Math_fround($136 - $142);
     $152 = Math_fround($137 - $143);
     HEAPF32[$4>>2] = $150;
     $153 = (($4) + 4|0);
     HEAPF32[$153>>2] = $151;
     $154 = (($4) + 8|0);
     HEAPF32[$154>>2] = $152;
     $155 = (($4) + 12|0);
     HEAPF32[$155>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($71|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($71|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  $157 = Math_fround(HEAPF32[$4>>2]);
  $158 = (($4) + 4|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = (($4) + 8|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = Math_fround($157 * $157);
  $163 = Math_fround($159 * $159);
  $164 = Math_fround($162 + $163);
  $165 = Math_fround($161 * $161);
  $166 = Math_fround($164 + $165);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $167 = $166 > $19;
  $$ph1078 = $166;$$ph1079 = $167;$$ph1083 = $161;$$ph1084 = $159;$$ph1085 = $157;
 }
 do {
  if ($$ph1079) {
   $197 = (($a) + 96|0);
   $198 = (($a) + 96|0);
   $199 = (($a) + 100|0);
   $200 = (($a) + 104|0);
   $201 = (($a) + 112|0);
   $202 = (($a) + 112|0);
   $203 = (($a) + 116|0);
   $204 = (($a) + 120|0);
   $205 = (($supportA) + 4|0);
   $206 = (($supportA) + 8|0);
   $207 = (($supportA) + 12|0);
   $208 = (($b) + 144|0);
   $209 = (($b) + 144|0);
   $210 = (($b) + 148|0);
   $211 = (($b) + 152|0);
   $212 = (($0) + 4|0);
   $213 = (($0) + 8|0);
   $214 = (($0) + 12|0);
   $215 = (($supportB) + 4|0);
   $216 = (($supportB) + 8|0);
   $217 = (($supportB) + 12|0);
   $218 = (($support) + 4|0);
   $219 = (($support) + 8|0);
   $220 = (($support) + 12|0);
   $221 = (($a) + 48|0);
   $222 = (($b) + 48|0);
   $223 = (($5) + 4|0);
   $224 = (($5) + 8|0);
   $225 = (($Q) + 4|0);
   $226 = (($Q) + 8|0);
   $227 = (($A) + 4|0);
   $228 = (($A) + 8|0);
   $229 = (($B) + 4|0);
   $230 = (($B) + 8|0);
   $231 = (($closA) + 4|0);
   $232 = (($closA) + 8|0);
   $233 = (($closA) + 12|0);
   $234 = (($closB) + 4|0);
   $235 = (($closB) + 8|0);
   $236 = (($closB) + 12|0);
   $237 = (($5) + 12|0);
   $238 = (($Q) + 16|0);
   $$$i10571104 = $6;$240 = $$ph1085;$242 = $$ph1084;$244 = $$ph1083;$311 = $$ph1078;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    ;HEAP32[$tempClosA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$closA+12>>2]|0;
    ;HEAP32[$tempClosB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$closB+12>>2]|0;
    $239 = Math_fround(-$240);
    $241 = Math_fround(-$242);
    $243 = Math_fround(-$244);
    $245 = HEAP32[$size>>2]|0;
    $246 = (($aInd) + ($245<<2)|0);
    $247 = Math_fround(HEAPF32[$198>>2]);
    $248 = Math_fround(HEAPF32[$199>>2]);
    $249 = Math_fround(HEAPF32[$200>>2]);
    $250 = Math_fround($247 * $239);
    $251 = Math_fround($248 * $241);
    $252 = Math_fround($250 + $251);
    $253 = Math_fround($249 * $243);
    $254 = Math_fround($252 + $253);
    $255 = Math_fround(HEAPF32[$202>>2]);
    $256 = Math_fround(HEAPF32[$203>>2]);
    $257 = Math_fround(HEAPF32[$204>>2]);
    $258 = Math_fround($255 * $239);
    $259 = Math_fround($256 * $241);
    $260 = Math_fround($258 + $259);
    $261 = Math_fround($257 * $243);
    $262 = Math_fround($260 + $261);
    $263 = $254 > $262;
    $264 = $263&1;
    HEAP32[$246>>2] = $264;
    ;HEAP32[$1+0>>2]=HEAP32[$197+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$197+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$197+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$197+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$201+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$201+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$201+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$201+12>>2]|0;
    $b$a$i$i$i = $263 ? $1 : $0;
    $265 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
    $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
    $266 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
    $267 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    $268 = (($A) + ($245<<4)|0);
    HEAPF32[$268>>2] = $265;
    $269 = ((($A) + ($245<<4)|0) + 4|0);
    HEAPF32[$269>>2] = $266;
    $270 = ((($A) + ($245<<4)|0) + 8|0);
    HEAPF32[$270>>2] = $267;
    $271 = ((($A) + ($245<<4)|0) + 12|0);
    HEAPF32[$271>>2] = Math_fround(0.0);
    HEAPF32[$supportA>>2] = $265;
    HEAPF32[$205>>2] = $266;
    HEAPF32[$206>>2] = $267;
    HEAPF32[$207>>2] = Math_fround(0.0);
    $272 = (($bInd) + ($245<<2)|0);
    $273 = $240 > Math_fround(0.0);
    $274 = $242 > Math_fround(0.0);
    $275 = $274 << 31 >> 31;
    $276 = $244 > Math_fround(0.0);
    $277 = $276 << 31 >> 31;
    $278 = $273&1;
    $279 = $275 << 1;
    $280 = $279 & 2;
    $281 = $277 << 2;
    $282 = $281 & 4;
    $283 = $282 | $278;
    $284 = $283 | $280;
    HEAP32[$272>>2] = $284;
    ;HEAP32[$1+0>>2]=HEAP32[$208+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$208+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$208+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$208+12>>2]|0;
    $285 = Math_fround(HEAPF32[$209>>2]);
    $286 = Math_fround(HEAPF32[$210>>2]);
    $287 = Math_fround(HEAPF32[$211>>2]);
    $288 = Math_fround(-$285);
    $289 = Math_fround(-$286);
    $290 = Math_fround(-$287);
    HEAPF32[$0>>2] = $288;
    HEAPF32[$212>>2] = $289;
    HEAPF32[$213>>2] = $290;
    HEAPF32[$214>>2] = Math_fround(0.0);
    $b$a$i$i = $273 ? $1 : $0;
    $291 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $274 ? $1 : $0;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $292 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $276 ? $1 : $0;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $293 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    $294 = (($B) + ($245<<4)|0);
    HEAPF32[$294>>2] = $291;
    $295 = ((($B) + ($245<<4)|0) + 4|0);
    HEAPF32[$295>>2] = $292;
    $296 = ((($B) + ($245<<4)|0) + 8|0);
    HEAPF32[$296>>2] = $293;
    $297 = ((($B) + ($245<<4)|0) + 12|0);
    HEAPF32[$297>>2] = Math_fround(0.0);
    HEAPF32[$supportB>>2] = $291;
    HEAPF32[$215>>2] = $292;
    HEAPF32[$216>>2] = $293;
    HEAPF32[$217>>2] = Math_fround(0.0);
    $298 = Math_fround($265 - $291);
    $299 = Math_fround($266 - $292);
    $300 = Math_fround($267 - $293);
    HEAPF32[$support>>2] = $298;
    HEAPF32[$218>>2] = $299;
    HEAPF32[$219>>2] = $300;
    HEAPF32[$220>>2] = Math_fround(0.0);
    $301 = HEAP32[$size>>2]|0;
    $302 = (($301) + 1)|0;
    HEAP32[$size>>2] = $302;
    $303 = (($Q) + ($301<<4)|0);
    ;HEAP32[$303+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$303+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$303+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$303+12>>2]=HEAP32[$support+12>>2]|0;
    $304 = Math_fround(HEAPF32[$221>>2]);
    $305 = Math_fround(HEAPF32[$222>>2]);
    $306 = $304 > $305;
    $$$i204 = $306 ? $304 : $305;
    $307 = $$$i10571104 > $$$i204;
    $$$i = $307 ? $$$i10571104 : $$$i204;
    $308 = Math_fround($17 + $$$i);
    $309 = Math_fround($308 * $308);
    $310 = Math_fround($311 * $309);
    $312 = Math_fround($240 * $298);
    $313 = Math_fround($242 * $299);
    $314 = Math_fround($312 + $313);
    $315 = Math_fround($244 * $300);
    $316 = Math_fround($314 + $315);
    $317 = Math_fround($316 * $316);
    $318 = $316 > Math_fround(0.0);
    $319 = $317 > $310;
    if ($318) {
     $phitmp1074 = $319 ^ 1;
     $323 = $319;$325 = $phitmp1074;
    } else {
     $323 = 0;$325 = 1;
    }
    $320 = Math_fround($311 - $316);
    $321 = Math_fround($19 * $311);
    $322 = $321 >= $320;
    $brmerge$demorgan = $322 | $323;
    if ($brmerge$demorgan) {
     $324 = $325 ^ 1;
     $$1066 = $322 | $324;
     if ($$1066) {
      break;
     }
    }
    do {
     if ((($301|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support,$supportA,$supportB,$size,$closA,$closB);
     } else if ((($301|0) == 1)) {
      $407 = Math_fround(HEAPF32[$Q>>2]);
      $408 = Math_fround(HEAPF32[$225>>2]);
      $409 = Math_fround(HEAPF32[$226>>2]);
      $410 = Math_fround($298 - $407);
      $411 = Math_fround($299 - $408);
      $412 = Math_fround($300 - $409);
      $413 = Math_fround($410 * $410);
      $414 = Math_fround($411 * $411);
      $415 = Math_fround($413 + $414);
      $416 = Math_fround($412 * $412);
      $417 = Math_fround($415 + $416);
      $418 = $417 == Math_fround(0.0);
      if ($418) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $419 = Math_fround($408 * $411);
       $420 = Math_fround(-$419);
       $421 = Math_fround($407 * $410);
       $422 = Math_fround($420 - $421);
       $423 = Math_fround($409 * $412);
       $424 = Math_fround($422 - $423);
       $425 = Math_fround(HEAPF32[$A>>2]);
       $426 = Math_fround(HEAPF32[$227>>2]);
       $427 = Math_fround(HEAPF32[$228>>2]);
       $428 = Math_fround($265 - $425);
       $429 = Math_fround($266 - $426);
       $430 = Math_fround($267 - $427);
       $431 = Math_fround(HEAPF32[$B>>2]);
       $432 = Math_fround(HEAPF32[$229>>2]);
       $433 = Math_fround(HEAPF32[$230>>2]);
       $434 = Math_fround($291 - $431);
       $435 = Math_fround($292 - $432);
       $436 = Math_fround($293 - $433);
       $437 = Math_fround($424 / $417);
       $438 = $437 > Math_fround(1.0);
       $$$i$i$i = $438 ? Math_fround(1.0) : $437;
       $439 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $439 ? $$$i$i$i : Math_fround(0.0);
       $440 = Math_fround($428 * $$$i8$i$i);
       $441 = Math_fround($429 * $$$i8$i$i);
       $442 = Math_fround($430 * $$$i8$i$i);
       $443 = Math_fround($425 + $440);
       $444 = Math_fround($426 + $441);
       $445 = Math_fround($427 + $442);
       $446 = Math_fround($434 * $$$i8$i$i);
       $447 = Math_fround($435 * $$$i8$i$i);
       $448 = Math_fround($436 * $$$i8$i$i);
       $449 = Math_fround($431 + $446);
       $450 = Math_fround($432 + $447);
       $451 = Math_fround($433 + $448);
       HEAPF32[$closA>>2] = $443;
       HEAPF32[$231>>2] = $444;
       HEAPF32[$232>>2] = $445;
       HEAPF32[$233>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $449;
       HEAPF32[$234>>2] = $450;
       HEAPF32[$235>>2] = $451;
       HEAPF32[$236>>2] = Math_fround(0.0);
       $452 = Math_fround($443 - $449);
       $453 = Math_fround($444 - $450);
       $454 = Math_fround($445 - $451);
       HEAPF32[$5>>2] = $452;
       HEAPF32[$223>>2] = $453;
       HEAPF32[$224>>2] = $454;
       HEAPF32[$237>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($301|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($301|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$238,$support,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $455 = Math_fround(HEAPF32[$5>>2]);
    $456 = Math_fround(HEAPF32[$223>>2]);
    $457 = Math_fround(HEAPF32[$224>>2]);
    $458 = Math_fround($455 * $455);
    $459 = Math_fround($456 * $456);
    $460 = Math_fround($458 + $459);
    $461 = Math_fround($457 * $457);
    $462 = Math_fround($460 + $461);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1356+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1356+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1356+8>>2]|0;
    $463 = $311 > $462;
    $464 = $462 > $19;
    if (!($464)) {
     label = 38;
     break;
    }
    if ($463) {
     $$$i10571104 = $$$i;$240 = $455;$242 = $456;$244 = $457;$311 = $462;
    } else {
     label = 38;
     break;
    }
   }
   if ((label|0) == 38) {
    $465 = HEAP32[$size>>2]|0;
    if ($463) {
     $552 = $465;
     break;
    }
    $466 = (($465) + -1)|0;
    $467 = ($aIndices|0)==(0|0);
    if (!($467)) {
     $468 = $466&255;
     HEAP8[$_size>>0] = $468;
     $469 = ($466|0)==(0);
     if (!($469)) {
      $i$01$i63 = 0;
      while(1) {
       $470 = (($aInd) + ($i$01$i63<<2)|0);
       $471 = HEAP32[$470>>2]|0;
       $472 = $471&255;
       $473 = (($aIndices) + ($i$01$i63)|0);
       HEAP8[$473>>0] = $472;
       $474 = (($bInd) + ($i$01$i63<<2)|0);
       $475 = HEAP32[$474>>2]|0;
       $476 = $475&255;
       $477 = (($bIndices) + ($i$01$i63)|0);
       HEAP8[$477>>0] = $476;
       $478 = (($i$01$i63) + 1)|0;
       $exitcond$i64 = ($478|0)==($466|0);
       if ($exitcond$i64) {
        break;
       } else {
        $i$01$i63 = $478;
       }
      }
     }
    }
    ;HEAP32[$closA+0>>2]=HEAP32[$tempClosA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$tempClosA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$tempClosA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$tempClosA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$tempClosB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$tempClosB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$tempClosB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$tempClosB+12>>2]|0;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $479 = Math_fround(HEAPF32[$closA>>2]);
    $480 = (($closA) + 4|0);
    $481 = Math_fround(HEAPF32[$480>>2]);
    $482 = (($closA) + 8|0);
    $483 = Math_fround(HEAPF32[$482>>2]);
    $484 = Math_fround(HEAPF32[$closB>>2]);
    $485 = (($closB) + 4|0);
    $486 = Math_fround(HEAPF32[$485>>2]);
    $487 = (($closB) + 8|0);
    $488 = Math_fround(HEAPF32[$487>>2]);
    $489 = Math_fround($479 - $484);
    $490 = Math_fround($481 - $486);
    $491 = Math_fround($483 - $488);
    $492 = (Math_fround(Math_sqrt((Math_fround($311)))));
    $493 = Math_fround(Math_fround(1.0) / $492);
    $494 = Math_fround($489 * $493);
    $495 = Math_fround($490 * $493);
    $496 = Math_fround($491 * $493);
    if ($takeCoreShape) {
     $497 = (($a) + 64|0);
     $498 = HEAP32[$497>>2]|0;
     $499 = (($b) + 64|0);
     $500 = HEAP32[$499>>2]|0;
     $501 = ($498|0)==(0);
     $502 = $501 ? $8 : Math_fround(0.0);
     $503 = ($500|0)==(0);
     $504 = $503 ? $10 : Math_fround(0.0);
     $505 = Math_fround($502 + $504);
     $506 = Math_fround($494 * $502);
     $507 = Math_fround($495 * $502);
     $508 = Math_fround($496 * $502);
     $509 = Math_fround($479 - $506);
     $510 = Math_fround($481 - $507);
     $511 = Math_fround($483 - $508);
     HEAPF32[$contactA>>2] = $509;
     $512 = (($contactA) + 4|0);
     HEAPF32[$512>>2] = $510;
     $513 = (($contactA) + 8|0);
     HEAPF32[$513>>2] = $511;
     $514 = (($contactA) + 12|0);
     HEAPF32[$514>>2] = Math_fround(0.0);
     $515 = Math_fround($494 * $504);
     $516 = Math_fround($495 * $504);
     $517 = Math_fround($496 * $504);
     $518 = Math_fround($515 + $484);
     $519 = Math_fround($516 + $486);
     $520 = Math_fround($517 + $488);
     HEAPF32[$contactB>>2] = $518;
     $521 = (($contactB) + 4|0);
     HEAPF32[$521>>2] = $519;
     $522 = (($contactB) + 8|0);
     HEAPF32[$522>>2] = $520;
     $523 = (($contactB) + 12|0);
     HEAPF32[$523>>2] = Math_fround(0.0);
     $524 = Math_fround($492 - $505);
     HEAPF32[$penetrationDepth>>2] = $524;
     $525 = (($penetrationDepth) + 4|0);
     ;HEAP32[$525+0>>2]=HEAP32[$$sroa$1290+0>>2]|0;HEAP32[$525+4>>2]=HEAP32[$$sroa$1290+4>>2]|0;HEAP32[$525+8>>2]=HEAP32[$$sroa$1290+8>>2]|0;
    } else {
     $526 = Math_fround($8 * $494);
     $527 = Math_fround($8 * $495);
     $528 = Math_fround($8 * $496);
     $529 = Math_fround($479 - $526);
     $530 = Math_fround($481 - $527);
     $531 = Math_fround($483 - $528);
     HEAPF32[$contactA>>2] = $529;
     $532 = (($contactA) + 4|0);
     HEAPF32[$532>>2] = $530;
     $533 = (($contactA) + 8|0);
     HEAPF32[$533>>2] = $531;
     $534 = (($contactA) + 12|0);
     HEAPF32[$534>>2] = Math_fround(0.0);
     $535 = Math_fround($10 * $494);
     $536 = Math_fround($10 * $495);
     $537 = Math_fround($10 * $496);
     $538 = Math_fround($535 + $484);
     $539 = Math_fround($536 + $486);
     $540 = Math_fround($537 + $488);
     HEAPF32[$contactB>>2] = $538;
     $541 = (($contactB) + 4|0);
     HEAPF32[$541>>2] = $539;
     $542 = (($contactB) + 8|0);
     HEAPF32[$542>>2] = $540;
     $543 = (($contactB) + 12|0);
     HEAPF32[$543>>2] = Math_fround(0.0);
     $544 = Math_fround($492 - $17);
     HEAPF32[$penetrationDepth>>2] = $544;
     $545 = (($penetrationDepth) + 4|0);
     ;HEAP32[$545+0>>2]=HEAP32[$$sroa$1282+0>>2]|0;HEAP32[$545+4>>2]=HEAP32[$$sroa$1282+4>>2]|0;HEAP32[$545+8>>2]=HEAP32[$$sroa$1282+8>>2]|0;
    }
    HEAPF32[$normal>>2] = $494;
    $546 = (($normal) + 4|0);
    HEAPF32[$546>>2] = $495;
    $547 = (($normal) + 8|0);
    HEAPF32[$547>>2] = $496;
    $548 = (($normal) + 12|0);
    HEAPF32[$548>>2] = Math_fround(0.0);
    $549 = $20 >= $311;
    $$ = $549 ? 1 : 3;
    $$0 = $$;
    STACKTOP = sp;return ($$0|0);
   }
   $326 = ($aIndices|0)==(0|0);
   if (!($326)) {
    $327 = $301&255;
    HEAP8[$_size>>0] = $327;
    $328 = ($301|0)==(0);
    if (!($328)) {
     $i$01$i142 = 0;
     while(1) {
      $329 = (($aInd) + ($i$01$i142<<2)|0);
      $330 = HEAP32[$329>>2]|0;
      $331 = $330&255;
      $332 = (($aIndices) + ($i$01$i142)|0);
      HEAP8[$332>>0] = $331;
      $333 = (($bInd) + ($i$01$i142<<2)|0);
      $334 = HEAP32[$333>>2]|0;
      $335 = $334&255;
      $336 = (($bIndices) + ($i$01$i142)|0);
      HEAP8[$336>>0] = $335;
      $337 = (($i$01$i142) + 1)|0;
      $exitcond$i143 = ($337|0)==($301|0);
      if ($exitcond$i143) {
       break;
      } else {
       $i$01$i142 = $337;
      }
     }
    }
   }
   $not$ = $323 ^ 1;
   $$$1070 = $325 & $not$;
   if (!($$$1070)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $338 = (Math_fround(Math_sqrt((Math_fround($311)))));
   $339 = Math_fround(Math_fround(1.0) / $338);
   $340 = Math_fround($240 * $339);
   $341 = Math_fround($242 * $339);
   $342 = Math_fround($244 * $339);
   HEAPF32[$normal>>2] = $340;
   $343 = (($normal) + 4|0);
   HEAPF32[$343>>2] = $341;
   $344 = (($normal) + 8|0);
   HEAPF32[$344>>2] = $342;
   $345 = (($normal) + 12|0);
   HEAPF32[$345>>2] = Math_fround(0.0);
   if ($takeCoreShape) {
    $346 = (($a) + 64|0);
    $347 = HEAP32[$346>>2]|0;
    $348 = (($b) + 64|0);
    $349 = HEAP32[$348>>2]|0;
    $350 = ($347|0)==(0);
    $351 = $350 ? $8 : Math_fround(0.0);
    $352 = ($349|0)==(0);
    $353 = $352 ? $10 : Math_fround(0.0);
    $354 = Math_fround($351 + $353);
    $355 = Math_fround(HEAPF32[$closA>>2]);
    $356 = Math_fround(HEAPF32[$231>>2]);
    $357 = Math_fround(HEAPF32[$232>>2]);
    $358 = Math_fround($340 * $351);
    $359 = Math_fround($341 * $351);
    $360 = Math_fround($342 * $351);
    $361 = Math_fround($355 - $358);
    $362 = Math_fround($356 - $359);
    $363 = Math_fround($357 - $360);
    HEAPF32[$contactA>>2] = $361;
    $364 = (($contactA) + 4|0);
    HEAPF32[$364>>2] = $362;
    $365 = (($contactA) + 8|0);
    HEAPF32[$365>>2] = $363;
    $366 = (($contactA) + 12|0);
    HEAPF32[$366>>2] = Math_fround(0.0);
    $367 = Math_fround(HEAPF32[$closB>>2]);
    $368 = Math_fround(HEAPF32[$234>>2]);
    $369 = Math_fround(HEAPF32[$235>>2]);
    $370 = Math_fround($340 * $353);
    $371 = Math_fround($341 * $353);
    $372 = Math_fround($342 * $353);
    $373 = Math_fround($370 + $367);
    $374 = Math_fround($371 + $368);
    $375 = Math_fround($372 + $369);
    HEAPF32[$contactB>>2] = $373;
    $376 = (($contactB) + 4|0);
    HEAPF32[$376>>2] = $374;
    $377 = (($contactB) + 8|0);
    HEAPF32[$377>>2] = $375;
    $378 = (($contactB) + 12|0);
    HEAPF32[$378>>2] = Math_fround(0.0);
    $379 = Math_fround($338 - $354);
    HEAPF32[$penetrationDepth>>2] = $379;
    $380 = (($penetrationDepth) + 4|0);
    ;HEAP32[$380+0>>2]=HEAP32[$$sroa$1368+0>>2]|0;HEAP32[$380+4>>2]=HEAP32[$$sroa$1368+4>>2]|0;HEAP32[$380+8>>2]=HEAP32[$$sroa$1368+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $381 = Math_fround(HEAPF32[$closA>>2]);
    $382 = Math_fround(HEAPF32[$231>>2]);
    $383 = Math_fround(HEAPF32[$232>>2]);
    $384 = Math_fround($8 * $340);
    $385 = Math_fround($8 * $341);
    $386 = Math_fround($8 * $342);
    $387 = Math_fround($381 - $384);
    $388 = Math_fround($382 - $385);
    $389 = Math_fround($383 - $386);
    HEAPF32[$contactA>>2] = $387;
    $390 = (($contactA) + 4|0);
    HEAPF32[$390>>2] = $388;
    $391 = (($contactA) + 8|0);
    HEAPF32[$391>>2] = $389;
    $392 = (($contactA) + 12|0);
    HEAPF32[$392>>2] = Math_fround(0.0);
    $393 = Math_fround(HEAPF32[$closB>>2]);
    $394 = Math_fround(HEAPF32[$234>>2]);
    $395 = Math_fround(HEAPF32[$235>>2]);
    $396 = Math_fround($10 * $340);
    $397 = Math_fround($10 * $341);
    $398 = Math_fround($10 * $342);
    $399 = Math_fround($396 + $393);
    $400 = Math_fround($397 + $394);
    $401 = Math_fround($398 + $395);
    HEAPF32[$contactB>>2] = $399;
    $402 = (($contactB) + 4|0);
    HEAPF32[$402>>2] = $400;
    $403 = (($contactB) + 8|0);
    HEAPF32[$403>>2] = $401;
    $404 = (($contactB) + 12|0);
    HEAPF32[$404>>2] = Math_fround(0.0);
    $405 = Math_fround($338 - $17);
    HEAPF32[$penetrationDepth>>2] = $405;
    $406 = (($penetrationDepth) + 4|0);
    ;HEAP32[$406+0>>2]=HEAP32[$$sroa$1358+0>>2]|0;HEAP32[$406+4>>2]=HEAP32[$$sroa$1358+4>>2]|0;HEAP32[$406+8>>2]=HEAP32[$$sroa$1358+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $196 = HEAP32[$size>>2]|0;
   $552 = $196;
  }
 } while(0);
 $550 = ($aIndices|0)==(0|0);
 if (!($550)) {
  $551 = $552&255;
  HEAP8[$_size>>0] = $551;
  $553 = ($552|0)==(0);
  if (!($553)) {
   $i$01$i = 0;
   while(1) {
    $554 = (($aInd) + ($i$01$i<<2)|0);
    $555 = HEAP32[$554>>2]|0;
    $556 = $555&255;
    $557 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$557>>0] = $556;
    $558 = (($bInd) + ($i$01$i<<2)|0);
    $559 = HEAP32[$558>>2]|0;
    $560 = $559&255;
    $561 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$561>>0] = $560;
    $562 = (($i$01$i) + 1)|0;
    $exitcond$i = ($562|0)==($552|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $562;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_10ShrunkBoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$ = 0, $$$1070 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i246 = Math_fround(0), $$$i10571104 = Math_fround(0), $$$i204 = Math_fround(0), $$$i245 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i247 = Math_fround(0), $$0 = 0, $$1066 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i$i = 0, $$in1$i$i256 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i$i = 0, $$in2$i$i258 = 0;
 var $$ph1078 = Math_fround(0), $$ph1079 = 0, $$ph1083 = Math_fround(0), $$ph1084 = Math_fround(0), $$ph1085 = Math_fround(0), $$pre = Math_fround(0), $$pre1127 = Math_fround(0), $$pre1128 = Math_fround(0), $$sroa$1282 = 0, $$sroa$1290 = 0, $$sroa$1356 = 0, $$sroa$1358 = 0, $$sroa$1368 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0);
 var $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0;
 var $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0;
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0);
 var $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0);
 var $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0;
 var $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0);
 var $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0);
 var $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0;
 var $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = 0, $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0);
 var $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = Math_fround(0), $449 = 0, $45 = 0, $450 = 0, $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0);
 var $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = 0;
 var $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0);
 var $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = 0, $524 = 0, $525 = 0, $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = 0, $534 = 0, $535 = Math_fround(0), $536 = 0;
 var $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = 0, $544 = 0, $545 = 0, $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = 0, $553 = 0, $554 = 0;
 var $555 = Math_fround(0), $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0;
 var $573 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $a$pn3$i$i = 0, $a$pn3$i$i255 = 0, $aInd = 0, $b$a$i$i = 0, $b$a$i$i$i = 0, $b$a$i$i253 = 0, $b$a$i218 = 0, $b$a5$i$i = 0, $b$a5$i$i257 = 0, $bInd = 0;
 var $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i143 = 0, $exitcond$i64 = 0, $i$01$i = 0, $i$01$i142 = 0, $i$01$i63 = 0, $i$01106 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp1074 = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportA = 0;
 var $supportB = 0, $tempClosA = 0, $tempClosB = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 592|0;
 $0 = sp + 80|0;
 $1 = sp + 384|0;
 $2 = sp + 432|0;
 $3 = sp + 368|0;
 $zeroV = sp + 448|0;
 $closA = sp + 416|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 556|0;
 $minDist$sroa$1 = sp + 544|0;
 $tempClosA = sp + 352|0;
 $tempClosB = sp + 64|0;
 $Q = sp;
 $A = sp + 128|0;
 $B = sp + 288|0;
 $aInd = sp + 528|0;
 $bInd = sp + 568|0;
 $supportA = sp + 112|0;
 $supportB = sp + 192|0;
 $support = sp + 208|0;
 $size = sp + 488|0;
 $lastQ = sp + 224|0;
 $lastA = sp + 240|0;
 $lastB = sp + 256|0;
 $4 = sp + 272|0;
 $$sroa$1368 = sp + 476|0;
 $$sroa$1358 = sp + 464|0;
 $5 = sp + 96|0;
 $$sroa$1356 = sp + 516|0;
 $$sroa$1290 = sp + 492|0;
 $$sroa$1282 = sp + 504|0;
 $6 = Math_fround(HEAPF32[$_contactDist>>2]);
 $7 = (($a) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($b) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i245 = $15 ? $14 : $12;
 $16 = Math_fround($$$i245 * Math_fround(0.100000001490116119385));
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $17 = Math_fround($8 + $10);
 $18 = Math_fround($6 + $17);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 ;HEAP32[$tempClosA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$tempClosB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $19 = Math_fround($16 * $16);
 $20 = Math_fround($18 * $18);
 ;HEAP32[$supportA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$supportB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$support+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAP32[$size>>2] = 0;
 $21 = HEAP8[$_size>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $173 = Math_fround(HEAPF32[$a>>2]);
  $174 = (($a) + 4|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (($a) + 8|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround(HEAPF32[$b>>2]);
  $179 = (($b) + 4|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = (($b) + 8|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = Math_fround($173 - $178);
  $184 = Math_fround($175 - $180);
  $185 = Math_fround($177 - $182);
  $186 = Math_fround($183 * $183);
  $187 = Math_fround($184 * $184);
  $188 = Math_fround($186 + $187);
  $189 = Math_fround($185 * $185);
  $190 = Math_fround($188 + $189);
  $191 = $190 > Math_fround(0.0);
  HEAPF32[$3>>2] = $183;
  $192 = (($3) + 4|0);
  HEAPF32[$192>>2] = $184;
  $193 = (($3) + 8|0);
  HEAPF32[$193>>2] = $185;
  $194 = (($3) + 12|0);
  HEAPF32[$194>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = Math_fround(1.0);
  $195 = (($2) + 4|0);
  HEAPF32[$195>>2] = Math_fround(0.0);
  $196 = (($2) + 8|0);
  HEAPF32[$196>>2] = Math_fround(0.0);
  $197 = (($2) + 12|0);
  HEAPF32[$197>>2] = Math_fround(0.0);
  $b$a$i218 = $191 ? $3 : $2;
  $198 = Math_fround(HEAPF32[$b$a$i218>>2]);
  $$in1$i = (($b$a$i218) + 4|0);
  $199 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i218) + 8|0);
  $200 = Math_fround(HEAPF32[$$in2$i>>2]);
  $$ph1078 = Math_fround(3.40282346638528859812E+38);$$ph1079 = 1;$$ph1083 = $200;$$ph1084 = $199;$$ph1085 = $198;
 } else {
  ;HEAP32[$lastQ+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$zeroV+12>>2]|0;
  $23 = (($a) + 96|0);
  $24 = (($b) + 144|0);
  $25 = (($b) + 148|0);
  $26 = (($b) + 152|0);
  $27 = (($1) + 4|0);
  $28 = (($1) + 8|0);
  $29 = (($1) + 12|0);
  $30 = (($0) + 4|0);
  $31 = (($0) + 8|0);
  $32 = (($0) + 12|0);
  $33 = (($supportB) + 4|0);
  $34 = (($supportB) + 8|0);
  $35 = (($supportB) + 12|0);
  $36 = (($supportA) + 4|0);
  $37 = (($supportA) + 8|0);
  $38 = (($support) + 4|0);
  $39 = (($support) + 8|0);
  $40 = (($support) + 12|0);
  $$pre = Math_fround(HEAPF32[$24>>2]);
  $$pre1127 = Math_fround(HEAPF32[$25>>2]);
  $$pre1128 = Math_fround(HEAPF32[$26>>2]);
  $76 = 0;$i$01106 = 0;
  while(1) {
   $41 = (($aIndices) + ($i$01106)|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = $42&255;
   $44 = (($aInd) + ($i$01106<<2)|0);
   HEAP32[$44>>2] = $43;
   $45 = (($bIndices) + ($i$01106)|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = $46&255;
   $48 = (($bInd) + ($i$01106<<2)|0);
   HEAP32[$48>>2] = $47;
   $49 = (1 - ($43))|0;
   $50 = (($23) + ($49<<4)|0);
   ;HEAP32[$supportA+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$50+12>>2]|0;
   $51 = Math_fround($$pre - $10);
   $52 = Math_fround($$pre1127 - $10);
   $53 = Math_fround($$pre1128 - $10);
   $54 = (549664 + ($47<<4)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ((549664 + ($47<<4)|0) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ((549664 + ($47<<4)|0) + 8|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = Math_fround(-$51);
   $61 = Math_fround(-$52);
   $62 = Math_fround(-$53);
   HEAPF32[$1>>2] = $51;
   HEAPF32[$27>>2] = $52;
   HEAPF32[$28>>2] = $53;
   HEAPF32[$29>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $60;
   HEAPF32[$30>>2] = $61;
   HEAPF32[$31>>2] = $62;
   HEAPF32[$32>>2] = Math_fround(0.0);
   $63 = ($55|0)==(0);
   $b$a$i$i253 = $63 ? $0 : $1;
   $64 = Math_fround(HEAPF32[$b$a$i$i253>>2]);
   $65 = ($57|0)==(0);
   $a$pn3$i$i255 = $65 ? $0 : $1;
   $$in1$i$i256 = (($a$pn3$i$i255) + 4|0);
   $66 = Math_fround(HEAPF32[$$in1$i$i256>>2]);
   $67 = ($59|0)==(0);
   $b$a5$i$i257 = $67 ? $0 : $1;
   $$in2$i$i258 = (($b$a5$i$i257) + 8|0);
   $68 = Math_fround(HEAPF32[$$in2$i$i258>>2]);
   HEAPF32[$supportB>>2] = $64;
   HEAPF32[$33>>2] = $66;
   HEAPF32[$34>>2] = $68;
   HEAPF32[$35>>2] = Math_fround(0.0);
   $69 = Math_fround(HEAPF32[$supportA>>2]);
   $70 = Math_fround(HEAPF32[$36>>2]);
   $71 = Math_fround(HEAPF32[$37>>2]);
   $72 = Math_fround($69 - $64);
   $73 = Math_fround($70 - $66);
   $74 = Math_fround($71 - $68);
   HEAPF32[$support>>2] = $72;
   HEAPF32[$38>>2] = $73;
   HEAPF32[$39>>2] = $74;
   HEAPF32[$40>>2] = Math_fround(0.0);
   $75 = (($A) + ($76<<4)|0);
   ;HEAP32[$lastA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$supportA+12>>2]|0;
   ;HEAP32[$75+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$supportA+12>>2]|0;
   $77 = (($B) + ($76<<4)|0);
   ;HEAP32[$lastB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$supportB+12>>2]|0;
   ;HEAP32[$77+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$supportB+12>>2]|0;
   $78 = (($76) + 1)|0;
   $79 = (($Q) + ($76<<4)|0);
   ;HEAP32[$lastQ+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$support+12>>2]|0;
   ;HEAP32[$79+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$support+12>>2]|0;
   $80 = (($i$01106) + 1)|0;
   $81 = $21&255;
   $82 = ($80>>>0)<($81>>>0);
   if ($82) {
    $76 = $78;$i$01106 = $80;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $78;
  do {
   if ((($76|0) == 2)) {
    $161 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$161,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($76|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($76|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($76|0) == 1)) {
    $83 = Math_fround(HEAPF32[$Q>>2]);
    $84 = (($Q) + 4|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = (($Q) + 8|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = Math_fround(HEAPF32[$lastQ>>2]);
    $89 = (($lastQ) + 4|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = (($lastQ) + 8|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = Math_fround($88 - $83);
    $94 = Math_fround($90 - $85);
    $95 = Math_fround($92 - $87);
    $96 = Math_fround($93 * $93);
    $97 = Math_fround($94 * $94);
    $98 = Math_fround($96 + $97);
    $99 = Math_fround($95 * $95);
    $100 = Math_fround($98 + $99);
    $101 = $100 == Math_fround(0.0);
    if ($101) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $102 = Math_fround($85 * $94);
     $103 = Math_fround(-$102);
     $104 = Math_fround($83 * $93);
     $105 = Math_fround($103 - $104);
     $106 = Math_fround($87 * $95);
     $107 = Math_fround($105 - $106);
     $108 = Math_fround(HEAPF32[$lastA>>2]);
     $109 = (($lastA) + 4|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = (($lastA) + 8|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = Math_fround(HEAPF32[$A>>2]);
     $114 = (($A) + 4|0);
     $115 = Math_fround(HEAPF32[$114>>2]);
     $116 = (($A) + 8|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = Math_fround($108 - $113);
     $119 = Math_fround($110 - $115);
     $120 = Math_fround($112 - $117);
     $121 = Math_fround(HEAPF32[$lastB>>2]);
     $122 = (($lastB) + 4|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     $124 = (($lastB) + 8|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     $126 = Math_fround(HEAPF32[$B>>2]);
     $127 = (($B) + 4|0);
     $128 = Math_fround(HEAPF32[$127>>2]);
     $129 = (($B) + 8|0);
     $130 = Math_fround(HEAPF32[$129>>2]);
     $131 = Math_fround($121 - $126);
     $132 = Math_fround($123 - $128);
     $133 = Math_fround($125 - $130);
     $134 = Math_fround($107 / $100);
     $135 = $134 > Math_fround(1.0);
     $$$i$i$i246 = $135 ? Math_fround(1.0) : $134;
     $136 = $$$i$i$i246 > Math_fround(0.0);
     $$$i8$i$i247 = $136 ? $$$i$i$i246 : Math_fround(0.0);
     $137 = Math_fround($118 * $$$i8$i$i247);
     $138 = Math_fround($119 * $$$i8$i$i247);
     $139 = Math_fround($120 * $$$i8$i$i247);
     $140 = Math_fround($113 + $137);
     $141 = Math_fround($115 + $138);
     $142 = Math_fround($117 + $139);
     $143 = Math_fround($131 * $$$i8$i$i247);
     $144 = Math_fround($132 * $$$i8$i$i247);
     $145 = Math_fround($133 * $$$i8$i$i247);
     $146 = Math_fround($126 + $143);
     $147 = Math_fround($128 + $144);
     $148 = Math_fround($130 + $145);
     HEAPF32[$closA>>2] = $140;
     $149 = (($closA) + 4|0);
     HEAPF32[$149>>2] = $141;
     $150 = (($closA) + 8|0);
     HEAPF32[$150>>2] = $142;
     $151 = (($closA) + 12|0);
     HEAPF32[$151>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $146;
     $152 = (($closB) + 4|0);
     HEAPF32[$152>>2] = $147;
     $153 = (($closB) + 8|0);
     HEAPF32[$153>>2] = $148;
     $154 = (($closB) + 12|0);
     HEAPF32[$154>>2] = Math_fround(0.0);
     $155 = Math_fround($140 - $146);
     $156 = Math_fround($141 - $147);
     $157 = Math_fround($142 - $148);
     HEAPF32[$4>>2] = $155;
     $158 = (($4) + 4|0);
     HEAPF32[$158>>2] = $156;
     $159 = (($4) + 8|0);
     HEAPF32[$159>>2] = $157;
     $160 = (($4) + 12|0);
     HEAPF32[$160>>2] = Math_fround(0.0);
     break;
    }
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  $162 = Math_fround(HEAPF32[$4>>2]);
  $163 = (($4) + 4|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = (($4) + 8|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = Math_fround($162 * $162);
  $168 = Math_fround($164 * $164);
  $169 = Math_fround($167 + $168);
  $170 = Math_fround($166 * $166);
  $171 = Math_fround($169 + $170);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $172 = $171 > $19;
  $$ph1078 = $171;$$ph1079 = $172;$$ph1083 = $166;$$ph1084 = $164;$$ph1085 = $162;
 }
 do {
  if ($$ph1079) {
   $202 = (($a) + 96|0);
   $203 = (($a) + 96|0);
   $204 = (($a) + 100|0);
   $205 = (($a) + 104|0);
   $206 = (($a) + 112|0);
   $207 = (($a) + 112|0);
   $208 = (($a) + 116|0);
   $209 = (($a) + 120|0);
   $210 = (($supportA) + 4|0);
   $211 = (($supportA) + 8|0);
   $212 = (($supportA) + 12|0);
   $213 = (($b) + 144|0);
   $214 = (($b) + 148|0);
   $215 = (($b) + 152|0);
   $216 = (($1) + 4|0);
   $217 = (($1) + 8|0);
   $218 = (($1) + 12|0);
   $219 = (($0) + 4|0);
   $220 = (($0) + 8|0);
   $221 = (($0) + 12|0);
   $222 = (($supportB) + 4|0);
   $223 = (($supportB) + 8|0);
   $224 = (($supportB) + 12|0);
   $225 = (($support) + 4|0);
   $226 = (($support) + 8|0);
   $227 = (($support) + 12|0);
   $228 = (($a) + 48|0);
   $229 = (($b) + 48|0);
   $230 = (($5) + 4|0);
   $231 = (($5) + 8|0);
   $232 = (($Q) + 4|0);
   $233 = (($Q) + 8|0);
   $234 = (($A) + 4|0);
   $235 = (($A) + 8|0);
   $236 = (($B) + 4|0);
   $237 = (($B) + 8|0);
   $238 = (($closA) + 4|0);
   $239 = (($closA) + 8|0);
   $240 = (($closA) + 12|0);
   $241 = (($closB) + 4|0);
   $242 = (($closB) + 8|0);
   $243 = (($closB) + 12|0);
   $244 = (($5) + 12|0);
   $245 = (($Q) + 16|0);
   $$$i10571104 = $6;$247 = $$ph1085;$249 = $$ph1084;$251 = $$ph1083;$322 = $$ph1078;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    ;HEAP32[$tempClosA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$closA+12>>2]|0;
    ;HEAP32[$tempClosB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$closB+12>>2]|0;
    $246 = Math_fround(-$247);
    $248 = Math_fround(-$249);
    $250 = Math_fround(-$251);
    $252 = HEAP32[$size>>2]|0;
    $253 = (($aInd) + ($252<<2)|0);
    $254 = Math_fround(HEAPF32[$203>>2]);
    $255 = Math_fround(HEAPF32[$204>>2]);
    $256 = Math_fround(HEAPF32[$205>>2]);
    $257 = Math_fround($254 * $246);
    $258 = Math_fround($255 * $248);
    $259 = Math_fround($257 + $258);
    $260 = Math_fround($256 * $250);
    $261 = Math_fround($259 + $260);
    $262 = Math_fround(HEAPF32[$207>>2]);
    $263 = Math_fround(HEAPF32[$208>>2]);
    $264 = Math_fround(HEAPF32[$209>>2]);
    $265 = Math_fround($262 * $246);
    $266 = Math_fround($263 * $248);
    $267 = Math_fround($265 + $266);
    $268 = Math_fround($264 * $250);
    $269 = Math_fround($267 + $268);
    $270 = $261 > $269;
    $271 = $270&1;
    HEAP32[$253>>2] = $271;
    ;HEAP32[$1+0>>2]=HEAP32[$202+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$202+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$202+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$202+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$206+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$206+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$206+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$206+12>>2]|0;
    $b$a$i$i$i = $270 ? $1 : $0;
    $272 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
    $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
    $273 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
    $274 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    $275 = (($A) + ($252<<4)|0);
    HEAPF32[$275>>2] = $272;
    $276 = ((($A) + ($252<<4)|0) + 4|0);
    HEAPF32[$276>>2] = $273;
    $277 = ((($A) + ($252<<4)|0) + 8|0);
    HEAPF32[$277>>2] = $274;
    $278 = ((($A) + ($252<<4)|0) + 12|0);
    HEAPF32[$278>>2] = Math_fround(0.0);
    HEAPF32[$supportA>>2] = $272;
    HEAPF32[$210>>2] = $273;
    HEAPF32[$211>>2] = $274;
    HEAPF32[$212>>2] = Math_fround(0.0);
    $279 = (($bInd) + ($252<<2)|0);
    $280 = Math_fround(HEAPF32[$213>>2]);
    $281 = Math_fround(HEAPF32[$214>>2]);
    $282 = Math_fround(HEAPF32[$215>>2]);
    $283 = Math_fround(HEAPF32[$9>>2]);
    $284 = Math_fround($280 - $283);
    $285 = Math_fround($281 - $283);
    $286 = Math_fround($282 - $283);
    $287 = $247 > Math_fround(0.0);
    $288 = $249 > Math_fround(0.0);
    $289 = $288 << 31 >> 31;
    $290 = $251 > Math_fround(0.0);
    $291 = $290 << 31 >> 31;
    $292 = $287&1;
    $293 = $289 << 1;
    $294 = $293 & 2;
    $295 = $291 << 2;
    $296 = $295 & 4;
    $297 = $296 | $292;
    $298 = $297 | $294;
    HEAP32[$279>>2] = $298;
    $299 = Math_fround(-$284);
    $300 = Math_fround(-$285);
    $301 = Math_fround(-$286);
    HEAPF32[$1>>2] = $284;
    HEAPF32[$216>>2] = $285;
    HEAPF32[$217>>2] = $286;
    HEAPF32[$218>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $299;
    HEAPF32[$219>>2] = $300;
    HEAPF32[$220>>2] = $301;
    HEAPF32[$221>>2] = Math_fround(0.0);
    $b$a$i$i = $287 ? $1 : $0;
    $302 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $288 ? $1 : $0;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $303 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $290 ? $1 : $0;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $304 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    $305 = (($B) + ($252<<4)|0);
    HEAPF32[$305>>2] = $302;
    $306 = ((($B) + ($252<<4)|0) + 4|0);
    HEAPF32[$306>>2] = $303;
    $307 = ((($B) + ($252<<4)|0) + 8|0);
    HEAPF32[$307>>2] = $304;
    $308 = ((($B) + ($252<<4)|0) + 12|0);
    HEAPF32[$308>>2] = Math_fround(0.0);
    HEAPF32[$supportB>>2] = $302;
    HEAPF32[$222>>2] = $303;
    HEAPF32[$223>>2] = $304;
    HEAPF32[$224>>2] = Math_fround(0.0);
    $309 = Math_fround($272 - $302);
    $310 = Math_fround($273 - $303);
    $311 = Math_fround($274 - $304);
    HEAPF32[$support>>2] = $309;
    HEAPF32[$225>>2] = $310;
    HEAPF32[$226>>2] = $311;
    HEAPF32[$227>>2] = Math_fround(0.0);
    $312 = HEAP32[$size>>2]|0;
    $313 = (($312) + 1)|0;
    HEAP32[$size>>2] = $313;
    $314 = (($Q) + ($312<<4)|0);
    ;HEAP32[$314+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$314+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$314+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$314+12>>2]=HEAP32[$support+12>>2]|0;
    $315 = Math_fround(HEAPF32[$228>>2]);
    $316 = Math_fround(HEAPF32[$229>>2]);
    $317 = $315 > $316;
    $$$i204 = $317 ? $315 : $316;
    $318 = $$$i10571104 > $$$i204;
    $$$i = $318 ? $$$i10571104 : $$$i204;
    $319 = Math_fround($17 + $$$i);
    $320 = Math_fround($319 * $319);
    $321 = Math_fround($322 * $320);
    $323 = Math_fround($247 * $309);
    $324 = Math_fround($249 * $310);
    $325 = Math_fround($323 + $324);
    $326 = Math_fround($251 * $311);
    $327 = Math_fround($325 + $326);
    $328 = Math_fround($327 * $327);
    $329 = $327 > Math_fround(0.0);
    $330 = $328 > $321;
    if ($329) {
     $phitmp1074 = $330 ^ 1;
     $334 = $330;$336 = $phitmp1074;
    } else {
     $334 = 0;$336 = 1;
    }
    $331 = Math_fround($322 - $327);
    $332 = Math_fround($19 * $322);
    $333 = $332 >= $331;
    $brmerge$demorgan = $333 | $334;
    if ($brmerge$demorgan) {
     $335 = $336 ^ 1;
     $$1066 = $333 | $335;
     if ($$1066) {
      break;
     }
    }
    do {
     if ((($312|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support,$supportA,$supportB,$size,$closA,$closB);
     } else if ((($312|0) == 1)) {
      $418 = Math_fround(HEAPF32[$Q>>2]);
      $419 = Math_fround(HEAPF32[$232>>2]);
      $420 = Math_fround(HEAPF32[$233>>2]);
      $421 = Math_fround($309 - $418);
      $422 = Math_fround($310 - $419);
      $423 = Math_fround($311 - $420);
      $424 = Math_fround($421 * $421);
      $425 = Math_fround($422 * $422);
      $426 = Math_fround($424 + $425);
      $427 = Math_fround($423 * $423);
      $428 = Math_fround($426 + $427);
      $429 = $428 == Math_fround(0.0);
      if ($429) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $430 = Math_fround($419 * $422);
       $431 = Math_fround(-$430);
       $432 = Math_fround($418 * $421);
       $433 = Math_fround($431 - $432);
       $434 = Math_fround($420 * $423);
       $435 = Math_fround($433 - $434);
       $436 = Math_fround(HEAPF32[$A>>2]);
       $437 = Math_fround(HEAPF32[$234>>2]);
       $438 = Math_fround(HEAPF32[$235>>2]);
       $439 = Math_fround($272 - $436);
       $440 = Math_fround($273 - $437);
       $441 = Math_fround($274 - $438);
       $442 = Math_fround(HEAPF32[$B>>2]);
       $443 = Math_fround(HEAPF32[$236>>2]);
       $444 = Math_fround(HEAPF32[$237>>2]);
       $445 = Math_fround($302 - $442);
       $446 = Math_fround($303 - $443);
       $447 = Math_fround($304 - $444);
       $448 = Math_fround($435 / $428);
       $449 = $448 > Math_fround(1.0);
       $$$i$i$i = $449 ? Math_fround(1.0) : $448;
       $450 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $450 ? $$$i$i$i : Math_fround(0.0);
       $451 = Math_fround($439 * $$$i8$i$i);
       $452 = Math_fround($440 * $$$i8$i$i);
       $453 = Math_fround($441 * $$$i8$i$i);
       $454 = Math_fround($436 + $451);
       $455 = Math_fround($437 + $452);
       $456 = Math_fround($438 + $453);
       $457 = Math_fround($445 * $$$i8$i$i);
       $458 = Math_fround($446 * $$$i8$i$i);
       $459 = Math_fround($447 * $$$i8$i$i);
       $460 = Math_fround($442 + $457);
       $461 = Math_fround($443 + $458);
       $462 = Math_fround($444 + $459);
       HEAPF32[$closA>>2] = $454;
       HEAPF32[$238>>2] = $455;
       HEAPF32[$239>>2] = $456;
       HEAPF32[$240>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $460;
       HEAPF32[$241>>2] = $461;
       HEAPF32[$242>>2] = $462;
       HEAPF32[$243>>2] = Math_fround(0.0);
       $463 = Math_fround($454 - $460);
       $464 = Math_fround($455 - $461);
       $465 = Math_fround($456 - $462);
       HEAPF32[$5>>2] = $463;
       HEAPF32[$230>>2] = $464;
       HEAPF32[$231>>2] = $465;
       HEAPF32[$244>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($312|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$245,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($312|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support+12>>2]|0;
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $466 = Math_fround(HEAPF32[$5>>2]);
    $467 = Math_fround(HEAPF32[$230>>2]);
    $468 = Math_fround(HEAPF32[$231>>2]);
    $469 = Math_fround($466 * $466);
    $470 = Math_fround($467 * $467);
    $471 = Math_fround($469 + $470);
    $472 = Math_fround($468 * $468);
    $473 = Math_fround($471 + $472);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1356+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1356+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1356+8>>2]|0;
    $474 = $322 > $473;
    $475 = $473 > $19;
    if (!($475)) {
     label = 38;
     break;
    }
    if ($474) {
     $$$i10571104 = $$$i;$247 = $466;$249 = $467;$251 = $468;$322 = $473;
    } else {
     label = 38;
     break;
    }
   }
   if ((label|0) == 38) {
    $476 = HEAP32[$size>>2]|0;
    if ($474) {
     $563 = $476;
     break;
    }
    $477 = (($476) + -1)|0;
    $478 = ($aIndices|0)==(0|0);
    if (!($478)) {
     $479 = $477&255;
     HEAP8[$_size>>0] = $479;
     $480 = ($477|0)==(0);
     if (!($480)) {
      $i$01$i63 = 0;
      while(1) {
       $481 = (($aInd) + ($i$01$i63<<2)|0);
       $482 = HEAP32[$481>>2]|0;
       $483 = $482&255;
       $484 = (($aIndices) + ($i$01$i63)|0);
       HEAP8[$484>>0] = $483;
       $485 = (($bInd) + ($i$01$i63<<2)|0);
       $486 = HEAP32[$485>>2]|0;
       $487 = $486&255;
       $488 = (($bIndices) + ($i$01$i63)|0);
       HEAP8[$488>>0] = $487;
       $489 = (($i$01$i63) + 1)|0;
       $exitcond$i64 = ($489|0)==($477|0);
       if ($exitcond$i64) {
        break;
       } else {
        $i$01$i63 = $489;
       }
      }
     }
    }
    ;HEAP32[$closA+0>>2]=HEAP32[$tempClosA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$tempClosA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$tempClosA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$tempClosA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$tempClosB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$tempClosB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$tempClosB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$tempClosB+12>>2]|0;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $490 = Math_fround(HEAPF32[$closA>>2]);
    $491 = (($closA) + 4|0);
    $492 = Math_fround(HEAPF32[$491>>2]);
    $493 = (($closA) + 8|0);
    $494 = Math_fround(HEAPF32[$493>>2]);
    $495 = Math_fround(HEAPF32[$closB>>2]);
    $496 = (($closB) + 4|0);
    $497 = Math_fround(HEAPF32[$496>>2]);
    $498 = (($closB) + 8|0);
    $499 = Math_fround(HEAPF32[$498>>2]);
    $500 = Math_fround($490 - $495);
    $501 = Math_fround($492 - $497);
    $502 = Math_fround($494 - $499);
    $503 = (Math_fround(Math_sqrt((Math_fround($322)))));
    $504 = Math_fround(Math_fround(1.0) / $503);
    $505 = Math_fround($500 * $504);
    $506 = Math_fround($501 * $504);
    $507 = Math_fround($502 * $504);
    if ($takeCoreShape) {
     $508 = (($a) + 64|0);
     $509 = HEAP32[$508>>2]|0;
     $510 = (($b) + 64|0);
     $511 = HEAP32[$510>>2]|0;
     $512 = ($509|0)==(0);
     $513 = $512 ? $8 : Math_fround(0.0);
     $514 = ($511|0)==(0);
     $515 = $514 ? $10 : Math_fround(0.0);
     $516 = Math_fround($513 + $515);
     $517 = Math_fround($505 * $513);
     $518 = Math_fround($506 * $513);
     $519 = Math_fround($507 * $513);
     $520 = Math_fround($490 - $517);
     $521 = Math_fround($492 - $518);
     $522 = Math_fround($494 - $519);
     HEAPF32[$contactA>>2] = $520;
     $523 = (($contactA) + 4|0);
     HEAPF32[$523>>2] = $521;
     $524 = (($contactA) + 8|0);
     HEAPF32[$524>>2] = $522;
     $525 = (($contactA) + 12|0);
     HEAPF32[$525>>2] = Math_fround(0.0);
     $526 = Math_fround($505 * $515);
     $527 = Math_fround($506 * $515);
     $528 = Math_fround($507 * $515);
     $529 = Math_fround($526 + $495);
     $530 = Math_fround($527 + $497);
     $531 = Math_fround($528 + $499);
     HEAPF32[$contactB>>2] = $529;
     $532 = (($contactB) + 4|0);
     HEAPF32[$532>>2] = $530;
     $533 = (($contactB) + 8|0);
     HEAPF32[$533>>2] = $531;
     $534 = (($contactB) + 12|0);
     HEAPF32[$534>>2] = Math_fround(0.0);
     $535 = Math_fround($503 - $516);
     HEAPF32[$penetrationDepth>>2] = $535;
     $536 = (($penetrationDepth) + 4|0);
     ;HEAP32[$536+0>>2]=HEAP32[$$sroa$1290+0>>2]|0;HEAP32[$536+4>>2]=HEAP32[$$sroa$1290+4>>2]|0;HEAP32[$536+8>>2]=HEAP32[$$sroa$1290+8>>2]|0;
    } else {
     $537 = Math_fround($8 * $505);
     $538 = Math_fround($8 * $506);
     $539 = Math_fround($8 * $507);
     $540 = Math_fround($490 - $537);
     $541 = Math_fround($492 - $538);
     $542 = Math_fround($494 - $539);
     HEAPF32[$contactA>>2] = $540;
     $543 = (($contactA) + 4|0);
     HEAPF32[$543>>2] = $541;
     $544 = (($contactA) + 8|0);
     HEAPF32[$544>>2] = $542;
     $545 = (($contactA) + 12|0);
     HEAPF32[$545>>2] = Math_fround(0.0);
     $546 = Math_fround($10 * $505);
     $547 = Math_fround($10 * $506);
     $548 = Math_fround($10 * $507);
     $549 = Math_fround($546 + $495);
     $550 = Math_fround($547 + $497);
     $551 = Math_fround($548 + $499);
     HEAPF32[$contactB>>2] = $549;
     $552 = (($contactB) + 4|0);
     HEAPF32[$552>>2] = $550;
     $553 = (($contactB) + 8|0);
     HEAPF32[$553>>2] = $551;
     $554 = (($contactB) + 12|0);
     HEAPF32[$554>>2] = Math_fround(0.0);
     $555 = Math_fround($503 - $17);
     HEAPF32[$penetrationDepth>>2] = $555;
     $556 = (($penetrationDepth) + 4|0);
     ;HEAP32[$556+0>>2]=HEAP32[$$sroa$1282+0>>2]|0;HEAP32[$556+4>>2]=HEAP32[$$sroa$1282+4>>2]|0;HEAP32[$556+8>>2]=HEAP32[$$sroa$1282+8>>2]|0;
    }
    HEAPF32[$normal>>2] = $505;
    $557 = (($normal) + 4|0);
    HEAPF32[$557>>2] = $506;
    $558 = (($normal) + 8|0);
    HEAPF32[$558>>2] = $507;
    $559 = (($normal) + 12|0);
    HEAPF32[$559>>2] = Math_fround(0.0);
    $560 = $20 >= $322;
    $$ = $560 ? 1 : 3;
    $$0 = $$;
    STACKTOP = sp;return ($$0|0);
   }
   $337 = ($aIndices|0)==(0|0);
   if (!($337)) {
    $338 = $312&255;
    HEAP8[$_size>>0] = $338;
    $339 = ($312|0)==(0);
    if (!($339)) {
     $i$01$i142 = 0;
     while(1) {
      $340 = (($aInd) + ($i$01$i142<<2)|0);
      $341 = HEAP32[$340>>2]|0;
      $342 = $341&255;
      $343 = (($aIndices) + ($i$01$i142)|0);
      HEAP8[$343>>0] = $342;
      $344 = (($bInd) + ($i$01$i142<<2)|0);
      $345 = HEAP32[$344>>2]|0;
      $346 = $345&255;
      $347 = (($bIndices) + ($i$01$i142)|0);
      HEAP8[$347>>0] = $346;
      $348 = (($i$01$i142) + 1)|0;
      $exitcond$i143 = ($348|0)==($312|0);
      if ($exitcond$i143) {
       break;
      } else {
       $i$01$i142 = $348;
      }
     }
    }
   }
   $not$ = $334 ^ 1;
   $$$1070 = $336 & $not$;
   if (!($$$1070)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $349 = (Math_fround(Math_sqrt((Math_fround($322)))));
   $350 = Math_fround(Math_fround(1.0) / $349);
   $351 = Math_fround($247 * $350);
   $352 = Math_fround($249 * $350);
   $353 = Math_fround($251 * $350);
   HEAPF32[$normal>>2] = $351;
   $354 = (($normal) + 4|0);
   HEAPF32[$354>>2] = $352;
   $355 = (($normal) + 8|0);
   HEAPF32[$355>>2] = $353;
   $356 = (($normal) + 12|0);
   HEAPF32[$356>>2] = Math_fround(0.0);
   if ($takeCoreShape) {
    $357 = (($a) + 64|0);
    $358 = HEAP32[$357>>2]|0;
    $359 = (($b) + 64|0);
    $360 = HEAP32[$359>>2]|0;
    $361 = ($358|0)==(0);
    $362 = $361 ? $8 : Math_fround(0.0);
    $363 = ($360|0)==(0);
    $364 = $363 ? $10 : Math_fround(0.0);
    $365 = Math_fround($362 + $364);
    $366 = Math_fround(HEAPF32[$closA>>2]);
    $367 = Math_fround(HEAPF32[$238>>2]);
    $368 = Math_fround(HEAPF32[$239>>2]);
    $369 = Math_fround($351 * $362);
    $370 = Math_fround($352 * $362);
    $371 = Math_fround($353 * $362);
    $372 = Math_fround($366 - $369);
    $373 = Math_fround($367 - $370);
    $374 = Math_fround($368 - $371);
    HEAPF32[$contactA>>2] = $372;
    $375 = (($contactA) + 4|0);
    HEAPF32[$375>>2] = $373;
    $376 = (($contactA) + 8|0);
    HEAPF32[$376>>2] = $374;
    $377 = (($contactA) + 12|0);
    HEAPF32[$377>>2] = Math_fround(0.0);
    $378 = Math_fround(HEAPF32[$closB>>2]);
    $379 = Math_fround(HEAPF32[$241>>2]);
    $380 = Math_fround(HEAPF32[$242>>2]);
    $381 = Math_fround($351 * $364);
    $382 = Math_fround($352 * $364);
    $383 = Math_fround($353 * $364);
    $384 = Math_fround($381 + $378);
    $385 = Math_fround($382 + $379);
    $386 = Math_fround($383 + $380);
    HEAPF32[$contactB>>2] = $384;
    $387 = (($contactB) + 4|0);
    HEAPF32[$387>>2] = $385;
    $388 = (($contactB) + 8|0);
    HEAPF32[$388>>2] = $386;
    $389 = (($contactB) + 12|0);
    HEAPF32[$389>>2] = Math_fround(0.0);
    $390 = Math_fround($349 - $365);
    HEAPF32[$penetrationDepth>>2] = $390;
    $391 = (($penetrationDepth) + 4|0);
    ;HEAP32[$391+0>>2]=HEAP32[$$sroa$1368+0>>2]|0;HEAP32[$391+4>>2]=HEAP32[$$sroa$1368+4>>2]|0;HEAP32[$391+8>>2]=HEAP32[$$sroa$1368+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $392 = Math_fround(HEAPF32[$closA>>2]);
    $393 = Math_fround(HEAPF32[$238>>2]);
    $394 = Math_fround(HEAPF32[$239>>2]);
    $395 = Math_fround($8 * $351);
    $396 = Math_fround($8 * $352);
    $397 = Math_fround($8 * $353);
    $398 = Math_fround($392 - $395);
    $399 = Math_fround($393 - $396);
    $400 = Math_fround($394 - $397);
    HEAPF32[$contactA>>2] = $398;
    $401 = (($contactA) + 4|0);
    HEAPF32[$401>>2] = $399;
    $402 = (($contactA) + 8|0);
    HEAPF32[$402>>2] = $400;
    $403 = (($contactA) + 12|0);
    HEAPF32[$403>>2] = Math_fround(0.0);
    $404 = Math_fround(HEAPF32[$closB>>2]);
    $405 = Math_fround(HEAPF32[$241>>2]);
    $406 = Math_fround(HEAPF32[$242>>2]);
    $407 = Math_fround($10 * $351);
    $408 = Math_fround($10 * $352);
    $409 = Math_fround($10 * $353);
    $410 = Math_fround($407 + $404);
    $411 = Math_fround($408 + $405);
    $412 = Math_fround($409 + $406);
    HEAPF32[$contactB>>2] = $410;
    $413 = (($contactB) + 4|0);
    HEAPF32[$413>>2] = $411;
    $414 = (($contactB) + 8|0);
    HEAPF32[$414>>2] = $412;
    $415 = (($contactB) + 12|0);
    HEAPF32[$415>>2] = Math_fround(0.0);
    $416 = Math_fround($349 - $17);
    HEAPF32[$penetrationDepth>>2] = $416;
    $417 = (($penetrationDepth) + 4|0);
    ;HEAP32[$417+0>>2]=HEAP32[$$sroa$1358+0>>2]|0;HEAP32[$417+4>>2]=HEAP32[$$sroa$1358+4>>2]|0;HEAP32[$417+8>>2]=HEAP32[$$sroa$1358+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $201 = HEAP32[$size>>2]|0;
   $563 = $201;
  }
 } while(0);
 $561 = ($aIndices|0)==(0|0);
 if (!($561)) {
  $562 = $563&255;
  HEAP8[$_size>>0] = $562;
  $564 = ($563|0)==(0);
  if (!($564)) {
   $i$01$i = 0;
   while(1) {
    $565 = (($aInd) + ($i$01$i<<2)|0);
    $566 = HEAP32[$565>>2]|0;
    $567 = $566&255;
    $568 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$568>>0] = $567;
    $569 = (($bInd) + ($i$01$i<<2)|0);
    $570 = HEAP32[$569>>2]|0;
    $571 = $570&255;
    $572 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$572>>0] = $571;
    $573 = (($i$01$i) + 1)|0;
    $exitcond$i = ($573|0)==($563|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $573;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$ = 0, $$$1060 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i250 = Math_fround(0), $$$i10471088 = Math_fround(0), $$$i204 = Math_fround(0), $$$i213 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i251 = Math_fround(0), $$0 = 0, $$1056 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$ph1068 = Math_fround(0), $$ph1069 = 0, $$pre = 0, $$pre1105 = Math_fround(0);
 var $$pre1106 = Math_fround(0), $$pre1107 = Math_fround(0), $$pre1108 = Math_fround(0), $$pre1109 = Math_fround(0), $$pre1110 = Math_fround(0), $$pre1111 = Math_fround(0), $$pre1112 = Math_fround(0), $$pre1113 = Math_fround(0), $$sroa$1276 = 0, $$sroa$1284 = 0, $$sroa$1350 = 0, $$sroa$1352 = 0, $$sroa$1362 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0);
 var $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0;
 var $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0;
 var $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0);
 var $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0);
 var $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0;
 var $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0);
 var $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0);
 var $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0;
 var $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0);
 var $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = 0, $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0);
 var $483 = Math_fround(0), $484 = 0, $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = 0;
 var $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = 0, $517 = 0, $518 = 0;
 var $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = 0;
 var $537 = 0, $538 = 0, $539 = Math_fround(0), $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0;
 var $555 = 0, $556 = 0, $557 = 0, $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $aInd = 0, $b$a$i$i$i = 0, $b$a$i223 = 0;
 var $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i143 = 0, $exitcond$i64 = 0, $i$01$i = 0, $i$01$i142 = 0, $i$01$i63 = 0, $i$01090 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp1064 = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0;
 var $supportA = 0, $supportB = 0, $tempClosA = 0, $tempClosB = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 624|0;
 $0 = sp + 80|0;
 $1 = sp + 416|0;
 $2 = sp + 448|0;
 $3 = sp + 400|0;
 $zeroV = sp + 480|0;
 $closA = sp + 464|0;
 $closB = sp + 432|0;
 $sDist$sroa$1 = sp + 588|0;
 $minDist$sroa$1 = sp + 576|0;
 $tempClosA = sp + 384|0;
 $tempClosB = sp + 368|0;
 $v = sp + 64|0;
 $Q = sp;
 $A = sp + 128|0;
 $B = sp + 304|0;
 $aInd = sp + 560|0;
 $bInd = sp + 600|0;
 $supportA = sp + 112|0;
 $supportB = sp + 192|0;
 $support = sp + 208|0;
 $size = sp + 520|0;
 $lastQ = sp + 224|0;
 $lastA = sp + 240|0;
 $lastB = sp + 256|0;
 $4 = sp + 272|0;
 $5 = sp + 288|0;
 $$sroa$1362 = sp + 508|0;
 $$sroa$1352 = sp + 496|0;
 $6 = sp + 96|0;
 $$sroa$1350 = sp + 536|0;
 $$sroa$1284 = sp + 524|0;
 $$sroa$1276 = sp + 548|0;
 $7 = Math_fround(HEAPF32[$_contactDist>>2]);
 $8 = (($a) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($b) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($a) + 32|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($b) + 32|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = $13 > $15;
 $$$i213 = $16 ? $15 : $13;
 $17 = Math_fround($$$i213 * Math_fround(0.100000001490116119385));
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $18 = Math_fround($9 + $11);
 $19 = Math_fround($7 + $18);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 ;HEAP32[$tempClosA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$tempClosB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $20 = Math_fround($17 * $17);
 $21 = Math_fround($19 * $19);
 ;HEAP32[$supportA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$supportB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$support+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAP32[$size>>2] = 0;
 $22 = HEAP8[$_size>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $178 = Math_fround(HEAPF32[$a>>2]);
  $179 = (($a) + 4|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = (($a) + 8|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = Math_fround(HEAPF32[$b>>2]);
  $184 = (($b) + 4|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = (($b) + 8|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = Math_fround($178 - $183);
  $189 = Math_fround($180 - $185);
  $190 = Math_fround($182 - $187);
  $191 = Math_fround($188 * $188);
  $192 = Math_fround($189 * $189);
  $193 = Math_fround($191 + $192);
  $194 = Math_fround($190 * $190);
  $195 = Math_fround($193 + $194);
  $196 = $195 > Math_fround(0.0);
  HEAPF32[$1>>2] = $188;
  $197 = (($1) + 4|0);
  HEAPF32[$197>>2] = $189;
  $198 = (($1) + 8|0);
  HEAPF32[$198>>2] = $190;
  $199 = (($1) + 12|0);
  HEAPF32[$199>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = Math_fround(1.0);
  $200 = (($0) + 4|0);
  HEAPF32[$200>>2] = Math_fround(0.0);
  $201 = (($0) + 8|0);
  HEAPF32[$201>>2] = Math_fround(0.0);
  $202 = (($0) + 12|0);
  HEAPF32[$202>>2] = Math_fround(0.0);
  $b$a$i223 = $196 ? $1 : $0;
  $203 = Math_fround(HEAPF32[$b$a$i223>>2]);
  $$in1$i = (($b$a$i223) + 4|0);
  $204 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i223) + 8|0);
  $205 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $203;
  $206 = (($v) + 4|0);
  HEAPF32[$206>>2] = $204;
  $207 = (($v) + 8|0);
  HEAPF32[$207>>2] = $205;
  $208 = (($v) + 12|0);
  HEAPF32[$208>>2] = Math_fround(0.0);
  $$ph1068 = Math_fround(3.40282346638528859812E+38);$$ph1069 = 1;$558 = $205;$559 = $204;$560 = $203;
 } else {
  ;HEAP32[$lastQ+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$zeroV+12>>2]|0;
  $24 = (($a) + 96|0);
  $25 = (($b) + 200|0);
  $26 = (($b) + 96|0);
  $27 = (($b) + 112|0);
  $28 = (($b) + 128|0);
  $29 = (($b) + 100|0);
  $30 = (($b) + 116|0);
  $31 = (($b) + 132|0);
  $32 = (($b) + 104|0);
  $33 = (($b) + 120|0);
  $34 = (($b) + 136|0);
  $35 = (($supportB) + 4|0);
  $36 = (($supportB) + 8|0);
  $37 = (($supportB) + 12|0);
  $38 = (($supportA) + 4|0);
  $39 = (($supportA) + 8|0);
  $40 = (($support) + 4|0);
  $41 = (($support) + 8|0);
  $42 = (($support) + 12|0);
  $$pre = HEAP32[$25>>2]|0;
  $$pre1105 = Math_fround(HEAPF32[$26>>2]);
  $$pre1106 = Math_fround(HEAPF32[$27>>2]);
  $$pre1107 = Math_fround(HEAPF32[$28>>2]);
  $$pre1108 = Math_fround(HEAPF32[$29>>2]);
  $$pre1109 = Math_fround(HEAPF32[$30>>2]);
  $$pre1110 = Math_fround(HEAPF32[$31>>2]);
  $$pre1111 = Math_fround(HEAPF32[$32>>2]);
  $$pre1112 = Math_fround(HEAPF32[$33>>2]);
  $$pre1113 = Math_fround(HEAPF32[$34>>2]);
  $81 = 0;$i$01090 = 0;
  while(1) {
   $43 = (($aIndices) + ($i$01090)|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = $44&255;
   $46 = (($aInd) + ($i$01090<<2)|0);
   HEAP32[$46>>2] = $45;
   $47 = (($bIndices) + ($i$01090)|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = $48&255;
   $50 = (($bInd) + ($i$01090<<2)|0);
   HEAP32[$50>>2] = $49;
   $51 = (1 - ($45))|0;
   $52 = (($24) + ($51<<4)|0);
   ;HEAP32[$supportA+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$52+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$52+12>>2]|0;
   $53 = (($$pre) + (($49*12)|0)|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = ((($$pre) + (($49*12)|0)|0) + 4|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = ((($$pre) + (($49*12)|0)|0) + 8|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = Math_fround($54 * $$pre1105);
   $60 = Math_fround($56 * $$pre1106);
   $61 = Math_fround($59 + $60);
   $62 = Math_fround($58 * $$pre1107);
   $63 = Math_fround($61 + $62);
   $64 = Math_fround($54 * $$pre1108);
   $65 = Math_fround($56 * $$pre1109);
   $66 = Math_fround($64 + $65);
   $67 = Math_fround($58 * $$pre1110);
   $68 = Math_fround($66 + $67);
   $69 = Math_fround($54 * $$pre1111);
   $70 = Math_fround($56 * $$pre1112);
   $71 = Math_fround($69 + $70);
   $72 = Math_fround($58 * $$pre1113);
   $73 = Math_fround($71 + $72);
   HEAPF32[$supportB>>2] = $63;
   HEAPF32[$35>>2] = $68;
   HEAPF32[$36>>2] = $73;
   HEAPF32[$37>>2] = Math_fround(0.0);
   $74 = Math_fround(HEAPF32[$supportA>>2]);
   $75 = Math_fround(HEAPF32[$38>>2]);
   $76 = Math_fround(HEAPF32[$39>>2]);
   $77 = Math_fround($74 - $63);
   $78 = Math_fround($75 - $68);
   $79 = Math_fround($76 - $73);
   HEAPF32[$support>>2] = $77;
   HEAPF32[$40>>2] = $78;
   HEAPF32[$41>>2] = $79;
   HEAPF32[$42>>2] = Math_fround(0.0);
   $80 = (($A) + ($81<<4)|0);
   ;HEAP32[$lastA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$supportA+12>>2]|0;
   ;HEAP32[$80+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$80+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$80+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$80+12>>2]=HEAP32[$supportA+12>>2]|0;
   $82 = (($B) + ($81<<4)|0);
   ;HEAP32[$lastB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$supportB+12>>2]|0;
   ;HEAP32[$82+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$82+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$82+12>>2]=HEAP32[$supportB+12>>2]|0;
   $83 = (($81) + 1)|0;
   $84 = (($Q) + ($81<<4)|0);
   ;HEAP32[$lastQ+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$support+12>>2]|0;
   ;HEAP32[$84+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$84+12>>2]=HEAP32[$support+12>>2]|0;
   $85 = (($i$01090) + 1)|0;
   $86 = $22&255;
   $87 = ($85>>>0)<($86>>>0);
   if ($87) {
    $81 = $83;$i$01090 = $85;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $83;
  do {
   if ((($81|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($81|0) == 1)) {
    $88 = Math_fround(HEAPF32[$Q>>2]);
    $89 = (($Q) + 4|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = (($Q) + 8|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = Math_fround(HEAPF32[$lastQ>>2]);
    $94 = (($lastQ) + 4|0);
    $95 = Math_fround(HEAPF32[$94>>2]);
    $96 = (($lastQ) + 8|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = Math_fround($93 - $88);
    $99 = Math_fround($95 - $90);
    $100 = Math_fround($97 - $92);
    $101 = Math_fround($98 * $98);
    $102 = Math_fround($99 * $99);
    $103 = Math_fround($101 + $102);
    $104 = Math_fround($100 * $100);
    $105 = Math_fround($103 + $104);
    $106 = $105 == Math_fround(0.0);
    if ($106) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $107 = Math_fround($90 * $99);
     $108 = Math_fround(-$107);
     $109 = Math_fround($88 * $98);
     $110 = Math_fround($108 - $109);
     $111 = Math_fround($92 * $100);
     $112 = Math_fround($110 - $111);
     $113 = Math_fround(HEAPF32[$lastA>>2]);
     $114 = (($lastA) + 4|0);
     $115 = Math_fround(HEAPF32[$114>>2]);
     $116 = (($lastA) + 8|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = Math_fround(HEAPF32[$A>>2]);
     $119 = (($A) + 4|0);
     $120 = Math_fround(HEAPF32[$119>>2]);
     $121 = (($A) + 8|0);
     $122 = Math_fround(HEAPF32[$121>>2]);
     $123 = Math_fround($113 - $118);
     $124 = Math_fround($115 - $120);
     $125 = Math_fround($117 - $122);
     $126 = Math_fround(HEAPF32[$lastB>>2]);
     $127 = (($lastB) + 4|0);
     $128 = Math_fround(HEAPF32[$127>>2]);
     $129 = (($lastB) + 8|0);
     $130 = Math_fround(HEAPF32[$129>>2]);
     $131 = Math_fround(HEAPF32[$B>>2]);
     $132 = (($B) + 4|0);
     $133 = Math_fround(HEAPF32[$132>>2]);
     $134 = (($B) + 8|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     $136 = Math_fround($126 - $131);
     $137 = Math_fround($128 - $133);
     $138 = Math_fround($130 - $135);
     $139 = Math_fround($112 / $105);
     $140 = $139 > Math_fround(1.0);
     $$$i$i$i250 = $140 ? Math_fround(1.0) : $139;
     $141 = $$$i$i$i250 > Math_fround(0.0);
     $$$i8$i$i251 = $141 ? $$$i$i$i250 : Math_fround(0.0);
     $142 = Math_fround($123 * $$$i8$i$i251);
     $143 = Math_fround($124 * $$$i8$i$i251);
     $144 = Math_fround($125 * $$$i8$i$i251);
     $145 = Math_fround($118 + $142);
     $146 = Math_fround($120 + $143);
     $147 = Math_fround($122 + $144);
     $148 = Math_fround($136 * $$$i8$i$i251);
     $149 = Math_fround($137 * $$$i8$i$i251);
     $150 = Math_fround($138 * $$$i8$i$i251);
     $151 = Math_fround($131 + $148);
     $152 = Math_fround($133 + $149);
     $153 = Math_fround($135 + $150);
     HEAPF32[$closA>>2] = $145;
     $154 = (($closA) + 4|0);
     HEAPF32[$154>>2] = $146;
     $155 = (($closA) + 8|0);
     HEAPF32[$155>>2] = $147;
     $156 = (($closA) + 12|0);
     HEAPF32[$156>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $151;
     $157 = (($closB) + 4|0);
     HEAPF32[$157>>2] = $152;
     $158 = (($closB) + 8|0);
     HEAPF32[$158>>2] = $153;
     $159 = (($closB) + 12|0);
     HEAPF32[$159>>2] = Math_fround(0.0);
     $160 = Math_fround($145 - $151);
     $161 = Math_fround($146 - $152);
     $162 = Math_fround($147 - $153);
     HEAPF32[$4>>2] = $160;
     $163 = (($4) + 4|0);
     HEAPF32[$163>>2] = $161;
     $164 = (($4) + 8|0);
     HEAPF32[$164>>2] = $162;
     $165 = (($4) + 12|0);
     HEAPF32[$165>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($81|0) == 2)) {
    $166 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$166,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($81|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$4+12>>2]|0;
  $167 = Math_fround(HEAPF32[$v>>2]);
  $168 = (($v) + 4|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = (($v) + 8|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = Math_fround($167 * $167);
  $173 = Math_fround($169 * $169);
  $174 = Math_fround($172 + $173);
  $175 = Math_fround($171 * $171);
  $176 = Math_fround($174 + $175);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $177 = $176 > $20;
  $$ph1068 = $176;$$ph1069 = $177;$558 = $171;$559 = $169;$560 = $167;
 }
 do {
  if ($$ph1069) {
   $210 = (($v) + 4|0);
   $211 = (($v) + 8|0);
   $212 = (($a) + 96|0);
   $213 = (($a) + 96|0);
   $214 = (($a) + 100|0);
   $215 = (($a) + 104|0);
   $216 = (($a) + 112|0);
   $217 = (($a) + 112|0);
   $218 = (($a) + 116|0);
   $219 = (($a) + 120|0);
   $220 = (($supportA) + 4|0);
   $221 = (($supportA) + 8|0);
   $222 = (($supportA) + 12|0);
   $223 = (($supportB) + 4|0);
   $224 = (($supportB) + 8|0);
   $225 = (($support) + 4|0);
   $226 = (($support) + 8|0);
   $227 = (($support) + 12|0);
   $228 = (($a) + 48|0);
   $229 = (($b) + 48|0);
   $230 = (($Q) + 4|0);
   $231 = (($Q) + 8|0);
   $232 = (($A) + 4|0);
   $233 = (($A) + 8|0);
   $234 = (($B) + 4|0);
   $235 = (($B) + 8|0);
   $236 = (($closA) + 4|0);
   $237 = (($closA) + 8|0);
   $238 = (($closA) + 12|0);
   $239 = (($closB) + 4|0);
   $240 = (($closB) + 8|0);
   $241 = (($closB) + 12|0);
   $242 = (($6) + 4|0);
   $243 = (($6) + 8|0);
   $244 = (($6) + 12|0);
   $245 = (($Q) + 16|0);
   $$$i10471088 = $7;$247 = $560;$249 = $559;$251 = $558;$300 = $$ph1068;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    ;HEAP32[$tempClosA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$closA+12>>2]|0;
    ;HEAP32[$tempClosB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$closB+12>>2]|0;
    $246 = Math_fround(-$247);
    $248 = Math_fround(-$249);
    $250 = Math_fround(-$251);
    $252 = HEAP32[$size>>2]|0;
    $253 = (($aInd) + ($252<<2)|0);
    $254 = Math_fround(HEAPF32[$213>>2]);
    $255 = Math_fround(HEAPF32[$214>>2]);
    $256 = Math_fround(HEAPF32[$215>>2]);
    $257 = Math_fround($254 * $246);
    $258 = Math_fround($255 * $248);
    $259 = Math_fround($257 + $258);
    $260 = Math_fround($256 * $250);
    $261 = Math_fround($259 + $260);
    $262 = Math_fround(HEAPF32[$217>>2]);
    $263 = Math_fround(HEAPF32[$218>>2]);
    $264 = Math_fround(HEAPF32[$219>>2]);
    $265 = Math_fround($262 * $246);
    $266 = Math_fround($263 * $248);
    $267 = Math_fround($265 + $266);
    $268 = Math_fround($264 * $250);
    $269 = Math_fround($267 + $268);
    $270 = $261 > $269;
    $271 = $270&1;
    HEAP32[$253>>2] = $271;
    ;HEAP32[$3+0>>2]=HEAP32[$212+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$212+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$212+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$212+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$216+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$216+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$216+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$216+12>>2]|0;
    $b$a$i$i$i = $270 ? $3 : $2;
    $272 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
    $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
    $273 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
    $274 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    $275 = (($A) + ($252<<4)|0);
    HEAPF32[$275>>2] = $272;
    $276 = ((($A) + ($252<<4)|0) + 4|0);
    HEAPF32[$276>>2] = $273;
    $277 = ((($A) + ($252<<4)|0) + 8|0);
    HEAPF32[$277>>2] = $274;
    $278 = ((($A) + ($252<<4)|0) + 12|0);
    HEAPF32[$278>>2] = Math_fround(0.0);
    HEAPF32[$supportA>>2] = $272;
    HEAPF32[$220>>2] = $273;
    HEAPF32[$221>>2] = $274;
    HEAPF32[$222>>2] = Math_fround(0.0);
    $279 = (($B) + ($252<<4)|0);
    $280 = (($bInd) + ($252<<2)|0);
    __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($5,$b,$v,$279,$280);
    ;HEAP32[$supportB+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$5+12>>2]|0;
    $281 = Math_fround(HEAPF32[$supportA>>2]);
    $282 = Math_fround(HEAPF32[$220>>2]);
    $283 = Math_fround(HEAPF32[$221>>2]);
    $284 = Math_fround(HEAPF32[$supportB>>2]);
    $285 = Math_fround(HEAPF32[$223>>2]);
    $286 = Math_fround(HEAPF32[$224>>2]);
    $287 = Math_fround($281 - $284);
    $288 = Math_fround($282 - $285);
    $289 = Math_fround($283 - $286);
    HEAPF32[$support>>2] = $287;
    HEAPF32[$225>>2] = $288;
    HEAPF32[$226>>2] = $289;
    HEAPF32[$227>>2] = Math_fround(0.0);
    $290 = HEAP32[$size>>2]|0;
    $291 = (($290) + 1)|0;
    HEAP32[$size>>2] = $291;
    $292 = (($Q) + ($290<<4)|0);
    ;HEAP32[$292+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$292+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$292+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$292+12>>2]=HEAP32[$support+12>>2]|0;
    $293 = Math_fround(HEAPF32[$228>>2]);
    $294 = Math_fround(HEAPF32[$229>>2]);
    $295 = $293 > $294;
    $$$i204 = $295 ? $293 : $294;
    $296 = $$$i10471088 > $$$i204;
    $$$i = $296 ? $$$i10471088 : $$$i204;
    $297 = Math_fround($18 + $$$i);
    $298 = Math_fround($297 * $297);
    $299 = Math_fround($300 * $298);
    $301 = Math_fround(HEAPF32[$v>>2]);
    $302 = Math_fround(HEAPF32[$210>>2]);
    $303 = Math_fround(HEAPF32[$211>>2]);
    $304 = Math_fround($301 * $287);
    $305 = Math_fround($302 * $288);
    $306 = Math_fround($304 + $305);
    $307 = Math_fround($303 * $289);
    $308 = Math_fround($306 + $307);
    $309 = Math_fround($308 * $308);
    $310 = $308 > Math_fround(0.0);
    $311 = $309 > $299;
    if ($310) {
     $phitmp1064 = $311 ^ 1;
     $315 = $311;$317 = $phitmp1064;
    } else {
     $315 = 0;$317 = 1;
    }
    $312 = Math_fround($300 - $308);
    $313 = Math_fround($20 * $300);
    $314 = $313 >= $312;
    $brmerge$demorgan = $314 | $315;
    if ($brmerge$demorgan) {
     $316 = $317 ^ 1;
     $$1056 = $314 | $316;
     if ($$1056) {
      break;
     }
    }
    do {
     if ((($290|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
      ;HEAP32[$6+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($290|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($6,$Q,$245,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($290|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($6,$Q,$A,$B,$aInd,$bInd,$support,$supportA,$supportB,$size,$closA,$closB);
     } else if ((($290|0) == 1)) {
      $399 = Math_fround(HEAPF32[$Q>>2]);
      $400 = Math_fround(HEAPF32[$230>>2]);
      $401 = Math_fround(HEAPF32[$231>>2]);
      $402 = Math_fround($287 - $399);
      $403 = Math_fround($288 - $400);
      $404 = Math_fround($289 - $401);
      $405 = Math_fround($402 * $402);
      $406 = Math_fround($403 * $403);
      $407 = Math_fround($405 + $406);
      $408 = Math_fround($404 * $404);
      $409 = Math_fround($407 + $408);
      $410 = $409 == Math_fround(0.0);
      if ($410) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$6+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $411 = Math_fround($400 * $403);
       $412 = Math_fround(-$411);
       $413 = Math_fround($399 * $402);
       $414 = Math_fround($412 - $413);
       $415 = Math_fround($401 * $404);
       $416 = Math_fround($414 - $415);
       $417 = Math_fround(HEAPF32[$A>>2]);
       $418 = Math_fround(HEAPF32[$232>>2]);
       $419 = Math_fround(HEAPF32[$233>>2]);
       $420 = Math_fround($281 - $417);
       $421 = Math_fround($282 - $418);
       $422 = Math_fround($283 - $419);
       $423 = Math_fround(HEAPF32[$B>>2]);
       $424 = Math_fround(HEAPF32[$234>>2]);
       $425 = Math_fround(HEAPF32[$235>>2]);
       $426 = Math_fround($284 - $423);
       $427 = Math_fround($285 - $424);
       $428 = Math_fround($286 - $425);
       $429 = Math_fround($416 / $409);
       $430 = $429 > Math_fround(1.0);
       $$$i$i$i = $430 ? Math_fround(1.0) : $429;
       $431 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $431 ? $$$i$i$i : Math_fround(0.0);
       $432 = Math_fround($420 * $$$i8$i$i);
       $433 = Math_fround($421 * $$$i8$i$i);
       $434 = Math_fround($422 * $$$i8$i$i);
       $435 = Math_fround($417 + $432);
       $436 = Math_fround($418 + $433);
       $437 = Math_fround($419 + $434);
       $438 = Math_fround($426 * $$$i8$i$i);
       $439 = Math_fround($427 * $$$i8$i$i);
       $440 = Math_fround($428 * $$$i8$i$i);
       $441 = Math_fround($423 + $438);
       $442 = Math_fround($424 + $439);
       $443 = Math_fround($425 + $440);
       HEAPF32[$closA>>2] = $435;
       HEAPF32[$236>>2] = $436;
       HEAPF32[$237>>2] = $437;
       HEAPF32[$238>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $441;
       HEAPF32[$239>>2] = $442;
       HEAPF32[$240>>2] = $443;
       HEAPF32[$241>>2] = Math_fround(0.0);
       $444 = Math_fround($435 - $441);
       $445 = Math_fround($436 - $442);
       $446 = Math_fround($437 - $443);
       HEAPF32[$6>>2] = $444;
       HEAPF32[$242>>2] = $445;
       HEAPF32[$243>>2] = $446;
       HEAPF32[$244>>2] = Math_fround(0.0);
       break;
      }
     } else {
      ;HEAP32[$6+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$6+12>>2]|0;
    $447 = Math_fround(HEAPF32[$v>>2]);
    $448 = Math_fround(HEAPF32[$210>>2]);
    $449 = Math_fround(HEAPF32[$211>>2]);
    $450 = Math_fround($447 * $447);
    $451 = Math_fround($448 * $448);
    $452 = Math_fround($450 + $451);
    $453 = Math_fround($449 * $449);
    $454 = Math_fround($452 + $453);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1350+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1350+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1350+8>>2]|0;
    $455 = $300 > $454;
    $456 = $454 > $20;
    if (!($456)) {
     label = 38;
     break;
    }
    if ($455) {
     $$$i10471088 = $$$i;$247 = $447;$249 = $448;$251 = $449;$300 = $454;
    } else {
     label = 38;
     break;
    }
   }
   if ((label|0) == 38) {
    $457 = HEAP32[$size>>2]|0;
    if ($455) {
     $547 = $457;
     break;
    }
    $458 = (($457) + -1)|0;
    $459 = ($aIndices|0)==(0|0);
    if (!($459)) {
     $460 = $458&255;
     HEAP8[$_size>>0] = $460;
     $461 = ($458|0)==(0);
     if (!($461)) {
      $i$01$i63 = 0;
      while(1) {
       $462 = (($aInd) + ($i$01$i63<<2)|0);
       $463 = HEAP32[$462>>2]|0;
       $464 = $463&255;
       $465 = (($aIndices) + ($i$01$i63)|0);
       HEAP8[$465>>0] = $464;
       $466 = (($bInd) + ($i$01$i63<<2)|0);
       $467 = HEAP32[$466>>2]|0;
       $468 = $467&255;
       $469 = (($bIndices) + ($i$01$i63)|0);
       HEAP8[$469>>0] = $468;
       $470 = (($i$01$i63) + 1)|0;
       $exitcond$i64 = ($470|0)==($458|0);
       if ($exitcond$i64) {
        break;
       } else {
        $i$01$i63 = $470;
       }
      }
     }
    }
    ;HEAP32[$closA+0>>2]=HEAP32[$tempClosA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$tempClosA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$tempClosA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$tempClosA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$tempClosB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$tempClosB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$tempClosB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$tempClosB+12>>2]|0;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $471 = Math_fround(HEAPF32[$closA>>2]);
    $472 = (($closA) + 4|0);
    $473 = Math_fround(HEAPF32[$472>>2]);
    $474 = (($closA) + 8|0);
    $475 = Math_fround(HEAPF32[$474>>2]);
    $476 = Math_fround(HEAPF32[$closB>>2]);
    $477 = (($closB) + 4|0);
    $478 = Math_fround(HEAPF32[$477>>2]);
    $479 = (($closB) + 8|0);
    $480 = Math_fround(HEAPF32[$479>>2]);
    $481 = Math_fround($471 - $476);
    $482 = Math_fround($473 - $478);
    $483 = Math_fround($475 - $480);
    HEAPF32[$v>>2] = $481;
    $484 = (($v) + 4|0);
    HEAPF32[$484>>2] = $482;
    $485 = (($v) + 8|0);
    HEAPF32[$485>>2] = $483;
    $486 = (($v) + 12|0);
    HEAPF32[$486>>2] = Math_fround(0.0);
    $487 = (Math_fround(Math_sqrt((Math_fround($300)))));
    $488 = Math_fround(Math_fround(1.0) / $487);
    $489 = Math_fround($481 * $488);
    $490 = Math_fround($482 * $488);
    $491 = Math_fround($483 * $488);
    if ($takeCoreShape) {
     $492 = (($a) + 64|0);
     $493 = HEAP32[$492>>2]|0;
     $494 = (($b) + 64|0);
     $495 = HEAP32[$494>>2]|0;
     $496 = ($493|0)==(0);
     $497 = $496 ? $9 : Math_fround(0.0);
     $498 = ($495|0)==(0);
     $499 = $498 ? $11 : Math_fround(0.0);
     $500 = Math_fround($497 + $499);
     $501 = Math_fround($489 * $497);
     $502 = Math_fround($490 * $497);
     $503 = Math_fround($491 * $497);
     $504 = Math_fround($471 - $501);
     $505 = Math_fround($473 - $502);
     $506 = Math_fround($475 - $503);
     HEAPF32[$contactA>>2] = $504;
     $507 = (($contactA) + 4|0);
     HEAPF32[$507>>2] = $505;
     $508 = (($contactA) + 8|0);
     HEAPF32[$508>>2] = $506;
     $509 = (($contactA) + 12|0);
     HEAPF32[$509>>2] = Math_fround(0.0);
     $510 = Math_fround($489 * $499);
     $511 = Math_fround($490 * $499);
     $512 = Math_fround($491 * $499);
     $513 = Math_fround($510 + $476);
     $514 = Math_fround($511 + $478);
     $515 = Math_fround($512 + $480);
     HEAPF32[$contactB>>2] = $513;
     $516 = (($contactB) + 4|0);
     HEAPF32[$516>>2] = $514;
     $517 = (($contactB) + 8|0);
     HEAPF32[$517>>2] = $515;
     $518 = (($contactB) + 12|0);
     HEAPF32[$518>>2] = Math_fround(0.0);
     $519 = Math_fround($487 - $500);
     HEAPF32[$penetrationDepth>>2] = $519;
     $520 = (($penetrationDepth) + 4|0);
     ;HEAP32[$520+0>>2]=HEAP32[$$sroa$1284+0>>2]|0;HEAP32[$520+4>>2]=HEAP32[$$sroa$1284+4>>2]|0;HEAP32[$520+8>>2]=HEAP32[$$sroa$1284+8>>2]|0;
    } else {
     $521 = Math_fround($9 * $489);
     $522 = Math_fround($9 * $490);
     $523 = Math_fround($9 * $491);
     $524 = Math_fround($471 - $521);
     $525 = Math_fround($473 - $522);
     $526 = Math_fround($475 - $523);
     HEAPF32[$contactA>>2] = $524;
     $527 = (($contactA) + 4|0);
     HEAPF32[$527>>2] = $525;
     $528 = (($contactA) + 8|0);
     HEAPF32[$528>>2] = $526;
     $529 = (($contactA) + 12|0);
     HEAPF32[$529>>2] = Math_fround(0.0);
     $530 = Math_fround($11 * $489);
     $531 = Math_fround($11 * $490);
     $532 = Math_fround($11 * $491);
     $533 = Math_fround($530 + $476);
     $534 = Math_fround($531 + $478);
     $535 = Math_fround($532 + $480);
     HEAPF32[$contactB>>2] = $533;
     $536 = (($contactB) + 4|0);
     HEAPF32[$536>>2] = $534;
     $537 = (($contactB) + 8|0);
     HEAPF32[$537>>2] = $535;
     $538 = (($contactB) + 12|0);
     HEAPF32[$538>>2] = Math_fround(0.0);
     $539 = Math_fround($487 - $18);
     HEAPF32[$penetrationDepth>>2] = $539;
     $540 = (($penetrationDepth) + 4|0);
     ;HEAP32[$540+0>>2]=HEAP32[$$sroa$1276+0>>2]|0;HEAP32[$540+4>>2]=HEAP32[$$sroa$1276+4>>2]|0;HEAP32[$540+8>>2]=HEAP32[$$sroa$1276+8>>2]|0;
    }
    HEAPF32[$normal>>2] = $489;
    $541 = (($normal) + 4|0);
    HEAPF32[$541>>2] = $490;
    $542 = (($normal) + 8|0);
    HEAPF32[$542>>2] = $491;
    $543 = (($normal) + 12|0);
    HEAPF32[$543>>2] = Math_fround(0.0);
    $544 = $21 >= $300;
    $$ = $544 ? 1 : 3;
    $$0 = $$;
    STACKTOP = sp;return ($$0|0);
   }
   $318 = ($aIndices|0)==(0|0);
   if (!($318)) {
    $319 = $290&255;
    HEAP8[$_size>>0] = $319;
    $320 = ($290|0)==(0);
    if (!($320)) {
     $i$01$i142 = 0;
     while(1) {
      $321 = (($aInd) + ($i$01$i142<<2)|0);
      $322 = HEAP32[$321>>2]|0;
      $323 = $322&255;
      $324 = (($aIndices) + ($i$01$i142)|0);
      HEAP8[$324>>0] = $323;
      $325 = (($bInd) + ($i$01$i142<<2)|0);
      $326 = HEAP32[$325>>2]|0;
      $327 = $326&255;
      $328 = (($bIndices) + ($i$01$i142)|0);
      HEAP8[$328>>0] = $327;
      $329 = (($i$01$i142) + 1)|0;
      $exitcond$i143 = ($329|0)==($290|0);
      if ($exitcond$i143) {
       break;
      } else {
       $i$01$i142 = $329;
      }
     }
    }
   }
   $not$ = $315 ^ 1;
   $$$1060 = $317 & $not$;
   if (!($$$1060)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $330 = (Math_fround(Math_sqrt((Math_fround($300)))));
   $331 = Math_fround(Math_fround(1.0) / $330);
   $332 = Math_fround($301 * $331);
   $333 = Math_fround($302 * $331);
   $334 = Math_fround($303 * $331);
   HEAPF32[$normal>>2] = $332;
   $335 = (($normal) + 4|0);
   HEAPF32[$335>>2] = $333;
   $336 = (($normal) + 8|0);
   HEAPF32[$336>>2] = $334;
   $337 = (($normal) + 12|0);
   HEAPF32[$337>>2] = Math_fround(0.0);
   if ($takeCoreShape) {
    $338 = (($a) + 64|0);
    $339 = HEAP32[$338>>2]|0;
    $340 = (($b) + 64|0);
    $341 = HEAP32[$340>>2]|0;
    $342 = ($339|0)==(0);
    $343 = $342 ? $9 : Math_fround(0.0);
    $344 = ($341|0)==(0);
    $345 = $344 ? $11 : Math_fround(0.0);
    $346 = Math_fround($343 + $345);
    $347 = Math_fround(HEAPF32[$closA>>2]);
    $348 = Math_fround(HEAPF32[$236>>2]);
    $349 = Math_fround(HEAPF32[$237>>2]);
    $350 = Math_fround($332 * $343);
    $351 = Math_fround($333 * $343);
    $352 = Math_fround($334 * $343);
    $353 = Math_fround($347 - $350);
    $354 = Math_fround($348 - $351);
    $355 = Math_fround($349 - $352);
    HEAPF32[$contactA>>2] = $353;
    $356 = (($contactA) + 4|0);
    HEAPF32[$356>>2] = $354;
    $357 = (($contactA) + 8|0);
    HEAPF32[$357>>2] = $355;
    $358 = (($contactA) + 12|0);
    HEAPF32[$358>>2] = Math_fround(0.0);
    $359 = Math_fround(HEAPF32[$closB>>2]);
    $360 = Math_fround(HEAPF32[$239>>2]);
    $361 = Math_fround(HEAPF32[$240>>2]);
    $362 = Math_fround($332 * $345);
    $363 = Math_fround($333 * $345);
    $364 = Math_fround($334 * $345);
    $365 = Math_fround($362 + $359);
    $366 = Math_fround($363 + $360);
    $367 = Math_fround($364 + $361);
    HEAPF32[$contactB>>2] = $365;
    $368 = (($contactB) + 4|0);
    HEAPF32[$368>>2] = $366;
    $369 = (($contactB) + 8|0);
    HEAPF32[$369>>2] = $367;
    $370 = (($contactB) + 12|0);
    HEAPF32[$370>>2] = Math_fround(0.0);
    $371 = Math_fround($330 - $346);
    HEAPF32[$penetrationDepth>>2] = $371;
    $372 = (($penetrationDepth) + 4|0);
    ;HEAP32[$372+0>>2]=HEAP32[$$sroa$1362+0>>2]|0;HEAP32[$372+4>>2]=HEAP32[$$sroa$1362+4>>2]|0;HEAP32[$372+8>>2]=HEAP32[$$sroa$1362+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $373 = Math_fround(HEAPF32[$closA>>2]);
    $374 = Math_fround(HEAPF32[$236>>2]);
    $375 = Math_fround(HEAPF32[$237>>2]);
    $376 = Math_fround($9 * $332);
    $377 = Math_fround($9 * $333);
    $378 = Math_fround($9 * $334);
    $379 = Math_fround($373 - $376);
    $380 = Math_fround($374 - $377);
    $381 = Math_fround($375 - $378);
    HEAPF32[$contactA>>2] = $379;
    $382 = (($contactA) + 4|0);
    HEAPF32[$382>>2] = $380;
    $383 = (($contactA) + 8|0);
    HEAPF32[$383>>2] = $381;
    $384 = (($contactA) + 12|0);
    HEAPF32[$384>>2] = Math_fround(0.0);
    $385 = Math_fround(HEAPF32[$closB>>2]);
    $386 = Math_fround(HEAPF32[$239>>2]);
    $387 = Math_fround(HEAPF32[$240>>2]);
    $388 = Math_fround($11 * $332);
    $389 = Math_fround($11 * $333);
    $390 = Math_fround($11 * $334);
    $391 = Math_fround($388 + $385);
    $392 = Math_fround($389 + $386);
    $393 = Math_fround($390 + $387);
    HEAPF32[$contactB>>2] = $391;
    $394 = (($contactB) + 4|0);
    HEAPF32[$394>>2] = $392;
    $395 = (($contactB) + 8|0);
    HEAPF32[$395>>2] = $393;
    $396 = (($contactB) + 12|0);
    HEAPF32[$396>>2] = Math_fround(0.0);
    $397 = Math_fround($330 - $18);
    HEAPF32[$penetrationDepth>>2] = $397;
    $398 = (($penetrationDepth) + 4|0);
    ;HEAP32[$398+0>>2]=HEAP32[$$sroa$1352+0>>2]|0;HEAP32[$398+4>>2]=HEAP32[$$sroa$1352+4>>2]|0;HEAP32[$398+8>>2]=HEAP32[$$sroa$1352+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $209 = HEAP32[$size>>2]|0;
   $547 = $209;
  }
 } while(0);
 $545 = ($aIndices|0)==(0|0);
 if (!($545)) {
  $546 = $547&255;
  HEAP8[$_size>>0] = $546;
  $548 = ($547|0)==(0);
  if (!($548)) {
   $i$01$i = 0;
   while(1) {
    $549 = (($aInd) + ($i$01$i<<2)|0);
    $550 = HEAP32[$549>>2]|0;
    $551 = $550&255;
    $552 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$552>>0] = $551;
    $553 = (($bInd) + ($i$01$i<<2)|0);
    $554 = HEAP32[$553>>2]|0;
    $555 = $554&255;
    $556 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$556>>0] = $555;
    $557 = (($i$01$i) + 1)|0;
    $exitcond$i = ($557|0)==($547|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $557;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$ = 0, $$$1056 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i250 = Math_fround(0), $$$i10431084 = Math_fround(0), $$$i204 = Math_fround(0), $$$i213 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i251 = Math_fround(0), $$0 = 0, $$1052 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$ph1064 = Math_fround(0), $$ph1065 = 0, $$sroa$1276 = 0, $$sroa$1284 = 0;
 var $$sroa$1350 = 0, $$sroa$1352 = 0, $$sroa$1362 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0);
 var $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0);
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0);
 var $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0);
 var $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0);
 var $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0);
 var $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0);
 var $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = Math_fround(0), $455 = Math_fround(0);
 var $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0);
 var $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = 0, $482 = 0, $483 = 0, $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = 0, $491 = 0;
 var $492 = 0, $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = 0, $502 = 0, $503 = 0, $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0);
 var $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0);
 var $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0;
 var $Q = 0, $aInd = 0, $b$a$i$i$i = 0, $b$a$i223 = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i143 = 0, $exitcond$i64 = 0, $i$01$i = 0, $i$01$i142 = 0, $i$01$i63 = 0, $i$01086 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0;
 var $phitmp1060 = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportA = 0, $supportB = 0, $tempClosA = 0, $tempClosB = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 640|0;
 $0 = sp + 64|0;
 $1 = sp + 464|0;
 $2 = sp + 448|0;
 $3 = sp + 432|0;
 $zeroV = sp + 400|0;
 $closA = sp + 496|0;
 $closB = sp + 416|0;
 $sDist$sroa$1 = sp + 604|0;
 $minDist$sroa$1 = sp + 592|0;
 $tempClosA = sp + 480|0;
 $tempClosB = sp + 384|0;
 $v = sp + 368|0;
 $Q = sp;
 $A = sp + 128|0;
 $B = sp + 304|0;
 $aInd = sp + 576|0;
 $bInd = sp + 616|0;
 $supportA = sp + 96|0;
 $supportB = sp + 112|0;
 $support = sp + 192|0;
 $size = sp + 536|0;
 $lastQ = sp + 208|0;
 $lastA = sp + 224|0;
 $lastB = sp + 240|0;
 $4 = sp + 256|0;
 $5 = sp + 272|0;
 $6 = sp + 288|0;
 $$sroa$1362 = sp + 524|0;
 $$sroa$1352 = sp + 512|0;
 $7 = sp + 80|0;
 $$sroa$1350 = sp + 552|0;
 $$sroa$1284 = sp + 540|0;
 $$sroa$1276 = sp + 564|0;
 $8 = Math_fround(HEAPF32[$_contactDist>>2]);
 $9 = (($a) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($b) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($a) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($b) + 32|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = $14 > $16;
 $$$i213 = $17 ? $16 : $14;
 $18 = Math_fround($$$i213 * Math_fround(0.100000001490116119385));
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $19 = Math_fround($10 + $12);
 $20 = Math_fround($8 + $19);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 ;HEAP32[$tempClosA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$tempClosB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $21 = Math_fround($18 * $18);
 $22 = Math_fround($20 * $20);
 ;HEAP32[$supportA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$supportB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$support+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAP32[$size>>2] = 0;
 $23 = HEAP8[$_size>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $152 = Math_fround(HEAPF32[$a>>2]);
  $153 = (($a) + 4|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = (($a) + 8|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = Math_fround(HEAPF32[$b>>2]);
  $158 = (($b) + 4|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = (($b) + 8|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = Math_fround($152 - $157);
  $163 = Math_fround($154 - $159);
  $164 = Math_fround($156 - $161);
  $165 = Math_fround($162 * $162);
  $166 = Math_fround($163 * $163);
  $167 = Math_fround($165 + $166);
  $168 = Math_fround($164 * $164);
  $169 = Math_fround($167 + $168);
  $170 = $169 > Math_fround(0.0);
  HEAPF32[$1>>2] = $162;
  $171 = (($1) + 4|0);
  HEAPF32[$171>>2] = $163;
  $172 = (($1) + 8|0);
  HEAPF32[$172>>2] = $164;
  $173 = (($1) + 12|0);
  HEAPF32[$173>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = Math_fround(1.0);
  $174 = (($0) + 4|0);
  HEAPF32[$174>>2] = Math_fround(0.0);
  $175 = (($0) + 8|0);
  HEAPF32[$175>>2] = Math_fround(0.0);
  $176 = (($0) + 12|0);
  HEAPF32[$176>>2] = Math_fround(0.0);
  $b$a$i223 = $170 ? $1 : $0;
  $177 = Math_fround(HEAPF32[$b$a$i223>>2]);
  $$in1$i = (($b$a$i223) + 4|0);
  $178 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i223) + 8|0);
  $179 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $177;
  $180 = (($v) + 4|0);
  HEAPF32[$180>>2] = $178;
  $181 = (($v) + 8|0);
  HEAPF32[$181>>2] = $179;
  $182 = (($v) + 12|0);
  HEAPF32[$182>>2] = Math_fround(0.0);
  $$ph1064 = Math_fround(3.40282346638528859812E+38);$$ph1065 = 1;$532 = $179;$533 = $178;$534 = $177;
 } else {
  ;HEAP32[$lastQ+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$zeroV+12>>2]|0;
  $25 = (($a) + 96|0);
  $26 = (($b) + 16|0);
  $27 = (($supportA) + 4|0);
  $28 = (($supportA) + 8|0);
  $29 = (($supportB) + 4|0);
  $30 = (($supportB) + 8|0);
  $31 = (($support) + 4|0);
  $32 = (($support) + 8|0);
  $33 = (($support) + 12|0);
  $i$01086 = 0;
  while(1) {
   $34 = (($aIndices) + ($i$01086)|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = (($aInd) + ($i$01086<<2)|0);
   HEAP32[$37>>2] = $36;
   $38 = (($bIndices) + ($i$01086)|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = $39&255;
   $41 = (($bInd) + ($i$01086<<2)|0);
   HEAP32[$41>>2] = $40;
   $42 = (1 - ($36))|0;
   $43 = (($25) + ($42<<4)|0);
   ;HEAP32[$supportA+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$43+12>>2]|0;
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($4,$b,$40,$26);
   ;HEAP32[$supportB+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$4+12>>2]|0;
   $44 = Math_fround(HEAPF32[$supportA>>2]);
   $45 = Math_fround(HEAPF32[$27>>2]);
   $46 = Math_fround(HEAPF32[$28>>2]);
   $47 = Math_fround(HEAPF32[$supportB>>2]);
   $48 = Math_fround(HEAPF32[$29>>2]);
   $49 = Math_fround(HEAPF32[$30>>2]);
   $50 = Math_fround($44 - $47);
   $51 = Math_fround($45 - $48);
   $52 = Math_fround($46 - $49);
   HEAPF32[$support>>2] = $50;
   HEAPF32[$31>>2] = $51;
   HEAPF32[$32>>2] = $52;
   HEAPF32[$33>>2] = Math_fround(0.0);
   $53 = HEAP32[$size>>2]|0;
   $54 = (($A) + ($53<<4)|0);
   ;HEAP32[$lastA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$supportA+12>>2]|0;
   ;HEAP32[$54+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$supportA+12>>2]|0;
   $55 = (($B) + ($53<<4)|0);
   ;HEAP32[$lastB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$supportB+12>>2]|0;
   ;HEAP32[$55+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$supportB+12>>2]|0;
   $56 = (($53) + 1)|0;
   HEAP32[$size>>2] = $56;
   $57 = (($Q) + ($53<<4)|0);
   ;HEAP32[$lastQ+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$support+12>>2]|0;
   ;HEAP32[$57+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$support+12>>2]|0;
   $58 = (($i$01086) + 1)|0;
   $59 = HEAP8[$_size>>0]|0;
   $60 = $59&255;
   $61 = ($58>>>0)<($60>>>0);
   if ($61) {
    $i$01086 = $58;
   } else {
    break;
   }
  }
  do {
   if ((($53|0) == 1)) {
    $62 = Math_fround(HEAPF32[$Q>>2]);
    $63 = (($Q) + 4|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = (($Q) + 8|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = Math_fround(HEAPF32[$lastQ>>2]);
    $68 = (($lastQ) + 4|0);
    $69 = Math_fround(HEAPF32[$68>>2]);
    $70 = (($lastQ) + 8|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = Math_fround($67 - $62);
    $73 = Math_fround($69 - $64);
    $74 = Math_fround($71 - $66);
    $75 = Math_fround($72 * $72);
    $76 = Math_fround($73 * $73);
    $77 = Math_fround($75 + $76);
    $78 = Math_fround($74 * $74);
    $79 = Math_fround($77 + $78);
    $80 = $79 == Math_fround(0.0);
    if ($80) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $81 = Math_fround($64 * $73);
     $82 = Math_fround(-$81);
     $83 = Math_fround($62 * $72);
     $84 = Math_fround($82 - $83);
     $85 = Math_fround($66 * $74);
     $86 = Math_fround($84 - $85);
     $87 = Math_fround(HEAPF32[$lastA>>2]);
     $88 = (($lastA) + 4|0);
     $89 = Math_fround(HEAPF32[$88>>2]);
     $90 = (($lastA) + 8|0);
     $91 = Math_fround(HEAPF32[$90>>2]);
     $92 = Math_fround(HEAPF32[$A>>2]);
     $93 = (($A) + 4|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = (($A) + 8|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $97 = Math_fround($87 - $92);
     $98 = Math_fround($89 - $94);
     $99 = Math_fround($91 - $96);
     $100 = Math_fround(HEAPF32[$lastB>>2]);
     $101 = (($lastB) + 4|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = (($lastB) + 8|0);
     $104 = Math_fround(HEAPF32[$103>>2]);
     $105 = Math_fround(HEAPF32[$B>>2]);
     $106 = (($B) + 4|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = (($B) + 8|0);
     $109 = Math_fround(HEAPF32[$108>>2]);
     $110 = Math_fround($100 - $105);
     $111 = Math_fround($102 - $107);
     $112 = Math_fround($104 - $109);
     $113 = Math_fround($86 / $79);
     $114 = $113 > Math_fround(1.0);
     $$$i$i$i250 = $114 ? Math_fround(1.0) : $113;
     $115 = $$$i$i$i250 > Math_fround(0.0);
     $$$i8$i$i251 = $115 ? $$$i$i$i250 : Math_fround(0.0);
     $116 = Math_fround($97 * $$$i8$i$i251);
     $117 = Math_fround($98 * $$$i8$i$i251);
     $118 = Math_fround($99 * $$$i8$i$i251);
     $119 = Math_fround($92 + $116);
     $120 = Math_fround($94 + $117);
     $121 = Math_fround($96 + $118);
     $122 = Math_fround($110 * $$$i8$i$i251);
     $123 = Math_fround($111 * $$$i8$i$i251);
     $124 = Math_fround($112 * $$$i8$i$i251);
     $125 = Math_fround($105 + $122);
     $126 = Math_fround($107 + $123);
     $127 = Math_fround($109 + $124);
     HEAPF32[$closA>>2] = $119;
     $128 = (($closA) + 4|0);
     HEAPF32[$128>>2] = $120;
     $129 = (($closA) + 8|0);
     HEAPF32[$129>>2] = $121;
     $130 = (($closA) + 12|0);
     HEAPF32[$130>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $125;
     $131 = (($closB) + 4|0);
     HEAPF32[$131>>2] = $126;
     $132 = (($closB) + 8|0);
     HEAPF32[$132>>2] = $127;
     $133 = (($closB) + 12|0);
     HEAPF32[$133>>2] = Math_fround(0.0);
     $134 = Math_fround($119 - $125);
     $135 = Math_fround($120 - $126);
     $136 = Math_fround($121 - $127);
     HEAPF32[$5>>2] = $134;
     $137 = (($5) + 4|0);
     HEAPF32[$137>>2] = $135;
     $138 = (($5) + 8|0);
     HEAPF32[$138>>2] = $136;
     $139 = (($5) + 12|0);
     HEAPF32[$139>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($53|0) == 2)) {
    $140 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$140,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($53|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($53|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$5+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$5+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
  $141 = Math_fround(HEAPF32[$v>>2]);
  $142 = (($v) + 4|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = (($v) + 8|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = Math_fround($141 * $141);
  $147 = Math_fround($143 * $143);
  $148 = Math_fround($146 + $147);
  $149 = Math_fround($145 * $145);
  $150 = Math_fround($148 + $149);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $151 = $150 > $21;
  $$ph1064 = $150;$$ph1065 = $151;$532 = $145;$533 = $143;$534 = $141;
 }
 do {
  if ($$ph1065) {
   $184 = (($v) + 4|0);
   $185 = (($v) + 8|0);
   $186 = (($a) + 96|0);
   $187 = (($a) + 96|0);
   $188 = (($a) + 100|0);
   $189 = (($a) + 104|0);
   $190 = (($a) + 112|0);
   $191 = (($a) + 112|0);
   $192 = (($a) + 116|0);
   $193 = (($a) + 120|0);
   $194 = (($supportA) + 4|0);
   $195 = (($supportA) + 8|0);
   $196 = (($supportA) + 12|0);
   $197 = (($supportB) + 4|0);
   $198 = (($supportB) + 8|0);
   $199 = (($support) + 4|0);
   $200 = (($support) + 8|0);
   $201 = (($support) + 12|0);
   $202 = (($a) + 48|0);
   $203 = (($b) + 48|0);
   $204 = (($Q) + 4|0);
   $205 = (($Q) + 8|0);
   $206 = (($A) + 4|0);
   $207 = (($A) + 8|0);
   $208 = (($B) + 4|0);
   $209 = (($B) + 8|0);
   $210 = (($closA) + 4|0);
   $211 = (($closA) + 8|0);
   $212 = (($closA) + 12|0);
   $213 = (($closB) + 4|0);
   $214 = (($closB) + 8|0);
   $215 = (($closB) + 12|0);
   $216 = (($7) + 4|0);
   $217 = (($7) + 8|0);
   $218 = (($7) + 12|0);
   $219 = (($Q) + 16|0);
   $$$i10431084 = $8;$221 = $534;$223 = $533;$225 = $532;$274 = $$ph1064;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    ;HEAP32[$tempClosA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$closA+12>>2]|0;
    ;HEAP32[$tempClosB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$closB+12>>2]|0;
    $220 = Math_fround(-$221);
    $222 = Math_fround(-$223);
    $224 = Math_fround(-$225);
    $226 = HEAP32[$size>>2]|0;
    $227 = (($aInd) + ($226<<2)|0);
    $228 = Math_fround(HEAPF32[$187>>2]);
    $229 = Math_fround(HEAPF32[$188>>2]);
    $230 = Math_fround(HEAPF32[$189>>2]);
    $231 = Math_fround($228 * $220);
    $232 = Math_fround($229 * $222);
    $233 = Math_fround($231 + $232);
    $234 = Math_fround($230 * $224);
    $235 = Math_fround($233 + $234);
    $236 = Math_fround(HEAPF32[$191>>2]);
    $237 = Math_fround(HEAPF32[$192>>2]);
    $238 = Math_fround(HEAPF32[$193>>2]);
    $239 = Math_fround($236 * $220);
    $240 = Math_fround($237 * $222);
    $241 = Math_fround($239 + $240);
    $242 = Math_fround($238 * $224);
    $243 = Math_fround($241 + $242);
    $244 = $235 > $243;
    $245 = $244&1;
    HEAP32[$227>>2] = $245;
    ;HEAP32[$3+0>>2]=HEAP32[$186+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$186+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$186+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$186+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$190+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$190+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$190+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$190+12>>2]|0;
    $b$a$i$i$i = $244 ? $3 : $2;
    $246 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
    $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
    $247 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
    $248 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    $249 = (($A) + ($226<<4)|0);
    HEAPF32[$249>>2] = $246;
    $250 = ((($A) + ($226<<4)|0) + 4|0);
    HEAPF32[$250>>2] = $247;
    $251 = ((($A) + ($226<<4)|0) + 8|0);
    HEAPF32[$251>>2] = $248;
    $252 = ((($A) + ($226<<4)|0) + 12|0);
    HEAPF32[$252>>2] = Math_fround(0.0);
    HEAPF32[$supportA>>2] = $246;
    HEAPF32[$194>>2] = $247;
    HEAPF32[$195>>2] = $248;
    HEAPF32[$196>>2] = Math_fround(0.0);
    $253 = (($B) + ($226<<4)|0);
    $254 = (($bInd) + ($226<<2)|0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($6,$b,$v,$253,$254);
    ;HEAP32[$supportB+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$6+12>>2]|0;
    $255 = Math_fround(HEAPF32[$supportA>>2]);
    $256 = Math_fround(HEAPF32[$194>>2]);
    $257 = Math_fround(HEAPF32[$195>>2]);
    $258 = Math_fround(HEAPF32[$supportB>>2]);
    $259 = Math_fround(HEAPF32[$197>>2]);
    $260 = Math_fround(HEAPF32[$198>>2]);
    $261 = Math_fround($255 - $258);
    $262 = Math_fround($256 - $259);
    $263 = Math_fround($257 - $260);
    HEAPF32[$support>>2] = $261;
    HEAPF32[$199>>2] = $262;
    HEAPF32[$200>>2] = $263;
    HEAPF32[$201>>2] = Math_fround(0.0);
    $264 = HEAP32[$size>>2]|0;
    $265 = (($264) + 1)|0;
    HEAP32[$size>>2] = $265;
    $266 = (($Q) + ($264<<4)|0);
    ;HEAP32[$266+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$266+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$266+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$266+12>>2]=HEAP32[$support+12>>2]|0;
    $267 = Math_fround(HEAPF32[$202>>2]);
    $268 = Math_fround(HEAPF32[$203>>2]);
    $269 = $267 > $268;
    $$$i204 = $269 ? $267 : $268;
    $270 = $$$i10431084 > $$$i204;
    $$$i = $270 ? $$$i10431084 : $$$i204;
    $271 = Math_fround($19 + $$$i);
    $272 = Math_fround($271 * $271);
    $273 = Math_fround($274 * $272);
    $275 = Math_fround(HEAPF32[$v>>2]);
    $276 = Math_fround(HEAPF32[$184>>2]);
    $277 = Math_fround(HEAPF32[$185>>2]);
    $278 = Math_fround($275 * $261);
    $279 = Math_fround($276 * $262);
    $280 = Math_fround($278 + $279);
    $281 = Math_fround($277 * $263);
    $282 = Math_fround($280 + $281);
    $283 = Math_fround($282 * $282);
    $284 = $282 > Math_fround(0.0);
    $285 = $283 > $273;
    if ($284) {
     $phitmp1060 = $285 ^ 1;
     $289 = $285;$291 = $phitmp1060;
    } else {
     $289 = 0;$291 = 1;
    }
    $286 = Math_fround($274 - $282);
    $287 = Math_fround($21 * $274);
    $288 = $287 >= $286;
    $brmerge$demorgan = $288 | $289;
    if ($brmerge$demorgan) {
     $290 = $291 ^ 1;
     $$1052 = $288 | $290;
     if ($$1052) {
      break;
     }
    }
    do {
     if ((($264|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
      ;HEAP32[$7+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($264|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($7,$Q,$219,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($264|0) == 1)) {
      $373 = Math_fround(HEAPF32[$Q>>2]);
      $374 = Math_fround(HEAPF32[$204>>2]);
      $375 = Math_fround(HEAPF32[$205>>2]);
      $376 = Math_fround($261 - $373);
      $377 = Math_fround($262 - $374);
      $378 = Math_fround($263 - $375);
      $379 = Math_fround($376 * $376);
      $380 = Math_fround($377 * $377);
      $381 = Math_fround($379 + $380);
      $382 = Math_fround($378 * $378);
      $383 = Math_fround($381 + $382);
      $384 = $383 == Math_fround(0.0);
      if ($384) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$7+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $385 = Math_fround($374 * $377);
       $386 = Math_fround(-$385);
       $387 = Math_fround($373 * $376);
       $388 = Math_fround($386 - $387);
       $389 = Math_fround($375 * $378);
       $390 = Math_fround($388 - $389);
       $391 = Math_fround(HEAPF32[$A>>2]);
       $392 = Math_fround(HEAPF32[$206>>2]);
       $393 = Math_fround(HEAPF32[$207>>2]);
       $394 = Math_fround($255 - $391);
       $395 = Math_fround($256 - $392);
       $396 = Math_fround($257 - $393);
       $397 = Math_fround(HEAPF32[$B>>2]);
       $398 = Math_fround(HEAPF32[$208>>2]);
       $399 = Math_fround(HEAPF32[$209>>2]);
       $400 = Math_fround($258 - $397);
       $401 = Math_fround($259 - $398);
       $402 = Math_fround($260 - $399);
       $403 = Math_fround($390 / $383);
       $404 = $403 > Math_fround(1.0);
       $$$i$i$i = $404 ? Math_fround(1.0) : $403;
       $405 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $405 ? $$$i$i$i : Math_fround(0.0);
       $406 = Math_fround($394 * $$$i8$i$i);
       $407 = Math_fround($395 * $$$i8$i$i);
       $408 = Math_fround($396 * $$$i8$i$i);
       $409 = Math_fround($391 + $406);
       $410 = Math_fround($392 + $407);
       $411 = Math_fround($393 + $408);
       $412 = Math_fround($400 * $$$i8$i$i);
       $413 = Math_fround($401 * $$$i8$i$i);
       $414 = Math_fround($402 * $$$i8$i$i);
       $415 = Math_fround($397 + $412);
       $416 = Math_fround($398 + $413);
       $417 = Math_fround($399 + $414);
       HEAPF32[$closA>>2] = $409;
       HEAPF32[$210>>2] = $410;
       HEAPF32[$211>>2] = $411;
       HEAPF32[$212>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $415;
       HEAPF32[$213>>2] = $416;
       HEAPF32[$214>>2] = $417;
       HEAPF32[$215>>2] = Math_fround(0.0);
       $418 = Math_fround($409 - $415);
       $419 = Math_fround($410 - $416);
       $420 = Math_fround($411 - $417);
       HEAPF32[$7>>2] = $418;
       HEAPF32[$216>>2] = $419;
       HEAPF32[$217>>2] = $420;
       HEAPF32[$218>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($264|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($7,$Q,$A,$B,$aInd,$bInd,$support,$supportA,$supportB,$size,$closA,$closB);
     } else {
      ;HEAP32[$7+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$7+12>>2]|0;
    $421 = Math_fround(HEAPF32[$v>>2]);
    $422 = Math_fround(HEAPF32[$184>>2]);
    $423 = Math_fround(HEAPF32[$185>>2]);
    $424 = Math_fround($421 * $421);
    $425 = Math_fround($422 * $422);
    $426 = Math_fround($424 + $425);
    $427 = Math_fround($423 * $423);
    $428 = Math_fround($426 + $427);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1350+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1350+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1350+8>>2]|0;
    $429 = $274 > $428;
    $430 = $428 > $21;
    if (!($430)) {
     label = 38;
     break;
    }
    if ($429) {
     $$$i10431084 = $$$i;$221 = $421;$223 = $422;$225 = $423;$274 = $428;
    } else {
     label = 38;
     break;
    }
   }
   if ((label|0) == 38) {
    $431 = HEAP32[$size>>2]|0;
    if ($429) {
     $521 = $431;
     break;
    }
    $432 = (($431) + -1)|0;
    $433 = ($aIndices|0)==(0|0);
    if (!($433)) {
     $434 = $432&255;
     HEAP8[$_size>>0] = $434;
     $435 = ($432|0)==(0);
     if (!($435)) {
      $i$01$i63 = 0;
      while(1) {
       $436 = (($aInd) + ($i$01$i63<<2)|0);
       $437 = HEAP32[$436>>2]|0;
       $438 = $437&255;
       $439 = (($aIndices) + ($i$01$i63)|0);
       HEAP8[$439>>0] = $438;
       $440 = (($bInd) + ($i$01$i63<<2)|0);
       $441 = HEAP32[$440>>2]|0;
       $442 = $441&255;
       $443 = (($bIndices) + ($i$01$i63)|0);
       HEAP8[$443>>0] = $442;
       $444 = (($i$01$i63) + 1)|0;
       $exitcond$i64 = ($444|0)==($432|0);
       if ($exitcond$i64) {
        break;
       } else {
        $i$01$i63 = $444;
       }
      }
     }
    }
    ;HEAP32[$closA+0>>2]=HEAP32[$tempClosA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$tempClosA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$tempClosA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$tempClosA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$tempClosB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$tempClosB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$tempClosB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$tempClosB+12>>2]|0;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $445 = Math_fround(HEAPF32[$closA>>2]);
    $446 = (($closA) + 4|0);
    $447 = Math_fround(HEAPF32[$446>>2]);
    $448 = (($closA) + 8|0);
    $449 = Math_fround(HEAPF32[$448>>2]);
    $450 = Math_fround(HEAPF32[$closB>>2]);
    $451 = (($closB) + 4|0);
    $452 = Math_fround(HEAPF32[$451>>2]);
    $453 = (($closB) + 8|0);
    $454 = Math_fround(HEAPF32[$453>>2]);
    $455 = Math_fround($445 - $450);
    $456 = Math_fround($447 - $452);
    $457 = Math_fround($449 - $454);
    HEAPF32[$v>>2] = $455;
    $458 = (($v) + 4|0);
    HEAPF32[$458>>2] = $456;
    $459 = (($v) + 8|0);
    HEAPF32[$459>>2] = $457;
    $460 = (($v) + 12|0);
    HEAPF32[$460>>2] = Math_fround(0.0);
    $461 = (Math_fround(Math_sqrt((Math_fround($274)))));
    $462 = Math_fround(Math_fround(1.0) / $461);
    $463 = Math_fround($455 * $462);
    $464 = Math_fround($456 * $462);
    $465 = Math_fround($457 * $462);
    if ($takeCoreShape) {
     $466 = (($a) + 64|0);
     $467 = HEAP32[$466>>2]|0;
     $468 = (($b) + 64|0);
     $469 = HEAP32[$468>>2]|0;
     $470 = ($467|0)==(0);
     $471 = $470 ? $10 : Math_fround(0.0);
     $472 = ($469|0)==(0);
     $473 = $472 ? $12 : Math_fround(0.0);
     $474 = Math_fround($471 + $473);
     $475 = Math_fround($463 * $471);
     $476 = Math_fround($464 * $471);
     $477 = Math_fround($465 * $471);
     $478 = Math_fround($445 - $475);
     $479 = Math_fround($447 - $476);
     $480 = Math_fround($449 - $477);
     HEAPF32[$contactA>>2] = $478;
     $481 = (($contactA) + 4|0);
     HEAPF32[$481>>2] = $479;
     $482 = (($contactA) + 8|0);
     HEAPF32[$482>>2] = $480;
     $483 = (($contactA) + 12|0);
     HEAPF32[$483>>2] = Math_fround(0.0);
     $484 = Math_fround($463 * $473);
     $485 = Math_fround($464 * $473);
     $486 = Math_fround($465 * $473);
     $487 = Math_fround($484 + $450);
     $488 = Math_fround($485 + $452);
     $489 = Math_fround($486 + $454);
     HEAPF32[$contactB>>2] = $487;
     $490 = (($contactB) + 4|0);
     HEAPF32[$490>>2] = $488;
     $491 = (($contactB) + 8|0);
     HEAPF32[$491>>2] = $489;
     $492 = (($contactB) + 12|0);
     HEAPF32[$492>>2] = Math_fround(0.0);
     $493 = Math_fround($461 - $474);
     HEAPF32[$penetrationDepth>>2] = $493;
     $494 = (($penetrationDepth) + 4|0);
     ;HEAP32[$494+0>>2]=HEAP32[$$sroa$1284+0>>2]|0;HEAP32[$494+4>>2]=HEAP32[$$sroa$1284+4>>2]|0;HEAP32[$494+8>>2]=HEAP32[$$sroa$1284+8>>2]|0;
    } else {
     $495 = Math_fround($10 * $463);
     $496 = Math_fround($10 * $464);
     $497 = Math_fround($10 * $465);
     $498 = Math_fround($445 - $495);
     $499 = Math_fround($447 - $496);
     $500 = Math_fround($449 - $497);
     HEAPF32[$contactA>>2] = $498;
     $501 = (($contactA) + 4|0);
     HEAPF32[$501>>2] = $499;
     $502 = (($contactA) + 8|0);
     HEAPF32[$502>>2] = $500;
     $503 = (($contactA) + 12|0);
     HEAPF32[$503>>2] = Math_fround(0.0);
     $504 = Math_fround($12 * $463);
     $505 = Math_fround($12 * $464);
     $506 = Math_fround($12 * $465);
     $507 = Math_fround($504 + $450);
     $508 = Math_fround($505 + $452);
     $509 = Math_fround($506 + $454);
     HEAPF32[$contactB>>2] = $507;
     $510 = (($contactB) + 4|0);
     HEAPF32[$510>>2] = $508;
     $511 = (($contactB) + 8|0);
     HEAPF32[$511>>2] = $509;
     $512 = (($contactB) + 12|0);
     HEAPF32[$512>>2] = Math_fround(0.0);
     $513 = Math_fround($461 - $19);
     HEAPF32[$penetrationDepth>>2] = $513;
     $514 = (($penetrationDepth) + 4|0);
     ;HEAP32[$514+0>>2]=HEAP32[$$sroa$1276+0>>2]|0;HEAP32[$514+4>>2]=HEAP32[$$sroa$1276+4>>2]|0;HEAP32[$514+8>>2]=HEAP32[$$sroa$1276+8>>2]|0;
    }
    HEAPF32[$normal>>2] = $463;
    $515 = (($normal) + 4|0);
    HEAPF32[$515>>2] = $464;
    $516 = (($normal) + 8|0);
    HEAPF32[$516>>2] = $465;
    $517 = (($normal) + 12|0);
    HEAPF32[$517>>2] = Math_fround(0.0);
    $518 = $22 >= $274;
    $$ = $518 ? 1 : 3;
    $$0 = $$;
    STACKTOP = sp;return ($$0|0);
   }
   $292 = ($aIndices|0)==(0|0);
   if (!($292)) {
    $293 = $264&255;
    HEAP8[$_size>>0] = $293;
    $294 = ($264|0)==(0);
    if (!($294)) {
     $i$01$i142 = 0;
     while(1) {
      $295 = (($aInd) + ($i$01$i142<<2)|0);
      $296 = HEAP32[$295>>2]|0;
      $297 = $296&255;
      $298 = (($aIndices) + ($i$01$i142)|0);
      HEAP8[$298>>0] = $297;
      $299 = (($bInd) + ($i$01$i142<<2)|0);
      $300 = HEAP32[$299>>2]|0;
      $301 = $300&255;
      $302 = (($bIndices) + ($i$01$i142)|0);
      HEAP8[$302>>0] = $301;
      $303 = (($i$01$i142) + 1)|0;
      $exitcond$i143 = ($303|0)==($264|0);
      if ($exitcond$i143) {
       break;
      } else {
       $i$01$i142 = $303;
      }
     }
    }
   }
   $not$ = $289 ^ 1;
   $$$1056 = $291 & $not$;
   if (!($$$1056)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $304 = (Math_fround(Math_sqrt((Math_fround($274)))));
   $305 = Math_fround(Math_fround(1.0) / $304);
   $306 = Math_fround($275 * $305);
   $307 = Math_fround($276 * $305);
   $308 = Math_fround($277 * $305);
   HEAPF32[$normal>>2] = $306;
   $309 = (($normal) + 4|0);
   HEAPF32[$309>>2] = $307;
   $310 = (($normal) + 8|0);
   HEAPF32[$310>>2] = $308;
   $311 = (($normal) + 12|0);
   HEAPF32[$311>>2] = Math_fround(0.0);
   if ($takeCoreShape) {
    $312 = (($a) + 64|0);
    $313 = HEAP32[$312>>2]|0;
    $314 = (($b) + 64|0);
    $315 = HEAP32[$314>>2]|0;
    $316 = ($313|0)==(0);
    $317 = $316 ? $10 : Math_fround(0.0);
    $318 = ($315|0)==(0);
    $319 = $318 ? $12 : Math_fround(0.0);
    $320 = Math_fround($317 + $319);
    $321 = Math_fround(HEAPF32[$closA>>2]);
    $322 = Math_fround(HEAPF32[$210>>2]);
    $323 = Math_fround(HEAPF32[$211>>2]);
    $324 = Math_fround($306 * $317);
    $325 = Math_fround($307 * $317);
    $326 = Math_fround($308 * $317);
    $327 = Math_fround($321 - $324);
    $328 = Math_fround($322 - $325);
    $329 = Math_fround($323 - $326);
    HEAPF32[$contactA>>2] = $327;
    $330 = (($contactA) + 4|0);
    HEAPF32[$330>>2] = $328;
    $331 = (($contactA) + 8|0);
    HEAPF32[$331>>2] = $329;
    $332 = (($contactA) + 12|0);
    HEAPF32[$332>>2] = Math_fround(0.0);
    $333 = Math_fround(HEAPF32[$closB>>2]);
    $334 = Math_fround(HEAPF32[$213>>2]);
    $335 = Math_fround(HEAPF32[$214>>2]);
    $336 = Math_fround($306 * $319);
    $337 = Math_fround($307 * $319);
    $338 = Math_fround($308 * $319);
    $339 = Math_fround($336 + $333);
    $340 = Math_fround($337 + $334);
    $341 = Math_fround($338 + $335);
    HEAPF32[$contactB>>2] = $339;
    $342 = (($contactB) + 4|0);
    HEAPF32[$342>>2] = $340;
    $343 = (($contactB) + 8|0);
    HEAPF32[$343>>2] = $341;
    $344 = (($contactB) + 12|0);
    HEAPF32[$344>>2] = Math_fround(0.0);
    $345 = Math_fround($304 - $320);
    HEAPF32[$penetrationDepth>>2] = $345;
    $346 = (($penetrationDepth) + 4|0);
    ;HEAP32[$346+0>>2]=HEAP32[$$sroa$1362+0>>2]|0;HEAP32[$346+4>>2]=HEAP32[$$sroa$1362+4>>2]|0;HEAP32[$346+8>>2]=HEAP32[$$sroa$1362+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $347 = Math_fround(HEAPF32[$closA>>2]);
    $348 = Math_fround(HEAPF32[$210>>2]);
    $349 = Math_fround(HEAPF32[$211>>2]);
    $350 = Math_fround($10 * $306);
    $351 = Math_fround($10 * $307);
    $352 = Math_fround($10 * $308);
    $353 = Math_fround($347 - $350);
    $354 = Math_fround($348 - $351);
    $355 = Math_fround($349 - $352);
    HEAPF32[$contactA>>2] = $353;
    $356 = (($contactA) + 4|0);
    HEAPF32[$356>>2] = $354;
    $357 = (($contactA) + 8|0);
    HEAPF32[$357>>2] = $355;
    $358 = (($contactA) + 12|0);
    HEAPF32[$358>>2] = Math_fround(0.0);
    $359 = Math_fround(HEAPF32[$closB>>2]);
    $360 = Math_fround(HEAPF32[$213>>2]);
    $361 = Math_fround(HEAPF32[$214>>2]);
    $362 = Math_fround($12 * $306);
    $363 = Math_fround($12 * $307);
    $364 = Math_fround($12 * $308);
    $365 = Math_fround($362 + $359);
    $366 = Math_fround($363 + $360);
    $367 = Math_fround($364 + $361);
    HEAPF32[$contactB>>2] = $365;
    $368 = (($contactB) + 4|0);
    HEAPF32[$368>>2] = $366;
    $369 = (($contactB) + 8|0);
    HEAPF32[$369>>2] = $367;
    $370 = (($contactB) + 12|0);
    HEAPF32[$370>>2] = Math_fround(0.0);
    $371 = Math_fround($304 - $19);
    HEAPF32[$penetrationDepth>>2] = $371;
    $372 = (($penetrationDepth) + 4|0);
    ;HEAP32[$372+0>>2]=HEAP32[$$sroa$1352+0>>2]|0;HEAP32[$372+4>>2]=HEAP32[$$sroa$1352+4>>2]|0;HEAP32[$372+8>>2]=HEAP32[$$sroa$1352+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $183 = HEAP32[$size>>2]|0;
   $521 = $183;
  }
 } while(0);
 $519 = ($aIndices|0)==(0|0);
 if (!($519)) {
  $520 = $521&255;
  HEAP8[$_size>>0] = $520;
  $522 = ($521|0)==(0);
  if (!($522)) {
   $i$01$i = 0;
   while(1) {
    $523 = (($aInd) + ($i$01$i<<2)|0);
    $524 = HEAP32[$523>>2]|0;
    $525 = $524&255;
    $526 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$526>>0] = $525;
    $527 = (($bInd) + ($i$01$i<<2)|0);
    $528 = HEAP32[$527>>2]|0;
    $529 = $528&255;
    $530 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$530>>0] = $529;
    $531 = (($i$01$i) + 1)|0;
    $exitcond$i = ($531|0)==($521|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $531;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_18ConvexHullNoScaleVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$ = 0, $$$1064 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i250 = Math_fround(0), $$$i10511093 = Math_fround(0), $$$i204 = Math_fround(0), $$$i213 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i251 = Math_fround(0), $$0 = 0, $$0$i$i = 0, $$1060 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$ph1072 = Math_fround(0), $$ph1073 = 0, $$pre = 0;
 var $$pre$i = 0, $$pre1110 = Math_fround(0), $$pre1111 = Math_fround(0), $$pre1112 = Math_fround(0), $$sroa$1276 = 0, $$sroa$1284 = 0, $$sroa$1350 = 0, $$sroa$1352 = 0, $$sroa$1362 = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0);
 var $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0);
 var $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0);
 var $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0;
 var $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0;
 var $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0);
 var $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0);
 var $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0, $394 = Math_fround(0), $395 = 0;
 var $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0);
 var $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0);
 var $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0);
 var $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = 0, $454 = 0, $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0);
 var $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = Math_fround(0), $497 = 0, $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = Math_fround(0), $502 = 0;
 var $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0);
 var $521 = 0, $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0;
 var $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = Math_fround(0), $543 = 0, $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0);
 var $558 = Math_fround(0), $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = Math_fround(0), $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $aInd = 0, $b$a$i$i$i = 0, $b$a$i223 = 0;
 var $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i143 = 0, $exitcond$i64 = 0, $i$01$i = 0, $i$01$i142 = 0, $i$01$i63 = 0, $i$01095 = 0, $i$041$i$i$i = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $maxIndex$040$i$i$i = 0, $maxIndex$1$i$i$i = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp1068 = 0;
 var $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportA = 0, $supportB = 0, $tempClosA = 0, $tempClosB = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $0 = sp + 448|0;
 $1 = sp + 368|0;
 $2 = sp + 384|0;
 $3 = sp + 400|0;
 $zeroV = sp + 416|0;
 $closA = sp + 432|0;
 $closB = sp + 464|0;
 $sDist$sroa$1 = sp + 576|0;
 $minDist$sroa$1 = sp + 564|0;
 $tempClosA = sp + 96|0;
 $tempClosB = sp + 80|0;
 $v = sp + 64|0;
 $Q = sp;
 $A = sp + 176|0;
 $B = sp + 112|0;
 $aInd = sp + 592|0;
 $bInd = sp + 496|0;
 $supportA = sp + 240|0;
 $supportB = sp + 256|0;
 $support = sp + 272|0;
 $size = sp + 560|0;
 $lastQ = sp + 288|0;
 $lastA = sp + 304|0;
 $lastB = sp + 320|0;
 $4 = sp + 336|0;
 $$sroa$1362 = sp + 524|0;
 $$sroa$1352 = sp + 536|0;
 $5 = sp + 352|0;
 $$sroa$1350 = sp + 548|0;
 $$sroa$1284 = sp + 480|0;
 $$sroa$1276 = sp + 512|0;
 $6 = Math_fround(HEAPF32[$_contactDist>>2]);
 $7 = (($a) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($b) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i213 = $15 ? $14 : $12;
 $16 = Math_fround($$$i213 * Math_fround(0.100000001490116119385));
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $17 = Math_fround($8 + $10);
 $18 = Math_fround($6 + $17);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 ;HEAP32[$tempClosA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$tempClosB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $19 = Math_fround($16 * $16);
 $20 = Math_fround($18 * $18);
 ;HEAP32[$supportA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$supportB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$support+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAP32[$size>>2] = 0;
 $21 = HEAP8[$_size>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $153 = Math_fround(HEAPF32[$a>>2]);
  $154 = (($a) + 4|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = (($a) + 8|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = Math_fround(HEAPF32[$b>>2]);
  $159 = (($b) + 4|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = (($b) + 8|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($153 - $158);
  $164 = Math_fround($155 - $160);
  $165 = Math_fround($157 - $162);
  $166 = Math_fround($163 * $163);
  $167 = Math_fround($164 * $164);
  $168 = Math_fround($166 + $167);
  $169 = Math_fround($165 * $165);
  $170 = Math_fround($168 + $169);
  $171 = $170 > Math_fround(0.0);
  HEAPF32[$1>>2] = $163;
  $172 = (($1) + 4|0);
  HEAPF32[$172>>2] = $164;
  $173 = (($1) + 8|0);
  HEAPF32[$173>>2] = $165;
  $174 = (($1) + 12|0);
  HEAPF32[$174>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = Math_fround(1.0);
  $175 = (($0) + 4|0);
  HEAPF32[$175>>2] = Math_fround(0.0);
  $176 = (($0) + 8|0);
  HEAPF32[$176>>2] = Math_fround(0.0);
  $177 = (($0) + 12|0);
  HEAPF32[$177>>2] = Math_fround(0.0);
  $b$a$i223 = $171 ? $1 : $0;
  $178 = Math_fround(HEAPF32[$b$a$i223>>2]);
  $$in1$i = (($b$a$i223) + 4|0);
  $179 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i223) + 8|0);
  $180 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $178;
  $181 = (($v) + 4|0);
  HEAPF32[$181>>2] = $179;
  $182 = (($v) + 8|0);
  HEAPF32[$182>>2] = $180;
  $183 = (($v) + 12|0);
  HEAPF32[$183>>2] = Math_fround(0.0);
  $$ph1072 = Math_fround(3.40282346638528859812E+38);$$ph1073 = 1;$581 = $180;$582 = $179;$583 = $178;
 } else {
  ;HEAP32[$lastQ+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$zeroV+12>>2]|0;
  $23 = (($a) + 96|0);
  $24 = (($b) + 200|0);
  $25 = (($supportB) + 4|0);
  $26 = (($supportB) + 8|0);
  $27 = (($supportB) + 12|0);
  $28 = (($supportA) + 4|0);
  $29 = (($supportA) + 8|0);
  $30 = (($support) + 4|0);
  $31 = (($support) + 8|0);
  $32 = (($support) + 12|0);
  $$pre = HEAP32[$24>>2]|0;
  $56 = 0;$i$01095 = 0;
  while(1) {
   $33 = (($aIndices) + ($i$01095)|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34&255;
   $36 = (($aInd) + ($i$01095<<2)|0);
   HEAP32[$36>>2] = $35;
   $37 = (($bIndices) + ($i$01095)|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = $38&255;
   $40 = (($bInd) + ($i$01095<<2)|0);
   HEAP32[$40>>2] = $39;
   $41 = (1 - ($35))|0;
   $42 = (($23) + ($41<<4)|0);
   ;HEAP32[$supportA+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$42+12>>2]|0;
   $43 = (($$pre) + (($39*12)|0)|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = ((($$pre) + (($39*12)|0)|0) + 4|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = ((($$pre) + (($39*12)|0)|0) + 8|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   HEAPF32[$supportB>>2] = $44;
   HEAPF32[$25>>2] = $46;
   HEAPF32[$26>>2] = $48;
   HEAPF32[$27>>2] = Math_fround(0.0);
   $49 = Math_fround(HEAPF32[$supportA>>2]);
   $50 = Math_fround(HEAPF32[$28>>2]);
   $51 = Math_fround(HEAPF32[$29>>2]);
   $52 = Math_fround($49 - $44);
   $53 = Math_fround($50 - $46);
   $54 = Math_fround($51 - $48);
   HEAPF32[$support>>2] = $52;
   HEAPF32[$30>>2] = $53;
   HEAPF32[$31>>2] = $54;
   HEAPF32[$32>>2] = Math_fround(0.0);
   $55 = (($A) + ($56<<4)|0);
   ;HEAP32[$lastA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$supportA+12>>2]|0;
   ;HEAP32[$55+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$supportA+12>>2]|0;
   $57 = (($B) + ($56<<4)|0);
   ;HEAP32[$lastB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$supportB+12>>2]|0;
   ;HEAP32[$57+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$supportB+12>>2]|0;
   $58 = (($56) + 1)|0;
   $59 = (($Q) + ($56<<4)|0);
   ;HEAP32[$lastQ+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$support+12>>2]|0;
   ;HEAP32[$59+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$59+12>>2]=HEAP32[$support+12>>2]|0;
   $60 = (($i$01095) + 1)|0;
   $61 = $21&255;
   $62 = ($60>>>0)<($61>>>0);
   if ($62) {
    $56 = $58;$i$01095 = $60;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $58;
  do {
   if ((($56|0) == 2)) {
    $141 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$141,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($56|0) == 1)) {
    $63 = Math_fround(HEAPF32[$Q>>2]);
    $64 = (($Q) + 4|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    $66 = (($Q) + 8|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = Math_fround(HEAPF32[$lastQ>>2]);
    $69 = (($lastQ) + 4|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = (($lastQ) + 8|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = Math_fround($68 - $63);
    $74 = Math_fround($70 - $65);
    $75 = Math_fround($72 - $67);
    $76 = Math_fround($73 * $73);
    $77 = Math_fround($74 * $74);
    $78 = Math_fround($76 + $77);
    $79 = Math_fround($75 * $75);
    $80 = Math_fround($78 + $79);
    $81 = $80 == Math_fround(0.0);
    if ($81) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $82 = Math_fround($65 * $74);
     $83 = Math_fround(-$82);
     $84 = Math_fround($63 * $73);
     $85 = Math_fround($83 - $84);
     $86 = Math_fround($67 * $75);
     $87 = Math_fround($85 - $86);
     $88 = Math_fround(HEAPF32[$lastA>>2]);
     $89 = (($lastA) + 4|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     $91 = (($lastA) + 8|0);
     $92 = Math_fround(HEAPF32[$91>>2]);
     $93 = Math_fround(HEAPF32[$A>>2]);
     $94 = (($A) + 4|0);
     $95 = Math_fround(HEAPF32[$94>>2]);
     $96 = (($A) + 8|0);
     $97 = Math_fround(HEAPF32[$96>>2]);
     $98 = Math_fround($88 - $93);
     $99 = Math_fround($90 - $95);
     $100 = Math_fround($92 - $97);
     $101 = Math_fround(HEAPF32[$lastB>>2]);
     $102 = (($lastB) + 4|0);
     $103 = Math_fround(HEAPF32[$102>>2]);
     $104 = (($lastB) + 8|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = Math_fround(HEAPF32[$B>>2]);
     $107 = (($B) + 4|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     $109 = (($B) + 8|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = Math_fround($101 - $106);
     $112 = Math_fround($103 - $108);
     $113 = Math_fround($105 - $110);
     $114 = Math_fround($87 / $80);
     $115 = $114 > Math_fround(1.0);
     $$$i$i$i250 = $115 ? Math_fround(1.0) : $114;
     $116 = $$$i$i$i250 > Math_fround(0.0);
     $$$i8$i$i251 = $116 ? $$$i$i$i250 : Math_fround(0.0);
     $117 = Math_fround($98 * $$$i8$i$i251);
     $118 = Math_fround($99 * $$$i8$i$i251);
     $119 = Math_fround($100 * $$$i8$i$i251);
     $120 = Math_fround($93 + $117);
     $121 = Math_fround($95 + $118);
     $122 = Math_fround($97 + $119);
     $123 = Math_fround($111 * $$$i8$i$i251);
     $124 = Math_fround($112 * $$$i8$i$i251);
     $125 = Math_fround($113 * $$$i8$i$i251);
     $126 = Math_fround($106 + $123);
     $127 = Math_fround($108 + $124);
     $128 = Math_fround($110 + $125);
     HEAPF32[$closA>>2] = $120;
     $129 = (($closA) + 4|0);
     HEAPF32[$129>>2] = $121;
     $130 = (($closA) + 8|0);
     HEAPF32[$130>>2] = $122;
     $131 = (($closA) + 12|0);
     HEAPF32[$131>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $126;
     $132 = (($closB) + 4|0);
     HEAPF32[$132>>2] = $127;
     $133 = (($closB) + 8|0);
     HEAPF32[$133>>2] = $128;
     $134 = (($closB) + 12|0);
     HEAPF32[$134>>2] = Math_fround(0.0);
     $135 = Math_fround($120 - $126);
     $136 = Math_fround($121 - $127);
     $137 = Math_fround($122 - $128);
     HEAPF32[$4>>2] = $135;
     $138 = (($4) + 4|0);
     HEAPF32[$138>>2] = $136;
     $139 = (($4) + 8|0);
     HEAPF32[$139>>2] = $137;
     $140 = (($4) + 12|0);
     HEAPF32[$140>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($56|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($56|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$4+12>>2]|0;
  $142 = Math_fround(HEAPF32[$v>>2]);
  $143 = (($v) + 4|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = (($v) + 8|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = Math_fround($142 * $142);
  $148 = Math_fround($144 * $144);
  $149 = Math_fround($147 + $148);
  $150 = Math_fround($146 * $146);
  $151 = Math_fround($149 + $150);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $152 = $151 > $19;
  $$ph1072 = $151;$$ph1073 = $152;$581 = $146;$582 = $144;$583 = $142;
 }
 do {
  if ($$ph1073) {
   $185 = (($v) + 4|0);
   $186 = (($v) + 8|0);
   $187 = (($a) + 96|0);
   $188 = (($a) + 96|0);
   $189 = (($a) + 100|0);
   $190 = (($a) + 104|0);
   $191 = (($a) + 112|0);
   $192 = (($a) + 112|0);
   $193 = (($a) + 116|0);
   $194 = (($a) + 120|0);
   $195 = (($supportA) + 4|0);
   $196 = (($supportA) + 8|0);
   $197 = (($supportA) + 12|0);
   $198 = (($b) + 196|0);
   $199 = (($b) + 200|0);
   $200 = (($b) + 204|0);
   $201 = (($supportB) + 4|0);
   $202 = (($supportB) + 8|0);
   $203 = (($supportB) + 12|0);
   $204 = (($support) + 4|0);
   $205 = (($support) + 8|0);
   $206 = (($support) + 12|0);
   $207 = (($a) + 48|0);
   $208 = (($b) + 48|0);
   $209 = (($Q) + 4|0);
   $210 = (($Q) + 8|0);
   $211 = (($A) + 4|0);
   $212 = (($A) + 8|0);
   $213 = (($B) + 4|0);
   $214 = (($B) + 8|0);
   $215 = (($closA) + 4|0);
   $216 = (($closA) + 8|0);
   $217 = (($closA) + 12|0);
   $218 = (($closB) + 4|0);
   $219 = (($closB) + 8|0);
   $220 = (($closB) + 12|0);
   $221 = (($5) + 4|0);
   $222 = (($5) + 8|0);
   $223 = (($5) + 12|0);
   $224 = (($Q) + 16|0);
   $$$i10511093 = $6;$226 = $583;$228 = $582;$230 = $581;$323 = $$ph1072;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    ;HEAP32[$tempClosA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$closA+12>>2]|0;
    ;HEAP32[$tempClosB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$closB+12>>2]|0;
    $225 = Math_fround(-$226);
    $227 = Math_fround(-$228);
    $229 = Math_fround(-$230);
    $231 = HEAP32[$size>>2]|0;
    $232 = (($aInd) + ($231<<2)|0);
    $233 = Math_fround(HEAPF32[$188>>2]);
    $234 = Math_fround(HEAPF32[$189>>2]);
    $235 = Math_fround(HEAPF32[$190>>2]);
    $236 = Math_fround($233 * $225);
    $237 = Math_fround($234 * $227);
    $238 = Math_fround($236 + $237);
    $239 = Math_fround($235 * $229);
    $240 = Math_fround($238 + $239);
    $241 = Math_fround(HEAPF32[$192>>2]);
    $242 = Math_fround(HEAPF32[$193>>2]);
    $243 = Math_fround(HEAPF32[$194>>2]);
    $244 = Math_fround($241 * $225);
    $245 = Math_fround($242 * $227);
    $246 = Math_fround($244 + $245);
    $247 = Math_fround($243 * $229);
    $248 = Math_fround($246 + $247);
    $249 = $240 > $248;
    $250 = $249&1;
    HEAP32[$232>>2] = $250;
    ;HEAP32[$3+0>>2]=HEAP32[$187+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$187+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$187+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$187+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$191+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$191+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$191+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$191+12>>2]|0;
    $b$a$i$i$i = $249 ? $3 : $2;
    $251 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
    $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
    $252 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
    $253 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    $254 = (($A) + ($231<<4)|0);
    HEAPF32[$254>>2] = $251;
    $255 = ((($A) + ($231<<4)|0) + 4|0);
    HEAPF32[$255>>2] = $252;
    $256 = ((($A) + ($231<<4)|0) + 8|0);
    HEAPF32[$256>>2] = $253;
    $257 = ((($A) + ($231<<4)|0) + 12|0);
    HEAPF32[$257>>2] = Math_fround(0.0);
    HEAPF32[$supportA>>2] = $251;
    HEAPF32[$195>>2] = $252;
    HEAPF32[$196>>2] = $253;
    HEAPF32[$197>>2] = Math_fround(0.0);
    $258 = (($bInd) + ($231<<2)|0);
    $259 = HEAP32[$198>>2]|0;
    $260 = ($259|0)==(0|0);
    if ($260) {
     $262 = HEAP32[$199>>2]|0;
     $263 = HEAP8[$200>>0]|0;
     $264 = ($263&255)>(1);
     if ($264) {
      $265 = (($262) + 4|0);
      $266 = (($262) + 8|0);
      $267 = Math_fround(HEAPF32[$265>>2]);
      $268 = Math_fround(HEAPF32[$262>>2]);
      $269 = Math_fround($228 * $267);
      $270 = Math_fround($226 * $268);
      $271 = Math_fround(HEAPF32[$266>>2]);
      $272 = Math_fround($230 * $271);
      $273 = Math_fround($269 + $270);
      $274 = Math_fround($273 + $272);
      $276 = $262;$290 = $274;$i$041$i$i$i = 1;$maxIndex$040$i$i$i = 0;
      while(1) {
       $$sum$i$i$i = (($i$041$i$i$i) + 10)|0;
       $275 = ((($276) + (($$sum$i$i$i*12)|0)|0) + 8|0);
       $277 = HEAP32[$199>>2]|0;
       $278 = (($277) + (($i$041$i$i$i*12)|0)|0);
       $279 = Math_fround(HEAPF32[$278>>2]);
       $280 = ((($277) + (($i$041$i$i$i*12)|0)|0) + 4|0);
       $281 = Math_fround(HEAPF32[$280>>2]);
       $282 = ((($277) + (($i$041$i$i$i*12)|0)|0) + 8|0);
       $283 = Math_fround(HEAPF32[$282>>2]);
       $284 = Math_fround($279 * $226);
       $285 = Math_fround($281 * $228);
       $286 = Math_fround($284 + $285);
       $287 = Math_fround($283 * $230);
       $288 = Math_fround($286 + $287);
       $289 = $288 > $290;
       $291 = $289 ? $288 : $290;
       $maxIndex$1$i$i$i = $289 ? $i$041$i$i$i : $maxIndex$040$i$i$i;
       $292 = (($i$041$i$i$i) + 1)|0;
       $293 = HEAP8[$200>>0]|0;
       $294 = $293&255;
       $295 = ($292>>>0)<($294>>>0);
       if ($295) {
        $276 = $277;$290 = $291;$i$041$i$i$i = $292;$maxIndex$040$i$i$i = $maxIndex$1$i$i$i;
       } else {
        $$0$i$i = $maxIndex$1$i$i$i;$297 = $277;$325 = $226;$327 = $228;$330 = $230;
        break;
       }
      }
     } else {
      $$0$i$i = 0;$297 = $262;$325 = $226;$327 = $228;$330 = $230;
     }
    } else {
     $261 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($b,$v)|0);
     $$pre$i = HEAP32[$199>>2]|0;
     $$pre1110 = Math_fround(HEAPF32[$v>>2]);
     $$pre1111 = Math_fround(HEAPF32[$185>>2]);
     $$pre1112 = Math_fround(HEAPF32[$186>>2]);
     $$0$i$i = $261;$297 = $$pre$i;$325 = $$pre1110;$327 = $$pre1111;$330 = $$pre1112;
    }
    HEAP32[$258>>2] = $$0$i$i;
    $296 = (($297) + (($$0$i$i*12)|0)|0);
    $298 = Math_fround(HEAPF32[$296>>2]);
    $299 = ((($297) + (($$0$i$i*12)|0)|0) + 4|0);
    $300 = Math_fround(HEAPF32[$299>>2]);
    $301 = ((($297) + (($$0$i$i*12)|0)|0) + 8|0);
    $302 = Math_fround(HEAPF32[$301>>2]);
    $303 = (($B) + ($231<<4)|0);
    HEAPF32[$303>>2] = $298;
    $304 = ((($B) + ($231<<4)|0) + 4|0);
    HEAPF32[$304>>2] = $300;
    $305 = ((($B) + ($231<<4)|0) + 8|0);
    HEAPF32[$305>>2] = $302;
    $306 = ((($B) + ($231<<4)|0) + 12|0);
    HEAPF32[$306>>2] = Math_fround(0.0);
    HEAPF32[$supportB>>2] = $298;
    HEAPF32[$201>>2] = $300;
    HEAPF32[$202>>2] = $302;
    HEAPF32[$203>>2] = Math_fround(0.0);
    $307 = Math_fround(HEAPF32[$supportA>>2]);
    $308 = Math_fround(HEAPF32[$195>>2]);
    $309 = Math_fround(HEAPF32[$196>>2]);
    $310 = Math_fround($307 - $298);
    $311 = Math_fround($308 - $300);
    $312 = Math_fround($309 - $302);
    HEAPF32[$support>>2] = $310;
    HEAPF32[$204>>2] = $311;
    HEAPF32[$205>>2] = $312;
    HEAPF32[$206>>2] = Math_fround(0.0);
    $313 = HEAP32[$size>>2]|0;
    $314 = (($313) + 1)|0;
    HEAP32[$size>>2] = $314;
    $315 = (($Q) + ($313<<4)|0);
    ;HEAP32[$315+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$315+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$315+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$315+12>>2]=HEAP32[$support+12>>2]|0;
    $316 = Math_fround(HEAPF32[$207>>2]);
    $317 = Math_fround(HEAPF32[$208>>2]);
    $318 = $316 > $317;
    $$$i204 = $318 ? $316 : $317;
    $319 = $$$i10511093 > $$$i204;
    $$$i = $319 ? $$$i10511093 : $$$i204;
    $320 = Math_fround($17 + $$$i);
    $321 = Math_fround($320 * $320);
    $322 = Math_fround($323 * $321);
    $324 = Math_fround($325 * $310);
    $326 = Math_fround($327 * $311);
    $328 = Math_fround($324 + $326);
    $329 = Math_fround($330 * $312);
    $331 = Math_fround($328 + $329);
    $332 = Math_fround($331 * $331);
    $333 = $331 > Math_fround(0.0);
    $334 = $332 > $322;
    if ($333) {
     $phitmp1068 = $334 ^ 1;
     $338 = $334;$340 = $phitmp1068;
    } else {
     $338 = 0;$340 = 1;
    }
    $335 = Math_fround($323 - $331);
    $336 = Math_fround($19 * $323);
    $337 = $336 >= $335;
    $brmerge$demorgan = $337 | $338;
    if ($brmerge$demorgan) {
     $339 = $340 ^ 1;
     $$1060 = $337 | $339;
     if ($$1060) {
      break;
     }
    }
    do {
     if ((($313|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$224,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($313|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($313|0) == 1)) {
      $422 = Math_fround(HEAPF32[$Q>>2]);
      $423 = Math_fround(HEAPF32[$209>>2]);
      $424 = Math_fround(HEAPF32[$210>>2]);
      $425 = Math_fround($310 - $422);
      $426 = Math_fround($311 - $423);
      $427 = Math_fround($312 - $424);
      $428 = Math_fround($425 * $425);
      $429 = Math_fround($426 * $426);
      $430 = Math_fround($428 + $429);
      $431 = Math_fround($427 * $427);
      $432 = Math_fround($430 + $431);
      $433 = $432 == Math_fround(0.0);
      if ($433) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $434 = Math_fround($423 * $426);
       $435 = Math_fround(-$434);
       $436 = Math_fround($422 * $425);
       $437 = Math_fround($435 - $436);
       $438 = Math_fround($424 * $427);
       $439 = Math_fround($437 - $438);
       $440 = Math_fround(HEAPF32[$A>>2]);
       $441 = Math_fround(HEAPF32[$211>>2]);
       $442 = Math_fround(HEAPF32[$212>>2]);
       $443 = Math_fround($307 - $440);
       $444 = Math_fround($308 - $441);
       $445 = Math_fround($309 - $442);
       $446 = Math_fround(HEAPF32[$B>>2]);
       $447 = Math_fround(HEAPF32[$213>>2]);
       $448 = Math_fround(HEAPF32[$214>>2]);
       $449 = Math_fround($298 - $446);
       $450 = Math_fround($300 - $447);
       $451 = Math_fround($302 - $448);
       $452 = Math_fround($439 / $432);
       $453 = $452 > Math_fround(1.0);
       $$$i$i$i = $453 ? Math_fround(1.0) : $452;
       $454 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $454 ? $$$i$i$i : Math_fround(0.0);
       $455 = Math_fround($443 * $$$i8$i$i);
       $456 = Math_fround($444 * $$$i8$i$i);
       $457 = Math_fround($445 * $$$i8$i$i);
       $458 = Math_fround($440 + $455);
       $459 = Math_fround($441 + $456);
       $460 = Math_fround($442 + $457);
       $461 = Math_fround($449 * $$$i8$i$i);
       $462 = Math_fround($450 * $$$i8$i$i);
       $463 = Math_fround($451 * $$$i8$i$i);
       $464 = Math_fround($446 + $461);
       $465 = Math_fround($447 + $462);
       $466 = Math_fround($448 + $463);
       HEAPF32[$closA>>2] = $458;
       HEAPF32[$215>>2] = $459;
       HEAPF32[$216>>2] = $460;
       HEAPF32[$217>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $464;
       HEAPF32[$218>>2] = $465;
       HEAPF32[$219>>2] = $466;
       HEAPF32[$220>>2] = Math_fround(0.0);
       $467 = Math_fround($458 - $464);
       $468 = Math_fround($459 - $465);
       $469 = Math_fround($460 - $466);
       HEAPF32[$5>>2] = $467;
       HEAPF32[$221>>2] = $468;
       HEAPF32[$222>>2] = $469;
       HEAPF32[$223>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($313|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support,$supportA,$supportB,$size,$closA,$closB);
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
    $470 = Math_fround(HEAPF32[$v>>2]);
    $471 = Math_fround(HEAPF32[$185>>2]);
    $472 = Math_fround(HEAPF32[$186>>2]);
    $473 = Math_fround($470 * $470);
    $474 = Math_fround($471 * $471);
    $475 = Math_fround($473 + $474);
    $476 = Math_fround($472 * $472);
    $477 = Math_fround($475 + $476);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1350+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1350+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1350+8>>2]|0;
    $478 = $323 > $477;
    $479 = $477 > $19;
    if (!($479)) {
     label = 43;
     break;
    }
    if ($478) {
     $$$i10511093 = $$$i;$226 = $470;$228 = $471;$230 = $472;$323 = $477;
    } else {
     label = 43;
     break;
    }
   }
   if ((label|0) == 43) {
    $480 = HEAP32[$size>>2]|0;
    if ($478) {
     $570 = $480;
     break;
    }
    $481 = (($480) + -1)|0;
    $482 = ($aIndices|0)==(0|0);
    if (!($482)) {
     $483 = $481&255;
     HEAP8[$_size>>0] = $483;
     $484 = ($481|0)==(0);
     if (!($484)) {
      $i$01$i63 = 0;
      while(1) {
       $485 = (($aInd) + ($i$01$i63<<2)|0);
       $486 = HEAP32[$485>>2]|0;
       $487 = $486&255;
       $488 = (($aIndices) + ($i$01$i63)|0);
       HEAP8[$488>>0] = $487;
       $489 = (($bInd) + ($i$01$i63<<2)|0);
       $490 = HEAP32[$489>>2]|0;
       $491 = $490&255;
       $492 = (($bIndices) + ($i$01$i63)|0);
       HEAP8[$492>>0] = $491;
       $493 = (($i$01$i63) + 1)|0;
       $exitcond$i64 = ($493|0)==($481|0);
       if ($exitcond$i64) {
        break;
       } else {
        $i$01$i63 = $493;
       }
      }
     }
    }
    ;HEAP32[$closA+0>>2]=HEAP32[$tempClosA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$tempClosA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$tempClosA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$tempClosA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$tempClosB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$tempClosB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$tempClosB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$tempClosB+12>>2]|0;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $494 = Math_fround(HEAPF32[$closA>>2]);
    $495 = (($closA) + 4|0);
    $496 = Math_fround(HEAPF32[$495>>2]);
    $497 = (($closA) + 8|0);
    $498 = Math_fround(HEAPF32[$497>>2]);
    $499 = Math_fround(HEAPF32[$closB>>2]);
    $500 = (($closB) + 4|0);
    $501 = Math_fround(HEAPF32[$500>>2]);
    $502 = (($closB) + 8|0);
    $503 = Math_fround(HEAPF32[$502>>2]);
    $504 = Math_fround($494 - $499);
    $505 = Math_fround($496 - $501);
    $506 = Math_fround($498 - $503);
    HEAPF32[$v>>2] = $504;
    $507 = (($v) + 4|0);
    HEAPF32[$507>>2] = $505;
    $508 = (($v) + 8|0);
    HEAPF32[$508>>2] = $506;
    $509 = (($v) + 12|0);
    HEAPF32[$509>>2] = Math_fround(0.0);
    $510 = (Math_fround(Math_sqrt((Math_fround($323)))));
    $511 = Math_fround(Math_fround(1.0) / $510);
    $512 = Math_fround($504 * $511);
    $513 = Math_fround($505 * $511);
    $514 = Math_fround($506 * $511);
    if ($takeCoreShape) {
     $515 = (($a) + 64|0);
     $516 = HEAP32[$515>>2]|0;
     $517 = (($b) + 64|0);
     $518 = HEAP32[$517>>2]|0;
     $519 = ($516|0)==(0);
     $520 = $519 ? $8 : Math_fround(0.0);
     $521 = ($518|0)==(0);
     $522 = $521 ? $10 : Math_fround(0.0);
     $523 = Math_fround($520 + $522);
     $524 = Math_fround($512 * $520);
     $525 = Math_fround($513 * $520);
     $526 = Math_fround($514 * $520);
     $527 = Math_fround($494 - $524);
     $528 = Math_fround($496 - $525);
     $529 = Math_fround($498 - $526);
     HEAPF32[$contactA>>2] = $527;
     $530 = (($contactA) + 4|0);
     HEAPF32[$530>>2] = $528;
     $531 = (($contactA) + 8|0);
     HEAPF32[$531>>2] = $529;
     $532 = (($contactA) + 12|0);
     HEAPF32[$532>>2] = Math_fround(0.0);
     $533 = Math_fround($512 * $522);
     $534 = Math_fround($513 * $522);
     $535 = Math_fround($514 * $522);
     $536 = Math_fround($533 + $499);
     $537 = Math_fround($534 + $501);
     $538 = Math_fround($535 + $503);
     HEAPF32[$contactB>>2] = $536;
     $539 = (($contactB) + 4|0);
     HEAPF32[$539>>2] = $537;
     $540 = (($contactB) + 8|0);
     HEAPF32[$540>>2] = $538;
     $541 = (($contactB) + 12|0);
     HEAPF32[$541>>2] = Math_fround(0.0);
     $542 = Math_fround($510 - $523);
     HEAPF32[$penetrationDepth>>2] = $542;
     $543 = (($penetrationDepth) + 4|0);
     ;HEAP32[$543+0>>2]=HEAP32[$$sroa$1284+0>>2]|0;HEAP32[$543+4>>2]=HEAP32[$$sroa$1284+4>>2]|0;HEAP32[$543+8>>2]=HEAP32[$$sroa$1284+8>>2]|0;
    } else {
     $544 = Math_fround($8 * $512);
     $545 = Math_fround($8 * $513);
     $546 = Math_fround($8 * $514);
     $547 = Math_fround($494 - $544);
     $548 = Math_fround($496 - $545);
     $549 = Math_fround($498 - $546);
     HEAPF32[$contactA>>2] = $547;
     $550 = (($contactA) + 4|0);
     HEAPF32[$550>>2] = $548;
     $551 = (($contactA) + 8|0);
     HEAPF32[$551>>2] = $549;
     $552 = (($contactA) + 12|0);
     HEAPF32[$552>>2] = Math_fround(0.0);
     $553 = Math_fround($10 * $512);
     $554 = Math_fround($10 * $513);
     $555 = Math_fround($10 * $514);
     $556 = Math_fround($553 + $499);
     $557 = Math_fround($554 + $501);
     $558 = Math_fround($555 + $503);
     HEAPF32[$contactB>>2] = $556;
     $559 = (($contactB) + 4|0);
     HEAPF32[$559>>2] = $557;
     $560 = (($contactB) + 8|0);
     HEAPF32[$560>>2] = $558;
     $561 = (($contactB) + 12|0);
     HEAPF32[$561>>2] = Math_fround(0.0);
     $562 = Math_fround($510 - $17);
     HEAPF32[$penetrationDepth>>2] = $562;
     $563 = (($penetrationDepth) + 4|0);
     ;HEAP32[$563+0>>2]=HEAP32[$$sroa$1276+0>>2]|0;HEAP32[$563+4>>2]=HEAP32[$$sroa$1276+4>>2]|0;HEAP32[$563+8>>2]=HEAP32[$$sroa$1276+8>>2]|0;
    }
    HEAPF32[$normal>>2] = $512;
    $564 = (($normal) + 4|0);
    HEAPF32[$564>>2] = $513;
    $565 = (($normal) + 8|0);
    HEAPF32[$565>>2] = $514;
    $566 = (($normal) + 12|0);
    HEAPF32[$566>>2] = Math_fround(0.0);
    $567 = $20 >= $323;
    $$ = $567 ? 1 : 3;
    $$0 = $$;
    STACKTOP = sp;return ($$0|0);
   }
   $341 = ($aIndices|0)==(0|0);
   if (!($341)) {
    $342 = $313&255;
    HEAP8[$_size>>0] = $342;
    $343 = ($313|0)==(0);
    if (!($343)) {
     $i$01$i142 = 0;
     while(1) {
      $344 = (($aInd) + ($i$01$i142<<2)|0);
      $345 = HEAP32[$344>>2]|0;
      $346 = $345&255;
      $347 = (($aIndices) + ($i$01$i142)|0);
      HEAP8[$347>>0] = $346;
      $348 = (($bInd) + ($i$01$i142<<2)|0);
      $349 = HEAP32[$348>>2]|0;
      $350 = $349&255;
      $351 = (($bIndices) + ($i$01$i142)|0);
      HEAP8[$351>>0] = $350;
      $352 = (($i$01$i142) + 1)|0;
      $exitcond$i143 = ($352|0)==($313|0);
      if ($exitcond$i143) {
       break;
      } else {
       $i$01$i142 = $352;
      }
     }
    }
   }
   $not$ = $338 ^ 1;
   $$$1064 = $340 & $not$;
   if (!($$$1064)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $353 = (Math_fround(Math_sqrt((Math_fround($323)))));
   $354 = Math_fround(Math_fround(1.0) / $353);
   $355 = Math_fround($325 * $354);
   $356 = Math_fround($327 * $354);
   $357 = Math_fround($330 * $354);
   HEAPF32[$normal>>2] = $355;
   $358 = (($normal) + 4|0);
   HEAPF32[$358>>2] = $356;
   $359 = (($normal) + 8|0);
   HEAPF32[$359>>2] = $357;
   $360 = (($normal) + 12|0);
   HEAPF32[$360>>2] = Math_fround(0.0);
   if ($takeCoreShape) {
    $361 = (($a) + 64|0);
    $362 = HEAP32[$361>>2]|0;
    $363 = (($b) + 64|0);
    $364 = HEAP32[$363>>2]|0;
    $365 = ($362|0)==(0);
    $366 = $365 ? $8 : Math_fround(0.0);
    $367 = ($364|0)==(0);
    $368 = $367 ? $10 : Math_fround(0.0);
    $369 = Math_fround($366 + $368);
    $370 = Math_fround(HEAPF32[$closA>>2]);
    $371 = Math_fround(HEAPF32[$215>>2]);
    $372 = Math_fround(HEAPF32[$216>>2]);
    $373 = Math_fround($355 * $366);
    $374 = Math_fround($356 * $366);
    $375 = Math_fround($357 * $366);
    $376 = Math_fround($370 - $373);
    $377 = Math_fround($371 - $374);
    $378 = Math_fround($372 - $375);
    HEAPF32[$contactA>>2] = $376;
    $379 = (($contactA) + 4|0);
    HEAPF32[$379>>2] = $377;
    $380 = (($contactA) + 8|0);
    HEAPF32[$380>>2] = $378;
    $381 = (($contactA) + 12|0);
    HEAPF32[$381>>2] = Math_fround(0.0);
    $382 = Math_fround(HEAPF32[$closB>>2]);
    $383 = Math_fround(HEAPF32[$218>>2]);
    $384 = Math_fround(HEAPF32[$219>>2]);
    $385 = Math_fround($355 * $368);
    $386 = Math_fround($356 * $368);
    $387 = Math_fround($357 * $368);
    $388 = Math_fround($385 + $382);
    $389 = Math_fround($386 + $383);
    $390 = Math_fround($387 + $384);
    HEAPF32[$contactB>>2] = $388;
    $391 = (($contactB) + 4|0);
    HEAPF32[$391>>2] = $389;
    $392 = (($contactB) + 8|0);
    HEAPF32[$392>>2] = $390;
    $393 = (($contactB) + 12|0);
    HEAPF32[$393>>2] = Math_fround(0.0);
    $394 = Math_fround($353 - $369);
    HEAPF32[$penetrationDepth>>2] = $394;
    $395 = (($penetrationDepth) + 4|0);
    ;HEAP32[$395+0>>2]=HEAP32[$$sroa$1362+0>>2]|0;HEAP32[$395+4>>2]=HEAP32[$$sroa$1362+4>>2]|0;HEAP32[$395+8>>2]=HEAP32[$$sroa$1362+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $396 = Math_fround(HEAPF32[$closA>>2]);
    $397 = Math_fround(HEAPF32[$215>>2]);
    $398 = Math_fround(HEAPF32[$216>>2]);
    $399 = Math_fround($8 * $355);
    $400 = Math_fround($8 * $356);
    $401 = Math_fround($8 * $357);
    $402 = Math_fround($396 - $399);
    $403 = Math_fround($397 - $400);
    $404 = Math_fround($398 - $401);
    HEAPF32[$contactA>>2] = $402;
    $405 = (($contactA) + 4|0);
    HEAPF32[$405>>2] = $403;
    $406 = (($contactA) + 8|0);
    HEAPF32[$406>>2] = $404;
    $407 = (($contactA) + 12|0);
    HEAPF32[$407>>2] = Math_fround(0.0);
    $408 = Math_fround(HEAPF32[$closB>>2]);
    $409 = Math_fround(HEAPF32[$218>>2]);
    $410 = Math_fround(HEAPF32[$219>>2]);
    $411 = Math_fround($10 * $355);
    $412 = Math_fround($10 * $356);
    $413 = Math_fround($10 * $357);
    $414 = Math_fround($411 + $408);
    $415 = Math_fround($412 + $409);
    $416 = Math_fround($413 + $410);
    HEAPF32[$contactB>>2] = $414;
    $417 = (($contactB) + 4|0);
    HEAPF32[$417>>2] = $415;
    $418 = (($contactB) + 8|0);
    HEAPF32[$418>>2] = $416;
    $419 = (($contactB) + 12|0);
    HEAPF32[$419>>2] = Math_fround(0.0);
    $420 = Math_fround($353 - $17);
    HEAPF32[$penetrationDepth>>2] = $420;
    $421 = (($penetrationDepth) + 4|0);
    ;HEAP32[$421+0>>2]=HEAP32[$$sroa$1352+0>>2]|0;HEAP32[$421+4>>2]=HEAP32[$$sroa$1352+4>>2]|0;HEAP32[$421+8>>2]=HEAP32[$$sroa$1352+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $184 = HEAP32[$size>>2]|0;
   $570 = $184;
  }
 } while(0);
 $568 = ($aIndices|0)==(0|0);
 if (!($568)) {
  $569 = $570&255;
  HEAP8[$_size>>0] = $569;
  $571 = ($570|0)==(0);
  if (!($571)) {
   $i$01$i = 0;
   while(1) {
    $572 = (($aInd) + ($i$01$i<<2)|0);
    $573 = HEAP32[$572>>2]|0;
    $574 = $573&255;
    $575 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$575>>0] = $574;
    $576 = (($bInd) + ($i$01$i<<2)|0);
    $577 = HEAP32[$576>>2]|0;
    $578 = $577&255;
    $579 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$579>>0] = $578;
    $580 = (($i$01$i) + 1)|0;
    $exitcond$i = ($580|0)==($570|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $580;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22GJKRelativePenetrationERKNS0_10ShrunkBoxVES3_RKNS_6shdfnd3aos15PsMatTransformVERKNS5_6FloatVERNS5_5Vec3VESD_SD_RS9_PhSF_Rh($a,$b,$aTob,$contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aTob = $aTob|0;
 $contactDist = $contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_10ShrunkBoxVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($a,$b,$aTob,$contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_10ShrunkBoxVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$773 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i171 = Math_fround(0), $$$i134 = Math_fround(0), $$$i206 = Math_fround(0), $$$i761831 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i172 = Math_fround(0), $$0 = 0, $$769 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i142 = 0, $$in1$i$i181 = 0, $$in1$i$i187 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i144 = 0, $$in2$i$i183 = 0;
 var $$in2$i$i189 = 0, $$ph = Math_fround(0), $$ph781 = Math_fround(0), $$ph782 = Math_fround(0), $$ph783 = Math_fround(0), $$ph784 = Math_fround(0), $$ph785 = Math_fround(0), $$ph786 = Math_fround(0), $$ph787 = Math_fround(0), $$ph789 = Math_fround(0), $$ph790 = 0, $$ph794 = Math_fround(0), $$ph795 = Math_fround(0), $$ph796 = Math_fround(0), $$pre = Math_fround(0), $$pre878 = Math_fround(0), $$pre879 = Math_fround(0), $$pre880 = Math_fround(0), $$pre881 = Math_fround(0), $$pre882 = Math_fround(0);
 var $$pre883 = Math_fround(0), $$pre884 = Math_fround(0), $$sroa$1 = 0, $$sroa$1250 = 0, $$sroa$1252 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0);
 var $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0;
 var $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = 0;
 var $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = Math_fround(0);
 var $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0;
 var $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0);
 var $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0);
 var $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0);
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0);
 var $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0;
 var $580 = Math_fround(0), $581 = Math_fround(0), $582 = 0, $583 = 0, $584 = 0, $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = 0, $593 = 0, $594 = Math_fround(0), $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0;
 var $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $A = 0, $B = 0, $Q = 0;
 var $a$pn3$i$i = 0, $a$pn3$i$i141 = 0, $a$pn3$i$i180 = 0, $a$pn3$i$i186 = 0, $aInd = 0, $b$a$i = 0, $b$a$i$i = 0, $b$a$i$i139 = 0, $b$a$i$i178 = 0, $b$a$i$i184 = 0, $b$a5$i$i = 0, $b$a5$i$i143 = 0, $b$a5$i$i182 = 0, $b$a5$i$i188 = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0;
 var $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$0841 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp777 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 368|0;
 $1 = sp + 320|0;
 $2 = sp + 336|0;
 $3 = sp + 352|0;
 $closA = sp + 384|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 484|0;
 $minDist$sroa$1 = sp + 472|0;
 $Q = sp;
 $A = sp + 144|0;
 $B = sp + 64|0;
 $aInd = sp + 456|0;
 $bInd = sp + 496|0;
 $size = sp + 416|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 208|0;
 $lastB = sp + 224|0;
 $4 = sp + 240|0;
 $supportA1 = sp + 256|0;
 $supportB2 = sp + 272|0;
 $support3 = sp + 288|0;
 $$sroa$1252 = sp + 432|0;
 $5 = sp + 304|0;
 $$sroa$1250 = sp + 444|0;
 $$sroa$1 = sp + 420|0;
 $6 = (($a) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($b) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$_contactDist>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i206 = $15 ? $14 : $12;
 $16 = Math_fround($$$i206 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($7 + $9);
 $18 = (($closA) + 4|0);
 $19 = (($closA) + 8|0);
 $20 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $21 = (($closB) + 4|0);
 $22 = (($closB) + 8|0);
 $23 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $24 = Math_fround($16 * $16);
 HEAP32[$size>>2] = 0;
 $25 = HEAP8[$_size>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $234 = (($aToB) + 48|0);
  $235 = Math_fround(HEAPF32[$234>>2]);
  $236 = (($aToB) + 52|0);
  $237 = Math_fround(HEAPF32[$236>>2]);
  $238 = (($aToB) + 56|0);
  $239 = Math_fround(HEAPF32[$238>>2]);
  $240 = (($aToB) + 60|0);
  $241 = Math_fround(HEAPF32[$240>>2]);
  $242 = Math_fround($235 * $235);
  $243 = Math_fround($237 * $237);
  $244 = Math_fround($242 + $243);
  $245 = Math_fround($239 * $239);
  $246 = Math_fround($244 + $245);
  $247 = $246 > Math_fround(0.0);
  HEAPF32[$3>>2] = $235;
  $248 = (($3) + 4|0);
  HEAPF32[$248>>2] = $237;
  $249 = (($3) + 8|0);
  HEAPF32[$249>>2] = $239;
  $250 = (($3) + 12|0);
  HEAPF32[$250>>2] = $241;
  HEAPF32[$2>>2] = Math_fround(1.0);
  $251 = (($2) + 4|0);
  HEAPF32[$251>>2] = Math_fround(0.0);
  $252 = (($2) + 8|0);
  HEAPF32[$252>>2] = Math_fround(0.0);
  $253 = (($2) + 12|0);
  HEAPF32[$253>>2] = Math_fround(0.0);
  $b$a$i = $247 ? $3 : $2;
  $254 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $255 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $256 = Math_fround(HEAPF32[$$in2$i>>2]);
  $$ph = Math_fround(0.0);$$ph781 = Math_fround(0.0);$$ph782 = Math_fround(0.0);$$ph783 = Math_fround(0.0);$$ph784 = Math_fround(0.0);$$ph785 = Math_fround(0.0);$$ph786 = Math_fround(0.0);$$ph787 = Math_fround(0.0);$$ph789 = Math_fround(3.40282346638528859812E+38);$$ph790 = 1;$$ph794 = $256;$$ph795 = $255;$$ph796 = $254;
 } else {
  $27 = (($lastQ) + 4|0);
  $28 = (($lastQ) + 8|0);
  $29 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $30 = (($lastA) + 4|0);
  $31 = (($lastA) + 8|0);
  $32 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $33 = (($lastB) + 4|0);
  $34 = (($lastB) + 8|0);
  $35 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $36 = (($a) + 144|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($a) + 148|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($a) + 152|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($37 - $7);
  $43 = Math_fround($39 - $7);
  $44 = Math_fround($41 - $7);
  $45 = Math_fround(-$42);
  $46 = Math_fround(-$43);
  $47 = Math_fround(-$44);
  $48 = (($1) + 4|0);
  $49 = (($1) + 8|0);
  $50 = (($1) + 12|0);
  $51 = (($0) + 4|0);
  $52 = (($0) + 8|0);
  $53 = (($0) + 12|0);
  $54 = (($aToB) + 48|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($aToB) + 52|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($aToB) + 56|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround(HEAPF32[$aToB>>2]);
  $61 = (($aToB) + 16|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = (($aToB) + 32|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($aToB) + 4|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = (($aToB) + 20|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($aToB) + 36|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = (($aToB) + 8|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($aToB) + 24|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($aToB) + 40|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($b) + 144|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($b) + 148|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = (($b) + 152|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($78 - $9);
  $84 = Math_fround($80 - $9);
  $85 = Math_fround($82 - $9);
  $86 = Math_fround(-$83);
  $87 = Math_fround(-$84);
  $88 = Math_fround(-$85);
  $89 = (($1) + 4|0);
  $90 = (($1) + 8|0);
  $91 = (($1) + 12|0);
  $92 = (($0) + 4|0);
  $93 = (($0) + 8|0);
  $94 = (($0) + 12|0);
  $95 = $25&255;
  $96 = ($95>>>0)>(1);
  $umax = $96 ? $95 : 1;
  $151 = 0;$i$0841 = 0;
  while(1) {
   $97 = (($aIndices) + ($i$0841)|0);
   $98 = HEAP8[$97>>0]|0;
   $99 = $98&255;
   $100 = (($aInd) + ($i$0841<<2)|0);
   HEAP32[$100>>2] = $99;
   $101 = (($bIndices) + ($i$0841)|0);
   $102 = HEAP8[$101>>0]|0;
   $103 = $102&255;
   $104 = (($bInd) + ($i$0841<<2)|0);
   HEAP32[$104>>2] = $103;
   $105 = (549664 + ($99<<4)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ((549664 + ($99<<4)|0) + 4|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = ((549664 + ($99<<4)|0) + 8|0);
   $110 = HEAP32[$109>>2]|0;
   HEAPF32[$1>>2] = $42;
   HEAPF32[$48>>2] = $43;
   HEAPF32[$49>>2] = $44;
   HEAPF32[$50>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $45;
   HEAPF32[$51>>2] = $46;
   HEAPF32[$52>>2] = $47;
   HEAPF32[$53>>2] = Math_fround(0.0);
   $111 = ($106|0)==(0);
   $b$a$i$i184 = $111 ? $0 : $1;
   $112 = Math_fround(HEAPF32[$b$a$i$i184>>2]);
   $113 = ($108|0)==(0);
   $a$pn3$i$i186 = $113 ? $0 : $1;
   $$in1$i$i187 = (($a$pn3$i$i186) + 4|0);
   $114 = Math_fround(HEAPF32[$$in1$i$i187>>2]);
   $115 = ($110|0)==(0);
   $b$a5$i$i188 = $115 ? $0 : $1;
   $$in2$i$i189 = (($b$a5$i$i188) + 8|0);
   $116 = Math_fround(HEAPF32[$$in2$i$i189>>2]);
   $117 = Math_fround($112 * $60);
   $118 = Math_fround($114 * $62);
   $119 = Math_fround($117 + $118);
   $120 = Math_fround($116 * $64);
   $121 = Math_fround($119 + $120);
   $122 = Math_fround($112 * $66);
   $123 = Math_fround($114 * $68);
   $124 = Math_fround($122 + $123);
   $125 = Math_fround($116 * $70);
   $126 = Math_fround($124 + $125);
   $127 = Math_fround($112 * $72);
   $128 = Math_fround($114 * $74);
   $129 = Math_fround($127 + $128);
   $130 = Math_fround($116 * $76);
   $131 = Math_fround($129 + $130);
   $132 = Math_fround($55 + $121);
   $133 = Math_fround($57 + $126);
   $134 = Math_fround($59 + $131);
   $135 = (549664 + ($103<<4)|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ((549664 + ($103<<4)|0) + 4|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ((549664 + ($103<<4)|0) + 8|0);
   $140 = HEAP32[$139>>2]|0;
   HEAPF32[$1>>2] = $83;
   HEAPF32[$89>>2] = $84;
   HEAPF32[$90>>2] = $85;
   HEAPF32[$91>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $86;
   HEAPF32[$92>>2] = $87;
   HEAPF32[$93>>2] = $88;
   HEAPF32[$94>>2] = Math_fround(0.0);
   $141 = ($136|0)==(0);
   $b$a$i$i178 = $141 ? $0 : $1;
   $142 = Math_fround(HEAPF32[$b$a$i$i178>>2]);
   $143 = ($138|0)==(0);
   $a$pn3$i$i180 = $143 ? $0 : $1;
   $$in1$i$i181 = (($a$pn3$i$i180) + 4|0);
   $144 = Math_fround(HEAPF32[$$in1$i$i181>>2]);
   $145 = ($140|0)==(0);
   $b$a5$i$i182 = $145 ? $0 : $1;
   $$in2$i$i183 = (($b$a5$i$i182) + 8|0);
   $146 = Math_fround(HEAPF32[$$in2$i$i183>>2]);
   $147 = Math_fround($132 - $142);
   $148 = Math_fround($133 - $144);
   $149 = Math_fround($134 - $146);
   $150 = (($A) + ($151<<4)|0);
   HEAPF32[$lastA>>2] = $132;
   HEAPF32[$30>>2] = $133;
   HEAPF32[$31>>2] = $134;
   HEAPF32[$32>>2] = Math_fround(0.0);
   ;HEAP32[$150+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$150+12>>2]=HEAP32[$lastA+12>>2]|0;
   $152 = (($B) + ($151<<4)|0);
   HEAPF32[$lastB>>2] = $142;
   HEAPF32[$33>>2] = $144;
   HEAPF32[$34>>2] = $146;
   HEAPF32[$35>>2] = Math_fround(0.0);
   ;HEAP32[$152+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$152+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$152+12>>2]=HEAP32[$lastB+12>>2]|0;
   $153 = (($151) + 1)|0;
   $154 = (($Q) + ($151<<4)|0);
   HEAPF32[$lastQ>>2] = $147;
   HEAPF32[$27>>2] = $148;
   HEAPF32[$28>>2] = $149;
   HEAPF32[$29>>2] = Math_fround(0.0);
   ;HEAP32[$154+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$154+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$154+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$154+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $155 = (($i$0841) + 1)|0;
   $156 = ($155>>>0)<($95>>>0);
   if ($156) {
    $151 = $153;$i$0841 = $155;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $umax;
  do {
   if ((($umax|0) == 3)) {
    $214 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$214,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($umax|0) == 2)) {
    $157 = Math_fround(HEAPF32[$Q>>2]);
    $158 = (($Q) + 4|0);
    $159 = Math_fround(HEAPF32[$158>>2]);
    $160 = (($Q) + 8|0);
    $161 = Math_fround(HEAPF32[$160>>2]);
    $162 = Math_fround($147 - $157);
    $163 = Math_fround($148 - $159);
    $164 = Math_fround($149 - $161);
    $165 = Math_fround($162 * $162);
    $166 = Math_fround($163 * $163);
    $167 = Math_fround($165 + $166);
    $168 = Math_fround($164 * $164);
    $169 = Math_fround($167 + $168);
    $170 = $169 == Math_fround(0.0);
    if ($170) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $171 = Math_fround($159 * $163);
     $172 = Math_fround(-$171);
     $173 = Math_fround($157 * $162);
     $174 = Math_fround($172 - $173);
     $175 = Math_fround($161 * $164);
     $176 = Math_fround($174 - $175);
     $177 = Math_fround(HEAPF32[$A>>2]);
     $178 = (($A) + 4|0);
     $179 = Math_fround(HEAPF32[$178>>2]);
     $180 = (($A) + 8|0);
     $181 = Math_fround(HEAPF32[$180>>2]);
     $182 = Math_fround($132 - $177);
     $183 = Math_fround($133 - $179);
     $184 = Math_fround($134 - $181);
     $185 = Math_fround(HEAPF32[$B>>2]);
     $186 = (($B) + 4|0);
     $187 = Math_fround(HEAPF32[$186>>2]);
     $188 = (($B) + 8|0);
     $189 = Math_fround(HEAPF32[$188>>2]);
     $190 = Math_fround($142 - $185);
     $191 = Math_fround($144 - $187);
     $192 = Math_fround($146 - $189);
     $193 = Math_fround($176 / $169);
     $194 = $193 > Math_fround(1.0);
     $$$i$i$i171 = $194 ? Math_fround(1.0) : $193;
     $195 = $$$i$i$i171 > Math_fround(0.0);
     $$$i8$i$i172 = $195 ? $$$i$i$i171 : Math_fround(0.0);
     $196 = Math_fround($182 * $$$i8$i$i172);
     $197 = Math_fround($183 * $$$i8$i$i172);
     $198 = Math_fround($184 * $$$i8$i$i172);
     $199 = Math_fround($177 + $196);
     $200 = Math_fround($179 + $197);
     $201 = Math_fround($181 + $198);
     $202 = Math_fround($190 * $$$i8$i$i172);
     $203 = Math_fround($191 * $$$i8$i$i172);
     $204 = Math_fround($192 * $$$i8$i$i172);
     $205 = Math_fround($185 + $202);
     $206 = Math_fround($187 + $203);
     $207 = Math_fround($189 + $204);
     HEAPF32[$closA>>2] = $199;
     HEAPF32[$18>>2] = $200;
     HEAPF32[$19>>2] = $201;
     HEAPF32[$20>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $205;
     HEAPF32[$21>>2] = $206;
     HEAPF32[$22>>2] = $207;
     HEAPF32[$23>>2] = Math_fround(0.0);
     $208 = Math_fround($199 - $205);
     $209 = Math_fround($200 - $206);
     $210 = Math_fround($201 - $207);
     HEAPF32[$4>>2] = $208;
     $211 = (($4) + 4|0);
     HEAPF32[$211>>2] = $209;
     $212 = (($4) + 8|0);
     HEAPF32[$212>>2] = $210;
     $213 = (($4) + 12|0);
     HEAPF32[$213>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($umax|0) == 4)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($umax|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  $215 = Math_fround(HEAPF32[$4>>2]);
  $216 = (($4) + 4|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($4) + 8|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = Math_fround($215 * $215);
  $221 = Math_fround($217 * $217);
  $222 = Math_fround($220 + $221);
  $223 = Math_fround($219 * $219);
  $224 = Math_fround($222 + $223);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $225 = Math_fround(HEAPF32[$closA>>2]);
  $226 = Math_fround(HEAPF32[$18>>2]);
  $227 = Math_fround(HEAPF32[$19>>2]);
  $228 = Math_fround(HEAPF32[$20>>2]);
  $229 = Math_fround(HEAPF32[$closB>>2]);
  $230 = Math_fround(HEAPF32[$21>>2]);
  $231 = Math_fround(HEAPF32[$22>>2]);
  $232 = Math_fround(HEAPF32[$23>>2]);
  $233 = $224 > $24;
  $$ph = $228;$$ph781 = $227;$$ph782 = $226;$$ph783 = $225;$$ph784 = $232;$$ph785 = $231;$$ph786 = $230;$$ph787 = $229;$$ph789 = $224;$$ph790 = $233;$$ph794 = $219;$$ph795 = $217;$$ph796 = $215;
 }
 do {
  if ($$ph790) {
   $258 = (($a) + 144|0);
   $259 = (($a) + 148|0);
   $260 = (($a) + 152|0);
   $261 = (($aToB) + 4|0);
   $262 = (($aToB) + 8|0);
   $263 = (($aToB) + 16|0);
   $264 = (($aToB) + 20|0);
   $265 = (($aToB) + 24|0);
   $266 = (($aToB) + 32|0);
   $267 = (($aToB) + 36|0);
   $268 = (($aToB) + 40|0);
   $269 = (($1) + 4|0);
   $270 = (($1) + 8|0);
   $271 = (($1) + 12|0);
   $272 = (($0) + 4|0);
   $273 = (($0) + 8|0);
   $274 = (($0) + 12|0);
   $275 = (($aToB) + 48|0);
   $276 = (($aToB) + 52|0);
   $277 = (($aToB) + 56|0);
   $278 = (($supportA1) + 4|0);
   $279 = (($supportA1) + 8|0);
   $280 = (($supportA1) + 12|0);
   $281 = (($b) + 144|0);
   $282 = (($b) + 148|0);
   $283 = (($b) + 152|0);
   $284 = (($1) + 4|0);
   $285 = (($1) + 8|0);
   $286 = (($1) + 12|0);
   $287 = (($0) + 4|0);
   $288 = (($0) + 8|0);
   $289 = (($0) + 12|0);
   $290 = (($supportB2) + 4|0);
   $291 = (($supportB2) + 8|0);
   $292 = (($supportB2) + 12|0);
   $293 = (($support3) + 4|0);
   $294 = (($support3) + 8|0);
   $295 = (($support3) + 12|0);
   $296 = (($a) + 48|0);
   $297 = (($b) + 48|0);
   $298 = (($5) + 4|0);
   $299 = (($5) + 8|0);
   $300 = (($Q) + 4|0);
   $301 = (($Q) + 8|0);
   $302 = (($A) + 4|0);
   $303 = (($A) + 8|0);
   $304 = (($B) + 4|0);
   $305 = (($B) + 8|0);
   $306 = (($5) + 12|0);
   $307 = (($Q) + 16|0);
   $$$i761831 = $10;$309 = $$ph796;$311 = $$ph795;$313 = $$ph794;$427 = $$ph789;$560 = $$ph783;$561 = $$ph782;$562 = $$ph781;$563 = $$ph;$564 = $$ph787;$565 = $$ph786;$566 = $$ph785;$567 = $$ph784;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $308 = Math_fround(-$309);
    $310 = Math_fround(-$311);
    $312 = Math_fround(-$313);
    $314 = HEAP32[$size>>2]|0;
    $315 = (($A) + ($314<<4)|0);
    $316 = (($aInd) + ($314<<2)|0);
    $317 = Math_fround(HEAPF32[$258>>2]);
    $318 = Math_fround(HEAPF32[$259>>2]);
    $319 = Math_fround(HEAPF32[$260>>2]);
    $320 = Math_fround(HEAPF32[$6>>2]);
    $321 = Math_fround($317 - $320);
    $322 = Math_fround($318 - $320);
    $323 = Math_fround($319 - $320);
    $324 = Math_fround(HEAPF32[$aToB>>2]);
    $325 = Math_fround($324 * $308);
    $326 = Math_fround(HEAPF32[$261>>2]);
    $327 = Math_fround($326 * $310);
    $328 = Math_fround($325 + $327);
    $329 = Math_fround(HEAPF32[$262>>2]);
    $330 = Math_fround($329 * $312);
    $331 = Math_fround($328 + $330);
    $332 = Math_fround(HEAPF32[$263>>2]);
    $333 = Math_fround($332 * $308);
    $334 = Math_fround(HEAPF32[$264>>2]);
    $335 = Math_fround($334 * $310);
    $336 = Math_fround($333 + $335);
    $337 = Math_fround(HEAPF32[$265>>2]);
    $338 = Math_fround($337 * $312);
    $339 = Math_fround($336 + $338);
    $340 = Math_fround(HEAPF32[$266>>2]);
    $341 = Math_fround($340 * $308);
    $342 = Math_fround(HEAPF32[$267>>2]);
    $343 = Math_fround($342 * $310);
    $344 = Math_fround($341 + $343);
    $345 = Math_fround(HEAPF32[$268>>2]);
    $346 = Math_fround($345 * $312);
    $347 = Math_fround($344 + $346);
    $348 = $331 > Math_fround(0.0);
    $349 = $339 > Math_fround(0.0);
    $350 = $349 << 31 >> 31;
    $351 = $347 > Math_fround(0.0);
    $352 = $351 << 31 >> 31;
    $353 = $348&1;
    $354 = $350 << 1;
    $355 = $354 & 2;
    $356 = $352 << 2;
    $357 = $356 & 4;
    $358 = $355 | $353;
    $359 = $358 | $357;
    HEAP32[$316>>2] = $359;
    $360 = Math_fround(-$321);
    $361 = Math_fround(-$322);
    $362 = Math_fround(-$323);
    HEAPF32[$1>>2] = $321;
    HEAPF32[$269>>2] = $322;
    HEAPF32[$270>>2] = $323;
    HEAPF32[$271>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $360;
    HEAPF32[$272>>2] = $361;
    HEAPF32[$273>>2] = $362;
    HEAPF32[$274>>2] = Math_fround(0.0);
    $b$a$i$i139 = $348 ? $1 : $0;
    $363 = Math_fround(HEAPF32[$b$a$i$i139>>2]);
    $a$pn3$i$i141 = $349 ? $1 : $0;
    $$in1$i$i142 = (($a$pn3$i$i141) + 4|0);
    $364 = Math_fround(HEAPF32[$$in1$i$i142>>2]);
    $b$a5$i$i143 = $351 ? $1 : $0;
    $$in2$i$i144 = (($b$a5$i$i143) + 8|0);
    $365 = Math_fround(HEAPF32[$$in2$i$i144>>2]);
    $366 = Math_fround(HEAPF32[$275>>2]);
    $367 = Math_fround(HEAPF32[$276>>2]);
    $368 = Math_fround(HEAPF32[$277>>2]);
    $369 = Math_fround($324 * $363);
    $370 = Math_fround($332 * $364);
    $371 = Math_fround($369 + $370);
    $372 = Math_fround($340 * $365);
    $373 = Math_fround($371 + $372);
    $374 = Math_fround($326 * $363);
    $375 = Math_fround($334 * $364);
    $376 = Math_fround($374 + $375);
    $377 = Math_fround($342 * $365);
    $378 = Math_fround($376 + $377);
    $379 = Math_fround($329 * $363);
    $380 = Math_fround($337 * $364);
    $381 = Math_fround($379 + $380);
    $382 = Math_fround($345 * $365);
    $383 = Math_fround($381 + $382);
    $384 = Math_fround($366 + $373);
    $385 = Math_fround($367 + $378);
    $386 = Math_fround($383 + $368);
    HEAPF32[$supportA1>>2] = $384;
    HEAPF32[$278>>2] = $385;
    HEAPF32[$279>>2] = $386;
    HEAPF32[$280>>2] = Math_fround(0.0);
    ;HEAP32[$315+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$315+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$315+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$315+12>>2]=HEAP32[$supportA1+12>>2]|0;
    $387 = (($B) + ($314<<4)|0);
    $388 = (($bInd) + ($314<<2)|0);
    $389 = Math_fround(HEAPF32[$281>>2]);
    $390 = Math_fround(HEAPF32[$282>>2]);
    $391 = Math_fround(HEAPF32[$283>>2]);
    $392 = Math_fround(HEAPF32[$8>>2]);
    $393 = Math_fround($389 - $392);
    $394 = Math_fround($390 - $392);
    $395 = Math_fround($391 - $392);
    $396 = $309 > Math_fround(0.0);
    $397 = $311 > Math_fround(0.0);
    $398 = $397 << 31 >> 31;
    $399 = $313 > Math_fround(0.0);
    $400 = $399 << 31 >> 31;
    $401 = $396&1;
    $402 = $398 << 1;
    $403 = $402 & 2;
    $404 = $400 << 2;
    $405 = $404 & 4;
    $406 = $405 | $401;
    $407 = $406 | $403;
    HEAP32[$388>>2] = $407;
    $408 = Math_fround(-$393);
    $409 = Math_fround(-$394);
    $410 = Math_fround(-$395);
    HEAPF32[$1>>2] = $393;
    HEAPF32[$284>>2] = $394;
    HEAPF32[$285>>2] = $395;
    HEAPF32[$286>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $408;
    HEAPF32[$287>>2] = $409;
    HEAPF32[$288>>2] = $410;
    HEAPF32[$289>>2] = Math_fround(0.0);
    $b$a$i$i = $396 ? $1 : $0;
    $411 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $397 ? $1 : $0;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $412 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $399 ? $1 : $0;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $413 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    HEAPF32[$supportB2>>2] = $411;
    HEAPF32[$290>>2] = $412;
    HEAPF32[$291>>2] = $413;
    HEAPF32[$292>>2] = Math_fround(0.0);
    ;HEAP32[$387+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$387+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$387+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$387+12>>2]=HEAP32[$supportB2+12>>2]|0;
    $414 = Math_fround($384 - $411);
    $415 = Math_fround($385 - $412);
    $416 = Math_fround($386 - $413);
    HEAPF32[$support3>>2] = $414;
    HEAPF32[$293>>2] = $415;
    HEAPF32[$294>>2] = $416;
    HEAPF32[$295>>2] = Math_fround(0.0);
    $417 = HEAP32[$size>>2]|0;
    $418 = (($417) + 1)|0;
    HEAP32[$size>>2] = $418;
    $419 = (($Q) + ($417<<4)|0);
    ;HEAP32[$419+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$419+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$419+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$419+12>>2]=HEAP32[$support3+12>>2]|0;
    $420 = Math_fround(HEAPF32[$296>>2]);
    $421 = Math_fround(HEAPF32[$297>>2]);
    $422 = $420 > $421;
    $$$i134 = $422 ? $420 : $421;
    $423 = $$$i761831 > $$$i134;
    $$$i = $423 ? $$$i761831 : $$$i134;
    $424 = Math_fround($17 + $$$i);
    $425 = Math_fround($424 * $424);
    $426 = Math_fround($427 * $425);
    $428 = Math_fround($309 * $414);
    $429 = Math_fround($311 * $415);
    $430 = Math_fround($428 + $429);
    $431 = Math_fround($313 * $416);
    $432 = Math_fround($430 + $431);
    $433 = Math_fround($432 * $432);
    $434 = $432 > Math_fround(0.0);
    $435 = $433 > $426;
    if ($434) {
     $phitmp777 = $435 ^ 1;
     $439 = $435;$441 = $phitmp777;
    } else {
     $439 = 0;$441 = 1;
    }
    $436 = Math_fround($427 - $432);
    $437 = Math_fround($24 * $427);
    $438 = $437 >= $436;
    $brmerge$demorgan = $438 | $439;
    if ($brmerge$demorgan) {
     $440 = $441 ^ 1;
     $$769 = $438 | $440;
     if ($$769) {
      break;
     }
    }
    do {
     if ((($417|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($417|0) == 1)) {
      $488 = Math_fround(HEAPF32[$Q>>2]);
      $489 = Math_fround(HEAPF32[$300>>2]);
      $490 = Math_fround(HEAPF32[$301>>2]);
      $491 = Math_fround($414 - $488);
      $492 = Math_fround($415 - $489);
      $493 = Math_fround($416 - $490);
      $494 = Math_fround($491 * $491);
      $495 = Math_fround($492 * $492);
      $496 = Math_fround($494 + $495);
      $497 = Math_fround($493 * $493);
      $498 = Math_fround($496 + $497);
      $499 = $498 == Math_fround(0.0);
      if ($499) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $500 = Math_fround($489 * $492);
       $501 = Math_fround(-$500);
       $502 = Math_fround($488 * $491);
       $503 = Math_fround($501 - $502);
       $504 = Math_fround($490 * $493);
       $505 = Math_fround($503 - $504);
       $506 = Math_fround(HEAPF32[$A>>2]);
       $507 = Math_fround(HEAPF32[$302>>2]);
       $508 = Math_fround(HEAPF32[$303>>2]);
       $509 = Math_fround($384 - $506);
       $510 = Math_fround($385 - $507);
       $511 = Math_fround($386 - $508);
       $512 = Math_fround(HEAPF32[$B>>2]);
       $513 = Math_fround(HEAPF32[$304>>2]);
       $514 = Math_fround(HEAPF32[$305>>2]);
       $515 = Math_fround($411 - $512);
       $516 = Math_fround($412 - $513);
       $517 = Math_fround($413 - $514);
       $518 = Math_fround($505 / $498);
       $519 = $518 > Math_fround(1.0);
       $$$i$i$i = $519 ? Math_fround(1.0) : $518;
       $520 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $520 ? $$$i$i$i : Math_fround(0.0);
       $521 = Math_fround($509 * $$$i8$i$i);
       $522 = Math_fround($510 * $$$i8$i$i);
       $523 = Math_fround($511 * $$$i8$i$i);
       $524 = Math_fround($506 + $521);
       $525 = Math_fround($507 + $522);
       $526 = Math_fround($508 + $523);
       $527 = Math_fround($515 * $$$i8$i$i);
       $528 = Math_fround($516 * $$$i8$i$i);
       $529 = Math_fround($517 * $$$i8$i$i);
       $530 = Math_fround($512 + $527);
       $531 = Math_fround($513 + $528);
       $532 = Math_fround($514 + $529);
       HEAPF32[$closA>>2] = $524;
       HEAPF32[$18>>2] = $525;
       HEAPF32[$19>>2] = $526;
       HEAPF32[$20>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $530;
       HEAPF32[$21>>2] = $531;
       HEAPF32[$22>>2] = $532;
       HEAPF32[$23>>2] = Math_fround(0.0);
       $533 = Math_fround($524 - $530);
       $534 = Math_fround($525 - $531);
       $535 = Math_fround($526 - $532);
       HEAPF32[$5>>2] = $533;
       HEAPF32[$298>>2] = $534;
       HEAPF32[$299>>2] = $535;
       HEAPF32[$306>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($417|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$307,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($417|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    $536 = Math_fround(HEAPF32[$5>>2]);
    $537 = Math_fround(HEAPF32[$298>>2]);
    $538 = Math_fround(HEAPF32[$299>>2]);
    $539 = Math_fround($536 * $536);
    $540 = Math_fround($537 * $537);
    $541 = Math_fround($539 + $540);
    $542 = Math_fround($538 * $538);
    $543 = Math_fround($541 + $542);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1250+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1250+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1250+8>>2]|0;
    $544 = $427 > $543;
    $545 = $543 > $24;
    if (!($545)) {
     label = 37;
     break;
    }
    if (!($544)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre878 = Math_fround(HEAPF32[$18>>2]);
    $$pre879 = Math_fround(HEAPF32[$19>>2]);
    $$pre880 = Math_fround(HEAPF32[$20>>2]);
    $$pre881 = Math_fround(HEAPF32[$closB>>2]);
    $$pre882 = Math_fround(HEAPF32[$21>>2]);
    $$pre883 = Math_fround(HEAPF32[$22>>2]);
    $$pre884 = Math_fround(HEAPF32[$23>>2]);
    $$$i761831 = $$$i;$309 = $536;$311 = $537;$313 = $538;$427 = $543;$560 = $$pre;$561 = $$pre878;$562 = $$pre879;$563 = $$pre880;$564 = $$pre881;$565 = $$pre882;$566 = $$pre883;$567 = $$pre884;
   }
   if ((label|0) == 37) {
    $546 = HEAP32[$size>>2]|0;
    if ($544) {
     $601 = $546;
     break;
    }
    $547 = (($546) + -1)|0;
    $548 = ($aIndices|0)==(0|0);
    if (!($548)) {
     $549 = $547&255;
     HEAP8[$_size>>0] = $549;
     $550 = ($547|0)==(0);
     if (!($550)) {
      $i$01$i29 = 0;
      while(1) {
       $551 = (($aInd) + ($i$01$i29<<2)|0);
       $552 = HEAP32[$551>>2]|0;
       $553 = $552&255;
       $554 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$554>>0] = $553;
       $555 = (($bInd) + ($i$01$i29<<2)|0);
       $556 = HEAP32[$555>>2]|0;
       $557 = $556&255;
       $558 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$558>>0] = $557;
       $559 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($559|0)==($547|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $559;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $560;
    HEAPF32[$18>>2] = $561;
    HEAPF32[$19>>2] = $562;
    HEAPF32[$20>>2] = $563;
    HEAPF32[$closB>>2] = $564;
    HEAPF32[$21>>2] = $565;
    HEAPF32[$22>>2] = $566;
    HEAPF32[$23>>2] = $567;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $568 = Math_fround($560 - $564);
    $569 = Math_fround($561 - $565);
    $570 = Math_fround($562 - $566);
    $571 = (Math_fround(Math_sqrt((Math_fround($427)))));
    $572 = Math_fround(Math_fround(1.0) / $571);
    $573 = Math_fround($568 * $572);
    $574 = Math_fround($569 * $572);
    $575 = Math_fround($570 * $572);
    $576 = Math_fround($7 * $573);
    $577 = Math_fround($7 * $574);
    $578 = Math_fround($7 * $575);
    $579 = Math_fround($560 - $576);
    $580 = Math_fround($561 - $577);
    $581 = Math_fround($562 - $578);
    HEAPF32[$contactA>>2] = $579;
    $582 = (($contactA) + 4|0);
    HEAPF32[$582>>2] = $580;
    $583 = (($contactA) + 8|0);
    HEAPF32[$583>>2] = $581;
    $584 = (($contactA) + 12|0);
    HEAPF32[$584>>2] = Math_fround(0.0);
    $585 = Math_fround($9 * $573);
    $586 = Math_fround($9 * $574);
    $587 = Math_fround($9 * $575);
    $588 = Math_fround($585 + $564);
    $589 = Math_fround($586 + $565);
    $590 = Math_fround($587 + $566);
    HEAPF32[$contactB>>2] = $588;
    $591 = (($contactB) + 4|0);
    HEAPF32[$591>>2] = $589;
    $592 = (($contactB) + 8|0);
    HEAPF32[$592>>2] = $590;
    $593 = (($contactB) + 12|0);
    HEAPF32[$593>>2] = Math_fround(0.0);
    $594 = Math_fround($571 - $17);
    HEAPF32[$penetrationDepth>>2] = $594;
    $595 = (($penetrationDepth) + 4|0);
    ;HEAP32[$595+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$595+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$595+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $573;
    $596 = (($normal) + 4|0);
    HEAPF32[$596>>2] = $574;
    $597 = (($normal) + 8|0);
    HEAPF32[$597>>2] = $575;
    $598 = (($normal) + 12|0);
    HEAPF32[$598>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $442 = ($aIndices|0)==(0|0);
   if (!($442)) {
    $443 = $417&255;
    HEAP8[$_size>>0] = $443;
    $444 = ($417|0)==(0);
    if (!($444)) {
     $i$01$i72 = 0;
     while(1) {
      $445 = (($aInd) + ($i$01$i72<<2)|0);
      $446 = HEAP32[$445>>2]|0;
      $447 = $446&255;
      $448 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$448>>0] = $447;
      $449 = (($bInd) + ($i$01$i72<<2)|0);
      $450 = HEAP32[$449>>2]|0;
      $451 = $450&255;
      $452 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$452>>0] = $451;
      $453 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($453|0)==($417|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $453;
      }
     }
    }
   }
   $not$ = $439 ^ 1;
   $$$773 = $441 & $not$;
   if (!($$$773)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $454 = (Math_fround(Math_sqrt((Math_fround($427)))));
   $455 = Math_fround(Math_fround(1.0) / $454);
   $456 = Math_fround($309 * $455);
   $457 = Math_fround($311 * $455);
   $458 = Math_fround($313 * $455);
   $459 = Math_fround(HEAPF32[$closA>>2]);
   $460 = Math_fround(HEAPF32[$18>>2]);
   $461 = Math_fround(HEAPF32[$19>>2]);
   $462 = Math_fround($7 * $456);
   $463 = Math_fround($7 * $457);
   $464 = Math_fround($7 * $458);
   $465 = Math_fround($459 - $462);
   $466 = Math_fround($460 - $463);
   $467 = Math_fround($461 - $464);
   HEAPF32[$contactA>>2] = $465;
   $468 = (($contactA) + 4|0);
   HEAPF32[$468>>2] = $466;
   $469 = (($contactA) + 8|0);
   HEAPF32[$469>>2] = $467;
   $470 = (($contactA) + 12|0);
   HEAPF32[$470>>2] = Math_fround(0.0);
   $471 = Math_fround(HEAPF32[$closB>>2]);
   $472 = Math_fround(HEAPF32[$21>>2]);
   $473 = Math_fround(HEAPF32[$22>>2]);
   $474 = Math_fround($9 * $456);
   $475 = Math_fround($9 * $457);
   $476 = Math_fround($9 * $458);
   $477 = Math_fround($474 + $471);
   $478 = Math_fround($475 + $472);
   $479 = Math_fround($476 + $473);
   HEAPF32[$contactB>>2] = $477;
   $480 = (($contactB) + 4|0);
   HEAPF32[$480>>2] = $478;
   $481 = (($contactB) + 8|0);
   HEAPF32[$481>>2] = $479;
   $482 = (($contactB) + 12|0);
   HEAPF32[$482>>2] = Math_fround(0.0);
   $483 = Math_fround($454 - $17);
   HEAPF32[$penetrationDepth>>2] = $483;
   $484 = (($penetrationDepth) + 4|0);
   ;HEAP32[$484+0>>2]=HEAP32[$$sroa$1252+0>>2]|0;HEAP32[$484+4>>2]=HEAP32[$$sroa$1252+4>>2]|0;HEAP32[$484+8>>2]=HEAP32[$$sroa$1252+8>>2]|0;
   HEAPF32[$normal>>2] = $456;
   $485 = (($normal) + 4|0);
   HEAPF32[$485>>2] = $457;
   $486 = (($normal) + 8|0);
   HEAPF32[$486>>2] = $458;
   $487 = (($normal) + 12|0);
   HEAPF32[$487>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $257 = HEAP32[$size>>2]|0;
   $601 = $257;
  }
 } while(0);
 $599 = ($aIndices|0)==(0|0);
 if (!($599)) {
  $600 = $601&255;
  HEAP8[$_size>>0] = $600;
  $602 = ($601|0)==(0);
  if (!($602)) {
   $i$01$i = 0;
   while(1) {
    $603 = (($aInd) + ($i$01$i<<2)|0);
    $604 = HEAP32[$603>>2]|0;
    $605 = $604&255;
    $606 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$606>>0] = $605;
    $607 = (($bInd) + ($i$01$i<<2)|0);
    $608 = HEAP32[$607>>2]|0;
    $609 = $608&255;
    $610 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$610>>0] = $609;
    $611 = (($i$01$i) + 1)|0;
    $exitcond$i = ($611|0)==($601|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $611;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_10ShrunkBoxVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$757 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i165 = Math_fround(0), $$$i134 = Math_fround(0), $$$i176 = Math_fround(0), $$$i745809 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i166 = Math_fround(0), $$0 = 0, $$753 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i180 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i182 = 0, $$ph = Math_fround(0), $$ph765 = Math_fround(0), $$ph766 = Math_fround(0);
 var $$ph767 = Math_fround(0), $$ph768 = Math_fround(0), $$ph769 = Math_fround(0), $$ph770 = Math_fround(0), $$ph771 = Math_fround(0), $$ph773 = Math_fround(0), $$ph774 = 0, $$pre = Math_fround(0), $$pre849 = Math_fround(0), $$pre850 = Math_fround(0), $$pre851 = Math_fround(0), $$pre852 = Math_fround(0), $$pre853 = Math_fround(0), $$pre854 = Math_fround(0), $$pre855 = Math_fround(0), $$pre856 = Math_fround(0), $$sroa$1 = 0, $$sroa$1238 = 0, $$sroa$1240 = 0, $0 = 0;
 var $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0);
 var $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0);
 var $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0);
 var $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0);
 var $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0);
 var $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0);
 var $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0);
 var $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0);
 var $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0);
 var $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = 0, $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0);
 var $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0);
 var $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = Math_fround(0), $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0);
 var $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0);
 var $478 = 0, $479 = 0, $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0);
 var $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = 0, $545 = 0, $546 = 0, $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0);
 var $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = 0, $554 = 0, $555 = 0, $556 = Math_fround(0), $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0;
 var $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $a$pn3$i$i = 0;
 var $a$pn3$i$i179 = 0, $aInd = 0, $b$a$i = 0, $b$a$i$i = 0, $b$a$i$i177 = 0, $b$a5$i$i = 0, $b$a5$i$i181 = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$0819 = 0, $lastA = 0, $lastB = 0;
 var $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp761 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 400|0;
 $1 = sp + 336|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $closA = sp + 384|0;
 $closB = sp + 416|0;
 $sDist$sroa$1 = sp + 516|0;
 $minDist$sroa$1 = sp + 504|0;
 $v = sp + 320|0;
 $Q = sp;
 $A = sp + 160|0;
 $B = sp + 64|0;
 $aInd = sp + 488|0;
 $bInd = sp + 528|0;
 $size = sp + 448|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 144|0;
 $lastB = sp + 224|0;
 $4 = sp + 240|0;
 $5 = sp + 256|0;
 $supportA1 = sp + 272|0;
 $supportB2 = sp + 288|0;
 $support3 = sp + 304|0;
 $$sroa$1240 = sp + 464|0;
 $6 = sp + 432|0;
 $$sroa$1238 = sp + 476|0;
 $$sroa$1 = sp + 452|0;
 $7 = (($a) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($b) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$_contactDist>>2]);
 $12 = (($a) + 32|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($b) + 32|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = $13 > $15;
 $$$i176 = $16 ? $15 : $13;
 $17 = Math_fround($$$i176 * Math_fround(0.100000001490116119385));
 $18 = Math_fround($8 + $10);
 $19 = (($closA) + 4|0);
 $20 = (($closA) + 8|0);
 $21 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $22 = (($closB) + 4|0);
 $23 = (($closB) + 8|0);
 $24 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $25 = Math_fround($17 * $17);
 HEAP32[$size>>2] = 0;
 $26 = HEAP8[$_size>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $214 = (($aToB) + 48|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($aToB) + 52|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($aToB) + 56|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = (($aToB) + 60|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = Math_fround($215 * $215);
  $223 = Math_fround($217 * $217);
  $224 = Math_fround($222 + $223);
  $225 = Math_fround($219 * $219);
  $226 = Math_fround($224 + $225);
  $227 = $226 > Math_fround(0.0);
  HEAPF32[$3>>2] = $215;
  $228 = (($3) + 4|0);
  HEAPF32[$228>>2] = $217;
  $229 = (($3) + 8|0);
  HEAPF32[$229>>2] = $219;
  $230 = (($3) + 12|0);
  HEAPF32[$230>>2] = $221;
  HEAPF32[$2>>2] = Math_fround(1.0);
  $231 = (($2) + 4|0);
  HEAPF32[$231>>2] = Math_fround(0.0);
  $232 = (($2) + 8|0);
  HEAPF32[$232>>2] = Math_fround(0.0);
  $233 = (($2) + 12|0);
  HEAPF32[$233>>2] = Math_fround(0.0);
  $b$a$i = $227 ? $3 : $2;
  $234 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $235 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $236 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $234;
  $237 = (($v) + 4|0);
  HEAPF32[$237>>2] = $235;
  $238 = (($v) + 8|0);
  HEAPF32[$238>>2] = $236;
  $239 = (($v) + 12|0);
  HEAPF32[$239>>2] = Math_fround(0.0);
  $$ph = Math_fround(0.0);$$ph765 = Math_fround(0.0);$$ph766 = Math_fround(0.0);$$ph767 = Math_fround(0.0);$$ph768 = Math_fround(0.0);$$ph769 = Math_fround(0.0);$$ph770 = Math_fround(0.0);$$ph771 = Math_fround(0.0);$$ph773 = Math_fround(3.40282346638528859812E+38);$$ph774 = 1;$574 = $236;$575 = $235;$576 = $234;
 } else {
  $28 = (($lastQ) + 4|0);
  $29 = (($lastQ) + 8|0);
  $30 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $31 = (($lastA) + 4|0);
  $32 = (($lastA) + 8|0);
  $33 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $34 = (($lastB) + 4|0);
  $35 = (($lastB) + 8|0);
  $36 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $37 = (($a) + 144|0);
  $38 = (($a) + 148|0);
  $39 = (($a) + 152|0);
  $40 = (($1) + 4|0);
  $41 = (($1) + 8|0);
  $42 = (($1) + 12|0);
  $43 = (($0) + 4|0);
  $44 = (($0) + 8|0);
  $45 = (($0) + 12|0);
  $46 = (($aToB) + 48|0);
  $47 = (($aToB) + 52|0);
  $48 = (($aToB) + 56|0);
  $49 = (($aToB) + 16|0);
  $50 = (($aToB) + 32|0);
  $51 = (($aToB) + 4|0);
  $52 = (($aToB) + 20|0);
  $53 = (($aToB) + 36|0);
  $54 = (($aToB) + 8|0);
  $55 = (($aToB) + 24|0);
  $56 = (($aToB) + 40|0);
  $57 = (($b) + 16|0);
  $58 = (($4) + 4|0);
  $59 = (($4) + 8|0);
  $60 = (($4) + 12|0);
  $73 = $8;$i$0819 = 0;
  while(1) {
   $61 = (($aIndices) + ($i$0819)|0);
   $62 = HEAP8[$61>>0]|0;
   $63 = $62&255;
   $64 = (($aInd) + ($i$0819<<2)|0);
   HEAP32[$64>>2] = $63;
   $65 = (($bIndices) + ($i$0819)|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = $66&255;
   $68 = (($bInd) + ($i$0819<<2)|0);
   HEAP32[$68>>2] = $67;
   $69 = Math_fround(HEAPF32[$37>>2]);
   $70 = Math_fround(HEAPF32[$38>>2]);
   $71 = Math_fround(HEAPF32[$39>>2]);
   $72 = Math_fround($69 - $73);
   $74 = Math_fround($70 - $73);
   $75 = Math_fround($71 - $73);
   $76 = (549664 + ($63<<4)|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ((549664 + ($63<<4)|0) + 4|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ((549664 + ($63<<4)|0) + 8|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = Math_fround(-$72);
   $83 = Math_fround(-$74);
   $84 = Math_fround(-$75);
   HEAPF32[$1>>2] = $72;
   HEAPF32[$40>>2] = $74;
   HEAPF32[$41>>2] = $75;
   HEAPF32[$42>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $82;
   HEAPF32[$43>>2] = $83;
   HEAPF32[$44>>2] = $84;
   HEAPF32[$45>>2] = Math_fround(0.0);
   $85 = ($77|0)==(0);
   $b$a$i$i177 = $85 ? $0 : $1;
   $86 = Math_fround(HEAPF32[$b$a$i$i177>>2]);
   $87 = ($79|0)==(0);
   $a$pn3$i$i179 = $87 ? $0 : $1;
   $$in1$i$i180 = (($a$pn3$i$i179) + 4|0);
   $88 = Math_fround(HEAPF32[$$in1$i$i180>>2]);
   $89 = ($81|0)==(0);
   $b$a5$i$i181 = $89 ? $0 : $1;
   $$in2$i$i182 = (($b$a5$i$i181) + 8|0);
   $90 = Math_fround(HEAPF32[$$in2$i$i182>>2]);
   $91 = Math_fround(HEAPF32[$46>>2]);
   $92 = Math_fround(HEAPF32[$47>>2]);
   $93 = Math_fround(HEAPF32[$48>>2]);
   $94 = Math_fround(HEAPF32[$aToB>>2]);
   $95 = Math_fround($86 * $94);
   $96 = Math_fround(HEAPF32[$49>>2]);
   $97 = Math_fround($88 * $96);
   $98 = Math_fround($95 + $97);
   $99 = Math_fround(HEAPF32[$50>>2]);
   $100 = Math_fround($90 * $99);
   $101 = Math_fround($98 + $100);
   $102 = Math_fround(HEAPF32[$51>>2]);
   $103 = Math_fround($86 * $102);
   $104 = Math_fround(HEAPF32[$52>>2]);
   $105 = Math_fround($88 * $104);
   $106 = Math_fround($103 + $105);
   $107 = Math_fround(HEAPF32[$53>>2]);
   $108 = Math_fround($90 * $107);
   $109 = Math_fround($106 + $108);
   $110 = Math_fround(HEAPF32[$54>>2]);
   $111 = Math_fround($86 * $110);
   $112 = Math_fround(HEAPF32[$55>>2]);
   $113 = Math_fround($88 * $112);
   $114 = Math_fround($111 + $113);
   $115 = Math_fround(HEAPF32[$56>>2]);
   $116 = Math_fround($90 * $115);
   $117 = Math_fround($114 + $116);
   $118 = Math_fround($91 + $101);
   $119 = Math_fround($92 + $109);
   $120 = Math_fround($93 + $117);
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($4,$b,$67,$57);
   $121 = Math_fround(HEAPF32[$4>>2]);
   $122 = Math_fround(HEAPF32[$58>>2]);
   $123 = Math_fround(HEAPF32[$59>>2]);
   $124 = Math_fround(HEAPF32[$60>>2]);
   $125 = Math_fround($118 - $121);
   $126 = Math_fround($119 - $122);
   $127 = Math_fround($120 - $123);
   $128 = HEAP32[$size>>2]|0;
   $129 = (($A) + ($128<<4)|0);
   HEAPF32[$lastA>>2] = $118;
   HEAPF32[$31>>2] = $119;
   HEAPF32[$32>>2] = $120;
   HEAPF32[$33>>2] = Math_fround(0.0);
   ;HEAP32[$129+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$129+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$129+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$129+12>>2]=HEAP32[$lastA+12>>2]|0;
   $130 = (($B) + ($128<<4)|0);
   HEAPF32[$lastB>>2] = $121;
   HEAPF32[$34>>2] = $122;
   HEAPF32[$35>>2] = $123;
   HEAPF32[$36>>2] = $124;
   ;HEAP32[$130+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$130+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$130+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$130+12>>2]=HEAP32[$lastB+12>>2]|0;
   $131 = (($128) + 1)|0;
   HEAP32[$size>>2] = $131;
   $132 = (($Q) + ($128<<4)|0);
   HEAPF32[$lastQ>>2] = $125;
   HEAPF32[$28>>2] = $126;
   HEAPF32[$29>>2] = $127;
   HEAPF32[$30>>2] = Math_fround(0.0);
   ;HEAP32[$132+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$132+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $133 = (($i$0819) + 1)|0;
   $134 = HEAP8[$_size>>0]|0;
   $135 = $134&255;
   $136 = ($133>>>0)<($135>>>0);
   if (!($136)) {
    break;
   }
   $$pre = Math_fround(HEAPF32[$7>>2]);
   $73 = $$pre;$i$0819 = $133;
  }
  do {
   if ((($128|0) == 1)) {
    $137 = Math_fround(HEAPF32[$Q>>2]);
    $138 = (($Q) + 4|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = (($Q) + 8|0);
    $141 = Math_fround(HEAPF32[$140>>2]);
    $142 = Math_fround($125 - $137);
    $143 = Math_fround($126 - $139);
    $144 = Math_fround($127 - $141);
    $145 = Math_fround($142 * $142);
    $146 = Math_fround($143 * $143);
    $147 = Math_fround($145 + $146);
    $148 = Math_fround($144 * $144);
    $149 = Math_fround($147 + $148);
    $150 = $149 == Math_fround(0.0);
    if ($150) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $151 = Math_fround($139 * $143);
     $152 = Math_fround(-$151);
     $153 = Math_fround($137 * $142);
     $154 = Math_fround($152 - $153);
     $155 = Math_fround($141 * $144);
     $156 = Math_fround($154 - $155);
     $157 = Math_fround(HEAPF32[$A>>2]);
     $158 = (($A) + 4|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = (($A) + 8|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = Math_fround($118 - $157);
     $163 = Math_fround($119 - $159);
     $164 = Math_fround($120 - $161);
     $165 = Math_fround(HEAPF32[$B>>2]);
     $166 = (($B) + 4|0);
     $167 = Math_fround(HEAPF32[$166>>2]);
     $168 = (($B) + 8|0);
     $169 = Math_fround(HEAPF32[$168>>2]);
     $170 = Math_fround($121 - $165);
     $171 = Math_fround($122 - $167);
     $172 = Math_fround($123 - $169);
     $173 = Math_fround($156 / $149);
     $174 = $173 > Math_fround(1.0);
     $$$i$i$i165 = $174 ? Math_fround(1.0) : $173;
     $175 = $$$i$i$i165 > Math_fround(0.0);
     $$$i8$i$i166 = $175 ? $$$i$i$i165 : Math_fround(0.0);
     $176 = Math_fround($162 * $$$i8$i$i166);
     $177 = Math_fround($163 * $$$i8$i$i166);
     $178 = Math_fround($164 * $$$i8$i$i166);
     $179 = Math_fround($157 + $176);
     $180 = Math_fround($159 + $177);
     $181 = Math_fround($161 + $178);
     $182 = Math_fround($170 * $$$i8$i$i166);
     $183 = Math_fround($171 * $$$i8$i$i166);
     $184 = Math_fround($172 * $$$i8$i$i166);
     $185 = Math_fround($165 + $182);
     $186 = Math_fround($167 + $183);
     $187 = Math_fround($169 + $184);
     HEAPF32[$closA>>2] = $179;
     HEAPF32[$19>>2] = $180;
     HEAPF32[$20>>2] = $181;
     HEAPF32[$21>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $185;
     HEAPF32[$22>>2] = $186;
     HEAPF32[$23>>2] = $187;
     HEAPF32[$24>>2] = Math_fround(0.0);
     $188 = Math_fround($179 - $185);
     $189 = Math_fround($180 - $186);
     $190 = Math_fround($181 - $187);
     HEAPF32[$5>>2] = $188;
     $191 = (($5) + 4|0);
     HEAPF32[$191>>2] = $189;
     $192 = (($5) + 8|0);
     HEAPF32[$192>>2] = $190;
     $193 = (($5) + 12|0);
     HEAPF32[$193>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($128|0) == 2)) {
    $194 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$194,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($128|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($128|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$5+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$5+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
  $195 = Math_fround(HEAPF32[$v>>2]);
  $196 = (($v) + 4|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = (($v) + 8|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = Math_fround($195 * $195);
  $201 = Math_fround($197 * $197);
  $202 = Math_fround($200 + $201);
  $203 = Math_fround($199 * $199);
  $204 = Math_fround($202 + $203);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $205 = Math_fround(HEAPF32[$closA>>2]);
  $206 = Math_fround(HEAPF32[$19>>2]);
  $207 = Math_fround(HEAPF32[$20>>2]);
  $208 = Math_fround(HEAPF32[$21>>2]);
  $209 = Math_fround(HEAPF32[$closB>>2]);
  $210 = Math_fround(HEAPF32[$22>>2]);
  $211 = Math_fround(HEAPF32[$23>>2]);
  $212 = Math_fround(HEAPF32[$24>>2]);
  $213 = $204 > $25;
  $$ph = $208;$$ph765 = $207;$$ph766 = $206;$$ph767 = $205;$$ph768 = $212;$$ph769 = $211;$$ph770 = $210;$$ph771 = $209;$$ph773 = $204;$$ph774 = $213;$574 = $199;$575 = $197;$576 = $195;
 }
 do {
  if ($$ph774) {
   $241 = (($v) + 4|0);
   $242 = (($v) + 8|0);
   $243 = (($a) + 144|0);
   $244 = (($a) + 148|0);
   $245 = (($a) + 152|0);
   $246 = (($aToB) + 4|0);
   $247 = (($aToB) + 8|0);
   $248 = (($aToB) + 16|0);
   $249 = (($aToB) + 20|0);
   $250 = (($aToB) + 24|0);
   $251 = (($aToB) + 32|0);
   $252 = (($aToB) + 36|0);
   $253 = (($aToB) + 40|0);
   $254 = (($1) + 4|0);
   $255 = (($1) + 8|0);
   $256 = (($1) + 12|0);
   $257 = (($0) + 4|0);
   $258 = (($0) + 8|0);
   $259 = (($0) + 12|0);
   $260 = (($aToB) + 48|0);
   $261 = (($aToB) + 52|0);
   $262 = (($aToB) + 56|0);
   $263 = (($supportA1) + 4|0);
   $264 = (($supportA1) + 8|0);
   $265 = (($supportA1) + 12|0);
   $266 = (($supportB2) + 4|0);
   $267 = (($supportB2) + 8|0);
   $268 = (($support3) + 4|0);
   $269 = (($support3) + 8|0);
   $270 = (($support3) + 12|0);
   $271 = (($a) + 48|0);
   $272 = (($b) + 48|0);
   $273 = (($Q) + 4|0);
   $274 = (($Q) + 8|0);
   $275 = (($A) + 4|0);
   $276 = (($A) + 8|0);
   $277 = (($B) + 4|0);
   $278 = (($B) + 8|0);
   $279 = (($6) + 4|0);
   $280 = (($6) + 8|0);
   $281 = (($6) + 12|0);
   $282 = (($Q) + 16|0);
   $$$i745809 = $11;$284 = $576;$286 = $575;$288 = $574;$383 = $$ph773;$519 = $$ph767;$520 = $$ph766;$521 = $$ph765;$522 = $$ph;$523 = $$ph771;$524 = $$ph770;$525 = $$ph769;$526 = $$ph768;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $283 = Math_fround(-$284);
    $285 = Math_fround(-$286);
    $287 = Math_fround(-$288);
    $289 = HEAP32[$size>>2]|0;
    $290 = (($A) + ($289<<4)|0);
    $291 = (($aInd) + ($289<<2)|0);
    $292 = Math_fround(HEAPF32[$243>>2]);
    $293 = Math_fround(HEAPF32[$244>>2]);
    $294 = Math_fround(HEAPF32[$245>>2]);
    $295 = Math_fround(HEAPF32[$7>>2]);
    $296 = Math_fround($292 - $295);
    $297 = Math_fround($293 - $295);
    $298 = Math_fround($294 - $295);
    $299 = Math_fround(HEAPF32[$aToB>>2]);
    $300 = Math_fround($299 * $283);
    $301 = Math_fround(HEAPF32[$246>>2]);
    $302 = Math_fround($301 * $285);
    $303 = Math_fround($300 + $302);
    $304 = Math_fround(HEAPF32[$247>>2]);
    $305 = Math_fround($304 * $287);
    $306 = Math_fround($303 + $305);
    $307 = Math_fround(HEAPF32[$248>>2]);
    $308 = Math_fround($307 * $283);
    $309 = Math_fround(HEAPF32[$249>>2]);
    $310 = Math_fround($309 * $285);
    $311 = Math_fround($308 + $310);
    $312 = Math_fround(HEAPF32[$250>>2]);
    $313 = Math_fround($312 * $287);
    $314 = Math_fround($311 + $313);
    $315 = Math_fround(HEAPF32[$251>>2]);
    $316 = Math_fround($315 * $283);
    $317 = Math_fround(HEAPF32[$252>>2]);
    $318 = Math_fround($317 * $285);
    $319 = Math_fround($316 + $318);
    $320 = Math_fround(HEAPF32[$253>>2]);
    $321 = Math_fround($320 * $287);
    $322 = Math_fround($319 + $321);
    $323 = $306 > Math_fround(0.0);
    $324 = $314 > Math_fround(0.0);
    $325 = $324 << 31 >> 31;
    $326 = $322 > Math_fround(0.0);
    $327 = $326 << 31 >> 31;
    $328 = $323&1;
    $329 = $325 << 1;
    $330 = $329 & 2;
    $331 = $327 << 2;
    $332 = $331 & 4;
    $333 = $330 | $328;
    $334 = $333 | $332;
    HEAP32[$291>>2] = $334;
    $335 = Math_fround(-$296);
    $336 = Math_fround(-$297);
    $337 = Math_fround(-$298);
    HEAPF32[$1>>2] = $296;
    HEAPF32[$254>>2] = $297;
    HEAPF32[$255>>2] = $298;
    HEAPF32[$256>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $335;
    HEAPF32[$257>>2] = $336;
    HEAPF32[$258>>2] = $337;
    HEAPF32[$259>>2] = Math_fround(0.0);
    $b$a$i$i = $323 ? $1 : $0;
    $338 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $324 ? $1 : $0;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $339 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $326 ? $1 : $0;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $340 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    $341 = Math_fround(HEAPF32[$260>>2]);
    $342 = Math_fround(HEAPF32[$261>>2]);
    $343 = Math_fround(HEAPF32[$262>>2]);
    $344 = Math_fround($299 * $338);
    $345 = Math_fround($307 * $339);
    $346 = Math_fround($344 + $345);
    $347 = Math_fround($315 * $340);
    $348 = Math_fround($346 + $347);
    $349 = Math_fround($301 * $338);
    $350 = Math_fround($309 * $339);
    $351 = Math_fround($349 + $350);
    $352 = Math_fround($317 * $340);
    $353 = Math_fround($351 + $352);
    $354 = Math_fround($304 * $338);
    $355 = Math_fround($312 * $339);
    $356 = Math_fround($354 + $355);
    $357 = Math_fround($320 * $340);
    $358 = Math_fround($356 + $357);
    $359 = Math_fround($341 + $348);
    $360 = Math_fround($342 + $353);
    $361 = Math_fround($358 + $343);
    HEAPF32[$supportA1>>2] = $359;
    HEAPF32[$263>>2] = $360;
    HEAPF32[$264>>2] = $361;
    HEAPF32[$265>>2] = Math_fround(0.0);
    ;HEAP32[$290+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$290+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$290+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$290+12>>2]=HEAP32[$supportA1+12>>2]|0;
    $362 = (($B) + ($289<<4)|0);
    $363 = (($bInd) + ($289<<2)|0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($supportB2,$b,$v,$362,$363);
    $364 = Math_fround(HEAPF32[$supportA1>>2]);
    $365 = Math_fround(HEAPF32[$263>>2]);
    $366 = Math_fround(HEAPF32[$264>>2]);
    $367 = Math_fround(HEAPF32[$supportB2>>2]);
    $368 = Math_fround(HEAPF32[$266>>2]);
    $369 = Math_fround(HEAPF32[$267>>2]);
    $370 = Math_fround($364 - $367);
    $371 = Math_fround($365 - $368);
    $372 = Math_fround($366 - $369);
    HEAPF32[$support3>>2] = $370;
    HEAPF32[$268>>2] = $371;
    HEAPF32[$269>>2] = $372;
    HEAPF32[$270>>2] = Math_fround(0.0);
    $373 = HEAP32[$size>>2]|0;
    $374 = (($373) + 1)|0;
    HEAP32[$size>>2] = $374;
    $375 = (($Q) + ($373<<4)|0);
    ;HEAP32[$375+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$375+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$375+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$375+12>>2]=HEAP32[$support3+12>>2]|0;
    $376 = Math_fround(HEAPF32[$271>>2]);
    $377 = Math_fround(HEAPF32[$272>>2]);
    $378 = $376 > $377;
    $$$i134 = $378 ? $376 : $377;
    $379 = $$$i745809 > $$$i134;
    $$$i = $379 ? $$$i745809 : $$$i134;
    $380 = Math_fround($18 + $$$i);
    $381 = Math_fround($380 * $380);
    $382 = Math_fround($383 * $381);
    $384 = Math_fround(HEAPF32[$v>>2]);
    $385 = Math_fround(HEAPF32[$241>>2]);
    $386 = Math_fround(HEAPF32[$242>>2]);
    $387 = Math_fround($384 * $370);
    $388 = Math_fround($385 * $371);
    $389 = Math_fround($387 + $388);
    $390 = Math_fround($386 * $372);
    $391 = Math_fround($389 + $390);
    $392 = Math_fround($391 * $391);
    $393 = $391 > Math_fround(0.0);
    $394 = $392 > $382;
    if ($393) {
     $phitmp761 = $394 ^ 1;
     $398 = $394;$400 = $phitmp761;
    } else {
     $398 = 0;$400 = 1;
    }
    $395 = Math_fround($383 - $391);
    $396 = Math_fround($25 * $383);
    $397 = $396 >= $395;
    $brmerge$demorgan = $397 | $398;
    if ($brmerge$demorgan) {
     $399 = $400 ^ 1;
     $$753 = $397 | $399;
     if ($$753) {
      break;
     }
    }
    do {
     if ((($373|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$6+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($373|0) == 1)) {
      $447 = Math_fround(HEAPF32[$Q>>2]);
      $448 = Math_fround(HEAPF32[$273>>2]);
      $449 = Math_fround(HEAPF32[$274>>2]);
      $450 = Math_fround($370 - $447);
      $451 = Math_fround($371 - $448);
      $452 = Math_fround($372 - $449);
      $453 = Math_fround($450 * $450);
      $454 = Math_fround($451 * $451);
      $455 = Math_fround($453 + $454);
      $456 = Math_fround($452 * $452);
      $457 = Math_fround($455 + $456);
      $458 = $457 == Math_fround(0.0);
      if ($458) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$6+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $459 = Math_fround($448 * $451);
       $460 = Math_fround(-$459);
       $461 = Math_fround($447 * $450);
       $462 = Math_fround($460 - $461);
       $463 = Math_fround($449 * $452);
       $464 = Math_fround($462 - $463);
       $465 = Math_fround(HEAPF32[$A>>2]);
       $466 = Math_fround(HEAPF32[$275>>2]);
       $467 = Math_fround(HEAPF32[$276>>2]);
       $468 = Math_fround($364 - $465);
       $469 = Math_fround($365 - $466);
       $470 = Math_fround($366 - $467);
       $471 = Math_fround(HEAPF32[$B>>2]);
       $472 = Math_fround(HEAPF32[$277>>2]);
       $473 = Math_fround(HEAPF32[$278>>2]);
       $474 = Math_fround($367 - $471);
       $475 = Math_fround($368 - $472);
       $476 = Math_fround($369 - $473);
       $477 = Math_fround($464 / $457);
       $478 = $477 > Math_fround(1.0);
       $$$i$i$i = $478 ? Math_fround(1.0) : $477;
       $479 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $479 ? $$$i$i$i : Math_fround(0.0);
       $480 = Math_fround($468 * $$$i8$i$i);
       $481 = Math_fround($469 * $$$i8$i$i);
       $482 = Math_fround($470 * $$$i8$i$i);
       $483 = Math_fround($465 + $480);
       $484 = Math_fround($466 + $481);
       $485 = Math_fround($467 + $482);
       $486 = Math_fround($474 * $$$i8$i$i);
       $487 = Math_fround($475 * $$$i8$i$i);
       $488 = Math_fround($476 * $$$i8$i$i);
       $489 = Math_fround($471 + $486);
       $490 = Math_fround($472 + $487);
       $491 = Math_fround($473 + $488);
       HEAPF32[$closA>>2] = $483;
       HEAPF32[$19>>2] = $484;
       HEAPF32[$20>>2] = $485;
       HEAPF32[$21>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $489;
       HEAPF32[$22>>2] = $490;
       HEAPF32[$23>>2] = $491;
       HEAPF32[$24>>2] = Math_fround(0.0);
       $492 = Math_fround($483 - $489);
       $493 = Math_fround($484 - $490);
       $494 = Math_fround($485 - $491);
       HEAPF32[$6>>2] = $492;
       HEAPF32[$279>>2] = $493;
       HEAPF32[$280>>2] = $494;
       HEAPF32[$281>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($373|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($6,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($373|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($6,$Q,$282,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$6+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$6+12>>2]|0;
    $495 = Math_fround(HEAPF32[$v>>2]);
    $496 = Math_fround(HEAPF32[$241>>2]);
    $497 = Math_fround(HEAPF32[$242>>2]);
    $498 = Math_fround($495 * $495);
    $499 = Math_fround($496 * $496);
    $500 = Math_fround($498 + $499);
    $501 = Math_fround($497 * $497);
    $502 = Math_fround($500 + $501);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1238+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1238+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1238+8>>2]|0;
    $503 = $383 > $502;
    $504 = $502 > $25;
    if (!($504)) {
     label = 38;
     break;
    }
    if (!($503)) {
     label = 38;
     break;
    }
    $$pre849 = Math_fround(HEAPF32[$closA>>2]);
    $$pre850 = Math_fround(HEAPF32[$19>>2]);
    $$pre851 = Math_fround(HEAPF32[$20>>2]);
    $$pre852 = Math_fround(HEAPF32[$21>>2]);
    $$pre853 = Math_fround(HEAPF32[$closB>>2]);
    $$pre854 = Math_fround(HEAPF32[$22>>2]);
    $$pre855 = Math_fround(HEAPF32[$23>>2]);
    $$pre856 = Math_fround(HEAPF32[$24>>2]);
    $$$i745809 = $$$i;$284 = $495;$286 = $496;$288 = $497;$383 = $502;$519 = $$pre849;$520 = $$pre850;$521 = $$pre851;$522 = $$pre852;$523 = $$pre853;$524 = $$pre854;$525 = $$pre855;$526 = $$pre856;
   }
   if ((label|0) == 38) {
    $505 = HEAP32[$size>>2]|0;
    if ($503) {
     $563 = $505;
     break;
    }
    $506 = (($505) + -1)|0;
    $507 = ($aIndices|0)==(0|0);
    if (!($507)) {
     $508 = $506&255;
     HEAP8[$_size>>0] = $508;
     $509 = ($506|0)==(0);
     if (!($509)) {
      $i$01$i29 = 0;
      while(1) {
       $510 = (($aInd) + ($i$01$i29<<2)|0);
       $511 = HEAP32[$510>>2]|0;
       $512 = $511&255;
       $513 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$513>>0] = $512;
       $514 = (($bInd) + ($i$01$i29<<2)|0);
       $515 = HEAP32[$514>>2]|0;
       $516 = $515&255;
       $517 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$517>>0] = $516;
       $518 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($518|0)==($506|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $518;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $519;
    HEAPF32[$19>>2] = $520;
    HEAPF32[$20>>2] = $521;
    HEAPF32[$21>>2] = $522;
    HEAPF32[$closB>>2] = $523;
    HEAPF32[$22>>2] = $524;
    HEAPF32[$23>>2] = $525;
    HEAPF32[$24>>2] = $526;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $527 = Math_fround($519 - $523);
    $528 = Math_fround($520 - $524);
    $529 = Math_fround($521 - $525);
    HEAPF32[$v>>2] = $527;
    $530 = (($v) + 4|0);
    HEAPF32[$530>>2] = $528;
    $531 = (($v) + 8|0);
    HEAPF32[$531>>2] = $529;
    $532 = (($v) + 12|0);
    HEAPF32[$532>>2] = Math_fround(0.0);
    $533 = (Math_fround(Math_sqrt((Math_fround($383)))));
    $534 = Math_fround(Math_fround(1.0) / $533);
    $535 = Math_fround($527 * $534);
    $536 = Math_fround($528 * $534);
    $537 = Math_fround($529 * $534);
    $538 = Math_fround($8 * $535);
    $539 = Math_fround($8 * $536);
    $540 = Math_fround($8 * $537);
    $541 = Math_fround($519 - $538);
    $542 = Math_fround($520 - $539);
    $543 = Math_fround($521 - $540);
    HEAPF32[$contactA>>2] = $541;
    $544 = (($contactA) + 4|0);
    HEAPF32[$544>>2] = $542;
    $545 = (($contactA) + 8|0);
    HEAPF32[$545>>2] = $543;
    $546 = (($contactA) + 12|0);
    HEAPF32[$546>>2] = Math_fround(0.0);
    $547 = Math_fround($10 * $535);
    $548 = Math_fround($10 * $536);
    $549 = Math_fround($10 * $537);
    $550 = Math_fround($547 + $523);
    $551 = Math_fround($548 + $524);
    $552 = Math_fround($549 + $525);
    HEAPF32[$contactB>>2] = $550;
    $553 = (($contactB) + 4|0);
    HEAPF32[$553>>2] = $551;
    $554 = (($contactB) + 8|0);
    HEAPF32[$554>>2] = $552;
    $555 = (($contactB) + 12|0);
    HEAPF32[$555>>2] = Math_fround(0.0);
    $556 = Math_fround($533 - $18);
    HEAPF32[$penetrationDepth>>2] = $556;
    $557 = (($penetrationDepth) + 4|0);
    ;HEAP32[$557+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$557+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$557+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $535;
    $558 = (($normal) + 4|0);
    HEAPF32[$558>>2] = $536;
    $559 = (($normal) + 8|0);
    HEAPF32[$559>>2] = $537;
    $560 = (($normal) + 12|0);
    HEAPF32[$560>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $401 = ($aIndices|0)==(0|0);
   if (!($401)) {
    $402 = $373&255;
    HEAP8[$_size>>0] = $402;
    $403 = ($373|0)==(0);
    if (!($403)) {
     $i$01$i72 = 0;
     while(1) {
      $404 = (($aInd) + ($i$01$i72<<2)|0);
      $405 = HEAP32[$404>>2]|0;
      $406 = $405&255;
      $407 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$407>>0] = $406;
      $408 = (($bInd) + ($i$01$i72<<2)|0);
      $409 = HEAP32[$408>>2]|0;
      $410 = $409&255;
      $411 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$411>>0] = $410;
      $412 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($412|0)==($373|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $412;
      }
     }
    }
   }
   $not$ = $398 ^ 1;
   $$$757 = $400 & $not$;
   if (!($$$757)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $413 = (Math_fround(Math_sqrt((Math_fround($383)))));
   $414 = Math_fround(Math_fround(1.0) / $413);
   $415 = Math_fround($384 * $414);
   $416 = Math_fround($385 * $414);
   $417 = Math_fround($386 * $414);
   $418 = Math_fround(HEAPF32[$closA>>2]);
   $419 = Math_fround(HEAPF32[$19>>2]);
   $420 = Math_fround(HEAPF32[$20>>2]);
   $421 = Math_fround($8 * $415);
   $422 = Math_fround($8 * $416);
   $423 = Math_fround($8 * $417);
   $424 = Math_fround($418 - $421);
   $425 = Math_fround($419 - $422);
   $426 = Math_fround($420 - $423);
   HEAPF32[$contactA>>2] = $424;
   $427 = (($contactA) + 4|0);
   HEAPF32[$427>>2] = $425;
   $428 = (($contactA) + 8|0);
   HEAPF32[$428>>2] = $426;
   $429 = (($contactA) + 12|0);
   HEAPF32[$429>>2] = Math_fround(0.0);
   $430 = Math_fround(HEAPF32[$closB>>2]);
   $431 = Math_fround(HEAPF32[$22>>2]);
   $432 = Math_fround(HEAPF32[$23>>2]);
   $433 = Math_fround($10 * $415);
   $434 = Math_fround($10 * $416);
   $435 = Math_fround($10 * $417);
   $436 = Math_fround($433 + $430);
   $437 = Math_fround($434 + $431);
   $438 = Math_fround($435 + $432);
   HEAPF32[$contactB>>2] = $436;
   $439 = (($contactB) + 4|0);
   HEAPF32[$439>>2] = $437;
   $440 = (($contactB) + 8|0);
   HEAPF32[$440>>2] = $438;
   $441 = (($contactB) + 12|0);
   HEAPF32[$441>>2] = Math_fround(0.0);
   $442 = Math_fround($413 - $18);
   HEAPF32[$penetrationDepth>>2] = $442;
   $443 = (($penetrationDepth) + 4|0);
   ;HEAP32[$443+0>>2]=HEAP32[$$sroa$1240+0>>2]|0;HEAP32[$443+4>>2]=HEAP32[$$sroa$1240+4>>2]|0;HEAP32[$443+8>>2]=HEAP32[$$sroa$1240+8>>2]|0;
   HEAPF32[$normal>>2] = $415;
   $444 = (($normal) + 4|0);
   HEAPF32[$444>>2] = $416;
   $445 = (($normal) + 8|0);
   HEAPF32[$445>>2] = $417;
   $446 = (($normal) + 12|0);
   HEAPF32[$446>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $240 = HEAP32[$size>>2]|0;
   $563 = $240;
  }
 } while(0);
 $561 = ($aIndices|0)==(0|0);
 if (!($561)) {
  $562 = $563&255;
  HEAP8[$_size>>0] = $562;
  $564 = ($563|0)==(0);
  if (!($564)) {
   $i$01$i = 0;
   while(1) {
    $565 = (($aInd) + ($i$01$i<<2)|0);
    $566 = HEAP32[$565>>2]|0;
    $567 = $566&255;
    $568 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$568>>0] = $567;
    $569 = (($bInd) + ($i$01$i<<2)|0);
    $570 = HEAP32[$569>>2]|0;
    $571 = $570&255;
    $572 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$572>>0] = $571;
    $573 = (($i$01$i) + 1)|0;
    $exitcond$i = ($573|0)==($563|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $573;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_10ShrunkBoxVENS0_24ShrunkConvexHullNoScaleVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$757 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i170 = Math_fround(0), $$$i134 = Math_fround(0), $$$i169 = Math_fround(0), $$$i745809 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i171 = Math_fround(0), $$0 = 0, $$0$i$i = 0, $$753 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i180 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i182 = 0, $$ph = Math_fround(0), $$ph765 = Math_fround(0);
 var $$ph766 = Math_fround(0), $$ph767 = Math_fround(0), $$ph768 = Math_fround(0), $$ph769 = Math_fround(0), $$ph770 = Math_fround(0), $$ph771 = Math_fround(0), $$ph773 = Math_fround(0), $$ph774 = 0, $$pre = Math_fround(0), $$pre849 = Math_fround(0), $$pre850 = Math_fround(0), $$pre851 = Math_fround(0), $$pre852 = Math_fround(0), $$pre853 = Math_fround(0), $$pre854 = Math_fround(0), $$pre855 = Math_fround(0), $$pre856 = Math_fround(0), $$sroa$1 = 0, $$sroa$1238 = 0, $$sroa$1240 = 0;
 var $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0;
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = 0;
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = 0, $438 = 0, $439 = Math_fround(0);
 var $44 = 0, $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = Math_fround(0);
 var $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = 0, $473 = 0, $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = 0, $484 = 0, $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0);
 var $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0);
 var $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0);
 var $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0);
 var $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = 0, $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0);
 var $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = Math_fround(0);
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0);
 var $62 = 0, $620 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $a$pn3$i$i = 0, $a$pn3$i$i179 = 0, $aInd = 0, $b$a$i = 0, $b$a$i$i = 0, $b$a$i$i177 = 0, $b$a5$i$i = 0, $b$a5$i$i181 = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0;
 var $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$041$i$i$i = 0, $i$0819 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $maxIndex$040$i$i$i = 0, $maxIndex$1$i$i$i = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp761 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $v = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 400|0;
 $1 = sp + 336|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $closA = sp + 384|0;
 $closB = sp + 416|0;
 $sDist$sroa$1 = sp + 516|0;
 $minDist$sroa$1 = sp + 504|0;
 $v = sp + 320|0;
 $Q = sp;
 $A = sp + 160|0;
 $B = sp + 64|0;
 $aInd = sp + 488|0;
 $bInd = sp + 528|0;
 $size = sp + 448|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 144|0;
 $lastB = sp + 224|0;
 $4 = sp + 240|0;
 $5 = sp + 256|0;
 $supportA1 = sp + 272|0;
 $supportB2 = sp + 288|0;
 $support3 = sp + 304|0;
 $$sroa$1240 = sp + 464|0;
 $6 = sp + 432|0;
 $$sroa$1238 = sp + 476|0;
 $$sroa$1 = sp + 452|0;
 $7 = (($a) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($b) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$_contactDist>>2]);
 $12 = (($a) + 32|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($b) + 32|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = $13 > $15;
 $$$i169 = $16 ? $15 : $13;
 $17 = Math_fround($$$i169 * Math_fround(0.100000001490116119385));
 $18 = Math_fround($8 + $10);
 $19 = (($closA) + 4|0);
 $20 = (($closA) + 8|0);
 $21 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $22 = (($closB) + 4|0);
 $23 = (($closB) + 8|0);
 $24 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $25 = Math_fround($17 * $17);
 HEAP32[$size>>2] = 0;
 $26 = HEAP8[$_size>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $214 = (($aToB) + 48|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($aToB) + 52|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($aToB) + 56|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = (($aToB) + 60|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = Math_fround($215 * $215);
  $223 = Math_fround($217 * $217);
  $224 = Math_fround($222 + $223);
  $225 = Math_fround($219 * $219);
  $226 = Math_fround($224 + $225);
  $227 = $226 > Math_fround(0.0);
  HEAPF32[$3>>2] = $215;
  $228 = (($3) + 4|0);
  HEAPF32[$228>>2] = $217;
  $229 = (($3) + 8|0);
  HEAPF32[$229>>2] = $219;
  $230 = (($3) + 12|0);
  HEAPF32[$230>>2] = $221;
  HEAPF32[$2>>2] = Math_fround(1.0);
  $231 = (($2) + 4|0);
  HEAPF32[$231>>2] = Math_fround(0.0);
  $232 = (($2) + 8|0);
  HEAPF32[$232>>2] = Math_fround(0.0);
  $233 = (($2) + 12|0);
  HEAPF32[$233>>2] = Math_fround(0.0);
  $b$a$i = $227 ? $3 : $2;
  $234 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $235 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $236 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $234;
  $237 = (($v) + 4|0);
  HEAPF32[$237>>2] = $235;
  $238 = (($v) + 8|0);
  HEAPF32[$238>>2] = $236;
  $239 = (($v) + 12|0);
  HEAPF32[$239>>2] = Math_fround(0.0);
  $$ph = Math_fround(0.0);$$ph765 = Math_fround(0.0);$$ph766 = Math_fround(0.0);$$ph767 = Math_fround(0.0);$$ph768 = Math_fround(0.0);$$ph769 = Math_fround(0.0);$$ph770 = Math_fround(0.0);$$ph771 = Math_fround(0.0);$$ph773 = Math_fround(3.40282346638528859812E+38);$$ph774 = 1;$618 = $236;$619 = $235;$620 = $234;
 } else {
  $28 = (($lastQ) + 4|0);
  $29 = (($lastQ) + 8|0);
  $30 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $31 = (($lastA) + 4|0);
  $32 = (($lastA) + 8|0);
  $33 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $34 = (($lastB) + 4|0);
  $35 = (($lastB) + 8|0);
  $36 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $37 = (($a) + 144|0);
  $38 = (($a) + 148|0);
  $39 = (($a) + 152|0);
  $40 = (($1) + 4|0);
  $41 = (($1) + 8|0);
  $42 = (($1) + 12|0);
  $43 = (($0) + 4|0);
  $44 = (($0) + 8|0);
  $45 = (($0) + 12|0);
  $46 = (($aToB) + 48|0);
  $47 = (($aToB) + 52|0);
  $48 = (($aToB) + 56|0);
  $49 = (($aToB) + 16|0);
  $50 = (($aToB) + 32|0);
  $51 = (($aToB) + 4|0);
  $52 = (($aToB) + 20|0);
  $53 = (($aToB) + 36|0);
  $54 = (($aToB) + 8|0);
  $55 = (($aToB) + 24|0);
  $56 = (($aToB) + 40|0);
  $57 = (($b) + 16|0);
  $58 = (($4) + 4|0);
  $59 = (($4) + 8|0);
  $60 = (($4) + 12|0);
  $73 = $8;$i$0819 = 0;
  while(1) {
   $61 = (($aIndices) + ($i$0819)|0);
   $62 = HEAP8[$61>>0]|0;
   $63 = $62&255;
   $64 = (($aInd) + ($i$0819<<2)|0);
   HEAP32[$64>>2] = $63;
   $65 = (($bIndices) + ($i$0819)|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = $66&255;
   $68 = (($bInd) + ($i$0819<<2)|0);
   HEAP32[$68>>2] = $67;
   $69 = Math_fround(HEAPF32[$37>>2]);
   $70 = Math_fround(HEAPF32[$38>>2]);
   $71 = Math_fround(HEAPF32[$39>>2]);
   $72 = Math_fround($69 - $73);
   $74 = Math_fround($70 - $73);
   $75 = Math_fround($71 - $73);
   $76 = (549664 + ($63<<4)|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ((549664 + ($63<<4)|0) + 4|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ((549664 + ($63<<4)|0) + 8|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = Math_fround(-$72);
   $83 = Math_fround(-$74);
   $84 = Math_fround(-$75);
   HEAPF32[$1>>2] = $72;
   HEAPF32[$40>>2] = $74;
   HEAPF32[$41>>2] = $75;
   HEAPF32[$42>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $82;
   HEAPF32[$43>>2] = $83;
   HEAPF32[$44>>2] = $84;
   HEAPF32[$45>>2] = Math_fround(0.0);
   $85 = ($77|0)==(0);
   $b$a$i$i177 = $85 ? $0 : $1;
   $86 = Math_fround(HEAPF32[$b$a$i$i177>>2]);
   $87 = ($79|0)==(0);
   $a$pn3$i$i179 = $87 ? $0 : $1;
   $$in1$i$i180 = (($a$pn3$i$i179) + 4|0);
   $88 = Math_fround(HEAPF32[$$in1$i$i180>>2]);
   $89 = ($81|0)==(0);
   $b$a5$i$i181 = $89 ? $0 : $1;
   $$in2$i$i182 = (($b$a5$i$i181) + 8|0);
   $90 = Math_fround(HEAPF32[$$in2$i$i182>>2]);
   $91 = Math_fround(HEAPF32[$46>>2]);
   $92 = Math_fround(HEAPF32[$47>>2]);
   $93 = Math_fround(HEAPF32[$48>>2]);
   $94 = Math_fround(HEAPF32[$aToB>>2]);
   $95 = Math_fround($86 * $94);
   $96 = Math_fround(HEAPF32[$49>>2]);
   $97 = Math_fround($88 * $96);
   $98 = Math_fround($95 + $97);
   $99 = Math_fround(HEAPF32[$50>>2]);
   $100 = Math_fround($90 * $99);
   $101 = Math_fround($98 + $100);
   $102 = Math_fround(HEAPF32[$51>>2]);
   $103 = Math_fround($86 * $102);
   $104 = Math_fround(HEAPF32[$52>>2]);
   $105 = Math_fround($88 * $104);
   $106 = Math_fround($103 + $105);
   $107 = Math_fround(HEAPF32[$53>>2]);
   $108 = Math_fround($90 * $107);
   $109 = Math_fround($106 + $108);
   $110 = Math_fround(HEAPF32[$54>>2]);
   $111 = Math_fround($86 * $110);
   $112 = Math_fround(HEAPF32[$55>>2]);
   $113 = Math_fround($88 * $112);
   $114 = Math_fround($111 + $113);
   $115 = Math_fround(HEAPF32[$56>>2]);
   $116 = Math_fround($90 * $115);
   $117 = Math_fround($114 + $116);
   $118 = Math_fround($91 + $101);
   $119 = Math_fround($92 + $109);
   $120 = Math_fround($93 + $117);
   __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($4,$b,$67,$57);
   $121 = Math_fround(HEAPF32[$4>>2]);
   $122 = Math_fround(HEAPF32[$58>>2]);
   $123 = Math_fround(HEAPF32[$59>>2]);
   $124 = Math_fround(HEAPF32[$60>>2]);
   $125 = Math_fround($118 - $121);
   $126 = Math_fround($119 - $122);
   $127 = Math_fround($120 - $123);
   $128 = HEAP32[$size>>2]|0;
   $129 = (($A) + ($128<<4)|0);
   HEAPF32[$lastA>>2] = $118;
   HEAPF32[$31>>2] = $119;
   HEAPF32[$32>>2] = $120;
   HEAPF32[$33>>2] = Math_fround(0.0);
   ;HEAP32[$129+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$129+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$129+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$129+12>>2]=HEAP32[$lastA+12>>2]|0;
   $130 = (($B) + ($128<<4)|0);
   HEAPF32[$lastB>>2] = $121;
   HEAPF32[$34>>2] = $122;
   HEAPF32[$35>>2] = $123;
   HEAPF32[$36>>2] = $124;
   ;HEAP32[$130+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$130+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$130+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$130+12>>2]=HEAP32[$lastB+12>>2]|0;
   $131 = (($128) + 1)|0;
   HEAP32[$size>>2] = $131;
   $132 = (($Q) + ($128<<4)|0);
   HEAPF32[$lastQ>>2] = $125;
   HEAPF32[$28>>2] = $126;
   HEAPF32[$29>>2] = $127;
   HEAPF32[$30>>2] = Math_fround(0.0);
   ;HEAP32[$132+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$132+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $133 = (($i$0819) + 1)|0;
   $134 = HEAP8[$_size>>0]|0;
   $135 = $134&255;
   $136 = ($133>>>0)<($135>>>0);
   if (!($136)) {
    break;
   }
   $$pre = Math_fround(HEAPF32[$7>>2]);
   $73 = $$pre;$i$0819 = $133;
  }
  do {
   if ((($128|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$5+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($128|0) == 1)) {
    $137 = Math_fround(HEAPF32[$Q>>2]);
    $138 = (($Q) + 4|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = (($Q) + 8|0);
    $141 = Math_fround(HEAPF32[$140>>2]);
    $142 = Math_fround($125 - $137);
    $143 = Math_fround($126 - $139);
    $144 = Math_fround($127 - $141);
    $145 = Math_fround($142 * $142);
    $146 = Math_fround($143 * $143);
    $147 = Math_fround($145 + $146);
    $148 = Math_fround($144 * $144);
    $149 = Math_fround($147 + $148);
    $150 = $149 == Math_fround(0.0);
    if ($150) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $151 = Math_fround($139 * $143);
     $152 = Math_fround(-$151);
     $153 = Math_fround($137 * $142);
     $154 = Math_fround($152 - $153);
     $155 = Math_fround($141 * $144);
     $156 = Math_fround($154 - $155);
     $157 = Math_fround(HEAPF32[$A>>2]);
     $158 = (($A) + 4|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = (($A) + 8|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = Math_fround($118 - $157);
     $163 = Math_fround($119 - $159);
     $164 = Math_fround($120 - $161);
     $165 = Math_fround(HEAPF32[$B>>2]);
     $166 = (($B) + 4|0);
     $167 = Math_fround(HEAPF32[$166>>2]);
     $168 = (($B) + 8|0);
     $169 = Math_fround(HEAPF32[$168>>2]);
     $170 = Math_fround($121 - $165);
     $171 = Math_fround($122 - $167);
     $172 = Math_fround($123 - $169);
     $173 = Math_fround($156 / $149);
     $174 = $173 > Math_fround(1.0);
     $$$i$i$i170 = $174 ? Math_fround(1.0) : $173;
     $175 = $$$i$i$i170 > Math_fround(0.0);
     $$$i8$i$i171 = $175 ? $$$i$i$i170 : Math_fround(0.0);
     $176 = Math_fround($162 * $$$i8$i$i171);
     $177 = Math_fround($163 * $$$i8$i$i171);
     $178 = Math_fround($164 * $$$i8$i$i171);
     $179 = Math_fround($157 + $176);
     $180 = Math_fround($159 + $177);
     $181 = Math_fround($161 + $178);
     $182 = Math_fround($170 * $$$i8$i$i171);
     $183 = Math_fround($171 * $$$i8$i$i171);
     $184 = Math_fround($172 * $$$i8$i$i171);
     $185 = Math_fround($165 + $182);
     $186 = Math_fround($167 + $183);
     $187 = Math_fround($169 + $184);
     HEAPF32[$closA>>2] = $179;
     HEAPF32[$19>>2] = $180;
     HEAPF32[$20>>2] = $181;
     HEAPF32[$21>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $185;
     HEAPF32[$22>>2] = $186;
     HEAPF32[$23>>2] = $187;
     HEAPF32[$24>>2] = Math_fround(0.0);
     $188 = Math_fround($179 - $185);
     $189 = Math_fround($180 - $186);
     $190 = Math_fround($181 - $187);
     HEAPF32[$5>>2] = $188;
     $191 = (($5) + 4|0);
     HEAPF32[$191>>2] = $189;
     $192 = (($5) + 8|0);
     HEAPF32[$192>>2] = $190;
     $193 = (($5) + 12|0);
     HEAPF32[$193>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($128|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($128|0) == 2)) {
    $194 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$194,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$5+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
  $195 = Math_fround(HEAPF32[$v>>2]);
  $196 = (($v) + 4|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = (($v) + 8|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = Math_fround($195 * $195);
  $201 = Math_fround($197 * $197);
  $202 = Math_fround($200 + $201);
  $203 = Math_fround($199 * $199);
  $204 = Math_fround($202 + $203);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $205 = Math_fround(HEAPF32[$closA>>2]);
  $206 = Math_fround(HEAPF32[$19>>2]);
  $207 = Math_fround(HEAPF32[$20>>2]);
  $208 = Math_fround(HEAPF32[$21>>2]);
  $209 = Math_fround(HEAPF32[$closB>>2]);
  $210 = Math_fround(HEAPF32[$22>>2]);
  $211 = Math_fround(HEAPF32[$23>>2]);
  $212 = Math_fround(HEAPF32[$24>>2]);
  $213 = $204 > $25;
  $$ph = $208;$$ph765 = $207;$$ph766 = $206;$$ph767 = $205;$$ph768 = $212;$$ph769 = $211;$$ph770 = $210;$$ph771 = $209;$$ph773 = $204;$$ph774 = $213;$618 = $199;$619 = $197;$620 = $195;
 }
 do {
  if ($$ph774) {
   $241 = (($v) + 4|0);
   $242 = (($v) + 8|0);
   $243 = (($a) + 144|0);
   $244 = (($a) + 148|0);
   $245 = (($a) + 152|0);
   $246 = (($aToB) + 4|0);
   $247 = (($aToB) + 8|0);
   $248 = (($aToB) + 16|0);
   $249 = (($aToB) + 20|0);
   $250 = (($aToB) + 24|0);
   $251 = (($aToB) + 32|0);
   $252 = (($aToB) + 36|0);
   $253 = (($aToB) + 40|0);
   $254 = (($1) + 4|0);
   $255 = (($1) + 8|0);
   $256 = (($1) + 12|0);
   $257 = (($0) + 4|0);
   $258 = (($0) + 8|0);
   $259 = (($0) + 12|0);
   $260 = (($aToB) + 48|0);
   $261 = (($aToB) + 52|0);
   $262 = (($aToB) + 56|0);
   $263 = (($supportA1) + 4|0);
   $264 = (($supportA1) + 8|0);
   $265 = (($supportA1) + 12|0);
   $266 = (($b) + 196|0);
   $267 = (($b) + 200|0);
   $268 = (($b) + 204|0);
   $269 = (($b) + 16|0);
   $270 = (($supportB2) + 4|0);
   $271 = (($supportB2) + 8|0);
   $272 = (($support3) + 4|0);
   $273 = (($support3) + 8|0);
   $274 = (($support3) + 12|0);
   $275 = (($a) + 48|0);
   $276 = (($b) + 48|0);
   $277 = (($Q) + 4|0);
   $278 = (($Q) + 8|0);
   $279 = (($A) + 4|0);
   $280 = (($A) + 8|0);
   $281 = (($B) + 4|0);
   $282 = (($B) + 8|0);
   $283 = (($6) + 4|0);
   $284 = (($6) + 8|0);
   $285 = (($6) + 12|0);
   $286 = (($Q) + 16|0);
   $$$i745809 = $11;$288 = $620;$290 = $619;$292 = $618;$427 = $$ph773;$563 = $$ph767;$564 = $$ph766;$565 = $$ph765;$566 = $$ph;$567 = $$ph771;$568 = $$ph770;$569 = $$ph769;$570 = $$ph768;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $287 = Math_fround(-$288);
    $289 = Math_fround(-$290);
    $291 = Math_fround(-$292);
    $293 = HEAP32[$size>>2]|0;
    $294 = (($A) + ($293<<4)|0);
    $295 = (($aInd) + ($293<<2)|0);
    $296 = Math_fround(HEAPF32[$243>>2]);
    $297 = Math_fround(HEAPF32[$244>>2]);
    $298 = Math_fround(HEAPF32[$245>>2]);
    $299 = Math_fround(HEAPF32[$7>>2]);
    $300 = Math_fround($296 - $299);
    $301 = Math_fround($297 - $299);
    $302 = Math_fround($298 - $299);
    $303 = Math_fround(HEAPF32[$aToB>>2]);
    $304 = Math_fround($303 * $287);
    $305 = Math_fround(HEAPF32[$246>>2]);
    $306 = Math_fround($305 * $289);
    $307 = Math_fround($304 + $306);
    $308 = Math_fround(HEAPF32[$247>>2]);
    $309 = Math_fround($308 * $291);
    $310 = Math_fround($307 + $309);
    $311 = Math_fround(HEAPF32[$248>>2]);
    $312 = Math_fround($311 * $287);
    $313 = Math_fround(HEAPF32[$249>>2]);
    $314 = Math_fround($313 * $289);
    $315 = Math_fround($312 + $314);
    $316 = Math_fround(HEAPF32[$250>>2]);
    $317 = Math_fround($316 * $291);
    $318 = Math_fround($315 + $317);
    $319 = Math_fround(HEAPF32[$251>>2]);
    $320 = Math_fround($319 * $287);
    $321 = Math_fround(HEAPF32[$252>>2]);
    $322 = Math_fround($321 * $289);
    $323 = Math_fround($320 + $322);
    $324 = Math_fround(HEAPF32[$253>>2]);
    $325 = Math_fround($324 * $291);
    $326 = Math_fround($323 + $325);
    $327 = $310 > Math_fround(0.0);
    $328 = $318 > Math_fround(0.0);
    $329 = $328 << 31 >> 31;
    $330 = $326 > Math_fround(0.0);
    $331 = $330 << 31 >> 31;
    $332 = $327&1;
    $333 = $329 << 1;
    $334 = $333 & 2;
    $335 = $331 << 2;
    $336 = $335 & 4;
    $337 = $334 | $332;
    $338 = $337 | $336;
    HEAP32[$295>>2] = $338;
    $339 = Math_fround(-$300);
    $340 = Math_fround(-$301);
    $341 = Math_fround(-$302);
    HEAPF32[$1>>2] = $300;
    HEAPF32[$254>>2] = $301;
    HEAPF32[$255>>2] = $302;
    HEAPF32[$256>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $339;
    HEAPF32[$257>>2] = $340;
    HEAPF32[$258>>2] = $341;
    HEAPF32[$259>>2] = Math_fround(0.0);
    $b$a$i$i = $327 ? $1 : $0;
    $342 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $328 ? $1 : $0;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $343 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $330 ? $1 : $0;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $344 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    $345 = Math_fround(HEAPF32[$260>>2]);
    $346 = Math_fround(HEAPF32[$261>>2]);
    $347 = Math_fround(HEAPF32[$262>>2]);
    $348 = Math_fround($303 * $342);
    $349 = Math_fround($311 * $343);
    $350 = Math_fround($348 + $349);
    $351 = Math_fround($319 * $344);
    $352 = Math_fround($350 + $351);
    $353 = Math_fround($305 * $342);
    $354 = Math_fround($313 * $343);
    $355 = Math_fround($353 + $354);
    $356 = Math_fround($321 * $344);
    $357 = Math_fround($355 + $356);
    $358 = Math_fround($308 * $342);
    $359 = Math_fround($316 * $343);
    $360 = Math_fround($358 + $359);
    $361 = Math_fround($324 * $344);
    $362 = Math_fround($360 + $361);
    $363 = Math_fround($345 + $352);
    $364 = Math_fround($346 + $357);
    $365 = Math_fround($362 + $347);
    HEAPF32[$supportA1>>2] = $363;
    HEAPF32[$263>>2] = $364;
    HEAPF32[$264>>2] = $365;
    HEAPF32[$265>>2] = Math_fround(0.0);
    ;HEAP32[$294+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$294+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$294+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$294+12>>2]=HEAP32[$supportA1+12>>2]|0;
    $366 = (($B) + ($293<<4)|0);
    $367 = (($bInd) + ($293<<2)|0);
    $368 = HEAP32[$266>>2]|0;
    $369 = ($368|0)==(0|0);
    if ($369) {
     $371 = HEAP32[$267>>2]|0;
     $372 = HEAP8[$268>>0]|0;
     $373 = ($372&255)>(1);
     if ($373) {
      $374 = (($371) + 4|0);
      $375 = Math_fround(HEAPF32[$241>>2]);
      $376 = Math_fround(HEAPF32[$v>>2]);
      $377 = (($371) + 8|0);
      $378 = Math_fround(HEAPF32[$374>>2]);
      $379 = Math_fround(HEAPF32[$371>>2]);
      $380 = Math_fround($375 * $378);
      $381 = Math_fround($376 * $379);
      $382 = Math_fround(HEAPF32[$242>>2]);
      $383 = Math_fround(HEAPF32[$377>>2]);
      $384 = Math_fround($382 * $383);
      $385 = Math_fround($380 + $381);
      $386 = Math_fround($385 + $384);
      $388 = $371;$402 = $386;$i$041$i$i$i = 1;$maxIndex$040$i$i$i = 0;
      while(1) {
       $$sum$i$i$i = (($i$041$i$i$i) + 10)|0;
       $387 = ((($388) + (($$sum$i$i$i*12)|0)|0) + 8|0);
       $389 = HEAP32[$267>>2]|0;
       $390 = (($389) + (($i$041$i$i$i*12)|0)|0);
       $391 = Math_fround(HEAPF32[$390>>2]);
       $392 = ((($389) + (($i$041$i$i$i*12)|0)|0) + 4|0);
       $393 = Math_fround(HEAPF32[$392>>2]);
       $394 = ((($389) + (($i$041$i$i$i*12)|0)|0) + 8|0);
       $395 = Math_fround(HEAPF32[$394>>2]);
       $396 = Math_fround($391 * $376);
       $397 = Math_fround($393 * $375);
       $398 = Math_fround($396 + $397);
       $399 = Math_fround($395 * $382);
       $400 = Math_fround($398 + $399);
       $401 = $400 > $402;
       $403 = $401 ? $400 : $402;
       $maxIndex$1$i$i$i = $401 ? $i$041$i$i$i : $maxIndex$040$i$i$i;
       $404 = (($i$041$i$i$i) + 1)|0;
       $405 = HEAP8[$268>>0]|0;
       $406 = $405&255;
       $407 = ($404>>>0)<($406>>>0);
       if ($407) {
        $388 = $389;$402 = $403;$i$041$i$i$i = $404;$maxIndex$040$i$i$i = $maxIndex$1$i$i$i;
       } else {
        $$0$i$i = $maxIndex$1$i$i$i;
        break;
       }
      }
     } else {
      $$0$i$i = 0;
     }
    } else {
     $370 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($b,$v)|0);
     $$0$i$i = $370;
    }
    HEAP32[$367>>2] = $$0$i$i;
    __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($supportB2,$b,$$0$i$i,$269);
    ;HEAP32[$366+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$366+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$366+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$366+12>>2]=HEAP32[$supportB2+12>>2]|0;
    $408 = Math_fround(HEAPF32[$supportA1>>2]);
    $409 = Math_fround(HEAPF32[$263>>2]);
    $410 = Math_fround(HEAPF32[$264>>2]);
    $411 = Math_fround(HEAPF32[$supportB2>>2]);
    $412 = Math_fround(HEAPF32[$270>>2]);
    $413 = Math_fround(HEAPF32[$271>>2]);
    $414 = Math_fround($408 - $411);
    $415 = Math_fround($409 - $412);
    $416 = Math_fround($410 - $413);
    HEAPF32[$support3>>2] = $414;
    HEAPF32[$272>>2] = $415;
    HEAPF32[$273>>2] = $416;
    HEAPF32[$274>>2] = Math_fround(0.0);
    $417 = HEAP32[$size>>2]|0;
    $418 = (($417) + 1)|0;
    HEAP32[$size>>2] = $418;
    $419 = (($Q) + ($417<<4)|0);
    ;HEAP32[$419+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$419+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$419+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$419+12>>2]=HEAP32[$support3+12>>2]|0;
    $420 = Math_fround(HEAPF32[$275>>2]);
    $421 = Math_fround(HEAPF32[$276>>2]);
    $422 = $420 > $421;
    $$$i134 = $422 ? $420 : $421;
    $423 = $$$i745809 > $$$i134;
    $$$i = $423 ? $$$i745809 : $$$i134;
    $424 = Math_fround($18 + $$$i);
    $425 = Math_fround($424 * $424);
    $426 = Math_fround($427 * $425);
    $428 = Math_fround(HEAPF32[$v>>2]);
    $429 = Math_fround(HEAPF32[$241>>2]);
    $430 = Math_fround(HEAPF32[$242>>2]);
    $431 = Math_fround($428 * $414);
    $432 = Math_fround($429 * $415);
    $433 = Math_fround($431 + $432);
    $434 = Math_fround($430 * $416);
    $435 = Math_fround($433 + $434);
    $436 = Math_fround($435 * $435);
    $437 = $435 > Math_fround(0.0);
    $438 = $436 > $426;
    if ($437) {
     $phitmp761 = $438 ^ 1;
     $442 = $438;$444 = $phitmp761;
    } else {
     $442 = 0;$444 = 1;
    }
    $439 = Math_fround($427 - $435);
    $440 = Math_fround($25 * $427);
    $441 = $440 >= $439;
    $brmerge$demorgan = $441 | $442;
    if ($brmerge$demorgan) {
     $443 = $444 ^ 1;
     $$753 = $441 | $443;
     if ($$753) {
      break;
     }
    }
    do {
     if ((($417|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($6,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($417|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$6+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($417|0) == 1)) {
      $491 = Math_fround(HEAPF32[$Q>>2]);
      $492 = Math_fround(HEAPF32[$277>>2]);
      $493 = Math_fround(HEAPF32[$278>>2]);
      $494 = Math_fround($414 - $491);
      $495 = Math_fround($415 - $492);
      $496 = Math_fround($416 - $493);
      $497 = Math_fround($494 * $494);
      $498 = Math_fround($495 * $495);
      $499 = Math_fround($497 + $498);
      $500 = Math_fround($496 * $496);
      $501 = Math_fround($499 + $500);
      $502 = $501 == Math_fround(0.0);
      if ($502) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$6+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $503 = Math_fround($492 * $495);
       $504 = Math_fround(-$503);
       $505 = Math_fround($491 * $494);
       $506 = Math_fround($504 - $505);
       $507 = Math_fround($493 * $496);
       $508 = Math_fround($506 - $507);
       $509 = Math_fround(HEAPF32[$A>>2]);
       $510 = Math_fround(HEAPF32[$279>>2]);
       $511 = Math_fround(HEAPF32[$280>>2]);
       $512 = Math_fround($408 - $509);
       $513 = Math_fround($409 - $510);
       $514 = Math_fround($410 - $511);
       $515 = Math_fround(HEAPF32[$B>>2]);
       $516 = Math_fround(HEAPF32[$281>>2]);
       $517 = Math_fround(HEAPF32[$282>>2]);
       $518 = Math_fround($411 - $515);
       $519 = Math_fround($412 - $516);
       $520 = Math_fround($413 - $517);
       $521 = Math_fround($508 / $501);
       $522 = $521 > Math_fround(1.0);
       $$$i$i$i = $522 ? Math_fround(1.0) : $521;
       $523 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $523 ? $$$i$i$i : Math_fround(0.0);
       $524 = Math_fround($512 * $$$i8$i$i);
       $525 = Math_fround($513 * $$$i8$i$i);
       $526 = Math_fround($514 * $$$i8$i$i);
       $527 = Math_fround($509 + $524);
       $528 = Math_fround($510 + $525);
       $529 = Math_fround($511 + $526);
       $530 = Math_fround($518 * $$$i8$i$i);
       $531 = Math_fround($519 * $$$i8$i$i);
       $532 = Math_fround($520 * $$$i8$i$i);
       $533 = Math_fround($515 + $530);
       $534 = Math_fround($516 + $531);
       $535 = Math_fround($517 + $532);
       HEAPF32[$closA>>2] = $527;
       HEAPF32[$19>>2] = $528;
       HEAPF32[$20>>2] = $529;
       HEAPF32[$21>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $533;
       HEAPF32[$22>>2] = $534;
       HEAPF32[$23>>2] = $535;
       HEAPF32[$24>>2] = Math_fround(0.0);
       $536 = Math_fround($527 - $533);
       $537 = Math_fround($528 - $534);
       $538 = Math_fround($529 - $535);
       HEAPF32[$6>>2] = $536;
       HEAPF32[$283>>2] = $537;
       HEAPF32[$284>>2] = $538;
       HEAPF32[$285>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($417|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($6,$Q,$286,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$6+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$6+12>>2]|0;
    $539 = Math_fround(HEAPF32[$v>>2]);
    $540 = Math_fround(HEAPF32[$241>>2]);
    $541 = Math_fround(HEAPF32[$242>>2]);
    $542 = Math_fround($539 * $539);
    $543 = Math_fround($540 * $540);
    $544 = Math_fround($542 + $543);
    $545 = Math_fround($541 * $541);
    $546 = Math_fround($544 + $545);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1238+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1238+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1238+8>>2]|0;
    $547 = $427 > $546;
    $548 = $546 > $25;
    if (!($548)) {
     label = 43;
     break;
    }
    if (!($547)) {
     label = 43;
     break;
    }
    $$pre849 = Math_fround(HEAPF32[$closA>>2]);
    $$pre850 = Math_fround(HEAPF32[$19>>2]);
    $$pre851 = Math_fround(HEAPF32[$20>>2]);
    $$pre852 = Math_fround(HEAPF32[$21>>2]);
    $$pre853 = Math_fround(HEAPF32[$closB>>2]);
    $$pre854 = Math_fround(HEAPF32[$22>>2]);
    $$pre855 = Math_fround(HEAPF32[$23>>2]);
    $$pre856 = Math_fround(HEAPF32[$24>>2]);
    $$$i745809 = $$$i;$288 = $539;$290 = $540;$292 = $541;$427 = $546;$563 = $$pre849;$564 = $$pre850;$565 = $$pre851;$566 = $$pre852;$567 = $$pre853;$568 = $$pre854;$569 = $$pre855;$570 = $$pre856;
   }
   if ((label|0) == 43) {
    $549 = HEAP32[$size>>2]|0;
    if ($547) {
     $607 = $549;
     break;
    }
    $550 = (($549) + -1)|0;
    $551 = ($aIndices|0)==(0|0);
    if (!($551)) {
     $552 = $550&255;
     HEAP8[$_size>>0] = $552;
     $553 = ($550|0)==(0);
     if (!($553)) {
      $i$01$i29 = 0;
      while(1) {
       $554 = (($aInd) + ($i$01$i29<<2)|0);
       $555 = HEAP32[$554>>2]|0;
       $556 = $555&255;
       $557 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$557>>0] = $556;
       $558 = (($bInd) + ($i$01$i29<<2)|0);
       $559 = HEAP32[$558>>2]|0;
       $560 = $559&255;
       $561 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$561>>0] = $560;
       $562 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($562|0)==($550|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $562;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $563;
    HEAPF32[$19>>2] = $564;
    HEAPF32[$20>>2] = $565;
    HEAPF32[$21>>2] = $566;
    HEAPF32[$closB>>2] = $567;
    HEAPF32[$22>>2] = $568;
    HEAPF32[$23>>2] = $569;
    HEAPF32[$24>>2] = $570;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $571 = Math_fround($563 - $567);
    $572 = Math_fround($564 - $568);
    $573 = Math_fround($565 - $569);
    HEAPF32[$v>>2] = $571;
    $574 = (($v) + 4|0);
    HEAPF32[$574>>2] = $572;
    $575 = (($v) + 8|0);
    HEAPF32[$575>>2] = $573;
    $576 = (($v) + 12|0);
    HEAPF32[$576>>2] = Math_fround(0.0);
    $577 = (Math_fround(Math_sqrt((Math_fround($427)))));
    $578 = Math_fround(Math_fround(1.0) / $577);
    $579 = Math_fround($571 * $578);
    $580 = Math_fround($572 * $578);
    $581 = Math_fround($573 * $578);
    $582 = Math_fround($8 * $579);
    $583 = Math_fround($8 * $580);
    $584 = Math_fround($8 * $581);
    $585 = Math_fround($563 - $582);
    $586 = Math_fround($564 - $583);
    $587 = Math_fround($565 - $584);
    HEAPF32[$contactA>>2] = $585;
    $588 = (($contactA) + 4|0);
    HEAPF32[$588>>2] = $586;
    $589 = (($contactA) + 8|0);
    HEAPF32[$589>>2] = $587;
    $590 = (($contactA) + 12|0);
    HEAPF32[$590>>2] = Math_fround(0.0);
    $591 = Math_fround($10 * $579);
    $592 = Math_fround($10 * $580);
    $593 = Math_fround($10 * $581);
    $594 = Math_fround($591 + $567);
    $595 = Math_fround($592 + $568);
    $596 = Math_fround($593 + $569);
    HEAPF32[$contactB>>2] = $594;
    $597 = (($contactB) + 4|0);
    HEAPF32[$597>>2] = $595;
    $598 = (($contactB) + 8|0);
    HEAPF32[$598>>2] = $596;
    $599 = (($contactB) + 12|0);
    HEAPF32[$599>>2] = Math_fround(0.0);
    $600 = Math_fround($577 - $18);
    HEAPF32[$penetrationDepth>>2] = $600;
    $601 = (($penetrationDepth) + 4|0);
    ;HEAP32[$601+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$601+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$601+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $579;
    $602 = (($normal) + 4|0);
    HEAPF32[$602>>2] = $580;
    $603 = (($normal) + 8|0);
    HEAPF32[$603>>2] = $581;
    $604 = (($normal) + 12|0);
    HEAPF32[$604>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $445 = ($aIndices|0)==(0|0);
   if (!($445)) {
    $446 = $417&255;
    HEAP8[$_size>>0] = $446;
    $447 = ($417|0)==(0);
    if (!($447)) {
     $i$01$i72 = 0;
     while(1) {
      $448 = (($aInd) + ($i$01$i72<<2)|0);
      $449 = HEAP32[$448>>2]|0;
      $450 = $449&255;
      $451 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$451>>0] = $450;
      $452 = (($bInd) + ($i$01$i72<<2)|0);
      $453 = HEAP32[$452>>2]|0;
      $454 = $453&255;
      $455 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$455>>0] = $454;
      $456 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($456|0)==($417|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $456;
      }
     }
    }
   }
   $not$ = $442 ^ 1;
   $$$757 = $444 & $not$;
   if (!($$$757)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $457 = (Math_fround(Math_sqrt((Math_fround($427)))));
   $458 = Math_fround(Math_fround(1.0) / $457);
   $459 = Math_fround($428 * $458);
   $460 = Math_fround($429 * $458);
   $461 = Math_fround($430 * $458);
   $462 = Math_fround(HEAPF32[$closA>>2]);
   $463 = Math_fround(HEAPF32[$19>>2]);
   $464 = Math_fround(HEAPF32[$20>>2]);
   $465 = Math_fround($8 * $459);
   $466 = Math_fround($8 * $460);
   $467 = Math_fround($8 * $461);
   $468 = Math_fround($462 - $465);
   $469 = Math_fround($463 - $466);
   $470 = Math_fround($464 - $467);
   HEAPF32[$contactA>>2] = $468;
   $471 = (($contactA) + 4|0);
   HEAPF32[$471>>2] = $469;
   $472 = (($contactA) + 8|0);
   HEAPF32[$472>>2] = $470;
   $473 = (($contactA) + 12|0);
   HEAPF32[$473>>2] = Math_fround(0.0);
   $474 = Math_fround(HEAPF32[$closB>>2]);
   $475 = Math_fround(HEAPF32[$22>>2]);
   $476 = Math_fround(HEAPF32[$23>>2]);
   $477 = Math_fround($10 * $459);
   $478 = Math_fround($10 * $460);
   $479 = Math_fround($10 * $461);
   $480 = Math_fround($477 + $474);
   $481 = Math_fround($478 + $475);
   $482 = Math_fround($479 + $476);
   HEAPF32[$contactB>>2] = $480;
   $483 = (($contactB) + 4|0);
   HEAPF32[$483>>2] = $481;
   $484 = (($contactB) + 8|0);
   HEAPF32[$484>>2] = $482;
   $485 = (($contactB) + 12|0);
   HEAPF32[$485>>2] = Math_fround(0.0);
   $486 = Math_fround($457 - $18);
   HEAPF32[$penetrationDepth>>2] = $486;
   $487 = (($penetrationDepth) + 4|0);
   ;HEAP32[$487+0>>2]=HEAP32[$$sroa$1240+0>>2]|0;HEAP32[$487+4>>2]=HEAP32[$$sroa$1240+4>>2]|0;HEAP32[$487+8>>2]=HEAP32[$$sroa$1240+8>>2]|0;
   HEAPF32[$normal>>2] = $459;
   $488 = (($normal) + 4|0);
   HEAPF32[$488>>2] = $460;
   $489 = (($normal) + 8|0);
   HEAPF32[$489>>2] = $461;
   $490 = (($normal) + 12|0);
   HEAPF32[$490>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $240 = HEAP32[$size>>2]|0;
   $607 = $240;
  }
 } while(0);
 $605 = ($aIndices|0)==(0|0);
 if (!($605)) {
  $606 = $607&255;
  HEAP8[$_size>>0] = $606;
  $608 = ($607|0)==(0);
  if (!($608)) {
   $i$01$i = 0;
   while(1) {
    $609 = (($aInd) + ($i$01$i<<2)|0);
    $610 = HEAP32[$609>>2]|0;
    $611 = $610&255;
    $612 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$612>>0] = $611;
    $613 = (($bInd) + ($i$01$i<<2)|0);
    $614 = HEAP32[$613>>2]|0;
    $615 = $614&255;
    $616 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$616>>0] = $615;
    $617 = (($i$01$i) + 1)|0;
    $exitcond$i = ($617|0)==($607|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $617;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_17ShrunkConvexHullVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$747 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i170 = Math_fround(0), $$$i134 = Math_fround(0), $$$i169 = Math_fround(0), $$$i735799 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i171 = Math_fround(0), $$0 = 0, $$743 = 0, $$in1$i = 0, $$in2$i = 0, $$ph = Math_fround(0), $$ph755 = Math_fround(0), $$ph756 = Math_fround(0), $$ph757 = Math_fround(0), $$ph758 = Math_fround(0), $$ph759 = Math_fround(0), $$ph760 = Math_fround(0);
 var $$ph761 = Math_fround(0), $$ph763 = Math_fround(0), $$ph764 = 0, $$pre = Math_fround(0), $$pre838 = Math_fround(0), $$pre839 = Math_fround(0), $$pre840 = Math_fround(0), $$pre841 = Math_fround(0), $$pre842 = Math_fround(0), $$pre843 = Math_fround(0), $$pre844 = Math_fround(0), $$sroa$1 = 0, $$sroa$1232 = 0, $$sroa$1234 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0);
 var $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0);
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0);
 var $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0);
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0);
 var $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = 0;
 var $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0);
 var $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0);
 var $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0);
 var $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0);
 var $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0);
 var $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0);
 var $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0;
 var $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = 0, $513 = 0, $514 = Math_fround(0), $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_dir$i = 0, $aInd = 0, $b$a$i = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0;
 var $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$0809 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $p$i = 0, $phitmp751 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $v = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $0 = sp + 400|0;
 $1 = sp + 336|0;
 $_dir$i = sp + 352|0;
 $p$i = sp + 368|0;
 $closA = sp + 384|0;
 $closB = sp + 416|0;
 $sDist$sroa$1 = sp + 548|0;
 $minDist$sroa$1 = sp + 536|0;
 $v = sp + 448|0;
 $Q = sp + 272|0;
 $A = sp + 112|0;
 $B = sp;
 $aInd = sp + 520|0;
 $bInd = sp + 504|0;
 $size = sp + 560|0;
 $lastQ = sp + 80|0;
 $lastA = sp + 96|0;
 $lastB = sp + 176|0;
 $2 = sp + 192|0;
 $3 = sp + 208|0;
 $4 = sp + 224|0;
 $supportA1 = sp + 240|0;
 $supportB2 = sp + 256|0;
 $support3 = sp + 64|0;
 $$sroa$1234 = sp + 476|0;
 $5 = sp + 432|0;
 $$sroa$1232 = sp + 488|0;
 $$sroa$1 = sp + 464|0;
 $6 = (($a) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($b) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$_contactDist>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i169 = $15 ? $14 : $12;
 $16 = Math_fround($$$i169 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($7 + $9);
 $18 = (($closA) + 4|0);
 $19 = (($closA) + 8|0);
 $20 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $21 = (($closB) + 4|0);
 $22 = (($closB) + 8|0);
 $23 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $24 = Math_fround($16 * $16);
 HEAP32[$size>>2] = 0;
 $25 = HEAP8[$_size>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $188 = (($aToB) + 48|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = (($aToB) + 52|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = (($aToB) + 56|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($aToB) + 60|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($189 * $189);
  $197 = Math_fround($191 * $191);
  $198 = Math_fround($196 + $197);
  $199 = Math_fround($193 * $193);
  $200 = Math_fround($198 + $199);
  $201 = $200 > Math_fround(0.0);
  HEAPF32[$1>>2] = $189;
  $202 = (($1) + 4|0);
  HEAPF32[$202>>2] = $191;
  $203 = (($1) + 8|0);
  HEAPF32[$203>>2] = $193;
  $204 = (($1) + 12|0);
  HEAPF32[$204>>2] = $195;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $205 = (($0) + 4|0);
  HEAPF32[$205>>2] = Math_fround(0.0);
  $206 = (($0) + 8|0);
  HEAPF32[$206>>2] = Math_fround(0.0);
  $207 = (($0) + 12|0);
  HEAPF32[$207>>2] = Math_fround(0.0);
  $b$a$i = $201 ? $1 : $0;
  $208 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $209 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $210 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $208;
  $211 = (($v) + 4|0);
  HEAPF32[$211>>2] = $209;
  $212 = (($v) + 8|0);
  HEAPF32[$212>>2] = $210;
  $213 = (($v) + 12|0);
  HEAPF32[$213>>2] = Math_fround(0.0);
  $$ph = Math_fround(0.0);$$ph755 = Math_fround(0.0);$$ph756 = Math_fround(0.0);$$ph757 = Math_fround(0.0);$$ph758 = Math_fround(0.0);$$ph759 = Math_fround(0.0);$$ph760 = Math_fround(0.0);$$ph761 = Math_fround(0.0);$$ph763 = Math_fround(3.40282346638528859812E+38);$$ph764 = 1;$532 = $210;$533 = $209;$534 = $208;
 } else {
  $27 = (($lastQ) + 4|0);
  $28 = (($lastQ) + 8|0);
  $29 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $30 = (($lastA) + 4|0);
  $31 = (($lastA) + 8|0);
  $32 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $33 = (($lastB) + 4|0);
  $34 = (($lastB) + 8|0);
  $35 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $36 = (($a) + 16|0);
  $37 = (($aToB) + 48|0);
  $38 = (($aToB) + 52|0);
  $39 = (($aToB) + 56|0);
  $40 = (($2) + 4|0);
  $41 = (($2) + 8|0);
  $42 = (($aToB) + 16|0);
  $43 = (($aToB) + 32|0);
  $44 = (($aToB) + 4|0);
  $45 = (($aToB) + 20|0);
  $46 = (($aToB) + 36|0);
  $47 = (($aToB) + 8|0);
  $48 = (($aToB) + 24|0);
  $49 = (($aToB) + 40|0);
  $50 = (($b) + 16|0);
  $51 = (($3) + 4|0);
  $52 = (($3) + 8|0);
  $53 = (($3) + 12|0);
  $i$0809 = 0;
  while(1) {
   $54 = (($aIndices) + ($i$0809)|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55&255;
   $57 = (($aInd) + ($i$0809<<2)|0);
   HEAP32[$57>>2] = $56;
   $58 = (($bIndices) + ($i$0809)|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = $59&255;
   $61 = (($bInd) + ($i$0809<<2)|0);
   HEAP32[$61>>2] = $60;
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($2,$a,$56,$36);
   $62 = Math_fround(HEAPF32[$37>>2]);
   $63 = Math_fround(HEAPF32[$38>>2]);
   $64 = Math_fround(HEAPF32[$39>>2]);
   $65 = Math_fround(HEAPF32[$2>>2]);
   $66 = Math_fround(HEAPF32[$40>>2]);
   $67 = Math_fround(HEAPF32[$41>>2]);
   $68 = Math_fround(HEAPF32[$aToB>>2]);
   $69 = Math_fround($65 * $68);
   $70 = Math_fround(HEAPF32[$42>>2]);
   $71 = Math_fround($66 * $70);
   $72 = Math_fround($69 + $71);
   $73 = Math_fround(HEAPF32[$43>>2]);
   $74 = Math_fround($67 * $73);
   $75 = Math_fround($72 + $74);
   $76 = Math_fround(HEAPF32[$44>>2]);
   $77 = Math_fround($65 * $76);
   $78 = Math_fround(HEAPF32[$45>>2]);
   $79 = Math_fround($66 * $78);
   $80 = Math_fround($77 + $79);
   $81 = Math_fround(HEAPF32[$46>>2]);
   $82 = Math_fround($67 * $81);
   $83 = Math_fround($80 + $82);
   $84 = Math_fround(HEAPF32[$47>>2]);
   $85 = Math_fround($65 * $84);
   $86 = Math_fround(HEAPF32[$48>>2]);
   $87 = Math_fround($66 * $86);
   $88 = Math_fround($85 + $87);
   $89 = Math_fround(HEAPF32[$49>>2]);
   $90 = Math_fround($67 * $89);
   $91 = Math_fround($88 + $90);
   $92 = Math_fround($62 + $75);
   $93 = Math_fround($63 + $83);
   $94 = Math_fround($64 + $91);
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($3,$b,$60,$50);
   $95 = Math_fround(HEAPF32[$3>>2]);
   $96 = Math_fround(HEAPF32[$51>>2]);
   $97 = Math_fround(HEAPF32[$52>>2]);
   $98 = Math_fround(HEAPF32[$53>>2]);
   $99 = Math_fround($92 - $95);
   $100 = Math_fround($93 - $96);
   $101 = Math_fround($94 - $97);
   $102 = HEAP32[$size>>2]|0;
   $103 = (($A) + ($102<<4)|0);
   HEAPF32[$lastA>>2] = $92;
   HEAPF32[$30>>2] = $93;
   HEAPF32[$31>>2] = $94;
   HEAPF32[$32>>2] = Math_fround(0.0);
   ;HEAP32[$103+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$lastA+12>>2]|0;
   $104 = (($B) + ($102<<4)|0);
   HEAPF32[$lastB>>2] = $95;
   HEAPF32[$33>>2] = $96;
   HEAPF32[$34>>2] = $97;
   HEAPF32[$35>>2] = $98;
   ;HEAP32[$104+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$104+12>>2]=HEAP32[$lastB+12>>2]|0;
   $105 = (($102) + 1)|0;
   HEAP32[$size>>2] = $105;
   $106 = (($Q) + ($102<<4)|0);
   HEAPF32[$lastQ>>2] = $99;
   HEAPF32[$27>>2] = $100;
   HEAPF32[$28>>2] = $101;
   HEAPF32[$29>>2] = Math_fround(0.0);
   ;HEAP32[$106+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $107 = (($i$0809) + 1)|0;
   $108 = HEAP8[$_size>>0]|0;
   $109 = $108&255;
   $110 = ($107>>>0)<($109>>>0);
   if ($110) {
    $i$0809 = $107;
   } else {
    break;
   }
  }
  do {
   if ((($102|0) == 1)) {
    $111 = Math_fround(HEAPF32[$Q>>2]);
    $112 = (($Q) + 4|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = (($Q) + 8|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = Math_fround($99 - $111);
    $117 = Math_fround($100 - $113);
    $118 = Math_fround($101 - $115);
    $119 = Math_fround($116 * $116);
    $120 = Math_fround($117 * $117);
    $121 = Math_fround($119 + $120);
    $122 = Math_fround($118 * $118);
    $123 = Math_fround($121 + $122);
    $124 = $123 == Math_fround(0.0);
    if ($124) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $125 = Math_fround($113 * $117);
     $126 = Math_fround(-$125);
     $127 = Math_fround($111 * $116);
     $128 = Math_fround($126 - $127);
     $129 = Math_fround($115 * $118);
     $130 = Math_fround($128 - $129);
     $131 = Math_fround(HEAPF32[$A>>2]);
     $132 = (($A) + 4|0);
     $133 = Math_fround(HEAPF32[$132>>2]);
     $134 = (($A) + 8|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     $136 = Math_fround($92 - $131);
     $137 = Math_fround($93 - $133);
     $138 = Math_fround($94 - $135);
     $139 = Math_fround(HEAPF32[$B>>2]);
     $140 = (($B) + 4|0);
     $141 = Math_fround(HEAPF32[$140>>2]);
     $142 = (($B) + 8|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = Math_fround($95 - $139);
     $145 = Math_fround($96 - $141);
     $146 = Math_fround($97 - $143);
     $147 = Math_fround($130 / $123);
     $148 = $147 > Math_fround(1.0);
     $$$i$i$i170 = $148 ? Math_fround(1.0) : $147;
     $149 = $$$i$i$i170 > Math_fround(0.0);
     $$$i8$i$i171 = $149 ? $$$i$i$i170 : Math_fround(0.0);
     $150 = Math_fround($136 * $$$i8$i$i171);
     $151 = Math_fround($137 * $$$i8$i$i171);
     $152 = Math_fround($138 * $$$i8$i$i171);
     $153 = Math_fround($131 + $150);
     $154 = Math_fround($133 + $151);
     $155 = Math_fround($135 + $152);
     $156 = Math_fround($144 * $$$i8$i$i171);
     $157 = Math_fround($145 * $$$i8$i$i171);
     $158 = Math_fround($146 * $$$i8$i$i171);
     $159 = Math_fround($139 + $156);
     $160 = Math_fround($141 + $157);
     $161 = Math_fround($143 + $158);
     HEAPF32[$closA>>2] = $153;
     HEAPF32[$18>>2] = $154;
     HEAPF32[$19>>2] = $155;
     HEAPF32[$20>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $159;
     HEAPF32[$21>>2] = $160;
     HEAPF32[$22>>2] = $161;
     HEAPF32[$23>>2] = Math_fround(0.0);
     $162 = Math_fround($153 - $159);
     $163 = Math_fround($154 - $160);
     $164 = Math_fround($155 - $161);
     HEAPF32[$4>>2] = $162;
     $165 = (($4) + 4|0);
     HEAPF32[$165>>2] = $163;
     $166 = (($4) + 8|0);
     HEAPF32[$166>>2] = $164;
     $167 = (($4) + 12|0);
     HEAPF32[$167>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($102|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($102|0) == 2)) {
    $168 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$168,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($102|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$4+12>>2]|0;
  $169 = Math_fround(HEAPF32[$v>>2]);
  $170 = (($v) + 4|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = (($v) + 8|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($169 * $169);
  $175 = Math_fround($171 * $171);
  $176 = Math_fround($174 + $175);
  $177 = Math_fround($173 * $173);
  $178 = Math_fround($176 + $177);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $179 = Math_fround(HEAPF32[$closA>>2]);
  $180 = Math_fround(HEAPF32[$18>>2]);
  $181 = Math_fround(HEAPF32[$19>>2]);
  $182 = Math_fround(HEAPF32[$20>>2]);
  $183 = Math_fround(HEAPF32[$closB>>2]);
  $184 = Math_fround(HEAPF32[$21>>2]);
  $185 = Math_fround(HEAPF32[$22>>2]);
  $186 = Math_fround(HEAPF32[$23>>2]);
  $187 = $178 > $24;
  $$ph = $182;$$ph755 = $181;$$ph756 = $180;$$ph757 = $179;$$ph758 = $186;$$ph759 = $185;$$ph760 = $184;$$ph761 = $183;$$ph763 = $178;$$ph764 = $187;$532 = $173;$533 = $171;$534 = $169;
 }
 do {
  if ($$ph764) {
   $215 = (($v) + 4|0);
   $216 = (($v) + 8|0);
   $217 = (($aToB) + 4|0);
   $218 = (($aToB) + 8|0);
   $219 = (($aToB) + 16|0);
   $220 = (($aToB) + 20|0);
   $221 = (($aToB) + 24|0);
   $222 = (($aToB) + 32|0);
   $223 = (($aToB) + 36|0);
   $224 = (($aToB) + 40|0);
   $225 = (($_dir$i) + 4|0);
   $226 = (($_dir$i) + 8|0);
   $227 = (($_dir$i) + 12|0);
   $228 = (($aToB) + 48|0);
   $229 = (($aToB) + 52|0);
   $230 = (($aToB) + 56|0);
   $231 = (($p$i) + 4|0);
   $232 = (($p$i) + 8|0);
   $233 = (($supportA1) + 4|0);
   $234 = (($supportA1) + 8|0);
   $235 = (($supportA1) + 12|0);
   $236 = (($supportB2) + 4|0);
   $237 = (($supportB2) + 8|0);
   $238 = (($support3) + 4|0);
   $239 = (($support3) + 8|0);
   $240 = (($support3) + 12|0);
   $241 = (($a) + 48|0);
   $242 = (($b) + 48|0);
   $243 = (($Q) + 4|0);
   $244 = (($Q) + 8|0);
   $245 = (($A) + 4|0);
   $246 = (($A) + 8|0);
   $247 = (($B) + 4|0);
   $248 = (($B) + 8|0);
   $249 = (($5) + 4|0);
   $250 = (($5) + 8|0);
   $251 = (($5) + 12|0);
   $252 = (($Q) + 16|0);
   $$$i735799 = $10;$254 = $534;$256 = $533;$258 = $532;$341 = $$ph763;$477 = $$ph757;$478 = $$ph756;$479 = $$ph755;$480 = $$ph;$481 = $$ph761;$482 = $$ph760;$483 = $$ph759;$484 = $$ph758;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $253 = Math_fround(-$254);
    $255 = Math_fround(-$256);
    $257 = Math_fround(-$258);
    $259 = HEAP32[$size>>2]|0;
    $260 = (($A) + ($259<<4)|0);
    $261 = (($aInd) + ($259<<2)|0);
    $262 = Math_fround(HEAPF32[$aToB>>2]);
    $263 = Math_fround($262 * $253);
    $264 = Math_fround(HEAPF32[$217>>2]);
    $265 = Math_fround($264 * $255);
    $266 = Math_fround($263 + $265);
    $267 = Math_fround(HEAPF32[$218>>2]);
    $268 = Math_fround($267 * $257);
    $269 = Math_fround($266 + $268);
    $270 = Math_fround(HEAPF32[$219>>2]);
    $271 = Math_fround($270 * $253);
    $272 = Math_fround(HEAPF32[$220>>2]);
    $273 = Math_fround($272 * $255);
    $274 = Math_fround($271 + $273);
    $275 = Math_fround(HEAPF32[$221>>2]);
    $276 = Math_fround($275 * $257);
    $277 = Math_fround($274 + $276);
    $278 = Math_fround(HEAPF32[$222>>2]);
    $279 = Math_fround($278 * $253);
    $280 = Math_fround(HEAPF32[$223>>2]);
    $281 = Math_fround($280 * $255);
    $282 = Math_fround($279 + $281);
    $283 = Math_fround(HEAPF32[$224>>2]);
    $284 = Math_fround($283 * $257);
    $285 = Math_fround($282 + $284);
    HEAPF32[$_dir$i>>2] = $269;
    HEAPF32[$225>>2] = $277;
    HEAPF32[$226>>2] = $285;
    HEAPF32[$227>>2] = Math_fround(0.0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($p$i,$a,$_dir$i,$260,$261);
    $286 = Math_fround(HEAPF32[$228>>2]);
    $287 = Math_fround(HEAPF32[$229>>2]);
    $288 = Math_fround(HEAPF32[$230>>2]);
    $289 = Math_fround(HEAPF32[$p$i>>2]);
    $290 = Math_fround(HEAPF32[$231>>2]);
    $291 = Math_fround(HEAPF32[$232>>2]);
    $292 = Math_fround(HEAPF32[$aToB>>2]);
    $293 = Math_fround($289 * $292);
    $294 = Math_fround(HEAPF32[$219>>2]);
    $295 = Math_fround($290 * $294);
    $296 = Math_fround($293 + $295);
    $297 = Math_fround(HEAPF32[$222>>2]);
    $298 = Math_fround($291 * $297);
    $299 = Math_fround($296 + $298);
    $300 = Math_fround(HEAPF32[$217>>2]);
    $301 = Math_fround($289 * $300);
    $302 = Math_fround(HEAPF32[$220>>2]);
    $303 = Math_fround($290 * $302);
    $304 = Math_fround($301 + $303);
    $305 = Math_fround(HEAPF32[$223>>2]);
    $306 = Math_fround($291 * $305);
    $307 = Math_fround($304 + $306);
    $308 = Math_fround(HEAPF32[$218>>2]);
    $309 = Math_fround($289 * $308);
    $310 = Math_fround(HEAPF32[$221>>2]);
    $311 = Math_fround($290 * $310);
    $312 = Math_fround($309 + $311);
    $313 = Math_fround(HEAPF32[$224>>2]);
    $314 = Math_fround($291 * $313);
    $315 = Math_fround($312 + $314);
    $316 = Math_fround($286 + $299);
    $317 = Math_fround($287 + $307);
    $318 = Math_fround($288 + $315);
    HEAPF32[$supportA1>>2] = $316;
    HEAPF32[$233>>2] = $317;
    HEAPF32[$234>>2] = $318;
    HEAPF32[$235>>2] = Math_fround(0.0);
    ;HEAP32[$260+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$260+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$260+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$260+12>>2]=HEAP32[$supportA1+12>>2]|0;
    $319 = HEAP32[$size>>2]|0;
    $320 = (($B) + ($319<<4)|0);
    $321 = (($bInd) + ($319<<2)|0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($supportB2,$b,$v,$320,$321);
    $322 = Math_fround(HEAPF32[$supportA1>>2]);
    $323 = Math_fround(HEAPF32[$233>>2]);
    $324 = Math_fround(HEAPF32[$234>>2]);
    $325 = Math_fround(HEAPF32[$supportB2>>2]);
    $326 = Math_fround(HEAPF32[$236>>2]);
    $327 = Math_fround(HEAPF32[$237>>2]);
    $328 = Math_fround($322 - $325);
    $329 = Math_fround($323 - $326);
    $330 = Math_fround($324 - $327);
    HEAPF32[$support3>>2] = $328;
    HEAPF32[$238>>2] = $329;
    HEAPF32[$239>>2] = $330;
    HEAPF32[$240>>2] = Math_fround(0.0);
    $331 = HEAP32[$size>>2]|0;
    $332 = (($331) + 1)|0;
    HEAP32[$size>>2] = $332;
    $333 = (($Q) + ($331<<4)|0);
    ;HEAP32[$333+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$333+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$333+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$333+12>>2]=HEAP32[$support3+12>>2]|0;
    $334 = Math_fround(HEAPF32[$241>>2]);
    $335 = Math_fround(HEAPF32[$242>>2]);
    $336 = $334 > $335;
    $$$i134 = $336 ? $334 : $335;
    $337 = $$$i735799 > $$$i134;
    $$$i = $337 ? $$$i735799 : $$$i134;
    $338 = Math_fround($17 + $$$i);
    $339 = Math_fround($338 * $338);
    $340 = Math_fround($341 * $339);
    $342 = Math_fround(HEAPF32[$v>>2]);
    $343 = Math_fround(HEAPF32[$215>>2]);
    $344 = Math_fround(HEAPF32[$216>>2]);
    $345 = Math_fround($342 * $328);
    $346 = Math_fround($343 * $329);
    $347 = Math_fround($345 + $346);
    $348 = Math_fround($344 * $330);
    $349 = Math_fround($347 + $348);
    $350 = Math_fround($349 * $349);
    $351 = $349 > Math_fround(0.0);
    $352 = $350 > $340;
    if ($351) {
     $phitmp751 = $352 ^ 1;
     $356 = $352;$358 = $phitmp751;
    } else {
     $356 = 0;$358 = 1;
    }
    $353 = Math_fround($341 - $349);
    $354 = Math_fround($24 * $341);
    $355 = $354 >= $353;
    $brmerge$demorgan = $355 | $356;
    if ($brmerge$demorgan) {
     $357 = $358 ^ 1;
     $$743 = $355 | $357;
     if ($$743) {
      break;
     }
    }
    do {
     if ((($331|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$252,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($331|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($331|0) == 1)) {
      $405 = Math_fround(HEAPF32[$Q>>2]);
      $406 = Math_fround(HEAPF32[$243>>2]);
      $407 = Math_fround(HEAPF32[$244>>2]);
      $408 = Math_fround($328 - $405);
      $409 = Math_fround($329 - $406);
      $410 = Math_fround($330 - $407);
      $411 = Math_fround($408 * $408);
      $412 = Math_fround($409 * $409);
      $413 = Math_fround($411 + $412);
      $414 = Math_fround($410 * $410);
      $415 = Math_fround($413 + $414);
      $416 = $415 == Math_fround(0.0);
      if ($416) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $417 = Math_fround($406 * $409);
       $418 = Math_fround(-$417);
       $419 = Math_fround($405 * $408);
       $420 = Math_fround($418 - $419);
       $421 = Math_fround($407 * $410);
       $422 = Math_fround($420 - $421);
       $423 = Math_fround(HEAPF32[$A>>2]);
       $424 = Math_fround(HEAPF32[$245>>2]);
       $425 = Math_fround(HEAPF32[$246>>2]);
       $426 = Math_fround($322 - $423);
       $427 = Math_fround($323 - $424);
       $428 = Math_fround($324 - $425);
       $429 = Math_fround(HEAPF32[$B>>2]);
       $430 = Math_fround(HEAPF32[$247>>2]);
       $431 = Math_fround(HEAPF32[$248>>2]);
       $432 = Math_fround($325 - $429);
       $433 = Math_fround($326 - $430);
       $434 = Math_fround($327 - $431);
       $435 = Math_fround($422 / $415);
       $436 = $435 > Math_fround(1.0);
       $$$i$i$i = $436 ? Math_fround(1.0) : $435;
       $437 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $437 ? $$$i$i$i : Math_fround(0.0);
       $438 = Math_fround($426 * $$$i8$i$i);
       $439 = Math_fround($427 * $$$i8$i$i);
       $440 = Math_fround($428 * $$$i8$i$i);
       $441 = Math_fround($423 + $438);
       $442 = Math_fround($424 + $439);
       $443 = Math_fround($425 + $440);
       $444 = Math_fround($432 * $$$i8$i$i);
       $445 = Math_fround($433 * $$$i8$i$i);
       $446 = Math_fround($434 * $$$i8$i$i);
       $447 = Math_fround($429 + $444);
       $448 = Math_fround($430 + $445);
       $449 = Math_fround($431 + $446);
       HEAPF32[$closA>>2] = $441;
       HEAPF32[$18>>2] = $442;
       HEAPF32[$19>>2] = $443;
       HEAPF32[$20>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $447;
       HEAPF32[$21>>2] = $448;
       HEAPF32[$22>>2] = $449;
       HEAPF32[$23>>2] = Math_fround(0.0);
       $450 = Math_fround($441 - $447);
       $451 = Math_fround($442 - $448);
       $452 = Math_fround($443 - $449);
       HEAPF32[$5>>2] = $450;
       HEAPF32[$249>>2] = $451;
       HEAPF32[$250>>2] = $452;
       HEAPF32[$251>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($331|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
    $453 = Math_fround(HEAPF32[$v>>2]);
    $454 = Math_fround(HEAPF32[$215>>2]);
    $455 = Math_fround(HEAPF32[$216>>2]);
    $456 = Math_fround($453 * $453);
    $457 = Math_fround($454 * $454);
    $458 = Math_fround($456 + $457);
    $459 = Math_fround($455 * $455);
    $460 = Math_fround($458 + $459);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1232+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1232+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1232+8>>2]|0;
    $461 = $341 > $460;
    $462 = $460 > $24;
    if (!($462)) {
     label = 37;
     break;
    }
    if (!($461)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre838 = Math_fround(HEAPF32[$18>>2]);
    $$pre839 = Math_fround(HEAPF32[$19>>2]);
    $$pre840 = Math_fround(HEAPF32[$20>>2]);
    $$pre841 = Math_fround(HEAPF32[$closB>>2]);
    $$pre842 = Math_fround(HEAPF32[$21>>2]);
    $$pre843 = Math_fround(HEAPF32[$22>>2]);
    $$pre844 = Math_fround(HEAPF32[$23>>2]);
    $$$i735799 = $$$i;$254 = $453;$256 = $454;$258 = $455;$341 = $460;$477 = $$pre;$478 = $$pre838;$479 = $$pre839;$480 = $$pre840;$481 = $$pre841;$482 = $$pre842;$483 = $$pre843;$484 = $$pre844;
   }
   if ((label|0) == 37) {
    $463 = HEAP32[$size>>2]|0;
    if ($461) {
     $521 = $463;
     break;
    }
    $464 = (($463) + -1)|0;
    $465 = ($aIndices|0)==(0|0);
    if (!($465)) {
     $466 = $464&255;
     HEAP8[$_size>>0] = $466;
     $467 = ($464|0)==(0);
     if (!($467)) {
      $i$01$i29 = 0;
      while(1) {
       $468 = (($aInd) + ($i$01$i29<<2)|0);
       $469 = HEAP32[$468>>2]|0;
       $470 = $469&255;
       $471 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$471>>0] = $470;
       $472 = (($bInd) + ($i$01$i29<<2)|0);
       $473 = HEAP32[$472>>2]|0;
       $474 = $473&255;
       $475 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$475>>0] = $474;
       $476 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($476|0)==($464|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $476;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $477;
    HEAPF32[$18>>2] = $478;
    HEAPF32[$19>>2] = $479;
    HEAPF32[$20>>2] = $480;
    HEAPF32[$closB>>2] = $481;
    HEAPF32[$21>>2] = $482;
    HEAPF32[$22>>2] = $483;
    HEAPF32[$23>>2] = $484;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $485 = Math_fround($477 - $481);
    $486 = Math_fround($478 - $482);
    $487 = Math_fround($479 - $483);
    HEAPF32[$v>>2] = $485;
    $488 = (($v) + 4|0);
    HEAPF32[$488>>2] = $486;
    $489 = (($v) + 8|0);
    HEAPF32[$489>>2] = $487;
    $490 = (($v) + 12|0);
    HEAPF32[$490>>2] = Math_fround(0.0);
    $491 = (Math_fround(Math_sqrt((Math_fround($341)))));
    $492 = Math_fround(Math_fround(1.0) / $491);
    $493 = Math_fround($485 * $492);
    $494 = Math_fround($486 * $492);
    $495 = Math_fround($487 * $492);
    $496 = Math_fround($7 * $493);
    $497 = Math_fround($7 * $494);
    $498 = Math_fround($7 * $495);
    $499 = Math_fround($477 - $496);
    $500 = Math_fround($478 - $497);
    $501 = Math_fround($479 - $498);
    HEAPF32[$contactA>>2] = $499;
    $502 = (($contactA) + 4|0);
    HEAPF32[$502>>2] = $500;
    $503 = (($contactA) + 8|0);
    HEAPF32[$503>>2] = $501;
    $504 = (($contactA) + 12|0);
    HEAPF32[$504>>2] = Math_fround(0.0);
    $505 = Math_fround($9 * $493);
    $506 = Math_fround($9 * $494);
    $507 = Math_fround($9 * $495);
    $508 = Math_fround($505 + $481);
    $509 = Math_fround($506 + $482);
    $510 = Math_fround($507 + $483);
    HEAPF32[$contactB>>2] = $508;
    $511 = (($contactB) + 4|0);
    HEAPF32[$511>>2] = $509;
    $512 = (($contactB) + 8|0);
    HEAPF32[$512>>2] = $510;
    $513 = (($contactB) + 12|0);
    HEAPF32[$513>>2] = Math_fround(0.0);
    $514 = Math_fround($491 - $17);
    HEAPF32[$penetrationDepth>>2] = $514;
    $515 = (($penetrationDepth) + 4|0);
    ;HEAP32[$515+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$515+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$515+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $493;
    $516 = (($normal) + 4|0);
    HEAPF32[$516>>2] = $494;
    $517 = (($normal) + 8|0);
    HEAPF32[$517>>2] = $495;
    $518 = (($normal) + 12|0);
    HEAPF32[$518>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $359 = ($aIndices|0)==(0|0);
   if (!($359)) {
    $360 = $331&255;
    HEAP8[$_size>>0] = $360;
    $361 = ($331|0)==(0);
    if (!($361)) {
     $i$01$i72 = 0;
     while(1) {
      $362 = (($aInd) + ($i$01$i72<<2)|0);
      $363 = HEAP32[$362>>2]|0;
      $364 = $363&255;
      $365 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$365>>0] = $364;
      $366 = (($bInd) + ($i$01$i72<<2)|0);
      $367 = HEAP32[$366>>2]|0;
      $368 = $367&255;
      $369 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$369>>0] = $368;
      $370 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($370|0)==($331|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $370;
      }
     }
    }
   }
   $not$ = $356 ^ 1;
   $$$747 = $358 & $not$;
   if (!($$$747)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $371 = (Math_fround(Math_sqrt((Math_fround($341)))));
   $372 = Math_fround(Math_fround(1.0) / $371);
   $373 = Math_fround($342 * $372);
   $374 = Math_fround($343 * $372);
   $375 = Math_fround($344 * $372);
   $376 = Math_fround(HEAPF32[$closA>>2]);
   $377 = Math_fround(HEAPF32[$18>>2]);
   $378 = Math_fround(HEAPF32[$19>>2]);
   $379 = Math_fround($7 * $373);
   $380 = Math_fround($7 * $374);
   $381 = Math_fround($7 * $375);
   $382 = Math_fround($376 - $379);
   $383 = Math_fround($377 - $380);
   $384 = Math_fround($378 - $381);
   HEAPF32[$contactA>>2] = $382;
   $385 = (($contactA) + 4|0);
   HEAPF32[$385>>2] = $383;
   $386 = (($contactA) + 8|0);
   HEAPF32[$386>>2] = $384;
   $387 = (($contactA) + 12|0);
   HEAPF32[$387>>2] = Math_fround(0.0);
   $388 = Math_fround(HEAPF32[$closB>>2]);
   $389 = Math_fround(HEAPF32[$21>>2]);
   $390 = Math_fround(HEAPF32[$22>>2]);
   $391 = Math_fround($9 * $373);
   $392 = Math_fround($9 * $374);
   $393 = Math_fround($9 * $375);
   $394 = Math_fround($391 + $388);
   $395 = Math_fround($392 + $389);
   $396 = Math_fround($393 + $390);
   HEAPF32[$contactB>>2] = $394;
   $397 = (($contactB) + 4|0);
   HEAPF32[$397>>2] = $395;
   $398 = (($contactB) + 8|0);
   HEAPF32[$398>>2] = $396;
   $399 = (($contactB) + 12|0);
   HEAPF32[$399>>2] = Math_fround(0.0);
   $400 = Math_fround($371 - $17);
   HEAPF32[$penetrationDepth>>2] = $400;
   $401 = (($penetrationDepth) + 4|0);
   ;HEAP32[$401+0>>2]=HEAP32[$$sroa$1234+0>>2]|0;HEAP32[$401+4>>2]=HEAP32[$$sroa$1234+4>>2]|0;HEAP32[$401+8>>2]=HEAP32[$$sroa$1234+8>>2]|0;
   HEAPF32[$normal>>2] = $373;
   $402 = (($normal) + 4|0);
   HEAPF32[$402>>2] = $374;
   $403 = (($normal) + 8|0);
   HEAPF32[$403>>2] = $375;
   $404 = (($normal) + 12|0);
   HEAPF32[$404>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $214 = HEAP32[$size>>2]|0;
   $521 = $214;
  }
 } while(0);
 $519 = ($aIndices|0)==(0|0);
 if (!($519)) {
  $520 = $521&255;
  HEAP8[$_size>>0] = $520;
  $522 = ($521|0)==(0);
  if (!($522)) {
   $i$01$i = 0;
   while(1) {
    $523 = (($aInd) + ($i$01$i<<2)|0);
    $524 = HEAP32[$523>>2]|0;
    $525 = $524&255;
    $526 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$526>>0] = $525;
    $527 = (($bInd) + ($i$01$i<<2)|0);
    $528 = HEAP32[$527>>2]|0;
    $529 = $528&255;
    $530 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$530>>0] = $529;
    $531 = (($i$01$i) + 1)|0;
    $exitcond$i = ($531|0)==($521|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $531;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_17ShrunkConvexHullVENS0_24ShrunkConvexHullNoScaleVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$747 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i170 = Math_fround(0), $$$i134 = Math_fround(0), $$$i169 = Math_fround(0), $$$i735799 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i171 = Math_fround(0), $$0 = 0, $$0$i$i = 0, $$743 = 0, $$in1$i = 0, $$in2$i = 0, $$ph = Math_fround(0), $$ph755 = Math_fround(0), $$ph756 = Math_fround(0), $$ph757 = Math_fround(0), $$ph758 = Math_fround(0), $$ph759 = Math_fround(0);
 var $$ph760 = Math_fround(0), $$ph761 = Math_fround(0), $$ph763 = Math_fround(0), $$ph764 = 0, $$pre = Math_fround(0), $$pre838 = Math_fround(0), $$pre839 = Math_fround(0), $$pre840 = Math_fround(0), $$pre841 = Math_fround(0), $$pre842 = Math_fround(0), $$pre843 = Math_fround(0), $$pre844 = Math_fround(0), $$pre845 = Math_fround(0), $$pre846 = Math_fround(0), $$pre847 = Math_fround(0), $$sroa$1 = 0, $$sroa$1232 = 0, $$sroa$1234 = 0, $$sum$i$i$i = 0, $0 = 0;
 var $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0;
 var $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0);
 var $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0;
 var $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0);
 var $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0);
 var $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0);
 var $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0);
 var $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0);
 var $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = Math_fround(0);
 var $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0);
 var $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0);
 var $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = 0, $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0);
 var $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0), $459 = Math_fround(0);
 var $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0;
 var $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0);
 var $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = 0, $53 = 0, $530 = 0;
 var $531 = 0, $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = 0, $544 = 0, $545 = 0, $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0);
 var $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0;
 var $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_dir$i = 0, $aInd = 0;
 var $b$a$i = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$041$i$i$i = 0, $i$0809 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $maxIndex$040$i$i$i = 0, $maxIndex$1$i$i$i = 0, $minDist$sroa$1 = 0, $not$ = 0;
 var $p$i = 0, $phitmp751 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $0 = sp + 400|0;
 $1 = sp + 336|0;
 $_dir$i = sp + 352|0;
 $p$i = sp + 368|0;
 $closA = sp + 384|0;
 $closB = sp + 416|0;
 $sDist$sroa$1 = sp + 548|0;
 $minDist$sroa$1 = sp + 536|0;
 $v = sp + 448|0;
 $Q = sp + 272|0;
 $A = sp + 112|0;
 $B = sp;
 $aInd = sp + 520|0;
 $bInd = sp + 504|0;
 $size = sp + 560|0;
 $lastQ = sp + 80|0;
 $lastA = sp + 96|0;
 $lastB = sp + 176|0;
 $2 = sp + 192|0;
 $3 = sp + 208|0;
 $4 = sp + 224|0;
 $supportA1 = sp + 240|0;
 $supportB2 = sp + 256|0;
 $support3 = sp + 64|0;
 $$sroa$1234 = sp + 476|0;
 $5 = sp + 432|0;
 $$sroa$1232 = sp + 488|0;
 $$sroa$1 = sp + 464|0;
 $6 = (($a) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($b) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$_contactDist>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i169 = $15 ? $14 : $12;
 $16 = Math_fround($$$i169 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($7 + $9);
 $18 = (($closA) + 4|0);
 $19 = (($closA) + 8|0);
 $20 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $21 = (($closB) + 4|0);
 $22 = (($closB) + 8|0);
 $23 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $24 = Math_fround($16 * $16);
 HEAP32[$size>>2] = 0;
 $25 = HEAP8[$_size>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $188 = (($aToB) + 48|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = (($aToB) + 52|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = (($aToB) + 56|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($aToB) + 60|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($189 * $189);
  $197 = Math_fround($191 * $191);
  $198 = Math_fround($196 + $197);
  $199 = Math_fround($193 * $193);
  $200 = Math_fround($198 + $199);
  $201 = $200 > Math_fround(0.0);
  HEAPF32[$1>>2] = $189;
  $202 = (($1) + 4|0);
  HEAPF32[$202>>2] = $191;
  $203 = (($1) + 8|0);
  HEAPF32[$203>>2] = $193;
  $204 = (($1) + 12|0);
  HEAPF32[$204>>2] = $195;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $205 = (($0) + 4|0);
  HEAPF32[$205>>2] = Math_fround(0.0);
  $206 = (($0) + 8|0);
  HEAPF32[$206>>2] = Math_fround(0.0);
  $207 = (($0) + 12|0);
  HEAPF32[$207>>2] = Math_fround(0.0);
  $b$a$i = $201 ? $1 : $0;
  $208 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $209 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $210 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $208;
  $211 = (($v) + 4|0);
  HEAPF32[$211>>2] = $209;
  $212 = (($v) + 8|0);
  HEAPF32[$212>>2] = $210;
  $213 = (($v) + 12|0);
  HEAPF32[$213>>2] = Math_fround(0.0);
  $$ph = Math_fround(0.0);$$ph755 = Math_fround(0.0);$$ph756 = Math_fround(0.0);$$ph757 = Math_fround(0.0);$$ph758 = Math_fround(0.0);$$ph759 = Math_fround(0.0);$$ph760 = Math_fround(0.0);$$ph761 = Math_fround(0.0);$$ph763 = Math_fround(3.40282346638528859812E+38);$$ph764 = 1;$573 = $210;$574 = $209;$575 = $208;
 } else {
  $27 = (($lastQ) + 4|0);
  $28 = (($lastQ) + 8|0);
  $29 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $30 = (($lastA) + 4|0);
  $31 = (($lastA) + 8|0);
  $32 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $33 = (($lastB) + 4|0);
  $34 = (($lastB) + 8|0);
  $35 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $36 = (($a) + 16|0);
  $37 = (($aToB) + 48|0);
  $38 = (($aToB) + 52|0);
  $39 = (($aToB) + 56|0);
  $40 = (($2) + 4|0);
  $41 = (($2) + 8|0);
  $42 = (($aToB) + 16|0);
  $43 = (($aToB) + 32|0);
  $44 = (($aToB) + 4|0);
  $45 = (($aToB) + 20|0);
  $46 = (($aToB) + 36|0);
  $47 = (($aToB) + 8|0);
  $48 = (($aToB) + 24|0);
  $49 = (($aToB) + 40|0);
  $50 = (($b) + 16|0);
  $51 = (($3) + 4|0);
  $52 = (($3) + 8|0);
  $53 = (($3) + 12|0);
  $i$0809 = 0;
  while(1) {
   $54 = (($aIndices) + ($i$0809)|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55&255;
   $57 = (($aInd) + ($i$0809<<2)|0);
   HEAP32[$57>>2] = $56;
   $58 = (($bIndices) + ($i$0809)|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = $59&255;
   $61 = (($bInd) + ($i$0809<<2)|0);
   HEAP32[$61>>2] = $60;
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($2,$a,$56,$36);
   $62 = Math_fround(HEAPF32[$37>>2]);
   $63 = Math_fround(HEAPF32[$38>>2]);
   $64 = Math_fround(HEAPF32[$39>>2]);
   $65 = Math_fround(HEAPF32[$2>>2]);
   $66 = Math_fround(HEAPF32[$40>>2]);
   $67 = Math_fround(HEAPF32[$41>>2]);
   $68 = Math_fround(HEAPF32[$aToB>>2]);
   $69 = Math_fround($65 * $68);
   $70 = Math_fround(HEAPF32[$42>>2]);
   $71 = Math_fround($66 * $70);
   $72 = Math_fround($69 + $71);
   $73 = Math_fround(HEAPF32[$43>>2]);
   $74 = Math_fround($67 * $73);
   $75 = Math_fround($72 + $74);
   $76 = Math_fround(HEAPF32[$44>>2]);
   $77 = Math_fround($65 * $76);
   $78 = Math_fround(HEAPF32[$45>>2]);
   $79 = Math_fround($66 * $78);
   $80 = Math_fround($77 + $79);
   $81 = Math_fround(HEAPF32[$46>>2]);
   $82 = Math_fround($67 * $81);
   $83 = Math_fround($80 + $82);
   $84 = Math_fround(HEAPF32[$47>>2]);
   $85 = Math_fround($65 * $84);
   $86 = Math_fround(HEAPF32[$48>>2]);
   $87 = Math_fround($66 * $86);
   $88 = Math_fround($85 + $87);
   $89 = Math_fround(HEAPF32[$49>>2]);
   $90 = Math_fround($67 * $89);
   $91 = Math_fround($88 + $90);
   $92 = Math_fround($62 + $75);
   $93 = Math_fround($63 + $83);
   $94 = Math_fround($64 + $91);
   __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($3,$b,$60,$50);
   $95 = Math_fround(HEAPF32[$3>>2]);
   $96 = Math_fround(HEAPF32[$51>>2]);
   $97 = Math_fround(HEAPF32[$52>>2]);
   $98 = Math_fround(HEAPF32[$53>>2]);
   $99 = Math_fround($92 - $95);
   $100 = Math_fround($93 - $96);
   $101 = Math_fround($94 - $97);
   $102 = HEAP32[$size>>2]|0;
   $103 = (($A) + ($102<<4)|0);
   HEAPF32[$lastA>>2] = $92;
   HEAPF32[$30>>2] = $93;
   HEAPF32[$31>>2] = $94;
   HEAPF32[$32>>2] = Math_fround(0.0);
   ;HEAP32[$103+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$lastA+12>>2]|0;
   $104 = (($B) + ($102<<4)|0);
   HEAPF32[$lastB>>2] = $95;
   HEAPF32[$33>>2] = $96;
   HEAPF32[$34>>2] = $97;
   HEAPF32[$35>>2] = $98;
   ;HEAP32[$104+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$104+12>>2]=HEAP32[$lastB+12>>2]|0;
   $105 = (($102) + 1)|0;
   HEAP32[$size>>2] = $105;
   $106 = (($Q) + ($102<<4)|0);
   HEAPF32[$lastQ>>2] = $99;
   HEAPF32[$27>>2] = $100;
   HEAPF32[$28>>2] = $101;
   HEAPF32[$29>>2] = Math_fround(0.0);
   ;HEAP32[$106+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $107 = (($i$0809) + 1)|0;
   $108 = HEAP8[$_size>>0]|0;
   $109 = $108&255;
   $110 = ($107>>>0)<($109>>>0);
   if ($110) {
    $i$0809 = $107;
   } else {
    break;
   }
  }
  do {
   if ((($102|0) == 2)) {
    $168 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$168,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($102|0) == 1)) {
    $111 = Math_fround(HEAPF32[$Q>>2]);
    $112 = (($Q) + 4|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = (($Q) + 8|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = Math_fround($99 - $111);
    $117 = Math_fround($100 - $113);
    $118 = Math_fround($101 - $115);
    $119 = Math_fround($116 * $116);
    $120 = Math_fround($117 * $117);
    $121 = Math_fround($119 + $120);
    $122 = Math_fround($118 * $118);
    $123 = Math_fround($121 + $122);
    $124 = $123 == Math_fround(0.0);
    if ($124) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $125 = Math_fround($113 * $117);
     $126 = Math_fround(-$125);
     $127 = Math_fround($111 * $116);
     $128 = Math_fround($126 - $127);
     $129 = Math_fround($115 * $118);
     $130 = Math_fround($128 - $129);
     $131 = Math_fround(HEAPF32[$A>>2]);
     $132 = (($A) + 4|0);
     $133 = Math_fround(HEAPF32[$132>>2]);
     $134 = (($A) + 8|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     $136 = Math_fround($92 - $131);
     $137 = Math_fround($93 - $133);
     $138 = Math_fround($94 - $135);
     $139 = Math_fround(HEAPF32[$B>>2]);
     $140 = (($B) + 4|0);
     $141 = Math_fround(HEAPF32[$140>>2]);
     $142 = (($B) + 8|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = Math_fround($95 - $139);
     $145 = Math_fround($96 - $141);
     $146 = Math_fround($97 - $143);
     $147 = Math_fround($130 / $123);
     $148 = $147 > Math_fround(1.0);
     $$$i$i$i170 = $148 ? Math_fround(1.0) : $147;
     $149 = $$$i$i$i170 > Math_fround(0.0);
     $$$i8$i$i171 = $149 ? $$$i$i$i170 : Math_fround(0.0);
     $150 = Math_fround($136 * $$$i8$i$i171);
     $151 = Math_fround($137 * $$$i8$i$i171);
     $152 = Math_fround($138 * $$$i8$i$i171);
     $153 = Math_fround($131 + $150);
     $154 = Math_fround($133 + $151);
     $155 = Math_fround($135 + $152);
     $156 = Math_fround($144 * $$$i8$i$i171);
     $157 = Math_fround($145 * $$$i8$i$i171);
     $158 = Math_fround($146 * $$$i8$i$i171);
     $159 = Math_fround($139 + $156);
     $160 = Math_fround($141 + $157);
     $161 = Math_fround($143 + $158);
     HEAPF32[$closA>>2] = $153;
     HEAPF32[$18>>2] = $154;
     HEAPF32[$19>>2] = $155;
     HEAPF32[$20>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $159;
     HEAPF32[$21>>2] = $160;
     HEAPF32[$22>>2] = $161;
     HEAPF32[$23>>2] = Math_fround(0.0);
     $162 = Math_fround($153 - $159);
     $163 = Math_fround($154 - $160);
     $164 = Math_fround($155 - $161);
     HEAPF32[$4>>2] = $162;
     $165 = (($4) + 4|0);
     HEAPF32[$165>>2] = $163;
     $166 = (($4) + 8|0);
     HEAPF32[$166>>2] = $164;
     $167 = (($4) + 12|0);
     HEAPF32[$167>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($102|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($102|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$4+12>>2]|0;
  $169 = Math_fround(HEAPF32[$v>>2]);
  $170 = (($v) + 4|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = (($v) + 8|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($169 * $169);
  $175 = Math_fround($171 * $171);
  $176 = Math_fround($174 + $175);
  $177 = Math_fround($173 * $173);
  $178 = Math_fround($176 + $177);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $179 = Math_fround(HEAPF32[$closA>>2]);
  $180 = Math_fround(HEAPF32[$18>>2]);
  $181 = Math_fround(HEAPF32[$19>>2]);
  $182 = Math_fround(HEAPF32[$20>>2]);
  $183 = Math_fround(HEAPF32[$closB>>2]);
  $184 = Math_fround(HEAPF32[$21>>2]);
  $185 = Math_fround(HEAPF32[$22>>2]);
  $186 = Math_fround(HEAPF32[$23>>2]);
  $187 = $178 > $24;
  $$ph = $182;$$ph755 = $181;$$ph756 = $180;$$ph757 = $179;$$ph758 = $186;$$ph759 = $185;$$ph760 = $184;$$ph761 = $183;$$ph763 = $178;$$ph764 = $187;$573 = $173;$574 = $171;$575 = $169;
 }
 do {
  if ($$ph764) {
   $215 = (($v) + 4|0);
   $216 = (($v) + 8|0);
   $217 = (($aToB) + 4|0);
   $218 = (($aToB) + 8|0);
   $219 = (($aToB) + 16|0);
   $220 = (($aToB) + 20|0);
   $221 = (($aToB) + 24|0);
   $222 = (($aToB) + 32|0);
   $223 = (($aToB) + 36|0);
   $224 = (($aToB) + 40|0);
   $225 = (($_dir$i) + 4|0);
   $226 = (($_dir$i) + 8|0);
   $227 = (($_dir$i) + 12|0);
   $228 = (($aToB) + 48|0);
   $229 = (($aToB) + 52|0);
   $230 = (($aToB) + 56|0);
   $231 = (($p$i) + 4|0);
   $232 = (($p$i) + 8|0);
   $233 = (($supportA1) + 4|0);
   $234 = (($supportA1) + 8|0);
   $235 = (($supportA1) + 12|0);
   $236 = (($b) + 196|0);
   $237 = (($b) + 200|0);
   $238 = (($b) + 204|0);
   $239 = (($b) + 16|0);
   $240 = (($supportB2) + 4|0);
   $241 = (($supportB2) + 8|0);
   $242 = (($support3) + 4|0);
   $243 = (($support3) + 8|0);
   $244 = (($support3) + 12|0);
   $245 = (($a) + 48|0);
   $246 = (($b) + 48|0);
   $247 = (($Q) + 4|0);
   $248 = (($Q) + 8|0);
   $249 = (($A) + 4|0);
   $250 = (($A) + 8|0);
   $251 = (($B) + 4|0);
   $252 = (($B) + 8|0);
   $253 = (($5) + 4|0);
   $254 = (($5) + 8|0);
   $255 = (($5) + 12|0);
   $256 = (($Q) + 16|0);
   $$$i735799 = $10;$258 = $575;$260 = $574;$262 = $573;$382 = $$ph763;$518 = $$ph757;$519 = $$ph756;$520 = $$ph755;$521 = $$ph;$522 = $$ph761;$523 = $$ph760;$524 = $$ph759;$525 = $$ph758;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $257 = Math_fround(-$258);
    $259 = Math_fround(-$260);
    $261 = Math_fround(-$262);
    $263 = HEAP32[$size>>2]|0;
    $264 = (($A) + ($263<<4)|0);
    $265 = (($aInd) + ($263<<2)|0);
    $266 = Math_fround(HEAPF32[$aToB>>2]);
    $267 = Math_fround($266 * $257);
    $268 = Math_fround(HEAPF32[$217>>2]);
    $269 = Math_fround($268 * $259);
    $270 = Math_fround($267 + $269);
    $271 = Math_fround(HEAPF32[$218>>2]);
    $272 = Math_fround($271 * $261);
    $273 = Math_fround($270 + $272);
    $274 = Math_fround(HEAPF32[$219>>2]);
    $275 = Math_fround($274 * $257);
    $276 = Math_fround(HEAPF32[$220>>2]);
    $277 = Math_fround($276 * $259);
    $278 = Math_fround($275 + $277);
    $279 = Math_fround(HEAPF32[$221>>2]);
    $280 = Math_fround($279 * $261);
    $281 = Math_fround($278 + $280);
    $282 = Math_fround(HEAPF32[$222>>2]);
    $283 = Math_fround($282 * $257);
    $284 = Math_fround(HEAPF32[$223>>2]);
    $285 = Math_fround($284 * $259);
    $286 = Math_fround($283 + $285);
    $287 = Math_fround(HEAPF32[$224>>2]);
    $288 = Math_fround($287 * $261);
    $289 = Math_fround($286 + $288);
    HEAPF32[$_dir$i>>2] = $273;
    HEAPF32[$225>>2] = $281;
    HEAPF32[$226>>2] = $289;
    HEAPF32[$227>>2] = Math_fround(0.0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($p$i,$a,$_dir$i,$264,$265);
    $290 = Math_fround(HEAPF32[$228>>2]);
    $291 = Math_fround(HEAPF32[$229>>2]);
    $292 = Math_fround(HEAPF32[$230>>2]);
    $293 = Math_fround(HEAPF32[$p$i>>2]);
    $294 = Math_fround(HEAPF32[$231>>2]);
    $295 = Math_fround(HEAPF32[$232>>2]);
    $296 = Math_fround(HEAPF32[$aToB>>2]);
    $297 = Math_fround($293 * $296);
    $298 = Math_fround(HEAPF32[$219>>2]);
    $299 = Math_fround($294 * $298);
    $300 = Math_fround($297 + $299);
    $301 = Math_fround(HEAPF32[$222>>2]);
    $302 = Math_fround($295 * $301);
    $303 = Math_fround($300 + $302);
    $304 = Math_fround(HEAPF32[$217>>2]);
    $305 = Math_fround($293 * $304);
    $306 = Math_fround(HEAPF32[$220>>2]);
    $307 = Math_fround($294 * $306);
    $308 = Math_fround($305 + $307);
    $309 = Math_fround(HEAPF32[$223>>2]);
    $310 = Math_fround($295 * $309);
    $311 = Math_fround($308 + $310);
    $312 = Math_fround(HEAPF32[$218>>2]);
    $313 = Math_fround($293 * $312);
    $314 = Math_fround(HEAPF32[$221>>2]);
    $315 = Math_fround($294 * $314);
    $316 = Math_fround($313 + $315);
    $317 = Math_fround(HEAPF32[$224>>2]);
    $318 = Math_fround($295 * $317);
    $319 = Math_fround($316 + $318);
    $320 = Math_fround($290 + $303);
    $321 = Math_fround($291 + $311);
    $322 = Math_fround($292 + $319);
    HEAPF32[$supportA1>>2] = $320;
    HEAPF32[$233>>2] = $321;
    HEAPF32[$234>>2] = $322;
    HEAPF32[$235>>2] = Math_fround(0.0);
    ;HEAP32[$264+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$264+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$264+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$264+12>>2]=HEAP32[$supportA1+12>>2]|0;
    $323 = HEAP32[$size>>2]|0;
    $324 = (($B) + ($323<<4)|0);
    $325 = (($bInd) + ($323<<2)|0);
    $326 = HEAP32[$236>>2]|0;
    $327 = ($326|0)==(0|0);
    if ($327) {
     $329 = HEAP32[$237>>2]|0;
     $330 = HEAP8[$238>>0]|0;
     $331 = ($330&255)>(1);
     if ($331) {
      $332 = (($329) + 4|0);
      $333 = (($329) + 8|0);
      $334 = Math_fround(HEAPF32[$332>>2]);
      $335 = Math_fround(HEAPF32[$329>>2]);
      $336 = Math_fround($260 * $334);
      $337 = Math_fround($258 * $335);
      $338 = Math_fround(HEAPF32[$333>>2]);
      $339 = Math_fround($262 * $338);
      $340 = Math_fround($336 + $337);
      $341 = Math_fround($340 + $339);
      $343 = $329;$357 = $341;$i$041$i$i$i = 1;$maxIndex$040$i$i$i = 0;
      while(1) {
       $$sum$i$i$i = (($i$041$i$i$i) + 10)|0;
       $342 = ((($343) + (($$sum$i$i$i*12)|0)|0) + 8|0);
       $344 = HEAP32[$237>>2]|0;
       $345 = (($344) + (($i$041$i$i$i*12)|0)|0);
       $346 = Math_fround(HEAPF32[$345>>2]);
       $347 = ((($344) + (($i$041$i$i$i*12)|0)|0) + 4|0);
       $348 = Math_fround(HEAPF32[$347>>2]);
       $349 = ((($344) + (($i$041$i$i$i*12)|0)|0) + 8|0);
       $350 = Math_fround(HEAPF32[$349>>2]);
       $351 = Math_fround($346 * $258);
       $352 = Math_fround($348 * $260);
       $353 = Math_fround($351 + $352);
       $354 = Math_fround($350 * $262);
       $355 = Math_fround($353 + $354);
       $356 = $355 > $357;
       $358 = $356 ? $355 : $357;
       $maxIndex$1$i$i$i = $356 ? $i$041$i$i$i : $maxIndex$040$i$i$i;
       $359 = (($i$041$i$i$i) + 1)|0;
       $360 = HEAP8[$238>>0]|0;
       $361 = $360&255;
       $362 = ($359>>>0)<($361>>>0);
       if ($362) {
        $343 = $344;$357 = $358;$i$041$i$i$i = $359;$maxIndex$040$i$i$i = $maxIndex$1$i$i$i;
       } else {
        $$0$i$i = $maxIndex$1$i$i$i;$384 = $258;$386 = $260;$389 = $262;
        break;
       }
      }
     } else {
      $$0$i$i = 0;$384 = $258;$386 = $260;$389 = $262;
     }
    } else {
     $328 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($b,$v)|0);
     $$pre = Math_fround(HEAPF32[$v>>2]);
     $$pre838 = Math_fround(HEAPF32[$215>>2]);
     $$pre839 = Math_fround(HEAPF32[$216>>2]);
     $$0$i$i = $328;$384 = $$pre;$386 = $$pre838;$389 = $$pre839;
    }
    HEAP32[$325>>2] = $$0$i$i;
    __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($supportB2,$b,$$0$i$i,$239);
    ;HEAP32[$324+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$324+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$324+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$324+12>>2]=HEAP32[$supportB2+12>>2]|0;
    $363 = Math_fround(HEAPF32[$supportA1>>2]);
    $364 = Math_fround(HEAPF32[$233>>2]);
    $365 = Math_fround(HEAPF32[$234>>2]);
    $366 = Math_fround(HEAPF32[$supportB2>>2]);
    $367 = Math_fround(HEAPF32[$240>>2]);
    $368 = Math_fround(HEAPF32[$241>>2]);
    $369 = Math_fround($363 - $366);
    $370 = Math_fround($364 - $367);
    $371 = Math_fround($365 - $368);
    HEAPF32[$support3>>2] = $369;
    HEAPF32[$242>>2] = $370;
    HEAPF32[$243>>2] = $371;
    HEAPF32[$244>>2] = Math_fround(0.0);
    $372 = HEAP32[$size>>2]|0;
    $373 = (($372) + 1)|0;
    HEAP32[$size>>2] = $373;
    $374 = (($Q) + ($372<<4)|0);
    ;HEAP32[$374+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$374+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$374+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$374+12>>2]=HEAP32[$support3+12>>2]|0;
    $375 = Math_fround(HEAPF32[$245>>2]);
    $376 = Math_fround(HEAPF32[$246>>2]);
    $377 = $375 > $376;
    $$$i134 = $377 ? $375 : $376;
    $378 = $$$i735799 > $$$i134;
    $$$i = $378 ? $$$i735799 : $$$i134;
    $379 = Math_fround($17 + $$$i);
    $380 = Math_fround($379 * $379);
    $381 = Math_fround($382 * $380);
    $383 = Math_fround($384 * $369);
    $385 = Math_fround($386 * $370);
    $387 = Math_fround($383 + $385);
    $388 = Math_fround($389 * $371);
    $390 = Math_fround($387 + $388);
    $391 = Math_fround($390 * $390);
    $392 = $390 > Math_fround(0.0);
    $393 = $391 > $381;
    if ($392) {
     $phitmp751 = $393 ^ 1;
     $397 = $393;$399 = $phitmp751;
    } else {
     $397 = 0;$399 = 1;
    }
    $394 = Math_fround($382 - $390);
    $395 = Math_fround($24 * $382);
    $396 = $395 >= $394;
    $brmerge$demorgan = $396 | $397;
    if ($brmerge$demorgan) {
     $398 = $399 ^ 1;
     $$743 = $396 | $398;
     if ($$743) {
      break;
     }
    }
    do {
     if ((($372|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($372|0) == 1)) {
      $446 = Math_fround(HEAPF32[$Q>>2]);
      $447 = Math_fround(HEAPF32[$247>>2]);
      $448 = Math_fround(HEAPF32[$248>>2]);
      $449 = Math_fround($369 - $446);
      $450 = Math_fround($370 - $447);
      $451 = Math_fround($371 - $448);
      $452 = Math_fround($449 * $449);
      $453 = Math_fround($450 * $450);
      $454 = Math_fround($452 + $453);
      $455 = Math_fround($451 * $451);
      $456 = Math_fround($454 + $455);
      $457 = $456 == Math_fround(0.0);
      if ($457) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $458 = Math_fround($447 * $450);
       $459 = Math_fround(-$458);
       $460 = Math_fround($446 * $449);
       $461 = Math_fround($459 - $460);
       $462 = Math_fround($448 * $451);
       $463 = Math_fround($461 - $462);
       $464 = Math_fround(HEAPF32[$A>>2]);
       $465 = Math_fround(HEAPF32[$249>>2]);
       $466 = Math_fround(HEAPF32[$250>>2]);
       $467 = Math_fround($363 - $464);
       $468 = Math_fround($364 - $465);
       $469 = Math_fround($365 - $466);
       $470 = Math_fround(HEAPF32[$B>>2]);
       $471 = Math_fround(HEAPF32[$251>>2]);
       $472 = Math_fround(HEAPF32[$252>>2]);
       $473 = Math_fround($366 - $470);
       $474 = Math_fround($367 - $471);
       $475 = Math_fround($368 - $472);
       $476 = Math_fround($463 / $456);
       $477 = $476 > Math_fround(1.0);
       $$$i$i$i = $477 ? Math_fround(1.0) : $476;
       $478 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $478 ? $$$i$i$i : Math_fround(0.0);
       $479 = Math_fround($467 * $$$i8$i$i);
       $480 = Math_fround($468 * $$$i8$i$i);
       $481 = Math_fround($469 * $$$i8$i$i);
       $482 = Math_fround($464 + $479);
       $483 = Math_fround($465 + $480);
       $484 = Math_fround($466 + $481);
       $485 = Math_fround($473 * $$$i8$i$i);
       $486 = Math_fround($474 * $$$i8$i$i);
       $487 = Math_fround($475 * $$$i8$i$i);
       $488 = Math_fround($470 + $485);
       $489 = Math_fround($471 + $486);
       $490 = Math_fround($472 + $487);
       HEAPF32[$closA>>2] = $482;
       HEAPF32[$18>>2] = $483;
       HEAPF32[$19>>2] = $484;
       HEAPF32[$20>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $488;
       HEAPF32[$21>>2] = $489;
       HEAPF32[$22>>2] = $490;
       HEAPF32[$23>>2] = Math_fround(0.0);
       $491 = Math_fround($482 - $488);
       $492 = Math_fround($483 - $489);
       $493 = Math_fround($484 - $490);
       HEAPF32[$5>>2] = $491;
       HEAPF32[$253>>2] = $492;
       HEAPF32[$254>>2] = $493;
       HEAPF32[$255>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($372|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($372|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$256,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
    $494 = Math_fround(HEAPF32[$v>>2]);
    $495 = Math_fround(HEAPF32[$215>>2]);
    $496 = Math_fround(HEAPF32[$216>>2]);
    $497 = Math_fround($494 * $494);
    $498 = Math_fround($495 * $495);
    $499 = Math_fround($497 + $498);
    $500 = Math_fround($496 * $496);
    $501 = Math_fround($499 + $500);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1232+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1232+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1232+8>>2]|0;
    $502 = $382 > $501;
    $503 = $501 > $24;
    if (!($503)) {
     label = 42;
     break;
    }
    if (!($502)) {
     label = 42;
     break;
    }
    $$pre840 = Math_fround(HEAPF32[$closA>>2]);
    $$pre841 = Math_fround(HEAPF32[$18>>2]);
    $$pre842 = Math_fround(HEAPF32[$19>>2]);
    $$pre843 = Math_fround(HEAPF32[$20>>2]);
    $$pre844 = Math_fround(HEAPF32[$closB>>2]);
    $$pre845 = Math_fround(HEAPF32[$21>>2]);
    $$pre846 = Math_fround(HEAPF32[$22>>2]);
    $$pre847 = Math_fround(HEAPF32[$23>>2]);
    $$$i735799 = $$$i;$258 = $494;$260 = $495;$262 = $496;$382 = $501;$518 = $$pre840;$519 = $$pre841;$520 = $$pre842;$521 = $$pre843;$522 = $$pre844;$523 = $$pre845;$524 = $$pre846;$525 = $$pre847;
   }
   if ((label|0) == 42) {
    $504 = HEAP32[$size>>2]|0;
    if ($502) {
     $562 = $504;
     break;
    }
    $505 = (($504) + -1)|0;
    $506 = ($aIndices|0)==(0|0);
    if (!($506)) {
     $507 = $505&255;
     HEAP8[$_size>>0] = $507;
     $508 = ($505|0)==(0);
     if (!($508)) {
      $i$01$i29 = 0;
      while(1) {
       $509 = (($aInd) + ($i$01$i29<<2)|0);
       $510 = HEAP32[$509>>2]|0;
       $511 = $510&255;
       $512 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$512>>0] = $511;
       $513 = (($bInd) + ($i$01$i29<<2)|0);
       $514 = HEAP32[$513>>2]|0;
       $515 = $514&255;
       $516 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$516>>0] = $515;
       $517 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($517|0)==($505|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $517;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $518;
    HEAPF32[$18>>2] = $519;
    HEAPF32[$19>>2] = $520;
    HEAPF32[$20>>2] = $521;
    HEAPF32[$closB>>2] = $522;
    HEAPF32[$21>>2] = $523;
    HEAPF32[$22>>2] = $524;
    HEAPF32[$23>>2] = $525;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $526 = Math_fround($518 - $522);
    $527 = Math_fround($519 - $523);
    $528 = Math_fround($520 - $524);
    HEAPF32[$v>>2] = $526;
    $529 = (($v) + 4|0);
    HEAPF32[$529>>2] = $527;
    $530 = (($v) + 8|0);
    HEAPF32[$530>>2] = $528;
    $531 = (($v) + 12|0);
    HEAPF32[$531>>2] = Math_fround(0.0);
    $532 = (Math_fround(Math_sqrt((Math_fround($382)))));
    $533 = Math_fround(Math_fround(1.0) / $532);
    $534 = Math_fround($526 * $533);
    $535 = Math_fround($527 * $533);
    $536 = Math_fround($528 * $533);
    $537 = Math_fround($7 * $534);
    $538 = Math_fround($7 * $535);
    $539 = Math_fround($7 * $536);
    $540 = Math_fround($518 - $537);
    $541 = Math_fround($519 - $538);
    $542 = Math_fround($520 - $539);
    HEAPF32[$contactA>>2] = $540;
    $543 = (($contactA) + 4|0);
    HEAPF32[$543>>2] = $541;
    $544 = (($contactA) + 8|0);
    HEAPF32[$544>>2] = $542;
    $545 = (($contactA) + 12|0);
    HEAPF32[$545>>2] = Math_fround(0.0);
    $546 = Math_fround($9 * $534);
    $547 = Math_fround($9 * $535);
    $548 = Math_fround($9 * $536);
    $549 = Math_fround($546 + $522);
    $550 = Math_fround($547 + $523);
    $551 = Math_fround($548 + $524);
    HEAPF32[$contactB>>2] = $549;
    $552 = (($contactB) + 4|0);
    HEAPF32[$552>>2] = $550;
    $553 = (($contactB) + 8|0);
    HEAPF32[$553>>2] = $551;
    $554 = (($contactB) + 12|0);
    HEAPF32[$554>>2] = Math_fround(0.0);
    $555 = Math_fround($532 - $17);
    HEAPF32[$penetrationDepth>>2] = $555;
    $556 = (($penetrationDepth) + 4|0);
    ;HEAP32[$556+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$556+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$556+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $534;
    $557 = (($normal) + 4|0);
    HEAPF32[$557>>2] = $535;
    $558 = (($normal) + 8|0);
    HEAPF32[$558>>2] = $536;
    $559 = (($normal) + 12|0);
    HEAPF32[$559>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $400 = ($aIndices|0)==(0|0);
   if (!($400)) {
    $401 = $372&255;
    HEAP8[$_size>>0] = $401;
    $402 = ($372|0)==(0);
    if (!($402)) {
     $i$01$i72 = 0;
     while(1) {
      $403 = (($aInd) + ($i$01$i72<<2)|0);
      $404 = HEAP32[$403>>2]|0;
      $405 = $404&255;
      $406 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$406>>0] = $405;
      $407 = (($bInd) + ($i$01$i72<<2)|0);
      $408 = HEAP32[$407>>2]|0;
      $409 = $408&255;
      $410 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$410>>0] = $409;
      $411 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($411|0)==($372|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $411;
      }
     }
    }
   }
   $not$ = $397 ^ 1;
   $$$747 = $399 & $not$;
   if (!($$$747)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $412 = (Math_fround(Math_sqrt((Math_fround($382)))));
   $413 = Math_fround(Math_fround(1.0) / $412);
   $414 = Math_fround($384 * $413);
   $415 = Math_fround($386 * $413);
   $416 = Math_fround($389 * $413);
   $417 = Math_fround(HEAPF32[$closA>>2]);
   $418 = Math_fround(HEAPF32[$18>>2]);
   $419 = Math_fround(HEAPF32[$19>>2]);
   $420 = Math_fround($7 * $414);
   $421 = Math_fround($7 * $415);
   $422 = Math_fround($7 * $416);
   $423 = Math_fround($417 - $420);
   $424 = Math_fround($418 - $421);
   $425 = Math_fround($419 - $422);
   HEAPF32[$contactA>>2] = $423;
   $426 = (($contactA) + 4|0);
   HEAPF32[$426>>2] = $424;
   $427 = (($contactA) + 8|0);
   HEAPF32[$427>>2] = $425;
   $428 = (($contactA) + 12|0);
   HEAPF32[$428>>2] = Math_fround(0.0);
   $429 = Math_fround(HEAPF32[$closB>>2]);
   $430 = Math_fround(HEAPF32[$21>>2]);
   $431 = Math_fround(HEAPF32[$22>>2]);
   $432 = Math_fround($9 * $414);
   $433 = Math_fround($9 * $415);
   $434 = Math_fround($9 * $416);
   $435 = Math_fround($432 + $429);
   $436 = Math_fround($433 + $430);
   $437 = Math_fround($434 + $431);
   HEAPF32[$contactB>>2] = $435;
   $438 = (($contactB) + 4|0);
   HEAPF32[$438>>2] = $436;
   $439 = (($contactB) + 8|0);
   HEAPF32[$439>>2] = $437;
   $440 = (($contactB) + 12|0);
   HEAPF32[$440>>2] = Math_fround(0.0);
   $441 = Math_fround($412 - $17);
   HEAPF32[$penetrationDepth>>2] = $441;
   $442 = (($penetrationDepth) + 4|0);
   ;HEAP32[$442+0>>2]=HEAP32[$$sroa$1234+0>>2]|0;HEAP32[$442+4>>2]=HEAP32[$$sroa$1234+4>>2]|0;HEAP32[$442+8>>2]=HEAP32[$$sroa$1234+8>>2]|0;
   HEAPF32[$normal>>2] = $414;
   $443 = (($normal) + 4|0);
   HEAPF32[$443>>2] = $415;
   $444 = (($normal) + 8|0);
   HEAPF32[$444>>2] = $416;
   $445 = (($normal) + 12|0);
   HEAPF32[$445>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $214 = HEAP32[$size>>2]|0;
   $562 = $214;
  }
 } while(0);
 $560 = ($aIndices|0)==(0|0);
 if (!($560)) {
  $561 = $562&255;
  HEAP8[$_size>>0] = $561;
  $563 = ($562|0)==(0);
  if (!($563)) {
   $i$01$i = 0;
   while(1) {
    $564 = (($aInd) + ($i$01$i<<2)|0);
    $565 = HEAP32[$564>>2]|0;
    $566 = $565&255;
    $567 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$567>>0] = $566;
    $568 = (($bInd) + ($i$01$i<<2)|0);
    $569 = HEAP32[$568>>2]|0;
    $570 = $569&255;
    $571 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$571>>0] = $570;
    $572 = (($i$01$i) + 1)|0;
    $exitcond$i = ($572|0)==($562|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $572;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_24ShrunkConvexHullNoScaleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$747 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i170 = Math_fround(0), $$$i134 = Math_fround(0), $$$i169 = Math_fround(0), $$$i735799 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i171 = Math_fround(0), $$0 = 0, $$743 = 0, $$in1$i = 0, $$in2$i = 0, $$ph = Math_fround(0), $$ph755 = Math_fround(0), $$ph756 = Math_fround(0), $$ph757 = Math_fround(0), $$ph758 = Math_fround(0), $$ph759 = Math_fround(0), $$ph760 = Math_fround(0);
 var $$ph761 = Math_fround(0), $$ph763 = Math_fround(0), $$ph764 = 0, $$pre = Math_fround(0), $$pre838 = Math_fround(0), $$pre839 = Math_fround(0), $$pre840 = Math_fround(0), $$pre841 = Math_fround(0), $$pre842 = Math_fround(0), $$pre843 = Math_fround(0), $$pre844 = Math_fround(0), $$sroa$1 = 0, $$sroa$1232 = 0, $$sroa$1234 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0);
 var $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0);
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0);
 var $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0);
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0;
 var $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0);
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0);
 var $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0);
 var $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0);
 var $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0);
 var $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0);
 var $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0);
 var $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = 0, $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0);
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0;
 var $Q = 0, $aInd = 0, $b$a$i = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$0809 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $nv = 0;
 var $phitmp751 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 176|0;
 $1 = sp + 256|0;
 $closA = sp + 416|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 448|0;
 $minDist$sroa$1 = sp + 460|0;
 $v = sp + 432|0;
 $Q = sp + 192|0;
 $A = sp + 336|0;
 $B = sp + 272|0;
 $aInd = sp + 512|0;
 $bInd = sp + 528|0;
 $size = sp + 544|0;
 $lastQ = sp + 160|0;
 $lastA = sp + 64|0;
 $lastB = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = sp + 48|0;
 $nv = sp + 80|0;
 $supportA1 = sp + 96|0;
 $supportB2 = sp + 112|0;
 $support3 = sp + 128|0;
 $$sroa$1234 = sp + 472|0;
 $5 = sp + 144|0;
 $$sroa$1232 = sp + 484|0;
 $$sroa$1 = sp + 496|0;
 $6 = (($a) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($b) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$_contactDist>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i169 = $15 ? $14 : $12;
 $16 = Math_fround($$$i169 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($7 + $9);
 $18 = (($closA) + 4|0);
 $19 = (($closA) + 8|0);
 $20 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $21 = (($closB) + 4|0);
 $22 = (($closB) + 8|0);
 $23 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $24 = Math_fround($16 * $16);
 HEAP32[$size>>2] = 0;
 $25 = HEAP8[$_size>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $188 = (($aToB) + 48|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = (($aToB) + 52|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = (($aToB) + 56|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($aToB) + 60|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($189 * $189);
  $197 = Math_fround($191 * $191);
  $198 = Math_fround($196 + $197);
  $199 = Math_fround($193 * $193);
  $200 = Math_fround($198 + $199);
  $201 = $200 > Math_fround(0.0);
  HEAPF32[$1>>2] = $189;
  $202 = (($1) + 4|0);
  HEAPF32[$202>>2] = $191;
  $203 = (($1) + 8|0);
  HEAPF32[$203>>2] = $193;
  $204 = (($1) + 12|0);
  HEAPF32[$204>>2] = $195;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $205 = (($0) + 4|0);
  HEAPF32[$205>>2] = Math_fround(0.0);
  $206 = (($0) + 8|0);
  HEAPF32[$206>>2] = Math_fround(0.0);
  $207 = (($0) + 12|0);
  HEAPF32[$207>>2] = Math_fround(0.0);
  $b$a$i = $201 ? $1 : $0;
  $208 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $209 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $210 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $208;
  $211 = (($v) + 4|0);
  HEAPF32[$211>>2] = $209;
  $212 = (($v) + 8|0);
  HEAPF32[$212>>2] = $210;
  $213 = (($v) + 12|0);
  HEAPF32[$213>>2] = Math_fround(0.0);
  $$ph = Math_fround(0.0);$$ph755 = Math_fround(0.0);$$ph756 = Math_fround(0.0);$$ph757 = Math_fround(0.0);$$ph758 = Math_fround(0.0);$$ph759 = Math_fround(0.0);$$ph760 = Math_fround(0.0);$$ph761 = Math_fround(0.0);$$ph763 = Math_fround(3.40282346638528859812E+38);$$ph764 = 1;$461 = $210;$462 = $209;$463 = $208;
 } else {
  $27 = (($lastQ) + 4|0);
  $28 = (($lastQ) + 8|0);
  $29 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $30 = (($lastA) + 4|0);
  $31 = (($lastA) + 8|0);
  $32 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $33 = (($lastB) + 4|0);
  $34 = (($lastB) + 8|0);
  $35 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $36 = (($a) + 16|0);
  $37 = (($aToB) + 48|0);
  $38 = (($aToB) + 52|0);
  $39 = (($aToB) + 56|0);
  $40 = (($2) + 4|0);
  $41 = (($2) + 8|0);
  $42 = (($aToB) + 16|0);
  $43 = (($aToB) + 32|0);
  $44 = (($aToB) + 4|0);
  $45 = (($aToB) + 20|0);
  $46 = (($aToB) + 36|0);
  $47 = (($aToB) + 8|0);
  $48 = (($aToB) + 24|0);
  $49 = (($aToB) + 40|0);
  $50 = (($b) + 16|0);
  $51 = (($3) + 4|0);
  $52 = (($3) + 8|0);
  $53 = (($3) + 12|0);
  $i$0809 = 0;
  while(1) {
   $54 = (($aIndices) + ($i$0809)|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55&255;
   $57 = (($aInd) + ($i$0809<<2)|0);
   HEAP32[$57>>2] = $56;
   $58 = (($bIndices) + ($i$0809)|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = $59&255;
   $61 = (($bInd) + ($i$0809<<2)|0);
   HEAP32[$61>>2] = $60;
   __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($2,$a,$56,$36);
   $62 = Math_fround(HEAPF32[$37>>2]);
   $63 = Math_fround(HEAPF32[$38>>2]);
   $64 = Math_fround(HEAPF32[$39>>2]);
   $65 = Math_fround(HEAPF32[$2>>2]);
   $66 = Math_fround(HEAPF32[$40>>2]);
   $67 = Math_fround(HEAPF32[$41>>2]);
   $68 = Math_fround(HEAPF32[$aToB>>2]);
   $69 = Math_fround($65 * $68);
   $70 = Math_fround(HEAPF32[$42>>2]);
   $71 = Math_fround($66 * $70);
   $72 = Math_fround($69 + $71);
   $73 = Math_fround(HEAPF32[$43>>2]);
   $74 = Math_fround($67 * $73);
   $75 = Math_fround($72 + $74);
   $76 = Math_fround(HEAPF32[$44>>2]);
   $77 = Math_fround($65 * $76);
   $78 = Math_fround(HEAPF32[$45>>2]);
   $79 = Math_fround($66 * $78);
   $80 = Math_fround($77 + $79);
   $81 = Math_fround(HEAPF32[$46>>2]);
   $82 = Math_fround($67 * $81);
   $83 = Math_fround($80 + $82);
   $84 = Math_fround(HEAPF32[$47>>2]);
   $85 = Math_fround($65 * $84);
   $86 = Math_fround(HEAPF32[$48>>2]);
   $87 = Math_fround($66 * $86);
   $88 = Math_fround($85 + $87);
   $89 = Math_fround(HEAPF32[$49>>2]);
   $90 = Math_fround($67 * $89);
   $91 = Math_fround($88 + $90);
   $92 = Math_fround($62 + $75);
   $93 = Math_fround($63 + $83);
   $94 = Math_fround($64 + $91);
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($3,$b,$60,$50);
   $95 = Math_fround(HEAPF32[$3>>2]);
   $96 = Math_fround(HEAPF32[$51>>2]);
   $97 = Math_fround(HEAPF32[$52>>2]);
   $98 = Math_fround(HEAPF32[$53>>2]);
   $99 = Math_fround($92 - $95);
   $100 = Math_fround($93 - $96);
   $101 = Math_fround($94 - $97);
   $102 = HEAP32[$size>>2]|0;
   $103 = (($A) + ($102<<4)|0);
   HEAPF32[$lastA>>2] = $92;
   HEAPF32[$30>>2] = $93;
   HEAPF32[$31>>2] = $94;
   HEAPF32[$32>>2] = Math_fround(0.0);
   ;HEAP32[$103+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$lastA+12>>2]|0;
   $104 = (($B) + ($102<<4)|0);
   HEAPF32[$lastB>>2] = $95;
   HEAPF32[$33>>2] = $96;
   HEAPF32[$34>>2] = $97;
   HEAPF32[$35>>2] = $98;
   ;HEAP32[$104+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$104+12>>2]=HEAP32[$lastB+12>>2]|0;
   $105 = (($102) + 1)|0;
   HEAP32[$size>>2] = $105;
   $106 = (($Q) + ($102<<4)|0);
   HEAPF32[$lastQ>>2] = $99;
   HEAPF32[$27>>2] = $100;
   HEAPF32[$28>>2] = $101;
   HEAPF32[$29>>2] = Math_fround(0.0);
   ;HEAP32[$106+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $107 = (($i$0809) + 1)|0;
   $108 = HEAP8[$_size>>0]|0;
   $109 = $108&255;
   $110 = ($107>>>0)<($109>>>0);
   if ($110) {
    $i$0809 = $107;
   } else {
    break;
   }
  }
  do {
   if ((($102|0) == 1)) {
    $111 = Math_fround(HEAPF32[$Q>>2]);
    $112 = (($Q) + 4|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = (($Q) + 8|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = Math_fround($99 - $111);
    $117 = Math_fround($100 - $113);
    $118 = Math_fround($101 - $115);
    $119 = Math_fround($116 * $116);
    $120 = Math_fround($117 * $117);
    $121 = Math_fround($119 + $120);
    $122 = Math_fround($118 * $118);
    $123 = Math_fround($121 + $122);
    $124 = $123 == Math_fround(0.0);
    if ($124) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $125 = Math_fround($113 * $117);
     $126 = Math_fround(-$125);
     $127 = Math_fround($111 * $116);
     $128 = Math_fround($126 - $127);
     $129 = Math_fround($115 * $118);
     $130 = Math_fround($128 - $129);
     $131 = Math_fround(HEAPF32[$A>>2]);
     $132 = (($A) + 4|0);
     $133 = Math_fround(HEAPF32[$132>>2]);
     $134 = (($A) + 8|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     $136 = Math_fround($92 - $131);
     $137 = Math_fround($93 - $133);
     $138 = Math_fround($94 - $135);
     $139 = Math_fround(HEAPF32[$B>>2]);
     $140 = (($B) + 4|0);
     $141 = Math_fround(HEAPF32[$140>>2]);
     $142 = (($B) + 8|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = Math_fround($95 - $139);
     $145 = Math_fround($96 - $141);
     $146 = Math_fround($97 - $143);
     $147 = Math_fround($130 / $123);
     $148 = $147 > Math_fround(1.0);
     $$$i$i$i170 = $148 ? Math_fround(1.0) : $147;
     $149 = $$$i$i$i170 > Math_fround(0.0);
     $$$i8$i$i171 = $149 ? $$$i$i$i170 : Math_fround(0.0);
     $150 = Math_fround($136 * $$$i8$i$i171);
     $151 = Math_fround($137 * $$$i8$i$i171);
     $152 = Math_fround($138 * $$$i8$i$i171);
     $153 = Math_fround($131 + $150);
     $154 = Math_fround($133 + $151);
     $155 = Math_fround($135 + $152);
     $156 = Math_fround($144 * $$$i8$i$i171);
     $157 = Math_fround($145 * $$$i8$i$i171);
     $158 = Math_fround($146 * $$$i8$i$i171);
     $159 = Math_fround($139 + $156);
     $160 = Math_fround($141 + $157);
     $161 = Math_fround($143 + $158);
     HEAPF32[$closA>>2] = $153;
     HEAPF32[$18>>2] = $154;
     HEAPF32[$19>>2] = $155;
     HEAPF32[$20>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $159;
     HEAPF32[$21>>2] = $160;
     HEAPF32[$22>>2] = $161;
     HEAPF32[$23>>2] = Math_fround(0.0);
     $162 = Math_fround($153 - $159);
     $163 = Math_fround($154 - $160);
     $164 = Math_fround($155 - $161);
     HEAPF32[$4>>2] = $162;
     $165 = (($4) + 4|0);
     HEAPF32[$165>>2] = $163;
     $166 = (($4) + 8|0);
     HEAPF32[$166>>2] = $164;
     $167 = (($4) + 12|0);
     HEAPF32[$167>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($102|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($102|0) == 2)) {
    $168 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$168,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($102|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$4+12>>2]|0;
  $169 = Math_fround(HEAPF32[$v>>2]);
  $170 = (($v) + 4|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = (($v) + 8|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($169 * $169);
  $175 = Math_fround($171 * $171);
  $176 = Math_fround($174 + $175);
  $177 = Math_fround($173 * $173);
  $178 = Math_fround($176 + $177);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $179 = Math_fround(HEAPF32[$closA>>2]);
  $180 = Math_fround(HEAPF32[$18>>2]);
  $181 = Math_fround(HEAPF32[$19>>2]);
  $182 = Math_fround(HEAPF32[$20>>2]);
  $183 = Math_fround(HEAPF32[$closB>>2]);
  $184 = Math_fround(HEAPF32[$21>>2]);
  $185 = Math_fround(HEAPF32[$22>>2]);
  $186 = Math_fround(HEAPF32[$23>>2]);
  $187 = $178 > $24;
  $$ph = $182;$$ph755 = $181;$$ph756 = $180;$$ph757 = $179;$$ph758 = $186;$$ph759 = $185;$$ph760 = $184;$$ph761 = $183;$$ph763 = $178;$$ph764 = $187;$461 = $173;$462 = $171;$463 = $169;
 }
 do {
  if ($$ph764) {
   $215 = (($v) + 4|0);
   $216 = (($v) + 8|0);
   $217 = (($nv) + 4|0);
   $218 = (($nv) + 8|0);
   $219 = (($nv) + 12|0);
   $220 = (($supportA1) + 4|0);
   $221 = (($supportA1) + 8|0);
   $222 = (($supportB2) + 4|0);
   $223 = (($supportB2) + 8|0);
   $224 = (($support3) + 4|0);
   $225 = (($support3) + 8|0);
   $226 = (($support3) + 12|0);
   $227 = (($a) + 48|0);
   $228 = (($b) + 48|0);
   $229 = (($Q) + 4|0);
   $230 = (($Q) + 8|0);
   $231 = (($A) + 4|0);
   $232 = (($A) + 8|0);
   $233 = (($B) + 4|0);
   $234 = (($B) + 8|0);
   $235 = (($5) + 4|0);
   $236 = (($5) + 8|0);
   $237 = (($5) + 12|0);
   $238 = (($Q) + 16|0);
   $$$i735799 = $10;$240 = $463;$242 = $462;$244 = $461;$270 = $$ph763;$406 = $$ph757;$407 = $$ph756;$408 = $$ph755;$409 = $$ph;$410 = $$ph761;$411 = $$ph760;$412 = $$ph759;$413 = $$ph758;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $239 = Math_fround(-$240);
    $241 = Math_fround(-$242);
    $243 = Math_fround(-$244);
    HEAPF32[$nv>>2] = $239;
    HEAPF32[$217>>2] = $241;
    HEAPF32[$218>>2] = $243;
    HEAPF32[$219>>2] = Math_fround(0.0);
    $245 = HEAP32[$size>>2]|0;
    $246 = (($A) + ($245<<4)|0);
    $247 = (($aInd) + ($245<<2)|0);
    __ZNK5physx2Gu24ShrunkConvexHullNoScaleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVERS4_Ri($supportA1,$a,$nv,$aToB,$246,$247);
    $248 = HEAP32[$size>>2]|0;
    $249 = (($B) + ($248<<4)|0);
    $250 = (($bInd) + ($248<<2)|0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($supportB2,$b,$v,$249,$250);
    $251 = Math_fround(HEAPF32[$supportA1>>2]);
    $252 = Math_fround(HEAPF32[$220>>2]);
    $253 = Math_fround(HEAPF32[$221>>2]);
    $254 = Math_fround(HEAPF32[$supportB2>>2]);
    $255 = Math_fround(HEAPF32[$222>>2]);
    $256 = Math_fround(HEAPF32[$223>>2]);
    $257 = Math_fround($251 - $254);
    $258 = Math_fround($252 - $255);
    $259 = Math_fround($253 - $256);
    HEAPF32[$support3>>2] = $257;
    HEAPF32[$224>>2] = $258;
    HEAPF32[$225>>2] = $259;
    HEAPF32[$226>>2] = Math_fround(0.0);
    $260 = HEAP32[$size>>2]|0;
    $261 = (($260) + 1)|0;
    HEAP32[$size>>2] = $261;
    $262 = (($Q) + ($260<<4)|0);
    ;HEAP32[$262+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$262+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$262+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$262+12>>2]=HEAP32[$support3+12>>2]|0;
    $263 = Math_fround(HEAPF32[$227>>2]);
    $264 = Math_fround(HEAPF32[$228>>2]);
    $265 = $263 > $264;
    $$$i134 = $265 ? $263 : $264;
    $266 = $$$i735799 > $$$i134;
    $$$i = $266 ? $$$i735799 : $$$i134;
    $267 = Math_fround($17 + $$$i);
    $268 = Math_fround($267 * $267);
    $269 = Math_fround($270 * $268);
    $271 = Math_fround(HEAPF32[$v>>2]);
    $272 = Math_fround(HEAPF32[$215>>2]);
    $273 = Math_fround(HEAPF32[$216>>2]);
    $274 = Math_fround($271 * $257);
    $275 = Math_fround($272 * $258);
    $276 = Math_fround($274 + $275);
    $277 = Math_fround($273 * $259);
    $278 = Math_fround($276 + $277);
    $279 = Math_fround($278 * $278);
    $280 = $278 > Math_fround(0.0);
    $281 = $279 > $269;
    if ($280) {
     $phitmp751 = $281 ^ 1;
     $285 = $281;$287 = $phitmp751;
    } else {
     $285 = 0;$287 = 1;
    }
    $282 = Math_fround($270 - $278);
    $283 = Math_fround($24 * $270);
    $284 = $283 >= $282;
    $brmerge$demorgan = $284 | $285;
    if ($brmerge$demorgan) {
     $286 = $287 ^ 1;
     $$743 = $284 | $286;
     if ($$743) {
      break;
     }
    }
    do {
     if ((($260|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$238,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($260|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($260|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($260|0) == 1)) {
      $334 = Math_fround(HEAPF32[$Q>>2]);
      $335 = Math_fround(HEAPF32[$229>>2]);
      $336 = Math_fround(HEAPF32[$230>>2]);
      $337 = Math_fround($257 - $334);
      $338 = Math_fround($258 - $335);
      $339 = Math_fround($259 - $336);
      $340 = Math_fround($337 * $337);
      $341 = Math_fround($338 * $338);
      $342 = Math_fround($340 + $341);
      $343 = Math_fround($339 * $339);
      $344 = Math_fround($342 + $343);
      $345 = $344 == Math_fround(0.0);
      if ($345) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $346 = Math_fround($335 * $338);
       $347 = Math_fround(-$346);
       $348 = Math_fround($334 * $337);
       $349 = Math_fround($347 - $348);
       $350 = Math_fround($336 * $339);
       $351 = Math_fround($349 - $350);
       $352 = Math_fround(HEAPF32[$A>>2]);
       $353 = Math_fround(HEAPF32[$231>>2]);
       $354 = Math_fround(HEAPF32[$232>>2]);
       $355 = Math_fround($251 - $352);
       $356 = Math_fround($252 - $353);
       $357 = Math_fround($253 - $354);
       $358 = Math_fround(HEAPF32[$B>>2]);
       $359 = Math_fround(HEAPF32[$233>>2]);
       $360 = Math_fround(HEAPF32[$234>>2]);
       $361 = Math_fround($254 - $358);
       $362 = Math_fround($255 - $359);
       $363 = Math_fround($256 - $360);
       $364 = Math_fround($351 / $344);
       $365 = $364 > Math_fround(1.0);
       $$$i$i$i = $365 ? Math_fround(1.0) : $364;
       $366 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $366 ? $$$i$i$i : Math_fround(0.0);
       $367 = Math_fround($355 * $$$i8$i$i);
       $368 = Math_fround($356 * $$$i8$i$i);
       $369 = Math_fround($357 * $$$i8$i$i);
       $370 = Math_fround($352 + $367);
       $371 = Math_fround($353 + $368);
       $372 = Math_fround($354 + $369);
       $373 = Math_fround($361 * $$$i8$i$i);
       $374 = Math_fround($362 * $$$i8$i$i);
       $375 = Math_fround($363 * $$$i8$i$i);
       $376 = Math_fround($358 + $373);
       $377 = Math_fround($359 + $374);
       $378 = Math_fround($360 + $375);
       HEAPF32[$closA>>2] = $370;
       HEAPF32[$18>>2] = $371;
       HEAPF32[$19>>2] = $372;
       HEAPF32[$20>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $376;
       HEAPF32[$21>>2] = $377;
       HEAPF32[$22>>2] = $378;
       HEAPF32[$23>>2] = Math_fround(0.0);
       $379 = Math_fround($370 - $376);
       $380 = Math_fround($371 - $377);
       $381 = Math_fround($372 - $378);
       HEAPF32[$5>>2] = $379;
       HEAPF32[$235>>2] = $380;
       HEAPF32[$236>>2] = $381;
       HEAPF32[$237>>2] = Math_fround(0.0);
       break;
      }
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
    $382 = Math_fround(HEAPF32[$v>>2]);
    $383 = Math_fround(HEAPF32[$215>>2]);
    $384 = Math_fround(HEAPF32[$216>>2]);
    $385 = Math_fround($382 * $382);
    $386 = Math_fround($383 * $383);
    $387 = Math_fround($385 + $386);
    $388 = Math_fround($384 * $384);
    $389 = Math_fround($387 + $388);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1232+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1232+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1232+8>>2]|0;
    $390 = $270 > $389;
    $391 = $389 > $24;
    if (!($391)) {
     label = 37;
     break;
    }
    if (!($390)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre838 = Math_fround(HEAPF32[$18>>2]);
    $$pre839 = Math_fround(HEAPF32[$19>>2]);
    $$pre840 = Math_fround(HEAPF32[$20>>2]);
    $$pre841 = Math_fround(HEAPF32[$closB>>2]);
    $$pre842 = Math_fround(HEAPF32[$21>>2]);
    $$pre843 = Math_fround(HEAPF32[$22>>2]);
    $$pre844 = Math_fround(HEAPF32[$23>>2]);
    $$$i735799 = $$$i;$240 = $382;$242 = $383;$244 = $384;$270 = $389;$406 = $$pre;$407 = $$pre838;$408 = $$pre839;$409 = $$pre840;$410 = $$pre841;$411 = $$pre842;$412 = $$pre843;$413 = $$pre844;
   }
   if ((label|0) == 37) {
    $392 = HEAP32[$size>>2]|0;
    if ($390) {
     $450 = $392;
     break;
    }
    $393 = (($392) + -1)|0;
    $394 = ($aIndices|0)==(0|0);
    if (!($394)) {
     $395 = $393&255;
     HEAP8[$_size>>0] = $395;
     $396 = ($393|0)==(0);
     if (!($396)) {
      $i$01$i29 = 0;
      while(1) {
       $397 = (($aInd) + ($i$01$i29<<2)|0);
       $398 = HEAP32[$397>>2]|0;
       $399 = $398&255;
       $400 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$400>>0] = $399;
       $401 = (($bInd) + ($i$01$i29<<2)|0);
       $402 = HEAP32[$401>>2]|0;
       $403 = $402&255;
       $404 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$404>>0] = $403;
       $405 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($405|0)==($393|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $405;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $406;
    HEAPF32[$18>>2] = $407;
    HEAPF32[$19>>2] = $408;
    HEAPF32[$20>>2] = $409;
    HEAPF32[$closB>>2] = $410;
    HEAPF32[$21>>2] = $411;
    HEAPF32[$22>>2] = $412;
    HEAPF32[$23>>2] = $413;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $414 = Math_fround($406 - $410);
    $415 = Math_fround($407 - $411);
    $416 = Math_fround($408 - $412);
    HEAPF32[$v>>2] = $414;
    $417 = (($v) + 4|0);
    HEAPF32[$417>>2] = $415;
    $418 = (($v) + 8|0);
    HEAPF32[$418>>2] = $416;
    $419 = (($v) + 12|0);
    HEAPF32[$419>>2] = Math_fround(0.0);
    $420 = (Math_fround(Math_sqrt((Math_fround($270)))));
    $421 = Math_fround(Math_fround(1.0) / $420);
    $422 = Math_fround($414 * $421);
    $423 = Math_fround($415 * $421);
    $424 = Math_fround($416 * $421);
    $425 = Math_fround($7 * $422);
    $426 = Math_fround($7 * $423);
    $427 = Math_fround($7 * $424);
    $428 = Math_fround($406 - $425);
    $429 = Math_fround($407 - $426);
    $430 = Math_fround($408 - $427);
    HEAPF32[$contactA>>2] = $428;
    $431 = (($contactA) + 4|0);
    HEAPF32[$431>>2] = $429;
    $432 = (($contactA) + 8|0);
    HEAPF32[$432>>2] = $430;
    $433 = (($contactA) + 12|0);
    HEAPF32[$433>>2] = Math_fround(0.0);
    $434 = Math_fround($9 * $422);
    $435 = Math_fround($9 * $423);
    $436 = Math_fround($9 * $424);
    $437 = Math_fround($434 + $410);
    $438 = Math_fround($435 + $411);
    $439 = Math_fround($436 + $412);
    HEAPF32[$contactB>>2] = $437;
    $440 = (($contactB) + 4|0);
    HEAPF32[$440>>2] = $438;
    $441 = (($contactB) + 8|0);
    HEAPF32[$441>>2] = $439;
    $442 = (($contactB) + 12|0);
    HEAPF32[$442>>2] = Math_fround(0.0);
    $443 = Math_fround($420 - $17);
    HEAPF32[$penetrationDepth>>2] = $443;
    $444 = (($penetrationDepth) + 4|0);
    ;HEAP32[$444+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$444+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$444+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $422;
    $445 = (($normal) + 4|0);
    HEAPF32[$445>>2] = $423;
    $446 = (($normal) + 8|0);
    HEAPF32[$446>>2] = $424;
    $447 = (($normal) + 12|0);
    HEAPF32[$447>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $288 = ($aIndices|0)==(0|0);
   if (!($288)) {
    $289 = $260&255;
    HEAP8[$_size>>0] = $289;
    $290 = ($260|0)==(0);
    if (!($290)) {
     $i$01$i72 = 0;
     while(1) {
      $291 = (($aInd) + ($i$01$i72<<2)|0);
      $292 = HEAP32[$291>>2]|0;
      $293 = $292&255;
      $294 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$294>>0] = $293;
      $295 = (($bInd) + ($i$01$i72<<2)|0);
      $296 = HEAP32[$295>>2]|0;
      $297 = $296&255;
      $298 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$298>>0] = $297;
      $299 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($299|0)==($260|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $299;
      }
     }
    }
   }
   $not$ = $285 ^ 1;
   $$$747 = $287 & $not$;
   if (!($$$747)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $300 = (Math_fround(Math_sqrt((Math_fround($270)))));
   $301 = Math_fround(Math_fround(1.0) / $300);
   $302 = Math_fround($271 * $301);
   $303 = Math_fround($272 * $301);
   $304 = Math_fround($273 * $301);
   $305 = Math_fround(HEAPF32[$closA>>2]);
   $306 = Math_fround(HEAPF32[$18>>2]);
   $307 = Math_fround(HEAPF32[$19>>2]);
   $308 = Math_fround($7 * $302);
   $309 = Math_fround($7 * $303);
   $310 = Math_fround($7 * $304);
   $311 = Math_fround($305 - $308);
   $312 = Math_fround($306 - $309);
   $313 = Math_fround($307 - $310);
   HEAPF32[$contactA>>2] = $311;
   $314 = (($contactA) + 4|0);
   HEAPF32[$314>>2] = $312;
   $315 = (($contactA) + 8|0);
   HEAPF32[$315>>2] = $313;
   $316 = (($contactA) + 12|0);
   HEAPF32[$316>>2] = Math_fround(0.0);
   $317 = Math_fround(HEAPF32[$closB>>2]);
   $318 = Math_fround(HEAPF32[$21>>2]);
   $319 = Math_fround(HEAPF32[$22>>2]);
   $320 = Math_fround($9 * $302);
   $321 = Math_fround($9 * $303);
   $322 = Math_fround($9 * $304);
   $323 = Math_fround($320 + $317);
   $324 = Math_fround($321 + $318);
   $325 = Math_fround($322 + $319);
   HEAPF32[$contactB>>2] = $323;
   $326 = (($contactB) + 4|0);
   HEAPF32[$326>>2] = $324;
   $327 = (($contactB) + 8|0);
   HEAPF32[$327>>2] = $325;
   $328 = (($contactB) + 12|0);
   HEAPF32[$328>>2] = Math_fround(0.0);
   $329 = Math_fround($300 - $17);
   HEAPF32[$penetrationDepth>>2] = $329;
   $330 = (($penetrationDepth) + 4|0);
   ;HEAP32[$330+0>>2]=HEAP32[$$sroa$1234+0>>2]|0;HEAP32[$330+4>>2]=HEAP32[$$sroa$1234+4>>2]|0;HEAP32[$330+8>>2]=HEAP32[$$sroa$1234+8>>2]|0;
   HEAPF32[$normal>>2] = $302;
   $331 = (($normal) + 4|0);
   HEAPF32[$331>>2] = $303;
   $332 = (($normal) + 8|0);
   HEAPF32[$332>>2] = $304;
   $333 = (($normal) + 12|0);
   HEAPF32[$333>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $214 = HEAP32[$size>>2]|0;
   $450 = $214;
  }
 } while(0);
 $448 = ($aIndices|0)==(0|0);
 if (!($448)) {
  $449 = $450&255;
  HEAP8[$_size>>0] = $449;
  $451 = ($450|0)==(0);
  if (!($451)) {
   $i$01$i = 0;
   while(1) {
    $452 = (($aInd) + ($i$01$i<<2)|0);
    $453 = HEAP32[$452>>2]|0;
    $454 = $453&255;
    $455 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$455>>0] = $454;
    $456 = (($bInd) + ($i$01$i<<2)|0);
    $457 = HEAP32[$456>>2]|0;
    $458 = $457&255;
    $459 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$459>>0] = $458;
    $460 = (($i$01$i) + 1)|0;
    $exitcond$i = ($460|0)==($450|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $460;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_24ShrunkConvexHullNoScaleVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$747 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i170 = Math_fround(0), $$$i134 = Math_fround(0), $$$i169 = Math_fround(0), $$$i735799 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i171 = Math_fround(0), $$0 = 0, $$0$i$i = 0, $$743 = 0, $$in1$i = 0, $$in2$i = 0, $$ph = Math_fround(0), $$ph755 = Math_fround(0), $$ph756 = Math_fround(0), $$ph757 = Math_fround(0), $$ph758 = Math_fround(0), $$ph759 = Math_fround(0);
 var $$ph760 = Math_fround(0), $$ph761 = Math_fround(0), $$ph763 = Math_fround(0), $$ph764 = 0, $$pre = Math_fround(0), $$pre838 = Math_fround(0), $$pre839 = Math_fround(0), $$pre840 = Math_fround(0), $$pre841 = Math_fround(0), $$pre842 = Math_fround(0), $$pre843 = Math_fround(0), $$pre844 = Math_fround(0), $$pre845 = Math_fround(0), $$pre846 = Math_fround(0), $$pre847 = Math_fround(0), $$sroa$1 = 0, $$sroa$1232 = 0, $$sroa$1234 = 0, $$sum$i$i$i = 0, $0 = 0;
 var $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0;
 var $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0);
 var $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0;
 var $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0);
 var $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0;
 var $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0);
 var $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0);
 var $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0);
 var $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0);
 var $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0, $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0);
 var $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0);
 var $405 = Math_fround(0), $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0);
 var $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = 0, $474 = 0, $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0);
 var $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = 0, $482 = 0, $483 = 0, $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $aInd = 0, $b$a$i = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$041$i$i$i = 0;
 var $i$0809 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $maxIndex$040$i$i$i = 0, $maxIndex$1$i$i$i = 0, $minDist$sroa$1 = 0, $not$ = 0, $nv = 0, $phitmp751 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 176|0;
 $1 = sp + 256|0;
 $closA = sp + 416|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 448|0;
 $minDist$sroa$1 = sp + 460|0;
 $v = sp + 432|0;
 $Q = sp + 192|0;
 $A = sp + 336|0;
 $B = sp + 272|0;
 $aInd = sp + 512|0;
 $bInd = sp + 528|0;
 $size = sp + 544|0;
 $lastQ = sp + 160|0;
 $lastA = sp + 64|0;
 $lastB = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = sp + 48|0;
 $nv = sp + 80|0;
 $supportA1 = sp + 96|0;
 $supportB2 = sp + 112|0;
 $support3 = sp + 128|0;
 $$sroa$1234 = sp + 472|0;
 $5 = sp + 144|0;
 $$sroa$1232 = sp + 484|0;
 $$sroa$1 = sp + 496|0;
 $6 = (($a) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($b) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$_contactDist>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i169 = $15 ? $14 : $12;
 $16 = Math_fround($$$i169 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($7 + $9);
 $18 = (($closA) + 4|0);
 $19 = (($closA) + 8|0);
 $20 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $21 = (($closB) + 4|0);
 $22 = (($closB) + 8|0);
 $23 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $24 = Math_fround($16 * $16);
 HEAP32[$size>>2] = 0;
 $25 = HEAP8[$_size>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $188 = (($aToB) + 48|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = (($aToB) + 52|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = (($aToB) + 56|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($aToB) + 60|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($189 * $189);
  $197 = Math_fround($191 * $191);
  $198 = Math_fround($196 + $197);
  $199 = Math_fround($193 * $193);
  $200 = Math_fround($198 + $199);
  $201 = $200 > Math_fround(0.0);
  HEAPF32[$1>>2] = $189;
  $202 = (($1) + 4|0);
  HEAPF32[$202>>2] = $191;
  $203 = (($1) + 8|0);
  HEAPF32[$203>>2] = $193;
  $204 = (($1) + 12|0);
  HEAPF32[$204>>2] = $195;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $205 = (($0) + 4|0);
  HEAPF32[$205>>2] = Math_fround(0.0);
  $206 = (($0) + 8|0);
  HEAPF32[$206>>2] = Math_fround(0.0);
  $207 = (($0) + 12|0);
  HEAPF32[$207>>2] = Math_fround(0.0);
  $b$a$i = $201 ? $1 : $0;
  $208 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $209 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $210 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $208;
  $211 = (($v) + 4|0);
  HEAPF32[$211>>2] = $209;
  $212 = (($v) + 8|0);
  HEAPF32[$212>>2] = $210;
  $213 = (($v) + 12|0);
  HEAPF32[$213>>2] = Math_fround(0.0);
  $$ph = Math_fround(0.0);$$ph755 = Math_fround(0.0);$$ph756 = Math_fround(0.0);$$ph757 = Math_fround(0.0);$$ph758 = Math_fround(0.0);$$ph759 = Math_fround(0.0);$$ph760 = Math_fround(0.0);$$ph761 = Math_fround(0.0);$$ph763 = Math_fround(3.40282346638528859812E+38);$$ph764 = 1;$502 = $210;$503 = $209;$504 = $208;
 } else {
  $27 = (($lastQ) + 4|0);
  $28 = (($lastQ) + 8|0);
  $29 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $30 = (($lastA) + 4|0);
  $31 = (($lastA) + 8|0);
  $32 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $33 = (($lastB) + 4|0);
  $34 = (($lastB) + 8|0);
  $35 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $36 = (($a) + 16|0);
  $37 = (($aToB) + 48|0);
  $38 = (($aToB) + 52|0);
  $39 = (($aToB) + 56|0);
  $40 = (($2) + 4|0);
  $41 = (($2) + 8|0);
  $42 = (($aToB) + 16|0);
  $43 = (($aToB) + 32|0);
  $44 = (($aToB) + 4|0);
  $45 = (($aToB) + 20|0);
  $46 = (($aToB) + 36|0);
  $47 = (($aToB) + 8|0);
  $48 = (($aToB) + 24|0);
  $49 = (($aToB) + 40|0);
  $50 = (($b) + 16|0);
  $51 = (($3) + 4|0);
  $52 = (($3) + 8|0);
  $53 = (($3) + 12|0);
  $i$0809 = 0;
  while(1) {
   $54 = (($aIndices) + ($i$0809)|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55&255;
   $57 = (($aInd) + ($i$0809<<2)|0);
   HEAP32[$57>>2] = $56;
   $58 = (($bIndices) + ($i$0809)|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = $59&255;
   $61 = (($bInd) + ($i$0809<<2)|0);
   HEAP32[$61>>2] = $60;
   __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($2,$a,$56,$36);
   $62 = Math_fround(HEAPF32[$37>>2]);
   $63 = Math_fround(HEAPF32[$38>>2]);
   $64 = Math_fround(HEAPF32[$39>>2]);
   $65 = Math_fround(HEAPF32[$2>>2]);
   $66 = Math_fround(HEAPF32[$40>>2]);
   $67 = Math_fround(HEAPF32[$41>>2]);
   $68 = Math_fround(HEAPF32[$aToB>>2]);
   $69 = Math_fround($65 * $68);
   $70 = Math_fround(HEAPF32[$42>>2]);
   $71 = Math_fround($66 * $70);
   $72 = Math_fround($69 + $71);
   $73 = Math_fround(HEAPF32[$43>>2]);
   $74 = Math_fround($67 * $73);
   $75 = Math_fround($72 + $74);
   $76 = Math_fround(HEAPF32[$44>>2]);
   $77 = Math_fround($65 * $76);
   $78 = Math_fround(HEAPF32[$45>>2]);
   $79 = Math_fround($66 * $78);
   $80 = Math_fround($77 + $79);
   $81 = Math_fround(HEAPF32[$46>>2]);
   $82 = Math_fround($67 * $81);
   $83 = Math_fround($80 + $82);
   $84 = Math_fround(HEAPF32[$47>>2]);
   $85 = Math_fround($65 * $84);
   $86 = Math_fround(HEAPF32[$48>>2]);
   $87 = Math_fround($66 * $86);
   $88 = Math_fround($85 + $87);
   $89 = Math_fround(HEAPF32[$49>>2]);
   $90 = Math_fround($67 * $89);
   $91 = Math_fround($88 + $90);
   $92 = Math_fround($62 + $75);
   $93 = Math_fround($63 + $83);
   $94 = Math_fround($64 + $91);
   __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($3,$b,$60,$50);
   $95 = Math_fround(HEAPF32[$3>>2]);
   $96 = Math_fround(HEAPF32[$51>>2]);
   $97 = Math_fround(HEAPF32[$52>>2]);
   $98 = Math_fround(HEAPF32[$53>>2]);
   $99 = Math_fround($92 - $95);
   $100 = Math_fround($93 - $96);
   $101 = Math_fround($94 - $97);
   $102 = HEAP32[$size>>2]|0;
   $103 = (($A) + ($102<<4)|0);
   HEAPF32[$lastA>>2] = $92;
   HEAPF32[$30>>2] = $93;
   HEAPF32[$31>>2] = $94;
   HEAPF32[$32>>2] = Math_fround(0.0);
   ;HEAP32[$103+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$lastA+12>>2]|0;
   $104 = (($B) + ($102<<4)|0);
   HEAPF32[$lastB>>2] = $95;
   HEAPF32[$33>>2] = $96;
   HEAPF32[$34>>2] = $97;
   HEAPF32[$35>>2] = $98;
   ;HEAP32[$104+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$104+12>>2]=HEAP32[$lastB+12>>2]|0;
   $105 = (($102) + 1)|0;
   HEAP32[$size>>2] = $105;
   $106 = (($Q) + ($102<<4)|0);
   HEAPF32[$lastQ>>2] = $99;
   HEAPF32[$27>>2] = $100;
   HEAPF32[$28>>2] = $101;
   HEAPF32[$29>>2] = Math_fround(0.0);
   ;HEAP32[$106+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $107 = (($i$0809) + 1)|0;
   $108 = HEAP8[$_size>>0]|0;
   $109 = $108&255;
   $110 = ($107>>>0)<($109>>>0);
   if ($110) {
    $i$0809 = $107;
   } else {
    break;
   }
  }
  do {
   if ((($102|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($102|0) == 1)) {
    $111 = Math_fround(HEAPF32[$Q>>2]);
    $112 = (($Q) + 4|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = (($Q) + 8|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = Math_fround($99 - $111);
    $117 = Math_fround($100 - $113);
    $118 = Math_fround($101 - $115);
    $119 = Math_fround($116 * $116);
    $120 = Math_fround($117 * $117);
    $121 = Math_fround($119 + $120);
    $122 = Math_fround($118 * $118);
    $123 = Math_fround($121 + $122);
    $124 = $123 == Math_fround(0.0);
    if ($124) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $125 = Math_fround($113 * $117);
     $126 = Math_fround(-$125);
     $127 = Math_fround($111 * $116);
     $128 = Math_fround($126 - $127);
     $129 = Math_fround($115 * $118);
     $130 = Math_fround($128 - $129);
     $131 = Math_fround(HEAPF32[$A>>2]);
     $132 = (($A) + 4|0);
     $133 = Math_fround(HEAPF32[$132>>2]);
     $134 = (($A) + 8|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     $136 = Math_fround($92 - $131);
     $137 = Math_fround($93 - $133);
     $138 = Math_fround($94 - $135);
     $139 = Math_fround(HEAPF32[$B>>2]);
     $140 = (($B) + 4|0);
     $141 = Math_fround(HEAPF32[$140>>2]);
     $142 = (($B) + 8|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = Math_fround($95 - $139);
     $145 = Math_fround($96 - $141);
     $146 = Math_fround($97 - $143);
     $147 = Math_fround($130 / $123);
     $148 = $147 > Math_fround(1.0);
     $$$i$i$i170 = $148 ? Math_fround(1.0) : $147;
     $149 = $$$i$i$i170 > Math_fround(0.0);
     $$$i8$i$i171 = $149 ? $$$i$i$i170 : Math_fround(0.0);
     $150 = Math_fround($136 * $$$i8$i$i171);
     $151 = Math_fround($137 * $$$i8$i$i171);
     $152 = Math_fround($138 * $$$i8$i$i171);
     $153 = Math_fround($131 + $150);
     $154 = Math_fround($133 + $151);
     $155 = Math_fround($135 + $152);
     $156 = Math_fround($144 * $$$i8$i$i171);
     $157 = Math_fround($145 * $$$i8$i$i171);
     $158 = Math_fround($146 * $$$i8$i$i171);
     $159 = Math_fround($139 + $156);
     $160 = Math_fround($141 + $157);
     $161 = Math_fround($143 + $158);
     HEAPF32[$closA>>2] = $153;
     HEAPF32[$18>>2] = $154;
     HEAPF32[$19>>2] = $155;
     HEAPF32[$20>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $159;
     HEAPF32[$21>>2] = $160;
     HEAPF32[$22>>2] = $161;
     HEAPF32[$23>>2] = Math_fround(0.0);
     $162 = Math_fround($153 - $159);
     $163 = Math_fround($154 - $160);
     $164 = Math_fround($155 - $161);
     HEAPF32[$4>>2] = $162;
     $165 = (($4) + 4|0);
     HEAPF32[$165>>2] = $163;
     $166 = (($4) + 8|0);
     HEAPF32[$166>>2] = $164;
     $167 = (($4) + 12|0);
     HEAPF32[$167>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($102|0) == 2)) {
    $168 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$168,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($102|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$4+12>>2]|0;
  $169 = Math_fround(HEAPF32[$v>>2]);
  $170 = (($v) + 4|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = (($v) + 8|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($169 * $169);
  $175 = Math_fround($171 * $171);
  $176 = Math_fround($174 + $175);
  $177 = Math_fround($173 * $173);
  $178 = Math_fround($176 + $177);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $179 = Math_fround(HEAPF32[$closA>>2]);
  $180 = Math_fround(HEAPF32[$18>>2]);
  $181 = Math_fround(HEAPF32[$19>>2]);
  $182 = Math_fround(HEAPF32[$20>>2]);
  $183 = Math_fround(HEAPF32[$closB>>2]);
  $184 = Math_fround(HEAPF32[$21>>2]);
  $185 = Math_fround(HEAPF32[$22>>2]);
  $186 = Math_fround(HEAPF32[$23>>2]);
  $187 = $178 > $24;
  $$ph = $182;$$ph755 = $181;$$ph756 = $180;$$ph757 = $179;$$ph758 = $186;$$ph759 = $185;$$ph760 = $184;$$ph761 = $183;$$ph763 = $178;$$ph764 = $187;$502 = $173;$503 = $171;$504 = $169;
 }
 do {
  if ($$ph764) {
   $215 = (($v) + 4|0);
   $216 = (($v) + 8|0);
   $217 = (($nv) + 4|0);
   $218 = (($nv) + 8|0);
   $219 = (($nv) + 12|0);
   $220 = (($b) + 196|0);
   $221 = (($b) + 200|0);
   $222 = (($b) + 204|0);
   $223 = (($b) + 16|0);
   $224 = (($supportA1) + 4|0);
   $225 = (($supportA1) + 8|0);
   $226 = (($supportB2) + 4|0);
   $227 = (($supportB2) + 8|0);
   $228 = (($support3) + 4|0);
   $229 = (($support3) + 8|0);
   $230 = (($support3) + 12|0);
   $231 = (($a) + 48|0);
   $232 = (($b) + 48|0);
   $233 = (($Q) + 4|0);
   $234 = (($Q) + 8|0);
   $235 = (($A) + 4|0);
   $236 = (($A) + 8|0);
   $237 = (($B) + 4|0);
   $238 = (($B) + 8|0);
   $239 = (($5) + 4|0);
   $240 = (($5) + 8|0);
   $241 = (($5) + 12|0);
   $242 = (($Q) + 16|0);
   $$$i735799 = $10;$244 = $504;$246 = $503;$248 = $502;$311 = $$ph763;$447 = $$ph757;$448 = $$ph756;$449 = $$ph755;$450 = $$ph;$451 = $$ph761;$452 = $$ph760;$453 = $$ph759;$454 = $$ph758;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $243 = Math_fround(-$244);
    $245 = Math_fround(-$246);
    $247 = Math_fround(-$248);
    HEAPF32[$nv>>2] = $243;
    HEAPF32[$217>>2] = $245;
    HEAPF32[$218>>2] = $247;
    HEAPF32[$219>>2] = Math_fround(0.0);
    $249 = HEAP32[$size>>2]|0;
    $250 = (($A) + ($249<<4)|0);
    $251 = (($aInd) + ($249<<2)|0);
    __ZNK5physx2Gu24ShrunkConvexHullNoScaleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVERS4_Ri($supportA1,$a,$nv,$aToB,$250,$251);
    $252 = HEAP32[$size>>2]|0;
    $253 = (($B) + ($252<<4)|0);
    $254 = (($bInd) + ($252<<2)|0);
    $255 = HEAP32[$220>>2]|0;
    $256 = ($255|0)==(0|0);
    if ($256) {
     $258 = HEAP32[$221>>2]|0;
     $259 = HEAP8[$222>>0]|0;
     $260 = ($259&255)>(1);
     if ($260) {
      $261 = (($258) + 4|0);
      $262 = (($258) + 8|0);
      $263 = Math_fround(HEAPF32[$261>>2]);
      $264 = Math_fround(HEAPF32[$258>>2]);
      $265 = Math_fround($246 * $263);
      $266 = Math_fround($244 * $264);
      $267 = Math_fround(HEAPF32[$262>>2]);
      $268 = Math_fround($248 * $267);
      $269 = Math_fround($265 + $266);
      $270 = Math_fround($269 + $268);
      $272 = $258;$286 = $270;$i$041$i$i$i = 1;$maxIndex$040$i$i$i = 0;
      while(1) {
       $$sum$i$i$i = (($i$041$i$i$i) + 10)|0;
       $271 = ((($272) + (($$sum$i$i$i*12)|0)|0) + 8|0);
       $273 = HEAP32[$221>>2]|0;
       $274 = (($273) + (($i$041$i$i$i*12)|0)|0);
       $275 = Math_fround(HEAPF32[$274>>2]);
       $276 = ((($273) + (($i$041$i$i$i*12)|0)|0) + 4|0);
       $277 = Math_fround(HEAPF32[$276>>2]);
       $278 = ((($273) + (($i$041$i$i$i*12)|0)|0) + 8|0);
       $279 = Math_fround(HEAPF32[$278>>2]);
       $280 = Math_fround($275 * $244);
       $281 = Math_fround($277 * $246);
       $282 = Math_fround($280 + $281);
       $283 = Math_fround($279 * $248);
       $284 = Math_fround($282 + $283);
       $285 = $284 > $286;
       $287 = $285 ? $284 : $286;
       $maxIndex$1$i$i$i = $285 ? $i$041$i$i$i : $maxIndex$040$i$i$i;
       $288 = (($i$041$i$i$i) + 1)|0;
       $289 = HEAP8[$222>>0]|0;
       $290 = $289&255;
       $291 = ($288>>>0)<($290>>>0);
       if ($291) {
        $272 = $273;$286 = $287;$i$041$i$i$i = $288;$maxIndex$040$i$i$i = $maxIndex$1$i$i$i;
       } else {
        $$0$i$i = $maxIndex$1$i$i$i;$313 = $244;$315 = $246;$318 = $248;
        break;
       }
      }
     } else {
      $$0$i$i = 0;$313 = $244;$315 = $246;$318 = $248;
     }
    } else {
     $257 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($b,$v)|0);
     $$pre = Math_fround(HEAPF32[$v>>2]);
     $$pre838 = Math_fround(HEAPF32[$215>>2]);
     $$pre839 = Math_fround(HEAPF32[$216>>2]);
     $$0$i$i = $257;$313 = $$pre;$315 = $$pre838;$318 = $$pre839;
    }
    HEAP32[$254>>2] = $$0$i$i;
    __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($supportB2,$b,$$0$i$i,$223);
    ;HEAP32[$253+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$253+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$253+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$253+12>>2]=HEAP32[$supportB2+12>>2]|0;
    $292 = Math_fround(HEAPF32[$supportA1>>2]);
    $293 = Math_fround(HEAPF32[$224>>2]);
    $294 = Math_fround(HEAPF32[$225>>2]);
    $295 = Math_fround(HEAPF32[$supportB2>>2]);
    $296 = Math_fround(HEAPF32[$226>>2]);
    $297 = Math_fround(HEAPF32[$227>>2]);
    $298 = Math_fround($292 - $295);
    $299 = Math_fround($293 - $296);
    $300 = Math_fround($294 - $297);
    HEAPF32[$support3>>2] = $298;
    HEAPF32[$228>>2] = $299;
    HEAPF32[$229>>2] = $300;
    HEAPF32[$230>>2] = Math_fround(0.0);
    $301 = HEAP32[$size>>2]|0;
    $302 = (($301) + 1)|0;
    HEAP32[$size>>2] = $302;
    $303 = (($Q) + ($301<<4)|0);
    ;HEAP32[$303+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$303+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$303+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$303+12>>2]=HEAP32[$support3+12>>2]|0;
    $304 = Math_fround(HEAPF32[$231>>2]);
    $305 = Math_fround(HEAPF32[$232>>2]);
    $306 = $304 > $305;
    $$$i134 = $306 ? $304 : $305;
    $307 = $$$i735799 > $$$i134;
    $$$i = $307 ? $$$i735799 : $$$i134;
    $308 = Math_fround($17 + $$$i);
    $309 = Math_fround($308 * $308);
    $310 = Math_fround($311 * $309);
    $312 = Math_fround($313 * $298);
    $314 = Math_fround($315 * $299);
    $316 = Math_fround($312 + $314);
    $317 = Math_fround($318 * $300);
    $319 = Math_fround($316 + $317);
    $320 = Math_fround($319 * $319);
    $321 = $319 > Math_fround(0.0);
    $322 = $320 > $310;
    if ($321) {
     $phitmp751 = $322 ^ 1;
     $326 = $322;$328 = $phitmp751;
    } else {
     $326 = 0;$328 = 1;
    }
    $323 = Math_fround($311 - $319);
    $324 = Math_fround($24 * $311);
    $325 = $324 >= $323;
    $brmerge$demorgan = $325 | $326;
    if ($brmerge$demorgan) {
     $327 = $328 ^ 1;
     $$743 = $325 | $327;
     if ($$743) {
      break;
     }
    }
    do {
     if ((($301|0) == 1)) {
      $375 = Math_fround(HEAPF32[$Q>>2]);
      $376 = Math_fround(HEAPF32[$233>>2]);
      $377 = Math_fround(HEAPF32[$234>>2]);
      $378 = Math_fround($298 - $375);
      $379 = Math_fround($299 - $376);
      $380 = Math_fround($300 - $377);
      $381 = Math_fround($378 * $378);
      $382 = Math_fround($379 * $379);
      $383 = Math_fround($381 + $382);
      $384 = Math_fround($380 * $380);
      $385 = Math_fround($383 + $384);
      $386 = $385 == Math_fround(0.0);
      if ($386) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $387 = Math_fround($376 * $379);
       $388 = Math_fround(-$387);
       $389 = Math_fround($375 * $378);
       $390 = Math_fround($388 - $389);
       $391 = Math_fround($377 * $380);
       $392 = Math_fround($390 - $391);
       $393 = Math_fround(HEAPF32[$A>>2]);
       $394 = Math_fround(HEAPF32[$235>>2]);
       $395 = Math_fround(HEAPF32[$236>>2]);
       $396 = Math_fround($292 - $393);
       $397 = Math_fround($293 - $394);
       $398 = Math_fround($294 - $395);
       $399 = Math_fround(HEAPF32[$B>>2]);
       $400 = Math_fround(HEAPF32[$237>>2]);
       $401 = Math_fround(HEAPF32[$238>>2]);
       $402 = Math_fround($295 - $399);
       $403 = Math_fround($296 - $400);
       $404 = Math_fround($297 - $401);
       $405 = Math_fround($392 / $385);
       $406 = $405 > Math_fround(1.0);
       $$$i$i$i = $406 ? Math_fround(1.0) : $405;
       $407 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $407 ? $$$i$i$i : Math_fround(0.0);
       $408 = Math_fround($396 * $$$i8$i$i);
       $409 = Math_fround($397 * $$$i8$i$i);
       $410 = Math_fround($398 * $$$i8$i$i);
       $411 = Math_fround($393 + $408);
       $412 = Math_fround($394 + $409);
       $413 = Math_fround($395 + $410);
       $414 = Math_fround($402 * $$$i8$i$i);
       $415 = Math_fround($403 * $$$i8$i$i);
       $416 = Math_fround($404 * $$$i8$i$i);
       $417 = Math_fround($399 + $414);
       $418 = Math_fround($400 + $415);
       $419 = Math_fround($401 + $416);
       HEAPF32[$closA>>2] = $411;
       HEAPF32[$18>>2] = $412;
       HEAPF32[$19>>2] = $413;
       HEAPF32[$20>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $417;
       HEAPF32[$21>>2] = $418;
       HEAPF32[$22>>2] = $419;
       HEAPF32[$23>>2] = Math_fround(0.0);
       $420 = Math_fround($411 - $417);
       $421 = Math_fround($412 - $418);
       $422 = Math_fround($413 - $419);
       HEAPF32[$5>>2] = $420;
       HEAPF32[$239>>2] = $421;
       HEAPF32[$240>>2] = $422;
       HEAPF32[$241>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($301|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($301|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($301|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$242,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
    $423 = Math_fround(HEAPF32[$v>>2]);
    $424 = Math_fround(HEAPF32[$215>>2]);
    $425 = Math_fround(HEAPF32[$216>>2]);
    $426 = Math_fround($423 * $423);
    $427 = Math_fround($424 * $424);
    $428 = Math_fround($426 + $427);
    $429 = Math_fround($425 * $425);
    $430 = Math_fround($428 + $429);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1232+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1232+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1232+8>>2]|0;
    $431 = $311 > $430;
    $432 = $430 > $24;
    if (!($432)) {
     label = 42;
     break;
    }
    if (!($431)) {
     label = 42;
     break;
    }
    $$pre840 = Math_fround(HEAPF32[$closA>>2]);
    $$pre841 = Math_fround(HEAPF32[$18>>2]);
    $$pre842 = Math_fround(HEAPF32[$19>>2]);
    $$pre843 = Math_fround(HEAPF32[$20>>2]);
    $$pre844 = Math_fround(HEAPF32[$closB>>2]);
    $$pre845 = Math_fround(HEAPF32[$21>>2]);
    $$pre846 = Math_fround(HEAPF32[$22>>2]);
    $$pre847 = Math_fround(HEAPF32[$23>>2]);
    $$$i735799 = $$$i;$244 = $423;$246 = $424;$248 = $425;$311 = $430;$447 = $$pre840;$448 = $$pre841;$449 = $$pre842;$450 = $$pre843;$451 = $$pre844;$452 = $$pre845;$453 = $$pre846;$454 = $$pre847;
   }
   if ((label|0) == 42) {
    $433 = HEAP32[$size>>2]|0;
    if ($431) {
     $491 = $433;
     break;
    }
    $434 = (($433) + -1)|0;
    $435 = ($aIndices|0)==(0|0);
    if (!($435)) {
     $436 = $434&255;
     HEAP8[$_size>>0] = $436;
     $437 = ($434|0)==(0);
     if (!($437)) {
      $i$01$i29 = 0;
      while(1) {
       $438 = (($aInd) + ($i$01$i29<<2)|0);
       $439 = HEAP32[$438>>2]|0;
       $440 = $439&255;
       $441 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$441>>0] = $440;
       $442 = (($bInd) + ($i$01$i29<<2)|0);
       $443 = HEAP32[$442>>2]|0;
       $444 = $443&255;
       $445 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$445>>0] = $444;
       $446 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($446|0)==($434|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $446;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $447;
    HEAPF32[$18>>2] = $448;
    HEAPF32[$19>>2] = $449;
    HEAPF32[$20>>2] = $450;
    HEAPF32[$closB>>2] = $451;
    HEAPF32[$21>>2] = $452;
    HEAPF32[$22>>2] = $453;
    HEAPF32[$23>>2] = $454;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $455 = Math_fround($447 - $451);
    $456 = Math_fround($448 - $452);
    $457 = Math_fround($449 - $453);
    HEAPF32[$v>>2] = $455;
    $458 = (($v) + 4|0);
    HEAPF32[$458>>2] = $456;
    $459 = (($v) + 8|0);
    HEAPF32[$459>>2] = $457;
    $460 = (($v) + 12|0);
    HEAPF32[$460>>2] = Math_fround(0.0);
    $461 = (Math_fround(Math_sqrt((Math_fround($311)))));
    $462 = Math_fround(Math_fround(1.0) / $461);
    $463 = Math_fround($455 * $462);
    $464 = Math_fround($456 * $462);
    $465 = Math_fround($457 * $462);
    $466 = Math_fround($7 * $463);
    $467 = Math_fround($7 * $464);
    $468 = Math_fround($7 * $465);
    $469 = Math_fround($447 - $466);
    $470 = Math_fround($448 - $467);
    $471 = Math_fround($449 - $468);
    HEAPF32[$contactA>>2] = $469;
    $472 = (($contactA) + 4|0);
    HEAPF32[$472>>2] = $470;
    $473 = (($contactA) + 8|0);
    HEAPF32[$473>>2] = $471;
    $474 = (($contactA) + 12|0);
    HEAPF32[$474>>2] = Math_fround(0.0);
    $475 = Math_fround($9 * $463);
    $476 = Math_fround($9 * $464);
    $477 = Math_fround($9 * $465);
    $478 = Math_fround($475 + $451);
    $479 = Math_fround($476 + $452);
    $480 = Math_fround($477 + $453);
    HEAPF32[$contactB>>2] = $478;
    $481 = (($contactB) + 4|0);
    HEAPF32[$481>>2] = $479;
    $482 = (($contactB) + 8|0);
    HEAPF32[$482>>2] = $480;
    $483 = (($contactB) + 12|0);
    HEAPF32[$483>>2] = Math_fround(0.0);
    $484 = Math_fround($461 - $17);
    HEAPF32[$penetrationDepth>>2] = $484;
    $485 = (($penetrationDepth) + 4|0);
    ;HEAP32[$485+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$485+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$485+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $463;
    $486 = (($normal) + 4|0);
    HEAPF32[$486>>2] = $464;
    $487 = (($normal) + 8|0);
    HEAPF32[$487>>2] = $465;
    $488 = (($normal) + 12|0);
    HEAPF32[$488>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $329 = ($aIndices|0)==(0|0);
   if (!($329)) {
    $330 = $301&255;
    HEAP8[$_size>>0] = $330;
    $331 = ($301|0)==(0);
    if (!($331)) {
     $i$01$i72 = 0;
     while(1) {
      $332 = (($aInd) + ($i$01$i72<<2)|0);
      $333 = HEAP32[$332>>2]|0;
      $334 = $333&255;
      $335 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$335>>0] = $334;
      $336 = (($bInd) + ($i$01$i72<<2)|0);
      $337 = HEAP32[$336>>2]|0;
      $338 = $337&255;
      $339 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$339>>0] = $338;
      $340 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($340|0)==($301|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $340;
      }
     }
    }
   }
   $not$ = $326 ^ 1;
   $$$747 = $328 & $not$;
   if (!($$$747)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $341 = (Math_fround(Math_sqrt((Math_fround($311)))));
   $342 = Math_fround(Math_fround(1.0) / $341);
   $343 = Math_fround($313 * $342);
   $344 = Math_fround($315 * $342);
   $345 = Math_fround($318 * $342);
   $346 = Math_fround(HEAPF32[$closA>>2]);
   $347 = Math_fround(HEAPF32[$18>>2]);
   $348 = Math_fround(HEAPF32[$19>>2]);
   $349 = Math_fround($7 * $343);
   $350 = Math_fround($7 * $344);
   $351 = Math_fround($7 * $345);
   $352 = Math_fround($346 - $349);
   $353 = Math_fround($347 - $350);
   $354 = Math_fround($348 - $351);
   HEAPF32[$contactA>>2] = $352;
   $355 = (($contactA) + 4|0);
   HEAPF32[$355>>2] = $353;
   $356 = (($contactA) + 8|0);
   HEAPF32[$356>>2] = $354;
   $357 = (($contactA) + 12|0);
   HEAPF32[$357>>2] = Math_fround(0.0);
   $358 = Math_fround(HEAPF32[$closB>>2]);
   $359 = Math_fround(HEAPF32[$21>>2]);
   $360 = Math_fround(HEAPF32[$22>>2]);
   $361 = Math_fround($9 * $343);
   $362 = Math_fround($9 * $344);
   $363 = Math_fround($9 * $345);
   $364 = Math_fround($361 + $358);
   $365 = Math_fround($362 + $359);
   $366 = Math_fround($363 + $360);
   HEAPF32[$contactB>>2] = $364;
   $367 = (($contactB) + 4|0);
   HEAPF32[$367>>2] = $365;
   $368 = (($contactB) + 8|0);
   HEAPF32[$368>>2] = $366;
   $369 = (($contactB) + 12|0);
   HEAPF32[$369>>2] = Math_fround(0.0);
   $370 = Math_fround($341 - $17);
   HEAPF32[$penetrationDepth>>2] = $370;
   $371 = (($penetrationDepth) + 4|0);
   ;HEAP32[$371+0>>2]=HEAP32[$$sroa$1234+0>>2]|0;HEAP32[$371+4>>2]=HEAP32[$$sroa$1234+4>>2]|0;HEAP32[$371+8>>2]=HEAP32[$$sroa$1234+8>>2]|0;
   HEAPF32[$normal>>2] = $343;
   $372 = (($normal) + 4|0);
   HEAPF32[$372>>2] = $344;
   $373 = (($normal) + 8|0);
   HEAPF32[$373>>2] = $345;
   $374 = (($normal) + 12|0);
   HEAPF32[$374>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $214 = HEAP32[$size>>2]|0;
   $491 = $214;
  }
 } while(0);
 $489 = ($aIndices|0)==(0|0);
 if (!($489)) {
  $490 = $491&255;
  HEAP8[$_size>>0] = $490;
  $492 = ($491|0)==(0);
  if (!($492)) {
   $i$01$i = 0;
   while(1) {
    $493 = (($aInd) + ($i$01$i<<2)|0);
    $494 = HEAP32[$493>>2]|0;
    $495 = $494&255;
    $496 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$496>>0] = $495;
    $497 = (($bInd) + ($i$01$i<<2)|0);
    $498 = HEAP32[$497>>2]|0;
    $499 = $498&255;
    $500 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$500>>0] = $499;
    $501 = (($i$01$i) + 1)|0;
    $exitcond$i = ($501|0)==($491|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $501;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_9TriangleVENS0_8CapsuleVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$755 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i165 = Math_fround(0), $$$i134 = Math_fround(0), $$$i188 = Math_fround(0), $$$i743813 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i166 = Math_fround(0), $$0 = 0, $$751 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$ph = Math_fround(0), $$ph763 = Math_fround(0), $$ph764 = Math_fround(0), $$ph765 = Math_fround(0), $$ph766 = Math_fround(0);
 var $$ph767 = Math_fround(0), $$ph768 = Math_fround(0), $$ph769 = Math_fround(0), $$ph771 = Math_fround(0), $$ph772 = 0, $$ph776 = Math_fround(0), $$ph777 = Math_fround(0), $$ph778 = Math_fround(0), $$pre = Math_fround(0), $$pre860 = Math_fround(0), $$pre861 = Math_fround(0), $$pre862 = Math_fround(0), $$pre863 = Math_fround(0), $$pre864 = Math_fround(0), $$pre865 = Math_fround(0), $$pre866 = Math_fround(0), $$sroa$1 = 0, $$sroa$1232 = 0, $$sroa$1234 = 0, $0 = 0;
 var $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0);
 var $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0;
 var $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0);
 var $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0;
 var $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0);
 var $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0);
 var $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0);
 var $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0);
 var $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0);
 var $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0);
 var $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0;
 var $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0);
 var $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0);
 var $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0);
 var $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0);
 var $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0);
 var $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0);
 var $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0);
 var $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0);
 var $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = 0, $524 = 0, $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0);
 var $97 = 0, $98 = Math_fround(0), $99 = 0, $A = 0, $B = 0, $Q = 0, $_dir$i = 0, $aInd = 0, $b$a$i = 0, $b$a$i$i$i = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0;
 var $i$0823 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp759 = 0, $res$i = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 368|0;
 $1 = sp + 320|0;
 $_dir$i = sp + 336|0;
 $res$i = sp + 352|0;
 $closA = sp + 384|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 484|0;
 $minDist$sroa$1 = sp + 472|0;
 $Q = sp;
 $A = sp + 144|0;
 $B = sp + 64|0;
 $aInd = sp + 456|0;
 $bInd = sp + 496|0;
 $size = sp + 416|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 208|0;
 $lastB = sp + 224|0;
 $2 = sp + 240|0;
 $supportA1 = sp + 256|0;
 $supportB2 = sp + 272|0;
 $support3 = sp + 288|0;
 $$sroa$1234 = sp + 432|0;
 $3 = sp + 304|0;
 $$sroa$1232 = sp + 444|0;
 $$sroa$1 = sp + 420|0;
 $4 = (($a) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($b) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(HEAPF32[$_contactDist>>2]);
 $9 = (($a) + 32|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($b) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = $10 > $12;
 $$$i188 = $13 ? $12 : $10;
 $14 = Math_fround($$$i188 * Math_fround(0.100000001490116119385));
 $15 = Math_fround($5 + $7);
 $16 = (($closA) + 4|0);
 $17 = (($closA) + 8|0);
 $18 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $19 = (($closB) + 4|0);
 $20 = (($closB) + 8|0);
 $21 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $22 = Math_fround($14 * $14);
 HEAP32[$size>>2] = 0;
 $23 = HEAP8[$_size>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $188 = (($aToB) + 48|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = (($aToB) + 52|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = (($aToB) + 56|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($aToB) + 60|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($189 * $189);
  $197 = Math_fround($191 * $191);
  $198 = Math_fround($196 + $197);
  $199 = Math_fround($193 * $193);
  $200 = Math_fround($198 + $199);
  $201 = $200 > Math_fround(0.0);
  HEAPF32[$1>>2] = $189;
  $202 = (($1) + 4|0);
  HEAPF32[$202>>2] = $191;
  $203 = (($1) + 8|0);
  HEAPF32[$203>>2] = $193;
  $204 = (($1) + 12|0);
  HEAPF32[$204>>2] = $195;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $205 = (($0) + 4|0);
  HEAPF32[$205>>2] = Math_fround(0.0);
  $206 = (($0) + 8|0);
  HEAPF32[$206>>2] = Math_fround(0.0);
  $207 = (($0) + 12|0);
  HEAPF32[$207>>2] = Math_fround(0.0);
  $b$a$i = $201 ? $1 : $0;
  $208 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $209 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $210 = Math_fround(HEAPF32[$$in2$i>>2]);
  $$ph = Math_fround(0.0);$$ph763 = Math_fround(0.0);$$ph764 = Math_fround(0.0);$$ph765 = Math_fround(0.0);$$ph766 = Math_fround(0.0);$$ph767 = Math_fround(0.0);$$ph768 = Math_fround(0.0);$$ph769 = Math_fround(0.0);$$ph771 = Math_fround(3.40282346638528859812E+38);$$ph772 = 1;$$ph776 = $210;$$ph777 = $209;$$ph778 = $208;
 } else {
  $25 = (($lastQ) + 4|0);
  $26 = (($lastQ) + 8|0);
  $27 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $28 = (($lastA) + 4|0);
  $29 = (($lastA) + 8|0);
  $30 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $31 = (($lastB) + 4|0);
  $32 = (($lastB) + 8|0);
  $33 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $34 = (($aToB) + 48|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = (($aToB) + 52|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($aToB) + 56|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround(HEAPF32[$aToB>>2]);
  $41 = (($aToB) + 16|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($aToB) + 32|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($aToB) + 4|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($aToB) + 20|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($aToB) + 36|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = (($aToB) + 8|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (($aToB) + 24|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($aToB) + 40|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($b) + 96|0);
  $58 = $23&255;
  $59 = ($58>>>0)>(1);
  $umax = $59 ? $58 : 1;
  $105 = 0;$i$0823 = 0;
  while(1) {
   $60 = (($aIndices) + ($i$0823)|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61&255;
   $63 = (($aInd) + ($i$0823<<2)|0);
   HEAP32[$63>>2] = $62;
   $64 = (($bIndices) + ($i$0823)|0);
   $65 = HEAP8[$64>>0]|0;
   $66 = $65&255;
   $67 = (($bInd) + ($i$0823<<2)|0);
   HEAP32[$67>>2] = $66;
   $68 = ((($a) + ($62<<4)|0) + 96|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = ((($a) + ($62<<4)|0) + 100|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = ((($a) + ($62<<4)|0) + 104|0);
   $73 = Math_fround(HEAPF32[$72>>2]);
   $74 = Math_fround($69 * $40);
   $75 = Math_fround($71 * $42);
   $76 = Math_fround($74 + $75);
   $77 = Math_fround($73 * $44);
   $78 = Math_fround($76 + $77);
   $79 = Math_fround($69 * $46);
   $80 = Math_fround($71 * $48);
   $81 = Math_fround($79 + $80);
   $82 = Math_fround($73 * $50);
   $83 = Math_fround($81 + $82);
   $84 = Math_fround($69 * $52);
   $85 = Math_fround($71 * $54);
   $86 = Math_fround($84 + $85);
   $87 = Math_fround($73 * $56);
   $88 = Math_fround($86 + $87);
   $89 = Math_fround($35 + $78);
   $90 = Math_fround($37 + $83);
   $91 = Math_fround($39 + $88);
   $92 = (1 - ($66))|0;
   $93 = (($57) + ($92<<4)|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = ((($57) + ($92<<4)|0) + 4|0);
   $96 = Math_fround(HEAPF32[$95>>2]);
   $97 = ((($57) + ($92<<4)|0) + 8|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = ((($57) + ($92<<4)|0) + 12|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = Math_fround($89 - $94);
   $102 = Math_fround($90 - $96);
   $103 = Math_fround($91 - $98);
   $104 = (($A) + ($105<<4)|0);
   HEAPF32[$lastA>>2] = $89;
   HEAPF32[$28>>2] = $90;
   HEAPF32[$29>>2] = $91;
   HEAPF32[$30>>2] = Math_fround(0.0);
   ;HEAP32[$104+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$104+12>>2]=HEAP32[$lastA+12>>2]|0;
   $106 = (($B) + ($105<<4)|0);
   HEAPF32[$lastB>>2] = $94;
   HEAPF32[$31>>2] = $96;
   HEAPF32[$32>>2] = $98;
   HEAPF32[$33>>2] = $100;
   ;HEAP32[$106+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$lastB+12>>2]|0;
   $107 = (($105) + 1)|0;
   $108 = (($Q) + ($105<<4)|0);
   HEAPF32[$lastQ>>2] = $101;
   HEAPF32[$25>>2] = $102;
   HEAPF32[$26>>2] = $103;
   HEAPF32[$27>>2] = Math_fround(0.0);
   ;HEAP32[$108+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$108+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$108+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$108+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $109 = (($i$0823) + 1)|0;
   $110 = ($109>>>0)<($58>>>0);
   if ($110) {
    $105 = $107;$i$0823 = $109;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $umax;
  do {
   if ((($umax|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($umax|0) == 3)) {
    $168 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($2,$Q,$168,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($umax|0) == 4)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($2,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($umax|0) == 2)) {
    $111 = Math_fround(HEAPF32[$Q>>2]);
    $112 = (($Q) + 4|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = (($Q) + 8|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = Math_fround($101 - $111);
    $117 = Math_fround($102 - $113);
    $118 = Math_fround($103 - $115);
    $119 = Math_fround($116 * $116);
    $120 = Math_fround($117 * $117);
    $121 = Math_fround($119 + $120);
    $122 = Math_fround($118 * $118);
    $123 = Math_fround($121 + $122);
    $124 = $123 == Math_fround(0.0);
    if ($124) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$2+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $125 = Math_fround($113 * $117);
     $126 = Math_fround(-$125);
     $127 = Math_fround($111 * $116);
     $128 = Math_fround($126 - $127);
     $129 = Math_fround($115 * $118);
     $130 = Math_fround($128 - $129);
     $131 = Math_fround(HEAPF32[$A>>2]);
     $132 = (($A) + 4|0);
     $133 = Math_fround(HEAPF32[$132>>2]);
     $134 = (($A) + 8|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     $136 = Math_fround($89 - $131);
     $137 = Math_fround($90 - $133);
     $138 = Math_fround($91 - $135);
     $139 = Math_fround(HEAPF32[$B>>2]);
     $140 = (($B) + 4|0);
     $141 = Math_fround(HEAPF32[$140>>2]);
     $142 = (($B) + 8|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = Math_fround($94 - $139);
     $145 = Math_fround($96 - $141);
     $146 = Math_fround($98 - $143);
     $147 = Math_fround($130 / $123);
     $148 = $147 > Math_fround(1.0);
     $$$i$i$i165 = $148 ? Math_fround(1.0) : $147;
     $149 = $$$i$i$i165 > Math_fround(0.0);
     $$$i8$i$i166 = $149 ? $$$i$i$i165 : Math_fround(0.0);
     $150 = Math_fround($136 * $$$i8$i$i166);
     $151 = Math_fround($137 * $$$i8$i$i166);
     $152 = Math_fround($138 * $$$i8$i$i166);
     $153 = Math_fround($131 + $150);
     $154 = Math_fround($133 + $151);
     $155 = Math_fround($135 + $152);
     $156 = Math_fround($144 * $$$i8$i$i166);
     $157 = Math_fround($145 * $$$i8$i$i166);
     $158 = Math_fround($146 * $$$i8$i$i166);
     $159 = Math_fround($139 + $156);
     $160 = Math_fround($141 + $157);
     $161 = Math_fround($143 + $158);
     HEAPF32[$closA>>2] = $153;
     HEAPF32[$16>>2] = $154;
     HEAPF32[$17>>2] = $155;
     HEAPF32[$18>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $159;
     HEAPF32[$19>>2] = $160;
     HEAPF32[$20>>2] = $161;
     HEAPF32[$21>>2] = Math_fround(0.0);
     $162 = Math_fround($153 - $159);
     $163 = Math_fround($154 - $160);
     $164 = Math_fround($155 - $161);
     HEAPF32[$2>>2] = $162;
     $165 = (($2) + 4|0);
     HEAPF32[$165>>2] = $163;
     $166 = (($2) + 8|0);
     HEAPF32[$166>>2] = $164;
     $167 = (($2) + 12|0);
     HEAPF32[$167>>2] = Math_fround(0.0);
     break;
    }
   } else {
    ;HEAP32[$2+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  $169 = Math_fround(HEAPF32[$2>>2]);
  $170 = (($2) + 4|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = (($2) + 8|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($169 * $169);
  $175 = Math_fround($171 * $171);
  $176 = Math_fround($174 + $175);
  $177 = Math_fround($173 * $173);
  $178 = Math_fround($176 + $177);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $179 = Math_fround(HEAPF32[$closA>>2]);
  $180 = Math_fround(HEAPF32[$16>>2]);
  $181 = Math_fround(HEAPF32[$17>>2]);
  $182 = Math_fround(HEAPF32[$18>>2]);
  $183 = Math_fround(HEAPF32[$closB>>2]);
  $184 = Math_fround(HEAPF32[$19>>2]);
  $185 = Math_fround(HEAPF32[$20>>2]);
  $186 = Math_fround(HEAPF32[$21>>2]);
  $187 = $178 > $22;
  $$ph = $182;$$ph763 = $181;$$ph764 = $180;$$ph765 = $179;$$ph766 = $186;$$ph767 = $185;$$ph768 = $184;$$ph769 = $183;$$ph771 = $178;$$ph772 = $187;$$ph776 = $173;$$ph777 = $171;$$ph778 = $169;
 }
 do {
  if ($$ph772) {
   $212 = (($aToB) + 4|0);
   $213 = (($aToB) + 8|0);
   $214 = (($aToB) + 16|0);
   $215 = (($aToB) + 20|0);
   $216 = (($aToB) + 24|0);
   $217 = (($aToB) + 32|0);
   $218 = (($aToB) + 36|0);
   $219 = (($aToB) + 40|0);
   $220 = (($_dir$i) + 4|0);
   $221 = (($_dir$i) + 8|0);
   $222 = (($_dir$i) + 12|0);
   $223 = (($aToB) + 48|0);
   $224 = (($aToB) + 52|0);
   $225 = (($aToB) + 56|0);
   $226 = (($res$i) + 4|0);
   $227 = (($res$i) + 8|0);
   $228 = (($supportA1) + 4|0);
   $229 = (($supportA1) + 8|0);
   $230 = (($supportA1) + 12|0);
   $231 = (($b) + 96|0);
   $232 = (($b) + 96|0);
   $233 = (($b) + 100|0);
   $234 = (($b) + 104|0);
   $235 = (($b) + 112|0);
   $236 = (($b) + 112|0);
   $237 = (($b) + 116|0);
   $238 = (($b) + 120|0);
   $239 = (($supportB2) + 4|0);
   $240 = (($supportB2) + 8|0);
   $241 = (($supportB2) + 12|0);
   $242 = (($support3) + 4|0);
   $243 = (($support3) + 8|0);
   $244 = (($support3) + 12|0);
   $245 = (($a) + 48|0);
   $246 = (($b) + 48|0);
   $247 = (($3) + 4|0);
   $248 = (($3) + 8|0);
   $249 = (($Q) + 4|0);
   $250 = (($Q) + 8|0);
   $251 = (($A) + 4|0);
   $252 = (($A) + 8|0);
   $253 = (($B) + 4|0);
   $254 = (($B) + 8|0);
   $255 = (($3) + 12|0);
   $256 = (($Q) + 16|0);
   $$$i743813 = $8;$258 = $$ph778;$260 = $$ph777;$262 = $$ph776;$359 = $$ph771;$492 = $$ph765;$493 = $$ph764;$494 = $$ph763;$495 = $$ph;$496 = $$ph769;$497 = $$ph768;$498 = $$ph767;$499 = $$ph766;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $257 = Math_fround(-$258);
    $259 = Math_fround(-$260);
    $261 = Math_fround(-$262);
    $263 = HEAP32[$size>>2]|0;
    $264 = (($A) + ($263<<4)|0);
    $265 = (($aInd) + ($263<<2)|0);
    $266 = Math_fround(HEAPF32[$aToB>>2]);
    $267 = Math_fround($266 * $257);
    $268 = Math_fround(HEAPF32[$212>>2]);
    $269 = Math_fround($268 * $259);
    $270 = Math_fround($267 + $269);
    $271 = Math_fround(HEAPF32[$213>>2]);
    $272 = Math_fround($271 * $261);
    $273 = Math_fround($270 + $272);
    $274 = Math_fround(HEAPF32[$214>>2]);
    $275 = Math_fround($274 * $257);
    $276 = Math_fround(HEAPF32[$215>>2]);
    $277 = Math_fround($276 * $259);
    $278 = Math_fround($275 + $277);
    $279 = Math_fround(HEAPF32[$216>>2]);
    $280 = Math_fround($279 * $261);
    $281 = Math_fround($278 + $280);
    $282 = Math_fround(HEAPF32[$217>>2]);
    $283 = Math_fround($282 * $257);
    $284 = Math_fround(HEAPF32[$218>>2]);
    $285 = Math_fround($284 * $259);
    $286 = Math_fround($283 + $285);
    $287 = Math_fround(HEAPF32[$219>>2]);
    $288 = Math_fround($287 * $261);
    $289 = Math_fround($286 + $288);
    HEAPF32[$_dir$i>>2] = $273;
    HEAPF32[$220>>2] = $281;
    HEAPF32[$221>>2] = $289;
    HEAPF32[$222>>2] = Math_fround(0.0);
    __ZNK5physx2Gu9TriangleV12supportLocalERKNS_6shdfnd3aos5Vec3VERi($res$i,$a,$_dir$i,$265);
    ;HEAP32[$264+0>>2]=HEAP32[$res$i+0>>2]|0;HEAP32[$264+4>>2]=HEAP32[$res$i+4>>2]|0;HEAP32[$264+8>>2]=HEAP32[$res$i+8>>2]|0;HEAP32[$264+12>>2]=HEAP32[$res$i+12>>2]|0;
    $290 = Math_fround(HEAPF32[$223>>2]);
    $291 = Math_fround(HEAPF32[$224>>2]);
    $292 = Math_fround(HEAPF32[$225>>2]);
    $293 = Math_fround(HEAPF32[$res$i>>2]);
    $294 = Math_fround(HEAPF32[$226>>2]);
    $295 = Math_fround(HEAPF32[$227>>2]);
    $296 = Math_fround(HEAPF32[$aToB>>2]);
    $297 = Math_fround($293 * $296);
    $298 = Math_fround(HEAPF32[$214>>2]);
    $299 = Math_fround($294 * $298);
    $300 = Math_fround($297 + $299);
    $301 = Math_fround(HEAPF32[$217>>2]);
    $302 = Math_fround($295 * $301);
    $303 = Math_fround($300 + $302);
    $304 = Math_fround(HEAPF32[$212>>2]);
    $305 = Math_fround($293 * $304);
    $306 = Math_fround(HEAPF32[$215>>2]);
    $307 = Math_fround($294 * $306);
    $308 = Math_fround($305 + $307);
    $309 = Math_fround(HEAPF32[$218>>2]);
    $310 = Math_fround($295 * $309);
    $311 = Math_fround($308 + $310);
    $312 = Math_fround(HEAPF32[$213>>2]);
    $313 = Math_fround($293 * $312);
    $314 = Math_fround(HEAPF32[$216>>2]);
    $315 = Math_fround($294 * $314);
    $316 = Math_fround($313 + $315);
    $317 = Math_fround(HEAPF32[$219>>2]);
    $318 = Math_fround($295 * $317);
    $319 = Math_fround($316 + $318);
    $320 = Math_fround($290 + $303);
    $321 = Math_fround($291 + $311);
    $322 = Math_fround($292 + $319);
    HEAPF32[$supportA1>>2] = $320;
    HEAPF32[$228>>2] = $321;
    HEAPF32[$229>>2] = $322;
    HEAPF32[$230>>2] = Math_fround(0.0);
    $323 = HEAP32[$size>>2]|0;
    $324 = (($B) + ($323<<4)|0);
    $325 = (($bInd) + ($323<<2)|0);
    $326 = Math_fround(HEAPF32[$232>>2]);
    $327 = Math_fround(HEAPF32[$233>>2]);
    $328 = Math_fround(HEAPF32[$234>>2]);
    $329 = Math_fround($258 * $326);
    $330 = Math_fround($260 * $327);
    $331 = Math_fround($329 + $330);
    $332 = Math_fround($262 * $328);
    $333 = Math_fround($331 + $332);
    $334 = Math_fround(HEAPF32[$236>>2]);
    $335 = Math_fround(HEAPF32[$237>>2]);
    $336 = Math_fround(HEAPF32[$238>>2]);
    $337 = Math_fround($258 * $334);
    $338 = Math_fround($260 * $335);
    $339 = Math_fround($337 + $338);
    $340 = Math_fround($262 * $336);
    $341 = Math_fround($339 + $340);
    $342 = $333 > $341;
    $343 = $342&1;
    HEAP32[$325>>2] = $343;
    ;HEAP32[$res$i+0>>2]=HEAP32[$231+0>>2]|0;HEAP32[$res$i+4>>2]=HEAP32[$231+4>>2]|0;HEAP32[$res$i+8>>2]=HEAP32[$231+8>>2]|0;HEAP32[$res$i+12>>2]=HEAP32[$231+12>>2]|0;
    ;HEAP32[$_dir$i+0>>2]=HEAP32[$235+0>>2]|0;HEAP32[$_dir$i+4>>2]=HEAP32[$235+4>>2]|0;HEAP32[$_dir$i+8>>2]=HEAP32[$235+8>>2]|0;HEAP32[$_dir$i+12>>2]=HEAP32[$235+12>>2]|0;
    $b$a$i$i$i = $342 ? $res$i : $_dir$i;
    $344 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
    $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
    $345 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
    $346 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    HEAPF32[$supportB2>>2] = $344;
    HEAPF32[$239>>2] = $345;
    HEAPF32[$240>>2] = $346;
    HEAPF32[$241>>2] = Math_fround(0.0);
    ;HEAP32[$324+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$324+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$324+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$324+12>>2]=HEAP32[$supportB2+12>>2]|0;
    $347 = Math_fround($320 - $344);
    $348 = Math_fround($321 - $345);
    $349 = Math_fround($322 - $346);
    HEAPF32[$support3>>2] = $347;
    HEAPF32[$242>>2] = $348;
    HEAPF32[$243>>2] = $349;
    HEAPF32[$244>>2] = Math_fround(0.0);
    $350 = (($323) + 1)|0;
    HEAP32[$size>>2] = $350;
    $351 = (($Q) + ($323<<4)|0);
    ;HEAP32[$351+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$351+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$351+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$351+12>>2]=HEAP32[$support3+12>>2]|0;
    $352 = Math_fround(HEAPF32[$245>>2]);
    $353 = Math_fround(HEAPF32[$246>>2]);
    $354 = $352 > $353;
    $$$i134 = $354 ? $352 : $353;
    $355 = $$$i743813 > $$$i134;
    $$$i = $355 ? $$$i743813 : $$$i134;
    $356 = Math_fround($15 + $$$i);
    $357 = Math_fround($356 * $356);
    $358 = Math_fround($359 * $357);
    $360 = Math_fround($258 * $347);
    $361 = Math_fround($260 * $348);
    $362 = Math_fround($360 + $361);
    $363 = Math_fround($262 * $349);
    $364 = Math_fround($362 + $363);
    $365 = Math_fround($364 * $364);
    $366 = $364 > Math_fround(0.0);
    $367 = $365 > $358;
    if ($366) {
     $phitmp759 = $367 ^ 1;
     $371 = $367;$373 = $phitmp759;
    } else {
     $371 = 0;$373 = 1;
    }
    $368 = Math_fround($359 - $364);
    $369 = Math_fround($22 * $359);
    $370 = $369 >= $368;
    $brmerge$demorgan = $370 | $371;
    if ($brmerge$demorgan) {
     $372 = $373 ^ 1;
     $$751 = $370 | $372;
     if ($$751) {
      break;
     }
    }
    do {
     if ((($323|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($3,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($323|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($3,$Q,$256,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($323|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$3+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($323|0) == 1)) {
      $420 = Math_fround(HEAPF32[$Q>>2]);
      $421 = Math_fround(HEAPF32[$249>>2]);
      $422 = Math_fround(HEAPF32[$250>>2]);
      $423 = Math_fround($347 - $420);
      $424 = Math_fround($348 - $421);
      $425 = Math_fround($349 - $422);
      $426 = Math_fround($423 * $423);
      $427 = Math_fround($424 * $424);
      $428 = Math_fround($426 + $427);
      $429 = Math_fround($425 * $425);
      $430 = Math_fround($428 + $429);
      $431 = $430 == Math_fround(0.0);
      if ($431) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$3+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $432 = Math_fround($421 * $424);
       $433 = Math_fround(-$432);
       $434 = Math_fround($420 * $423);
       $435 = Math_fround($433 - $434);
       $436 = Math_fround($422 * $425);
       $437 = Math_fround($435 - $436);
       $438 = Math_fround(HEAPF32[$A>>2]);
       $439 = Math_fround(HEAPF32[$251>>2]);
       $440 = Math_fround(HEAPF32[$252>>2]);
       $441 = Math_fround($320 - $438);
       $442 = Math_fround($321 - $439);
       $443 = Math_fround($322 - $440);
       $444 = Math_fround(HEAPF32[$B>>2]);
       $445 = Math_fround(HEAPF32[$253>>2]);
       $446 = Math_fround(HEAPF32[$254>>2]);
       $447 = Math_fround($344 - $444);
       $448 = Math_fround($345 - $445);
       $449 = Math_fround($346 - $446);
       $450 = Math_fround($437 / $430);
       $451 = $450 > Math_fround(1.0);
       $$$i$i$i = $451 ? Math_fround(1.0) : $450;
       $452 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $452 ? $$$i$i$i : Math_fround(0.0);
       $453 = Math_fround($441 * $$$i8$i$i);
       $454 = Math_fround($442 * $$$i8$i$i);
       $455 = Math_fround($443 * $$$i8$i$i);
       $456 = Math_fround($438 + $453);
       $457 = Math_fround($439 + $454);
       $458 = Math_fround($440 + $455);
       $459 = Math_fround($447 * $$$i8$i$i);
       $460 = Math_fround($448 * $$$i8$i$i);
       $461 = Math_fround($449 * $$$i8$i$i);
       $462 = Math_fround($444 + $459);
       $463 = Math_fround($445 + $460);
       $464 = Math_fround($446 + $461);
       HEAPF32[$closA>>2] = $456;
       HEAPF32[$16>>2] = $457;
       HEAPF32[$17>>2] = $458;
       HEAPF32[$18>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $462;
       HEAPF32[$19>>2] = $463;
       HEAPF32[$20>>2] = $464;
       HEAPF32[$21>>2] = Math_fround(0.0);
       $465 = Math_fround($456 - $462);
       $466 = Math_fround($457 - $463);
       $467 = Math_fround($458 - $464);
       HEAPF32[$3>>2] = $465;
       HEAPF32[$247>>2] = $466;
       HEAPF32[$248>>2] = $467;
       HEAPF32[$255>>2] = Math_fround(0.0);
       break;
      }
     } else {
      ;HEAP32[$3+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    $468 = Math_fround(HEAPF32[$3>>2]);
    $469 = Math_fround(HEAPF32[$247>>2]);
    $470 = Math_fround(HEAPF32[$248>>2]);
    $471 = Math_fround($468 * $468);
    $472 = Math_fround($469 * $469);
    $473 = Math_fround($471 + $472);
    $474 = Math_fround($470 * $470);
    $475 = Math_fround($473 + $474);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1232+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1232+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1232+8>>2]|0;
    $476 = $359 > $475;
    $477 = $475 > $22;
    if (!($477)) {
     label = 37;
     break;
    }
    if (!($476)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre860 = Math_fround(HEAPF32[$16>>2]);
    $$pre861 = Math_fround(HEAPF32[$17>>2]);
    $$pre862 = Math_fround(HEAPF32[$18>>2]);
    $$pre863 = Math_fround(HEAPF32[$closB>>2]);
    $$pre864 = Math_fround(HEAPF32[$19>>2]);
    $$pre865 = Math_fround(HEAPF32[$20>>2]);
    $$pre866 = Math_fround(HEAPF32[$21>>2]);
    $$$i743813 = $$$i;$258 = $468;$260 = $469;$262 = $470;$359 = $475;$492 = $$pre;$493 = $$pre860;$494 = $$pre861;$495 = $$pre862;$496 = $$pre863;$497 = $$pre864;$498 = $$pre865;$499 = $$pre866;
   }
   if ((label|0) == 37) {
    $478 = HEAP32[$size>>2]|0;
    if ($476) {
     $533 = $478;
     break;
    }
    $479 = (($478) + -1)|0;
    $480 = ($aIndices|0)==(0|0);
    if (!($480)) {
     $481 = $479&255;
     HEAP8[$_size>>0] = $481;
     $482 = ($479|0)==(0);
     if (!($482)) {
      $i$01$i29 = 0;
      while(1) {
       $483 = (($aInd) + ($i$01$i29<<2)|0);
       $484 = HEAP32[$483>>2]|0;
       $485 = $484&255;
       $486 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$486>>0] = $485;
       $487 = (($bInd) + ($i$01$i29<<2)|0);
       $488 = HEAP32[$487>>2]|0;
       $489 = $488&255;
       $490 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$490>>0] = $489;
       $491 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($491|0)==($479|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $491;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $492;
    HEAPF32[$16>>2] = $493;
    HEAPF32[$17>>2] = $494;
    HEAPF32[$18>>2] = $495;
    HEAPF32[$closB>>2] = $496;
    HEAPF32[$19>>2] = $497;
    HEAPF32[$20>>2] = $498;
    HEAPF32[$21>>2] = $499;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $500 = Math_fround($492 - $496);
    $501 = Math_fround($493 - $497);
    $502 = Math_fround($494 - $498);
    $503 = (Math_fround(Math_sqrt((Math_fround($359)))));
    $504 = Math_fround(Math_fround(1.0) / $503);
    $505 = Math_fround($500 * $504);
    $506 = Math_fround($501 * $504);
    $507 = Math_fround($502 * $504);
    $508 = Math_fround($5 * $505);
    $509 = Math_fround($5 * $506);
    $510 = Math_fround($5 * $507);
    $511 = Math_fround($492 - $508);
    $512 = Math_fround($493 - $509);
    $513 = Math_fround($494 - $510);
    HEAPF32[$contactA>>2] = $511;
    $514 = (($contactA) + 4|0);
    HEAPF32[$514>>2] = $512;
    $515 = (($contactA) + 8|0);
    HEAPF32[$515>>2] = $513;
    $516 = (($contactA) + 12|0);
    HEAPF32[$516>>2] = Math_fround(0.0);
    $517 = Math_fround($7 * $505);
    $518 = Math_fround($7 * $506);
    $519 = Math_fround($7 * $507);
    $520 = Math_fround($517 + $496);
    $521 = Math_fround($518 + $497);
    $522 = Math_fround($519 + $498);
    HEAPF32[$contactB>>2] = $520;
    $523 = (($contactB) + 4|0);
    HEAPF32[$523>>2] = $521;
    $524 = (($contactB) + 8|0);
    HEAPF32[$524>>2] = $522;
    $525 = (($contactB) + 12|0);
    HEAPF32[$525>>2] = Math_fround(0.0);
    $526 = Math_fround($503 - $15);
    HEAPF32[$penetrationDepth>>2] = $526;
    $527 = (($penetrationDepth) + 4|0);
    ;HEAP32[$527+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$527+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$527+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $505;
    $528 = (($normal) + 4|0);
    HEAPF32[$528>>2] = $506;
    $529 = (($normal) + 8|0);
    HEAPF32[$529>>2] = $507;
    $530 = (($normal) + 12|0);
    HEAPF32[$530>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $374 = ($aIndices|0)==(0|0);
   if (!($374)) {
    $375 = $323&255;
    HEAP8[$_size>>0] = $375;
    $376 = ($323|0)==(0);
    if (!($376)) {
     $i$01$i72 = 0;
     while(1) {
      $377 = (($aInd) + ($i$01$i72<<2)|0);
      $378 = HEAP32[$377>>2]|0;
      $379 = $378&255;
      $380 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$380>>0] = $379;
      $381 = (($bInd) + ($i$01$i72<<2)|0);
      $382 = HEAP32[$381>>2]|0;
      $383 = $382&255;
      $384 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$384>>0] = $383;
      $385 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($385|0)==($323|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $385;
      }
     }
    }
   }
   $not$ = $371 ^ 1;
   $$$755 = $373 & $not$;
   if (!($$$755)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $386 = (Math_fround(Math_sqrt((Math_fround($359)))));
   $387 = Math_fround(Math_fround(1.0) / $386);
   $388 = Math_fround($258 * $387);
   $389 = Math_fround($260 * $387);
   $390 = Math_fround($262 * $387);
   $391 = Math_fround(HEAPF32[$closA>>2]);
   $392 = Math_fround(HEAPF32[$16>>2]);
   $393 = Math_fround(HEAPF32[$17>>2]);
   $394 = Math_fround($5 * $388);
   $395 = Math_fround($5 * $389);
   $396 = Math_fround($5 * $390);
   $397 = Math_fround($391 - $394);
   $398 = Math_fround($392 - $395);
   $399 = Math_fround($393 - $396);
   HEAPF32[$contactA>>2] = $397;
   $400 = (($contactA) + 4|0);
   HEAPF32[$400>>2] = $398;
   $401 = (($contactA) + 8|0);
   HEAPF32[$401>>2] = $399;
   $402 = (($contactA) + 12|0);
   HEAPF32[$402>>2] = Math_fround(0.0);
   $403 = Math_fround(HEAPF32[$closB>>2]);
   $404 = Math_fround(HEAPF32[$19>>2]);
   $405 = Math_fround(HEAPF32[$20>>2]);
   $406 = Math_fround($7 * $388);
   $407 = Math_fround($7 * $389);
   $408 = Math_fround($7 * $390);
   $409 = Math_fround($406 + $403);
   $410 = Math_fround($407 + $404);
   $411 = Math_fround($408 + $405);
   HEAPF32[$contactB>>2] = $409;
   $412 = (($contactB) + 4|0);
   HEAPF32[$412>>2] = $410;
   $413 = (($contactB) + 8|0);
   HEAPF32[$413>>2] = $411;
   $414 = (($contactB) + 12|0);
   HEAPF32[$414>>2] = Math_fround(0.0);
   $415 = Math_fround($386 - $15);
   HEAPF32[$penetrationDepth>>2] = $415;
   $416 = (($penetrationDepth) + 4|0);
   ;HEAP32[$416+0>>2]=HEAP32[$$sroa$1234+0>>2]|0;HEAP32[$416+4>>2]=HEAP32[$$sroa$1234+4>>2]|0;HEAP32[$416+8>>2]=HEAP32[$$sroa$1234+8>>2]|0;
   HEAPF32[$normal>>2] = $388;
   $417 = (($normal) + 4|0);
   HEAPF32[$417>>2] = $389;
   $418 = (($normal) + 8|0);
   HEAPF32[$418>>2] = $390;
   $419 = (($normal) + 12|0);
   HEAPF32[$419>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $211 = HEAP32[$size>>2]|0;
   $533 = $211;
  }
 } while(0);
 $531 = ($aIndices|0)==(0|0);
 if (!($531)) {
  $532 = $533&255;
  HEAP8[$_size>>0] = $532;
  $534 = ($533|0)==(0);
  if (!($534)) {
   $i$01$i = 0;
   while(1) {
    $535 = (($aInd) + ($i$01$i<<2)|0);
    $536 = HEAP32[$535>>2]|0;
    $537 = $536&255;
    $538 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$538>>0] = $537;
    $539 = (($bInd) + ($i$01$i<<2)|0);
    $540 = HEAP32[$539>>2]|0;
    $541 = $540&255;
    $542 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$542>>0] = $541;
    $543 = (($i$01$i) + 1)|0;
    $exitcond$i = ($543|0)==($533|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $543;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_8CapsuleVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$755 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i165 = Math_fround(0), $$$i134 = Math_fround(0), $$$i188 = Math_fround(0), $$$i743813 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i166 = Math_fround(0), $$0 = 0, $$751 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i$i = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i$i = 0, $$ph = Math_fround(0), $$ph763 = Math_fround(0), $$ph764 = Math_fround(0);
 var $$ph765 = Math_fround(0), $$ph766 = Math_fround(0), $$ph767 = Math_fround(0), $$ph768 = Math_fround(0), $$ph769 = Math_fround(0), $$ph771 = Math_fround(0), $$ph772 = 0, $$ph776 = Math_fround(0), $$ph777 = Math_fround(0), $$ph778 = Math_fround(0), $$pre = Math_fround(0), $$pre860 = Math_fround(0), $$pre861 = Math_fround(0), $$pre862 = Math_fround(0), $$pre863 = Math_fround(0), $$pre864 = Math_fround(0), $$pre865 = Math_fround(0), $$pre866 = Math_fround(0), $$sroa$1 = 0, $$sroa$1232 = 0;
 var $$sroa$1234 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0;
 var $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = 0;
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0);
 var $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0);
 var $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = 0, $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0);
 var $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0);
 var $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = Math_fround(0), $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0);
 var $99 = 0, $A = 0, $B = 0, $Q = 0, $aInd = 0, $b$a$i = 0, $b$a$i$i$i = 0, $b$a$i$i$i$i = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$0823 = 0, $lastA = 0;
 var $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp759 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 368|0;
 $1 = sp + 320|0;
 $2 = sp + 336|0;
 $3 = sp + 352|0;
 $closA = sp + 384|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 484|0;
 $minDist$sroa$1 = sp + 472|0;
 $Q = sp;
 $A = sp + 144|0;
 $B = sp + 64|0;
 $aInd = sp + 456|0;
 $bInd = sp + 496|0;
 $size = sp + 416|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 208|0;
 $lastB = sp + 224|0;
 $4 = sp + 240|0;
 $supportA1 = sp + 256|0;
 $supportB2 = sp + 272|0;
 $support3 = sp + 288|0;
 $$sroa$1234 = sp + 432|0;
 $5 = sp + 304|0;
 $$sroa$1232 = sp + 444|0;
 $$sroa$1 = sp + 420|0;
 $6 = (($a) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($b) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$_contactDist>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i188 = $15 ? $14 : $12;
 $16 = Math_fround($$$i188 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($7 + $9);
 $18 = (($closA) + 4|0);
 $19 = (($closA) + 8|0);
 $20 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $21 = (($closB) + 4|0);
 $22 = (($closB) + 8|0);
 $23 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $24 = Math_fround($16 * $16);
 HEAP32[$size>>2] = 0;
 $25 = HEAP8[$_size>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $192 = (($aToB) + 48|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($aToB) + 52|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($aToB) + 56|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = (($aToB) + 60|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = Math_fround($193 * $193);
  $201 = Math_fround($195 * $195);
  $202 = Math_fround($200 + $201);
  $203 = Math_fround($197 * $197);
  $204 = Math_fround($202 + $203);
  $205 = $204 > Math_fround(0.0);
  HEAPF32[$1>>2] = $193;
  $206 = (($1) + 4|0);
  HEAPF32[$206>>2] = $195;
  $207 = (($1) + 8|0);
  HEAPF32[$207>>2] = $197;
  $208 = (($1) + 12|0);
  HEAPF32[$208>>2] = $199;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $209 = (($0) + 4|0);
  HEAPF32[$209>>2] = Math_fround(0.0);
  $210 = (($0) + 8|0);
  HEAPF32[$210>>2] = Math_fround(0.0);
  $211 = (($0) + 12|0);
  HEAPF32[$211>>2] = Math_fround(0.0);
  $b$a$i = $205 ? $1 : $0;
  $212 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $213 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $214 = Math_fround(HEAPF32[$$in2$i>>2]);
  $$ph = Math_fround(0.0);$$ph763 = Math_fround(0.0);$$ph764 = Math_fround(0.0);$$ph765 = Math_fround(0.0);$$ph766 = Math_fround(0.0);$$ph767 = Math_fround(0.0);$$ph768 = Math_fround(0.0);$$ph769 = Math_fround(0.0);$$ph771 = Math_fround(3.40282346638528859812E+38);$$ph772 = 1;$$ph776 = $214;$$ph777 = $213;$$ph778 = $212;
 } else {
  $27 = (($lastQ) + 4|0);
  $28 = (($lastQ) + 8|0);
  $29 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $30 = (($lastA) + 4|0);
  $31 = (($lastA) + 8|0);
  $32 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $33 = (($lastB) + 4|0);
  $34 = (($lastB) + 8|0);
  $35 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $36 = (($a) + 96|0);
  $37 = (($aToB) + 48|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($aToB) + 52|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($aToB) + 56|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(HEAPF32[$aToB>>2]);
  $44 = (($aToB) + 16|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($aToB) + 32|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = (($aToB) + 4|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($aToB) + 20|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($aToB) + 36|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($aToB) + 8|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($aToB) + 24|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($aToB) + 40|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($b) + 96|0);
  $61 = $25&255;
  $62 = ($61>>>0)>(1);
  $umax = $62 ? $61 : 1;
  $109 = 0;$i$0823 = 0;
  while(1) {
   $63 = (($aIndices) + ($i$0823)|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = $64&255;
   $66 = (($aInd) + ($i$0823<<2)|0);
   HEAP32[$66>>2] = $65;
   $67 = (($bIndices) + ($i$0823)|0);
   $68 = HEAP8[$67>>0]|0;
   $69 = $68&255;
   $70 = (($bInd) + ($i$0823<<2)|0);
   HEAP32[$70>>2] = $69;
   $71 = (1 - ($65))|0;
   $72 = (($36) + ($71<<4)|0);
   $73 = Math_fround(HEAPF32[$72>>2]);
   $74 = ((($36) + ($71<<4)|0) + 4|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = ((($36) + ($71<<4)|0) + 8|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = Math_fround($73 * $43);
   $79 = Math_fround($75 * $45);
   $80 = Math_fround($78 + $79);
   $81 = Math_fround($77 * $47);
   $82 = Math_fround($80 + $81);
   $83 = Math_fround($73 * $49);
   $84 = Math_fround($75 * $51);
   $85 = Math_fround($83 + $84);
   $86 = Math_fround($77 * $53);
   $87 = Math_fround($85 + $86);
   $88 = Math_fround($73 * $55);
   $89 = Math_fround($75 * $57);
   $90 = Math_fround($88 + $89);
   $91 = Math_fround($77 * $59);
   $92 = Math_fround($90 + $91);
   $93 = Math_fround($38 + $82);
   $94 = Math_fround($40 + $87);
   $95 = Math_fround($42 + $92);
   $96 = (1 - ($69))|0;
   $97 = (($60) + ($96<<4)|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = ((($60) + ($96<<4)|0) + 4|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = ((($60) + ($96<<4)|0) + 8|0);
   $102 = Math_fround(HEAPF32[$101>>2]);
   $103 = ((($60) + ($96<<4)|0) + 12|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = Math_fround($93 - $98);
   $106 = Math_fround($94 - $100);
   $107 = Math_fround($95 - $102);
   $108 = (($A) + ($109<<4)|0);
   HEAPF32[$lastA>>2] = $93;
   HEAPF32[$30>>2] = $94;
   HEAPF32[$31>>2] = $95;
   HEAPF32[$32>>2] = Math_fround(0.0);
   ;HEAP32[$108+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$108+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$108+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$108+12>>2]=HEAP32[$lastA+12>>2]|0;
   $110 = (($B) + ($109<<4)|0);
   HEAPF32[$lastB>>2] = $98;
   HEAPF32[$33>>2] = $100;
   HEAPF32[$34>>2] = $102;
   HEAPF32[$35>>2] = $104;
   ;HEAP32[$110+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$110+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$110+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$110+12>>2]=HEAP32[$lastB+12>>2]|0;
   $111 = (($109) + 1)|0;
   $112 = (($Q) + ($109<<4)|0);
   HEAPF32[$lastQ>>2] = $105;
   HEAPF32[$27>>2] = $106;
   HEAPF32[$28>>2] = $107;
   HEAPF32[$29>>2] = Math_fround(0.0);
   ;HEAP32[$112+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$112+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$112+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$112+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $113 = (($i$0823) + 1)|0;
   $114 = ($113>>>0)<($61>>>0);
   if ($114) {
    $109 = $111;$i$0823 = $113;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $umax;
  do {
   if ((($umax|0) == 4)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($umax|0) == 3)) {
    $172 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$172,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($umax|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($umax|0) == 2)) {
    $115 = Math_fround(HEAPF32[$Q>>2]);
    $116 = (($Q) + 4|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = (($Q) + 8|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = Math_fround($105 - $115);
    $121 = Math_fround($106 - $117);
    $122 = Math_fround($107 - $119);
    $123 = Math_fround($120 * $120);
    $124 = Math_fround($121 * $121);
    $125 = Math_fround($123 + $124);
    $126 = Math_fround($122 * $122);
    $127 = Math_fround($125 + $126);
    $128 = $127 == Math_fround(0.0);
    if ($128) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $129 = Math_fround($117 * $121);
     $130 = Math_fround(-$129);
     $131 = Math_fround($115 * $120);
     $132 = Math_fround($130 - $131);
     $133 = Math_fround($119 * $122);
     $134 = Math_fround($132 - $133);
     $135 = Math_fround(HEAPF32[$A>>2]);
     $136 = (($A) + 4|0);
     $137 = Math_fround(HEAPF32[$136>>2]);
     $138 = (($A) + 8|0);
     $139 = Math_fround(HEAPF32[$138>>2]);
     $140 = Math_fround($93 - $135);
     $141 = Math_fround($94 - $137);
     $142 = Math_fround($95 - $139);
     $143 = Math_fround(HEAPF32[$B>>2]);
     $144 = (($B) + 4|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = (($B) + 8|0);
     $147 = Math_fround(HEAPF32[$146>>2]);
     $148 = Math_fround($98 - $143);
     $149 = Math_fround($100 - $145);
     $150 = Math_fround($102 - $147);
     $151 = Math_fround($134 / $127);
     $152 = $151 > Math_fround(1.0);
     $$$i$i$i165 = $152 ? Math_fround(1.0) : $151;
     $153 = $$$i$i$i165 > Math_fround(0.0);
     $$$i8$i$i166 = $153 ? $$$i$i$i165 : Math_fround(0.0);
     $154 = Math_fround($140 * $$$i8$i$i166);
     $155 = Math_fround($141 * $$$i8$i$i166);
     $156 = Math_fround($142 * $$$i8$i$i166);
     $157 = Math_fround($135 + $154);
     $158 = Math_fround($137 + $155);
     $159 = Math_fround($139 + $156);
     $160 = Math_fround($148 * $$$i8$i$i166);
     $161 = Math_fround($149 * $$$i8$i$i166);
     $162 = Math_fround($150 * $$$i8$i$i166);
     $163 = Math_fround($143 + $160);
     $164 = Math_fround($145 + $161);
     $165 = Math_fround($147 + $162);
     HEAPF32[$closA>>2] = $157;
     HEAPF32[$18>>2] = $158;
     HEAPF32[$19>>2] = $159;
     HEAPF32[$20>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $163;
     HEAPF32[$21>>2] = $164;
     HEAPF32[$22>>2] = $165;
     HEAPF32[$23>>2] = Math_fround(0.0);
     $166 = Math_fround($157 - $163);
     $167 = Math_fround($158 - $164);
     $168 = Math_fround($159 - $165);
     HEAPF32[$4>>2] = $166;
     $169 = (($4) + 4|0);
     HEAPF32[$169>>2] = $167;
     $170 = (($4) + 8|0);
     HEAPF32[$170>>2] = $168;
     $171 = (($4) + 12|0);
     HEAPF32[$171>>2] = Math_fround(0.0);
     break;
    }
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  $173 = Math_fround(HEAPF32[$4>>2]);
  $174 = (($4) + 4|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (($4) + 8|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround($173 * $173);
  $179 = Math_fround($175 * $175);
  $180 = Math_fround($178 + $179);
  $181 = Math_fround($177 * $177);
  $182 = Math_fround($180 + $181);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $183 = Math_fround(HEAPF32[$closA>>2]);
  $184 = Math_fround(HEAPF32[$18>>2]);
  $185 = Math_fround(HEAPF32[$19>>2]);
  $186 = Math_fround(HEAPF32[$20>>2]);
  $187 = Math_fround(HEAPF32[$closB>>2]);
  $188 = Math_fround(HEAPF32[$21>>2]);
  $189 = Math_fround(HEAPF32[$22>>2]);
  $190 = Math_fround(HEAPF32[$23>>2]);
  $191 = $182 > $24;
  $$ph = $186;$$ph763 = $185;$$ph764 = $184;$$ph765 = $183;$$ph766 = $190;$$ph767 = $189;$$ph768 = $188;$$ph769 = $187;$$ph771 = $182;$$ph772 = $191;$$ph776 = $177;$$ph777 = $175;$$ph778 = $173;
 }
 do {
  if ($$ph772) {
   $216 = (($aToB) + 4|0);
   $217 = (($aToB) + 8|0);
   $218 = (($aToB) + 16|0);
   $219 = (($aToB) + 20|0);
   $220 = (($aToB) + 24|0);
   $221 = (($aToB) + 32|0);
   $222 = (($aToB) + 36|0);
   $223 = (($aToB) + 40|0);
   $224 = (($a) + 96|0);
   $225 = (($a) + 96|0);
   $226 = (($a) + 100|0);
   $227 = (($a) + 104|0);
   $228 = (($a) + 112|0);
   $229 = (($a) + 112|0);
   $230 = (($a) + 116|0);
   $231 = (($a) + 120|0);
   $232 = (($aToB) + 48|0);
   $233 = (($aToB) + 52|0);
   $234 = (($aToB) + 56|0);
   $235 = (($supportA1) + 4|0);
   $236 = (($supportA1) + 8|0);
   $237 = (($supportA1) + 12|0);
   $238 = (($b) + 96|0);
   $239 = (($b) + 96|0);
   $240 = (($b) + 100|0);
   $241 = (($b) + 104|0);
   $242 = (($b) + 112|0);
   $243 = (($b) + 112|0);
   $244 = (($b) + 116|0);
   $245 = (($b) + 120|0);
   $246 = (($supportB2) + 4|0);
   $247 = (($supportB2) + 8|0);
   $248 = (($supportB2) + 12|0);
   $249 = (($support3) + 4|0);
   $250 = (($support3) + 8|0);
   $251 = (($support3) + 12|0);
   $252 = (($a) + 48|0);
   $253 = (($b) + 48|0);
   $254 = (($5) + 4|0);
   $255 = (($5) + 8|0);
   $256 = (($Q) + 4|0);
   $257 = (($Q) + 8|0);
   $258 = (($A) + 4|0);
   $259 = (($A) + 8|0);
   $260 = (($B) + 4|0);
   $261 = (($B) + 8|0);
   $262 = (($5) + 12|0);
   $263 = (($Q) + 16|0);
   $$$i743813 = $10;$265 = $$ph778;$267 = $$ph777;$269 = $$ph776;$375 = $$ph771;$508 = $$ph765;$509 = $$ph764;$510 = $$ph763;$511 = $$ph;$512 = $$ph769;$513 = $$ph768;$514 = $$ph767;$515 = $$ph766;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $264 = Math_fround(-$265);
    $266 = Math_fround(-$267);
    $268 = Math_fround(-$269);
    $270 = HEAP32[$size>>2]|0;
    $271 = (($A) + ($270<<4)|0);
    $272 = (($aInd) + ($270<<2)|0);
    $273 = Math_fround(HEAPF32[$aToB>>2]);
    $274 = Math_fround($273 * $264);
    $275 = Math_fround(HEAPF32[$216>>2]);
    $276 = Math_fround($275 * $266);
    $277 = Math_fround($274 + $276);
    $278 = Math_fround(HEAPF32[$217>>2]);
    $279 = Math_fround($278 * $268);
    $280 = Math_fround($277 + $279);
    $281 = Math_fround(HEAPF32[$218>>2]);
    $282 = Math_fround($281 * $264);
    $283 = Math_fround(HEAPF32[$219>>2]);
    $284 = Math_fround($283 * $266);
    $285 = Math_fround($282 + $284);
    $286 = Math_fround(HEAPF32[$220>>2]);
    $287 = Math_fround($286 * $268);
    $288 = Math_fround($285 + $287);
    $289 = Math_fround(HEAPF32[$221>>2]);
    $290 = Math_fround($289 * $264);
    $291 = Math_fround(HEAPF32[$222>>2]);
    $292 = Math_fround($291 * $266);
    $293 = Math_fround($290 + $292);
    $294 = Math_fround(HEAPF32[$223>>2]);
    $295 = Math_fround($294 * $268);
    $296 = Math_fround($293 + $295);
    $297 = Math_fround(HEAPF32[$225>>2]);
    $298 = Math_fround(HEAPF32[$226>>2]);
    $299 = Math_fround(HEAPF32[$227>>2]);
    $300 = Math_fround($280 * $297);
    $301 = Math_fround($288 * $298);
    $302 = Math_fround($300 + $301);
    $303 = Math_fround($296 * $299);
    $304 = Math_fround($302 + $303);
    $305 = Math_fround(HEAPF32[$229>>2]);
    $306 = Math_fround(HEAPF32[$230>>2]);
    $307 = Math_fround(HEAPF32[$231>>2]);
    $308 = Math_fround($280 * $305);
    $309 = Math_fround($288 * $306);
    $310 = Math_fround($308 + $309);
    $311 = Math_fround($296 * $307);
    $312 = Math_fround($310 + $311);
    $313 = $304 > $312;
    $314 = $313&1;
    HEAP32[$272>>2] = $314;
    ;HEAP32[$3+0>>2]=HEAP32[$224+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$224+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$224+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$224+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$228+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$228+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$228+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$228+12>>2]|0;
    $b$a$i$i$i$i = $313 ? $3 : $2;
    $315 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
    $$in1$i$i$i$i = (($b$a$i$i$i$i) + 4|0);
    $316 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
    $$in2$i$i$i$i = (($b$a$i$i$i$i) + 8|0);
    $317 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
    $318 = Math_fround(HEAPF32[$232>>2]);
    $319 = Math_fround(HEAPF32[$233>>2]);
    $320 = Math_fround(HEAPF32[$234>>2]);
    $321 = Math_fround($273 * $315);
    $322 = Math_fround($281 * $316);
    $323 = Math_fround($321 + $322);
    $324 = Math_fround($289 * $317);
    $325 = Math_fround($323 + $324);
    $326 = Math_fround($275 * $315);
    $327 = Math_fround($283 * $316);
    $328 = Math_fround($326 + $327);
    $329 = Math_fround($291 * $317);
    $330 = Math_fround($328 + $329);
    $331 = Math_fround($278 * $315);
    $332 = Math_fround($286 * $316);
    $333 = Math_fround($331 + $332);
    $334 = Math_fround($294 * $317);
    $335 = Math_fround($333 + $334);
    $336 = Math_fround($325 + $318);
    $337 = Math_fround($330 + $319);
    $338 = Math_fround($335 + $320);
    HEAPF32[$supportA1>>2] = $336;
    HEAPF32[$235>>2] = $337;
    HEAPF32[$236>>2] = $338;
    HEAPF32[$237>>2] = Math_fround(0.0);
    ;HEAP32[$271+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$271+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$271+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$271+12>>2]=HEAP32[$supportA1+12>>2]|0;
    $339 = (($B) + ($270<<4)|0);
    $340 = (($bInd) + ($270<<2)|0);
    $341 = Math_fround(HEAPF32[$239>>2]);
    $342 = Math_fround(HEAPF32[$240>>2]);
    $343 = Math_fround(HEAPF32[$241>>2]);
    $344 = Math_fround($265 * $341);
    $345 = Math_fround($267 * $342);
    $346 = Math_fround($344 + $345);
    $347 = Math_fround($269 * $343);
    $348 = Math_fround($346 + $347);
    $349 = Math_fround(HEAPF32[$243>>2]);
    $350 = Math_fround(HEAPF32[$244>>2]);
    $351 = Math_fround(HEAPF32[$245>>2]);
    $352 = Math_fround($265 * $349);
    $353 = Math_fround($267 * $350);
    $354 = Math_fround($352 + $353);
    $355 = Math_fround($269 * $351);
    $356 = Math_fround($354 + $355);
    $357 = $348 > $356;
    $358 = $357&1;
    HEAP32[$340>>2] = $358;
    ;HEAP32[$3+0>>2]=HEAP32[$238+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$238+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$238+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$238+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$242+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$242+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$242+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$242+12>>2]|0;
    $b$a$i$i$i = $357 ? $3 : $2;
    $359 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
    $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
    $360 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
    $361 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    HEAPF32[$supportB2>>2] = $359;
    HEAPF32[$246>>2] = $360;
    HEAPF32[$247>>2] = $361;
    HEAPF32[$248>>2] = Math_fround(0.0);
    ;HEAP32[$339+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$339+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$339+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$339+12>>2]=HEAP32[$supportB2+12>>2]|0;
    $362 = Math_fround($336 - $359);
    $363 = Math_fround($337 - $360);
    $364 = Math_fround($338 - $361);
    HEAPF32[$support3>>2] = $362;
    HEAPF32[$249>>2] = $363;
    HEAPF32[$250>>2] = $364;
    HEAPF32[$251>>2] = Math_fround(0.0);
    $365 = HEAP32[$size>>2]|0;
    $366 = (($365) + 1)|0;
    HEAP32[$size>>2] = $366;
    $367 = (($Q) + ($365<<4)|0);
    ;HEAP32[$367+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$367+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$367+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$367+12>>2]=HEAP32[$support3+12>>2]|0;
    $368 = Math_fround(HEAPF32[$252>>2]);
    $369 = Math_fround(HEAPF32[$253>>2]);
    $370 = $368 > $369;
    $$$i134 = $370 ? $368 : $369;
    $371 = $$$i743813 > $$$i134;
    $$$i = $371 ? $$$i743813 : $$$i134;
    $372 = Math_fround($17 + $$$i);
    $373 = Math_fround($372 * $372);
    $374 = Math_fround($375 * $373);
    $376 = Math_fround($265 * $362);
    $377 = Math_fround($267 * $363);
    $378 = Math_fround($376 + $377);
    $379 = Math_fround($269 * $364);
    $380 = Math_fround($378 + $379);
    $381 = Math_fround($380 * $380);
    $382 = $380 > Math_fround(0.0);
    $383 = $381 > $374;
    if ($382) {
     $phitmp759 = $383 ^ 1;
     $387 = $383;$389 = $phitmp759;
    } else {
     $387 = 0;$389 = 1;
    }
    $384 = Math_fround($375 - $380);
    $385 = Math_fround($24 * $375);
    $386 = $385 >= $384;
    $brmerge$demorgan = $386 | $387;
    if ($brmerge$demorgan) {
     $388 = $389 ^ 1;
     $$751 = $386 | $388;
     if ($$751) {
      break;
     }
    }
    do {
     if ((($365|0) == 1)) {
      $436 = Math_fround(HEAPF32[$Q>>2]);
      $437 = Math_fround(HEAPF32[$256>>2]);
      $438 = Math_fround(HEAPF32[$257>>2]);
      $439 = Math_fround($362 - $436);
      $440 = Math_fround($363 - $437);
      $441 = Math_fround($364 - $438);
      $442 = Math_fround($439 * $439);
      $443 = Math_fround($440 * $440);
      $444 = Math_fround($442 + $443);
      $445 = Math_fround($441 * $441);
      $446 = Math_fround($444 + $445);
      $447 = $446 == Math_fround(0.0);
      if ($447) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $448 = Math_fround($437 * $440);
       $449 = Math_fround(-$448);
       $450 = Math_fround($436 * $439);
       $451 = Math_fround($449 - $450);
       $452 = Math_fround($438 * $441);
       $453 = Math_fround($451 - $452);
       $454 = Math_fround(HEAPF32[$A>>2]);
       $455 = Math_fround(HEAPF32[$258>>2]);
       $456 = Math_fround(HEAPF32[$259>>2]);
       $457 = Math_fround($336 - $454);
       $458 = Math_fround($337 - $455);
       $459 = Math_fround($338 - $456);
       $460 = Math_fround(HEAPF32[$B>>2]);
       $461 = Math_fround(HEAPF32[$260>>2]);
       $462 = Math_fround(HEAPF32[$261>>2]);
       $463 = Math_fround($359 - $460);
       $464 = Math_fround($360 - $461);
       $465 = Math_fround($361 - $462);
       $466 = Math_fround($453 / $446);
       $467 = $466 > Math_fround(1.0);
       $$$i$i$i = $467 ? Math_fround(1.0) : $466;
       $468 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $468 ? $$$i$i$i : Math_fround(0.0);
       $469 = Math_fround($457 * $$$i8$i$i);
       $470 = Math_fround($458 * $$$i8$i$i);
       $471 = Math_fround($459 * $$$i8$i$i);
       $472 = Math_fround($454 + $469);
       $473 = Math_fround($455 + $470);
       $474 = Math_fround($456 + $471);
       $475 = Math_fround($463 * $$$i8$i$i);
       $476 = Math_fround($464 * $$$i8$i$i);
       $477 = Math_fround($465 * $$$i8$i$i);
       $478 = Math_fround($460 + $475);
       $479 = Math_fround($461 + $476);
       $480 = Math_fround($462 + $477);
       HEAPF32[$closA>>2] = $472;
       HEAPF32[$18>>2] = $473;
       HEAPF32[$19>>2] = $474;
       HEAPF32[$20>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $478;
       HEAPF32[$21>>2] = $479;
       HEAPF32[$22>>2] = $480;
       HEAPF32[$23>>2] = Math_fround(0.0);
       $481 = Math_fround($472 - $478);
       $482 = Math_fround($473 - $479);
       $483 = Math_fround($474 - $480);
       HEAPF32[$5>>2] = $481;
       HEAPF32[$254>>2] = $482;
       HEAPF32[$255>>2] = $483;
       HEAPF32[$262>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($365|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$263,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($365|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($365|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    $484 = Math_fround(HEAPF32[$5>>2]);
    $485 = Math_fround(HEAPF32[$254>>2]);
    $486 = Math_fround(HEAPF32[$255>>2]);
    $487 = Math_fround($484 * $484);
    $488 = Math_fround($485 * $485);
    $489 = Math_fround($487 + $488);
    $490 = Math_fround($486 * $486);
    $491 = Math_fround($489 + $490);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1232+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1232+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1232+8>>2]|0;
    $492 = $375 > $491;
    $493 = $491 > $24;
    if (!($493)) {
     label = 37;
     break;
    }
    if (!($492)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre860 = Math_fround(HEAPF32[$18>>2]);
    $$pre861 = Math_fround(HEAPF32[$19>>2]);
    $$pre862 = Math_fround(HEAPF32[$20>>2]);
    $$pre863 = Math_fround(HEAPF32[$closB>>2]);
    $$pre864 = Math_fround(HEAPF32[$21>>2]);
    $$pre865 = Math_fround(HEAPF32[$22>>2]);
    $$pre866 = Math_fround(HEAPF32[$23>>2]);
    $$$i743813 = $$$i;$265 = $484;$267 = $485;$269 = $486;$375 = $491;$508 = $$pre;$509 = $$pre860;$510 = $$pre861;$511 = $$pre862;$512 = $$pre863;$513 = $$pre864;$514 = $$pre865;$515 = $$pre866;
   }
   if ((label|0) == 37) {
    $494 = HEAP32[$size>>2]|0;
    if ($492) {
     $549 = $494;
     break;
    }
    $495 = (($494) + -1)|0;
    $496 = ($aIndices|0)==(0|0);
    if (!($496)) {
     $497 = $495&255;
     HEAP8[$_size>>0] = $497;
     $498 = ($495|0)==(0);
     if (!($498)) {
      $i$01$i29 = 0;
      while(1) {
       $499 = (($aInd) + ($i$01$i29<<2)|0);
       $500 = HEAP32[$499>>2]|0;
       $501 = $500&255;
       $502 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$502>>0] = $501;
       $503 = (($bInd) + ($i$01$i29<<2)|0);
       $504 = HEAP32[$503>>2]|0;
       $505 = $504&255;
       $506 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$506>>0] = $505;
       $507 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($507|0)==($495|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $507;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $508;
    HEAPF32[$18>>2] = $509;
    HEAPF32[$19>>2] = $510;
    HEAPF32[$20>>2] = $511;
    HEAPF32[$closB>>2] = $512;
    HEAPF32[$21>>2] = $513;
    HEAPF32[$22>>2] = $514;
    HEAPF32[$23>>2] = $515;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $516 = Math_fround($508 - $512);
    $517 = Math_fround($509 - $513);
    $518 = Math_fround($510 - $514);
    $519 = (Math_fround(Math_sqrt((Math_fround($375)))));
    $520 = Math_fround(Math_fround(1.0) / $519);
    $521 = Math_fround($516 * $520);
    $522 = Math_fround($517 * $520);
    $523 = Math_fround($518 * $520);
    $524 = Math_fround($7 * $521);
    $525 = Math_fround($7 * $522);
    $526 = Math_fround($7 * $523);
    $527 = Math_fround($508 - $524);
    $528 = Math_fround($509 - $525);
    $529 = Math_fround($510 - $526);
    HEAPF32[$contactA>>2] = $527;
    $530 = (($contactA) + 4|0);
    HEAPF32[$530>>2] = $528;
    $531 = (($contactA) + 8|0);
    HEAPF32[$531>>2] = $529;
    $532 = (($contactA) + 12|0);
    HEAPF32[$532>>2] = Math_fround(0.0);
    $533 = Math_fround($9 * $521);
    $534 = Math_fround($9 * $522);
    $535 = Math_fround($9 * $523);
    $536 = Math_fround($533 + $512);
    $537 = Math_fround($534 + $513);
    $538 = Math_fround($535 + $514);
    HEAPF32[$contactB>>2] = $536;
    $539 = (($contactB) + 4|0);
    HEAPF32[$539>>2] = $537;
    $540 = (($contactB) + 8|0);
    HEAPF32[$540>>2] = $538;
    $541 = (($contactB) + 12|0);
    HEAPF32[$541>>2] = Math_fround(0.0);
    $542 = Math_fround($519 - $17);
    HEAPF32[$penetrationDepth>>2] = $542;
    $543 = (($penetrationDepth) + 4|0);
    ;HEAP32[$543+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$543+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$543+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $521;
    $544 = (($normal) + 4|0);
    HEAPF32[$544>>2] = $522;
    $545 = (($normal) + 8|0);
    HEAPF32[$545>>2] = $523;
    $546 = (($normal) + 12|0);
    HEAPF32[$546>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $390 = ($aIndices|0)==(0|0);
   if (!($390)) {
    $391 = $365&255;
    HEAP8[$_size>>0] = $391;
    $392 = ($365|0)==(0);
    if (!($392)) {
     $i$01$i72 = 0;
     while(1) {
      $393 = (($aInd) + ($i$01$i72<<2)|0);
      $394 = HEAP32[$393>>2]|0;
      $395 = $394&255;
      $396 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$396>>0] = $395;
      $397 = (($bInd) + ($i$01$i72<<2)|0);
      $398 = HEAP32[$397>>2]|0;
      $399 = $398&255;
      $400 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$400>>0] = $399;
      $401 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($401|0)==($365|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $401;
      }
     }
    }
   }
   $not$ = $387 ^ 1;
   $$$755 = $389 & $not$;
   if (!($$$755)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $402 = (Math_fround(Math_sqrt((Math_fround($375)))));
   $403 = Math_fround(Math_fround(1.0) / $402);
   $404 = Math_fround($265 * $403);
   $405 = Math_fround($267 * $403);
   $406 = Math_fround($269 * $403);
   $407 = Math_fround(HEAPF32[$closA>>2]);
   $408 = Math_fround(HEAPF32[$18>>2]);
   $409 = Math_fround(HEAPF32[$19>>2]);
   $410 = Math_fround($7 * $404);
   $411 = Math_fround($7 * $405);
   $412 = Math_fround($7 * $406);
   $413 = Math_fround($407 - $410);
   $414 = Math_fround($408 - $411);
   $415 = Math_fround($409 - $412);
   HEAPF32[$contactA>>2] = $413;
   $416 = (($contactA) + 4|0);
   HEAPF32[$416>>2] = $414;
   $417 = (($contactA) + 8|0);
   HEAPF32[$417>>2] = $415;
   $418 = (($contactA) + 12|0);
   HEAPF32[$418>>2] = Math_fround(0.0);
   $419 = Math_fround(HEAPF32[$closB>>2]);
   $420 = Math_fround(HEAPF32[$21>>2]);
   $421 = Math_fround(HEAPF32[$22>>2]);
   $422 = Math_fround($9 * $404);
   $423 = Math_fround($9 * $405);
   $424 = Math_fround($9 * $406);
   $425 = Math_fround($422 + $419);
   $426 = Math_fround($423 + $420);
   $427 = Math_fround($424 + $421);
   HEAPF32[$contactB>>2] = $425;
   $428 = (($contactB) + 4|0);
   HEAPF32[$428>>2] = $426;
   $429 = (($contactB) + 8|0);
   HEAPF32[$429>>2] = $427;
   $430 = (($contactB) + 12|0);
   HEAPF32[$430>>2] = Math_fround(0.0);
   $431 = Math_fround($402 - $17);
   HEAPF32[$penetrationDepth>>2] = $431;
   $432 = (($penetrationDepth) + 4|0);
   ;HEAP32[$432+0>>2]=HEAP32[$$sroa$1234+0>>2]|0;HEAP32[$432+4>>2]=HEAP32[$$sroa$1234+4>>2]|0;HEAP32[$432+8>>2]=HEAP32[$$sroa$1234+8>>2]|0;
   HEAPF32[$normal>>2] = $404;
   $433 = (($normal) + 4|0);
   HEAPF32[$433>>2] = $405;
   $434 = (($normal) + 8|0);
   HEAPF32[$434>>2] = $406;
   $435 = (($normal) + 12|0);
   HEAPF32[$435>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $215 = HEAP32[$size>>2]|0;
   $549 = $215;
  }
 } while(0);
 $547 = ($aIndices|0)==(0|0);
 if (!($547)) {
  $548 = $549&255;
  HEAP8[$_size>>0] = $548;
  $550 = ($549|0)==(0);
  if (!($550)) {
   $i$01$i = 0;
   while(1) {
    $551 = (($aInd) + ($i$01$i<<2)|0);
    $552 = HEAP32[$551>>2]|0;
    $553 = $552&255;
    $554 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$554>>0] = $553;
    $555 = (($bInd) + ($i$01$i<<2)|0);
    $556 = HEAP32[$555>>2]|0;
    $557 = $556&255;
    $558 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$558>>0] = $557;
    $559 = (($i$01$i) + 1)|0;
    $exitcond$i = ($559|0)==($549|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $559;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($agg$result,$this,$dir,$support,$index) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 $support = $support|0;
 $index = $index|0;
 var $$0$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$sum$i$i = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0;
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_dir = 0;
 var $i$041$i$i = 0, $maxIndex$040$i$i = 0, $maxIndex$1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_dir = sp;
 $0 = Math_fround(HEAPF32[$dir>>2]);
 $1 = (($dir) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($dir) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 96|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 * $6);
 $8 = (($this) + 100|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($2 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($this) + 104|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($4 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (($this) + 112|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($0 * $17);
 $19 = (($this) + 116|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($2 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($this) + 120|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($4 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($this) + 128|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($0 * $28);
 $30 = (($this) + 132|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($2 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($this) + 136|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($4 * $35);
 $37 = Math_fround($33 + $36);
 HEAPF32[$_dir>>2] = $15;
 $38 = (($_dir) + 4|0);
 HEAPF32[$38>>2] = $26;
 $39 = (($_dir) + 8|0);
 HEAPF32[$39>>2] = $37;
 $40 = (($_dir) + 12|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($this) + 196|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $45 = (($this) + 200|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($this) + 204|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48&255)>(1);
  if ($49) {
   $50 = (($46) + 4|0);
   $51 = (($46) + 8|0);
   $52 = Math_fround(HEAPF32[$50>>2]);
   $53 = Math_fround(HEAPF32[$46>>2]);
   $54 = Math_fround($26 * $52);
   $55 = Math_fround($15 * $53);
   $56 = Math_fround(HEAPF32[$51>>2]);
   $57 = Math_fround($37 * $56);
   $58 = Math_fround($54 + $55);
   $59 = Math_fround($58 + $57);
   $61 = $46;$75 = $59;$i$041$i$i = 1;$maxIndex$040$i$i = 0;
   while(1) {
    $$sum$i$i = (($i$041$i$i) + 10)|0;
    $60 = ((($61) + (($$sum$i$i*12)|0)|0) + 8|0);
    $62 = HEAP32[$45>>2]|0;
    $63 = (($62) + (($i$041$i$i*12)|0)|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = ((($62) + (($i$041$i$i*12)|0)|0) + 4|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($62) + (($i$041$i$i*12)|0)|0) + 8|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = Math_fround($64 * $15);
    $70 = Math_fround($66 * $26);
    $71 = Math_fround($69 + $70);
    $72 = Math_fround($68 * $37);
    $73 = Math_fround($71 + $72);
    $74 = $73 > $75;
    $76 = $74 ? $73 : $75;
    $maxIndex$1$i$i = $74 ? $i$041$i$i : $maxIndex$040$i$i;
    $77 = (($i$041$i$i) + 1)|0;
    $78 = HEAP8[$47>>0]|0;
    $79 = $78&255;
    $80 = ($77>>>0)<($79>>>0);
    if ($80) {
     $61 = $62;$75 = $76;$i$041$i$i = $77;$maxIndex$040$i$i = $maxIndex$1$i$i;
    } else {
     $$0$i = $maxIndex$1$i$i;$82 = $62;
     break;
    }
   }
  } else {
   $$0$i = 0;$82 = $46;
  }
 } else {
  $44 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$_dir)|0);
  $$phi$trans$insert = (($this) + 200|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$0$i = $44;$82 = $$pre;
 }
 HEAP32[$index>>2] = $$0$i;
 $81 = (($82) + (($$0$i*12)|0)|0);
 $83 = Math_fround(HEAPF32[$81>>2]);
 $84 = ((($82) + (($$0$i*12)|0)|0) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = ((($82) + (($$0$i*12)|0)|0) + 8|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround(HEAPF32[$5>>2]);
 $89 = Math_fround($83 * $88);
 $90 = Math_fround(HEAPF32[$16>>2]);
 $91 = Math_fround($85 * $90);
 $92 = Math_fround($89 + $91);
 $93 = Math_fround(HEAPF32[$27>>2]);
 $94 = Math_fround($87 * $93);
 $95 = Math_fround($92 + $94);
 $96 = Math_fround(HEAPF32[$8>>2]);
 $97 = Math_fround($83 * $96);
 $98 = Math_fround(HEAPF32[$19>>2]);
 $99 = Math_fround($85 * $98);
 $100 = Math_fround($97 + $99);
 $101 = Math_fround(HEAPF32[$30>>2]);
 $102 = Math_fround($87 * $101);
 $103 = Math_fround($100 + $102);
 $104 = Math_fround(HEAPF32[$12>>2]);
 $105 = Math_fround($83 * $104);
 $106 = Math_fround(HEAPF32[$23>>2]);
 $107 = Math_fround($85 * $106);
 $108 = Math_fround($105 + $107);
 $109 = Math_fround(HEAPF32[$34>>2]);
 $110 = Math_fround($87 * $109);
 $111 = Math_fround($108 + $110);
 HEAPF32[$agg$result>>2] = $95;
 $112 = (($agg$result) + 4|0);
 HEAPF32[$112>>2] = $103;
 $113 = (($agg$result) + 8|0);
 HEAPF32[$113>>2] = $111;
 $114 = (($agg$result) + 12|0);
 HEAPF32[$114>>2] = Math_fround(0.0);
 ;HEAP32[$support+0>>2]=HEAP32[$agg$result+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$agg$result+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$agg$result+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$agg$result+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu9TriangleV12supportLocalERKNS_6shdfnd3aos5Vec3VERi($agg$result,$this,$dir,$index) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 $index = $index|0;
 var $$in1$i = 0, $$in1$i15 = 0, $$in1$i29 = 0, $$in2$i = 0, $$in2$i17 = 0, $$in2$i31 = 0, $$in3$i33 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0;
 var $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $9 = 0, $b$a$i = 0, $b$a$i12 = 0, $b$a$i20 = 0, $b$a$i26 = 0;
 var $phitmp = 0, $phitmp198 = 0, $vOne = 0, $vTwo = 0, $vZero = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 112|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $vZero = sp + 48|0;
 $vOne = sp + 64|0;
 $vTwo = sp + 80|0;
 $4 = sp + 96|0;
 ;HEAP32[$vZero+0>>2]=0|0;HEAP32[$vZero+4>>2]=0|0;HEAP32[$vZero+8>>2]=0|0;HEAP32[$vZero+12>>2]=0|0;
 HEAP32[$vOne>>2] = 1;
 $5 = (($vOne) + 4|0);
 HEAP32[$5>>2] = 1;
 $6 = (($vOne) + 8|0);
 HEAP32[$6>>2] = 1;
 $7 = (($vOne) + 12|0);
 HEAP32[$7>>2] = 1;
 HEAP32[$vTwo>>2] = 2;
 $8 = (($vTwo) + 4|0);
 HEAP32[$8>>2] = 2;
 $9 = (($vTwo) + 8|0);
 HEAP32[$9>>2] = 2;
 $10 = (($vTwo) + 12|0);
 HEAP32[$10>>2] = 2;
 $11 = (($this) + 96|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 100|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 104|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 108|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 112|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 116|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 120|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($this) + 124|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 128|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 132|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($this) + 136|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 140|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround(HEAPF32[$dir>>2]);
 $36 = (($dir) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($dir) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($12 * $35);
 $41 = Math_fround($14 * $37);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($16 * $39);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($20 * $35);
 $46 = Math_fround($22 * $37);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($24 * $39);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($28 * $35);
 $51 = Math_fround($30 * $37);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($32 * $39);
 $54 = Math_fround($52 + $53);
 $55 = $44 > $49;
 $56 = $44 > $54;
 if ($55) {
  $phitmp = $56 ^ 1;
  $phitmp198 = $56 ? $3 : $2;
  $65 = $phitmp;$83 = $phitmp198;
 } else {
  $65 = 1;$83 = $2;
 }
 $57 = $49 > $54;
 $b$a$i26 = $57 ? $vOne : $vTwo;
 $58 = HEAP32[$b$a$i26>>2]|0;
 $$in1$i29 = (($b$a$i26) + 4|0);
 $59 = HEAP32[$$in1$i29>>2]|0;
 $$in2$i31 = (($b$a$i26) + 8|0);
 $60 = HEAP32[$$in2$i31>>2]|0;
 $$in3$i33 = (($b$a$i26) + 12|0);
 $61 = HEAP32[$$in3$i33>>2]|0;
 HEAP32[$4>>2] = $58;
 $62 = (($4) + 4|0);
 HEAP32[$62>>2] = $59;
 $63 = (($4) + 8|0);
 HEAP32[$63>>2] = $60;
 $64 = (($4) + 12|0);
 HEAP32[$64>>2] = $61;
 $b$a$i20 = $65 ? $4 : $vZero;
 $66 = HEAP32[$b$a$i20>>2]|0;
 HEAP32[$index>>2] = $66;
 HEAPF32[$1>>2] = $20;
 $67 = (($1) + 4|0);
 HEAPF32[$67>>2] = $22;
 $68 = (($1) + 8|0);
 HEAPF32[$68>>2] = $24;
 $69 = (($1) + 12|0);
 HEAPF32[$69>>2] = $26;
 HEAPF32[$0>>2] = $28;
 $70 = (($0) + 4|0);
 HEAPF32[$70>>2] = $30;
 $71 = (($0) + 8|0);
 HEAPF32[$71>>2] = $32;
 $72 = (($0) + 12|0);
 HEAPF32[$72>>2] = $34;
 $b$a$i12 = $57 ? $1 : $0;
 $73 = Math_fround(HEAPF32[$b$a$i12>>2]);
 $$in1$i15 = (($b$a$i12) + 4|0);
 $74 = Math_fround(HEAPF32[$$in1$i15>>2]);
 $$in2$i17 = (($b$a$i12) + 8|0);
 $75 = Math_fround(HEAPF32[$$in2$i17>>2]);
 HEAPF32[$3>>2] = $12;
 $76 = (($3) + 4|0);
 HEAPF32[$76>>2] = $14;
 $77 = (($3) + 8|0);
 HEAPF32[$77>>2] = $16;
 $78 = (($3) + 12|0);
 HEAPF32[$78>>2] = $18;
 HEAPF32[$2>>2] = $73;
 $79 = (($2) + 4|0);
 HEAPF32[$79>>2] = $74;
 $80 = (($2) + 8|0);
 HEAPF32[$80>>2] = $75;
 $81 = (($2) + 12|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 $b$a$i = $65 ? $2 : $3;
 $82 = Math_fround(HEAPF32[$b$a$i>>2]);
 $$in1$i = (($83) + 4|0);
 $84 = Math_fround(HEAPF32[$$in1$i>>2]);
 $$in2$i = (($83) + 8|0);
 $85 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$agg$result>>2] = $82;
 $86 = (($agg$result) + 4|0);
 HEAPF32[$86>>2] = $84;
 $87 = (($agg$result) + 8|0);
 HEAPF32[$87>>2] = $85;
 $88 = (($agg$result) + 12|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu24ShrunkConvexHullNoScaleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVERS4_Ri($agg$result,$this,$dir,$aTob,$support,$index) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 $aTob = $aTob|0;
 $support = $support|0;
 $index = $index|0;
 var $$0$i$i = 0, $$sum$i$i$i = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0;
 var $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_dir = 0, $i$041$i$i$i = 0, $maxIndex$040$i$i$i = 0, $maxIndex$1$i$i$i = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_dir = sp + 16|0;
 $p = sp;
 $0 = Math_fround(HEAPF32[$dir>>2]);
 $1 = (($dir) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($dir) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$aTob>>2]);
 $6 = Math_fround($0 * $5);
 $7 = (($aTob) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($2 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($aTob) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($4 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($aTob) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($0 * $16);
 $18 = (($aTob) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($2 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (($aTob) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($4 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($aTob) + 32|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($0 * $27);
 $29 = (($aTob) + 36|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($2 * $30);
 $32 = Math_fround($28 + $31);
 $33 = (($aTob) + 40|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($4 * $34);
 $36 = Math_fround($32 + $35);
 HEAPF32[$_dir>>2] = $14;
 $37 = (($_dir) + 4|0);
 HEAPF32[$37>>2] = $25;
 $38 = (($_dir) + 8|0);
 HEAPF32[$38>>2] = $36;
 $39 = (($_dir) + 12|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($this) + 196|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  $44 = (($this) + 200|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($this) + 204|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = ($47&255)>(1);
  if ($48) {
   $49 = (($45) + 4|0);
   $50 = (($45) + 8|0);
   $51 = Math_fround(HEAPF32[$49>>2]);
   $52 = Math_fround(HEAPF32[$45>>2]);
   $53 = Math_fround($25 * $51);
   $54 = Math_fround($14 * $52);
   $55 = Math_fround(HEAPF32[$50>>2]);
   $56 = Math_fround($36 * $55);
   $57 = Math_fround($53 + $54);
   $58 = Math_fround($57 + $56);
   $60 = $45;$74 = $58;$i$041$i$i$i = 1;$maxIndex$040$i$i$i = 0;
   while(1) {
    $$sum$i$i$i = (($i$041$i$i$i) + 10)|0;
    $59 = ((($60) + (($$sum$i$i$i*12)|0)|0) + 8|0);
    $61 = HEAP32[$44>>2]|0;
    $62 = (($61) + (($i$041$i$i$i*12)|0)|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    $64 = ((($61) + (($i$041$i$i$i*12)|0)|0) + 4|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    $66 = ((($61) + (($i$041$i$i$i*12)|0)|0) + 8|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = Math_fround($63 * $14);
    $69 = Math_fround($65 * $25);
    $70 = Math_fround($68 + $69);
    $71 = Math_fround($67 * $36);
    $72 = Math_fround($70 + $71);
    $73 = $72 > $74;
    $75 = $73 ? $72 : $74;
    $maxIndex$1$i$i$i = $73 ? $i$041$i$i$i : $maxIndex$040$i$i$i;
    $76 = (($i$041$i$i$i) + 1)|0;
    $77 = HEAP8[$46>>0]|0;
    $78 = $77&255;
    $79 = ($76>>>0)<($78>>>0);
    if ($79) {
     $60 = $61;$74 = $75;$i$041$i$i$i = $76;$maxIndex$040$i$i$i = $maxIndex$1$i$i$i;
    } else {
     $$0$i$i = $maxIndex$1$i$i$i;
     break;
    }
   }
  } else {
   $$0$i$i = 0;
  }
 } else {
  $43 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$_dir)|0);
  $$0$i$i = $43;
 }
 HEAP32[$index>>2] = $$0$i$i;
 $80 = (($this) + 16|0);
 __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($p,$this,$$0$i$i,$80);
 ;HEAP32[$support+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$p+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$p+12>>2]|0;
 $81 = (($aTob) + 48|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($aTob) + 52|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($aTob) + 56|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround(HEAPF32[$p>>2]);
 $88 = (($p) + 4|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($p) + 8|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround(HEAPF32[$aTob>>2]);
 $93 = Math_fround($87 * $92);
 $94 = Math_fround(HEAPF32[$15>>2]);
 $95 = Math_fround($89 * $94);
 $96 = Math_fround($93 + $95);
 $97 = Math_fround(HEAPF32[$26>>2]);
 $98 = Math_fround($91 * $97);
 $99 = Math_fround($96 + $98);
 $100 = Math_fround(HEAPF32[$7>>2]);
 $101 = Math_fround($87 * $100);
 $102 = Math_fround(HEAPF32[$18>>2]);
 $103 = Math_fround($89 * $102);
 $104 = Math_fround($101 + $103);
 $105 = Math_fround(HEAPF32[$29>>2]);
 $106 = Math_fround($91 * $105);
 $107 = Math_fround($104 + $106);
 $108 = Math_fround(HEAPF32[$11>>2]);
 $109 = Math_fround($87 * $108);
 $110 = Math_fround(HEAPF32[$22>>2]);
 $111 = Math_fround($89 * $110);
 $112 = Math_fround($109 + $111);
 $113 = Math_fround(HEAPF32[$33>>2]);
 $114 = Math_fround($91 * $113);
 $115 = Math_fround($112 + $114);
 $116 = Math_fround($82 + $99);
 $117 = Math_fround($84 + $107);
 $118 = Math_fround($86 + $115);
 HEAPF32[$agg$result>>2] = $116;
 $119 = (($agg$result) + 4|0);
 HEAPF32[$119>>2] = $117;
 $120 = (($agg$result) + 8|0);
 HEAPF32[$120>>2] = $118;
 $121 = (($agg$result) + 12|0);
 HEAPF32[$121>>2] = Math_fround(0.0);
 ;HEAP32[$support+0>>2]=HEAP32[$agg$result+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$agg$result+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$agg$result+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$agg$result+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu24ShrunkConvexHullNoScaleV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($agg$result,$this,$index,$margin_) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $index = $index|0;
 $margin_ = $margin_|0;
 var $$sroa$1 = 0, $$sum = 0, $$sum$i = 0, $$sum154 = 0, $$sum155 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0;
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0;
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$sroa$1 = sp;
 $0 = (($this) + 192|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 39|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = (($3) + (($6*20)|0)|0);
 $8 = (($1) + 38|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = ($10*12)|0;
 $12 = (($1) + 36|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13&65535;
 $15 = $14 << 1;
 $$sum$i = (($15) + ($11))|0;
 $16 = (($this) + 200|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + (($index*12)|0)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($17) + (($index*12)|0)|0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = ((($17) + (($index*12)|0)|0) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = ($index*3)|0;
 $$sum = (($$sum$i) + ($24))|0;
 $25 = (($7) + ($$sum)|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = (($24) + 1)|0;
 $$sum154 = (($28) + ($$sum$i))|0;
 $29 = (($7) + ($$sum154)|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = $30&255;
 $32 = (($24) + 2)|0;
 $$sum155 = (($32) + ($$sum$i))|0;
 $33 = (($7) + ($$sum155)|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34&255;
 $36 = (($3) + (($27*20)|0)|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = ((($3) + (($27*20)|0)|0) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = ((($3) + (($27*20)|0)|0) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($37 * $37);
 $43 = Math_fround($39 * $39);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($41 * $41);
 $46 = Math_fround($44 + $45);
 $47 = (Math_fround(Math_sqrt((Math_fround($46)))));
 $48 = Math_fround(Math_fround(1.0) / $47);
 $49 = Math_fround($37 * $48);
 $50 = Math_fround($39 * $48);
 $51 = Math_fround($41 * $48);
 $52 = (($3) + (($31*20)|0)|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = ((($3) + (($31*20)|0)|0) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = ((($3) + (($31*20)|0)|0) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($53 * $53);
 $59 = Math_fround($55 * $55);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($57 * $57);
 $62 = Math_fround($60 + $61);
 $63 = (Math_fround(Math_sqrt((Math_fround($62)))));
 $64 = Math_fround(Math_fround(1.0) / $63);
 $65 = Math_fround($53 * $64);
 $66 = Math_fround($55 * $64);
 $67 = Math_fround($57 * $64);
 $68 = (($3) + (($35*20)|0)|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = ((($3) + (($35*20)|0)|0) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = ((($3) + (($35*20)|0)|0) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($69 * $69);
 $75 = Math_fround($71 * $71);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($73 * $73);
 $78 = Math_fround($76 + $77);
 $79 = (Math_fround(Math_sqrt((Math_fround($78)))));
 $80 = Math_fround(Math_fround(1.0) / $79);
 $81 = Math_fround($69 * $80);
 $82 = Math_fround($71 * $80);
 $83 = Math_fround($73 * $80);
 $84 = Math_fround(HEAPF32[$margin_>>2]);
 $85 = Math_fround($19 * $49);
 $86 = Math_fround($21 * $50);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($23 * $51);
 $89 = Math_fround($88 + $87);
 $90 = Math_fround($84 - $89);
 $91 = Math_fround($19 * $65);
 $92 = Math_fround($21 * $66);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($23 * $67);
 $95 = Math_fround($94 + $93);
 $96 = Math_fround($84 - $95);
 $97 = Math_fround($19 * $81);
 $98 = Math_fround($21 * $82);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($23 * $83);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($84 - $101);
 $103 = Math_fround($66 * $83);
 $104 = Math_fround($67 * $82);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($67 * $81);
 $107 = Math_fround($65 * $83);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($65 * $82);
 $110 = Math_fround($66 * $81);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($49 * $105);
 $113 = Math_fround($50 * $108);
 $114 = Math_fround($112 + $113);
 $115 = Math_fround($51 * $111);
 $116 = Math_fround($115 + $114);
 $117 = Math_fround($81 * $96);
 $118 = Math_fround($82 * $96);
 $119 = Math_fround($83 * $96);
 $120 = Math_fround($65 * $102);
 $121 = Math_fround($66 * $102);
 $122 = Math_fround($67 * $102);
 $123 = Math_fround($117 - $120);
 $124 = Math_fround($118 - $121);
 $125 = Math_fround($119 - $122);
 $126 = Math_fround($50 * $125);
 $127 = Math_fround($51 * $124);
 $128 = Math_fround($126 - $127);
 $129 = Math_fround($51 * $123);
 $130 = Math_fround($49 * $125);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($49 * $124);
 $133 = Math_fround($50 * $123);
 $134 = Math_fround($132 - $133);
 $135 = Math_fround($90 * $105);
 $136 = Math_fround($90 * $108);
 $137 = Math_fround($90 * $111);
 $138 = Math_fround($128 - $135);
 $139 = Math_fround($131 - $136);
 $140 = Math_fround($134 - $137);
 $141 = Math_fround(Math_fround(1.0) / $116);
 $142 = Math_fround($141 * $138);
 $143 = Math_fround($141 * $139);
 $144 = Math_fround($141 * $140);
 HEAPF32[$agg$result>>2] = $142;
 $145 = (($agg$result) + 4|0);
 HEAPF32[$145>>2] = $143;
 $146 = (($agg$result) + 8|0);
 HEAPF32[$146>>2] = $144;
 $147 = (($agg$result) + 12|0);
 HEAPF32[$147>>2] = Math_fround(0.0);
 $148 = Math_fround($19 - $142);
 $149 = Math_fround($21 - $143);
 $150 = Math_fround($23 - $144);
 $151 = Math_fround($148 * $148);
 $152 = Math_fround($149 * $149);
 $153 = Math_fround($151 + $152);
 $154 = Math_fround($150 * $150);
 $155 = Math_fround($153 + $154);
 $156 = (Math_fround(Math_sqrt((Math_fround($155)))));
 $157 = (($this) + 48|0);
 HEAPF32[$157>>2] = $156;
 $158 = (($this) + 52|0);
 ;HEAP32[$158+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($agg$result,$this,$dir,$support,$index) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 $support = $support|0;
 $index = $index|0;
 var $$0$i = 0, $$sum$i$i = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = Math_fround(0), $_dir = 0, $i$041$i$i = 0, $maxIndex$040$i$i = 0, $maxIndex$1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_dir = sp;
 $0 = Math_fround(HEAPF32[$dir>>2]);
 $1 = (($dir) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($dir) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 96|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 * $6);
 $8 = (($this) + 100|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($2 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($this) + 104|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($4 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (($this) + 112|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($0 * $17);
 $19 = (($this) + 116|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($2 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($this) + 120|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($4 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($this) + 128|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($0 * $28);
 $30 = (($this) + 132|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($2 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($this) + 136|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($4 * $35);
 $37 = Math_fround($33 + $36);
 HEAPF32[$_dir>>2] = $15;
 $38 = (($_dir) + 4|0);
 HEAPF32[$38>>2] = $26;
 $39 = (($_dir) + 8|0);
 HEAPF32[$39>>2] = $37;
 $40 = (($_dir) + 12|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($this) + 196|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $45 = (($this) + 200|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($this) + 204|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48&255)>(1);
  if ($49) {
   $50 = (($46) + 4|0);
   $51 = (($46) + 8|0);
   $52 = Math_fround(HEAPF32[$50>>2]);
   $53 = Math_fround(HEAPF32[$46>>2]);
   $54 = Math_fround($26 * $52);
   $55 = Math_fround($15 * $53);
   $56 = Math_fround(HEAPF32[$51>>2]);
   $57 = Math_fround($37 * $56);
   $58 = Math_fround($54 + $55);
   $59 = Math_fround($58 + $57);
   $61 = $46;$75 = $59;$i$041$i$i = 1;$maxIndex$040$i$i = 0;
   while(1) {
    $$sum$i$i = (($i$041$i$i) + 10)|0;
    $60 = ((($61) + (($$sum$i$i*12)|0)|0) + 8|0);
    $62 = HEAP32[$45>>2]|0;
    $63 = (($62) + (($i$041$i$i*12)|0)|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = ((($62) + (($i$041$i$i*12)|0)|0) + 4|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($62) + (($i$041$i$i*12)|0)|0) + 8|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = Math_fround($64 * $15);
    $70 = Math_fround($66 * $26);
    $71 = Math_fround($69 + $70);
    $72 = Math_fround($68 * $37);
    $73 = Math_fround($71 + $72);
    $74 = $73 > $75;
    $76 = $74 ? $73 : $75;
    $maxIndex$1$i$i = $74 ? $i$041$i$i : $maxIndex$040$i$i;
    $77 = (($i$041$i$i) + 1)|0;
    $78 = HEAP8[$47>>0]|0;
    $79 = $78&255;
    $80 = ($77>>>0)<($79>>>0);
    if ($80) {
     $61 = $62;$75 = $76;$i$041$i$i = $77;$maxIndex$040$i$i = $maxIndex$1$i$i;
    } else {
     $$0$i = $maxIndex$1$i$i;
     break;
    }
   }
  } else {
   $$0$i = 0;
  }
 } else {
  $44 = (__ZNK5physx2Gu11ConvexHullV12HillClimbingERKNS_6shdfnd3aos5Vec3VE($this,$_dir)|0);
  $$0$i = $44;
 }
 HEAP32[$index>>2] = $$0$i;
 $81 = (($this) + 16|0);
 __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($agg$result,$this,$$0$i,$81);
 ;HEAP32[$support+0>>2]=HEAP32[$agg$result+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$agg$result+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$agg$result+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$agg$result+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($agg$result,$this,$index,$margin_) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $index = $index|0;
 $margin_ = $margin_|0;
 var $$sroa$149 = 0, $$sum = 0, $$sum$i = 0, $$sum206 = 0, $$sum207 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0);
 var $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$sroa$149 = sp;
 $0 = (($this) + 192|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 39|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = (($3) + (($6*20)|0)|0);
 $8 = (($1) + 38|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = ($10*12)|0;
 $12 = (($1) + 36|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13&65535;
 $15 = $14 << 1;
 $$sum$i = (($15) + ($11))|0;
 $16 = (($this) + 200|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + (($index*12)|0)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($17) + (($index*12)|0)|0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = ((($17) + (($index*12)|0)|0) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 96|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($19 * $25);
 $27 = (($this) + 112|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($21 * $28);
 $30 = Math_fround($26 + $29);
 $31 = (($this) + 128|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($23 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($this) + 100|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($19 * $36);
 $38 = (($this) + 116|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($21 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($this) + 132|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($23 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($this) + 104|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($19 * $47);
 $49 = (($this) + 120|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($21 * $50);
 $52 = Math_fround($48 + $51);
 $53 = (($this) + 136|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($23 * $54);
 $56 = Math_fround($52 + $55);
 $57 = ($index*3)|0;
 $$sum = (($$sum$i) + ($57))|0;
 $58 = (($7) + ($$sum)|0);
 $59 = HEAP8[$58>>0]|0;
 $60 = $59&255;
 $61 = (($57) + 1)|0;
 $$sum206 = (($61) + ($$sum$i))|0;
 $62 = (($7) + ($$sum206)|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = $63&255;
 $65 = (($57) + 2)|0;
 $$sum207 = (($65) + ($$sum$i))|0;
 $66 = (($7) + ($$sum207)|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = $67&255;
 $69 = (($3) + (($60*20)|0)|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = ((($3) + (($60*20)|0)|0) + 4|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = ((($3) + (($60*20)|0)|0) + 8|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($this) + 144|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($70 * $76);
 $78 = (($this) + 148|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($72 * $79);
 $81 = Math_fround($77 + $80);
 $82 = (($this) + 152|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($74 * $83);
 $85 = Math_fround($81 + $84);
 $86 = (($this) + 160|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($70 * $87);
 $89 = (($this) + 164|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($72 * $90);
 $92 = Math_fround($88 + $91);
 $93 = (($this) + 168|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($74 * $94);
 $96 = Math_fround($92 + $95);
 $97 = (($this) + 176|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($70 * $98);
 $100 = (($this) + 180|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($72 * $101);
 $103 = Math_fround($99 + $102);
 $104 = (($this) + 184|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($74 * $105);
 $107 = Math_fround($103 + $106);
 $108 = Math_fround($85 * $85);
 $109 = Math_fround($96 * $96);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($107 * $107);
 $112 = Math_fround($110 + $111);
 $113 = (Math_fround(Math_sqrt((Math_fround($112)))));
 $114 = Math_fround(Math_fround(1.0) / $113);
 $115 = Math_fround($85 * $114);
 $116 = Math_fround($96 * $114);
 $117 = Math_fround($107 * $114);
 $118 = (($3) + (($64*20)|0)|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = ((($3) + (($64*20)|0)|0) + 4|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = ((($3) + (($64*20)|0)|0) + 8|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($76 * $119);
 $125 = Math_fround($79 * $121);
 $126 = Math_fround($124 + $125);
 $127 = Math_fround($83 * $123);
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($87 * $119);
 $130 = Math_fround($90 * $121);
 $131 = Math_fround($129 + $130);
 $132 = Math_fround($94 * $123);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround($98 * $119);
 $135 = Math_fround($101 * $121);
 $136 = Math_fround($134 + $135);
 $137 = Math_fround($105 * $123);
 $138 = Math_fround($136 + $137);
 $139 = Math_fround($128 * $128);
 $140 = Math_fround($133 * $133);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($138 * $138);
 $143 = Math_fround($142 + $141);
 $144 = (Math_fround(Math_sqrt((Math_fround($143)))));
 $145 = Math_fround(Math_fround(1.0) / $144);
 $146 = Math_fround($128 * $145);
 $147 = Math_fround($133 * $145);
 $148 = Math_fround($138 * $145);
 $149 = (($3) + (($68*20)|0)|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = ((($3) + (($68*20)|0)|0) + 4|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = ((($3) + (($68*20)|0)|0) + 8|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = Math_fround($76 * $150);
 $156 = Math_fround($79 * $152);
 $157 = Math_fround($155 + $156);
 $158 = Math_fround($83 * $154);
 $159 = Math_fround($157 + $158);
 $160 = Math_fround($87 * $150);
 $161 = Math_fround($90 * $152);
 $162 = Math_fround($160 + $161);
 $163 = Math_fround($94 * $154);
 $164 = Math_fround($162 + $163);
 $165 = Math_fround($98 * $150);
 $166 = Math_fround($101 * $152);
 $167 = Math_fround($165 + $166);
 $168 = Math_fround($105 * $154);
 $169 = Math_fround($167 + $168);
 $170 = Math_fround($159 * $159);
 $171 = Math_fround($164 * $164);
 $172 = Math_fround($170 + $171);
 $173 = Math_fround($169 * $169);
 $174 = Math_fround($173 + $172);
 $175 = (Math_fround(Math_sqrt((Math_fround($174)))));
 $176 = Math_fround(Math_fround(1.0) / $175);
 $177 = Math_fround($159 * $176);
 $178 = Math_fround($164 * $176);
 $179 = Math_fround($169 * $176);
 $180 = Math_fround(HEAPF32[$margin_>>2]);
 $181 = Math_fround($34 * $115);
 $182 = Math_fround($45 * $116);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround($56 * $117);
 $185 = Math_fround($184 + $183);
 $186 = Math_fround($180 - $185);
 $187 = Math_fround($34 * $146);
 $188 = Math_fround($45 * $147);
 $189 = Math_fround($187 + $188);
 $190 = Math_fround($56 * $148);
 $191 = Math_fround($190 + $189);
 $192 = Math_fround($180 - $191);
 $193 = Math_fround($34 * $177);
 $194 = Math_fround($45 * $178);
 $195 = Math_fround($193 + $194);
 $196 = Math_fround($56 * $179);
 $197 = Math_fround($196 + $195);
 $198 = Math_fround($180 - $197);
 $199 = Math_fround($147 * $179);
 $200 = Math_fround($148 * $178);
 $201 = Math_fround($199 - $200);
 $202 = Math_fround($148 * $177);
 $203 = Math_fround($146 * $179);
 $204 = Math_fround($202 - $203);
 $205 = Math_fround($146 * $178);
 $206 = Math_fround($147 * $177);
 $207 = Math_fround($205 - $206);
 $208 = Math_fround($115 * $201);
 $209 = Math_fround($116 * $204);
 $210 = Math_fround($208 + $209);
 $211 = Math_fround($117 * $207);
 $212 = Math_fround($211 + $210);
 $213 = Math_fround($177 * $192);
 $214 = Math_fround($178 * $192);
 $215 = Math_fround($179 * $192);
 $216 = Math_fround($146 * $198);
 $217 = Math_fround($147 * $198);
 $218 = Math_fround($148 * $198);
 $219 = Math_fround($213 - $216);
 $220 = Math_fround($214 - $217);
 $221 = Math_fround($215 - $218);
 $222 = Math_fround($116 * $221);
 $223 = Math_fround($117 * $220);
 $224 = Math_fround($222 - $223);
 $225 = Math_fround($117 * $219);
 $226 = Math_fround($115 * $221);
 $227 = Math_fround($225 - $226);
 $228 = Math_fround($115 * $220);
 $229 = Math_fround($116 * $219);
 $230 = Math_fround($228 - $229);
 $231 = Math_fround($186 * $201);
 $232 = Math_fround($186 * $204);
 $233 = Math_fround($186 * $207);
 $234 = Math_fround($224 - $231);
 $235 = Math_fround($227 - $232);
 $236 = Math_fround($230 - $233);
 $237 = Math_fround(Math_fround(1.0) / $212);
 $238 = Math_fround($237 * $234);
 $239 = Math_fround($237 * $235);
 $240 = Math_fround($237 * $236);
 HEAPF32[$agg$result>>2] = $238;
 $241 = (($agg$result) + 4|0);
 HEAPF32[$241>>2] = $239;
 $242 = (($agg$result) + 8|0);
 HEAPF32[$242>>2] = $240;
 $243 = (($agg$result) + 12|0);
 HEAPF32[$243>>2] = Math_fround(0.0);
 $244 = Math_fround($34 - $238);
 $245 = Math_fround($45 - $239);
 $246 = Math_fround($56 - $240);
 $247 = Math_fround($244 * $244);
 $248 = Math_fround($245 * $245);
 $249 = Math_fround($247 + $248);
 $250 = Math_fround($246 * $246);
 $251 = Math_fround($249 + $250);
 $252 = (Math_fround(Math_sqrt((Math_fround($251)))));
 $253 = Math_fround($252 - $180);
 $254 = (($this) + 48|0);
 HEAPF32[$254>>2] = $253;
 $255 = (($this) + 52|0);
 ;HEAP32[$255+0>>2]=HEAP32[$$sroa$149+0>>2]|0;HEAP32[$255+4>>2]=HEAP32[$$sroa$149+4>>2]|0;HEAP32[$255+8>>2]=HEAP32[$$sroa$149+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($agg$result,$Q,$A,$B,$size,$closestA,$closestB) {
 $agg$result = $agg$result|0;
 $Q = $Q|0;
 $A = $A|0;
 $B = $B|0;
 $size = $size|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 var $$$i = Math_fround(0), $$$i99 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0);
 var $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0);
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0);
 var $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $26 = Math_fround(0), $27 = 0;
 var $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0);
 var $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $_A = 0;
 var $_B = 0, $_Q = 0, $_size = 0, $_size1 = 0, $_size11 = 0, $_size5 = 0, $a = 0, $b = 0, $bIsOutside4 = 0, $c = 0, $d = 0, $indices$sroa$0$2 = 0, $indices$sroa$1$0 = 0, $indices$sroa$1$1 = 0, $indices$sroa$1$2 = 0, $indices$sroa$2$0 = 0, $indices$sroa$2$1 = 0, $indices$sroa$2$2 = 0, $q = 0, $q14 = 0;
 var $q8 = 0, $t = 0, $t12 = 0, $t2 = 0, $t6 = 0, $tempSize$0 = 0, $tempSize$1 = 0, $tempSize$2 = 0, $tempSize$3 = 0, $w = 0, $w13 = 0, $w3 = 0, $w7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $a = sp + 16|0;
 $b = sp + 288|0;
 $c = sp + 304|0;
 $d = sp + 208|0;
 $bIsOutside4 = sp + 448|0;
 $_Q = sp + 224|0;
 $_A = sp + 320|0;
 $_B = sp + 384|0;
 $_size = sp + 476|0;
 $t = sp + 192|0;
 $w = sp;
 $0 = sp + 64|0;
 $_size1 = sp + 468|0;
 $t2 = sp + 32|0;
 $w3 = sp + 48|0;
 $q = sp + 80|0;
 $_size5 = sp + 472|0;
 $t6 = sp + 96|0;
 $w7 = sp + 112|0;
 $q8 = sp + 128|0;
 $_size11 = sp + 464|0;
 $t12 = sp + 144|0;
 $w13 = sp + 160|0;
 $q14 = sp + 176|0;
 $1 = HEAP32[$size>>2]|0;
 ;HEAP32[$a+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$a+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$a+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$a+12>>2]=HEAP32[$Q+12>>2]|0;
 $2 = (($Q) + 16|0);
 ;HEAP32[$b+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$b+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$b+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$b+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($Q) + 32|0);
 ;HEAP32[$c+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$c+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$c+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$c+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (($Q) + 48|0);
 ;HEAP32[$d+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$d+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$d+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$d+12>>2]=HEAP32[$4+12>>2]|0;
 $5 = Math_fround(HEAPF32[$d>>2]);
 $6 = (($d) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($d) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$a>>2]);
 $11 = (($a) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($a) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($5 - $10);
 $16 = Math_fround($7 - $12);
 $17 = Math_fround($9 - $14);
 $18 = Math_fround(HEAPF32[$b>>2]);
 $19 = (($b) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($b) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($5 - $18);
 $24 = Math_fround($7 - $20);
 $25 = Math_fround($9 - $22);
 $26 = Math_fround(HEAPF32[$c>>2]);
 $27 = (($c) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($c) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($5 - $26);
 $32 = Math_fround($7 - $28);
 $33 = Math_fround($9 - $30);
 $34 = Math_fround($15 * $15);
 $35 = Math_fround($16 * $16);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($17 * $17);
 $38 = Math_fround($36 + $37);
 $39 = Math_fround($23 * $23);
 $40 = Math_fround($24 * $24);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($25 * $25);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($31 * $31);
 $45 = Math_fround($32 * $32);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($33 * $33);
 $48 = Math_fround($46 + $47);
 $49 = $43 > $48;
 $$$i99 = $49 ? $48 : $43;
 $50 = $38 > $$$i99;
 $$$i = $50 ? $$$i99 : $38;
 $51 = $$$i < Math_fround(1.1920928955078125E-7);
 if ($51) {
  HEAP32[$size>>2] = 3;
  __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($agg$result,$a,$b,$c,$Q,$A,$B,$size,$closestA,$closestB);
  STACKTOP = sp;return;
 }
 __ZN5physx2Gu20PointOutsideOfPlane4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_($bIsOutside4,$a,$b,$c,$d);
 $52 = HEAP32[$bIsOutside4>>2]|0;
 $53 = (($bIsOutside4) + 4|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($bIsOutside4) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($bIsOutside4) + 12|0);
 $58 = $54 | $52;
 $59 = $58 | $56;
 $60 = ($59|0)==(0);
 if ($60) {
  $61 = HEAP32[$57>>2]|0;
  $62 = ($61|0)==(0);
  if ($62) {
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$_Q+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$_Q+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$_Q+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$_Q+12>>2]=HEAP32[$Q+12>>2]|0;
 $63 = (($_Q) + 16|0);
 ;HEAP32[$63+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$63+12>>2]=HEAP32[$2+12>>2]|0;
 $64 = (($_Q) + 32|0);
 ;HEAP32[$64+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$64+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$64+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$64+12>>2]=HEAP32[$3+12>>2]|0;
 $65 = (($_Q) + 48|0);
 ;HEAP32[$65+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$4+12>>2]|0;
 ;HEAP32[$_A+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$_A+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$_A+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$_A+12>>2]=HEAP32[$A+12>>2]|0;
 $66 = (($_A) + 16|0);
 $67 = (($A) + 16|0);
 ;HEAP32[$66+0>>2]=HEAP32[$67+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$67+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$67+8>>2]|0;HEAP32[$66+12>>2]=HEAP32[$67+12>>2]|0;
 $68 = (($_A) + 32|0);
 $69 = (($A) + 32|0);
 ;HEAP32[$68+0>>2]=HEAP32[$69+0>>2]|0;HEAP32[$68+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$68+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$68+12>>2]=HEAP32[$69+12>>2]|0;
 $70 = (($_A) + 48|0);
 $71 = (($A) + 48|0);
 ;HEAP32[$70+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$70+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$70+12>>2]=HEAP32[$71+12>>2]|0;
 ;HEAP32[$_B+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$_B+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$_B+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$_B+12>>2]=HEAP32[$B+12>>2]|0;
 $72 = (($_B) + 16|0);
 $73 = (($B) + 16|0);
 ;HEAP32[$72+0>>2]=HEAP32[$73+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$73+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$73+8>>2]|0;HEAP32[$72+12>>2]=HEAP32[$73+12>>2]|0;
 $74 = (($_B) + 32|0);
 $75 = (($B) + 32|0);
 ;HEAP32[$74+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$75+12>>2]|0;
 $76 = (($_B) + 48|0);
 $77 = (($B) + 48|0);
 ;HEAP32[$76+0>>2]=HEAP32[$77+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$77+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$77+8>>2]|0;HEAP32[$76+12>>2]=HEAP32[$77+12>>2]|0;
 $78 = ($52|0)==(-1);
 if ($78) {
  HEAP32[$_size>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($0,$_Q,$63,$64,$_size,$t,$w);
  $79 = Math_fround(HEAPF32[$0>>2]);
  $80 = (($0) + 4|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($0) + 8|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($0) + 12|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($79 * $79);
  $87 = Math_fround($81 * $81);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround($83 * $83);
  $90 = Math_fround($88 + $89);
  $91 = HEAP32[$_size>>2]|0;
  $92 = Math_fround(HEAPF32[$t>>2]);
  $93 = Math_fround(HEAPF32[$w>>2]);
  $106 = $90;$239 = $85;$240 = $83;$241 = $81;$242 = $79;$243 = $92;$244 = $93;$tempSize$0 = $91;
 } else {
  $106 = Math_fround(3.40282346638528859812E+38);$239 = Math_fround(0.0);$240 = Math_fround(0.0);$241 = Math_fround(0.0);$242 = Math_fround(0.0);$243 = Math_fround(0.0);$244 = Math_fround(0.0);$tempSize$0 = $1;
 }
 $94 = ($54|0)==(-1);
 if ($94) {
  HEAP32[$_size1>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($q,$_Q,$64,$65,$_size1,$t2,$w3);
  $95 = Math_fround(HEAPF32[$q>>2]);
  $96 = (($q) + 4|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = (($q) + 8|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = Math_fround($95 * $95);
  $101 = Math_fround($97 * $97);
  $102 = Math_fround($100 + $101);
  $103 = Math_fround($99 * $99);
  $104 = Math_fround($102 + $103);
  $105 = $106 > $104;
  if ($105) {
   $107 = (($q) + 12|0);
   $108 = Math_fround(HEAPF32[$107>>2]);
   $109 = HEAP32[$_size1>>2]|0;
   $110 = Math_fround(HEAPF32[$t2>>2]);
   $111 = Math_fround(HEAPF32[$w3>>2]);
   $124 = $104;$245 = $108;$246 = $99;$247 = $97;$248 = $95;$249 = $110;$250 = $111;$indices$sroa$1$0 = 2;$indices$sroa$2$0 = 3;$tempSize$1 = $109;
  } else {
   $124 = $106;$245 = $239;$246 = $240;$247 = $241;$248 = $242;$249 = $243;$250 = $244;$indices$sroa$1$0 = 1;$indices$sroa$2$0 = 2;$tempSize$1 = $tempSize$0;
  }
 } else {
  $124 = $106;$245 = $239;$246 = $240;$247 = $241;$248 = $242;$249 = $243;$250 = $244;$indices$sroa$1$0 = 1;$indices$sroa$2$0 = 2;$tempSize$1 = $tempSize$0;
 }
 $112 = ($56|0)==(-1);
 if ($112) {
  HEAP32[$_size5>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($q8,$_Q,$65,$63,$_size5,$t6,$w7);
  $113 = Math_fround(HEAPF32[$q8>>2]);
  $114 = (($q8) + 4|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($q8) + 8|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = Math_fround($113 * $113);
  $119 = Math_fround($115 * $115);
  $120 = Math_fround($118 + $119);
  $121 = Math_fround($117 * $117);
  $122 = Math_fround($120 + $121);
  $123 = $124 > $122;
  if ($123) {
   $125 = (($q8) + 12|0);
   $126 = Math_fround(HEAPF32[$125>>2]);
   $127 = HEAP32[$_size5>>2]|0;
   $128 = Math_fround(HEAPF32[$t6>>2]);
   $129 = Math_fround(HEAPF32[$w7>>2]);
   $143 = $122;$251 = $126;$252 = $117;$253 = $115;$254 = $113;$255 = $128;$256 = $129;$indices$sroa$1$1 = 3;$indices$sroa$2$1 = 1;$tempSize$2 = $127;
  } else {
   $143 = $124;$251 = $245;$252 = $246;$253 = $247;$254 = $248;$255 = $249;$256 = $250;$indices$sroa$1$1 = $indices$sroa$1$0;$indices$sroa$2$1 = $indices$sroa$2$0;$tempSize$2 = $tempSize$1;
  }
 } else {
  $143 = $124;$251 = $245;$252 = $246;$253 = $247;$254 = $248;$255 = $249;$256 = $250;$indices$sroa$1$1 = $indices$sroa$1$0;$indices$sroa$2$1 = $indices$sroa$2$0;$tempSize$2 = $tempSize$1;
 }
 $130 = HEAP32[$57>>2]|0;
 $131 = ($130|0)==(-1);
 if ($131) {
  HEAP32[$_size11>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($q14,$63,$65,$64,$_size11,$t12,$w13);
  $132 = Math_fround(HEAPF32[$q14>>2]);
  $133 = (($q14) + 4|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($q14) + 8|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = Math_fround($132 * $132);
  $138 = Math_fround($134 * $134);
  $139 = Math_fround($137 + $138);
  $140 = Math_fround($136 * $136);
  $141 = Math_fround($139 + $140);
  $142 = $143 > $141;
  if ($142) {
   $144 = (($q14) + 12|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = HEAP32[$_size11>>2]|0;
   $147 = Math_fround(HEAPF32[$t12>>2]);
   $148 = Math_fround(HEAPF32[$w13>>2]);
   $201 = $148;$205 = $147;$232 = $132;$234 = $134;$236 = $136;$238 = $145;$indices$sroa$0$2 = 1;$indices$sroa$1$2 = 3;$indices$sroa$2$2 = 2;$tempSize$3 = $146;
  } else {
   $201 = $256;$205 = $255;$232 = $254;$234 = $253;$236 = $252;$238 = $251;$indices$sroa$0$2 = 0;$indices$sroa$1$2 = $indices$sroa$1$1;$indices$sroa$2$2 = $indices$sroa$2$1;$tempSize$3 = $tempSize$2;
  }
 } else {
  $201 = $256;$205 = $255;$232 = $254;$234 = $253;$236 = $252;$238 = $251;$indices$sroa$0$2 = 0;$indices$sroa$1$2 = $indices$sroa$1$1;$indices$sroa$2$2 = $indices$sroa$2$1;$tempSize$3 = $tempSize$2;
 }
 $149 = (($_A) + ($indices$sroa$0$2<<4)|0);
 ;HEAP32[$A+0>>2]=HEAP32[$149+0>>2]|0;HEAP32[$A+4>>2]=HEAP32[$149+4>>2]|0;HEAP32[$A+8>>2]=HEAP32[$149+8>>2]|0;HEAP32[$A+12>>2]=HEAP32[$149+12>>2]|0;
 $150 = (($_A) + ($indices$sroa$1$2<<4)|0);
 ;HEAP32[$67+0>>2]=HEAP32[$150+0>>2]|0;HEAP32[$67+4>>2]=HEAP32[$150+4>>2]|0;HEAP32[$67+8>>2]=HEAP32[$150+8>>2]|0;HEAP32[$67+12>>2]=HEAP32[$150+12>>2]|0;
 $151 = (($_A) + ($indices$sroa$2$2<<4)|0);
 ;HEAP32[$69+0>>2]=HEAP32[$151+0>>2]|0;HEAP32[$69+4>>2]=HEAP32[$151+4>>2]|0;HEAP32[$69+8>>2]=HEAP32[$151+8>>2]|0;HEAP32[$69+12>>2]=HEAP32[$151+12>>2]|0;
 $152 = (($_B) + ($indices$sroa$0$2<<4)|0);
 ;HEAP32[$B+0>>2]=HEAP32[$152+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$152+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$152+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$152+12>>2]|0;
 $153 = (($_B) + ($indices$sroa$1$2<<4)|0);
 ;HEAP32[$73+0>>2]=HEAP32[$153+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$153+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$153+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$153+12>>2]|0;
 $154 = (($_B) + ($indices$sroa$2$2<<4)|0);
 ;HEAP32[$75+0>>2]=HEAP32[$154+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$154+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$154+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$154+12>>2]|0;
 $155 = (($_Q) + ($indices$sroa$0$2<<4)|0);
 ;HEAP32[$Q+0>>2]=HEAP32[$155+0>>2]|0;HEAP32[$Q+4>>2]=HEAP32[$155+4>>2]|0;HEAP32[$Q+8>>2]=HEAP32[$155+8>>2]|0;HEAP32[$Q+12>>2]=HEAP32[$155+12>>2]|0;
 $156 = (($_Q) + ($indices$sroa$1$2<<4)|0);
 ;HEAP32[$2+0>>2]=HEAP32[$156+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$156+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$156+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$156+12>>2]|0;
 $157 = (($_Q) + ($indices$sroa$2$2<<4)|0);
 ;HEAP32[$3+0>>2]=HEAP32[$157+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$157+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$157+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$157+12>>2]|0;
 $158 = Math_fround(HEAPF32[$150>>2]);
 $159 = ((($_A) + ($indices$sroa$1$2<<4)|0) + 4|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = ((($_A) + ($indices$sroa$1$2<<4)|0) + 8|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = Math_fround(HEAPF32[$149>>2]);
 $164 = ((($_A) + ($indices$sroa$0$2<<4)|0) + 4|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = ((($_A) + ($indices$sroa$0$2<<4)|0) + 8|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = Math_fround($158 - $163);
 $169 = Math_fround($160 - $165);
 $170 = Math_fround($162 - $167);
 $171 = Math_fround(HEAPF32[$151>>2]);
 $172 = ((($_A) + ($indices$sroa$2$2<<4)|0) + 4|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = ((($_A) + ($indices$sroa$2$2<<4)|0) + 8|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = Math_fround($171 - $163);
 $177 = Math_fround($173 - $165);
 $178 = Math_fround($175 - $167);
 $179 = Math_fround(HEAPF32[$153>>2]);
 $180 = ((($_B) + ($indices$sroa$1$2<<4)|0) + 4|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = ((($_B) + ($indices$sroa$1$2<<4)|0) + 8|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = Math_fround(HEAPF32[$152>>2]);
 $185 = ((($_B) + ($indices$sroa$0$2<<4)|0) + 4|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = ((($_B) + ($indices$sroa$0$2<<4)|0) + 8|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = Math_fround($179 - $184);
 $190 = Math_fround($181 - $186);
 $191 = Math_fround($183 - $188);
 $192 = Math_fround(HEAPF32[$154>>2]);
 $193 = ((($_B) + ($indices$sroa$2$2<<4)|0) + 4|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = ((($_B) + ($indices$sroa$2$2<<4)|0) + 8|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = Math_fround($192 - $184);
 $198 = Math_fround($194 - $186);
 $199 = Math_fround($196 - $188);
 $200 = Math_fround($201 * $176);
 $202 = Math_fround($201 * $177);
 $203 = Math_fround($201 * $178);
 $204 = Math_fround($205 * $168);
 $206 = Math_fround($205 * $169);
 $207 = Math_fround($205 * $170);
 $208 = Math_fround($204 + $200);
 $209 = Math_fround($206 + $202);
 $210 = Math_fround($207 + $203);
 $211 = Math_fround($163 + $208);
 $212 = Math_fround($165 + $209);
 $213 = Math_fround($167 + $210);
 HEAPF32[$closestA>>2] = $211;
 $214 = (($closestA) + 4|0);
 HEAPF32[$214>>2] = $212;
 $215 = (($closestA) + 8|0);
 HEAPF32[$215>>2] = $213;
 $216 = (($closestA) + 12|0);
 HEAPF32[$216>>2] = Math_fround(0.0);
 $217 = Math_fround($201 * $197);
 $218 = Math_fround($201 * $198);
 $219 = Math_fround($201 * $199);
 $220 = Math_fround($205 * $189);
 $221 = Math_fround($205 * $190);
 $222 = Math_fround($205 * $191);
 $223 = Math_fround($220 + $217);
 $224 = Math_fround($221 + $218);
 $225 = Math_fround($222 + $219);
 $226 = Math_fround($184 + $223);
 $227 = Math_fround($186 + $224);
 $228 = Math_fround($188 + $225);
 HEAPF32[$closestB>>2] = $226;
 $229 = (($closestB) + 4|0);
 HEAPF32[$229>>2] = $227;
 $230 = (($closestB) + 8|0);
 HEAPF32[$230>>2] = $228;
 $231 = (($closestB) + 12|0);
 HEAPF32[$231>>2] = Math_fround(0.0);
 HEAP32[$size>>2] = $tempSize$3;
 HEAPF32[$agg$result>>2] = $232;
 $233 = (($agg$result) + 4|0);
 HEAPF32[$233>>2] = $234;
 $235 = (($agg$result) + 8|0);
 HEAPF32[$235>>2] = $236;
 $237 = (($agg$result) + 12|0);
 HEAPF32[$237>>2] = $238;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($agg$result,$a,$b,$c,$size,$t,$w) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $size = $size|0;
 $t = $t|0;
 $w = $w|0;
 var $$$$not = 0, $$$i$i = Math_fround(0), $$$not = 0, $$1$i$i = Math_fround(0), $$1455 = 0, $$1455$ = 0, $$1456 = 0, $$1457$$not = 0, $$1457$not = 0, $$1458 = 0, $$1458$ = 0, $$1461 = 0, $$in1$i = 0, $$in1$i102 = 0, $$in1$i114 = 0, $$in1$i143 = 0, $$in1$i290 = 0, $$in1$i302 = 0, $$in2$i = 0, $$in2$i104 = 0;
 var $$in2$i116 = 0, $$in2$i144 = 0, $$in2$i292 = 0, $$in2$i304 = 0, $$in3$i = 0, $$not = 0, $$not1459 = 0, $$not1472 = 0, $$not1473 = 0, $$not1482 = 0, $$not1483 = 0, $$not1488 = 0, $$sroa$1432 = 0, $$sroa$1438 = 0, $$sroa$1664 = 0, $$sroa$1666 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0;
 var $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0);
 var $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0;
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0);
 var $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $_t$sroa$1 = 0;
 var $_w$sroa$1 = 0, $a$pn3$i = 0, $a$pn3$i101 = 0, $a$pn3$i113 = 0, $a$pn3$i289 = 0, $a$pn3$i301 = 0, $a$pn4$i = 0, $a$pn6$i = 0, $b$a$i111 = 0, $b$a$i141 = 0, $b$a$i287 = 0, $b$a$i299 = 0, $b$a$i91 = 0, $b$a$i99 = 0, $b$a5$i = 0, $b$a5$i103 = 0, $b$a5$i115 = 0, $b$a5$i291 = 0, $b$a5$i303 = 0, $b$a7$i = 0;
 var $brmerge = 0, $brmerge1460 = 0, $not$ = 0, $not$1463 = 0, $not$1468 = 0, $not$1476 = 0, $not$1480 = 0, $not$1490 = 0, $not$1491 = 0, $not$1492 = 0, $not$1496 = 0, $not$1497 = 0, $phitmp = 0, $phitmp1493 = 0, $phitmp1493$demorgan = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $0 = sp + 80|0;
 $1 = sp + 176|0;
 $2 = sp + 160|0;
 $3 = sp + 144|0;
 $4 = sp + 64|0;
 $5 = sp + 32|0;
 $6 = sp + 16|0;
 $7 = sp;
 $8 = sp + 48|0;
 $9 = sp + 128|0;
 $10 = sp + 96|0;
 $11 = sp + 112|0;
 $$sroa$1666 = sp + 252|0;
 $$sroa$1664 = sp + 192|0;
 $$sroa$1438 = sp + 204|0;
 $$sroa$1432 = sp + 216|0;
 $_t$sroa$1 = sp + 228|0;
 $_w$sroa$1 = sp + 240|0;
 HEAP32[$size>>2] = 3;
 $12 = Math_fround(HEAPF32[$b>>2]);
 $13 = (($b) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($b) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$a>>2]);
 $18 = (($a) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($a) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($12 - $17);
 $23 = Math_fround($14 - $19);
 $24 = Math_fround($16 - $21);
 $25 = Math_fround(HEAPF32[$c>>2]);
 $26 = (($c) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($c) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($25 - $17);
 $31 = Math_fround($27 - $19);
 $32 = Math_fround($29 - $21);
 $33 = Math_fround(-$17);
 $34 = Math_fround(-$19);
 $35 = Math_fround(-$21);
 $36 = Math_fround(-$12);
 $37 = Math_fround(-$14);
 $38 = Math_fround(-$16);
 $39 = Math_fround(-$25);
 $40 = Math_fround(-$27);
 $41 = Math_fround(-$29);
 $42 = Math_fround($22 * $33);
 $43 = Math_fround($23 * $34);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($24 * $35);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($30 * $33);
 $48 = Math_fround($31 * $34);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($32 * $35);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($22 * $36);
 $53 = Math_fround($23 * $37);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($24 * $38);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($30 * $36);
 $58 = Math_fround($31 * $37);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($32 * $38);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($22 * $39);
 $63 = Math_fround($23 * $40);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($24 * $41);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($30 * $39);
 $68 = Math_fround($31 * $40);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround($32 * $41);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($61 - $56);
 $73 = Math_fround($66 - $71);
 $74 = !($46 <= Math_fround(0.0));
 $75 = $51 <= Math_fround(0.0);
 $76 = !($56 >= Math_fround(0.0));
 $77 = $56 >= $61;
 $78 = !($71 >= Math_fround(0.0));
 $79 = $71 >= $66;
 $80 = $75 << 31 >> 31;
 $81 = $74 ? 0 : $80;
 $not$1496 = $74 ^ 1;
 $82 = $75 & $not$1496;
 if ($76) {
  $87 = 1;$89 = 0;
 } else {
  $phitmp = $77 ^ 1;
  $87 = $phitmp;$89 = $77;
 }
 $not$ = $78 ^ 1;
 $83 = $79 & $not$;
 $84 = ($81|0)==(0);
 $85 = ($81|0)==(0);
 $86 = ($81|0)==(0);
 $$not1488 = $79 ^ 1;
 $$not1472 = $78 | $$not1488;
 $$$not = $87 & $$not1472;
 $$$$not = $84 & $$$not;
 $$not1473 = $87 & $$not1472;
 $$not = $85 & $$not1473;
 $brmerge = $$$$not | $$not;
 if (!($brmerge)) {
  $not$1463 = $87 ^ 1;
  $88 = $83 | $89;
  $90 = $88 | $82;
  $$1455 = $83 | $not$1463;
  $not$1468 = $86 ^ 1;
  $$1455$ = $$1455 | $not$1468;
  $$1456 = $$1455$ & $90;
  if ($$1456) {
   $91 = $87 ? Math_fround(0.0) : Math_fround(1.0);
   HEAPF32[$t>>2] = $91;
   $92 = (($t) + 4|0);
   ;HEAP32[$92+0>>2]=HEAP32[$$sroa$1666+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$$sroa$1666+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$$sroa$1666+8>>2]|0;
   $93 = $$not1472 ? Math_fround(0.0) : Math_fround(1.0);
   HEAPF32[$w>>2] = $93;
   $94 = (($w) + 4|0);
   ;HEAP32[$94+0>>2]=HEAP32[$$sroa$1664+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$$sroa$1664+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$$sroa$1664+8>>2]|0;
   ;HEAP32[$3+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$a+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$b+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$b+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$b+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$b+12>>2]|0;
   ;HEAP32[$0+0>>2]=HEAP32[$c+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$c+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$c+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$c+12>>2]|0;
   $b$a$i299 = $87 ? $0 : $1;
   $95 = Math_fround(HEAPF32[$b$a$i299>>2]);
   $a$pn3$i301 = $87 ? $0 : $1;
   $$in1$i302 = (($a$pn3$i301) + 4|0);
   $96 = Math_fround(HEAPF32[$$in1$i302>>2]);
   $b$a5$i303 = $87 ? $0 : $1;
   $$in2$i304 = (($b$a5$i303) + 8|0);
   $97 = Math_fround(HEAPF32[$$in2$i304>>2]);
   HEAPF32[$2>>2] = $95;
   $98 = (($2) + 4|0);
   HEAPF32[$98>>2] = $96;
   $99 = (($2) + 8|0);
   HEAPF32[$99>>2] = $97;
   $100 = (($2) + 12|0);
   HEAPF32[$100>>2] = Math_fround(0.0);
   $b$a$i287 = $84 ? $2 : $3;
   $101 = Math_fround(HEAPF32[$b$a$i287>>2]);
   $a$pn3$i289 = $85 ? $2 : $3;
   $$in1$i290 = (($a$pn3$i289) + 4|0);
   $102 = Math_fround(HEAPF32[$$in1$i290>>2]);
   $b$a5$i291 = $86 ? $2 : $3;
   $$in2$i292 = (($b$a5$i291) + 8|0);
   $103 = Math_fround(HEAPF32[$$in2$i292>>2]);
   HEAPF32[$agg$result>>2] = $101;
   $104 = (($agg$result) + 4|0);
   HEAPF32[$104>>2] = $102;
   $105 = (($agg$result) + 8|0);
   HEAPF32[$105>>2] = $103;
   $106 = (($agg$result) + 12|0);
   HEAPF32[$106>>2] = Math_fround(0.0);
   STACKTOP = sp;return;
  }
 }
 $107 = Math_fround($56 * $71);
 $108 = Math_fround($66 * $61);
 $109 = Math_fround($107 - $108);
 $110 = Math_fround($66 * $51);
 $111 = Math_fround($46 * $71);
 $112 = Math_fround($110 - $111);
 $113 = Math_fround($46 * $61);
 $114 = Math_fround($56 * $51);
 $115 = Math_fround($113 - $114);
 $116 = !($115 <= Math_fround(0.0));
 $117 = !($46 >= Math_fround(0.0));
 $118 = !($109 <= Math_fround(0.0));
 $119 = $66 >= $71;
 $120 = $71 <= Math_fround(0.0);
 if ($117) {
  $123 = 0;
 } else {
  $121 = $56 <= Math_fround(0.0);
  $123 = $121;
 }
 $122 = $123 << 31 >> 31;
 $124 = $116 ? 0 : $122;
 $not$1497 = $116 ^ 1;
 $125 = $123 & $not$1497;
 $not$1490 = $61 >= $56;
 if ($118) {
  $162 = 1;$164 = 0;
 } else {
  $126 = $119 & $not$1490;
  $phitmp1493$demorgan = $119 & $not$1490;
  $phitmp1493 = $phitmp1493$demorgan ^ 1;
  $162 = $phitmp1493;$164 = $126;
 }
 $not$1491 = $51 >= Math_fround(0.0);
 $127 = $120 & $not$1491;
 $not$1492 = $112 <= Math_fround(0.0);
 $128 = $127 & $not$1492;
 $129 = ($124|0)==(0);
 $130 = ($124|0)==(0);
 $131 = ($124|0)==(0);
 $132 = Math_fround($46 - $56);
 $133 = Math_fround($72 + $73);
 $134 = Math_fround($51 - $71);
 $135 = Math_fround($112 + $115);
 $136 = Math_fround($109 + $135);
 $137 = Math_fround(-$132);
 $138 = Math_fround(-$133);
 $139 = Math_fround(-$134);
 $140 = Math_fround(-$136);
 $141 = $132 > $137;
 $$$i$i = $141 ? $132 : $137;
 $142 = $133 > $138;
 $143 = $142 ? $133 : $138;
 $144 = $134 > $139;
 $$1$i$i = $144 ? $134 : $139;
 $145 = $136 > $140;
 $146 = $145 ? $136 : $140;
 $147 = $$$i$i > Math_fround(1.1920928955078125E-7);
 $148 = $143 > Math_fround(1.1920928955078125E-7);
 $149 = $$1$i$i > Math_fround(1.1920928955078125E-7);
 $150 = $146 > Math_fround(1.1920928955078125E-7);
 $151 = Math_fround(Math_fround(1.0) / $132);
 $152 = Math_fround(Math_fround(1.0) / $133);
 $153 = Math_fround(Math_fround(1.0) / $134);
 $154 = Math_fround(Math_fround(1.0) / $136);
 HEAPF32[$5>>2] = $151;
 $155 = (($5) + 4|0);
 HEAPF32[$155>>2] = $152;
 $156 = (($5) + 8|0);
 HEAPF32[$156>>2] = $153;
 $157 = (($5) + 12|0);
 HEAPF32[$157>>2] = $154;
 $b$a$i141 = $147 ? $5 : $4;
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 $158 = Math_fround(HEAPF32[$b$a$i141>>2]);
 $a$pn4$i = $148 ? $5 : $4;
 $$in1$i143 = (($a$pn4$i) + 4|0);
 $159 = Math_fround(HEAPF32[$$in1$i143>>2]);
 $b$a7$i = $149 ? $5 : $4;
 $$in2$i144 = (($b$a7$i) + 8|0);
 $160 = Math_fround(HEAPF32[$$in2$i144>>2]);
 $a$pn6$i = $150 ? $5 : $4;
 $$in3$i = (($a$pn6$i) + 12|0);
 $161 = Math_fround(HEAPF32[$$in3$i>>2]);
 $$not1482 = $128 ^ 1;
 $$1457$not = $162 & $$not1482;
 $$1457$$not = $129 & $$1457$not;
 $$not1483 = $162 & $$not1482;
 $$not1459 = $130 & $$not1483;
 $brmerge1460 = $$1457$$not | $$not1459;
 if (!($brmerge1460)) {
  $not$1476 = $162 ^ 1;
  $163 = $128 | $164;
  $165 = $163 | $125;
  $$1458 = $128 | $not$1476;
  $not$1480 = $131 ^ 1;
  $$1458$ = $$1458 | $not$1480;
  $$1461 = $$1458$ & $165;
  if ($$1461) {
   $166 = Math_fround($46 * $158);
   $167 = Math_fround($72 * $159);
   $168 = Math_fround($51 * $160);
   ;HEAP32[$7+0>>2]=HEAP32[$b+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$b+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$b+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$b+12>>2]|0;
   ;HEAP32[$6+0>>2]=HEAP32[$c+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$c+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$c+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$c+12>>2]|0;
   $b$a$i111 = $129 ? $6 : $7;
   $169 = Math_fround(HEAPF32[$b$a$i111>>2]);
   $a$pn3$i113 = $130 ? $6 : $7;
   $$in1$i114 = (($a$pn3$i113) + 4|0);
   $170 = Math_fround(HEAPF32[$$in1$i114>>2]);
   $b$a5$i115 = $131 ? $6 : $7;
   $$in2$i116 = (($b$a5$i115) + 8|0);
   $171 = Math_fround(HEAPF32[$$in2$i116>>2]);
   ;HEAP32[$11+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$a+12>>2]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$b+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$b+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$b+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$b+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$a+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$a+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$a+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$a+12>>2]|0;
   $b$a$i99 = $162 ? $8 : $9;
   $172 = Math_fround(HEAPF32[$b$a$i99>>2]);
   $a$pn3$i101 = $162 ? $8 : $9;
   $$in1$i102 = (($a$pn3$i101) + 4|0);
   $173 = Math_fround(HEAPF32[$$in1$i102>>2]);
   $b$a5$i103 = $162 ? $8 : $9;
   $$in2$i104 = (($b$a5$i103) + 8|0);
   $174 = Math_fround(HEAPF32[$$in2$i104>>2]);
   HEAPF32[$10>>2] = $172;
   $175 = (($10) + 4|0);
   HEAPF32[$175>>2] = $173;
   $176 = (($10) + 8|0);
   HEAPF32[$176>>2] = $174;
   $177 = (($10) + 12|0);
   HEAPF32[$177>>2] = Math_fround(0.0);
   $b$a$i91 = $129 ? $10 : $11;
   $178 = Math_fround(HEAPF32[$b$a$i91>>2]);
   $a$pn3$i = $130 ? $10 : $11;
   $$in1$i = (($a$pn3$i) + 4|0);
   $179 = Math_fround(HEAPF32[$$in1$i>>2]);
   $b$a5$i = $131 ? $10 : $11;
   $$in2$i = (($b$a5$i) + 8|0);
   $180 = Math_fround(HEAPF32[$$in2$i>>2]);
   $181 = Math_fround($169 - $178);
   $182 = Math_fround($170 - $179);
   $183 = Math_fround($171 - $180);
   $184 = $162 ? $168 : $167;
   $185 = $129 ? $184 : $166;
   $186 = Math_fround(Math_fround(1.0) - $167);
   $187 = $162 ? Math_fround(0.0) : $186;
   $188 = $129 ? $187 : $166;
   HEAPF32[$t>>2] = $188;
   $189 = (($t) + 4|0);
   ;HEAP32[$189+0>>2]=HEAP32[$$sroa$1438+0>>2]|0;HEAP32[$189+4>>2]=HEAP32[$$sroa$1438+4>>2]|0;HEAP32[$189+8>>2]=HEAP32[$$sroa$1438+8>>2]|0;
   $190 = $129 ? $184 : Math_fround(0.0);
   HEAPF32[$w>>2] = $190;
   $191 = (($w) + 4|0);
   ;HEAP32[$191+0>>2]=HEAP32[$$sroa$1432+0>>2]|0;HEAP32[$191+4>>2]=HEAP32[$$sroa$1432+4>>2]|0;HEAP32[$191+8>>2]=HEAP32[$$sroa$1432+8>>2]|0;
   $192 = Math_fround($185 * $181);
   $193 = Math_fround($185 * $182);
   $194 = Math_fround($185 * $183);
   $195 = Math_fround($178 + $192);
   $196 = Math_fround($179 + $193);
   $197 = Math_fround($180 + $194);
   HEAPF32[$agg$result>>2] = $195;
   $198 = (($agg$result) + 4|0);
   HEAPF32[$198>>2] = $196;
   $199 = (($agg$result) + 8|0);
   HEAPF32[$199>>2] = $197;
   $200 = (($agg$result) + 12|0);
   HEAPF32[$200>>2] = Math_fround(0.0);
   STACKTOP = sp;return;
  }
 }
 $201 = Math_fround($112 * $161);
 $202 = Math_fround($115 * $161);
 HEAPF32[$t>>2] = $201;
 $203 = (($t) + 4|0);
 ;HEAP32[$203+0>>2]=HEAP32[$_t$sroa$1+0>>2]|0;HEAP32[$203+4>>2]=HEAP32[$_t$sroa$1+4>>2]|0;HEAP32[$203+8>>2]=HEAP32[$_t$sroa$1+8>>2]|0;
 HEAPF32[$w>>2] = $202;
 $204 = (($w) + 4|0);
 ;HEAP32[$204+0>>2]=HEAP32[$_w$sroa$1+0>>2]|0;HEAP32[$204+4>>2]=HEAP32[$_w$sroa$1+4>>2]|0;HEAP32[$204+8>>2]=HEAP32[$_w$sroa$1+8>>2]|0;
 $205 = Math_fround(HEAPF32[$a>>2]);
 $206 = Math_fround(HEAPF32[$18>>2]);
 $207 = Math_fround(HEAPF32[$20>>2]);
 $208 = Math_fround($30 * $202);
 $209 = Math_fround($31 * $202);
 $210 = Math_fround($32 * $202);
 $211 = Math_fround($22 * $201);
 $212 = Math_fround($23 * $201);
 $213 = Math_fround($24 * $201);
 $214 = Math_fround($211 + $208);
 $215 = Math_fround($212 + $209);
 $216 = Math_fround($213 + $210);
 $217 = Math_fround($214 + $205);
 $218 = Math_fround($215 + $206);
 $219 = Math_fround($216 + $207);
 HEAPF32[$agg$result>>2] = $217;
 $220 = (($agg$result) + 4|0);
 HEAPF32[$220>>2] = $218;
 $221 = (($agg$result) + 8|0);
 HEAPF32[$221>>2] = $219;
 $222 = (($agg$result) + 12|0);
 HEAPF32[$222>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($agg$result,$Q,$A,$B,$aInd,$bInd,$Q4,$A4,$B4,$size,$closestA,$closestB) {
 $agg$result = $agg$result|0;
 $Q = $Q|0;
 $A = $A|0;
 $B = $B|0;
 $aInd = $aInd|0;
 $bInd = $bInd|0;
 $Q4 = $Q4|0;
 $A4 = $A4|0;
 $B4 = $B4|0;
 $size = $size|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 var $$$i = Math_fround(0), $$$i99 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0;
 var $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0;
 var $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0);
 var $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0;
 var $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $_A = 0, $_B = 0, $_Q = 0, $_aInd = 0, $_bInd = 0, $_size = 0, $_size1 = 0, $_size2 = 0, $_size6 = 0, $a = 0, $b = 0, $bIsOutside4 = 0, $c = 0, $d = 0;
 var $indices$sroa$0$2 = 0, $indices$sroa$1$0 = 0, $indices$sroa$1$1 = 0, $indices$sroa$1$2 = 0, $indices$sroa$2$0 = 0, $indices$sroa$2$1 = 0, $indices$sroa$2$2 = 0, $q = 0, $q3 = 0, $q7 = 0, $t = 0, $tempSize$0 = 0, $tempSize$1 = 0, $tempSize$2 = 0, $tempSize$3 = 0, $w = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $a = sp + 272|0;
 $b = sp + 256|0;
 $c = sp + 224|0;
 $d = sp + 240|0;
 $bIsOutside4 = sp + 288|0;
 $_Q = sp + 304|0;
 $_A = sp + 80|0;
 $_B = sp + 144|0;
 $_aInd = sp + 400|0;
 $_bInd = sp + 384|0;
 $t = sp + 64|0;
 $w = sp + 48|0;
 $_size = sp + 380|0;
 $0 = sp + 32|0;
 $_size1 = sp + 376|0;
 $q = sp + 16|0;
 $_size2 = sp + 372|0;
 $q3 = sp;
 $_size6 = sp + 368|0;
 $q7 = sp + 208|0;
 $1 = HEAP32[$size>>2]|0;
 ;HEAP32[$a+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$a+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$a+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$a+12>>2]=HEAP32[$Q+12>>2]|0;
 $2 = (($Q) + 16|0);
 ;HEAP32[$b+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$b+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$b+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$b+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($Q) + 32|0);
 ;HEAP32[$c+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$c+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$c+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$c+12>>2]=HEAP32[$3+12>>2]|0;
 ;HEAP32[$d+0>>2]=HEAP32[$Q4+0>>2]|0;HEAP32[$d+4>>2]=HEAP32[$Q4+4>>2]|0;HEAP32[$d+8>>2]=HEAP32[$Q4+8>>2]|0;HEAP32[$d+12>>2]=HEAP32[$Q4+12>>2]|0;
 $4 = Math_fround(HEAPF32[$d>>2]);
 $5 = (($d) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($d) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$a>>2]);
 $10 = (($a) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($a) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($4 - $9);
 $15 = Math_fround($6 - $11);
 $16 = Math_fround($8 - $13);
 $17 = Math_fround(HEAPF32[$b>>2]);
 $18 = (($b) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($b) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($4 - $17);
 $23 = Math_fround($6 - $19);
 $24 = Math_fround($8 - $21);
 $25 = Math_fround(HEAPF32[$c>>2]);
 $26 = (($c) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($c) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($4 - $25);
 $31 = Math_fround($6 - $27);
 $32 = Math_fround($8 - $29);
 $33 = Math_fround($14 * $14);
 $34 = Math_fround($15 * $15);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($16 * $16);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($22 * $22);
 $39 = Math_fround($23 * $23);
 $40 = Math_fround($38 + $39);
 $41 = Math_fround($24 * $24);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($30 * $30);
 $44 = Math_fround($31 * $31);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($32 * $32);
 $47 = Math_fround($45 + $46);
 $48 = $42 > $47;
 $$$i99 = $48 ? $47 : $42;
 $49 = $37 > $$$i99;
 $$$i = $49 ? $$$i99 : $37;
 $50 = $$$i < Math_fround(1.1920928955078125E-7);
 if ($50) {
  HEAP32[$size>>2] = 3;
  __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($agg$result,$a,$b,$c,$Q,$A,$B,$size,$closestA,$closestB);
  STACKTOP = sp;return;
 }
 __ZN5physx2Gu20PointOutsideOfPlane4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_($bIsOutside4,$a,$b,$c,$d);
 $51 = HEAP32[$bIsOutside4>>2]|0;
 $52 = (($bIsOutside4) + 4|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($bIsOutside4) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($bIsOutside4) + 12|0);
 $57 = $53 | $51;
 $58 = $57 | $55;
 $59 = ($58|0)==(0);
 if ($59) {
  $60 = HEAP32[$56>>2]|0;
  $61 = ($60|0)==(0);
  if ($61) {
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$_Q+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$_Q+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$_Q+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$_Q+12>>2]=HEAP32[$Q+12>>2]|0;
 $62 = (($_Q) + 16|0);
 ;HEAP32[$62+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$62+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$62+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$62+12>>2]=HEAP32[$2+12>>2]|0;
 $63 = (($_Q) + 32|0);
 ;HEAP32[$63+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$63+12>>2]=HEAP32[$3+12>>2]|0;
 $64 = (($_Q) + 48|0);
 ;HEAP32[$64+0>>2]=HEAP32[$Q4+0>>2]|0;HEAP32[$64+4>>2]=HEAP32[$Q4+4>>2]|0;HEAP32[$64+8>>2]=HEAP32[$Q4+8>>2]|0;HEAP32[$64+12>>2]=HEAP32[$Q4+12>>2]|0;
 ;HEAP32[$_A+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$_A+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$_A+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$_A+12>>2]=HEAP32[$A+12>>2]|0;
 $65 = (($_A) + 16|0);
 $66 = (($A) + 16|0);
 ;HEAP32[$65+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$66+12>>2]|0;
 $67 = (($_A) + 32|0);
 $68 = (($A) + 32|0);
 ;HEAP32[$67+0>>2]=HEAP32[$68+0>>2]|0;HEAP32[$67+4>>2]=HEAP32[$68+4>>2]|0;HEAP32[$67+8>>2]=HEAP32[$68+8>>2]|0;HEAP32[$67+12>>2]=HEAP32[$68+12>>2]|0;
 $69 = (($_A) + 48|0);
 ;HEAP32[$69+0>>2]=HEAP32[$A4+0>>2]|0;HEAP32[$69+4>>2]=HEAP32[$A4+4>>2]|0;HEAP32[$69+8>>2]=HEAP32[$A4+8>>2]|0;HEAP32[$69+12>>2]=HEAP32[$A4+12>>2]|0;
 ;HEAP32[$_B+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$_B+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$_B+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$_B+12>>2]=HEAP32[$B+12>>2]|0;
 $70 = (($_B) + 16|0);
 $71 = (($B) + 16|0);
 ;HEAP32[$70+0>>2]=HEAP32[$71+0>>2]|0;HEAP32[$70+4>>2]=HEAP32[$71+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$71+8>>2]|0;HEAP32[$70+12>>2]=HEAP32[$71+12>>2]|0;
 $72 = (($_B) + 32|0);
 $73 = (($B) + 32|0);
 ;HEAP32[$72+0>>2]=HEAP32[$73+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$73+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$73+8>>2]|0;HEAP32[$72+12>>2]=HEAP32[$73+12>>2]|0;
 $74 = (($_B) + 48|0);
 ;HEAP32[$74+0>>2]=HEAP32[$B4+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$B4+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$B4+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$B4+12>>2]|0;
 $75 = HEAP32[$aInd>>2]|0;
 HEAP32[$_aInd>>2] = $75;
 $76 = (($_aInd) + 4|0);
 $77 = (($aInd) + 4|0);
 $78 = HEAP32[$77>>2]|0;
 HEAP32[$76>>2] = $78;
 $79 = (($_aInd) + 8|0);
 $80 = (($aInd) + 8|0);
 $81 = HEAP32[$80>>2]|0;
 HEAP32[$79>>2] = $81;
 $82 = (($_aInd) + 12|0);
 $83 = (($aInd) + 12|0);
 $84 = HEAP32[$83>>2]|0;
 HEAP32[$82>>2] = $84;
 $85 = HEAP32[$bInd>>2]|0;
 HEAP32[$_bInd>>2] = $85;
 $86 = (($_bInd) + 4|0);
 $87 = (($bInd) + 4|0);
 $88 = HEAP32[$87>>2]|0;
 HEAP32[$86>>2] = $88;
 $89 = (($_bInd) + 8|0);
 $90 = (($bInd) + 8|0);
 $91 = HEAP32[$90>>2]|0;
 HEAP32[$89>>2] = $91;
 $92 = (($_bInd) + 12|0);
 $93 = (($bInd) + 12|0);
 $94 = HEAP32[$93>>2]|0;
 HEAP32[$92>>2] = $94;
 $95 = ($51|0)==(-1);
 if ($95) {
  HEAP32[$_size>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($0,$_Q,$62,$63,$_size,$t,$w);
  $96 = Math_fround(HEAPF32[$0>>2]);
  $97 = (($0) + 4|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($0) + 8|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($0) + 12|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($96 * $96);
  $104 = Math_fround($98 * $98);
  $105 = Math_fround($103 + $104);
  $106 = Math_fround($100 * $100);
  $107 = Math_fround($105 + $106);
  $108 = HEAP32[$_size>>2]|0;
  $109 = Math_fround(HEAPF32[$t>>2]);
  $110 = Math_fround(HEAPF32[$w>>2]);
  $123 = $107;$266 = $102;$267 = $100;$268 = $98;$269 = $96;$270 = $109;$271 = $110;$tempSize$0 = $108;
 } else {
  $123 = Math_fround(3.40282346638528859812E+38);$266 = Math_fround(0.0);$267 = Math_fround(0.0);$268 = Math_fround(0.0);$269 = Math_fround(0.0);$270 = Math_fround(0.0);$271 = Math_fround(0.0);$tempSize$0 = $1;
 }
 $111 = ($53|0)==(-1);
 if ($111) {
  HEAP32[$_size1>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($q,$_Q,$63,$64,$_size1,$t,$w);
  $112 = Math_fround(HEAPF32[$q>>2]);
  $113 = (($q) + 4|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = (($q) + 8|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = Math_fround($112 * $112);
  $118 = Math_fround($114 * $114);
  $119 = Math_fround($117 + $118);
  $120 = Math_fround($116 * $116);
  $121 = Math_fround($119 + $120);
  $122 = $123 > $121;
  if ($122) {
   $124 = (($q) + 12|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = HEAP32[$_size1>>2]|0;
   $127 = Math_fround(HEAPF32[$t>>2]);
   $128 = Math_fround(HEAPF32[$w>>2]);
   $141 = $121;$272 = $125;$273 = $116;$274 = $114;$275 = $112;$276 = $127;$277 = $128;$indices$sroa$1$0 = 2;$indices$sroa$2$0 = 3;$tempSize$1 = $126;
  } else {
   $141 = $123;$272 = $266;$273 = $267;$274 = $268;$275 = $269;$276 = $270;$277 = $271;$indices$sroa$1$0 = 1;$indices$sroa$2$0 = 2;$tempSize$1 = $tempSize$0;
  }
 } else {
  $141 = $123;$272 = $266;$273 = $267;$274 = $268;$275 = $269;$276 = $270;$277 = $271;$indices$sroa$1$0 = 1;$indices$sroa$2$0 = 2;$tempSize$1 = $tempSize$0;
 }
 $129 = ($55|0)==(-1);
 if ($129) {
  HEAP32[$_size2>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($q3,$_Q,$64,$62,$_size2,$t,$w);
  $130 = Math_fround(HEAPF32[$q3>>2]);
  $131 = (($q3) + 4|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($q3) + 8|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($130 * $130);
  $136 = Math_fround($132 * $132);
  $137 = Math_fround($135 + $136);
  $138 = Math_fround($134 * $134);
  $139 = Math_fround($137 + $138);
  $140 = $141 > $139;
  if ($140) {
   $142 = (($q3) + 12|0);
   $143 = Math_fround(HEAPF32[$142>>2]);
   $144 = HEAP32[$_size2>>2]|0;
   $145 = Math_fround(HEAPF32[$t>>2]);
   $146 = Math_fround(HEAPF32[$w>>2]);
   $160 = $139;$278 = $143;$279 = $134;$280 = $132;$281 = $130;$282 = $145;$283 = $146;$indices$sroa$1$1 = 3;$indices$sroa$2$1 = 1;$tempSize$2 = $144;
  } else {
   $160 = $141;$278 = $272;$279 = $273;$280 = $274;$281 = $275;$282 = $276;$283 = $277;$indices$sroa$1$1 = $indices$sroa$1$0;$indices$sroa$2$1 = $indices$sroa$2$0;$tempSize$2 = $tempSize$1;
  }
 } else {
  $160 = $141;$278 = $272;$279 = $273;$280 = $274;$281 = $275;$282 = $276;$283 = $277;$indices$sroa$1$1 = $indices$sroa$1$0;$indices$sroa$2$1 = $indices$sroa$2$0;$tempSize$2 = $tempSize$1;
 }
 $147 = HEAP32[$56>>2]|0;
 $148 = ($147|0)==(-1);
 if ($148) {
  HEAP32[$_size6>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleBaryCentricERKNS_6shdfnd3aos5Vec3VES5_S5_RjRNS2_6FloatVES8_($q7,$62,$64,$63,$_size6,$t,$w);
  $149 = Math_fround(HEAPF32[$q7>>2]);
  $150 = (($q7) + 4|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = (($q7) + 8|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  $154 = Math_fround($149 * $149);
  $155 = Math_fround($151 * $151);
  $156 = Math_fround($154 + $155);
  $157 = Math_fround($153 * $153);
  $158 = Math_fround($156 + $157);
  $159 = $160 > $158;
  if ($159) {
   $161 = (($q7) + 12|0);
   $162 = Math_fround(HEAPF32[$161>>2]);
   $163 = HEAP32[$_size6>>2]|0;
   $164 = Math_fround(HEAPF32[$t>>2]);
   $165 = Math_fround(HEAPF32[$w>>2]);
   $175 = $78;$180 = $88;$228 = $165;$232 = $164;$259 = $149;$261 = $151;$263 = $153;$265 = $162;$indices$sroa$0$2 = 1;$indices$sroa$1$2 = 3;$indices$sroa$2$2 = 2;$tempSize$3 = $163;
  } else {
   $175 = $75;$180 = $85;$228 = $283;$232 = $282;$259 = $281;$261 = $280;$263 = $279;$265 = $278;$indices$sroa$0$2 = 0;$indices$sroa$1$2 = $indices$sroa$1$1;$indices$sroa$2$2 = $indices$sroa$2$1;$tempSize$3 = $tempSize$2;
  }
 } else {
  $175 = $75;$180 = $85;$228 = $283;$232 = $282;$259 = $281;$261 = $280;$263 = $279;$265 = $278;$indices$sroa$0$2 = 0;$indices$sroa$1$2 = $indices$sroa$1$1;$indices$sroa$2$2 = $indices$sroa$2$1;$tempSize$3 = $tempSize$2;
 }
 $166 = (($_A) + ($indices$sroa$0$2<<4)|0);
 ;HEAP32[$A+0>>2]=HEAP32[$166+0>>2]|0;HEAP32[$A+4>>2]=HEAP32[$166+4>>2]|0;HEAP32[$A+8>>2]=HEAP32[$166+8>>2]|0;HEAP32[$A+12>>2]=HEAP32[$166+12>>2]|0;
 $167 = (($_A) + ($indices$sroa$1$2<<4)|0);
 ;HEAP32[$66+0>>2]=HEAP32[$167+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$167+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$167+8>>2]|0;HEAP32[$66+12>>2]=HEAP32[$167+12>>2]|0;
 $168 = (($_A) + ($indices$sroa$2$2<<4)|0);
 ;HEAP32[$68+0>>2]=HEAP32[$168+0>>2]|0;HEAP32[$68+4>>2]=HEAP32[$168+4>>2]|0;HEAP32[$68+8>>2]=HEAP32[$168+8>>2]|0;HEAP32[$68+12>>2]=HEAP32[$168+12>>2]|0;
 $169 = (($_B) + ($indices$sroa$0$2<<4)|0);
 ;HEAP32[$B+0>>2]=HEAP32[$169+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$169+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$169+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$169+12>>2]|0;
 $170 = (($_B) + ($indices$sroa$1$2<<4)|0);
 ;HEAP32[$71+0>>2]=HEAP32[$170+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$170+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$170+8>>2]|0;HEAP32[$71+12>>2]=HEAP32[$170+12>>2]|0;
 $171 = (($_B) + ($indices$sroa$2$2<<4)|0);
 ;HEAP32[$73+0>>2]=HEAP32[$171+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$171+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$171+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$171+12>>2]|0;
 $172 = (($_Q) + ($indices$sroa$0$2<<4)|0);
 ;HEAP32[$Q+0>>2]=HEAP32[$172+0>>2]|0;HEAP32[$Q+4>>2]=HEAP32[$172+4>>2]|0;HEAP32[$Q+8>>2]=HEAP32[$172+8>>2]|0;HEAP32[$Q+12>>2]=HEAP32[$172+12>>2]|0;
 $173 = (($_Q) + ($indices$sroa$1$2<<4)|0);
 ;HEAP32[$2+0>>2]=HEAP32[$173+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$173+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$173+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$173+12>>2]|0;
 $174 = (($_Q) + ($indices$sroa$2$2<<4)|0);
 ;HEAP32[$3+0>>2]=HEAP32[$174+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$174+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$174+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$174+12>>2]|0;
 HEAP32[$aInd>>2] = $175;
 $176 = (($_aInd) + ($indices$sroa$1$2<<2)|0);
 $177 = HEAP32[$176>>2]|0;
 HEAP32[$77>>2] = $177;
 $178 = (($_aInd) + ($indices$sroa$2$2<<2)|0);
 $179 = HEAP32[$178>>2]|0;
 HEAP32[$80>>2] = $179;
 HEAP32[$bInd>>2] = $180;
 $181 = (($_bInd) + ($indices$sroa$1$2<<2)|0);
 $182 = HEAP32[$181>>2]|0;
 HEAP32[$87>>2] = $182;
 $183 = (($_bInd) + ($indices$sroa$2$2<<2)|0);
 $184 = HEAP32[$183>>2]|0;
 HEAP32[$90>>2] = $184;
 $185 = Math_fround(HEAPF32[$167>>2]);
 $186 = ((($_A) + ($indices$sroa$1$2<<4)|0) + 4|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = ((($_A) + ($indices$sroa$1$2<<4)|0) + 8|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = Math_fround(HEAPF32[$166>>2]);
 $191 = ((($_A) + ($indices$sroa$0$2<<4)|0) + 4|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = ((($_A) + ($indices$sroa$0$2<<4)|0) + 8|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround($185 - $190);
 $196 = Math_fround($187 - $192);
 $197 = Math_fround($189 - $194);
 $198 = Math_fround(HEAPF32[$168>>2]);
 $199 = ((($_A) + ($indices$sroa$2$2<<4)|0) + 4|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = ((($_A) + ($indices$sroa$2$2<<4)|0) + 8|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = Math_fround($198 - $190);
 $204 = Math_fround($200 - $192);
 $205 = Math_fround($202 - $194);
 $206 = Math_fround(HEAPF32[$170>>2]);
 $207 = ((($_B) + ($indices$sroa$1$2<<4)|0) + 4|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = ((($_B) + ($indices$sroa$1$2<<4)|0) + 8|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = Math_fround(HEAPF32[$169>>2]);
 $212 = ((($_B) + ($indices$sroa$0$2<<4)|0) + 4|0);
 $213 = Math_fround(HEAPF32[$212>>2]);
 $214 = ((($_B) + ($indices$sroa$0$2<<4)|0) + 8|0);
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = Math_fround($206 - $211);
 $217 = Math_fround($208 - $213);
 $218 = Math_fround($210 - $215);
 $219 = Math_fround(HEAPF32[$171>>2]);
 $220 = ((($_B) + ($indices$sroa$2$2<<4)|0) + 4|0);
 $221 = Math_fround(HEAPF32[$220>>2]);
 $222 = ((($_B) + ($indices$sroa$2$2<<4)|0) + 8|0);
 $223 = Math_fround(HEAPF32[$222>>2]);
 $224 = Math_fround($219 - $211);
 $225 = Math_fround($221 - $213);
 $226 = Math_fround($223 - $215);
 $227 = Math_fround($228 * $203);
 $229 = Math_fround($228 * $204);
 $230 = Math_fround($228 * $205);
 $231 = Math_fround($232 * $195);
 $233 = Math_fround($232 * $196);
 $234 = Math_fround($232 * $197);
 $235 = Math_fround($231 + $227);
 $236 = Math_fround($233 + $229);
 $237 = Math_fround($234 + $230);
 $238 = Math_fround($190 + $235);
 $239 = Math_fround($192 + $236);
 $240 = Math_fround($194 + $237);
 HEAPF32[$closestA>>2] = $238;
 $241 = (($closestA) + 4|0);
 HEAPF32[$241>>2] = $239;
 $242 = (($closestA) + 8|0);
 HEAPF32[$242>>2] = $240;
 $243 = (($closestA) + 12|0);
 HEAPF32[$243>>2] = Math_fround(0.0);
 $244 = Math_fround($228 * $224);
 $245 = Math_fround($228 * $225);
 $246 = Math_fround($228 * $226);
 $247 = Math_fround($232 * $216);
 $248 = Math_fround($232 * $217);
 $249 = Math_fround($232 * $218);
 $250 = Math_fround($247 + $244);
 $251 = Math_fround($248 + $245);
 $252 = Math_fround($249 + $246);
 $253 = Math_fround($211 + $250);
 $254 = Math_fround($213 + $251);
 $255 = Math_fround($215 + $252);
 HEAPF32[$closestB>>2] = $253;
 $256 = (($closestB) + 4|0);
 HEAPF32[$256>>2] = $254;
 $257 = (($closestB) + 8|0);
 HEAPF32[$257>>2] = $255;
 $258 = (($closestB) + 12|0);
 HEAPF32[$258>>2] = Math_fround(0.0);
 HEAP32[$size>>2] = $tempSize$3;
 HEAPF32[$agg$result>>2] = $259;
 $260 = (($agg$result) + 4|0);
 HEAPF32[$260>>2] = $261;
 $262 = (($agg$result) + 8|0);
 HEAPF32[$262>>2] = $263;
 $264 = (($agg$result) + 12|0);
 HEAPF32[$264>>2] = $265;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32closestPtPointSegmentTesselationERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_RjRS3_S7_($agg$result,$Q0,$Q1,$A0,$A1,$B0,$B1,$size,$closestA,$closestB) {
 $agg$result = $agg$result|0;
 $Q0 = $Q0|0;
 $Q1 = $Q1|0;
 $A0 = $A0|0;
 $A1 = $A1|0;
 $B0 = $B0|0;
 $B1 = $B1|0;
 $size = $size|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 var $$ = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i10 = Math_fround(0), $$$i$i$i4 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i11 = Math_fround(0), $$$i8$i$i5 = Math_fround(0), $$200 = Math_fround(0), $$201 = Math_fround(0), $$202 = Math_fround(0), $$203 = Math_fround(0), $$204 = Math_fround(0), $$205 = Math_fround(0), $$206 = Math_fround(0), $$207 = Math_fround(0), $$208 = Math_fround(0), $$209 = Math_fround(0), $$210 = Math_fround(0), $$212 = Math_fround(0), $$213 = Math_fround(0);
 var $$214 = Math_fround(0), $$215 = Math_fround(0), $$216 = Math_fround(0), $$217 = Math_fround(0), $$218 = Math_fround(0), $$220 = Math_fround(0), $$221 = Math_fround(0), $$222 = Math_fround(0), $$in1$i$i = 0, $$in1$i$i14 = 0, $$in2$i$i = 0, $$in2$i$i15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0;
 var $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0);
 var $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0);
 var $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0;
 var $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $b$a$i$i = 0, $b$a$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = Math_fround(HEAPF32[$Q0>>2]);
 $3 = (($Q0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($Q0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($Q0) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$Q1>>2]);
 $10 = (($Q1) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($Q1) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($Q1) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$A0>>2]);
 $17 = (($A0) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($A0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($A0) + 12|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround(HEAPF32[$A1>>2]);
 $24 = (($A1) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($A1) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround(HEAPF32[$B0>>2]);
 $29 = (($B0) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($B0) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($B0) + 12|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround(HEAPF32[$B1>>2]);
 $36 = (($B1) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($B1) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($1) + 4|0);
 $41 = (($1) + 8|0);
 $42 = (($1) + 12|0);
 $43 = (($0) + 4|0);
 $44 = (($0) + 8|0);
 $45 = (($0) + 12|0);
 $46 = (($1) + 4|0);
 $47 = (($1) + 8|0);
 $48 = (($1) + 12|0);
 $49 = (($0) + 4|0);
 $50 = (($0) + 8|0);
 $51 = (($0) + 12|0);
 $108 = $8;$142 = $15;$158 = $22;$159 = $34;$53 = $9;$54 = $2;$56 = $11;$57 = $4;$59 = $13;$60 = $6;$65 = $23;$66 = $16;$68 = $25;$69 = $18;$71 = $27;$72 = $20;$77 = $35;$78 = $28;$80 = $37;$81 = $30;$83 = $39;$84 = $32;
 while(1) {
  $52 = Math_fround($54 + $53);
  $55 = Math_fround($57 + $56);
  $58 = Math_fround($60 + $59);
  $61 = Math_fround($52 * Math_fround(0.5));
  $62 = Math_fround($55 * Math_fround(0.5));
  $63 = Math_fround($58 * Math_fround(0.5));
  $64 = Math_fround($66 + $65);
  $67 = Math_fround($69 + $68);
  $70 = Math_fround($72 + $71);
  $73 = Math_fround($64 * Math_fround(0.5));
  $74 = Math_fround($67 * Math_fround(0.5));
  $75 = Math_fround($70 * Math_fround(0.5));
  $76 = Math_fround($78 + $77);
  $79 = Math_fround($81 + $80);
  $82 = Math_fround($84 + $83);
  $85 = Math_fround($76 * Math_fround(0.5));
  $86 = Math_fround($79 * Math_fround(0.5));
  $87 = Math_fround($82 * Math_fround(0.5));
  $88 = Math_fround($61 - $54);
  $89 = Math_fround($62 - $57);
  $90 = Math_fround($63 - $60);
  $91 = Math_fround($88 * $88);
  $92 = Math_fround($89 * $89);
  $93 = Math_fround($92 + $91);
  $94 = Math_fround($90 * $90);
  $95 = Math_fround($94 + $93);
  $96 = $95 < Math_fround(1.0E+4);
  if ($96) {
   break;
  }
  $97 = Math_fround($54 * $88);
  $98 = Math_fround($57 * $89);
  $99 = Math_fround(-$98);
  $100 = Math_fround($99 - $97);
  $101 = Math_fround($60 * $90);
  $102 = Math_fround($100 - $101);
  $103 = Math_fround($102 / $95);
  $104 = $103 > Math_fround(1.0);
  $$$i$i$i10 = $104 ? Math_fround(1.0) : $103;
  $105 = $$$i$i$i10 > Math_fround(0.0);
  $$$i8$i$i11 = $105 ? $$$i$i$i10 : Math_fround(0.0);
  $106 = $95 != Math_fround(0.0);
  $107 = $106 ? $$$i8$i$i11 : Math_fround(0.0);
  HEAPF32[$1>>2] = $54;
  HEAPF32[$40>>2] = $57;
  HEAPF32[$41>>2] = $60;
  HEAPF32[$42>>2] = $108;
  $109 = Math_fround($88 * $107);
  $110 = Math_fround($89 * $107);
  $111 = Math_fround($90 * $107);
  $112 = Math_fround($54 + $109);
  $113 = Math_fround($57 + $110);
  $114 = Math_fround($60 + $111);
  HEAPF32[$0>>2] = $112;
  HEAPF32[$43>>2] = $113;
  HEAPF32[$44>>2] = $114;
  HEAPF32[$45>>2] = Math_fround(0.0);
  $b$a$i$i12 = $106 ? $0 : $1;
  $115 = Math_fround(HEAPF32[$b$a$i$i12>>2]);
  $$in1$i$i14 = (($b$a$i$i12) + 4|0);
  $116 = Math_fround(HEAPF32[$$in1$i$i14>>2]);
  $$in2$i$i15 = (($b$a$i$i12) + 8|0);
  $117 = Math_fround(HEAPF32[$$in2$i$i15>>2]);
  $118 = Math_fround($115 * $115);
  $119 = Math_fround($116 * $116);
  $120 = Math_fround($118 + $119);
  $121 = Math_fround($117 * $117);
  $122 = Math_fround($120 + $121);
  $123 = Math_fround($61 - $53);
  $124 = Math_fround($62 - $56);
  $125 = Math_fround($63 - $59);
  $126 = Math_fround($123 * $123);
  $127 = Math_fround($124 * $124);
  $128 = Math_fround($127 + $126);
  $129 = Math_fround($125 * $125);
  $130 = Math_fround($129 + $128);
  $131 = Math_fround($53 * $123);
  $132 = Math_fround($56 * $124);
  $133 = Math_fround(-$132);
  $134 = Math_fround($133 - $131);
  $135 = Math_fround($59 * $125);
  $136 = Math_fround($134 - $135);
  $137 = Math_fround($136 / $130);
  $138 = $137 > Math_fround(1.0);
  $$$i$i$i4 = $138 ? Math_fround(1.0) : $137;
  $139 = $$$i$i$i4 > Math_fround(0.0);
  $$$i8$i$i5 = $139 ? $$$i$i$i4 : Math_fround(0.0);
  $140 = $130 != Math_fround(0.0);
  $141 = $140 ? $$$i8$i$i5 : Math_fround(0.0);
  HEAPF32[$1>>2] = $53;
  HEAPF32[$46>>2] = $56;
  HEAPF32[$47>>2] = $59;
  HEAPF32[$48>>2] = $142;
  $143 = Math_fround($123 * $141);
  $144 = Math_fround($124 * $141);
  $145 = Math_fround($125 * $141);
  $146 = Math_fround($53 + $143);
  $147 = Math_fround($56 + $144);
  $148 = Math_fround($59 + $145);
  HEAPF32[$0>>2] = $146;
  HEAPF32[$49>>2] = $147;
  HEAPF32[$50>>2] = $148;
  HEAPF32[$51>>2] = Math_fround(0.0);
  $b$a$i$i = $140 ? $0 : $1;
  $149 = Math_fround(HEAPF32[$b$a$i$i>>2]);
  $$in1$i$i = (($b$a$i$i) + 4|0);
  $150 = Math_fround(HEAPF32[$$in1$i$i>>2]);
  $$in2$i$i = (($b$a$i$i) + 8|0);
  $151 = Math_fround(HEAPF32[$$in2$i$i>>2]);
  $152 = Math_fround($149 * $149);
  $153 = Math_fround($150 * $150);
  $154 = Math_fround($152 + $153);
  $155 = Math_fround($151 * $151);
  $156 = Math_fround($154 + $155);
  $157 = $122 > $156;
  $$ = $157 ? Math_fround(0.0) : $108;
  $$200 = $157 ? $63 : $60;
  $$201 = $157 ? $62 : $57;
  $$202 = $157 ? $61 : $54;
  $$203 = $157 ? $142 : Math_fround(0.0);
  $$204 = $157 ? $59 : $63;
  $$205 = $157 ? $56 : $62;
  $$206 = $157 ? $53 : $61;
  $$207 = $157 ? Math_fround(0.0) : $158;
  $$208 = $157 ? $75 : $72;
  $$209 = $157 ? $74 : $69;
  $$210 = $157 ? $73 : $66;
  $$212 = $157 ? $71 : $75;
  $$213 = $157 ? $68 : $74;
  $$214 = $157 ? $65 : $73;
  $$215 = $157 ? Math_fround(0.0) : $159;
  $$216 = $157 ? $87 : $84;
  $$217 = $157 ? $86 : $81;
  $$218 = $157 ? $85 : $78;
  $$220 = $157 ? $83 : $87;
  $$221 = $157 ? $80 : $86;
  $$222 = $157 ? $77 : $85;
  $108 = $$;$142 = $$203;$158 = $$207;$159 = $$215;$53 = $$206;$54 = $$202;$56 = $$205;$57 = $$201;$59 = $$204;$60 = $$200;$65 = $$214;$66 = $$210;$68 = $$213;$69 = $$209;$71 = $$212;$72 = $$208;$77 = $$222;$78 = $$218;$80 = $$221;$81 = $$217;$83 = $$220;$84 = $$216;
 }
 $160 = Math_fround($53 - $54);
 $161 = Math_fround($56 - $57);
 $162 = Math_fround($59 - $60);
 $163 = Math_fround($160 * $160);
 $164 = Math_fround($161 * $161);
 $165 = Math_fround($164 + $163);
 $166 = Math_fround($162 * $162);
 $167 = Math_fround($166 + $165);
 $168 = $167 == Math_fround(0.0);
 if ($168) {
  HEAP32[$size>>2] = 1;
  HEAPF32[$closestA>>2] = $66;
  $169 = (($closestA) + 4|0);
  HEAPF32[$169>>2] = $69;
  $170 = (($closestA) + 8|0);
  HEAPF32[$170>>2] = $72;
  $171 = (($closestA) + 12|0);
  HEAPF32[$171>>2] = $158;
  HEAPF32[$closestB>>2] = $78;
  $172 = (($closestB) + 4|0);
  HEAPF32[$172>>2] = $81;
  $173 = (($closestB) + 8|0);
  HEAPF32[$173>>2] = $84;
  $174 = (($closestB) + 12|0);
  HEAPF32[$174>>2] = $159;
  HEAPF32[$agg$result>>2] = $54;
  $175 = (($agg$result) + 4|0);
  HEAPF32[$175>>2] = $57;
  $176 = (($agg$result) + 8|0);
  HEAPF32[$176>>2] = $60;
  $177 = (($agg$result) + 12|0);
  HEAPF32[$177>>2] = $108;
  STACKTOP = sp;return;
 } else {
  $178 = Math_fround($57 * $161);
  $179 = Math_fround(-$178);
  $180 = Math_fround($54 * $160);
  $181 = Math_fround($179 - $180);
  $182 = Math_fround($60 * $162);
  $183 = Math_fround($181 - $182);
  $184 = Math_fround($65 - $66);
  $185 = Math_fround($68 - $69);
  $186 = Math_fround($71 - $72);
  $187 = Math_fround($77 - $78);
  $188 = Math_fround($80 - $81);
  $189 = Math_fround($83 - $84);
  $190 = Math_fround($183 / $167);
  $191 = $190 > Math_fround(1.0);
  $$$i$i$i = $191 ? Math_fround(1.0) : $190;
  $192 = $$$i$i$i > Math_fround(0.0);
  $$$i8$i$i = $192 ? $$$i$i$i : Math_fround(0.0);
  $193 = Math_fround($184 * $$$i8$i$i);
  $194 = Math_fround($185 * $$$i8$i$i);
  $195 = Math_fround($186 * $$$i8$i$i);
  $196 = Math_fround($66 + $193);
  $197 = Math_fround($69 + $194);
  $198 = Math_fround($72 + $195);
  $199 = Math_fround($187 * $$$i8$i$i);
  $200 = Math_fround($188 * $$$i8$i$i);
  $201 = Math_fround($189 * $$$i8$i$i);
  $202 = Math_fround($78 + $199);
  $203 = Math_fround($81 + $200);
  $204 = Math_fround($84 + $201);
  HEAPF32[$closestA>>2] = $196;
  $205 = (($closestA) + 4|0);
  HEAPF32[$205>>2] = $197;
  $206 = (($closestA) + 8|0);
  HEAPF32[$206>>2] = $198;
  $207 = (($closestA) + 12|0);
  HEAPF32[$207>>2] = Math_fround(0.0);
  HEAPF32[$closestB>>2] = $202;
  $208 = (($closestB) + 4|0);
  HEAPF32[$208>>2] = $203;
  $209 = (($closestB) + 8|0);
  HEAPF32[$209>>2] = $204;
  $210 = (($closestB) + 12|0);
  HEAPF32[$210>>2] = Math_fround(0.0);
  $211 = Math_fround($196 - $202);
  $212 = Math_fround($197 - $203);
  $213 = Math_fround($198 - $204);
  HEAPF32[$agg$result>>2] = $211;
  $214 = (($agg$result) + 4|0);
  HEAPF32[$214>>2] = $212;
  $215 = (($agg$result) + 8|0);
  HEAPF32[$215>>2] = $213;
  $216 = (($agg$result) + 12|0);
  HEAPF32[$216>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu21closestPtPointSegmentERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_RjRS3_S7_($agg$result,$Q0,$Q1,$A0,$A1,$B0,$B1,$size,$closestA,$closestB) {
 $agg$result = $agg$result|0;
 $Q0 = $Q0|0;
 $Q1 = $Q1|0;
 $A0 = $A0|0;
 $A1 = $A1|0;
 $B0 = $B0|0;
 $B1 = $B1|0;
 $size = $size|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 var $$$i$i = Math_fround(0), $$$i8$i = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$Q0>>2]);
 $1 = (($Q0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($Q0) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$Q1>>2]);
 $6 = (($Q1) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($Q1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($5 - $0);
 $11 = Math_fround($7 - $2);
 $12 = Math_fround($9 - $4);
 $13 = Math_fround($10 * $10);
 $14 = Math_fround($11 * $11);
 $15 = Math_fround($13 + $14);
 $16 = Math_fround($12 * $12);
 $17 = Math_fround($15 + $16);
 $18 = $17 == Math_fround(0.0);
 if ($18) {
  HEAP32[$size>>2] = 1;
  ;HEAP32[$closestA+0>>2]=HEAP32[$A0+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$A0+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$A0+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$A0+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$B0+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$B0+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$B0+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$B0+12>>2]|0;
  ;HEAP32[$agg$result+0>>2]=HEAP32[$Q0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$Q0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$Q0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$Q0+12>>2]|0;
  STACKTOP = sp;return;
 } else {
  $19 = Math_fround($2 * $11);
  $20 = Math_fround(-$19);
  $21 = Math_fround($0 * $10);
  $22 = Math_fround($20 - $21);
  $23 = Math_fround($4 * $12);
  $24 = Math_fround($22 - $23);
  $25 = Math_fround(HEAPF32[$A1>>2]);
  $26 = (($A1) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($A1) + 8|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround(HEAPF32[$A0>>2]);
  $31 = (($A0) + 4|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($A0) + 8|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($25 - $30);
  $36 = Math_fround($27 - $32);
  $37 = Math_fround($29 - $34);
  $38 = Math_fround(HEAPF32[$B1>>2]);
  $39 = (($B1) + 4|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($B1) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(HEAPF32[$B0>>2]);
  $44 = (($B0) + 4|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($B0) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($38 - $43);
  $49 = Math_fround($40 - $45);
  $50 = Math_fround($42 - $47);
  $51 = Math_fround($24 / $17);
  $52 = $51 > Math_fround(1.0);
  $$$i$i = $52 ? Math_fround(1.0) : $51;
  $53 = $$$i$i > Math_fround(0.0);
  $$$i8$i = $53 ? $$$i$i : Math_fround(0.0);
  $54 = Math_fround($35 * $$$i8$i);
  $55 = Math_fround($36 * $$$i8$i);
  $56 = Math_fround($37 * $$$i8$i);
  $57 = Math_fround($30 + $54);
  $58 = Math_fround($32 + $55);
  $59 = Math_fround($34 + $56);
  $60 = Math_fround($48 * $$$i8$i);
  $61 = Math_fround($49 * $$$i8$i);
  $62 = Math_fround($50 * $$$i8$i);
  $63 = Math_fround($43 + $60);
  $64 = Math_fround($45 + $61);
  $65 = Math_fround($62 + $47);
  HEAPF32[$closestA>>2] = $57;
  $66 = (($closestA) + 4|0);
  HEAPF32[$66>>2] = $58;
  $67 = (($closestA) + 8|0);
  HEAPF32[$67>>2] = $59;
  $68 = (($closestA) + 12|0);
  HEAPF32[$68>>2] = Math_fround(0.0);
  HEAPF32[$closestB>>2] = $63;
  $69 = (($closestB) + 4|0);
  HEAPF32[$69>>2] = $64;
  $70 = (($closestB) + 8|0);
  HEAPF32[$70>>2] = $65;
  $71 = (($closestB) + 12|0);
  HEAPF32[$71>>2] = Math_fround(0.0);
  $72 = Math_fround($57 - $63);
  $73 = Math_fround($58 - $64);
  $74 = Math_fround($59 - $65);
  HEAPF32[$agg$result>>2] = $72;
  $75 = (($agg$result) + 4|0);
  HEAPF32[$75>>2] = $73;
  $76 = (($agg$result) + 8|0);
  HEAPF32[$76>>2] = $74;
  $77 = (($agg$result) + 12|0);
  HEAPF32[$77>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu33closestPtPointTriangleTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_PjRjRS3_S7_($agg$result,$Q,$A,$B,$indices,$size,$closestA,$closestB) {
 $agg$result = $agg$result|0;
 $Q = $Q|0;
 $A = $A|0;
 $B = $B|0;
 $indices = $indices|0;
 $size = $size|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 var $$$i = Math_fround(0), $$$i322 = Math_fround(0), $$$i327 = Math_fround(0), $$$i332 = Math_fround(0), $$$i542 = Math_fround(0), $$2355 = Math_fround(0), $$2356 = Math_fround(0), $$2357 = Math_fround(0), $$2359 = Math_fround(0), $$2360 = Math_fround(0), $$2361 = Math_fround(0), $$2363 = Math_fround(0), $$2364 = Math_fround(0), $$2365 = Math_fround(0), $$2367 = Math_fround(0), $$2368 = Math_fround(0), $$2369 = Math_fround(0), $$2371 = Math_fround(0), $$2372 = Math_fround(0), $$2373 = Math_fround(0);
 var $$2375 = Math_fround(0), $$2376 = Math_fround(0), $$2377 = Math_fround(0), $$2379 = Math_fround(0), $$2380 = Math_fround(0), $$2381 = Math_fround(0), $$2383 = Math_fround(0), $$2384 = Math_fround(0), $$2385 = Math_fround(0), $$2387 = Math_fround(0), $$2388 = Math_fround(0), $$2389 = Math_fround(0), $$2391 = Math_fround(0), $$2392 = Math_fround(0), $$2393 = Math_fround(0), $$2395 = Math_fround(0), $$2396 = Math_fround(0), $$2397 = Math_fround(0), $$2399 = Math_fround(0), $$2400 = Math_fround(0);
 var $$2401 = Math_fround(0), $$2403 = Math_fround(0), $$2404 = Math_fround(0), $$2405 = Math_fround(0), $$2407 = Math_fround(0), $$2408 = Math_fround(0), $$2409 = Math_fround(0), $$2411 = Math_fround(0), $$2412 = Math_fround(0), $$2413 = Math_fround(0), $$2415 = Math_fround(0), $$2416 = Math_fround(0), $$2417 = Math_fround(0), $$2419 = Math_fround(0), $$2420 = Math_fround(0), $$2421 = Math_fround(0), $$2423 = Math_fround(0), $$2424 = Math_fround(0), $$2425 = Math_fround(0), $$ph2437 = Math_fround(0);
 var $$ph2438 = Math_fround(0), $$ph2439 = Math_fround(0), $$ph2441 = Math_fround(0), $$ph2442 = Math_fround(0), $$ph2443 = Math_fround(0), $$ph2445 = Math_fround(0), $$ph2446 = Math_fround(0), $$ph2447 = Math_fround(0), $$ph2449 = Math_fround(0), $$ph2450 = Math_fround(0), $$ph2451 = Math_fround(0), $$ph2453 = Math_fround(0), $$ph2454 = Math_fround(0), $$ph2455 = Math_fround(0), $$ph2457 = Math_fround(0), $$ph2458 = Math_fround(0), $$ph2459 = Math_fround(0), $$ph2461 = Math_fround(0), $$ph2462 = Math_fround(0), $$ph2463 = Math_fround(0);
 var $$ph2465 = Math_fround(0), $$ph2466 = Math_fround(0), $$ph2467 = Math_fround(0), $$ph2469 = Math_fround(0), $$ph2470 = Math_fround(0), $$ph2471 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0;
 var $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0;
 var $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0);
 var $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0);
 var $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0);
 var $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0);
 var $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0);
 var $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0);
 var $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0);
 var $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0);
 var $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0);
 var $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0);
 var $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0);
 var $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = 0, $504 = 0, $505 = 0, $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge2661 = 0, $brmerge2663 = 0, $or$cond = 0, $or$cond2426 = 0, $or$cond2428 = 0, $or$cond2435 = 0, $or$cond2436 = 0;
 var $phitmp = 0, $phitmp2664 = 0, $phitmp2665 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$size>>2] = 3;
 $0 = HEAP32[$indices>>2]|0;
 $1 = (($indices) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($indices) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($Q) + ($0<<4)|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = ((($Q) + ($0<<4)|0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = ((($Q) + ($0<<4)|0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($Q) + ($2<<4)|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = ((($Q) + ($2<<4)|0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = ((($Q) + ($2<<4)|0) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($Q) + ($4<<4)|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = ((($Q) + ($4<<4)|0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = ((($Q) + ($4<<4)|0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($12 - $6);
 $24 = Math_fround($14 - $8);
 $25 = Math_fround($16 - $10);
 $26 = Math_fround($18 - $6);
 $27 = Math_fround($20 - $8);
 $28 = Math_fround($22 - $10);
 $29 = Math_fround($12 - $18);
 $30 = Math_fround($14 - $20);
 $31 = Math_fround($16 - $22);
 $32 = Math_fround($26 * $26);
 $33 = Math_fround($27 * $27);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($28 * $28);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($29 * $29);
 $38 = Math_fround($30 * $30);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($31 * $31);
 $41 = Math_fround($39 + $40);
 $42 = $36 > $41;
 $$$i542 = $42 ? $41 : $36;
 $43 = !($$$i542 <= Math_fround(1.1920928955078125E-7));
 if (!($43)) {
  HEAP32[$size>>2] = 2;
  $44 = (($A) + ($0<<4)|0);
  $45 = (($A) + ($2<<4)|0);
  $46 = (($B) + ($0<<4)|0);
  $47 = (($B) + ($2<<4)|0);
  __ZN5physx2Gu21closestPtPointSegmentERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_RjRS3_S7_($agg$result,$5,$11,$44,$45,$46,$47,$size,$closestA,$closestB);
  STACKTOP = sp;return;
 }
 $48 = Math_fround(-$6);
 $49 = Math_fround(-$8);
 $50 = Math_fround(-$10);
 $51 = Math_fround(-$12);
 $52 = Math_fround(-$14);
 $53 = Math_fround(-$16);
 $54 = Math_fround(-$18);
 $55 = Math_fround(-$20);
 $56 = Math_fround(-$22);
 $57 = Math_fround($23 * $48);
 $58 = Math_fround($24 * $49);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($25 * $50);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($26 * $48);
 $63 = Math_fround($27 * $49);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($28 * $50);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($23 * $51);
 $68 = Math_fround($24 * $52);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround($25 * $53);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($26 * $51);
 $73 = Math_fround($27 * $52);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($28 * $53);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($23 * $54);
 $78 = Math_fround($24 * $55);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($25 * $56);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($26 * $54);
 $83 = Math_fround($27 * $55);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($28 * $56);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($71 * $86);
 $88 = Math_fround($81 * $76);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($81 * $66);
 $91 = Math_fround($61 * $86);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($61 * $76);
 $94 = Math_fround($71 * $66);
 $95 = Math_fround($93 - $94);
 $96 = !($61 <= Math_fround(0.0));
 $97 = !($66 <= Math_fround(0.0));
 $or$cond = $96 | $97;
 if (!($or$cond)) {
  $98 = (($A) + ($0<<4)|0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$98+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$98+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$98+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$98+12>>2]|0;
  $99 = (($B) + ($0<<4)|0);
  ;HEAP32[$closestB+0>>2]=HEAP32[$99+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$99+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$99+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$99+12>>2]|0;
  ;HEAP32[$agg$result+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$5+12>>2]|0;
  STACKTOP = sp;return;
 }
 $100 = !($71 >= Math_fround(0.0));
 $101 = !($71 >= $76);
 $or$cond2426 = $100 | $101;
 if (!($or$cond2426)) {
  $102 = (($A) + ($2<<4)|0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$102+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$102+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$102+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$102+12>>2]|0;
  $103 = (($B) + ($2<<4)|0);
  ;HEAP32[$closestB+0>>2]=HEAP32[$103+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$103+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$103+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$103+12>>2]|0;
  ;HEAP32[$agg$result+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$11+12>>2]|0;
  STACKTOP = sp;return;
 }
 $104 = !($86 >= Math_fround(0.0));
 $105 = !($86 >= $81);
 $or$cond2428 = $104 | $105;
 if (!($or$cond2428)) {
  $106 = (($A) + ($4<<4)|0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$106+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$106+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$106+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$106+12>>2]|0;
  $107 = (($B) + ($4<<4)|0);
  ;HEAP32[$closestB+0>>2]=HEAP32[$107+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$107+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$107+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$107+12>>2]|0;
  ;HEAP32[$agg$result+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$17+12>>2]|0;
  STACKTOP = sp;return;
 }
 $108 = !($95 <= Math_fround(0.0));
 $109 = !($61 >= Math_fround(0.0));
 if ($109) {
  $110 = 1;
 } else {
  $phitmp = !($71 <= Math_fround(0.0));
  $110 = $phitmp;
 }
 $brmerge = $108 | $110;
 if (!($brmerge)) {
  $111 = (($A) + ($0<<4)|0);
  $112 = (($A) + ($2<<4)|0);
  $113 = (($B) + ($0<<4)|0);
  $114 = (($B) + ($2<<4)|0);
  __ZN5physx2Gu32closestPtPointSegmentTesselationERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_RjRS3_S7_($agg$result,$5,$11,$111,$112,$113,$114,$size,$closestA,$closestB);
  STACKTOP = sp;return;
 }
 $115 = !($89 <= Math_fround(0.0));
 $116 = !($76 >= $71);
 if ($116) {
  $117 = 1;
 } else {
  $phitmp2664 = !($81 >= $86);
  $117 = $phitmp2664;
 }
 $brmerge2661 = $115 | $117;
 if (!($brmerge2661)) {
  $118 = (($A) + ($2<<4)|0);
  $119 = (($A) + ($4<<4)|0);
  $120 = (($B) + ($2<<4)|0);
  $121 = (($B) + ($4<<4)|0);
  __ZN5physx2Gu32closestPtPointSegmentTesselationERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_RjRS3_S7_($agg$result,$11,$17,$118,$119,$120,$121,$size,$closestA,$closestB);
  STACKTOP = sp;return;
 }
 $122 = !($92 <= Math_fround(0.0));
 $123 = !($66 >= Math_fround(0.0));
 if ($123) {
  $124 = 1;
 } else {
  $phitmp2665 = !($86 <= Math_fround(0.0));
  $124 = $phitmp2665;
 }
 $brmerge2663 = $122 | $124;
 if (!($brmerge2663)) {
  $125 = (($A) + ($0<<4)|0);
  $126 = (($A) + ($4<<4)|0);
  $127 = (($B) + ($0<<4)|0);
  $128 = (($B) + ($4<<4)|0);
  __ZN5physx2Gu32closestPtPointSegmentTesselationERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_RjRS3_S7_($agg$result,$5,$17,$125,$126,$127,$128,$size,$closestA,$closestB);
  STACKTOP = sp;return;
 }
 HEAP32[$size>>2] = 3;
 $129 = Math_fround(HEAPF32[$5>>2]);
 $130 = Math_fround(HEAPF32[$7>>2]);
 $131 = Math_fround(HEAPF32[$9>>2]);
 $132 = Math_fround(HEAPF32[$11>>2]);
 $133 = Math_fround(HEAPF32[$13>>2]);
 $134 = Math_fround(HEAPF32[$15>>2]);
 $135 = Math_fround(HEAPF32[$17>>2]);
 $136 = Math_fround(HEAPF32[$19>>2]);
 $137 = Math_fround(HEAPF32[$21>>2]);
 $138 = (($A) + ($0<<4)|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = ((($A) + ($0<<4)|0) + 4|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = ((($A) + ($0<<4)|0) + 8|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($A) + ($2<<4)|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = ((($A) + ($2<<4)|0) + 4|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = ((($A) + ($2<<4)|0) + 8|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($A) + ($4<<4)|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = ((($A) + ($4<<4)|0) + 4|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = ((($A) + ($4<<4)|0) + 8|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = (($B) + ($0<<4)|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = ((($B) + ($0<<4)|0) + 4|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = ((($B) + ($0<<4)|0) + 8|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($B) + ($2<<4)|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = ((($B) + ($2<<4)|0) + 4|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = ((($B) + ($2<<4)|0) + 8|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = (($B) + ($4<<4)|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = ((($B) + ($4<<4)|0) + 4|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = ((($B) + ($4<<4)|0) + 8|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $$ph2437 = $131;$$ph2438 = $130;$$ph2439 = $129;$$ph2441 = $134;$$ph2442 = $133;$$ph2443 = $132;$$ph2445 = $137;$$ph2446 = $136;$$ph2447 = $135;$$ph2449 = $143;$$ph2450 = $141;$$ph2451 = $139;$$ph2453 = $149;$$ph2454 = $147;$$ph2455 = $145;$$ph2457 = $155;$$ph2458 = $153;$$ph2459 = $151;$$ph2461 = $161;$$ph2462 = $159;$$ph2463 = $157;$$ph2465 = $167;$$ph2466 = $165;$$ph2467 = $163;$$ph2469 = $173;$$ph2470 = $171;$$ph2471 = $169;
 L38: while(1) {
  $175 = $$ph2443;$177 = $$ph2442;$179 = $$ph2441;$181 = $$ph2447;$183 = $$ph2446;$185 = $$ph2445;$240 = $$ph2455;$242 = $$ph2454;$244 = $$ph2453;$249 = $$ph2467;$251 = $$ph2466;$253 = $$ph2465;$300 = $$ph2459;$302 = $$ph2458;$304 = $$ph2457;$309 = $$ph2471;$311 = $$ph2470;$313 = $$ph2469;
  while(1) {
   $174 = Math_fround($175 - $$ph2439);
   $176 = Math_fround($177 - $$ph2438);
   $178 = Math_fround($179 - $$ph2437);
   $180 = Math_fround($181 - $$ph2439);
   $182 = Math_fround($183 - $$ph2438);
   $184 = Math_fround($185 - $$ph2437);
   $186 = Math_fround($181 - $175);
   $187 = Math_fround($183 - $177);
   $188 = Math_fround($185 - $179);
   $189 = Math_fround($174 * $174);
   $190 = Math_fround($176 * $176);
   $191 = Math_fround($190 + $189);
   $192 = Math_fround($178 * $178);
   $193 = Math_fround($192 + $191);
   $194 = Math_fround($180 * $180);
   $195 = Math_fround($182 * $182);
   $196 = Math_fround($195 + $194);
   $197 = Math_fround($184 * $184);
   $198 = Math_fround($197 + $196);
   $199 = Math_fround($186 * $186);
   $200 = Math_fround($187 * $187);
   $201 = Math_fround($200 + $199);
   $202 = Math_fround($188 * $188);
   $203 = Math_fround($202 + $201);
   $204 = $198 > $203;
   $$$i332 = $204 ? $198 : $203;
   $205 = $193 > $$$i332;
   $$$i327 = $205 ? $193 : $$$i332;
   $$$i322 = $204 ? $203 : $198;
   $206 = $193 > $$$i322;
   $$$i = $206 ? $$$i322 : $193;
   $207 = Math_fround($176 * $184);
   $208 = Math_fround($178 * $182);
   $209 = Math_fround($207 - $208);
   $210 = Math_fround($178 * $180);
   $211 = Math_fround($174 * $184);
   $212 = Math_fround($210 - $211);
   $213 = Math_fround($174 * $182);
   $214 = Math_fround($176 * $180);
   $215 = Math_fround($213 - $214);
   $216 = Math_fround($209 * $209);
   $217 = Math_fround($212 * $212);
   $218 = Math_fround($216 + $217);
   $219 = Math_fround($215 * $215);
   $220 = Math_fround($219 + $218);
   $221 = (Math_fround(Math_sqrt((Math_fround($220)))));
   $222 = (Math_fround(Math_sqrt((Math_fround($$$i327)))));
   $223 = (Math_fround(Math_sqrt((Math_fround($$$i)))));
   $224 = Math_fround($222 / $223);
   $225 = $224 < Math_fround(4.0);
   $226 = $221 < Math_fround(100.0);
   $or$cond2435 = $225 & $226;
   if ($or$cond2435) {
    break L38;
   }
   $227 = Math_fround(Math_fround(1.0) / $221);
   $228 = Math_fround($209 * $227);
   $229 = Math_fround($212 * $227);
   $230 = Math_fround($215 * $227);
   $231 = !($193 >= $198);
   $232 = !($193 >= $203);
   $or$cond2436 = $231 | $232;
   if (!($or$cond2436)) {
    label = 25;
    break;
   }
   $292 = !($198 >= $203);
   if (!($292)) {
    label = 27;
    break;
   }
   $352 = Math_fround($175 + $181);
   $353 = Math_fround($177 + $183);
   $354 = Math_fround($179 + $185);
   $355 = Math_fround($352 * Math_fround(0.5));
   $356 = Math_fround($353 * Math_fround(0.5));
   $357 = Math_fround($354 * Math_fround(0.5));
   $358 = Math_fround($240 + $300);
   $359 = Math_fround($242 + $302);
   $360 = Math_fround($244 + $304);
   $361 = Math_fround($358 * Math_fround(0.5));
   $362 = Math_fround($359 * Math_fround(0.5));
   $363 = Math_fround($360 * Math_fround(0.5));
   $364 = Math_fround($249 + $309);
   $365 = Math_fround($251 + $311);
   $366 = Math_fround($253 + $313);
   $367 = Math_fround($364 * Math_fround(0.5));
   $368 = Math_fround($365 * Math_fround(0.5));
   $369 = Math_fround($366 * Math_fround(0.5));
   $370 = Math_fround($355 - $$ph2439);
   $371 = Math_fround($356 - $$ph2438);
   $372 = Math_fround($357 - $$ph2437);
   $373 = Math_fround($371 * $230);
   $374 = Math_fround($372 * $229);
   $375 = Math_fround($373 - $374);
   $376 = Math_fround($372 * $228);
   $377 = Math_fround($370 * $230);
   $378 = Math_fround($376 - $377);
   $379 = Math_fround($370 * $229);
   $380 = Math_fround($371 * $228);
   $381 = Math_fround($379 - $380);
   $382 = Math_fround($375 * $375);
   $383 = Math_fround($378 * $378);
   $384 = Math_fround($382 + $383);
   $385 = Math_fround($381 * $381);
   $386 = Math_fround($385 + $384);
   $387 = (Math_fround(Math_sqrt((Math_fround($386)))));
   $388 = Math_fround(Math_fround(1.0) / $387);
   $389 = Math_fround($375 * $388);
   $390 = Math_fround($378 * $388);
   $391 = Math_fround($381 * $388);
   $392 = Math_fround($355 * $389);
   $393 = Math_fround($356 * $390);
   $394 = Math_fround($392 + $393);
   $395 = Math_fround($357 * $391);
   $396 = Math_fround($395 + $394);
   $397 = Math_fround($175 * $389);
   $398 = Math_fround($177 * $390);
   $399 = Math_fround($397 + $398);
   $400 = Math_fround($179 * $391);
   $401 = Math_fround($400 + $399);
   $402 = Math_fround($401 - $396);
   $403 = Math_fround($396 * $402);
   $404 = $403 < Math_fround(-0.0);
   $$2403 = $404 ? $179 : $357;
   $$2404 = $404 ? $177 : $356;
   $$2405 = $404 ? $175 : $355;
   $$2407 = $404 ? $357 : $185;
   $$2408 = $404 ? $356 : $183;
   $$2409 = $404 ? $355 : $181;
   $$2411 = $404 ? $244 : $363;
   $$2412 = $404 ? $242 : $362;
   $$2413 = $404 ? $240 : $361;
   $$2415 = $404 ? $363 : $304;
   $$2416 = $404 ? $362 : $302;
   $$2417 = $404 ? $361 : $300;
   $$2419 = $404 ? $253 : $369;
   $$2420 = $404 ? $251 : $368;
   $$2421 = $404 ? $249 : $367;
   $$2423 = $404 ? $369 : $313;
   $$2424 = $404 ? $368 : $311;
   $$2425 = $404 ? $367 : $309;
   $175 = $$2405;$177 = $$2404;$179 = $$2403;$181 = $$2409;$183 = $$2408;$185 = $$2407;$240 = $$2413;$242 = $$2412;$244 = $$2411;$249 = $$2421;$251 = $$2420;$253 = $$2419;$300 = $$2417;$302 = $$2416;$304 = $$2415;$309 = $$2425;$311 = $$2424;$313 = $$2423;
  }
  if ((label|0) == 25) {
   label = 0;
   $233 = Math_fround($$ph2439 + $175);
   $234 = Math_fround($$ph2438 + $177);
   $235 = Math_fround($$ph2437 + $179);
   $236 = Math_fround($233 * Math_fround(0.5));
   $237 = Math_fround($234 * Math_fround(0.5));
   $238 = Math_fround($235 * Math_fround(0.5));
   $239 = Math_fround($$ph2451 + $240);
   $241 = Math_fround($$ph2450 + $242);
   $243 = Math_fround($$ph2449 + $244);
   $245 = Math_fround($239 * Math_fround(0.5));
   $246 = Math_fround($241 * Math_fround(0.5));
   $247 = Math_fround($243 * Math_fround(0.5));
   $248 = Math_fround($$ph2463 + $249);
   $250 = Math_fround($$ph2462 + $251);
   $252 = Math_fround($$ph2461 + $253);
   $254 = Math_fround($248 * Math_fround(0.5));
   $255 = Math_fround($250 * Math_fround(0.5));
   $256 = Math_fround($252 * Math_fround(0.5));
   $257 = Math_fround($236 - $181);
   $258 = Math_fround($237 - $183);
   $259 = Math_fround($238 - $185);
   $260 = Math_fround($258 * $230);
   $261 = Math_fround($259 * $229);
   $262 = Math_fround($260 - $261);
   $263 = Math_fround($259 * $228);
   $264 = Math_fround($257 * $230);
   $265 = Math_fround($263 - $264);
   $266 = Math_fround($257 * $229);
   $267 = Math_fround($258 * $228);
   $268 = Math_fround($266 - $267);
   $269 = Math_fround($262 * $262);
   $270 = Math_fround($265 * $265);
   $271 = Math_fround($269 + $270);
   $272 = Math_fround($268 * $268);
   $273 = Math_fround($272 + $271);
   $274 = (Math_fround(Math_sqrt((Math_fround($273)))));
   $275 = Math_fround(Math_fround(1.0) / $274);
   $276 = Math_fround($262 * $275);
   $277 = Math_fround($265 * $275);
   $278 = Math_fround($268 * $275);
   $279 = Math_fround($236 * $276);
   $280 = Math_fround($237 * $277);
   $281 = Math_fround($279 + $280);
   $282 = Math_fround($238 * $278);
   $283 = Math_fround($282 + $281);
   $284 = Math_fround($$ph2439 * $276);
   $285 = Math_fround($$ph2438 * $277);
   $286 = Math_fround($284 + $285);
   $287 = Math_fround($$ph2437 * $278);
   $288 = Math_fround($287 + $286);
   $289 = Math_fround($288 - $283);
   $290 = Math_fround($283 * $289);
   $291 = $290 < Math_fround(-0.0);
   $$2355 = $291 ? $$ph2437 : $238;
   $$2356 = $291 ? $$ph2438 : $237;
   $$2357 = $291 ? $$ph2439 : $236;
   $$2359 = $291 ? $238 : $179;
   $$2360 = $291 ? $237 : $177;
   $$2361 = $291 ? $236 : $175;
   $$2363 = $291 ? $$ph2449 : $247;
   $$2364 = $291 ? $$ph2450 : $246;
   $$2365 = $291 ? $$ph2451 : $245;
   $$2367 = $291 ? $247 : $244;
   $$2368 = $291 ? $246 : $242;
   $$2369 = $291 ? $245 : $240;
   $$2371 = $291 ? $$ph2461 : $256;
   $$2372 = $291 ? $$ph2462 : $255;
   $$2373 = $291 ? $$ph2463 : $254;
   $$2375 = $291 ? $256 : $253;
   $$2376 = $291 ? $255 : $251;
   $$2377 = $291 ? $254 : $249;
   $$ph2437 = $$2355;$$ph2438 = $$2356;$$ph2439 = $$2357;$$ph2441 = $$2359;$$ph2442 = $$2360;$$ph2443 = $$2361;$$ph2445 = $185;$$ph2446 = $183;$$ph2447 = $181;$$ph2449 = $$2363;$$ph2450 = $$2364;$$ph2451 = $$2365;$$ph2453 = $$2367;$$ph2454 = $$2368;$$ph2455 = $$2369;$$ph2457 = $304;$$ph2458 = $302;$$ph2459 = $300;$$ph2461 = $$2371;$$ph2462 = $$2372;$$ph2463 = $$2373;$$ph2465 = $$2375;$$ph2466 = $$2376;$$ph2467 = $$2377;$$ph2469 = $313;$$ph2470 = $311;$$ph2471 = $309;
   continue;
  }
  else if ((label|0) == 27) {
   label = 0;
   $293 = Math_fround($$ph2439 + $181);
   $294 = Math_fround($$ph2438 + $183);
   $295 = Math_fround($$ph2437 + $185);
   $296 = Math_fround($293 * Math_fround(0.5));
   $297 = Math_fround($294 * Math_fround(0.5));
   $298 = Math_fround($295 * Math_fround(0.5));
   $299 = Math_fround($$ph2451 + $300);
   $301 = Math_fround($$ph2450 + $302);
   $303 = Math_fround($$ph2449 + $304);
   $305 = Math_fround($299 * Math_fround(0.5));
   $306 = Math_fround($301 * Math_fround(0.5));
   $307 = Math_fround($303 * Math_fround(0.5));
   $308 = Math_fround($$ph2463 + $309);
   $310 = Math_fround($$ph2462 + $311);
   $312 = Math_fround($$ph2461 + $313);
   $314 = Math_fround($308 * Math_fround(0.5));
   $315 = Math_fround($310 * Math_fround(0.5));
   $316 = Math_fround($312 * Math_fround(0.5));
   $317 = Math_fround($296 - $175);
   $318 = Math_fround($297 - $177);
   $319 = Math_fround($298 - $179);
   $320 = Math_fround($318 * $230);
   $321 = Math_fround($319 * $229);
   $322 = Math_fround($320 - $321);
   $323 = Math_fround($319 * $228);
   $324 = Math_fround($317 * $230);
   $325 = Math_fround($323 - $324);
   $326 = Math_fround($317 * $229);
   $327 = Math_fround($318 * $228);
   $328 = Math_fround($326 - $327);
   $329 = Math_fround($322 * $322);
   $330 = Math_fround($325 * $325);
   $331 = Math_fround($329 + $330);
   $332 = Math_fround($328 * $328);
   $333 = Math_fround($332 + $331);
   $334 = (Math_fround(Math_sqrt((Math_fround($333)))));
   $335 = Math_fround(Math_fround(1.0) / $334);
   $336 = Math_fround($322 * $335);
   $337 = Math_fround($325 * $335);
   $338 = Math_fround($328 * $335);
   $339 = Math_fround($296 * $336);
   $340 = Math_fround($297 * $337);
   $341 = Math_fround($339 + $340);
   $342 = Math_fround($298 * $338);
   $343 = Math_fround($342 + $341);
   $344 = Math_fround($$ph2439 * $336);
   $345 = Math_fround($$ph2438 * $337);
   $346 = Math_fround($344 + $345);
   $347 = Math_fround($$ph2437 * $338);
   $348 = Math_fround($347 + $346);
   $349 = Math_fround($348 - $343);
   $350 = Math_fround($343 * $349);
   $351 = $350 < Math_fround(-0.0);
   $$2379 = $351 ? $$ph2437 : $298;
   $$2380 = $351 ? $$ph2438 : $297;
   $$2381 = $351 ? $$ph2439 : $296;
   $$2383 = $351 ? $298 : $185;
   $$2384 = $351 ? $297 : $183;
   $$2385 = $351 ? $296 : $181;
   $$2387 = $351 ? $$ph2449 : $307;
   $$2388 = $351 ? $$ph2450 : $306;
   $$2389 = $351 ? $$ph2451 : $305;
   $$2391 = $351 ? $307 : $304;
   $$2392 = $351 ? $306 : $302;
   $$2393 = $351 ? $305 : $300;
   $$2395 = $351 ? $$ph2461 : $316;
   $$2396 = $351 ? $$ph2462 : $315;
   $$2397 = $351 ? $$ph2463 : $314;
   $$2399 = $351 ? $316 : $313;
   $$2400 = $351 ? $315 : $311;
   $$2401 = $351 ? $314 : $309;
   $$ph2437 = $$2379;$$ph2438 = $$2380;$$ph2439 = $$2381;$$ph2441 = $179;$$ph2442 = $177;$$ph2443 = $175;$$ph2445 = $$2383;$$ph2446 = $$2384;$$ph2447 = $$2385;$$ph2449 = $$2387;$$ph2450 = $$2388;$$ph2451 = $$2389;$$ph2453 = $244;$$ph2454 = $242;$$ph2455 = $240;$$ph2457 = $$2391;$$ph2458 = $$2392;$$ph2459 = $$2393;$$ph2461 = $$2395;$$ph2462 = $$2396;$$ph2463 = $$2397;$$ph2465 = $253;$$ph2466 = $251;$$ph2467 = $249;$$ph2469 = $$2399;$$ph2470 = $$2400;$$ph2471 = $$2401;
   continue;
  }
 }
 $405 = Math_fround(-$$ph2439);
 $406 = Math_fround(-$$ph2438);
 $407 = Math_fround(-$$ph2437);
 $408 = Math_fround(-$175);
 $409 = Math_fround(-$177);
 $410 = Math_fround(-$179);
 $411 = Math_fround(-$181);
 $412 = Math_fround(-$183);
 $413 = Math_fround(-$185);
 $414 = Math_fround($174 * $405);
 $415 = Math_fround($176 * $406);
 $416 = Math_fround($415 + $414);
 $417 = Math_fround($178 * $407);
 $418 = Math_fround($417 + $416);
 $419 = Math_fround($180 * $405);
 $420 = Math_fround($182 * $406);
 $421 = Math_fround($420 + $419);
 $422 = Math_fround($184 * $407);
 $423 = Math_fround($422 + $421);
 $424 = Math_fround($174 * $408);
 $425 = Math_fround($176 * $409);
 $426 = Math_fround($425 + $424);
 $427 = Math_fround($178 * $410);
 $428 = Math_fround($427 + $426);
 $429 = Math_fround($180 * $408);
 $430 = Math_fround($182 * $409);
 $431 = Math_fround($430 + $429);
 $432 = Math_fround($184 * $410);
 $433 = Math_fround($432 + $431);
 $434 = Math_fround($174 * $411);
 $435 = Math_fround($176 * $412);
 $436 = Math_fround($435 + $434);
 $437 = Math_fround($178 * $413);
 $438 = Math_fround($437 + $436);
 $439 = Math_fround($180 * $411);
 $440 = Math_fround($182 * $412);
 $441 = Math_fround($440 + $439);
 $442 = Math_fround($184 * $413);
 $443 = Math_fround($442 + $441);
 $444 = Math_fround($428 * $443);
 $445 = Math_fround($438 * $433);
 $446 = Math_fround($444 - $445);
 $447 = Math_fround($438 * $423);
 $448 = Math_fround($418 * $443);
 $449 = Math_fround($447 - $448);
 $450 = Math_fround($418 * $433);
 $451 = Math_fround($428 * $423);
 $452 = Math_fround($450 - $451);
 $453 = Math_fround($449 + $452);
 $454 = Math_fround($446 + $453);
 $455 = Math_fround(Math_fround(1.0) / $454);
 $456 = Math_fround($240 - $$ph2451);
 $457 = Math_fround($242 - $$ph2450);
 $458 = Math_fround($244 - $$ph2449);
 $459 = Math_fround($300 - $$ph2451);
 $460 = Math_fround($302 - $$ph2450);
 $461 = Math_fround($304 - $$ph2449);
 $462 = Math_fround($249 - $$ph2463);
 $463 = Math_fround($251 - $$ph2462);
 $464 = Math_fround($253 - $$ph2461);
 $465 = Math_fround($309 - $$ph2463);
 $466 = Math_fround($311 - $$ph2462);
 $467 = Math_fround($313 - $$ph2461);
 $468 = Math_fround($449 * $455);
 $469 = Math_fround($452 * $455);
 $470 = Math_fround($459 * $469);
 $471 = Math_fround($460 * $469);
 $472 = Math_fround($461 * $469);
 $473 = Math_fround($465 * $469);
 $474 = Math_fround($466 * $469);
 $475 = Math_fround($467 * $469);
 $476 = Math_fround($456 * $468);
 $477 = Math_fround($457 * $468);
 $478 = Math_fround($458 * $468);
 $479 = Math_fround($476 + $470);
 $480 = Math_fround($477 + $471);
 $481 = Math_fround($478 + $472);
 $482 = Math_fround($$ph2451 + $479);
 $483 = Math_fround($$ph2450 + $480);
 $484 = Math_fround($$ph2449 + $481);
 $485 = Math_fround($462 * $468);
 $486 = Math_fround($463 * $468);
 $487 = Math_fround($464 * $468);
 $488 = Math_fround($485 + $473);
 $489 = Math_fround($486 + $474);
 $490 = Math_fround($487 + $475);
 $491 = Math_fround($$ph2463 + $488);
 $492 = Math_fround($$ph2462 + $489);
 $493 = Math_fround($$ph2461 + $490);
 HEAPF32[$closestA>>2] = $482;
 $494 = (($closestA) + 4|0);
 HEAPF32[$494>>2] = $483;
 $495 = (($closestA) + 8|0);
 HEAPF32[$495>>2] = $484;
 $496 = (($closestA) + 12|0);
 HEAPF32[$496>>2] = Math_fround(0.0);
 HEAPF32[$closestB>>2] = $491;
 $497 = (($closestB) + 4|0);
 HEAPF32[$497>>2] = $492;
 $498 = (($closestB) + 8|0);
 HEAPF32[$498>>2] = $493;
 $499 = (($closestB) + 12|0);
 HEAPF32[$499>>2] = Math_fround(0.0);
 $500 = Math_fround($482 - $491);
 $501 = Math_fround($483 - $492);
 $502 = Math_fround($484 - $493);
 HEAPF32[$agg$result>>2] = $500;
 $503 = (($agg$result) + 4|0);
 HEAPF32[$503>>2] = $501;
 $504 = (($agg$result) + 8|0);
 HEAPF32[$504>>2] = $502;
 $505 = (($agg$result) + 12|0);
 HEAPF32[$505>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu36closestPtPointTetrahedronTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($agg$result,$Q,$A,$B,$size,$closestA,$closestB) {
 $agg$result = $agg$result|0;
 $Q = $Q|0;
 $A = $A|0;
 $B = $B|0;
 $size = $size|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 var $$$i = Math_fround(0), $$$i59 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $_A = 0, $_B = 0, $_Q = 0, $_size = 0, $_size11 = 0, $_size3 = 0, $_size6 = 0, $a = 0, $b = 0;
 var $bIsOutside4 = 0, $c = 0, $d = 0, $indices$sroa$0$0 = 0, $indices$sroa$0$1 = 0, $indices$sroa$0$2 = 0, $indices$sroa$0$3 = 0, $indices$sroa$1$0 = 0, $indices$sroa$1$1 = 0, $indices$sroa$1$2 = 0, $indices$sroa$1$3 = 0, $indices$sroa$2$0 = 0, $indices$sroa$2$1 = 0, $indices$sroa$2$2 = 0, $indices$sroa$2$3 = 0, $q = 0, $q12 = 0, $q7 = 0, $tempClosestA = 0, $tempClosestB = 0;
 var $tempIndices = 0, $tempIndices1 = 0, $tempIndices10 = 0, $tempIndices2 = 0, $tempIndices5 = 0, $tempSize$0 = 0, $tempSize$1 = 0, $tempSize$2 = 0, $tempSize$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $a = sp + 240|0;
 $b = sp + 320|0;
 $c = sp + 352|0;
 $d = sp + 336|0;
 $tempIndices = sp + 432|0;
 $_Q = sp + 176|0;
 $_A = sp + 96|0;
 $_B = sp + 32|0;
 $bIsOutside4 = sp + 16|0;
 $tempClosestA = sp;
 $tempClosestB = sp + 160|0;
 $tempIndices1 = sp + 400|0;
 $_size = sp + 428|0;
 $0 = sp + 256|0;
 $tempIndices2 = sp + 416|0;
 $_size3 = sp + 412|0;
 $q = sp + 272|0;
 $tempIndices5 = sp + 384|0;
 $_size6 = sp + 396|0;
 $q7 = sp + 288|0;
 $tempIndices10 = sp + 368|0;
 $_size11 = sp + 380|0;
 $q12 = sp + 304|0;
 $1 = HEAP32[$size>>2]|0;
 ;HEAP32[$a+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$a+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$a+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$a+12>>2]=HEAP32[$Q+12>>2]|0;
 $2 = (($Q) + 16|0);
 ;HEAP32[$b+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$b+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$b+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$b+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($Q) + 32|0);
 ;HEAP32[$c+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$c+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$c+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$c+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (($Q) + 48|0);
 ;HEAP32[$d+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$d+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$d+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$d+12>>2]=HEAP32[$4+12>>2]|0;
 $5 = Math_fround(HEAPF32[$d>>2]);
 $6 = (($d) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($d) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$a>>2]);
 $11 = (($a) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($a) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($5 - $10);
 $16 = Math_fround($7 - $12);
 $17 = Math_fround($9 - $14);
 $18 = Math_fround(HEAPF32[$b>>2]);
 $19 = (($b) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($b) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($5 - $18);
 $24 = Math_fround($7 - $20);
 $25 = Math_fround($9 - $22);
 $26 = Math_fround(HEAPF32[$c>>2]);
 $27 = (($c) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($c) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($5 - $26);
 $32 = Math_fround($7 - $28);
 $33 = Math_fround($9 - $30);
 $34 = Math_fround($15 * $15);
 $35 = Math_fround($16 * $16);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($17 * $17);
 $38 = Math_fround($36 + $37);
 $39 = Math_fround($23 * $23);
 $40 = Math_fround($24 * $24);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($25 * $25);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($31 * $31);
 $45 = Math_fround($32 * $32);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($33 * $33);
 $48 = Math_fround($46 + $47);
 $49 = $43 > $48;
 $$$i59 = $49 ? $48 : $43;
 $50 = $38 > $$$i59;
 $$$i = $50 ? $$$i59 : $38;
 $51 = $$$i < Math_fround(1.1920928955078125E-7);
 if ($51) {
  HEAP32[$size>>2] = 3;
  ;HEAP32[$tempIndices+0>>2]=HEAP32[551072+0>>2]|0;HEAP32[$tempIndices+4>>2]=HEAP32[551072+4>>2]|0;HEAP32[$tempIndices+8>>2]=HEAP32[551072+8>>2]|0;
  __ZN5physx2Gu33closestPtPointTriangleTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_PjRjRS3_S7_($agg$result,$Q,$A,$B,$tempIndices,$size,$closestA,$closestB);
  STACKTOP = sp;return;
 }
 ;HEAP32[$_Q+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$_Q+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$_Q+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$_Q+12>>2]=HEAP32[$Q+12>>2]|0;
 $52 = (($_Q) + 16|0);
 ;HEAP32[$52+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$52+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$52+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$52+12>>2]=HEAP32[$2+12>>2]|0;
 $53 = (($_Q) + 32|0);
 ;HEAP32[$53+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$53+12>>2]=HEAP32[$3+12>>2]|0;
 $54 = (($_Q) + 48|0);
 ;HEAP32[$54+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$4+12>>2]|0;
 ;HEAP32[$_A+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$_A+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$_A+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$_A+12>>2]=HEAP32[$A+12>>2]|0;
 $55 = (($_A) + 16|0);
 $56 = (($A) + 16|0);
 ;HEAP32[$55+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$56+12>>2]|0;
 $57 = (($_A) + 32|0);
 $58 = (($A) + 32|0);
 ;HEAP32[$57+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$58+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$58+12>>2]|0;
 $59 = (($_A) + 48|0);
 $60 = (($A) + 48|0);
 ;HEAP32[$59+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$59+12>>2]=HEAP32[$60+12>>2]|0;
 ;HEAP32[$_B+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$_B+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$_B+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$_B+12>>2]=HEAP32[$B+12>>2]|0;
 $61 = (($_B) + 16|0);
 $62 = (($B) + 16|0);
 ;HEAP32[$61+0>>2]=HEAP32[$62+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$62+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$62+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$62+12>>2]|0;
 $63 = (($_B) + 32|0);
 $64 = (($B) + 32|0);
 ;HEAP32[$63+0>>2]=HEAP32[$64+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$64+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$64+8>>2]|0;HEAP32[$63+12>>2]=HEAP32[$64+12>>2]|0;
 $65 = (($_B) + 48|0);
 $66 = (($B) + 48|0);
 ;HEAP32[$65+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$66+12>>2]|0;
 __ZN5physx2Gu20PointOutsideOfPlane4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_($bIsOutside4,$a,$b,$c,$d);
 $67 = HEAP32[$bIsOutside4>>2]|0;
 $68 = (($bIsOutside4) + 4|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($bIsOutside4) + 8|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($bIsOutside4) + 12|0);
 $73 = $69 | $67;
 $74 = $73 | $71;
 $75 = ($74|0)==(0);
 if ($75) {
  $76 = HEAP32[$72>>2]|0;
  $77 = ($76|0)==(0);
  if ($77) {
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
   STACKTOP = sp;return;
  }
 }
 $78 = ($67|0)==(-1);
 if ($78) {
  ;HEAP32[$tempIndices1+0>>2]=HEAP32[551072+0>>2]|0;HEAP32[$tempIndices1+4>>2]=HEAP32[551072+4>>2]|0;HEAP32[$tempIndices1+8>>2]=HEAP32[551072+8>>2]|0;
  HEAP32[$_size>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_PjRjRS3_S7_($0,$_Q,$_A,$_B,$tempIndices1,$_size,$tempClosestA,$tempClosestB);
  $79 = Math_fround(HEAPF32[$0>>2]);
  $80 = (($0) + 4|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($0) + 8|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($0) + 12|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($79 * $79);
  $87 = Math_fround($81 * $81);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround($83 * $83);
  $90 = Math_fround($88 + $89);
  $91 = HEAP32[$tempIndices1>>2]|0;
  $92 = (($tempIndices1) + 4|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (($tempIndices1) + 8|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = HEAP32[$_size>>2]|0;
  ;HEAP32[$closestA+0>>2]=HEAP32[$tempClosestA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$tempClosestA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$tempClosestA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$tempClosestA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$tempClosestB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$tempClosestB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$tempClosestB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$tempClosestB+12>>2]|0;
  $109 = $90;$177 = $85;$178 = $83;$179 = $81;$180 = $79;$indices$sroa$0$0 = $91;$indices$sroa$1$0 = $93;$indices$sroa$2$0 = $95;$tempSize$0 = $96;
 } else {
  $109 = Math_fround(3.40282346638528859812E+38);$177 = Math_fround(0.0);$178 = Math_fround(0.0);$179 = Math_fround(0.0);$180 = Math_fround(0.0);$indices$sroa$0$0 = 0;$indices$sroa$1$0 = 1;$indices$sroa$2$0 = 2;$tempSize$0 = $1;
 }
 $97 = ($69|0)==(-1);
 if ($97) {
  ;HEAP32[$tempIndices2+0>>2]=HEAP32[551088+0>>2]|0;HEAP32[$tempIndices2+4>>2]=HEAP32[551088+4>>2]|0;HEAP32[$tempIndices2+8>>2]=HEAP32[551088+8>>2]|0;
  HEAP32[$_size3>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_PjRjRS3_S7_($q,$_Q,$_A,$_B,$tempIndices2,$_size3,$tempClosestA,$tempClosestB);
  $98 = Math_fround(HEAPF32[$q>>2]);
  $99 = (($q) + 4|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($q) + 8|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($98 * $98);
  $104 = Math_fround($100 * $100);
  $105 = Math_fround($103 + $104);
  $106 = Math_fround($102 * $102);
  $107 = Math_fround($105 + $106);
  $108 = $109 > $107;
  if ($108) {
   $110 = (($q) + 12|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = HEAP32[$tempIndices2>>2]|0;
   $113 = (($tempIndices2) + 4|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = (($tempIndices2) + 8|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = HEAP32[$_size3>>2]|0;
   ;HEAP32[$closestA+0>>2]=HEAP32[$tempClosestA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$tempClosestA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$tempClosestA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$tempClosestA+12>>2]|0;
   ;HEAP32[$closestB+0>>2]=HEAP32[$tempClosestB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$tempClosestB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$tempClosestB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$tempClosestB+12>>2]|0;
   $130 = $107;$181 = $111;$182 = $102;$183 = $100;$184 = $98;$indices$sroa$0$1 = $112;$indices$sroa$1$1 = $114;$indices$sroa$2$1 = $116;$tempSize$1 = $117;
  } else {
   $130 = $109;$181 = $177;$182 = $178;$183 = $179;$184 = $180;$indices$sroa$0$1 = $indices$sroa$0$0;$indices$sroa$1$1 = $indices$sroa$1$0;$indices$sroa$2$1 = $indices$sroa$2$0;$tempSize$1 = $tempSize$0;
  }
 } else {
  $130 = $109;$181 = $177;$182 = $178;$183 = $179;$184 = $180;$indices$sroa$0$1 = $indices$sroa$0$0;$indices$sroa$1$1 = $indices$sroa$1$0;$indices$sroa$2$1 = $indices$sroa$2$0;$tempSize$1 = $tempSize$0;
 }
 $118 = ($71|0)==(-1);
 if ($118) {
  ;HEAP32[$tempIndices5+0>>2]=HEAP32[551104+0>>2]|0;HEAP32[$tempIndices5+4>>2]=HEAP32[551104+4>>2]|0;HEAP32[$tempIndices5+8>>2]=HEAP32[551104+8>>2]|0;
  HEAP32[$_size6>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_PjRjRS3_S7_($q7,$_Q,$_A,$_B,$tempIndices5,$_size6,$tempClosestA,$tempClosestB);
  $119 = Math_fround(HEAPF32[$q7>>2]);
  $120 = (($q7) + 4|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = (($q7) + 8|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = Math_fround($119 * $119);
  $125 = Math_fround($121 * $121);
  $126 = Math_fround($124 + $125);
  $127 = Math_fround($123 * $123);
  $128 = Math_fround($126 + $127);
  $129 = $130 > $128;
  if ($129) {
   $131 = (($q7) + 12|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = HEAP32[$tempIndices5>>2]|0;
   $134 = (($tempIndices5) + 4|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = (($tempIndices5) + 8|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = HEAP32[$_size6>>2]|0;
   ;HEAP32[$closestA+0>>2]=HEAP32[$tempClosestA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$tempClosestA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$tempClosestA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$tempClosestA+12>>2]|0;
   ;HEAP32[$closestB+0>>2]=HEAP32[$tempClosestB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$tempClosestB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$tempClosestB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$tempClosestB+12>>2]|0;
   $152 = $128;$185 = $132;$186 = $123;$187 = $121;$188 = $119;$indices$sroa$0$2 = $133;$indices$sroa$1$2 = $135;$indices$sroa$2$2 = $137;$tempSize$2 = $138;
  } else {
   $152 = $130;$185 = $181;$186 = $182;$187 = $183;$188 = $184;$indices$sroa$0$2 = $indices$sroa$0$1;$indices$sroa$1$2 = $indices$sroa$1$1;$indices$sroa$2$2 = $indices$sroa$2$1;$tempSize$2 = $tempSize$1;
  }
 } else {
  $152 = $130;$185 = $181;$186 = $182;$187 = $183;$188 = $184;$indices$sroa$0$2 = $indices$sroa$0$1;$indices$sroa$1$2 = $indices$sroa$1$1;$indices$sroa$2$2 = $indices$sroa$2$1;$tempSize$2 = $tempSize$1;
 }
 $139 = HEAP32[$72>>2]|0;
 $140 = ($139|0)==(-1);
 if ($140) {
  ;HEAP32[$tempIndices10+0>>2]=HEAP32[551120+0>>2]|0;HEAP32[$tempIndices10+4>>2]=HEAP32[551120+4>>2]|0;HEAP32[$tempIndices10+8>>2]=HEAP32[551120+8>>2]|0;
  HEAP32[$_size11>>2] = 3;
  __ZN5physx2Gu33closestPtPointTriangleTesselationEPNS_6shdfnd3aos5Vec3VES4_S4_PjRjRS3_S7_($q12,$_Q,$_A,$_B,$tempIndices10,$_size11,$tempClosestA,$tempClosestB);
  $141 = Math_fround(HEAPF32[$q12>>2]);
  $142 = (($q12) + 4|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = (($q12) + 8|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = Math_fround($141 * $141);
  $147 = Math_fround($143 * $143);
  $148 = Math_fround($146 + $147);
  $149 = Math_fround($145 * $145);
  $150 = Math_fround($148 + $149);
  $151 = $152 > $150;
  if ($151) {
   $153 = (($q12) + 12|0);
   $154 = Math_fround(HEAPF32[$153>>2]);
   $155 = HEAP32[$tempIndices10>>2]|0;
   $156 = (($tempIndices10) + 4|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($tempIndices10) + 8|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = HEAP32[$_size11>>2]|0;
   ;HEAP32[$closestA+0>>2]=HEAP32[$tempClosestA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$tempClosestA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$tempClosestA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$tempClosestA+12>>2]|0;
   ;HEAP32[$closestB+0>>2]=HEAP32[$tempClosestB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$tempClosestB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$tempClosestB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$tempClosestB+12>>2]|0;
   $170 = $141;$172 = $143;$174 = $145;$176 = $154;$indices$sroa$0$3 = $155;$indices$sroa$1$3 = $157;$indices$sroa$2$3 = $159;$tempSize$3 = $160;
  } else {
   $170 = $188;$172 = $187;$174 = $186;$176 = $185;$indices$sroa$0$3 = $indices$sroa$0$2;$indices$sroa$1$3 = $indices$sroa$1$2;$indices$sroa$2$3 = $indices$sroa$2$2;$tempSize$3 = $tempSize$2;
  }
 } else {
  $170 = $188;$172 = $187;$174 = $186;$176 = $185;$indices$sroa$0$3 = $indices$sroa$0$2;$indices$sroa$1$3 = $indices$sroa$1$2;$indices$sroa$2$3 = $indices$sroa$2$2;$tempSize$3 = $tempSize$2;
 }
 $161 = (($_A) + ($indices$sroa$0$3<<4)|0);
 ;HEAP32[$A+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$A+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$A+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$A+12>>2]=HEAP32[$161+12>>2]|0;
 $162 = (($_A) + ($indices$sroa$1$3<<4)|0);
 ;HEAP32[$56+0>>2]=HEAP32[$162+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$162+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$162+8>>2]|0;HEAP32[$56+12>>2]=HEAP32[$162+12>>2]|0;
 $163 = (($_A) + ($indices$sroa$2$3<<4)|0);
 ;HEAP32[$58+0>>2]=HEAP32[$163+0>>2]|0;HEAP32[$58+4>>2]=HEAP32[$163+4>>2]|0;HEAP32[$58+8>>2]=HEAP32[$163+8>>2]|0;HEAP32[$58+12>>2]=HEAP32[$163+12>>2]|0;
 $164 = (($_B) + ($indices$sroa$0$3<<4)|0);
 ;HEAP32[$B+0>>2]=HEAP32[$164+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$164+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$164+12>>2]|0;
 $165 = (($_B) + ($indices$sroa$1$3<<4)|0);
 ;HEAP32[$62+0>>2]=HEAP32[$165+0>>2]|0;HEAP32[$62+4>>2]=HEAP32[$165+4>>2]|0;HEAP32[$62+8>>2]=HEAP32[$165+8>>2]|0;HEAP32[$62+12>>2]=HEAP32[$165+12>>2]|0;
 $166 = (($_B) + ($indices$sroa$2$3<<4)|0);
 ;HEAP32[$64+0>>2]=HEAP32[$166+0>>2]|0;HEAP32[$64+4>>2]=HEAP32[$166+4>>2]|0;HEAP32[$64+8>>2]=HEAP32[$166+8>>2]|0;HEAP32[$64+12>>2]=HEAP32[$166+12>>2]|0;
 $167 = (($_Q) + ($indices$sroa$0$3<<4)|0);
 ;HEAP32[$Q+0>>2]=HEAP32[$167+0>>2]|0;HEAP32[$Q+4>>2]=HEAP32[$167+4>>2]|0;HEAP32[$Q+8>>2]=HEAP32[$167+8>>2]|0;HEAP32[$Q+12>>2]=HEAP32[$167+12>>2]|0;
 $168 = (($_Q) + ($indices$sroa$1$3<<4)|0);
 ;HEAP32[$2+0>>2]=HEAP32[$168+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$168+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$168+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$168+12>>2]|0;
 $169 = (($_Q) + ($indices$sroa$2$3<<4)|0);
 ;HEAP32[$3+0>>2]=HEAP32[$169+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$169+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$169+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$169+12>>2]|0;
 HEAP32[$size>>2] = $tempSize$3;
 HEAPF32[$agg$result>>2] = $170;
 $171 = (($agg$result) + 4|0);
 HEAPF32[$171>>2] = $172;
 $173 = (($agg$result) + 8|0);
 HEAPF32[$173>>2] = $174;
 $175 = (($agg$result) + 12|0);
 HEAPF32[$175>>2] = $176;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11GJKRelativeERKNS0_8CapsuleVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERNS8_5Vec3VESD_SD_RNS8_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu11gjkRelativeINS0_8CapsuleVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERNSB_5Vec3VESG_SG_RNSB_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu11gjkRelativeINS0_8CapsuleVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERNSB_5Vec3VESG_SG_RNSB_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i29 = 0, $$in1$i94 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i31 = 0, $$in2$i96 = 0, $$not = 0, $$not402 = 0, $$sroa$1110 = 0, $$sroa$1148 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0);
 var $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0);
 var $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0);
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0;
 var $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0);
 var $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0);
 var $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0);
 var $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $b$a$i$i$i = 0;
 var $b$a$i18 = 0, $b$a$i26 = 0, $b$a$i91 = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closB = 0, $closBB = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportB = 0, $tempV = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp;
 $1 = sp + 336|0;
 $2 = sp + 320|0;
 $3 = sp + 288|0;
 $4 = sp + 304|0;
 $5 = sp + 448|0;
 $6 = sp + 352|0;
 $7 = sp + 368|0;
 $Q = sp + 384|0;
 $A = sp + 224|0;
 $B = sp + 64|0;
 $zeroV = sp + 208|0;
 $size = sp + 500|0;
 $v = sp + 16|0;
 $closA = sp + 32|0;
 $closB = sp + 48|0;
 $sDist$sroa$1 = sp + 476|0;
 $closAA = sp + 128|0;
 $closBB = sp + 144|0;
 $supportB = sp + 160|0;
 $support = sp + 176|0;
 $tempV = sp + 192|0;
 $$sroa$1148 = sp + 464|0;
 $$sroa$1110 = sp + 488|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAP32[$size>>2] = 0;
 $8 = (($aToB) + 48|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($aToB) + 52|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($aToB) + 56|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($aToB) + 60|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($9 * $9);
 $17 = Math_fround($11 * $11);
 $18 = Math_fround($16 + $17);
 $19 = Math_fround($13 * $13);
 $20 = Math_fround($18 + $19);
 $21 = $20 > Math_fround(0.0);
 HEAPF32[$1>>2] = $9;
 $22 = (($1) + 4|0);
 HEAPF32[$22>>2] = $11;
 $23 = (($1) + 8|0);
 HEAPF32[$23>>2] = $13;
 $24 = (($1) + 12|0);
 HEAPF32[$24>>2] = $15;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $25 = (($0) + 4|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($0) + 8|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($0) + 12|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $b$a$i91 = $21 ? $1 : $0;
 $28 = Math_fround(HEAPF32[$b$a$i91>>2]);
 $$in1$i94 = (($b$a$i91) + 4|0);
 $29 = Math_fround(HEAPF32[$$in1$i94>>2]);
 $$in2$i96 = (($b$a$i91) + 8|0);
 $30 = Math_fround(HEAPF32[$$in2$i96>>2]);
 HEAPF32[$v>>2] = $28;
 $31 = (($v) + 4|0);
 HEAPF32[$31>>2] = $29;
 $32 = (($v) + 8|0);
 HEAPF32[$32>>2] = $30;
 $33 = (($v) + 12|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($a) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($b) + 32|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = $35 > $37;
 $$$i = $38 ? $37 : $35;
 $39 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $40 = Math_fround($39 * $39);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $41 = (($aToB) + 4|0);
 $42 = (($aToB) + 8|0);
 $43 = (($aToB) + 16|0);
 $44 = (($aToB) + 20|0);
 $45 = (($aToB) + 24|0);
 $46 = (($aToB) + 32|0);
 $47 = (($aToB) + 36|0);
 $48 = (($aToB) + 40|0);
 $49 = (($a) + 96|0);
 $50 = (($a) + 96|0);
 $51 = (($a) + 100|0);
 $52 = (($a) + 104|0);
 $53 = (($a) + 112|0);
 $54 = (($a) + 112|0);
 $55 = (($a) + 116|0);
 $56 = (($a) + 120|0);
 $57 = (($supportB) + 4|0);
 $58 = (($supportB) + 8|0);
 $59 = (($support) + 4|0);
 $60 = (($support) + 8|0);
 $61 = (($support) + 12|0);
 $62 = (($closA) + 4|0);
 $63 = (($closA) + 8|0);
 $64 = (($closA) + 12|0);
 $65 = (($Q) + 4|0);
 $66 = (($Q) + 8|0);
 $67 = (($A) + 4|0);
 $68 = (($A) + 8|0);
 $69 = (($B) + 4|0);
 $70 = (($B) + 8|0);
 $71 = (($closB) + 4|0);
 $72 = (($closB) + 8|0);
 $73 = (($closB) + 12|0);
 $74 = (($tempV) + 4|0);
 $75 = (($tempV) + 8|0);
 $76 = (($tempV) + 12|0);
 $77 = (($Q) + 16|0);
 $164 = Math_fround(3.40282346638528859812E+38);$79 = $28;$81 = $29;$83 = $30;
 while(1) {
  ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closBB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closBB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closBB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closBB+12>>2]=HEAP32[$closB+12>>2]|0;
  $78 = Math_fround(-$79);
  $80 = Math_fround(-$81);
  $82 = Math_fround(-$83);
  $84 = Math_fround(HEAPF32[$aToB>>2]);
  $85 = Math_fround($84 * $78);
  $86 = Math_fround(HEAPF32[$41>>2]);
  $87 = Math_fround($86 * $80);
  $88 = Math_fround($85 + $87);
  $89 = Math_fround(HEAPF32[$42>>2]);
  $90 = Math_fround($89 * $82);
  $91 = Math_fround($88 + $90);
  $92 = Math_fround(HEAPF32[$43>>2]);
  $93 = Math_fround($92 * $78);
  $94 = Math_fround(HEAPF32[$44>>2]);
  $95 = Math_fround($94 * $80);
  $96 = Math_fround($93 + $95);
  $97 = Math_fround(HEAPF32[$45>>2]);
  $98 = Math_fround($97 * $82);
  $99 = Math_fround($96 + $98);
  $100 = Math_fround(HEAPF32[$46>>2]);
  $101 = Math_fround($100 * $78);
  $102 = Math_fround(HEAPF32[$47>>2]);
  $103 = Math_fround($102 * $80);
  $104 = Math_fround($101 + $103);
  $105 = Math_fround(HEAPF32[$48>>2]);
  $106 = Math_fround($105 * $82);
  $107 = Math_fround($104 + $106);
  $108 = Math_fround(HEAPF32[$50>>2]);
  $109 = Math_fround(HEAPF32[$51>>2]);
  $110 = Math_fround(HEAPF32[$52>>2]);
  $111 = Math_fround($91 * $108);
  $112 = Math_fround($99 * $109);
  $113 = Math_fround($111 + $112);
  $114 = Math_fround($107 * $110);
  $115 = Math_fround($113 + $114);
  $116 = Math_fround(HEAPF32[$54>>2]);
  $117 = Math_fround(HEAPF32[$55>>2]);
  $118 = Math_fround(HEAPF32[$56>>2]);
  $119 = Math_fround($91 * $116);
  $120 = Math_fround($99 * $117);
  $121 = Math_fround($119 + $120);
  $122 = Math_fround($107 * $118);
  $123 = Math_fround($121 + $122);
  $124 = $115 > $123;
  ;HEAP32[$3+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$49+12>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$53+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$53+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$53+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$53+12>>2]|0;
  $b$a$i$i$i = $124 ? $3 : $2;
  $125 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
  $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
  $126 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
  $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
  $127 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
  $128 = Math_fround(HEAPF32[$8>>2]);
  $129 = Math_fround(HEAPF32[$10>>2]);
  $130 = Math_fround(HEAPF32[$12>>2]);
  $131 = Math_fround($84 * $125);
  $132 = Math_fround($92 * $126);
  $133 = Math_fround($131 + $132);
  $134 = Math_fround($100 * $127);
  $135 = Math_fround($133 + $134);
  $136 = Math_fround($86 * $125);
  $137 = Math_fround($94 * $126);
  $138 = Math_fround($136 + $137);
  $139 = Math_fround($102 * $127);
  $140 = Math_fround($138 + $139);
  $141 = Math_fround($89 * $125);
  $142 = Math_fround($97 * $126);
  $143 = Math_fround($141 + $142);
  $144 = Math_fround($105 * $127);
  $145 = Math_fround($143 + $144);
  $146 = Math_fround($135 + $128);
  $147 = Math_fround($140 + $129);
  $148 = Math_fround($145 + $130);
  __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($supportB,$b,$v);
  $149 = Math_fround(HEAPF32[$supportB>>2]);
  $150 = Math_fround(HEAPF32[$57>>2]);
  $151 = Math_fround(HEAPF32[$58>>2]);
  $152 = Math_fround($146 - $149);
  $153 = Math_fround($147 - $150);
  $154 = Math_fround($148 - $151);
  HEAPF32[$support>>2] = $152;
  HEAPF32[$59>>2] = $153;
  HEAPF32[$60>>2] = $154;
  HEAPF32[$61>>2] = Math_fround(0.0);
  $155 = Math_fround(HEAPF32[$v>>2]);
  $156 = Math_fround(HEAPF32[$31>>2]);
  $157 = Math_fround(HEAPF32[$32>>2]);
  $158 = Math_fround($155 * $152);
  $159 = Math_fround($156 * $153);
  $160 = Math_fround($158 + $159);
  $161 = Math_fround($157 * $154);
  $162 = Math_fround($160 + $161);
  $163 = Math_fround($164 - $162);
  $165 = HEAP32[$size>>2]|0;
  $166 = (($A) + ($165<<4)|0);
  HEAPF32[$166>>2] = $146;
  $167 = ((($A) + ($165<<4)|0) + 4|0);
  HEAPF32[$167>>2] = $147;
  $168 = ((($A) + ($165<<4)|0) + 8|0);
  HEAPF32[$168>>2] = $148;
  $169 = ((($A) + ($165<<4)|0) + 12|0);
  HEAPF32[$169>>2] = Math_fround(0.0);
  $170 = (($B) + ($165<<4)|0);
  ;HEAP32[$170+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$170+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$170+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$170+12>>2]=HEAP32[$supportB+12>>2]|0;
  $171 = (($165) + 1)|0;
  HEAP32[$size>>2] = $171;
  $172 = (($Q) + ($165<<4)|0);
  ;HEAP32[$172+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$172+12>>2]=HEAP32[$support+12>>2]|0;
  $173 = Math_fround($164 * Math_fround(2.24999996135011315346E-4));
  $174 = $173 > $163;
  if ($174) {
   label = 3;
   break;
  }
  do {
   if ((($165|0) == 0)) {
    HEAPF32[$closA>>2] = $146;
    HEAPF32[$62>>2] = $147;
    HEAPF32[$63>>2] = $148;
    HEAPF32[$64>>2] = Math_fround(0.0);
    ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   } else if ((($165|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($165|0) == 1)) {
    $198 = Math_fround(HEAPF32[$Q>>2]);
    $199 = Math_fround(HEAPF32[$65>>2]);
    $200 = Math_fround(HEAPF32[$66>>2]);
    $201 = Math_fround($152 - $198);
    $202 = Math_fround($153 - $199);
    $203 = Math_fround($154 - $200);
    $204 = Math_fround($201 * $201);
    $205 = Math_fround($202 * $202);
    $206 = Math_fround($204 + $205);
    $207 = Math_fround($203 * $203);
    $208 = Math_fround($206 + $207);
    $209 = $208 == Math_fround(0.0);
    if ($209) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $210 = Math_fround($199 * $202);
     $211 = Math_fround(-$210);
     $212 = Math_fround($198 * $201);
     $213 = Math_fround($211 - $212);
     $214 = Math_fround($200 * $203);
     $215 = Math_fround($213 - $214);
     $216 = Math_fround(HEAPF32[$A>>2]);
     $217 = Math_fround(HEAPF32[$67>>2]);
     $218 = Math_fround(HEAPF32[$68>>2]);
     $219 = Math_fround($146 - $216);
     $220 = Math_fround($147 - $217);
     $221 = Math_fround($148 - $218);
     $222 = Math_fround(HEAPF32[$B>>2]);
     $223 = Math_fround(HEAPF32[$69>>2]);
     $224 = Math_fround(HEAPF32[$70>>2]);
     $225 = Math_fround($149 - $222);
     $226 = Math_fround($150 - $223);
     $227 = Math_fround($151 - $224);
     $228 = Math_fround($215 / $208);
     $229 = $228 > Math_fround(1.0);
     $$$i$i$i = $229 ? Math_fround(1.0) : $228;
     $230 = $$$i$i$i > Math_fround(0.0);
     $$$i8$i$i = $230 ? $$$i$i$i : Math_fround(0.0);
     $231 = Math_fround($219 * $$$i8$i$i);
     $232 = Math_fround($220 * $$$i8$i$i);
     $233 = Math_fround($221 * $$$i8$i$i);
     $234 = Math_fround($216 + $231);
     $235 = Math_fround($217 + $232);
     $236 = Math_fround($218 + $233);
     $237 = Math_fround($225 * $$$i8$i$i);
     $238 = Math_fround($226 * $$$i8$i$i);
     $239 = Math_fround($227 * $$$i8$i$i);
     $240 = Math_fround($222 + $237);
     $241 = Math_fround($223 + $238);
     $242 = Math_fround($224 + $239);
     HEAPF32[$closA>>2] = $234;
     HEAPF32[$62>>2] = $235;
     HEAPF32[$63>>2] = $236;
     HEAPF32[$64>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $240;
     HEAPF32[$71>>2] = $241;
     HEAPF32[$72>>2] = $242;
     HEAPF32[$73>>2] = Math_fround(0.0);
     $243 = Math_fround($234 - $240);
     $244 = Math_fround($235 - $241);
     $245 = Math_fround($236 - $242);
     HEAPF32[$tempV>>2] = $243;
     HEAPF32[$74>>2] = $244;
     HEAPF32[$75>>2] = $245;
     HEAPF32[$76>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($165|0) == 2)) {
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$77,$support,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$tempV+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$tempV+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$tempV+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$tempV+12>>2]|0;
  $246 = Math_fround(HEAPF32[$v>>2]);
  $247 = Math_fround(HEAPF32[$31>>2]);
  $248 = Math_fround(HEAPF32[$32>>2]);
  $249 = Math_fround($246 * $246);
  $250 = Math_fround($247 * $247);
  $251 = Math_fround($249 + $250);
  $252 = Math_fround($248 * $248);
  $253 = Math_fround($251 + $252);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1148+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1148+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1148+8>>2]|0;
  $254 = $164 > $253;
  $$not = !($253 > $40);
  $$not402 = $254 ^ 1;
  $brmerge = $$not | $$not402;
  if ($brmerge) {
   label = 13;
   break;
  } else {
   $164 = $253;$79 = $246;$81 = $247;$83 = $248;
  }
 }
 if ((label|0) == 3) {
  $175 = Math_fround(HEAPF32[$closB>>2]);
  $176 = Math_fround(HEAPF32[$71>>2]);
  $177 = Math_fround(HEAPF32[$72>>2]);
  $178 = Math_fround(HEAPF32[$closA>>2]);
  $179 = Math_fround(HEAPF32[$62>>2]);
  $180 = Math_fround(HEAPF32[$63>>2]);
  $181 = Math_fround($175 - $178);
  $182 = Math_fround($176 - $179);
  $183 = Math_fround($177 - $180);
  $184 = Math_fround($181 * $181);
  $185 = Math_fround($182 * $182);
  $186 = Math_fround($184 + $185);
  $187 = Math_fround($183 * $183);
  $188 = Math_fround($186 + $187);
  $189 = (Math_fround(Math_sqrt((Math_fround($188)))));
  $190 = Math_fround(Math_fround(1.0) / $189);
  $191 = Math_fround($181 * $190);
  $192 = Math_fround($182 * $190);
  $193 = Math_fround($183 * $190);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  HEAPF32[$sqDist>>2] = $164;
  $194 = (($sqDist) + 4|0);
  ;HEAP32[$194+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$194+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$194+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
  HEAPF32[$normal>>2] = $191;
  $195 = (($normal) + 4|0);
  HEAPF32[$195>>2] = $192;
  $196 = (($normal) + 8|0);
  HEAPF32[$196>>2] = $193;
  $197 = (($normal) + 12|0);
  HEAPF32[$197>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 13) {
  ;HEAP32[$5+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$closAA+12>>2]|0;
  $b$a$i26 = $254 ? $5 : $4;
  $255 = Math_fround(HEAPF32[$b$a$i26>>2]);
  $$in1$i29 = (($b$a$i26) + 4|0);
  $256 = Math_fround(HEAPF32[$$in1$i29>>2]);
  $$in2$i31 = (($b$a$i26) + 8|0);
  $257 = Math_fround(HEAPF32[$$in2$i31>>2]);
  HEAPF32[$closA>>2] = $255;
  HEAPF32[$62>>2] = $256;
  HEAPF32[$63>>2] = $257;
  HEAPF32[$64>>2] = Math_fround(0.0);
  ;HEAP32[$7+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closB+12>>2]|0;
  ;HEAP32[$6+0>>2]=HEAP32[$closBB+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$closBB+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$closBB+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$closBB+12>>2]|0;
  $b$a$i18 = $254 ? $7 : $6;
  $258 = Math_fround(HEAPF32[$b$a$i18>>2]);
  $$in1$i = (($b$a$i18) + 4|0);
  $259 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i18) + 8|0);
  $260 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$closB>>2] = $258;
  HEAPF32[$71>>2] = $259;
  HEAPF32[$72>>2] = $260;
  HEAPF32[$73>>2] = Math_fround(0.0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  $261 = Math_fround($258 - $255);
  $262 = Math_fround($259 - $256);
  $263 = Math_fround($260 - $257);
  $264 = Math_fround($261 * $261);
  $265 = Math_fround($262 * $262);
  $266 = Math_fround($264 + $265);
  $267 = Math_fround($263 * $263);
  $268 = Math_fround($266 + $267);
  $269 = (Math_fround(Math_sqrt((Math_fround($268)))));
  $270 = Math_fround(Math_fround(1.0) / $269);
  $271 = Math_fround($261 * $270);
  $272 = Math_fround($262 * $270);
  $273 = Math_fround($263 * $270);
  HEAPF32[$normal>>2] = $271;
  $274 = (($normal) + 4|0);
  HEAPF32[$274>>2] = $272;
  $275 = (($normal) + 8|0);
  HEAPF32[$275>>2] = $273;
  $276 = (($normal) + 12|0);
  HEAPF32[$276>>2] = Math_fround(0.0);
  $277 = $254 ? $253 : $164;
  HEAPF32[$sqDist>>2] = $277;
  $278 = (($sqDist) + 4|0);
  ;HEAP32[$278+0>>2]=HEAP32[$$sroa$1110+0>>2]|0;HEAP32[$278+4>>2]=HEAP32[$$sroa$1110+4>>2]|0;HEAP32[$278+8>>2]=HEAP32[$$sroa$1110+8>>2]|0;
  $279 = $254 ? 1 : 3;
  $$0 = $279;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu11gjkRelativeINS0_4BoxVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERNSB_5Vec3VESG_SG_RNSB_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i29 = 0, $$in1$i94 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i31 = 0, $$in2$i96 = 0, $$not = 0, $$not402 = 0, $$sroa$1110 = 0, $$sroa$1148 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0);
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0);
 var $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0);
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0);
 var $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0);
 var $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0;
 var $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0);
 var $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $a$pn3$i$i$i = 0, $b$a$i$i$i = 0, $b$a$i18 = 0, $b$a$i26 = 0, $b$a$i91 = 0, $b$a5$i$i$i = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closB = 0;
 var $closBB = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportB = 0, $tempV = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp;
 $1 = sp + 336|0;
 $2 = sp + 320|0;
 $3 = sp + 288|0;
 $4 = sp + 304|0;
 $5 = sp + 448|0;
 $6 = sp + 352|0;
 $7 = sp + 368|0;
 $Q = sp + 384|0;
 $A = sp + 224|0;
 $B = sp + 64|0;
 $zeroV = sp + 208|0;
 $size = sp + 500|0;
 $v = sp + 16|0;
 $closA = sp + 32|0;
 $closB = sp + 48|0;
 $sDist$sroa$1 = sp + 476|0;
 $closAA = sp + 128|0;
 $closBB = sp + 144|0;
 $supportB = sp + 160|0;
 $support = sp + 176|0;
 $tempV = sp + 192|0;
 $$sroa$1148 = sp + 464|0;
 $$sroa$1110 = sp + 488|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAP32[$size>>2] = 0;
 $8 = (($aToB) + 48|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($aToB) + 52|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($aToB) + 56|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($aToB) + 60|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($9 * $9);
 $17 = Math_fround($11 * $11);
 $18 = Math_fround($16 + $17);
 $19 = Math_fround($13 * $13);
 $20 = Math_fround($18 + $19);
 $21 = $20 > Math_fround(0.0);
 HEAPF32[$1>>2] = $9;
 $22 = (($1) + 4|0);
 HEAPF32[$22>>2] = $11;
 $23 = (($1) + 8|0);
 HEAPF32[$23>>2] = $13;
 $24 = (($1) + 12|0);
 HEAPF32[$24>>2] = $15;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $25 = (($0) + 4|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($0) + 8|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($0) + 12|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $b$a$i91 = $21 ? $1 : $0;
 $28 = Math_fround(HEAPF32[$b$a$i91>>2]);
 $$in1$i94 = (($b$a$i91) + 4|0);
 $29 = Math_fround(HEAPF32[$$in1$i94>>2]);
 $$in2$i96 = (($b$a$i91) + 8|0);
 $30 = Math_fround(HEAPF32[$$in2$i96>>2]);
 HEAPF32[$v>>2] = $28;
 $31 = (($v) + 4|0);
 HEAPF32[$31>>2] = $29;
 $32 = (($v) + 8|0);
 HEAPF32[$32>>2] = $30;
 $33 = (($v) + 12|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($a) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($b) + 32|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = $35 > $37;
 $$$i = $38 ? $37 : $35;
 $39 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $40 = Math_fround($39 * $39);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $41 = (($aToB) + 4|0);
 $42 = (($aToB) + 8|0);
 $43 = (($aToB) + 16|0);
 $44 = (($aToB) + 20|0);
 $45 = (($aToB) + 24|0);
 $46 = (($aToB) + 32|0);
 $47 = (($aToB) + 36|0);
 $48 = (($aToB) + 40|0);
 $49 = (($a) + 144|0);
 $50 = (($a) + 144|0);
 $51 = (($a) + 148|0);
 $52 = (($a) + 152|0);
 $53 = (($2) + 4|0);
 $54 = (($2) + 8|0);
 $55 = (($2) + 12|0);
 $56 = (($supportB) + 4|0);
 $57 = (($supportB) + 8|0);
 $58 = (($support) + 4|0);
 $59 = (($support) + 8|0);
 $60 = (($support) + 12|0);
 $61 = (($closA) + 4|0);
 $62 = (($closA) + 8|0);
 $63 = (($closA) + 12|0);
 $64 = (($Q) + 4|0);
 $65 = (($Q) + 8|0);
 $66 = (($A) + 4|0);
 $67 = (($A) + 8|0);
 $68 = (($B) + 4|0);
 $69 = (($B) + 8|0);
 $70 = (($closB) + 4|0);
 $71 = (($closB) + 8|0);
 $72 = (($closB) + 12|0);
 $73 = (($tempV) + 4|0);
 $74 = (($tempV) + 8|0);
 $75 = (($tempV) + 12|0);
 $76 = (($Q) + 16|0);
 $155 = Math_fround(3.40282346638528859812E+38);$78 = $28;$80 = $29;$82 = $30;
 while(1) {
  ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closBB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closBB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closBB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closBB+12>>2]=HEAP32[$closB+12>>2]|0;
  $77 = Math_fround(-$78);
  $79 = Math_fround(-$80);
  $81 = Math_fround(-$82);
  $83 = Math_fround(HEAPF32[$aToB>>2]);
  $84 = Math_fround($83 * $77);
  $85 = Math_fround(HEAPF32[$41>>2]);
  $86 = Math_fround($85 * $79);
  $87 = Math_fround($84 + $86);
  $88 = Math_fround(HEAPF32[$42>>2]);
  $89 = Math_fround($88 * $81);
  $90 = Math_fround($87 + $89);
  $91 = Math_fround(HEAPF32[$43>>2]);
  $92 = Math_fround($91 * $77);
  $93 = Math_fround(HEAPF32[$44>>2]);
  $94 = Math_fround($93 * $79);
  $95 = Math_fround($92 + $94);
  $96 = Math_fround(HEAPF32[$45>>2]);
  $97 = Math_fround($96 * $81);
  $98 = Math_fround($95 + $97);
  $99 = Math_fround(HEAPF32[$46>>2]);
  $100 = Math_fround($99 * $77);
  $101 = Math_fround(HEAPF32[$47>>2]);
  $102 = Math_fround($101 * $79);
  $103 = Math_fround($100 + $102);
  $104 = Math_fround(HEAPF32[$48>>2]);
  $105 = Math_fround($104 * $81);
  $106 = Math_fround($103 + $105);
  $107 = $90 > Math_fround(0.0);
  $108 = $98 > Math_fround(0.0);
  $109 = $106 > Math_fround(0.0);
  ;HEAP32[$3+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$49+12>>2]|0;
  $110 = Math_fround(HEAPF32[$50>>2]);
  $111 = Math_fround(HEAPF32[$51>>2]);
  $112 = Math_fround(HEAPF32[$52>>2]);
  $113 = Math_fround(-$110);
  $114 = Math_fround(-$111);
  $115 = Math_fround(-$112);
  HEAPF32[$2>>2] = $113;
  HEAPF32[$53>>2] = $114;
  HEAPF32[$54>>2] = $115;
  HEAPF32[$55>>2] = Math_fround(0.0);
  $b$a$i$i$i = $107 ? $3 : $2;
  $116 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
  $a$pn3$i$i$i = $108 ? $3 : $2;
  $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
  $117 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
  $b$a5$i$i$i = $109 ? $3 : $2;
  $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
  $118 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
  $119 = Math_fround(HEAPF32[$8>>2]);
  $120 = Math_fround(HEAPF32[$10>>2]);
  $121 = Math_fround(HEAPF32[$12>>2]);
  $122 = Math_fround($83 * $116);
  $123 = Math_fround($91 * $117);
  $124 = Math_fround($122 + $123);
  $125 = Math_fround($99 * $118);
  $126 = Math_fround($124 + $125);
  $127 = Math_fround($85 * $116);
  $128 = Math_fround($93 * $117);
  $129 = Math_fround($127 + $128);
  $130 = Math_fround($101 * $118);
  $131 = Math_fround($129 + $130);
  $132 = Math_fround($88 * $116);
  $133 = Math_fround($96 * $117);
  $134 = Math_fround($132 + $133);
  $135 = Math_fround($104 * $118);
  $136 = Math_fround($134 + $135);
  $137 = Math_fround($126 + $119);
  $138 = Math_fround($131 + $120);
  $139 = Math_fround($136 + $121);
  __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($supportB,$b,$v);
  $140 = Math_fround(HEAPF32[$supportB>>2]);
  $141 = Math_fround(HEAPF32[$56>>2]);
  $142 = Math_fround(HEAPF32[$57>>2]);
  $143 = Math_fround($137 - $140);
  $144 = Math_fround($138 - $141);
  $145 = Math_fround($139 - $142);
  HEAPF32[$support>>2] = $143;
  HEAPF32[$58>>2] = $144;
  HEAPF32[$59>>2] = $145;
  HEAPF32[$60>>2] = Math_fround(0.0);
  $146 = Math_fround(HEAPF32[$v>>2]);
  $147 = Math_fround(HEAPF32[$31>>2]);
  $148 = Math_fround(HEAPF32[$32>>2]);
  $149 = Math_fround($146 * $143);
  $150 = Math_fround($147 * $144);
  $151 = Math_fround($149 + $150);
  $152 = Math_fround($148 * $145);
  $153 = Math_fround($151 + $152);
  $154 = Math_fround($155 - $153);
  $156 = HEAP32[$size>>2]|0;
  $157 = (($A) + ($156<<4)|0);
  HEAPF32[$157>>2] = $137;
  $158 = ((($A) + ($156<<4)|0) + 4|0);
  HEAPF32[$158>>2] = $138;
  $159 = ((($A) + ($156<<4)|0) + 8|0);
  HEAPF32[$159>>2] = $139;
  $160 = ((($A) + ($156<<4)|0) + 12|0);
  HEAPF32[$160>>2] = Math_fround(0.0);
  $161 = (($B) + ($156<<4)|0);
  ;HEAP32[$161+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$supportB+12>>2]|0;
  $162 = (($156) + 1)|0;
  HEAP32[$size>>2] = $162;
  $163 = (($Q) + ($156<<4)|0);
  ;HEAP32[$163+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$163+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$support+12>>2]|0;
  $164 = Math_fround($155 * Math_fround(2.24999996135011315346E-4));
  $165 = $164 > $154;
  if ($165) {
   label = 3;
   break;
  }
  do {
   if ((($156|0) == 1)) {
    $189 = Math_fround(HEAPF32[$Q>>2]);
    $190 = Math_fround(HEAPF32[$64>>2]);
    $191 = Math_fround(HEAPF32[$65>>2]);
    $192 = Math_fround($143 - $189);
    $193 = Math_fround($144 - $190);
    $194 = Math_fround($145 - $191);
    $195 = Math_fround($192 * $192);
    $196 = Math_fround($193 * $193);
    $197 = Math_fround($195 + $196);
    $198 = Math_fround($194 * $194);
    $199 = Math_fround($197 + $198);
    $200 = $199 == Math_fround(0.0);
    if ($200) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $201 = Math_fround($190 * $193);
     $202 = Math_fround(-$201);
     $203 = Math_fround($189 * $192);
     $204 = Math_fround($202 - $203);
     $205 = Math_fround($191 * $194);
     $206 = Math_fround($204 - $205);
     $207 = Math_fround(HEAPF32[$A>>2]);
     $208 = Math_fround(HEAPF32[$66>>2]);
     $209 = Math_fround(HEAPF32[$67>>2]);
     $210 = Math_fround($137 - $207);
     $211 = Math_fround($138 - $208);
     $212 = Math_fround($139 - $209);
     $213 = Math_fround(HEAPF32[$B>>2]);
     $214 = Math_fround(HEAPF32[$68>>2]);
     $215 = Math_fround(HEAPF32[$69>>2]);
     $216 = Math_fround($140 - $213);
     $217 = Math_fround($141 - $214);
     $218 = Math_fround($142 - $215);
     $219 = Math_fround($206 / $199);
     $220 = $219 > Math_fround(1.0);
     $$$i$i$i = $220 ? Math_fround(1.0) : $219;
     $221 = $$$i$i$i > Math_fround(0.0);
     $$$i8$i$i = $221 ? $$$i$i$i : Math_fround(0.0);
     $222 = Math_fround($210 * $$$i8$i$i);
     $223 = Math_fround($211 * $$$i8$i$i);
     $224 = Math_fround($212 * $$$i8$i$i);
     $225 = Math_fround($207 + $222);
     $226 = Math_fround($208 + $223);
     $227 = Math_fround($209 + $224);
     $228 = Math_fround($216 * $$$i8$i$i);
     $229 = Math_fround($217 * $$$i8$i$i);
     $230 = Math_fround($218 * $$$i8$i$i);
     $231 = Math_fround($213 + $228);
     $232 = Math_fround($214 + $229);
     $233 = Math_fround($215 + $230);
     HEAPF32[$closA>>2] = $225;
     HEAPF32[$61>>2] = $226;
     HEAPF32[$62>>2] = $227;
     HEAPF32[$63>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $231;
     HEAPF32[$70>>2] = $232;
     HEAPF32[$71>>2] = $233;
     HEAPF32[$72>>2] = Math_fround(0.0);
     $234 = Math_fround($225 - $231);
     $235 = Math_fround($226 - $232);
     $236 = Math_fround($227 - $233);
     HEAPF32[$tempV>>2] = $234;
     HEAPF32[$73>>2] = $235;
     HEAPF32[$74>>2] = $236;
     HEAPF32[$75>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($156|0) == 0)) {
    HEAPF32[$closA>>2] = $137;
    HEAPF32[$61>>2] = $138;
    HEAPF32[$62>>2] = $139;
    HEAPF32[$63>>2] = Math_fround(0.0);
    ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   } else if ((($156|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($156|0) == 2)) {
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$76,$support,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$tempV+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$tempV+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$tempV+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$tempV+12>>2]|0;
  $237 = Math_fround(HEAPF32[$v>>2]);
  $238 = Math_fround(HEAPF32[$31>>2]);
  $239 = Math_fround(HEAPF32[$32>>2]);
  $240 = Math_fround($237 * $237);
  $241 = Math_fround($238 * $238);
  $242 = Math_fround($240 + $241);
  $243 = Math_fround($239 * $239);
  $244 = Math_fround($242 + $243);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1148+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1148+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1148+8>>2]|0;
  $245 = $155 > $244;
  $$not = !($244 > $40);
  $$not402 = $245 ^ 1;
  $brmerge = $$not | $$not402;
  if ($brmerge) {
   label = 13;
   break;
  } else {
   $155 = $244;$78 = $237;$80 = $238;$82 = $239;
  }
 }
 if ((label|0) == 3) {
  $166 = Math_fround(HEAPF32[$closB>>2]);
  $167 = Math_fround(HEAPF32[$70>>2]);
  $168 = Math_fround(HEAPF32[$71>>2]);
  $169 = Math_fround(HEAPF32[$closA>>2]);
  $170 = Math_fround(HEAPF32[$61>>2]);
  $171 = Math_fround(HEAPF32[$62>>2]);
  $172 = Math_fround($166 - $169);
  $173 = Math_fround($167 - $170);
  $174 = Math_fround($168 - $171);
  $175 = Math_fround($172 * $172);
  $176 = Math_fround($173 * $173);
  $177 = Math_fround($175 + $176);
  $178 = Math_fround($174 * $174);
  $179 = Math_fround($177 + $178);
  $180 = (Math_fround(Math_sqrt((Math_fround($179)))));
  $181 = Math_fround(Math_fround(1.0) / $180);
  $182 = Math_fround($172 * $181);
  $183 = Math_fround($173 * $181);
  $184 = Math_fround($174 * $181);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  HEAPF32[$sqDist>>2] = $155;
  $185 = (($sqDist) + 4|0);
  ;HEAP32[$185+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$185+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$185+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
  HEAPF32[$normal>>2] = $182;
  $186 = (($normal) + 4|0);
  HEAPF32[$186>>2] = $183;
  $187 = (($normal) + 8|0);
  HEAPF32[$187>>2] = $184;
  $188 = (($normal) + 12|0);
  HEAPF32[$188>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 13) {
  ;HEAP32[$5+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$closAA+12>>2]|0;
  $b$a$i26 = $245 ? $5 : $4;
  $246 = Math_fround(HEAPF32[$b$a$i26>>2]);
  $$in1$i29 = (($b$a$i26) + 4|0);
  $247 = Math_fround(HEAPF32[$$in1$i29>>2]);
  $$in2$i31 = (($b$a$i26) + 8|0);
  $248 = Math_fround(HEAPF32[$$in2$i31>>2]);
  HEAPF32[$closA>>2] = $246;
  HEAPF32[$61>>2] = $247;
  HEAPF32[$62>>2] = $248;
  HEAPF32[$63>>2] = Math_fround(0.0);
  ;HEAP32[$7+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closB+12>>2]|0;
  ;HEAP32[$6+0>>2]=HEAP32[$closBB+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$closBB+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$closBB+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$closBB+12>>2]|0;
  $b$a$i18 = $245 ? $7 : $6;
  $249 = Math_fround(HEAPF32[$b$a$i18>>2]);
  $$in1$i = (($b$a$i18) + 4|0);
  $250 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i18) + 8|0);
  $251 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$closB>>2] = $249;
  HEAPF32[$70>>2] = $250;
  HEAPF32[$71>>2] = $251;
  HEAPF32[$72>>2] = Math_fround(0.0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  $252 = Math_fround($249 - $246);
  $253 = Math_fround($250 - $247);
  $254 = Math_fround($251 - $248);
  $255 = Math_fround($252 * $252);
  $256 = Math_fround($253 * $253);
  $257 = Math_fround($255 + $256);
  $258 = Math_fround($254 * $254);
  $259 = Math_fround($257 + $258);
  $260 = (Math_fround(Math_sqrt((Math_fround($259)))));
  $261 = Math_fround(Math_fround(1.0) / $260);
  $262 = Math_fround($252 * $261);
  $263 = Math_fround($253 * $261);
  $264 = Math_fround($254 * $261);
  HEAPF32[$normal>>2] = $262;
  $265 = (($normal) + 4|0);
  HEAPF32[$265>>2] = $263;
  $266 = (($normal) + 8|0);
  HEAPF32[$266>>2] = $264;
  $267 = (($normal) + 12|0);
  HEAPF32[$267>>2] = Math_fround(0.0);
  $268 = $245 ? $244 : $155;
  HEAPF32[$sqDist>>2] = $268;
  $269 = (($sqDist) + 4|0);
  ;HEAP32[$269+0>>2]=HEAP32[$$sroa$1110+0>>2]|0;HEAP32[$269+4>>2]=HEAP32[$$sroa$1110+4>>2]|0;HEAP32[$269+8>>2]=HEAP32[$$sroa$1110+8>>2]|0;
  $270 = $245 ? 1 : 3;
  $$0 = $270;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu11gjkRelativeINS0_11ConvexHullVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERNSA_5Vec3VESF_SF_RNSA_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i29 = 0, $$in1$i94 = 0, $$in2$i = 0, $$in2$i31 = 0, $$in2$i96 = 0, $$not = 0, $$not402 = 0, $$sroa$1110 = 0, $$sroa$1148 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0);
 var $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0);
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0);
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0);
 var $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0);
 var $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0);
 var $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0;
 var $266 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_dir$i = 0, $b$a$i18 = 0, $b$a$i26 = 0, $b$a$i91 = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closB = 0, $closBB = 0, $maxPoint$i = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportB = 0, $tempV = 0, $v = 0;
 var $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp;
 $1 = sp + 336|0;
 $_dir$i = sp + 320|0;
 $maxPoint$i = sp + 288|0;
 $2 = sp + 304|0;
 $3 = sp + 448|0;
 $4 = sp + 352|0;
 $5 = sp + 368|0;
 $Q = sp + 384|0;
 $A = sp + 224|0;
 $B = sp + 64|0;
 $zeroV = sp + 208|0;
 $size = sp + 500|0;
 $v = sp + 16|0;
 $closA = sp + 32|0;
 $closB = sp + 48|0;
 $sDist$sroa$1 = sp + 476|0;
 $closAA = sp + 128|0;
 $closBB = sp + 144|0;
 $supportB = sp + 160|0;
 $support = sp + 176|0;
 $tempV = sp + 192|0;
 $$sroa$1148 = sp + 464|0;
 $$sroa$1110 = sp + 488|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAP32[$size>>2] = 0;
 $6 = (($aToB) + 48|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($aToB) + 52|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($aToB) + 56|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($aToB) + 60|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($7 * $7);
 $15 = Math_fround($9 * $9);
 $16 = Math_fround($14 + $15);
 $17 = Math_fround($11 * $11);
 $18 = Math_fround($16 + $17);
 $19 = $18 > Math_fround(0.0);
 HEAPF32[$1>>2] = $7;
 $20 = (($1) + 4|0);
 HEAPF32[$20>>2] = $9;
 $21 = (($1) + 8|0);
 HEAPF32[$21>>2] = $11;
 $22 = (($1) + 12|0);
 HEAPF32[$22>>2] = $13;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $23 = (($0) + 4|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($0) + 8|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($0) + 12|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $b$a$i91 = $19 ? $1 : $0;
 $26 = Math_fround(HEAPF32[$b$a$i91>>2]);
 $$in1$i94 = (($b$a$i91) + 4|0);
 $27 = Math_fround(HEAPF32[$$in1$i94>>2]);
 $$in2$i96 = (($b$a$i91) + 8|0);
 $28 = Math_fround(HEAPF32[$$in2$i96>>2]);
 HEAPF32[$v>>2] = $26;
 $29 = (($v) + 4|0);
 HEAPF32[$29>>2] = $27;
 $30 = (($v) + 8|0);
 HEAPF32[$30>>2] = $28;
 $31 = (($v) + 12|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($a) + 32|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($b) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = $33 > $35;
 $$$i = $36 ? $35 : $33;
 $37 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $38 = Math_fround($37 * $37);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $39 = (($aToB) + 4|0);
 $40 = (($aToB) + 8|0);
 $41 = (($aToB) + 16|0);
 $42 = (($aToB) + 20|0);
 $43 = (($aToB) + 24|0);
 $44 = (($aToB) + 32|0);
 $45 = (($aToB) + 36|0);
 $46 = (($aToB) + 40|0);
 $47 = (($_dir$i) + 4|0);
 $48 = (($_dir$i) + 8|0);
 $49 = (($_dir$i) + 12|0);
 $50 = (($maxPoint$i) + 4|0);
 $51 = (($maxPoint$i) + 8|0);
 $52 = (($supportB) + 4|0);
 $53 = (($supportB) + 8|0);
 $54 = (($support) + 4|0);
 $55 = (($support) + 8|0);
 $56 = (($support) + 12|0);
 $57 = (($closA) + 4|0);
 $58 = (($closA) + 8|0);
 $59 = (($closA) + 12|0);
 $60 = (($Q) + 4|0);
 $61 = (($Q) + 8|0);
 $62 = (($A) + 4|0);
 $63 = (($A) + 8|0);
 $64 = (($B) + 4|0);
 $65 = (($B) + 8|0);
 $66 = (($closB) + 4|0);
 $67 = (($closB) + 8|0);
 $68 = (($closB) + 12|0);
 $69 = (($tempV) + 4|0);
 $70 = (($tempV) + 8|0);
 $71 = (($tempV) + 12|0);
 $72 = (($Q) + 16|0);
 $151 = Math_fround(3.40282346638528859812E+38);$74 = $26;$76 = $27;$78 = $28;
 while(1) {
  ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closBB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closBB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closBB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closBB+12>>2]=HEAP32[$closB+12>>2]|0;
  $73 = Math_fround(-$74);
  $75 = Math_fround(-$76);
  $77 = Math_fround(-$78);
  $79 = Math_fround(HEAPF32[$aToB>>2]);
  $80 = Math_fround($79 * $73);
  $81 = Math_fround(HEAPF32[$39>>2]);
  $82 = Math_fround($81 * $75);
  $83 = Math_fround($80 + $82);
  $84 = Math_fround(HEAPF32[$40>>2]);
  $85 = Math_fround($84 * $77);
  $86 = Math_fround($83 + $85);
  $87 = Math_fround(HEAPF32[$41>>2]);
  $88 = Math_fround($87 * $73);
  $89 = Math_fround(HEAPF32[$42>>2]);
  $90 = Math_fround($89 * $75);
  $91 = Math_fround($88 + $90);
  $92 = Math_fround(HEAPF32[$43>>2]);
  $93 = Math_fround($92 * $77);
  $94 = Math_fround($91 + $93);
  $95 = Math_fround(HEAPF32[$44>>2]);
  $96 = Math_fround($95 * $73);
  $97 = Math_fround(HEAPF32[$45>>2]);
  $98 = Math_fround($97 * $75);
  $99 = Math_fround($96 + $98);
  $100 = Math_fround(HEAPF32[$46>>2]);
  $101 = Math_fround($100 * $77);
  $102 = Math_fround($99 + $101);
  HEAPF32[$_dir$i>>2] = $86;
  HEAPF32[$47>>2] = $94;
  HEAPF32[$48>>2] = $102;
  HEAPF32[$49>>2] = Math_fround(0.0);
  __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($maxPoint$i,$a,$_dir$i);
  $103 = Math_fround(HEAPF32[$6>>2]);
  $104 = Math_fround(HEAPF32[$8>>2]);
  $105 = Math_fround(HEAPF32[$10>>2]);
  $106 = Math_fround(HEAPF32[$maxPoint$i>>2]);
  $107 = Math_fround(HEAPF32[$50>>2]);
  $108 = Math_fround(HEAPF32[$51>>2]);
  $109 = Math_fround(HEAPF32[$aToB>>2]);
  $110 = Math_fround($106 * $109);
  $111 = Math_fround(HEAPF32[$41>>2]);
  $112 = Math_fround($107 * $111);
  $113 = Math_fround($110 + $112);
  $114 = Math_fround(HEAPF32[$44>>2]);
  $115 = Math_fround($108 * $114);
  $116 = Math_fround($113 + $115);
  $117 = Math_fround(HEAPF32[$39>>2]);
  $118 = Math_fround($106 * $117);
  $119 = Math_fround(HEAPF32[$42>>2]);
  $120 = Math_fround($107 * $119);
  $121 = Math_fround($118 + $120);
  $122 = Math_fround(HEAPF32[$45>>2]);
  $123 = Math_fround($108 * $122);
  $124 = Math_fround($121 + $123);
  $125 = Math_fround(HEAPF32[$40>>2]);
  $126 = Math_fround($106 * $125);
  $127 = Math_fround(HEAPF32[$43>>2]);
  $128 = Math_fround($107 * $127);
  $129 = Math_fround($126 + $128);
  $130 = Math_fround(HEAPF32[$46>>2]);
  $131 = Math_fround($108 * $130);
  $132 = Math_fround($129 + $131);
  $133 = Math_fround($103 + $116);
  $134 = Math_fround($104 + $124);
  $135 = Math_fround($105 + $132);
  __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($supportB,$b,$v);
  $136 = Math_fround(HEAPF32[$supportB>>2]);
  $137 = Math_fround(HEAPF32[$52>>2]);
  $138 = Math_fround(HEAPF32[$53>>2]);
  $139 = Math_fround($133 - $136);
  $140 = Math_fround($134 - $137);
  $141 = Math_fround($135 - $138);
  HEAPF32[$support>>2] = $139;
  HEAPF32[$54>>2] = $140;
  HEAPF32[$55>>2] = $141;
  HEAPF32[$56>>2] = Math_fround(0.0);
  $142 = Math_fround(HEAPF32[$v>>2]);
  $143 = Math_fround(HEAPF32[$29>>2]);
  $144 = Math_fround(HEAPF32[$30>>2]);
  $145 = Math_fround($142 * $139);
  $146 = Math_fround($143 * $140);
  $147 = Math_fround($145 + $146);
  $148 = Math_fround($144 * $141);
  $149 = Math_fround($147 + $148);
  $150 = Math_fround($151 - $149);
  $152 = HEAP32[$size>>2]|0;
  $153 = (($A) + ($152<<4)|0);
  HEAPF32[$153>>2] = $133;
  $154 = ((($A) + ($152<<4)|0) + 4|0);
  HEAPF32[$154>>2] = $134;
  $155 = ((($A) + ($152<<4)|0) + 8|0);
  HEAPF32[$155>>2] = $135;
  $156 = ((($A) + ($152<<4)|0) + 12|0);
  HEAPF32[$156>>2] = Math_fround(0.0);
  $157 = (($B) + ($152<<4)|0);
  ;HEAP32[$157+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$157+12>>2]=HEAP32[$supportB+12>>2]|0;
  $158 = (($152) + 1)|0;
  HEAP32[$size>>2] = $158;
  $159 = (($Q) + ($152<<4)|0);
  ;HEAP32[$159+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$159+12>>2]=HEAP32[$support+12>>2]|0;
  $160 = Math_fround($151 * Math_fround(2.24999996135011315346E-4));
  $161 = $160 > $150;
  if ($161) {
   label = 3;
   break;
  }
  do {
   if ((($152|0) == 0)) {
    HEAPF32[$closA>>2] = $133;
    HEAPF32[$57>>2] = $134;
    HEAPF32[$58>>2] = $135;
    HEAPF32[$59>>2] = Math_fround(0.0);
    ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   } else if ((($152|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($152|0) == 1)) {
    $185 = Math_fround(HEAPF32[$Q>>2]);
    $186 = Math_fround(HEAPF32[$60>>2]);
    $187 = Math_fround(HEAPF32[$61>>2]);
    $188 = Math_fround($139 - $185);
    $189 = Math_fround($140 - $186);
    $190 = Math_fround($141 - $187);
    $191 = Math_fround($188 * $188);
    $192 = Math_fround($189 * $189);
    $193 = Math_fround($191 + $192);
    $194 = Math_fround($190 * $190);
    $195 = Math_fround($193 + $194);
    $196 = $195 == Math_fround(0.0);
    if ($196) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $197 = Math_fround($186 * $189);
     $198 = Math_fround(-$197);
     $199 = Math_fround($185 * $188);
     $200 = Math_fround($198 - $199);
     $201 = Math_fround($187 * $190);
     $202 = Math_fround($200 - $201);
     $203 = Math_fround(HEAPF32[$A>>2]);
     $204 = Math_fround(HEAPF32[$62>>2]);
     $205 = Math_fround(HEAPF32[$63>>2]);
     $206 = Math_fround($133 - $203);
     $207 = Math_fround($134 - $204);
     $208 = Math_fround($135 - $205);
     $209 = Math_fround(HEAPF32[$B>>2]);
     $210 = Math_fround(HEAPF32[$64>>2]);
     $211 = Math_fround(HEAPF32[$65>>2]);
     $212 = Math_fround($136 - $209);
     $213 = Math_fround($137 - $210);
     $214 = Math_fround($138 - $211);
     $215 = Math_fround($202 / $195);
     $216 = $215 > Math_fround(1.0);
     $$$i$i$i = $216 ? Math_fround(1.0) : $215;
     $217 = $$$i$i$i > Math_fround(0.0);
     $$$i8$i$i = $217 ? $$$i$i$i : Math_fround(0.0);
     $218 = Math_fround($206 * $$$i8$i$i);
     $219 = Math_fround($207 * $$$i8$i$i);
     $220 = Math_fround($208 * $$$i8$i$i);
     $221 = Math_fround($203 + $218);
     $222 = Math_fround($204 + $219);
     $223 = Math_fround($205 + $220);
     $224 = Math_fround($212 * $$$i8$i$i);
     $225 = Math_fround($213 * $$$i8$i$i);
     $226 = Math_fround($214 * $$$i8$i$i);
     $227 = Math_fround($209 + $224);
     $228 = Math_fround($210 + $225);
     $229 = Math_fround($211 + $226);
     HEAPF32[$closA>>2] = $221;
     HEAPF32[$57>>2] = $222;
     HEAPF32[$58>>2] = $223;
     HEAPF32[$59>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $227;
     HEAPF32[$66>>2] = $228;
     HEAPF32[$67>>2] = $229;
     HEAPF32[$68>>2] = Math_fround(0.0);
     $230 = Math_fround($221 - $227);
     $231 = Math_fround($222 - $228);
     $232 = Math_fround($223 - $229);
     HEAPF32[$tempV>>2] = $230;
     HEAPF32[$69>>2] = $231;
     HEAPF32[$70>>2] = $232;
     HEAPF32[$71>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($152|0) == 2)) {
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$72,$support,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$tempV+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$tempV+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$tempV+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$tempV+12>>2]|0;
  $233 = Math_fround(HEAPF32[$v>>2]);
  $234 = Math_fround(HEAPF32[$29>>2]);
  $235 = Math_fround(HEAPF32[$30>>2]);
  $236 = Math_fround($233 * $233);
  $237 = Math_fround($234 * $234);
  $238 = Math_fround($236 + $237);
  $239 = Math_fround($235 * $235);
  $240 = Math_fround($238 + $239);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1148+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1148+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1148+8>>2]|0;
  $241 = $151 > $240;
  $$not = !($240 > $38);
  $$not402 = $241 ^ 1;
  $brmerge = $$not | $$not402;
  if ($brmerge) {
   label = 13;
   break;
  } else {
   $151 = $240;$74 = $233;$76 = $234;$78 = $235;
  }
 }
 if ((label|0) == 3) {
  $162 = Math_fround(HEAPF32[$closB>>2]);
  $163 = Math_fround(HEAPF32[$66>>2]);
  $164 = Math_fround(HEAPF32[$67>>2]);
  $165 = Math_fround(HEAPF32[$closA>>2]);
  $166 = Math_fround(HEAPF32[$57>>2]);
  $167 = Math_fround(HEAPF32[$58>>2]);
  $168 = Math_fround($162 - $165);
  $169 = Math_fround($163 - $166);
  $170 = Math_fround($164 - $167);
  $171 = Math_fround($168 * $168);
  $172 = Math_fround($169 * $169);
  $173 = Math_fround($171 + $172);
  $174 = Math_fround($170 * $170);
  $175 = Math_fround($173 + $174);
  $176 = (Math_fround(Math_sqrt((Math_fround($175)))));
  $177 = Math_fround(Math_fround(1.0) / $176);
  $178 = Math_fround($168 * $177);
  $179 = Math_fround($169 * $177);
  $180 = Math_fround($170 * $177);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  HEAPF32[$sqDist>>2] = $151;
  $181 = (($sqDist) + 4|0);
  ;HEAP32[$181+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$181+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
  HEAPF32[$normal>>2] = $178;
  $182 = (($normal) + 4|0);
  HEAPF32[$182>>2] = $179;
  $183 = (($normal) + 8|0);
  HEAPF32[$183>>2] = $180;
  $184 = (($normal) + 12|0);
  HEAPF32[$184>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 13) {
  ;HEAP32[$3+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$closAA+12>>2]|0;
  $b$a$i26 = $241 ? $3 : $2;
  $242 = Math_fround(HEAPF32[$b$a$i26>>2]);
  $$in1$i29 = (($b$a$i26) + 4|0);
  $243 = Math_fround(HEAPF32[$$in1$i29>>2]);
  $$in2$i31 = (($b$a$i26) + 8|0);
  $244 = Math_fround(HEAPF32[$$in2$i31>>2]);
  HEAPF32[$closA>>2] = $242;
  HEAPF32[$57>>2] = $243;
  HEAPF32[$58>>2] = $244;
  HEAPF32[$59>>2] = Math_fround(0.0);
  ;HEAP32[$5+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$closB+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$closBB+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$closBB+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$closBB+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$closBB+12>>2]|0;
  $b$a$i18 = $241 ? $5 : $4;
  $245 = Math_fround(HEAPF32[$b$a$i18>>2]);
  $$in1$i = (($b$a$i18) + 4|0);
  $246 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i18) + 8|0);
  $247 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$closB>>2] = $245;
  HEAPF32[$66>>2] = $246;
  HEAPF32[$67>>2] = $247;
  HEAPF32[$68>>2] = Math_fround(0.0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  $248 = Math_fround($245 - $242);
  $249 = Math_fround($246 - $243);
  $250 = Math_fround($247 - $244);
  $251 = Math_fround($248 * $248);
  $252 = Math_fround($249 * $249);
  $253 = Math_fround($251 + $252);
  $254 = Math_fround($250 * $250);
  $255 = Math_fround($253 + $254);
  $256 = (Math_fround(Math_sqrt((Math_fround($255)))));
  $257 = Math_fround(Math_fround(1.0) / $256);
  $258 = Math_fround($248 * $257);
  $259 = Math_fround($249 * $257);
  $260 = Math_fround($250 * $257);
  HEAPF32[$normal>>2] = $258;
  $261 = (($normal) + 4|0);
  HEAPF32[$261>>2] = $259;
  $262 = (($normal) + 8|0);
  HEAPF32[$262>>2] = $260;
  $263 = (($normal) + 12|0);
  HEAPF32[$263>>2] = Math_fround(0.0);
  $264 = $241 ? $240 : $151;
  HEAPF32[$sqDist>>2] = $264;
  $265 = (($sqDist) + 4|0);
  ;HEAP32[$265+0>>2]=HEAP32[$$sroa$1110+0>>2]|0;HEAP32[$265+4>>2]=HEAP32[$$sroa$1110+4>>2]|0;HEAP32[$265+8>>2]=HEAP32[$$sroa$1110+8>>2]|0;
  $266 = $241 ? 1 : 3;
  $$0 = $266;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu11GJKRelativeERKNS0_9TriangleVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERNS8_5Vec3VESD_SD_RNS8_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu11gjkRelativeINS0_9TriangleVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERNSB_5Vec3VESG_SG_RNSB_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu11gjkRelativeINS0_9TriangleVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERNSB_5Vec3VESG_SG_RNSB_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i29 = 0, $$in1$i94 = 0, $$in2$i = 0, $$in2$i31 = 0, $$in2$i96 = 0, $$not = 0, $$not398 = 0, $$sroa$1110 = 0, $$sroa$1148 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0);
 var $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0;
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0);
 var $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0);
 var $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0);
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0);
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0;
 var $b$a$i18 = 0, $b$a$i26 = 0, $b$a$i91 = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closB = 0, $closBB = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportA = 0, $supportB = 0, $tempV = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp;
 $1 = sp + 224|0;
 $2 = sp + 176|0;
 $3 = sp + 192|0;
 $4 = sp + 208|0;
 $5 = sp + 448|0;
 $Q = sp + 240|0;
 $A = sp + 304|0;
 $B = sp + 384|0;
 $zeroV = sp + 368|0;
 $size = sp + 500|0;
 $v = sp + 64|0;
 $closA = sp + 160|0;
 $closB = sp + 16|0;
 $sDist$sroa$1 = sp + 488|0;
 $closAA = sp + 32|0;
 $closBB = sp + 48|0;
 $supportA = sp + 80|0;
 $6 = sp + 96|0;
 $supportB = sp + 112|0;
 $support = sp + 128|0;
 $tempV = sp + 144|0;
 $$sroa$1148 = sp + 464|0;
 $$sroa$1110 = sp + 476|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAP32[$size>>2] = 0;
 $7 = (($aToB) + 48|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($aToB) + 52|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($aToB) + 56|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($aToB) + 60|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($8 * $8);
 $16 = Math_fround($10 * $10);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($12 * $12);
 $19 = Math_fround($17 + $18);
 $20 = $19 > Math_fround(0.0);
 HEAPF32[$1>>2] = $8;
 $21 = (($1) + 4|0);
 HEAPF32[$21>>2] = $10;
 $22 = (($1) + 8|0);
 HEAPF32[$22>>2] = $12;
 $23 = (($1) + 12|0);
 HEAPF32[$23>>2] = $14;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $24 = (($0) + 4|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($0) + 8|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($0) + 12|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $b$a$i91 = $20 ? $1 : $0;
 $27 = Math_fround(HEAPF32[$b$a$i91>>2]);
 $$in1$i94 = (($b$a$i91) + 4|0);
 $28 = Math_fround(HEAPF32[$$in1$i94>>2]);
 $$in2$i96 = (($b$a$i91) + 8|0);
 $29 = Math_fround(HEAPF32[$$in2$i96>>2]);
 HEAPF32[$v>>2] = $27;
 $30 = (($v) + 4|0);
 HEAPF32[$30>>2] = $28;
 $31 = (($v) + 8|0);
 HEAPF32[$31>>2] = $29;
 $32 = (($v) + 12|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($a) + 32|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($b) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = $34 > $36;
 $$$i = $37 ? $36 : $34;
 $38 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $39 = Math_fround($38 * $38);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $40 = (($6) + 4|0);
 $41 = (($6) + 8|0);
 $42 = (($6) + 12|0);
 $43 = (($supportA) + 4|0);
 $44 = (($supportA) + 8|0);
 $45 = (($supportB) + 4|0);
 $46 = (($supportB) + 8|0);
 $47 = (($support) + 4|0);
 $48 = (($support) + 8|0);
 $49 = (($support) + 12|0);
 $50 = (($Q) + 4|0);
 $51 = (($Q) + 8|0);
 $52 = (($A) + 4|0);
 $53 = (($A) + 8|0);
 $54 = (($B) + 4|0);
 $55 = (($B) + 8|0);
 $56 = (($closA) + 4|0);
 $57 = (($closA) + 8|0);
 $58 = (($closA) + 12|0);
 $59 = (($closB) + 4|0);
 $60 = (($closB) + 8|0);
 $61 = (($closB) + 12|0);
 $62 = (($tempV) + 4|0);
 $63 = (($tempV) + 8|0);
 $64 = (($tempV) + 12|0);
 $65 = (($Q) + 16|0);
 $67 = $27;$69 = $28;$71 = $29;$90 = Math_fround(3.40282346638528859812E+38);
 while(1) {
  ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closBB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closBB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closBB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closBB+12>>2]=HEAP32[$closB+12>>2]|0;
  $66 = Math_fround(-$67);
  $68 = Math_fround(-$69);
  $70 = Math_fround(-$71);
  HEAPF32[$6>>2] = $66;
  HEAPF32[$40>>2] = $68;
  HEAPF32[$41>>2] = $70;
  HEAPF32[$42>>2] = Math_fround(0.0);
  __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($supportA,$a,$6,$aToB);
  __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($supportB,$b,$v);
  $72 = Math_fround(HEAPF32[$supportA>>2]);
  $73 = Math_fround(HEAPF32[$43>>2]);
  $74 = Math_fround(HEAPF32[$44>>2]);
  $75 = Math_fround(HEAPF32[$supportB>>2]);
  $76 = Math_fround(HEAPF32[$45>>2]);
  $77 = Math_fround(HEAPF32[$46>>2]);
  $78 = Math_fround($72 - $75);
  $79 = Math_fround($73 - $76);
  $80 = Math_fround($74 - $77);
  HEAPF32[$support>>2] = $78;
  HEAPF32[$47>>2] = $79;
  HEAPF32[$48>>2] = $80;
  HEAPF32[$49>>2] = Math_fround(0.0);
  $81 = Math_fround(HEAPF32[$v>>2]);
  $82 = Math_fround(HEAPF32[$30>>2]);
  $83 = Math_fround(HEAPF32[$31>>2]);
  $84 = Math_fround($81 * $78);
  $85 = Math_fround($82 * $79);
  $86 = Math_fround($84 + $85);
  $87 = Math_fround($83 * $80);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround($90 - $88);
  $91 = HEAP32[$size>>2]|0;
  $92 = (($A) + ($91<<4)|0);
  ;HEAP32[$92+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$92+12>>2]=HEAP32[$supportA+12>>2]|0;
  $93 = (($B) + ($91<<4)|0);
  ;HEAP32[$93+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$93+12>>2]=HEAP32[$supportB+12>>2]|0;
  $94 = (($91) + 1)|0;
  HEAP32[$size>>2] = $94;
  $95 = (($Q) + ($91<<4)|0);
  ;HEAP32[$95+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$95+12>>2]=HEAP32[$support+12>>2]|0;
  $96 = Math_fround($90 * Math_fround(2.24999996135011315346E-4));
  $97 = $96 > $89;
  if ($97) {
   label = 3;
   break;
  }
  do {
   if ((($91|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   } else if ((($91|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($91|0) == 1)) {
    $121 = Math_fround(HEAPF32[$Q>>2]);
    $122 = Math_fround(HEAPF32[$50>>2]);
    $123 = Math_fround(HEAPF32[$51>>2]);
    $124 = Math_fround($78 - $121);
    $125 = Math_fround($79 - $122);
    $126 = Math_fround($80 - $123);
    $127 = Math_fround($124 * $124);
    $128 = Math_fround($125 * $125);
    $129 = Math_fround($127 + $128);
    $130 = Math_fround($126 * $126);
    $131 = Math_fround($129 + $130);
    $132 = $131 == Math_fround(0.0);
    if ($132) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $133 = Math_fround($122 * $125);
     $134 = Math_fround(-$133);
     $135 = Math_fround($121 * $124);
     $136 = Math_fround($134 - $135);
     $137 = Math_fround($123 * $126);
     $138 = Math_fround($136 - $137);
     $139 = Math_fround(HEAPF32[$A>>2]);
     $140 = Math_fround(HEAPF32[$52>>2]);
     $141 = Math_fround(HEAPF32[$53>>2]);
     $142 = Math_fround($72 - $139);
     $143 = Math_fround($73 - $140);
     $144 = Math_fround($74 - $141);
     $145 = Math_fround(HEAPF32[$B>>2]);
     $146 = Math_fround(HEAPF32[$54>>2]);
     $147 = Math_fround(HEAPF32[$55>>2]);
     $148 = Math_fround($75 - $145);
     $149 = Math_fround($76 - $146);
     $150 = Math_fround($77 - $147);
     $151 = Math_fround($138 / $131);
     $152 = $151 > Math_fround(1.0);
     $$$i$i$i = $152 ? Math_fround(1.0) : $151;
     $153 = $$$i$i$i > Math_fround(0.0);
     $$$i8$i$i = $153 ? $$$i$i$i : Math_fround(0.0);
     $154 = Math_fround($142 * $$$i8$i$i);
     $155 = Math_fround($143 * $$$i8$i$i);
     $156 = Math_fround($144 * $$$i8$i$i);
     $157 = Math_fround($139 + $154);
     $158 = Math_fround($140 + $155);
     $159 = Math_fround($141 + $156);
     $160 = Math_fround($148 * $$$i8$i$i);
     $161 = Math_fround($149 * $$$i8$i$i);
     $162 = Math_fround($150 * $$$i8$i$i);
     $163 = Math_fround($145 + $160);
     $164 = Math_fround($146 + $161);
     $165 = Math_fround($147 + $162);
     HEAPF32[$closA>>2] = $157;
     HEAPF32[$56>>2] = $158;
     HEAPF32[$57>>2] = $159;
     HEAPF32[$58>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $163;
     HEAPF32[$59>>2] = $164;
     HEAPF32[$60>>2] = $165;
     HEAPF32[$61>>2] = Math_fround(0.0);
     $166 = Math_fround($157 - $163);
     $167 = Math_fround($158 - $164);
     $168 = Math_fround($159 - $165);
     HEAPF32[$tempV>>2] = $166;
     HEAPF32[$62>>2] = $167;
     HEAPF32[$63>>2] = $168;
     HEAPF32[$64>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($91|0) == 2)) {
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$65,$support,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$tempV+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$tempV+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$tempV+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$tempV+12>>2]|0;
  $169 = Math_fround(HEAPF32[$v>>2]);
  $170 = Math_fround(HEAPF32[$30>>2]);
  $171 = Math_fround(HEAPF32[$31>>2]);
  $172 = Math_fround($169 * $169);
  $173 = Math_fround($170 * $170);
  $174 = Math_fround($172 + $173);
  $175 = Math_fround($171 * $171);
  $176 = Math_fround($174 + $175);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1148+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1148+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1148+8>>2]|0;
  $177 = $90 > $176;
  $$not = !($176 > $39);
  $$not398 = $177 ^ 1;
  $brmerge = $$not | $$not398;
  if ($brmerge) {
   label = 13;
   break;
  } else {
   $67 = $169;$69 = $170;$71 = $171;$90 = $176;
  }
 }
 if ((label|0) == 3) {
  $98 = Math_fround(HEAPF32[$closB>>2]);
  $99 = Math_fround(HEAPF32[$59>>2]);
  $100 = Math_fround(HEAPF32[$60>>2]);
  $101 = Math_fround(HEAPF32[$closA>>2]);
  $102 = Math_fround(HEAPF32[$56>>2]);
  $103 = Math_fround(HEAPF32[$57>>2]);
  $104 = Math_fround($98 - $101);
  $105 = Math_fround($99 - $102);
  $106 = Math_fround($100 - $103);
  $107 = Math_fround($104 * $104);
  $108 = Math_fround($105 * $105);
  $109 = Math_fround($107 + $108);
  $110 = Math_fround($106 * $106);
  $111 = Math_fround($109 + $110);
  $112 = (Math_fround(Math_sqrt((Math_fround($111)))));
  $113 = Math_fround(Math_fround(1.0) / $112);
  $114 = Math_fround($104 * $113);
  $115 = Math_fround($105 * $113);
  $116 = Math_fround($106 * $113);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  HEAPF32[$sqDist>>2] = $90;
  $117 = (($sqDist) + 4|0);
  ;HEAP32[$117+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$117+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$117+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
  HEAPF32[$normal>>2] = $114;
  $118 = (($normal) + 4|0);
  HEAPF32[$118>>2] = $115;
  $119 = (($normal) + 8|0);
  HEAPF32[$119>>2] = $116;
  $120 = (($normal) + 12|0);
  HEAPF32[$120>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 13) {
  ;HEAP32[$3+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$closAA+12>>2]|0;
  $b$a$i26 = $177 ? $3 : $2;
  $178 = Math_fround(HEAPF32[$b$a$i26>>2]);
  $$in1$i29 = (($b$a$i26) + 4|0);
  $179 = Math_fround(HEAPF32[$$in1$i29>>2]);
  $$in2$i31 = (($b$a$i26) + 8|0);
  $180 = Math_fround(HEAPF32[$$in2$i31>>2]);
  HEAPF32[$closA>>2] = $178;
  HEAPF32[$56>>2] = $179;
  HEAPF32[$57>>2] = $180;
  HEAPF32[$58>>2] = Math_fround(0.0);
  ;HEAP32[$5+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$closB+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$closBB+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$closBB+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$closBB+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$closBB+12>>2]|0;
  $b$a$i18 = $177 ? $5 : $4;
  $181 = Math_fround(HEAPF32[$b$a$i18>>2]);
  $$in1$i = (($b$a$i18) + 4|0);
  $182 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i18) + 8|0);
  $183 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$closB>>2] = $181;
  HEAPF32[$59>>2] = $182;
  HEAPF32[$60>>2] = $183;
  HEAPF32[$61>>2] = Math_fround(0.0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  $184 = Math_fround($181 - $178);
  $185 = Math_fround($182 - $179);
  $186 = Math_fround($183 - $180);
  $187 = Math_fround($184 * $184);
  $188 = Math_fround($185 * $185);
  $189 = Math_fround($187 + $188);
  $190 = Math_fround($186 * $186);
  $191 = Math_fround($189 + $190);
  $192 = (Math_fround(Math_sqrt((Math_fround($191)))));
  $193 = Math_fround(Math_fround(1.0) / $192);
  $194 = Math_fround($184 * $193);
  $195 = Math_fround($185 * $193);
  $196 = Math_fround($186 * $193);
  HEAPF32[$normal>>2] = $194;
  $197 = (($normal) + 4|0);
  HEAPF32[$197>>2] = $195;
  $198 = (($normal) + 8|0);
  HEAPF32[$198>>2] = $196;
  $199 = (($normal) + 12|0);
  HEAPF32[$199>>2] = Math_fround(0.0);
  $200 = $177 ? $176 : $90;
  HEAPF32[$sqDist>>2] = $200;
  $201 = (($sqDist) + 4|0);
  ;HEAP32[$201+0>>2]=HEAP32[$$sroa$1110+0>>2]|0;HEAP32[$201+4>>2]=HEAP32[$$sroa$1110+4>>2]|0;HEAP32[$201+8>>2]=HEAP32[$$sroa$1110+8>>2]|0;
  $202 = $177 ? 1 : 3;
  $$0 = $202;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu8GJKLocalERKNS0_8CapsuleVERKNS0_11ConvexHullVERNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVE($a,$b,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu8gjkLocalINS0_8CapsuleVENS0_11ConvexHullVEEEjRKT_RKT0_RNS_6shdfnd3aos5Vec3VESD_SD_RNSB_6FloatVE($a,$b,$closestA,$closestB,$normal,$sqDist)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu8gjkLocalINS0_8CapsuleVENS0_11ConvexHullVEEEjRKT_RKT0_RNS_6shdfnd3aos5Vec3VESD_SD_RNSB_6FloatVE($a,$b,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i29 = 0, $$in1$i94 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i31 = 0, $$in2$i96 = 0, $$not = 0, $$not422 = 0, $$sroa$1114 = 0, $$sroa$1152 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0;
 var $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0);
 var $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0);
 var $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0);
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0);
 var $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0;
 var $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $b$a$i$i = 0, $b$a$i18 = 0, $b$a$i26 = 0, $b$a$i91 = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closB = 0, $closBB = 0;
 var $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportB = 0, $tempV = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp;
 $1 = sp + 336|0;
 $2 = sp + 320|0;
 $3 = sp + 288|0;
 $4 = sp + 304|0;
 $5 = sp + 448|0;
 $6 = sp + 352|0;
 $7 = sp + 368|0;
 $Q = sp + 384|0;
 $A = sp + 224|0;
 $B = sp + 64|0;
 $zeroV = sp + 208|0;
 $size = sp + 500|0;
 $v = sp + 16|0;
 $closA = sp + 32|0;
 $closB = sp + 48|0;
 $sDist$sroa$1 = sp + 476|0;
 $closAA = sp + 128|0;
 $closBB = sp + 144|0;
 $supportB = sp + 160|0;
 $support = sp + 176|0;
 $tempV = sp + 192|0;
 $$sroa$1152 = sp + 464|0;
 $$sroa$1114 = sp + 488|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAP32[$size>>2] = 0;
 $8 = Math_fround(HEAPF32[$a>>2]);
 $9 = (($a) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(HEAPF32[$b>>2]);
 $14 = (($b) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($b) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($8 - $13);
 $19 = Math_fround($10 - $15);
 $20 = Math_fround($12 - $17);
 $21 = Math_fround($18 * $18);
 $22 = Math_fround($19 * $19);
 $23 = Math_fround($21 + $22);
 $24 = Math_fround($20 * $20);
 $25 = Math_fround($23 + $24);
 $26 = $25 > Math_fround(0.0);
 HEAPF32[$1>>2] = $18;
 $27 = (($1) + 4|0);
 HEAPF32[$27>>2] = $19;
 $28 = (($1) + 8|0);
 HEAPF32[$28>>2] = $20;
 $29 = (($1) + 12|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $30 = (($0) + 4|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($0) + 8|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($0) + 12|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $b$a$i91 = $26 ? $1 : $0;
 $33 = Math_fround(HEAPF32[$b$a$i91>>2]);
 $$in1$i94 = (($b$a$i91) + 4|0);
 $34 = Math_fround(HEAPF32[$$in1$i94>>2]);
 $$in2$i96 = (($b$a$i91) + 8|0);
 $35 = Math_fround(HEAPF32[$$in2$i96>>2]);
 HEAPF32[$v>>2] = $33;
 $36 = (($v) + 4|0);
 HEAPF32[$36>>2] = $34;
 $37 = (($v) + 8|0);
 HEAPF32[$37>>2] = $35;
 $38 = (($v) + 12|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($a) + 32|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($b) + 32|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = $40 > $42;
 $$$i = $43 ? $42 : $40;
 $44 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $45 = Math_fround($44 * $44);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $46 = (($a) + 96|0);
 $47 = (($a) + 96|0);
 $48 = (($a) + 100|0);
 $49 = (($a) + 104|0);
 $50 = (($a) + 112|0);
 $51 = (($a) + 112|0);
 $52 = (($a) + 116|0);
 $53 = (($a) + 120|0);
 $54 = (($supportB) + 4|0);
 $55 = (($supportB) + 8|0);
 $56 = (($support) + 4|0);
 $57 = (($support) + 8|0);
 $58 = (($support) + 12|0);
 $59 = (($closA) + 4|0);
 $60 = (($closA) + 8|0);
 $61 = (($closA) + 12|0);
 $62 = (($Q) + 4|0);
 $63 = (($Q) + 8|0);
 $64 = (($A) + 4|0);
 $65 = (($A) + 8|0);
 $66 = (($B) + 4|0);
 $67 = (($B) + 8|0);
 $68 = (($closB) + 4|0);
 $69 = (($closB) + 8|0);
 $70 = (($closB) + 12|0);
 $71 = (($tempV) + 4|0);
 $72 = (($tempV) + 8|0);
 $73 = (($tempV) + 12|0);
 $74 = (($Q) + 16|0);
 $116 = Math_fround(3.40282346638528859812E+38);$76 = $33;$78 = $34;$80 = $35;
 while(1) {
  ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closBB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closBB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closBB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closBB+12>>2]=HEAP32[$closB+12>>2]|0;
  $75 = Math_fround(-$76);
  $77 = Math_fround(-$78);
  $79 = Math_fround(-$80);
  $81 = Math_fround(HEAPF32[$47>>2]);
  $82 = Math_fround(HEAPF32[$48>>2]);
  $83 = Math_fround(HEAPF32[$49>>2]);
  $84 = Math_fround($81 * $75);
  $85 = Math_fround($82 * $77);
  $86 = Math_fround($84 + $85);
  $87 = Math_fround($83 * $79);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround(HEAPF32[$51>>2]);
  $90 = Math_fround(HEAPF32[$52>>2]);
  $91 = Math_fround(HEAPF32[$53>>2]);
  $92 = Math_fround($89 * $75);
  $93 = Math_fround($90 * $77);
  $94 = Math_fround($92 + $93);
  $95 = Math_fround($91 * $79);
  $96 = Math_fround($94 + $95);
  $97 = $88 > $96;
  ;HEAP32[$3+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$46+12>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$50+12>>2]|0;
  $b$a$i$i = $97 ? $3 : $2;
  $98 = Math_fround(HEAPF32[$b$a$i$i>>2]);
  $$in1$i$i = (($b$a$i$i) + 4|0);
  $99 = Math_fround(HEAPF32[$$in1$i$i>>2]);
  $$in2$i$i = (($b$a$i$i) + 8|0);
  $100 = Math_fround(HEAPF32[$$in2$i$i>>2]);
  __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($supportB,$b,$v);
  $101 = Math_fround(HEAPF32[$supportB>>2]);
  $102 = Math_fround(HEAPF32[$54>>2]);
  $103 = Math_fround(HEAPF32[$55>>2]);
  $104 = Math_fround($98 - $101);
  $105 = Math_fround($99 - $102);
  $106 = Math_fround($100 - $103);
  HEAPF32[$support>>2] = $104;
  HEAPF32[$56>>2] = $105;
  HEAPF32[$57>>2] = $106;
  HEAPF32[$58>>2] = Math_fround(0.0);
  $107 = Math_fround(HEAPF32[$v>>2]);
  $108 = Math_fround(HEAPF32[$36>>2]);
  $109 = Math_fround(HEAPF32[$37>>2]);
  $110 = Math_fround($107 * $104);
  $111 = Math_fround($108 * $105);
  $112 = Math_fround($110 + $111);
  $113 = Math_fround($109 * $106);
  $114 = Math_fround($112 + $113);
  $115 = Math_fround($116 - $114);
  $117 = HEAP32[$size>>2]|0;
  $118 = (($A) + ($117<<4)|0);
  HEAPF32[$118>>2] = $98;
  $119 = ((($A) + ($117<<4)|0) + 4|0);
  HEAPF32[$119>>2] = $99;
  $120 = ((($A) + ($117<<4)|0) + 8|0);
  HEAPF32[$120>>2] = $100;
  $121 = ((($A) + ($117<<4)|0) + 12|0);
  HEAPF32[$121>>2] = Math_fround(0.0);
  $122 = (($B) + ($117<<4)|0);
  ;HEAP32[$122+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$122+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$122+12>>2]=HEAP32[$supportB+12>>2]|0;
  $123 = (($117) + 1)|0;
  HEAP32[$size>>2] = $123;
  $124 = (($Q) + ($117<<4)|0);
  ;HEAP32[$124+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$124+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$124+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$124+12>>2]=HEAP32[$support+12>>2]|0;
  $125 = Math_fround($116 * Math_fround(2.24999996135011315346E-4));
  $126 = $125 > $115;
  if ($126) {
   label = 3;
   break;
  }
  do {
   if ((($117|0) == 1)) {
    $150 = Math_fround(HEAPF32[$Q>>2]);
    $151 = Math_fround(HEAPF32[$62>>2]);
    $152 = Math_fround(HEAPF32[$63>>2]);
    $153 = Math_fround($104 - $150);
    $154 = Math_fround($105 - $151);
    $155 = Math_fround($106 - $152);
    $156 = Math_fround($153 * $153);
    $157 = Math_fround($154 * $154);
    $158 = Math_fround($156 + $157);
    $159 = Math_fround($155 * $155);
    $160 = Math_fround($158 + $159);
    $161 = $160 == Math_fround(0.0);
    if ($161) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $162 = Math_fround($151 * $154);
     $163 = Math_fround(-$162);
     $164 = Math_fround($150 * $153);
     $165 = Math_fround($163 - $164);
     $166 = Math_fround($152 * $155);
     $167 = Math_fround($165 - $166);
     $168 = Math_fround(HEAPF32[$A>>2]);
     $169 = Math_fround(HEAPF32[$64>>2]);
     $170 = Math_fround(HEAPF32[$65>>2]);
     $171 = Math_fround($98 - $168);
     $172 = Math_fround($99 - $169);
     $173 = Math_fround($100 - $170);
     $174 = Math_fround(HEAPF32[$B>>2]);
     $175 = Math_fround(HEAPF32[$66>>2]);
     $176 = Math_fround(HEAPF32[$67>>2]);
     $177 = Math_fround($101 - $174);
     $178 = Math_fround($102 - $175);
     $179 = Math_fround($103 - $176);
     $180 = Math_fround($167 / $160);
     $181 = $180 > Math_fround(1.0);
     $$$i$i$i = $181 ? Math_fround(1.0) : $180;
     $182 = $$$i$i$i > Math_fround(0.0);
     $$$i8$i$i = $182 ? $$$i$i$i : Math_fround(0.0);
     $183 = Math_fround($171 * $$$i8$i$i);
     $184 = Math_fround($172 * $$$i8$i$i);
     $185 = Math_fround($173 * $$$i8$i$i);
     $186 = Math_fround($168 + $183);
     $187 = Math_fround($169 + $184);
     $188 = Math_fround($170 + $185);
     $189 = Math_fround($177 * $$$i8$i$i);
     $190 = Math_fround($178 * $$$i8$i$i);
     $191 = Math_fround($179 * $$$i8$i$i);
     $192 = Math_fround($174 + $189);
     $193 = Math_fround($175 + $190);
     $194 = Math_fround($176 + $191);
     HEAPF32[$closA>>2] = $186;
     HEAPF32[$59>>2] = $187;
     HEAPF32[$60>>2] = $188;
     HEAPF32[$61>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $192;
     HEAPF32[$68>>2] = $193;
     HEAPF32[$69>>2] = $194;
     HEAPF32[$70>>2] = Math_fround(0.0);
     $195 = Math_fround($186 - $192);
     $196 = Math_fround($187 - $193);
     $197 = Math_fround($188 - $194);
     HEAPF32[$tempV>>2] = $195;
     HEAPF32[$71>>2] = $196;
     HEAPF32[$72>>2] = $197;
     HEAPF32[$73>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($117|0) == 0)) {
    HEAPF32[$closA>>2] = $98;
    HEAPF32[$59>>2] = $99;
    HEAPF32[$60>>2] = $100;
    HEAPF32[$61>>2] = Math_fround(0.0);
    ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   } else if ((($117|0) == 2)) {
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$74,$support,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($117|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$tempV+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$tempV+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$tempV+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$tempV+12>>2]|0;
  $198 = Math_fround(HEAPF32[$v>>2]);
  $199 = Math_fround(HEAPF32[$36>>2]);
  $200 = Math_fround(HEAPF32[$37>>2]);
  $201 = Math_fround($198 * $198);
  $202 = Math_fround($199 * $199);
  $203 = Math_fround($201 + $202);
  $204 = Math_fround($200 * $200);
  $205 = Math_fround($203 + $204);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1152+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1152+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1152+8>>2]|0;
  $206 = $116 > $205;
  $$not = !($205 > $45);
  $$not422 = $206 ^ 1;
  $brmerge = $$not | $$not422;
  if ($brmerge) {
   label = 13;
   break;
  } else {
   $116 = $205;$76 = $198;$78 = $199;$80 = $200;
  }
 }
 if ((label|0) == 3) {
  $127 = Math_fround(HEAPF32[$closB>>2]);
  $128 = Math_fround(HEAPF32[$68>>2]);
  $129 = Math_fround(HEAPF32[$69>>2]);
  $130 = Math_fround(HEAPF32[$closA>>2]);
  $131 = Math_fround(HEAPF32[$59>>2]);
  $132 = Math_fround(HEAPF32[$60>>2]);
  $133 = Math_fround($127 - $130);
  $134 = Math_fround($128 - $131);
  $135 = Math_fround($129 - $132);
  $136 = Math_fround($133 * $133);
  $137 = Math_fround($134 * $134);
  $138 = Math_fround($136 + $137);
  $139 = Math_fround($135 * $135);
  $140 = Math_fround($138 + $139);
  $141 = (Math_fround(Math_sqrt((Math_fround($140)))));
  $142 = Math_fround(Math_fround(1.0) / $141);
  $143 = Math_fround($133 * $142);
  $144 = Math_fround($134 * $142);
  $145 = Math_fround($135 * $142);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  HEAPF32[$sqDist>>2] = $116;
  $146 = (($sqDist) + 4|0);
  ;HEAP32[$146+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
  HEAPF32[$normal>>2] = $143;
  $147 = (($normal) + 4|0);
  HEAPF32[$147>>2] = $144;
  $148 = (($normal) + 8|0);
  HEAPF32[$148>>2] = $145;
  $149 = (($normal) + 12|0);
  HEAPF32[$149>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 13) {
  ;HEAP32[$5+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$closAA+12>>2]|0;
  $b$a$i26 = $206 ? $5 : $4;
  $207 = Math_fround(HEAPF32[$b$a$i26>>2]);
  $$in1$i29 = (($b$a$i26) + 4|0);
  $208 = Math_fround(HEAPF32[$$in1$i29>>2]);
  $$in2$i31 = (($b$a$i26) + 8|0);
  $209 = Math_fround(HEAPF32[$$in2$i31>>2]);
  HEAPF32[$closA>>2] = $207;
  HEAPF32[$59>>2] = $208;
  HEAPF32[$60>>2] = $209;
  HEAPF32[$61>>2] = Math_fround(0.0);
  ;HEAP32[$7+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closB+12>>2]|0;
  ;HEAP32[$6+0>>2]=HEAP32[$closBB+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$closBB+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$closBB+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$closBB+12>>2]|0;
  $b$a$i18 = $206 ? $7 : $6;
  $210 = Math_fround(HEAPF32[$b$a$i18>>2]);
  $$in1$i = (($b$a$i18) + 4|0);
  $211 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i18) + 8|0);
  $212 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$closB>>2] = $210;
  HEAPF32[$68>>2] = $211;
  HEAPF32[$69>>2] = $212;
  HEAPF32[$70>>2] = Math_fround(0.0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  $213 = Math_fround($210 - $207);
  $214 = Math_fround($211 - $208);
  $215 = Math_fround($212 - $209);
  $216 = Math_fround($213 * $213);
  $217 = Math_fround($214 * $214);
  $218 = Math_fround($216 + $217);
  $219 = Math_fround($215 * $215);
  $220 = Math_fround($218 + $219);
  $221 = (Math_fround(Math_sqrt((Math_fround($220)))));
  $222 = Math_fround(Math_fround(1.0) / $221);
  $223 = Math_fround($213 * $222);
  $224 = Math_fround($214 * $222);
  $225 = Math_fround($215 * $222);
  HEAPF32[$normal>>2] = $223;
  $226 = (($normal) + 4|0);
  HEAPF32[$226>>2] = $224;
  $227 = (($normal) + 8|0);
  HEAPF32[$227>>2] = $225;
  $228 = (($normal) + 12|0);
  HEAPF32[$228>>2] = Math_fround(0.0);
  $229 = $206 ? $205 : $116;
  HEAPF32[$sqDist>>2] = $229;
  $230 = (($sqDist) + 4|0);
  ;HEAP32[$230+0>>2]=HEAP32[$$sroa$1114+0>>2]|0;HEAP32[$230+4>>2]=HEAP32[$$sroa$1114+4>>2]|0;HEAP32[$230+8>>2]=HEAP32[$$sroa$1114+8>>2]|0;
  $231 = $206 ? 1 : 3;
  $$0 = $231;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu8GJKLocalERKNS0_9TriangleVERKNS0_4BoxVERNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVE($a,$b,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu8gjkLocalINS0_9TriangleVENS0_4BoxVEEEjRKT_RKT0_RNS_6shdfnd3aos5Vec3VESD_SD_RNSB_6FloatVE($a,$b,$closestA,$closestB,$normal,$sqDist)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu8gjkLocalINS0_9TriangleVENS0_4BoxVEEEjRKT_RKT0_RNS_6shdfnd3aos5Vec3VESD_SD_RNSB_6FloatVE($a,$b,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i72 = 0, $$in1$i19$i = 0, $$in1$i29 = 0, $$in1$i97 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i73 = 0, $$in2$i21$i = 0, $$in2$i31 = 0, $$in2$i99 = 0, $$not = 0, $$not425 = 0, $$sroa$1117 = 0, $$sroa$1155 = 0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0;
 var $Q = 0, $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a$i16$i = 0, $b$a$i18 = 0, $b$a$i26 = 0, $b$a$i94 = 0, $b$a5$i$i = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closB = 0, $closBB = 0, $phitmp164$i = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $tempV = 0, $zeroV = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 80|0;
 $1 = sp + 400|0;
 $2 = sp + 432|0;
 $3 = sp + 448|0;
 $4 = sp + 416|0;
 $5 = sp + 384|0;
 $6 = sp + 368|0;
 $7 = sp + 352|0;
 $8 = sp + 336|0;
 $9 = sp + 64|0;
 $Q = sp;
 $A = sp + 112|0;
 $B = sp + 272|0;
 $zeroV = sp + 96|0;
 $size = sp + 500|0;
 $closA = sp + 176|0;
 $closB = sp + 192|0;
 $sDist$sroa$1 = sp + 488|0;
 $closAA = sp + 208|0;
 $closBB = sp + 224|0;
 $support = sp + 240|0;
 $tempV = sp + 256|0;
 $$sroa$1155 = sp + 476|0;
 $$sroa$1117 = sp + 464|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAP32[$size>>2] = 0;
 $10 = Math_fround(HEAPF32[$a>>2]);
 $11 = (($a) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($a) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$b>>2]);
 $16 = (($b) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($b) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($10 - $15);
 $21 = Math_fround($12 - $17);
 $22 = Math_fround($14 - $19);
 $23 = Math_fround($20 * $20);
 $24 = Math_fround($21 * $21);
 $25 = Math_fround($23 + $24);
 $26 = Math_fround($22 * $22);
 $27 = Math_fround($25 + $26);
 $28 = $27 > Math_fround(0.0);
 HEAPF32[$1>>2] = $20;
 $29 = (($1) + 4|0);
 HEAPF32[$29>>2] = $21;
 $30 = (($1) + 8|0);
 HEAPF32[$30>>2] = $22;
 $31 = (($1) + 12|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $32 = (($0) + 4|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($0) + 8|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($0) + 12|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $b$a$i94 = $28 ? $1 : $0;
 $35 = Math_fround(HEAPF32[$b$a$i94>>2]);
 $$in1$i97 = (($b$a$i94) + 4|0);
 $36 = Math_fround(HEAPF32[$$in1$i97>>2]);
 $$in2$i99 = (($b$a$i94) + 8|0);
 $37 = Math_fround(HEAPF32[$$in2$i99>>2]);
 $38 = (($a) + 32|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($b) + 32|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = $39 > $41;
 $$$i = $42 ? $41 : $39;
 $43 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $44 = Math_fround($43 * $43);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $45 = (($a) + 96|0);
 $46 = (($a) + 100|0);
 $47 = (($a) + 104|0);
 $48 = (($a) + 108|0);
 $49 = (($a) + 112|0);
 $50 = (($a) + 116|0);
 $51 = (($a) + 120|0);
 $52 = (($a) + 124|0);
 $53 = (($a) + 128|0);
 $54 = (($a) + 132|0);
 $55 = (($a) + 136|0);
 $56 = (($a) + 140|0);
 $57 = (($3) + 4|0);
 $58 = (($3) + 8|0);
 $59 = (($3) + 12|0);
 $60 = (($2) + 4|0);
 $61 = (($2) + 8|0);
 $62 = (($2) + 12|0);
 $63 = (($5) + 4|0);
 $64 = (($5) + 8|0);
 $65 = (($5) + 12|0);
 $66 = (($4) + 4|0);
 $67 = (($4) + 8|0);
 $68 = (($4) + 12|0);
 $69 = (($b) + 144|0);
 $70 = (($b) + 144|0);
 $71 = (($b) + 148|0);
 $72 = (($b) + 152|0);
 $73 = (($2) + 4|0);
 $74 = (($2) + 8|0);
 $75 = (($2) + 12|0);
 $76 = (($support) + 4|0);
 $77 = (($support) + 8|0);
 $78 = (($support) + 12|0);
 $79 = (($tempV) + 4|0);
 $80 = (($tempV) + 8|0);
 $81 = (($closA) + 4|0);
 $82 = (($closA) + 8|0);
 $83 = (($closA) + 12|0);
 $84 = (($closB) + 4|0);
 $85 = (($closB) + 8|0);
 $86 = (($closB) + 12|0);
 $87 = (($Q) + 4|0);
 $88 = (($Q) + 8|0);
 $89 = (($A) + 4|0);
 $90 = (($A) + 8|0);
 $91 = (($B) + 4|0);
 $92 = (($B) + 8|0);
 $93 = (($tempV) + 12|0);
 $94 = (($Q) + 16|0);
 $100 = $37;$159 = Math_fround(3.40282346638528859812E+38);$96 = $35;$98 = $36;
 while(1) {
  ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closBB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closBB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closBB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closBB+12>>2]=HEAP32[$closB+12>>2]|0;
  $95 = Math_fround(-$96);
  $97 = Math_fround(-$98);
  $99 = Math_fround(-$100);
  $101 = Math_fround(HEAPF32[$45>>2]);
  $102 = Math_fround(HEAPF32[$46>>2]);
  $103 = Math_fround(HEAPF32[$47>>2]);
  $104 = Math_fround(HEAPF32[$48>>2]);
  $105 = Math_fround(HEAPF32[$49>>2]);
  $106 = Math_fround(HEAPF32[$50>>2]);
  $107 = Math_fround(HEAPF32[$51>>2]);
  $108 = Math_fround(HEAPF32[$52>>2]);
  $109 = Math_fround(HEAPF32[$53>>2]);
  $110 = Math_fround(HEAPF32[$54>>2]);
  $111 = Math_fround(HEAPF32[$55>>2]);
  $112 = Math_fround(HEAPF32[$56>>2]);
  $113 = Math_fround($101 * $95);
  $114 = Math_fround($102 * $97);
  $115 = Math_fround($113 + $114);
  $116 = Math_fround($103 * $99);
  $117 = Math_fround($115 + $116);
  $118 = Math_fround($105 * $95);
  $119 = Math_fround($106 * $97);
  $120 = Math_fround($118 + $119);
  $121 = Math_fround($107 * $99);
  $122 = Math_fround($120 + $121);
  $123 = Math_fround($109 * $95);
  $124 = Math_fround($110 * $97);
  $125 = Math_fround($123 + $124);
  $126 = Math_fround($111 * $99);
  $127 = Math_fround($125 + $126);
  $128 = $117 > $122;
  if ($128) {
   $129 = $117 > $127;
   $phitmp164$i = $129 ? $5 : $4;
   $135 = $phitmp164$i;
  } else {
   $135 = $4;
  }
  $130 = $122 > $127;
  HEAPF32[$3>>2] = $105;
  HEAPF32[$57>>2] = $106;
  HEAPF32[$58>>2] = $107;
  HEAPF32[$59>>2] = $108;
  HEAPF32[$2>>2] = $109;
  HEAPF32[$60>>2] = $110;
  HEAPF32[$61>>2] = $111;
  HEAPF32[$62>>2] = $112;
  $b$a$i16$i = $130 ? $3 : $2;
  $131 = Math_fround(HEAPF32[$b$a$i16$i>>2]);
  $$in1$i19$i = (($b$a$i16$i) + 4|0);
  $132 = Math_fround(HEAPF32[$$in1$i19$i>>2]);
  $$in2$i21$i = (($b$a$i16$i) + 8|0);
  $133 = Math_fround(HEAPF32[$$in2$i21$i>>2]);
  HEAPF32[$5>>2] = $101;
  HEAPF32[$63>>2] = $102;
  HEAPF32[$64>>2] = $103;
  HEAPF32[$65>>2] = $104;
  HEAPF32[$4>>2] = $131;
  HEAPF32[$66>>2] = $132;
  HEAPF32[$67>>2] = $133;
  HEAPF32[$68>>2] = Math_fround(0.0);
  $134 = Math_fround(HEAPF32[$135>>2]);
  $$in1$i$i72 = (($135) + 4|0);
  $136 = Math_fround(HEAPF32[$$in1$i$i72>>2]);
  $$in2$i$i73 = (($135) + 8|0);
  $137 = Math_fround(HEAPF32[$$in2$i$i73>>2]);
  $138 = $96 > Math_fround(0.0);
  $139 = $98 > Math_fround(0.0);
  $140 = $100 > Math_fround(0.0);
  ;HEAP32[$3+0>>2]=HEAP32[$69+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$69+12>>2]|0;
  $141 = Math_fround(HEAPF32[$70>>2]);
  $142 = Math_fround(HEAPF32[$71>>2]);
  $143 = Math_fround(HEAPF32[$72>>2]);
  $144 = Math_fround(-$141);
  $145 = Math_fround(-$142);
  $146 = Math_fround(-$143);
  HEAPF32[$2>>2] = $144;
  HEAPF32[$73>>2] = $145;
  HEAPF32[$74>>2] = $146;
  HEAPF32[$75>>2] = Math_fround(0.0);
  $b$a$i$i = $138 ? $3 : $2;
  $147 = Math_fround(HEAPF32[$b$a$i$i>>2]);
  $a$pn3$i$i = $139 ? $3 : $2;
  $$in1$i$i = (($a$pn3$i$i) + 4|0);
  $148 = Math_fround(HEAPF32[$$in1$i$i>>2]);
  $b$a5$i$i = $140 ? $3 : $2;
  $$in2$i$i = (($b$a5$i$i) + 8|0);
  $149 = Math_fround(HEAPF32[$$in2$i$i>>2]);
  $150 = Math_fround($134 - $147);
  $151 = Math_fround($136 - $148);
  $152 = Math_fround($137 - $149);
  HEAPF32[$support>>2] = $150;
  HEAPF32[$76>>2] = $151;
  HEAPF32[$77>>2] = $152;
  HEAPF32[$78>>2] = Math_fround(0.0);
  $153 = Math_fround($96 * $150);
  $154 = Math_fround($98 * $151);
  $155 = Math_fround($153 + $154);
  $156 = Math_fround($100 * $152);
  $157 = Math_fround($155 + $156);
  $158 = Math_fround($159 - $157);
  $160 = HEAP32[$size>>2]|0;
  $161 = (($A) + ($160<<4)|0);
  HEAPF32[$161>>2] = $134;
  $162 = ((($A) + ($160<<4)|0) + 4|0);
  HEAPF32[$162>>2] = $136;
  $163 = ((($A) + ($160<<4)|0) + 8|0);
  HEAPF32[$163>>2] = $137;
  $164 = ((($A) + ($160<<4)|0) + 12|0);
  HEAPF32[$164>>2] = Math_fround(0.0);
  $165 = (($B) + ($160<<4)|0);
  HEAPF32[$165>>2] = $147;
  $166 = ((($B) + ($160<<4)|0) + 4|0);
  HEAPF32[$166>>2] = $148;
  $167 = ((($B) + ($160<<4)|0) + 8|0);
  HEAPF32[$167>>2] = $149;
  $168 = ((($B) + ($160<<4)|0) + 12|0);
  HEAPF32[$168>>2] = Math_fround(0.0);
  $169 = (($160) + 1)|0;
  HEAP32[$size>>2] = $169;
  $170 = (($Q) + ($160<<4)|0);
  ;HEAP32[$170+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$170+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$170+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$170+12>>2]=HEAP32[$support+12>>2]|0;
  $171 = Math_fround($159 * Math_fround(2.24999996135011315346E-4));
  $172 = $171 > $158;
  if ($172) {
   label = 5;
   break;
  }
  do {
   if ((($160|0) == 0)) {
    HEAPF32[$closA>>2] = $134;
    HEAPF32[$81>>2] = $136;
    HEAPF32[$82>>2] = $137;
    HEAPF32[$83>>2] = Math_fround(0.0);
    HEAPF32[$closB>>2] = $147;
    HEAPF32[$84>>2] = $148;
    HEAPF32[$85>>2] = $149;
    HEAPF32[$86>>2] = Math_fround(0.0);
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   } else if ((($160|0) == 1)) {
    $196 = Math_fround(HEAPF32[$Q>>2]);
    $197 = Math_fround(HEAPF32[$87>>2]);
    $198 = Math_fround(HEAPF32[$88>>2]);
    $199 = Math_fround($150 - $196);
    $200 = Math_fround($151 - $197);
    $201 = Math_fround($152 - $198);
    $202 = Math_fround($199 * $199);
    $203 = Math_fround($200 * $200);
    $204 = Math_fround($202 + $203);
    $205 = Math_fround($201 * $201);
    $206 = Math_fround($204 + $205);
    $207 = $206 == Math_fround(0.0);
    if ($207) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $208 = Math_fround($197 * $200);
     $209 = Math_fround(-$208);
     $210 = Math_fround($196 * $199);
     $211 = Math_fround($209 - $210);
     $212 = Math_fround($198 * $201);
     $213 = Math_fround($211 - $212);
     $214 = Math_fround(HEAPF32[$A>>2]);
     $215 = Math_fround(HEAPF32[$89>>2]);
     $216 = Math_fround(HEAPF32[$90>>2]);
     $217 = Math_fround($134 - $214);
     $218 = Math_fround($136 - $215);
     $219 = Math_fround($137 - $216);
     $220 = Math_fround(HEAPF32[$B>>2]);
     $221 = Math_fround(HEAPF32[$91>>2]);
     $222 = Math_fround(HEAPF32[$92>>2]);
     $223 = Math_fround($147 - $220);
     $224 = Math_fround($148 - $221);
     $225 = Math_fround($149 - $222);
     $226 = Math_fround($213 / $206);
     $227 = $226 > Math_fround(1.0);
     $$$i$i$i = $227 ? Math_fround(1.0) : $226;
     $228 = $$$i$i$i > Math_fround(0.0);
     $$$i8$i$i = $228 ? $$$i$i$i : Math_fround(0.0);
     $229 = Math_fround($217 * $$$i8$i$i);
     $230 = Math_fround($218 * $$$i8$i$i);
     $231 = Math_fround($219 * $$$i8$i$i);
     $232 = Math_fround($214 + $229);
     $233 = Math_fround($215 + $230);
     $234 = Math_fround($216 + $231);
     $235 = Math_fround($223 * $$$i8$i$i);
     $236 = Math_fround($224 * $$$i8$i$i);
     $237 = Math_fround($225 * $$$i8$i$i);
     $238 = Math_fround($220 + $235);
     $239 = Math_fround($221 + $236);
     $240 = Math_fround($222 + $237);
     HEAPF32[$closA>>2] = $232;
     HEAPF32[$81>>2] = $233;
     HEAPF32[$82>>2] = $234;
     HEAPF32[$83>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $238;
     HEAPF32[$84>>2] = $239;
     HEAPF32[$85>>2] = $240;
     HEAPF32[$86>>2] = Math_fround(0.0);
     $241 = Math_fround($232 - $238);
     $242 = Math_fround($233 - $239);
     $243 = Math_fround($234 - $240);
     HEAPF32[$tempV>>2] = $241;
     HEAPF32[$79>>2] = $242;
     HEAPF32[$80>>2] = $243;
     HEAPF32[$93>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($160|0) == 2)) {
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$94,$support,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($160|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
   }
  } while(0);
  $244 = Math_fround(HEAPF32[$tempV>>2]);
  $245 = Math_fround(HEAPF32[$79>>2]);
  $246 = Math_fround(HEAPF32[$80>>2]);
  $247 = Math_fround($244 * $244);
  $248 = Math_fround($245 * $245);
  $249 = Math_fround($247 + $248);
  $250 = Math_fround($246 * $246);
  $251 = Math_fround($249 + $250);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1155+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1155+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1155+8>>2]|0;
  $252 = $159 > $251;
  $$not = !($251 > $44);
  $$not425 = $252 ^ 1;
  $brmerge = $$not | $$not425;
  if ($brmerge) {
   label = 15;
   break;
  } else {
   $100 = $246;$159 = $251;$96 = $244;$98 = $245;
  }
 }
 if ((label|0) == 5) {
  $173 = Math_fround(HEAPF32[$closB>>2]);
  $174 = Math_fround(HEAPF32[$84>>2]);
  $175 = Math_fround(HEAPF32[$85>>2]);
  $176 = Math_fround(HEAPF32[$closA>>2]);
  $177 = Math_fround(HEAPF32[$81>>2]);
  $178 = Math_fround(HEAPF32[$82>>2]);
  $179 = Math_fround($173 - $176);
  $180 = Math_fround($174 - $177);
  $181 = Math_fround($175 - $178);
  $182 = Math_fround($179 * $179);
  $183 = Math_fround($180 * $180);
  $184 = Math_fround($182 + $183);
  $185 = Math_fround($181 * $181);
  $186 = Math_fround($184 + $185);
  $187 = (Math_fround(Math_sqrt((Math_fround($186)))));
  $188 = Math_fround(Math_fround(1.0) / $187);
  $189 = Math_fround($179 * $188);
  $190 = Math_fround($180 * $188);
  $191 = Math_fround($181 * $188);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  HEAPF32[$sqDist>>2] = $159;
  $192 = (($sqDist) + 4|0);
  ;HEAP32[$192+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$192+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$192+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
  HEAPF32[$normal>>2] = $189;
  $193 = (($normal) + 4|0);
  HEAPF32[$193>>2] = $190;
  $194 = (($normal) + 8|0);
  HEAPF32[$194>>2] = $191;
  $195 = (($normal) + 12|0);
  HEAPF32[$195>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 15) {
  ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$6+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$closAA+12>>2]|0;
  $b$a$i26 = $252 ? $7 : $6;
  $253 = Math_fround(HEAPF32[$b$a$i26>>2]);
  $$in1$i29 = (($b$a$i26) + 4|0);
  $254 = Math_fround(HEAPF32[$$in1$i29>>2]);
  $$in2$i31 = (($b$a$i26) + 8|0);
  $255 = Math_fround(HEAPF32[$$in2$i31>>2]);
  HEAPF32[$closA>>2] = $253;
  HEAPF32[$81>>2] = $254;
  HEAPF32[$82>>2] = $255;
  HEAPF32[$83>>2] = Math_fround(0.0);
  ;HEAP32[$9+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$closB+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$closBB+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closBB+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closBB+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closBB+12>>2]|0;
  $b$a$i18 = $252 ? $9 : $8;
  $256 = Math_fround(HEAPF32[$b$a$i18>>2]);
  $$in1$i = (($b$a$i18) + 4|0);
  $257 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i18) + 8|0);
  $258 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$closB>>2] = $256;
  HEAPF32[$84>>2] = $257;
  HEAPF32[$85>>2] = $258;
  HEAPF32[$86>>2] = Math_fround(0.0);
  ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
  ;HEAP32[$closestB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$closB+12>>2]|0;
  $259 = Math_fround($256 - $253);
  $260 = Math_fround($257 - $254);
  $261 = Math_fround($258 - $255);
  $262 = Math_fround($259 * $259);
  $263 = Math_fround($260 * $260);
  $264 = Math_fround($262 + $263);
  $265 = Math_fround($261 * $261);
  $266 = Math_fround($264 + $265);
  $267 = (Math_fround(Math_sqrt((Math_fround($266)))));
  $268 = Math_fround(Math_fround(1.0) / $267);
  $269 = Math_fround($259 * $268);
  $270 = Math_fround($260 * $268);
  $271 = Math_fround($261 * $268);
  HEAPF32[$normal>>2] = $269;
  $272 = (($normal) + 4|0);
  HEAPF32[$272>>2] = $270;
  $273 = (($normal) + 8|0);
  HEAPF32[$273>>2] = $271;
  $274 = (($normal) + 12|0);
  HEAPF32[$274>>2] = Math_fround(0.0);
  $275 = $252 ? $251 : $159;
  HEAPF32[$sqDist>>2] = $275;
  $276 = (($sqDist) + 4|0);
  ;HEAP32[$276+0>>2]=HEAP32[$$sroa$1117+0>>2]|0;HEAP32[$276+4>>2]=HEAP32[$$sroa$1117+4>>2]|0;HEAP32[$276+8>>2]=HEAP32[$$sroa$1117+8>>2]|0;
  $277 = $252 ? 1 : 3;
  $$0 = $277;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu22GJKRelativeTesselationERKNS0_4BoxVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERNS8_5Vec3VESG_SG_RSC_($a,$b,$aToB,$sqTolerance,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $sqTolerance = $sqTolerance|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $map0$i = 0, $map1$i = 0, $status$1$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $map0$i = sp + 8|0;
 $map1$i = sp;
 $0 = (__ZN5physx2Gu11gjkRelativeINS0_4BoxVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERNSB_5Vec3VESG_SG_RNSB_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist)|0);
 $1 = ($0|0)==(1);
 if ($1) {
  $status$1$i = 1;
  STACKTOP = sp;return ($status$1$i|0);
 }
 $2 = Math_fround(HEAPF32[$sqTolerance>>2]);
 $3 = Math_fround(HEAPF32[$sqDist>>2]);
 $4 = $2 > $3;
 if ($4) {
  $status$1$i = 1;
  STACKTOP = sp;return ($status$1$i|0);
 }
 $5 = ($0|0)==(3);
 $6 = $5 ? 3 : 0;
 if (!($5)) {
  $status$1$i = $6;
  STACKTOP = sp;return ($status$1$i|0);
 }
 HEAP32[$map0$i>>2] = ((551392 + 8|0));
 $7 = (($map0$i) + 4|0);
 HEAP32[$7>>2] = $a;
 $8 = (($map0$i) + 8|0);
 HEAP32[$8>>2] = $aToB;
 HEAP32[$map1$i>>2] = ((551328 + 8|0));
 $9 = (($map1$i) + 4|0);
 HEAP32[$9>>2] = $b;
 $10 = (($aToB) + 48|0);
 $11 = (__ZN5physx2Gu19gjkRelativeFallbackERKNS0_7ConvexVES3_PNS0_10SupportMapES5_RKNS_6shdfnd3aos5Vec3VERS8_SB_SB_RNS7_6FloatVE($a,$b,$map0$i,$map1$i,$10,$closestA,$closestB,$normal,$sqDist)|0);
 $12 = ($11|0)==(3);
 if (!($12)) {
  $status$1$i = $11;
  STACKTOP = sp;return ($status$1$i|0);
 }
 $13 = Math_fround(HEAPF32[$sqTolerance>>2]);
 $14 = Math_fround(HEAPF32[$sqDist>>2]);
 $15 = $13 > $14;
 $16 = $15&1;
 $status$1$i = $16;
 STACKTOP = sp;return ($status$1$i|0);
}
function __ZN5physx2Gu22GJKRelativeTesselationERKNS0_11ConvexHullVES3_RKNS_6shdfnd3aos15PsMatTransformVERKNS5_6FloatVERNS5_5Vec3VESD_SD_RS9_($a,$b,$aToB,$sqTolerance,$closestA,$closestB,$normal,$sqDist) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $sqTolerance = $sqTolerance|0;
 $closestA = $closestA|0;
 $closestB = $closestB|0;
 $normal = $normal|0;
 $sqDist = $sqDist|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $map0$i = 0, $map1$i = 0, $status$1$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $map0$i = sp + 8|0;
 $map1$i = sp;
 $0 = (__ZN5physx2Gu11gjkRelativeINS0_11ConvexHullVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERNSA_5Vec3VESF_SF_RNSA_6FloatVE($a,$b,$aToB,$closestA,$closestB,$normal,$sqDist)|0);
 $1 = ($0|0)==(1);
 if ($1) {
  $status$1$i = 1;
  STACKTOP = sp;return ($status$1$i|0);
 }
 $2 = Math_fround(HEAPF32[$sqTolerance>>2]);
 $3 = Math_fround(HEAPF32[$sqDist>>2]);
 $4 = $2 > $3;
 if ($4) {
  $status$1$i = 1;
  STACKTOP = sp;return ($status$1$i|0);
 }
 $5 = ($0|0)==(3);
 $6 = $5 ? 3 : 0;
 if (!($5)) {
  $status$1$i = $6;
  STACKTOP = sp;return ($status$1$i|0);
 }
 HEAP32[$map0$i>>2] = ((551360 + 8|0));
 $7 = (($map0$i) + 4|0);
 HEAP32[$7>>2] = $a;
 $8 = (($map0$i) + 8|0);
 HEAP32[$8>>2] = $aToB;
 HEAP32[$map1$i>>2] = ((551328 + 8|0));
 $9 = (($map1$i) + 4|0);
 HEAP32[$9>>2] = $b;
 $10 = (($aToB) + 48|0);
 $11 = (__ZN5physx2Gu19gjkRelativeFallbackERKNS0_7ConvexVES3_PNS0_10SupportMapES5_RKNS_6shdfnd3aos5Vec3VERS8_SB_SB_RNS7_6FloatVE($a,$b,$map0$i,$map1$i,$10,$closestA,$closestB,$normal,$sqDist)|0);
 $12 = ($11|0)==(3);
 if (!($12)) {
  $status$1$i = $11;
  STACKTOP = sp;return ($status$1$i|0);
 }
 $13 = Math_fround(HEAPF32[$sqTolerance>>2]);
 $14 = Math_fround(HEAPF32[$sqDist>>2]);
 $15 = $13 > $14;
 $16 = $15&1;
 $status$1$i = $16;
 STACKTOP = sp;return ($status$1$i|0);
}
function __ZN5physx2Gu15GJKLocalRayCastERNS0_9TriangleVERNS0_4BoxVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu15gjkLocalRayCastINS0_9TriangleVENS0_4BoxVES2_NS0_10ShrunkBoxVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNSA_5Vec3VESG_RSB_RSE_SI_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu15gjkLocalRayCastINS0_9TriangleVENS0_4BoxVES2_NS0_10ShrunkBoxVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNSA_5Vec3VESG_RSB_RSE_SI_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 128|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu16_gjkLocalRayCastINS0_9TriangleVENS0_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VESF_RSA_RSD_SH_f($a,$b,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAPF32[$sDist>>2] = Math_fround(0.0);
  $9 = (($sDist) + 4|0);
  ;HEAP32[$9+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  HEAP8[$size>>0] = 0;
  $10 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_9TriangleVENS0_10ShrunkBoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size,0)|0);
  do {
   if ((($10|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else if ((($10|0) == 6)) {
    $11 = (($supportMap) + 4|0);
    HEAP8[$11>>0] = 0;
    HEAP32[$supportMap>>2] = ((550960 + 8|0));
    $12 = (($supportMap) + 8|0);
    HEAP32[$12>>2] = $a;
    $13 = (($supportMap) + 12|0);
    HEAP32[$13>>2] = $b;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     ;HEAP32[$9+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $38 = Math_fround(HEAPF32[$sDist>>2]);
  $39 = $38 < Math_fround(0.0);
  $$$i = $39 ? $38 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $40 = (($lambda) + 4|0);
  ;HEAP32[$40+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15GJKLocalRayCastERNS0_9TriangleVERNS0_11ConvexHullVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu15gjkLocalRayCastINS0_9TriangleVENS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNSA_5Vec3VESG_RSB_RSE_SI_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu15gjkLocalRayCastINS0_9TriangleVENS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNSA_5Vec3VESG_RSB_RSE_SI_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 128|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu16_gjkLocalRayCastINS0_9TriangleVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VESF_RSA_RSD_SH_f($a,$b,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAPF32[$sDist>>2] = Math_fround(0.0);
  $9 = (($sDist) + 4|0);
  ;HEAP32[$9+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  HEAP8[$size>>0] = 0;
  $10 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_9TriangleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size,0)|0);
  do {
   if ((($10|0) == 6)) {
    $11 = (($supportMap) + 4|0);
    HEAP8[$11>>0] = 0;
    HEAP32[$supportMap>>2] = ((550928 + 8|0));
    $12 = (($supportMap) + 8|0);
    HEAP32[$12>>2] = $a;
    $13 = (($supportMap) + 12|0);
    HEAP32[$13>>2] = $b;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     ;HEAP32[$9+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else if ((($10|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $38 = Math_fround(HEAPF32[$sDist>>2]);
  $39 = $38 < Math_fround(0.0);
  $$$i = $39 ? $38 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $40 = (($lambda) + 4|0);
  ;HEAP32[$40+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15GJKLocalRayCastERNS0_8CapsuleVERNS0_4BoxVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu15gjkLocalRayCastINS0_8CapsuleVENS0_4BoxVES2_NS0_10ShrunkBoxVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNSA_5Vec3VESG_RSB_RSE_SI_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu15gjkLocalRayCastINS0_8CapsuleVENS0_4BoxVES2_NS0_10ShrunkBoxVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNSA_5Vec3VESG_RSB_RSE_SI_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 128|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu16_gjkLocalRayCastINS0_8CapsuleVENS0_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VESF_RSA_RSD_SH_f($a,$b,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAPF32[$sDist>>2] = Math_fround(0.0);
  $9 = (($sDist) + 4|0);
  ;HEAP32[$9+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  HEAP8[$size>>0] = 0;
  $10 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_10ShrunkBoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size,0)|0);
  do {
   if ((($10|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else if ((($10|0) == 6)) {
    $11 = (($supportMap) + 4|0);
    HEAP8[$11>>0] = 0;
    HEAP32[$supportMap>>2] = ((551024 + 8|0));
    $12 = (($supportMap) + 8|0);
    HEAP32[$12>>2] = $a;
    $13 = (($supportMap) + 12|0);
    HEAP32[$13>>2] = $b;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     ;HEAP32[$9+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $38 = Math_fround(HEAPF32[$sDist>>2]);
  $39 = $38 < Math_fround(0.0);
  $$$i = $39 ? $38 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $40 = (($lambda) + 4|0);
  ;HEAP32[$40+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15GJKLocalRayCastERNS0_8CapsuleVERNS0_11ConvexHullVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu15gjkLocalRayCastINS0_8CapsuleVENS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNSA_5Vec3VESG_RSB_RSE_SI_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu15gjkLocalRayCastINS0_8CapsuleVENS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNSA_5Vec3VESG_RSB_RSE_SI_fb($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 128|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu16_gjkLocalRayCastINS0_8CapsuleVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VESF_RSA_RSD_SH_f($a,$b,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAPF32[$sDist>>2] = Math_fround(0.0);
  $9 = (($sDist) + 4|0);
  ;HEAP32[$9+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
  HEAP8[$size>>0] = 0;
  $10 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size,0)|0);
  do {
   if ((($10|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else if ((($10|0) == 6)) {
    $11 = (($supportMap) + 4|0);
    HEAP8[$11>>0] = 0;
    HEAP32[$supportMap>>2] = ((550992 + 8|0));
    $12 = (($supportMap) + 8|0);
    HEAP32[$12>>2] = $a;
    $13 = (($supportMap) + 12|0);
    HEAP32[$13>>2] = $b;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     ;HEAP32[$9+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $38 = Math_fround(HEAPF32[$sDist>>2]);
  $39 = $38 < Math_fround(0.0);
  $$$i = $39 ? $38 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $40 = (($lambda) + 4|0);
  ;HEAP32[$40+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_9TriangleVERNS0_4BoxVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_9TriangleVENS0_4BoxVES2_NS0_10ShrunkBoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERKNSA_5Vec3VESJ_RSE_RSH_SL_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_9TriangleVENS0_4BoxVES2_NS0_10ShrunkBoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERKNSA_5Vec3VESJ_RSE_RSH_SL_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_9TriangleVENS0_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_9TriangleVENS0_10ShrunkBoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((551296 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_9TriangleVERNS0_8CapsuleVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_9TriangleVENS0_8CapsuleVES2_S3_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_9TriangleVENS0_8CapsuleVES2_S3_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_9TriangleVENS0_8CapsuleVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_9TriangleVENS0_8CapsuleVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((551264 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_9TriangleVERNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_9TriangleVENS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERKNSA_5Vec3VESJ_RSE_RSH_SL_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_9TriangleVENS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERKNSA_5Vec3VESJ_RSE_RSH_SL_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_9TriangleVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_9TriangleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((551232 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_8CapsuleVES2_RKNS_6shdfnd3aos15PsMatTransformVERKNS4_6FloatVERKNS4_5Vec3VESD_RS8_RSB_SF_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_8CapsuleVES2_S2_S2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERKNS8_5Vec3VESH_RSC_RSF_SJ_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_8CapsuleVES2_S2_S2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERKNS8_5Vec3VESH_RSC_RSF_SJ_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_8CapsuleVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERKNS8_5Vec3VESH_RSC_RSF_SJ_f($a,$b,$aToB,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_8CapsuleVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((551200 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_8CapsuleVERNS0_4BoxVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_8CapsuleVENS0_4BoxVES2_NS0_10ShrunkBoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERKNSA_5Vec3VESJ_RSE_RSH_SL_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_8CapsuleVENS0_4BoxVES2_NS0_10ShrunkBoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERKNSA_5Vec3VESJ_RSE_RSH_SL_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_8CapsuleVENS0_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_8CapsuleVENS0_10ShrunkBoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((551168 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_8CapsuleVERNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_8CapsuleVENS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERKNSA_5Vec3VESJ_RSE_RSH_SL_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_8CapsuleVENS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERKNSA_5Vec3VESJ_RSE_RSH_SL_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_8CapsuleVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_8CapsuleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((551136 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_4BoxVES2_RKNS_6shdfnd3aos15PsMatTransformVERKNS4_6FloatVERKNS4_5Vec3VESD_RS8_RSB_SF_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_4BoxVES2_NS0_10ShrunkBoxVES3_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_4BoxVES2_NS0_10ShrunkBoxVES3_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_4BoxVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERKNS8_5Vec3VESH_RSC_RSF_SJ_f($a,$b,$aToB,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_10ShrunkBoxVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((550896 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_4BoxVERNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS6_6FloatVERKNS6_5Vec3VESF_RSA_RSD_SH_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_4BoxVENS0_11ConvexHullVENS0_10ShrunkBoxVENS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERKNSB_5Vec3VESK_RSF_RSI_SM_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_4BoxVENS0_11ConvexHullVENS0_10ShrunkBoxVENS0_17ShrunkConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERKNSB_5Vec3VESK_RSF_RSI_SM_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_4BoxVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,0,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_10ShrunkBoxVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((550864 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18GJKRelativeRayCastERNS0_11ConvexHullVES2_RKNS_6shdfnd3aos15PsMatTransformVERKNS4_6FloatVERKNS4_5Vec3VESD_RS8_RSB_SF_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $inflation = Math_fround($inflation);
 $initialOverlap = $initialOverlap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5physx2Gu18gjkRelativeRayCastINS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVES3_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$inflation,$initialOverlap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx2Gu18gjkRelativeRayCastINS0_11ConvexHullVES2_NS0_17ShrunkConvexHullVES3_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_fb($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation,$initialOverlap) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 $initialOverlap = $initialOverlap|0;
 var $$$i = Math_fround(0), $$0 = 0, $$off = 0, $$sroa$1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_lambda = 0, $aIndices = 0, $bIndices = 0, $brmerge = 0, $closA = 0, $closAA = 0, $closBB = 0, $contactDist = 0, $initialOverlap$not = 0, $norm = 0, $sDist = 0, $size = 0, $supportMap = 0, $zero$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $closA = sp + 16|0;
 $norm = sp + 96|0;
 $_lambda = sp + 80|0;
 $zero$sroa$1 = sp + 144|0;
 $contactDist = sp + 48|0;
 $closAA = sp + 32|0;
 $closBB = sp + 64|0;
 $sDist = sp;
 $aIndices = sp + 164|0;
 $bIndices = sp + 160|0;
 $size = sp + 156|0;
 $supportMap = sp + 124|0;
 $$sroa$1 = sp + 112|0;
 $0 = (__ZN5physx2Gu19_gjkRelativeRayCastINS0_11ConvexHullVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERKNS8_5Vec3VESH_RSC_RSF_SJ_f($a,$b,$aToB,$initialLambda,$s,$r,$_lambda,$norm,$closA,$_inflation)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$lambda+0>>2]=HEAP32[$_lambda+0>>2]|0;HEAP32[$lambda+4>>2]=HEAP32[$_lambda+4>>2]|0;HEAP32[$lambda+8>>2]=HEAP32[$_lambda+8>>2]|0;HEAP32[$lambda+12>>2]=HEAP32[$_lambda+12>>2]|0;
 $1 = Math_fround(HEAPF32[$_lambda>>2]);
 $2 = $1 != Math_fround(0.0);
 $initialOverlap$not = $initialOverlap ^ 1;
 $brmerge = $2 | $initialOverlap$not;
 if (!($brmerge)) {
  $3 = (($a) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($b) + 16|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  $8 = Math_fround($7 * Math_fround(100.0));
  HEAPF32[$contactDist>>2] = $8;
  HEAP8[$size>>0] = 0;
  $9 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_17ShrunkConvexHullVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($a,$b,$aToB,$contactDist,$closAA,$closBB,$norm,$sDist,$aIndices,$bIndices,$size)|0);
  do {
   if ((($9|0) == 6)) {
    $10 = (($supportMap) + 4|0);
    HEAP8[$10>>0] = 0;
    HEAP32[$supportMap>>2] = ((550832 + 8|0));
    $11 = (($supportMap) + 8|0);
    HEAP32[$11>>2] = $a;
    $12 = (($supportMap) + 12|0);
    HEAP32[$12>>2] = $b;
    $13 = (($supportMap) + 16|0);
    HEAP32[$13>>2] = $aToB;
    $14 = HEAP8[$size>>0]|0;
    $15 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($a,$b,$supportMap,$aIndices,$bIndices,$14,$closAA,$closBB,$norm,$sDist,0)|0);
    $$off = (($15) + -5)|0;
    $16 = ($$off>>>0)<(2);
    if ($16) {
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     break;
    } else {
     $17 = Math_fround(HEAPF32[$r>>2]);
     $18 = (($r) + 4|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = (($r) + 8|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = Math_fround($17 * $17);
     $23 = Math_fround($19 * $19);
     $24 = Math_fround($22 + $23);
     $25 = Math_fround($21 * $21);
     $26 = Math_fround($24 + $25);
     $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
     $28 = Math_fround(Math_fround(1.0) / $27);
     $29 = Math_fround($17 * $28);
     $30 = Math_fround(-$29);
     $31 = Math_fround($19 * $28);
     $32 = Math_fround(-$31);
     $33 = Math_fround($21 * $28);
     $34 = Math_fround(-$33);
     HEAPF32[$norm>>2] = $30;
     $35 = (($norm) + 4|0);
     HEAPF32[$35>>2] = $32;
     $36 = (($norm) + 8|0);
     HEAPF32[$36>>2] = $34;
     $37 = (($norm) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
     HEAPF32[$sDist>>2] = Math_fround(0.0);
     $38 = (($sDist) + 4|0);
     ;HEAP32[$38+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
     break;
    }
   } else if ((($9|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   } else {
    ;HEAP32[$closA+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$closAA+12>>2]|0;
   }
  } while(0);
  $39 = Math_fround(HEAPF32[$sDist>>2]);
  $40 = $39 < Math_fround(0.0);
  $$$i = $40 ? $39 : Math_fround(0.0);
  HEAPF32[$lambda>>2] = $$$i;
  $41 = (($lambda) + 4|0);
  ;HEAP32[$41+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$norm+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$norm+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$norm+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$norm+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_11ConvexHullVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERKNS8_5Vec3VESH_RSC_RSF_SJ_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i206 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i208 = 0, $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa898 = Math_fround(0), $$lcssa900 = Math_fround(0), $$lcssa902 = Math_fround(0), $$lcssa904 = Math_fround(0), $$lcssa906 = Math_fround(0), $$lcssa908 = Math_fround(0), $$lcssa910 = Math_fround(0);
 var $$lcssa912 = Math_fround(0), $$lcssa914 = 0, $$lcssa916 = Math_fround(0), $$lcssa918 = Math_fround(0), $$lcssa920 = Math_fround(0), $$pre = Math_fround(0), $$pre954 = Math_fround(0), $$pre955 = Math_fround(0), $$pre956 = Math_fround(0), $$sroa$1314 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0);
 var $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0);
 var $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0);
 var $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0;
 var $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0);
 var $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0);
 var $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0);
 var $396 = 0, $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0);
 var $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0);
 var $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0);
 var $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0);
 var $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = 0, $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0);
 var $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = 0, $525 = 0, $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0);
 var $54 = Math_fround(0), $540 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_dir$i$i183 = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $b$a$i = 0, $b$a$i18 = 0, $b$a$i203 = 0;
 var $b$a5$i = 0, $closA = 0, $closB = 0, $initialSearchDir = 0, $initialSupportB = 0, $maxPoint$i$i184 = 0, $nvNorm = 0, $phitmp = 0, $phitmp891 = 0, $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 336|0;
 $1 = sp + 496|0;
 $_dir$i$i183 = sp + 352|0;
 $maxPoint$i$i184 = sp + 368|0;
 $2 = sp + 384|0;
 $3 = sp + 400|0;
 $4 = sp + 432|0;
 $5 = sp + 416|0;
 $6 = sp + 448|0;
 $7 = sp + 464|0;
 $zeroV = sp + 480|0;
 $zero$sroa$1 = sp + 528|0;
 $_lambda$sroa$1 = sp + 540|0;
 $size = sp + 524|0;
 $initialSearchDir = sp + 208|0;
 $initialSupportB = sp;
 $Q = sp + 16|0;
 $A = sp + 80|0;
 $B = sp + 144|0;
 $support = sp + 224|0;
 $closA = sp + 240|0;
 $closB = sp + 256|0;
 $nvNorm = sp + 272|0;
 $8 = sp + 288|0;
 $$sroa$1314 = sp + 512|0;
 $9 = sp + 304|0;
 $tempV = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $10 = Math_fround(HEAPF32[$r>>2]);
 $11 = (($r) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($r) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$s>>2]);
 $16 = (($s) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($s) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAP32[$size>>2] = 1;
 $20 = (($aToB) + 48|0);
 $21 = (($aToB) + 48|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($aToB) + 52|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 56|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($22 * $22);
 $28 = Math_fround($24 * $24);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = $31 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$20+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $33 = (($0) + 4|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($0) + 8|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($0) + 12|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $b$a$i203 = $32 ? $1 : $0;
 $36 = Math_fround(HEAPF32[$b$a$i203>>2]);
 $$in1$i206 = (($b$a$i203) + 4|0);
 $37 = Math_fround(HEAPF32[$$in1$i206>>2]);
 $$in2$i208 = (($b$a$i203) + 8|0);
 $38 = Math_fround(HEAPF32[$$in2$i208>>2]);
 $39 = Math_fround($36 * $36);
 $40 = Math_fround($37 * $37);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($38 * $38);
 $43 = Math_fround($41 + $42);
 $44 = (Math_fround(Math_sqrt((Math_fround($43)))));
 $45 = Math_fround(Math_fround(1.0) / $44);
 $46 = Math_fround($36 * $45);
 $47 = Math_fround($37 * $45);
 $48 = Math_fround($38 * $45);
 HEAPF32[$initialSearchDir>>2] = $46;
 $49 = (($initialSearchDir) + 4|0);
 HEAPF32[$49>>2] = $47;
 $50 = (($initialSearchDir) + 8|0);
 HEAPF32[$50>>2] = $48;
 $51 = (($initialSearchDir) + 12|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = Math_fround(-$46);
 $53 = Math_fround(-$47);
 $54 = Math_fround(-$48);
 $55 = Math_fround(HEAPF32[$aToB>>2]);
 $56 = Math_fround($55 * $52);
 $57 = (($aToB) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 * $53);
 $60 = Math_fround($56 + $59);
 $61 = (($aToB) + 8|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * $54);
 $64 = Math_fround($60 + $63);
 $65 = (($aToB) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $52);
 $68 = (($aToB) + 20|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 * $53);
 $71 = Math_fround($67 + $70);
 $72 = (($aToB) + 24|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 * $54);
 $75 = Math_fround($71 + $74);
 $76 = (($aToB) + 32|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 * $52);
 $79 = (($aToB) + 36|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($80 * $53);
 $82 = Math_fround($78 + $81);
 $83 = (($aToB) + 40|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 * $54);
 $86 = Math_fround($82 + $85);
 HEAPF32[$_dir$i$i183>>2] = $64;
 $87 = (($_dir$i$i183) + 4|0);
 HEAPF32[$87>>2] = $75;
 $88 = (($_dir$i$i183) + 8|0);
 HEAPF32[$88>>2] = $86;
 $89 = (($_dir$i$i183) + 12|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($maxPoint$i$i184,$a,$_dir$i$i183);
 $90 = Math_fround(HEAPF32[$21>>2]);
 $91 = Math_fround(HEAPF32[$23>>2]);
 $92 = Math_fround(HEAPF32[$25>>2]);
 $93 = Math_fround(HEAPF32[$maxPoint$i$i184>>2]);
 $94 = (($maxPoint$i$i184) + 4|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($maxPoint$i$i184) + 8|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround(HEAPF32[$aToB>>2]);
 $99 = Math_fround($93 * $98);
 $100 = Math_fround(HEAPF32[$65>>2]);
 $101 = Math_fround($95 * $100);
 $102 = Math_fround($99 + $101);
 $103 = Math_fround(HEAPF32[$76>>2]);
 $104 = Math_fround($97 * $103);
 $105 = Math_fround($102 + $104);
 $106 = Math_fround(HEAPF32[$57>>2]);
 $107 = Math_fround($93 * $106);
 $108 = Math_fround(HEAPF32[$68>>2]);
 $109 = Math_fround($95 * $108);
 $110 = Math_fround($107 + $109);
 $111 = Math_fround(HEAPF32[$79>>2]);
 $112 = Math_fround($97 * $111);
 $113 = Math_fround($110 + $112);
 $114 = Math_fround(HEAPF32[$61>>2]);
 $115 = Math_fround($93 * $114);
 $116 = Math_fround(HEAPF32[$72>>2]);
 $117 = Math_fround($95 * $116);
 $118 = Math_fround($115 + $117);
 $119 = Math_fround(HEAPF32[$83>>2]);
 $120 = Math_fround($97 * $119);
 $121 = Math_fround($118 + $120);
 $122 = Math_fround($90 + $105);
 $123 = Math_fround($91 + $113);
 $124 = Math_fround($92 + $121);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($initialSupportB,$b,$initialSearchDir);
 $125 = Math_fround(HEAPF32[$initialSupportB>>2]);
 $126 = (($initialSupportB) + 4|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($initialSupportB) + 8|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($122 - $125);
 $131 = Math_fround($123 - $127);
 $132 = Math_fround($124 - $129);
 HEAPF32[$Q>>2] = $130;
 $133 = (($Q) + 4|0);
 HEAPF32[$133>>2] = $131;
 $134 = (($Q) + 8|0);
 HEAPF32[$134>>2] = $132;
 $135 = (($Q) + 12|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = (($Q) + 16|0);
 ;HEAP32[$136+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$136+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$136+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $137 = (($Q) + 32|0);
 ;HEAP32[$137+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$137+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$137+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$137+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $138 = (($Q) + 48|0);
 ;HEAP32[$138+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$138+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$138+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$138+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $122;
 $139 = (($A) + 4|0);
 HEAPF32[$139>>2] = $123;
 $140 = (($A) + 8|0);
 HEAPF32[$140>>2] = $124;
 $141 = (($A) + 12|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 $142 = (($A) + 16|0);
 ;HEAP32[$142+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$142+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$142+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$142+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $143 = (($A) + 32|0);
 ;HEAP32[$143+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$143+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $144 = (($A) + 48|0);
 ;HEAP32[$144+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$B+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $145 = (($B) + 16|0);
 ;HEAP32[$145+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$145+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$145+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$145+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $146 = (($B) + 32|0);
 ;HEAP32[$146+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$146+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $147 = (($B) + 48|0);
 ;HEAP32[$147+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$147+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $148 = Math_fround(-$130);
 $149 = Math_fround(-$131);
 $150 = Math_fround(-$132);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $151 = (($a) + 32|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($b) + 32|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = $152 > $154;
 $$$i = $155 ? $154 : $152;
 $156 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $157 = Math_fround($156 * $156);
 $158 = Math_fround($_inflation * $_inflation);
 $159 = Math_fround($158 + $157);
 HEAPF32[$closA>>2] = $122;
 $160 = (($closA) + 4|0);
 HEAPF32[$160>>2] = $123;
 $161 = (($closA) + 8|0);
 HEAPF32[$161>>2] = $124;
 $162 = (($closA) + 12|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 ;HEAP32[$closB+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $163 = Math_fround($130 * $130);
 $164 = Math_fround($131 * $131);
 $165 = Math_fround($163 + $164);
 $166 = Math_fround($132 * $132);
 $167 = Math_fround($165 + $166);
 $168 = $167 > $157;
 L1: do {
  if ($168) {
   $169 = Math_fround($14 * Math_fround(0.0));
   $170 = Math_fround($12 * Math_fround(0.0));
   $171 = Math_fround($10 * Math_fround(0.0));
   $172 = Math_fround($169 + $19);
   $173 = Math_fround($170 + $17);
   $174 = Math_fround($171 + $15);
   $175 = (($nvNorm) + 4|0);
   $176 = (($nvNorm) + 8|0);
   $177 = (($nvNorm) + 12|0);
   $178 = (($_dir$i$i183) + 4|0);
   $179 = (($_dir$i$i183) + 8|0);
   $180 = (($_dir$i$i183) + 12|0);
   $181 = (($maxPoint$i$i184) + 4|0);
   $182 = (($maxPoint$i$i184) + 8|0);
   $183 = (($8) + 4|0);
   $184 = (($8) + 8|0);
   $185 = (($support) + 4|0);
   $186 = (($support) + 8|0);
   $187 = (($support) + 12|0);
   $188 = (($B) + 4|0);
   $189 = (($B) + 8|0);
   $190 = (($B) + 12|0);
   $191 = (($B) + 16|0);
   $192 = (($B) + 20|0);
   $193 = (($B) + 24|0);
   $194 = (($B) + 28|0);
   $195 = (($B) + 32|0);
   $196 = (($B) + 36|0);
   $197 = (($B) + 40|0);
   $198 = (($B) + 44|0);
   $199 = (($A) + 16|0);
   $200 = (($A) + 20|0);
   $201 = (($A) + 24|0);
   $202 = (($Q) + 16|0);
   $203 = (($Q) + 20|0);
   $204 = (($Q) + 24|0);
   $205 = (($Q) + 28|0);
   $206 = (($A) + 32|0);
   $207 = (($A) + 36|0);
   $208 = (($A) + 40|0);
   $209 = (($Q) + 32|0);
   $210 = (($Q) + 36|0);
   $211 = (($Q) + 40|0);
   $212 = (($Q) + 44|0);
   $213 = (($9) + 4|0);
   $214 = (($9) + 8|0);
   $215 = (($tempV) + 4|0);
   $216 = (($tempV) + 8|0);
   $217 = (($closB) + 4|0);
   $218 = (($closB) + 8|0);
   $219 = (($closB) + 12|0);
   $220 = (($tempV) + 12|0);
   $222 = $148;$224 = $149;$227 = $150;$298 = $174;$300 = $173;$302 = $172;$325 = Math_fround(0.0);$526 = Math_fround(0.0);$527 = $124;$528 = $123;$529 = $122;$530 = $148;$531 = $149;$532 = $150;$533 = $167;
   while(1) {
    $221 = Math_fround($222 * $222);
    $223 = Math_fround($224 * $224);
    $225 = Math_fround($223 + $221);
    $226 = Math_fround($227 * $227);
    $228 = Math_fround($226 + $225);
    $229 = (Math_fround(Math_sqrt((Math_fround($228)))));
    $230 = Math_fround(Math_fround(1.0) / $229);
    $231 = Math_fround($222 * $230);
    $232 = Math_fround($224 * $230);
    $233 = Math_fround($227 * $230);
    $234 = Math_fround(-$231);
    $235 = Math_fround(-$232);
    $236 = Math_fround(-$233);
    HEAPF32[$nvNorm>>2] = $234;
    HEAPF32[$175>>2] = $235;
    HEAPF32[$176>>2] = $236;
    HEAPF32[$177>>2] = Math_fround(0.0);
    $237 = Math_fround(HEAPF32[$aToB>>2]);
    $238 = Math_fround($231 * $237);
    $239 = Math_fround(HEAPF32[$57>>2]);
    $240 = Math_fround($232 * $239);
    $241 = Math_fround($238 + $240);
    $242 = Math_fround(HEAPF32[$61>>2]);
    $243 = Math_fround($233 * $242);
    $244 = Math_fround($241 + $243);
    $245 = Math_fround(HEAPF32[$65>>2]);
    $246 = Math_fround($231 * $245);
    $247 = Math_fround(HEAPF32[$68>>2]);
    $248 = Math_fround($232 * $247);
    $249 = Math_fround($246 + $248);
    $250 = Math_fround(HEAPF32[$72>>2]);
    $251 = Math_fround($233 * $250);
    $252 = Math_fround($249 + $251);
    $253 = Math_fround(HEAPF32[$76>>2]);
    $254 = Math_fround($231 * $253);
    $255 = Math_fround(HEAPF32[$79>>2]);
    $256 = Math_fround($232 * $255);
    $257 = Math_fround($254 + $256);
    $258 = Math_fround(HEAPF32[$83>>2]);
    $259 = Math_fround($233 * $258);
    $260 = Math_fround($257 + $259);
    HEAPF32[$_dir$i$i183>>2] = $244;
    HEAPF32[$178>>2] = $252;
    HEAPF32[$179>>2] = $260;
    HEAPF32[$180>>2] = Math_fround(0.0);
    __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($maxPoint$i$i184,$a,$_dir$i$i183);
    $261 = Math_fround(HEAPF32[$21>>2]);
    $262 = Math_fround(HEAPF32[$23>>2]);
    $263 = Math_fround(HEAPF32[$25>>2]);
    $264 = Math_fround(HEAPF32[$maxPoint$i$i184>>2]);
    $265 = Math_fround(HEAPF32[$181>>2]);
    $266 = Math_fround(HEAPF32[$182>>2]);
    $267 = Math_fround(HEAPF32[$aToB>>2]);
    $268 = Math_fround($264 * $267);
    $269 = Math_fround(HEAPF32[$65>>2]);
    $270 = Math_fround($265 * $269);
    $271 = Math_fround($268 + $270);
    $272 = Math_fround(HEAPF32[$76>>2]);
    $273 = Math_fround($266 * $272);
    $274 = Math_fround($271 + $273);
    $275 = Math_fround(HEAPF32[$57>>2]);
    $276 = Math_fround($264 * $275);
    $277 = Math_fround(HEAPF32[$68>>2]);
    $278 = Math_fround($265 * $277);
    $279 = Math_fround($276 + $278);
    $280 = Math_fround(HEAPF32[$79>>2]);
    $281 = Math_fround($266 * $280);
    $282 = Math_fround($279 + $281);
    $283 = Math_fround(HEAPF32[$61>>2]);
    $284 = Math_fround($264 * $283);
    $285 = Math_fround(HEAPF32[$72>>2]);
    $286 = Math_fround($265 * $285);
    $287 = Math_fround($284 + $286);
    $288 = Math_fround(HEAPF32[$83>>2]);
    $289 = Math_fround($266 * $288);
    $290 = Math_fround($287 + $289);
    $291 = Math_fround($261 + $274);
    $292 = Math_fround($262 + $282);
    $293 = Math_fround($263 + $290);
    __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($8,$b,$nvNorm);
    $294 = Math_fround(HEAPF32[$8>>2]);
    $295 = Math_fround(HEAPF32[$183>>2]);
    $296 = Math_fround(HEAPF32[$184>>2]);
    $297 = Math_fround($298 + $294);
    $299 = Math_fround($300 + $295);
    $301 = Math_fround($302 + $296);
    $303 = Math_fround($291 - $297);
    $304 = Math_fround($292 - $299);
    $305 = Math_fround($293 - $301);
    HEAPF32[$support>>2] = $303;
    HEAPF32[$185>>2] = $304;
    HEAPF32[$186>>2] = $305;
    HEAPF32[$187>>2] = Math_fround(0.0);
    $306 = Math_fround($231 * $303);
    $307 = Math_fround($232 * $304);
    $308 = Math_fround(-$307);
    $309 = Math_fround($308 - $306);
    $310 = Math_fround($233 * $305);
    $311 = Math_fround($309 - $310);
    $312 = Math_fround($311 - $_inflation);
    $313 = Math_fround(HEAPF32[$r>>2]);
    $314 = Math_fround(HEAPF32[$11>>2]);
    $315 = Math_fround(HEAPF32[$13>>2]);
    $316 = Math_fround($231 * $313);
    $317 = Math_fround($232 * $314);
    $318 = Math_fround($316 + $317);
    $319 = Math_fround($233 * $315);
    $320 = Math_fround($318 + $319);
    $321 = $312 > Math_fround(0.0);
    if ($321) {
     $322 = !($320 >= Math_fround(0.0));
     if (!($322)) {
      $$0 = 0;
      label = 22;
      break;
     }
     $323 = Math_fround($312 / $320);
     $324 = Math_fround($325 - $323);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1314+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1314+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1314+8>>2]|0;
     $326 = $324 > $325;
     if ($326) {
      $327 = $324 > Math_fround(1.0);
      if ($327) {
       $$0 = 0;
       label = 22;
       break;
      }
      $328 = Math_fround(HEAPF32[$s>>2]);
      $329 = Math_fround(HEAPF32[$16>>2]);
      $330 = Math_fround(HEAPF32[$18>>2]);
      $331 = Math_fround($324 * $313);
      $332 = Math_fround($324 * $314);
      $333 = Math_fround($324 * $315);
      $334 = Math_fround($331 + $328);
      $335 = Math_fround($332 + $329);
      $336 = Math_fround($333 + $330);
      $337 = Math_fround($334 - $298);
      $338 = Math_fround($335 - $300);
      $339 = Math_fround($336 - $302);
      $340 = Math_fround(HEAPF32[$B>>2]);
      $341 = Math_fround(HEAPF32[$188>>2]);
      $342 = Math_fround(HEAPF32[$189>>2]);
      $343 = Math_fround($337 + $340);
      $344 = Math_fround($338 + $341);
      $345 = Math_fround($339 + $342);
      $346 = Math_fround(HEAPF32[$191>>2]);
      $347 = Math_fround(HEAPF32[$192>>2]);
      $348 = Math_fround(HEAPF32[$193>>2]);
      $349 = Math_fround($337 + $346);
      $350 = Math_fround($338 + $347);
      $351 = Math_fround($339 + $348);
      $352 = Math_fround(HEAPF32[$195>>2]);
      $353 = Math_fround(HEAPF32[$196>>2]);
      $354 = Math_fround(HEAPF32[$197>>2]);
      $355 = Math_fround($337 + $352);
      $356 = Math_fround($338 + $353);
      $357 = Math_fround($339 + $354);
      HEAPF32[$B>>2] = $343;
      HEAPF32[$188>>2] = $344;
      HEAPF32[$189>>2] = $345;
      HEAPF32[$190>>2] = Math_fround(0.0);
      HEAPF32[$191>>2] = $349;
      HEAPF32[$192>>2] = $350;
      HEAPF32[$193>>2] = $351;
      HEAPF32[$194>>2] = Math_fround(0.0);
      HEAPF32[$195>>2] = $355;
      HEAPF32[$196>>2] = $356;
      HEAPF32[$197>>2] = $357;
      HEAPF32[$198>>2] = Math_fround(0.0);
      $358 = Math_fround(HEAPF32[$A>>2]);
      $359 = Math_fround(HEAPF32[$139>>2]);
      $360 = Math_fround(HEAPF32[$140>>2]);
      $361 = Math_fround($358 - $343);
      $362 = Math_fround($359 - $344);
      $363 = Math_fround($360 - $345);
      HEAPF32[$Q>>2] = $361;
      HEAPF32[$133>>2] = $362;
      HEAPF32[$134>>2] = $363;
      HEAPF32[$135>>2] = Math_fround(0.0);
      $364 = Math_fround(HEAPF32[$199>>2]);
      $365 = Math_fround(HEAPF32[$200>>2]);
      $366 = Math_fround(HEAPF32[$201>>2]);
      $367 = Math_fround($364 - $349);
      $368 = Math_fround($365 - $350);
      $369 = Math_fround($366 - $351);
      HEAPF32[$202>>2] = $367;
      HEAPF32[$203>>2] = $368;
      HEAPF32[$204>>2] = $369;
      HEAPF32[$205>>2] = Math_fround(0.0);
      $370 = Math_fround(HEAPF32[$206>>2]);
      $371 = Math_fround(HEAPF32[$207>>2]);
      $372 = Math_fround(HEAPF32[$208>>2]);
      $373 = Math_fround($370 - $355);
      $374 = Math_fround($371 - $356);
      $375 = Math_fround($372 - $357);
      HEAPF32[$209>>2] = $373;
      HEAPF32[$210>>2] = $374;
      HEAPF32[$211>>2] = $375;
      HEAPF32[$212>>2] = Math_fround(0.0);
      __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($9,$b,$nvNorm);
      $376 = Math_fround(HEAPF32[$9>>2]);
      $377 = Math_fround(HEAPF32[$213>>2]);
      $378 = Math_fround(HEAPF32[$214>>2]);
      $379 = Math_fround($334 + $376);
      $380 = Math_fround($335 + $377);
      $381 = Math_fround($336 + $378);
      $382 = Math_fround($291 - $379);
      $383 = Math_fround($292 - $380);
      $384 = Math_fround($293 - $381);
      HEAPF32[$support>>2] = $382;
      HEAPF32[$185>>2] = $383;
      HEAPF32[$186>>2] = $384;
      HEAPF32[$187>>2] = Math_fround(0.0);
      $391 = $379;$393 = $380;$395 = $381;$403 = $382;$405 = $383;$407 = $384;$462 = Math_fround(3.40282346638528859812E+38);$534 = $324;$535 = $336;$536 = $335;$537 = $334;$538 = $227;$539 = $224;$540 = $222;
     } else {
      $391 = $297;$393 = $299;$395 = $301;$403 = $303;$405 = $304;$407 = $305;$462 = $533;$534 = $324;$535 = $302;$536 = $300;$537 = $298;$538 = $532;$539 = $531;$540 = $530;
     }
    } else {
     $391 = $297;$393 = $299;$395 = $301;$403 = $303;$405 = $304;$407 = $305;$462 = $533;$534 = $325;$535 = $302;$536 = $300;$537 = $298;$538 = $532;$539 = $531;$540 = $530;
    }
    $385 = HEAP32[$size>>2]|0;
    $386 = (($A) + ($385<<4)|0);
    HEAPF32[$386>>2] = $291;
    $387 = ((($A) + ($385<<4)|0) + 4|0);
    HEAPF32[$387>>2] = $292;
    $388 = ((($A) + ($385<<4)|0) + 8|0);
    HEAPF32[$388>>2] = $293;
    $389 = ((($A) + ($385<<4)|0) + 12|0);
    HEAPF32[$389>>2] = Math_fround(0.0);
    $390 = (($B) + ($385<<4)|0);
    HEAPF32[$390>>2] = $391;
    $392 = ((($B) + ($385<<4)|0) + 4|0);
    HEAPF32[$392>>2] = $393;
    $394 = ((($B) + ($385<<4)|0) + 8|0);
    HEAPF32[$394>>2] = $395;
    $396 = ((($B) + ($385<<4)|0) + 12|0);
    HEAPF32[$396>>2] = Math_fround(0.0);
    $397 = (($385) + 1)|0;
    HEAP32[$size>>2] = $397;
    $398 = (($Q) + ($385<<4)|0);
    ;HEAP32[$398+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$398+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$398+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$398+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($385|0) == 1)) {
      $399 = Math_fround(HEAPF32[$Q>>2]);
      $400 = Math_fround(HEAPF32[$133>>2]);
      $401 = Math_fround(HEAPF32[$134>>2]);
      $402 = Math_fround($403 - $399);
      $404 = Math_fround($405 - $400);
      $406 = Math_fround($407 - $401);
      $408 = Math_fround($402 * $402);
      $409 = Math_fround($404 * $404);
      $410 = Math_fround($408 + $409);
      $411 = Math_fround($406 * $406);
      $412 = Math_fround($410 + $411);
      $413 = $412 == Math_fround(0.0);
      if ($413) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $414 = Math_fround($400 * $404);
       $415 = Math_fround(-$414);
       $416 = Math_fround($399 * $402);
       $417 = Math_fround($415 - $416);
       $418 = Math_fround($401 * $406);
       $419 = Math_fround($417 - $418);
       $420 = Math_fround(HEAPF32[$A>>2]);
       $421 = Math_fround(HEAPF32[$139>>2]);
       $422 = Math_fround(HEAPF32[$140>>2]);
       $423 = Math_fround($291 - $420);
       $424 = Math_fround($292 - $421);
       $425 = Math_fround($293 - $422);
       $426 = Math_fround(HEAPF32[$B>>2]);
       $427 = Math_fround(HEAPF32[$188>>2]);
       $428 = Math_fround(HEAPF32[$189>>2]);
       $429 = Math_fround($391 - $426);
       $430 = Math_fround($393 - $427);
       $431 = Math_fround($395 - $428);
       $432 = Math_fround($419 / $412);
       $433 = $432 > Math_fround(1.0);
       $$$i$i$i = $433 ? Math_fround(1.0) : $432;
       $434 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $434 ? $$$i$i$i : Math_fround(0.0);
       $435 = Math_fround($423 * $$$i8$i$i);
       $436 = Math_fround($424 * $$$i8$i$i);
       $437 = Math_fround($425 * $$$i8$i$i);
       $438 = Math_fround($420 + $435);
       $439 = Math_fround($421 + $436);
       $440 = Math_fround($422 + $437);
       $441 = Math_fround($429 * $$$i8$i$i);
       $442 = Math_fround($430 * $$$i8$i$i);
       $443 = Math_fround($431 * $$$i8$i$i);
       $444 = Math_fround($426 + $441);
       $445 = Math_fround($427 + $442);
       $446 = Math_fround($428 + $443);
       HEAPF32[$closA>>2] = $438;
       HEAPF32[$160>>2] = $439;
       HEAPF32[$161>>2] = $440;
       HEAPF32[$162>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $444;
       HEAPF32[$217>>2] = $445;
       HEAPF32[$218>>2] = $446;
       HEAPF32[$219>>2] = Math_fround(0.0);
       $447 = Math_fround($438 - $444);
       $448 = Math_fround($439 - $445);
       $449 = Math_fround($440 - $446);
       HEAPF32[$tempV>>2] = $447;
       HEAPF32[$215>>2] = $448;
       HEAPF32[$216>>2] = $449;
       HEAPF32[$220>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($385|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$136,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($385|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($385|0) == 0)) {
      HEAPF32[$closA>>2] = $291;
      HEAPF32[$160>>2] = $292;
      HEAPF32[$161>>2] = $293;
      HEAPF32[$162>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $391;
      HEAPF32[$217>>2] = $393;
      HEAPF32[$218>>2] = $395;
      HEAPF32[$219>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $450 = Math_fround(HEAPF32[$tempV>>2]);
    $451 = Math_fround(HEAPF32[$215>>2]);
    $452 = Math_fround(HEAPF32[$216>>2]);
    $453 = Math_fround(-$450);
    $454 = Math_fround(-$451);
    $455 = Math_fround(-$452);
    $456 = Math_fround($450 * $450);
    $457 = Math_fround($451 * $451);
    $458 = Math_fround($456 + $457);
    $459 = Math_fround($452 * $452);
    $460 = Math_fround($458 + $459);
    $461 = $462 > $460;
    $463 = $461 << 31 >> 31;
    $464 = $460 > $159;
    if (!($464)) {
     $$lcssa = $534;$$lcssa898 = $526;$$lcssa900 = $527;$$lcssa902 = $528;$$lcssa904 = $529;$$lcssa906 = $455;$$lcssa908 = $454;$$lcssa910 = $453;$$lcssa912 = $460;$$lcssa914 = $463;$$lcssa916 = $538;$$lcssa918 = $539;$$lcssa920 = $540;
     break L1;
    }
    if (!($461)) {
     $$lcssa = $534;$$lcssa898 = $526;$$lcssa900 = $527;$$lcssa902 = $528;$$lcssa904 = $529;$$lcssa906 = $455;$$lcssa908 = $454;$$lcssa910 = $453;$$lcssa912 = $460;$$lcssa914 = $463;$$lcssa916 = $538;$$lcssa918 = $539;$$lcssa920 = $540;
     break L1;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre954 = Math_fround(HEAPF32[$160>>2]);
    $$pre955 = Math_fround(HEAPF32[$161>>2]);
    $$pre956 = Math_fround(HEAPF32[$162>>2]);
    $222 = $453;$224 = $454;$227 = $455;$298 = $537;$300 = $536;$302 = $535;$325 = $534;$526 = $$pre956;$527 = $$pre955;$528 = $$pre954;$529 = $$pre;$530 = $540;$531 = $539;$532 = $538;$533 = $460;
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa898 = Math_fround(0.0);$$lcssa900 = $124;$$lcssa902 = $123;$$lcssa904 = $122;$$lcssa906 = $150;$$lcssa908 = $149;$$lcssa910 = $148;$$lcssa912 = $167;$$lcssa914 = -1;$$lcssa916 = $150;$$lcssa918 = $149;$$lcssa920 = $148;
  }
 } while(0);
 $465 = (($a) + 64|0);
 $466 = HEAP32[$465>>2]|0;
 $467 = (($a) + 68|0);
 $468 = HEAP32[$467>>2]|0;
 $469 = (($a) + 72|0);
 $470 = HEAP32[$469>>2]|0;
 $471 = $$lcssa912 > $157;
 if ($471) {
  $phitmp = ($$lcssa914|0)==(0);
  $phitmp891 = $phitmp ? $2 : $3;
  $479 = $phitmp891;
 } else {
  $479 = $2;
 }
 HEAPF32[$3>>2] = $$lcssa910;
 $472 = (($3) + 4|0);
 HEAPF32[$472>>2] = $$lcssa908;
 $473 = (($3) + 8|0);
 HEAPF32[$473>>2] = $$lcssa906;
 $474 = (($3) + 12|0);
 HEAPF32[$474>>2] = Math_fround(0.0);
 HEAPF32[$2>>2] = $$lcssa920;
 $475 = (($2) + 4|0);
 HEAPF32[$475>>2] = $$lcssa918;
 $476 = (($2) + 8|0);
 HEAPF32[$476>>2] = $$lcssa916;
 $477 = (($2) + 12|0);
 HEAPF32[$477>>2] = Math_fround(0.0);
 $478 = Math_fround(HEAPF32[$479>>2]);
 $$in1$i37 = (($479) + 4|0);
 $480 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($479) + 8|0);
 $481 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $482 = Math_fround($478 * $478);
 $483 = Math_fround($480 * $480);
 $484 = Math_fround($482 + $483);
 $485 = Math_fround($481 * $481);
 $486 = Math_fround($484 + $485);
 $487 = (Math_fround(Math_sqrt((Math_fround($486)))));
 $488 = Math_fround(Math_fround(1.0) / $487);
 $489 = Math_fround($478 * $488);
 $490 = Math_fround($480 * $488);
 $491 = Math_fround($481 * $488);
 $492 = Math_fround(-$489);
 $493 = Math_fround(-$490);
 $494 = Math_fround(-$491);
 HEAPF32[$normal>>2] = $492;
 $495 = (($normal) + 4|0);
 HEAPF32[$495>>2] = $493;
 $496 = (($normal) + 8|0);
 HEAPF32[$496>>2] = $494;
 $497 = (($normal) + 12|0);
 HEAPF32[$497>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $498 = (($lambda) + 4|0);
 ;HEAP32[$498+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$498+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$498+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$5+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$4>>2] = $$lcssa904;
 $499 = (($4) + 4|0);
 HEAPF32[$499>>2] = $$lcssa902;
 $500 = (($4) + 8|0);
 HEAPF32[$500>>2] = $$lcssa900;
 $501 = (($4) + 12|0);
 HEAPF32[$501>>2] = $$lcssa898;
 $502 = ($$lcssa914|0)==(0);
 $b$a$i18 = $502 ? $4 : $5;
 $503 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $504 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $505 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $503;
 HEAPF32[$160>>2] = $504;
 HEAPF32[$161>>2] = $505;
 HEAPF32[$162>>2] = Math_fround(0.0);
 $506 = (($a) + 16|0);
 $507 = Math_fround(HEAPF32[$506>>2]);
 $508 = Math_fround($507 * $492);
 $509 = Math_fround($507 * $493);
 $510 = Math_fround($507 * $494);
 $511 = Math_fround($503 - $508);
 $512 = Math_fround($504 - $509);
 $513 = Math_fround($505 - $510);
 ;HEAP32[$6+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$7>>2] = $511;
 $514 = (($7) + 4|0);
 HEAPF32[$514>>2] = $512;
 $515 = (($7) + 8|0);
 HEAPF32[$515>>2] = $513;
 $516 = (($7) + 12|0);
 HEAPF32[$516>>2] = Math_fround(0.0);
 $517 = ($466|0)==(0);
 $b$a$i = $517 ? $6 : $7;
 $518 = Math_fround(HEAPF32[$b$a$i>>2]);
 $519 = ($468|0)==(0);
 $a$pn3$i = $519 ? $6 : $7;
 $$in1$i = (($a$pn3$i) + 4|0);
 $520 = Math_fround(HEAPF32[$$in1$i>>2]);
 $521 = ($470|0)==(0);
 $b$a5$i = $521 ? $6 : $7;
 $$in2$i = (($b$a5$i) + 8|0);
 $522 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $518;
 $523 = (($closestA) + 4|0);
 HEAPF32[$523>>2] = $520;
 $524 = (($closestA) + 8|0);
 HEAPF32[$524>>2] = $522;
 $525 = (($closestA) + 12|0);
 HEAPF32[$525>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_4BoxVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i$i = 0, $$in1$i$i$i$i180 = 0, $$in1$i202 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i$i = 0, $$in2$i$i$i$i182 = 0, $$in2$i204 = 0, $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa902 = Math_fround(0), $$lcssa904 = Math_fround(0), $$lcssa906 = Math_fround(0);
 var $$lcssa908 = Math_fround(0), $$lcssa910 = Math_fround(0), $$lcssa912 = Math_fround(0), $$lcssa914 = Math_fround(0), $$lcssa916 = Math_fround(0), $$lcssa918 = 0, $$lcssa920 = Math_fround(0), $$lcssa922 = Math_fround(0), $$lcssa924 = Math_fround(0), $$pre = Math_fround(0), $$pre958 = Math_fround(0), $$pre959 = Math_fround(0), $$pre960 = Math_fround(0), $$sroa$1318 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0;
 var $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0;
 var $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0;
 var $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0);
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0);
 var $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0);
 var $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0;
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0);
 var $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0);
 var $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0);
 var $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0);
 var $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0);
 var $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0;
 var $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0);
 var $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0);
 var $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0);
 var $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = 0;
 var $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = 0;
 var $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = 0, $498 = 0, $499 = 0, $5 = 0;
 var $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = 0, $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0);
 var $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0;
 var $_lambda$sroa$1 = 0, $a$pn3$i = 0, $a$pn3$i$i$i$i = 0, $a$pn3$i$i$i$i179 = 0, $b$a$i = 0, $b$a$i$i$i$i = 0, $b$a$i$i$i$i177 = 0, $b$a$i18 = 0, $b$a$i199 = 0, $b$a5$i = 0, $b$a5$i$i$i$i = 0, $b$a5$i$i$i$i181 = 0, $closA = 0, $closB = 0, $initialSearchDir = 0, $initialSupportB = 0, $nvNorm = 0, $phitmp = 0, $phitmp895 = 0, $size = 0;
 var $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 336|0;
 $1 = sp + 496|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $4 = sp + 384|0;
 $5 = sp + 400|0;
 $6 = sp + 432|0;
 $7 = sp + 416|0;
 $8 = sp + 448|0;
 $9 = sp + 464|0;
 $zeroV = sp + 480|0;
 $zero$sroa$1 = sp + 528|0;
 $_lambda$sroa$1 = sp + 540|0;
 $size = sp + 524|0;
 $initialSearchDir = sp + 208|0;
 $initialSupportB = sp;
 $Q = sp + 16|0;
 $A = sp + 80|0;
 $B = sp + 144|0;
 $support = sp + 224|0;
 $closA = sp + 240|0;
 $closB = sp + 256|0;
 $nvNorm = sp + 272|0;
 $10 = sp + 288|0;
 $$sroa$1318 = sp + 512|0;
 $11 = sp + 304|0;
 $tempV = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $12 = Math_fround(HEAPF32[$r>>2]);
 $13 = (($r) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($r) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$s>>2]);
 $18 = (($s) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($s) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAP32[$size>>2] = 1;
 $22 = (($aToB) + 48|0);
 $23 = (($aToB) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($aToB) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($24 * $24);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($28 * $28);
 $33 = Math_fround($31 + $32);
 $34 = $33 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$22+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $35 = (($0) + 4|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($0) + 8|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($0) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $b$a$i199 = $34 ? $1 : $0;
 $38 = Math_fround(HEAPF32[$b$a$i199>>2]);
 $$in1$i202 = (($b$a$i199) + 4|0);
 $39 = Math_fround(HEAPF32[$$in1$i202>>2]);
 $$in2$i204 = (($b$a$i199) + 8|0);
 $40 = Math_fround(HEAPF32[$$in2$i204>>2]);
 $41 = Math_fround($38 * $38);
 $42 = Math_fround($39 * $39);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($40 * $40);
 $45 = Math_fround($43 + $44);
 $46 = (Math_fround(Math_sqrt((Math_fround($45)))));
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = Math_fround($38 * $47);
 $49 = Math_fround($39 * $47);
 $50 = Math_fround($40 * $47);
 HEAPF32[$initialSearchDir>>2] = $48;
 $51 = (($initialSearchDir) + 4|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($initialSearchDir) + 8|0);
 HEAPF32[$52>>2] = $50;
 $53 = (($initialSearchDir) + 12|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = Math_fround(-$48);
 $55 = Math_fround(-$49);
 $56 = Math_fround(-$50);
 $57 = Math_fround(HEAPF32[$aToB>>2]);
 $58 = Math_fround($57 * $54);
 $59 = (($aToB) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 * $55);
 $62 = Math_fround($58 + $61);
 $63 = (($aToB) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 * $56);
 $66 = Math_fround($62 + $65);
 $67 = (($aToB) + 16|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 * $54);
 $70 = (($aToB) + 20|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $55);
 $73 = Math_fround($69 + $72);
 $74 = (($aToB) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 * $56);
 $77 = Math_fround($73 + $76);
 $78 = (($aToB) + 32|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 * $54);
 $81 = (($aToB) + 36|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 * $55);
 $84 = Math_fround($80 + $83);
 $85 = (($aToB) + 40|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 * $56);
 $88 = Math_fround($84 + $87);
 $89 = $66 > Math_fround(0.0);
 $90 = $77 > Math_fround(0.0);
 $91 = $88 > Math_fround(0.0);
 $92 = (($a) + 144|0);
 ;HEAP32[$3+0>>2]=HEAP32[$92+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$92+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$92+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$92+12>>2]|0;
 $93 = (($a) + 144|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($a) + 148|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($a) + 152|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround(-$94);
 $100 = Math_fround(-$96);
 $101 = Math_fround(-$98);
 HEAPF32[$2>>2] = $99;
 $102 = (($2) + 4|0);
 HEAPF32[$102>>2] = $100;
 $103 = (($2) + 8|0);
 HEAPF32[$103>>2] = $101;
 $104 = (($2) + 12|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $b$a$i$i$i$i177 = $89 ? $3 : $2;
 $105 = Math_fround(HEAPF32[$b$a$i$i$i$i177>>2]);
 $a$pn3$i$i$i$i179 = $90 ? $3 : $2;
 $$in1$i$i$i$i180 = (($a$pn3$i$i$i$i179) + 4|0);
 $106 = Math_fround(HEAPF32[$$in1$i$i$i$i180>>2]);
 $b$a5$i$i$i$i181 = $91 ? $3 : $2;
 $$in2$i$i$i$i182 = (($b$a5$i$i$i$i181) + 8|0);
 $107 = Math_fround(HEAPF32[$$in2$i$i$i$i182>>2]);
 $108 = Math_fround(HEAPF32[$23>>2]);
 $109 = Math_fround(HEAPF32[$25>>2]);
 $110 = Math_fround(HEAPF32[$27>>2]);
 $111 = Math_fround($57 * $105);
 $112 = Math_fround($68 * $106);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($79 * $107);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($60 * $105);
 $117 = Math_fround($71 * $106);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($82 * $107);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($64 * $105);
 $122 = Math_fround($75 * $106);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($86 * $107);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($115 + $108);
 $127 = Math_fround($120 + $109);
 $128 = Math_fround($125 + $110);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($initialSupportB,$b,$initialSearchDir);
 $129 = Math_fround(HEAPF32[$initialSupportB>>2]);
 $130 = (($initialSupportB) + 4|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($initialSupportB) + 8|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($126 - $129);
 $135 = Math_fround($127 - $131);
 $136 = Math_fround($128 - $133);
 HEAPF32[$Q>>2] = $134;
 $137 = (($Q) + 4|0);
 HEAPF32[$137>>2] = $135;
 $138 = (($Q) + 8|0);
 HEAPF32[$138>>2] = $136;
 $139 = (($Q) + 12|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($Q) + 16|0);
 ;HEAP32[$140+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$140+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$140+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$140+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $141 = (($Q) + 32|0);
 ;HEAP32[$141+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$141+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$141+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$141+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $142 = (($Q) + 48|0);
 ;HEAP32[$142+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$142+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$142+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$142+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $126;
 $143 = (($A) + 4|0);
 HEAPF32[$143>>2] = $127;
 $144 = (($A) + 8|0);
 HEAPF32[$144>>2] = $128;
 $145 = (($A) + 12|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = (($A) + 16|0);
 ;HEAP32[$146+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$146+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $147 = (($A) + 32|0);
 ;HEAP32[$147+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$147+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $148 = (($A) + 48|0);
 ;HEAP32[$148+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$148+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$148+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$148+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$B+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $149 = (($B) + 16|0);
 ;HEAP32[$149+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$149+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$149+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$149+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $150 = (($B) + 32|0);
 ;HEAP32[$150+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$150+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $151 = (($B) + 48|0);
 ;HEAP32[$151+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$151+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$151+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$151+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $152 = Math_fround(-$134);
 $153 = Math_fround(-$135);
 $154 = Math_fround(-$136);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $155 = (($a) + 32|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($b) + 32|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = $156 > $158;
 $$$i = $159 ? $158 : $156;
 $160 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $161 = Math_fround($160 * $160);
 $162 = Math_fround($_inflation * $_inflation);
 $163 = Math_fround($162 + $161);
 HEAPF32[$closA>>2] = $126;
 $164 = (($closA) + 4|0);
 HEAPF32[$164>>2] = $127;
 $165 = (($closA) + 8|0);
 HEAPF32[$165>>2] = $128;
 $166 = (($closA) + 12|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 ;HEAP32[$closB+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $167 = Math_fround($134 * $134);
 $168 = Math_fround($135 * $135);
 $169 = Math_fround($167 + $168);
 $170 = Math_fround($136 * $136);
 $171 = Math_fround($169 + $170);
 $172 = $171 > $161;
 L1: do {
  if ($172) {
   $173 = Math_fround($16 * Math_fround(0.0));
   $174 = Math_fround($14 * Math_fround(0.0));
   $175 = Math_fround($12 * Math_fround(0.0));
   $176 = Math_fround($173 + $21);
   $177 = Math_fround($174 + $19);
   $178 = Math_fround($175 + $17);
   $179 = (($nvNorm) + 4|0);
   $180 = (($nvNorm) + 8|0);
   $181 = (($nvNorm) + 12|0);
   $182 = (($2) + 4|0);
   $183 = (($2) + 8|0);
   $184 = (($2) + 12|0);
   $185 = (($10) + 4|0);
   $186 = (($10) + 8|0);
   $187 = (($support) + 4|0);
   $188 = (($support) + 8|0);
   $189 = (($support) + 12|0);
   $190 = (($B) + 4|0);
   $191 = (($B) + 8|0);
   $192 = (($B) + 12|0);
   $193 = (($B) + 16|0);
   $194 = (($B) + 20|0);
   $195 = (($B) + 24|0);
   $196 = (($B) + 28|0);
   $197 = (($B) + 32|0);
   $198 = (($B) + 36|0);
   $199 = (($B) + 40|0);
   $200 = (($B) + 44|0);
   $201 = (($A) + 16|0);
   $202 = (($A) + 20|0);
   $203 = (($A) + 24|0);
   $204 = (($Q) + 16|0);
   $205 = (($Q) + 20|0);
   $206 = (($Q) + 24|0);
   $207 = (($Q) + 28|0);
   $208 = (($A) + 32|0);
   $209 = (($A) + 36|0);
   $210 = (($A) + 40|0);
   $211 = (($Q) + 32|0);
   $212 = (($Q) + 36|0);
   $213 = (($Q) + 40|0);
   $214 = (($Q) + 44|0);
   $215 = (($11) + 4|0);
   $216 = (($11) + 8|0);
   $217 = (($tempV) + 4|0);
   $218 = (($tempV) + 8|0);
   $219 = (($closB) + 4|0);
   $220 = (($closB) + 8|0);
   $221 = (($closB) + 12|0);
   $222 = (($tempV) + 12|0);
   $224 = $152;$226 = $153;$229 = $154;$300 = $178;$302 = $177;$304 = $176;$327 = Math_fround(0.0);$528 = Math_fround(0.0);$529 = $128;$530 = $127;$531 = $126;$532 = $152;$533 = $153;$534 = $154;$535 = $171;
   while(1) {
    $223 = Math_fround($224 * $224);
    $225 = Math_fround($226 * $226);
    $227 = Math_fround($225 + $223);
    $228 = Math_fround($229 * $229);
    $230 = Math_fround($228 + $227);
    $231 = (Math_fround(Math_sqrt((Math_fround($230)))));
    $232 = Math_fround(Math_fround(1.0) / $231);
    $233 = Math_fround($224 * $232);
    $234 = Math_fround($226 * $232);
    $235 = Math_fround($229 * $232);
    $236 = Math_fround(-$233);
    $237 = Math_fround(-$234);
    $238 = Math_fround(-$235);
    HEAPF32[$nvNorm>>2] = $236;
    HEAPF32[$179>>2] = $237;
    HEAPF32[$180>>2] = $238;
    HEAPF32[$181>>2] = Math_fround(0.0);
    $239 = Math_fround(HEAPF32[$aToB>>2]);
    $240 = Math_fround($233 * $239);
    $241 = Math_fround(HEAPF32[$59>>2]);
    $242 = Math_fround($234 * $241);
    $243 = Math_fround($240 + $242);
    $244 = Math_fround(HEAPF32[$63>>2]);
    $245 = Math_fround($235 * $244);
    $246 = Math_fround($243 + $245);
    $247 = Math_fround(HEAPF32[$67>>2]);
    $248 = Math_fround($233 * $247);
    $249 = Math_fround(HEAPF32[$70>>2]);
    $250 = Math_fround($234 * $249);
    $251 = Math_fround($248 + $250);
    $252 = Math_fround(HEAPF32[$74>>2]);
    $253 = Math_fround($235 * $252);
    $254 = Math_fround($251 + $253);
    $255 = Math_fround(HEAPF32[$78>>2]);
    $256 = Math_fround($233 * $255);
    $257 = Math_fround(HEAPF32[$81>>2]);
    $258 = Math_fround($234 * $257);
    $259 = Math_fround($256 + $258);
    $260 = Math_fround(HEAPF32[$85>>2]);
    $261 = Math_fround($235 * $260);
    $262 = Math_fround($259 + $261);
    $263 = $246 > Math_fround(0.0);
    $264 = $254 > Math_fround(0.0);
    $265 = $262 > Math_fround(0.0);
    ;HEAP32[$3+0>>2]=HEAP32[$92+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$92+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$92+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$92+12>>2]|0;
    $266 = Math_fround(HEAPF32[$93>>2]);
    $267 = Math_fround(HEAPF32[$95>>2]);
    $268 = Math_fround(HEAPF32[$97>>2]);
    $269 = Math_fround(-$266);
    $270 = Math_fround(-$267);
    $271 = Math_fround(-$268);
    HEAPF32[$2>>2] = $269;
    HEAPF32[$182>>2] = $270;
    HEAPF32[$183>>2] = $271;
    HEAPF32[$184>>2] = Math_fround(0.0);
    $b$a$i$i$i$i = $263 ? $3 : $2;
    $272 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
    $a$pn3$i$i$i$i = $264 ? $3 : $2;
    $$in1$i$i$i$i = (($a$pn3$i$i$i$i) + 4|0);
    $273 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
    $b$a5$i$i$i$i = $265 ? $3 : $2;
    $$in2$i$i$i$i = (($b$a5$i$i$i$i) + 8|0);
    $274 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
    $275 = Math_fround(HEAPF32[$23>>2]);
    $276 = Math_fround(HEAPF32[$25>>2]);
    $277 = Math_fround(HEAPF32[$27>>2]);
    $278 = Math_fround($239 * $272);
    $279 = Math_fround($247 * $273);
    $280 = Math_fround($278 + $279);
    $281 = Math_fround($255 * $274);
    $282 = Math_fround($280 + $281);
    $283 = Math_fround($241 * $272);
    $284 = Math_fround($249 * $273);
    $285 = Math_fround($283 + $284);
    $286 = Math_fround($257 * $274);
    $287 = Math_fround($285 + $286);
    $288 = Math_fround($244 * $272);
    $289 = Math_fround($252 * $273);
    $290 = Math_fround($288 + $289);
    $291 = Math_fround($260 * $274);
    $292 = Math_fround($290 + $291);
    $293 = Math_fround($282 + $275);
    $294 = Math_fround($287 + $276);
    $295 = Math_fround($292 + $277);
    __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($10,$b,$nvNorm);
    $296 = Math_fround(HEAPF32[$10>>2]);
    $297 = Math_fround(HEAPF32[$185>>2]);
    $298 = Math_fround(HEAPF32[$186>>2]);
    $299 = Math_fround($300 + $296);
    $301 = Math_fround($302 + $297);
    $303 = Math_fround($304 + $298);
    $305 = Math_fround($293 - $299);
    $306 = Math_fround($294 - $301);
    $307 = Math_fround($295 - $303);
    HEAPF32[$support>>2] = $305;
    HEAPF32[$187>>2] = $306;
    HEAPF32[$188>>2] = $307;
    HEAPF32[$189>>2] = Math_fround(0.0);
    $308 = Math_fround($233 * $305);
    $309 = Math_fround($234 * $306);
    $310 = Math_fround(-$309);
    $311 = Math_fround($310 - $308);
    $312 = Math_fround($235 * $307);
    $313 = Math_fround($311 - $312);
    $314 = Math_fround($313 - $_inflation);
    $315 = Math_fround(HEAPF32[$r>>2]);
    $316 = Math_fround(HEAPF32[$13>>2]);
    $317 = Math_fround(HEAPF32[$15>>2]);
    $318 = Math_fround($233 * $315);
    $319 = Math_fround($234 * $316);
    $320 = Math_fround($318 + $319);
    $321 = Math_fround($235 * $317);
    $322 = Math_fround($320 + $321);
    $323 = $314 > Math_fround(0.0);
    if ($323) {
     $324 = !($322 >= Math_fround(0.0));
     if (!($324)) {
      $$0 = 0;
      label = 22;
      break;
     }
     $325 = Math_fround($314 / $322);
     $326 = Math_fround($327 - $325);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1318+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1318+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1318+8>>2]|0;
     $328 = $326 > $327;
     if ($328) {
      $329 = $326 > Math_fround(1.0);
      if ($329) {
       $$0 = 0;
       label = 22;
       break;
      }
      $330 = Math_fround(HEAPF32[$s>>2]);
      $331 = Math_fround(HEAPF32[$18>>2]);
      $332 = Math_fround(HEAPF32[$20>>2]);
      $333 = Math_fround($326 * $315);
      $334 = Math_fround($326 * $316);
      $335 = Math_fround($326 * $317);
      $336 = Math_fround($333 + $330);
      $337 = Math_fround($334 + $331);
      $338 = Math_fround($335 + $332);
      $339 = Math_fround($336 - $300);
      $340 = Math_fround($337 - $302);
      $341 = Math_fround($338 - $304);
      $342 = Math_fround(HEAPF32[$B>>2]);
      $343 = Math_fround(HEAPF32[$190>>2]);
      $344 = Math_fround(HEAPF32[$191>>2]);
      $345 = Math_fround($339 + $342);
      $346 = Math_fround($340 + $343);
      $347 = Math_fround($341 + $344);
      $348 = Math_fround(HEAPF32[$193>>2]);
      $349 = Math_fround(HEAPF32[$194>>2]);
      $350 = Math_fround(HEAPF32[$195>>2]);
      $351 = Math_fround($339 + $348);
      $352 = Math_fround($340 + $349);
      $353 = Math_fround($341 + $350);
      $354 = Math_fround(HEAPF32[$197>>2]);
      $355 = Math_fround(HEAPF32[$198>>2]);
      $356 = Math_fround(HEAPF32[$199>>2]);
      $357 = Math_fround($339 + $354);
      $358 = Math_fround($340 + $355);
      $359 = Math_fround($341 + $356);
      HEAPF32[$B>>2] = $345;
      HEAPF32[$190>>2] = $346;
      HEAPF32[$191>>2] = $347;
      HEAPF32[$192>>2] = Math_fround(0.0);
      HEAPF32[$193>>2] = $351;
      HEAPF32[$194>>2] = $352;
      HEAPF32[$195>>2] = $353;
      HEAPF32[$196>>2] = Math_fround(0.0);
      HEAPF32[$197>>2] = $357;
      HEAPF32[$198>>2] = $358;
      HEAPF32[$199>>2] = $359;
      HEAPF32[$200>>2] = Math_fround(0.0);
      $360 = Math_fround(HEAPF32[$A>>2]);
      $361 = Math_fround(HEAPF32[$143>>2]);
      $362 = Math_fround(HEAPF32[$144>>2]);
      $363 = Math_fround($360 - $345);
      $364 = Math_fround($361 - $346);
      $365 = Math_fround($362 - $347);
      HEAPF32[$Q>>2] = $363;
      HEAPF32[$137>>2] = $364;
      HEAPF32[$138>>2] = $365;
      HEAPF32[$139>>2] = Math_fround(0.0);
      $366 = Math_fround(HEAPF32[$201>>2]);
      $367 = Math_fround(HEAPF32[$202>>2]);
      $368 = Math_fround(HEAPF32[$203>>2]);
      $369 = Math_fround($366 - $351);
      $370 = Math_fround($367 - $352);
      $371 = Math_fround($368 - $353);
      HEAPF32[$204>>2] = $369;
      HEAPF32[$205>>2] = $370;
      HEAPF32[$206>>2] = $371;
      HEAPF32[$207>>2] = Math_fround(0.0);
      $372 = Math_fround(HEAPF32[$208>>2]);
      $373 = Math_fround(HEAPF32[$209>>2]);
      $374 = Math_fround(HEAPF32[$210>>2]);
      $375 = Math_fround($372 - $357);
      $376 = Math_fround($373 - $358);
      $377 = Math_fround($374 - $359);
      HEAPF32[$211>>2] = $375;
      HEAPF32[$212>>2] = $376;
      HEAPF32[$213>>2] = $377;
      HEAPF32[$214>>2] = Math_fround(0.0);
      __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($11,$b,$nvNorm);
      $378 = Math_fround(HEAPF32[$11>>2]);
      $379 = Math_fround(HEAPF32[$215>>2]);
      $380 = Math_fround(HEAPF32[$216>>2]);
      $381 = Math_fround($336 + $378);
      $382 = Math_fround($337 + $379);
      $383 = Math_fround($338 + $380);
      $384 = Math_fround($293 - $381);
      $385 = Math_fround($294 - $382);
      $386 = Math_fround($295 - $383);
      HEAPF32[$support>>2] = $384;
      HEAPF32[$187>>2] = $385;
      HEAPF32[$188>>2] = $386;
      HEAPF32[$189>>2] = Math_fround(0.0);
      $393 = $381;$395 = $382;$397 = $383;$405 = $384;$407 = $385;$409 = $386;$464 = Math_fround(3.40282346638528859812E+38);$536 = $326;$537 = $338;$538 = $337;$539 = $336;$540 = $229;$541 = $226;$542 = $224;
     } else {
      $393 = $299;$395 = $301;$397 = $303;$405 = $305;$407 = $306;$409 = $307;$464 = $535;$536 = $326;$537 = $304;$538 = $302;$539 = $300;$540 = $534;$541 = $533;$542 = $532;
     }
    } else {
     $393 = $299;$395 = $301;$397 = $303;$405 = $305;$407 = $306;$409 = $307;$464 = $535;$536 = $327;$537 = $304;$538 = $302;$539 = $300;$540 = $534;$541 = $533;$542 = $532;
    }
    $387 = HEAP32[$size>>2]|0;
    $388 = (($A) + ($387<<4)|0);
    HEAPF32[$388>>2] = $293;
    $389 = ((($A) + ($387<<4)|0) + 4|0);
    HEAPF32[$389>>2] = $294;
    $390 = ((($A) + ($387<<4)|0) + 8|0);
    HEAPF32[$390>>2] = $295;
    $391 = ((($A) + ($387<<4)|0) + 12|0);
    HEAPF32[$391>>2] = Math_fround(0.0);
    $392 = (($B) + ($387<<4)|0);
    HEAPF32[$392>>2] = $393;
    $394 = ((($B) + ($387<<4)|0) + 4|0);
    HEAPF32[$394>>2] = $395;
    $396 = ((($B) + ($387<<4)|0) + 8|0);
    HEAPF32[$396>>2] = $397;
    $398 = ((($B) + ($387<<4)|0) + 12|0);
    HEAPF32[$398>>2] = Math_fround(0.0);
    $399 = (($387) + 1)|0;
    HEAP32[$size>>2] = $399;
    $400 = (($Q) + ($387<<4)|0);
    ;HEAP32[$400+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$400+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$400+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$400+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($387|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($387|0) == 0)) {
      HEAPF32[$closA>>2] = $293;
      HEAPF32[$164>>2] = $294;
      HEAPF32[$165>>2] = $295;
      HEAPF32[$166>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $393;
      HEAPF32[$219>>2] = $395;
      HEAPF32[$220>>2] = $397;
      HEAPF32[$221>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($387|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$140,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($387|0) == 1)) {
      $401 = Math_fround(HEAPF32[$Q>>2]);
      $402 = Math_fround(HEAPF32[$137>>2]);
      $403 = Math_fround(HEAPF32[$138>>2]);
      $404 = Math_fround($405 - $401);
      $406 = Math_fround($407 - $402);
      $408 = Math_fround($409 - $403);
      $410 = Math_fround($404 * $404);
      $411 = Math_fround($406 * $406);
      $412 = Math_fround($410 + $411);
      $413 = Math_fround($408 * $408);
      $414 = Math_fround($412 + $413);
      $415 = $414 == Math_fround(0.0);
      if ($415) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $416 = Math_fround($402 * $406);
       $417 = Math_fround(-$416);
       $418 = Math_fround($401 * $404);
       $419 = Math_fround($417 - $418);
       $420 = Math_fround($403 * $408);
       $421 = Math_fround($419 - $420);
       $422 = Math_fround(HEAPF32[$A>>2]);
       $423 = Math_fround(HEAPF32[$143>>2]);
       $424 = Math_fround(HEAPF32[$144>>2]);
       $425 = Math_fround($293 - $422);
       $426 = Math_fround($294 - $423);
       $427 = Math_fround($295 - $424);
       $428 = Math_fround(HEAPF32[$B>>2]);
       $429 = Math_fround(HEAPF32[$190>>2]);
       $430 = Math_fround(HEAPF32[$191>>2]);
       $431 = Math_fround($393 - $428);
       $432 = Math_fround($395 - $429);
       $433 = Math_fround($397 - $430);
       $434 = Math_fround($421 / $414);
       $435 = $434 > Math_fround(1.0);
       $$$i$i$i = $435 ? Math_fround(1.0) : $434;
       $436 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $436 ? $$$i$i$i : Math_fround(0.0);
       $437 = Math_fround($425 * $$$i8$i$i);
       $438 = Math_fround($426 * $$$i8$i$i);
       $439 = Math_fround($427 * $$$i8$i$i);
       $440 = Math_fround($422 + $437);
       $441 = Math_fround($423 + $438);
       $442 = Math_fround($424 + $439);
       $443 = Math_fround($431 * $$$i8$i$i);
       $444 = Math_fround($432 * $$$i8$i$i);
       $445 = Math_fround($433 * $$$i8$i$i);
       $446 = Math_fround($428 + $443);
       $447 = Math_fround($429 + $444);
       $448 = Math_fround($430 + $445);
       HEAPF32[$closA>>2] = $440;
       HEAPF32[$164>>2] = $441;
       HEAPF32[$165>>2] = $442;
       HEAPF32[$166>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $446;
       HEAPF32[$219>>2] = $447;
       HEAPF32[$220>>2] = $448;
       HEAPF32[$221>>2] = Math_fround(0.0);
       $449 = Math_fround($440 - $446);
       $450 = Math_fround($441 - $447);
       $451 = Math_fround($442 - $448);
       HEAPF32[$tempV>>2] = $449;
       HEAPF32[$217>>2] = $450;
       HEAPF32[$218>>2] = $451;
       HEAPF32[$222>>2] = Math_fround(0.0);
       break;
      }
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $452 = Math_fround(HEAPF32[$tempV>>2]);
    $453 = Math_fround(HEAPF32[$217>>2]);
    $454 = Math_fround(HEAPF32[$218>>2]);
    $455 = Math_fround(-$452);
    $456 = Math_fround(-$453);
    $457 = Math_fround(-$454);
    $458 = Math_fround($452 * $452);
    $459 = Math_fround($453 * $453);
    $460 = Math_fround($458 + $459);
    $461 = Math_fround($454 * $454);
    $462 = Math_fround($460 + $461);
    $463 = $464 > $462;
    $465 = $463 << 31 >> 31;
    $466 = $462 > $163;
    if (!($466)) {
     $$lcssa = $536;$$lcssa902 = $528;$$lcssa904 = $529;$$lcssa906 = $530;$$lcssa908 = $531;$$lcssa910 = $457;$$lcssa912 = $456;$$lcssa914 = $455;$$lcssa916 = $462;$$lcssa918 = $465;$$lcssa920 = $540;$$lcssa922 = $541;$$lcssa924 = $542;
     break L1;
    }
    if (!($463)) {
     $$lcssa = $536;$$lcssa902 = $528;$$lcssa904 = $529;$$lcssa906 = $530;$$lcssa908 = $531;$$lcssa910 = $457;$$lcssa912 = $456;$$lcssa914 = $455;$$lcssa916 = $462;$$lcssa918 = $465;$$lcssa920 = $540;$$lcssa922 = $541;$$lcssa924 = $542;
     break L1;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre958 = Math_fround(HEAPF32[$164>>2]);
    $$pre959 = Math_fround(HEAPF32[$165>>2]);
    $$pre960 = Math_fround(HEAPF32[$166>>2]);
    $224 = $455;$226 = $456;$229 = $457;$300 = $539;$302 = $538;$304 = $537;$327 = $536;$528 = $$pre960;$529 = $$pre959;$530 = $$pre958;$531 = $$pre;$532 = $542;$533 = $541;$534 = $540;$535 = $462;
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa902 = Math_fround(0.0);$$lcssa904 = $128;$$lcssa906 = $127;$$lcssa908 = $126;$$lcssa910 = $154;$$lcssa912 = $153;$$lcssa914 = $152;$$lcssa916 = $171;$$lcssa918 = -1;$$lcssa920 = $154;$$lcssa922 = $153;$$lcssa924 = $152;
  }
 } while(0);
 $467 = (($a) + 64|0);
 $468 = HEAP32[$467>>2]|0;
 $469 = (($a) + 68|0);
 $470 = HEAP32[$469>>2]|0;
 $471 = (($a) + 72|0);
 $472 = HEAP32[$471>>2]|0;
 $473 = $$lcssa916 > $161;
 if ($473) {
  $phitmp = ($$lcssa918|0)==(0);
  $phitmp895 = $phitmp ? $4 : $5;
  $481 = $phitmp895;
 } else {
  $481 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa914;
 $474 = (($5) + 4|0);
 HEAPF32[$474>>2] = $$lcssa912;
 $475 = (($5) + 8|0);
 HEAPF32[$475>>2] = $$lcssa910;
 $476 = (($5) + 12|0);
 HEAPF32[$476>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa924;
 $477 = (($4) + 4|0);
 HEAPF32[$477>>2] = $$lcssa922;
 $478 = (($4) + 8|0);
 HEAPF32[$478>>2] = $$lcssa920;
 $479 = (($4) + 12|0);
 HEAPF32[$479>>2] = Math_fround(0.0);
 $480 = Math_fround(HEAPF32[$481>>2]);
 $$in1$i37 = (($481) + 4|0);
 $482 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($481) + 8|0);
 $483 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $484 = Math_fround($480 * $480);
 $485 = Math_fround($482 * $482);
 $486 = Math_fround($484 + $485);
 $487 = Math_fround($483 * $483);
 $488 = Math_fround($486 + $487);
 $489 = (Math_fround(Math_sqrt((Math_fround($488)))));
 $490 = Math_fround(Math_fround(1.0) / $489);
 $491 = Math_fround($480 * $490);
 $492 = Math_fround($482 * $490);
 $493 = Math_fround($483 * $490);
 $494 = Math_fround(-$491);
 $495 = Math_fround(-$492);
 $496 = Math_fround(-$493);
 HEAPF32[$normal>>2] = $494;
 $497 = (($normal) + 4|0);
 HEAPF32[$497>>2] = $495;
 $498 = (($normal) + 8|0);
 HEAPF32[$498>>2] = $496;
 $499 = (($normal) + 12|0);
 HEAPF32[$499>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $500 = (($lambda) + 4|0);
 ;HEAP32[$500+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$500+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$500+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$6>>2] = $$lcssa908;
 $501 = (($6) + 4|0);
 HEAPF32[$501>>2] = $$lcssa906;
 $502 = (($6) + 8|0);
 HEAPF32[$502>>2] = $$lcssa904;
 $503 = (($6) + 12|0);
 HEAPF32[$503>>2] = $$lcssa902;
 $504 = ($$lcssa918|0)==(0);
 $b$a$i18 = $504 ? $6 : $7;
 $505 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $506 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $507 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $505;
 HEAPF32[$164>>2] = $506;
 HEAPF32[$165>>2] = $507;
 HEAPF32[$166>>2] = Math_fround(0.0);
 $508 = (($a) + 16|0);
 $509 = Math_fround(HEAPF32[$508>>2]);
 $510 = Math_fround($509 * $494);
 $511 = Math_fround($509 * $495);
 $512 = Math_fround($509 * $496);
 $513 = Math_fround($505 - $510);
 $514 = Math_fround($506 - $511);
 $515 = Math_fround($507 - $512);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $513;
 $516 = (($9) + 4|0);
 HEAPF32[$516>>2] = $514;
 $517 = (($9) + 8|0);
 HEAPF32[$517>>2] = $515;
 $518 = (($9) + 12|0);
 HEAPF32[$518>>2] = Math_fround(0.0);
 $519 = ($468|0)==(0);
 $b$a$i = $519 ? $8 : $9;
 $520 = Math_fround(HEAPF32[$b$a$i>>2]);
 $521 = ($470|0)==(0);
 $a$pn3$i = $521 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $522 = Math_fround(HEAPF32[$$in1$i>>2]);
 $523 = ($472|0)==(0);
 $b$a5$i = $523 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $524 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $520;
 $525 = (($closestA) + 4|0);
 HEAPF32[$525>>2] = $522;
 $526 = (($closestA) + 8|0);
 HEAPF32[$526>>2] = $524;
 $527 = (($closestA) + 12|0);
 HEAPF32[$527>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_4BoxVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERKNS8_5Vec3VESH_RSC_RSF_SJ_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i$i = 0, $$in1$i$i$i$i192 = 0, $$in1$i$i$i142 = 0, $$in1$i$i$i186 = 0, $$in1$i208 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i$i = 0, $$in2$i$i$i$i194 = 0, $$in2$i$i$i144 = 0, $$in2$i$i$i188 = 0, $$in2$i210 = 0;
 var $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa922 = Math_fround(0), $$lcssa924 = Math_fround(0), $$lcssa926 = Math_fround(0), $$lcssa928 = Math_fround(0), $$lcssa930 = Math_fround(0), $$lcssa932 = Math_fround(0), $$lcssa934 = Math_fround(0), $$lcssa936 = Math_fround(0), $$lcssa938 = 0, $$lcssa940 = Math_fround(0), $$lcssa942 = Math_fround(0), $$lcssa944 = Math_fround(0), $$pre = Math_fround(0), $$pre978 = Math_fround(0), $$pre979 = Math_fround(0), $$pre980 = Math_fround(0), $$sroa$1334 = 0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0;
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0);
 var $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0);
 var $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = Math_fround(0);
 var $495 = 0, $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = 0, $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0);
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = Math_fround(0), $535 = 0, $536 = Math_fround(0), $537 = 0, $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0);
 var $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0;
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $A = 0, $B = 0, $Q = 0;
 var $_lambda$sroa$1 = 0, $a$pn3$i = 0, $a$pn3$i$i$i = 0, $a$pn3$i$i$i$i = 0, $a$pn3$i$i$i$i191 = 0, $a$pn3$i$i$i141 = 0, $a$pn3$i$i$i185 = 0, $b$a$i = 0, $b$a$i$i$i = 0, $b$a$i$i$i$i = 0, $b$a$i$i$i$i189 = 0, $b$a$i$i$i139 = 0, $b$a$i$i$i183 = 0, $b$a$i18 = 0, $b$a$i205 = 0, $b$a5$i = 0, $b$a5$i$i$i = 0, $b$a5$i$i$i$i = 0, $b$a5$i$i$i$i193 = 0, $b$a5$i$i$i143 = 0;
 var $b$a5$i$i$i187 = 0, $closA = 0, $closB = 0, $phitmp = 0, $phitmp915 = 0, $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $0 = sp + 32|0;
 $1 = sp + 336|0;
 $2 = sp + 400|0;
 $3 = sp + 416|0;
 $4 = sp + 384|0;
 $5 = sp + 368|0;
 $6 = sp + 352|0;
 $7 = sp + 320|0;
 $8 = sp + 16|0;
 $9 = sp;
 $zeroV = sp + 112|0;
 $zero$sroa$1 = sp + 432|0;
 $_lambda$sroa$1 = sp + 460|0;
 $size = sp + 456|0;
 $Q = sp + 48|0;
 $A = sp + 128|0;
 $B = sp + 192|0;
 $support = sp + 256|0;
 $closA = sp + 272|0;
 $closB = sp + 288|0;
 $$sroa$1334 = sp + 444|0;
 $tempV = sp + 304|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $10 = Math_fround(HEAPF32[$r>>2]);
 $11 = (($r) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($r) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$s>>2]);
 $16 = (($s) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($s) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAP32[$size>>2] = 1;
 $20 = (($aToB) + 48|0);
 $21 = (($aToB) + 48|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($aToB) + 52|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 56|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($22 * $22);
 $28 = Math_fround($24 * $24);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = $31 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$20+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $33 = (($0) + 4|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($0) + 8|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($0) + 12|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $b$a$i205 = $32 ? $1 : $0;
 $36 = Math_fround(HEAPF32[$b$a$i205>>2]);
 $$in1$i208 = (($b$a$i205) + 4|0);
 $37 = Math_fround(HEAPF32[$$in1$i208>>2]);
 $$in2$i210 = (($b$a$i205) + 8|0);
 $38 = Math_fround(HEAPF32[$$in2$i210>>2]);
 $39 = Math_fround($36 * $36);
 $40 = Math_fround($37 * $37);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($38 * $38);
 $43 = Math_fround($41 + $42);
 $44 = (Math_fround(Math_sqrt((Math_fround($43)))));
 $45 = Math_fround(Math_fround(1.0) / $44);
 $46 = Math_fround($36 * $45);
 $47 = Math_fround($37 * $45);
 $48 = Math_fround($38 * $45);
 $49 = Math_fround(-$46);
 $50 = Math_fround(-$47);
 $51 = Math_fround(-$48);
 $52 = Math_fround(HEAPF32[$aToB>>2]);
 $53 = Math_fround($52 * $49);
 $54 = (($aToB) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * $50);
 $57 = Math_fround($53 + $56);
 $58 = (($aToB) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 * $51);
 $61 = Math_fround($57 + $60);
 $62 = (($aToB) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $49);
 $65 = (($aToB) + 20|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $50);
 $68 = Math_fround($64 + $67);
 $69 = (($aToB) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $51);
 $72 = Math_fround($68 + $71);
 $73 = (($aToB) + 32|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($74 * $49);
 $76 = (($aToB) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 * $50);
 $79 = Math_fround($75 + $78);
 $80 = (($aToB) + 40|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 * $51);
 $83 = Math_fround($79 + $82);
 $84 = $61 > Math_fround(0.0);
 $85 = $72 > Math_fround(0.0);
 $86 = $83 > Math_fround(0.0);
 $87 = (($a) + 144|0);
 ;HEAP32[$3+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$87+12>>2]|0;
 $88 = (($a) + 144|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($a) + 148|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($a) + 152|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround(-$89);
 $95 = Math_fround(-$91);
 $96 = Math_fround(-$93);
 HEAPF32[$2>>2] = $94;
 $97 = (($2) + 4|0);
 HEAPF32[$97>>2] = $95;
 $98 = (($2) + 8|0);
 HEAPF32[$98>>2] = $96;
 $99 = (($2) + 12|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $b$a$i$i$i$i189 = $84 ? $3 : $2;
 $100 = Math_fround(HEAPF32[$b$a$i$i$i$i189>>2]);
 $a$pn3$i$i$i$i191 = $85 ? $3 : $2;
 $$in1$i$i$i$i192 = (($a$pn3$i$i$i$i191) + 4|0);
 $101 = Math_fround(HEAPF32[$$in1$i$i$i$i192>>2]);
 $b$a5$i$i$i$i193 = $86 ? $3 : $2;
 $$in2$i$i$i$i194 = (($b$a5$i$i$i$i193) + 8|0);
 $102 = Math_fround(HEAPF32[$$in2$i$i$i$i194>>2]);
 $103 = Math_fround(HEAPF32[$21>>2]);
 $104 = Math_fround(HEAPF32[$23>>2]);
 $105 = Math_fround(HEAPF32[$25>>2]);
 $106 = Math_fround($52 * $100);
 $107 = Math_fround($63 * $101);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($74 * $102);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($55 * $100);
 $112 = Math_fround($66 * $101);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($77 * $102);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($59 * $100);
 $117 = Math_fround($70 * $101);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($81 * $102);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($110 + $103);
 $122 = Math_fround($115 + $104);
 $123 = Math_fround($120 + $105);
 $124 = $46 > Math_fround(0.0);
 $125 = $47 > Math_fround(0.0);
 $126 = $48 > Math_fround(0.0);
 $127 = (($b) + 144|0);
 ;HEAP32[$3+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$127+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$127+12>>2]|0;
 $128 = (($b) + 144|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = (($b) + 148|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($b) + 152|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround(-$129);
 $135 = Math_fround(-$131);
 $136 = Math_fround(-$133);
 HEAPF32[$2>>2] = $134;
 $137 = (($2) + 4|0);
 HEAPF32[$137>>2] = $135;
 $138 = (($2) + 8|0);
 HEAPF32[$138>>2] = $136;
 $139 = (($2) + 12|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $b$a$i$i$i183 = $124 ? $3 : $2;
 $140 = Math_fround(HEAPF32[$b$a$i$i$i183>>2]);
 $a$pn3$i$i$i185 = $125 ? $3 : $2;
 $$in1$i$i$i186 = (($a$pn3$i$i$i185) + 4|0);
 $141 = Math_fround(HEAPF32[$$in1$i$i$i186>>2]);
 $b$a5$i$i$i187 = $126 ? $3 : $2;
 $$in2$i$i$i188 = (($b$a5$i$i$i187) + 8|0);
 $142 = Math_fround(HEAPF32[$$in2$i$i$i188>>2]);
 $143 = Math_fround($121 - $140);
 $144 = Math_fround($122 - $141);
 $145 = Math_fround($123 - $142);
 HEAPF32[$Q>>2] = $143;
 $146 = (($Q) + 4|0);
 HEAPF32[$146>>2] = $144;
 $147 = (($Q) + 8|0);
 HEAPF32[$147>>2] = $145;
 $148 = (($Q) + 12|0);
 HEAPF32[$148>>2] = Math_fround(0.0);
 $149 = (($Q) + 16|0);
 ;HEAP32[$149+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$149+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$149+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$149+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $150 = (($Q) + 32|0);
 ;HEAP32[$150+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$150+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $151 = (($Q) + 48|0);
 ;HEAP32[$151+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$151+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$151+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$151+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $121;
 $152 = (($A) + 4|0);
 HEAPF32[$152>>2] = $122;
 $153 = (($A) + 8|0);
 HEAPF32[$153>>2] = $123;
 $154 = (($A) + 12|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 $155 = (($A) + 16|0);
 ;HEAP32[$155+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$155+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $156 = (($A) + 32|0);
 ;HEAP32[$156+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$156+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$156+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $157 = (($A) + 48|0);
 ;HEAP32[$157+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$157+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$B>>2] = $140;
 $158 = (($B) + 4|0);
 HEAPF32[$158>>2] = $141;
 $159 = (($B) + 8|0);
 HEAPF32[$159>>2] = $142;
 $160 = (($B) + 12|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 $161 = (($B) + 16|0);
 ;HEAP32[$161+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $162 = (($B) + 32|0);
 ;HEAP32[$162+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $163 = (($B) + 48|0);
 ;HEAP32[$163+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$163+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $164 = Math_fround(-$143);
 $165 = Math_fround(-$144);
 $166 = Math_fround(-$145);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $167 = (($a) + 32|0);
 $168 = Math_fround(HEAPF32[$167>>2]);
 $169 = (($b) + 32|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = $168 > $170;
 $$$i = $171 ? $170 : $168;
 $172 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $173 = Math_fround($172 * $172);
 $174 = Math_fround($_inflation * $_inflation);
 $175 = Math_fround($174 + $173);
 HEAPF32[$closA>>2] = $121;
 $176 = (($closA) + 4|0);
 HEAPF32[$176>>2] = $122;
 $177 = (($closA) + 8|0);
 HEAPF32[$177>>2] = $123;
 $178 = (($closA) + 12|0);
 HEAPF32[$178>>2] = Math_fround(0.0);
 HEAPF32[$closB>>2] = $140;
 $179 = (($closB) + 4|0);
 HEAPF32[$179>>2] = $141;
 $180 = (($closB) + 8|0);
 HEAPF32[$180>>2] = $142;
 $181 = (($closB) + 12|0);
 HEAPF32[$181>>2] = Math_fround(0.0);
 $182 = Math_fround($143 * $143);
 $183 = Math_fround($144 * $144);
 $184 = Math_fround($182 + $183);
 $185 = Math_fround($145 * $145);
 $186 = Math_fround($184 + $185);
 $187 = $186 > $173;
 L1: do {
  if ($187) {
   $188 = Math_fround($14 * Math_fround(0.0));
   $189 = Math_fround($12 * Math_fround(0.0));
   $190 = Math_fround($10 * Math_fround(0.0));
   $191 = Math_fround($188 + $19);
   $192 = Math_fround($189 + $17);
   $193 = Math_fround($190 + $15);
   $194 = (($2) + 4|0);
   $195 = (($2) + 8|0);
   $196 = (($2) + 12|0);
   $197 = (($2) + 4|0);
   $198 = (($2) + 8|0);
   $199 = (($2) + 12|0);
   $200 = (($support) + 4|0);
   $201 = (($support) + 8|0);
   $202 = (($support) + 12|0);
   $203 = (($B) + 16|0);
   $204 = (($B) + 20|0);
   $205 = (($B) + 24|0);
   $206 = (($B) + 28|0);
   $207 = (($B) + 32|0);
   $208 = (($B) + 36|0);
   $209 = (($B) + 40|0);
   $210 = (($B) + 44|0);
   $211 = (($A) + 16|0);
   $212 = (($A) + 20|0);
   $213 = (($A) + 24|0);
   $214 = (($Q) + 16|0);
   $215 = (($Q) + 20|0);
   $216 = (($Q) + 24|0);
   $217 = (($Q) + 28|0);
   $218 = (($A) + 32|0);
   $219 = (($A) + 36|0);
   $220 = (($A) + 40|0);
   $221 = (($Q) + 32|0);
   $222 = (($Q) + 36|0);
   $223 = (($Q) + 40|0);
   $224 = (($Q) + 44|0);
   $225 = (($2) + 4|0);
   $226 = (($2) + 8|0);
   $227 = (($2) + 12|0);
   $228 = (($tempV) + 4|0);
   $229 = (($tempV) + 8|0);
   $230 = (($tempV) + 12|0);
   $232 = $164;$234 = $165;$237 = $166;$314 = $193;$316 = $192;$318 = $191;$341 = Math_fround(0.0);$542 = Math_fround(0.0);$543 = $123;$544 = $122;$545 = $121;$546 = $164;$547 = $165;$548 = $166;$549 = $186;
   while(1) {
    $231 = Math_fround($232 * $232);
    $233 = Math_fround($234 * $234);
    $235 = Math_fround($233 + $231);
    $236 = Math_fround($237 * $237);
    $238 = Math_fround($236 + $235);
    $239 = (Math_fround(Math_sqrt((Math_fround($238)))));
    $240 = Math_fround(Math_fround(1.0) / $239);
    $241 = Math_fround($232 * $240);
    $242 = Math_fround($234 * $240);
    $243 = Math_fround($237 * $240);
    $244 = Math_fround(HEAPF32[$aToB>>2]);
    $245 = Math_fround($241 * $244);
    $246 = Math_fround(HEAPF32[$54>>2]);
    $247 = Math_fround($242 * $246);
    $248 = Math_fround($245 + $247);
    $249 = Math_fround(HEAPF32[$58>>2]);
    $250 = Math_fround($243 * $249);
    $251 = Math_fround($248 + $250);
    $252 = Math_fround(HEAPF32[$62>>2]);
    $253 = Math_fround($241 * $252);
    $254 = Math_fround(HEAPF32[$65>>2]);
    $255 = Math_fround($242 * $254);
    $256 = Math_fround($253 + $255);
    $257 = Math_fround(HEAPF32[$69>>2]);
    $258 = Math_fround($243 * $257);
    $259 = Math_fround($256 + $258);
    $260 = Math_fround(HEAPF32[$73>>2]);
    $261 = Math_fround($241 * $260);
    $262 = Math_fround(HEAPF32[$76>>2]);
    $263 = Math_fround($242 * $262);
    $264 = Math_fround($261 + $263);
    $265 = Math_fround(HEAPF32[$80>>2]);
    $266 = Math_fround($243 * $265);
    $267 = Math_fround($264 + $266);
    $268 = $251 > Math_fround(0.0);
    $269 = $259 > Math_fround(0.0);
    $270 = $267 > Math_fround(0.0);
    ;HEAP32[$3+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$87+12>>2]|0;
    $271 = Math_fround(HEAPF32[$88>>2]);
    $272 = Math_fround(HEAPF32[$90>>2]);
    $273 = Math_fround(HEAPF32[$92>>2]);
    $274 = Math_fround(-$271);
    $275 = Math_fround(-$272);
    $276 = Math_fround(-$273);
    HEAPF32[$2>>2] = $274;
    HEAPF32[$194>>2] = $275;
    HEAPF32[$195>>2] = $276;
    HEAPF32[$196>>2] = Math_fround(0.0);
    $b$a$i$i$i$i = $268 ? $3 : $2;
    $277 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
    $a$pn3$i$i$i$i = $269 ? $3 : $2;
    $$in1$i$i$i$i = (($a$pn3$i$i$i$i) + 4|0);
    $278 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
    $b$a5$i$i$i$i = $270 ? $3 : $2;
    $$in2$i$i$i$i = (($b$a5$i$i$i$i) + 8|0);
    $279 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
    $280 = Math_fround(HEAPF32[$21>>2]);
    $281 = Math_fround(HEAPF32[$23>>2]);
    $282 = Math_fround(HEAPF32[$25>>2]);
    $283 = Math_fround($244 * $277);
    $284 = Math_fround($252 * $278);
    $285 = Math_fround($283 + $284);
    $286 = Math_fround($260 * $279);
    $287 = Math_fround($285 + $286);
    $288 = Math_fround($246 * $277);
    $289 = Math_fround($254 * $278);
    $290 = Math_fround($288 + $289);
    $291 = Math_fround($262 * $279);
    $292 = Math_fround($290 + $291);
    $293 = Math_fround($249 * $277);
    $294 = Math_fround($257 * $278);
    $295 = Math_fround($293 + $294);
    $296 = Math_fround($265 * $279);
    $297 = Math_fround($295 + $296);
    $298 = Math_fround($287 + $280);
    $299 = Math_fround($292 + $281);
    $300 = Math_fround($297 + $282);
    $301 = $241 < Math_fround(-0.0);
    $302 = $242 < Math_fround(-0.0);
    $303 = $243 < Math_fround(-0.0);
    ;HEAP32[$3+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$127+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$127+12>>2]|0;
    $304 = Math_fround(HEAPF32[$128>>2]);
    $305 = Math_fround(HEAPF32[$130>>2]);
    $306 = Math_fround(HEAPF32[$132>>2]);
    $307 = Math_fround(-$304);
    $308 = Math_fround(-$305);
    $309 = Math_fround(-$306);
    HEAPF32[$2>>2] = $307;
    HEAPF32[$197>>2] = $308;
    HEAPF32[$198>>2] = $309;
    HEAPF32[$199>>2] = Math_fround(0.0);
    $b$a$i$i$i139 = $301 ? $3 : $2;
    $310 = Math_fround(HEAPF32[$b$a$i$i$i139>>2]);
    $a$pn3$i$i$i141 = $302 ? $3 : $2;
    $$in1$i$i$i142 = (($a$pn3$i$i$i141) + 4|0);
    $311 = Math_fround(HEAPF32[$$in1$i$i$i142>>2]);
    $b$a5$i$i$i143 = $303 ? $3 : $2;
    $$in2$i$i$i144 = (($b$a5$i$i$i143) + 8|0);
    $312 = Math_fround(HEAPF32[$$in2$i$i$i144>>2]);
    $313 = Math_fround($314 + $310);
    $315 = Math_fround($316 + $311);
    $317 = Math_fround($318 + $312);
    $319 = Math_fround($298 - $313);
    $320 = Math_fround($299 - $315);
    $321 = Math_fround($300 - $317);
    HEAPF32[$support>>2] = $319;
    HEAPF32[$200>>2] = $320;
    HEAPF32[$201>>2] = $321;
    HEAPF32[$202>>2] = Math_fround(0.0);
    $322 = Math_fround($241 * $319);
    $323 = Math_fround($242 * $320);
    $324 = Math_fround(-$323);
    $325 = Math_fround($324 - $322);
    $326 = Math_fround($243 * $321);
    $327 = Math_fround($325 - $326);
    $328 = Math_fround($327 - $_inflation);
    $329 = Math_fround(HEAPF32[$r>>2]);
    $330 = Math_fround(HEAPF32[$11>>2]);
    $331 = Math_fround(HEAPF32[$13>>2]);
    $332 = Math_fround($241 * $329);
    $333 = Math_fround($242 * $330);
    $334 = Math_fround($332 + $333);
    $335 = Math_fround($243 * $331);
    $336 = Math_fround($334 + $335);
    $337 = $328 > Math_fround(0.0);
    if ($337) {
     $338 = !($336 >= Math_fround(0.0));
     if (!($338)) {
      $$0 = 0;
      label = 22;
      break;
     }
     $339 = Math_fround($328 / $336);
     $340 = Math_fround($341 - $339);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1334+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1334+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1334+8>>2]|0;
     $342 = $340 > $341;
     if ($342) {
      $343 = $340 > Math_fround(1.0);
      if ($343) {
       $$0 = 0;
       label = 22;
       break;
      }
      $344 = Math_fround(HEAPF32[$s>>2]);
      $345 = Math_fround(HEAPF32[$16>>2]);
      $346 = Math_fround(HEAPF32[$18>>2]);
      $347 = Math_fround($340 * $329);
      $348 = Math_fround($340 * $330);
      $349 = Math_fround($340 * $331);
      $350 = Math_fround($347 + $344);
      $351 = Math_fround($348 + $345);
      $352 = Math_fround($349 + $346);
      $353 = Math_fround($350 - $314);
      $354 = Math_fround($351 - $316);
      $355 = Math_fround($352 - $318);
      $356 = Math_fround(HEAPF32[$B>>2]);
      $357 = Math_fround(HEAPF32[$158>>2]);
      $358 = Math_fround(HEAPF32[$159>>2]);
      $359 = Math_fround($353 + $356);
      $360 = Math_fround($354 + $357);
      $361 = Math_fround($355 + $358);
      $362 = Math_fround(HEAPF32[$203>>2]);
      $363 = Math_fround(HEAPF32[$204>>2]);
      $364 = Math_fround(HEAPF32[$205>>2]);
      $365 = Math_fround($353 + $362);
      $366 = Math_fround($354 + $363);
      $367 = Math_fround($355 + $364);
      $368 = Math_fround(HEAPF32[$207>>2]);
      $369 = Math_fround(HEAPF32[$208>>2]);
      $370 = Math_fround(HEAPF32[$209>>2]);
      $371 = Math_fround($353 + $368);
      $372 = Math_fround($354 + $369);
      $373 = Math_fround($355 + $370);
      HEAPF32[$B>>2] = $359;
      HEAPF32[$158>>2] = $360;
      HEAPF32[$159>>2] = $361;
      HEAPF32[$160>>2] = Math_fround(0.0);
      HEAPF32[$203>>2] = $365;
      HEAPF32[$204>>2] = $366;
      HEAPF32[$205>>2] = $367;
      HEAPF32[$206>>2] = Math_fround(0.0);
      HEAPF32[$207>>2] = $371;
      HEAPF32[$208>>2] = $372;
      HEAPF32[$209>>2] = $373;
      HEAPF32[$210>>2] = Math_fround(0.0);
      $374 = Math_fround(HEAPF32[$A>>2]);
      $375 = Math_fround(HEAPF32[$152>>2]);
      $376 = Math_fround(HEAPF32[$153>>2]);
      $377 = Math_fround($374 - $359);
      $378 = Math_fround($375 - $360);
      $379 = Math_fround($376 - $361);
      HEAPF32[$Q>>2] = $377;
      HEAPF32[$146>>2] = $378;
      HEAPF32[$147>>2] = $379;
      HEAPF32[$148>>2] = Math_fround(0.0);
      $380 = Math_fround(HEAPF32[$211>>2]);
      $381 = Math_fround(HEAPF32[$212>>2]);
      $382 = Math_fround(HEAPF32[$213>>2]);
      $383 = Math_fround($380 - $365);
      $384 = Math_fround($381 - $366);
      $385 = Math_fround($382 - $367);
      HEAPF32[$214>>2] = $383;
      HEAPF32[$215>>2] = $384;
      HEAPF32[$216>>2] = $385;
      HEAPF32[$217>>2] = Math_fround(0.0);
      $386 = Math_fround(HEAPF32[$218>>2]);
      $387 = Math_fround(HEAPF32[$219>>2]);
      $388 = Math_fround(HEAPF32[$220>>2]);
      $389 = Math_fround($386 - $371);
      $390 = Math_fround($387 - $372);
      $391 = Math_fround($388 - $373);
      HEAPF32[$221>>2] = $389;
      HEAPF32[$222>>2] = $390;
      HEAPF32[$223>>2] = $391;
      HEAPF32[$224>>2] = Math_fround(0.0);
      ;HEAP32[$3+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$127+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$127+12>>2]|0;
      HEAPF32[$2>>2] = $307;
      HEAPF32[$225>>2] = $308;
      HEAPF32[$226>>2] = $309;
      HEAPF32[$227>>2] = Math_fround(0.0);
      $b$a$i$i$i = $301 ? $3 : $2;
      $392 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
      $a$pn3$i$i$i = $302 ? $3 : $2;
      $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
      $393 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
      $b$a5$i$i$i = $303 ? $3 : $2;
      $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
      $394 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
      $395 = Math_fround($350 + $392);
      $396 = Math_fround($351 + $393);
      $397 = Math_fround($352 + $394);
      $398 = Math_fround($298 - $395);
      $399 = Math_fround($299 - $396);
      $400 = Math_fround($300 - $397);
      HEAPF32[$support>>2] = $398;
      HEAPF32[$200>>2] = $399;
      HEAPF32[$201>>2] = $400;
      HEAPF32[$202>>2] = Math_fround(0.0);
      $407 = $395;$409 = $396;$411 = $397;$419 = $398;$421 = $399;$423 = $400;$478 = Math_fround(3.40282346638528859812E+38);$550 = $340;$551 = $352;$552 = $351;$553 = $350;$554 = $237;$555 = $234;$556 = $232;
     } else {
      $407 = $313;$409 = $315;$411 = $317;$419 = $319;$421 = $320;$423 = $321;$478 = $549;$550 = $340;$551 = $318;$552 = $316;$553 = $314;$554 = $548;$555 = $547;$556 = $546;
     }
    } else {
     $407 = $313;$409 = $315;$411 = $317;$419 = $319;$421 = $320;$423 = $321;$478 = $549;$550 = $341;$551 = $318;$552 = $316;$553 = $314;$554 = $548;$555 = $547;$556 = $546;
    }
    $401 = HEAP32[$size>>2]|0;
    $402 = (($A) + ($401<<4)|0);
    HEAPF32[$402>>2] = $298;
    $403 = ((($A) + ($401<<4)|0) + 4|0);
    HEAPF32[$403>>2] = $299;
    $404 = ((($A) + ($401<<4)|0) + 8|0);
    HEAPF32[$404>>2] = $300;
    $405 = ((($A) + ($401<<4)|0) + 12|0);
    HEAPF32[$405>>2] = Math_fround(0.0);
    $406 = (($B) + ($401<<4)|0);
    HEAPF32[$406>>2] = $407;
    $408 = ((($B) + ($401<<4)|0) + 4|0);
    HEAPF32[$408>>2] = $409;
    $410 = ((($B) + ($401<<4)|0) + 8|0);
    HEAPF32[$410>>2] = $411;
    $412 = ((($B) + ($401<<4)|0) + 12|0);
    HEAPF32[$412>>2] = Math_fround(0.0);
    $413 = (($401) + 1)|0;
    HEAP32[$size>>2] = $413;
    $414 = (($Q) + ($401<<4)|0);
    ;HEAP32[$414+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$414+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$414+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$414+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($401|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($401|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$149,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($401|0) == 0)) {
      HEAPF32[$closA>>2] = $298;
      HEAPF32[$176>>2] = $299;
      HEAPF32[$177>>2] = $300;
      HEAPF32[$178>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $407;
      HEAPF32[$179>>2] = $409;
      HEAPF32[$180>>2] = $411;
      HEAPF32[$181>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($401|0) == 1)) {
      $415 = Math_fround(HEAPF32[$Q>>2]);
      $416 = Math_fround(HEAPF32[$146>>2]);
      $417 = Math_fround(HEAPF32[$147>>2]);
      $418 = Math_fround($419 - $415);
      $420 = Math_fround($421 - $416);
      $422 = Math_fround($423 - $417);
      $424 = Math_fround($418 * $418);
      $425 = Math_fround($420 * $420);
      $426 = Math_fround($424 + $425);
      $427 = Math_fround($422 * $422);
      $428 = Math_fround($426 + $427);
      $429 = $428 == Math_fround(0.0);
      if ($429) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $430 = Math_fround($416 * $420);
       $431 = Math_fround(-$430);
       $432 = Math_fround($415 * $418);
       $433 = Math_fround($431 - $432);
       $434 = Math_fround($417 * $422);
       $435 = Math_fround($433 - $434);
       $436 = Math_fround(HEAPF32[$A>>2]);
       $437 = Math_fround(HEAPF32[$152>>2]);
       $438 = Math_fround(HEAPF32[$153>>2]);
       $439 = Math_fround($298 - $436);
       $440 = Math_fround($299 - $437);
       $441 = Math_fround($300 - $438);
       $442 = Math_fround(HEAPF32[$B>>2]);
       $443 = Math_fround(HEAPF32[$158>>2]);
       $444 = Math_fround(HEAPF32[$159>>2]);
       $445 = Math_fround($407 - $442);
       $446 = Math_fround($409 - $443);
       $447 = Math_fround($411 - $444);
       $448 = Math_fround($435 / $428);
       $449 = $448 > Math_fround(1.0);
       $$$i$i$i = $449 ? Math_fround(1.0) : $448;
       $450 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $450 ? $$$i$i$i : Math_fround(0.0);
       $451 = Math_fround($439 * $$$i8$i$i);
       $452 = Math_fround($440 * $$$i8$i$i);
       $453 = Math_fround($441 * $$$i8$i$i);
       $454 = Math_fround($436 + $451);
       $455 = Math_fround($437 + $452);
       $456 = Math_fround($438 + $453);
       $457 = Math_fround($445 * $$$i8$i$i);
       $458 = Math_fround($446 * $$$i8$i$i);
       $459 = Math_fround($447 * $$$i8$i$i);
       $460 = Math_fround($442 + $457);
       $461 = Math_fround($443 + $458);
       $462 = Math_fround($444 + $459);
       HEAPF32[$closA>>2] = $454;
       HEAPF32[$176>>2] = $455;
       HEAPF32[$177>>2] = $456;
       HEAPF32[$178>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $460;
       HEAPF32[$179>>2] = $461;
       HEAPF32[$180>>2] = $462;
       HEAPF32[$181>>2] = Math_fround(0.0);
       $463 = Math_fround($454 - $460);
       $464 = Math_fround($455 - $461);
       $465 = Math_fround($456 - $462);
       HEAPF32[$tempV>>2] = $463;
       HEAPF32[$228>>2] = $464;
       HEAPF32[$229>>2] = $465;
       HEAPF32[$230>>2] = Math_fround(0.0);
       break;
      }
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $466 = Math_fround(HEAPF32[$tempV>>2]);
    $467 = Math_fround(HEAPF32[$228>>2]);
    $468 = Math_fround(HEAPF32[$229>>2]);
    $469 = Math_fround(-$466);
    $470 = Math_fround(-$467);
    $471 = Math_fround(-$468);
    $472 = Math_fround($466 * $466);
    $473 = Math_fround($467 * $467);
    $474 = Math_fround($472 + $473);
    $475 = Math_fround($468 * $468);
    $476 = Math_fround($474 + $475);
    $477 = $478 > $476;
    $479 = $477 << 31 >> 31;
    $480 = $476 > $175;
    if (!($480)) {
     $$lcssa = $550;$$lcssa922 = $542;$$lcssa924 = $543;$$lcssa926 = $544;$$lcssa928 = $545;$$lcssa930 = $471;$$lcssa932 = $470;$$lcssa934 = $469;$$lcssa936 = $476;$$lcssa938 = $479;$$lcssa940 = $554;$$lcssa942 = $555;$$lcssa944 = $556;
     break L1;
    }
    if (!($477)) {
     $$lcssa = $550;$$lcssa922 = $542;$$lcssa924 = $543;$$lcssa926 = $544;$$lcssa928 = $545;$$lcssa930 = $471;$$lcssa932 = $470;$$lcssa934 = $469;$$lcssa936 = $476;$$lcssa938 = $479;$$lcssa940 = $554;$$lcssa942 = $555;$$lcssa944 = $556;
     break L1;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre978 = Math_fround(HEAPF32[$176>>2]);
    $$pre979 = Math_fround(HEAPF32[$177>>2]);
    $$pre980 = Math_fround(HEAPF32[$178>>2]);
    $232 = $469;$234 = $470;$237 = $471;$314 = $553;$316 = $552;$318 = $551;$341 = $550;$542 = $$pre980;$543 = $$pre979;$544 = $$pre978;$545 = $$pre;$546 = $556;$547 = $555;$548 = $554;$549 = $476;
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa922 = Math_fround(0.0);$$lcssa924 = $123;$$lcssa926 = $122;$$lcssa928 = $121;$$lcssa930 = $166;$$lcssa932 = $165;$$lcssa934 = $164;$$lcssa936 = $186;$$lcssa938 = -1;$$lcssa940 = $166;$$lcssa942 = $165;$$lcssa944 = $164;
  }
 } while(0);
 $481 = (($a) + 64|0);
 $482 = HEAP32[$481>>2]|0;
 $483 = (($a) + 68|0);
 $484 = HEAP32[$483>>2]|0;
 $485 = (($a) + 72|0);
 $486 = HEAP32[$485>>2]|0;
 $487 = $$lcssa936 > $173;
 if ($487) {
  $phitmp = ($$lcssa938|0)==(0);
  $phitmp915 = $phitmp ? $4 : $5;
  $495 = $phitmp915;
 } else {
  $495 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa934;
 $488 = (($5) + 4|0);
 HEAPF32[$488>>2] = $$lcssa932;
 $489 = (($5) + 8|0);
 HEAPF32[$489>>2] = $$lcssa930;
 $490 = (($5) + 12|0);
 HEAPF32[$490>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa944;
 $491 = (($4) + 4|0);
 HEAPF32[$491>>2] = $$lcssa942;
 $492 = (($4) + 8|0);
 HEAPF32[$492>>2] = $$lcssa940;
 $493 = (($4) + 12|0);
 HEAPF32[$493>>2] = Math_fround(0.0);
 $494 = Math_fround(HEAPF32[$495>>2]);
 $$in1$i37 = (($495) + 4|0);
 $496 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($495) + 8|0);
 $497 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $498 = Math_fround($494 * $494);
 $499 = Math_fround($496 * $496);
 $500 = Math_fround($498 + $499);
 $501 = Math_fround($497 * $497);
 $502 = Math_fround($500 + $501);
 $503 = (Math_fround(Math_sqrt((Math_fround($502)))));
 $504 = Math_fround(Math_fround(1.0) / $503);
 $505 = Math_fround($494 * $504);
 $506 = Math_fround($496 * $504);
 $507 = Math_fround($497 * $504);
 $508 = Math_fround(-$505);
 $509 = Math_fround(-$506);
 $510 = Math_fround(-$507);
 HEAPF32[$normal>>2] = $508;
 $511 = (($normal) + 4|0);
 HEAPF32[$511>>2] = $509;
 $512 = (($normal) + 8|0);
 HEAPF32[$512>>2] = $510;
 $513 = (($normal) + 12|0);
 HEAPF32[$513>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $514 = (($lambda) + 4|0);
 ;HEAP32[$514+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$514+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$514+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$6>>2] = $$lcssa928;
 $515 = (($6) + 4|0);
 HEAPF32[$515>>2] = $$lcssa926;
 $516 = (($6) + 8|0);
 HEAPF32[$516>>2] = $$lcssa924;
 $517 = (($6) + 12|0);
 HEAPF32[$517>>2] = $$lcssa922;
 $518 = ($$lcssa938|0)==(0);
 $b$a$i18 = $518 ? $6 : $7;
 $519 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $520 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $521 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $519;
 HEAPF32[$176>>2] = $520;
 HEAPF32[$177>>2] = $521;
 HEAPF32[$178>>2] = Math_fround(0.0);
 $522 = (($a) + 16|0);
 $523 = Math_fround(HEAPF32[$522>>2]);
 $524 = Math_fround($523 * $508);
 $525 = Math_fround($523 * $509);
 $526 = Math_fround($523 * $510);
 $527 = Math_fround($519 - $524);
 $528 = Math_fround($520 - $525);
 $529 = Math_fround($521 - $526);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $527;
 $530 = (($9) + 4|0);
 HEAPF32[$530>>2] = $528;
 $531 = (($9) + 8|0);
 HEAPF32[$531>>2] = $529;
 $532 = (($9) + 12|0);
 HEAPF32[$532>>2] = Math_fround(0.0);
 $533 = ($482|0)==(0);
 $b$a$i = $533 ? $8 : $9;
 $534 = Math_fround(HEAPF32[$b$a$i>>2]);
 $535 = ($484|0)==(0);
 $a$pn3$i = $535 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $536 = Math_fround(HEAPF32[$$in1$i>>2]);
 $537 = ($486|0)==(0);
 $b$a5$i = $537 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $538 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $534;
 $539 = (($closestA) + 4|0);
 HEAPF32[$539>>2] = $536;
 $540 = (($closestA) + 8|0);
 HEAPF32[$540>>2] = $538;
 $541 = (($closestA) + 12|0);
 HEAPF32[$541>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_8CapsuleVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i$i = 0, $$in1$i$i$i$i179 = 0, $$in1$i200 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i$i = 0, $$in2$i$i$i$i180 = 0, $$in2$i202 = 0, $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa900 = Math_fround(0), $$lcssa902 = Math_fround(0), $$lcssa904 = Math_fround(0);
 var $$lcssa906 = Math_fround(0), $$lcssa908 = Math_fround(0), $$lcssa910 = Math_fround(0), $$lcssa912 = Math_fround(0), $$lcssa914 = Math_fround(0), $$lcssa916 = 0, $$lcssa918 = Math_fround(0), $$lcssa920 = Math_fround(0), $$lcssa922 = Math_fround(0), $$pre = Math_fround(0), $$pre956 = Math_fround(0), $$pre957 = Math_fround(0), $$pre958 = Math_fround(0), $$sroa$1316 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0;
 var $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0;
 var $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0;
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0);
 var $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0);
 var $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0);
 var $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0);
 var $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0;
 var $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0);
 var $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0);
 var $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0);
 var $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0);
 var $41 = Math_fround(0), $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0);
 var $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0);
 var $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0);
 var $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0;
 var $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = 0, $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = Math_fround(0), $535 = 0;
 var $536 = Math_fround(0), $537 = 0, $538 = Math_fround(0), $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0);
 var $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0;
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0;
 var $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $b$a$i = 0, $b$a$i$i$i$i = 0, $b$a$i$i$i$i177 = 0, $b$a$i18 = 0;
 var $b$a$i197 = 0, $b$a5$i = 0, $closA = 0, $closB = 0, $initialSearchDir = 0, $initialSupportB = 0, $nvNorm = 0, $phitmp = 0, $phitmp893 = 0, $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 336|0;
 $1 = sp + 496|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $4 = sp + 384|0;
 $5 = sp + 400|0;
 $6 = sp + 432|0;
 $7 = sp + 416|0;
 $8 = sp + 448|0;
 $9 = sp + 464|0;
 $zeroV = sp + 480|0;
 $zero$sroa$1 = sp + 528|0;
 $_lambda$sroa$1 = sp + 540|0;
 $size = sp + 524|0;
 $initialSearchDir = sp + 208|0;
 $initialSupportB = sp;
 $Q = sp + 16|0;
 $A = sp + 80|0;
 $B = sp + 144|0;
 $support = sp + 224|0;
 $closA = sp + 240|0;
 $closB = sp + 256|0;
 $nvNorm = sp + 272|0;
 $10 = sp + 288|0;
 $$sroa$1316 = sp + 512|0;
 $11 = sp + 304|0;
 $tempV = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $12 = Math_fround(HEAPF32[$r>>2]);
 $13 = (($r) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($r) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$s>>2]);
 $18 = (($s) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($s) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAP32[$size>>2] = 1;
 $22 = (($aToB) + 48|0);
 $23 = (($aToB) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($aToB) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($24 * $24);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($28 * $28);
 $33 = Math_fround($31 + $32);
 $34 = $33 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$22+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $35 = (($0) + 4|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($0) + 8|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($0) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $b$a$i197 = $34 ? $1 : $0;
 $38 = Math_fround(HEAPF32[$b$a$i197>>2]);
 $$in1$i200 = (($b$a$i197) + 4|0);
 $39 = Math_fround(HEAPF32[$$in1$i200>>2]);
 $$in2$i202 = (($b$a$i197) + 8|0);
 $40 = Math_fround(HEAPF32[$$in2$i202>>2]);
 $41 = Math_fround($38 * $38);
 $42 = Math_fround($39 * $39);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($40 * $40);
 $45 = Math_fround($43 + $44);
 $46 = (Math_fround(Math_sqrt((Math_fround($45)))));
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = Math_fround($38 * $47);
 $49 = Math_fround($39 * $47);
 $50 = Math_fround($40 * $47);
 HEAPF32[$initialSearchDir>>2] = $48;
 $51 = (($initialSearchDir) + 4|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($initialSearchDir) + 8|0);
 HEAPF32[$52>>2] = $50;
 $53 = (($initialSearchDir) + 12|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = Math_fround(-$48);
 $55 = Math_fround(-$49);
 $56 = Math_fround(-$50);
 $57 = Math_fround(HEAPF32[$aToB>>2]);
 $58 = Math_fround($57 * $54);
 $59 = (($aToB) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 * $55);
 $62 = Math_fround($58 + $61);
 $63 = (($aToB) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 * $56);
 $66 = Math_fround($62 + $65);
 $67 = (($aToB) + 16|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 * $54);
 $70 = (($aToB) + 20|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $55);
 $73 = Math_fround($69 + $72);
 $74 = (($aToB) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 * $56);
 $77 = Math_fround($73 + $76);
 $78 = (($aToB) + 32|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 * $54);
 $81 = (($aToB) + 36|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 * $55);
 $84 = Math_fround($80 + $83);
 $85 = (($aToB) + 40|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 * $56);
 $88 = Math_fround($84 + $87);
 $89 = (($a) + 96|0);
 $90 = (($a) + 96|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($a) + 100|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($a) + 104|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($66 * $91);
 $97 = Math_fround($77 * $93);
 $98 = Math_fround($96 + $97);
 $99 = Math_fround($88 * $95);
 $100 = Math_fround($98 + $99);
 $101 = (($a) + 112|0);
 $102 = (($a) + 112|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($a) + 116|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($a) + 120|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($66 * $103);
 $109 = Math_fround($77 * $105);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($88 * $107);
 $112 = Math_fround($110 + $111);
 $113 = $100 > $112;
 ;HEAP32[$3+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$89+12>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$101+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$101+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$101+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$101+12>>2]|0;
 $b$a$i$i$i$i177 = $113 ? $3 : $2;
 $114 = Math_fround(HEAPF32[$b$a$i$i$i$i177>>2]);
 $$in1$i$i$i$i179 = (($b$a$i$i$i$i177) + 4|0);
 $115 = Math_fround(HEAPF32[$$in1$i$i$i$i179>>2]);
 $$in2$i$i$i$i180 = (($b$a$i$i$i$i177) + 8|0);
 $116 = Math_fround(HEAPF32[$$in2$i$i$i$i180>>2]);
 $117 = Math_fround(HEAPF32[$23>>2]);
 $118 = Math_fround(HEAPF32[$25>>2]);
 $119 = Math_fround(HEAPF32[$27>>2]);
 $120 = Math_fround($57 * $114);
 $121 = Math_fround($68 * $115);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($79 * $116);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($60 * $114);
 $126 = Math_fround($71 * $115);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround($82 * $116);
 $129 = Math_fround($127 + $128);
 $130 = Math_fround($64 * $114);
 $131 = Math_fround($75 * $115);
 $132 = Math_fround($130 + $131);
 $133 = Math_fround($86 * $116);
 $134 = Math_fround($132 + $133);
 $135 = Math_fround($124 + $117);
 $136 = Math_fround($129 + $118);
 $137 = Math_fround($134 + $119);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($initialSupportB,$b,$initialSearchDir);
 $138 = Math_fround(HEAPF32[$initialSupportB>>2]);
 $139 = (($initialSupportB) + 4|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($initialSupportB) + 8|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround($135 - $138);
 $144 = Math_fround($136 - $140);
 $145 = Math_fround($137 - $142);
 HEAPF32[$Q>>2] = $143;
 $146 = (($Q) + 4|0);
 HEAPF32[$146>>2] = $144;
 $147 = (($Q) + 8|0);
 HEAPF32[$147>>2] = $145;
 $148 = (($Q) + 12|0);
 HEAPF32[$148>>2] = Math_fround(0.0);
 $149 = (($Q) + 16|0);
 ;HEAP32[$149+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$149+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$149+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$149+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $150 = (($Q) + 32|0);
 ;HEAP32[$150+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$150+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $151 = (($Q) + 48|0);
 ;HEAP32[$151+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$151+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$151+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$151+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $135;
 $152 = (($A) + 4|0);
 HEAPF32[$152>>2] = $136;
 $153 = (($A) + 8|0);
 HEAPF32[$153>>2] = $137;
 $154 = (($A) + 12|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 $155 = (($A) + 16|0);
 ;HEAP32[$155+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$155+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $156 = (($A) + 32|0);
 ;HEAP32[$156+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$156+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$156+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $157 = (($A) + 48|0);
 ;HEAP32[$157+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$157+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$B+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $158 = (($B) + 16|0);
 ;HEAP32[$158+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$158+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $159 = (($B) + 32|0);
 ;HEAP32[$159+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$159+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $160 = (($B) + 48|0);
 ;HEAP32[$160+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$160+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$160+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$160+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $161 = Math_fround(-$143);
 $162 = Math_fround(-$144);
 $163 = Math_fround(-$145);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $164 = (($a) + 32|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = (($b) + 32|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = $165 > $167;
 $$$i = $168 ? $167 : $165;
 $169 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $170 = Math_fround($169 * $169);
 $171 = Math_fround($_inflation * $_inflation);
 $172 = Math_fround($171 + $170);
 HEAPF32[$closA>>2] = $135;
 $173 = (($closA) + 4|0);
 HEAPF32[$173>>2] = $136;
 $174 = (($closA) + 8|0);
 HEAPF32[$174>>2] = $137;
 $175 = (($closA) + 12|0);
 HEAPF32[$175>>2] = Math_fround(0.0);
 ;HEAP32[$closB+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $176 = Math_fround($143 * $143);
 $177 = Math_fround($144 * $144);
 $178 = Math_fround($176 + $177);
 $179 = Math_fround($145 * $145);
 $180 = Math_fround($178 + $179);
 $181 = $180 > $170;
 L1: do {
  if ($181) {
   $182 = Math_fround($16 * Math_fround(0.0));
   $183 = Math_fround($14 * Math_fround(0.0));
   $184 = Math_fround($12 * Math_fround(0.0));
   $185 = Math_fround($182 + $21);
   $186 = Math_fround($183 + $19);
   $187 = Math_fround($184 + $17);
   $188 = (($nvNorm) + 4|0);
   $189 = (($nvNorm) + 8|0);
   $190 = (($nvNorm) + 12|0);
   $191 = (($10) + 4|0);
   $192 = (($10) + 8|0);
   $193 = (($support) + 4|0);
   $194 = (($support) + 8|0);
   $195 = (($support) + 12|0);
   $196 = (($B) + 4|0);
   $197 = (($B) + 8|0);
   $198 = (($B) + 12|0);
   $199 = (($B) + 16|0);
   $200 = (($B) + 20|0);
   $201 = (($B) + 24|0);
   $202 = (($B) + 28|0);
   $203 = (($B) + 32|0);
   $204 = (($B) + 36|0);
   $205 = (($B) + 40|0);
   $206 = (($B) + 44|0);
   $207 = (($A) + 16|0);
   $208 = (($A) + 20|0);
   $209 = (($A) + 24|0);
   $210 = (($Q) + 16|0);
   $211 = (($Q) + 20|0);
   $212 = (($Q) + 24|0);
   $213 = (($Q) + 28|0);
   $214 = (($A) + 32|0);
   $215 = (($A) + 36|0);
   $216 = (($A) + 40|0);
   $217 = (($Q) + 32|0);
   $218 = (($Q) + 36|0);
   $219 = (($Q) + 40|0);
   $220 = (($Q) + 44|0);
   $221 = (($11) + 4|0);
   $222 = (($11) + 8|0);
   $223 = (($tempV) + 4|0);
   $224 = (($tempV) + 8|0);
   $225 = (($closB) + 4|0);
   $226 = (($closB) + 8|0);
   $227 = (($closB) + 12|0);
   $228 = (($tempV) + 12|0);
   $230 = $161;$232 = $162;$235 = $163;$314 = $187;$316 = $186;$318 = $185;$341 = Math_fround(0.0);$542 = Math_fround(0.0);$543 = $137;$544 = $136;$545 = $135;$546 = $161;$547 = $162;$548 = $163;$549 = $180;
   while(1) {
    $229 = Math_fround($230 * $230);
    $231 = Math_fround($232 * $232);
    $233 = Math_fround($231 + $229);
    $234 = Math_fround($235 * $235);
    $236 = Math_fround($234 + $233);
    $237 = (Math_fround(Math_sqrt((Math_fround($236)))));
    $238 = Math_fround(Math_fround(1.0) / $237);
    $239 = Math_fround($230 * $238);
    $240 = Math_fround($232 * $238);
    $241 = Math_fround($235 * $238);
    $242 = Math_fround(-$239);
    $243 = Math_fround(-$240);
    $244 = Math_fround(-$241);
    HEAPF32[$nvNorm>>2] = $242;
    HEAPF32[$188>>2] = $243;
    HEAPF32[$189>>2] = $244;
    HEAPF32[$190>>2] = Math_fround(0.0);
    $245 = Math_fround(HEAPF32[$aToB>>2]);
    $246 = Math_fround($239 * $245);
    $247 = Math_fround(HEAPF32[$59>>2]);
    $248 = Math_fround($240 * $247);
    $249 = Math_fround($246 + $248);
    $250 = Math_fround(HEAPF32[$63>>2]);
    $251 = Math_fround($241 * $250);
    $252 = Math_fround($249 + $251);
    $253 = Math_fround(HEAPF32[$67>>2]);
    $254 = Math_fround($239 * $253);
    $255 = Math_fround(HEAPF32[$70>>2]);
    $256 = Math_fround($240 * $255);
    $257 = Math_fround($254 + $256);
    $258 = Math_fround(HEAPF32[$74>>2]);
    $259 = Math_fround($241 * $258);
    $260 = Math_fround($257 + $259);
    $261 = Math_fround(HEAPF32[$78>>2]);
    $262 = Math_fround($239 * $261);
    $263 = Math_fround(HEAPF32[$81>>2]);
    $264 = Math_fround($240 * $263);
    $265 = Math_fround($262 + $264);
    $266 = Math_fround(HEAPF32[$85>>2]);
    $267 = Math_fround($241 * $266);
    $268 = Math_fround($265 + $267);
    $269 = Math_fround(HEAPF32[$90>>2]);
    $270 = Math_fround(HEAPF32[$92>>2]);
    $271 = Math_fround(HEAPF32[$94>>2]);
    $272 = Math_fround($252 * $269);
    $273 = Math_fround($260 * $270);
    $274 = Math_fround($272 + $273);
    $275 = Math_fround($268 * $271);
    $276 = Math_fround($274 + $275);
    $277 = Math_fround(HEAPF32[$102>>2]);
    $278 = Math_fround(HEAPF32[$104>>2]);
    $279 = Math_fround(HEAPF32[$106>>2]);
    $280 = Math_fround($252 * $277);
    $281 = Math_fround($260 * $278);
    $282 = Math_fround($280 + $281);
    $283 = Math_fround($268 * $279);
    $284 = Math_fround($282 + $283);
    $285 = $276 > $284;
    ;HEAP32[$3+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$89+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$101+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$101+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$101+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$101+12>>2]|0;
    $b$a$i$i$i$i = $285 ? $3 : $2;
    $286 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
    $$in1$i$i$i$i = (($b$a$i$i$i$i) + 4|0);
    $287 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
    $$in2$i$i$i$i = (($b$a$i$i$i$i) + 8|0);
    $288 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
    $289 = Math_fround(HEAPF32[$23>>2]);
    $290 = Math_fround(HEAPF32[$25>>2]);
    $291 = Math_fround(HEAPF32[$27>>2]);
    $292 = Math_fround($245 * $286);
    $293 = Math_fround($253 * $287);
    $294 = Math_fround($292 + $293);
    $295 = Math_fround($261 * $288);
    $296 = Math_fround($294 + $295);
    $297 = Math_fround($247 * $286);
    $298 = Math_fround($255 * $287);
    $299 = Math_fround($297 + $298);
    $300 = Math_fround($263 * $288);
    $301 = Math_fround($299 + $300);
    $302 = Math_fround($250 * $286);
    $303 = Math_fround($258 * $287);
    $304 = Math_fround($302 + $303);
    $305 = Math_fround($266 * $288);
    $306 = Math_fround($304 + $305);
    $307 = Math_fround($296 + $289);
    $308 = Math_fround($301 + $290);
    $309 = Math_fround($306 + $291);
    __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($10,$b,$nvNorm);
    $310 = Math_fround(HEAPF32[$10>>2]);
    $311 = Math_fround(HEAPF32[$191>>2]);
    $312 = Math_fround(HEAPF32[$192>>2]);
    $313 = Math_fround($314 + $310);
    $315 = Math_fround($316 + $311);
    $317 = Math_fround($318 + $312);
    $319 = Math_fround($307 - $313);
    $320 = Math_fround($308 - $315);
    $321 = Math_fround($309 - $317);
    HEAPF32[$support>>2] = $319;
    HEAPF32[$193>>2] = $320;
    HEAPF32[$194>>2] = $321;
    HEAPF32[$195>>2] = Math_fround(0.0);
    $322 = Math_fround($239 * $319);
    $323 = Math_fround($240 * $320);
    $324 = Math_fround(-$323);
    $325 = Math_fround($324 - $322);
    $326 = Math_fround($241 * $321);
    $327 = Math_fround($325 - $326);
    $328 = Math_fround($327 - $_inflation);
    $329 = Math_fround(HEAPF32[$r>>2]);
    $330 = Math_fround(HEAPF32[$13>>2]);
    $331 = Math_fround(HEAPF32[$15>>2]);
    $332 = Math_fround($239 * $329);
    $333 = Math_fround($240 * $330);
    $334 = Math_fround($332 + $333);
    $335 = Math_fround($241 * $331);
    $336 = Math_fround($334 + $335);
    $337 = $328 > Math_fround(0.0);
    if ($337) {
     $338 = !($336 >= Math_fround(0.0));
     if (!($338)) {
      $$0 = 0;
      label = 22;
      break;
     }
     $339 = Math_fround($328 / $336);
     $340 = Math_fround($341 - $339);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1316+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1316+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1316+8>>2]|0;
     $342 = $340 > $341;
     if ($342) {
      $343 = $340 > Math_fround(1.0);
      if ($343) {
       $$0 = 0;
       label = 22;
       break;
      }
      $344 = Math_fround(HEAPF32[$s>>2]);
      $345 = Math_fround(HEAPF32[$18>>2]);
      $346 = Math_fround(HEAPF32[$20>>2]);
      $347 = Math_fround($340 * $329);
      $348 = Math_fround($340 * $330);
      $349 = Math_fround($340 * $331);
      $350 = Math_fround($347 + $344);
      $351 = Math_fround($348 + $345);
      $352 = Math_fround($349 + $346);
      $353 = Math_fround($350 - $314);
      $354 = Math_fround($351 - $316);
      $355 = Math_fround($352 - $318);
      $356 = Math_fround(HEAPF32[$B>>2]);
      $357 = Math_fround(HEAPF32[$196>>2]);
      $358 = Math_fround(HEAPF32[$197>>2]);
      $359 = Math_fround($353 + $356);
      $360 = Math_fround($354 + $357);
      $361 = Math_fround($355 + $358);
      $362 = Math_fround(HEAPF32[$199>>2]);
      $363 = Math_fround(HEAPF32[$200>>2]);
      $364 = Math_fround(HEAPF32[$201>>2]);
      $365 = Math_fround($353 + $362);
      $366 = Math_fround($354 + $363);
      $367 = Math_fround($355 + $364);
      $368 = Math_fround(HEAPF32[$203>>2]);
      $369 = Math_fround(HEAPF32[$204>>2]);
      $370 = Math_fround(HEAPF32[$205>>2]);
      $371 = Math_fround($353 + $368);
      $372 = Math_fround($354 + $369);
      $373 = Math_fround($355 + $370);
      HEAPF32[$B>>2] = $359;
      HEAPF32[$196>>2] = $360;
      HEAPF32[$197>>2] = $361;
      HEAPF32[$198>>2] = Math_fround(0.0);
      HEAPF32[$199>>2] = $365;
      HEAPF32[$200>>2] = $366;
      HEAPF32[$201>>2] = $367;
      HEAPF32[$202>>2] = Math_fround(0.0);
      HEAPF32[$203>>2] = $371;
      HEAPF32[$204>>2] = $372;
      HEAPF32[$205>>2] = $373;
      HEAPF32[$206>>2] = Math_fround(0.0);
      $374 = Math_fround(HEAPF32[$A>>2]);
      $375 = Math_fround(HEAPF32[$152>>2]);
      $376 = Math_fround(HEAPF32[$153>>2]);
      $377 = Math_fround($374 - $359);
      $378 = Math_fround($375 - $360);
      $379 = Math_fround($376 - $361);
      HEAPF32[$Q>>2] = $377;
      HEAPF32[$146>>2] = $378;
      HEAPF32[$147>>2] = $379;
      HEAPF32[$148>>2] = Math_fround(0.0);
      $380 = Math_fround(HEAPF32[$207>>2]);
      $381 = Math_fround(HEAPF32[$208>>2]);
      $382 = Math_fround(HEAPF32[$209>>2]);
      $383 = Math_fround($380 - $365);
      $384 = Math_fround($381 - $366);
      $385 = Math_fround($382 - $367);
      HEAPF32[$210>>2] = $383;
      HEAPF32[$211>>2] = $384;
      HEAPF32[$212>>2] = $385;
      HEAPF32[$213>>2] = Math_fround(0.0);
      $386 = Math_fround(HEAPF32[$214>>2]);
      $387 = Math_fround(HEAPF32[$215>>2]);
      $388 = Math_fround(HEAPF32[$216>>2]);
      $389 = Math_fround($386 - $371);
      $390 = Math_fround($387 - $372);
      $391 = Math_fround($388 - $373);
      HEAPF32[$217>>2] = $389;
      HEAPF32[$218>>2] = $390;
      HEAPF32[$219>>2] = $391;
      HEAPF32[$220>>2] = Math_fround(0.0);
      __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($11,$b,$nvNorm);
      $392 = Math_fround(HEAPF32[$11>>2]);
      $393 = Math_fround(HEAPF32[$221>>2]);
      $394 = Math_fround(HEAPF32[$222>>2]);
      $395 = Math_fround($350 + $392);
      $396 = Math_fround($351 + $393);
      $397 = Math_fround($352 + $394);
      $398 = Math_fround($307 - $395);
      $399 = Math_fround($308 - $396);
      $400 = Math_fround($309 - $397);
      HEAPF32[$support>>2] = $398;
      HEAPF32[$193>>2] = $399;
      HEAPF32[$194>>2] = $400;
      HEAPF32[$195>>2] = Math_fround(0.0);
      $407 = $395;$409 = $396;$411 = $397;$419 = $398;$421 = $399;$423 = $400;$478 = Math_fround(3.40282346638528859812E+38);$550 = $340;$551 = $352;$552 = $351;$553 = $350;$554 = $235;$555 = $232;$556 = $230;
     } else {
      $407 = $313;$409 = $315;$411 = $317;$419 = $319;$421 = $320;$423 = $321;$478 = $549;$550 = $340;$551 = $318;$552 = $316;$553 = $314;$554 = $548;$555 = $547;$556 = $546;
     }
    } else {
     $407 = $313;$409 = $315;$411 = $317;$419 = $319;$421 = $320;$423 = $321;$478 = $549;$550 = $341;$551 = $318;$552 = $316;$553 = $314;$554 = $548;$555 = $547;$556 = $546;
    }
    $401 = HEAP32[$size>>2]|0;
    $402 = (($A) + ($401<<4)|0);
    HEAPF32[$402>>2] = $307;
    $403 = ((($A) + ($401<<4)|0) + 4|0);
    HEAPF32[$403>>2] = $308;
    $404 = ((($A) + ($401<<4)|0) + 8|0);
    HEAPF32[$404>>2] = $309;
    $405 = ((($A) + ($401<<4)|0) + 12|0);
    HEAPF32[$405>>2] = Math_fround(0.0);
    $406 = (($B) + ($401<<4)|0);
    HEAPF32[$406>>2] = $407;
    $408 = ((($B) + ($401<<4)|0) + 4|0);
    HEAPF32[$408>>2] = $409;
    $410 = ((($B) + ($401<<4)|0) + 8|0);
    HEAPF32[$410>>2] = $411;
    $412 = ((($B) + ($401<<4)|0) + 12|0);
    HEAPF32[$412>>2] = Math_fround(0.0);
    $413 = (($401) + 1)|0;
    HEAP32[$size>>2] = $413;
    $414 = (($Q) + ($401<<4)|0);
    ;HEAP32[$414+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$414+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$414+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$414+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($401|0) == 1)) {
      $415 = Math_fround(HEAPF32[$Q>>2]);
      $416 = Math_fround(HEAPF32[$146>>2]);
      $417 = Math_fround(HEAPF32[$147>>2]);
      $418 = Math_fround($419 - $415);
      $420 = Math_fround($421 - $416);
      $422 = Math_fround($423 - $417);
      $424 = Math_fround($418 * $418);
      $425 = Math_fround($420 * $420);
      $426 = Math_fround($424 + $425);
      $427 = Math_fround($422 * $422);
      $428 = Math_fround($426 + $427);
      $429 = $428 == Math_fround(0.0);
      if ($429) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $430 = Math_fround($416 * $420);
       $431 = Math_fround(-$430);
       $432 = Math_fround($415 * $418);
       $433 = Math_fround($431 - $432);
       $434 = Math_fround($417 * $422);
       $435 = Math_fround($433 - $434);
       $436 = Math_fround(HEAPF32[$A>>2]);
       $437 = Math_fround(HEAPF32[$152>>2]);
       $438 = Math_fround(HEAPF32[$153>>2]);
       $439 = Math_fround($307 - $436);
       $440 = Math_fround($308 - $437);
       $441 = Math_fround($309 - $438);
       $442 = Math_fround(HEAPF32[$B>>2]);
       $443 = Math_fround(HEAPF32[$196>>2]);
       $444 = Math_fround(HEAPF32[$197>>2]);
       $445 = Math_fround($407 - $442);
       $446 = Math_fround($409 - $443);
       $447 = Math_fround($411 - $444);
       $448 = Math_fround($435 / $428);
       $449 = $448 > Math_fround(1.0);
       $$$i$i$i = $449 ? Math_fround(1.0) : $448;
       $450 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $450 ? $$$i$i$i : Math_fround(0.0);
       $451 = Math_fround($439 * $$$i8$i$i);
       $452 = Math_fround($440 * $$$i8$i$i);
       $453 = Math_fround($441 * $$$i8$i$i);
       $454 = Math_fround($436 + $451);
       $455 = Math_fround($437 + $452);
       $456 = Math_fround($438 + $453);
       $457 = Math_fround($445 * $$$i8$i$i);
       $458 = Math_fround($446 * $$$i8$i$i);
       $459 = Math_fround($447 * $$$i8$i$i);
       $460 = Math_fround($442 + $457);
       $461 = Math_fround($443 + $458);
       $462 = Math_fround($444 + $459);
       HEAPF32[$closA>>2] = $454;
       HEAPF32[$173>>2] = $455;
       HEAPF32[$174>>2] = $456;
       HEAPF32[$175>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $460;
       HEAPF32[$225>>2] = $461;
       HEAPF32[$226>>2] = $462;
       HEAPF32[$227>>2] = Math_fround(0.0);
       $463 = Math_fround($454 - $460);
       $464 = Math_fround($455 - $461);
       $465 = Math_fround($456 - $462);
       HEAPF32[$tempV>>2] = $463;
       HEAPF32[$223>>2] = $464;
       HEAPF32[$224>>2] = $465;
       HEAPF32[$228>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($401|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($401|0) == 0)) {
      HEAPF32[$closA>>2] = $307;
      HEAPF32[$173>>2] = $308;
      HEAPF32[$174>>2] = $309;
      HEAPF32[$175>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $407;
      HEAPF32[$225>>2] = $409;
      HEAPF32[$226>>2] = $411;
      HEAPF32[$227>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($401|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$149,$support,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $466 = Math_fround(HEAPF32[$tempV>>2]);
    $467 = Math_fround(HEAPF32[$223>>2]);
    $468 = Math_fround(HEAPF32[$224>>2]);
    $469 = Math_fround(-$466);
    $470 = Math_fround(-$467);
    $471 = Math_fround(-$468);
    $472 = Math_fround($466 * $466);
    $473 = Math_fround($467 * $467);
    $474 = Math_fround($472 + $473);
    $475 = Math_fround($468 * $468);
    $476 = Math_fround($474 + $475);
    $477 = $478 > $476;
    $479 = $477 << 31 >> 31;
    $480 = $476 > $172;
    if (!($480)) {
     $$lcssa = $550;$$lcssa900 = $542;$$lcssa902 = $543;$$lcssa904 = $544;$$lcssa906 = $545;$$lcssa908 = $471;$$lcssa910 = $470;$$lcssa912 = $469;$$lcssa914 = $476;$$lcssa916 = $479;$$lcssa918 = $554;$$lcssa920 = $555;$$lcssa922 = $556;
     break L1;
    }
    if (!($477)) {
     $$lcssa = $550;$$lcssa900 = $542;$$lcssa902 = $543;$$lcssa904 = $544;$$lcssa906 = $545;$$lcssa908 = $471;$$lcssa910 = $470;$$lcssa912 = $469;$$lcssa914 = $476;$$lcssa916 = $479;$$lcssa918 = $554;$$lcssa920 = $555;$$lcssa922 = $556;
     break L1;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre956 = Math_fround(HEAPF32[$173>>2]);
    $$pre957 = Math_fround(HEAPF32[$174>>2]);
    $$pre958 = Math_fround(HEAPF32[$175>>2]);
    $230 = $469;$232 = $470;$235 = $471;$314 = $553;$316 = $552;$318 = $551;$341 = $550;$542 = $$pre958;$543 = $$pre957;$544 = $$pre956;$545 = $$pre;$546 = $556;$547 = $555;$548 = $554;$549 = $476;
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa900 = Math_fround(0.0);$$lcssa902 = $137;$$lcssa904 = $136;$$lcssa906 = $135;$$lcssa908 = $163;$$lcssa910 = $162;$$lcssa912 = $161;$$lcssa914 = $180;$$lcssa916 = -1;$$lcssa918 = $163;$$lcssa920 = $162;$$lcssa922 = $161;
  }
 } while(0);
 $481 = (($a) + 64|0);
 $482 = HEAP32[$481>>2]|0;
 $483 = (($a) + 68|0);
 $484 = HEAP32[$483>>2]|0;
 $485 = (($a) + 72|0);
 $486 = HEAP32[$485>>2]|0;
 $487 = $$lcssa914 > $170;
 if ($487) {
  $phitmp = ($$lcssa916|0)==(0);
  $phitmp893 = $phitmp ? $4 : $5;
  $495 = $phitmp893;
 } else {
  $495 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa912;
 $488 = (($5) + 4|0);
 HEAPF32[$488>>2] = $$lcssa910;
 $489 = (($5) + 8|0);
 HEAPF32[$489>>2] = $$lcssa908;
 $490 = (($5) + 12|0);
 HEAPF32[$490>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa922;
 $491 = (($4) + 4|0);
 HEAPF32[$491>>2] = $$lcssa920;
 $492 = (($4) + 8|0);
 HEAPF32[$492>>2] = $$lcssa918;
 $493 = (($4) + 12|0);
 HEAPF32[$493>>2] = Math_fround(0.0);
 $494 = Math_fround(HEAPF32[$495>>2]);
 $$in1$i37 = (($495) + 4|0);
 $496 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($495) + 8|0);
 $497 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $498 = Math_fround($494 * $494);
 $499 = Math_fround($496 * $496);
 $500 = Math_fround($498 + $499);
 $501 = Math_fround($497 * $497);
 $502 = Math_fround($500 + $501);
 $503 = (Math_fround(Math_sqrt((Math_fround($502)))));
 $504 = Math_fround(Math_fround(1.0) / $503);
 $505 = Math_fround($494 * $504);
 $506 = Math_fround($496 * $504);
 $507 = Math_fround($497 * $504);
 $508 = Math_fround(-$505);
 $509 = Math_fround(-$506);
 $510 = Math_fround(-$507);
 HEAPF32[$normal>>2] = $508;
 $511 = (($normal) + 4|0);
 HEAPF32[$511>>2] = $509;
 $512 = (($normal) + 8|0);
 HEAPF32[$512>>2] = $510;
 $513 = (($normal) + 12|0);
 HEAPF32[$513>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $514 = (($lambda) + 4|0);
 ;HEAP32[$514+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$514+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$514+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$6>>2] = $$lcssa906;
 $515 = (($6) + 4|0);
 HEAPF32[$515>>2] = $$lcssa904;
 $516 = (($6) + 8|0);
 HEAPF32[$516>>2] = $$lcssa902;
 $517 = (($6) + 12|0);
 HEAPF32[$517>>2] = $$lcssa900;
 $518 = ($$lcssa916|0)==(0);
 $b$a$i18 = $518 ? $6 : $7;
 $519 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $520 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $521 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $519;
 HEAPF32[$173>>2] = $520;
 HEAPF32[$174>>2] = $521;
 HEAPF32[$175>>2] = Math_fround(0.0);
 $522 = (($a) + 16|0);
 $523 = Math_fround(HEAPF32[$522>>2]);
 $524 = Math_fround($523 * $508);
 $525 = Math_fround($523 * $509);
 $526 = Math_fround($523 * $510);
 $527 = Math_fround($519 - $524);
 $528 = Math_fround($520 - $525);
 $529 = Math_fround($521 - $526);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $527;
 $530 = (($9) + 4|0);
 HEAPF32[$530>>2] = $528;
 $531 = (($9) + 8|0);
 HEAPF32[$531>>2] = $529;
 $532 = (($9) + 12|0);
 HEAPF32[$532>>2] = Math_fround(0.0);
 $533 = ($482|0)==(0);
 $b$a$i = $533 ? $8 : $9;
 $534 = Math_fround(HEAPF32[$b$a$i>>2]);
 $535 = ($484|0)==(0);
 $a$pn3$i = $535 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $536 = Math_fround(HEAPF32[$$in1$i>>2]);
 $537 = ($486|0)==(0);
 $b$a5$i = $537 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $538 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $534;
 $539 = (($closestA) + 4|0);
 HEAPF32[$539>>2] = $536;
 $540 = (($closestA) + 8|0);
 HEAPF32[$540>>2] = $538;
 $541 = (($closestA) + 12|0);
 HEAPF32[$541>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_8CapsuleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$751 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i165 = Math_fround(0), $$$i134 = Math_fround(0), $$$i176 = Math_fround(0), $$$i739803 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i166 = Math_fround(0), $$0 = 0, $$747 = 0, $$in1$i = 0, $$in1$i$i$i$i = 0, $$in2$i = 0, $$in2$i$i$i$i = 0, $$ph = Math_fround(0), $$ph759 = Math_fround(0), $$ph760 = Math_fround(0), $$ph761 = Math_fround(0), $$ph762 = Math_fround(0);
 var $$ph763 = Math_fround(0), $$ph764 = Math_fround(0), $$ph765 = Math_fround(0), $$ph767 = Math_fround(0), $$ph768 = 0, $$pre = Math_fround(0), $$pre842 = Math_fround(0), $$pre843 = Math_fround(0), $$pre844 = Math_fround(0), $$pre845 = Math_fround(0), $$pre846 = Math_fround(0), $$pre847 = Math_fround(0), $$pre848 = Math_fround(0), $$sroa$1 = 0, $$sroa$1232 = 0, $$sroa$1234 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0;
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0);
 var $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0;
 var $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0;
 var $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0);
 var $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0);
 var $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0;
 var $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0);
 var $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = 0;
 var $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0);
 var $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0;
 var $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0);
 var $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0);
 var $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0);
 var $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0);
 var $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0);
 var $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0);
 var $516 = 0, $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = 0, $528 = Math_fround(0), $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $aInd = 0, $b$a$i = 0, $b$a$i$i$i$i = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0;
 var $i$01$i72 = 0, $i$0813 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp755 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 400|0;
 $1 = sp + 336|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $closA = sp + 384|0;
 $closB = sp + 416|0;
 $sDist$sroa$1 = sp + 516|0;
 $minDist$sroa$1 = sp + 504|0;
 $v = sp + 320|0;
 $Q = sp;
 $A = sp + 160|0;
 $B = sp + 64|0;
 $aInd = sp + 488|0;
 $bInd = sp + 528|0;
 $size = sp + 448|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 144|0;
 $lastB = sp + 224|0;
 $4 = sp + 240|0;
 $5 = sp + 256|0;
 $supportA1 = sp + 272|0;
 $supportB2 = sp + 288|0;
 $support3 = sp + 304|0;
 $$sroa$1234 = sp + 464|0;
 $6 = sp + 432|0;
 $$sroa$1232 = sp + 476|0;
 $$sroa$1 = sp + 452|0;
 $7 = (($a) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($b) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$_contactDist>>2]);
 $12 = (($a) + 32|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($b) + 32|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = $13 > $15;
 $$$i176 = $16 ? $15 : $13;
 $17 = Math_fround($$$i176 * Math_fround(0.100000001490116119385));
 $18 = Math_fround($8 + $10);
 $19 = (($closA) + 4|0);
 $20 = (($closA) + 8|0);
 $21 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $22 = (($closB) + 4|0);
 $23 = (($closB) + 8|0);
 $24 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $25 = Math_fround($17 * $17);
 HEAP32[$size>>2] = 0;
 $26 = HEAP8[$_size>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $191 = (($aToB) + 48|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = (($aToB) + 52|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = (($aToB) + 56|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = (($aToB) + 60|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = Math_fround($192 * $192);
  $200 = Math_fround($194 * $194);
  $201 = Math_fround($199 + $200);
  $202 = Math_fround($196 * $196);
  $203 = Math_fround($201 + $202);
  $204 = $203 > Math_fround(0.0);
  HEAPF32[$1>>2] = $192;
  $205 = (($1) + 4|0);
  HEAPF32[$205>>2] = $194;
  $206 = (($1) + 8|0);
  HEAPF32[$206>>2] = $196;
  $207 = (($1) + 12|0);
  HEAPF32[$207>>2] = $198;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $208 = (($0) + 4|0);
  HEAPF32[$208>>2] = Math_fround(0.0);
  $209 = (($0) + 8|0);
  HEAPF32[$209>>2] = Math_fround(0.0);
  $210 = (($0) + 12|0);
  HEAPF32[$210>>2] = Math_fround(0.0);
  $b$a$i = $204 ? $1 : $0;
  $211 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $212 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $213 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $211;
  $214 = (($v) + 4|0);
  HEAPF32[$214>>2] = $212;
  $215 = (($v) + 8|0);
  HEAPF32[$215>>2] = $213;
  $216 = (($v) + 12|0);
  HEAPF32[$216>>2] = Math_fround(0.0);
  $$ph = Math_fround(0.0);$$ph759 = Math_fround(0.0);$$ph760 = Math_fround(0.0);$$ph761 = Math_fround(0.0);$$ph762 = Math_fround(0.0);$$ph763 = Math_fround(0.0);$$ph764 = Math_fround(0.0);$$ph765 = Math_fround(0.0);$$ph767 = Math_fround(3.40282346638528859812E+38);$$ph768 = 1;$546 = $213;$547 = $212;$548 = $211;
 } else {
  $28 = (($lastQ) + 4|0);
  $29 = (($lastQ) + 8|0);
  $30 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $31 = (($lastA) + 4|0);
  $32 = (($lastA) + 8|0);
  $33 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $34 = (($lastB) + 4|0);
  $35 = (($lastB) + 8|0);
  $36 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $37 = (($a) + 96|0);
  $38 = (($aToB) + 48|0);
  $39 = (($aToB) + 52|0);
  $40 = (($aToB) + 56|0);
  $41 = (($aToB) + 16|0);
  $42 = (($aToB) + 32|0);
  $43 = (($aToB) + 4|0);
  $44 = (($aToB) + 20|0);
  $45 = (($aToB) + 36|0);
  $46 = (($aToB) + 8|0);
  $47 = (($aToB) + 24|0);
  $48 = (($aToB) + 40|0);
  $49 = (($b) + 16|0);
  $50 = (($4) + 4|0);
  $51 = (($4) + 8|0);
  $52 = (($4) + 12|0);
  $i$0813 = 0;
  while(1) {
   $53 = (($aIndices) + ($i$0813)|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = $54&255;
   $56 = (($aInd) + ($i$0813<<2)|0);
   HEAP32[$56>>2] = $55;
   $57 = (($bIndices) + ($i$0813)|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = $58&255;
   $60 = (($bInd) + ($i$0813<<2)|0);
   HEAP32[$60>>2] = $59;
   $61 = (1 - ($55))|0;
   $62 = (($37) + ($61<<4)|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = ((($37) + ($61<<4)|0) + 4|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = ((($37) + ($61<<4)|0) + 8|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = Math_fround(HEAPF32[$38>>2]);
   $69 = Math_fround(HEAPF32[$39>>2]);
   $70 = Math_fround(HEAPF32[$40>>2]);
   $71 = Math_fround(HEAPF32[$aToB>>2]);
   $72 = Math_fround($63 * $71);
   $73 = Math_fround(HEAPF32[$41>>2]);
   $74 = Math_fround($65 * $73);
   $75 = Math_fround($72 + $74);
   $76 = Math_fround(HEAPF32[$42>>2]);
   $77 = Math_fround($67 * $76);
   $78 = Math_fround($75 + $77);
   $79 = Math_fround(HEAPF32[$43>>2]);
   $80 = Math_fround($63 * $79);
   $81 = Math_fround(HEAPF32[$44>>2]);
   $82 = Math_fround($65 * $81);
   $83 = Math_fround($80 + $82);
   $84 = Math_fround(HEAPF32[$45>>2]);
   $85 = Math_fround($67 * $84);
   $86 = Math_fround($83 + $85);
   $87 = Math_fround(HEAPF32[$46>>2]);
   $88 = Math_fround($63 * $87);
   $89 = Math_fround(HEAPF32[$47>>2]);
   $90 = Math_fround($65 * $89);
   $91 = Math_fround($88 + $90);
   $92 = Math_fround(HEAPF32[$48>>2]);
   $93 = Math_fround($67 * $92);
   $94 = Math_fround($91 + $93);
   $95 = Math_fround($68 + $78);
   $96 = Math_fround($69 + $86);
   $97 = Math_fround($70 + $94);
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($4,$b,$59,$49);
   $98 = Math_fround(HEAPF32[$4>>2]);
   $99 = Math_fround(HEAPF32[$50>>2]);
   $100 = Math_fround(HEAPF32[$51>>2]);
   $101 = Math_fround(HEAPF32[$52>>2]);
   $102 = Math_fround($95 - $98);
   $103 = Math_fround($96 - $99);
   $104 = Math_fround($97 - $100);
   $105 = HEAP32[$size>>2]|0;
   $106 = (($A) + ($105<<4)|0);
   HEAPF32[$lastA>>2] = $95;
   HEAPF32[$31>>2] = $96;
   HEAPF32[$32>>2] = $97;
   HEAPF32[$33>>2] = Math_fround(0.0);
   ;HEAP32[$106+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$lastA+12>>2]|0;
   $107 = (($B) + ($105<<4)|0);
   HEAPF32[$lastB>>2] = $98;
   HEAPF32[$34>>2] = $99;
   HEAPF32[$35>>2] = $100;
   HEAPF32[$36>>2] = $101;
   ;HEAP32[$107+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$107+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$107+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$107+12>>2]=HEAP32[$lastB+12>>2]|0;
   $108 = (($105) + 1)|0;
   HEAP32[$size>>2] = $108;
   $109 = (($Q) + ($105<<4)|0);
   HEAPF32[$lastQ>>2] = $102;
   HEAPF32[$28>>2] = $103;
   HEAPF32[$29>>2] = $104;
   HEAPF32[$30>>2] = Math_fround(0.0);
   ;HEAP32[$109+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$109+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$109+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $110 = (($i$0813) + 1)|0;
   $111 = HEAP8[$_size>>0]|0;
   $112 = $111&255;
   $113 = ($110>>>0)<($112>>>0);
   if ($113) {
    $i$0813 = $110;
   } else {
    break;
   }
  }
  do {
   if ((($105|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($105|0) == 1)) {
    $114 = Math_fround(HEAPF32[$Q>>2]);
    $115 = (($Q) + 4|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = (($Q) + 8|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = Math_fround($102 - $114);
    $120 = Math_fround($103 - $116);
    $121 = Math_fround($104 - $118);
    $122 = Math_fround($119 * $119);
    $123 = Math_fround($120 * $120);
    $124 = Math_fround($122 + $123);
    $125 = Math_fround($121 * $121);
    $126 = Math_fround($124 + $125);
    $127 = $126 == Math_fround(0.0);
    if ($127) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $128 = Math_fround($116 * $120);
     $129 = Math_fround(-$128);
     $130 = Math_fround($114 * $119);
     $131 = Math_fround($129 - $130);
     $132 = Math_fround($118 * $121);
     $133 = Math_fround($131 - $132);
     $134 = Math_fround(HEAPF32[$A>>2]);
     $135 = (($A) + 4|0);
     $136 = Math_fround(HEAPF32[$135>>2]);
     $137 = (($A) + 8|0);
     $138 = Math_fround(HEAPF32[$137>>2]);
     $139 = Math_fround($95 - $134);
     $140 = Math_fround($96 - $136);
     $141 = Math_fround($97 - $138);
     $142 = Math_fround(HEAPF32[$B>>2]);
     $143 = (($B) + 4|0);
     $144 = Math_fround(HEAPF32[$143>>2]);
     $145 = (($B) + 8|0);
     $146 = Math_fround(HEAPF32[$145>>2]);
     $147 = Math_fround($98 - $142);
     $148 = Math_fround($99 - $144);
     $149 = Math_fround($100 - $146);
     $150 = Math_fround($133 / $126);
     $151 = $150 > Math_fround(1.0);
     $$$i$i$i165 = $151 ? Math_fround(1.0) : $150;
     $152 = $$$i$i$i165 > Math_fround(0.0);
     $$$i8$i$i166 = $152 ? $$$i$i$i165 : Math_fround(0.0);
     $153 = Math_fround($139 * $$$i8$i$i166);
     $154 = Math_fround($140 * $$$i8$i$i166);
     $155 = Math_fround($141 * $$$i8$i$i166);
     $156 = Math_fround($134 + $153);
     $157 = Math_fround($136 + $154);
     $158 = Math_fround($138 + $155);
     $159 = Math_fround($147 * $$$i8$i$i166);
     $160 = Math_fround($148 * $$$i8$i$i166);
     $161 = Math_fround($149 * $$$i8$i$i166);
     $162 = Math_fround($142 + $159);
     $163 = Math_fround($144 + $160);
     $164 = Math_fround($146 + $161);
     HEAPF32[$closA>>2] = $156;
     HEAPF32[$19>>2] = $157;
     HEAPF32[$20>>2] = $158;
     HEAPF32[$21>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $162;
     HEAPF32[$22>>2] = $163;
     HEAPF32[$23>>2] = $164;
     HEAPF32[$24>>2] = Math_fround(0.0);
     $165 = Math_fround($156 - $162);
     $166 = Math_fround($157 - $163);
     $167 = Math_fround($158 - $164);
     HEAPF32[$5>>2] = $165;
     $168 = (($5) + 4|0);
     HEAPF32[$168>>2] = $166;
     $169 = (($5) + 8|0);
     HEAPF32[$169>>2] = $167;
     $170 = (($5) + 12|0);
     HEAPF32[$170>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($105|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$5+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($105|0) == 2)) {
    $171 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$171,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else {
    ;HEAP32[$5+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$5+12>>2]|0;
  $172 = Math_fround(HEAPF32[$v>>2]);
  $173 = (($v) + 4|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = (($v) + 8|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = Math_fround($172 * $172);
  $178 = Math_fround($174 * $174);
  $179 = Math_fround($177 + $178);
  $180 = Math_fround($176 * $176);
  $181 = Math_fround($179 + $180);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $182 = Math_fround(HEAPF32[$closA>>2]);
  $183 = Math_fround(HEAPF32[$19>>2]);
  $184 = Math_fround(HEAPF32[$20>>2]);
  $185 = Math_fround(HEAPF32[$21>>2]);
  $186 = Math_fround(HEAPF32[$closB>>2]);
  $187 = Math_fround(HEAPF32[$22>>2]);
  $188 = Math_fround(HEAPF32[$23>>2]);
  $189 = Math_fround(HEAPF32[$24>>2]);
  $190 = $181 > $25;
  $$ph = $185;$$ph759 = $184;$$ph760 = $183;$$ph761 = $182;$$ph762 = $189;$$ph763 = $188;$$ph764 = $187;$$ph765 = $186;$$ph767 = $181;$$ph768 = $190;$546 = $176;$547 = $174;$548 = $172;
 }
 do {
  if ($$ph768) {
   $218 = (($v) + 4|0);
   $219 = (($v) + 8|0);
   $220 = (($aToB) + 4|0);
   $221 = (($aToB) + 8|0);
   $222 = (($aToB) + 16|0);
   $223 = (($aToB) + 20|0);
   $224 = (($aToB) + 24|0);
   $225 = (($aToB) + 32|0);
   $226 = (($aToB) + 36|0);
   $227 = (($aToB) + 40|0);
   $228 = (($a) + 96|0);
   $229 = (($a) + 96|0);
   $230 = (($a) + 100|0);
   $231 = (($a) + 104|0);
   $232 = (($a) + 112|0);
   $233 = (($a) + 112|0);
   $234 = (($a) + 116|0);
   $235 = (($a) + 120|0);
   $236 = (($aToB) + 48|0);
   $237 = (($aToB) + 52|0);
   $238 = (($aToB) + 56|0);
   $239 = (($supportA1) + 4|0);
   $240 = (($supportA1) + 8|0);
   $241 = (($supportA1) + 12|0);
   $242 = (($supportB2) + 4|0);
   $243 = (($supportB2) + 8|0);
   $244 = (($support3) + 4|0);
   $245 = (($support3) + 8|0);
   $246 = (($support3) + 12|0);
   $247 = (($a) + 48|0);
   $248 = (($b) + 48|0);
   $249 = (($Q) + 4|0);
   $250 = (($Q) + 8|0);
   $251 = (($A) + 4|0);
   $252 = (($A) + 8|0);
   $253 = (($B) + 4|0);
   $254 = (($B) + 8|0);
   $255 = (($6) + 4|0);
   $256 = (($6) + 8|0);
   $257 = (($6) + 12|0);
   $258 = (($Q) + 16|0);
   $$$i739803 = $11;$260 = $548;$262 = $547;$264 = $546;$355 = $$ph767;$491 = $$ph761;$492 = $$ph760;$493 = $$ph759;$494 = $$ph;$495 = $$ph765;$496 = $$ph764;$497 = $$ph763;$498 = $$ph762;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $259 = Math_fround(-$260);
    $261 = Math_fround(-$262);
    $263 = Math_fround(-$264);
    $265 = HEAP32[$size>>2]|0;
    $266 = (($A) + ($265<<4)|0);
    $267 = (($aInd) + ($265<<2)|0);
    $268 = Math_fround(HEAPF32[$aToB>>2]);
    $269 = Math_fround($268 * $259);
    $270 = Math_fround(HEAPF32[$220>>2]);
    $271 = Math_fround($270 * $261);
    $272 = Math_fround($269 + $271);
    $273 = Math_fround(HEAPF32[$221>>2]);
    $274 = Math_fround($273 * $263);
    $275 = Math_fround($272 + $274);
    $276 = Math_fround(HEAPF32[$222>>2]);
    $277 = Math_fround($276 * $259);
    $278 = Math_fround(HEAPF32[$223>>2]);
    $279 = Math_fround($278 * $261);
    $280 = Math_fround($277 + $279);
    $281 = Math_fround(HEAPF32[$224>>2]);
    $282 = Math_fround($281 * $263);
    $283 = Math_fround($280 + $282);
    $284 = Math_fround(HEAPF32[$225>>2]);
    $285 = Math_fround($284 * $259);
    $286 = Math_fround(HEAPF32[$226>>2]);
    $287 = Math_fround($286 * $261);
    $288 = Math_fround($285 + $287);
    $289 = Math_fround(HEAPF32[$227>>2]);
    $290 = Math_fround($289 * $263);
    $291 = Math_fround($288 + $290);
    $292 = Math_fround(HEAPF32[$229>>2]);
    $293 = Math_fround(HEAPF32[$230>>2]);
    $294 = Math_fround(HEAPF32[$231>>2]);
    $295 = Math_fround($275 * $292);
    $296 = Math_fround($283 * $293);
    $297 = Math_fround($295 + $296);
    $298 = Math_fround($291 * $294);
    $299 = Math_fround($297 + $298);
    $300 = Math_fround(HEAPF32[$233>>2]);
    $301 = Math_fround(HEAPF32[$234>>2]);
    $302 = Math_fround(HEAPF32[$235>>2]);
    $303 = Math_fround($275 * $300);
    $304 = Math_fround($283 * $301);
    $305 = Math_fround($303 + $304);
    $306 = Math_fround($291 * $302);
    $307 = Math_fround($305 + $306);
    $308 = $299 > $307;
    $309 = $308&1;
    HEAP32[$267>>2] = $309;
    ;HEAP32[$3+0>>2]=HEAP32[$228+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$228+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$228+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$228+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$232+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$232+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$232+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$232+12>>2]|0;
    $b$a$i$i$i$i = $308 ? $3 : $2;
    $310 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
    $$in1$i$i$i$i = (($b$a$i$i$i$i) + 4|0);
    $311 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
    $$in2$i$i$i$i = (($b$a$i$i$i$i) + 8|0);
    $312 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
    $313 = Math_fround(HEAPF32[$236>>2]);
    $314 = Math_fround(HEAPF32[$237>>2]);
    $315 = Math_fround(HEAPF32[$238>>2]);
    $316 = Math_fround($268 * $310);
    $317 = Math_fround($276 * $311);
    $318 = Math_fround($316 + $317);
    $319 = Math_fround($284 * $312);
    $320 = Math_fround($318 + $319);
    $321 = Math_fround($270 * $310);
    $322 = Math_fround($278 * $311);
    $323 = Math_fround($321 + $322);
    $324 = Math_fround($286 * $312);
    $325 = Math_fround($323 + $324);
    $326 = Math_fround($273 * $310);
    $327 = Math_fround($281 * $311);
    $328 = Math_fround($326 + $327);
    $329 = Math_fround($289 * $312);
    $330 = Math_fround($328 + $329);
    $331 = Math_fround($320 + $313);
    $332 = Math_fround($325 + $314);
    $333 = Math_fround($330 + $315);
    HEAPF32[$supportA1>>2] = $331;
    HEAPF32[$239>>2] = $332;
    HEAPF32[$240>>2] = $333;
    HEAPF32[$241>>2] = Math_fround(0.0);
    ;HEAP32[$266+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$266+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$266+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$266+12>>2]=HEAP32[$supportA1+12>>2]|0;
    $334 = (($B) + ($265<<4)|0);
    $335 = (($bInd) + ($265<<2)|0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($supportB2,$b,$v,$334,$335);
    $336 = Math_fround(HEAPF32[$supportA1>>2]);
    $337 = Math_fround(HEAPF32[$239>>2]);
    $338 = Math_fround(HEAPF32[$240>>2]);
    $339 = Math_fround(HEAPF32[$supportB2>>2]);
    $340 = Math_fround(HEAPF32[$242>>2]);
    $341 = Math_fround(HEAPF32[$243>>2]);
    $342 = Math_fround($336 - $339);
    $343 = Math_fround($337 - $340);
    $344 = Math_fround($338 - $341);
    HEAPF32[$support3>>2] = $342;
    HEAPF32[$244>>2] = $343;
    HEAPF32[$245>>2] = $344;
    HEAPF32[$246>>2] = Math_fround(0.0);
    $345 = HEAP32[$size>>2]|0;
    $346 = (($345) + 1)|0;
    HEAP32[$size>>2] = $346;
    $347 = (($Q) + ($345<<4)|0);
    ;HEAP32[$347+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$347+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$347+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$347+12>>2]=HEAP32[$support3+12>>2]|0;
    $348 = Math_fround(HEAPF32[$247>>2]);
    $349 = Math_fround(HEAPF32[$248>>2]);
    $350 = $348 > $349;
    $$$i134 = $350 ? $348 : $349;
    $351 = $$$i739803 > $$$i134;
    $$$i = $351 ? $$$i739803 : $$$i134;
    $352 = Math_fround($18 + $$$i);
    $353 = Math_fround($352 * $352);
    $354 = Math_fround($355 * $353);
    $356 = Math_fround(HEAPF32[$v>>2]);
    $357 = Math_fround(HEAPF32[$218>>2]);
    $358 = Math_fround(HEAPF32[$219>>2]);
    $359 = Math_fround($356 * $342);
    $360 = Math_fround($357 * $343);
    $361 = Math_fround($359 + $360);
    $362 = Math_fround($358 * $344);
    $363 = Math_fround($361 + $362);
    $364 = Math_fround($363 * $363);
    $365 = $363 > Math_fround(0.0);
    $366 = $364 > $354;
    if ($365) {
     $phitmp755 = $366 ^ 1;
     $370 = $366;$372 = $phitmp755;
    } else {
     $370 = 0;$372 = 1;
    }
    $367 = Math_fround($355 - $363);
    $368 = Math_fround($25 * $355);
    $369 = $368 >= $367;
    $brmerge$demorgan = $369 | $370;
    if ($brmerge$demorgan) {
     $371 = $372 ^ 1;
     $$747 = $369 | $371;
     if ($$747) {
      break;
     }
    }
    do {
     if ((($345|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($6,$Q,$258,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($345|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($6,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($345|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$6+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($345|0) == 1)) {
      $419 = Math_fround(HEAPF32[$Q>>2]);
      $420 = Math_fround(HEAPF32[$249>>2]);
      $421 = Math_fround(HEAPF32[$250>>2]);
      $422 = Math_fround($342 - $419);
      $423 = Math_fround($343 - $420);
      $424 = Math_fround($344 - $421);
      $425 = Math_fround($422 * $422);
      $426 = Math_fround($423 * $423);
      $427 = Math_fround($425 + $426);
      $428 = Math_fround($424 * $424);
      $429 = Math_fround($427 + $428);
      $430 = $429 == Math_fround(0.0);
      if ($430) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$6+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $431 = Math_fround($420 * $423);
       $432 = Math_fround(-$431);
       $433 = Math_fround($419 * $422);
       $434 = Math_fround($432 - $433);
       $435 = Math_fround($421 * $424);
       $436 = Math_fround($434 - $435);
       $437 = Math_fround(HEAPF32[$A>>2]);
       $438 = Math_fround(HEAPF32[$251>>2]);
       $439 = Math_fround(HEAPF32[$252>>2]);
       $440 = Math_fround($336 - $437);
       $441 = Math_fround($337 - $438);
       $442 = Math_fround($338 - $439);
       $443 = Math_fround(HEAPF32[$B>>2]);
       $444 = Math_fround(HEAPF32[$253>>2]);
       $445 = Math_fround(HEAPF32[$254>>2]);
       $446 = Math_fround($339 - $443);
       $447 = Math_fround($340 - $444);
       $448 = Math_fround($341 - $445);
       $449 = Math_fround($436 / $429);
       $450 = $449 > Math_fround(1.0);
       $$$i$i$i = $450 ? Math_fround(1.0) : $449;
       $451 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $451 ? $$$i$i$i : Math_fround(0.0);
       $452 = Math_fround($440 * $$$i8$i$i);
       $453 = Math_fround($441 * $$$i8$i$i);
       $454 = Math_fround($442 * $$$i8$i$i);
       $455 = Math_fround($437 + $452);
       $456 = Math_fround($438 + $453);
       $457 = Math_fround($439 + $454);
       $458 = Math_fround($446 * $$$i8$i$i);
       $459 = Math_fround($447 * $$$i8$i$i);
       $460 = Math_fround($448 * $$$i8$i$i);
       $461 = Math_fround($443 + $458);
       $462 = Math_fround($444 + $459);
       $463 = Math_fround($445 + $460);
       HEAPF32[$closA>>2] = $455;
       HEAPF32[$19>>2] = $456;
       HEAPF32[$20>>2] = $457;
       HEAPF32[$21>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $461;
       HEAPF32[$22>>2] = $462;
       HEAPF32[$23>>2] = $463;
       HEAPF32[$24>>2] = Math_fround(0.0);
       $464 = Math_fround($455 - $461);
       $465 = Math_fround($456 - $462);
       $466 = Math_fround($457 - $463);
       HEAPF32[$6>>2] = $464;
       HEAPF32[$255>>2] = $465;
       HEAPF32[$256>>2] = $466;
       HEAPF32[$257>>2] = Math_fround(0.0);
       break;
      }
     } else {
      ;HEAP32[$6+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$6+12>>2]|0;
    $467 = Math_fround(HEAPF32[$v>>2]);
    $468 = Math_fround(HEAPF32[$218>>2]);
    $469 = Math_fround(HEAPF32[$219>>2]);
    $470 = Math_fround($467 * $467);
    $471 = Math_fround($468 * $468);
    $472 = Math_fround($470 + $471);
    $473 = Math_fround($469 * $469);
    $474 = Math_fround($472 + $473);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1232+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1232+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1232+8>>2]|0;
    $475 = $355 > $474;
    $476 = $474 > $25;
    if (!($476)) {
     label = 37;
     break;
    }
    if (!($475)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre842 = Math_fround(HEAPF32[$19>>2]);
    $$pre843 = Math_fround(HEAPF32[$20>>2]);
    $$pre844 = Math_fround(HEAPF32[$21>>2]);
    $$pre845 = Math_fround(HEAPF32[$closB>>2]);
    $$pre846 = Math_fround(HEAPF32[$22>>2]);
    $$pre847 = Math_fround(HEAPF32[$23>>2]);
    $$pre848 = Math_fround(HEAPF32[$24>>2]);
    $$$i739803 = $$$i;$260 = $467;$262 = $468;$264 = $469;$355 = $474;$491 = $$pre;$492 = $$pre842;$493 = $$pre843;$494 = $$pre844;$495 = $$pre845;$496 = $$pre846;$497 = $$pre847;$498 = $$pre848;
   }
   if ((label|0) == 37) {
    $477 = HEAP32[$size>>2]|0;
    if ($475) {
     $535 = $477;
     break;
    }
    $478 = (($477) + -1)|0;
    $479 = ($aIndices|0)==(0|0);
    if (!($479)) {
     $480 = $478&255;
     HEAP8[$_size>>0] = $480;
     $481 = ($478|0)==(0);
     if (!($481)) {
      $i$01$i29 = 0;
      while(1) {
       $482 = (($aInd) + ($i$01$i29<<2)|0);
       $483 = HEAP32[$482>>2]|0;
       $484 = $483&255;
       $485 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$485>>0] = $484;
       $486 = (($bInd) + ($i$01$i29<<2)|0);
       $487 = HEAP32[$486>>2]|0;
       $488 = $487&255;
       $489 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$489>>0] = $488;
       $490 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($490|0)==($478|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $490;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $491;
    HEAPF32[$19>>2] = $492;
    HEAPF32[$20>>2] = $493;
    HEAPF32[$21>>2] = $494;
    HEAPF32[$closB>>2] = $495;
    HEAPF32[$22>>2] = $496;
    HEAPF32[$23>>2] = $497;
    HEAPF32[$24>>2] = $498;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $499 = Math_fround($491 - $495);
    $500 = Math_fround($492 - $496);
    $501 = Math_fround($493 - $497);
    HEAPF32[$v>>2] = $499;
    $502 = (($v) + 4|0);
    HEAPF32[$502>>2] = $500;
    $503 = (($v) + 8|0);
    HEAPF32[$503>>2] = $501;
    $504 = (($v) + 12|0);
    HEAPF32[$504>>2] = Math_fround(0.0);
    $505 = (Math_fround(Math_sqrt((Math_fround($355)))));
    $506 = Math_fround(Math_fround(1.0) / $505);
    $507 = Math_fround($499 * $506);
    $508 = Math_fround($500 * $506);
    $509 = Math_fround($501 * $506);
    $510 = Math_fround($8 * $507);
    $511 = Math_fround($8 * $508);
    $512 = Math_fround($8 * $509);
    $513 = Math_fround($491 - $510);
    $514 = Math_fround($492 - $511);
    $515 = Math_fround($493 - $512);
    HEAPF32[$contactA>>2] = $513;
    $516 = (($contactA) + 4|0);
    HEAPF32[$516>>2] = $514;
    $517 = (($contactA) + 8|0);
    HEAPF32[$517>>2] = $515;
    $518 = (($contactA) + 12|0);
    HEAPF32[$518>>2] = Math_fround(0.0);
    $519 = Math_fround($10 * $507);
    $520 = Math_fround($10 * $508);
    $521 = Math_fround($10 * $509);
    $522 = Math_fround($519 + $495);
    $523 = Math_fround($520 + $496);
    $524 = Math_fround($521 + $497);
    HEAPF32[$contactB>>2] = $522;
    $525 = (($contactB) + 4|0);
    HEAPF32[$525>>2] = $523;
    $526 = (($contactB) + 8|0);
    HEAPF32[$526>>2] = $524;
    $527 = (($contactB) + 12|0);
    HEAPF32[$527>>2] = Math_fround(0.0);
    $528 = Math_fround($505 - $18);
    HEAPF32[$penetrationDepth>>2] = $528;
    $529 = (($penetrationDepth) + 4|0);
    ;HEAP32[$529+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$529+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$529+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $507;
    $530 = (($normal) + 4|0);
    HEAPF32[$530>>2] = $508;
    $531 = (($normal) + 8|0);
    HEAPF32[$531>>2] = $509;
    $532 = (($normal) + 12|0);
    HEAPF32[$532>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $373 = ($aIndices|0)==(0|0);
   if (!($373)) {
    $374 = $345&255;
    HEAP8[$_size>>0] = $374;
    $375 = ($345|0)==(0);
    if (!($375)) {
     $i$01$i72 = 0;
     while(1) {
      $376 = (($aInd) + ($i$01$i72<<2)|0);
      $377 = HEAP32[$376>>2]|0;
      $378 = $377&255;
      $379 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$379>>0] = $378;
      $380 = (($bInd) + ($i$01$i72<<2)|0);
      $381 = HEAP32[$380>>2]|0;
      $382 = $381&255;
      $383 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$383>>0] = $382;
      $384 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($384|0)==($345|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $384;
      }
     }
    }
   }
   $not$ = $370 ^ 1;
   $$$751 = $372 & $not$;
   if (!($$$751)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $385 = (Math_fround(Math_sqrt((Math_fround($355)))));
   $386 = Math_fround(Math_fround(1.0) / $385);
   $387 = Math_fround($356 * $386);
   $388 = Math_fround($357 * $386);
   $389 = Math_fround($358 * $386);
   $390 = Math_fround(HEAPF32[$closA>>2]);
   $391 = Math_fround(HEAPF32[$19>>2]);
   $392 = Math_fround(HEAPF32[$20>>2]);
   $393 = Math_fround($8 * $387);
   $394 = Math_fround($8 * $388);
   $395 = Math_fround($8 * $389);
   $396 = Math_fround($390 - $393);
   $397 = Math_fround($391 - $394);
   $398 = Math_fround($392 - $395);
   HEAPF32[$contactA>>2] = $396;
   $399 = (($contactA) + 4|0);
   HEAPF32[$399>>2] = $397;
   $400 = (($contactA) + 8|0);
   HEAPF32[$400>>2] = $398;
   $401 = (($contactA) + 12|0);
   HEAPF32[$401>>2] = Math_fround(0.0);
   $402 = Math_fround(HEAPF32[$closB>>2]);
   $403 = Math_fround(HEAPF32[$22>>2]);
   $404 = Math_fround(HEAPF32[$23>>2]);
   $405 = Math_fround($10 * $387);
   $406 = Math_fround($10 * $388);
   $407 = Math_fround($10 * $389);
   $408 = Math_fround($405 + $402);
   $409 = Math_fround($406 + $403);
   $410 = Math_fround($407 + $404);
   HEAPF32[$contactB>>2] = $408;
   $411 = (($contactB) + 4|0);
   HEAPF32[$411>>2] = $409;
   $412 = (($contactB) + 8|0);
   HEAPF32[$412>>2] = $410;
   $413 = (($contactB) + 12|0);
   HEAPF32[$413>>2] = Math_fround(0.0);
   $414 = Math_fround($385 - $18);
   HEAPF32[$penetrationDepth>>2] = $414;
   $415 = (($penetrationDepth) + 4|0);
   ;HEAP32[$415+0>>2]=HEAP32[$$sroa$1234+0>>2]|0;HEAP32[$415+4>>2]=HEAP32[$$sroa$1234+4>>2]|0;HEAP32[$415+8>>2]=HEAP32[$$sroa$1234+8>>2]|0;
   HEAPF32[$normal>>2] = $387;
   $416 = (($normal) + 4|0);
   HEAPF32[$416>>2] = $388;
   $417 = (($normal) + 8|0);
   HEAPF32[$417>>2] = $389;
   $418 = (($normal) + 12|0);
   HEAPF32[$418>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $217 = HEAP32[$size>>2]|0;
   $535 = $217;
  }
 } while(0);
 $533 = ($aIndices|0)==(0|0);
 if (!($533)) {
  $534 = $535&255;
  HEAP8[$_size>>0] = $534;
  $536 = ($535|0)==(0);
  if (!($536)) {
   $i$01$i = 0;
   while(1) {
    $537 = (($aInd) + ($i$01$i<<2)|0);
    $538 = HEAP32[$537>>2]|0;
    $539 = $538&255;
    $540 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$540>>0] = $539;
    $541 = (($bInd) + ($i$01$i<<2)|0);
    $542 = HEAP32[$541>>2]|0;
    $543 = $542&255;
    $544 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$544>>0] = $543;
    $545 = (($i$01$i) + 1)|0;
    $exitcond$i = ($545|0)==($535|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $545;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0);
 var $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (1 - ($indexA))|0;
 $5 = (($3) + 96|0);
 $6 = (($5) + ($4<<4)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($5) + ($4<<4)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($5) + ($4<<4)|0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($1) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 52|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($1) + 56|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$1>>2]);
 $19 = Math_fround($7 * $18);
 $20 = (($1) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($9 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($1) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($11 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($1) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($7 * $29);
 $31 = (($1) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($9 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($1) + 36|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($11 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($1) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($7 * $40);
 $42 = (($1) + 24|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($9 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($1) + 40|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($11 * $47);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround($13 + $27);
 $51 = Math_fround($15 + $38);
 $52 = Math_fround($17 + $49);
 $53 = (($this) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 200|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + (($indexB*12)|0)|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = ((($56) + (($indexB*12)|0)|0) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = ((($56) + (($indexB*12)|0)|0) + 8|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($54) + 96|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($58 * $64);
 $66 = (($54) + 112|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($60 * $67);
 $69 = Math_fround($65 + $68);
 $70 = (($54) + 128|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($62 * $71);
 $73 = Math_fround($69 + $72);
 $74 = (($54) + 100|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($58 * $75);
 $77 = (($54) + 116|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($60 * $78);
 $80 = Math_fround($76 + $79);
 $81 = (($54) + 132|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($62 * $82);
 $84 = Math_fround($80 + $83);
 $85 = (($54) + 104|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($58 * $86);
 $88 = (($54) + 120|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($60 * $89);
 $91 = Math_fround($87 + $90);
 $92 = (($54) + 136|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($62 * $93);
 $95 = Math_fround($91 + $94);
 HEAPF32[$supportA>>2] = $50;
 $96 = (($supportA) + 4|0);
 HEAPF32[$96>>2] = $51;
 $97 = (($supportA) + 8|0);
 HEAPF32[$97>>2] = $52;
 $98 = (($supportA) + 12|0);
 HEAPF32[$98>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $73;
 $99 = (($supportB) + 4|0);
 HEAPF32[$99>>2] = $84;
 $100 = (($supportB) + 8|0);
 HEAPF32[$100>>2] = $95;
 $101 = (($supportB) + 12|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = Math_fround($50 - $73);
 $103 = Math_fround($51 - $84);
 $104 = Math_fround($52 - $95);
 HEAPF32[$support>>2] = $102;
 $105 = (($support) + 4|0);
 HEAPF32[$105>>2] = $103;
 $106 = (($support) + 8|0);
 HEAPF32[$106>>2] = $104;
 $107 = (($support) + 12|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i$i = 0, $$in2$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0;
 var $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0);
 var $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $_sb = 0, $b$a$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $_sb = sp + 16|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$6);
 $11 = Math_fround(-$8);
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $9);
 $16 = (($13) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $10);
 $19 = Math_fround($15 + $18);
 $20 = (($13) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $11);
 $23 = Math_fround($19 + $22);
 $24 = (($13) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $9);
 $27 = (($13) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $10);
 $30 = Math_fround($26 + $29);
 $31 = (($13) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $11);
 $34 = Math_fround($30 + $33);
 $35 = (($13) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * $9);
 $38 = (($13) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $10);
 $41 = Math_fround($37 + $40);
 $42 = (($13) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $11);
 $45 = Math_fround($41 + $44);
 $46 = (($3) + 96|0);
 $47 = (($3) + 96|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($3) + 100|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($3) + 104|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($23 * $48);
 $54 = Math_fround($34 * $50);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($45 * $52);
 $57 = Math_fround($55 + $56);
 $58 = (($3) + 112|0);
 $59 = (($3) + 112|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($3) + 116|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($3) + 120|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($23 * $60);
 $66 = Math_fround($34 * $62);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($45 * $64);
 $69 = Math_fround($67 + $68);
 $70 = $57 > $69;
 ;HEAP32[$1+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$46+12>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$58+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$58+12>>2]|0;
 $b$a$i$i$i = $70 ? $1 : $0;
 $71 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
 $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
 $72 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
 $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
 $73 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
 $74 = (($13) + 48|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($13) + 52|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($13) + 56|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($14 * $71);
 $81 = Math_fround($25 * $72);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($36 * $73);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($17 * $71);
 $86 = Math_fround($28 * $72);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($39 * $73);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($21 * $71);
 $91 = Math_fround($32 * $72);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($43 * $73);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($84 + $75);
 $96 = Math_fround($89 + $77);
 $97 = Math_fround($94 + $79);
 $98 = (($this) + 12|0);
 $99 = HEAP32[$98>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($_sb,$99,$dir);
 HEAPF32[$supportA>>2] = $95;
 $100 = (($supportA) + 4|0);
 HEAPF32[$100>>2] = $96;
 $101 = (($supportA) + 8|0);
 HEAPF32[$101>>2] = $97;
 $102 = (($supportA) + 12|0);
 HEAPF32[$102>>2] = Math_fround(0.0);
 ;HEAP32[$supportB+0>>2]=HEAP32[$_sb+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$_sb+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$_sb+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$_sb+12>>2]|0;
 $103 = Math_fround(HEAPF32[$_sb>>2]);
 $104 = (($_sb) + 4|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($_sb) + 8|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($95 - $103);
 $109 = Math_fround($96 - $105);
 $110 = Math_fround($97 - $107);
 HEAPF32[$support>>2] = $108;
 $111 = (($support) + 4|0);
 HEAPF32[$111>>2] = $109;
 $112 = (($support) + 8|0);
 HEAPF32[$112>>2] = $110;
 $113 = (($support) + 12|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_8CapsuleVENS0_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i$i = 0, $$in1$i$i$i$i191 = 0, $$in1$i$i$i142 = 0, $$in1$i$i$i186 = 0, $$in1$i206 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i$i = 0, $$in2$i$i$i$i192 = 0, $$in2$i$i$i144 = 0, $$in2$i$i$i188 = 0, $$in2$i208 = 0;
 var $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa920 = Math_fround(0), $$lcssa922 = Math_fround(0), $$lcssa924 = Math_fround(0), $$lcssa926 = Math_fround(0), $$lcssa928 = Math_fround(0), $$lcssa930 = Math_fround(0), $$lcssa932 = Math_fround(0), $$lcssa934 = Math_fround(0), $$lcssa936 = 0, $$lcssa938 = Math_fround(0), $$lcssa940 = Math_fround(0), $$lcssa942 = Math_fround(0), $$pre = Math_fround(0), $$pre976 = Math_fround(0), $$pre977 = Math_fround(0), $$pre978 = Math_fround(0), $$sroa$1332 = 0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0;
 var $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0);
 var $422 = 0, $423 = Math_fround(0), $424 = 0, $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0);
 var $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = 0, $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0);
 var $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = 0, $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = Math_fround(0), $509 = 0, $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0);
 var $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0);
 var $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = Math_fround(0);
 var $549 = 0, $55 = Math_fround(0), $550 = Math_fround(0), $551 = 0, $552 = Math_fround(0), $553 = 0, $554 = 0, $555 = 0, $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0);
 var $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0;
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $a$pn3$i$i$i = 0, $a$pn3$i$i$i141 = 0, $a$pn3$i$i$i185 = 0, $b$a$i = 0;
 var $b$a$i$i$i = 0, $b$a$i$i$i$i = 0, $b$a$i$i$i$i189 = 0, $b$a$i$i$i139 = 0, $b$a$i$i$i183 = 0, $b$a$i18 = 0, $b$a$i203 = 0, $b$a5$i = 0, $b$a5$i$i$i = 0, $b$a5$i$i$i143 = 0, $b$a5$i$i$i187 = 0, $closA = 0, $closB = 0, $phitmp = 0, $phitmp913 = 0, $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $0 = sp + 32|0;
 $1 = sp + 336|0;
 $2 = sp + 400|0;
 $3 = sp + 416|0;
 $4 = sp + 384|0;
 $5 = sp + 368|0;
 $6 = sp + 352|0;
 $7 = sp + 320|0;
 $8 = sp + 16|0;
 $9 = sp;
 $zeroV = sp + 112|0;
 $zero$sroa$1 = sp + 432|0;
 $_lambda$sroa$1 = sp + 460|0;
 $size = sp + 456|0;
 $Q = sp + 48|0;
 $A = sp + 128|0;
 $B = sp + 192|0;
 $support = sp + 256|0;
 $closA = sp + 272|0;
 $closB = sp + 288|0;
 $$sroa$1332 = sp + 444|0;
 $tempV = sp + 304|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $10 = Math_fround(HEAPF32[$r>>2]);
 $11 = (($r) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($r) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$s>>2]);
 $16 = (($s) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($s) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAP32[$size>>2] = 1;
 $20 = (($aToB) + 48|0);
 $21 = (($aToB) + 48|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($aToB) + 52|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 56|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($22 * $22);
 $28 = Math_fround($24 * $24);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = $31 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$20+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $33 = (($0) + 4|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($0) + 8|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($0) + 12|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $b$a$i203 = $32 ? $1 : $0;
 $36 = Math_fround(HEAPF32[$b$a$i203>>2]);
 $$in1$i206 = (($b$a$i203) + 4|0);
 $37 = Math_fround(HEAPF32[$$in1$i206>>2]);
 $$in2$i208 = (($b$a$i203) + 8|0);
 $38 = Math_fround(HEAPF32[$$in2$i208>>2]);
 $39 = Math_fround($36 * $36);
 $40 = Math_fround($37 * $37);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($38 * $38);
 $43 = Math_fround($41 + $42);
 $44 = (Math_fround(Math_sqrt((Math_fround($43)))));
 $45 = Math_fround(Math_fround(1.0) / $44);
 $46 = Math_fround($36 * $45);
 $47 = Math_fround($37 * $45);
 $48 = Math_fround($38 * $45);
 $49 = Math_fround(-$46);
 $50 = Math_fround(-$47);
 $51 = Math_fround(-$48);
 $52 = Math_fround(HEAPF32[$aToB>>2]);
 $53 = Math_fround($52 * $49);
 $54 = (($aToB) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * $50);
 $57 = Math_fround($53 + $56);
 $58 = (($aToB) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 * $51);
 $61 = Math_fround($57 + $60);
 $62 = (($aToB) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $49);
 $65 = (($aToB) + 20|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $50);
 $68 = Math_fround($64 + $67);
 $69 = (($aToB) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $51);
 $72 = Math_fround($68 + $71);
 $73 = (($aToB) + 32|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($74 * $49);
 $76 = (($aToB) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 * $50);
 $79 = Math_fround($75 + $78);
 $80 = (($aToB) + 40|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 * $51);
 $83 = Math_fround($79 + $82);
 $84 = (($a) + 96|0);
 $85 = (($a) + 96|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($a) + 100|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($a) + 104|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($61 * $86);
 $92 = Math_fround($72 * $88);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($83 * $90);
 $95 = Math_fround($93 + $94);
 $96 = (($a) + 112|0);
 $97 = (($a) + 112|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($a) + 116|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($a) + 120|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($61 * $98);
 $104 = Math_fround($72 * $100);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($83 * $102);
 $107 = Math_fround($105 + $106);
 $108 = $95 > $107;
 ;HEAP32[$3+0>>2]=HEAP32[$84+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$84+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$84+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$84+12>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$96+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$96+12>>2]|0;
 $b$a$i$i$i$i189 = $108 ? $3 : $2;
 $109 = Math_fround(HEAPF32[$b$a$i$i$i$i189>>2]);
 $$in1$i$i$i$i191 = (($b$a$i$i$i$i189) + 4|0);
 $110 = Math_fround(HEAPF32[$$in1$i$i$i$i191>>2]);
 $$in2$i$i$i$i192 = (($b$a$i$i$i$i189) + 8|0);
 $111 = Math_fround(HEAPF32[$$in2$i$i$i$i192>>2]);
 $112 = Math_fround(HEAPF32[$21>>2]);
 $113 = Math_fround(HEAPF32[$23>>2]);
 $114 = Math_fround(HEAPF32[$25>>2]);
 $115 = Math_fround($52 * $109);
 $116 = Math_fround($63 * $110);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($74 * $111);
 $119 = Math_fround($117 + $118);
 $120 = Math_fround($55 * $109);
 $121 = Math_fround($66 * $110);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($77 * $111);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($59 * $109);
 $126 = Math_fround($70 * $110);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround($81 * $111);
 $129 = Math_fround($127 + $128);
 $130 = Math_fround($119 + $112);
 $131 = Math_fround($124 + $113);
 $132 = Math_fround($129 + $114);
 $133 = $46 > Math_fround(0.0);
 $134 = $47 > Math_fround(0.0);
 $135 = $48 > Math_fround(0.0);
 $136 = (($b) + 144|0);
 ;HEAP32[$3+0>>2]=HEAP32[$136+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$136+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$136+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$136+12>>2]|0;
 $137 = (($b) + 144|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($b) + 148|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($b) + 152|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround(-$138);
 $144 = Math_fround(-$140);
 $145 = Math_fround(-$142);
 HEAPF32[$2>>2] = $143;
 $146 = (($2) + 4|0);
 HEAPF32[$146>>2] = $144;
 $147 = (($2) + 8|0);
 HEAPF32[$147>>2] = $145;
 $148 = (($2) + 12|0);
 HEAPF32[$148>>2] = Math_fround(0.0);
 $b$a$i$i$i183 = $133 ? $3 : $2;
 $149 = Math_fround(HEAPF32[$b$a$i$i$i183>>2]);
 $a$pn3$i$i$i185 = $134 ? $3 : $2;
 $$in1$i$i$i186 = (($a$pn3$i$i$i185) + 4|0);
 $150 = Math_fround(HEAPF32[$$in1$i$i$i186>>2]);
 $b$a5$i$i$i187 = $135 ? $3 : $2;
 $$in2$i$i$i188 = (($b$a5$i$i$i187) + 8|0);
 $151 = Math_fround(HEAPF32[$$in2$i$i$i188>>2]);
 $152 = Math_fround($130 - $149);
 $153 = Math_fround($131 - $150);
 $154 = Math_fround($132 - $151);
 HEAPF32[$Q>>2] = $152;
 $155 = (($Q) + 4|0);
 HEAPF32[$155>>2] = $153;
 $156 = (($Q) + 8|0);
 HEAPF32[$156>>2] = $154;
 $157 = (($Q) + 12|0);
 HEAPF32[$157>>2] = Math_fround(0.0);
 $158 = (($Q) + 16|0);
 ;HEAP32[$158+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$158+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $159 = (($Q) + 32|0);
 ;HEAP32[$159+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$159+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $160 = (($Q) + 48|0);
 ;HEAP32[$160+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$160+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$160+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$160+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $130;
 $161 = (($A) + 4|0);
 HEAPF32[$161>>2] = $131;
 $162 = (($A) + 8|0);
 HEAPF32[$162>>2] = $132;
 $163 = (($A) + 12|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = (($A) + 16|0);
 ;HEAP32[$164+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$164+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$164+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $165 = (($A) + 32|0);
 ;HEAP32[$165+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$165+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $166 = (($A) + 48|0);
 ;HEAP32[$166+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$166+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$166+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$166+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$B>>2] = $149;
 $167 = (($B) + 4|0);
 HEAPF32[$167>>2] = $150;
 $168 = (($B) + 8|0);
 HEAPF32[$168>>2] = $151;
 $169 = (($B) + 12|0);
 HEAPF32[$169>>2] = Math_fround(0.0);
 $170 = (($B) + 16|0);
 ;HEAP32[$170+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$170+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$170+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$170+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $171 = (($B) + 32|0);
 ;HEAP32[$171+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$171+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$171+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$171+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $172 = (($B) + 48|0);
 ;HEAP32[$172+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$172+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $173 = Math_fround(-$152);
 $174 = Math_fround(-$153);
 $175 = Math_fround(-$154);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $176 = (($a) + 32|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = (($b) + 32|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = $177 > $179;
 $$$i = $180 ? $179 : $177;
 $181 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $182 = Math_fround($181 * $181);
 $183 = Math_fround($_inflation * $_inflation);
 $184 = Math_fround($183 + $182);
 HEAPF32[$closA>>2] = $130;
 $185 = (($closA) + 4|0);
 HEAPF32[$185>>2] = $131;
 $186 = (($closA) + 8|0);
 HEAPF32[$186>>2] = $132;
 $187 = (($closA) + 12|0);
 HEAPF32[$187>>2] = Math_fround(0.0);
 HEAPF32[$closB>>2] = $149;
 $188 = (($closB) + 4|0);
 HEAPF32[$188>>2] = $150;
 $189 = (($closB) + 8|0);
 HEAPF32[$189>>2] = $151;
 $190 = (($closB) + 12|0);
 HEAPF32[$190>>2] = Math_fround(0.0);
 $191 = Math_fround($152 * $152);
 $192 = Math_fround($153 * $153);
 $193 = Math_fround($191 + $192);
 $194 = Math_fround($154 * $154);
 $195 = Math_fround($193 + $194);
 $196 = $195 > $182;
 L1: do {
  if ($196) {
   $197 = Math_fround($14 * Math_fround(0.0));
   $198 = Math_fround($12 * Math_fround(0.0));
   $199 = Math_fround($10 * Math_fround(0.0));
   $200 = Math_fround($197 + $19);
   $201 = Math_fround($198 + $17);
   $202 = Math_fround($199 + $15);
   $203 = (($2) + 4|0);
   $204 = (($2) + 8|0);
   $205 = (($2) + 12|0);
   $206 = (($support) + 4|0);
   $207 = (($support) + 8|0);
   $208 = (($support) + 12|0);
   $209 = (($B) + 16|0);
   $210 = (($B) + 20|0);
   $211 = (($B) + 24|0);
   $212 = (($B) + 28|0);
   $213 = (($B) + 32|0);
   $214 = (($B) + 36|0);
   $215 = (($B) + 40|0);
   $216 = (($B) + 44|0);
   $217 = (($A) + 16|0);
   $218 = (($A) + 20|0);
   $219 = (($A) + 24|0);
   $220 = (($Q) + 16|0);
   $221 = (($Q) + 20|0);
   $222 = (($Q) + 24|0);
   $223 = (($Q) + 28|0);
   $224 = (($A) + 32|0);
   $225 = (($A) + 36|0);
   $226 = (($A) + 40|0);
   $227 = (($Q) + 32|0);
   $228 = (($Q) + 36|0);
   $229 = (($Q) + 40|0);
   $230 = (($Q) + 44|0);
   $231 = (($2) + 4|0);
   $232 = (($2) + 8|0);
   $233 = (($2) + 12|0);
   $234 = (($tempV) + 4|0);
   $235 = (($tempV) + 8|0);
   $236 = (($tempV) + 12|0);
   $238 = $173;$240 = $174;$243 = $175;$328 = $202;$330 = $201;$332 = $200;$355 = Math_fround(0.0);$556 = Math_fround(0.0);$557 = $132;$558 = $131;$559 = $130;$560 = $173;$561 = $174;$562 = $175;$563 = $195;
   while(1) {
    $237 = Math_fround($238 * $238);
    $239 = Math_fround($240 * $240);
    $241 = Math_fround($239 + $237);
    $242 = Math_fround($243 * $243);
    $244 = Math_fround($242 + $241);
    $245 = (Math_fround(Math_sqrt((Math_fround($244)))));
    $246 = Math_fround(Math_fround(1.0) / $245);
    $247 = Math_fround($238 * $246);
    $248 = Math_fround($240 * $246);
    $249 = Math_fround($243 * $246);
    $250 = Math_fround(HEAPF32[$aToB>>2]);
    $251 = Math_fround($247 * $250);
    $252 = Math_fround(HEAPF32[$54>>2]);
    $253 = Math_fround($248 * $252);
    $254 = Math_fround($251 + $253);
    $255 = Math_fround(HEAPF32[$58>>2]);
    $256 = Math_fround($249 * $255);
    $257 = Math_fround($254 + $256);
    $258 = Math_fround(HEAPF32[$62>>2]);
    $259 = Math_fround($247 * $258);
    $260 = Math_fround(HEAPF32[$65>>2]);
    $261 = Math_fround($248 * $260);
    $262 = Math_fround($259 + $261);
    $263 = Math_fround(HEAPF32[$69>>2]);
    $264 = Math_fround($249 * $263);
    $265 = Math_fround($262 + $264);
    $266 = Math_fround(HEAPF32[$73>>2]);
    $267 = Math_fround($247 * $266);
    $268 = Math_fround(HEAPF32[$76>>2]);
    $269 = Math_fround($248 * $268);
    $270 = Math_fround($267 + $269);
    $271 = Math_fround(HEAPF32[$80>>2]);
    $272 = Math_fround($249 * $271);
    $273 = Math_fround($270 + $272);
    $274 = Math_fround(HEAPF32[$85>>2]);
    $275 = Math_fround(HEAPF32[$87>>2]);
    $276 = Math_fround(HEAPF32[$89>>2]);
    $277 = Math_fround($257 * $274);
    $278 = Math_fround($265 * $275);
    $279 = Math_fround($277 + $278);
    $280 = Math_fround($273 * $276);
    $281 = Math_fround($279 + $280);
    $282 = Math_fround(HEAPF32[$97>>2]);
    $283 = Math_fround(HEAPF32[$99>>2]);
    $284 = Math_fround(HEAPF32[$101>>2]);
    $285 = Math_fround($257 * $282);
    $286 = Math_fround($265 * $283);
    $287 = Math_fround($285 + $286);
    $288 = Math_fround($273 * $284);
    $289 = Math_fround($287 + $288);
    $290 = $281 > $289;
    ;HEAP32[$3+0>>2]=HEAP32[$84+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$84+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$84+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$84+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$96+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$96+12>>2]|0;
    $b$a$i$i$i$i = $290 ? $3 : $2;
    $291 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
    $$in1$i$i$i$i = (($b$a$i$i$i$i) + 4|0);
    $292 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
    $$in2$i$i$i$i = (($b$a$i$i$i$i) + 8|0);
    $293 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
    $294 = Math_fround(HEAPF32[$21>>2]);
    $295 = Math_fround(HEAPF32[$23>>2]);
    $296 = Math_fround(HEAPF32[$25>>2]);
    $297 = Math_fround($250 * $291);
    $298 = Math_fround($258 * $292);
    $299 = Math_fround($297 + $298);
    $300 = Math_fround($266 * $293);
    $301 = Math_fround($299 + $300);
    $302 = Math_fround($252 * $291);
    $303 = Math_fround($260 * $292);
    $304 = Math_fround($302 + $303);
    $305 = Math_fround($268 * $293);
    $306 = Math_fround($304 + $305);
    $307 = Math_fround($255 * $291);
    $308 = Math_fround($263 * $292);
    $309 = Math_fround($307 + $308);
    $310 = Math_fround($271 * $293);
    $311 = Math_fround($309 + $310);
    $312 = Math_fround($301 + $294);
    $313 = Math_fround($306 + $295);
    $314 = Math_fround($311 + $296);
    $315 = $247 < Math_fround(-0.0);
    $316 = $248 < Math_fround(-0.0);
    $317 = $249 < Math_fround(-0.0);
    ;HEAP32[$3+0>>2]=HEAP32[$136+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$136+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$136+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$136+12>>2]|0;
    $318 = Math_fround(HEAPF32[$137>>2]);
    $319 = Math_fround(HEAPF32[$139>>2]);
    $320 = Math_fround(HEAPF32[$141>>2]);
    $321 = Math_fround(-$318);
    $322 = Math_fround(-$319);
    $323 = Math_fround(-$320);
    HEAPF32[$2>>2] = $321;
    HEAPF32[$203>>2] = $322;
    HEAPF32[$204>>2] = $323;
    HEAPF32[$205>>2] = Math_fround(0.0);
    $b$a$i$i$i139 = $315 ? $3 : $2;
    $324 = Math_fround(HEAPF32[$b$a$i$i$i139>>2]);
    $a$pn3$i$i$i141 = $316 ? $3 : $2;
    $$in1$i$i$i142 = (($a$pn3$i$i$i141) + 4|0);
    $325 = Math_fround(HEAPF32[$$in1$i$i$i142>>2]);
    $b$a5$i$i$i143 = $317 ? $3 : $2;
    $$in2$i$i$i144 = (($b$a5$i$i$i143) + 8|0);
    $326 = Math_fround(HEAPF32[$$in2$i$i$i144>>2]);
    $327 = Math_fround($328 + $324);
    $329 = Math_fround($330 + $325);
    $331 = Math_fround($332 + $326);
    $333 = Math_fround($312 - $327);
    $334 = Math_fround($313 - $329);
    $335 = Math_fround($314 - $331);
    HEAPF32[$support>>2] = $333;
    HEAPF32[$206>>2] = $334;
    HEAPF32[$207>>2] = $335;
    HEAPF32[$208>>2] = Math_fround(0.0);
    $336 = Math_fround($247 * $333);
    $337 = Math_fround($248 * $334);
    $338 = Math_fround(-$337);
    $339 = Math_fround($338 - $336);
    $340 = Math_fround($249 * $335);
    $341 = Math_fround($339 - $340);
    $342 = Math_fround($341 - $_inflation);
    $343 = Math_fround(HEAPF32[$r>>2]);
    $344 = Math_fround(HEAPF32[$11>>2]);
    $345 = Math_fround(HEAPF32[$13>>2]);
    $346 = Math_fround($247 * $343);
    $347 = Math_fround($248 * $344);
    $348 = Math_fround($346 + $347);
    $349 = Math_fround($249 * $345);
    $350 = Math_fround($348 + $349);
    $351 = $342 > Math_fround(0.0);
    if ($351) {
     $352 = !($350 >= Math_fround(0.0));
     if (!($352)) {
      $$0 = 0;
      label = 22;
      break;
     }
     $353 = Math_fround($342 / $350);
     $354 = Math_fround($355 - $353);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1332+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1332+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1332+8>>2]|0;
     $356 = $354 > $355;
     if ($356) {
      $357 = $354 > Math_fround(1.0);
      if ($357) {
       $$0 = 0;
       label = 22;
       break;
      }
      $358 = Math_fround(HEAPF32[$s>>2]);
      $359 = Math_fround(HEAPF32[$16>>2]);
      $360 = Math_fround(HEAPF32[$18>>2]);
      $361 = Math_fround($354 * $343);
      $362 = Math_fround($354 * $344);
      $363 = Math_fround($354 * $345);
      $364 = Math_fround($361 + $358);
      $365 = Math_fround($362 + $359);
      $366 = Math_fround($363 + $360);
      $367 = Math_fround($364 - $328);
      $368 = Math_fround($365 - $330);
      $369 = Math_fround($366 - $332);
      $370 = Math_fround(HEAPF32[$B>>2]);
      $371 = Math_fround(HEAPF32[$167>>2]);
      $372 = Math_fround(HEAPF32[$168>>2]);
      $373 = Math_fround($367 + $370);
      $374 = Math_fround($368 + $371);
      $375 = Math_fround($369 + $372);
      $376 = Math_fround(HEAPF32[$209>>2]);
      $377 = Math_fround(HEAPF32[$210>>2]);
      $378 = Math_fround(HEAPF32[$211>>2]);
      $379 = Math_fround($367 + $376);
      $380 = Math_fround($368 + $377);
      $381 = Math_fround($369 + $378);
      $382 = Math_fround(HEAPF32[$213>>2]);
      $383 = Math_fround(HEAPF32[$214>>2]);
      $384 = Math_fround(HEAPF32[$215>>2]);
      $385 = Math_fround($367 + $382);
      $386 = Math_fround($368 + $383);
      $387 = Math_fround($369 + $384);
      HEAPF32[$B>>2] = $373;
      HEAPF32[$167>>2] = $374;
      HEAPF32[$168>>2] = $375;
      HEAPF32[$169>>2] = Math_fround(0.0);
      HEAPF32[$209>>2] = $379;
      HEAPF32[$210>>2] = $380;
      HEAPF32[$211>>2] = $381;
      HEAPF32[$212>>2] = Math_fround(0.0);
      HEAPF32[$213>>2] = $385;
      HEAPF32[$214>>2] = $386;
      HEAPF32[$215>>2] = $387;
      HEAPF32[$216>>2] = Math_fround(0.0);
      $388 = Math_fround(HEAPF32[$A>>2]);
      $389 = Math_fround(HEAPF32[$161>>2]);
      $390 = Math_fround(HEAPF32[$162>>2]);
      $391 = Math_fround($388 - $373);
      $392 = Math_fround($389 - $374);
      $393 = Math_fround($390 - $375);
      HEAPF32[$Q>>2] = $391;
      HEAPF32[$155>>2] = $392;
      HEAPF32[$156>>2] = $393;
      HEAPF32[$157>>2] = Math_fround(0.0);
      $394 = Math_fround(HEAPF32[$217>>2]);
      $395 = Math_fround(HEAPF32[$218>>2]);
      $396 = Math_fround(HEAPF32[$219>>2]);
      $397 = Math_fround($394 - $379);
      $398 = Math_fround($395 - $380);
      $399 = Math_fround($396 - $381);
      HEAPF32[$220>>2] = $397;
      HEAPF32[$221>>2] = $398;
      HEAPF32[$222>>2] = $399;
      HEAPF32[$223>>2] = Math_fround(0.0);
      $400 = Math_fround(HEAPF32[$224>>2]);
      $401 = Math_fround(HEAPF32[$225>>2]);
      $402 = Math_fround(HEAPF32[$226>>2]);
      $403 = Math_fround($400 - $385);
      $404 = Math_fround($401 - $386);
      $405 = Math_fround($402 - $387);
      HEAPF32[$227>>2] = $403;
      HEAPF32[$228>>2] = $404;
      HEAPF32[$229>>2] = $405;
      HEAPF32[$230>>2] = Math_fround(0.0);
      ;HEAP32[$3+0>>2]=HEAP32[$136+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$136+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$136+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$136+12>>2]|0;
      HEAPF32[$2>>2] = $321;
      HEAPF32[$231>>2] = $322;
      HEAPF32[$232>>2] = $323;
      HEAPF32[$233>>2] = Math_fround(0.0);
      $b$a$i$i$i = $315 ? $3 : $2;
      $406 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
      $a$pn3$i$i$i = $316 ? $3 : $2;
      $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
      $407 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
      $b$a5$i$i$i = $317 ? $3 : $2;
      $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
      $408 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
      $409 = Math_fround($364 + $406);
      $410 = Math_fround($365 + $407);
      $411 = Math_fround($366 + $408);
      $412 = Math_fround($312 - $409);
      $413 = Math_fround($313 - $410);
      $414 = Math_fround($314 - $411);
      HEAPF32[$support>>2] = $412;
      HEAPF32[$206>>2] = $413;
      HEAPF32[$207>>2] = $414;
      HEAPF32[$208>>2] = Math_fround(0.0);
      $421 = $409;$423 = $410;$425 = $411;$433 = $412;$435 = $413;$437 = $414;$492 = Math_fround(3.40282346638528859812E+38);$564 = $354;$565 = $366;$566 = $365;$567 = $364;$568 = $243;$569 = $240;$570 = $238;
     } else {
      $421 = $327;$423 = $329;$425 = $331;$433 = $333;$435 = $334;$437 = $335;$492 = $563;$564 = $354;$565 = $332;$566 = $330;$567 = $328;$568 = $562;$569 = $561;$570 = $560;
     }
    } else {
     $421 = $327;$423 = $329;$425 = $331;$433 = $333;$435 = $334;$437 = $335;$492 = $563;$564 = $355;$565 = $332;$566 = $330;$567 = $328;$568 = $562;$569 = $561;$570 = $560;
    }
    $415 = HEAP32[$size>>2]|0;
    $416 = (($A) + ($415<<4)|0);
    HEAPF32[$416>>2] = $312;
    $417 = ((($A) + ($415<<4)|0) + 4|0);
    HEAPF32[$417>>2] = $313;
    $418 = ((($A) + ($415<<4)|0) + 8|0);
    HEAPF32[$418>>2] = $314;
    $419 = ((($A) + ($415<<4)|0) + 12|0);
    HEAPF32[$419>>2] = Math_fround(0.0);
    $420 = (($B) + ($415<<4)|0);
    HEAPF32[$420>>2] = $421;
    $422 = ((($B) + ($415<<4)|0) + 4|0);
    HEAPF32[$422>>2] = $423;
    $424 = ((($B) + ($415<<4)|0) + 8|0);
    HEAPF32[$424>>2] = $425;
    $426 = ((($B) + ($415<<4)|0) + 12|0);
    HEAPF32[$426>>2] = Math_fround(0.0);
    $427 = (($415) + 1)|0;
    HEAP32[$size>>2] = $427;
    $428 = (($Q) + ($415<<4)|0);
    ;HEAP32[$428+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$428+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$428+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$428+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($415|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($415|0) == 0)) {
      HEAPF32[$closA>>2] = $312;
      HEAPF32[$185>>2] = $313;
      HEAPF32[$186>>2] = $314;
      HEAPF32[$187>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $421;
      HEAPF32[$188>>2] = $423;
      HEAPF32[$189>>2] = $425;
      HEAPF32[$190>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($415|0) == 1)) {
      $429 = Math_fround(HEAPF32[$Q>>2]);
      $430 = Math_fround(HEAPF32[$155>>2]);
      $431 = Math_fround(HEAPF32[$156>>2]);
      $432 = Math_fround($433 - $429);
      $434 = Math_fround($435 - $430);
      $436 = Math_fround($437 - $431);
      $438 = Math_fround($432 * $432);
      $439 = Math_fround($434 * $434);
      $440 = Math_fround($438 + $439);
      $441 = Math_fround($436 * $436);
      $442 = Math_fround($440 + $441);
      $443 = $442 == Math_fround(0.0);
      if ($443) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $444 = Math_fround($430 * $434);
       $445 = Math_fround(-$444);
       $446 = Math_fround($429 * $432);
       $447 = Math_fround($445 - $446);
       $448 = Math_fround($431 * $436);
       $449 = Math_fround($447 - $448);
       $450 = Math_fround(HEAPF32[$A>>2]);
       $451 = Math_fround(HEAPF32[$161>>2]);
       $452 = Math_fround(HEAPF32[$162>>2]);
       $453 = Math_fround($312 - $450);
       $454 = Math_fround($313 - $451);
       $455 = Math_fround($314 - $452);
       $456 = Math_fround(HEAPF32[$B>>2]);
       $457 = Math_fround(HEAPF32[$167>>2]);
       $458 = Math_fround(HEAPF32[$168>>2]);
       $459 = Math_fround($421 - $456);
       $460 = Math_fround($423 - $457);
       $461 = Math_fround($425 - $458);
       $462 = Math_fround($449 / $442);
       $463 = $462 > Math_fround(1.0);
       $$$i$i$i = $463 ? Math_fround(1.0) : $462;
       $464 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $464 ? $$$i$i$i : Math_fround(0.0);
       $465 = Math_fround($453 * $$$i8$i$i);
       $466 = Math_fround($454 * $$$i8$i$i);
       $467 = Math_fround($455 * $$$i8$i$i);
       $468 = Math_fround($450 + $465);
       $469 = Math_fround($451 + $466);
       $470 = Math_fround($452 + $467);
       $471 = Math_fround($459 * $$$i8$i$i);
       $472 = Math_fround($460 * $$$i8$i$i);
       $473 = Math_fround($461 * $$$i8$i$i);
       $474 = Math_fround($456 + $471);
       $475 = Math_fround($457 + $472);
       $476 = Math_fround($458 + $473);
       HEAPF32[$closA>>2] = $468;
       HEAPF32[$185>>2] = $469;
       HEAPF32[$186>>2] = $470;
       HEAPF32[$187>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $474;
       HEAPF32[$188>>2] = $475;
       HEAPF32[$189>>2] = $476;
       HEAPF32[$190>>2] = Math_fround(0.0);
       $477 = Math_fround($468 - $474);
       $478 = Math_fround($469 - $475);
       $479 = Math_fround($470 - $476);
       HEAPF32[$tempV>>2] = $477;
       HEAPF32[$234>>2] = $478;
       HEAPF32[$235>>2] = $479;
       HEAPF32[$236>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($415|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$158,$support,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $480 = Math_fround(HEAPF32[$tempV>>2]);
    $481 = Math_fround(HEAPF32[$234>>2]);
    $482 = Math_fround(HEAPF32[$235>>2]);
    $483 = Math_fround(-$480);
    $484 = Math_fround(-$481);
    $485 = Math_fround(-$482);
    $486 = Math_fround($480 * $480);
    $487 = Math_fround($481 * $481);
    $488 = Math_fround($486 + $487);
    $489 = Math_fround($482 * $482);
    $490 = Math_fround($488 + $489);
    $491 = $492 > $490;
    $493 = $491 << 31 >> 31;
    $494 = $490 > $184;
    if (!($494)) {
     $$lcssa = $564;$$lcssa920 = $556;$$lcssa922 = $557;$$lcssa924 = $558;$$lcssa926 = $559;$$lcssa928 = $485;$$lcssa930 = $484;$$lcssa932 = $483;$$lcssa934 = $490;$$lcssa936 = $493;$$lcssa938 = $568;$$lcssa940 = $569;$$lcssa942 = $570;
     break L1;
    }
    if (!($491)) {
     $$lcssa = $564;$$lcssa920 = $556;$$lcssa922 = $557;$$lcssa924 = $558;$$lcssa926 = $559;$$lcssa928 = $485;$$lcssa930 = $484;$$lcssa932 = $483;$$lcssa934 = $490;$$lcssa936 = $493;$$lcssa938 = $568;$$lcssa940 = $569;$$lcssa942 = $570;
     break L1;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre976 = Math_fround(HEAPF32[$185>>2]);
    $$pre977 = Math_fround(HEAPF32[$186>>2]);
    $$pre978 = Math_fround(HEAPF32[$187>>2]);
    $238 = $483;$240 = $484;$243 = $485;$328 = $567;$330 = $566;$332 = $565;$355 = $564;$556 = $$pre978;$557 = $$pre977;$558 = $$pre976;$559 = $$pre;$560 = $570;$561 = $569;$562 = $568;$563 = $490;
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa920 = Math_fround(0.0);$$lcssa922 = $132;$$lcssa924 = $131;$$lcssa926 = $130;$$lcssa928 = $175;$$lcssa930 = $174;$$lcssa932 = $173;$$lcssa934 = $195;$$lcssa936 = -1;$$lcssa938 = $175;$$lcssa940 = $174;$$lcssa942 = $173;
  }
 } while(0);
 $495 = (($a) + 64|0);
 $496 = HEAP32[$495>>2]|0;
 $497 = (($a) + 68|0);
 $498 = HEAP32[$497>>2]|0;
 $499 = (($a) + 72|0);
 $500 = HEAP32[$499>>2]|0;
 $501 = $$lcssa934 > $182;
 if ($501) {
  $phitmp = ($$lcssa936|0)==(0);
  $phitmp913 = $phitmp ? $4 : $5;
  $509 = $phitmp913;
 } else {
  $509 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa932;
 $502 = (($5) + 4|0);
 HEAPF32[$502>>2] = $$lcssa930;
 $503 = (($5) + 8|0);
 HEAPF32[$503>>2] = $$lcssa928;
 $504 = (($5) + 12|0);
 HEAPF32[$504>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa942;
 $505 = (($4) + 4|0);
 HEAPF32[$505>>2] = $$lcssa940;
 $506 = (($4) + 8|0);
 HEAPF32[$506>>2] = $$lcssa938;
 $507 = (($4) + 12|0);
 HEAPF32[$507>>2] = Math_fround(0.0);
 $508 = Math_fround(HEAPF32[$509>>2]);
 $$in1$i37 = (($509) + 4|0);
 $510 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($509) + 8|0);
 $511 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $512 = Math_fround($508 * $508);
 $513 = Math_fround($510 * $510);
 $514 = Math_fround($512 + $513);
 $515 = Math_fround($511 * $511);
 $516 = Math_fround($514 + $515);
 $517 = (Math_fround(Math_sqrt((Math_fround($516)))));
 $518 = Math_fround(Math_fround(1.0) / $517);
 $519 = Math_fround($508 * $518);
 $520 = Math_fround($510 * $518);
 $521 = Math_fround($511 * $518);
 $522 = Math_fround(-$519);
 $523 = Math_fround(-$520);
 $524 = Math_fround(-$521);
 HEAPF32[$normal>>2] = $522;
 $525 = (($normal) + 4|0);
 HEAPF32[$525>>2] = $523;
 $526 = (($normal) + 8|0);
 HEAPF32[$526>>2] = $524;
 $527 = (($normal) + 12|0);
 HEAPF32[$527>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $528 = (($lambda) + 4|0);
 ;HEAP32[$528+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$528+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$528+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$6>>2] = $$lcssa926;
 $529 = (($6) + 4|0);
 HEAPF32[$529>>2] = $$lcssa924;
 $530 = (($6) + 8|0);
 HEAPF32[$530>>2] = $$lcssa922;
 $531 = (($6) + 12|0);
 HEAPF32[$531>>2] = $$lcssa920;
 $532 = ($$lcssa936|0)==(0);
 $b$a$i18 = $532 ? $6 : $7;
 $533 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $534 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $535 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $533;
 HEAPF32[$185>>2] = $534;
 HEAPF32[$186>>2] = $535;
 HEAPF32[$187>>2] = Math_fround(0.0);
 $536 = (($a) + 16|0);
 $537 = Math_fround(HEAPF32[$536>>2]);
 $538 = Math_fround($537 * $522);
 $539 = Math_fround($537 * $523);
 $540 = Math_fround($537 * $524);
 $541 = Math_fround($533 - $538);
 $542 = Math_fround($534 - $539);
 $543 = Math_fround($535 - $540);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $541;
 $544 = (($9) + 4|0);
 HEAPF32[$544>>2] = $542;
 $545 = (($9) + 8|0);
 HEAPF32[$545>>2] = $543;
 $546 = (($9) + 12|0);
 HEAPF32[$546>>2] = Math_fround(0.0);
 $547 = ($496|0)==(0);
 $b$a$i = $547 ? $8 : $9;
 $548 = Math_fround(HEAPF32[$b$a$i>>2]);
 $549 = ($498|0)==(0);
 $a$pn3$i = $549 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $550 = Math_fround(HEAPF32[$$in1$i>>2]);
 $551 = ($500|0)==(0);
 $b$a5$i = $551 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $552 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $548;
 $553 = (($closestA) + 4|0);
 HEAPF32[$553>>2] = $550;
 $554 = (($closestA) + 8|0);
 HEAPF32[$554>>2] = $552;
 $555 = (($closestA) + 12|0);
 HEAPF32[$555>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_8CapsuleVENS0_10ShrunkBoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$761 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i165 = Math_fround(0), $$$i134 = Math_fround(0), $$$i194 = Math_fround(0), $$$i749819 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i166 = Math_fround(0), $$0 = 0, $$757 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i$i$i = 0, $$in1$i$i175 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i$i$i = 0, $$in2$i$i177 = 0, $$ph = Math_fround(0);
 var $$ph769 = Math_fround(0), $$ph770 = Math_fround(0), $$ph771 = Math_fround(0), $$ph772 = Math_fround(0), $$ph773 = Math_fround(0), $$ph774 = Math_fround(0), $$ph775 = Math_fround(0), $$ph777 = Math_fround(0), $$ph778 = 0, $$ph782 = Math_fround(0), $$ph783 = Math_fround(0), $$ph784 = Math_fround(0), $$pre = Math_fround(0), $$pre866 = Math_fround(0), $$pre867 = Math_fround(0), $$pre868 = Math_fround(0), $$pre869 = Math_fround(0), $$pre870 = Math_fround(0), $$pre871 = Math_fround(0), $$pre872 = Math_fround(0);
 var $$sroa$1 = 0, $$sroa$1238 = 0, $$sroa$1240 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0;
 var $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0);
 var $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0);
 var $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0);
 var $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0);
 var $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0);
 var $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0);
 var $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0);
 var $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = 0, $454 = 0, $455 = 0;
 var $456 = Math_fround(0), $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0);
 var $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0);
 var $492 = 0, $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0);
 var $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0);
 var $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = 0, $556 = 0, $557 = 0, $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0);
 var $564 = 0, $565 = 0, $566 = 0, $567 = Math_fround(0), $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0;
 var $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $a$pn3$i$i = 0, $a$pn3$i$i174 = 0, $aInd = 0, $b$a$i = 0, $b$a$i$i = 0, $b$a$i$i$i$i = 0, $b$a$i$i172 = 0, $b$a5$i$i = 0, $b$a5$i$i176 = 0;
 var $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$0829 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp765 = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0;
 var $supportA1 = 0, $supportB2 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 368|0;
 $1 = sp + 320|0;
 $2 = sp + 336|0;
 $3 = sp + 352|0;
 $closA = sp + 384|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 484|0;
 $minDist$sroa$1 = sp + 472|0;
 $Q = sp;
 $A = sp + 144|0;
 $B = sp + 64|0;
 $aInd = sp + 456|0;
 $bInd = sp + 496|0;
 $size = sp + 416|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 208|0;
 $lastB = sp + 224|0;
 $4 = sp + 240|0;
 $supportA1 = sp + 256|0;
 $supportB2 = sp + 272|0;
 $support3 = sp + 288|0;
 $$sroa$1240 = sp + 432|0;
 $5 = sp + 304|0;
 $$sroa$1238 = sp + 444|0;
 $$sroa$1 = sp + 420|0;
 $6 = (($a) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($b) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$_contactDist>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i194 = $15 ? $14 : $12;
 $16 = Math_fround($$$i194 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($7 + $9);
 $18 = (($closA) + 4|0);
 $19 = (($closA) + 8|0);
 $20 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $21 = (($closB) + 4|0);
 $22 = (($closB) + 8|0);
 $23 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $24 = Math_fround($16 * $16);
 HEAP32[$size>>2] = 0;
 $25 = HEAP8[$_size>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $212 = (($aToB) + 48|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = (($aToB) + 52|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($aToB) + 56|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($aToB) + 60|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = Math_fround($213 * $213);
  $221 = Math_fround($215 * $215);
  $222 = Math_fround($220 + $221);
  $223 = Math_fround($217 * $217);
  $224 = Math_fround($222 + $223);
  $225 = $224 > Math_fround(0.0);
  HEAPF32[$3>>2] = $213;
  $226 = (($3) + 4|0);
  HEAPF32[$226>>2] = $215;
  $227 = (($3) + 8|0);
  HEAPF32[$227>>2] = $217;
  $228 = (($3) + 12|0);
  HEAPF32[$228>>2] = $219;
  HEAPF32[$2>>2] = Math_fround(1.0);
  $229 = (($2) + 4|0);
  HEAPF32[$229>>2] = Math_fround(0.0);
  $230 = (($2) + 8|0);
  HEAPF32[$230>>2] = Math_fround(0.0);
  $231 = (($2) + 12|0);
  HEAPF32[$231>>2] = Math_fround(0.0);
  $b$a$i = $225 ? $3 : $2;
  $232 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $233 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $234 = Math_fround(HEAPF32[$$in2$i>>2]);
  $$ph = Math_fround(0.0);$$ph769 = Math_fround(0.0);$$ph770 = Math_fround(0.0);$$ph771 = Math_fround(0.0);$$ph772 = Math_fround(0.0);$$ph773 = Math_fround(0.0);$$ph774 = Math_fround(0.0);$$ph775 = Math_fround(0.0);$$ph777 = Math_fround(3.40282346638528859812E+38);$$ph778 = 1;$$ph782 = $234;$$ph783 = $233;$$ph784 = $232;
 } else {
  $27 = (($lastQ) + 4|0);
  $28 = (($lastQ) + 8|0);
  $29 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $30 = (($lastA) + 4|0);
  $31 = (($lastA) + 8|0);
  $32 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $33 = (($lastB) + 4|0);
  $34 = (($lastB) + 8|0);
  $35 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $36 = (($a) + 96|0);
  $37 = (($aToB) + 48|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($aToB) + 52|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($aToB) + 56|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(HEAPF32[$aToB>>2]);
  $44 = (($aToB) + 16|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($aToB) + 32|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = (($aToB) + 4|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($aToB) + 20|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($aToB) + 36|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($aToB) + 8|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($aToB) + 24|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($aToB) + 40|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($b) + 144|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($b) + 148|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($b) + 152|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($61 - $9);
  $67 = Math_fround($63 - $9);
  $68 = Math_fround($65 - $9);
  $69 = Math_fround(-$66);
  $70 = Math_fround(-$67);
  $71 = Math_fround(-$68);
  $72 = (($1) + 4|0);
  $73 = (($1) + 8|0);
  $74 = (($1) + 12|0);
  $75 = (($0) + 4|0);
  $76 = (($0) + 8|0);
  $77 = (($0) + 12|0);
  $78 = $25&255;
  $79 = ($78>>>0)>(1);
  $umax = $79 ? $78 : 1;
  $129 = 0;$i$0829 = 0;
  while(1) {
   $80 = (($aIndices) + ($i$0829)|0);
   $81 = HEAP8[$80>>0]|0;
   $82 = $81&255;
   $83 = (($aInd) + ($i$0829<<2)|0);
   HEAP32[$83>>2] = $82;
   $84 = (($bIndices) + ($i$0829)|0);
   $85 = HEAP8[$84>>0]|0;
   $86 = $85&255;
   $87 = (($bInd) + ($i$0829<<2)|0);
   HEAP32[$87>>2] = $86;
   $88 = (1 - ($82))|0;
   $89 = (($36) + ($88<<4)|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = ((($36) + ($88<<4)|0) + 4|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = ((($36) + ($88<<4)|0) + 8|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = Math_fround($90 * $43);
   $96 = Math_fround($92 * $45);
   $97 = Math_fround($95 + $96);
   $98 = Math_fround($94 * $47);
   $99 = Math_fround($97 + $98);
   $100 = Math_fround($90 * $49);
   $101 = Math_fround($92 * $51);
   $102 = Math_fround($100 + $101);
   $103 = Math_fround($94 * $53);
   $104 = Math_fround($102 + $103);
   $105 = Math_fround($90 * $55);
   $106 = Math_fround($92 * $57);
   $107 = Math_fround($105 + $106);
   $108 = Math_fround($94 * $59);
   $109 = Math_fround($107 + $108);
   $110 = Math_fround($38 + $99);
   $111 = Math_fround($40 + $104);
   $112 = Math_fround($42 + $109);
   $113 = (549664 + ($86<<4)|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ((549664 + ($86<<4)|0) + 4|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = ((549664 + ($86<<4)|0) + 8|0);
   $118 = HEAP32[$117>>2]|0;
   HEAPF32[$1>>2] = $66;
   HEAPF32[$72>>2] = $67;
   HEAPF32[$73>>2] = $68;
   HEAPF32[$74>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $69;
   HEAPF32[$75>>2] = $70;
   HEAPF32[$76>>2] = $71;
   HEAPF32[$77>>2] = Math_fround(0.0);
   $119 = ($114|0)==(0);
   $b$a$i$i172 = $119 ? $0 : $1;
   $120 = Math_fround(HEAPF32[$b$a$i$i172>>2]);
   $121 = ($116|0)==(0);
   $a$pn3$i$i174 = $121 ? $0 : $1;
   $$in1$i$i175 = (($a$pn3$i$i174) + 4|0);
   $122 = Math_fround(HEAPF32[$$in1$i$i175>>2]);
   $123 = ($118|0)==(0);
   $b$a5$i$i176 = $123 ? $0 : $1;
   $$in2$i$i177 = (($b$a5$i$i176) + 8|0);
   $124 = Math_fround(HEAPF32[$$in2$i$i177>>2]);
   $125 = Math_fround($110 - $120);
   $126 = Math_fround($111 - $122);
   $127 = Math_fround($112 - $124);
   $128 = (($A) + ($129<<4)|0);
   HEAPF32[$lastA>>2] = $110;
   HEAPF32[$30>>2] = $111;
   HEAPF32[$31>>2] = $112;
   HEAPF32[$32>>2] = Math_fround(0.0);
   ;HEAP32[$128+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$128+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$128+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$128+12>>2]=HEAP32[$lastA+12>>2]|0;
   $130 = (($B) + ($129<<4)|0);
   HEAPF32[$lastB>>2] = $120;
   HEAPF32[$33>>2] = $122;
   HEAPF32[$34>>2] = $124;
   HEAPF32[$35>>2] = Math_fround(0.0);
   ;HEAP32[$130+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$130+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$130+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$130+12>>2]=HEAP32[$lastB+12>>2]|0;
   $131 = (($129) + 1)|0;
   $132 = (($Q) + ($129<<4)|0);
   HEAPF32[$lastQ>>2] = $125;
   HEAPF32[$27>>2] = $126;
   HEAPF32[$28>>2] = $127;
   HEAPF32[$29>>2] = Math_fround(0.0);
   ;HEAP32[$132+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$132+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $133 = (($i$0829) + 1)|0;
   $134 = ($133>>>0)<($78>>>0);
   if ($134) {
    $129 = $131;$i$0829 = $133;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $umax;
  do {
   if ((($umax|0) == 2)) {
    $135 = Math_fround(HEAPF32[$Q>>2]);
    $136 = (($Q) + 4|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = (($Q) + 8|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = Math_fround($125 - $135);
    $141 = Math_fround($126 - $137);
    $142 = Math_fround($127 - $139);
    $143 = Math_fround($140 * $140);
    $144 = Math_fround($141 * $141);
    $145 = Math_fround($143 + $144);
    $146 = Math_fround($142 * $142);
    $147 = Math_fround($145 + $146);
    $148 = $147 == Math_fround(0.0);
    if ($148) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $149 = Math_fround($137 * $141);
     $150 = Math_fround(-$149);
     $151 = Math_fround($135 * $140);
     $152 = Math_fround($150 - $151);
     $153 = Math_fround($139 * $142);
     $154 = Math_fround($152 - $153);
     $155 = Math_fround(HEAPF32[$A>>2]);
     $156 = (($A) + 4|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = (($A) + 8|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = Math_fround($110 - $155);
     $161 = Math_fround($111 - $157);
     $162 = Math_fround($112 - $159);
     $163 = Math_fround(HEAPF32[$B>>2]);
     $164 = (($B) + 4|0);
     $165 = Math_fround(HEAPF32[$164>>2]);
     $166 = (($B) + 8|0);
     $167 = Math_fround(HEAPF32[$166>>2]);
     $168 = Math_fround($120 - $163);
     $169 = Math_fround($122 - $165);
     $170 = Math_fround($124 - $167);
     $171 = Math_fround($154 / $147);
     $172 = $171 > Math_fround(1.0);
     $$$i$i$i165 = $172 ? Math_fround(1.0) : $171;
     $173 = $$$i$i$i165 > Math_fround(0.0);
     $$$i8$i$i166 = $173 ? $$$i$i$i165 : Math_fround(0.0);
     $174 = Math_fround($160 * $$$i8$i$i166);
     $175 = Math_fround($161 * $$$i8$i$i166);
     $176 = Math_fround($162 * $$$i8$i$i166);
     $177 = Math_fround($155 + $174);
     $178 = Math_fround($157 + $175);
     $179 = Math_fround($159 + $176);
     $180 = Math_fround($168 * $$$i8$i$i166);
     $181 = Math_fround($169 * $$$i8$i$i166);
     $182 = Math_fround($170 * $$$i8$i$i166);
     $183 = Math_fround($163 + $180);
     $184 = Math_fround($165 + $181);
     $185 = Math_fround($167 + $182);
     HEAPF32[$closA>>2] = $177;
     HEAPF32[$18>>2] = $178;
     HEAPF32[$19>>2] = $179;
     HEAPF32[$20>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $183;
     HEAPF32[$21>>2] = $184;
     HEAPF32[$22>>2] = $185;
     HEAPF32[$23>>2] = Math_fround(0.0);
     $186 = Math_fround($177 - $183);
     $187 = Math_fround($178 - $184);
     $188 = Math_fround($179 - $185);
     HEAPF32[$4>>2] = $186;
     $189 = (($4) + 4|0);
     HEAPF32[$189>>2] = $187;
     $190 = (($4) + 8|0);
     HEAPF32[$190>>2] = $188;
     $191 = (($4) + 12|0);
     HEAPF32[$191>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($umax|0) == 3)) {
    $192 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$192,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($umax|0) == 4)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($umax|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  $193 = Math_fround(HEAPF32[$4>>2]);
  $194 = (($4) + 4|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($4) + 8|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = Math_fround($193 * $193);
  $199 = Math_fround($195 * $195);
  $200 = Math_fround($198 + $199);
  $201 = Math_fround($197 * $197);
  $202 = Math_fround($200 + $201);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $203 = Math_fround(HEAPF32[$closA>>2]);
  $204 = Math_fround(HEAPF32[$18>>2]);
  $205 = Math_fround(HEAPF32[$19>>2]);
  $206 = Math_fround(HEAPF32[$20>>2]);
  $207 = Math_fround(HEAPF32[$closB>>2]);
  $208 = Math_fround(HEAPF32[$21>>2]);
  $209 = Math_fround(HEAPF32[$22>>2]);
  $210 = Math_fround(HEAPF32[$23>>2]);
  $211 = $202 > $24;
  $$ph = $206;$$ph769 = $205;$$ph770 = $204;$$ph771 = $203;$$ph772 = $210;$$ph773 = $209;$$ph774 = $208;$$ph775 = $207;$$ph777 = $202;$$ph778 = $211;$$ph782 = $197;$$ph783 = $195;$$ph784 = $193;
 }
 do {
  if ($$ph778) {
   $236 = (($aToB) + 4|0);
   $237 = (($aToB) + 8|0);
   $238 = (($aToB) + 16|0);
   $239 = (($aToB) + 20|0);
   $240 = (($aToB) + 24|0);
   $241 = (($aToB) + 32|0);
   $242 = (($aToB) + 36|0);
   $243 = (($aToB) + 40|0);
   $244 = (($a) + 96|0);
   $245 = (($a) + 96|0);
   $246 = (($a) + 100|0);
   $247 = (($a) + 104|0);
   $248 = (($a) + 112|0);
   $249 = (($a) + 112|0);
   $250 = (($a) + 116|0);
   $251 = (($a) + 120|0);
   $252 = (($aToB) + 48|0);
   $253 = (($aToB) + 52|0);
   $254 = (($aToB) + 56|0);
   $255 = (($supportA1) + 4|0);
   $256 = (($supportA1) + 8|0);
   $257 = (($supportA1) + 12|0);
   $258 = (($b) + 144|0);
   $259 = (($b) + 148|0);
   $260 = (($b) + 152|0);
   $261 = (($1) + 4|0);
   $262 = (($1) + 8|0);
   $263 = (($1) + 12|0);
   $264 = (($0) + 4|0);
   $265 = (($0) + 8|0);
   $266 = (($0) + 12|0);
   $267 = (($supportB2) + 4|0);
   $268 = (($supportB2) + 8|0);
   $269 = (($supportB2) + 12|0);
   $270 = (($support3) + 4|0);
   $271 = (($support3) + 8|0);
   $272 = (($support3) + 12|0);
   $273 = (($a) + 48|0);
   $274 = (($b) + 48|0);
   $275 = (($5) + 4|0);
   $276 = (($5) + 8|0);
   $277 = (($Q) + 4|0);
   $278 = (($Q) + 8|0);
   $279 = (($A) + 4|0);
   $280 = (($A) + 8|0);
   $281 = (($B) + 4|0);
   $282 = (($B) + 8|0);
   $283 = (($5) + 12|0);
   $284 = (($Q) + 16|0);
   $$$i749819 = $10;$286 = $$ph784;$288 = $$ph783;$290 = $$ph782;$400 = $$ph777;$533 = $$ph771;$534 = $$ph770;$535 = $$ph769;$536 = $$ph;$537 = $$ph775;$538 = $$ph774;$539 = $$ph773;$540 = $$ph772;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $285 = Math_fround(-$286);
    $287 = Math_fround(-$288);
    $289 = Math_fround(-$290);
    $291 = HEAP32[$size>>2]|0;
    $292 = (($A) + ($291<<4)|0);
    $293 = (($aInd) + ($291<<2)|0);
    $294 = Math_fround(HEAPF32[$aToB>>2]);
    $295 = Math_fround($294 * $285);
    $296 = Math_fround(HEAPF32[$236>>2]);
    $297 = Math_fround($296 * $287);
    $298 = Math_fround($295 + $297);
    $299 = Math_fround(HEAPF32[$237>>2]);
    $300 = Math_fround($299 * $289);
    $301 = Math_fround($298 + $300);
    $302 = Math_fround(HEAPF32[$238>>2]);
    $303 = Math_fround($302 * $285);
    $304 = Math_fround(HEAPF32[$239>>2]);
    $305 = Math_fround($304 * $287);
    $306 = Math_fround($303 + $305);
    $307 = Math_fround(HEAPF32[$240>>2]);
    $308 = Math_fround($307 * $289);
    $309 = Math_fround($306 + $308);
    $310 = Math_fround(HEAPF32[$241>>2]);
    $311 = Math_fround($310 * $285);
    $312 = Math_fround(HEAPF32[$242>>2]);
    $313 = Math_fround($312 * $287);
    $314 = Math_fround($311 + $313);
    $315 = Math_fround(HEAPF32[$243>>2]);
    $316 = Math_fround($315 * $289);
    $317 = Math_fround($314 + $316);
    $318 = Math_fround(HEAPF32[$245>>2]);
    $319 = Math_fround(HEAPF32[$246>>2]);
    $320 = Math_fround(HEAPF32[$247>>2]);
    $321 = Math_fround($301 * $318);
    $322 = Math_fround($309 * $319);
    $323 = Math_fround($321 + $322);
    $324 = Math_fround($317 * $320);
    $325 = Math_fround($323 + $324);
    $326 = Math_fround(HEAPF32[$249>>2]);
    $327 = Math_fround(HEAPF32[$250>>2]);
    $328 = Math_fround(HEAPF32[$251>>2]);
    $329 = Math_fround($301 * $326);
    $330 = Math_fround($309 * $327);
    $331 = Math_fround($329 + $330);
    $332 = Math_fround($317 * $328);
    $333 = Math_fround($331 + $332);
    $334 = $325 > $333;
    $335 = $334&1;
    HEAP32[$293>>2] = $335;
    ;HEAP32[$1+0>>2]=HEAP32[$244+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$244+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$244+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$244+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$248+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$248+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$248+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$248+12>>2]|0;
    $b$a$i$i$i$i = $334 ? $1 : $0;
    $336 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
    $$in1$i$i$i$i = (($b$a$i$i$i$i) + 4|0);
    $337 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
    $$in2$i$i$i$i = (($b$a$i$i$i$i) + 8|0);
    $338 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
    $339 = Math_fround(HEAPF32[$252>>2]);
    $340 = Math_fround(HEAPF32[$253>>2]);
    $341 = Math_fround(HEAPF32[$254>>2]);
    $342 = Math_fround($294 * $336);
    $343 = Math_fround($302 * $337);
    $344 = Math_fround($342 + $343);
    $345 = Math_fround($310 * $338);
    $346 = Math_fround($344 + $345);
    $347 = Math_fround($296 * $336);
    $348 = Math_fround($304 * $337);
    $349 = Math_fround($347 + $348);
    $350 = Math_fround($312 * $338);
    $351 = Math_fround($349 + $350);
    $352 = Math_fround($299 * $336);
    $353 = Math_fround($307 * $337);
    $354 = Math_fround($352 + $353);
    $355 = Math_fround($315 * $338);
    $356 = Math_fround($354 + $355);
    $357 = Math_fround($346 + $339);
    $358 = Math_fround($351 + $340);
    $359 = Math_fround($356 + $341);
    HEAPF32[$supportA1>>2] = $357;
    HEAPF32[$255>>2] = $358;
    HEAPF32[$256>>2] = $359;
    HEAPF32[$257>>2] = Math_fround(0.0);
    ;HEAP32[$292+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$292+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$292+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$292+12>>2]=HEAP32[$supportA1+12>>2]|0;
    $360 = (($B) + ($291<<4)|0);
    $361 = (($bInd) + ($291<<2)|0);
    $362 = Math_fround(HEAPF32[$258>>2]);
    $363 = Math_fround(HEAPF32[$259>>2]);
    $364 = Math_fround(HEAPF32[$260>>2]);
    $365 = Math_fround(HEAPF32[$8>>2]);
    $366 = Math_fround($362 - $365);
    $367 = Math_fround($363 - $365);
    $368 = Math_fround($364 - $365);
    $369 = $286 > Math_fround(0.0);
    $370 = $288 > Math_fround(0.0);
    $371 = $370 << 31 >> 31;
    $372 = $290 > Math_fround(0.0);
    $373 = $372 << 31 >> 31;
    $374 = $369&1;
    $375 = $371 << 1;
    $376 = $375 & 2;
    $377 = $373 << 2;
    $378 = $377 & 4;
    $379 = $378 | $374;
    $380 = $379 | $376;
    HEAP32[$361>>2] = $380;
    $381 = Math_fround(-$366);
    $382 = Math_fround(-$367);
    $383 = Math_fround(-$368);
    HEAPF32[$1>>2] = $366;
    HEAPF32[$261>>2] = $367;
    HEAPF32[$262>>2] = $368;
    HEAPF32[$263>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $381;
    HEAPF32[$264>>2] = $382;
    HEAPF32[$265>>2] = $383;
    HEAPF32[$266>>2] = Math_fround(0.0);
    $b$a$i$i = $369 ? $1 : $0;
    $384 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $370 ? $1 : $0;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $385 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $372 ? $1 : $0;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $386 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    HEAPF32[$supportB2>>2] = $384;
    HEAPF32[$267>>2] = $385;
    HEAPF32[$268>>2] = $386;
    HEAPF32[$269>>2] = Math_fround(0.0);
    ;HEAP32[$360+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$360+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$360+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$360+12>>2]=HEAP32[$supportB2+12>>2]|0;
    $387 = Math_fround($357 - $384);
    $388 = Math_fround($358 - $385);
    $389 = Math_fround($359 - $386);
    HEAPF32[$support3>>2] = $387;
    HEAPF32[$270>>2] = $388;
    HEAPF32[$271>>2] = $389;
    HEAPF32[$272>>2] = Math_fround(0.0);
    $390 = HEAP32[$size>>2]|0;
    $391 = (($390) + 1)|0;
    HEAP32[$size>>2] = $391;
    $392 = (($Q) + ($390<<4)|0);
    ;HEAP32[$392+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$392+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$392+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$392+12>>2]=HEAP32[$support3+12>>2]|0;
    $393 = Math_fround(HEAPF32[$273>>2]);
    $394 = Math_fround(HEAPF32[$274>>2]);
    $395 = $393 > $394;
    $$$i134 = $395 ? $393 : $394;
    $396 = $$$i749819 > $$$i134;
    $$$i = $396 ? $$$i749819 : $$$i134;
    $397 = Math_fround($17 + $$$i);
    $398 = Math_fround($397 * $397);
    $399 = Math_fround($400 * $398);
    $401 = Math_fround($286 * $387);
    $402 = Math_fround($288 * $388);
    $403 = Math_fround($401 + $402);
    $404 = Math_fround($290 * $389);
    $405 = Math_fround($403 + $404);
    $406 = Math_fround($405 * $405);
    $407 = $405 > Math_fround(0.0);
    $408 = $406 > $399;
    if ($407) {
     $phitmp765 = $408 ^ 1;
     $412 = $408;$414 = $phitmp765;
    } else {
     $412 = 0;$414 = 1;
    }
    $409 = Math_fround($400 - $405);
    $410 = Math_fround($24 * $400);
    $411 = $410 >= $409;
    $brmerge$demorgan = $411 | $412;
    if ($brmerge$demorgan) {
     $413 = $414 ^ 1;
     $$757 = $411 | $413;
     if ($$757) {
      break;
     }
    }
    do {
     if ((($390|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$284,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($390|0) == 1)) {
      $461 = Math_fround(HEAPF32[$Q>>2]);
      $462 = Math_fround(HEAPF32[$277>>2]);
      $463 = Math_fround(HEAPF32[$278>>2]);
      $464 = Math_fround($387 - $461);
      $465 = Math_fround($388 - $462);
      $466 = Math_fround($389 - $463);
      $467 = Math_fround($464 * $464);
      $468 = Math_fround($465 * $465);
      $469 = Math_fround($467 + $468);
      $470 = Math_fround($466 * $466);
      $471 = Math_fround($469 + $470);
      $472 = $471 == Math_fround(0.0);
      if ($472) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $473 = Math_fround($462 * $465);
       $474 = Math_fround(-$473);
       $475 = Math_fround($461 * $464);
       $476 = Math_fround($474 - $475);
       $477 = Math_fround($463 * $466);
       $478 = Math_fround($476 - $477);
       $479 = Math_fround(HEAPF32[$A>>2]);
       $480 = Math_fround(HEAPF32[$279>>2]);
       $481 = Math_fround(HEAPF32[$280>>2]);
       $482 = Math_fround($357 - $479);
       $483 = Math_fround($358 - $480);
       $484 = Math_fround($359 - $481);
       $485 = Math_fround(HEAPF32[$B>>2]);
       $486 = Math_fround(HEAPF32[$281>>2]);
       $487 = Math_fround(HEAPF32[$282>>2]);
       $488 = Math_fround($384 - $485);
       $489 = Math_fround($385 - $486);
       $490 = Math_fround($386 - $487);
       $491 = Math_fround($478 / $471);
       $492 = $491 > Math_fround(1.0);
       $$$i$i$i = $492 ? Math_fround(1.0) : $491;
       $493 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $493 ? $$$i$i$i : Math_fround(0.0);
       $494 = Math_fround($482 * $$$i8$i$i);
       $495 = Math_fround($483 * $$$i8$i$i);
       $496 = Math_fround($484 * $$$i8$i$i);
       $497 = Math_fround($479 + $494);
       $498 = Math_fround($480 + $495);
       $499 = Math_fround($481 + $496);
       $500 = Math_fround($488 * $$$i8$i$i);
       $501 = Math_fround($489 * $$$i8$i$i);
       $502 = Math_fround($490 * $$$i8$i$i);
       $503 = Math_fround($485 + $500);
       $504 = Math_fround($486 + $501);
       $505 = Math_fround($487 + $502);
       HEAPF32[$closA>>2] = $497;
       HEAPF32[$18>>2] = $498;
       HEAPF32[$19>>2] = $499;
       HEAPF32[$20>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $503;
       HEAPF32[$21>>2] = $504;
       HEAPF32[$22>>2] = $505;
       HEAPF32[$23>>2] = Math_fround(0.0);
       $506 = Math_fround($497 - $503);
       $507 = Math_fround($498 - $504);
       $508 = Math_fround($499 - $505);
       HEAPF32[$5>>2] = $506;
       HEAPF32[$275>>2] = $507;
       HEAPF32[$276>>2] = $508;
       HEAPF32[$283>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($390|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($390|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    $509 = Math_fround(HEAPF32[$5>>2]);
    $510 = Math_fround(HEAPF32[$275>>2]);
    $511 = Math_fround(HEAPF32[$276>>2]);
    $512 = Math_fround($509 * $509);
    $513 = Math_fround($510 * $510);
    $514 = Math_fround($512 + $513);
    $515 = Math_fround($511 * $511);
    $516 = Math_fround($514 + $515);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1238+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1238+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1238+8>>2]|0;
    $517 = $400 > $516;
    $518 = $516 > $24;
    if (!($518)) {
     label = 37;
     break;
    }
    if (!($517)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre866 = Math_fround(HEAPF32[$18>>2]);
    $$pre867 = Math_fround(HEAPF32[$19>>2]);
    $$pre868 = Math_fround(HEAPF32[$20>>2]);
    $$pre869 = Math_fround(HEAPF32[$closB>>2]);
    $$pre870 = Math_fround(HEAPF32[$21>>2]);
    $$pre871 = Math_fround(HEAPF32[$22>>2]);
    $$pre872 = Math_fround(HEAPF32[$23>>2]);
    $$$i749819 = $$$i;$286 = $509;$288 = $510;$290 = $511;$400 = $516;$533 = $$pre;$534 = $$pre866;$535 = $$pre867;$536 = $$pre868;$537 = $$pre869;$538 = $$pre870;$539 = $$pre871;$540 = $$pre872;
   }
   if ((label|0) == 37) {
    $519 = HEAP32[$size>>2]|0;
    if ($517) {
     $574 = $519;
     break;
    }
    $520 = (($519) + -1)|0;
    $521 = ($aIndices|0)==(0|0);
    if (!($521)) {
     $522 = $520&255;
     HEAP8[$_size>>0] = $522;
     $523 = ($520|0)==(0);
     if (!($523)) {
      $i$01$i29 = 0;
      while(1) {
       $524 = (($aInd) + ($i$01$i29<<2)|0);
       $525 = HEAP32[$524>>2]|0;
       $526 = $525&255;
       $527 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$527>>0] = $526;
       $528 = (($bInd) + ($i$01$i29<<2)|0);
       $529 = HEAP32[$528>>2]|0;
       $530 = $529&255;
       $531 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$531>>0] = $530;
       $532 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($532|0)==($520|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $532;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $533;
    HEAPF32[$18>>2] = $534;
    HEAPF32[$19>>2] = $535;
    HEAPF32[$20>>2] = $536;
    HEAPF32[$closB>>2] = $537;
    HEAPF32[$21>>2] = $538;
    HEAPF32[$22>>2] = $539;
    HEAPF32[$23>>2] = $540;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $541 = Math_fround($533 - $537);
    $542 = Math_fround($534 - $538);
    $543 = Math_fround($535 - $539);
    $544 = (Math_fround(Math_sqrt((Math_fround($400)))));
    $545 = Math_fround(Math_fround(1.0) / $544);
    $546 = Math_fround($541 * $545);
    $547 = Math_fround($542 * $545);
    $548 = Math_fround($543 * $545);
    $549 = Math_fround($7 * $546);
    $550 = Math_fround($7 * $547);
    $551 = Math_fround($7 * $548);
    $552 = Math_fround($533 - $549);
    $553 = Math_fround($534 - $550);
    $554 = Math_fround($535 - $551);
    HEAPF32[$contactA>>2] = $552;
    $555 = (($contactA) + 4|0);
    HEAPF32[$555>>2] = $553;
    $556 = (($contactA) + 8|0);
    HEAPF32[$556>>2] = $554;
    $557 = (($contactA) + 12|0);
    HEAPF32[$557>>2] = Math_fround(0.0);
    $558 = Math_fround($9 * $546);
    $559 = Math_fround($9 * $547);
    $560 = Math_fround($9 * $548);
    $561 = Math_fround($558 + $537);
    $562 = Math_fround($559 + $538);
    $563 = Math_fround($560 + $539);
    HEAPF32[$contactB>>2] = $561;
    $564 = (($contactB) + 4|0);
    HEAPF32[$564>>2] = $562;
    $565 = (($contactB) + 8|0);
    HEAPF32[$565>>2] = $563;
    $566 = (($contactB) + 12|0);
    HEAPF32[$566>>2] = Math_fround(0.0);
    $567 = Math_fround($544 - $17);
    HEAPF32[$penetrationDepth>>2] = $567;
    $568 = (($penetrationDepth) + 4|0);
    ;HEAP32[$568+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$568+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$568+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $546;
    $569 = (($normal) + 4|0);
    HEAPF32[$569>>2] = $547;
    $570 = (($normal) + 8|0);
    HEAPF32[$570>>2] = $548;
    $571 = (($normal) + 12|0);
    HEAPF32[$571>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $415 = ($aIndices|0)==(0|0);
   if (!($415)) {
    $416 = $390&255;
    HEAP8[$_size>>0] = $416;
    $417 = ($390|0)==(0);
    if (!($417)) {
     $i$01$i72 = 0;
     while(1) {
      $418 = (($aInd) + ($i$01$i72<<2)|0);
      $419 = HEAP32[$418>>2]|0;
      $420 = $419&255;
      $421 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$421>>0] = $420;
      $422 = (($bInd) + ($i$01$i72<<2)|0);
      $423 = HEAP32[$422>>2]|0;
      $424 = $423&255;
      $425 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$425>>0] = $424;
      $426 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($426|0)==($390|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $426;
      }
     }
    }
   }
   $not$ = $412 ^ 1;
   $$$761 = $414 & $not$;
   if (!($$$761)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $427 = (Math_fround(Math_sqrt((Math_fround($400)))));
   $428 = Math_fround(Math_fround(1.0) / $427);
   $429 = Math_fround($286 * $428);
   $430 = Math_fround($288 * $428);
   $431 = Math_fround($290 * $428);
   $432 = Math_fround(HEAPF32[$closA>>2]);
   $433 = Math_fround(HEAPF32[$18>>2]);
   $434 = Math_fround(HEAPF32[$19>>2]);
   $435 = Math_fround($7 * $429);
   $436 = Math_fround($7 * $430);
   $437 = Math_fround($7 * $431);
   $438 = Math_fround($432 - $435);
   $439 = Math_fround($433 - $436);
   $440 = Math_fround($434 - $437);
   HEAPF32[$contactA>>2] = $438;
   $441 = (($contactA) + 4|0);
   HEAPF32[$441>>2] = $439;
   $442 = (($contactA) + 8|0);
   HEAPF32[$442>>2] = $440;
   $443 = (($contactA) + 12|0);
   HEAPF32[$443>>2] = Math_fround(0.0);
   $444 = Math_fround(HEAPF32[$closB>>2]);
   $445 = Math_fround(HEAPF32[$21>>2]);
   $446 = Math_fround(HEAPF32[$22>>2]);
   $447 = Math_fround($9 * $429);
   $448 = Math_fround($9 * $430);
   $449 = Math_fround($9 * $431);
   $450 = Math_fround($447 + $444);
   $451 = Math_fround($448 + $445);
   $452 = Math_fround($449 + $446);
   HEAPF32[$contactB>>2] = $450;
   $453 = (($contactB) + 4|0);
   HEAPF32[$453>>2] = $451;
   $454 = (($contactB) + 8|0);
   HEAPF32[$454>>2] = $452;
   $455 = (($contactB) + 12|0);
   HEAPF32[$455>>2] = Math_fround(0.0);
   $456 = Math_fround($427 - $17);
   HEAPF32[$penetrationDepth>>2] = $456;
   $457 = (($penetrationDepth) + 4|0);
   ;HEAP32[$457+0>>2]=HEAP32[$$sroa$1240+0>>2]|0;HEAP32[$457+4>>2]=HEAP32[$$sroa$1240+4>>2]|0;HEAP32[$457+8>>2]=HEAP32[$$sroa$1240+8>>2]|0;
   HEAPF32[$normal>>2] = $429;
   $458 = (($normal) + 4|0);
   HEAPF32[$458>>2] = $430;
   $459 = (($normal) + 8|0);
   HEAPF32[$459>>2] = $431;
   $460 = (($normal) + 12|0);
   HEAPF32[$460>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $235 = HEAP32[$size>>2]|0;
   $574 = $235;
  }
 } while(0);
 $572 = ($aIndices|0)==(0|0);
 if (!($572)) {
  $573 = $574&255;
  HEAP8[$_size>>0] = $573;
  $575 = ($574|0)==(0);
  if (!($575)) {
   $i$01$i = 0;
   while(1) {
    $576 = (($aInd) + ($i$01$i<<2)|0);
    $577 = HEAP32[$576>>2]|0;
    $578 = $577&255;
    $579 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$579>>0] = $578;
    $580 = (($bInd) + ($i$01$i<<2)|0);
    $581 = HEAP32[$580>>2]|0;
    $582 = $581&255;
    $583 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$583>>0] = $582;
    $584 = (($i$01$i) + 1)|0;
    $exitcond$i = ($584|0)==($574|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $584;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (1 - ($indexA))|0;
 $7 = (($5) + 96|0);
 $8 = (($7) + ($6<<4)|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($7) + ($6<<4)|0) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = ((($7) + ($6<<4)|0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($3) + 48|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($3) + 52|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($3) + 56|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$3>>2]);
 $21 = Math_fround($9 * $20);
 $22 = (($3) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($11 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($3) + 32|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($13 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($3) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($9 * $31);
 $33 = (($3) + 20|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($11 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($3) + 36|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($13 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($3) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($9 * $42);
 $44 = (($3) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($11 * $45);
 $47 = Math_fround($43 + $46);
 $48 = (($3) + 40|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($13 * $49);
 $51 = Math_fround($47 + $50);
 $52 = Math_fround($15 + $29);
 $53 = Math_fround($17 + $40);
 $54 = Math_fround($19 + $51);
 $55 = (($this) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (549664 + ($indexB<<4)|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ((549664 + ($indexB<<4)|0) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((549664 + ($indexB<<4)|0) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($56) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$63+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$63+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$63+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$63+12>>2]|0;
 $64 = (($56) + 144|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($56) + 148|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($56) + 152|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround(-$65);
 $71 = Math_fround(-$67);
 $72 = Math_fround(-$69);
 HEAPF32[$0>>2] = $70;
 $73 = (($0) + 4|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($0) + 8|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($0) + 12|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = ($58|0)==(0);
 $b$a$i$i = $76 ? $0 : $1;
 $77 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $78 = ($60|0)==(0);
 $a$pn3$i$i = $78 ? $0 : $1;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $79 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $80 = ($62|0)==(0);
 $b$a5$i$i = $80 ? $0 : $1;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $81 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $52;
 $82 = (($supportA) + 4|0);
 HEAPF32[$82>>2] = $53;
 $83 = (($supportA) + 8|0);
 HEAPF32[$83>>2] = $54;
 $84 = (($supportA) + 12|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $77;
 $85 = (($supportB) + 4|0);
 HEAPF32[$85>>2] = $79;
 $86 = (($supportB) + 8|0);
 HEAPF32[$86>>2] = $81;
 $87 = (($supportB) + 12|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = Math_fround($52 - $77);
 $89 = Math_fround($53 - $79);
 $90 = Math_fround($54 - $81);
 HEAPF32[$support>>2] = $88;
 $91 = (($support) + 4|0);
 HEAPF32[$91>>2] = $89;
 $92 = (($support) + 8|0);
 HEAPF32[$92>>2] = $90;
 $93 = (($support) + 12|0);
 HEAPF32[$93>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in1$i$i$i = 0, $$in2$i$i = 0, $$in2$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0;
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0);
 var $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0;
 var $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $a$pn3$i$i = 0, $b$a$i$i = 0;
 var $b$a$i$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$6);
 $11 = Math_fround(-$8);
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $9);
 $16 = (($13) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $10);
 $19 = Math_fround($15 + $18);
 $20 = (($13) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $11);
 $23 = Math_fround($19 + $22);
 $24 = (($13) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $9);
 $27 = (($13) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $10);
 $30 = Math_fround($26 + $29);
 $31 = (($13) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $11);
 $34 = Math_fround($30 + $33);
 $35 = (($13) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * $9);
 $38 = (($13) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $10);
 $41 = Math_fround($37 + $40);
 $42 = (($13) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $11);
 $45 = Math_fround($41 + $44);
 $46 = (($3) + 96|0);
 $47 = (($3) + 96|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($3) + 100|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($3) + 104|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($23 * $48);
 $54 = Math_fround($34 * $50);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($45 * $52);
 $57 = Math_fround($55 + $56);
 $58 = (($3) + 112|0);
 $59 = (($3) + 112|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($3) + 116|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($3) + 120|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($23 * $60);
 $66 = Math_fround($34 * $62);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($45 * $64);
 $69 = Math_fround($67 + $68);
 $70 = $57 > $69;
 ;HEAP32[$1+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$46+12>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$58+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$58+12>>2]|0;
 $b$a$i$i$i = $70 ? $1 : $0;
 $71 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
 $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
 $72 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
 $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
 $73 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
 $74 = (($13) + 48|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($13) + 52|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($13) + 56|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($14 * $71);
 $81 = Math_fround($25 * $72);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($36 * $73);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($17 * $71);
 $86 = Math_fround($28 * $72);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($39 * $73);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($21 * $71);
 $91 = Math_fround($32 * $72);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($43 * $73);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($84 + $75);
 $96 = Math_fround($89 + $77);
 $97 = Math_fround($94 + $79);
 $98 = (($this) + 12|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = Math_fround(HEAPF32[$dir>>2]);
 $101 = Math_fround(HEAPF32[$5>>2]);
 $102 = Math_fround(HEAPF32[$7>>2]);
 $103 = $100 > Math_fround(0.0);
 $104 = $101 > Math_fround(0.0);
 $105 = $102 > Math_fround(0.0);
 $106 = (($99) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$106+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$106+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$106+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$106+12>>2]|0;
 $107 = (($99) + 144|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($99) + 148|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($99) + 152|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround(-$108);
 $114 = Math_fround(-$110);
 $115 = Math_fround(-$112);
 HEAPF32[$0>>2] = $113;
 $116 = (($0) + 4|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($0) + 8|0);
 HEAPF32[$117>>2] = $115;
 $118 = (($0) + 12|0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 $b$a$i$i = $103 ? $1 : $0;
 $119 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $104 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $120 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $105 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $121 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $95;
 $122 = (($supportA) + 4|0);
 HEAPF32[$122>>2] = $96;
 $123 = (($supportA) + 8|0);
 HEAPF32[$123>>2] = $97;
 $124 = (($supportA) + 12|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $119;
 $125 = (($supportB) + 4|0);
 HEAPF32[$125>>2] = $120;
 $126 = (($supportB) + 8|0);
 HEAPF32[$126>>2] = $121;
 $127 = (($supportB) + 12|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = Math_fround($95 - $119);
 $129 = Math_fround($96 - $120);
 $130 = Math_fround($97 - $121);
 HEAPF32[$support>>2] = $128;
 $131 = (($support) + 4|0);
 HEAPF32[$131>>2] = $129;
 $132 = (($support) + 8|0);
 HEAPF32[$132>>2] = $130;
 $133 = (($support) + 12|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_8CapsuleVES2_EEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS8_6FloatVERKNS8_5Vec3VESH_RSC_RSF_SJ_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i$i = 0, $$in1$i$i$i$i187 = 0, $$in1$i$i$i141 = 0, $$in1$i$i$i183 = 0, $$in1$i202 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i$i = 0, $$in2$i$i$i$i188 = 0, $$in2$i$i$i142 = 0, $$in2$i$i$i184 = 0, $$in2$i204 = 0;
 var $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa916 = Math_fround(0), $$lcssa918 = Math_fround(0), $$lcssa920 = Math_fround(0), $$lcssa922 = Math_fround(0), $$lcssa924 = Math_fround(0), $$lcssa926 = Math_fround(0), $$lcssa928 = Math_fround(0), $$lcssa930 = Math_fround(0), $$lcssa932 = 0, $$lcssa934 = Math_fround(0), $$lcssa936 = Math_fround(0), $$lcssa938 = Math_fround(0), $$pre = Math_fround(0), $$pre972 = Math_fround(0), $$pre973 = Math_fround(0), $$pre974 = Math_fround(0), $$sroa$1328 = 0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0;
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0;
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0;
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0);
 var $440 = 0, $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0);
 var $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0);
 var $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = 0, $506 = Math_fround(0), $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0);
 var $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = Math_fround(0), $548 = Math_fround(0);
 var $549 = Math_fround(0), $55 = Math_fround(0), $550 = 0, $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = Math_fround(0), $563 = 0, $564 = Math_fround(0), $565 = 0, $566 = Math_fround(0);
 var $567 = 0, $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0);
 var $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $b$a$i = 0, $b$a$i$i$i = 0, $b$a$i$i$i$i = 0, $b$a$i$i$i$i185 = 0, $b$a$i$i$i139 = 0, $b$a$i$i$i181 = 0, $b$a$i18 = 0, $b$a$i199 = 0, $b$a5$i = 0, $closA = 0;
 var $closB = 0, $phitmp = 0, $phitmp909 = 0, $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $0 = sp + 32|0;
 $1 = sp + 336|0;
 $2 = sp + 400|0;
 $3 = sp + 416|0;
 $4 = sp + 384|0;
 $5 = sp + 368|0;
 $6 = sp + 352|0;
 $7 = sp + 320|0;
 $8 = sp + 16|0;
 $9 = sp;
 $zeroV = sp + 112|0;
 $zero$sroa$1 = sp + 432|0;
 $_lambda$sroa$1 = sp + 460|0;
 $size = sp + 456|0;
 $Q = sp + 48|0;
 $A = sp + 128|0;
 $B = sp + 192|0;
 $support = sp + 256|0;
 $closA = sp + 272|0;
 $closB = sp + 288|0;
 $$sroa$1328 = sp + 444|0;
 $tempV = sp + 304|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $10 = Math_fround(HEAPF32[$r>>2]);
 $11 = (($r) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($r) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$s>>2]);
 $16 = (($s) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($s) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAP32[$size>>2] = 1;
 $20 = (($aToB) + 48|0);
 $21 = (($aToB) + 48|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($aToB) + 52|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 56|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($22 * $22);
 $28 = Math_fround($24 * $24);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = $31 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$20+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $33 = (($0) + 4|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($0) + 8|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($0) + 12|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $b$a$i199 = $32 ? $1 : $0;
 $36 = Math_fround(HEAPF32[$b$a$i199>>2]);
 $$in1$i202 = (($b$a$i199) + 4|0);
 $37 = Math_fround(HEAPF32[$$in1$i202>>2]);
 $$in2$i204 = (($b$a$i199) + 8|0);
 $38 = Math_fround(HEAPF32[$$in2$i204>>2]);
 $39 = Math_fround($36 * $36);
 $40 = Math_fround($37 * $37);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($38 * $38);
 $43 = Math_fround($41 + $42);
 $44 = (Math_fround(Math_sqrt((Math_fround($43)))));
 $45 = Math_fround(Math_fround(1.0) / $44);
 $46 = Math_fround($36 * $45);
 $47 = Math_fround($37 * $45);
 $48 = Math_fround($38 * $45);
 $49 = Math_fround(-$46);
 $50 = Math_fround(-$47);
 $51 = Math_fround(-$48);
 $52 = Math_fround(HEAPF32[$aToB>>2]);
 $53 = Math_fround($52 * $49);
 $54 = (($aToB) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * $50);
 $57 = Math_fround($53 + $56);
 $58 = (($aToB) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 * $51);
 $61 = Math_fround($57 + $60);
 $62 = (($aToB) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $49);
 $65 = (($aToB) + 20|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $50);
 $68 = Math_fround($64 + $67);
 $69 = (($aToB) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $51);
 $72 = Math_fround($68 + $71);
 $73 = (($aToB) + 32|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($74 * $49);
 $76 = (($aToB) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 * $50);
 $79 = Math_fround($75 + $78);
 $80 = (($aToB) + 40|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 * $51);
 $83 = Math_fround($79 + $82);
 $84 = (($a) + 96|0);
 $85 = (($a) + 96|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($a) + 100|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($a) + 104|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($61 * $86);
 $92 = Math_fround($72 * $88);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($83 * $90);
 $95 = Math_fround($93 + $94);
 $96 = (($a) + 112|0);
 $97 = (($a) + 112|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($a) + 116|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($a) + 120|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($61 * $98);
 $104 = Math_fround($72 * $100);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($83 * $102);
 $107 = Math_fround($105 + $106);
 $108 = $95 > $107;
 ;HEAP32[$3+0>>2]=HEAP32[$84+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$84+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$84+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$84+12>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$96+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$96+12>>2]|0;
 $b$a$i$i$i$i185 = $108 ? $3 : $2;
 $109 = Math_fround(HEAPF32[$b$a$i$i$i$i185>>2]);
 $$in1$i$i$i$i187 = (($b$a$i$i$i$i185) + 4|0);
 $110 = Math_fround(HEAPF32[$$in1$i$i$i$i187>>2]);
 $$in2$i$i$i$i188 = (($b$a$i$i$i$i185) + 8|0);
 $111 = Math_fround(HEAPF32[$$in2$i$i$i$i188>>2]);
 $112 = Math_fround(HEAPF32[$21>>2]);
 $113 = Math_fround(HEAPF32[$23>>2]);
 $114 = Math_fround(HEAPF32[$25>>2]);
 $115 = Math_fround($52 * $109);
 $116 = Math_fround($63 * $110);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($74 * $111);
 $119 = Math_fround($117 + $118);
 $120 = Math_fround($55 * $109);
 $121 = Math_fround($66 * $110);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($77 * $111);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($59 * $109);
 $126 = Math_fround($70 * $110);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround($81 * $111);
 $129 = Math_fround($127 + $128);
 $130 = Math_fround($119 + $112);
 $131 = Math_fround($124 + $113);
 $132 = Math_fround($129 + $114);
 $133 = (($b) + 96|0);
 $134 = (($b) + 96|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($b) + 100|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($b) + 104|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($46 * $135);
 $141 = Math_fround($47 * $137);
 $142 = Math_fround($140 + $141);
 $143 = Math_fround($48 * $139);
 $144 = Math_fround($142 + $143);
 $145 = (($b) + 112|0);
 $146 = (($b) + 112|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = (($b) + 116|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($b) + 120|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = Math_fround($46 * $147);
 $153 = Math_fround($47 * $149);
 $154 = Math_fround($152 + $153);
 $155 = Math_fround($48 * $151);
 $156 = Math_fround($154 + $155);
 $157 = $144 > $156;
 ;HEAP32[$3+0>>2]=HEAP32[$133+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$133+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$133+12>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$145+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$145+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$145+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$145+12>>2]|0;
 $b$a$i$i$i181 = $157 ? $3 : $2;
 $158 = Math_fround(HEAPF32[$b$a$i$i$i181>>2]);
 $$in1$i$i$i183 = (($b$a$i$i$i181) + 4|0);
 $159 = Math_fround(HEAPF32[$$in1$i$i$i183>>2]);
 $$in2$i$i$i184 = (($b$a$i$i$i181) + 8|0);
 $160 = Math_fround(HEAPF32[$$in2$i$i$i184>>2]);
 $161 = Math_fround($130 - $158);
 $162 = Math_fround($131 - $159);
 $163 = Math_fround($132 - $160);
 HEAPF32[$Q>>2] = $161;
 $164 = (($Q) + 4|0);
 HEAPF32[$164>>2] = $162;
 $165 = (($Q) + 8|0);
 HEAPF32[$165>>2] = $163;
 $166 = (($Q) + 12|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = (($Q) + 16|0);
 ;HEAP32[$167+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$167+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $168 = (($Q) + 32|0);
 ;HEAP32[$168+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$168+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$168+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$168+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $169 = (($Q) + 48|0);
 ;HEAP32[$169+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$169+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$169+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$169+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $130;
 $170 = (($A) + 4|0);
 HEAPF32[$170>>2] = $131;
 $171 = (($A) + 8|0);
 HEAPF32[$171>>2] = $132;
 $172 = (($A) + 12|0);
 HEAPF32[$172>>2] = Math_fround(0.0);
 $173 = (($A) + 16|0);
 ;HEAP32[$173+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$173+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$173+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$173+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $174 = (($A) + 32|0);
 ;HEAP32[$174+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$174+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$174+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$174+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $175 = (($A) + 48|0);
 ;HEAP32[$175+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$175+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$175+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$175+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$B>>2] = $158;
 $176 = (($B) + 4|0);
 HEAPF32[$176>>2] = $159;
 $177 = (($B) + 8|0);
 HEAPF32[$177>>2] = $160;
 $178 = (($B) + 12|0);
 HEAPF32[$178>>2] = Math_fround(0.0);
 $179 = (($B) + 16|0);
 ;HEAP32[$179+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$179+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$179+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$179+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $180 = (($B) + 32|0);
 ;HEAP32[$180+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$180+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$180+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$180+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $181 = (($B) + 48|0);
 ;HEAP32[$181+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$181+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$181+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $182 = Math_fround(-$161);
 $183 = Math_fround(-$162);
 $184 = Math_fround(-$163);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $185 = (($a) + 32|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($b) + 32|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = $186 > $188;
 $$$i = $189 ? $188 : $186;
 $190 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $191 = Math_fround($190 * $190);
 $192 = Math_fround($_inflation * $_inflation);
 $193 = Math_fround($192 + $191);
 HEAPF32[$closA>>2] = $130;
 $194 = (($closA) + 4|0);
 HEAPF32[$194>>2] = $131;
 $195 = (($closA) + 8|0);
 HEAPF32[$195>>2] = $132;
 $196 = (($closA) + 12|0);
 HEAPF32[$196>>2] = Math_fround(0.0);
 HEAPF32[$closB>>2] = $158;
 $197 = (($closB) + 4|0);
 HEAPF32[$197>>2] = $159;
 $198 = (($closB) + 8|0);
 HEAPF32[$198>>2] = $160;
 $199 = (($closB) + 12|0);
 HEAPF32[$199>>2] = Math_fround(0.0);
 $200 = Math_fround($161 * $161);
 $201 = Math_fround($162 * $162);
 $202 = Math_fround($200 + $201);
 $203 = Math_fround($163 * $163);
 $204 = Math_fround($202 + $203);
 $205 = $204 > $191;
 L1: do {
  if ($205) {
   $206 = Math_fround($14 * Math_fround(0.0));
   $207 = Math_fround($12 * Math_fround(0.0));
   $208 = Math_fround($10 * Math_fround(0.0));
   $209 = Math_fround($206 + $19);
   $210 = Math_fround($207 + $17);
   $211 = Math_fround($208 + $15);
   $212 = (($support) + 4|0);
   $213 = (($support) + 8|0);
   $214 = (($support) + 12|0);
   $215 = (($B) + 16|0);
   $216 = (($B) + 20|0);
   $217 = (($B) + 24|0);
   $218 = (($B) + 28|0);
   $219 = (($B) + 32|0);
   $220 = (($B) + 36|0);
   $221 = (($B) + 40|0);
   $222 = (($B) + 44|0);
   $223 = (($A) + 16|0);
   $224 = (($A) + 20|0);
   $225 = (($A) + 24|0);
   $226 = (($Q) + 16|0);
   $227 = (($Q) + 20|0);
   $228 = (($Q) + 24|0);
   $229 = (($Q) + 28|0);
   $230 = (($A) + 32|0);
   $231 = (($A) + 36|0);
   $232 = (($A) + 40|0);
   $233 = (($Q) + 32|0);
   $234 = (($Q) + 36|0);
   $235 = (($Q) + 40|0);
   $236 = (($Q) + 44|0);
   $237 = (($tempV) + 4|0);
   $238 = (($tempV) + 8|0);
   $239 = (($tempV) + 12|0);
   $241 = $182;$243 = $183;$246 = $184;$342 = $211;$344 = $210;$346 = $209;$369 = Math_fround(0.0);$570 = Math_fround(0.0);$571 = $132;$572 = $131;$573 = $130;$574 = $182;$575 = $183;$576 = $184;$577 = $204;
   while(1) {
    $240 = Math_fround($241 * $241);
    $242 = Math_fround($243 * $243);
    $244 = Math_fround($242 + $240);
    $245 = Math_fround($246 * $246);
    $247 = Math_fround($245 + $244);
    $248 = (Math_fround(Math_sqrt((Math_fround($247)))));
    $249 = Math_fround(Math_fround(1.0) / $248);
    $250 = Math_fround($241 * $249);
    $251 = Math_fround($243 * $249);
    $252 = Math_fround($246 * $249);
    $253 = Math_fround(-$250);
    $254 = Math_fround(-$251);
    $255 = Math_fround(-$252);
    $256 = Math_fround(HEAPF32[$aToB>>2]);
    $257 = Math_fround($250 * $256);
    $258 = Math_fround(HEAPF32[$54>>2]);
    $259 = Math_fround($251 * $258);
    $260 = Math_fround($257 + $259);
    $261 = Math_fround(HEAPF32[$58>>2]);
    $262 = Math_fround($252 * $261);
    $263 = Math_fround($260 + $262);
    $264 = Math_fround(HEAPF32[$62>>2]);
    $265 = Math_fround($250 * $264);
    $266 = Math_fround(HEAPF32[$65>>2]);
    $267 = Math_fround($251 * $266);
    $268 = Math_fround($265 + $267);
    $269 = Math_fround(HEAPF32[$69>>2]);
    $270 = Math_fround($252 * $269);
    $271 = Math_fround($268 + $270);
    $272 = Math_fround(HEAPF32[$73>>2]);
    $273 = Math_fround($250 * $272);
    $274 = Math_fround(HEAPF32[$76>>2]);
    $275 = Math_fround($251 * $274);
    $276 = Math_fround($273 + $275);
    $277 = Math_fround(HEAPF32[$80>>2]);
    $278 = Math_fround($252 * $277);
    $279 = Math_fround($276 + $278);
    $280 = Math_fround(HEAPF32[$85>>2]);
    $281 = Math_fround(HEAPF32[$87>>2]);
    $282 = Math_fround(HEAPF32[$89>>2]);
    $283 = Math_fround($263 * $280);
    $284 = Math_fround($271 * $281);
    $285 = Math_fround($283 + $284);
    $286 = Math_fround($279 * $282);
    $287 = Math_fround($285 + $286);
    $288 = Math_fround(HEAPF32[$97>>2]);
    $289 = Math_fround(HEAPF32[$99>>2]);
    $290 = Math_fround(HEAPF32[$101>>2]);
    $291 = Math_fround($263 * $288);
    $292 = Math_fround($271 * $289);
    $293 = Math_fround($291 + $292);
    $294 = Math_fround($279 * $290);
    $295 = Math_fround($293 + $294);
    $296 = $287 > $295;
    ;HEAP32[$3+0>>2]=HEAP32[$84+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$84+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$84+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$84+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$96+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$96+12>>2]|0;
    $b$a$i$i$i$i = $296 ? $3 : $2;
    $297 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
    $$in1$i$i$i$i = (($b$a$i$i$i$i) + 4|0);
    $298 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
    $$in2$i$i$i$i = (($b$a$i$i$i$i) + 8|0);
    $299 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
    $300 = Math_fround(HEAPF32[$21>>2]);
    $301 = Math_fround(HEAPF32[$23>>2]);
    $302 = Math_fround(HEAPF32[$25>>2]);
    $303 = Math_fround($256 * $297);
    $304 = Math_fround($264 * $298);
    $305 = Math_fround($303 + $304);
    $306 = Math_fround($272 * $299);
    $307 = Math_fround($305 + $306);
    $308 = Math_fround($258 * $297);
    $309 = Math_fround($266 * $298);
    $310 = Math_fround($308 + $309);
    $311 = Math_fround($274 * $299);
    $312 = Math_fround($310 + $311);
    $313 = Math_fround($261 * $297);
    $314 = Math_fround($269 * $298);
    $315 = Math_fround($313 + $314);
    $316 = Math_fround($277 * $299);
    $317 = Math_fround($315 + $316);
    $318 = Math_fround($307 + $300);
    $319 = Math_fround($312 + $301);
    $320 = Math_fround($317 + $302);
    $321 = Math_fround(HEAPF32[$134>>2]);
    $322 = Math_fround(HEAPF32[$136>>2]);
    $323 = Math_fround(HEAPF32[$138>>2]);
    $324 = Math_fround($321 * $253);
    $325 = Math_fround($322 * $254);
    $326 = Math_fround($324 + $325);
    $327 = Math_fround($323 * $255);
    $328 = Math_fround($326 + $327);
    $329 = Math_fround(HEAPF32[$146>>2]);
    $330 = Math_fround(HEAPF32[$148>>2]);
    $331 = Math_fround(HEAPF32[$150>>2]);
    $332 = Math_fround($329 * $253);
    $333 = Math_fround($330 * $254);
    $334 = Math_fround($332 + $333);
    $335 = Math_fround($331 * $255);
    $336 = Math_fround($334 + $335);
    $337 = $328 > $336;
    ;HEAP32[$3+0>>2]=HEAP32[$133+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$133+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$133+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$145+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$145+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$145+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$145+12>>2]|0;
    $b$a$i$i$i139 = $337 ? $3 : $2;
    $338 = Math_fround(HEAPF32[$b$a$i$i$i139>>2]);
    $$in1$i$i$i141 = (($b$a$i$i$i139) + 4|0);
    $339 = Math_fround(HEAPF32[$$in1$i$i$i141>>2]);
    $$in2$i$i$i142 = (($b$a$i$i$i139) + 8|0);
    $340 = Math_fround(HEAPF32[$$in2$i$i$i142>>2]);
    $341 = Math_fround($342 + $338);
    $343 = Math_fround($344 + $339);
    $345 = Math_fround($346 + $340);
    $347 = Math_fround($318 - $341);
    $348 = Math_fround($319 - $343);
    $349 = Math_fround($320 - $345);
    HEAPF32[$support>>2] = $347;
    HEAPF32[$212>>2] = $348;
    HEAPF32[$213>>2] = $349;
    HEAPF32[$214>>2] = Math_fround(0.0);
    $350 = Math_fround($250 * $347);
    $351 = Math_fround($251 * $348);
    $352 = Math_fround(-$351);
    $353 = Math_fround($352 - $350);
    $354 = Math_fround($252 * $349);
    $355 = Math_fround($353 - $354);
    $356 = Math_fround($355 - $_inflation);
    $357 = Math_fround(HEAPF32[$r>>2]);
    $358 = Math_fround(HEAPF32[$11>>2]);
    $359 = Math_fround(HEAPF32[$13>>2]);
    $360 = Math_fround($250 * $357);
    $361 = Math_fround($251 * $358);
    $362 = Math_fround($360 + $361);
    $363 = Math_fround($252 * $359);
    $364 = Math_fround($362 + $363);
    $365 = $356 > Math_fround(0.0);
    if ($365) {
     $366 = !($364 >= Math_fround(0.0));
     if (!($366)) {
      $$0 = 0;
      label = 22;
      break;
     }
     $367 = Math_fround($356 / $364);
     $368 = Math_fround($369 - $367);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1328+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1328+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1328+8>>2]|0;
     $370 = $368 > $369;
     if ($370) {
      $371 = $368 > Math_fround(1.0);
      if ($371) {
       $$0 = 0;
       label = 22;
       break;
      }
      $372 = Math_fround(HEAPF32[$s>>2]);
      $373 = Math_fround(HEAPF32[$16>>2]);
      $374 = Math_fround(HEAPF32[$18>>2]);
      $375 = Math_fround($368 * $357);
      $376 = Math_fround($368 * $358);
      $377 = Math_fround($368 * $359);
      $378 = Math_fround($375 + $372);
      $379 = Math_fround($376 + $373);
      $380 = Math_fround($377 + $374);
      $381 = Math_fround($378 - $342);
      $382 = Math_fround($379 - $344);
      $383 = Math_fround($380 - $346);
      $384 = Math_fround(HEAPF32[$B>>2]);
      $385 = Math_fround(HEAPF32[$176>>2]);
      $386 = Math_fround(HEAPF32[$177>>2]);
      $387 = Math_fround($381 + $384);
      $388 = Math_fround($382 + $385);
      $389 = Math_fround($383 + $386);
      $390 = Math_fround(HEAPF32[$215>>2]);
      $391 = Math_fround(HEAPF32[$216>>2]);
      $392 = Math_fround(HEAPF32[$217>>2]);
      $393 = Math_fround($381 + $390);
      $394 = Math_fround($382 + $391);
      $395 = Math_fround($383 + $392);
      $396 = Math_fround(HEAPF32[$219>>2]);
      $397 = Math_fround(HEAPF32[$220>>2]);
      $398 = Math_fround(HEAPF32[$221>>2]);
      $399 = Math_fround($381 + $396);
      $400 = Math_fround($382 + $397);
      $401 = Math_fround($383 + $398);
      HEAPF32[$B>>2] = $387;
      HEAPF32[$176>>2] = $388;
      HEAPF32[$177>>2] = $389;
      HEAPF32[$178>>2] = Math_fround(0.0);
      HEAPF32[$215>>2] = $393;
      HEAPF32[$216>>2] = $394;
      HEAPF32[$217>>2] = $395;
      HEAPF32[$218>>2] = Math_fround(0.0);
      HEAPF32[$219>>2] = $399;
      HEAPF32[$220>>2] = $400;
      HEAPF32[$221>>2] = $401;
      HEAPF32[$222>>2] = Math_fround(0.0);
      $402 = Math_fround(HEAPF32[$A>>2]);
      $403 = Math_fround(HEAPF32[$170>>2]);
      $404 = Math_fround(HEAPF32[$171>>2]);
      $405 = Math_fround($402 - $387);
      $406 = Math_fround($403 - $388);
      $407 = Math_fround($404 - $389);
      HEAPF32[$Q>>2] = $405;
      HEAPF32[$164>>2] = $406;
      HEAPF32[$165>>2] = $407;
      HEAPF32[$166>>2] = Math_fround(0.0);
      $408 = Math_fround(HEAPF32[$223>>2]);
      $409 = Math_fround(HEAPF32[$224>>2]);
      $410 = Math_fround(HEAPF32[$225>>2]);
      $411 = Math_fround($408 - $393);
      $412 = Math_fround($409 - $394);
      $413 = Math_fround($410 - $395);
      HEAPF32[$226>>2] = $411;
      HEAPF32[$227>>2] = $412;
      HEAPF32[$228>>2] = $413;
      HEAPF32[$229>>2] = Math_fround(0.0);
      $414 = Math_fround(HEAPF32[$230>>2]);
      $415 = Math_fround(HEAPF32[$231>>2]);
      $416 = Math_fround(HEAPF32[$232>>2]);
      $417 = Math_fround($414 - $399);
      $418 = Math_fround($415 - $400);
      $419 = Math_fround($416 - $401);
      HEAPF32[$233>>2] = $417;
      HEAPF32[$234>>2] = $418;
      HEAPF32[$235>>2] = $419;
      HEAPF32[$236>>2] = Math_fround(0.0);
      ;HEAP32[$3+0>>2]=HEAP32[$133+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$133+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$133+12>>2]|0;
      ;HEAP32[$2+0>>2]=HEAP32[$145+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$145+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$145+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$145+12>>2]|0;
      $b$a$i$i$i = $337 ? $3 : $2;
      $420 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
      $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
      $421 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
      $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
      $422 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
      $423 = Math_fround($378 + $420);
      $424 = Math_fround($379 + $421);
      $425 = Math_fround($380 + $422);
      $426 = Math_fround($318 - $423);
      $427 = Math_fround($319 - $424);
      $428 = Math_fround($320 - $425);
      HEAPF32[$support>>2] = $426;
      HEAPF32[$212>>2] = $427;
      HEAPF32[$213>>2] = $428;
      HEAPF32[$214>>2] = Math_fround(0.0);
      $435 = $423;$437 = $424;$439 = $425;$447 = $426;$449 = $427;$451 = $428;$506 = Math_fround(3.40282346638528859812E+38);$578 = $368;$579 = $380;$580 = $379;$581 = $378;$582 = $246;$583 = $243;$584 = $241;
     } else {
      $435 = $341;$437 = $343;$439 = $345;$447 = $347;$449 = $348;$451 = $349;$506 = $577;$578 = $368;$579 = $346;$580 = $344;$581 = $342;$582 = $576;$583 = $575;$584 = $574;
     }
    } else {
     $435 = $341;$437 = $343;$439 = $345;$447 = $347;$449 = $348;$451 = $349;$506 = $577;$578 = $369;$579 = $346;$580 = $344;$581 = $342;$582 = $576;$583 = $575;$584 = $574;
    }
    $429 = HEAP32[$size>>2]|0;
    $430 = (($A) + ($429<<4)|0);
    HEAPF32[$430>>2] = $318;
    $431 = ((($A) + ($429<<4)|0) + 4|0);
    HEAPF32[$431>>2] = $319;
    $432 = ((($A) + ($429<<4)|0) + 8|0);
    HEAPF32[$432>>2] = $320;
    $433 = ((($A) + ($429<<4)|0) + 12|0);
    HEAPF32[$433>>2] = Math_fround(0.0);
    $434 = (($B) + ($429<<4)|0);
    HEAPF32[$434>>2] = $435;
    $436 = ((($B) + ($429<<4)|0) + 4|0);
    HEAPF32[$436>>2] = $437;
    $438 = ((($B) + ($429<<4)|0) + 8|0);
    HEAPF32[$438>>2] = $439;
    $440 = ((($B) + ($429<<4)|0) + 12|0);
    HEAPF32[$440>>2] = Math_fround(0.0);
    $441 = (($429) + 1)|0;
    HEAP32[$size>>2] = $441;
    $442 = (($Q) + ($429<<4)|0);
    ;HEAP32[$442+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$442+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$442+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$442+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($429|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($429|0) == 1)) {
      $443 = Math_fround(HEAPF32[$Q>>2]);
      $444 = Math_fround(HEAPF32[$164>>2]);
      $445 = Math_fround(HEAPF32[$165>>2]);
      $446 = Math_fround($447 - $443);
      $448 = Math_fround($449 - $444);
      $450 = Math_fround($451 - $445);
      $452 = Math_fround($446 * $446);
      $453 = Math_fround($448 * $448);
      $454 = Math_fround($452 + $453);
      $455 = Math_fround($450 * $450);
      $456 = Math_fround($454 + $455);
      $457 = $456 == Math_fround(0.0);
      if ($457) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $458 = Math_fround($444 * $448);
       $459 = Math_fround(-$458);
       $460 = Math_fround($443 * $446);
       $461 = Math_fround($459 - $460);
       $462 = Math_fround($445 * $450);
       $463 = Math_fround($461 - $462);
       $464 = Math_fround(HEAPF32[$A>>2]);
       $465 = Math_fround(HEAPF32[$170>>2]);
       $466 = Math_fround(HEAPF32[$171>>2]);
       $467 = Math_fround($318 - $464);
       $468 = Math_fround($319 - $465);
       $469 = Math_fround($320 - $466);
       $470 = Math_fround(HEAPF32[$B>>2]);
       $471 = Math_fround(HEAPF32[$176>>2]);
       $472 = Math_fround(HEAPF32[$177>>2]);
       $473 = Math_fround($435 - $470);
       $474 = Math_fround($437 - $471);
       $475 = Math_fround($439 - $472);
       $476 = Math_fround($463 / $456);
       $477 = $476 > Math_fround(1.0);
       $$$i$i$i = $477 ? Math_fround(1.0) : $476;
       $478 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $478 ? $$$i$i$i : Math_fround(0.0);
       $479 = Math_fround($467 * $$$i8$i$i);
       $480 = Math_fround($468 * $$$i8$i$i);
       $481 = Math_fround($469 * $$$i8$i$i);
       $482 = Math_fround($464 + $479);
       $483 = Math_fround($465 + $480);
       $484 = Math_fround($466 + $481);
       $485 = Math_fround($473 * $$$i8$i$i);
       $486 = Math_fround($474 * $$$i8$i$i);
       $487 = Math_fround($475 * $$$i8$i$i);
       $488 = Math_fround($470 + $485);
       $489 = Math_fround($471 + $486);
       $490 = Math_fround($472 + $487);
       HEAPF32[$closA>>2] = $482;
       HEAPF32[$194>>2] = $483;
       HEAPF32[$195>>2] = $484;
       HEAPF32[$196>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $488;
       HEAPF32[$197>>2] = $489;
       HEAPF32[$198>>2] = $490;
       HEAPF32[$199>>2] = Math_fround(0.0);
       $491 = Math_fround($482 - $488);
       $492 = Math_fround($483 - $489);
       $493 = Math_fround($484 - $490);
       HEAPF32[$tempV>>2] = $491;
       HEAPF32[$237>>2] = $492;
       HEAPF32[$238>>2] = $493;
       HEAPF32[$239>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($429|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$167,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($429|0) == 0)) {
      HEAPF32[$closA>>2] = $318;
      HEAPF32[$194>>2] = $319;
      HEAPF32[$195>>2] = $320;
      HEAPF32[$196>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $435;
      HEAPF32[$197>>2] = $437;
      HEAPF32[$198>>2] = $439;
      HEAPF32[$199>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $494 = Math_fround(HEAPF32[$tempV>>2]);
    $495 = Math_fround(HEAPF32[$237>>2]);
    $496 = Math_fround(HEAPF32[$238>>2]);
    $497 = Math_fround(-$494);
    $498 = Math_fround(-$495);
    $499 = Math_fround(-$496);
    $500 = Math_fround($494 * $494);
    $501 = Math_fround($495 * $495);
    $502 = Math_fround($500 + $501);
    $503 = Math_fround($496 * $496);
    $504 = Math_fround($502 + $503);
    $505 = $506 > $504;
    $507 = $505 << 31 >> 31;
    $508 = $504 > $193;
    if (!($508)) {
     $$lcssa = $578;$$lcssa916 = $570;$$lcssa918 = $571;$$lcssa920 = $572;$$lcssa922 = $573;$$lcssa924 = $499;$$lcssa926 = $498;$$lcssa928 = $497;$$lcssa930 = $504;$$lcssa932 = $507;$$lcssa934 = $582;$$lcssa936 = $583;$$lcssa938 = $584;
     break L1;
    }
    if (!($505)) {
     $$lcssa = $578;$$lcssa916 = $570;$$lcssa918 = $571;$$lcssa920 = $572;$$lcssa922 = $573;$$lcssa924 = $499;$$lcssa926 = $498;$$lcssa928 = $497;$$lcssa930 = $504;$$lcssa932 = $507;$$lcssa934 = $582;$$lcssa936 = $583;$$lcssa938 = $584;
     break L1;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre972 = Math_fround(HEAPF32[$194>>2]);
    $$pre973 = Math_fround(HEAPF32[$195>>2]);
    $$pre974 = Math_fround(HEAPF32[$196>>2]);
    $241 = $497;$243 = $498;$246 = $499;$342 = $581;$344 = $580;$346 = $579;$369 = $578;$570 = $$pre974;$571 = $$pre973;$572 = $$pre972;$573 = $$pre;$574 = $584;$575 = $583;$576 = $582;$577 = $504;
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa916 = Math_fround(0.0);$$lcssa918 = $132;$$lcssa920 = $131;$$lcssa922 = $130;$$lcssa924 = $184;$$lcssa926 = $183;$$lcssa928 = $182;$$lcssa930 = $204;$$lcssa932 = -1;$$lcssa934 = $184;$$lcssa936 = $183;$$lcssa938 = $182;
  }
 } while(0);
 $509 = (($a) + 64|0);
 $510 = HEAP32[$509>>2]|0;
 $511 = (($a) + 68|0);
 $512 = HEAP32[$511>>2]|0;
 $513 = (($a) + 72|0);
 $514 = HEAP32[$513>>2]|0;
 $515 = $$lcssa930 > $191;
 if ($515) {
  $phitmp = ($$lcssa932|0)==(0);
  $phitmp909 = $phitmp ? $4 : $5;
  $523 = $phitmp909;
 } else {
  $523 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa928;
 $516 = (($5) + 4|0);
 HEAPF32[$516>>2] = $$lcssa926;
 $517 = (($5) + 8|0);
 HEAPF32[$517>>2] = $$lcssa924;
 $518 = (($5) + 12|0);
 HEAPF32[$518>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa938;
 $519 = (($4) + 4|0);
 HEAPF32[$519>>2] = $$lcssa936;
 $520 = (($4) + 8|0);
 HEAPF32[$520>>2] = $$lcssa934;
 $521 = (($4) + 12|0);
 HEAPF32[$521>>2] = Math_fround(0.0);
 $522 = Math_fround(HEAPF32[$523>>2]);
 $$in1$i37 = (($523) + 4|0);
 $524 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($523) + 8|0);
 $525 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $526 = Math_fround($522 * $522);
 $527 = Math_fround($524 * $524);
 $528 = Math_fround($526 + $527);
 $529 = Math_fround($525 * $525);
 $530 = Math_fround($528 + $529);
 $531 = (Math_fround(Math_sqrt((Math_fround($530)))));
 $532 = Math_fround(Math_fround(1.0) / $531);
 $533 = Math_fround($522 * $532);
 $534 = Math_fround($524 * $532);
 $535 = Math_fround($525 * $532);
 $536 = Math_fround(-$533);
 $537 = Math_fround(-$534);
 $538 = Math_fround(-$535);
 HEAPF32[$normal>>2] = $536;
 $539 = (($normal) + 4|0);
 HEAPF32[$539>>2] = $537;
 $540 = (($normal) + 8|0);
 HEAPF32[$540>>2] = $538;
 $541 = (($normal) + 12|0);
 HEAPF32[$541>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $542 = (($lambda) + 4|0);
 ;HEAP32[$542+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$542+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$542+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$6>>2] = $$lcssa922;
 $543 = (($6) + 4|0);
 HEAPF32[$543>>2] = $$lcssa920;
 $544 = (($6) + 8|0);
 HEAPF32[$544>>2] = $$lcssa918;
 $545 = (($6) + 12|0);
 HEAPF32[$545>>2] = $$lcssa916;
 $546 = ($$lcssa932|0)==(0);
 $b$a$i18 = $546 ? $6 : $7;
 $547 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $548 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $549 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $547;
 HEAPF32[$194>>2] = $548;
 HEAPF32[$195>>2] = $549;
 HEAPF32[$196>>2] = Math_fround(0.0);
 $550 = (($a) + 16|0);
 $551 = Math_fround(HEAPF32[$550>>2]);
 $552 = Math_fround($551 * $536);
 $553 = Math_fround($551 * $537);
 $554 = Math_fround($551 * $538);
 $555 = Math_fround($547 - $552);
 $556 = Math_fround($548 - $553);
 $557 = Math_fround($549 - $554);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $555;
 $558 = (($9) + 4|0);
 HEAPF32[$558>>2] = $556;
 $559 = (($9) + 8|0);
 HEAPF32[$559>>2] = $557;
 $560 = (($9) + 12|0);
 HEAPF32[$560>>2] = Math_fround(0.0);
 $561 = ($510|0)==(0);
 $b$a$i = $561 ? $8 : $9;
 $562 = Math_fround(HEAPF32[$b$a$i>>2]);
 $563 = ($512|0)==(0);
 $a$pn3$i = $563 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $564 = Math_fround(HEAPF32[$$in1$i>>2]);
 $565 = ($514|0)==(0);
 $b$a5$i = $565 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $566 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $562;
 $567 = (($closestA) + 4|0);
 HEAPF32[$567>>2] = $564;
 $568 = (($closestA) + 8|0);
 HEAPF32[$568>>2] = $566;
 $569 = (($closestA) + 12|0);
 HEAPF32[$569>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_ED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_ED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_E18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES7_S7_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (1 - ($indexA))|0;
 $5 = (($3) + 96|0);
 $6 = (($5) + ($4<<4)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($5) + ($4<<4)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($5) + ($4<<4)|0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($1) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 52|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($1) + 56|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$1>>2]);
 $19 = Math_fround($7 * $18);
 $20 = (($1) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($9 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($1) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($11 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($1) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($7 * $29);
 $31 = (($1) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($9 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($1) + 36|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($11 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($1) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($7 * $40);
 $42 = (($1) + 24|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($9 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($1) + 40|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($11 * $47);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround($13 + $27);
 $51 = Math_fround($15 + $38);
 $52 = Math_fround($17 + $49);
 $53 = (($this) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (1 - ($indexB))|0;
 $56 = (($54) + 96|0);
 $57 = (($56) + ($55<<4)|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = ((($56) + ($55<<4)|0) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = ((($56) + ($55<<4)|0) + 8|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = ((($56) + ($55<<4)|0) + 12|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 HEAPF32[$supportA>>2] = $50;
 $65 = (($supportA) + 4|0);
 HEAPF32[$65>>2] = $51;
 $66 = (($supportA) + 8|0);
 HEAPF32[$66>>2] = $52;
 $67 = (($supportA) + 12|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $58;
 $68 = (($supportB) + 4|0);
 HEAPF32[$68>>2] = $60;
 $69 = (($supportB) + 8|0);
 HEAPF32[$69>>2] = $62;
 $70 = (($supportB) + 12|0);
 HEAPF32[$70>>2] = $64;
 $71 = Math_fround($50 - $58);
 $72 = Math_fround($51 - $60);
 $73 = Math_fround($52 - $62);
 HEAPF32[$support>>2] = $71;
 $74 = (($support) + 4|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($support) + 8|0);
 HEAPF32[$75>>2] = $73;
 $76 = (($support) + 12|0);
 HEAPF32[$76>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_E9doSupportERKNS_6shdfnd3aos5Vec3VERS6_S9_S9_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in1$i$i$i = 0, $$in2$i$i = 0, $$in2$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0;
 var $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $b$a$i$i = 0, $b$a$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$6);
 $11 = Math_fround(-$8);
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $9);
 $16 = (($13) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $10);
 $19 = Math_fround($15 + $18);
 $20 = (($13) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * $11);
 $23 = Math_fround($19 + $22);
 $24 = (($13) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $9);
 $27 = (($13) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $10);
 $30 = Math_fround($26 + $29);
 $31 = (($13) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $11);
 $34 = Math_fround($30 + $33);
 $35 = (($13) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * $9);
 $38 = (($13) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $10);
 $41 = Math_fround($37 + $40);
 $42 = (($13) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $11);
 $45 = Math_fround($41 + $44);
 $46 = (($3) + 96|0);
 $47 = (($3) + 96|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($3) + 100|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($3) + 104|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($23 * $48);
 $54 = Math_fround($34 * $50);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($45 * $52);
 $57 = Math_fround($55 + $56);
 $58 = (($3) + 112|0);
 $59 = (($3) + 112|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($3) + 116|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($3) + 120|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($23 * $60);
 $66 = Math_fround($34 * $62);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($45 * $64);
 $69 = Math_fround($67 + $68);
 $70 = $57 > $69;
 ;HEAP32[$1+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$46+12>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$58+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$58+12>>2]|0;
 $b$a$i$i$i = $70 ? $1 : $0;
 $71 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
 $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
 $72 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
 $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
 $73 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
 $74 = (($13) + 48|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($13) + 52|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($13) + 56|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($14 * $71);
 $81 = Math_fround($25 * $72);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($36 * $73);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($17 * $71);
 $86 = Math_fround($28 * $72);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($39 * $73);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($21 * $71);
 $91 = Math_fround($32 * $72);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($43 * $73);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($84 + $75);
 $96 = Math_fround($89 + $77);
 $97 = Math_fround($94 + $79);
 $98 = (($this) + 12|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = (($99) + 96|0);
 $101 = (($99) + 96|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($99) + 100|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($99) + 104|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround(HEAPF32[$dir>>2]);
 $108 = Math_fround(HEAPF32[$5>>2]);
 $109 = Math_fround(HEAPF32[$7>>2]);
 $110 = Math_fround($102 * $107);
 $111 = Math_fround($104 * $108);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround($106 * $109);
 $114 = Math_fround($112 + $113);
 $115 = (($99) + 112|0);
 $116 = (($99) + 112|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($99) + 116|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($99) + 120|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround($107 * $117);
 $123 = Math_fround($108 * $119);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($109 * $121);
 $126 = Math_fround($124 + $125);
 $127 = $114 > $126;
 ;HEAP32[$1+0>>2]=HEAP32[$100+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$100+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$100+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$100+12>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$115+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$115+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$115+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$115+12>>2]|0;
 $b$a$i$i = $127 ? $1 : $0;
 $128 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $$in1$i$i = (($b$a$i$i) + 4|0);
 $129 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $$in2$i$i = (($b$a$i$i) + 8|0);
 $130 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $95;
 $131 = (($supportA) + 4|0);
 HEAPF32[$131>>2] = $96;
 $132 = (($supportA) + 8|0);
 HEAPF32[$132>>2] = $97;
 $133 = (($supportA) + 12|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $128;
 $134 = (($supportB) + 4|0);
 HEAPF32[$134>>2] = $129;
 $135 = (($supportB) + 8|0);
 HEAPF32[$135>>2] = $130;
 $136 = (($supportB) + 12|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 $137 = Math_fround($95 - $128);
 $138 = Math_fround($96 - $129);
 $139 = Math_fround($97 - $130);
 HEAPF32[$support>>2] = $137;
 $140 = (($support) + 4|0);
 HEAPF32[$140>>2] = $138;
 $141 = (($support) + 8|0);
 HEAPF32[$141>>2] = $139;
 $142 = (($support) + 12|0);
 HEAPF32[$142>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_E6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_9TriangleVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i204 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i206 = 0, $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa884 = Math_fround(0), $$lcssa886 = Math_fround(0), $$lcssa888 = Math_fround(0), $$lcssa890 = Math_fround(0), $$lcssa892 = 0, $$lcssa894 = Math_fround(0), $$lcssa896 = Math_fround(0);
 var $$lcssa898 = Math_fround(0), $$sroa$1312 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = Math_fround(0), $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0);
 var $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0;
 var $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $b$a$i = 0, $b$a$i18 = 0, $b$a$i201 = 0, $b$a5$i = 0, $closA = 0, $closAA = 0;
 var $closB = 0, $initialSearchDir = 0, $initialSupportA = 0, $initialSupportB = 0, $nvNorm = 0, $phitmp = 0, $phitmp877 = 0, $size = 0, $support = 0, $tempV = 0, $vNorm = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $0 = sp + 480|0;
 $1 = sp + 416|0;
 $2 = sp + 432|0;
 $3 = sp + 448|0;
 $4 = sp + 464|0;
 $5 = sp + 496|0;
 $6 = sp + 512|0;
 $7 = sp + 528|0;
 $zeroV = sp + 544|0;
 $zero$sroa$1 = sp + 588|0;
 $_lambda$sroa$1 = sp + 572|0;
 $size = sp + 584|0;
 $initialSearchDir = sp + 400|0;
 $initialSupportA = sp + 384|0;
 $8 = sp + 240|0;
 $initialSupportB = sp;
 $Q = sp + 16|0;
 $A = sp + 80|0;
 $B = sp + 144|0;
 $support = sp + 208|0;
 $closA = sp + 224|0;
 $closB = sp + 256|0;
 $closAA = sp + 272|0;
 $vNorm = sp + 288|0;
 $nvNorm = sp + 304|0;
 $9 = sp + 320|0;
 $10 = sp + 336|0;
 $$sroa$1312 = sp + 560|0;
 $11 = sp + 352|0;
 $tempV = sp + 368|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $12 = Math_fround(HEAPF32[$r>>2]);
 $13 = (($r) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($r) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$s>>2]);
 $18 = (($s) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($s) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAP32[$size>>2] = 1;
 $22 = (($aToB) + 48|0);
 $23 = (($aToB) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($aToB) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($24 * $24);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($28 * $28);
 $33 = Math_fround($31 + $32);
 $34 = $33 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$22+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $35 = (($0) + 4|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($0) + 8|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($0) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $b$a$i201 = $34 ? $1 : $0;
 $38 = Math_fround(HEAPF32[$b$a$i201>>2]);
 $$in1$i204 = (($b$a$i201) + 4|0);
 $39 = Math_fround(HEAPF32[$$in1$i204>>2]);
 $$in2$i206 = (($b$a$i201) + 8|0);
 $40 = Math_fround(HEAPF32[$$in2$i206>>2]);
 $41 = Math_fround($38 * $38);
 $42 = Math_fround($39 * $39);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($40 * $40);
 $45 = Math_fround($43 + $44);
 $46 = (Math_fround(Math_sqrt((Math_fround($45)))));
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = Math_fround($38 * $47);
 $49 = Math_fround($39 * $47);
 $50 = Math_fround($40 * $47);
 HEAPF32[$initialSearchDir>>2] = $48;
 $51 = (($initialSearchDir) + 4|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($initialSearchDir) + 8|0);
 HEAPF32[$52>>2] = $50;
 $53 = (($initialSearchDir) + 12|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = Math_fround(-$48);
 $55 = Math_fround(-$49);
 $56 = Math_fround(-$50);
 HEAPF32[$8>>2] = $54;
 $57 = (($8) + 4|0);
 HEAPF32[$57>>2] = $55;
 $58 = (($8) + 8|0);
 HEAPF32[$58>>2] = $56;
 $59 = (($8) + 12|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($initialSupportA,$a,$8,$aToB);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($initialSupportB,$b,$initialSearchDir);
 $60 = Math_fround(HEAPF32[$initialSupportA>>2]);
 $61 = (($initialSupportA) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($initialSupportA) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(HEAPF32[$initialSupportB>>2]);
 $66 = (($initialSupportB) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($initialSupportB) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($60 - $65);
 $71 = Math_fround($62 - $67);
 $72 = Math_fround($64 - $69);
 HEAPF32[$Q>>2] = $70;
 $73 = (($Q) + 4|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($Q) + 8|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($Q) + 12|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($Q) + 16|0);
 ;HEAP32[$76+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$76+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $77 = (($Q) + 32|0);
 ;HEAP32[$77+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $78 = (($Q) + 48|0);
 ;HEAP32[$78+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$78+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$A+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$A+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$A+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$A+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 $79 = (($A) + 16|0);
 ;HEAP32[$79+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $80 = (($A) + 32|0);
 ;HEAP32[$80+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$80+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$80+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$80+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $81 = (($A) + 48|0);
 ;HEAP32[$81+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$81+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$81+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$81+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$B+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $82 = (($B) + 16|0);
 ;HEAP32[$82+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$82+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$82+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $83 = (($B) + 32|0);
 ;HEAP32[$83+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$83+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $84 = (($B) + 48|0);
 ;HEAP32[$84+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$84+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $85 = Math_fround(-$70);
 $86 = Math_fround(-$71);
 $87 = Math_fround(-$72);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $88 = (($a) + 32|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($b) + 32|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = $89 > $91;
 $$$i = $92 ? $91 : $89;
 $93 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $94 = Math_fround($93 * $93);
 $95 = Math_fround($_inflation * $_inflation);
 $96 = Math_fround($95 + $94);
 ;HEAP32[$closA+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $97 = Math_fround($70 * $70);
 $98 = Math_fround($71 * $71);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($72 * $72);
 $101 = Math_fround($99 + $100);
 ;HEAP32[$closAA+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 $102 = $101 > $94;
 L1: do {
  if ($102) {
   $103 = Math_fround($16 * Math_fround(0.0));
   $104 = Math_fround($14 * Math_fround(0.0));
   $105 = Math_fround($12 * Math_fround(0.0));
   $106 = Math_fround($103 + $21);
   $107 = Math_fround($104 + $19);
   $108 = Math_fround($105 + $17);
   $109 = (($vNorm) + 4|0);
   $110 = (($vNorm) + 8|0);
   $111 = (($vNorm) + 12|0);
   $112 = (($nvNorm) + 4|0);
   $113 = (($nvNorm) + 8|0);
   $114 = (($nvNorm) + 12|0);
   $115 = (($9) + 4|0);
   $116 = (($9) + 8|0);
   $117 = (($9) + 12|0);
   $118 = (($10) + 4|0);
   $119 = (($10) + 8|0);
   $120 = (($support) + 4|0);
   $121 = (($support) + 8|0);
   $122 = (($support) + 12|0);
   $123 = (($B) + 4|0);
   $124 = (($B) + 8|0);
   $125 = (($B) + 12|0);
   $126 = (($B) + 16|0);
   $127 = (($B) + 20|0);
   $128 = (($B) + 24|0);
   $129 = (($B) + 28|0);
   $130 = (($B) + 32|0);
   $131 = (($B) + 36|0);
   $132 = (($B) + 40|0);
   $133 = (($B) + 44|0);
   $134 = (($A) + 4|0);
   $135 = (($A) + 8|0);
   $136 = (($A) + 16|0);
   $137 = (($A) + 20|0);
   $138 = (($A) + 24|0);
   $139 = (($Q) + 16|0);
   $140 = (($Q) + 20|0);
   $141 = (($Q) + 24|0);
   $142 = (($Q) + 28|0);
   $143 = (($A) + 32|0);
   $144 = (($A) + 36|0);
   $145 = (($A) + 40|0);
   $146 = (($Q) + 32|0);
   $147 = (($Q) + 36|0);
   $148 = (($Q) + 40|0);
   $149 = (($Q) + 44|0);
   $150 = (($11) + 4|0);
   $151 = (($11) + 8|0);
   $152 = (($tempV) + 4|0);
   $153 = (($tempV) + 8|0);
   $154 = (($closA) + 4|0);
   $155 = (($closA) + 8|0);
   $156 = (($closA) + 12|0);
   $157 = (($closB) + 4|0);
   $158 = (($closB) + 8|0);
   $159 = (($closB) + 12|0);
   $160 = (($tempV) + 12|0);
   $162 = $85;$164 = $86;$167 = $87;$185 = $108;$187 = $107;$189 = $106;$215 = Math_fround(0.0);$416 = $85;$417 = $86;$418 = $87;$419 = $101;
   while(1) {
    ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
    $161 = Math_fround($162 * $162);
    $163 = Math_fround($164 * $164);
    $165 = Math_fround($163 + $161);
    $166 = Math_fround($167 * $167);
    $168 = Math_fround($166 + $165);
    $169 = (Math_fround(Math_sqrt((Math_fround($168)))));
    $170 = Math_fround(Math_fround(1.0) / $169);
    $171 = Math_fround($162 * $170);
    $172 = Math_fround($164 * $170);
    $173 = Math_fround($167 * $170);
    HEAPF32[$vNorm>>2] = $171;
    HEAPF32[$109>>2] = $172;
    HEAPF32[$110>>2] = $173;
    HEAPF32[$111>>2] = Math_fround(0.0);
    $174 = Math_fround(-$171);
    $175 = Math_fround(-$172);
    $176 = Math_fround(-$173);
    HEAPF32[$nvNorm>>2] = $174;
    HEAPF32[$112>>2] = $175;
    HEAPF32[$113>>2] = $176;
    HEAPF32[$114>>2] = Math_fround(0.0);
    __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($9,$a,$vNorm,$aToB);
    $177 = Math_fround(HEAPF32[$9>>2]);
    $178 = Math_fround(HEAPF32[$115>>2]);
    $179 = Math_fround(HEAPF32[$116>>2]);
    $180 = Math_fround(HEAPF32[$117>>2]);
    __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($10,$b,$nvNorm);
    $181 = Math_fround(HEAPF32[$10>>2]);
    $182 = Math_fround(HEAPF32[$118>>2]);
    $183 = Math_fround(HEAPF32[$119>>2]);
    $184 = Math_fround($185 + $181);
    $186 = Math_fround($187 + $182);
    $188 = Math_fround($189 + $183);
    $190 = Math_fround($177 - $184);
    $191 = Math_fround($178 - $186);
    $192 = Math_fround($179 - $188);
    HEAPF32[$support>>2] = $190;
    HEAPF32[$120>>2] = $191;
    HEAPF32[$121>>2] = $192;
    HEAPF32[$122>>2] = Math_fround(0.0);
    $193 = Math_fround(HEAPF32[$vNorm>>2]);
    $194 = Math_fround(HEAPF32[$109>>2]);
    $195 = Math_fround(HEAPF32[$110>>2]);
    $196 = Math_fround($190 * $193);
    $197 = Math_fround($191 * $194);
    $198 = Math_fround(-$197);
    $199 = Math_fround($198 - $196);
    $200 = Math_fround($192 * $195);
    $201 = Math_fround($199 - $200);
    $202 = Math_fround($201 - $_inflation);
    $203 = Math_fround(HEAPF32[$r>>2]);
    $204 = Math_fround(HEAPF32[$13>>2]);
    $205 = Math_fround(HEAPF32[$15>>2]);
    $206 = Math_fround($193 * $203);
    $207 = Math_fround($194 * $204);
    $208 = Math_fround($206 + $207);
    $209 = Math_fround($195 * $205);
    $210 = Math_fround($208 + $209);
    $211 = $202 > Math_fround(0.0);
    if ($211) {
     $212 = !($210 >= Math_fround(0.0));
     if (!($212)) {
      $$0 = 0;
      label = 21;
      break;
     }
     $213 = Math_fround($202 / $210);
     $214 = Math_fround($215 - $213);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1312+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1312+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1312+8>>2]|0;
     $216 = $214 > $215;
     if ($216) {
      $217 = $214 > Math_fround(1.0);
      if ($217) {
       $$0 = 0;
       label = 21;
       break;
      }
      $218 = Math_fround(HEAPF32[$s>>2]);
      $219 = Math_fround(HEAPF32[$18>>2]);
      $220 = Math_fround(HEAPF32[$20>>2]);
      $221 = Math_fround($214 * $203);
      $222 = Math_fround($214 * $204);
      $223 = Math_fround($214 * $205);
      $224 = Math_fround($221 + $218);
      $225 = Math_fround($222 + $219);
      $226 = Math_fround($223 + $220);
      $227 = Math_fround($224 - $185);
      $228 = Math_fround($225 - $187);
      $229 = Math_fround($226 - $189);
      $230 = Math_fround(HEAPF32[$B>>2]);
      $231 = Math_fround(HEAPF32[$123>>2]);
      $232 = Math_fround(HEAPF32[$124>>2]);
      $233 = Math_fround($227 + $230);
      $234 = Math_fround($228 + $231);
      $235 = Math_fround($229 + $232);
      $236 = Math_fround(HEAPF32[$126>>2]);
      $237 = Math_fround(HEAPF32[$127>>2]);
      $238 = Math_fround(HEAPF32[$128>>2]);
      $239 = Math_fround($227 + $236);
      $240 = Math_fround($228 + $237);
      $241 = Math_fround($229 + $238);
      $242 = Math_fround(HEAPF32[$130>>2]);
      $243 = Math_fround(HEAPF32[$131>>2]);
      $244 = Math_fround(HEAPF32[$132>>2]);
      $245 = Math_fround($227 + $242);
      $246 = Math_fround($228 + $243);
      $247 = Math_fround($229 + $244);
      HEAPF32[$B>>2] = $233;
      HEAPF32[$123>>2] = $234;
      HEAPF32[$124>>2] = $235;
      HEAPF32[$125>>2] = Math_fround(0.0);
      HEAPF32[$126>>2] = $239;
      HEAPF32[$127>>2] = $240;
      HEAPF32[$128>>2] = $241;
      HEAPF32[$129>>2] = Math_fround(0.0);
      HEAPF32[$130>>2] = $245;
      HEAPF32[$131>>2] = $246;
      HEAPF32[$132>>2] = $247;
      HEAPF32[$133>>2] = Math_fround(0.0);
      $248 = Math_fround(HEAPF32[$A>>2]);
      $249 = Math_fround(HEAPF32[$134>>2]);
      $250 = Math_fround(HEAPF32[$135>>2]);
      $251 = Math_fround($248 - $233);
      $252 = Math_fround($249 - $234);
      $253 = Math_fround($250 - $235);
      HEAPF32[$Q>>2] = $251;
      HEAPF32[$73>>2] = $252;
      HEAPF32[$74>>2] = $253;
      HEAPF32[$75>>2] = Math_fround(0.0);
      $254 = Math_fround(HEAPF32[$136>>2]);
      $255 = Math_fround(HEAPF32[$137>>2]);
      $256 = Math_fround(HEAPF32[$138>>2]);
      $257 = Math_fround($254 - $239);
      $258 = Math_fround($255 - $240);
      $259 = Math_fround($256 - $241);
      HEAPF32[$139>>2] = $257;
      HEAPF32[$140>>2] = $258;
      HEAPF32[$141>>2] = $259;
      HEAPF32[$142>>2] = Math_fround(0.0);
      $260 = Math_fround(HEAPF32[$143>>2]);
      $261 = Math_fround(HEAPF32[$144>>2]);
      $262 = Math_fround(HEAPF32[$145>>2]);
      $263 = Math_fround($260 - $245);
      $264 = Math_fround($261 - $246);
      $265 = Math_fround($262 - $247);
      HEAPF32[$146>>2] = $263;
      HEAPF32[$147>>2] = $264;
      HEAPF32[$148>>2] = $265;
      HEAPF32[$149>>2] = Math_fround(0.0);
      __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($11,$b,$nvNorm);
      $266 = Math_fround(HEAPF32[$11>>2]);
      $267 = Math_fround(HEAPF32[$150>>2]);
      $268 = Math_fround(HEAPF32[$151>>2]);
      $269 = Math_fround($224 + $266);
      $270 = Math_fround($225 + $267);
      $271 = Math_fround($226 + $268);
      $272 = Math_fround($177 - $269);
      $273 = Math_fround($178 - $270);
      $274 = Math_fround($179 - $271);
      HEAPF32[$support>>2] = $272;
      HEAPF32[$120>>2] = $273;
      HEAPF32[$121>>2] = $274;
      HEAPF32[$122>>2] = Math_fround(0.0);
      $281 = $269;$283 = $270;$285 = $271;$293 = $272;$295 = $273;$297 = $274;$352 = Math_fround(3.40282346638528859812E+38);$420 = $214;$421 = $226;$422 = $225;$423 = $224;$424 = $167;$425 = $164;$426 = $162;
     } else {
      $281 = $184;$283 = $186;$285 = $188;$293 = $190;$295 = $191;$297 = $192;$352 = $419;$420 = $214;$421 = $189;$422 = $187;$423 = $185;$424 = $418;$425 = $417;$426 = $416;
     }
    } else {
     $281 = $184;$283 = $186;$285 = $188;$293 = $190;$295 = $191;$297 = $192;$352 = $419;$420 = $215;$421 = $189;$422 = $187;$423 = $185;$424 = $418;$425 = $417;$426 = $416;
    }
    $275 = HEAP32[$size>>2]|0;
    $276 = (($A) + ($275<<4)|0);
    HEAPF32[$276>>2] = $177;
    $277 = ((($A) + ($275<<4)|0) + 4|0);
    HEAPF32[$277>>2] = $178;
    $278 = ((($A) + ($275<<4)|0) + 8|0);
    HEAPF32[$278>>2] = $179;
    $279 = ((($A) + ($275<<4)|0) + 12|0);
    HEAPF32[$279>>2] = $180;
    $280 = (($B) + ($275<<4)|0);
    HEAPF32[$280>>2] = $281;
    $282 = ((($B) + ($275<<4)|0) + 4|0);
    HEAPF32[$282>>2] = $283;
    $284 = ((($B) + ($275<<4)|0) + 8|0);
    HEAPF32[$284>>2] = $285;
    $286 = ((($B) + ($275<<4)|0) + 12|0);
    HEAPF32[$286>>2] = Math_fround(0.0);
    $287 = (($275) + 1)|0;
    HEAP32[$size>>2] = $287;
    $288 = (($Q) + ($275<<4)|0);
    ;HEAP32[$288+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$288+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$288+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$288+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($275|0) == 1)) {
      $289 = Math_fround(HEAPF32[$Q>>2]);
      $290 = Math_fround(HEAPF32[$73>>2]);
      $291 = Math_fround(HEAPF32[$74>>2]);
      $292 = Math_fround($293 - $289);
      $294 = Math_fround($295 - $290);
      $296 = Math_fround($297 - $291);
      $298 = Math_fround($292 * $292);
      $299 = Math_fround($294 * $294);
      $300 = Math_fround($298 + $299);
      $301 = Math_fround($296 * $296);
      $302 = Math_fround($300 + $301);
      $303 = $302 == Math_fround(0.0);
      if ($303) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $304 = Math_fround($290 * $294);
       $305 = Math_fround(-$304);
       $306 = Math_fround($289 * $292);
       $307 = Math_fround($305 - $306);
       $308 = Math_fround($291 * $296);
       $309 = Math_fround($307 - $308);
       $310 = Math_fround(HEAPF32[$A>>2]);
       $311 = Math_fround(HEAPF32[$134>>2]);
       $312 = Math_fround(HEAPF32[$135>>2]);
       $313 = Math_fround($177 - $310);
       $314 = Math_fround($178 - $311);
       $315 = Math_fround($179 - $312);
       $316 = Math_fround(HEAPF32[$B>>2]);
       $317 = Math_fround(HEAPF32[$123>>2]);
       $318 = Math_fround(HEAPF32[$124>>2]);
       $319 = Math_fround($281 - $316);
       $320 = Math_fround($283 - $317);
       $321 = Math_fround($285 - $318);
       $322 = Math_fround($309 / $302);
       $323 = $322 > Math_fround(1.0);
       $$$i$i$i = $323 ? Math_fround(1.0) : $322;
       $324 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $324 ? $$$i$i$i : Math_fround(0.0);
       $325 = Math_fround($313 * $$$i8$i$i);
       $326 = Math_fround($314 * $$$i8$i$i);
       $327 = Math_fround($315 * $$$i8$i$i);
       $328 = Math_fround($310 + $325);
       $329 = Math_fround($311 + $326);
       $330 = Math_fround($312 + $327);
       $331 = Math_fround($319 * $$$i8$i$i);
       $332 = Math_fround($320 * $$$i8$i$i);
       $333 = Math_fround($321 * $$$i8$i$i);
       $334 = Math_fround($316 + $331);
       $335 = Math_fround($317 + $332);
       $336 = Math_fround($318 + $333);
       HEAPF32[$closA>>2] = $328;
       HEAPF32[$154>>2] = $329;
       HEAPF32[$155>>2] = $330;
       HEAPF32[$156>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $334;
       HEAPF32[$157>>2] = $335;
       HEAPF32[$158>>2] = $336;
       HEAPF32[$159>>2] = Math_fround(0.0);
       $337 = Math_fround($328 - $334);
       $338 = Math_fround($329 - $335);
       $339 = Math_fround($330 - $336);
       HEAPF32[$tempV>>2] = $337;
       HEAPF32[$152>>2] = $338;
       HEAPF32[$153>>2] = $339;
       HEAPF32[$160>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($275|0) == 0)) {
      HEAPF32[$closA>>2] = $177;
      HEAPF32[$154>>2] = $178;
      HEAPF32[$155>>2] = $179;
      HEAPF32[$156>>2] = $180;
      HEAPF32[$closB>>2] = $281;
      HEAPF32[$157>>2] = $283;
      HEAPF32[$158>>2] = $285;
      HEAPF32[$159>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($275|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($275|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$76,$support,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $340 = Math_fround(HEAPF32[$tempV>>2]);
    $341 = Math_fround(HEAPF32[$152>>2]);
    $342 = Math_fround(HEAPF32[$153>>2]);
    $343 = Math_fround(-$340);
    $344 = Math_fround(-$341);
    $345 = Math_fround(-$342);
    $346 = Math_fround($340 * $340);
    $347 = Math_fround($341 * $341);
    $348 = Math_fround($346 + $347);
    $349 = Math_fround($342 * $342);
    $350 = Math_fround($348 + $349);
    $351 = $352 > $350;
    $353 = $351 << 31 >> 31;
    $354 = $350 > $96;
    if (!($354)) {
     $$lcssa = $420;$$lcssa884 = $345;$$lcssa886 = $344;$$lcssa888 = $343;$$lcssa890 = $350;$$lcssa892 = $353;$$lcssa894 = $424;$$lcssa896 = $425;$$lcssa898 = $426;
     break L1;
    }
    if ($351) {
     $162 = $343;$164 = $344;$167 = $345;$185 = $423;$187 = $422;$189 = $421;$215 = $420;$416 = $426;$417 = $425;$418 = $424;$419 = $350;
    } else {
     $$lcssa = $420;$$lcssa884 = $345;$$lcssa886 = $344;$$lcssa888 = $343;$$lcssa890 = $350;$$lcssa892 = $353;$$lcssa894 = $424;$$lcssa896 = $425;$$lcssa898 = $426;
     break L1;
    }
   }
   if ((label|0) == 21) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa884 = $87;$$lcssa886 = $86;$$lcssa888 = $85;$$lcssa890 = $101;$$lcssa892 = -1;$$lcssa894 = $87;$$lcssa896 = $86;$$lcssa898 = $85;
  }
 } while(0);
 $355 = (($a) + 64|0);
 $356 = HEAP32[$355>>2]|0;
 $357 = (($a) + 68|0);
 $358 = HEAP32[$357>>2]|0;
 $359 = (($a) + 72|0);
 $360 = HEAP32[$359>>2]|0;
 $361 = $$lcssa890 > $94;
 if ($361) {
  $phitmp = ($$lcssa892|0)==(0);
  $phitmp877 = $phitmp ? $2 : $3;
  $369 = $phitmp877;
 } else {
  $369 = $2;
 }
 HEAPF32[$3>>2] = $$lcssa888;
 $362 = (($3) + 4|0);
 HEAPF32[$362>>2] = $$lcssa886;
 $363 = (($3) + 8|0);
 HEAPF32[$363>>2] = $$lcssa884;
 $364 = (($3) + 12|0);
 HEAPF32[$364>>2] = Math_fround(0.0);
 HEAPF32[$2>>2] = $$lcssa898;
 $365 = (($2) + 4|0);
 HEAPF32[$365>>2] = $$lcssa896;
 $366 = (($2) + 8|0);
 HEAPF32[$366>>2] = $$lcssa894;
 $367 = (($2) + 12|0);
 HEAPF32[$367>>2] = Math_fround(0.0);
 $368 = Math_fround(HEAPF32[$369>>2]);
 $$in1$i37 = (($369) + 4|0);
 $370 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($369) + 8|0);
 $371 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $372 = Math_fround($368 * $368);
 $373 = Math_fround($370 * $370);
 $374 = Math_fround($372 + $373);
 $375 = Math_fround($371 * $371);
 $376 = Math_fround($374 + $375);
 $377 = (Math_fround(Math_sqrt((Math_fround($376)))));
 $378 = Math_fround(Math_fround(1.0) / $377);
 $379 = Math_fround($368 * $378);
 $380 = Math_fround($370 * $378);
 $381 = Math_fround($371 * $378);
 $382 = Math_fround(-$379);
 $383 = Math_fround(-$380);
 $384 = Math_fround(-$381);
 HEAPF32[$normal>>2] = $382;
 $385 = (($normal) + 4|0);
 HEAPF32[$385>>2] = $383;
 $386 = (($normal) + 8|0);
 HEAPF32[$386>>2] = $384;
 $387 = (($normal) + 12|0);
 HEAPF32[$387>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $388 = (($lambda) + 4|0);
 ;HEAP32[$388+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$388+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$388+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$5+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$4+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$closAA+12>>2]|0;
 $389 = ($$lcssa892|0)==(0);
 $b$a$i18 = $389 ? $4 : $5;
 $390 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $391 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $392 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $390;
 $393 = (($closA) + 4|0);
 HEAPF32[$393>>2] = $391;
 $394 = (($closA) + 8|0);
 HEAPF32[$394>>2] = $392;
 $395 = (($closA) + 12|0);
 HEAPF32[$395>>2] = Math_fround(0.0);
 $396 = (($a) + 16|0);
 $397 = Math_fround(HEAPF32[$396>>2]);
 $398 = Math_fround($397 * $382);
 $399 = Math_fround($397 * $383);
 $400 = Math_fround($397 * $384);
 $401 = Math_fround($390 - $398);
 $402 = Math_fround($391 - $399);
 $403 = Math_fround($392 - $400);
 ;HEAP32[$6+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$7>>2] = $401;
 $404 = (($7) + 4|0);
 HEAPF32[$404>>2] = $402;
 $405 = (($7) + 8|0);
 HEAPF32[$405>>2] = $403;
 $406 = (($7) + 12|0);
 HEAPF32[$406>>2] = Math_fround(0.0);
 $407 = ($356|0)==(0);
 $b$a$i = $407 ? $6 : $7;
 $408 = Math_fround(HEAPF32[$b$a$i>>2]);
 $409 = ($358|0)==(0);
 $a$pn3$i = $409 ? $6 : $7;
 $$in1$i = (($a$pn3$i) + 4|0);
 $410 = Math_fround(HEAPF32[$$in1$i>>2]);
 $411 = ($360|0)==(0);
 $b$a5$i = $411 ? $6 : $7;
 $$in2$i = (($b$a5$i) + 8|0);
 $412 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $408;
 $413 = (($closestA) + 4|0);
 HEAPF32[$413>>2] = $410;
 $414 = (($closestA) + 8|0);
 HEAPF32[$414>>2] = $412;
 $415 = (($closestA) + 12|0);
 HEAPF32[$415>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_9TriangleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$751 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i170 = Math_fround(0), $$$i134 = Math_fround(0), $$$i169 = Math_fround(0), $$$i739803 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i171 = Math_fround(0), $$0 = 0, $$747 = 0, $$in1$i = 0, $$in2$i = 0, $$ph = Math_fround(0), $$ph759 = Math_fround(0), $$ph760 = Math_fround(0), $$ph761 = Math_fround(0), $$ph762 = Math_fround(0), $$ph763 = Math_fround(0), $$ph764 = Math_fround(0);
 var $$ph765 = Math_fround(0), $$ph767 = Math_fround(0), $$ph768 = 0, $$pre = Math_fround(0), $$pre842 = Math_fround(0), $$pre843 = Math_fround(0), $$pre844 = Math_fround(0), $$pre845 = Math_fround(0), $$pre846 = Math_fround(0), $$pre847 = Math_fround(0), $$pre848 = Math_fround(0), $$sroa$1 = 0, $$sroa$1232 = 0, $$sroa$1234 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0);
 var $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0;
 var $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0);
 var $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0);
 var $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0;
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0);
 var $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = 0, $337 = Math_fround(0);
 var $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0);
 var $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0);
 var $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0);
 var $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0);
 var $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0);
 var $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0);
 var $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0;
 var $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = 0, $503 = 0, $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_dir$i = 0, $aInd = 0, $b$a$i = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0;
 var $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$0813 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp755 = 0, $res$i = 0, $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $0 = sp + 400|0;
 $1 = sp + 336|0;
 $_dir$i = sp + 352|0;
 $res$i = sp + 368|0;
 $closA = sp + 384|0;
 $closB = sp + 416|0;
 $sDist$sroa$1 = sp + 516|0;
 $minDist$sroa$1 = sp + 504|0;
 $v = sp + 320|0;
 $Q = sp;
 $A = sp + 160|0;
 $B = sp + 64|0;
 $aInd = sp + 488|0;
 $bInd = sp + 528|0;
 $size = sp + 448|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 144|0;
 $lastB = sp + 224|0;
 $2 = sp + 240|0;
 $3 = sp + 256|0;
 $supportA1 = sp + 272|0;
 $supportB2 = sp + 288|0;
 $support3 = sp + 304|0;
 $$sroa$1234 = sp + 464|0;
 $4 = sp + 432|0;
 $$sroa$1232 = sp + 476|0;
 $$sroa$1 = sp + 452|0;
 $5 = (($a) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($b) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$_contactDist>>2]);
 $10 = (($a) + 32|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($b) + 32|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = $11 > $13;
 $$$i169 = $14 ? $13 : $11;
 $15 = Math_fround($$$i169 * Math_fround(0.100000001490116119385));
 $16 = Math_fround($6 + $8);
 $17 = (($closA) + 4|0);
 $18 = (($closA) + 8|0);
 $19 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $20 = (($closB) + 4|0);
 $21 = (($closB) + 8|0);
 $22 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $23 = Math_fround($15 * $15);
 HEAP32[$size>>2] = 0;
 $24 = HEAP8[$_size>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $187 = (($aToB) + 48|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = (($aToB) + 52|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($aToB) + 56|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = (($aToB) + 60|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = Math_fround($188 * $188);
  $196 = Math_fround($190 * $190);
  $197 = Math_fround($195 + $196);
  $198 = Math_fround($192 * $192);
  $199 = Math_fround($197 + $198);
  $200 = $199 > Math_fround(0.0);
  HEAPF32[$1>>2] = $188;
  $201 = (($1) + 4|0);
  HEAPF32[$201>>2] = $190;
  $202 = (($1) + 8|0);
  HEAPF32[$202>>2] = $192;
  $203 = (($1) + 12|0);
  HEAPF32[$203>>2] = $194;
  HEAPF32[$0>>2] = Math_fround(1.0);
  $204 = (($0) + 4|0);
  HEAPF32[$204>>2] = Math_fround(0.0);
  $205 = (($0) + 8|0);
  HEAPF32[$205>>2] = Math_fround(0.0);
  $206 = (($0) + 12|0);
  HEAPF32[$206>>2] = Math_fround(0.0);
  $b$a$i = $200 ? $1 : $0;
  $207 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $208 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $209 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $207;
  $210 = (($v) + 4|0);
  HEAPF32[$210>>2] = $208;
  $211 = (($v) + 8|0);
  HEAPF32[$211>>2] = $209;
  $212 = (($v) + 12|0);
  HEAPF32[$212>>2] = Math_fround(0.0);
  $$ph = Math_fround(0.0);$$ph759 = Math_fround(0.0);$$ph760 = Math_fround(0.0);$$ph761 = Math_fround(0.0);$$ph762 = Math_fround(0.0);$$ph763 = Math_fround(0.0);$$ph764 = Math_fround(0.0);$$ph765 = Math_fround(0.0);$$ph767 = Math_fround(3.40282346638528859812E+38);$$ph768 = 1;$531 = $209;$532 = $208;$533 = $207;
 } else {
  $26 = (($lastQ) + 4|0);
  $27 = (($lastQ) + 8|0);
  $28 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $29 = (($lastA) + 4|0);
  $30 = (($lastA) + 8|0);
  $31 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $32 = (($lastB) + 4|0);
  $33 = (($lastB) + 8|0);
  $34 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $35 = (($aToB) + 48|0);
  $36 = (($aToB) + 52|0);
  $37 = (($aToB) + 56|0);
  $38 = (($aToB) + 16|0);
  $39 = (($aToB) + 32|0);
  $40 = (($aToB) + 4|0);
  $41 = (($aToB) + 20|0);
  $42 = (($aToB) + 36|0);
  $43 = (($aToB) + 8|0);
  $44 = (($aToB) + 24|0);
  $45 = (($aToB) + 40|0);
  $46 = (($b) + 16|0);
  $47 = (($2) + 4|0);
  $48 = (($2) + 8|0);
  $49 = (($2) + 12|0);
  $i$0813 = 0;
  while(1) {
   $50 = (($aIndices) + ($i$0813)|0);
   $51 = HEAP8[$50>>0]|0;
   $52 = $51&255;
   $53 = (($aInd) + ($i$0813<<2)|0);
   HEAP32[$53>>2] = $52;
   $54 = (($bIndices) + ($i$0813)|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55&255;
   $57 = (($bInd) + ($i$0813<<2)|0);
   HEAP32[$57>>2] = $56;
   $58 = ((($a) + ($52<<4)|0) + 96|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = ((($a) + ($52<<4)|0) + 100|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = ((($a) + ($52<<4)|0) + 104|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = Math_fround(HEAPF32[$35>>2]);
   $65 = Math_fround(HEAPF32[$36>>2]);
   $66 = Math_fround(HEAPF32[$37>>2]);
   $67 = Math_fround(HEAPF32[$aToB>>2]);
   $68 = Math_fround($59 * $67);
   $69 = Math_fround(HEAPF32[$38>>2]);
   $70 = Math_fround($61 * $69);
   $71 = Math_fround($68 + $70);
   $72 = Math_fround(HEAPF32[$39>>2]);
   $73 = Math_fround($63 * $72);
   $74 = Math_fround($71 + $73);
   $75 = Math_fround(HEAPF32[$40>>2]);
   $76 = Math_fround($59 * $75);
   $77 = Math_fround(HEAPF32[$41>>2]);
   $78 = Math_fround($61 * $77);
   $79 = Math_fround($76 + $78);
   $80 = Math_fround(HEAPF32[$42>>2]);
   $81 = Math_fround($63 * $80);
   $82 = Math_fround($79 + $81);
   $83 = Math_fround(HEAPF32[$43>>2]);
   $84 = Math_fround($59 * $83);
   $85 = Math_fround(HEAPF32[$44>>2]);
   $86 = Math_fround($61 * $85);
   $87 = Math_fround($84 + $86);
   $88 = Math_fround(HEAPF32[$45>>2]);
   $89 = Math_fround($63 * $88);
   $90 = Math_fround($87 + $89);
   $91 = Math_fround($64 + $74);
   $92 = Math_fround($65 + $82);
   $93 = Math_fround($66 + $90);
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($2,$b,$56,$46);
   $94 = Math_fround(HEAPF32[$2>>2]);
   $95 = Math_fround(HEAPF32[$47>>2]);
   $96 = Math_fround(HEAPF32[$48>>2]);
   $97 = Math_fround(HEAPF32[$49>>2]);
   $98 = Math_fround($91 - $94);
   $99 = Math_fround($92 - $95);
   $100 = Math_fround($93 - $96);
   $101 = HEAP32[$size>>2]|0;
   $102 = (($A) + ($101<<4)|0);
   HEAPF32[$lastA>>2] = $91;
   HEAPF32[$29>>2] = $92;
   HEAPF32[$30>>2] = $93;
   HEAPF32[$31>>2] = Math_fround(0.0);
   ;HEAP32[$102+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$102+12>>2]=HEAP32[$lastA+12>>2]|0;
   $103 = (($B) + ($101<<4)|0);
   HEAPF32[$lastB>>2] = $94;
   HEAPF32[$32>>2] = $95;
   HEAPF32[$33>>2] = $96;
   HEAPF32[$34>>2] = $97;
   ;HEAP32[$103+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$lastB+12>>2]|0;
   $104 = (($101) + 1)|0;
   HEAP32[$size>>2] = $104;
   $105 = (($Q) + ($101<<4)|0);
   HEAPF32[$lastQ>>2] = $98;
   HEAPF32[$26>>2] = $99;
   HEAPF32[$27>>2] = $100;
   HEAPF32[$28>>2] = Math_fround(0.0);
   ;HEAP32[$105+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$105+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$105+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$105+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $106 = (($i$0813) + 1)|0;
   $107 = HEAP8[$_size>>0]|0;
   $108 = $107&255;
   $109 = ($106>>>0)<($108>>>0);
   if ($109) {
    $i$0813 = $106;
   } else {
    break;
   }
  }
  do {
   if ((($101|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$3+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($101|0) == 1)) {
    $110 = Math_fround(HEAPF32[$Q>>2]);
    $111 = (($Q) + 4|0);
    $112 = Math_fround(HEAPF32[$111>>2]);
    $113 = (($Q) + 8|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = Math_fround($98 - $110);
    $116 = Math_fround($99 - $112);
    $117 = Math_fround($100 - $114);
    $118 = Math_fround($115 * $115);
    $119 = Math_fround($116 * $116);
    $120 = Math_fround($118 + $119);
    $121 = Math_fround($117 * $117);
    $122 = Math_fround($120 + $121);
    $123 = $122 == Math_fround(0.0);
    if ($123) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$3+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $124 = Math_fround($112 * $116);
     $125 = Math_fround(-$124);
     $126 = Math_fround($110 * $115);
     $127 = Math_fround($125 - $126);
     $128 = Math_fround($114 * $117);
     $129 = Math_fround($127 - $128);
     $130 = Math_fround(HEAPF32[$A>>2]);
     $131 = (($A) + 4|0);
     $132 = Math_fround(HEAPF32[$131>>2]);
     $133 = (($A) + 8|0);
     $134 = Math_fround(HEAPF32[$133>>2]);
     $135 = Math_fround($91 - $130);
     $136 = Math_fround($92 - $132);
     $137 = Math_fround($93 - $134);
     $138 = Math_fround(HEAPF32[$B>>2]);
     $139 = (($B) + 4|0);
     $140 = Math_fround(HEAPF32[$139>>2]);
     $141 = (($B) + 8|0);
     $142 = Math_fround(HEAPF32[$141>>2]);
     $143 = Math_fround($94 - $138);
     $144 = Math_fround($95 - $140);
     $145 = Math_fround($96 - $142);
     $146 = Math_fround($129 / $122);
     $147 = $146 > Math_fround(1.0);
     $$$i$i$i170 = $147 ? Math_fround(1.0) : $146;
     $148 = $$$i$i$i170 > Math_fround(0.0);
     $$$i8$i$i171 = $148 ? $$$i$i$i170 : Math_fround(0.0);
     $149 = Math_fround($135 * $$$i8$i$i171);
     $150 = Math_fround($136 * $$$i8$i$i171);
     $151 = Math_fround($137 * $$$i8$i$i171);
     $152 = Math_fround($130 + $149);
     $153 = Math_fround($132 + $150);
     $154 = Math_fround($134 + $151);
     $155 = Math_fround($143 * $$$i8$i$i171);
     $156 = Math_fround($144 * $$$i8$i$i171);
     $157 = Math_fround($145 * $$$i8$i$i171);
     $158 = Math_fround($138 + $155);
     $159 = Math_fround($140 + $156);
     $160 = Math_fround($142 + $157);
     HEAPF32[$closA>>2] = $152;
     HEAPF32[$17>>2] = $153;
     HEAPF32[$18>>2] = $154;
     HEAPF32[$19>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $158;
     HEAPF32[$20>>2] = $159;
     HEAPF32[$21>>2] = $160;
     HEAPF32[$22>>2] = Math_fround(0.0);
     $161 = Math_fround($152 - $158);
     $162 = Math_fround($153 - $159);
     $163 = Math_fround($154 - $160);
     HEAPF32[$3>>2] = $161;
     $164 = (($3) + 4|0);
     HEAPF32[$164>>2] = $162;
     $165 = (($3) + 8|0);
     HEAPF32[$165>>2] = $163;
     $166 = (($3) + 12|0);
     HEAPF32[$166>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($101|0) == 2)) {
    $167 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($3,$Q,$167,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($101|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($3,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else {
    ;HEAP32[$3+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$3+12>>2]|0;
  $168 = Math_fround(HEAPF32[$v>>2]);
  $169 = (($v) + 4|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = (($v) + 8|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = Math_fround($168 * $168);
  $174 = Math_fround($170 * $170);
  $175 = Math_fround($173 + $174);
  $176 = Math_fround($172 * $172);
  $177 = Math_fround($175 + $176);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $178 = Math_fround(HEAPF32[$closA>>2]);
  $179 = Math_fround(HEAPF32[$17>>2]);
  $180 = Math_fround(HEAPF32[$18>>2]);
  $181 = Math_fround(HEAPF32[$19>>2]);
  $182 = Math_fround(HEAPF32[$closB>>2]);
  $183 = Math_fround(HEAPF32[$20>>2]);
  $184 = Math_fround(HEAPF32[$21>>2]);
  $185 = Math_fround(HEAPF32[$22>>2]);
  $186 = $177 > $23;
  $$ph = $181;$$ph759 = $180;$$ph760 = $179;$$ph761 = $178;$$ph762 = $185;$$ph763 = $184;$$ph764 = $183;$$ph765 = $182;$$ph767 = $177;$$ph768 = $186;$531 = $172;$532 = $170;$533 = $168;
 }
 do {
  if ($$ph768) {
   $214 = (($v) + 4|0);
   $215 = (($v) + 8|0);
   $216 = (($aToB) + 4|0);
   $217 = (($aToB) + 8|0);
   $218 = (($aToB) + 16|0);
   $219 = (($aToB) + 20|0);
   $220 = (($aToB) + 24|0);
   $221 = (($aToB) + 32|0);
   $222 = (($aToB) + 36|0);
   $223 = (($aToB) + 40|0);
   $224 = (($_dir$i) + 4|0);
   $225 = (($_dir$i) + 8|0);
   $226 = (($_dir$i) + 12|0);
   $227 = (($aToB) + 48|0);
   $228 = (($aToB) + 52|0);
   $229 = (($aToB) + 56|0);
   $230 = (($res$i) + 4|0);
   $231 = (($res$i) + 8|0);
   $232 = (($supportA1) + 4|0);
   $233 = (($supportA1) + 8|0);
   $234 = (($supportA1) + 12|0);
   $235 = (($supportB2) + 4|0);
   $236 = (($supportB2) + 8|0);
   $237 = (($support3) + 4|0);
   $238 = (($support3) + 8|0);
   $239 = (($support3) + 12|0);
   $240 = (($a) + 48|0);
   $241 = (($b) + 48|0);
   $242 = (($Q) + 4|0);
   $243 = (($Q) + 8|0);
   $244 = (($A) + 4|0);
   $245 = (($A) + 8|0);
   $246 = (($B) + 4|0);
   $247 = (($B) + 8|0);
   $248 = (($4) + 4|0);
   $249 = (($4) + 8|0);
   $250 = (($4) + 12|0);
   $251 = (($Q) + 16|0);
   $$$i739803 = $9;$253 = $533;$255 = $532;$257 = $531;$340 = $$ph767;$476 = $$ph761;$477 = $$ph760;$478 = $$ph759;$479 = $$ph;$480 = $$ph765;$481 = $$ph764;$482 = $$ph763;$483 = $$ph762;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $252 = Math_fround(-$253);
    $254 = Math_fround(-$255);
    $256 = Math_fround(-$257);
    $258 = HEAP32[$size>>2]|0;
    $259 = (($A) + ($258<<4)|0);
    $260 = (($aInd) + ($258<<2)|0);
    $261 = Math_fround(HEAPF32[$aToB>>2]);
    $262 = Math_fround($261 * $252);
    $263 = Math_fround(HEAPF32[$216>>2]);
    $264 = Math_fround($263 * $254);
    $265 = Math_fround($262 + $264);
    $266 = Math_fround(HEAPF32[$217>>2]);
    $267 = Math_fround($266 * $256);
    $268 = Math_fround($265 + $267);
    $269 = Math_fround(HEAPF32[$218>>2]);
    $270 = Math_fround($269 * $252);
    $271 = Math_fround(HEAPF32[$219>>2]);
    $272 = Math_fround($271 * $254);
    $273 = Math_fround($270 + $272);
    $274 = Math_fround(HEAPF32[$220>>2]);
    $275 = Math_fround($274 * $256);
    $276 = Math_fround($273 + $275);
    $277 = Math_fround(HEAPF32[$221>>2]);
    $278 = Math_fround($277 * $252);
    $279 = Math_fround(HEAPF32[$222>>2]);
    $280 = Math_fround($279 * $254);
    $281 = Math_fround($278 + $280);
    $282 = Math_fround(HEAPF32[$223>>2]);
    $283 = Math_fround($282 * $256);
    $284 = Math_fround($281 + $283);
    HEAPF32[$_dir$i>>2] = $268;
    HEAPF32[$224>>2] = $276;
    HEAPF32[$225>>2] = $284;
    HEAPF32[$226>>2] = Math_fround(0.0);
    __ZNK5physx2Gu9TriangleV12supportLocalERKNS_6shdfnd3aos5Vec3VERi($res$i,$a,$_dir$i,$260);
    ;HEAP32[$259+0>>2]=HEAP32[$res$i+0>>2]|0;HEAP32[$259+4>>2]=HEAP32[$res$i+4>>2]|0;HEAP32[$259+8>>2]=HEAP32[$res$i+8>>2]|0;HEAP32[$259+12>>2]=HEAP32[$res$i+12>>2]|0;
    $285 = Math_fround(HEAPF32[$227>>2]);
    $286 = Math_fround(HEAPF32[$228>>2]);
    $287 = Math_fround(HEAPF32[$229>>2]);
    $288 = Math_fround(HEAPF32[$res$i>>2]);
    $289 = Math_fround(HEAPF32[$230>>2]);
    $290 = Math_fround(HEAPF32[$231>>2]);
    $291 = Math_fround(HEAPF32[$aToB>>2]);
    $292 = Math_fround($288 * $291);
    $293 = Math_fround(HEAPF32[$218>>2]);
    $294 = Math_fround($289 * $293);
    $295 = Math_fround($292 + $294);
    $296 = Math_fround(HEAPF32[$221>>2]);
    $297 = Math_fround($290 * $296);
    $298 = Math_fround($295 + $297);
    $299 = Math_fround(HEAPF32[$216>>2]);
    $300 = Math_fround($288 * $299);
    $301 = Math_fround(HEAPF32[$219>>2]);
    $302 = Math_fround($289 * $301);
    $303 = Math_fround($300 + $302);
    $304 = Math_fround(HEAPF32[$222>>2]);
    $305 = Math_fround($290 * $304);
    $306 = Math_fround($303 + $305);
    $307 = Math_fround(HEAPF32[$217>>2]);
    $308 = Math_fround($288 * $307);
    $309 = Math_fround(HEAPF32[$220>>2]);
    $310 = Math_fround($289 * $309);
    $311 = Math_fround($308 + $310);
    $312 = Math_fround(HEAPF32[$223>>2]);
    $313 = Math_fround($290 * $312);
    $314 = Math_fround($311 + $313);
    $315 = Math_fround($285 + $298);
    $316 = Math_fround($286 + $306);
    $317 = Math_fround($287 + $314);
    HEAPF32[$supportA1>>2] = $315;
    HEAPF32[$232>>2] = $316;
    HEAPF32[$233>>2] = $317;
    HEAPF32[$234>>2] = Math_fround(0.0);
    $318 = HEAP32[$size>>2]|0;
    $319 = (($B) + ($318<<4)|0);
    $320 = (($bInd) + ($318<<2)|0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($supportB2,$b,$v,$319,$320);
    $321 = Math_fround(HEAPF32[$supportA1>>2]);
    $322 = Math_fround(HEAPF32[$232>>2]);
    $323 = Math_fround(HEAPF32[$233>>2]);
    $324 = Math_fround(HEAPF32[$supportB2>>2]);
    $325 = Math_fround(HEAPF32[$235>>2]);
    $326 = Math_fround(HEAPF32[$236>>2]);
    $327 = Math_fround($321 - $324);
    $328 = Math_fround($322 - $325);
    $329 = Math_fround($323 - $326);
    HEAPF32[$support3>>2] = $327;
    HEAPF32[$237>>2] = $328;
    HEAPF32[$238>>2] = $329;
    HEAPF32[$239>>2] = Math_fround(0.0);
    $330 = HEAP32[$size>>2]|0;
    $331 = (($330) + 1)|0;
    HEAP32[$size>>2] = $331;
    $332 = (($Q) + ($330<<4)|0);
    ;HEAP32[$332+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$332+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$332+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$332+12>>2]=HEAP32[$support3+12>>2]|0;
    $333 = Math_fround(HEAPF32[$240>>2]);
    $334 = Math_fround(HEAPF32[$241>>2]);
    $335 = $333 > $334;
    $$$i134 = $335 ? $333 : $334;
    $336 = $$$i739803 > $$$i134;
    $$$i = $336 ? $$$i739803 : $$$i134;
    $337 = Math_fround($16 + $$$i);
    $338 = Math_fround($337 * $337);
    $339 = Math_fround($340 * $338);
    $341 = Math_fround(HEAPF32[$v>>2]);
    $342 = Math_fround(HEAPF32[$214>>2]);
    $343 = Math_fround(HEAPF32[$215>>2]);
    $344 = Math_fround($341 * $327);
    $345 = Math_fround($342 * $328);
    $346 = Math_fround($344 + $345);
    $347 = Math_fround($343 * $329);
    $348 = Math_fround($346 + $347);
    $349 = Math_fround($348 * $348);
    $350 = $348 > Math_fround(0.0);
    $351 = $349 > $339;
    if ($350) {
     $phitmp755 = $351 ^ 1;
     $355 = $351;$357 = $phitmp755;
    } else {
     $355 = 0;$357 = 1;
    }
    $352 = Math_fround($340 - $348);
    $353 = Math_fround($23 * $340);
    $354 = $353 >= $352;
    $brmerge$demorgan = $354 | $355;
    if ($brmerge$demorgan) {
     $356 = $357 ^ 1;
     $$747 = $354 | $356;
     if ($$747) {
      break;
     }
    }
    do {
     if ((($330|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$4+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$support3+12>>2]|0;
     } else if ((($330|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($330|0) == 1)) {
      $404 = Math_fround(HEAPF32[$Q>>2]);
      $405 = Math_fround(HEAPF32[$242>>2]);
      $406 = Math_fround(HEAPF32[$243>>2]);
      $407 = Math_fround($327 - $404);
      $408 = Math_fround($328 - $405);
      $409 = Math_fround($329 - $406);
      $410 = Math_fround($407 * $407);
      $411 = Math_fround($408 * $408);
      $412 = Math_fround($410 + $411);
      $413 = Math_fround($409 * $409);
      $414 = Math_fround($412 + $413);
      $415 = $414 == Math_fround(0.0);
      if ($415) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $416 = Math_fround($405 * $408);
       $417 = Math_fround(-$416);
       $418 = Math_fround($404 * $407);
       $419 = Math_fround($417 - $418);
       $420 = Math_fround($406 * $409);
       $421 = Math_fround($419 - $420);
       $422 = Math_fround(HEAPF32[$A>>2]);
       $423 = Math_fround(HEAPF32[$244>>2]);
       $424 = Math_fround(HEAPF32[$245>>2]);
       $425 = Math_fround($321 - $422);
       $426 = Math_fround($322 - $423);
       $427 = Math_fround($323 - $424);
       $428 = Math_fround(HEAPF32[$B>>2]);
       $429 = Math_fround(HEAPF32[$246>>2]);
       $430 = Math_fround(HEAPF32[$247>>2]);
       $431 = Math_fround($324 - $428);
       $432 = Math_fround($325 - $429);
       $433 = Math_fround($326 - $430);
       $434 = Math_fround($421 / $414);
       $435 = $434 > Math_fround(1.0);
       $$$i$i$i = $435 ? Math_fround(1.0) : $434;
       $436 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $436 ? $$$i$i$i : Math_fround(0.0);
       $437 = Math_fround($425 * $$$i8$i$i);
       $438 = Math_fround($426 * $$$i8$i$i);
       $439 = Math_fround($427 * $$$i8$i$i);
       $440 = Math_fround($422 + $437);
       $441 = Math_fround($423 + $438);
       $442 = Math_fround($424 + $439);
       $443 = Math_fround($431 * $$$i8$i$i);
       $444 = Math_fround($432 * $$$i8$i$i);
       $445 = Math_fround($433 * $$$i8$i$i);
       $446 = Math_fround($428 + $443);
       $447 = Math_fround($429 + $444);
       $448 = Math_fround($430 + $445);
       HEAPF32[$closA>>2] = $440;
       HEAPF32[$17>>2] = $441;
       HEAPF32[$18>>2] = $442;
       HEAPF32[$19>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $446;
       HEAPF32[$20>>2] = $447;
       HEAPF32[$21>>2] = $448;
       HEAPF32[$22>>2] = Math_fround(0.0);
       $449 = Math_fround($440 - $446);
       $450 = Math_fround($441 - $447);
       $451 = Math_fround($442 - $448);
       HEAPF32[$4>>2] = $449;
       HEAPF32[$248>>2] = $450;
       HEAPF32[$249>>2] = $451;
       HEAPF32[$250>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($330|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$251,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$4+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$4+12>>2]|0;
    $452 = Math_fround(HEAPF32[$v>>2]);
    $453 = Math_fround(HEAPF32[$214>>2]);
    $454 = Math_fround(HEAPF32[$215>>2]);
    $455 = Math_fround($452 * $452);
    $456 = Math_fround($453 * $453);
    $457 = Math_fround($455 + $456);
    $458 = Math_fround($454 * $454);
    $459 = Math_fround($457 + $458);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1232+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1232+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1232+8>>2]|0;
    $460 = $340 > $459;
    $461 = $459 > $23;
    if (!($461)) {
     label = 37;
     break;
    }
    if (!($460)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre842 = Math_fround(HEAPF32[$17>>2]);
    $$pre843 = Math_fround(HEAPF32[$18>>2]);
    $$pre844 = Math_fround(HEAPF32[$19>>2]);
    $$pre845 = Math_fround(HEAPF32[$closB>>2]);
    $$pre846 = Math_fround(HEAPF32[$20>>2]);
    $$pre847 = Math_fround(HEAPF32[$21>>2]);
    $$pre848 = Math_fround(HEAPF32[$22>>2]);
    $$$i739803 = $$$i;$253 = $452;$255 = $453;$257 = $454;$340 = $459;$476 = $$pre;$477 = $$pre842;$478 = $$pre843;$479 = $$pre844;$480 = $$pre845;$481 = $$pre846;$482 = $$pre847;$483 = $$pre848;
   }
   if ((label|0) == 37) {
    $462 = HEAP32[$size>>2]|0;
    if ($460) {
     $520 = $462;
     break;
    }
    $463 = (($462) + -1)|0;
    $464 = ($aIndices|0)==(0|0);
    if (!($464)) {
     $465 = $463&255;
     HEAP8[$_size>>0] = $465;
     $466 = ($463|0)==(0);
     if (!($466)) {
      $i$01$i29 = 0;
      while(1) {
       $467 = (($aInd) + ($i$01$i29<<2)|0);
       $468 = HEAP32[$467>>2]|0;
       $469 = $468&255;
       $470 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$470>>0] = $469;
       $471 = (($bInd) + ($i$01$i29<<2)|0);
       $472 = HEAP32[$471>>2]|0;
       $473 = $472&255;
       $474 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$474>>0] = $473;
       $475 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($475|0)==($463|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $475;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $476;
    HEAPF32[$17>>2] = $477;
    HEAPF32[$18>>2] = $478;
    HEAPF32[$19>>2] = $479;
    HEAPF32[$closB>>2] = $480;
    HEAPF32[$20>>2] = $481;
    HEAPF32[$21>>2] = $482;
    HEAPF32[$22>>2] = $483;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $484 = Math_fround($476 - $480);
    $485 = Math_fround($477 - $481);
    $486 = Math_fround($478 - $482);
    HEAPF32[$v>>2] = $484;
    $487 = (($v) + 4|0);
    HEAPF32[$487>>2] = $485;
    $488 = (($v) + 8|0);
    HEAPF32[$488>>2] = $486;
    $489 = (($v) + 12|0);
    HEAPF32[$489>>2] = Math_fround(0.0);
    $490 = (Math_fround(Math_sqrt((Math_fround($340)))));
    $491 = Math_fround(Math_fround(1.0) / $490);
    $492 = Math_fround($484 * $491);
    $493 = Math_fround($485 * $491);
    $494 = Math_fround($486 * $491);
    $495 = Math_fround($6 * $492);
    $496 = Math_fround($6 * $493);
    $497 = Math_fround($6 * $494);
    $498 = Math_fround($476 - $495);
    $499 = Math_fround($477 - $496);
    $500 = Math_fround($478 - $497);
    HEAPF32[$contactA>>2] = $498;
    $501 = (($contactA) + 4|0);
    HEAPF32[$501>>2] = $499;
    $502 = (($contactA) + 8|0);
    HEAPF32[$502>>2] = $500;
    $503 = (($contactA) + 12|0);
    HEAPF32[$503>>2] = Math_fround(0.0);
    $504 = Math_fround($8 * $492);
    $505 = Math_fround($8 * $493);
    $506 = Math_fround($8 * $494);
    $507 = Math_fround($504 + $480);
    $508 = Math_fround($505 + $481);
    $509 = Math_fround($506 + $482);
    HEAPF32[$contactB>>2] = $507;
    $510 = (($contactB) + 4|0);
    HEAPF32[$510>>2] = $508;
    $511 = (($contactB) + 8|0);
    HEAPF32[$511>>2] = $509;
    $512 = (($contactB) + 12|0);
    HEAPF32[$512>>2] = Math_fround(0.0);
    $513 = Math_fround($490 - $16);
    HEAPF32[$penetrationDepth>>2] = $513;
    $514 = (($penetrationDepth) + 4|0);
    ;HEAP32[$514+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$514+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$514+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $492;
    $515 = (($normal) + 4|0);
    HEAPF32[$515>>2] = $493;
    $516 = (($normal) + 8|0);
    HEAPF32[$516>>2] = $494;
    $517 = (($normal) + 12|0);
    HEAPF32[$517>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $358 = ($aIndices|0)==(0|0);
   if (!($358)) {
    $359 = $330&255;
    HEAP8[$_size>>0] = $359;
    $360 = ($330|0)==(0);
    if (!($360)) {
     $i$01$i72 = 0;
     while(1) {
      $361 = (($aInd) + ($i$01$i72<<2)|0);
      $362 = HEAP32[$361>>2]|0;
      $363 = $362&255;
      $364 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$364>>0] = $363;
      $365 = (($bInd) + ($i$01$i72<<2)|0);
      $366 = HEAP32[$365>>2]|0;
      $367 = $366&255;
      $368 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$368>>0] = $367;
      $369 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($369|0)==($330|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $369;
      }
     }
    }
   }
   $not$ = $355 ^ 1;
   $$$751 = $357 & $not$;
   if (!($$$751)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $370 = (Math_fround(Math_sqrt((Math_fround($340)))));
   $371 = Math_fround(Math_fround(1.0) / $370);
   $372 = Math_fround($341 * $371);
   $373 = Math_fround($342 * $371);
   $374 = Math_fround($343 * $371);
   $375 = Math_fround(HEAPF32[$closA>>2]);
   $376 = Math_fround(HEAPF32[$17>>2]);
   $377 = Math_fround(HEAPF32[$18>>2]);
   $378 = Math_fround($6 * $372);
   $379 = Math_fround($6 * $373);
   $380 = Math_fround($6 * $374);
   $381 = Math_fround($375 - $378);
   $382 = Math_fround($376 - $379);
   $383 = Math_fround($377 - $380);
   HEAPF32[$contactA>>2] = $381;
   $384 = (($contactA) + 4|0);
   HEAPF32[$384>>2] = $382;
   $385 = (($contactA) + 8|0);
   HEAPF32[$385>>2] = $383;
   $386 = (($contactA) + 12|0);
   HEAPF32[$386>>2] = Math_fround(0.0);
   $387 = Math_fround(HEAPF32[$closB>>2]);
   $388 = Math_fround(HEAPF32[$20>>2]);
   $389 = Math_fround(HEAPF32[$21>>2]);
   $390 = Math_fround($8 * $372);
   $391 = Math_fround($8 * $373);
   $392 = Math_fround($8 * $374);
   $393 = Math_fround($390 + $387);
   $394 = Math_fround($391 + $388);
   $395 = Math_fround($392 + $389);
   HEAPF32[$contactB>>2] = $393;
   $396 = (($contactB) + 4|0);
   HEAPF32[$396>>2] = $394;
   $397 = (($contactB) + 8|0);
   HEAPF32[$397>>2] = $395;
   $398 = (($contactB) + 12|0);
   HEAPF32[$398>>2] = Math_fround(0.0);
   $399 = Math_fround($370 - $16);
   HEAPF32[$penetrationDepth>>2] = $399;
   $400 = (($penetrationDepth) + 4|0);
   ;HEAP32[$400+0>>2]=HEAP32[$$sroa$1234+0>>2]|0;HEAP32[$400+4>>2]=HEAP32[$$sroa$1234+4>>2]|0;HEAP32[$400+8>>2]=HEAP32[$$sroa$1234+8>>2]|0;
   HEAPF32[$normal>>2] = $372;
   $401 = (($normal) + 4|0);
   HEAPF32[$401>>2] = $373;
   $402 = (($normal) + 8|0);
   HEAPF32[$402>>2] = $374;
   $403 = (($normal) + 12|0);
   HEAPF32[$403>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $213 = HEAP32[$size>>2]|0;
   $520 = $213;
  }
 } while(0);
 $518 = ($aIndices|0)==(0|0);
 if (!($518)) {
  $519 = $520&255;
  HEAP8[$_size>>0] = $519;
  $521 = ($520|0)==(0);
  if (!($521)) {
   $i$01$i = 0;
   while(1) {
    $522 = (($aInd) + ($i$01$i<<2)|0);
    $523 = HEAP32[$522>>2]|0;
    $524 = $523&255;
    $525 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$525>>0] = $524;
    $526 = (($bInd) + ($i$01$i<<2)|0);
    $527 = HEAP32[$526>>2]|0;
    $528 = $527&255;
    $529 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$529>>0] = $528;
    $530 = (($i$01$i) + 1)|0;
    $exitcond$i = ($530|0)==($520|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $530;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0;
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + ($indexA<<4)|0) + 96|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = ((($3) + ($indexA<<4)|0) + 100|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($3) + ($indexA<<4)|0) + 104|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($1) + 48|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($1) + 52|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 56|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$1>>2]);
 $17 = Math_fround($5 * $16);
 $18 = (($1) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($7 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (($1) + 32|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($9 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($1) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($5 * $27);
 $29 = (($1) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($7 * $30);
 $32 = Math_fround($28 + $31);
 $33 = (($1) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($9 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($1) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($5 * $38);
 $40 = (($1) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($7 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (($1) + 40|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($9 * $45);
 $47 = Math_fround($43 + $46);
 $48 = Math_fround($11 + $25);
 $49 = Math_fround($13 + $36);
 $50 = Math_fround($15 + $47);
 $51 = (($this) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 200|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + (($indexB*12)|0)|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = ((($54) + (($indexB*12)|0)|0) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = ((($54) + (($indexB*12)|0)|0) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($52) + 96|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($56 * $62);
 $64 = (($52) + 112|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($58 * $65);
 $67 = Math_fround($63 + $66);
 $68 = (($52) + 128|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($60 * $69);
 $71 = Math_fround($67 + $70);
 $72 = (($52) + 100|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($56 * $73);
 $75 = (($52) + 116|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($58 * $76);
 $78 = Math_fround($74 + $77);
 $79 = (($52) + 132|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($60 * $80);
 $82 = Math_fround($78 + $81);
 $83 = (($52) + 104|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($56 * $84);
 $86 = (($52) + 120|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($58 * $87);
 $89 = Math_fround($85 + $88);
 $90 = (($52) + 136|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($60 * $91);
 $93 = Math_fround($89 + $92);
 HEAPF32[$supportA>>2] = $48;
 $94 = (($supportA) + 4|0);
 HEAPF32[$94>>2] = $49;
 $95 = (($supportA) + 8|0);
 HEAPF32[$95>>2] = $50;
 $96 = (($supportA) + 12|0);
 HEAPF32[$96>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $71;
 $97 = (($supportB) + 4|0);
 HEAPF32[$97>>2] = $82;
 $98 = (($supportB) + 8|0);
 HEAPF32[$98>>2] = $93;
 $99 = (($supportB) + 12|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = Math_fround($48 - $71);
 $101 = Math_fround($49 - $82);
 $102 = Math_fround($50 - $93);
 HEAPF32[$support>>2] = $100;
 $103 = (($support) + 4|0);
 HEAPF32[$103>>2] = $101;
 $104 = (($support) + 8|0);
 HEAPF32[$104>>2] = $102;
 $105 = (($support) + 12|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $_sa = 0, $_sb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_sa = sp + 32|0;
 $0 = sp;
 $_sb = sp + 16|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$dir>>2]);
 $4 = (($dir) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($dir) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(-$3);
 $9 = Math_fround(-$5);
 $10 = Math_fround(-$7);
 HEAPF32[$0>>2] = $8;
 $11 = (($0) + 4|0);
 HEAPF32[$11>>2] = $9;
 $12 = (($0) + 8|0);
 HEAPF32[$12>>2] = $10;
 $13 = (($0) + 12|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($this) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($_sa,$2,$0,$15);
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($_sb,$17,$dir);
 ;HEAP32[$supportA+0>>2]=HEAP32[$_sa+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$_sa+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$_sa+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$_sa+12>>2]|0;
 ;HEAP32[$supportB+0>>2]=HEAP32[$_sb+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$_sb+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$_sb+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$_sb+12>>2]|0;
 $18 = Math_fround(HEAPF32[$_sa>>2]);
 $19 = (($_sa) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($_sa) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround(HEAPF32[$_sb>>2]);
 $24 = (($_sb) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($_sb) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($18 - $23);
 $29 = Math_fround($20 - $25);
 $30 = Math_fround($22 - $27);
 HEAPF32[$support>>2] = $28;
 $31 = (($support) + 4|0);
 HEAPF32[$31>>2] = $29;
 $32 = (($support) + 8|0);
 HEAPF32[$32>>2] = $30;
 $33 = (($support) + 12|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($agg$result,$this,$dir,$aToB) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 $aToB = $aToB|0;
 var $$in1$i$i = 0, $$in1$i19$i = 0, $$in2$i$i = 0, $$in2$i21$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $13 = Math_fround(0), $14 = Math_fround(0);
 var $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0);
 var $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $b$a$i16$i = 0, $phitmp164$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$aToB>>2]);
 $10 = Math_fround($4 * $9);
 $11 = (($aToB) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($6 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($aToB) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($8 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($aToB) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($4 * $20);
 $22 = (($aToB) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($6 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($aToB) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($8 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($aToB) + 32|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($4 * $31);
 $33 = (($aToB) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($6 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($aToB) + 40|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($8 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($this) + 96|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 100|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($this) + 104|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($this) + 108|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($this) + 112|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($this) + 116|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($this) + 120|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($this) + 124|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($this) + 128|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($this) + 132|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($this) + 136|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($this) + 140|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($18 * $42);
 $66 = Math_fround($29 * $44);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($40 * $46);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround($18 * $50);
 $71 = Math_fround($29 * $52);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($40 * $54);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($18 * $58);
 $76 = Math_fround($29 * $60);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($40 * $62);
 $79 = Math_fround($77 + $78);
 $80 = $69 > $74;
 if ($80) {
  $81 = $69 > $79;
  $phitmp164$i = $81 ? $3 : $2;
  $99 = $phitmp164$i;
 } else {
  $99 = $2;
 }
 $82 = $74 > $79;
 HEAPF32[$1>>2] = $50;
 $83 = (($1) + 4|0);
 HEAPF32[$83>>2] = $52;
 $84 = (($1) + 8|0);
 HEAPF32[$84>>2] = $54;
 $85 = (($1) + 12|0);
 HEAPF32[$85>>2] = $56;
 HEAPF32[$0>>2] = $58;
 $86 = (($0) + 4|0);
 HEAPF32[$86>>2] = $60;
 $87 = (($0) + 8|0);
 HEAPF32[$87>>2] = $62;
 $88 = (($0) + 12|0);
 HEAPF32[$88>>2] = $64;
 $b$a$i16$i = $82 ? $1 : $0;
 $89 = Math_fround(HEAPF32[$b$a$i16$i>>2]);
 $$in1$i19$i = (($b$a$i16$i) + 4|0);
 $90 = Math_fround(HEAPF32[$$in1$i19$i>>2]);
 $$in2$i21$i = (($b$a$i16$i) + 8|0);
 $91 = Math_fround(HEAPF32[$$in2$i21$i>>2]);
 HEAPF32[$3>>2] = $42;
 $92 = (($3) + 4|0);
 HEAPF32[$92>>2] = $44;
 $93 = (($3) + 8|0);
 HEAPF32[$93>>2] = $46;
 $94 = (($3) + 12|0);
 HEAPF32[$94>>2] = $48;
 HEAPF32[$2>>2] = $89;
 $95 = (($2) + 4|0);
 HEAPF32[$95>>2] = $90;
 $96 = (($2) + 8|0);
 HEAPF32[$96>>2] = $91;
 $97 = (($2) + 12|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 $98 = Math_fround(HEAPF32[$99>>2]);
 $$in1$i$i = (($99) + 4|0);
 $100 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $$in2$i$i = (($99) + 8|0);
 $101 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $102 = (($aToB) + 48|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($aToB) + 52|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($aToB) + 56|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($98 * $9);
 $109 = Math_fround($100 * $20);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($101 * $31);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround($98 * $12);
 $114 = Math_fround($100 * $23);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($101 * $34);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($98 * $16);
 $119 = Math_fround($100 * $27);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($101 * $38);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($103 + $112);
 $124 = Math_fround($105 + $117);
 $125 = Math_fround($107 + $122);
 HEAPF32[$agg$result>>2] = $123;
 $126 = (($agg$result) + 4|0);
 HEAPF32[$126>>2] = $124;
 $127 = (($agg$result) + 8|0);
 HEAPF32[$127>>2] = $125;
 $128 = (($agg$result) + 12|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_9TriangleVENS0_8CapsuleVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i141 = 0, $$in1$i$i$i183 = 0, $$in1$i198 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i142 = 0, $$in2$i$i$i184 = 0, $$in2$i200 = 0, $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa900 = Math_fround(0);
 var $$lcssa902 = Math_fround(0), $$lcssa904 = Math_fround(0), $$lcssa906 = Math_fround(0), $$lcssa908 = 0, $$lcssa910 = Math_fround(0), $$lcssa912 = Math_fround(0), $$lcssa914 = Math_fround(0), $$sroa$1324 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0);
 var $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0);
 var $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0);
 var $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0);
 var $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0);
 var $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0);
 var $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0);
 var $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0);
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0);
 var $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0);
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0);
 var $433 = Math_fround(0), $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = 0, $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0);
 var $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $b$a$i = 0, $b$a$i$i$i = 0, $b$a$i$i$i139 = 0, $b$a$i$i$i181 = 0, $b$a$i18 = 0, $b$a$i195 = 0, $b$a5$i = 0, $closA = 0, $closAA = 0, $closB = 0;
 var $initialSupportA = 0, $phitmp = 0, $phitmp893 = 0, $size = 0, $support = 0, $tempV = 0, $vNorm = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 336|0;
 $1 = sp + 432|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $4 = sp + 384|0;
 $5 = sp + 496|0;
 $6 = sp + 400|0;
 $7 = sp + 416|0;
 $8 = sp + 448|0;
 $9 = sp + 464|0;
 $zeroV = sp + 480|0;
 $zero$sroa$1 = sp + 528|0;
 $_lambda$sroa$1 = sp + 540|0;
 $size = sp + 524|0;
 $initialSupportA = sp + 208|0;
 $10 = sp;
 $Q = sp + 16|0;
 $A = sp + 80|0;
 $B = sp + 144|0;
 $support = sp + 224|0;
 $closA = sp + 240|0;
 $closB = sp + 256|0;
 $closAA = sp + 272|0;
 $vNorm = sp + 288|0;
 $11 = sp + 304|0;
 $$sroa$1324 = sp + 512|0;
 $tempV = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $12 = Math_fround(HEAPF32[$r>>2]);
 $13 = (($r) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($r) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$s>>2]);
 $18 = (($s) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($s) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAP32[$size>>2] = 1;
 $22 = (($aToB) + 48|0);
 $23 = (($aToB) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($aToB) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($24 * $24);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($28 * $28);
 $33 = Math_fround($31 + $32);
 $34 = $33 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$22+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $35 = (($0) + 4|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($0) + 8|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($0) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $b$a$i195 = $34 ? $1 : $0;
 $38 = Math_fround(HEAPF32[$b$a$i195>>2]);
 $$in1$i198 = (($b$a$i195) + 4|0);
 $39 = Math_fround(HEAPF32[$$in1$i198>>2]);
 $$in2$i200 = (($b$a$i195) + 8|0);
 $40 = Math_fround(HEAPF32[$$in2$i200>>2]);
 $41 = Math_fround($38 * $38);
 $42 = Math_fround($39 * $39);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($40 * $40);
 $45 = Math_fround($43 + $44);
 $46 = (Math_fround(Math_sqrt((Math_fround($45)))));
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = Math_fround($38 * $47);
 $49 = Math_fround($39 * $47);
 $50 = Math_fround($40 * $47);
 $51 = Math_fround(-$48);
 $52 = Math_fround(-$49);
 $53 = Math_fround(-$50);
 HEAPF32[$10>>2] = $51;
 $54 = (($10) + 4|0);
 HEAPF32[$54>>2] = $52;
 $55 = (($10) + 8|0);
 HEAPF32[$55>>2] = $53;
 $56 = (($10) + 12|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($initialSupportA,$a,$10,$aToB);
 $57 = (($b) + 96|0);
 $58 = (($b) + 96|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($b) + 100|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($b) + 104|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($48 * $59);
 $65 = Math_fround($49 * $61);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($50 * $63);
 $68 = Math_fround($66 + $67);
 $69 = (($b) + 112|0);
 $70 = (($b) + 112|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($b) + 116|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($b) + 120|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($48 * $71);
 $77 = Math_fround($49 * $73);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($50 * $75);
 $80 = Math_fround($78 + $79);
 $81 = $68 > $80;
 ;HEAP32[$3+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$57+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$57+12>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$69+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$69+12>>2]|0;
 $b$a$i$i$i181 = $81 ? $3 : $2;
 $82 = Math_fround(HEAPF32[$b$a$i$i$i181>>2]);
 $$in1$i$i$i183 = (($b$a$i$i$i181) + 4|0);
 $83 = Math_fround(HEAPF32[$$in1$i$i$i183>>2]);
 $$in2$i$i$i184 = (($b$a$i$i$i181) + 8|0);
 $84 = Math_fround(HEAPF32[$$in2$i$i$i184>>2]);
 $85 = Math_fround(HEAPF32[$initialSupportA>>2]);
 $86 = (($initialSupportA) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($initialSupportA) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($85 - $82);
 $91 = Math_fround($87 - $83);
 $92 = Math_fround($89 - $84);
 HEAPF32[$Q>>2] = $90;
 $93 = (($Q) + 4|0);
 HEAPF32[$93>>2] = $91;
 $94 = (($Q) + 8|0);
 HEAPF32[$94>>2] = $92;
 $95 = (($Q) + 12|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($Q) + 16|0);
 ;HEAP32[$96+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$96+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$96+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$96+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $97 = (($Q) + 32|0);
 ;HEAP32[$97+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$97+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $98 = (($Q) + 48|0);
 ;HEAP32[$98+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$98+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$A+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$A+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$A+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$A+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 $99 = (($A) + 16|0);
 ;HEAP32[$99+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $100 = (($A) + 32|0);
 ;HEAP32[$100+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$100+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$100+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$100+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $101 = (($A) + 48|0);
 ;HEAP32[$101+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$101+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$101+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$101+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$B>>2] = $82;
 $102 = (($B) + 4|0);
 HEAPF32[$102>>2] = $83;
 $103 = (($B) + 8|0);
 HEAPF32[$103>>2] = $84;
 $104 = (($B) + 12|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($B) + 16|0);
 ;HEAP32[$105+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$105+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$105+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$105+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $106 = (($B) + 32|0);
 ;HEAP32[$106+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $107 = (($B) + 48|0);
 ;HEAP32[$107+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$107+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$107+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$107+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $108 = Math_fround(-$90);
 $109 = Math_fround(-$91);
 $110 = Math_fround(-$92);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $111 = (($a) + 32|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($b) + 32|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = $112 > $114;
 $$$i = $115 ? $114 : $112;
 $116 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $117 = Math_fround($116 * $116);
 $118 = Math_fround($_inflation * $_inflation);
 $119 = Math_fround($118 + $117);
 ;HEAP32[$closA+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 HEAPF32[$closB>>2] = $82;
 $120 = (($closB) + 4|0);
 HEAPF32[$120>>2] = $83;
 $121 = (($closB) + 8|0);
 HEAPF32[$121>>2] = $84;
 $122 = (($closB) + 12|0);
 HEAPF32[$122>>2] = Math_fround(0.0);
 $123 = Math_fround($90 * $90);
 $124 = Math_fround($91 * $91);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($92 * $92);
 $127 = Math_fround($125 + $126);
 ;HEAP32[$closAA+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 $128 = $127 > $117;
 L1: do {
  if ($128) {
   $129 = Math_fround($16 * Math_fround(0.0));
   $130 = Math_fround($14 * Math_fround(0.0));
   $131 = Math_fround($12 * Math_fround(0.0));
   $132 = Math_fround($129 + $21);
   $133 = Math_fround($130 + $19);
   $134 = Math_fround($131 + $17);
   $135 = (($vNorm) + 4|0);
   $136 = (($vNorm) + 8|0);
   $137 = (($vNorm) + 12|0);
   $138 = (($11) + 4|0);
   $139 = (($11) + 8|0);
   $140 = (($11) + 12|0);
   $141 = (($support) + 4|0);
   $142 = (($support) + 8|0);
   $143 = (($support) + 12|0);
   $144 = (($B) + 16|0);
   $145 = (($B) + 20|0);
   $146 = (($B) + 24|0);
   $147 = (($B) + 28|0);
   $148 = (($B) + 32|0);
   $149 = (($B) + 36|0);
   $150 = (($B) + 40|0);
   $151 = (($B) + 44|0);
   $152 = (($A) + 4|0);
   $153 = (($A) + 8|0);
   $154 = (($A) + 16|0);
   $155 = (($A) + 20|0);
   $156 = (($A) + 24|0);
   $157 = (($Q) + 16|0);
   $158 = (($Q) + 20|0);
   $159 = (($Q) + 24|0);
   $160 = (($Q) + 28|0);
   $161 = (($A) + 32|0);
   $162 = (($A) + 36|0);
   $163 = (($A) + 40|0);
   $164 = (($Q) + 32|0);
   $165 = (($Q) + 36|0);
   $166 = (($Q) + 40|0);
   $167 = (($Q) + 44|0);
   $168 = (($tempV) + 4|0);
   $169 = (($tempV) + 8|0);
   $170 = (($closA) + 4|0);
   $171 = (($closA) + 8|0);
   $172 = (($closA) + 12|0);
   $173 = (($tempV) + 12|0);
   $175 = $108;$177 = $109;$180 = $110;$215 = $134;$217 = $133;$219 = $132;$245 = Math_fround(0.0);$446 = $108;$447 = $109;$448 = $110;$449 = $127;
   while(1) {
    ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
    $174 = Math_fround($175 * $175);
    $176 = Math_fround($177 * $177);
    $178 = Math_fround($176 + $174);
    $179 = Math_fround($180 * $180);
    $181 = Math_fround($179 + $178);
    $182 = (Math_fround(Math_sqrt((Math_fround($181)))));
    $183 = Math_fround(Math_fround(1.0) / $182);
    $184 = Math_fround($175 * $183);
    $185 = Math_fround($177 * $183);
    $186 = Math_fround($180 * $183);
    HEAPF32[$vNorm>>2] = $184;
    HEAPF32[$135>>2] = $185;
    HEAPF32[$136>>2] = $186;
    HEAPF32[$137>>2] = Math_fround(0.0);
    $187 = Math_fround(-$184);
    $188 = Math_fround(-$185);
    $189 = Math_fround(-$186);
    __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($11,$a,$vNorm,$aToB);
    $190 = Math_fround(HEAPF32[$11>>2]);
    $191 = Math_fround(HEAPF32[$138>>2]);
    $192 = Math_fround(HEAPF32[$139>>2]);
    $193 = Math_fround(HEAPF32[$140>>2]);
    $194 = Math_fround(HEAPF32[$58>>2]);
    $195 = Math_fround(HEAPF32[$60>>2]);
    $196 = Math_fround(HEAPF32[$62>>2]);
    $197 = Math_fround($194 * $187);
    $198 = Math_fround($195 * $188);
    $199 = Math_fround($197 + $198);
    $200 = Math_fround($196 * $189);
    $201 = Math_fround($199 + $200);
    $202 = Math_fround(HEAPF32[$70>>2]);
    $203 = Math_fround(HEAPF32[$72>>2]);
    $204 = Math_fround(HEAPF32[$74>>2]);
    $205 = Math_fround($202 * $187);
    $206 = Math_fround($203 * $188);
    $207 = Math_fround($205 + $206);
    $208 = Math_fround($204 * $189);
    $209 = Math_fround($207 + $208);
    $210 = $201 > $209;
    ;HEAP32[$3+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$57+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$57+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$69+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$69+12>>2]|0;
    $b$a$i$i$i139 = $210 ? $3 : $2;
    $211 = Math_fround(HEAPF32[$b$a$i$i$i139>>2]);
    $$in1$i$i$i141 = (($b$a$i$i$i139) + 4|0);
    $212 = Math_fround(HEAPF32[$$in1$i$i$i141>>2]);
    $$in2$i$i$i142 = (($b$a$i$i$i139) + 8|0);
    $213 = Math_fround(HEAPF32[$$in2$i$i$i142>>2]);
    $214 = Math_fround($215 + $211);
    $216 = Math_fround($217 + $212);
    $218 = Math_fround($219 + $213);
    $220 = Math_fround($190 - $214);
    $221 = Math_fround($191 - $216);
    $222 = Math_fround($192 - $218);
    HEAPF32[$support>>2] = $220;
    HEAPF32[$141>>2] = $221;
    HEAPF32[$142>>2] = $222;
    HEAPF32[$143>>2] = Math_fround(0.0);
    $223 = Math_fround(HEAPF32[$vNorm>>2]);
    $224 = Math_fround(HEAPF32[$135>>2]);
    $225 = Math_fround(HEAPF32[$136>>2]);
    $226 = Math_fround($220 * $223);
    $227 = Math_fround($221 * $224);
    $228 = Math_fround(-$227);
    $229 = Math_fround($228 - $226);
    $230 = Math_fround($222 * $225);
    $231 = Math_fround($229 - $230);
    $232 = Math_fround($231 - $_inflation);
    $233 = Math_fround(HEAPF32[$r>>2]);
    $234 = Math_fround(HEAPF32[$13>>2]);
    $235 = Math_fround(HEAPF32[$15>>2]);
    $236 = Math_fround($223 * $233);
    $237 = Math_fround($224 * $234);
    $238 = Math_fround($236 + $237);
    $239 = Math_fround($225 * $235);
    $240 = Math_fround($238 + $239);
    $241 = $232 > Math_fround(0.0);
    if ($241) {
     $242 = !($240 >= Math_fround(0.0));
     if (!($242)) {
      $$0 = 0;
      label = 21;
      break;
     }
     $243 = Math_fround($232 / $240);
     $244 = Math_fround($245 - $243);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1324+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1324+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1324+8>>2]|0;
     $246 = $244 > $245;
     if ($246) {
      $247 = $244 > Math_fround(1.0);
      if ($247) {
       $$0 = 0;
       label = 21;
       break;
      }
      $248 = Math_fround(HEAPF32[$s>>2]);
      $249 = Math_fround(HEAPF32[$18>>2]);
      $250 = Math_fround(HEAPF32[$20>>2]);
      $251 = Math_fround($244 * $233);
      $252 = Math_fround($244 * $234);
      $253 = Math_fround($244 * $235);
      $254 = Math_fround($251 + $248);
      $255 = Math_fround($252 + $249);
      $256 = Math_fround($253 + $250);
      $257 = Math_fround($254 - $215);
      $258 = Math_fround($255 - $217);
      $259 = Math_fround($256 - $219);
      $260 = Math_fround(HEAPF32[$B>>2]);
      $261 = Math_fround(HEAPF32[$102>>2]);
      $262 = Math_fround(HEAPF32[$103>>2]);
      $263 = Math_fround($257 + $260);
      $264 = Math_fround($258 + $261);
      $265 = Math_fround($259 + $262);
      $266 = Math_fround(HEAPF32[$144>>2]);
      $267 = Math_fround(HEAPF32[$145>>2]);
      $268 = Math_fround(HEAPF32[$146>>2]);
      $269 = Math_fround($257 + $266);
      $270 = Math_fround($258 + $267);
      $271 = Math_fround($259 + $268);
      $272 = Math_fround(HEAPF32[$148>>2]);
      $273 = Math_fround(HEAPF32[$149>>2]);
      $274 = Math_fround(HEAPF32[$150>>2]);
      $275 = Math_fround($257 + $272);
      $276 = Math_fround($258 + $273);
      $277 = Math_fround($259 + $274);
      HEAPF32[$B>>2] = $263;
      HEAPF32[$102>>2] = $264;
      HEAPF32[$103>>2] = $265;
      HEAPF32[$104>>2] = Math_fround(0.0);
      HEAPF32[$144>>2] = $269;
      HEAPF32[$145>>2] = $270;
      HEAPF32[$146>>2] = $271;
      HEAPF32[$147>>2] = Math_fround(0.0);
      HEAPF32[$148>>2] = $275;
      HEAPF32[$149>>2] = $276;
      HEAPF32[$150>>2] = $277;
      HEAPF32[$151>>2] = Math_fround(0.0);
      $278 = Math_fround(HEAPF32[$A>>2]);
      $279 = Math_fround(HEAPF32[$152>>2]);
      $280 = Math_fround(HEAPF32[$153>>2]);
      $281 = Math_fround($278 - $263);
      $282 = Math_fround($279 - $264);
      $283 = Math_fround($280 - $265);
      HEAPF32[$Q>>2] = $281;
      HEAPF32[$93>>2] = $282;
      HEAPF32[$94>>2] = $283;
      HEAPF32[$95>>2] = Math_fround(0.0);
      $284 = Math_fround(HEAPF32[$154>>2]);
      $285 = Math_fround(HEAPF32[$155>>2]);
      $286 = Math_fround(HEAPF32[$156>>2]);
      $287 = Math_fround($284 - $269);
      $288 = Math_fround($285 - $270);
      $289 = Math_fround($286 - $271);
      HEAPF32[$157>>2] = $287;
      HEAPF32[$158>>2] = $288;
      HEAPF32[$159>>2] = $289;
      HEAPF32[$160>>2] = Math_fround(0.0);
      $290 = Math_fround(HEAPF32[$161>>2]);
      $291 = Math_fround(HEAPF32[$162>>2]);
      $292 = Math_fround(HEAPF32[$163>>2]);
      $293 = Math_fround($290 - $275);
      $294 = Math_fround($291 - $276);
      $295 = Math_fround($292 - $277);
      HEAPF32[$164>>2] = $293;
      HEAPF32[$165>>2] = $294;
      HEAPF32[$166>>2] = $295;
      HEAPF32[$167>>2] = Math_fround(0.0);
      ;HEAP32[$3+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$57+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$57+12>>2]|0;
      ;HEAP32[$2+0>>2]=HEAP32[$69+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$69+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$69+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$69+12>>2]|0;
      $b$a$i$i$i = $210 ? $3 : $2;
      $296 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
      $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
      $297 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
      $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
      $298 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
      $299 = Math_fround($254 + $296);
      $300 = Math_fround($255 + $297);
      $301 = Math_fround($256 + $298);
      $302 = Math_fround($190 - $299);
      $303 = Math_fround($191 - $300);
      $304 = Math_fround($192 - $301);
      HEAPF32[$support>>2] = $302;
      HEAPF32[$141>>2] = $303;
      HEAPF32[$142>>2] = $304;
      HEAPF32[$143>>2] = Math_fround(0.0);
      $311 = $299;$313 = $300;$315 = $301;$323 = $302;$325 = $303;$327 = $304;$382 = Math_fround(3.40282346638528859812E+38);$450 = $244;$451 = $256;$452 = $255;$453 = $254;$454 = $180;$455 = $177;$456 = $175;
     } else {
      $311 = $214;$313 = $216;$315 = $218;$323 = $220;$325 = $221;$327 = $222;$382 = $449;$450 = $244;$451 = $219;$452 = $217;$453 = $215;$454 = $448;$455 = $447;$456 = $446;
     }
    } else {
     $311 = $214;$313 = $216;$315 = $218;$323 = $220;$325 = $221;$327 = $222;$382 = $449;$450 = $245;$451 = $219;$452 = $217;$453 = $215;$454 = $448;$455 = $447;$456 = $446;
    }
    $305 = HEAP32[$size>>2]|0;
    $306 = (($A) + ($305<<4)|0);
    HEAPF32[$306>>2] = $190;
    $307 = ((($A) + ($305<<4)|0) + 4|0);
    HEAPF32[$307>>2] = $191;
    $308 = ((($A) + ($305<<4)|0) + 8|0);
    HEAPF32[$308>>2] = $192;
    $309 = ((($A) + ($305<<4)|0) + 12|0);
    HEAPF32[$309>>2] = $193;
    $310 = (($B) + ($305<<4)|0);
    HEAPF32[$310>>2] = $311;
    $312 = ((($B) + ($305<<4)|0) + 4|0);
    HEAPF32[$312>>2] = $313;
    $314 = ((($B) + ($305<<4)|0) + 8|0);
    HEAPF32[$314>>2] = $315;
    $316 = ((($B) + ($305<<4)|0) + 12|0);
    HEAPF32[$316>>2] = Math_fround(0.0);
    $317 = (($305) + 1)|0;
    HEAP32[$size>>2] = $317;
    $318 = (($Q) + ($305<<4)|0);
    ;HEAP32[$318+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$318+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$318+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$318+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($305|0) == 1)) {
      $319 = Math_fround(HEAPF32[$Q>>2]);
      $320 = Math_fround(HEAPF32[$93>>2]);
      $321 = Math_fround(HEAPF32[$94>>2]);
      $322 = Math_fround($323 - $319);
      $324 = Math_fround($325 - $320);
      $326 = Math_fround($327 - $321);
      $328 = Math_fround($322 * $322);
      $329 = Math_fround($324 * $324);
      $330 = Math_fround($328 + $329);
      $331 = Math_fround($326 * $326);
      $332 = Math_fround($330 + $331);
      $333 = $332 == Math_fround(0.0);
      if ($333) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $334 = Math_fround($320 * $324);
       $335 = Math_fround(-$334);
       $336 = Math_fround($319 * $322);
       $337 = Math_fround($335 - $336);
       $338 = Math_fround($321 * $326);
       $339 = Math_fround($337 - $338);
       $340 = Math_fround(HEAPF32[$A>>2]);
       $341 = Math_fround(HEAPF32[$152>>2]);
       $342 = Math_fround(HEAPF32[$153>>2]);
       $343 = Math_fround($190 - $340);
       $344 = Math_fround($191 - $341);
       $345 = Math_fround($192 - $342);
       $346 = Math_fround(HEAPF32[$B>>2]);
       $347 = Math_fround(HEAPF32[$102>>2]);
       $348 = Math_fround(HEAPF32[$103>>2]);
       $349 = Math_fround($311 - $346);
       $350 = Math_fround($313 - $347);
       $351 = Math_fround($315 - $348);
       $352 = Math_fround($339 / $332);
       $353 = $352 > Math_fround(1.0);
       $$$i$i$i = $353 ? Math_fround(1.0) : $352;
       $354 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $354 ? $$$i$i$i : Math_fround(0.0);
       $355 = Math_fround($343 * $$$i8$i$i);
       $356 = Math_fround($344 * $$$i8$i$i);
       $357 = Math_fround($345 * $$$i8$i$i);
       $358 = Math_fround($340 + $355);
       $359 = Math_fround($341 + $356);
       $360 = Math_fround($342 + $357);
       $361 = Math_fround($349 * $$$i8$i$i);
       $362 = Math_fround($350 * $$$i8$i$i);
       $363 = Math_fround($351 * $$$i8$i$i);
       $364 = Math_fround($346 + $361);
       $365 = Math_fround($347 + $362);
       $366 = Math_fround($348 + $363);
       HEAPF32[$closA>>2] = $358;
       HEAPF32[$170>>2] = $359;
       HEAPF32[$171>>2] = $360;
       HEAPF32[$172>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $364;
       HEAPF32[$120>>2] = $365;
       HEAPF32[$121>>2] = $366;
       HEAPF32[$122>>2] = Math_fround(0.0);
       $367 = Math_fround($358 - $364);
       $368 = Math_fround($359 - $365);
       $369 = Math_fround($360 - $366);
       HEAPF32[$tempV>>2] = $367;
       HEAPF32[$168>>2] = $368;
       HEAPF32[$169>>2] = $369;
       HEAPF32[$173>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($305|0) == 0)) {
      HEAPF32[$closA>>2] = $190;
      HEAPF32[$170>>2] = $191;
      HEAPF32[$171>>2] = $192;
      HEAPF32[$172>>2] = $193;
      HEAPF32[$closB>>2] = $311;
      HEAPF32[$120>>2] = $313;
      HEAPF32[$121>>2] = $315;
      HEAPF32[$122>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($305|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($305|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$96,$support,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $370 = Math_fround(HEAPF32[$tempV>>2]);
    $371 = Math_fround(HEAPF32[$168>>2]);
    $372 = Math_fround(HEAPF32[$169>>2]);
    $373 = Math_fround(-$370);
    $374 = Math_fround(-$371);
    $375 = Math_fround(-$372);
    $376 = Math_fround($370 * $370);
    $377 = Math_fround($371 * $371);
    $378 = Math_fround($376 + $377);
    $379 = Math_fround($372 * $372);
    $380 = Math_fround($378 + $379);
    $381 = $382 > $380;
    $383 = $381 << 31 >> 31;
    $384 = $380 > $119;
    if (!($384)) {
     $$lcssa = $450;$$lcssa900 = $375;$$lcssa902 = $374;$$lcssa904 = $373;$$lcssa906 = $380;$$lcssa908 = $383;$$lcssa910 = $454;$$lcssa912 = $455;$$lcssa914 = $456;
     break L1;
    }
    if ($381) {
     $175 = $373;$177 = $374;$180 = $375;$215 = $453;$217 = $452;$219 = $451;$245 = $450;$446 = $456;$447 = $455;$448 = $454;$449 = $380;
    } else {
     $$lcssa = $450;$$lcssa900 = $375;$$lcssa902 = $374;$$lcssa904 = $373;$$lcssa906 = $380;$$lcssa908 = $383;$$lcssa910 = $454;$$lcssa912 = $455;$$lcssa914 = $456;
     break L1;
    }
   }
   if ((label|0) == 21) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa900 = $110;$$lcssa902 = $109;$$lcssa904 = $108;$$lcssa906 = $127;$$lcssa908 = -1;$$lcssa910 = $110;$$lcssa912 = $109;$$lcssa914 = $108;
  }
 } while(0);
 $385 = (($a) + 64|0);
 $386 = HEAP32[$385>>2]|0;
 $387 = (($a) + 68|0);
 $388 = HEAP32[$387>>2]|0;
 $389 = (($a) + 72|0);
 $390 = HEAP32[$389>>2]|0;
 $391 = $$lcssa906 > $117;
 if ($391) {
  $phitmp = ($$lcssa908|0)==(0);
  $phitmp893 = $phitmp ? $4 : $5;
  $399 = $phitmp893;
 } else {
  $399 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa904;
 $392 = (($5) + 4|0);
 HEAPF32[$392>>2] = $$lcssa902;
 $393 = (($5) + 8|0);
 HEAPF32[$393>>2] = $$lcssa900;
 $394 = (($5) + 12|0);
 HEAPF32[$394>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa914;
 $395 = (($4) + 4|0);
 HEAPF32[$395>>2] = $$lcssa912;
 $396 = (($4) + 8|0);
 HEAPF32[$396>>2] = $$lcssa910;
 $397 = (($4) + 12|0);
 HEAPF32[$397>>2] = Math_fround(0.0);
 $398 = Math_fround(HEAPF32[$399>>2]);
 $$in1$i37 = (($399) + 4|0);
 $400 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($399) + 8|0);
 $401 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $402 = Math_fround($398 * $398);
 $403 = Math_fround($400 * $400);
 $404 = Math_fround($402 + $403);
 $405 = Math_fround($401 * $401);
 $406 = Math_fround($404 + $405);
 $407 = (Math_fround(Math_sqrt((Math_fround($406)))));
 $408 = Math_fround(Math_fround(1.0) / $407);
 $409 = Math_fround($398 * $408);
 $410 = Math_fround($400 * $408);
 $411 = Math_fround($401 * $408);
 $412 = Math_fround(-$409);
 $413 = Math_fround(-$410);
 $414 = Math_fround(-$411);
 HEAPF32[$normal>>2] = $412;
 $415 = (($normal) + 4|0);
 HEAPF32[$415>>2] = $413;
 $416 = (($normal) + 8|0);
 HEAPF32[$416>>2] = $414;
 $417 = (($normal) + 12|0);
 HEAPF32[$417>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $418 = (($lambda) + 4|0);
 ;HEAP32[$418+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$418+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$418+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$6+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$closAA+12>>2]|0;
 $419 = ($$lcssa908|0)==(0);
 $b$a$i18 = $419 ? $6 : $7;
 $420 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $421 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $422 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $420;
 $423 = (($closA) + 4|0);
 HEAPF32[$423>>2] = $421;
 $424 = (($closA) + 8|0);
 HEAPF32[$424>>2] = $422;
 $425 = (($closA) + 12|0);
 HEAPF32[$425>>2] = Math_fround(0.0);
 $426 = (($a) + 16|0);
 $427 = Math_fround(HEAPF32[$426>>2]);
 $428 = Math_fround($427 * $412);
 $429 = Math_fround($427 * $413);
 $430 = Math_fround($427 * $414);
 $431 = Math_fround($420 - $428);
 $432 = Math_fround($421 - $429);
 $433 = Math_fround($422 - $430);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $431;
 $434 = (($9) + 4|0);
 HEAPF32[$434>>2] = $432;
 $435 = (($9) + 8|0);
 HEAPF32[$435>>2] = $433;
 $436 = (($9) + 12|0);
 HEAPF32[$436>>2] = Math_fround(0.0);
 $437 = ($386|0)==(0);
 $b$a$i = $437 ? $8 : $9;
 $438 = Math_fround(HEAPF32[$b$a$i>>2]);
 $439 = ($388|0)==(0);
 $a$pn3$i = $439 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $440 = Math_fround(HEAPF32[$$in1$i>>2]);
 $441 = ($390|0)==(0);
 $b$a5$i = $441 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $442 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $438;
 $443 = (($closestA) + 4|0);
 HEAPF32[$443>>2] = $440;
 $444 = (($closestA) + 8|0);
 HEAPF32[$444>>2] = $442;
 $445 = (($closestA) + 12|0);
 HEAPF32[$445>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + ($indexA<<4)|0) + 96|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = ((($3) + ($indexA<<4)|0) + 100|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($3) + ($indexA<<4)|0) + 104|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($1) + 48|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($1) + 52|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 56|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$1>>2]);
 $17 = Math_fround($5 * $16);
 $18 = (($1) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($7 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (($1) + 32|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($9 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($1) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($5 * $27);
 $29 = (($1) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($7 * $30);
 $32 = Math_fround($28 + $31);
 $33 = (($1) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($9 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($1) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($5 * $38);
 $40 = (($1) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($7 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (($1) + 40|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($9 * $45);
 $47 = Math_fround($43 + $46);
 $48 = Math_fround($11 + $25);
 $49 = Math_fround($13 + $36);
 $50 = Math_fround($15 + $47);
 $51 = (($this) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (1 - ($indexB))|0;
 $54 = (($52) + 96|0);
 $55 = (($54) + ($53<<4)|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = ((($54) + ($53<<4)|0) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = ((($54) + ($53<<4)|0) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = ((($54) + ($53<<4)|0) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 HEAPF32[$supportA>>2] = $48;
 $63 = (($supportA) + 4|0);
 HEAPF32[$63>>2] = $49;
 $64 = (($supportA) + 8|0);
 HEAPF32[$64>>2] = $50;
 $65 = (($supportA) + 12|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $56;
 $66 = (($supportB) + 4|0);
 HEAPF32[$66>>2] = $58;
 $67 = (($supportB) + 8|0);
 HEAPF32[$67>>2] = $60;
 $68 = (($supportB) + 12|0);
 HEAPF32[$68>>2] = $62;
 $69 = Math_fround($48 - $56);
 $70 = Math_fround($49 - $58);
 $71 = Math_fround($50 - $60);
 HEAPF32[$support>>2] = $69;
 $72 = (($support) + 4|0);
 HEAPF32[$72>>2] = $70;
 $73 = (($support) + 8|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($support) + 12|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $_sa = 0, $b$a$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $_sa = sp + 16|0;
 $2 = sp + 32|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$dir>>2]);
 $6 = (($dir) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($dir) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(-$5);
 $11 = Math_fround(-$7);
 $12 = Math_fround(-$9);
 HEAPF32[$2>>2] = $10;
 $13 = (($2) + 4|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($2) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($2) + 12|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($_sa,$4,$2,$17);
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 96|0);
 $21 = (($19) + 96|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($19) + 100|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($19) + 104|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(HEAPF32[$dir>>2]);
 $28 = Math_fround(HEAPF32[$6>>2]);
 $29 = Math_fround(HEAPF32[$8>>2]);
 $30 = Math_fround($22 * $27);
 $31 = Math_fround($24 * $28);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($26 * $29);
 $34 = Math_fround($32 + $33);
 $35 = (($19) + 112|0);
 $36 = (($19) + 112|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($19) + 116|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($19) + 120|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($27 * $37);
 $43 = Math_fround($28 * $39);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($29 * $41);
 $46 = Math_fround($44 + $45);
 $47 = $34 > $46;
 ;HEAP32[$1+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$20+12>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$35+12>>2]|0;
 $b$a$i$i = $47 ? $1 : $0;
 $48 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $$in1$i$i = (($b$a$i$i) + 4|0);
 $49 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $$in2$i$i = (($b$a$i$i) + 8|0);
 $50 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 ;HEAP32[$supportA+0>>2]=HEAP32[$_sa+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$_sa+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$_sa+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$_sa+12>>2]|0;
 HEAPF32[$supportB>>2] = $48;
 $51 = (($supportB) + 4|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($supportB) + 8|0);
 HEAPF32[$52>>2] = $50;
 $53 = (($supportB) + 12|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = Math_fround(HEAPF32[$_sa>>2]);
 $55 = (($_sa) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($_sa) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($54 - $48);
 $60 = Math_fround($56 - $49);
 $61 = Math_fround($58 - $50);
 HEAPF32[$support>>2] = $59;
 $62 = (($support) + 4|0);
 HEAPF32[$62>>2] = $60;
 $63 = (($support) + 8|0);
 HEAPF32[$63>>2] = $61;
 $64 = (($support) + 12|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19_gjkRelativeRayCastINS0_9TriangleVENS0_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos15PsMatTransformVERKNS9_6FloatVERKNS9_5Vec3VESI_RSD_RSG_SK_f($a,$b,$aToB,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i142 = 0, $$in1$i$i$i186 = 0, $$in1$i202 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i144 = 0, $$in2$i$i$i188 = 0, $$in2$i204 = 0, $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa904 = Math_fround(0);
 var $$lcssa906 = Math_fround(0), $$lcssa908 = Math_fround(0), $$lcssa910 = Math_fround(0), $$lcssa912 = 0, $$lcssa914 = Math_fround(0), $$lcssa916 = Math_fround(0), $$lcssa918 = Math_fround(0), $$sroa$1328 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0);
 var $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0);
 var $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0);
 var $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0);
 var $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0);
 var $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0);
 var $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0);
 var $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0);
 var $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0);
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0);
 var $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0);
 var $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = Math_fround(0);
 var $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $a$pn3$i$i$i = 0, $a$pn3$i$i$i141 = 0, $a$pn3$i$i$i185 = 0, $b$a$i = 0;
 var $b$a$i$i$i = 0, $b$a$i$i$i139 = 0, $b$a$i$i$i183 = 0, $b$a$i18 = 0, $b$a$i199 = 0, $b$a5$i = 0, $b$a5$i$i$i = 0, $b$a5$i$i$i143 = 0, $b$a5$i$i$i187 = 0, $closA = 0, $closAA = 0, $closB = 0, $initialSupportA = 0, $phitmp = 0, $phitmp897 = 0, $size = 0, $support = 0, $tempV = 0, $vNorm = 0, $zero$sroa$1 = 0;
 var $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 336|0;
 $1 = sp + 432|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $4 = sp + 384|0;
 $5 = sp + 496|0;
 $6 = sp + 400|0;
 $7 = sp + 416|0;
 $8 = sp + 448|0;
 $9 = sp + 464|0;
 $zeroV = sp + 480|0;
 $zero$sroa$1 = sp + 528|0;
 $_lambda$sroa$1 = sp + 540|0;
 $size = sp + 524|0;
 $initialSupportA = sp + 208|0;
 $10 = sp;
 $Q = sp + 16|0;
 $A = sp + 80|0;
 $B = sp + 144|0;
 $support = sp + 224|0;
 $closA = sp + 240|0;
 $closB = sp + 256|0;
 $closAA = sp + 272|0;
 $vNorm = sp + 288|0;
 $11 = sp + 304|0;
 $$sroa$1328 = sp + 512|0;
 $tempV = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $12 = Math_fround(HEAPF32[$r>>2]);
 $13 = (($r) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($r) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$s>>2]);
 $18 = (($s) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($s) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAP32[$size>>2] = 1;
 $22 = (($aToB) + 48|0);
 $23 = (($aToB) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($aToB) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($aToB) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($24 * $24);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($28 * $28);
 $33 = Math_fround($31 + $32);
 $34 = $33 > Math_fround(1.1920928955078125E-7);
 ;HEAP32[$1+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$22+12>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $35 = (($0) + 4|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($0) + 8|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($0) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $b$a$i199 = $34 ? $1 : $0;
 $38 = Math_fround(HEAPF32[$b$a$i199>>2]);
 $$in1$i202 = (($b$a$i199) + 4|0);
 $39 = Math_fround(HEAPF32[$$in1$i202>>2]);
 $$in2$i204 = (($b$a$i199) + 8|0);
 $40 = Math_fround(HEAPF32[$$in2$i204>>2]);
 $41 = Math_fround($38 * $38);
 $42 = Math_fround($39 * $39);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($40 * $40);
 $45 = Math_fround($43 + $44);
 $46 = (Math_fround(Math_sqrt((Math_fround($45)))));
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = Math_fround($38 * $47);
 $49 = Math_fround($39 * $47);
 $50 = Math_fround($40 * $47);
 $51 = Math_fround(-$48);
 $52 = Math_fround(-$49);
 $53 = Math_fround(-$50);
 HEAPF32[$10>>2] = $51;
 $54 = (($10) + 4|0);
 HEAPF32[$54>>2] = $52;
 $55 = (($10) + 8|0);
 HEAPF32[$55>>2] = $53;
 $56 = (($10) + 12|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($initialSupportA,$a,$10,$aToB);
 $57 = $48 > Math_fround(0.0);
 $58 = $49 > Math_fround(0.0);
 $59 = $50 > Math_fround(0.0);
 $60 = (($b) + 144|0);
 ;HEAP32[$3+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$60+12>>2]|0;
 $61 = (($b) + 144|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($b) + 148|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($b) + 152|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround(-$62);
 $68 = Math_fround(-$64);
 $69 = Math_fround(-$66);
 HEAPF32[$2>>2] = $67;
 $70 = (($2) + 4|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($2) + 8|0);
 HEAPF32[$71>>2] = $69;
 $72 = (($2) + 12|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $b$a$i$i$i183 = $57 ? $3 : $2;
 $73 = Math_fround(HEAPF32[$b$a$i$i$i183>>2]);
 $a$pn3$i$i$i185 = $58 ? $3 : $2;
 $$in1$i$i$i186 = (($a$pn3$i$i$i185) + 4|0);
 $74 = Math_fround(HEAPF32[$$in1$i$i$i186>>2]);
 $b$a5$i$i$i187 = $59 ? $3 : $2;
 $$in2$i$i$i188 = (($b$a5$i$i$i187) + 8|0);
 $75 = Math_fround(HEAPF32[$$in2$i$i$i188>>2]);
 $76 = Math_fround(HEAPF32[$initialSupportA>>2]);
 $77 = (($initialSupportA) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($initialSupportA) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($76 - $73);
 $82 = Math_fround($78 - $74);
 $83 = Math_fround($80 - $75);
 HEAPF32[$Q>>2] = $81;
 $84 = (($Q) + 4|0);
 HEAPF32[$84>>2] = $82;
 $85 = (($Q) + 8|0);
 HEAPF32[$85>>2] = $83;
 $86 = (($Q) + 12|0);
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = (($Q) + 16|0);
 ;HEAP32[$87+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$87+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $88 = (($Q) + 32|0);
 ;HEAP32[$88+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $89 = (($Q) + 48|0);
 ;HEAP32[$89+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$A+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$A+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$A+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$A+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 $90 = (($A) + 16|0);
 ;HEAP32[$90+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $91 = (($A) + 32|0);
 ;HEAP32[$91+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$91+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $92 = (($A) + 48|0);
 ;HEAP32[$92+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$92+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$B>>2] = $73;
 $93 = (($B) + 4|0);
 HEAPF32[$93>>2] = $74;
 $94 = (($B) + 8|0);
 HEAPF32[$94>>2] = $75;
 $95 = (($B) + 12|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($B) + 16|0);
 ;HEAP32[$96+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$96+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$96+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$96+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $97 = (($B) + 32|0);
 ;HEAP32[$97+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$97+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $98 = (($B) + 48|0);
 ;HEAP32[$98+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$98+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $99 = Math_fround(-$81);
 $100 = Math_fround(-$82);
 $101 = Math_fround(-$83);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $102 = (($a) + 32|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($b) + 32|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = $103 > $105;
 $$$i = $106 ? $105 : $103;
 $107 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $108 = Math_fround($107 * $107);
 $109 = Math_fround($_inflation * $_inflation);
 $110 = Math_fround($109 + $108);
 ;HEAP32[$closA+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 HEAPF32[$closB>>2] = $73;
 $111 = (($closB) + 4|0);
 HEAPF32[$111>>2] = $74;
 $112 = (($closB) + 8|0);
 HEAPF32[$112>>2] = $75;
 $113 = (($closB) + 12|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = Math_fround($81 * $81);
 $115 = Math_fround($82 * $82);
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($83 * $83);
 $118 = Math_fround($116 + $117);
 ;HEAP32[$closAA+0>>2]=HEAP32[$initialSupportA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$initialSupportA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$initialSupportA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$initialSupportA+12>>2]|0;
 $119 = $118 > $108;
 L1: do {
  if ($119) {
   $120 = Math_fround($16 * Math_fround(0.0));
   $121 = Math_fround($14 * Math_fround(0.0));
   $122 = Math_fround($12 * Math_fround(0.0));
   $123 = Math_fround($120 + $21);
   $124 = Math_fround($121 + $19);
   $125 = Math_fround($122 + $17);
   $126 = (($vNorm) + 4|0);
   $127 = (($vNorm) + 8|0);
   $128 = (($vNorm) + 12|0);
   $129 = (($11) + 4|0);
   $130 = (($11) + 8|0);
   $131 = (($11) + 12|0);
   $132 = (($2) + 4|0);
   $133 = (($2) + 8|0);
   $134 = (($2) + 12|0);
   $135 = (($support) + 4|0);
   $136 = (($support) + 8|0);
   $137 = (($support) + 12|0);
   $138 = (($B) + 16|0);
   $139 = (($B) + 20|0);
   $140 = (($B) + 24|0);
   $141 = (($B) + 28|0);
   $142 = (($B) + 32|0);
   $143 = (($B) + 36|0);
   $144 = (($B) + 40|0);
   $145 = (($B) + 44|0);
   $146 = (($A) + 4|0);
   $147 = (($A) + 8|0);
   $148 = (($A) + 16|0);
   $149 = (($A) + 20|0);
   $150 = (($A) + 24|0);
   $151 = (($Q) + 16|0);
   $152 = (($Q) + 20|0);
   $153 = (($Q) + 24|0);
   $154 = (($Q) + 28|0);
   $155 = (($A) + 32|0);
   $156 = (($A) + 36|0);
   $157 = (($A) + 40|0);
   $158 = (($Q) + 32|0);
   $159 = (($Q) + 36|0);
   $160 = (($Q) + 40|0);
   $161 = (($Q) + 44|0);
   $162 = (($2) + 4|0);
   $163 = (($2) + 8|0);
   $164 = (($2) + 12|0);
   $165 = (($tempV) + 4|0);
   $166 = (($tempV) + 8|0);
   $167 = (($closA) + 4|0);
   $168 = (($closA) + 8|0);
   $169 = (($closA) + 12|0);
   $170 = (($tempV) + 12|0);
   $172 = $99;$174 = $100;$177 = $101;$201 = $125;$203 = $124;$205 = $123;$231 = Math_fround(0.0);$432 = $99;$433 = $100;$434 = $101;$435 = $118;
   while(1) {
    ;HEAP32[$closAA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$closAA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$closAA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$closAA+12>>2]=HEAP32[$closA+12>>2]|0;
    $171 = Math_fround($172 * $172);
    $173 = Math_fround($174 * $174);
    $175 = Math_fround($173 + $171);
    $176 = Math_fround($177 * $177);
    $178 = Math_fround($176 + $175);
    $179 = (Math_fround(Math_sqrt((Math_fround($178)))));
    $180 = Math_fround(Math_fround(1.0) / $179);
    $181 = Math_fround($172 * $180);
    $182 = Math_fround($174 * $180);
    $183 = Math_fround($177 * $180);
    HEAPF32[$vNorm>>2] = $181;
    HEAPF32[$126>>2] = $182;
    HEAPF32[$127>>2] = $183;
    HEAPF32[$128>>2] = Math_fround(0.0);
    __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($11,$a,$vNorm,$aToB);
    $184 = Math_fround(HEAPF32[$11>>2]);
    $185 = Math_fround(HEAPF32[$129>>2]);
    $186 = Math_fround(HEAPF32[$130>>2]);
    $187 = Math_fround(HEAPF32[$131>>2]);
    $188 = $181 < Math_fround(-0.0);
    $189 = $182 < Math_fround(-0.0);
    $190 = $183 < Math_fround(-0.0);
    ;HEAP32[$3+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$60+12>>2]|0;
    $191 = Math_fround(HEAPF32[$61>>2]);
    $192 = Math_fround(HEAPF32[$63>>2]);
    $193 = Math_fround(HEAPF32[$65>>2]);
    $194 = Math_fround(-$191);
    $195 = Math_fround(-$192);
    $196 = Math_fround(-$193);
    HEAPF32[$2>>2] = $194;
    HEAPF32[$132>>2] = $195;
    HEAPF32[$133>>2] = $196;
    HEAPF32[$134>>2] = Math_fround(0.0);
    $b$a$i$i$i139 = $188 ? $3 : $2;
    $197 = Math_fround(HEAPF32[$b$a$i$i$i139>>2]);
    $a$pn3$i$i$i141 = $189 ? $3 : $2;
    $$in1$i$i$i142 = (($a$pn3$i$i$i141) + 4|0);
    $198 = Math_fround(HEAPF32[$$in1$i$i$i142>>2]);
    $b$a5$i$i$i143 = $190 ? $3 : $2;
    $$in2$i$i$i144 = (($b$a5$i$i$i143) + 8|0);
    $199 = Math_fround(HEAPF32[$$in2$i$i$i144>>2]);
    $200 = Math_fround($201 + $197);
    $202 = Math_fround($203 + $198);
    $204 = Math_fround($205 + $199);
    $206 = Math_fround($184 - $200);
    $207 = Math_fround($185 - $202);
    $208 = Math_fround($186 - $204);
    HEAPF32[$support>>2] = $206;
    HEAPF32[$135>>2] = $207;
    HEAPF32[$136>>2] = $208;
    HEAPF32[$137>>2] = Math_fround(0.0);
    $209 = Math_fround(HEAPF32[$vNorm>>2]);
    $210 = Math_fround(HEAPF32[$126>>2]);
    $211 = Math_fround(HEAPF32[$127>>2]);
    $212 = Math_fround($206 * $209);
    $213 = Math_fround($207 * $210);
    $214 = Math_fround(-$213);
    $215 = Math_fround($214 - $212);
    $216 = Math_fround($208 * $211);
    $217 = Math_fround($215 - $216);
    $218 = Math_fround($217 - $_inflation);
    $219 = Math_fround(HEAPF32[$r>>2]);
    $220 = Math_fround(HEAPF32[$13>>2]);
    $221 = Math_fround(HEAPF32[$15>>2]);
    $222 = Math_fround($209 * $219);
    $223 = Math_fround($210 * $220);
    $224 = Math_fround($222 + $223);
    $225 = Math_fround($211 * $221);
    $226 = Math_fround($224 + $225);
    $227 = $218 > Math_fround(0.0);
    if ($227) {
     $228 = !($226 >= Math_fround(0.0));
     if (!($228)) {
      $$0 = 0;
      label = 21;
      break;
     }
     $229 = Math_fround($218 / $226);
     $230 = Math_fround($231 - $229);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1328+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1328+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1328+8>>2]|0;
     $232 = $230 > $231;
     if ($232) {
      $233 = $230 > Math_fround(1.0);
      if ($233) {
       $$0 = 0;
       label = 21;
       break;
      }
      $234 = Math_fround(HEAPF32[$s>>2]);
      $235 = Math_fround(HEAPF32[$18>>2]);
      $236 = Math_fround(HEAPF32[$20>>2]);
      $237 = Math_fround($230 * $219);
      $238 = Math_fround($230 * $220);
      $239 = Math_fround($230 * $221);
      $240 = Math_fround($237 + $234);
      $241 = Math_fround($238 + $235);
      $242 = Math_fround($239 + $236);
      $243 = Math_fround($240 - $201);
      $244 = Math_fround($241 - $203);
      $245 = Math_fround($242 - $205);
      $246 = Math_fround(HEAPF32[$B>>2]);
      $247 = Math_fround(HEAPF32[$93>>2]);
      $248 = Math_fround(HEAPF32[$94>>2]);
      $249 = Math_fround($243 + $246);
      $250 = Math_fround($244 + $247);
      $251 = Math_fround($245 + $248);
      $252 = Math_fround(HEAPF32[$138>>2]);
      $253 = Math_fround(HEAPF32[$139>>2]);
      $254 = Math_fround(HEAPF32[$140>>2]);
      $255 = Math_fround($243 + $252);
      $256 = Math_fround($244 + $253);
      $257 = Math_fround($245 + $254);
      $258 = Math_fround(HEAPF32[$142>>2]);
      $259 = Math_fround(HEAPF32[$143>>2]);
      $260 = Math_fround(HEAPF32[$144>>2]);
      $261 = Math_fround($243 + $258);
      $262 = Math_fround($244 + $259);
      $263 = Math_fround($245 + $260);
      HEAPF32[$B>>2] = $249;
      HEAPF32[$93>>2] = $250;
      HEAPF32[$94>>2] = $251;
      HEAPF32[$95>>2] = Math_fround(0.0);
      HEAPF32[$138>>2] = $255;
      HEAPF32[$139>>2] = $256;
      HEAPF32[$140>>2] = $257;
      HEAPF32[$141>>2] = Math_fround(0.0);
      HEAPF32[$142>>2] = $261;
      HEAPF32[$143>>2] = $262;
      HEAPF32[$144>>2] = $263;
      HEAPF32[$145>>2] = Math_fround(0.0);
      $264 = Math_fround(HEAPF32[$A>>2]);
      $265 = Math_fround(HEAPF32[$146>>2]);
      $266 = Math_fround(HEAPF32[$147>>2]);
      $267 = Math_fround($264 - $249);
      $268 = Math_fround($265 - $250);
      $269 = Math_fround($266 - $251);
      HEAPF32[$Q>>2] = $267;
      HEAPF32[$84>>2] = $268;
      HEAPF32[$85>>2] = $269;
      HEAPF32[$86>>2] = Math_fround(0.0);
      $270 = Math_fround(HEAPF32[$148>>2]);
      $271 = Math_fround(HEAPF32[$149>>2]);
      $272 = Math_fround(HEAPF32[$150>>2]);
      $273 = Math_fround($270 - $255);
      $274 = Math_fround($271 - $256);
      $275 = Math_fround($272 - $257);
      HEAPF32[$151>>2] = $273;
      HEAPF32[$152>>2] = $274;
      HEAPF32[$153>>2] = $275;
      HEAPF32[$154>>2] = Math_fround(0.0);
      $276 = Math_fround(HEAPF32[$155>>2]);
      $277 = Math_fround(HEAPF32[$156>>2]);
      $278 = Math_fround(HEAPF32[$157>>2]);
      $279 = Math_fround($276 - $261);
      $280 = Math_fround($277 - $262);
      $281 = Math_fround($278 - $263);
      HEAPF32[$158>>2] = $279;
      HEAPF32[$159>>2] = $280;
      HEAPF32[$160>>2] = $281;
      HEAPF32[$161>>2] = Math_fround(0.0);
      ;HEAP32[$3+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$60+12>>2]|0;
      HEAPF32[$2>>2] = $194;
      HEAPF32[$162>>2] = $195;
      HEAPF32[$163>>2] = $196;
      HEAPF32[$164>>2] = Math_fround(0.0);
      $b$a$i$i$i = $188 ? $3 : $2;
      $282 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
      $a$pn3$i$i$i = $189 ? $3 : $2;
      $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
      $283 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
      $b$a5$i$i$i = $190 ? $3 : $2;
      $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
      $284 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
      $285 = Math_fround($240 + $282);
      $286 = Math_fround($241 + $283);
      $287 = Math_fround($242 + $284);
      $288 = Math_fround($184 - $285);
      $289 = Math_fround($185 - $286);
      $290 = Math_fround($186 - $287);
      HEAPF32[$support>>2] = $288;
      HEAPF32[$135>>2] = $289;
      HEAPF32[$136>>2] = $290;
      HEAPF32[$137>>2] = Math_fround(0.0);
      $297 = $285;$299 = $286;$301 = $287;$309 = $288;$311 = $289;$313 = $290;$368 = Math_fround(3.40282346638528859812E+38);$436 = $230;$437 = $242;$438 = $241;$439 = $240;$440 = $177;$441 = $174;$442 = $172;
     } else {
      $297 = $200;$299 = $202;$301 = $204;$309 = $206;$311 = $207;$313 = $208;$368 = $435;$436 = $230;$437 = $205;$438 = $203;$439 = $201;$440 = $434;$441 = $433;$442 = $432;
     }
    } else {
     $297 = $200;$299 = $202;$301 = $204;$309 = $206;$311 = $207;$313 = $208;$368 = $435;$436 = $231;$437 = $205;$438 = $203;$439 = $201;$440 = $434;$441 = $433;$442 = $432;
    }
    $291 = HEAP32[$size>>2]|0;
    $292 = (($A) + ($291<<4)|0);
    HEAPF32[$292>>2] = $184;
    $293 = ((($A) + ($291<<4)|0) + 4|0);
    HEAPF32[$293>>2] = $185;
    $294 = ((($A) + ($291<<4)|0) + 8|0);
    HEAPF32[$294>>2] = $186;
    $295 = ((($A) + ($291<<4)|0) + 12|0);
    HEAPF32[$295>>2] = $187;
    $296 = (($B) + ($291<<4)|0);
    HEAPF32[$296>>2] = $297;
    $298 = ((($B) + ($291<<4)|0) + 4|0);
    HEAPF32[$298>>2] = $299;
    $300 = ((($B) + ($291<<4)|0) + 8|0);
    HEAPF32[$300>>2] = $301;
    $302 = ((($B) + ($291<<4)|0) + 12|0);
    HEAPF32[$302>>2] = Math_fround(0.0);
    $303 = (($291) + 1)|0;
    HEAP32[$size>>2] = $303;
    $304 = (($Q) + ($291<<4)|0);
    ;HEAP32[$304+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$304+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$304+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$304+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($291|0) == 1)) {
      $305 = Math_fround(HEAPF32[$Q>>2]);
      $306 = Math_fround(HEAPF32[$84>>2]);
      $307 = Math_fround(HEAPF32[$85>>2]);
      $308 = Math_fround($309 - $305);
      $310 = Math_fround($311 - $306);
      $312 = Math_fround($313 - $307);
      $314 = Math_fround($308 * $308);
      $315 = Math_fround($310 * $310);
      $316 = Math_fround($314 + $315);
      $317 = Math_fround($312 * $312);
      $318 = Math_fround($316 + $317);
      $319 = $318 == Math_fround(0.0);
      if ($319) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $320 = Math_fround($306 * $310);
       $321 = Math_fround(-$320);
       $322 = Math_fround($305 * $308);
       $323 = Math_fround($321 - $322);
       $324 = Math_fround($307 * $312);
       $325 = Math_fround($323 - $324);
       $326 = Math_fround(HEAPF32[$A>>2]);
       $327 = Math_fround(HEAPF32[$146>>2]);
       $328 = Math_fround(HEAPF32[$147>>2]);
       $329 = Math_fround($184 - $326);
       $330 = Math_fround($185 - $327);
       $331 = Math_fround($186 - $328);
       $332 = Math_fround(HEAPF32[$B>>2]);
       $333 = Math_fround(HEAPF32[$93>>2]);
       $334 = Math_fround(HEAPF32[$94>>2]);
       $335 = Math_fround($297 - $332);
       $336 = Math_fround($299 - $333);
       $337 = Math_fround($301 - $334);
       $338 = Math_fround($325 / $318);
       $339 = $338 > Math_fround(1.0);
       $$$i$i$i = $339 ? Math_fround(1.0) : $338;
       $340 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $340 ? $$$i$i$i : Math_fround(0.0);
       $341 = Math_fround($329 * $$$i8$i$i);
       $342 = Math_fround($330 * $$$i8$i$i);
       $343 = Math_fround($331 * $$$i8$i$i);
       $344 = Math_fround($326 + $341);
       $345 = Math_fround($327 + $342);
       $346 = Math_fround($328 + $343);
       $347 = Math_fround($335 * $$$i8$i$i);
       $348 = Math_fround($336 * $$$i8$i$i);
       $349 = Math_fround($337 * $$$i8$i$i);
       $350 = Math_fround($332 + $347);
       $351 = Math_fround($333 + $348);
       $352 = Math_fround($334 + $349);
       HEAPF32[$closA>>2] = $344;
       HEAPF32[$167>>2] = $345;
       HEAPF32[$168>>2] = $346;
       HEAPF32[$169>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $350;
       HEAPF32[$111>>2] = $351;
       HEAPF32[$112>>2] = $352;
       HEAPF32[$113>>2] = Math_fround(0.0);
       $353 = Math_fround($344 - $350);
       $354 = Math_fround($345 - $351);
       $355 = Math_fround($346 - $352);
       HEAPF32[$tempV>>2] = $353;
       HEAPF32[$165>>2] = $354;
       HEAPF32[$166>>2] = $355;
       HEAPF32[$170>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($291|0) == 0)) {
      HEAPF32[$closA>>2] = $184;
      HEAPF32[$167>>2] = $185;
      HEAPF32[$168>>2] = $186;
      HEAPF32[$169>>2] = $187;
      HEAPF32[$closB>>2] = $297;
      HEAPF32[$111>>2] = $299;
      HEAPF32[$112>>2] = $301;
      HEAPF32[$113>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($291|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$87,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($291|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $356 = Math_fround(HEAPF32[$tempV>>2]);
    $357 = Math_fround(HEAPF32[$165>>2]);
    $358 = Math_fround(HEAPF32[$166>>2]);
    $359 = Math_fround(-$356);
    $360 = Math_fround(-$357);
    $361 = Math_fround(-$358);
    $362 = Math_fround($356 * $356);
    $363 = Math_fround($357 * $357);
    $364 = Math_fround($362 + $363);
    $365 = Math_fround($358 * $358);
    $366 = Math_fround($364 + $365);
    $367 = $368 > $366;
    $369 = $367 << 31 >> 31;
    $370 = $366 > $110;
    if (!($370)) {
     $$lcssa = $436;$$lcssa904 = $361;$$lcssa906 = $360;$$lcssa908 = $359;$$lcssa910 = $366;$$lcssa912 = $369;$$lcssa914 = $440;$$lcssa916 = $441;$$lcssa918 = $442;
     break L1;
    }
    if ($367) {
     $172 = $359;$174 = $360;$177 = $361;$201 = $439;$203 = $438;$205 = $437;$231 = $436;$432 = $442;$433 = $441;$434 = $440;$435 = $366;
    } else {
     $$lcssa = $436;$$lcssa904 = $361;$$lcssa906 = $360;$$lcssa908 = $359;$$lcssa910 = $366;$$lcssa912 = $369;$$lcssa914 = $440;$$lcssa916 = $441;$$lcssa918 = $442;
     break L1;
    }
   }
   if ((label|0) == 21) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa904 = $101;$$lcssa906 = $100;$$lcssa908 = $99;$$lcssa910 = $118;$$lcssa912 = -1;$$lcssa914 = $101;$$lcssa916 = $100;$$lcssa918 = $99;
  }
 } while(0);
 $371 = (($a) + 64|0);
 $372 = HEAP32[$371>>2]|0;
 $373 = (($a) + 68|0);
 $374 = HEAP32[$373>>2]|0;
 $375 = (($a) + 72|0);
 $376 = HEAP32[$375>>2]|0;
 $377 = $$lcssa910 > $108;
 if ($377) {
  $phitmp = ($$lcssa912|0)==(0);
  $phitmp897 = $phitmp ? $4 : $5;
  $385 = $phitmp897;
 } else {
  $385 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa908;
 $378 = (($5) + 4|0);
 HEAPF32[$378>>2] = $$lcssa906;
 $379 = (($5) + 8|0);
 HEAPF32[$379>>2] = $$lcssa904;
 $380 = (($5) + 12|0);
 HEAPF32[$380>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa918;
 $381 = (($4) + 4|0);
 HEAPF32[$381>>2] = $$lcssa916;
 $382 = (($4) + 8|0);
 HEAPF32[$382>>2] = $$lcssa914;
 $383 = (($4) + 12|0);
 HEAPF32[$383>>2] = Math_fround(0.0);
 $384 = Math_fround(HEAPF32[$385>>2]);
 $$in1$i37 = (($385) + 4|0);
 $386 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($385) + 8|0);
 $387 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $388 = Math_fround($384 * $384);
 $389 = Math_fround($386 * $386);
 $390 = Math_fround($388 + $389);
 $391 = Math_fround($387 * $387);
 $392 = Math_fround($390 + $391);
 $393 = (Math_fround(Math_sqrt((Math_fround($392)))));
 $394 = Math_fround(Math_fround(1.0) / $393);
 $395 = Math_fround($384 * $394);
 $396 = Math_fround($386 * $394);
 $397 = Math_fround($387 * $394);
 $398 = Math_fround(-$395);
 $399 = Math_fround(-$396);
 $400 = Math_fround(-$397);
 HEAPF32[$normal>>2] = $398;
 $401 = (($normal) + 4|0);
 HEAPF32[$401>>2] = $399;
 $402 = (($normal) + 8|0);
 HEAPF32[$402>>2] = $400;
 $403 = (($normal) + 12|0);
 HEAPF32[$403>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $404 = (($lambda) + 4|0);
 ;HEAP32[$404+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$404+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$404+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$6+0>>2]=HEAP32[$closAA+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$closAA+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$closAA+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$closAA+12>>2]|0;
 $405 = ($$lcssa912|0)==(0);
 $b$a$i18 = $405 ? $6 : $7;
 $406 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $407 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $408 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $406;
 $409 = (($closA) + 4|0);
 HEAPF32[$409>>2] = $407;
 $410 = (($closA) + 8|0);
 HEAPF32[$410>>2] = $408;
 $411 = (($closA) + 12|0);
 HEAPF32[$411>>2] = Math_fround(0.0);
 $412 = (($a) + 16|0);
 $413 = Math_fround(HEAPF32[$412>>2]);
 $414 = Math_fround($413 * $398);
 $415 = Math_fround($413 * $399);
 $416 = Math_fround($413 * $400);
 $417 = Math_fround($406 - $414);
 $418 = Math_fround($407 - $415);
 $419 = Math_fround($408 - $416);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $417;
 $420 = (($9) + 4|0);
 HEAPF32[$420>>2] = $418;
 $421 = (($9) + 8|0);
 HEAPF32[$421>>2] = $419;
 $422 = (($9) + 12|0);
 HEAPF32[$422>>2] = Math_fround(0.0);
 $423 = ($372|0)==(0);
 $b$a$i = $423 ? $8 : $9;
 $424 = Math_fround(HEAPF32[$b$a$i>>2]);
 $425 = ($374|0)==(0);
 $a$pn3$i = $425 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $426 = Math_fround(HEAPF32[$$in1$i>>2]);
 $427 = ($376|0)==(0);
 $b$a5$i = $427 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $428 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $424;
 $429 = (($closestA) + 4|0);
 HEAPF32[$429>>2] = $426;
 $430 = (($closestA) + 8|0);
 HEAPF32[$430>>2] = $428;
 $431 = (($closestA) + 12|0);
 HEAPF32[$431>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22gjkRelativePenetrationINS0_9TriangleVENS0_10ShrunkBoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($a,$b,$aToB,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size) {
 $a = $a|0;
 $b = $b|0;
 $aToB = $aToB|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 var $$$761 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i165 = Math_fround(0), $$$i134 = Math_fround(0), $$$i194 = Math_fround(0), $$$i749819 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i166 = Math_fround(0), $$0 = 0, $$757 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i175 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i177 = 0, $$ph = Math_fround(0), $$ph769 = Math_fround(0), $$ph770 = Math_fround(0);
 var $$ph771 = Math_fround(0), $$ph772 = Math_fround(0), $$ph773 = Math_fround(0), $$ph774 = Math_fround(0), $$ph775 = Math_fround(0), $$ph777 = Math_fround(0), $$ph778 = 0, $$ph782 = Math_fround(0), $$ph783 = Math_fround(0), $$ph784 = Math_fround(0), $$pre = Math_fround(0), $$pre866 = Math_fround(0), $$pre867 = Math_fround(0), $$pre868 = Math_fround(0), $$pre869 = Math_fround(0), $$pre870 = Math_fround(0), $$pre871 = Math_fround(0), $$pre872 = Math_fround(0), $$sroa$1 = 0, $$sroa$1238 = 0;
 var $$sroa$1240 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0);
 var $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0;
 var $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = Math_fround(0), $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0);
 var $458 = 0, $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0);
 var $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0);
 var $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = 0, $542 = 0, $543 = 0, $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0);
 var $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = Math_fround(0), $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0);
 var $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $a$pn3$i$i = 0, $a$pn3$i$i174 = 0, $aInd = 0, $b$a$i = 0, $b$a$i$i = 0;
 var $b$a$i$i172 = 0, $b$a5$i$i = 0, $b$a5$i$i176 = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i30 = 0, $exitcond$i73 = 0, $i$01$i = 0, $i$01$i29 = 0, $i$01$i72 = 0, $i$0829 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp765 = 0;
 var $sDist$sroa$1 = 0, $size = 0, $support3 = 0, $supportA1 = 0, $supportB2 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 368|0;
 $1 = sp + 320|0;
 $2 = sp + 336|0;
 $3 = sp + 352|0;
 $closA = sp + 384|0;
 $closB = sp + 400|0;
 $sDist$sroa$1 = sp + 484|0;
 $minDist$sroa$1 = sp + 472|0;
 $Q = sp;
 $A = sp + 144|0;
 $B = sp + 64|0;
 $aInd = sp + 456|0;
 $bInd = sp + 496|0;
 $size = sp + 416|0;
 $lastQ = sp + 128|0;
 $lastA = sp + 208|0;
 $lastB = sp + 224|0;
 $4 = sp + 240|0;
 $supportA1 = sp + 256|0;
 $supportB2 = sp + 272|0;
 $support3 = sp + 288|0;
 $$sroa$1240 = sp + 432|0;
 $5 = sp + 304|0;
 $$sroa$1238 = sp + 444|0;
 $$sroa$1 = sp + 420|0;
 $6 = (($a) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($b) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$_contactDist>>2]);
 $11 = (($a) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($b) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $$$i194 = $15 ? $14 : $12;
 $16 = Math_fround($$$i194 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($7 + $9);
 $18 = (($closA) + 4|0);
 $19 = (($closA) + 8|0);
 $20 = (($closA) + 12|0);
 ;HEAP32[$closA+0>>2]=0|0;HEAP32[$closA+4>>2]=0|0;HEAP32[$closA+8>>2]=0|0;HEAP32[$closA+12>>2]=0|0;
 $21 = (($closB) + 4|0);
 $22 = (($closB) + 8|0);
 $23 = (($closB) + 12|0);
 ;HEAP32[$closB+0>>2]=0|0;HEAP32[$closB+4>>2]=0|0;HEAP32[$closB+8>>2]=0|0;HEAP32[$closB+12>>2]=0|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 $24 = Math_fround($16 * $16);
 HEAP32[$size>>2] = 0;
 $25 = HEAP8[$_size>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $210 = (($aToB) + 48|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = (($aToB) + 52|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = (($aToB) + 56|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($aToB) + 60|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = Math_fround($211 * $211);
  $219 = Math_fround($213 * $213);
  $220 = Math_fround($218 + $219);
  $221 = Math_fround($215 * $215);
  $222 = Math_fround($220 + $221);
  $223 = $222 > Math_fround(0.0);
  HEAPF32[$3>>2] = $211;
  $224 = (($3) + 4|0);
  HEAPF32[$224>>2] = $213;
  $225 = (($3) + 8|0);
  HEAPF32[$225>>2] = $215;
  $226 = (($3) + 12|0);
  HEAPF32[$226>>2] = $217;
  HEAPF32[$2>>2] = Math_fround(1.0);
  $227 = (($2) + 4|0);
  HEAPF32[$227>>2] = Math_fround(0.0);
  $228 = (($2) + 8|0);
  HEAPF32[$228>>2] = Math_fround(0.0);
  $229 = (($2) + 12|0);
  HEAPF32[$229>>2] = Math_fround(0.0);
  $b$a$i = $223 ? $3 : $2;
  $230 = Math_fround(HEAPF32[$b$a$i>>2]);
  $$in1$i = (($b$a$i) + 4|0);
  $231 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i) + 8|0);
  $232 = Math_fround(HEAPF32[$$in2$i>>2]);
  $$ph = Math_fround(0.0);$$ph769 = Math_fround(0.0);$$ph770 = Math_fround(0.0);$$ph771 = Math_fround(0.0);$$ph772 = Math_fround(0.0);$$ph773 = Math_fround(0.0);$$ph774 = Math_fround(0.0);$$ph775 = Math_fround(0.0);$$ph777 = Math_fround(3.40282346638528859812E+38);$$ph778 = 1;$$ph782 = $232;$$ph783 = $231;$$ph784 = $230;
 } else {
  $27 = (($lastQ) + 4|0);
  $28 = (($lastQ) + 8|0);
  $29 = (($lastQ) + 12|0);
  ;HEAP32[$lastQ+0>>2]=0|0;HEAP32[$lastQ+4>>2]=0|0;HEAP32[$lastQ+8>>2]=0|0;HEAP32[$lastQ+12>>2]=0|0;
  $30 = (($lastA) + 4|0);
  $31 = (($lastA) + 8|0);
  $32 = (($lastA) + 12|0);
  ;HEAP32[$lastA+0>>2]=0|0;HEAP32[$lastA+4>>2]=0|0;HEAP32[$lastA+8>>2]=0|0;HEAP32[$lastA+12>>2]=0|0;
  $33 = (($lastB) + 4|0);
  $34 = (($lastB) + 8|0);
  $35 = (($lastB) + 12|0);
  ;HEAP32[$lastB+0>>2]=0|0;HEAP32[$lastB+4>>2]=0|0;HEAP32[$lastB+8>>2]=0|0;HEAP32[$lastB+12>>2]=0|0;
  $36 = (($aToB) + 48|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($aToB) + 52|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($aToB) + 56|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround(HEAPF32[$aToB>>2]);
  $43 = (($aToB) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($aToB) + 32|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($aToB) + 4|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($aToB) + 20|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = (($aToB) + 36|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (($aToB) + 8|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($aToB) + 24|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($aToB) + 40|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($b) + 144|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($b) + 148|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = (($b) + 152|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($60 - $9);
  $66 = Math_fround($62 - $9);
  $67 = Math_fround($64 - $9);
  $68 = Math_fround(-$65);
  $69 = Math_fround(-$66);
  $70 = Math_fround(-$67);
  $71 = (($1) + 4|0);
  $72 = (($1) + 8|0);
  $73 = (($1) + 12|0);
  $74 = (($0) + 4|0);
  $75 = (($0) + 8|0);
  $76 = (($0) + 12|0);
  $77 = $25&255;
  $78 = ($77>>>0)>(1);
  $umax = $78 ? $77 : 1;
  $127 = 0;$i$0829 = 0;
  while(1) {
   $79 = (($aIndices) + ($i$0829)|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = $80&255;
   $82 = (($aInd) + ($i$0829<<2)|0);
   HEAP32[$82>>2] = $81;
   $83 = (($bIndices) + ($i$0829)|0);
   $84 = HEAP8[$83>>0]|0;
   $85 = $84&255;
   $86 = (($bInd) + ($i$0829<<2)|0);
   HEAP32[$86>>2] = $85;
   $87 = ((($a) + ($81<<4)|0) + 96|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = ((($a) + ($81<<4)|0) + 100|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = ((($a) + ($81<<4)|0) + 104|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = Math_fround($88 * $42);
   $94 = Math_fround($90 * $44);
   $95 = Math_fround($93 + $94);
   $96 = Math_fround($92 * $46);
   $97 = Math_fround($95 + $96);
   $98 = Math_fround($88 * $48);
   $99 = Math_fround($90 * $50);
   $100 = Math_fround($98 + $99);
   $101 = Math_fround($92 * $52);
   $102 = Math_fround($100 + $101);
   $103 = Math_fround($88 * $54);
   $104 = Math_fround($90 * $56);
   $105 = Math_fround($103 + $104);
   $106 = Math_fround($92 * $58);
   $107 = Math_fround($105 + $106);
   $108 = Math_fround($37 + $97);
   $109 = Math_fround($39 + $102);
   $110 = Math_fround($41 + $107);
   $111 = (549664 + ($85<<4)|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ((549664 + ($85<<4)|0) + 4|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ((549664 + ($85<<4)|0) + 8|0);
   $116 = HEAP32[$115>>2]|0;
   HEAPF32[$1>>2] = $65;
   HEAPF32[$71>>2] = $66;
   HEAPF32[$72>>2] = $67;
   HEAPF32[$73>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $68;
   HEAPF32[$74>>2] = $69;
   HEAPF32[$75>>2] = $70;
   HEAPF32[$76>>2] = Math_fround(0.0);
   $117 = ($112|0)==(0);
   $b$a$i$i172 = $117 ? $0 : $1;
   $118 = Math_fround(HEAPF32[$b$a$i$i172>>2]);
   $119 = ($114|0)==(0);
   $a$pn3$i$i174 = $119 ? $0 : $1;
   $$in1$i$i175 = (($a$pn3$i$i174) + 4|0);
   $120 = Math_fround(HEAPF32[$$in1$i$i175>>2]);
   $121 = ($116|0)==(0);
   $b$a5$i$i176 = $121 ? $0 : $1;
   $$in2$i$i177 = (($b$a5$i$i176) + 8|0);
   $122 = Math_fround(HEAPF32[$$in2$i$i177>>2]);
   $123 = Math_fround($108 - $118);
   $124 = Math_fround($109 - $120);
   $125 = Math_fround($110 - $122);
   $126 = (($A) + ($127<<4)|0);
   HEAPF32[$lastA>>2] = $108;
   HEAPF32[$30>>2] = $109;
   HEAPF32[$31>>2] = $110;
   HEAPF32[$32>>2] = Math_fround(0.0);
   ;HEAP32[$126+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$126+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$126+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$126+12>>2]=HEAP32[$lastA+12>>2]|0;
   $128 = (($B) + ($127<<4)|0);
   HEAPF32[$lastB>>2] = $118;
   HEAPF32[$33>>2] = $120;
   HEAPF32[$34>>2] = $122;
   HEAPF32[$35>>2] = Math_fround(0.0);
   ;HEAP32[$128+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$128+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$128+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$128+12>>2]=HEAP32[$lastB+12>>2]|0;
   $129 = (($127) + 1)|0;
   $130 = (($Q) + ($127<<4)|0);
   HEAPF32[$lastQ>>2] = $123;
   HEAPF32[$27>>2] = $124;
   HEAPF32[$28>>2] = $125;
   HEAPF32[$29>>2] = Math_fround(0.0);
   ;HEAP32[$130+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$130+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$130+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$130+12>>2]=HEAP32[$lastQ+12>>2]|0;
   $131 = (($i$0829) + 1)|0;
   $132 = ($131>>>0)<($77>>>0);
   if ($132) {
    $127 = $129;$i$0829 = $131;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $umax;
  do {
   if ((($umax|0) == 3)) {
    $190 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$190,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($umax|0) == 4)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($umax|0) == 2)) {
    $133 = Math_fround(HEAPF32[$Q>>2]);
    $134 = (($Q) + 4|0);
    $135 = Math_fround(HEAPF32[$134>>2]);
    $136 = (($Q) + 8|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = Math_fround($123 - $133);
    $139 = Math_fround($124 - $135);
    $140 = Math_fround($125 - $137);
    $141 = Math_fround($138 * $138);
    $142 = Math_fround($139 * $139);
    $143 = Math_fround($141 + $142);
    $144 = Math_fround($140 * $140);
    $145 = Math_fround($143 + $144);
    $146 = $145 == Math_fround(0.0);
    if ($146) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $147 = Math_fround($135 * $139);
     $148 = Math_fround(-$147);
     $149 = Math_fround($133 * $138);
     $150 = Math_fround($148 - $149);
     $151 = Math_fround($137 * $140);
     $152 = Math_fround($150 - $151);
     $153 = Math_fround(HEAPF32[$A>>2]);
     $154 = (($A) + 4|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = (($A) + 8|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = Math_fround($108 - $153);
     $159 = Math_fround($109 - $155);
     $160 = Math_fround($110 - $157);
     $161 = Math_fround(HEAPF32[$B>>2]);
     $162 = (($B) + 4|0);
     $163 = Math_fround(HEAPF32[$162>>2]);
     $164 = (($B) + 8|0);
     $165 = Math_fround(HEAPF32[$164>>2]);
     $166 = Math_fround($118 - $161);
     $167 = Math_fround($120 - $163);
     $168 = Math_fround($122 - $165);
     $169 = Math_fround($152 / $145);
     $170 = $169 > Math_fround(1.0);
     $$$i$i$i165 = $170 ? Math_fround(1.0) : $169;
     $171 = $$$i$i$i165 > Math_fround(0.0);
     $$$i8$i$i166 = $171 ? $$$i$i$i165 : Math_fround(0.0);
     $172 = Math_fround($158 * $$$i8$i$i166);
     $173 = Math_fround($159 * $$$i8$i$i166);
     $174 = Math_fround($160 * $$$i8$i$i166);
     $175 = Math_fround($153 + $172);
     $176 = Math_fround($155 + $173);
     $177 = Math_fround($157 + $174);
     $178 = Math_fround($166 * $$$i8$i$i166);
     $179 = Math_fround($167 * $$$i8$i$i166);
     $180 = Math_fround($168 * $$$i8$i$i166);
     $181 = Math_fround($161 + $178);
     $182 = Math_fround($163 + $179);
     $183 = Math_fround($165 + $180);
     HEAPF32[$closA>>2] = $175;
     HEAPF32[$18>>2] = $176;
     HEAPF32[$19>>2] = $177;
     HEAPF32[$20>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $181;
     HEAPF32[$21>>2] = $182;
     HEAPF32[$22>>2] = $183;
     HEAPF32[$23>>2] = Math_fround(0.0);
     $184 = Math_fround($175 - $181);
     $185 = Math_fround($176 - $182);
     $186 = Math_fround($177 - $183);
     HEAPF32[$4>>2] = $184;
     $187 = (($4) + 4|0);
     HEAPF32[$187>>2] = $185;
     $188 = (($4) + 8|0);
     HEAPF32[$188>>2] = $186;
     $189 = (($4) + 12|0);
     HEAPF32[$189>>2] = Math_fround(0.0);
     break;
    }
   } else if ((($umax|0) == 1)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  $191 = Math_fround(HEAPF32[$4>>2]);
  $192 = (($4) + 4|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($4) + 8|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = Math_fround($191 * $191);
  $197 = Math_fround($193 * $193);
  $198 = Math_fround($196 + $197);
  $199 = Math_fround($195 * $195);
  $200 = Math_fround($198 + $199);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $201 = Math_fround(HEAPF32[$closA>>2]);
  $202 = Math_fround(HEAPF32[$18>>2]);
  $203 = Math_fround(HEAPF32[$19>>2]);
  $204 = Math_fround(HEAPF32[$20>>2]);
  $205 = Math_fround(HEAPF32[$closB>>2]);
  $206 = Math_fround(HEAPF32[$21>>2]);
  $207 = Math_fround(HEAPF32[$22>>2]);
  $208 = Math_fround(HEAPF32[$23>>2]);
  $209 = $200 > $24;
  $$ph = $204;$$ph769 = $203;$$ph770 = $202;$$ph771 = $201;$$ph772 = $208;$$ph773 = $207;$$ph774 = $206;$$ph775 = $205;$$ph777 = $200;$$ph778 = $209;$$ph782 = $195;$$ph783 = $193;$$ph784 = $191;
 }
 do {
  if ($$ph778) {
   $234 = (($aToB) + 4|0);
   $235 = (($aToB) + 8|0);
   $236 = (($aToB) + 16|0);
   $237 = (($aToB) + 20|0);
   $238 = (($aToB) + 24|0);
   $239 = (($aToB) + 32|0);
   $240 = (($aToB) + 36|0);
   $241 = (($aToB) + 40|0);
   $242 = (($0) + 4|0);
   $243 = (($0) + 8|0);
   $244 = (($0) + 12|0);
   $245 = (($aToB) + 48|0);
   $246 = (($aToB) + 52|0);
   $247 = (($aToB) + 56|0);
   $248 = (($1) + 4|0);
   $249 = (($1) + 8|0);
   $250 = (($supportA1) + 4|0);
   $251 = (($supportA1) + 8|0);
   $252 = (($supportA1) + 12|0);
   $253 = (($b) + 144|0);
   $254 = (($b) + 148|0);
   $255 = (($b) + 152|0);
   $256 = (($1) + 4|0);
   $257 = (($1) + 8|0);
   $258 = (($1) + 12|0);
   $259 = (($0) + 4|0);
   $260 = (($0) + 8|0);
   $261 = (($0) + 12|0);
   $262 = (($supportB2) + 4|0);
   $263 = (($supportB2) + 8|0);
   $264 = (($supportB2) + 12|0);
   $265 = (($support3) + 4|0);
   $266 = (($support3) + 8|0);
   $267 = (($support3) + 12|0);
   $268 = (($a) + 48|0);
   $269 = (($b) + 48|0);
   $270 = (($5) + 4|0);
   $271 = (($5) + 8|0);
   $272 = (($Q) + 4|0);
   $273 = (($Q) + 8|0);
   $274 = (($A) + 4|0);
   $275 = (($A) + 8|0);
   $276 = (($B) + 4|0);
   $277 = (($B) + 8|0);
   $278 = (($5) + 12|0);
   $279 = (($Q) + 16|0);
   $$$i749819 = $10;$281 = $$ph784;$283 = $$ph783;$285 = $$ph782;$386 = $$ph777;$519 = $$ph771;$520 = $$ph770;$521 = $$ph769;$522 = $$ph;$523 = $$ph775;$524 = $$ph774;$525 = $$ph773;$526 = $$ph772;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    $280 = Math_fround(-$281);
    $282 = Math_fround(-$283);
    $284 = Math_fround(-$285);
    $286 = HEAP32[$size>>2]|0;
    $287 = (($A) + ($286<<4)|0);
    $288 = (($aInd) + ($286<<2)|0);
    $289 = Math_fround(HEAPF32[$aToB>>2]);
    $290 = Math_fround($289 * $280);
    $291 = Math_fround(HEAPF32[$234>>2]);
    $292 = Math_fround($291 * $282);
    $293 = Math_fround($290 + $292);
    $294 = Math_fround(HEAPF32[$235>>2]);
    $295 = Math_fround($294 * $284);
    $296 = Math_fround($293 + $295);
    $297 = Math_fround(HEAPF32[$236>>2]);
    $298 = Math_fround($297 * $280);
    $299 = Math_fround(HEAPF32[$237>>2]);
    $300 = Math_fround($299 * $282);
    $301 = Math_fround($298 + $300);
    $302 = Math_fround(HEAPF32[$238>>2]);
    $303 = Math_fround($302 * $284);
    $304 = Math_fround($301 + $303);
    $305 = Math_fround(HEAPF32[$239>>2]);
    $306 = Math_fround($305 * $280);
    $307 = Math_fround(HEAPF32[$240>>2]);
    $308 = Math_fround($307 * $282);
    $309 = Math_fround($306 + $308);
    $310 = Math_fround(HEAPF32[$241>>2]);
    $311 = Math_fround($310 * $284);
    $312 = Math_fround($309 + $311);
    HEAPF32[$0>>2] = $296;
    HEAPF32[$242>>2] = $304;
    HEAPF32[$243>>2] = $312;
    HEAPF32[$244>>2] = Math_fround(0.0);
    __ZNK5physx2Gu9TriangleV12supportLocalERKNS_6shdfnd3aos5Vec3VERi($1,$a,$0,$288);
    ;HEAP32[$287+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$287+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$287+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$287+12>>2]=HEAP32[$1+12>>2]|0;
    $313 = Math_fround(HEAPF32[$245>>2]);
    $314 = Math_fround(HEAPF32[$246>>2]);
    $315 = Math_fround(HEAPF32[$247>>2]);
    $316 = Math_fround(HEAPF32[$1>>2]);
    $317 = Math_fround(HEAPF32[$248>>2]);
    $318 = Math_fround(HEAPF32[$249>>2]);
    $319 = Math_fround(HEAPF32[$aToB>>2]);
    $320 = Math_fround($316 * $319);
    $321 = Math_fround(HEAPF32[$236>>2]);
    $322 = Math_fround($317 * $321);
    $323 = Math_fround($320 + $322);
    $324 = Math_fround(HEAPF32[$239>>2]);
    $325 = Math_fround($318 * $324);
    $326 = Math_fround($323 + $325);
    $327 = Math_fround(HEAPF32[$234>>2]);
    $328 = Math_fround($316 * $327);
    $329 = Math_fround(HEAPF32[$237>>2]);
    $330 = Math_fround($317 * $329);
    $331 = Math_fround($328 + $330);
    $332 = Math_fround(HEAPF32[$240>>2]);
    $333 = Math_fround($318 * $332);
    $334 = Math_fround($331 + $333);
    $335 = Math_fround(HEAPF32[$235>>2]);
    $336 = Math_fround($316 * $335);
    $337 = Math_fround(HEAPF32[$238>>2]);
    $338 = Math_fround($317 * $337);
    $339 = Math_fround($336 + $338);
    $340 = Math_fround(HEAPF32[$241>>2]);
    $341 = Math_fround($318 * $340);
    $342 = Math_fround($339 + $341);
    $343 = Math_fround($313 + $326);
    $344 = Math_fround($314 + $334);
    $345 = Math_fround($315 + $342);
    HEAPF32[$supportA1>>2] = $343;
    HEAPF32[$250>>2] = $344;
    HEAPF32[$251>>2] = $345;
    HEAPF32[$252>>2] = Math_fround(0.0);
    $346 = HEAP32[$size>>2]|0;
    $347 = (($B) + ($346<<4)|0);
    $348 = (($bInd) + ($346<<2)|0);
    $349 = Math_fround(HEAPF32[$253>>2]);
    $350 = Math_fround(HEAPF32[$254>>2]);
    $351 = Math_fround(HEAPF32[$255>>2]);
    $352 = Math_fround(HEAPF32[$8>>2]);
    $353 = Math_fround($349 - $352);
    $354 = Math_fround($350 - $352);
    $355 = Math_fround($351 - $352);
    $356 = $281 > Math_fround(0.0);
    $357 = $283 > Math_fround(0.0);
    $358 = $357 << 31 >> 31;
    $359 = $285 > Math_fround(0.0);
    $360 = $359 << 31 >> 31;
    $361 = $356&1;
    $362 = $358 << 1;
    $363 = $362 & 2;
    $364 = $360 << 2;
    $365 = $364 & 4;
    $366 = $365 | $361;
    $367 = $366 | $363;
    HEAP32[$348>>2] = $367;
    $368 = Math_fround(-$353);
    $369 = Math_fround(-$354);
    $370 = Math_fround(-$355);
    HEAPF32[$1>>2] = $353;
    HEAPF32[$256>>2] = $354;
    HEAPF32[$257>>2] = $355;
    HEAPF32[$258>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $368;
    HEAPF32[$259>>2] = $369;
    HEAPF32[$260>>2] = $370;
    HEAPF32[$261>>2] = Math_fround(0.0);
    $b$a$i$i = $356 ? $1 : $0;
    $371 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $357 ? $1 : $0;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $372 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $359 ? $1 : $0;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $373 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    HEAPF32[$supportB2>>2] = $371;
    HEAPF32[$262>>2] = $372;
    HEAPF32[$263>>2] = $373;
    HEAPF32[$264>>2] = Math_fround(0.0);
    ;HEAP32[$347+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$347+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$347+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$347+12>>2]=HEAP32[$supportB2+12>>2]|0;
    $374 = Math_fround($343 - $371);
    $375 = Math_fround($344 - $372);
    $376 = Math_fround($345 - $373);
    HEAPF32[$support3>>2] = $374;
    HEAPF32[$265>>2] = $375;
    HEAPF32[$266>>2] = $376;
    HEAPF32[$267>>2] = Math_fround(0.0);
    $377 = (($346) + 1)|0;
    HEAP32[$size>>2] = $377;
    $378 = (($Q) + ($346<<4)|0);
    ;HEAP32[$378+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$378+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$378+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$378+12>>2]=HEAP32[$support3+12>>2]|0;
    $379 = Math_fround(HEAPF32[$268>>2]);
    $380 = Math_fround(HEAPF32[$269>>2]);
    $381 = $379 > $380;
    $$$i134 = $381 ? $379 : $380;
    $382 = $$$i749819 > $$$i134;
    $$$i = $382 ? $$$i749819 : $$$i134;
    $383 = Math_fround($17 + $$$i);
    $384 = Math_fround($383 * $383);
    $385 = Math_fround($386 * $384);
    $387 = Math_fround($281 * $374);
    $388 = Math_fround($283 * $375);
    $389 = Math_fround($387 + $388);
    $390 = Math_fround($285 * $376);
    $391 = Math_fround($389 + $390);
    $392 = Math_fround($391 * $391);
    $393 = $391 > Math_fround(0.0);
    $394 = $392 > $385;
    if ($393) {
     $phitmp765 = $394 ^ 1;
     $398 = $394;$400 = $phitmp765;
    } else {
     $398 = 0;$400 = 1;
    }
    $395 = Math_fround($386 - $391);
    $396 = Math_fround($24 * $386);
    $397 = $396 >= $395;
    $brmerge$demorgan = $397 | $398;
    if ($brmerge$demorgan) {
     $399 = $400 ^ 1;
     $$757 = $397 | $399;
     if ($$757) {
      break;
     }
    }
    do {
     if ((($346|0) == 1)) {
      $447 = Math_fround(HEAPF32[$Q>>2]);
      $448 = Math_fround(HEAPF32[$272>>2]);
      $449 = Math_fround(HEAPF32[$273>>2]);
      $450 = Math_fround($374 - $447);
      $451 = Math_fround($375 - $448);
      $452 = Math_fround($376 - $449);
      $453 = Math_fround($450 * $450);
      $454 = Math_fround($451 * $451);
      $455 = Math_fround($453 + $454);
      $456 = Math_fround($452 * $452);
      $457 = Math_fround($455 + $456);
      $458 = $457 == Math_fround(0.0);
      if ($458) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$5+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $459 = Math_fround($448 * $451);
       $460 = Math_fround(-$459);
       $461 = Math_fround($447 * $450);
       $462 = Math_fround($460 - $461);
       $463 = Math_fround($449 * $452);
       $464 = Math_fround($462 - $463);
       $465 = Math_fround(HEAPF32[$A>>2]);
       $466 = Math_fround(HEAPF32[$274>>2]);
       $467 = Math_fround(HEAPF32[$275>>2]);
       $468 = Math_fround($343 - $465);
       $469 = Math_fround($344 - $466);
       $470 = Math_fround($345 - $467);
       $471 = Math_fround(HEAPF32[$B>>2]);
       $472 = Math_fround(HEAPF32[$276>>2]);
       $473 = Math_fround(HEAPF32[$277>>2]);
       $474 = Math_fround($371 - $471);
       $475 = Math_fround($372 - $472);
       $476 = Math_fround($373 - $473);
       $477 = Math_fround($464 / $457);
       $478 = $477 > Math_fround(1.0);
       $$$i$i$i = $478 ? Math_fround(1.0) : $477;
       $479 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $479 ? $$$i$i$i : Math_fround(0.0);
       $480 = Math_fround($468 * $$$i8$i$i);
       $481 = Math_fround($469 * $$$i8$i$i);
       $482 = Math_fround($470 * $$$i8$i$i);
       $483 = Math_fround($465 + $480);
       $484 = Math_fround($466 + $481);
       $485 = Math_fround($467 + $482);
       $486 = Math_fround($474 * $$$i8$i$i);
       $487 = Math_fround($475 * $$$i8$i$i);
       $488 = Math_fround($476 * $$$i8$i$i);
       $489 = Math_fround($471 + $486);
       $490 = Math_fround($472 + $487);
       $491 = Math_fround($473 + $488);
       HEAPF32[$closA>>2] = $483;
       HEAPF32[$18>>2] = $484;
       HEAPF32[$19>>2] = $485;
       HEAPF32[$20>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $489;
       HEAPF32[$21>>2] = $490;
       HEAPF32[$22>>2] = $491;
       HEAPF32[$23>>2] = Math_fround(0.0);
       $492 = Math_fround($483 - $489);
       $493 = Math_fround($484 - $490);
       $494 = Math_fround($485 - $491);
       HEAPF32[$5>>2] = $492;
       HEAPF32[$270>>2] = $493;
       HEAPF32[$271>>2] = $494;
       HEAPF32[$278>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($346|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($5,$Q,$A,$B,$aInd,$bInd,$support3,$supportA1,$supportB2,$size,$closA,$closB);
     } else if ((($346|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($5,$Q,$279,$support3,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($346|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA1+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA1+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA1+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA1+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB2+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB2+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB2+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB2+12>>2]|0;
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     } else {
      ;HEAP32[$5+0>>2]=HEAP32[$support3+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$support3+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$support3+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$support3+12>>2]|0;
     }
    } while(0);
    $495 = Math_fround(HEAPF32[$5>>2]);
    $496 = Math_fround(HEAPF32[$270>>2]);
    $497 = Math_fround(HEAPF32[$271>>2]);
    $498 = Math_fround($495 * $495);
    $499 = Math_fround($496 * $496);
    $500 = Math_fround($498 + $499);
    $501 = Math_fround($497 * $497);
    $502 = Math_fround($500 + $501);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1238+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1238+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1238+8>>2]|0;
    $503 = $386 > $502;
    $504 = $502 > $24;
    if (!($504)) {
     label = 37;
     break;
    }
    if (!($503)) {
     label = 37;
     break;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre866 = Math_fround(HEAPF32[$18>>2]);
    $$pre867 = Math_fround(HEAPF32[$19>>2]);
    $$pre868 = Math_fround(HEAPF32[$20>>2]);
    $$pre869 = Math_fround(HEAPF32[$closB>>2]);
    $$pre870 = Math_fround(HEAPF32[$21>>2]);
    $$pre871 = Math_fround(HEAPF32[$22>>2]);
    $$pre872 = Math_fround(HEAPF32[$23>>2]);
    $$$i749819 = $$$i;$281 = $495;$283 = $496;$285 = $497;$386 = $502;$519 = $$pre;$520 = $$pre866;$521 = $$pre867;$522 = $$pre868;$523 = $$pre869;$524 = $$pre870;$525 = $$pre871;$526 = $$pre872;
   }
   if ((label|0) == 37) {
    $505 = HEAP32[$size>>2]|0;
    if ($503) {
     $560 = $505;
     break;
    }
    $506 = (($505) + -1)|0;
    $507 = ($aIndices|0)==(0|0);
    if (!($507)) {
     $508 = $506&255;
     HEAP8[$_size>>0] = $508;
     $509 = ($506|0)==(0);
     if (!($509)) {
      $i$01$i29 = 0;
      while(1) {
       $510 = (($aInd) + ($i$01$i29<<2)|0);
       $511 = HEAP32[$510>>2]|0;
       $512 = $511&255;
       $513 = (($aIndices) + ($i$01$i29)|0);
       HEAP8[$513>>0] = $512;
       $514 = (($bInd) + ($i$01$i29<<2)|0);
       $515 = HEAP32[$514>>2]|0;
       $516 = $515&255;
       $517 = (($bIndices) + ($i$01$i29)|0);
       HEAP8[$517>>0] = $516;
       $518 = (($i$01$i29) + 1)|0;
       $exitcond$i30 = ($518|0)==($506|0);
       if ($exitcond$i30) {
        break;
       } else {
        $i$01$i29 = $518;
       }
      }
     }
    }
    HEAPF32[$closA>>2] = $519;
    HEAPF32[$18>>2] = $520;
    HEAPF32[$19>>2] = $521;
    HEAPF32[$20>>2] = $522;
    HEAPF32[$closB>>2] = $523;
    HEAPF32[$21>>2] = $524;
    HEAPF32[$22>>2] = $525;
    HEAPF32[$23>>2] = $526;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $527 = Math_fround($519 - $523);
    $528 = Math_fround($520 - $524);
    $529 = Math_fround($521 - $525);
    $530 = (Math_fround(Math_sqrt((Math_fround($386)))));
    $531 = Math_fround(Math_fround(1.0) / $530);
    $532 = Math_fround($527 * $531);
    $533 = Math_fround($528 * $531);
    $534 = Math_fround($529 * $531);
    $535 = Math_fround($7 * $532);
    $536 = Math_fround($7 * $533);
    $537 = Math_fround($7 * $534);
    $538 = Math_fround($519 - $535);
    $539 = Math_fround($520 - $536);
    $540 = Math_fround($521 - $537);
    HEAPF32[$contactA>>2] = $538;
    $541 = (($contactA) + 4|0);
    HEAPF32[$541>>2] = $539;
    $542 = (($contactA) + 8|0);
    HEAPF32[$542>>2] = $540;
    $543 = (($contactA) + 12|0);
    HEAPF32[$543>>2] = Math_fround(0.0);
    $544 = Math_fround($9 * $532);
    $545 = Math_fround($9 * $533);
    $546 = Math_fround($9 * $534);
    $547 = Math_fround($544 + $523);
    $548 = Math_fround($545 + $524);
    $549 = Math_fround($546 + $525);
    HEAPF32[$contactB>>2] = $547;
    $550 = (($contactB) + 4|0);
    HEAPF32[$550>>2] = $548;
    $551 = (($contactB) + 8|0);
    HEAPF32[$551>>2] = $549;
    $552 = (($contactB) + 12|0);
    HEAPF32[$552>>2] = Math_fround(0.0);
    $553 = Math_fround($530 - $17);
    HEAPF32[$penetrationDepth>>2] = $553;
    $554 = (($penetrationDepth) + 4|0);
    ;HEAP32[$554+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$554+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$554+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
    HEAPF32[$normal>>2] = $532;
    $555 = (($normal) + 4|0);
    HEAPF32[$555>>2] = $533;
    $556 = (($normal) + 8|0);
    HEAPF32[$556>>2] = $534;
    $557 = (($normal) + 12|0);
    HEAPF32[$557>>2] = Math_fround(0.0);
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   }
   $401 = ($aIndices|0)==(0|0);
   if (!($401)) {
    $402 = $346&255;
    HEAP8[$_size>>0] = $402;
    $403 = ($346|0)==(0);
    if (!($403)) {
     $i$01$i72 = 0;
     while(1) {
      $404 = (($aInd) + ($i$01$i72<<2)|0);
      $405 = HEAP32[$404>>2]|0;
      $406 = $405&255;
      $407 = (($aIndices) + ($i$01$i72)|0);
      HEAP8[$407>>0] = $406;
      $408 = (($bInd) + ($i$01$i72<<2)|0);
      $409 = HEAP32[$408>>2]|0;
      $410 = $409&255;
      $411 = (($bIndices) + ($i$01$i72)|0);
      HEAP8[$411>>0] = $410;
      $412 = (($i$01$i72) + 1)|0;
      $exitcond$i73 = ($412|0)==($346|0);
      if ($exitcond$i73) {
       break;
      } else {
       $i$01$i72 = $412;
      }
     }
    }
   }
   $not$ = $398 ^ 1;
   $$$761 = $400 & $not$;
   if (!($$$761)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $413 = (Math_fround(Math_sqrt((Math_fround($386)))));
   $414 = Math_fround(Math_fround(1.0) / $413);
   $415 = Math_fround($281 * $414);
   $416 = Math_fround($283 * $414);
   $417 = Math_fround($285 * $414);
   $418 = Math_fround(HEAPF32[$closA>>2]);
   $419 = Math_fround(HEAPF32[$18>>2]);
   $420 = Math_fround(HEAPF32[$19>>2]);
   $421 = Math_fround($7 * $415);
   $422 = Math_fround($7 * $416);
   $423 = Math_fround($7 * $417);
   $424 = Math_fround($418 - $421);
   $425 = Math_fround($419 - $422);
   $426 = Math_fround($420 - $423);
   HEAPF32[$contactA>>2] = $424;
   $427 = (($contactA) + 4|0);
   HEAPF32[$427>>2] = $425;
   $428 = (($contactA) + 8|0);
   HEAPF32[$428>>2] = $426;
   $429 = (($contactA) + 12|0);
   HEAPF32[$429>>2] = Math_fround(0.0);
   $430 = Math_fround(HEAPF32[$closB>>2]);
   $431 = Math_fround(HEAPF32[$21>>2]);
   $432 = Math_fround(HEAPF32[$22>>2]);
   $433 = Math_fround($9 * $415);
   $434 = Math_fround($9 * $416);
   $435 = Math_fround($9 * $417);
   $436 = Math_fround($433 + $430);
   $437 = Math_fround($434 + $431);
   $438 = Math_fround($435 + $432);
   HEAPF32[$contactB>>2] = $436;
   $439 = (($contactB) + 4|0);
   HEAPF32[$439>>2] = $437;
   $440 = (($contactB) + 8|0);
   HEAPF32[$440>>2] = $438;
   $441 = (($contactB) + 12|0);
   HEAPF32[$441>>2] = Math_fround(0.0);
   $442 = Math_fround($413 - $17);
   HEAPF32[$penetrationDepth>>2] = $442;
   $443 = (($penetrationDepth) + 4|0);
   ;HEAP32[$443+0>>2]=HEAP32[$$sroa$1240+0>>2]|0;HEAP32[$443+4>>2]=HEAP32[$$sroa$1240+4>>2]|0;HEAP32[$443+8>>2]=HEAP32[$$sroa$1240+8>>2]|0;
   HEAPF32[$normal>>2] = $415;
   $444 = (($normal) + 4|0);
   HEAPF32[$444>>2] = $416;
   $445 = (($normal) + 8|0);
   HEAPF32[$445>>2] = $417;
   $446 = (($normal) + 12|0);
   HEAPF32[$446>>2] = Math_fround(0.0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $233 = HEAP32[$size>>2]|0;
   $560 = $233;
  }
 } while(0);
 $558 = ($aIndices|0)==(0|0);
 if (!($558)) {
  $559 = $560&255;
  HEAP8[$_size>>0] = $559;
  $561 = ($560|0)==(0);
  if (!($561)) {
   $i$01$i = 0;
   while(1) {
    $562 = (($aInd) + ($i$01$i<<2)|0);
    $563 = HEAP32[$562>>2]|0;
    $564 = $563&255;
    $565 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$565>>0] = $564;
    $566 = (($bInd) + ($i$01$i<<2)|0);
    $567 = HEAP32[$566>>2]|0;
    $568 = $567&255;
    $569 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$569>>0] = $568;
    $570 = (($i$01$i) + 1)|0;
    $exitcond$i = ($570|0)==($560|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $570;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_($this,$indexA,$indexB,$supportA,$supportB,$support) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0;
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5) + ($indexA<<4)|0) + 96|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($5) + ($indexA<<4)|0) + 100|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($5) + ($indexA<<4)|0) + 104|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($3) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($3) + 52|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($3) + 56|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$3>>2]);
 $19 = Math_fround($7 * $18);
 $20 = (($3) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($9 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($3) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($11 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($3) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($7 * $29);
 $31 = (($3) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($9 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($3) + 36|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($11 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($3) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($7 * $40);
 $42 = (($3) + 24|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($9 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($3) + 40|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($11 * $47);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround($13 + $27);
 $51 = Math_fround($15 + $38);
 $52 = Math_fround($17 + $49);
 $53 = (($this) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (549664 + ($indexB<<4)|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((549664 + ($indexB<<4)|0) + 4|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ((549664 + ($indexB<<4)|0) + 8|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($54) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$61+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$61+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$61+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$61+12>>2]|0;
 $62 = (($54) + 144|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($54) + 148|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($54) + 152|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround(-$63);
 $69 = Math_fround(-$65);
 $70 = Math_fround(-$67);
 HEAPF32[$0>>2] = $68;
 $71 = (($0) + 4|0);
 HEAPF32[$71>>2] = $69;
 $72 = (($0) + 8|0);
 HEAPF32[$72>>2] = $70;
 $73 = (($0) + 12|0);
 HEAPF32[$73>>2] = Math_fround(0.0);
 $74 = ($56|0)==(0);
 $b$a$i$i = $74 ? $0 : $1;
 $75 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $76 = ($58|0)==(0);
 $a$pn3$i$i = $76 ? $0 : $1;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $77 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $78 = ($60|0)==(0);
 $b$a5$i$i = $78 ? $0 : $1;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $79 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$supportA>>2] = $50;
 $80 = (($supportA) + 4|0);
 HEAPF32[$80>>2] = $51;
 $81 = (($supportA) + 8|0);
 HEAPF32[$81>>2] = $52;
 $82 = (($supportA) + 12|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 HEAPF32[$supportB>>2] = $75;
 $83 = (($supportB) + 4|0);
 HEAPF32[$83>>2] = $77;
 $84 = (($supportB) + 8|0);
 HEAPF32[$84>>2] = $79;
 $85 = (($supportB) + 12|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 $86 = Math_fround($50 - $75);
 $87 = Math_fround($51 - $77);
 $88 = Math_fround($52 - $79);
 HEAPF32[$support>>2] = $86;
 $89 = (($support) + 4|0);
 HEAPF32[$89>>2] = $87;
 $90 = (($support) + 8|0);
 HEAPF32[$90>>2] = $88;
 $91 = (($support) + 12|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_($this,$dir,$supportA,$supportB,$support) {
 $this = $this|0;
 $dir = $dir|0;
 $supportA = $supportA|0;
 $supportB = $supportB|0;
 $support = $support|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0;
 var $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $_sa = 0, $a$pn3$i$i = 0;
 var $b$a$i$i = 0, $b$a5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $_sa = sp + 16|0;
 $2 = sp + 32|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$dir>>2]);
 $6 = (($dir) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($dir) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(-$5);
 $11 = Math_fround(-$7);
 $12 = Math_fround(-$9);
 HEAPF32[$2>>2] = $10;
 $13 = (($2) + 4|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($2) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($2) + 12|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 __ZNK5physx2Gu9TriangleV15supportRelativeERKNS_6shdfnd3aos5Vec3VERKNS3_15PsMatTransformVE($_sa,$4,$2,$17);
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = Math_fround(HEAPF32[$dir>>2]);
 $21 = Math_fround(HEAPF32[$6>>2]);
 $22 = Math_fround(HEAPF32[$8>>2]);
 $23 = $20 > Math_fround(0.0);
 $24 = $21 > Math_fround(0.0);
 $25 = $22 > Math_fround(0.0);
 $26 = (($19) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$26+12>>2]|0;
 $27 = (($19) + 144|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($19) + 148|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($19) + 152|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(-$28);
 $34 = Math_fround(-$30);
 $35 = Math_fround(-$32);
 HEAPF32[$0>>2] = $33;
 $36 = (($0) + 4|0);
 HEAPF32[$36>>2] = $34;
 $37 = (($0) + 8|0);
 HEAPF32[$37>>2] = $35;
 $38 = (($0) + 12|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $b$a$i$i = $23 ? $1 : $0;
 $39 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $a$pn3$i$i = $24 ? $1 : $0;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $40 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $b$a5$i$i = $25 ? $1 : $0;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $41 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 ;HEAP32[$supportA+0>>2]=HEAP32[$_sa+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$_sa+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$_sa+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$_sa+12>>2]|0;
 HEAPF32[$supportB>>2] = $39;
 $42 = (($supportB) + 4|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($supportB) + 8|0);
 HEAPF32[$43>>2] = $41;
 $44 = (($supportB) + 12|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = Math_fround(HEAPF32[$_sa>>2]);
 $46 = (($_sa) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($_sa) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($45 - $39);
 $51 = Math_fround($47 - $40);
 $52 = Math_fround($49 - $41);
 HEAPF32[$support>>2] = $50;
 $53 = (($support) + 4|0);
 HEAPF32[$53>>2] = $51;
 $54 = (($support) + 8|0);
 HEAPF32[$54>>2] = $52;
 $55 = (($support) + 12|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEE6getDirEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16_gjkLocalRayCastINS0_8CapsuleVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VESF_RSA_RSD_SH_f($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i185 = 0, $$in1$i200 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i186 = 0, $$in2$i202 = 0, $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa924 = Math_fround(0), $$lcssa926 = Math_fround(0), $$lcssa928 = Math_fround(0);
 var $$lcssa930 = Math_fround(0), $$lcssa932 = Math_fround(0), $$lcssa934 = Math_fround(0), $$lcssa936 = Math_fround(0), $$lcssa938 = Math_fround(0), $$lcssa940 = 0, $$lcssa942 = Math_fround(0), $$lcssa944 = Math_fround(0), $$lcssa946 = Math_fround(0), $$pre = Math_fround(0), $$pre980 = Math_fround(0), $$pre981 = Math_fround(0), $$pre982 = Math_fround(0), $$sroa$1320 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0;
 var $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0);
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0);
 var $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0);
 var $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0);
 var $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0);
 var $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0);
 var $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = 0;
 var $32 = Math_fround(0), $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0);
 var $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0);
 var $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0);
 var $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0);
 var $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = Math_fround(0);
 var $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0);
 var $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0;
 var $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $b$a$i = 0, $b$a$i$i$i = 0, $b$a$i$i$i183 = 0, $b$a$i18 = 0, $b$a$i197 = 0, $b$a5$i = 0, $closA = 0, $closB = 0, $initialSearchDir = 0, $initialSupportB = 0, $nvNorm = 0, $phitmp = 0, $phitmp917 = 0;
 var $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $0 = sp + 336|0;
 $1 = sp + 496|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $4 = sp + 384|0;
 $5 = sp + 400|0;
 $6 = sp + 432|0;
 $7 = sp + 416|0;
 $8 = sp + 448|0;
 $9 = sp + 464|0;
 $zeroV = sp + 480|0;
 $zero$sroa$1 = sp + 528|0;
 $_lambda$sroa$1 = sp + 540|0;
 $size = sp + 524|0;
 $initialSearchDir = sp + 208|0;
 $initialSupportB = sp;
 $Q = sp + 16|0;
 $A = sp + 80|0;
 $B = sp + 144|0;
 $support = sp + 224|0;
 $closA = sp + 240|0;
 $closB = sp + 256|0;
 $nvNorm = sp + 272|0;
 $10 = sp + 288|0;
 $$sroa$1320 = sp + 512|0;
 $11 = sp + 304|0;
 $tempV = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $12 = Math_fround(HEAPF32[$r>>2]);
 $13 = (($r) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($r) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$s>>2]);
 $18 = (($s) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($s) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAP32[$size>>2] = 1;
 $22 = Math_fround(HEAPF32[$a>>2]);
 $23 = (($a) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($a) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(HEAPF32[$b>>2]);
 $28 = (($b) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($b) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($22 - $27);
 $33 = Math_fround($24 - $29);
 $34 = Math_fround($26 - $31);
 $35 = Math_fround($32 * $32);
 $36 = Math_fround($33 * $33);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($34 * $34);
 $39 = Math_fround($37 + $38);
 $40 = $39 > Math_fround(1.1920928955078125E-7);
 HEAPF32[$1>>2] = $32;
 $41 = (($1) + 4|0);
 HEAPF32[$41>>2] = $33;
 $42 = (($1) + 8|0);
 HEAPF32[$42>>2] = $34;
 $43 = (($1) + 12|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $44 = (($0) + 4|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($0) + 8|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($0) + 12|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $b$a$i197 = $40 ? $1 : $0;
 $47 = Math_fround(HEAPF32[$b$a$i197>>2]);
 $$in1$i200 = (($b$a$i197) + 4|0);
 $48 = Math_fround(HEAPF32[$$in1$i200>>2]);
 $$in2$i202 = (($b$a$i197) + 8|0);
 $49 = Math_fround(HEAPF32[$$in2$i202>>2]);
 $50 = Math_fround($47 * $47);
 $51 = Math_fround($48 * $48);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($49 * $49);
 $54 = Math_fround($52 + $53);
 $55 = (Math_fround(Math_sqrt((Math_fround($54)))));
 $56 = Math_fround(Math_fround(1.0) / $55);
 $57 = Math_fround($47 * $56);
 $58 = Math_fround($48 * $56);
 $59 = Math_fround($49 * $56);
 HEAPF32[$initialSearchDir>>2] = $57;
 $60 = (($initialSearchDir) + 4|0);
 HEAPF32[$60>>2] = $58;
 $61 = (($initialSearchDir) + 8|0);
 HEAPF32[$61>>2] = $59;
 $62 = (($initialSearchDir) + 12|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = Math_fround(-$57);
 $64 = Math_fround(-$58);
 $65 = Math_fround(-$59);
 $66 = (($a) + 96|0);
 $67 = (($a) + 96|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($a) + 100|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($a) + 104|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($68 * $63);
 $74 = Math_fround($70 * $64);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($72 * $65);
 $77 = Math_fround($75 + $76);
 $78 = (($a) + 112|0);
 $79 = (($a) + 112|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($a) + 116|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($a) + 120|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($80 * $63);
 $86 = Math_fround($82 * $64);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($84 * $65);
 $89 = Math_fround($87 + $88);
 $90 = $77 > $89;
 ;HEAP32[$3+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$66+12>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$78+12>>2]|0;
 $b$a$i$i$i183 = $90 ? $3 : $2;
 $91 = Math_fround(HEAPF32[$b$a$i$i$i183>>2]);
 $$in1$i$i$i185 = (($b$a$i$i$i183) + 4|0);
 $92 = Math_fround(HEAPF32[$$in1$i$i$i185>>2]);
 $$in2$i$i$i186 = (($b$a$i$i$i183) + 8|0);
 $93 = Math_fround(HEAPF32[$$in2$i$i$i186>>2]);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($initialSupportB,$b,$initialSearchDir);
 $94 = Math_fround(HEAPF32[$initialSupportB>>2]);
 $95 = (($initialSupportB) + 4|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($initialSupportB) + 8|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($91 - $94);
 $100 = Math_fround($92 - $96);
 $101 = Math_fround($93 - $98);
 HEAPF32[$Q>>2] = $99;
 $102 = (($Q) + 4|0);
 HEAPF32[$102>>2] = $100;
 $103 = (($Q) + 8|0);
 HEAPF32[$103>>2] = $101;
 $104 = (($Q) + 12|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($Q) + 16|0);
 ;HEAP32[$105+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$105+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$105+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$105+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $106 = (($Q) + 32|0);
 ;HEAP32[$106+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $107 = (($Q) + 48|0);
 ;HEAP32[$107+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$107+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$107+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$107+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $91;
 $108 = (($A) + 4|0);
 HEAPF32[$108>>2] = $92;
 $109 = (($A) + 8|0);
 HEAPF32[$109>>2] = $93;
 $110 = (($A) + 12|0);
 HEAPF32[$110>>2] = Math_fround(0.0);
 $111 = (($A) + 16|0);
 ;HEAP32[$111+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$111+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$111+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$111+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $112 = (($A) + 32|0);
 ;HEAP32[$112+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$112+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$112+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$112+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $113 = (($A) + 48|0);
 ;HEAP32[$113+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$113+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$B+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $114 = (($B) + 16|0);
 ;HEAP32[$114+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$114+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$114+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$114+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $115 = (($B) + 32|0);
 ;HEAP32[$115+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$115+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$115+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$115+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $116 = (($B) + 48|0);
 ;HEAP32[$116+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$116+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$116+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $117 = Math_fround(-$99);
 $118 = Math_fround(-$100);
 $119 = Math_fround(-$101);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $120 = (($a) + 32|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($b) + 32|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = $121 > $123;
 $$$i = $124 ? $123 : $121;
 $125 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $126 = Math_fround($125 * $125);
 $127 = Math_fround($_inflation * $_inflation);
 $128 = Math_fround($127 + $126);
 HEAPF32[$closA>>2] = $91;
 $129 = (($closA) + 4|0);
 HEAPF32[$129>>2] = $92;
 $130 = (($closA) + 8|0);
 HEAPF32[$130>>2] = $93;
 $131 = (($closA) + 12|0);
 HEAPF32[$131>>2] = Math_fround(0.0);
 ;HEAP32[$closB+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $132 = Math_fround($99 * $99);
 $133 = Math_fround($100 * $100);
 $134 = Math_fround($132 + $133);
 $135 = Math_fround($101 * $101);
 $136 = Math_fround($134 + $135);
 $137 = $136 > $126;
 L1: do {
  if ($137) {
   $138 = Math_fround($16 * Math_fround(0.0));
   $139 = Math_fround($14 * Math_fround(0.0));
   $140 = Math_fround($12 * Math_fround(0.0));
   $141 = Math_fround($138 + $21);
   $142 = Math_fround($139 + $19);
   $143 = Math_fround($140 + $17);
   $144 = (($nvNorm) + 4|0);
   $145 = (($nvNorm) + 8|0);
   $146 = (($nvNorm) + 12|0);
   $147 = (($10) + 4|0);
   $148 = (($10) + 8|0);
   $149 = (($support) + 4|0);
   $150 = (($support) + 8|0);
   $151 = (($support) + 12|0);
   $152 = (($B) + 4|0);
   $153 = (($B) + 8|0);
   $154 = (($B) + 12|0);
   $155 = (($B) + 16|0);
   $156 = (($B) + 20|0);
   $157 = (($B) + 24|0);
   $158 = (($B) + 28|0);
   $159 = (($B) + 32|0);
   $160 = (($B) + 36|0);
   $161 = (($B) + 40|0);
   $162 = (($B) + 44|0);
   $163 = (($A) + 16|0);
   $164 = (($A) + 20|0);
   $165 = (($A) + 24|0);
   $166 = (($Q) + 16|0);
   $167 = (($Q) + 20|0);
   $168 = (($Q) + 24|0);
   $169 = (($Q) + 28|0);
   $170 = (($A) + 32|0);
   $171 = (($A) + 36|0);
   $172 = (($A) + 40|0);
   $173 = (($Q) + 32|0);
   $174 = (($Q) + 36|0);
   $175 = (($Q) + 40|0);
   $176 = (($Q) + 44|0);
   $177 = (($11) + 4|0);
   $178 = (($11) + 8|0);
   $179 = (($tempV) + 4|0);
   $180 = (($tempV) + 8|0);
   $181 = (($closB) + 4|0);
   $182 = (($closB) + 8|0);
   $183 = (($closB) + 12|0);
   $184 = (($tempV) + 12|0);
   $186 = $117;$188 = $118;$191 = $119;$225 = $143;$227 = $142;$229 = $141;$252 = Math_fround(0.0);$453 = Math_fround(0.0);$454 = $93;$455 = $92;$456 = $91;$457 = $117;$458 = $118;$459 = $119;$460 = $136;
   while(1) {
    $185 = Math_fround($186 * $186);
    $187 = Math_fround($188 * $188);
    $189 = Math_fround($187 + $185);
    $190 = Math_fround($191 * $191);
    $192 = Math_fround($190 + $189);
    $193 = (Math_fround(Math_sqrt((Math_fround($192)))));
    $194 = Math_fround(Math_fround(1.0) / $193);
    $195 = Math_fround($186 * $194);
    $196 = Math_fround($188 * $194);
    $197 = Math_fround($191 * $194);
    $198 = Math_fround(-$195);
    $199 = Math_fround(-$196);
    $200 = Math_fround(-$197);
    HEAPF32[$nvNorm>>2] = $198;
    HEAPF32[$144>>2] = $199;
    HEAPF32[$145>>2] = $200;
    HEAPF32[$146>>2] = Math_fround(0.0);
    $201 = Math_fround(HEAPF32[$67>>2]);
    $202 = Math_fround(HEAPF32[$69>>2]);
    $203 = Math_fround(HEAPF32[$71>>2]);
    $204 = Math_fround($195 * $201);
    $205 = Math_fround($196 * $202);
    $206 = Math_fround($204 + $205);
    $207 = Math_fround($197 * $203);
    $208 = Math_fround($206 + $207);
    $209 = Math_fround(HEAPF32[$79>>2]);
    $210 = Math_fround(HEAPF32[$81>>2]);
    $211 = Math_fround(HEAPF32[$83>>2]);
    $212 = Math_fround($195 * $209);
    $213 = Math_fround($196 * $210);
    $214 = Math_fround($212 + $213);
    $215 = Math_fround($197 * $211);
    $216 = Math_fround($214 + $215);
    $217 = $208 > $216;
    ;HEAP32[$3+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$66+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$78+12>>2]|0;
    $b$a$i$i$i = $217 ? $3 : $2;
    $218 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
    $$in1$i$i$i = (($b$a$i$i$i) + 4|0);
    $219 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($b$a$i$i$i) + 8|0);
    $220 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($10,$b,$nvNorm);
    $221 = Math_fround(HEAPF32[$10>>2]);
    $222 = Math_fround(HEAPF32[$147>>2]);
    $223 = Math_fround(HEAPF32[$148>>2]);
    $224 = Math_fround($225 + $221);
    $226 = Math_fround($227 + $222);
    $228 = Math_fround($229 + $223);
    $230 = Math_fround($218 - $224);
    $231 = Math_fround($219 - $226);
    $232 = Math_fround($220 - $228);
    HEAPF32[$support>>2] = $230;
    HEAPF32[$149>>2] = $231;
    HEAPF32[$150>>2] = $232;
    HEAPF32[$151>>2] = Math_fround(0.0);
    $233 = Math_fround($195 * $230);
    $234 = Math_fround($196 * $231);
    $235 = Math_fround(-$234);
    $236 = Math_fround($235 - $233);
    $237 = Math_fround($197 * $232);
    $238 = Math_fround($236 - $237);
    $239 = Math_fround($238 - $_inflation);
    $240 = Math_fround(HEAPF32[$r>>2]);
    $241 = Math_fround(HEAPF32[$13>>2]);
    $242 = Math_fround(HEAPF32[$15>>2]);
    $243 = Math_fround($195 * $240);
    $244 = Math_fround($196 * $241);
    $245 = Math_fround($243 + $244);
    $246 = Math_fround($197 * $242);
    $247 = Math_fround($245 + $246);
    $248 = $239 > Math_fround(0.0);
    if ($248) {
     $249 = !($247 >= Math_fround(0.0));
     if (!($249)) {
      $$0 = 0;
      label = 22;
      break;
     }
     $250 = Math_fround($239 / $247);
     $251 = Math_fround($252 - $250);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1320+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1320+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1320+8>>2]|0;
     $253 = $251 > $252;
     if ($253) {
      $254 = $251 > Math_fround(1.0);
      if ($254) {
       $$0 = 0;
       label = 22;
       break;
      }
      $255 = Math_fround(HEAPF32[$s>>2]);
      $256 = Math_fround(HEAPF32[$18>>2]);
      $257 = Math_fround(HEAPF32[$20>>2]);
      $258 = Math_fround($251 * $240);
      $259 = Math_fround($251 * $241);
      $260 = Math_fround($251 * $242);
      $261 = Math_fround($258 + $255);
      $262 = Math_fround($259 + $256);
      $263 = Math_fround($260 + $257);
      $264 = Math_fround($261 - $225);
      $265 = Math_fround($262 - $227);
      $266 = Math_fround($263 - $229);
      $267 = Math_fround(HEAPF32[$B>>2]);
      $268 = Math_fround(HEAPF32[$152>>2]);
      $269 = Math_fround(HEAPF32[$153>>2]);
      $270 = Math_fround($264 + $267);
      $271 = Math_fround($265 + $268);
      $272 = Math_fround($266 + $269);
      $273 = Math_fround(HEAPF32[$155>>2]);
      $274 = Math_fround(HEAPF32[$156>>2]);
      $275 = Math_fround(HEAPF32[$157>>2]);
      $276 = Math_fround($264 + $273);
      $277 = Math_fround($265 + $274);
      $278 = Math_fround($266 + $275);
      $279 = Math_fround(HEAPF32[$159>>2]);
      $280 = Math_fround(HEAPF32[$160>>2]);
      $281 = Math_fround(HEAPF32[$161>>2]);
      $282 = Math_fround($264 + $279);
      $283 = Math_fround($265 + $280);
      $284 = Math_fround($266 + $281);
      HEAPF32[$B>>2] = $270;
      HEAPF32[$152>>2] = $271;
      HEAPF32[$153>>2] = $272;
      HEAPF32[$154>>2] = Math_fround(0.0);
      HEAPF32[$155>>2] = $276;
      HEAPF32[$156>>2] = $277;
      HEAPF32[$157>>2] = $278;
      HEAPF32[$158>>2] = Math_fround(0.0);
      HEAPF32[$159>>2] = $282;
      HEAPF32[$160>>2] = $283;
      HEAPF32[$161>>2] = $284;
      HEAPF32[$162>>2] = Math_fround(0.0);
      $285 = Math_fround(HEAPF32[$A>>2]);
      $286 = Math_fround(HEAPF32[$108>>2]);
      $287 = Math_fround(HEAPF32[$109>>2]);
      $288 = Math_fround($285 - $270);
      $289 = Math_fround($286 - $271);
      $290 = Math_fround($287 - $272);
      HEAPF32[$Q>>2] = $288;
      HEAPF32[$102>>2] = $289;
      HEAPF32[$103>>2] = $290;
      HEAPF32[$104>>2] = Math_fround(0.0);
      $291 = Math_fround(HEAPF32[$163>>2]);
      $292 = Math_fround(HEAPF32[$164>>2]);
      $293 = Math_fround(HEAPF32[$165>>2]);
      $294 = Math_fround($291 - $276);
      $295 = Math_fround($292 - $277);
      $296 = Math_fround($293 - $278);
      HEAPF32[$166>>2] = $294;
      HEAPF32[$167>>2] = $295;
      HEAPF32[$168>>2] = $296;
      HEAPF32[$169>>2] = Math_fround(0.0);
      $297 = Math_fround(HEAPF32[$170>>2]);
      $298 = Math_fround(HEAPF32[$171>>2]);
      $299 = Math_fround(HEAPF32[$172>>2]);
      $300 = Math_fround($297 - $282);
      $301 = Math_fround($298 - $283);
      $302 = Math_fround($299 - $284);
      HEAPF32[$173>>2] = $300;
      HEAPF32[$174>>2] = $301;
      HEAPF32[$175>>2] = $302;
      HEAPF32[$176>>2] = Math_fround(0.0);
      __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($11,$b,$nvNorm);
      $303 = Math_fround(HEAPF32[$11>>2]);
      $304 = Math_fround(HEAPF32[$177>>2]);
      $305 = Math_fround(HEAPF32[$178>>2]);
      $306 = Math_fround($261 + $303);
      $307 = Math_fround($262 + $304);
      $308 = Math_fround($263 + $305);
      $309 = Math_fround($218 - $306);
      $310 = Math_fround($219 - $307);
      $311 = Math_fround($220 - $308);
      HEAPF32[$support>>2] = $309;
      HEAPF32[$149>>2] = $310;
      HEAPF32[$150>>2] = $311;
      HEAPF32[$151>>2] = Math_fround(0.0);
      $318 = $306;$320 = $307;$322 = $308;$330 = $309;$332 = $310;$334 = $311;$389 = Math_fround(3.40282346638528859812E+38);$461 = $251;$462 = $263;$463 = $262;$464 = $261;$465 = $191;$466 = $188;$467 = $186;
     } else {
      $318 = $224;$320 = $226;$322 = $228;$330 = $230;$332 = $231;$334 = $232;$389 = $460;$461 = $251;$462 = $229;$463 = $227;$464 = $225;$465 = $459;$466 = $458;$467 = $457;
     }
    } else {
     $318 = $224;$320 = $226;$322 = $228;$330 = $230;$332 = $231;$334 = $232;$389 = $460;$461 = $252;$462 = $229;$463 = $227;$464 = $225;$465 = $459;$466 = $458;$467 = $457;
    }
    $312 = HEAP32[$size>>2]|0;
    $313 = (($A) + ($312<<4)|0);
    HEAPF32[$313>>2] = $218;
    $314 = ((($A) + ($312<<4)|0) + 4|0);
    HEAPF32[$314>>2] = $219;
    $315 = ((($A) + ($312<<4)|0) + 8|0);
    HEAPF32[$315>>2] = $220;
    $316 = ((($A) + ($312<<4)|0) + 12|0);
    HEAPF32[$316>>2] = Math_fround(0.0);
    $317 = (($B) + ($312<<4)|0);
    HEAPF32[$317>>2] = $318;
    $319 = ((($B) + ($312<<4)|0) + 4|0);
    HEAPF32[$319>>2] = $320;
    $321 = ((($B) + ($312<<4)|0) + 8|0);
    HEAPF32[$321>>2] = $322;
    $323 = ((($B) + ($312<<4)|0) + 12|0);
    HEAPF32[$323>>2] = Math_fround(0.0);
    $324 = (($312) + 1)|0;
    HEAP32[$size>>2] = $324;
    $325 = (($Q) + ($312<<4)|0);
    ;HEAP32[$325+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$325+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$325+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$325+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($312|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($312|0) == 0)) {
      HEAPF32[$closA>>2] = $218;
      HEAPF32[$129>>2] = $219;
      HEAPF32[$130>>2] = $220;
      HEAPF32[$131>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $318;
      HEAPF32[$181>>2] = $320;
      HEAPF32[$182>>2] = $322;
      HEAPF32[$183>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($312|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$105,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($312|0) == 1)) {
      $326 = Math_fround(HEAPF32[$Q>>2]);
      $327 = Math_fround(HEAPF32[$102>>2]);
      $328 = Math_fround(HEAPF32[$103>>2]);
      $329 = Math_fround($330 - $326);
      $331 = Math_fround($332 - $327);
      $333 = Math_fround($334 - $328);
      $335 = Math_fround($329 * $329);
      $336 = Math_fround($331 * $331);
      $337 = Math_fround($335 + $336);
      $338 = Math_fround($333 * $333);
      $339 = Math_fround($337 + $338);
      $340 = $339 == Math_fround(0.0);
      if ($340) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $341 = Math_fround($327 * $331);
       $342 = Math_fround(-$341);
       $343 = Math_fround($326 * $329);
       $344 = Math_fround($342 - $343);
       $345 = Math_fround($328 * $333);
       $346 = Math_fround($344 - $345);
       $347 = Math_fround(HEAPF32[$A>>2]);
       $348 = Math_fround(HEAPF32[$108>>2]);
       $349 = Math_fround(HEAPF32[$109>>2]);
       $350 = Math_fround($218 - $347);
       $351 = Math_fround($219 - $348);
       $352 = Math_fround($220 - $349);
       $353 = Math_fround(HEAPF32[$B>>2]);
       $354 = Math_fround(HEAPF32[$152>>2]);
       $355 = Math_fround(HEAPF32[$153>>2]);
       $356 = Math_fround($318 - $353);
       $357 = Math_fround($320 - $354);
       $358 = Math_fround($322 - $355);
       $359 = Math_fround($346 / $339);
       $360 = $359 > Math_fround(1.0);
       $$$i$i$i = $360 ? Math_fround(1.0) : $359;
       $361 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $361 ? $$$i$i$i : Math_fround(0.0);
       $362 = Math_fround($350 * $$$i8$i$i);
       $363 = Math_fround($351 * $$$i8$i$i);
       $364 = Math_fround($352 * $$$i8$i$i);
       $365 = Math_fround($347 + $362);
       $366 = Math_fround($348 + $363);
       $367 = Math_fround($349 + $364);
       $368 = Math_fround($356 * $$$i8$i$i);
       $369 = Math_fround($357 * $$$i8$i$i);
       $370 = Math_fround($358 * $$$i8$i$i);
       $371 = Math_fround($353 + $368);
       $372 = Math_fround($354 + $369);
       $373 = Math_fround($355 + $370);
       HEAPF32[$closA>>2] = $365;
       HEAPF32[$129>>2] = $366;
       HEAPF32[$130>>2] = $367;
       HEAPF32[$131>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $371;
       HEAPF32[$181>>2] = $372;
       HEAPF32[$182>>2] = $373;
       HEAPF32[$183>>2] = Math_fround(0.0);
       $374 = Math_fround($365 - $371);
       $375 = Math_fround($366 - $372);
       $376 = Math_fround($367 - $373);
       HEAPF32[$tempV>>2] = $374;
       HEAPF32[$179>>2] = $375;
       HEAPF32[$180>>2] = $376;
       HEAPF32[$184>>2] = Math_fround(0.0);
       break;
      }
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $377 = Math_fround(HEAPF32[$tempV>>2]);
    $378 = Math_fround(HEAPF32[$179>>2]);
    $379 = Math_fround(HEAPF32[$180>>2]);
    $380 = Math_fround(-$377);
    $381 = Math_fround(-$378);
    $382 = Math_fround(-$379);
    $383 = Math_fround($377 * $377);
    $384 = Math_fround($378 * $378);
    $385 = Math_fround($383 + $384);
    $386 = Math_fround($379 * $379);
    $387 = Math_fround($385 + $386);
    $388 = $389 > $387;
    $390 = $388 << 31 >> 31;
    $391 = $387 > $128;
    if (!($391)) {
     $$lcssa = $461;$$lcssa924 = $453;$$lcssa926 = $454;$$lcssa928 = $455;$$lcssa930 = $456;$$lcssa932 = $382;$$lcssa934 = $381;$$lcssa936 = $380;$$lcssa938 = $387;$$lcssa940 = $390;$$lcssa942 = $465;$$lcssa944 = $466;$$lcssa946 = $467;
     break L1;
    }
    if (!($388)) {
     $$lcssa = $461;$$lcssa924 = $453;$$lcssa926 = $454;$$lcssa928 = $455;$$lcssa930 = $456;$$lcssa932 = $382;$$lcssa934 = $381;$$lcssa936 = $380;$$lcssa938 = $387;$$lcssa940 = $390;$$lcssa942 = $465;$$lcssa944 = $466;$$lcssa946 = $467;
     break L1;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre980 = Math_fround(HEAPF32[$129>>2]);
    $$pre981 = Math_fround(HEAPF32[$130>>2]);
    $$pre982 = Math_fround(HEAPF32[$131>>2]);
    $186 = $380;$188 = $381;$191 = $382;$225 = $464;$227 = $463;$229 = $462;$252 = $461;$453 = $$pre982;$454 = $$pre981;$455 = $$pre980;$456 = $$pre;$457 = $467;$458 = $466;$459 = $465;$460 = $387;
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa924 = Math_fround(0.0);$$lcssa926 = $93;$$lcssa928 = $92;$$lcssa930 = $91;$$lcssa932 = $119;$$lcssa934 = $118;$$lcssa936 = $117;$$lcssa938 = $136;$$lcssa940 = -1;$$lcssa942 = $119;$$lcssa944 = $118;$$lcssa946 = $117;
  }
 } while(0);
 $392 = (($a) + 64|0);
 $393 = HEAP32[$392>>2]|0;
 $394 = (($a) + 68|0);
 $395 = HEAP32[$394>>2]|0;
 $396 = (($a) + 72|0);
 $397 = HEAP32[$396>>2]|0;
 $398 = $$lcssa938 > $126;
 if ($398) {
  $phitmp = ($$lcssa940|0)==(0);
  $phitmp917 = $phitmp ? $4 : $5;
  $406 = $phitmp917;
 } else {
  $406 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa936;
 $399 = (($5) + 4|0);
 HEAPF32[$399>>2] = $$lcssa934;
 $400 = (($5) + 8|0);
 HEAPF32[$400>>2] = $$lcssa932;
 $401 = (($5) + 12|0);
 HEAPF32[$401>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa946;
 $402 = (($4) + 4|0);
 HEAPF32[$402>>2] = $$lcssa944;
 $403 = (($4) + 8|0);
 HEAPF32[$403>>2] = $$lcssa942;
 $404 = (($4) + 12|0);
 HEAPF32[$404>>2] = Math_fround(0.0);
 $405 = Math_fround(HEAPF32[$406>>2]);
 $$in1$i37 = (($406) + 4|0);
 $407 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($406) + 8|0);
 $408 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $409 = Math_fround($405 * $405);
 $410 = Math_fround($407 * $407);
 $411 = Math_fround($409 + $410);
 $412 = Math_fround($408 * $408);
 $413 = Math_fround($411 + $412);
 $414 = (Math_fround(Math_sqrt((Math_fround($413)))));
 $415 = Math_fround(Math_fround(1.0) / $414);
 $416 = Math_fround($405 * $415);
 $417 = Math_fround($407 * $415);
 $418 = Math_fround($408 * $415);
 $419 = Math_fround(-$416);
 $420 = Math_fround(-$417);
 $421 = Math_fround(-$418);
 HEAPF32[$normal>>2] = $419;
 $422 = (($normal) + 4|0);
 HEAPF32[$422>>2] = $420;
 $423 = (($normal) + 8|0);
 HEAPF32[$423>>2] = $421;
 $424 = (($normal) + 12|0);
 HEAPF32[$424>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $425 = (($lambda) + 4|0);
 ;HEAP32[$425+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$425+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$425+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$6>>2] = $$lcssa930;
 $426 = (($6) + 4|0);
 HEAPF32[$426>>2] = $$lcssa928;
 $427 = (($6) + 8|0);
 HEAPF32[$427>>2] = $$lcssa926;
 $428 = (($6) + 12|0);
 HEAPF32[$428>>2] = $$lcssa924;
 $429 = ($$lcssa940|0)==(0);
 $b$a$i18 = $429 ? $6 : $7;
 $430 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $431 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $432 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $430;
 HEAPF32[$129>>2] = $431;
 HEAPF32[$130>>2] = $432;
 HEAPF32[$131>>2] = Math_fround(0.0);
 $433 = (($a) + 16|0);
 $434 = Math_fround(HEAPF32[$433>>2]);
 $435 = Math_fround($434 * $419);
 $436 = Math_fround($434 * $420);
 $437 = Math_fround($434 * $421);
 $438 = Math_fround($430 - $435);
 $439 = Math_fround($431 - $436);
 $440 = Math_fround($432 - $437);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $438;
 $441 = (($9) + 4|0);
 HEAPF32[$441>>2] = $439;
 $442 = (($9) + 8|0);
 HEAPF32[$442>>2] = $440;
 $443 = (($9) + 12|0);
 HEAPF32[$443>>2] = Math_fround(0.0);
 $444 = ($393|0)==(0);
 $b$a$i = $444 ? $8 : $9;
 $445 = Math_fround(HEAPF32[$b$a$i>>2]);
 $446 = ($395|0)==(0);
 $a$pn3$i = $446 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $447 = Math_fround(HEAPF32[$$in1$i>>2]);
 $448 = ($397|0)==(0);
 $b$a5$i = $448 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $449 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $445;
 $450 = (($closestA) + 4|0);
 HEAPF32[$450>>2] = $447;
 $451 = (($closestA) + 8|0);
 HEAPF32[$451>>2] = $449;
 $452 = (($closestA) + 12|0);
 HEAPF32[$452>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu16_gjkLocalRayCastINS0_8CapsuleVENS0_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VESF_RSA_RSD_SH_f($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i142 = 0, $$in1$i$i$i147 = 0, $$in1$i$i$i190 = 0, $$in1$i$i$i195 = 0, $$in1$i21 = 0, $$in1$i210 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i144 = 0, $$in2$i$i$i148 = 0, $$in2$i$i$i192 = 0, $$in2$i$i$i196 = 0, $$in2$i212 = 0;
 var $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa948 = Math_fround(0), $$lcssa950 = Math_fround(0), $$lcssa952 = Math_fround(0), $$lcssa954 = Math_fround(0), $$lcssa956 = Math_fround(0), $$lcssa958 = Math_fround(0), $$lcssa960 = Math_fround(0), $$lcssa962 = Math_fround(0), $$lcssa964 = 0, $$lcssa966 = Math_fround(0), $$lcssa968 = Math_fround(0), $$lcssa970 = Math_fround(0), $$pre = Math_fround(0), $$pre1004 = Math_fround(0), $$pre1005 = Math_fround(0), $$pre1006 = Math_fround(0), $$sroa$1340 = 0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0;
 var $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0);
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = Math_fround(0), $46 = Math_fround(0), $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = 0, $466 = 0, $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $a$pn3$i$i$i = 0, $a$pn3$i$i$i141 = 0, $a$pn3$i$i$i189 = 0, $b$a$i = 0, $b$a$i$i$i = 0, $b$a$i$i$i139 = 0, $b$a$i$i$i145 = 0, $b$a$i$i$i187 = 0, $b$a$i$i$i193 = 0, $b$a$i18 = 0, $b$a$i207 = 0, $b$a5$i = 0, $b$a5$i$i$i = 0;
 var $b$a5$i$i$i143 = 0, $b$a5$i$i$i191 = 0, $closA = 0, $closB = 0, $phitmp = 0, $phitmp941 = 0, $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $0 = sp + 32|0;
 $1 = sp + 336|0;
 $2 = sp + 400|0;
 $3 = sp + 416|0;
 $4 = sp + 384|0;
 $5 = sp + 368|0;
 $6 = sp + 352|0;
 $7 = sp + 320|0;
 $8 = sp + 16|0;
 $9 = sp;
 $zeroV = sp + 112|0;
 $zero$sroa$1 = sp + 432|0;
 $_lambda$sroa$1 = sp + 460|0;
 $size = sp + 456|0;
 $Q = sp + 48|0;
 $A = sp + 128|0;
 $B = sp + 192|0;
 $support = sp + 256|0;
 $closA = sp + 272|0;
 $closB = sp + 288|0;
 $$sroa$1340 = sp + 444|0;
 $tempV = sp + 304|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $10 = Math_fround(HEAPF32[$r>>2]);
 $11 = (($r) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($r) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$s>>2]);
 $16 = (($s) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($s) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 HEAP32[$size>>2] = 1;
 $20 = Math_fround(HEAPF32[$a>>2]);
 $21 = (($a) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($a) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround(HEAPF32[$b>>2]);
 $26 = (($b) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($b) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($20 - $25);
 $31 = Math_fround($22 - $27);
 $32 = Math_fround($24 - $29);
 $33 = Math_fround($30 * $30);
 $34 = Math_fround($31 * $31);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($32 * $32);
 $37 = Math_fround($35 + $36);
 $38 = $37 > Math_fround(1.1920928955078125E-7);
 HEAPF32[$1>>2] = $30;
 $39 = (($1) + 4|0);
 HEAPF32[$39>>2] = $31;
 $40 = (($1) + 8|0);
 HEAPF32[$40>>2] = $32;
 $41 = (($1) + 12|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $42 = (($0) + 4|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($0) + 8|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($0) + 12|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $b$a$i207 = $38 ? $1 : $0;
 $45 = Math_fround(HEAPF32[$b$a$i207>>2]);
 $$in1$i210 = (($b$a$i207) + 4|0);
 $46 = Math_fround(HEAPF32[$$in1$i210>>2]);
 $$in2$i212 = (($b$a$i207) + 8|0);
 $47 = Math_fround(HEAPF32[$$in2$i212>>2]);
 $48 = Math_fround($45 * $45);
 $49 = Math_fround($46 * $46);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($47 * $47);
 $52 = Math_fround($50 + $51);
 $53 = (Math_fround(Math_sqrt((Math_fround($52)))));
 $54 = Math_fround(Math_fround(1.0) / $53);
 $55 = Math_fround($45 * $54);
 $56 = Math_fround($46 * $54);
 $57 = Math_fround($47 * $54);
 $58 = Math_fround(-$55);
 $59 = Math_fround(-$56);
 $60 = Math_fround(-$57);
 $61 = (($a) + 96|0);
 $62 = (($a) + 96|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($a) + 100|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($a) + 104|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($63 * $58);
 $69 = Math_fround($65 * $59);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($67 * $60);
 $72 = Math_fround($70 + $71);
 $73 = (($a) + 112|0);
 $74 = (($a) + 112|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($a) + 116|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($a) + 120|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($75 * $58);
 $81 = Math_fround($77 * $59);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($79 * $60);
 $84 = Math_fround($82 + $83);
 $85 = $72 > $84;
 ;HEAP32[$3+0>>2]=HEAP32[$61+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$61+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$61+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$61+12>>2]|0;
 ;HEAP32[$2+0>>2]=HEAP32[$73+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$73+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$73+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$73+12>>2]|0;
 $b$a$i$i$i193 = $85 ? $3 : $2;
 $86 = Math_fround(HEAPF32[$b$a$i$i$i193>>2]);
 $$in1$i$i$i195 = (($b$a$i$i$i193) + 4|0);
 $87 = Math_fround(HEAPF32[$$in1$i$i$i195>>2]);
 $$in2$i$i$i196 = (($b$a$i$i$i193) + 8|0);
 $88 = Math_fround(HEAPF32[$$in2$i$i$i196>>2]);
 $89 = $55 > Math_fround(0.0);
 $90 = $56 > Math_fround(0.0);
 $91 = $57 > Math_fround(0.0);
 $92 = (($b) + 144|0);
 ;HEAP32[$3+0>>2]=HEAP32[$92+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$92+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$92+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$92+12>>2]|0;
 $93 = (($b) + 144|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($b) + 148|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($b) + 152|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround(-$94);
 $100 = Math_fround(-$96);
 $101 = Math_fround(-$98);
 HEAPF32[$2>>2] = $99;
 $102 = (($2) + 4|0);
 HEAPF32[$102>>2] = $100;
 $103 = (($2) + 8|0);
 HEAPF32[$103>>2] = $101;
 $104 = (($2) + 12|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $b$a$i$i$i187 = $89 ? $3 : $2;
 $105 = Math_fround(HEAPF32[$b$a$i$i$i187>>2]);
 $a$pn3$i$i$i189 = $90 ? $3 : $2;
 $$in1$i$i$i190 = (($a$pn3$i$i$i189) + 4|0);
 $106 = Math_fround(HEAPF32[$$in1$i$i$i190>>2]);
 $b$a5$i$i$i191 = $91 ? $3 : $2;
 $$in2$i$i$i192 = (($b$a5$i$i$i191) + 8|0);
 $107 = Math_fround(HEAPF32[$$in2$i$i$i192>>2]);
 $108 = Math_fround($86 - $105);
 $109 = Math_fround($87 - $106);
 $110 = Math_fround($88 - $107);
 HEAPF32[$Q>>2] = $108;
 $111 = (($Q) + 4|0);
 HEAPF32[$111>>2] = $109;
 $112 = (($Q) + 8|0);
 HEAPF32[$112>>2] = $110;
 $113 = (($Q) + 12|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = (($Q) + 16|0);
 ;HEAP32[$114+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$114+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$114+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$114+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $115 = (($Q) + 32|0);
 ;HEAP32[$115+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$115+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$115+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$115+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $116 = (($Q) + 48|0);
 ;HEAP32[$116+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$116+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$116+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $86;
 $117 = (($A) + 4|0);
 HEAPF32[$117>>2] = $87;
 $118 = (($A) + 8|0);
 HEAPF32[$118>>2] = $88;
 $119 = (($A) + 12|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($A) + 16|0);
 ;HEAP32[$120+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$120+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$120+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$120+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $121 = (($A) + 32|0);
 ;HEAP32[$121+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$121+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$121+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$121+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $122 = (($A) + 48|0);
 ;HEAP32[$122+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$122+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$122+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$B>>2] = $105;
 $123 = (($B) + 4|0);
 HEAPF32[$123>>2] = $106;
 $124 = (($B) + 8|0);
 HEAPF32[$124>>2] = $107;
 $125 = (($B) + 12|0);
 HEAPF32[$125>>2] = Math_fround(0.0);
 $126 = (($B) + 16|0);
 ;HEAP32[$126+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$126+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$126+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$126+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $127 = (($B) + 32|0);
 ;HEAP32[$127+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$127+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$127+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$127+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $128 = (($B) + 48|0);
 ;HEAP32[$128+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$128+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$128+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$128+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $129 = Math_fround(-$108);
 $130 = Math_fround(-$109);
 $131 = Math_fround(-$110);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $132 = (($a) + 32|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($b) + 32|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = $133 > $135;
 $$$i = $136 ? $135 : $133;
 $137 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $138 = Math_fround($137 * $137);
 $139 = Math_fround($_inflation * $_inflation);
 $140 = Math_fround($139 + $138);
 HEAPF32[$closA>>2] = $86;
 $141 = (($closA) + 4|0);
 HEAPF32[$141>>2] = $87;
 $142 = (($closA) + 8|0);
 HEAPF32[$142>>2] = $88;
 $143 = (($closA) + 12|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 HEAPF32[$closB>>2] = $105;
 $144 = (($closB) + 4|0);
 HEAPF32[$144>>2] = $106;
 $145 = (($closB) + 8|0);
 HEAPF32[$145>>2] = $107;
 $146 = (($closB) + 12|0);
 HEAPF32[$146>>2] = Math_fround(0.0);
 $147 = Math_fround($108 * $108);
 $148 = Math_fround($109 * $109);
 $149 = Math_fround($147 + $148);
 $150 = Math_fround($110 * $110);
 $151 = Math_fround($149 + $150);
 $152 = $151 > $138;
 L1: do {
  if ($152) {
   $153 = Math_fround($14 * Math_fround(0.0));
   $154 = Math_fround($12 * Math_fround(0.0));
   $155 = Math_fround($10 * Math_fround(0.0));
   $156 = Math_fround($153 + $19);
   $157 = Math_fround($154 + $17);
   $158 = Math_fround($155 + $15);
   $159 = (($2) + 4|0);
   $160 = (($2) + 8|0);
   $161 = (($2) + 12|0);
   $162 = (($support) + 4|0);
   $163 = (($support) + 8|0);
   $164 = (($support) + 12|0);
   $165 = (($B) + 16|0);
   $166 = (($B) + 20|0);
   $167 = (($B) + 24|0);
   $168 = (($B) + 28|0);
   $169 = (($B) + 32|0);
   $170 = (($B) + 36|0);
   $171 = (($B) + 40|0);
   $172 = (($B) + 44|0);
   $173 = (($A) + 16|0);
   $174 = (($A) + 20|0);
   $175 = (($A) + 24|0);
   $176 = (($Q) + 16|0);
   $177 = (($Q) + 20|0);
   $178 = (($Q) + 24|0);
   $179 = (($Q) + 28|0);
   $180 = (($A) + 32|0);
   $181 = (($A) + 36|0);
   $182 = (($A) + 40|0);
   $183 = (($Q) + 32|0);
   $184 = (($Q) + 36|0);
   $185 = (($Q) + 40|0);
   $186 = (($Q) + 44|0);
   $187 = (($2) + 4|0);
   $188 = (($2) + 8|0);
   $189 = (($2) + 12|0);
   $190 = (($tempV) + 4|0);
   $191 = (($tempV) + 8|0);
   $192 = (($tempV) + 12|0);
   $194 = $129;$196 = $130;$199 = $131;$239 = $158;$241 = $157;$243 = $156;$266 = Math_fround(0.0);$467 = Math_fround(0.0);$468 = $88;$469 = $87;$470 = $86;$471 = $129;$472 = $130;$473 = $131;$474 = $151;
   while(1) {
    $193 = Math_fround($194 * $194);
    $195 = Math_fround($196 * $196);
    $197 = Math_fround($195 + $193);
    $198 = Math_fround($199 * $199);
    $200 = Math_fround($198 + $197);
    $201 = (Math_fround(Math_sqrt((Math_fround($200)))));
    $202 = Math_fround(Math_fround(1.0) / $201);
    $203 = Math_fround($194 * $202);
    $204 = Math_fround($196 * $202);
    $205 = Math_fround($199 * $202);
    $206 = Math_fround(HEAPF32[$62>>2]);
    $207 = Math_fround(HEAPF32[$64>>2]);
    $208 = Math_fround(HEAPF32[$66>>2]);
    $209 = Math_fround($203 * $206);
    $210 = Math_fround($204 * $207);
    $211 = Math_fround($209 + $210);
    $212 = Math_fround($205 * $208);
    $213 = Math_fround($211 + $212);
    $214 = Math_fround(HEAPF32[$74>>2]);
    $215 = Math_fround(HEAPF32[$76>>2]);
    $216 = Math_fround(HEAPF32[$78>>2]);
    $217 = Math_fround($203 * $214);
    $218 = Math_fround($204 * $215);
    $219 = Math_fround($217 + $218);
    $220 = Math_fround($205 * $216);
    $221 = Math_fround($219 + $220);
    $222 = $213 > $221;
    ;HEAP32[$3+0>>2]=HEAP32[$61+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$61+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$61+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$61+12>>2]|0;
    ;HEAP32[$2+0>>2]=HEAP32[$73+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$73+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$73+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$73+12>>2]|0;
    $b$a$i$i$i145 = $222 ? $3 : $2;
    $223 = Math_fround(HEAPF32[$b$a$i$i$i145>>2]);
    $$in1$i$i$i147 = (($b$a$i$i$i145) + 4|0);
    $224 = Math_fround(HEAPF32[$$in1$i$i$i147>>2]);
    $$in2$i$i$i148 = (($b$a$i$i$i145) + 8|0);
    $225 = Math_fround(HEAPF32[$$in2$i$i$i148>>2]);
    $226 = $203 < Math_fround(-0.0);
    $227 = $204 < Math_fround(-0.0);
    $228 = $205 < Math_fround(-0.0);
    ;HEAP32[$3+0>>2]=HEAP32[$92+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$92+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$92+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$92+12>>2]|0;
    $229 = Math_fround(HEAPF32[$93>>2]);
    $230 = Math_fround(HEAPF32[$95>>2]);
    $231 = Math_fround(HEAPF32[$97>>2]);
    $232 = Math_fround(-$229);
    $233 = Math_fround(-$230);
    $234 = Math_fround(-$231);
    HEAPF32[$2>>2] = $232;
    HEAPF32[$159>>2] = $233;
    HEAPF32[$160>>2] = $234;
    HEAPF32[$161>>2] = Math_fround(0.0);
    $b$a$i$i$i139 = $226 ? $3 : $2;
    $235 = Math_fround(HEAPF32[$b$a$i$i$i139>>2]);
    $a$pn3$i$i$i141 = $227 ? $3 : $2;
    $$in1$i$i$i142 = (($a$pn3$i$i$i141) + 4|0);
    $236 = Math_fround(HEAPF32[$$in1$i$i$i142>>2]);
    $b$a5$i$i$i143 = $228 ? $3 : $2;
    $$in2$i$i$i144 = (($b$a5$i$i$i143) + 8|0);
    $237 = Math_fround(HEAPF32[$$in2$i$i$i144>>2]);
    $238 = Math_fround($239 + $235);
    $240 = Math_fround($241 + $236);
    $242 = Math_fround($243 + $237);
    $244 = Math_fround($223 - $238);
    $245 = Math_fround($224 - $240);
    $246 = Math_fround($225 - $242);
    HEAPF32[$support>>2] = $244;
    HEAPF32[$162>>2] = $245;
    HEAPF32[$163>>2] = $246;
    HEAPF32[$164>>2] = Math_fround(0.0);
    $247 = Math_fround($203 * $244);
    $248 = Math_fround($204 * $245);
    $249 = Math_fround(-$248);
    $250 = Math_fround($249 - $247);
    $251 = Math_fround($205 * $246);
    $252 = Math_fround($250 - $251);
    $253 = Math_fround($252 - $_inflation);
    $254 = Math_fround(HEAPF32[$r>>2]);
    $255 = Math_fround(HEAPF32[$11>>2]);
    $256 = Math_fround(HEAPF32[$13>>2]);
    $257 = Math_fround($203 * $254);
    $258 = Math_fround($204 * $255);
    $259 = Math_fround($257 + $258);
    $260 = Math_fround($205 * $256);
    $261 = Math_fround($259 + $260);
    $262 = $253 > Math_fround(0.0);
    if ($262) {
     $263 = !($261 >= Math_fround(0.0));
     if (!($263)) {
      $$0 = 0;
      label = 22;
      break;
     }
     $264 = Math_fround($253 / $261);
     $265 = Math_fround($266 - $264);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1340+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1340+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1340+8>>2]|0;
     $267 = $265 > $266;
     if ($267) {
      $268 = $265 > Math_fround(1.0);
      if ($268) {
       $$0 = 0;
       label = 22;
       break;
      }
      $269 = Math_fround(HEAPF32[$s>>2]);
      $270 = Math_fround(HEAPF32[$16>>2]);
      $271 = Math_fround(HEAPF32[$18>>2]);
      $272 = Math_fround($265 * $254);
      $273 = Math_fround($265 * $255);
      $274 = Math_fround($265 * $256);
      $275 = Math_fround($272 + $269);
      $276 = Math_fround($273 + $270);
      $277 = Math_fround($274 + $271);
      $278 = Math_fround($275 - $239);
      $279 = Math_fround($276 - $241);
      $280 = Math_fround($277 - $243);
      $281 = Math_fround(HEAPF32[$B>>2]);
      $282 = Math_fround(HEAPF32[$123>>2]);
      $283 = Math_fround(HEAPF32[$124>>2]);
      $284 = Math_fround($278 + $281);
      $285 = Math_fround($279 + $282);
      $286 = Math_fround($280 + $283);
      $287 = Math_fround(HEAPF32[$165>>2]);
      $288 = Math_fround(HEAPF32[$166>>2]);
      $289 = Math_fround(HEAPF32[$167>>2]);
      $290 = Math_fround($278 + $287);
      $291 = Math_fround($279 + $288);
      $292 = Math_fround($280 + $289);
      $293 = Math_fround(HEAPF32[$169>>2]);
      $294 = Math_fround(HEAPF32[$170>>2]);
      $295 = Math_fround(HEAPF32[$171>>2]);
      $296 = Math_fround($278 + $293);
      $297 = Math_fround($279 + $294);
      $298 = Math_fround($280 + $295);
      HEAPF32[$B>>2] = $284;
      HEAPF32[$123>>2] = $285;
      HEAPF32[$124>>2] = $286;
      HEAPF32[$125>>2] = Math_fround(0.0);
      HEAPF32[$165>>2] = $290;
      HEAPF32[$166>>2] = $291;
      HEAPF32[$167>>2] = $292;
      HEAPF32[$168>>2] = Math_fround(0.0);
      HEAPF32[$169>>2] = $296;
      HEAPF32[$170>>2] = $297;
      HEAPF32[$171>>2] = $298;
      HEAPF32[$172>>2] = Math_fround(0.0);
      $299 = Math_fround(HEAPF32[$A>>2]);
      $300 = Math_fround(HEAPF32[$117>>2]);
      $301 = Math_fround(HEAPF32[$118>>2]);
      $302 = Math_fround($299 - $284);
      $303 = Math_fround($300 - $285);
      $304 = Math_fround($301 - $286);
      HEAPF32[$Q>>2] = $302;
      HEAPF32[$111>>2] = $303;
      HEAPF32[$112>>2] = $304;
      HEAPF32[$113>>2] = Math_fround(0.0);
      $305 = Math_fround(HEAPF32[$173>>2]);
      $306 = Math_fround(HEAPF32[$174>>2]);
      $307 = Math_fround(HEAPF32[$175>>2]);
      $308 = Math_fround($305 - $290);
      $309 = Math_fround($306 - $291);
      $310 = Math_fround($307 - $292);
      HEAPF32[$176>>2] = $308;
      HEAPF32[$177>>2] = $309;
      HEAPF32[$178>>2] = $310;
      HEAPF32[$179>>2] = Math_fround(0.0);
      $311 = Math_fround(HEAPF32[$180>>2]);
      $312 = Math_fround(HEAPF32[$181>>2]);
      $313 = Math_fround(HEAPF32[$182>>2]);
      $314 = Math_fround($311 - $296);
      $315 = Math_fround($312 - $297);
      $316 = Math_fround($313 - $298);
      HEAPF32[$183>>2] = $314;
      HEAPF32[$184>>2] = $315;
      HEAPF32[$185>>2] = $316;
      HEAPF32[$186>>2] = Math_fround(0.0);
      ;HEAP32[$3+0>>2]=HEAP32[$92+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$92+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$92+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$92+12>>2]|0;
      HEAPF32[$2>>2] = $232;
      HEAPF32[$187>>2] = $233;
      HEAPF32[$188>>2] = $234;
      HEAPF32[$189>>2] = Math_fround(0.0);
      $b$a$i$i$i = $226 ? $3 : $2;
      $317 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
      $a$pn3$i$i$i = $227 ? $3 : $2;
      $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
      $318 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
      $b$a5$i$i$i = $228 ? $3 : $2;
      $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
      $319 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
      $320 = Math_fround($275 + $317);
      $321 = Math_fround($276 + $318);
      $322 = Math_fround($277 + $319);
      $323 = Math_fround($223 - $320);
      $324 = Math_fround($224 - $321);
      $325 = Math_fround($225 - $322);
      HEAPF32[$support>>2] = $323;
      HEAPF32[$162>>2] = $324;
      HEAPF32[$163>>2] = $325;
      HEAPF32[$164>>2] = Math_fround(0.0);
      $332 = $320;$334 = $321;$336 = $322;$344 = $323;$346 = $324;$348 = $325;$403 = Math_fround(3.40282346638528859812E+38);$475 = $265;$476 = $277;$477 = $276;$478 = $275;$479 = $199;$480 = $196;$481 = $194;
     } else {
      $332 = $238;$334 = $240;$336 = $242;$344 = $244;$346 = $245;$348 = $246;$403 = $474;$475 = $265;$476 = $243;$477 = $241;$478 = $239;$479 = $473;$480 = $472;$481 = $471;
     }
    } else {
     $332 = $238;$334 = $240;$336 = $242;$344 = $244;$346 = $245;$348 = $246;$403 = $474;$475 = $266;$476 = $243;$477 = $241;$478 = $239;$479 = $473;$480 = $472;$481 = $471;
    }
    $326 = HEAP32[$size>>2]|0;
    $327 = (($A) + ($326<<4)|0);
    HEAPF32[$327>>2] = $223;
    $328 = ((($A) + ($326<<4)|0) + 4|0);
    HEAPF32[$328>>2] = $224;
    $329 = ((($A) + ($326<<4)|0) + 8|0);
    HEAPF32[$329>>2] = $225;
    $330 = ((($A) + ($326<<4)|0) + 12|0);
    HEAPF32[$330>>2] = Math_fround(0.0);
    $331 = (($B) + ($326<<4)|0);
    HEAPF32[$331>>2] = $332;
    $333 = ((($B) + ($326<<4)|0) + 4|0);
    HEAPF32[$333>>2] = $334;
    $335 = ((($B) + ($326<<4)|0) + 8|0);
    HEAPF32[$335>>2] = $336;
    $337 = ((($B) + ($326<<4)|0) + 12|0);
    HEAPF32[$337>>2] = Math_fround(0.0);
    $338 = (($326) + 1)|0;
    HEAP32[$size>>2] = $338;
    $339 = (($Q) + ($326<<4)|0);
    ;HEAP32[$339+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$339+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$339+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$339+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($326|0) == 1)) {
      $340 = Math_fround(HEAPF32[$Q>>2]);
      $341 = Math_fround(HEAPF32[$111>>2]);
      $342 = Math_fround(HEAPF32[$112>>2]);
      $343 = Math_fround($344 - $340);
      $345 = Math_fround($346 - $341);
      $347 = Math_fround($348 - $342);
      $349 = Math_fround($343 * $343);
      $350 = Math_fround($345 * $345);
      $351 = Math_fround($349 + $350);
      $352 = Math_fround($347 * $347);
      $353 = Math_fround($351 + $352);
      $354 = $353 == Math_fround(0.0);
      if ($354) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $355 = Math_fround($341 * $345);
       $356 = Math_fround(-$355);
       $357 = Math_fround($340 * $343);
       $358 = Math_fround($356 - $357);
       $359 = Math_fround($342 * $347);
       $360 = Math_fround($358 - $359);
       $361 = Math_fround(HEAPF32[$A>>2]);
       $362 = Math_fround(HEAPF32[$117>>2]);
       $363 = Math_fround(HEAPF32[$118>>2]);
       $364 = Math_fround($223 - $361);
       $365 = Math_fround($224 - $362);
       $366 = Math_fround($225 - $363);
       $367 = Math_fround(HEAPF32[$B>>2]);
       $368 = Math_fround(HEAPF32[$123>>2]);
       $369 = Math_fround(HEAPF32[$124>>2]);
       $370 = Math_fround($332 - $367);
       $371 = Math_fround($334 - $368);
       $372 = Math_fround($336 - $369);
       $373 = Math_fround($360 / $353);
       $374 = $373 > Math_fround(1.0);
       $$$i$i$i = $374 ? Math_fround(1.0) : $373;
       $375 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $375 ? $$$i$i$i : Math_fround(0.0);
       $376 = Math_fround($364 * $$$i8$i$i);
       $377 = Math_fround($365 * $$$i8$i$i);
       $378 = Math_fround($366 * $$$i8$i$i);
       $379 = Math_fround($361 + $376);
       $380 = Math_fround($362 + $377);
       $381 = Math_fround($363 + $378);
       $382 = Math_fround($370 * $$$i8$i$i);
       $383 = Math_fround($371 * $$$i8$i$i);
       $384 = Math_fround($372 * $$$i8$i$i);
       $385 = Math_fround($367 + $382);
       $386 = Math_fround($368 + $383);
       $387 = Math_fround($369 + $384);
       HEAPF32[$closA>>2] = $379;
       HEAPF32[$141>>2] = $380;
       HEAPF32[$142>>2] = $381;
       HEAPF32[$143>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $385;
       HEAPF32[$144>>2] = $386;
       HEAPF32[$145>>2] = $387;
       HEAPF32[$146>>2] = Math_fround(0.0);
       $388 = Math_fround($379 - $385);
       $389 = Math_fround($380 - $386);
       $390 = Math_fround($381 - $387);
       HEAPF32[$tempV>>2] = $388;
       HEAPF32[$190>>2] = $389;
       HEAPF32[$191>>2] = $390;
       HEAPF32[$192>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($326|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$114,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($326|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($326|0) == 0)) {
      HEAPF32[$closA>>2] = $223;
      HEAPF32[$141>>2] = $224;
      HEAPF32[$142>>2] = $225;
      HEAPF32[$143>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $332;
      HEAPF32[$144>>2] = $334;
      HEAPF32[$145>>2] = $336;
      HEAPF32[$146>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $391 = Math_fround(HEAPF32[$tempV>>2]);
    $392 = Math_fround(HEAPF32[$190>>2]);
    $393 = Math_fround(HEAPF32[$191>>2]);
    $394 = Math_fround(-$391);
    $395 = Math_fround(-$392);
    $396 = Math_fround(-$393);
    $397 = Math_fround($391 * $391);
    $398 = Math_fround($392 * $392);
    $399 = Math_fround($397 + $398);
    $400 = Math_fround($393 * $393);
    $401 = Math_fround($399 + $400);
    $402 = $403 > $401;
    $404 = $402 << 31 >> 31;
    $405 = $401 > $140;
    if (!($405)) {
     $$lcssa = $475;$$lcssa948 = $467;$$lcssa950 = $468;$$lcssa952 = $469;$$lcssa954 = $470;$$lcssa956 = $396;$$lcssa958 = $395;$$lcssa960 = $394;$$lcssa962 = $401;$$lcssa964 = $404;$$lcssa966 = $479;$$lcssa968 = $480;$$lcssa970 = $481;
     break L1;
    }
    if (!($402)) {
     $$lcssa = $475;$$lcssa948 = $467;$$lcssa950 = $468;$$lcssa952 = $469;$$lcssa954 = $470;$$lcssa956 = $396;$$lcssa958 = $395;$$lcssa960 = $394;$$lcssa962 = $401;$$lcssa964 = $404;$$lcssa966 = $479;$$lcssa968 = $480;$$lcssa970 = $481;
     break L1;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre1004 = Math_fround(HEAPF32[$141>>2]);
    $$pre1005 = Math_fround(HEAPF32[$142>>2]);
    $$pre1006 = Math_fround(HEAPF32[$143>>2]);
    $194 = $394;$196 = $395;$199 = $396;$239 = $478;$241 = $477;$243 = $476;$266 = $475;$467 = $$pre1006;$468 = $$pre1005;$469 = $$pre1004;$470 = $$pre;$471 = $481;$472 = $480;$473 = $479;$474 = $401;
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa948 = Math_fround(0.0);$$lcssa950 = $88;$$lcssa952 = $87;$$lcssa954 = $86;$$lcssa956 = $131;$$lcssa958 = $130;$$lcssa960 = $129;$$lcssa962 = $151;$$lcssa964 = -1;$$lcssa966 = $131;$$lcssa968 = $130;$$lcssa970 = $129;
  }
 } while(0);
 $406 = (($a) + 64|0);
 $407 = HEAP32[$406>>2]|0;
 $408 = (($a) + 68|0);
 $409 = HEAP32[$408>>2]|0;
 $410 = (($a) + 72|0);
 $411 = HEAP32[$410>>2]|0;
 $412 = $$lcssa962 > $138;
 if ($412) {
  $phitmp = ($$lcssa964|0)==(0);
  $phitmp941 = $phitmp ? $4 : $5;
  $420 = $phitmp941;
 } else {
  $420 = $4;
 }
 HEAPF32[$5>>2] = $$lcssa960;
 $413 = (($5) + 4|0);
 HEAPF32[$413>>2] = $$lcssa958;
 $414 = (($5) + 8|0);
 HEAPF32[$414>>2] = $$lcssa956;
 $415 = (($5) + 12|0);
 HEAPF32[$415>>2] = Math_fround(0.0);
 HEAPF32[$4>>2] = $$lcssa970;
 $416 = (($4) + 4|0);
 HEAPF32[$416>>2] = $$lcssa968;
 $417 = (($4) + 8|0);
 HEAPF32[$417>>2] = $$lcssa966;
 $418 = (($4) + 12|0);
 HEAPF32[$418>>2] = Math_fround(0.0);
 $419 = Math_fround(HEAPF32[$420>>2]);
 $$in1$i37 = (($420) + 4|0);
 $421 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($420) + 8|0);
 $422 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $423 = Math_fround($419 * $419);
 $424 = Math_fround($421 * $421);
 $425 = Math_fround($423 + $424);
 $426 = Math_fround($422 * $422);
 $427 = Math_fround($425 + $426);
 $428 = (Math_fround(Math_sqrt((Math_fround($427)))));
 $429 = Math_fround(Math_fround(1.0) / $428);
 $430 = Math_fround($419 * $429);
 $431 = Math_fround($421 * $429);
 $432 = Math_fround($422 * $429);
 $433 = Math_fround(-$430);
 $434 = Math_fround(-$431);
 $435 = Math_fround(-$432);
 HEAPF32[$normal>>2] = $433;
 $436 = (($normal) + 4|0);
 HEAPF32[$436>>2] = $434;
 $437 = (($normal) + 8|0);
 HEAPF32[$437>>2] = $435;
 $438 = (($normal) + 12|0);
 HEAPF32[$438>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $439 = (($lambda) + 4|0);
 ;HEAP32[$439+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$439+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$439+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$6>>2] = $$lcssa954;
 $440 = (($6) + 4|0);
 HEAPF32[$440>>2] = $$lcssa952;
 $441 = (($6) + 8|0);
 HEAPF32[$441>>2] = $$lcssa950;
 $442 = (($6) + 12|0);
 HEAPF32[$442>>2] = $$lcssa948;
 $443 = ($$lcssa964|0)==(0);
 $b$a$i18 = $443 ? $6 : $7;
 $444 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $445 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $446 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $444;
 HEAPF32[$141>>2] = $445;
 HEAPF32[$142>>2] = $446;
 HEAPF32[$143>>2] = Math_fround(0.0);
 $447 = (($a) + 16|0);
 $448 = Math_fround(HEAPF32[$447>>2]);
 $449 = Math_fround($448 * $433);
 $450 = Math_fround($448 * $434);
 $451 = Math_fround($448 * $435);
 $452 = Math_fround($444 - $449);
 $453 = Math_fround($445 - $450);
 $454 = Math_fround($446 - $451);
 ;HEAP32[$8+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$9>>2] = $452;
 $455 = (($9) + 4|0);
 HEAPF32[$455>>2] = $453;
 $456 = (($9) + 8|0);
 HEAPF32[$456>>2] = $454;
 $457 = (($9) + 12|0);
 HEAPF32[$457>>2] = Math_fround(0.0);
 $458 = ($407|0)==(0);
 $b$a$i = $458 ? $8 : $9;
 $459 = Math_fround(HEAPF32[$b$a$i>>2]);
 $460 = ($409|0)==(0);
 $a$pn3$i = $460 ? $8 : $9;
 $$in1$i = (($a$pn3$i) + 4|0);
 $461 = Math_fround(HEAPF32[$$in1$i>>2]);
 $462 = ($411|0)==(0);
 $b$a5$i = $462 ? $8 : $9;
 $$in2$i = (($b$a5$i) + 8|0);
 $463 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $459;
 $464 = (($closestA) + 4|0);
 HEAPF32[$464>>2] = $461;
 $465 = (($closestA) + 8|0);
 HEAPF32[$465>>2] = $463;
 $466 = (($closestA) + 12|0);
 HEAPF32[$466>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu16_gjkLocalRayCastINS0_9TriangleVENS0_11ConvexHullVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VESF_RSA_RSD_SH_f($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i189 = 0, $$in1$i19$i$i = 0, $$in1$i19$i$i186 = 0, $$in1$i205 = 0, $$in1$i21 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i190 = 0, $$in2$i207 = 0, $$in2$i21$i$i = 0, $$in2$i21$i$i187 = 0, $$in2$i23 = 0, $$in2$i39 = 0;
 var $$lcssa = Math_fround(0), $$lcssa929 = Math_fround(0), $$lcssa931 = Math_fround(0), $$lcssa933 = Math_fround(0), $$lcssa935 = Math_fround(0), $$lcssa937 = Math_fround(0), $$lcssa939 = Math_fround(0), $$lcssa941 = Math_fround(0), $$lcssa943 = Math_fround(0), $$lcssa945 = 0, $$lcssa947 = Math_fround(0), $$lcssa949 = Math_fround(0), $$lcssa951 = Math_fround(0), $$pre = Math_fround(0), $$pre985 = Math_fround(0), $$pre986 = Math_fround(0), $$pre987 = Math_fround(0), $$sroa$1325 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0);
 var $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0);
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0);
 var $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0);
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0);
 var $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0);
 var $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0);
 var $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0);
 var $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0);
 var $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = 0, $388 = 0;
 var $389 = 0, $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0);
 var $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0);
 var $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0);
 var $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0);
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = 0, $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0);
 var $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0);
 var $497 = 0, $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = Math_fround(0), $512 = 0, $513 = Math_fround(0);
 var $514 = 0, $515 = 0, $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0);
 var $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0;
 var $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $b$a$i = 0, $b$a$i16$i$i = 0, $b$a$i16$i$i184 = 0, $b$a$i18 = 0, $b$a$i202 = 0;
 var $b$a5$i = 0, $closA = 0, $closB = 0, $initialSearchDir = 0, $initialSupportB = 0, $nvNorm = 0, $phitmp = 0, $phitmp164$i$i = 0, $phitmp164$i$i183 = 0, $phitmp922 = 0, $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 592|0;
 $0 = sp + 336|0;
 $1 = sp + 512|0;
 $2 = sp + 352|0;
 $3 = sp + 368|0;
 $4 = sp + 384|0;
 $5 = sp + 400|0;
 $6 = sp + 416|0;
 $7 = sp + 448|0;
 $8 = sp + 432|0;
 $9 = sp + 464|0;
 $10 = sp + 480|0;
 $11 = sp + 496|0;
 $zeroV = sp + 528|0;
 $zero$sroa$1 = sp + 572|0;
 $_lambda$sroa$1 = sp + 556|0;
 $size = sp + 568|0;
 $initialSearchDir = sp + 208|0;
 $initialSupportB = sp;
 $Q = sp + 16|0;
 $A = sp + 80|0;
 $B = sp + 144|0;
 $support = sp + 224|0;
 $closA = sp + 240|0;
 $closB = sp + 256|0;
 $nvNorm = sp + 272|0;
 $12 = sp + 288|0;
 $$sroa$1325 = sp + 544|0;
 $13 = sp + 304|0;
 $tempV = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $14 = Math_fround(HEAPF32[$r>>2]);
 $15 = (($r) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($r) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(HEAPF32[$s>>2]);
 $20 = (($s) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($s) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($14 * Math_fround(0.0));
 $25 = Math_fround($16 * Math_fround(0.0));
 $26 = Math_fround($18 * Math_fround(0.0));
 $27 = Math_fround($24 + $19);
 $28 = Math_fround($25 + $21);
 $29 = Math_fround($26 + $23);
 HEAP32[$size>>2] = 1;
 $30 = Math_fround(HEAPF32[$a>>2]);
 $31 = (($a) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($a) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround(HEAPF32[$b>>2]);
 $36 = (($b) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($b) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($30 - $35);
 $41 = Math_fround($32 - $37);
 $42 = Math_fround($34 - $39);
 $43 = Math_fround($40 * $40);
 $44 = Math_fround($41 * $41);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($42 * $42);
 $47 = Math_fround($45 + $46);
 $48 = $47 > Math_fround(1.1920928955078125E-7);
 HEAPF32[$1>>2] = $40;
 $49 = (($1) + 4|0);
 HEAPF32[$49>>2] = $41;
 $50 = (($1) + 8|0);
 HEAPF32[$50>>2] = $42;
 $51 = (($1) + 12|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $52 = (($0) + 4|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($0) + 8|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($0) + 12|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $b$a$i202 = $48 ? $1 : $0;
 $55 = Math_fround(HEAPF32[$b$a$i202>>2]);
 $$in1$i205 = (($b$a$i202) + 4|0);
 $56 = Math_fround(HEAPF32[$$in1$i205>>2]);
 $$in2$i207 = (($b$a$i202) + 8|0);
 $57 = Math_fround(HEAPF32[$$in2$i207>>2]);
 $58 = Math_fround($55 * $55);
 $59 = Math_fround($56 * $56);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($57 * $57);
 $62 = Math_fround($60 + $61);
 $63 = (Math_fround(Math_sqrt((Math_fround($62)))));
 $64 = Math_fround(Math_fround(1.0) / $63);
 $65 = Math_fround($55 * $64);
 $66 = Math_fround($56 * $64);
 $67 = Math_fround($57 * $64);
 HEAPF32[$initialSearchDir>>2] = $65;
 $68 = (($initialSearchDir) + 4|0);
 HEAPF32[$68>>2] = $66;
 $69 = (($initialSearchDir) + 8|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($initialSearchDir) + 12|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = Math_fround(-$65);
 $72 = Math_fround(-$66);
 $73 = Math_fround(-$67);
 $74 = (($a) + 96|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($a) + 100|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($a) + 104|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($a) + 108|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($a) + 112|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($a) + 116|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($a) + 120|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($a) + 124|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($a) + 128|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($a) + 132|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($a) + 136|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($a) + 140|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($75 * $71);
 $99 = Math_fround($77 * $72);
 $100 = Math_fround($98 + $99);
 $101 = Math_fround($79 * $73);
 $102 = Math_fround($100 + $101);
 $103 = Math_fround($83 * $71);
 $104 = Math_fround($85 * $72);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($87 * $73);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($91 * $71);
 $109 = Math_fround($93 * $72);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($95 * $73);
 $112 = Math_fround($110 + $111);
 $113 = $102 > $107;
 if ($113) {
  $114 = $102 > $112;
  $phitmp164$i$i183 = $114 ? $5 : $4;
  $132 = $phitmp164$i$i183;
 } else {
  $132 = $4;
 }
 $115 = $107 > $112;
 HEAPF32[$3>>2] = $83;
 $116 = (($3) + 4|0);
 HEAPF32[$116>>2] = $85;
 $117 = (($3) + 8|0);
 HEAPF32[$117>>2] = $87;
 $118 = (($3) + 12|0);
 HEAPF32[$118>>2] = $89;
 HEAPF32[$2>>2] = $91;
 $119 = (($2) + 4|0);
 HEAPF32[$119>>2] = $93;
 $120 = (($2) + 8|0);
 HEAPF32[$120>>2] = $95;
 $121 = (($2) + 12|0);
 HEAPF32[$121>>2] = $97;
 $b$a$i16$i$i184 = $115 ? $3 : $2;
 $122 = Math_fround(HEAPF32[$b$a$i16$i$i184>>2]);
 $$in1$i19$i$i186 = (($b$a$i16$i$i184) + 4|0);
 $123 = Math_fround(HEAPF32[$$in1$i19$i$i186>>2]);
 $$in2$i21$i$i187 = (($b$a$i16$i$i184) + 8|0);
 $124 = Math_fround(HEAPF32[$$in2$i21$i$i187>>2]);
 HEAPF32[$5>>2] = $75;
 $125 = (($5) + 4|0);
 HEAPF32[$125>>2] = $77;
 $126 = (($5) + 8|0);
 HEAPF32[$126>>2] = $79;
 $127 = (($5) + 12|0);
 HEAPF32[$127>>2] = $81;
 HEAPF32[$4>>2] = $122;
 $128 = (($4) + 4|0);
 HEAPF32[$128>>2] = $123;
 $129 = (($4) + 8|0);
 HEAPF32[$129>>2] = $124;
 $130 = (($4) + 12|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = Math_fround(HEAPF32[$132>>2]);
 $$in1$i$i$i189 = (($132) + 4|0);
 $133 = Math_fround(HEAPF32[$$in1$i$i$i189>>2]);
 $$in2$i$i$i190 = (($132) + 8|0);
 $134 = Math_fround(HEAPF32[$$in2$i$i$i190>>2]);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($initialSupportB,$b,$initialSearchDir);
 $135 = Math_fround(HEAPF32[$initialSupportB>>2]);
 $136 = (($initialSupportB) + 4|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($initialSupportB) + 8|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($131 - $135);
 $141 = Math_fround($133 - $137);
 $142 = Math_fround($134 - $139);
 HEAPF32[$Q>>2] = $140;
 $143 = (($Q) + 4|0);
 HEAPF32[$143>>2] = $141;
 $144 = (($Q) + 8|0);
 HEAPF32[$144>>2] = $142;
 $145 = (($Q) + 12|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = (($Q) + 16|0);
 ;HEAP32[$146+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$146+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $147 = (($Q) + 32|0);
 ;HEAP32[$147+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$147+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $148 = (($Q) + 48|0);
 ;HEAP32[$148+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$148+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$148+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$148+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $131;
 $149 = (($A) + 4|0);
 HEAPF32[$149>>2] = $133;
 $150 = (($A) + 8|0);
 HEAPF32[$150>>2] = $134;
 $151 = (($A) + 12|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = (($A) + 16|0);
 ;HEAP32[$152+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$152+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$152+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $153 = (($A) + 32|0);
 ;HEAP32[$153+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$153+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$153+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$153+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $154 = (($A) + 48|0);
 ;HEAP32[$154+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$154+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$154+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$154+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$B+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$B+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$B+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$B+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $155 = (($B) + 16|0);
 ;HEAP32[$155+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$155+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $156 = (($B) + 32|0);
 ;HEAP32[$156+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$156+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$156+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $157 = (($B) + 48|0);
 ;HEAP32[$157+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$157+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $158 = Math_fround(-$140);
 $159 = Math_fround(-$141);
 $160 = Math_fround(-$142);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $161 = (($a) + 32|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = (($b) + 32|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = $162 > $164;
 $$$i = $165 ? $164 : $162;
 $166 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $167 = Math_fround($166 * $166);
 $168 = Math_fround($_inflation * $_inflation);
 $169 = Math_fround($168 + $167);
 HEAPF32[$closA>>2] = $131;
 $170 = (($closA) + 4|0);
 HEAPF32[$170>>2] = $133;
 $171 = (($closA) + 8|0);
 HEAPF32[$171>>2] = $134;
 $172 = (($closA) + 12|0);
 HEAPF32[$172>>2] = Math_fround(0.0);
 ;HEAP32[$closB+0>>2]=HEAP32[$initialSupportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$initialSupportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$initialSupportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$initialSupportB+12>>2]|0;
 $173 = Math_fround($140 * $140);
 $174 = Math_fround($141 * $141);
 $175 = Math_fround($173 + $174);
 $176 = Math_fround($142 * $142);
 $177 = Math_fround($175 + $176);
 $178 = $177 > $167;
 L4: do {
  if ($178) {
   $179 = (($nvNorm) + 4|0);
   $180 = (($nvNorm) + 8|0);
   $181 = (($nvNorm) + 12|0);
   $182 = (($3) + 4|0);
   $183 = (($3) + 8|0);
   $184 = (($3) + 12|0);
   $185 = (($2) + 4|0);
   $186 = (($2) + 8|0);
   $187 = (($2) + 12|0);
   $188 = (($5) + 4|0);
   $189 = (($5) + 8|0);
   $190 = (($5) + 12|0);
   $191 = (($4) + 4|0);
   $192 = (($4) + 8|0);
   $193 = (($4) + 12|0);
   $194 = (($12) + 4|0);
   $195 = (($12) + 8|0);
   $196 = (($support) + 4|0);
   $197 = (($support) + 8|0);
   $198 = (($support) + 12|0);
   $199 = (($B) + 4|0);
   $200 = (($B) + 8|0);
   $201 = (($B) + 12|0);
   $202 = (($B) + 16|0);
   $203 = (($B) + 20|0);
   $204 = (($B) + 24|0);
   $205 = (($B) + 28|0);
   $206 = (($B) + 32|0);
   $207 = (($B) + 36|0);
   $208 = (($B) + 40|0);
   $209 = (($B) + 44|0);
   $210 = (($A) + 16|0);
   $211 = (($A) + 20|0);
   $212 = (($A) + 24|0);
   $213 = (($Q) + 16|0);
   $214 = (($Q) + 20|0);
   $215 = (($Q) + 24|0);
   $216 = (($Q) + 28|0);
   $217 = (($A) + 32|0);
   $218 = (($A) + 36|0);
   $219 = (($A) + 40|0);
   $220 = (($Q) + 32|0);
   $221 = (($Q) + 36|0);
   $222 = (($Q) + 40|0);
   $223 = (($Q) + 44|0);
   $224 = (($13) + 4|0);
   $225 = (($13) + 8|0);
   $226 = (($tempV) + 4|0);
   $227 = (($tempV) + 8|0);
   $228 = (($closB) + 4|0);
   $229 = (($closB) + 8|0);
   $230 = (($closB) + 12|0);
   $231 = (($tempV) + 12|0);
   $233 = $158;$235 = $159;$238 = $160;$289 = $27;$291 = $28;$293 = $29;$316 = Math_fround(0.0);$517 = Math_fround(0.0);$518 = $134;$519 = $133;$520 = $131;$521 = $158;$522 = $159;$523 = $160;$524 = $177;
   while(1) {
    $232 = Math_fround($233 * $233);
    $234 = Math_fround($235 * $235);
    $236 = Math_fround($234 + $232);
    $237 = Math_fround($238 * $238);
    $239 = Math_fround($237 + $236);
    $240 = (Math_fround(Math_sqrt((Math_fround($239)))));
    $241 = Math_fround(Math_fround(1.0) / $240);
    $242 = Math_fround($233 * $241);
    $243 = Math_fround($235 * $241);
    $244 = Math_fround($238 * $241);
    $245 = Math_fround(-$242);
    $246 = Math_fround(-$243);
    $247 = Math_fround(-$244);
    HEAPF32[$nvNorm>>2] = $245;
    HEAPF32[$179>>2] = $246;
    HEAPF32[$180>>2] = $247;
    HEAPF32[$181>>2] = Math_fround(0.0);
    $248 = Math_fround(HEAPF32[$74>>2]);
    $249 = Math_fround(HEAPF32[$76>>2]);
    $250 = Math_fround(HEAPF32[$78>>2]);
    $251 = Math_fround(HEAPF32[$80>>2]);
    $252 = Math_fround(HEAPF32[$82>>2]);
    $253 = Math_fround(HEAPF32[$84>>2]);
    $254 = Math_fround(HEAPF32[$86>>2]);
    $255 = Math_fround(HEAPF32[$88>>2]);
    $256 = Math_fround(HEAPF32[$90>>2]);
    $257 = Math_fround(HEAPF32[$92>>2]);
    $258 = Math_fround(HEAPF32[$94>>2]);
    $259 = Math_fround(HEAPF32[$96>>2]);
    $260 = Math_fround($242 * $248);
    $261 = Math_fround($243 * $249);
    $262 = Math_fround($260 + $261);
    $263 = Math_fround($244 * $250);
    $264 = Math_fround($262 + $263);
    $265 = Math_fround($242 * $252);
    $266 = Math_fround($243 * $253);
    $267 = Math_fround($265 + $266);
    $268 = Math_fround($244 * $254);
    $269 = Math_fround($267 + $268);
    $270 = Math_fround($242 * $256);
    $271 = Math_fround($243 * $257);
    $272 = Math_fround($270 + $271);
    $273 = Math_fround($244 * $258);
    $274 = Math_fround($272 + $273);
    $275 = $264 > $269;
    if ($275) {
     $276 = $264 > $274;
     $phitmp164$i$i = $276 ? $5 : $4;
     $282 = $phitmp164$i$i;
    } else {
     $282 = $4;
    }
    $277 = $269 > $274;
    HEAPF32[$3>>2] = $252;
    HEAPF32[$182>>2] = $253;
    HEAPF32[$183>>2] = $254;
    HEAPF32[$184>>2] = $255;
    HEAPF32[$2>>2] = $256;
    HEAPF32[$185>>2] = $257;
    HEAPF32[$186>>2] = $258;
    HEAPF32[$187>>2] = $259;
    $b$a$i16$i$i = $277 ? $3 : $2;
    $278 = Math_fround(HEAPF32[$b$a$i16$i$i>>2]);
    $$in1$i19$i$i = (($b$a$i16$i$i) + 4|0);
    $279 = Math_fround(HEAPF32[$$in1$i19$i$i>>2]);
    $$in2$i21$i$i = (($b$a$i16$i$i) + 8|0);
    $280 = Math_fround(HEAPF32[$$in2$i21$i$i>>2]);
    HEAPF32[$5>>2] = $248;
    HEAPF32[$188>>2] = $249;
    HEAPF32[$189>>2] = $250;
    HEAPF32[$190>>2] = $251;
    HEAPF32[$4>>2] = $278;
    HEAPF32[$191>>2] = $279;
    HEAPF32[$192>>2] = $280;
    HEAPF32[$193>>2] = Math_fround(0.0);
    $281 = Math_fround(HEAPF32[$282>>2]);
    $$in1$i$i$i = (($282) + 4|0);
    $283 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
    $$in2$i$i$i = (($282) + 8|0);
    $284 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
    __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($12,$b,$nvNorm);
    $285 = Math_fround(HEAPF32[$12>>2]);
    $286 = Math_fround(HEAPF32[$194>>2]);
    $287 = Math_fround(HEAPF32[$195>>2]);
    $288 = Math_fround($289 + $285);
    $290 = Math_fround($291 + $286);
    $292 = Math_fround($293 + $287);
    $294 = Math_fround($281 - $288);
    $295 = Math_fround($283 - $290);
    $296 = Math_fround($284 - $292);
    HEAPF32[$support>>2] = $294;
    HEAPF32[$196>>2] = $295;
    HEAPF32[$197>>2] = $296;
    HEAPF32[$198>>2] = Math_fround(0.0);
    $297 = Math_fround($242 * $294);
    $298 = Math_fround($243 * $295);
    $299 = Math_fround(-$298);
    $300 = Math_fround($299 - $297);
    $301 = Math_fround($244 * $296);
    $302 = Math_fround($300 - $301);
    $303 = Math_fround($302 - $_inflation);
    $304 = Math_fround(HEAPF32[$r>>2]);
    $305 = Math_fround(HEAPF32[$15>>2]);
    $306 = Math_fround(HEAPF32[$17>>2]);
    $307 = Math_fround($242 * $304);
    $308 = Math_fround($243 * $305);
    $309 = Math_fround($307 + $308);
    $310 = Math_fround($244 * $306);
    $311 = Math_fround($309 + $310);
    $312 = $303 > Math_fround(0.0);
    if ($312) {
     $313 = !($311 >= Math_fround(0.0));
     if (!($313)) {
      $$0 = 0;
      label = 26;
      break;
     }
     $314 = Math_fround($303 / $311);
     $315 = Math_fround($316 - $314);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1325+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1325+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1325+8>>2]|0;
     $317 = $315 > $316;
     if ($317) {
      $318 = $315 > Math_fround(1.0);
      if ($318) {
       $$0 = 0;
       label = 26;
       break;
      }
      $319 = Math_fround(HEAPF32[$s>>2]);
      $320 = Math_fround(HEAPF32[$20>>2]);
      $321 = Math_fround(HEAPF32[$22>>2]);
      $322 = Math_fround($315 * $304);
      $323 = Math_fround($315 * $305);
      $324 = Math_fround($315 * $306);
      $325 = Math_fround($322 + $319);
      $326 = Math_fround($323 + $320);
      $327 = Math_fround($324 + $321);
      $328 = Math_fround($325 - $289);
      $329 = Math_fround($326 - $291);
      $330 = Math_fround($327 - $293);
      $331 = Math_fround(HEAPF32[$B>>2]);
      $332 = Math_fround(HEAPF32[$199>>2]);
      $333 = Math_fround(HEAPF32[$200>>2]);
      $334 = Math_fround($328 + $331);
      $335 = Math_fround($329 + $332);
      $336 = Math_fround($330 + $333);
      $337 = Math_fround(HEAPF32[$202>>2]);
      $338 = Math_fround(HEAPF32[$203>>2]);
      $339 = Math_fround(HEAPF32[$204>>2]);
      $340 = Math_fround($328 + $337);
      $341 = Math_fround($329 + $338);
      $342 = Math_fround($330 + $339);
      $343 = Math_fround(HEAPF32[$206>>2]);
      $344 = Math_fround(HEAPF32[$207>>2]);
      $345 = Math_fround(HEAPF32[$208>>2]);
      $346 = Math_fround($328 + $343);
      $347 = Math_fround($329 + $344);
      $348 = Math_fround($330 + $345);
      HEAPF32[$B>>2] = $334;
      HEAPF32[$199>>2] = $335;
      HEAPF32[$200>>2] = $336;
      HEAPF32[$201>>2] = Math_fround(0.0);
      HEAPF32[$202>>2] = $340;
      HEAPF32[$203>>2] = $341;
      HEAPF32[$204>>2] = $342;
      HEAPF32[$205>>2] = Math_fround(0.0);
      HEAPF32[$206>>2] = $346;
      HEAPF32[$207>>2] = $347;
      HEAPF32[$208>>2] = $348;
      HEAPF32[$209>>2] = Math_fround(0.0);
      $349 = Math_fround(HEAPF32[$A>>2]);
      $350 = Math_fround(HEAPF32[$149>>2]);
      $351 = Math_fround(HEAPF32[$150>>2]);
      $352 = Math_fround($349 - $334);
      $353 = Math_fround($350 - $335);
      $354 = Math_fround($351 - $336);
      HEAPF32[$Q>>2] = $352;
      HEAPF32[$143>>2] = $353;
      HEAPF32[$144>>2] = $354;
      HEAPF32[$145>>2] = Math_fround(0.0);
      $355 = Math_fround(HEAPF32[$210>>2]);
      $356 = Math_fround(HEAPF32[$211>>2]);
      $357 = Math_fround(HEAPF32[$212>>2]);
      $358 = Math_fround($355 - $340);
      $359 = Math_fround($356 - $341);
      $360 = Math_fround($357 - $342);
      HEAPF32[$213>>2] = $358;
      HEAPF32[$214>>2] = $359;
      HEAPF32[$215>>2] = $360;
      HEAPF32[$216>>2] = Math_fround(0.0);
      $361 = Math_fround(HEAPF32[$217>>2]);
      $362 = Math_fround(HEAPF32[$218>>2]);
      $363 = Math_fround(HEAPF32[$219>>2]);
      $364 = Math_fround($361 - $346);
      $365 = Math_fround($362 - $347);
      $366 = Math_fround($363 - $348);
      HEAPF32[$220>>2] = $364;
      HEAPF32[$221>>2] = $365;
      HEAPF32[$222>>2] = $366;
      HEAPF32[$223>>2] = Math_fround(0.0);
      __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($13,$b,$nvNorm);
      $367 = Math_fround(HEAPF32[$13>>2]);
      $368 = Math_fround(HEAPF32[$224>>2]);
      $369 = Math_fround(HEAPF32[$225>>2]);
      $370 = Math_fround($325 + $367);
      $371 = Math_fround($326 + $368);
      $372 = Math_fround($327 + $369);
      $373 = Math_fround($281 - $370);
      $374 = Math_fround($283 - $371);
      $375 = Math_fround($284 - $372);
      HEAPF32[$support>>2] = $373;
      HEAPF32[$196>>2] = $374;
      HEAPF32[$197>>2] = $375;
      HEAPF32[$198>>2] = Math_fround(0.0);
      $382 = $370;$384 = $371;$386 = $372;$394 = $373;$396 = $374;$398 = $375;$453 = Math_fround(3.40282346638528859812E+38);$525 = $315;$526 = $327;$527 = $326;$528 = $325;$529 = $238;$530 = $235;$531 = $233;
     } else {
      $382 = $288;$384 = $290;$386 = $292;$394 = $294;$396 = $295;$398 = $296;$453 = $524;$525 = $315;$526 = $293;$527 = $291;$528 = $289;$529 = $523;$530 = $522;$531 = $521;
     }
    } else {
     $382 = $288;$384 = $290;$386 = $292;$394 = $294;$396 = $295;$398 = $296;$453 = $524;$525 = $316;$526 = $293;$527 = $291;$528 = $289;$529 = $523;$530 = $522;$531 = $521;
    }
    $376 = HEAP32[$size>>2]|0;
    $377 = (($A) + ($376<<4)|0);
    HEAPF32[$377>>2] = $281;
    $378 = ((($A) + ($376<<4)|0) + 4|0);
    HEAPF32[$378>>2] = $283;
    $379 = ((($A) + ($376<<4)|0) + 8|0);
    HEAPF32[$379>>2] = $284;
    $380 = ((($A) + ($376<<4)|0) + 12|0);
    HEAPF32[$380>>2] = Math_fround(0.0);
    $381 = (($B) + ($376<<4)|0);
    HEAPF32[$381>>2] = $382;
    $383 = ((($B) + ($376<<4)|0) + 4|0);
    HEAPF32[$383>>2] = $384;
    $385 = ((($B) + ($376<<4)|0) + 8|0);
    HEAPF32[$385>>2] = $386;
    $387 = ((($B) + ($376<<4)|0) + 12|0);
    HEAPF32[$387>>2] = Math_fround(0.0);
    $388 = (($376) + 1)|0;
    HEAP32[$size>>2] = $388;
    $389 = (($Q) + ($376<<4)|0);
    ;HEAP32[$389+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$389+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$389+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$389+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($376|0) == 1)) {
      $390 = Math_fround(HEAPF32[$Q>>2]);
      $391 = Math_fround(HEAPF32[$143>>2]);
      $392 = Math_fround(HEAPF32[$144>>2]);
      $393 = Math_fround($394 - $390);
      $395 = Math_fround($396 - $391);
      $397 = Math_fround($398 - $392);
      $399 = Math_fround($393 * $393);
      $400 = Math_fround($395 * $395);
      $401 = Math_fround($399 + $400);
      $402 = Math_fround($397 * $397);
      $403 = Math_fround($401 + $402);
      $404 = $403 == Math_fround(0.0);
      if ($404) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $405 = Math_fround($391 * $395);
       $406 = Math_fround(-$405);
       $407 = Math_fround($390 * $393);
       $408 = Math_fround($406 - $407);
       $409 = Math_fround($392 * $397);
       $410 = Math_fround($408 - $409);
       $411 = Math_fround(HEAPF32[$A>>2]);
       $412 = Math_fround(HEAPF32[$149>>2]);
       $413 = Math_fround(HEAPF32[$150>>2]);
       $414 = Math_fround($281 - $411);
       $415 = Math_fround($283 - $412);
       $416 = Math_fround($284 - $413);
       $417 = Math_fround(HEAPF32[$B>>2]);
       $418 = Math_fround(HEAPF32[$199>>2]);
       $419 = Math_fround(HEAPF32[$200>>2]);
       $420 = Math_fround($382 - $417);
       $421 = Math_fround($384 - $418);
       $422 = Math_fround($386 - $419);
       $423 = Math_fround($410 / $403);
       $424 = $423 > Math_fround(1.0);
       $$$i$i$i = $424 ? Math_fround(1.0) : $423;
       $425 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $425 ? $$$i$i$i : Math_fround(0.0);
       $426 = Math_fround($414 * $$$i8$i$i);
       $427 = Math_fround($415 * $$$i8$i$i);
       $428 = Math_fround($416 * $$$i8$i$i);
       $429 = Math_fround($411 + $426);
       $430 = Math_fround($412 + $427);
       $431 = Math_fround($413 + $428);
       $432 = Math_fround($420 * $$$i8$i$i);
       $433 = Math_fround($421 * $$$i8$i$i);
       $434 = Math_fround($422 * $$$i8$i$i);
       $435 = Math_fround($417 + $432);
       $436 = Math_fround($418 + $433);
       $437 = Math_fround($419 + $434);
       HEAPF32[$closA>>2] = $429;
       HEAPF32[$170>>2] = $430;
       HEAPF32[$171>>2] = $431;
       HEAPF32[$172>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $435;
       HEAPF32[$228>>2] = $436;
       HEAPF32[$229>>2] = $437;
       HEAPF32[$230>>2] = Math_fround(0.0);
       $438 = Math_fround($429 - $435);
       $439 = Math_fround($430 - $436);
       $440 = Math_fround($431 - $437);
       HEAPF32[$tempV>>2] = $438;
       HEAPF32[$226>>2] = $439;
       HEAPF32[$227>>2] = $440;
       HEAPF32[$231>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($376|0) == 0)) {
      HEAPF32[$closA>>2] = $281;
      HEAPF32[$170>>2] = $283;
      HEAPF32[$171>>2] = $284;
      HEAPF32[$172>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $382;
      HEAPF32[$228>>2] = $384;
      HEAPF32[$229>>2] = $386;
      HEAPF32[$230>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($376|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$146,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($376|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $441 = Math_fround(HEAPF32[$tempV>>2]);
    $442 = Math_fround(HEAPF32[$226>>2]);
    $443 = Math_fround(HEAPF32[$227>>2]);
    $444 = Math_fround(-$441);
    $445 = Math_fround(-$442);
    $446 = Math_fround(-$443);
    $447 = Math_fround($441 * $441);
    $448 = Math_fround($442 * $442);
    $449 = Math_fround($447 + $448);
    $450 = Math_fround($443 * $443);
    $451 = Math_fround($449 + $450);
    $452 = $453 > $451;
    $454 = $452 << 31 >> 31;
    $455 = $451 > $169;
    if (!($455)) {
     $$lcssa = $525;$$lcssa929 = $517;$$lcssa931 = $518;$$lcssa933 = $519;$$lcssa935 = $520;$$lcssa937 = $446;$$lcssa939 = $445;$$lcssa941 = $444;$$lcssa943 = $451;$$lcssa945 = $454;$$lcssa947 = $529;$$lcssa949 = $530;$$lcssa951 = $531;
     break L4;
    }
    if (!($452)) {
     $$lcssa = $525;$$lcssa929 = $517;$$lcssa931 = $518;$$lcssa933 = $519;$$lcssa935 = $520;$$lcssa937 = $446;$$lcssa939 = $445;$$lcssa941 = $444;$$lcssa943 = $451;$$lcssa945 = $454;$$lcssa947 = $529;$$lcssa949 = $530;$$lcssa951 = $531;
     break L4;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre985 = Math_fround(HEAPF32[$170>>2]);
    $$pre986 = Math_fround(HEAPF32[$171>>2]);
    $$pre987 = Math_fround(HEAPF32[$172>>2]);
    $233 = $444;$235 = $445;$238 = $446;$289 = $528;$291 = $527;$293 = $526;$316 = $525;$517 = $$pre987;$518 = $$pre986;$519 = $$pre985;$520 = $$pre;$521 = $531;$522 = $530;$523 = $529;$524 = $451;
   }
   if ((label|0) == 26) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa929 = Math_fround(0.0);$$lcssa931 = $134;$$lcssa933 = $133;$$lcssa935 = $131;$$lcssa937 = $160;$$lcssa939 = $159;$$lcssa941 = $158;$$lcssa943 = $177;$$lcssa945 = -1;$$lcssa947 = $160;$$lcssa949 = $159;$$lcssa951 = $158;
  }
 } while(0);
 $456 = (($a) + 64|0);
 $457 = HEAP32[$456>>2]|0;
 $458 = (($a) + 68|0);
 $459 = HEAP32[$458>>2]|0;
 $460 = (($a) + 72|0);
 $461 = HEAP32[$460>>2]|0;
 $462 = $$lcssa943 > $167;
 if ($462) {
  $phitmp = ($$lcssa945|0)==(0);
  $phitmp922 = $phitmp ? $6 : $7;
  $470 = $phitmp922;
 } else {
  $470 = $6;
 }
 HEAPF32[$7>>2] = $$lcssa941;
 $463 = (($7) + 4|0);
 HEAPF32[$463>>2] = $$lcssa939;
 $464 = (($7) + 8|0);
 HEAPF32[$464>>2] = $$lcssa937;
 $465 = (($7) + 12|0);
 HEAPF32[$465>>2] = Math_fround(0.0);
 HEAPF32[$6>>2] = $$lcssa951;
 $466 = (($6) + 4|0);
 HEAPF32[$466>>2] = $$lcssa949;
 $467 = (($6) + 8|0);
 HEAPF32[$467>>2] = $$lcssa947;
 $468 = (($6) + 12|0);
 HEAPF32[$468>>2] = Math_fround(0.0);
 $469 = Math_fround(HEAPF32[$470>>2]);
 $$in1$i37 = (($470) + 4|0);
 $471 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($470) + 8|0);
 $472 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $473 = Math_fround($469 * $469);
 $474 = Math_fround($471 * $471);
 $475 = Math_fround($473 + $474);
 $476 = Math_fround($472 * $472);
 $477 = Math_fround($475 + $476);
 $478 = (Math_fround(Math_sqrt((Math_fround($477)))));
 $479 = Math_fround(Math_fround(1.0) / $478);
 $480 = Math_fround($469 * $479);
 $481 = Math_fround($471 * $479);
 $482 = Math_fround($472 * $479);
 $483 = Math_fround(-$480);
 $484 = Math_fround(-$481);
 $485 = Math_fround(-$482);
 HEAPF32[$normal>>2] = $483;
 $486 = (($normal) + 4|0);
 HEAPF32[$486>>2] = $484;
 $487 = (($normal) + 8|0);
 HEAPF32[$487>>2] = $485;
 $488 = (($normal) + 12|0);
 HEAPF32[$488>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $489 = (($lambda) + 4|0);
 ;HEAP32[$489+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$489+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$489+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$9+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$8>>2] = $$lcssa935;
 $490 = (($8) + 4|0);
 HEAPF32[$490>>2] = $$lcssa933;
 $491 = (($8) + 8|0);
 HEAPF32[$491>>2] = $$lcssa931;
 $492 = (($8) + 12|0);
 HEAPF32[$492>>2] = $$lcssa929;
 $493 = ($$lcssa945|0)==(0);
 $b$a$i18 = $493 ? $8 : $9;
 $494 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $495 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $496 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $494;
 HEAPF32[$170>>2] = $495;
 HEAPF32[$171>>2] = $496;
 HEAPF32[$172>>2] = Math_fround(0.0);
 $497 = (($a) + 16|0);
 $498 = Math_fround(HEAPF32[$497>>2]);
 $499 = Math_fround($498 * $483);
 $500 = Math_fround($498 * $484);
 $501 = Math_fround($498 * $485);
 $502 = Math_fround($494 - $499);
 $503 = Math_fround($495 - $500);
 $504 = Math_fround($496 - $501);
 ;HEAP32[$10+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$11>>2] = $502;
 $505 = (($11) + 4|0);
 HEAPF32[$505>>2] = $503;
 $506 = (($11) + 8|0);
 HEAPF32[$506>>2] = $504;
 $507 = (($11) + 12|0);
 HEAPF32[$507>>2] = Math_fround(0.0);
 $508 = ($457|0)==(0);
 $b$a$i = $508 ? $10 : $11;
 $509 = Math_fround(HEAPF32[$b$a$i>>2]);
 $510 = ($459|0)==(0);
 $a$pn3$i = $510 ? $10 : $11;
 $$in1$i = (($a$pn3$i) + 4|0);
 $511 = Math_fround(HEAPF32[$$in1$i>>2]);
 $512 = ($461|0)==(0);
 $b$a5$i = $512 ? $10 : $11;
 $$in2$i = (($b$a5$i) + 8|0);
 $513 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $509;
 $514 = (($closestA) + 4|0);
 HEAPF32[$514>>2] = $511;
 $515 = (($closestA) + 8|0);
 HEAPF32[$515>>2] = $513;
 $516 = (($closestA) + 12|0);
 HEAPF32[$516>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19gjkLocalPenetrationINS0_9TriangleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$ = 0, $$$1048 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i254 = Math_fround(0), $$$i10351076 = Math_fround(0), $$$i204 = Math_fround(0), $$$i213 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i255 = Math_fround(0), $$0 = 0, $$1044 = 0, $$in1$i = 0, $$in2$i = 0, $$ph1056 = Math_fround(0), $$ph1057 = 0, $$sroa$1276 = 0, $$sroa$1284 = 0, $$sroa$1350 = 0, $$sroa$1352 = 0;
 var $$sroa$1362 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = 0;
 var $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = 0;
 var $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0);
 var $458 = Math_fround(0), $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0);
 var $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $A = 0, $B = 0, $Q = 0, $aInd = 0, $b$a$i223 = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i143 = 0, $exitcond$i64 = 0, $i$01$i = 0, $i$01$i142 = 0, $i$01$i63 = 0;
 var $i$01078 = 0, $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp1052 = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportA = 0, $supportB = 0, $tempClosA = 0, $tempClosB = 0, $v = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 640|0;
 $0 = sp + 64|0;
 $1 = sp + 288|0;
 $zeroV = sp + 320|0;
 $closA = sp + 352|0;
 $closB = sp + 272|0;
 $sDist$sroa$1 = sp + 524|0;
 $minDist$sroa$1 = sp + 584|0;
 $tempClosA = sp + 496|0;
 $tempClosB = sp + 304|0;
 $v = sp + 336|0;
 $Q = sp + 368|0;
 $A = sp + 432|0;
 $B = sp;
 $aInd = sp + 600|0;
 $bInd = sp + 616|0;
 $supportA = sp + 128|0;
 $supportB = sp + 256|0;
 $support = sp + 80|0;
 $size = sp + 596|0;
 $lastQ = sp + 96|0;
 $lastA = sp + 112|0;
 $lastB = sp + 144|0;
 $2 = sp + 160|0;
 $3 = sp + 176|0;
 $4 = sp + 192|0;
 $5 = sp + 208|0;
 $6 = sp + 224|0;
 $$sroa$1362 = sp + 512|0;
 $$sroa$1352 = sp + 536|0;
 $7 = sp + 240|0;
 $$sroa$1350 = sp + 548|0;
 $$sroa$1284 = sp + 560|0;
 $$sroa$1276 = sp + 572|0;
 $8 = Math_fround(HEAPF32[$_contactDist>>2]);
 $9 = (($a) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($b) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($a) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($b) + 32|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = $14 > $16;
 $$$i213 = $17 ? $16 : $14;
 $18 = Math_fround($$$i213 * Math_fround(0.100000001490116119385));
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $19 = Math_fround($10 + $12);
 $20 = Math_fround($8 + $19);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 ;HEAP32[$tempClosA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$tempClosB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $21 = Math_fround($18 * $18);
 $22 = Math_fround($20 * $20);
 ;HEAP32[$supportA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$supportB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$support+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAP32[$size>>2] = 0;
 $23 = HEAP8[$_size>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $150 = Math_fround(HEAPF32[$a>>2]);
  $151 = (($a) + 4|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = (($a) + 8|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = Math_fround(HEAPF32[$b>>2]);
  $156 = (($b) + 4|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = (($b) + 8|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = Math_fround($150 - $155);
  $161 = Math_fround($152 - $157);
  $162 = Math_fround($154 - $159);
  $163 = Math_fround($160 * $160);
  $164 = Math_fround($161 * $161);
  $165 = Math_fround($163 + $164);
  $166 = Math_fround($162 * $162);
  $167 = Math_fround($165 + $166);
  $168 = $167 > Math_fround(0.0);
  HEAPF32[$1>>2] = $160;
  $169 = (($1) + 4|0);
  HEAPF32[$169>>2] = $161;
  $170 = (($1) + 8|0);
  HEAPF32[$170>>2] = $162;
  $171 = (($1) + 12|0);
  HEAPF32[$171>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = Math_fround(1.0);
  $172 = (($0) + 4|0);
  HEAPF32[$172>>2] = Math_fround(0.0);
  $173 = (($0) + 8|0);
  HEAPF32[$173>>2] = Math_fround(0.0);
  $174 = (($0) + 12|0);
  HEAPF32[$174>>2] = Math_fround(0.0);
  $b$a$i223 = $168 ? $1 : $0;
  $175 = Math_fround(HEAPF32[$b$a$i223>>2]);
  $$in1$i = (($b$a$i223) + 4|0);
  $176 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i223) + 8|0);
  $177 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$v>>2] = $175;
  $178 = (($v) + 4|0);
  HEAPF32[$178>>2] = $176;
  $179 = (($v) + 8|0);
  HEAPF32[$179>>2] = $177;
  $180 = (($v) + 12|0);
  HEAPF32[$180>>2] = Math_fround(0.0);
  $$ph1056 = Math_fround(3.40282346638528859812E+38);$$ph1057 = 1;$501 = $177;$502 = $176;$503 = $175;
 } else {
  ;HEAP32[$lastQ+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$zeroV+12>>2]|0;
  $25 = (($b) + 16|0);
  $26 = (($supportA) + 4|0);
  $27 = (($supportA) + 8|0);
  $28 = (($supportB) + 4|0);
  $29 = (($supportB) + 8|0);
  $30 = (($support) + 4|0);
  $31 = (($support) + 8|0);
  $32 = (($support) + 12|0);
  $i$01078 = 0;
  while(1) {
   $33 = (($aIndices) + ($i$01078)|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34&255;
   $36 = (($aInd) + ($i$01078<<2)|0);
   HEAP32[$36>>2] = $35;
   $37 = (($bIndices) + ($i$01078)|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = $38&255;
   $40 = (($bInd) + ($i$01078<<2)|0);
   HEAP32[$40>>2] = $39;
   $41 = ((($a) + ($35<<4)|0) + 96|0);
   ;HEAP32[$supportA+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$41+12>>2]|0;
   __ZNK5physx2Gu17ShrunkConvexHullV10planeShiftEjRKNS_6shdfnd3aos6FloatVE($2,$b,$39,$25);
   ;HEAP32[$supportB+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$2+12>>2]|0;
   $42 = Math_fround(HEAPF32[$supportA>>2]);
   $43 = Math_fround(HEAPF32[$26>>2]);
   $44 = Math_fround(HEAPF32[$27>>2]);
   $45 = Math_fround(HEAPF32[$supportB>>2]);
   $46 = Math_fround(HEAPF32[$28>>2]);
   $47 = Math_fround(HEAPF32[$29>>2]);
   $48 = Math_fround($42 - $45);
   $49 = Math_fround($43 - $46);
   $50 = Math_fround($44 - $47);
   HEAPF32[$support>>2] = $48;
   HEAPF32[$30>>2] = $49;
   HEAPF32[$31>>2] = $50;
   HEAPF32[$32>>2] = Math_fround(0.0);
   $51 = HEAP32[$size>>2]|0;
   $52 = (($A) + ($51<<4)|0);
   ;HEAP32[$lastA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$supportA+12>>2]|0;
   ;HEAP32[$52+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$52+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$52+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$52+12>>2]=HEAP32[$supportA+12>>2]|0;
   $53 = (($B) + ($51<<4)|0);
   ;HEAP32[$lastB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$supportB+12>>2]|0;
   ;HEAP32[$53+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$53+12>>2]=HEAP32[$supportB+12>>2]|0;
   $54 = (($51) + 1)|0;
   HEAP32[$size>>2] = $54;
   $55 = (($Q) + ($51<<4)|0);
   ;HEAP32[$lastQ+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$support+12>>2]|0;
   ;HEAP32[$55+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$support+12>>2]|0;
   $56 = (($i$01078) + 1)|0;
   $57 = HEAP8[$_size>>0]|0;
   $58 = $57&255;
   $59 = ($56>>>0)<($58>>>0);
   if ($59) {
    $i$01078 = $56;
   } else {
    break;
   }
  }
  do {
   if ((($51|0) == 2)) {
    $138 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($3,$Q,$138,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($51|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$3+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($51|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($3,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($51|0) == 1)) {
    $60 = Math_fround(HEAPF32[$Q>>2]);
    $61 = (($Q) + 4|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = (($Q) + 8|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = Math_fround(HEAPF32[$lastQ>>2]);
    $66 = (($lastQ) + 4|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = (($lastQ) + 8|0);
    $69 = Math_fround(HEAPF32[$68>>2]);
    $70 = Math_fround($65 - $60);
    $71 = Math_fround($67 - $62);
    $72 = Math_fround($69 - $64);
    $73 = Math_fround($70 * $70);
    $74 = Math_fround($71 * $71);
    $75 = Math_fround($73 + $74);
    $76 = Math_fround($72 * $72);
    $77 = Math_fround($75 + $76);
    $78 = $77 == Math_fround(0.0);
    if ($78) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$3+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $79 = Math_fround($62 * $71);
     $80 = Math_fround(-$79);
     $81 = Math_fround($60 * $70);
     $82 = Math_fround($80 - $81);
     $83 = Math_fround($64 * $72);
     $84 = Math_fround($82 - $83);
     $85 = Math_fround(HEAPF32[$lastA>>2]);
     $86 = (($lastA) + 4|0);
     $87 = Math_fround(HEAPF32[$86>>2]);
     $88 = (($lastA) + 8|0);
     $89 = Math_fround(HEAPF32[$88>>2]);
     $90 = Math_fround(HEAPF32[$A>>2]);
     $91 = (($A) + 4|0);
     $92 = Math_fround(HEAPF32[$91>>2]);
     $93 = (($A) + 8|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = Math_fround($85 - $90);
     $96 = Math_fround($87 - $92);
     $97 = Math_fround($89 - $94);
     $98 = Math_fround(HEAPF32[$lastB>>2]);
     $99 = (($lastB) + 4|0);
     $100 = Math_fround(HEAPF32[$99>>2]);
     $101 = (($lastB) + 8|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = Math_fround(HEAPF32[$B>>2]);
     $104 = (($B) + 4|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = (($B) + 8|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = Math_fround($98 - $103);
     $109 = Math_fround($100 - $105);
     $110 = Math_fround($102 - $107);
     $111 = Math_fround($84 / $77);
     $112 = $111 > Math_fround(1.0);
     $$$i$i$i254 = $112 ? Math_fround(1.0) : $111;
     $113 = $$$i$i$i254 > Math_fround(0.0);
     $$$i8$i$i255 = $113 ? $$$i$i$i254 : Math_fround(0.0);
     $114 = Math_fround($95 * $$$i8$i$i255);
     $115 = Math_fround($96 * $$$i8$i$i255);
     $116 = Math_fround($97 * $$$i8$i$i255);
     $117 = Math_fround($90 + $114);
     $118 = Math_fround($92 + $115);
     $119 = Math_fround($94 + $116);
     $120 = Math_fround($108 * $$$i8$i$i255);
     $121 = Math_fround($109 * $$$i8$i$i255);
     $122 = Math_fround($110 * $$$i8$i$i255);
     $123 = Math_fround($103 + $120);
     $124 = Math_fround($105 + $121);
     $125 = Math_fround($107 + $122);
     HEAPF32[$closA>>2] = $117;
     $126 = (($closA) + 4|0);
     HEAPF32[$126>>2] = $118;
     $127 = (($closA) + 8|0);
     HEAPF32[$127>>2] = $119;
     $128 = (($closA) + 12|0);
     HEAPF32[$128>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $123;
     $129 = (($closB) + 4|0);
     HEAPF32[$129>>2] = $124;
     $130 = (($closB) + 8|0);
     HEAPF32[$130>>2] = $125;
     $131 = (($closB) + 12|0);
     HEAPF32[$131>>2] = Math_fround(0.0);
     $132 = Math_fround($117 - $123);
     $133 = Math_fround($118 - $124);
     $134 = Math_fround($119 - $125);
     HEAPF32[$3>>2] = $132;
     $135 = (($3) + 4|0);
     HEAPF32[$135>>2] = $133;
     $136 = (($3) + 8|0);
     HEAPF32[$136>>2] = $134;
     $137 = (($3) + 12|0);
     HEAPF32[$137>>2] = Math_fround(0.0);
     break;
    }
   } else {
    ;HEAP32[$3+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  ;HEAP32[$v+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$3+12>>2]|0;
  $139 = Math_fround(HEAPF32[$v>>2]);
  $140 = (($v) + 4|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = (($v) + 8|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = Math_fround($139 * $139);
  $145 = Math_fround($141 * $141);
  $146 = Math_fround($144 + $145);
  $147 = Math_fround($143 * $143);
  $148 = Math_fround($146 + $147);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $149 = $148 > $21;
  $$ph1056 = $148;$$ph1057 = $149;$501 = $143;$502 = $141;$503 = $139;
 }
 do {
  if ($$ph1057) {
   $182 = (($v) + 4|0);
   $183 = (($v) + 8|0);
   $184 = (($5) + 4|0);
   $185 = (($5) + 8|0);
   $186 = (($5) + 12|0);
   $187 = (($supportA) + 4|0);
   $188 = (($supportA) + 8|0);
   $189 = (($supportB) + 4|0);
   $190 = (($supportB) + 8|0);
   $191 = (($support) + 4|0);
   $192 = (($support) + 8|0);
   $193 = (($support) + 12|0);
   $194 = (($a) + 48|0);
   $195 = (($b) + 48|0);
   $196 = (($Q) + 4|0);
   $197 = (($Q) + 8|0);
   $198 = (($A) + 4|0);
   $199 = (($A) + 8|0);
   $200 = (($B) + 4|0);
   $201 = (($B) + 8|0);
   $202 = (($closA) + 4|0);
   $203 = (($closA) + 8|0);
   $204 = (($closA) + 12|0);
   $205 = (($closB) + 4|0);
   $206 = (($closB) + 8|0);
   $207 = (($closB) + 12|0);
   $208 = (($7) + 4|0);
   $209 = (($7) + 8|0);
   $210 = (($7) + 12|0);
   $211 = (($Q) + 16|0);
   $$$i10351076 = $8;$213 = $503;$215 = $502;$217 = $501;$243 = $$ph1056;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    ;HEAP32[$tempClosA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$closA+12>>2]|0;
    ;HEAP32[$tempClosB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$closB+12>>2]|0;
    $212 = Math_fround(-$213);
    $214 = Math_fround(-$215);
    $216 = Math_fround(-$217);
    HEAPF32[$5>>2] = $212;
    HEAPF32[$184>>2] = $214;
    HEAPF32[$185>>2] = $216;
    HEAPF32[$186>>2] = Math_fround(0.0);
    $218 = HEAP32[$size>>2]|0;
    $219 = (($A) + ($218<<4)|0);
    $220 = (($aInd) + ($218<<2)|0);
    __ZNK5physx2Gu9TriangleV12supportLocalERKNS_6shdfnd3aos5Vec3VERi($4,$a,$5,$220);
    ;HEAP32[$219+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$219+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$219+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$219+12>>2]=HEAP32[$4+12>>2]|0;
    ;HEAP32[$supportA+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$4+12>>2]|0;
    $221 = HEAP32[$size>>2]|0;
    $222 = (($B) + ($221<<4)|0);
    $223 = (($bInd) + ($221<<2)|0);
    __ZNK5physx2Gu17ShrunkConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VERS4_Ri($6,$b,$v,$222,$223);
    ;HEAP32[$supportB+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$6+12>>2]|0;
    $224 = Math_fround(HEAPF32[$supportA>>2]);
    $225 = Math_fround(HEAPF32[$187>>2]);
    $226 = Math_fround(HEAPF32[$188>>2]);
    $227 = Math_fround(HEAPF32[$supportB>>2]);
    $228 = Math_fround(HEAPF32[$189>>2]);
    $229 = Math_fround(HEAPF32[$190>>2]);
    $230 = Math_fround($224 - $227);
    $231 = Math_fround($225 - $228);
    $232 = Math_fround($226 - $229);
    HEAPF32[$support>>2] = $230;
    HEAPF32[$191>>2] = $231;
    HEAPF32[$192>>2] = $232;
    HEAPF32[$193>>2] = Math_fround(0.0);
    $233 = HEAP32[$size>>2]|0;
    $234 = (($233) + 1)|0;
    HEAP32[$size>>2] = $234;
    $235 = (($Q) + ($233<<4)|0);
    ;HEAP32[$235+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$235+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$235+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$235+12>>2]=HEAP32[$support+12>>2]|0;
    $236 = Math_fround(HEAPF32[$194>>2]);
    $237 = Math_fround(HEAPF32[$195>>2]);
    $238 = $236 > $237;
    $$$i204 = $238 ? $236 : $237;
    $239 = $$$i10351076 > $$$i204;
    $$$i = $239 ? $$$i10351076 : $$$i204;
    $240 = Math_fround($19 + $$$i);
    $241 = Math_fround($240 * $240);
    $242 = Math_fround($243 * $241);
    $244 = Math_fround(HEAPF32[$v>>2]);
    $245 = Math_fround(HEAPF32[$182>>2]);
    $246 = Math_fround(HEAPF32[$183>>2]);
    $247 = Math_fround($244 * $230);
    $248 = Math_fround($245 * $231);
    $249 = Math_fround($247 + $248);
    $250 = Math_fround($246 * $232);
    $251 = Math_fround($249 + $250);
    $252 = Math_fround($251 * $251);
    $253 = $251 > Math_fround(0.0);
    $254 = $252 > $242;
    if ($253) {
     $phitmp1052 = $254 ^ 1;
     $258 = $254;$260 = $phitmp1052;
    } else {
     $258 = 0;$260 = 1;
    }
    $255 = Math_fround($243 - $251);
    $256 = Math_fround($21 * $243);
    $257 = $256 >= $255;
    $brmerge$demorgan = $257 | $258;
    if ($brmerge$demorgan) {
     $259 = $260 ^ 1;
     $$1044 = $257 | $259;
     if ($$1044) {
      break;
     }
    }
    do {
     if ((($233|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
      ;HEAP32[$7+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($233|0) == 1)) {
      $342 = Math_fround(HEAPF32[$Q>>2]);
      $343 = Math_fround(HEAPF32[$196>>2]);
      $344 = Math_fround(HEAPF32[$197>>2]);
      $345 = Math_fround($230 - $342);
      $346 = Math_fround($231 - $343);
      $347 = Math_fround($232 - $344);
      $348 = Math_fround($345 * $345);
      $349 = Math_fround($346 * $346);
      $350 = Math_fround($348 + $349);
      $351 = Math_fround($347 * $347);
      $352 = Math_fround($350 + $351);
      $353 = $352 == Math_fround(0.0);
      if ($353) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$7+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $354 = Math_fround($343 * $346);
       $355 = Math_fround(-$354);
       $356 = Math_fround($342 * $345);
       $357 = Math_fround($355 - $356);
       $358 = Math_fround($344 * $347);
       $359 = Math_fround($357 - $358);
       $360 = Math_fround(HEAPF32[$A>>2]);
       $361 = Math_fround(HEAPF32[$198>>2]);
       $362 = Math_fround(HEAPF32[$199>>2]);
       $363 = Math_fround($224 - $360);
       $364 = Math_fround($225 - $361);
       $365 = Math_fround($226 - $362);
       $366 = Math_fround(HEAPF32[$B>>2]);
       $367 = Math_fround(HEAPF32[$200>>2]);
       $368 = Math_fround(HEAPF32[$201>>2]);
       $369 = Math_fround($227 - $366);
       $370 = Math_fround($228 - $367);
       $371 = Math_fround($229 - $368);
       $372 = Math_fround($359 / $352);
       $373 = $372 > Math_fround(1.0);
       $$$i$i$i = $373 ? Math_fround(1.0) : $372;
       $374 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $374 ? $$$i$i$i : Math_fround(0.0);
       $375 = Math_fround($363 * $$$i8$i$i);
       $376 = Math_fround($364 * $$$i8$i$i);
       $377 = Math_fround($365 * $$$i8$i$i);
       $378 = Math_fround($360 + $375);
       $379 = Math_fround($361 + $376);
       $380 = Math_fround($362 + $377);
       $381 = Math_fround($369 * $$$i8$i$i);
       $382 = Math_fround($370 * $$$i8$i$i);
       $383 = Math_fround($371 * $$$i8$i$i);
       $384 = Math_fround($366 + $381);
       $385 = Math_fround($367 + $382);
       $386 = Math_fround($368 + $383);
       HEAPF32[$closA>>2] = $378;
       HEAPF32[$202>>2] = $379;
       HEAPF32[$203>>2] = $380;
       HEAPF32[$204>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $384;
       HEAPF32[$205>>2] = $385;
       HEAPF32[$206>>2] = $386;
       HEAPF32[$207>>2] = Math_fround(0.0);
       $387 = Math_fround($378 - $384);
       $388 = Math_fround($379 - $385);
       $389 = Math_fround($380 - $386);
       HEAPF32[$7>>2] = $387;
       HEAPF32[$208>>2] = $388;
       HEAPF32[$209>>2] = $389;
       HEAPF32[$210>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($233|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($7,$Q,$A,$B,$aInd,$bInd,$support,$supportA,$supportB,$size,$closA,$closB);
     } else if ((($233|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($7,$Q,$211,$support,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$7+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    ;HEAP32[$v+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$v+12>>2]=HEAP32[$7+12>>2]|0;
    $390 = Math_fround(HEAPF32[$v>>2]);
    $391 = Math_fround(HEAPF32[$182>>2]);
    $392 = Math_fround(HEAPF32[$183>>2]);
    $393 = Math_fround($390 * $390);
    $394 = Math_fround($391 * $391);
    $395 = Math_fround($393 + $394);
    $396 = Math_fround($392 * $392);
    $397 = Math_fround($395 + $396);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1350+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1350+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1350+8>>2]|0;
    $398 = $243 > $397;
    $399 = $397 > $21;
    if (!($399)) {
     label = 38;
     break;
    }
    if ($398) {
     $$$i10351076 = $$$i;$213 = $390;$215 = $391;$217 = $392;$243 = $397;
    } else {
     label = 38;
     break;
    }
   }
   if ((label|0) == 38) {
    $400 = HEAP32[$size>>2]|0;
    if ($398) {
     $490 = $400;
     break;
    }
    $401 = (($400) + -1)|0;
    $402 = ($aIndices|0)==(0|0);
    if (!($402)) {
     $403 = $401&255;
     HEAP8[$_size>>0] = $403;
     $404 = ($401|0)==(0);
     if (!($404)) {
      $i$01$i63 = 0;
      while(1) {
       $405 = (($aInd) + ($i$01$i63<<2)|0);
       $406 = HEAP32[$405>>2]|0;
       $407 = $406&255;
       $408 = (($aIndices) + ($i$01$i63)|0);
       HEAP8[$408>>0] = $407;
       $409 = (($bInd) + ($i$01$i63<<2)|0);
       $410 = HEAP32[$409>>2]|0;
       $411 = $410&255;
       $412 = (($bIndices) + ($i$01$i63)|0);
       HEAP8[$412>>0] = $411;
       $413 = (($i$01$i63) + 1)|0;
       $exitcond$i64 = ($413|0)==($401|0);
       if ($exitcond$i64) {
        break;
       } else {
        $i$01$i63 = $413;
       }
      }
     }
    }
    ;HEAP32[$closA+0>>2]=HEAP32[$tempClosA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$tempClosA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$tempClosA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$tempClosA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$tempClosB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$tempClosB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$tempClosB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$tempClosB+12>>2]|0;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $414 = Math_fround(HEAPF32[$closA>>2]);
    $415 = (($closA) + 4|0);
    $416 = Math_fround(HEAPF32[$415>>2]);
    $417 = (($closA) + 8|0);
    $418 = Math_fround(HEAPF32[$417>>2]);
    $419 = Math_fround(HEAPF32[$closB>>2]);
    $420 = (($closB) + 4|0);
    $421 = Math_fround(HEAPF32[$420>>2]);
    $422 = (($closB) + 8|0);
    $423 = Math_fround(HEAPF32[$422>>2]);
    $424 = Math_fround($414 - $419);
    $425 = Math_fround($416 - $421);
    $426 = Math_fround($418 - $423);
    HEAPF32[$v>>2] = $424;
    $427 = (($v) + 4|0);
    HEAPF32[$427>>2] = $425;
    $428 = (($v) + 8|0);
    HEAPF32[$428>>2] = $426;
    $429 = (($v) + 12|0);
    HEAPF32[$429>>2] = Math_fround(0.0);
    $430 = (Math_fround(Math_sqrt((Math_fround($243)))));
    $431 = Math_fround(Math_fround(1.0) / $430);
    $432 = Math_fround($424 * $431);
    $433 = Math_fround($425 * $431);
    $434 = Math_fround($426 * $431);
    if ($takeCoreShape) {
     $435 = (($a) + 64|0);
     $436 = HEAP32[$435>>2]|0;
     $437 = (($b) + 64|0);
     $438 = HEAP32[$437>>2]|0;
     $439 = ($436|0)==(0);
     $440 = $439 ? $10 : Math_fround(0.0);
     $441 = ($438|0)==(0);
     $442 = $441 ? $12 : Math_fround(0.0);
     $443 = Math_fround($440 + $442);
     $444 = Math_fround($432 * $440);
     $445 = Math_fround($433 * $440);
     $446 = Math_fround($434 * $440);
     $447 = Math_fround($414 - $444);
     $448 = Math_fround($416 - $445);
     $449 = Math_fround($418 - $446);
     HEAPF32[$contactA>>2] = $447;
     $450 = (($contactA) + 4|0);
     HEAPF32[$450>>2] = $448;
     $451 = (($contactA) + 8|0);
     HEAPF32[$451>>2] = $449;
     $452 = (($contactA) + 12|0);
     HEAPF32[$452>>2] = Math_fround(0.0);
     $453 = Math_fround($432 * $442);
     $454 = Math_fround($433 * $442);
     $455 = Math_fround($434 * $442);
     $456 = Math_fround($453 + $419);
     $457 = Math_fround($454 + $421);
     $458 = Math_fround($455 + $423);
     HEAPF32[$contactB>>2] = $456;
     $459 = (($contactB) + 4|0);
     HEAPF32[$459>>2] = $457;
     $460 = (($contactB) + 8|0);
     HEAPF32[$460>>2] = $458;
     $461 = (($contactB) + 12|0);
     HEAPF32[$461>>2] = Math_fround(0.0);
     $462 = Math_fround($430 - $443);
     HEAPF32[$penetrationDepth>>2] = $462;
     $463 = (($penetrationDepth) + 4|0);
     ;HEAP32[$463+0>>2]=HEAP32[$$sroa$1284+0>>2]|0;HEAP32[$463+4>>2]=HEAP32[$$sroa$1284+4>>2]|0;HEAP32[$463+8>>2]=HEAP32[$$sroa$1284+8>>2]|0;
    } else {
     $464 = Math_fround($10 * $432);
     $465 = Math_fround($10 * $433);
     $466 = Math_fround($10 * $434);
     $467 = Math_fround($414 - $464);
     $468 = Math_fround($416 - $465);
     $469 = Math_fround($418 - $466);
     HEAPF32[$contactA>>2] = $467;
     $470 = (($contactA) + 4|0);
     HEAPF32[$470>>2] = $468;
     $471 = (($contactA) + 8|0);
     HEAPF32[$471>>2] = $469;
     $472 = (($contactA) + 12|0);
     HEAPF32[$472>>2] = Math_fround(0.0);
     $473 = Math_fround($12 * $432);
     $474 = Math_fround($12 * $433);
     $475 = Math_fround($12 * $434);
     $476 = Math_fround($473 + $419);
     $477 = Math_fround($474 + $421);
     $478 = Math_fround($475 + $423);
     HEAPF32[$contactB>>2] = $476;
     $479 = (($contactB) + 4|0);
     HEAPF32[$479>>2] = $477;
     $480 = (($contactB) + 8|0);
     HEAPF32[$480>>2] = $478;
     $481 = (($contactB) + 12|0);
     HEAPF32[$481>>2] = Math_fround(0.0);
     $482 = Math_fround($430 - $19);
     HEAPF32[$penetrationDepth>>2] = $482;
     $483 = (($penetrationDepth) + 4|0);
     ;HEAP32[$483+0>>2]=HEAP32[$$sroa$1276+0>>2]|0;HEAP32[$483+4>>2]=HEAP32[$$sroa$1276+4>>2]|0;HEAP32[$483+8>>2]=HEAP32[$$sroa$1276+8>>2]|0;
    }
    HEAPF32[$normal>>2] = $432;
    $484 = (($normal) + 4|0);
    HEAPF32[$484>>2] = $433;
    $485 = (($normal) + 8|0);
    HEAPF32[$485>>2] = $434;
    $486 = (($normal) + 12|0);
    HEAPF32[$486>>2] = Math_fround(0.0);
    $487 = $22 >= $243;
    $$ = $487 ? 1 : 3;
    $$0 = $$;
    STACKTOP = sp;return ($$0|0);
   }
   $261 = ($aIndices|0)==(0|0);
   if (!($261)) {
    $262 = $233&255;
    HEAP8[$_size>>0] = $262;
    $263 = ($233|0)==(0);
    if (!($263)) {
     $i$01$i142 = 0;
     while(1) {
      $264 = (($aInd) + ($i$01$i142<<2)|0);
      $265 = HEAP32[$264>>2]|0;
      $266 = $265&255;
      $267 = (($aIndices) + ($i$01$i142)|0);
      HEAP8[$267>>0] = $266;
      $268 = (($bInd) + ($i$01$i142<<2)|0);
      $269 = HEAP32[$268>>2]|0;
      $270 = $269&255;
      $271 = (($bIndices) + ($i$01$i142)|0);
      HEAP8[$271>>0] = $270;
      $272 = (($i$01$i142) + 1)|0;
      $exitcond$i143 = ($272|0)==($233|0);
      if ($exitcond$i143) {
       break;
      } else {
       $i$01$i142 = $272;
      }
     }
    }
   }
   $not$ = $258 ^ 1;
   $$$1048 = $260 & $not$;
   if (!($$$1048)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $273 = (Math_fround(Math_sqrt((Math_fround($243)))));
   $274 = Math_fround(Math_fround(1.0) / $273);
   $275 = Math_fround($244 * $274);
   $276 = Math_fround($245 * $274);
   $277 = Math_fround($246 * $274);
   HEAPF32[$normal>>2] = $275;
   $278 = (($normal) + 4|0);
   HEAPF32[$278>>2] = $276;
   $279 = (($normal) + 8|0);
   HEAPF32[$279>>2] = $277;
   $280 = (($normal) + 12|0);
   HEAPF32[$280>>2] = Math_fround(0.0);
   if ($takeCoreShape) {
    $281 = (($a) + 64|0);
    $282 = HEAP32[$281>>2]|0;
    $283 = (($b) + 64|0);
    $284 = HEAP32[$283>>2]|0;
    $285 = ($282|0)==(0);
    $286 = $285 ? $10 : Math_fround(0.0);
    $287 = ($284|0)==(0);
    $288 = $287 ? $12 : Math_fround(0.0);
    $289 = Math_fround($286 + $288);
    $290 = Math_fround(HEAPF32[$closA>>2]);
    $291 = Math_fround(HEAPF32[$202>>2]);
    $292 = Math_fround(HEAPF32[$203>>2]);
    $293 = Math_fround($275 * $286);
    $294 = Math_fround($276 * $286);
    $295 = Math_fround($277 * $286);
    $296 = Math_fround($290 - $293);
    $297 = Math_fround($291 - $294);
    $298 = Math_fround($292 - $295);
    HEAPF32[$contactA>>2] = $296;
    $299 = (($contactA) + 4|0);
    HEAPF32[$299>>2] = $297;
    $300 = (($contactA) + 8|0);
    HEAPF32[$300>>2] = $298;
    $301 = (($contactA) + 12|0);
    HEAPF32[$301>>2] = Math_fround(0.0);
    $302 = Math_fround(HEAPF32[$closB>>2]);
    $303 = Math_fround(HEAPF32[$205>>2]);
    $304 = Math_fround(HEAPF32[$206>>2]);
    $305 = Math_fround($275 * $288);
    $306 = Math_fround($276 * $288);
    $307 = Math_fround($277 * $288);
    $308 = Math_fround($305 + $302);
    $309 = Math_fround($306 + $303);
    $310 = Math_fround($307 + $304);
    HEAPF32[$contactB>>2] = $308;
    $311 = (($contactB) + 4|0);
    HEAPF32[$311>>2] = $309;
    $312 = (($contactB) + 8|0);
    HEAPF32[$312>>2] = $310;
    $313 = (($contactB) + 12|0);
    HEAPF32[$313>>2] = Math_fround(0.0);
    $314 = Math_fround($273 - $289);
    HEAPF32[$penetrationDepth>>2] = $314;
    $315 = (($penetrationDepth) + 4|0);
    ;HEAP32[$315+0>>2]=HEAP32[$$sroa$1362+0>>2]|0;HEAP32[$315+4>>2]=HEAP32[$$sroa$1362+4>>2]|0;HEAP32[$315+8>>2]=HEAP32[$$sroa$1362+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $316 = Math_fround(HEAPF32[$closA>>2]);
    $317 = Math_fround(HEAPF32[$202>>2]);
    $318 = Math_fround(HEAPF32[$203>>2]);
    $319 = Math_fround($10 * $275);
    $320 = Math_fround($10 * $276);
    $321 = Math_fround($10 * $277);
    $322 = Math_fround($316 - $319);
    $323 = Math_fround($317 - $320);
    $324 = Math_fround($318 - $321);
    HEAPF32[$contactA>>2] = $322;
    $325 = (($contactA) + 4|0);
    HEAPF32[$325>>2] = $323;
    $326 = (($contactA) + 8|0);
    HEAPF32[$326>>2] = $324;
    $327 = (($contactA) + 12|0);
    HEAPF32[$327>>2] = Math_fround(0.0);
    $328 = Math_fround(HEAPF32[$closB>>2]);
    $329 = Math_fround(HEAPF32[$205>>2]);
    $330 = Math_fround(HEAPF32[$206>>2]);
    $331 = Math_fround($12 * $275);
    $332 = Math_fround($12 * $276);
    $333 = Math_fround($12 * $277);
    $334 = Math_fround($331 + $328);
    $335 = Math_fround($332 + $329);
    $336 = Math_fround($333 + $330);
    HEAPF32[$contactB>>2] = $334;
    $337 = (($contactB) + 4|0);
    HEAPF32[$337>>2] = $335;
    $338 = (($contactB) + 8|0);
    HEAPF32[$338>>2] = $336;
    $339 = (($contactB) + 12|0);
    HEAPF32[$339>>2] = Math_fround(0.0);
    $340 = Math_fround($273 - $19);
    HEAPF32[$penetrationDepth>>2] = $340;
    $341 = (($penetrationDepth) + 4|0);
    ;HEAP32[$341+0>>2]=HEAP32[$$sroa$1352+0>>2]|0;HEAP32[$341+4>>2]=HEAP32[$$sroa$1352+4>>2]|0;HEAP32[$341+8>>2]=HEAP32[$$sroa$1352+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $181 = HEAP32[$size>>2]|0;
   $490 = $181;
  }
 } while(0);
 $488 = ($aIndices|0)==(0|0);
 if (!($488)) {
  $489 = $490&255;
  HEAP8[$_size>>0] = $489;
  $491 = ($490|0)==(0);
  if (!($491)) {
   $i$01$i = 0;
   while(1) {
    $492 = (($aInd) + ($i$01$i<<2)|0);
    $493 = HEAP32[$492>>2]|0;
    $494 = $493&255;
    $495 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$495>>0] = $494;
    $496 = (($bInd) + ($i$01$i<<2)|0);
    $497 = HEAP32[$496>>2]|0;
    $498 = $497&255;
    $499 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$499>>0] = $498;
    $500 = (($i$01$i) + 1)|0;
    $exitcond$i = ($500|0)==($490|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $500;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu16_gjkLocalRayCastINS0_9TriangleVENS0_4BoxVEEEbRT_RT0_RKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VESF_RSA_RSD_SH_f($a,$b,$initialLambda,$s,$r,$lambda,$normal,$closestA,$_inflation) {
 $a = $a|0;
 $b = $b|0;
 $initialLambda = $initialLambda|0;
 $s = $s|0;
 $r = $r|0;
 $lambda = $lambda|0;
 $normal = $normal|0;
 $closestA = $closestA|0;
 $_inflation = Math_fround($_inflation);
 var $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in1$i$i$i = 0, $$in1$i$i$i142 = 0, $$in1$i$i$i146 = 0, $$in1$i$i$i189 = 0, $$in1$i$i$i198 = 0, $$in1$i19$i$i = 0, $$in1$i19$i$i195 = 0, $$in1$i21 = 0, $$in1$i214 = 0, $$in1$i37 = 0, $$in2$i = 0, $$in2$i$i$i = 0, $$in2$i$i$i144 = 0, $$in2$i$i$i147 = 0, $$in2$i$i$i191 = 0;
 var $$in2$i$i$i199 = 0, $$in2$i21$i$i = 0, $$in2$i21$i$i196 = 0, $$in2$i216 = 0, $$in2$i23 = 0, $$in2$i39 = 0, $$lcssa = Math_fround(0), $$lcssa952 = Math_fround(0), $$lcssa954 = Math_fround(0), $$lcssa956 = Math_fround(0), $$lcssa958 = Math_fround(0), $$lcssa960 = Math_fround(0), $$lcssa962 = Math_fround(0), $$lcssa964 = Math_fround(0), $$lcssa966 = Math_fround(0), $$lcssa968 = 0, $$lcssa970 = Math_fround(0), $$lcssa972 = Math_fround(0), $$lcssa974 = Math_fround(0), $$pre = Math_fround(0);
 var $$pre1008 = Math_fround(0), $$pre1009 = Math_fround(0), $$pre1010 = Math_fround(0), $$sroa$1344 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0);
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0);
 var $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0;
 var $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0);
 var $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0);
 var $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0);
 var $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = Math_fround(0);
 var $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = 0;
 var $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0);
 var $545 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0;
 var $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0, $Q = 0, $_lambda$sroa$1 = 0, $a$pn3$i = 0, $a$pn3$i$i$i = 0, $a$pn3$i$i$i141 = 0, $a$pn3$i$i$i188 = 0, $b$a$i = 0, $b$a$i$i$i = 0;
 var $b$a$i$i$i139 = 0, $b$a$i$i$i186 = 0, $b$a$i16$i$i = 0, $b$a$i16$i$i193 = 0, $b$a$i18 = 0, $b$a$i211 = 0, $b$a5$i = 0, $b$a5$i$i$i = 0, $b$a5$i$i$i143 = 0, $b$a5$i$i$i190 = 0, $closA = 0, $closB = 0, $phitmp = 0, $phitmp164$i$i = 0, $phitmp164$i$i192 = 0, $phitmp945 = 0, $size = 0, $support = 0, $tempV = 0, $zero$sroa$1 = 0;
 var $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 400|0;
 $1 = sp + 352|0;
 $2 = sp + 368|0;
 $3 = sp + 384|0;
 $4 = sp + 416|0;
 $5 = sp + 432|0;
 $6 = sp + 448|0;
 $7 = sp + 336|0;
 $8 = sp + 32|0;
 $9 = sp + 16|0;
 $10 = sp;
 $11 = sp + 64|0;
 $zeroV = sp + 48|0;
 $zero$sroa$1 = sp + 488|0;
 $_lambda$sroa$1 = sp + 464|0;
 $size = sp + 500|0;
 $Q = sp + 80|0;
 $A = sp + 144|0;
 $B = sp + 208|0;
 $support = sp + 272|0;
 $closA = sp + 288|0;
 $closB = sp + 304|0;
 $$sroa$1344 = sp + 476|0;
 $tempV = sp + 320|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $12 = Math_fround(HEAPF32[$r>>2]);
 $13 = (($r) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($r) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$s>>2]);
 $18 = (($s) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($s) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($12 * Math_fround(0.0));
 $23 = Math_fround($14 * Math_fround(0.0));
 $24 = Math_fround($16 * Math_fround(0.0));
 $25 = Math_fround($22 + $17);
 $26 = Math_fround($23 + $19);
 $27 = Math_fround($24 + $21);
 HEAP32[$size>>2] = 1;
 $28 = Math_fround(HEAPF32[$a>>2]);
 $29 = (($a) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($a) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(HEAPF32[$b>>2]);
 $34 = (($b) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($b) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($28 - $33);
 $39 = Math_fround($30 - $35);
 $40 = Math_fround($32 - $37);
 $41 = Math_fround($38 * $38);
 $42 = Math_fround($39 * $39);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($40 * $40);
 $45 = Math_fround($43 + $44);
 $46 = $45 > Math_fround(1.1920928955078125E-7);
 HEAPF32[$1>>2] = $38;
 $47 = (($1) + 4|0);
 HEAPF32[$47>>2] = $39;
 $48 = (($1) + 8|0);
 HEAPF32[$48>>2] = $40;
 $49 = (($1) + 12|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $50 = (($0) + 4|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($0) + 8|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($0) + 12|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $b$a$i211 = $46 ? $1 : $0;
 $53 = Math_fround(HEAPF32[$b$a$i211>>2]);
 $$in1$i214 = (($b$a$i211) + 4|0);
 $54 = Math_fround(HEAPF32[$$in1$i214>>2]);
 $$in2$i216 = (($b$a$i211) + 8|0);
 $55 = Math_fround(HEAPF32[$$in2$i216>>2]);
 $56 = Math_fround($53 * $53);
 $57 = Math_fround($54 * $54);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($55 * $55);
 $60 = Math_fround($58 + $59);
 $61 = (Math_fround(Math_sqrt((Math_fround($60)))));
 $62 = Math_fround(Math_fround(1.0) / $61);
 $63 = Math_fround($53 * $62);
 $64 = Math_fround($54 * $62);
 $65 = Math_fround($55 * $62);
 $66 = Math_fround(-$63);
 $67 = Math_fround(-$64);
 $68 = Math_fround(-$65);
 $69 = (($a) + 96|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($a) + 100|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($a) + 104|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($a) + 108|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($a) + 112|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($a) + 116|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($a) + 120|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($a) + 124|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($a) + 128|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($a) + 132|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($a) + 136|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($a) + 140|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($70 * $66);
 $94 = Math_fround($72 * $67);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($74 * $68);
 $97 = Math_fround($95 + $96);
 $98 = Math_fround($78 * $66);
 $99 = Math_fround($80 * $67);
 $100 = Math_fround($98 + $99);
 $101 = Math_fround($82 * $68);
 $102 = Math_fround($100 + $101);
 $103 = Math_fround($86 * $66);
 $104 = Math_fround($88 * $67);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($90 * $68);
 $107 = Math_fround($105 + $106);
 $108 = $97 > $102;
 if ($108) {
  $109 = $97 > $107;
  $phitmp164$i$i192 = $109 ? $5 : $4;
  $127 = $phitmp164$i$i192;
 } else {
  $127 = $4;
 }
 $110 = $102 > $107;
 HEAPF32[$3>>2] = $78;
 $111 = (($3) + 4|0);
 HEAPF32[$111>>2] = $80;
 $112 = (($3) + 8|0);
 HEAPF32[$112>>2] = $82;
 $113 = (($3) + 12|0);
 HEAPF32[$113>>2] = $84;
 HEAPF32[$2>>2] = $86;
 $114 = (($2) + 4|0);
 HEAPF32[$114>>2] = $88;
 $115 = (($2) + 8|0);
 HEAPF32[$115>>2] = $90;
 $116 = (($2) + 12|0);
 HEAPF32[$116>>2] = $92;
 $b$a$i16$i$i193 = $110 ? $3 : $2;
 $117 = Math_fround(HEAPF32[$b$a$i16$i$i193>>2]);
 $$in1$i19$i$i195 = (($b$a$i16$i$i193) + 4|0);
 $118 = Math_fround(HEAPF32[$$in1$i19$i$i195>>2]);
 $$in2$i21$i$i196 = (($b$a$i16$i$i193) + 8|0);
 $119 = Math_fround(HEAPF32[$$in2$i21$i$i196>>2]);
 HEAPF32[$5>>2] = $70;
 $120 = (($5) + 4|0);
 HEAPF32[$120>>2] = $72;
 $121 = (($5) + 8|0);
 HEAPF32[$121>>2] = $74;
 $122 = (($5) + 12|0);
 HEAPF32[$122>>2] = $76;
 HEAPF32[$4>>2] = $117;
 $123 = (($4) + 4|0);
 HEAPF32[$123>>2] = $118;
 $124 = (($4) + 8|0);
 HEAPF32[$124>>2] = $119;
 $125 = (($4) + 12|0);
 HEAPF32[$125>>2] = Math_fround(0.0);
 $126 = Math_fround(HEAPF32[$127>>2]);
 $$in1$i$i$i198 = (($127) + 4|0);
 $128 = Math_fround(HEAPF32[$$in1$i$i$i198>>2]);
 $$in2$i$i$i199 = (($127) + 8|0);
 $129 = Math_fround(HEAPF32[$$in2$i$i$i199>>2]);
 $130 = $63 > Math_fround(0.0);
 $131 = $64 > Math_fround(0.0);
 $132 = $65 > Math_fround(0.0);
 $133 = (($b) + 144|0);
 ;HEAP32[$3+0>>2]=HEAP32[$133+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$133+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$133+12>>2]|0;
 $134 = (($b) + 144|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($b) + 148|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($b) + 152|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround(-$135);
 $141 = Math_fround(-$137);
 $142 = Math_fround(-$139);
 HEAPF32[$2>>2] = $140;
 $143 = (($2) + 4|0);
 HEAPF32[$143>>2] = $141;
 $144 = (($2) + 8|0);
 HEAPF32[$144>>2] = $142;
 $145 = (($2) + 12|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $b$a$i$i$i186 = $130 ? $3 : $2;
 $146 = Math_fround(HEAPF32[$b$a$i$i$i186>>2]);
 $a$pn3$i$i$i188 = $131 ? $3 : $2;
 $$in1$i$i$i189 = (($a$pn3$i$i$i188) + 4|0);
 $147 = Math_fround(HEAPF32[$$in1$i$i$i189>>2]);
 $b$a5$i$i$i190 = $132 ? $3 : $2;
 $$in2$i$i$i191 = (($b$a5$i$i$i190) + 8|0);
 $148 = Math_fround(HEAPF32[$$in2$i$i$i191>>2]);
 $149 = Math_fround($126 - $146);
 $150 = Math_fround($128 - $147);
 $151 = Math_fround($129 - $148);
 HEAPF32[$Q>>2] = $149;
 $152 = (($Q) + 4|0);
 HEAPF32[$152>>2] = $150;
 $153 = (($Q) + 8|0);
 HEAPF32[$153>>2] = $151;
 $154 = (($Q) + 12|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 $155 = (($Q) + 16|0);
 ;HEAP32[$155+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$155+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $156 = (($Q) + 32|0);
 ;HEAP32[$156+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$156+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$156+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $157 = (($Q) + 48|0);
 ;HEAP32[$157+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$157+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$A>>2] = $126;
 $158 = (($A) + 4|0);
 HEAPF32[$158>>2] = $128;
 $159 = (($A) + 8|0);
 HEAPF32[$159>>2] = $129;
 $160 = (($A) + 12|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 $161 = (($A) + 16|0);
 ;HEAP32[$161+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $162 = (($A) + 32|0);
 ;HEAP32[$162+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $163 = (($A) + 48|0);
 ;HEAP32[$163+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$163+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$B>>2] = $146;
 $164 = (($B) + 4|0);
 HEAPF32[$164>>2] = $147;
 $165 = (($B) + 8|0);
 HEAPF32[$165>>2] = $148;
 $166 = (($B) + 12|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = (($B) + 16|0);
 ;HEAP32[$167+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$167+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $168 = (($B) + 32|0);
 ;HEAP32[$168+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$168+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$168+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$168+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $169 = (($B) + 48|0);
 ;HEAP32[$169+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$169+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$169+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$169+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $170 = Math_fround(-$149);
 $171 = Math_fround(-$150);
 $172 = Math_fround(-$151);
 ;HEAP32[$support+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$Q+12>>2]|0;
 $173 = (($a) + 32|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($b) + 32|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = $174 > $176;
 $$$i = $177 ? $176 : $174;
 $178 = Math_fround($$$i * Math_fround(0.100000001490116119385));
 $179 = Math_fround($178 * $178);
 $180 = Math_fround($_inflation * $_inflation);
 $181 = Math_fround($180 + $179);
 HEAPF32[$closA>>2] = $126;
 $182 = (($closA) + 4|0);
 HEAPF32[$182>>2] = $128;
 $183 = (($closA) + 8|0);
 HEAPF32[$183>>2] = $129;
 $184 = (($closA) + 12|0);
 HEAPF32[$184>>2] = Math_fround(0.0);
 HEAPF32[$closB>>2] = $146;
 $185 = (($closB) + 4|0);
 HEAPF32[$185>>2] = $147;
 $186 = (($closB) + 8|0);
 HEAPF32[$186>>2] = $148;
 $187 = (($closB) + 12|0);
 HEAPF32[$187>>2] = Math_fround(0.0);
 $188 = Math_fround($149 * $149);
 $189 = Math_fround($150 * $150);
 $190 = Math_fround($188 + $189);
 $191 = Math_fround($151 * $151);
 $192 = Math_fround($190 + $191);
 $193 = $192 > $179;
 L4: do {
  if ($193) {
   $194 = (($3) + 4|0);
   $195 = (($3) + 8|0);
   $196 = (($3) + 12|0);
   $197 = (($2) + 4|0);
   $198 = (($2) + 8|0);
   $199 = (($2) + 12|0);
   $200 = (($5) + 4|0);
   $201 = (($5) + 8|0);
   $202 = (($5) + 12|0);
   $203 = (($4) + 4|0);
   $204 = (($4) + 8|0);
   $205 = (($4) + 12|0);
   $206 = (($2) + 4|0);
   $207 = (($2) + 8|0);
   $208 = (($2) + 12|0);
   $209 = (($support) + 4|0);
   $210 = (($support) + 8|0);
   $211 = (($support) + 12|0);
   $212 = (($B) + 16|0);
   $213 = (($B) + 20|0);
   $214 = (($B) + 24|0);
   $215 = (($B) + 28|0);
   $216 = (($B) + 32|0);
   $217 = (($B) + 36|0);
   $218 = (($B) + 40|0);
   $219 = (($B) + 44|0);
   $220 = (($A) + 16|0);
   $221 = (($A) + 20|0);
   $222 = (($A) + 24|0);
   $223 = (($Q) + 16|0);
   $224 = (($Q) + 20|0);
   $225 = (($Q) + 24|0);
   $226 = (($Q) + 28|0);
   $227 = (($A) + 32|0);
   $228 = (($A) + 36|0);
   $229 = (($A) + 40|0);
   $230 = (($Q) + 32|0);
   $231 = (($Q) + 36|0);
   $232 = (($Q) + 40|0);
   $233 = (($Q) + 44|0);
   $234 = (($2) + 4|0);
   $235 = (($2) + 8|0);
   $236 = (($2) + 12|0);
   $237 = (($tempV) + 4|0);
   $238 = (($tempV) + 8|0);
   $239 = (($tempV) + 12|0);
   $241 = $170;$243 = $171;$246 = $172;$303 = $25;$305 = $26;$307 = $27;$330 = Math_fround(0.0);$531 = Math_fround(0.0);$532 = $129;$533 = $128;$534 = $126;$535 = $170;$536 = $171;$537 = $172;$538 = $192;
   while(1) {
    $240 = Math_fround($241 * $241);
    $242 = Math_fround($243 * $243);
    $244 = Math_fround($242 + $240);
    $245 = Math_fround($246 * $246);
    $247 = Math_fround($245 + $244);
    $248 = (Math_fround(Math_sqrt((Math_fround($247)))));
    $249 = Math_fround(Math_fround(1.0) / $248);
    $250 = Math_fround($241 * $249);
    $251 = Math_fround($243 * $249);
    $252 = Math_fround($246 * $249);
    $253 = Math_fround(HEAPF32[$69>>2]);
    $254 = Math_fround(HEAPF32[$71>>2]);
    $255 = Math_fround(HEAPF32[$73>>2]);
    $256 = Math_fround(HEAPF32[$75>>2]);
    $257 = Math_fround(HEAPF32[$77>>2]);
    $258 = Math_fround(HEAPF32[$79>>2]);
    $259 = Math_fround(HEAPF32[$81>>2]);
    $260 = Math_fround(HEAPF32[$83>>2]);
    $261 = Math_fround(HEAPF32[$85>>2]);
    $262 = Math_fround(HEAPF32[$87>>2]);
    $263 = Math_fround(HEAPF32[$89>>2]);
    $264 = Math_fround(HEAPF32[$91>>2]);
    $265 = Math_fround($250 * $253);
    $266 = Math_fround($251 * $254);
    $267 = Math_fround($265 + $266);
    $268 = Math_fround($252 * $255);
    $269 = Math_fround($267 + $268);
    $270 = Math_fround($250 * $257);
    $271 = Math_fround($251 * $258);
    $272 = Math_fround($270 + $271);
    $273 = Math_fround($252 * $259);
    $274 = Math_fround($272 + $273);
    $275 = Math_fround($250 * $261);
    $276 = Math_fround($251 * $262);
    $277 = Math_fround($275 + $276);
    $278 = Math_fround($252 * $263);
    $279 = Math_fround($277 + $278);
    $280 = $269 > $274;
    if ($280) {
     $281 = $269 > $279;
     $phitmp164$i$i = $281 ? $5 : $4;
     $287 = $phitmp164$i$i;
    } else {
     $287 = $4;
    }
    $282 = $274 > $279;
    HEAPF32[$3>>2] = $257;
    HEAPF32[$194>>2] = $258;
    HEAPF32[$195>>2] = $259;
    HEAPF32[$196>>2] = $260;
    HEAPF32[$2>>2] = $261;
    HEAPF32[$197>>2] = $262;
    HEAPF32[$198>>2] = $263;
    HEAPF32[$199>>2] = $264;
    $b$a$i16$i$i = $282 ? $3 : $2;
    $283 = Math_fround(HEAPF32[$b$a$i16$i$i>>2]);
    $$in1$i19$i$i = (($b$a$i16$i$i) + 4|0);
    $284 = Math_fround(HEAPF32[$$in1$i19$i$i>>2]);
    $$in2$i21$i$i = (($b$a$i16$i$i) + 8|0);
    $285 = Math_fround(HEAPF32[$$in2$i21$i$i>>2]);
    HEAPF32[$5>>2] = $253;
    HEAPF32[$200>>2] = $254;
    HEAPF32[$201>>2] = $255;
    HEAPF32[$202>>2] = $256;
    HEAPF32[$4>>2] = $283;
    HEAPF32[$203>>2] = $284;
    HEAPF32[$204>>2] = $285;
    HEAPF32[$205>>2] = Math_fround(0.0);
    $286 = Math_fround(HEAPF32[$287>>2]);
    $$in1$i$i$i146 = (($287) + 4|0);
    $288 = Math_fround(HEAPF32[$$in1$i$i$i146>>2]);
    $$in2$i$i$i147 = (($287) + 8|0);
    $289 = Math_fround(HEAPF32[$$in2$i$i$i147>>2]);
    $290 = $250 < Math_fround(-0.0);
    $291 = $251 < Math_fround(-0.0);
    $292 = $252 < Math_fround(-0.0);
    ;HEAP32[$3+0>>2]=HEAP32[$133+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$133+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$133+12>>2]|0;
    $293 = Math_fround(HEAPF32[$134>>2]);
    $294 = Math_fround(HEAPF32[$136>>2]);
    $295 = Math_fround(HEAPF32[$138>>2]);
    $296 = Math_fround(-$293);
    $297 = Math_fround(-$294);
    $298 = Math_fround(-$295);
    HEAPF32[$2>>2] = $296;
    HEAPF32[$206>>2] = $297;
    HEAPF32[$207>>2] = $298;
    HEAPF32[$208>>2] = Math_fround(0.0);
    $b$a$i$i$i139 = $290 ? $3 : $2;
    $299 = Math_fround(HEAPF32[$b$a$i$i$i139>>2]);
    $a$pn3$i$i$i141 = $291 ? $3 : $2;
    $$in1$i$i$i142 = (($a$pn3$i$i$i141) + 4|0);
    $300 = Math_fround(HEAPF32[$$in1$i$i$i142>>2]);
    $b$a5$i$i$i143 = $292 ? $3 : $2;
    $$in2$i$i$i144 = (($b$a5$i$i$i143) + 8|0);
    $301 = Math_fround(HEAPF32[$$in2$i$i$i144>>2]);
    $302 = Math_fround($303 + $299);
    $304 = Math_fround($305 + $300);
    $306 = Math_fround($307 + $301);
    $308 = Math_fround($286 - $302);
    $309 = Math_fround($288 - $304);
    $310 = Math_fround($289 - $306);
    HEAPF32[$support>>2] = $308;
    HEAPF32[$209>>2] = $309;
    HEAPF32[$210>>2] = $310;
    HEAPF32[$211>>2] = Math_fround(0.0);
    $311 = Math_fround($250 * $308);
    $312 = Math_fround($251 * $309);
    $313 = Math_fround(-$312);
    $314 = Math_fround($313 - $311);
    $315 = Math_fround($252 * $310);
    $316 = Math_fround($314 - $315);
    $317 = Math_fround($316 - $_inflation);
    $318 = Math_fround(HEAPF32[$r>>2]);
    $319 = Math_fround(HEAPF32[$13>>2]);
    $320 = Math_fround(HEAPF32[$15>>2]);
    $321 = Math_fround($250 * $318);
    $322 = Math_fround($251 * $319);
    $323 = Math_fround($321 + $322);
    $324 = Math_fround($252 * $320);
    $325 = Math_fround($323 + $324);
    $326 = $317 > Math_fround(0.0);
    if ($326) {
     $327 = !($325 >= Math_fround(0.0));
     if (!($327)) {
      $$0 = 0;
      label = 26;
      break;
     }
     $328 = Math_fround($317 / $325);
     $329 = Math_fround($330 - $328);
     ;HEAP32[$_lambda$sroa$1+0>>2]=HEAP32[$$sroa$1344+0>>2]|0;HEAP32[$_lambda$sroa$1+4>>2]=HEAP32[$$sroa$1344+4>>2]|0;HEAP32[$_lambda$sroa$1+8>>2]=HEAP32[$$sroa$1344+8>>2]|0;
     $331 = $329 > $330;
     if ($331) {
      $332 = $329 > Math_fround(1.0);
      if ($332) {
       $$0 = 0;
       label = 26;
       break;
      }
      $333 = Math_fround(HEAPF32[$s>>2]);
      $334 = Math_fround(HEAPF32[$18>>2]);
      $335 = Math_fround(HEAPF32[$20>>2]);
      $336 = Math_fround($329 * $318);
      $337 = Math_fround($329 * $319);
      $338 = Math_fround($329 * $320);
      $339 = Math_fround($336 + $333);
      $340 = Math_fround($337 + $334);
      $341 = Math_fround($338 + $335);
      $342 = Math_fround($339 - $303);
      $343 = Math_fround($340 - $305);
      $344 = Math_fround($341 - $307);
      $345 = Math_fround(HEAPF32[$B>>2]);
      $346 = Math_fround(HEAPF32[$164>>2]);
      $347 = Math_fround(HEAPF32[$165>>2]);
      $348 = Math_fround($342 + $345);
      $349 = Math_fround($343 + $346);
      $350 = Math_fround($344 + $347);
      $351 = Math_fround(HEAPF32[$212>>2]);
      $352 = Math_fround(HEAPF32[$213>>2]);
      $353 = Math_fround(HEAPF32[$214>>2]);
      $354 = Math_fround($342 + $351);
      $355 = Math_fround($343 + $352);
      $356 = Math_fround($344 + $353);
      $357 = Math_fround(HEAPF32[$216>>2]);
      $358 = Math_fround(HEAPF32[$217>>2]);
      $359 = Math_fround(HEAPF32[$218>>2]);
      $360 = Math_fround($342 + $357);
      $361 = Math_fround($343 + $358);
      $362 = Math_fround($344 + $359);
      HEAPF32[$B>>2] = $348;
      HEAPF32[$164>>2] = $349;
      HEAPF32[$165>>2] = $350;
      HEAPF32[$166>>2] = Math_fround(0.0);
      HEAPF32[$212>>2] = $354;
      HEAPF32[$213>>2] = $355;
      HEAPF32[$214>>2] = $356;
      HEAPF32[$215>>2] = Math_fround(0.0);
      HEAPF32[$216>>2] = $360;
      HEAPF32[$217>>2] = $361;
      HEAPF32[$218>>2] = $362;
      HEAPF32[$219>>2] = Math_fround(0.0);
      $363 = Math_fround(HEAPF32[$A>>2]);
      $364 = Math_fround(HEAPF32[$158>>2]);
      $365 = Math_fround(HEAPF32[$159>>2]);
      $366 = Math_fround($363 - $348);
      $367 = Math_fround($364 - $349);
      $368 = Math_fround($365 - $350);
      HEAPF32[$Q>>2] = $366;
      HEAPF32[$152>>2] = $367;
      HEAPF32[$153>>2] = $368;
      HEAPF32[$154>>2] = Math_fround(0.0);
      $369 = Math_fround(HEAPF32[$220>>2]);
      $370 = Math_fround(HEAPF32[$221>>2]);
      $371 = Math_fround(HEAPF32[$222>>2]);
      $372 = Math_fround($369 - $354);
      $373 = Math_fround($370 - $355);
      $374 = Math_fround($371 - $356);
      HEAPF32[$223>>2] = $372;
      HEAPF32[$224>>2] = $373;
      HEAPF32[$225>>2] = $374;
      HEAPF32[$226>>2] = Math_fround(0.0);
      $375 = Math_fround(HEAPF32[$227>>2]);
      $376 = Math_fround(HEAPF32[$228>>2]);
      $377 = Math_fround(HEAPF32[$229>>2]);
      $378 = Math_fround($375 - $360);
      $379 = Math_fround($376 - $361);
      $380 = Math_fround($377 - $362);
      HEAPF32[$230>>2] = $378;
      HEAPF32[$231>>2] = $379;
      HEAPF32[$232>>2] = $380;
      HEAPF32[$233>>2] = Math_fround(0.0);
      ;HEAP32[$3+0>>2]=HEAP32[$133+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$133+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$133+12>>2]|0;
      HEAPF32[$2>>2] = $296;
      HEAPF32[$234>>2] = $297;
      HEAPF32[$235>>2] = $298;
      HEAPF32[$236>>2] = Math_fround(0.0);
      $b$a$i$i$i = $290 ? $3 : $2;
      $381 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
      $a$pn3$i$i$i = $291 ? $3 : $2;
      $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
      $382 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
      $b$a5$i$i$i = $292 ? $3 : $2;
      $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
      $383 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
      $384 = Math_fround($339 + $381);
      $385 = Math_fround($340 + $382);
      $386 = Math_fround($341 + $383);
      $387 = Math_fround($286 - $384);
      $388 = Math_fround($288 - $385);
      $389 = Math_fround($289 - $386);
      HEAPF32[$support>>2] = $387;
      HEAPF32[$209>>2] = $388;
      HEAPF32[$210>>2] = $389;
      HEAPF32[$211>>2] = Math_fround(0.0);
      $396 = $384;$398 = $385;$400 = $386;$408 = $387;$410 = $388;$412 = $389;$467 = Math_fround(3.40282346638528859812E+38);$539 = $329;$540 = $341;$541 = $340;$542 = $339;$543 = $246;$544 = $243;$545 = $241;
     } else {
      $396 = $302;$398 = $304;$400 = $306;$408 = $308;$410 = $309;$412 = $310;$467 = $538;$539 = $329;$540 = $307;$541 = $305;$542 = $303;$543 = $537;$544 = $536;$545 = $535;
     }
    } else {
     $396 = $302;$398 = $304;$400 = $306;$408 = $308;$410 = $309;$412 = $310;$467 = $538;$539 = $330;$540 = $307;$541 = $305;$542 = $303;$543 = $537;$544 = $536;$545 = $535;
    }
    $390 = HEAP32[$size>>2]|0;
    $391 = (($A) + ($390<<4)|0);
    HEAPF32[$391>>2] = $286;
    $392 = ((($A) + ($390<<4)|0) + 4|0);
    HEAPF32[$392>>2] = $288;
    $393 = ((($A) + ($390<<4)|0) + 8|0);
    HEAPF32[$393>>2] = $289;
    $394 = ((($A) + ($390<<4)|0) + 12|0);
    HEAPF32[$394>>2] = Math_fround(0.0);
    $395 = (($B) + ($390<<4)|0);
    HEAPF32[$395>>2] = $396;
    $397 = ((($B) + ($390<<4)|0) + 4|0);
    HEAPF32[$397>>2] = $398;
    $399 = ((($B) + ($390<<4)|0) + 8|0);
    HEAPF32[$399>>2] = $400;
    $401 = ((($B) + ($390<<4)|0) + 12|0);
    HEAPF32[$401>>2] = Math_fround(0.0);
    $402 = (($390) + 1)|0;
    HEAP32[$size>>2] = $402;
    $403 = (($Q) + ($390<<4)|0);
    ;HEAP32[$403+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$403+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$403+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$403+12>>2]=HEAP32[$support+12>>2]|0;
    do {
     if ((($390|0) == 1)) {
      $404 = Math_fround(HEAPF32[$Q>>2]);
      $405 = Math_fround(HEAPF32[$152>>2]);
      $406 = Math_fround(HEAPF32[$153>>2]);
      $407 = Math_fround($408 - $404);
      $409 = Math_fround($410 - $405);
      $411 = Math_fround($412 - $406);
      $413 = Math_fround($407 * $407);
      $414 = Math_fround($409 * $409);
      $415 = Math_fround($413 + $414);
      $416 = Math_fround($411 * $411);
      $417 = Math_fround($415 + $416);
      $418 = $417 == Math_fround(0.0);
      if ($418) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$tempV+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $419 = Math_fround($405 * $409);
       $420 = Math_fround(-$419);
       $421 = Math_fround($404 * $407);
       $422 = Math_fround($420 - $421);
       $423 = Math_fround($406 * $411);
       $424 = Math_fround($422 - $423);
       $425 = Math_fround(HEAPF32[$A>>2]);
       $426 = Math_fround(HEAPF32[$158>>2]);
       $427 = Math_fround(HEAPF32[$159>>2]);
       $428 = Math_fround($286 - $425);
       $429 = Math_fround($288 - $426);
       $430 = Math_fround($289 - $427);
       $431 = Math_fround(HEAPF32[$B>>2]);
       $432 = Math_fround(HEAPF32[$164>>2]);
       $433 = Math_fround(HEAPF32[$165>>2]);
       $434 = Math_fround($396 - $431);
       $435 = Math_fround($398 - $432);
       $436 = Math_fround($400 - $433);
       $437 = Math_fround($424 / $417);
       $438 = $437 > Math_fround(1.0);
       $$$i$i$i = $438 ? Math_fround(1.0) : $437;
       $439 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $439 ? $$$i$i$i : Math_fround(0.0);
       $440 = Math_fround($428 * $$$i8$i$i);
       $441 = Math_fround($429 * $$$i8$i$i);
       $442 = Math_fround($430 * $$$i8$i$i);
       $443 = Math_fround($425 + $440);
       $444 = Math_fround($426 + $441);
       $445 = Math_fround($427 + $442);
       $446 = Math_fround($434 * $$$i8$i$i);
       $447 = Math_fround($435 * $$$i8$i$i);
       $448 = Math_fround($436 * $$$i8$i$i);
       $449 = Math_fround($431 + $446);
       $450 = Math_fround($432 + $447);
       $451 = Math_fround($433 + $448);
       HEAPF32[$closA>>2] = $443;
       HEAPF32[$182>>2] = $444;
       HEAPF32[$183>>2] = $445;
       HEAPF32[$184>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $449;
       HEAPF32[$185>>2] = $450;
       HEAPF32[$186>>2] = $451;
       HEAPF32[$187>>2] = Math_fround(0.0);
       $452 = Math_fround($443 - $449);
       $453 = Math_fround($444 - $450);
       $454 = Math_fround($445 - $451);
       HEAPF32[$tempV>>2] = $452;
       HEAPF32[$237>>2] = $453;
       HEAPF32[$238>>2] = $454;
       HEAPF32[$239>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($390|0) == 0)) {
      HEAPF32[$closA>>2] = $286;
      HEAPF32[$182>>2] = $288;
      HEAPF32[$183>>2] = $289;
      HEAPF32[$184>>2] = Math_fround(0.0);
      HEAPF32[$closB>>2] = $396;
      HEAPF32[$185>>2] = $398;
      HEAPF32[$186>>2] = $400;
      HEAPF32[$187>>2] = Math_fround(0.0);
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($390|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($tempV,$Q,$155,$support,$Q,$A,$B,$size,$closA,$closB);
     } else if ((($390|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_RjRS3_S6_($tempV,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$tempV+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$tempV+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$tempV+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$tempV+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $455 = Math_fround(HEAPF32[$tempV>>2]);
    $456 = Math_fround(HEAPF32[$237>>2]);
    $457 = Math_fround(HEAPF32[$238>>2]);
    $458 = Math_fround(-$455);
    $459 = Math_fround(-$456);
    $460 = Math_fround(-$457);
    $461 = Math_fround($455 * $455);
    $462 = Math_fround($456 * $456);
    $463 = Math_fround($461 + $462);
    $464 = Math_fround($457 * $457);
    $465 = Math_fround($463 + $464);
    $466 = $467 > $465;
    $468 = $466 << 31 >> 31;
    $469 = $465 > $181;
    if (!($469)) {
     $$lcssa = $539;$$lcssa952 = $531;$$lcssa954 = $532;$$lcssa956 = $533;$$lcssa958 = $534;$$lcssa960 = $460;$$lcssa962 = $459;$$lcssa964 = $458;$$lcssa966 = $465;$$lcssa968 = $468;$$lcssa970 = $543;$$lcssa972 = $544;$$lcssa974 = $545;
     break L4;
    }
    if (!($466)) {
     $$lcssa = $539;$$lcssa952 = $531;$$lcssa954 = $532;$$lcssa956 = $533;$$lcssa958 = $534;$$lcssa960 = $460;$$lcssa962 = $459;$$lcssa964 = $458;$$lcssa966 = $465;$$lcssa968 = $468;$$lcssa970 = $543;$$lcssa972 = $544;$$lcssa974 = $545;
     break L4;
    }
    $$pre = Math_fround(HEAPF32[$closA>>2]);
    $$pre1008 = Math_fround(HEAPF32[$182>>2]);
    $$pre1009 = Math_fround(HEAPF32[$183>>2]);
    $$pre1010 = Math_fround(HEAPF32[$184>>2]);
    $241 = $458;$243 = $459;$246 = $460;$303 = $542;$305 = $541;$307 = $540;$330 = $539;$531 = $$pre1010;$532 = $$pre1009;$533 = $$pre1008;$534 = $$pre;$535 = $545;$536 = $544;$537 = $543;$538 = $465;
   }
   if ((label|0) == 26) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$lcssa = Math_fround(0.0);$$lcssa952 = Math_fround(0.0);$$lcssa954 = $129;$$lcssa956 = $128;$$lcssa958 = $126;$$lcssa960 = $172;$$lcssa962 = $171;$$lcssa964 = $170;$$lcssa966 = $192;$$lcssa968 = -1;$$lcssa970 = $172;$$lcssa972 = $171;$$lcssa974 = $170;
  }
 } while(0);
 $470 = (($a) + 64|0);
 $471 = HEAP32[$470>>2]|0;
 $472 = (($a) + 68|0);
 $473 = HEAP32[$472>>2]|0;
 $474 = (($a) + 72|0);
 $475 = HEAP32[$474>>2]|0;
 $476 = $$lcssa966 > $179;
 if ($476) {
  $phitmp = ($$lcssa968|0)==(0);
  $phitmp945 = $phitmp ? $6 : $7;
  $484 = $phitmp945;
 } else {
  $484 = $6;
 }
 HEAPF32[$7>>2] = $$lcssa964;
 $477 = (($7) + 4|0);
 HEAPF32[$477>>2] = $$lcssa962;
 $478 = (($7) + 8|0);
 HEAPF32[$478>>2] = $$lcssa960;
 $479 = (($7) + 12|0);
 HEAPF32[$479>>2] = Math_fround(0.0);
 HEAPF32[$6>>2] = $$lcssa974;
 $480 = (($6) + 4|0);
 HEAPF32[$480>>2] = $$lcssa972;
 $481 = (($6) + 8|0);
 HEAPF32[$481>>2] = $$lcssa970;
 $482 = (($6) + 12|0);
 HEAPF32[$482>>2] = Math_fround(0.0);
 $483 = Math_fround(HEAPF32[$484>>2]);
 $$in1$i37 = (($484) + 4|0);
 $485 = Math_fround(HEAPF32[$$in1$i37>>2]);
 $$in2$i39 = (($484) + 8|0);
 $486 = Math_fround(HEAPF32[$$in2$i39>>2]);
 $487 = Math_fround($483 * $483);
 $488 = Math_fround($485 * $485);
 $489 = Math_fround($487 + $488);
 $490 = Math_fround($486 * $486);
 $491 = Math_fround($489 + $490);
 $492 = (Math_fround(Math_sqrt((Math_fround($491)))));
 $493 = Math_fround(Math_fround(1.0) / $492);
 $494 = Math_fround($483 * $493);
 $495 = Math_fround($485 * $493);
 $496 = Math_fround($486 * $493);
 $497 = Math_fround(-$494);
 $498 = Math_fround(-$495);
 $499 = Math_fround(-$496);
 HEAPF32[$normal>>2] = $497;
 $500 = (($normal) + 4|0);
 HEAPF32[$500>>2] = $498;
 $501 = (($normal) + 8|0);
 HEAPF32[$501>>2] = $499;
 $502 = (($normal) + 12|0);
 HEAPF32[$502>>2] = Math_fround(0.0);
 HEAPF32[$lambda>>2] = $$lcssa;
 $503 = (($lambda) + 4|0);
 ;HEAP32[$503+0>>2]=HEAP32[$_lambda$sroa$1+0>>2]|0;HEAP32[$503+4>>2]=HEAP32[$_lambda$sroa$1+4>>2]|0;HEAP32[$503+8>>2]=HEAP32[$_lambda$sroa$1+8>>2]|0;
 ;HEAP32[$9+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$8>>2] = $$lcssa958;
 $504 = (($8) + 4|0);
 HEAPF32[$504>>2] = $$lcssa956;
 $505 = (($8) + 8|0);
 HEAPF32[$505>>2] = $$lcssa954;
 $506 = (($8) + 12|0);
 HEAPF32[$506>>2] = $$lcssa952;
 $507 = ($$lcssa968|0)==(0);
 $b$a$i18 = $507 ? $8 : $9;
 $508 = Math_fround(HEAPF32[$b$a$i18>>2]);
 $$in1$i21 = (($b$a$i18) + 4|0);
 $509 = Math_fround(HEAPF32[$$in1$i21>>2]);
 $$in2$i23 = (($b$a$i18) + 8|0);
 $510 = Math_fround(HEAPF32[$$in2$i23>>2]);
 HEAPF32[$closA>>2] = $508;
 HEAPF32[$182>>2] = $509;
 HEAPF32[$183>>2] = $510;
 HEAPF32[$184>>2] = Math_fround(0.0);
 $511 = (($a) + 16|0);
 $512 = Math_fround(HEAPF32[$511>>2]);
 $513 = Math_fround($512 * $497);
 $514 = Math_fround($512 * $498);
 $515 = Math_fround($512 * $499);
 $516 = Math_fround($508 - $513);
 $517 = Math_fround($509 - $514);
 $518 = Math_fround($510 - $515);
 ;HEAP32[$10+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$closA+12>>2]|0;
 HEAPF32[$11>>2] = $516;
 $519 = (($11) + 4|0);
 HEAPF32[$519>>2] = $517;
 $520 = (($11) + 8|0);
 HEAPF32[$520>>2] = $518;
 $521 = (($11) + 12|0);
 HEAPF32[$521>>2] = Math_fround(0.0);
 $522 = ($471|0)==(0);
 $b$a$i = $522 ? $10 : $11;
 $523 = Math_fround(HEAPF32[$b$a$i>>2]);
 $524 = ($473|0)==(0);
 $a$pn3$i = $524 ? $10 : $11;
 $$in1$i = (($a$pn3$i) + 4|0);
 $525 = Math_fround(HEAPF32[$$in1$i>>2]);
 $526 = ($475|0)==(0);
 $b$a5$i = $526 ? $10 : $11;
 $$in2$i = (($b$a5$i) + 8|0);
 $527 = Math_fround(HEAPF32[$$in2$i>>2]);
 HEAPF32[$closestA>>2] = $523;
 $528 = (($closestA) + 4|0);
 HEAPF32[$528>>2] = $525;
 $529 = (($closestA) + 8|0);
 HEAPF32[$529>>2] = $527;
 $530 = (($closestA) + 12|0);
 HEAPF32[$530>>2] = Math_fround(0.0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19gjkLocalPenetrationINS0_9TriangleVENS0_10ShrunkBoxVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($a,$b,$_contactDist,$contactA,$contactB,$normal,$penetrationDepth,$aIndices,$bIndices,$_size,$takeCoreShape) {
 $a = $a|0;
 $b = $b|0;
 $_contactDist = $_contactDist|0;
 $contactA = $contactA|0;
 $contactB = $contactB|0;
 $normal = $normal|0;
 $penetrationDepth = $penetrationDepth|0;
 $aIndices = $aIndices|0;
 $bIndices = $bIndices|0;
 $_size = $_size|0;
 $takeCoreShape = $takeCoreShape|0;
 var $$ = 0, $$$1062 = 0, $$$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i250 = Math_fround(0), $$$i10491096 = Math_fround(0), $$$i204 = Math_fround(0), $$$i213 = Math_fround(0), $$$i8$i$i = Math_fround(0), $$$i8$i$i251 = Math_fround(0), $$0 = 0, $$1058 = 0, $$in1$i = 0, $$in1$i$i = 0, $$in1$i$i260 = 0, $$in2$i = 0, $$in2$i$i = 0, $$in2$i$i262 = 0, $$ph1070 = Math_fround(0), $$ph1071 = 0;
 var $$ph1075 = Math_fround(0), $$ph1076 = Math_fround(0), $$ph1077 = Math_fround(0), $$pre = Math_fround(0), $$pre1119 = Math_fround(0), $$pre1120 = Math_fround(0), $$sroa$1282 = 0, $$sroa$1290 = 0, $$sroa$1356 = 0, $$sroa$1358 = 0, $$sroa$1368 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0);
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0);
 var $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0);
 var $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0);
 var $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0;
 var $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = 0;
 var $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0;
 var $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0);
 var $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = 0;
 var $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0);
 var $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0);
 var $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0;
 var $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = 0;
 var $467 = Math_fround(0), $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = 0, $482 = 0, $483 = 0, $484 = 0;
 var $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = 0, $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0);
 var $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = 0, $506 = 0, $507 = 0, $508 = Math_fround(0), $509 = 0, $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = 0, $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = Math_fround(0);
 var $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = 0, $528 = Math_fround(0), $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0;
 var $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0);
 var $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0;
 var $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $A = 0, $B = 0;
 var $Q = 0, $a$pn3$i$i = 0, $a$pn3$i$i259 = 0, $aInd = 0, $b$a$i$i = 0, $b$a$i$i257 = 0, $b$a$i223 = 0, $b$a5$i$i = 0, $b$a5$i$i261 = 0, $bInd = 0, $brmerge$demorgan = 0, $closA = 0, $closB = 0, $exitcond$i = 0, $exitcond$i143 = 0, $exitcond$i64 = 0, $i$01$i = 0, $i$01$i142 = 0, $i$01$i63 = 0, $i$01098 = 0;
 var $lastA = 0, $lastB = 0, $lastQ = 0, $minDist$sroa$1 = 0, $not$ = 0, $phitmp1066 = 0, $sDist$sroa$1 = 0, $size = 0, $support = 0, $supportA = 0, $supportB = 0, $tempClosA = 0, $tempClosB = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 624|0;
 $0 = sp + 128|0;
 $1 = sp + 432|0;
 $2 = sp + 480|0;
 $3 = sp + 416|0;
 $zeroV = sp + 400|0;
 $closA = sp + 368|0;
 $closB = sp + 384|0;
 $sDist$sroa$1 = sp + 556|0;
 $minDist$sroa$1 = sp + 572|0;
 $tempClosA = sp + 448|0;
 $tempClosB = sp + 464|0;
 $Q = sp + 64|0;
 $A = sp;
 $B = sp + 176|0;
 $aInd = sp + 600|0;
 $bInd = sp + 584|0;
 $supportA = sp + 352|0;
 $supportB = sp + 144|0;
 $support = sp + 160|0;
 $size = sp + 568|0;
 $lastQ = sp + 240|0;
 $lastA = sp + 256|0;
 $lastB = sp + 272|0;
 $4 = sp + 288|0;
 $5 = sp + 304|0;
 $6 = sp + 320|0;
 $$sroa$1368 = sp + 508|0;
 $$sroa$1358 = sp + 544|0;
 $7 = sp + 336|0;
 $$sroa$1356 = sp + 520|0;
 $$sroa$1290 = sp + 532|0;
 $$sroa$1282 = sp + 496|0;
 $8 = Math_fround(HEAPF32[$_contactDist>>2]);
 $9 = (($a) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($b) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($a) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($b) + 32|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = $14 > $16;
 $$$i213 = $17 ? $16 : $14;
 $18 = Math_fround($$$i213 * Math_fround(0.100000001490116119385));
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $19 = Math_fround($10 + $12);
 $20 = Math_fround($8 + $19);
 ;HEAP32[$closA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
 ;HEAP32[$tempClosA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$tempClosB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $21 = Math_fround($18 * $18);
 $22 = Math_fround($20 * $20);
 ;HEAP32[$supportA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$supportB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$supportB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$supportB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$supportB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$support+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$support+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$support+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$support+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAP32[$size>>2] = 0;
 $23 = HEAP8[$_size>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $173 = Math_fround(HEAPF32[$a>>2]);
  $174 = (($a) + 4|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (($a) + 8|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround(HEAPF32[$b>>2]);
  $179 = (($b) + 4|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = (($b) + 8|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = Math_fround($173 - $178);
  $184 = Math_fround($175 - $180);
  $185 = Math_fround($177 - $182);
  $186 = Math_fround($183 * $183);
  $187 = Math_fround($184 * $184);
  $188 = Math_fround($186 + $187);
  $189 = Math_fround($185 * $185);
  $190 = Math_fround($188 + $189);
  $191 = $190 > Math_fround(0.0);
  HEAPF32[$3>>2] = $183;
  $192 = (($3) + 4|0);
  HEAPF32[$192>>2] = $184;
  $193 = (($3) + 8|0);
  HEAPF32[$193>>2] = $185;
  $194 = (($3) + 12|0);
  HEAPF32[$194>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = Math_fround(1.0);
  $195 = (($2) + 4|0);
  HEAPF32[$195>>2] = Math_fround(0.0);
  $196 = (($2) + 8|0);
  HEAPF32[$196>>2] = Math_fround(0.0);
  $197 = (($2) + 12|0);
  HEAPF32[$197>>2] = Math_fround(0.0);
  $b$a$i223 = $191 ? $3 : $2;
  $198 = Math_fround(HEAPF32[$b$a$i223>>2]);
  $$in1$i = (($b$a$i223) + 4|0);
  $199 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i223) + 8|0);
  $200 = Math_fround(HEAPF32[$$in2$i>>2]);
  $$ph1070 = Math_fround(3.40282346638528859812E+38);$$ph1071 = 1;$$ph1075 = $200;$$ph1076 = $199;$$ph1077 = $198;
 } else {
  ;HEAP32[$lastQ+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$zeroV+12>>2]|0;
  ;HEAP32[$lastB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$zeroV+12>>2]|0;
  $25 = (($b) + 144|0);
  $26 = (($b) + 148|0);
  $27 = (($b) + 152|0);
  $28 = (($1) + 4|0);
  $29 = (($1) + 8|0);
  $30 = (($1) + 12|0);
  $31 = (($0) + 4|0);
  $32 = (($0) + 8|0);
  $33 = (($0) + 12|0);
  $34 = (($supportB) + 4|0);
  $35 = (($supportB) + 8|0);
  $36 = (($supportB) + 12|0);
  $37 = (($supportA) + 4|0);
  $38 = (($supportA) + 8|0);
  $39 = (($support) + 4|0);
  $40 = (($support) + 8|0);
  $41 = (($support) + 12|0);
  $$pre = Math_fround(HEAPF32[$25>>2]);
  $$pre1119 = Math_fround(HEAPF32[$26>>2]);
  $$pre1120 = Math_fround(HEAPF32[$27>>2]);
  $76 = 0;$i$01098 = 0;
  while(1) {
   $42 = (($aIndices) + ($i$01098)|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = $43&255;
   $45 = (($aInd) + ($i$01098<<2)|0);
   HEAP32[$45>>2] = $44;
   $46 = (($bIndices) + ($i$01098)|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = $47&255;
   $49 = (($bInd) + ($i$01098<<2)|0);
   HEAP32[$49>>2] = $48;
   $50 = ((($a) + ($44<<4)|0) + 96|0);
   ;HEAP32[$supportA+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$50+12>>2]|0;
   $51 = Math_fround($$pre - $12);
   $52 = Math_fround($$pre1119 - $12);
   $53 = Math_fround($$pre1120 - $12);
   $54 = (549664 + ($48<<4)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ((549664 + ($48<<4)|0) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ((549664 + ($48<<4)|0) + 8|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = Math_fround(-$51);
   $61 = Math_fround(-$52);
   $62 = Math_fround(-$53);
   HEAPF32[$1>>2] = $51;
   HEAPF32[$28>>2] = $52;
   HEAPF32[$29>>2] = $53;
   HEAPF32[$30>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $60;
   HEAPF32[$31>>2] = $61;
   HEAPF32[$32>>2] = $62;
   HEAPF32[$33>>2] = Math_fround(0.0);
   $63 = ($55|0)==(0);
   $b$a$i$i257 = $63 ? $0 : $1;
   $64 = Math_fround(HEAPF32[$b$a$i$i257>>2]);
   $65 = ($57|0)==(0);
   $a$pn3$i$i259 = $65 ? $0 : $1;
   $$in1$i$i260 = (($a$pn3$i$i259) + 4|0);
   $66 = Math_fround(HEAPF32[$$in1$i$i260>>2]);
   $67 = ($59|0)==(0);
   $b$a5$i$i261 = $67 ? $0 : $1;
   $$in2$i$i262 = (($b$a5$i$i261) + 8|0);
   $68 = Math_fround(HEAPF32[$$in2$i$i262>>2]);
   HEAPF32[$supportB>>2] = $64;
   HEAPF32[$34>>2] = $66;
   HEAPF32[$35>>2] = $68;
   HEAPF32[$36>>2] = Math_fround(0.0);
   $69 = Math_fround(HEAPF32[$supportA>>2]);
   $70 = Math_fround(HEAPF32[$37>>2]);
   $71 = Math_fround(HEAPF32[$38>>2]);
   $72 = Math_fround($69 - $64);
   $73 = Math_fround($70 - $66);
   $74 = Math_fround($71 - $68);
   HEAPF32[$support>>2] = $72;
   HEAPF32[$39>>2] = $73;
   HEAPF32[$40>>2] = $74;
   HEAPF32[$41>>2] = Math_fround(0.0);
   $75 = (($A) + ($76<<4)|0);
   ;HEAP32[$lastA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$lastA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$lastA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$lastA+12>>2]=HEAP32[$supportA+12>>2]|0;
   ;HEAP32[$75+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$supportA+12>>2]|0;
   $77 = (($B) + ($76<<4)|0);
   ;HEAP32[$lastB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$lastB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$lastB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$lastB+12>>2]=HEAP32[$supportB+12>>2]|0;
   ;HEAP32[$77+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$supportB+12>>2]|0;
   $78 = (($76) + 1)|0;
   $79 = (($Q) + ($76<<4)|0);
   ;HEAP32[$lastQ+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$lastQ+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$lastQ+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$lastQ+12>>2]=HEAP32[$support+12>>2]|0;
   ;HEAP32[$79+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$support+12>>2]|0;
   $80 = (($i$01098) + 1)|0;
   $81 = $23&255;
   $82 = ($80>>>0)<($81>>>0);
   if ($82) {
    $76 = $78;$i$01098 = $80;
   } else {
    break;
   }
  }
  HEAP32[$size>>2] = $78;
  do {
   if ((($76|0) == 2)) {
    $161 = (($Q) + 16|0);
    __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($4,$Q,$161,$lastQ,$Q,$A,$B,$size,$closA,$closB);
   } else if ((($76|0) == 3)) {
    __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($4,$Q,$A,$B,$aInd,$bInd,$lastQ,$lastA,$lastB,$size,$closA,$closB);
   } else if ((($76|0) == 0)) {
    ;HEAP32[$closA+0>>2]=HEAP32[$lastA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$lastA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$lastA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$lastA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$lastB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$lastB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$lastB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$lastB+12>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   } else if ((($76|0) == 1)) {
    $83 = Math_fround(HEAPF32[$Q>>2]);
    $84 = (($Q) + 4|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = (($Q) + 8|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = Math_fround(HEAPF32[$lastQ>>2]);
    $89 = (($lastQ) + 4|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = (($lastQ) + 8|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = Math_fround($88 - $83);
    $94 = Math_fround($90 - $85);
    $95 = Math_fround($92 - $87);
    $96 = Math_fround($93 * $93);
    $97 = Math_fround($94 * $94);
    $98 = Math_fround($96 + $97);
    $99 = Math_fround($95 * $95);
    $100 = Math_fround($98 + $99);
    $101 = $100 == Math_fround(0.0);
    if ($101) {
     HEAP32[$size>>2] = 1;
     ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
     ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
     ;HEAP32[$4+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$Q+12>>2]|0;
     break;
    } else {
     $102 = Math_fround($85 * $94);
     $103 = Math_fround(-$102);
     $104 = Math_fround($83 * $93);
     $105 = Math_fround($103 - $104);
     $106 = Math_fround($87 * $95);
     $107 = Math_fround($105 - $106);
     $108 = Math_fround(HEAPF32[$lastA>>2]);
     $109 = (($lastA) + 4|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = (($lastA) + 8|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = Math_fround(HEAPF32[$A>>2]);
     $114 = (($A) + 4|0);
     $115 = Math_fround(HEAPF32[$114>>2]);
     $116 = (($A) + 8|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = Math_fround($108 - $113);
     $119 = Math_fround($110 - $115);
     $120 = Math_fround($112 - $117);
     $121 = Math_fround(HEAPF32[$lastB>>2]);
     $122 = (($lastB) + 4|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     $124 = (($lastB) + 8|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     $126 = Math_fround(HEAPF32[$B>>2]);
     $127 = (($B) + 4|0);
     $128 = Math_fround(HEAPF32[$127>>2]);
     $129 = (($B) + 8|0);
     $130 = Math_fround(HEAPF32[$129>>2]);
     $131 = Math_fround($121 - $126);
     $132 = Math_fround($123 - $128);
     $133 = Math_fround($125 - $130);
     $134 = Math_fround($107 / $100);
     $135 = $134 > Math_fround(1.0);
     $$$i$i$i250 = $135 ? Math_fround(1.0) : $134;
     $136 = $$$i$i$i250 > Math_fround(0.0);
     $$$i8$i$i251 = $136 ? $$$i$i$i250 : Math_fround(0.0);
     $137 = Math_fround($118 * $$$i8$i$i251);
     $138 = Math_fround($119 * $$$i8$i$i251);
     $139 = Math_fround($120 * $$$i8$i$i251);
     $140 = Math_fround($113 + $137);
     $141 = Math_fround($115 + $138);
     $142 = Math_fround($117 + $139);
     $143 = Math_fround($131 * $$$i8$i$i251);
     $144 = Math_fround($132 * $$$i8$i$i251);
     $145 = Math_fround($133 * $$$i8$i$i251);
     $146 = Math_fround($126 + $143);
     $147 = Math_fround($128 + $144);
     $148 = Math_fround($130 + $145);
     HEAPF32[$closA>>2] = $140;
     $149 = (($closA) + 4|0);
     HEAPF32[$149>>2] = $141;
     $150 = (($closA) + 8|0);
     HEAPF32[$150>>2] = $142;
     $151 = (($closA) + 12|0);
     HEAPF32[$151>>2] = Math_fround(0.0);
     HEAPF32[$closB>>2] = $146;
     $152 = (($closB) + 4|0);
     HEAPF32[$152>>2] = $147;
     $153 = (($closB) + 8|0);
     HEAPF32[$153>>2] = $148;
     $154 = (($closB) + 12|0);
     HEAPF32[$154>>2] = Math_fround(0.0);
     $155 = Math_fround($140 - $146);
     $156 = Math_fround($141 - $147);
     $157 = Math_fround($142 - $148);
     HEAPF32[$4>>2] = $155;
     $158 = (($4) + 4|0);
     HEAPF32[$158>>2] = $156;
     $159 = (($4) + 8|0);
     HEAPF32[$159>>2] = $157;
     $160 = (($4) + 12|0);
     HEAPF32[$160>>2] = Math_fround(0.0);
     break;
    }
   } else {
    ;HEAP32[$4+0>>2]=HEAP32[$lastQ+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lastQ+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lastQ+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$lastQ+12>>2]|0;
   }
  } while(0);
  $162 = Math_fround(HEAPF32[$4>>2]);
  $163 = (($4) + 4|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = (($4) + 8|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = Math_fround($162 * $162);
  $168 = Math_fround($164 * $164);
  $169 = Math_fround($167 + $168);
  $170 = Math_fround($166 * $166);
  $171 = Math_fround($169 + $170);
  ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
  $172 = $171 > $21;
  $$ph1070 = $171;$$ph1071 = $172;$$ph1075 = $166;$$ph1076 = $164;$$ph1077 = $162;
 }
 do {
  if ($$ph1071) {
   $202 = (($6) + 4|0);
   $203 = (($6) + 8|0);
   $204 = (($6) + 12|0);
   $205 = (($b) + 144|0);
   $206 = (($b) + 148|0);
   $207 = (($b) + 152|0);
   $208 = (($1) + 4|0);
   $209 = (($1) + 8|0);
   $210 = (($1) + 12|0);
   $211 = (($0) + 4|0);
   $212 = (($0) + 8|0);
   $213 = (($0) + 12|0);
   $214 = (($supportB) + 4|0);
   $215 = (($supportB) + 8|0);
   $216 = (($supportB) + 12|0);
   $217 = (($supportA) + 4|0);
   $218 = (($supportA) + 8|0);
   $219 = (($support) + 4|0);
   $220 = (($support) + 8|0);
   $221 = (($support) + 12|0);
   $222 = (($a) + 48|0);
   $223 = (($b) + 48|0);
   $224 = (($7) + 4|0);
   $225 = (($7) + 8|0);
   $226 = (($Q) + 4|0);
   $227 = (($Q) + 8|0);
   $228 = (($A) + 4|0);
   $229 = (($A) + 8|0);
   $230 = (($B) + 4|0);
   $231 = (($B) + 8|0);
   $232 = (($closA) + 4|0);
   $233 = (($closA) + 8|0);
   $234 = (($closA) + 12|0);
   $235 = (($closB) + 4|0);
   $236 = (($closB) + 8|0);
   $237 = (($closB) + 12|0);
   $238 = (($7) + 12|0);
   $239 = (($Q) + 16|0);
   $$$i10491096 = $8;$241 = $$ph1077;$243 = $$ph1076;$245 = $$ph1075;$295 = $$ph1070;
   while(1) {
    ;HEAP32[$minDist$sroa$1+0>>2]=HEAP32[$sDist$sroa$1+0>>2]|0;HEAP32[$minDist$sroa$1+4>>2]=HEAP32[$sDist$sroa$1+4>>2]|0;HEAP32[$minDist$sroa$1+8>>2]=HEAP32[$sDist$sroa$1+8>>2]|0;
    ;HEAP32[$tempClosA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$tempClosA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$tempClosA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$tempClosA+12>>2]=HEAP32[$closA+12>>2]|0;
    ;HEAP32[$tempClosB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$tempClosB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$tempClosB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$tempClosB+12>>2]=HEAP32[$closB+12>>2]|0;
    $240 = Math_fround(-$241);
    $242 = Math_fround(-$243);
    $244 = Math_fround(-$245);
    HEAPF32[$6>>2] = $240;
    HEAPF32[$202>>2] = $242;
    HEAPF32[$203>>2] = $244;
    HEAPF32[$204>>2] = Math_fround(0.0);
    $246 = HEAP32[$size>>2]|0;
    $247 = (($A) + ($246<<4)|0);
    $248 = (($aInd) + ($246<<2)|0);
    __ZNK5physx2Gu9TriangleV12supportLocalERKNS_6shdfnd3aos5Vec3VERi($5,$a,$6,$248);
    ;HEAP32[$247+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$247+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$247+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$247+12>>2]=HEAP32[$5+12>>2]|0;
    ;HEAP32[$supportA+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$supportA+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$supportA+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$supportA+12>>2]=HEAP32[$5+12>>2]|0;
    $249 = HEAP32[$size>>2]|0;
    $250 = (($bInd) + ($249<<2)|0);
    $251 = Math_fround(HEAPF32[$205>>2]);
    $252 = Math_fround(HEAPF32[$206>>2]);
    $253 = Math_fround(HEAPF32[$207>>2]);
    $254 = Math_fround(HEAPF32[$11>>2]);
    $255 = Math_fround($251 - $254);
    $256 = Math_fround($252 - $254);
    $257 = Math_fround($253 - $254);
    $258 = $241 > Math_fround(0.0);
    $259 = $243 > Math_fround(0.0);
    $260 = $259 << 31 >> 31;
    $261 = $245 > Math_fround(0.0);
    $262 = $261 << 31 >> 31;
    $263 = $258&1;
    $264 = $260 << 1;
    $265 = $264 & 2;
    $266 = $262 << 2;
    $267 = $266 & 4;
    $268 = $267 | $263;
    $269 = $268 | $265;
    HEAP32[$250>>2] = $269;
    $270 = Math_fround(-$255);
    $271 = Math_fround(-$256);
    $272 = Math_fround(-$257);
    HEAPF32[$1>>2] = $255;
    HEAPF32[$208>>2] = $256;
    HEAPF32[$209>>2] = $257;
    HEAPF32[$210>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $270;
    HEAPF32[$211>>2] = $271;
    HEAPF32[$212>>2] = $272;
    HEAPF32[$213>>2] = Math_fround(0.0);
    $b$a$i$i = $258 ? $1 : $0;
    $273 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $259 ? $1 : $0;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $274 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $261 ? $1 : $0;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $275 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    $276 = (($B) + ($249<<4)|0);
    HEAPF32[$276>>2] = $273;
    $277 = ((($B) + ($249<<4)|0) + 4|0);
    HEAPF32[$277>>2] = $274;
    $278 = ((($B) + ($249<<4)|0) + 8|0);
    HEAPF32[$278>>2] = $275;
    $279 = ((($B) + ($249<<4)|0) + 12|0);
    HEAPF32[$279>>2] = Math_fround(0.0);
    HEAPF32[$supportB>>2] = $273;
    HEAPF32[$214>>2] = $274;
    HEAPF32[$215>>2] = $275;
    HEAPF32[$216>>2] = Math_fround(0.0);
    $280 = Math_fround(HEAPF32[$supportA>>2]);
    $281 = Math_fround(HEAPF32[$217>>2]);
    $282 = Math_fround(HEAPF32[$218>>2]);
    $283 = Math_fround($280 - $273);
    $284 = Math_fround($281 - $274);
    $285 = Math_fround($282 - $275);
    HEAPF32[$support>>2] = $283;
    HEAPF32[$219>>2] = $284;
    HEAPF32[$220>>2] = $285;
    HEAPF32[$221>>2] = Math_fround(0.0);
    $286 = (($249) + 1)|0;
    HEAP32[$size>>2] = $286;
    $287 = (($Q) + ($249<<4)|0);
    ;HEAP32[$287+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$287+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$287+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$287+12>>2]=HEAP32[$support+12>>2]|0;
    $288 = Math_fround(HEAPF32[$222>>2]);
    $289 = Math_fround(HEAPF32[$223>>2]);
    $290 = $288 > $289;
    $$$i204 = $290 ? $288 : $289;
    $291 = $$$i10491096 > $$$i204;
    $$$i = $291 ? $$$i10491096 : $$$i204;
    $292 = Math_fround($19 + $$$i);
    $293 = Math_fround($292 * $292);
    $294 = Math_fround($295 * $293);
    $296 = Math_fround($241 * $283);
    $297 = Math_fround($243 * $284);
    $298 = Math_fround($296 + $297);
    $299 = Math_fround($245 * $285);
    $300 = Math_fround($298 + $299);
    $301 = Math_fround($300 * $300);
    $302 = $300 > Math_fround(0.0);
    $303 = $301 > $294;
    if ($302) {
     $phitmp1066 = $303 ^ 1;
     $307 = $303;$309 = $phitmp1066;
    } else {
     $307 = 0;$309 = 1;
    }
    $304 = Math_fround($295 - $300);
    $305 = Math_fround($21 * $295);
    $306 = $305 >= $304;
    $brmerge$demorgan = $306 | $307;
    if ($brmerge$demorgan) {
     $308 = $309 ^ 1;
     $$1058 = $306 | $308;
     if ($$1058) {
      break;
     }
    }
    do {
     if ((($249|0) == 3)) {
      __ZN5physx2Gu25closestPtPointTetrahedronEPNS_6shdfnd3aos5Vec3VES4_S4_PiS5_RKS3_S7_S7_RjRS3_S9_($7,$Q,$A,$B,$aInd,$bInd,$support,$supportA,$supportB,$size,$closA,$closB);
     } else if ((($249|0) == 1)) {
      $391 = Math_fround(HEAPF32[$Q>>2]);
      $392 = Math_fround(HEAPF32[$226>>2]);
      $393 = Math_fround(HEAPF32[$227>>2]);
      $394 = Math_fround($283 - $391);
      $395 = Math_fround($284 - $392);
      $396 = Math_fround($285 - $393);
      $397 = Math_fround($394 * $394);
      $398 = Math_fround($395 * $395);
      $399 = Math_fround($397 + $398);
      $400 = Math_fround($396 * $396);
      $401 = Math_fround($399 + $400);
      $402 = $401 == Math_fround(0.0);
      if ($402) {
       HEAP32[$size>>2] = 1;
       ;HEAP32[$closA+0>>2]=HEAP32[$A+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$A+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$A+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$A+12>>2]|0;
       ;HEAP32[$closB+0>>2]=HEAP32[$B+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$B+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$B+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$B+12>>2]|0;
       ;HEAP32[$7+0>>2]=HEAP32[$Q+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$Q+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$Q+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$Q+12>>2]|0;
       break;
      } else {
       $403 = Math_fround($392 * $395);
       $404 = Math_fround(-$403);
       $405 = Math_fround($391 * $394);
       $406 = Math_fround($404 - $405);
       $407 = Math_fround($393 * $396);
       $408 = Math_fround($406 - $407);
       $409 = Math_fround(HEAPF32[$A>>2]);
       $410 = Math_fround(HEAPF32[$228>>2]);
       $411 = Math_fround(HEAPF32[$229>>2]);
       $412 = Math_fround($280 - $409);
       $413 = Math_fround($281 - $410);
       $414 = Math_fround($282 - $411);
       $415 = Math_fround(HEAPF32[$B>>2]);
       $416 = Math_fround(HEAPF32[$230>>2]);
       $417 = Math_fround(HEAPF32[$231>>2]);
       $418 = Math_fround($273 - $415);
       $419 = Math_fround($274 - $416);
       $420 = Math_fround($275 - $417);
       $421 = Math_fround($408 / $401);
       $422 = $421 > Math_fround(1.0);
       $$$i$i$i = $422 ? Math_fround(1.0) : $421;
       $423 = $$$i$i$i > Math_fround(0.0);
       $$$i8$i$i = $423 ? $$$i$i$i : Math_fround(0.0);
       $424 = Math_fround($412 * $$$i8$i$i);
       $425 = Math_fround($413 * $$$i8$i$i);
       $426 = Math_fround($414 * $$$i8$i$i);
       $427 = Math_fround($409 + $424);
       $428 = Math_fround($410 + $425);
       $429 = Math_fround($411 + $426);
       $430 = Math_fround($418 * $$$i8$i$i);
       $431 = Math_fround($419 * $$$i8$i$i);
       $432 = Math_fround($420 * $$$i8$i$i);
       $433 = Math_fround($415 + $430);
       $434 = Math_fround($416 + $431);
       $435 = Math_fround($417 + $432);
       HEAPF32[$closA>>2] = $427;
       HEAPF32[$232>>2] = $428;
       HEAPF32[$233>>2] = $429;
       HEAPF32[$234>>2] = Math_fround(0.0);
       HEAPF32[$closB>>2] = $433;
       HEAPF32[$235>>2] = $434;
       HEAPF32[$236>>2] = $435;
       HEAPF32[$237>>2] = Math_fround(0.0);
       $436 = Math_fround($427 - $433);
       $437 = Math_fround($428 - $434);
       $438 = Math_fround($429 - $435);
       HEAPF32[$7>>2] = $436;
       HEAPF32[$224>>2] = $437;
       HEAPF32[$225>>2] = $438;
       HEAPF32[$238>>2] = Math_fround(0.0);
       break;
      }
     } else if ((($249|0) == 0)) {
      ;HEAP32[$closA+0>>2]=HEAP32[$supportA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$supportA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$supportA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$supportA+12>>2]|0;
      ;HEAP32[$closB+0>>2]=HEAP32[$supportB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$supportB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$supportB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$supportB+12>>2]|0;
      ;HEAP32[$7+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$support+12>>2]|0;
     } else if ((($249|0) == 2)) {
      __ZN5physx2Gu22closestPtPointTriangleERKNS_6shdfnd3aos5Vec3VES5_S5_PS3_S6_S6_RjRS3_S8_($7,$Q,$239,$support,$Q,$A,$B,$size,$closA,$closB);
     } else {
      ;HEAP32[$7+0>>2]=HEAP32[$support+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$support+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$support+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$support+12>>2]|0;
     }
    } while(0);
    $439 = Math_fround(HEAPF32[$7>>2]);
    $440 = Math_fround(HEAPF32[$224>>2]);
    $441 = Math_fround(HEAPF32[$225>>2]);
    $442 = Math_fround($439 * $439);
    $443 = Math_fround($440 * $440);
    $444 = Math_fround($442 + $443);
    $445 = Math_fround($441 * $441);
    $446 = Math_fround($444 + $445);
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$$sroa$1356+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$$sroa$1356+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$$sroa$1356+8>>2]|0;
    $447 = $295 > $446;
    $448 = $446 > $21;
    if (!($448)) {
     label = 38;
     break;
    }
    if ($447) {
     $$$i10491096 = $$$i;$241 = $439;$243 = $440;$245 = $441;$295 = $446;
    } else {
     label = 38;
     break;
    }
   }
   if ((label|0) == 38) {
    $449 = HEAP32[$size>>2]|0;
    if ($447) {
     $536 = $449;
     break;
    }
    $450 = (($449) + -1)|0;
    $451 = ($aIndices|0)==(0|0);
    if (!($451)) {
     $452 = $450&255;
     HEAP8[$_size>>0] = $452;
     $453 = ($450|0)==(0);
     if (!($453)) {
      $i$01$i63 = 0;
      while(1) {
       $454 = (($aInd) + ($i$01$i63<<2)|0);
       $455 = HEAP32[$454>>2]|0;
       $456 = $455&255;
       $457 = (($aIndices) + ($i$01$i63)|0);
       HEAP8[$457>>0] = $456;
       $458 = (($bInd) + ($i$01$i63<<2)|0);
       $459 = HEAP32[$458>>2]|0;
       $460 = $459&255;
       $461 = (($bIndices) + ($i$01$i63)|0);
       HEAP8[$461>>0] = $460;
       $462 = (($i$01$i63) + 1)|0;
       $exitcond$i64 = ($462|0)==($450|0);
       if ($exitcond$i64) {
        break;
       } else {
        $i$01$i63 = $462;
       }
      }
     }
    }
    ;HEAP32[$closA+0>>2]=HEAP32[$tempClosA+0>>2]|0;HEAP32[$closA+4>>2]=HEAP32[$tempClosA+4>>2]|0;HEAP32[$closA+8>>2]=HEAP32[$tempClosA+8>>2]|0;HEAP32[$closA+12>>2]=HEAP32[$tempClosA+12>>2]|0;
    ;HEAP32[$closB+0>>2]=HEAP32[$tempClosB+0>>2]|0;HEAP32[$closB+4>>2]=HEAP32[$tempClosB+4>>2]|0;HEAP32[$closB+8>>2]=HEAP32[$tempClosB+8>>2]|0;HEAP32[$closB+12>>2]=HEAP32[$tempClosB+12>>2]|0;
    ;HEAP32[$sDist$sroa$1+0>>2]=HEAP32[$minDist$sroa$1+0>>2]|0;HEAP32[$sDist$sroa$1+4>>2]=HEAP32[$minDist$sroa$1+4>>2]|0;HEAP32[$sDist$sroa$1+8>>2]=HEAP32[$minDist$sroa$1+8>>2]|0;
    $463 = Math_fround(HEAPF32[$closA>>2]);
    $464 = (($closA) + 4|0);
    $465 = Math_fround(HEAPF32[$464>>2]);
    $466 = (($closA) + 8|0);
    $467 = Math_fround(HEAPF32[$466>>2]);
    $468 = Math_fround(HEAPF32[$closB>>2]);
    $469 = (($closB) + 4|0);
    $470 = Math_fround(HEAPF32[$469>>2]);
    $471 = (($closB) + 8|0);
    $472 = Math_fround(HEAPF32[$471>>2]);
    $473 = Math_fround($463 - $468);
    $474 = Math_fround($465 - $470);
    $475 = Math_fround($467 - $472);
    $476 = (Math_fround(Math_sqrt((Math_fround($295)))));
    $477 = Math_fround(Math_fround(1.0) / $476);
    $478 = Math_fround($473 * $477);
    $479 = Math_fround($474 * $477);
    $480 = Math_fround($475 * $477);
    if ($takeCoreShape) {
     $481 = (($a) + 64|0);
     $482 = HEAP32[$481>>2]|0;
     $483 = (($b) + 64|0);
     $484 = HEAP32[$483>>2]|0;
     $485 = ($482|0)==(0);
     $486 = $485 ? $10 : Math_fround(0.0);
     $487 = ($484|0)==(0);
     $488 = $487 ? $12 : Math_fround(0.0);
     $489 = Math_fround($486 + $488);
     $490 = Math_fround($478 * $486);
     $491 = Math_fround($479 * $486);
     $492 = Math_fround($480 * $486);
     $493 = Math_fround($463 - $490);
     $494 = Math_fround($465 - $491);
     $495 = Math_fround($467 - $492);
     HEAPF32[$contactA>>2] = $493;
     $496 = (($contactA) + 4|0);
     HEAPF32[$496>>2] = $494;
     $497 = (($contactA) + 8|0);
     HEAPF32[$497>>2] = $495;
     $498 = (($contactA) + 12|0);
     HEAPF32[$498>>2] = Math_fround(0.0);
     $499 = Math_fround($478 * $488);
     $500 = Math_fround($479 * $488);
     $501 = Math_fround($480 * $488);
     $502 = Math_fround($499 + $468);
     $503 = Math_fround($500 + $470);
     $504 = Math_fround($501 + $472);
     HEAPF32[$contactB>>2] = $502;
     $505 = (($contactB) + 4|0);
     HEAPF32[$505>>2] = $503;
     $506 = (($contactB) + 8|0);
     HEAPF32[$506>>2] = $504;
     $507 = (($contactB) + 12|0);
     HEAPF32[$507>>2] = Math_fround(0.0);
     $508 = Math_fround($476 - $489);
     HEAPF32[$penetrationDepth>>2] = $508;
     $509 = (($penetrationDepth) + 4|0);
     ;HEAP32[$509+0>>2]=HEAP32[$$sroa$1290+0>>2]|0;HEAP32[$509+4>>2]=HEAP32[$$sroa$1290+4>>2]|0;HEAP32[$509+8>>2]=HEAP32[$$sroa$1290+8>>2]|0;
    } else {
     $510 = Math_fround($10 * $478);
     $511 = Math_fround($10 * $479);
     $512 = Math_fround($10 * $480);
     $513 = Math_fround($463 - $510);
     $514 = Math_fround($465 - $511);
     $515 = Math_fround($467 - $512);
     HEAPF32[$contactA>>2] = $513;
     $516 = (($contactA) + 4|0);
     HEAPF32[$516>>2] = $514;
     $517 = (($contactA) + 8|0);
     HEAPF32[$517>>2] = $515;
     $518 = (($contactA) + 12|0);
     HEAPF32[$518>>2] = Math_fround(0.0);
     $519 = Math_fround($12 * $478);
     $520 = Math_fround($12 * $479);
     $521 = Math_fround($12 * $480);
     $522 = Math_fround($519 + $468);
     $523 = Math_fround($520 + $470);
     $524 = Math_fround($521 + $472);
     HEAPF32[$contactB>>2] = $522;
     $525 = (($contactB) + 4|0);
     HEAPF32[$525>>2] = $523;
     $526 = (($contactB) + 8|0);
     HEAPF32[$526>>2] = $524;
     $527 = (($contactB) + 12|0);
     HEAPF32[$527>>2] = Math_fround(0.0);
     $528 = Math_fround($476 - $19);
     HEAPF32[$penetrationDepth>>2] = $528;
     $529 = (($penetrationDepth) + 4|0);
     ;HEAP32[$529+0>>2]=HEAP32[$$sroa$1282+0>>2]|0;HEAP32[$529+4>>2]=HEAP32[$$sroa$1282+4>>2]|0;HEAP32[$529+8>>2]=HEAP32[$$sroa$1282+8>>2]|0;
    }
    HEAPF32[$normal>>2] = $478;
    $530 = (($normal) + 4|0);
    HEAPF32[$530>>2] = $479;
    $531 = (($normal) + 8|0);
    HEAPF32[$531>>2] = $480;
    $532 = (($normal) + 12|0);
    HEAPF32[$532>>2] = Math_fround(0.0);
    $533 = $22 >= $295;
    $$ = $533 ? 1 : 3;
    $$0 = $$;
    STACKTOP = sp;return ($$0|0);
   }
   $310 = ($aIndices|0)==(0|0);
   if (!($310)) {
    $311 = $249&255;
    HEAP8[$_size>>0] = $311;
    $312 = ($249|0)==(0);
    if (!($312)) {
     $i$01$i142 = 0;
     while(1) {
      $313 = (($aInd) + ($i$01$i142<<2)|0);
      $314 = HEAP32[$313>>2]|0;
      $315 = $314&255;
      $316 = (($aIndices) + ($i$01$i142)|0);
      HEAP8[$316>>0] = $315;
      $317 = (($bInd) + ($i$01$i142<<2)|0);
      $318 = HEAP32[$317>>2]|0;
      $319 = $318&255;
      $320 = (($bIndices) + ($i$01$i142)|0);
      HEAP8[$320>>0] = $319;
      $321 = (($i$01$i142) + 1)|0;
      $exitcond$i143 = ($321|0)==($249|0);
      if ($exitcond$i143) {
       break;
      } else {
       $i$01$i142 = $321;
      }
     }
    }
   }
   $not$ = $307 ^ 1;
   $$$1062 = $309 & $not$;
   if (!($$$1062)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $322 = (Math_fround(Math_sqrt((Math_fround($295)))));
   $323 = Math_fround(Math_fround(1.0) / $322);
   $324 = Math_fround($241 * $323);
   $325 = Math_fround($243 * $323);
   $326 = Math_fround($245 * $323);
   HEAPF32[$normal>>2] = $324;
   $327 = (($normal) + 4|0);
   HEAPF32[$327>>2] = $325;
   $328 = (($normal) + 8|0);
   HEAPF32[$328>>2] = $326;
   $329 = (($normal) + 12|0);
   HEAPF32[$329>>2] = Math_fround(0.0);
   if ($takeCoreShape) {
    $330 = (($a) + 64|0);
    $331 = HEAP32[$330>>2]|0;
    $332 = (($b) + 64|0);
    $333 = HEAP32[$332>>2]|0;
    $334 = ($331|0)==(0);
    $335 = $334 ? $10 : Math_fround(0.0);
    $336 = ($333|0)==(0);
    $337 = $336 ? $12 : Math_fround(0.0);
    $338 = Math_fround($335 + $337);
    $339 = Math_fround(HEAPF32[$closA>>2]);
    $340 = Math_fround(HEAPF32[$232>>2]);
    $341 = Math_fround(HEAPF32[$233>>2]);
    $342 = Math_fround($324 * $335);
    $343 = Math_fround($325 * $335);
    $344 = Math_fround($326 * $335);
    $345 = Math_fround($339 - $342);
    $346 = Math_fround($340 - $343);
    $347 = Math_fround($341 - $344);
    HEAPF32[$contactA>>2] = $345;
    $348 = (($contactA) + 4|0);
    HEAPF32[$348>>2] = $346;
    $349 = (($contactA) + 8|0);
    HEAPF32[$349>>2] = $347;
    $350 = (($contactA) + 12|0);
    HEAPF32[$350>>2] = Math_fround(0.0);
    $351 = Math_fround(HEAPF32[$closB>>2]);
    $352 = Math_fround(HEAPF32[$235>>2]);
    $353 = Math_fround(HEAPF32[$236>>2]);
    $354 = Math_fround($324 * $337);
    $355 = Math_fround($325 * $337);
    $356 = Math_fround($326 * $337);
    $357 = Math_fround($354 + $351);
    $358 = Math_fround($355 + $352);
    $359 = Math_fround($356 + $353);
    HEAPF32[$contactB>>2] = $357;
    $360 = (($contactB) + 4|0);
    HEAPF32[$360>>2] = $358;
    $361 = (($contactB) + 8|0);
    HEAPF32[$361>>2] = $359;
    $362 = (($contactB) + 12|0);
    HEAPF32[$362>>2] = Math_fround(0.0);
    $363 = Math_fround($322 - $338);
    HEAPF32[$penetrationDepth>>2] = $363;
    $364 = (($penetrationDepth) + 4|0);
    ;HEAP32[$364+0>>2]=HEAP32[$$sroa$1368+0>>2]|0;HEAP32[$364+4>>2]=HEAP32[$$sroa$1368+4>>2]|0;HEAP32[$364+8>>2]=HEAP32[$$sroa$1368+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $365 = Math_fround(HEAPF32[$closA>>2]);
    $366 = Math_fround(HEAPF32[$232>>2]);
    $367 = Math_fround(HEAPF32[$233>>2]);
    $368 = Math_fround($10 * $324);
    $369 = Math_fround($10 * $325);
    $370 = Math_fround($10 * $326);
    $371 = Math_fround($365 - $368);
    $372 = Math_fround($366 - $369);
    $373 = Math_fround($367 - $370);
    HEAPF32[$contactA>>2] = $371;
    $374 = (($contactA) + 4|0);
    HEAPF32[$374>>2] = $372;
    $375 = (($contactA) + 8|0);
    HEAPF32[$375>>2] = $373;
    $376 = (($contactA) + 12|0);
    HEAPF32[$376>>2] = Math_fround(0.0);
    $377 = Math_fround(HEAPF32[$closB>>2]);
    $378 = Math_fround(HEAPF32[$235>>2]);
    $379 = Math_fround(HEAPF32[$236>>2]);
    $380 = Math_fround($12 * $324);
    $381 = Math_fround($12 * $325);
    $382 = Math_fround($12 * $326);
    $383 = Math_fround($380 + $377);
    $384 = Math_fround($381 + $378);
    $385 = Math_fround($382 + $379);
    HEAPF32[$contactB>>2] = $383;
    $386 = (($contactB) + 4|0);
    HEAPF32[$386>>2] = $384;
    $387 = (($contactB) + 8|0);
    HEAPF32[$387>>2] = $385;
    $388 = (($contactB) + 12|0);
    HEAPF32[$388>>2] = Math_fround(0.0);
    $389 = Math_fround($322 - $19);
    HEAPF32[$penetrationDepth>>2] = $389;
    $390 = (($penetrationDepth) + 4|0);
    ;HEAP32[$390+0>>2]=HEAP32[$$sroa$1358+0>>2]|0;HEAP32[$390+4>>2]=HEAP32[$$sroa$1358+4>>2]|0;HEAP32[$390+8>>2]=HEAP32[$$sroa$1358+8>>2]|0;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $201 = HEAP32[$size>>2]|0;
   $536 = $201;
  }
 } while(0);
 $534 = ($aIndices|0)==(0|0);
 if (!($534)) {
  $535 = $536&255;
  HEAP8[$_size>>0] = $535;
  $537 = ($536|0)==(0);
  if (!($537)) {
   $i$01$i = 0;
   while(1) {
    $538 = (($aInd) + ($i$01$i<<2)|0);
    $539 = HEAP32[$538>>2]|0;
    $540 = $539&255;
    $541 = (($aIndices) + ($i$01$i)|0);
    HEAP8[$541>>0] = $540;
    $542 = (($bInd) + ($i$01$i<<2)|0);
    $543 = HEAP32[$542>>2]|0;
    $544 = $543&255;
    $545 = (($bIndices) + ($i$01$i)|0);
    HEAP8[$545>>0] = $544;
    $546 = (($i$01$i) + 1)|0;
    $exitcond$i = ($546|0)==($536|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $546;
    }
   }
  }
 }
 ;HEAP32[$contactA+0>>2]=HEAP32[$closA+0>>2]|0;HEAP32[$contactA+4>>2]=HEAP32[$closA+4>>2]|0;HEAP32[$contactA+8>>2]=HEAP32[$closA+8>>2]|0;HEAP32[$contactA+12>>2]=HEAP32[$closA+12>>2]|0;
 ;HEAP32[$contactB+0>>2]=HEAP32[$closB+0>>2]|0;HEAP32[$contactB+4>>2]=HEAP32[$closB+4>>2]|0;HEAP32[$contactB+8>>2]=HEAP32[$closB+8>>2]|0;HEAP32[$contactB+12>>2]=HEAP32[$closB+12>>2]|0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEE18doWarmStartSupportEiRNS_6shdfnd3aos5Vec3VE($this,$index,$point) {
 $this = $this|0;
 $index = $index|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 200|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + (($index*12)|0)|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = ((($3) + (($index*12)|0)|0) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($3) + (($index*12)|0)|0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($1) + 96|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($5 * $11);
 $13 = (($1) + 112|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($7 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($1) + 128|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($9 * $18);
 $20 = Math_fround($16 + $19);
 $21 = (($1) + 100|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($5 * $22);
 $24 = (($1) + 116|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($7 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($1) + 132|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($9 * $29);
 $31 = Math_fround($27 + $30);
 $32 = (($1) + 104|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($5 * $33);
 $35 = (($1) + 120|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($7 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($1) + 136|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($9 * $40);
 $42 = Math_fround($38 + $41);
 HEAPF32[$point>>2] = $20;
 $43 = (($point) + 4|0);
 HEAPF32[$43>>2] = $31;
 $44 = (($point) + 8|0);
 HEAPF32[$44>>2] = $42;
 $45 = (($point) + 12|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($agg$result,$1,$dir);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEE14doSupportSweepERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($agg$result,$1,$dir);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEE18doWarmStartSupportEiRNS_6shdfnd3aos5Vec3VE($this,$index,$point) {
 $this = $this|0;
 $index = $index|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 200|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + (($index*12)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($5) + (($index*12)|0)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($5) + (($index*12)|0)|0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($3) + 96|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($7 * $13);
 $15 = (($3) + 112|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($9 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($3) + 128|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($11 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($3) + 100|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($7 * $24);
 $26 = (($3) + 116|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($9 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($3) + 132|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($11 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($3) + 104|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($7 * $35);
 $37 = (($3) + 120|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($9 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($3) + 136|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($11 * $42);
 $44 = Math_fround($40 + $43);
 $45 = (($1) + 48|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($1) + 52|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($1) + 56|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround(HEAPF32[$1>>2]);
 $52 = Math_fround($22 * $51);
 $53 = (($1) + 16|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($33 * $54);
 $56 = Math_fround($52 + $55);
 $57 = (($1) + 32|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($44 * $58);
 $60 = Math_fround($56 + $59);
 $61 = (($1) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($22 * $62);
 $64 = (($1) + 20|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($33 * $65);
 $67 = Math_fround($63 + $66);
 $68 = (($1) + 36|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($44 * $69);
 $71 = Math_fround($67 + $70);
 $72 = (($1) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($22 * $73);
 $75 = (($1) + 24|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($33 * $76);
 $78 = Math_fround($74 + $77);
 $79 = (($1) + 40|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($44 * $80);
 $82 = Math_fround($78 + $81);
 $83 = Math_fround($46 + $60);
 $84 = Math_fround($48 + $71);
 $85 = Math_fround($50 + $82);
 HEAPF32[$point>>2] = $83;
 $86 = (($point) + 4|0);
 HEAPF32[$86>>2] = $84;
 $87 = (($point) + 8|0);
 HEAPF32[$87>>2] = $85;
 $88 = (($point) + 12|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $9 = Math_fround(0), $_dir$i = 0, $maxPoint$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_dir$i = sp + 16|0;
 $maxPoint$i = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$3>>2]);
 $10 = Math_fround($4 * $9);
 $11 = (($3) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($6 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($3) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($8 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($3) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($4 * $20);
 $22 = (($3) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($6 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($3) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($8 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($3) + 32|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($4 * $31);
 $33 = (($3) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($6 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($3) + 40|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($8 * $38);
 $40 = Math_fround($36 + $39);
 HEAPF32[$_dir$i>>2] = $18;
 $41 = (($_dir$i) + 4|0);
 HEAPF32[$41>>2] = $29;
 $42 = (($_dir$i) + 8|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($_dir$i) + 12|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($maxPoint$i,$1,$_dir$i);
 $44 = (($3) + 48|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($3) + 52|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($3) + 56|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround(HEAPF32[$maxPoint$i>>2]);
 $51 = (($maxPoint$i) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($maxPoint$i) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround(HEAPF32[$3>>2]);
 $56 = Math_fround($50 * $55);
 $57 = Math_fround(HEAPF32[$19>>2]);
 $58 = Math_fround($52 * $57);
 $59 = Math_fround($56 + $58);
 $60 = Math_fround(HEAPF32[$30>>2]);
 $61 = Math_fround($54 * $60);
 $62 = Math_fround($59 + $61);
 $63 = Math_fround(HEAPF32[$11>>2]);
 $64 = Math_fround($50 * $63);
 $65 = Math_fround(HEAPF32[$22>>2]);
 $66 = Math_fround($52 * $65);
 $67 = Math_fround($64 + $66);
 $68 = Math_fround(HEAPF32[$33>>2]);
 $69 = Math_fround($54 * $68);
 $70 = Math_fround($67 + $69);
 $71 = Math_fround(HEAPF32[$15>>2]);
 $72 = Math_fround($50 * $71);
 $73 = Math_fround(HEAPF32[$26>>2]);
 $74 = Math_fround($52 * $73);
 $75 = Math_fround($72 + $74);
 $76 = Math_fround(HEAPF32[$37>>2]);
 $77 = Math_fround($54 * $76);
 $78 = Math_fround($75 + $77);
 $79 = Math_fround($45 + $62);
 $80 = Math_fround($47 + $70);
 $81 = Math_fround($49 + $78);
 HEAPF32[$agg$result>>2] = $79;
 $82 = (($agg$result) + 4|0);
 HEAPF32[$82>>2] = $80;
 $83 = (($agg$result) + 8|0);
 HEAPF32[$83>>2] = $81;
 $84 = (($agg$result) + 12|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEE14doSupportSweepERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $9 = Math_fround(0), $_dir$i$i = 0, $maxPoint$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_dir$i$i = sp + 16|0;
 $maxPoint$i$i = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$dir>>2]);
 $5 = (($dir) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($dir) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$3>>2]);
 $10 = Math_fround($4 * $9);
 $11 = (($3) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($6 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($3) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($8 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($3) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($4 * $20);
 $22 = (($3) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($6 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($3) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($8 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($3) + 32|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($4 * $31);
 $33 = (($3) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($6 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($3) + 40|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($8 * $38);
 $40 = Math_fround($36 + $39);
 HEAPF32[$_dir$i$i>>2] = $18;
 $41 = (($_dir$i$i) + 4|0);
 HEAPF32[$41>>2] = $29;
 $42 = (($_dir$i$i) + 8|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($_dir$i$i) + 12|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 __ZNK5physx2Gu11ConvexHullV12supportLocalERKNS_6shdfnd3aos5Vec3VE($maxPoint$i$i,$1,$_dir$i$i);
 $44 = (($3) + 48|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($3) + 52|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($3) + 56|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround(HEAPF32[$maxPoint$i$i>>2]);
 $51 = (($maxPoint$i$i) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($maxPoint$i$i) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround(HEAPF32[$3>>2]);
 $56 = Math_fround($50 * $55);
 $57 = Math_fround(HEAPF32[$19>>2]);
 $58 = Math_fround($52 * $57);
 $59 = Math_fround($56 + $58);
 $60 = Math_fround(HEAPF32[$30>>2]);
 $61 = Math_fround($54 * $60);
 $62 = Math_fround($59 + $61);
 $63 = Math_fround(HEAPF32[$11>>2]);
 $64 = Math_fround($50 * $63);
 $65 = Math_fround(HEAPF32[$22>>2]);
 $66 = Math_fround($52 * $65);
 $67 = Math_fround($64 + $66);
 $68 = Math_fround(HEAPF32[$33>>2]);
 $69 = Math_fround($54 * $68);
 $70 = Math_fround($67 + $69);
 $71 = Math_fround(HEAPF32[$15>>2]);
 $72 = Math_fround($50 * $71);
 $73 = Math_fround(HEAPF32[$26>>2]);
 $74 = Math_fround($52 * $73);
 $75 = Math_fround($72 + $74);
 $76 = Math_fround(HEAPF32[$37>>2]);
 $77 = Math_fround($54 * $76);
 $78 = Math_fround($75 + $77);
 $79 = Math_fround($45 + $62);
 $80 = Math_fround($47 + $70);
 $81 = Math_fround($49 + $78);
 HEAPF32[$agg$result>>2] = $79;
 $82 = (($agg$result) + 4|0);
 HEAPF32[$82>>2] = $80;
 $83 = (($agg$result) + 8|0);
 HEAPF32[$83>>2] = $81;
 $84 = (($agg$result) + 12|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu22SupportMapRelativeImplINS0_4BoxVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu22SupportMapRelativeImplINS0_4BoxVEE18doWarmStartSupportEiRNS_6shdfnd3aos5Vec3VE($this,$index,$point) {
 $this = $this|0;
 $index = $index|0;
 $point = $point|0;
 var $$in1$i$i = 0, $$in2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $a$pn3$i$i = 0, $b$a$i$i = 0, $b$a5$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (549664 + ($index<<4)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((549664 + ($index<<4)|0) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((549664 + ($index<<4)|0) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($5) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$12+12>>2]|0;
 $13 = (($5) + 144|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($5) + 148|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($5) + 152|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(-$14);
 $20 = Math_fround(-$16);
 $21 = Math_fround(-$18);
 HEAPF32[$0>>2] = $19;
 $22 = (($0) + 4|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($0) + 8|0);
 HEAPF32[$23>>2] = $21;
 $24 = (($0) + 12|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = ($7|0)==(0);
 $b$a$i$i = $25 ? $0 : $1;
 $26 = Math_fround(HEAPF32[$b$a$i$i>>2]);
 $27 = ($9|0)==(0);
 $a$pn3$i$i = $27 ? $0 : $1;
 $$in1$i$i = (($a$pn3$i$i) + 4|0);
 $28 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $29 = ($11|0)==(0);
 $b$a5$i$i = $29 ? $0 : $1;
 $$in2$i$i = (($b$a5$i$i) + 8|0);
 $30 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 $31 = (($3) + 48|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($3) + 52|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($3) + 56|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$3>>2]);
 $38 = Math_fround($26 * $37);
 $39 = (($3) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($28 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($3) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($30 * $44);
 $46 = Math_fround($42 + $45);
 $47 = (($3) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($26 * $48);
 $50 = (($3) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($28 * $51);
 $53 = Math_fround($49 + $52);
 $54 = (($3) + 36|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($30 * $55);
 $57 = Math_fround($53 + $56);
 $58 = (($3) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($26 * $59);
 $61 = (($3) + 24|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($28 * $62);
 $64 = Math_fround($60 + $63);
 $65 = (($3) + 40|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($30 * $66);
 $68 = Math_fround($64 + $67);
 $69 = Math_fround($32 + $46);
 $70 = Math_fround($34 + $57);
 $71 = Math_fround($36 + $68);
 HEAPF32[$point>>2] = $69;
 $72 = (($point) + 4|0);
 HEAPF32[$72>>2] = $70;
 $73 = (($point) + 8|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($point) + 12|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu22SupportMapRelativeImplINS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $$in1$i$i$i = 0, $$in2$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $9 = 0, $a$pn3$i$i$i = 0, $b$a$i$i$i = 0, $b$a5$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_fround(HEAPF32[$dir>>2]);
 $7 = (($dir) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($dir) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$5>>2]);
 $12 = Math_fround($6 * $11);
 $13 = (($5) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($8 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($5) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($10 * $18);
 $20 = Math_fround($16 + $19);
 $21 = (($5) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($6 * $22);
 $24 = (($5) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($8 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($5) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($10 * $29);
 $31 = Math_fround($27 + $30);
 $32 = (($5) + 32|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($6 * $33);
 $35 = (($5) + 36|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($8 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($5) + 40|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($10 * $40);
 $42 = Math_fround($38 + $41);
 $43 = $20 > Math_fround(0.0);
 $44 = $31 > Math_fround(0.0);
 $45 = $42 > Math_fround(0.0);
 $46 = (($3) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$46+12>>2]|0;
 $47 = (($3) + 144|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($3) + 148|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($3) + 152|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(-$48);
 $54 = Math_fround(-$50);
 $55 = Math_fround(-$52);
 HEAPF32[$0>>2] = $53;
 $56 = (($0) + 4|0);
 HEAPF32[$56>>2] = $54;
 $57 = (($0) + 8|0);
 HEAPF32[$57>>2] = $55;
 $58 = (($0) + 12|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $b$a$i$i$i = $43 ? $1 : $0;
 $59 = Math_fround(HEAPF32[$b$a$i$i$i>>2]);
 $a$pn3$i$i$i = $44 ? $1 : $0;
 $$in1$i$i$i = (($a$pn3$i$i$i) + 4|0);
 $60 = Math_fround(HEAPF32[$$in1$i$i$i>>2]);
 $b$a5$i$i$i = $45 ? $1 : $0;
 $$in2$i$i$i = (($b$a5$i$i$i) + 8|0);
 $61 = Math_fround(HEAPF32[$$in2$i$i$i>>2]);
 $62 = (($5) + 48|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($5) + 52|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($5) + 56|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($11 * $59);
 $69 = Math_fround($22 * $60);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($33 * $61);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($14 * $59);
 $74 = Math_fround($25 * $60);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($36 * $61);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($18 * $59);
 $79 = Math_fround($29 * $60);
 $80 = Math_fround($78 + $79);
 $81 = Math_fround($40 * $61);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($72 + $63);
 $84 = Math_fround($77 + $65);
 $85 = Math_fround($82 + $67);
 HEAPF32[$agg$result>>2] = $83;
 $86 = (($agg$result) + 4|0);
 HEAPF32[$86>>2] = $84;
 $87 = (($agg$result) + 8|0);
 HEAPF32[$87>>2] = $85;
 $88 = (($agg$result) + 12|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu22SupportMapRelativeImplINS0_4BoxVEE14doSupportSweepERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $$in1$i$i$i$i = 0, $$in2$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $9 = 0, $a$pn3$i$i$i$i = 0, $b$a$i$i$i$i = 0, $b$a5$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_fround(HEAPF32[$dir>>2]);
 $7 = (($dir) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($dir) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$5>>2]);
 $12 = Math_fround($6 * $11);
 $13 = (($5) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($8 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($5) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($10 * $18);
 $20 = Math_fround($16 + $19);
 $21 = (($5) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($6 * $22);
 $24 = (($5) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($8 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($5) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($10 * $29);
 $31 = Math_fround($27 + $30);
 $32 = (($5) + 32|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($6 * $33);
 $35 = (($5) + 36|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($8 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($5) + 40|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($10 * $40);
 $42 = Math_fround($38 + $41);
 $43 = $20 > Math_fround(0.0);
 $44 = $31 > Math_fround(0.0);
 $45 = $42 > Math_fround(0.0);
 $46 = (($3) + 144|0);
 ;HEAP32[$1+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$46+12>>2]|0;
 $47 = (($3) + 144|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($3) + 148|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($3) + 152|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(-$48);
 $54 = Math_fround(-$50);
 $55 = Math_fround(-$52);
 HEAPF32[$0>>2] = $53;
 $56 = (($0) + 4|0);
 HEAPF32[$56>>2] = $54;
 $57 = (($0) + 8|0);
 HEAPF32[$57>>2] = $55;
 $58 = (($0) + 12|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $b$a$i$i$i$i = $43 ? $1 : $0;
 $59 = Math_fround(HEAPF32[$b$a$i$i$i$i>>2]);
 $a$pn3$i$i$i$i = $44 ? $1 : $0;
 $$in1$i$i$i$i = (($a$pn3$i$i$i$i) + 4|0);
 $60 = Math_fround(HEAPF32[$$in1$i$i$i$i>>2]);
 $b$a5$i$i$i$i = $45 ? $1 : $0;
 $$in2$i$i$i$i = (($b$a5$i$i$i$i) + 8|0);
 $61 = Math_fround(HEAPF32[$$in2$i$i$i$i>>2]);
 $62 = (($5) + 48|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($5) + 52|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($5) + 56|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($11 * $59);
 $69 = Math_fround($22 * $60);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($33 * $61);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($14 * $59);
 $74 = Math_fround($25 * $60);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($36 * $61);
 $77 = Math_fround($75 + $76);
 $78 = Math_fround($18 * $59);
 $79 = Math_fround($29 * $60);
 $80 = Math_fround($78 + $79);
 $81 = Math_fround($40 * $61);
 $82 = Math_fround($80 + $81);
 $83 = Math_fround($72 + $63);
 $84 = Math_fround($77 + $65);
 $85 = Math_fround($82 + $67);
 HEAPF32[$agg$result>>2] = $83;
 $86 = (($agg$result) + 4|0);
 HEAPF32[$86>>2] = $84;
 $87 = (($agg$result) + 8|0);
 HEAPF32[$87>>2] = $85;
 $88 = (($agg$result) + 12|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu22SupportMapRelativeImplINS0_4BoxVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15intersectOBBOBBERKNS_6PxVec3ES3_RKNS_7PxMat33ES3_S3_S6_b($e0,$c0,$r0,$e1,$c1,$r1,$full_test) {
 $e0 = $e0|0;
 $c0 = $c0|0;
 $r0 = $r0|0;
 $e1 = $e1|0;
 $c1 = $c1|0;
 $r1 = $r1|0;
 $full_test = $full_test|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert20 = 0, $$phi$trans$insert22 = 0, $$phi$trans$insert24 = 0, $$phi$trans$insert26 = 0, $$phi$trans$insert28 = 0, $$phi$trans$insert30 = 0, $$phi$trans$insert32 = 0, $$phi$trans$insert35 = 0, $$phi$trans$insert37 = 0, $$pre = Math_fround(0), $$pre19 = Math_fround(0), $$pre21 = Math_fround(0), $$pre23 = Math_fround(0), $$pre25 = Math_fround(0), $$pre27 = Math_fround(0), $$pre29 = Math_fround(0), $$pre31 = Math_fround(0), $$pre33 = Math_fround(0);
 var $$pre36 = Math_fround(0), $$pre38 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0;
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0;
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0);
 var $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $FR = 0, $R = 0, $T = 0, $exitcond = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i1 = Math_fround(0), $fabsf$i$i10 = Math_fround(0), $fabsf$i$i11 = Math_fround(0), $fabsf$i$i11$1 = Math_fround(0), $fabsf$i$i11$2 = Math_fround(0), $fabsf$i$i2 = Math_fround(0), $fabsf$i$i3 = Math_fround(0);
 var $fabsf$i$i4 = Math_fround(0), $fabsf$i$i5 = Math_fround(0), $fabsf$i$i6 = Math_fround(0), $fabsf$i$i7 = Math_fround(0), $fabsf$i$i8 = Math_fround(0), $fabsf$i$i9 = Math_fround(0), $i$018 = 0, $i1$015 = 0, $k2$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $T = sp + 72|0;
 $R = sp;
 $FR = sp + 36|0;
 $0 = Math_fround(HEAPF32[$c1>>2]);
 $1 = Math_fround(HEAPF32[$c0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($c1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($c0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($c1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($c0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$r0>>2]);
 $14 = Math_fround($2 * $13);
 $15 = (($r0) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($r0) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($12 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($r0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($2 * $24);
 $26 = (($r0) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($7 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($r0) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($12 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($r0) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($2 * $35);
 $37 = (($r0) + 28|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($7 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($r0) + 32|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($12 * $42);
 $44 = Math_fround($40 + $43);
 HEAPF32[$T>>2] = $22;
 $45 = (($T) + 4|0);
 HEAPF32[$45>>2] = $33;
 $46 = (($T) + 8|0);
 HEAPF32[$46>>2] = $44;
 $$pre = Math_fround(HEAPF32[$r1>>2]);
 $$phi$trans$insert = (($r1) + 4|0);
 $$pre19 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
 $$phi$trans$insert20 = (($r1) + 8|0);
 $$pre21 = Math_fround(HEAPF32[$$phi$trans$insert20>>2]);
 $$phi$trans$insert22 = (($r1) + 12|0);
 $$pre23 = Math_fround(HEAPF32[$$phi$trans$insert22>>2]);
 $$phi$trans$insert24 = (($r1) + 16|0);
 $$pre25 = Math_fround(HEAPF32[$$phi$trans$insert24>>2]);
 $$phi$trans$insert26 = (($r1) + 20|0);
 $$pre27 = Math_fround(HEAPF32[$$phi$trans$insert26>>2]);
 $$phi$trans$insert28 = (($r1) + 24|0);
 $$pre29 = Math_fround(HEAPF32[$$phi$trans$insert28>>2]);
 $$phi$trans$insert30 = (($r1) + 28|0);
 $$pre31 = Math_fround(HEAPF32[$$phi$trans$insert30>>2]);
 $$phi$trans$insert32 = (($r1) + 32|0);
 $$pre33 = Math_fround(HEAPF32[$$phi$trans$insert32>>2]);
 $i$018 = 0;
 while(1) {
  $47 = (($r0) + (($i$018*12)|0)|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = ((($r0) + (($i$018*12)|0)|0) + 4|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = ((($r0) + (($i$018*12)|0)|0) + 8|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = Math_fround($48 * $$pre);
  $54 = Math_fround($50 * $$pre19);
  $55 = Math_fround($53 + $54);
  $56 = Math_fround($52 * $$pre21);
  $57 = Math_fround($55 + $56);
  $58 = (($R) + (($i$018*12)|0)|0);
  HEAPF32[$58>>2] = $57;
  $fabsf$i$i11 = (Math_fround(Math_abs((Math_fround($57)))));
  $59 = Math_fround($fabsf$i$i11 + Math_fround(9.99999997475242707878E-7));
  $60 = (($FR) + (($i$018*12)|0)|0);
  HEAPF32[$60>>2] = $59;
  $61 = Math_fround($48 * $$pre23);
  $62 = Math_fround($50 * $$pre25);
  $63 = Math_fround($61 + $62);
  $64 = Math_fround($52 * $$pre27);
  $65 = Math_fround($63 + $64);
  $66 = ((($R) + (($i$018*12)|0)|0) + 4|0);
  HEAPF32[$66>>2] = $65;
  $fabsf$i$i11$1 = (Math_fround(Math_abs((Math_fround($65)))));
  $67 = Math_fround($fabsf$i$i11$1 + Math_fround(9.99999997475242707878E-7));
  $68 = ((($FR) + (($i$018*12)|0)|0) + 4|0);
  HEAPF32[$68>>2] = $67;
  $69 = Math_fround($48 * $$pre29);
  $70 = Math_fround($50 * $$pre31);
  $71 = Math_fround($69 + $70);
  $72 = Math_fround($52 * $$pre33);
  $73 = Math_fround($71 + $72);
  $74 = ((($R) + (($i$018*12)|0)|0) + 8|0);
  HEAPF32[$74>>2] = $73;
  $fabsf$i$i11$2 = (Math_fround(Math_abs((Math_fround($73)))));
  $75 = Math_fround($fabsf$i$i11$2 + Math_fround(9.99999997475242707878E-7));
  $76 = ((($FR) + (($i$018*12)|0)|0) + 8|0);
  HEAPF32[$76>>2] = $75;
  $77 = (($i$018) + 1)|0;
  $exitcond = ($77|0)==(3);
  if ($exitcond) {
   break;
  } else {
   $i$018 = $77;
  }
 }
 $78 = Math_fround(HEAPF32[$e1>>2]);
 $79 = (($e1) + 4|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($e1) + 8|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $103 = $22;$i1$015 = 0;
 while(1) {
  $90 = (($e0) + ($i1$015<<2)|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = (($FR) + (($i1$015*12)|0)|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = Math_fround($78 * $93);
  $95 = ((($FR) + (($i1$015*12)|0)|0) + 4|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = Math_fround($80 * $96);
  $98 = Math_fround($94 + $97);
  $99 = ((($FR) + (($i1$015*12)|0)|0) + 8|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($82 * $100);
  $102 = Math_fround($98 + $101);
  $fabsf$i$i10 = (Math_fround(Math_abs((Math_fround($103)))));
  $104 = Math_fround($91 + $102);
  $105 = $fabsf$i$i10 > $104;
  $84 = (($i1$015) + 1)|0;
  if ($105) {
   $$0 = 0;
   label = 22;
   break;
  }
  $83 = ($84>>>0)<(3);
  if (!($83)) {
   break;
  }
  $$phi$trans$insert35 = (($T) + ($84<<2)|0);
  $$pre36 = Math_fround(HEAPF32[$$phi$trans$insert35>>2]);
  $103 = $$pre36;$i1$015 = $84;
 }
 if ((label|0) == 22) {
  STACKTOP = sp;return ($$0|0);
 }
 $85 = Math_fround(HEAPF32[$e0>>2]);
 $86 = (($e0) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($e0) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $131 = $78;$k2$012 = 0;
 while(1) {
  $108 = (($FR) + ($k2$012<<2)|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = Math_fround($85 * $109);
  $111 = ((($FR) + ($k2$012<<2)|0) + 12|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = Math_fround($87 * $112);
  $114 = Math_fround($110 + $113);
  $115 = ((($FR) + ($k2$012<<2)|0) + 24|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = Math_fround($89 * $116);
  $118 = Math_fround($114 + $117);
  $119 = (($R) + ($k2$012<<2)|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $121 = Math_fround($22 * $120);
  $122 = ((($R) + ($k2$012<<2)|0) + 12|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = Math_fround($33 * $123);
  $125 = Math_fround($121 + $124);
  $126 = ((($R) + ($k2$012<<2)|0) + 24|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = Math_fround($44 * $127);
  $129 = Math_fround($125 + $128);
  $fabsf$i$i9 = (Math_fround(Math_abs((Math_fround($129)))));
  $130 = Math_fround($131 + $118);
  $132 = $fabsf$i$i9 > $130;
  $107 = (($k2$012) + 1)|0;
  if ($132) {
   $$0 = 0;
   label = 22;
   break;
  }
  $106 = ($107>>>0)<(3);
  if (!($106)) {
   break;
  }
  $$phi$trans$insert37 = (($e1) + ($107<<2)|0);
  $$pre38 = Math_fround(HEAPF32[$$phi$trans$insert37>>2]);
  $131 = $$pre38;$k2$012 = $107;
 }
 if ((label|0) == 22) {
  STACKTOP = sp;return ($$0|0);
 }
 if ($full_test) {
  $133 = (($FR) + 24|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($87 * $134);
  $136 = (($FR) + 12|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = Math_fround($89 * $137);
  $139 = Math_fround($135 + $138);
  $140 = (($FR) + 8|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = Math_fround($80 * $141);
  $143 = (($FR) + 4|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = Math_fround($82 * $144);
  $146 = Math_fround($142 + $145);
  $147 = (($R) + 12|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = Math_fround($44 * $148);
  $150 = (($R) + 24|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = Math_fround($33 * $151);
  $153 = Math_fround($149 - $152);
  $fabsf$i$i8 = (Math_fround(Math_abs((Math_fround($153)))));
  $154 = Math_fround($139 + $146);
  $155 = $fabsf$i$i8 > $154;
  if ($155) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $156 = (($FR) + 28|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = Math_fround($87 * $157);
  $159 = (($FR) + 16|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = Math_fround($89 * $160);
  $162 = Math_fround($158 + $161);
  $163 = Math_fround($141 * $78);
  $164 = Math_fround(HEAPF32[$FR>>2]);
  $165 = Math_fround($82 * $164);
  $166 = Math_fround($163 + $165);
  $167 = (($R) + 16|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = Math_fround($44 * $168);
  $170 = (($R) + 28|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = Math_fround($33 * $171);
  $173 = Math_fround($169 - $172);
  $fabsf$i$i7 = (Math_fround(Math_abs((Math_fround($173)))));
  $174 = Math_fround($162 + $166);
  $175 = $fabsf$i$i7 > $174;
  if ($175) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $176 = (($FR) + 32|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround($87 * $177);
  $179 = (($FR) + 20|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = Math_fround($89 * $180);
  $182 = Math_fround($178 + $181);
  $183 = Math_fround($144 * $78);
  $184 = Math_fround($80 * $164);
  $185 = Math_fround($183 + $184);
  $186 = (($R) + 20|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = Math_fround($44 * $187);
  $189 = (($R) + 32|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = Math_fround($33 * $190);
  $192 = Math_fround($188 - $191);
  $fabsf$i$i6 = (Math_fround(Math_abs((Math_fround($192)))));
  $193 = Math_fround($185 + $182);
  $194 = $fabsf$i$i6 > $193;
  if ($194) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $195 = Math_fround($134 * $85);
  $196 = Math_fround($89 * $164);
  $197 = Math_fround($196 + $195);
  $198 = Math_fround($80 * $180);
  $199 = Math_fround($82 * $160);
  $200 = Math_fround($199 + $198);
  $201 = Math_fround($151 * $22);
  $202 = Math_fround(HEAPF32[$R>>2]);
  $203 = Math_fround($44 * $202);
  $204 = Math_fround($201 - $203);
  $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($204)))));
  $205 = Math_fround($200 + $197);
  $206 = $fabsf$i$i5 > $205;
  if ($206) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $207 = Math_fround($157 * $85);
  $208 = Math_fround($89 * $144);
  $209 = Math_fround($208 + $207);
  $210 = Math_fround($78 * $180);
  $211 = Math_fround($137 * $82);
  $212 = Math_fround($211 + $210);
  $213 = Math_fround($171 * $22);
  $214 = (($R) + 4|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = Math_fround($44 * $215);
  $217 = Math_fround($213 - $216);
  $fabsf$i$i4 = (Math_fround(Math_abs((Math_fround($217)))));
  $218 = Math_fround($212 + $209);
  $219 = $fabsf$i$i4 > $218;
  if ($219) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $220 = Math_fround($177 * $85);
  $221 = Math_fround($89 * $141);
  $222 = Math_fround($221 + $220);
  $223 = Math_fround($160 * $78);
  $224 = Math_fround($137 * $80);
  $225 = Math_fround($224 + $223);
  $226 = Math_fround($190 * $22);
  $227 = (($R) + 8|0);
  $228 = Math_fround(HEAPF32[$227>>2]);
  $229 = Math_fround($44 * $228);
  $230 = Math_fround($226 - $229);
  $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($230)))));
  $231 = Math_fround($225 + $222);
  $232 = $fabsf$i$i3 > $231;
  if ($232) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $233 = Math_fround($137 * $85);
  $234 = Math_fround($87 * $164);
  $235 = Math_fround($234 + $233);
  $236 = Math_fround($80 * $177);
  $237 = Math_fround($82 * $157);
  $238 = Math_fround($237 + $236);
  $239 = Math_fround($33 * $202);
  $240 = Math_fround($148 * $22);
  $241 = Math_fround($239 - $240);
  $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($241)))));
  $242 = Math_fround($238 + $235);
  $243 = $fabsf$i$i2 > $242;
  if ($243) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $244 = Math_fround($160 * $85);
  $245 = Math_fround($87 * $144);
  $246 = Math_fround($245 + $244);
  $247 = Math_fround($78 * $177);
  $248 = Math_fround($134 * $82);
  $249 = Math_fround($248 + $247);
  $250 = Math_fround($33 * $215);
  $251 = Math_fround($168 * $22);
  $252 = Math_fround($250 - $251);
  $fabsf$i$i1 = (Math_fround(Math_abs((Math_fround($252)))));
  $253 = Math_fround($249 + $246);
  $254 = $fabsf$i$i1 > $253;
  if ($254) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $255 = Math_fround($180 * $85);
  $256 = Math_fround($87 * $141);
  $257 = Math_fround($256 + $255);
  $258 = Math_fround($157 * $78);
  $259 = Math_fround($134 * $80);
  $260 = Math_fround($259 + $258);
  $261 = Math_fround($33 * $228);
  $262 = Math_fround($187 * $22);
  $263 = Math_fround($261 - $262);
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($263)))));
  $264 = Math_fround($260 + $257);
  $265 = $fabsf$i$i > $264;
  if ($265) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu17intersectEdgeEdgeERKNS_6PxVec3ES3_S3_S3_S3_RfRS1_($p1,$p2,$dir,$p3,$p4,$dist,$ip) {
 $p1 = $p1|0;
 $p2 = $p2|0;
 $dir = $dir|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $dist = $dist|0;
 $ip = $ip|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $dir$idx$val = Math_fround(0), $dir$idx1$val = Math_fround(0), $dir$idx2$val = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0);
 var $fabsf$i$i2$i = Math_fround(0), $or$cond$i = 0, $v1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $v1 = sp;
 $0 = Math_fround(HEAPF32[$p2>>2]);
 $1 = Math_fround(HEAPF32[$p1>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($p2) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($p1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($p2) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($p1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 HEAPF32[$v1>>2] = $2;
 $13 = (($v1) + 4|0);
 HEAPF32[$13>>2] = $7;
 $14 = (($v1) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($dir) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = (($dir) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($12 * $19);
 $21 = Math_fround($17 - $20);
 $22 = Math_fround(HEAPF32[$dir>>2]);
 $23 = Math_fround($12 * $22);
 $24 = Math_fround($16 * $2);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($19 * $2);
 $27 = Math_fround($7 * $22);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($21 * $1);
 $30 = Math_fround($25 * $6);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($28 * $11);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround(HEAPF32[$p3>>2]);
 $35 = Math_fround($21 * $34);
 $36 = (($p3) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($25 * $37);
 $39 = Math_fround($35 + $38);
 $40 = (($p3) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($28 * $41);
 $43 = Math_fround($39 + $42);
 $44 = Math_fround($43 - $33);
 $45 = Math_fround(HEAPF32[$p4>>2]);
 $46 = Math_fround($21 * $45);
 $47 = (($p4) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($25 * $48);
 $50 = Math_fround($46 + $49);
 $51 = (($p4) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($28 * $52);
 $54 = Math_fround($50 + $53);
 $55 = Math_fround($54 - $33);
 $56 = Math_fround($44 * $55);
 $57 = $56 > Math_fround(0.0);
 if ($57) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $58 = Math_fround($45 - $34);
 $59 = Math_fround($48 - $37);
 $60 = Math_fround($52 - $41);
 $61 = Math_fround($21 * $58);
 $62 = Math_fround($25 * $59);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($28 * $60);
 $65 = Math_fround($63 + $64);
 $66 = $65 == Math_fround(0.0);
 if ($66) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = Math_fround($44 / $65);
 $68 = Math_fround($58 * $67);
 $69 = Math_fround($59 * $67);
 $70 = Math_fround($60 * $67);
 $71 = Math_fround($34 - $68);
 $72 = Math_fround($37 - $69);
 $73 = Math_fround($41 - $70);
 HEAPF32[$ip>>2] = $71;
 $74 = (($ip) + 4|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($ip) + 8|0);
 HEAPF32[$75>>2] = $73;
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($21)))));
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($25)))));
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($28)))));
 $76 = $fabsf$i$i1$i > $fabsf$i$i$i;
 $77 = $fabsf$i$i1$i > $fabsf$i$i2$i;
 $or$cond$i = $76 & $77;
 if ($or$cond$i) {
  $80 = 2;$83 = 0;
 } else {
  $78 = $fabsf$i$i2$i > $fabsf$i$i$i;
  if ($78) {
   $80 = 0;$83 = 1;
  } else {
   $80 = 1;$83 = 2;
  }
 }
 $79 = (($v1) + ($80<<2)|0);
 $81 = Math_fround(HEAPF32[$79>>2]);
 $82 = (($ip) + ($83<<2)|0);
 $84 = Math_fround(HEAPF32[$82>>2]);
 $85 = (($p1) + ($83<<2)|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($84 - $86);
 $88 = Math_fround($81 * $87);
 $89 = (($v1) + ($83<<2)|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($ip) + ($80<<2)|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($p1) + ($80<<2)|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($92 - $94);
 $96 = Math_fround($90 * $95);
 $97 = Math_fround($88 - $96);
 $98 = (($dir) + ($83<<2)|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($81 * $99);
 $101 = (($dir) + ($80<<2)|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($90 * $102);
 $104 = Math_fround($100 - $103);
 $105 = Math_fround($97 / $104);
 HEAPF32[$dist>>2] = $105;
 $106 = $105 < Math_fround(0.0);
 if ($106) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $dir$idx$val = Math_fround(HEAPF32[$dir>>2]);
 $dir$idx1$val = Math_fround(HEAPF32[$18>>2]);
 $dir$idx2$val = Math_fround(HEAPF32[$15>>2]);
 $107 = Math_fround($105 * $dir$idx$val);
 $108 = Math_fround($105 * $dir$idx1$val);
 $109 = Math_fround($105 * $dir$idx2$val);
 $110 = Math_fround(HEAPF32[$ip>>2]);
 $111 = Math_fround($110 - $107);
 HEAPF32[$ip>>2] = $111;
 $112 = Math_fround(HEAPF32[$74>>2]);
 $113 = Math_fround($112 - $108);
 HEAPF32[$74>>2] = $113;
 $114 = Math_fround(HEAPF32[$75>>2]);
 $115 = Math_fround($114 - $109);
 HEAPF32[$75>>2] = $115;
 $116 = Math_fround(HEAPF32[$p1>>2]);
 $117 = Math_fround($116 - $111);
 $118 = Math_fround(HEAPF32[$p2>>2]);
 $119 = Math_fround($118 - $111);
 $120 = Math_fround($117 * $119);
 $121 = Math_fround(HEAPF32[$5>>2]);
 $122 = Math_fround($121 - $113);
 $123 = Math_fround(HEAPF32[$3>>2]);
 $124 = Math_fround($123 - $113);
 $125 = Math_fround($122 * $124);
 $126 = Math_fround($120 + $125);
 $127 = Math_fround(HEAPF32[$10>>2]);
 $128 = Math_fround($127 - $115);
 $129 = Math_fround(HEAPF32[$8>>2]);
 $130 = Math_fround($129 - $115);
 $131 = Math_fround($128 * $130);
 $132 = Math_fround($126 + $131);
 $133 = $132 < Math_fround(0.0);
 $$0 = $133;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu17rayAABBIntersect2ERKNS_6PxVec3ES3_S3_S3_RS1_Rf($minimum,$maximum,$origin,$_dir,$coord,$t) {
 $minimum = $minimum|0;
 $maximum = $maximum|0;
 $origin = $origin|0;
 $_dir = $_dir|0;
 $coord = $coord|0;
 $t = $t|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0;
 var $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0);
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $Inside$1 = 0, $Inside$1$1 = 0, $MaxT = 0, $WhichPlane$0 = 0;
 var $WhichPlane$1 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $MaxT = sp;
 HEAPF32[$MaxT>>2] = Math_fround(-1.0);
 $0 = (($MaxT) + 4|0);
 HEAPF32[$0>>2] = Math_fround(-1.0);
 $1 = (($MaxT) + 8|0);
 HEAPF32[$1>>2] = Math_fround(-1.0);
 $2 = Math_fround(HEAPF32[$origin>>2]);
 $3 = Math_fround(HEAPF32[$minimum>>2]);
 $4 = $2 < $3;
 if ($4) {
  HEAPF32[$coord>>2] = $3;
  $5 = HEAP32[$_dir>>2]|0;
  $6 = ($5|0)==(0);
  if ($6) {
   $35 = Math_fround(-1.0);$Inside$1 = 0;
  } else {
   $7 = (HEAP32[tempDoublePtr>>2]=$5,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $8 = Math_fround(HEAPF32[$minimum>>2]);
   $9 = Math_fround(HEAPF32[$origin>>2]);
   $10 = Math_fround($8 - $9);
   $11 = Math_fround($10 / $7);
   HEAPF32[$MaxT>>2] = $11;
   $35 = $11;$Inside$1 = 0;
  }
 } else {
  $12 = Math_fround(HEAPF32[$maximum>>2]);
  $13 = $2 > $12;
  if ($13) {
   HEAPF32[$coord>>2] = $12;
   $14 = HEAP32[$_dir>>2]|0;
   $15 = ($14|0)==(0);
   if ($15) {
    $35 = Math_fround(-1.0);$Inside$1 = 0;
   } else {
    $16 = (HEAP32[tempDoublePtr>>2]=$14,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $17 = Math_fround(HEAPF32[$maximum>>2]);
    $18 = Math_fround(HEAPF32[$origin>>2]);
    $19 = Math_fround($17 - $18);
    $20 = Math_fround($19 / $16);
    HEAPF32[$MaxT>>2] = $20;
    $35 = $20;$Inside$1 = 0;
   }
  } else {
   $35 = Math_fround(-1.0);$Inside$1 = 1;
  }
 }
 $21 = (($origin) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($minimum) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $22 < $24;
 if ($25) {
  $76 = (($coord) + 4|0);
  HEAPF32[$76>>2] = $24;
  $77 = (($_dir) + 4|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0);
  if ($79) {
   $34 = Math_fround(-1.0);$Inside$1$1 = 0;
  } else {
   $80 = (HEAP32[tempDoublePtr>>2]=$78,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $81 = Math_fround(HEAPF32[$23>>2]);
   $82 = Math_fround(HEAPF32[$21>>2]);
   $83 = Math_fround($81 - $82);
   $84 = Math_fround($83 / $80);
   $85 = (($MaxT) + 4|0);
   HEAPF32[$85>>2] = $84;
   $34 = $84;$Inside$1$1 = 0;
  }
 } else {
  $63 = (($maximum) + 4|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = $22 > $64;
  if ($65) {
   $66 = (($coord) + 4|0);
   HEAPF32[$66>>2] = $64;
   $67 = (($_dir) + 4|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(0);
   if ($69) {
    $34 = Math_fround(-1.0);$Inside$1$1 = 0;
   } else {
    $70 = (HEAP32[tempDoublePtr>>2]=$68,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $71 = Math_fround(HEAPF32[$63>>2]);
    $72 = Math_fround(HEAPF32[$21>>2]);
    $73 = Math_fround($71 - $72);
    $74 = Math_fround($73 / $70);
    $75 = (($MaxT) + 4|0);
    HEAPF32[$75>>2] = $74;
    $34 = $74;$Inside$1$1 = 0;
   }
  } else {
   $34 = Math_fround(-1.0);$Inside$1$1 = $Inside$1;
  }
 }
 $86 = (($origin) + 8|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($minimum) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = $87 < $89;
 do {
  if ($90) {
   $104 = (($coord) + 8|0);
   HEAPF32[$104>>2] = $89;
   $105 = (($_dir) + 8|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($106|0)==(0);
   if ($107) {
    $39 = Math_fround(-1.0);
   } else {
    $108 = (HEAP32[tempDoublePtr>>2]=$106,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $109 = Math_fround(HEAPF32[$88>>2]);
    $110 = Math_fround(HEAPF32[$86>>2]);
    $111 = Math_fround($109 - $110);
    $112 = Math_fround($111 / $108);
    $113 = (($MaxT) + 8|0);
    HEAPF32[$113>>2] = $112;
    $39 = $112;
   }
  } else {
   $91 = (($maximum) + 8|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = $87 > $92;
   if ($93) {
    $94 = (($coord) + 8|0);
    HEAPF32[$94>>2] = $92;
    $95 = (($_dir) + 8|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ($96|0)==(0);
    if ($97) {
     $39 = Math_fround(-1.0);
     break;
    }
    $98 = (HEAP32[tempDoublePtr>>2]=$96,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $99 = Math_fround(HEAPF32[$91>>2]);
    $100 = Math_fround(HEAPF32[$86>>2]);
    $101 = Math_fround($99 - $100);
    $102 = Math_fround($101 / $98);
    $103 = (($MaxT) + 8|0);
    HEAPF32[$103>>2] = $102;
    $39 = $102;
    break;
   }
   $114 = ($Inside$1$1|0)==(0);
   if ($114) {
    $39 = Math_fround(-1.0);
   } else {
    $26 = Math_fround(HEAPF32[$origin>>2]);
    HEAPF32[$coord>>2] = $26;
    $27 = (($origin) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = (($coord) + 4|0);
    HEAPF32[$29>>2] = $28;
    $30 = (($origin) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = (($coord) + 8|0);
    HEAPF32[$32>>2] = $31;
    HEAPF32[$t>>2] = Math_fround(0.0);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $33 = $34 > $35;
 $WhichPlane$0 = $33&1;
 $36 = (($MaxT) + ($WhichPlane$0<<2)|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = $39 > $37;
 $WhichPlane$1 = $38 ? 2 : $WhichPlane$0;
 $40 = (($MaxT) + ($WhichPlane$1<<2)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)<(0);
 $43 = (HEAP32[tempDoublePtr>>2]=$41,Math_fround(HEAPF32[tempDoublePtr>>2]));
 if ($42) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i1$01 = 0;
 }
 while(1) {
  $44 = ($i1$01|0)==($WhichPlane$1|0);
  if (!($44)) {
   $45 = (($origin) + ($i1$01<<2)|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($_dir) + ($i1$01<<2)|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = Math_fround($43 * $48);
   $50 = Math_fround($46 + $49);
   $51 = (($coord) + ($i1$01<<2)|0);
   HEAPF32[$51>>2] = $50;
   $52 = (($minimum) + ($i1$01<<2)|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = Math_fround($53 + Math_fround(-9.99999974737875163555E-6));
   $55 = $50 < $54;
   if ($55) {
    $$0 = 0;
    label = 15;
    break;
   }
   $56 = (($maximum) + ($i1$01<<2)|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround($57 + Math_fround(9.99999974737875163555E-6));
   $59 = $50 > $58;
   if ($59) {
    $$0 = 0;
    label = 15;
    break;
   }
  }
  $60 = (($i1$01) + 1)|0;
  $61 = ($60>>>0)<(3);
  if ($61) {
   $i1$01 = $60;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  HEAPF32[$t>>2] = $43;
  $62 = (($WhichPlane$1) + 1)|0;
  $$0 = $62;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 15) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu16intersectRayAABBERKNS_6PxVec3ES3_S3_S3_RfS4_($minimum,$maximum,$ro,$rd,$tnear,$tfar) {
 $minimum = $minimum|0;
 $maximum = $maximum|0;
 $ro = $ro|0;
 $rd = $rd|0;
 $tnear = $tnear|0;
 $tfar = $tfar|0;
 var $$pre = Math_fround(0), $$pre6 = Math_fround(0), $$ret$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $5 = Math_fround(0);
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $a$04 = 0, $b$0 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $ret$05 = 0, $ret$1 = 0, $ret$2 = 0, $t1$0 = Math_fround(0), $t2$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$tnear>>2] = Math_fround(-3.40282346638528859812E+38);
 HEAPF32[$tfar>>2] = Math_fround(3.40282346638528859812E+38);
 $39 = Math_fround(3.40282346638528859812E+38);$a$04 = 0;$ret$05 = -1;
 while(1) {
  $0 = (($rd) + ($a$04<<2)|0);
  $1 = Math_fround(HEAPF32[$0>>2]);
  $2 = $1 > Math_fround(-1.1920928955078125E-7);
  $3 = $1 < Math_fround(1.1920928955078125E-7);
  $or$cond2 = $2 & $3;
  if ($or$cond2) {
   $4 = (($ro) + ($a$04<<2)|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   $6 = (($minimum) + ($a$04<<2)|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $5 < $7;
   if ($8) {
    label = 12;
    break;
   }
   $9 = (($maximum) + ($a$04<<2)|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = $5 > $10;
   if ($11) {
    label = 12;
    break;
   } else {
    $37 = $39;$ret$2 = $ret$05;
   }
  } else {
   $12 = Math_fround(Math_fround(1.0) / $1);
   $13 = (($minimum) + ($a$04<<2)|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = (($ro) + ($a$04<<2)|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($14 - $16);
   $18 = Math_fround($12 * $17);
   $19 = (($maximum) + ($a$04<<2)|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround($20 - $16);
   $22 = Math_fround($12 * $21);
   $23 = $18 > $22;
   $t1$0 = $23 ? $22 : $18;
   $t2$0 = $23 ? $18 : $22;
   $24 = Math_fround(HEAPF32[$tnear>>2]);
   $25 = $t1$0 > $24;
   if ($25) {
    $26 = (($a$04) + 3)|0;
    $b$0 = $23 ? $26 : $a$04;
    HEAPF32[$tnear>>2] = $t1$0;
    $$pre = Math_fround(HEAPF32[$tfar>>2]);
    $28 = $$pre;$40 = $t1$0;$ret$1 = $b$0;
   } else {
    $28 = $39;$40 = $24;$ret$1 = $ret$05;
   }
   $27 = $t2$0 < $28;
   if ($27) {
    HEAPF32[$tfar>>2] = $t2$0;
    $$pre6 = Math_fround(HEAPF32[$tnear>>2]);
    $30 = $$pre6;$31 = $t2$0;
   } else {
    $30 = $40;$31 = $28;
   }
   $29 = $30 > $31;
   $32 = $31 < Math_fround(1.1920928955078125E-7);
   $or$cond = $29 | $32;
   if ($or$cond) {
    label = 12;
    break;
   } else {
    $37 = $31;$ret$2 = $ret$1;
   }
  }
  $33 = (($a$04) + 1)|0;
  $34 = ($33|0)<(3);
  if ($34) {
   $39 = $37;$a$04 = $33;$ret$05 = $ret$2;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  $35 = Math_fround(HEAPF32[$tnear>>2]);
  $36 = $35 > $37;
  $38 = $37 < Math_fround(1.1920928955078125E-7);
  $or$cond1 = $36 | $38;
  $$ret$0 = $or$cond1 ? -1 : $ret$2;
  STACKTOP = sp;return ($$ret$0|0);
 }
 else if ((label|0) == 12) {
  STACKTOP = sp;return -1;
 }
 return 0|0;
}
function __ZN5physx2Gu17intersectRayAABB2ERKNS_6PxVec3ES3_S3_S3_fRfS4_($minimum,$maximum,$ro,$rd,$maxDist,$tnear,$tfar) {
 $minimum = $minimum|0;
 $maximum = $maximum|0;
 $ro = $ro|0;
 $rd = $rd|0;
 $maxDist = Math_fround($maxDist);
 $tnear = $tnear|0;
 $tfar = $tfar|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $fabsf$i = Math_fround(0), $fabsf$i1 = Math_fround(0), $fabsf$i2 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$rd>>2]);
 $fabsf$i = (Math_fround(Math_abs((Math_fround($0)))));
 $1 = $fabsf$i > Math_fround(9.99999971718068536574E-10);
 $2 = $1 ? $fabsf$i : Math_fround(9.99999971718068536574E-10);
 $3 = $0 >= Math_fround(0.0);
 $4 = $3 ? Math_fround(1.0) : Math_fround(-1.0);
 $5 = Math_fround($4 * $2);
 $6 = Math_fround(Math_fround(1.0) / $5);
 $7 = Math_fround(HEAPF32[$minimum>>2]);
 $8 = Math_fround(HEAPF32[$ro>>2]);
 $9 = Math_fround($7 - $8);
 $10 = Math_fround($6 * $9);
 $11 = Math_fround(HEAPF32[$maximum>>2]);
 $12 = Math_fround($11 - $8);
 $13 = Math_fround($6 * $12);
 $14 = $10 < $13;
 $15 = $14 ? $10 : $13;
 $16 = $10 > $13;
 $17 = $16 ? $10 : $13;
 $18 = (($rd) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $fabsf$i2 = (Math_fround(Math_abs((Math_fround($19)))));
 $20 = $fabsf$i2 > Math_fround(9.99999971718068536574E-10);
 $21 = $20 ? $fabsf$i2 : Math_fround(9.99999971718068536574E-10);
 $22 = $19 >= Math_fround(0.0);
 $23 = $22 ? Math_fround(1.0) : Math_fround(-1.0);
 $24 = Math_fround($23 * $21);
 $25 = Math_fround(Math_fround(1.0) / $24);
 $26 = (($minimum) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($ro) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($27 - $29);
 $31 = Math_fround($25 * $30);
 $32 = (($maximum) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 - $29);
 $35 = Math_fround($25 * $34);
 $36 = $31 < $35;
 $37 = $36 ? $31 : $35;
 $38 = $31 > $35;
 $39 = $38 ? $31 : $35;
 $40 = (($rd) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $fabsf$i1 = (Math_fround(Math_abs((Math_fround($41)))));
 $42 = $fabsf$i1 > Math_fround(9.99999971718068536574E-10);
 $43 = $42 ? $fabsf$i1 : Math_fround(9.99999971718068536574E-10);
 $44 = $41 >= Math_fround(0.0);
 $45 = $44 ? Math_fround(1.0) : Math_fround(-1.0);
 $46 = Math_fround($45 * $43);
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = (($minimum) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($ro) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($49 - $51);
 $53 = Math_fround($47 * $52);
 $54 = (($maximum) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 - $51);
 $57 = Math_fround($47 * $56);
 $58 = $53 < $57;
 $59 = $58 ? $53 : $57;
 $60 = $53 > $57;
 $61 = $60 ? $53 : $57;
 $62 = $15 > $37;
 $63 = $62 ? $15 : $37;
 $64 = $63 > $59;
 $65 = $64 ? $63 : $59;
 $66 = $17 < $39;
 $67 = $66 ? $17 : $39;
 $68 = $67 < $61;
 $69 = $68 ? $67 : $61;
 $70 = $65 > Math_fround(0.0);
 $71 = $70 ? $65 : Math_fround(0.0);
 HEAPF32[$tnear>>2] = $71;
 $72 = $69 < $maxDist;
 $73 = $72 ? $69 : $maxDist;
 HEAPF32[$tfar>>2] = $73;
 $74 = Math_fround(HEAPF32[$tnear>>2]);
 $75 = $74 < $73;
 STACKTOP = sp;return ($75|0);
}
function __ZN5physx2Gu17intersectRayAABB2ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_RKNS2_6FloatVERS6_S9_($minimum,$maximum,$ro,$rd,$maxDist,$tnear,$tfar) {
 $minimum = $minimum|0;
 $maximum = $maximum|0;
 $ro = $ro|0;
 $rd = $rd|0;
 $maxDist = $maxDist|0;
 $tnear = $tnear|0;
 $tfar = $tfar|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i13 = Math_fround(0), $$$i18 = Math_fround(0), $$$i29 = Math_fround(0), $$$i34 = Math_fround(0), $$$i45 = Math_fround(0), $$$i50 = Math_fround(0), $$$i8 = Math_fround(0), $$$i80 = Math_fround(0), $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i51 = Math_fround(0), $$1$i81 = Math_fround(0), $$sroa$187 = 0, $$sroa$189 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0;
 var $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$sroa$189 = sp + 12|0;
 $$sroa$187 = sp;
 $0 = Math_fround(HEAPF32[$rd>>2]);
 $1 = (($rd) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($rd) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$0);
 $6 = Math_fround(-$2);
 $7 = Math_fround(-$4);
 $8 = $0 > $5;
 $$$i$i = $8 ? $0 : $5;
 $9 = $2 > $6;
 $10 = $9 ? $2 : $6;
 $11 = $4 > $7;
 $$1$i$i = $11 ? $4 : $7;
 $12 = $$$i$i > Math_fround(9.99999971718068536574E-10);
 $$$i80 = $12 ? $$$i$i : Math_fround(9.99999971718068536574E-10);
 $13 = $10 > Math_fround(9.99999971718068536574E-10);
 $14 = $13 ? $10 : Math_fround(9.99999971718068536574E-10);
 $15 = $$1$i$i > Math_fround(9.99999971718068536574E-10);
 $$1$i81 = $15 ? $$1$i$i : Math_fround(9.99999971718068536574E-10);
 $16 = $0 >= Math_fround(0.0);
 $17 = $16 ? Math_fround(1.0) : Math_fround(-1.0);
 $18 = $2 >= Math_fround(0.0);
 $19 = $18 ? Math_fround(1.0) : Math_fround(-1.0);
 $20 = $4 >= Math_fround(0.0);
 $21 = $20 ? Math_fround(1.0) : Math_fround(-1.0);
 $22 = Math_fround($17 * $$$i80);
 $23 = Math_fround($19 * $14);
 $24 = Math_fround($21 * $$1$i81);
 $25 = Math_fround(Math_fround(1.0) / $22);
 $26 = Math_fround(Math_fround(1.0) / $23);
 $27 = Math_fround(Math_fround(1.0) / $24);
 $28 = Math_fround(HEAPF32[$minimum>>2]);
 $29 = (($minimum) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($minimum) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(HEAPF32[$ro>>2]);
 $34 = (($ro) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($ro) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($28 - $33);
 $39 = Math_fround($30 - $35);
 $40 = Math_fround($32 - $37);
 $41 = Math_fround($25 * $38);
 $42 = Math_fround($26 * $39);
 $43 = Math_fround($27 * $40);
 $44 = Math_fround(HEAPF32[$maximum>>2]);
 $45 = (($maximum) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($maximum) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($44 - $33);
 $50 = Math_fround($46 - $35);
 $51 = Math_fround($48 - $37);
 $52 = Math_fround($25 * $49);
 $53 = Math_fround($26 * $50);
 $54 = Math_fround($27 * $51);
 $55 = $52 < $41;
 $$$i50 = $55 ? $52 : $41;
 $56 = $53 < $42;
 $57 = $56 ? $53 : $42;
 $58 = $54 < $43;
 $$1$i51 = $58 ? $54 : $43;
 $59 = $52 > $41;
 $$$i45 = $59 ? $52 : $41;
 $60 = $53 > $42;
 $61 = $60 ? $53 : $42;
 $62 = $54 > $43;
 $$1$i = $62 ? $54 : $43;
 $63 = $57 > $$1$i51;
 $$$i34 = $63 ? $57 : $$1$i51;
 $64 = $$$i50 > $$$i34;
 $$$i29 = $64 ? $$$i50 : $$$i34;
 $65 = $61 > $$1$i;
 $$$i18 = $65 ? $$1$i : $61;
 $66 = $$$i45 > $$$i18;
 $$$i13 = $66 ? $$$i18 : $$$i45;
 $67 = $$$i29 > Math_fround(0.0);
 $$$i8 = $67 ? $$$i29 : Math_fround(0.0);
 HEAPF32[$tnear>>2] = $$$i8;
 $68 = (($tnear) + 4|0);
 ;HEAP32[$68+0>>2]=HEAP32[$$sroa$189+0>>2]|0;HEAP32[$68+4>>2]=HEAP32[$$sroa$189+4>>2]|0;HEAP32[$68+8>>2]=HEAP32[$$sroa$189+8>>2]|0;
 $69 = Math_fround(HEAPF32[$maxDist>>2]);
 $70 = $$$i13 > $69;
 $$$i = $70 ? $69 : $$$i13;
 HEAPF32[$tfar>>2] = $$$i;
 $71 = (($tfar) + 4|0);
 ;HEAP32[$71+0>>2]=HEAP32[$$sroa$187+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$$sroa$187+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$$sroa$187+8>>2]|0;
 $72 = Math_fround(HEAPF32[$tnear>>2]);
 $73 = $$$i > $72;
 STACKTOP = sp;return ($73|0);
}
function __ZN5physx2Gu19intersectRayCapsuleERKNS_6PxVec3ES3_RKNS0_7CapsuleEPf($origin,$dir,$capsule,$s) {
 $origin = $origin|0;
 $dir = $dir|0;
 $capsule = $capsule|0;
 $s = $s|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0;
 var $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = Math_fround(0);
 var $223 = 0, $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i8 = Math_fround(0), $fabsf$i$i9 = Math_fround(0), $iQuantity$0 = 0, $iQuantity$2 = 0, $iQuantity$3 = 0, $iQuantity$4 = 0, $iQuantity$5 = 0, $iQuantity$6 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($capsule) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$capsule>>2]);
 $3 = Math_fround($1 - $2);
 $4 = (($capsule) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($capsule) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($capsule) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($capsule) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = Math_fround($3 * $3);
 $15 = Math_fround($8 * $8);
 $16 = Math_fround($14 + $15);
 $17 = Math_fround($13 * $13);
 $18 = Math_fround($16 + $17);
 $19 = (Math_fround(Math_sqrt((Math_fround($18)))));
 $20 = $19 > Math_fround(0.0);
 if ($20) {
  $21 = Math_fround(Math_fround(1.0) / $19);
  $22 = Math_fround($3 * $21);
  $23 = Math_fround($8 * $21);
  $24 = Math_fround($13 * $21);
  $55 = $22;$56 = $23;$60 = $24;
 } else {
  $55 = $3;$56 = $8;$60 = $13;
 }
 $25 = !($19 <= Math_fround(9.99999997475242707878E-7));
 if (!($25)) {
  $26 = Math_fround(HEAPF32[$origin>>2]);
  $27 = Math_fround($26 - $2);
  $28 = (($origin) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($29 - $7);
  $31 = (($origin) + 8|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($32 - $12);
  $34 = Math_fround($27 * $27);
  $35 = Math_fround($30 * $30);
  $36 = Math_fround($34 + $35);
  $37 = Math_fround($33 * $33);
  $38 = Math_fround($36 + $37);
  $39 = Math_fround($26 - $1);
  $40 = Math_fround($29 - $5);
  $41 = Math_fround($32 - $10);
  $42 = Math_fround($39 * $39);
  $43 = Math_fround($40 * $40);
  $44 = Math_fround($42 + $43);
  $45 = Math_fround($41 * $41);
  $46 = Math_fround($44 + $45);
  $47 = $38 > $46;
  $48 = $47 ? $38 : $46;
  $49 = (($capsule) + 24|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($50 + $48);
  $52 = Math_fround($51 * Math_fround(2.0));
  $53 = (__ZN5physx2Gu18intersectRaySphereERKNS_6PxVec3ES3_fS3_fRfPS1_($origin,$dir,$52,$capsule,$50,$s,0)|0);
  $54 = $53&1;
  $$0 = $54;
  STACKTOP = sp;return ($$0|0);
 }
 do {
  if ($20) {
   $fabsf$i$i8 = (Math_fround(Math_abs((Math_fround($55)))));
   $fabsf$i$i9 = (Math_fround(Math_abs((Math_fround($56)))));
   $57 = !($fabsf$i$i8 >= $fabsf$i$i9);
   if ($57) {
    $67 = Math_fround($56 * $56);
    $68 = Math_fround($60 * $60);
    $69 = Math_fround($68 + $67);
    $70 = (Math_fround(Math_sqrt((Math_fround($69)))));
    $71 = Math_fround(Math_fround(1.0) / $70);
    $72 = Math_fround($60 * $71);
    $73 = Math_fround($56 * $71);
    $74 = Math_fround(-$73);
    $76 = $74;$78 = $72;$81 = Math_fround(0.0);
    break;
   } else {
    $58 = Math_fround($55 * $55);
    $59 = Math_fround($60 * $60);
    $61 = Math_fround($59 + $58);
    $62 = (Math_fround(Math_sqrt((Math_fround($61)))));
    $63 = Math_fround(Math_fround(1.0) / $62);
    $64 = Math_fround($60 * $63);
    $65 = Math_fround(-$64);
    $66 = Math_fround($55 * $63);
    $76 = $66;$78 = Math_fround(0.0);$81 = $65;
    break;
   }
  } else {
   $76 = Math_fround(0.0);$78 = Math_fround(0.0);$81 = Math_fround(0.0);
  }
 } while(0);
 $75 = Math_fround($56 * $76);
 $77 = Math_fround($60 * $78);
 $79 = Math_fround($75 - $77);
 $80 = Math_fround($60 * $81);
 $82 = Math_fround($55 * $76);
 $83 = Math_fround($80 - $82);
 $84 = Math_fround($55 * $78);
 $85 = Math_fround($56 * $81);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($79 * $79);
 $88 = Math_fround($83 * $83);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($86 * $86);
 $91 = Math_fround($90 + $89);
 $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
 $93 = $92 > Math_fround(0.0);
 if ($93) {
  $94 = Math_fround(Math_fround(1.0) / $92);
  $95 = Math_fround($79 * $94);
  $96 = Math_fround($83 * $94);
  $97 = Math_fround($86 * $94);
  $109 = $95;$111 = $96;$114 = $97;
 } else {
  $109 = $79;$111 = $83;$114 = $86;
 }
 $98 = Math_fround(HEAPF32[$dir>>2]);
 $99 = Math_fround($81 * $98);
 $100 = (($dir) + 4|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($78 * $101);
 $103 = Math_fround($99 + $102);
 $104 = (($dir) + 8|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($76 * $105);
 $107 = Math_fround($103 + $106);
 $108 = Math_fround($109 * $98);
 $110 = Math_fround($111 * $101);
 $112 = Math_fround($108 + $110);
 $113 = Math_fround($114 * $105);
 $115 = Math_fround($112 + $113);
 $116 = Math_fround($55 * $98);
 $117 = Math_fround($56 * $101);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($60 * $105);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($107 * $107);
 $122 = Math_fround($115 * $115);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($120 * $120);
 $125 = Math_fround($124 + $123);
 $126 = (Math_fround(Math_sqrt((Math_fround($125)))));
 $127 = $126 > Math_fround(0.0);
 $128 = Math_fround(Math_fround(1.0) / $126);
 if ($127) {
  $129 = Math_fround($107 * $128);
  $130 = Math_fround($115 * $128);
  $131 = Math_fround($120 * $128);
  $158 = $131;$190 = $129;$192 = $130;
 } else {
  $158 = $120;$190 = $107;$192 = $115;
 }
 $132 = Math_fround(HEAPF32[$origin>>2]);
 $133 = Math_fround($132 - $2);
 $134 = (($origin) + 4|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($135 - $7);
 $137 = (($origin) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($138 - $12);
 $140 = Math_fround($81 * $133);
 $141 = Math_fround($78 * $136);
 $142 = Math_fround($140 + $141);
 $143 = Math_fround($76 * $139);
 $144 = Math_fround($142 + $143);
 $145 = Math_fround($109 * $133);
 $146 = Math_fround($111 * $136);
 $147 = Math_fround($145 + $146);
 $148 = Math_fround($114 * $139);
 $149 = Math_fround($147 + $148);
 $150 = Math_fround($55 * $133);
 $151 = Math_fround($56 * $136);
 $152 = Math_fround($150 + $151);
 $153 = Math_fround($60 * $139);
 $154 = Math_fround($152 + $153);
 $155 = (($capsule) + 24|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = Math_fround($156 * $156);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($158)))));
 $159 = $fabsf$i$i >= Math_fround(0.999999880790710449218);
 $160 = $126 < Math_fround(1.1920928955078125E-7);
 $or$cond = $159 | $160;
 if ($or$cond) {
  $161 = Math_fround($3 * $98);
  $162 = Math_fround($8 * $101);
  $163 = Math_fround($161 + $162);
  $164 = Math_fround($13 * $105);
  $165 = Math_fround($163 + $164);
  $166 = Math_fround($144 * $144);
  $167 = Math_fround($157 - $166);
  $168 = Math_fround($149 * $149);
  $169 = Math_fround($167 - $168);
  $170 = !($165 < Math_fround(0.0));
  $171 = !($169 >= Math_fround(0.0));
  $or$cond1 = $170 | $171;
  if (!($or$cond1)) {
   $172 = (Math_fround(Math_sqrt((Math_fround($169)))));
   $173 = Math_fround($154 + $172);
   $174 = Math_fround($128 * $173);
   HEAPF32[$s>>2] = $174;
   $175 = Math_fround($19 - $154);
   $176 = Math_fround($175 + $172);
   $177 = Math_fround($128 * $176);
   $178 = Math_fround(-$177);
   $179 = (($s) + 4|0);
   HEAPF32[$179>>2] = $178;
   $$0 = 2;
   STACKTOP = sp;return ($$0|0);
  }
  $180 = !($165 > Math_fround(0.0));
  $or$cond2 = $180 | $171;
  if ($or$cond2) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $181 = (Math_fround(Math_sqrt((Math_fround($169)))));
  $182 = Math_fround($154 + $181);
  $183 = Math_fround($128 * $182);
  $184 = Math_fround(-$183);
  HEAPF32[$s>>2] = $184;
  $185 = Math_fround($19 - $154);
  $186 = Math_fround($185 + $181);
  $187 = Math_fround($128 * $186);
  $188 = (($s) + 4|0);
  HEAPF32[$188>>2] = $187;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $189 = Math_fround($190 * $190);
 $191 = Math_fround($192 * $192);
 $193 = Math_fround($191 + $189);
 $194 = Math_fround($190 * $144);
 $195 = Math_fround($192 * $149);
 $196 = Math_fround($194 + $195);
 $197 = Math_fround($144 * $144);
 $198 = Math_fround($149 * $149);
 $199 = Math_fround($197 + $198);
 $200 = Math_fround($199 - $157);
 $201 = Math_fround($196 * $196);
 $202 = Math_fround($193 * $200);
 $203 = Math_fround($201 - $202);
 $204 = $203 < Math_fround(0.0);
 if ($204) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $205 = $203 > Math_fround(0.0);
 if ($205) {
  $206 = (Math_fround(Math_sqrt((Math_fround($203)))));
  $207 = Math_fround(Math_fround(1.0) / $193);
  $208 = Math_fround(-$196);
  $209 = Math_fround($208 - $206);
  $210 = Math_fround($209 * $207);
  $211 = Math_fround($158 * $210);
  $212 = Math_fround($154 + $211);
  $213 = !($212 >= Math_fround(0.0));
  $214 = !($212 <= $19);
  $or$cond3 = $213 | $214;
  if ($or$cond3) {
   $iQuantity$0 = 0;
  } else {
   $215 = Math_fround($128 * $210);
   HEAPF32[$s>>2] = $215;
   $iQuantity$0 = 1;
  }
  $216 = Math_fround($206 - $196);
  $217 = Math_fround($216 * $207);
  $218 = Math_fround($158 * $217);
  $219 = Math_fround($154 + $218);
  $220 = !($219 >= Math_fround(0.0));
  $221 = !($219 <= $19);
  $or$cond4 = $220 | $221;
  if ($or$cond4) {
   $iQuantity$2 = $iQuantity$0;
  } else {
   $222 = Math_fround($128 * $217);
   $223 = (($iQuantity$0) + 1)|0;
   $224 = (($s) + ($iQuantity$0<<2)|0);
   HEAPF32[$224>>2] = $222;
   $225 = ($223|0)==(2);
   if ($225) {
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   } else {
    $iQuantity$2 = $223;
   }
  }
 } else {
  $226 = Math_fround(-$196);
  $227 = Math_fround($226 / $193);
  $228 = Math_fround($158 * $227);
  $229 = Math_fround($154 + $228);
  $230 = !($229 >= Math_fround(0.0));
  $231 = !($229 <= $19);
  $or$cond5 = $230 | $231;
  if ($or$cond5) {
   $iQuantity$2 = 0;
  } else {
   $232 = Math_fround($128 * $227);
   HEAPF32[$s>>2] = $232;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $233 = Math_fround($158 * $154);
 $234 = Math_fround($233 + $196);
 $235 = Math_fround($154 * $154);
 $236 = Math_fround($235 + $200);
 $237 = Math_fround($234 * $234);
 $238 = Math_fround($237 - $236);
 $239 = $238 > Math_fround(0.0);
 if ($239) {
  $240 = (Math_fround(Math_sqrt((Math_fround($238)))));
  $241 = Math_fround(-$234);
  $242 = Math_fround($241 - $240);
  $243 = Math_fround($158 * $242);
  $244 = Math_fround($154 + $243);
  $245 = !($244 <= Math_fround(0.0));
  if ($245) {
   $iQuantity$3 = $iQuantity$2;
  } else {
   $246 = Math_fround($128 * $242);
   $247 = (($iQuantity$2) + 1)|0;
   $248 = (($s) + ($iQuantity$2<<2)|0);
   HEAPF32[$248>>2] = $246;
   $249 = ($247|0)==(2);
   if ($249) {
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   } else {
    $iQuantity$3 = $247;
   }
  }
  $250 = Math_fround($240 - $234);
  $251 = Math_fround($158 * $250);
  $252 = Math_fround($154 + $251);
  $253 = !($252 <= Math_fround(0.0));
  if ($253) {
   $iQuantity$4 = $iQuantity$3;
  } else {
   $254 = Math_fround($128 * $250);
   $255 = (($iQuantity$3) + 1)|0;
   $256 = (($s) + ($iQuantity$3<<2)|0);
   HEAPF32[$256>>2] = $254;
   $257 = ($255|0)==(2);
   if ($257) {
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   } else {
    $iQuantity$4 = $255;
   }
  }
 } else {
  $258 = $238 == Math_fround(0.0);
  if ($258) {
   $259 = Math_fround(-$234);
   $260 = Math_fround($158 * $259);
   $261 = Math_fround($154 + $260);
   $262 = !($261 <= Math_fround(0.0));
   if ($262) {
    $iQuantity$4 = $iQuantity$2;
   } else {
    $263 = Math_fround($128 * $259);
    $264 = (($iQuantity$2) + 1)|0;
    $265 = (($s) + ($iQuantity$2<<2)|0);
    HEAPF32[$265>>2] = $263;
    $266 = ($264|0)==(2);
    if ($266) {
     $$0 = 2;
     STACKTOP = sp;return ($$0|0);
    } else {
     $iQuantity$4 = $264;
    }
   }
  } else {
   $iQuantity$4 = $iQuantity$2;
  }
 }
 $267 = Math_fround($19 * $158);
 $268 = Math_fround($234 - $267);
 $269 = Math_fround($154 * Math_fround(2.0));
 $270 = Math_fround($19 - $269);
 $271 = Math_fround($19 * $270);
 $272 = Math_fround($271 + $236);
 $273 = Math_fround($268 * $268);
 $274 = Math_fround($273 - $272);
 $275 = $274 > Math_fround(0.0);
 if ($275) {
  $276 = (Math_fround(Math_sqrt((Math_fround($274)))));
  $277 = Math_fround(-$268);
  $278 = Math_fround($277 - $276);
  $279 = Math_fround($158 * $278);
  $280 = Math_fround($154 + $279);
  $281 = !($280 >= $19);
  if ($281) {
   $iQuantity$5 = $iQuantity$4;
  } else {
   $282 = Math_fround($128 * $278);
   $283 = (($iQuantity$4) + 1)|0;
   $284 = (($s) + ($iQuantity$4<<2)|0);
   HEAPF32[$284>>2] = $282;
   $285 = ($283|0)==(2);
   if ($285) {
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   } else {
    $iQuantity$5 = $283;
   }
  }
  $286 = Math_fround($276 - $268);
  $287 = Math_fround($158 * $286);
  $288 = Math_fround($154 + $287);
  $289 = !($288 >= $19);
  if ($289) {
   $iQuantity$6 = $iQuantity$5;
  } else {
   $290 = Math_fround($128 * $286);
   $291 = (($iQuantity$5) + 1)|0;
   $292 = (($s) + ($iQuantity$5<<2)|0);
   HEAPF32[$292>>2] = $290;
   $293 = ($291|0)==(2);
   if ($293) {
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   } else {
    $iQuantity$6 = $291;
   }
  }
 } else {
  $294 = $274 == Math_fround(0.0);
  if ($294) {
   $295 = Math_fround(-$268);
   $296 = Math_fround($158 * $295);
   $297 = Math_fround($154 + $296);
   $298 = !($297 >= $19);
   if ($298) {
    $iQuantity$6 = $iQuantity$4;
   } else {
    $299 = Math_fround($128 * $295);
    $300 = (($iQuantity$4) + 1)|0;
    $301 = (($s) + ($iQuantity$4<<2)|0);
    HEAPF32[$301>>2] = $299;
    $302 = ($300|0)==(2);
    if ($302) {
     $$0 = 2;
     STACKTOP = sp;return ($$0|0);
    } else {
     $iQuantity$6 = $300;
    }
   }
  } else {
   $iQuantity$6 = $iQuantity$4;
  }
 }
 $$0 = $iQuantity$6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18intersectRaySphereERKNS_6PxVec3ES3_fS3_fRfPS1_($origin,$dir,$length,$center,$radius,$dist,$hit_pos) {
 $origin = $origin|0;
 $dir = $dir|0;
 $length = Math_fround($length);
 $center = $center|0;
 $radius = Math_fround($radius);
 $dist = $dist|0;
 $hit_pos = $hit_pos|0;
 var $$0$i6 = 0, $$pre = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $dir$idx$val = Math_fround(0), $dir$idx1 = 0, $dir$idx1$val = Math_fround(0), $dir$idx2 = 0, $dir$idx2$val = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$origin>>2]);
 $1 = Math_fround(HEAPF32[$center>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($origin) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($center) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($origin) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($center) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround($2 * $2);
 $14 = Math_fround($7 * $7);
 $15 = Math_fround($13 + $14);
 $16 = Math_fround($12 * $12);
 $17 = Math_fround($15 + $16);
 $18 = (Math_fround(Math_sqrt((Math_fround($17)))));
 $19 = Math_fround($18 - $radius);
 $20 = Math_fround($19 + Math_fround(-10.0));
 $21 = $20 > Math_fround(0.0);
 $22 = $21 ? $20 : Math_fround(0.0);
 $dir$idx$val = Math_fround(HEAPF32[$dir>>2]);
 $dir$idx1 = (($dir) + 4|0);
 $dir$idx1$val = Math_fround(HEAPF32[$dir$idx1>>2]);
 $dir$idx2 = (($dir) + 8|0);
 $dir$idx2$val = Math_fround(HEAPF32[$dir$idx2>>2]);
 $23 = Math_fround($dir$idx$val * $22);
 $24 = Math_fround($dir$idx1$val * $22);
 $25 = Math_fround($dir$idx2$val * $22);
 $26 = Math_fround($0 + $23);
 $27 = Math_fround($4 + $24);
 $28 = Math_fround($9 + $25);
 $29 = Math_fround($length - $22);
 $30 = Math_fround($1 - $26);
 $31 = Math_fround($6 - $27);
 $32 = Math_fround($11 - $28);
 $33 = Math_fround($dir$idx$val * $30);
 $34 = Math_fround($dir$idx1$val * $31);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($dir$idx2$val * $32);
 $37 = Math_fround($36 + $35);
 $38 = Math_fround($30 * $30);
 $39 = Math_fround($31 * $31);
 $40 = Math_fround($38 + $39);
 $41 = Math_fround($32 * $32);
 $42 = Math_fround($41 + $40);
 $43 = Math_fround($radius * $radius);
 $44 = !($42 <= $43);
 if ($44) {
  $48 = !($37 <= Math_fround(0.0));
  if (!($48)) {
   $$0$i6 = 0;
   STACKTOP = sp;return ($$0$i6|0);
  }
  $49 = Math_fround($37 - $29);
  $50 = $49 > $radius;
  if ($50) {
   $$0$i6 = 0;
   STACKTOP = sp;return ($$0$i6|0);
  }
  $51 = Math_fround($37 * $37);
  $52 = Math_fround($42 - $51);
  $53 = Math_fround($43 - $52);
  $54 = $53 < Math_fround(0.0);
  if ($54) {
   $$0$i6 = 0;
   STACKTOP = sp;return ($$0$i6|0);
  }
  $55 = (Math_fround(Math_sqrt((Math_fround($53)))));
  $56 = Math_fround($37 - $55);
  HEAPF32[$dist>>2] = $56;
  $57 = $56 > $29;
  if ($57) {
   $$0$i6 = 0;
   STACKTOP = sp;return ($$0$i6|0);
  }
  $58 = ($hit_pos|0)==(0|0);
  if ($58) {
   $71 = $56;
  } else {
   $59 = Math_fround(HEAPF32[$dir>>2]);
   $60 = Math_fround($56 * $59);
   $61 = Math_fround(HEAPF32[$dir$idx1>>2]);
   $62 = Math_fround($56 * $61);
   $63 = Math_fround(HEAPF32[$dir$idx2>>2]);
   $64 = Math_fround($56 * $63);
   $65 = Math_fround($26 + $60);
   $66 = Math_fround($27 + $62);
   $67 = Math_fround($28 + $64);
   HEAPF32[$hit_pos>>2] = $65;
   $68 = (($hit_pos) + 4|0);
   HEAPF32[$68>>2] = $66;
   $69 = (($hit_pos) + 8|0);
   HEAPF32[$69>>2] = $67;
   $$pre = Math_fround(HEAPF32[$dist>>2]);
   $71 = $$pre;
  }
 } else {
  $45 = ($hit_pos|0)==(0|0);
  if (!($45)) {
   HEAPF32[$hit_pos>>2] = $26;
   $46 = (($hit_pos) + 4|0);
   HEAPF32[$46>>2] = $27;
   $47 = (($hit_pos) + 8|0);
   HEAPF32[$47>>2] = $28;
  }
  HEAPF32[$dist>>2] = Math_fround(0.0);
  $71 = Math_fround(0.0);
 }
 $70 = Math_fround($22 + $71);
 HEAPF32[$dist>>2] = $70;
 $$0$i6 = 1;
 STACKTOP = sp;return ($$0$i6|0);
}
function __ZN5physx2Gu27intersectRayTriangleCullingERKNS_6PxVec3ES3_S3_S3_S3_RfS4_S4_f($orig,$dir,$vert0,$vert1,$vert2,$t,$u,$v,$enlarge) {
 $orig = $orig|0;
 $dir = $dir|0;
 $vert0 = $vert0|0;
 $vert1 = $vert1|0;
 $vert2 = $vert2|0;
 $t = $t|0;
 $u = $u|0;
 $v = $v|0;
 $enlarge = Math_fround($enlarge);
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$vert1>>2]);
 $1 = Math_fround(HEAPF32[$vert0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($vert1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($vert0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($vert1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($vert0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$vert2>>2]);
 $14 = Math_fround($13 - $1);
 $15 = (($vert2) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 - $6);
 $18 = (($vert2) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 - $11);
 $21 = (($dir) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $20);
 $24 = (($dir) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($17 * $25);
 $27 = Math_fround($23 - $26);
 $28 = Math_fround($14 * $25);
 $29 = Math_fround(HEAPF32[$dir>>2]);
 $30 = Math_fround($20 * $29);
 $31 = Math_fround($28 - $30);
 $32 = Math_fround($17 * $29);
 $33 = Math_fround($14 * $22);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($2 * $27);
 $36 = Math_fround($7 * $31);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($12 * $34);
 $39 = Math_fround($38 + $37);
 $40 = $39 < Math_fround(9.99999997475242707878E-7);
 if ($40) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = Math_fround(HEAPF32[$orig>>2]);
 $42 = Math_fround($41 - $1);
 $43 = (($orig) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 - $6);
 $46 = (($orig) + 8|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 - $11);
 $49 = Math_fround($27 * $42);
 $50 = Math_fround($31 * $45);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($34 * $48);
 $53 = Math_fround($51 + $52);
 HEAPF32[$u>>2] = $53;
 $54 = Math_fround(-$enlarge);
 $55 = $53 < $54;
 if ($55) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $56 = Math_fround($39 + $enlarge);
 $57 = $53 > $56;
 if ($57) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $58 = Math_fround($12 * $45);
 $59 = Math_fround($7 * $48);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($2 * $48);
 $62 = Math_fround($12 * $42);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($7 * $42);
 $65 = Math_fround($2 * $45);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround(HEAPF32[$dir>>2]);
 $68 = Math_fround($60 * $67);
 $69 = Math_fround(HEAPF32[$21>>2]);
 $70 = Math_fround($63 * $69);
 $71 = Math_fround($68 + $70);
 $72 = Math_fround(HEAPF32[$24>>2]);
 $73 = Math_fround($66 * $72);
 $74 = Math_fround($71 + $73);
 HEAPF32[$v>>2] = $74;
 $75 = $74 < $54;
 if ($75) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $76 = Math_fround(HEAPF32[$u>>2]);
 $77 = Math_fround($74 + $76);
 $78 = $77 > $56;
 if ($78) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $79 = Math_fround($14 * $60);
 $80 = Math_fround($17 * $63);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($20 * $66);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround(Math_fround(1.0) / $39);
 $85 = Math_fround($83 * $84);
 HEAPF32[$t>>2] = $85;
 $86 = Math_fround(HEAPF32[$u>>2]);
 $87 = Math_fround($84 * $86);
 HEAPF32[$u>>2] = $87;
 $88 = Math_fround(HEAPF32[$v>>2]);
 $89 = Math_fround($84 * $88);
 HEAPF32[$v>>2] = $89;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu29intersectRayTriangleNoCullingERKNS_6PxVec3ES3_S3_S3_S3_RfS4_S4_f($orig,$dir,$vert0,$vert1,$vert2,$t,$u,$v,$enlarge) {
 $orig = $orig|0;
 $dir = $dir|0;
 $vert0 = $vert0|0;
 $vert1 = $vert1|0;
 $vert2 = $vert2|0;
 $t = $t|0;
 $u = $u|0;
 $v = $v|0;
 $enlarge = Math_fround($enlarge);
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $9 = Math_fround(0), $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$vert1>>2]);
 $1 = Math_fround(HEAPF32[$vert0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($vert1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($vert0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($vert1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($vert0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$vert2>>2]);
 $14 = Math_fround($13 - $1);
 $15 = (($vert2) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 - $6);
 $18 = (($vert2) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 - $11);
 $21 = (($dir) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $20);
 $24 = (($dir) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($17 * $25);
 $27 = Math_fround($23 - $26);
 $28 = Math_fround($14 * $25);
 $29 = Math_fround(HEAPF32[$dir>>2]);
 $30 = Math_fround($20 * $29);
 $31 = Math_fround($28 - $30);
 $32 = Math_fround($17 * $29);
 $33 = Math_fround($14 * $22);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($2 * $27);
 $36 = Math_fround($7 * $31);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($12 * $34);
 $39 = Math_fround($38 + $37);
 $40 = $39 > Math_fround(-9.99999997475242707878E-7);
 $41 = $39 < Math_fround(9.99999997475242707878E-7);
 $or$cond = $40 & $41;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = Math_fround(Math_fround(1.0) / $39);
 $43 = Math_fround(HEAPF32[$orig>>2]);
 $44 = Math_fround($43 - $1);
 $45 = (($orig) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 - $6);
 $48 = (($orig) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 - $11);
 $51 = Math_fround($27 * $44);
 $52 = Math_fround($31 * $47);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($34 * $50);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($42 * $55);
 HEAPF32[$u>>2] = $56;
 $57 = Math_fround(-$enlarge);
 $58 = $56 < $57;
 if ($58) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $59 = Math_fround($enlarge + Math_fround(1.0));
 $60 = $56 > $59;
 if ($60) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $61 = Math_fround($12 * $47);
 $62 = Math_fround($7 * $50);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($2 * $50);
 $65 = Math_fround($12 * $44);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround($7 * $44);
 $68 = Math_fround($2 * $47);
 $69 = Math_fround($67 - $68);
 $70 = Math_fround(HEAPF32[$dir>>2]);
 $71 = Math_fround($63 * $70);
 $72 = Math_fround(HEAPF32[$21>>2]);
 $73 = Math_fround($66 * $72);
 $74 = Math_fround($71 + $73);
 $75 = Math_fround(HEAPF32[$24>>2]);
 $76 = Math_fround($69 * $75);
 $77 = Math_fround($74 + $76);
 $78 = Math_fround($42 * $77);
 HEAPF32[$v>>2] = $78;
 $79 = $78 < $57;
 if ($79) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $80 = Math_fround(HEAPF32[$u>>2]);
 $81 = Math_fround($78 + $80);
 $82 = $81 > $59;
 if ($82) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $83 = Math_fround($14 * $63);
 $84 = Math_fround($17 * $66);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($20 * $69);
 $87 = Math_fround($86 + $85);
 $88 = Math_fround($42 * $87);
 HEAPF32[$t>>2] = $88;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu20intersectTriangleBoxERKNS_6PxVec3ES3_S3_S3_S3_($boxcenter,$extents,$tp0,$tp1,$tp2) {
 $boxcenter = $boxcenter|0;
 $extents = $extents|0;
 $tp0 = $tp0|0;
 $tp1 = $tp1|0;
 $tp2 = $tp2|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$1$i = Math_fround(0), $$2$i = Math_fround(0), $$3$i = Math_fround(0), $$4$i = Math_fround(0), $$5$i = Math_fround(0), $$6$i = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0;
 var $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0;
 var $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0;
 var $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0);
 var $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i26 = Math_fround(0), $fabsf$i$i27 = Math_fround(0), $fabsf$i$i28 = Math_fround(0), $fabsf$i$i29 = Math_fround(0), $fabsf$i$i30 = Math_fround(0), $fabsf$i$i31 = Math_fround(0), $fabsf$i$i32 = Math_fround(0), $fabsf$i$i33 = Math_fround(0), $or$cond = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond15 = 0, $or$cond17 = 0, $or$cond19 = 0, $or$cond21 = 0, $or$cond23 = 0;
 var $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$tp0>>2]);
 $1 = Math_fround(HEAPF32[$boxcenter>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($tp0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($boxcenter) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($tp0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($boxcenter) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$tp1>>2]);
 $14 = Math_fround($13 - $1);
 $15 = (($tp1) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 - $6);
 $18 = (($tp1) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 - $11);
 $21 = Math_fround(HEAPF32[$tp2>>2]);
 $22 = Math_fround($21 - $1);
 $23 = (($tp2) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 - $6);
 $26 = (($tp2) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 - $11);
 $29 = Math_fround($14 - $2);
 $30 = Math_fround($17 - $7);
 $31 = Math_fround($20 - $12);
 $32 = Math_fround($22 - $14);
 $33 = Math_fround($25 - $17);
 $34 = Math_fround($28 - $20);
 $35 = Math_fround($2 - $22);
 $36 = Math_fround($7 - $25);
 $37 = Math_fround($12 - $28);
 $fabsf$i$i31 = (Math_fround(Math_abs((Math_fround($29)))));
 $fabsf$i$i32 = (Math_fround(Math_abs((Math_fround($30)))));
 $fabsf$i$i33 = (Math_fround(Math_abs((Math_fround($31)))));
 $38 = Math_fround($7 * $31);
 $39 = Math_fround($12 * $30);
 $40 = Math_fround($38 - $39);
 $41 = Math_fround($31 * $25);
 $42 = Math_fround($30 * $28);
 $43 = Math_fround($41 - $42);
 $44 = $40 < $43;
 $45 = $44 ? $40 : $43;
 $46 = $40 > $43;
 $47 = $46 ? $40 : $43;
 $48 = (($extents) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($fabsf$i$i33 * $49);
 $51 = (($extents) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($fabsf$i$i32 * $52);
 $54 = Math_fround($50 + $53);
 $55 = $45 > $54;
 $56 = Math_fround(-$54);
 $57 = $47 < $56;
 $or$cond = $55 | $57;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $58 = Math_fround(-$31);
 $59 = Math_fround($2 * $58);
 $60 = Math_fround($12 * $29);
 $61 = Math_fround($60 + $59);
 $62 = Math_fround($22 * $58);
 $63 = Math_fround($29 * $28);
 $64 = Math_fround($62 + $63);
 $65 = $61 < $64;
 $66 = $65 ? $61 : $64;
 $67 = $61 > $64;
 $68 = $67 ? $61 : $64;
 $69 = Math_fround(HEAPF32[$extents>>2]);
 $70 = Math_fround($fabsf$i$i33 * $69);
 $71 = Math_fround($fabsf$i$i31 * $52);
 $72 = Math_fround($71 + $70);
 $73 = $66 > $72;
 $74 = Math_fround(-$72);
 $75 = $68 < $74;
 $or$cond3 = $73 | $75;
 if ($or$cond3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $76 = Math_fround($14 * $30);
 $77 = Math_fround($29 * $17);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($30 * $22);
 $80 = Math_fround($29 * $25);
 $81 = Math_fround($79 - $80);
 $82 = $78 < $81;
 $83 = $82 ? $78 : $81;
 $84 = $78 > $81;
 $85 = $84 ? $78 : $81;
 $86 = Math_fround($fabsf$i$i32 * $69);
 $87 = Math_fround($fabsf$i$i31 * $49);
 $88 = Math_fround($87 + $86);
 $89 = $83 > $88;
 $90 = Math_fround(-$88);
 $91 = $85 < $90;
 $or$cond5 = $89 | $91;
 if ($or$cond5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $fabsf$i$i30 = (Math_fround(Math_abs((Math_fround($32)))));
 $fabsf$i$i29 = (Math_fround(Math_abs((Math_fround($33)))));
 $fabsf$i$i28 = (Math_fround(Math_abs((Math_fround($34)))));
 $92 = Math_fround($7 * $34);
 $93 = Math_fround($12 * $33);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($25 * $34);
 $96 = Math_fround($33 * $28);
 $97 = Math_fround($95 - $96);
 $98 = $94 < $97;
 $99 = $98 ? $94 : $97;
 $100 = $94 > $97;
 $101 = $100 ? $94 : $97;
 $102 = Math_fround($49 * $fabsf$i$i28);
 $103 = Math_fround($52 * $fabsf$i$i29);
 $104 = Math_fround($103 + $102);
 $105 = $99 > $104;
 $106 = Math_fround(-$104);
 $107 = $101 < $106;
 $or$cond7 = $105 | $107;
 if ($or$cond7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $108 = Math_fround(-$34);
 $109 = Math_fround($2 * $108);
 $110 = Math_fround($12 * $32);
 $111 = Math_fround($110 + $109);
 $112 = Math_fround($22 * $108);
 $113 = Math_fround($32 * $28);
 $114 = Math_fround($113 + $112);
 $115 = $111 < $114;
 $116 = $115 ? $111 : $114;
 $117 = $111 > $114;
 $118 = $117 ? $111 : $114;
 $119 = Math_fround($69 * $fabsf$i$i28);
 $120 = Math_fround($52 * $fabsf$i$i30);
 $121 = Math_fround($120 + $119);
 $122 = $116 > $121;
 $123 = Math_fround(-$121);
 $124 = $118 < $123;
 $or$cond9 = $122 | $124;
 if ($or$cond9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $125 = Math_fround($2 * $33);
 $126 = Math_fround($7 * $32);
 $127 = Math_fround($125 - $126);
 $128 = Math_fround($14 * $33);
 $129 = Math_fround($17 * $32);
 $130 = Math_fround($128 - $129);
 $131 = $127 < $130;
 $132 = $131 ? $127 : $130;
 $133 = $127 > $130;
 $134 = $133 ? $127 : $130;
 $135 = Math_fround($69 * $fabsf$i$i29);
 $136 = Math_fround($49 * $fabsf$i$i30);
 $137 = Math_fround($136 + $135);
 $138 = $132 > $137;
 $139 = Math_fround(-$137);
 $140 = $134 < $139;
 $or$cond11 = $138 | $140;
 if ($or$cond11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $fabsf$i$i27 = (Math_fround(Math_abs((Math_fround($35)))));
 $fabsf$i$i26 = (Math_fround(Math_abs((Math_fround($36)))));
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($37)))));
 $141 = Math_fround($7 * $37);
 $142 = Math_fround($12 * $36);
 $143 = Math_fround($141 - $142);
 $144 = Math_fround($17 * $37);
 $145 = Math_fround($20 * $36);
 $146 = Math_fround($144 - $145);
 $147 = $143 < $146;
 $148 = $147 ? $143 : $146;
 $149 = $143 > $146;
 $150 = $149 ? $143 : $146;
 $151 = Math_fround($49 * $fabsf$i$i);
 $152 = Math_fround($52 * $fabsf$i$i26);
 $153 = Math_fround($152 + $151);
 $154 = $148 > $153;
 $155 = Math_fround(-$153);
 $156 = $150 < $155;
 $or$cond13 = $154 | $156;
 if ($or$cond13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $157 = Math_fround(-$37);
 $158 = Math_fround($2 * $157);
 $159 = Math_fround($12 * $35);
 $160 = Math_fround($159 + $158);
 $161 = Math_fround($14 * $157);
 $162 = Math_fround($20 * $35);
 $163 = Math_fround($162 + $161);
 $164 = $160 < $163;
 $165 = $164 ? $160 : $163;
 $166 = $160 > $163;
 $167 = $166 ? $160 : $163;
 $168 = Math_fround($69 * $fabsf$i$i);
 $169 = Math_fround($52 * $fabsf$i$i27);
 $170 = Math_fround($169 + $168);
 $171 = $165 > $170;
 $172 = Math_fround(-$170);
 $173 = $167 < $172;
 $or$cond15 = $171 | $173;
 if ($or$cond15) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $174 = Math_fround($14 * $36);
 $175 = Math_fround($17 * $35);
 $176 = Math_fround($174 - $175);
 $177 = Math_fround($22 * $36);
 $178 = Math_fround($35 * $25);
 $179 = Math_fround($177 - $178);
 $180 = $176 < $179;
 $181 = $180 ? $176 : $179;
 $182 = $176 > $179;
 $183 = $182 ? $176 : $179;
 $184 = Math_fround($69 * $fabsf$i$i26);
 $185 = Math_fround($49 * $fabsf$i$i27);
 $186 = Math_fround($185 + $184);
 $187 = $181 > $186;
 $188 = Math_fround(-$186);
 $189 = $183 < $188;
 $or$cond17 = $187 | $189;
 if ($or$cond17) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $190 = $2 < $14;
 $191 = $190 ? $2 : $14;
 $192 = $2 > $14;
 $193 = $192 ? $2 : $14;
 $194 = $191 < $22;
 $195 = $194 ? $191 : $22;
 $196 = $193 > $22;
 $197 = $196 ? $193 : $22;
 $198 = $195 > $69;
 $199 = Math_fround(-$69);
 $200 = $197 < $199;
 $or$cond19 = $198 | $200;
 if ($or$cond19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $201 = $7 < $17;
 $202 = $201 ? $7 : $17;
 $203 = $7 > $17;
 $204 = $203 ? $7 : $17;
 $205 = $202 < $25;
 $206 = $205 ? $202 : $25;
 $207 = $204 > $25;
 $208 = $207 ? $204 : $25;
 $209 = $206 > $49;
 $210 = Math_fround(-$49);
 $211 = $208 < $210;
 $or$cond21 = $209 | $211;
 if ($or$cond21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $212 = $12 < $20;
 $213 = $212 ? $12 : $20;
 $214 = $12 > $20;
 $215 = $214 ? $12 : $20;
 $216 = $213 < $28;
 $217 = $216 ? $213 : $28;
 $218 = $215 > $28;
 $219 = $218 ? $215 : $28;
 $220 = $217 > $52;
 $221 = Math_fround(-$52);
 $222 = $219 < $221;
 $or$cond23 = $220 | $222;
 if ($or$cond23) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $223 = Math_fround($30 * $34);
 $224 = Math_fround($31 * $33);
 $225 = Math_fround($223 - $224);
 $226 = Math_fround($31 * $32);
 $227 = Math_fround($29 * $34);
 $228 = Math_fround($226 - $227);
 $229 = Math_fround($29 * $33);
 $230 = Math_fround($30 * $32);
 $231 = Math_fround($229 - $230);
 $232 = Math_fround($2 * $225);
 $233 = Math_fround($7 * $228);
 $234 = Math_fround($232 + $233);
 $235 = Math_fround($12 * $231);
 $236 = Math_fround($235 + $234);
 $237 = $225 > Math_fround(0.0);
 $$1$i = $237 ? $199 : $69;
 $238 = $228 > Math_fround(0.0);
 $$5$i = $238 ? $210 : $49;
 $239 = $231 > Math_fround(0.0);
 $$3$i = $239 ? $221 : $52;
 $240 = Math_fround($225 * $$1$i);
 $241 = Math_fround($228 * $$5$i);
 $242 = Math_fround($241 + $240);
 $243 = Math_fround($231 * $$3$i);
 $244 = Math_fround($243 + $242);
 $245 = Math_fround($244 - $236);
 $246 = $245 > Math_fround(0.0);
 if ($246) {
  $$0$i = 1;
 } else {
  $$4$i = $239 ? $52 : $221;
  $$6$i = $238 ? $49 : $210;
  $$2$i = $237 ? $69 : $199;
  $247 = Math_fround($225 * $$2$i);
  $248 = Math_fround($228 * $$6$i);
  $249 = Math_fround($248 + $247);
  $250 = Math_fround($231 * $$4$i);
  $251 = Math_fround($250 + $249);
  $252 = Math_fround($251 - $236);
  $phitmp = !($252 >= Math_fround(0.0));
  $$0$i = $phitmp;
 }
 $253 = $$0$i&1;
 $$ = $253 ^ 1;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu20intersectTriangleBoxERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_($boxCenter,$extents,$tp0,$tp1,$tp2) {
 $boxCenter = $boxCenter|0;
 $extents = $extents|0;
 $tp0 = $tp0|0;
 $tp1 = $tp1|0;
 $tp2 = $tp2|0;
 var $$ = 0, $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i148 = Math_fround(0), $$$i$i164 = Math_fround(0), $$$i$i211 = Math_fround(0), $$$i$i227 = Math_fround(0), $$$i$i243 = Math_fround(0), $$$i118 = Math_fround(0), $$$i124 = Math_fround(0), $$$i195 = Math_fround(0), $$$i201 = Math_fround(0), $$$i274 = Math_fround(0), $$$i280 = Math_fround(0), $$$i83 = Math_fround(0), $$$i89 = Math_fround(0), $$$i95 = Math_fround(0), $$0 = 0, $$1$i = Math_fround(0), $$1$i$i212 = Math_fround(0);
 var $$1$i$i228 = Math_fround(0), $$1$i$i244 = Math_fround(0), $$1$i$i291 = Math_fround(0), $$1$i$i307 = Math_fround(0), $$1$i$i323 = Math_fround(0), $$1$i119 = Math_fround(0), $$1$i125 = Math_fround(0), $$1$i196 = Math_fround(0), $$1$i202 = Math_fround(0), $$1$i275 = Math_fround(0), $$1$i281 = Math_fround(0), $$1$i84 = Math_fround(0), $$1$i90 = Math_fround(0), $$1$i96 = Math_fround(0), $$1712 = 0, $$1713 = 0, $$1714 = 0, $$1715 = 0, $$1716 = 0, $$1717 = 0;
 var $$1718 = 0, $$in1$i = 0, $$in1$i43 = 0, $$in2$i = 0, $$in2$i45 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0);
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0;
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn3$i = 0, $a$pn3$i42 = 0, $b$a$i = 0, $b$a$i40 = 0, $b$a5$i = 0, $b$a5$i44 = 0, $not$ = 0, $not$1719 = 0, $not$1720 = 0, $not$1722 = 0, $not$1723 = 0, $not$1724 = 0, $not$1726 = 0;
 var $not$1727 = 0, $not$1728 = 0, $not$1730 = 0, $not$1731 = 0, $not$1732 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = Math_fround(HEAPF32[$extents>>2]);
 $5 = (($extents) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($extents) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$4);
 $10 = Math_fround(-$6);
 $11 = Math_fround(-$8);
 $12 = Math_fround(HEAPF32[$tp0>>2]);
 $13 = (($tp0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($tp0) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$boxCenter>>2]);
 $18 = (($boxCenter) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($boxCenter) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($12 - $17);
 $23 = Math_fround($14 - $19);
 $24 = Math_fround($16 - $21);
 $25 = Math_fround(HEAPF32[$tp1>>2]);
 $26 = (($tp1) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($tp1) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($25 - $17);
 $31 = Math_fround($27 - $19);
 $32 = Math_fround($29 - $21);
 $33 = Math_fround(HEAPF32[$tp2>>2]);
 $34 = (($tp2) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($tp2) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($33 - $17);
 $39 = Math_fround($35 - $19);
 $40 = Math_fround($37 - $21);
 $41 = Math_fround($30 - $22);
 $42 = Math_fround($31 - $23);
 $43 = Math_fround($32 - $24);
 $44 = Math_fround($38 - $30);
 $45 = Math_fround($39 - $31);
 $46 = Math_fround($40 - $32);
 $47 = Math_fround($22 - $38);
 $48 = Math_fround($23 - $39);
 $49 = Math_fround($24 - $40);
 $50 = Math_fround(-$43);
 $51 = Math_fround(-$46);
 $52 = Math_fround(-$49);
 $53 = Math_fround(-$41);
 $54 = Math_fround(-$44);
 $55 = Math_fround(-$47);
 $56 = Math_fround(-$42);
 $57 = Math_fround(-$45);
 $58 = Math_fround(-$48);
 $59 = Math_fround($22 * Math_fround(0.0));
 $60 = Math_fround($23 * $50);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($24 * $42);
 $63 = Math_fround($62 + $61);
 $64 = Math_fround($38 * Math_fround(0.0));
 $65 = Math_fround($39 * $50);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($42 * $40);
 $68 = Math_fround($66 + $67);
 $69 = $43 < $50;
 $70 = $69 ? $50 : $43;
 $71 = $42 > $56;
 $$1$i$i323 = $71 ? $42 : $56;
 $72 = Math_fround($4 * Math_fround(-0.0));
 $73 = Math_fround($70 * $6);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($$1$i$i323 * $8);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($23 * $51);
 $78 = Math_fround($59 + $77);
 $79 = Math_fround($24 * $45);
 $80 = Math_fround($79 + $78);
 $81 = Math_fround($30 * Math_fround(0.0));
 $82 = Math_fround($31 * $51);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($32 * $45);
 $85 = Math_fround($84 + $83);
 $86 = $46 < $51;
 $87 = $86 ? $51 : $46;
 $88 = $45 > $57;
 $$1$i$i307 = $88 ? $45 : $57;
 $89 = Math_fround($6 * $87);
 $90 = Math_fround($72 + $89);
 $91 = Math_fround($8 * $$1$i$i307);
 $92 = Math_fround($91 + $90);
 $93 = Math_fround($23 * $52);
 $94 = Math_fround($59 + $93);
 $95 = Math_fround($24 * $48);
 $96 = Math_fround($95 + $94);
 $97 = Math_fround($31 * $52);
 $98 = Math_fround($81 + $97);
 $99 = Math_fround($32 * $48);
 $100 = Math_fround($99 + $98);
 $101 = $49 < $52;
 $102 = $101 ? $52 : $49;
 $103 = $48 > $58;
 $$1$i$i291 = $103 ? $48 : $58;
 $104 = Math_fround($6 * $102);
 $105 = Math_fround($72 + $104);
 $106 = Math_fround($8 * $$1$i$i291);
 $107 = Math_fround($106 + $105);
 $108 = Math_fround(-$76);
 $109 = Math_fround(-$92);
 $110 = Math_fround(-$107);
 $111 = $63 < $68;
 $$$i280 = $111 ? $63 : $68;
 $112 = $80 < $85;
 $113 = $112 ? $80 : $85;
 $114 = $96 < $100;
 $$1$i281 = $114 ? $96 : $100;
 $115 = $63 > $68;
 $$$i274 = $115 ? $63 : $68;
 $116 = $80 > $85;
 $117 = $116 ? $80 : $85;
 $118 = $96 > $100;
 $$1$i275 = $118 ? $96 : $100;
 $119 = $$$i274 < $108;
 $120 = $117 < $109;
 $121 = $$1$i275 < $110;
 $not$ = $$$i280 > $76;
 $$ = $119 | $not$;
 $not$1719 = $113 > $92;
 $122 = $120 | $not$1719;
 $not$1720 = $$1$i281 > $107;
 $$1712 = $121 | $not$1720;
 $123 = $122 | $$;
 $124 = $123 | $$1712;
 if ($124) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $125 = Math_fround($22 * $43);
 $126 = Math_fround($23 * Math_fround(0.0));
 $127 = Math_fround($126 + $125);
 $128 = Math_fround($24 * $53);
 $129 = Math_fround($128 + $127);
 $130 = Math_fround($43 * $38);
 $131 = Math_fround($39 * Math_fround(0.0));
 $132 = Math_fround($130 + $131);
 $133 = Math_fround($40 * $53);
 $134 = Math_fround($132 + $133);
 $135 = $43 > $50;
 $$$i$i243 = $135 ? $43 : $50;
 $136 = $41 < $53;
 $$1$i$i244 = $136 ? $53 : $41;
 $137 = Math_fround(HEAPF32[$extents>>2]);
 $138 = Math_fround(HEAPF32[$5>>2]);
 $139 = Math_fround(HEAPF32[$7>>2]);
 $140 = Math_fround($$$i$i243 * $137);
 $141 = Math_fround($138 * Math_fround(-0.0));
 $142 = Math_fround($140 + $141);
 $143 = Math_fround($$1$i$i244 * $139);
 $144 = Math_fround($142 + $143);
 $145 = Math_fround($22 * $46);
 $146 = Math_fround($126 + $145);
 $147 = Math_fround($24 * $54);
 $148 = Math_fround($147 + $146);
 $149 = Math_fround($30 * $46);
 $150 = Math_fround($31 * Math_fround(0.0));
 $151 = Math_fround($150 + $149);
 $152 = Math_fround($32 * $54);
 $153 = Math_fround($152 + $151);
 $154 = $46 > $51;
 $$$i$i227 = $154 ? $46 : $51;
 $155 = $44 < $54;
 $$1$i$i228 = $155 ? $54 : $44;
 $156 = Math_fround($$$i$i227 * $137);
 $157 = Math_fround($156 + $141);
 $158 = Math_fround($$1$i$i228 * $139);
 $159 = Math_fround($157 + $158);
 $160 = Math_fround($22 * $49);
 $161 = Math_fround($126 + $160);
 $162 = Math_fround($24 * $55);
 $163 = Math_fround($162 + $161);
 $164 = Math_fround($30 * $49);
 $165 = Math_fround($150 + $164);
 $166 = Math_fround($32 * $55);
 $167 = Math_fround($166 + $165);
 $168 = $49 > $52;
 $$$i$i211 = $168 ? $49 : $52;
 $169 = $47 < $55;
 $$1$i$i212 = $169 ? $55 : $47;
 $170 = Math_fround($$$i$i211 * $137);
 $171 = Math_fround($170 + $141);
 $172 = Math_fround($$1$i$i212 * $139);
 $173 = Math_fround($171 + $172);
 $174 = Math_fround(-$144);
 $175 = Math_fround(-$159);
 $176 = Math_fround(-$173);
 $177 = $129 < $134;
 $$$i201 = $177 ? $129 : $134;
 $178 = $148 < $153;
 $179 = $178 ? $148 : $153;
 $180 = $163 < $167;
 $$1$i202 = $180 ? $163 : $167;
 $181 = $129 > $134;
 $$$i195 = $181 ? $129 : $134;
 $182 = $148 > $153;
 $183 = $182 ? $148 : $153;
 $184 = $163 > $167;
 $$1$i196 = $184 ? $163 : $167;
 $185 = $$$i195 < $174;
 $186 = $183 < $175;
 $187 = $$1$i196 < $176;
 $not$1722 = $$$i201 > $144;
 $$1713 = $185 | $not$1722;
 $not$1723 = $179 > $159;
 $188 = $186 | $not$1723;
 $not$1724 = $$1$i202 > $173;
 $$1714 = $187 | $not$1724;
 $189 = $188 | $$1713;
 $190 = $189 | $$1714;
 if ($190) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $191 = Math_fround($22 * $56);
 $192 = Math_fround($23 * $41);
 $193 = Math_fround($192 + $191);
 $194 = Math_fround($24 * Math_fround(0.0));
 $195 = Math_fround($194 + $193);
 $196 = Math_fround($38 * $56);
 $197 = Math_fround($41 * $39);
 $198 = Math_fround($196 + $197);
 $199 = Math_fround($40 * Math_fround(0.0));
 $200 = Math_fround($198 + $199);
 $201 = $42 < $56;
 $$$i$i164 = $201 ? $56 : $42;
 $202 = $41 > $53;
 $203 = $202 ? $41 : $53;
 $204 = Math_fround($$$i$i164 * $137);
 $205 = Math_fround($203 * $138);
 $206 = Math_fround($204 + $205);
 $207 = Math_fround($139 * Math_fround(-0.0));
 $208 = Math_fround($206 + $207);
 $209 = Math_fround($22 * $57);
 $210 = Math_fround($23 * $44);
 $211 = Math_fround($210 + $209);
 $212 = Math_fround($194 + $211);
 $213 = Math_fround($30 * $57);
 $214 = Math_fround($31 * $44);
 $215 = Math_fround($214 + $213);
 $216 = Math_fround($32 * Math_fround(0.0));
 $217 = Math_fround($216 + $215);
 $218 = $45 < $57;
 $$$i$i148 = $218 ? $57 : $45;
 $219 = $44 > $54;
 $220 = $219 ? $44 : $54;
 $221 = Math_fround($$$i$i148 * $137);
 $222 = Math_fround($220 * $138);
 $223 = Math_fround($221 + $222);
 $224 = Math_fround($223 + $207);
 $225 = Math_fround($22 * $58);
 $226 = Math_fround($23 * $47);
 $227 = Math_fround($226 + $225);
 $228 = Math_fround($194 + $227);
 $229 = Math_fround($30 * $58);
 $230 = Math_fround($31 * $47);
 $231 = Math_fround($230 + $229);
 $232 = Math_fround($216 + $231);
 $233 = $48 < $58;
 $$$i$i = $233 ? $58 : $48;
 $234 = $47 > $55;
 $235 = $234 ? $47 : $55;
 $236 = Math_fround($$$i$i * $137);
 $237 = Math_fround($235 * $138);
 $238 = Math_fround($236 + $237);
 $239 = Math_fround($238 + $207);
 $240 = Math_fround(-$208);
 $241 = Math_fround(-$224);
 $242 = Math_fround(-$239);
 $243 = $195 < $200;
 $$$i124 = $243 ? $195 : $200;
 $244 = $212 < $217;
 $245 = $244 ? $212 : $217;
 $246 = $228 < $232;
 $$1$i125 = $246 ? $228 : $232;
 $247 = $195 > $200;
 $$$i118 = $247 ? $195 : $200;
 $248 = $212 > $217;
 $249 = $248 ? $212 : $217;
 $250 = $228 > $232;
 $$1$i119 = $250 ? $228 : $232;
 $251 = $$$i118 < $240;
 $252 = $249 < $241;
 $253 = $$1$i119 < $242;
 $not$1726 = $$$i124 > $208;
 $$1715 = $251 | $not$1726;
 $not$1727 = $245 > $224;
 $254 = $252 | $not$1727;
 $not$1728 = $$1$i125 > $239;
 $$1716 = $253 | $not$1728;
 $255 = $254 | $$1715;
 $256 = $255 | $$1716;
 if ($256) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $257 = $30 < $38;
 $$$i95 = $257 ? $30 : $38;
 $258 = $31 < $39;
 $259 = $258 ? $31 : $39;
 $260 = $32 < $40;
 $$1$i96 = $260 ? $32 : $40;
 $261 = $22 < $$$i95;
 $$$i89 = $261 ? $22 : $$$i95;
 $262 = $23 < $259;
 $263 = $262 ? $23 : $259;
 $264 = $24 < $$1$i96;
 $$1$i90 = $264 ? $24 : $$1$i96;
 $265 = $30 > $38;
 $$$i83 = $265 ? $30 : $38;
 $266 = $31 > $39;
 $267 = $266 ? $31 : $39;
 $268 = $32 > $40;
 $$1$i84 = $268 ? $32 : $40;
 $269 = $22 > $$$i83;
 $$$i = $269 ? $22 : $$$i83;
 $270 = $23 > $267;
 $271 = $270 ? $23 : $267;
 $272 = $24 > $$1$i84;
 $$1$i = $272 ? $24 : $$1$i84;
 $273 = $$$i < $9;
 $274 = $271 < $10;
 $275 = $$1$i < $11;
 $not$1730 = $$$i89 > $137;
 $$1717 = $273 | $not$1730;
 $not$1731 = $263 > $138;
 $276 = $274 | $not$1731;
 $not$1732 = $$1$i90 > $139;
 $$1718 = $275 | $not$1732;
 $277 = $276 | $$1717;
 $278 = $277 | $$1718;
 $279 = Math_fround($42 * $46);
 $280 = Math_fround($43 * $45);
 $281 = Math_fround($279 - $280);
 $282 = Math_fround($43 * $44);
 $283 = Math_fround($41 * $46);
 $284 = Math_fround($282 - $283);
 $285 = Math_fround($41 * $45);
 $286 = Math_fround($42 * $44);
 $287 = Math_fround($285 - $286);
 $288 = Math_fround($22 * $281);
 $289 = Math_fround($23 * $284);
 $290 = Math_fround($288 + $289);
 $291 = Math_fround($24 * $287);
 $292 = Math_fround($291 + $290);
 $293 = $281 > Math_fround(0.0);
 $294 = $284 > Math_fround(0.0);
 $295 = $287 > Math_fround(0.0);
 ;HEAP32[$0+0>>2]=HEAP32[$extents+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$extents+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$extents+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$extents+12>>2]|0;
 HEAPF32[$1>>2] = $9;
 $296 = (($1) + 4|0);
 HEAPF32[$296>>2] = $10;
 $297 = (($1) + 8|0);
 HEAPF32[$297>>2] = $11;
 $298 = (($1) + 12|0);
 HEAPF32[$298>>2] = Math_fround(0.0);
 $b$a$i40 = $293 ? $1 : $0;
 $299 = Math_fround(HEAPF32[$b$a$i40>>2]);
 $a$pn3$i42 = $294 ? $1 : $0;
 $$in1$i43 = (($a$pn3$i42) + 4|0);
 $300 = Math_fround(HEAPF32[$$in1$i43>>2]);
 $b$a5$i44 = $295 ? $1 : $0;
 $$in2$i45 = (($b$a5$i44) + 8|0);
 $301 = Math_fround(HEAPF32[$$in2$i45>>2]);
 ;HEAP32[$3+0>>2]=HEAP32[$extents+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$extents+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$extents+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$extents+12>>2]|0;
 HEAPF32[$2>>2] = $9;
 $302 = (($2) + 4|0);
 HEAPF32[$302>>2] = $10;
 $303 = (($2) + 8|0);
 HEAPF32[$303>>2] = $11;
 $304 = (($2) + 12|0);
 HEAPF32[$304>>2] = Math_fround(0.0);
 if (!($278)) {
  $a$pn3$i = $294 ? $3 : $2;
  $b$a$i = $293 ? $3 : $2;
  $b$a5$i = $295 ? $3 : $2;
  $$in1$i = (($a$pn3$i) + 4|0);
  $$in2$i = (($b$a5$i) + 8|0);
  $305 = Math_fround(HEAPF32[$$in1$i>>2]);
  $306 = Math_fround(HEAPF32[$b$a$i>>2]);
  $307 = Math_fround($284 * $305);
  $308 = Math_fround($281 * $306);
  $309 = Math_fround($284 * $300);
  $310 = Math_fround($281 * $299);
  $311 = Math_fround(HEAPF32[$$in2$i>>2]);
  $312 = Math_fround($287 * $311);
  $313 = Math_fround($307 + $308);
  $314 = Math_fround($287 * $301);
  $315 = Math_fround($310 + $309);
  $316 = Math_fround($313 + $312);
  $317 = Math_fround($315 + $314);
  $318 = Math_fround($316 - $292);
  $319 = Math_fround($317 - $292);
  $320 = Math_fround($319 * $318);
  $321 = $320 > Math_fround(0.0);
  if (!($321)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15OBBTriangleTestC2ERKNS0_3BoxE($this,$box) {
 $this = $this|0;
 $box = $box|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($box) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 96|0);
 HEAPF32[$2>>2] = $1;
 $3 = (($box) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 100|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($box) + 56|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 104|0);
 HEAPF32[$8>>2] = $7;
 $9 = Math_fround(HEAPF32[$box>>2]);
 $10 = (($box) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($box) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($box) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($box) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($box) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($box) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($box) + 28|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($box) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($box) + 36|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($box) + 40|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($box) + 44|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(-$27);
 $33 = Math_fround(-$29);
 $34 = Math_fround(-$31);
 $35 = Math_fround($9 * $32);
 $36 = Math_fround($11 * $33);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($13 * $34);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($15 * $32);
 $41 = Math_fround($17 * $33);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($19 * $34);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($21 * $32);
 $46 = Math_fround($23 * $33);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($25 * $34);
 $49 = Math_fround($47 + $48);
 HEAPF32[$this>>2] = $9;
 $50 = (($this) + 4|0);
 HEAPF32[$50>>2] = $15;
 $51 = (($this) + 8|0);
 HEAPF32[$51>>2] = $21;
 $52 = (($this) + 12|0);
 HEAPF32[$52>>2] = $11;
 $53 = (($this) + 16|0);
 HEAPF32[$53>>2] = $17;
 $54 = (($this) + 20|0);
 HEAPF32[$54>>2] = $23;
 $55 = (($this) + 24|0);
 HEAPF32[$55>>2] = $13;
 $56 = (($this) + 28|0);
 HEAPF32[$56>>2] = $19;
 $57 = (($this) + 32|0);
 HEAPF32[$57>>2] = $25;
 $58 = (($this) + 72|0);
 HEAPF32[$58>>2] = $39;
 $59 = (($this) + 76|0);
 HEAPF32[$59>>2] = $44;
 $60 = (($this) + 80|0);
 HEAPF32[$60>>2] = $49;
 $61 = (($this) + 36|0);
 HEAPF32[$61>>2] = $9;
 $62 = (($this) + 40|0);
 HEAPF32[$62>>2] = $11;
 $63 = (($this) + 44|0);
 HEAPF32[$63>>2] = $13;
 $64 = (($this) + 48|0);
 HEAPF32[$64>>2] = $15;
 $65 = (($this) + 52|0);
 HEAPF32[$65>>2] = $17;
 $66 = (($this) + 56|0);
 HEAPF32[$66>>2] = $19;
 $67 = (($this) + 60|0);
 HEAPF32[$67>>2] = $21;
 $68 = (($this) + 64|0);
 HEAPF32[$68>>2] = $23;
 $69 = (($this) + 68|0);
 HEAPF32[$69>>2] = $25;
 $70 = (($this) + 84|0);
 HEAPF32[$70>>2] = $27;
 $71 = (($this) + 88|0);
 HEAPF32[$71>>2] = $29;
 $72 = (($this) + 92|0);
 HEAPF32[$72>>2] = $31;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu15OBBTriangleTest10obbTriTestERKNS_6PxVec3ES4_S4_($this,$vert0,$vert1,$vert2) {
 $this = $this|0;
 $vert0 = $vert0|0;
 $vert1 = $vert1|0;
 $vert2 = $vert2|0;
 var $$ = 0, $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i102 = Math_fround(0), $$$i$i142 = Math_fround(0), $$$i$i182 = Math_fround(0), $$$i$i222 = Math_fround(0), $$$i$i381 = Math_fround(0), $$$i$i62 = Math_fround(0), $$$i419 = Math_fround(0), $$$i425 = Math_fround(0), $$$i431 = Math_fround(0), $$0 = 0, $$1$i = Math_fround(0), $$1$i$i143 = Math_fround(0), $$1$i$i183 = Math_fround(0), $$1$i$i223 = Math_fround(0), $$1$i$i263 = Math_fround(0), $$1$i$i305 = Math_fround(0), $$1$i$i351 = Math_fround(0);
 var $$1$i$i382 = Math_fround(0), $$1$i420 = Math_fround(0), $$1$i426 = Math_fround(0), $$1$i432 = Math_fround(0), $$1888 = 0, $$demorgan = 0, $$demorgan1886 = 0, $$demorgan1887 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0;
 var $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0);
 var $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0);
 var $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0);
 var $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0;
 var $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0;
 var $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0;
 var $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0);
 var $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0;
 var $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0);
 var $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0);
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i127 = Math_fround(0), $fabsf$i$i$i167 = Math_fround(0), $fabsf$i$i$i207 = Math_fround(0);
 var $fabsf$i$i$i247 = Math_fround(0), $fabsf$i$i$i289 = Math_fround(0), $fabsf$i$i$i335 = Math_fround(0), $fabsf$i$i$i47 = Math_fround(0), $fabsf$i$i$i87 = Math_fround(0), $not$ = 0, $not$1884 = 0, $not$1885 = 0, $or$cond = 0, $or$cond$demorgan = 0, $or$cond1899 = 0, $or$cond1901 = 0, $or$cond1903 = 0, $or$cond1905 = 0, $or$cond1907 = 0, $or$cond1909 = 0, $or$cond1911 = 0, $or$cond1913 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$this>>2]);
 $1 = (($this) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 28|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 32|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 72|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 76|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 80|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 96|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($this) + 100|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 104|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$vert0>>2]);
 $30 = (($vert0) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($vert0) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround(HEAPF32[$vert1>>2]);
 $35 = (($vert1) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($vert1) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(HEAPF32[$vert2>>2]);
 $40 = (($vert2) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($vert2) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($0 * $29);
 $45 = Math_fround($2 * $29);
 $46 = Math_fround($4 * $29);
 $47 = Math_fround($18 + $44);
 $48 = Math_fround($20 + $45);
 $49 = Math_fround($22 + $46);
 $50 = Math_fround($6 * $31);
 $51 = Math_fround($8 * $31);
 $52 = Math_fround($10 * $31);
 $53 = Math_fround($47 + $50);
 $54 = Math_fround($48 + $51);
 $55 = Math_fround($49 + $52);
 $56 = Math_fround($12 * $33);
 $57 = Math_fround($14 * $33);
 $58 = Math_fround($16 * $33);
 $59 = Math_fround($53 + $56);
 $60 = Math_fround($54 + $57);
 $61 = Math_fround($55 + $58);
 $62 = Math_fround($0 * $34);
 $63 = Math_fround($2 * $34);
 $64 = Math_fround($4 * $34);
 $65 = Math_fround($18 + $62);
 $66 = Math_fround($20 + $63);
 $67 = Math_fround($22 + $64);
 $68 = Math_fround($6 * $36);
 $69 = Math_fround($8 * $36);
 $70 = Math_fround($10 * $36);
 $71 = Math_fround($65 + $68);
 $72 = Math_fround($66 + $69);
 $73 = Math_fround($67 + $70);
 $74 = Math_fround($12 * $38);
 $75 = Math_fround($14 * $38);
 $76 = Math_fround($16 * $38);
 $77 = Math_fround($71 + $74);
 $78 = Math_fround($72 + $75);
 $79 = Math_fround($73 + $76);
 $80 = Math_fround($0 * $39);
 $81 = Math_fround($2 * $39);
 $82 = Math_fround($4 * $39);
 $83 = Math_fround($18 + $80);
 $84 = Math_fround($20 + $81);
 $85 = Math_fround($22 + $82);
 $86 = Math_fround($6 * $41);
 $87 = Math_fround($8 * $41);
 $88 = Math_fround($10 * $41);
 $89 = Math_fround($83 + $86);
 $90 = Math_fround($84 + $87);
 $91 = Math_fround($85 + $88);
 $92 = Math_fround($12 * $43);
 $93 = Math_fround($14 * $43);
 $94 = Math_fround($16 * $43);
 $95 = Math_fround($89 + $92);
 $96 = Math_fround($90 + $93);
 $97 = Math_fround($91 + $94);
 $98 = Math_fround(-$24);
 $99 = Math_fround(-$26);
 $100 = Math_fround(-$28);
 $101 = $77 < $95;
 $$$i431 = $101 ? $77 : $95;
 $102 = $78 < $96;
 $103 = $102 ? $78 : $96;
 $104 = $79 < $97;
 $$1$i432 = $104 ? $79 : $97;
 $105 = $59 < $$$i431;
 $$$i425 = $105 ? $59 : $$$i431;
 $106 = $60 < $103;
 $107 = $106 ? $60 : $103;
 $108 = $61 < $$1$i432;
 $$1$i426 = $108 ? $61 : $$1$i432;
 $109 = $77 > $95;
 $$$i419 = $109 ? $77 : $95;
 $110 = $78 > $96;
 $111 = $110 ? $78 : $96;
 $112 = $79 > $97;
 $$1$i420 = $112 ? $79 : $97;
 $113 = $59 > $$$i419;
 $$$i = $113 ? $59 : $$$i419;
 $114 = $60 > $111;
 $115 = $114 ? $60 : $111;
 $116 = $61 > $$1$i420;
 $$1$i = $116 ? $61 : $$1$i420;
 $117 = $$$i < $98;
 $118 = $115 < $99;
 $119 = $$1$i < $100;
 $not$ = $$$i425 > $24;
 $not$1884 = $107 > $26;
 $not$1885 = $$1$i426 > $28;
 $$demorgan = $117 | $not$;
 $$demorgan1886 = $118 | $not$1884;
 $or$cond$demorgan = $$demorgan | $$demorgan1886;
 $$demorgan1887 = $119 | $not$1885;
 $$1888 = $or$cond$demorgan | $$demorgan1887;
 if ($$1888) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $120 = Math_fround($77 - $59);
 $121 = Math_fround($78 - $60);
 $122 = Math_fround($79 - $61);
 $123 = Math_fround($59 - $95);
 $124 = Math_fround($60 - $96);
 $125 = Math_fround($61 - $97);
 $126 = Math_fround($122 * $124);
 $127 = Math_fround($121 * $125);
 $128 = Math_fround($126 - $127);
 $129 = Math_fround($120 * $125);
 $130 = Math_fround($122 * $123);
 $131 = Math_fround($129 - $130);
 $132 = Math_fround($121 * $123);
 $133 = Math_fround($120 * $124);
 $134 = Math_fround($132 - $133);
 $135 = Math_fround($59 * $128);
 $136 = Math_fround($60 * $131);
 $137 = Math_fround($135 + $136);
 $138 = Math_fround($61 * $134);
 $139 = Math_fround($138 + $137);
 $140 = Math_fround(-$128);
 $141 = Math_fround(-$131);
 $142 = Math_fround(-$134);
 $143 = $128 > $140;
 $$$i$i381 = $143 ? $128 : $140;
 $144 = $131 > $141;
 $145 = $144 ? $131 : $141;
 $146 = $134 > $142;
 $$1$i$i382 = $146 ? $134 : $142;
 $147 = Math_fround($24 * $$$i$i381);
 $148 = Math_fround($26 * $145);
 $149 = Math_fround($147 + $148);
 $150 = Math_fround($28 * $$1$i$i382);
 $151 = Math_fround($150 + $149);
 $152 = $139 > $151;
 $153 = Math_fround(-$151);
 $154 = $139 < $153;
 $or$cond = $152 | $154;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $155 = Math_fround($24 + $24);
 $156 = Math_fround($26 + $26);
 $157 = Math_fround($28 + $28);
 $158 = Math_fround(-$120);
 $159 = Math_fround(-$121);
 $160 = Math_fround(-$122);
 $161 = Math_fround($59 * Math_fround(0.0));
 $162 = Math_fround($60 * $160);
 $163 = Math_fround($161 + $162);
 $164 = Math_fround($61 * $121);
 $165 = Math_fround($164 + $163);
 $166 = Math_fround($95 * Math_fround(0.0));
 $167 = Math_fround($96 * $160);
 $168 = Math_fround($166 + $167);
 $169 = Math_fround($121 * $97);
 $170 = Math_fround($169 + $168);
 $171 = $122 < $160;
 $172 = $171 ? $160 : $122;
 $173 = $121 > $159;
 $$1$i$i351 = $173 ? $121 : $159;
 $174 = Math_fround($155 * Math_fround(-0.0));
 $175 = Math_fround($156 * $172);
 $176 = Math_fround($174 + $175);
 $177 = Math_fround($157 * $$1$i$i351);
 $178 = Math_fround($177 + $176);
 $179 = Math_fround($165 + $170);
 $180 = Math_fround($165 - $170);
 $fabsf$i$i$i335 = (Math_fround(Math_abs((Math_fround($180)))));
 $181 = Math_fround($178 + $fabsf$i$i$i335);
 $182 = $179 > $181;
 $183 = Math_fround(-$181);
 $184 = $179 < $183;
 $or$cond1899 = $182 | $184;
 if ($or$cond1899) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $185 = Math_fround($95 - $77);
 $186 = Math_fround($96 - $78);
 $187 = Math_fround($97 - $79);
 $188 = Math_fround(-$185);
 $189 = Math_fround(-$186);
 $190 = Math_fround(-$187);
 $191 = Math_fround($60 * $190);
 $192 = Math_fround($161 + $191);
 $193 = Math_fround($61 * $186);
 $194 = Math_fround($193 + $192);
 $195 = Math_fround($77 * Math_fround(0.0));
 $196 = Math_fround($78 * $190);
 $197 = Math_fround($195 + $196);
 $198 = Math_fround($79 * $186);
 $199 = Math_fround($198 + $197);
 $200 = $187 < $190;
 $201 = $200 ? $190 : $187;
 $202 = $186 > $189;
 $$1$i$i305 = $202 ? $186 : $189;
 $203 = Math_fround($156 * $201);
 $204 = Math_fround($174 + $203);
 $205 = Math_fround($157 * $$1$i$i305);
 $206 = Math_fround($205 + $204);
 $207 = Math_fround($194 + $199);
 $208 = Math_fround($194 - $199);
 $fabsf$i$i$i289 = (Math_fround(Math_abs((Math_fround($208)))));
 $209 = Math_fround($206 + $fabsf$i$i$i289);
 $210 = $207 > $209;
 $211 = Math_fround(-$209);
 $212 = $207 < $211;
 $or$cond1901 = $210 | $212;
 if ($or$cond1901) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $213 = Math_fround(-$123);
 $214 = Math_fround(-$124);
 $215 = Math_fround(-$125);
 $216 = Math_fround($60 * $215);
 $217 = Math_fround($161 + $216);
 $218 = Math_fround($61 * $124);
 $219 = Math_fround($218 + $217);
 $220 = Math_fround($78 * $215);
 $221 = Math_fround($195 + $220);
 $222 = Math_fround($79 * $124);
 $223 = Math_fround($222 + $221);
 $224 = $125 < $215;
 $225 = $224 ? $215 : $125;
 $226 = $124 > $214;
 $$1$i$i263 = $226 ? $124 : $214;
 $227 = Math_fround($156 * $225);
 $228 = Math_fround($174 + $227);
 $229 = Math_fround($157 * $$1$i$i263);
 $230 = Math_fround($229 + $228);
 $231 = Math_fround($219 + $223);
 $232 = Math_fround($219 - $223);
 $fabsf$i$i$i247 = (Math_fround(Math_abs((Math_fround($232)))));
 $233 = Math_fround($230 + $fabsf$i$i$i247);
 $234 = $231 > $233;
 $235 = Math_fround(-$233);
 $236 = $231 < $235;
 $or$cond1903 = $234 | $236;
 if ($or$cond1903) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $237 = Math_fround($59 * $122);
 $238 = Math_fround($60 * Math_fround(0.0));
 $239 = Math_fround($238 + $237);
 $240 = Math_fround($61 * $158);
 $241 = Math_fround($239 + $240);
 $242 = Math_fround($122 * $95);
 $243 = Math_fround($96 * Math_fround(0.0));
 $244 = Math_fround($242 + $243);
 $245 = Math_fround($97 * $158);
 $246 = Math_fround($245 + $244);
 $247 = $122 > $160;
 $$$i$i222 = $247 ? $122 : $160;
 $248 = $120 < $158;
 $$1$i$i223 = $248 ? $158 : $120;
 $249 = Math_fround($155 * $$$i$i222);
 $250 = Math_fround($156 * Math_fround(-0.0));
 $251 = Math_fround($250 + $249);
 $252 = Math_fround($157 * $$1$i$i223);
 $253 = Math_fround($252 + $251);
 $254 = Math_fround($241 + $246);
 $255 = Math_fround($241 - $246);
 $fabsf$i$i$i207 = (Math_fround(Math_abs((Math_fround($255)))));
 $256 = Math_fround($253 + $fabsf$i$i$i207);
 $257 = $254 > $256;
 $258 = Math_fround(-$256);
 $259 = $254 < $258;
 $or$cond1905 = $257 | $259;
 if ($or$cond1905) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $260 = Math_fround($59 * $187);
 $261 = Math_fround($238 + $260);
 $262 = Math_fround($61 * $188);
 $263 = Math_fround($261 + $262);
 $264 = Math_fround($77 * $187);
 $265 = Math_fround($78 * Math_fround(0.0));
 $266 = Math_fround($265 + $264);
 $267 = Math_fround($79 * $188);
 $268 = Math_fround($266 + $267);
 $269 = $187 > $190;
 $$$i$i182 = $269 ? $187 : $190;
 $270 = $185 < $188;
 $$1$i$i183 = $270 ? $188 : $185;
 $271 = Math_fround($155 * $$$i$i182);
 $272 = Math_fround($250 + $271);
 $273 = Math_fround($157 * $$1$i$i183);
 $274 = Math_fround($273 + $272);
 $275 = Math_fround($263 + $268);
 $276 = Math_fround($263 - $268);
 $fabsf$i$i$i167 = (Math_fround(Math_abs((Math_fround($276)))));
 $277 = Math_fround($274 + $fabsf$i$i$i167);
 $278 = $275 > $277;
 $279 = Math_fround(-$277);
 $280 = $275 < $279;
 $or$cond1907 = $278 | $280;
 if ($or$cond1907) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $281 = Math_fround($59 * $125);
 $282 = Math_fround($238 + $281);
 $283 = Math_fround($61 * $213);
 $284 = Math_fround($282 + $283);
 $285 = Math_fround($77 * $125);
 $286 = Math_fround($265 + $285);
 $287 = Math_fround($79 * $213);
 $288 = Math_fround($286 + $287);
 $289 = $125 > $215;
 $$$i$i142 = $289 ? $125 : $215;
 $290 = $123 < $213;
 $$1$i$i143 = $290 ? $213 : $123;
 $291 = Math_fround($155 * $$$i$i142);
 $292 = Math_fround($250 + $291);
 $293 = Math_fround($157 * $$1$i$i143);
 $294 = Math_fround($293 + $292);
 $295 = Math_fround($284 + $288);
 $296 = Math_fround($284 - $288);
 $fabsf$i$i$i127 = (Math_fround(Math_abs((Math_fround($296)))));
 $297 = Math_fround($294 + $fabsf$i$i$i127);
 $298 = $295 > $297;
 $299 = Math_fround(-$297);
 $300 = $295 < $299;
 $or$cond1909 = $298 | $300;
 if ($or$cond1909) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $301 = Math_fround($59 * $159);
 $302 = Math_fround($60 * $120);
 $303 = Math_fround($302 + $301);
 $304 = Math_fround($61 * Math_fround(0.0));
 $305 = Math_fround($304 + $303);
 $306 = Math_fround($95 * $159);
 $307 = Math_fround($120 * $96);
 $308 = Math_fround($306 + $307);
 $309 = Math_fround($97 * Math_fround(0.0));
 $310 = Math_fround($309 + $308);
 $311 = $121 < $159;
 $$$i$i102 = $311 ? $159 : $121;
 $312 = $120 > $158;
 $313 = $312 ? $120 : $158;
 $314 = Math_fround($155 * $$$i$i102);
 $315 = Math_fround($156 * $313);
 $316 = Math_fround($314 + $315);
 $317 = Math_fround($157 * Math_fround(-0.0));
 $318 = Math_fround($317 + $316);
 $319 = Math_fround($305 + $310);
 $320 = Math_fround($305 - $310);
 $fabsf$i$i$i87 = (Math_fround(Math_abs((Math_fround($320)))));
 $321 = Math_fround($318 + $fabsf$i$i$i87);
 $322 = $319 > $321;
 $323 = Math_fround(-$321);
 $324 = $319 < $323;
 $or$cond1911 = $322 | $324;
 if ($or$cond1911) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $325 = Math_fround($59 * $189);
 $326 = Math_fround($60 * $185);
 $327 = Math_fround($326 + $325);
 $328 = Math_fround($304 + $327);
 $329 = Math_fround($77 * $189);
 $330 = Math_fround($78 * $185);
 $331 = Math_fround($330 + $329);
 $332 = Math_fround($79 * Math_fround(0.0));
 $333 = Math_fround($332 + $331);
 $334 = $186 < $189;
 $$$i$i62 = $334 ? $189 : $186;
 $335 = $185 > $188;
 $336 = $335 ? $185 : $188;
 $337 = Math_fround($155 * $$$i$i62);
 $338 = Math_fround($156 * $336);
 $339 = Math_fround($337 + $338);
 $340 = Math_fround($317 + $339);
 $341 = Math_fround($328 + $333);
 $342 = Math_fround($328 - $333);
 $fabsf$i$i$i47 = (Math_fround(Math_abs((Math_fround($342)))));
 $343 = Math_fround($340 + $fabsf$i$i$i47);
 $344 = $341 > $343;
 $345 = Math_fround(-$343);
 $346 = $341 < $345;
 $or$cond1913 = $344 | $346;
 if ($or$cond1913) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $347 = Math_fround($59 * $214);
 $348 = Math_fround($60 * $123);
 $349 = Math_fround($348 + $347);
 $350 = Math_fround($304 + $349);
 $351 = Math_fround($77 * $214);
 $352 = Math_fround($78 * $123);
 $353 = Math_fround($352 + $351);
 $354 = Math_fround($332 + $353);
 $355 = $124 < $214;
 $$$i$i = $355 ? $214 : $124;
 $356 = $123 > $213;
 $357 = $356 ? $123 : $213;
 $358 = Math_fround($155 * $$$i$i);
 $359 = Math_fround($156 * $357);
 $360 = Math_fround($358 + $359);
 $361 = Math_fround($317 + $360);
 $362 = Math_fround($350 + $354);
 $363 = Math_fround($350 - $354);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($363)))));
 $364 = Math_fround($361 + $fabsf$i$i$i);
 $365 = $362 > $364;
 if ($365) {
  $367 = 0;
 } else {
  $366 = Math_fround(-$364);
  $phitmp = !($362 < $366);
  $367 = $phitmp;
 }
 $$ = $367&1;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu13RTreeMidphaseC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 16|0);
 __ZN5physx2Gu5RTreeC2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu13RTreeMidphaseD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Gu5RTree7releaseEv($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu13RTreeMidphase15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Gu5RTree15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx20InternalTriangleMeshC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Gu13RTreeMidphaseC2Ev($0);
 $1 = (($this) + 160|0);
 $2 = (($this) + 176|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAPF32[$2>>2] = Math_fround(0.00100000004749745130539);
 $3 = (($this) + 180|0);
 __ZN5physx2Gu13MeshInterfaceC2Ev($3);
 $4 = (($this) + 200|0);
 HEAP32[$4>>2] = 1;
 $5 = (($this) + 128|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;HEAP32[$5+24>>2]=0|0;HEAP8[$5+28>>0]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx20InternalTriangleMeshD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx20InternalTriangleMesh7releaseEv($this);
 $0 = (($this) + 16|0);
 __ZN5physx2Gu13RTreeMidphaseD2Ev($0);
 STACKTOP = sp;return;
}
function __ZN5physx20InternalTriangleMesh7releaseEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phi10Z2D = 0, $$pre$phi2Z2D = 0, $$pre$phi4Z2D = 0, $$pre$phi6Z2D = 0, $$pre$phi8Z2D = 0, $$pre1 = 0, $$pre3 = 0, $$pre5 = 0, $$pre7 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $1 = sp;
 $2 = sp + 1|0;
 $3 = sp + 2|0;
 $4 = sp + 3|0;
 $5 = sp + 4|0;
 $6 = (($this) + 200|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $$pre = (($this) + 152|0);
 if ($8) {
  $$pre1 = (($this) + 164|0);
  $$pre3 = (($this) + 168|0);
  $$pre5 = (($this) + 160|0);
  $$pre7 = (($this) + 12|0);
  $$pre9 = (($this) + 8|0);
  $$pre$phi10Z2D = $$pre9;$$pre$phi2Z2D = $$pre1;$$pre$phi4Z2D = $$pre3;$$pre$phi6Z2D = $$pre5;$$pre$phi8Z2D = $$pre7;
  HEAP32[$$pre>>2] = 0;
  HEAP32[$$pre$phi2Z2D>>2] = 0;
  HEAP32[$$pre$phi4Z2D>>2] = 0;
  HEAP32[$$pre$phi6Z2D>>2] = 0;
  HEAP32[$$pre$phi8Z2D>>2] = 0;
  HEAP32[$$pre$phi10Z2D>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $9 = HEAP32[$$pre>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$9);
  HEAP32[$$pre>>2] = 0;
  $10 = (($this) + 164|0);
  $11 = HEAP32[$10>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($1,$11);
  HEAP32[$10>>2] = 0;
  $12 = (($this) + 168|0);
  $13 = HEAP32[$12>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($2,$13);
  HEAP32[$12>>2] = 0;
  $14 = (($this) + 160|0);
  $15 = HEAP32[$14>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($3,$15);
  HEAP32[$14>>2] = 0;
  $16 = (($this) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($4,$17);
  HEAP32[$16>>2] = 0;
  $18 = (($this) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($5,$19);
  HEAP32[$18>>2] = 0;
  $$pre$phi10Z2D = $18;$$pre$phi2Z2D = $10;$$pre$phi4Z2D = $12;$$pre$phi6Z2D = $14;$$pre$phi8Z2D = $16;
  HEAP32[$$pre>>2] = 0;
  HEAP32[$$pre$phi2Z2D>>2] = 0;
  HEAP32[$$pre$phi4Z2D>>2] = 0;
  HEAP32[$$pre$phi6Z2D>>2] = 0;
  HEAP32[$$pre$phi8Z2D>>2] = 0;
  HEAP32[$$pre$phi10Z2D>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx20InternalTriangleMesh15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx2Gu13RTreeMidphase15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$stream>>2]|0;
  $5 = (($4) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($stream,16);
  $7 = HEAP32[$stream>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$1>>2]|0;
  $11 = HEAP32[$this>>2]|0;
  $12 = ($11*12)|0;
  FUNCTION_TABLE_viii[$9 & 4095]($stream,$10,$12);
 }
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = (($this) + 156|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17 & 2;
  $19 = ($18<<24>>24)!=(0);
  $20 = HEAP32[$stream>>2]|0;
  $21 = (($20) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_vii[$22 & 4095]($stream,16);
  $23 = HEAP32[$stream>>2]|0;
  $24 = (($23) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$13>>2]|0;
  $27 = (($this) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $19 ? 6 : 12;
  $30 = Math_imul($29, $28)|0;
  FUNCTION_TABLE_viii[$25 & 4095]($stream,$26,$30);
 }
 $31 = (($this) + 152|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = HEAP32[$stream>>2]|0;
  $35 = (($34) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_vii[$36 & 4095]($stream,16);
  $37 = HEAP32[$stream>>2]|0;
  $38 = (($37) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = HEAP32[$31>>2]|0;
  $41 = (($this) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  FUNCTION_TABLE_viii[$39 & 4095]($stream,$40,$42);
 }
 $43 = (($this) + 160|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = HEAP32[$stream>>2]|0;
  $47 = (($46) + 12|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 4095]($stream,16);
  $49 = HEAP32[$stream>>2]|0;
  $50 = (($49) + 8|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = HEAP32[$43>>2]|0;
  $53 = (($this) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = $54 << 1;
  FUNCTION_TABLE_viii[$51 & 4095]($stream,$52,$55);
 }
 $56 = (($this) + 164|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 if (!($58)) {
  $59 = HEAP32[$stream>>2]|0;
  $60 = (($59) + 12|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_vii[$61 & 4095]($stream,16);
  $62 = HEAP32[$stream>>2]|0;
  $63 = (($62) + 8|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = HEAP32[$56>>2]|0;
  $66 = (($this) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = $67 << 2;
  FUNCTION_TABLE_viii[$64 & 4095]($stream,$65,$68);
 }
 $69 = (($this) + 168|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(0|0);
 if ($71) {
  STACKTOP = sp;return;
 }
 $72 = HEAP32[$stream>>2]|0;
 $73 = (($72) + 12|0);
 $74 = HEAP32[$73>>2]|0;
 FUNCTION_TABLE_vii[$74 & 4095]($stream,16);
 $75 = HEAP32[$stream>>2]|0;
 $76 = (($75) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = HEAP32[$69>>2]|0;
 $79 = (($this) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80*12)|0;
 FUNCTION_TABLE_viii[$77 & 4095]($stream,$78,$81);
 STACKTOP = sp;return;
}
function __ZN5physx20InternalTriangleMesh18setupMeshInterfaceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 180|0);
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 184|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 156|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 2;
 $10 = ($9<<24>>24)!=(0);
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 (__ZN5physx2Gu13MeshInterface11SetPointersEPKvbPKNS_6PxVec3E($0,$6,$10,$12)|0);
 STACKTOP = sp;return;
}
function __ZN5physx20InternalTriangleMesh16allocateVerticesEj($this,$nbVertices) {
 $this = $this|0;
 $nbVertices = $nbVertices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = $nbVertices;
 $1 = ($nbVertices*12)|0;
 $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$1,551424,181)|0);
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $2;
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx20InternalTriangleMesh17allocateTrianglesEjb($this,$nbTriangles,$force32Bit) {
 $this = $this|0;
 $nbTriangles = $nbTriangles|0;
 $force32Bit = $force32Bit|0;
 var $$0 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $nbTriangles;
 $$not = ($2>>>0)>(65535);
 $brmerge = $$not | $force32Bit;
 if ($brmerge) {
  $13 = ($nbTriangles*12)|0;
  $14 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$13,551424,202)|0);
  $15 = (($this) + 12|0);
  HEAP32[$15>>2] = $14;
  $16 = (($this) + 156|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $18 & 253;
  $20 = $19&255;
  HEAP8[$16>>0] = $20;
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 } else {
  $5 = ($nbTriangles*6)|0;
  $6 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$5,551424,197)|0);
  $7 = (($this) + 12|0);
  HEAP32[$7>>2] = $6;
  $8 = (($this) + 156|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $10 | 2;
  $12 = $11&255;
  HEAP8[$8>>0] = $12;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx20InternalTriangleMesh17allocateMaterialsEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$0 = 0, $$arith = 0, $$overflow = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$arith = $1<<1;
 $$overflow = ($1>>>0)>(2147483647);
 $3 = $$overflow ? -1 : $$arith;
 $4 = ($3|0)==(0);
 if ($4) {
  $16 = 0;
 } else {
  $5 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__Z15PxGetFoundationv()|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
  $$$i$i$i = $13 ? 551776 : 551640;
  $14 = (FUNCTION_TABLE_iiiiii[$8 & 255]($5,$3,$$$i$i$i,551424,216)|0);
  $16 = $14;
 }
 $15 = (($this) + 160|0);
 HEAP32[$15>>2] = $16;
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx20InternalTriangleMesh17allocateFaceRemapEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$0 = 0, $$arith = 0, $$overflow = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$arith = $1<<2;
 $$overflow = ($1>>>0)>(1073741823);
 $3 = $$overflow ? -1 : $$arith;
 $4 = ($3|0)==(0);
 if ($4) {
  $16 = 0;
 } else {
  $5 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__Z15PxGetFoundationv()|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
  $$$i$i$i = $13 ? 551672 : 551640;
  $14 = (FUNCTION_TABLE_iiiiii[$8 & 255]($5,$3,$$$i$i$i,551424,226)|0);
  $16 = $14;
 }
 $15 = (($this) + 164|0);
 HEAP32[$15>>2] = $16;
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx20InternalTriangleMesh19allocateAdjacenciesEv($this) {
 $this = $this|0;
 var $$$i$i$i = 0, $$0 = 0, $$arith = 0, $$overflow = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($1*3)|0;
 $$arith = $3<<2;
 $$overflow = ($3>>>0)>(1073741823);
 $4 = $$overflow ? -1 : $$arith;
 $5 = ($4|0)==(0);
 if ($5) {
  $17 = 0;$24 = $1;
 } else {
  $6 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__Z15PxGetFoundationv()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
  $$$i$i$i = $14 ? 551672 : 551640;
  $15 = (FUNCTION_TABLE_iiiiii[$9 & 255]($6,$4,$$$i$i$i,551424,236)|0);
  $$pre = HEAP32[$0>>2]|0;
  $17 = $15;$24 = $$pre;
 }
 $16 = (($this) + 168|0);
 HEAP32[$16>>2] = $17;
 $18 = (($this) + 156|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = $20 | 4;
 $22 = $21&255;
 HEAP8[$18>>0] = $22;
 $23 = ($24*3)|0;
 $25 = (($this) + 172|0);
 HEAP32[$25>>2] = $23;
 $$0 = $17;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx20InternalTriangleMesh9loadRTreeERNS_13PxInputStreamEj($this,$stream,$meshVersion) {
 $this = $this|0;
 $stream = $stream|0;
 $meshVersion = $meshVersion|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (($this) + 180|0);
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 184|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 156|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 2;
 $10 = ($9<<24>>24)!=(0);
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 (__ZN5physx2Gu13MeshInterface11SetPointersEPKvbPKNS_6PxVec3E($0,$6,$10,$12)|0);
 $13 = ($meshVersion>>>0)<(10);
 if ($13) {
  $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,32,551424,259,551520,$vararg_buffer1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($this) + 16|0);
 HEAP32[$15>>2] = $0;
 $16 = (($this) + 32|0);
 $17 = (__ZN5physx2Gu5RTree4loadERNS_13PxInputStreamEj($16,$stream,$meshVersion)|0);
 if ($17) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
 __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($18,32,551424,268,551608,$vararg_buffer1);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu13MeshInterfaceC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu13MeshInterfaceD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu13MeshInterface11SetPointersEPKvbPKNS_6PxVec3E($this,$tris,$has16BitIndices,$verts) {
 $this = $this|0;
 $tris = $tris|0;
 $has16BitIndices = $has16BitIndices|0;
 $verts = $verts|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($tris|0)==(0|0);
 $1 = ($verts|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $2 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($2,8,551880,86,551968,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (($this) + 8|0);
  HEAP32[$3>>2] = $tris;
  $4 = (($this) + 12|0);
  HEAP32[$4>>2] = $verts;
  $5 = $has16BitIndices&1;
  $6 = (($this) + 16|0);
  HEAP32[$6>>2] = $5;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx11PxMeshQuery11getTriangleERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($triGeom,$globalPose,$triangleIndex,$triangle,$vertexIndices,$adjacencyIndices) {
 $triGeom = $triGeom|0;
 $globalPose = $globalPose|0;
 $triangleIndex = $triangleIndex|0;
 $triangle = $triangle|0;
 $vertexIndices = $vertexIndices|0;
 $adjacencyIndices = $adjacencyIndices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $0 = (($triGeom) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($adjacencyIndices|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 184|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $6 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($6,8,552016,161,552104,$vararg_buffer);
  }
 }
 $7 = (($triGeom) + 4|0);
 __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($vararg_buffer,$globalPose,$7);
 __ZNK5physx2Gu12TriangleMesh20computeWorldTriangleERNS_10PxTriangleEjRKNS_2Cm8Matrix34EPjS8_($1,$triangle,$triangleIndex,$vararg_buffer,$vertexIndices,$adjacencyIndices);
 STACKTOP = sp;return;
}
function __ZN5physx11PxMeshQuery11getTriangleERKNS_21PxHeightFieldGeometryERKNS_11PxTransformEjRNS_10PxTriangleEPjS9_($hfGeom,$globalPose,$triangleIndex,$triangle,$vertexIndices,$adjacencyIndices) {
 $hfGeom = $hfGeom|0;
 $globalPose = $globalPose|0;
 $triangleIndex = $triangleIndex|0;
 $triangle = $triangle|0;
 $vertexIndices = $vertexIndices|0;
 $adjacencyIndices = $adjacencyIndices|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $hfUtil = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $hfUtil = sp;
 $0 = (($hfUtil) + 12|0);
 $1 = (($hfGeom) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($hfUtil) + 16|0);
 HEAP32[$3>>2] = $hfGeom;
 $4 = (($hfGeom) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(Math_fround(1.0) / $5);
 $7 = (($hfUtil) + 4|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($hfGeom) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(Math_fround(1.0) / $9);
 HEAPF32[$hfUtil>>2] = $10;
 $11 = (($hfGeom) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(Math_fround(1.0) / $12);
 $14 = (($hfUtil) + 8|0);
 HEAPF32[$14>>2] = $13;
 (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($hfUtil,$globalPose,$triangle,$vertexIndices,$adjacencyIndices,$triangleIndex,1,1)|0);
 STACKTOP = sp;return;
}
function __ZN5physx11PxMeshQuery23findOverlapTriangleMeshERKNS_10PxGeometryERKNS_11PxTransformERKNS_22PxTriangleMeshGeometryES6_PjjjRb($geom,$geomPose,$meshGeom,$meshPose,$results,$maxResults,$startIndex,$overflow) {
 $geom = $geom|0;
 $geomPose = $geomPose|0;
 $meshGeom = $meshGeom|0;
 $meshPose = $meshPose|0;
 $results = $results|0;
 $maxResults = $maxResults|0;
 $startIndex = $startIndex|0;
 $overflow = $overflow|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0);
 var $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0;
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0;
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $box = 0, $capsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $box = sp + 48|0;
 $capsule = sp;
 $0 = sp + 32|0;
 $1 = HEAP32[$geom>>2]|0;
 if ((($1|0) == 3)) {
  $2 = (($geom) + 4|0);
  $3 = (($geomPose) + 16|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($box) + 36|0);
  HEAPF32[$5>>2] = $4;
  $6 = (($geomPose) + 20|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($box) + 40|0);
  HEAPF32[$8>>2] = $7;
  $9 = (($geomPose) + 24|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($box) + 44|0);
  HEAPF32[$11>>2] = $10;
  $12 = Math_fround(HEAPF32[$2>>2]);
  $13 = (($box) + 48|0);
  HEAPF32[$13>>2] = $12;
  $14 = (($geom) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($box) + 52|0);
  HEAPF32[$16>>2] = $15;
  $17 = (($geom) + 12|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($box) + 56|0);
  HEAPF32[$19>>2] = $18;
  $20 = Math_fround(HEAPF32[$geomPose>>2]);
  $21 = (($geomPose) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($geomPose) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($geomPose) + 12|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($20 + $20);
  $28 = Math_fround($22 + $22);
  $29 = Math_fround($24 + $24);
  $30 = Math_fround($20 * $27);
  $31 = Math_fround($22 * $28);
  $32 = Math_fround($24 * $29);
  $33 = Math_fround($27 * $22);
  $34 = Math_fround($27 * $24);
  $35 = Math_fround($27 * $26);
  $36 = Math_fround($28 * $24);
  $37 = Math_fround($28 * $26);
  $38 = Math_fround($29 * $26);
  $39 = Math_fround(Math_fround(1.0) - $31);
  $40 = Math_fround($39 - $32);
  $41 = Math_fround($33 + $38);
  $42 = Math_fround($34 - $37);
  $43 = Math_fround($33 - $38);
  $44 = Math_fround(Math_fround(1.0) - $30);
  $45 = Math_fround($44 - $32);
  $46 = Math_fround($36 + $35);
  $47 = Math_fround($34 + $37);
  $48 = Math_fround($36 - $35);
  $49 = Math_fround($44 - $31);
  HEAPF32[$box>>2] = $40;
  $50 = (($box) + 4|0);
  HEAPF32[$50>>2] = $41;
  $51 = (($box) + 8|0);
  HEAPF32[$51>>2] = $42;
  $52 = (($box) + 12|0);
  HEAPF32[$52>>2] = $43;
  $53 = (($box) + 16|0);
  HEAPF32[$53>>2] = $45;
  $54 = (($box) + 20|0);
  HEAPF32[$54>>2] = $46;
  $55 = (($box) + 24|0);
  HEAPF32[$55>>2] = $47;
  $56 = (($box) + 28|0);
  HEAPF32[$56>>2] = $48;
  $57 = (($box) + 32|0);
  HEAPF32[$57>>2] = $49;
  $58 = (($meshGeom) + 36|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + 32|0);
  $61 = (($meshGeom) + 4|0);
  $62 = (__ZN5physx2Gu18findOverlapOBBMeshERKNS0_3BoxERKNS0_13RTreeMidphaseERKNS_11PxTransformERKNS_11PxMeshScaleEPjjjRb($box,$60,$meshPose,$61,$results,$maxResults,$startIndex,$overflow)|0);
  $$0 = $62;
  STACKTOP = sp;return ($$0|0);
 } else if ((($1|0) == 0)) {
  $112 = (($meshGeom) + 36|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($geom) + 4|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($geomPose) + 16|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  HEAPF32[$0>>2] = $117;
  $118 = (($0) + 4|0);
  $119 = (($geomPose) + 20|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  HEAPF32[$118>>2] = $120;
  $121 = (($0) + 8|0);
  $122 = (($geomPose) + 24|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  HEAPF32[$121>>2] = $123;
  $124 = (($0) + 12|0);
  HEAPF32[$124>>2] = $115;
  $125 = (($113) + 32|0);
  $126 = (($meshGeom) + 4|0);
  $127 = (__ZN5physx2Gu21findOverlapSphereMeshERKNS0_6SphereERKNS0_13RTreeMidphaseERKNS_11PxTransformERKNS_11PxMeshScaleEPjjjRb($0,$125,$meshPose,$126,$results,$maxResults,$startIndex,$overflow)|0);
  $$0 = $127;
  STACKTOP = sp;return ($$0|0);
 } else if ((($1|0) == 2)) {
  $63 = Math_fround(HEAPF32[$geomPose>>2]);
  $64 = Math_fround($63 * Math_fround(2.0));
  $65 = (($geomPose) + 12|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($66 * Math_fround(2.0));
  $68 = Math_fround($66 * $67);
  $69 = Math_fround($68 + Math_fround(-1.0));
  $70 = Math_fround($63 * $64);
  $71 = Math_fround($70 + $69);
  $72 = (($geomPose) + 8|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($73 * $67);
  $75 = (($geomPose) + 4|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($64 * $76);
  $78 = Math_fround($74 + $77);
  $79 = Math_fround($67 * $76);
  $80 = Math_fround($64 * $73);
  $81 = Math_fround($80 - $79);
  $82 = (($geom) + 8|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($83 * $71);
  $85 = Math_fround($83 * $78);
  $86 = Math_fround($83 * $81);
  $87 = (($geomPose) + 16|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($88 + $84);
  $90 = (($geomPose) + 20|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($91 + $85);
  $93 = (($geomPose) + 24|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = Math_fround($86 + $94);
  HEAPF32[$capsule>>2] = $89;
  $96 = (($capsule) + 4|0);
  HEAPF32[$96>>2] = $92;
  $97 = (($capsule) + 8|0);
  HEAPF32[$97>>2] = $95;
  $98 = Math_fround($88 - $84);
  $99 = Math_fround($91 - $85);
  $100 = Math_fround($94 - $86);
  $101 = (($capsule) + 12|0);
  HEAPF32[$101>>2] = $98;
  $102 = (($capsule) + 16|0);
  HEAPF32[$102>>2] = $99;
  $103 = (($capsule) + 20|0);
  HEAPF32[$103>>2] = $100;
  $104 = (($geom) + 4|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = (($capsule) + 24|0);
  HEAPF32[$106>>2] = $105;
  $107 = (($meshGeom) + 36|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($108) + 32|0);
  $110 = (($meshGeom) + 4|0);
  $111 = (__ZN5physx2Gu22findOverlapCapsuleMeshERKNS0_7CapsuleERKNS0_13RTreeMidphaseERKNS_11PxTransformERKNS_11PxMeshScaleEPjjjRb($capsule,$109,$meshPose,$110,$results,$maxResults,$startIndex,$overflow)|0);
  $$0 = $111;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP8[$overflow>>0] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx11PxMeshQuery22findOverlapHeightFieldERKNS_10PxGeometryERKNS_11PxTransformERKNS_21PxHeightFieldGeometryES6_PjjjRb($geom,$geomPose,$hfGeom,$hfPose,$results,$maxResults,$startIndex,$overflow) {
 $geom = $geom|0;
 $geomPose = $geomPose|0;
 $hfGeom = $hfGeom|0;
 $hfPose = $hfPose|0;
 $results = $results|0;
 $maxResults = $maxResults|0;
 $startIndex = $startIndex|0;
 $overflow = $overflow|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $bounds = 0, $entityReport = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0);
 var $fabsf$i$i8$i$i = Math_fround(0), $hfUtil = 0, $or$cond = 0, $or$cond13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $bounds = sp + 96|0;
 $hfUtil = sp;
 $entityReport = sp + 24|0;
 $0 = Math_fround(HEAPF32[$hfPose>>2]);
 $1 = Math_fround(-$0);
 $2 = (($hfPose) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(-$3);
 $5 = (($hfPose) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 $8 = (($hfPose) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($geomPose) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($hfPose) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($geomPose) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($hfPose) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = (($geomPose) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($hfPose) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 $25 = Math_fround($14 * Math_fround(2.0));
 $26 = Math_fround($19 * Math_fround(2.0));
 $27 = Math_fround($24 * Math_fround(2.0));
 $28 = Math_fround($9 * $9);
 $29 = Math_fround($28 + Math_fround(-0.5));
 $30 = Math_fround($25 * $1);
 $31 = Math_fround($26 * $4);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($27 * $7);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($29 * $25);
 $36 = Math_fround($27 * $4);
 $37 = Math_fround($26 * $7);
 $38 = Math_fround($36 - $37);
 $39 = Math_fround($9 * $38);
 $40 = Math_fround($35 + $39);
 $41 = Math_fround($34 * $1);
 $42 = Math_fround($41 + $40);
 $43 = Math_fround($29 * $26);
 $44 = Math_fround($25 * $7);
 $45 = Math_fround($27 * $1);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($9 * $46);
 $48 = Math_fround($43 + $47);
 $49 = Math_fround($34 * $4);
 $50 = Math_fround($49 + $48);
 $51 = Math_fround($29 * $27);
 $52 = Math_fround($26 * $1);
 $53 = Math_fround($25 * $4);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($9 * $54);
 $56 = Math_fround($51 + $55);
 $57 = Math_fround($34 * $7);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround(HEAPF32[$geomPose>>2]);
 $60 = Math_fround($9 * $59);
 $61 = (($geomPose) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * $1);
 $64 = Math_fround($60 + $63);
 $65 = (($geomPose) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $4);
 $68 = Math_fround($64 + $67);
 $69 = (($geomPose) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $7);
 $72 = Math_fround($68 - $71);
 $73 = Math_fround($9 * $70);
 $74 = Math_fround($62 * $4);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($59 * $7);
 $77 = Math_fround($76 + $75);
 $78 = Math_fround($66 * $1);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($9 * $66);
 $81 = Math_fround($62 * $7);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($70 * $1);
 $84 = Math_fround($83 + $82);
 $85 = Math_fround($59 * $4);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($9 * $62);
 $88 = Math_fround($59 * $1);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($70 * $4);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($66 * $7);
 $93 = Math_fround($91 - $92);
 $94 = HEAP32[$geom>>2]|0;
 if ((($94|0) == 3)) {
  $102 = (($geom) + 4|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = (($geom) + 8|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = (($geom) + 12|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $112 = $103;$114 = $105;$116 = $107;
 } else if ((($94|0) == 2)) {
  $95 = (($geom) + 8|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = (($geom) + 4|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = Math_fround($96 + $98);
  $112 = $99;$114 = $98;$116 = $98;
 } else if ((($94|0) == 0)) {
  $100 = (($geom) + 4|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $112 = $101;$114 = $101;$116 = $101;
 } else {
  HEAP8[$overflow>>0] = 0;
  $112 = Math_fround(0.0);$114 = Math_fround(0.0);$116 = Math_fround(0.0);
 }
 $108 = $72 == Math_fround(0.0);
 $109 = $79 == Math_fround(0.0);
 $or$cond = $108 & $109;
 $110 = $86 == Math_fround(0.0);
 $or$cond13 = $or$cond & $110;
 if ($or$cond13) {
  $111 = Math_fround($42 - $112);
  $113 = Math_fround($50 - $114);
  $115 = Math_fround($58 - $116);
  $117 = Math_fround($42 + $112);
  $118 = Math_fround($50 + $114);
  $119 = Math_fround($58 + $116);
  HEAPF32[$bounds>>2] = $111;
  $120 = (($bounds) + 4|0);
  HEAPF32[$120>>2] = $113;
  $121 = (($bounds) + 8|0);
  HEAPF32[$121>>2] = $115;
  $122 = (($bounds) + 12|0);
  HEAPF32[$122>>2] = $117;
  $123 = (($bounds) + 16|0);
  HEAPF32[$123>>2] = $118;
  $124 = (($bounds) + 20|0);
  HEAPF32[$124>>2] = $119;
  $206 = 1;
 } else {
  $125 = Math_fround($72 + $72);
  $126 = Math_fround($79 + $79);
  $127 = Math_fround($86 + $86);
  $128 = Math_fround($72 * $125);
  $129 = Math_fround($79 * $126);
  $130 = Math_fround($86 * $127);
  $131 = Math_fround($125 * $79);
  $132 = Math_fround($125 * $86);
  $133 = Math_fround($125 * $93);
  $134 = Math_fround($86 * $126);
  $135 = Math_fround($93 * $126);
  $136 = Math_fround($93 * $127);
  $137 = Math_fround(Math_fround(1.0) - $129);
  $138 = Math_fround($137 - $130);
  $139 = Math_fround($131 + $136);
  $140 = Math_fround($132 - $135);
  $141 = Math_fround($131 - $136);
  $142 = Math_fround(Math_fround(1.0) - $128);
  $143 = Math_fround($142 - $130);
  $144 = Math_fround($133 + $134);
  $145 = Math_fround($132 + $135);
  $146 = Math_fround($134 - $133);
  $147 = Math_fround($142 - $129);
  $148 = Math_fround($138 * $112);
  $149 = Math_fround($139 * $112);
  $150 = Math_fround($140 * $112);
  $151 = Math_fround($141 * $114);
  $152 = Math_fround($143 * $114);
  $153 = Math_fround($144 * $114);
  $154 = Math_fround($145 * $116);
  $155 = Math_fround($146 * $116);
  $156 = Math_fround($147 * $116);
  $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($148)))));
  $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($151)))));
  $157 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
  $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($154)))));
  $158 = Math_fround($157 + $fabsf$i$i6$i$i);
  $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($149)))));
  $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($152)))));
  $159 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
  $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($155)))));
  $160 = Math_fround($159 + $fabsf$i$i3$i$i);
  $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($150)))));
  $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($153)))));
  $161 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
  $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($156)))));
  $162 = Math_fround($161 + $fabsf$i$i$i$i);
  $163 = Math_fround($42 - $158);
  $164 = Math_fround($50 - $160);
  $165 = Math_fround($58 - $162);
  $166 = Math_fround($42 + $158);
  $167 = Math_fround($50 + $160);
  $168 = Math_fround($58 + $162);
  HEAPF32[$bounds>>2] = $163;
  $169 = (($bounds) + 4|0);
  HEAPF32[$169>>2] = $164;
  $170 = (($bounds) + 8|0);
  HEAPF32[$170>>2] = $165;
  $171 = (($bounds) + 12|0);
  HEAPF32[$171>>2] = $166;
  $172 = (($bounds) + 16|0);
  HEAPF32[$172>>2] = $167;
  $173 = (($bounds) + 20|0);
  HEAPF32[$173>>2] = $168;
  $206 = 0;
 }
 $174 = (($hfUtil) + 12|0);
 $175 = (($hfGeom) + 4|0);
 $176 = HEAP32[$175>>2]|0;
 HEAP32[$174>>2] = $176;
 $177 = (($hfUtil) + 16|0);
 HEAP32[$177>>2] = $hfGeom;
 $178 = (($hfGeom) + 8|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 $180 = Math_fround(Math_fround(1.0) / $179);
 $181 = (($hfUtil) + 4|0);
 HEAPF32[$181>>2] = $180;
 $182 = (($hfGeom) + 12|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = Math_fround(Math_fround(1.0) / $183);
 HEAPF32[$hfUtil>>2] = $184;
 $185 = (($hfGeom) + 16|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = Math_fround(Math_fround(1.0) / $186);
 $188 = (($hfUtil) + 8|0);
 HEAPF32[$188>>2] = $187;
 HEAP32[$entityReport>>2] = ((552192 + 8|0));
 $189 = (($entityReport) + 4|0);
 HEAP32[$189>>2] = $hfUtil;
 $190 = (($entityReport) + 8|0);
 HEAPF32[$190>>2] = $42;
 $191 = (($entityReport) + 12|0);
 HEAPF32[$191>>2] = $50;
 $192 = (($entityReport) + 16|0);
 HEAPF32[$192>>2] = $58;
 $193 = (($entityReport) + 20|0);
 HEAPF32[$193>>2] = $112;
 $194 = (($entityReport) + 24|0);
 HEAPF32[$194>>2] = $114;
 $195 = (($entityReport) + 28|0);
 HEAPF32[$195>>2] = $116;
 $196 = (($entityReport) + 32|0);
 HEAPF32[$196>>2] = $72;
 $197 = (($entityReport) + 36|0);
 HEAPF32[$197>>2] = $79;
 $198 = (($entityReport) + 40|0);
 HEAPF32[$198>>2] = $86;
 $199 = (($entityReport) + 44|0);
 HEAPF32[$199>>2] = $93;
 $200 = (($entityReport) + 48|0);
 HEAP32[$200>>2] = $results;
 $201 = (($entityReport) + 52|0);
 HEAP32[$201>>2] = $maxResults;
 $202 = (($entityReport) + 56|0);
 HEAP32[$202>>2] = $startIndex;
 $203 = (($entityReport) + 60|0);
 HEAP32[$203>>2] = 0;
 $204 = (($entityReport) + 64|0);
 HEAP32[$204>>2] = 0;
 $205 = (($entityReport) + 68|0);
 HEAP8[$205>>0] = $206;
 $207 = (($entityReport) + 69|0);
 HEAP8[$207>>0] = 0;
 (__ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($hfUtil,$hfPose,$bounds,0,$entityReport)|0);
 $208 = HEAP8[$207>>0]|0;
 HEAP8[$overflow>>0] = $208;
 $209 = HEAP32[$203>>2]|0;
 STACKTOP = sp;return ($209|0);
}
function __ZN5physx11PxMeshQuery5sweepERKNS_6PxVec3EfRKNS_10PxGeometryERKNS_11PxTransformEjPKNS_10PxTriangleERNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEPKjf($unitDir,$distance,$geom,$pose,$triangleCount,$triangles,$sweepHit,$hintFlags,$cachedIndex,$inflation) {
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $geom = $geom|0;
 $pose = $pose|0;
 $triangleCount = $triangleCount|0;
 $triangles = $triangles|0;
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $cachedIndex = $cachedIndex|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $capsuleGeom = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $capsuleGeom = sp;
 $0 = sp + 18|0;
 $1 = sp + 12|0;
 $2 = sp + 14|0;
 $3 = sp + 16|0;
 $4 = HEAP32[$geom>>2]|0;
 if ((($4|0) == 2)) {
  $15 = (($sweepHit) + 16|0);
  $16 = (($sweepHit) + 28|0);
  $17 = (($sweepHit) + 40|0);
  $18 = (($sweepHit) + 8|0);
  $19 = HEAP16[$hintFlags>>1]|0;
  HEAP16[$1>>1] = $19;
  $20 = (__ZN5physx2Gu21SweepCapsuleTrianglesEjPKNS_10PxTriangleERKNS_17PxCapsuleGeometryERKNS_11PxTransformERKNS_6PxVec3EfPKjRSA_SF_RfRjfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($triangleCount,$triangles,$geom,$pose,$unitDir,$distance,$cachedIndex,$15,$16,$17,$18,$inflation,$1)|0);
  $$0 = $20;
  STACKTOP = sp;return ($$0|0);
 } else if ((($4|0) == 0)) {
  $5 = (($geom) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  HEAP32[$capsuleGeom>>2] = 2;
  $7 = (($capsuleGeom) + 4|0);
  HEAPF32[$7>>2] = $6;
  $8 = (($capsuleGeom) + 8|0);
  HEAPF32[$8>>2] = Math_fround(0.0);
  $9 = (($sweepHit) + 16|0);
  $10 = (($sweepHit) + 28|0);
  $11 = (($sweepHit) + 40|0);
  $12 = (($sweepHit) + 8|0);
  $13 = HEAP16[$hintFlags>>1]|0;
  HEAP16[$0>>1] = $13;
  $14 = (__ZN5physx2Gu21SweepCapsuleTrianglesEjPKNS_10PxTriangleERKNS_17PxCapsuleGeometryERKNS_11PxTransformERKNS_6PxVec3EfPKjRSA_SF_RfRjfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($triangleCount,$triangles,$capsuleGeom,$pose,$unitDir,$distance,$cachedIndex,$9,$10,$11,$12,$inflation,$0)|0);
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 } else if ((($4|0) == 3)) {
  $21 = HEAP16[$hintFlags>>1]|0;
  $22 = $21 & 256;
  $23 = ($22<<16>>16)==(0);
  $24 = (($sweepHit) + 16|0);
  $25 = (($sweepHit) + 28|0);
  $26 = (($sweepHit) + 40|0);
  $27 = (($sweepHit) + 8|0);
  if ($23) {
   HEAP16[$3>>1] = $21;
   $29 = (__ZN5physx2Gu17SweepBoxTrianglesEjPKNS_10PxTriangleERKNS_13PxBoxGeometryERKNS_11PxTransformERKNS_6PxVec3EfRSA_SD_RfRjPKjfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($triangleCount,$triangles,$geom,$pose,$unitDir,$distance,$24,$25,$26,$27,$cachedIndex,$inflation,$3)|0);
   $$0 = $29;
   STACKTOP = sp;return ($$0|0);
  } else {
   HEAP16[$2>>1] = $21;
   $28 = (__Z20sweepCCTBoxTrianglesjPKN5physx10PxTriangleERKNS_13PxBoxGeometryERKNS_11PxTransformERKNS_6PxVec3EfRS9_SC_RfRjPKjfNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($triangleCount,$triangles,$geom,$pose,$unitDir,$distance,$24,$25,$26,$27,$cachedIndex,$inflation,$2)|0);
   $$0 = $28;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN12_GLOBAL__N_124HfTrianglesEntityReport2D2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_124HfTrianglesEntityReport2D0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_124HfTrianglesEntityReport27onEventEjPj($this,$nbEntities,$entities) {
 $this = $this|0;
 $nbEntities = $nbEntities|0;
 $entities = $entities|0;
 var $$019 = 0, $$028 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0);
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$06 = 0, $tri = 0, $v0 = 0, $v1 = 0, $v2 = 0, $zero = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $tri = sp + 76|0;
 $0 = sp;
 $v0 = sp + 28|0;
 $v1 = sp + 40|0;
 $v2 = sp + 52|0;
 $zero = sp + 64|0;
 $1 = (($this) + 68|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = ($nbEntities|0)==(0);
  if ($4) {
   $$2 = 1;
   STACKTOP = sp;return ($$2|0);
  }
  $5 = (($this) + 60|0);
  $6 = (($this) + 52|0);
  $7 = (($this) + 64|0);
  $8 = (($this) + 56|0);
  $9 = (($this) + 48|0);
  $$019 = $entities;$$028 = $nbEntities;
  while(1) {
   $10 = (($$028) + -1)|0;
   $11 = (($$019) + 4|0);
   $12 = HEAP32[$$019>>2]|0;
   $13 = HEAP32[$5>>2]|0;
   $14 = HEAP32[$6>>2]|0;
   $15 = ($13>>>0)<($14>>>0);
   if (!($15)) {
    break;
   }
   $16 = HEAP32[$7>>2]|0;
   $17 = HEAP32[$8>>2]|0;
   $18 = ($16>>>0)<($17>>>0);
   if ($18) {
    $22 = (($16) + 1)|0;
    HEAP32[$7>>2] = $22;
   } else {
    $19 = (($13) + 1)|0;
    HEAP32[$5>>2] = $19;
    $20 = HEAP32[$9>>2]|0;
    $21 = (($20) + ($13<<2)|0);
    HEAP32[$21>>2] = $12;
   }
   $23 = ($10|0)==(0);
   if ($23) {
    $$2 = 1;
    label = 19;
    break;
   } else {
    $$019 = $11;$$028 = $10;
   }
  }
  if ((label|0) == 19) {
   STACKTOP = sp;return ($$2|0);
  }
  $24 = (($this) + 69|0);
  HEAP8[$24>>0] = 1;
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $25 = (($this) + 32|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 36|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($this) + 40|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($this) + 44|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($this) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($this) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = ($nbEntities|0)==(0);
 if ($39) {
  $$2 = 1;
  STACKTOP = sp;return ($$2|0);
 }
 $40 = (($this) + 4|0);
 $41 = (($0) + 4|0);
 $42 = (($0) + 8|0);
 $43 = (($0) + 12|0);
 $44 = (($0) + 16|0);
 $45 = (($0) + 20|0);
 $46 = (($0) + 24|0);
 $47 = (($tri) + 4|0);
 $48 = (($tri) + 8|0);
 $49 = Math_fround($32 * $32);
 $50 = Math_fround($49 + Math_fround(-0.5));
 $51 = (($v0) + 4|0);
 $52 = (($v0) + 8|0);
 $53 = (($tri) + 12|0);
 $54 = (($tri) + 16|0);
 $55 = (($tri) + 20|0);
 $56 = (($v1) + 4|0);
 $57 = (($v1) + 8|0);
 $58 = (($tri) + 24|0);
 $59 = (($tri) + 28|0);
 $60 = (($tri) + 32|0);
 $61 = (($v2) + 4|0);
 $62 = (($v2) + 8|0);
 $63 = (($zero) + 4|0);
 $64 = (($zero) + 8|0);
 $65 = (($this) + 20|0);
 $66 = (($this) + 60|0);
 $67 = (($this) + 52|0);
 $68 = (($this) + 64|0);
 $69 = (($this) + 56|0);
 $70 = (($this) + 48|0);
 $i$06 = 0;
 L21: while(1) {
  $71 = HEAP32[$40>>2]|0;
  HEAPF32[$0>>2] = Math_fround(0.0);
  HEAPF32[$41>>2] = Math_fround(0.0);
  HEAPF32[$42>>2] = Math_fround(0.0);
  HEAPF32[$43>>2] = Math_fround(1.0);
  HEAPF32[$44>>2] = Math_fround(0.0);
  HEAPF32[$45>>2] = Math_fround(0.0);
  HEAPF32[$46>>2] = Math_fround(0.0);
  $72 = (($entities) + ($i$06<<2)|0);
  $73 = HEAP32[$72>>2]|0;
  (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($71,$0,$tri,0,0,$73,0,0)|0);
  $74 = Math_fround(HEAPF32[$tri>>2]);
  $75 = Math_fround($74 - $34);
  $76 = Math_fround(HEAPF32[$47>>2]);
  $77 = Math_fround($76 - $36);
  $78 = Math_fround(HEAPF32[$48>>2]);
  $79 = Math_fround($78 - $38);
  $80 = Math_fround($75 * Math_fround(2.0));
  $81 = Math_fround($77 * Math_fround(2.0));
  $82 = Math_fround($79 * Math_fround(2.0));
  $83 = Math_fround($26 * $80);
  $84 = Math_fround($28 * $81);
  $85 = Math_fround($83 + $84);
  $86 = Math_fround($30 * $82);
  $87 = Math_fround($85 + $86);
  $88 = Math_fround($50 * $80);
  $89 = Math_fround($28 * $82);
  $90 = Math_fround($30 * $81);
  $91 = Math_fround($89 - $90);
  $92 = Math_fround($32 * $91);
  $93 = Math_fround($88 - $92);
  $94 = Math_fround($26 * $87);
  $95 = Math_fround($94 + $93);
  $96 = Math_fround($50 * $81);
  $97 = Math_fround($30 * $80);
  $98 = Math_fround($26 * $82);
  $99 = Math_fround($97 - $98);
  $100 = Math_fround($32 * $99);
  $101 = Math_fround($96 - $100);
  $102 = Math_fround($28 * $87);
  $103 = Math_fround($102 + $101);
  $104 = Math_fround($50 * $82);
  $105 = Math_fround($26 * $81);
  $106 = Math_fround($28 * $80);
  $107 = Math_fround($105 - $106);
  $108 = Math_fround($32 * $107);
  $109 = Math_fround($104 - $108);
  $110 = Math_fround($30 * $87);
  $111 = Math_fround($109 + $110);
  HEAPF32[$v0>>2] = $95;
  HEAPF32[$51>>2] = $103;
  HEAPF32[$52>>2] = $111;
  $112 = Math_fround(HEAPF32[$53>>2]);
  $113 = Math_fround($112 - $34);
  $114 = Math_fround(HEAPF32[$54>>2]);
  $115 = Math_fround($114 - $36);
  $116 = Math_fround(HEAPF32[$55>>2]);
  $117 = Math_fround($116 - $38);
  $118 = Math_fround($113 * Math_fround(2.0));
  $119 = Math_fround($115 * Math_fround(2.0));
  $120 = Math_fround($117 * Math_fround(2.0));
  $121 = Math_fround($26 * $118);
  $122 = Math_fround($28 * $119);
  $123 = Math_fround($121 + $122);
  $124 = Math_fround($30 * $120);
  $125 = Math_fround($123 + $124);
  $126 = Math_fround($50 * $118);
  $127 = Math_fround($28 * $120);
  $128 = Math_fround($30 * $119);
  $129 = Math_fround($127 - $128);
  $130 = Math_fround($32 * $129);
  $131 = Math_fround($126 - $130);
  $132 = Math_fround($26 * $125);
  $133 = Math_fround($132 + $131);
  $134 = Math_fround($50 * $119);
  $135 = Math_fround($30 * $118);
  $136 = Math_fround($26 * $120);
  $137 = Math_fround($135 - $136);
  $138 = Math_fround($32 * $137);
  $139 = Math_fround($134 - $138);
  $140 = Math_fround($28 * $125);
  $141 = Math_fround($140 + $139);
  $142 = Math_fround($50 * $120);
  $143 = Math_fround($26 * $119);
  $144 = Math_fround($28 * $118);
  $145 = Math_fround($143 - $144);
  $146 = Math_fround($32 * $145);
  $147 = Math_fround($142 - $146);
  $148 = Math_fround($30 * $125);
  $149 = Math_fround($147 + $148);
  HEAPF32[$v1>>2] = $133;
  HEAPF32[$56>>2] = $141;
  HEAPF32[$57>>2] = $149;
  $150 = Math_fround(HEAPF32[$58>>2]);
  $151 = Math_fround($150 - $34);
  $152 = Math_fround(HEAPF32[$59>>2]);
  $153 = Math_fround($152 - $36);
  $154 = Math_fround(HEAPF32[$60>>2]);
  $155 = Math_fround($154 - $38);
  $156 = Math_fround($151 * Math_fround(2.0));
  $157 = Math_fround($153 * Math_fround(2.0));
  $158 = Math_fround($155 * Math_fround(2.0));
  $159 = Math_fround($26 * $156);
  $160 = Math_fround($28 * $157);
  $161 = Math_fround($159 + $160);
  $162 = Math_fround($30 * $158);
  $163 = Math_fround($161 + $162);
  $164 = Math_fround($50 * $156);
  $165 = Math_fround($28 * $158);
  $166 = Math_fround($30 * $157);
  $167 = Math_fround($165 - $166);
  $168 = Math_fround($32 * $167);
  $169 = Math_fround($164 - $168);
  $170 = Math_fround($26 * $163);
  $171 = Math_fround($170 + $169);
  $172 = Math_fround($50 * $157);
  $173 = Math_fround($30 * $156);
  $174 = Math_fround($26 * $158);
  $175 = Math_fround($173 - $174);
  $176 = Math_fround($32 * $175);
  $177 = Math_fround($172 - $176);
  $178 = Math_fround($28 * $163);
  $179 = Math_fround($178 + $177);
  $180 = Math_fround($50 * $158);
  $181 = Math_fround($26 * $157);
  $182 = Math_fround($28 * $156);
  $183 = Math_fround($181 - $182);
  $184 = Math_fround($32 * $183);
  $185 = Math_fround($180 - $184);
  $186 = Math_fround($30 * $163);
  $187 = Math_fround($185 + $186);
  HEAPF32[$v2>>2] = $171;
  HEAPF32[$61>>2] = $179;
  HEAPF32[$62>>2] = $187;
  HEAPF32[$zero>>2] = Math_fround(0.0);
  HEAPF32[$63>>2] = Math_fround(0.0);
  HEAPF32[$64>>2] = Math_fround(0.0);
  $188 = (__ZN5physx2Gu20intersectTriangleBoxERKNS_6PxVec3ES3_S3_S3_S3_($zero,$65,$v0,$v1,$v2)|0);
  $189 = ($188|0)==(0);
  do {
   if (!($189)) {
    $190 = HEAP32[$72>>2]|0;
    $191 = HEAP32[$66>>2]|0;
    $192 = HEAP32[$67>>2]|0;
    $193 = ($191>>>0)<($192>>>0);
    if (!($193)) {
     break L21;
    }
    $194 = HEAP32[$68>>2]|0;
    $195 = HEAP32[$69>>2]|0;
    $196 = ($194>>>0)<($195>>>0);
    if ($196) {
     $200 = (($194) + 1)|0;
     HEAP32[$68>>2] = $200;
     break;
    } else {
     $197 = (($191) + 1)|0;
     HEAP32[$66>>2] = $197;
     $198 = HEAP32[$70>>2]|0;
     $199 = (($198) + ($191<<2)|0);
     HEAP32[$199>>2] = $190;
     break;
    }
   }
  } while(0);
  $202 = (($i$06) + 1)|0;
  $203 = ($202>>>0)<($nbEntities>>>0);
  if ($203) {
   $i$06 = $202;
  } else {
   $$2 = 1;
   label = 19;
   break;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return ($$2|0);
 }
 $201 = (($this) + 69|0);
 HEAP8[$201>>0] = 1;
 $$2 = 0;
 STACKTOP = sp;return ($$2|0);
}
function __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($obb,$bothTriangleSidesCollide,$model,$callback,$checkObbIsAligned) {
 $obb = $obb|0;
 $bothTriangleSidesCollide = $bothTriangleSidesCollide|0;
 $model = $model|0;
 $callback = $callback|0;
 $checkObbIsAligned = $checkObbIsAligned|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0;
 var $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $buf = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0);
 var $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $rTreeCallback = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $buf = sp + 280|0;
 $rTreeCallback = sp;
 $0 = sp + 240|0;
 $1 = sp + 256|0;
 $2 = sp + 268|0;
 $3 = HEAP32[$model>>2]|0;
 $4 = $3;
 $5 = (($4) + 16)|0;
 $6 = $5;
 $7 = (($4) + 8)|0;
 $8 = $7;
 $9 = (($4) + 12)|0;
 $10 = $9;
 $11 = HEAP32[$6>>2]|0;
 $12 = (($rTreeCallback) + 4|0);
 HEAP32[$rTreeCallback>>2] = ((552360 + 8|0));
 HEAP32[$12>>2] = ((552360 + 32|0));
 $13 = (($rTreeCallback) + 8|0);
 HEAP32[$13>>2] = $model;
 $14 = (($rTreeCallback) + 12|0);
 HEAP32[$14>>2] = $callback;
 $15 = (($rTreeCallback) + 16|0);
 HEAP32[$15>>2] = $11;
 $16 = (($rTreeCallback) + 20|0);
 HEAP32[$16>>2] = $8;
 $17 = (($rTreeCallback) + 24|0);
 HEAP32[$17>>2] = $10;
 $18 = (($rTreeCallback) + 28|0);
 HEAP32[$18>>2] = 0;
 $19 = (($model) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($rTreeCallback) + 32|0);
 $22 = (($rTreeCallback) + 56|0);
 $23 = $bothTriangleSidesCollide&1;
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;HEAP32[$21+20>>2]=0|0;
 HEAP8[$22>>0] = $23;
 $24 = (($rTreeCallback) + 60|0);
 HEAPF32[$24>>2] = $20;
 $25 = (($rTreeCallback) + 64|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($rTreeCallback) + 68|0);
 HEAP32[$26>>2] = 0;
 $27 = (($rTreeCallback) + 72|0);
 HEAP32[$27>>2] = 0;
 $28 = (($rTreeCallback) + 76|0);
 HEAP32[$28>>2] = -1;
 $29 = (($rTreeCallback) + 80|0);
 HEAP16[$29>>1] = 0;
 $30 = (($rTreeCallback) + 84|0);
 $31 = (($rTreeCallback) + 108|0);
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP32[$30+16>>2]=0|0;HEAP32[$30+20>>2]=0|0;
 HEAPF32[$31>>2] = Math_fround(3.40282346638528859812E+38);
 $32 = (($rTreeCallback) + 112|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($rTreeCallback) + 116|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($rTreeCallback) + 181|0);
 $35 = (($callback) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(1);
 $38 = $37&1;
 HEAP8[$34>>0] = $38;
 $39 = (($rTreeCallback) + 180|0);
 HEAP8[$39>>0] = 0;
 $40 = (($rTreeCallback) + 208|0);
 ;HEAP32[$40+0>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;HEAP32[$40+16>>2]=0|0;HEAP32[$40+20>>2]=0|0;HEAP32[$40+24>>2]=0|0;HEAP32[$40+28>>2]=0|0;
 if ($checkObbIsAligned) {
  __ZN5physx6PxQuatC2ERKNS_7PxMat33E($0,$obb);
  $41 = (($0) + 12|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($42)))));
  $43 = $fabsf$i$i > Math_fround(0.999899983406066894531);
  if ($43) {
   $44 = Math_fround(HEAPF32[$obb>>2]);
   $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($44)))));
   $45 = (($obb) + 4|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($46)))));
   $47 = (($obb) + 8|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($48)))));
   $49 = (($obb) + 12|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($50)))));
   $51 = (($49) + 4|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($52)))));
   $53 = (($49) + 8|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($54)))));
   $55 = (($obb) + 24|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($56)))));
   $57 = (($55) + 4|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($58)))));
   $59 = (($55) + 8|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($60)))));
   $61 = (($obb) + 48|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = (($obb) + 52|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = (($obb) + 56|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = Math_fround($fabsf$i$i2$i * $62);
   $68 = Math_fround($fabsf$i$i7$i * $64);
   $69 = Math_fround($67 + $68);
   $70 = Math_fround($fabsf$i$i3$i * $66);
   $71 = Math_fround($69 + $70);
   $72 = Math_fround($fabsf$i$i5$i * $62);
   $73 = Math_fround($fabsf$i$i6$i * $64);
   $74 = Math_fround($72 + $73);
   $75 = Math_fround($fabsf$i$i1$i * $66);
   $76 = Math_fround($74 + $75);
   $77 = Math_fround($fabsf$i$i8$i * $62);
   $78 = Math_fround($fabsf$i$i4$i * $64);
   $79 = Math_fround($77 + $78);
   $80 = Math_fround($fabsf$i$i$i * $66);
   $81 = Math_fround($79 + $80);
   $82 = (($model) + 4|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($obb) + 36|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = Math_fround($85 - $71);
   $87 = (($obb) + 40|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = Math_fround($88 - $76);
   $90 = (($obb) + 44|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = Math_fround($91 - $81);
   HEAPF32[$1>>2] = $86;
   $93 = (($1) + 4|0);
   HEAPF32[$93>>2] = $89;
   $94 = (($1) + 8|0);
   HEAPF32[$94>>2] = $92;
   $95 = Math_fround($71 + $85);
   $96 = Math_fround($76 + $88);
   $97 = Math_fround($81 + $91);
   HEAPF32[$2>>2] = $95;
   $98 = (($2) + 4|0);
   HEAPF32[$98>>2] = $96;
   $99 = (($2) + 8|0);
   HEAPF32[$99>>2] = $97;
   $100 = (($rTreeCallback) + 4|0);
   __ZNK5physx2Gu5RTree12traverseAABBERKNS_6PxVec3ES4_jPjPNS1_8CallbackE($83,$1,$2,4,$buf,$100);
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $101 = (($model) + 4|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($rTreeCallback) + 4|0);
  __ZNK5physx2Gu5RTree11traverseOBBERKNS0_3BoxEjPjPNS1_8CallbackE($102,$obb,4,$buf,$103);
 }
 HEAP32[$rTreeCallback>>2] = ((552360 + 8|0));
 HEAP32[$12>>2] = ((552360 + 32|0));
 $104 = HEAP8[$39>>0]|0;
 $105 = ($104<<24>>24)==(0);
 if ($105) {
  STACKTOP = sp;return;
 }
 $106 = HEAP32[$14>>2]|0;
 $107 = HEAP32[$106>>2]|0;
 $108 = HEAP32[$107>>2]|0;
 $109 = (($rTreeCallback) + 68|0);
 $110 = (($rTreeCallback) + 132|0);
 $111 = (($rTreeCallback) + 144|0);
 $112 = (($rTreeCallback) + 156|0);
 $113 = (($rTreeCallback) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$108 & 127]($106,$109,$110,$111,$112,$25,$113)|0);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi0ELb0EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552360 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((552360 + 32|0));
 $1 = (($this) + 180|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 144|0);
 $11 = (($this) + 156|0);
 $12 = (($this) + 64|0);
 $13 = (($this) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$7 & 127]($5,$8,$9,$10,$11,$12,$13)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15MeshRayCollider7collideILi1ELi0EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($orig,$dir,$maxT,$bothSides,$model,$callback,$inflate) {
 $orig = $orig|0;
 $dir = $dir|0;
 $maxT = Math_fround($maxT);
 $bothSides = $bothSides|0;
 $model = $model|0;
 $callback = $callback|0;
 $inflate = $inflate|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0);
 var $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf = 0, $rTreeCallback = 0, $rTreeCallback1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $buf = sp + 504|0;
 $rTreeCallback = sp;
 $0 = sp + 492|0;
 $1 = sp + 480|0;
 $rTreeCallback1 = sp + 240|0;
 $2 = HEAP32[$model>>2]|0;
 $3 = $2;
 $4 = (($3) + 16)|0;
 $5 = $4;
 $6 = (($3) + 8)|0;
 $7 = $6;
 $8 = (($3) + 12)|0;
 $9 = $8;
 $10 = $maxT == Math_fround(0.0);
 if ($10) {
  $11 = HEAP32[$5>>2]|0;
  $12 = (($rTreeCallback) + 4|0);
  HEAP32[$rTreeCallback>>2] = ((552312 + 8|0));
  HEAP32[$12>>2] = ((552312 + 32|0));
  $13 = (($rTreeCallback) + 8|0);
  HEAP32[$13>>2] = $model;
  $14 = (($rTreeCallback) + 12|0);
  HEAP32[$14>>2] = $callback;
  $15 = (($rTreeCallback) + 16|0);
  HEAP32[$15>>2] = $11;
  $16 = (($rTreeCallback) + 20|0);
  HEAP32[$16>>2] = $7;
  $17 = (($rTreeCallback) + 24|0);
  HEAP32[$17>>2] = $9;
  $18 = (($rTreeCallback) + 28|0);
  HEAP32[$18>>2] = $inflate;
  $19 = (($model) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($rTreeCallback) + 32|0);
  $22 = Math_fround(HEAPF32[$orig>>2]);
  HEAPF32[$21>>2] = $22;
  $23 = (($rTreeCallback) + 36|0);
  $24 = (($orig) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$23>>2] = $25;
  $26 = (($rTreeCallback) + 40|0);
  $27 = (($orig) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$26>>2] = $28;
  $29 = (($rTreeCallback) + 44|0);
  $30 = Math_fround(HEAPF32[$dir>>2]);
  HEAPF32[$29>>2] = $30;
  $31 = (($rTreeCallback) + 48|0);
  $32 = (($dir) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$31>>2] = $33;
  $34 = (($rTreeCallback) + 52|0);
  $35 = (($dir) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$34>>2] = $36;
  $37 = (($rTreeCallback) + 56|0);
  $38 = $bothSides&1;
  HEAP8[$37>>0] = $38;
  $39 = (($rTreeCallback) + 60|0);
  HEAPF32[$39>>2] = $20;
  $40 = (($rTreeCallback) + 64|0);
  HEAPF32[$40>>2] = $maxT;
  $41 = (($rTreeCallback) + 68|0);
  HEAP32[$41>>2] = 0;
  $42 = (($rTreeCallback) + 72|0);
  HEAP32[$42>>2] = 0;
  $43 = (($rTreeCallback) + 76|0);
  HEAP32[$43>>2] = -1;
  $44 = (($rTreeCallback) + 80|0);
  HEAP16[$44>>1] = 0;
  $45 = (($rTreeCallback) + 84|0);
  $46 = (($rTreeCallback) + 108|0);
  ;HEAP32[$45+0>>2]=0|0;HEAP32[$45+4>>2]=0|0;HEAP32[$45+8>>2]=0|0;HEAP32[$45+12>>2]=0|0;HEAP32[$45+16>>2]=0|0;HEAP32[$45+20>>2]=0|0;
  HEAPF32[$46>>2] = Math_fround(3.40282346638528859812E+38);
  $47 = (($rTreeCallback) + 112|0);
  HEAPF32[$47>>2] = Math_fround(0.0);
  $48 = (($rTreeCallback) + 116|0);
  HEAPF32[$48>>2] = Math_fround(0.0);
  $49 = (($rTreeCallback) + 181|0);
  $50 = (($callback) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(1);
  $53 = $52&1;
  HEAP8[$49>>0] = $53;
  $54 = (($rTreeCallback) + 180|0);
  HEAP8[$54>>0] = 0;
  $55 = Math_fround(HEAPF32[$inflate>>2]);
  $56 = (($inflate) + 4|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($inflate) + 8|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($rTreeCallback) + 192|0);
  HEAPF32[$60>>2] = $55;
  $61 = (($rTreeCallback) + 196|0);
  HEAPF32[$61>>2] = $57;
  $62 = (($rTreeCallback) + 200|0);
  HEAPF32[$62>>2] = $59;
  $63 = (($rTreeCallback) + 204|0);
  HEAPF32[$63>>2] = Math_fround(0.0);
  $64 = (($rTreeCallback) + 208|0);
  HEAPF32[$64>>2] = $22;
  $65 = (($rTreeCallback) + 212|0);
  HEAPF32[$65>>2] = $25;
  $66 = (($rTreeCallback) + 216|0);
  HEAPF32[$66>>2] = $28;
  $67 = (($rTreeCallback) + 220|0);
  HEAPF32[$67>>2] = Math_fround(0.0);
  $68 = (($rTreeCallback) + 224|0);
  HEAPF32[$68>>2] = $30;
  $69 = (($rTreeCallback) + 228|0);
  HEAPF32[$69>>2] = $33;
  $70 = (($rTreeCallback) + 232|0);
  HEAPF32[$70>>2] = $36;
  $71 = (($rTreeCallback) + 236|0);
  HEAPF32[$71>>2] = Math_fround(0.0);
  $72 = (($model) + 4|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = Math_fround($22 - $55);
  $75 = Math_fround($25 - $57);
  $76 = Math_fround($28 - $59);
  HEAPF32[$0>>2] = $74;
  $77 = (($0) + 4|0);
  HEAPF32[$77>>2] = $75;
  $78 = (($0) + 8|0);
  HEAPF32[$78>>2] = $76;
  $79 = Math_fround($55 + $22);
  $80 = Math_fround($57 + $25);
  $81 = Math_fround($59 + $28);
  HEAPF32[$1>>2] = $79;
  $82 = (($1) + 4|0);
  HEAPF32[$82>>2] = $80;
  $83 = (($1) + 8|0);
  HEAPF32[$83>>2] = $81;
  $84 = (($rTreeCallback) + 4|0);
  __ZNK5physx2Gu5RTree12traverseAABBERKNS_6PxVec3ES4_jPjPNS1_8CallbackE($73,$0,$1,4,$buf,$84);
  HEAP32[$rTreeCallback>>2] = ((552312 + 8|0));
  HEAP32[$12>>2] = ((552312 + 32|0));
  $85 = HEAP8[$54>>0]|0;
  $86 = ($85<<24>>24)==(0);
  if ($86) {
   STACKTOP = sp;return;
  }
  $87 = HEAP32[$14>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = HEAP32[$88>>2]|0;
  $90 = (($rTreeCallback) + 68|0);
  $91 = (($rTreeCallback) + 132|0);
  $92 = (($rTreeCallback) + 144|0);
  $93 = (($rTreeCallback) + 156|0);
  $94 = (($rTreeCallback) + 168|0);
  (FUNCTION_TABLE_iiiiiiii[$89 & 127]($87,$90,$91,$92,$93,$40,$94)|0);
  STACKTOP = sp;return;
 } else {
  $95 = HEAP32[$5>>2]|0;
  $96 = (($rTreeCallback1) + 4|0);
  HEAP32[$rTreeCallback1>>2] = ((552312 + 8|0));
  HEAP32[$96>>2] = ((552312 + 32|0));
  $97 = (($rTreeCallback1) + 8|0);
  HEAP32[$97>>2] = $model;
  $98 = (($rTreeCallback1) + 12|0);
  HEAP32[$98>>2] = $callback;
  $99 = (($rTreeCallback1) + 16|0);
  HEAP32[$99>>2] = $95;
  $100 = (($rTreeCallback1) + 20|0);
  HEAP32[$100>>2] = $7;
  $101 = (($rTreeCallback1) + 24|0);
  HEAP32[$101>>2] = $9;
  $102 = (($rTreeCallback1) + 28|0);
  HEAP32[$102>>2] = $inflate;
  $103 = (($model) + 8|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = (($rTreeCallback1) + 32|0);
  $106 = Math_fround(HEAPF32[$orig>>2]);
  HEAPF32[$105>>2] = $106;
  $107 = (($rTreeCallback1) + 36|0);
  $108 = (($orig) + 4|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  HEAPF32[$107>>2] = $109;
  $110 = (($rTreeCallback1) + 40|0);
  $111 = (($orig) + 8|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  HEAPF32[$110>>2] = $112;
  $113 = (($rTreeCallback1) + 44|0);
  $114 = Math_fround(HEAPF32[$dir>>2]);
  HEAPF32[$113>>2] = $114;
  $115 = (($rTreeCallback1) + 48|0);
  $116 = (($dir) + 4|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  HEAPF32[$115>>2] = $117;
  $118 = (($rTreeCallback1) + 52|0);
  $119 = (($dir) + 8|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  HEAPF32[$118>>2] = $120;
  $121 = (($rTreeCallback1) + 56|0);
  $122 = $bothSides&1;
  HEAP8[$121>>0] = $122;
  $123 = (($rTreeCallback1) + 60|0);
  HEAPF32[$123>>2] = $104;
  $124 = (($rTreeCallback1) + 64|0);
  HEAPF32[$124>>2] = $maxT;
  $125 = (($rTreeCallback1) + 68|0);
  HEAP32[$125>>2] = 0;
  $126 = (($rTreeCallback1) + 72|0);
  HEAP32[$126>>2] = 0;
  $127 = (($rTreeCallback1) + 76|0);
  HEAP32[$127>>2] = -1;
  $128 = (($rTreeCallback1) + 80|0);
  HEAP16[$128>>1] = 0;
  $129 = (($rTreeCallback1) + 84|0);
  $130 = (($rTreeCallback1) + 108|0);
  ;HEAP32[$129+0>>2]=0|0;HEAP32[$129+4>>2]=0|0;HEAP32[$129+8>>2]=0|0;HEAP32[$129+12>>2]=0|0;HEAP32[$129+16>>2]=0|0;HEAP32[$129+20>>2]=0|0;
  HEAPF32[$130>>2] = Math_fround(3.40282346638528859812E+38);
  $131 = (($rTreeCallback1) + 112|0);
  HEAPF32[$131>>2] = Math_fround(0.0);
  $132 = (($rTreeCallback1) + 116|0);
  HEAPF32[$132>>2] = Math_fround(0.0);
  $133 = (($rTreeCallback1) + 181|0);
  $134 = (($callback) + 4|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ($135|0)==(1);
  $137 = $136&1;
  HEAP8[$133>>0] = $137;
  $138 = (($rTreeCallback1) + 180|0);
  HEAP8[$138>>0] = 0;
  $139 = Math_fround(HEAPF32[$inflate>>2]);
  $140 = (($inflate) + 4|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = (($inflate) + 8|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = (($rTreeCallback1) + 192|0);
  HEAPF32[$144>>2] = $139;
  $145 = (($rTreeCallback1) + 196|0);
  HEAPF32[$145>>2] = $141;
  $146 = (($rTreeCallback1) + 200|0);
  HEAPF32[$146>>2] = $143;
  $147 = (($rTreeCallback1) + 204|0);
  HEAPF32[$147>>2] = Math_fround(0.0);
  $148 = (($rTreeCallback1) + 208|0);
  HEAPF32[$148>>2] = $106;
  $149 = (($rTreeCallback1) + 212|0);
  HEAPF32[$149>>2] = $109;
  $150 = (($rTreeCallback1) + 216|0);
  HEAPF32[$150>>2] = $112;
  $151 = (($rTreeCallback1) + 220|0);
  HEAPF32[$151>>2] = Math_fround(0.0);
  $152 = (($rTreeCallback1) + 224|0);
  HEAPF32[$152>>2] = $114;
  $153 = (($rTreeCallback1) + 228|0);
  HEAPF32[$153>>2] = $117;
  $154 = (($rTreeCallback1) + 232|0);
  HEAPF32[$154>>2] = $120;
  $155 = (($rTreeCallback1) + 236|0);
  HEAPF32[$155>>2] = Math_fround(0.0);
  $156 = (($model) + 4|0);
  $157 = HEAP32[$156>>2]|0;
  __ZNK5physx2Gu5RTree11traverseRayILi1EEEvRKNS_6PxVec3ES5_jPjPNS1_15CallbackRaycastEPS4_f($157,$orig,$dir,4,$buf,$rTreeCallback1,$inflate,$maxT);
  HEAP32[$rTreeCallback1>>2] = ((552312 + 8|0));
  HEAP32[$96>>2] = ((552312 + 32|0));
  $158 = HEAP8[$138>>0]|0;
  $159 = ($158<<24>>24)==(0);
  if ($159) {
   STACKTOP = sp;return;
  }
  $160 = HEAP32[$98>>2]|0;
  $161 = HEAP32[$160>>2]|0;
  $162 = HEAP32[$161>>2]|0;
  $163 = (($rTreeCallback1) + 68|0);
  $164 = (($rTreeCallback1) + 132|0);
  $165 = (($rTreeCallback1) + 144|0);
  $166 = (($rTreeCallback1) + 156|0);
  $167 = (($rTreeCallback1) + 168|0);
  (FUNCTION_TABLE_iiiiiiii[$162 & 127]($160,$163,$164,$165,$166,$124,$167)|0);
  STACKTOP = sp;return;
 }
}
function __ZN16RayRTreeCallbackILi1ELb0EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552312 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((552312 + 32|0));
 $1 = (($this) + 180|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 144|0);
 $11 = (($this) + 156|0);
 $12 = (($this) + 64|0);
 $13 = (($this) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$7 & 127]($5,$8,$9,$10,$11,$12,$13)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15MeshRayCollider7collideILi0ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($orig,$dir,$maxT,$bothSides,$model,$callback,$inflate) {
 $orig = $orig|0;
 $dir = $dir|0;
 $maxT = Math_fround($maxT);
 $bothSides = $bothSides|0;
 $model = $model|0;
 $callback = $callback|0;
 $inflate = $inflate|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $buf = 0, $rTreeCallback = 0, $rTreeCallback1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $buf = sp + 504|0;
 $rTreeCallback = sp;
 $0 = sp + 492|0;
 $1 = sp + 480|0;
 $rTreeCallback1 = sp + 240|0;
 $2 = HEAP32[$model>>2]|0;
 $3 = $2;
 $4 = (($3) + 16)|0;
 $5 = $4;
 $6 = (($3) + 8)|0;
 $7 = $6;
 $8 = (($3) + 12)|0;
 $9 = $8;
 $10 = $maxT == Math_fround(0.0);
 if ($10) {
  $11 = HEAP32[$5>>2]|0;
  $12 = (($rTreeCallback) + 4|0);
  HEAP32[$rTreeCallback>>2] = ((552360 + 8|0));
  HEAP32[$12>>2] = ((552360 + 32|0));
  $13 = (($rTreeCallback) + 8|0);
  HEAP32[$13>>2] = $model;
  $14 = (($rTreeCallback) + 12|0);
  HEAP32[$14>>2] = $callback;
  $15 = (($rTreeCallback) + 16|0);
  HEAP32[$15>>2] = $11;
  $16 = (($rTreeCallback) + 20|0);
  HEAP32[$16>>2] = $7;
  $17 = (($rTreeCallback) + 24|0);
  HEAP32[$17>>2] = $9;
  $18 = (($rTreeCallback) + 28|0);
  HEAP32[$18>>2] = $inflate;
  $19 = (($model) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($rTreeCallback) + 32|0);
  $22 = Math_fround(HEAPF32[$orig>>2]);
  HEAPF32[$21>>2] = $22;
  $23 = (($rTreeCallback) + 36|0);
  $24 = (($orig) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$23>>2] = $25;
  $26 = (($rTreeCallback) + 40|0);
  $27 = (($orig) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$26>>2] = $28;
  $29 = (($rTreeCallback) + 44|0);
  $30 = Math_fround(HEAPF32[$dir>>2]);
  HEAPF32[$29>>2] = $30;
  $31 = (($rTreeCallback) + 48|0);
  $32 = (($dir) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$31>>2] = $33;
  $34 = (($rTreeCallback) + 52|0);
  $35 = (($dir) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$34>>2] = $36;
  $37 = (($rTreeCallback) + 56|0);
  $38 = $bothSides&1;
  HEAP8[$37>>0] = $38;
  $39 = (($rTreeCallback) + 60|0);
  HEAPF32[$39>>2] = $20;
  $40 = (($rTreeCallback) + 64|0);
  HEAPF32[$40>>2] = $maxT;
  $41 = (($rTreeCallback) + 68|0);
  HEAP32[$41>>2] = 0;
  $42 = (($rTreeCallback) + 72|0);
  HEAP32[$42>>2] = 0;
  $43 = (($rTreeCallback) + 76|0);
  HEAP32[$43>>2] = -1;
  $44 = (($rTreeCallback) + 80|0);
  HEAP16[$44>>1] = 0;
  $45 = (($rTreeCallback) + 84|0);
  $46 = (($rTreeCallback) + 108|0);
  ;HEAP32[$45+0>>2]=0|0;HEAP32[$45+4>>2]=0|0;HEAP32[$45+8>>2]=0|0;HEAP32[$45+12>>2]=0|0;HEAP32[$45+16>>2]=0|0;HEAP32[$45+20>>2]=0|0;
  HEAPF32[$46>>2] = Math_fround(3.40282346638528859812E+38);
  $47 = (($rTreeCallback) + 112|0);
  HEAPF32[$47>>2] = Math_fround(0.0);
  $48 = (($rTreeCallback) + 116|0);
  HEAPF32[$48>>2] = Math_fround(0.0);
  $49 = (($rTreeCallback) + 181|0);
  $50 = (($callback) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(1);
  $53 = $52&1;
  HEAP8[$49>>0] = $53;
  $54 = (($rTreeCallback) + 180|0);
  HEAP8[$54>>0] = 0;
  $55 = (($rTreeCallback) + 208|0);
  HEAPF32[$55>>2] = $22;
  $56 = (($rTreeCallback) + 212|0);
  HEAPF32[$56>>2] = $25;
  $57 = (($rTreeCallback) + 216|0);
  HEAPF32[$57>>2] = $28;
  $58 = (($rTreeCallback) + 220|0);
  HEAPF32[$58>>2] = Math_fround(0.0);
  $59 = (($rTreeCallback) + 224|0);
  HEAPF32[$59>>2] = $30;
  $60 = (($rTreeCallback) + 228|0);
  HEAPF32[$60>>2] = $33;
  $61 = (($rTreeCallback) + 232|0);
  HEAPF32[$61>>2] = $36;
  $62 = (($rTreeCallback) + 236|0);
  HEAPF32[$62>>2] = Math_fround(0.0);
  $63 = (($model) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  HEAPF32[$0>>2] = $22;
  $65 = (($0) + 4|0);
  HEAPF32[$65>>2] = $25;
  $66 = (($0) + 8|0);
  HEAPF32[$66>>2] = $28;
  $67 = Math_fround($22 + Math_fround(0.0));
  $68 = Math_fround($25 + Math_fround(0.0));
  $69 = Math_fround($28 + Math_fround(0.0));
  HEAPF32[$1>>2] = $67;
  $70 = (($1) + 4|0);
  HEAPF32[$70>>2] = $68;
  $71 = (($1) + 8|0);
  HEAPF32[$71>>2] = $69;
  $72 = (($rTreeCallback) + 4|0);
  __ZNK5physx2Gu5RTree12traverseAABBERKNS_6PxVec3ES4_jPjPNS1_8CallbackE($64,$0,$1,4,$buf,$72);
  HEAP32[$rTreeCallback>>2] = ((552360 + 8|0));
  HEAP32[$12>>2] = ((552360 + 32|0));
  $73 = HEAP8[$54>>0]|0;
  $74 = ($73<<24>>24)==(0);
  if ($74) {
   STACKTOP = sp;return;
  }
  $75 = HEAP32[$14>>2]|0;
  $76 = HEAP32[$75>>2]|0;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($rTreeCallback) + 68|0);
  $79 = (($rTreeCallback) + 132|0);
  $80 = (($rTreeCallback) + 144|0);
  $81 = (($rTreeCallback) + 156|0);
  $82 = (($rTreeCallback) + 168|0);
  (FUNCTION_TABLE_iiiiiiii[$77 & 127]($75,$78,$79,$80,$81,$40,$82)|0);
  STACKTOP = sp;return;
 } else {
  $83 = HEAP32[$5>>2]|0;
  $84 = (($rTreeCallback1) + 4|0);
  HEAP32[$rTreeCallback1>>2] = ((552264 + 8|0));
  HEAP32[$84>>2] = ((552264 + 32|0));
  $85 = (($rTreeCallback1) + 8|0);
  HEAP32[$85>>2] = $model;
  $86 = (($rTreeCallback1) + 12|0);
  HEAP32[$86>>2] = $callback;
  $87 = (($rTreeCallback1) + 16|0);
  HEAP32[$87>>2] = $83;
  $88 = (($rTreeCallback1) + 20|0);
  HEAP32[$88>>2] = $7;
  $89 = (($rTreeCallback1) + 24|0);
  HEAP32[$89>>2] = $9;
  $90 = (($rTreeCallback1) + 28|0);
  HEAP32[$90>>2] = $inflate;
  $91 = (($model) + 8|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = (($rTreeCallback1) + 32|0);
  $94 = Math_fround(HEAPF32[$orig>>2]);
  HEAPF32[$93>>2] = $94;
  $95 = (($rTreeCallback1) + 36|0);
  $96 = (($orig) + 4|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  HEAPF32[$95>>2] = $97;
  $98 = (($rTreeCallback1) + 40|0);
  $99 = (($orig) + 8|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  HEAPF32[$98>>2] = $100;
  $101 = (($rTreeCallback1) + 44|0);
  $102 = Math_fround(HEAPF32[$dir>>2]);
  HEAPF32[$101>>2] = $102;
  $103 = (($rTreeCallback1) + 48|0);
  $104 = (($dir) + 4|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  HEAPF32[$103>>2] = $105;
  $106 = (($rTreeCallback1) + 52|0);
  $107 = (($dir) + 8|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  HEAPF32[$106>>2] = $108;
  $109 = (($rTreeCallback1) + 56|0);
  $110 = $bothSides&1;
  HEAP8[$109>>0] = $110;
  $111 = (($rTreeCallback1) + 60|0);
  HEAPF32[$111>>2] = $92;
  $112 = (($rTreeCallback1) + 64|0);
  HEAPF32[$112>>2] = $maxT;
  $113 = (($rTreeCallback1) + 68|0);
  HEAP32[$113>>2] = 0;
  $114 = (($rTreeCallback1) + 72|0);
  HEAP32[$114>>2] = 0;
  $115 = (($rTreeCallback1) + 76|0);
  HEAP32[$115>>2] = -1;
  $116 = (($rTreeCallback1) + 80|0);
  HEAP16[$116>>1] = 0;
  $117 = (($rTreeCallback1) + 84|0);
  $118 = (($rTreeCallback1) + 108|0);
  ;HEAP32[$117+0>>2]=0|0;HEAP32[$117+4>>2]=0|0;HEAP32[$117+8>>2]=0|0;HEAP32[$117+12>>2]=0|0;HEAP32[$117+16>>2]=0|0;HEAP32[$117+20>>2]=0|0;
  HEAPF32[$118>>2] = Math_fround(3.40282346638528859812E+38);
  $119 = (($rTreeCallback1) + 112|0);
  HEAPF32[$119>>2] = Math_fround(0.0);
  $120 = (($rTreeCallback1) + 116|0);
  HEAPF32[$120>>2] = Math_fround(0.0);
  $121 = (($rTreeCallback1) + 181|0);
  $122 = (($callback) + 4|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)==(1);
  $125 = $124&1;
  HEAP8[$121>>0] = $125;
  $126 = (($rTreeCallback1) + 180|0);
  HEAP8[$126>>0] = 0;
  $127 = (($rTreeCallback1) + 208|0);
  HEAPF32[$127>>2] = $94;
  $128 = (($rTreeCallback1) + 212|0);
  HEAPF32[$128>>2] = $97;
  $129 = (($rTreeCallback1) + 216|0);
  HEAPF32[$129>>2] = $100;
  $130 = (($rTreeCallback1) + 220|0);
  HEAPF32[$130>>2] = Math_fround(0.0);
  $131 = (($rTreeCallback1) + 224|0);
  HEAPF32[$131>>2] = $102;
  $132 = (($rTreeCallback1) + 228|0);
  HEAPF32[$132>>2] = $105;
  $133 = (($rTreeCallback1) + 232|0);
  HEAPF32[$133>>2] = $108;
  $134 = (($rTreeCallback1) + 236|0);
  HEAPF32[$134>>2] = Math_fround(0.0);
  $135 = (($model) + 4|0);
  $136 = HEAP32[$135>>2]|0;
  __ZNK5physx2Gu5RTree11traverseRayILi0EEEvRKNS_6PxVec3ES5_jPjPNS1_15CallbackRaycastEPS4_f($136,$orig,$dir,4,$buf,$rTreeCallback1,$inflate,$maxT);
  HEAP32[$rTreeCallback1>>2] = ((552264 + 8|0));
  HEAP32[$84>>2] = ((552264 + 32|0));
  $137 = HEAP8[$126>>0]|0;
  $138 = ($137<<24>>24)==(0);
  if ($138) {
   STACKTOP = sp;return;
  }
  $139 = HEAP32[$86>>2]|0;
  $140 = HEAP32[$139>>2]|0;
  $141 = HEAP32[$140>>2]|0;
  $142 = (($rTreeCallback1) + 68|0);
  $143 = (($rTreeCallback1) + 132|0);
  $144 = (($rTreeCallback1) + 144|0);
  $145 = (($rTreeCallback1) + 156|0);
  $146 = (($rTreeCallback1) + 168|0);
  (FUNCTION_TABLE_iiiiiiii[$141 & 127]($139,$142,$143,$144,$145,$112,$146)|0);
  STACKTOP = sp;return;
 }
}
function __ZN16RayRTreeCallbackILi0ELb1EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552264 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((552264 + 32|0));
 $1 = (($this) + 180|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 144|0);
 $11 = (($this) + 156|0);
 $12 = (($this) + 64|0);
 $13 = (($this) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$7 & 127]($5,$8,$9,$10,$11,$12,$13)|0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15MeshRayCollider7collideILi1ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($orig,$dir,$maxT,$bothSides,$model,$callback,$inflate) {
 $orig = $orig|0;
 $dir = $dir|0;
 $maxT = Math_fround($maxT);
 $bothSides = $bothSides|0;
 $model = $model|0;
 $callback = $callback|0;
 $inflate = $inflate|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0);
 var $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf = 0, $rTreeCallback = 0, $rTreeCallback1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $buf = sp + 504|0;
 $rTreeCallback = sp;
 $0 = sp + 492|0;
 $1 = sp + 480|0;
 $rTreeCallback1 = sp + 240|0;
 $2 = HEAP32[$model>>2]|0;
 $3 = $2;
 $4 = (($3) + 16)|0;
 $5 = $4;
 $6 = (($3) + 8)|0;
 $7 = $6;
 $8 = (($3) + 12)|0;
 $9 = $8;
 $10 = $maxT == Math_fround(0.0);
 if ($10) {
  $11 = HEAP32[$5>>2]|0;
  $12 = (($rTreeCallback) + 4|0);
  HEAP32[$rTreeCallback>>2] = ((552312 + 8|0));
  HEAP32[$12>>2] = ((552312 + 32|0));
  $13 = (($rTreeCallback) + 8|0);
  HEAP32[$13>>2] = $model;
  $14 = (($rTreeCallback) + 12|0);
  HEAP32[$14>>2] = $callback;
  $15 = (($rTreeCallback) + 16|0);
  HEAP32[$15>>2] = $11;
  $16 = (($rTreeCallback) + 20|0);
  HEAP32[$16>>2] = $7;
  $17 = (($rTreeCallback) + 24|0);
  HEAP32[$17>>2] = $9;
  $18 = (($rTreeCallback) + 28|0);
  HEAP32[$18>>2] = $inflate;
  $19 = (($model) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($rTreeCallback) + 32|0);
  $22 = Math_fround(HEAPF32[$orig>>2]);
  HEAPF32[$21>>2] = $22;
  $23 = (($rTreeCallback) + 36|0);
  $24 = (($orig) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$23>>2] = $25;
  $26 = (($rTreeCallback) + 40|0);
  $27 = (($orig) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$26>>2] = $28;
  $29 = (($rTreeCallback) + 44|0);
  $30 = Math_fround(HEAPF32[$dir>>2]);
  HEAPF32[$29>>2] = $30;
  $31 = (($rTreeCallback) + 48|0);
  $32 = (($dir) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$31>>2] = $33;
  $34 = (($rTreeCallback) + 52|0);
  $35 = (($dir) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$34>>2] = $36;
  $37 = (($rTreeCallback) + 56|0);
  $38 = $bothSides&1;
  HEAP8[$37>>0] = $38;
  $39 = (($rTreeCallback) + 60|0);
  HEAPF32[$39>>2] = $20;
  $40 = (($rTreeCallback) + 64|0);
  HEAPF32[$40>>2] = $maxT;
  $41 = (($rTreeCallback) + 68|0);
  HEAP32[$41>>2] = 0;
  $42 = (($rTreeCallback) + 72|0);
  HEAP32[$42>>2] = 0;
  $43 = (($rTreeCallback) + 76|0);
  HEAP32[$43>>2] = -1;
  $44 = (($rTreeCallback) + 80|0);
  HEAP16[$44>>1] = 0;
  $45 = (($rTreeCallback) + 84|0);
  $46 = (($rTreeCallback) + 108|0);
  ;HEAP32[$45+0>>2]=0|0;HEAP32[$45+4>>2]=0|0;HEAP32[$45+8>>2]=0|0;HEAP32[$45+12>>2]=0|0;HEAP32[$45+16>>2]=0|0;HEAP32[$45+20>>2]=0|0;
  HEAPF32[$46>>2] = Math_fround(3.40282346638528859812E+38);
  $47 = (($rTreeCallback) + 112|0);
  HEAPF32[$47>>2] = Math_fround(0.0);
  $48 = (($rTreeCallback) + 116|0);
  HEAPF32[$48>>2] = Math_fround(0.0);
  $49 = (($rTreeCallback) + 181|0);
  $50 = (($callback) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(1);
  $53 = $52&1;
  HEAP8[$49>>0] = $53;
  $54 = (($rTreeCallback) + 180|0);
  HEAP8[$54>>0] = 0;
  $55 = Math_fround(HEAPF32[$inflate>>2]);
  $56 = (($inflate) + 4|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($inflate) + 8|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($rTreeCallback) + 192|0);
  HEAPF32[$60>>2] = $55;
  $61 = (($rTreeCallback) + 196|0);
  HEAPF32[$61>>2] = $57;
  $62 = (($rTreeCallback) + 200|0);
  HEAPF32[$62>>2] = $59;
  $63 = (($rTreeCallback) + 204|0);
  HEAPF32[$63>>2] = Math_fround(0.0);
  $64 = (($rTreeCallback) + 208|0);
  HEAPF32[$64>>2] = $22;
  $65 = (($rTreeCallback) + 212|0);
  HEAPF32[$65>>2] = $25;
  $66 = (($rTreeCallback) + 216|0);
  HEAPF32[$66>>2] = $28;
  $67 = (($rTreeCallback) + 220|0);
  HEAPF32[$67>>2] = Math_fround(0.0);
  $68 = (($rTreeCallback) + 224|0);
  HEAPF32[$68>>2] = $30;
  $69 = (($rTreeCallback) + 228|0);
  HEAPF32[$69>>2] = $33;
  $70 = (($rTreeCallback) + 232|0);
  HEAPF32[$70>>2] = $36;
  $71 = (($rTreeCallback) + 236|0);
  HEAPF32[$71>>2] = Math_fround(0.0);
  $72 = (($model) + 4|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = Math_fround($22 - $55);
  $75 = Math_fround($25 - $57);
  $76 = Math_fround($28 - $59);
  HEAPF32[$0>>2] = $74;
  $77 = (($0) + 4|0);
  HEAPF32[$77>>2] = $75;
  $78 = (($0) + 8|0);
  HEAPF32[$78>>2] = $76;
  $79 = Math_fround($55 + $22);
  $80 = Math_fround($57 + $25);
  $81 = Math_fround($59 + $28);
  HEAPF32[$1>>2] = $79;
  $82 = (($1) + 4|0);
  HEAPF32[$82>>2] = $80;
  $83 = (($1) + 8|0);
  HEAPF32[$83>>2] = $81;
  $84 = (($rTreeCallback) + 4|0);
  __ZNK5physx2Gu5RTree12traverseAABBERKNS_6PxVec3ES4_jPjPNS1_8CallbackE($73,$0,$1,4,$buf,$84);
  HEAP32[$rTreeCallback>>2] = ((552312 + 8|0));
  HEAP32[$12>>2] = ((552312 + 32|0));
  $85 = HEAP8[$54>>0]|0;
  $86 = ($85<<24>>24)==(0);
  if ($86) {
   STACKTOP = sp;return;
  }
  $87 = HEAP32[$14>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = HEAP32[$88>>2]|0;
  $90 = (($rTreeCallback) + 68|0);
  $91 = (($rTreeCallback) + 132|0);
  $92 = (($rTreeCallback) + 144|0);
  $93 = (($rTreeCallback) + 156|0);
  $94 = (($rTreeCallback) + 168|0);
  (FUNCTION_TABLE_iiiiiiii[$89 & 127]($87,$90,$91,$92,$93,$40,$94)|0);
  STACKTOP = sp;return;
 } else {
  $95 = HEAP32[$5>>2]|0;
  $96 = (($rTreeCallback1) + 4|0);
  HEAP32[$rTreeCallback1>>2] = ((552216 + 8|0));
  HEAP32[$96>>2] = ((552216 + 32|0));
  $97 = (($rTreeCallback1) + 8|0);
  HEAP32[$97>>2] = $model;
  $98 = (($rTreeCallback1) + 12|0);
  HEAP32[$98>>2] = $callback;
  $99 = (($rTreeCallback1) + 16|0);
  HEAP32[$99>>2] = $95;
  $100 = (($rTreeCallback1) + 20|0);
  HEAP32[$100>>2] = $7;
  $101 = (($rTreeCallback1) + 24|0);
  HEAP32[$101>>2] = $9;
  $102 = (($rTreeCallback1) + 28|0);
  HEAP32[$102>>2] = $inflate;
  $103 = (($model) + 8|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = (($rTreeCallback1) + 32|0);
  $106 = Math_fround(HEAPF32[$orig>>2]);
  HEAPF32[$105>>2] = $106;
  $107 = (($rTreeCallback1) + 36|0);
  $108 = (($orig) + 4|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  HEAPF32[$107>>2] = $109;
  $110 = (($rTreeCallback1) + 40|0);
  $111 = (($orig) + 8|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  HEAPF32[$110>>2] = $112;
  $113 = (($rTreeCallback1) + 44|0);
  $114 = Math_fround(HEAPF32[$dir>>2]);
  HEAPF32[$113>>2] = $114;
  $115 = (($rTreeCallback1) + 48|0);
  $116 = (($dir) + 4|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  HEAPF32[$115>>2] = $117;
  $118 = (($rTreeCallback1) + 52|0);
  $119 = (($dir) + 8|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  HEAPF32[$118>>2] = $120;
  $121 = (($rTreeCallback1) + 56|0);
  $122 = $bothSides&1;
  HEAP8[$121>>0] = $122;
  $123 = (($rTreeCallback1) + 60|0);
  HEAPF32[$123>>2] = $104;
  $124 = (($rTreeCallback1) + 64|0);
  HEAPF32[$124>>2] = $maxT;
  $125 = (($rTreeCallback1) + 68|0);
  HEAP32[$125>>2] = 0;
  $126 = (($rTreeCallback1) + 72|0);
  HEAP32[$126>>2] = 0;
  $127 = (($rTreeCallback1) + 76|0);
  HEAP32[$127>>2] = -1;
  $128 = (($rTreeCallback1) + 80|0);
  HEAP16[$128>>1] = 0;
  $129 = (($rTreeCallback1) + 84|0);
  $130 = (($rTreeCallback1) + 108|0);
  ;HEAP32[$129+0>>2]=0|0;HEAP32[$129+4>>2]=0|0;HEAP32[$129+8>>2]=0|0;HEAP32[$129+12>>2]=0|0;HEAP32[$129+16>>2]=0|0;HEAP32[$129+20>>2]=0|0;
  HEAPF32[$130>>2] = Math_fround(3.40282346638528859812E+38);
  $131 = (($rTreeCallback1) + 112|0);
  HEAPF32[$131>>2] = Math_fround(0.0);
  $132 = (($rTreeCallback1) + 116|0);
  HEAPF32[$132>>2] = Math_fround(0.0);
  $133 = (($rTreeCallback1) + 181|0);
  $134 = (($callback) + 4|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ($135|0)==(1);
  $137 = $136&1;
  HEAP8[$133>>0] = $137;
  $138 = (($rTreeCallback1) + 180|0);
  HEAP8[$138>>0] = 0;
  $139 = Math_fround(HEAPF32[$inflate>>2]);
  $140 = (($inflate) + 4|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = (($inflate) + 8|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = (($rTreeCallback1) + 192|0);
  HEAPF32[$144>>2] = $139;
  $145 = (($rTreeCallback1) + 196|0);
  HEAPF32[$145>>2] = $141;
  $146 = (($rTreeCallback1) + 200|0);
  HEAPF32[$146>>2] = $143;
  $147 = (($rTreeCallback1) + 204|0);
  HEAPF32[$147>>2] = Math_fround(0.0);
  $148 = (($rTreeCallback1) + 208|0);
  HEAPF32[$148>>2] = $106;
  $149 = (($rTreeCallback1) + 212|0);
  HEAPF32[$149>>2] = $109;
  $150 = (($rTreeCallback1) + 216|0);
  HEAPF32[$150>>2] = $112;
  $151 = (($rTreeCallback1) + 220|0);
  HEAPF32[$151>>2] = Math_fround(0.0);
  $152 = (($rTreeCallback1) + 224|0);
  HEAPF32[$152>>2] = $114;
  $153 = (($rTreeCallback1) + 228|0);
  HEAPF32[$153>>2] = $117;
  $154 = (($rTreeCallback1) + 232|0);
  HEAPF32[$154>>2] = $120;
  $155 = (($rTreeCallback1) + 236|0);
  HEAPF32[$155>>2] = Math_fround(0.0);
  $156 = (($model) + 4|0);
  $157 = HEAP32[$156>>2]|0;
  __ZNK5physx2Gu5RTree11traverseRayILi1EEEvRKNS_6PxVec3ES5_jPjPNS1_15CallbackRaycastEPS4_f($157,$orig,$dir,4,$buf,$rTreeCallback1,$inflate,$maxT);
  HEAP32[$rTreeCallback1>>2] = ((552216 + 8|0));
  HEAP32[$96>>2] = ((552216 + 32|0));
  $158 = HEAP8[$138>>0]|0;
  $159 = ($158<<24>>24)==(0);
  if ($159) {
   STACKTOP = sp;return;
  }
  $160 = HEAP32[$98>>2]|0;
  $161 = HEAP32[$160>>2]|0;
  $162 = HEAP32[$161>>2]|0;
  $163 = (($rTreeCallback1) + 68|0);
  $164 = (($rTreeCallback1) + 132|0);
  $165 = (($rTreeCallback1) + 144|0);
  $166 = (($rTreeCallback1) + 156|0);
  $167 = (($rTreeCallback1) + 168|0);
  (FUNCTION_TABLE_iiiiiiii[$162 & 127]($160,$163,$164,$165,$166,$124,$167)|0);
  STACKTOP = sp;return;
 }
}
function __ZN16RayRTreeCallbackILi1ELb1EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552216 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((552216 + 32|0));
 $1 = (($this) + 180|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 144|0);
 $11 = (($this) + 156|0);
 $12 = (($this) + 64|0);
 $13 = (($this) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$7 & 127]($5,$8,$9,$10,$11,$12,$13)|0);
 STACKTOP = sp;return;
}
function __ZThn4_N16RayRTreeCallbackILi1ELb1EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((552216 + 8|0));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = ((552216 + 32|0));
 $2 = (($0) + 180|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 68|0);
 $10 = (($0) + 132|0);
 $11 = (($0) + 144|0);
 $12 = (($0) + 156|0);
 $13 = (($0) + 64|0);
 $14 = (($0) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$8 & 127]($6,$9,$10,$11,$12,$13,$14)|0);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi1ELb1EE14processResultsEjPjRf($this,$NumTouched,$Touched,$newMaxT) {
 $this = $this|0;
 $NumTouched = $NumTouched|0;
 $Touched = $Touched|0;
 $newMaxT = $newMaxT|0;
 var $$$i = Math_fround(0), $$$i16 = Math_fround(0), $$$i22 = Math_fround(0), $$$i28 = Math_fround(0), $$0 = 0, $$1$i = Math_fround(0), $$1$i17 = Math_fround(0), $$1$i23 = Math_fround(0), $$1$i29 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0;
 var $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0);
 var $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0;
 var $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $i$0123 = 0, $leaf$0125 = 0, $shrunkMaxT = 0, $storemerge$i = 0, $tFar = 0, $tNear = 0, $tempHit = 0, $vinds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $tempHit = sp + 96|0;
 $vinds = sp + 80|0;
 $tNear = sp + 16|0;
 $tFar = sp + 32|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 64|0;
 $shrunkMaxT = sp + 92|0;
 HEAP32[$tempHit>>2] = 0;
 $3 = (($tempHit) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tempHit) + 8|0);
 HEAP32[$4>>2] = -1;
 $5 = (($tempHit) + 12|0);
 HEAP16[$5>>1] = 0;
 $6 = (($tempHit) + 16|0);
 $7 = (($tempHit) + 40|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 HEAPF32[$7>>2] = Math_fround(3.40282346638528859812E+38);
 $8 = (($tempHit) + 44|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($tempHit) + 48|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = ($NumTouched|0)==(0);
 if ($10) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 16|0);
 $12 = (($this) + 20|0);
 $13 = (($this) + 24|0);
 $14 = (($vinds) + 4|0);
 $15 = (($vinds) + 8|0);
 $16 = (($this) + 192|0);
 $17 = (($this) + 196|0);
 $18 = (($this) + 200|0);
 $19 = (($0) + 4|0);
 $20 = (($0) + 8|0);
 $21 = (($0) + 12|0);
 $22 = (($1) + 4|0);
 $23 = (($1) + 8|0);
 $24 = (($1) + 12|0);
 $25 = (($this) + 208|0);
 $26 = (($this) + 224|0);
 $27 = (($this) + 64|0);
 $28 = (($this) + 181|0);
 $29 = (($this) + 12|0);
 $30 = (($this) + 108|0);
 $31 = (($this) + 68|0);
 $32 = (($this) + 80|0);
 $33 = (($this) + 84|0);
 $34 = (($tempHit) + 20|0);
 $35 = (($this) + 88|0);
 $36 = (($tempHit) + 24|0);
 $37 = (($this) + 92|0);
 $38 = (($tempHit) + 28|0);
 $39 = (($this) + 96|0);
 $40 = (($tempHit) + 32|0);
 $41 = (($this) + 100|0);
 $42 = (($tempHit) + 36|0);
 $43 = (($this) + 104|0);
 $44 = (($this) + 112|0);
 $45 = (($this) + 132|0);
 $46 = (($this) + 136|0);
 $47 = (($this) + 140|0);
 $48 = (($this) + 144|0);
 $49 = (($this) + 148|0);
 $50 = (($this) + 152|0);
 $51 = (($this) + 156|0);
 $52 = (($this) + 160|0);
 $53 = (($this) + 164|0);
 $54 = (($this) + 168|0);
 $55 = (($this) + 172|0);
 $56 = (($this) + 176|0);
 $57 = (($this) + 180|0);
 $leaf$0125 = 0;
 L4: while(1) {
  $58 = (($Touched) + ($leaf$0125<<2)|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $59 >>> 1;
  $61 = $60 & 15;
  $62 = (($61) + 1)|0;
  $63 = $59 >>> 5;
  $i$0123 = 0;
  while(1) {
   $64 = (($i$0123) + ($63))|0;
   $65 = HEAP32[$11>>2]|0;
   $66 = ($65|0)==(0);
   $67 = HEAP32[$12>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   if ($66) {
    $80 = ($64*12)|0;
    $81 = (($68) + ($80))|0;
    $82 = $81;
    $83 = HEAP32[$82>>2]|0;
    $84 = (($82) + 4|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($82) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $92 = $83;$94 = $85;$storemerge$i = $87;
   } else {
    $69 = ($64*6)|0;
    $70 = (($68) + ($69))|0;
    $71 = $70;
    $72 = HEAP16[$71>>1]|0;
    $73 = $72&65535;
    $74 = (($71) + 2|0);
    $75 = HEAP16[$74>>1]|0;
    $76 = $75&65535;
    $77 = (($71) + 4|0);
    $78 = HEAP16[$77>>1]|0;
    $79 = $78&65535;
    $92 = $73;$94 = $76;$storemerge$i = $79;
   }
   $88 = HEAP32[$13>>2]|0;
   $89 = HEAP32[$88>>2]|0;
   $90 = $89;
   $91 = (($90) + (($92*12)|0)|0);
   $93 = (($90) + (($94*12)|0)|0);
   $95 = (($90) + (($storemerge$i*12)|0)|0);
   HEAP32[$vinds>>2] = $92;
   HEAP32[$14>>2] = $94;
   HEAP32[$15>>2] = $storemerge$i;
   $96 = Math_fround(HEAPF32[$91>>2]);
   $97 = ((($90) + (($92*12)|0)|0) + 4|0);
   $98 = Math_fround(HEAPF32[$97>>2]);
   $99 = ((($90) + (($92*12)|0)|0) + 8|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = Math_fround(HEAPF32[$93>>2]);
   $102 = ((($90) + (($94*12)|0)|0) + 4|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = ((($90) + (($94*12)|0)|0) + 8|0);
   $105 = Math_fround(HEAPF32[$104>>2]);
   $106 = Math_fround(HEAPF32[$95>>2]);
   $107 = ((($90) + (($storemerge$i*12)|0)|0) + 4|0);
   $108 = Math_fround(HEAPF32[$107>>2]);
   $109 = ((($90) + (($storemerge$i*12)|0)|0) + 8|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = $96 < $101;
   $$$i28 = $111 ? $96 : $101;
   $112 = $98 < $103;
   $113 = $112 ? $98 : $103;
   $114 = $100 < $105;
   $$1$i29 = $114 ? $100 : $105;
   $115 = $$$i28 < $106;
   $$$i22 = $115 ? $$$i28 : $106;
   $116 = $113 < $108;
   $117 = $116 ? $113 : $108;
   $118 = $$1$i29 < $110;
   $$1$i23 = $118 ? $$1$i29 : $110;
   $119 = $96 > $101;
   $$$i16 = $119 ? $96 : $101;
   $120 = $98 > $103;
   $121 = $120 ? $98 : $103;
   $122 = $100 > $105;
   $$1$i17 = $122 ? $100 : $105;
   $123 = $$$i16 > $106;
   $$$i = $123 ? $$$i16 : $106;
   $124 = $121 > $108;
   $125 = $124 ? $121 : $108;
   $126 = $$1$i17 > $110;
   $$1$i = $126 ? $$1$i17 : $110;
   $127 = Math_fround(HEAPF32[$16>>2]);
   $128 = Math_fround(HEAPF32[$17>>2]);
   $129 = Math_fround(HEAPF32[$18>>2]);
   $130 = Math_fround($$$i22 - $127);
   $131 = Math_fround($117 - $128);
   $132 = Math_fround($$1$i23 - $129);
   HEAPF32[$0>>2] = $130;
   HEAPF32[$19>>2] = $131;
   HEAPF32[$20>>2] = $132;
   HEAPF32[$21>>2] = Math_fround(0.0);
   $133 = Math_fround($$$i + $127);
   $134 = Math_fround($125 + $128);
   $135 = Math_fround($$1$i + $129);
   HEAPF32[$1>>2] = $133;
   HEAPF32[$22>>2] = $134;
   HEAPF32[$23>>2] = $135;
   HEAPF32[$24>>2] = Math_fround(0.0);
   $136 = Math_fround(HEAPF32[$27>>2]);
   HEAPF32[$2>>2] = $136;
   $137 = (__ZN5physx2Gu17intersectRayAABB2ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_RKNS2_6FloatVERS6_S9_($0,$1,$25,$26,$2,$tNear,$tFar)|0);
   if ($137) {
    $138 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$7>>2] = $138;
    HEAPF32[$9>>2] = Math_fround(0.0);
    HEAPF32[$8>>2] = Math_fround(0.0);
    HEAP32[$4>>2] = $64;
    HEAP16[$5>>1] = 5;
    $139 = HEAP8[$28>>0]|0;
    $140 = ($139<<24>>24)==(0);
    if ($140) {
     $164 = Math_fround(HEAPF32[$newMaxT>>2]);
     HEAPF32[$shrunkMaxT>>2] = $164;
     $165 = HEAP32[$29>>2]|0;
     $166 = HEAP32[$165>>2]|0;
     $167 = HEAP32[$166>>2]|0;
     $168 = (FUNCTION_TABLE_iiiiiiii[$167 & 127]($165,$tempHit,$91,$93,$95,$shrunkMaxT,$vinds)|0);
     if (!($168)) {
      $$0 = 0;
      label = 17;
      break L4;
     }
     $169 = Math_fround(HEAPF32[$shrunkMaxT>>2]);
     $170 = Math_fround(HEAPF32[$newMaxT>>2]);
     $171 = $169 < $170;
     if ($171) {
      HEAPF32[$newMaxT>>2] = $169;
      HEAPF32[$27>>2] = $169;
     }
    } else {
     $141 = Math_fround(HEAPF32[$30>>2]);
     $142 = $138 < $141;
     if ($142) {
      ;HEAP32[$31+0>>2]=HEAP32[$tempHit+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$tempHit+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$tempHit+8>>2]|0;
      HEAP16[$32>>1] = 5;
      $143 = Math_fround(HEAPF32[$6>>2]);
      HEAPF32[$33>>2] = $143;
      $144 = Math_fround(HEAPF32[$34>>2]);
      HEAPF32[$35>>2] = $144;
      $145 = Math_fround(HEAPF32[$36>>2]);
      HEAPF32[$37>>2] = $145;
      $146 = Math_fround(HEAPF32[$38>>2]);
      HEAPF32[$39>>2] = $146;
      $147 = Math_fround(HEAPF32[$40>>2]);
      HEAPF32[$41>>2] = $147;
      $148 = Math_fround(HEAPF32[$42>>2]);
      HEAPF32[$43>>2] = $148;
      HEAPF32[$30>>2] = $138;
      ;HEAP32[$44+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$44+16>>2]=HEAP32[$8+16>>2]|0;
      $149 = Math_fround(HEAPF32[$newMaxT>>2]);
      $150 = $138 < $149;
      $151 = $150 ? $138 : $149;
      HEAPF32[$newMaxT>>2] = $151;
      $152 = Math_fround(HEAPF32[$91>>2]);
      HEAPF32[$45>>2] = $152;
      $153 = Math_fround(HEAPF32[$97>>2]);
      HEAPF32[$46>>2] = $153;
      $154 = Math_fround(HEAPF32[$99>>2]);
      HEAPF32[$47>>2] = $154;
      $155 = Math_fround(HEAPF32[$93>>2]);
      HEAPF32[$48>>2] = $155;
      $156 = Math_fround(HEAPF32[$102>>2]);
      HEAPF32[$49>>2] = $156;
      $157 = Math_fround(HEAPF32[$104>>2]);
      HEAPF32[$50>>2] = $157;
      $158 = Math_fround(HEAPF32[$95>>2]);
      HEAPF32[$51>>2] = $158;
      $159 = Math_fround(HEAPF32[$107>>2]);
      HEAPF32[$52>>2] = $159;
      $160 = Math_fround(HEAPF32[$109>>2]);
      HEAPF32[$53>>2] = $160;
      $161 = HEAP32[$vinds>>2]|0;
      HEAP32[$54>>2] = $161;
      $162 = HEAP32[$14>>2]|0;
      HEAP32[$55>>2] = $162;
      $163 = HEAP32[$15>>2]|0;
      HEAP32[$56>>2] = $163;
      HEAP8[$57>>0] = 1;
     }
    }
    $172 = HEAP32[$29>>2]|0;
    $173 = (($172) + 4|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = ($174|0)==(0);
    if ($175) {
     $$0 = 0;
     label = 17;
     break L4;
    }
   }
   $176 = (($i$0123) + 1)|0;
   $177 = ($176>>>0)<($62>>>0);
   if ($177) {
    $i$0123 = $176;
   } else {
    break;
   }
  }
  $178 = (($leaf$0125) + 1)|0;
  $179 = ($178>>>0)<($NumTouched>>>0);
  if ($179) {
   $leaf$0125 = $178;
  } else {
   $$0 = 1;
   label = 17;
   break;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN16RayRTreeCallbackILi1ELb1EED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552216 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((552216 + 32|0));
 $1 = (($this) + 180|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 144|0);
 $11 = (($this) + 156|0);
 $12 = (($this) + 64|0);
 $13 = (($this) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$7 & 127]($5,$8,$9,$10,$11,$12,$13)|0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi1ELb1EE14processResultsEjPj($this,$numTouched,$touched) {
 $this = $this|0;
 $numTouched = $numTouched|0;
 $touched = $touched|0;
 var $0 = 0, $dummy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dummy = sp;
 $0 = (__ZN16RayRTreeCallbackILi1ELb1EE14processResultsEjPjRf($this,$numTouched,$touched,$dummy)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn4_N16RayRTreeCallbackILi1ELb1EE14processResultsEjPj($this,$numTouched,$touched) {
 $this = $this|0;
 $numTouched = $numTouched|0;
 $touched = $touched|0;
 var $0 = 0, $1 = 0, $dummy$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dummy$i = sp;
 $0 = (($this) + -4|0);
 $1 = (__ZN16RayRTreeCallbackILi1ELb1EE14processResultsEjPjRf($0,$numTouched,$touched,$dummy$i)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Gu5RTree8Callback7profileEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn4_N16RayRTreeCallbackILi1ELb1EED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((552216 + 8|0));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = ((552216 + 32|0));
 $2 = (($0) + 180|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 68|0);
 $10 = (($0) + 132|0);
 $11 = (($0) + 144|0);
 $12 = (($0) + 156|0);
 $13 = (($0) + 64|0);
 $14 = (($0) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$8 & 127]($6,$9,$10,$11,$12,$13,$14)|0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZThn4_N16RayRTreeCallbackILi0ELb1EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((552264 + 8|0));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = ((552264 + 32|0));
 $2 = (($0) + 180|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 68|0);
 $10 = (($0) + 132|0);
 $11 = (($0) + 144|0);
 $12 = (($0) + 156|0);
 $13 = (($0) + 64|0);
 $14 = (($0) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$8 & 127]($6,$9,$10,$11,$12,$13,$14)|0);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi0ELb1EE14processResultsEjPjRf($this,$NumTouched,$Touched,$newMaxT) {
 $this = $this|0;
 $NumTouched = $NumTouched|0;
 $Touched = $Touched|0;
 $newMaxT = $newMaxT|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $i$01 = 0, $leaf$03 = 0, $shrunkMaxT = 0, $storemerge$i = 0;
 var $tempHit = 0, $vinds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tempHit = sp + 16|0;
 $vinds = sp;
 $shrunkMaxT = sp + 12|0;
 HEAP32[$tempHit>>2] = 0;
 $0 = (($tempHit) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($tempHit) + 8|0);
 HEAP32[$1>>2] = -1;
 $2 = (($tempHit) + 12|0);
 HEAP16[$2>>1] = 0;
 $3 = (($tempHit) + 16|0);
 $4 = (($tempHit) + 40|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(3.40282346638528859812E+38);
 $5 = (($tempHit) + 44|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($tempHit) + 48|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = ($NumTouched|0)==(0);
 if ($7) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 16|0);
 $9 = (($this) + 20|0);
 $10 = (($this) + 24|0);
 $11 = (($vinds) + 4|0);
 $12 = (($vinds) + 8|0);
 $13 = (($this) + 32|0);
 $14 = (($this) + 64|0);
 $15 = (($this) + 181|0);
 $16 = (($this) + 12|0);
 $17 = (($this) + 108|0);
 $18 = (($this) + 68|0);
 $19 = (($this) + 80|0);
 $20 = (($this) + 84|0);
 $21 = (($tempHit) + 20|0);
 $22 = (($this) + 88|0);
 $23 = (($tempHit) + 24|0);
 $24 = (($this) + 92|0);
 $25 = (($tempHit) + 28|0);
 $26 = (($this) + 96|0);
 $27 = (($tempHit) + 32|0);
 $28 = (($this) + 100|0);
 $29 = (($tempHit) + 36|0);
 $30 = (($this) + 104|0);
 $31 = (($this) + 112|0);
 $32 = (($this) + 132|0);
 $33 = (($this) + 136|0);
 $34 = (($this) + 140|0);
 $35 = (($this) + 144|0);
 $36 = (($this) + 148|0);
 $37 = (($this) + 152|0);
 $38 = (($this) + 156|0);
 $39 = (($this) + 160|0);
 $40 = (($this) + 164|0);
 $41 = (($this) + 168|0);
 $42 = (($this) + 172|0);
 $43 = (($this) + 176|0);
 $44 = (($this) + 180|0);
 $leaf$03 = 0;
 L4: while(1) {
  $45 = (($Touched) + ($leaf$03<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46 >>> 1;
  $48 = $47 & 15;
  $49 = (($48) + 1)|0;
  $50 = $46 >>> 5;
  $i$01 = 0;
  while(1) {
   $51 = (($i$01) + ($50))|0;
   $52 = HEAP32[$8>>2]|0;
   $53 = ($52|0)==(0);
   $54 = HEAP32[$9>>2]|0;
   $55 = HEAP32[$54>>2]|0;
   if ($53) {
    $67 = ($51*12)|0;
    $68 = (($55) + ($67))|0;
    $69 = $68;
    $70 = HEAP32[$69>>2]|0;
    $71 = (($69) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($69) + 8|0);
    $74 = HEAP32[$73>>2]|0;
    $79 = $70;$81 = $72;$storemerge$i = $74;
   } else {
    $56 = ($51*6)|0;
    $57 = (($55) + ($56))|0;
    $58 = $57;
    $59 = HEAP16[$58>>1]|0;
    $60 = $59&65535;
    $61 = (($58) + 2|0);
    $62 = HEAP16[$61>>1]|0;
    $63 = $62&65535;
    $64 = (($58) + 4|0);
    $65 = HEAP16[$64>>1]|0;
    $66 = $65&65535;
    $79 = $60;$81 = $63;$storemerge$i = $66;
   }
   $75 = HEAP32[$10>>2]|0;
   $76 = HEAP32[$75>>2]|0;
   $77 = $76;
   $78 = (($77) + (($79*12)|0)|0);
   $80 = (($77) + (($81*12)|0)|0);
   $82 = (($77) + (($storemerge$i*12)|0)|0);
   HEAP32[$vinds>>2] = $79;
   HEAP32[$11>>2] = $81;
   HEAP32[$12>>2] = $storemerge$i;
   $83 = (__ZNK19SimpleRayTriOverlap7overlapERKN5physx6PxVec3ES3_S3_RNS0_12PxRaycastHitE($13,$78,$80,$82,$tempHit)|0);
   $84 = ($83|0)==(0);
   if (!($84)) {
    $85 = Math_fround(HEAPF32[$4>>2]);
    $86 = Math_fround(HEAPF32[$14>>2]);
    $87 = !($85 <= $86);
    if (!($87)) {
     HEAP32[$1>>2] = $51;
     HEAP16[$2>>1] = 5;
     $88 = HEAP8[$15>>0]|0;
     $89 = ($88<<24>>24)==(0);
     if ($89) {
      $119 = Math_fround(HEAPF32[$newMaxT>>2]);
      HEAPF32[$shrunkMaxT>>2] = $119;
      $120 = HEAP32[$16>>2]|0;
      $121 = HEAP32[$120>>2]|0;
      $122 = HEAP32[$121>>2]|0;
      $123 = (FUNCTION_TABLE_iiiiiiii[$122 & 127]($120,$tempHit,$78,$80,$82,$shrunkMaxT,$vinds)|0);
      if (!($123)) {
       $$0 = 0;
       label = 18;
       break L4;
      }
      $124 = Math_fround(HEAPF32[$shrunkMaxT>>2]);
      $125 = Math_fround(HEAPF32[$newMaxT>>2]);
      $126 = $124 < $125;
      if ($126) {
       HEAPF32[$newMaxT>>2] = $124;
       HEAPF32[$14>>2] = $124;
      }
     } else {
      $90 = Math_fround(HEAPF32[$17>>2]);
      $91 = $85 < $90;
      if ($91) {
       ;HEAP32[$18+0>>2]=HEAP32[$tempHit+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$tempHit+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$tempHit+8>>2]|0;
       HEAP16[$19>>1] = 5;
       $92 = Math_fround(HEAPF32[$3>>2]);
       HEAPF32[$20>>2] = $92;
       $93 = Math_fround(HEAPF32[$21>>2]);
       HEAPF32[$22>>2] = $93;
       $94 = Math_fround(HEAPF32[$23>>2]);
       HEAPF32[$24>>2] = $94;
       $95 = Math_fround(HEAPF32[$25>>2]);
       HEAPF32[$26>>2] = $95;
       $96 = Math_fround(HEAPF32[$27>>2]);
       HEAPF32[$28>>2] = $96;
       $97 = Math_fround(HEAPF32[$29>>2]);
       HEAPF32[$30>>2] = $97;
       HEAPF32[$17>>2] = $85;
       ;HEAP32[$31+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$31+16>>2]=HEAP32[$5+16>>2]|0;
       $98 = Math_fround(HEAPF32[$newMaxT>>2]);
       $99 = $85 < $98;
       $100 = $99 ? $85 : $98;
       HEAPF32[$newMaxT>>2] = $100;
       $101 = Math_fround(HEAPF32[$78>>2]);
       HEAPF32[$32>>2] = $101;
       $102 = ((($77) + (($79*12)|0)|0) + 4|0);
       $103 = Math_fround(HEAPF32[$102>>2]);
       HEAPF32[$33>>2] = $103;
       $104 = ((($77) + (($79*12)|0)|0) + 8|0);
       $105 = Math_fround(HEAPF32[$104>>2]);
       HEAPF32[$34>>2] = $105;
       $106 = Math_fround(HEAPF32[$80>>2]);
       HEAPF32[$35>>2] = $106;
       $107 = ((($77) + (($81*12)|0)|0) + 4|0);
       $108 = Math_fround(HEAPF32[$107>>2]);
       HEAPF32[$36>>2] = $108;
       $109 = ((($77) + (($81*12)|0)|0) + 8|0);
       $110 = Math_fround(HEAPF32[$109>>2]);
       HEAPF32[$37>>2] = $110;
       $111 = Math_fround(HEAPF32[$82>>2]);
       HEAPF32[$38>>2] = $111;
       $112 = ((($77) + (($storemerge$i*12)|0)|0) + 4|0);
       $113 = Math_fround(HEAPF32[$112>>2]);
       HEAPF32[$39>>2] = $113;
       $114 = ((($77) + (($storemerge$i*12)|0)|0) + 8|0);
       $115 = Math_fround(HEAPF32[$114>>2]);
       HEAPF32[$40>>2] = $115;
       $116 = HEAP32[$vinds>>2]|0;
       HEAP32[$41>>2] = $116;
       $117 = HEAP32[$11>>2]|0;
       HEAP32[$42>>2] = $117;
       $118 = HEAP32[$12>>2]|0;
       HEAP32[$43>>2] = $118;
       HEAP8[$44>>0] = 1;
      }
     }
     $127 = HEAP32[$16>>2]|0;
     $128 = (($127) + 4|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = ($129|0)==(0);
     if ($130) {
      $$0 = 0;
      label = 18;
      break L4;
     }
    }
   }
   $131 = (($i$01) + 1)|0;
   $132 = ($131>>>0)<($49>>>0);
   if ($132) {
    $i$01 = $131;
   } else {
    break;
   }
  }
  $133 = (($leaf$03) + 1)|0;
  $134 = ($133>>>0)<($NumTouched>>>0);
  if ($134) {
   $leaf$03 = $133;
  } else {
   $$0 = 1;
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN16RayRTreeCallbackILi0ELb1EED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552264 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((552264 + 32|0));
 $1 = (($this) + 180|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 144|0);
 $11 = (($this) + 156|0);
 $12 = (($this) + 64|0);
 $13 = (($this) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$7 & 127]($5,$8,$9,$10,$11,$12,$13)|0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi0ELb1EE14processResultsEjPj($this,$numTouched,$touched) {
 $this = $this|0;
 $numTouched = $numTouched|0;
 $touched = $touched|0;
 var $0 = 0, $dummy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dummy = sp;
 $0 = (__ZN16RayRTreeCallbackILi0ELb1EE14processResultsEjPjRf($this,$numTouched,$touched,$dummy)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn4_N16RayRTreeCallbackILi0ELb1EE14processResultsEjPj($this,$numTouched,$touched) {
 $this = $this|0;
 $numTouched = $numTouched|0;
 $touched = $touched|0;
 var $0 = 0, $1 = 0, $dummy$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dummy$i = sp;
 $0 = (($this) + -4|0);
 $1 = (__ZN16RayRTreeCallbackILi0ELb1EE14processResultsEjPjRf($0,$numTouched,$touched,$dummy$i)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N16RayRTreeCallbackILi0ELb1EED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((552264 + 8|0));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = ((552264 + 32|0));
 $2 = (($0) + 180|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 68|0);
 $10 = (($0) + 132|0);
 $11 = (($0) + 144|0);
 $12 = (($0) + 156|0);
 $13 = (($0) + 64|0);
 $14 = (($0) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$8 & 127]($6,$9,$10,$11,$12,$13,$14)|0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZNK19SimpleRayTriOverlap7overlapERKN5physx6PxVec3ES3_S3_RNS0_12PxRaycastHitE($this,$vert0,$vert1,$vert2,$hit) {
 $this = $this|0;
 $vert0 = $vert0|0;
 $vert1 = $vert1|0;
 $vert2 = $vert2|0;
 $hit = $hit|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0;
 var $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $fabsf$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$vert1>>2]);
 $1 = Math_fround(HEAPF32[$vert0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($vert1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($vert0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($vert1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($vert0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$vert2>>2]);
 $14 = Math_fround($13 - $1);
 $15 = (($vert2) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 - $6);
 $18 = (($vert2) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 - $11);
 $21 = (($this) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $20);
 $24 = (($this) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($17 * $25);
 $27 = Math_fround($23 - $26);
 $28 = Math_fround($14 * $25);
 $29 = (($this) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($20 * $30);
 $32 = Math_fround($28 - $31);
 $33 = Math_fround($17 * $30);
 $34 = Math_fround($14 * $22);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($2 * $27);
 $37 = Math_fround($7 * $32);
 $38 = Math_fround($36 + $37);
 $39 = Math_fround($12 * $35);
 $40 = Math_fround($39 + $38);
 $41 = (($this) + 28|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 24|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if ($45) {
  $46 = $40 < $42;
  if ($46) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $47 = Math_fround(HEAPF32[$this>>2]);
  $48 = Math_fround($47 - $1);
  $49 = (($this) + 4|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($50 - $6);
  $52 = (($this) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($53 - $11);
  $55 = Math_fround($27 * $48);
  $56 = Math_fround($32 * $51);
  $57 = Math_fround($55 + $56);
  $58 = Math_fround($35 * $54);
  $59 = Math_fround($57 + $58);
  $60 = Math_fround(-$42);
  $61 = $59 < $60;
  if ($61) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $62 = Math_fround($42 + $40);
  $63 = $59 > $62;
  if ($63) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $64 = Math_fround($12 * $51);
  $65 = Math_fround($7 * $54);
  $66 = Math_fround($64 - $65);
  $67 = Math_fround($2 * $54);
  $68 = Math_fround($12 * $48);
  $69 = Math_fround($67 - $68);
  $70 = Math_fround($7 * $48);
  $71 = Math_fround($2 * $51);
  $72 = Math_fround($70 - $71);
  $73 = Math_fround($30 * $66);
  $74 = Math_fround($22 * $69);
  $75 = Math_fround($73 + $74);
  $76 = Math_fround($25 * $72);
  $77 = Math_fround($76 + $75);
  $78 = $77 < $60;
  if ($78) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $79 = Math_fround($59 + $77);
  $80 = $79 > $62;
  if ($80) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $81 = Math_fround($14 * $66);
  $82 = Math_fround($17 * $69);
  $83 = Math_fround($81 + $82);
  $84 = Math_fround($20 * $72);
  $85 = Math_fround($84 + $83);
  $86 = $85 < $60;
  if ($86) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $87 = Math_fround(Math_fround(1.0) / $40);
  $88 = Math_fround($85 * $87);
  $89 = (($hit) + 40|0);
  HEAPF32[$89>>2] = $88;
  $90 = Math_fround($59 * $87);
  $91 = (($hit) + 44|0);
  HEAPF32[$91>>2] = $90;
  $92 = Math_fround($77 * $87);
  $93 = (($hit) + 48|0);
  HEAPF32[$93>>2] = $92;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $fabsf$i$i = (Math_fround(Math_abs((Math_fround($40)))));
  $94 = $fabsf$i$i < $42;
  if ($94) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $95 = Math_fround(Math_fround(1.0) / $40);
  $96 = Math_fround(HEAPF32[$this>>2]);
  $97 = Math_fround($96 - $1);
  $98 = (($this) + 4|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = Math_fround($99 - $6);
  $101 = (($this) + 8|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($102 - $11);
  $104 = Math_fround($27 * $97);
  $105 = Math_fround($32 * $100);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($35 * $103);
  $108 = Math_fround($106 + $107);
  $109 = Math_fround($95 * $108);
  $110 = Math_fround(-$42);
  $111 = $109 < $110;
  if ($111) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $112 = Math_fround($42 + Math_fround(1.0));
  $113 = $109 > $112;
  if ($113) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $114 = Math_fround($12 * $100);
  $115 = Math_fround($7 * $103);
  $116 = Math_fround($114 - $115);
  $117 = Math_fround($2 * $103);
  $118 = Math_fround($12 * $97);
  $119 = Math_fround($117 - $118);
  $120 = Math_fround($7 * $97);
  $121 = Math_fround($2 * $100);
  $122 = Math_fround($120 - $121);
  $123 = Math_fround($30 * $116);
  $124 = Math_fround($22 * $119);
  $125 = Math_fround($123 + $124);
  $126 = Math_fround($25 * $122);
  $127 = Math_fround($126 + $125);
  $128 = Math_fround($95 * $127);
  $129 = $128 < $110;
  if ($129) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $130 = Math_fround($109 + $128);
  $131 = $130 > $112;
  if ($131) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $132 = Math_fround($14 * $116);
  $133 = Math_fround($17 * $119);
  $134 = Math_fround($132 + $133);
  $135 = Math_fround($20 * $122);
  $136 = Math_fround($135 + $134);
  $137 = Math_fround($95 * $136);
  $138 = $137 < $110;
  if ($138) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $139 = (($hit) + 40|0);
  HEAPF32[$139>>2] = $137;
  $140 = (($hit) + 44|0);
  HEAPF32[$140>>2] = $109;
  $141 = (($hit) + 48|0);
  HEAPF32[$141>>2] = $128;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZThn4_N16RayRTreeCallbackILi1ELb0EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((552312 + 8|0));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = ((552312 + 32|0));
 $2 = (($0) + 180|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 68|0);
 $10 = (($0) + 132|0);
 $11 = (($0) + 144|0);
 $12 = (($0) + 156|0);
 $13 = (($0) + 64|0);
 $14 = (($0) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$8 & 127]($6,$9,$10,$11,$12,$13,$14)|0);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi1ELb0EE14processResultsEjPjRf($this,$NumTouched,$Touched,$newMaxT) {
 $this = $this|0;
 $NumTouched = $NumTouched|0;
 $Touched = $Touched|0;
 $newMaxT = $newMaxT|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $i$01 = 0, $leaf$03 = 0, $shrunkMaxT = 0, $tempHit = 0, $vinds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tempHit = sp + 16|0;
 $vinds = sp;
 $shrunkMaxT = sp + 12|0;
 HEAP32[$tempHit>>2] = 0;
 $0 = (($tempHit) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($tempHit) + 8|0);
 HEAP32[$1>>2] = -1;
 $2 = (($tempHit) + 12|0);
 HEAP16[$2>>1] = 0;
 $3 = (($tempHit) + 16|0);
 $4 = (($tempHit) + 40|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(3.40282346638528859812E+38);
 $5 = (($tempHit) + 44|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($tempHit) + 48|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = ($NumTouched|0)==(0);
 if ($7) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 16|0);
 $9 = (($this) + 20|0);
 $10 = (($this) + 24|0);
 $11 = (($vinds) + 4|0);
 $12 = (($vinds) + 8|0);
 $13 = (($this) + 181|0);
 $14 = (($this) + 12|0);
 $15 = (($this) + 64|0);
 $16 = (($this) + 108|0);
 $17 = (($this) + 68|0);
 $18 = (($this) + 80|0);
 $19 = (($this) + 84|0);
 $20 = (($tempHit) + 20|0);
 $21 = (($this) + 88|0);
 $22 = (($tempHit) + 24|0);
 $23 = (($this) + 92|0);
 $24 = (($tempHit) + 28|0);
 $25 = (($this) + 96|0);
 $26 = (($tempHit) + 32|0);
 $27 = (($this) + 100|0);
 $28 = (($tempHit) + 36|0);
 $29 = (($this) + 104|0);
 $30 = (($this) + 112|0);
 $31 = (($this) + 132|0);
 $32 = (($this) + 136|0);
 $33 = (($this) + 140|0);
 $34 = (($this) + 144|0);
 $35 = (($this) + 148|0);
 $36 = (($this) + 152|0);
 $37 = (($this) + 156|0);
 $38 = (($this) + 160|0);
 $39 = (($this) + 164|0);
 $40 = (($this) + 168|0);
 $41 = (($this) + 172|0);
 $42 = (($this) + 176|0);
 $43 = (($this) + 180|0);
 $leaf$03 = 0;
 L4: while(1) {
  $44 = (($Touched) + ($leaf$03<<2)|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $45 >>> 1;
  $47 = $46 & 15;
  $48 = (($47) + 1)|0;
  $49 = $45 >>> 5;
  $i$01 = 0;
  while(1) {
   $52 = (($i$01) + ($49))|0;
   $53 = HEAP32[$8>>2]|0;
   $54 = ($53|0)==(0);
   $55 = HEAP32[$9>>2]|0;
   $56 = HEAP32[$55>>2]|0;
   if ($54) {
    $68 = ($52*12)|0;
    $69 = (($56) + ($68))|0;
    $70 = $69;
    $71 = HEAP32[$70>>2]|0;
    $72 = (($70) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($70) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    $80 = $71;$82 = $73;$84 = $75;
   } else {
    $57 = ($52*6)|0;
    $58 = (($56) + ($57))|0;
    $59 = $58;
    $60 = HEAP16[$59>>1]|0;
    $61 = $60&65535;
    $62 = (($59) + 2|0);
    $63 = HEAP16[$62>>1]|0;
    $64 = $63&65535;
    $65 = (($59) + 4|0);
    $66 = HEAP16[$65>>1]|0;
    $67 = $66&65535;
    $80 = $61;$82 = $64;$84 = $67;
   }
   $76 = HEAP32[$10>>2]|0;
   $77 = HEAP32[$76>>2]|0;
   $78 = $77;
   $79 = (($78) + (($80*12)|0)|0);
   $81 = (($78) + (($82*12)|0)|0);
   $83 = (($78) + (($84*12)|0)|0);
   HEAP32[$vinds>>2] = $80;
   HEAP32[$11>>2] = $82;
   HEAP32[$12>>2] = $84;
   HEAP32[$1>>2] = $52;
   HEAP16[$2>>1] = 5;
   $85 = HEAP8[$13>>0]|0;
   $86 = ($85<<24>>24)==(0);
   if ($86) {
    $114 = Math_fround(HEAPF32[$newMaxT>>2]);
    HEAPF32[$shrunkMaxT>>2] = $114;
    $115 = HEAP32[$14>>2]|0;
    $116 = HEAP32[$115>>2]|0;
    $117 = HEAP32[$116>>2]|0;
    $118 = (FUNCTION_TABLE_iiiiiiii[$117 & 127]($115,$tempHit,$79,$81,$83,$shrunkMaxT,$vinds)|0);
    if (!($118)) {
     $$0 = 0;
     label = 16;
     break L4;
    }
    $119 = Math_fround(HEAPF32[$shrunkMaxT>>2]);
    $120 = Math_fround(HEAPF32[$newMaxT>>2]);
    $121 = $119 < $120;
    if ($121) {
     HEAPF32[$newMaxT>>2] = $119;
     HEAPF32[$15>>2] = $119;
    }
   } else {
    $87 = Math_fround(HEAPF32[$4>>2]);
    $88 = Math_fround(HEAPF32[$16>>2]);
    $89 = $87 < $88;
    if ($89) {
     ;HEAP32[$17+0>>2]=HEAP32[$tempHit+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$tempHit+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$tempHit+8>>2]|0;
     HEAP16[$18>>1] = 5;
     $90 = Math_fround(HEAPF32[$3>>2]);
     HEAPF32[$19>>2] = $90;
     $91 = Math_fround(HEAPF32[$20>>2]);
     HEAPF32[$21>>2] = $91;
     $92 = Math_fround(HEAPF32[$22>>2]);
     HEAPF32[$23>>2] = $92;
     $93 = Math_fround(HEAPF32[$24>>2]);
     HEAPF32[$25>>2] = $93;
     $94 = Math_fround(HEAPF32[$26>>2]);
     HEAPF32[$27>>2] = $94;
     $95 = Math_fround(HEAPF32[$28>>2]);
     HEAPF32[$29>>2] = $95;
     HEAPF32[$16>>2] = $87;
     ;HEAP32[$30+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$30+16>>2]=HEAP32[$5+16>>2]|0;
     $96 = Math_fround(HEAPF32[$newMaxT>>2]);
     $97 = $87 < $96;
     $98 = $97 ? $87 : $96;
     HEAPF32[$newMaxT>>2] = $98;
     $99 = Math_fround(HEAPF32[$79>>2]);
     HEAPF32[$31>>2] = $99;
     $100 = ((($78) + (($80*12)|0)|0) + 4|0);
     $101 = Math_fround(HEAPF32[$100>>2]);
     HEAPF32[$32>>2] = $101;
     $102 = ((($78) + (($80*12)|0)|0) + 8|0);
     $103 = Math_fround(HEAPF32[$102>>2]);
     HEAPF32[$33>>2] = $103;
     $104 = Math_fround(HEAPF32[$81>>2]);
     HEAPF32[$34>>2] = $104;
     $105 = ((($78) + (($82*12)|0)|0) + 4|0);
     $106 = Math_fround(HEAPF32[$105>>2]);
     HEAPF32[$35>>2] = $106;
     $107 = ((($78) + (($82*12)|0)|0) + 8|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     HEAPF32[$36>>2] = $108;
     $109 = Math_fround(HEAPF32[$83>>2]);
     HEAPF32[$37>>2] = $109;
     $110 = ((($78) + (($84*12)|0)|0) + 4|0);
     $111 = Math_fround(HEAPF32[$110>>2]);
     HEAPF32[$38>>2] = $111;
     $112 = ((($78) + (($84*12)|0)|0) + 8|0);
     $113 = Math_fround(HEAPF32[$112>>2]);
     HEAPF32[$39>>2] = $113;
     HEAP32[$40>>2] = $80;
     HEAP32[$41>>2] = $82;
     HEAP32[$42>>2] = $84;
     HEAP8[$43>>0] = 1;
    }
   }
   $122 = HEAP32[$14>>2]|0;
   $123 = (($122) + 4|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)==(0);
   $51 = (($i$01) + 1)|0;
   if ($125) {
    $$0 = 0;
    label = 16;
    break L4;
   }
   $50 = ($51>>>0)<($48>>>0);
   if ($50) {
    $i$01 = $51;
   } else {
    break;
   }
  }
  $126 = (($leaf$03) + 1)|0;
  $127 = ($126>>>0)<($NumTouched>>>0);
  if ($127) {
   $leaf$03 = $126;
  } else {
   $$0 = 1;
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN16RayRTreeCallbackILi1ELb0EED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552312 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((552312 + 32|0));
 $1 = (($this) + 180|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 144|0);
 $11 = (($this) + 156|0);
 $12 = (($this) + 64|0);
 $13 = (($this) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$7 & 127]($5,$8,$9,$10,$11,$12,$13)|0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi1ELb0EE14processResultsEjPj($this,$numTouched,$touched) {
 $this = $this|0;
 $numTouched = $numTouched|0;
 $touched = $touched|0;
 var $0 = 0, $dummy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dummy = sp;
 $0 = (__ZN16RayRTreeCallbackILi1ELb0EE14processResultsEjPjRf($this,$numTouched,$touched,$dummy)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn4_N16RayRTreeCallbackILi1ELb0EE14processResultsEjPj($this,$numTouched,$touched) {
 $this = $this|0;
 $numTouched = $numTouched|0;
 $touched = $touched|0;
 var $0 = 0, $1 = 0, $dummy$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dummy$i = sp;
 $0 = (($this) + -4|0);
 $1 = (__ZN16RayRTreeCallbackILi1ELb0EE14processResultsEjPjRf($0,$numTouched,$touched,$dummy$i)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N16RayRTreeCallbackILi1ELb0EED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((552312 + 8|0));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = ((552312 + 32|0));
 $2 = (($0) + 180|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 68|0);
 $10 = (($0) + 132|0);
 $11 = (($0) + 144|0);
 $12 = (($0) + 156|0);
 $13 = (($0) + 64|0);
 $14 = (($0) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$8 & 127]($6,$9,$10,$11,$12,$13,$14)|0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZThn4_N16RayRTreeCallbackILi0ELb0EED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((552360 + 8|0));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = ((552360 + 32|0));
 $2 = (($0) + 180|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 68|0);
 $10 = (($0) + 132|0);
 $11 = (($0) + 144|0);
 $12 = (($0) + 156|0);
 $13 = (($0) + 64|0);
 $14 = (($0) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$8 & 127]($6,$9,$10,$11,$12,$13,$14)|0);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi0ELb0EE14processResultsEjPjRf($this,$NumTouched,$Touched,$newMaxT) {
 $this = $this|0;
 $NumTouched = $NumTouched|0;
 $Touched = $Touched|0;
 $newMaxT = $newMaxT|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $i$01 = 0, $leaf$03 = 0, $shrunkMaxT = 0, $tempHit = 0, $vinds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tempHit = sp + 16|0;
 $vinds = sp;
 $shrunkMaxT = sp + 12|0;
 HEAP32[$tempHit>>2] = 0;
 $0 = (($tempHit) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($tempHit) + 8|0);
 HEAP32[$1>>2] = -1;
 $2 = (($tempHit) + 12|0);
 HEAP16[$2>>1] = 0;
 $3 = (($tempHit) + 16|0);
 $4 = (($tempHit) + 40|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(3.40282346638528859812E+38);
 $5 = (($tempHit) + 44|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($tempHit) + 48|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = ($NumTouched|0)==(0);
 if ($7) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 16|0);
 $9 = (($this) + 20|0);
 $10 = (($this) + 24|0);
 $11 = (($vinds) + 4|0);
 $12 = (($vinds) + 8|0);
 $13 = (($this) + 181|0);
 $14 = (($this) + 12|0);
 $15 = (($this) + 64|0);
 $16 = (($this) + 108|0);
 $17 = (($this) + 68|0);
 $18 = (($this) + 80|0);
 $19 = (($this) + 84|0);
 $20 = (($tempHit) + 20|0);
 $21 = (($this) + 88|0);
 $22 = (($tempHit) + 24|0);
 $23 = (($this) + 92|0);
 $24 = (($tempHit) + 28|0);
 $25 = (($this) + 96|0);
 $26 = (($tempHit) + 32|0);
 $27 = (($this) + 100|0);
 $28 = (($tempHit) + 36|0);
 $29 = (($this) + 104|0);
 $30 = (($this) + 112|0);
 $31 = (($this) + 132|0);
 $32 = (($this) + 136|0);
 $33 = (($this) + 140|0);
 $34 = (($this) + 144|0);
 $35 = (($this) + 148|0);
 $36 = (($this) + 152|0);
 $37 = (($this) + 156|0);
 $38 = (($this) + 160|0);
 $39 = (($this) + 164|0);
 $40 = (($this) + 168|0);
 $41 = (($this) + 172|0);
 $42 = (($this) + 176|0);
 $43 = (($this) + 180|0);
 $leaf$03 = 0;
 L4: while(1) {
  $44 = (($Touched) + ($leaf$03<<2)|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $45 >>> 1;
  $47 = $46 & 15;
  $48 = (($47) + 1)|0;
  $49 = $45 >>> 5;
  $i$01 = 0;
  while(1) {
   $52 = (($i$01) + ($49))|0;
   $53 = HEAP32[$8>>2]|0;
   $54 = ($53|0)==(0);
   $55 = HEAP32[$9>>2]|0;
   $56 = HEAP32[$55>>2]|0;
   if ($54) {
    $68 = ($52*12)|0;
    $69 = (($56) + ($68))|0;
    $70 = $69;
    $71 = HEAP32[$70>>2]|0;
    $72 = (($70) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($70) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    $80 = $71;$82 = $73;$84 = $75;
   } else {
    $57 = ($52*6)|0;
    $58 = (($56) + ($57))|0;
    $59 = $58;
    $60 = HEAP16[$59>>1]|0;
    $61 = $60&65535;
    $62 = (($59) + 2|0);
    $63 = HEAP16[$62>>1]|0;
    $64 = $63&65535;
    $65 = (($59) + 4|0);
    $66 = HEAP16[$65>>1]|0;
    $67 = $66&65535;
    $80 = $61;$82 = $64;$84 = $67;
   }
   $76 = HEAP32[$10>>2]|0;
   $77 = HEAP32[$76>>2]|0;
   $78 = $77;
   $79 = (($78) + (($80*12)|0)|0);
   $81 = (($78) + (($82*12)|0)|0);
   $83 = (($78) + (($84*12)|0)|0);
   HEAP32[$vinds>>2] = $80;
   HEAP32[$11>>2] = $82;
   HEAP32[$12>>2] = $84;
   HEAP32[$1>>2] = $52;
   HEAP16[$2>>1] = 5;
   $85 = HEAP8[$13>>0]|0;
   $86 = ($85<<24>>24)==(0);
   if ($86) {
    $114 = Math_fround(HEAPF32[$newMaxT>>2]);
    HEAPF32[$shrunkMaxT>>2] = $114;
    $115 = HEAP32[$14>>2]|0;
    $116 = HEAP32[$115>>2]|0;
    $117 = HEAP32[$116>>2]|0;
    $118 = (FUNCTION_TABLE_iiiiiiii[$117 & 127]($115,$tempHit,$79,$81,$83,$shrunkMaxT,$vinds)|0);
    if (!($118)) {
     $$0 = 0;
     label = 16;
     break L4;
    }
    $119 = Math_fround(HEAPF32[$shrunkMaxT>>2]);
    $120 = Math_fround(HEAPF32[$newMaxT>>2]);
    $121 = $119 < $120;
    if ($121) {
     HEAPF32[$newMaxT>>2] = $119;
     HEAPF32[$15>>2] = $119;
    }
   } else {
    $87 = Math_fround(HEAPF32[$4>>2]);
    $88 = Math_fround(HEAPF32[$16>>2]);
    $89 = $87 < $88;
    if ($89) {
     ;HEAP32[$17+0>>2]=HEAP32[$tempHit+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$tempHit+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$tempHit+8>>2]|0;
     HEAP16[$18>>1] = 5;
     $90 = Math_fround(HEAPF32[$3>>2]);
     HEAPF32[$19>>2] = $90;
     $91 = Math_fround(HEAPF32[$20>>2]);
     HEAPF32[$21>>2] = $91;
     $92 = Math_fround(HEAPF32[$22>>2]);
     HEAPF32[$23>>2] = $92;
     $93 = Math_fround(HEAPF32[$24>>2]);
     HEAPF32[$25>>2] = $93;
     $94 = Math_fround(HEAPF32[$26>>2]);
     HEAPF32[$27>>2] = $94;
     $95 = Math_fround(HEAPF32[$28>>2]);
     HEAPF32[$29>>2] = $95;
     HEAPF32[$16>>2] = $87;
     ;HEAP32[$30+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$30+16>>2]=HEAP32[$5+16>>2]|0;
     $96 = Math_fround(HEAPF32[$newMaxT>>2]);
     $97 = $87 < $96;
     $98 = $97 ? $87 : $96;
     HEAPF32[$newMaxT>>2] = $98;
     $99 = Math_fround(HEAPF32[$79>>2]);
     HEAPF32[$31>>2] = $99;
     $100 = ((($78) + (($80*12)|0)|0) + 4|0);
     $101 = Math_fround(HEAPF32[$100>>2]);
     HEAPF32[$32>>2] = $101;
     $102 = ((($78) + (($80*12)|0)|0) + 8|0);
     $103 = Math_fround(HEAPF32[$102>>2]);
     HEAPF32[$33>>2] = $103;
     $104 = Math_fround(HEAPF32[$81>>2]);
     HEAPF32[$34>>2] = $104;
     $105 = ((($78) + (($82*12)|0)|0) + 4|0);
     $106 = Math_fround(HEAPF32[$105>>2]);
     HEAPF32[$35>>2] = $106;
     $107 = ((($78) + (($82*12)|0)|0) + 8|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     HEAPF32[$36>>2] = $108;
     $109 = Math_fround(HEAPF32[$83>>2]);
     HEAPF32[$37>>2] = $109;
     $110 = ((($78) + (($84*12)|0)|0) + 4|0);
     $111 = Math_fround(HEAPF32[$110>>2]);
     HEAPF32[$38>>2] = $111;
     $112 = ((($78) + (($84*12)|0)|0) + 8|0);
     $113 = Math_fround(HEAPF32[$112>>2]);
     HEAPF32[$39>>2] = $113;
     HEAP32[$40>>2] = $80;
     HEAP32[$41>>2] = $82;
     HEAP32[$42>>2] = $84;
     HEAP8[$43>>0] = 1;
    }
   }
   $122 = HEAP32[$14>>2]|0;
   $123 = (($122) + 4|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)==(0);
   $51 = (($i$01) + 1)|0;
   if ($125) {
    $$0 = 0;
    label = 16;
    break L4;
   }
   $50 = ($51>>>0)<($48>>>0);
   if ($50) {
    $i$01 = $51;
   } else {
    break;
   }
  }
  $126 = (($leaf$03) + 1)|0;
  $127 = ($126>>>0)<($NumTouched>>>0);
  if ($127) {
   $leaf$03 = $126;
  } else {
   $$0 = 1;
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN16RayRTreeCallbackILi0ELb0EED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552360 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = ((552360 + 32|0));
 $1 = (($this) + 180|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 144|0);
 $11 = (($this) + 156|0);
 $12 = (($this) + 64|0);
 $13 = (($this) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$7 & 127]($5,$8,$9,$10,$11,$12,$13)|0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16RayRTreeCallbackILi0ELb0EE14processResultsEjPj($this,$numTouched,$touched) {
 $this = $this|0;
 $numTouched = $numTouched|0;
 $touched = $touched|0;
 var $0 = 0, $dummy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dummy = sp;
 $0 = (__ZN16RayRTreeCallbackILi0ELb0EE14processResultsEjPjRf($this,$numTouched,$touched,$dummy)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn4_N16RayRTreeCallbackILi0ELb0EE14processResultsEjPj($this,$numTouched,$touched) {
 $this = $this|0;
 $numTouched = $numTouched|0;
 $touched = $touched|0;
 var $0 = 0, $1 = 0, $dummy$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dummy$i = sp;
 $0 = (($this) + -4|0);
 $1 = (__ZN16RayRTreeCallbackILi0ELb0EE14processResultsEjPjRf($0,$numTouched,$touched,$dummy$i)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZThn4_N16RayRTreeCallbackILi0ELb0EED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 HEAP32[$0>>2] = ((552360 + 8|0));
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = ((552360 + 32|0));
 $2 = (($0) + 180|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($0) + 68|0);
 $10 = (($0) + 132|0);
 $11 = (($0) + 144|0);
 $12 = (($0) + 156|0);
 $13 = (($0) + 64|0);
 $14 = (($0) + 168|0);
 (FUNCTION_TABLE_iiiiiiii[$8 & 127]($6,$9,$10,$11,$12,$13,$14)|0);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu21findOverlapSphereMeshERKNS0_6SphereERKNS0_13RTreeMidphaseERKNS_11PxTransformERKNS_11PxMeshScaleEPjjjRb($worldSphere,$meshModel,$meshTransform,$scaling,$results,$maxResults,$startIndex,$overflow) {
 $worldSphere = $worldSphere|0;
 $meshModel = $meshModel|0;
 $meshTransform = $meshTransform|0;
 $scaling = $scaling|0;
 $results = $results|0;
 $maxResults = $maxResults|0;
 $startIndex = $startIndex|0;
 $overflow = $overflow|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $limitedResults = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $limitedResults = sp;
 HEAP32[$limitedResults>>2] = $results;
 $0 = (($limitedResults) + 8|0);
 HEAP32[$0>>2] = $maxResults;
 $1 = (($limitedResults) + 12|0);
 HEAP32[$1>>2] = $startIndex;
 $2 = (($limitedResults) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($limitedResults) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($limitedResults) + 20|0);
 HEAP8[$4>>0] = 0;
 (__ZL18intersectAnyVsMeshILi0EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($worldSphere,$meshModel,$meshTransform,$scaling,$limitedResults)|0);
 $5 = HEAP8[$4>>0]|0;
 HEAP8[$overflow>>0] = $5;
 $6 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZL18intersectAnyVsMeshILi0EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($worldSphere,$hmd,$meshTransform,$meshScale,$results) {
 $worldSphere = $worldSphere|0;
 $hmd = $hmd|0;
 $meshTransform = $meshTransform|0;
 $meshScale = $meshScale|0;
 $results = $results|0;
 var $$0 = 0, $$0$in = 0, $$phi$trans$insert = 0, $$pre = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $callback$i3 = 0, $rtreeData$i2 = 0, $sweepDir$i5 = 0, $sweepExtents$i = 0, $sweepExtents$i6 = 0, $sweepLen$i = 0, $sweepOrigin$i4 = 0, $vertexOBB$i = 0, $vertexToShapeSkew$i1 = 0, $worldOBB_$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $vertexToShapeSkew$i1 = sp + 516|0;
 $rtreeData$i2 = sp + 320|0;
 $callback$i3 = sp;
 $sweepOrigin$i4 = sp + 160|0;
 $sweepDir$i5 = sp + 504|0;
 $sweepExtents$i6 = sp + 416|0;
 $sweepExtents$i = sp + 428|0;
 $sweepLen$i = sp + 440|0;
 $worldOBB_$i = sp + 356|0;
 $vertexOBB$i = sp + 444|0;
 $0 = Math_fround(HEAPF32[$meshScale>>2]);
 $1 = $0 == Math_fround(1.0);
 if ($1) {
  $2 = (($meshScale) + 4|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = $3 == Math_fround(1.0);
  if ($4) {
   $5 = (($meshScale) + 8|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = $6 == Math_fround(1.0);
   if ($7) {
    $8 = $rtreeData$i2;
    $9 = $8;
    HEAP32[$9>>2] = 0;
    $10 = (($8) + 4)|0;
    $11 = $10;
    HEAP32[$11>>2] = 0;
    $12 = HEAP32[$hmd>>2]|0;
    HEAP32[$rtreeData$i2>>2] = $12;
    $13 = (($hmd) + 16|0);
    $14 = (($rtreeData$i2) + 4|0);
    HEAP32[$14>>2] = $13;
    $15 = (($hmd) + 4|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = (($rtreeData$i2) + 8|0);
    HEAPF32[$17>>2] = $16;
    $18 = (($callback$i3) + 4|0);
    HEAP32[$18>>2] = 2;
    HEAP32[$callback$i3>>2] = ((552528 + 8|0));
    $19 = (($callback$i3) + 8|0);
    HEAP32[$19>>2] = $hmd;
    $20 = (($callback$i3) + 16|0);
    HEAP32[$20>>2] = $vertexToShapeSkew$i1;
    $21 = (($callback$i3) + 68|0);
    HEAP8[$21>>0] = 0;
    $22 = (($callback$i3) + 116|0);
    HEAP32[$22>>2] = $results;
    $23 = Math_fround(HEAPF32[$worldSphere>>2]);
    $24 = (($meshTransform) + 16|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = Math_fround($23 - $25);
    $27 = (($worldSphere) + 4|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = (($meshTransform) + 20|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = Math_fround($28 - $30);
    $32 = (($worldSphere) + 8|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = (($meshTransform) + 24|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = Math_fround($33 - $35);
    $37 = Math_fround($26 * Math_fround(2.0));
    $38 = Math_fround($31 * Math_fround(2.0));
    $39 = Math_fround($36 * Math_fround(2.0));
    $40 = (($meshTransform) + 12|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = Math_fround($41 * $41);
    $43 = Math_fround($42 + Math_fround(-0.5));
    $44 = Math_fround(HEAPF32[$meshTransform>>2]);
    $45 = Math_fround($37 * $44);
    $46 = (($meshTransform) + 4|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = Math_fround($38 * $47);
    $49 = Math_fround($45 + $48);
    $50 = (($meshTransform) + 8|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = Math_fround($39 * $51);
    $53 = Math_fround($49 + $52);
    $54 = Math_fround($37 * $43);
    $55 = Math_fround($39 * $47);
    $56 = Math_fround($38 * $51);
    $57 = Math_fround($55 - $56);
    $58 = Math_fround($41 * $57);
    $59 = Math_fround($54 - $58);
    $60 = Math_fround($44 * $53);
    $61 = Math_fround($60 + $59);
    $62 = Math_fround($38 * $43);
    $63 = Math_fround($37 * $51);
    $64 = Math_fround($39 * $44);
    $65 = Math_fround($63 - $64);
    $66 = Math_fround($41 * $65);
    $67 = Math_fround($62 - $66);
    $68 = Math_fround($47 * $53);
    $69 = Math_fround($68 + $67);
    $70 = Math_fround($39 * $43);
    $71 = Math_fround($38 * $44);
    $72 = Math_fround($37 * $47);
    $73 = Math_fround($71 - $72);
    $74 = Math_fround($41 * $73);
    $75 = Math_fround($70 - $74);
    $76 = Math_fround($51 * $53);
    $77 = Math_fround($75 + $76);
    $78 = (($callback$i3) + 76|0);
    HEAPF32[$78>>2] = $61;
    $79 = (($callback$i3) + 80|0);
    HEAPF32[$79>>2] = $69;
    $80 = (($callback$i3) + 84|0);
    HEAPF32[$80>>2] = $77;
    $81 = (($worldSphere) + 12|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround($82 * $82);
    $84 = (($callback$i3) + 72|0);
    HEAPF32[$84>>2] = $83;
    HEAPF32[$sweepOrigin$i4>>2] = $61;
    $85 = (($sweepOrigin$i4) + 4|0);
    HEAPF32[$85>>2] = $69;
    $86 = (($sweepOrigin$i4) + 8|0);
    HEAPF32[$86>>2] = $77;
    HEAPF32[$sweepDir$i5>>2] = Math_fround(1.0);
    $87 = (($sweepDir$i5) + 4|0);
    HEAPF32[$87>>2] = Math_fround(0.0);
    $88 = (($sweepDir$i5) + 8|0);
    HEAPF32[$88>>2] = Math_fround(0.0);
    $89 = $82 > Math_fround(0.00100000004749745130539);
    $90 = $89 ? $82 : Math_fround(0.00100000004749745130539);
    HEAPF32[$sweepExtents$i6>>2] = $90;
    $91 = (($sweepExtents$i6) + 4|0);
    HEAPF32[$91>>2] = $90;
    $92 = (($sweepExtents$i6) + 8|0);
    HEAPF32[$92>>2] = $90;
    __ZN5physx2Gu15MeshRayCollider7collideILi1ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($sweepOrigin$i4,$sweepDir$i5,Math_fround(0.0),1,$rtreeData$i2,$callback$i3,$sweepExtents$i6);
    $93 = HEAP8[$21>>0]|0;
    $$0$in = $93;
    $$0 = ($$0$in<<24>>24)!=(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    $129 = $3;
   }
  } else {
   $129 = $3;
  }
 } else {
  $$phi$trans$insert = (($meshScale) + 4|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $129 = $$pre;
 }
 $94 = (($meshScale) + 12|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($meshScale) + 16|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($meshScale) + 20|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($meshScale) + 24|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($95 + $95);
 $103 = Math_fround($97 + $97);
 $104 = Math_fround($99 + $99);
 $105 = Math_fround($95 * $102);
 $106 = Math_fround($97 * $103);
 $107 = Math_fround($99 * $104);
 $108 = Math_fround($102 * $97);
 $109 = Math_fround($102 * $99);
 $110 = Math_fround($102 * $101);
 $111 = Math_fround($103 * $99);
 $112 = Math_fround($103 * $101);
 $113 = Math_fround($104 * $101);
 $114 = Math_fround(Math_fround(1.0) - $106);
 $115 = Math_fround($114 - $107);
 $116 = Math_fround($108 + $113);
 $117 = Math_fround($109 - $112);
 $118 = Math_fround($108 - $113);
 $119 = Math_fround(Math_fround(1.0) - $105);
 $120 = Math_fround($119 - $107);
 $121 = Math_fround($111 + $110);
 $122 = Math_fround($109 + $112);
 $123 = Math_fround($111 - $110);
 $124 = Math_fround($119 - $106);
 $125 = Math_fround($0 * $115);
 $126 = Math_fround($0 * $118);
 $127 = Math_fround($0 * $122);
 $128 = Math_fround($116 * $129);
 $130 = Math_fround($120 * $129);
 $131 = Math_fround($123 * $129);
 $132 = (($meshScale) + 8|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($117 * $133);
 $135 = Math_fround($121 * $133);
 $136 = Math_fround($124 * $133);
 $137 = Math_fround($115 * $125);
 $138 = Math_fround($115 * $126);
 $139 = Math_fround($115 * $127);
 $140 = Math_fround($116 * $128);
 $141 = Math_fround($116 * $130);
 $142 = Math_fround($116 * $131);
 $143 = Math_fround($137 + $140);
 $144 = Math_fround($138 + $141);
 $145 = Math_fround($139 + $142);
 $146 = Math_fround($117 * $134);
 $147 = Math_fround($117 * $135);
 $148 = Math_fround($117 * $136);
 $149 = Math_fround($143 + $146);
 $150 = Math_fround($144 + $147);
 $151 = Math_fround($145 + $148);
 $152 = Math_fround($118 * $125);
 $153 = Math_fround($118 * $126);
 $154 = Math_fround($118 * $127);
 $155 = Math_fround($120 * $128);
 $156 = Math_fround($120 * $130);
 $157 = Math_fround($120 * $131);
 $158 = Math_fround($152 + $155);
 $159 = Math_fround($153 + $156);
 $160 = Math_fround($154 + $157);
 $161 = Math_fround($121 * $134);
 $162 = Math_fround($121 * $135);
 $163 = Math_fround($121 * $136);
 $164 = Math_fround($158 + $161);
 $165 = Math_fround($159 + $162);
 $166 = Math_fround($160 + $163);
 $167 = Math_fround($122 * $125);
 $168 = Math_fround($122 * $126);
 $169 = Math_fround($122 * $127);
 $170 = Math_fround($123 * $128);
 $171 = Math_fround($123 * $130);
 $172 = Math_fround($123 * $131);
 $173 = Math_fround($167 + $170);
 $174 = Math_fround($168 + $171);
 $175 = Math_fround($169 + $172);
 $176 = Math_fround($124 * $134);
 $177 = Math_fround($124 * $135);
 $178 = Math_fround($124 * $136);
 $179 = Math_fround($173 + $176);
 $180 = Math_fround($174 + $177);
 $181 = Math_fround($175 + $178);
 HEAPF32[$vertexToShapeSkew$i1>>2] = $149;
 $182 = (($vertexToShapeSkew$i1) + 4|0);
 HEAPF32[$182>>2] = $150;
 $183 = (($vertexToShapeSkew$i1) + 8|0);
 HEAPF32[$183>>2] = $151;
 $184 = (($vertexToShapeSkew$i1) + 12|0);
 HEAPF32[$184>>2] = $164;
 $185 = (($vertexToShapeSkew$i1) + 16|0);
 HEAPF32[$185>>2] = $165;
 $186 = (($vertexToShapeSkew$i1) + 20|0);
 HEAPF32[$186>>2] = $166;
 $187 = (($vertexToShapeSkew$i1) + 24|0);
 HEAPF32[$187>>2] = $179;
 $188 = (($vertexToShapeSkew$i1) + 28|0);
 HEAPF32[$188>>2] = $180;
 $189 = (($vertexToShapeSkew$i1) + 32|0);
 HEAPF32[$189>>2] = $181;
 __ZNK5physx7PxMat3310getInverseEv($rtreeData$i2,$vertexToShapeSkew$i1);
 $190 = $callback$i3;
 $191 = $190;
 HEAP32[$191>>2] = 0;
 $192 = (($190) + 4)|0;
 $193 = $192;
 HEAP32[$193>>2] = 0;
 $194 = HEAP32[$hmd>>2]|0;
 HEAP32[$callback$i3>>2] = $194;
 $195 = (($hmd) + 16|0);
 $196 = (($callback$i3) + 4|0);
 HEAP32[$196>>2] = $195;
 $197 = (($hmd) + 4|0);
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = (($callback$i3) + 8|0);
 HEAPF32[$199>>2] = $198;
 $200 = (($sweepOrigin$i4) + 4|0);
 HEAP32[$200>>2] = 2;
 HEAP32[$sweepOrigin$i4>>2] = ((552504 + 8|0));
 $201 = (($sweepOrigin$i4) + 8|0);
 HEAP32[$201>>2] = $hmd;
 $202 = (($sweepOrigin$i4) + 16|0);
 HEAP32[$202>>2] = $vertexToShapeSkew$i1;
 $203 = (($sweepOrigin$i4) + 68|0);
 HEAP8[$203>>0] = 0;
 $204 = (($sweepOrigin$i4) + 116|0);
 HEAP32[$204>>2] = $results;
 $205 = Math_fround(HEAPF32[$worldSphere>>2]);
 $206 = (($meshTransform) + 16|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = Math_fround($205 - $207);
 $209 = (($worldSphere) + 4|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($meshTransform) + 20|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = Math_fround($210 - $212);
 $214 = (($worldSphere) + 8|0);
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = (($meshTransform) + 24|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = Math_fround($215 - $217);
 $219 = Math_fround($208 * Math_fround(2.0));
 $220 = Math_fround($213 * Math_fround(2.0));
 $221 = Math_fround($218 * Math_fround(2.0));
 $222 = (($meshTransform) + 12|0);
 $223 = Math_fround(HEAPF32[$222>>2]);
 $224 = Math_fround($223 * $223);
 $225 = Math_fround($224 + Math_fround(-0.5));
 $226 = Math_fround(HEAPF32[$meshTransform>>2]);
 $227 = Math_fround($219 * $226);
 $228 = (($meshTransform) + 4|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = Math_fround($220 * $229);
 $231 = Math_fround($227 + $230);
 $232 = (($meshTransform) + 8|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = Math_fround($221 * $233);
 $235 = Math_fround($231 + $234);
 $236 = Math_fround($219 * $225);
 $237 = Math_fround($221 * $229);
 $238 = Math_fround($220 * $233);
 $239 = Math_fround($237 - $238);
 $240 = Math_fround($223 * $239);
 $241 = Math_fround($236 - $240);
 $242 = Math_fround($226 * $235);
 $243 = Math_fround($242 + $241);
 $244 = Math_fround($220 * $225);
 $245 = Math_fround($219 * $233);
 $246 = Math_fround($221 * $226);
 $247 = Math_fround($245 - $246);
 $248 = Math_fround($223 * $247);
 $249 = Math_fround($244 - $248);
 $250 = Math_fround($229 * $235);
 $251 = Math_fround($250 + $249);
 $252 = Math_fround($221 * $225);
 $253 = Math_fround($220 * $226);
 $254 = Math_fround($219 * $229);
 $255 = Math_fround($253 - $254);
 $256 = Math_fround($223 * $255);
 $257 = Math_fround($252 - $256);
 $258 = Math_fround($233 * $235);
 $259 = Math_fround($257 + $258);
 $260 = (($sweepOrigin$i4) + 76|0);
 HEAPF32[$260>>2] = $243;
 $261 = (($sweepOrigin$i4) + 80|0);
 HEAPF32[$261>>2] = $251;
 $262 = (($sweepOrigin$i4) + 84|0);
 HEAPF32[$262>>2] = $259;
 $263 = (($worldSphere) + 12|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = Math_fround($264 * $264);
 $266 = (($sweepOrigin$i4) + 72|0);
 HEAPF32[$266>>2] = $265;
 HEAPF32[$worldOBB_$i>>2] = Math_fround(1.0);
 $267 = (($worldOBB_$i) + 4|0);
 HEAPF32[$267>>2] = Math_fround(0.0);
 $268 = (($worldOBB_$i) + 8|0);
 HEAPF32[$268>>2] = Math_fround(0.0);
 $269 = (($worldOBB_$i) + 12|0);
 HEAPF32[$269>>2] = Math_fround(0.0);
 $270 = (($worldOBB_$i) + 16|0);
 HEAPF32[$270>>2] = Math_fround(1.0);
 $271 = (($worldOBB_$i) + 20|0);
 HEAPF32[$271>>2] = Math_fround(0.0);
 $272 = (($worldOBB_$i) + 24|0);
 HEAPF32[$272>>2] = Math_fround(0.0);
 $273 = (($worldOBB_$i) + 28|0);
 HEAPF32[$273>>2] = Math_fround(0.0);
 $274 = (($worldOBB_$i) + 32|0);
 HEAPF32[$274>>2] = Math_fround(1.0);
 $275 = (($worldOBB_$i) + 36|0);
 HEAPF32[$275>>2] = $205;
 $276 = (($worldOBB_$i) + 40|0);
 HEAPF32[$276>>2] = $210;
 $277 = (($worldOBB_$i) + 44|0);
 HEAPF32[$277>>2] = $215;
 $278 = (($worldOBB_$i) + 48|0);
 HEAPF32[$278>>2] = $264;
 $279 = (($worldOBB_$i) + 52|0);
 HEAPF32[$279>>2] = $264;
 $280 = (($worldOBB_$i) + 56|0);
 HEAPF32[$280>>2] = $264;
 __ZN5physx2Gu21computeVertexSpaceOBBERNS0_3BoxERKS1_RKNS_11PxTransformERKNS_11PxMeshScaleE($vertexOBB$i,$worldOBB_$i,$meshTransform,$meshScale);
 __ZN5physx2Gu25computeSweptAABBAroundOBBERKNS0_3BoxERNS_6PxVec3ES5_S5_Rf($vertexOBB$i,$sweepDir$i5,$sweepExtents$i,$sweepExtents$i6,$sweepLen$i);
 $281 = Math_fround(HEAPF32[$sweepLen$i>>2]);
 __ZN5physx2Gu15MeshRayCollider7collideILi1ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($sweepDir$i5,$sweepExtents$i6,$281,1,$callback$i3,$sweepOrigin$i4,$sweepExtents$i);
 $282 = HEAP8[$203>>0]|0;
 $$0$in = $282;
 $$0 = ($$0$in<<24>>24)!=(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22findOverlapCapsuleMeshERKNS0_7CapsuleERKNS0_13RTreeMidphaseERKNS_11PxTransformERKNS_11PxMeshScaleEPjjjRb($worldCapsule,$meshModel,$meshTransform,$scaling,$results,$maxResults,$startIndex,$overflow) {
 $worldCapsule = $worldCapsule|0;
 $meshModel = $meshModel|0;
 $meshTransform = $meshTransform|0;
 $scaling = $scaling|0;
 $results = $results|0;
 $maxResults = $maxResults|0;
 $startIndex = $startIndex|0;
 $overflow = $overflow|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $limitedResults = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $limitedResults = sp;
 HEAP32[$limitedResults>>2] = $results;
 $0 = (($limitedResults) + 8|0);
 HEAP32[$0>>2] = $maxResults;
 $1 = (($limitedResults) + 12|0);
 HEAP32[$1>>2] = $startIndex;
 $2 = (($limitedResults) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($limitedResults) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($limitedResults) + 20|0);
 HEAP8[$4>>0] = 0;
 (__ZL18intersectAnyVsMeshILi1EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($worldCapsule,$meshModel,$meshTransform,$scaling,$limitedResults)|0);
 $5 = HEAP8[$4>>0]|0;
 HEAP8[$overflow>>0] = $5;
 $6 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZL18intersectAnyVsMeshILi1EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($worldCapsule,$hmd,$meshTransform,$meshScale,$results) {
 $worldCapsule = $worldCapsule|0;
 $hmd = $hmd|0;
 $meshTransform = $meshTransform|0;
 $meshScale = $meshScale|0;
 $results = $results|0;
 var $$0 = 0, $$0$in = 0, $$phi$trans$insert = 0, $$pre = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0);
 var $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $callback$i3 = 0, $radius3$i = 0, $rtreeData$i2 = 0, $vertexToShapeSkew$i1 = 0, $worldOBB_$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $vertexToShapeSkew$i1 = sp + 476|0;
 $rtreeData$i2 = sp + 320|0;
 $callback$i3 = sp;
 $radius3$i = sp + 160|0;
 $0 = sp + 356|0;
 $worldOBB_$i = sp + 416|0;
 $1 = Math_fround(HEAPF32[$meshScale>>2]);
 $2 = $1 == Math_fround(1.0);
 if ($2) {
  $3 = (($meshScale) + 4|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(1.0);
  if ($5) {
   $6 = (($meshScale) + 8|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 == Math_fround(1.0);
   if ($8) {
    $9 = $rtreeData$i2;
    $10 = $9;
    HEAP32[$10>>2] = 0;
    $11 = (($9) + 4)|0;
    $12 = $11;
    HEAP32[$12>>2] = 0;
    $13 = HEAP32[$hmd>>2]|0;
    HEAP32[$rtreeData$i2>>2] = $13;
    $14 = (($hmd) + 16|0);
    $15 = (($rtreeData$i2) + 4|0);
    HEAP32[$15>>2] = $14;
    $16 = (($hmd) + 4|0);
    $17 = Math_fround(HEAPF32[$16>>2]);
    $18 = (($rtreeData$i2) + 8|0);
    HEAPF32[$18>>2] = $17;
    $19 = (($callback$i3) + 4|0);
    HEAP32[$19>>2] = 2;
    HEAP32[$callback$i3>>2] = ((552480 + 8|0));
    $20 = (($callback$i3) + 8|0);
    HEAP32[$20>>2] = $hmd;
    $21 = (($callback$i3) + 16|0);
    HEAP32[$21>>2] = $vertexToShapeSkew$i1;
    $22 = (($callback$i3) + 68|0);
    HEAP8[$22>>0] = 0;
    $23 = (($callback$i3) + 116|0);
    HEAP32[$23>>2] = $results;
    $24 = (($worldCapsule) + 24|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = Math_fround($25 * $25);
    $27 = (($callback$i3) + 72|0);
    HEAPF32[$27>>2] = $26;
    $28 = (($callback$i3) + 88|0);
    $29 = Math_fround(HEAPF32[$worldCapsule>>2]);
    $30 = (($meshTransform) + 16|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = Math_fround($29 - $31);
    $33 = (($worldCapsule) + 4|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($meshTransform) + 20|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = Math_fround($34 - $36);
    $38 = (($worldCapsule) + 8|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = (($meshTransform) + 24|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = Math_fround($39 - $41);
    $43 = Math_fround($32 * Math_fround(2.0));
    $44 = Math_fround($37 * Math_fround(2.0));
    $45 = Math_fround($42 * Math_fround(2.0));
    $46 = (($meshTransform) + 12|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = Math_fround($47 * $47);
    $49 = Math_fround($48 + Math_fround(-0.5));
    $50 = Math_fround(HEAPF32[$meshTransform>>2]);
    $51 = Math_fround($43 * $50);
    $52 = (($meshTransform) + 4|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = Math_fround($44 * $53);
    $55 = Math_fround($51 + $54);
    $56 = (($meshTransform) + 8|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = Math_fround($45 * $57);
    $59 = Math_fround($55 + $58);
    $60 = Math_fround($43 * $49);
    $61 = Math_fround($45 * $53);
    $62 = Math_fround($44 * $57);
    $63 = Math_fround($61 - $62);
    $64 = Math_fround($47 * $63);
    $65 = Math_fround($60 - $64);
    $66 = Math_fround($50 * $59);
    $67 = Math_fround($66 + $65);
    $68 = Math_fround($44 * $49);
    $69 = Math_fround($43 * $57);
    $70 = Math_fround($45 * $50);
    $71 = Math_fround($69 - $70);
    $72 = Math_fround($47 * $71);
    $73 = Math_fround($68 - $72);
    $74 = Math_fround($53 * $59);
    $75 = Math_fround($74 + $73);
    $76 = Math_fround($45 * $49);
    $77 = Math_fround($44 * $50);
    $78 = Math_fround($43 * $53);
    $79 = Math_fround($77 - $78);
    $80 = Math_fround($47 * $79);
    $81 = Math_fround($76 - $80);
    $82 = Math_fround($57 * $59);
    $83 = Math_fround($81 + $82);
    HEAPF32[$28>>2] = $67;
    $84 = (($callback$i3) + 92|0);
    HEAPF32[$84>>2] = $75;
    $85 = (($callback$i3) + 96|0);
    HEAPF32[$85>>2] = $83;
    $86 = (($worldCapsule) + 12|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = Math_fround($87 - $31);
    $89 = (($worldCapsule) + 16|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = Math_fround($90 - $36);
    $92 = (($worldCapsule) + 20|0);
    $93 = Math_fround(HEAPF32[$92>>2]);
    $94 = Math_fround($93 - $41);
    $95 = Math_fround($88 * Math_fround(2.0));
    $96 = Math_fround($91 * Math_fround(2.0));
    $97 = Math_fround($94 * Math_fround(2.0));
    $98 = Math_fround($50 * $95);
    $99 = Math_fround($53 * $96);
    $100 = Math_fround($98 + $99);
    $101 = Math_fround($57 * $97);
    $102 = Math_fround($100 + $101);
    $103 = Math_fround($49 * $95);
    $104 = Math_fround($53 * $97);
    $105 = Math_fround($57 * $96);
    $106 = Math_fround($104 - $105);
    $107 = Math_fround($47 * $106);
    $108 = Math_fround($103 - $107);
    $109 = Math_fround($50 * $102);
    $110 = Math_fround($109 + $108);
    $111 = Math_fround($49 * $96);
    $112 = Math_fround($57 * $95);
    $113 = Math_fround($50 * $97);
    $114 = Math_fround($112 - $113);
    $115 = Math_fround($47 * $114);
    $116 = Math_fround($111 - $115);
    $117 = Math_fround($53 * $102);
    $118 = Math_fround($117 + $116);
    $119 = Math_fround($49 * $97);
    $120 = Math_fround($50 * $96);
    $121 = Math_fround($53 * $95);
    $122 = Math_fround($120 - $121);
    $123 = Math_fround($47 * $122);
    $124 = Math_fround($119 - $123);
    $125 = Math_fround($57 * $102);
    $126 = Math_fround($124 + $125);
    $127 = (($callback$i3) + 100|0);
    HEAPF32[$127>>2] = $110;
    $128 = (($callback$i3) + 104|0);
    HEAPF32[$128>>2] = $118;
    $129 = (($callback$i3) + 108|0);
    HEAPF32[$129>>2] = $126;
    $130 = (($callback$i3) + 112|0);
    HEAPF32[$130>>2] = $25;
    HEAPF32[$radius3$i>>2] = $25;
    $131 = (($radius3$i) + 4|0);
    HEAPF32[$131>>2] = $25;
    $132 = (($radius3$i) + 8|0);
    HEAPF32[$132>>2] = $25;
    $133 = Math_fround($110 - $67);
    $134 = Math_fround($118 - $75);
    $135 = Math_fround($126 - $83);
    HEAPF32[$0>>2] = $133;
    $136 = (($0) + 4|0);
    HEAPF32[$136>>2] = $134;
    $137 = (($0) + 8|0);
    HEAPF32[$137>>2] = $135;
    __ZN5physx2Gu15MeshRayCollider7collideILi1ELi0EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($28,$0,Math_fround(1.0),1,$rtreeData$i2,$callback$i3,$radius3$i);
    $138 = HEAP8[$22>>0]|0;
    $$0$in = $138;
    $$0 = ($$0$in<<24>>24)!=(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    $174 = $4;
   }
  } else {
   $174 = $4;
  }
 } else {
  $$phi$trans$insert = (($meshScale) + 4|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $174 = $$pre;
 }
 $139 = (($meshScale) + 12|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($meshScale) + 16|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($meshScale) + 20|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = (($meshScale) + 24|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = Math_fround($140 + $140);
 $148 = Math_fround($142 + $142);
 $149 = Math_fround($144 + $144);
 $150 = Math_fround($140 * $147);
 $151 = Math_fround($142 * $148);
 $152 = Math_fround($144 * $149);
 $153 = Math_fround($147 * $142);
 $154 = Math_fround($147 * $144);
 $155 = Math_fround($147 * $146);
 $156 = Math_fround($148 * $144);
 $157 = Math_fround($148 * $146);
 $158 = Math_fround($149 * $146);
 $159 = Math_fround(Math_fround(1.0) - $151);
 $160 = Math_fround($159 - $152);
 $161 = Math_fround($153 + $158);
 $162 = Math_fround($154 - $157);
 $163 = Math_fround($153 - $158);
 $164 = Math_fround(Math_fround(1.0) - $150);
 $165 = Math_fround($164 - $152);
 $166 = Math_fround($156 + $155);
 $167 = Math_fround($154 + $157);
 $168 = Math_fround($156 - $155);
 $169 = Math_fround($164 - $151);
 $170 = Math_fround($1 * $160);
 $171 = Math_fround($1 * $163);
 $172 = Math_fround($1 * $167);
 $173 = Math_fround($161 * $174);
 $175 = Math_fround($165 * $174);
 $176 = Math_fround($168 * $174);
 $177 = (($meshScale) + 8|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = Math_fround($162 * $178);
 $180 = Math_fround($166 * $178);
 $181 = Math_fround($169 * $178);
 $182 = Math_fround($160 * $170);
 $183 = Math_fround($160 * $171);
 $184 = Math_fround($160 * $172);
 $185 = Math_fround($161 * $173);
 $186 = Math_fround($161 * $175);
 $187 = Math_fround($161 * $176);
 $188 = Math_fround($182 + $185);
 $189 = Math_fround($183 + $186);
 $190 = Math_fround($184 + $187);
 $191 = Math_fround($162 * $179);
 $192 = Math_fround($162 * $180);
 $193 = Math_fround($162 * $181);
 $194 = Math_fround($188 + $191);
 $195 = Math_fround($189 + $192);
 $196 = Math_fround($190 + $193);
 $197 = Math_fround($163 * $170);
 $198 = Math_fround($163 * $171);
 $199 = Math_fround($163 * $172);
 $200 = Math_fround($165 * $173);
 $201 = Math_fround($165 * $175);
 $202 = Math_fround($165 * $176);
 $203 = Math_fround($197 + $200);
 $204 = Math_fround($198 + $201);
 $205 = Math_fround($199 + $202);
 $206 = Math_fround($166 * $179);
 $207 = Math_fround($166 * $180);
 $208 = Math_fround($166 * $181);
 $209 = Math_fround($203 + $206);
 $210 = Math_fround($204 + $207);
 $211 = Math_fround($205 + $208);
 $212 = Math_fround($167 * $170);
 $213 = Math_fround($167 * $171);
 $214 = Math_fround($167 * $172);
 $215 = Math_fround($168 * $173);
 $216 = Math_fround($168 * $175);
 $217 = Math_fround($168 * $176);
 $218 = Math_fround($212 + $215);
 $219 = Math_fround($213 + $216);
 $220 = Math_fround($214 + $217);
 $221 = Math_fround($169 * $179);
 $222 = Math_fround($169 * $180);
 $223 = Math_fround($169 * $181);
 $224 = Math_fround($218 + $221);
 $225 = Math_fround($219 + $222);
 $226 = Math_fround($220 + $223);
 HEAPF32[$vertexToShapeSkew$i1>>2] = $194;
 $227 = (($vertexToShapeSkew$i1) + 4|0);
 HEAPF32[$227>>2] = $195;
 $228 = (($vertexToShapeSkew$i1) + 8|0);
 HEAPF32[$228>>2] = $196;
 $229 = (($vertexToShapeSkew$i1) + 12|0);
 HEAPF32[$229>>2] = $209;
 $230 = (($vertexToShapeSkew$i1) + 16|0);
 HEAPF32[$230>>2] = $210;
 $231 = (($vertexToShapeSkew$i1) + 20|0);
 HEAPF32[$231>>2] = $211;
 $232 = (($vertexToShapeSkew$i1) + 24|0);
 HEAPF32[$232>>2] = $224;
 $233 = (($vertexToShapeSkew$i1) + 28|0);
 HEAPF32[$233>>2] = $225;
 $234 = (($vertexToShapeSkew$i1) + 32|0);
 HEAPF32[$234>>2] = $226;
 __ZNK5physx7PxMat3310getInverseEv($rtreeData$i2,$vertexToShapeSkew$i1);
 $235 = $callback$i3;
 $236 = $235;
 HEAP32[$236>>2] = 0;
 $237 = (($235) + 4)|0;
 $238 = $237;
 HEAP32[$238>>2] = 0;
 $239 = HEAP32[$hmd>>2]|0;
 HEAP32[$callback$i3>>2] = $239;
 $240 = (($hmd) + 16|0);
 $241 = (($callback$i3) + 4|0);
 HEAP32[$241>>2] = $240;
 $242 = (($hmd) + 4|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($callback$i3) + 8|0);
 HEAPF32[$244>>2] = $243;
 $245 = (($radius3$i) + 4|0);
 HEAP32[$245>>2] = 2;
 HEAP32[$radius3$i>>2] = ((552456 + 8|0));
 $246 = (($radius3$i) + 8|0);
 HEAP32[$246>>2] = $hmd;
 $247 = (($radius3$i) + 16|0);
 HEAP32[$247>>2] = $vertexToShapeSkew$i1;
 $248 = (($radius3$i) + 68|0);
 HEAP8[$248>>0] = 0;
 $249 = (($radius3$i) + 116|0);
 HEAP32[$249>>2] = $results;
 $250 = (($worldCapsule) + 24|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = Math_fround($251 * $251);
 $253 = (($radius3$i) + 72|0);
 HEAPF32[$253>>2] = $252;
 $254 = Math_fround(HEAPF32[$worldCapsule>>2]);
 $255 = (($meshTransform) + 16|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 $257 = Math_fround($254 - $256);
 $258 = (($worldCapsule) + 4|0);
 $259 = Math_fround(HEAPF32[$258>>2]);
 $260 = (($meshTransform) + 20|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = Math_fround($259 - $261);
 $263 = (($worldCapsule) + 8|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = (($meshTransform) + 24|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = Math_fround($264 - $266);
 $268 = Math_fround($257 * Math_fround(2.0));
 $269 = Math_fround($262 * Math_fround(2.0));
 $270 = Math_fround($267 * Math_fround(2.0));
 $271 = (($meshTransform) + 12|0);
 $272 = Math_fround(HEAPF32[$271>>2]);
 $273 = Math_fround($272 * $272);
 $274 = Math_fround($273 + Math_fround(-0.5));
 $275 = Math_fround(HEAPF32[$meshTransform>>2]);
 $276 = Math_fround($268 * $275);
 $277 = (($meshTransform) + 4|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = Math_fround($269 * $278);
 $280 = Math_fround($276 + $279);
 $281 = (($meshTransform) + 8|0);
 $282 = Math_fround(HEAPF32[$281>>2]);
 $283 = Math_fround($270 * $282);
 $284 = Math_fround($280 + $283);
 $285 = Math_fround($268 * $274);
 $286 = Math_fround($270 * $278);
 $287 = Math_fround($269 * $282);
 $288 = Math_fround($286 - $287);
 $289 = Math_fround($272 * $288);
 $290 = Math_fround($285 - $289);
 $291 = Math_fround($275 * $284);
 $292 = Math_fround($291 + $290);
 $293 = Math_fround($269 * $274);
 $294 = Math_fround($268 * $282);
 $295 = Math_fround($270 * $275);
 $296 = Math_fround($294 - $295);
 $297 = Math_fround($272 * $296);
 $298 = Math_fround($293 - $297);
 $299 = Math_fround($278 * $284);
 $300 = Math_fround($299 + $298);
 $301 = Math_fround($270 * $274);
 $302 = Math_fround($269 * $275);
 $303 = Math_fround($268 * $278);
 $304 = Math_fround($302 - $303);
 $305 = Math_fround($272 * $304);
 $306 = Math_fround($301 - $305);
 $307 = Math_fround($282 * $284);
 $308 = Math_fround($306 + $307);
 $309 = (($radius3$i) + 88|0);
 HEAPF32[$309>>2] = $292;
 $310 = (($radius3$i) + 92|0);
 HEAPF32[$310>>2] = $300;
 $311 = (($radius3$i) + 96|0);
 HEAPF32[$311>>2] = $308;
 $312 = (($worldCapsule) + 12|0);
 $313 = Math_fround(HEAPF32[$312>>2]);
 $314 = Math_fround($313 - $256);
 $315 = (($worldCapsule) + 16|0);
 $316 = Math_fround(HEAPF32[$315>>2]);
 $317 = Math_fround($316 - $261);
 $318 = (($worldCapsule) + 20|0);
 $319 = Math_fround(HEAPF32[$318>>2]);
 $320 = Math_fround($319 - $266);
 $321 = Math_fround($314 * Math_fround(2.0));
 $322 = Math_fround($317 * Math_fround(2.0));
 $323 = Math_fround($320 * Math_fround(2.0));
 $324 = Math_fround($275 * $321);
 $325 = Math_fround($278 * $322);
 $326 = Math_fround($324 + $325);
 $327 = Math_fround($282 * $323);
 $328 = Math_fround($326 + $327);
 $329 = Math_fround($274 * $321);
 $330 = Math_fround($278 * $323);
 $331 = Math_fround($282 * $322);
 $332 = Math_fround($330 - $331);
 $333 = Math_fround($272 * $332);
 $334 = Math_fround($329 - $333);
 $335 = Math_fround($275 * $328);
 $336 = Math_fround($335 + $334);
 $337 = Math_fround($274 * $322);
 $338 = Math_fround($282 * $321);
 $339 = Math_fround($275 * $323);
 $340 = Math_fround($338 - $339);
 $341 = Math_fround($272 * $340);
 $342 = Math_fround($337 - $341);
 $343 = Math_fround($278 * $328);
 $344 = Math_fround($343 + $342);
 $345 = Math_fround($274 * $323);
 $346 = Math_fround($275 * $322);
 $347 = Math_fround($278 * $321);
 $348 = Math_fround($346 - $347);
 $349 = Math_fround($272 * $348);
 $350 = Math_fround($345 - $349);
 $351 = Math_fround($282 * $328);
 $352 = Math_fround($350 + $351);
 $353 = (($radius3$i) + 100|0);
 HEAPF32[$353>>2] = $336;
 $354 = (($radius3$i) + 104|0);
 HEAPF32[$354>>2] = $344;
 $355 = (($radius3$i) + 108|0);
 HEAPF32[$355>>2] = $352;
 $356 = (($radius3$i) + 112|0);
 HEAPF32[$356>>2] = $251;
 __ZN5physx2Gu3Box6createERKNS0_7CapsuleE($worldOBB_$i,$worldCapsule);
 __ZN5physx2Gu21computeVertexSpaceOBBERNS0_3BoxERKS1_RKNS_11PxTransformERKNS_11PxMeshScaleE($0,$worldOBB_$i,$meshTransform,$meshScale);
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($0,1,$callback$i3,$radius3$i,1);
 $357 = HEAP8[$248>>0]|0;
 $$0$in = $357;
 $$0 = ($$0$in<<24>>24)!=(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18findOverlapOBBMeshERKNS0_3BoxERKNS0_13RTreeMidphaseERKNS_11PxTransformERKNS_11PxMeshScaleEPjjjRb($worldOBB,$meshModel,$meshTransform,$scaling,$results,$maxResults,$startIndex,$overflow) {
 $worldOBB = $worldOBB|0;
 $meshModel = $meshModel|0;
 $meshTransform = $meshTransform|0;
 $scaling = $scaling|0;
 $results = $results|0;
 $maxResults = $maxResults|0;
 $startIndex = $startIndex|0;
 $overflow = $overflow|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $limitedResults = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $limitedResults = sp;
 HEAP32[$limitedResults>>2] = $results;
 $0 = (($limitedResults) + 8|0);
 HEAP32[$0>>2] = $maxResults;
 $1 = (($limitedResults) + 12|0);
 HEAP32[$1>>2] = $startIndex;
 $2 = (($limitedResults) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($limitedResults) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($limitedResults) + 20|0);
 HEAP8[$4>>0] = 0;
 (__ZL18intersectAnyVsMeshILi2EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($worldOBB,$meshModel,$meshTransform,$scaling,$limitedResults)|0);
 $5 = HEAP8[$4>>0]|0;
 HEAP8[$overflow>>0] = $5;
 $6 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZL18intersectAnyVsMeshILi2EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($worldOBB,$hmd,$meshTransform,$meshScale,$results) {
 $worldOBB = $worldOBB|0;
 $hmd = $hmd|0;
 $meshTransform = $meshTransform|0;
 $meshScale = $meshScale|0;
 $results = $results|0;
 var $$0 = 0, $$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0;
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0;
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = 0;
 var $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = Math_fround(0), $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = 0;
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0);
 var $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0);
 var $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0);
 var $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0);
 var $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = Math_fround(0);
 var $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = Math_fround(0), $497 = 0, $498 = 0, $499 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $500 = 0, $501 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0;
 var $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0;
 var $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $invRot$i$i = 0, $rtreeData$i2 = 0, $vertexOBB$i3 = 0, $vertexToShapeSkew$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $invRot$i$i = sp + 224|0;
 $vertexToShapeSkew$i1 = sp + 448|0;
 $rtreeData$i2 = sp + 384|0;
 $vertexOBB$i3 = sp + 64|0;
 $0 = sp;
 $1 = sp + 484|0;
 $2 = Math_fround(HEAPF32[$meshScale>>2]);
 $3 = $2 == Math_fround(1.0);
 if ($3) {
  $4 = (($meshScale) + 4|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = $5 == Math_fround(1.0);
  if ($6) {
   $7 = (($meshScale) + 8|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = $8 == Math_fround(1.0);
   if ($9) {
    $10 = $rtreeData$i2;
    $11 = $10;
    HEAP32[$11>>2] = 0;
    $12 = (($10) + 4)|0;
    $13 = $12;
    HEAP32[$13>>2] = 0;
    $14 = HEAP32[$hmd>>2]|0;
    HEAP32[$rtreeData$i2>>2] = $14;
    $15 = (($hmd) + 16|0);
    $16 = (($rtreeData$i2) + 4|0);
    HEAP32[$16>>2] = $15;
    $17 = (($hmd) + 4|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = (($rtreeData$i2) + 8|0);
    HEAPF32[$19>>2] = $18;
    $20 = (($meshTransform) + 16|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = (($meshTransform) + 20|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = (($meshTransform) + 24|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = Math_fround($21 * Math_fround(-2.0));
    $27 = Math_fround($23 * Math_fround(-2.0));
    $28 = Math_fround($25 * Math_fround(-2.0));
    $29 = (($meshTransform) + 12|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = Math_fround($30 * $30);
    $32 = Math_fround($31 + Math_fround(-0.5));
    $33 = Math_fround(HEAPF32[$meshTransform>>2]);
    $34 = Math_fround($26 * $33);
    $35 = (($meshTransform) + 4|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = Math_fround($27 * $36);
    $38 = Math_fround($34 + $37);
    $39 = (($meshTransform) + 8|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = Math_fround($28 * $40);
    $42 = Math_fround($38 + $41);
    $43 = Math_fround($26 * $32);
    $44 = Math_fround($28 * $36);
    $45 = Math_fround($27 * $40);
    $46 = Math_fround($44 - $45);
    $47 = Math_fround($30 * $46);
    $48 = Math_fround($43 - $47);
    $49 = Math_fround($33 * $42);
    $50 = Math_fround($49 + $48);
    $51 = Math_fround($27 * $32);
    $52 = Math_fround($26 * $40);
    $53 = Math_fround($28 * $33);
    $54 = Math_fround($52 - $53);
    $55 = Math_fround($30 * $54);
    $56 = Math_fround($51 - $55);
    $57 = Math_fround($36 * $42);
    $58 = Math_fround($57 + $56);
    $59 = Math_fround($28 * $32);
    $60 = Math_fround($27 * $33);
    $61 = Math_fround($26 * $36);
    $62 = Math_fround($60 - $61);
    $63 = Math_fround($30 * $62);
    $64 = Math_fround($59 - $63);
    $65 = Math_fround($40 * $42);
    $66 = Math_fround($64 + $65);
    $67 = Math_fround(-$33);
    $68 = Math_fround(-$36);
    $69 = Math_fround(-$40);
    HEAPF32[$1>>2] = $67;
    $70 = (($1) + 4|0);
    HEAPF32[$70>>2] = $68;
    $71 = (($1) + 8|0);
    HEAPF32[$71>>2] = $69;
    $72 = (($1) + 12|0);
    HEAPF32[$72>>2] = $30;
    $73 = (($1) + 16|0);
    HEAPF32[$73>>2] = $50;
    $74 = (($1) + 20|0);
    HEAPF32[$74>>2] = $58;
    $75 = (($1) + 24|0);
    HEAPF32[$75>>2] = $66;
    __ZN5physx23transformBoxOrthonormalERKNS_2Gu3BoxERKNS_11PxTransformE($0,$worldOBB,$1);
    $76 = Math_fround(HEAPF32[$0>>2]);
    HEAPF32[$vertexOBB$i3>>2] = $76;
    $77 = (($0) + 4|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = (($vertexOBB$i3) + 4|0);
    HEAPF32[$79>>2] = $78;
    $80 = (($0) + 8|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = (($vertexOBB$i3) + 8|0);
    HEAPF32[$82>>2] = $81;
    $83 = (($0) + 12|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = (($vertexOBB$i3) + 12|0);
    HEAPF32[$85>>2] = $84;
    $86 = (($0) + 16|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = (($vertexOBB$i3) + 16|0);
    HEAPF32[$88>>2] = $87;
    $89 = (($0) + 20|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = (($vertexOBB$i3) + 20|0);
    HEAPF32[$91>>2] = $90;
    $92 = (($0) + 24|0);
    $93 = Math_fround(HEAPF32[$92>>2]);
    $94 = (($vertexOBB$i3) + 24|0);
    HEAPF32[$94>>2] = $93;
    $95 = (($0) + 28|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $97 = (($vertexOBB$i3) + 28|0);
    HEAPF32[$97>>2] = $96;
    $98 = (($0) + 32|0);
    $99 = Math_fround(HEAPF32[$98>>2]);
    $100 = (($vertexOBB$i3) + 32|0);
    HEAPF32[$100>>2] = $99;
    $101 = (($0) + 36|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $103 = (($vertexOBB$i3) + 36|0);
    HEAPF32[$103>>2] = $102;
    $104 = (($0) + 40|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = (($vertexOBB$i3) + 40|0);
    HEAPF32[$106>>2] = $105;
    $107 = (($0) + 44|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $109 = (($vertexOBB$i3) + 44|0);
    HEAPF32[$109>>2] = $108;
    $110 = (($0) + 48|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = (($vertexOBB$i3) + 48|0);
    HEAPF32[$112>>2] = $111;
    $113 = (($0) + 52|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = (($vertexOBB$i3) + 52|0);
    HEAPF32[$115>>2] = $114;
    $116 = (($0) + 56|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = (($vertexOBB$i3) + 56|0);
    HEAPF32[$118>>2] = $117;
    __ZNK5physx7PxMat3310getInverseEv($invRot$i$i,$vertexOBB$i3);
    $119 = Math_fround(HEAPF32[$103>>2]);
    $120 = Math_fround(-$119);
    $121 = Math_fround(HEAPF32[$106>>2]);
    $122 = Math_fround(-$121);
    $123 = Math_fround(HEAPF32[$109>>2]);
    $124 = Math_fround(-$123);
    $125 = Math_fround(HEAPF32[$invRot$i$i>>2]);
    $126 = Math_fround($125 * $120);
    $127 = (($invRot$i$i) + 4|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $129 = Math_fround($128 * $120);
    $130 = (($invRot$i$i) + 8|0);
    $131 = Math_fround(HEAPF32[$130>>2]);
    $132 = Math_fround($131 * $120);
    $133 = (($invRot$i$i) + 12|0);
    $134 = Math_fround(HEAPF32[$133>>2]);
    $135 = Math_fround($134 * $122);
    $136 = (($invRot$i$i) + 16|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = Math_fround($137 * $122);
    $139 = (($invRot$i$i) + 20|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = Math_fround($140 * $122);
    $142 = Math_fround($126 + $135);
    $143 = Math_fround($129 + $138);
    $144 = Math_fround($132 + $141);
    $145 = (($invRot$i$i) + 24|0);
    $146 = Math_fround(HEAPF32[$145>>2]);
    $147 = Math_fround($146 * $124);
    $148 = (($invRot$i$i) + 28|0);
    $149 = Math_fround(HEAPF32[$148>>2]);
    $150 = Math_fround($149 * $124);
    $151 = (($invRot$i$i) + 32|0);
    $152 = Math_fround(HEAPF32[$151>>2]);
    $153 = Math_fround($152 * $124);
    $154 = Math_fround($142 + $147);
    $155 = Math_fround($143 + $150);
    $156 = Math_fround($144 + $153);
    HEAPF32[$vertexToShapeSkew$i1>>2] = $125;
    $157 = (($vertexToShapeSkew$i1) + 4|0);
    HEAPF32[$157>>2] = $128;
    $158 = (($vertexToShapeSkew$i1) + 8|0);
    HEAPF32[$158>>2] = $131;
    $159 = (($vertexToShapeSkew$i1) + 12|0);
    HEAPF32[$159>>2] = $134;
    $160 = (($vertexToShapeSkew$i1) + 16|0);
    HEAPF32[$160>>2] = $137;
    $161 = (($vertexToShapeSkew$i1) + 20|0);
    HEAPF32[$161>>2] = $140;
    $162 = (($vertexToShapeSkew$i1) + 24|0);
    HEAPF32[$162>>2] = $146;
    $163 = (($vertexToShapeSkew$i1) + 28|0);
    HEAPF32[$163>>2] = $149;
    $164 = (($vertexToShapeSkew$i1) + 32|0);
    HEAPF32[$164>>2] = $152;
    $165 = (($invRot$i$i) + 4|0);
    HEAP32[$165>>2] = 2;
    HEAP32[$invRot$i$i>>2] = ((552432 + 8|0));
    $166 = (($invRot$i$i) + 8|0);
    HEAP32[$166>>2] = $hmd;
    $167 = (($invRot$i$i) + 16|0);
    HEAP32[$167>>2] = $vertexToShapeSkew$i1;
    $168 = (($invRot$i$i) + 68|0);
    HEAP8[$168>>0] = 0;
    $169 = (($invRot$i$i) + 116|0);
    HEAP32[$169>>2] = $results;
    $170 = Math_fround(-$154);
    $171 = Math_fround(-$155);
    $172 = Math_fround(-$156);
    $173 = (($invRot$i$i) + 144|0);
    HEAPF32[$173>>2] = $170;
    $174 = (($invRot$i$i) + 148|0);
    HEAPF32[$174>>2] = $171;
    $175 = (($invRot$i$i) + 152|0);
    HEAPF32[$175>>2] = $172;
    $176 = (($invRot$i$i) + 156|0);
    HEAPF32[$176>>2] = Math_fround(0.0);
    $177 = (($worldOBB) + 48|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = (($worldOBB) + 52|0);
    $180 = Math_fround(HEAPF32[$179>>2]);
    $181 = (($worldOBB) + 56|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    $183 = (($invRot$i$i) + 128|0);
    HEAPF32[$183>>2] = $178;
    $184 = (($invRot$i$i) + 132|0);
    HEAPF32[$184>>2] = $180;
    $185 = (($invRot$i$i) + 136|0);
    HEAPF32[$185>>2] = $182;
    $186 = (($invRot$i$i) + 140|0);
    HEAPF32[$186>>2] = Math_fround(0.0);
    __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($vertexOBB$i3,1,$rtreeData$i2,$invRot$i$i,1);
    $187 = HEAP8[$168>>0]|0;
    $$0$in = $187;
    $$0 = ($$0$in<<24>>24)!=(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $188 = $vertexToShapeSkew$i1;
 $189 = $188;
 HEAP32[$189>>2] = 0;
 $190 = (($188) + 4)|0;
 $191 = $190;
 HEAP32[$191>>2] = 0;
 $192 = HEAP32[$hmd>>2]|0;
 HEAP32[$vertexToShapeSkew$i1>>2] = $192;
 $193 = (($hmd) + 16|0);
 $194 = (($vertexToShapeSkew$i1) + 4|0);
 HEAP32[$194>>2] = $193;
 $195 = (($hmd) + 4|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($vertexToShapeSkew$i1) + 8|0);
 HEAPF32[$197>>2] = $196;
 __ZN5physx2Gu21computeVertexSpaceOBBERNS0_3BoxERKS1_RKNS_11PxTransformERKNS_11PxMeshScaleE($rtreeData$i2,$worldOBB,$meshTransform,$meshScale);
 $198 = Math_fround(HEAPF32[$meshTransform>>2]);
 $199 = (($meshTransform) + 4|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = (($meshTransform) + 8|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($meshTransform) + 12|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = Math_fround($198 + $198);
 $206 = Math_fround($200 + $200);
 $207 = Math_fround($202 + $202);
 $208 = Math_fround($198 * $205);
 $209 = Math_fround($200 * $206);
 $210 = Math_fround($202 * $207);
 $211 = Math_fround($205 * $200);
 $212 = Math_fround($205 * $202);
 $213 = Math_fround($205 * $204);
 $214 = Math_fround($206 * $202);
 $215 = Math_fround($206 * $204);
 $216 = Math_fround($207 * $204);
 $217 = Math_fround(Math_fround(1.0) - $209);
 $218 = Math_fround($217 - $210);
 $219 = Math_fround($211 + $216);
 $220 = Math_fround($212 - $215);
 $221 = Math_fround($211 - $216);
 $222 = Math_fround(Math_fround(1.0) - $208);
 $223 = Math_fround($222 - $210);
 $224 = Math_fround($214 + $213);
 $225 = Math_fround($212 + $215);
 $226 = Math_fround($214 - $213);
 $227 = Math_fround($222 - $209);
 $228 = (($meshScale) + 12|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = (($meshScale) + 16|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($meshScale) + 20|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = (($meshScale) + 24|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = Math_fround($229 + $229);
 $237 = Math_fround($231 + $231);
 $238 = Math_fround($233 + $233);
 $239 = Math_fround($229 * $236);
 $240 = Math_fround($231 * $237);
 $241 = Math_fround($233 * $238);
 $242 = Math_fround($236 * $231);
 $243 = Math_fround($236 * $233);
 $244 = Math_fround($236 * $235);
 $245 = Math_fround($237 * $233);
 $246 = Math_fround($237 * $235);
 $247 = Math_fround($238 * $235);
 $248 = Math_fround(Math_fround(1.0) - $240);
 $249 = Math_fround($248 - $241);
 $250 = Math_fround($242 + $247);
 $251 = Math_fround($243 - $246);
 $252 = Math_fround($242 - $247);
 $253 = Math_fround(Math_fround(1.0) - $239);
 $254 = Math_fround($253 - $241);
 $255 = Math_fround($245 + $244);
 $256 = Math_fround($243 + $246);
 $257 = Math_fround($245 - $244);
 $258 = Math_fround($253 - $240);
 $259 = Math_fround(HEAPF32[$meshScale>>2]);
 $260 = Math_fround($259 * $249);
 $261 = Math_fround($259 * $252);
 $262 = Math_fround($259 * $256);
 $263 = (($meshScale) + 4|0);
 $264 = Math_fround(HEAPF32[$263>>2]);
 $265 = Math_fround($250 * $264);
 $266 = Math_fround($254 * $264);
 $267 = Math_fround($257 * $264);
 $268 = (($meshScale) + 8|0);
 $269 = Math_fround(HEAPF32[$268>>2]);
 $270 = Math_fround($251 * $269);
 $271 = Math_fround($255 * $269);
 $272 = Math_fround($258 * $269);
 $273 = Math_fround($249 * $260);
 $274 = Math_fround($249 * $261);
 $275 = Math_fround($249 * $262);
 $276 = Math_fround($250 * $265);
 $277 = Math_fround($250 * $266);
 $278 = Math_fround($250 * $267);
 $279 = Math_fround($273 + $276);
 $280 = Math_fround($274 + $277);
 $281 = Math_fround($275 + $278);
 $282 = Math_fround($251 * $270);
 $283 = Math_fround($251 * $271);
 $284 = Math_fround($251 * $272);
 $285 = Math_fround($279 + $282);
 $286 = Math_fround($280 + $283);
 $287 = Math_fround($281 + $284);
 $288 = Math_fround($252 * $260);
 $289 = Math_fround($252 * $261);
 $290 = Math_fround($252 * $262);
 $291 = Math_fround($254 * $265);
 $292 = Math_fround($254 * $266);
 $293 = Math_fround($254 * $267);
 $294 = Math_fround($288 + $291);
 $295 = Math_fround($289 + $292);
 $296 = Math_fround($290 + $293);
 $297 = Math_fround($255 * $270);
 $298 = Math_fround($255 * $271);
 $299 = Math_fround($255 * $272);
 $300 = Math_fround($294 + $297);
 $301 = Math_fround($295 + $298);
 $302 = Math_fround($296 + $299);
 $303 = Math_fround($256 * $260);
 $304 = Math_fround($256 * $261);
 $305 = Math_fround($256 * $262);
 $306 = Math_fround($257 * $265);
 $307 = Math_fround($257 * $266);
 $308 = Math_fround($257 * $267);
 $309 = Math_fround($303 + $306);
 $310 = Math_fround($304 + $307);
 $311 = Math_fround($305 + $308);
 $312 = Math_fround($258 * $270);
 $313 = Math_fround($258 * $271);
 $314 = Math_fround($258 * $272);
 $315 = Math_fround($309 + $312);
 $316 = Math_fround($310 + $313);
 $317 = Math_fround($311 + $314);
 $318 = Math_fround($218 * $285);
 $319 = Math_fround($219 * $285);
 $320 = Math_fround($220 * $285);
 $321 = Math_fround($221 * $286);
 $322 = Math_fround($223 * $286);
 $323 = Math_fround($224 * $286);
 $324 = Math_fround($318 + $321);
 $325 = Math_fround($319 + $322);
 $326 = Math_fround($320 + $323);
 $327 = Math_fround($225 * $287);
 $328 = Math_fround($226 * $287);
 $329 = Math_fround($227 * $287);
 $330 = Math_fround($327 + $324);
 $331 = Math_fround($328 + $325);
 $332 = Math_fround($329 + $326);
 $333 = Math_fround($218 * $300);
 $334 = Math_fround($219 * $300);
 $335 = Math_fround($220 * $300);
 $336 = Math_fround($221 * $301);
 $337 = Math_fround($223 * $301);
 $338 = Math_fround($224 * $301);
 $339 = Math_fround($333 + $336);
 $340 = Math_fround($334 + $337);
 $341 = Math_fround($335 + $338);
 $342 = Math_fround($225 * $302);
 $343 = Math_fround($226 * $302);
 $344 = Math_fround($227 * $302);
 $345 = Math_fround($342 + $339);
 $346 = Math_fround($343 + $340);
 $347 = Math_fround($344 + $341);
 $348 = Math_fround($218 * $315);
 $349 = Math_fround($219 * $315);
 $350 = Math_fround($220 * $315);
 $351 = Math_fround($221 * $316);
 $352 = Math_fround($223 * $316);
 $353 = Math_fround($224 * $316);
 $354 = Math_fround($348 + $351);
 $355 = Math_fround($349 + $352);
 $356 = Math_fround($350 + $353);
 $357 = Math_fround($225 * $317);
 $358 = Math_fround($226 * $317);
 $359 = Math_fround($227 * $317);
 $360 = Math_fround($357 + $354);
 $361 = Math_fround($358 + $355);
 $362 = Math_fround($359 + $356);
 $363 = Math_fround(HEAPF32[$worldOBB>>2]);
 $364 = (($worldOBB) + 4|0);
 $365 = Math_fround(HEAPF32[$364>>2]);
 $366 = (($worldOBB) + 8|0);
 $367 = Math_fround(HEAPF32[$366>>2]);
 $368 = (($worldOBB) + 12|0);
 $369 = Math_fround(HEAPF32[$368>>2]);
 $370 = (($worldOBB) + 16|0);
 $371 = Math_fround(HEAPF32[$370>>2]);
 $372 = (($worldOBB) + 20|0);
 $373 = Math_fround(HEAPF32[$372>>2]);
 $374 = (($worldOBB) + 24|0);
 $375 = Math_fround(HEAPF32[$374>>2]);
 $376 = (($worldOBB) + 28|0);
 $377 = Math_fround(HEAPF32[$376>>2]);
 $378 = (($worldOBB) + 32|0);
 $379 = Math_fround(HEAPF32[$378>>2]);
 $380 = (($worldOBB) + 36|0);
 $381 = Math_fround(HEAPF32[$380>>2]);
 $382 = (($worldOBB) + 40|0);
 $383 = Math_fround(HEAPF32[$382>>2]);
 $384 = (($worldOBB) + 44|0);
 $385 = Math_fround(HEAPF32[$384>>2]);
 $386 = Math_fround(-$381);
 $387 = Math_fround(-$383);
 $388 = Math_fround(-$385);
 $389 = Math_fround($363 * $386);
 $390 = Math_fround($365 * $387);
 $391 = Math_fround($389 + $390);
 $392 = Math_fround($367 * $388);
 $393 = Math_fround($391 + $392);
 $394 = Math_fround($369 * $386);
 $395 = Math_fround($371 * $387);
 $396 = Math_fround($394 + $395);
 $397 = Math_fround($373 * $388);
 $398 = Math_fround($396 + $397);
 $399 = Math_fround($375 * $386);
 $400 = Math_fround($377 * $387);
 $401 = Math_fround($399 + $400);
 $402 = Math_fround($379 * $388);
 $403 = Math_fround($401 + $402);
 $404 = (($meshTransform) + 16|0);
 $405 = Math_fround(HEAPF32[$404>>2]);
 $406 = (($meshTransform) + 20|0);
 $407 = Math_fround(HEAPF32[$406>>2]);
 $408 = (($meshTransform) + 24|0);
 $409 = Math_fround(HEAPF32[$408>>2]);
 $410 = (($vertexOBB$i3) + 4|0);
 HEAP32[$410>>2] = 2;
 HEAP32[$vertexOBB$i3>>2] = ((552408 + 8|0));
 $411 = (($vertexOBB$i3) + 8|0);
 HEAP32[$411>>2] = $hmd;
 $412 = (($vertexOBB$i3) + 16|0);
 HEAP32[$412>>2] = $invRot$i$i;
 $413 = (($vertexOBB$i3) + 68|0);
 HEAP8[$413>>0] = 0;
 $414 = (($vertexOBB$i3) + 116|0);
 HEAP32[$414>>2] = $results;
 $415 = Math_fround($363 * $330);
 $416 = Math_fround($369 * $330);
 $417 = Math_fround($330 * $375);
 $418 = Math_fround($365 * $331);
 $419 = Math_fround($371 * $331);
 $420 = Math_fround($331 * $377);
 $421 = Math_fround($415 + $418);
 $422 = Math_fround($416 + $419);
 $423 = Math_fround($417 + $420);
 $424 = Math_fround($367 * $332);
 $425 = Math_fround($332 * $373);
 $426 = Math_fround($332 * $379);
 $427 = Math_fround($424 + $421);
 $428 = Math_fround($425 + $422);
 $429 = Math_fround($423 + $426);
 $430 = Math_fround($363 * $345);
 $431 = Math_fround($369 * $345);
 $432 = Math_fround($345 * $375);
 $433 = Math_fround($365 * $346);
 $434 = Math_fround($371 * $346);
 $435 = Math_fround($346 * $377);
 $436 = Math_fround($430 + $433);
 $437 = Math_fround($431 + $434);
 $438 = Math_fround($432 + $435);
 $439 = Math_fround($367 * $347);
 $440 = Math_fround($373 * $347);
 $441 = Math_fround($347 * $379);
 $442 = Math_fround($439 + $436);
 $443 = Math_fround($440 + $437);
 $444 = Math_fround($438 + $441);
 $445 = Math_fround($363 * $360);
 $446 = Math_fround($369 * $360);
 $447 = Math_fround($360 * $375);
 $448 = Math_fround($365 * $361);
 $449 = Math_fround($371 * $361);
 $450 = Math_fround($361 * $377);
 $451 = Math_fround($445 + $448);
 $452 = Math_fround($446 + $449);
 $453 = Math_fround($447 + $450);
 $454 = Math_fround($367 * $362);
 $455 = Math_fround($373 * $362);
 $456 = Math_fround($362 * $379);
 $457 = Math_fround($454 + $451);
 $458 = Math_fround($455 + $452);
 $459 = Math_fround($453 + $456);
 $460 = Math_fround($363 * $405);
 $461 = Math_fround($369 * $405);
 $462 = Math_fround($375 * $405);
 $463 = Math_fround($365 * $407);
 $464 = Math_fround($371 * $407);
 $465 = Math_fround($377 * $407);
 $466 = Math_fround($460 + $463);
 $467 = Math_fround($461 + $464);
 $468 = Math_fround($462 + $465);
 $469 = Math_fround($367 * $409);
 $470 = Math_fround($373 * $409);
 $471 = Math_fround($379 * $409);
 $472 = Math_fround($466 + $469);
 $473 = Math_fround($467 + $470);
 $474 = Math_fround($468 + $471);
 $475 = Math_fround($393 + $472);
 $476 = Math_fround($398 + $473);
 $477 = Math_fround($403 + $474);
 $478 = (($vertexOBB$i3) + 20|0);
 HEAPF32[$478>>2] = $427;
 $479 = (($vertexOBB$i3) + 24|0);
 HEAPF32[$479>>2] = $428;
 $480 = (($vertexOBB$i3) + 28|0);
 HEAPF32[$480>>2] = $429;
 $481 = (($vertexOBB$i3) + 32|0);
 HEAPF32[$481>>2] = $442;
 $482 = (($vertexOBB$i3) + 36|0);
 HEAPF32[$482>>2] = $443;
 $483 = (($vertexOBB$i3) + 40|0);
 HEAPF32[$483>>2] = $444;
 $484 = (($vertexOBB$i3) + 44|0);
 HEAPF32[$484>>2] = $457;
 $485 = (($vertexOBB$i3) + 48|0);
 HEAPF32[$485>>2] = $458;
 $486 = (($vertexOBB$i3) + 52|0);
 HEAPF32[$486>>2] = $459;
 $487 = (($vertexOBB$i3) + 56|0);
 HEAPF32[$487>>2] = $475;
 $488 = (($vertexOBB$i3) + 60|0);
 HEAPF32[$488>>2] = $476;
 $489 = (($vertexOBB$i3) + 64|0);
 HEAPF32[$489>>2] = $477;
 $490 = (($vertexOBB$i3) + 144|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$490+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$490+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$490+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$490+12>>2]=HEAP32[$0+12>>2]|0;
 $491 = (($worldOBB) + 48|0);
 $492 = Math_fround(HEAPF32[$491>>2]);
 $493 = (($worldOBB) + 52|0);
 $494 = Math_fround(HEAPF32[$493>>2]);
 $495 = (($worldOBB) + 56|0);
 $496 = Math_fround(HEAPF32[$495>>2]);
 $497 = (($vertexOBB$i3) + 128|0);
 HEAPF32[$497>>2] = $492;
 $498 = (($vertexOBB$i3) + 132|0);
 HEAPF32[$498>>2] = $494;
 $499 = (($vertexOBB$i3) + 136|0);
 HEAPF32[$499>>2] = $496;
 $500 = (($vertexOBB$i3) + 140|0);
 HEAPF32[$500>>2] = Math_fround(0.0);
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($rtreeData$i2,1,$vertexToShapeSkew$i1,$vertexOBB$i3,1);
 $501 = HEAP8[$413>>0]|0;
 $$0$in = $501;
 $$0 = ($$0$in<<24>>24)!=(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu28checkOverlapOBB_triangleGeomERKNS_10PxGeometryERKNS_11PxTransformERKNS0_3BoxE($geom,$pose,$box) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($geom) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = (($geom) + 4|0);
 $4 = (__ZL18intersectAnyVsMeshILi2EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($box,$2,$pose,$3,0)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z30GeomOverlapCallback_SphereMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $worldSphere = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $worldSphere = sp;
 $0 = (($geom0) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($transform0) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$worldSphere>>2] = $3;
 $4 = (($worldSphere) + 4|0);
 $5 = (($transform0) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($worldSphere) + 8|0);
 $8 = (($transform0) + 24|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($worldSphere) + 12|0);
 HEAPF32[$10>>2] = $1;
 $11 = (($geom1) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 32|0);
 $14 = (($geom1) + 4|0);
 $15 = (__ZL18intersectAnyVsMeshILi0EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($worldSphere,$13,$transform1,$14,0)|0);
 STACKTOP = sp;return ($15|0);
}
function __Z31GeomOverlapCallback_CapsuleMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $capsule = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $capsule = sp;
 $0 = (($geom1) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$transform0>>2]);
 $3 = Math_fround($2 * Math_fround(2.0));
 $4 = (($transform0) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = Math_fround($5 * $6);
 $8 = Math_fround($7 + Math_fround(-1.0));
 $9 = Math_fround($2 * $3);
 $10 = Math_fround($9 + $8);
 $11 = (($transform0) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $6);
 $14 = (($transform0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($3 * $15);
 $17 = Math_fround($13 + $16);
 $18 = Math_fround($6 * $15);
 $19 = Math_fround($3 * $12);
 $20 = Math_fround($19 - $18);
 $21 = (($geom0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $10);
 $24 = Math_fround($22 * $17);
 $25 = Math_fround($22 * $20);
 $26 = (($transform0) + 16|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 + $23);
 $29 = (($transform0) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $24);
 $32 = (($transform0) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($25 + $33);
 HEAPF32[$capsule>>2] = $28;
 $35 = (($capsule) + 4|0);
 HEAPF32[$35>>2] = $31;
 $36 = (($capsule) + 8|0);
 HEAPF32[$36>>2] = $34;
 $37 = Math_fround($27 - $23);
 $38 = Math_fround($30 - $24);
 $39 = Math_fround($33 - $25);
 $40 = (($capsule) + 12|0);
 HEAPF32[$40>>2] = $37;
 $41 = (($capsule) + 16|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($capsule) + 20|0);
 HEAPF32[$42>>2] = $39;
 $43 = (($geom0) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($capsule) + 24|0);
 HEAPF32[$45>>2] = $44;
 $46 = (($1) + 32|0);
 $47 = (($geom1) + 4|0);
 $48 = (__ZL18intersectAnyVsMeshILi1EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($capsule,$46,$transform1,$47,0)|0);
 STACKTOP = sp;return ($48|0);
}
function __Z27GeomOverlapCallback_BoxMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = Math_fround(0), $8 = 0;
 var $9 = 0, $box = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $box = sp;
 $0 = (($geom1) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($geom0) + 4|0);
 $3 = (($transform0) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($box) + 36|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($transform0) + 20|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($box) + 40|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($transform0) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($box) + 44|0);
 HEAPF32[$11>>2] = $10;
 $12 = Math_fround(HEAPF32[$2>>2]);
 $13 = (($box) + 48|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($geom0) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($box) + 52|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($geom0) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($box) + 56|0);
 HEAPF32[$19>>2] = $18;
 $20 = Math_fround(HEAPF32[$transform0>>2]);
 $21 = (($transform0) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($transform0) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($20 + $20);
 $28 = Math_fround($22 + $22);
 $29 = Math_fround($24 + $24);
 $30 = Math_fround($20 * $27);
 $31 = Math_fround($22 * $28);
 $32 = Math_fround($24 * $29);
 $33 = Math_fround($27 * $22);
 $34 = Math_fround($27 * $24);
 $35 = Math_fround($27 * $26);
 $36 = Math_fround($28 * $24);
 $37 = Math_fround($28 * $26);
 $38 = Math_fround($29 * $26);
 $39 = Math_fround(Math_fround(1.0) - $31);
 $40 = Math_fround($39 - $32);
 $41 = Math_fround($33 + $38);
 $42 = Math_fround($34 - $37);
 $43 = Math_fround($33 - $38);
 $44 = Math_fround(Math_fround(1.0) - $30);
 $45 = Math_fround($44 - $32);
 $46 = Math_fround($36 + $35);
 $47 = Math_fround($34 + $37);
 $48 = Math_fround($36 - $35);
 $49 = Math_fround($44 - $31);
 HEAPF32[$box>>2] = $40;
 $50 = (($box) + 4|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($box) + 8|0);
 HEAPF32[$51>>2] = $42;
 $52 = (($box) + 12|0);
 HEAPF32[$52>>2] = $43;
 $53 = (($box) + 16|0);
 HEAPF32[$53>>2] = $45;
 $54 = (($box) + 20|0);
 HEAPF32[$54>>2] = $46;
 $55 = (($box) + 24|0);
 HEAPF32[$55>>2] = $47;
 $56 = (($box) + 28|0);
 HEAPF32[$56>>2] = $48;
 $57 = (($box) + 32|0);
 HEAPF32[$57>>2] = $49;
 $58 = (($1) + 32|0);
 $59 = (($geom1) + 4|0);
 $60 = (__ZL18intersectAnyVsMeshILi2EEbPKN5physx2Gu6SphereEPKNS1_7CapsuleEPKNS1_3BoxERKNS1_13RTreeMidphaseERKNS0_11PxTransformERKNS0_11PxMeshScaleEP14LimitedResults($box,$58,$transform1,$59,0)|0);
 STACKTOP = sp;return ($60|0);
}
function __Z30GeomOverlapCallback_ConvexMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0;
 var $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cb = 0, $convexScaling = 0;
 var $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0), $hmd = 0, $hullAABB = 0, $hullOBB = 0, $meshScaling = 0, $world0 = 0, $world1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 784|0;
 $convexScaling = sp + 712|0;
 $meshScaling = sp + 640|0;
 $world0 = sp + 448|0;
 $world1 = sp + 496|0;
 $hullAABB = sp + 544|0;
 $hullOBB = sp + 568|0;
 $hmd = sp + 628|0;
 $cb = sp;
 $0 = (($geom0) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($geom1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($geom0) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 == Math_fround(1.0);
 if ($6) {
  $7 = (($geom0) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = $8 == Math_fround(1.0);
  if ($9) {
   $10 = (($geom0) + 12|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = $11 == Math_fround(1.0);
   $237 = $12;
  } else {
   $237 = 0;
  }
 } else {
  $237 = 0;
 }
 $13 = (($geom1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $14 == Math_fround(1.0);
 if ($15) {
  $16 = (($geom1) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = $17 == Math_fround(1.0);
  if ($18) {
   $19 = (($geom1) + 12|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = $20 == Math_fround(1.0);
   $226 = $21;
  } else {
   $226 = 0;
  }
 } else {
  $226 = 0;
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $22 = (($convexScaling) + 4|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($convexScaling) + 8|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($convexScaling) + 12|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($convexScaling) + 16|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($convexScaling) + 20|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($convexScaling) + 24|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($convexScaling) + 28|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($convexScaling) + 32|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = (($convexScaling) + 36|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($convexScaling) + 40|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($convexScaling) + 44|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($convexScaling) + 48|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($convexScaling) + 52|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (($convexScaling) + 56|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($convexScaling) + 60|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($convexScaling) + 64|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($convexScaling) + 68|0);
 HEAPF32[$38>>2] = Math_fround(1.0);
 if (!($237)) {
  $39 = (($geom0) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$4,$39);
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $40 = (($meshScaling) + 4|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($meshScaling) + 8|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($meshScaling) + 12|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($meshScaling) + 16|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 $44 = (($meshScaling) + 20|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($meshScaling) + 24|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($meshScaling) + 28|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($meshScaling) + 32|0);
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (($meshScaling) + 36|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($meshScaling) + 40|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($meshScaling) + 44|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($meshScaling) + 48|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($meshScaling) + 52|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($meshScaling) + 56|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($meshScaling) + 60|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($meshScaling) + 64|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($meshScaling) + 68|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 if (!($226)) {
  $57 = (($geom1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$13,$57);
 }
 $58 = Math_fround(HEAPF32[$transform0>>2]);
 $59 = Math_fround($58 + $58);
 $60 = (($transform0) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 + $61);
 $63 = (($transform0) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 + $64);
 $66 = (($transform0) + 12|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($59 * $67);
 $69 = Math_fround($62 * $67);
 $70 = Math_fround($67 * $65);
 $71 = Math_fround($58 * $59);
 $72 = Math_fround($58 * $62);
 $73 = Math_fround($58 * $65);
 $74 = Math_fround($61 * $62);
 $75 = Math_fround($61 * $65);
 $76 = Math_fround($64 * $65);
 $77 = Math_fround(Math_fround(1.0) - $74);
 $78 = Math_fround($77 - $76);
 HEAPF32[$world0>>2] = $78;
 $79 = Math_fround($72 + $70);
 $80 = (($world0) + 4|0);
 HEAPF32[$80>>2] = $79;
 $81 = Math_fround($73 - $69);
 $82 = (($world0) + 8|0);
 HEAPF32[$82>>2] = $81;
 $83 = Math_fround($72 - $70);
 $84 = (($world0) + 12|0);
 HEAPF32[$84>>2] = $83;
 $85 = Math_fround(Math_fround(1.0) - $71);
 $86 = Math_fround($85 - $76);
 $87 = (($world0) + 16|0);
 HEAPF32[$87>>2] = $86;
 $88 = Math_fround($75 + $68);
 $89 = (($world0) + 20|0);
 HEAPF32[$89>>2] = $88;
 $90 = Math_fround($73 + $69);
 $91 = (($world0) + 24|0);
 HEAPF32[$91>>2] = $90;
 $92 = Math_fround($75 - $68);
 $93 = (($world0) + 28|0);
 HEAPF32[$93>>2] = $92;
 $94 = Math_fround($85 - $74);
 $95 = (($world0) + 32|0);
 HEAPF32[$95>>2] = $94;
 $96 = (($world0) + 36|0);
 $97 = (($world0) + 40|0);
 $98 = (($world0) + 44|0);
 $99 = (($transform0) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 HEAPF32[$96>>2] = $100;
 $101 = (($transform0) + 20|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 HEAPF32[$97>>2] = $102;
 $103 = (($transform0) + 24|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 HEAPF32[$98>>2] = $104;
 $105 = Math_fround(HEAPF32[$transform1>>2]);
 $106 = Math_fround($105 + $105);
 $107 = (($transform1) + 4|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($108 + $108);
 $110 = (($transform1) + 8|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($111 + $111);
 $113 = (($transform1) + 12|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($106 * $114);
 $116 = Math_fround($109 * $114);
 $117 = Math_fround($114 * $112);
 $118 = Math_fround($105 * $106);
 $119 = Math_fround($105 * $109);
 $120 = Math_fround($105 * $112);
 $121 = Math_fround($108 * $109);
 $122 = Math_fround($108 * $112);
 $123 = Math_fround($111 * $112);
 $124 = Math_fround(Math_fround(1.0) - $121);
 $125 = Math_fround($124 - $123);
 HEAPF32[$world1>>2] = $125;
 $126 = Math_fround($119 + $117);
 $127 = (($world1) + 4|0);
 HEAPF32[$127>>2] = $126;
 $128 = Math_fround($120 - $116);
 $129 = (($world1) + 8|0);
 HEAPF32[$129>>2] = $128;
 $130 = Math_fround($119 - $117);
 $131 = (($world1) + 12|0);
 HEAPF32[$131>>2] = $130;
 $132 = Math_fround(Math_fround(1.0) - $118);
 $133 = Math_fround($132 - $123);
 $134 = (($world1) + 16|0);
 HEAPF32[$134>>2] = $133;
 $135 = Math_fround($122 + $115);
 $136 = (($world1) + 20|0);
 HEAPF32[$136>>2] = $135;
 $137 = Math_fround($120 + $116);
 $138 = (($world1) + 24|0);
 HEAPF32[$138>>2] = $137;
 $139 = Math_fround($122 - $115);
 $140 = (($world1) + 28|0);
 HEAPF32[$140>>2] = $139;
 $141 = Math_fround($132 - $121);
 $142 = (($world1) + 32|0);
 HEAPF32[$142>>2] = $141;
 $143 = (($world1) + 36|0);
 $144 = (($world1) + 40|0);
 $145 = (($world1) + 44|0);
 $146 = (($transform1) + 16|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 HEAPF32[$143>>2] = $147;
 $148 = (($transform1) + 20|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 HEAPF32[$144>>2] = $149;
 $150 = (($transform1) + 24|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 HEAPF32[$145>>2] = $151;
 $152 = (($1) + 16|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = (($1) + 28|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = Math_fround($153 + $155);
 $157 = (($1) + 20|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($1) + 32|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = Math_fround($158 + $160);
 $162 = (($1) + 24|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($1) + 36|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = Math_fround($163 + $165);
 $167 = Math_fround($156 * Math_fround(0.5));
 $168 = Math_fround($161 * Math_fround(0.5));
 $169 = Math_fround($166 * Math_fround(0.5));
 $170 = Math_fround(HEAPF32[$convexScaling>>2]);
 $171 = Math_fround($167 * $170);
 $172 = Math_fround(HEAPF32[$22>>2]);
 $173 = Math_fround($167 * $172);
 $174 = Math_fround(HEAPF32[$23>>2]);
 $175 = Math_fround($167 * $174);
 $176 = Math_fround(HEAPF32[$24>>2]);
 $177 = Math_fround($168 * $176);
 $178 = Math_fround(HEAPF32[$25>>2]);
 $179 = Math_fround($168 * $178);
 $180 = Math_fround(HEAPF32[$26>>2]);
 $181 = Math_fround($168 * $180);
 $182 = Math_fround($171 + $177);
 $183 = Math_fround($173 + $179);
 $184 = Math_fround($175 + $181);
 $185 = Math_fround(HEAPF32[$27>>2]);
 $186 = Math_fround($169 * $185);
 $187 = Math_fround(HEAPF32[$28>>2]);
 $188 = Math_fround($169 * $187);
 $189 = Math_fround(HEAPF32[$29>>2]);
 $190 = Math_fround($169 * $189);
 $191 = Math_fround($182 + $186);
 $192 = Math_fround($183 + $188);
 $193 = Math_fround($184 + $190);
 $194 = Math_fround($155 - $153);
 $195 = Math_fround($160 - $158);
 $196 = Math_fround($165 - $163);
 $197 = Math_fround($194 * Math_fround(0.5));
 $198 = Math_fround($195 * Math_fround(0.5));
 $199 = Math_fround($196 * Math_fround(0.5));
 $200 = Math_fround($197 * $170);
 $201 = Math_fround($197 * $172);
 $202 = Math_fround($197 * $174);
 $203 = Math_fround($198 * $176);
 $204 = Math_fround($198 * $178);
 $205 = Math_fround($198 * $180);
 $206 = Math_fround($199 * $185);
 $207 = Math_fround($199 * $187);
 $208 = Math_fround($199 * $189);
 $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($200)))));
 $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($203)))));
 $209 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
 $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($206)))));
 $210 = Math_fround($209 + $fabsf$i$i6$i$i);
 $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($201)))));
 $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($204)))));
 $211 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
 $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($207)))));
 $212 = Math_fround($211 + $fabsf$i$i3$i$i);
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($202)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($205)))));
 $213 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($208)))));
 $214 = Math_fround($213 + $fabsf$i$i$i$i);
 $215 = Math_fround($191 - $210);
 $216 = Math_fround($192 - $212);
 $217 = Math_fround($193 - $214);
 $218 = Math_fround($191 + $210);
 $219 = Math_fround($192 + $212);
 $220 = Math_fround($193 + $214);
 HEAPF32[$hullAABB>>2] = $215;
 $221 = (($hullAABB) + 4|0);
 HEAPF32[$221>>2] = $216;
 $222 = (($hullAABB) + 8|0);
 HEAPF32[$222>>2] = $217;
 $223 = (($hullAABB) + 12|0);
 HEAPF32[$223>>2] = $218;
 $224 = (($hullAABB) + 16|0);
 HEAPF32[$224>>2] = $219;
 $225 = (($hullAABB) + 20|0);
 HEAPF32[$225>>2] = $220;
 __ZN5physx2Gu14computeHullOBBERNS0_3BoxERKNS_9PxBounds3EfRKNS_11PxTransformERKNS_2Cm8Matrix34ESC_RKNS9_23FastVertex2ShapeScalingEb($hullOBB,$hullAABB,Math_fround(0.0),$transform0,$world0,$world1,$meshScaling,$226);
 $227 = (($3) + 32|0);
 $228 = HEAP32[$227>>2]|0;
 HEAP32[$hmd>>2] = $228;
 $229 = (($3) + 48|0);
 $230 = (($hmd) + 4|0);
 HEAP32[$230>>2] = $229;
 $231 = (($3) + 36|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = (($hmd) + 8|0);
 HEAPF32[$233>>2] = $232;
 __ZN27ConvexVsMeshOverlapCallbackC2ERKN5physx2Gu10ConvexMeshERKNS0_11PxMeshScaleERKNS0_2Cm23FastVertex2ShapeScalingERKNS0_11PxTransformESE_bRKNS1_3BoxE($cb,$1,$4,$meshScaling,$transform0,$transform1,$226,$hullOBB);
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($hullOBB,1,$hmd,$cb,0);
 $234 = (($cb) + 432|0);
 $235 = HEAP8[$234>>0]|0;
 $236 = ($235<<24>>24)!=(0);
 STACKTOP = sp;return ($236|0);
}
function __ZN27ConvexVsMeshOverlapCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi2ELb0EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi2ELb0EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj($this,$aHit,$av0,$av1,$av2,$0,$1) {
 $this = $this|0;
 $aHit = $aHit|0;
 $av0 = $av0|0;
 $av1 = $av1|0;
 $av2 = $av2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0);
 var $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0;
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $v0 = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $v0 = sp + 32|0;
 $v1 = sp;
 $v2 = sp + 16|0;
 $2 = Math_fround(HEAPF32[$av0>>2]);
 $3 = (($this) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 * $4);
 $6 = (($this) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($2 * $7);
 $9 = (($this) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($2 * $10);
 $12 = (($av0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 32|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 * $15);
 $17 = (($this) + 36|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($13 * $18);
 $20 = (($this) + 40|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($13 * $21);
 $23 = Math_fround($5 + $16);
 $24 = Math_fround($8 + $19);
 $25 = Math_fround($11 + $22);
 $26 = (($av0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($this) + 44|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($27 * $29);
 $31 = (($this) + 48|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($27 * $32);
 $34 = (($this) + 52|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($27 * $35);
 $37 = Math_fround($23 + $30);
 $38 = Math_fround($24 + $33);
 $39 = Math_fround($25 + $36);
 $40 = (($this) + 56|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($37 + $41);
 $43 = (($this) + 60|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($38 + $44);
 $46 = (($this) + 64|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($39 + $47);
 HEAPF32[$v0>>2] = $42;
 $49 = (($v0) + 4|0);
 HEAPF32[$49>>2] = $45;
 $50 = (($v0) + 8|0);
 HEAPF32[$50>>2] = $48;
 $51 = (($v0) + 12|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = Math_fround(HEAPF32[$av1>>2]);
 $53 = Math_fround($52 * $4);
 $54 = Math_fround($52 * $7);
 $55 = Math_fround($52 * $10);
 $56 = (($av1) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 * $15);
 $59 = Math_fround($57 * $18);
 $60 = Math_fround($57 * $21);
 $61 = Math_fround($53 + $58);
 $62 = Math_fround($54 + $59);
 $63 = Math_fround($55 + $60);
 $64 = (($av1) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 * $29);
 $67 = Math_fround($65 * $32);
 $68 = Math_fround($65 * $35);
 $69 = Math_fround($61 + $66);
 $70 = Math_fround($62 + $67);
 $71 = Math_fround($63 + $68);
 $72 = Math_fround($69 + $41);
 $73 = Math_fround($70 + $44);
 $74 = Math_fround($71 + $47);
 HEAPF32[$v1>>2] = $72;
 $75 = (($v1) + 4|0);
 HEAPF32[$75>>2] = $73;
 $76 = (($v1) + 8|0);
 HEAPF32[$76>>2] = $74;
 $77 = (($v1) + 12|0);
 HEAPF32[$77>>2] = Math_fround(0.0);
 $78 = Math_fround(HEAPF32[$av2>>2]);
 $79 = Math_fround($78 * $4);
 $80 = Math_fround($78 * $7);
 $81 = Math_fround($78 * $10);
 $82 = (($av2) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($83 * $15);
 $85 = Math_fround($83 * $18);
 $86 = Math_fround($83 * $21);
 $87 = Math_fround($79 + $84);
 $88 = Math_fround($80 + $85);
 $89 = Math_fround($81 + $86);
 $90 = (($av2) + 8|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 * $29);
 $93 = Math_fround($91 * $32);
 $94 = Math_fround($91 * $35);
 $95 = Math_fround($87 + $92);
 $96 = Math_fround($88 + $93);
 $97 = Math_fround($89 + $94);
 $98 = Math_fround($95 + $41);
 $99 = Math_fround($96 + $44);
 $100 = Math_fround($97 + $47);
 HEAPF32[$v2>>2] = $98;
 $101 = (($v2) + 4|0);
 HEAPF32[$101>>2] = $99;
 $102 = (($v2) + 8|0);
 HEAPF32[$102>>2] = $100;
 $103 = (($v2) + 12|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($this) + 144|0);
 $105 = (($this) + 128|0);
 $106 = (__ZN5physx2Gu20intersectTriangleBoxERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_($104,$105,$v0,$v1,$v2)|0);
 if (!($106)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $107 = (($this) + 68|0);
 HEAP8[$107>>0] = 1;
 $108 = (($this) + 116|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ($109|0)==(0|0);
 if ($110) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $111 = (($aHit) + 8|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = (($109) + 4|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (($109) + 8|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = ($114>>>0)<($116>>>0);
 if (!($117)) {
  $118 = (($109) + 20|0);
  HEAP8[$118>>0] = 1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $119 = (($109) + 16|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = (($109) + 12|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($120>>>0)<($122>>>0);
 if ($123) {
  $127 = (($120) + 1)|0;
  HEAP32[$119>>2] = $127;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $124 = (($114) + 1)|0;
  HEAP32[$113>>2] = $124;
  $125 = HEAP32[$109>>2]|0;
  $126 = (($125) + ($114<<2)|0);
  HEAP32[$126>>2] = $112;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN26IntersectAnyVsMeshCallbackILi2ELb0EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi2ELb1EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi2ELb1EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj($this,$aHit,$av0,$av1,$av2,$0,$1) {
 $this = $this|0;
 $aHit = $aHit|0;
 $av0 = $av0|0;
 $av1 = $av1|0;
 $av2 = $av2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0);
 var $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $v0 = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $v0 = sp + 32|0;
 $v1 = sp;
 $v2 = sp + 16|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$av0>>2]);
 $5 = Math_fround(HEAPF32[$3>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($3) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($4 * $8);
 $10 = (($3) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($4 * $11);
 $13 = (($av0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($3) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = (($3) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($14 * $19);
 $21 = (($3) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($14 * $22);
 $24 = Math_fround($6 + $17);
 $25 = Math_fround($9 + $20);
 $26 = Math_fround($12 + $23);
 $27 = (($av0) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($3) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 * $30);
 $32 = (($3) + 28|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($28 * $33);
 $35 = (($3) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($28 * $36);
 $38 = Math_fround($24 + $31);
 $39 = Math_fround($25 + $34);
 $40 = Math_fround($26 + $37);
 HEAPF32[$v0>>2] = $38;
 $41 = (($v0) + 4|0);
 HEAPF32[$41>>2] = $39;
 $42 = (($v0) + 8|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($v0) + 12|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = Math_fround(HEAPF32[$av1>>2]);
 $45 = Math_fround(HEAPF32[$3>>2]);
 $46 = Math_fround($44 * $45);
 $47 = Math_fround(HEAPF32[$7>>2]);
 $48 = Math_fround($44 * $47);
 $49 = Math_fround(HEAPF32[$10>>2]);
 $50 = Math_fround($44 * $49);
 $51 = (($av1) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(HEAPF32[$15>>2]);
 $54 = Math_fround($52 * $53);
 $55 = Math_fround(HEAPF32[$18>>2]);
 $56 = Math_fround($52 * $55);
 $57 = Math_fround(HEAPF32[$21>>2]);
 $58 = Math_fround($52 * $57);
 $59 = Math_fround($46 + $54);
 $60 = Math_fround($48 + $56);
 $61 = Math_fround($50 + $58);
 $62 = (($av1) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(HEAPF32[$29>>2]);
 $65 = Math_fround($63 * $64);
 $66 = Math_fround(HEAPF32[$32>>2]);
 $67 = Math_fround($63 * $66);
 $68 = Math_fround(HEAPF32[$35>>2]);
 $69 = Math_fround($63 * $68);
 $70 = Math_fround($59 + $65);
 $71 = Math_fround($60 + $67);
 $72 = Math_fround($61 + $69);
 HEAPF32[$v1>>2] = $70;
 $73 = (($v1) + 4|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($v1) + 8|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($v1) + 12|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = Math_fround(HEAPF32[$av2>>2]);
 $77 = Math_fround(HEAPF32[$3>>2]);
 $78 = Math_fround($76 * $77);
 $79 = Math_fround(HEAPF32[$7>>2]);
 $80 = Math_fround($76 * $79);
 $81 = Math_fround(HEAPF32[$10>>2]);
 $82 = Math_fround($76 * $81);
 $83 = (($av2) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround(HEAPF32[$15>>2]);
 $86 = Math_fround($84 * $85);
 $87 = Math_fround(HEAPF32[$18>>2]);
 $88 = Math_fround($84 * $87);
 $89 = Math_fround(HEAPF32[$21>>2]);
 $90 = Math_fround($84 * $89);
 $91 = Math_fround($78 + $86);
 $92 = Math_fround($80 + $88);
 $93 = Math_fround($82 + $90);
 $94 = (($av2) + 8|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround(HEAPF32[$29>>2]);
 $97 = Math_fround($95 * $96);
 $98 = Math_fround(HEAPF32[$32>>2]);
 $99 = Math_fround($95 * $98);
 $100 = Math_fround(HEAPF32[$35>>2]);
 $101 = Math_fround($95 * $100);
 $102 = Math_fround($91 + $97);
 $103 = Math_fround($92 + $99);
 $104 = Math_fround($93 + $101);
 HEAPF32[$v2>>2] = $102;
 $105 = (($v2) + 4|0);
 HEAPF32[$105>>2] = $103;
 $106 = (($v2) + 8|0);
 HEAPF32[$106>>2] = $104;
 $107 = (($v2) + 12|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($this) + 144|0);
 $109 = (($this) + 128|0);
 $110 = (__ZN5physx2Gu20intersectTriangleBoxERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_($108,$109,$v0,$v1,$v2)|0);
 if (!($110)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $111 = (($this) + 68|0);
 HEAP8[$111>>0] = 1;
 $112 = (($this) + 116|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ($113|0)==(0|0);
 if ($114) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $115 = (($aHit) + 8|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($113) + 4|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = (($113) + 8|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($118>>>0)<($120>>>0);
 if (!($121)) {
  $122 = (($113) + 20|0);
  HEAP8[$122>>0] = 1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $123 = (($113) + 16|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($113) + 12|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($124>>>0)<($126>>>0);
 if ($127) {
  $131 = (($124) + 1)|0;
  HEAP32[$123>>2] = $131;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $128 = (($118) + 1)|0;
  HEAP32[$117>>2] = $128;
  $129 = HEAP32[$113>>2]|0;
  $130 = (($129) + ($118<<2)|0);
  HEAP32[$130>>2] = $116;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN26IntersectAnyVsMeshCallbackILi2ELb1EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi1ELb0EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi1ELb0EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj($this,$aHit,$av0,$av1,$av2,$0,$1) {
 $this = $this|0;
 $aHit = $aHit|0;
 $av0 = $av0|0;
 $av1 = $av1|0;
 $av2 = $av2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = Math_fround(0), $17 = Math_fround(0);
 var $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0;
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $cap0 = 0, $cap1 = 0, $dummy1 = 0, $dummy2 = 0, $result = 0, $v0 = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $v0 = sp + 112|0;
 $v1 = sp;
 $v2 = sp + 16|0;
 $dummy1 = sp + 32|0;
 $dummy2 = sp + 48|0;
 $cap0 = sp + 64|0;
 $cap1 = sp + 80|0;
 $result = sp + 96|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$av0>>2]);
 $5 = Math_fround(HEAPF32[$3>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($3) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($4 * $8);
 $10 = (($3) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($4 * $11);
 $13 = (($av0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($3) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = (($3) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($14 * $19);
 $21 = (($3) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($14 * $22);
 $24 = Math_fround($6 + $17);
 $25 = Math_fround($9 + $20);
 $26 = Math_fround($12 + $23);
 $27 = (($av0) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($3) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 * $30);
 $32 = (($3) + 28|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($28 * $33);
 $35 = (($3) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($28 * $36);
 $38 = Math_fround($24 + $31);
 $39 = Math_fround($25 + $34);
 $40 = Math_fround($26 + $37);
 HEAPF32[$v0>>2] = $38;
 $41 = (($v0) + 4|0);
 HEAPF32[$41>>2] = $39;
 $42 = (($v0) + 8|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($v0) + 12|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = Math_fround(HEAPF32[$av1>>2]);
 $45 = Math_fround(HEAPF32[$3>>2]);
 $46 = Math_fround($44 * $45);
 $47 = Math_fround(HEAPF32[$7>>2]);
 $48 = Math_fround($44 * $47);
 $49 = Math_fround(HEAPF32[$10>>2]);
 $50 = Math_fround($44 * $49);
 $51 = (($av1) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround(HEAPF32[$15>>2]);
 $54 = Math_fround($52 * $53);
 $55 = Math_fround(HEAPF32[$18>>2]);
 $56 = Math_fround($52 * $55);
 $57 = Math_fround(HEAPF32[$21>>2]);
 $58 = Math_fround($52 * $57);
 $59 = Math_fround($46 + $54);
 $60 = Math_fround($48 + $56);
 $61 = Math_fround($50 + $58);
 $62 = (($av1) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(HEAPF32[$29>>2]);
 $65 = Math_fround($63 * $64);
 $66 = Math_fround(HEAPF32[$32>>2]);
 $67 = Math_fround($63 * $66);
 $68 = Math_fround(HEAPF32[$35>>2]);
 $69 = Math_fround($63 * $68);
 $70 = Math_fround($59 + $65);
 $71 = Math_fround($60 + $67);
 $72 = Math_fround($61 + $69);
 HEAPF32[$v1>>2] = $70;
 $73 = (($v1) + 4|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($v1) + 8|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($v1) + 12|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = Math_fround(HEAPF32[$av2>>2]);
 $77 = Math_fround(HEAPF32[$3>>2]);
 $78 = Math_fround($76 * $77);
 $79 = Math_fround(HEAPF32[$7>>2]);
 $80 = Math_fround($76 * $79);
 $81 = Math_fround(HEAPF32[$10>>2]);
 $82 = Math_fround($76 * $81);
 $83 = (($av2) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround(HEAPF32[$15>>2]);
 $86 = Math_fround($84 * $85);
 $87 = Math_fround(HEAPF32[$18>>2]);
 $88 = Math_fround($84 * $87);
 $89 = Math_fround(HEAPF32[$21>>2]);
 $90 = Math_fround($84 * $89);
 $91 = Math_fround($78 + $86);
 $92 = Math_fround($80 + $88);
 $93 = Math_fround($82 + $90);
 $94 = (($av2) + 8|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround(HEAPF32[$29>>2]);
 $97 = Math_fround($95 * $96);
 $98 = Math_fround(HEAPF32[$32>>2]);
 $99 = Math_fround($95 * $98);
 $100 = Math_fround(HEAPF32[$35>>2]);
 $101 = Math_fround($95 * $100);
 $102 = Math_fround($91 + $97);
 $103 = Math_fround($92 + $99);
 $104 = Math_fround($93 + $101);
 HEAPF32[$v2>>2] = $102;
 $105 = (($v2) + 4|0);
 HEAPF32[$105>>2] = $103;
 $106 = (($v2) + 8|0);
 HEAPF32[$106>>2] = $104;
 $107 = (($v2) + 12|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($this) + 88|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($this) + 92|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($this) + 96|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 HEAPF32[$cap0>>2] = $109;
 $114 = (($cap0) + 4|0);
 HEAPF32[$114>>2] = $111;
 $115 = (($cap0) + 8|0);
 HEAPF32[$115>>2] = $113;
 $116 = (($cap0) + 12|0);
 HEAPF32[$116>>2] = Math_fround(0.0);
 $117 = (($this) + 100|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($this) + 104|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($this) + 108|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 HEAPF32[$cap1>>2] = $118;
 $123 = (($cap1) + 4|0);
 HEAPF32[$123>>2] = $120;
 $124 = (($cap1) + 8|0);
 HEAPF32[$124>>2] = $122;
 $125 = (($cap1) + 12|0);
 HEAPF32[$125>>2] = Math_fround(0.0);
 __ZN5physx2Gu30distanceSegmentTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_RS3_S6_($result,$cap0,$cap1,$v0,$v1,$v2,$dummy1,$dummy2);
 $126 = Math_fround(HEAPF32[$result>>2]);
 $127 = (($this) + 72|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = !($126 <= $128);
 if ($129) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $130 = (($this) + 68|0);
 HEAP8[$130>>0] = 1;
 $131 = (($this) + 116|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($132|0)==(0|0);
 if ($133) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $134 = (($aHit) + 8|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($132) + 4|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (($132) + 8|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = ($137>>>0)<($139>>>0);
 if (!($140)) {
  $141 = (($132) + 20|0);
  HEAP8[$141>>0] = 1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $142 = (($132) + 16|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = (($132) + 12|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = ($143>>>0)<($145>>>0);
 if ($146) {
  $150 = (($143) + 1)|0;
  HEAP32[$142>>2] = $150;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $147 = (($137) + 1)|0;
  HEAP32[$136>>2] = $147;
  $148 = HEAP32[$132>>2]|0;
  $149 = (($148) + ($137<<2)|0);
  HEAP32[$149>>2] = $135;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN26IntersectAnyVsMeshCallbackILi1ELb0EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi1ELb1EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi1ELb1EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj($this,$aHit,$av0,$av1,$av2,$0,$1) {
 $this = $this|0;
 $aHit = $aHit|0;
 $av0 = $av0|0;
 $av1 = $av1|0;
 $av2 = $av2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0;
 var $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $cap0 = 0, $cap1 = 0, $dummy1 = 0, $dummy2 = 0, $result = 0, $v0 = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $v0 = sp + 112|0;
 $v1 = sp;
 $v2 = sp + 16|0;
 $dummy1 = sp + 32|0;
 $dummy2 = sp + 48|0;
 $cap0 = sp + 64|0;
 $cap1 = sp + 80|0;
 $result = sp + 96|0;
 $2 = Math_fround(HEAPF32[$av0>>2]);
 $3 = (($av0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($av0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$v0>>2] = $2;
 $7 = (($v0) + 4|0);
 HEAPF32[$7>>2] = $4;
 $8 = (($v0) + 8|0);
 HEAPF32[$8>>2] = $6;
 $9 = (($v0) + 12|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = Math_fround(HEAPF32[$av1>>2]);
 $11 = (($av1) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($av1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$v1>>2] = $10;
 $15 = (($v1) + 4|0);
 HEAPF32[$15>>2] = $12;
 $16 = (($v1) + 8|0);
 HEAPF32[$16>>2] = $14;
 $17 = (($v1) + 12|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = Math_fround(HEAPF32[$av2>>2]);
 $19 = (($av2) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($av2) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$v2>>2] = $18;
 $23 = (($v2) + 4|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($v2) + 8|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($v2) + 12|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($this) + 88|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($this) + 92|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($this) + 96|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$cap0>>2] = $27;
 $32 = (($cap0) + 4|0);
 HEAPF32[$32>>2] = $29;
 $33 = (($cap0) + 8|0);
 HEAPF32[$33>>2] = $31;
 $34 = (($cap0) + 12|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($this) + 100|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($this) + 104|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($this) + 108|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 HEAPF32[$cap1>>2] = $36;
 $41 = (($cap1) + 4|0);
 HEAPF32[$41>>2] = $38;
 $42 = (($cap1) + 8|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($cap1) + 12|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 __ZN5physx2Gu30distanceSegmentTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_RS3_S6_($result,$cap0,$cap1,$v0,$v1,$v2,$dummy1,$dummy2);
 $44 = Math_fround(HEAPF32[$result>>2]);
 $45 = (($this) + 72|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = !($44 <= $46);
 if ($47) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $48 = (($this) + 68|0);
 HEAP8[$48>>0] = 1;
 $49 = (($this) + 116|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $52 = (($aHit) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($50) + 4|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($50) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($55>>>0)<($57>>>0);
 if (!($58)) {
  $59 = (($50) + 20|0);
  HEAP8[$59>>0] = 1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $60 = (($50) + 16|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($50) + 12|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($61>>>0)<($63>>>0);
 if ($64) {
  $68 = (($61) + 1)|0;
  HEAP32[$60>>2] = $68;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $65 = (($55) + 1)|0;
  HEAP32[$54>>2] = $65;
  $66 = HEAP32[$50>>2]|0;
  $67 = (($66) + ($55<<2)|0);
  HEAP32[$67>>2] = $53;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN26IntersectAnyVsMeshCallbackILi1ELb1EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25computeSweptAABBAroundOBBERKNS0_3BoxERNS_6PxVec3ES5_S5_Rf($obb,$sweepOrigin,$sweepExtents,$sweepDir,$sweepLen) {
 $obb = $obb|0;
 $sweepOrigin = $sweepOrigin|0;
 $sweepExtents = $sweepExtents|0;
 $sweepDir = $sweepDir|0;
 $sweepLen = $sweepLen|0;
 var $$0$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i1 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i2 = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i2$i3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($obb) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($obb) + 52|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($obb) + 56|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $3 > $5;
 $7 = $6 ? $3 : $5;
 $8 = !($1 >= $7);
 if ($8) {
  $9 = !($3 >= $5);
  if ($9) {
   $$0$i = 2;$22 = 0;$34 = 1;
  } else {
   $$0$i = 1;$22 = 0;$34 = 2;
  }
 } else {
  $$0$i = 0;$22 = 1;$34 = 2;
 }
 $10 = (($0) + ($$0$i<<2)|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($obb) + (($$0$i*12)|0)|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 * $13);
 $15 = ((($obb) + (($$0$i*12)|0)|0) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($11 * $16);
 $18 = ((($obb) + (($$0$i*12)|0)|0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($11 * $19);
 $21 = (($obb) + (($22*12)|0)|0);
 $23 = Math_fround(HEAPF32[$21>>2]);
 $fabsf$i$i$i1 = (Math_fround(Math_abs((Math_fround($23)))));
 $24 = ((($obb) + (($22*12)|0)|0) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $fabsf$i$i1$i2 = (Math_fround(Math_abs((Math_fround($25)))));
 $26 = ((($obb) + (($22*12)|0)|0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $fabsf$i$i2$i3 = (Math_fround(Math_abs((Math_fround($27)))));
 $28 = (($0) + ($22<<2)|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($fabsf$i$i$i1 * $29);
 $31 = Math_fround($fabsf$i$i1$i2 * $29);
 $32 = Math_fround($fabsf$i$i2$i3 * $29);
 $33 = (($obb) + (($34*12)|0)|0);
 $35 = Math_fround(HEAPF32[$33>>2]);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($35)))));
 $36 = ((($obb) + (($34*12)|0)|0) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($37)))));
 $38 = ((($obb) + (($34*12)|0)|0) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($39)))));
 $40 = (($0) + ($34<<2)|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($fabsf$i$i$i * $41);
 $43 = Math_fround($fabsf$i$i1$i * $41);
 $44 = Math_fround($fabsf$i$i2$i * $41);
 $45 = (($obb) + 36|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 - $14);
 $48 = (($obb) + 40|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 - $17);
 $51 = (($obb) + 44|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 - $20);
 HEAPF32[$sweepOrigin>>2] = $47;
 $54 = (($sweepOrigin) + 4|0);
 HEAPF32[$54>>2] = $50;
 $55 = (($sweepOrigin) + 8|0);
 HEAPF32[$55>>2] = $53;
 $56 = Math_fround($30 + $42);
 $57 = Math_fround($31 + $43);
 $58 = Math_fround($32 + $44);
 $59 = Math_fround($56 + Math_fround(0.00100000004749745130539));
 $60 = Math_fround($57 + Math_fround(0.00100000004749745130539));
 $61 = Math_fround($58 + Math_fround(0.00100000004749745130539));
 HEAPF32[$sweepExtents>>2] = $59;
 $62 = (($sweepExtents) + 4|0);
 HEAPF32[$62>>2] = $60;
 $63 = (($sweepExtents) + 8|0);
 HEAPF32[$63>>2] = $61;
 HEAPF32[$sweepLen>>2] = Math_fround(2.0);
 HEAPF32[$sweepDir>>2] = $14;
 $64 = (($sweepDir) + 4|0);
 HEAPF32[$64>>2] = $17;
 $65 = (($sweepDir) + 8|0);
 HEAPF32[$65>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi0ELb0EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi0ELb0EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj($this,$aHit,$av0,$av1,$av2,$0,$1) {
 $this = $this|0;
 $aHit = $aHit|0;
 $av0 = $av0|0;
 $av1 = $av1|0;
 $av2 = $av2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0;
 var $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0;
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $closestP = 0, $dummy1 = 0, $dummy2 = 0, $v0 = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $v0 = sp + 112|0;
 $v1 = sp;
 $v2 = sp + 16|0;
 $dummy1 = sp + 32|0;
 $dummy2 = sp + 48|0;
 $closestP = sp + 64|0;
 $2 = sp + 80|0;
 $3 = sp + 96|0;
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_fround(HEAPF32[$av0>>2]);
 $7 = Math_fround(HEAPF32[$5>>2]);
 $8 = Math_fround($6 * $7);
 $9 = (($5) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($6 * $10);
 $12 = (($5) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($6 * $13);
 $15 = (($av0) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($5) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = (($5) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($16 * $21);
 $23 = (($5) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($16 * $24);
 $26 = Math_fround($8 + $19);
 $27 = Math_fround($11 + $22);
 $28 = Math_fround($14 + $25);
 $29 = (($av0) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($5) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($30 * $32);
 $34 = (($5) + 28|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($30 * $35);
 $37 = (($5) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($30 * $38);
 $40 = Math_fround($26 + $33);
 $41 = Math_fround($27 + $36);
 $42 = Math_fround($28 + $39);
 HEAPF32[$v0>>2] = $40;
 $43 = (($v0) + 4|0);
 HEAPF32[$43>>2] = $41;
 $44 = (($v0) + 8|0);
 HEAPF32[$44>>2] = $42;
 $45 = (($v0) + 12|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = Math_fround(HEAPF32[$av1>>2]);
 $47 = Math_fround(HEAPF32[$5>>2]);
 $48 = Math_fround($46 * $47);
 $49 = Math_fround(HEAPF32[$9>>2]);
 $50 = Math_fround($46 * $49);
 $51 = Math_fround(HEAPF32[$12>>2]);
 $52 = Math_fround($46 * $51);
 $53 = (($av1) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround(HEAPF32[$17>>2]);
 $56 = Math_fround($54 * $55);
 $57 = Math_fround(HEAPF32[$20>>2]);
 $58 = Math_fround($54 * $57);
 $59 = Math_fround(HEAPF32[$23>>2]);
 $60 = Math_fround($54 * $59);
 $61 = Math_fround($48 + $56);
 $62 = Math_fround($50 + $58);
 $63 = Math_fround($52 + $60);
 $64 = (($av1) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround(HEAPF32[$31>>2]);
 $67 = Math_fround($65 * $66);
 $68 = Math_fround(HEAPF32[$34>>2]);
 $69 = Math_fround($65 * $68);
 $70 = Math_fround(HEAPF32[$37>>2]);
 $71 = Math_fround($65 * $70);
 $72 = Math_fround($61 + $67);
 $73 = Math_fround($62 + $69);
 $74 = Math_fround($63 + $71);
 HEAPF32[$v1>>2] = $72;
 $75 = (($v1) + 4|0);
 HEAPF32[$75>>2] = $73;
 $76 = (($v1) + 8|0);
 HEAPF32[$76>>2] = $74;
 $77 = (($v1) + 12|0);
 HEAPF32[$77>>2] = Math_fround(0.0);
 $78 = Math_fround(HEAPF32[$av2>>2]);
 $79 = Math_fround(HEAPF32[$5>>2]);
 $80 = Math_fround($78 * $79);
 $81 = Math_fround(HEAPF32[$9>>2]);
 $82 = Math_fround($78 * $81);
 $83 = Math_fround(HEAPF32[$12>>2]);
 $84 = Math_fround($78 * $83);
 $85 = (($av2) + 4|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround(HEAPF32[$17>>2]);
 $88 = Math_fround($86 * $87);
 $89 = Math_fround(HEAPF32[$20>>2]);
 $90 = Math_fround($86 * $89);
 $91 = Math_fround(HEAPF32[$23>>2]);
 $92 = Math_fround($86 * $91);
 $93 = Math_fround($80 + $88);
 $94 = Math_fround($82 + $90);
 $95 = Math_fround($84 + $92);
 $96 = (($av2) + 8|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround(HEAPF32[$31>>2]);
 $99 = Math_fround($97 * $98);
 $100 = Math_fround(HEAPF32[$34>>2]);
 $101 = Math_fround($97 * $100);
 $102 = Math_fround(HEAPF32[$37>>2]);
 $103 = Math_fround($97 * $102);
 $104 = Math_fround($93 + $99);
 $105 = Math_fround($94 + $101);
 $106 = Math_fround($95 + $103);
 HEAPF32[$v2>>2] = $104;
 $107 = (($v2) + 4|0);
 HEAPF32[$107>>2] = $105;
 $108 = (($v2) + 8|0);
 HEAPF32[$108>>2] = $106;
 $109 = (($v2) + 12|0);
 HEAPF32[$109>>2] = Math_fround(0.0);
 $110 = (($this) + 76|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($this) + 80|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($this) + 84|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 HEAPF32[$3>>2] = $111;
 $116 = (($3) + 4|0);
 HEAPF32[$116>>2] = $113;
 $117 = (($3) + 8|0);
 HEAPF32[$117>>2] = $115;
 $118 = (($3) + 12|0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 __ZN5physx2Gu28distancePointTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_RNS2_6FloatVES7_RS3_($2,$3,$v0,$v1,$v2,$dummy1,$dummy2,$closestP);
 $119 = Math_fround(HEAPF32[$2>>2]);
 $120 = (($this) + 72|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = !($119 <= $121);
 if ($122) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $123 = (($this) + 68|0);
 HEAP8[$123>>0] = 1;
 $124 = (($this) + 116|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = ($125|0)==(0|0);
 if ($126) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $127 = (($aHit) + 8|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = (($125) + 4|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (($125) + 8|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($130>>>0)<($132>>>0);
 if (!($133)) {
  $134 = (($125) + 20|0);
  HEAP8[$134>>0] = 1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $135 = (($125) + 16|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = (($125) + 12|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = ($136>>>0)<($138>>>0);
 if ($139) {
  $143 = (($136) + 1)|0;
  HEAP32[$135>>2] = $143;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $140 = (($130) + 1)|0;
  HEAP32[$129>>2] = $140;
  $141 = HEAP32[$125>>2]|0;
  $142 = (($141) + ($130<<2)|0);
  HEAP32[$142>>2] = $128;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN26IntersectAnyVsMeshCallbackILi0ELb0EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi0ELb1EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN26IntersectAnyVsMeshCallbackILi0ELb1EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj($this,$aHit,$av0,$av1,$av2,$0,$1) {
 $this = $this|0;
 $aHit = $aHit|0;
 $av0 = $av0|0;
 $av1 = $av1|0;
 $av2 = $av2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $7 = 0, $8 = Math_fround(0);
 var $9 = 0, $closestP = 0, $dummy1 = 0, $dummy2 = 0, $v0 = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $v0 = sp + 112|0;
 $v1 = sp;
 $v2 = sp + 16|0;
 $dummy1 = sp + 32|0;
 $dummy2 = sp + 48|0;
 $closestP = sp + 64|0;
 $2 = sp + 80|0;
 $3 = sp + 96|0;
 $4 = Math_fround(HEAPF32[$av0>>2]);
 $5 = (($av0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($av0) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$v0>>2] = $4;
 $9 = (($v0) + 4|0);
 HEAPF32[$9>>2] = $6;
 $10 = (($v0) + 8|0);
 HEAPF32[$10>>2] = $8;
 $11 = (($v0) + 12|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = Math_fround(HEAPF32[$av1>>2]);
 $13 = (($av1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($av1) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$v1>>2] = $12;
 $17 = (($v1) + 4|0);
 HEAPF32[$17>>2] = $14;
 $18 = (($v1) + 8|0);
 HEAPF32[$18>>2] = $16;
 $19 = (($v1) + 12|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = Math_fround(HEAPF32[$av2>>2]);
 $21 = (($av2) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($av2) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$v2>>2] = $20;
 $25 = (($v2) + 4|0);
 HEAPF32[$25>>2] = $22;
 $26 = (($v2) + 8|0);
 HEAPF32[$26>>2] = $24;
 $27 = (($v2) + 12|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 76|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($this) + 80|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 84|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$3>>2] = $29;
 $34 = (($3) + 4|0);
 HEAPF32[$34>>2] = $31;
 $35 = (($3) + 8|0);
 HEAPF32[$35>>2] = $33;
 $36 = (($3) + 12|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 __ZN5physx2Gu28distancePointTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_RNS2_6FloatVES7_RS3_($2,$3,$v0,$v1,$v2,$dummy1,$dummy2,$closestP);
 $37 = Math_fround(HEAPF32[$2>>2]);
 $38 = (($this) + 72|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = !($37 <= $39);
 if ($40) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = (($this) + 68|0);
 HEAP8[$41>>0] = 1;
 $42 = (($this) + 116|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($aHit) + 8|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($43) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($43) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($48>>>0)<($50>>>0);
 if (!($51)) {
  $52 = (($43) + 20|0);
  HEAP8[$52>>0] = 1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $53 = (($43) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($43) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($54>>>0)<($56>>>0);
 if ($57) {
  $61 = (($54) + 1)|0;
  HEAP32[$53>>2] = $61;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $58 = (($48) + 1)|0;
  HEAP32[$47>>2] = $58;
  $59 = HEAP32[$43>>2]|0;
  $60 = (($59) + ($48<<2)|0);
  HEAP32[$60>>2] = $46;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN26IntersectAnyVsMeshCallbackILi0ELb1EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN27ConvexVsMeshOverlapCallbackC2ERKN5physx2Gu10ConvexMeshERKNS0_11PxMeshScaleERKNS0_2Cm23FastVertex2ShapeScalingERKNS0_11PxTransformESE_bRKNS1_3BoxE($this,$cm,$convexScale,$meshScale,$tr0,$tr1,$identityScale,$meshSpaceOBB) {
 $this = $this|0;
 $cm = $cm|0;
 $convexScale = $convexScale|0;
 $meshScale = $meshScale|0;
 $tr0 = $tr0|0;
 $tr1 = $tr1|0;
 $identityScale = $identityScale|0;
 $meshSpaceOBB = $meshSpaceOBB|0;
 var $$$i$i = Math_fround(0), $$sroa$117 = 0, $$sroa$3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0);
 var $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0;
 var $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0;
 var $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0);
 var $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $vQuat0 = 0, $vScale0 = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $zero$sroa$1$i$i$i = sp + 272|0;
 $0 = sp;
 $$sroa$3$i$i = sp + 288|0;
 $vScale0 = sp + 32|0;
 $vQuat0 = sp + 48|0;
 $1 = sp + 64|0;
 $2 = sp + 16|0;
 $$sroa$117 = sp + 304|0;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = 2;
 HEAP32[$this>>2] = ((552552 + 8|0));
 $4 = (($this) + 64|0);
 ;HEAP32[$zero$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$zero$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$zero$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$zero$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$4+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$zero$sroa$1$i$i$i+12>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$$sroa$3$i$i+0>>2]=0|0;HEAP32[$$sroa$3$i$i+4>>2]=0|0;HEAP32[$$sroa$3$i$i+8>>2]=0|0;HEAP32[$$sroa$3$i$i+12>>2]=0|0;
 $5 = (($this) + 16|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 20|0);
 ;HEAP32[$6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$0+12>>2]|0;
 $7 = (($this) + 36|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($this) + 40|0);
 ;HEAP32[$8+0>>2]=HEAP32[$$sroa$3$i$i+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$$sroa$3$i$i+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$$sroa$3$i$i+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$$sroa$3$i$i+12>>2]|0;
 $9 = (($this) + 56|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 60|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 96|0);
 $12 = (($this) + 160|0);
 $13 = (($this) + 176|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 112|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($this) + 116|0);
 ;HEAP32[$15+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $16 = (($this) + 128|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 132|0);
 ;HEAP32[$17+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $18 = (($this) + 144|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 148|0);
 ;HEAP32[$19+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$12+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$0+12>>2]|0;
 $20 = (($this) + 352|0);
 ;HEAP32[$zero$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$zero$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$zero$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$zero$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$20+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$zero$sroa$1$i$i$i+12>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$$sroa$3$i$i+0>>2]=0|0;HEAP32[$$sroa$3$i$i+4>>2]=0|0;HEAP32[$$sroa$3$i$i+8>>2]=0|0;HEAP32[$$sroa$3$i$i+12>>2]=0|0;
 $21 = (($this) + 304|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 308|0);
 ;HEAP32[$22+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$0+12>>2]|0;
 $23 = (($this) + 324|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($this) + 328|0);
 ;HEAP32[$24+0>>2]=HEAP32[$$sroa$3$i$i+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$$sroa$3$i$i+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$$sroa$3$i$i+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$$sroa$3$i$i+12>>2]|0;
 $25 = (($this) + 344|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($this) + 348|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 432|0);
 HEAP8[$27>>0] = 0;
 $28 = (($this) + 433|0);
 $29 = $identityScale&1;
 HEAP8[$28>>0] = $29;
 if (!($identityScale)) {
  $30 = Math_fround(HEAPF32[$meshScale>>2]);
  $31 = (($meshScale) + 4|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($meshScale) + 8|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($meshScale) + 12|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($meshScale) + 16|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($meshScale) + 20|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($meshScale) + 24|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($meshScale) + 28|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($meshScale) + 32|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($this) + 384|0);
  HEAPF32[$47>>2] = $30;
  $48 = (($this) + 388|0);
  HEAPF32[$48>>2] = $32;
  $49 = (($this) + 392|0);
  HEAPF32[$49>>2] = $34;
  $50 = (($this) + 396|0);
  HEAPF32[$50>>2] = Math_fround(0.0);
  $51 = (($this) + 400|0);
  HEAPF32[$51>>2] = $36;
  $52 = (($this) + 404|0);
  HEAPF32[$52>>2] = $38;
  $53 = (($this) + 408|0);
  HEAPF32[$53>>2] = $40;
  $54 = (($this) + 412|0);
  HEAPF32[$54>>2] = Math_fround(0.0);
  $55 = (($this) + 416|0);
  HEAPF32[$55>>2] = $42;
  $56 = (($this) + 420|0);
  HEAPF32[$56>>2] = $44;
  $57 = (($this) + 424|0);
  HEAPF32[$57>>2] = $46;
  $58 = (($this) + 428|0);
  HEAPF32[$58>>2] = Math_fround(0.0);
 }
 $59 = (($cm) + 16|0);
 $60 = Math_fround(HEAPF32[$convexScale>>2]);
 $61 = (($convexScale) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($convexScale) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 HEAPF32[$vScale0>>2] = $60;
 $65 = (($vScale0) + 4|0);
 HEAPF32[$65>>2] = $62;
 $66 = (($vScale0) + 8|0);
 HEAPF32[$66>>2] = $64;
 $67 = (($vScale0) + 12|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($convexScale) + 12|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($68) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($68) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($68) + 12|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 HEAPF32[$vQuat0>>2] = $69;
 $76 = (($vQuat0) + 4|0);
 HEAPF32[$76>>2] = $71;
 $77 = (($vQuat0) + 8|0);
 HEAPF32[$77>>2] = $73;
 $78 = (($vQuat0) + 12|0);
 HEAPF32[$78>>2] = $75;
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($1,$59,$2,$vScale0,$vQuat0);
 _memcpy(($11|0),($1|0),205)|0;
 $79 = Math_fround(HEAPF32[$tr0>>2]);
 $80 = Math_fround(-$79);
 $81 = (($tr0) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround(-$82);
 $84 = (($tr0) + 8|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround(-$85);
 $87 = (($tr0) + 12|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($tr1) + 16|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($tr0) + 16|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($90 - $92);
 $94 = (($tr1) + 20|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($tr0) + 20|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($95 - $97);
 $99 = (($tr1) + 24|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($tr0) + 24|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($100 - $102);
 $104 = Math_fround($93 * Math_fround(2.0));
 $105 = Math_fround($98 * Math_fround(2.0));
 $106 = Math_fround($103 * Math_fround(2.0));
 $107 = Math_fround($88 * $88);
 $108 = Math_fround($107 + Math_fround(-0.5));
 $109 = Math_fround($104 * $80);
 $110 = Math_fround($105 * $83);
 $111 = Math_fround($109 + $110);
 $112 = Math_fround($106 * $86);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($108 * $104);
 $115 = Math_fround($106 * $83);
 $116 = Math_fround($105 * $86);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($88 * $117);
 $119 = Math_fround($114 + $118);
 $120 = Math_fround($113 * $80);
 $121 = Math_fround($120 + $119);
 $122 = Math_fround($108 * $105);
 $123 = Math_fround($104 * $86);
 $124 = Math_fround($106 * $80);
 $125 = Math_fround($123 - $124);
 $126 = Math_fround($88 * $125);
 $127 = Math_fround($122 + $126);
 $128 = Math_fround($113 * $83);
 $129 = Math_fround($128 + $127);
 $130 = Math_fround($108 * $106);
 $131 = Math_fround($105 * $80);
 $132 = Math_fround($104 * $83);
 $133 = Math_fround($131 - $132);
 $134 = Math_fround($88 * $133);
 $135 = Math_fround($130 + $134);
 $136 = Math_fround($113 * $86);
 $137 = Math_fround($135 + $136);
 $138 = Math_fround(HEAPF32[$tr1>>2]);
 $139 = Math_fround($88 * $138);
 $140 = (($tr1) + 12|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = Math_fround($141 * $80);
 $143 = Math_fround($139 + $142);
 $144 = (($tr1) + 8|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround($145 * $83);
 $147 = Math_fround($143 + $146);
 $148 = (($tr1) + 4|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = Math_fround($149 * $86);
 $151 = Math_fround($147 - $150);
 $152 = Math_fround($88 * $149);
 $153 = Math_fround($141 * $83);
 $154 = Math_fround($153 + $152);
 $155 = Math_fround($138 * $86);
 $156 = Math_fround($155 + $154);
 $157 = Math_fround($145 * $80);
 $158 = Math_fround($156 - $157);
 $159 = Math_fround($88 * $145);
 $160 = Math_fround($141 * $86);
 $161 = Math_fround($160 + $159);
 $162 = Math_fround($149 * $80);
 $163 = Math_fround($162 + $161);
 $164 = Math_fround($138 * $83);
 $165 = Math_fround($163 - $164);
 $166 = Math_fround($88 * $141);
 $167 = Math_fround($138 * $80);
 $168 = Math_fround($166 - $167);
 $169 = Math_fround($149 * $83);
 $170 = Math_fround($168 - $169);
 $171 = Math_fround($145 * $86);
 $172 = Math_fround($170 - $171);
 $173 = Math_fround($151 + $151);
 $174 = Math_fround($158 + $158);
 $175 = Math_fround($165 + $165);
 $176 = Math_fround($151 * $173);
 $177 = Math_fround($158 * $174);
 $178 = Math_fround($165 * $175);
 $179 = Math_fround($173 * $158);
 $180 = Math_fround($173 * $165);
 $181 = Math_fround($173 * $172);
 $182 = Math_fround($165 * $174);
 $183 = Math_fround($172 * $174);
 $184 = Math_fround($172 * $175);
 $185 = Math_fround(Math_fround(1.0) - $176);
 $186 = Math_fround(Math_fround(1.0) - $177);
 $187 = Math_fround($186 - $178);
 $188 = Math_fround($179 + $184);
 $189 = Math_fround($180 - $183);
 $190 = Math_fround($179 - $184);
 $191 = Math_fround($185 - $178);
 $192 = Math_fround($181 + $182);
 $193 = Math_fround($180 + $183);
 $194 = Math_fround($182 - $181);
 $195 = Math_fround($185 - $177);
 HEAPF32[$21>>2] = $187;
 HEAPF32[$22>>2] = $188;
 $196 = (($this) + 312|0);
 HEAPF32[$196>>2] = $189;
 $197 = (($this) + 316|0);
 HEAPF32[$197>>2] = Math_fround(0.0);
 $198 = (($this) + 320|0);
 HEAPF32[$198>>2] = $190;
 HEAPF32[$23>>2] = $191;
 HEAPF32[$24>>2] = $192;
 $199 = (($this) + 332|0);
 HEAPF32[$199>>2] = Math_fround(0.0);
 $200 = (($this) + 336|0);
 HEAPF32[$200>>2] = $193;
 $201 = (($this) + 340|0);
 HEAPF32[$201>>2] = $194;
 HEAPF32[$25>>2] = $195;
 HEAPF32[$26>>2] = Math_fround(0.0);
 $202 = (($this) + 352|0);
 HEAPF32[$202>>2] = $121;
 $203 = (($this) + 356|0);
 HEAPF32[$203>>2] = $129;
 $204 = (($this) + 360|0);
 HEAPF32[$204>>2] = $137;
 $205 = (($this) + 364|0);
 HEAPF32[$205>>2] = Math_fround(0.0);
 $206 = (($cm) + 68|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = (($cm) + 72|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = (($cm) + 76|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = Math_fround(HEAPF32[$vScale0>>2]);
 $213 = Math_fround(HEAPF32[$65>>2]);
 $214 = Math_fround(HEAPF32[$66>>2]);
 $215 = Math_fround($207 * $212);
 $216 = Math_fround($209 * $213);
 $217 = Math_fround($211 * $214);
 $218 = !($215 <= $216);
 $$$i$i = $218 ? $216 : $215;
 $219 = !($$$i$i <= $217);
 $220 = $219 ? $217 : $$$i$i;
 $221 = Math_fround($220 * Math_fround(0.00999999977648258209228));
 $222 = Math_fround($221 * $221);
 $223 = (($this) + 368|0);
 HEAPF32[$223>>2] = $222;
 $224 = (($this) + 372|0);
 ;HEAP32[$224+0>>2]=HEAP32[$$sroa$117+0>>2]|0;HEAP32[$224+4>>2]=HEAP32[$$sroa$117+4>>2]|0;HEAP32[$224+8>>2]=HEAP32[$$sroa$117+8>>2]|0;
 HEAP8[$28>>0] = $29;
 $225 = Math_fround(HEAPF32[$meshSpaceOBB>>2]);
 $226 = (($meshSpaceOBB) + 4|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 $228 = (($meshSpaceOBB) + 8|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = (($meshSpaceOBB) + 12|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($meshSpaceOBB) + 16|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = (($meshSpaceOBB) + 20|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = (($meshSpaceOBB) + 24|0);
 $237 = Math_fround(HEAPF32[$236>>2]);
 $238 = (($meshSpaceOBB) + 28|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($meshSpaceOBB) + 32|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = (($meshSpaceOBB) + 36|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($meshSpaceOBB) + 40|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = (($meshSpaceOBB) + 44|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = Math_fround(-$243);
 $249 = Math_fround(-$245);
 $250 = Math_fround(-$247);
 $251 = Math_fround($225 * $248);
 $252 = Math_fround($227 * $249);
 $253 = Math_fround($251 + $252);
 $254 = Math_fround($229 * $250);
 $255 = Math_fround($253 + $254);
 $256 = Math_fround($231 * $248);
 $257 = Math_fround($233 * $249);
 $258 = Math_fround($256 + $257);
 $259 = Math_fround($235 * $250);
 $260 = Math_fround($258 + $259);
 $261 = Math_fround($237 * $248);
 $262 = Math_fround($239 * $249);
 $263 = Math_fround($261 + $262);
 $264 = Math_fround($241 * $250);
 $265 = Math_fround($263 + $264);
 HEAPF32[$5>>2] = $225;
 HEAPF32[$6>>2] = $231;
 $266 = (($this) + 24|0);
 HEAPF32[$266>>2] = $237;
 $267 = (($this) + 28|0);
 HEAPF32[$267>>2] = Math_fround(0.0);
 $268 = (($this) + 32|0);
 HEAPF32[$268>>2] = $227;
 HEAPF32[$7>>2] = $233;
 HEAPF32[$8>>2] = $239;
 $269 = (($this) + 44|0);
 HEAPF32[$269>>2] = Math_fround(0.0);
 $270 = (($this) + 48|0);
 HEAPF32[$270>>2] = $229;
 $271 = (($this) + 52|0);
 HEAPF32[$271>>2] = $235;
 HEAPF32[$9>>2] = $241;
 HEAPF32[$10>>2] = Math_fround(0.0);
 $272 = (($this) + 64|0);
 HEAPF32[$272>>2] = $255;
 $273 = (($this) + 68|0);
 HEAPF32[$273>>2] = $260;
 $274 = (($this) + 72|0);
 HEAPF32[$274>>2] = $265;
 $275 = (($this) + 76|0);
 HEAPF32[$275>>2] = Math_fround(0.0);
 $276 = (($meshSpaceOBB) + 48|0);
 $277 = Math_fround(HEAPF32[$276>>2]);
 $278 = Math_fround($277 + Math_fround(0.00100000004749745130539));
 $279 = (($meshSpaceOBB) + 52|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = Math_fround($280 + Math_fround(0.00100000004749745130539));
 $282 = (($meshSpaceOBB) + 56|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = Math_fround($283 + Math_fround(0.00100000004749745130539));
 $285 = (($this) + 80|0);
 HEAPF32[$285>>2] = $278;
 $286 = (($this) + 84|0);
 HEAPF32[$286>>2] = $281;
 $287 = (($this) + 88|0);
 HEAPF32[$287>>2] = $284;
 $288 = (($this) + 92|0);
 HEAPF32[$288>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN27ConvexVsMeshOverlapCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$0,$v0a,$v1a,$v2a,$1,$2) {
 $this = $this|0;
 $0 = $0|0;
 $v0a = $v0a|0;
 $v1a = $v1a|0;
 $v2a = $v2a|0;
 $1 = $1|0;
 $2 = $2|0;
 var $$ = 0, $$$i = Math_fround(0), $$$i30 = Math_fround(0), $$$i36 = Math_fround(0), $$$i42 = Math_fround(0), $$1 = 0, $$1$i = Math_fround(0), $$1$i31 = Math_fround(0), $$1$i37 = Math_fround(0), $$1$i43 = Math_fround(0), $$216 = 0, $$sroa$1$i$i = 0, $$sroa$113$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0;
 var $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0);
 var $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0);
 var $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0);
 var $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $contactA = 0, $contactB = 0, $normal = 0, $not$ = 0, $not$217 = 0, $not$218 = 0;
 var $sqDist = 0, $triangle = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $zero$sroa$1$i$i$i = sp + 236|0;
 $3 = sp + 208|0;
 $$sroa$113$i$i = sp + 224|0;
 $$sroa$1$i$i = sp + 248|0;
 $triangle = sp + 64|0;
 $contactA = sp + 32|0;
 $contactB = sp + 16|0;
 $normal = sp;
 $sqDist = sp + 48|0;
 $4 = Math_fround(HEAPF32[$v0a>>2]);
 $5 = (($v0a) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($v0a) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$v1a>>2]);
 $10 = (($v1a) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($v1a) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$v2a>>2]);
 $15 = (($v2a) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($v2a) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 64|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 68|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 72|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($this) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($4 * $26);
 $28 = (($this) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($6 * $29);
 $31 = Math_fround($27 + $30);
 $32 = (($this) + 48|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($8 * $33);
 $35 = Math_fround($31 + $34);
 $36 = (($this) + 20|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($4 * $37);
 $39 = (($this) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($6 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($this) + 52|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($8 * $44);
 $46 = Math_fround($42 + $45);
 $47 = (($this) + 24|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($4 * $48);
 $50 = (($this) + 40|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($6 * $51);
 $53 = Math_fround($49 + $52);
 $54 = (($this) + 56|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($8 * $55);
 $57 = Math_fround($53 + $56);
 $58 = Math_fround($20 + $35);
 $59 = Math_fround($22 + $46);
 $60 = Math_fround($24 + $57);
 $61 = Math_fround($9 * $26);
 $62 = Math_fround($11 * $29);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($13 * $33);
 $65 = Math_fround($63 + $64);
 $66 = Math_fround($9 * $37);
 $67 = Math_fround($11 * $40);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($13 * $44);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($9 * $48);
 $72 = Math_fround($11 * $51);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($13 * $55);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($20 + $65);
 $77 = Math_fround($22 + $70);
 $78 = Math_fround($24 + $75);
 $79 = Math_fround($14 * $26);
 $80 = Math_fround($16 * $29);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($18 * $33);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($14 * $37);
 $85 = Math_fround($16 * $40);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($18 * $44);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($14 * $48);
 $90 = Math_fround($16 * $51);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($18 * $55);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($20 + $83);
 $95 = Math_fround($22 + $88);
 $96 = Math_fround($24 + $93);
 $97 = $58 < $76;
 $$$i42 = $97 ? $58 : $76;
 $98 = $59 < $77;
 $99 = $98 ? $59 : $77;
 $100 = $60 < $78;
 $$1$i43 = $100 ? $60 : $78;
 $101 = $$$i42 < $94;
 $$$i36 = $101 ? $$$i42 : $94;
 $102 = $99 < $95;
 $103 = $102 ? $99 : $95;
 $104 = $$1$i43 < $96;
 $$1$i37 = $104 ? $$1$i43 : $96;
 $105 = $58 > $76;
 $$$i30 = $105 ? $58 : $76;
 $106 = $59 > $77;
 $107 = $106 ? $59 : $77;
 $108 = $60 > $78;
 $$1$i31 = $108 ? $60 : $78;
 $109 = $$$i30 > $94;
 $$$i = $109 ? $$$i30 : $94;
 $110 = $107 > $95;
 $111 = $110 ? $107 : $95;
 $112 = $$1$i31 > $96;
 $$1$i = $112 ? $$1$i31 : $96;
 $113 = (($this) + 80|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($this) + 84|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (($this) + 88|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = Math_fround(-$114);
 $120 = Math_fround(-$116);
 $121 = Math_fround(-$118);
 $122 = $$$i < $119;
 $123 = $111 < $120;
 $124 = $$1$i < $121;
 $not$ = $$$i36 > $114;
 $$ = $122 | $not$;
 $not$217 = $103 > $116;
 $125 = $123 | $not$217;
 $not$218 = $$1$i37 > $118;
 $$216 = $124 | $not$218;
 $126 = $125 | $$;
 $127 = $126 | $$216;
 if ($127) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $128 = (($this) + 433|0);
 $129 = HEAP8[$128>>0]|0;
 $130 = ($129<<24>>24)==(0);
 if ($130) {
  $131 = (($this) + 384|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = Math_fround($4 * $132);
  $134 = (($this) + 400|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = Math_fround($6 * $135);
  $137 = Math_fround($133 + $136);
  $138 = (($this) + 416|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($8 * $139);
  $141 = Math_fround($137 + $140);
  $142 = (($this) + 388|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = Math_fround($4 * $143);
  $145 = (($this) + 404|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = Math_fround($6 * $146);
  $148 = Math_fround($144 + $147);
  $149 = (($this) + 420|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $151 = Math_fround($8 * $150);
  $152 = Math_fround($148 + $151);
  $153 = (($this) + 392|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = Math_fround($4 * $154);
  $156 = (($this) + 408|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = Math_fround($6 * $157);
  $159 = Math_fround($155 + $158);
  $160 = (($this) + 424|0);
  $161 = Math_fround(HEAPF32[$160>>2]);
  $162 = Math_fround($8 * $161);
  $163 = Math_fround($159 + $162);
  $164 = Math_fround($9 * $132);
  $165 = Math_fround($11 * $135);
  $166 = Math_fround($164 + $165);
  $167 = Math_fround($13 * $139);
  $168 = Math_fround($166 + $167);
  $169 = Math_fround($9 * $143);
  $170 = Math_fround($11 * $146);
  $171 = Math_fround($169 + $170);
  $172 = Math_fround($13 * $150);
  $173 = Math_fround($171 + $172);
  $174 = Math_fround($9 * $154);
  $175 = Math_fround($11 * $157);
  $176 = Math_fround($174 + $175);
  $177 = Math_fround($13 * $161);
  $178 = Math_fround($176 + $177);
  $179 = Math_fround($14 * $132);
  $180 = Math_fround($16 * $135);
  $181 = Math_fround($179 + $180);
  $182 = Math_fround($18 * $139);
  $183 = Math_fround($181 + $182);
  $184 = Math_fround($14 * $143);
  $185 = Math_fround($16 * $146);
  $186 = Math_fround($184 + $185);
  $187 = Math_fround($18 * $150);
  $188 = Math_fround($186 + $187);
  $189 = Math_fround($14 * $154);
  $190 = Math_fround($16 * $157);
  $191 = Math_fround($189 + $190);
  $192 = Math_fround($18 * $161);
  $193 = Math_fround($191 + $192);
  $203 = $168;$204 = $141;$206 = $173;$207 = $152;$209 = $178;$210 = $163;$212 = $183;$214 = $188;$216 = $193;
 } else {
  $203 = $9;$204 = $4;$206 = $11;$207 = $6;$209 = $13;$210 = $8;$212 = $14;$214 = $16;$216 = $18;
 }
 $194 = (($triangle) + 64|0);
 $195 = (($triangle) + 80|0);
 HEAP32[$195>>2] = 7;
 $196 = (($triangle) + 16|0);
 $197 = (($triangle) + 20|0);
 $198 = (($triangle) + 32|0);
 $199 = (($triangle) + 36|0);
 $200 = (($triangle) + 48|0);
 HEAPF32[$200>>2] = Math_fround(0.0);
 $201 = (($triangle) + 52|0);
 ;HEAP32[$201+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$201+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$201+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 ;HEAP32[$194+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$194+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$194+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$194+12>>2]=HEAP32[$3+12>>2]|0;
 $202 = Math_fround($204 + $203);
 $205 = Math_fround($207 + $206);
 $208 = Math_fround($210 + $209);
 $211 = Math_fround($202 + $212);
 $213 = Math_fround($205 + $214);
 $215 = Math_fround($208 + $216);
 $217 = Math_fround($211 * Math_fround(0.333332985639572143555));
 $218 = Math_fround($213 * Math_fround(0.333332985639572143555));
 $219 = Math_fround($215 * Math_fround(0.333332985639572143555));
 HEAPF32[$triangle>>2] = $217;
 $220 = (($triangle) + 4|0);
 HEAPF32[$220>>2] = $218;
 $221 = (($triangle) + 8|0);
 HEAPF32[$221>>2] = $219;
 $222 = (($triangle) + 12|0);
 HEAPF32[$222>>2] = Math_fround(0.0);
 $223 = (($triangle) + 96|0);
 HEAPF32[$223>>2] = $204;
 $224 = (($triangle) + 100|0);
 HEAPF32[$224>>2] = $207;
 $225 = (($triangle) + 104|0);
 HEAPF32[$225>>2] = $210;
 $226 = (($triangle) + 108|0);
 HEAPF32[$226>>2] = Math_fround(0.0);
 $227 = (($triangle) + 112|0);
 HEAPF32[$227>>2] = $203;
 $228 = (($triangle) + 116|0);
 HEAPF32[$228>>2] = $206;
 $229 = (($triangle) + 120|0);
 HEAPF32[$229>>2] = $209;
 $230 = (($triangle) + 124|0);
 HEAPF32[$230>>2] = Math_fround(0.0);
 $231 = (($triangle) + 128|0);
 HEAPF32[$231>>2] = $212;
 $232 = (($triangle) + 132|0);
 HEAPF32[$232>>2] = $214;
 $233 = (($triangle) + 136|0);
 HEAPF32[$233>>2] = $216;
 $234 = (($triangle) + 140|0);
 HEAPF32[$234>>2] = Math_fround(0.0);
 HEAPF32[$196>>2] = Math_fround(0.0);
 ;HEAP32[$197+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$197+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$197+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 HEAPF32[$198>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$199+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$199+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$199+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
 $235 = (($this) + 96|0);
 $236 = (($this) + 304|0);
 $237 = (__ZN5physx2Gu11GJKRelativeERKNS0_9TriangleVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERNS8_5Vec3VESD_SD_RNS8_6FloatVE($triangle,$235,$236,$contactA,$contactB,$normal,$sqDist)|0);
 $238 = ($237|0)==(1);
 if (!($238)) {
  $239 = (($this) + 368|0);
  $240 = Math_fround(HEAPF32[$239>>2]);
  $241 = Math_fround(HEAPF32[$sqDist>>2]);
  $242 = !($240 >= $241);
  if ($242) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $243 = (($this) + 432|0);
 HEAP8[$243>>0] = 1;
 $$1 = 0;
 STACKTOP = sp;return ($$1|0);
}
function __ZN27ConvexVsMeshOverlapCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5RTreeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 92|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 76|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 72|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 64|0);
 HEAP32[$4>>2] = 4;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu5RTree4saveERNS_14PxOutputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5physx10writeChunkEaaaaRNS_14PxOutputStreamE(82,84,82,69,$stream);
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE(1,1,$stream);
 __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($this,4,1,$stream);
 $0 = (($this) + 16|0);
 __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($0,4,1,$stream);
 $1 = (($this) + 32|0);
 __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($1,4,1,$stream);
 $2 = (($this) + 48|0);
 __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($2,4,1,$stream);
 $3 = (($this) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($4,1,$stream);
 $5 = (($this) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($6,1,$stream);
 $7 = (($this) + 72|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($8,1,$stream);
 $9 = (($this) + 76|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($10,1,$stream);
 $11 = (($this) + 80|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($12,1,$stream);
 $13 = (($this) + 88|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN5physx10writeDwordEjbRNS_14PxOutputStreamE($14,1,$stream);
 $15 = HEAP32[$11>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  STACKTOP = sp;return 1;
 }
 $17 = (($this) + 92|0);
 $j$01 = 0;
 while(1) {
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + (($j$01*112)|0)|0);
  __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($19,4,1,$stream);
  $20 = HEAP32[$17>>2]|0;
  $21 = ((($20) + (($j$01*112)|0)|0) + 16|0);
  __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($21,4,1,$stream);
  $22 = HEAP32[$17>>2]|0;
  $23 = ((($22) + (($j$01*112)|0)|0) + 32|0);
  __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($23,4,1,$stream);
  $24 = HEAP32[$17>>2]|0;
  $25 = ((($24) + (($j$01*112)|0)|0) + 48|0);
  __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($25,4,1,$stream);
  $26 = HEAP32[$17>>2]|0;
  $27 = ((($26) + (($j$01*112)|0)|0) + 64|0);
  __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($27,4,1,$stream);
  $28 = HEAP32[$17>>2]|0;
  $29 = ((($28) + (($j$01*112)|0)|0) + 80|0);
  __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($29,4,1,$stream);
  $30 = HEAP32[$17>>2]|0;
  $31 = ((($30) + (($j$01*112)|0)|0) + 96|0);
  __ZN5physx16writeFloatBufferEPKfjbRNS_14PxOutputStreamE($31,4,1,$stream);
  $32 = (($j$01) + 1)|0;
  $33 = HEAP32[$11>>2]|0;
  $34 = ($32>>>0)<($33>>>0);
  if ($34) {
   $j$01 = $32;
  } else {
   break;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu5RTree4loadERNS_13PxInputStreamEj($this,$stream,$meshVersion) {
 $this = $this|0;
 $stream = $stream|0;
 $meshVersion = $meshVersion|0;
 var $$0 = 0, $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $a = 0, $b = 0, $c = 0, $d = 0, $j$01 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $a = sp;
 $b = sp + 1|0;
 $c = sp + 2|0;
 $d = sp + 3|0;
 $1 = sp + 4|0;
 $2 = (($this) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = (($this) + 92|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (($7) + -4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (0 - ($10))|0;
   $12 = (($7) + ($11)|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$12);
   HEAP32[$6>>2] = 0;
  }
 }
 __ZN5physx9readChunkERaS0_S0_S0_RNS_13PxInputStreamE($a,$b,$c,$d,$stream);
 $13 = HEAP8[$a>>0]|0;
 $14 = ($13<<24>>24)==(82);
 if (!($14)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = HEAP8[$b>>0]|0;
 $16 = ($15<<24>>24)==(84);
 if (!($16)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = HEAP8[$c>>0]|0;
 $18 = ($17<<24>>24)==(82);
 if (!($18)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = HEAP8[$d>>0]|0;
 $20 = ($19<<24>>24)==(69);
 if (!($20)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE(1,$stream)|0);
 $22 = ($21|0)==(1);
 if (!($22)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($this,4,1,$stream)|0);
 $23 = (($this) + 16|0);
 (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($23,4,1,$stream)|0);
 $24 = (($this) + 32|0);
 (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($24,4,1,$stream)|0);
 $25 = (($this) + 48|0);
 (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($25,4,1,$stream)|0);
 $26 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE(1,$stream)|0);
 $27 = (($this) + 64|0);
 HEAP32[$27>>2] = $26;
 $28 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE(1,$stream)|0);
 $29 = (($this) + 68|0);
 HEAP32[$29>>2] = $28;
 $30 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE(1,$stream)|0);
 $31 = (($this) + 72|0);
 HEAP32[$31>>2] = $30;
 $32 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE(1,$stream)|0);
 $33 = (($this) + 76|0);
 HEAP32[$33>>2] = $32;
 $34 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE(1,$stream)|0);
 $35 = (($this) + 80|0);
 HEAP32[$35>>2] = $34;
 $36 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE(1,$stream)|0);
 $37 = (($this) + 88|0);
 HEAP32[$37>>2] = $36;
 $38 = HEAP32[$35>>2]|0;
 $39 = ($38*112)|0;
 $40 = (($39) + 131)|0;
 $41 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,$40,552576,137)|0);
 $42 = ($41|0)==(0|0);
 if ($42) {
  $$0$i = 0;
 } else {
  $43 = (($41) + 131|0);
  $44 = $43;
  $45 = $44 & -128;
  $46 = $41;
  $47 = (($45) - ($46))|0;
  $48 = $45;
  $49 = (($48) + -4|0);
  HEAP32[$49>>2] = $47;
  $phitmp = $45;
  $$0$i = $phitmp;
 }
 $50 = (($this) + 92|0);
 HEAP32[$50>>2] = $$0$i;
 $51 = HEAP32[$35>>2]|0;
 $52 = ($51|0)==(0);
 if ($52) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $54 = $$0$i;$j$01 = 0;
 }
 while(1) {
  $53 = (($54) + (($j$01*112)|0)|0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($53,4,1,$stream)|0);
  $55 = HEAP32[$50>>2]|0;
  $56 = ((($55) + (($j$01*112)|0)|0) + 16|0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($56,4,1,$stream)|0);
  $57 = HEAP32[$50>>2]|0;
  $58 = ((($57) + (($j$01*112)|0)|0) + 32|0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($58,4,1,$stream)|0);
  $59 = HEAP32[$50>>2]|0;
  $60 = ((($59) + (($j$01*112)|0)|0) + 48|0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($60,4,1,$stream)|0);
  $61 = HEAP32[$50>>2]|0;
  $62 = ((($61) + (($j$01*112)|0)|0) + 64|0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($62,4,1,$stream)|0);
  $63 = HEAP32[$50>>2]|0;
  $64 = ((($63) + (($j$01*112)|0)|0) + 80|0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($64,4,1,$stream)|0);
  $65 = HEAP32[$50>>2]|0;
  $66 = ((($65) + (($j$01*112)|0)|0) + 96|0);
  (__ZN5physx15readFloatBufferEPfjbRNS_13PxInputStreamE($66,4,1,$stream)|0);
  $67 = (($j$01) + 1)|0;
  $68 = HEAP32[$35>>2]|0;
  $69 = ($67>>>0)<($68>>>0);
  if (!($69)) {
   $$0 = 1;
   break;
  }
  $$pre = HEAP32[$50>>2]|0;
  $54 = $$pre;$j$01 = $67;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu5RTree7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 92|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($6) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (0 - ($9))|0;
 $11 = (($6) + ($10)|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$11);
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu5RTree15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$stream>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($stream,128);
 $3 = HEAP32[$stream>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9*112)|0;
 FUNCTION_TABLE_viii[$5 & 4095]($stream,$7,$10);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu5RTree11traverseRayILi0EEEvRKNS_6PxVec3ES5_jPjPNS1_15CallbackRaycastEPS4_f($this,$rayOrigin,$rayDir,$maxResults,$resultsPtr,$callback,$fattenAABBs,$maxT) {
 $this = $this|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxResults = $maxResults|0;
 $resultsPtr = $resultsPtr|0;
 $callback = $callback|0;
 $fattenAABBs = $fattenAABBs|0;
 $maxT = Math_fround($maxT);
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i46 = Math_fround(0), $$$i52 = Math_fround(0), $$$i58 = Math_fround(0), $$$i64 = Math_fround(0), $$$i70 = Math_fround(0), $$$i76 = Math_fround(0), $$$i82 = Math_fround(0), $$$i88 = Math_fround(0), $$$i94 = Math_fround(0), $$0$ph799 = Math_fround(0), $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i47 = Math_fround(0), $$1$i53 = Math_fround(0), $$1$i59 = Math_fround(0), $$1$i65 = Math_fround(0), $$1$i71 = Math_fround(0), $$1$i77 = Math_fround(0);
 var $$1$i83 = Math_fround(0), $$1$i89 = Math_fround(0), $$1$i95 = Math_fround(0), $$sum = 0, $$sum1 = 0, $$sum10 = 0, $$sum11 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum772 = 0, $$sum773 = 0, $$sum774 = 0, $$sum775 = 0, $$sum776 = 0, $$sum777 = 0, $$sum778 = 0;
 var $$sum779 = 0, $$sum780 = 0, $$sum781 = 0, $$sum782 = 0, $$sum783 = 0, $$sum784 = 0, $$sum785 = 0, $$sum786 = 0, $$sum787 = 0, $$sum788 = 0, $$sum789 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0;
 var $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0;
 var $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0;
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0;
 var $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0;
 var $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0);
 var $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $exitcond = 0, $exitcond804 = 0, $j$0$us = 0, $j$0792 = 0, $j$0794$us = 0, $newMaxT = 0, $stack1 = 0, $stackPtr$0793 = 0, $stackPtr$0793$us = 0, $stackPtr$1$be = 0, $stackPtr$1$ph798 = 0, $stackPtr$1791 = 0, $top = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $stack1 = sp + 8|0;
 $top = sp;
 $newMaxT = sp + 4|0;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 92|0);
  $5 = HEAP32[$4>>2]|0;
  $87 = $5;
 } else {
  $87 = 0;
 }
 $6 = Math_fround(HEAPF32[$rayOrigin>>2]);
 $7 = (($rayOrigin) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($rayOrigin) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$rayDir>>2]);
 $12 = (($rayDir) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($rayDir) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (HEAPF32[tempDoublePtr>>2]=$11,HEAP32[tempDoublePtr>>2]|0);
 $17 = (HEAPF32[tempDoublePtr>>2]=$13,HEAP32[tempDoublePtr>>2]|0);
 $18 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
 $19 = $16 & -2147483648;
 $20 = $17 & -2147483648;
 $21 = $18 & -2147483648;
 $22 = Math_fround(-$11);
 $23 = Math_fround(-$13);
 $24 = Math_fround(-$15);
 $25 = $11 > $22;
 $$$i$i = $25 ? $11 : $22;
 $26 = $13 > $23;
 $27 = $26 ? $13 : $23;
 $28 = $15 > $24;
 $$1$i$i = $28 ? $15 : $24;
 $29 = $$$i$i > Math_fround(9.99999971718068536574E-10);
 $30 = $27 > Math_fround(9.99999971718068536574E-10);
 $31 = $$1$i$i > Math_fround(9.99999971718068536574E-10);
 $32 = (HEAPF32[tempDoublePtr>>2]=$$$i$i,HEAP32[tempDoublePtr>>2]|0);
 $33 = $29 ? $32 : 814313567;
 $34 = (HEAPF32[tempDoublePtr>>2]=$27,HEAP32[tempDoublePtr>>2]|0);
 $35 = $30 ? $34 : 814313567;
 $36 = (HEAPF32[tempDoublePtr>>2]=$$1$i$i,HEAP32[tempDoublePtr>>2]|0);
 $37 = $31 ? $36 : 814313567;
 $38 = $33 | $19;
 $39 = $35 | $20;
 $40 = $37 | $21;
 $41 = (HEAP32[tempDoublePtr>>2]=$38,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $42 = (HEAP32[tempDoublePtr>>2]=$39,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $43 = (HEAP32[tempDoublePtr>>2]=$40,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $44 = Math_fround(Math_fround(1.0) / $41);
 $45 = Math_fround(Math_fround(1.0) / $42);
 $46 = Math_fround(Math_fround(1.0) / $43);
 $47 = Math_fround($44 * $41);
 $48 = Math_fround($45 * $42);
 $49 = Math_fround($46 * $43);
 $50 = Math_fround(Math_fround(2.0) - $47);
 $51 = Math_fround(Math_fround(2.0) - $48);
 $52 = Math_fround(Math_fround(2.0) - $49);
 $53 = Math_fround($44 * $50);
 $54 = Math_fround($45 * $51);
 $55 = Math_fround($46 * $52);
 $56 = Math_fround($6 * $53);
 $57 = Math_fround($8 * $54);
 $58 = Math_fround($10 * $55);
 $59 = Math_fround(Math_fround(0.0) - $56);
 $60 = Math_fround(Math_fround(0.0) - $57);
 $61 = Math_fround(Math_fround(0.0) - $58);
 $62 = (($this) + 68|0);
 $63 = HEAP32[$62>>2]|0;
 $j$0792 = (($63) + -1)|0;
 $64 = ($j$0792|0)>(-1);
 if (!($64)) {
  STACKTOP = sp;return;
 }
 $65 = (($this) + 92|0);
 if ($3) {
  $j$0794$us = $j$0792;$stackPtr$0793$us = 0;
  while(1) {
   $66 = ($j$0794$us*112)|0;
   $67 = (($stackPtr$0793$us) + 1)|0;
   $68 = (($stack1) + ($67<<2)|0);
   HEAP32[$68>>2] = $66;
   $j$0$us = (($j$0794$us) + -1)|0;
   $exitcond804 = ($67|0)==($63|0);
   if ($exitcond804) {
    break;
   } else {
    $j$0794$us = $j$0$us;$stackPtr$0793$us = $67;
   }
  }
 } else {
  $stackPtr$0793 = 0;
  while(1) {
   $70 = HEAP32[$65>>2]|0;
   $71 = $70;
   $72 = (($stackPtr$0793) + 1)|0;
   $73 = (($stack1) + ($72<<2)|0);
   HEAP32[$73>>2] = $71;
   $exitcond = ($72|0)==($63|0);
   if ($exitcond) {
    break;
   } else {
    $stackPtr$0793 = $72;
   }
  }
 }
 $69 = ($63|0)==(0);
 if ($69) {
  STACKTOP = sp;return;
 }
 $$0$ph799 = $maxT;$stackPtr$1$ph798 = $63;
 L16: while(1) {
  $stackPtr$1791 = $stackPtr$1$ph798;
  while(1) {
   $74 = (($stackPtr$1791) + -1)|0;
   $75 = (($stack1) + ($stackPtr$1791<<2)|0);
   $76 = HEAP32[$75>>2]|0;
   HEAP32[$top>>2] = $76;
   $77 = $76 & 1;
   $78 = ($77|0)==(0);
   if ($78) {
    $86 = (($87) + ($76)|0);
    $88 = Math_fround(HEAPF32[$86>>2]);
    $$sum772 = (($76) + 4)|0;
    $89 = (($87) + ($$sum772)|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $$sum773 = (($76) + 8)|0;
    $91 = (($87) + ($$sum773)|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $$sum774 = (($76) + 12)|0;
    $93 = (($87) + ($$sum774)|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $$sum = (($76) + 16)|0;
    $95 = (($87) + ($$sum)|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $$sum775 = (($76) + 20)|0;
    $97 = (($87) + ($$sum775)|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $$sum776 = (($76) + 24)|0;
    $99 = (($87) + ($$sum776)|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $$sum777 = (($76) + 28)|0;
    $101 = (($87) + ($$sum777)|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $$sum1 = (($76) + 32)|0;
    $103 = (($87) + ($$sum1)|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $$sum778 = (($76) + 36)|0;
    $105 = (($87) + ($$sum778)|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $$sum779 = (($76) + 40)|0;
    $107 = (($87) + ($$sum779)|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $$sum780 = (($76) + 44)|0;
    $109 = (($87) + ($$sum780)|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $$sum2 = (($76) + 48)|0;
    $111 = (($87) + ($$sum2)|0);
    $112 = Math_fround(HEAPF32[$111>>2]);
    $$sum781 = (($76) + 52)|0;
    $113 = (($87) + ($$sum781)|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $$sum782 = (($76) + 56)|0;
    $115 = (($87) + ($$sum782)|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $$sum783 = (($76) + 60)|0;
    $117 = (($87) + ($$sum783)|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $$sum3 = (($76) + 64)|0;
    $119 = (($87) + ($$sum3)|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $$sum784 = (($76) + 68)|0;
    $121 = (($87) + ($$sum784)|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $$sum785 = (($76) + 72)|0;
    $123 = (($87) + ($$sum785)|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $$sum786 = (($76) + 76)|0;
    $125 = (($87) + ($$sum786)|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $$sum4 = (($76) + 80)|0;
    $127 = (($87) + ($$sum4)|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $$sum787 = (($76) + 84)|0;
    $129 = (($87) + ($$sum787)|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $$sum788 = (($76) + 88)|0;
    $131 = (($87) + ($$sum788)|0);
    $132 = Math_fround(HEAPF32[$131>>2]);
    $$sum789 = (($76) + 92)|0;
    $133 = (($87) + ($$sum789)|0);
    $134 = Math_fround(HEAPF32[$133>>2]);
    $135 = $88 > $112;
    $136 = $90 > $114;
    $137 = $92 > $116;
    $138 = $94 > $118;
    $139 = Math_fround($53 * $88);
    $140 = Math_fround($53 * $90);
    $141 = Math_fround($53 * $92);
    $142 = Math_fround($53 * $94);
    $143 = Math_fround($59 + $139);
    $144 = Math_fround($59 + $140);
    $145 = Math_fround($59 + $141);
    $146 = Math_fround($59 + $142);
    $147 = Math_fround($54 * $96);
    $148 = Math_fround($54 * $98);
    $149 = Math_fround($54 * $100);
    $150 = Math_fround($54 * $102);
    $151 = Math_fround($60 + $147);
    $152 = Math_fround($60 + $148);
    $153 = Math_fround($60 + $149);
    $154 = Math_fround($60 + $150);
    $155 = Math_fround($55 * $104);
    $156 = Math_fround($55 * $106);
    $157 = Math_fround($55 * $108);
    $158 = Math_fround($55 * $110);
    $159 = Math_fround($61 + $155);
    $160 = Math_fround($61 + $156);
    $161 = Math_fround($61 + $157);
    $162 = Math_fround($61 + $158);
    $163 = Math_fround($53 * $112);
    $164 = Math_fround($53 * $114);
    $165 = Math_fround($53 * $116);
    $166 = Math_fround($53 * $118);
    $167 = Math_fround($59 + $163);
    $168 = Math_fround($59 + $164);
    $169 = Math_fround($59 + $165);
    $170 = Math_fround($59 + $166);
    $171 = Math_fround($54 * $120);
    $172 = Math_fround($54 * $122);
    $173 = Math_fround($54 * $124);
    $174 = Math_fround($54 * $126);
    $175 = Math_fround($60 + $171);
    $176 = Math_fround($60 + $172);
    $177 = Math_fround($60 + $173);
    $178 = Math_fround($60 + $174);
    $179 = Math_fround($55 * $128);
    $180 = Math_fround($55 * $130);
    $181 = Math_fround($55 * $132);
    $182 = Math_fround($55 * $134);
    $183 = Math_fround($61 + $179);
    $184 = Math_fround($61 + $180);
    $185 = Math_fround($61 + $181);
    $186 = Math_fround($61 + $182);
    $187 = $143 < $167;
    $$$i94 = $187 ? $143 : $167;
    $188 = $144 < $168;
    $189 = $188 ? $144 : $168;
    $190 = $145 < $169;
    $$1$i95 = $190 ? $145 : $169;
    $191 = $146 < $170;
    $192 = $191 ? $146 : $170;
    $193 = $143 > $167;
    $$$i88 = $193 ? $143 : $167;
    $194 = $144 > $168;
    $195 = $194 ? $144 : $168;
    $196 = $145 > $169;
    $$1$i89 = $196 ? $145 : $169;
    $197 = $146 > $170;
    $198 = $197 ? $146 : $170;
    $199 = $151 < $175;
    $$$i82 = $199 ? $151 : $175;
    $200 = $152 < $176;
    $201 = $200 ? $152 : $176;
    $202 = $153 < $177;
    $$1$i83 = $202 ? $153 : $177;
    $203 = $154 < $178;
    $204 = $203 ? $154 : $178;
    $205 = $151 > $175;
    $$$i76 = $205 ? $151 : $175;
    $206 = $152 > $176;
    $207 = $206 ? $152 : $176;
    $208 = $153 > $177;
    $$1$i77 = $208 ? $153 : $177;
    $209 = $154 > $178;
    $210 = $209 ? $154 : $178;
    $211 = $159 < $183;
    $$$i70 = $211 ? $159 : $183;
    $212 = $160 < $184;
    $213 = $212 ? $160 : $184;
    $214 = $161 < $185;
    $$1$i71 = $214 ? $161 : $185;
    $215 = $162 < $186;
    $216 = $215 ? $162 : $186;
    $217 = $159 > $183;
    $$$i64 = $217 ? $159 : $183;
    $218 = $160 > $184;
    $219 = $218 ? $160 : $184;
    $220 = $161 > $185;
    $$1$i65 = $220 ? $161 : $185;
    $221 = $162 > $186;
    $222 = $221 ? $162 : $186;
    $223 = $$$i94 > $$$i82;
    $$$i58 = $223 ? $$$i94 : $$$i82;
    $224 = $189 > $201;
    $225 = $224 ? $189 : $201;
    $226 = $$1$i95 > $$1$i83;
    $$1$i59 = $226 ? $$1$i95 : $$1$i83;
    $227 = $192 > $204;
    $228 = $227 ? $192 : $204;
    $229 = $$$i58 > $$$i70;
    $$$i52 = $229 ? $$$i58 : $$$i70;
    $230 = $225 > $213;
    $231 = $230 ? $225 : $213;
    $232 = $$1$i59 > $$1$i71;
    $$1$i53 = $232 ? $$1$i59 : $$1$i71;
    $233 = $228 > $216;
    $234 = $233 ? $228 : $216;
    $235 = $$$i88 < $$$i76;
    $$$i46 = $235 ? $$$i88 : $$$i76;
    $236 = $195 < $207;
    $237 = $236 ? $195 : $207;
    $238 = $$1$i89 < $$1$i77;
    $$1$i47 = $238 ? $$1$i89 : $$1$i77;
    $239 = $198 < $210;
    $240 = $239 ? $198 : $210;
    $241 = $$$i46 < $$$i64;
    $$$i = $241 ? $$$i46 : $$$i64;
    $242 = $237 < $219;
    $243 = $242 ? $237 : $219;
    $244 = $$1$i47 < $$1$i65;
    $$1$i = $244 ? $$1$i47 : $$1$i65;
    $245 = $240 < $222;
    $246 = $245 ? $240 : $222;
    $247 = $$$i < Math_fround(9.99999971718068536574E-10);
    $248 = $243 < Math_fround(9.99999971718068536574E-10);
    $249 = $$1$i < Math_fround(9.99999971718068536574E-10);
    $250 = $246 < Math_fround(9.99999971718068536574E-10);
    $251 = $247 | $135;
    $252 = $248 | $136;
    $253 = $249 | $137;
    $254 = $250 | $138;
    $255 = $$$i52 > $$0$ph799;
    $256 = $231 > $$0$ph799;
    $257 = $$1$i53 > $$0$ph799;
    $258 = $234 > $$0$ph799;
    $259 = $255 | $251;
    $260 = $256 | $252;
    $261 = $257 | $253;
    $262 = $258 | $254;
    $263 = $$$i52 > $$$i;
    $264 = $231 > $243;
    $265 = $$1$i53 > $$1$i;
    $266 = $234 > $246;
    $267 = $259 | $263;
    $268 = $267 << 31 >> 31;
    $269 = $260 | $264;
    $270 = $269 << 31 >> 31;
    $271 = $261 | $265;
    $272 = $271 << 31 >> 31;
    $273 = $262 | $266;
    $274 = $273 << 31 >> 31;
    $$sum5 = (($76) + 96)|0;
    $275 = (($87) + ($$sum5)|0);
    $276 = HEAP32[$275>>2]|0;
    HEAP32[$75>>2] = $276;
    $277 = (($268) + ($stackPtr$1791))|0;
    $$sum6 = (($76) + 100)|0;
    $278 = (($87) + ($$sum6)|0);
    $279 = HEAP32[$278>>2]|0;
    $$sum7 = (($277) + 1)|0;
    $280 = (($stack1) + ($$sum7<<2)|0);
    HEAP32[$280>>2] = $279;
    $281 = (($270) + 1)|0;
    $282 = (($281) + ($277))|0;
    $$sum8 = (($76) + 104)|0;
    $283 = (($87) + ($$sum8)|0);
    $284 = HEAP32[$283>>2]|0;
    $$sum9 = (($282) + 1)|0;
    $285 = (($stack1) + ($$sum9<<2)|0);
    HEAP32[$285>>2] = $284;
    $286 = (($272) + 1)|0;
    $287 = (($286) + ($282))|0;
    $$sum10 = (($76) + 108)|0;
    $288 = (($87) + ($$sum10)|0);
    $289 = HEAP32[$288>>2]|0;
    $$sum11 = (($287) + 1)|0;
    $290 = (($stack1) + ($$sum11<<2)|0);
    HEAP32[$290>>2] = $289;
    $291 = (($274) + 1)|0;
    $292 = (($291) + ($287))|0;
    $stackPtr$1$be = $292;
   } else {
    $79 = (($76) + -1)|0;
    HEAP32[$top>>2] = $79;
    HEAPF32[$newMaxT>>2] = $$0$ph799;
    $80 = HEAP32[$callback>>2]|0;
    $81 = HEAP32[$80>>2]|0;
    $82 = (FUNCTION_TABLE_iiiii[$81 & 511]($callback,1,$top,$newMaxT)|0);
    if (!($82)) {
     label = 16;
     break L16;
    }
    $83 = Math_fround(HEAPF32[$newMaxT>>2]);
    $84 = $$0$ph799 != $83;
    if ($84) {
     break;
    } else {
     $stackPtr$1$be = $74;
    }
   }
   $293 = ($stackPtr$1$be|0)==(0);
   if ($293) {
    label = 16;
    break L16;
   } else {
    $stackPtr$1791 = $stackPtr$1$be;
   }
  }
  $85 = ($74|0)==(0);
  if ($85) {
   label = 16;
   break;
  } else {
   $$0$ph799 = $83;$stackPtr$1$ph798 = $74;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu5RTree11traverseRayILi1EEEvRKNS_6PxVec3ES5_jPjPNS1_15CallbackRaycastEPS4_f($this,$rayOrigin,$rayDir,$maxResults,$resultsPtr,$callback,$fattenAABBs,$maxT) {
 $this = $this|0;
 $rayOrigin = $rayOrigin|0;
 $rayDir = $rayDir|0;
 $maxResults = $maxResults|0;
 $resultsPtr = $resultsPtr|0;
 $callback = $callback|0;
 $fattenAABBs = $fattenAABBs|0;
 $maxT = Math_fround($maxT);
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i46 = Math_fround(0), $$$i52 = Math_fround(0), $$$i58 = Math_fround(0), $$$i64 = Math_fround(0), $$$i70 = Math_fround(0), $$$i76 = Math_fround(0), $$$i82 = Math_fround(0), $$$i88 = Math_fround(0), $$$i94 = Math_fround(0), $$0$ph1001 = Math_fround(0), $$1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i47 = Math_fround(0), $$1$i53 = Math_fround(0), $$1$i59 = Math_fround(0), $$1$i65 = Math_fround(0), $$1$i71 = Math_fround(0), $$1$i77 = Math_fround(0);
 var $$1$i83 = Math_fround(0), $$1$i89 = Math_fround(0), $$1$i95 = Math_fround(0), $$sum = 0, $$sum1 = 0, $$sum10 = 0, $$sum11 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $$sum974 = 0, $$sum975 = 0, $$sum976 = 0, $$sum977 = 0, $$sum978 = 0;
 var $$sum979 = 0, $$sum980 = 0, $$sum981 = 0, $$sum982 = 0, $$sum983 = 0, $$sum984 = 0, $$sum985 = 0, $$sum986 = 0, $$sum987 = 0, $$sum988 = 0, $$sum989 = 0, $$sum990 = 0, $$sum991 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0;
 var $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0;
 var $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = Math_fround(0);
 var $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = Math_fround(0);
 var $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = Math_fround(0);
 var $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0);
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $exitcond = 0;
 var $exitcond1006 = 0, $j$0$us = 0, $j$0994 = 0, $j$0996$us = 0, $newMaxT = 0, $stack1 = 0, $stackPtr$0995 = 0, $stackPtr$0995$us = 0, $stackPtr$1$be = 0, $stackPtr$1$ph1000 = 0, $stackPtr$1993 = 0, $top = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $stack1 = sp + 8|0;
 $top = sp;
 $newMaxT = sp + 4|0;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 92|0);
  $5 = HEAP32[$4>>2]|0;
  $95 = $5;
 } else {
  $95 = 0;
 }
 $6 = Math_fround(HEAPF32[$fattenAABBs>>2]);
 $7 = (($fattenAABBs) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($fattenAABBs) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($6 + Math_fround(1.00000001168609742308E-7));
 $12 = Math_fround($8 + Math_fround(1.00000001168609742308E-7));
 $13 = Math_fround($10 + Math_fround(1.00000001168609742308E-7));
 $14 = Math_fround(HEAPF32[$rayOrigin>>2]);
 $15 = (($rayOrigin) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($rayOrigin) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(HEAPF32[$rayDir>>2]);
 $20 = (($rayDir) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($rayDir) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (HEAPF32[tempDoublePtr>>2]=$19,HEAP32[tempDoublePtr>>2]|0);
 $25 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
 $26 = (HEAPF32[tempDoublePtr>>2]=$23,HEAP32[tempDoublePtr>>2]|0);
 $27 = $24 & -2147483648;
 $28 = $25 & -2147483648;
 $29 = $26 & -2147483648;
 $30 = Math_fround(-$19);
 $31 = Math_fround(-$21);
 $32 = Math_fround(-$23);
 $33 = $19 > $30;
 $$$i$i = $33 ? $19 : $30;
 $34 = $21 > $31;
 $35 = $34 ? $21 : $31;
 $36 = $23 > $32;
 $$1$i$i = $36 ? $23 : $32;
 $37 = $$$i$i > Math_fround(9.99999971718068536574E-10);
 $38 = $35 > Math_fround(9.99999971718068536574E-10);
 $39 = $$1$i$i > Math_fround(9.99999971718068536574E-10);
 $40 = (HEAPF32[tempDoublePtr>>2]=$$$i$i,HEAP32[tempDoublePtr>>2]|0);
 $41 = $37 ? $40 : 814313567;
 $42 = (HEAPF32[tempDoublePtr>>2]=$35,HEAP32[tempDoublePtr>>2]|0);
 $43 = $38 ? $42 : 814313567;
 $44 = (HEAPF32[tempDoublePtr>>2]=$$1$i$i,HEAP32[tempDoublePtr>>2]|0);
 $45 = $39 ? $44 : 814313567;
 $46 = $41 | $27;
 $47 = $43 | $28;
 $48 = $45 | $29;
 $49 = (HEAP32[tempDoublePtr>>2]=$46,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $50 = (HEAP32[tempDoublePtr>>2]=$47,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $51 = (HEAP32[tempDoublePtr>>2]=$48,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $52 = Math_fround(Math_fround(1.0) / $49);
 $53 = Math_fround(Math_fround(1.0) / $50);
 $54 = Math_fround(Math_fround(1.0) / $51);
 $55 = Math_fround($52 * $49);
 $56 = Math_fround($53 * $50);
 $57 = Math_fround($54 * $51);
 $58 = Math_fround(Math_fround(2.0) - $55);
 $59 = Math_fround(Math_fround(2.0) - $56);
 $60 = Math_fround(Math_fround(2.0) - $57);
 $61 = Math_fround($52 * $58);
 $62 = Math_fround($53 * $59);
 $63 = Math_fround($54 * $60);
 $64 = Math_fround($14 * $61);
 $65 = Math_fround($16 * $62);
 $66 = Math_fround($18 * $63);
 $67 = Math_fround(Math_fround(0.0) - $64);
 $68 = Math_fround(Math_fround(0.0) - $65);
 $69 = Math_fround(Math_fround(0.0) - $66);
 $70 = (($this) + 68|0);
 $71 = HEAP32[$70>>2]|0;
 $j$0994 = (($71) + -1)|0;
 $72 = ($j$0994|0)>(-1);
 if (!($72)) {
  STACKTOP = sp;return;
 }
 $73 = (($this) + 92|0);
 if ($3) {
  $j$0996$us = $j$0994;$stackPtr$0995$us = 0;
  while(1) {
   $74 = ($j$0996$us*112)|0;
   $75 = (($stackPtr$0995$us) + 1)|0;
   $76 = (($stack1) + ($75<<2)|0);
   HEAP32[$76>>2] = $74;
   $j$0$us = (($j$0996$us) + -1)|0;
   $exitcond1006 = ($75|0)==($71|0);
   if ($exitcond1006) {
    break;
   } else {
    $j$0996$us = $j$0$us;$stackPtr$0995$us = $75;
   }
  }
 } else {
  $stackPtr$0995 = 0;
  while(1) {
   $78 = HEAP32[$73>>2]|0;
   $79 = $78;
   $80 = (($stackPtr$0995) + 1)|0;
   $81 = (($stack1) + ($80<<2)|0);
   HEAP32[$81>>2] = $79;
   $exitcond = ($80|0)==($71|0);
   if ($exitcond) {
    break;
   } else {
    $stackPtr$0995 = $80;
   }
  }
 }
 $77 = ($71|0)==(0);
 if ($77) {
  STACKTOP = sp;return;
 }
 $$0$ph1001 = $maxT;$stackPtr$1$ph1000 = $71;
 L16: while(1) {
  $stackPtr$1993 = $stackPtr$1$ph1000;
  while(1) {
   $82 = (($stackPtr$1993) + -1)|0;
   $83 = (($stack1) + ($stackPtr$1993<<2)|0);
   $84 = HEAP32[$83>>2]|0;
   HEAP32[$top>>2] = $84;
   $85 = $84 & 1;
   $86 = ($85|0)==(0);
   if ($86) {
    $94 = (($95) + ($84)|0);
    $96 = Math_fround(HEAPF32[$94>>2]);
    $$sum974 = (($84) + 4)|0;
    $97 = (($95) + ($$sum974)|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $$sum975 = (($84) + 8)|0;
    $99 = (($95) + ($$sum975)|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $$sum976 = (($84) + 12)|0;
    $101 = (($95) + ($$sum976)|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $$sum = (($84) + 16)|0;
    $103 = (($95) + ($$sum)|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $$sum977 = (($84) + 20)|0;
    $105 = (($95) + ($$sum977)|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $$sum978 = (($84) + 24)|0;
    $107 = (($95) + ($$sum978)|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $$sum979 = (($84) + 28)|0;
    $109 = (($95) + ($$sum979)|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $$sum1 = (($84) + 32)|0;
    $111 = (($95) + ($$sum1)|0);
    $112 = Math_fround(HEAPF32[$111>>2]);
    $$sum980 = (($84) + 36)|0;
    $113 = (($95) + ($$sum980)|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $$sum981 = (($84) + 40)|0;
    $115 = (($95) + ($$sum981)|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $$sum982 = (($84) + 44)|0;
    $117 = (($95) + ($$sum982)|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $$sum2 = (($84) + 48)|0;
    $119 = (($95) + ($$sum2)|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $$sum983 = (($84) + 52)|0;
    $121 = (($95) + ($$sum983)|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $$sum984 = (($84) + 56)|0;
    $123 = (($95) + ($$sum984)|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $$sum985 = (($84) + 60)|0;
    $125 = (($95) + ($$sum985)|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $$sum3 = (($84) + 64)|0;
    $127 = (($95) + ($$sum3)|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $$sum986 = (($84) + 68)|0;
    $129 = (($95) + ($$sum986)|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $$sum987 = (($84) + 72)|0;
    $131 = (($95) + ($$sum987)|0);
    $132 = Math_fround(HEAPF32[$131>>2]);
    $$sum988 = (($84) + 76)|0;
    $133 = (($95) + ($$sum988)|0);
    $134 = Math_fround(HEAPF32[$133>>2]);
    $$sum4 = (($84) + 80)|0;
    $135 = (($95) + ($$sum4)|0);
    $136 = Math_fround(HEAPF32[$135>>2]);
    $$sum989 = (($84) + 84)|0;
    $137 = (($95) + ($$sum989)|0);
    $138 = Math_fround(HEAPF32[$137>>2]);
    $$sum990 = (($84) + 88)|0;
    $139 = (($95) + ($$sum990)|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $$sum991 = (($84) + 92)|0;
    $141 = (($95) + ($$sum991)|0);
    $142 = Math_fround(HEAPF32[$141>>2]);
    $143 = $96 > $120;
    $144 = $98 > $122;
    $145 = $100 > $124;
    $146 = $102 > $126;
    $147 = Math_fround($11 + $120);
    $148 = Math_fround($11 + $122);
    $149 = Math_fround($11 + $124);
    $150 = Math_fround($11 + $126);
    $151 = Math_fround($12 + $128);
    $152 = Math_fround($12 + $130);
    $153 = Math_fround($12 + $132);
    $154 = Math_fround($12 + $134);
    $155 = Math_fround($13 + $136);
    $156 = Math_fround($13 + $138);
    $157 = Math_fround($13 + $140);
    $158 = Math_fround($13 + $142);
    $159 = Math_fround($96 - $11);
    $160 = Math_fround($98 - $11);
    $161 = Math_fround($100 - $11);
    $162 = Math_fround($102 - $11);
    $163 = Math_fround($104 - $12);
    $164 = Math_fround($106 - $12);
    $165 = Math_fround($108 - $12);
    $166 = Math_fround($110 - $12);
    $167 = Math_fround($112 - $13);
    $168 = Math_fround($114 - $13);
    $169 = Math_fround($116 - $13);
    $170 = Math_fround($118 - $13);
    $171 = Math_fround($61 * $159);
    $172 = Math_fround($61 * $160);
    $173 = Math_fround($61 * $161);
    $174 = Math_fround($61 * $162);
    $175 = Math_fround($67 + $171);
    $176 = Math_fround($67 + $172);
    $177 = Math_fround($67 + $173);
    $178 = Math_fround($67 + $174);
    $179 = Math_fround($62 * $163);
    $180 = Math_fround($62 * $164);
    $181 = Math_fround($62 * $165);
    $182 = Math_fround($62 * $166);
    $183 = Math_fround($68 + $179);
    $184 = Math_fround($68 + $180);
    $185 = Math_fround($68 + $181);
    $186 = Math_fround($68 + $182);
    $187 = Math_fround($63 * $167);
    $188 = Math_fround($63 * $168);
    $189 = Math_fround($63 * $169);
    $190 = Math_fround($63 * $170);
    $191 = Math_fround($69 + $187);
    $192 = Math_fround($69 + $188);
    $193 = Math_fround($69 + $189);
    $194 = Math_fround($69 + $190);
    $195 = Math_fround($61 * $147);
    $196 = Math_fround($61 * $148);
    $197 = Math_fround($61 * $149);
    $198 = Math_fround($61 * $150);
    $199 = Math_fround($67 + $195);
    $200 = Math_fround($67 + $196);
    $201 = Math_fround($67 + $197);
    $202 = Math_fround($67 + $198);
    $203 = Math_fround($62 * $151);
    $204 = Math_fround($62 * $152);
    $205 = Math_fround($62 * $153);
    $206 = Math_fround($62 * $154);
    $207 = Math_fround($68 + $203);
    $208 = Math_fround($68 + $204);
    $209 = Math_fround($68 + $205);
    $210 = Math_fround($68 + $206);
    $211 = Math_fround($63 * $155);
    $212 = Math_fround($63 * $156);
    $213 = Math_fround($63 * $157);
    $214 = Math_fround($63 * $158);
    $215 = Math_fround($69 + $211);
    $216 = Math_fround($69 + $212);
    $217 = Math_fround($69 + $213);
    $218 = Math_fround($69 + $214);
    $219 = $175 < $199;
    $$$i94 = $219 ? $175 : $199;
    $220 = $176 < $200;
    $221 = $220 ? $176 : $200;
    $222 = $177 < $201;
    $$1$i95 = $222 ? $177 : $201;
    $223 = $178 < $202;
    $224 = $223 ? $178 : $202;
    $225 = $175 > $199;
    $$$i88 = $225 ? $175 : $199;
    $226 = $176 > $200;
    $227 = $226 ? $176 : $200;
    $228 = $177 > $201;
    $$1$i89 = $228 ? $177 : $201;
    $229 = $178 > $202;
    $230 = $229 ? $178 : $202;
    $231 = $183 < $207;
    $$$i82 = $231 ? $183 : $207;
    $232 = $184 < $208;
    $233 = $232 ? $184 : $208;
    $234 = $185 < $209;
    $$1$i83 = $234 ? $185 : $209;
    $235 = $186 < $210;
    $236 = $235 ? $186 : $210;
    $237 = $183 > $207;
    $$$i76 = $237 ? $183 : $207;
    $238 = $184 > $208;
    $239 = $238 ? $184 : $208;
    $240 = $185 > $209;
    $$1$i77 = $240 ? $185 : $209;
    $241 = $186 > $210;
    $242 = $241 ? $186 : $210;
    $243 = $191 < $215;
    $$$i70 = $243 ? $191 : $215;
    $244 = $192 < $216;
    $245 = $244 ? $192 : $216;
    $246 = $193 < $217;
    $$1$i71 = $246 ? $193 : $217;
    $247 = $194 < $218;
    $248 = $247 ? $194 : $218;
    $249 = $191 > $215;
    $$$i64 = $249 ? $191 : $215;
    $250 = $192 > $216;
    $251 = $250 ? $192 : $216;
    $252 = $193 > $217;
    $$1$i65 = $252 ? $193 : $217;
    $253 = $194 > $218;
    $254 = $253 ? $194 : $218;
    $255 = $$$i94 > $$$i82;
    $$$i58 = $255 ? $$$i94 : $$$i82;
    $256 = $221 > $233;
    $257 = $256 ? $221 : $233;
    $258 = $$1$i95 > $$1$i83;
    $$1$i59 = $258 ? $$1$i95 : $$1$i83;
    $259 = $224 > $236;
    $260 = $259 ? $224 : $236;
    $261 = $$$i58 > $$$i70;
    $$$i52 = $261 ? $$$i58 : $$$i70;
    $262 = $257 > $245;
    $263 = $262 ? $257 : $245;
    $264 = $$1$i59 > $$1$i71;
    $$1$i53 = $264 ? $$1$i59 : $$1$i71;
    $265 = $260 > $248;
    $266 = $265 ? $260 : $248;
    $267 = $$$i88 < $$$i76;
    $$$i46 = $267 ? $$$i88 : $$$i76;
    $268 = $227 < $239;
    $269 = $268 ? $227 : $239;
    $270 = $$1$i89 < $$1$i77;
    $$1$i47 = $270 ? $$1$i89 : $$1$i77;
    $271 = $230 < $242;
    $272 = $271 ? $230 : $242;
    $273 = $$$i46 < $$$i64;
    $$$i = $273 ? $$$i46 : $$$i64;
    $274 = $269 < $251;
    $275 = $274 ? $269 : $251;
    $276 = $$1$i47 < $$1$i65;
    $$1$i = $276 ? $$1$i47 : $$1$i65;
    $277 = $272 < $254;
    $278 = $277 ? $272 : $254;
    $279 = $$$i < Math_fround(9.99999971718068536574E-10);
    $280 = $275 < Math_fround(9.99999971718068536574E-10);
    $281 = $$1$i < Math_fround(9.99999971718068536574E-10);
    $282 = $278 < Math_fround(9.99999971718068536574E-10);
    $283 = $279 | $143;
    $284 = $280 | $144;
    $285 = $281 | $145;
    $286 = $282 | $146;
    $287 = $$$i52 > $$0$ph1001;
    $288 = $263 > $$0$ph1001;
    $289 = $$1$i53 > $$0$ph1001;
    $290 = $266 > $$0$ph1001;
    $291 = $287 | $283;
    $292 = $288 | $284;
    $293 = $289 | $285;
    $294 = $290 | $286;
    $295 = $$$i52 > $$$i;
    $296 = $263 > $275;
    $297 = $$1$i53 > $$1$i;
    $298 = $266 > $278;
    $299 = $291 | $295;
    $300 = $299 << 31 >> 31;
    $301 = $292 | $296;
    $302 = $301 << 31 >> 31;
    $303 = $293 | $297;
    $304 = $303 << 31 >> 31;
    $305 = $294 | $298;
    $306 = $305 << 31 >> 31;
    $$sum5 = (($84) + 96)|0;
    $307 = (($95) + ($$sum5)|0);
    $308 = HEAP32[$307>>2]|0;
    HEAP32[$83>>2] = $308;
    $309 = (($300) + ($stackPtr$1993))|0;
    $$sum6 = (($84) + 100)|0;
    $310 = (($95) + ($$sum6)|0);
    $311 = HEAP32[$310>>2]|0;
    $$sum7 = (($309) + 1)|0;
    $312 = (($stack1) + ($$sum7<<2)|0);
    HEAP32[$312>>2] = $311;
    $313 = (($302) + 1)|0;
    $314 = (($313) + ($309))|0;
    $$sum8 = (($84) + 104)|0;
    $315 = (($95) + ($$sum8)|0);
    $316 = HEAP32[$315>>2]|0;
    $$sum9 = (($314) + 1)|0;
    $317 = (($stack1) + ($$sum9<<2)|0);
    HEAP32[$317>>2] = $316;
    $318 = (($304) + 1)|0;
    $319 = (($318) + ($314))|0;
    $$sum10 = (($84) + 108)|0;
    $320 = (($95) + ($$sum10)|0);
    $321 = HEAP32[$320>>2]|0;
    $$sum11 = (($319) + 1)|0;
    $322 = (($stack1) + ($$sum11<<2)|0);
    HEAP32[$322>>2] = $321;
    $323 = (($306) + 1)|0;
    $324 = (($323) + ($319))|0;
    $stackPtr$1$be = $324;
   } else {
    $87 = (($84) + -1)|0;
    HEAP32[$top>>2] = $87;
    HEAPF32[$newMaxT>>2] = $$0$ph1001;
    $88 = HEAP32[$callback>>2]|0;
    $89 = HEAP32[$88>>2]|0;
    $90 = (FUNCTION_TABLE_iiiii[$89 & 511]($callback,1,$top,$newMaxT)|0);
    if (!($90)) {
     label = 16;
     break L16;
    }
    $91 = Math_fround(HEAPF32[$newMaxT>>2]);
    $92 = $$0$ph1001 != $91;
    if ($92) {
     break;
    } else {
     $stackPtr$1$be = $82;
    }
   }
   $325 = ($stackPtr$1$be|0)==(0);
   if ($325) {
    label = 16;
    break L16;
   } else {
    $stackPtr$1993 = $stackPtr$1$be;
   }
  }
  $93 = ($82|0)==(0);
  if ($93) {
   label = 16;
   break;
  } else {
   $$0$ph1001 = $91;$stackPtr$1$ph1000 = $82;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu5RTree12traverseAABBERKNS_6PxVec3ES4_jPjPNS1_8CallbackE($this,$boxMin,$boxMax,$maxResults,$resultsPtr,$callback) {
 $this = $this|0;
 $boxMin = $boxMin|0;
 $boxMax = $boxMax|0;
 $maxResults = $maxResults|0;
 $resultsPtr = $resultsPtr|0;
 $callback = $callback|0;
 var $$292 = 0, $$292$ = 0, $$293 = 0, $$293$ = 0, $$294 = 0, $$294$ = 0, $$295 = 0, $$295$ = 0, $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum296 = 0, $$sum297 = 0, $$sum298 = 0, $$sum299 = 0, $$sum3 = 0, $$sum300 = 0, $$sum301 = 0;
 var $$sum302 = 0, $$sum303 = 0, $$sum304 = 0, $$sum305 = 0, $$sum306 = 0, $$sum307 = 0, $$sum308 = 0, $$sum309 = 0, $$sum310 = 0, $$sum311 = 0, $$sum312 = 0, $$sum313 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $cacheTop$0 = 0, $cacheTop$0$ph = 0, $cacheTop$1344 = 0, $cacheTop$2 = 0, $cacheTopValid$0 = 0, $cacheTopValid$1343 = 0, $cacheTopValid$2 = 0, $i$0346 = 0, $j$0 = 0, $j$0348 = 0, $j$0350 = 0, $not$ = 0, $not$317 = 0, $not$318 = 0, $not$319 = 0, $not$320 = 0, $not$321 = 0;
 var $not$326 = 0, $not$329 = 0, $not$332 = 0, $not$333 = 0, $not$334 = 0, $not$335 = 0, $notlhs322 = 0, $notlhs324 = 0, $notlhs327 = 0, $notlhs330 = 0, $notrhs323 = 0, $notrhs325 = 0, $notrhs328 = 0, $notrhs331 = 0, $ptr = 0, $resa = 0, $scevgep = 0, $stack1 = 0, $stackPtr$0$lcssa355 = 0, $stackPtr$0$lcssa356 = 0;
 var $stackPtr$0349 = 0, $stackPtr$1 = 0, $stackPtr$2345 = 0, $stackPtr$3 = 0, $top$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $stack1 = sp + 24|0;
 $resa = sp;
 $ptr = sp + 16|0;
 $0 = (($stack1) + 4|0);
 $1 = Math_fround(HEAPF32[$boxMin>>2]);
 $2 = (($boxMin) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($boxMin) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$boxMax>>2]);
 $7 = (($boxMax) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($boxMax) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2;
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = (($this) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $42 = $16;
 } else {
  $42 = 0;
 }
 $17 = (($this) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $j$0348 = (($18) + -1)|0;
 $19 = ($j$0348|0)>(-1);
 if ($19) {
  $20 = (($this) + 92|0);
  $21 = (($18) + 1)|0;
  $128 = $14;$j$0350 = $j$0348;$stackPtr$0349 = $0;
  while(1) {
   if ($128) {
    $25 = ($j$0350*112)|0;
    $27 = $25;
   } else {
    $22 = HEAP32[$20>>2]|0;
    $23 = (($22) + (($j$0350*112)|0)|0);
    $24 = $23;
    $27 = $24;
   }
   $26 = (($stackPtr$0349) + 4|0);
   HEAP32[$stackPtr$0349>>2] = $27;
   $j$0 = (($j$0350) + -1)|0;
   $28 = ($j$0|0)>(-1);
   $29 = HEAP32[$11>>2]|0;
   $30 = $29 & 2;
   $31 = ($30|0)==(0);
   if ($28) {
    $128 = $31;$j$0350 = $j$0;$stackPtr$0349 = $26;
   } else {
    break;
   }
  }
  $scevgep = (($stack1) + ($21<<2)|0);
  if ($31) {
   $cacheTop$0$ph = 0;$stackPtr$0$lcssa356 = $scevgep;
  } else {
   $stackPtr$0$lcssa355 = $scevgep;
   label = 11;
  }
 } else {
  if ($14) {
   $cacheTop$0$ph = 0;$stackPtr$0$lcssa356 = $0;
  } else {
   $stackPtr$0$lcssa355 = $0;
   label = 11;
  }
 }
 if ((label|0) == 11) {
  $32 = (($this) + 92|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33;
  $cacheTop$0$ph = $34;$stackPtr$0$lcssa356 = $stackPtr$0$lcssa355;
 }
 $35 = (($resa) + 4|0);
 $36 = (($resa) + 8|0);
 $37 = (($resa) + 12|0);
 $cacheTop$0 = $cacheTop$0$ph;$cacheTopValid$0 = 1;$stackPtr$1 = $stackPtr$0$lcssa356;
 L17: while(1) {
  $38 = (($stackPtr$1) + -4|0);
  $39 = ($cacheTopValid$0|0)==(0);
  if ($39) {
   $40 = HEAP32[$38>>2]|0;
   $top$0 = $40;
  } else {
   $top$0 = $cacheTop$0;
  }
  $41 = (($42) + ($top$0)|0);
  $$sum = (($top$0) + 96)|0;
  $43 = (($42) + ($$sum)|0);
  $44 = Math_fround(HEAPF32[$41>>2]);
  $$sum296 = (($top$0) + 4)|0;
  $45 = (($42) + ($$sum296)|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $$sum297 = (($top$0) + 8)|0;
  $47 = (($42) + ($$sum297)|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $$sum298 = (($top$0) + 12)|0;
  $49 = (($42) + ($$sum298)|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $$sum1 = (($top$0) + 16)|0;
  $51 = (($42) + ($$sum1)|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $$sum299 = (($top$0) + 20)|0;
  $53 = (($42) + ($$sum299)|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $$sum300 = (($top$0) + 24)|0;
  $55 = (($42) + ($$sum300)|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $$sum301 = (($top$0) + 28)|0;
  $57 = (($42) + ($$sum301)|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $$sum2 = (($top$0) + 32)|0;
  $59 = (($42) + ($$sum2)|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $$sum302 = (($top$0) + 36)|0;
  $61 = (($42) + ($$sum302)|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $$sum303 = (($top$0) + 40)|0;
  $63 = (($42) + ($$sum303)|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $$sum304 = (($top$0) + 44)|0;
  $65 = (($42) + ($$sum304)|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $$sum3 = (($top$0) + 48)|0;
  $67 = (($42) + ($$sum3)|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $$sum305 = (($top$0) + 52)|0;
  $69 = (($42) + ($$sum305)|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $$sum306 = (($top$0) + 56)|0;
  $71 = (($42) + ($$sum306)|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $$sum307 = (($top$0) + 60)|0;
  $73 = (($42) + ($$sum307)|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $$sum4 = (($top$0) + 64)|0;
  $75 = (($42) + ($$sum4)|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $$sum308 = (($top$0) + 68)|0;
  $77 = (($42) + ($$sum308)|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $$sum309 = (($top$0) + 72)|0;
  $79 = (($42) + ($$sum309)|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $$sum310 = (($top$0) + 76)|0;
  $81 = (($42) + ($$sum310)|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $$sum5 = (($top$0) + 80)|0;
  $83 = (($42) + ($$sum5)|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $$sum311 = (($top$0) + 84)|0;
  $85 = (($42) + ($$sum311)|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $$sum312 = (($top$0) + 88)|0;
  $87 = (($42) + ($$sum312)|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $$sum313 = (($top$0) + 92)|0;
  $89 = (($42) + ($$sum313)|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = $44 > $6;
  $92 = $46 > $6;
  $93 = $48 > $6;
  $94 = $50 > $6;
  $95 = $60 > $10;
  $96 = $62 > $10;
  $97 = $64 > $10;
  $98 = $66 > $10;
  $not$317 = $5 > $84;
  $$292 = $91 | $not$317;
  $not$318 = $5 > $86;
  $99 = $92 | $not$318;
  $not$319 = $5 > $88;
  $$293 = $93 | $not$319;
  $not$320 = $5 > $90;
  $100 = $94 | $not$320;
  $notlhs322 = $1 > $68;
  $notrhs323 = $3 > $76;
  $not$321 = $notrhs323 | $notlhs322;
  $$292$ = $$292 | $not$321;
  $notlhs324 = $1 > $70;
  $notrhs325 = $3 > $78;
  $not$ = $notrhs325 | $notlhs324;
  $101 = $99 | $not$;
  $notlhs327 = $1 > $72;
  $notrhs328 = $3 > $80;
  $not$326 = $notrhs328 | $notlhs327;
  $$293$ = $$293 | $not$326;
  $notlhs330 = $1 > $74;
  $notrhs331 = $3 > $82;
  $not$329 = $notrhs331 | $notlhs330;
  $102 = $100 | $not$329;
  $not$332 = $52 > $8;
  $$294 = $95 | $not$332;
  $not$333 = $54 > $8;
  $103 = $96 | $not$333;
  $not$334 = $56 > $8;
  $$295 = $97 | $not$334;
  $not$335 = $58 > $8;
  $104 = $98 | $not$335;
  $$294$ = $$294 | $$292$;
  $105 = $$294$ << 31 >> 31;
  $106 = $103 | $101;
  $107 = $106 << 31 >> 31;
  $$295$ = $$295 | $$293$;
  $108 = $$295$ << 31 >> 31;
  $109 = $104 | $102;
  $110 = $109 << 31 >> 31;
  HEAP32[$resa>>2] = $105;
  HEAP32[$35>>2] = $107;
  HEAP32[$36>>2] = $108;
  HEAP32[$37>>2] = $110;
  $115 = $105;$cacheTop$1344 = $cacheTop$0;$cacheTopValid$1343 = 0;$i$0346 = 0;$stackPtr$2345 = $38;
  while(1) {
   $111 = (($43) + ($i$0346<<2)|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = $112 & -2;
   HEAP32[$ptr>>2] = $113;
   $114 = ($115|0)==(0);
   do {
    if ($114) {
     $116 = ((($41) + ($i$0346<<2)|0) + 96|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = $117 & 1;
     $119 = ($118|0)==(0);
     if ($119) {
      $123 = (($stackPtr$2345) + 4|0);
      HEAP32[$stackPtr$2345>>2] = $113;
      $124 = HEAP32[$ptr>>2]|0;
      $cacheTop$2 = $124;$cacheTopValid$2 = 1;$stackPtr$3 = $123;
      break;
     } else {
      $120 = HEAP32[$callback>>2]|0;
      $121 = HEAP32[$120>>2]|0;
      $122 = (FUNCTION_TABLE_iiii[$121 & 2047]($callback,1,$ptr)|0);
      if ($122) {
       $cacheTop$2 = $cacheTop$1344;$cacheTopValid$2 = $cacheTopValid$1343;$stackPtr$3 = $stackPtr$2345;
       break;
      } else {
       label = 23;
       break L17;
      }
     }
    } else {
     $cacheTop$2 = $cacheTop$1344;$cacheTopValid$2 = $cacheTopValid$1343;$stackPtr$3 = $stackPtr$2345;
    }
   } while(0);
   $125 = (($i$0346) + 1)|0;
   $126 = ($125>>>0)<(4);
   if (!($126)) {
    break;
   }
   $$phi$trans$insert = (($resa) + ($125<<2)|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $115 = $$pre;$cacheTop$1344 = $cacheTop$2;$cacheTopValid$1343 = $cacheTopValid$2;$i$0346 = $125;$stackPtr$2345 = $stackPtr$3;
  }
  $127 = ($stackPtr$3>>>0)>($0>>>0);
  if ($127) {
   $cacheTop$0 = $cacheTop$2;$cacheTopValid$0 = $cacheTopValid$2;$stackPtr$1 = $stackPtr$3;
  } else {
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu5RTree11traverseOBBERKNS0_3BoxEjPjPNS1_8CallbackE($this,$obb,$maxResults,$resultsPtr,$callback) {
 $this = $this|0;
 $obb = $obb|0;
 $maxResults = $maxResults|0;
 $resultsPtr = $resultsPtr|0;
 $callback = $callback|0;
 var $$$i = Math_fround(0), $$$i690 = Math_fround(0), $$$i696 = Math_fround(0), $$$i702 = Math_fround(0), $$$i708 = Math_fround(0), $$$i714 = Math_fround(0), $$$i798 = Math_fround(0), $$$i804 = Math_fround(0), $$$i819 = Math_fround(0), $$$i825 = Math_fround(0), $$$i840 = Math_fround(0), $$$i846 = Math_fround(0), $$$i954 = Math_fround(0), $$$i960 = Math_fround(0), $$$i968 = Math_fround(0), $$$i974 = Math_fround(0), $$$i982 = Math_fround(0), $$$i988 = Math_fround(0), $$1$i = Math_fround(0), $$1$i691 = Math_fround(0);
 var $$1$i697 = Math_fround(0), $$1$i703 = Math_fround(0), $$1$i709 = Math_fround(0), $$1$i715 = Math_fround(0), $$1$i799 = Math_fround(0), $$1$i805 = Math_fround(0), $$1$i820 = Math_fround(0), $$1$i826 = Math_fround(0), $$1$i841 = Math_fround(0), $$1$i847 = Math_fround(0), $$1$i955 = Math_fround(0), $$1$i961 = Math_fround(0), $$1$i969 = Math_fround(0), $$1$i975 = Math_fround(0), $$1$i983 = Math_fround(0), $$1$i989 = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1 = 0;
 var $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum4123 = 0, $$sum4124 = 0, $$sum4125 = 0, $$sum4126 = 0, $$sum4127 = 0, $$sum4128 = 0, $$sum4129 = 0, $$sum4130 = 0, $$sum4131 = 0, $$sum4132 = 0, $$sum4133 = 0, $$sum4134 = 0, $$sum4135 = 0, $$sum4136 = 0, $$sum4137 = 0, $$sum4138 = 0, $$sum4139 = 0;
 var $$sum4140 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = Math_fround(0), $1010 = 0, $1011 = 0, $1012 = 0;
 var $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = Math_fround(0), $1030 = 0;
 var $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = Math_fround(0), $278 = 0;
 var $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0;
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = 0;
 var $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = 0, $385 = Math_fround(0), $386 = 0;
 var $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0;
 var $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0);
 var $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0);
 var $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0);
 var $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0);
 var $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0);
 var $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0);
 var $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0);
 var $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = Math_fround(0);
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0);
 var $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0);
 var $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = 0, $709 = 0, $71 = Math_fround(0);
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0);
 var $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0);
 var $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0);
 var $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0);
 var $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0;
 var $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0);
 var $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0);
 var $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0);
 var $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0);
 var $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = Math_fround(0), $890 = 0;
 var $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = Math_fround(0), $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0);
 var $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0);
 var $927 = Math_fround(0), $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = Math_fround(0);
 var $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = Math_fround(0), $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0;
 var $963 = 0, $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0);
 var $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = Math_fround(0), $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0;
 var $cacheTop$0 = 0, $cacheTop$0$ph = 0, $cacheTop$14144 = 0, $cacheTop$2 = 0, $cacheTopValid$0 = 0, $cacheTopValid$14145 = 0, $cacheTopValid$2 = 0, $i$04147 = 0, $j$0 = 0, $j$04149 = 0, $j$04151 = 0, $ptr = 0, $resa_ = 0, $scevgep = 0, $stack = 0, $stackPtr$0$lcssa4156 = 0, $stackPtr$0$lcssa4157 = 0, $stackPtr$04150 = 0, $stackPtr$1 = 0, $stackPtr$24146 = 0;
 var $stackPtr$3 = 0, $top$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $stack = sp + 24|0;
 $resa_ = sp;
 $ptr = sp + 16|0;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 92|0);
  $5 = HEAP32[$4>>2]|0;
  $79 = $5;
 } else {
  $79 = 0;
 }
 $6 = (($obb) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($6) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($6) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($obb) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($12) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$obb>>2]);
 $19 = (($obb) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($obb) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($obb) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($23) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($23) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($obb) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($29) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($29) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($this) + 68|0);
 $36 = HEAP32[$35>>2]|0;
 $j$04149 = (($36) + -1)|0;
 $37 = ($j$04149|0)>(-1);
 if ($37) {
  $38 = (($this) + 92|0);
  $1037 = $3;$j$04151 = $j$04149;$stackPtr$04150 = $stack;
  while(1) {
   if ($1037) {
    $41 = ($j$04151*112)|0;
    $43 = $41;
   } else {
    $39 = HEAP32[$38>>2]|0;
    $40 = $39;
    $43 = $40;
   }
   $42 = (($stackPtr$04150) + 4|0);
   HEAP32[$stackPtr$04150>>2] = $43;
   $j$0 = (($j$04151) + -1)|0;
   $44 = ($j$0|0)>(-1);
   $45 = HEAP32[$0>>2]|0;
   $46 = $45 & 2;
   $47 = ($46|0)==(0);
   if ($44) {
    $1037 = $47;$j$04151 = $j$0;$stackPtr$04150 = $42;
   } else {
    break;
   }
  }
  $scevgep = (($stack) + ($36<<2)|0);
  if ($47) {
   $cacheTop$0$ph = 0;$stackPtr$0$lcssa4157 = $scevgep;
  } else {
   $stackPtr$0$lcssa4156 = $scevgep;
   label = 11;
  }
 } else {
  if ($3) {
   $cacheTop$0$ph = 0;$stackPtr$0$lcssa4157 = $stack;
  } else {
   $stackPtr$0$lcssa4156 = $stack;
   label = 11;
  }
 }
 if ((label|0) == 11) {
  $48 = (($this) + 92|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = $49;
  $cacheTop$0$ph = $50;$stackPtr$0$lcssa4157 = $stackPtr$0$lcssa4156;
 }
 $51 = Math_fround(Math_fround(0.0) - $13);
 $52 = Math_fround(Math_fround(0.0) - $15);
 $53 = Math_fround(Math_fround(0.0) - $17);
 $54 = Math_fround($13 * $18);
 $55 = Math_fround($13 * $20);
 $56 = Math_fround($13 * $22);
 $57 = Math_fround($54 + Math_fround(0.0));
 $58 = Math_fround($55 + Math_fround(0.0));
 $59 = Math_fround($56 + Math_fround(0.0));
 $60 = Math_fround($15 * $24);
 $61 = Math_fround($15 * $26);
 $62 = Math_fround($15 * $28);
 $63 = Math_fround($60 + Math_fround(0.0));
 $64 = Math_fround($61 + Math_fround(0.0));
 $65 = Math_fround($62 + Math_fround(0.0));
 $66 = Math_fround($17 * $30);
 $67 = Math_fround($17 * $32);
 $68 = Math_fround($17 * $34);
 $69 = Math_fround($66 + Math_fround(0.0));
 $70 = Math_fround($67 + Math_fround(0.0));
 $71 = Math_fround($68 + Math_fround(0.0));
 $72 = (($resa_) + 4|0);
 $73 = (($resa_) + 8|0);
 $74 = (($resa_) + 12|0);
 $cacheTop$0 = $cacheTop$0$ph;$cacheTopValid$0 = 1;$stackPtr$1 = $stackPtr$0$lcssa4157;
 L17: while(1) {
  $75 = (($stackPtr$1) + -4|0);
  $76 = ($cacheTopValid$0|0)==(0);
  if ($76) {
   $77 = HEAP32[$75>>2]|0;
   $top$0 = $77;
  } else {
   $top$0 = $cacheTop$0;
  }
  $78 = (($79) + ($top$0)|0);
  $$sum = (($top$0) + 96)|0;
  $80 = (($79) + ($$sum)|0);
  $81 = Math_fround(HEAPF32[$78>>2]);
  $$sum4123 = (($top$0) + 4)|0;
  $82 = (($79) + ($$sum4123)|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $$sum4124 = (($top$0) + 8)|0;
  $84 = (($79) + ($$sum4124)|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $$sum4125 = (($top$0) + 12)|0;
  $86 = (($79) + ($$sum4125)|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $$sum1 = (($top$0) + 16)|0;
  $88 = (($79) + ($$sum1)|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $$sum4126 = (($top$0) + 20)|0;
  $90 = (($79) + ($$sum4126)|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $$sum4127 = (($top$0) + 24)|0;
  $92 = (($79) + ($$sum4127)|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $$sum4128 = (($top$0) + 28)|0;
  $94 = (($79) + ($$sum4128)|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $$sum2 = (($top$0) + 32)|0;
  $96 = (($79) + ($$sum2)|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $$sum4129 = (($top$0) + 36)|0;
  $98 = (($79) + ($$sum4129)|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $$sum4130 = (($top$0) + 40)|0;
  $100 = (($79) + ($$sum4130)|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $$sum4131 = (($top$0) + 44)|0;
  $102 = (($79) + ($$sum4131)|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $$sum3 = (($top$0) + 48)|0;
  $104 = (($79) + ($$sum3)|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $$sum4132 = (($top$0) + 52)|0;
  $106 = (($79) + ($$sum4132)|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $$sum4133 = (($top$0) + 56)|0;
  $108 = (($79) + ($$sum4133)|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $$sum4134 = (($top$0) + 60)|0;
  $110 = (($79) + ($$sum4134)|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $$sum4 = (($top$0) + 64)|0;
  $112 = (($79) + ($$sum4)|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $$sum4135 = (($top$0) + 68)|0;
  $114 = (($79) + ($$sum4135)|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $$sum4136 = (($top$0) + 72)|0;
  $116 = (($79) + ($$sum4136)|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $$sum4137 = (($top$0) + 76)|0;
  $118 = (($79) + ($$sum4137)|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $$sum5 = (($top$0) + 80)|0;
  $120 = (($79) + ($$sum5)|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $$sum4138 = (($top$0) + 84)|0;
  $122 = (($79) + ($$sum4138)|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $$sum4139 = (($top$0) + 88)|0;
  $124 = (($79) + ($$sum4139)|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $$sum4140 = (($top$0) + 92)|0;
  $126 = (($79) + ($$sum4140)|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = $105 < $7;
  $$$i988 = $128 ? $105 : $7;
  $129 = $107 < $7;
  $130 = $129 ? $107 : $7;
  $131 = $109 < $7;
  $$1$i989 = $131 ? $109 : $7;
  $132 = $111 < $7;
  $133 = $132 ? $111 : $7;
  $134 = $81 > $$$i988;
  $$$i982 = $134 ? $81 : $$$i988;
  $135 = $83 > $130;
  $136 = $135 ? $83 : $130;
  $137 = $85 > $$1$i989;
  $$1$i983 = $137 ? $85 : $$1$i989;
  $138 = $87 > $133;
  $139 = $138 ? $87 : $133;
  $140 = $113 < $9;
  $$$i974 = $140 ? $113 : $9;
  $141 = $115 < $9;
  $142 = $141 ? $115 : $9;
  $143 = $117 < $9;
  $$1$i975 = $143 ? $117 : $9;
  $144 = $119 < $9;
  $145 = $144 ? $119 : $9;
  $146 = $89 > $$$i974;
  $$$i968 = $146 ? $89 : $$$i974;
  $147 = $91 > $142;
  $148 = $147 ? $91 : $142;
  $149 = $93 > $$1$i975;
  $$1$i969 = $149 ? $93 : $$1$i975;
  $150 = $95 > $145;
  $151 = $150 ? $95 : $145;
  $152 = $121 < $11;
  $$$i960 = $152 ? $121 : $11;
  $153 = $123 < $11;
  $154 = $153 ? $123 : $11;
  $155 = $125 < $11;
  $$1$i961 = $155 ? $125 : $11;
  $156 = $127 < $11;
  $157 = $156 ? $127 : $11;
  $158 = $97 > $$$i960;
  $$$i954 = $158 ? $97 : $$$i960;
  $159 = $99 > $154;
  $160 = $159 ? $99 : $154;
  $161 = $101 > $$1$i961;
  $$1$i955 = $161 ? $101 : $$1$i961;
  $162 = $103 > $157;
  $163 = $162 ? $103 : $157;
  $164 = Math_fround($$$i982 - $7);
  $165 = Math_fround($136 - $7);
  $166 = Math_fround($$1$i983 - $7);
  $167 = Math_fround($139 - $7);
  $168 = Math_fround($$$i968 - $9);
  $169 = Math_fround($148 - $9);
  $170 = Math_fround($$1$i969 - $9);
  $171 = Math_fround($151 - $9);
  $172 = Math_fround($$$i954 - $11);
  $173 = Math_fround($160 - $11);
  $174 = Math_fround($$1$i955 - $11);
  $175 = Math_fround($163 - $11);
  $176 = Math_fround($22 * $172);
  $177 = Math_fround($22 * $173);
  $178 = Math_fround($22 * $174);
  $179 = Math_fround($22 * $175);
  $180 = Math_fround($176 + Math_fround(0.0));
  $181 = Math_fround($177 + Math_fround(0.0));
  $182 = Math_fround($178 + Math_fround(0.0));
  $183 = Math_fround($179 + Math_fround(0.0));
  $184 = Math_fround($20 * $168);
  $185 = Math_fround($20 * $169);
  $186 = Math_fround($20 * $170);
  $187 = Math_fround($20 * $171);
  $188 = Math_fround($184 + $180);
  $189 = Math_fround($185 + $181);
  $190 = Math_fround($186 + $182);
  $191 = Math_fround($187 + $183);
  $192 = Math_fround($18 * $164);
  $193 = Math_fround($18 * $165);
  $194 = Math_fround($18 * $166);
  $195 = Math_fround($18 * $167);
  $196 = Math_fround($192 + $188);
  $197 = Math_fround($193 + $189);
  $198 = Math_fround($194 + $190);
  $199 = Math_fround($195 + $191);
  $200 = Math_fround($28 * $172);
  $201 = Math_fround($28 * $173);
  $202 = Math_fround($28 * $174);
  $203 = Math_fround($28 * $175);
  $204 = Math_fround($200 + Math_fround(0.0));
  $205 = Math_fround($201 + Math_fround(0.0));
  $206 = Math_fround($202 + Math_fround(0.0));
  $207 = Math_fround($203 + Math_fround(0.0));
  $208 = Math_fround($26 * $168);
  $209 = Math_fround($26 * $169);
  $210 = Math_fround($26 * $170);
  $211 = Math_fround($26 * $171);
  $212 = Math_fround($208 + $204);
  $213 = Math_fround($209 + $205);
  $214 = Math_fround($210 + $206);
  $215 = Math_fround($211 + $207);
  $216 = Math_fround($24 * $164);
  $217 = Math_fround($24 * $165);
  $218 = Math_fround($24 * $166);
  $219 = Math_fround($24 * $167);
  $220 = Math_fround($216 + $212);
  $221 = Math_fround($217 + $213);
  $222 = Math_fround($218 + $214);
  $223 = Math_fround($219 + $215);
  $224 = Math_fround($34 * $172);
  $225 = Math_fround($34 * $173);
  $226 = Math_fround($34 * $174);
  $227 = Math_fround($34 * $175);
  $228 = Math_fround($224 + Math_fround(0.0));
  $229 = Math_fround($225 + Math_fround(0.0));
  $230 = Math_fround($226 + Math_fround(0.0));
  $231 = Math_fround($227 + Math_fround(0.0));
  $232 = Math_fround($32 * $168);
  $233 = Math_fround($32 * $169);
  $234 = Math_fround($32 * $170);
  $235 = Math_fround($32 * $171);
  $236 = Math_fround($232 + $228);
  $237 = Math_fround($233 + $229);
  $238 = Math_fround($234 + $230);
  $239 = Math_fround($235 + $231);
  $240 = Math_fround($30 * $164);
  $241 = Math_fround($30 * $165);
  $242 = Math_fround($30 * $166);
  $243 = Math_fround($30 * $167);
  $244 = Math_fround($240 + $236);
  $245 = Math_fround($241 + $237);
  $246 = Math_fround($242 + $238);
  $247 = Math_fround($243 + $239);
  $248 = $196 < $13;
  $$$i846 = $248 ? $196 : $13;
  $249 = $197 < $13;
  $250 = $249 ? $197 : $13;
  $251 = $198 < $13;
  $$1$i847 = $251 ? $198 : $13;
  $252 = $199 < $13;
  $253 = $252 ? $199 : $13;
  $254 = $51 > $$$i846;
  $$$i840 = $254 ? $51 : $$$i846;
  $255 = $51 > $250;
  $256 = $255 ? $51 : $250;
  $257 = $51 > $$1$i847;
  $$1$i841 = $257 ? $51 : $$1$i847;
  $258 = $51 > $253;
  $259 = $258 ? $51 : $253;
  $260 = $220 < $15;
  $$$i825 = $260 ? $220 : $15;
  $261 = $221 < $15;
  $262 = $261 ? $221 : $15;
  $263 = $222 < $15;
  $$1$i826 = $263 ? $222 : $15;
  $264 = $223 < $15;
  $265 = $264 ? $223 : $15;
  $266 = $52 > $$$i825;
  $$$i819 = $266 ? $52 : $$$i825;
  $267 = $52 > $262;
  $268 = $267 ? $52 : $262;
  $269 = $52 > $$1$i826;
  $$1$i820 = $269 ? $52 : $$1$i826;
  $270 = $52 > $265;
  $271 = $270 ? $52 : $265;
  $272 = $244 < $17;
  $$$i804 = $272 ? $244 : $17;
  $273 = $245 < $17;
  $274 = $273 ? $245 : $17;
  $275 = $246 < $17;
  $$1$i805 = $275 ? $246 : $17;
  $276 = $247 < $17;
  $277 = $276 ? $247 : $17;
  $278 = $53 > $$$i804;
  $$$i798 = $278 ? $53 : $$$i804;
  $279 = $53 > $274;
  $280 = $279 ? $53 : $274;
  $281 = $53 > $$1$i805;
  $$1$i799 = $281 ? $53 : $$1$i805;
  $282 = $53 > $277;
  $283 = $282 ? $53 : $277;
  $284 = Math_fround($30 * $$$i798);
  $285 = Math_fround($30 * $280);
  $286 = Math_fround($30 * $$1$i799);
  $287 = Math_fround($30 * $283);
  $288 = Math_fround($7 + $284);
  $289 = Math_fround($7 + $285);
  $290 = Math_fround($7 + $286);
  $291 = Math_fround($7 + $287);
  $292 = Math_fround($24 * $$$i819);
  $293 = Math_fround($24 * $268);
  $294 = Math_fround($24 * $$1$i820);
  $295 = Math_fround($24 * $271);
  $296 = Math_fround($292 + $288);
  $297 = Math_fround($293 + $289);
  $298 = Math_fround($294 + $290);
  $299 = Math_fround($295 + $291);
  $300 = Math_fround($18 * $$$i840);
  $301 = Math_fround($18 * $256);
  $302 = Math_fround($18 * $$1$i841);
  $303 = Math_fround($18 * $259);
  $304 = Math_fround($300 + $296);
  $305 = Math_fround($301 + $297);
  $306 = Math_fround($302 + $298);
  $307 = Math_fround($303 + $299);
  $308 = Math_fround($32 * $$$i798);
  $309 = Math_fround($32 * $280);
  $310 = Math_fround($32 * $$1$i799);
  $311 = Math_fround($32 * $283);
  $312 = Math_fround($9 + $308);
  $313 = Math_fround($9 + $309);
  $314 = Math_fround($9 + $310);
  $315 = Math_fround($9 + $311);
  $316 = Math_fround($26 * $$$i819);
  $317 = Math_fround($26 * $268);
  $318 = Math_fround($26 * $$1$i820);
  $319 = Math_fround($26 * $271);
  $320 = Math_fround($316 + $312);
  $321 = Math_fround($317 + $313);
  $322 = Math_fround($318 + $314);
  $323 = Math_fround($319 + $315);
  $324 = Math_fround($20 * $$$i840);
  $325 = Math_fround($20 * $256);
  $326 = Math_fround($20 * $$1$i841);
  $327 = Math_fround($20 * $259);
  $328 = Math_fround($324 + $320);
  $329 = Math_fround($325 + $321);
  $330 = Math_fround($326 + $322);
  $331 = Math_fround($327 + $323);
  $332 = Math_fround($34 * $$$i798);
  $333 = Math_fround($34 * $280);
  $334 = Math_fround($34 * $$1$i799);
  $335 = Math_fround($34 * $283);
  $336 = Math_fround($11 + $332);
  $337 = Math_fround($11 + $333);
  $338 = Math_fround($11 + $334);
  $339 = Math_fround($11 + $335);
  $340 = Math_fround($28 * $$$i819);
  $341 = Math_fround($28 * $268);
  $342 = Math_fround($28 * $$1$i820);
  $343 = Math_fround($28 * $271);
  $344 = Math_fround($340 + $336);
  $345 = Math_fround($341 + $337);
  $346 = Math_fround($342 + $338);
  $347 = Math_fround($343 + $339);
  $348 = Math_fround($22 * $$$i840);
  $349 = Math_fround($22 * $256);
  $350 = Math_fround($22 * $$1$i841);
  $351 = Math_fround($22 * $259);
  $352 = Math_fround($348 + $344);
  $353 = Math_fround($349 + $345);
  $354 = Math_fround($350 + $346);
  $355 = Math_fround($351 + $347);
  $356 = $105 < $304;
  $$$i714 = $356 ? $105 : $304;
  $357 = $107 < $305;
  $358 = $357 ? $107 : $305;
  $359 = $109 < $306;
  $$1$i715 = $359 ? $109 : $306;
  $360 = $111 < $307;
  $361 = $360 ? $111 : $307;
  $362 = $81 > $$$i714;
  $$$i708 = $362 ? $81 : $$$i714;
  $363 = $83 > $358;
  $364 = $363 ? $83 : $358;
  $365 = $85 > $$1$i715;
  $$1$i709 = $365 ? $85 : $$1$i715;
  $366 = $87 > $361;
  $367 = $366 ? $87 : $361;
  $368 = $113 < $328;
  $$$i702 = $368 ? $113 : $328;
  $369 = $115 < $329;
  $370 = $369 ? $115 : $329;
  $371 = $117 < $330;
  $$1$i703 = $371 ? $117 : $330;
  $372 = $119 < $331;
  $373 = $372 ? $119 : $331;
  $374 = $89 > $$$i702;
  $$$i696 = $374 ? $89 : $$$i702;
  $375 = $91 > $370;
  $376 = $375 ? $91 : $370;
  $377 = $93 > $$1$i703;
  $$1$i697 = $377 ? $93 : $$1$i703;
  $378 = $95 > $373;
  $379 = $378 ? $95 : $373;
  $380 = $121 < $352;
  $$$i690 = $380 ? $121 : $352;
  $381 = $123 < $353;
  $382 = $381 ? $123 : $353;
  $383 = $125 < $354;
  $$1$i691 = $383 ? $125 : $354;
  $384 = $127 < $355;
  $385 = $384 ? $127 : $355;
  $386 = $97 > $$$i690;
  $$$i = $386 ? $97 : $$$i690;
  $387 = $99 > $382;
  $388 = $387 ? $99 : $382;
  $389 = $101 > $$1$i691;
  $$1$i = $389 ? $101 : $$1$i691;
  $390 = $103 > $385;
  $391 = $390 ? $103 : $385;
  $392 = Math_fround($81 + $105);
  $393 = Math_fround($83 + $107);
  $394 = Math_fround($85 + $109);
  $395 = Math_fround($87 + $111);
  $396 = Math_fround($392 * Math_fround(0.5));
  $397 = Math_fround($393 * Math_fround(0.5));
  $398 = Math_fround($394 * Math_fround(0.5));
  $399 = Math_fround($395 * Math_fround(0.5));
  $400 = Math_fround($396 + Math_fround(0.0));
  $401 = Math_fround($397 + Math_fround(0.0));
  $402 = Math_fround($398 + Math_fround(0.0));
  $403 = Math_fround($399 + Math_fround(0.0));
  $404 = Math_fround($89 + $113);
  $405 = Math_fround($91 + $115);
  $406 = Math_fround($93 + $117);
  $407 = Math_fround($95 + $119);
  $408 = Math_fround($404 * Math_fround(0.5));
  $409 = Math_fround($405 * Math_fround(0.5));
  $410 = Math_fround($406 * Math_fround(0.5));
  $411 = Math_fround($407 * Math_fround(0.5));
  $412 = Math_fround($408 + Math_fround(0.0));
  $413 = Math_fround($409 + Math_fround(0.0));
  $414 = Math_fround($410 + Math_fround(0.0));
  $415 = Math_fround($411 + Math_fround(0.0));
  $416 = Math_fround($97 + $121);
  $417 = Math_fround($99 + $123);
  $418 = Math_fround($101 + $125);
  $419 = Math_fround($103 + $127);
  $420 = Math_fround($416 * Math_fround(0.5));
  $421 = Math_fround($417 * Math_fround(0.5));
  $422 = Math_fround($418 * Math_fround(0.5));
  $423 = Math_fround($419 * Math_fround(0.5));
  $424 = Math_fround($420 + Math_fround(0.0));
  $425 = Math_fround($421 + Math_fround(0.0));
  $426 = Math_fround($422 + Math_fround(0.0));
  $427 = Math_fround($423 + Math_fround(0.0));
  $428 = Math_fround($105 - $400);
  $429 = Math_fround($107 - $401);
  $430 = Math_fround($109 - $402);
  $431 = Math_fround($111 - $403);
  $432 = Math_fround($113 - $412);
  $433 = Math_fround($115 - $413);
  $434 = Math_fround($117 - $414);
  $435 = Math_fround($119 - $415);
  $436 = Math_fround($121 - $424);
  $437 = Math_fround($123 - $425);
  $438 = Math_fround($125 - $426);
  $439 = Math_fround($127 - $427);
  $440 = Math_fround($304 - $$$i982);
  $441 = Math_fround($305 - $136);
  $442 = Math_fround($306 - $$1$i983);
  $443 = Math_fround($307 - $139);
  $444 = Math_fround($328 - $$$i968);
  $445 = Math_fround($329 - $148);
  $446 = Math_fround($330 - $$1$i969);
  $447 = Math_fround($331 - $151);
  $448 = Math_fround($352 - $$$i954);
  $449 = Math_fround($353 - $160);
  $450 = Math_fround($354 - $$1$i955);
  $451 = Math_fround($355 - $163);
  $452 = Math_fround($428 * $440);
  $453 = Math_fround($429 * $441);
  $454 = Math_fround($430 * $442);
  $455 = Math_fround($431 * $443);
  $456 = Math_fround($452 + Math_fround(0.0));
  $457 = Math_fround($453 + Math_fround(0.0));
  $458 = Math_fround($454 + Math_fround(0.0));
  $459 = Math_fround($455 + Math_fround(0.0));
  $460 = Math_fround($432 * $444);
  $461 = Math_fround($433 * $445);
  $462 = Math_fround($434 * $446);
  $463 = Math_fround($435 * $447);
  $464 = Math_fround($460 + Math_fround(0.0));
  $465 = Math_fround($461 + Math_fround(0.0));
  $466 = Math_fround($462 + Math_fround(0.0));
  $467 = Math_fround($463 + Math_fround(0.0));
  $468 = Math_fround($436 * $448);
  $469 = Math_fround($437 * $449);
  $470 = Math_fround($438 * $450);
  $471 = Math_fround($439 * $451);
  $472 = Math_fround($468 + Math_fround(0.0));
  $473 = Math_fround($469 + Math_fround(0.0));
  $474 = Math_fround($470 + Math_fround(0.0));
  $475 = Math_fround($471 + Math_fround(0.0));
  $476 = Math_fround($424 * $448);
  $477 = Math_fround($425 * $449);
  $478 = Math_fround($426 * $450);
  $479 = Math_fround($427 * $451);
  $480 = Math_fround($476 + Math_fround(0.0));
  $481 = Math_fround($477 + Math_fround(0.0));
  $482 = Math_fround($478 + Math_fround(0.0));
  $483 = Math_fround($479 + Math_fround(0.0));
  $484 = Math_fround($412 * $444);
  $485 = Math_fround($413 * $445);
  $486 = Math_fround($414 * $446);
  $487 = Math_fround($415 * $447);
  $488 = Math_fround($484 + $480);
  $489 = Math_fround($485 + $481);
  $490 = Math_fround($486 + $482);
  $491 = Math_fround($487 + $483);
  $492 = Math_fround($400 * $440);
  $493 = Math_fround($401 * $441);
  $494 = Math_fround($402 * $442);
  $495 = Math_fround($403 * $443);
  $496 = Math_fround($492 + $488);
  $497 = Math_fround($493 + $489);
  $498 = Math_fround($494 + $490);
  $499 = Math_fround($495 + $491);
  $500 = Math_fround($59 * $448);
  $501 = Math_fround($59 * $449);
  $502 = Math_fround($59 * $450);
  $503 = Math_fround($59 * $451);
  $504 = Math_fround($500 + Math_fround(0.0));
  $505 = Math_fround($501 + Math_fround(0.0));
  $506 = Math_fround($502 + Math_fround(0.0));
  $507 = Math_fround($503 + Math_fround(0.0));
  $508 = Math_fround($58 * $444);
  $509 = Math_fround($58 * $445);
  $510 = Math_fround($58 * $446);
  $511 = Math_fround($58 * $447);
  $512 = Math_fround($508 + $504);
  $513 = Math_fround($509 + $505);
  $514 = Math_fround($510 + $506);
  $515 = Math_fround($511 + $507);
  $516 = Math_fround($57 * $440);
  $517 = Math_fround($57 * $441);
  $518 = Math_fround($57 * $442);
  $519 = Math_fround($57 * $443);
  $520 = Math_fround($516 + $512);
  $521 = Math_fround($517 + $513);
  $522 = Math_fround($518 + $514);
  $523 = Math_fround($519 + $515);
  $524 = Math_fround($65 * $448);
  $525 = Math_fround($65 * $449);
  $526 = Math_fround($65 * $450);
  $527 = Math_fround($65 * $451);
  $528 = Math_fround($524 + Math_fround(0.0));
  $529 = Math_fround($525 + Math_fround(0.0));
  $530 = Math_fround($526 + Math_fround(0.0));
  $531 = Math_fround($527 + Math_fround(0.0));
  $532 = Math_fround($64 * $444);
  $533 = Math_fround($64 * $445);
  $534 = Math_fround($64 * $446);
  $535 = Math_fround($64 * $447);
  $536 = Math_fround($532 + $528);
  $537 = Math_fround($533 + $529);
  $538 = Math_fround($534 + $530);
  $539 = Math_fround($535 + $531);
  $540 = Math_fround($63 * $440);
  $541 = Math_fround($63 * $441);
  $542 = Math_fround($63 * $442);
  $543 = Math_fround($63 * $443);
  $544 = Math_fround($540 + $536);
  $545 = Math_fround($541 + $537);
  $546 = Math_fround($542 + $538);
  $547 = Math_fround($543 + $539);
  $548 = Math_fround($71 * $448);
  $549 = Math_fround($71 * $449);
  $550 = Math_fround($71 * $450);
  $551 = Math_fround($71 * $451);
  $552 = Math_fround($548 + Math_fround(0.0));
  $553 = Math_fround($549 + Math_fround(0.0));
  $554 = Math_fround($550 + Math_fround(0.0));
  $555 = Math_fround($551 + Math_fround(0.0));
  $556 = Math_fround($70 * $444);
  $557 = Math_fround($70 * $445);
  $558 = Math_fround($70 * $446);
  $559 = Math_fround($70 * $447);
  $560 = Math_fround($556 + $552);
  $561 = Math_fround($557 + $553);
  $562 = Math_fround($558 + $554);
  $563 = Math_fround($559 + $555);
  $564 = Math_fround($69 * $440);
  $565 = Math_fround($69 * $441);
  $566 = Math_fround($69 * $442);
  $567 = Math_fround($69 * $443);
  $568 = Math_fround($564 + $560);
  $569 = Math_fround($565 + $561);
  $570 = Math_fround($566 + $562);
  $571 = Math_fround($567 + $563);
  $572 = Math_fround($11 * $448);
  $573 = Math_fround($11 * $449);
  $574 = Math_fround($11 * $450);
  $575 = Math_fround($11 * $451);
  $576 = Math_fround($572 + Math_fround(0.0));
  $577 = Math_fround($573 + Math_fround(0.0));
  $578 = Math_fround($574 + Math_fround(0.0));
  $579 = Math_fround($575 + Math_fround(0.0));
  $580 = Math_fround($9 * $444);
  $581 = Math_fround($9 * $445);
  $582 = Math_fround($9 * $446);
  $583 = Math_fround($9 * $447);
  $584 = Math_fround($580 + $576);
  $585 = Math_fround($581 + $577);
  $586 = Math_fround($582 + $578);
  $587 = Math_fround($583 + $579);
  $588 = Math_fround($7 * $440);
  $589 = Math_fround($7 * $441);
  $590 = Math_fround($7 * $442);
  $591 = Math_fround($7 * $443);
  $592 = Math_fround($588 + $584);
  $593 = Math_fround($589 + $585);
  $594 = Math_fround($590 + $586);
  $595 = Math_fround($591 + $587);
  $596 = Math_fround($496 - $592);
  $597 = Math_fround($497 - $593);
  $598 = Math_fround($498 - $594);
  $599 = Math_fround($499 - $595);
  $600 = (HEAPF32[tempDoublePtr>>2]=$596,HEAP32[tempDoublePtr>>2]|0);
  $601 = (HEAPF32[tempDoublePtr>>2]=$597,HEAP32[tempDoublePtr>>2]|0);
  $602 = (HEAPF32[tempDoublePtr>>2]=$598,HEAP32[tempDoublePtr>>2]|0);
  $603 = (HEAPF32[tempDoublePtr>>2]=$599,HEAP32[tempDoublePtr>>2]|0);
  $604 = $600 & 2147483647;
  $605 = $601 & 2147483647;
  $606 = $602 & 2147483647;
  $607 = $603 & 2147483647;
  $608 = (HEAPF32[tempDoublePtr>>2]=$456,HEAP32[tempDoublePtr>>2]|0);
  $609 = (HEAPF32[tempDoublePtr>>2]=$457,HEAP32[tempDoublePtr>>2]|0);
  $610 = (HEAPF32[tempDoublePtr>>2]=$458,HEAP32[tempDoublePtr>>2]|0);
  $611 = (HEAPF32[tempDoublePtr>>2]=$459,HEAP32[tempDoublePtr>>2]|0);
  $612 = $608 & 2147483647;
  $613 = $609 & 2147483647;
  $614 = $610 & 2147483647;
  $615 = $611 & 2147483647;
  $616 = (HEAPF32[tempDoublePtr>>2]=$464,HEAP32[tempDoublePtr>>2]|0);
  $617 = (HEAPF32[tempDoublePtr>>2]=$465,HEAP32[tempDoublePtr>>2]|0);
  $618 = (HEAPF32[tempDoublePtr>>2]=$466,HEAP32[tempDoublePtr>>2]|0);
  $619 = (HEAPF32[tempDoublePtr>>2]=$467,HEAP32[tempDoublePtr>>2]|0);
  $620 = $616 & 2147483647;
  $621 = $617 & 2147483647;
  $622 = $618 & 2147483647;
  $623 = $619 & 2147483647;
  $624 = (HEAP32[tempDoublePtr>>2]=$612,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $625 = (HEAP32[tempDoublePtr>>2]=$620,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $626 = Math_fround($624 + $625);
  $627 = (HEAP32[tempDoublePtr>>2]=$613,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $628 = (HEAP32[tempDoublePtr>>2]=$621,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $629 = Math_fround($627 + $628);
  $630 = (HEAP32[tempDoublePtr>>2]=$614,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $631 = (HEAP32[tempDoublePtr>>2]=$622,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $632 = Math_fround($630 + $631);
  $633 = (HEAP32[tempDoublePtr>>2]=$615,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $634 = (HEAP32[tempDoublePtr>>2]=$623,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $635 = Math_fround($633 + $634);
  $636 = (HEAPF32[tempDoublePtr>>2]=$472,HEAP32[tempDoublePtr>>2]|0);
  $637 = (HEAPF32[tempDoublePtr>>2]=$473,HEAP32[tempDoublePtr>>2]|0);
  $638 = (HEAPF32[tempDoublePtr>>2]=$474,HEAP32[tempDoublePtr>>2]|0);
  $639 = (HEAPF32[tempDoublePtr>>2]=$475,HEAP32[tempDoublePtr>>2]|0);
  $640 = $636 & 2147483647;
  $641 = $637 & 2147483647;
  $642 = $638 & 2147483647;
  $643 = $639 & 2147483647;
  $644 = (HEAP32[tempDoublePtr>>2]=$640,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $645 = Math_fround($644 + $626);
  $646 = (HEAP32[tempDoublePtr>>2]=$641,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $647 = Math_fround($646 + $629);
  $648 = (HEAP32[tempDoublePtr>>2]=$642,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $649 = Math_fround($648 + $632);
  $650 = (HEAP32[tempDoublePtr>>2]=$643,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $651 = Math_fround($650 + $635);
  $652 = (HEAPF32[tempDoublePtr>>2]=$520,HEAP32[tempDoublePtr>>2]|0);
  $653 = (HEAPF32[tempDoublePtr>>2]=$521,HEAP32[tempDoublePtr>>2]|0);
  $654 = (HEAPF32[tempDoublePtr>>2]=$522,HEAP32[tempDoublePtr>>2]|0);
  $655 = (HEAPF32[tempDoublePtr>>2]=$523,HEAP32[tempDoublePtr>>2]|0);
  $656 = $652 & 2147483647;
  $657 = $653 & 2147483647;
  $658 = $654 & 2147483647;
  $659 = $655 & 2147483647;
  $660 = (HEAPF32[tempDoublePtr>>2]=$544,HEAP32[tempDoublePtr>>2]|0);
  $661 = (HEAPF32[tempDoublePtr>>2]=$545,HEAP32[tempDoublePtr>>2]|0);
  $662 = (HEAPF32[tempDoublePtr>>2]=$546,HEAP32[tempDoublePtr>>2]|0);
  $663 = (HEAPF32[tempDoublePtr>>2]=$547,HEAP32[tempDoublePtr>>2]|0);
  $664 = $660 & 2147483647;
  $665 = $661 & 2147483647;
  $666 = $662 & 2147483647;
  $667 = $663 & 2147483647;
  $668 = (HEAP32[tempDoublePtr>>2]=$656,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $669 = (HEAP32[tempDoublePtr>>2]=$664,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $670 = Math_fround($668 + $669);
  $671 = (HEAP32[tempDoublePtr>>2]=$657,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $672 = (HEAP32[tempDoublePtr>>2]=$665,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $673 = Math_fround($671 + $672);
  $674 = (HEAP32[tempDoublePtr>>2]=$658,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $675 = (HEAP32[tempDoublePtr>>2]=$666,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $676 = Math_fround($674 + $675);
  $677 = (HEAP32[tempDoublePtr>>2]=$659,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $678 = (HEAP32[tempDoublePtr>>2]=$667,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $679 = Math_fround($677 + $678);
  $680 = (HEAPF32[tempDoublePtr>>2]=$568,HEAP32[tempDoublePtr>>2]|0);
  $681 = (HEAPF32[tempDoublePtr>>2]=$569,HEAP32[tempDoublePtr>>2]|0);
  $682 = (HEAPF32[tempDoublePtr>>2]=$570,HEAP32[tempDoublePtr>>2]|0);
  $683 = (HEAPF32[tempDoublePtr>>2]=$571,HEAP32[tempDoublePtr>>2]|0);
  $684 = $680 & 2147483647;
  $685 = $681 & 2147483647;
  $686 = $682 & 2147483647;
  $687 = $683 & 2147483647;
  $688 = (HEAP32[tempDoublePtr>>2]=$684,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $689 = Math_fround($688 + $670);
  $690 = (HEAP32[tempDoublePtr>>2]=$685,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $691 = Math_fround($690 + $673);
  $692 = (HEAP32[tempDoublePtr>>2]=$686,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $693 = Math_fround($692 + $676);
  $694 = (HEAP32[tempDoublePtr>>2]=$687,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $695 = Math_fround($694 + $679);
  $696 = (HEAP32[tempDoublePtr>>2]=$604,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $697 = Math_fround($696 + Math_fround(-9.99999997475242707878E-7));
  $698 = (HEAP32[tempDoublePtr>>2]=$605,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $699 = Math_fround($698 + Math_fround(-9.99999997475242707878E-7));
  $700 = (HEAP32[tempDoublePtr>>2]=$606,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $701 = Math_fround($700 + Math_fround(-9.99999997475242707878E-7));
  $702 = (HEAP32[tempDoublePtr>>2]=$607,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $703 = Math_fround($702 + Math_fround(-9.99999997475242707878E-7));
  $704 = Math_fround($645 + $689);
  $705 = Math_fround($647 + $691);
  $706 = Math_fround($649 + $693);
  $707 = Math_fround($651 + $695);
  $708 = $697 > $704;
  $709 = $699 > $705;
  $710 = $701 > $706;
  $711 = $703 > $707;
  $712 = $696 > Math_fround(9.99999997475242707878E-7);
  $713 = $698 > Math_fround(9.99999997475242707878E-7);
  $714 = $700 > Math_fround(9.99999997475242707878E-7);
  $715 = $702 > Math_fround(9.99999997475242707878E-7);
  $716 = Math_fround($304 - $$$i708);
  $717 = Math_fround($305 - $364);
  $718 = Math_fround($306 - $$1$i709);
  $719 = Math_fround($307 - $367);
  $720 = Math_fround($328 - $$$i696);
  $721 = Math_fround($329 - $376);
  $722 = Math_fround($330 - $$1$i697);
  $723 = Math_fround($331 - $379);
  $724 = Math_fround($352 - $$$i);
  $725 = Math_fround($353 - $388);
  $726 = Math_fround($354 - $$1$i);
  $727 = Math_fround($355 - $391);
  $728 = Math_fround($428 * $716);
  $729 = Math_fround($429 * $717);
  $730 = Math_fround($430 * $718);
  $731 = Math_fround($431 * $719);
  $732 = Math_fround($728 + Math_fround(0.0));
  $733 = Math_fround($729 + Math_fround(0.0));
  $734 = Math_fround($730 + Math_fround(0.0));
  $735 = Math_fround($731 + Math_fround(0.0));
  $736 = Math_fround($432 * $720);
  $737 = Math_fround($433 * $721);
  $738 = Math_fround($434 * $722);
  $739 = Math_fround($435 * $723);
  $740 = Math_fround($736 + Math_fround(0.0));
  $741 = Math_fround($737 + Math_fround(0.0));
  $742 = Math_fround($738 + Math_fround(0.0));
  $743 = Math_fround($739 + Math_fround(0.0));
  $744 = Math_fround($436 * $724);
  $745 = Math_fround($437 * $725);
  $746 = Math_fround($438 * $726);
  $747 = Math_fround($439 * $727);
  $748 = Math_fround($744 + Math_fround(0.0));
  $749 = Math_fround($745 + Math_fround(0.0));
  $750 = Math_fround($746 + Math_fround(0.0));
  $751 = Math_fround($747 + Math_fround(0.0));
  $752 = Math_fround($424 * $724);
  $753 = Math_fround($425 * $725);
  $754 = Math_fround($426 * $726);
  $755 = Math_fround($427 * $727);
  $756 = Math_fround($752 + Math_fround(0.0));
  $757 = Math_fround($753 + Math_fround(0.0));
  $758 = Math_fround($754 + Math_fround(0.0));
  $759 = Math_fround($755 + Math_fround(0.0));
  $760 = Math_fround($412 * $720);
  $761 = Math_fround($413 * $721);
  $762 = Math_fround($414 * $722);
  $763 = Math_fround($415 * $723);
  $764 = Math_fround($760 + $756);
  $765 = Math_fround($761 + $757);
  $766 = Math_fround($762 + $758);
  $767 = Math_fround($763 + $759);
  $768 = Math_fround($400 * $716);
  $769 = Math_fround($401 * $717);
  $770 = Math_fround($402 * $718);
  $771 = Math_fround($403 * $719);
  $772 = Math_fround($768 + $764);
  $773 = Math_fround($769 + $765);
  $774 = Math_fround($770 + $766);
  $775 = Math_fround($771 + $767);
  $776 = Math_fround($59 * $724);
  $777 = Math_fround($59 * $725);
  $778 = Math_fround($59 * $726);
  $779 = Math_fround($59 * $727);
  $780 = Math_fround($776 + Math_fround(0.0));
  $781 = Math_fround($777 + Math_fround(0.0));
  $782 = Math_fround($778 + Math_fround(0.0));
  $783 = Math_fround($779 + Math_fround(0.0));
  $784 = Math_fround($58 * $720);
  $785 = Math_fround($58 * $721);
  $786 = Math_fround($58 * $722);
  $787 = Math_fround($58 * $723);
  $788 = Math_fround($784 + $780);
  $789 = Math_fround($785 + $781);
  $790 = Math_fround($786 + $782);
  $791 = Math_fround($787 + $783);
  $792 = Math_fround($57 * $716);
  $793 = Math_fround($57 * $717);
  $794 = Math_fround($57 * $718);
  $795 = Math_fround($57 * $719);
  $796 = Math_fround($792 + $788);
  $797 = Math_fround($793 + $789);
  $798 = Math_fround($794 + $790);
  $799 = Math_fround($795 + $791);
  $800 = Math_fround($65 * $724);
  $801 = Math_fround($65 * $725);
  $802 = Math_fround($65 * $726);
  $803 = Math_fround($65 * $727);
  $804 = Math_fround($800 + Math_fround(0.0));
  $805 = Math_fround($801 + Math_fround(0.0));
  $806 = Math_fround($802 + Math_fround(0.0));
  $807 = Math_fround($803 + Math_fround(0.0));
  $808 = Math_fround($64 * $720);
  $809 = Math_fround($64 * $721);
  $810 = Math_fround($64 * $722);
  $811 = Math_fround($64 * $723);
  $812 = Math_fround($808 + $804);
  $813 = Math_fround($809 + $805);
  $814 = Math_fround($810 + $806);
  $815 = Math_fround($811 + $807);
  $816 = Math_fround($63 * $716);
  $817 = Math_fround($63 * $717);
  $818 = Math_fround($63 * $718);
  $819 = Math_fround($63 * $719);
  $820 = Math_fround($816 + $812);
  $821 = Math_fround($817 + $813);
  $822 = Math_fround($818 + $814);
  $823 = Math_fround($819 + $815);
  $824 = Math_fround($71 * $724);
  $825 = Math_fround($71 * $725);
  $826 = Math_fround($71 * $726);
  $827 = Math_fround($71 * $727);
  $828 = Math_fround($824 + Math_fround(0.0));
  $829 = Math_fround($825 + Math_fround(0.0));
  $830 = Math_fround($826 + Math_fround(0.0));
  $831 = Math_fround($827 + Math_fround(0.0));
  $832 = Math_fround($70 * $720);
  $833 = Math_fround($70 * $721);
  $834 = Math_fround($70 * $722);
  $835 = Math_fround($70 * $723);
  $836 = Math_fround($832 + $828);
  $837 = Math_fround($833 + $829);
  $838 = Math_fround($834 + $830);
  $839 = Math_fround($835 + $831);
  $840 = Math_fround($69 * $716);
  $841 = Math_fround($69 * $717);
  $842 = Math_fround($69 * $718);
  $843 = Math_fround($69 * $719);
  $844 = Math_fround($840 + $836);
  $845 = Math_fround($841 + $837);
  $846 = Math_fround($842 + $838);
  $847 = Math_fround($843 + $839);
  $848 = Math_fround($11 * $724);
  $849 = Math_fround($11 * $725);
  $850 = Math_fround($11 * $726);
  $851 = Math_fround($11 * $727);
  $852 = Math_fround($848 + Math_fround(0.0));
  $853 = Math_fround($849 + Math_fround(0.0));
  $854 = Math_fround($850 + Math_fround(0.0));
  $855 = Math_fround($851 + Math_fround(0.0));
  $856 = Math_fround($9 * $720);
  $857 = Math_fround($9 * $721);
  $858 = Math_fround($9 * $722);
  $859 = Math_fround($9 * $723);
  $860 = Math_fround($856 + $852);
  $861 = Math_fround($857 + $853);
  $862 = Math_fround($858 + $854);
  $863 = Math_fround($859 + $855);
  $864 = Math_fround($7 * $716);
  $865 = Math_fround($7 * $717);
  $866 = Math_fround($7 * $718);
  $867 = Math_fround($7 * $719);
  $868 = Math_fround($864 + $860);
  $869 = Math_fround($865 + $861);
  $870 = Math_fround($866 + $862);
  $871 = Math_fround($867 + $863);
  $872 = Math_fround($772 - $868);
  $873 = Math_fround($773 - $869);
  $874 = Math_fround($774 - $870);
  $875 = Math_fround($775 - $871);
  $876 = (HEAPF32[tempDoublePtr>>2]=$872,HEAP32[tempDoublePtr>>2]|0);
  $877 = (HEAPF32[tempDoublePtr>>2]=$873,HEAP32[tempDoublePtr>>2]|0);
  $878 = (HEAPF32[tempDoublePtr>>2]=$874,HEAP32[tempDoublePtr>>2]|0);
  $879 = (HEAPF32[tempDoublePtr>>2]=$875,HEAP32[tempDoublePtr>>2]|0);
  $880 = $876 & 2147483647;
  $881 = $877 & 2147483647;
  $882 = $878 & 2147483647;
  $883 = $879 & 2147483647;
  $884 = (HEAPF32[tempDoublePtr>>2]=$732,HEAP32[tempDoublePtr>>2]|0);
  $885 = (HEAPF32[tempDoublePtr>>2]=$733,HEAP32[tempDoublePtr>>2]|0);
  $886 = (HEAPF32[tempDoublePtr>>2]=$734,HEAP32[tempDoublePtr>>2]|0);
  $887 = (HEAPF32[tempDoublePtr>>2]=$735,HEAP32[tempDoublePtr>>2]|0);
  $888 = $884 & 2147483647;
  $889 = $885 & 2147483647;
  $890 = $886 & 2147483647;
  $891 = $887 & 2147483647;
  $892 = (HEAPF32[tempDoublePtr>>2]=$740,HEAP32[tempDoublePtr>>2]|0);
  $893 = (HEAPF32[tempDoublePtr>>2]=$741,HEAP32[tempDoublePtr>>2]|0);
  $894 = (HEAPF32[tempDoublePtr>>2]=$742,HEAP32[tempDoublePtr>>2]|0);
  $895 = (HEAPF32[tempDoublePtr>>2]=$743,HEAP32[tempDoublePtr>>2]|0);
  $896 = $892 & 2147483647;
  $897 = $893 & 2147483647;
  $898 = $894 & 2147483647;
  $899 = $895 & 2147483647;
  $900 = (HEAP32[tempDoublePtr>>2]=$888,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $901 = (HEAP32[tempDoublePtr>>2]=$896,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $902 = Math_fround($900 + $901);
  $903 = (HEAP32[tempDoublePtr>>2]=$889,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $904 = (HEAP32[tempDoublePtr>>2]=$897,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $905 = Math_fround($903 + $904);
  $906 = (HEAP32[tempDoublePtr>>2]=$890,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $907 = (HEAP32[tempDoublePtr>>2]=$898,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $908 = Math_fround($906 + $907);
  $909 = (HEAP32[tempDoublePtr>>2]=$891,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $910 = (HEAP32[tempDoublePtr>>2]=$899,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $911 = Math_fround($909 + $910);
  $912 = (HEAPF32[tempDoublePtr>>2]=$748,HEAP32[tempDoublePtr>>2]|0);
  $913 = (HEAPF32[tempDoublePtr>>2]=$749,HEAP32[tempDoublePtr>>2]|0);
  $914 = (HEAPF32[tempDoublePtr>>2]=$750,HEAP32[tempDoublePtr>>2]|0);
  $915 = (HEAPF32[tempDoublePtr>>2]=$751,HEAP32[tempDoublePtr>>2]|0);
  $916 = $912 & 2147483647;
  $917 = $913 & 2147483647;
  $918 = $914 & 2147483647;
  $919 = $915 & 2147483647;
  $920 = (HEAP32[tempDoublePtr>>2]=$916,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $921 = Math_fround($920 + $902);
  $922 = (HEAP32[tempDoublePtr>>2]=$917,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $923 = Math_fround($922 + $905);
  $924 = (HEAP32[tempDoublePtr>>2]=$918,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $925 = Math_fround($924 + $908);
  $926 = (HEAP32[tempDoublePtr>>2]=$919,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $927 = Math_fround($926 + $911);
  $928 = (HEAPF32[tempDoublePtr>>2]=$796,HEAP32[tempDoublePtr>>2]|0);
  $929 = (HEAPF32[tempDoublePtr>>2]=$797,HEAP32[tempDoublePtr>>2]|0);
  $930 = (HEAPF32[tempDoublePtr>>2]=$798,HEAP32[tempDoublePtr>>2]|0);
  $931 = (HEAPF32[tempDoublePtr>>2]=$799,HEAP32[tempDoublePtr>>2]|0);
  $932 = $928 & 2147483647;
  $933 = $929 & 2147483647;
  $934 = $930 & 2147483647;
  $935 = $931 & 2147483647;
  $936 = (HEAPF32[tempDoublePtr>>2]=$820,HEAP32[tempDoublePtr>>2]|0);
  $937 = (HEAPF32[tempDoublePtr>>2]=$821,HEAP32[tempDoublePtr>>2]|0);
  $938 = (HEAPF32[tempDoublePtr>>2]=$822,HEAP32[tempDoublePtr>>2]|0);
  $939 = (HEAPF32[tempDoublePtr>>2]=$823,HEAP32[tempDoublePtr>>2]|0);
  $940 = $936 & 2147483647;
  $941 = $937 & 2147483647;
  $942 = $938 & 2147483647;
  $943 = $939 & 2147483647;
  $944 = (HEAP32[tempDoublePtr>>2]=$932,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $945 = (HEAP32[tempDoublePtr>>2]=$940,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $946 = Math_fround($944 + $945);
  $947 = (HEAP32[tempDoublePtr>>2]=$933,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $948 = (HEAP32[tempDoublePtr>>2]=$941,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $949 = Math_fround($947 + $948);
  $950 = (HEAP32[tempDoublePtr>>2]=$934,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $951 = (HEAP32[tempDoublePtr>>2]=$942,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $952 = Math_fround($950 + $951);
  $953 = (HEAP32[tempDoublePtr>>2]=$935,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $954 = (HEAP32[tempDoublePtr>>2]=$943,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $955 = Math_fround($953 + $954);
  $956 = (HEAPF32[tempDoublePtr>>2]=$844,HEAP32[tempDoublePtr>>2]|0);
  $957 = (HEAPF32[tempDoublePtr>>2]=$845,HEAP32[tempDoublePtr>>2]|0);
  $958 = (HEAPF32[tempDoublePtr>>2]=$846,HEAP32[tempDoublePtr>>2]|0);
  $959 = (HEAPF32[tempDoublePtr>>2]=$847,HEAP32[tempDoublePtr>>2]|0);
  $960 = $956 & 2147483647;
  $961 = $957 & 2147483647;
  $962 = $958 & 2147483647;
  $963 = $959 & 2147483647;
  $964 = (HEAP32[tempDoublePtr>>2]=$960,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $965 = Math_fround($964 + $946);
  $966 = (HEAP32[tempDoublePtr>>2]=$961,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $967 = Math_fround($966 + $949);
  $968 = (HEAP32[tempDoublePtr>>2]=$962,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $969 = Math_fround($968 + $952);
  $970 = (HEAP32[tempDoublePtr>>2]=$963,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $971 = Math_fround($970 + $955);
  $972 = (HEAP32[tempDoublePtr>>2]=$880,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $973 = Math_fround($972 + Math_fround(-9.99999997475242707878E-7));
  $974 = (HEAP32[tempDoublePtr>>2]=$881,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $975 = Math_fround($974 + Math_fround(-9.99999997475242707878E-7));
  $976 = (HEAP32[tempDoublePtr>>2]=$882,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $977 = Math_fround($976 + Math_fround(-9.99999997475242707878E-7));
  $978 = (HEAP32[tempDoublePtr>>2]=$883,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $979 = Math_fround($978 + Math_fround(-9.99999997475242707878E-7));
  $980 = Math_fround($921 + $965);
  $981 = Math_fround($923 + $967);
  $982 = Math_fround($925 + $969);
  $983 = Math_fround($927 + $971);
  $984 = $973 > $980;
  $985 = $975 > $981;
  $986 = $977 > $982;
  $987 = $979 > $983;
  $988 = $972 > Math_fround(9.99999997475242707878E-7);
  $989 = $974 > Math_fround(9.99999997475242707878E-7);
  $990 = $976 > Math_fround(9.99999997475242707878E-7);
  $991 = $978 > Math_fround(9.99999997475242707878E-7);
  $992 = $712 & $708;
  $993 = $713 & $709;
  $994 = $714 & $710;
  $995 = $715 & $711;
  $996 = $988 & $984;
  $997 = $989 & $985;
  $998 = $990 & $986;
  $999 = $991 & $987;
  $1000 = $996 | $992;
  $1001 = $997 | $993;
  $1002 = $998 | $994;
  $1003 = $999 | $995;
  $1004 = $81 > $105;
  $1005 = $83 > $107;
  $1006 = $85 > $109;
  $1007 = $87 > $111;
  $1008 = $1004 | $1000;
  $1009 = $1008&1;
  $1010 = $1005 | $1001;
  $1011 = $1010&1;
  $1012 = $1006 | $1002;
  $1013 = $1012&1;
  $1014 = $1007 | $1003;
  $1015 = $1014&1;
  $1016 = $1009 ^ 1;
  $1017 = $1011 ^ 1;
  $1018 = $1013 ^ 1;
  $1019 = $1015 ^ 1;
  HEAP32[$resa_>>2] = $1016;
  HEAP32[$72>>2] = $1017;
  HEAP32[$73>>2] = $1018;
  HEAP32[$74>>2] = $1019;
  $1024 = $1016;$cacheTop$14144 = $cacheTop$0;$cacheTopValid$14145 = 0;$i$04147 = 0;$stackPtr$24146 = $75;
  while(1) {
   $1020 = (($80) + ($i$04147<<2)|0);
   $1021 = HEAP32[$1020>>2]|0;
   $1022 = $1021 & -2;
   HEAP32[$ptr>>2] = $1022;
   $1023 = ($1024|0)==(0);
   do {
    if ($1023) {
     $cacheTop$2 = $cacheTop$14144;$cacheTopValid$2 = $cacheTopValid$14145;$stackPtr$3 = $stackPtr$24146;
    } else {
     $1025 = ((($78) + ($i$04147<<2)|0) + 96|0);
     $1026 = HEAP32[$1025>>2]|0;
     $1027 = $1026 & 1;
     $1028 = ($1027|0)==(0);
     if ($1028) {
      $1032 = (($stackPtr$24146) + 4|0);
      HEAP32[$stackPtr$24146>>2] = $1022;
      $1033 = HEAP32[$ptr>>2]|0;
      $cacheTop$2 = $1033;$cacheTopValid$2 = 1;$stackPtr$3 = $1032;
      break;
     } else {
      $1029 = HEAP32[$callback>>2]|0;
      $1030 = HEAP32[$1029>>2]|0;
      $1031 = (FUNCTION_TABLE_iiii[$1030 & 2047]($callback,1,$ptr)|0);
      if ($1031) {
       $cacheTop$2 = $cacheTop$14144;$cacheTopValid$2 = $cacheTopValid$14145;$stackPtr$3 = $stackPtr$24146;
       break;
      } else {
       label = 23;
       break L17;
      }
     }
    }
   } while(0);
   $1034 = (($i$04147) + 1)|0;
   $1035 = ($1034>>>0)<(4);
   if (!($1035)) {
    break;
   }
   $$phi$trans$insert = (($resa_) + ($1034<<2)|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $1024 = $$pre;$cacheTop$14144 = $cacheTop$2;$cacheTopValid$14145 = $cacheTopValid$2;$i$04147 = $1034;$stackPtr$24146 = $stackPtr$3;
  }
  $1036 = ($stackPtr$3>>>0)>($stack>>>0);
  if ($1036) {
   $cacheTop$0 = $cacheTop$2;$cacheTopValid$0 = $cacheTopValid$2;$stackPtr$1 = $stackPtr$3;
  } else {
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  STACKTOP = sp;return;
 }
}
function __Z21sweepCapsule_MeshGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$lss,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $lss = $lss|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$ = 0, $$lobit = 0, $$lobit57 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0;
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = 0;
 var $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = Math_fround(0);
 var $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0);
 var $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0;
 var $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0);
 var $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0);
 var $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0);
 var $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0);
 var $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0);
 var $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0);
 var $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0);
 var $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0);
 var $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0);
 var $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $callback = 0, $data = 0;
 var $distance1$0 = Math_fround(0), $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i$i$i = Math_fround(0), $fabsf$i$i$i$i$i9 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i$i$i = Math_fround(0), $fabsf$i$i1$i$i$i8 = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i2$i$i$i = Math_fround(0), $fabsf$i$i2$i$i$i7 = Math_fround(0), $fabsf$i$i3$i$i$i = Math_fround(0), $fabsf$i$i3$i$i$i6 = Math_fround(0), $fabsf$i$i4$i$i$i = Math_fround(0), $fabsf$i$i4$i$i$i1 = Math_fround(0), $fabsf$i$i5$i$i$i = Math_fround(0), $fabsf$i$i5$i$i$i2 = Math_fround(0), $fabsf$i$i6$i$i$i = Math_fround(0), $fabsf$i$i6$i$i$i3 = Math_fround(0), $fabsf$i$i7$i$i$i = Math_fround(0), $fabsf$i$i7$i$i$i4 = Math_fround(0);
 var $fabsf$i$i8$i$i$i = Math_fround(0), $fabsf$i$i8$i$i$i5 = Math_fround(0), $inflatedCapsule = 0, $meshScaling = 0, $poseWithScale = 0, $sweepDir = 0, $sweepExtents = 0, $sweepOrigin = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $data = sp + 312|0;
 $inflatedCapsule = sp + 284|0;
 $sweepOrigin = sp + 272|0;
 $sweepDir = sp + 260|0;
 $sweepExtents = sp + 248|0;
 $poseWithScale = sp + 200|0;
 $0 = sp + 104|0;
 $meshScaling = sp + 32|0;
 $1 = sp;
 $callback = sp + 152|0;
 $2 = (($geom) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$hintFlags>>1]|0;
 $5 = (($geom) + 32|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 2;
 $8 = ($7<<24>>24)!=(0);
 $9 = $4 & 128;
 $10 = ($9<<16>>16)!=(0);
 $$ = $8 | $10;
 $11 = (($3) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$data>>2] = $12;
 $13 = (($3) + 48|0);
 $14 = (($data) + 4|0);
 HEAP32[$14>>2] = $13;
 $15 = (($3) + 36|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($data) + 8|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($lss) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 + $inflation);
 $21 = Math_fround(HEAPF32[$lss>>2]);
 HEAPF32[$inflatedCapsule>>2] = $21;
 $22 = (($inflatedCapsule) + 4|0);
 $23 = (($lss) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$22>>2] = $24;
 $25 = (($inflatedCapsule) + 8|0);
 $26 = (($lss) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($inflatedCapsule) + 12|0);
 $29 = (($lss) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($inflatedCapsule) + 16|0);
 $32 = (($lss) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 $34 = (($inflatedCapsule) + 20|0);
 $35 = (($lss) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 $37 = (($inflatedCapsule) + 24|0);
 HEAPF32[$37>>2] = $20;
 $38 = (($pose) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($21 - $39);
 $41 = (($pose) + 20|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($24 - $42);
 $44 = (($pose) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($27 - $45);
 $47 = Math_fround($40 * Math_fround(2.0));
 $48 = Math_fround($43 * Math_fround(2.0));
 $49 = Math_fround($46 * Math_fround(2.0));
 $50 = (($pose) + 12|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $51);
 $53 = Math_fround($52 + Math_fround(-0.5));
 $54 = Math_fround(HEAPF32[$pose>>2]);
 $55 = Math_fround($47 * $54);
 $56 = (($pose) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($48 * $57);
 $59 = Math_fround($55 + $58);
 $60 = (($pose) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($49 * $61);
 $63 = Math_fround($59 + $62);
 $64 = Math_fround($47 * $53);
 $65 = Math_fround($49 * $57);
 $66 = Math_fround($48 * $61);
 $67 = Math_fround($65 - $66);
 $68 = Math_fround($51 * $67);
 $69 = Math_fround($64 - $68);
 $70 = Math_fround($54 * $63);
 $71 = Math_fround($70 + $69);
 $72 = Math_fround($48 * $53);
 $73 = Math_fround($47 * $61);
 $74 = Math_fround($49 * $54);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($51 * $75);
 $77 = Math_fround($72 - $76);
 $78 = Math_fround($57 * $63);
 $79 = Math_fround($78 + $77);
 $80 = Math_fround($49 * $53);
 $81 = Math_fround($48 * $54);
 $82 = Math_fround($47 * $57);
 $83 = Math_fround($81 - $82);
 $84 = Math_fround($51 * $83);
 $85 = Math_fround($80 - $84);
 $86 = Math_fround($61 * $63);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($30 - $39);
 $89 = Math_fround($33 - $42);
 $90 = Math_fround($36 - $45);
 $91 = Math_fround($88 * Math_fround(2.0));
 $92 = Math_fround($89 * Math_fround(2.0));
 $93 = Math_fround($90 * Math_fround(2.0));
 $94 = Math_fround($54 * $91);
 $95 = Math_fround($57 * $92);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($61 * $93);
 $98 = Math_fround($96 + $97);
 $99 = Math_fround($53 * $91);
 $100 = Math_fround($57 * $93);
 $101 = Math_fround($61 * $92);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($51 * $102);
 $104 = Math_fround($99 - $103);
 $105 = Math_fround($54 * $98);
 $106 = Math_fround($105 + $104);
 $107 = Math_fround($53 * $92);
 $108 = Math_fround($61 * $91);
 $109 = Math_fround($54 * $93);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($51 * $110);
 $112 = Math_fround($107 - $111);
 $113 = Math_fround($57 * $98);
 $114 = Math_fround($113 + $112);
 $115 = Math_fround($53 * $93);
 $116 = Math_fround($54 * $92);
 $117 = Math_fround($57 * $91);
 $118 = Math_fround($116 - $117);
 $119 = Math_fround($51 * $118);
 $120 = Math_fround($115 - $119);
 $121 = Math_fround($61 * $98);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($71 + $106);
 $124 = Math_fround($79 + $114);
 $125 = Math_fround($87 + $122);
 $126 = Math_fround($123 * Math_fround(0.5));
 $127 = Math_fround($124 * Math_fround(0.5));
 $128 = Math_fround($125 * Math_fround(0.5));
 HEAPF32[$sweepOrigin>>2] = $126;
 $129 = (($sweepOrigin) + 4|0);
 HEAPF32[$129>>2] = $127;
 $130 = (($sweepOrigin) + 8|0);
 HEAPF32[$130>>2] = $128;
 $131 = Math_fround(HEAPF32[$unitDir>>2]);
 $132 = Math_fround($131 * Math_fround(2.0));
 $133 = (($unitDir) + 4|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround($134 * Math_fround(2.0));
 $136 = (($unitDir) + 8|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($137 * Math_fround(2.0));
 $139 = Math_fround($132 * $54);
 $140 = Math_fround($135 * $57);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($138 * $61);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround($132 * $53);
 $145 = Math_fround($138 * $57);
 $146 = Math_fround($135 * $61);
 $147 = Math_fround($145 - $146);
 $148 = Math_fround($51 * $147);
 $149 = Math_fround($144 - $148);
 $150 = Math_fround($54 * $143);
 $151 = Math_fround($150 + $149);
 $152 = Math_fround($135 * $53);
 $153 = Math_fround($132 * $61);
 $154 = Math_fround($138 * $54);
 $155 = Math_fround($153 - $154);
 $156 = Math_fround($51 * $155);
 $157 = Math_fround($152 - $156);
 $158 = Math_fround($57 * $143);
 $159 = Math_fround($158 + $157);
 $160 = Math_fround($138 * $53);
 $161 = Math_fround($135 * $54);
 $162 = Math_fround($132 * $57);
 $163 = Math_fround($161 - $162);
 $164 = Math_fround($51 * $163);
 $165 = Math_fround($160 - $164);
 $166 = Math_fround($61 * $143);
 $167 = Math_fround($165 + $166);
 HEAPF32[$sweepDir>>2] = $151;
 $168 = (($sweepDir) + 4|0);
 HEAPF32[$168>>2] = $159;
 $169 = (($sweepDir) + 8|0);
 HEAPF32[$169>>2] = $167;
 $170 = Math_fround(HEAPF32[$37>>2]);
 $171 = Math_fround($71 - $106);
 $172 = Math_fround($79 - $114);
 $173 = Math_fround($87 - $122);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($171)))));
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($172)))));
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($173)))));
 $174 = Math_fround($fabsf$i$i$i * Math_fround(0.5));
 $175 = Math_fround($fabsf$i$i1$i * Math_fround(0.5));
 $176 = Math_fround($fabsf$i$i2$i * Math_fround(0.5));
 $177 = Math_fround($170 + $174);
 $178 = Math_fround($170 + $175);
 $179 = Math_fround($170 + $176);
 HEAPF32[$sweepExtents>>2] = $177;
 $180 = (($sweepExtents) + 4|0);
 HEAPF32[$180>>2] = $178;
 $181 = (($sweepExtents) + 8|0);
 HEAPF32[$181>>2] = $179;
 $182 = (($geom) + 4|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = $183 == Math_fround(1.0);
 $185 = (($geom) + 8|0);
 if ($184) {
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = $186 == Math_fround(1.0);
  if ($187) {
   $188 = (($geom) + 12|0);
   $189 = Math_fround(HEAPF32[$188>>2]);
   $190 = $189 == Math_fround(1.0);
   if ($190) {
    $419 = Math_fround(HEAPF32[$pose>>2]);
    $420 = Math_fround($419 + $419);
    $421 = Math_fround(HEAPF32[$56>>2]);
    $422 = Math_fround($421 + $421);
    $423 = Math_fround(HEAPF32[$60>>2]);
    $424 = Math_fround($423 + $423);
    $425 = Math_fround(HEAPF32[$50>>2]);
    $426 = Math_fround($420 * $425);
    $427 = Math_fround($422 * $425);
    $428 = Math_fround($425 * $424);
    $429 = Math_fround($419 * $420);
    $430 = Math_fround($419 * $422);
    $431 = Math_fround($419 * $424);
    $432 = Math_fround($421 * $422);
    $433 = Math_fround($421 * $424);
    $434 = Math_fround($423 * $424);
    $435 = Math_fround(Math_fround(1.0) - $432);
    $436 = Math_fround($435 - $434);
    $437 = Math_fround($430 + $428);
    $438 = Math_fround($431 - $427);
    $439 = Math_fround($430 - $428);
    $440 = Math_fround(Math_fround(1.0) - $429);
    $441 = Math_fround($440 - $434);
    $442 = Math_fround($433 + $426);
    $443 = Math_fround($431 + $427);
    $444 = Math_fround($433 - $426);
    $445 = Math_fround($440 - $432);
    $446 = Math_fround(HEAPF32[$38>>2]);
    $447 = Math_fround(HEAPF32[$41>>2]);
    $448 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$poseWithScale>>2] = $436;
    $449 = (($poseWithScale) + 4|0);
    HEAPF32[$449>>2] = $437;
    $450 = (($poseWithScale) + 8|0);
    HEAPF32[$450>>2] = $438;
    $451 = (($poseWithScale) + 12|0);
    HEAPF32[$451>>2] = $439;
    $452 = (($poseWithScale) + 16|0);
    HEAPF32[$452>>2] = $441;
    $453 = (($poseWithScale) + 20|0);
    HEAPF32[$453>>2] = $442;
    $454 = (($poseWithScale) + 24|0);
    HEAPF32[$454>>2] = $443;
    $455 = (($poseWithScale) + 28|0);
    HEAPF32[$455>>2] = $444;
    $456 = (($poseWithScale) + 32|0);
    HEAPF32[$456>>2] = $445;
    $457 = (($poseWithScale) + 36|0);
    HEAPF32[$457>>2] = $446;
    $458 = (($poseWithScale) + 40|0);
    HEAPF32[$458>>2] = $447;
    $459 = (($poseWithScale) + 44|0);
    HEAPF32[$459>>2] = $448;
    $distance1$0 = $distance;
    $460 = (($callback) + 4|0);
    HEAP32[$460>>2] = 2;
    HEAP32[$callback>>2] = ((552704 + 8|0));
    $461 = (($callback) + 8|0);
    HEAP32[$461>>2] = $sweepHit;
    $462 = (($callback) + 12|0);
    HEAP32[$462>>2] = $poseWithScale;
    $463 = (($callback) + 16|0);
    HEAPF32[$463>>2] = $distance;
    $464 = (($callback) + 20|0);
    HEAPF32[$464>>2] = $distance;
    $465 = (($callback) + 24|0);
    $$lobit57 = ($7&255) >>> 1;
    $$lobit = ($9&65535) >>> 7;
    $466 = $$lobit&255;
    $467 = $$lobit57 | $466;
    HEAP8[$465>>0] = $467;
    $468 = (($callback) + 28|0);
    HEAP32[$468>>2] = $inflatedCapsule;
    $469 = (($callback) + 32|0);
    HEAP32[$469>>2] = $unitDir;
    $470 = (($callback) + 36|0);
    HEAP32[$470>>2] = $hintFlags;
    $471 = (($callback) + 40|0);
    HEAP8[$471>>0] = 0;
    $472 = (($callback) + 41|0);
    HEAP8[$472>>0] = 0;
    $473 = (($sweepHit) + 40|0);
    HEAPF32[$473>>2] = Math_fround(3.40282346638528859812E+38);
    __ZN5physx2Gu15MeshRayCollider7collideILi1ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($sweepOrigin,$sweepDir,$distance1$0,1,$data,$callback,$sweepExtents);
    $474 = (__ZN20SweepCapsuleCallback8finalizeERN5physx10PxSweepHitERKNS0_2Gu7CapsuleERKNS0_22PxTriangleMeshGeometryERKNS0_11PxTransformEbf($callback,$sweepHit,$inflatedCapsule,$geom,$pose,$$,$distance)|0);
    STACKTOP = sp;return ($474|0);
   }
  }
 }
 __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($0,$pose,$182);
 $191 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$poseWithScale>>2] = $191;
 $192 = (($0) + 4|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = (($poseWithScale) + 4|0);
 HEAPF32[$194>>2] = $193;
 $195 = (($0) + 8|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($poseWithScale) + 8|0);
 HEAPF32[$197>>2] = $196;
 $198 = (($0) + 12|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($poseWithScale) + 12|0);
 HEAPF32[$200>>2] = $199;
 $201 = (($0) + 16|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($poseWithScale) + 16|0);
 HEAPF32[$203>>2] = $202;
 $204 = (($0) + 20|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($poseWithScale) + 20|0);
 HEAPF32[$206>>2] = $205;
 $207 = (($0) + 24|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($poseWithScale) + 24|0);
 HEAPF32[$209>>2] = $208;
 $210 = (($0) + 28|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = (($poseWithScale) + 28|0);
 HEAPF32[$212>>2] = $211;
 $213 = (($0) + 32|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = (($poseWithScale) + 32|0);
 HEAPF32[$215>>2] = $214;
 $216 = (($0) + 36|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = (($poseWithScale) + 36|0);
 HEAPF32[$218>>2] = $217;
 $219 = (($0) + 40|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = (($poseWithScale) + 40|0);
 HEAPF32[$221>>2] = $220;
 $222 = (($0) + 44|0);
 $223 = Math_fround(HEAPF32[$222>>2]);
 $224 = (($poseWithScale) + 44|0);
 HEAPF32[$224>>2] = $223;
 $225 = Math_fround(HEAPF32[$182>>2]);
 $226 = Math_fround(Math_fround(1.0) / $225);
 $227 = Math_fround(HEAPF32[$185>>2]);
 $228 = Math_fround(Math_fround(1.0) / $227);
 $229 = (($geom) + 12|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = Math_fround(Math_fround(1.0) / $230);
 HEAPF32[$1>>2] = $226;
 $232 = (($1) + 4|0);
 HEAPF32[$232>>2] = $228;
 $233 = (($1) + 8|0);
 HEAPF32[$233>>2] = $231;
 $234 = (($geom) + 16|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = (($1) + 12|0);
 HEAPF32[$236>>2] = $235;
 $237 = (($geom) + 20|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = (($1) + 16|0);
 HEAPF32[$239>>2] = $238;
 $240 = (($geom) + 24|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = (($1) + 20|0);
 HEAPF32[$242>>2] = $241;
 $243 = (($geom) + 28|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = (($1) + 24|0);
 HEAPF32[$245>>2] = $244;
 $246 = (($1) + 12|0);
 __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$1,$246);
 $247 = Math_fround(HEAPF32[$sweepOrigin>>2]);
 $248 = Math_fround(HEAPF32[$sweepExtents>>2]);
 $249 = Math_fround($247 - $248);
 $250 = Math_fround(HEAPF32[$129>>2]);
 $251 = Math_fround(HEAPF32[$180>>2]);
 $252 = Math_fround($250 - $251);
 $253 = Math_fround(HEAPF32[$130>>2]);
 $254 = Math_fround(HEAPF32[$181>>2]);
 $255 = Math_fround($253 - $254);
 $256 = Math_fround($247 + $248);
 $257 = Math_fround($250 + $251);
 $258 = Math_fround($253 + $254);
 $259 = Math_fround($249 + $256);
 $260 = Math_fround($252 + $257);
 $261 = Math_fround($255 + $258);
 $262 = Math_fround($259 * Math_fround(0.5));
 $263 = Math_fround($260 * Math_fround(0.5));
 $264 = Math_fround($261 * Math_fround(0.5));
 $265 = Math_fround(HEAPF32[$meshScaling>>2]);
 $266 = Math_fround($262 * $265);
 $267 = (($meshScaling) + 4|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = Math_fround($262 * $268);
 $270 = (($meshScaling) + 8|0);
 $271 = Math_fround(HEAPF32[$270>>2]);
 $272 = Math_fround($262 * $271);
 $273 = (($meshScaling) + 12|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 $275 = Math_fround($263 * $274);
 $276 = (($meshScaling) + 16|0);
 $277 = Math_fround(HEAPF32[$276>>2]);
 $278 = Math_fround($263 * $277);
 $279 = (($meshScaling) + 20|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = Math_fround($263 * $280);
 $282 = Math_fround($266 + $275);
 $283 = Math_fround($269 + $278);
 $284 = Math_fround($272 + $281);
 $285 = (($meshScaling) + 24|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = Math_fround($264 * $286);
 $288 = (($meshScaling) + 28|0);
 $289 = Math_fround(HEAPF32[$288>>2]);
 $290 = Math_fround($264 * $289);
 $291 = (($meshScaling) + 32|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = Math_fround($264 * $292);
 $294 = Math_fround($282 + $287);
 $295 = Math_fround($283 + $290);
 $296 = Math_fround($284 + $293);
 $297 = Math_fround($256 - $249);
 $298 = Math_fround($257 - $252);
 $299 = Math_fround($258 - $255);
 $300 = Math_fround($297 * Math_fround(0.5));
 $301 = Math_fround($298 * Math_fround(0.5));
 $302 = Math_fround($299 * Math_fround(0.5));
 $303 = Math_fround($300 * $265);
 $304 = Math_fround($300 * $268);
 $305 = Math_fround($300 * $271);
 $306 = Math_fround($301 * $274);
 $307 = Math_fround($301 * $277);
 $308 = Math_fround($301 * $280);
 $309 = Math_fround($302 * $286);
 $310 = Math_fround($302 * $289);
 $311 = Math_fround($302 * $292);
 $fabsf$i$i4$i$i$i1 = (Math_fround(Math_abs((Math_fround($303)))));
 $fabsf$i$i5$i$i$i2 = (Math_fround(Math_abs((Math_fround($306)))));
 $312 = Math_fround($fabsf$i$i4$i$i$i1 + $fabsf$i$i5$i$i$i2);
 $fabsf$i$i6$i$i$i3 = (Math_fround(Math_abs((Math_fround($309)))));
 $313 = Math_fround($312 + $fabsf$i$i6$i$i$i3);
 $fabsf$i$i7$i$i$i4 = (Math_fround(Math_abs((Math_fround($304)))));
 $fabsf$i$i8$i$i$i5 = (Math_fround(Math_abs((Math_fround($307)))));
 $314 = Math_fround($fabsf$i$i7$i$i$i4 + $fabsf$i$i8$i$i$i5);
 $fabsf$i$i3$i$i$i6 = (Math_fround(Math_abs((Math_fround($310)))));
 $315 = Math_fround($314 + $fabsf$i$i3$i$i$i6);
 $fabsf$i$i2$i$i$i7 = (Math_fround(Math_abs((Math_fround($305)))));
 $fabsf$i$i1$i$i$i8 = (Math_fround(Math_abs((Math_fround($308)))));
 $316 = Math_fround($fabsf$i$i2$i$i$i7 + $fabsf$i$i1$i$i$i8);
 $fabsf$i$i$i$i$i9 = (Math_fround(Math_abs((Math_fround($311)))));
 $317 = Math_fround($316 + $fabsf$i$i$i$i$i9);
 $318 = Math_fround($294 - $313);
 $319 = Math_fround($295 - $315);
 $320 = Math_fround($296 - $317);
 $321 = Math_fround($294 + $313);
 $322 = Math_fround($295 + $315);
 $323 = Math_fround($296 + $317);
 $324 = Math_fround(HEAPF32[$sweepDir>>2]);
 $325 = Math_fround($324 * $distance);
 $326 = Math_fround(HEAPF32[$168>>2]);
 $327 = Math_fround($326 * $distance);
 $328 = Math_fround(HEAPF32[$169>>2]);
 $329 = Math_fround($328 * $distance);
 $330 = Math_fround($247 + $325);
 $331 = Math_fround($250 + $327);
 $332 = Math_fround($253 + $329);
 $333 = Math_fround($330 - $248);
 $334 = Math_fround($331 - $251);
 $335 = Math_fround($332 - $254);
 $336 = Math_fround($248 + $330);
 $337 = Math_fround($251 + $331);
 $338 = Math_fround($254 + $332);
 $339 = Math_fround($333 + $336);
 $340 = Math_fround($334 + $337);
 $341 = Math_fround($335 + $338);
 $342 = Math_fround($339 * Math_fround(0.5));
 $343 = Math_fround($340 * Math_fround(0.5));
 $344 = Math_fround($341 * Math_fround(0.5));
 $345 = Math_fround($265 * $342);
 $346 = Math_fround($268 * $342);
 $347 = Math_fround($271 * $342);
 $348 = Math_fround($274 * $343);
 $349 = Math_fround($277 * $343);
 $350 = Math_fround($280 * $343);
 $351 = Math_fround($345 + $348);
 $352 = Math_fround($346 + $349);
 $353 = Math_fround($347 + $350);
 $354 = Math_fround($286 * $344);
 $355 = Math_fround($289 * $344);
 $356 = Math_fround($292 * $344);
 $357 = Math_fround($351 + $354);
 $358 = Math_fround($352 + $355);
 $359 = Math_fround($353 + $356);
 $360 = Math_fround($336 - $333);
 $361 = Math_fround($337 - $334);
 $362 = Math_fround($338 - $335);
 $363 = Math_fround($360 * Math_fround(0.5));
 $364 = Math_fround($361 * Math_fround(0.5));
 $365 = Math_fround($362 * Math_fround(0.5));
 $366 = Math_fround($265 * $363);
 $367 = Math_fround($268 * $363);
 $368 = Math_fround($271 * $363);
 $369 = Math_fround($274 * $364);
 $370 = Math_fround($277 * $364);
 $371 = Math_fround($280 * $364);
 $372 = Math_fround($286 * $365);
 $373 = Math_fround($289 * $365);
 $374 = Math_fround($292 * $365);
 $fabsf$i$i4$i$i$i = (Math_fround(Math_abs((Math_fround($366)))));
 $fabsf$i$i5$i$i$i = (Math_fround(Math_abs((Math_fround($369)))));
 $375 = Math_fround($fabsf$i$i4$i$i$i + $fabsf$i$i5$i$i$i);
 $fabsf$i$i6$i$i$i = (Math_fround(Math_abs((Math_fround($372)))));
 $376 = Math_fround($375 + $fabsf$i$i6$i$i$i);
 $fabsf$i$i7$i$i$i = (Math_fround(Math_abs((Math_fround($367)))));
 $fabsf$i$i8$i$i$i = (Math_fround(Math_abs((Math_fround($370)))));
 $377 = Math_fround($fabsf$i$i7$i$i$i + $fabsf$i$i8$i$i$i);
 $fabsf$i$i3$i$i$i = (Math_fround(Math_abs((Math_fround($373)))));
 $378 = Math_fround($377 + $fabsf$i$i3$i$i$i);
 $fabsf$i$i2$i$i$i = (Math_fround(Math_abs((Math_fround($368)))));
 $fabsf$i$i1$i$i$i = (Math_fround(Math_abs((Math_fround($371)))));
 $379 = Math_fround($fabsf$i$i2$i$i$i + $fabsf$i$i1$i$i$i);
 $fabsf$i$i$i$i$i = (Math_fround(Math_abs((Math_fround($374)))));
 $380 = Math_fround($379 + $fabsf$i$i$i$i$i);
 $381 = Math_fround($357 - $376);
 $382 = Math_fround($358 - $378);
 $383 = Math_fround($359 - $380);
 $384 = Math_fround($376 + $357);
 $385 = Math_fround($358 + $378);
 $386 = Math_fround($359 + $380);
 $387 = Math_fround($318 + $321);
 $388 = Math_fround($319 + $322);
 $389 = Math_fround($320 + $323);
 $390 = Math_fround($387 * Math_fround(0.5));
 $391 = Math_fround($388 * Math_fround(0.5));
 $392 = Math_fround($389 * Math_fround(0.5));
 HEAPF32[$sweepOrigin>>2] = $390;
 HEAPF32[$129>>2] = $391;
 HEAPF32[$130>>2] = $392;
 $393 = Math_fround($321 - $318);
 $394 = Math_fround($322 - $319);
 $395 = Math_fround($323 - $320);
 $396 = Math_fround($393 * Math_fround(0.5));
 $397 = Math_fround($394 * Math_fround(0.5));
 $398 = Math_fround($395 * Math_fround(0.5));
 HEAPF32[$sweepExtents>>2] = $396;
 HEAPF32[$180>>2] = $397;
 HEAPF32[$181>>2] = $398;
 $399 = Math_fround($381 + $384);
 $400 = Math_fround($382 + $385);
 $401 = Math_fround($383 + $386);
 $402 = Math_fround($399 * Math_fround(0.5));
 $403 = Math_fround($400 * Math_fround(0.5));
 $404 = Math_fround($401 * Math_fround(0.5));
 $405 = Math_fround($402 - $390);
 $406 = Math_fround($403 - $391);
 $407 = Math_fround($404 - $392);
 HEAPF32[$sweepDir>>2] = $405;
 HEAPF32[$168>>2] = $406;
 HEAPF32[$169>>2] = $407;
 $408 = Math_fround($405 * $405);
 $409 = Math_fround($406 * $406);
 $410 = Math_fround($408 + $409);
 $411 = Math_fround($407 * $407);
 $412 = Math_fround($411 + $410);
 $413 = (Math_fround(Math_sqrt((Math_fround($412)))));
 $414 = $413 < Math_fround(9.99999968265522538896E-21);
 if ($414) {
  $distance1$0 = Math_fround(0.0);
  $460 = (($callback) + 4|0);
  HEAP32[$460>>2] = 2;
  HEAP32[$callback>>2] = ((552704 + 8|0));
  $461 = (($callback) + 8|0);
  HEAP32[$461>>2] = $sweepHit;
  $462 = (($callback) + 12|0);
  HEAP32[$462>>2] = $poseWithScale;
  $463 = (($callback) + 16|0);
  HEAPF32[$463>>2] = $distance;
  $464 = (($callback) + 20|0);
  HEAPF32[$464>>2] = $distance;
  $465 = (($callback) + 24|0);
  $$lobit57 = ($7&255) >>> 1;
  $$lobit = ($9&65535) >>> 7;
  $466 = $$lobit&255;
  $467 = $$lobit57 | $466;
  HEAP8[$465>>0] = $467;
  $468 = (($callback) + 28|0);
  HEAP32[$468>>2] = $inflatedCapsule;
  $469 = (($callback) + 32|0);
  HEAP32[$469>>2] = $unitDir;
  $470 = (($callback) + 36|0);
  HEAP32[$470>>2] = $hintFlags;
  $471 = (($callback) + 40|0);
  HEAP8[$471>>0] = 0;
  $472 = (($callback) + 41|0);
  HEAP8[$472>>0] = 0;
  $473 = (($sweepHit) + 40|0);
  HEAPF32[$473>>2] = Math_fround(3.40282346638528859812E+38);
  __ZN5physx2Gu15MeshRayCollider7collideILi1ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($sweepOrigin,$sweepDir,$distance1$0,1,$data,$callback,$sweepExtents);
  $474 = (__ZN20SweepCapsuleCallback8finalizeERN5physx10PxSweepHitERKNS0_2Gu7CapsuleERKNS0_22PxTriangleMeshGeometryERKNS0_11PxTransformEbf($callback,$sweepHit,$inflatedCapsule,$geom,$pose,$$,$distance)|0);
  STACKTOP = sp;return ($474|0);
 }
 $415 = Math_fround(Math_fround(1.0) / $413);
 $416 = Math_fround($405 * $415);
 HEAPF32[$sweepDir>>2] = $416;
 $417 = Math_fround($406 * $415);
 HEAPF32[$168>>2] = $417;
 $418 = Math_fround($407 * $415);
 HEAPF32[$169>>2] = $418;
 $distance1$0 = $413;
 $460 = (($callback) + 4|0);
 HEAP32[$460>>2] = 2;
 HEAP32[$callback>>2] = ((552704 + 8|0));
 $461 = (($callback) + 8|0);
 HEAP32[$461>>2] = $sweepHit;
 $462 = (($callback) + 12|0);
 HEAP32[$462>>2] = $poseWithScale;
 $463 = (($callback) + 16|0);
 HEAPF32[$463>>2] = $distance;
 $464 = (($callback) + 20|0);
 HEAPF32[$464>>2] = $distance;
 $465 = (($callback) + 24|0);
 $$lobit57 = ($7&255) >>> 1;
 $$lobit = ($9&65535) >>> 7;
 $466 = $$lobit&255;
 $467 = $$lobit57 | $466;
 HEAP8[$465>>0] = $467;
 $468 = (($callback) + 28|0);
 HEAP32[$468>>2] = $inflatedCapsule;
 $469 = (($callback) + 32|0);
 HEAP32[$469>>2] = $unitDir;
 $470 = (($callback) + 36|0);
 HEAP32[$470>>2] = $hintFlags;
 $471 = (($callback) + 40|0);
 HEAP8[$471>>0] = 0;
 $472 = (($callback) + 41|0);
 HEAP8[$472>>0] = 0;
 $473 = (($sweepHit) + 40|0);
 HEAPF32[$473>>2] = Math_fround(3.40282346638528859812E+38);
 __ZN5physx2Gu15MeshRayCollider7collideILi1ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($sweepOrigin,$sweepDir,$distance1$0,1,$data,$callback,$sweepExtents);
 $474 = (__ZN20SweepCapsuleCallback8finalizeERN5physx10PxSweepHitERKNS0_2Gu7CapsuleERKNS0_22PxTriangleMeshGeometryERKNS0_11PxTransformEbf($callback,$sweepHit,$inflatedCapsule,$geom,$pose,$$,$distance)|0);
 STACKTOP = sp;return ($474|0);
}
function __ZN20SweepCapsuleCallback8finalizeERN5physx10PxSweepHitERKNS0_2Gu7CapsuleERKNS0_22PxTriangleMeshGeometryERKNS0_11PxTransformEbf($this,$sweepHit,$lss,$triMeshGeom,$pose,$isDoubleSided,$distance) {
 $this = $this|0;
 $sweepHit = $sweepHit|0;
 $lss = $lss|0;
 $triMeshGeom = $triMeshGeom|0;
 $pose = $pose|0;
 $isDoubleSided = $isDoubleSided|0;
 $distance = Math_fround($distance);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $capsuleV = 0, $radius$sroa$1 = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $zero$sroa$1$i$i$i = sp + 172|0;
 $0 = sp;
 $radius$sroa$1 = sp + 160|0;
 $capsuleV = sp + 16|0;
 $1 = (($this) + 40|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 41|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $87 = (($sweepHit) + 12|0);
  HEAP16[$87>>1] = 7;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP16[$8>>1]|0;
 $10 = $9 & 512;
 $11 = ($10<<16>>16)==(0);
 if ($11) {
  $72 = (($sweepHit) + 40|0);
  HEAPF32[$72>>2] = Math_fround(0.0);
  $73 = (($this) + 32|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround(-$75);
  $77 = (($74) + 4|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround(-$78);
  $80 = (($74) + 8|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround(-$81);
  $83 = (($sweepHit) + 28|0);
  HEAPF32[$83>>2] = $76;
  $84 = (($sweepHit) + 32|0);
  HEAPF32[$84>>2] = $79;
  $85 = (($sweepHit) + 36|0);
  HEAPF32[$85>>2] = $82;
  $86 = (($sweepHit) + 12|0);
  HEAP16[$86>>1] = 6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($13) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($13) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($13) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($13) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($13) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($lss) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($capsuleV) + 64|0);
 $28 = (($capsuleV) + 80|0);
 HEAP32[$28>>2] = 4;
 $29 = (($capsuleV) + 16|0);
 $30 = (($capsuleV) + 20|0);
 $31 = (($capsuleV) + 32|0);
 $32 = (($capsuleV) + 36|0);
 $33 = (($capsuleV) + 48|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($capsuleV) + 52|0);
 ;HEAP32[$34+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$27+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$0+12>>2]|0;
 $35 = (($capsuleV) + 128|0);
 HEAPF32[$35>>2] = $26;
 $36 = (($capsuleV) + 132|0);
 ;HEAP32[$36+0>>2]=HEAP32[$radius$sroa$1+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$radius$sroa$1+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$radius$sroa$1+8>>2]|0;
 $37 = (($capsuleV) + 96|0);
 HEAPF32[$37>>2] = $14;
 $38 = (($capsuleV) + 100|0);
 HEAPF32[$38>>2] = $16;
 $39 = (($capsuleV) + 104|0);
 HEAPF32[$39>>2] = $18;
 $40 = (($capsuleV) + 108|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($capsuleV) + 112|0);
 HEAPF32[$41>>2] = $20;
 $42 = (($capsuleV) + 116|0);
 HEAPF32[$42>>2] = $22;
 $43 = (($capsuleV) + 120|0);
 HEAPF32[$43>>2] = $24;
 $44 = (($capsuleV) + 124|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 HEAPF32[$29>>2] = $26;
 ;HEAP32[$30+0>>2]=HEAP32[$radius$sroa$1+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$radius$sroa$1+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$radius$sroa$1+8>>2]|0;
 HEAPF32[$31>>2] = $26;
 ;HEAP32[$32+0>>2]=HEAP32[$radius$sroa$1+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$radius$sroa$1+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$radius$sroa$1+8>>2]|0;
 $45 = Math_fround($14 + $20);
 $46 = Math_fround($16 + $22);
 $47 = Math_fround($18 + $24);
 $48 = Math_fround($45 * Math_fround(0.5));
 $49 = Math_fround($46 * Math_fround(0.5));
 $50 = Math_fround($47 * Math_fround(0.5));
 HEAPF32[$capsuleV>>2] = $48;
 $51 = (($capsuleV) + 4|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($capsuleV) + 8|0);
 HEAPF32[$52>>2] = $50;
 $53 = (($capsuleV) + 12|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($13) + 24|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (__ZN5physx2Gu30computeCapsule_TriangleMeshMTDERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformERNS0_8CapsuleVEffbRNS_10PxSweepHitE($triMeshGeom,$pose,$capsuleV,$55,$distance,$isDoubleSided,$sweepHit)|0);
 $57 = (($sweepHit) + 12|0);
 HEAP16[$57>>1] = 6;
 if ($56) {
  HEAP16[$57>>1] = 7;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $58 = (($sweepHit) + 40|0);
  HEAPF32[$58>>2] = Math_fround(0.0);
  $59 = (($this) + 32|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround(-$61);
  $63 = (($60) + 4|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround(-$64);
  $66 = (($60) + 8|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround(-$67);
  $69 = (($sweepHit) + 28|0);
  HEAPF32[$69>>2] = $62;
  $70 = (($sweepHit) + 32|0);
  HEAPF32[$70>>2] = $65;
  $71 = (($sweepHit) + 36|0);
  HEAPF32[$71>>2] = $68;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN20SweepCapsuleCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z17sweepBox_MeshGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$ = 0, $$0 = 0, $$lobit = 0, $$lobit169 = 0, $$phi$trans$insert170 = 0, $$phi$trans$insert172 = 0, $$phi$trans$insert174 = 0, $$phi$trans$insert176 = 0, $$phi$trans$insert178 = 0, $$phi$trans$insert180 = 0, $$phi$trans$insert182 = 0, $$phi$trans$insert184 = 0, $$pre = Math_fround(0), $$pre171 = Math_fround(0), $$pre173 = Math_fround(0), $$pre175 = Math_fround(0), $$pre177 = Math_fround(0), $$pre179 = Math_fround(0), $$pre181 = Math_fround(0), $$pre183 = Math_fround(0);
 var $$pre185 = Math_fround(0), $$pre187 = Math_fround(0), $$pre189 = Math_fround(0), $$pre191 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0);
 var $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = Math_fround(0), $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0);
 var $103 = Math_fround(0), $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = 0, $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0);
 var $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0);
 var $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0;
 var $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = 0, $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0;
 var $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0;
 var $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = Math_fround(0), $456 = 0;
 var $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = 0, $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = 0;
 var $475 = Math_fround(0), $476 = 0, $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0);
 var $493 = 0, $494 = 0, $495 = 0, $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = 0, $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0);
 var $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0);
 var $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = Math_fround(0), $535 = 0, $536 = Math_fround(0), $537 = Math_fround(0), $538 = 0, $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0);
 var $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = 0, $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0);
 var $565 = Math_fround(0), $566 = Math_fround(0), $567 = 0, $568 = 0, $569 = 0, $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0);
 var $583 = Math_fround(0), $584 = Math_fround(0), $585 = 0, $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0);
 var $619 = Math_fround(0), $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0);
 var $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0);
 var $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0);
 var $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0);
 var $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0;
 var $709 = 0, $71 = Math_fround(0), $710 = 0, $711 = 0, $712 = 0, $713 = Math_fround(0), $714 = 0, $715 = 0, $716 = Math_fround(0), $717 = 0, $718 = 0, $719 = Math_fround(0), $72 = Math_fround(0), $720 = 0, $721 = 0, $722 = Math_fround(0), $723 = 0, $724 = Math_fround(0), $725 = 0, $726 = Math_fround(0);
 var $727 = 0, $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = 0, $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = 0, $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0);
 var $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = 0, $75 = Math_fround(0), $750 = 0, $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = Math_fround(0), $760 = 0, $761 = 0, $762 = 0;
 var $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = Math_fround(0), $780 = 0;
 var $781 = 0, $782 = Math_fround(0), $783 = 0, $784 = Math_fround(0), $785 = 0, $786 = Math_fround(0), $787 = 0, $788 = Math_fround(0), $789 = 0, $79 = Math_fround(0), $790 = Math_fround(0), $791 = 0, $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = 0, $798 = 0, $799 = 0;
 var $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = Math_fround(0), $804 = 0, $805 = Math_fround(0), $806 = 0, $807 = Math_fround(0), $808 = 0, $809 = Math_fround(0), $81 = Math_fround(0), $810 = 0, $811 = Math_fround(0), $812 = 0, $813 = Math_fround(0), $814 = 0, $815 = 0, $816 = 0;
 var $817 = 0, $818 = 0, $819 = 0, $82 = Math_fround(0), $820 = 0, $821 = 0, $822 = 0, $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = 0, $83 = Math_fround(0), $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = Math_fround(0);
 var $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = Math_fround(0), $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = Math_fround(0), $850 = 0, $851 = Math_fround(0), $852 = 0;
 var $853 = Math_fround(0), $854 = Math_fround(0), $855 = 0, $856 = Math_fround(0), $857 = Math_fround(0), $858 = 0, $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = 0, $862 = Math_fround(0), $863 = 0, $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = 0, $87 = Math_fround(0), $870 = 0;
 var $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = Math_fround(0), $880 = 0, $881 = 0, $882 = Math_fround(0), $883 = 0, $884 = 0, $885 = Math_fround(0), $886 = 0, $887 = 0, $888 = Math_fround(0), $889 = 0;
 var $89 = Math_fround(0), $890 = 0, $891 = Math_fround(0), $892 = Math_fround(0), $893 = 0, $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = 0, $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0), $902 = 0, $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0);
 var $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = 0, $919 = Math_fround(0), $92 = Math_fround(0), $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0);
 var $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = Math_fround(0), $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = Math_fround(0), $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0);
 var $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = Math_fround(0), $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = 0, $96 = Math_fround(0), $960 = Math_fround(0);
 var $961 = 0, $962 = Math_fround(0), $963 = 0, $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0);
 var $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0, $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0);
 var $998 = Math_fround(0), $999 = Math_fround(0), $boxTransform = 0, $callback = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i10 = Math_fround(0), $fabsf$i$i$i13 = Math_fround(0), $fabsf$i$i$i16 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i11 = Math_fround(0), $fabsf$i$i1$i14 = Math_fround(0), $fabsf$i$i1$i17 = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i2$i12 = Math_fround(0), $fabsf$i$i2$i15 = Math_fround(0), $fabsf$i$i2$i18 = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i6$i = Math_fround(0);
 var $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $hmd = 0, $invRot$i = 0, $localDir = 0, $localDirDist = 0, $meshSpaceOrigin = 0, $meshToWorldSkew_Rot = 0, $oneOverMotion = 0, $sweptAABBMeshSpaceExtents = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0;
 $invRot$i = sp + 480|0;
 $sweptAABBMeshSpaceExtents = sp + 468|0;
 $meshSpaceOrigin = sp + 456|0;
 $0 = sp + 408|0;
 $meshToWorldSkew_Rot = sp + 360|0;
 $1 = sp + 296|0;
 $hmd = sp + 284|0;
 $boxTransform = sp + 244|0;
 $localDir = sp + 232|0;
 $localDirDist = sp + 220|0;
 $callback = sp;
 $2 = sp + 208|0;
 $oneOverMotion = sp + 272|0;
 $3 = (($geom) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = $4 == Math_fround(1.0);
 $6 = (($geom) + 8|0);
 if ($5) {
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = $7 == Math_fround(1.0);
  if ($8) {
   $9 = (($geom) + 12|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = $10 == Math_fround(1.0);
   if ($11) {
    $12 = Math_fround(HEAPF32[$pose>>2]);
    $13 = Math_fround($12 + $12);
    $14 = (($pose) + 4|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = Math_fround($15 + $15);
    $17 = (($pose) + 8|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = Math_fround($18 + $18);
    $20 = (($pose) + 12|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = Math_fround($13 * $21);
    $23 = Math_fround($16 * $21);
    $24 = Math_fround($21 * $19);
    $25 = Math_fround($12 * $13);
    $26 = Math_fround($12 * $16);
    $27 = Math_fround($12 * $19);
    $28 = Math_fround($15 * $16);
    $29 = Math_fround($15 * $19);
    $30 = Math_fround($18 * $19);
    $31 = Math_fround(Math_fround(1.0) - $28);
    $32 = Math_fround($31 - $30);
    $33 = Math_fround($26 + $24);
    $34 = Math_fround($27 - $23);
    $35 = Math_fround($26 - $24);
    $36 = Math_fround(Math_fround(1.0) - $25);
    $37 = Math_fround($36 - $30);
    $38 = Math_fround($29 + $22);
    $39 = Math_fround($27 + $23);
    $40 = Math_fround($29 - $22);
    $41 = Math_fround($36 - $28);
    $42 = (($pose) + 16|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = (($pose) + 20|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = (($pose) + 24|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = Math_fround(-$12);
    $49 = Math_fround(-$15);
    $50 = Math_fround(-$18);
    $51 = Math_fround($48 - $12);
    $52 = Math_fround($49 - $15);
    $53 = Math_fround($50 - $18);
    $54 = Math_fround($51 * $48);
    $55 = Math_fround($52 * $49);
    $56 = Math_fround($53 * $50);
    $57 = Math_fround($51 * $49);
    $58 = Math_fround($51 * $50);
    $59 = Math_fround($51 * $21);
    $60 = Math_fround($52 * $50);
    $61 = Math_fround($52 * $21);
    $62 = Math_fround($21 * $53);
    $63 = Math_fround(Math_fround(1.0) - $55);
    $64 = Math_fround($63 - $56);
    $65 = Math_fround($57 + $62);
    $66 = Math_fround($58 - $61);
    $67 = Math_fround($57 - $62);
    $68 = Math_fround(Math_fround(1.0) - $54);
    $69 = Math_fround($68 - $56);
    $70 = Math_fround($60 + $59);
    $71 = Math_fround($58 + $61);
    $72 = Math_fround($60 - $59);
    $73 = Math_fround($68 - $55);
    $74 = (($box) + 36|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = Math_fround($75 - $43);
    $77 = (($box) + 40|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = Math_fround($78 - $45);
    $80 = (($box) + 44|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = Math_fround($81 - $47);
    $83 = Math_fround($76 * $64);
    $84 = Math_fround($76 * $65);
    $85 = Math_fround($66 * $76);
    $86 = Math_fround($67 * $79);
    $87 = Math_fround($69 * $79);
    $88 = Math_fround($70 * $79);
    $89 = Math_fround($83 + $86);
    $90 = Math_fround($84 + $87);
    $91 = Math_fround($85 + $88);
    $92 = Math_fround($71 * $82);
    $93 = Math_fround($72 * $82);
    $94 = Math_fround($73 * $82);
    $95 = Math_fround($89 + $92);
    $96 = Math_fround($90 + $93);
    $97 = Math_fround($91 + $94);
    HEAPF32[$meshSpaceOrigin>>2] = $95;
    $98 = (($meshSpaceOrigin) + 4|0);
    HEAPF32[$98>>2] = $96;
    $99 = (($meshSpaceOrigin) + 8|0);
    HEAPF32[$99>>2] = $97;
    $100 = Math_fround(HEAPF32[$unitDir>>2]);
    $101 = Math_fround($64 * $100);
    $102 = Math_fround($65 * $100);
    $103 = Math_fround($66 * $100);
    $104 = (($unitDir) + 4|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = Math_fround($67 * $105);
    $107 = Math_fround($69 * $105);
    $108 = Math_fround($70 * $105);
    $109 = Math_fround($101 + $106);
    $110 = Math_fround($102 + $107);
    $111 = Math_fround($103 + $108);
    $112 = (($unitDir) + 8|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = Math_fround($71 * $113);
    $115 = Math_fround($72 * $113);
    $116 = Math_fround($73 * $113);
    $117 = Math_fround($109 + $114);
    $118 = Math_fround($110 + $115);
    $119 = Math_fround($111 + $116);
    $120 = Math_fround($117 * $distance);
    $121 = Math_fround($118 * $distance);
    $122 = Math_fround($119 * $distance);
    $123 = Math_fround(HEAPF32[$box>>2]);
    $124 = Math_fround($64 * $123);
    $125 = Math_fround($65 * $123);
    $126 = Math_fround($66 * $123);
    $127 = (($box) + 4|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $129 = Math_fround($67 * $128);
    $130 = Math_fround($69 * $128);
    $131 = Math_fround($70 * $128);
    $132 = Math_fround($124 + $129);
    $133 = Math_fround($125 + $130);
    $134 = Math_fround($126 + $131);
    $135 = (($box) + 8|0);
    $136 = Math_fround(HEAPF32[$135>>2]);
    $137 = Math_fround($71 * $136);
    $138 = Math_fround($72 * $136);
    $139 = Math_fround($73 * $136);
    $140 = Math_fround($132 + $137);
    $141 = Math_fround($133 + $138);
    $142 = Math_fround($134 + $139);
    $143 = (($box) + 12|0);
    $144 = Math_fround(HEAPF32[$143>>2]);
    $145 = Math_fround($64 * $144);
    $146 = Math_fround($65 * $144);
    $147 = Math_fround($66 * $144);
    $148 = (($box) + 16|0);
    $149 = Math_fround(HEAPF32[$148>>2]);
    $150 = Math_fround($67 * $149);
    $151 = Math_fround($69 * $149);
    $152 = Math_fround($70 * $149);
    $153 = Math_fround($145 + $150);
    $154 = Math_fround($146 + $151);
    $155 = Math_fround($147 + $152);
    $156 = (($box) + 20|0);
    $157 = Math_fround(HEAPF32[$156>>2]);
    $158 = Math_fround($71 * $157);
    $159 = Math_fround($72 * $157);
    $160 = Math_fround($73 * $157);
    $161 = Math_fround($153 + $158);
    $162 = Math_fround($154 + $159);
    $163 = Math_fround($155 + $160);
    $164 = (($box) + 24|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = Math_fround($64 * $165);
    $167 = Math_fround($65 * $165);
    $168 = Math_fround($66 * $165);
    $169 = (($box) + 28|0);
    $170 = Math_fround(HEAPF32[$169>>2]);
    $171 = Math_fround($67 * $170);
    $172 = Math_fround($69 * $170);
    $173 = Math_fround($70 * $170);
    $174 = Math_fround($166 + $171);
    $175 = Math_fround($167 + $172);
    $176 = Math_fround($168 + $173);
    $177 = (($box) + 32|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = Math_fround($71 * $178);
    $180 = Math_fround($72 * $178);
    $181 = Math_fround($73 * $178);
    $182 = Math_fround($174 + $179);
    $183 = Math_fround($175 + $180);
    $184 = Math_fround($176 + $181);
    $fabsf$i$i$i13 = (Math_fround(Math_abs((Math_fround($140)))));
    $fabsf$i$i1$i14 = (Math_fround(Math_abs((Math_fround($141)))));
    $fabsf$i$i2$i15 = (Math_fround(Math_abs((Math_fround($142)))));
    $185 = (($box) + 48|0);
    $186 = Math_fround(HEAPF32[$185>>2]);
    $187 = Math_fround($fabsf$i$i$i13 * $186);
    $188 = Math_fround($fabsf$i$i1$i14 * $186);
    $189 = Math_fround($fabsf$i$i2$i15 * $186);
    $fabsf$i$i$i16 = (Math_fround(Math_abs((Math_fround($161)))));
    $fabsf$i$i1$i17 = (Math_fround(Math_abs((Math_fround($162)))));
    $fabsf$i$i2$i18 = (Math_fround(Math_abs((Math_fround($163)))));
    $190 = (($box) + 52|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = Math_fround($fabsf$i$i$i16 * $191);
    $193 = Math_fround($fabsf$i$i1$i17 * $191);
    $194 = Math_fround($fabsf$i$i2$i18 * $191);
    $195 = Math_fround($187 + $192);
    $196 = Math_fround($188 + $193);
    $197 = Math_fround($189 + $194);
    $fabsf$i$i$i10 = (Math_fround(Math_abs((Math_fround($182)))));
    $fabsf$i$i1$i11 = (Math_fround(Math_abs((Math_fround($183)))));
    $fabsf$i$i2$i12 = (Math_fround(Math_abs((Math_fround($184)))));
    $198 = (($box) + 56|0);
    $199 = Math_fround(HEAPF32[$198>>2]);
    $200 = Math_fround($fabsf$i$i$i10 * $199);
    $201 = Math_fround($fabsf$i$i1$i11 * $199);
    $202 = Math_fround($fabsf$i$i2$i12 * $199);
    $203 = Math_fround($195 + $200);
    $204 = Math_fround($196 + $201);
    $205 = Math_fround($197 + $202);
    HEAPF32[$sweptAABBMeshSpaceExtents>>2] = $203;
    $206 = (($sweptAABBMeshSpaceExtents) + 4|0);
    HEAPF32[$206>>2] = $204;
    $207 = (($sweptAABBMeshSpaceExtents) + 8|0);
    HEAPF32[$207>>2] = $205;
    $$pre187 = Math_fround(HEAPF32[$74>>2]);
    $$pre189 = Math_fround(HEAPF32[$77>>2]);
    $$pre191 = Math_fround(HEAPF32[$80>>2]);
    $557 = $203;$560 = $204;$563 = $205;$577 = $120;$579 = $121;$582 = $122;$591 = $$pre187;$593 = $$pre189;$595 = $$pre191;$597 = $123;$599 = $128;$602 = $136;$605 = $144;$607 = $149;$610 = $157;$613 = $165;$615 = $170;$618 = $178;$628 = $32;$632 = $33;$639 = $34;$646 = $35;$650 = $37;$657 = $38;$664 = $39;$668 = $40;$675 = $41;$682 = $43;$686 = $45;$693 = $47;
   } else {
    label = 5;
   }
  } else {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  __ZN5physxmlERKNS_11PxTransformERKNS_11PxMeshScaleE($0,$pose,$3);
  $208 = Math_fround(HEAPF32[$0>>2]);
  $209 = (($0) + 4|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $211 = (($0) + 8|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $213 = (($0) + 12|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = (($0) + 16|0);
  $216 = Math_fround(HEAPF32[$215>>2]);
  $217 = (($0) + 20|0);
  $218 = Math_fround(HEAPF32[$217>>2]);
  $219 = (($0) + 24|0);
  $220 = Math_fround(HEAPF32[$219>>2]);
  $221 = (($0) + 28|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  $223 = (($0) + 32|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = (($0) + 36|0);
  $226 = Math_fround(HEAPF32[$225>>2]);
  $227 = (($0) + 40|0);
  $228 = Math_fround(HEAPF32[$227>>2]);
  $229 = (($0) + 44|0);
  $230 = Math_fround(HEAPF32[$229>>2]);
  $231 = Math_fround(HEAPF32[$pose>>2]);
  $232 = (($pose) + 4|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = (($pose) + 8|0);
  $235 = Math_fround(HEAPF32[$234>>2]);
  $236 = (($pose) + 12|0);
  $237 = Math_fround(HEAPF32[$236>>2]);
  $238 = Math_fround($231 + $231);
  $239 = Math_fround($233 + $233);
  $240 = Math_fround($235 + $235);
  $241 = Math_fround($231 * $238);
  $242 = Math_fround($233 * $239);
  $243 = Math_fround($235 * $240);
  $244 = Math_fround($238 * $233);
  $245 = Math_fround($238 * $235);
  $246 = Math_fround($238 * $237);
  $247 = Math_fround($239 * $235);
  $248 = Math_fround($239 * $237);
  $249 = Math_fround($240 * $237);
  $250 = Math_fround(Math_fround(1.0) - $242);
  $251 = Math_fround($250 - $243);
  $252 = Math_fround($244 + $249);
  $253 = Math_fround($245 - $248);
  $254 = Math_fround($244 - $249);
  $255 = Math_fround(Math_fround(1.0) - $241);
  $256 = Math_fround($255 - $243);
  $257 = Math_fround($247 + $246);
  $258 = Math_fround($245 + $248);
  $259 = Math_fround($247 - $246);
  $260 = Math_fround($255 - $242);
  $261 = (($geom) + 16|0);
  $262 = Math_fround(HEAPF32[$261>>2]);
  $263 = (($geom) + 20|0);
  $264 = Math_fround(HEAPF32[$263>>2]);
  $265 = (($geom) + 24|0);
  $266 = Math_fround(HEAPF32[$265>>2]);
  $267 = (($geom) + 28|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = Math_fround($262 + $262);
  $270 = Math_fround($264 + $264);
  $271 = Math_fround($266 + $266);
  $272 = Math_fround($262 * $269);
  $273 = Math_fround($264 * $270);
  $274 = Math_fround($266 * $271);
  $275 = Math_fround($269 * $264);
  $276 = Math_fround($269 * $266);
  $277 = Math_fround($269 * $268);
  $278 = Math_fround($270 * $266);
  $279 = Math_fround($270 * $268);
  $280 = Math_fround($271 * $268);
  $281 = Math_fround(Math_fround(1.0) - $273);
  $282 = Math_fround($281 - $274);
  $283 = Math_fround($275 + $280);
  $284 = Math_fround($276 - $279);
  $285 = Math_fround($275 - $280);
  $286 = Math_fround(Math_fround(1.0) - $272);
  $287 = Math_fround($286 - $274);
  $288 = Math_fround($278 + $277);
  $289 = Math_fround($276 + $279);
  $290 = Math_fround($278 - $277);
  $291 = Math_fround($286 - $273);
  $292 = Math_fround(HEAPF32[$3>>2]);
  $293 = Math_fround($292 * $282);
  $294 = Math_fround($292 * $285);
  $295 = Math_fround($292 * $289);
  $296 = Math_fround(HEAPF32[$6>>2]);
  $297 = Math_fround($283 * $296);
  $298 = Math_fround($287 * $296);
  $299 = Math_fround($290 * $296);
  $300 = (($geom) + 12|0);
  $301 = Math_fround(HEAPF32[$300>>2]);
  $302 = Math_fround($284 * $301);
  $303 = Math_fround($288 * $301);
  $304 = Math_fround($291 * $301);
  $305 = Math_fround($282 * $293);
  $306 = Math_fround($282 * $294);
  $307 = Math_fround($282 * $295);
  $308 = Math_fround($283 * $297);
  $309 = Math_fround($283 * $298);
  $310 = Math_fround($283 * $299);
  $311 = Math_fround($305 + $308);
  $312 = Math_fround($306 + $309);
  $313 = Math_fround($307 + $310);
  $314 = Math_fround($284 * $302);
  $315 = Math_fround($284 * $303);
  $316 = Math_fround($284 * $304);
  $317 = Math_fround($311 + $314);
  $318 = Math_fround($312 + $315);
  $319 = Math_fround($313 + $316);
  $320 = Math_fround($285 * $293);
  $321 = Math_fround($285 * $294);
  $322 = Math_fround($285 * $295);
  $323 = Math_fround($287 * $297);
  $324 = Math_fround($287 * $298);
  $325 = Math_fround($287 * $299);
  $326 = Math_fround($320 + $323);
  $327 = Math_fround($321 + $324);
  $328 = Math_fround($322 + $325);
  $329 = Math_fround($288 * $302);
  $330 = Math_fround($288 * $303);
  $331 = Math_fround($288 * $304);
  $332 = Math_fround($326 + $329);
  $333 = Math_fround($327 + $330);
  $334 = Math_fround($328 + $331);
  $335 = Math_fround($289 * $293);
  $336 = Math_fround($289 * $294);
  $337 = Math_fround($289 * $295);
  $338 = Math_fround($290 * $297);
  $339 = Math_fround($290 * $298);
  $340 = Math_fround($290 * $299);
  $341 = Math_fround($335 + $338);
  $342 = Math_fround($336 + $339);
  $343 = Math_fround($337 + $340);
  $344 = Math_fround($291 * $302);
  $345 = Math_fround($291 * $303);
  $346 = Math_fround($291 * $304);
  $347 = Math_fround($341 + $344);
  $348 = Math_fround($342 + $345);
  $349 = Math_fround($343 + $346);
  $350 = Math_fround($251 * $317);
  $351 = Math_fround($252 * $317);
  $352 = Math_fround($253 * $317);
  $353 = Math_fround($254 * $318);
  $354 = Math_fround($256 * $318);
  $355 = Math_fround($257 * $318);
  $356 = Math_fround($350 + $353);
  $357 = Math_fround($351 + $354);
  $358 = Math_fround($352 + $355);
  $359 = Math_fround($258 * $319);
  $360 = Math_fround($259 * $319);
  $361 = Math_fround($260 * $319);
  $362 = Math_fround($359 + $356);
  $363 = Math_fround($360 + $357);
  $364 = Math_fround($361 + $358);
  $365 = Math_fround($251 * $332);
  $366 = Math_fround($252 * $332);
  $367 = Math_fround($253 * $332);
  $368 = Math_fround($254 * $333);
  $369 = Math_fround($256 * $333);
  $370 = Math_fround($257 * $333);
  $371 = Math_fround($365 + $368);
  $372 = Math_fround($366 + $369);
  $373 = Math_fround($367 + $370);
  $374 = Math_fround($258 * $334);
  $375 = Math_fround($259 * $334);
  $376 = Math_fround($260 * $334);
  $377 = Math_fround($374 + $371);
  $378 = Math_fround($375 + $372);
  $379 = Math_fround($376 + $373);
  $380 = Math_fround($251 * $347);
  $381 = Math_fround($252 * $347);
  $382 = Math_fround($253 * $347);
  $383 = Math_fround($254 * $348);
  $384 = Math_fround($256 * $348);
  $385 = Math_fround($257 * $348);
  $386 = Math_fround($380 + $383);
  $387 = Math_fround($381 + $384);
  $388 = Math_fround($382 + $385);
  $389 = Math_fround($258 * $349);
  $390 = Math_fround($259 * $349);
  $391 = Math_fround($260 * $349);
  $392 = Math_fround($389 + $386);
  $393 = Math_fround($390 + $387);
  $394 = Math_fround($391 + $388);
  HEAPF32[$meshToWorldSkew_Rot>>2] = $362;
  $395 = (($meshToWorldSkew_Rot) + 4|0);
  HEAPF32[$395>>2] = $363;
  $396 = (($meshToWorldSkew_Rot) + 8|0);
  HEAPF32[$396>>2] = $364;
  $397 = (($meshToWorldSkew_Rot) + 12|0);
  HEAPF32[$397>>2] = $377;
  $398 = (($meshToWorldSkew_Rot) + 16|0);
  HEAPF32[$398>>2] = $378;
  $399 = (($meshToWorldSkew_Rot) + 20|0);
  HEAPF32[$399>>2] = $379;
  $400 = (($meshToWorldSkew_Rot) + 24|0);
  HEAPF32[$400>>2] = $392;
  $401 = (($meshToWorldSkew_Rot) + 28|0);
  HEAPF32[$401>>2] = $393;
  $402 = (($meshToWorldSkew_Rot) + 32|0);
  HEAPF32[$402>>2] = $394;
  __ZNK5physx7PxMat3310getInverseEv($invRot$i,$meshToWorldSkew_Rot);
  $403 = (($pose) + 16|0);
  $404 = Math_fround(HEAPF32[$403>>2]);
  $405 = Math_fround(-$404);
  $406 = (($pose) + 20|0);
  $407 = Math_fround(HEAPF32[$406>>2]);
  $408 = Math_fround(-$407);
  $409 = (($pose) + 24|0);
  $410 = Math_fround(HEAPF32[$409>>2]);
  $411 = Math_fround(-$410);
  $412 = Math_fround(HEAPF32[$invRot$i>>2]);
  $413 = Math_fround($412 * $405);
  $414 = (($invRot$i) + 4|0);
  $415 = Math_fround(HEAPF32[$414>>2]);
  $416 = Math_fround($415 * $405);
  $417 = (($invRot$i) + 8|0);
  $418 = Math_fround(HEAPF32[$417>>2]);
  $419 = Math_fround($418 * $405);
  $420 = (($invRot$i) + 12|0);
  $421 = Math_fround(HEAPF32[$420>>2]);
  $422 = Math_fround($421 * $408);
  $423 = (($invRot$i) + 16|0);
  $424 = Math_fround(HEAPF32[$423>>2]);
  $425 = Math_fround($424 * $408);
  $426 = (($invRot$i) + 20|0);
  $427 = Math_fround(HEAPF32[$426>>2]);
  $428 = Math_fround($427 * $408);
  $429 = Math_fround($413 + $422);
  $430 = Math_fround($416 + $425);
  $431 = Math_fround($419 + $428);
  $432 = (($invRot$i) + 24|0);
  $433 = Math_fround(HEAPF32[$432>>2]);
  $434 = Math_fround($433 * $411);
  $435 = (($invRot$i) + 28|0);
  $436 = Math_fround(HEAPF32[$435>>2]);
  $437 = Math_fround($436 * $411);
  $438 = (($invRot$i) + 32|0);
  $439 = Math_fround(HEAPF32[$438>>2]);
  $440 = Math_fround($439 * $411);
  $441 = Math_fround($429 + $434);
  $442 = Math_fround($430 + $437);
  $443 = Math_fround($431 + $440);
  HEAPF32[$invRot$i>>2] = $412;
  $444 = (($invRot$i) + 4|0);
  HEAPF32[$444>>2] = $415;
  $445 = (($invRot$i) + 8|0);
  HEAPF32[$445>>2] = $418;
  $446 = (($invRot$i) + 12|0);
  HEAPF32[$446>>2] = $421;
  $447 = (($invRot$i) + 16|0);
  HEAPF32[$447>>2] = $424;
  $448 = (($invRot$i) + 20|0);
  HEAPF32[$448>>2] = $427;
  $449 = (($invRot$i) + 24|0);
  HEAPF32[$449>>2] = $433;
  $450 = (($invRot$i) + 28|0);
  HEAPF32[$450>>2] = $436;
  $451 = (($invRot$i) + 32|0);
  HEAPF32[$451>>2] = $439;
  $452 = (($invRot$i) + 36|0);
  HEAPF32[$452>>2] = $441;
  $453 = (($invRot$i) + 40|0);
  HEAPF32[$453>>2] = $442;
  $454 = (($invRot$i) + 44|0);
  HEAPF32[$454>>2] = $443;
  __ZN5physx9transformERKNS_2Cm8Matrix34ERKNS_2Gu3BoxE($1,$invRot$i,$box);
  $455 = Math_fround(HEAPF32[$1>>2]);
  $456 = (($1) + 4|0);
  $457 = Math_fround(HEAPF32[$456>>2]);
  $458 = (($1) + 8|0);
  $459 = Math_fround(HEAPF32[$458>>2]);
  $460 = (($1) + 12|0);
  $461 = Math_fround(HEAPF32[$460>>2]);
  $462 = (($1) + 16|0);
  $463 = Math_fround(HEAPF32[$462>>2]);
  $464 = (($1) + 20|0);
  $465 = Math_fround(HEAPF32[$464>>2]);
  $466 = (($1) + 24|0);
  $467 = Math_fround(HEAPF32[$466>>2]);
  $468 = (($1) + 28|0);
  $469 = Math_fround(HEAPF32[$468>>2]);
  $470 = (($1) + 32|0);
  $471 = Math_fround(HEAPF32[$470>>2]);
  $472 = (($1) + 48|0);
  $473 = Math_fround(HEAPF32[$472>>2]);
  $474 = (($1) + 52|0);
  $475 = Math_fround(HEAPF32[$474>>2]);
  $476 = (($1) + 56|0);
  $477 = Math_fround(HEAPF32[$476>>2]);
  $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($455)))));
  $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($457)))));
  $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($459)))));
  $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($461)))));
  $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($463)))));
  $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($465)))));
  $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($467)))));
  $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($469)))));
  $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($471)))));
  $478 = Math_fround($473 * $fabsf$i$i2$i);
  $479 = Math_fround($475 * $fabsf$i$i7$i);
  $480 = Math_fround($478 + $479);
  $481 = Math_fround($477 * $fabsf$i$i3$i);
  $482 = Math_fround($480 + $481);
  $483 = Math_fround($473 * $fabsf$i$i5$i);
  $484 = Math_fround($475 * $fabsf$i$i6$i);
  $485 = Math_fround($483 + $484);
  $486 = Math_fround($477 * $fabsf$i$i1$i);
  $487 = Math_fround($485 + $486);
  $488 = Math_fround($473 * $fabsf$i$i8$i);
  $489 = Math_fround($475 * $fabsf$i$i4$i);
  $490 = Math_fround($488 + $489);
  $491 = Math_fround($477 * $fabsf$i$i$i);
  $492 = Math_fround($490 + $491);
  HEAPF32[$sweptAABBMeshSpaceExtents>>2] = $482;
  $493 = (($sweptAABBMeshSpaceExtents) + 4|0);
  HEAPF32[$493>>2] = $487;
  $494 = (($sweptAABBMeshSpaceExtents) + 8|0);
  HEAPF32[$494>>2] = $492;
  $495 = (($box) + 36|0);
  $496 = Math_fround(HEAPF32[$495>>2]);
  $497 = Math_fround(HEAPF32[$invRot$i>>2]);
  $498 = Math_fround($496 * $497);
  $499 = Math_fround(HEAPF32[$444>>2]);
  $500 = Math_fround($496 * $499);
  $501 = Math_fround(HEAPF32[$445>>2]);
  $502 = Math_fround($496 * $501);
  $503 = (($box) + 40|0);
  $504 = Math_fround(HEAPF32[$503>>2]);
  $505 = Math_fround(HEAPF32[$446>>2]);
  $506 = Math_fround($504 * $505);
  $507 = Math_fround(HEAPF32[$447>>2]);
  $508 = Math_fround($504 * $507);
  $509 = Math_fround(HEAPF32[$448>>2]);
  $510 = Math_fround($504 * $509);
  $511 = Math_fround($498 + $506);
  $512 = Math_fround($500 + $508);
  $513 = Math_fround($502 + $510);
  $514 = (($box) + 44|0);
  $515 = Math_fround(HEAPF32[$514>>2]);
  $516 = Math_fround(HEAPF32[$449>>2]);
  $517 = Math_fround($515 * $516);
  $518 = Math_fround(HEAPF32[$450>>2]);
  $519 = Math_fround($515 * $518);
  $520 = Math_fround(HEAPF32[$451>>2]);
  $521 = Math_fround($515 * $520);
  $522 = Math_fround($511 + $517);
  $523 = Math_fround($512 + $519);
  $524 = Math_fround($513 + $521);
  $525 = Math_fround(HEAPF32[$452>>2]);
  $526 = Math_fround($522 + $525);
  $527 = Math_fround(HEAPF32[$453>>2]);
  $528 = Math_fround($523 + $527);
  $529 = Math_fround(HEAPF32[$454>>2]);
  $530 = Math_fround($524 + $529);
  HEAPF32[$meshSpaceOrigin>>2] = $526;
  $531 = (($meshSpaceOrigin) + 4|0);
  HEAPF32[$531>>2] = $528;
  $532 = (($meshSpaceOrigin) + 8|0);
  HEAPF32[$532>>2] = $530;
  $533 = Math_fround(HEAPF32[$unitDir>>2]);
  $534 = Math_fround($533 * $distance);
  $535 = (($unitDir) + 4|0);
  $536 = Math_fround(HEAPF32[$535>>2]);
  $537 = Math_fround($536 * $distance);
  $538 = (($unitDir) + 8|0);
  $539 = Math_fround(HEAPF32[$538>>2]);
  $540 = Math_fround($539 * $distance);
  $541 = Math_fround($534 * $497);
  $542 = Math_fround($534 * $499);
  $543 = Math_fround($534 * $501);
  $544 = Math_fround($537 * $505);
  $545 = Math_fround($537 * $507);
  $546 = Math_fround($537 * $509);
  $547 = Math_fround($541 + $544);
  $548 = Math_fround($542 + $545);
  $549 = Math_fround($543 + $546);
  $550 = Math_fround($540 * $516);
  $551 = Math_fround($540 * $518);
  $552 = Math_fround($540 * $520);
  $553 = Math_fround($547 + $550);
  $554 = Math_fround($548 + $551);
  $555 = Math_fround($549 + $552);
  $$pre = Math_fround(HEAPF32[$box>>2]);
  $$phi$trans$insert170 = (($box) + 4|0);
  $$pre171 = Math_fround(HEAPF32[$$phi$trans$insert170>>2]);
  $$phi$trans$insert172 = (($box) + 8|0);
  $$pre173 = Math_fround(HEAPF32[$$phi$trans$insert172>>2]);
  $$phi$trans$insert174 = (($box) + 12|0);
  $$pre175 = Math_fround(HEAPF32[$$phi$trans$insert174>>2]);
  $$phi$trans$insert176 = (($box) + 16|0);
  $$pre177 = Math_fround(HEAPF32[$$phi$trans$insert176>>2]);
  $$phi$trans$insert178 = (($box) + 20|0);
  $$pre179 = Math_fround(HEAPF32[$$phi$trans$insert178>>2]);
  $$phi$trans$insert180 = (($box) + 24|0);
  $$pre181 = Math_fround(HEAPF32[$$phi$trans$insert180>>2]);
  $$phi$trans$insert182 = (($box) + 28|0);
  $$pre183 = Math_fround(HEAPF32[$$phi$trans$insert182>>2]);
  $$phi$trans$insert184 = (($box) + 32|0);
  $$pre185 = Math_fround(HEAPF32[$$phi$trans$insert184>>2]);
  $557 = $482;$560 = $487;$563 = $492;$577 = $553;$579 = $554;$582 = $555;$591 = $496;$593 = $504;$595 = $515;$597 = $$pre;$599 = $$pre171;$602 = $$pre173;$605 = $$pre175;$607 = $$pre177;$610 = $$pre179;$613 = $$pre181;$615 = $$pre183;$618 = $$pre185;$628 = $208;$632 = $210;$639 = $212;$646 = $214;$650 = $216;$657 = $218;$664 = $220;$668 = $222;$675 = $224;$682 = $226;$686 = $228;$693 = $230;
 }
 $556 = Math_fround($557 + $inflation);
 $558 = (($sweptAABBMeshSpaceExtents) + 4|0);
 $559 = Math_fround($560 + $inflation);
 $561 = (($sweptAABBMeshSpaceExtents) + 8|0);
 $562 = Math_fround($563 + $inflation);
 $564 = Math_fround($556 * Math_fround(1.00999999046325683594));
 HEAPF32[$sweptAABBMeshSpaceExtents>>2] = $564;
 $565 = Math_fround($559 * Math_fround(1.00999999046325683594));
 HEAPF32[$558>>2] = $565;
 $566 = Math_fround($562 * Math_fround(1.00999999046325683594));
 HEAPF32[$561>>2] = $566;
 $567 = (($geom) + 36|0);
 $568 = HEAP32[$567>>2]|0;
 $569 = (($568) + 32|0);
 $570 = HEAP32[$569>>2]|0;
 HEAP32[$hmd>>2] = $570;
 $571 = (($568) + 48|0);
 $572 = (($hmd) + 4|0);
 HEAP32[$572>>2] = $571;
 $573 = (($568) + 36|0);
 $574 = Math_fround(HEAPF32[$573>>2]);
 $575 = (($hmd) + 8|0);
 HEAPF32[$575>>2] = $574;
 $576 = Math_fround($577 * $577);
 $578 = Math_fround($579 * $579);
 $580 = Math_fround($578 + $576);
 $581 = Math_fround($582 * $582);
 $583 = Math_fround($581 + $580);
 $584 = (Math_fround(Math_sqrt((Math_fround($583)))));
 $585 = $584 > Math_fround(9.99999974737875163555E-6);
 $586 = $585 ? $584 : Math_fround(9.99999974737875163555E-6);
 $587 = (($box) + 36|0);
 $588 = (($box) + 40|0);
 $589 = (($box) + 44|0);
 $590 = Math_fround(-$591);
 $592 = Math_fround(-$593);
 $594 = Math_fround(-$595);
 $596 = Math_fround($597 * $590);
 $598 = Math_fround($599 * $592);
 $600 = Math_fround($596 + $598);
 $601 = Math_fround($602 * $594);
 $603 = Math_fround($600 + $601);
 $604 = Math_fround($605 * $590);
 $606 = Math_fround($607 * $592);
 $608 = Math_fround($604 + $606);
 $609 = Math_fround($610 * $594);
 $611 = Math_fround($608 + $609);
 $612 = Math_fround($613 * $590);
 $614 = Math_fround($615 * $592);
 $616 = Math_fround($612 + $614);
 $617 = Math_fround($618 * $594);
 $619 = Math_fround($616 + $617);
 $620 = HEAP16[$hintFlags>>1]|0;
 $621 = (($geom) + 32|0);
 $622 = HEAP8[$621>>0]|0;
 $623 = $622 & 2;
 $624 = ($623<<24>>24)!=(0);
 $625 = $620 & 128;
 $626 = ($625<<16>>16)!=(0);
 $$ = $624 | $626;
 $627 = Math_fround($628 * $597);
 $629 = Math_fround($628 * $605);
 $630 = Math_fround($628 * $613);
 $631 = Math_fround($632 * $599);
 $633 = Math_fround($632 * $607);
 $634 = Math_fround($632 * $615);
 $635 = Math_fround($627 + $631);
 $636 = Math_fround($629 + $633);
 $637 = Math_fround($630 + $634);
 $638 = Math_fround($639 * $602);
 $640 = Math_fround($639 * $610);
 $641 = Math_fround($639 * $618);
 $642 = Math_fround($635 + $638);
 $643 = Math_fround($636 + $640);
 $644 = Math_fround($637 + $641);
 $645 = Math_fround($646 * $597);
 $647 = Math_fround($646 * $605);
 $648 = Math_fround($646 * $613);
 $649 = Math_fround($650 * $599);
 $651 = Math_fround($650 * $607);
 $652 = Math_fround($650 * $615);
 $653 = Math_fround($645 + $649);
 $654 = Math_fround($647 + $651);
 $655 = Math_fround($648 + $652);
 $656 = Math_fround($657 * $602);
 $658 = Math_fround($657 * $610);
 $659 = Math_fround($657 * $618);
 $660 = Math_fround($653 + $656);
 $661 = Math_fround($654 + $658);
 $662 = Math_fround($655 + $659);
 $663 = Math_fround($664 * $597);
 $665 = Math_fround($664 * $605);
 $666 = Math_fround($664 * $613);
 $667 = Math_fround($668 * $599);
 $669 = Math_fround($668 * $607);
 $670 = Math_fround($668 * $615);
 $671 = Math_fround($663 + $667);
 $672 = Math_fround($665 + $669);
 $673 = Math_fround($666 + $670);
 $674 = Math_fround($675 * $602);
 $676 = Math_fround($675 * $610);
 $677 = Math_fround($675 * $618);
 $678 = Math_fround($671 + $674);
 $679 = Math_fround($672 + $676);
 $680 = Math_fround($673 + $677);
 $681 = Math_fround($682 * $597);
 $683 = Math_fround($682 * $605);
 $684 = Math_fround($682 * $613);
 $685 = Math_fround($686 * $599);
 $687 = Math_fround($686 * $607);
 $688 = Math_fround($686 * $615);
 $689 = Math_fround($681 + $685);
 $690 = Math_fround($683 + $687);
 $691 = Math_fround($684 + $688);
 $692 = Math_fround($693 * $602);
 $694 = Math_fround($693 * $610);
 $695 = Math_fround($693 * $618);
 $696 = Math_fround($689 + $692);
 $697 = Math_fround($690 + $694);
 $698 = Math_fround($691 + $695);
 $699 = Math_fround($696 + $603);
 $700 = Math_fround($697 + $611);
 $701 = Math_fround($698 + $619);
 HEAPF32[$meshToWorldSkew_Rot>>2] = $642;
 $702 = (($meshToWorldSkew_Rot) + 4|0);
 HEAPF32[$702>>2] = $643;
 $703 = (($meshToWorldSkew_Rot) + 8|0);
 HEAPF32[$703>>2] = $644;
 $704 = (($meshToWorldSkew_Rot) + 12|0);
 HEAPF32[$704>>2] = $660;
 $705 = (($meshToWorldSkew_Rot) + 16|0);
 HEAPF32[$705>>2] = $661;
 $706 = (($meshToWorldSkew_Rot) + 20|0);
 HEAPF32[$706>>2] = $662;
 $707 = (($meshToWorldSkew_Rot) + 24|0);
 HEAPF32[$707>>2] = $678;
 $708 = (($meshToWorldSkew_Rot) + 28|0);
 HEAPF32[$708>>2] = $679;
 $709 = (($meshToWorldSkew_Rot) + 32|0);
 HEAPF32[$709>>2] = $680;
 $710 = (($meshToWorldSkew_Rot) + 36|0);
 HEAPF32[$710>>2] = $699;
 $711 = (($meshToWorldSkew_Rot) + 40|0);
 HEAPF32[$711>>2] = $700;
 $712 = (($meshToWorldSkew_Rot) + 44|0);
 HEAPF32[$712>>2] = $701;
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($invRot$i,$box);
 $713 = Math_fround(HEAPF32[$invRot$i>>2]);
 HEAPF32[$boxTransform>>2] = $713;
 $714 = (($boxTransform) + 4|0);
 $715 = (($invRot$i) + 4|0);
 $716 = Math_fround(HEAPF32[$715>>2]);
 HEAPF32[$714>>2] = $716;
 $717 = (($boxTransform) + 8|0);
 $718 = (($invRot$i) + 8|0);
 $719 = Math_fround(HEAPF32[$718>>2]);
 HEAPF32[$717>>2] = $719;
 $720 = (($boxTransform) + 12|0);
 $721 = (($invRot$i) + 12|0);
 $722 = Math_fround(HEAPF32[$721>>2]);
 HEAPF32[$720>>2] = $722;
 $723 = (($boxTransform) + 16|0);
 $724 = Math_fround(HEAPF32[$587>>2]);
 HEAPF32[$723>>2] = $724;
 $725 = (($boxTransform) + 20|0);
 $726 = Math_fround(HEAPF32[$588>>2]);
 HEAPF32[$725>>2] = $726;
 $727 = (($boxTransform) + 24|0);
 $728 = Math_fround(HEAPF32[$589>>2]);
 HEAPF32[$727>>2] = $728;
 $729 = Math_fround(HEAPF32[$unitDir>>2]);
 $730 = Math_fround($597 * $729);
 $731 = Math_fround($605 * $729);
 $732 = Math_fround($613 * $729);
 $733 = (($unitDir) + 4|0);
 $734 = Math_fround(HEAPF32[$733>>2]);
 $735 = Math_fround($599 * $734);
 $736 = Math_fround($607 * $734);
 $737 = Math_fround($615 * $734);
 $738 = Math_fround($730 + $735);
 $739 = Math_fround($731 + $736);
 $740 = Math_fround($732 + $737);
 $741 = (($unitDir) + 8|0);
 $742 = Math_fround(HEAPF32[$741>>2]);
 $743 = Math_fround($602 * $742);
 $744 = Math_fround($610 * $742);
 $745 = Math_fround($618 * $742);
 $746 = Math_fround($738 + $743);
 $747 = Math_fround($739 + $744);
 $748 = Math_fround($740 + $745);
 HEAPF32[$localDir>>2] = $746;
 $749 = (($localDir) + 4|0);
 HEAPF32[$749>>2] = $747;
 $750 = (($localDir) + 8|0);
 HEAPF32[$750>>2] = $748;
 $751 = Math_fround($746 * $distance);
 $752 = Math_fround($747 * $distance);
 $753 = Math_fround($748 * $distance);
 HEAPF32[$localDirDist>>2] = $751;
 $754 = (($localDirDist) + 4|0);
 HEAPF32[$754>>2] = $752;
 $755 = (($localDirDist) + 8|0);
 HEAPF32[$755>>2] = $753;
 $756 = (($callback) + 4|0);
 HEAP32[$756>>2] = 2;
 HEAP32[$callback>>2] = ((552680 + 8|0));
 $757 = (($callback) + 8|0);
 HEAP32[$757>>2] = $meshToWorldSkew_Rot;
 $758 = (($callback) + 12|0);
 HEAPF32[$758>>2] = $distance;
 $759 = (($callback) + 48|0);
 $$lobit169 = ($623&255) >>> 1;
 $$lobit = ($625&65535) >>> 7;
 $760 = $$lobit&255;
 $761 = $$lobit169 | $760;
 HEAP8[$759>>0] = $761;
 $762 = (($callback) + 52|0);
 HEAP32[$762>>2] = $box;
 $763 = (($callback) + 60|0);
 HEAP32[$763>>2] = $localDirDist;
 $764 = (($callback) + 64|0);
 HEAP32[$764>>2] = $localDir;
 $765 = (($callback) + 68|0);
 HEAP32[$765>>2] = $unitDir;
 $766 = (($callback) + 72|0);
 HEAP32[$766>>2] = $hintFlags;
 $767 = (($callback) + 76|0);
 HEAP8[$767>>0] = 0;
 $768 = (($callback) + 77|0);
 HEAP8[$768>>0] = 0;
 $769 = (($callback) + 80|0);
 HEAPF32[$769>>2] = $inflation;
 $770 = (($callback) + 160|0);
 HEAPF32[$770>>2] = $746;
 $771 = (($callback) + 164|0);
 HEAPF32[$771>>2] = $747;
 $772 = (($callback) + 168|0);
 HEAPF32[$772>>2] = $748;
 $773 = (($callback) + 172|0);
 HEAPF32[$773>>2] = Math_fround(0.0);
 $774 = (($callback) + 176|0);
 HEAPF32[$774>>2] = $751;
 $775 = (($callback) + 180|0);
 HEAPF32[$775>>2] = $752;
 $776 = (($callback) + 184|0);
 HEAPF32[$776>>2] = $753;
 $777 = (($callback) + 188|0);
 HEAPF32[$777>>2] = Math_fround(0.0);
 $778 = (($callback) + 32|0);
 HEAPF32[$778>>2] = $distance;
 $779 = (($callback) + 36|0);
 ;HEAP32[$779+0>>2]=HEAP32[$invRot$i+0>>2]|0;HEAP32[$779+4>>2]=HEAP32[$invRot$i+4>>2]|0;HEAP32[$779+8>>2]=HEAP32[$invRot$i+8>>2]|0;
 $780 = (($callback) + 16|0);
 HEAPF32[$780>>2] = $distance;
 $781 = $746 != Math_fround(0.0);
 if ($781) {
  $782 = Math_fround(Math_fround(1.0) / $746);
  $788 = $782;
 } else {
  $788 = Math_fround(0.0);
 }
 $783 = $747 != Math_fround(0.0);
 if ($783) {
  $784 = Math_fround(Math_fround(1.0) / $747);
  $790 = $784;
 } else {
  $790 = Math_fround(0.0);
 }
 $785 = $748 != Math_fround(0.0);
 if ($785) {
  $786 = Math_fround(Math_fround(1.0) / $748);
  $792 = $786;
 } else {
  $792 = Math_fround(0.0);
 }
 $787 = (($callback) + 196|0);
 HEAPF32[$787>>2] = $788;
 $789 = (($callback) + 200|0);
 HEAPF32[$789>>2] = $790;
 $791 = (($callback) + 204|0);
 HEAPF32[$791>>2] = $792;
 $793 = Math_fround(Math_fround(1.0) / $586);
 $794 = Math_fround($577 * $793);
 $795 = Math_fround($579 * $793);
 $796 = Math_fround($582 * $793);
 HEAPF32[$2>>2] = $794;
 $797 = (($2) + 4|0);
 HEAPF32[$797>>2] = $795;
 $798 = (($2) + 8|0);
 HEAPF32[$798>>2] = $796;
 __ZN5physx2Gu15MeshRayCollider7collideILi1ELi1EEEvRKNS_6PxVec3ES5_fbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEPS4_($meshSpaceOrigin,$2,$586,$$,$hmd,$callback,$sweptAABBMeshSpaceExtents);
 $799 = HEAP16[$767>>1]|0;
 $800 = $799&255;
 $801 = ($800<<24>>24)==(0);
 $802 = (($callback) + 128|0);
 $803 = Math_fround(HEAPF32[$802>>2]);
 $804 = (($callback) + 132|0);
 $805 = Math_fround(HEAPF32[$804>>2]);
 $806 = (($callback) + 136|0);
 $807 = Math_fround(HEAPF32[$806>>2]);
 $808 = (($callback) + 144|0);
 $809 = Math_fround(HEAPF32[$808>>2]);
 $810 = (($callback) + 148|0);
 $811 = Math_fround(HEAPF32[$810>>2]);
 $812 = (($callback) + 152|0);
 $813 = Math_fround(HEAPF32[$812>>2]);
 $814 = (($callback) + 192|0);
 $815 = HEAP32[$814>>2]|0;
 if ($801) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $816 = ($799&65535)<(256);
 if (!($816)) {
  $817 = HEAP16[$hintFlags>>1]|0;
  $818 = $817 & 512;
  $819 = ($818<<16>>16)==(0);
  do {
   if ($819) {
    $832 = (($sweepHit) + 12|0);
    HEAP16[$832>>1] = 6;
    $833 = (($sweepHit) + 40|0);
    HEAPF32[$833>>2] = Math_fround(0.0);
    $834 = Math_fround(HEAPF32[$unitDir>>2]);
    $835 = Math_fround(-$834);
    $836 = Math_fround(HEAPF32[$733>>2]);
    $837 = Math_fround(-$836);
    $838 = Math_fround(HEAPF32[$741>>2]);
    $839 = Math_fround(-$838);
    $840 = (($sweepHit) + 28|0);
    HEAPF32[$840>>2] = $835;
    $841 = (($sweepHit) + 32|0);
    HEAPF32[$841>>2] = $837;
    $842 = (($sweepHit) + 36|0);
    HEAPF32[$842>>2] = $839;
   } else {
    $820 = (__ZN5physx2Gu26computeBox_TriangleMeshMTDERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformERKNS0_3BoxES6_ffbRNS_10PxSweepHitE($geom,$pose,$box,$boxTransform,$inflation,$distance,$$,$sweepHit)|0);
    $821 = (($sweepHit) + 12|0);
    HEAP16[$821>>1] = 6;
    if ($820) {
     HEAP16[$821>>1] = 7;
     break;
    } else {
     $822 = (($sweepHit) + 40|0);
     HEAPF32[$822>>2] = Math_fround(0.0);
     $823 = Math_fround(HEAPF32[$unitDir>>2]);
     $824 = Math_fround(-$823);
     $825 = Math_fround(HEAPF32[$733>>2]);
     $826 = Math_fround(-$825);
     $827 = Math_fround(HEAPF32[$741>>2]);
     $828 = Math_fround(-$827);
     $829 = (($sweepHit) + 28|0);
     HEAPF32[$829>>2] = $824;
     $830 = (($sweepHit) + 32|0);
     HEAPF32[$830>>2] = $826;
     $831 = (($sweepHit) + 36|0);
     HEAPF32[$831>>2] = $828;
     break;
    }
   }
  } while(0);
  $843 = (($sweepHit) + 8|0);
  HEAP32[$843>>2] = $815;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $844 = (($sweepHit) + 8|0);
 HEAP32[$844>>2] = $815;
 $845 = Math_fround(HEAPF32[$758>>2]);
 $846 = (($sweepHit) + 40|0);
 HEAPF32[$846>>2] = $845;
 $847 = (($sweepHit) + 12|0);
 HEAP16[$847>>1] = 7;
 $848 = HEAP16[$hintFlags>>1]|0;
 $849 = $848 & 256;
 $850 = ($849<<16>>16)==(0);
 if ($850) {
  $1000 = Math_fround($722 * $722);
  $1001 = Math_fround($1000 + Math_fround(-0.5));
  $1002 = Math_fround($1001 * $809);
  $1003 = Math_fround($1001 * $811);
  $1004 = Math_fround($1001 * $813);
  $1005 = Math_fround($716 * $813);
  $1006 = Math_fround($719 * $811);
  $1007 = Math_fround($1005 - $1006);
  $1008 = Math_fround($719 * $809);
  $1009 = Math_fround($713 * $813);
  $1010 = Math_fround($1008 - $1009);
  $1011 = Math_fround($713 * $811);
  $1012 = Math_fround($716 * $809);
  $1013 = Math_fround($1011 - $1012);
  $1014 = Math_fround($722 * $1007);
  $1015 = Math_fround($722 * $1010);
  $1016 = Math_fround($722 * $1013);
  $1017 = Math_fround($1002 + $1014);
  $1018 = Math_fround($1003 + $1015);
  $1019 = Math_fround($1004 + $1016);
  $1020 = Math_fround($713 * $809);
  $1021 = Math_fround($716 * $811);
  $1022 = Math_fround($1020 + $1021);
  $1023 = Math_fround($719 * $813);
  $1024 = Math_fround($1022 + $1023);
  $1025 = Math_fround($713 * $1024);
  $1026 = Math_fround($716 * $1024);
  $1027 = Math_fround($719 * $1024);
  $1028 = Math_fround($1025 + $1017);
  $1029 = Math_fround($1026 + $1018);
  $1030 = Math_fround($1019 + $1027);
  $1031 = Math_fround($1028 * Math_fround(2.0));
  $1032 = Math_fround($1029 * Math_fround(2.0));
  $1033 = Math_fround($1030 * Math_fround(2.0));
  $1034 = Math_fround(-$1031);
  $1035 = Math_fround(-$1032);
  $1036 = Math_fround(-$1033);
  $1037 = Math_fround($1001 * $803);
  $1038 = Math_fround($1001 * $805);
  $1039 = Math_fround($1001 * $807);
  $1040 = Math_fround($716 * $807);
  $1041 = Math_fround($719 * $805);
  $1042 = Math_fround($1040 - $1041);
  $1043 = Math_fround($719 * $803);
  $1044 = Math_fround($713 * $807);
  $1045 = Math_fround($1043 - $1044);
  $1046 = Math_fround($713 * $805);
  $1047 = Math_fround($716 * $803);
  $1048 = Math_fround($1046 - $1047);
  $1049 = Math_fround($722 * $1042);
  $1050 = Math_fround($722 * $1045);
  $1051 = Math_fround($722 * $1048);
  $1052 = Math_fround($1037 + $1049);
  $1053 = Math_fround($1038 + $1050);
  $1054 = Math_fround($1039 + $1051);
  $1055 = Math_fround($713 * $803);
  $1056 = Math_fround($716 * $805);
  $1057 = Math_fround($1055 + $1056);
  $1058 = Math_fround($719 * $807);
  $1059 = Math_fround($1057 + $1058);
  $1060 = Math_fround($713 * $1059);
  $1061 = Math_fround($716 * $1059);
  $1062 = Math_fround($719 * $1059);
  $1063 = Math_fround($1060 + $1052);
  $1064 = Math_fround($1061 + $1053);
  $1065 = Math_fround($1054 + $1062);
  $1066 = Math_fround($1063 * Math_fround(2.0));
  $1067 = Math_fround($1064 * Math_fround(2.0));
  $1068 = Math_fround($1065 * Math_fround(2.0));
  $1069 = Math_fround($724 + $1066);
  $1070 = Math_fround($726 + $1067);
  $1071 = Math_fround($728 + $1068);
  $1072 = (($sweepHit) + 28|0);
  HEAPF32[$1072>>2] = $1034;
  $1073 = (($sweepHit) + 32|0);
  HEAPF32[$1073>>2] = $1035;
  $1074 = (($sweepHit) + 36|0);
  HEAPF32[$1074>>2] = $1036;
  $1075 = (($sweepHit) + 16|0);
  HEAPF32[$1075>>2] = $1069;
  $1076 = (($sweepHit) + 20|0);
  HEAPF32[$1076>>2] = $1070;
  $1077 = (($sweepHit) + 24|0);
  HEAPF32[$1077>>2] = $1071;
  HEAP32[$844>>2] = $815;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $851 = Math_fround(HEAPF32[$localDir>>2]);
 $852 = $851 != Math_fround(0.0);
 if ($852) {
  $853 = Math_fround(Math_fround(1.0) / $851);
  $860 = $853;
 } else {
  $860 = Math_fround(0.0);
 }
 $854 = Math_fround(HEAPF32[$749>>2]);
 $855 = $854 != Math_fround(0.0);
 if ($855) {
  $856 = Math_fround(Math_fround(1.0) / $854);
  $862 = $856;
 } else {
  $862 = Math_fround(0.0);
 }
 $857 = Math_fround(HEAPF32[$750>>2]);
 $858 = $857 != Math_fround(0.0);
 if ($858) {
  $859 = Math_fround(Math_fround(1.0) / $857);
  $864 = $859;
 } else {
  $864 = Math_fround(0.0);
 }
 HEAPF32[$oneOverMotion>>2] = $860;
 $861 = (($oneOverMotion) + 4|0);
 HEAPF32[$861>>2] = $862;
 $863 = (($oneOverMotion) + 8|0);
 HEAPF32[$863>>2] = $864;
 $865 = Math_fround($845 + Math_fround(-0.00999999977648258209228));
 $866 = Math_fround($851 * $865);
 $867 = Math_fround($865 * $854);
 $868 = Math_fround($865 * $857);
 HEAPF32[$invRot$i>>2] = Math_fround(1.0);
 $869 = (($invRot$i) + 4|0);
 HEAPF32[$869>>2] = Math_fround(0.0);
 $870 = (($invRot$i) + 8|0);
 HEAPF32[$870>>2] = Math_fround(0.0);
 $871 = (($invRot$i) + 12|0);
 HEAPF32[$871>>2] = Math_fround(0.0);
 $872 = (($invRot$i) + 16|0);
 HEAPF32[$872>>2] = Math_fround(1.0);
 $873 = (($invRot$i) + 20|0);
 HEAPF32[$873>>2] = Math_fround(0.0);
 $874 = (($invRot$i) + 24|0);
 HEAPF32[$874>>2] = Math_fround(0.0);
 $875 = (($invRot$i) + 28|0);
 HEAPF32[$875>>2] = Math_fround(0.0);
 $876 = (($invRot$i) + 32|0);
 HEAPF32[$876>>2] = Math_fround(1.0);
 $877 = (($invRot$i) + 36|0);
 HEAPF32[$877>>2] = $866;
 $878 = (($invRot$i) + 40|0);
 HEAPF32[$878>>2] = $867;
 $879 = (($invRot$i) + 44|0);
 HEAPF32[$879>>2] = $868;
 $880 = (($invRot$i) + 48|0);
 $881 = (($box) + 48|0);
 $882 = Math_fround(HEAPF32[$881>>2]);
 HEAPF32[$880>>2] = $882;
 $883 = (($invRot$i) + 52|0);
 $884 = (($box) + 52|0);
 $885 = Math_fround(HEAPF32[$884>>2]);
 HEAPF32[$883>>2] = $885;
 $886 = (($invRot$i) + 56|0);
 $887 = (($box) + 56|0);
 $888 = Math_fround(HEAPF32[$887>>2]);
 HEAPF32[$886>>2] = $888;
 $889 = (($callback) + 84|0);
 __ZN5physx2Gu17computeImpactDataERNS_10PxSweepHitERKNS0_3BoxERKNS_6PxVec3ES8_S8_RKNS_10PxTriangleE($sweepHit,$invRot$i,$localDir,$localDir,$oneOverMotion,$889);
 $890 = (($sweepHit) + 28|0);
 $891 = Math_fround(HEAPF32[$890>>2]);
 $892 = Math_fround($891 * $891);
 $893 = (($sweepHit) + 32|0);
 $894 = Math_fround(HEAPF32[$893>>2]);
 $895 = Math_fround($894 * $894);
 $896 = Math_fround($892 + $895);
 $897 = (($sweepHit) + 36|0);
 $898 = Math_fround(HEAPF32[$897>>2]);
 $899 = Math_fround($898 * $898);
 $900 = Math_fround($896 + $899);
 $901 = (Math_fround(Math_sqrt((Math_fround($900)))));
 $902 = $901 > Math_fround(0.0);
 if ($902) {
  $903 = Math_fround(Math_fround(1.0) / $901);
  $904 = Math_fround($891 * $903);
  HEAPF32[$890>>2] = $904;
  $905 = Math_fround($894 * $903);
  HEAPF32[$893>>2] = $905;
  $906 = Math_fround($898 * $903);
  HEAPF32[$897>>2] = $906;
  $909 = $904;$912 = $905;$916 = $906;
 } else {
  $909 = $891;$912 = $894;$916 = $898;
 }
 $907 = Math_fround(HEAPF32[$localDir>>2]);
 $908 = Math_fround($909 * $907);
 $910 = Math_fround(HEAPF32[$749>>2]);
 $911 = Math_fround($912 * $910);
 $913 = Math_fround($908 + $911);
 $914 = Math_fround(HEAPF32[$750>>2]);
 $915 = Math_fround($916 * $914);
 $917 = Math_fround($913 + $915);
 $918 = $917 > Math_fround(0.0);
 if ($918) {
  $919 = Math_fround(-$909);
  $920 = Math_fround(-$912);
  $921 = Math_fround(-$916);
  HEAPF32[$890>>2] = $919;
  HEAPF32[$893>>2] = $920;
  HEAPF32[$897>>2] = $921;
  $925 = $919;$927 = $920;$929 = $921;
 } else {
  $925 = $909;$927 = $912;$929 = $916;
 }
 $922 = Math_fround($722 * $722);
 $923 = Math_fround($922 + Math_fround(-0.5));
 $924 = Math_fround($923 * $925);
 $926 = Math_fround($923 * $927);
 $928 = Math_fround($923 * $929);
 $930 = Math_fround($716 * $929);
 $931 = Math_fround($719 * $927);
 $932 = Math_fround($930 - $931);
 $933 = Math_fround($719 * $925);
 $934 = Math_fround($713 * $929);
 $935 = Math_fround($933 - $934);
 $936 = Math_fround($713 * $927);
 $937 = Math_fround($716 * $925);
 $938 = Math_fround($936 - $937);
 $939 = Math_fround($722 * $932);
 $940 = Math_fround($722 * $935);
 $941 = Math_fround($722 * $938);
 $942 = Math_fround($924 + $939);
 $943 = Math_fround($926 + $940);
 $944 = Math_fround($928 + $941);
 $945 = Math_fround($713 * $925);
 $946 = Math_fround($716 * $927);
 $947 = Math_fround($945 + $946);
 $948 = Math_fround($719 * $929);
 $949 = Math_fround($947 + $948);
 $950 = Math_fround($713 * $949);
 $951 = Math_fround($716 * $949);
 $952 = Math_fround($719 * $949);
 $953 = Math_fround($950 + $942);
 $954 = Math_fround($951 + $943);
 $955 = Math_fround($944 + $952);
 $956 = Math_fround($953 * Math_fround(2.0));
 $957 = Math_fround($954 * Math_fround(2.0));
 $958 = Math_fround($955 * Math_fround(2.0));
 HEAPF32[$890>>2] = $956;
 HEAPF32[$893>>2] = $957;
 HEAPF32[$897>>2] = $958;
 $959 = (($sweepHit) + 16|0);
 $960 = Math_fround(HEAPF32[$959>>2]);
 $961 = (($sweepHit) + 20|0);
 $962 = Math_fround(HEAPF32[$961>>2]);
 $963 = (($sweepHit) + 24|0);
 $964 = Math_fround(HEAPF32[$963>>2]);
 $965 = Math_fround($923 * $960);
 $966 = Math_fround($923 * $962);
 $967 = Math_fround($923 * $964);
 $968 = Math_fround($716 * $964);
 $969 = Math_fround($719 * $962);
 $970 = Math_fround($968 - $969);
 $971 = Math_fround($719 * $960);
 $972 = Math_fround($713 * $964);
 $973 = Math_fround($971 - $972);
 $974 = Math_fround($713 * $962);
 $975 = Math_fround($716 * $960);
 $976 = Math_fround($974 - $975);
 $977 = Math_fround($722 * $970);
 $978 = Math_fround($722 * $973);
 $979 = Math_fround($722 * $976);
 $980 = Math_fround($965 + $977);
 $981 = Math_fround($966 + $978);
 $982 = Math_fround($967 + $979);
 $983 = Math_fround($713 * $960);
 $984 = Math_fround($716 * $962);
 $985 = Math_fround($983 + $984);
 $986 = Math_fround($719 * $964);
 $987 = Math_fround($985 + $986);
 $988 = Math_fround($713 * $987);
 $989 = Math_fround($716 * $987);
 $990 = Math_fround($719 * $987);
 $991 = Math_fround($988 + $980);
 $992 = Math_fround($989 + $981);
 $993 = Math_fround($982 + $990);
 $994 = Math_fround($991 * Math_fround(2.0));
 $995 = Math_fround($992 * Math_fround(2.0));
 $996 = Math_fround($993 * Math_fround(2.0));
 $997 = Math_fround($724 + $994);
 $998 = Math_fround($726 + $995);
 $999 = Math_fround($728 + $996);
 HEAPF32[$959>>2] = $997;
 HEAPF32[$961>>2] = $998;
 HEAPF32[$963>>2] = $999;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN23SweepBoxMeshHitCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z20sweepConvex_MeshGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($aMeshGeom,$meshPose,$convexGeom,$convexPose,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $aMeshGeom = $aMeshGeom|0;
 $meshPose = $meshPose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0;
 var $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0;
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0;
 var $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = 0, $366 = Math_fround(0);
 var $367 = 0, $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0;
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $callback = 0, $convexScaling = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0), $hullAABB = 0, $hullOBB = 0, $meshScaling = 0;
 var $querySweptBox = 0, $rtreeData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 912|0;
 $convexScaling = sp + 824|0;
 $meshScaling = sp + 752|0;
 $hullAABB = sp + 728|0;
 $hullOBB = sp + 664|0;
 $0 = sp + 616|0;
 $1 = sp + 552|0;
 $querySweptBox = sp + 488|0;
 $2 = sp + 476|0;
 $callback = sp;
 $3 = sp + 464|0;
 $4 = sp + 896|0;
 $rtreeData = sp + 600|0;
 $5 = (($convexGeom) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($aMeshGeom) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($convexGeom) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = $10 == Math_fround(1.0);
 if ($11) {
  $12 = (($convexGeom) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = $13 == Math_fround(1.0);
  if ($14) {
   $15 = (($convexGeom) + 12|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = $16 == Math_fround(1.0);
   $403 = $17;
  } else {
   $403 = 0;
  }
 } else {
  $403 = 0;
 }
 $18 = (($aMeshGeom) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = $19 == Math_fround(1.0);
 if ($20) {
  $21 = (($aMeshGeom) + 8|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = $22 == Math_fround(1.0);
  if ($23) {
   $24 = (($aMeshGeom) + 12|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = $25 == Math_fround(1.0);
   $231 = $26;
  } else {
   $231 = 0;
  }
 } else {
  $231 = 0;
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $27 = (($convexScaling) + 4|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($convexScaling) + 8|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($convexScaling) + 12|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($convexScaling) + 16|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($convexScaling) + 20|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($convexScaling) + 24|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($convexScaling) + 28|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($convexScaling) + 32|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (($convexScaling) + 36|0);
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($convexScaling) + 40|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($convexScaling) + 44|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($convexScaling) + 48|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($convexScaling) + 52|0);
 HEAPF32[$39>>2] = Math_fround(1.0);
 $40 = (($convexScaling) + 56|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($convexScaling) + 60|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($convexScaling) + 64|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($convexScaling) + 68|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 if (!($403)) {
  $44 = (($convexGeom) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$9,$44);
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $45 = (($meshScaling) + 4|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($meshScaling) + 8|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($meshScaling) + 12|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($meshScaling) + 16|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($meshScaling) + 20|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($meshScaling) + 24|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($meshScaling) + 28|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($meshScaling) + 32|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($meshScaling) + 36|0);
 HEAPF32[$53>>2] = Math_fround(1.0);
 $54 = (($meshScaling) + 40|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($meshScaling) + 44|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($meshScaling) + 48|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($meshScaling) + 52|0);
 HEAPF32[$57>>2] = Math_fround(1.0);
 $58 = (($meshScaling) + 56|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($meshScaling) + 60|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($meshScaling) + 64|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($meshScaling) + 68|0);
 HEAPF32[$61>>2] = Math_fround(1.0);
 if (!($231)) {
  $62 = (($aMeshGeom) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$18,$62);
 }
 $63 = (($6) + 16|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($6) + 28|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($64 + $66);
 $68 = (($6) + 20|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($6) + 32|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($69 + $71);
 $73 = (($6) + 24|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($6) + 36|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($74 + $76);
 $78 = Math_fround($67 * Math_fround(0.5));
 $79 = Math_fround($72 * Math_fround(0.5));
 $80 = Math_fround($77 * Math_fround(0.5));
 $81 = Math_fround(HEAPF32[$convexScaling>>2]);
 $82 = Math_fround($78 * $81);
 $83 = Math_fround(HEAPF32[$27>>2]);
 $84 = Math_fround($78 * $83);
 $85 = Math_fround(HEAPF32[$28>>2]);
 $86 = Math_fround($78 * $85);
 $87 = Math_fround(HEAPF32[$29>>2]);
 $88 = Math_fround($79 * $87);
 $89 = Math_fround(HEAPF32[$30>>2]);
 $90 = Math_fround($79 * $89);
 $91 = Math_fround(HEAPF32[$31>>2]);
 $92 = Math_fround($79 * $91);
 $93 = Math_fround($82 + $88);
 $94 = Math_fround($84 + $90);
 $95 = Math_fround($86 + $92);
 $96 = Math_fround(HEAPF32[$32>>2]);
 $97 = Math_fround($80 * $96);
 $98 = Math_fround(HEAPF32[$33>>2]);
 $99 = Math_fround($80 * $98);
 $100 = Math_fround(HEAPF32[$34>>2]);
 $101 = Math_fround($80 * $100);
 $102 = Math_fround($93 + $97);
 $103 = Math_fround($94 + $99);
 $104 = Math_fround($95 + $101);
 $105 = Math_fround($66 - $64);
 $106 = Math_fround($71 - $69);
 $107 = Math_fround($76 - $74);
 $108 = Math_fround($105 * Math_fround(0.5));
 $109 = Math_fround($106 * Math_fround(0.5));
 $110 = Math_fround($107 * Math_fround(0.5));
 $111 = Math_fround($108 * $81);
 $112 = Math_fround($108 * $83);
 $113 = Math_fround($108 * $85);
 $114 = Math_fround($109 * $87);
 $115 = Math_fround($109 * $89);
 $116 = Math_fround($109 * $91);
 $117 = Math_fround($110 * $96);
 $118 = Math_fround($110 * $98);
 $119 = Math_fround($110 * $100);
 $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($111)))));
 $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($114)))));
 $120 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
 $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($117)))));
 $121 = Math_fround($120 + $fabsf$i$i6$i$i);
 $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($112)))));
 $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($115)))));
 $122 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
 $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($118)))));
 $123 = Math_fround($122 + $fabsf$i$i3$i$i);
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($113)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($116)))));
 $124 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($119)))));
 $125 = Math_fround($124 + $fabsf$i$i$i$i);
 $126 = Math_fround($102 - $121);
 $127 = Math_fround($103 - $123);
 $128 = Math_fround($104 - $125);
 $129 = Math_fround($102 + $121);
 $130 = Math_fround($103 + $123);
 $131 = Math_fround($104 + $125);
 HEAPF32[$hullAABB>>2] = $126;
 $132 = (($hullAABB) + 4|0);
 HEAPF32[$132>>2] = $127;
 $133 = (($hullAABB) + 8|0);
 HEAPF32[$133>>2] = $128;
 $134 = (($hullAABB) + 12|0);
 HEAPF32[$134>>2] = $129;
 $135 = (($hullAABB) + 16|0);
 HEAPF32[$135>>2] = $130;
 $136 = (($hullAABB) + 20|0);
 HEAPF32[$136>>2] = $131;
 $137 = Math_fround(HEAPF32[$convexPose>>2]);
 $138 = Math_fround($137 + $137);
 $139 = (($convexPose) + 4|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($140 + $140);
 $142 = (($convexPose) + 8|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = Math_fround($143 + $143);
 $145 = (($convexPose) + 12|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = Math_fround($138 * $146);
 $148 = Math_fround($141 * $146);
 $149 = Math_fround($146 * $144);
 $150 = Math_fround($137 * $138);
 $151 = Math_fround($137 * $141);
 $152 = Math_fround($137 * $144);
 $153 = Math_fround($140 * $141);
 $154 = Math_fround($140 * $144);
 $155 = Math_fround($143 * $144);
 $156 = Math_fround(Math_fround(1.0) - $153);
 $157 = Math_fround($156 - $155);
 HEAPF32[$0>>2] = $157;
 $158 = Math_fround($151 + $149);
 $159 = (($0) + 4|0);
 HEAPF32[$159>>2] = $158;
 $160 = Math_fround($152 - $148);
 $161 = (($0) + 8|0);
 HEAPF32[$161>>2] = $160;
 $162 = Math_fround($151 - $149);
 $163 = (($0) + 12|0);
 HEAPF32[$163>>2] = $162;
 $164 = Math_fround(Math_fround(1.0) - $150);
 $165 = Math_fround($164 - $155);
 $166 = (($0) + 16|0);
 HEAPF32[$166>>2] = $165;
 $167 = Math_fround($154 + $147);
 $168 = (($0) + 20|0);
 HEAPF32[$168>>2] = $167;
 $169 = Math_fround($152 + $148);
 $170 = (($0) + 24|0);
 HEAPF32[$170>>2] = $169;
 $171 = Math_fround($154 - $147);
 $172 = (($0) + 28|0);
 HEAPF32[$172>>2] = $171;
 $173 = Math_fround($164 - $153);
 $174 = (($0) + 32|0);
 HEAPF32[$174>>2] = $173;
 $175 = (($0) + 36|0);
 $176 = (($0) + 40|0);
 $177 = (($0) + 44|0);
 $178 = (($convexPose) + 16|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 HEAPF32[$175>>2] = $179;
 $180 = (($convexPose) + 20|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 HEAPF32[$176>>2] = $181;
 $182 = (($convexPose) + 24|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 HEAPF32[$177>>2] = $183;
 $184 = Math_fround(HEAPF32[$meshPose>>2]);
 $185 = Math_fround($184 + $184);
 $186 = (($meshPose) + 4|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = Math_fround($187 + $187);
 $189 = (($meshPose) + 8|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = Math_fround($190 + $190);
 $192 = (($meshPose) + 12|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = Math_fround($185 * $193);
 $195 = Math_fround($188 * $193);
 $196 = Math_fround($193 * $191);
 $197 = Math_fround($184 * $185);
 $198 = Math_fround($184 * $188);
 $199 = Math_fround($184 * $191);
 $200 = Math_fround($187 * $188);
 $201 = Math_fround($187 * $191);
 $202 = Math_fround($190 * $191);
 $203 = Math_fround(Math_fround(1.0) - $200);
 $204 = Math_fround($203 - $202);
 HEAPF32[$1>>2] = $204;
 $205 = Math_fround($198 + $196);
 $206 = (($1) + 4|0);
 HEAPF32[$206>>2] = $205;
 $207 = Math_fround($199 - $195);
 $208 = (($1) + 8|0);
 HEAPF32[$208>>2] = $207;
 $209 = Math_fround($198 - $196);
 $210 = (($1) + 12|0);
 HEAPF32[$210>>2] = $209;
 $211 = Math_fround(Math_fround(1.0) - $197);
 $212 = Math_fround($211 - $202);
 $213 = (($1) + 16|0);
 HEAPF32[$213>>2] = $212;
 $214 = Math_fround($201 + $194);
 $215 = (($1) + 20|0);
 HEAPF32[$215>>2] = $214;
 $216 = Math_fround($199 + $195);
 $217 = (($1) + 24|0);
 HEAPF32[$217>>2] = $216;
 $218 = Math_fround($201 - $194);
 $219 = (($1) + 28|0);
 HEAPF32[$219>>2] = $218;
 $220 = Math_fround($211 - $200);
 $221 = (($1) + 32|0);
 HEAPF32[$221>>2] = $220;
 $222 = (($1) + 36|0);
 $223 = (($1) + 40|0);
 $224 = (($1) + 44|0);
 $225 = (($meshPose) + 16|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 HEAPF32[$222>>2] = $226;
 $227 = (($meshPose) + 20|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 HEAPF32[$223>>2] = $228;
 $229 = (($meshPose) + 24|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 HEAPF32[$224>>2] = $230;
 __ZN5physx2Gu14computeHullOBBERNS0_3BoxERKNS_9PxBounds3EfRKNS_11PxTransformERKNS_2Cm8Matrix34ESC_RKNS9_23FastVertex2ShapeScalingEb($hullOBB,$hullAABB,Math_fround(0.0),$convexPose,$0,$1,$meshScaling,$231);
 $232 = (($hullOBB) + 48|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = Math_fround($233 + $inflation);
 HEAPF32[$232>>2] = $234;
 $235 = (($hullOBB) + 52|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = Math_fround($236 + $inflation);
 HEAPF32[$235>>2] = $237;
 $238 = (($hullOBB) + 56|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = Math_fround($239 + $inflation);
 HEAPF32[$238>>2] = $240;
 $241 = (($hullOBB) + 36|0);
 $242 = Math_fround(HEAPF32[$unitDir>>2]);
 $243 = Math_fround($242 * Math_fround(2.0));
 $244 = (($unitDir) + 4|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = Math_fround($245 * Math_fround(2.0));
 $247 = (($unitDir) + 8|0);
 $248 = Math_fround(HEAPF32[$247>>2]);
 $249 = Math_fround($248 * Math_fround(2.0));
 $250 = Math_fround(HEAPF32[$192>>2]);
 $251 = Math_fround($250 * $250);
 $252 = Math_fround($251 + Math_fround(-0.5));
 $253 = Math_fround(HEAPF32[$meshPose>>2]);
 $254 = Math_fround($243 * $253);
 $255 = Math_fround(HEAPF32[$186>>2]);
 $256 = Math_fround($246 * $255);
 $257 = Math_fround($254 + $256);
 $258 = Math_fround(HEAPF32[$189>>2]);
 $259 = Math_fround($249 * $258);
 $260 = Math_fround($257 + $259);
 $261 = Math_fround($243 * $252);
 $262 = Math_fround($249 * $255);
 $263 = Math_fround($246 * $258);
 $264 = Math_fround($262 - $263);
 $265 = Math_fround($250 * $264);
 $266 = Math_fround($261 - $265);
 $267 = Math_fround($253 * $260);
 $268 = Math_fround($267 + $266);
 $269 = Math_fround($246 * $252);
 $270 = Math_fround($243 * $258);
 $271 = Math_fround($249 * $253);
 $272 = Math_fround($270 - $271);
 $273 = Math_fround($250 * $272);
 $274 = Math_fround($269 - $273);
 $275 = Math_fround($255 * $260);
 $276 = Math_fround($275 + $274);
 $277 = Math_fround($249 * $252);
 $278 = Math_fround($246 * $253);
 $279 = Math_fround($243 * $255);
 $280 = Math_fround($278 - $279);
 $281 = Math_fround($250 * $280);
 $282 = Math_fround($277 - $281);
 $283 = Math_fround($258 * $260);
 $284 = Math_fround($282 + $283);
 HEAPF32[$2>>2] = $268;
 $285 = (($2) + 4|0);
 HEAPF32[$285>>2] = $276;
 $286 = (($2) + 8|0);
 HEAPF32[$286>>2] = $284;
 __ZN5physx2Gu15computeSweptBoxERNS0_3BoxERKNS_6PxVec3ES5_RKNS_7PxMat33ES5_f($querySweptBox,$232,$241,$hullOBB,$2,$distance);
 $287 = HEAP16[$hintFlags>>1]|0;
 $288 = $287&65535;
 $289 = $288 & 128;
 $290 = (($aMeshGeom) + 32|0);
 $291 = HEAP8[$290>>0]|0;
 $292 = $291 & 2;
 $293 = ($292<<24>>24)!=(0);
 $294 = ($289|0)!=(0);
 $$ = $293 | $294;
 $295 = $288 & 512;
 $296 = ($295|0)==(0);
 $297 = Math_fround(HEAPF32[$unitDir>>2]);
 $298 = Math_fround(-$297);
 $299 = Math_fround(HEAPF32[$244>>2]);
 $300 = Math_fround(-$299);
 $301 = Math_fround(HEAPF32[$247>>2]);
 $302 = Math_fround(-$301);
 HEAPF32[$3>>2] = $298;
 $303 = (($3) + 4|0);
 HEAPF32[$303>>2] = $300;
 $304 = (($3) + 8|0);
 HEAPF32[$304>>2] = $302;
 HEAP16[$4>>1] = $287;
 $305 = $287 & 64;
 $306 = ($305<<16>>16)!=(0);
 __ZN25ConvexVsMeshSweepCallbackC2ERKN5physx2Gu14ConvexHullDataERKNS0_11PxMeshScaleERKNS0_2Cm23FastVertex2ShapeScalingERKNS0_11PxTransformESE_RKNS0_6PxVec3EfNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEEbfb($callback,$63,$9,$meshScaling,$convexPose,$meshPose,$3,$distance,$4,$$,$inflation,$306);
 $307 = (($8) + 32|0);
 $308 = HEAP32[$307>>2]|0;
 HEAP32[$rtreeData>>2] = $308;
 $309 = (($8) + 48|0);
 $310 = (($rtreeData) + 4|0);
 HEAP32[$310>>2] = $309;
 $311 = (($8) + 36|0);
 $312 = Math_fround(HEAPF32[$311>>2]);
 $313 = (($rtreeData) + 8|0);
 HEAPF32[$313>>2] = $312;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($querySweptBox,1,$rtreeData,$callback,1);
 $314 = (($callback) + 449|0);
 $315 = HEAP8[$314>>0]|0;
 $316 = ($315<<24>>24)==(0);
 if ($316) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $317 = (($callback) + 448|0);
 $318 = HEAP8[$317>>0]|0;
 $319 = ($318<<24>>24)==(0);
 if (!($319)) {
  do {
   if ($296) {
    $332 = (($sweepHit) + 12|0);
    HEAP16[$332>>1] = 6;
    $333 = (($sweepHit) + 40|0);
    HEAPF32[$333>>2] = Math_fround(0.0);
    $334 = Math_fround(HEAPF32[$unitDir>>2]);
    $335 = Math_fround(-$334);
    $336 = Math_fround(HEAPF32[$244>>2]);
    $337 = Math_fround(-$336);
    $338 = Math_fround(HEAPF32[$247>>2]);
    $339 = Math_fround(-$338);
    $340 = (($sweepHit) + 28|0);
    HEAPF32[$340>>2] = $335;
    $341 = (($sweepHit) + 32|0);
    HEAPF32[$341>>2] = $337;
    $342 = (($sweepHit) + 36|0);
    HEAPF32[$342>>2] = $339;
   } else {
    $320 = (__ZN5physx2Gu29computeConvex_TriangleMeshMTDERKNS_22PxTriangleMeshGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES6_ffbRNS_10PxSweepHitE($aMeshGeom,$meshPose,$convexGeom,$convexPose,$inflation,$distance,$$,$sweepHit)|0);
    $321 = (($sweepHit) + 12|0);
    HEAP16[$321>>1] = 6;
    if ($320) {
     HEAP16[$321>>1] = 7;
     break;
    } else {
     $322 = (($sweepHit) + 40|0);
     HEAPF32[$322>>2] = Math_fround(0.0);
     $323 = Math_fround(HEAPF32[$unitDir>>2]);
     $324 = Math_fround(-$323);
     $325 = Math_fround(HEAPF32[$244>>2]);
     $326 = Math_fround(-$325);
     $327 = Math_fround(HEAPF32[$247>>2]);
     $328 = Math_fround(-$327);
     $329 = (($sweepHit) + 28|0);
     HEAPF32[$329>>2] = $324;
     $330 = (($sweepHit) + 32|0);
     HEAPF32[$330>>2] = $326;
     $331 = (($sweepHit) + 36|0);
     HEAPF32[$331>>2] = $328;
     break;
    }
   }
  } while(0);
  $343 = (($callback) + 332|0);
  $344 = HEAP32[$343>>2]|0;
  $345 = (($sweepHit) + 8|0);
  HEAP32[$345>>2] = $344;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $346 = (($callback) + 324|0);
 ;HEAP32[$sweepHit+0>>2]=HEAP32[$346+0>>2]|0;HEAP32[$sweepHit+4>>2]=HEAP32[$346+4>>2]|0;HEAP32[$sweepHit+8>>2]=HEAP32[$346+8>>2]|0;
 $347 = (($callback) + 336|0);
 $348 = HEAP16[$347>>1]|0;
 $349 = (($sweepHit) + 12|0);
 HEAP16[$349>>1] = $348;
 $350 = (($callback) + 340|0);
 $351 = Math_fround(HEAPF32[$350>>2]);
 $352 = (($sweepHit) + 16|0);
 HEAPF32[$352>>2] = $351;
 $353 = (($callback) + 344|0);
 $354 = Math_fround(HEAPF32[$353>>2]);
 $355 = (($sweepHit) + 20|0);
 HEAPF32[$355>>2] = $354;
 $356 = (($callback) + 348|0);
 $357 = Math_fround(HEAPF32[$356>>2]);
 $358 = (($sweepHit) + 24|0);
 HEAPF32[$358>>2] = $357;
 $359 = (($callback) + 352|0);
 $360 = Math_fround(HEAPF32[$359>>2]);
 $361 = (($sweepHit) + 28|0);
 $362 = (($callback) + 356|0);
 $363 = Math_fround(HEAPF32[$362>>2]);
 $364 = (($sweepHit) + 32|0);
 $365 = (($callback) + 360|0);
 $366 = Math_fround(HEAPF32[$365>>2]);
 $367 = (($sweepHit) + 36|0);
 $368 = (($callback) + 364|0);
 $369 = Math_fround(HEAPF32[$368>>2]);
 $370 = (($sweepHit) + 40|0);
 HEAPF32[$370>>2] = $369;
 $371 = (($callback) + 368|0);
 $372 = HEAP32[$371>>2]|0;
 $373 = (($sweepHit) + 44|0);
 HEAP32[$373>>2] = $372;
 $374 = Math_fround(-$360);
 $375 = Math_fround(-$363);
 $376 = Math_fround(-$366);
 HEAPF32[$361>>2] = $374;
 HEAPF32[$364>>2] = $375;
 HEAPF32[$367>>2] = $376;
 $377 = Math_fround($360 * $360);
 $378 = Math_fround($363 * $363);
 $379 = Math_fround($377 + $378);
 $380 = Math_fround($366 * $366);
 $381 = Math_fround($380 + $379);
 $382 = (Math_fround(Math_sqrt((Math_fround($381)))));
 $383 = $382 > Math_fround(0.0);
 if ($383) {
  $384 = Math_fround(Math_fround(1.0) / $382);
  $385 = Math_fround($384 * $374);
  HEAPF32[$361>>2] = $385;
  $386 = Math_fround($384 * $375);
  HEAPF32[$364>>2] = $386;
  $387 = Math_fround($384 * $376);
  HEAPF32[$367>>2] = $387;
  $390 = $385;$393 = $386;$397 = $387;
 } else {
  $390 = $374;$393 = $375;$397 = $376;
 }
 if (!($$)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $388 = Math_fround(HEAPF32[$unitDir>>2]);
 $389 = Math_fround($390 * $388);
 $391 = Math_fround(HEAPF32[$244>>2]);
 $392 = Math_fround($393 * $391);
 $394 = Math_fround($389 + $392);
 $395 = Math_fround(HEAPF32[$247>>2]);
 $396 = Math_fround($397 * $395);
 $398 = Math_fround($394 + $396);
 $399 = $398 > Math_fround(0.0);
 if (!($399)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $400 = Math_fround(-$390);
 $401 = Math_fround(-$393);
 $402 = Math_fround(-$397);
 HEAPF32[$361>>2] = $400;
 HEAPF32[$364>>2] = $401;
 HEAPF32[$367>>2] = $402;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN25ConvexVsMeshSweepCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN25ConvexVsMeshSweepCallbackC2ERKN5physx2Gu14ConvexHullDataERKNS0_11PxMeshScaleERKNS0_2Cm23FastVertex2ShapeScalingERKNS0_11PxTransformESE_RKNS0_6PxVec3EfNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEEbfb($this,$hull,$convexScale,$meshScale,$convexPose,$meshPose,$unitDir,$distance,$hintFlags,$isDoubleSided,$inflation,$anyHit) {
 $this = $this|0;
 $hull = $hull|0;
 $convexScale = $convexScale|0;
 $meshScale = $meshScale|0;
 $convexPose = $convexPose|0;
 $meshPose = $meshPose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $hintFlags = $hintFlags|0;
 $isDoubleSided = $isDoubleSided|0;
 $inflation = Math_fround($inflation);
 $anyHit = $anyHit|0;
 var $$$i$i$i = Math_fround(0), $$$i12$i$i = Math_fround(0), $$$i23$i$i = Math_fround(0), $$$i26$i$i = Math_fround(0), $$sroa$1$i$i6 = 0, $$sroa$3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = 0;
 var $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $dist$sroa$1 = 0, $vQuat = 0, $vScale = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 64|0;
 $$sroa$1$i$i6 = sp + 112|0;
 $$sroa$3$i$i = sp + 80|0;
 $1 = sp + 32|0;
 $dist$sroa$1 = sp + 96|0;
 $vScale = sp + 16|0;
 $vQuat = sp + 48|0;
 $2 = sp;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = 2;
 HEAP32[$this>>2] = ((552656 + 8|0));
 $4 = (($this) + 16|0);
 $5 = (($this) + 80|0);
 $6 = (($this) + 96|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 32|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 36|0);
 ;HEAP32[$8+0>>2]=HEAP32[$$sroa$1$i$i6+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$$sroa$1$i$i6+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$$sroa$1$i$i6+8>>2]|0;
 $9 = (($this) + 48|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 52|0);
 ;HEAP32[$10+0>>2]=HEAP32[$$sroa$1$i$i6+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$$sroa$1$i$i6+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$$sroa$1$i$i6+8>>2]|0;
 $11 = (($this) + 64|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 68|0);
 ;HEAP32[$12+0>>2]=HEAP32[$$sroa$1$i$i6+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$$sroa$1$i$i6+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$$sroa$1$i$i6+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$5+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$0+12>>2]|0;
 $13 = (($this) + 272|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$13+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$sroa$1$i$i6+0>>2]=0|0;HEAP32[$$sroa$1$i$i6+4>>2]=0|0;HEAP32[$$sroa$1$i$i6+8>>2]=0|0;HEAP32[$$sroa$1$i$i6+12>>2]=0|0;
 ;HEAP32[$$sroa$3$i$i+0>>2]=0|0;HEAP32[$$sroa$3$i$i+4>>2]=0|0;HEAP32[$$sroa$3$i$i+8>>2]=0|0;HEAP32[$$sroa$3$i$i+12>>2]=0|0;
 $14 = (($this) + 224|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($this) + 228|0);
 ;HEAP32[$15+0>>2]=HEAP32[$$sroa$1$i$i6+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$$sroa$1$i$i6+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$$sroa$1$i$i6+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$$sroa$1$i$i6+12>>2]|0;
 $16 = (($this) + 244|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($this) + 248|0);
 ;HEAP32[$17+0>>2]=HEAP32[$$sroa$3$i$i+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$$sroa$3$i$i+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$$sroa$3$i$i+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$$sroa$3$i$i+12>>2]|0;
 $18 = (($this) + 264|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 268|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 $20 = (($this) + 288|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($this) + 292|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($this) + 296|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 300|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($this) + 304|0);
 ;HEAP32[$24+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$1+12>>2]|0;
 $25 = (($this) + 320|0);
 HEAP32[$25>>2] = $meshScale;
 $26 = (($this) + 324|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 328|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 332|0);
 $29 = (($this) + 336|0);
 HEAP16[$29>>1] = 0;
 $30 = (($this) + 340|0);
 $31 = (($this) + 364|0);
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP32[$30+16>>2]=0|0;HEAP32[$30+20>>2]=0|0;
 HEAPF32[$31>>2] = Math_fround(3.40282346638528859812E+38);
 $32 = (($this) + 416|0);
 $33 = Math_fround(HEAPF32[$unitDir>>2]);
 HEAPF32[$32>>2] = $33;
 $34 = (($this) + 420|0);
 $35 = (($unitDir) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$34>>2] = $36;
 $37 = (($this) + 424|0);
 $38 = (($unitDir) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$37>>2] = $39;
 $40 = (($this) + 440|0);
 HEAPF32[$40>>2] = $inflation;
 $41 = HEAP16[$hintFlags>>1]|0;
 $42 = (($this) + 444|0);
 HEAP16[$42>>1] = $41;
 $43 = (($this) + 446|0);
 $44 = $anyHit&1;
 HEAP8[$43>>0] = $44;
 $45 = (($this) + 447|0);
 $46 = $isDoubleSided&1;
 HEAP8[$45>>0] = $46;
 $47 = (($this) + 448|0);
 HEAP8[$47>>0] = 0;
 HEAPF32[$31>>2] = $distance;
 HEAP32[$28>>2] = -1;
 $48 = Math_fround(HEAPF32[$unitDir>>2]);
 $49 = Math_fround($48 * Math_fround(2.0));
 $50 = Math_fround(HEAPF32[$35>>2]);
 $51 = Math_fround($50 * Math_fround(2.0));
 $52 = Math_fround(HEAPF32[$38>>2]);
 $53 = Math_fround($52 * Math_fround(2.0));
 $54 = (($meshPose) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * $55);
 $57 = Math_fround($56 + Math_fround(-0.5));
 $58 = Math_fround(HEAPF32[$meshPose>>2]);
 $59 = Math_fround($49 * $58);
 $60 = (($meshPose) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($51 * $61);
 $63 = Math_fround($59 + $62);
 $64 = (($meshPose) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($53 * $65);
 $67 = Math_fround($63 + $66);
 $68 = Math_fround($49 * $57);
 $69 = Math_fround($53 * $61);
 $70 = Math_fround($51 * $65);
 $71 = Math_fround($69 - $70);
 $72 = Math_fround($55 * $71);
 $73 = Math_fround($68 - $72);
 $74 = Math_fround($58 * $67);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($51 * $57);
 $77 = Math_fround($49 * $65);
 $78 = Math_fround($53 * $58);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($55 * $79);
 $81 = Math_fround($76 - $80);
 $82 = Math_fround($61 * $67);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($53 * $57);
 $85 = Math_fround($51 * $58);
 $86 = Math_fround($49 * $61);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($55 * $87);
 $89 = Math_fround($84 - $88);
 $90 = Math_fround($65 * $67);
 $91 = Math_fround($89 + $90);
 $92 = (($this) + 428|0);
 HEAPF32[$92>>2] = $75;
 $93 = (($this) + 432|0);
 HEAPF32[$93>>2] = $83;
 $94 = (($this) + 436|0);
 HEAPF32[$94>>2] = $91;
 $95 = Math_fround(HEAPF32[$unitDir>>2]);
 $96 = Math_fround(HEAPF32[$35>>2]);
 $97 = Math_fround(HEAPF32[$38>>2]);
 $98 = Math_fround(HEAPF32[$meshPose>>2]);
 $99 = (($meshPose) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($meshPose) + 8|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($meshPose) + 12|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($meshPose) + 16|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($105) + 4|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($105) + 8|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround(HEAPF32[$convexPose>>2]);
 $112 = (($convexPose) + 4|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($convexPose) + 8|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($convexPose) + 12|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($convexPose) + 16|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($118) + 4|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($118) + 8|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround(-$111);
 $125 = Math_fround(-$113);
 $126 = Math_fround(-$115);
 $127 = Math_fround($106 - $119);
 $128 = Math_fround($108 - $121);
 $129 = Math_fround($110 - $123);
 $130 = Math_fround($117 * $117);
 $131 = Math_fround($130 + Math_fround(-0.5));
 $132 = Math_fround($131 * $127);
 $133 = Math_fround($131 * $128);
 $134 = Math_fround($131 * $129);
 $135 = Math_fround($129 * $125);
 $136 = Math_fround($128 * $126);
 $137 = Math_fround($135 - $136);
 $138 = Math_fround($127 * $126);
 $139 = Math_fround($129 * $124);
 $140 = Math_fround($138 - $139);
 $141 = Math_fround($128 * $124);
 $142 = Math_fround($127 * $125);
 $143 = Math_fround($141 - $142);
 $144 = Math_fround($117 * $137);
 $145 = Math_fround($117 * $140);
 $146 = Math_fround($117 * $143);
 $147 = Math_fround($132 + $144);
 $148 = Math_fround($133 + $145);
 $149 = Math_fround($134 + $146);
 $150 = Math_fround($127 * $124);
 $151 = Math_fround($128 * $125);
 $152 = Math_fround($150 + $151);
 $153 = Math_fround($129 * $126);
 $154 = Math_fround($152 + $153);
 $155 = Math_fround($154 * $124);
 $156 = Math_fround($154 * $125);
 $157 = Math_fround($154 * $126);
 $158 = Math_fround($155 + $147);
 $159 = Math_fround($156 + $148);
 $160 = Math_fround($149 + $157);
 $161 = Math_fround($158 * Math_fround(2.0));
 $162 = Math_fround($159 * Math_fround(2.0));
 $163 = Math_fround($160 * Math_fround(2.0));
 $164 = Math_fround($104 * $117);
 $165 = Math_fround($98 * $124);
 $166 = Math_fround($100 * $125);
 $167 = Math_fround($165 + $166);
 $168 = Math_fround($102 * $126);
 $169 = Math_fround($167 + $168);
 $170 = Math_fround($164 - $169);
 $171 = Math_fround($104 * $124);
 $172 = Math_fround($104 * $125);
 $173 = Math_fround($104 * $126);
 $174 = Math_fround($98 * $117);
 $175 = Math_fround($100 * $117);
 $176 = Math_fround($102 * $117);
 $177 = Math_fround($102 * $125);
 $178 = Math_fround($100 * $126);
 $179 = Math_fround($177 - $178);
 $180 = Math_fround($98 * $126);
 $181 = Math_fround($102 * $124);
 $182 = Math_fround($180 - $181);
 $183 = Math_fround($100 * $124);
 $184 = Math_fround($98 * $125);
 $185 = Math_fround($183 - $184);
 $186 = Math_fround($171 + $174);
 $187 = Math_fround($172 + $175);
 $188 = Math_fround($176 + $173);
 $189 = Math_fround($179 + $186);
 $190 = Math_fround($182 + $187);
 $191 = Math_fround($185 + $188);
 $192 = Math_fround($189 + $189);
 $193 = Math_fround($190 + $190);
 $194 = Math_fround($191 + $191);
 $195 = Math_fround($189 * $192);
 $196 = Math_fround($190 * $193);
 $197 = Math_fround($191 * $194);
 $198 = Math_fround($190 * $192);
 $199 = Math_fround($191 * $192);
 $200 = Math_fround($170 * $192);
 $201 = Math_fround($191 * $193);
 $202 = Math_fround($170 * $193);
 $203 = Math_fround($170 * $194);
 $204 = Math_fround(Math_fround(1.0) - $195);
 $205 = Math_fround(Math_fround(1.0) - $196);
 $206 = Math_fround($205 - $197);
 $207 = Math_fround($198 + $203);
 $208 = Math_fround($199 - $202);
 $209 = Math_fround($198 - $203);
 $210 = Math_fround($204 - $197);
 $211 = Math_fround($201 + $200);
 $212 = Math_fround($199 + $202);
 $213 = Math_fround($201 - $200);
 $214 = Math_fround($204 - $196);
 HEAPF32[$14>>2] = $206;
 HEAPF32[$15>>2] = $207;
 $215 = (($this) + 232|0);
 HEAPF32[$215>>2] = $208;
 $216 = (($this) + 236|0);
 HEAPF32[$216>>2] = Math_fround(0.0);
 $217 = (($this) + 240|0);
 HEAPF32[$217>>2] = $209;
 HEAPF32[$16>>2] = $210;
 HEAPF32[$17>>2] = $211;
 $218 = (($this) + 252|0);
 HEAPF32[$218>>2] = Math_fround(0.0);
 $219 = (($this) + 256|0);
 HEAPF32[$219>>2] = $212;
 $220 = (($this) + 260|0);
 HEAPF32[$220>>2] = $213;
 HEAPF32[$18>>2] = $214;
 HEAPF32[$19>>2] = Math_fround(0.0);
 $221 = (($this) + 272|0);
 HEAPF32[$221>>2] = $161;
 $222 = (($this) + 276|0);
 HEAPF32[$222>>2] = $162;
 $223 = (($this) + 280|0);
 HEAPF32[$223>>2] = $163;
 $224 = (($this) + 284|0);
 HEAPF32[$224>>2] = Math_fround(0.0);
 HEAPF32[$20>>2] = $111;
 HEAPF32[$21>>2] = $113;
 HEAPF32[$22>>2] = $115;
 HEAPF32[$23>>2] = $117;
 $225 = (($this) + 304|0);
 HEAPF32[$225>>2] = $119;
 $226 = (($this) + 308|0);
 HEAPF32[$226>>2] = $121;
 $227 = (($this) + 312|0);
 HEAPF32[$227>>2] = $123;
 $228 = (($this) + 316|0);
 HEAPF32[$228>>2] = Math_fround(0.0);
 $229 = Math_fround($95 * $distance);
 $230 = Math_fround($96 * $distance);
 $231 = Math_fround($97 * $distance);
 $232 = Math_fround(-$229);
 $233 = Math_fround(-$230);
 $234 = Math_fround(-$231);
 $235 = Math_fround($131 * $232);
 $236 = Math_fround($131 * $233);
 $237 = Math_fround($131 * $234);
 $238 = Math_fround($113 * $234);
 $239 = Math_fround($115 * $233);
 $240 = Math_fround($238 - $239);
 $241 = Math_fround($115 * $232);
 $242 = Math_fround($111 * $234);
 $243 = Math_fround($241 - $242);
 $244 = Math_fround($111 * $233);
 $245 = Math_fround($113 * $232);
 $246 = Math_fround($244 - $245);
 $247 = Math_fround($117 * $240);
 $248 = Math_fround($117 * $243);
 $249 = Math_fround($117 * $246);
 $250 = Math_fround($235 - $247);
 $251 = Math_fround($236 - $248);
 $252 = Math_fround($237 - $249);
 $253 = Math_fround($111 * $232);
 $254 = Math_fround($113 * $233);
 $255 = Math_fround($253 + $254);
 $256 = Math_fround($115 * $234);
 $257 = Math_fround($255 + $256);
 $258 = Math_fround($111 * $257);
 $259 = Math_fround($113 * $257);
 $260 = Math_fround($115 * $257);
 $261 = Math_fround($258 + $250);
 $262 = Math_fround($259 + $251);
 $263 = Math_fround($260 + $252);
 $264 = Math_fround($261 * Math_fround(2.0));
 $265 = Math_fround($262 * Math_fround(2.0));
 $266 = Math_fround($263 * Math_fround(2.0));
 $267 = (($this) + 400|0);
 HEAPF32[$267>>2] = $264;
 $268 = (($this) + 404|0);
 HEAPF32[$268>>2] = $265;
 $269 = (($this) + 408|0);
 HEAPF32[$269>>2] = $266;
 $270 = (($this) + 412|0);
 HEAPF32[$270>>2] = Math_fround(0.0);
 $271 = (($this) + 384|0);
 HEAPF32[$271>>2] = $distance;
 $272 = (($this) + 388|0);
 ;HEAP32[$272+0>>2]=HEAP32[$dist$sroa$1+0>>2]|0;HEAP32[$272+4>>2]=HEAP32[$dist$sroa$1+4>>2]|0;HEAP32[$272+8>>2]=HEAP32[$dist$sroa$1+8>>2]|0;
 $273 = Math_fround(HEAPF32[$convexScale>>2]);
 $274 = (($convexScale) + 4|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = (($convexScale) + 8|0);
 $277 = Math_fround(HEAPF32[$276>>2]);
 HEAPF32[$vScale>>2] = $273;
 $278 = (($vScale) + 4|0);
 HEAPF32[$278>>2] = $275;
 $279 = (($vScale) + 8|0);
 HEAPF32[$279>>2] = $277;
 $280 = (($vScale) + 12|0);
 HEAPF32[$280>>2] = Math_fround(0.0);
 $281 = (($convexScale) + 12|0);
 $282 = Math_fround(HEAPF32[$281>>2]);
 $283 = (($281) + 4|0);
 $284 = Math_fround(HEAPF32[$283>>2]);
 $285 = (($281) + 8|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = (($281) + 12|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 HEAPF32[$vQuat>>2] = $282;
 $289 = (($vQuat) + 4|0);
 HEAPF32[$289>>2] = $284;
 $290 = (($vQuat) + 8|0);
 HEAPF32[$290>>2] = $286;
 $291 = (($vQuat) + 12|0);
 HEAPF32[$291>>2] = $288;
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 $292 = (($hull) + 40|0);
 $293 = HEAP32[$292>>2]|0;
 $294 = (($hull) + 39|0);
 $295 = HEAP8[$294>>0]|0;
 $296 = $295&255;
 $297 = (($293) + (($296*20)|0)|0);
 $298 = (($hull) + 52|0);
 $299 = Math_fround(HEAPF32[$298>>2]);
 $300 = (($hull) + 56|0);
 $301 = Math_fround(HEAPF32[$300>>2]);
 $302 = (($hull) + 60|0);
 $303 = Math_fround(HEAPF32[$302>>2]);
 $304 = Math_fround($299 * $273);
 $305 = Math_fround($301 * $275);
 $306 = Math_fround($303 * $277);
 $307 = !($304 <= $305);
 $$$i26$i$i = $307 ? $305 : $304;
 $308 = !($$$i26$i$i <= $306);
 $309 = $308 ? $306 : $$$i26$i$i;
 $310 = !($304 >= $305);
 $$$i23$i$i = $310 ? $305 : $304;
 $311 = !($$$i23$i$i >= $306);
 $312 = $311 ? $306 : $$$i23$i$i;
 $313 = Math_fround($309 * Math_fround(0.20000000298023223877));
 $314 = Math_fround($312 * Math_fround(0.0500000007450580596924));
 $315 = $313 > $314;
 $$$i12$i$i = $315 ? $313 : $314;
 $316 = $309 > $$$i12$i$i;
 $$$i$i$i = $316 ? $$$i12$i$i : $309;
 HEAPF32[$7>>2] = $$$i$i$i;
 ;HEAP32[$8+0>>2]=HEAP32[$$sroa$1$i$i6+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$$sroa$1$i$i6+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$$sroa$1$i$i6+8>>2]|0;
 $317 = Math_fround($309 * Math_fround(0.100000001490116119385));
 HEAPF32[$9>>2] = $317;
 ;HEAP32[$10+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$0+8>>2]|0;
 $318 = (($this) + 112|0);
 $319 = (($this) + 160|0);
 __ZN5physx2Gu19ConstructSkewMatrixERKNS_6shdfnd3aos5Vec3VERKNS2_5Vec4VERNS2_6Mat33VESA_($vScale,$vQuat,$318,$319);
 $320 = (($this) + 216|0);
 HEAP32[$320>>2] = $297;
 $321 = (($hull) + 38|0);
 $322 = HEAP8[$321>>0]|0;
 $323 = (($this) + 220|0);
 HEAP8[$323>>0] = $322;
 ;HEAP32[$4+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$2+12>>2]|0;
 $324 = (($hull) + 44|0);
 $325 = HEAP32[$324>>2]|0;
 $326 = (($this) + 212|0);
 HEAP32[$326>>2] = $325;
 $327 = (($this) + 208|0);
 HEAP32[$327>>2] = $hull;
 $328 = HEAP32[$324>>2]|0;
 $329 = ($328|0)==(0|0);
 if ($329) {
  $343 = (($this) + 449|0);
  HEAP8[$343>>0] = 0;
  STACKTOP = sp;return;
 }
 $330 = (($328) + 16|0);
 $331 = HEAP32[$330>>2]|0;
 $332 = HEAP32[$327>>2]|0;
 $333 = (($332) + 44|0);
 $334 = HEAP32[$333>>2]|0;
 $335 = (($334) + 16|0);
 $336 = HEAP32[$335>>2]|0;
 $337 = (($336) + 128|0);
 $338 = HEAP32[$327>>2]|0;
 $339 = (($338) + 44|0);
 $340 = HEAP32[$339>>2]|0;
 $341 = (($340) + 20|0);
 $342 = HEAP32[$341>>2]|0;
 $343 = (($this) + 449|0);
 HEAP8[$343>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN25ConvexVsMeshSweepCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$hit,$av0,$av1,$av2,$0,$1) {
 $this = $this|0;
 $hit = $hit|0;
 $av0 = $av0|0;
 $av1 = $av1|0;
 $av2 = $av2|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $$sroa$1$i$i$i = 0, $$sroa$113$i$i$i = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0;
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0;
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = 0, $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0);
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $closestA$i = 0, $normal$i = 0, $toi$i = 0, $triangleV$i = 0, $zero$i = 0, $zero$sroa$1$i$i$i$i = 0;
 var $zeroV$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $zero$sroa$1$i$i$i$i = sp + 252|0;
 $2 = sp + 224|0;
 $$sroa$113$i$i$i = sp + 240|0;
 $$sroa$1$i$i$i = sp + 264|0;
 $zeroV$i = sp + 208|0;
 $zero$i = sp + 192|0;
 $triangleV$i = sp + 32|0;
 $toi$i = sp + 16|0;
 $closestA$i = sp;
 $normal$i = sp + 176|0;
 $3 = (($this) + 320|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$av0>>2]);
 $6 = Math_fround(HEAPF32[$4>>2]);
 $7 = Math_fround($5 * $6);
 $8 = (($4) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($5 * $9);
 $11 = (($4) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($5 * $12);
 $14 = (($av0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($4) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $17);
 $19 = (($4) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($15 * $20);
 $22 = (($4) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($15 * $23);
 $25 = Math_fround($7 + $18);
 $26 = Math_fround($10 + $21);
 $27 = Math_fround($13 + $24);
 $28 = (($av0) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($4) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($29 * $31);
 $33 = (($4) + 28|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($29 * $34);
 $36 = (($4) + 32|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($29 * $37);
 $39 = Math_fround($25 + $32);
 $40 = Math_fround($26 + $35);
 $41 = Math_fround($27 + $38);
 $42 = Math_fround(HEAPF32[$av1>>2]);
 $43 = Math_fround($6 * $42);
 $44 = Math_fround($9 * $42);
 $45 = Math_fround($12 * $42);
 $46 = (($av1) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($17 * $47);
 $49 = Math_fround($20 * $47);
 $50 = Math_fround($23 * $47);
 $51 = Math_fround($43 + $48);
 $52 = Math_fround($44 + $49);
 $53 = Math_fround($45 + $50);
 $54 = (($av1) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($31 * $55);
 $57 = Math_fround($34 * $55);
 $58 = Math_fround($37 * $55);
 $59 = Math_fround($51 + $56);
 $60 = Math_fround($52 + $57);
 $61 = Math_fround($53 + $58);
 $62 = Math_fround(HEAPF32[$av2>>2]);
 $63 = Math_fround($6 * $62);
 $64 = Math_fround($9 * $62);
 $65 = Math_fround($12 * $62);
 $66 = (($av2) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($17 * $67);
 $69 = Math_fround($20 * $67);
 $70 = Math_fround($23 * $67);
 $71 = Math_fround($63 + $68);
 $72 = Math_fround($64 + $69);
 $73 = Math_fround($65 + $70);
 $74 = (($av2) + 8|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($31 * $75);
 $77 = Math_fround($34 * $75);
 $78 = Math_fround($37 * $75);
 $79 = Math_fround($71 + $76);
 $80 = Math_fround($72 + $77);
 $81 = Math_fround($73 + $78);
 $82 = (($this) + 364|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($this) + 16|0);
 $85 = (($this) + 400|0);
 $86 = (($this) + 447|0);
 $87 = HEAP8[$86>>0]|0;
 $88 = ($87<<24>>24)==(0);
 $89 = (($this) + 440|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($this) + 448|0);
 $92 = Math_fround($59 - $39);
 $93 = Math_fround($60 - $40);
 $94 = Math_fround($61 - $41);
 $95 = Math_fround($79 - $59);
 $96 = Math_fround($80 - $60);
 $97 = Math_fround($81 - $61);
 if ($88) {
  $98 = Math_fround($93 * $95);
  $99 = Math_fround($92 * $96);
  $100 = Math_fround($92 * $97);
  $101 = Math_fround($94 * $95);
  $102 = Math_fround($94 * $96);
  $103 = Math_fround($93 * $97);
  $104 = Math_fround($99 - $98);
  $105 = Math_fround($101 - $100);
  $106 = Math_fround($103 - $102);
  $107 = (($this) + 428|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($106 * $108);
  $110 = (($this) + 432|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround($105 * $111);
  $113 = Math_fround($109 + $112);
  $114 = (($this) + 436|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($104 * $115);
  $117 = Math_fround($113 + $116);
  $118 = !($117 <= Math_fround(0.0));
  if (!($118)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 ;HEAP32[$zeroV$i+0>>2]=0|0;HEAP32[$zeroV$i+4>>2]=0|0;HEAP32[$zeroV$i+8>>2]=0|0;HEAP32[$zeroV$i+12>>2]=0|0;
 HEAPF32[$zero$i>>2] = Math_fround(0.0);
 $119 = (($this) + 272|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($this) + 276|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($this) + 280|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($this) + 224|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($39 * $126);
 $128 = (($this) + 240|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($40 * $129);
 $131 = Math_fround($127 + $130);
 $132 = (($this) + 256|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($41 * $133);
 $135 = Math_fround($131 + $134);
 $136 = (($this) + 228|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround($39 * $137);
 $139 = (($this) + 244|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($40 * $140);
 $142 = Math_fround($138 + $141);
 $143 = (($this) + 260|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround($41 * $144);
 $146 = Math_fround($142 + $145);
 $147 = (($this) + 232|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = Math_fround($39 * $148);
 $150 = (($this) + 248|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = Math_fround($40 * $151);
 $153 = Math_fround($149 + $152);
 $154 = (($this) + 264|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = Math_fround($41 * $155);
 $157 = Math_fround($153 + $156);
 $158 = Math_fround($120 + $135);
 $159 = Math_fround($122 + $146);
 $160 = Math_fround($124 + $157);
 $161 = Math_fround($59 * $126);
 $162 = Math_fround($60 * $129);
 $163 = Math_fround($161 + $162);
 $164 = Math_fround($61 * $133);
 $165 = Math_fround($163 + $164);
 $166 = Math_fround($59 * $137);
 $167 = Math_fround($60 * $140);
 $168 = Math_fround($166 + $167);
 $169 = Math_fround($61 * $144);
 $170 = Math_fround($168 + $169);
 $171 = Math_fround($59 * $148);
 $172 = Math_fround($60 * $151);
 $173 = Math_fround($171 + $172);
 $174 = Math_fround($61 * $155);
 $175 = Math_fround($173 + $174);
 $176 = Math_fround($120 + $165);
 $177 = Math_fround($122 + $170);
 $178 = Math_fround($124 + $175);
 $179 = Math_fround($79 * $126);
 $180 = Math_fround($80 * $129);
 $181 = Math_fround($179 + $180);
 $182 = Math_fround($81 * $133);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround($79 * $137);
 $185 = Math_fround($80 * $140);
 $186 = Math_fround($184 + $185);
 $187 = Math_fround($81 * $144);
 $188 = Math_fround($186 + $187);
 $189 = Math_fround($79 * $148);
 $190 = Math_fround($80 * $151);
 $191 = Math_fround($189 + $190);
 $192 = Math_fround($81 * $155);
 $193 = Math_fround($191 + $192);
 $194 = Math_fround($120 + $183);
 $195 = Math_fround($122 + $188);
 $196 = Math_fround($124 + $193);
 $197 = (($triangleV$i) + 64|0);
 $198 = (($triangleV$i) + 80|0);
 HEAP32[$198>>2] = 7;
 $199 = (($triangleV$i) + 16|0);
 $200 = (($triangleV$i) + 20|0);
 $201 = (($triangleV$i) + 32|0);
 $202 = (($triangleV$i) + 36|0);
 $203 = (($triangleV$i) + 48|0);
 HEAPF32[$203>>2] = Math_fround(0.0);
 $204 = (($triangleV$i) + 52|0);
 ;HEAP32[$204+0>>2]=HEAP32[$zero$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$204+4>>2]=HEAP32[$zero$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$204+8>>2]=HEAP32[$zero$sroa$1$i$i$i$i+8>>2]|0;
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 ;HEAP32[$197+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$197+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$197+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$197+12>>2]=HEAP32[$2+12>>2]|0;
 $205 = Math_fround($158 + $176);
 $206 = Math_fround($159 + $177);
 $207 = Math_fround($160 + $178);
 $208 = Math_fround($194 + $205);
 $209 = Math_fround($195 + $206);
 $210 = Math_fround($196 + $207);
 $211 = Math_fround($208 * Math_fround(0.333332985639572143555));
 $212 = Math_fround($209 * Math_fround(0.333332985639572143555));
 $213 = Math_fround($210 * Math_fround(0.333332985639572143555));
 HEAPF32[$triangleV$i>>2] = $211;
 $214 = (($triangleV$i) + 4|0);
 HEAPF32[$214>>2] = $212;
 $215 = (($triangleV$i) + 8|0);
 HEAPF32[$215>>2] = $213;
 $216 = (($triangleV$i) + 12|0);
 HEAPF32[$216>>2] = Math_fround(0.0);
 $217 = (($triangleV$i) + 96|0);
 HEAPF32[$217>>2] = $158;
 $218 = (($triangleV$i) + 100|0);
 HEAPF32[$218>>2] = $159;
 $219 = (($triangleV$i) + 104|0);
 HEAPF32[$219>>2] = $160;
 $220 = (($triangleV$i) + 108|0);
 HEAPF32[$220>>2] = Math_fround(0.0);
 $221 = (($triangleV$i) + 112|0);
 HEAPF32[$221>>2] = $176;
 $222 = (($triangleV$i) + 116|0);
 HEAPF32[$222>>2] = $177;
 $223 = (($triangleV$i) + 120|0);
 HEAPF32[$223>>2] = $178;
 $224 = (($triangleV$i) + 124|0);
 HEAPF32[$224>>2] = Math_fround(0.0);
 $225 = (($triangleV$i) + 128|0);
 HEAPF32[$225>>2] = $194;
 $226 = (($triangleV$i) + 132|0);
 HEAPF32[$226>>2] = $195;
 $227 = (($triangleV$i) + 136|0);
 HEAPF32[$227>>2] = $196;
 $228 = (($triangleV$i) + 140|0);
 HEAPF32[$228>>2] = Math_fround(0.0);
 HEAPF32[$199>>2] = Math_fround(0.0);
 ;HEAP32[$200+0>>2]=HEAP32[$$sroa$113$i$i$i+0>>2]|0;HEAP32[$200+4>>2]=HEAP32[$$sroa$113$i$i$i+4>>2]|0;HEAP32[$200+8>>2]=HEAP32[$$sroa$113$i$i$i+8>>2]|0;
 HEAPF32[$201>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$202+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$202+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$202+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $229 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_9TriangleVERNS0_11ConvexHullVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($triangleV$i,$84,$zero$i,$zeroV$i,$85,$toi$i,$normal$i,$closestA$i,$90,0)|0);
 if (!($229)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $230 = (($this) + 288|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($this) + 292|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = (($this) + 296|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = (($this) + 300|0);
 $237 = Math_fround(HEAPF32[$236>>2]);
 $238 = (($this) + 304|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($this) + 308|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = (($this) + 312|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = Math_fround(HEAPF32[$closestA$i>>2]);
 $245 = (($closestA$i) + 4|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = (($closestA$i) + 8|0);
 $248 = Math_fround(HEAPF32[$247>>2]);
 $249 = Math_fround($237 * $237);
 $250 = Math_fround($249 + Math_fround(-0.5));
 $251 = Math_fround($250 * $244);
 $252 = Math_fround($250 * $246);
 $253 = Math_fround($250 * $248);
 $254 = Math_fround($233 * $248);
 $255 = Math_fround($235 * $246);
 $256 = Math_fround($254 - $255);
 $257 = Math_fround($235 * $244);
 $258 = Math_fround($231 * $248);
 $259 = Math_fround($257 - $258);
 $260 = Math_fround($231 * $246);
 $261 = Math_fround($233 * $244);
 $262 = Math_fround($260 - $261);
 $263 = Math_fround($237 * $256);
 $264 = Math_fround($237 * $259);
 $265 = Math_fround($237 * $262);
 $266 = Math_fround($251 + $263);
 $267 = Math_fround($252 + $264);
 $268 = Math_fround($253 + $265);
 $269 = Math_fround($231 * $244);
 $270 = Math_fround($233 * $246);
 $271 = Math_fround($269 + $270);
 $272 = Math_fround($235 * $248);
 $273 = Math_fround($271 + $272);
 $274 = Math_fround($231 * $273);
 $275 = Math_fround($233 * $273);
 $276 = Math_fround($235 * $273);
 $277 = Math_fround($274 + $266);
 $278 = Math_fround($275 + $267);
 $279 = Math_fround($268 + $276);
 $280 = Math_fround($277 * Math_fround(2.0));
 $281 = Math_fround($278 * Math_fround(2.0));
 $282 = Math_fround($279 * Math_fround(2.0));
 $283 = Math_fround($239 + $280);
 $284 = Math_fround($241 + $281);
 $285 = Math_fround($243 + $282);
 $286 = Math_fround(HEAPF32[$normal$i>>2]);
 $287 = (($normal$i) + 4|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $289 = (($normal$i) + 8|0);
 $290 = Math_fround(HEAPF32[$289>>2]);
 $291 = Math_fround($250 * $286);
 $292 = Math_fround($250 * $288);
 $293 = Math_fround($250 * $290);
 $294 = Math_fround($233 * $290);
 $295 = Math_fround($235 * $288);
 $296 = Math_fround($294 - $295);
 $297 = Math_fround($235 * $286);
 $298 = Math_fround($231 * $290);
 $299 = Math_fround($297 - $298);
 $300 = Math_fround($231 * $288);
 $301 = Math_fround($233 * $286);
 $302 = Math_fround($300 - $301);
 $303 = Math_fround($237 * $296);
 $304 = Math_fround($237 * $299);
 $305 = Math_fround($237 * $302);
 $306 = Math_fround($291 + $303);
 $307 = Math_fround($292 + $304);
 $308 = Math_fround($293 + $305);
 $309 = Math_fround($231 * $286);
 $310 = Math_fround($233 * $288);
 $311 = Math_fround($309 + $310);
 $312 = Math_fround($235 * $290);
 $313 = Math_fround($311 + $312);
 $314 = Math_fround($231 * $313);
 $315 = Math_fround($233 * $313);
 $316 = Math_fround($235 * $313);
 $317 = Math_fround($314 + $306);
 $318 = Math_fround($315 + $307);
 $319 = Math_fround($308 + $316);
 $320 = Math_fround($317 * Math_fround(2.0));
 $321 = Math_fround($318 * Math_fround(2.0));
 $322 = Math_fround($319 * Math_fround(2.0));
 $323 = Math_fround($320 * $320);
 $324 = Math_fround($321 * $321);
 $325 = Math_fround($323 + $324);
 $326 = Math_fround($322 * $322);
 $327 = Math_fround($326 + $325);
 $328 = (Math_fround(Math_sqrt((Math_fround($327)))));
 $329 = Math_fround(Math_fround(1.0) / $328);
 $330 = Math_fround($329 * $320);
 $331 = Math_fround($329 * $321);
 $332 = Math_fround($329 * $322);
 $333 = Math_fround(HEAPF32[$zero$i>>2]);
 $334 = Math_fround(HEAPF32[$toi$i>>2]);
 $335 = !($333 >= $334);
 do {
  if ($335) {
   $349 = (($this) + 384|0);
   $350 = Math_fround(HEAPF32[$349>>2]);
   $351 = Math_fround($334 * $350);
   $352 = $351 < $83;
   if ($352) {
    $353 = (($this) + 336|0);
    HEAP16[$353>>1] = 7;
    $354 = (($this) + 340|0);
    HEAPF32[$354>>2] = $283;
    $355 = (($this) + 344|0);
    HEAPF32[$355>>2] = $284;
    $356 = (($this) + 348|0);
    HEAPF32[$356>>2] = $285;
    $357 = (($this) + 352|0);
    HEAPF32[$357>>2] = $330;
    $358 = (($this) + 356|0);
    HEAPF32[$358>>2] = $331;
    $359 = (($this) + 360|0);
    HEAPF32[$359>>2] = $332;
    HEAPF32[$82>>2] = $351;
    $368 = $351;
    break;
   } else {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $336 = (($this) + 336|0);
   HEAP16[$336>>1] = 6;
   HEAPF32[$82>>2] = Math_fround(0.0);
   $337 = (($this) + 416|0);
   $338 = Math_fround(HEAPF32[$337>>2]);
   $339 = Math_fround(-$338);
   $340 = (($this) + 420|0);
   $341 = Math_fround(HEAPF32[$340>>2]);
   $342 = Math_fround(-$341);
   $343 = (($this) + 424|0);
   $344 = Math_fround(HEAPF32[$343>>2]);
   $345 = Math_fround(-$344);
   $346 = (($this) + 352|0);
   HEAPF32[$346>>2] = $339;
   $347 = (($this) + 356|0);
   HEAPF32[$347>>2] = $342;
   $348 = (($this) + 360|0);
   HEAPF32[$348>>2] = $345;
   HEAP8[$91>>0] = 1;
   $368 = Math_fround(0.0);
  }
 } while(0);
 $360 = (($this) + 449|0);
 HEAP8[$360>>0] = 1;
 $361 = (($hit) + 8|0);
 $362 = HEAP32[$361>>2]|0;
 $363 = (($this) + 332|0);
 HEAP32[$363>>2] = $362;
 $364 = (($this) + 446|0);
 $365 = HEAP8[$364>>0]|0;
 $366 = ($365<<24>>24)==(0);
 if (!($366)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $367 = $368 == Math_fround(0.0);
 if (!($367)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $369 = (($this) + 444|0);
 $370 = HEAP16[$369>>1]|0;
 $371 = $370 & 32;
 $372 = ($371<<16>>16)!=(0);
 $$0 = $372;
 STACKTOP = sp;return ($$0|0);
}
function __ZN25ConvexVsMeshSweepCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN23SweepBoxMeshHitCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$meshHit,$lp0,$lp1,$lp2,$shrinkMaxT,$0) {
 $this = $this|0;
 $meshHit = $meshHit|0;
 $lp0 = $lp0|0;
 $lp1 = $lp1|0;
 $lp2 = $lp2|0;
 $shrinkMaxT = $shrinkMaxT|0;
 $0 = $0|0;
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$3 = 0, $$sroa$1 = 0, $$sroa$1$i$i = 0, $$sroa$113$i$i = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0;
 var $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0;
 var $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0);
 var $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0;
 var $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0;
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0);
 var $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0);
 var $308 = Math_fround(0), $309 = 0, $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0);
 var $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0);
 var $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0);
 var $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0);
 var $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0), $419 = 0, $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $boxV = 0, $closestA = 0, $lambda = 0, $normal = 0, $t = 0, $triangleV = 0, $zero = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 496|0;
 $1 = sp + 368|0;
 $2 = sp + 432|0;
 $$sroa$113$i$i = sp + 448|0;
 $$sroa$1$i$i = sp + 460|0;
 $t = sp + 484|0;
 $zeroV = sp + 416|0;
 $zero = sp + 352|0;
 $boxV = sp + 192|0;
 $triangleV = sp + 48|0;
 $lambda = sp + 32|0;
 $closestA = sp + 16|0;
 $normal = sp;
 $$sroa$1 = sp + 472|0;
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 & 256;
 $7 = ($6<<16>>16)==(0);
 if (!($7)) {
  $8 = (($this) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = Math_fround(HEAPF32[$lp0>>2]);
  $11 = Math_fround(HEAPF32[$9>>2]);
  $12 = Math_fround($10 * $11);
  $13 = (($9) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($10 * $14);
  $16 = (($9) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($10 * $17);
  $19 = (($lp0) + 4|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($9) + 12|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($20 * $22);
  $24 = (($9) + 16|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($20 * $25);
  $27 = (($9) + 20|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround($20 * $28);
  $30 = Math_fround($12 + $23);
  $31 = Math_fround($15 + $26);
  $32 = Math_fround($18 + $29);
  $33 = (($lp0) + 8|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($9) + 24|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($34 * $36);
  $38 = (($9) + 28|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($34 * $39);
  $41 = (($9) + 32|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($34 * $42);
  $44 = Math_fround($30 + $37);
  $45 = Math_fround($31 + $40);
  $46 = Math_fround($32 + $43);
  $47 = (($9) + 36|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($44 + $48);
  $50 = (($9) + 40|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($45 + $51);
  $53 = (($9) + 44|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($46 + $54);
  HEAPF32[$1>>2] = $49;
  $56 = (($1) + 4|0);
  HEAPF32[$56>>2] = $52;
  $57 = (($1) + 8|0);
  HEAPF32[$57>>2] = $55;
  $58 = Math_fround(HEAPF32[$lp1>>2]);
  $59 = Math_fround(HEAPF32[$9>>2]);
  $60 = Math_fround($58 * $59);
  $61 = Math_fround(HEAPF32[$13>>2]);
  $62 = Math_fround($58 * $61);
  $63 = Math_fround(HEAPF32[$16>>2]);
  $64 = Math_fround($58 * $63);
  $65 = (($lp1) + 4|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround(HEAPF32[$21>>2]);
  $68 = Math_fround($66 * $67);
  $69 = Math_fround(HEAPF32[$24>>2]);
  $70 = Math_fround($66 * $69);
  $71 = Math_fround(HEAPF32[$27>>2]);
  $72 = Math_fround($66 * $71);
  $73 = Math_fround($60 + $68);
  $74 = Math_fround($62 + $70);
  $75 = Math_fround($64 + $72);
  $76 = (($lp1) + 8|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = Math_fround(HEAPF32[$35>>2]);
  $79 = Math_fround($77 * $78);
  $80 = Math_fround(HEAPF32[$38>>2]);
  $81 = Math_fround($77 * $80);
  $82 = Math_fround(HEAPF32[$41>>2]);
  $83 = Math_fround($77 * $82);
  $84 = Math_fround($73 + $79);
  $85 = Math_fround($74 + $81);
  $86 = Math_fround($75 + $83);
  $87 = Math_fround(HEAPF32[$47>>2]);
  $88 = Math_fround($84 + $87);
  $89 = Math_fround(HEAPF32[$50>>2]);
  $90 = Math_fround($85 + $89);
  $91 = Math_fround(HEAPF32[$53>>2]);
  $92 = Math_fround($86 + $91);
  $93 = (($1) + 12|0);
  HEAPF32[$93>>2] = $88;
  $94 = (($1) + 16|0);
  HEAPF32[$94>>2] = $90;
  $95 = (($1) + 20|0);
  HEAPF32[$95>>2] = $92;
  $96 = Math_fround(HEAPF32[$lp2>>2]);
  $97 = Math_fround(HEAPF32[$9>>2]);
  $98 = Math_fround($96 * $97);
  $99 = Math_fround(HEAPF32[$13>>2]);
  $100 = Math_fround($96 * $99);
  $101 = Math_fround(HEAPF32[$16>>2]);
  $102 = Math_fround($96 * $101);
  $103 = (($lp2) + 4|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = Math_fround(HEAPF32[$21>>2]);
  $106 = Math_fround($104 * $105);
  $107 = Math_fround(HEAPF32[$24>>2]);
  $108 = Math_fround($104 * $107);
  $109 = Math_fround(HEAPF32[$27>>2]);
  $110 = Math_fround($104 * $109);
  $111 = Math_fround($98 + $106);
  $112 = Math_fround($100 + $108);
  $113 = Math_fround($102 + $110);
  $114 = (($lp2) + 8|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround(HEAPF32[$35>>2]);
  $117 = Math_fround($115 * $116);
  $118 = Math_fround(HEAPF32[$38>>2]);
  $119 = Math_fround($115 * $118);
  $120 = Math_fround(HEAPF32[$41>>2]);
  $121 = Math_fround($115 * $120);
  $122 = Math_fround($111 + $117);
  $123 = Math_fround($112 + $119);
  $124 = Math_fround($113 + $121);
  $125 = Math_fround(HEAPF32[$47>>2]);
  $126 = Math_fround($122 + $125);
  $127 = Math_fround(HEAPF32[$50>>2]);
  $128 = Math_fround($123 + $127);
  $129 = Math_fround(HEAPF32[$53>>2]);
  $130 = Math_fround($124 + $129);
  $131 = (($1) + 24|0);
  HEAPF32[$131>>2] = $126;
  $132 = (($1) + 28|0);
  HEAPF32[$132>>2] = $128;
  $133 = (($1) + 32|0);
  HEAPF32[$133>>2] = $130;
  HEAPF32[$t>>2] = Math_fround(3.40282346638528859812E+38);
  $134 = (($this) + 52|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + 48|0);
  $137 = (($this) + 64|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = (($this) + 196|0);
  $140 = (($this) + 12|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = (($this) + 48|0);
  $143 = HEAP8[$142>>0]|0;
  $144 = ($143<<24>>24)!=(0);
  $145 = (__ZN5physx2Gu23triBoxSweepTestBoxSpaceERKNS_10PxTriangleERKNS_6PxVec3ES6_S6_fRfb($1,$136,$138,$139,$141,$t,$144)|0);
  $146 = ($145|0)==(0);
  if ($146) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  $147 = Math_fround(HEAPF32[$t>>2]);
  $148 = Math_fround(HEAPF32[$140>>2]);
  $149 = !($147 <= $148);
  if ($149) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  HEAPF32[$140>>2] = $147;
  HEAPF32[$shrinkMaxT>>2] = $147;
  $150 = Math_fround(HEAPF32[$1>>2]);
  $151 = Math_fround(HEAPF32[$56>>2]);
  $152 = Math_fround(HEAPF32[$57>>2]);
  $153 = (($this) + 128|0);
  HEAPF32[$153>>2] = $150;
  $154 = (($this) + 132|0);
  HEAPF32[$154>>2] = $151;
  $155 = (($this) + 136|0);
  HEAPF32[$155>>2] = $152;
  $156 = (($this) + 140|0);
  HEAPF32[$156>>2] = Math_fround(0.0);
  $157 = (($this) + 68|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = Math_fround(-$159);
  $161 = (($158) + 4|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround(-$162);
  $164 = (($158) + 8|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  $166 = Math_fround(-$165);
  $167 = (($this) + 144|0);
  HEAPF32[$167>>2] = $160;
  $168 = (($this) + 148|0);
  HEAPF32[$168>>2] = $163;
  $169 = (($this) + 152|0);
  HEAPF32[$169>>2] = $166;
  $170 = (($this) + 156|0);
  HEAPF32[$170>>2] = Math_fround(0.0);
  $171 = (($this) + 76|0);
  HEAP8[$171>>0] = 1;
  $172 = (($meshHit) + 8|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = (($this) + 192|0);
  HEAP32[$174>>2] = $173;
  $175 = (($this) + 84|0);
  HEAPF32[$175>>2] = $150;
  $176 = (($this) + 88|0);
  HEAPF32[$176>>2] = $151;
  $177 = (($this) + 92|0);
  HEAPF32[$177>>2] = $152;
  $178 = Math_fround(HEAPF32[$93>>2]);
  $179 = (($this) + 96|0);
  HEAPF32[$179>>2] = $178;
  $180 = Math_fround(HEAPF32[$94>>2]);
  $181 = (($this) + 100|0);
  HEAPF32[$181>>2] = $180;
  $182 = Math_fround(HEAPF32[$95>>2]);
  $183 = (($this) + 104|0);
  HEAPF32[$183>>2] = $182;
  $184 = Math_fround(HEAPF32[$131>>2]);
  $185 = (($this) + 108|0);
  HEAPF32[$185>>2] = $184;
  $186 = Math_fround(HEAPF32[$132>>2]);
  $187 = (($this) + 112|0);
  HEAPF32[$187>>2] = $186;
  $188 = Math_fround(HEAPF32[$133>>2]);
  $189 = (($this) + 116|0);
  HEAPF32[$189>>2] = $188;
  $190 = $147 == Math_fround(0.0);
  if (!($190)) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  $191 = (($this) + 77|0);
  HEAP8[$191>>0] = 1;
  $$3 = 0;
  STACKTOP = sp;return ($$3|0);
 }
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 $192 = (($this) + 52|0);
 $193 = HEAP32[$192>>2]|0;
 $194 = (($193) + 48|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = (($193) + 52|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = (($193) + 56|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($boxV) + 64|0);
 ;HEAP32[$boxV+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$boxV+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$boxV+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$boxV+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $201 = (($boxV) + 80|0);
 HEAP32[$201>>2] = 3;
 $202 = (($boxV) + 16|0);
 $203 = (($boxV) + 20|0);
 ;HEAP32[$203+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$203+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$203+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 $204 = (($boxV) + 32|0);
 $205 = (($boxV) + 36|0);
 $206 = (($boxV) + 48|0);
 HEAPF32[$206>>2] = Math_fround(0.0);
 $207 = (($boxV) + 52|0);
 ;HEAP32[$207+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$207+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$207+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 ;HEAP32[$200+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$200+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$200+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$200+12>>2]=HEAP32[$1+12>>2]|0;
 $208 = (($boxV) + 144|0);
 HEAPF32[$208>>2] = $195;
 $209 = (($boxV) + 148|0);
 HEAPF32[$209>>2] = $197;
 $210 = (($boxV) + 152|0);
 HEAPF32[$210>>2] = $199;
 $211 = (($boxV) + 156|0);
 HEAPF32[$211>>2] = Math_fround(0.0);
 $212 = !($195 <= $197);
 $$$i26$i$i$i = $212 ? $197 : $195;
 $213 = !($$$i26$i$i$i <= $199);
 $214 = $213 ? $199 : $$$i26$i$i$i;
 $215 = !($195 >= $197);
 $$$i23$i$i$i = $215 ? $197 : $195;
 $216 = !($$$i23$i$i$i >= $199);
 $217 = $216 ? $199 : $$$i23$i$i$i;
 $218 = Math_fround($214 * Math_fround(0.150000005960464477539));
 $219 = Math_fround($217 * Math_fround(0.0299999993294477462769));
 $220 = $218 > $219;
 $$$i12$i$i$i = $220 ? $218 : $219;
 $221 = $214 > $$$i12$i$i$i;
 $$$i$i$i$i = $221 ? $$$i12$i$i$i : $214;
 HEAPF32[$202>>2] = $$$i$i$i$i;
 ;HEAP32[$203+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$203+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$203+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 $222 = Math_fround($214 * Math_fround(0.0500000007450580596924));
 HEAPF32[$204>>2] = $222;
 ;HEAP32[$205+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$205+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$205+8>>2]=HEAP32[$1+8>>2]|0;
 $223 = (($this) + 48|0);
 $224 = HEAP8[$223>>0]|0;
 $225 = ($224<<24>>24)==(0);
 $226 = (($this) + 8|0);
 $227 = HEAP32[$226>>2]|0;
 $228 = Math_fround(HEAPF32[$lp0>>2]);
 $229 = Math_fround(HEAPF32[$227>>2]);
 $230 = Math_fround($228 * $229);
 $231 = (($227) + 4|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = Math_fround($228 * $232);
 $234 = (($227) + 8|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = Math_fround($228 * $235);
 $237 = (($lp0) + 4|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = (($227) + 12|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 $241 = Math_fround($238 * $240);
 $242 = (($227) + 16|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = Math_fround($238 * $243);
 $245 = (($227) + 20|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = Math_fround($238 * $246);
 $248 = Math_fround($230 + $241);
 $249 = Math_fround($233 + $244);
 $250 = Math_fround($236 + $247);
 $251 = (($lp0) + 8|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 $253 = (($227) + 24|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = Math_fround($252 * $254);
 $256 = (($227) + 28|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = Math_fround($252 * $257);
 $259 = (($227) + 32|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = Math_fround($252 * $260);
 $262 = Math_fround($248 + $255);
 $263 = Math_fround($249 + $258);
 $264 = Math_fround($250 + $261);
 $265 = (($227) + 36|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = Math_fround($262 + $266);
 $268 = (($227) + 40|0);
 $269 = Math_fround(HEAPF32[$268>>2]);
 $270 = Math_fround($263 + $269);
 $271 = (($227) + 44|0);
 $272 = Math_fround(HEAPF32[$271>>2]);
 $273 = Math_fround($264 + $272);
 $274 = Math_fround(HEAPF32[$lp1>>2]);
 $275 = Math_fround($229 * $274);
 $276 = Math_fround($232 * $274);
 $277 = Math_fround($235 * $274);
 $278 = (($lp1) + 4|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = Math_fround($240 * $279);
 $281 = Math_fround($243 * $279);
 $282 = Math_fround($246 * $279);
 $283 = Math_fround($275 + $280);
 $284 = Math_fround($276 + $281);
 $285 = Math_fround($277 + $282);
 $286 = (($lp1) + 8|0);
 $287 = Math_fround(HEAPF32[$286>>2]);
 $288 = Math_fround($254 * $287);
 $289 = Math_fround($257 * $287);
 $290 = Math_fround($260 * $287);
 $291 = Math_fround($283 + $288);
 $292 = Math_fround($284 + $289);
 $293 = Math_fround($285 + $290);
 $294 = Math_fround($266 + $291);
 $295 = Math_fround($269 + $292);
 $296 = Math_fround($272 + $293);
 $297 = Math_fround(HEAPF32[$lp2>>2]);
 $298 = Math_fround($229 * $297);
 $299 = Math_fround($232 * $297);
 $300 = Math_fround($235 * $297);
 $301 = (($lp2) + 4|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = Math_fround($240 * $302);
 $304 = Math_fround($243 * $302);
 $305 = Math_fround($246 * $302);
 $306 = Math_fround($298 + $303);
 $307 = Math_fround($299 + $304);
 $308 = Math_fround($300 + $305);
 $309 = (($lp2) + 8|0);
 $310 = Math_fround(HEAPF32[$309>>2]);
 $311 = Math_fround($254 * $310);
 $312 = Math_fround($257 * $310);
 $313 = Math_fround($260 * $310);
 $314 = Math_fround($306 + $311);
 $315 = Math_fround($307 + $312);
 $316 = Math_fround($308 + $313);
 $317 = Math_fround($266 + $314);
 $318 = Math_fround($269 + $315);
 $319 = Math_fround($272 + $316);
 $320 = Math_fround($317 - $294);
 $321 = Math_fround($318 - $295);
 $322 = Math_fround($319 - $296);
 $323 = Math_fround($267 - $294);
 $324 = Math_fround($270 - $295);
 $325 = Math_fround($273 - $296);
 if ($225) {
  $326 = Math_fround($323 * $321);
  $327 = Math_fround($324 * $320);
  $328 = Math_fround($325 * $320);
  $329 = Math_fround($323 * $322);
  $330 = Math_fround($324 * $322);
  $331 = Math_fround($325 * $321);
  $332 = Math_fround($327 - $326);
  $333 = Math_fround($329 - $328);
  $334 = Math_fround($331 - $330);
  $335 = (($this) + 176|0);
  $336 = Math_fround(HEAPF32[$335>>2]);
  $337 = (($this) + 180|0);
  $338 = Math_fround(HEAPF32[$337>>2]);
  $339 = (($this) + 184|0);
  $340 = Math_fround(HEAPF32[$339>>2]);
  $341 = Math_fround($334 * $336);
  $342 = Math_fround($333 * $338);
  $343 = Math_fround($341 + $342);
  $344 = Math_fround($332 * $340);
  $345 = Math_fround($343 + $344);
  $346 = Math_fround(HEAPF32[$zero>>2]);
  $347 = !($345 >= $346);
  if (!($347)) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
 }
 $348 = (($triangleV) + 64|0);
 $349 = (($triangleV) + 80|0);
 HEAP32[$349>>2] = 7;
 $350 = (($triangleV) + 16|0);
 $351 = (($triangleV) + 20|0);
 $352 = (($triangleV) + 32|0);
 $353 = (($triangleV) + 36|0);
 $354 = (($triangleV) + 48|0);
 HEAPF32[$354>>2] = Math_fround(0.0);
 $355 = (($triangleV) + 52|0);
 ;HEAP32[$355+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$355+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$355+8>>2]=HEAP32[$1+8>>2]|0;
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 ;HEAP32[$348+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$348+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$348+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$348+12>>2]=HEAP32[$2+12>>2]|0;
 $356 = Math_fround($267 + $294);
 $357 = Math_fround($270 + $295);
 $358 = Math_fround($273 + $296);
 $359 = Math_fround($356 + $317);
 $360 = Math_fround($357 + $318);
 $361 = Math_fround($358 + $319);
 $362 = Math_fround($359 * Math_fround(0.333332985639572143555));
 $363 = Math_fround($360 * Math_fround(0.333332985639572143555));
 $364 = Math_fround($361 * Math_fround(0.333332985639572143555));
 HEAPF32[$triangleV>>2] = $362;
 $365 = (($triangleV) + 4|0);
 HEAPF32[$365>>2] = $363;
 $366 = (($triangleV) + 8|0);
 HEAPF32[$366>>2] = $364;
 $367 = (($triangleV) + 12|0);
 HEAPF32[$367>>2] = Math_fround(0.0);
 $368 = (($triangleV) + 96|0);
 HEAPF32[$368>>2] = $267;
 $369 = (($triangleV) + 100|0);
 HEAPF32[$369>>2] = $270;
 $370 = (($triangleV) + 104|0);
 HEAPF32[$370>>2] = $273;
 $371 = (($triangleV) + 108|0);
 HEAPF32[$371>>2] = Math_fround(0.0);
 $372 = (($triangleV) + 112|0);
 HEAPF32[$372>>2] = $294;
 $373 = (($triangleV) + 116|0);
 HEAPF32[$373>>2] = $295;
 $374 = (($triangleV) + 120|0);
 HEAPF32[$374>>2] = $296;
 $375 = (($triangleV) + 124|0);
 HEAPF32[$375>>2] = Math_fround(0.0);
 $376 = (($triangleV) + 128|0);
 HEAPF32[$376>>2] = $317;
 $377 = (($triangleV) + 132|0);
 HEAPF32[$377>>2] = $318;
 $378 = (($triangleV) + 136|0);
 HEAPF32[$378>>2] = $319;
 $379 = (($triangleV) + 140|0);
 HEAPF32[$379>>2] = Math_fround(0.0);
 HEAPF32[$350>>2] = Math_fround(0.0);
 ;HEAP32[$351+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$351+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$351+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 HEAPF32[$352>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$353+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$353+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$353+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
 $380 = (($this) + 176|0);
 $381 = (($this) + 80|0);
 $382 = Math_fround(HEAPF32[$381>>2]);
 $383 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_9TriangleVERNS0_4BoxVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($triangleV,$boxV,$zero,$zeroV,$380,$lambda,$normal,$closestA,$382,0)|0);
 if (!($383)) {
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
 }
 $384 = (($this) + 76|0);
 HEAP8[$384>>0] = 1;
 $385 = (($this) + 128|0);
 ;HEAP32[$385+0>>2]=HEAP32[$closestA+0>>2]|0;HEAP32[$385+4>>2]=HEAP32[$closestA+4>>2]|0;HEAP32[$385+8>>2]=HEAP32[$closestA+8>>2]|0;HEAP32[$385+12>>2]=HEAP32[$closestA+12>>2]|0;
 $386 = (($meshHit) + 8|0);
 $387 = HEAP32[$386>>2]|0;
 $388 = (($this) + 192|0);
 HEAP32[$388>>2] = $387;
 $389 = Math_fround(HEAPF32[$zero>>2]);
 $390 = Math_fround(HEAPF32[$lambda>>2]);
 $391 = !($389 >= $390);
 if (!($391)) {
  $412 = (($this) + 77|0);
  HEAP8[$412>>0] = 1;
  HEAPF32[$shrinkMaxT>>2] = Math_fround(0.0);
  $413 = (($this) + 32|0);
  ;HEAP32[$413+0>>2]=HEAP32[$zero+0>>2]|0;HEAP32[$413+4>>2]=HEAP32[$zero+4>>2]|0;HEAP32[$413+8>>2]=HEAP32[$zero+8>>2]|0;HEAP32[$413+12>>2]=HEAP32[$zero+12>>2]|0;
  $414 = (($this) + 12|0);
  HEAPF32[$414>>2] = Math_fround(0.0);
  $415 = (($this) + 68|0);
  $416 = HEAP32[$415>>2]|0;
  $417 = Math_fround(HEAPF32[$416>>2]);
  $418 = Math_fround(-$417);
  $419 = (($416) + 4|0);
  $420 = Math_fround(HEAPF32[$419>>2]);
  $421 = Math_fround(-$420);
  $422 = (($416) + 8|0);
  $423 = Math_fround(HEAPF32[$422>>2]);
  $424 = Math_fround(-$423);
  $425 = (($this) + 144|0);
  HEAPF32[$425>>2] = $418;
  $426 = (($this) + 148|0);
  HEAPF32[$426>>2] = $421;
  $427 = (($this) + 152|0);
  HEAPF32[$427>>2] = $424;
  $428 = (($this) + 156|0);
  HEAPF32[$428>>2] = Math_fround(0.0);
  $429 = HEAP32[$3>>2]|0;
  $430 = HEAP16[$429>>1]|0;
  $431 = $430 & 32;
  $432 = ($431<<16>>16)!=(0);
  $$3 = $432;
  STACKTOP = sp;return ($$3|0);
 }
 $392 = (($this) + 12|0);
 $393 = Math_fround(HEAPF32[$392>>2]);
 $394 = Math_fround($390 * $393);
 HEAPF32[$392>>2] = $394;
 $395 = (($this) + 176|0);
 $396 = Math_fround(HEAPF32[$395>>2]);
 $397 = (($this) + 180|0);
 $398 = Math_fround(HEAPF32[$397>>2]);
 $399 = (($this) + 184|0);
 $400 = Math_fround(HEAPF32[$399>>2]);
 $401 = (($this) + 188|0);
 $402 = Math_fround($396 * $390);
 $403 = Math_fround($398 * $390);
 $404 = Math_fround($400 * $390);
 HEAPF32[$395>>2] = $402;
 HEAPF32[$397>>2] = $403;
 HEAPF32[$399>>2] = $404;
 HEAPF32[$401>>2] = Math_fround(0.0);
 $405 = (($this) + 32|0);
 $406 = Math_fround(HEAPF32[$405>>2]);
 $407 = (($this) + 36|0);
 $408 = Math_fround($406 * $390);
 HEAPF32[$405>>2] = $408;
 ;HEAP32[$407+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$407+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$407+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 $409 = (($this) + 144|0);
 ;HEAP32[$409+0>>2]=HEAP32[$normal+0>>2]|0;HEAP32[$409+4>>2]=HEAP32[$normal+4>>2]|0;HEAP32[$409+8>>2]=HEAP32[$normal+8>>2]|0;HEAP32[$409+12>>2]=HEAP32[$normal+12>>2]|0;
 $410 = Math_fround(HEAPF32[$shrinkMaxT>>2]);
 $411 = $394 < $410;
 if (!($411)) {
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
 }
 HEAPF32[$shrinkMaxT>>2] = $394;
 $$3 = 1;
 STACKTOP = sp;return ($$3|0);
}
function __ZN23SweepBoxMeshHitCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN20SweepCapsuleCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj($this,$aHit,$v0,$v1,$v2,$shrunkMaxT,$0) {
 $this = $this|0;
 $aHit = $aHit|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 $shrunkMaxT = $shrunkMaxT|0;
 $0 = $0|0;
 var $$0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0;
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $localDist = 0, $localIndex = 0, $localNormal = 0, $localPos = 0, $tmpt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpt = sp + 32|0;
 $localDist = sp;
 $localPos = sp + 4|0;
 $localNormal = sp + 16|0;
 $localIndex = sp + 28|0;
 $1 = sp + 68|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$v0>>2]);
 $5 = Math_fround(HEAPF32[$3>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($3) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($4 * $8);
 $10 = (($3) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($4 * $11);
 $13 = (($v0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($3) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = (($3) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($14 * $19);
 $21 = (($3) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($14 * $22);
 $24 = Math_fround($6 + $17);
 $25 = Math_fround($9 + $20);
 $26 = Math_fround($12 + $23);
 $27 = (($v0) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($3) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 * $30);
 $32 = (($3) + 28|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($28 * $33);
 $35 = (($3) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($28 * $36);
 $38 = Math_fround($24 + $31);
 $39 = Math_fround($25 + $34);
 $40 = Math_fround($26 + $37);
 $41 = (($3) + 36|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($38 + $42);
 $44 = (($3) + 40|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($39 + $45);
 $47 = (($3) + 44|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($40 + $48);
 HEAPF32[$tmpt>>2] = $43;
 $50 = (($tmpt) + 4|0);
 HEAPF32[$50>>2] = $46;
 $51 = (($tmpt) + 8|0);
 HEAPF32[$51>>2] = $49;
 $52 = Math_fround(HEAPF32[$v1>>2]);
 $53 = Math_fround(HEAPF32[$3>>2]);
 $54 = Math_fround($52 * $53);
 $55 = Math_fround(HEAPF32[$7>>2]);
 $56 = Math_fround($52 * $55);
 $57 = Math_fround(HEAPF32[$10>>2]);
 $58 = Math_fround($52 * $57);
 $59 = (($v1) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround(HEAPF32[$15>>2]);
 $62 = Math_fround($60 * $61);
 $63 = Math_fround(HEAPF32[$18>>2]);
 $64 = Math_fround($60 * $63);
 $65 = Math_fround(HEAPF32[$21>>2]);
 $66 = Math_fround($60 * $65);
 $67 = Math_fround($54 + $62);
 $68 = Math_fround($56 + $64);
 $69 = Math_fround($58 + $66);
 $70 = (($v1) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround(HEAPF32[$29>>2]);
 $73 = Math_fround($71 * $72);
 $74 = Math_fround(HEAPF32[$32>>2]);
 $75 = Math_fround($71 * $74);
 $76 = Math_fround(HEAPF32[$35>>2]);
 $77 = Math_fround($71 * $76);
 $78 = Math_fround($67 + $73);
 $79 = Math_fround($68 + $75);
 $80 = Math_fround($69 + $77);
 $81 = Math_fround(HEAPF32[$41>>2]);
 $82 = Math_fround($78 + $81);
 $83 = Math_fround(HEAPF32[$44>>2]);
 $84 = Math_fround($79 + $83);
 $85 = Math_fround(HEAPF32[$47>>2]);
 $86 = Math_fround($80 + $85);
 $87 = (($tmpt) + 12|0);
 HEAPF32[$87>>2] = $82;
 $88 = (($tmpt) + 16|0);
 HEAPF32[$88>>2] = $84;
 $89 = (($tmpt) + 20|0);
 HEAPF32[$89>>2] = $86;
 $90 = Math_fround(HEAPF32[$v2>>2]);
 $91 = Math_fround(HEAPF32[$3>>2]);
 $92 = Math_fround($90 * $91);
 $93 = Math_fround(HEAPF32[$7>>2]);
 $94 = Math_fround($90 * $93);
 $95 = Math_fround(HEAPF32[$10>>2]);
 $96 = Math_fround($90 * $95);
 $97 = (($v2) + 4|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround(HEAPF32[$15>>2]);
 $100 = Math_fround($98 * $99);
 $101 = Math_fround(HEAPF32[$18>>2]);
 $102 = Math_fround($98 * $101);
 $103 = Math_fround(HEAPF32[$21>>2]);
 $104 = Math_fround($98 * $103);
 $105 = Math_fround($92 + $100);
 $106 = Math_fround($94 + $102);
 $107 = Math_fround($96 + $104);
 $108 = (($v2) + 8|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround(HEAPF32[$29>>2]);
 $111 = Math_fround($109 * $110);
 $112 = Math_fround(HEAPF32[$32>>2]);
 $113 = Math_fround($109 * $112);
 $114 = Math_fround(HEAPF32[$35>>2]);
 $115 = Math_fround($109 * $114);
 $116 = Math_fround($105 + $111);
 $117 = Math_fround($106 + $113);
 $118 = Math_fround($107 + $115);
 $119 = Math_fround(HEAPF32[$41>>2]);
 $120 = Math_fround($116 + $119);
 $121 = Math_fround(HEAPF32[$44>>2]);
 $122 = Math_fround($117 + $121);
 $123 = Math_fround(HEAPF32[$47>>2]);
 $124 = Math_fround($118 + $123);
 $125 = (($tmpt) + 24|0);
 HEAPF32[$125>>2] = $120;
 $126 = (($tmpt) + 28|0);
 HEAPF32[$126>>2] = $122;
 $127 = (($tmpt) + 32|0);
 HEAPF32[$127>>2] = $124;
 $128 = (($this) + 28|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = (($this) + 32|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = (($this) + 20|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($this) + 8|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($135) + 12|0);
 $137 = (($this) + 36|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = HEAP16[$138>>1]|0;
 HEAP16[$1>>1] = $139;
 $140 = (($this) + 24|0);
 $141 = HEAP8[$140>>0]|0;
 $142 = ($141<<24>>24)!=(0);
 $143 = (__ZN5physx2Gu21sweepCapsuleTrianglesEjPKNS_10PxTriangleERKNS0_7CapsuleERKNS_6PxVec3EfPKjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEERfRS7_SI_RjSF_bPKNS0_3BoxE(1,$tmpt,$129,$131,$133,0,$136,$localDist,$localNormal,$localPos,$localIndex,$1,$142,0)|0);
 do {
  if ($143) {
   $144 = Math_fround(HEAPF32[$localDist>>2]);
   $145 = HEAP32[$134>>2]|0;
   $146 = (($145) + 40|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = $144 < $147;
   if ($148) {
    HEAPF32[$132>>2] = $144;
    HEAPF32[$shrunkMaxT>>2] = $144;
    $149 = HEAP32[$134>>2]|0;
    $150 = (($149) + 40|0);
    HEAPF32[$150>>2] = $144;
    $151 = HEAP32[$134>>2]|0;
    $152 = Math_fround(HEAPF32[$localNormal>>2]);
    $153 = (($151) + 28|0);
    HEAPF32[$153>>2] = $152;
    $154 = (($localNormal) + 4|0);
    $155 = Math_fround(HEAPF32[$154>>2]);
    $156 = (($151) + 32|0);
    HEAPF32[$156>>2] = $155;
    $157 = (($localNormal) + 8|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = (($151) + 36|0);
    HEAPF32[$159>>2] = $158;
    $160 = HEAP32[$134>>2]|0;
    $161 = Math_fround(HEAPF32[$localPos>>2]);
    $162 = (($160) + 16|0);
    HEAPF32[$162>>2] = $161;
    $163 = (($localPos) + 4|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = (($160) + 20|0);
    HEAPF32[$165>>2] = $164;
    $166 = (($localPos) + 8|0);
    $167 = Math_fround(HEAPF32[$166>>2]);
    $168 = (($160) + 24|0);
    HEAPF32[$168>>2] = $167;
    $169 = (($aHit) + 8|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = HEAP32[$134>>2]|0;
    $172 = (($171) + 8|0);
    HEAP32[$172>>2] = $170;
    $173 = (($this) + 40|0);
    HEAP8[$173>>0] = 1;
    $174 = Math_fround(HEAPF32[$localDist>>2]);
    $175 = $174 == Math_fround(0.0);
    if ($175) {
     $176 = (($this) + 41|0);
     HEAP8[$176>>0] = 1;
     $177 = HEAP32[$137>>2]|0;
     $178 = HEAP16[$177>>1]|0;
     $179 = $178 & 32;
     $180 = ($179<<16>>16)!=(0);
     $$0 = $180;
     STACKTOP = sp;return ($$0|0);
    } else {
     $181 = HEAP32[$137>>2]|0;
     $182 = HEAP16[$181>>1]|0;
     $183 = $182 & 64;
     $184 = ($183<<16>>16)==(0);
     if ($184) {
      break;
     } else {
      $$0 = 0;
     }
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SweepCapsuleCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12TriangleMesh15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx20InternalTriangleMesh15exportExtraDataERNS_22PxSerializationContextE($0,$stream);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12TriangleMeshC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 3;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 HEAP32[$this>>2] = ((553272 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = ((424432 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 1;
 HEAP32[$this>>2] = ((552728 + 8|0));
 HEAP32[$2>>2] = ((552728 + 88|0));
 $4 = (($this) + 16|0);
 __ZN5physx20InternalTriangleMeshC2Ev($4);
 $5 = (($this) + 144|0);
 HEAPF32[$5>>2] = Math_fround(8.50705866596322149529E+37);
 $6 = (($this) + 148|0);
 HEAPF32[$6>>2] = Math_fround(8.50705866596322149529E+37);
 $7 = (($this) + 152|0);
 HEAPF32[$7>>2] = Math_fround(8.50705866596322149529E+37);
 $8 = (($this) + 156|0);
 HEAPF32[$8>>2] = Math_fround(-8.50705866596322149529E+37);
 $9 = (($this) + 160|0);
 HEAPF32[$9>>2] = Math_fround(-8.50705866596322149529E+37);
 $10 = (($this) + 164|0);
 HEAPF32[$10>>2] = Math_fround(-8.50705866596322149529E+37);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12TriangleMeshD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((552728 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((552728 + 88|0));
 $2 = (($this) + 16|0);
 __ZN5physx20InternalTriangleMesh7releaseEv($2);
 __ZN5physx20InternalTriangleMeshD2Ev($2);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu12TriangleMeshD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 HEAP32[$1>>2] = ((552728 + 8|0));
 $2 = ($this);
 HEAP32[$2>>2] = ((552728 + 88|0));
 $3 = (($this) + 8|0);
 __ZN5physx20InternalTriangleMesh7releaseEv($3);
 __ZN5physx20InternalTriangleMeshD2Ev($3);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12TriangleMeshD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((552728 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = ((552728 + 88|0));
 $1 = (($this) + 16|0);
 __ZN5physx20InternalTriangleMesh7releaseEv($1);
 __ZN5physx20InternalTriangleMeshD2Ev($1);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu12TriangleMeshD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -8|0);
 HEAP32[$0>>2] = ((552728 + 8|0));
 $1 = ($this);
 HEAP32[$1>>2] = ((552728 + 88|0));
 $2 = (($this) + 8|0);
 __ZN5physx20InternalTriangleMesh7releaseEv($2);
 __ZN5physx20InternalTriangleMeshD2Ev($2);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12TriangleMesh14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 224|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx13GuMeshFactory18removeTriangleMeshERNS_14PxTriangleMeshE($1,$this)|0);
 if (!($2)) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($13,8,552832,98,552920,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$0>>2]|0;
 $4 = (($this) + 6|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 & 1;
 $7 = ($6<<16>>16)==(0);
 $8 = HEAP32[$this>>2]|0;
 if ($7) {
  $11 = (($8) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($this);
 } else {
  $9 = (($8) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 4095]($this);
 }
 __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($3,$this,3,1);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu12TriangleMesh14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + -8|0);
 $1 = (($this) + 216|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN5physx13GuMeshFactory18removeTriangleMeshERNS_14PxTriangleMeshE($2,$0)|0);
 if (!($3)) {
  $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,8,552832,98,552920,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$1>>2]|0;
 $5 = (($this) + -2|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6 & 1;
 $8 = ($7<<16>>16)==(0);
 $9 = HEAP32[$0>>2]|0;
 if ($8) {
  $12 = (($9) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($0);
 } else {
  $10 = (($9) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($0);
 }
 __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($4,$0,3,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12TriangleMesh4loadERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0);
 var $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond34 = 0, $exitcond35 = 0, $exitcond36 = 0, $exitcond37 = 0, $exitcond38 = 0, $i$032 = 0, $i1$027 = 0, $i10$08 = 0, $i12$012 = 0, $i13$04 = 0, $i14$01 = 0, $i2$023 = 0, $i4$016 = 0, $i7$020 = 0, $mismatch = 0;
 var $or$cond = 0, $or$cond39 = 0, $tris16$028 = 0, $tris169$07 = 0, $tris32$024 = 0, $tris325$019 = 0, $vararg_buffer = 0, $version = 0, $x = 0, $x6 = 0, $x8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $version = sp + 8|0;
 $mismatch = sp + 15|0;
 $x = sp + 14|0;
 $x6 = sp + 12|0;
 $x8 = sp + 4|0;
 $0 = (($this) + 16|0);
 __ZN5physx20InternalTriangleMesh7releaseEv($0);
 $1 = (__ZN5physx10readHeaderEaaaaRjRbRNS_13PxInputStreamE(77,69,83,72,$version,$mismatch,$stream)|0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP32[$version>>2]|0;
 $3 = ($2>>>0)<(10);
 if ($3) {
  $4 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($4,32,552832,115,552976,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP8[$mismatch>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($6,$stream)|0);
 $8 = HEAP8[$mismatch>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 $10 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($9,$stream)));
 $11 = (($this) + 192|0);
 HEAPF32[$11>>2] = $10;
 $12 = HEAP8[$mismatch>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 $14 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($13,$stream)|0);
 $15 = (__ZN5physx20InternalTriangleMesh16allocateVerticesEj($0,$14)|0);
 $16 = HEAP8[$mismatch>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($17,$stream)|0);
 $19 = (__ZN5physx20InternalTriangleMesh17allocateTrianglesEjb($0,$18,0)|0);
 $20 = HEAP32[$stream>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$0>>2]|0;
 $23 = ($22*12)|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($stream,$15,$23)|0);
 $24 = HEAP8[$mismatch>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if (!($25)) {
  $26 = HEAP32[$0>>2]|0;
  $27 = ($26|0)==(0);
  if (!($27)) {
   $i$032 = 0;
   while(1) {
    $28 = (($15) + (($i$032*12)|0)|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = (($28) + 3|0);
    $31 = HEAP8[$30>>0]|0;
    HEAP8[$28>>0] = $31;
    HEAP8[$30>>0] = $29;
    $32 = (($28) + 1|0);
    $33 = HEAP8[$32>>0]|0;
    $34 = (($28) + 2|0);
    $35 = HEAP8[$34>>0]|0;
    HEAP8[$32>>0] = $35;
    HEAP8[$34>>0] = $33;
    $36 = ((($15) + (($i$032*12)|0)|0) + 4|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = (($36) + 3|0);
    $39 = HEAP8[$38>>0]|0;
    HEAP8[$36>>0] = $39;
    HEAP8[$38>>0] = $37;
    $40 = (($36) + 1|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = (($36) + 2|0);
    $43 = HEAP8[$42>>0]|0;
    HEAP8[$40>>0] = $43;
    HEAP8[$42>>0] = $41;
    $44 = ((($15) + (($i$032*12)|0)|0) + 8|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = (($44) + 3|0);
    $47 = HEAP8[$46>>0]|0;
    HEAP8[$44>>0] = $47;
    HEAP8[$46>>0] = $45;
    $48 = (($44) + 1|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = (($44) + 2|0);
    $51 = HEAP8[$50>>0]|0;
    HEAP8[$48>>0] = $51;
    HEAP8[$50>>0] = $49;
    $52 = (($i$032) + 1)|0;
    $53 = HEAP32[$0>>2]|0;
    $54 = ($52>>>0)<($53>>>0);
    if ($54) {
     $i$032 = $52;
    } else {
     break;
    }
   }
  }
 }
 $55 = (($this) + 20|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56*3)|0;
 $58 = $7 & 4;
 $59 = ($58|0)==(0);
 L13: do {
  if ($59) {
   $77 = $7 & 8;
   $78 = ($77|0)==(0);
   $79 = (($this) + 172|0);
   $80 = HEAP8[$79>>0]|0;
   $81 = $80 & 2;
   $82 = ($81<<24>>24)!=(0);
   if ($78) {
    if (!($82)) {
     $129 = HEAP32[$stream>>2]|0;
     $130 = HEAP32[$129>>2]|0;
     $131 = ($56*12)|0;
     (FUNCTION_TABLE_iiii[$130 & 2047]($stream,$19,$131)|0);
     $132 = HEAP8[$mismatch>>0]|0;
     $133 = ($132<<24>>24)==(0);
     $134 = ($57|0)==(0);
     $or$cond39 = $133 | $134;
     if ($or$cond39) {
      break;
     } else {
      $i12$012 = 0;
     }
     while(1) {
      $135 = (($19) + ($i12$012<<2)|0);
      $136 = HEAP8[$135>>0]|0;
      $137 = (($135) + 3|0);
      $138 = HEAP8[$137>>0]|0;
      HEAP8[$135>>0] = $138;
      HEAP8[$137>>0] = $136;
      $139 = (($135) + 1|0);
      $140 = HEAP8[$139>>0]|0;
      $141 = (($135) + 2|0);
      $142 = HEAP8[$141>>0]|0;
      HEAP8[$139>>0] = $142;
      HEAP8[$141>>0] = $140;
      $143 = (($i12$012) + 1)|0;
      $exitcond34 = ($143|0)==($57|0);
      if ($exitcond34) {
       break L13;
      } else {
       $i12$012 = $143;
      }
     }
    }
    $108 = ($57|0)==(0);
    if ($108) {
     break;
    }
    $109 = (($x8) + 3|0);
    $110 = (($x8) + 1|0);
    $111 = (($x8) + 2|0);
    $i10$08 = 0;$tris169$07 = $19;
    while(1) {
     $112 = HEAP32[$stream>>2]|0;
     $113 = HEAP32[$112>>2]|0;
     (FUNCTION_TABLE_iiii[$113 & 2047]($stream,$x8,4)|0);
     $114 = HEAP8[$mismatch>>0]|0;
     $115 = ($114<<24>>24)==(0);
     if (!($115)) {
      $116 = HEAP32[$x8>>2]|0;
      $117 = $116&65535;
      $118 = $116&255;
      $119 = $116 >>> 24;
      $120 = $119&255;
      HEAP8[$x8>>0] = $120;
      HEAP8[$109>>0] = $118;
      $121 = ($117&65535) >>> 8;
      $122 = $121&255;
      $123 = $116 >>> 16;
      $124 = $123&255;
      HEAP8[$110>>0] = $124;
      HEAP8[$111>>0] = $122;
     }
     $125 = HEAP32[$x8>>2]|0;
     $126 = $125&65535;
     $127 = (($tris169$07) + 2|0);
     HEAP16[$tris169$07>>1] = $126;
     $128 = (($i10$08) + 1)|0;
     $exitcond = ($128|0)==($57|0);
     if ($exitcond) {
      break;
     } else {
      $i10$08 = $128;$tris169$07 = $127;
     }
    }
   } else {
    if ($82) {
     $83 = HEAP32[$stream>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = ($56*6)|0;
     (FUNCTION_TABLE_iiii[$84 & 2047]($stream,$19,$85)|0);
     $86 = HEAP8[$mismatch>>0]|0;
     $87 = ($86<<24>>24)==(0);
     $88 = ($57|0)==(0);
     $or$cond = $87 | $88;
     if ($or$cond) {
      break;
     } else {
      $i4$016 = 0;
     }
     while(1) {
      $89 = (($19) + ($i4$016<<1)|0);
      $90 = HEAP8[$89>>0]|0;
      $91 = (($89) + 1|0);
      $92 = HEAP8[$91>>0]|0;
      HEAP8[$89>>0] = $92;
      HEAP8[$91>>0] = $90;
      $93 = (($i4$016) + 1)|0;
      $exitcond35 = ($93|0)==($57|0);
      if ($exitcond35) {
       break L13;
      } else {
       $i4$016 = $93;
      }
     }
    }
    $94 = ($57|0)==(0);
    if ($94) {
     break;
    }
    $95 = (($x6) + 1|0);
    $i7$020 = 0;$tris325$019 = $19;
    while(1) {
     $96 = HEAP32[$stream>>2]|0;
     $97 = HEAP32[$96>>2]|0;
     (FUNCTION_TABLE_iiii[$97 & 2047]($stream,$x6,2)|0);
     $98 = HEAP8[$mismatch>>0]|0;
     $99 = ($98<<24>>24)==(0);
     if (!($99)) {
      $100 = HEAP16[$x6>>1]|0;
      $101 = $100&255;
      $102 = ($100&65535) >>> 8;
      $103 = $102&255;
      HEAP8[$x6>>0] = $103;
      HEAP8[$95>>0] = $101;
     }
     $104 = HEAP16[$x6>>1]|0;
     $105 = $104&65535;
     $106 = (($tris325$019) + 4|0);
     HEAP32[$tris325$019>>2] = $105;
     $107 = (($i7$020) + 1)|0;
     $exitcond36 = ($107|0)==($57|0);
     if ($exitcond36) {
      break;
     } else {
      $i7$020 = $107;$tris325$019 = $106;
     }
    }
   }
  } else {
   $60 = (($this) + 172|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61 & 2;
   $63 = ($62<<24>>24)==(0);
   $64 = ($57|0)==(0);
   if ($63) {
    if ($64) {
     break;
    }
    $i2$023 = 0;$tris32$024 = $19;
    while(1) {
     $71 = HEAP32[$stream>>2]|0;
     $72 = HEAP32[$71>>2]|0;
     (FUNCTION_TABLE_iiii[$72 & 2047]($stream,$x,1)|0);
     $73 = HEAP8[$x>>0]|0;
     $74 = $73&255;
     $75 = (($tris32$024) + 4|0);
     HEAP32[$tris32$024>>2] = $74;
     $76 = (($i2$023) + 1)|0;
     $exitcond37 = ($76|0)==($57|0);
     if ($exitcond37) {
      break;
     } else {
      $i2$023 = $76;$tris32$024 = $75;
     }
    }
   } else {
    if ($64) {
     break;
    }
    $i1$027 = 0;$tris16$028 = $19;
    while(1) {
     $65 = HEAP32[$stream>>2]|0;
     $66 = HEAP32[$65>>2]|0;
     (FUNCTION_TABLE_iiii[$66 & 2047]($stream,$x,1)|0);
     $67 = HEAP8[$x>>0]|0;
     $68 = $67&255;
     $69 = (($tris16$028) + 2|0);
     HEAP16[$tris16$028>>1] = $68;
     $70 = (($i1$027) + 1)|0;
     $exitcond38 = ($70|0)==($57|0);
     if ($exitcond38) {
      break;
     } else {
      $i1$027 = $70;$tris16$028 = $69;
     }
    }
   }
  }
 } while(0);
 $144 = $7 & 1;
 $145 = ($144|0)==(0);
 if (!($145)) {
  $146 = (__ZN5physx20InternalTriangleMesh17allocateMaterialsEv($0)|0);
  $147 = HEAP32[$stream>>2]|0;
  $148 = HEAP32[$147>>2]|0;
  $149 = HEAP32[$55>>2]|0;
  $150 = $149 << 1;
  (FUNCTION_TABLE_iiii[$148 & 2047]($stream,$146,$150)|0);
  $151 = HEAP8[$mismatch>>0]|0;
  $152 = ($151<<24>>24)==(0);
  if (!($152)) {
   $153 = HEAP32[$55>>2]|0;
   $154 = ($153|0)==(0);
   if (!($154)) {
    $i13$04 = 0;
    while(1) {
     $155 = (($146) + ($i13$04<<1)|0);
     $156 = HEAP8[$155>>0]|0;
     $157 = (($155) + 1|0);
     $158 = HEAP8[$157>>0]|0;
     HEAP8[$155>>0] = $158;
     HEAP8[$157>>0] = $156;
     $159 = (($i13$04) + 1)|0;
     $160 = HEAP32[$55>>2]|0;
     $161 = ($159>>>0)<($160>>>0);
     if ($161) {
      $i13$04 = $159;
     } else {
      break;
     }
    }
   }
  }
 }
 $162 = $7 & 2;
 $163 = ($162|0)==(0);
 if (!($163)) {
  $164 = (__ZN5physx20InternalTriangleMesh17allocateFaceRemapEv($0)|0);
  $165 = HEAP8[$mismatch>>0]|0;
  $166 = ($165<<24>>24)!=(0);
  $167 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($166,$stream)|0);
  $168 = HEAP32[$55>>2]|0;
  $169 = HEAP8[$mismatch>>0]|0;
  $170 = ($169<<24>>24)!=(0);
  __ZN5physx11readIndicesEjjPjRNS_13PxInputStreamEb($167,$168,$164,$stream,$170);
 }
 $171 = $7 & 16;
 $172 = ($171|0)==(0);
 if (!($172)) {
  $173 = (__ZN5physx20InternalTriangleMesh19allocateAdjacenciesEv($0)|0);
  $174 = HEAP32[$stream>>2]|0;
  $175 = HEAP32[$174>>2]|0;
  $176 = HEAP32[$55>>2]|0;
  $177 = ($176*12)|0;
  (FUNCTION_TABLE_iiii[$175 & 2047]($stream,$173,$177)|0);
  $178 = HEAP8[$mismatch>>0]|0;
  $179 = ($178<<24>>24)==(0);
  if (!($179)) {
   $180 = HEAP32[$55>>2]|0;
   $181 = ($180*3)|0;
   $182 = ($181|0)==(0);
   if (!($182)) {
    $i14$01 = 0;
    while(1) {
     $183 = (($173) + ($i14$01<<2)|0);
     $184 = HEAP8[$183>>0]|0;
     $185 = (($183) + 3|0);
     $186 = HEAP8[$185>>0]|0;
     HEAP8[$183>>0] = $186;
     HEAP8[$185>>0] = $184;
     $187 = (($183) + 1|0);
     $188 = HEAP8[$187>>0]|0;
     $189 = (($183) + 2|0);
     $190 = HEAP8[$189>>0]|0;
     HEAP8[$187>>0] = $190;
     HEAP8[$189>>0] = $188;
     $191 = (($i14$01) + 1)|0;
     $192 = HEAP32[$55>>2]|0;
     $193 = ($192*3)|0;
     $194 = ($191>>>0)<($193>>>0);
     if ($194) {
      $i14$01 = $191;
     } else {
      break;
     }
    }
   }
  }
 }
 $195 = HEAP32[$version>>2]|0;
 $196 = (__ZN5physx20InternalTriangleMesh9loadRTreeERNS_13PxInputStreamEj($0,$stream,$195)|0);
 if (!($196)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $197 = HEAP8[$mismatch>>0]|0;
 $198 = ($197<<24>>24)!=(0);
 $199 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($198,$stream)));
 $200 = (($this) + 36|0);
 HEAPF32[$200>>2] = $199;
 $201 = HEAP8[$mismatch>>0]|0;
 $202 = ($201<<24>>24)!=(0);
 $203 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($202,$stream)));
 $204 = (($this) + 144|0);
 HEAPF32[$204>>2] = $203;
 $205 = HEAP8[$mismatch>>0]|0;
 $206 = ($205<<24>>24)!=(0);
 $207 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($206,$stream)));
 $208 = (($this) + 148|0);
 HEAPF32[$208>>2] = $207;
 $209 = HEAP8[$mismatch>>0]|0;
 $210 = ($209<<24>>24)!=(0);
 $211 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($210,$stream)));
 $212 = (($this) + 152|0);
 HEAPF32[$212>>2] = $211;
 $213 = HEAP8[$mismatch>>0]|0;
 $214 = ($213<<24>>24)!=(0);
 $215 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($214,$stream)));
 $216 = (($this) + 156|0);
 HEAPF32[$216>>2] = $215;
 $217 = HEAP8[$mismatch>>0]|0;
 $218 = ($217<<24>>24)!=(0);
 $219 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($218,$stream)));
 $220 = (($this) + 160|0);
 HEAPF32[$220>>2] = $219;
 $221 = HEAP8[$mismatch>>0]|0;
 $222 = ($221<<24>>24)!=(0);
 $223 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($222,$stream)));
 $224 = (($this) + 164|0);
 HEAPF32[$224>>2] = $223;
 $225 = HEAP8[$mismatch>>0]|0;
 $226 = ($225<<24>>24)!=(0);
 $227 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($226,$stream)|0);
 $228 = ($227|0)==(0);
 if ($228) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $229 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = (($230) + 8|0);
 $232 = HEAP32[$231>>2]|0;
 $233 = (__Z15PxGetFoundationv()|0);
 $234 = HEAP32[$233>>2]|0;
 $235 = (($234) + 24|0);
 $236 = HEAP32[$235>>2]|0;
 $237 = (FUNCTION_TABLE_ii[$236 & 4095]($233)|0);
 $$$i$i$i = $237 ? 553168 : 553136;
 $238 = (FUNCTION_TABLE_iiiiii[$232 & 255]($229,$227,$$$i$i$i,552832,262)|0);
 $239 = (($this) + 168|0);
 HEAP32[$239>>2] = $238;
 $240 = HEAP32[$stream>>2]|0;
 $241 = HEAP32[$240>>2]|0;
 (FUNCTION_TABLE_iiii[$241 & 2047]($stream,$238,$227)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu12TriangleMesh18setupMeshInterfaceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN5physx20InternalTriangleMesh18setupMeshInterfaceEv($0);
 $1 = (($this) + 196|0);
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu12TriangleMesh7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 224|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($1,$this,3,0);
 $2 = (($this) + 6|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & -3;
 HEAP16[$2>>1] = $4;
 $5 = (($this) + 8|0);
 $6 = (($this) + 12|0);
 $7 = (__ZN5physx6shdfnd15atomicDecrementEPVi($6)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$5>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$11 & 4095]($5);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu12TriangleMesh17getReferenceCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu12TriangleMesh14debugVisualizeERNS_2Cm12RenderOutputERKNS2_8Matrix34ERKNS_11PxMeshScaleERKNS_9PxBounds3Eyfj($this,$out,$absPose,$scaling,$cullbox,$0,$1,$fscale,$numMaterials) {
 $this = $this|0;
 $out = $out|0;
 $absPose = $absPose|0;
 $scaling = $scaling|0;
 $cullbox = $cullbox|0;
 $0 = $0|0;
 $1 = $1|0;
 $fscale = Math_fround($fscale);
 $numMaterials = $numMaterials|0;
 var $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0);
 var $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0);
 var $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0);
 var $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0;
 var $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0);
 var $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0);
 var $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0;
 var $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0);
 var $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0;
 var $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0);
 var $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0);
 var $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0);
 var $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = 0, $53 = Math_fround(0), $530 = Math_fround(0), $531 = 0;
 var $532 = Math_fround(0), $533 = 0, $534 = Math_fround(0), $535 = 0, $536 = Math_fround(0), $537 = 0, $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = Math_fround(0);
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = Math_fround(0);
 var $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = Math_fround(0), $595 = 0, $596 = Math_fround(0), $597 = 0, $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = 0, $602 = Math_fround(0), $603 = 0;
 var $604 = Math_fround(0), $605 = 0, $606 = Math_fround(0), $607 = 0, $608 = Math_fround(0), $609 = 0, $61 = Math_fround(0), $610 = Math_fround(0), $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = 0;
 var $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = Math_fround(0);
 var $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = Math_fround(0), $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0;
 var $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0;
 var $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = Math_fround(0), $694 = Math_fround(0);
 var $695 = Math_fround(0), $696 = 0, $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = 0, $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0);
 var $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = 0, $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0;
 var $97 = 0, $98 = Math_fround(0), $99 = 0, $exitcond = 0, $exitcond126 = 0, $exitcond127 = 0, $exitcond128 = 0, $exitcond129 = 0, $exitcond130 = 0, $exitcond131 = 0, $exitcond132 = 0, $i$0124 = 0, $i1$0118 = 0, $i13$0105 = 0, $i15$0103 = 0, $i15$0103$us = 0, $i18$0101 = 0, $i4$0115 = 0, $i8$0111 = 0, $meshRot = 0;
 var $meshTransform = 0, $midt = 0, $or$cond = 0, $or$cond133 = 0, $or$cond134 = 0, $or$cond135 = 0, $overflow = 0, $segments$0119 = 0, $segments14$0102 = 0, $segments14$0102$us = 0, $worldBox = 0, $wp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $midt = sp + 360|0;
 $worldBox = sp + 236|0;
 $2 = sp + 441|0;
 $overflow = sp + 440|0;
 $meshTransform = sp + 296|0;
 $meshRot = sp + 324|0;
 $3 = sp + 424|0;
 $wp = sp + 200|0;
 $4 = sp + 172|0;
 $5 = sp + 160|0;
 $6 = sp;
 $7 = sp + 48|0;
 $8 = sp + 12|0;
 $9 = sp + 24|0;
 $10 = sp + 36|0;
 $11 = sp + 443|0;
 $12 = sp + 60|0;
 $13 = sp + 442|0;
 $14 = sp + 444|0;
 $15 = sp + 88|0;
 $16 = sp + 100|0;
 $17 = sp + 112|0;
 $18 = sp + 124|0;
 $19 = sp + 136|0;
 $20 = sp + 148|0;
 $21 = $0 & 1073741824;
 $22 = ($21|0)==(0);
 $23 = (0)==(0);
 $24 = $22 & $23;
 HEAPF32[$midt>>2] = Math_fround(1.0);
 $25 = (($midt) + 4|0);
 $26 = (($midt) + 20|0);
 ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($midt) + 24|0);
 $28 = (($midt) + 40|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($midt) + 44|0);
 $30 = (($midt) + 60|0);
 ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($this) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($this) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 28|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($this) + 172|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = $40 & 2;
 $42 = ($41<<24>>24)!=(0);
 if (!($24)) {
  $43 = (($cullbox) + 12|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround(HEAPF32[$cullbox>>2]);
  $46 = Math_fround($44 + $45);
  $47 = (($cullbox) + 16|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($cullbox) + 4|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($48 + $50);
  $52 = (($cullbox) + 20|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($cullbox) + 8|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($53 + $55);
  $57 = Math_fround($46 * Math_fround(0.5));
  $58 = Math_fround($51 * Math_fround(0.5));
  $59 = Math_fround($56 * Math_fround(0.5));
  $60 = Math_fround($44 - $45);
  $61 = Math_fround($48 - $50);
  $62 = Math_fround($53 - $55);
  $63 = Math_fround($60 * Math_fround(0.5));
  $64 = Math_fround($61 * Math_fround(0.5));
  $65 = Math_fround($62 * Math_fround(0.5));
  HEAPF32[$worldBox>>2] = Math_fround(1.0);
  $66 = (($worldBox) + 4|0);
  HEAPF32[$66>>2] = Math_fround(0.0);
  $67 = (($worldBox) + 8|0);
  HEAPF32[$67>>2] = Math_fround(0.0);
  $68 = (($worldBox) + 12|0);
  HEAPF32[$68>>2] = Math_fround(0.0);
  $69 = (($worldBox) + 16|0);
  HEAPF32[$69>>2] = Math_fround(1.0);
  $70 = (($worldBox) + 20|0);
  HEAPF32[$70>>2] = Math_fround(0.0);
  $71 = (($worldBox) + 24|0);
  HEAPF32[$71>>2] = Math_fround(0.0);
  $72 = (($worldBox) + 28|0);
  HEAPF32[$72>>2] = Math_fround(0.0);
  $73 = (($worldBox) + 32|0);
  HEAPF32[$73>>2] = Math_fround(1.0);
  $74 = (($worldBox) + 36|0);
  HEAPF32[$74>>2] = $57;
  $75 = (($worldBox) + 40|0);
  HEAPF32[$75>>2] = $58;
  $76 = (($worldBox) + 44|0);
  HEAPF32[$76>>2] = $59;
  $77 = (($worldBox) + 48|0);
  HEAPF32[$77>>2] = $63;
  $78 = (($worldBox) + 52|0);
  HEAPF32[$78>>2] = $64;
  $79 = (($worldBox) + 56|0);
  HEAPF32[$79>>2] = $65;
  $80 = ($32*12)|0;
  $81 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($2,$80,552832,370)|0);
  $82 = ($32*3)|0;
  HEAP8[$overflow>>0] = 0;
  $83 = Math_fround(HEAPF32[$absPose>>2]);
  HEAPF32[$meshRot>>2] = $83;
  $84 = (($meshRot) + 4|0);
  $85 = (($absPose) + 4|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  HEAPF32[$84>>2] = $86;
  $87 = (($meshRot) + 8|0);
  $88 = (($absPose) + 8|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  HEAPF32[$87>>2] = $89;
  $90 = (($meshRot) + 12|0);
  $91 = (($absPose) + 12|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  HEAPF32[$90>>2] = $92;
  $93 = (($meshRot) + 16|0);
  $94 = (($absPose) + 16|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  HEAPF32[$93>>2] = $95;
  $96 = (($meshRot) + 20|0);
  $97 = (($absPose) + 20|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  HEAPF32[$96>>2] = $98;
  $99 = (($meshRot) + 24|0);
  $100 = (($absPose) + 24|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  HEAPF32[$99>>2] = $101;
  $102 = (($meshRot) + 28|0);
  $103 = (($absPose) + 28|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  HEAPF32[$102>>2] = $104;
  $105 = (($meshRot) + 32|0);
  $106 = (($absPose) + 32|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  HEAPF32[$105>>2] = $107;
  $108 = (($absPose) + 36|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($meshTransform) + 16|0);
  HEAPF32[$110>>2] = $109;
  $111 = (($absPose) + 40|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($meshTransform) + 20|0);
  HEAPF32[$113>>2] = $112;
  $114 = (($absPose) + 44|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($meshTransform) + 24|0);
  HEAPF32[$116>>2] = $115;
  __ZN5physx6PxQuatC2ERKNS_7PxMat33E($3,$meshRot);
  $117 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$meshTransform>>2] = $117;
  $118 = (($3) + 4|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = (($meshTransform) + 4|0);
  HEAPF32[$120>>2] = $119;
  $121 = (($3) + 8|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = (($meshTransform) + 8|0);
  HEAPF32[$123>>2] = $122;
  $124 = (($3) + 12|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = (($meshTransform) + 12|0);
  HEAPF32[$126>>2] = $125;
  $127 = (($this) + 32|0);
  $128 = (__ZN5physx2Gu18findOverlapOBBMeshERKNS0_3BoxERKNS0_13RTreeMidphaseERKNS_11PxTransformERKNS_11PxMeshScaleEPjjjRb($worldBox,$127,$meshTransform,$scaling,$81,$82,0,$overflow)|0);
  $129 = $fscale == Math_fround(0.0);
  $130 = ($128|0)==(0);
  $or$cond = $129 | $130;
  if (!($or$cond)) {
   $131 = (($wp) + 12|0);
   $132 = (($wp) + 4|0);
   $133 = (($wp) + 16|0);
   $134 = (($wp) + 8|0);
   $135 = (($wp) + 20|0);
   $136 = (($wp) + 24|0);
   $137 = (($wp) + 28|0);
   $138 = (($wp) + 32|0);
   $139 = (($4) + 4|0);
   $140 = (($4) + 8|0);
   $141 = (($4) + 12|0);
   $142 = (($4) + 16|0);
   $143 = (($4) + 20|0);
   $144 = (($4) + 24|0);
   $i$0124 = 0;
   while(1) {
    $145 = (($81) + ($i$0124<<2)|0);
    $146 = HEAP32[$145>>2]|0;
    __ZN5physxL11getTriangleERKNS_2Gu12TriangleMeshEjPNS_6PxVec3EPKS4_PKvRKNS_2Cm8Matrix34Eb($146,$wp,$36,$38,$absPose,$42);
    $147 = Math_fround(HEAPF32[$wp>>2]);
    $148 = Math_fround(HEAPF32[$131>>2]);
    $149 = Math_fround($147 + $148);
    $150 = Math_fround(HEAPF32[$132>>2]);
    $151 = Math_fround(HEAPF32[$133>>2]);
    $152 = Math_fround($150 + $151);
    $153 = Math_fround(HEAPF32[$134>>2]);
    $154 = Math_fround(HEAPF32[$135>>2]);
    $155 = Math_fround($153 + $154);
    $156 = Math_fround(HEAPF32[$136>>2]);
    $157 = Math_fround($149 + $156);
    $158 = Math_fround(HEAPF32[$137>>2]);
    $159 = Math_fround($152 + $158);
    $160 = Math_fround(HEAPF32[$138>>2]);
    $161 = Math_fround($155 + $160);
    $162 = Math_fround($157 * Math_fround(0.333333343267440795898));
    $163 = Math_fround($159 * Math_fround(0.333333343267440795898));
    $164 = Math_fround($161 * Math_fround(0.333333343267440795898));
    $165 = Math_fround($147 - $148);
    $166 = Math_fround($150 - $151);
    $167 = Math_fround($153 - $154);
    $168 = Math_fround($147 - $156);
    $169 = Math_fround($150 - $158);
    $170 = Math_fround($153 - $160);
    $171 = Math_fround($166 * $170);
    $172 = Math_fround($167 * $169);
    $173 = Math_fround($171 - $172);
    $174 = Math_fround($167 * $168);
    $175 = Math_fround($165 * $170);
    $176 = Math_fround($174 - $175);
    $177 = Math_fround($165 * $169);
    $178 = Math_fround($166 * $168);
    $179 = Math_fround($177 - $178);
    $180 = Math_fround($173 * $173);
    $181 = Math_fround($176 * $176);
    $182 = Math_fround($180 + $181);
    $183 = Math_fround($179 * $179);
    $184 = Math_fround($183 + $182);
    $185 = $184 > Math_fround(0.0);
    if ($185) {
     $186 = (Math_fround(Math_sqrt((Math_fround($184)))));
     $187 = Math_fround(Math_fround(1.0) / $186);
     $188 = Math_fround($173 * $187);
     $189 = Math_fround($176 * $187);
     $190 = Math_fround($179 * $187);
     $194 = $188;$196 = $189;$198 = $190;
    } else {
     $194 = Math_fround(0.0);$196 = Math_fround(0.0);$198 = Math_fround(0.0);
    }
    $191 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
    $192 = (__ZN5physx2Cm12RenderOutputlsEj($191,-2004353024)|0);
    $193 = Math_fround($194 * $fscale);
    $195 = Math_fround($196 * $fscale);
    $197 = Math_fround($198 * $fscale);
    HEAPF32[$4>>2] = $162;
    HEAPF32[$139>>2] = $163;
    HEAPF32[$140>>2] = $164;
    $199 = Math_fround($162 + $193);
    $200 = Math_fround($163 + $195);
    $201 = Math_fround($164 + $197);
    HEAPF32[$141>>2] = $199;
    HEAPF32[$142>>2] = $200;
    HEAPF32[$143>>2] = $201;
    $202 = Math_fround($193 * $193);
    $203 = Math_fround($195 * $195);
    $204 = Math_fround($203 + $202);
    $205 = Math_fround($197 * $197);
    $206 = Math_fround($205 + $204);
    $207 = (Math_fround(Math_sqrt((Math_fround($206)))));
    $208 = Math_fround($207 * Math_fround(0.150000005960464477539));
    HEAPF32[$144>>2] = $208;
    (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($192,$4)|0);
    $209 = (($i$0124) + 1)|0;
    $exitcond131 = ($209|0)==($128|0);
    if ($exitcond131) {
     break;
    } else {
     $i$0124 = $209;
    }
   }
  }
  $210 = $0 & 8192;
  $211 = ($210|0)==(0);
  $212 = (0)==(0);
  $213 = $211 & $212;
  if (!($213)) {
   $214 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
   (__ZN5physx2Cm12RenderOutputlsEj($214,-65281)|0);
   $215 = ($128*3)|0;
   $216 = (($out) + 100|0);
   $217 = HEAP32[$216>>2]|0;
   $218 = (($217) + 16|0);
   $219 = (($217) + 20|0);
   $220 = HEAP32[$219>>2]|0;
   $221 = (($220) + ($215))|0;
   __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($218,$221);
   $222 = ($128|0)==(0);
   if (!($222)) {
    $223 = HEAP32[$216>>2]|0;
    $224 = (($223) + 16|0);
    $225 = HEAP32[$224>>2]|0;
    $226 = (($225) + ($220<<5)|0);
    $227 = (($wp) + 4|0);
    $228 = (($wp) + 8|0);
    $229 = (($wp) + 12|0);
    $230 = (($wp) + 16|0);
    $231 = (($wp) + 20|0);
    $232 = (($wp) + 24|0);
    $233 = (($wp) + 28|0);
    $234 = (($wp) + 32|0);
    $i1$0118 = 0;$segments$0119 = $226;
    while(1) {
     $235 = (($81) + ($i1$0118<<2)|0);
     $236 = HEAP32[$235>>2]|0;
     __ZN5physxL11getTriangleERKNS_2Gu12TriangleMeshEjPNS_6PxVec3EPKS4_PKvRKNS_2Cm8Matrix34Eb($236,$wp,$36,$38,$absPose,$42);
     $237 = Math_fround(HEAPF32[$wp>>2]);
     $238 = Math_fround(HEAPF32[$227>>2]);
     $239 = Math_fround(HEAPF32[$228>>2]);
     $240 = Math_fround(HEAPF32[$229>>2]);
     $241 = Math_fround(HEAPF32[$230>>2]);
     $242 = Math_fround(HEAPF32[$231>>2]);
     HEAPF32[$segments$0119>>2] = $237;
     $243 = (($segments$0119) + 4|0);
     HEAPF32[$243>>2] = $238;
     $244 = (($segments$0119) + 8|0);
     HEAPF32[$244>>2] = $239;
     $245 = (($segments$0119) + 12|0);
     HEAP32[$245>>2] = -65281;
     $246 = (($segments$0119) + 16|0);
     HEAPF32[$246>>2] = $240;
     $247 = (($segments$0119) + 20|0);
     HEAPF32[$247>>2] = $241;
     $248 = (($segments$0119) + 24|0);
     HEAPF32[$248>>2] = $242;
     $249 = (($segments$0119) + 28|0);
     HEAP32[$249>>2] = -65281;
     $250 = Math_fround(HEAPF32[$229>>2]);
     $251 = Math_fround(HEAPF32[$230>>2]);
     $252 = Math_fround(HEAPF32[$231>>2]);
     $253 = Math_fround(HEAPF32[$232>>2]);
     $254 = Math_fround(HEAPF32[$233>>2]);
     $255 = Math_fround(HEAPF32[$234>>2]);
     $256 = (($segments$0119) + 32|0);
     HEAPF32[$256>>2] = $250;
     $257 = (($segments$0119) + 36|0);
     HEAPF32[$257>>2] = $251;
     $258 = (($segments$0119) + 40|0);
     HEAPF32[$258>>2] = $252;
     $259 = (($segments$0119) + 44|0);
     HEAP32[$259>>2] = -65281;
     $260 = (($segments$0119) + 48|0);
     HEAPF32[$260>>2] = $253;
     $261 = (($segments$0119) + 52|0);
     HEAPF32[$261>>2] = $254;
     $262 = (($segments$0119) + 56|0);
     HEAPF32[$262>>2] = $255;
     $263 = (($segments$0119) + 60|0);
     HEAP32[$263>>2] = -65281;
     $264 = Math_fround(HEAPF32[$232>>2]);
     $265 = Math_fround(HEAPF32[$233>>2]);
     $266 = Math_fround(HEAPF32[$234>>2]);
     $267 = Math_fround(HEAPF32[$wp>>2]);
     $268 = Math_fround(HEAPF32[$227>>2]);
     $269 = Math_fround(HEAPF32[$228>>2]);
     $270 = (($segments$0119) + 64|0);
     HEAPF32[$270>>2] = $264;
     $271 = (($segments$0119) + 68|0);
     HEAPF32[$271>>2] = $265;
     $272 = (($segments$0119) + 72|0);
     HEAPF32[$272>>2] = $266;
     $273 = (($segments$0119) + 76|0);
     HEAP32[$273>>2] = -65281;
     $274 = (($segments$0119) + 80|0);
     HEAPF32[$274>>2] = $267;
     $275 = (($segments$0119) + 84|0);
     HEAPF32[$275>>2] = $268;
     $276 = (($segments$0119) + 88|0);
     HEAPF32[$276>>2] = $269;
     $277 = (($segments$0119) + 92|0);
     HEAP32[$277>>2] = -65281;
     $278 = (($segments$0119) + 96|0);
     $279 = (($i1$0118) + 1)|0;
     $exitcond130 = ($279|0)==($128|0);
     if ($exitcond130) {
      break;
     } else {
      $i1$0118 = $279;$segments$0119 = $278;
     }
    }
   }
  }
  $280 = $0 & 131072;
  $281 = ($280|0)==(0);
  $282 = (0)==(0);
  $283 = $281 & $282;
  if (!($283)) {
   $284 = (($this) + 168|0);
   $285 = HEAP32[$284>>2]|0;
   $286 = ($285|0)==(0|0);
   $287 = ($128|0)==(0);
   $or$cond133 = $286 | $287;
   if (!($or$cond133)) {
    $288 = (($9) + 4|0);
    $289 = (($wp) + 4|0);
    $290 = (($9) + 8|0);
    $291 = (($wp) + 8|0);
    $292 = (($wp) + 24|0);
    $293 = (($10) + 4|0);
    $294 = (($wp) + 28|0);
    $295 = (($10) + 8|0);
    $296 = (($wp) + 32|0);
    $297 = (($wp) + 12|0);
    $298 = (($7) + 4|0);
    $299 = (($wp) + 16|0);
    $300 = (($7) + 8|0);
    $301 = (($wp) + 20|0);
    $302 = (($8) + 4|0);
    $303 = (($8) + 8|0);
    $304 = (($5) + 4|0);
    $305 = (($5) + 8|0);
    $306 = (($6) + 4|0);
    $307 = (($6) + 8|0);
    $i4$0115 = 0;
    while(1) {
     $308 = (($81) + ($i4$0115<<2)|0);
     $309 = HEAP32[$308>>2]|0;
     __ZN5physxL11getTriangleERKNS_2Gu12TriangleMeshEjPNS_6PxVec3EPKS4_PKvRKNS_2Cm8Matrix34Eb($309,$wp,$36,$38,$absPose,$42);
     $310 = HEAP32[$284>>2]|0;
     $311 = (($310) + ($309)|0);
     $312 = HEAP8[$311>>0]|0;
     $313 = $312&255;
     $314 = $313 & 8;
     $315 = ($314|0)==(0);
     if (!($315)) {
      $316 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
      $317 = (__ZN5physx2Cm12RenderOutputlsEj($316,-256)|0);
      $318 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($317,1)|0);
      $319 = Math_fround(HEAPF32[$wp>>2]);
      HEAPF32[$5>>2] = $319;
      $320 = Math_fround(HEAPF32[$289>>2]);
      HEAPF32[$304>>2] = $320;
      $321 = Math_fround(HEAPF32[$291>>2]);
      HEAPF32[$305>>2] = $321;
      $322 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($318,$5)|0);
      $323 = Math_fround(HEAPF32[$297>>2]);
      HEAPF32[$6>>2] = $323;
      $324 = Math_fround(HEAPF32[$299>>2]);
      HEAPF32[$306>>2] = $324;
      $325 = Math_fround(HEAPF32[$301>>2]);
      HEAPF32[$307>>2] = $325;
      (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($322,$6)|0);
     }
     $326 = $313 & 16;
     $327 = ($326|0)==(0);
     if (!($327)) {
      $328 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
      $329 = (__ZN5physx2Cm12RenderOutputlsEj($328,-256)|0);
      $330 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($329,1)|0);
      $331 = Math_fround(HEAPF32[$297>>2]);
      HEAPF32[$7>>2] = $331;
      $332 = Math_fround(HEAPF32[$299>>2]);
      HEAPF32[$298>>2] = $332;
      $333 = Math_fround(HEAPF32[$301>>2]);
      HEAPF32[$300>>2] = $333;
      $334 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($330,$7)|0);
      $335 = Math_fround(HEAPF32[$292>>2]);
      HEAPF32[$8>>2] = $335;
      $336 = Math_fround(HEAPF32[$294>>2]);
      HEAPF32[$302>>2] = $336;
      $337 = Math_fround(HEAPF32[$296>>2]);
      HEAPF32[$303>>2] = $337;
      (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($334,$8)|0);
     }
     $338 = $313 & 32;
     $339 = ($338|0)==(0);
     if (!($339)) {
      $340 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
      $341 = (__ZN5physx2Cm12RenderOutputlsEj($340,-256)|0);
      $342 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($341,1)|0);
      $343 = Math_fround(HEAPF32[$wp>>2]);
      HEAPF32[$9>>2] = $343;
      $344 = Math_fround(HEAPF32[$289>>2]);
      HEAPF32[$288>>2] = $344;
      $345 = Math_fround(HEAPF32[$291>>2]);
      HEAPF32[$290>>2] = $345;
      $346 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($342,$9)|0);
      $347 = Math_fround(HEAPF32[$292>>2]);
      HEAPF32[$10>>2] = $347;
      $348 = Math_fround(HEAPF32[$294>>2]);
      HEAPF32[$293>>2] = $348;
      $349 = Math_fround(HEAPF32[$296>>2]);
      HEAPF32[$295>>2] = $349;
      (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($346,$10)|0);
     }
     $350 = (($i4$0115) + 1)|0;
     $exitcond129 = ($350|0)==($128|0);
     if ($exitcond129) {
      break;
     } else {
      $i4$0115 = $350;
     }
    }
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($11,$81);
  STACKTOP = sp;return;
 }
 $351 = $fscale == Math_fround(0.0);
 $352 = ($32|0)==(0);
 $or$cond134 = $351 | $352;
 if (!($or$cond134)) {
  $353 = (($worldBox) + 12|0);
  $354 = (($worldBox) + 4|0);
  $355 = (($worldBox) + 16|0);
  $356 = (($worldBox) + 8|0);
  $357 = (($worldBox) + 20|0);
  $358 = (($worldBox) + 24|0);
  $359 = (($worldBox) + 28|0);
  $360 = (($worldBox) + 32|0);
  $361 = (($12) + 4|0);
  $362 = (($12) + 8|0);
  $363 = (($12) + 12|0);
  $364 = (($12) + 16|0);
  $365 = (($12) + 20|0);
  $366 = (($12) + 24|0);
  $i8$0111 = 0;
  while(1) {
   __ZN5physxL11getTriangleERKNS_2Gu12TriangleMeshEjPNS_6PxVec3EPKS4_PKvRKNS_2Cm8Matrix34Eb($i8$0111,$worldBox,$36,$38,$absPose,$42);
   $367 = Math_fround(HEAPF32[$worldBox>>2]);
   $368 = Math_fround(HEAPF32[$353>>2]);
   $369 = Math_fround($367 + $368);
   $370 = Math_fround(HEAPF32[$354>>2]);
   $371 = Math_fround(HEAPF32[$355>>2]);
   $372 = Math_fround($370 + $371);
   $373 = Math_fround(HEAPF32[$356>>2]);
   $374 = Math_fround(HEAPF32[$357>>2]);
   $375 = Math_fround($373 + $374);
   $376 = Math_fround(HEAPF32[$358>>2]);
   $377 = Math_fround($369 + $376);
   $378 = Math_fround(HEAPF32[$359>>2]);
   $379 = Math_fround($372 + $378);
   $380 = Math_fround(HEAPF32[$360>>2]);
   $381 = Math_fround($375 + $380);
   $382 = Math_fround($377 * Math_fround(0.333333343267440795898));
   $383 = Math_fround($379 * Math_fround(0.333333343267440795898));
   $384 = Math_fround($381 * Math_fround(0.333333343267440795898));
   $385 = Math_fround($367 - $368);
   $386 = Math_fround($370 - $371);
   $387 = Math_fround($373 - $374);
   $388 = Math_fround($367 - $376);
   $389 = Math_fround($370 - $378);
   $390 = Math_fround($373 - $380);
   $391 = Math_fround($386 * $390);
   $392 = Math_fround($387 * $389);
   $393 = Math_fround($391 - $392);
   $394 = Math_fround($387 * $388);
   $395 = Math_fround($385 * $390);
   $396 = Math_fround($394 - $395);
   $397 = Math_fround($385 * $389);
   $398 = Math_fround($386 * $388);
   $399 = Math_fround($397 - $398);
   $400 = Math_fround($393 * $393);
   $401 = Math_fround($396 * $396);
   $402 = Math_fround($400 + $401);
   $403 = Math_fround($399 * $399);
   $404 = Math_fround($403 + $402);
   $405 = $404 > Math_fround(0.0);
   if ($405) {
    $406 = (Math_fround(Math_sqrt((Math_fround($404)))));
    $407 = Math_fround(Math_fround(1.0) / $406);
    $408 = Math_fround($393 * $407);
    $409 = Math_fround($396 * $407);
    $410 = Math_fround($399 * $407);
    $414 = $408;$416 = $409;$418 = $410;
   } else {
    $414 = Math_fround(0.0);$416 = Math_fround(0.0);$418 = Math_fround(0.0);
   }
   $411 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
   $412 = (__ZN5physx2Cm12RenderOutputlsEj($411,-2004353024)|0);
   $413 = Math_fround($414 * $fscale);
   $415 = Math_fround($416 * $fscale);
   $417 = Math_fround($418 * $fscale);
   HEAPF32[$12>>2] = $382;
   HEAPF32[$361>>2] = $383;
   HEAPF32[$362>>2] = $384;
   $419 = Math_fround($382 + $413);
   $420 = Math_fround($383 + $415);
   $421 = Math_fround($384 + $417);
   HEAPF32[$363>>2] = $419;
   HEAPF32[$364>>2] = $420;
   HEAPF32[$365>>2] = $421;
   $422 = Math_fround($413 * $413);
   $423 = Math_fround($415 * $415);
   $424 = Math_fround($423 + $422);
   $425 = Math_fround($417 * $417);
   $426 = Math_fround($425 + $424);
   $427 = (Math_fround(Math_sqrt((Math_fround($426)))));
   $428 = Math_fround($427 * Math_fround(0.150000005960464477539));
   HEAPF32[$366>>2] = $428;
   (__ZN5physx2CmlsERNS0_12RenderOutputERKNS0_10DebugArrowE($412,$12)|0);
   $429 = (($i8$0111) + 1)|0;
   $exitcond128 = ($429|0)==($32|0);
   if ($exitcond128) {
    break;
   } else {
    $i8$0111 = $429;
   }
  }
 }
 $430 = $0 & 8192;
 $431 = ($430|0)==(0);
 $432 = (0)==(0);
 $433 = $431 & $432;
 if (!($433)) {
  $434 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
  (__ZN5physx2Cm12RenderOutputlsEj($434,-65281)|0);
  $435 = ($34*12)|0;
  $436 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($13,$435,552832,475)|0);
  $437 = ($34|0)==(0);
  if (!($437)) {
   $438 = (($absPose) + 4|0);
   $439 = (($absPose) + 8|0);
   $440 = (($absPose) + 12|0);
   $441 = (($absPose) + 16|0);
   $442 = (($absPose) + 20|0);
   $443 = (($absPose) + 24|0);
   $444 = (($absPose) + 28|0);
   $445 = (($absPose) + 32|0);
   $446 = (($absPose) + 36|0);
   $447 = (($absPose) + 40|0);
   $448 = (($absPose) + 44|0);
   $i13$0105 = 0;
   while(1) {
    $449 = (($36) + (($i13$0105*12)|0)|0);
    $450 = Math_fround(HEAPF32[$449>>2]);
    $451 = Math_fround(HEAPF32[$absPose>>2]);
    $452 = Math_fround($450 * $451);
    $453 = Math_fround(HEAPF32[$438>>2]);
    $454 = Math_fround($450 * $453);
    $455 = Math_fround(HEAPF32[$439>>2]);
    $456 = Math_fround($450 * $455);
    $457 = ((($36) + (($i13$0105*12)|0)|0) + 4|0);
    $458 = Math_fround(HEAPF32[$457>>2]);
    $459 = Math_fround(HEAPF32[$440>>2]);
    $460 = Math_fround($458 * $459);
    $461 = Math_fround(HEAPF32[$441>>2]);
    $462 = Math_fround($458 * $461);
    $463 = Math_fround(HEAPF32[$442>>2]);
    $464 = Math_fround($458 * $463);
    $465 = Math_fround($452 + $460);
    $466 = Math_fround($454 + $462);
    $467 = Math_fround($456 + $464);
    $468 = ((($36) + (($i13$0105*12)|0)|0) + 8|0);
    $469 = Math_fround(HEAPF32[$468>>2]);
    $470 = Math_fround(HEAPF32[$443>>2]);
    $471 = Math_fround($469 * $470);
    $472 = Math_fround(HEAPF32[$444>>2]);
    $473 = Math_fround($469 * $472);
    $474 = Math_fround(HEAPF32[$445>>2]);
    $475 = Math_fround($469 * $474);
    $476 = Math_fround($465 + $471);
    $477 = Math_fround($466 + $473);
    $478 = Math_fround($467 + $475);
    $479 = Math_fround(HEAPF32[$446>>2]);
    $480 = Math_fround($476 + $479);
    $481 = Math_fround(HEAPF32[$447>>2]);
    $482 = Math_fround($477 + $481);
    $483 = Math_fround(HEAPF32[$448>>2]);
    $484 = Math_fround($478 + $483);
    $485 = (($436) + (($i13$0105*12)|0)|0);
    HEAPF32[$485>>2] = $480;
    $486 = ((($436) + (($i13$0105*12)|0)|0) + 4|0);
    HEAPF32[$486>>2] = $482;
    $487 = ((($436) + (($i13$0105*12)|0)|0) + 8|0);
    HEAPF32[$487>>2] = $484;
    $488 = (($i13$0105) + 1)|0;
    $exitcond127 = ($488|0)==($34|0);
    if ($exitcond127) {
     break;
    } else {
     $i13$0105 = $488;
    }
   }
  }
  $489 = ($32*3)|0;
  $490 = (($out) + 100|0);
  $491 = HEAP32[$490>>2]|0;
  $492 = (($491) + 16|0);
  $493 = (($491) + 20|0);
  $494 = HEAP32[$493>>2]|0;
  $495 = (($494) + ($489))|0;
  __ZN5physx6shdfnd5ArrayINS_11PxDebugLineENS0_19ReflectionAllocatorIS2_EEE19resizeUninitializedEj($492,$495);
  $496 = HEAP32[$490>>2]|0;
  $497 = (($496) + 16|0);
  $498 = HEAP32[$497>>2]|0;
  $499 = (($498) + ($494<<5)|0);
  $500 = ($32|0)==(0);
  if (!($500)) {
   $501 = (($worldBox) + 4|0);
   $502 = (($worldBox) + 8|0);
   $503 = (($worldBox) + 12|0);
   $504 = (($worldBox) + 16|0);
   $505 = (($worldBox) + 20|0);
   $506 = (($worldBox) + 24|0);
   $507 = (($worldBox) + 28|0);
   $508 = (($worldBox) + 32|0);
   if ($42) {
    $i15$0103$us = 0;$segments14$0102$us = $499;
    while(1) {
     $509 = ($i15$0103$us*3)|0;
     $510 = (($38) + ($509<<1)|0);
     $511 = HEAP16[$510>>1]|0;
     $512 = $511&65535;
     $513 = (($509) + 1)|0;
     $514 = (($38) + ($513<<1)|0);
     $515 = HEAP16[$514>>1]|0;
     $516 = $515&65535;
     $517 = (($509) + 2)|0;
     $518 = (($38) + ($517<<1)|0);
     $519 = HEAP16[$518>>1]|0;
     $520 = $519&65535;
     $521 = (($436) + (($512*12)|0)|0);
     $522 = Math_fround(HEAPF32[$521>>2]);
     HEAPF32[$worldBox>>2] = $522;
     $523 = ((($436) + (($512*12)|0)|0) + 4|0);
     $524 = Math_fround(HEAPF32[$523>>2]);
     HEAPF32[$501>>2] = $524;
     $525 = ((($436) + (($512*12)|0)|0) + 8|0);
     $526 = Math_fround(HEAPF32[$525>>2]);
     HEAPF32[$502>>2] = $526;
     $527 = (($436) + (($516*12)|0)|0);
     $528 = Math_fround(HEAPF32[$527>>2]);
     HEAPF32[$503>>2] = $528;
     $529 = ((($436) + (($516*12)|0)|0) + 4|0);
     $530 = Math_fround(HEAPF32[$529>>2]);
     HEAPF32[$504>>2] = $530;
     $531 = ((($436) + (($516*12)|0)|0) + 8|0);
     $532 = Math_fround(HEAPF32[$531>>2]);
     HEAPF32[$505>>2] = $532;
     $533 = (($436) + (($520*12)|0)|0);
     $534 = Math_fround(HEAPF32[$533>>2]);
     HEAPF32[$506>>2] = $534;
     $535 = ((($436) + (($520*12)|0)|0) + 4|0);
     $536 = Math_fround(HEAPF32[$535>>2]);
     HEAPF32[$507>>2] = $536;
     $537 = ((($436) + (($520*12)|0)|0) + 8|0);
     $538 = Math_fround(HEAPF32[$537>>2]);
     HEAPF32[$508>>2] = $538;
     $539 = HEAP32[$this>>2]|0;
     $540 = (($539) + 48|0);
     $541 = HEAP32[$540>>2]|0;
     $542 = (FUNCTION_TABLE_iii[$541 & 4095]($this,$i15$0103$us)|0);
     $543 = (($542&65535) % 12)&-1;
     $544 = $543&65535;
     $545 = (553088 + ($544<<2)|0);
     $546 = HEAP32[$545>>2]|0;
     HEAPF32[$segments14$0102$us>>2] = $522;
     $547 = (($segments14$0102$us) + 4|0);
     HEAPF32[$547>>2] = $524;
     $548 = (($segments14$0102$us) + 8|0);
     HEAPF32[$548>>2] = $526;
     $549 = (($segments14$0102$us) + 12|0);
     HEAP32[$549>>2] = $546;
     $550 = (($segments14$0102$us) + 16|0);
     HEAPF32[$550>>2] = $528;
     $551 = (($segments14$0102$us) + 20|0);
     HEAPF32[$551>>2] = $530;
     $552 = (($segments14$0102$us) + 24|0);
     HEAPF32[$552>>2] = $532;
     $553 = (($segments14$0102$us) + 28|0);
     HEAP32[$553>>2] = $546;
     $554 = Math_fround(HEAPF32[$503>>2]);
     $555 = Math_fround(HEAPF32[$504>>2]);
     $556 = Math_fround(HEAPF32[$505>>2]);
     $557 = Math_fround(HEAPF32[$506>>2]);
     $558 = Math_fround(HEAPF32[$507>>2]);
     $559 = Math_fround(HEAPF32[$508>>2]);
     $560 = (($segments14$0102$us) + 32|0);
     HEAPF32[$560>>2] = $554;
     $561 = (($segments14$0102$us) + 36|0);
     HEAPF32[$561>>2] = $555;
     $562 = (($segments14$0102$us) + 40|0);
     HEAPF32[$562>>2] = $556;
     $563 = (($segments14$0102$us) + 44|0);
     HEAP32[$563>>2] = $546;
     $564 = (($segments14$0102$us) + 48|0);
     HEAPF32[$564>>2] = $557;
     $565 = (($segments14$0102$us) + 52|0);
     HEAPF32[$565>>2] = $558;
     $566 = (($segments14$0102$us) + 56|0);
     HEAPF32[$566>>2] = $559;
     $567 = (($segments14$0102$us) + 60|0);
     HEAP32[$567>>2] = $546;
     $568 = Math_fround(HEAPF32[$506>>2]);
     $569 = Math_fround(HEAPF32[$507>>2]);
     $570 = Math_fround(HEAPF32[$508>>2]);
     $571 = Math_fround(HEAPF32[$worldBox>>2]);
     $572 = Math_fround(HEAPF32[$501>>2]);
     $573 = Math_fround(HEAPF32[$502>>2]);
     $574 = (($segments14$0102$us) + 64|0);
     HEAPF32[$574>>2] = $568;
     $575 = (($segments14$0102$us) + 68|0);
     HEAPF32[$575>>2] = $569;
     $576 = (($segments14$0102$us) + 72|0);
     HEAPF32[$576>>2] = $570;
     $577 = (($segments14$0102$us) + 76|0);
     HEAP32[$577>>2] = $546;
     $578 = (($segments14$0102$us) + 80|0);
     HEAPF32[$578>>2] = $571;
     $579 = (($segments14$0102$us) + 84|0);
     HEAPF32[$579>>2] = $572;
     $580 = (($segments14$0102$us) + 88|0);
     HEAPF32[$580>>2] = $573;
     $581 = (($segments14$0102$us) + 92|0);
     HEAP32[$581>>2] = $546;
     $582 = (($segments14$0102$us) + 96|0);
     $583 = (($i15$0103$us) + 1)|0;
     $exitcond132 = ($583|0)==($32|0);
     if ($exitcond132) {
      break;
     } else {
      $i15$0103$us = $583;$segments14$0102$us = $582;
     }
    }
   } else {
    $i15$0103 = 0;$segments14$0102 = $499;
    while(1) {
     $584 = ($i15$0103*3)|0;
     $585 = (($38) + ($584<<2)|0);
     $586 = HEAP32[$585>>2]|0;
     $587 = (($584) + 1)|0;
     $588 = (($38) + ($587<<2)|0);
     $589 = HEAP32[$588>>2]|0;
     $590 = (($584) + 2)|0;
     $591 = (($38) + ($590<<2)|0);
     $592 = HEAP32[$591>>2]|0;
     $593 = (($436) + (($586*12)|0)|0);
     $594 = Math_fround(HEAPF32[$593>>2]);
     HEAPF32[$worldBox>>2] = $594;
     $595 = ((($436) + (($586*12)|0)|0) + 4|0);
     $596 = Math_fround(HEAPF32[$595>>2]);
     HEAPF32[$501>>2] = $596;
     $597 = ((($436) + (($586*12)|0)|0) + 8|0);
     $598 = Math_fround(HEAPF32[$597>>2]);
     HEAPF32[$502>>2] = $598;
     $599 = (($436) + (($589*12)|0)|0);
     $600 = Math_fround(HEAPF32[$599>>2]);
     HEAPF32[$503>>2] = $600;
     $601 = ((($436) + (($589*12)|0)|0) + 4|0);
     $602 = Math_fround(HEAPF32[$601>>2]);
     HEAPF32[$504>>2] = $602;
     $603 = ((($436) + (($589*12)|0)|0) + 8|0);
     $604 = Math_fround(HEAPF32[$603>>2]);
     HEAPF32[$505>>2] = $604;
     $605 = (($436) + (($592*12)|0)|0);
     $606 = Math_fround(HEAPF32[$605>>2]);
     HEAPF32[$506>>2] = $606;
     $607 = ((($436) + (($592*12)|0)|0) + 4|0);
     $608 = Math_fround(HEAPF32[$607>>2]);
     HEAPF32[$507>>2] = $608;
     $609 = ((($436) + (($592*12)|0)|0) + 8|0);
     $610 = Math_fround(HEAPF32[$609>>2]);
     HEAPF32[$508>>2] = $610;
     $611 = HEAP32[$this>>2]|0;
     $612 = (($611) + 48|0);
     $613 = HEAP32[$612>>2]|0;
     $614 = (FUNCTION_TABLE_iii[$613 & 4095]($this,$i15$0103)|0);
     $615 = (($614&65535) % 12)&-1;
     $616 = $615&65535;
     $617 = (553088 + ($616<<2)|0);
     $618 = HEAP32[$617>>2]|0;
     HEAPF32[$segments14$0102>>2] = $594;
     $619 = (($segments14$0102) + 4|0);
     HEAPF32[$619>>2] = $596;
     $620 = (($segments14$0102) + 8|0);
     HEAPF32[$620>>2] = $598;
     $621 = (($segments14$0102) + 12|0);
     HEAP32[$621>>2] = $618;
     $622 = (($segments14$0102) + 16|0);
     HEAPF32[$622>>2] = $600;
     $623 = (($segments14$0102) + 20|0);
     HEAPF32[$623>>2] = $602;
     $624 = (($segments14$0102) + 24|0);
     HEAPF32[$624>>2] = $604;
     $625 = (($segments14$0102) + 28|0);
     HEAP32[$625>>2] = $618;
     $626 = Math_fround(HEAPF32[$503>>2]);
     $627 = Math_fround(HEAPF32[$504>>2]);
     $628 = Math_fround(HEAPF32[$505>>2]);
     $629 = Math_fround(HEAPF32[$506>>2]);
     $630 = Math_fround(HEAPF32[$507>>2]);
     $631 = Math_fround(HEAPF32[$508>>2]);
     $632 = (($segments14$0102) + 32|0);
     HEAPF32[$632>>2] = $626;
     $633 = (($segments14$0102) + 36|0);
     HEAPF32[$633>>2] = $627;
     $634 = (($segments14$0102) + 40|0);
     HEAPF32[$634>>2] = $628;
     $635 = (($segments14$0102) + 44|0);
     HEAP32[$635>>2] = $618;
     $636 = (($segments14$0102) + 48|0);
     HEAPF32[$636>>2] = $629;
     $637 = (($segments14$0102) + 52|0);
     HEAPF32[$637>>2] = $630;
     $638 = (($segments14$0102) + 56|0);
     HEAPF32[$638>>2] = $631;
     $639 = (($segments14$0102) + 60|0);
     HEAP32[$639>>2] = $618;
     $640 = Math_fround(HEAPF32[$506>>2]);
     $641 = Math_fround(HEAPF32[$507>>2]);
     $642 = Math_fround(HEAPF32[$508>>2]);
     $643 = Math_fround(HEAPF32[$worldBox>>2]);
     $644 = Math_fround(HEAPF32[$501>>2]);
     $645 = Math_fround(HEAPF32[$502>>2]);
     $646 = (($segments14$0102) + 64|0);
     HEAPF32[$646>>2] = $640;
     $647 = (($segments14$0102) + 68|0);
     HEAPF32[$647>>2] = $641;
     $648 = (($segments14$0102) + 72|0);
     HEAPF32[$648>>2] = $642;
     $649 = (($segments14$0102) + 76|0);
     HEAP32[$649>>2] = $618;
     $650 = (($segments14$0102) + 80|0);
     HEAPF32[$650>>2] = $643;
     $651 = (($segments14$0102) + 84|0);
     HEAPF32[$651>>2] = $644;
     $652 = (($segments14$0102) + 88|0);
     HEAPF32[$652>>2] = $645;
     $653 = (($segments14$0102) + 92|0);
     HEAP32[$653>>2] = $618;
     $654 = (($segments14$0102) + 96|0);
     $655 = (($i15$0103) + 1)|0;
     $exitcond126 = ($655|0)==($32|0);
     if ($exitcond126) {
      break;
     } else {
      $i15$0103 = $655;$segments14$0102 = $654;
     }
    }
   }
  }
  __ZN5physx6shdfnd9Allocator10deallocateEPv($14,$436);
 }
 $656 = $0 & 131072;
 $657 = ($656|0)==(0);
 $658 = (0)==(0);
 $659 = $657 & $658;
 if ($659) {
  STACKTOP = sp;return;
 }
 $660 = (($this) + 168|0);
 $661 = HEAP32[$660>>2]|0;
 $662 = ($661|0)==(0|0);
 $663 = ($32|0)==(0);
 $or$cond135 = $662 | $663;
 if ($or$cond135) {
  STACKTOP = sp;return;
 }
 $664 = (($19) + 4|0);
 $665 = (($worldBox) + 4|0);
 $666 = (($19) + 8|0);
 $667 = (($worldBox) + 8|0);
 $668 = (($worldBox) + 24|0);
 $669 = (($20) + 4|0);
 $670 = (($worldBox) + 28|0);
 $671 = (($20) + 8|0);
 $672 = (($worldBox) + 32|0);
 $673 = (($worldBox) + 12|0);
 $674 = (($17) + 4|0);
 $675 = (($worldBox) + 16|0);
 $676 = (($17) + 8|0);
 $677 = (($worldBox) + 20|0);
 $678 = (($18) + 4|0);
 $679 = (($18) + 8|0);
 $680 = (($15) + 4|0);
 $681 = (($15) + 8|0);
 $682 = (($16) + 4|0);
 $683 = (($16) + 8|0);
 $i18$0101 = 0;
 while(1) {
  __ZN5physxL11getTriangleERKNS_2Gu12TriangleMeshEjPNS_6PxVec3EPKS4_PKvRKNS_2Cm8Matrix34Eb($i18$0101,$worldBox,$36,$38,$absPose,$42);
  $684 = HEAP32[$660>>2]|0;
  $685 = (($684) + ($i18$0101)|0);
  $686 = HEAP8[$685>>0]|0;
  $687 = $686&255;
  $688 = $687 & 8;
  $689 = ($688|0)==(0);
  if (!($689)) {
   $690 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
   $691 = (__ZN5physx2Cm12RenderOutputlsEj($690,-256)|0);
   $692 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($691,1)|0);
   $693 = Math_fround(HEAPF32[$worldBox>>2]);
   HEAPF32[$15>>2] = $693;
   $694 = Math_fround(HEAPF32[$665>>2]);
   HEAPF32[$680>>2] = $694;
   $695 = Math_fround(HEAPF32[$667>>2]);
   HEAPF32[$681>>2] = $695;
   $696 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($692,$15)|0);
   $697 = Math_fround(HEAPF32[$673>>2]);
   HEAPF32[$16>>2] = $697;
   $698 = Math_fround(HEAPF32[$675>>2]);
   HEAPF32[$682>>2] = $698;
   $699 = Math_fround(HEAPF32[$677>>2]);
   HEAPF32[$683>>2] = $699;
   (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($696,$16)|0);
  }
  $700 = $687 & 16;
  $701 = ($700|0)==(0);
  if (!($701)) {
   $702 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
   $703 = (__ZN5physx2Cm12RenderOutputlsEj($702,-256)|0);
   $704 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($703,1)|0);
   $705 = Math_fround(HEAPF32[$673>>2]);
   HEAPF32[$17>>2] = $705;
   $706 = Math_fround(HEAPF32[$675>>2]);
   HEAPF32[$674>>2] = $706;
   $707 = Math_fround(HEAPF32[$677>>2]);
   HEAPF32[$676>>2] = $707;
   $708 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($704,$17)|0);
   $709 = Math_fround(HEAPF32[$668>>2]);
   HEAPF32[$18>>2] = $709;
   $710 = Math_fround(HEAPF32[$670>>2]);
   HEAPF32[$678>>2] = $710;
   $711 = Math_fround(HEAPF32[$672>>2]);
   HEAPF32[$679>>2] = $711;
   (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($708,$18)|0);
  }
  $712 = $687 & 32;
  $713 = ($712|0)==(0);
  if (!($713)) {
   $714 = (__ZN5physx2Cm12RenderOutputlsERKNS_7PxMat44E($out,$midt)|0);
   $715 = (__ZN5physx2Cm12RenderOutputlsEj($714,-256)|0);
   $716 = (__ZN5physx2Cm12RenderOutputlsENS1_9PrimitiveE($715,1)|0);
   $717 = Math_fround(HEAPF32[$worldBox>>2]);
   HEAPF32[$19>>2] = $717;
   $718 = Math_fround(HEAPF32[$665>>2]);
   HEAPF32[$664>>2] = $718;
   $719 = Math_fround(HEAPF32[$667>>2]);
   HEAPF32[$666>>2] = $719;
   $720 = (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($716,$19)|0);
   $721 = Math_fround(HEAPF32[$668>>2]);
   HEAPF32[$20>>2] = $721;
   $722 = Math_fround(HEAPF32[$670>>2]);
   HEAPF32[$669>>2] = $722;
   $723 = Math_fround(HEAPF32[$672>>2]);
   HEAPF32[$671>>2] = $723;
   (__ZN5physx2Cm12RenderOutputlsENS_6PxVec3E($720,$20)|0);
  }
  $724 = (($i18$0101) + 1)|0;
  $exitcond = ($724|0)==($32|0);
  if ($exitcond) {
   break;
  } else {
   $i18$0101 = $724;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physxL11getTriangleERKNS_2Gu12TriangleMeshEjPNS_6PxVec3EPKS4_PKvRKNS_2Cm8Matrix34Eb($i,$wp,$vertices,$indices,$absPose,$has16BitIndices) {
 $i = $i|0;
 $wp = $wp|0;
 $vertices = $vertices|0;
 $indices = $indices|0;
 $absPose = $absPose|0;
 $has16BitIndices = $has16BitIndices|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0;
 var $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $localVerts = 0, $ref0$0$i = 0, $ref1$0$i = 0;
 var $ref2$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $localVerts = sp;
 if ($has16BitIndices) {
  $9 = ($i*3)|0;
  $10 = (($indices) + ($9<<1)|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = $11&65535;
  $13 = (($9) + 1)|0;
  $14 = (($indices) + ($13<<1)|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = $15&65535;
  $17 = (($9) + 2)|0;
  $18 = (($indices) + ($17<<1)|0);
  $19 = HEAP16[$18>>1]|0;
  $20 = $19&65535;
  $ref0$0$i = $12;$ref1$0$i = $16;$ref2$0$i = $20;
 } else {
  $0 = ($i*3)|0;
  $1 = (($indices) + ($0<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($0) + 1)|0;
  $4 = (($indices) + ($3<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($0) + 2)|0;
  $7 = (($indices) + ($6<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $ref0$0$i = $2;$ref1$0$i = $5;$ref2$0$i = $8;
 }
 $21 = (($vertices) + (($ref0$0$i*12)|0)|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$localVerts>>2] = $22;
 $23 = ((($vertices) + (($ref0$0$i*12)|0)|0) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($localVerts) + 4|0);
 HEAPF32[$25>>2] = $24;
 $26 = ((($vertices) + (($ref0$0$i*12)|0)|0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($localVerts) + 8|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($vertices) + (($ref1$0$i*12)|0)|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($localVerts) + 12|0);
 HEAPF32[$31>>2] = $30;
 $32 = ((($vertices) + (($ref1$0$i*12)|0)|0) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($localVerts) + 16|0);
 HEAPF32[$34>>2] = $33;
 $35 = ((($vertices) + (($ref1$0$i*12)|0)|0) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($localVerts) + 20|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($vertices) + (($ref2$0$i*12)|0)|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($localVerts) + 24|0);
 HEAPF32[$40>>2] = $39;
 $41 = ((($vertices) + (($ref2$0$i*12)|0)|0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($localVerts) + 28|0);
 HEAPF32[$43>>2] = $42;
 $44 = ((($vertices) + (($ref2$0$i*12)|0)|0) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($localVerts) + 32|0);
 HEAPF32[$46>>2] = $45;
 $47 = Math_fround(HEAPF32[$absPose>>2]);
 $48 = Math_fround($22 * $47);
 $49 = (($absPose) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($22 * $50);
 $52 = (($absPose) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($22 * $53);
 $55 = (($absPose) + 12|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($24 * $56);
 $58 = (($absPose) + 16|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($24 * $59);
 $61 = (($absPose) + 20|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($24 * $62);
 $64 = Math_fround($48 + $57);
 $65 = Math_fround($51 + $60);
 $66 = Math_fround($54 + $63);
 $67 = (($absPose) + 24|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($27 * $68);
 $70 = (($absPose) + 28|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($27 * $71);
 $73 = (($absPose) + 32|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($27 * $74);
 $76 = Math_fround($64 + $69);
 $77 = Math_fround($65 + $72);
 $78 = Math_fround($66 + $75);
 $79 = (($absPose) + 36|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($76 + $80);
 $82 = (($absPose) + 40|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($77 + $83);
 $85 = (($absPose) + 44|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($78 + $86);
 HEAPF32[$wp>>2] = $81;
 $88 = (($wp) + 4|0);
 HEAPF32[$88>>2] = $84;
 $89 = (($wp) + 8|0);
 HEAPF32[$89>>2] = $87;
 $90 = Math_fround(HEAPF32[$absPose>>2]);
 $91 = Math_fround($30 * $90);
 $92 = Math_fround(HEAPF32[$49>>2]);
 $93 = Math_fround($30 * $92);
 $94 = Math_fround(HEAPF32[$52>>2]);
 $95 = Math_fround($30 * $94);
 $96 = Math_fround(HEAPF32[$55>>2]);
 $97 = Math_fround($33 * $96);
 $98 = Math_fround(HEAPF32[$58>>2]);
 $99 = Math_fround($33 * $98);
 $100 = Math_fround(HEAPF32[$61>>2]);
 $101 = Math_fround($33 * $100);
 $102 = Math_fround($91 + $97);
 $103 = Math_fround($93 + $99);
 $104 = Math_fround($95 + $101);
 $105 = Math_fround(HEAPF32[$67>>2]);
 $106 = Math_fround($36 * $105);
 $107 = Math_fround(HEAPF32[$70>>2]);
 $108 = Math_fround($36 * $107);
 $109 = Math_fround(HEAPF32[$73>>2]);
 $110 = Math_fround($36 * $109);
 $111 = Math_fround($102 + $106);
 $112 = Math_fround($103 + $108);
 $113 = Math_fround($104 + $110);
 $114 = Math_fround(HEAPF32[$79>>2]);
 $115 = Math_fround($111 + $114);
 $116 = Math_fround(HEAPF32[$82>>2]);
 $117 = Math_fround($112 + $116);
 $118 = Math_fround(HEAPF32[$85>>2]);
 $119 = Math_fround($113 + $118);
 $120 = (($wp) + 12|0);
 HEAPF32[$120>>2] = $115;
 $121 = (($wp) + 16|0);
 HEAPF32[$121>>2] = $117;
 $122 = (($wp) + 20|0);
 HEAPF32[$122>>2] = $119;
 $123 = Math_fround(HEAPF32[$absPose>>2]);
 $124 = Math_fround($39 * $123);
 $125 = Math_fround(HEAPF32[$49>>2]);
 $126 = Math_fround($39 * $125);
 $127 = Math_fround(HEAPF32[$52>>2]);
 $128 = Math_fround($39 * $127);
 $129 = Math_fround(HEAPF32[$55>>2]);
 $130 = Math_fround($42 * $129);
 $131 = Math_fround(HEAPF32[$58>>2]);
 $132 = Math_fround($42 * $131);
 $133 = Math_fround(HEAPF32[$61>>2]);
 $134 = Math_fround($42 * $133);
 $135 = Math_fround($124 + $130);
 $136 = Math_fround($126 + $132);
 $137 = Math_fround($128 + $134);
 $138 = Math_fround(HEAPF32[$46>>2]);
 $139 = Math_fround(HEAPF32[$67>>2]);
 $140 = Math_fround($138 * $139);
 $141 = Math_fround(HEAPF32[$70>>2]);
 $142 = Math_fround($138 * $141);
 $143 = Math_fround(HEAPF32[$73>>2]);
 $144 = Math_fround($138 * $143);
 $145 = Math_fround($135 + $140);
 $146 = Math_fround($136 + $142);
 $147 = Math_fround($137 + $144);
 $148 = Math_fround(HEAPF32[$79>>2]);
 $149 = Math_fround($145 + $148);
 $150 = Math_fround(HEAPF32[$82>>2]);
 $151 = Math_fround($146 + $150);
 $152 = Math_fround(HEAPF32[$85>>2]);
 $153 = Math_fround($147 + $152);
 $154 = (($wp) + 24|0);
 HEAPF32[$154>>2] = $149;
 $155 = (($wp) + 28|0);
 HEAPF32[$155>>2] = $151;
 $156 = (($wp) + 32|0);
 HEAPF32[$156>>2] = $153;
 STACKTOP = sp;return;
}
function __ZN5physx14PxTriangleMeshD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx14PxTriangleMeshD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11HeightFieldC2EPNS_13GuMeshFactoryE($this,$meshFactory) {
 $this = $this|0;
 $meshFactory = $meshFactory|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP16[$0>>1] = 1;
 $1 = (($this) + 6|0);
 HEAP16[$1>>1] = 3;
 HEAP32[$this>>2] = ((553752 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = ((424432 + 8|0));
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 1;
 HEAP32[$this>>2] = ((553344 + 8|0));
 HEAP32[$2>>2] = ((553344 + 104|0));
 $4 = (($this) + 96|0);
 $5 = (($this) + 112|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 HEAP32[$5>>2] = $meshFactory;
 $6 = (($this) + 52|0);
 HEAP32[$6>>2] = 1;
 $7 = (($this) + 16|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 20|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 36|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP16[$9+12>>1]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11HeightFieldD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((553344 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((553344 + 104|0));
 $2 = (($this) + 6|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & 1;
 $5 = ($4<<16>>16)==(0);
 if (!($5)) {
  $6 = (($this) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
  HEAP32[$6>>2] = 0;
 }
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$this);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu11HeightFieldD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 HEAP32[$1>>2] = ((553344 + 8|0));
 $2 = (($1) + 8|0);
 HEAP32[$2>>2] = ((553344 + 104|0));
 $3 = (($1) + 6|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 1;
 $6 = ($5<<16>>16)==(0);
 if ($6) {
  __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
  STACKTOP = sp;return;
 }
 $7 = (($1) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$8);
 HEAP32[$7>>2] = 0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$1);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11HeightFieldD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = ((553344 + 8|0));
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = ((553344 + 104|0));
 $2 = (($this) + 6|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & 1;
 $5 = ($4<<16>>16)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$7);
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu11HeightFieldD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + -8|0);
 HEAP32[$1>>2] = ((553344 + 8|0));
 $2 = (($1) + 8|0);
 HEAP32[$2>>2] = ((553344 + 104|0));
 $3 = (($1) + 6|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 1;
 $6 = ($5<<16>>16)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($1) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$8);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11HeightField13releaseMemoryEb($this,$enableTiled) {
 $this = $this|0;
 $enableTiled = $enableTiled|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 6|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & 1;
 $4 = ($3<<16>>16)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$6);
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11HeightField14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx13GuMeshFactory17removeHeightFieldERNS_13PxHeightFieldE($1,$this)|0);
 if (!($2)) {
  $13 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($13,8,553464,96,553552,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$0>>2]|0;
 $4 = (($this) + 6|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 & 1;
 $7 = ($6<<16>>16)==(0);
 $8 = HEAP32[$this>>2]|0;
 if ($7) {
  $11 = (($8) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($this);
 } else {
  $9 = (($8) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 4095]($this);
 }
 __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($3,$this,1,1);
 STACKTOP = sp;return;
}
function __ZThn8_N5physx2Gu11HeightField14onRefCountZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + -8|0);
 $1 = (($0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN5physx13GuMeshFactory17removeHeightFieldERNS_13PxHeightFieldE($2,$0)|0);
 if (!($3)) {
  $14 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($14,8,553464,96,553552,$vararg_buffer);
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$1>>2]|0;
 $5 = (($0) + 6|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6 & 1;
 $8 = ($7<<16>>16)==(0);
 $9 = HEAP32[$0>>2]|0;
 if ($8) {
  $12 = (($9) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($0);
 } else {
  $10 = (($9) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($0);
 }
 __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($4,$0,1,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11HeightField15exportExtraDataERNS_22PxSerializationContextE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1 << 2;
 $5 = Math_imul($4, $3)|0;
 $6 = HEAP32[$stream>>2]|0;
 $7 = (($6) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095]($stream,16);
 $9 = HEAP32[$stream>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viii[$11 & 4095]($stream,$13,$5);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11HeightField7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5physx13GuMeshFactory21notifyFactoryListenerEPKNS_6PxBaseEtb($1,$this,1,0);
 $2 = (($this) + 6|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 & -3;
 HEAP16[$2>>1] = $4;
 $5 = (($this) + 8|0);
 $6 = (($this) + 12|0);
 $7 = (__ZN5physx6shdfnd15atomicDecrementEPVi($6)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$5>>2]|0;
 $10 = (($9) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$11 & 4095]($5);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu11HeightField17getReferenceCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx2Gu11HeightField13modifySamplesEiiRKNS_17PxHeightFieldDescEb($this,$startCol,$startRow,$desc,$shrinkBounds) {
 $this = $this|0;
 $startCol = $startCol|0;
 $startRow = $startRow|0;
 $desc = $desc|0;
 $shrinkBounds = $shrinkBounds|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $9 = Math_fround(0), $col$05$us = 0, $exitcond = 0, $exitcond20 = 0, $exitcond25 = 0, $exitcond28 = 0, $maxHeight$0$lcssa = Math_fround(0), $maxHeight$012$us = Math_fround(0), $maxHeight$16$us = Math_fround(0), $maxHeight$22 = Math_fround(0), $maxHeight$3 = Math_fround(0), $minHeight$0$lcssa = Math_fround(0);
 var $minHeight$013$us = Math_fround(0), $minHeight$17$us = Math_fround(0), $minHeight$23 = Math_fround(0), $minHeight$3 = Math_fround(0), $row$011 = 0, $row$011$us = 0, $storemerge$in$us = 0, $storemerge$us = 0, $umax = 0, $umax24 = 0, $umax27 = 0, $vertexIndex1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
 $8 = (($this) + 104|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 108|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = HEAP32[$desc>>2]|0;
 $13 = (($12) + ($startRow))|0;
 $14 = ($13|0)>(0);
 $15 = $14 ? $13 : 0;
 $16 = ($15>>>0)<($7>>>0);
 $17 = $16 ? $15 : $7;
 $18 = (($desc) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($startCol))|0;
 $21 = ($20|0)>(0);
 $22 = $21 ? $20 : 0;
 $23 = ($startRow|0)<(0);
 $24 = $23 ? 0 : $startRow;
 $25 = ($24>>>0)<($17>>>0);
 L1: do {
  if ($25) {
   $26 = ($22>>>0)<($3>>>0);
   $27 = $26 ? $22 : $3;
   $28 = ($startCol|0)<(0);
   $29 = $28 ? 0 : $startCol;
   $30 = ($29>>>0)<($27>>>0);
   $31 = (($this) + 36|0);
   $32 = (($desc) + 16|0);
   if (!($30)) {
    $33 = $7 ^ -1;
    $34 = $15 ^ -1;
    $35 = ($33>>>0)>($34>>>0);
    $umax = $35 ? $33 : $34;
    $36 = $umax ^ -1;
    $row$011 = $24;
    while(1) {
     $73 = (($row$011) + 1)|0;
     $exitcond20 = ($73|0)==($36|0);
     if ($exitcond20) {
      $maxHeight$0$lcssa = $11;$minHeight$0$lcssa = $9;
      break L1;
     } else {
      $row$011 = $73;
     }
    }
   }
   $37 = $3 ^ -1;
   $38 = $22 ^ -1;
   $39 = ($37>>>0)>($38>>>0);
   $umax24 = $39 ? $37 : $38;
   $40 = $umax24 ^ -1;
   $41 = $7 ^ -1;
   $42 = $15 ^ -1;
   $43 = ($41>>>0)>($42>>>0);
   $umax27 = $43 ? $41 : $42;
   $44 = $umax27 ^ -1;
   $maxHeight$012$us = $11;$minHeight$013$us = $9;$row$011$us = $24;
   while(1) {
    $47 = Math_imul($row$011$us, $3)|0;
    $53 = (($row$011$us) - ($startRow))|0;
    $$pre = HEAP32[$31>>2]|0;
    $49 = $$pre;$col$05$us = $29;$maxHeight$16$us = $maxHeight$012$us;$minHeight$17$us = $minHeight$013$us;
    while(1) {
     $46 = (($col$05$us) + ($47))|0;
     $48 = (($49) + ($46<<2)|0);
     $50 = (($col$05$us) - ($startCol))|0;
     $51 = HEAP32[$18>>2]|0;
     $52 = Math_imul($51, $53)|0;
     $54 = (($50) + ($52))|0;
     $55 = HEAP32[$32>>2]|0;
     $56 = (($55) + ($54<<2)|0);
     $57 = HEAPU16[$56>>1]|(HEAPU16[$56+2>>1]<<16);
     HEAP16[$48>>1]=$57&65535;HEAP16[$48+2>>1]=$57>>>16;
     $58 = (__ZNK5physx2Gu11HeightField22isCollisionVertexPrecaEjjjt($this,$46,$row$011$us,$col$05$us,127)|0);
     $59 = ((($49) + ($46<<2)|0) + 3|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60&255;
     $62 = $61 & 127;
     $63 = $61 | 128;
     $storemerge$in$us = $58 ? $63 : $62;
     $storemerge$us = $storemerge$in$us&255;
     HEAP8[$59>>0] = $storemerge$us;
     $64 = HEAP32[$31>>2]|0;
     $65 = (($64) + ($46<<2)|0);
     $66 = HEAP16[$65>>1]|0;
     $67 = (Math_fround(($66<<16>>16)));
     $68 = $67 < $minHeight$17$us;
     $69 = $68 ? $67 : $minHeight$17$us;
     $70 = $67 > $maxHeight$16$us;
     $71 = $70 ? $67 : $maxHeight$16$us;
     $72 = (($col$05$us) + 1)|0;
     $exitcond25 = ($72|0)==($40|0);
     if ($exitcond25) {
      break;
     } else {
      $49 = $64;$col$05$us = $72;$maxHeight$16$us = $71;$minHeight$17$us = $69;
     }
    }
    $45 = (($row$011$us) + 1)|0;
    $exitcond28 = ($45|0)==($44|0);
    if ($exitcond28) {
     $maxHeight$0$lcssa = $71;$minHeight$0$lcssa = $69;
     break;
    } else {
     $maxHeight$012$us = $71;$minHeight$013$us = $69;$row$011$us = $45;
    }
   }
  } else {
   $maxHeight$0$lcssa = $11;$minHeight$0$lcssa = $9;
  }
 } while(0);
 if (!($shrinkBounds)) {
  $maxHeight$3 = $maxHeight$0$lcssa;$minHeight$3 = $minHeight$0$lcssa;
  HEAPF32[$8>>2] = $minHeight$3;
  HEAPF32[$10>>2] = $maxHeight$3;
  $86 = (($this) + 60|0);
  HEAPF32[$86>>2] = $minHeight$3;
  $87 = (($this) + 72|0);
  HEAPF32[$87>>2] = $maxHeight$3;
  STACKTOP = sp;return 1;
 }
 $74 = Math_imul($7, $3)|0;
 $75 = ($74|0)==(0);
 if ($75) {
  $maxHeight$3 = Math_fround(-3.40282346638528859812E+38);$minHeight$3 = Math_fround(3.40282346638528859812E+38);
  HEAPF32[$8>>2] = $minHeight$3;
  HEAPF32[$10>>2] = $maxHeight$3;
  $86 = (($this) + 60|0);
  HEAPF32[$86>>2] = $minHeight$3;
  $87 = (($this) + 72|0);
  HEAPF32[$87>>2] = $maxHeight$3;
  STACKTOP = sp;return 1;
 }
 $76 = (($this) + 36|0);
 $77 = HEAP32[$76>>2]|0;
 $maxHeight$22 = Math_fround(-3.40282346638528859812E+38);$minHeight$23 = Math_fround(3.40282346638528859812E+38);$vertexIndex1$01 = 0;
 while(1) {
  $78 = (($77) + ($vertexIndex1$01<<2)|0);
  $79 = HEAP16[$78>>1]|0;
  $80 = (Math_fround(($79<<16>>16)));
  $81 = $80 < $minHeight$23;
  $82 = $81 ? $80 : $minHeight$23;
  $83 = $80 > $maxHeight$22;
  $84 = $83 ? $80 : $maxHeight$22;
  $85 = (($vertexIndex1$01) + 1)|0;
  $exitcond = ($85|0)==($74|0);
  if ($exitcond) {
   $maxHeight$3 = $84;$minHeight$3 = $82;
   break;
  } else {
   $maxHeight$22 = $84;$minHeight$23 = $82;$vertexIndex1$01 = $85;
  }
 }
 HEAPF32[$8>>2] = $minHeight$3;
 HEAPF32[$10>>2] = $maxHeight$3;
 $86 = (($this) + 60|0);
 HEAPF32[$86>>2] = $minHeight$3;
 $87 = (($this) + 72|0);
 HEAPF32[$87>>2] = $maxHeight$3;
 STACKTOP = sp;return 1;
}
function __ZNK5physx2Gu11HeightField22isCollisionVertexPrecaEjjjt($this,$vertexIndex,$row,$column,$holeMaterialIndex) {
 $this = $this|0;
 $vertexIndex = $vertexIndex|0;
 $row = $row|0;
 $column = $column|0;
 $holeMaterialIndex = $holeMaterialIndex|0;
 var $$1 = 0, $$not = 0, $$sink$i = 0, $$sink$i5 = 0, $$sink$in$i = 0, $$sink$in$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0);
 var $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $brmerge = 0, $convexityX$0$i = 0, $convexityZ$02$i = 0, $currentfaceIndices$012 = 0, $definedInX$0$off0$i = 0, $dst$015 = 0, $edgeIndices = 0, $exitcond = 0, $faceCounts = 0, $faceIndices = 0, $i$014 = 0, $i1$013 = 0, $nbSolid$0$off011 = 0;
 var $nbSolid$1$off0$mux = 0, $nbSolid$2$off0 = 0, $not$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $edgeIndices = sp + 96|0;
 $faceCounts = sp;
 $faceIndices = sp + 32|0;
 $0 = (($this) + 48|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 1;
 $3 = ($2<<16>>16)==(0);
 if (!($3)) {
  $4 = ($row|0)==(0);
  $5 = ($column|0)==(0);
  $or$cond = $4 | $5;
  if ($or$cond) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $6 = (($this) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + -1)|0;
  $9 = ($8>>>0)>($row>>>0);
  if (!($9)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $10 = (($this) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + -1)|0;
  $13 = ($12>>>0)>($column>>>0);
  if (!($13)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $14 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($this,$vertexIndex,$row,$column,$edgeIndices)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 } else {
  $dst$015 = $faceIndices;$i$014 = 0;
 }
 while(1) {
  $18 = (($edgeIndices) + ($i$014<<4)|0);
  $19 = (__ZN5physx22getEdgeTriangleIndicesERKNS_2Gu11HeightFieldERKNS_8EdgeDataEPj($this,$18,$dst$015)|0);
  $20 = (($faceCounts) + ($i$014<<2)|0);
  HEAP32[$20>>2] = $19;
  $21 = (($dst$015) + 8|0);
  $22 = (($i$014) + 1)|0;
  $exitcond = ($22|0)==($14|0);
  if ($exitcond) {
   break;
  } else {
   $dst$015 = $21;$i$014 = $22;
  }
 }
 if ($15) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $16 = (($this) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $currentfaceIndices$012 = $faceIndices;$i1$013 = 0;$nbSolid$0$off011 = 0;
 L19: while(1) {
  $23 = (($faceCounts) + ($i1$013<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24>>>0)>(1);
  $26 = HEAP32[$currentfaceIndices$012>>2]|0;
  $27 = $26 & 1;
  $28 = ($27|0)==(0);
  $29 = $26 >>> 1;
  if ($28) {
   $30 = ((($17) + ($29<<2)|0) + 2|0);
   $$sink$in$i4 = $30;
  } else {
   $31 = ((($17) + ($29<<2)|0) + 3|0);
   $$sink$in$i4 = $31;
  }
  $$sink$i5 = HEAP8[$$sink$in$i4>>0]|0;
  $32 = $$sink$i5&255;
  $33 = $32 & 127;
  $34 = $33&65535;
  do {
   if ($25) {
    $35 = (($currentfaceIndices$012) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36 & 1;
    $38 = ($37|0)==(0);
    $39 = $36 >>> 1;
    if ($38) {
     $40 = ((($17) + ($39<<2)|0) + 2|0);
     $$sink$in$i = $40;
    } else {
     $41 = ((($17) + ($39<<2)|0) + 3|0);
     $$sink$in$i = $41;
    }
    $$sink$i = HEAP8[$$sink$in$i>>0]|0;
    $42 = $$sink$i&255;
    $43 = $42 & 127;
    $44 = $43&65535;
    $45 = ($34<<16>>16)==($holeMaterialIndex<<16>>16);
    $46 = ($44<<16>>16)==($holeMaterialIndex<<16>>16);
    if ($45) {
     $$not = $45 ^ 1;
     $brmerge = $46 | $$not;
     $not$ = $46 ^ 1;
     $nbSolid$1$off0$mux = $nbSolid$0$off011 | $not$;
     if ($brmerge) {
      $nbSolid$2$off0 = $nbSolid$1$off0$mux;
      break;
     } else {
      $$1 = 1;
      label = 34;
      break L19;
     }
    } else {
     if ($46) {
      $$1 = 1;
      label = 34;
      break L19;
     } else {
      $nbSolid$2$off0 = 1;
      break;
     }
    }
   } else {
    $47 = ($34<<16>>16)==($holeMaterialIndex<<16>>16);
    if ($47) {
     $nbSolid$2$off0 = $nbSolid$0$off011;
    } else {
     $$1 = 1;
     label = 34;
     break L19;
    }
   }
  } while(0);
  $48 = (($i1$013) + 1)|0;
  $49 = ($48>>>0)<($14>>>0);
  if (!($49)) {
   label = 22;
   break;
  }
  $50 = (($currentfaceIndices$012) + 8|0);
  $currentfaceIndices$012 = $50;$i1$013 = $48;$nbSolid$0$off011 = $nbSolid$2$off0;
 }
 if ((label|0) == 22) {
  if (!($nbSolid$2$off0)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $51 = (($this) + 36|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + ($vertexIndex<<2)|0);
  $54 = HEAP16[$53>>1]|0;
  $55 = $54 << 16 >> 16;
  $56 = $55 << 1;
  $57 = ($row|0)==(0);
  if ($57) {
   $convexityX$0$i = 0;$definedInX$0$off0$i = 0;
  } else {
   $58 = (($this) + 16|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + -1)|0;
   $61 = ($60>>>0)>($row>>>0);
   if ($61) {
    $62 = (($this) + 20|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($63) + ($vertexIndex))|0;
    $65 = (($52) + ($64<<2)|0);
    $66 = HEAP16[$65>>1]|0;
    $67 = $66 << 16 >> 16;
    $68 = (($56) - ($67))|0;
    $69 = (($vertexIndex) - ($63))|0;
    $70 = (($52) + ($69<<2)|0);
    $71 = HEAP16[$70>>1]|0;
    $72 = $71 << 16 >> 16;
    $73 = (($68) - ($72))|0;
    $convexityX$0$i = $73;$definedInX$0$off0$i = 1;
   } else {
    $convexityX$0$i = 0;$definedInX$0$off0$i = 0;
   }
  }
  $74 = ($column|0)==(0);
  if ($74) {
   label = 29;
  } else {
   $75 = (($this) + 20|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($76) + -1)|0;
   $78 = ($77>>>0)>($column>>>0);
   if ($78) {
    $79 = (($vertexIndex) + 1)|0;
    $80 = (($52) + ($79<<2)|0);
    $81 = HEAP16[$80>>1]|0;
    $82 = $81 << 16 >> 16;
    $83 = (($56) - ($82))|0;
    $84 = (($vertexIndex) + -1)|0;
    $85 = (($52) + ($84<<2)|0);
    $86 = HEAP16[$85>>1]|0;
    $87 = $86 << 16 >> 16;
    $88 = (($83) - ($87))|0;
    $convexityZ$02$i = $88;
   } else {
    label = 29;
   }
  }
  if ((label|0) == 29) {
   if ($definedInX$0$off0$i) {
    $convexityZ$02$i = 0;
   } else {
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $89 = $convexityZ$02$i ^ $convexityX$0$i;
  $90 = ($89|0)>(-1);
  if ($90) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $91 = (($convexityZ$02$i) + ($convexityX$0$i))|0;
  $92 = (Math_fround(($91|0)));
  $93 = (($this) + 40|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = !($94 <= Math_fround(0.0));
  $96 = (($this) + 44|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  if ($95) {
   $99 = Math_fround(-$97);
   $100 = $92 < $99;
   $$1 = $100;
   STACKTOP = sp;return ($$1|0);
  } else {
   $98 = $92 > $97;
   $$1 = $98;
   STACKTOP = sp;return ($$1|0);
  }
 }
 else if ((label|0) == 34) {
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZN5physx2Gu11HeightField4loadERNS_13PxInputStreamE($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $endian = 0, $i$01 = 0, $vararg_buffer = 0, $version = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $version = sp + 4|0;
 $endian = sp + 9|0;
 $0 = sp + 8|0;
 $1 = (($this) + 6|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & 1;
 $4 = ($3<<16>>16)==(0);
 if (!($4)) {
  $5 = (($this) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$6);
  HEAP32[$5>>2] = 0;
 }
 $7 = (__ZN5physx10readHeaderEaaaaRjRbRNS_13PxInputStreamE(72,70,72,70,$version,$endian,$stream)|0);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP8[$endian>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 $10 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($9,$stream)|0);
 $11 = (($this) + 16|0);
 HEAP32[$11>>2] = $10;
 $12 = HEAP8[$endian>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 $14 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($13,$stream)|0);
 $15 = (($this) + 20|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP8[$endian>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($17,$stream)));
 $19 = (($this) + 24|0);
 HEAPF32[$19>>2] = $18;
 $20 = HEAP8[$endian>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($21,$stream)));
 $23 = (($this) + 28|0);
 HEAPF32[$23>>2] = $22;
 $24 = HEAP8[$endian>>0]|0;
 $25 = ($24<<24>>24)!=(0);
 $26 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($25,$stream)));
 $27 = (($this) + 32|0);
 HEAPF32[$27>>2] = $26;
 $28 = HEAP8[$endian>>0]|0;
 $29 = ($28<<24>>24)!=(0);
 $30 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($29,$stream)));
 $31 = (($this) + 40|0);
 HEAPF32[$31>>2] = $30;
 $32 = HEAP8[$endian>>0]|0;
 $33 = ($32<<24>>24)!=(0);
 $34 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($33,$stream)));
 $35 = (($this) + 44|0);
 HEAPF32[$35>>2] = $34;
 $36 = HEAP8[$endian>>0]|0;
 $37 = ($36<<24>>24)!=(0);
 $38 = (__ZN5physx8readWordEbRNS_13PxInputStreamE($37,$stream)|0);
 $39 = (($this) + 48|0);
 HEAP16[$39>>1] = $38;
 $40 = HEAP8[$endian>>0]|0;
 $41 = ($40<<24>>24)!=(0);
 $42 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($41,$stream)|0);
 $43 = (($this) + 52|0);
 HEAP32[$43>>2] = $42;
 $44 = HEAP8[$endian>>0]|0;
 $45 = ($44<<24>>24)!=(0);
 $46 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($45,$stream)));
 $47 = (($this) + 56|0);
 HEAPF32[$47>>2] = $46;
 $48 = HEAP8[$endian>>0]|0;
 $49 = ($48<<24>>24)!=(0);
 $50 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($49,$stream)));
 $51 = (($this) + 60|0);
 HEAPF32[$51>>2] = $50;
 $52 = HEAP8[$endian>>0]|0;
 $53 = ($52<<24>>24)!=(0);
 $54 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($53,$stream)));
 $55 = (($this) + 64|0);
 HEAPF32[$55>>2] = $54;
 $56 = HEAP8[$endian>>0]|0;
 $57 = ($56<<24>>24)!=(0);
 $58 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($57,$stream)));
 $59 = (($this) + 68|0);
 HEAPF32[$59>>2] = $58;
 $60 = HEAP8[$endian>>0]|0;
 $61 = ($60<<24>>24)!=(0);
 $62 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($61,$stream)));
 $63 = (($this) + 72|0);
 HEAPF32[$63>>2] = $62;
 $64 = HEAP8[$endian>>0]|0;
 $65 = ($64<<24>>24)!=(0);
 $66 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($65,$stream)));
 $67 = (($this) + 76|0);
 HEAPF32[$67>>2] = $66;
 $68 = HEAP8[$endian>>0]|0;
 $69 = ($68<<24>>24)!=(0);
 $70 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($69,$stream)|0);
 $71 = (($this) + 80|0);
 HEAP32[$71>>2] = $70;
 $72 = HEAP8[$endian>>0]|0;
 $73 = ($72<<24>>24)!=(0);
 $74 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($73,$stream)|0);
 $75 = (($this) + 84|0);
 HEAP32[$75>>2] = $74;
 $76 = HEAP8[$endian>>0]|0;
 $77 = ($76<<24>>24)!=(0);
 $78 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($77,$stream)|0);
 $79 = (($this) + 88|0);
 HEAP32[$79>>2] = $78;
 $80 = HEAP8[$endian>>0]|0;
 $81 = ($80<<24>>24)!=(0);
 $82 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($81,$stream)|0);
 $83 = (($this) + 92|0);
 HEAP32[$83>>2] = $82;
 $84 = HEAP8[$endian>>0]|0;
 $85 = ($84<<24>>24)!=(0);
 $86 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($85,$stream)|0);
 $87 = (($this) + 96|0);
 HEAP32[$87>>2] = $86;
 $88 = HEAP8[$endian>>0]|0;
 $89 = ($88<<24>>24)!=(0);
 $90 = (__ZN5physx9readDwordEbRNS_13PxInputStreamE($89,$stream)|0);
 $91 = (($this) + 100|0);
 HEAP32[$91>>2] = $90;
 $92 = HEAP8[$endian>>0]|0;
 $93 = ($92<<24>>24)!=(0);
 $94 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($93,$stream)));
 $95 = (($this) + 104|0);
 HEAPF32[$95>>2] = $94;
 $96 = HEAP8[$endian>>0]|0;
 $97 = ($96<<24>>24)!=(0);
 $98 = (Math_fround(__ZN5physx9readFloatEbRNS_13PxInputStreamE($97,$stream)));
 $99 = (($this) + 108|0);
 HEAPF32[$99>>2] = $98;
 $100 = (($this) + 36|0);
 HEAP32[$100>>2] = 0;
 $101 = HEAP32[$11>>2]|0;
 $102 = HEAP32[$15>>2]|0;
 $103 = Math_imul($102, $101)|0;
 $104 = ($103|0)==(0);
 if ($104) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $105 = $103 << 2;
 $106 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$105,553464,324)|0);
 HEAP32[$100>>2] = $106;
 $107 = ($106|0)==(0|0);
 if ($107) {
  $108 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
  __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($108,16,553464,327,553616,$vararg_buffer);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $109 = HEAP32[$stream>>2]|0;
 $110 = HEAP32[$109>>2]|0;
 $111 = HEAP32[$91>>2]|0;
 $112 = $111 << 2;
 (FUNCTION_TABLE_iiii[$110 & 2047]($stream,$106,$112)|0);
 $113 = HEAP8[$endian>>0]|0;
 $114 = ($113<<24>>24)==(0);
 if ($114) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $115 = HEAP32[$91>>2]|0;
 $116 = ($115|0)==(0);
 if ($116) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$01 = 0;
 }
 while(1) {
  $117 = HEAP32[$100>>2]|0;
  $118 = (($117) + ($i$01<<2)|0);
  $119 = HEAP8[$118>>0]|0;
  $120 = (($118) + 1|0);
  $121 = HEAP8[$120>>0]|0;
  HEAP8[$118>>0] = $121;
  HEAP8[$120>>0] = $119;
  $122 = (($i$01) + 1)|0;
  $123 = HEAP32[$91>>2]|0;
  $124 = ($122>>>0)<($123>>>0);
  if ($124) {
   $i$01 = $122;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu11HeightField12loadFromDescERKNS_17PxHeightFieldDescEb($this,$desc,$enableTile) {
 $this = $this|0;
 $desc = $desc|0;
 $enableTile = $enableTile|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $dst$01 = 0, $exitcond = 0, $i$04 = 0, $maxHeight$03 = 0, $minHeight$02 = 0, $phitmp = Math_fround(0), $phitmp7 = Math_fround(0), $src$05 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 6|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & 1;
 $4 = ($3<<16>>16)==(0);
 $$pre = (($this) + 36|0);
 if (!($4)) {
  $5 = HEAP32[$$pre>>2]|0;
  __ZN5physx6shdfnd9Allocator10deallocateEPv($vararg_buffer,$5);
  HEAP32[$$pre>>2] = 0;
 }
 $6 = (($desc) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 52|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$desc>>2]|0;
 $10 = (($this) + 16|0);
 HEAP32[$10>>2] = $9;
 $11 = (($desc) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 20|0);
 HEAP32[$13>>2] = $12;
 $14 = (($desc) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 40|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($desc) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 44|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($desc) + 28|0);
 $21 = HEAP16[$20>>1]|0;
 $22 = (($this) + 48|0);
 HEAP16[$22>>1] = $21;
 $23 = (($desc) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 96|0);
 HEAP32[$25>>2] = $24;
 $26 = (($9) + -2)|0;
 $27 = (Math_fround(($26>>>0)));
 $28 = (($this) + 24|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($12) + -2)|0;
 $30 = (Math_fround(($29>>>0)));
 $31 = (($this) + 28|0);
 HEAPF32[$31>>2] = $30;
 $32 = HEAP32[$11>>2]|0;
 $33 = (Math_fround(($32>>>0)));
 $34 = (($this) + 32|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($32) + 3)|0;
 $36 = $35 & -4;
 $37 = (($this) + 84|0);
 HEAP32[$37>>2] = $36;
 $38 = HEAP32[$desc>>2]|0;
 $39 = (($38) + 3)|0;
 $40 = $39 & -4;
 $41 = (($this) + 80|0);
 HEAP32[$41>>2] = $40;
 $42 = $35 >>> 2;
 $43 = (($this) + 88|0);
 HEAP32[$43>>2] = $42;
 $44 = $39 >>> 2;
 $45 = (($this) + 92|0);
 HEAP32[$45>>2] = $44;
 HEAP32[$$pre>>2] = 0;
 $46 = HEAP32[$desc>>2]|0;
 $47 = HEAP32[$11>>2]|0;
 $48 = Math_imul($47, $46)|0;
 $49 = (($this) + 104|0);
 HEAPF32[$49>>2] = Math_fround(3.40282346638528859812E+38);
 $50 = (($this) + 108|0);
 HEAPF32[$50>>2] = Math_fround(-3.40282346638528859812E+38);
 $51 = ($48|0)==(0);
 if (!($51)) {
  $52 = $48 << 2;
  $53 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($0,$52,553464,388)|0);
  HEAP32[$$pre>>2] = $53;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $55 = (__ZN5physx6shdfnd10Foundation11getInstanceEv()|0);
   __ZN5physx6shdfnd10Foundation5errorENS_11PxErrorCode4EnumEPKciS5_z($55,16,553464,391,553616,$vararg_buffer);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $56 = (($desc) + 16|0);
  $57 = HEAP32[$56>>2]|0;
  $dst$01 = $53;$i$04 = 0;$maxHeight$03 = -32768;$minHeight$02 = 32767;$src$05 = $57;
  while(1) {
   $58 = (($dst$01) + 4|0);
   $59 = HEAPU16[$src$05>>1]|(HEAPU16[$src$05+2>>1]<<16);
   HEAP16[$dst$01>>1]=$59&65535;HEAP16[$dst$01+2>>1]=$59>>>16;
   $60 = HEAP16[$src$05>>1]|0;
   $61 = ($60<<16>>16)<($minHeight$02<<16>>16);
   $62 = $61 ? $60 : $minHeight$02;
   $63 = ($60<<16>>16)>($maxHeight$03<<16>>16);
   $64 = $63 ? $60 : $maxHeight$03;
   $65 = HEAP32[$23>>2]|0;
   $66 = (($src$05) + ($65)|0);
   $67 = (($i$04) + 1)|0;
   $exitcond = ($67|0)==($48|0);
   if ($exitcond) {
    break;
   } else {
    $dst$01 = $58;$i$04 = $67;$maxHeight$03 = $64;$minHeight$02 = $62;$src$05 = $66;
   }
  }
  $phitmp = (Math_fround(($62<<16>>16)));
  $phitmp7 = (Math_fround(($64<<16>>16)));
  HEAPF32[$49>>2] = $phitmp;
  HEAPF32[$50>>2] = $phitmp7;
 }
 __ZN5physx2Gu11HeightField34parseTrianglesForCollisionVerticesEt($this,127);
 $68 = HEAP32[$10>>2]|0;
 $69 = HEAP32[$13>>2]|0;
 $70 = Math_imul($69, $68)|0;
 $71 = (($this) + 100|0);
 HEAP32[$71>>2] = $70;
 $72 = Math_fround(HEAPF32[$49>>2]);
 $73 = Math_fround(HEAPF32[$50>>2]);
 $74 = (($68) + -1)|0;
 $75 = (Math_fround(($74>>>0)));
 $76 = (($69) + -1)|0;
 $77 = (Math_fround(($76>>>0)));
 $78 = (($this) + 56|0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = (($this) + 60|0);
 HEAPF32[$79>>2] = $72;
 $80 = (($this) + 64|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 $81 = (($this) + 68|0);
 HEAPF32[$81>>2] = $75;
 $82 = (($this) + 72|0);
 HEAPF32[$82>>2] = $73;
 $83 = (($this) + 76|0);
 HEAPF32[$83>>2] = $77;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu11HeightField34parseTrianglesForCollisionVerticesEt($this,$holeMaterialIndex) {
 $this = $this|0;
 $holeMaterialIndex = $holeMaterialIndex|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i2 = 0, $$pre$phi25Z2D = 0, $$pre$phiZ2D = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $convexityX$0$i = 0, $convexityZ$02$i = 0, $currentRow$012 = 0, $definedInX$0$off0$i = 0, $exitcond = 0, $exitcond19 = 0, $exitcond20 = 0, $iCol$017 = 0, $iCol1$09 = 0, $iRow$013 = 0, $nextRow$015 = 0;
 var $or$cond = 0, $or$cond$i$i1 = 0, $phitmp = 0, $rowHoles = 0, $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $rowHoles = sp;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$rowHoles>>2] = 0;
 $4 = (($rowHoles) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($rowHoles) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($rowHoles) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = (($1) + 32)|0;
 $8 = $7 >>> 5;
 $9 = (($rowHoles) + 4|0);
 $10 = ($8|0)==(0);
 if ($10) {
  $14 = 0;$15 = 0;
 } else {
  $11 = (($rowHoles) + 8|0);
  HEAP32[$9>>2] = $8;
  $12 = $8 << 2;
  $13 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($11,$12,553656,362)|0);
  HEAP32[$rowHoles>>2] = $13;
  $$pre$i = HEAP32[$9>>2]|0;
  $phitmp = $$pre$i << 2;
  $14 = $13;$15 = $phitmp;
 }
 _memset(($14|0),0,($15|0))|0;
 $16 = (($rowHoles) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2147483647;
 $19 = ($8>>>0)>($18>>>0);
 $20 = (($rowHoles) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 if ($19) {
  $22 = ($21|0)!=(0|0);
  $23 = ($17|0)>(-1);
  $or$cond$i$i1 = $22 & $23;
  $24 = (($rowHoles) + 20|0);
  if ($or$cond$i$i1) {
   __ZN5physx6shdfnd9Allocator10deallocateEPv($24,$21);
  }
  HEAP32[$16>>2] = $8;
  $25 = $8 << 2;
  $26 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($24,$25,553656,362)|0);
  HEAP32[$20>>2] = $26;
  $$pre$i2 = HEAP32[$16>>2]|0;
  $28 = $$pre$i2;$29 = $26;
 } else {
  $28 = $17;$29 = $21;
 }
 $27 = $28 << 2;
 _memset(($29|0),0,($27|0))|0;
 $30 = ($1|0)==(0);
 if (!($30)) {
  $31 = (($this) + 36|0);
  $32 = $holeMaterialIndex&65535;
  $iCol$017 = 0;
  while(1) {
   $40 = HEAP32[$31>>2]|0;
   $41 = ((($40) + ($iCol$017<<2)|0) + 2|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = $42&255;
   $44 = $43 & 127;
   $45 = ((($40) + ($iCol$017<<2)|0) + 3|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = $46&255;
   $48 = $47 & 127;
   $49 = ($44|0)==($32|0);
   $50 = $49&1;
   $51 = ($48|0)==($32|0);
   $52 = $51&1;
   $53 = $52 | $50;
   $54 = ($53|0)==(0);
   if ($54) {
    $$pre24 = (($iCol$017) + 1)|0;
    $$pre$phi25Z2D = $$pre24;
   } else {
    $55 = $iCol$017 & 31;
    $56 = 1 << $55;
    $57 = $iCol$017 >>> 5;
    $58 = HEAP32[$rowHoles>>2]|0;
    $59 = (($58) + ($57<<2)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = $60 | $56;
    HEAP32[$59>>2] = $61;
    $62 = (($iCol$017) + 1)|0;
    $63 = $62 & 31;
    $64 = 1 << $63;
    $65 = $62 >>> 5;
    $66 = (($58) + ($65<<2)|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = $67 | $64;
    HEAP32[$66>>2] = $68;
    $$pre$phi25Z2D = $62;
   }
   $69 = (__ZNK5physx2Gu11HeightField22isCollisionVertexPrecaEjjjt($this,$iCol$017,0,$iCol$017,$holeMaterialIndex)|0);
   $70 = HEAP32[$31>>2]|0;
   $71 = ((($70) + ($iCol$017<<2)|0) + 3|0);
   $72 = HEAP8[$71>>0]|0;
   $73 = $72&255;
   $74 = $73 & 127;
   $75 = $73 | 128;
   $storemerge$in = $69 ? $75 : $74;
   $storemerge = $storemerge$in&255;
   HEAP8[$71>>0] = $storemerge;
   $exitcond20 = ($$pre$phi25Z2D|0)==($1|0);
   if ($exitcond20) {
    break;
   } else {
    $iCol$017 = $$pre$phi25Z2D;
   }
  }
 }
 $33 = ($3>>>0)>(1);
 if ($33) {
  $34 = (($this) + 36|0);
  $35 = $holeMaterialIndex&65535;
  $36 = (($1) + -1)|0;
  $37 = (($3) + -1)|0;
  $38 = (($this) + 40|0);
  $39 = (($this) + 44|0);
  $currentRow$012 = 0;$iRow$013 = 1;$nextRow$015 = 1;
  while(1) {
   $79 = Math_imul($iRow$013, $1)|0;
   if ($30) {
    $$pre = (($rowHoles) + (($currentRow$012*12)|0)|0);
    $$pre$phiZ2D = $$pre;
   } else {
    $80 = ($iRow$013|0)==($37|0);
    $81 = (($rowHoles) + (($currentRow$012*12)|0)|0);
    $82 = (($rowHoles) + (($nextRow$015*12)|0)|0);
    $iCol1$09 = 0;
    while(1) {
     $83 = (($iCol1$09) + ($79))|0;
     $84 = HEAP32[$34>>2]|0;
     $85 = ((($84) + ($83<<2)|0) + 2|0);
     $86 = HEAP8[$85>>0]|0;
     $87 = $86&255;
     $88 = $87 & 127;
     $89 = ((($84) + ($83<<2)|0) + 3|0);
     $90 = HEAP8[$89>>0]|0;
     $91 = $90&255;
     $92 = $91 & 127;
     $93 = ($88|0)==($35|0);
     $94 = $93&1;
     $95 = ($92|0)==($35|0);
     $96 = $95&1;
     $97 = $96 | $94;
     $98 = ($97|0)==(0);
     if (!($98)) {
      $99 = $iCol1$09 & 31;
      $100 = 1 << $99;
      $101 = $iCol1$09 >>> 5;
      $102 = HEAP32[$81>>2]|0;
      $103 = (($102) + ($101<<2)|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = $104 | $100;
      HEAP32[$103>>2] = $105;
      $106 = (($iCol1$09) + 1)|0;
      $107 = $106 & 31;
      $108 = 1 << $107;
      $109 = $106 >>> 5;
      $110 = (($102) + ($109<<2)|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = $111 | $108;
      HEAP32[$110>>2] = $112;
      $113 = HEAP32[$82>>2]|0;
      $114 = (($113) + ($101<<2)|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = $115 | $100;
      HEAP32[$114>>2] = $116;
      $117 = (($113) + ($109<<2)|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = $118 | $108;
      HEAP32[$117>>2] = $119;
     }
     $120 = ($iCol1$09|0)==(0);
     $121 = ($iCol1$09|0)==($36|0);
     $or$cond = $120 | $121;
     $brmerge = $or$cond | $80;
     L30: do {
      if ($brmerge) {
       label = 23;
      } else {
       $122 = $iCol1$09 >>> 5;
       $123 = HEAP32[$81>>2]|0;
       $124 = (($123) + ($122<<2)|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = $iCol1$09 & 31;
       $127 = 1 << $126;
       $128 = $125 & $127;
       $129 = ($128|0)==(0);
       if ($129) {
        $139 = (($84) + ($83<<2)|0);
        $140 = HEAP16[$139>>1]|0;
        $141 = $140 << 16 >> 16;
        $142 = $141 << 1;
        $143 = HEAP32[$2>>2]|0;
        $144 = (($143) + -1)|0;
        $145 = ($144>>>0)>($iRow$013>>>0);
        if ($145) {
         $146 = HEAP32[$0>>2]|0;
         $147 = (($146) + ($83))|0;
         $148 = (($84) + ($147<<2)|0);
         $149 = HEAP16[$148>>1]|0;
         $150 = $149 << 16 >> 16;
         $151 = (($142) - ($150))|0;
         $152 = (($83) - ($146))|0;
         $153 = (($84) + ($152<<2)|0);
         $154 = HEAP16[$153>>1]|0;
         $155 = $154 << 16 >> 16;
         $156 = (($151) - ($155))|0;
         $convexityX$0$i = $156;$definedInX$0$off0$i = 1;
        } else {
         $convexityX$0$i = 0;$definedInX$0$off0$i = 0;
        }
        $157 = HEAP32[$0>>2]|0;
        $158 = (($157) + -1)|0;
        $159 = ($158>>>0)>($iCol1$09>>>0);
        if ($159) {
         $160 = (($83) + 1)|0;
         $161 = (($84) + ($160<<2)|0);
         $162 = HEAP16[$161>>1]|0;
         $163 = $162 << 16 >> 16;
         $164 = (($142) - ($163))|0;
         $165 = (($83) + -1)|0;
         $166 = (($84) + ($165<<2)|0);
         $167 = HEAP16[$166>>1]|0;
         $168 = $167 << 16 >> 16;
         $169 = (($164) - ($168))|0;
         $convexityZ$02$i = $169;
         label = 31;
        } else {
         if ($definedInX$0$off0$i) {
          $convexityZ$02$i = 0;
          label = 31;
         }
        }
        do {
         if ((label|0) == 31) {
          label = 0;
          $170 = $convexityZ$02$i ^ $convexityX$0$i;
          $171 = ($170|0)>(-1);
          if ($171) {
           break L30;
          }
          $172 = (($convexityZ$02$i) + ($convexityX$0$i))|0;
          $173 = (Math_fround(($172|0)));
          $174 = Math_fround(HEAPF32[$38>>2]);
          $175 = !($174 <= Math_fround(0.0));
          $176 = Math_fround(HEAPF32[$39>>2]);
          if ($175) {
           $178 = Math_fround(-$176);
           $179 = $173 < $178;
           if ($179) {
            break;
           } else {
            break L30;
           }
          } else {
           $177 = $173 > $176;
           if ($177) {
            break;
           } else {
            break L30;
           }
          }
         }
        } while(0);
        $180 = HEAP8[$89>>0]|0;
        $181 = $180&255;
        $182 = $181 | 128;
        $183 = $182&255;
        HEAP8[$89>>0] = $183;
       } else {
        label = 23;
       }
      }
     } while(0);
     do {
      if ((label|0) == 23) {
       label = 0;
       $130 = (__ZNK5physx2Gu11HeightField22isCollisionVertexPrecaEjjjt($this,$83,$iRow$013,$iCol1$09,$holeMaterialIndex)|0);
       $131 = HEAP32[$34>>2]|0;
       $132 = ((($131) + ($83<<2)|0) + 3|0);
       $133 = HEAP8[$132>>0]|0;
       $134 = $133&255;
       if ($130) {
        $135 = $134 | 128;
        $136 = $135&255;
        HEAP8[$132>>0] = $136;
        break;
       } else {
        $137 = $134 & 127;
        $138 = $137&255;
        HEAP8[$132>>0] = $138;
        break;
       }
      }
     } while(0);
     $184 = (($iCol1$09) + 1)|0;
     $exitcond = ($184|0)==($1|0);
     if ($exitcond) {
      $$pre$phiZ2D = $81;
      break;
     } else {
      $iCol1$09 = $184;
     }
    }
   }
   $185 = ((($rowHoles) + (($currentRow$012*12)|0)|0) + 4|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = HEAP32[$$pre$phiZ2D>>2]|0;
   $188 = $186 << 2;
   _memset(($187|0),0,($188|0))|0;
   $189 = $nextRow$015 ^ 1;
   $190 = $currentRow$012 ^ 1;
   $191 = (($iRow$013) + 1)|0;
   $exitcond19 = ($191|0)==($3|0);
   if ($exitcond19) {
    break;
   } else {
    $currentRow$012 = $190;$iRow$013 = $191;$nextRow$015 = $189;
   }
  }
 }
 $76 = (($rowHoles) + 12|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $192 = (($rowHoles) + 16|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = ($193|0)>(-1);
  if ($194) {
   $195 = (($rowHoles) + 20|0);
   __ZN5physx6shdfnd9Allocator10deallocateEPv($195,$77);
  }
 }
 $196 = HEAP32[$rowHoles>>2]|0;
 $197 = ($196|0)==(0|0);
 if ($197) {
  STACKTOP = sp;return;
 }
 $198 = (($rowHoles) + 4|0);
 $199 = HEAP32[$198>>2]|0;
 $200 = ($199|0)>(-1);
 if (!($200)) {
  STACKTOP = sp;return;
 }
 $201 = (($rowHoles) + 8|0);
 __ZN5physx6shdfnd9Allocator10deallocateEPv($201,$196);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu11HeightField9saveCellsEPvj($this,$destBuffer,$destBufferSize) {
 $this = $this|0;
 $destBuffer = $destBuffer|0;
 $destBufferSize = $destBufferSize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $destBufferSize$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1 << 2;
 $5 = Math_imul($4, $3)|0;
 $6 = ($5>>>0)>($destBufferSize>>>0);
 $destBufferSize$ = $6 ? $destBufferSize : $5;
 $7 = (($this) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 _memcpy(($destBuffer|0),($8|0),($destBufferSize$|0))|0;
 STACKTOP = sp;return ($destBufferSize$|0);
}
function __ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($heightfield,$vertexIndex,$row,$column,$edgeIndices) {
 $heightfield = $heightfield|0;
 $vertexIndex = $vertexIndex|0;
 $row = $row|0;
 $column = $column|0;
 $edgeIndices = $edgeIndices|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $count$0 = 0, $count$1 = 0, $count$2 = 0, $count$3 = 0, $count$4 = 0, $count$5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($heightfield) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($heightfield) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($row|0)!=(0);
 if ($4) {
  $5 = (($vertexIndex) - ($1))|0;
  $6 = ($5*3)|0;
  $7 = (($6) + 2)|0;
  HEAP32[$edgeIndices>>2] = $7;
  $8 = (($edgeIndices) + 4|0);
  HEAP32[$8>>2] = $5;
  $9 = (($row) + -1)|0;
  $10 = (($edgeIndices) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = (($edgeIndices) + 12|0);
  HEAP32[$11>>2] = $column;
  $count$0 = 1;
 } else {
  $count$0 = 0;
 }
 $12 = (($1) + -1)|0;
 $13 = ($12>>>0)>($column>>>0);
 if ($13) {
  if ($4) {
   $14 = (($vertexIndex) - ($1))|0;
   $15 = (($heightfield) + 36|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($16) + ($14<<2)|0) + 2|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)<(0);
   if ($19) {
    $count$1 = $count$0;
   } else {
    $20 = ($14*3)|0;
    $21 = (($20) + 1)|0;
    $22 = (($edgeIndices) + ($count$0<<4)|0);
    HEAP32[$22>>2] = $21;
    $23 = ((($edgeIndices) + ($count$0<<4)|0) + 4|0);
    HEAP32[$23>>2] = $14;
    $24 = (($row) + -1)|0;
    $25 = ((($edgeIndices) + ($count$0<<4)|0) + 8|0);
    HEAP32[$25>>2] = $24;
    $26 = ((($edgeIndices) + ($count$0<<4)|0) + 12|0);
    HEAP32[$26>>2] = $column;
    $27 = (($count$0) + 1)|0;
    $count$1 = $27;
   }
  } else {
   $count$1 = $count$0;
  }
  $28 = ($vertexIndex*3)|0;
  $29 = (($edgeIndices) + ($count$1<<4)|0);
  HEAP32[$29>>2] = $28;
  $30 = ((($edgeIndices) + ($count$1<<4)|0) + 4|0);
  HEAP32[$30>>2] = $vertexIndex;
  $31 = ((($edgeIndices) + ($count$1<<4)|0) + 8|0);
  HEAP32[$31>>2] = $row;
  $32 = ((($edgeIndices) + ($count$1<<4)|0) + 12|0);
  HEAP32[$32>>2] = $column;
  $33 = (($count$1) + 1)|0;
  $34 = (($3) + -1)|0;
  $35 = ($34>>>0)>($row>>>0);
  if ($35) {
   $36 = (($heightfield) + 36|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($37) + ($vertexIndex<<2)|0) + 2|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = ($39<<24>>24)<(0);
   if ($40) {
    $41 = (($28) + 1)|0;
    $42 = (($edgeIndices) + ($33<<4)|0);
    HEAP32[$42>>2] = $41;
    $43 = ((($edgeIndices) + ($33<<4)|0) + 4|0);
    HEAP32[$43>>2] = $vertexIndex;
    $44 = ((($edgeIndices) + ($33<<4)|0) + 8|0);
    HEAP32[$44>>2] = $row;
    $45 = ((($edgeIndices) + ($33<<4)|0) + 12|0);
    HEAP32[$45>>2] = $column;
    $46 = (($count$1) + 2)|0;
    $$pre$phiZ2D = $34;$count$2 = $46;
   } else {
    $$pre$phiZ2D = $34;$count$2 = $33;
   }
  } else {
   $$pre$phiZ2D = $34;$count$2 = $33;
  }
 } else {
  $$pre = (($3) + -1)|0;
  $$pre$phiZ2D = $$pre;$count$2 = $count$0;
 }
 $47 = ($$pre$phiZ2D>>>0)>($row>>>0);
 if ($47) {
  $48 = ($vertexIndex*3)|0;
  $49 = (($48) + 2)|0;
  $50 = (($edgeIndices) + ($count$2<<4)|0);
  HEAP32[$50>>2] = $49;
  $51 = ((($edgeIndices) + ($count$2<<4)|0) + 4|0);
  HEAP32[$51>>2] = $vertexIndex;
  $52 = ((($edgeIndices) + ($count$2<<4)|0) + 8|0);
  HEAP32[$52>>2] = $row;
  $53 = ((($edgeIndices) + ($count$2<<4)|0) + 12|0);
  HEAP32[$53>>2] = $column;
  $54 = (($count$2) + 1)|0;
  $count$3 = $54;
 } else {
  $count$3 = $count$2;
 }
 $55 = ($column|0)==(0);
 if ($55) {
  $count$5 = $count$3;
  STACKTOP = sp;return ($count$5|0);
 }
 $56 = (($vertexIndex) + -1)|0;
 if ($47) {
  $57 = (($heightfield) + 36|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58) + ($56<<2)|0) + 2|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = ($60<<24>>24)<(0);
  if ($61) {
   $count$4 = $count$3;
  } else {
   $62 = ($56*3)|0;
   $63 = (($62) + 1)|0;
   $64 = (($edgeIndices) + ($count$3<<4)|0);
   HEAP32[$64>>2] = $63;
   $65 = ((($edgeIndices) + ($count$3<<4)|0) + 4|0);
   HEAP32[$65>>2] = $56;
   $66 = ((($edgeIndices) + ($count$3<<4)|0) + 8|0);
   HEAP32[$66>>2] = $row;
   $67 = (($column) + -1)|0;
   $68 = ((($edgeIndices) + ($count$3<<4)|0) + 12|0);
   HEAP32[$68>>2] = $67;
   $69 = (($count$3) + 1)|0;
   $count$4 = $69;
  }
 } else {
  $count$4 = $count$3;
 }
 $70 = ($56*3)|0;
 $71 = (($edgeIndices) + ($count$4<<4)|0);
 HEAP32[$71>>2] = $70;
 $72 = ((($edgeIndices) + ($count$4<<4)|0) + 4|0);
 HEAP32[$72>>2] = $56;
 $73 = ((($edgeIndices) + ($count$4<<4)|0) + 8|0);
 HEAP32[$73>>2] = $row;
 $74 = (($column) + -1)|0;
 $75 = ((($edgeIndices) + ($count$4<<4)|0) + 12|0);
 HEAP32[$75>>2] = $74;
 $76 = (($count$4) + 1)|0;
 if (!($4)) {
  $count$5 = $76;
  STACKTOP = sp;return ($count$5|0);
 }
 $77 = (($vertexIndex) - ($1))|0;
 $78 = (($77) + -1)|0;
 $79 = (($heightfield) + 36|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80) + ($78<<2)|0) + 2|0);
 $82 = HEAP8[$81>>0]|0;
 $83 = ($82<<24>>24)<(0);
 if (!($83)) {
  $count$5 = $76;
  STACKTOP = sp;return ($count$5|0);
 }
 $84 = ($78*3)|0;
 $85 = (($84) + 1)|0;
 $86 = (($edgeIndices) + ($76<<4)|0);
 HEAP32[$86>>2] = $85;
 $87 = ((($edgeIndices) + ($76<<4)|0) + 4|0);
 HEAP32[$87>>2] = $78;
 $88 = (($row) + -1)|0;
 $89 = ((($edgeIndices) + ($76<<4)|0) + 8|0);
 HEAP32[$89>>2] = $88;
 $90 = ((($edgeIndices) + ($76<<4)|0) + 12|0);
 HEAP32[$90>>2] = $74;
 $91 = (($count$4) + 2)|0;
 $count$5 = $91;
 STACKTOP = sp;return ($count$5|0);
}
function __ZN5physx22getEdgeTriangleIndicesERKNS_2Gu11HeightFieldERKNS_8EdgeDataEPj($heightfield,$edgeData,$triangleIndices) {
 $heightfield = $heightfield|0;
 $edgeData = $edgeData|0;
 $triangleIndices = $triangleIndices|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0 = 0, $count$1 = 0, $count$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($heightfield) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($heightfield) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$edgeData>>2]|0;
 $5 = (($edgeData) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($edgeData) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($edgeData) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($6, -3)|0;
 $12 = (($11) + ($4))|0;
 do {
  if ((($12|0) == 1)) {
   $37 = (($3) + -1)|0;
   $38 = ($8>>>0)<($37>>>0);
   if ($38) {
    $39 = (($1) + -1)|0;
    $40 = ($10>>>0)<($39>>>0);
    if ($40) {
     $41 = $6 << 1;
     HEAP32[$triangleIndices>>2] = $41;
     $42 = $41 | 1;
     $43 = (($triangleIndices) + 4|0);
     HEAP32[$43>>2] = $42;
     $count$2 = 2;
    } else {
     $count$2 = 0;
    }
   } else {
    $count$2 = 0;
   }
  } else if ((($12|0) == 2)) {
   $44 = (($3) + -1)|0;
   $45 = ($8>>>0)<($44>>>0);
   if ($45) {
    $46 = ($10|0)==(0);
    if ($46) {
     $count$1 = 0;
    } else {
     $47 = $6 << 1;
     $48 = (($47) + -1)|0;
     HEAP32[$triangleIndices>>2] = $48;
     $count$1 = 1;
    }
    $49 = (($1) + -1)|0;
    $50 = ($10>>>0)<($49>>>0);
    if ($50) {
     $51 = $6 << 1;
     $52 = (($count$1) + 1)|0;
     $53 = (($triangleIndices) + ($count$1<<2)|0);
     HEAP32[$53>>2] = $51;
     $count$2 = $52;
    } else {
     $count$2 = $count$1;
    }
   } else {
    $count$2 = 0;
   }
  } else if ((($12|0) == 0)) {
   $13 = (($1) + -1)|0;
   $14 = ($10>>>0)<($13>>>0);
   if ($14) {
    $15 = ($8|0)==(0);
    do {
     if ($15) {
      $count$0 = 0;
     } else {
      $16 = (($6) - ($1))|0;
      $17 = (($heightfield) + 36|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ((($18) + ($16<<2)|0) + 2|0);
      $20 = HEAP8[$19>>0]|0;
      $21 = ($20<<24>>24)<(0);
      $22 = $16 << 1;
      if ($21) {
       HEAP32[$triangleIndices>>2] = $22;
       $count$0 = 1;
       break;
      } else {
       $23 = $22 | 1;
       HEAP32[$triangleIndices>>2] = $23;
       $count$0 = 1;
       break;
      }
     }
    } while(0);
    $24 = (($3) + -1)|0;
    $25 = ($8>>>0)<($24>>>0);
    if ($25) {
     $26 = (($heightfield) + 36|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($27) + ($6<<2)|0) + 2|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = ($29<<24>>24)<(0);
     $31 = $6 << 1;
     if ($30) {
      $32 = $31 | 1;
      $33 = (($count$0) + 1)|0;
      $34 = (($triangleIndices) + ($count$0<<2)|0);
      HEAP32[$34>>2] = $32;
      $count$2 = $33;
      break;
     } else {
      $35 = (($count$0) + 1)|0;
      $36 = (($triangleIndices) + ($count$0<<2)|0);
      HEAP32[$36>>2] = $31;
      $count$2 = $35;
      break;
     }
    } else {
     $count$2 = $count$0;
    }
   } else {
    $count$2 = 0;
   }
  } else {
   $count$2 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($count$2|0);
}
function __ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($this,$x,$z,$fracX,$fracZ) {
 $this = $this|0;
 $x = Math_fround($x);
 $z = Math_fround($z);
 $fracX = $fracX|0;
 $fracZ = $fracZ|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x > Math_fround(0.0);
 $1 = $0 ? $x : Math_fround(0.0);
 $2 = $z > Math_fround(0.0);
 $3 = $2 ? $z : Math_fround(0.0);
 $4 = Math_fround($1 + Math_fround(1.0));
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($4)))));
 $5 = Math_fround($fabsf$i$i * Math_fround(9.99999997475242707878E-7));
 $6 = Math_fround(Math_fround(1.0) - $5);
 $7 = Math_fround($3 + Math_fround(1.0));
 $fabsf$i$i1 = (Math_fround(Math_abs((Math_fround($7)))));
 $8 = Math_fround($fabsf$i$i1 * Math_fround(9.99999997475242707878E-7));
 $9 = Math_fround(Math_fround(1.0) - $8);
 $10 = (($this) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 + $6);
 $13 = $1 < $12;
 $14 = $13 ? $1 : $12;
 $15 = (($this) + 28|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + $9);
 $18 = $3 < $17;
 $19 = $18 ? $3 : $17;
 $20 = (Math_fround(Math_floor((Math_fround($14)))));
 $21 = Math_fround($14 - $20);
 HEAPF32[$fracX>>2] = $21;
 $22 = (Math_fround(Math_floor((Math_fround($19)))));
 $23 = Math_fround($19 - $22);
 HEAPF32[$fracZ>>2] = $23;
 $24 = (($this) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($20 * $25);
 $27 = Math_fround($22 + $26);
 $28 = (~~(($27))>>>0);
 STACKTOP = sp;return ($28|0);
}
function __ZNK5physx2Gu11HeightField14computeExtremeEjjjj($this,$minRow,$maxRow,$minColumn,$maxColumn) {
 $this = $this|0;
 $minRow = $minRow|0;
 $maxRow = $maxRow|0;
 $minColumn = $minColumn|0;
 $maxColumn = $maxColumn|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $column$01 = 0, $column2$08 = 0, $hfExtreme$05 = 0, $hfExtreme$12 = 0, $hfExtreme$216 = 0, $hfExtreme$39 = 0, $hfExtreme$4 = 0, $row$04 = 0, $row$04$us = 0, $row1$015 = 0, $row1$015$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 <= Math_fround(0.0);
 $3 = $2 ? -2147483648 : 2147483647;
 $4 = ($minRow>>>0)>($maxRow>>>0);
 L1: do {
  if ($2) {
   if ($4) {
    $hfExtreme$4 = $3;
   } else {
    $10 = ($minColumn>>>0)>($maxColumn>>>0);
    $11 = (($this) + 20|0);
    $12 = (($this) + 36|0);
    if ($10) {
     $row$04$us = $minRow;
     while(1) {
      $13 = (($row$04$us) + 1)|0;
      $14 = ($13>>>0)>($maxRow>>>0);
      if ($14) {
       $hfExtreme$4 = $3;
       break L1;
      } else {
       $row$04$us = $13;
      }
     }
    } else {
     $hfExtreme$05 = $3;$row$04 = $minRow;
    }
    while(1) {
     $15 = HEAP32[$11>>2]|0;
     $16 = Math_imul($15, $row$04)|0;
     $17 = HEAP32[$12>>2]|0;
     $column$01 = $minColumn;$hfExtreme$12 = $hfExtreme$05;
     while(1) {
      $18 = (($16) + ($column$01))|0;
      $19 = (($17) + ($18<<2)|0);
      $20 = HEAP16[$19>>1]|0;
      $21 = $20 << 16 >> 16;
      $22 = ($hfExtreme$12|0)<($21|0);
      $23 = $22 ? $21 : $hfExtreme$12;
      $24 = (($column$01) + 1)|0;
      $25 = ($24>>>0)>($maxColumn>>>0);
      if ($25) {
       break;
      } else {
       $column$01 = $24;$hfExtreme$12 = $23;
      }
     }
     $26 = (($row$04) + 1)|0;
     $27 = ($26>>>0)>($maxRow>>>0);
     if ($27) {
      $hfExtreme$4 = $23;
      break;
     } else {
      $hfExtreme$05 = $23;$row$04 = $26;
     }
    }
   }
  } else {
   if ($4) {
    $hfExtreme$4 = $3;
   } else {
    $5 = ($minColumn>>>0)>($maxColumn>>>0);
    $6 = (($this) + 20|0);
    $7 = (($this) + 36|0);
    if ($5) {
     $row1$015$us = $minRow;
     while(1) {
      $8 = (($row1$015$us) + 1)|0;
      $9 = ($8>>>0)>($maxRow>>>0);
      if ($9) {
       $hfExtreme$4 = $3;
       break L1;
      } else {
       $row1$015$us = $8;
      }
     }
    } else {
     $hfExtreme$216 = $3;$row1$015 = $minRow;
    }
    while(1) {
     $28 = HEAP32[$6>>2]|0;
     $29 = Math_imul($28, $row1$015)|0;
     $30 = HEAP32[$7>>2]|0;
     $column2$08 = $minColumn;$hfExtreme$39 = $hfExtreme$216;
     while(1) {
      $31 = (($29) + ($column2$08))|0;
      $32 = (($30) + ($31<<2)|0);
      $33 = HEAP16[$32>>1]|0;
      $34 = $33 << 16 >> 16;
      $35 = ($hfExtreme$39|0)<($34|0);
      $36 = $35 ? $hfExtreme$39 : $34;
      $37 = (($column2$08) + 1)|0;
      $38 = ($37>>>0)>($maxColumn>>>0);
      if ($38) {
       break;
      } else {
       $column2$08 = $37;$hfExtreme$39 = $36;
      }
     }
     $39 = (($row1$015) + 1)|0;
     $40 = ($39>>>0)>($maxRow>>>0);
     if ($40) {
      $hfExtreme$4 = $36;
      break;
     } else {
      $hfExtreme$216 = $36;$row1$015 = $39;
     }
    }
   }
  }
 } while(0);
 $41 = (Math_fround(($hfExtreme$4|0)));
 STACKTOP = sp;return (Math_fround($41));
}
function __ZNK5physx13PxHeightField19getConcreteTypeNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (553728|0);
}
function __ZNK5physx13PxHeightField8isKindOfEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp(553728,$name)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = 1;
 } else {
  $2 = (_strcmp($name,553744)|0);
  $3 = ($2|0)==(0);
  $4 = $3;
 }
 STACKTOP = sp;return ($4|0);
}
function __ZNK5physx2Gu11HeightField9getNbRowsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu11HeightField12getNbColumnsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu11HeightField9getFormatEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5physx2Gu11HeightField15getSampleStrideEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 4;
}
function __ZNK5physx2Gu11HeightField12getThicknessEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx2Gu11HeightField22getConvexEdgeThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK5physx2Gu11HeightField8getFlagsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP16[$0>>1]|0;
 HEAP16[$agg$result>>1] = $1;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu11HeightField9getHeightEff($this,$x,$z) {
 $this = $this|0;
 $x = Math_fround($x);
 $z = Math_fround($z);
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x > Math_fround(0.0);
 $1 = $0 ? $x : Math_fround(0.0);
 $2 = $z > Math_fround(0.0);
 $3 = $2 ? $z : Math_fround(0.0);
 $4 = Math_fround($1 + Math_fround(1.0));
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($4)))));
 $5 = Math_fround($fabsf$i$i$i$i * Math_fround(9.99999997475242707878E-7));
 $6 = Math_fround(Math_fround(1.0) - $5);
 $7 = Math_fround($3 + Math_fround(1.0));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($7)))));
 $8 = Math_fround($fabsf$i$i1$i$i * Math_fround(9.99999997475242707878E-7));
 $9 = Math_fround(Math_fround(1.0) - $8);
 $10 = (($this) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 + $6);
 $13 = $1 < $12;
 $14 = $13 ? $1 : $12;
 $15 = (($this) + 28|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + $9);
 $18 = $3 < $17;
 $19 = $18 ? $3 : $17;
 $20 = (Math_fround(Math_floor((Math_fround($14)))));
 $21 = Math_fround($14 - $20);
 $22 = (Math_fround(Math_floor((Math_fround($19)))));
 $23 = Math_fround($19 - $22);
 $24 = (($this) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($20 * $25);
 $27 = Math_fround($22 + $26);
 $28 = (~~(($27))>>>0);
 $29 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($this,$28,$21,$23)));
 STACKTOP = sp;return (Math_fround($29));
}
function __ZNK5physx2Gu11HeightField24getTriangleMaterialIndexEj($this,$triangleIndex) {
 $this = $this|0;
 $triangleIndex = $triangleIndex|0;
 var $$sink$i = 0, $$sink$in$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $triangleIndex & 1;
 $1 = ($0|0)==(0);
 $2 = $triangleIndex >>> 1;
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 if ($1) {
  $5 = ((($4) + ($2<<2)|0) + 2|0);
  $$sink$in$i = $5;
 } else {
  $6 = ((($4) + ($2<<2)|0) + 3|0);
  $$sink$in$i = $6;
 }
 $$sink$i = HEAP8[$$sink$in$i>>0]|0;
 $7 = $$sink$i&255;
 $8 = $7 & 127;
 $9 = $8&65535;
 STACKTOP = sp;return ($9|0);
}
function __ZNK5physx2Gu11HeightField17getTriangleNormalEj($agg$result,$this,$triangleIndex) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $triangleIndex = $triangleIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK5physx2Gu11HeightField25getTriangleNormalInternalEj($agg$result,$this,$triangleIndex);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu11HeightField8requiresERNS_23PxProcessPxBaseCallbackE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx13PxHeightFieldD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx13PxHeightFieldD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu15HeightFieldUtil18computeLocalBoundsERNS_9PxBounds3E($this,$bounds) {
 $this = $this|0;
 $bounds = $bounds|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($3 * Math_fround(0.0));
 $9 = Math_fround($5 * Math_fround(0.0));
 $10 = Math_fround($7 * Math_fround(0.0));
 $11 = Math_fround($9 * Math_fround(0.0));
 $12 = Math_fround($3 + $11);
 $13 = Math_fround($8 + $9);
 $14 = Math_fround($8 + $11);
 $15 = Math_fround($10 * Math_fround(0.0));
 $16 = Math_fround($12 + $15);
 $17 = Math_fround($13 + $15);
 $18 = Math_fround($10 + $14);
 $19 = Math_fround($8 * Math_fround(0.0));
 $20 = Math_fround($5 + $19);
 $21 = Math_fround($19 + $9);
 $22 = Math_fround($20 + $15);
 $23 = Math_fround($21 + $10);
 $24 = Math_fround($19 + $11);
 $25 = Math_fround($7 + $24);
 $26 = (($this) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 56|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $16);
 $31 = Math_fround($29 * $17);
 $32 = Math_fround($29 * $18);
 $33 = (($27) + 60|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $17);
 $36 = Math_fround($34 * $22);
 $37 = Math_fround($23 * $34);
 $38 = Math_fround($30 + $35);
 $39 = Math_fround($31 + $36);
 $40 = Math_fround($32 + $37);
 $41 = (($27) + 64|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($18 * $42);
 $44 = Math_fround($23 * $42);
 $45 = Math_fround($25 * $42);
 $46 = Math_fround($38 + $43);
 $47 = Math_fround($39 + $44);
 $48 = Math_fround($40 + $45);
 HEAPF32[$bounds>>2] = $46;
 $49 = (($bounds) + 4|0);
 HEAPF32[$49>>2] = $47;
 $50 = (($bounds) + 8|0);
 HEAPF32[$50>>2] = $48;
 $51 = (($27) + 68|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($16 * $52);
 $54 = Math_fround($17 * $52);
 $55 = Math_fround($18 * $52);
 $56 = (($27) + 72|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($17 * $57);
 $59 = Math_fround($22 * $57);
 $60 = Math_fround($23 * $57);
 $61 = Math_fround($53 + $58);
 $62 = Math_fround($54 + $59);
 $63 = Math_fround($55 + $60);
 $64 = (($27) + 76|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($18 * $65);
 $67 = Math_fround($23 * $65);
 $68 = Math_fround($25 * $65);
 $69 = Math_fround($61 + $66);
 $70 = Math_fround($62 + $67);
 $71 = Math_fround($63 + $68);
 $72 = (($bounds) + 12|0);
 HEAPF32[$72>>2] = $69;
 $73 = (($bounds) + 16|0);
 HEAPF32[$73>>2] = $70;
 $74 = (($bounds) + 20|0);
 HEAPF32[$74>>2] = $71;
 $75 = (($27) + 40|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = $76 < Math_fround(0.0);
 if ($77) {
  $78 = Math_fround($76 + $47);
  HEAPF32[$49>>2] = $78;
  STACKTOP = sp;return;
 } else {
  $79 = Math_fround($76 + $70);
  HEAPF32[$73>>2] = $79;
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu15HeightFieldUtil24getFaceIndexAtShapePointEff($this,$x,$z) {
 $this = $this|0;
 $x = Math_fround($x);
 $z = Math_fround($z);
 var $$0 = 0, $$0$i$i = 0, $$sink$i = 0, $$sink$in$i = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fracX$i = 0, $fracZ$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fracX$i = sp + 4|0;
 $fracZ$i = sp;
 $0 = Math_fround(HEAPF32[$this>>2]);
 $1 = Math_fround($0 * $x);
 $2 = (($this) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $z);
 $5 = !($1 >= Math_fround(0.0));
 $6 = !($4 >= Math_fround(0.0));
 $or$cond$i = $5 | $6;
 if ($or$cond$i) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 24|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 + Math_fround(1.0));
 $12 = $1 < $11;
 if (!($12)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($8) + 28|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 + Math_fround(1.0));
 $16 = $4 < $15;
 if (!($16)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($8,$1,$4,$fracX$i,$fracZ$i)|0);
 $18 = Math_fround(HEAPF32[$fracX$i>>2]);
 $19 = Math_fround(HEAPF32[$fracZ$i>>2]);
 $20 = (($8) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($21) + ($17<<2)|0) + 2|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)<(0);
 if ($24) {
  $25 = $19 > $18;
  $26 = $17 << 1;
  $27 = $25&1;
  $28 = $27 | $26;
  $$0$i$i = $28;
 } else {
  $29 = Math_fround($18 + $19);
  $30 = $29 > Math_fround(1.0);
  $31 = $17 << 1;
  $32 = $30&1;
  $33 = $32 | $31;
  $$0$i$i = $33;
 }
 $34 = HEAP32[$7>>2]|0;
 $35 = $$0$i$i & 1;
 $36 = ($35|0)==(0);
 $37 = $$0$i$i >>> 1;
 $38 = (($34) + 36|0);
 $39 = HEAP32[$38>>2]|0;
 if ($36) {
  $40 = ((($39) + ($37<<2)|0) + 2|0);
  $$sink$in$i = $40;
 } else {
  $41 = ((($39) + ($37<<2)|0) + 3|0);
  $$sink$in$i = $41;
 }
 $$sink$i = HEAP8[$$sink$in$i>>0]|0;
 $42 = $$sink$i & 127;
 $43 = ($42<<24>>24)!=(127);
 $44 = $43 ? $$0$i$i : -1;
 $$0 = $44;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Gu15HeightFieldUtil31getFaceIndexAtShapePointNoTest2Ejff($this,$cell,$fracX,$fracZ) {
 $this = $this|0;
 $cell = $cell|0;
 $fracX = Math_fround($fracX);
 $fracZ = Math_fround($fracZ);
 var $$0$i = 0, $$sink$i = 0, $$sink$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + ($cell<<2)|0) + 2|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)<(0);
 if ($6) {
  $7 = $fracZ > $fracX;
  $8 = $cell << 1;
  $9 = $7&1;
  $10 = $9 | $8;
  $$0$i = $10;
 } else {
  $11 = Math_fround($fracX + $fracZ);
  $12 = $11 > Math_fround(1.0);
  $13 = $cell << 1;
  $14 = $12&1;
  $15 = $14 | $13;
  $$0$i = $15;
 }
 $16 = $$0$i & 1;
 $17 = ($16|0)==(0);
 $18 = $$0$i >>> 1;
 if ($17) {
  $19 = ((($3) + ($18<<2)|0) + 2|0);
  $$sink$in$i = $19;
 } else {
  $20 = ((($3) + ($18<<2)|0) + 3|0);
  $$sink$in$i = $20;
 }
 $$sink$i = HEAP8[$$sink$in$i>>0]|0;
 $21 = $$sink$i & 127;
 $22 = ($21<<24>>24)!=(127);
 $23 = $22 ? $$0$i : -1;
 STACKTOP = sp;return ($23|0);
}
function __ZNK5physx2Gu15HeightFieldUtil15getVertexNormalEjjj($agg$result,$this,$vertexIndex,$row,$column) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $vertexIndex = $vertexIndex|0;
 $row = $row|0;
 $column = $column|0;
 var $$lcssa = Math_fround(0), $$lcssa15 = Math_fround(0), $$lcssa16 = Math_fround(0), $$sink$i = 0, $$sink$i3 = 0, $$sink$in$i = 0, $$sink$in$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $edgeIndices = 0, $exitcond = 0, $faces = 0, $i$017 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $edgeIndices = sp + 32|0;
 $faces = sp;
 $0 = sp + 8|0;
 $1 = sp + 20|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($3,$vertexIndex,$row,$column,$edgeIndices)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $$lcssa = Math_fround(0.0);$$lcssa15 = Math_fround(0.0);$$lcssa16 = Math_fround(0.0);
 } else {
  $6 = (($faces) + 4|0);
  $7 = (($0) + 4|0);
  $8 = (($this) + 4|0);
  $9 = (($0) + 8|0);
  $10 = (($this) + 8|0);
  $11 = (($1) + 4|0);
  $12 = (($1) + 8|0);
  $49 = Math_fround(0.0);$52 = Math_fround(0.0);$55 = Math_fround(0.0);$i$017 = 0;
  while(1) {
   $13 = HEAP32[$2>>2]|0;
   $14 = (($edgeIndices) + ($i$017<<4)|0);
   $15 = (__ZN5physx22getEdgeTriangleIndicesERKNS_2Gu11HeightFieldERKNS_8EdgeDataEPj($13,$14,$faces)|0);
   if ((($15|0) == 2)) {
    $16 = HEAP32[$2>>2]|0;
    $17 = HEAP32[$6>>2]|0;
    $18 = $17 & 1;
    $19 = ($18|0)==(0);
    $20 = $17 >>> 1;
    $21 = (($16) + 36|0);
    $22 = HEAP32[$21>>2]|0;
    if ($19) {
     $23 = ((($22) + ($20<<2)|0) + 2|0);
     $$sink$in$i = $23;
    } else {
     $24 = ((($22) + ($20<<2)|0) + 3|0);
     $$sink$in$i = $24;
    }
    $$sink$i = HEAP8[$$sink$in$i>>0]|0;
    $25 = $$sink$i & 127;
    $26 = ($25<<24>>24)==(127);
    if ($26) {
     $89 = $49;$92 = $52;$95 = $55;
     label = 11;
    } else {
     __ZNK5physx2Gu11HeightField25getTriangleNormalInternalEj($0,$16,$17);
     $27 = Math_fround(HEAPF32[$0>>2]);
     $28 = Math_fround(HEAPF32[$this>>2]);
     $29 = Math_fround($27 * $28);
     $30 = Math_fround(HEAPF32[$7>>2]);
     $31 = Math_fround(HEAPF32[$8>>2]);
     $32 = Math_fround($30 * $31);
     $33 = Math_fround(HEAPF32[$9>>2]);
     $34 = Math_fround(HEAPF32[$10>>2]);
     $35 = Math_fround($33 * $34);
     $36 = Math_fround($29 * $29);
     $37 = Math_fround($32 * $32);
     $38 = Math_fround($36 + $37);
     $39 = Math_fround($35 * $35);
     $40 = Math_fround($38 + $39);
     $41 = $40 > Math_fround(0.0);
     if ($41) {
      $42 = (Math_fround(Math_sqrt((Math_fround($40)))));
      $43 = Math_fround(Math_fround(1.0) / $42);
      $44 = Math_fround($29 * $43);
      $45 = Math_fround($32 * $43);
      $46 = Math_fround($35 * $43);
      $48 = $44;$51 = $45;$54 = $46;
     } else {
      $48 = Math_fround(0.0);$51 = Math_fround(0.0);$54 = Math_fround(0.0);
     }
     $47 = Math_fround($49 + $48);
     $50 = Math_fround($52 + $51);
     $53 = Math_fround($55 + $54);
     $89 = $47;$92 = $50;$95 = $53;
     label = 11;
    }
   } else if ((($15|0) == 1)) {
    $89 = $49;$92 = $52;$95 = $55;
    label = 11;
   } else {
    $112 = $55;$113 = $52;$114 = $49;
   }
   if ((label|0) == 11) {
    label = 0;
    $56 = HEAP32[$2>>2]|0;
    $57 = HEAP32[$faces>>2]|0;
    $58 = $57 & 1;
    $59 = ($58|0)==(0);
    $60 = $57 >>> 1;
    $61 = (($56) + 36|0);
    $62 = HEAP32[$61>>2]|0;
    if ($59) {
     $63 = ((($62) + ($60<<2)|0) + 2|0);
     $$sink$in$i2 = $63;
    } else {
     $64 = ((($62) + ($60<<2)|0) + 3|0);
     $$sink$in$i2 = $64;
    }
    $$sink$i3 = HEAP8[$$sink$in$i2>>0]|0;
    $65 = $$sink$i3 & 127;
    $66 = ($65<<24>>24)==(127);
    if ($66) {
     $112 = $95;$113 = $92;$114 = $89;
    } else {
     __ZNK5physx2Gu11HeightField25getTriangleNormalInternalEj($1,$56,$57);
     $67 = Math_fround(HEAPF32[$1>>2]);
     $68 = Math_fround(HEAPF32[$this>>2]);
     $69 = Math_fround($67 * $68);
     $70 = Math_fround(HEAPF32[$11>>2]);
     $71 = Math_fround(HEAPF32[$8>>2]);
     $72 = Math_fround($70 * $71);
     $73 = Math_fround(HEAPF32[$12>>2]);
     $74 = Math_fround(HEAPF32[$10>>2]);
     $75 = Math_fround($73 * $74);
     $76 = Math_fround($69 * $69);
     $77 = Math_fround($72 * $72);
     $78 = Math_fround($76 + $77);
     $79 = Math_fround($75 * $75);
     $80 = Math_fround($78 + $79);
     $81 = $80 > Math_fround(0.0);
     if ($81) {
      $82 = (Math_fround(Math_sqrt((Math_fround($80)))));
      $83 = Math_fround(Math_fround(1.0) / $82);
      $84 = Math_fround($69 * $83);
      $85 = Math_fround($72 * $83);
      $86 = Math_fround($75 * $83);
      $88 = $84;$91 = $85;$94 = $86;
     } else {
      $88 = Math_fround(0.0);$91 = Math_fround(0.0);$94 = Math_fround(0.0);
     }
     $87 = Math_fround($89 + $88);
     $90 = Math_fround($92 + $91);
     $93 = Math_fround($95 + $94);
     $112 = $93;$113 = $90;$114 = $87;
    }
   }
   $96 = (($i$017) + 1)|0;
   $exitcond = ($96|0)==($4|0);
   if ($exitcond) {
    $$lcssa = $112;$$lcssa15 = $113;$$lcssa16 = $114;
    break;
   } else {
    $49 = $114;$52 = $113;$55 = $112;$i$017 = $96;
   }
  }
 }
 $97 = Math_fround($$lcssa16 * $$lcssa16);
 $98 = Math_fround($$lcssa15 * $$lcssa15);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($$lcssa * $$lcssa);
 $101 = Math_fround($100 + $99);
 $102 = $101 > Math_fround(0.0);
 if ($102) {
  $103 = (Math_fround(Math_sqrt((Math_fround($101)))));
  $104 = Math_fround(Math_fround(1.0) / $103);
  $105 = Math_fround($$lcssa16 * $104);
  $106 = Math_fround($$lcssa15 * $104);
  $107 = Math_fround($$lcssa * $104);
  HEAPF32[$agg$result>>2] = $105;
  $108 = (($agg$result) + 4|0);
  HEAPF32[$108>>2] = $106;
  $109 = (($agg$result) + 8|0);
  HEAPF32[$109>>2] = $107;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $110 = (($agg$result) + 4|0);
  HEAPF32[$110>>2] = Math_fround(0.0);
  $111 = (($agg$result) + 8|0);
  HEAPF32[$111>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu15HeightFieldUtil23findClosestPointsOnCellEjjNS_6PxVec3EPS2_Pjbbb($this,$row,$column,$point,$closestPoints,$featureCodes,$testFaces,$testEdges,$skipEdgesIfFaceHits) {
 $this = $this|0;
 $row = $row|0;
 $column = $column|0;
 $point = $point|0;
 $closestPoints = $closestPoints|0;
 $featureCodes = $featureCodes|0;
 $testFaces = $testFaces|0;
 $testEdges = $testEdges|0;
 $skipEdgesIfFaceHits = $skipEdgesIfFaceHits|0;
 var $$$i = 0, $$$i100 = 0, $$$i52 = 0, $$$i63 = 0, $$$i79 = 0, $$0 = 0, $$1$i = 0, $$1$i102 = 0, $$1$i54 = 0, $$1$i65 = 0, $$1$i81 = 0, $$off013 = 0, $$sink$i = 0, $$sink$i$i = 0, $$sink$i$i48 = 0, $$sink$i$i59 = 0, $$sink$i$i75 = 0, $$sink$i$i96 = 0, $$sink$i3$i = 0, $$sink$i3$i51 = 0;
 var $$sink$i3$i62 = 0, $$sink$i3$i78 = 0, $$sink$i3$i99 = 0, $$sink$i45 = 0, $$sink$in$i$i = 0, $$sink$in$i$i47 = 0, $$sink$in$i$i58 = 0, $$sink$in$i$i74 = 0, $$sink$in$i$i95 = 0, $$sink$in$i2$i = 0, $$sink$in$i2$i50 = 0, $$sink$in$i2$i61 = 0, $$sink$in$i2$i77 = 0, $$sink$in$i2$i98 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0;
 var $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0;
 var $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = 0, $422 = 0, $423 = Math_fround(0), $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0);
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge42 = 0, $closestPoint = 0, $closestPoint1 = 0, $closestPoint2 = 0, $closestPoint3 = 0, $closestPoint5 = 0, $closestPoint7 = 0, $closestPoint9 = 0, $count$0 = 0, $count$1 = 0, $count$2118120 = 0, $count$4 = 0;
 var $count$4149 = 0, $count$5 = 0, $count$6 = 0, $count$7 = 0, $count$8 = 0, $edgeIndices$i = 0, $extract$t = 0, $faceIndices$i = 0, $i$01$i = 0, $i$01$i106 = 0, $i$01$i69 = 0, $i$01$i85 = 0, $i$01$i90 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $skipEdgesIfFaceHits$not = 0, $testDiagonal$0 = 0, $testDiagonal$1 = 0, $testDiagonal$2$off0116123 = 0;
 var $testDiagonal$2$off0116123145 = 0, $testDiagonal$2$off0116123146 = 0, $testDiagonal$2$off0116124 = 0, $testEdges$ = 0, $testEdges$$ = 0, $testRowEdge0$0 = 0, $testRowEdge0$1$off0117121 = 0, $testRowEdge0$1$off0117121147 = 0, $testRowEdge0$1$off0117122 = 0, $testRowEdge1$0$off0 = 0, $testRowEdge1$1$off0113128 = 0, $testRowEdge1$1$off0113128142 = 0, $testRowEdge1$1$off0113128143 = 0, $testRowEdge1$1$off0113129 = 0, $testVertex0$2$off0148 = 0, $testVertex2$0$off0 = 0, $testVertex2$1$off0114126 = 0, $testVertex2$1$off0114126144 = 0, $testVertex2$1$off0114127 = 0, $testVertex3$0$off0 = 0;
 var $testVertex3$1$off0112130 = 0, $testVertex3$1$off0112130140 = 0, $testVertex3$1$off0112130141 = 0, $testVertex3$1$off0112131 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $edgeIndices$i = sp + 96|0;
 $faceIndices$i = sp + 88|0;
 $closestPoint = sp + 72|0;
 $closestPoint1 = sp + 60|0;
 $closestPoint2 = sp + 48|0;
 $closestPoint3 = sp + 24|0;
 $closestPoint5 = sp + 12|0;
 $closestPoint7 = sp;
 $closestPoint9 = sp + 36|0;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_imul($3, $row)|0;
 $5 = (($4) + ($column))|0;
 $6 = ($5*3)|0;
 $7 = (($1) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + -2)|0;
 $10 = ($9|0)==($row|0);
 $11 = (($3) + -2)|0;
 $12 = ($11|0)==($column|0);
 $13 = $testEdges&1;
 $testEdges$ = $12 & $testEdges;
 $$off013 = $10 & $testEdges;
 $testEdges$$ = $10 & $testEdges$;
 $14 = $5 << 1;
 $15 = (($1) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $14 | 1;
 $18 = $5 & 2147483647;
 $19 = ((($16) + ($18<<2)|0) + 3|0);
 $$sink$i45 = HEAP8[$19>>0]|0;
 do {
  if ($testFaces) {
   $20 = ((($16) + ($18<<2)|0) + 2|0);
   $$sink$i = HEAP8[$20>>0]|0;
   $21 = $$sink$i & 127;
   $22 = ($21<<24>>24)==(127);
   if ($22) {
    $count$0 = 0;$testDiagonal$0 = $13;$testRowEdge0$0 = $testEdges;$testVertex2$0$off0 = $$off013;
   } else {
    $23 = (__ZNK5physx2Gu15HeightFieldUtil24findProjectionOnTriangleEjjjRKNS_6PxVec3ERS2_($this,$14,$row,$column,$point,$closestPoint)|0);
    if ($23) {
     $24 = Math_fround(HEAPF32[$closestPoint>>2]);
     HEAPF32[$closestPoints>>2] = $24;
     $25 = (($closestPoint) + 4|0);
     $26 = Math_fround(HEAPF32[$25>>2]);
     $27 = (($closestPoints) + 4|0);
     HEAPF32[$27>>2] = $26;
     $28 = (($closestPoint) + 8|0);
     $29 = Math_fround(HEAPF32[$28>>2]);
     $30 = (($closestPoints) + 8|0);
     HEAPF32[$30>>2] = $29;
     $31 = ($featureCodes|0)==(0|0);
     if ($31) {
      $count$0 = 1;$testDiagonal$0 = 0;$testRowEdge0$0 = 0;$testVertex2$0$off0 = 0;
     } else {
      HEAP32[$featureCodes>>2] = $14;
      $count$0 = 1;$testDiagonal$0 = 0;$testRowEdge0$0 = 0;$testVertex2$0$off0 = 0;
     }
    } else {
     $count$0 = 0;$testDiagonal$0 = $13;$testRowEdge0$0 = $testEdges;$testVertex2$0$off0 = $$off013;
    }
   }
   $32 = $$sink$i45 & 127;
   $33 = ($32<<24>>24)==(127);
   if ($33) {
    $count$1 = $count$0;$testDiagonal$1 = $testDiagonal$0;$testRowEdge1$0$off0 = $testEdges$;$testVertex3$0$off0 = $testEdges$$;
   } else {
    $34 = (__ZNK5physx2Gu15HeightFieldUtil24findProjectionOnTriangleEjjjRKNS_6PxVec3ERS2_($this,$17,$row,$column,$point,$closestPoint1)|0);
    if ($34) {
     $35 = Math_fround(HEAPF32[$closestPoint1>>2]);
     $36 = (($closestPoints) + (($count$0*12)|0)|0);
     HEAPF32[$36>>2] = $35;
     $37 = (($closestPoint1) + 4|0);
     $38 = Math_fround(HEAPF32[$37>>2]);
     $39 = ((($closestPoints) + (($count$0*12)|0)|0) + 4|0);
     HEAPF32[$39>>2] = $38;
     $40 = (($closestPoint1) + 8|0);
     $41 = Math_fround(HEAPF32[$40>>2]);
     $42 = ((($closestPoints) + (($count$0*12)|0)|0) + 8|0);
     HEAPF32[$42>>2] = $41;
     $43 = ($featureCodes|0)==(0|0);
     if (!($43)) {
      $44 = (($featureCodes) + ($count$0<<2)|0);
      HEAP32[$44>>2] = $17;
     }
     $45 = (($count$0) + 1)|0;
     $count$1 = $45;$testDiagonal$1 = 0;$testRowEdge1$0$off0 = 0;$testVertex3$0$off0 = 0;
    } else {
     $count$1 = $count$0;$testDiagonal$1 = $testDiagonal$0;$testRowEdge1$0$off0 = $testEdges$;$testVertex3$0$off0 = $testEdges$$;
    }
   }
   $46 = $testDiagonal$1 & 1;
   $extract$t = ($46<<24>>24)!=(0);
   if (!($testEdges)) {
    $$0 = $count$1;
    STACKTOP = sp;return ($$0|0);
   }
   $47 = ($count$1|0)==(0);
   $skipEdgesIfFaceHits$not = $skipEdgesIfFaceHits ^ 1;
   $brmerge = $47 | $skipEdgesIfFaceHits$not;
   if ($brmerge) {
    $48 = HEAP32[$0>>2]|0;
    $49 = (($48) + 20|0);
    $50 = HEAP32[$49>>2]|0;
    $78 = $50;$count$2118120 = $count$1;$testDiagonal$2$off0116124 = $extract$t;$testRowEdge0$1$off0117122 = $testRowEdge0$0;$testRowEdge1$1$off0113129 = $testRowEdge1$0$off0;$testVertex2$1$off0114127 = $testVertex2$0$off0;$testVertex3$1$off0112131 = $testVertex3$0$off0;
    label = 15;
    break;
   } else {
    $$0 = $count$1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   if ($testEdges) {
    $78 = $3;$count$2118120 = 0;$testDiagonal$2$off0116124 = 1;$testRowEdge0$1$off0117122 = 1;$testRowEdge1$1$off0113129 = $testEdges$;$testVertex2$1$off0114127 = $$off013;$testVertex3$1$off0112131 = $testEdges$$;
    label = 15;
   } else {
    $432 = $3;$count$4 = 0;$testDiagonal$2$off0116123 = 0;$testRowEdge0$1$off0117121 = 0;$testRowEdge1$1$off0113128 = $testEdges$;$testVertex2$1$off0114126 = $$off013;$testVertex3$1$off0112130 = $testEdges$$;
    label = 46;
   }
  }
 } while(0);
 L22: do {
  if ((label|0) == 15) {
   $51 = (Math_fround(__ZNK5physx2Gu15HeightFieldUtil22findClosestPointOnEdgeEjjjjRKNS_6PxVec3ERS2_($this,$6,$5,$row,$column,$point,$closestPoint2)));
   $52 = !($51 <= Math_fround(0.0));
   if (!($52)) {
    if (!($testRowEdge0$1$off0117122)) {
     $432 = $78;$count$4 = $count$2118120;$testDiagonal$2$off0116123 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121 = 0;$testRowEdge1$1$off0113128 = $testRowEdge1$1$off0113129;$testVertex2$1$off0114126 = $testVertex2$1$off0114127;$testVertex3$1$off0112130 = $testVertex3$1$off0112131;
     label = 46;
     break;
    }
    $53 = HEAP32[$0>>2]|0;
    $54 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($53,$5,$row,$column,$edgeIndices$i)|0);
    $55 = ($54|0)==(0);
    if ($55) {
     $180 = $78;$count$4149 = $count$2118120;$testDiagonal$2$off0116123146 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121147 = 1;$testRowEdge1$1$off0113128143 = $testRowEdge1$1$off0113129;$testVertex0$2$off0148 = 0;$testVertex2$1$off0114126144 = $testVertex2$1$off0114127;$testVertex3$1$off0112130141 = $testVertex3$1$off0112131;
     label = 47;
     break;
    } else {
     $i$01$i90 = 0;
    }
    while(1) {
     $58 = (($edgeIndices$i) + ($i$01$i90<<4)|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ((($edgeIndices$i) + ($i$01$i90<<4)|0) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ((($edgeIndices$i) + ($i$01$i90<<4)|0) + 8|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ((($edgeIndices$i) + ($i$01$i90<<4)|0) + 12|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (__ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEjjjj($this,$59,$61,$63,$65)|0);
     $67 = ($66|0)==(-1);
     $57 = (($i$01$i90) + 2)|0;
     if (!($67)) {
      break;
     }
     $56 = ($57>>>0)<($54>>>0);
     if ($56) {
      $i$01$i90 = $57;
     } else {
      $180 = $78;$count$4149 = $count$2118120;$testDiagonal$2$off0116123146 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121147 = 1;$testRowEdge1$1$off0113128143 = $testRowEdge1$1$off0113129;$testVertex0$2$off0148 = 0;$testVertex2$1$off0114126144 = $testVertex2$1$off0114127;$testVertex3$1$off0112130141 = $testVertex3$1$off0112131;
      label = 47;
      break L22;
     }
    }
    $68 = Math_fround(HEAPF32[$closestPoint2>>2]);
    $69 = (($closestPoints) + (($count$2118120*12)|0)|0);
    HEAPF32[$69>>2] = $68;
    $70 = (($closestPoint2) + 4|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = ((($closestPoints) + (($count$2118120*12)|0)|0) + 4|0);
    HEAPF32[$72>>2] = $71;
    $73 = (($closestPoint2) + 8|0);
    $74 = Math_fround(HEAPF32[$73>>2]);
    $75 = ((($closestPoints) + (($count$2118120*12)|0)|0) + 8|0);
    HEAPF32[$75>>2] = $74;
    $76 = ($featureCodes|0)==(0|0);
    if (!($76)) {
     $77 = Math_imul($78, $row)|0;
     $79 = (($77) + ($column))|0;
     $80 = $79 | -2147483648;
     $81 = (($featureCodes) + ($count$2118120<<2)|0);
     HEAP32[$81>>2] = $80;
    }
    $82 = (($count$2118120) + 1)|0;
    $180 = $78;$count$4149 = $82;$testDiagonal$2$off0116123146 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121147 = 1;$testRowEdge1$1$off0113128143 = $testRowEdge1$1$off0113129;$testVertex0$2$off0148 = 0;$testVertex2$1$off0114126144 = $testVertex2$1$off0114127;$testVertex3$1$off0112130141 = $testVertex3$1$off0112131;
    label = 47;
    break;
   }
   $83 = $51 < Math_fround(1.0);
   if (!($83)) {
    if (!($testRowEdge1$1$off0113129)) {
     $432 = $78;$count$4 = $count$2118120;$testDiagonal$2$off0116123 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121 = $testRowEdge0$1$off0117122;$testRowEdge1$1$off0113128 = 0;$testVertex2$1$off0114126 = $testVertex2$1$off0114127;$testVertex3$1$off0112130 = $testVertex3$1$off0112131;
     label = 46;
     break;
    }
    $121 = (($5) + 1)|0;
    $122 = (($column) + 1)|0;
    $123 = HEAP32[$0>>2]|0;
    $124 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($123,$121,$row,$122,$edgeIndices$i)|0);
    $125 = ($124|0)==(0);
    if ($125) {
     $432 = $78;$count$4 = $count$2118120;$testDiagonal$2$off0116123 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121 = $testRowEdge0$1$off0117122;$testRowEdge1$1$off0113128 = 1;$testVertex2$1$off0114126 = $testVertex2$1$off0114127;$testVertex3$1$off0112130 = $testVertex3$1$off0112131;
     label = 46;
     break;
    } else {
     $i$01$i106 = 0;
    }
    while(1) {
     $128 = (($edgeIndices$i) + ($i$01$i106<<4)|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = ((($edgeIndices$i) + ($i$01$i106<<4)|0) + 4|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ((($edgeIndices$i) + ($i$01$i106<<4)|0) + 8|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ((($edgeIndices$i) + ($i$01$i106<<4)|0) + 12|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = (__ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEjjjj($this,$129,$131,$133,$135)|0);
     $137 = ($136|0)==(-1);
     $127 = (($i$01$i106) + 2)|0;
     if (!($137)) {
      break;
     }
     $126 = ($127>>>0)<($124>>>0);
     if ($126) {
      $i$01$i106 = $127;
     } else {
      $432 = $78;$count$4 = $count$2118120;$testDiagonal$2$off0116123 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121 = $testRowEdge0$1$off0117122;$testRowEdge1$1$off0113128 = 1;$testVertex2$1$off0114126 = $testVertex2$1$off0114127;$testVertex3$1$off0112130 = $testVertex3$1$off0112131;
      label = 46;
      break L22;
     }
    }
    $138 = Math_fround(HEAPF32[$closestPoint2>>2]);
    $139 = (($closestPoints) + (($count$2118120*12)|0)|0);
    HEAPF32[$139>>2] = $138;
    $140 = (($closestPoint2) + 4|0);
    $141 = Math_fround(HEAPF32[$140>>2]);
    $142 = ((($closestPoints) + (($count$2118120*12)|0)|0) + 4|0);
    HEAPF32[$142>>2] = $141;
    $143 = (($closestPoint2) + 8|0);
    $144 = Math_fround(HEAPF32[$143>>2]);
    $145 = ((($closestPoints) + (($count$2118120*12)|0)|0) + 8|0);
    HEAPF32[$145>>2] = $144;
    $146 = ($featureCodes|0)==(0|0);
    if (!($146)) {
     $147 = Math_imul($78, $row)|0;
     $148 = (($122) + ($147))|0;
     $149 = $148 | -2147483648;
     $150 = (($featureCodes) + ($count$2118120<<2)|0);
     HEAP32[$150>>2] = $149;
    }
    $151 = (($count$2118120) + 1)|0;
    $432 = $78;$count$4 = $151;$testDiagonal$2$off0116123 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121 = $testRowEdge0$1$off0117122;$testRowEdge1$1$off0113128 = 1;$testVertex2$1$off0114126 = $testVertex2$1$off0114127;$testVertex3$1$off0112130 = $testVertex3$1$off0112131;
    label = 46;
    break;
   }
   if ($testEdges) {
    $84 = HEAP32[$0>>2]|0;
    $85 = (__ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($84,$6,$faceIndices$i)|0);
    $86 = ($85>>>0)>(1);
    $87 = HEAP32[$0>>2]|0;
    $88 = HEAP32[$faceIndices$i>>2]|0;
    $89 = $88 & 1;
    $90 = ($89|0)==(0);
    $91 = $88 >>> 1;
    $92 = (($87) + 36|0);
    $93 = HEAP32[$92>>2]|0;
    if ($90) {
     $94 = ((($93) + ($91<<2)|0) + 2|0);
     $$sink$in$i$i95 = $94;
    } else {
     $95 = ((($93) + ($91<<2)|0) + 3|0);
     $$sink$in$i$i95 = $95;
    }
    $$sink$i$i96 = HEAP8[$$sink$in$i$i95>>0]|0;
    $96 = $$sink$i$i96 & 127;
    $97 = ($96<<24>>24)!=(127);
    if ($86) {
     if ($97) {
      $108 = $88;
     } else {
      $98 = (($faceIndices$i) + 4|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = $99 & 1;
      $101 = ($100|0)==(0);
      $102 = $99 >>> 1;
      if ($101) {
       $103 = ((($93) + ($102<<2)|0) + 2|0);
       $$sink$in$i2$i98 = $103;
      } else {
       $104 = ((($93) + ($102<<2)|0) + 3|0);
       $$sink$in$i2$i98 = $104;
      }
      $$sink$i3$i99 = HEAP8[$$sink$in$i2$i98>>0]|0;
      $105 = $$sink$i3$i99 & 127;
      $106 = ($105<<24>>24)==(127);
      $$$i100 = $106 ? -1 : $99;
      $108 = $$$i100;
     }
    } else {
     $$1$i102 = $97 ? $88 : -1;
     $108 = $$1$i102;
    }
    $107 = ($108|0)==(-1);
    if ($107) {
     $432 = $78;$count$4 = $count$2118120;$testDiagonal$2$off0116123 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121 = $testRowEdge0$1$off0117122;$testRowEdge1$1$off0113128 = $testRowEdge1$1$off0113129;$testVertex2$1$off0114126 = $testVertex2$1$off0114127;$testVertex3$1$off0112130 = $testVertex3$1$off0112131;
     label = 46;
    } else {
     $109 = Math_fround(HEAPF32[$closestPoint2>>2]);
     $110 = (($closestPoints) + (($count$2118120*12)|0)|0);
     HEAPF32[$110>>2] = $109;
     $111 = (($closestPoint2) + 4|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = ((($closestPoints) + (($count$2118120*12)|0)|0) + 4|0);
     HEAPF32[$113>>2] = $112;
     $114 = (($closestPoint2) + 8|0);
     $115 = Math_fround(HEAPF32[$114>>2]);
     $116 = ((($closestPoints) + (($count$2118120*12)|0)|0) + 8|0);
     HEAPF32[$116>>2] = $115;
     $117 = ($featureCodes|0)==(0|0);
     if (!($117)) {
      $118 = $6 | 1073741824;
      $119 = (($featureCodes) + ($count$2118120<<2)|0);
      HEAP32[$119>>2] = $118;
     }
     $120 = (($count$2118120) + 1)|0;
     $432 = $78;$count$4 = $120;$testDiagonal$2$off0116123 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121 = $testRowEdge0$1$off0117122;$testRowEdge1$1$off0113128 = $testRowEdge1$1$off0113129;$testVertex2$1$off0114126 = $testVertex2$1$off0114127;$testVertex3$1$off0112130 = $testVertex3$1$off0112131;
     label = 46;
    }
   } else {
    $432 = $78;$count$4 = $count$2118120;$testDiagonal$2$off0116123 = $testDiagonal$2$off0116124;$testRowEdge0$1$off0117121 = $testRowEdge0$1$off0117122;$testRowEdge1$1$off0113128 = $testRowEdge1$1$off0113129;$testVertex2$1$off0114126 = $testVertex2$1$off0114127;$testVertex3$1$off0112130 = $testVertex3$1$off0112131;
    label = 46;
   }
  }
 } while(0);
 if ((label|0) == 46) {
  $brmerge42 = $testRowEdge0$1$off0117121 | $testVertex2$1$off0114126;
  if ($brmerge42) {
   $180 = $432;$count$4149 = $count$4;$testDiagonal$2$off0116123146 = $testDiagonal$2$off0116123;$testRowEdge0$1$off0117121147 = $testRowEdge0$1$off0117121;$testRowEdge1$1$off0113128143 = $testRowEdge1$1$off0113128;$testVertex0$2$off0148 = $testRowEdge0$1$off0117121;$testVertex2$1$off0114126144 = $testVertex2$1$off0114126;$testVertex3$1$off0112130141 = $testVertex3$1$off0112130;
   label = 47;
  } else {
   $255 = $432;$count$5 = $count$4;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130;
  }
 }
 L66: do {
  if ((label|0) == 47) {
   $152 = (($6) + 2)|0;
   $153 = (Math_fround(__ZNK5physx2Gu15HeightFieldUtil22findClosestPointOnEdgeEjjjjRKNS_6PxVec3ERS2_($this,$152,$5,$row,$column,$point,$closestPoint3)));
   $154 = !($153 <= Math_fround(0.0));
   if (!($154)) {
    if (!($testVertex0$2$off0148)) {
     $255 = $180;$count$5 = $count$4149;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
     break;
    }
    $155 = HEAP32[$0>>2]|0;
    $156 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($155,$5,$row,$column,$edgeIndices$i)|0);
    $157 = ($156|0)==(0);
    if ($157) {
     $255 = $180;$count$5 = $count$4149;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
     break;
    } else {
     $i$01$i85 = 0;
    }
    while(1) {
     $160 = (($edgeIndices$i) + ($i$01$i85<<4)|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = ((($edgeIndices$i) + ($i$01$i85<<4)|0) + 4|0);
     $163 = HEAP32[$162>>2]|0;
     $164 = ((($edgeIndices$i) + ($i$01$i85<<4)|0) + 8|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = ((($edgeIndices$i) + ($i$01$i85<<4)|0) + 12|0);
     $167 = HEAP32[$166>>2]|0;
     $168 = (__ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEjjjj($this,$161,$163,$165,$167)|0);
     $169 = ($168|0)==(-1);
     $159 = (($i$01$i85) + 2)|0;
     if (!($169)) {
      break;
     }
     $158 = ($159>>>0)<($156>>>0);
     if ($158) {
      $i$01$i85 = $159;
     } else {
      $255 = $180;$count$5 = $count$4149;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
      break L66;
     }
    }
    $170 = Math_fround(HEAPF32[$closestPoint3>>2]);
    $171 = (($closestPoints) + (($count$4149*12)|0)|0);
    HEAPF32[$171>>2] = $170;
    $172 = (($closestPoint3) + 4|0);
    $173 = Math_fround(HEAPF32[$172>>2]);
    $174 = ((($closestPoints) + (($count$4149*12)|0)|0) + 4|0);
    HEAPF32[$174>>2] = $173;
    $175 = (($closestPoint3) + 8|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = ((($closestPoints) + (($count$4149*12)|0)|0) + 8|0);
    HEAPF32[$177>>2] = $176;
    $178 = ($featureCodes|0)==(0|0);
    if (!($178)) {
     $179 = Math_imul($180, $row)|0;
     $181 = (($179) + ($column))|0;
     $182 = $181 | -2147483648;
     $183 = (($featureCodes) + ($count$4149<<2)|0);
     HEAP32[$183>>2] = $182;
    }
    $184 = (($count$4149) + 1)|0;
    $255 = $180;$count$5 = $184;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
    break;
   }
   $185 = $153 < Math_fround(1.0);
   if (!($185)) {
    if (!($testVertex2$1$off0114126144)) {
     $255 = $180;$count$5 = $count$4149;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
     break;
    }
    $223 = (($180) + ($5))|0;
    $224 = (($row) + 1)|0;
    $225 = HEAP32[$0>>2]|0;
    $226 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($225,$223,$224,$column,$edgeIndices$i)|0);
    $227 = ($226|0)==(0);
    if ($227) {
     $255 = $180;$count$5 = $count$4149;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
     break;
    } else {
     $i$01$i69 = 0;
    }
    while(1) {
     $230 = (($edgeIndices$i) + ($i$01$i69<<4)|0);
     $231 = HEAP32[$230>>2]|0;
     $232 = ((($edgeIndices$i) + ($i$01$i69<<4)|0) + 4|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = ((($edgeIndices$i) + ($i$01$i69<<4)|0) + 8|0);
     $235 = HEAP32[$234>>2]|0;
     $236 = ((($edgeIndices$i) + ($i$01$i69<<4)|0) + 12|0);
     $237 = HEAP32[$236>>2]|0;
     $238 = (__ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEjjjj($this,$231,$233,$235,$237)|0);
     $239 = ($238|0)==(-1);
     $229 = (($i$01$i69) + 2)|0;
     if (!($239)) {
      break;
     }
     $228 = ($229>>>0)<($226>>>0);
     if ($228) {
      $i$01$i69 = $229;
     } else {
      $255 = $180;$count$5 = $count$4149;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
      break L66;
     }
    }
    $240 = Math_fround(HEAPF32[$closestPoint3>>2]);
    $241 = (($closestPoints) + (($count$4149*12)|0)|0);
    HEAPF32[$241>>2] = $240;
    $242 = (($closestPoint3) + 4|0);
    $243 = Math_fround(HEAPF32[$242>>2]);
    $244 = ((($closestPoints) + (($count$4149*12)|0)|0) + 4|0);
    HEAPF32[$244>>2] = $243;
    $245 = (($closestPoint3) + 8|0);
    $246 = Math_fround(HEAPF32[$245>>2]);
    $247 = ((($closestPoints) + (($count$4149*12)|0)|0) + 8|0);
    HEAPF32[$247>>2] = $246;
    $248 = ($featureCodes|0)==(0|0);
    if (!($248)) {
     $249 = Math_imul($180, $224)|0;
     $250 = (($249) + ($column))|0;
     $251 = $250 | -2147483648;
     $252 = (($featureCodes) + ($count$4149<<2)|0);
     HEAP32[$252>>2] = $251;
    }
    $253 = (($count$4149) + 1)|0;
    $255 = $180;$count$5 = $253;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
    break;
   }
   if ($testRowEdge0$1$off0117121147) {
    $186 = HEAP32[$0>>2]|0;
    $187 = (__ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($186,$152,$faceIndices$i)|0);
    $188 = ($187>>>0)>(1);
    $189 = HEAP32[$0>>2]|0;
    $190 = HEAP32[$faceIndices$i>>2]|0;
    $191 = $190 & 1;
    $192 = ($191|0)==(0);
    $193 = $190 >>> 1;
    $194 = (($189) + 36|0);
    $195 = HEAP32[$194>>2]|0;
    if ($192) {
     $196 = ((($195) + ($193<<2)|0) + 2|0);
     $$sink$in$i$i74 = $196;
    } else {
     $197 = ((($195) + ($193<<2)|0) + 3|0);
     $$sink$in$i$i74 = $197;
    }
    $$sink$i$i75 = HEAP8[$$sink$in$i$i74>>0]|0;
    $198 = $$sink$i$i75 & 127;
    $199 = ($198<<24>>24)!=(127);
    if ($188) {
     if ($199) {
      $210 = $190;
     } else {
      $200 = (($faceIndices$i) + 4|0);
      $201 = HEAP32[$200>>2]|0;
      $202 = $201 & 1;
      $203 = ($202|0)==(0);
      $204 = $201 >>> 1;
      if ($203) {
       $205 = ((($195) + ($204<<2)|0) + 2|0);
       $$sink$in$i2$i77 = $205;
      } else {
       $206 = ((($195) + ($204<<2)|0) + 3|0);
       $$sink$in$i2$i77 = $206;
      }
      $$sink$i3$i78 = HEAP8[$$sink$in$i2$i77>>0]|0;
      $207 = $$sink$i3$i78 & 127;
      $208 = ($207<<24>>24)==(127);
      $$$i79 = $208 ? -1 : $201;
      $210 = $$$i79;
     }
    } else {
     $$1$i81 = $199 ? $190 : -1;
     $210 = $$1$i81;
    }
    $209 = ($210|0)==(-1);
    if ($209) {
     $255 = $180;$count$5 = $count$4149;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
    } else {
     $211 = Math_fround(HEAPF32[$closestPoint3>>2]);
     $212 = (($closestPoints) + (($count$4149*12)|0)|0);
     HEAPF32[$212>>2] = $211;
     $213 = (($closestPoint3) + 4|0);
     $214 = Math_fround(HEAPF32[$213>>2]);
     $215 = ((($closestPoints) + (($count$4149*12)|0)|0) + 4|0);
     HEAPF32[$215>>2] = $214;
     $216 = (($closestPoint3) + 8|0);
     $217 = Math_fround(HEAPF32[$216>>2]);
     $218 = ((($closestPoints) + (($count$4149*12)|0)|0) + 8|0);
     HEAPF32[$218>>2] = $217;
     $219 = ($featureCodes|0)==(0|0);
     if (!($219)) {
      $220 = $152 | 1073741824;
      $221 = (($featureCodes) + ($count$4149<<2)|0);
      HEAP32[$221>>2] = $220;
     }
     $222 = (($count$4149) + 1)|0;
     $255 = $180;$count$5 = $222;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
    }
   } else {
    $255 = $180;$count$5 = $count$4149;$testDiagonal$2$off0116123145 = $testDiagonal$2$off0116123146;$testRowEdge1$1$off0113128142 = $testRowEdge1$1$off0113128143;$testVertex3$1$off0112130140 = $testVertex3$1$off0112130141;
   }
  }
 } while(0);
 if ($$off013) {
  $254 = (($255) + ($5))|0;
  $256 = ($254*3)|0;
  $257 = (($row) + 1)|0;
  $258 = (Math_fround(__ZNK5physx2Gu15HeightFieldUtil22findClosestPointOnEdgeEjjjjRKNS_6PxVec3ERS2_($this,$256,$254,$257,$column,$point,$closestPoint5)));
  $259 = !($258 <= Math_fround(0.0));
  $260 = $258 < Math_fround(1.0);
  $or$cond = $259 & $260;
  if ($or$cond) {
   $261 = HEAP32[$0>>2]|0;
   $262 = (__ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($261,$256,$faceIndices$i)|0);
   $263 = ($262>>>0)>(1);
   $264 = HEAP32[$0>>2]|0;
   $265 = HEAP32[$faceIndices$i>>2]|0;
   $266 = $265 & 1;
   $267 = ($266|0)==(0);
   $268 = $265 >>> 1;
   $269 = (($264) + 36|0);
   $270 = HEAP32[$269>>2]|0;
   if ($267) {
    $271 = ((($270) + ($268<<2)|0) + 2|0);
    $$sink$in$i$i58 = $271;
   } else {
    $272 = ((($270) + ($268<<2)|0) + 3|0);
    $$sink$in$i$i58 = $272;
   }
   $$sink$i$i59 = HEAP8[$$sink$in$i$i58>>0]|0;
   $273 = $$sink$i$i59 & 127;
   $274 = ($273<<24>>24)!=(127);
   if ($263) {
    if ($274) {
     $285 = $265;
    } else {
     $275 = (($faceIndices$i) + 4|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = $276 & 1;
     $278 = ($277|0)==(0);
     $279 = $276 >>> 1;
     if ($278) {
      $280 = ((($270) + ($279<<2)|0) + 2|0);
      $$sink$in$i2$i61 = $280;
     } else {
      $281 = ((($270) + ($279<<2)|0) + 3|0);
      $$sink$in$i2$i61 = $281;
     }
     $$sink$i3$i62 = HEAP8[$$sink$in$i2$i61>>0]|0;
     $282 = $$sink$i3$i62 & 127;
     $283 = ($282<<24>>24)==(127);
     $$$i63 = $283 ? -1 : $276;
     $285 = $$$i63;
    }
   } else {
    $$1$i65 = $274 ? $265 : -1;
    $285 = $$1$i65;
   }
   $284 = ($285|0)==(-1);
   if ($284) {
    $count$6 = $count$5;
   } else {
    $286 = Math_fround(HEAPF32[$closestPoint5>>2]);
    $287 = (($closestPoints) + (($count$5*12)|0)|0);
    HEAPF32[$287>>2] = $286;
    $288 = (($closestPoint5) + 4|0);
    $289 = Math_fround(HEAPF32[$288>>2]);
    $290 = ((($closestPoints) + (($count$5*12)|0)|0) + 4|0);
    HEAPF32[$290>>2] = $289;
    $291 = (($closestPoint5) + 8|0);
    $292 = Math_fround(HEAPF32[$291>>2]);
    $293 = ((($closestPoints) + (($count$5*12)|0)|0) + 8|0);
    HEAPF32[$293>>2] = $292;
    $294 = ($featureCodes|0)==(0|0);
    if (!($294)) {
     $295 = $256 | 1073741824;
     $296 = (($featureCodes) + ($count$5<<2)|0);
     HEAP32[$296>>2] = $295;
    }
    $297 = (($count$5) + 1)|0;
    $count$6 = $297;
   }
  } else {
   $count$6 = $count$5;
  }
 } else {
  $count$6 = $count$5;
 }
 if ($testRowEdge1$1$off0113128142) {
  $298 = (($6) + 5)|0;
  $299 = (($5) + 1)|0;
  $300 = (($column) + 1)|0;
  $301 = (Math_fround(__ZNK5physx2Gu15HeightFieldUtil22findClosestPointOnEdgeEjjjjRKNS_6PxVec3ERS2_($this,$298,$299,$row,$300,$point,$closestPoint7)));
  $302 = !($301 <= Math_fround(0.0));
  $303 = $301 < Math_fround(1.0);
  $or$cond3 = $302 & $303;
  if ($or$cond3) {
   $304 = HEAP32[$0>>2]|0;
   $305 = (__ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($304,$298,$faceIndices$i)|0);
   $306 = ($305>>>0)>(1);
   $307 = HEAP32[$0>>2]|0;
   $308 = HEAP32[$faceIndices$i>>2]|0;
   $309 = $308 & 1;
   $310 = ($309|0)==(0);
   $311 = $308 >>> 1;
   $312 = (($307) + 36|0);
   $313 = HEAP32[$312>>2]|0;
   if ($310) {
    $314 = ((($313) + ($311<<2)|0) + 2|0);
    $$sink$in$i$i47 = $314;
   } else {
    $315 = ((($313) + ($311<<2)|0) + 3|0);
    $$sink$in$i$i47 = $315;
   }
   $$sink$i$i48 = HEAP8[$$sink$in$i$i47>>0]|0;
   $316 = $$sink$i$i48 & 127;
   $317 = ($316<<24>>24)!=(127);
   if ($306) {
    if ($317) {
     $328 = $308;
    } else {
     $318 = (($faceIndices$i) + 4|0);
     $319 = HEAP32[$318>>2]|0;
     $320 = $319 & 1;
     $321 = ($320|0)==(0);
     $322 = $319 >>> 1;
     if ($321) {
      $323 = ((($313) + ($322<<2)|0) + 2|0);
      $$sink$in$i2$i50 = $323;
     } else {
      $324 = ((($313) + ($322<<2)|0) + 3|0);
      $$sink$in$i2$i50 = $324;
     }
     $$sink$i3$i51 = HEAP8[$$sink$in$i2$i50>>0]|0;
     $325 = $$sink$i3$i51 & 127;
     $326 = ($325<<24>>24)==(127);
     $$$i52 = $326 ? -1 : $319;
     $328 = $$$i52;
    }
   } else {
    $$1$i54 = $317 ? $308 : -1;
    $328 = $$1$i54;
   }
   $327 = ($328|0)==(-1);
   if ($327) {
    $count$7 = $count$6;
   } else {
    $329 = Math_fround(HEAPF32[$closestPoint7>>2]);
    $330 = (($closestPoints) + (($count$6*12)|0)|0);
    HEAPF32[$330>>2] = $329;
    $331 = (($closestPoint7) + 4|0);
    $332 = Math_fround(HEAPF32[$331>>2]);
    $333 = ((($closestPoints) + (($count$6*12)|0)|0) + 4|0);
    HEAPF32[$333>>2] = $332;
    $334 = (($closestPoint7) + 8|0);
    $335 = Math_fround(HEAPF32[$334>>2]);
    $336 = ((($closestPoints) + (($count$6*12)|0)|0) + 8|0);
    HEAPF32[$336>>2] = $335;
    $337 = ($featureCodes|0)==(0|0);
    if (!($337)) {
     $338 = $298 | 1073741824;
     $339 = (($featureCodes) + ($count$6<<2)|0);
     HEAP32[$339>>2] = $338;
    }
    $340 = (($count$6) + 1)|0;
    $count$7 = $340;
   }
  } else {
   $count$7 = $count$6;
  }
 } else {
  $count$7 = $count$6;
 }
 L151: do {
  if ($testVertex3$1$off0112130140) {
   $341 = (($5) + 1)|0;
   $342 = (($341) + ($255))|0;
   $343 = (($row) + 1)|0;
   $344 = (($column) + 1)|0;
   $345 = HEAP32[$0>>2]|0;
   $346 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($345,$342,$343,$344,$edgeIndices$i)|0);
   $347 = ($346|0)==(0);
   if ($347) {
    $count$8 = $count$7;
   } else {
    $i$01$i = 0;
    while(1) {
     $350 = (($edgeIndices$i) + ($i$01$i<<4)|0);
     $351 = HEAP32[$350>>2]|0;
     $352 = ((($edgeIndices$i) + ($i$01$i<<4)|0) + 4|0);
     $353 = HEAP32[$352>>2]|0;
     $354 = ((($edgeIndices$i) + ($i$01$i<<4)|0) + 8|0);
     $355 = HEAP32[$354>>2]|0;
     $356 = ((($edgeIndices$i) + ($i$01$i<<4)|0) + 12|0);
     $357 = HEAP32[$356>>2]|0;
     $358 = (__ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEjjjj($this,$351,$353,$355,$357)|0);
     $359 = ($358|0)==(-1);
     $349 = (($i$01$i) + 2)|0;
     if (!($359)) {
      break;
     }
     $348 = ($349>>>0)<($346>>>0);
     if ($348) {
      $i$01$i = $349;
     } else {
      $count$8 = $count$7;
      break L151;
     }
    }
    $360 = (Math_fround(($343>>>0)));
    $361 = (($this) + 16|0);
    $362 = HEAP32[$361>>2]|0;
    $363 = (($362) + 12|0);
    $364 = Math_fround(HEAPF32[$363>>2]);
    $365 = Math_fround($360 * $364);
    $366 = (($362) + 8|0);
    $367 = Math_fround(HEAPF32[$366>>2]);
    $368 = HEAP32[$0>>2]|0;
    $369 = (($368) + 20|0);
    $370 = HEAP32[$369>>2]|0;
    $371 = (($341) + ($370))|0;
    $372 = (($368) + 36|0);
    $373 = HEAP32[$372>>2]|0;
    $374 = (($373) + ($371<<2)|0);
    $375 = HEAP16[$374>>1]|0;
    $376 = (Math_fround(($375<<16>>16)));
    $377 = Math_fround($367 * $376);
    $378 = (Math_fround(($344>>>0)));
    $379 = (($362) + 16|0);
    $380 = Math_fround(HEAPF32[$379>>2]);
    $381 = Math_fround($378 * $380);
    $382 = (($closestPoints) + (($count$7*12)|0)|0);
    HEAPF32[$382>>2] = $365;
    $383 = ((($closestPoints) + (($count$7*12)|0)|0) + 4|0);
    HEAPF32[$383>>2] = $377;
    $384 = ((($closestPoints) + (($count$7*12)|0)|0) + 8|0);
    HEAPF32[$384>>2] = $381;
    $385 = ($featureCodes|0)==(0|0);
    if (!($385)) {
     $386 = Math_imul($255, $343)|0;
     $387 = (($344) + ($386))|0;
     $388 = $387 | -2147483648;
     $389 = (($featureCodes) + ($count$7<<2)|0);
     HEAP32[$389>>2] = $388;
    }
    $390 = (($count$7) + 1)|0;
    $count$8 = $390;
   }
  } else {
   $count$8 = $count$7;
  }
 } while(0);
 if (!($testDiagonal$2$off0116123145)) {
  $$0 = $count$8;
  STACKTOP = sp;return ($$0|0);
 }
 $391 = (($6) + 1)|0;
 $392 = HEAP32[$0>>2]|0;
 $393 = (__ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($392,$391,$faceIndices$i)|0);
 $394 = ($393>>>0)>(1);
 $395 = HEAP32[$0>>2]|0;
 $396 = HEAP32[$faceIndices$i>>2]|0;
 $397 = $396 & 1;
 $398 = ($397|0)==(0);
 $399 = $396 >>> 1;
 $400 = (($395) + 36|0);
 $401 = HEAP32[$400>>2]|0;
 if ($398) {
  $402 = ((($401) + ($399<<2)|0) + 2|0);
  $$sink$in$i$i = $402;
 } else {
  $403 = ((($401) + ($399<<2)|0) + 3|0);
  $$sink$in$i$i = $403;
 }
 $$sink$i$i = HEAP8[$$sink$in$i$i>>0]|0;
 $404 = $$sink$i$i & 127;
 $405 = ($404<<24>>24)!=(127);
 if ($394) {
  if ($405) {
   $416 = $396;
  } else {
   $406 = (($faceIndices$i) + 4|0);
   $407 = HEAP32[$406>>2]|0;
   $408 = $407 & 1;
   $409 = ($408|0)==(0);
   $410 = $407 >>> 1;
   if ($409) {
    $411 = ((($401) + ($410<<2)|0) + 2|0);
    $$sink$in$i2$i = $411;
   } else {
    $412 = ((($401) + ($410<<2)|0) + 3|0);
    $$sink$in$i2$i = $412;
   }
   $$sink$i3$i = HEAP8[$$sink$in$i2$i>>0]|0;
   $413 = $$sink$i3$i & 127;
   $414 = ($413<<24>>24)==(127);
   $$$i = $414 ? -1 : $407;
   $416 = $$$i;
  }
 } else {
  $$1$i = $405 ? $396 : -1;
  $416 = $$1$i;
 }
 $415 = ($416|0)==(-1);
 if ($415) {
  $$0 = $count$8;
  STACKTOP = sp;return ($$0|0);
 }
 $417 = (Math_fround(__ZNK5physx2Gu15HeightFieldUtil22findClosestPointOnEdgeEjjjjRKNS_6PxVec3ERS2_($this,$391,$5,$row,$column,$point,$closestPoint9)));
 $418 = !($417 <= Math_fround(0.0));
 $419 = $417 < Math_fround(1.0);
 $or$cond5 = $418 & $419;
 if (!($or$cond5)) {
  $$0 = $count$8;
  STACKTOP = sp;return ($$0|0);
 }
 $420 = Math_fround(HEAPF32[$closestPoint9>>2]);
 $421 = (($closestPoints) + (($count$8*12)|0)|0);
 HEAPF32[$421>>2] = $420;
 $422 = (($closestPoint9) + 4|0);
 $423 = Math_fround(HEAPF32[$422>>2]);
 $424 = ((($closestPoints) + (($count$8*12)|0)|0) + 4|0);
 HEAPF32[$424>>2] = $423;
 $425 = (($closestPoint9) + 8|0);
 $426 = Math_fround(HEAPF32[$425>>2]);
 $427 = ((($closestPoints) + (($count$8*12)|0)|0) + 8|0);
 HEAPF32[$427>>2] = $426;
 $428 = ($featureCodes|0)==(0|0);
 if (!($428)) {
  $429 = $391 | 1073741824;
  $430 = (($featureCodes) + ($count$8<<2)|0);
  HEAP32[$430>>2] = $429;
 }
 $431 = (($count$8) + 1)|0;
 $$0 = $431;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Gu15HeightFieldUtil24findProjectionOnTriangleEjjjRKNS_6PxVec3ERS2_($this,$triangleIndex,$row,$column,$point,$projection) {
 $this = $this|0;
 $triangleIndex = $triangleIndex|0;
 $row = $row|0;
 $column = $column|0;
 $point = $point|0;
 $projection = $projection|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0);
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0);
 var $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $h0$0 = Math_fround(0), $h1$0 = Math_fround(0), $h2$0 = Math_fround(0), $or$cond = 0, $or$cond2 = 0, $uInvScale$0 = Math_fround(0), $vInvScale$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $triangleIndex >>> 1;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($0<<2)|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = (Math_fround(($10<<16>>16)));
 $12 = Math_fround($4 * $11);
 $13 = (($0) + 1)|0;
 $14 = (($8) + ($13<<2)|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = (Math_fround(($15<<16>>16)));
 $17 = Math_fround($4 * $16);
 $18 = (($6) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($0))|0;
 $21 = (($8) + ($20<<2)|0);
 $22 = HEAP16[$21>>1]|0;
 $23 = (Math_fround(($22<<16>>16)));
 $24 = Math_fround($4 * $23);
 $25 = (($20) + 1)|0;
 $26 = (($8) + ($25<<2)|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = (Math_fround(($27<<16>>16)));
 $29 = Math_fround($4 * $28);
 $30 = ((($8) + ($0<<2)|0) + 2|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)<(0);
 $33 = $triangleIndex & 1;
 $34 = ($33|0)==(0);
 do {
  if ($32) {
   if ($34) {
    $35 = (($row) + 1)|0;
    $36 = (Math_fround(($35>>>0)));
    $37 = (($2) + 12|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = Math_fround($36 * $38);
    $40 = (Math_fround(($column>>>0)));
    $41 = (($2) + 16|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = Math_fround($40 * $42);
    $44 = (($this) + 8|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = Math_fround(HEAPF32[$this>>2]);
    $47 = Math_fround(-$46);
    $89 = $39;$96 = $43;$h0$0 = $24;$h1$0 = $29;$h2$0 = $12;$uInvScale$0 = $45;$vInvScale$0 = $47;
    break;
   } else {
    $48 = (Math_fround(($row>>>0)));
    $49 = (($2) + 12|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = Math_fround($48 * $50);
    $52 = (($column) + 1)|0;
    $53 = (Math_fround(($52>>>0)));
    $54 = (($2) + 16|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = Math_fround($53 * $55);
    $57 = (($this) + 8|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround(-$58);
    $60 = Math_fround(HEAPF32[$this>>2]);
    $89 = $51;$96 = $56;$h0$0 = $17;$h1$0 = $12;$h2$0 = $29;$uInvScale$0 = $59;$vInvScale$0 = $60;
    break;
   }
  } else {
   if ($34) {
    $61 = (Math_fround(($row>>>0)));
    $62 = (($2) + 12|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    $64 = Math_fround($61 * $63);
    $65 = (Math_fround(($column>>>0)));
    $66 = (($2) + 16|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = Math_fround($65 * $67);
    $69 = (($this) + 8|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = Math_fround(HEAPF32[$this>>2]);
    $89 = $64;$96 = $68;$h0$0 = $12;$h1$0 = $17;$h2$0 = $24;$uInvScale$0 = $70;$vInvScale$0 = $71;
    break;
   } else {
    $72 = (($row) + 1)|0;
    $73 = (Math_fround(($72>>>0)));
    $74 = (($2) + 12|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = Math_fround($73 * $75);
    $77 = (($column) + 1)|0;
    $78 = (Math_fround(($77>>>0)));
    $79 = (($2) + 16|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = Math_fround($78 * $80);
    $82 = (($this) + 8|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = Math_fround(-$83);
    $85 = Math_fround(HEAPF32[$this>>2]);
    $86 = Math_fround(-$85);
    $89 = $76;$96 = $81;$h0$0 = $29;$h1$0 = $24;$h2$0 = $17;$uInvScale$0 = $84;$vInvScale$0 = $86;
    break;
   }
  }
 } while(0);
 $87 = Math_fround(HEAPF32[$point>>2]);
 $88 = Math_fround($87 - $89);
 $90 = (($point) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 - $h0$0);
 $93 = (($point) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 - $96);
 $97 = Math_fround($h1$0 - $h0$0);
 $98 = Math_fround($h2$0 - $h0$0);
 $99 = Math_fround($uInvScale$0 * $97);
 $100 = Math_fround(-$99);
 $101 = Math_fround($vInvScale$0 * $98);
 $102 = Math_fround(-$101);
 $103 = Math_fround($88 * $102);
 $104 = Math_fround($92 + $103);
 $105 = Math_fround($95 * $100);
 $106 = Math_fround($104 + $105);
 $107 = Math_fround($99 * $99);
 $108 = Math_fround($101 * $101);
 $109 = Math_fround($107 + $108);
 $110 = Math_fround($109 + Math_fround(1.0));
 $111 = Math_fround(Math_fround(1.0) / $110);
 $112 = Math_fround($111 * $106);
 $113 = Math_fround($112 * $102);
 $114 = Math_fround($112 * $100);
 $115 = Math_fround($88 - $113);
 $116 = Math_fround($95 - $114);
 $117 = Math_fround($vInvScale$0 * $115);
 $118 = Math_fround($uInvScale$0 * $116);
 $119 = $117 > Math_fround(0.0);
 $120 = $118 > Math_fround(0.0);
 $or$cond = $119 & $120;
 $121 = Math_fround($117 + $118);
 $122 = $121 < Math_fround(1.0);
 $or$cond2 = $or$cond & $122;
 if (!($or$cond2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $123 = Math_fround($92 - $112);
 $124 = Math_fround($89 + $115);
 $125 = Math_fround($h0$0 + $123);
 $126 = Math_fround($96 + $116);
 HEAPF32[$projection>>2] = $124;
 $127 = (($projection) + 4|0);
 HEAPF32[$127>>2] = $125;
 $128 = (($projection) + 8|0);
 HEAPF32[$128>>2] = $126;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Gu15HeightFieldUtil22findClosestPointOnEdgeEjjjjRKNS_6PxVec3ERS2_($this,$edgeIndex,$cell,$row,$column,$point,$closestPoint) {
 $this = $this|0;
 $edgeIndex = $edgeIndex|0;
 $cell = $cell|0;
 $row = $row|0;
 $column = $column|0;
 $point = $point|0;
 $closestPoint = $closestPoint|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0;
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $lengthSquared$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_imul($cell, -3)|0;
 $1 = (($0) + ($edgeIndex))|0;
 do {
  if ((($1|0) == 1)) {
   $31 = (($this) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 36|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34) + ($cell<<2)|0) + 2|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = ($36<<24>>24)<(0);
   $38 = (($this) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 8|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   if ($37) {
    $42 = (($34) + ($cell<<2)|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = (Math_fround(($43<<16>>16)));
    $45 = Math_fround($41 * $44);
    $46 = (($32) + 20|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($cell) + 1)|0;
    $49 = (($48) + ($47))|0;
    $50 = (($34) + ($49<<2)|0);
    $51 = HEAP16[$50>>1]|0;
    $52 = (Math_fround(($51<<16>>16)));
    $53 = Math_fround($41 * $52);
    $54 = (Math_fround(($row>>>0)));
    $55 = (($39) + 12|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = Math_fround($54 * $56);
    $58 = (Math_fround(($column>>>0)));
    $59 = (($39) + 16|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = Math_fround($58 * $60);
    $62 = Math_fround($53 - $45);
    $63 = Math_fround($56 * $56);
    $64 = Math_fround($60 * $60);
    $65 = Math_fround($63 + $64);
    $66 = Math_fround($62 * $62);
    $67 = Math_fround($65 + $66);
    $129 = $57;$133 = $45;$137 = $61;$139 = $56;$141 = $62;$144 = $60;$lengthSquared$0 = $67;
    break;
   } else {
    $68 = (($cell) + 1)|0;
    $69 = (($34) + ($68<<2)|0);
    $70 = HEAP16[$69>>1]|0;
    $71 = (Math_fround(($70<<16>>16)));
    $72 = Math_fround($41 * $71);
    $73 = (($32) + 20|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($74) + ($cell))|0;
    $76 = (($34) + ($75<<2)|0);
    $77 = HEAP16[$76>>1]|0;
    $78 = (Math_fround(($77<<16>>16)));
    $79 = Math_fround($41 * $78);
    $80 = (Math_fround(($row>>>0)));
    $81 = (($39) + 12|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround($80 * $82);
    $84 = (($column) + 1)|0;
    $85 = (Math_fround(($84>>>0)));
    $86 = (($39) + 16|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = Math_fround($85 * $87);
    $89 = Math_fround($79 - $72);
    $90 = Math_fround(-$87);
    $91 = Math_fround($82 * $82);
    $92 = Math_fround($87 * $87);
    $93 = Math_fround($91 + $92);
    $94 = Math_fround($89 * $89);
    $95 = Math_fround($93 + $94);
    $129 = $83;$133 = $72;$137 = $88;$139 = $82;$141 = $89;$144 = $90;$lengthSquared$0 = $95;
    break;
   }
  } else if ((($1|0) == 2)) {
   $96 = (($this) + 16|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($97) + 8|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $100 = (($this) + 12|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (($101) + 36|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (($103) + ($cell<<2)|0);
   $105 = HEAP16[$104>>1]|0;
   $106 = (Math_fround(($105<<16>>16)));
   $107 = Math_fround($99 * $106);
   $108 = (($101) + 20|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = (($109) + ($cell))|0;
   $111 = (($103) + ($110<<2)|0);
   $112 = HEAP16[$111>>1]|0;
   $113 = (Math_fround(($112<<16>>16)));
   $114 = Math_fround($99 * $113);
   $115 = (Math_fround(($row>>>0)));
   $116 = (($97) + 12|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = Math_fround($115 * $117);
   $119 = (Math_fround(($column>>>0)));
   $120 = (($97) + 16|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = Math_fround($119 * $121);
   $123 = Math_fround($114 - $107);
   $124 = Math_fround($117 * $117);
   $125 = Math_fround($123 * $123);
   $126 = Math_fround($124 + $125);
   $129 = $118;$133 = $107;$137 = $122;$139 = $117;$141 = $123;$144 = Math_fround(0.0);$lengthSquared$0 = $126;
  } else if ((($1|0) == 0)) {
   $2 = (($this) + 16|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($3) + 8|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 36|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + ($cell<<2)|0);
   $11 = HEAP16[$10>>1]|0;
   $12 = (Math_fround(($11<<16>>16)));
   $13 = Math_fround($5 * $12);
   $14 = (($cell) + 1)|0;
   $15 = (($9) + ($14<<2)|0);
   $16 = HEAP16[$15>>1]|0;
   $17 = (Math_fround(($16<<16>>16)));
   $18 = Math_fround($5 * $17);
   $19 = (Math_fround(($row>>>0)));
   $20 = (($3) + 12|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = Math_fround($19 * $21);
   $23 = (Math_fround(($column>>>0)));
   $24 = (($3) + 16|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = Math_fround($23 * $25);
   $27 = Math_fround($18 - $13);
   $28 = Math_fround($25 * $25);
   $29 = Math_fround($27 * $27);
   $30 = Math_fround($28 + $29);
   $129 = $22;$133 = $13;$137 = $26;$139 = Math_fround(0.0);$141 = $27;$144 = $25;$lengthSquared$0 = $30;
  } else {
   $129 = Math_fround(0.0);$133 = Math_fround(0.0);$137 = Math_fround(0.0);$139 = Math_fround(0.0);$141 = Math_fround(0.0);$144 = Math_fround(0.0);$lengthSquared$0 = Math_fround(0.0);
  }
 } while(0);
 $127 = Math_fround(HEAPF32[$point>>2]);
 $128 = Math_fround($127 - $129);
 $130 = (($point) + 4|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($131 - $133);
 $134 = (($point) + 8|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($135 - $137);
 $138 = Math_fround($139 * $128);
 $140 = Math_fround($141 * $132);
 $142 = Math_fround($138 + $140);
 $143 = Math_fround($144 * $136);
 $145 = Math_fround($142 + $143);
 $146 = Math_fround($145 / $lengthSquared$0);
 $147 = $146 < Math_fround(0.0);
 if ($147) {
  HEAPF32[$closestPoint>>2] = $129;
  $148 = (($closestPoint) + 4|0);
  HEAPF32[$148>>2] = $133;
  $149 = (($closestPoint) + 8|0);
  HEAPF32[$149>>2] = $137;
  STACKTOP = sp;return (Math_fround($146));
 }
 $150 = $146 > Math_fround(1.0);
 if ($150) {
  $151 = Math_fround($129 + $139);
  $152 = Math_fround($133 + $141);
  $153 = Math_fround($137 + $144);
  HEAPF32[$closestPoint>>2] = $151;
  $154 = (($closestPoint) + 4|0);
  HEAPF32[$154>>2] = $152;
  $155 = (($closestPoint) + 8|0);
  HEAPF32[$155>>2] = $153;
  STACKTOP = sp;return (Math_fround($146));
 } else {
  $156 = Math_fround($139 * $146);
  $157 = Math_fround($141 * $146);
  $158 = Math_fround($144 * $146);
  $159 = Math_fround($129 + $156);
  $160 = Math_fround($133 + $157);
  $161 = Math_fround($137 + $158);
  HEAPF32[$closestPoint>>2] = $159;
  $162 = (($closestPoint) + 4|0);
  HEAPF32[$162>>2] = $160;
  $163 = (($closestPoint) + 8|0);
  HEAPF32[$163>>2] = $161;
  STACKTOP = sp;return (Math_fround($146));
 }
 return Math_fround(0);
}
function __ZNK5physx2Gu15HeightFieldUtil18getVertexFaceIndexEjjj($this,$vertexIndex,$row,$column) {
 $this = $this|0;
 $vertexIndex = $vertexIndex|0;
 $row = $row|0;
 $column = $column|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $edgeIndices = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $edgeIndices = sp;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5physx20getVertexEdgeIndicesERKNS_2Gu11HeightFieldEjjjPNS_8EdgeDataE($1,$vertexIndex,$row,$column,$edgeIndices)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$01 = 0;
 }
 while(1) {
  $6 = (($edgeIndices) + ($i$01<<4)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($edgeIndices) + ($i$01<<4)|0) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($edgeIndices) + ($i$01<<4)|0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($edgeIndices) + ($i$01<<4)|0) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEjjjj($this,$7,$9,$11,$13)|0);
  $15 = ($14|0)==(-1);
  $5 = (($i$01) + 2)|0;
  if (!($15)) {
   $$0 = $14;
   label = 4;
   break;
  }
  $4 = ($5>>>0)<($2>>>0);
  if ($4) {
   $i$01 = $5;
  } else {
   $$0 = -1;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEj($this,$edgeIndex) {
 $this = $this|0;
 $edgeIndex = $edgeIndex|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$sink$i = 0, $$sink$i3 = 0, $$sink$in$i = 0, $$sink$in$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $faceIndices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $faceIndices = sp;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5physx2Gu11HeightField22getEdgeTriangleIndicesEjPj($1,$edgeIndex,$faceIndices)|0);
 $3 = ($2>>>0)>(1);
 $4 = HEAP32[$0>>2]|0;
 $5 = HEAP32[$faceIndices>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = $5 >>> 1;
 $9 = (($4) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 if ($7) {
  $11 = ((($10) + ($8<<2)|0) + 2|0);
  $$sink$in$i = $11;
 } else {
  $12 = ((($10) + ($8<<2)|0) + 3|0);
  $$sink$in$i = $12;
 }
 $$sink$i = HEAP8[$$sink$in$i>>0]|0;
 $13 = $$sink$i & 127;
 $14 = ($13<<24>>24)!=(127);
 if (!($3)) {
  $$1 = $14 ? $5 : -1;
  $$0 = $$1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($14) {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($faceIndices) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 1;
 $18 = ($17|0)==(0);
 $19 = $16 >>> 1;
 if ($18) {
  $20 = ((($10) + ($19<<2)|0) + 2|0);
  $$sink$in$i2 = $20;
  $$sink$i3 = HEAP8[$$sink$in$i2>>0]|0;
  $22 = $$sink$i3 & 127;
  $23 = ($22<<24>>24)==(127);
  $$ = $23 ? -1 : $16;
  STACKTOP = sp;return ($$|0);
 } else {
  $21 = ((($10) + ($19<<2)|0) + 3|0);
  $$sink$in$i2 = $21;
  $$sink$i3 = HEAP8[$$sink$in$i2>>0]|0;
  $22 = $$sink$i3 & 127;
  $23 = ($22<<24>>24)==(127);
  $$ = $23 ? -1 : $16;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEjjjj($this,$edgeIndex,$cell,$row,$column) {
 $this = $this|0;
 $edgeIndex = $edgeIndex|0;
 $cell = $cell|0;
 $row = $row|0;
 $column = $column|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$lobit$i = 0, $$lobit1$i = 0, $$sink$i = 0, $$sink$i3 = 0, $$sink$in$i = 0, $$sink$in$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $8 = 0, $9 = 0, $count$0$i = 0, $count$1$i = 0, $count$2$i = 0, $faceIndices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $faceIndices = sp;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_imul($cell, -3)|0;
 $3 = (($2) + ($edgeIndex))|0;
 if ((($3|0) == 0)) {
  $4 = (($1) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + -1)|0;
  $7 = ($6>>>0)>($column>>>0);
  if ($7) {
   $8 = ($row|0)==(0);
   if ($8) {
    $count$0$i = 0;
   } else {
    $9 = (($cell) - ($5))|0;
    $10 = $9 << 1;
    $11 = (($1) + 36|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($12) + ($9<<2)|0) + 2|0);
    $14 = HEAP8[$13>>0]|0;
    $$lobit$i = ($14&255) >>> 7;
    $15 = $$lobit$i&255;
    $16 = $15 | $10;
    HEAP32[$faceIndices>>2] = $16;
    $count$0$i = 1;
   }
   $17 = (($1) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + -1)|0;
   $20 = ($19>>>0)>($row>>>0);
   if ($20) {
    $21 = $cell << 1;
    $22 = (($1) + 36|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ((($23) + ($cell<<2)|0) + 2|0);
    $25 = HEAP8[$24>>0]|0;
    $$lobit1$i = ($25&255) >>> 7;
    $26 = $$lobit1$i&255;
    $27 = $26 | $21;
    $28 = (($count$0$i) + 1)|0;
    $29 = (($faceIndices) + ($count$0$i<<2)|0);
    HEAP32[$29>>2] = $27;
    $count$2$i = $28;
   } else {
    $count$2$i = $count$0$i;
   }
  } else {
   $count$2$i = 0;
  }
 } else if ((($3|0) == 2)) {
  $41 = (($1) + 16|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + -1)|0;
  $44 = ($43>>>0)>($row>>>0);
  if ($44) {
   $45 = ($column|0)==(0);
   if ($45) {
    $count$1$i = 0;
   } else {
    $46 = $cell << 1;
    $47 = (($46) + -1)|0;
    HEAP32[$faceIndices>>2] = $47;
    $count$1$i = 1;
   }
   $48 = (($1) + 20|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + -1)|0;
   $51 = ($50>>>0)>($column>>>0);
   if ($51) {
    $52 = $cell << 1;
    $53 = (($count$1$i) + 1)|0;
    $54 = (($faceIndices) + ($count$1$i<<2)|0);
    HEAP32[$54>>2] = $52;
    $count$2$i = $53;
   } else {
    $count$2$i = $count$1$i;
   }
  } else {
   $count$2$i = 0;
  }
 } else if ((($3|0) == 1)) {
  $30 = (($1) + 16|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + -1)|0;
  $33 = ($32>>>0)>($row>>>0);
  if ($33) {
   $34 = (($1) + 20|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + -1)|0;
   $37 = ($36>>>0)>($column>>>0);
   if ($37) {
    $38 = $cell << 1;
    HEAP32[$faceIndices>>2] = $38;
    $39 = $38 | 1;
    $40 = (($faceIndices) + 4|0);
    HEAP32[$40>>2] = $39;
    $count$2$i = 2;
   } else {
    $count$2$i = 0;
   }
  } else {
   $count$2$i = 0;
  }
 } else {
  $count$2$i = 0;
 }
 $55 = ($count$2$i>>>0)>(1);
 $56 = HEAP32[$faceIndices>>2]|0;
 $57 = $56 & 1;
 $58 = ($57|0)==(0);
 $59 = $56 >>> 1;
 $60 = (($1) + 36|0);
 $61 = HEAP32[$60>>2]|0;
 if ($58) {
  $62 = ((($61) + ($59<<2)|0) + 2|0);
  $$sink$in$i2 = $62;
 } else {
  $63 = ((($61) + ($59<<2)|0) + 3|0);
  $$sink$in$i2 = $63;
 }
 $$sink$i3 = HEAP8[$$sink$in$i2>>0]|0;
 $64 = $$sink$i3 & 127;
 $65 = ($64<<24>>24)!=(127);
 if (!($55)) {
  $$1 = $65 ? $56 : -1;
  $$0 = $$1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($65) {
  $$0 = $56;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = (($faceIndices) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = $67 & 1;
 $69 = ($68|0)==(0);
 $70 = $67 >>> 1;
 if ($69) {
  $71 = ((($61) + ($70<<2)|0) + 2|0);
  $$sink$in$i = $71;
  $$sink$i = HEAP8[$$sink$in$i>>0]|0;
  $73 = $$sink$i & 127;
  $74 = ($73<<24>>24)==(127);
  $$ = $74 ? -1 : $67;
  STACKTOP = sp;return ($$|0);
 } else {
  $72 = ((($61) + ($70<<2)|0) + 3|0);
  $$sink$in$i = $72;
  $$sink$i = HEAP8[$$sink$in$i>>0]|0;
  $73 = $$sink$i & 127;
  $74 = ($73<<24>>24)==(127);
  $$ = $74 ? -1 : $67;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu15HeightFieldUtil7getEdgeEjjjjRNS_6PxVec3ES3_($this,$edgeIndex,$cell,$row,$column,$origin,$extent) {
 $this = $this|0;
 $edgeIndex = $edgeIndex|0;
 $cell = $cell|0;
 $row = $row|0;
 $column = $column|0;
 $origin = $origin|0;
 $extent = $extent|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0;
 var $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_imul($cell, -3)|0;
 $1 = (($0) + ($edgeIndex))|0;
 if ((($1|0) == 1)) {
  $33 = (($this) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($36) + ($cell<<2)|0) + 2|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)<(0);
  $40 = (($this) + 16|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 8|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  if ($39) {
   $44 = (($36) + ($cell<<2)|0);
   $45 = HEAP16[$44>>1]|0;
   $46 = (Math_fround(($45<<16>>16)));
   $47 = Math_fround($43 * $46);
   $48 = (($34) + 20|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($cell) + 1)|0;
   $51 = (($50) + ($49))|0;
   $52 = (($36) + ($51<<2)|0);
   $53 = HEAP16[$52>>1]|0;
   $54 = (Math_fround(($53<<16>>16)));
   $55 = Math_fround($43 * $54);
   $56 = (Math_fround(($row>>>0)));
   $57 = (($41) + 12|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = Math_fround($56 * $58);
   $60 = (Math_fround(($column>>>0)));
   $61 = (($41) + 16|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = Math_fround($60 * $62);
   HEAPF32[$origin>>2] = $59;
   $64 = (($origin) + 4|0);
   HEAPF32[$64>>2] = $47;
   $65 = (($origin) + 8|0);
   HEAPF32[$65>>2] = $63;
   $66 = Math_fround(HEAPF32[$57>>2]);
   $67 = Math_fround($55 - $47);
   $68 = Math_fround(HEAPF32[$61>>2]);
   HEAPF32[$extent>>2] = $66;
   $69 = (($extent) + 4|0);
   HEAPF32[$69>>2] = $67;
   $70 = (($extent) + 8|0);
   HEAPF32[$70>>2] = $68;
   STACKTOP = sp;return;
  } else {
   $71 = (($cell) + 1)|0;
   $72 = (($36) + ($71<<2)|0);
   $73 = HEAP16[$72>>1]|0;
   $74 = (Math_fround(($73<<16>>16)));
   $75 = Math_fround($43 * $74);
   $76 = (($34) + 20|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = (($77) + ($cell))|0;
   $79 = (($36) + ($78<<2)|0);
   $80 = HEAP16[$79>>1]|0;
   $81 = (Math_fround(($80<<16>>16)));
   $82 = Math_fround($43 * $81);
   $83 = (Math_fround(($row>>>0)));
   $84 = (($41) + 12|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = Math_fround($83 * $85);
   $87 = (($column) + 1)|0;
   $88 = (Math_fround(($87>>>0)));
   $89 = (($41) + 16|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = Math_fround($88 * $90);
   HEAPF32[$origin>>2] = $86;
   $92 = (($origin) + 4|0);
   HEAPF32[$92>>2] = $75;
   $93 = (($origin) + 8|0);
   HEAPF32[$93>>2] = $91;
   $94 = Math_fround(HEAPF32[$84>>2]);
   $95 = Math_fround($82 - $75);
   $96 = Math_fround(HEAPF32[$89>>2]);
   $97 = Math_fround(-$96);
   HEAPF32[$extent>>2] = $94;
   $98 = (($extent) + 4|0);
   HEAPF32[$98>>2] = $95;
   $99 = (($extent) + 8|0);
   HEAPF32[$99>>2] = $97;
   STACKTOP = sp;return;
  }
 } else if ((($1|0) == 0)) {
  $2 = (($this) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 8|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($this) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($cell<<2)|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = (Math_fround(($11<<16>>16)));
  $13 = Math_fround($5 * $12);
  $14 = (($cell) + 1)|0;
  $15 = (($9) + ($14<<2)|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = (Math_fround(($16<<16>>16)));
  $18 = Math_fround($5 * $17);
  $19 = (Math_fround(($row>>>0)));
  $20 = (($3) + 12|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($19 * $21);
  $23 = (Math_fround(($column>>>0)));
  $24 = (($3) + 16|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($23 * $25);
  HEAPF32[$origin>>2] = $22;
  $27 = (($origin) + 4|0);
  HEAPF32[$27>>2] = $13;
  $28 = (($origin) + 8|0);
  HEAPF32[$28>>2] = $26;
  $29 = Math_fround($18 - $13);
  $30 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$extent>>2] = Math_fround(0.0);
  $31 = (($extent) + 4|0);
  HEAPF32[$31>>2] = $29;
  $32 = (($extent) + 8|0);
  HEAPF32[$32>>2] = $30;
  STACKTOP = sp;return;
 } else if ((($1|0) == 2)) {
  $100 = (($this) + 16|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (($101) + 8|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = (($this) + 12|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($105) + 36|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($107) + ($cell<<2)|0);
  $109 = HEAP16[$108>>1]|0;
  $110 = (Math_fround(($109<<16>>16)));
  $111 = Math_fround($103 * $110);
  $112 = (($105) + 20|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($113) + ($cell))|0;
  $115 = (($107) + ($114<<2)|0);
  $116 = HEAP16[$115>>1]|0;
  $117 = (Math_fround(($116<<16>>16)));
  $118 = Math_fround($103 * $117);
  $119 = (Math_fround(($row>>>0)));
  $120 = (($101) + 12|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = Math_fround($119 * $121);
  $123 = (Math_fround(($column>>>0)));
  $124 = (($101) + 16|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = Math_fround($123 * $125);
  HEAPF32[$origin>>2] = $122;
  $127 = (($origin) + 4|0);
  HEAPF32[$127>>2] = $111;
  $128 = (($origin) + 8|0);
  HEAPF32[$128>>2] = $126;
  $129 = Math_fround(HEAPF32[$120>>2]);
  $130 = Math_fround($118 - $111);
  HEAPF32[$extent>>2] = $129;
  $131 = (($extent) + 4|0);
  HEAPF32[$131>>2] = $130;
  $132 = (($extent) + 8|0);
  HEAPF32[$132>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNK5physx2Gu15HeightFieldUtil20overlapAABBTrianglesERKNS_11PxTransformERKNS_9PxBounds3EjPNS0_12EntityReportIjEE($this,$pose,$bounds,$flags,$callback) {
 $this = $this|0;
 $pose = $pose|0;
 $bounds = $bounds|0;
 $flags = $flags|0;
 $callback = $callback|0;
 var $$0 = 0, $$phi$trans$insert42 = 0, $$pre40 = 0, $$pre41 = 0, $$pre43 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0;
 var $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0);
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0;
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $column$010 = 0, $column$010$us = 0, $indexBuffer = 0;
 var $indexBufferUsed$025 = 0, $indexBufferUsed$1$lcssa = 0, $indexBufferUsed$113 = 0, $indexBufferUsed$2 = 0, $indexBufferUsed$2$us = 0, $indexBufferUsed$3 = 0, $indexBufferUsed$4 = 0, $indexBufferUsed$4$us = 0, $indexBufferUsed$5 = 0, $indexBufferUsed$6 = 0, $localBounds = 0, $nb$024 = 0, $nb$1$lcssa = 0, $nb$112 = 0, $nb$2 = 0, $nb$3 = 0, $nb$4 = 0, $nb$444 = 0, $offset$023 = 0, $offset$1$lcssa = 0;
 var $offset$111 = 0, $offset$111$us = 0, $or$cond = 0, $or$cond$us = 0, $or$cond1 = 0, $or$cond1$us = 0, $or$cond2 = 0, $or$cond2$us = 0, $or$cond3 = 0, $or$cond3$us = 0, $or$cond4 = 0, $or$cond4$us = 0, $or$cond45 = 0, $or$cond46 = 0, $or$cond5 = 0, $or$cond5$us = 0, $row$022 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $localBounds = sp + 312|0;
 $0 = sp;
 $1 = sp + 24|0;
 $indexBuffer = sp + 56|0;
 $2 = Math_fround(HEAPF32[$bounds>>2]);
 HEAPF32[$localBounds>>2] = $2;
 $3 = (($localBounds) + 4|0);
 $4 = (($bounds) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$3>>2] = $5;
 $6 = (($localBounds) + 8|0);
 $7 = (($bounds) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$6>>2] = $8;
 $9 = (($localBounds) + 12|0);
 $10 = (($bounds) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$9>>2] = $11;
 $12 = (($localBounds) + 16|0);
 $13 = (($bounds) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$12>>2] = $14;
 $15 = (($localBounds) + 20|0);
 $16 = (($bounds) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$15>>2] = $17;
 $18 = $flags & 1;
 $19 = ($18|0)==(0);
 if ($19) {
  $101 = $14;$103 = $17;$89 = $2;$93 = $5;$97 = $8;$99 = $11;
 } else {
  $20 = (($pose) + 16|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($pose) + 20|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($pose) + 24|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($21 * Math_fround(-2.0));
  $27 = Math_fround($23 * Math_fround(-2.0));
  $28 = Math_fround($25 * Math_fround(-2.0));
  $29 = (($pose) + 12|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($30 * $30);
  $32 = Math_fround($31 + Math_fround(-0.5));
  $33 = Math_fround(HEAPF32[$pose>>2]);
  $34 = Math_fround($26 * $33);
  $35 = (($pose) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($27 * $36);
  $38 = Math_fround($34 + $37);
  $39 = (($pose) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($28 * $40);
  $42 = Math_fround($38 + $41);
  $43 = Math_fround($26 * $32);
  $44 = Math_fround($28 * $36);
  $45 = Math_fround($27 * $40);
  $46 = Math_fround($44 - $45);
  $47 = Math_fround($30 * $46);
  $48 = Math_fround($43 - $47);
  $49 = Math_fround($33 * $42);
  $50 = Math_fround($49 + $48);
  $51 = Math_fround($27 * $32);
  $52 = Math_fround($26 * $40);
  $53 = Math_fround($28 * $33);
  $54 = Math_fround($52 - $53);
  $55 = Math_fround($30 * $54);
  $56 = Math_fround($51 - $55);
  $57 = Math_fround($36 * $42);
  $58 = Math_fround($57 + $56);
  $59 = Math_fround($28 * $32);
  $60 = Math_fround($27 * $33);
  $61 = Math_fround($26 * $36);
  $62 = Math_fround($60 - $61);
  $63 = Math_fround($30 * $62);
  $64 = Math_fround($59 - $63);
  $65 = Math_fround($40 * $42);
  $66 = Math_fround($64 + $65);
  $67 = Math_fround(-$33);
  $68 = Math_fround(-$36);
  $69 = Math_fround(-$40);
  HEAPF32[$1>>2] = $67;
  $70 = (($1) + 4|0);
  HEAPF32[$70>>2] = $68;
  $71 = (($1) + 8|0);
  HEAPF32[$71>>2] = $69;
  $72 = (($1) + 12|0);
  HEAPF32[$72>>2] = $30;
  $73 = (($1) + 16|0);
  HEAPF32[$73>>2] = $50;
  $74 = (($1) + 20|0);
  HEAPF32[$74>>2] = $58;
  $75 = (($1) + 24|0);
  HEAPF32[$75>>2] = $66;
  __ZN5physx9PxBounds313transformFastERKNS_11PxTransformERKS0_($0,$1,$localBounds);
  $76 = Math_fround(HEAPF32[$0>>2]);
  HEAPF32[$localBounds>>2] = $76;
  $77 = (($0) + 4|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  HEAPF32[$3>>2] = $78;
  $79 = (($0) + 8|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  HEAPF32[$6>>2] = $80;
  $81 = (($0) + 12|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  HEAPF32[$9>>2] = $82;
  $83 = (($0) + 16|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$12>>2] = $84;
  $85 = (($0) + 20|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  HEAPF32[$15>>2] = $86;
  $101 = $84;$103 = $86;$89 = $76;$93 = $78;$97 = $80;$99 = $82;
 }
 $87 = Math_fround(HEAPF32[$this>>2]);
 $88 = Math_fround($87 * $89);
 HEAPF32[$localBounds>>2] = $88;
 $90 = (($this) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 * $93);
 HEAPF32[$3>>2] = $92;
 $94 = (($this) + 8|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($95 * $97);
 HEAPF32[$6>>2] = $96;
 $98 = Math_fround($87 * $99);
 HEAPF32[$9>>2] = $98;
 $100 = Math_fround($91 * $101);
 HEAPF32[$12>>2] = $100;
 $102 = Math_fround($95 * $103);
 HEAPF32[$15>>2] = $102;
 $104 = (($this) + 16|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($105) + 12|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = $107 < Math_fround(0.0);
 if ($108) {
  HEAPF32[$localBounds>>2] = $98;
  HEAPF32[$9>>2] = $88;
  $119 = $98;$127 = $88;
 } else {
  $119 = $88;$127 = $98;
 }
 $109 = (($105) + 16|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = $110 < Math_fround(0.0);
 if ($111) {
  HEAPF32[$6>>2] = $102;
  HEAPF32[$15>>2] = $96;
  $125 = $102;$129 = $96;
 } else {
  $125 = $96;$129 = $102;
 }
 $112 = (($this) + 12|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($113) + 16|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (($115) + -1)|0;
 $117 = (Math_fround(($116>>>0)));
 $118 = $119 > $117;
 if ($118) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $120 = (($113) + 20|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = (($121) + -1)|0;
 $123 = (Math_fround(($122>>>0)));
 $124 = $125 > $123;
 $126 = $127 < Math_fround(0.0);
 $or$cond45 = $124 | $126;
 $128 = $129 < Math_fround(0.0);
 $or$cond46 = $or$cond45 | $128;
 if ($or$cond46) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $130 = (Math_fround(Math_floor((Math_fround($119)))));
 $131 = (~~(($130)));
 $132 = (($115) + -2)|0;
 $133 = ($131|0)>(0);
 $134 = $133 ? $131 : 0;
 $135 = ($134|0)>($132|0);
 $136 = $135 ? $132 : $134;
 $137 = (Math_fround(Math_ceil((Math_fround($127)))));
 $138 = (~~(($137)));
 $139 = ($138|0)>(0);
 $140 = $139 ? $138 : 0;
 $141 = ($140|0)>($116|0);
 $142 = $141 ? $116 : $140;
 $143 = (Math_fround(Math_floor((Math_fround($125)))));
 $144 = (~~(($143)));
 $145 = (($121) + -2)|0;
 $146 = ($144|0)>(0);
 $147 = $146 ? $144 : 0;
 $148 = ($147|0)>($145|0);
 $149 = $148 ? $145 : $147;
 $150 = (Math_fround(Math_ceil((Math_fround($129)))));
 $151 = (~~(($150)));
 $152 = ($151|0)>(0);
 $153 = $152 ? $151 : 0;
 $154 = ($153|0)>($122|0);
 $155 = $154 ? $122 : $153;
 $156 = (($155) - ($149))|0;
 $157 = (($142) - ($136))|0;
 $158 = $157 << 1;
 $159 = Math_imul($158, $156)|0;
 $160 = ($159|0)==(0);
 if ($160) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $161 = $flags & 2;
 $162 = ($161|0)==(0);
 $163 = ($136>>>0)<($142>>>0);
 if ($163) {
  $164 = Math_imul($121, $136)|0;
  $165 = (($164) + ($149))|0;
  $166 = ($149>>>0)<($155>>>0);
  $168 = $113;$indexBufferUsed$025 = 0;$nb$024 = 0;$offset$023 = $165;$row$022 = $136;
  L21: while(1) {
   L23: do {
    if ($166) {
     if ($162) {
      $223 = $168;$column$010 = $149;$indexBufferUsed$113 = $indexBufferUsed$025;$nb$112 = $nb$024;$offset$111 = $offset$023;
     } else {
      $column$010$us = $149;$offset$111$us = $offset$023;
      while(1) {
       $167 = (($168) + 36|0);
       $169 = HEAP32[$167>>2]|0;
       $170 = (($169) + ($offset$111$us<<2)|0);
       $171 = HEAP16[$170>>1]|0;
       $172 = (Math_fround(($171<<16>>16)));
       $173 = (($offset$111$us) + 1)|0;
       $174 = (($169) + ($173<<2)|0);
       $175 = HEAP16[$174>>1]|0;
       $176 = (Math_fround(($175<<16>>16)));
       $177 = (($168) + 20|0);
       $178 = HEAP32[$177>>2]|0;
       $179 = (($178) + ($offset$111$us))|0;
       $180 = (($169) + ($179<<2)|0);
       $181 = HEAP16[$180>>1]|0;
       $182 = (Math_fround(($181<<16>>16)));
       $183 = (($179) + 1)|0;
       $184 = (($169) + ($183<<2)|0);
       $185 = HEAP16[$184>>1]|0;
       $186 = (Math_fround(($185<<16>>16)));
       $187 = $100 < $172;
       $188 = $100 < $176;
       $or$cond$us = $187 & $188;
       $189 = $100 < $182;
       $or$cond1$us = $or$cond$us & $189;
       $190 = $100 < $186;
       $or$cond2$us = $or$cond1$us & $190;
       if (!($or$cond2$us)) {
        $191 = $92 > $172;
        $192 = $92 > $176;
        $or$cond3$us = $191 & $192;
        $193 = $92 > $182;
        $or$cond4$us = $or$cond3$us & $193;
        $194 = $92 > $186;
        $or$cond5$us = $or$cond4$us & $194;
        if (!($or$cond5$us)) {
         $195 = ((($169) + ($offset$111$us<<2)|0) + 2|0);
         $196 = HEAP8[$195>>0]|0;
         $197 = $196 & 127;
         $198 = ($197<<24>>24)==(127);
         if (!($198)) {
          label = 17;
          break L21;
         }
         $207 = ((($169) + ($offset$111$us<<2)|0) + 3|0);
         $208 = HEAP8[$207>>0]|0;
         $209 = $208 & 127;
         $210 = ($209<<24>>24)==(127);
         if (!($210)) {
          label = 21;
          break L21;
         }
        }
       }
       $220 = (($column$010$us) + 1)|0;
       $221 = ($220>>>0)<($155>>>0);
       if ($221) {
        $column$010$us = $220;$offset$111$us = $173;
       } else {
        $279 = $168;$indexBufferUsed$1$lcssa = $indexBufferUsed$025;$nb$1$lcssa = $nb$024;$offset$1$lcssa = $173;
        break L23;
       }
      }
     }
     while(1) {
      $222 = (($223) + 36|0);
      $224 = HEAP32[$222>>2]|0;
      $225 = (($224) + ($offset$111<<2)|0);
      $226 = HEAP16[$225>>1]|0;
      $227 = (Math_fround(($226<<16>>16)));
      $228 = (($offset$111) + 1)|0;
      $229 = (($224) + ($228<<2)|0);
      $230 = HEAP16[$229>>1]|0;
      $231 = (Math_fround(($230<<16>>16)));
      $232 = (($223) + 20|0);
      $233 = HEAP32[$232>>2]|0;
      $234 = (($233) + ($offset$111))|0;
      $235 = (($224) + ($234<<2)|0);
      $236 = HEAP16[$235>>1]|0;
      $237 = (Math_fround(($236<<16>>16)));
      $238 = (($234) + 1)|0;
      $239 = (($224) + ($238<<2)|0);
      $240 = HEAP16[$239>>1]|0;
      $241 = (Math_fround(($240<<16>>16)));
      $242 = $100 < $227;
      $243 = $100 < $231;
      $or$cond = $242 & $243;
      $244 = $100 < $237;
      $or$cond1 = $or$cond & $244;
      $245 = $100 < $241;
      $or$cond2 = $or$cond1 & $245;
      if ($or$cond2) {
       $290 = $223;$indexBufferUsed$5 = $indexBufferUsed$113;$nb$3 = $nb$112;
      } else {
       $246 = $92 > $227;
       $247 = $92 > $231;
       $or$cond3 = $246 & $247;
       $248 = $92 > $237;
       $or$cond4 = $or$cond3 & $248;
       $249 = $92 > $241;
       $or$cond5 = $or$cond4 & $249;
       if ($or$cond5) {
        $290 = $223;$indexBufferUsed$5 = $indexBufferUsed$113;$nb$3 = $nb$112;
       } else {
        $250 = ((($224) + ($offset$111<<2)|0) + 2|0);
        $251 = HEAP8[$250>>0]|0;
        $252 = $251 & 127;
        $253 = ($252<<24>>24)==(127);
        if ($253) {
         $263 = $224;$291 = $223;$indexBufferUsed$3 = $indexBufferUsed$113;$nb$2 = $nb$112;
        } else {
         $254 = ($indexBufferUsed$113>>>0)>(63);
         if ($254) {
          $255 = HEAP32[$callback>>2]|0;
          $256 = (($255) + 8|0);
          $257 = HEAP32[$256>>2]|0;
          (FUNCTION_TABLE_iiii[$257 & 2047]($callback,$indexBufferUsed$113,$indexBuffer)|0);
          $indexBufferUsed$2 = 0;
         } else {
          $indexBufferUsed$2 = $indexBufferUsed$113;
         }
         $258 = $offset$111 << 1;
         $259 = (($indexBuffer) + ($indexBufferUsed$2<<2)|0);
         HEAP32[$259>>2] = $258;
         $260 = (($nb$112) + 1)|0;
         $261 = (($indexBufferUsed$2) + 1)|0;
         $$pre41 = HEAP32[$112>>2]|0;
         $$phi$trans$insert42 = (($$pre41) + 36|0);
         $$pre43 = HEAP32[$$phi$trans$insert42>>2]|0;
         $263 = $$pre43;$291 = $$pre41;$indexBufferUsed$3 = $261;$nb$2 = $260;
        }
        $262 = ((($263) + ($offset$111<<2)|0) + 3|0);
        $264 = HEAP8[$262>>0]|0;
        $265 = $264 & 127;
        $266 = ($265<<24>>24)==(127);
        if ($266) {
         $290 = $291;$indexBufferUsed$5 = $indexBufferUsed$3;$nb$3 = $nb$2;
        } else {
         $267 = ($indexBufferUsed$3>>>0)>(63);
         if ($267) {
          $268 = HEAP32[$callback>>2]|0;
          $269 = (($268) + 8|0);
          $270 = HEAP32[$269>>2]|0;
          (FUNCTION_TABLE_iiii[$270 & 2047]($callback,$indexBufferUsed$3,$indexBuffer)|0);
          $indexBufferUsed$4 = 0;
         } else {
          $indexBufferUsed$4 = $indexBufferUsed$3;
         }
         $271 = $offset$111 << 1;
         $272 = $271 | 1;
         $273 = (($indexBuffer) + ($indexBufferUsed$4<<2)|0);
         HEAP32[$273>>2] = $272;
         $274 = (($nb$2) + 1)|0;
         $275 = (($indexBufferUsed$4) + 1)|0;
         $$pre40 = HEAP32[$112>>2]|0;
         $290 = $$pre40;$indexBufferUsed$5 = $275;$nb$3 = $274;
        }
       }
      }
      $276 = (($column$010) + 1)|0;
      $277 = ($276>>>0)<($155>>>0);
      if ($277) {
       $223 = $290;$column$010 = $276;$indexBufferUsed$113 = $indexBufferUsed$5;$nb$112 = $nb$3;$offset$111 = $228;
      } else {
       $279 = $290;$indexBufferUsed$1$lcssa = $indexBufferUsed$5;$nb$1$lcssa = $nb$3;$offset$1$lcssa = $228;
       break;
      }
     }
    } else {
     $279 = $168;$indexBufferUsed$1$lcssa = $indexBufferUsed$025;$nb$1$lcssa = $nb$024;$offset$1$lcssa = $offset$023;
    }
   } while(0);
   $278 = (($279) + 20|0);
   $280 = HEAP32[$278>>2]|0;
   $281 = (($offset$1$lcssa) - ($156))|0;
   $282 = (($281) + ($280))|0;
   $283 = (($row$022) + 1)|0;
   $284 = ($283>>>0)<($142>>>0);
   if ($284) {
    $168 = $279;$indexBufferUsed$025 = $indexBufferUsed$1$lcssa;$nb$024 = $nb$1$lcssa;$offset$023 = $282;$row$022 = $283;
   } else {
    $indexBufferUsed$6 = $indexBufferUsed$1$lcssa;$nb$4 = $nb$1$lcssa;
    break;
   }
  }
  if ((label|0) == 17) {
   $199 = ($indexBufferUsed$025>>>0)>(63);
   if ($199) {
    $200 = HEAP32[$callback>>2]|0;
    $201 = (($200) + 8|0);
    $202 = HEAP32[$201>>2]|0;
    (FUNCTION_TABLE_iiii[$202 & 2047]($callback,$indexBufferUsed$025,$indexBuffer)|0);
    $indexBufferUsed$2$us = 0;
   } else {
    $indexBufferUsed$2$us = $indexBufferUsed$025;
   }
   $203 = $offset$111$us << 1;
   $204 = (($indexBufferUsed$2$us) + 1)|0;
   $205 = (($indexBuffer) + ($indexBufferUsed$2$us<<2)|0);
   HEAP32[$205>>2] = $203;
   $206 = (($nb$024) + 1)|0;
   $indexBufferUsed$6 = $204;$nb$4 = $206;
  }
  else if ((label|0) == 21) {
   $211 = ($indexBufferUsed$025>>>0)>(63);
   if ($211) {
    $212 = HEAP32[$callback>>2]|0;
    $213 = (($212) + 8|0);
    $214 = HEAP32[$213>>2]|0;
    (FUNCTION_TABLE_iiii[$214 & 2047]($callback,$indexBufferUsed$025,$indexBuffer)|0);
    $indexBufferUsed$4$us = 0;
   } else {
    $indexBufferUsed$4$us = $indexBufferUsed$025;
   }
   $215 = $offset$111$us << 1;
   $216 = $215 | 1;
   $217 = (($indexBufferUsed$4$us) + 1)|0;
   $218 = (($indexBuffer) + ($indexBufferUsed$4$us<<2)|0);
   HEAP32[$218>>2] = $216;
   $219 = (($nb$024) + 1)|0;
   $indexBufferUsed$6 = $217;$nb$4 = $219;
  }
  $285 = ($indexBufferUsed$6|0)==(0);
  if ($285) {
   $nb$444 = $nb$4;
  } else {
   $286 = HEAP32[$callback>>2]|0;
   $287 = (($286) + 8|0);
   $288 = HEAP32[$287>>2]|0;
   (FUNCTION_TABLE_iiii[$288 & 2047]($callback,$indexBufferUsed$6,$indexBuffer)|0);
   $nb$444 = $nb$4;
  }
 } else {
  $nb$444 = 0;
 }
 $289 = ($nb$444|0)!=(0);
 $$0 = $289;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($this,$pose,$worldTri,$_vertexIndices,$adjacencyIndices,$triangleIndex,$worldSpaceTranslation,$worldSpaceRotation) {
 $this = $this|0;
 $pose = $pose|0;
 $worldTri = $worldTri|0;
 $_vertexIndices = $_vertexIndices|0;
 $adjacencyIndices = $adjacencyIndices|0;
 $triangleIndex = $triangleIndex|0;
 $worldSpaceTranslation = $worldSpaceTranslation|0;
 $worldSpaceRotation = $worldSpaceRotation|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert49 = 0, $$pre = 0, $$pre50 = 0, $$sink$i = 0, $$sink$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = 0;
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = Math_fround(0);
 var $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0);
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = Math_fround(0), $exitcond = 0, $exitcond45 = 0, $vertexIndices = 0, $vi$035 = 0, $vi1$038 = 0, $wrongHanded$1$off0 = 0, $wrongHanded$2$off032 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vertexIndices = sp;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $3 < Math_fround(0.0);
 $5 = (($1) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $6 < Math_fround(0.0);
 if ($7) {
  $8 = $4 ^ 1;
  $wrongHanded$1$off0 = $8;
 } else {
  $wrongHanded$1$off0 = $4;
 }
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = $12 > Math_fround(0.0);
 if ($13) {
  if ($wrongHanded$1$off0) {
   label = 13;
  } else {
   label = 6;
  }
 } else {
  if ($wrongHanded$1$off0) {
   label = 6;
  } else {
   label = 13;
  }
 }
 do {
  if ((label|0) == 6) {
   $14 = (($vertexIndices) + 8|0);
   $15 = (($vertexIndices) + 4|0);
   $16 = $triangleIndex >>> 1;
   $17 = (($10) + 36|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ((($18) + ($16<<2)|0) + 2|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)<(0);
   $22 = $triangleIndex & 1;
   $23 = ($22|0)==(0);
   if ($21) {
    if ($23) {
     $24 = (($10) + 20|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($25) + ($16))|0;
     HEAP32[$vertexIndices>>2] = $26;
     HEAP32[$14>>2] = $16;
     $27 = (($16) + 1)|0;
     $28 = (($27) + ($25))|0;
     HEAP32[$15>>2] = $28;
     $73 = $26;$74 = $16;$75 = $28;$wrongHanded$2$off032 = 1;
     break;
    } else {
     $29 = (($16) + 1)|0;
     HEAP32[$vertexIndices>>2] = $29;
     $30 = (($10) + 20|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($31) + ($29))|0;
     HEAP32[$14>>2] = $32;
     HEAP32[$15>>2] = $16;
     $73 = $29;$74 = $32;$75 = $16;$wrongHanded$2$off032 = 1;
     break;
    }
   } else {
    if ($23) {
     HEAP32[$vertexIndices>>2] = $16;
     $33 = (($16) + 1)|0;
     HEAP32[$14>>2] = $33;
     $34 = (($10) + 20|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($35) + ($16))|0;
     HEAP32[$15>>2] = $36;
     $73 = $16;$74 = $33;$75 = $36;$wrongHanded$2$off032 = 1;
     break;
    } else {
     $37 = (($10) + 20|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($16) + 1)|0;
     $40 = (($38) + ($39))|0;
     HEAP32[$vertexIndices>>2] = $40;
     $41 = (($38) + ($16))|0;
     HEAP32[$14>>2] = $41;
     HEAP32[$15>>2] = $39;
     $73 = $40;$74 = $41;$75 = $39;$wrongHanded$2$off032 = 1;
     break;
    }
   }
  }
  else if ((label|0) == 13) {
   $42 = (($vertexIndices) + 4|0);
   $43 = (($vertexIndices) + 8|0);
   $44 = $triangleIndex >>> 1;
   $45 = (($10) + 36|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ((($46) + ($44<<2)|0) + 2|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48<<24>>24)<(0);
   $50 = $triangleIndex & 1;
   $51 = ($50|0)==(0);
   if ($49) {
    if ($51) {
     $52 = (($10) + 20|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = (($53) + ($44))|0;
     HEAP32[$vertexIndices>>2] = $54;
     HEAP32[$42>>2] = $44;
     $55 = (($44) + 1)|0;
     $56 = (($55) + ($53))|0;
     HEAP32[$43>>2] = $56;
     $73 = $54;$74 = $56;$75 = $44;$wrongHanded$2$off032 = 0;
     break;
    } else {
     $57 = (($44) + 1)|0;
     HEAP32[$vertexIndices>>2] = $57;
     $58 = (($10) + 20|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = (($59) + ($57))|0;
     HEAP32[$42>>2] = $60;
     HEAP32[$43>>2] = $44;
     $73 = $57;$74 = $44;$75 = $60;$wrongHanded$2$off032 = 0;
     break;
    }
   } else {
    if ($51) {
     HEAP32[$vertexIndices>>2] = $44;
     $61 = (($44) + 1)|0;
     HEAP32[$42>>2] = $61;
     $62 = (($10) + 20|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = (($63) + ($44))|0;
     HEAP32[$43>>2] = $64;
     $73 = $44;$74 = $64;$75 = $61;$wrongHanded$2$off032 = 0;
     break;
    } else {
     $65 = (($10) + 20|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = (($44) + 1)|0;
     $68 = (($66) + ($67))|0;
     HEAP32[$vertexIndices>>2] = $68;
     $69 = (($66) + ($44))|0;
     HEAP32[$42>>2] = $69;
     HEAP32[$43>>2] = $67;
     $73 = $68;$74 = $67;$75 = $69;$wrongHanded$2$off032 = 0;
     break;
    }
   }
  }
 } while(0);
 $70 = ($adjacencyIndices|0)==(0|0);
 do {
  if (!($70)) {
   if ($wrongHanded$2$off032) {
    $71 = (($adjacencyIndices) + 8|0);
    $72 = (($adjacencyIndices) + 4|0);
    __ZNK5physx2Gu11HeightField27getTriangleAdjacencyIndicesEjjjjRjS2_S2_($10,$triangleIndex,$73,$74,$75,$71,$72,$adjacencyIndices);
    break;
   } else {
    $76 = (($adjacencyIndices) + 4|0);
    $77 = (($adjacencyIndices) + 8|0);
    __ZNK5physx2Gu11HeightField27getTriangleAdjacencyIndicesEjjjjRjS2_S2_($10,$triangleIndex,$73,$75,$74,$adjacencyIndices,$76,$77);
    break;
   }
  }
 } while(0);
 $78 = ($_vertexIndices|0)==(0|0);
 if (!($78)) {
  HEAP32[$_vertexIndices>>2] = $73;
  $79 = (($_vertexIndices) + 4|0);
  HEAP32[$79>>2] = $75;
  $80 = (($_vertexIndices) + 8|0);
  HEAP32[$80>>2] = $74;
 }
 $81 = HEAP32[$9>>2]|0;
 $82 = (($81) + 20|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($81) + 36|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = HEAP32[$0>>2]|0;
 $87 = (($86) + 12|0);
 $88 = (($86) + 8|0);
 $89 = (($86) + 16|0);
 L38: do {
  if ($worldSpaceRotation) {
   $90 = (($pose) + 12|0);
   $91 = (($pose) + 4|0);
   $92 = (($pose) + 8|0);
   if (!($worldSpaceTranslation)) {
    $159 = $73;$vi1$038 = 0;
    while(1) {
     $158 = (($159>>>0) / ($83>>>0))&-1;
     $160 = (($159>>>0) % ($83>>>0))&-1;
     $161 = (Math_fround(($158>>>0)));
     $162 = (($85) + ($159<<2)|0);
     $163 = HEAP16[$162>>1]|0;
     $164 = (Math_fround(($163<<16>>16)));
     $165 = (Math_fround(($160>>>0)));
     $166 = Math_fround(HEAPF32[$87>>2]);
     $167 = Math_fround($161 * $166);
     $168 = Math_fround(HEAPF32[$88>>2]);
     $169 = Math_fround($164 * $168);
     $170 = Math_fround(HEAPF32[$89>>2]);
     $171 = Math_fround($165 * $170);
     $172 = Math_fround($167 * Math_fround(2.0));
     $173 = Math_fround($169 * Math_fround(2.0));
     $174 = Math_fround($171 * Math_fround(2.0));
     $175 = Math_fround(HEAPF32[$90>>2]);
     $176 = Math_fround($175 * $175);
     $177 = Math_fround($176 + Math_fround(-0.5));
     $178 = Math_fround(HEAPF32[$pose>>2]);
     $179 = Math_fround($172 * $178);
     $180 = Math_fround(HEAPF32[$91>>2]);
     $181 = Math_fround($173 * $180);
     $182 = Math_fround($179 + $181);
     $183 = Math_fround(HEAPF32[$92>>2]);
     $184 = Math_fround($174 * $183);
     $185 = Math_fround($182 + $184);
     $186 = Math_fround($172 * $177);
     $187 = Math_fround($174 * $180);
     $188 = Math_fround($173 * $183);
     $189 = Math_fround($187 - $188);
     $190 = Math_fround($175 * $189);
     $191 = Math_fround($186 + $190);
     $192 = Math_fround($178 * $185);
     $193 = Math_fround($192 + $191);
     $194 = Math_fround($173 * $177);
     $195 = Math_fround($172 * $183);
     $196 = Math_fround($174 * $178);
     $197 = Math_fround($195 - $196);
     $198 = Math_fround($175 * $197);
     $199 = Math_fround($194 + $198);
     $200 = Math_fround($180 * $185);
     $201 = Math_fround($200 + $199);
     $202 = Math_fround($174 * $177);
     $203 = Math_fround($173 * $178);
     $204 = Math_fround($172 * $180);
     $205 = Math_fround($203 - $204);
     $206 = Math_fround($175 * $205);
     $207 = Math_fround($202 + $206);
     $208 = Math_fround($183 * $185);
     $209 = Math_fround($207 + $208);
     $210 = (($worldTri) + (($vi1$038*12)|0)|0);
     HEAPF32[$210>>2] = $193;
     $211 = ((($worldTri) + (($vi1$038*12)|0)|0) + 4|0);
     HEAPF32[$211>>2] = $201;
     $212 = ((($worldTri) + (($vi1$038*12)|0)|0) + 8|0);
     HEAPF32[$212>>2] = $209;
     $213 = (($vi1$038) + 1)|0;
     $exitcond45 = ($213|0)==(3);
     if ($exitcond45) {
      break L38;
     }
     $$phi$trans$insert49 = (($vertexIndices) + ($213<<2)|0);
     $$pre50 = HEAP32[$$phi$trans$insert49>>2]|0;
     $159 = $$pre50;$vi1$038 = $213;
    }
   }
   $93 = (($pose) + 16|0);
   $94 = (($pose) + 20|0);
   $95 = (($pose) + 24|0);
   $97 = $73;$vi$035 = 0;
   while(1) {
    $96 = (($97>>>0) / ($83>>>0))&-1;
    $98 = (($97>>>0) % ($83>>>0))&-1;
    $99 = (Math_fround(($96>>>0)));
    $100 = (($85) + ($97<<2)|0);
    $101 = HEAP16[$100>>1]|0;
    $102 = (Math_fround(($101<<16>>16)));
    $103 = (Math_fround(($98>>>0)));
    $104 = Math_fround(HEAPF32[$87>>2]);
    $105 = Math_fround($99 * $104);
    $106 = Math_fround(HEAPF32[$88>>2]);
    $107 = Math_fround($102 * $106);
    $108 = Math_fround(HEAPF32[$89>>2]);
    $109 = Math_fround($103 * $108);
    $110 = Math_fround($105 * Math_fround(2.0));
    $111 = Math_fround($107 * Math_fround(2.0));
    $112 = Math_fround($109 * Math_fround(2.0));
    $113 = Math_fround(HEAPF32[$90>>2]);
    $114 = Math_fround($113 * $113);
    $115 = Math_fround($114 + Math_fround(-0.5));
    $116 = Math_fround(HEAPF32[$pose>>2]);
    $117 = Math_fround($110 * $116);
    $118 = Math_fround(HEAPF32[$91>>2]);
    $119 = Math_fround($111 * $118);
    $120 = Math_fround($117 + $119);
    $121 = Math_fround(HEAPF32[$92>>2]);
    $122 = Math_fround($112 * $121);
    $123 = Math_fround($120 + $122);
    $124 = Math_fround($110 * $115);
    $125 = Math_fround($112 * $118);
    $126 = Math_fround($111 * $121);
    $127 = Math_fround($125 - $126);
    $128 = Math_fround($113 * $127);
    $129 = Math_fround($124 + $128);
    $130 = Math_fround($116 * $123);
    $131 = Math_fround($130 + $129);
    $132 = Math_fround($111 * $115);
    $133 = Math_fround($110 * $121);
    $134 = Math_fround($112 * $116);
    $135 = Math_fround($133 - $134);
    $136 = Math_fround($113 * $135);
    $137 = Math_fround($132 + $136);
    $138 = Math_fround($118 * $123);
    $139 = Math_fround($138 + $137);
    $140 = Math_fround($112 * $115);
    $141 = Math_fround($111 * $116);
    $142 = Math_fround($110 * $118);
    $143 = Math_fround($141 - $142);
    $144 = Math_fround($113 * $143);
    $145 = Math_fround($140 + $144);
    $146 = Math_fround($121 * $123);
    $147 = Math_fround($145 + $146);
    $148 = Math_fround(HEAPF32[$93>>2]);
    $149 = Math_fround($148 + $131);
    $150 = Math_fround(HEAPF32[$94>>2]);
    $151 = Math_fround($150 + $139);
    $152 = Math_fround(HEAPF32[$95>>2]);
    $153 = Math_fround($152 + $147);
    $154 = (($worldTri) + (($vi$035*12)|0)|0);
    HEAPF32[$154>>2] = $149;
    $155 = ((($worldTri) + (($vi$035*12)|0)|0) + 4|0);
    HEAPF32[$155>>2] = $151;
    $156 = ((($worldTri) + (($vi$035*12)|0)|0) + 8|0);
    HEAPF32[$156>>2] = $153;
    $157 = (($vi$035) + 1)|0;
    $exitcond = ($157|0)==(3);
    if ($exitcond) {
     break L38;
    }
    $$phi$trans$insert = (($vertexIndices) + ($157<<2)|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $97 = $$pre;$vi$035 = $157;
   }
  } else {
   if ($worldSpaceTranslation) {
    $261 = (($pose) + 16|0);
    $262 = (($pose) + 20|0);
    $263 = (($pose) + 24|0);
    $264 = (($73>>>0) / ($83>>>0))&-1;
    $265 = (($73>>>0) % ($83>>>0))&-1;
    $266 = (Math_fround(($264>>>0)));
    $267 = (($85) + ($73<<2)|0);
    $268 = HEAP16[$267>>1]|0;
    $269 = (Math_fround(($268<<16>>16)));
    $270 = (Math_fround(($265>>>0)));
    $271 = Math_fround(HEAPF32[$87>>2]);
    $272 = Math_fround($266 * $271);
    $273 = Math_fround(HEAPF32[$88>>2]);
    $274 = Math_fround($269 * $273);
    $275 = Math_fround(HEAPF32[$89>>2]);
    $276 = Math_fround($270 * $275);
    $277 = Math_fround(HEAPF32[$261>>2]);
    $278 = Math_fround($272 + $277);
    $279 = Math_fround(HEAPF32[$262>>2]);
    $280 = Math_fround($274 + $279);
    $281 = Math_fround(HEAPF32[$263>>2]);
    $282 = Math_fround($276 + $281);
    HEAPF32[$worldTri>>2] = $278;
    $283 = (($worldTri) + 4|0);
    HEAPF32[$283>>2] = $280;
    $284 = (($worldTri) + 8|0);
    HEAPF32[$284>>2] = $282;
    $285 = (($75>>>0) / ($83>>>0))&-1;
    $286 = (($75>>>0) % ($83>>>0))&-1;
    $287 = (Math_fround(($285>>>0)));
    $288 = (($85) + ($75<<2)|0);
    $289 = HEAP16[$288>>1]|0;
    $290 = (Math_fround(($289<<16>>16)));
    $291 = (Math_fround(($286>>>0)));
    $292 = Math_fround(HEAPF32[$87>>2]);
    $293 = Math_fround($287 * $292);
    $294 = Math_fround(HEAPF32[$88>>2]);
    $295 = Math_fround($290 * $294);
    $296 = Math_fround(HEAPF32[$89>>2]);
    $297 = Math_fround($291 * $296);
    $298 = Math_fround(HEAPF32[$261>>2]);
    $299 = Math_fround($293 + $298);
    $300 = Math_fround(HEAPF32[$262>>2]);
    $301 = Math_fround($295 + $300);
    $302 = Math_fround(HEAPF32[$263>>2]);
    $303 = Math_fround($297 + $302);
    $304 = (($worldTri) + 12|0);
    HEAPF32[$304>>2] = $299;
    $305 = (($worldTri) + 16|0);
    HEAPF32[$305>>2] = $301;
    $306 = (($worldTri) + 20|0);
    HEAPF32[$306>>2] = $303;
    $307 = (($74>>>0) / ($83>>>0))&-1;
    $308 = (($74>>>0) % ($83>>>0))&-1;
    $309 = (Math_fround(($307>>>0)));
    $310 = (($85) + ($74<<2)|0);
    $311 = HEAP16[$310>>1]|0;
    $312 = (Math_fround(($311<<16>>16)));
    $313 = (Math_fround(($308>>>0)));
    $314 = Math_fround(HEAPF32[$87>>2]);
    $315 = Math_fround($309 * $314);
    $316 = Math_fround(HEAPF32[$88>>2]);
    $317 = Math_fround($312 * $316);
    $318 = Math_fround(HEAPF32[$89>>2]);
    $319 = Math_fround($313 * $318);
    $320 = Math_fround(HEAPF32[$261>>2]);
    $321 = Math_fround($315 + $320);
    $322 = Math_fround(HEAPF32[$262>>2]);
    $323 = Math_fround($317 + $322);
    $324 = Math_fround(HEAPF32[$263>>2]);
    $325 = Math_fround($319 + $324);
    $326 = (($worldTri) + 24|0);
    HEAPF32[$326>>2] = $321;
    $327 = (($worldTri) + 28|0);
    HEAPF32[$327>>2] = $323;
    $328 = (($worldTri) + 32|0);
    HEAPF32[$328>>2] = $325;
    break;
   } else {
    $214 = (($73>>>0) / ($83>>>0))&-1;
    $215 = (($73>>>0) % ($83>>>0))&-1;
    $216 = (Math_fround(($214>>>0)));
    $217 = (($85) + ($73<<2)|0);
    $218 = HEAP16[$217>>1]|0;
    $219 = (Math_fround(($218<<16>>16)));
    $220 = (Math_fround(($215>>>0)));
    $221 = Math_fround(HEAPF32[$87>>2]);
    $222 = Math_fround($216 * $221);
    $223 = Math_fround(HEAPF32[$88>>2]);
    $224 = Math_fround($219 * $223);
    $225 = Math_fround(HEAPF32[$89>>2]);
    $226 = Math_fround($220 * $225);
    HEAPF32[$worldTri>>2] = $222;
    $227 = (($worldTri) + 4|0);
    HEAPF32[$227>>2] = $224;
    $228 = (($worldTri) + 8|0);
    HEAPF32[$228>>2] = $226;
    $229 = (($75>>>0) / ($83>>>0))&-1;
    $230 = (($75>>>0) % ($83>>>0))&-1;
    $231 = (Math_fround(($229>>>0)));
    $232 = (($85) + ($75<<2)|0);
    $233 = HEAP16[$232>>1]|0;
    $234 = (Math_fround(($233<<16>>16)));
    $235 = (Math_fround(($230>>>0)));
    $236 = Math_fround(HEAPF32[$87>>2]);
    $237 = Math_fround($231 * $236);
    $238 = Math_fround(HEAPF32[$88>>2]);
    $239 = Math_fround($234 * $238);
    $240 = Math_fround(HEAPF32[$89>>2]);
    $241 = Math_fround($235 * $240);
    $242 = (($worldTri) + 12|0);
    HEAPF32[$242>>2] = $237;
    $243 = (($worldTri) + 16|0);
    HEAPF32[$243>>2] = $239;
    $244 = (($worldTri) + 20|0);
    HEAPF32[$244>>2] = $241;
    $245 = (($74>>>0) / ($83>>>0))&-1;
    $246 = (($74>>>0) % ($83>>>0))&-1;
    $247 = (Math_fround(($245>>>0)));
    $248 = (($85) + ($74<<2)|0);
    $249 = HEAP16[$248>>1]|0;
    $250 = (Math_fround(($249<<16>>16)));
    $251 = (Math_fround(($246>>>0)));
    $252 = Math_fround(HEAPF32[$87>>2]);
    $253 = Math_fround($247 * $252);
    $254 = Math_fround(HEAPF32[$88>>2]);
    $255 = Math_fround($250 * $254);
    $256 = Math_fround(HEAPF32[$89>>2]);
    $257 = Math_fround($251 * $256);
    $258 = (($worldTri) + 24|0);
    HEAPF32[$258>>2] = $253;
    $259 = (($worldTri) + 28|0);
    HEAPF32[$259>>2] = $255;
    $260 = (($worldTri) + 32|0);
    HEAPF32[$260>>2] = $257;
    break;
   }
  }
 } while(0);
 $329 = $triangleIndex & 1;
 $330 = ($329|0)==(0);
 $331 = $triangleIndex >>> 1;
 if ($330) {
  $332 = ((($85) + ($331<<2)|0) + 2|0);
  $$sink$in$i = $332;
  $$sink$i = HEAP8[$$sink$in$i>>0]|0;
  $334 = $$sink$i & 127;
  $335 = ($334<<24>>24)!=(127);
  $336 = $335&1;
  STACKTOP = sp;return ($336|0);
 } else {
  $333 = ((($85) + ($331<<2)|0) + 3|0);
  $$sink$in$i = $333;
  $$sink$i = HEAP8[$$sink$in$i>>0]|0;
  $334 = $$sink$i & 127;
  $335 = ($334<<24>>24)!=(127);
  $336 = $335&1;
  STACKTOP = sp;return ($336|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu11HeightField27getTriangleAdjacencyIndicesEjjjjRjS2_S2_($this,$triangleIndex,$vertexIndex0,$vertexIndex1,$vertexIndex2,$adjacencyIndex0,$adjacencyIndex1,$adjacencyIndex2) {
 $this = $this|0;
 $triangleIndex = $triangleIndex|0;
 $vertexIndex0 = $vertexIndex0|0;
 $vertexIndex1 = $vertexIndex1|0;
 $vertexIndex2 = $vertexIndex2|0;
 $adjacencyIndex0 = $adjacencyIndex0|0;
 $adjacencyIndex1 = $adjacencyIndex1|0;
 $adjacencyIndex2 = $adjacencyIndex2|0;
 var $$pre = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $triangleIndex >>> 1;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2) + ($0<<2)|0) + 2|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)<(0);
 $6 = $triangleIndex & 1;
 $7 = ($6|0)==(0);
 HEAP32[$adjacencyIndex0>>2] = -1;
 if ($5) {
  if ($7) {
   $8 = (($triangleIndex) + 1)|0;
   HEAP32[$adjacencyIndex1>>2] = $8;
   HEAP32[$adjacencyIndex2>>2] = -1;
   $9 = (($this) + 20|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($0>>>0) % ($10>>>0))&-1;
   $12 = ($11|0)==(0);
   if ($12) {
    $15 = $10;
   } else {
    $13 = (($triangleIndex) + -1)|0;
    HEAP32[$adjacencyIndex0>>2] = $13;
    $$pre = HEAP32[$9>>2]|0;
    $15 = $$pre;
   }
   $14 = (($0>>>0) / ($15>>>0))&-1;
   $16 = (($this) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + -2)|0;
   $19 = ($14|0)==($18|0);
   if ($19) {
    STACKTOP = sp;return;
   }
   $20 = (($15) + ($0))|0;
   $21 = $20 << 1;
   $22 = $21 | 1;
   HEAP32[$adjacencyIndex2>>2] = $22;
   STACKTOP = sp;return;
  } else {
   $23 = (($triangleIndex) + -1)|0;
   HEAP32[$adjacencyIndex1>>2] = $23;
   HEAP32[$adjacencyIndex2>>2] = -1;
   $24 = (($this) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($0>>>0) % ($25>>>0))&-1;
   $27 = (($25) + -2)|0;
   $28 = ($26>>>0)<($27>>>0);
   if ($28) {
    $29 = (($triangleIndex) + 1)|0;
    HEAP32[$adjacencyIndex0>>2] = $29;
    $$pre1 = HEAP32[$24>>2]|0;
    $31 = $$pre1;
   } else {
    $31 = $25;
   }
   $30 = (($31) + -1)|0;
   $32 = ($0>>>0)<($30>>>0);
   if ($32) {
    STACKTOP = sp;return;
   }
   $33 = (($0) - ($31))|0;
   $34 = $33 << 1;
   HEAP32[$adjacencyIndex2>>2] = $34;
   STACKTOP = sp;return;
  }
 } else {
  if ($7) {
   $35 = (($triangleIndex) + 1)|0;
   HEAP32[$adjacencyIndex1>>2] = $35;
   HEAP32[$adjacencyIndex2>>2] = -1;
   $36 = (($this) + 20|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + -1)|0;
   $39 = ($0>>>0)<($38>>>0);
   if ($39) {
    $44 = $37;
   } else {
    $40 = (($0) - ($37))|0;
    $41 = $40 << 1;
    $42 = $41 | 1;
    HEAP32[$adjacencyIndex0>>2] = $42;
    $$pre2 = HEAP32[$36>>2]|0;
    $44 = $$pre2;
   }
   $43 = (($0>>>0) % ($44>>>0))&-1;
   $45 = ($43|0)==(0);
   if ($45) {
    STACKTOP = sp;return;
   }
   $46 = (($triangleIndex) + -1)|0;
   HEAP32[$adjacencyIndex2>>2] = $46;
   STACKTOP = sp;return;
  } else {
   $47 = (($triangleIndex) + -1)|0;
   HEAP32[$adjacencyIndex1>>2] = $47;
   HEAP32[$adjacencyIndex2>>2] = -1;
   $48 = (($this) + 20|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($0>>>0) / ($49>>>0))&-1;
   $51 = (($this) + 16|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + -2)|0;
   $54 = ($50|0)==($53|0);
   if ($54) {
    $58 = $49;
   } else {
    $55 = (($49) + ($0))|0;
    $56 = $55 << 1;
    HEAP32[$adjacencyIndex0>>2] = $56;
    $$pre3 = HEAP32[$48>>2]|0;
    $58 = $$pre3;
   }
   $57 = (($0>>>0) % ($58>>>0))&-1;
   $59 = (($58) + -2)|0;
   $60 = ($57>>>0)<($59>>>0);
   if (!($60)) {
    STACKTOP = sp;return;
   }
   $61 = (($triangleIndex) + 1)|0;
   HEAP32[$adjacencyIndex2>>2] = $61;
   STACKTOP = sp;return;
  }
 }
}
function __ZN5physx2Gu26intersectHeightFieldSphereERKNS0_15HeightFieldUtilERKNS0_6SphereE($hfUtil,$sphereInHfShape) {
 $hfUtil = $hfUtil|0;
 $sphereInHfShape = $sphereInHfShape|0;
 var $$3 = 0, $$pre = Math_fround(0), $$pre13 = Math_fround(0), $$pre14 = Math_fround(0), $$pre15 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0);
 var $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0;
 var $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0);
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $c$07$us = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i3 = Math_fround(0), $fracX$i$i = 0, $fracZ$i$i = 0, $not$ = 0, $or$cond = 0, $or$cond$i = 0;
 var $or$cond$i2 = 0, $or$cond1$i = 0, $or$cond5 = 0, $pi$06$us = 0, $r$011 = 0, $r$011$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $fracX$i$i = sp + 16|0;
 $fracZ$i$i = sp;
 $0 = sp + 4|0;
 $1 = (($hfUtil) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$sphereInHfShape>>2]);
 $4 = (($sphereInHfShape) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$hfUtil>>2]);
 $7 = Math_fround($3 * $6);
 $8 = (($hfUtil) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($5 * $9);
 $11 = !($7 >= Math_fround(0.0));
 $12 = !($10 >= Math_fround(0.0));
 $or$cond$i = $11 | $12;
 do {
  if ($or$cond$i) {
   $48 = $6;$49 = $3;$52 = $9;$53 = $5;
  } else {
   $13 = (($2) + 24|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = Math_fround($14 + Math_fround(1.0));
   $16 = $7 < $15;
   if ($16) {
    $17 = (($2) + 28|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = Math_fround($18 + Math_fround(1.0));
    $20 = $10 < $19;
    if ($20) {
     $21 = (($hfUtil) + 16|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($22) + 8|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $25 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($2,$7,$10,$fracX$i$i,$fracZ$i$i)|0);
     $26 = Math_fround(HEAPF32[$fracX$i$i>>2]);
     $27 = Math_fround(HEAPF32[$fracZ$i$i>>2]);
     $28 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($2,$25,$26,$27)));
     $29 = Math_fround($24 * $28);
     $30 = (($sphereInHfShape) + 4|0);
     $31 = Math_fround(HEAPF32[$30>>2]);
     $32 = Math_fround($31 - $29);
     $33 = (($2) + 40|0);
     $34 = Math_fround(HEAPF32[$33>>2]);
     $35 = !($34 <= Math_fround(0.0));
     $36 = !($32 <= Math_fround(0.0));
     $or$cond$i2 = $35 | $36;
     $37 = !($34 <= $32);
     $or$cond1$i = $or$cond$i2 | $37;
     if ($or$cond1$i) {
      $38 = $34 > Math_fround(0.0);
      $39 = $32 > Math_fround(-0.0);
      $or$cond = $38 & $39;
      $40 = $34 > $32;
      $or$cond5 = $or$cond & $40;
      if (!($or$cond5)) {
       $$pre = Math_fround(HEAPF32[$sphereInHfShape>>2]);
       $$pre13 = Math_fround(HEAPF32[$hfUtil>>2]);
       $$pre14 = Math_fround(HEAPF32[$4>>2]);
       $$pre15 = Math_fround(HEAPF32[$8>>2]);
       $48 = $$pre13;$49 = $$pre;$52 = $$pre15;$53 = $$pre14;
       break;
      }
     }
     $41 = Math_fround(HEAPF32[$sphereInHfShape>>2]);
     $42 = Math_fround(HEAPF32[$4>>2]);
     $43 = (__ZNK5physx2Gu15HeightFieldUtil24getFaceIndexAtShapePointEff($hfUtil,$41,$42)|0);
     $not$ = ($43|0)!=(-1);
     $$3 = $not$;
     STACKTOP = sp;return ($$3|0);
    } else {
     $48 = $6;$49 = $3;$52 = $9;$53 = $5;
    }
   } else {
    $48 = $6;$49 = $3;$52 = $9;$53 = $5;
   }
  }
 } while(0);
 $44 = (($sphereInHfShape) + 12|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 * $45);
 $47 = Math_fround($49 * $48);
 $50 = (($sphereInHfShape) + 4|0);
 $51 = Math_fround($53 * $52);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($48)))));
 $54 = Math_fround($45 * $fabsf$i$i);
 $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($52)))));
 $55 = Math_fround($45 * $fabsf$i$i3);
 $56 = Math_fround($47 - $54);
 $57 = (Math_fround(Math_floor((Math_fround($56)))));
 $58 = (~~(($57)));
 $59 = (($2) + 16|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + -2)|0;
 $62 = ($58|0)>(0);
 $63 = $62 ? $58 : 0;
 $64 = ($63|0)>($61|0);
 $65 = $64 ? $61 : $63;
 $66 = Math_fround($47 + $54);
 $67 = (Math_fround(Math_ceil((Math_fround($66)))));
 $68 = (~~(($67)));
 $69 = (($60) + -1)|0;
 $70 = ($68|0)>(0);
 $71 = $70 ? $68 : 0;
 $72 = ($71|0)>($69|0);
 $73 = $72 ? $69 : $71;
 $74 = Math_fround($51 - $55);
 $75 = (Math_fround(Math_floor((Math_fround($74)))));
 $76 = (~~(($75)));
 $77 = (($2) + 20|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + -2)|0;
 $80 = ($76|0)>(0);
 $81 = $80 ? $76 : 0;
 $82 = ($81|0)>($79|0);
 $83 = $82 ? $79 : $81;
 $84 = Math_fround($51 + $55);
 $85 = (Math_fround(Math_ceil((Math_fround($84)))));
 $86 = (~~(($85)));
 $87 = (($78) + -1)|0;
 $88 = ($86|0)>(0);
 $89 = $88 ? $86 : 0;
 $90 = ($89|0)>($87|0);
 $91 = $90 ? $87 : $89;
 $92 = ($65>>>0)<($73>>>0);
 if (!($92)) {
  $$3 = 0;
  STACKTOP = sp;return ($$3|0);
 }
 $93 = ($83>>>0)<($91>>>0);
 $94 = (($0) + 4|0);
 $95 = (($0) + 8|0);
 if ($93) {
  $r$011$us = $65;
 } else {
  $r$011 = $65;
  while(1) {
   $125 = (($r$011) + 1)|0;
   $126 = ($125>>>0)<($73>>>0);
   if ($126) {
    $r$011 = $125;
   } else {
    $$3 = 0;
    break;
   }
  }
  STACKTOP = sp;return ($$3|0);
 }
 L18: while(1) {
  $c$07$us = $83;
  while(1) {
   $98 = Math_fround(HEAPF32[$sphereInHfShape>>2]);
   HEAPF32[$0>>2] = $98;
   $99 = Math_fround(HEAPF32[$50>>2]);
   HEAPF32[$94>>2] = $99;
   $100 = Math_fround(HEAPF32[$4>>2]);
   HEAPF32[$95>>2] = $100;
   $101 = (__ZNK5physx2Gu15HeightFieldUtil23findClosestPointsOnCellEjjNS_6PxVec3EPS2_Pjbbb($hfUtil,$r$011$us,$c$07$us,$0,$fracX$i$i,0,1,1,1)|0);
   $102 = ($101|0)==(0);
   if (!($102)) {
    $110 = Math_fround(HEAPF32[$sphereInHfShape>>2]);
    $114 = Math_fround(HEAPF32[$50>>2]);
    $118 = Math_fround(HEAPF32[$4>>2]);
    $pi$06$us = 0;
    while(1) {
     $107 = (($fracX$i$i) + (($pi$06$us*12)|0)|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     $109 = Math_fround($110 - $108);
     $111 = ((($fracX$i$i) + (($pi$06$us*12)|0)|0) + 4|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = Math_fround($114 - $112);
     $115 = ((($fracX$i$i) + (($pi$06$us*12)|0)|0) + 8|0);
     $116 = Math_fround(HEAPF32[$115>>2]);
     $117 = Math_fround($118 - $116);
     $119 = Math_fround($109 * $109);
     $120 = Math_fround($113 * $113);
     $121 = Math_fround($119 + $120);
     $122 = Math_fround($117 * $117);
     $123 = Math_fround($121 + $122);
     $124 = $123 > $46;
     $104 = (($pi$06$us) + 1)|0;
     if (!($124)) {
      $$3 = 1;
      label = 18;
      break L18;
     }
     $103 = ($104>>>0)<($101>>>0);
     if ($103) {
      $pi$06$us = $104;
     } else {
      break;
     }
    }
   }
   $105 = (($c$07$us) + 1)|0;
   $106 = ($105>>>0)<($91>>>0);
   if ($106) {
    $c$07$us = $105;
   } else {
    break;
   }
  }
  $96 = (($r$011$us) + 1)|0;
  $97 = ($96>>>0)<($73>>>0);
  if ($97) {
   $r$011$us = $96;
  } else {
   $$3 = 0;
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return ($$3|0);
 }
 return 0|0;
}
function __ZN5physx2Gu27intersectHeightFieldCapsuleERKNS0_15HeightFieldUtilERKNS0_7CapsuleE($hfUtil,$capsuleInHfShape) {
 $hfUtil = $hfUtil|0;
 $capsuleInHfShape = $capsuleInHfShape|0;
 var $$5 = 0, $$absMaxRow$0 = 0, $$absMinRow$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert73 = 0, $$pre = Math_fround(0), $$pre71 = Math_fround(0), $$pre72 = Math_fround(0), $$pre74 = Math_fround(0), $$pre75 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0;
 var $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0);
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0);
 var $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0);
 var $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $absMaxColumn$049 = 0, $absMaxColumn$1 = 0, $absMaxRow$051 = 0, $absMinColumn$050 = 0, $absMinColumn$1 = 0, $absMinRow$052 = 0, $c$027 = 0, $column$010 = 0, $direction = 0, $ei$09 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i3 = Math_fround(0), $fracX$i$i = 0;
 var $fracZ$i$i = 0, $i$048 = 0, $or$cond = 0, $or$cond$i2 = 0, $or$cond$i4 = 0, $or$cond1$i = 0, $or$cond7 = 0, $or$cond76 = 0, $or$cond8$us = 0, $origin = 0, $pi$018 = 0, $pi$018$us = 0, $pi$018$us22 = 0, $r$030 = 0, $row$015 = 0, $s = 0, $t = 0, $verticesInHfShape = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $fracX$i$i = sp + 108|0;
 $fracZ$i$i = sp + 96|0;
 $verticesInHfShape = sp + 72|0;
 $0 = sp + 60|0;
 $origin = sp + 48|0;
 $direction = sp + 8|0;
 $s = sp + 4|0;
 $t = sp;
 $1 = sp + 24|0;
 $2 = (($hfUtil) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($capsuleInHfShape) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$hfUtil>>2]);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($6)))));
 $7 = (($hfUtil) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($8)))));
 $9 = Math_fround($5 * $fabsf$i$i);
 $10 = Math_fround($5 * $fabsf$i$i3);
 $11 = Math_fround(HEAPF32[$capsuleInHfShape>>2]);
 HEAPF32[$verticesInHfShape>>2] = $11;
 $12 = (($capsuleInHfShape) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($verticesInHfShape) + 4|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($capsuleInHfShape) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($verticesInHfShape) + 8|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($capsuleInHfShape) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($verticesInHfShape) + 12|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($capsuleInHfShape) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($verticesInHfShape) + 16|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($capsuleInHfShape) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($verticesInHfShape) + 20|0);
 HEAPF32[$26>>2] = $25;
 $27 = Math_fround($5 * $5);
 $28 = (($3) + 16|0);
 $29 = (($3) + 20|0);
 $30 = (($hfUtil) + 16|0);
 $31 = (($3) + 40|0);
 $32 = (($0) + 4|0);
 $33 = (($0) + 8|0);
 $50 = $6;$51 = $11;$54 = $8;$55 = $16;$absMaxColumn$049 = 0;$absMaxRow$051 = 0;$absMinColumn$050 = -1;$absMinRow$052 = -1;$i$048 = 0;
 L1: while(1) {
  $49 = Math_fround($51 * $50);
  $52 = ((($verticesInHfShape) + (($i$048*12)|0)|0) + 4|0);
  $53 = Math_fround($55 * $54);
  $56 = Math_fround($49 - $9);
  $57 = (Math_fround(Math_floor((Math_fround($56)))));
  $58 = (~~(($57)));
  $59 = HEAP32[$28>>2]|0;
  $60 = (($59) + -2)|0;
  $61 = ($58|0)>(0);
  $62 = $61 ? $58 : 0;
  $63 = ($62|0)>($60|0);
  $64 = $63 ? $60 : $62;
  $65 = Math_fround($9 + $49);
  $66 = (Math_fround(Math_ceil((Math_fround($65)))));
  $67 = (~~(($66)));
  $68 = (($59) + -1)|0;
  $69 = ($67|0)>(0);
  $70 = $69 ? $67 : 0;
  $71 = ($70|0)>($68|0);
  $72 = $71 ? $68 : $70;
  $73 = Math_fround($53 - $10);
  $74 = (Math_fround(Math_floor((Math_fround($73)))));
  $75 = (~~(($74)));
  $76 = HEAP32[$29>>2]|0;
  $77 = (($76) + -2)|0;
  $78 = ($75|0)>(0);
  $79 = $78 ? $75 : 0;
  $80 = ($79|0)>($77|0);
  $81 = $80 ? $77 : $79;
  $82 = Math_fround($10 + $53);
  $83 = (Math_fround(Math_ceil((Math_fround($82)))));
  $84 = (~~(($83)));
  $85 = (($76) + -1)|0;
  $86 = ($84|0)>(0);
  $87 = $86 ? $84 : 0;
  $88 = ($87|0)>($85|0);
  $89 = $88 ? $85 : $87;
  $90 = ($64>>>0)<($absMinRow$052>>>0);
  $$absMinRow$0 = $90 ? $64 : $absMinRow$052;
  $91 = ($81>>>0)<($absMinColumn$050>>>0);
  $absMinColumn$1 = $91 ? $81 : $absMinColumn$050;
  $92 = ($72>>>0)>($absMaxRow$051>>>0);
  $$absMaxRow$0 = $92 ? $72 : $absMaxRow$051;
  $93 = ($89>>>0)>($absMaxColumn$049>>>0);
  $absMaxColumn$1 = $93 ? $89 : $absMaxColumn$049;
  $94 = !($49 >= Math_fround(0.0));
  $95 = !($53 >= Math_fround(0.0));
  $or$cond$i4 = $94 | $95;
  do {
   if ($or$cond$i4) {
    label = 9;
   } else {
    $96 = HEAP32[$2>>2]|0;
    $97 = (($96) + 24|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = Math_fround($98 + Math_fround(1.0));
    $100 = $49 < $99;
    if ($100) {
     $101 = (($96) + 28|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = Math_fround($102 + Math_fround(1.0));
     $104 = $53 < $103;
     if ($104) {
      $105 = HEAP32[$30>>2]|0;
      $106 = (($105) + 8|0);
      $107 = Math_fround(HEAPF32[$106>>2]);
      $108 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($96,$49,$53,$fracX$i$i,$fracZ$i$i)|0);
      $109 = Math_fround(HEAPF32[$fracX$i$i>>2]);
      $110 = Math_fround(HEAPF32[$fracZ$i$i>>2]);
      $111 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($96,$108,$109,$110)));
      $112 = Math_fround($107 * $111);
      $113 = Math_fround(HEAPF32[$52>>2]);
      $114 = Math_fround($113 - $112);
      $115 = Math_fround(HEAPF32[$31>>2]);
      $116 = !($115 <= Math_fround(0.0));
      $117 = !($114 <= Math_fround(0.0));
      $or$cond$i2 = $116 | $117;
      $118 = !($115 <= $114);
      $or$cond1$i = $or$cond$i2 | $118;
      if ($or$cond1$i) {
       $119 = $115 > Math_fround(0.0);
       $120 = $114 > Math_fround(-0.0);
       $or$cond = $119 & $120;
       $121 = $115 > $114;
       $or$cond7 = $or$cond & $121;
       if (!($or$cond7)) {
        label = 9;
        break;
       }
      }
      $124 = (__ZNK5physx2Gu15HeightFieldUtil24getFaceIndexAtShapePointEff($hfUtil,$51,$55)|0);
      $125 = ($124|0)==(-1);
      if (!($125)) {
       $$5 = 1;
       label = 36;
       break L1;
      }
     } else {
      label = 9;
     }
    } else {
     label = 9;
    }
   }
  } while(0);
  if ((label|0) == 9) {
   label = 0;
   $122 = ($64>>>0)<($72>>>0);
   if ($122) {
    $123 = ($81>>>0)<($89>>>0);
    $r$030 = $64;
    while(1) {
     if ($123) {
      $$pre = Math_fround(HEAPF32[$52>>2]);
      $c$027 = $81;
      while(1) {
       HEAPF32[$0>>2] = $51;
       HEAPF32[$32>>2] = $$pre;
       HEAPF32[$33>>2] = $55;
       $126 = (__ZNK5physx2Gu15HeightFieldUtil23findClosestPointsOnCellEjjNS_6PxVec3EPS2_Pjbbb($hfUtil,$r$030,$c$027,$0,$fracX$i$i,0,1,1,1)|0);
       $127 = ($126|0)==(0);
       L19: do {
        if (!($127)) {
         $128 = Math_fround(HEAPF32[$31>>2]);
         $129 = !($128 <= Math_fround(0.0));
         $130 = $128 > Math_fround(0.0);
         if (!($129)) {
          $pi$018$us = 0;
          while(1) {
           $131 = (($fracX$i$i) + (($pi$018$us*12)|0)|0);
           $132 = Math_fround(HEAPF32[$131>>2]);
           $133 = Math_fround($51 - $132);
           $134 = ((($fracX$i$i) + (($pi$018$us*12)|0)|0) + 4|0);
           $135 = Math_fround(HEAPF32[$134>>2]);
           $136 = Math_fround($$pre - $135);
           $137 = ((($fracX$i$i) + (($pi$018$us*12)|0)|0) + 8|0);
           $138 = Math_fround(HEAPF32[$137>>2]);
           $139 = Math_fround($55 - $138);
           $140 = $136 > Math_fround(0.0);
           $141 = $136 < Math_fround(0.0);
           $or$cond8$us = $130 & $141;
           $or$cond76 = $140 | $or$cond8$us;
           if ($or$cond76) {
            $142 = Math_fround($133 * $133);
            $143 = Math_fround($136 * $136);
            $144 = Math_fround($142 + $143);
            $145 = Math_fround($139 * $139);
            $146 = Math_fround($144 + $145);
            $147 = $146 > $27;
            if (!($147)) {
             $$5 = 1;
             label = 36;
             break L1;
            }
           }
           $148 = (($pi$018$us) + 1)|0;
           $149 = ($148>>>0)<($126>>>0);
           if ($149) {
            $pi$018$us = $148;
           } else {
            break L19;
           }
          }
         }
         if ($130) {
          $pi$018$us22 = 0;
         } else {
          $pi$018 = 0;
          while(1) {
           $168 = (($pi$018) + 1)|0;
           $169 = ($168>>>0)<($126>>>0);
           if ($169) {
            $pi$018 = $168;
           } else {
            break L19;
           }
          }
         }
         while(1) {
          $150 = (($fracX$i$i) + (($pi$018$us22*12)|0)|0);
          $151 = Math_fround(HEAPF32[$150>>2]);
          $152 = Math_fround($51 - $151);
          $153 = ((($fracX$i$i) + (($pi$018$us22*12)|0)|0) + 4|0);
          $154 = Math_fround(HEAPF32[$153>>2]);
          $155 = Math_fround($$pre - $154);
          $156 = ((($fracX$i$i) + (($pi$018$us22*12)|0)|0) + 8|0);
          $157 = Math_fround(HEAPF32[$156>>2]);
          $158 = Math_fround($55 - $157);
          $159 = $155 < Math_fround(0.0);
          if ($159) {
           $160 = Math_fround($152 * $152);
           $161 = Math_fround($155 * $155);
           $162 = Math_fround($160 + $161);
           $163 = Math_fround($158 * $158);
           $164 = Math_fround($162 + $163);
           $165 = $164 > $27;
           if (!($165)) {
            $$5 = 1;
            label = 36;
            break L1;
           }
          }
          $166 = (($pi$018$us22) + 1)|0;
          $167 = ($166>>>0)<($126>>>0);
          if ($167) {
           $pi$018$us22 = $166;
          } else {
           break;
          }
         }
        }
       } while(0);
       $170 = (($c$027) + 1)|0;
       $171 = ($170>>>0)<($89>>>0);
       if ($171) {
        $c$027 = $170;
       } else {
        break;
       }
      }
     }
     $172 = (($r$030) + 1)|0;
     $173 = ($172>>>0)<($72>>>0);
     if ($173) {
      $r$030 = $172;
     } else {
      break;
     }
    }
   }
  }
  $174 = (($i$048) + 1)|0;
  $175 = ($174>>>0)<(2);
  if (!($175)) {
   label = 2;
   break;
  }
  $$phi$trans$insert = (($verticesInHfShape) + (($174*12)|0)|0);
  $$pre71 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$pre72 = Math_fround(HEAPF32[$hfUtil>>2]);
  $$phi$trans$insert73 = ((($verticesInHfShape) + (($174*12)|0)|0) + 8|0);
  $$pre74 = Math_fround(HEAPF32[$$phi$trans$insert73>>2]);
  $$pre75 = Math_fround(HEAPF32[$7>>2]);
  $50 = $$pre72;$51 = $$pre71;$54 = $$pre75;$55 = $$pre74;$absMaxColumn$049 = $absMaxColumn$1;$absMaxRow$051 = $$absMaxRow$0;$absMinColumn$050 = $absMinColumn$1;$absMinRow$052 = $$absMinRow$0;$i$048 = $174;
 }
 if ((label|0) == 2) {
  $34 = ($$absMinRow$0>>>0)>($$absMaxRow$0>>>0);
  if ($34) {
   $$5 = 0;
   STACKTOP = sp;return ($$5|0);
  }
  $35 = ($absMinColumn$1>>>0)>($absMaxColumn$1>>>0);
  $36 = (($origin) + 4|0);
  $37 = (($direction) + 4|0);
  $38 = (($origin) + 8|0);
  $39 = (($direction) + 8|0);
  $40 = (($1) + 4|0);
  $41 = (($1) + 8|0);
  $42 = (($1) + 12|0);
  $43 = (($1) + 16|0);
  $44 = (($1) + 20|0);
  $45 = (($fracX$i$i) + 4|0);
  $46 = (($fracX$i$i) + 8|0);
  $47 = (($fracZ$i$i) + 4|0);
  $48 = (($fracZ$i$i) + 8|0);
  $row$015 = $$absMinRow$0;
  L46: while(1) {
   if (!($35)) {
    $176 = ($row$015|0)==($$absMaxRow$0|0);
    $177 = $176 ? 1 : 3;
    $column$010 = $absMinColumn$1;
    while(1) {
     $178 = HEAP32[$29>>2]|0;
     $179 = Math_imul($178, $row$015)|0;
     $180 = (($179) + ($column$010))|0;
     $181 = ($180*3)|0;
     $182 = ($column$010|0)==($absMaxColumn$1|0);
     $183 = $182 ? 2 : 0;
     $184 = ($183>>>0)<($177>>>0);
     if ($184) {
      $ei$09 = $183;
      while(1) {
       $185 = (($ei$09) + ($181))|0;
       $186 = (__ZNK5physx2Gu15HeightFieldUtil16getEdgeFaceIndexEjjjj($hfUtil,$185,$180,$row$015,$column$010)|0);
       $187 = ($186|0)==(-1);
       if (!($187)) {
        __ZNK5physx2Gu15HeightFieldUtil7getEdgeEjjjjRNS_6PxVec3ES3_($hfUtil,$185,$180,$row$015,$column$010,$origin,$direction);
        $188 = Math_fround(HEAPF32[$origin>>2]);
        $189 = Math_fround(HEAPF32[$direction>>2]);
        $190 = Math_fround($188 + $189);
        $191 = Math_fround(HEAPF32[$36>>2]);
        $192 = Math_fround(HEAPF32[$37>>2]);
        $193 = Math_fround($191 + $192);
        $194 = Math_fround(HEAPF32[$38>>2]);
        $195 = Math_fround(HEAPF32[$39>>2]);
        $196 = Math_fround($194 + $195);
        HEAPF32[$1>>2] = $188;
        HEAPF32[$40>>2] = $191;
        HEAPF32[$41>>2] = $194;
        HEAPF32[$42>>2] = $190;
        HEAPF32[$43>>2] = $193;
        HEAPF32[$44>>2] = $196;
        $197 = Math_fround(HEAPF32[$18>>2]);
        $198 = Math_fround(HEAPF32[$capsuleInHfShape>>2]);
        $199 = Math_fround($197 - $198);
        $200 = Math_fround(HEAPF32[$21>>2]);
        $201 = Math_fround(HEAPF32[$12>>2]);
        $202 = Math_fround($200 - $201);
        $203 = Math_fround(HEAPF32[$24>>2]);
        $204 = Math_fround(HEAPF32[$15>>2]);
        $205 = Math_fround($203 - $204);
        HEAPF32[$fracX$i$i>>2] = $199;
        HEAPF32[$45>>2] = $202;
        HEAPF32[$46>>2] = $205;
        $206 = Math_fround($190 - $188);
        $207 = Math_fround($193 - $191);
        $208 = Math_fround($196 - $194);
        HEAPF32[$fracZ$i$i>>2] = $206;
        HEAPF32[$47>>2] = $207;
        HEAPF32[$48>>2] = $208;
        $209 = (Math_fround(__ZN5physx2Gu32distanceSegmentSegmentSquaredOLDERKNS_6PxVec3ES3_S3_S3_PfS4_($capsuleInHfShape,$fracX$i$i,$1,$fracZ$i$i,$s,$t)));
        $210 = $209 < $27;
        if ($210) {
         $$5 = 1;
         label = 36;
         break L46;
        }
       }
       $211 = (($ei$09) + 1)|0;
       $212 = ($211>>>0)<($177>>>0);
       if ($212) {
        $ei$09 = $211;
       } else {
        break;
       }
      }
     }
     $213 = (($column$010) + 1)|0;
     $214 = ($213>>>0)>($absMaxColumn$1>>>0);
     if ($214) {
      break;
     } else {
      $column$010 = $213;
     }
    }
   }
   $215 = (($row$015) + 1)|0;
   $216 = ($215>>>0)>($$absMaxRow$0>>>0);
   if ($216) {
    $$5 = 0;
    label = 36;
    break;
   } else {
    $row$015 = $215;
   }
  }
  if ((label|0) == 36) {
   STACKTOP = sp;return ($$5|0);
  }
 }
 else if ((label|0) == 36) {
  STACKTOP = sp;return ($$5|0);
 }
 return 0|0;
}
function __ZN5physx2Gu23intersectHeightFieldBoxERKNS0_15HeightFieldUtilERKNS0_3BoxE($hfUtil,$boxInHfShape) {
 $hfUtil = $hfUtil|0;
 $boxInHfShape = $boxInHfShape|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0);
 var $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0;
 var $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0;
 var $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0;
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $boxVertices = 0, $boxVerticesInHfShape = 0, $cb = 0, $column$013 = 0, $exitcond = 0, $exitcond34 = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i2 = Math_fround(0), $fabsf$i$i3 = Math_fround(0);
 var $fracX$i$i = 0, $fracZ$i$i = 0, $i$030 = 0, $i$128 = 0, $i$226 = 0, $i$323 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i4 = 0, $or$cond1$i = 0, $or$cond12 = 0, $row$015 = 0, $v0 = 0, $v1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $fracX$i$i = sp + 224|0;
 $fracZ$i$i = sp;
 $boxVertices = sp + 8|0;
 $boxVerticesInHfShape = sp + 104|0;
 $v0 = sp + 200|0;
 $v1 = sp + 212|0;
 $cb = sp + 228|0;
 $0 = (($hfUtil) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($boxInHfShape) + 48|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($boxInHfShape) + 52|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($boxInHfShape) + 56|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $i$030 = 0;
 while(1) {
  $8 = ($i$030*3)|0;
  $9 = (553840 + ($8<<2)|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround($3 * $10);
  $12 = (($8) + 1)|0;
  $13 = (553840 + ($12<<2)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($5 * $14);
  $16 = (($8) + 2)|0;
  $17 = (553840 + ($16<<2)|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($7 * $18);
  $20 = (($boxVertices) + (($i$030*12)|0)|0);
  HEAPF32[$20>>2] = $11;
  $21 = ((($boxVertices) + (($i$030*12)|0)|0) + 4|0);
  HEAPF32[$21>>2] = $15;
  $22 = ((($boxVertices) + (($i$030*12)|0)|0) + 8|0);
  HEAPF32[$22>>2] = $19;
  $23 = (($i$030) + 1)|0;
  $exitcond34 = ($23|0)==(8);
  if ($exitcond34) {
   break;
  } else {
   $i$030 = $23;
  }
 }
 $24 = Math_fround(HEAPF32[$boxInHfShape>>2]);
 $25 = (($boxInHfShape) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($boxInHfShape) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($boxInHfShape) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($boxInHfShape) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($boxInHfShape) + 20|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($boxInHfShape) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($boxInHfShape) + 28|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($boxInHfShape) + 32|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($boxInHfShape) + 36|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($boxInHfShape) + 40|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($boxInHfShape) + 44|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $i$128 = 0;
 while(1) {
  $50 = (($boxVertices) + (($i$128*12)|0)|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($51 * $24);
  $53 = Math_fround($51 * $26);
  $54 = Math_fround($51 * $28);
  $55 = ((($boxVertices) + (($i$128*12)|0)|0) + 4|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($56 * $30);
  $58 = Math_fround($56 * $32);
  $59 = Math_fround($56 * $34);
  $60 = Math_fround($52 + $57);
  $61 = Math_fround($53 + $58);
  $62 = Math_fround($54 + $59);
  $63 = ((($boxVertices) + (($i$128*12)|0)|0) + 8|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($64 * $36);
  $66 = Math_fround($64 * $38);
  $67 = Math_fround($64 * $40);
  $68 = Math_fround($60 + $65);
  $69 = Math_fround($61 + $66);
  $70 = Math_fround($62 + $67);
  $71 = Math_fround($68 + $42);
  $72 = Math_fround($69 + $44);
  $73 = Math_fround($70 + $46);
  $74 = (($boxVerticesInHfShape) + (($i$128*12)|0)|0);
  HEAPF32[$74>>2] = $71;
  $75 = ((($boxVerticesInHfShape) + (($i$128*12)|0)|0) + 4|0);
  HEAPF32[$75>>2] = $72;
  $76 = ((($boxVerticesInHfShape) + (($i$128*12)|0)|0) + 8|0);
  HEAPF32[$76>>2] = $73;
  $77 = (($i$128) + 1)|0;
  $exitcond = ($77|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i$128 = $77;
  }
 }
 $47 = (($hfUtil) + 8|0);
 $48 = (($hfUtil) + 16|0);
 $49 = (($1) + 40|0);
 $i$226 = 0;
 L7: while(1) {
  $82 = (($boxVerticesInHfShape) + (($i$226*12)|0)|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = ((($boxVerticesInHfShape) + (($i$226*12)|0)|0) + 8|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround(HEAPF32[$hfUtil>>2]);
  $87 = Math_fround($83 * $86);
  $88 = Math_fround(HEAPF32[$47>>2]);
  $89 = Math_fround($85 * $88);
  $90 = !($87 >= Math_fround(0.0));
  $91 = !($89 >= Math_fround(0.0));
  $or$cond$i = $90 | $91;
  do {
   if (!($or$cond$i)) {
    $92 = HEAP32[$0>>2]|0;
    $93 = (($92) + 24|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $95 = Math_fround($94 + Math_fround(1.0));
    $96 = $87 < $95;
    if ($96) {
     $97 = (($92) + 28|0);
     $98 = Math_fround(HEAPF32[$97>>2]);
     $99 = Math_fround($98 + Math_fround(1.0));
     $100 = $89 < $99;
     if ($100) {
      $101 = HEAP32[$48>>2]|0;
      $102 = (($101) + 8|0);
      $103 = Math_fround(HEAPF32[$102>>2]);
      $104 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($92,$87,$89,$fracX$i$i,$fracZ$i$i)|0);
      $105 = Math_fround(HEAPF32[$fracX$i$i>>2]);
      $106 = Math_fround(HEAPF32[$fracZ$i$i>>2]);
      $107 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($92,$104,$105,$106)));
      $108 = Math_fround($103 * $107);
      $109 = ((($boxVerticesInHfShape) + (($i$226*12)|0)|0) + 4|0);
      $110 = Math_fround(HEAPF32[$109>>2]);
      $111 = Math_fround($110 - $108);
      $112 = Math_fround(HEAPF32[$49>>2]);
      $113 = !($112 <= Math_fround(0.0));
      $114 = !($111 <= Math_fround(0.0));
      $or$cond$i4 = $113 | $114;
      $115 = !($112 <= $111);
      $or$cond1$i = $or$cond$i4 | $115;
      if ($or$cond1$i) {
       $116 = $112 > Math_fround(0.0);
       $117 = $111 > Math_fround(-0.0);
       $or$cond = $116 & $117;
       $118 = $112 > $111;
       $or$cond12 = $or$cond & $118;
       if (!($or$cond12)) {
        break;
       }
      }
      $119 = Math_fround(HEAPF32[$82>>2]);
      $120 = Math_fround(HEAPF32[$84>>2]);
      $121 = (__ZNK5physx2Gu15HeightFieldUtil24getFaceIndexAtShapePointEff($hfUtil,$119,$120)|0);
      $122 = ($121|0)==(-1);
      if (!($122)) {
       $$1 = 1;
       label = 26;
       break L7;
      }
     }
    }
   }
  } while(0);
  $123 = (($i$226) + 1)|0;
  $124 = ($123>>>0)<(8);
  if ($124) {
   $i$226 = $123;
  } else {
   break;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return ($$1|0);
 }
 $78 = (($v0) + 4|0);
 $79 = (($v0) + 8|0);
 $80 = (($v1) + 4|0);
 $81 = (($v1) + 8|0);
 $i$323 = 0;
 while(1) {
  $127 = $i$323 << 1;
  $128 = (553936 + ($127)|0);
  $129 = HEAP8[$128>>0]|0;
  $130 = $129&255;
  $131 = (($boxVerticesInHfShape) + (($130*12)|0)|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  HEAPF32[$v0>>2] = $132;
  $133 = ((($boxVerticesInHfShape) + (($130*12)|0)|0) + 4|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  HEAPF32[$78>>2] = $134;
  $135 = ((($boxVerticesInHfShape) + (($130*12)|0)|0) + 8|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  HEAPF32[$79>>2] = $136;
  $137 = $127 | 1;
  $138 = (553936 + ($137)|0);
  $139 = HEAP8[$138>>0]|0;
  $140 = $139&255;
  $141 = (($boxVerticesInHfShape) + (($140*12)|0)|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  HEAPF32[$v1>>2] = $142;
  $143 = ((($boxVerticesInHfShape) + (($140*12)|0)|0) + 4|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  HEAPF32[$80>>2] = $144;
  $145 = ((($boxVerticesInHfShape) + (($140*12)|0)|0) + 8|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  HEAPF32[$81>>2] = $146;
  HEAP8[$cb>>0] = 0;
  __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS0_27TriggerTraceSegmentCallbackELb0ELb0ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$v0,$v1,$cb,0);
  $147 = HEAP8[$cb>>0]|0;
  $148 = ($147<<24>>24)==(0);
  $126 = (($i$323) + 1)|0;
  if (!($148)) {
   $$1 = 1;
   label = 26;
   break;
  }
  $125 = ($126>>>0)<(12);
  if ($125) {
   $i$323 = $126;
  } else {
   break;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return ($$1|0);
 }
 $149 = Math_fround(HEAPF32[$boxInHfShape>>2]);
 $150 = Math_fround(HEAPF32[$25>>2]);
 $151 = Math_fround(HEAPF32[$27>>2]);
 $152 = Math_fround(HEAPF32[$29>>2]);
 $153 = Math_fround(HEAPF32[$31>>2]);
 $154 = Math_fround(HEAPF32[$33>>2]);
 $155 = Math_fround(HEAPF32[$35>>2]);
 $156 = Math_fround(HEAPF32[$37>>2]);
 $157 = Math_fround(HEAPF32[$39>>2]);
 $158 = Math_fround(HEAPF32[$41>>2]);
 $159 = Math_fround(HEAPF32[$43>>2]);
 $160 = Math_fround(HEAPF32[$45>>2]);
 $161 = Math_fround(-$158);
 $162 = Math_fround(-$159);
 $163 = Math_fround(-$160);
 $164 = Math_fround($150 * $162);
 $165 = Math_fround($151 * $163);
 $166 = Math_fround($152 * $161);
 $167 = Math_fround($153 * $162);
 $168 = Math_fround($166 + $167);
 $169 = Math_fround($154 * $163);
 $170 = Math_fround($168 + $169);
 $171 = Math_fround($156 * $162);
 $172 = Math_fround($157 * $163);
 $173 = Math_fround(HEAPF32[$boxVerticesInHfShape>>2]);
 $174 = $173 < Math_fround(3.40282346638528859812E+38);
 $175 = $174 ? $173 : Math_fround(3.40282346638528859812E+38);
 $176 = (($boxVerticesInHfShape) + 8|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = $177 < Math_fround(3.40282346638528859812E+38);
 $179 = $178 ? $177 : Math_fround(3.40282346638528859812E+38);
 $180 = $173 > Math_fround(-3.40282346638528859812E+38);
 $181 = $180 ? $173 : Math_fround(-3.40282346638528859812E+38);
 $182 = $177 > Math_fround(-3.40282346638528859812E+38);
 $183 = $182 ? $177 : Math_fround(-3.40282346638528859812E+38);
 $184 = (($boxVerticesInHfShape) + 12|0);
 $185 = Math_fround(HEAPF32[$184>>2]);
 $186 = $185 < $175;
 $187 = $186 ? $185 : $175;
 $188 = (($boxVerticesInHfShape) + 20|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = $189 < $179;
 $191 = $190 ? $189 : $179;
 $192 = $185 > $181;
 $193 = $192 ? $185 : $181;
 $194 = $189 > $183;
 $195 = $194 ? $189 : $183;
 $196 = (($boxVerticesInHfShape) + 24|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = $197 < $187;
 $199 = $198 ? $197 : $187;
 $200 = (($boxVerticesInHfShape) + 32|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = $201 < $191;
 $203 = $202 ? $201 : $191;
 $204 = $197 > $193;
 $205 = $204 ? $197 : $193;
 $206 = $201 > $195;
 $207 = $206 ? $201 : $195;
 $208 = (($boxVerticesInHfShape) + 36|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = $209 < $199;
 $211 = $210 ? $209 : $199;
 $212 = (($boxVerticesInHfShape) + 44|0);
 $213 = Math_fround(HEAPF32[$212>>2]);
 $214 = $213 < $203;
 $215 = $214 ? $213 : $203;
 $216 = $209 > $205;
 $217 = $216 ? $209 : $205;
 $218 = $213 > $207;
 $219 = $218 ? $213 : $207;
 $220 = (($boxVerticesInHfShape) + 48|0);
 $221 = Math_fround(HEAPF32[$220>>2]);
 $222 = $221 < $211;
 $223 = $222 ? $221 : $211;
 $224 = (($boxVerticesInHfShape) + 56|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = $225 < $215;
 $227 = $226 ? $225 : $215;
 $228 = $221 > $217;
 $229 = $228 ? $221 : $217;
 $230 = $225 > $219;
 $231 = $230 ? $225 : $219;
 $232 = (($boxVerticesInHfShape) + 60|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = $233 < $223;
 $235 = $234 ? $233 : $223;
 $236 = (($boxVerticesInHfShape) + 68|0);
 $237 = Math_fround(HEAPF32[$236>>2]);
 $238 = $237 < $227;
 $239 = $238 ? $237 : $227;
 $240 = $233 > $229;
 $241 = $240 ? $233 : $229;
 $242 = $237 > $231;
 $243 = $242 ? $237 : $231;
 $244 = (($boxVerticesInHfShape) + 72|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = $245 < $235;
 $247 = $246 ? $245 : $235;
 $248 = (($boxVerticesInHfShape) + 80|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = $249 < $239;
 $251 = $250 ? $249 : $239;
 $252 = $245 > $241;
 $253 = $252 ? $245 : $241;
 $254 = $249 > $243;
 $255 = $254 ? $249 : $243;
 $256 = (($boxVerticesInHfShape) + 84|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = $257 < $247;
 $259 = $258 ? $257 : $247;
 $260 = (($boxVerticesInHfShape) + 92|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = $261 < $251;
 $263 = $262 ? $261 : $251;
 $264 = $257 > $253;
 $265 = $264 ? $257 : $253;
 $266 = $261 > $255;
 $267 = $266 ? $261 : $255;
 $268 = Math_fround($149 * $161);
 $269 = Math_fround($268 + $164);
 $270 = Math_fround($269 + $165);
 $271 = Math_fround($155 * $161);
 $272 = Math_fround($271 + $171);
 $273 = Math_fround($272 + $172);
 $274 = Math_fround(HEAPF32[$hfUtil>>2]);
 $275 = Math_fround(HEAPF32[$47>>2]);
 $276 = Math_fround($259 * $274);
 $277 = (Math_fround(Math_floor((Math_fround($276)))));
 $278 = (~~(($277)));
 $279 = (($1) + 16|0);
 $280 = HEAP32[$279>>2]|0;
 $281 = (($280) + -2)|0;
 $282 = ($278|0)>(0);
 $283 = $282 ? $278 : 0;
 $284 = ($283|0)>($281|0);
 $285 = $284 ? $281 : $283;
 $286 = Math_fround($265 * $274);
 $287 = (Math_fround(Math_ceil((Math_fround($286)))));
 $288 = (~~(($287)));
 $289 = (($280) + -1)|0;
 $290 = ($288|0)>(0);
 $291 = $290 ? $288 : 0;
 $292 = ($291|0)>($289|0);
 $293 = $292 ? $289 : $291;
 $294 = Math_fround($263 * $275);
 $295 = (Math_fround(Math_floor((Math_fround($294)))));
 $296 = (~~(($295)));
 $297 = (($1) + 20|0);
 $298 = HEAP32[$297>>2]|0;
 $299 = (($298) + -2)|0;
 $300 = ($296|0)>(0);
 $301 = $300 ? $296 : 0;
 $302 = ($301|0)>($299|0);
 $303 = $302 ? $299 : $301;
 $304 = Math_fround($267 * $275);
 $305 = (Math_fround(Math_ceil((Math_fround($304)))));
 $306 = (~~(($305)));
 $307 = (($298) + -1)|0;
 $308 = ($306|0)>(0);
 $309 = $308 ? $306 : 0;
 $310 = ($309|0)>($307|0);
 $311 = $310 ? $307 : $309;
 $312 = ($285>>>0)>($293>>>0);
 if ($312) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $313 = ($303>>>0)>($311>>>0);
 $314 = (($1) + 36|0);
 $row$015 = $285;
 L29: while(1) {
  if (!($313)) {
   $315 = Math_imul($298, $row$015)|0;
   $316 = HEAP32[$0>>2]|0;
   $317 = (($316) + 36|0);
   $318 = HEAP32[$317>>2]|0;
   $319 = (Math_fround(($row$015>>>0)));
   $column$013 = $303;
   while(1) {
    $320 = (($315) + ($column$013))|0;
    $321 = ((($318) + ($320<<2)|0) + 3|0);
    $322 = HEAP8[$321>>0]|0;
    $323 = ($322<<24>>24)<(0);
    if ($323) {
     $324 = HEAP32[$48>>2]|0;
     $325 = (($324) + 12|0);
     $326 = Math_fround(HEAPF32[$325>>2]);
     $327 = Math_fround($319 * $326);
     $328 = (($324) + 8|0);
     $329 = Math_fround(HEAPF32[$328>>2]);
     $330 = HEAP32[$314>>2]|0;
     $331 = (($330) + ($320<<2)|0);
     $332 = HEAP16[$331>>1]|0;
     $333 = (Math_fround(($332<<16>>16)));
     $334 = Math_fround($329 * $333);
     $335 = (($324) + 16|0);
     $336 = Math_fround(HEAPF32[$335>>2]);
     $337 = (Math_fround(($column$013>>>0)));
     $338 = Math_fround($337 * $336);
     $339 = Math_fround($149 * $327);
     $340 = Math_fround($155 * $327);
     $341 = Math_fround($150 * $334);
     $342 = Math_fround($156 * $334);
     $343 = Math_fround($339 + $341);
     $344 = Math_fround($340 + $342);
     $345 = Math_fround($151 * $338);
     $346 = Math_fround($157 * $338);
     $347 = Math_fround($345 + $343);
     $348 = Math_fround($346 + $344);
     $349 = Math_fround($270 + $347);
     $350 = Math_fround($273 + $348);
     $fabsf$i$i3 = (Math_fround(Math_abs((Math_fround($349)))));
     $351 = Math_fround(HEAPF32[$2>>2]);
     $352 = Math_fround($fabsf$i$i3 - $351);
     $353 = $352 < Math_fround(0.0);
     if ($353) {
      $354 = Math_fround($153 * $334);
      $355 = Math_fround($152 * $327);
      $356 = Math_fround($154 * $338);
      $357 = Math_fround($355 + $354);
      $358 = Math_fround($356 + $357);
      $359 = Math_fround($170 + $358);
      $fabsf$i$i2 = (Math_fround(Math_abs((Math_fround($359)))));
      $360 = Math_fround(HEAPF32[$4>>2]);
      $361 = Math_fround($fabsf$i$i2 - $360);
      $362 = $361 < Math_fround(0.0);
      if ($362) {
       $fabsf$i$i = (Math_fround(Math_abs((Math_fround($350)))));
       $363 = Math_fround(HEAPF32[$6>>2]);
       $364 = Math_fround($fabsf$i$i - $363);
       $365 = $364 < Math_fround(0.0);
       if ($365) {
        $$1 = 1;
        label = 26;
        break L29;
       }
      }
     }
    }
    $366 = (($column$013) + 1)|0;
    $367 = ($366>>>0)>($311>>>0);
    if ($367) {
     break;
    } else {
     $column$013 = $366;
    }
   }
  }
  $368 = (($row$015) + 1)|0;
  $369 = ($368>>>0)>($293>>>0);
  if ($369) {
   $$1 = 0;
   label = 26;
   break;
  } else {
   $row$015 = $368;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS0_27TriggerTraceSegmentCallbackELb0ELb0ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($this,$aP0,$aP1,$aCallback,$overlapObjectExtent) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $aCallback = $aCallback|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 var $$sink = Math_fround(0), $$sink1 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0;
 var $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0;
 var $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0;
 var $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0);
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = 0;
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $du$0 = Math_fround(0), $duhvNorm = 0, $dv$0 = Math_fround(0), $fabsf$i$i = Math_fround(0), $fabsf$i$i5 = Math_fround(0), $fabsf$i$i8 = Math_fround(0), $fabsf$i$i9 = Math_fround(0), $h = 0, $hLinePrev$0 = Math_fround(0), $hit0$0$off0 = 0, $hit1$0$off0 = 0, $localBounds = 0, $or$cond = 0, $or$cond$not = 0, $or$cond14 = 0, $or$cond15 = 0, $or$cond16 = 0, $or$cond17 = 0;
 var $or$cond4 = 0, $or$cond4$not = 0, $p00 = 0, $p00$p01 = 0, $p01 = 0, $p01$p11 = 0, $p10 = 0, $p10$p00 = 0, $p11 = 0, $p11$p10 = 0, $rayDir = 0, $tfar = 0, $tnear = 0, $triT0 = 0, $triT1 = 0, $triU = 0, $triV = 0, $tu$0 = Math_fround(0), $tu$1 = Math_fround(0), $tv$0 = Math_fround(0);
 var $tv$1 = Math_fround(0), $uhv0 = 0, $ui$0 = 0, $ui$1 = 0, $uif$0 = Math_fround(0), $uif$1 = Math_fround(0), $vi$0 = 0, $vi$1 = 0, $vif$0 = Math_fround(0), $vif$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $localBounds = sp + 128|0;
 $rayDir = sp + 112|0;
 $tnear = sp + 108|0;
 $tfar = sp + 104|0;
 $uhv0 = sp + 92|0;
 $duhvNorm = sp + 80|0;
 $h = sp + 64|0;
 $triU = sp + 60|0;
 $triV = sp + 52|0;
 $p00 = sp + 40|0;
 $p01 = sp + 28|0;
 $p10 = sp + 16|0;
 $p11 = sp + 4|0;
 $triT0 = sp;
 $triT1 = sp + 56|0;
 __ZNK5physx2Gu15HeightFieldUtil18computeLocalBoundsERNS_9PxBounds3E($this,$localBounds);
 $0 = Math_fround(HEAPF32[$aP1>>2]);
 $1 = Math_fround(HEAPF32[$aP0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($aP1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($aP0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($aP1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($aP0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 HEAPF32[$rayDir>>2] = $2;
 $13 = (($rayDir) + 4|0);
 HEAPF32[$13>>2] = $7;
 $14 = (($rayDir) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($localBounds) + 12|0);
 $16 = (__ZN5physx2Gu17intersectRayAABB2ERKNS_6PxVec3ES3_S3_S3_fRfS4_($localBounds,$15,$aP0,$rayDir,Math_fround(1.0),$tnear,$tfar)|0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 12|0);
 $18 = Math_fround(HEAPF32[$tnear>>2]);
 $19 = Math_fround(HEAPF32[$rayDir>>2]);
 $20 = Math_fround($18 * $19);
 $21 = Math_fround(HEAPF32[$13>>2]);
 $22 = Math_fround($18 * $21);
 $23 = Math_fround(HEAPF32[$14>>2]);
 $24 = Math_fround($18 * $23);
 $25 = Math_fround(HEAPF32[$aP0>>2]);
 $26 = Math_fround($20 + $25);
 $27 = Math_fround(HEAPF32[$5>>2]);
 $28 = Math_fround($22 + $27);
 $29 = Math_fround(HEAPF32[$10>>2]);
 $30 = Math_fround($24 + $29);
 $31 = Math_fround(HEAPF32[$tfar>>2]);
 $32 = Math_fround($19 * $31);
 $33 = Math_fround($21 * $31);
 $34 = Math_fround($23 * $31);
 $35 = Math_fround($25 + $32);
 $36 = Math_fround($27 + $33);
 $37 = Math_fround($29 + $34);
 $38 = (($this) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = HEAP32[$17>>2]|0;
 $43 = (($42) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + 16|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = Math_fround(HEAPF32[$this>>2]);
 $48 = (($this) + 8|0);
 $49 = (($46) + -1)|0;
 $50 = (Math_fround(($49|0)));
 $51 = Math_fround($50 * Math_fround(0.999999880790710449218));
 $52 = (($44) + -1)|0;
 $53 = (Math_fround(($52|0)));
 $54 = Math_fround($53 * Math_fround(0.999999880790710449218));
 $55 = Math_fround($26 * $47);
 $56 = $55 > Math_fround(1.00000001168609742308E-7);
 $57 = $56 ? $55 : Math_fround(1.00000001168609742308E-7);
 $58 = Math_fround($51 + Math_fround(0.0));
 $59 = $57 < $58;
 $60 = $59 ? $57 : $58;
 $61 = Math_fround(HEAPF32[$48>>2]);
 $62 = Math_fround($30 * $61);
 $63 = $62 > Math_fround(1.00000001168609742308E-7);
 $64 = $63 ? $62 : Math_fround(1.00000001168609742308E-7);
 $65 = Math_fround($54 + Math_fround(0.0));
 $66 = $64 < $65;
 $67 = $66 ? $64 : $65;
 $68 = Math_fround($35 * $47);
 $69 = $68 > Math_fround(1.00000001168609742308E-7);
 $70 = $69 ? $68 : Math_fround(1.00000001168609742308E-7);
 $71 = $70 < $58;
 $72 = $71 ? $70 : $58;
 $73 = Math_fround($37 * $61);
 $74 = $73 > Math_fround(1.00000001168609742308E-7);
 $75 = $74 ? $73 : Math_fround(1.00000001168609742308E-7);
 $76 = $75 < $65;
 $77 = $76 ? $75 : $65;
 $78 = Math_fround($72 - $60);
 $79 = Math_fround($77 - $67);
 $80 = Math_fround($36 - $28);
 $81 = $78 >= Math_fround(0.0);
 $82 = $81 ? Math_fround(1.0) : Math_fround(-1.0);
 $83 = $79 >= Math_fround(0.0);
 $84 = $83 ? Math_fround(1.0) : Math_fround(-1.0);
 $85 = (~~(($82)));
 $86 = (~~(($84)));
 $fabsf$i$i9 = (Math_fround(Math_abs((Math_fround($78)))));
 $87 = $fabsf$i$i9 < Math_fround(1.00000001335143196002E-10);
 if ($87) {
  $88 = Math_fround($82 * Math_fround(1.00000001335143196002E-10));
  $du$0 = $88;
 } else {
  $du$0 = $78;
 }
 $fabsf$i$i8 = (Math_fround(Math_abs((Math_fround($79)))));
 $89 = $fabsf$i$i8 < Math_fround(1.00000001335143196002E-10);
 if ($89) {
  $90 = Math_fround($84 * Math_fround(1.00000001335143196002E-10));
  $dv$0 = $90;
 } else {
  $dv$0 = $79;
 }
 HEAPF32[$uhv0>>2] = $55;
 $91 = (($uhv0) + 4|0);
 HEAPF32[$91>>2] = $28;
 $92 = (($uhv0) + 8|0);
 HEAPF32[$92>>2] = $62;
 $93 = Math_fround($35 - $26);
 $94 = Math_fround($93 * $47);
 $95 = Math_fround($37 - $30);
 $96 = Math_fround($95 * $61);
 $97 = Math_fround($94 * $94);
 $98 = Math_fround($80 * $80);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($96 * $96);
 $101 = Math_fround($99 + $100);
 $102 = (Math_fround(Math_sqrt((Math_fround($101)))));
 HEAPF32[$duhvNorm>>2] = $94;
 $103 = (($duhvNorm) + 4|0);
 HEAPF32[$103>>2] = $80;
 $104 = (($duhvNorm) + 8|0);
 HEAPF32[$104>>2] = $96;
 $105 = $102 > Math_fround(9.99999968265522538896E-21);
 if ($105) {
  $106 = Math_fround(Math_fround(1.0) / $102);
  $107 = Math_fround($106 * $94);
  HEAPF32[$duhvNorm>>2] = $107;
  $108 = Math_fround($106 * $80);
  HEAPF32[$103>>2] = $108;
  $109 = Math_fround($106 * $96);
  HEAPF32[$104>>2] = $109;
 }
 $110 = $du$0 > Math_fround(0.0);
 if ($110) {
  $111 = (Math_fround(Math_floor((Math_fround($60)))));
  $$sink = $111;
 } else {
  $112 = (Math_fround(Math_ceil((Math_fround($60)))));
  $$sink = $112;
 }
 $113 = (~~(($$sink)));
 $114 = $dv$0 > Math_fround(0.0);
 if ($114) {
  $115 = (Math_fround(Math_floor((Math_fround($67)))));
  $$sink1 = $115;
 } else {
  $116 = (Math_fround(Math_ceil((Math_fround($67)))));
  $$sink1 = $116;
 }
 $117 = (~~(($$sink1)));
 if ($110) {
  $118 = (Math_fround(Math_ceil((Math_fround($60)))));
  $119 = $118 == $60;
  if ($119) {
   $120 = Math_fround($118 + Math_fround(1.0));
   $131 = $120;
  } else {
   $131 = $118;
  }
 } else {
  $121 = (Math_fround(Math_floor((Math_fround($60)))));
  $122 = $121 == $60;
  if ($122) {
   $123 = Math_fround($121 + Math_fround(-1.0));
   $131 = $123;
  } else {
   $131 = $121;
  }
 }
 if ($114) {
  $124 = (Math_fround(Math_ceil((Math_fround($67)))));
  $125 = $124 == $67;
  if ($125) {
   $126 = Math_fround($124 + Math_fround(1.0));
   $134 = $126;
  } else {
   $134 = $124;
  }
 } else {
  $127 = (Math_fround(Math_floor((Math_fround($67)))));
  $128 = $127 == $67;
  if ($128) {
   $129 = Math_fround($127 + Math_fround(-1.0));
   $134 = $129;
  } else {
   $134 = $127;
  }
 }
 $130 = Math_fround($131 - $60);
 $132 = Math_fround($130 / $du$0);
 $133 = Math_fround($134 - $67);
 $135 = Math_fround($133 / $dv$0);
 $fabsf$i$i5 = (Math_fround(Math_abs((Math_fround($du$0)))));
 $136 = Math_fround(Math_fround(1.0) / $fabsf$i$i5);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($dv$0)))));
 $137 = Math_fround(Math_fround(1.0) / $fabsf$i$i);
 $138 = (Math_fround(($113|0)));
 $139 = (Math_fround(($117|0)));
 $140 = (1 - ($85))|0;
 $141 = (1 - ($86))|0;
 $142 = (($141|0) / 2)&-1;
 $143 = Math_fround($80 * Math_fround(0.0));
 $144 = Math_fround($28 + $143);
 $145 = (Math_fround(($44|0)));
 $146 = (Math_fround(($46|0)));
 $147 = (($42) + 36|0);
 $148 = (($h) + 4|0);
 $149 = (($h) + 8|0);
 $150 = (($h) + 12|0);
 $151 = (($142) + ($140))|0;
 $152 = (($h) + ($151<<2)|0);
 $153 = (($140) + 1)|0;
 $154 = (($153) - ($142))|0;
 $155 = (($h) + ($154<<2)|0);
 $156 = (2 - ($140))|0;
 $157 = (($156) + ($142))|0;
 $158 = (($h) + ($157<<2)|0);
 $159 = (3 - ($140))|0;
 $160 = (($159) - ($142))|0;
 $161 = (($h) + ($160<<2)|0);
 $162 = (($p00) + 4|0);
 $163 = (($p00) + 8|0);
 $164 = (($p01) + 4|0);
 $165 = (($p01) + 8|0);
 $166 = (($p10) + 4|0);
 $167 = (($p10) + 8|0);
 $168 = (($p11) + 4|0);
 $169 = (($p11) + 8|0);
 $170 = Math_fround($102 + Math_fround(9.99999974737875163555E-5));
 $hLinePrev$0 = $144;$tu$0 = $132;$tv$0 = $135;$ui$0 = $113;$uif$0 = $138;$vi$0 = $117;$vif$0 = $139;
 while(1) {
  $171 = $tu$0 < $tv$0;
  $172 = $171 ? $tu$0 : $tv$0;
  $173 = Math_fround($80 * $172);
  $174 = Math_fround($28 + $173);
  $175 = Math_imul($ui$0, $44)|0;
  $176 = (($175) + ($vi$0))|0;
  $177 = (($ui$0) + ($85))|0;
  $178 = Math_imul($177, $44)|0;
  $179 = (($178) + ($vi$0))|0;
  $180 = HEAP32[$147>>2]|0;
  $181 = (($180) + ($176<<2)|0);
  $182 = HEAP16[$181>>1]|0;
  $183 = (Math_fround(($182<<16>>16)));
  $184 = Math_fround($41 * $183);
  HEAPF32[$h>>2] = $184;
  $185 = (($176) + ($86))|0;
  $186 = (($180) + ($185<<2)|0);
  $187 = HEAP16[$186>>1]|0;
  $188 = (Math_fround(($187<<16>>16)));
  $189 = Math_fround($41 * $188);
  HEAPF32[$148>>2] = $189;
  $190 = (($180) + ($179<<2)|0);
  $191 = HEAP16[$190>>1]|0;
  $192 = (Math_fround(($191<<16>>16)));
  $193 = Math_fround($41 * $192);
  HEAPF32[$149>>2] = $193;
  $194 = (($179) + ($86))|0;
  $195 = (($180) + ($194<<2)|0);
  $196 = HEAP16[$195>>1]|0;
  $197 = (Math_fround(($196<<16>>16)));
  $198 = Math_fround($41 * $197);
  HEAPF32[$150>>2] = $198;
  $199 = $184 < $189;
  $200 = $199 ? $184 : $189;
  $201 = $193 < $198;
  $202 = $201 ? $193 : $198;
  $203 = $184 > $189;
  $204 = $203 ? $184 : $189;
  $205 = $193 > $198;
  $206 = $205 ? $193 : $198;
  $207 = $204 > $206;
  $208 = $207 ? $204 : $206;
  $209 = $hLinePrev$0 < $174;
  $210 = $209 ? $hLinePrev$0 : $174;
  $211 = Math_fround($210 + Math_fround(-9.99999974737875163555E-5));
  $212 = $211 > $208;
  do {
   if (!($212)) {
    $213 = $hLinePrev$0 > $174;
    $214 = $200 < $202;
    $215 = $213 ? $hLinePrev$0 : $174;
    $216 = $214 ? $200 : $202;
    $217 = Math_fround($215 + Math_fround(9.99999974737875163555E-5));
    $218 = $217 < $216;
    if (!($218)) {
     $219 = Math_fround(HEAPF32[$152>>2]);
     $220 = Math_fround(HEAPF32[$155>>2]);
     $221 = Math_fround(HEAPF32[$158>>2]);
     $222 = Math_fround(HEAPF32[$161>>2]);
     $223 = Math_fround($82 + $uif$0);
     $224 = $uif$0 < $223;
     $225 = $224 ? $uif$0 : $223;
     $226 = $uif$0 > $223;
     $227 = $226 ? $uif$0 : $223;
     $228 = Math_fround($84 + $vif$0);
     $229 = $vif$0 < $228;
     $230 = $229 ? $vif$0 : $228;
     $231 = $vif$0 > $228;
     $232 = $231 ? $vif$0 : $228;
     HEAPF32[$p00>>2] = $225;
     HEAPF32[$162>>2] = $219;
     HEAPF32[$163>>2] = $230;
     HEAPF32[$p01>>2] = $225;
     HEAPF32[$164>>2] = $220;
     HEAPF32[$165>>2] = $232;
     HEAPF32[$p10>>2] = $227;
     HEAPF32[$166>>2] = $221;
     HEAPF32[$167>>2] = $230;
     HEAPF32[$p11>>2] = $227;
     HEAPF32[$168>>2] = $222;
     HEAPF32[$169>>2] = $232;
     $233 = ($177|0)<($ui$0|0);
     $234 = $233 ? $177 : $ui$0;
     $235 = (($vi$0) + ($86))|0;
     $236 = ($235|0)<($vi$0|0);
     $237 = $236 ? $235 : $vi$0;
     $238 = Math_imul($234, $44)|0;
     $239 = (($238) + ($237))|0;
     $240 = ((($180) + ($239<<2)|0) + 2|0);
     $241 = HEAP8[$240>>0]|0;
     $242 = ($241<<24>>24)<(0);
     $p00$p01 = $242 ? $p00 : $p01;
     $p01$p11 = $242 ? $p01 : $p11;
     $p10$p00 = $242 ? $p10 : $p00;
     $p11$p10 = $242 ? $p11 : $p10;
     HEAPF32[$triT0>>2] = Math_fround(3.40282346638528859812E+38);
     HEAPF32[$triT1>>2] = Math_fround(3.40282346638528859812E+38);
     $243 = (__ZN5physx2Gu29intersectRayTriangleNoCullingERKNS_6PxVec3ES3_S3_S3_S3_RfS4_S4_f($uhv0,$duhvNorm,$p10$p00,$p00$p01,$p11$p10,$triT0,$triU,$triV,Math_fround(9.99999974737875163555E-5))|0);
     $244 = Math_fround(HEAPF32[$triT0>>2]);
     $245 = $244 >= Math_fround(-9.99999974737875163555E-5);
     $or$cond = $243 & $245;
     $or$cond$not = $or$cond ^ 1;
     $246 = !($244 <= $170);
     $or$cond16 = $246 | $or$cond$not;
     if ($or$cond16) {
      label = 29;
     } else {
      $247 = HEAP32[$147>>2]|0;
      $248 = ((($247) + ($239<<2)|0) + 2|0);
      $249 = HEAP8[$248>>0]|0;
      $250 = $249 & 127;
      $251 = ($250<<24>>24)==(127);
      if ($251) {
       label = 29;
      } else {
       $hit0$0$off0 = 1;
      }
     }
     if ((label|0) == 29) {
      label = 0;
      HEAPF32[$triT0>>2] = Math_fround(3.40282346638528859812E+38);
      $hit0$0$off0 = 0;
     }
     $252 = (__ZN5physx2Gu29intersectRayTriangleNoCullingERKNS_6PxVec3ES3_S3_S3_S3_RfS4_S4_f($uhv0,$duhvNorm,$p01$p11,$p11$p10,$p00$p01,$triT1,$triU,$triV,Math_fround(9.99999974737875163555E-5))|0);
     $253 = Math_fround(HEAPF32[$triT1>>2]);
     $254 = $253 >= Math_fround(-9.99999974737875163555E-5);
     $or$cond4 = $252 & $254;
     $or$cond4$not = $or$cond4 ^ 1;
     $255 = !($253 <= $170);
     $or$cond17 = $255 | $or$cond4$not;
     if ($or$cond17) {
      label = 32;
     } else {
      $256 = HEAP32[$147>>2]|0;
      $257 = ((($256) + ($239<<2)|0) + 3|0);
      $258 = HEAP8[$257>>0]|0;
      $259 = $258 & 127;
      $260 = ($259<<24>>24)==(127);
      if ($260) {
       label = 32;
      } else {
       $263 = $253;$hit1$0$off0 = 1;
      }
     }
     if ((label|0) == 32) {
      label = 0;
      HEAPF32[$triT1>>2] = Math_fround(3.40282346638528859812E+38);
      $263 = Math_fround(3.40282346638528859812E+38);$hit1$0$off0 = 0;
     }
     if ($hit0$0$off0) {
      $261 = Math_fround(HEAPF32[$triT0>>2]);
      $262 = !($261 <= $263);
      if (!($262)) {
       HEAP8[$aCallback>>0] = 1;
       break;
      }
     }
     if ($hit1$0$off0) {
      $264 = Math_fround(HEAPF32[$triT0>>2]);
      $265 = !($263 <= $264);
      if (!($265)) {
       HEAP8[$aCallback>>0] = 1;
      }
     }
    }
   }
  } while(0);
  if ($171) {
   $266 = (($177) + ($85))|0;
   $267 = (Math_fround(($266|0)));
   $268 = !($267 < Math_fround(0.0));
   $269 = !($267 >= $146);
   $or$cond15 = $268 & $269;
   if (!($or$cond15)) {
    label = 45;
    break;
   }
   $270 = Math_fround($82 + $uif$0);
   $271 = Math_fround($136 + $tu$0);
   $tu$1 = $271;$tv$1 = $tv$0;$ui$1 = $177;$uif$1 = $270;$vi$1 = $vi$0;$vif$1 = $vif$0;
  } else {
   $272 = (($vi$0) + ($86))|0;
   $273 = (($272) + ($86))|0;
   $274 = (Math_fround(($273|0)));
   $275 = !($274 < Math_fround(0.0));
   $276 = !($274 >= $145);
   $or$cond14 = $275 & $276;
   if (!($or$cond14)) {
    label = 45;
    break;
   }
   $277 = Math_fround($84 + $vif$0);
   $278 = Math_fround($137 + $tv$0);
   $tu$1 = $tu$0;$tv$1 = $278;$ui$1 = $ui$0;$uif$1 = $uif$0;$vi$1 = $272;$vif$1 = $277;
  }
  $279 = $172 < Math_fround(0.999899983406066894531);
  if ($279) {
   $hLinePrev$0 = $174;$tu$0 = $tu$1;$tv$0 = $tv$1;$ui$0 = $ui$1;$uif$0 = $uif$1;$vi$0 = $vi$1;$vif$0 = $vif$1;
  } else {
   label = 45;
   break;
  }
 }
 if ((label|0) == 45) {
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu26intersectHeightFieldConvexERKNS0_15HeightFieldUtilERKNS_11PxTransformERKNS0_10ConvexMeshES6_RKNS_11PxMeshScaleE($hfUtil,$_hfAbsPose,$convexMesh,$_convexAbsPose,$convexMeshScaling) {
 $hfUtil = $hfUtil|0;
 $_hfAbsPose = $_hfAbsPose|0;
 $convexMesh = $convexMesh|0;
 $_convexAbsPose = $_convexAbsPose|0;
 $convexMeshScaling = $convexMeshScaling|0;
 var $$ = 0, $$2 = 0, $$5 = 0, $$in = 0, $$pre = Math_fround(0), $$sink = 0, $$sum = 0, $$sum1$i = 0, $$sum14 = 0, $$sum15 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0);
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0);
 var $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0);
 var $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0);
 var $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0);
 var $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0);
 var $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = Math_fround(0), $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0);
 var $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0);
 var $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = 0;
 var $341 = Math_fround(0), $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0;
 var $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0);
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = Math_fround(0);
 var $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = 0, $466 = 0, $467 = Math_fround(0);
 var $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = Math_fround(0), $483 = Math_fround(0), $484 = 0, $485 = 0;
 var $486 = 0, $487 = Math_fround(0), $488 = 0, $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = Math_fround(0);
 var $503 = Math_fround(0), $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = Math_fround(0), $567 = 0, $568 = 0, $569 = Math_fround(0), $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = Math_fround(0), $573 = 0, $574 = 0, $575 = 0;
 var $576 = Math_fround(0), $577 = 0, $578 = 0, $579 = Math_fround(0), $58 = Math_fround(0), $580 = 0, $581 = Math_fround(0), $582 = 0, $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0);
 var $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0);
 var $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0);
 var $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0);
 var $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0);
 var $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0);
 var $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $700 = Math_fround(0);
 var $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0, $717 = 0, $718 = 0, $719 = 0;
 var $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = 0, $73 = Math_fround(0), $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = Math_fround(0), $737 = Math_fround(0);
 var $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = 0;
 var $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = Math_fround(0), $763 = Math_fround(0), $764 = 0, $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = 0, $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = 0, $773 = Math_fround(0);
 var $774 = Math_fround(0), $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$0$ph = 0, $a$0$ph$phi = 0, $b$0$ph = 0, $cb = 0, $column$038 = 0, $column3$017 = 0, $convexBoundsInHfShape = 0, $fracX$i$i = 0, $fracZ$i$i = 0, $hfExtreme$0$lcssa = Math_fround(0);
 var $hfExtreme$043 = Math_fround(0), $hfExtreme$1$lcssa = Math_fround(0), $hfExtreme$139 = Math_fround(0), $i$047 = 0, $i1$033 = 0, $maxColumn$0 = 0, $maxRow$0 = 0, $minColumn$0 = 0, $minRow$0 = 0, $numEdges$0 = 0, $numEdges$0$ph = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i8 = 0, $or$cond1$i = 0, $or$cond13 = 0, $poly$016 = 0, $polygons$027 = 0, $row$042 = 0, $row2$020 = 0;
 var $tmp2$i = 0, $v0 = 0, $v1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $fracX$i$i = sp + 56|0;
 $fracZ$i$i = sp;
 $convexBoundsInHfShape = sp + 8|0;
 $v0 = sp + 32|0;
 $v1 = sp + 44|0;
 $cb = sp + 184|0;
 $0 = Math_fround(HEAPF32[$_hfAbsPose>>2]);
 $1 = Math_fround($0 + $0);
 $2 = (($_hfAbsPose) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 + $3);
 $5 = (($_hfAbsPose) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 + $6);
 $8 = (($_hfAbsPose) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($1 * $9);
 $11 = Math_fround($4 * $9);
 $12 = Math_fround($9 * $7);
 $13 = Math_fround($0 * $1);
 $14 = Math_fround($0 * $4);
 $15 = Math_fround($0 * $7);
 $16 = Math_fround($3 * $4);
 $17 = Math_fround($3 * $7);
 $18 = Math_fround($6 * $7);
 $19 = Math_fround(Math_fround(1.0) - $16);
 $20 = Math_fround($19 - $18);
 $21 = Math_fround($14 + $12);
 $22 = Math_fround($15 - $11);
 $23 = Math_fround($14 - $12);
 $24 = Math_fround(Math_fround(1.0) - $13);
 $25 = Math_fround($24 - $18);
 $26 = Math_fround($17 + $10);
 $27 = Math_fround($15 + $11);
 $28 = Math_fround($17 - $10);
 $29 = Math_fround($24 - $16);
 $30 = (($_hfAbsPose) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($_hfAbsPose) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($_hfAbsPose) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround(HEAPF32[$_convexAbsPose>>2]);
 $37 = Math_fround($36 + $36);
 $38 = (($_convexAbsPose) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 + $39);
 $41 = (($_convexAbsPose) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($42 + $42);
 $44 = (($_convexAbsPose) + 12|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($37 * $45);
 $47 = Math_fround($40 * $45);
 $48 = Math_fround($45 * $43);
 $49 = Math_fround($36 * $37);
 $50 = Math_fround($36 * $40);
 $51 = Math_fround($36 * $43);
 $52 = Math_fround($39 * $40);
 $53 = Math_fround($39 * $43);
 $54 = Math_fround($42 * $43);
 $55 = Math_fround(Math_fround(1.0) - $52);
 $56 = Math_fround($55 - $54);
 $57 = Math_fround($50 + $48);
 $58 = Math_fround($51 - $47);
 $59 = Math_fround($50 - $48);
 $60 = Math_fround(Math_fround(1.0) - $49);
 $61 = Math_fround($60 - $54);
 $62 = Math_fround($53 + $46);
 $63 = Math_fround($51 + $47);
 $64 = Math_fround($53 - $46);
 $65 = Math_fround($60 - $52);
 $66 = (($_convexAbsPose) + 16|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($_convexAbsPose) + 20|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($_convexAbsPose) + 24|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($convexMeshScaling) + 12|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($convexMeshScaling) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($convexMeshScaling) + 20|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($convexMeshScaling) + 24|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($73 + $73);
 $81 = Math_fround($75 + $75);
 $82 = Math_fround($77 + $77);
 $83 = Math_fround($73 * $80);
 $84 = Math_fround($75 * $81);
 $85 = Math_fround($77 * $82);
 $86 = Math_fround($80 * $75);
 $87 = Math_fround($80 * $77);
 $88 = Math_fround($80 * $79);
 $89 = Math_fround($81 * $77);
 $90 = Math_fround($81 * $79);
 $91 = Math_fround($82 * $79);
 $92 = Math_fround(Math_fround(1.0) - $84);
 $93 = Math_fround($92 - $85);
 $94 = Math_fround($86 + $91);
 $95 = Math_fround($87 - $90);
 $96 = Math_fround($86 - $91);
 $97 = Math_fround(Math_fround(1.0) - $83);
 $98 = Math_fround($97 - $85);
 $99 = Math_fround($89 + $88);
 $100 = Math_fround($87 + $90);
 $101 = Math_fround($89 - $88);
 $102 = Math_fround($97 - $84);
 $103 = Math_fround(HEAPF32[$convexMeshScaling>>2]);
 $104 = Math_fround($103 * $93);
 $105 = Math_fround($103 * $96);
 $106 = Math_fround($103 * $100);
 $107 = (($convexMeshScaling) + 4|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($94 * $108);
 $110 = Math_fround($98 * $108);
 $111 = Math_fround($101 * $108);
 $112 = (($convexMeshScaling) + 8|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($95 * $113);
 $115 = Math_fround($99 * $113);
 $116 = Math_fround($102 * $113);
 $117 = Math_fround($93 * $104);
 $118 = Math_fround($93 * $105);
 $119 = Math_fround($93 * $106);
 $120 = Math_fround($94 * $109);
 $121 = Math_fround($94 * $110);
 $122 = Math_fround($94 * $111);
 $123 = Math_fround($117 + $120);
 $124 = Math_fround($118 + $121);
 $125 = Math_fround($119 + $122);
 $126 = Math_fround($95 * $114);
 $127 = Math_fround($95 * $115);
 $128 = Math_fround($95 * $116);
 $129 = Math_fround($123 + $126);
 $130 = Math_fround($124 + $127);
 $131 = Math_fround($125 + $128);
 $132 = Math_fround($96 * $104);
 $133 = Math_fround($96 * $105);
 $134 = Math_fround($96 * $106);
 $135 = Math_fround($98 * $109);
 $136 = Math_fround($98 * $110);
 $137 = Math_fround($98 * $111);
 $138 = Math_fround($132 + $135);
 $139 = Math_fround($133 + $136);
 $140 = Math_fround($134 + $137);
 $141 = Math_fround($99 * $114);
 $142 = Math_fround($99 * $115);
 $143 = Math_fround($99 * $116);
 $144 = Math_fround($138 + $141);
 $145 = Math_fround($139 + $142);
 $146 = Math_fround($140 + $143);
 $147 = Math_fround($100 * $104);
 $148 = Math_fround($100 * $105);
 $149 = Math_fround($100 * $106);
 $150 = Math_fround($101 * $109);
 $151 = Math_fround($101 * $110);
 $152 = Math_fround($101 * $111);
 $153 = Math_fround($147 + $150);
 $154 = Math_fround($148 + $151);
 $155 = Math_fround($149 + $152);
 $156 = Math_fround($102 * $114);
 $157 = Math_fround($102 * $115);
 $158 = Math_fround($102 * $116);
 $159 = Math_fround($153 + $156);
 $160 = Math_fround($154 + $157);
 $161 = Math_fround($155 + $158);
 $162 = Math_fround($56 * $129);
 $163 = Math_fround($57 * $129);
 $164 = Math_fround($58 * $129);
 $165 = Math_fround($59 * $130);
 $166 = Math_fround($61 * $130);
 $167 = Math_fround($62 * $130);
 $168 = Math_fround($162 + $165);
 $169 = Math_fround($163 + $166);
 $170 = Math_fround($164 + $167);
 $171 = Math_fround($63 * $131);
 $172 = Math_fround($64 * $131);
 $173 = Math_fround($65 * $131);
 $174 = Math_fround($171 + $168);
 $175 = Math_fround($172 + $169);
 $176 = Math_fround($173 + $170);
 $177 = Math_fround($56 * $144);
 $178 = Math_fround($57 * $144);
 $179 = Math_fround($58 * $144);
 $180 = Math_fround($59 * $145);
 $181 = Math_fround($61 * $145);
 $182 = Math_fround($62 * $145);
 $183 = Math_fround($177 + $180);
 $184 = Math_fround($178 + $181);
 $185 = Math_fround($179 + $182);
 $186 = Math_fround($63 * $146);
 $187 = Math_fround($64 * $146);
 $188 = Math_fround($65 * $146);
 $189 = Math_fround($186 + $183);
 $190 = Math_fround($187 + $184);
 $191 = Math_fround($188 + $185);
 $192 = Math_fround($56 * $159);
 $193 = Math_fround($57 * $159);
 $194 = Math_fround($58 * $159);
 $195 = Math_fround($59 * $160);
 $196 = Math_fround($61 * $160);
 $197 = Math_fround($62 * $160);
 $198 = Math_fround($192 + $195);
 $199 = Math_fround($193 + $196);
 $200 = Math_fround($194 + $197);
 $201 = Math_fround($63 * $161);
 $202 = Math_fround($64 * $161);
 $203 = Math_fround($65 * $161);
 $204 = Math_fround($201 + $198);
 $205 = Math_fround($202 + $199);
 $206 = Math_fround($203 + $200);
 $207 = Math_fround($56 * Math_fround(0.0));
 $208 = Math_fround($57 * Math_fround(0.0));
 $209 = Math_fround($58 * Math_fround(0.0));
 $210 = Math_fround($59 * Math_fround(0.0));
 $211 = Math_fround($61 * Math_fround(0.0));
 $212 = Math_fround($62 * Math_fround(0.0));
 $213 = Math_fround($207 + $210);
 $214 = Math_fround($208 + $211);
 $215 = Math_fround($209 + $212);
 $216 = Math_fround($63 * Math_fround(0.0));
 $217 = Math_fround($64 * Math_fround(0.0));
 $218 = Math_fround($65 * Math_fround(0.0));
 $219 = Math_fround($216 + $213);
 $220 = Math_fround($217 + $214);
 $221 = Math_fround($218 + $215);
 $222 = Math_fround($67 + $219);
 $223 = Math_fround($69 + $220);
 $224 = Math_fround($71 + $221);
 $225 = Math_fround($222 - $31);
 $226 = Math_fround($223 - $33);
 $227 = Math_fround($224 - $35);
 $228 = Math_fround($20 * $225);
 $229 = Math_fround($21 * $226);
 $230 = Math_fround($228 + $229);
 $231 = Math_fround($22 * $227);
 $232 = Math_fround($231 + $230);
 $233 = Math_fround($23 * $225);
 $234 = Math_fround($25 * $226);
 $235 = Math_fround($233 + $234);
 $236 = Math_fround($26 * $227);
 $237 = Math_fround($236 + $235);
 $238 = Math_fround($27 * $225);
 $239 = Math_fround($28 * $226);
 $240 = Math_fround($238 + $239);
 $241 = Math_fround($29 * $227);
 $242 = Math_fround($241 + $240);
 $243 = Math_fround($20 * $174);
 $244 = Math_fround($23 * $174);
 $245 = Math_fround($27 * $174);
 $246 = Math_fround($21 * $175);
 $247 = Math_fround($25 * $175);
 $248 = Math_fround($28 * $175);
 $249 = Math_fround($243 + $246);
 $250 = Math_fround($244 + $247);
 $251 = Math_fround($245 + $248);
 $252 = Math_fround($22 * $176);
 $253 = Math_fround($26 * $176);
 $254 = Math_fround($29 * $176);
 $255 = Math_fround($252 + $249);
 $256 = Math_fround($253 + $250);
 $257 = Math_fround($254 + $251);
 $258 = Math_fround($20 * $189);
 $259 = Math_fround($23 * $189);
 $260 = Math_fround($27 * $189);
 $261 = Math_fround($21 * $190);
 $262 = Math_fround($25 * $190);
 $263 = Math_fround($28 * $190);
 $264 = Math_fround($258 + $261);
 $265 = Math_fround($259 + $262);
 $266 = Math_fround($260 + $263);
 $267 = Math_fround($22 * $191);
 $268 = Math_fround($26 * $191);
 $269 = Math_fround($29 * $191);
 $270 = Math_fround($267 + $264);
 $271 = Math_fround($268 + $265);
 $272 = Math_fround($269 + $266);
 $273 = Math_fround($20 * $204);
 $274 = Math_fround($23 * $204);
 $275 = Math_fround($27 * $204);
 $276 = Math_fround($21 * $205);
 $277 = Math_fround($25 * $205);
 $278 = Math_fround($28 * $205);
 $279 = Math_fround($273 + $276);
 $280 = Math_fround($274 + $277);
 $281 = Math_fround($275 + $278);
 $282 = Math_fround($22 * $206);
 $283 = Math_fround($26 * $206);
 $284 = Math_fround($29 * $206);
 $285 = Math_fround($282 + $279);
 $286 = Math_fround($283 + $280);
 $287 = Math_fround($284 + $281);
 $288 = (($convexMesh) + 54|0);
 $289 = HEAP8[$288>>0]|0;
 $290 = $289&255;
 $291 = ($290*12)|0;
 $292 = STACKTOP; STACKTOP = STACKTOP + ((((1*$291)|0)+15)&-16)|0;;
 $293 = (($convexMesh) + 56|0);
 $294 = HEAP32[$293>>2]|0;
 $295 = (($convexMesh) + 55|0);
 $296 = HEAP8[$295>>0]|0;
 $297 = $296&255;
 $298 = (($294) + (($297*20)|0)|0);
 $299 = ($289<<24>>24)==(0);
 if (!($299)) {
  $i$047 = 0;
  while(1) {
   $300 = (($298) + (($i$047*12)|0)|0);
   $301 = Math_fround(HEAPF32[$300>>2]);
   $302 = Math_fround($255 * $301);
   $303 = Math_fround($256 * $301);
   $304 = Math_fround($257 * $301);
   $305 = ((($298) + (($i$047*12)|0)|0) + 4|0);
   $306 = Math_fround(HEAPF32[$305>>2]);
   $307 = Math_fround($270 * $306);
   $308 = Math_fround($271 * $306);
   $309 = Math_fround($272 * $306);
   $310 = Math_fround($302 + $307);
   $311 = Math_fround($303 + $308);
   $312 = Math_fround($304 + $309);
   $313 = ((($298) + (($i$047*12)|0)|0) + 8|0);
   $314 = Math_fround(HEAPF32[$313>>2]);
   $315 = Math_fround($285 * $314);
   $316 = Math_fround($286 * $314);
   $317 = Math_fround($287 * $314);
   $318 = Math_fround($310 + $315);
   $319 = Math_fround($311 + $316);
   $320 = Math_fround($312 + $317);
   $321 = Math_fround($232 + $318);
   $322 = Math_fround($237 + $319);
   $323 = Math_fround($242 + $320);
   $324 = (($292) + (($i$047*12)|0)|0);
   HEAPF32[$324>>2] = $321;
   $325 = ((($292) + (($i$047*12)|0)|0) + 4|0);
   HEAPF32[$325>>2] = $322;
   $326 = ((($292) + (($i$047*12)|0)|0) + 8|0);
   HEAPF32[$326>>2] = $323;
   $327 = (($i$047) + 1)|0;
   $328 = ($327>>>0)<($290>>>0);
   if ($328) {
    $i$047 = $327;
   } else {
    break;
   }
  }
 }
 __ZN5physx2Gu27computeBoundsAroundVerticesERNS_9PxBounds3EjPKNS_6PxVec3E($convexBoundsInHfShape,$290,$292);
 $329 = (($hfUtil) + 12|0);
 $330 = HEAP32[$329>>2]|0;
 $331 = (($330) + 40|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = $332 <= Math_fround(0.0);
 $334 = $333 ? Math_fround(-3.40282346638528859812E+38) : Math_fround(3.40282346638528859812E+38);
 $335 = Math_fround(HEAPF32[$hfUtil>>2]);
 $336 = (($hfUtil) + 8|0);
 $337 = Math_fround(HEAPF32[$336>>2]);
 $338 = Math_fround(Math_fround(1.0) / $335);
 $339 = Math_fround(Math_fround(1.0) / $337);
 $340 = (($hfUtil) + 4|0);
 $341 = Math_fround(HEAPF32[$340>>2]);
 $342 = Math_fround(Math_fround(1.0) / $341);
 $343 = $335 > Math_fround(0.0);
 if ($343) {
  $344 = Math_fround(HEAPF32[$convexBoundsInHfShape>>2]);
  $345 = Math_fround($335 * $344);
  $346 = (Math_fround(Math_floor((Math_fround($345)))));
  $347 = (~~(($346)));
  $348 = (($330) + 16|0);
  $349 = HEAP32[$348>>2]|0;
  $350 = (($349) + -2)|0;
  $351 = ($347|0)>(0);
  $352 = $351 ? $347 : 0;
  $353 = ($352|0)>($350|0);
  $354 = $353 ? $350 : $352;
  $355 = (($convexBoundsInHfShape) + 12|0);
  $356 = Math_fround(HEAPF32[$355>>2]);
  $357 = Math_fround($335 * $356);
  $358 = (Math_fround(Math_ceil((Math_fround($357)))));
  $359 = (~~(($358)));
  $360 = (($349) + -1)|0;
  $361 = ($359|0)>(0);
  $362 = $361 ? $359 : 0;
  $363 = ($362|0)>($360|0);
  $364 = $363 ? $360 : $362;
  $maxRow$0 = $364;$minRow$0 = $354;
 } else {
  $365 = (($convexBoundsInHfShape) + 12|0);
  $366 = Math_fround(HEAPF32[$365>>2]);
  $367 = Math_fround($335 * $366);
  $368 = (Math_fround(Math_floor((Math_fround($367)))));
  $369 = (~~(($368)));
  $370 = (($330) + 16|0);
  $371 = HEAP32[$370>>2]|0;
  $372 = (($371) + -2)|0;
  $373 = ($369|0)>(0);
  $374 = $373 ? $369 : 0;
  $375 = ($374|0)>($372|0);
  $376 = $375 ? $372 : $374;
  $377 = Math_fround(HEAPF32[$convexBoundsInHfShape>>2]);
  $378 = Math_fround($335 * $377);
  $379 = (Math_fround(Math_ceil((Math_fround($378)))));
  $380 = (~~(($379)));
  $381 = (($371) + -1)|0;
  $382 = ($380|0)>(0);
  $383 = $382 ? $380 : 0;
  $384 = ($383|0)>($381|0);
  $385 = $384 ? $381 : $383;
  $maxRow$0 = $385;$minRow$0 = $376;
 }
 $386 = $337 > Math_fround(0.0);
 if ($386) {
  $387 = (($convexBoundsInHfShape) + 8|0);
  $388 = Math_fround(HEAPF32[$387>>2]);
  $389 = Math_fround($337 * $388);
  $390 = (Math_fround(Math_floor((Math_fround($389)))));
  $391 = (~~(($390)));
  $392 = (($330) + 20|0);
  $393 = HEAP32[$392>>2]|0;
  $394 = (($393) + -2)|0;
  $395 = ($391|0)>(0);
  $396 = $395 ? $391 : 0;
  $397 = ($396|0)>($394|0);
  $398 = $397 ? $394 : $396;
  $399 = (($convexBoundsInHfShape) + 20|0);
  $400 = Math_fround(HEAPF32[$399>>2]);
  $401 = Math_fround($337 * $400);
  $402 = (Math_fround(Math_ceil((Math_fround($401)))));
  $403 = (~~(($402)));
  $404 = (($393) + -1)|0;
  $405 = ($403|0)>(0);
  $406 = $405 ? $403 : 0;
  $407 = ($406|0)>($404|0);
  $408 = $407 ? $404 : $406;
  $435 = $393;$maxColumn$0 = $408;$minColumn$0 = $398;
 } else {
  $409 = (($convexBoundsInHfShape) + 20|0);
  $410 = Math_fround(HEAPF32[$409>>2]);
  $411 = Math_fround($337 * $410);
  $412 = (Math_fround(Math_floor((Math_fround($411)))));
  $413 = (~~(($412)));
  $414 = (($330) + 20|0);
  $415 = HEAP32[$414>>2]|0;
  $416 = (($415) + -2)|0;
  $417 = ($413|0)>(0);
  $418 = $417 ? $413 : 0;
  $419 = ($418|0)>($416|0);
  $420 = $419 ? $416 : $418;
  $421 = (($convexBoundsInHfShape) + 8|0);
  $422 = Math_fround(HEAPF32[$421>>2]);
  $423 = Math_fround($337 * $422);
  $424 = (Math_fround(Math_ceil((Math_fround($423)))));
  $425 = (~~(($424)));
  $426 = (($415) + -1)|0;
  $427 = ($425|0)>(0);
  $428 = $427 ? $425 : 0;
  $429 = ($428|0)>($426|0);
  $430 = $429 ? $426 : $428;
  $435 = $415;$maxColumn$0 = $430;$minColumn$0 = $420;
 }
 $431 = ($minRow$0>>>0)>($maxRow$0>>>0);
 if ($431) {
  $hfExtreme$0$lcssa = $334;
 } else {
  $432 = ($minColumn$0>>>0)>($maxColumn$0>>>0);
  $433 = (($330) + 36|0);
  $hfExtreme$043 = $334;$row$042 = $minRow$0;
  while(1) {
   if ($432) {
    $hfExtreme$1$lcssa = $hfExtreme$043;
   } else {
    $434 = Math_imul($435, $row$042)|0;
    $436 = HEAP32[$433>>2]|0;
    $437 = !($332 <= Math_fround(0.0));
    $column$038 = $minColumn$0;$hfExtreme$139 = $hfExtreme$043;
    while(1) {
     $438 = (($434) + ($column$038))|0;
     $439 = (($436) + ($438<<2)|0);
     $440 = HEAP16[$439>>1]|0;
     $441 = (Math_fround(($440<<16>>16)));
     if ($437) {
      $443 = $hfExtreme$139 < $441;
      $$sink = $443;
     } else {
      $442 = $hfExtreme$139 > $441;
      $$sink = $442;
     }
     $444 = $$sink ? $hfExtreme$139 : $441;
     $445 = (($column$038) + 1)|0;
     $446 = ($445>>>0)>($maxColumn$0>>>0);
     if ($446) {
      $hfExtreme$1$lcssa = $444;
      break;
     } else {
      $column$038 = $445;$hfExtreme$139 = $444;
     }
    }
   }
   $447 = (($row$042) + 1)|0;
   $448 = ($447>>>0)>($maxRow$0>>>0);
   if ($448) {
    $hfExtreme$0$lcssa = $hfExtreme$1$lcssa;
    break;
   } else {
    $hfExtreme$043 = $hfExtreme$1$lcssa;$row$042 = $447;
   }
  }
 }
 $449 = Math_fround($342 * $hfExtreme$0$lcssa);
 $450 = !($332 <= Math_fround(0.0));
 if ($450) {
  $454 = (($convexBoundsInHfShape) + 16|0);
  $455 = Math_fround(HEAPF32[$454>>2]);
  $456 = $455 < $449;
  if ($456) {
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
  }
 } else {
  $451 = (($convexBoundsInHfShape) + 4|0);
  $452 = Math_fround(HEAPF32[$451>>2]);
  $453 = $452 > $449;
  if ($453) {
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
  }
 }
 $457 = HEAP8[$288>>0]|0;
 $458 = ($457<<24>>24)==(0);
 L33: do {
  if ($458) {
   $515 = 0;
  } else {
   $459 = (($hfUtil) + 16|0);
   $461 = $332;$i1$033 = 0;
   L35: while(1) {
    $460 = !($461 <= Math_fround(0.0));
    $462 = ((($292) + (($i1$033*12)|0)|0) + 4|0);
    $463 = Math_fround(HEAPF32[$462>>2]);
    if ($460) {
     $465 = $463 > $449;
     if ($465) {
      label = 26;
     }
    } else {
     $464 = $463 < $449;
     if ($464) {
      label = 26;
     }
    }
    do {
     if ((label|0) == 26) {
      label = 0;
      $466 = (($292) + (($i1$033*12)|0)|0);
      $467 = Math_fround(HEAPF32[$466>>2]);
      $468 = ((($292) + (($i1$033*12)|0)|0) + 8|0);
      $469 = Math_fround(HEAPF32[$468>>2]);
      $470 = Math_fround(HEAPF32[$hfUtil>>2]);
      $471 = Math_fround($467 * $470);
      $472 = Math_fround(HEAPF32[$336>>2]);
      $473 = Math_fround($469 * $472);
      $474 = !($471 >= Math_fround(0.0));
      $475 = !($473 >= Math_fround(0.0));
      $or$cond$i8 = $474 | $475;
      if (!($or$cond$i8)) {
       $476 = HEAP32[$329>>2]|0;
       $477 = (($476) + 24|0);
       $478 = Math_fround(HEAPF32[$477>>2]);
       $479 = Math_fround($478 + Math_fround(1.0));
       $480 = $471 < $479;
       if ($480) {
        $481 = (($476) + 28|0);
        $482 = Math_fround(HEAPF32[$481>>2]);
        $483 = Math_fround($482 + Math_fround(1.0));
        $484 = $473 < $483;
        if ($484) {
         $485 = HEAP32[$459>>2]|0;
         $486 = (($485) + 8|0);
         $487 = Math_fround(HEAPF32[$486>>2]);
         $488 = (__ZNK5physx2Gu11HeightField22computeCellCoordinatesEffRfS2_($476,$471,$473,$fracX$i$i,$fracZ$i$i)|0);
         $489 = Math_fround(HEAPF32[$fracX$i$i>>2]);
         $490 = Math_fround(HEAPF32[$fracZ$i$i>>2]);
         $491 = (Math_fround(__ZNK5physx2Gu11HeightField18getHeightInternal2Ejff($476,$488,$489,$490)));
         $492 = Math_fround($487 * $491);
         $493 = Math_fround(HEAPF32[$462>>2]);
         $494 = Math_fround($493 - $492);
         $495 = Math_fround(HEAPF32[$331>>2]);
         $496 = !($495 <= Math_fround(0.0));
         $497 = !($494 <= Math_fround(0.0));
         $or$cond$i = $496 | $497;
         $498 = !($495 <= $494);
         $or$cond1$i = $or$cond$i | $498;
         if ($or$cond1$i) {
          $499 = $495 > Math_fround(0.0);
          $500 = $494 > Math_fround(-0.0);
          $or$cond = $499 & $500;
          $501 = $495 > $494;
          $or$cond13 = $or$cond & $501;
          if (!($or$cond13)) {
           break;
          }
         }
         $502 = Math_fround(HEAPF32[$466>>2]);
         $503 = Math_fround(HEAPF32[$468>>2]);
         $504 = (__ZNK5physx2Gu15HeightFieldUtil24getFaceIndexAtShapePointEff($hfUtil,$502,$503)|0);
         $505 = ($504|0)==(-1);
         if (!($505)) {
          $$2 = 1;
          break L35;
         }
        }
       }
      }
     }
    } while(0);
    $506 = (($i1$033) + 1)|0;
    $507 = HEAP8[$288>>0]|0;
    $508 = $507&255;
    $509 = ($506>>>0)<($508>>>0);
    if (!($509)) {
     $515 = $507;
     break L33;
    }
    $$pre = Math_fround(HEAPF32[$331>>2]);
    $461 = $$pre;$i1$033 = $506;
   }
   STACKTOP = sp;return ($$2|0);
  }
 } while(0);
 dest=$fracX$i$i+0|0; stop=dest+128|0; do { HEAP16[dest>>1]=0|0; dest=dest+2|0; } while ((dest|0) < (stop|0));
 $510 = HEAP8[$295>>0]|0;
 $511 = $510&255;
 $512 = HEAP32[$293>>2]|0;
 $513 = (($512) + (($511*20)|0)|0);
 $514 = $515&255;
 $516 = (($convexMesh) + 52|0);
 $517 = HEAP16[$516>>1]|0;
 $518 = $517&65535;
 $519 = $518 << 1;
 $tmp2$i = ($514*15)|0;
 $$sum1$i = (($519) + ($tmp2$i))|0;
 $520 = ($510<<24>>24)==(0);
 L52: do {
  if (!($520)) {
   $521 = (($v0) + 4|0);
   $522 = (($v0) + 8|0);
   $523 = (($v1) + 4|0);
   $524 = (($v1) + 8|0);
   $$in = $511;$polygons$027 = $512;
   L54: while(1) {
    $526 = (($$in) + -1)|0;
    $527 = (($polygons$027) + 20|0);
    $528 = (($polygons$027) + 16|0);
    $529 = HEAP16[$528>>1]|0;
    $530 = $529&65535;
    $531 = (($polygons$027) + 18|0);
    $532 = HEAP8[$531>>0]|0;
    $533 = $532&255;
    $534 = (($533) + -1)|0;
    $$sum = (($530) + ($$sum1$i))|0;
    $a$0$ph = $534;$b$0$ph = 0;$numEdges$0$ph = $533;
    L56: while(1) {
     $$sum14 = (($$sum) + ($a$0$ph))|0;
     $535 = (($513) + ($$sum14)|0);
     $$sum15 = (($$sum) + ($b$0$ph))|0;
     $536 = (($513) + ($$sum15)|0);
     $numEdges$0 = $numEdges$0$ph;
     while(1) {
      $537 = (($numEdges$0) + -1)|0;
      $538 = ($numEdges$0|0)==(0);
      if ($538) {
       break L56;
      }
      $539 = HEAP8[$535>>0]|0;
      $540 = HEAP8[$536>>0]|0;
      $541 = ($540&255)<($539&255);
      $$ = $541 ? $540 : $539;
      $$5 = $541 ? $539 : $540;
      $542 = $$&255;
      $543 = $542 << 8;
      $544 = $$5&255;
      $545 = $543 | $544;
      $546 = $545 << 15;
      $547 = $546 ^ -1;
      $548 = (($545) + ($547))|0;
      $549 = $548 >>> 10;
      $550 = $549 ^ $548;
      $551 = ($550*9)|0;
      $552 = $551 >>> 6;
      $553 = $552 ^ $551;
      $554 = $553 << 11;
      $555 = $554 ^ -1;
      $556 = (($553) + ($555))|0;
      $557 = $556 >>> 16;
      $558 = $557 ^ $556;
      $559 = $558 & 63;
      $560 = (($fracX$i$i) + ($559<<1)|0);
      $561 = HEAP16[$560>>1]|0;
      $562 = $561&65535;
      $563 = ($562|0)==($545|0);
      if ($563) {
       $numEdges$0 = $537;
      } else {
       break;
      }
     }
     $564 = $545&65535;
     HEAP16[$560>>1] = $564;
     $565 = (($b$0$ph) + 1)|0;
     $566 = Math_fround(HEAPF32[$331>>2]);
     $567 = !($566 <= Math_fround(0.0));
     $568 = ((($292) + (($542*12)|0)|0) + 4|0);
     $569 = Math_fround(HEAPF32[$568>>2]);
     if ($567) {
      $574 = $569 < $449;
      if ($574) {
       $575 = ((($292) + (($544*12)|0)|0) + 4|0);
       $576 = Math_fround(HEAPF32[$575>>2]);
       $577 = $576 < $449;
       if ($577) {
        $a$0$ph$phi = $b$0$ph;$b$0$ph = $565;$numEdges$0$ph = $537;$a$0$ph = $a$0$ph$phi;
        continue;
       }
      }
     } else {
      $570 = $569 > $449;
      if ($570) {
       $571 = ((($292) + (($544*12)|0)|0) + 4|0);
       $572 = Math_fround(HEAPF32[$571>>2]);
       $573 = $572 > $449;
       if ($573) {
        $a$0$ph$phi = $b$0$ph;$b$0$ph = $565;$numEdges$0$ph = $537;$a$0$ph = $a$0$ph$phi;
        continue;
       }
      }
     }
     $578 = (($292) + (($542*12)|0)|0);
     $579 = Math_fround(HEAPF32[$578>>2]);
     HEAPF32[$v0>>2] = $579;
     HEAPF32[$521>>2] = $569;
     $580 = ((($292) + (($542*12)|0)|0) + 8|0);
     $581 = Math_fround(HEAPF32[$580>>2]);
     HEAPF32[$522>>2] = $581;
     $582 = (($292) + (($544*12)|0)|0);
     $583 = Math_fround(HEAPF32[$582>>2]);
     HEAPF32[$v1>>2] = $583;
     $584 = ((($292) + (($544*12)|0)|0) + 4|0);
     $585 = Math_fround(HEAPF32[$584>>2]);
     HEAPF32[$523>>2] = $585;
     $586 = ((($292) + (($544*12)|0)|0) + 8|0);
     $587 = Math_fround(HEAPF32[$586>>2]);
     HEAPF32[$524>>2] = $587;
     HEAP8[$cb>>0] = 0;
     __ZNK5physx2Gu15HeightFieldUtil12traceSegmentINS0_27TriggerTraceSegmentCallbackELb0ELb0ELb0EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$v0,$v1,$cb,0);
     $588 = HEAP8[$cb>>0]|0;
     $589 = ($588<<24>>24)==(0);
     if ($589) {
      $a$0$ph$phi = $b$0$ph;$b$0$ph = $565;$numEdges$0$ph = $537;$a$0$ph = $a$0$ph$phi;
     } else {
      $$2 = 1;
      break L54;
     }
    }
    $525 = ($526|0)==(0);
    if ($525) {
     break L52;
    } else {
     $$in = $526;$polygons$027 = $527;
    }
   }
   STACKTOP = sp;return ($$2|0);
  }
 } while(0);
 $590 = Math_fround($31 - $67);
 $591 = Math_fround($33 - $69);
 $592 = Math_fround($35 - $71);
 $593 = Math_fround($590 * $56);
 $594 = Math_fround($57 * $591);
 $595 = Math_fround($593 + $594);
 $596 = Math_fround($58 * $592);
 $597 = Math_fround($595 + $596);
 $598 = Math_fround($590 * $59);
 $599 = Math_fround($61 * $591);
 $600 = Math_fround($598 + $599);
 $601 = Math_fround($62 * $592);
 $602 = Math_fround($600 + $601);
 $603 = Math_fround($590 * $63);
 $604 = Math_fround($64 * $591);
 $605 = Math_fround($603 + $604);
 $606 = Math_fround($65 * $592);
 $607 = Math_fround($605 + $606);
 $608 = Math_fround($20 * $56);
 $609 = Math_fround($20 * $59);
 $610 = Math_fround($20 * $63);
 $611 = Math_fround($21 * $57);
 $612 = Math_fround($21 * $61);
 $613 = Math_fround($21 * $64);
 $614 = Math_fround($608 + $611);
 $615 = Math_fround($609 + $612);
 $616 = Math_fround($610 + $613);
 $617 = Math_fround($22 * $58);
 $618 = Math_fround($22 * $62);
 $619 = Math_fround($22 * $65);
 $620 = Math_fround($617 + $614);
 $621 = Math_fround($618 + $615);
 $622 = Math_fround($619 + $616);
 $623 = Math_fround($23 * $56);
 $624 = Math_fround($23 * $59);
 $625 = Math_fround($23 * $63);
 $626 = Math_fround($25 * $57);
 $627 = Math_fround($25 * $61);
 $628 = Math_fround($25 * $64);
 $629 = Math_fround($623 + $626);
 $630 = Math_fround($624 + $627);
 $631 = Math_fround($625 + $628);
 $632 = Math_fround($26 * $58);
 $633 = Math_fround($26 * $62);
 $634 = Math_fround($26 * $65);
 $635 = Math_fround($632 + $629);
 $636 = Math_fround($633 + $630);
 $637 = Math_fround($634 + $631);
 $638 = Math_fround($27 * $56);
 $639 = Math_fround($27 * $59);
 $640 = Math_fround($27 * $63);
 $641 = Math_fround($28 * $57);
 $642 = Math_fround($28 * $61);
 $643 = Math_fround($28 * $64);
 $644 = Math_fround($638 + $641);
 $645 = Math_fround($639 + $642);
 $646 = Math_fround($640 + $643);
 $647 = Math_fround($29 * $58);
 $648 = Math_fround($29 * $62);
 $649 = Math_fround($29 * $65);
 $650 = Math_fround($647 + $644);
 $651 = Math_fround($648 + $645);
 $652 = Math_fround($649 + $646);
 $653 = Math_fround($620 * $129);
 $654 = Math_fround($620 * $130);
 $655 = Math_fround($620 * $131);
 $656 = Math_fround($621 * $144);
 $657 = Math_fround($621 * $145);
 $658 = Math_fround($621 * $146);
 $659 = Math_fround($653 + $656);
 $660 = Math_fround($654 + $657);
 $661 = Math_fround($655 + $658);
 $662 = Math_fround($622 * $159);
 $663 = Math_fround($622 * $160);
 $664 = Math_fround($622 * $161);
 $665 = Math_fround($662 + $659);
 $666 = Math_fround($663 + $660);
 $667 = Math_fround($664 + $661);
 $668 = Math_fround($635 * $129);
 $669 = Math_fround($635 * $130);
 $670 = Math_fround($635 * $131);
 $671 = Math_fround($636 * $144);
 $672 = Math_fround($636 * $145);
 $673 = Math_fround($636 * $146);
 $674 = Math_fround($668 + $671);
 $675 = Math_fround($669 + $672);
 $676 = Math_fround($670 + $673);
 $677 = Math_fround($637 * $159);
 $678 = Math_fround($637 * $160);
 $679 = Math_fround($637 * $161);
 $680 = Math_fround($677 + $674);
 $681 = Math_fround($678 + $675);
 $682 = Math_fround($679 + $676);
 $683 = Math_fround($650 * $129);
 $684 = Math_fround($650 * $130);
 $685 = Math_fround($650 * $131);
 $686 = Math_fround($651 * $144);
 $687 = Math_fround($651 * $145);
 $688 = Math_fround($651 * $146);
 $689 = Math_fround($683 + $686);
 $690 = Math_fround($684 + $687);
 $691 = Math_fround($685 + $688);
 $692 = Math_fround($652 * $159);
 $693 = Math_fround($652 * $160);
 $694 = Math_fround($652 * $161);
 $695 = Math_fround($692 + $689);
 $696 = Math_fround($693 + $690);
 $697 = Math_fround($694 + $691);
 $698 = Math_fround($597 * $129);
 $699 = Math_fround($597 * $130);
 $700 = Math_fround($597 * $131);
 $701 = Math_fround($602 * $144);
 $702 = Math_fround($602 * $145);
 $703 = Math_fround($602 * $146);
 $704 = Math_fround($698 + $701);
 $705 = Math_fround($699 + $702);
 $706 = Math_fround($700 + $703);
 $707 = Math_fround($607 * $159);
 $708 = Math_fround($607 * $160);
 $709 = Math_fround($607 * $161);
 $710 = Math_fround($707 + $704);
 $711 = Math_fround($708 + $705);
 $712 = Math_fround($709 + $706);
 $713 = Math_fround($710 + Math_fround(0.0));
 $714 = Math_fround($711 + Math_fround(0.0));
 $715 = Math_fround($712 + Math_fround(0.0));
 if ($431) {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $716 = ($minColumn$0>>>0)>($maxColumn$0>>>0);
 $717 = (($330) + 20|0);
 $718 = (($330) + 36|0);
 $row2$020 = $minRow$0;
 L74: while(1) {
  if (!($716)) {
   $719 = HEAP32[$717>>2]|0;
   $720 = Math_imul($719, $row2$020)|0;
   $721 = HEAP32[$329>>2]|0;
   $722 = (($721) + 36|0);
   $723 = HEAP32[$722>>2]|0;
   $724 = (Math_fround(($row2$020>>>0)));
   $725 = Math_fround($338 * $724);
   $726 = Math_fround($665 * $725);
   $727 = Math_fround($666 * $725);
   $728 = Math_fround($667 * $725);
   $column3$017 = $minColumn$0;
   while(1) {
    $729 = (($720) + ($column3$017))|0;
    $730 = ((($723) + ($729<<2)|0) + 3|0);
    $731 = HEAP8[$730>>0]|0;
    $732 = ($731<<24>>24)<(0);
    L80: do {
     if ($732) {
      $733 = HEAP32[$718>>2]|0;
      $734 = (($733) + ($729<<2)|0);
      $735 = HEAP16[$734>>1]|0;
      $736 = (Math_fround(($735<<16>>16)));
      $737 = Math_fround($342 * $736);
      $738 = (Math_fround(($column3$017>>>0)));
      $739 = Math_fround($339 * $738);
      $740 = Math_fround($680 * $737);
      $741 = Math_fround($681 * $737);
      $742 = Math_fround($682 * $737);
      $743 = Math_fround($726 + $740);
      $744 = Math_fround($727 + $741);
      $745 = Math_fround($728 + $742);
      $746 = Math_fround($695 * $739);
      $747 = Math_fround($696 * $739);
      $748 = Math_fround($697 * $739);
      $749 = Math_fround($746 + $743);
      $750 = Math_fround($747 + $744);
      $751 = Math_fround($748 + $745);
      $752 = Math_fround($713 + $749);
      $753 = Math_fround($714 + $750);
      $754 = Math_fround($715 + $751);
      $755 = HEAP8[$295>>0]|0;
      $756 = ($755<<24>>24)==(0);
      if ($756) {
       $$2 = 1;
       label = 58;
       break L74;
      }
      $757 = HEAP32[$293>>2]|0;
      $poly$016 = 0;
      while(1) {
       $761 = (($757) + (($poly$016*20)|0)|0);
       $762 = Math_fround(HEAPF32[$761>>2]);
       $763 = Math_fround($752 * $762);
       $764 = ((($757) + (($poly$016*20)|0)|0) + 4|0);
       $765 = Math_fround(HEAPF32[$764>>2]);
       $766 = Math_fround($753 * $765);
       $767 = Math_fround($763 + $766);
       $768 = ((($757) + (($poly$016*20)|0)|0) + 8|0);
       $769 = Math_fround(HEAPF32[$768>>2]);
       $770 = Math_fround($754 * $769);
       $771 = Math_fround($767 + $770);
       $772 = ((($757) + (($poly$016*20)|0)|0) + 12|0);
       $773 = Math_fround(HEAPF32[$772>>2]);
       $774 = Math_fround($773 + $771);
       $775 = !($774 >= Math_fround(0.0));
       $760 = (($poly$016) + 1)|0;
       if (!($775)) {
        break L80;
       }
       $758 = $755&255;
       $759 = ($760>>>0)<($758>>>0);
       if ($759) {
        $poly$016 = $760;
       } else {
        $$2 = 1;
        label = 58;
        break L74;
       }
      }
     }
    } while(0);
    $776 = (($column3$017) + 1)|0;
    $777 = ($776>>>0)>($maxColumn$0>>>0);
    if ($777) {
     break;
    } else {
     $column3$017 = $776;
    }
   }
  }
  $778 = (($row2$020) + 1)|0;
  $779 = ($778>>>0)>($maxRow$0>>>0);
  if ($779) {
   $$2 = 0;
   label = 58;
   break;
  } else {
   $row2$020 = $778;
  }
 }
 if ((label|0) == 58) {
  STACKTOP = sp;return ($$2|0);
 }
 return 0|0;
}
function __ZN5physx2Gu31checkOverlapOBB_heightFieldGeomERKNS_10PxGeometryERKNS_11PxTransformERKNS0_3BoxE($geom,$pose,$box) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $boxInHfShape = 0, $hfUtil = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $boxInHfShape = sp + 20|0;
 $hfUtil = sp;
 $0 = (($pose) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($pose) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($pose) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($1 * Math_fround(-2.0));
 $7 = Math_fround($3 * Math_fround(-2.0));
 $8 = Math_fround($5 * Math_fround(-2.0));
 $9 = (($pose) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $10);
 $12 = Math_fround($11 + Math_fround(-0.5));
 $13 = Math_fround(HEAPF32[$pose>>2]);
 $14 = Math_fround($6 * $13);
 $15 = (($pose) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($pose) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($8 * $20);
 $22 = Math_fround($18 + $21);
 $23 = Math_fround($6 * $12);
 $24 = Math_fround($8 * $16);
 $25 = Math_fround($7 * $20);
 $26 = Math_fround($24 - $25);
 $27 = Math_fround($10 * $26);
 $28 = Math_fround($23 - $27);
 $29 = Math_fround($13 * $22);
 $30 = Math_fround($29 + $28);
 $31 = Math_fround($7 * $12);
 $32 = Math_fround($6 * $20);
 $33 = Math_fround($8 * $13);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($10 * $34);
 $36 = Math_fround($31 - $35);
 $37 = Math_fround($16 * $22);
 $38 = Math_fround($37 + $36);
 $39 = Math_fround($8 * $12);
 $40 = Math_fround($7 * $13);
 $41 = Math_fround($6 * $16);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($10 * $42);
 $44 = Math_fround($39 - $43);
 $45 = Math_fround($20 * $22);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround(-$13);
 $48 = Math_fround(-$16);
 $49 = Math_fround(-$20);
 $50 = Math_fround($47 - $13);
 $51 = Math_fround($48 - $16);
 $52 = Math_fround($49 - $20);
 $53 = Math_fround($10 * $50);
 $54 = Math_fround($10 * $51);
 $55 = Math_fround($10 * $52);
 $56 = Math_fround($50 * $47);
 $57 = Math_fround($51 * $47);
 $58 = Math_fround($52 * $47);
 $59 = Math_fround($51 * $48);
 $60 = Math_fround($52 * $48);
 $61 = Math_fround($52 * $49);
 $62 = Math_fround(Math_fround(1.0) - $59);
 $63 = Math_fround($62 - $61);
 $64 = Math_fround($57 + $55);
 $65 = Math_fround($58 - $54);
 $66 = Math_fround($57 - $55);
 $67 = Math_fround(Math_fround(1.0) - $56);
 $68 = Math_fround($67 - $61);
 $69 = Math_fround($53 + $60);
 $70 = Math_fround($54 + $58);
 $71 = Math_fround($60 - $53);
 $72 = Math_fround($67 - $59);
 $73 = (($box) + 36|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($74 * $63);
 $76 = Math_fround($74 * $64);
 $77 = Math_fround($74 * $65);
 $78 = (($box) + 40|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 * $66);
 $81 = Math_fround($79 * $68);
 $82 = Math_fround($79 * $69);
 $83 = Math_fround($75 + $80);
 $84 = Math_fround($76 + $81);
 $85 = Math_fround($77 + $82);
 $86 = (($box) + 44|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($87 * $70);
 $89 = Math_fround($87 * $71);
 $90 = Math_fround($72 * $87);
 $91 = Math_fround($88 + $83);
 $92 = Math_fround($89 + $84);
 $93 = Math_fround($90 + $85);
 $94 = Math_fround($30 + $91);
 $95 = Math_fround($38 + $92);
 $96 = Math_fround($46 + $93);
 $97 = Math_fround(HEAPF32[$box>>2]);
 $98 = Math_fround($63 * $97);
 $99 = Math_fround($64 * $97);
 $100 = Math_fround($65 * $97);
 $101 = (($box) + 4|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($66 * $102);
 $104 = Math_fround($68 * $102);
 $105 = Math_fround($69 * $102);
 $106 = Math_fround($98 + $103);
 $107 = Math_fround($99 + $104);
 $108 = Math_fround($100 + $105);
 $109 = (($box) + 8|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($70 * $110);
 $112 = Math_fround($71 * $110);
 $113 = Math_fround($72 * $110);
 $114 = Math_fround($106 + $111);
 $115 = Math_fround($107 + $112);
 $116 = Math_fround($108 + $113);
 $117 = (($box) + 12|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = Math_fround($63 * $118);
 $120 = Math_fround($64 * $118);
 $121 = Math_fround($65 * $118);
 $122 = (($box) + 16|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($66 * $123);
 $125 = Math_fround($68 * $123);
 $126 = Math_fround($69 * $123);
 $127 = Math_fround($119 + $124);
 $128 = Math_fround($120 + $125);
 $129 = Math_fround($121 + $126);
 $130 = (($box) + 20|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround($70 * $131);
 $133 = Math_fround($71 * $131);
 $134 = Math_fround($72 * $131);
 $135 = Math_fround($127 + $132);
 $136 = Math_fround($128 + $133);
 $137 = Math_fround($129 + $134);
 $138 = (($box) + 24|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($63 * $139);
 $141 = Math_fround($64 * $139);
 $142 = Math_fround($65 * $139);
 $143 = (($box) + 28|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround($66 * $144);
 $146 = Math_fround($68 * $144);
 $147 = Math_fround($69 * $144);
 $148 = Math_fround($140 + $145);
 $149 = Math_fround($141 + $146);
 $150 = Math_fround($142 + $147);
 $151 = (($box) + 32|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = Math_fround($70 * $152);
 $154 = Math_fround($71 * $152);
 $155 = Math_fround($72 * $152);
 $156 = Math_fround($148 + $153);
 $157 = Math_fround($149 + $154);
 $158 = Math_fround($150 + $155);
 HEAPF32[$boxInHfShape>>2] = $114;
 $159 = (($boxInHfShape) + 4|0);
 HEAPF32[$159>>2] = $115;
 $160 = (($boxInHfShape) + 8|0);
 HEAPF32[$160>>2] = $116;
 $161 = (($boxInHfShape) + 12|0);
 HEAPF32[$161>>2] = $135;
 $162 = (($boxInHfShape) + 16|0);
 HEAPF32[$162>>2] = $136;
 $163 = (($boxInHfShape) + 20|0);
 HEAPF32[$163>>2] = $137;
 $164 = (($boxInHfShape) + 24|0);
 HEAPF32[$164>>2] = $156;
 $165 = (($boxInHfShape) + 28|0);
 HEAPF32[$165>>2] = $157;
 $166 = (($boxInHfShape) + 32|0);
 HEAPF32[$166>>2] = $158;
 $167 = (($boxInHfShape) + 36|0);
 HEAPF32[$167>>2] = $94;
 $168 = (($boxInHfShape) + 40|0);
 HEAPF32[$168>>2] = $95;
 $169 = (($boxInHfShape) + 44|0);
 HEAPF32[$169>>2] = $96;
 $170 = (($boxInHfShape) + 48|0);
 $171 = (($box) + 48|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 HEAPF32[$170>>2] = $172;
 $173 = (($boxInHfShape) + 52|0);
 $174 = (($box) + 52|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 HEAPF32[$173>>2] = $175;
 $176 = (($boxInHfShape) + 56|0);
 $177 = (($box) + 56|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 HEAPF32[$176>>2] = $178;
 $179 = (($hfUtil) + 12|0);
 $180 = (($geom) + 4|0);
 $181 = HEAP32[$180>>2]|0;
 HEAP32[$179>>2] = $181;
 $182 = (($hfUtil) + 16|0);
 HEAP32[$182>>2] = $geom;
 $183 = (($geom) + 8|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = Math_fround(Math_fround(1.0) / $184);
 $186 = (($hfUtil) + 4|0);
 HEAPF32[$186>>2] = $185;
 $187 = (($geom) + 12|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = Math_fround(Math_fround(1.0) / $188);
 HEAPF32[$hfUtil>>2] = $189;
 $190 = (($geom) + 16|0);
 $191 = Math_fround(HEAPF32[$190>>2]);
 $192 = Math_fround(Math_fround(1.0) / $191);
 $193 = (($hfUtil) + 8|0);
 HEAPF32[$193>>2] = $192;
 $194 = (__ZN5physx2Gu23intersectHeightFieldBoxERKNS0_15HeightFieldUtilERKNS0_3BoxE($hfUtil,$boxInHfShape)|0);
 STACKTOP = sp;return ($194|0);
}
function __Z37GeomOverlapCallback_SphereHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $hfUtil = 0, $sphereInHf = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $sphereInHf = sp + 24|0;
 $hfUtil = sp;
 $0 = (($transform0) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($transform1) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($transform0) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform1) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($transform0) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * Math_fround(2.0));
 $16 = Math_fround($9 * Math_fround(2.0));
 $17 = Math_fround($14 * Math_fround(2.0));
 $18 = (($transform1) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $19);
 $21 = Math_fround($20 + Math_fround(-0.5));
 $22 = Math_fround(HEAPF32[$transform1>>2]);
 $23 = Math_fround($15 * $22);
 $24 = (($transform1) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($16 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($transform1) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($17 * $29);
 $31 = Math_fround($27 + $30);
 $32 = Math_fround($15 * $21);
 $33 = Math_fround($17 * $25);
 $34 = Math_fround($16 * $29);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($19 * $35);
 $37 = Math_fround($32 - $36);
 $38 = Math_fround($22 * $31);
 $39 = Math_fround($38 + $37);
 $40 = Math_fround($16 * $21);
 $41 = Math_fround($15 * $29);
 $42 = Math_fround($17 * $22);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($19 * $43);
 $45 = Math_fround($40 - $44);
 $46 = Math_fround($25 * $31);
 $47 = Math_fround($46 + $45);
 $48 = Math_fround($17 * $21);
 $49 = Math_fround($16 * $22);
 $50 = Math_fround($15 * $25);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($19 * $51);
 $53 = Math_fround($48 - $52);
 $54 = Math_fround($29 * $31);
 $55 = Math_fround($53 + $54);
 $56 = (($geom0) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 HEAPF32[$sphereInHf>>2] = $39;
 $58 = (($sphereInHf) + 4|0);
 HEAPF32[$58>>2] = $47;
 $59 = (($sphereInHf) + 8|0);
 HEAPF32[$59>>2] = $55;
 $60 = (($sphereInHf) + 12|0);
 HEAPF32[$60>>2] = $57;
 $61 = (($hfUtil) + 12|0);
 $62 = (($geom1) + 4|0);
 $63 = HEAP32[$62>>2]|0;
 HEAP32[$61>>2] = $63;
 $64 = (($hfUtil) + 16|0);
 HEAP32[$64>>2] = $geom1;
 $65 = (($geom1) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround(Math_fround(1.0) / $66);
 $68 = (($hfUtil) + 4|0);
 HEAPF32[$68>>2] = $67;
 $69 = (($geom1) + 12|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround(Math_fround(1.0) / $70);
 HEAPF32[$hfUtil>>2] = $71;
 $72 = (($geom1) + 16|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround(Math_fround(1.0) / $73);
 $75 = (($hfUtil) + 8|0);
 HEAPF32[$75>>2] = $74;
 $76 = (__ZN5physx2Gu26intersectHeightFieldSphereERKNS0_15HeightFieldUtilERKNS0_6SphereE($hfUtil,$sphereInHf)|0);
 STACKTOP = sp;return ($76|0);
}
function __Z36GeomOverlapCallback_PlaneHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z38GeomOverlapCallback_CapsuleHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $capsuleInHfShape = 0, $hfUtil = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $capsuleInHfShape = sp + 20|0;
 $hfUtil = sp;
 $0 = Math_fround(HEAPF32[$transform1>>2]);
 $1 = Math_fround(-$0);
 $2 = (($transform1) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(-$3);
 $5 = (($transform1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 $8 = (($transform1) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($transform0) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($transform0) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transform1) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = (($transform0) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transform1) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 $25 = Math_fround($14 * Math_fround(2.0));
 $26 = Math_fround($19 * Math_fround(2.0));
 $27 = Math_fround($24 * Math_fround(2.0));
 $28 = Math_fround($9 * $9);
 $29 = Math_fround($28 + Math_fround(-0.5));
 $30 = Math_fround($25 * $1);
 $31 = Math_fround($26 * $4);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($27 * $7);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($29 * $25);
 $36 = Math_fround($27 * $4);
 $37 = Math_fround($26 * $7);
 $38 = Math_fround($36 - $37);
 $39 = Math_fround($9 * $38);
 $40 = Math_fround($35 + $39);
 $41 = Math_fround($34 * $1);
 $42 = Math_fround($41 + $40);
 $43 = Math_fround($29 * $26);
 $44 = Math_fround($25 * $7);
 $45 = Math_fround($27 * $1);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($9 * $46);
 $48 = Math_fround($43 + $47);
 $49 = Math_fround($34 * $4);
 $50 = Math_fround($49 + $48);
 $51 = Math_fround($29 * $27);
 $52 = Math_fround($26 * $1);
 $53 = Math_fround($25 * $4);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($9 * $54);
 $56 = Math_fround($51 + $55);
 $57 = Math_fround($34 * $7);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround(HEAPF32[$transform0>>2]);
 $60 = Math_fround($9 * $59);
 $61 = (($transform0) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * $1);
 $64 = Math_fround($60 + $63);
 $65 = (($transform0) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $4);
 $68 = Math_fround($64 + $67);
 $69 = (($transform0) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $7);
 $72 = Math_fround($68 - $71);
 $73 = Math_fround($9 * $70);
 $74 = Math_fround($62 * $4);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($59 * $7);
 $77 = Math_fround($76 + $75);
 $78 = Math_fround($66 * $1);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($9 * $66);
 $81 = Math_fround($62 * $7);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($70 * $1);
 $84 = Math_fround($83 + $82);
 $85 = Math_fround($59 * $4);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($9 * $62);
 $88 = Math_fround($59 * $1);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($70 * $4);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($66 * $7);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($72 * Math_fround(2.0));
 $95 = Math_fround($93 * Math_fround(2.0));
 $96 = Math_fround($93 * $95);
 $97 = Math_fround($96 + Math_fround(-1.0));
 $98 = Math_fround($72 * $94);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($86 * $95);
 $101 = Math_fround($94 * $79);
 $102 = Math_fround($100 + $101);
 $103 = Math_fround($95 * $79);
 $104 = Math_fround($94 * $86);
 $105 = Math_fround($104 - $103);
 $106 = (($geom0) + 8|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($107 * $99);
 $109 = Math_fround($107 * $102);
 $110 = Math_fround($107 * $105);
 $111 = Math_fround($42 + $108);
 $112 = Math_fround($50 + $109);
 $113 = Math_fround($58 + $110);
 HEAPF32[$capsuleInHfShape>>2] = $111;
 $114 = (($capsuleInHfShape) + 4|0);
 HEAPF32[$114>>2] = $112;
 $115 = (($capsuleInHfShape) + 8|0);
 HEAPF32[$115>>2] = $113;
 $116 = Math_fround($42 - $108);
 $117 = Math_fround($50 - $109);
 $118 = Math_fround($58 - $110);
 $119 = (($capsuleInHfShape) + 12|0);
 HEAPF32[$119>>2] = $116;
 $120 = (($capsuleInHfShape) + 16|0);
 HEAPF32[$120>>2] = $117;
 $121 = (($capsuleInHfShape) + 20|0);
 HEAPF32[$121>>2] = $118;
 $122 = (($geom0) + 4|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($capsuleInHfShape) + 24|0);
 HEAPF32[$124>>2] = $123;
 $125 = (($hfUtil) + 12|0);
 $126 = (($geom1) + 4|0);
 $127 = HEAP32[$126>>2]|0;
 HEAP32[$125>>2] = $127;
 $128 = (($hfUtil) + 16|0);
 HEAP32[$128>>2] = $geom1;
 $129 = (($geom1) + 8|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = Math_fround(Math_fround(1.0) / $130);
 $132 = (($hfUtil) + 4|0);
 HEAPF32[$132>>2] = $131;
 $133 = (($geom1) + 12|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = Math_fround(Math_fround(1.0) / $134);
 HEAPF32[$hfUtil>>2] = $135;
 $136 = (($geom1) + 16|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround(Math_fround(1.0) / $137);
 $139 = (($hfUtil) + 8|0);
 HEAPF32[$139>>2] = $138;
 $140 = (__ZN5physx2Gu27intersectHeightFieldCapsuleERKNS0_15HeightFieldUtilERKNS0_7CapsuleE($hfUtil,$capsuleInHfShape)|0);
 STACKTOP = sp;return ($140|0);
}
function __Z34GeomOverlapCallback_BoxHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0;
 var $152 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0;
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $box = 0, $hfUtil = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $box = sp + 20|0;
 $hfUtil = sp;
 $0 = Math_fround(HEAPF32[$transform1>>2]);
 $1 = Math_fround(-$0);
 $2 = (($transform1) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(-$3);
 $5 = (($transform1) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 $8 = (($transform1) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($transform0) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($transform0) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($transform1) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = (($transform0) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transform1) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 $25 = Math_fround($14 * Math_fround(2.0));
 $26 = Math_fround($19 * Math_fround(2.0));
 $27 = Math_fround($24 * Math_fround(2.0));
 $28 = Math_fround($9 * $9);
 $29 = Math_fround($28 + Math_fround(-0.5));
 $30 = Math_fround($25 * $1);
 $31 = Math_fround($26 * $4);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($27 * $7);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($29 * $25);
 $36 = Math_fround($27 * $4);
 $37 = Math_fround($26 * $7);
 $38 = Math_fround($36 - $37);
 $39 = Math_fround($9 * $38);
 $40 = Math_fround($35 + $39);
 $41 = Math_fround($34 * $1);
 $42 = Math_fround($41 + $40);
 $43 = Math_fround($29 * $26);
 $44 = Math_fround($25 * $7);
 $45 = Math_fround($27 * $1);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($9 * $46);
 $48 = Math_fround($43 + $47);
 $49 = Math_fround($34 * $4);
 $50 = Math_fround($49 + $48);
 $51 = Math_fround($29 * $27);
 $52 = Math_fround($26 * $1);
 $53 = Math_fround($25 * $4);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($9 * $54);
 $56 = Math_fround($51 + $55);
 $57 = Math_fround($34 * $7);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround(HEAPF32[$transform0>>2]);
 $60 = Math_fround($9 * $59);
 $61 = (($transform0) + 12|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($62 * $1);
 $64 = Math_fround($60 + $63);
 $65 = (($transform0) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $4);
 $68 = Math_fround($64 + $67);
 $69 = (($transform0) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $7);
 $72 = Math_fround($68 - $71);
 $73 = Math_fround($9 * $70);
 $74 = Math_fround($62 * $4);
 $75 = Math_fround($74 + $73);
 $76 = Math_fround($59 * $7);
 $77 = Math_fround($76 + $75);
 $78 = Math_fround($66 * $1);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($9 * $66);
 $81 = Math_fround($62 * $7);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($70 * $1);
 $84 = Math_fround($83 + $82);
 $85 = Math_fround($59 * $4);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($9 * $62);
 $88 = Math_fround($59 * $1);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($70 * $4);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($66 * $7);
 $93 = Math_fround($91 - $92);
 $94 = (($geom0) + 4|0);
 $95 = (($box) + 36|0);
 HEAPF32[$95>>2] = $42;
 $96 = (($box) + 40|0);
 HEAPF32[$96>>2] = $50;
 $97 = (($box) + 44|0);
 HEAPF32[$97>>2] = $58;
 $98 = Math_fround(HEAPF32[$94>>2]);
 $99 = (($box) + 48|0);
 HEAPF32[$99>>2] = $98;
 $100 = (($geom0) + 8|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($box) + 52|0);
 HEAPF32[$102>>2] = $101;
 $103 = (($geom0) + 12|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($box) + 56|0);
 HEAPF32[$105>>2] = $104;
 $106 = Math_fround($72 + $72);
 $107 = Math_fround($79 + $79);
 $108 = Math_fround($86 + $86);
 $109 = Math_fround($72 * $106);
 $110 = Math_fround($79 * $107);
 $111 = Math_fround($86 * $108);
 $112 = Math_fround($106 * $79);
 $113 = Math_fround($106 * $86);
 $114 = Math_fround($106 * $93);
 $115 = Math_fround($86 * $107);
 $116 = Math_fround($93 * $107);
 $117 = Math_fround($93 * $108);
 $118 = Math_fround(Math_fround(1.0) - $110);
 $119 = Math_fround($118 - $111);
 $120 = Math_fround($112 + $117);
 $121 = Math_fround($113 - $116);
 $122 = Math_fround($112 - $117);
 $123 = Math_fround(Math_fround(1.0) - $109);
 $124 = Math_fround($123 - $111);
 $125 = Math_fround($114 + $115);
 $126 = Math_fround($113 + $116);
 $127 = Math_fround($115 - $114);
 $128 = Math_fround($123 - $110);
 HEAPF32[$box>>2] = $119;
 $129 = (($box) + 4|0);
 HEAPF32[$129>>2] = $120;
 $130 = (($box) + 8|0);
 HEAPF32[$130>>2] = $121;
 $131 = (($box) + 12|0);
 HEAPF32[$131>>2] = $122;
 $132 = (($box) + 16|0);
 HEAPF32[$132>>2] = $124;
 $133 = (($box) + 20|0);
 HEAPF32[$133>>2] = $125;
 $134 = (($box) + 24|0);
 HEAPF32[$134>>2] = $126;
 $135 = (($box) + 28|0);
 HEAPF32[$135>>2] = $127;
 $136 = (($box) + 32|0);
 HEAPF32[$136>>2] = $128;
 $137 = (($hfUtil) + 12|0);
 $138 = (($geom1) + 4|0);
 $139 = HEAP32[$138>>2]|0;
 HEAP32[$137>>2] = $139;
 $140 = (($hfUtil) + 16|0);
 HEAP32[$140>>2] = $geom1;
 $141 = (($geom1) + 8|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround(Math_fround(1.0) / $142);
 $144 = (($hfUtil) + 4|0);
 HEAPF32[$144>>2] = $143;
 $145 = (($geom1) + 12|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = Math_fround(Math_fround(1.0) / $146);
 HEAPF32[$hfUtil>>2] = $147;
 $148 = (($geom1) + 16|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = Math_fround(Math_fround(1.0) / $149);
 $151 = (($hfUtil) + 8|0);
 HEAPF32[$151>>2] = $150;
 $152 = (__ZN5physx2Gu23intersectHeightFieldBoxERKNS0_15HeightFieldUtilERKNS0_3BoxE($hfUtil,$box)|0);
 STACKTOP = sp;return ($152|0);
}
function __Z37GeomOverlapCallback_ConvexHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE($geom0,$transform0,$geom1,$transform1,$cache) {
 $geom0 = $geom0|0;
 $transform0 = $transform0|0;
 $geom1 = $geom1|0;
 $transform1 = $transform1|0;
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $hfUtil = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $hfUtil = sp;
 $0 = (($geom0) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($hfUtil) + 12|0);
 $3 = (($geom1) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = (($hfUtil) + 16|0);
 HEAP32[$5>>2] = $geom1;
 $6 = (($geom1) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(Math_fround(1.0) / $7);
 $9 = (($hfUtil) + 4|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($geom1) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(Math_fround(1.0) / $11);
 HEAPF32[$hfUtil>>2] = $12;
 $13 = (($geom1) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(Math_fround(1.0) / $14);
 $16 = (($hfUtil) + 8|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($geom0) + 4|0);
 $18 = (__ZN5physx2Gu26intersectHeightFieldConvexERKNS0_15HeightFieldUtilERKNS_11PxTransformERKNS0_10ConvexMeshES6_RKNS_11PxMeshScaleE($hfUtil,$transform1,$1,$transform0,$17)|0);
 STACKTOP = sp;return ($18|0);
}
function __Z28sweepCapsule_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$lss,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $lss = $lss|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$0 = 0, $$tr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $capsuleAABBBExtentHfLocalSpace = 0, $capsuleBox = 0, $capsuleV = 0, $centerLocalSpace = 0;
 var $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i9 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i8 = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i2$i1 = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i3$i7 = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i4$i6 = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i5$i2 = Math_fround(0), $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i6$i5 = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i7$i4 = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $fabsf$i$i8$i3 = Math_fround(0), $hfUtil = 0, $inflatedCapsule = 0;
 var $myReport = 0, $phitmp = 0, $radius$sroa$1 = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $zero$sroa$1$i$i$i = sp + 360|0;
 $0 = sp;
 $inflatedCapsule = sp + 332|0;
 $capsuleBox = sp + 272|0;
 $myReport = sp + 232|0;
 $hfUtil = sp + 184|0;
 $centerLocalSpace = sp + 204|0;
 $capsuleAABBBExtentHfLocalSpace = sp + 172|0;
 $1 = sp + 160|0;
 $radius$sroa$1 = sp + 216|0;
 $capsuleV = sp + 16|0;
 $2 = (($lss) + 24|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 + $inflation);
 $5 = Math_fround(HEAPF32[$lss>>2]);
 HEAPF32[$inflatedCapsule>>2] = $5;
 $6 = (($inflatedCapsule) + 4|0);
 $7 = (($lss) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$6>>2] = $8;
 $9 = (($inflatedCapsule) + 8|0);
 $10 = (($lss) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$9>>2] = $11;
 $12 = (($inflatedCapsule) + 12|0);
 $13 = (($lss) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$12>>2] = $14;
 $15 = (($inflatedCapsule) + 16|0);
 $16 = (($lss) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$15>>2] = $17;
 $18 = (($inflatedCapsule) + 20|0);
 $19 = (($lss) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$18>>2] = $20;
 $21 = (($inflatedCapsule) + 24|0);
 HEAPF32[$21>>2] = $4;
 __ZN5physx2Gu23computeBoxAroundCapsuleERKNS0_7CapsuleERNS0_3BoxE($inflatedCapsule,$capsuleBox);
 $22 = Math_fround(HEAPF32[$capsuleBox>>2]);
 $fabsf$i$i2$i1 = (Math_fround(Math_abs((Math_fround($22)))));
 $23 = (($capsuleBox) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $fabsf$i$i5$i2 = (Math_fround(Math_abs((Math_fround($24)))));
 $25 = (($capsuleBox) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $fabsf$i$i8$i3 = (Math_fround(Math_abs((Math_fround($26)))));
 $27 = (($capsuleBox) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $fabsf$i$i7$i4 = (Math_fround(Math_abs((Math_fround($28)))));
 $29 = (($27) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $fabsf$i$i6$i5 = (Math_fround(Math_abs((Math_fround($30)))));
 $31 = (($27) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $fabsf$i$i4$i6 = (Math_fround(Math_abs((Math_fround($32)))));
 $33 = (($capsuleBox) + 24|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $fabsf$i$i3$i7 = (Math_fround(Math_abs((Math_fround($34)))));
 $35 = (($33) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $fabsf$i$i1$i8 = (Math_fround(Math_abs((Math_fround($36)))));
 $37 = (($33) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $fabsf$i$i$i9 = (Math_fround(Math_abs((Math_fround($38)))));
 $39 = (($capsuleBox) + 48|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($capsuleBox) + 52|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($capsuleBox) + 56|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($fabsf$i$i2$i1 * $40);
 $46 = Math_fround($fabsf$i$i7$i4 * $42);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($fabsf$i$i3$i7 * $44);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($fabsf$i$i5$i2 * $40);
 $51 = Math_fround($fabsf$i$i6$i5 * $42);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($fabsf$i$i1$i8 * $44);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($fabsf$i$i8$i3 * $40);
 $56 = Math_fround($fabsf$i$i4$i6 * $42);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($fabsf$i$i$i9 * $44);
 $59 = Math_fround($57 + $58);
 HEAP32[$myReport>>2] = ((554008 + 8|0));
 $60 = (($myReport) + 24|0);
 HEAP8[$60>>0] = 0;
 $61 = (($myReport) + 25|0);
 HEAP8[$61>>0] = 0;
 $62 = (($hfUtil) + 12|0);
 $63 = (($geom) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 HEAP32[$62>>2] = $64;
 $65 = (($hfUtil) + 16|0);
 HEAP32[$65>>2] = $geom;
 $66 = (($geom) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround(Math_fround(1.0) / $67);
 $69 = (($hfUtil) + 4|0);
 HEAPF32[$69>>2] = $68;
 $70 = (($geom) + 12|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround(Math_fround(1.0) / $71);
 HEAPF32[$hfUtil>>2] = $72;
 $73 = (($geom) + 16|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround(Math_fround(1.0) / $74);
 $76 = (($hfUtil) + 8|0);
 HEAPF32[$76>>2] = $75;
 $77 = (($myReport) + 28|0);
 HEAP32[$77>>2] = $pose;
 $78 = (($myReport) + 32|0);
 HEAP32[$78>>2] = $hfUtil;
 $79 = (($myReport) + 4|0);
 HEAP32[$79>>2] = $inflatedCapsule;
 $80 = (($myReport) + 8|0);
 HEAP32[$80>>2] = $unitDir;
 $81 = (($myReport) + 12|0);
 HEAPF32[$81>>2] = $distance;
 $82 = (($myReport) + 16|0);
 HEAP32[$82>>2] = $sweepHit;
 $83 = (($myReport) + 20|0);
 HEAP32[$83>>2] = $hintFlags;
 $84 = (($geom) + 20|0);
 $85 = HEAP8[$84>>0]|0;
 $86 = $85 & 2;
 $87 = ($86<<24>>24)==(0);
 if ($87) {
  $88 = HEAP16[$hintFlags>>1]|0;
  $89 = ($88&65535) >>> 7;
  $$tr = $89&255;
  $phitmp = $$tr & 1;
  $91 = $phitmp;
 } else {
  $91 = 1;
 }
 $90 = (($myReport) + 36|0);
 HEAP8[$90>>0] = $91;
 $92 = (($sweepHit) + 40|0);
 HEAPF32[$92>>2] = Math_fround(3.40282346638528859812E+38);
 $93 = (($pose) + 16|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($pose) + 20|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($pose) + 24|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($94 * Math_fround(-2.0));
 $100 = Math_fround($96 * Math_fround(-2.0));
 $101 = Math_fround($98 * Math_fround(-2.0));
 $102 = (($pose) + 12|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($103 * $103);
 $105 = Math_fround($104 + Math_fround(-0.5));
 $106 = Math_fround(HEAPF32[$pose>>2]);
 $107 = Math_fround($99 * $106);
 $108 = (($pose) + 4|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($100 * $109);
 $111 = Math_fround($107 + $110);
 $112 = (($pose) + 8|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($101 * $113);
 $115 = Math_fround($111 + $114);
 $116 = Math_fround($99 * $105);
 $117 = Math_fround($101 * $109);
 $118 = Math_fround($100 * $113);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($103 * $119);
 $121 = Math_fround($116 - $120);
 $122 = Math_fround($106 * $115);
 $123 = Math_fround($122 + $121);
 $124 = Math_fround($100 * $105);
 $125 = Math_fround($99 * $113);
 $126 = Math_fround($101 * $106);
 $127 = Math_fround($125 - $126);
 $128 = Math_fround($103 * $127);
 $129 = Math_fround($124 - $128);
 $130 = Math_fround($109 * $115);
 $131 = Math_fround($130 + $129);
 $132 = Math_fround($101 * $105);
 $133 = Math_fround($100 * $106);
 $134 = Math_fround($99 * $109);
 $135 = Math_fround($133 - $134);
 $136 = Math_fround($103 * $135);
 $137 = Math_fround($132 - $136);
 $138 = Math_fround($113 * $115);
 $139 = Math_fround($137 + $138);
 $140 = Math_fround(-$106);
 $141 = Math_fround(-$109);
 $142 = Math_fround(-$113);
 $143 = (($capsuleBox) + 36|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround($144 * Math_fround(2.0));
 $146 = (($capsuleBox) + 40|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = Math_fround($147 * Math_fround(2.0));
 $149 = (($capsuleBox) + 44|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = Math_fround($150 * Math_fround(2.0));
 $152 = Math_fround($145 * $140);
 $153 = Math_fround($148 * $141);
 $154 = Math_fround($152 + $153);
 $155 = Math_fround($151 * $142);
 $156 = Math_fround($154 + $155);
 $157 = Math_fround($105 * $145);
 $158 = Math_fround($151 * $141);
 $159 = Math_fround($148 * $142);
 $160 = Math_fround($158 - $159);
 $161 = Math_fround($103 * $160);
 $162 = Math_fround($157 + $161);
 $163 = Math_fround($156 * $140);
 $164 = Math_fround($163 + $162);
 $165 = Math_fround($105 * $148);
 $166 = Math_fround($145 * $142);
 $167 = Math_fround($151 * $140);
 $168 = Math_fround($166 - $167);
 $169 = Math_fround($103 * $168);
 $170 = Math_fround($165 + $169);
 $171 = Math_fround($156 * $141);
 $172 = Math_fround($171 + $170);
 $173 = Math_fround($105 * $151);
 $174 = Math_fround($148 * $140);
 $175 = Math_fround($145 * $141);
 $176 = Math_fround($174 - $175);
 $177 = Math_fround($103 * $176);
 $178 = Math_fround($173 + $177);
 $179 = Math_fround($156 * $142);
 $180 = Math_fround($178 + $179);
 $181 = Math_fround($123 + $164);
 $182 = Math_fround($131 + $172);
 $183 = Math_fround($139 + $180);
 HEAPF32[$centerLocalSpace>>2] = $181;
 $184 = (($centerLocalSpace) + 4|0);
 HEAPF32[$184>>2] = $182;
 $185 = (($centerLocalSpace) + 8|0);
 HEAPF32[$185>>2] = $183;
 $186 = Math_fround(HEAPF32[$unitDir>>2]);
 $187 = Math_fround($186 * Math_fround(2.0));
 $188 = (($unitDir) + 4|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = Math_fround($189 * Math_fround(2.0));
 $191 = (($unitDir) + 8|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = Math_fround($192 * Math_fround(2.0));
 $194 = Math_fround($187 * $140);
 $195 = Math_fround($190 * $141);
 $196 = Math_fround($194 + $195);
 $197 = Math_fround($193 * $142);
 $198 = Math_fround($196 + $197);
 $199 = Math_fround($105 * $187);
 $200 = Math_fround($193 * $141);
 $201 = Math_fround($190 * $142);
 $202 = Math_fround($200 - $201);
 $203 = Math_fround($103 * $202);
 $204 = Math_fround($199 + $203);
 $205 = Math_fround($198 * $140);
 $206 = Math_fround($205 + $204);
 $207 = Math_fround($105 * $190);
 $208 = Math_fround($187 * $142);
 $209 = Math_fround($193 * $140);
 $210 = Math_fround($208 - $209);
 $211 = Math_fround($103 * $210);
 $212 = Math_fround($207 + $211);
 $213 = Math_fround($198 * $141);
 $214 = Math_fround($213 + $212);
 $215 = Math_fround($105 * $193);
 $216 = Math_fround($190 * $140);
 $217 = Math_fround($187 * $141);
 $218 = Math_fround($216 - $217);
 $219 = Math_fround($103 * $218);
 $220 = Math_fround($215 + $219);
 $221 = Math_fround($198 * $142);
 $222 = Math_fround($220 + $221);
 $223 = Math_fround($140 - $106);
 $224 = Math_fround($141 - $109);
 $225 = Math_fround($142 - $113);
 $226 = Math_fround($223 * $140);
 $227 = Math_fround($224 * $141);
 $228 = Math_fround($225 * $142);
 $229 = Math_fround($223 * $141);
 $230 = Math_fround($223 * $142);
 $231 = Math_fround($103 * $223);
 $232 = Math_fround($224 * $142);
 $233 = Math_fround($103 * $224);
 $234 = Math_fround($103 * $225);
 $235 = Math_fround(Math_fround(1.0) - $227);
 $236 = Math_fround($235 - $228);
 $237 = Math_fround($229 + $234);
 $238 = Math_fround($230 - $233);
 $239 = Math_fround($229 - $234);
 $240 = Math_fround(Math_fround(1.0) - $226);
 $241 = Math_fround($240 - $228);
 $242 = Math_fround($231 + $232);
 $243 = Math_fround($230 + $233);
 $244 = Math_fround($232 - $231);
 $245 = Math_fround($240 - $227);
 $246 = Math_fround($49 * $236);
 $247 = Math_fround($49 * $237);
 $248 = Math_fround($49 * $238);
 $249 = Math_fround($54 * $239);
 $250 = Math_fround($54 * $241);
 $251 = Math_fround($54 * $242);
 $252 = Math_fround($59 * $243);
 $253 = Math_fround($59 * $244);
 $254 = Math_fround($59 * $245);
 $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($246)))));
 $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($249)))));
 $255 = Math_fround($fabsf$i$i4$i + $fabsf$i$i5$i);
 $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($252)))));
 $256 = Math_fround($255 + $fabsf$i$i6$i);
 $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($247)))));
 $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($250)))));
 $257 = Math_fround($fabsf$i$i7$i + $fabsf$i$i8$i);
 $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($253)))));
 $258 = Math_fround($257 + $fabsf$i$i3$i);
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($248)))));
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($251)))));
 $259 = Math_fround($fabsf$i$i2$i + $fabsf$i$i1$i);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($254)))));
 $260 = Math_fround($259 + $fabsf$i$i$i);
 $261 = Math_fround($181 - $256);
 $262 = Math_fround($182 - $258);
 $263 = Math_fround($183 - $260);
 $264 = Math_fround($256 + $181);
 $265 = Math_fround($258 + $182);
 $266 = Math_fround($183 + $260);
 $267 = Math_fround($264 - $261);
 $268 = Math_fround($265 - $262);
 $269 = Math_fround($266 - $263);
 $270 = Math_fround($267 * Math_fround(0.5));
 $271 = Math_fround($268 * Math_fround(0.5));
 $272 = Math_fround($269 * Math_fround(0.5));
 HEAPF32[$capsuleAABBBExtentHfLocalSpace>>2] = $270;
 $273 = (($capsuleAABBBExtentHfLocalSpace) + 4|0);
 HEAPF32[$273>>2] = $271;
 $274 = (($capsuleAABBBExtentHfLocalSpace) + 8|0);
 HEAPF32[$274>>2] = $272;
 $275 = Math_fround($206 * $distance);
 $276 = Math_fround($214 * $distance);
 $277 = Math_fround($222 * $distance);
 $278 = Math_fround(HEAPF32[$centerLocalSpace>>2]);
 $279 = Math_fround($275 + $278);
 $280 = Math_fround(HEAPF32[$184>>2]);
 $281 = Math_fround($276 + $280);
 $282 = Math_fround(HEAPF32[$185>>2]);
 $283 = Math_fround($277 + $282);
 HEAPF32[$1>>2] = $279;
 $284 = (($1) + 4|0);
 HEAPF32[$284>>2] = $281;
 $285 = (($1) + 8|0);
 HEAPF32[$285>>2] = $283;
 __ZNK5physx2Gu15HeightFieldUtil12traceSegmentI25CapsuleTraceSegmentReportLb0ELb0ELb1EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$centerLocalSpace,$1,$myReport,$capsuleAABBBExtentHfLocalSpace);
 $286 = HEAP16[$60>>1]|0;
 $287 = $286&255;
 $288 = ($287<<24>>24)==(0);
 if ($288) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $289 = ($286&65535)<(256);
 $290 = (($sweepHit) + 12|0);
 if ($289) {
  HEAP16[$290>>1] = 7;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP16[$290>>1] = 6;
 $291 = HEAP16[$hintFlags>>1]|0;
 $292 = $291 & 512;
 $293 = ($292<<16>>16)==(0);
 if ($293) {
  HEAPF32[$92>>2] = Math_fround(0.0);
  $345 = Math_fround(HEAPF32[$unitDir>>2]);
  $346 = Math_fround(-$345);
  $347 = Math_fround(HEAPF32[$188>>2]);
  $348 = Math_fround(-$347);
  $349 = Math_fround(HEAPF32[$191>>2]);
  $350 = Math_fround(-$349);
  $351 = (($sweepHit) + 28|0);
  HEAPF32[$351>>2] = $346;
  $352 = (($sweepHit) + 32|0);
  HEAPF32[$352>>2] = $348;
  $353 = (($sweepHit) + 36|0);
  HEAPF32[$353>>2] = $350;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $294 = Math_fround(HEAPF32[$lss>>2]);
 $295 = Math_fround(HEAPF32[$7>>2]);
 $296 = Math_fround(HEAPF32[$10>>2]);
 $297 = Math_fround(HEAPF32[$13>>2]);
 $298 = Math_fround(HEAPF32[$16>>2]);
 $299 = Math_fround(HEAPF32[$19>>2]);
 $300 = Math_fround(HEAPF32[$2>>2]);
 $301 = (($capsuleV) + 64|0);
 $302 = (($capsuleV) + 80|0);
 HEAP32[$302>>2] = 4;
 $303 = (($capsuleV) + 16|0);
 $304 = (($capsuleV) + 20|0);
 $305 = (($capsuleV) + 32|0);
 $306 = (($capsuleV) + 36|0);
 $307 = (($capsuleV) + 48|0);
 HEAPF32[$307>>2] = Math_fround(0.0);
 $308 = (($capsuleV) + 52|0);
 ;HEAP32[$308+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$308+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$308+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$301+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$301+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$301+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$301+12>>2]=HEAP32[$0+12>>2]|0;
 $309 = (($capsuleV) + 128|0);
 HEAPF32[$309>>2] = $300;
 $310 = (($capsuleV) + 132|0);
 ;HEAP32[$310+0>>2]=HEAP32[$radius$sroa$1+0>>2]|0;HEAP32[$310+4>>2]=HEAP32[$radius$sroa$1+4>>2]|0;HEAP32[$310+8>>2]=HEAP32[$radius$sroa$1+8>>2]|0;
 $311 = (($capsuleV) + 96|0);
 HEAPF32[$311>>2] = $294;
 $312 = (($capsuleV) + 100|0);
 HEAPF32[$312>>2] = $295;
 $313 = (($capsuleV) + 104|0);
 HEAPF32[$313>>2] = $296;
 $314 = (($capsuleV) + 108|0);
 HEAPF32[$314>>2] = Math_fround(0.0);
 $315 = (($capsuleV) + 112|0);
 HEAPF32[$315>>2] = $297;
 $316 = (($capsuleV) + 116|0);
 HEAPF32[$316>>2] = $298;
 $317 = (($capsuleV) + 120|0);
 HEAPF32[$317>>2] = $299;
 $318 = (($capsuleV) + 124|0);
 HEAPF32[$318>>2] = Math_fround(0.0);
 HEAPF32[$303>>2] = $300;
 ;HEAP32[$304+0>>2]=HEAP32[$radius$sroa$1+0>>2]|0;HEAP32[$304+4>>2]=HEAP32[$radius$sroa$1+4>>2]|0;HEAP32[$304+8>>2]=HEAP32[$radius$sroa$1+8>>2]|0;
 HEAPF32[$305>>2] = $300;
 ;HEAP32[$306+0>>2]=HEAP32[$radius$sroa$1+0>>2]|0;HEAP32[$306+4>>2]=HEAP32[$radius$sroa$1+4>>2]|0;HEAP32[$306+8>>2]=HEAP32[$radius$sroa$1+8>>2]|0;
 $319 = Math_fround($294 + $297);
 $320 = Math_fround($295 + $298);
 $321 = Math_fround($296 + $299);
 $322 = Math_fround($319 * Math_fround(0.5));
 $323 = Math_fround($320 * Math_fround(0.5));
 $324 = Math_fround($321 * Math_fround(0.5));
 HEAPF32[$capsuleV>>2] = $322;
 $325 = (($capsuleV) + 4|0);
 HEAPF32[$325>>2] = $323;
 $326 = (($capsuleV) + 8|0);
 HEAPF32[$326>>2] = $324;
 $327 = (($capsuleV) + 12|0);
 HEAPF32[$327>>2] = Math_fround(0.0);
 $328 = Math_fround(HEAPF32[$21>>2]);
 $329 = HEAP8[$90>>0]|0;
 $330 = ($329<<24>>24)!=(0);
 $331 = (__ZN5physx2Gu29computeCapsule_HeightFieldMTDERKNS_21PxHeightFieldGeometryERKNS_11PxTransformERNS0_8CapsuleVEffbjRNS_10PxSweepHitE($geom,$pose,$capsuleV,$328,$distance,$330,1,$sweepHit)|0);
 if ($331) {
  $341 = HEAP16[$290>>1]|0;
  $342 = $341&65535;
  $343 = $342 | 1;
  $344 = $343&65535;
  HEAP16[$290>>1] = $344;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAPF32[$92>>2] = Math_fround(0.0);
  $332 = Math_fround(HEAPF32[$unitDir>>2]);
  $333 = Math_fround(-$332);
  $334 = Math_fround(HEAPF32[$188>>2]);
  $335 = Math_fround(-$334);
  $336 = Math_fround(HEAPF32[$191>>2]);
  $337 = Math_fround(-$336);
  $338 = (($sweepHit) + 28|0);
  HEAPF32[$338>>2] = $333;
  $339 = (($sweepHit) + 32|0);
  HEAPF32[$339>>2] = $335;
  $340 = (($sweepHit) + 36|0);
  HEAPF32[$340>>2] = $337;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu15HeightFieldUtil12traceSegmentI25CapsuleTraceSegmentReportLb0ELb0ELb1EEEvRKNS_6PxVec3ES6_PT_PS5_($this,$aP0,$aP1,$aCallback,$overlapObjectExtent) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $aCallback = $aCallback|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 var $$$i = 0, $$1$i = 0, $$pre = 0, $$pre$i$pre = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre8$i$pre = 0, $$sink = Math_fround(0), $$sink1 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0;
 var $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0);
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0);
 var $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $du$0 = Math_fround(0), $dv$0 = Math_fround(0), $expandu = 0, $expandv = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i4 = Math_fround(0), $fabsf$i$i7 = Math_fround(0), $fabsf$i$i8 = Math_fround(0), $line$i = 0, $localBounds = 0, $not$$i = 0, $not$1$i = 0, $or$cond = 0, $or$cond24 = 0, $overlapTraceSegment = 0;
 var $rayDir = 0, $tfar = 0, $tnear = 0, $tu$0 = Math_fround(0), $tu$1 = Math_fround(0), $tv$0 = Math_fround(0), $tv$1 = Math_fround(0), $ui$0 = 0, $ui$04$i = 0, $ui$1 = 0, $vi$0 = 0, $vi$02$i = 0, $vi$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $line$i = sp + 216|0;
 $localBounds = sp;
 $overlapTraceSegment = sp + 24|0;
 $expandu = sp + 184|0;
 $expandv = sp + 188|0;
 $rayDir = sp + 192|0;
 $tnear = sp + 204|0;
 $tfar = sp + 208|0;
 __ZNK5physx2Gu15HeightFieldUtil18computeLocalBoundsERNS_9PxBounds3E($this,$localBounds);
 $0 = Math_fround(HEAPF32[$localBounds>>2]);
 $1 = Math_fround(HEAPF32[$overlapObjectExtent>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($localBounds) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($overlapObjectExtent) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($localBounds) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($overlapObjectExtent) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 HEAPF32[$localBounds>>2] = $2;
 HEAPF32[$3>>2] = $7;
 HEAPF32[$8>>2] = $12;
 $13 = (($localBounds) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 + $1);
 $16 = (($localBounds) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 + $6);
 $19 = (($localBounds) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 + $11);
 HEAPF32[$13>>2] = $15;
 HEAPF32[$16>>2] = $18;
 HEAPF32[$19>>2] = $21;
 $22 = (($this) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP8[$overlapTraceSegment>>0] = 0;
 $24 = (($overlapTraceSegment) + 4|0);
 HEAP32[$24>>2] = $this;
 $25 = (($overlapTraceSegment) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = (($overlapTraceSegment) + 156|0);
 HEAP32[$26>>2] = 0;
 HEAPF32[$expandu>>2] = Math_fround(0.0);
 HEAPF32[$expandv>>2] = Math_fround(0.0);
 $27 = Math_fround(HEAPF32[$aP1>>2]);
 $28 = Math_fround(HEAPF32[$aP0>>2]);
 $29 = Math_fround($27 - $28);
 $30 = (($aP1) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($aP0) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($31 - $33);
 $35 = (($aP1) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($aP0) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 - $38);
 HEAPF32[$rayDir>>2] = $29;
 $40 = (($rayDir) + 4|0);
 HEAPF32[$40>>2] = $34;
 $41 = (($rayDir) + 8|0);
 HEAPF32[$41>>2] = $39;
 $42 = (__ZN5physx2Gu17intersectRayAABB2ERKNS_6PxVec3ES3_S3_S3_fRfS4_($localBounds,$13,$aP0,$rayDir,Math_fround(1.0),$tnear,$tfar)|0);
 if (!($42)) {
  STACKTOP = sp;return;
 }
 $43 = Math_fround(HEAPF32[$tnear>>2]);
 $44 = Math_fround(HEAPF32[$rayDir>>2]);
 $45 = Math_fround($43 * $44);
 $46 = Math_fround(HEAPF32[$41>>2]);
 $47 = Math_fround($43 * $46);
 $48 = Math_fround(HEAPF32[$aP0>>2]);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround(HEAPF32[$37>>2]);
 $51 = Math_fround($47 + $50);
 $52 = Math_fround(HEAPF32[$tfar>>2]);
 $53 = Math_fround($44 * $52);
 $54 = Math_fround($46 * $52);
 $55 = Math_fround($48 + $53);
 $56 = Math_fround($50 + $54);
 __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI25CapsuleTraceSegmentReportE7prepareERKNS_6PxVec3ES7_S7_RfS8_($overlapTraceSegment,$aP0,$aP1,$overlapObjectExtent,$expandu,$expandv);
 $57 = HEAP32[$22>>2]|0;
 $58 = (($57) + 20|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 16|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = Math_fround(HEAPF32[$this>>2]);
 $63 = (($this) + 8|0);
 $64 = (($61) + -1)|0;
 $65 = (Math_fround(($64|0)));
 $66 = Math_fround($65 * Math_fround(0.999999880790710449218));
 $67 = (($59) + -1)|0;
 $68 = (Math_fround(($67|0)));
 $69 = Math_fround($68 * Math_fround(0.999999880790710449218));
 $70 = Math_fround($49 * $62);
 $71 = Math_fround(HEAPF32[$expandu>>2]);
 $72 = Math_fround(Math_fround(1.00000001168609742308E-7) - $71);
 $73 = $70 > $72;
 $74 = $73 ? $70 : $72;
 $75 = Math_fround($71 + $66);
 $76 = $74 < $75;
 $77 = $76 ? $74 : $75;
 $78 = Math_fround(HEAPF32[$63>>2]);
 $79 = Math_fround($51 * $78);
 $80 = Math_fround(HEAPF32[$expandv>>2]);
 $81 = Math_fround(Math_fround(1.00000001168609742308E-7) - $80);
 $82 = $79 > $81;
 $83 = $82 ? $79 : $81;
 $84 = Math_fround($69 + $80);
 $85 = $83 < $84;
 $86 = $85 ? $83 : $84;
 $87 = Math_fround($55 * $62);
 $88 = $87 > $72;
 $89 = $88 ? $87 : $72;
 $90 = $89 < $75;
 $91 = $90 ? $89 : $75;
 $92 = Math_fround($56 * $78);
 $93 = $92 > $81;
 $94 = $93 ? $92 : $81;
 $95 = $94 < $84;
 $96 = $95 ? $94 : $84;
 $97 = Math_fround($91 - $77);
 $98 = Math_fround($96 - $86);
 $99 = $97 >= Math_fround(0.0);
 $100 = $99 ? Math_fround(1.0) : Math_fround(-1.0);
 $101 = $98 >= Math_fround(0.0);
 $102 = $101 ? Math_fround(1.0) : Math_fround(-1.0);
 $103 = (~~(($100)));
 $104 = (~~(($102)));
 $fabsf$i$i8 = (Math_fround(Math_abs((Math_fround($97)))));
 $105 = $fabsf$i$i8 < Math_fround(1.00000001335143196002E-10);
 if ($105) {
  $106 = Math_fround($100 * Math_fround(1.00000001335143196002E-10));
  $du$0 = $106;
 } else {
  $du$0 = $97;
 }
 $fabsf$i$i7 = (Math_fround(Math_abs((Math_fround($98)))));
 $107 = $fabsf$i$i7 < Math_fround(1.00000001335143196002E-10);
 if ($107) {
  $108 = Math_fround($102 * Math_fround(1.00000001335143196002E-10));
  $dv$0 = $108;
 } else {
  $dv$0 = $98;
 }
 $109 = $du$0 > Math_fround(0.0);
 if ($109) {
  $110 = (Math_fround(Math_floor((Math_fround($77)))));
  $$sink = $110;
 } else {
  $111 = (Math_fround(Math_ceil((Math_fround($77)))));
  $$sink = $111;
 }
 $112 = (~~(($$sink)));
 $113 = $dv$0 > Math_fround(0.0);
 if ($113) {
  $114 = (Math_fround(Math_floor((Math_fround($86)))));
  $$sink1 = $114;
 } else {
  $115 = (Math_fround(Math_ceil((Math_fround($86)))));
  $$sink1 = $115;
 }
 $116 = (~~(($$sink1)));
 if ($109) {
  $117 = (Math_fround(Math_ceil((Math_fround($77)))));
  $118 = $117 == $77;
  if ($118) {
   $119 = Math_fround($117 + Math_fround(1.0));
   $130 = $119;
  } else {
   $130 = $117;
  }
 } else {
  $120 = (Math_fround(Math_floor((Math_fround($77)))));
  $121 = $120 == $77;
  if ($121) {
   $122 = Math_fround($120 + Math_fround(-1.0));
   $130 = $122;
  } else {
   $130 = $120;
  }
 }
 if ($113) {
  $123 = (Math_fround(Math_ceil((Math_fround($86)))));
  $124 = $123 == $86;
  if ($124) {
   $125 = Math_fround($123 + Math_fround(1.0));
   $133 = $125;
  } else {
   $133 = $123;
  }
 } else {
  $126 = (Math_fround(Math_floor((Math_fround($86)))));
  $127 = $126 == $86;
  if ($127) {
   $128 = Math_fround($126 + Math_fround(-1.0));
   $133 = $128;
  } else {
   $133 = $126;
  }
 }
 $129 = Math_fround($130 - $77);
 $131 = Math_fround($129 / $du$0);
 $132 = Math_fround($133 - $86);
 $134 = Math_fround($132 / $dv$0);
 $fabsf$i$i4 = (Math_fround(Math_abs((Math_fround($du$0)))));
 $135 = Math_fround(Math_fround(1.0) / $fabsf$i$i4);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($dv$0)))));
 $136 = Math_fround(Math_fround(1.0) / $fabsf$i$i);
 $137 = (($overlapTraceSegment) + 12|0);
 $138 = (($overlapTraceSegment) + 48|0);
 $not$$i = ($103|0)<(1);
 $139 = $not$$i << 31 >> 31;
 $140 = (($overlapTraceSegment) + 52|0);
 $not$1$i = ($104|0)<(1);
 $141 = $not$1$i << 31 >> 31;
 $142 = (($overlapTraceSegment) + 56|0);
 $143 = (($overlapTraceSegment) + 76|0);
 $144 = (($overlapTraceSegment) + 80|0);
 $145 = (($overlapTraceSegment) + 84|0);
 $146 = (($overlapTraceSegment) + 88|0);
 $147 = (($overlapTraceSegment) + 16|0);
 $148 = (($overlapTraceSegment) + 60|0);
 $149 = (($overlapTraceSegment) + 64|0);
 $150 = (($overlapTraceSegment) + 20|0);
 $151 = (($overlapTraceSegment) + 68|0);
 $152 = (($overlapTraceSegment) + 72|0);
 $153 = (($overlapTraceSegment) + 92|0);
 $154 = (($overlapTraceSegment) + 32|0);
 $155 = (($overlapTraceSegment) + 36|0);
 $156 = (($overlapTraceSegment) + 40|0);
 $157 = (($overlapTraceSegment) + 44|0);
 $158 = Math_fround(Math_fround(0.0) - $71);
 $159 = (Math_fround(($61|0)));
 $160 = Math_fround($159 + $71);
 $161 = Math_fround(Math_fround(0.0) - $80);
 $162 = (Math_fround(($59|0)));
 $163 = Math_fround($162 + $80);
 $164 = (($overlapTraceSegment) + 76|0);
 $165 = (($overlapTraceSegment) + 60|0);
 $166 = (($line$i) + 4|0);
 $167 = (($line$i) + 8|0);
 $168 = (($line$i) + 12|0);
 $tu$0 = $131;$tv$0 = $134;$ui$0 = $112;$vi$0 = $116;
 L30: while(1) {
  $169 = $tu$0 < $tv$0;
  $170 = $169 ? $tu$0 : $tv$0;
  $171 = HEAP8[$overlapTraceSegment>>0]|0;
  $172 = ($171<<24>>24)==(0);
  if ($172) {
   HEAP8[$overlapTraceSegment>>0] = 1;
   HEAP32[$137>>2] = $aCallback;
   HEAP32[$138>>2] = $59;
   HEAP32[$140>>2] = $139;
   HEAP32[$142>>2] = $141;
   HEAP32[$143>>2] = 1;
   HEAP32[$144>>2] = -1;
   HEAP32[$145>>2] = 1;
   HEAP32[$146>>2] = -1;
   $173 = HEAP32[$147>>2]|0;
   $174 = (($ui$0) - ($173))|0;
   HEAP32[$148>>2] = $174;
   $175 = (($173) + ($ui$0))|0;
   HEAP32[$149>>2] = $175;
   $176 = HEAP32[$150>>2]|0;
   $177 = (($vi$0) - ($176))|0;
   HEAP32[$151>>2] = $177;
   $178 = (($176) + ($vi$0))|0;
   HEAP32[$152>>2] = $178;
   $179 = (($139) + ($174))|0;
   $180 = (($175) + ($139))|0;
   $181 = ($179|0)>($180|0);
   if ($181) {
    $211 = $aCallback;
   } else {
    $188 = $141;$190 = $178;$248 = $139;$249 = $175;$ui$04$i = $179;
    while(1) {
     $182 = HEAP32[$154>>2]|0;
     $183 = ($ui$04$i|0)<($182|0);
     if ($183) {
      $206 = $249;$207 = $248;$250 = $190;$251 = $188;
     } else {
      $184 = HEAP32[$155>>2]|0;
      $185 = ($ui$04$i|0)<($184|0);
      if (!($185)) {
       break;
      }
      $186 = HEAP32[$151>>2]|0;
      $187 = (($188) + ($186))|0;
      $189 = (($190) + ($188))|0;
      $191 = ($187|0)>($189|0);
      if ($191) {
       $206 = $249;$207 = $248;$250 = $190;$251 = $188;
      } else {
       $252 = $188;$253 = $190;$vi$02$i = $187;
       while(1) {
        $192 = HEAP32[$156>>2]|0;
        $193 = ($vi$02$i|0)<($192|0);
        if ($193) {
         $201 = $253;$202 = $252;
        } else {
         $194 = HEAP32[$157>>2]|0;
         $195 = ($vi$02$i|0)<($194|0);
         if (!($195)) {
          $254 = $253;$255 = $252;
          break;
         }
         $196 = HEAP32[$138>>2]|0;
         $197 = Math_imul($196, $ui$04$i)|0;
         $198 = (($197) + ($vi$02$i))|0;
         $199 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI25CapsuleTraceSegmentReportE15testVertexIndexEj($overlapTraceSegment,$198)|0);
         if (!($199)) {
          label = 53;
          break L30;
         }
         $$pre11$i = HEAP32[$152>>2]|0;
         $$pre12$i = HEAP32[$142>>2]|0;
         $201 = $$pre11$i;$202 = $$pre12$i;
        }
        $200 = (($201) + ($202))|0;
        $203 = ($vi$02$i|0)<($200|0);
        if (!($203)) {
         $254 = $201;$255 = $202;
         break;
        }
        $204 = (($vi$02$i) + 1)|0;
        $252 = $202;$253 = $201;$vi$02$i = $204;
       }
       $$pre$i$pre = HEAP32[$149>>2]|0;
       $$pre8$i$pre = HEAP32[$140>>2]|0;
       $206 = $$pre$i$pre;$207 = $$pre8$i$pre;$250 = $254;$251 = $255;
      }
     }
     $205 = (($206) + ($207))|0;
     $208 = ($ui$04$i|0)<($205|0);
     if (!($208)) {
      break;
     }
     $209 = (($ui$04$i) + 1)|0;
     $188 = $251;$190 = $250;$248 = $207;$249 = $206;$ui$04$i = $209;
    }
    $$pre = HEAP32[$137>>2]|0;
    $211 = $$pre;
   }
   $210 = HEAP32[$211>>2]|0;
   $212 = (($210) + 8|0);
   $213 = HEAP32[$212>>2]|0;
   $214 = HEAP32[$26>>2]|0;
   $215 = (FUNCTION_TABLE_iiii[$213 & 2047]($211,$214,$153)|0);
   if (!($215)) {
    label = 53;
    break;
   }
   HEAP32[$26>>2] = 0;
  } else {
   $216 = HEAP32[$147>>2]|0;
   $217 = (($ui$0) - ($216))|0;
   HEAP32[$164>>2] = $217;
   $218 = (($216) + ($ui$0))|0;
   HEAP32[$144>>2] = $218;
   $219 = HEAP32[$150>>2]|0;
   $220 = (($vi$0) - ($219))|0;
   HEAP32[$145>>2] = $220;
   $221 = (($219) + ($vi$0))|0;
   HEAP32[$146>>2] = $221;
   $222 = HEAP32[$165>>2]|0;
   $223 = ($217|0)==($222|0);
   if ($223) {
    $225 = HEAP32[$151>>2]|0;
    $226 = ($220|0)==($225|0);
    if (!($226)) {
     HEAP8[$line$i>>0] = 1;
     $227 = ($220|0)<($225|0);
     $$1$i = $227 ? $220 : $221;
     HEAP32[$166>>2] = $$1$i;
     HEAP32[$167>>2] = $217;
     HEAP32[$168>>2] = $218;
    }
   } else {
    HEAP8[$line$i>>0] = 0;
    $224 = ($217|0)<($222|0);
    $$$i = $224 ? $217 : $218;
    HEAP32[$166>>2] = $$$i;
    HEAP32[$167>>2] = $220;
    HEAP32[$168>>2] = $221;
   }
   $228 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI25CapsuleTraceSegmentReportE10visitCellsERKNS4_11OverlapLineE($overlapTraceSegment,$line$i)|0);
   if (!($228)) {
    label = 53;
    break;
   }
   $229 = HEAP32[$137>>2]|0;
   $230 = HEAP32[$229>>2]|0;
   $231 = (($230) + 8|0);
   $232 = HEAP32[$231>>2]|0;
   $233 = HEAP32[$26>>2]|0;
   $234 = (FUNCTION_TABLE_iiii[$232 & 2047]($229,$233,$153)|0);
   if (!($234)) {
    label = 53;
    break;
   }
   HEAP32[$26>>2] = 0;
   ;HEAP32[$165+0>>2]=HEAP32[$164+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$164+8>>2]|0;HEAP32[$165+12>>2]=HEAP32[$164+12>>2]|0;
  }
  if ($169) {
   $235 = (($ui$0) + ($103))|0;
   $236 = (($235) + ($103))|0;
   $237 = (Math_fround(($236|0)));
   $238 = !($237 < $158);
   $239 = !($237 >= $160);
   $or$cond = $238 & $239;
   if (!($or$cond)) {
    label = 53;
    break;
   }
   $240 = Math_fround($135 + $tu$0);
   $tu$1 = $240;$tv$1 = $tv$0;$ui$1 = $235;$vi$1 = $vi$0;
  } else {
   $241 = (($vi$0) + ($104))|0;
   $242 = (($241) + ($104))|0;
   $243 = (Math_fround(($242|0)));
   $244 = !($243 < $161);
   $245 = !($243 >= $163);
   $or$cond24 = $244 & $245;
   if (!($or$cond24)) {
    label = 53;
    break;
   }
   $246 = Math_fround($136 + $tv$0);
   $tu$1 = $tu$0;$tv$1 = $246;$ui$1 = $ui$0;$vi$1 = $241;
  }
  $247 = $170 < Math_fround(1.00010001659393310547);
  if ($247) {
   $tu$0 = $tu$1;$tv$0 = $tv$1;$ui$0 = $ui$1;$vi$0 = $vi$1;
  } else {
   label = 53;
   break;
  }
 }
 if ((label|0) == 53) {
  STACKTOP = sp;return;
 }
}
function __ZN25CapsuleTraceSegmentReportD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z27sweepConvex_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$convexGeom,$convexPose,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $convexGeom = $convexGeom|0;
 $convexPose = $convexPose|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$ = 0, $$0 = 0, $$pre = Math_fround(0), $$pre27 = Math_fround(0), $$pre28 = Math_fround(0), $$pre29 = Math_fround(0), $$pre30 = Math_fround(0), $$pre31 = Math_fround(0), $$pre32 = Math_fround(0), $$pre33 = Math_fround(0), $$pre34 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0);
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0);
 var $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0;
 var $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0);
 var $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0);
 var $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0);
 var $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0;
 var $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0);
 var $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0);
 var $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0);
 var $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0);
 var $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = Math_fround(0);
 var $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = 0;
 var $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0);
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $centerLocalSpace = 0, $convexAABBExtentHfLocalSpace = 0, $convexScaling = 0, $entityReport = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i = Math_fround(0);
 var $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $fabsf$i$i8$i$i = Math_fround(0), $hfUtil = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $convexScaling = sp + 520|0;
 $hfUtil = sp + 448|0;
 $entityReport = sp;
 $0 = sp + 468|0;
 $1 = sp + 592|0;
 $centerLocalSpace = sp + 492|0;
 $convexAABBExtentHfLocalSpace = sp + 504|0;
 $2 = sp + 480|0;
 $3 = (($pose) + 4|0);
 $4 = (($pose) + 8|0);
 $5 = (($pose) + 12|0);
 $6 = (($pose) + 16|0);
 $7 = (($pose) + 20|0);
 $8 = (($pose) + 24|0);
 $9 = (($convexGeom) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($convexGeom) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = $12 == Math_fround(1.0);
 if ($13) {
  $14 = (($convexGeom) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = $15 == Math_fround(1.0);
  if ($16) {
   $17 = (($convexGeom) + 12|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = $18 == Math_fround(1.0);
   $415 = $19;
  } else {
   $415 = 0;
  }
 } else {
  $415 = 0;
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $20 = (($convexScaling) + 4|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($convexScaling) + 8|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($convexScaling) + 12|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($convexScaling) + 16|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($convexScaling) + 20|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($convexScaling) + 24|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($convexScaling) + 28|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($convexScaling) + 32|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($convexScaling) + 36|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($convexScaling) + 40|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($convexScaling) + 44|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($convexScaling) + 48|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($convexScaling) + 52|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $33 = (($convexScaling) + 56|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($convexScaling) + 60|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($convexScaling) + 64|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($convexScaling) + 68|0);
 HEAPF32[$36>>2] = Math_fround(1.0);
 if ($415) {
  $57 = Math_fround(1.0);$59 = Math_fround(0.0);$61 = Math_fround(0.0);$63 = Math_fround(0.0);$65 = Math_fround(1.0);$67 = Math_fround(0.0);$72 = Math_fround(0.0);$74 = Math_fround(0.0);$76 = Math_fround(1.0);
 } else {
  $37 = (($convexGeom) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($convexScaling,$11,$37);
  $$pre = Math_fround(HEAPF32[$convexScaling>>2]);
  $$pre27 = Math_fround(HEAPF32[$20>>2]);
  $$pre28 = Math_fround(HEAPF32[$21>>2]);
  $$pre29 = Math_fround(HEAPF32[$22>>2]);
  $$pre30 = Math_fround(HEAPF32[$23>>2]);
  $$pre31 = Math_fround(HEAPF32[$24>>2]);
  $$pre32 = Math_fround(HEAPF32[$25>>2]);
  $$pre33 = Math_fround(HEAPF32[$26>>2]);
  $$pre34 = Math_fround(HEAPF32[$27>>2]);
  $57 = $$pre;$59 = $$pre27;$61 = $$pre28;$63 = $$pre29;$65 = $$pre30;$67 = $$pre31;$72 = $$pre32;$74 = $$pre33;$76 = $$pre34;
 }
 $38 = (($10) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($10) + 28|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($39 + $41);
 $43 = (($10) + 20|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($10) + 32|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($44 + $46);
 $48 = (($10) + 24|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($10) + 36|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($49 + $51);
 $53 = Math_fround($42 * Math_fround(0.5));
 $54 = Math_fround($47 * Math_fround(0.5));
 $55 = Math_fround($52 * Math_fround(0.5));
 $56 = Math_fround($53 * $57);
 $58 = Math_fround($53 * $59);
 $60 = Math_fround($53 * $61);
 $62 = Math_fround($54 * $63);
 $64 = Math_fround($54 * $65);
 $66 = Math_fround($54 * $67);
 $68 = Math_fround($56 + $62);
 $69 = Math_fround($58 + $64);
 $70 = Math_fround($60 + $66);
 $71 = Math_fround($55 * $72);
 $73 = Math_fround($55 * $74);
 $75 = Math_fround($55 * $76);
 $77 = Math_fround($68 + $71);
 $78 = Math_fround($69 + $73);
 $79 = Math_fround($70 + $75);
 $80 = Math_fround($41 - $39);
 $81 = Math_fround($46 - $44);
 $82 = Math_fround($51 - $49);
 $83 = Math_fround($80 * Math_fround(0.5));
 $84 = Math_fround($81 * Math_fround(0.5));
 $85 = Math_fround($82 * Math_fround(0.5));
 $86 = Math_fround($83 * $57);
 $87 = Math_fround($83 * $59);
 $88 = Math_fround($83 * $61);
 $89 = Math_fround($84 * $63);
 $90 = Math_fround($84 * $65);
 $91 = Math_fround($84 * $67);
 $92 = Math_fround($85 * $72);
 $93 = Math_fround($85 * $74);
 $94 = Math_fround($85 * $76);
 $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($86)))));
 $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($89)))));
 $95 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
 $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($92)))));
 $96 = Math_fround($95 + $fabsf$i$i6$i$i);
 $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($87)))));
 $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($90)))));
 $97 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
 $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($93)))));
 $98 = Math_fround($97 + $fabsf$i$i3$i$i);
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($88)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($91)))));
 $99 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($94)))));
 $100 = Math_fround($99 + $fabsf$i$i$i$i);
 $101 = Math_fround($77 - $96);
 $102 = Math_fround($78 - $98);
 $103 = Math_fround($79 - $100);
 $104 = Math_fround($77 + $96);
 $105 = Math_fround($78 + $98);
 $106 = Math_fround($79 + $100);
 $107 = Math_fround($104 - $101);
 $108 = Math_fround($105 - $102);
 $109 = Math_fround($106 - $103);
 $110 = Math_fround($107 * Math_fround(0.5));
 $111 = Math_fround($108 * Math_fround(0.5));
 $112 = Math_fround($109 * Math_fround(0.5));
 $113 = Math_fround($110 + $inflation);
 $114 = Math_fround($111 + $inflation);
 $115 = Math_fround($112 + $inflation);
 $116 = HEAP16[$hintFlags>>1]|0;
 $117 = $116&65535;
 $118 = $117 & 512;
 $119 = ($118|0)==(0);
 $120 = $117 & 128;
 $121 = (($geom) + 20|0);
 $122 = HEAP8[$121>>0]|0;
 $123 = $122 & 2;
 $124 = ($123<<24>>24)!=(0);
 $125 = ($120|0)!=(0);
 $$ = $124 | $125;
 $126 = (($hfUtil) + 12|0);
 $127 = (($geom) + 4|0);
 $128 = HEAP32[$127>>2]|0;
 HEAP32[$126>>2] = $128;
 $129 = (($hfUtil) + 16|0);
 HEAP32[$129>>2] = $geom;
 $130 = (($geom) + 8|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = Math_fround(Math_fround(1.0) / $131);
 $133 = (($hfUtil) + 4|0);
 HEAPF32[$133>>2] = $132;
 $134 = (($geom) + 12|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround(Math_fround(1.0) / $135);
 HEAPF32[$hfUtil>>2] = $136;
 $137 = (($geom) + 16|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround(Math_fround(1.0) / $138);
 $140 = (($hfUtil) + 8|0);
 HEAPF32[$140>>2] = $139;
 $141 = Math_fround(HEAPF32[$unitDir>>2]);
 $142 = Math_fround(-$141);
 $143 = (($unitDir) + 4|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround(-$144);
 $146 = (($unitDir) + 8|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = Math_fround(-$147);
 HEAPF32[$0>>2] = $142;
 $149 = (($0) + 4|0);
 HEAPF32[$149>>2] = $145;
 $150 = (($0) + 8|0);
 HEAPF32[$150>>2] = $148;
 HEAP16[$1>>1] = $116;
 $151 = $116 & 64;
 $152 = ($151<<16>>16)!=(0);
 __ZN24ConvexVsHeightfieldSweepC2ERN5physx2Gu15HeightFieldUtilERKNS1_14ConvexHullDataERKNS0_11PxMeshScaleERKNS0_11PxTransformESC_RKNS0_6PxVec3EfNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEEfbb($entityReport,$hfUtil,$38,$11,$convexPose,$pose,$0,$distance,$1,$inflation,$152,$$);
 $153 = Math_fround(HEAPF32[$6>>2]);
 $154 = Math_fround(HEAPF32[$7>>2]);
 $155 = Math_fround(HEAPF32[$8>>2]);
 $156 = Math_fround($153 * Math_fround(-2.0));
 $157 = Math_fround($154 * Math_fround(-2.0));
 $158 = Math_fround($155 * Math_fround(-2.0));
 $159 = Math_fround(HEAPF32[$5>>2]);
 $160 = Math_fround($159 * $159);
 $161 = Math_fround($160 + Math_fround(-0.5));
 $162 = Math_fround(HEAPF32[$pose>>2]);
 $163 = Math_fround($156 * $162);
 $164 = Math_fround(HEAPF32[$3>>2]);
 $165 = Math_fround($157 * $164);
 $166 = Math_fround($163 + $165);
 $167 = Math_fround(HEAPF32[$4>>2]);
 $168 = Math_fround($158 * $167);
 $169 = Math_fround($166 + $168);
 $170 = Math_fround($156 * $161);
 $171 = Math_fround($158 * $164);
 $172 = Math_fround($157 * $167);
 $173 = Math_fround($171 - $172);
 $174 = Math_fround($159 * $173);
 $175 = Math_fround($170 - $174);
 $176 = Math_fround($162 * $169);
 $177 = Math_fround($176 + $175);
 $178 = Math_fround($157 * $161);
 $179 = Math_fround($156 * $167);
 $180 = Math_fround($158 * $162);
 $181 = Math_fround($179 - $180);
 $182 = Math_fround($159 * $181);
 $183 = Math_fround($178 - $182);
 $184 = Math_fround($164 * $169);
 $185 = Math_fround($184 + $183);
 $186 = Math_fround($158 * $161);
 $187 = Math_fround($157 * $162);
 $188 = Math_fround($156 * $164);
 $189 = Math_fround($187 - $188);
 $190 = Math_fround($159 * $189);
 $191 = Math_fround($186 - $190);
 $192 = Math_fround($167 * $169);
 $193 = Math_fround($191 + $192);
 $194 = Math_fround(-$162);
 $195 = Math_fround(-$164);
 $196 = Math_fround(-$167);
 $197 = Math_fround($101 + $104);
 $198 = Math_fround($102 + $105);
 $199 = Math_fround($103 + $106);
 $200 = Math_fround($197 * Math_fround(0.5));
 $201 = Math_fround($198 * Math_fround(0.5));
 $202 = Math_fround($199 * Math_fround(0.5));
 $203 = Math_fround($200 * Math_fround(2.0));
 $204 = Math_fround($201 * Math_fround(2.0));
 $205 = Math_fround($202 * Math_fround(2.0));
 $206 = Math_fround($203 * $194);
 $207 = Math_fround($204 * $195);
 $208 = Math_fround($206 + $207);
 $209 = Math_fround($205 * $196);
 $210 = Math_fround($208 + $209);
 $211 = Math_fround($203 * $161);
 $212 = Math_fround($205 * $195);
 $213 = Math_fround($204 * $196);
 $214 = Math_fround($212 - $213);
 $215 = Math_fround($159 * $214);
 $216 = Math_fround($211 + $215);
 $217 = Math_fround($210 * $194);
 $218 = Math_fround($217 + $216);
 $219 = Math_fround($204 * $161);
 $220 = Math_fround($203 * $196);
 $221 = Math_fround($205 * $194);
 $222 = Math_fround($220 - $221);
 $223 = Math_fround($159 * $222);
 $224 = Math_fround($219 + $223);
 $225 = Math_fround($210 * $195);
 $226 = Math_fround($225 + $224);
 $227 = Math_fround($205 * $161);
 $228 = Math_fround($204 * $194);
 $229 = Math_fround($203 * $195);
 $230 = Math_fround($228 - $229);
 $231 = Math_fround($159 * $230);
 $232 = Math_fround($227 + $231);
 $233 = Math_fround($210 * $196);
 $234 = Math_fround($232 + $233);
 $235 = Math_fround($177 + $218);
 $236 = Math_fround($185 + $226);
 $237 = Math_fround($193 + $234);
 HEAPF32[$centerLocalSpace>>2] = $235;
 $238 = (($centerLocalSpace) + 4|0);
 HEAPF32[$238>>2] = $236;
 $239 = (($centerLocalSpace) + 8|0);
 HEAPF32[$239>>2] = $237;
 $240 = Math_fround(HEAPF32[$unitDir>>2]);
 $241 = Math_fround($240 * Math_fround(2.0));
 $242 = Math_fround(HEAPF32[$143>>2]);
 $243 = Math_fround($242 * Math_fround(2.0));
 $244 = Math_fround(HEAPF32[$146>>2]);
 $245 = Math_fround($244 * Math_fround(2.0));
 $246 = Math_fround($241 * $194);
 $247 = Math_fround($243 * $195);
 $248 = Math_fround($246 + $247);
 $249 = Math_fround($245 * $196);
 $250 = Math_fround($248 + $249);
 $251 = Math_fround($161 * $241);
 $252 = Math_fround($245 * $195);
 $253 = Math_fround($243 * $196);
 $254 = Math_fround($252 - $253);
 $255 = Math_fround($159 * $254);
 $256 = Math_fround($251 + $255);
 $257 = Math_fround($250 * $194);
 $258 = Math_fround($257 + $256);
 $259 = Math_fround($161 * $243);
 $260 = Math_fround($241 * $196);
 $261 = Math_fround($245 * $194);
 $262 = Math_fround($260 - $261);
 $263 = Math_fround($159 * $262);
 $264 = Math_fround($259 + $263);
 $265 = Math_fround($250 * $195);
 $266 = Math_fround($265 + $264);
 $267 = Math_fround($161 * $245);
 $268 = Math_fround($243 * $194);
 $269 = Math_fround($241 * $195);
 $270 = Math_fround($268 - $269);
 $271 = Math_fround($159 * $270);
 $272 = Math_fround($267 + $271);
 $273 = Math_fround($250 * $196);
 $274 = Math_fround($272 + $273);
 $275 = Math_fround($194 - $162);
 $276 = Math_fround($195 - $164);
 $277 = Math_fround($196 - $167);
 $278 = Math_fround($275 * $194);
 $279 = Math_fround($276 * $195);
 $280 = Math_fround($277 * $196);
 $281 = Math_fround($275 * $195);
 $282 = Math_fround($275 * $196);
 $283 = Math_fround($159 * $275);
 $284 = Math_fround($276 * $196);
 $285 = Math_fround($159 * $276);
 $286 = Math_fround($159 * $277);
 $287 = Math_fround(Math_fround(1.0) - $279);
 $288 = Math_fround($287 - $280);
 $289 = Math_fround($281 + $286);
 $290 = Math_fround($282 - $285);
 $291 = Math_fround($281 - $286);
 $292 = Math_fround(Math_fround(1.0) - $278);
 $293 = Math_fround($292 - $280);
 $294 = Math_fround($283 + $284);
 $295 = Math_fround($282 + $285);
 $296 = Math_fround($284 - $283);
 $297 = Math_fround($292 - $279);
 $298 = Math_fround($113 * $288);
 $299 = Math_fround($113 * $289);
 $300 = Math_fround($113 * $290);
 $301 = Math_fround($114 * $291);
 $302 = Math_fround($114 * $293);
 $303 = Math_fround($114 * $294);
 $304 = Math_fround($115 * $295);
 $305 = Math_fround($115 * $296);
 $306 = Math_fround($115 * $297);
 $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($298)))));
 $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($301)))));
 $307 = Math_fround($fabsf$i$i4$i + $fabsf$i$i5$i);
 $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($304)))));
 $308 = Math_fround($307 + $fabsf$i$i6$i);
 $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($299)))));
 $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($302)))));
 $309 = Math_fround($fabsf$i$i7$i + $fabsf$i$i8$i);
 $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($305)))));
 $310 = Math_fround($309 + $fabsf$i$i3$i);
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($300)))));
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($303)))));
 $311 = Math_fround($fabsf$i$i2$i + $fabsf$i$i1$i);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($306)))));
 $312 = Math_fround($311 + $fabsf$i$i$i);
 $313 = Math_fround($235 - $308);
 $314 = Math_fround($236 - $310);
 $315 = Math_fround($237 - $312);
 $316 = Math_fround($308 + $235);
 $317 = Math_fround($310 + $236);
 $318 = Math_fround($237 + $312);
 $319 = Math_fround($316 - $313);
 $320 = Math_fround($317 - $314);
 $321 = Math_fround($318 - $315);
 $322 = Math_fround($319 * Math_fround(0.5));
 $323 = Math_fround($320 * Math_fround(0.5));
 $324 = Math_fround($321 * Math_fround(0.5));
 HEAPF32[$convexAABBExtentHfLocalSpace>>2] = $322;
 $325 = (($convexAABBExtentHfLocalSpace) + 4|0);
 HEAPF32[$325>>2] = $323;
 $326 = (($convexAABBExtentHfLocalSpace) + 8|0);
 HEAPF32[$326>>2] = $324;
 $327 = Math_fround($258 * $distance);
 $328 = Math_fround($266 * $distance);
 $329 = Math_fround($274 * $distance);
 $330 = Math_fround(HEAPF32[$centerLocalSpace>>2]);
 $331 = Math_fround($327 + $330);
 $332 = Math_fround(HEAPF32[$238>>2]);
 $333 = Math_fround($328 + $332);
 $334 = Math_fround(HEAPF32[$239>>2]);
 $335 = Math_fround($329 + $334);
 HEAPF32[$2>>2] = $331;
 $336 = (($2) + 4|0);
 HEAPF32[$336>>2] = $333;
 $337 = (($2) + 8|0);
 HEAPF32[$337>>2] = $335;
 __ZNK5physx2Gu15HeightFieldUtil12traceSegmentI24ConvexVsHeightfieldSweepLb0ELb0ELb1EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$centerLocalSpace,$2,$entityReport,$convexAABBExtentHfLocalSpace);
 $338 = (($entityReport) + 435|0);
 $339 = HEAP8[$338>>0]|0;
 $340 = ($339<<24>>24)==(0);
 if ($340) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $341 = (($entityReport) + 434|0);
 $342 = HEAP8[$341>>0]|0;
 $343 = ($342<<24>>24)==(0);
 if ($343) {
  $370 = (($entityReport) + 320|0);
  ;HEAP32[$sweepHit+0>>2]=HEAP32[$370+0>>2]|0;HEAP32[$sweepHit+4>>2]=HEAP32[$370+4>>2]|0;HEAP32[$sweepHit+8>>2]=HEAP32[$370+8>>2]|0;
  $371 = (($entityReport) + 332|0);
  $372 = HEAP16[$371>>1]|0;
  $373 = (($sweepHit) + 12|0);
  HEAP16[$373>>1] = $372;
  $374 = (($entityReport) + 336|0);
  $375 = Math_fround(HEAPF32[$374>>2]);
  $376 = (($sweepHit) + 16|0);
  HEAPF32[$376>>2] = $375;
  $377 = (($entityReport) + 340|0);
  $378 = Math_fround(HEAPF32[$377>>2]);
  $379 = (($sweepHit) + 20|0);
  HEAPF32[$379>>2] = $378;
  $380 = (($entityReport) + 344|0);
  $381 = Math_fround(HEAPF32[$380>>2]);
  $382 = (($sweepHit) + 24|0);
  HEAPF32[$382>>2] = $381;
  $383 = (($entityReport) + 348|0);
  $384 = Math_fround(HEAPF32[$383>>2]);
  $385 = (($sweepHit) + 28|0);
  $386 = (($entityReport) + 352|0);
  $387 = Math_fround(HEAPF32[$386>>2]);
  $388 = (($sweepHit) + 32|0);
  $389 = (($entityReport) + 356|0);
  $390 = Math_fround(HEAPF32[$389>>2]);
  $391 = (($sweepHit) + 36|0);
  $392 = (($entityReport) + 360|0);
  $393 = Math_fround(HEAPF32[$392>>2]);
  $394 = (($sweepHit) + 40|0);
  HEAPF32[$394>>2] = $393;
  $395 = (($entityReport) + 364|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = (($sweepHit) + 44|0);
  HEAP32[$397>>2] = $396;
  $398 = Math_fround(-$384);
  $399 = Math_fround(-$387);
  $400 = Math_fround(-$390);
  HEAPF32[$385>>2] = $398;
  HEAPF32[$388>>2] = $399;
  HEAPF32[$391>>2] = $400;
  $401 = Math_fround($384 * $384);
  $402 = Math_fround($387 * $387);
  $403 = Math_fround($401 + $402);
  $404 = Math_fround($390 * $390);
  $405 = Math_fround($404 + $403);
  $406 = (Math_fround(Math_sqrt((Math_fround($405)))));
  $407 = $406 > Math_fround(0.0);
  if ($407) {
   $408 = Math_fround(Math_fround(1.0) / $406);
   $409 = Math_fround($408 * $398);
   HEAPF32[$385>>2] = $409;
   $410 = Math_fround($408 * $399);
   HEAPF32[$388>>2] = $410;
   $411 = Math_fround($408 * $400);
   HEAPF32[$391>>2] = $411;
  }
  $412 = (($entityReport) + 328|0);
  $413 = HEAP32[$412>>2]|0;
  $414 = (($sweepHit) + 8|0);
  HEAP32[$414>>2] = $413;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($119) {
  $356 = (($sweepHit) + 12|0);
  HEAP16[$356>>1] = 6;
  $357 = (($sweepHit) + 40|0);
  HEAPF32[$357>>2] = Math_fround(0.0);
  $358 = Math_fround(HEAPF32[$unitDir>>2]);
  $359 = Math_fround(-$358);
  $360 = Math_fround(HEAPF32[$143>>2]);
  $361 = Math_fround(-$360);
  $362 = Math_fround(HEAPF32[$146>>2]);
  $363 = Math_fround(-$362);
  $364 = (($sweepHit) + 28|0);
  HEAPF32[$364>>2] = $359;
  $365 = (($sweepHit) + 32|0);
  HEAPF32[$365>>2] = $361;
  $366 = (($sweepHit) + 36|0);
  HEAPF32[$366>>2] = $363;
  $367 = (($entityReport) + 328|0);
  $368 = HEAP32[$367>>2]|0;
  $369 = (($sweepHit) + 8|0);
  HEAP32[$369>>2] = $368;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $344 = (__ZN5physx2Gu28computeConvex_HeightFieldMTDERKNS_21PxHeightFieldGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES6_ffbjRNS_10PxSweepHitE($geom,$pose,$convexGeom,$convexPose,$inflation,$distance,$$,1,$sweepHit)|0);
 $345 = (($sweepHit) + 12|0);
 HEAP16[$345>>1] = 6;
 if ($344) {
  HEAP16[$345>>1] = 7;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $346 = (($sweepHit) + 40|0);
  HEAPF32[$346>>2] = Math_fround(0.0);
  $347 = Math_fround(HEAPF32[$unitDir>>2]);
  $348 = Math_fround(-$347);
  $349 = Math_fround(HEAPF32[$143>>2]);
  $350 = Math_fround(-$349);
  $351 = Math_fround(HEAPF32[$146>>2]);
  $352 = Math_fround(-$351);
  $353 = (($sweepHit) + 28|0);
  HEAPF32[$353>>2] = $348;
  $354 = (($sweepHit) + 32|0);
  HEAPF32[$354>>2] = $350;
  $355 = (($sweepHit) + 36|0);
  HEAPF32[$355>>2] = $352;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu15HeightFieldUtil12traceSegmentI24ConvexVsHeightfieldSweepLb0ELb0ELb1EEEvRKNS_6PxVec3ES6_PT_PS5_($this,$aP0,$aP1,$aCallback,$overlapObjectExtent) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $aCallback = $aCallback|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 var $$$i = 0, $$1$i = 0, $$pre = 0, $$pre$i$pre = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre8$i$pre = 0, $$sink = Math_fround(0), $$sink1 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0;
 var $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0);
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0);
 var $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $du$0 = Math_fround(0), $dv$0 = Math_fround(0), $expandu = 0, $expandv = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i4 = Math_fround(0), $fabsf$i$i7 = Math_fround(0), $fabsf$i$i8 = Math_fround(0), $line$i = 0, $localBounds = 0, $not$$i = 0, $not$1$i = 0, $or$cond = 0, $or$cond24 = 0, $overlapTraceSegment = 0;
 var $rayDir = 0, $tfar = 0, $tnear = 0, $tu$0 = Math_fround(0), $tu$1 = Math_fround(0), $tv$0 = Math_fround(0), $tv$1 = Math_fround(0), $ui$0 = 0, $ui$04$i = 0, $ui$1 = 0, $vi$0 = 0, $vi$02$i = 0, $vi$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $line$i = sp + 216|0;
 $localBounds = sp;
 $overlapTraceSegment = sp + 24|0;
 $expandu = sp + 184|0;
 $expandv = sp + 188|0;
 $rayDir = sp + 192|0;
 $tnear = sp + 204|0;
 $tfar = sp + 208|0;
 __ZNK5physx2Gu15HeightFieldUtil18computeLocalBoundsERNS_9PxBounds3E($this,$localBounds);
 $0 = Math_fround(HEAPF32[$localBounds>>2]);
 $1 = Math_fround(HEAPF32[$overlapObjectExtent>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($localBounds) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($overlapObjectExtent) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($localBounds) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($overlapObjectExtent) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 HEAPF32[$localBounds>>2] = $2;
 HEAPF32[$3>>2] = $7;
 HEAPF32[$8>>2] = $12;
 $13 = (($localBounds) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 + $1);
 $16 = (($localBounds) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 + $6);
 $19 = (($localBounds) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 + $11);
 HEAPF32[$13>>2] = $15;
 HEAPF32[$16>>2] = $18;
 HEAPF32[$19>>2] = $21;
 $22 = (($this) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP8[$overlapTraceSegment>>0] = 0;
 $24 = (($overlapTraceSegment) + 4|0);
 HEAP32[$24>>2] = $this;
 $25 = (($overlapTraceSegment) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = (($overlapTraceSegment) + 156|0);
 HEAP32[$26>>2] = 0;
 HEAPF32[$expandu>>2] = Math_fround(0.0);
 HEAPF32[$expandv>>2] = Math_fround(0.0);
 $27 = Math_fround(HEAPF32[$aP1>>2]);
 $28 = Math_fround(HEAPF32[$aP0>>2]);
 $29 = Math_fround($27 - $28);
 $30 = (($aP1) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($aP0) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($31 - $33);
 $35 = (($aP1) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($aP0) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 - $38);
 HEAPF32[$rayDir>>2] = $29;
 $40 = (($rayDir) + 4|0);
 HEAPF32[$40>>2] = $34;
 $41 = (($rayDir) + 8|0);
 HEAPF32[$41>>2] = $39;
 $42 = (__ZN5physx2Gu17intersectRayAABB2ERKNS_6PxVec3ES3_S3_S3_fRfS4_($localBounds,$13,$aP0,$rayDir,Math_fround(1.0),$tnear,$tfar)|0);
 if (!($42)) {
  STACKTOP = sp;return;
 }
 $43 = Math_fround(HEAPF32[$tnear>>2]);
 $44 = Math_fround(HEAPF32[$rayDir>>2]);
 $45 = Math_fround($43 * $44);
 $46 = Math_fround(HEAPF32[$41>>2]);
 $47 = Math_fround($43 * $46);
 $48 = Math_fround(HEAPF32[$aP0>>2]);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround(HEAPF32[$37>>2]);
 $51 = Math_fround($47 + $50);
 $52 = Math_fround(HEAPF32[$tfar>>2]);
 $53 = Math_fround($44 * $52);
 $54 = Math_fround($46 * $52);
 $55 = Math_fround($48 + $53);
 $56 = Math_fround($50 + $54);
 __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI24ConvexVsHeightfieldSweepE7prepareERKNS_6PxVec3ES7_S7_RfS8_($overlapTraceSegment,$aP0,$aP1,$overlapObjectExtent,$expandu,$expandv);
 $57 = HEAP32[$22>>2]|0;
 $58 = (($57) + 20|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 16|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = Math_fround(HEAPF32[$this>>2]);
 $63 = (($this) + 8|0);
 $64 = (($61) + -1)|0;
 $65 = (Math_fround(($64|0)));
 $66 = Math_fround($65 * Math_fround(0.999999880790710449218));
 $67 = (($59) + -1)|0;
 $68 = (Math_fround(($67|0)));
 $69 = Math_fround($68 * Math_fround(0.999999880790710449218));
 $70 = Math_fround($49 * $62);
 $71 = Math_fround(HEAPF32[$expandu>>2]);
 $72 = Math_fround(Math_fround(1.00000001168609742308E-7) - $71);
 $73 = $70 > $72;
 $74 = $73 ? $70 : $72;
 $75 = Math_fround($71 + $66);
 $76 = $74 < $75;
 $77 = $76 ? $74 : $75;
 $78 = Math_fround(HEAPF32[$63>>2]);
 $79 = Math_fround($51 * $78);
 $80 = Math_fround(HEAPF32[$expandv>>2]);
 $81 = Math_fround(Math_fround(1.00000001168609742308E-7) - $80);
 $82 = $79 > $81;
 $83 = $82 ? $79 : $81;
 $84 = Math_fround($69 + $80);
 $85 = $83 < $84;
 $86 = $85 ? $83 : $84;
 $87 = Math_fround($55 * $62);
 $88 = $87 > $72;
 $89 = $88 ? $87 : $72;
 $90 = $89 < $75;
 $91 = $90 ? $89 : $75;
 $92 = Math_fround($56 * $78);
 $93 = $92 > $81;
 $94 = $93 ? $92 : $81;
 $95 = $94 < $84;
 $96 = $95 ? $94 : $84;
 $97 = Math_fround($91 - $77);
 $98 = Math_fround($96 - $86);
 $99 = $97 >= Math_fround(0.0);
 $100 = $99 ? Math_fround(1.0) : Math_fround(-1.0);
 $101 = $98 >= Math_fround(0.0);
 $102 = $101 ? Math_fround(1.0) : Math_fround(-1.0);
 $103 = (~~(($100)));
 $104 = (~~(($102)));
 $fabsf$i$i8 = (Math_fround(Math_abs((Math_fround($97)))));
 $105 = $fabsf$i$i8 < Math_fround(1.00000001335143196002E-10);
 if ($105) {
  $106 = Math_fround($100 * Math_fround(1.00000001335143196002E-10));
  $du$0 = $106;
 } else {
  $du$0 = $97;
 }
 $fabsf$i$i7 = (Math_fround(Math_abs((Math_fround($98)))));
 $107 = $fabsf$i$i7 < Math_fround(1.00000001335143196002E-10);
 if ($107) {
  $108 = Math_fround($102 * Math_fround(1.00000001335143196002E-10));
  $dv$0 = $108;
 } else {
  $dv$0 = $98;
 }
 $109 = $du$0 > Math_fround(0.0);
 if ($109) {
  $110 = (Math_fround(Math_floor((Math_fround($77)))));
  $$sink = $110;
 } else {
  $111 = (Math_fround(Math_ceil((Math_fround($77)))));
  $$sink = $111;
 }
 $112 = (~~(($$sink)));
 $113 = $dv$0 > Math_fround(0.0);
 if ($113) {
  $114 = (Math_fround(Math_floor((Math_fround($86)))));
  $$sink1 = $114;
 } else {
  $115 = (Math_fround(Math_ceil((Math_fround($86)))));
  $$sink1 = $115;
 }
 $116 = (~~(($$sink1)));
 if ($109) {
  $117 = (Math_fround(Math_ceil((Math_fround($77)))));
  $118 = $117 == $77;
  if ($118) {
   $119 = Math_fround($117 + Math_fround(1.0));
   $130 = $119;
  } else {
   $130 = $117;
  }
 } else {
  $120 = (Math_fround(Math_floor((Math_fround($77)))));
  $121 = $120 == $77;
  if ($121) {
   $122 = Math_fround($120 + Math_fround(-1.0));
   $130 = $122;
  } else {
   $130 = $120;
  }
 }
 if ($113) {
  $123 = (Math_fround(Math_ceil((Math_fround($86)))));
  $124 = $123 == $86;
  if ($124) {
   $125 = Math_fround($123 + Math_fround(1.0));
   $133 = $125;
  } else {
   $133 = $123;
  }
 } else {
  $126 = (Math_fround(Math_floor((Math_fround($86)))));
  $127 = $126 == $86;
  if ($127) {
   $128 = Math_fround($126 + Math_fround(-1.0));
   $133 = $128;
  } else {
   $133 = $126;
  }
 }
 $129 = Math_fround($130 - $77);
 $131 = Math_fround($129 / $du$0);
 $132 = Math_fround($133 - $86);
 $134 = Math_fround($132 / $dv$0);
 $fabsf$i$i4 = (Math_fround(Math_abs((Math_fround($du$0)))));
 $135 = Math_fround(Math_fround(1.0) / $fabsf$i$i4);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($dv$0)))));
 $136 = Math_fround(Math_fround(1.0) / $fabsf$i$i);
 $137 = (($overlapTraceSegment) + 12|0);
 $138 = (($overlapTraceSegment) + 48|0);
 $not$$i = ($103|0)<(1);
 $139 = $not$$i << 31 >> 31;
 $140 = (($overlapTraceSegment) + 52|0);
 $not$1$i = ($104|0)<(1);
 $141 = $not$1$i << 31 >> 31;
 $142 = (($overlapTraceSegment) + 56|0);
 $143 = (($overlapTraceSegment) + 76|0);
 $144 = (($overlapTraceSegment) + 80|0);
 $145 = (($overlapTraceSegment) + 84|0);
 $146 = (($overlapTraceSegment) + 88|0);
 $147 = (($overlapTraceSegment) + 16|0);
 $148 = (($overlapTraceSegment) + 60|0);
 $149 = (($overlapTraceSegment) + 64|0);
 $150 = (($overlapTraceSegment) + 20|0);
 $151 = (($overlapTraceSegment) + 68|0);
 $152 = (($overlapTraceSegment) + 72|0);
 $153 = (($overlapTraceSegment) + 92|0);
 $154 = (($overlapTraceSegment) + 32|0);
 $155 = (($overlapTraceSegment) + 36|0);
 $156 = (($overlapTraceSegment) + 40|0);
 $157 = (($overlapTraceSegment) + 44|0);
 $158 = Math_fround(Math_fround(0.0) - $71);
 $159 = (Math_fround(($61|0)));
 $160 = Math_fround($159 + $71);
 $161 = Math_fround(Math_fround(0.0) - $80);
 $162 = (Math_fround(($59|0)));
 $163 = Math_fround($162 + $80);
 $164 = (($overlapTraceSegment) + 76|0);
 $165 = (($overlapTraceSegment) + 60|0);
 $166 = (($line$i) + 4|0);
 $167 = (($line$i) + 8|0);
 $168 = (($line$i) + 12|0);
 $tu$0 = $131;$tv$0 = $134;$ui$0 = $112;$vi$0 = $116;
 L30: while(1) {
  $169 = $tu$0 < $tv$0;
  $170 = $169 ? $tu$0 : $tv$0;
  $171 = HEAP8[$overlapTraceSegment>>0]|0;
  $172 = ($171<<24>>24)==(0);
  if ($172) {
   HEAP8[$overlapTraceSegment>>0] = 1;
   HEAP32[$137>>2] = $aCallback;
   HEAP32[$138>>2] = $59;
   HEAP32[$140>>2] = $139;
   HEAP32[$142>>2] = $141;
   HEAP32[$143>>2] = 1;
   HEAP32[$144>>2] = -1;
   HEAP32[$145>>2] = 1;
   HEAP32[$146>>2] = -1;
   $173 = HEAP32[$147>>2]|0;
   $174 = (($ui$0) - ($173))|0;
   HEAP32[$148>>2] = $174;
   $175 = (($173) + ($ui$0))|0;
   HEAP32[$149>>2] = $175;
   $176 = HEAP32[$150>>2]|0;
   $177 = (($vi$0) - ($176))|0;
   HEAP32[$151>>2] = $177;
   $178 = (($176) + ($vi$0))|0;
   HEAP32[$152>>2] = $178;
   $179 = (($139) + ($174))|0;
   $180 = (($175) + ($139))|0;
   $181 = ($179|0)>($180|0);
   if ($181) {
    $211 = $aCallback;
   } else {
    $188 = $141;$190 = $178;$248 = $139;$249 = $175;$ui$04$i = $179;
    while(1) {
     $182 = HEAP32[$154>>2]|0;
     $183 = ($ui$04$i|0)<($182|0);
     if ($183) {
      $206 = $249;$207 = $248;$250 = $190;$251 = $188;
     } else {
      $184 = HEAP32[$155>>2]|0;
      $185 = ($ui$04$i|0)<($184|0);
      if (!($185)) {
       break;
      }
      $186 = HEAP32[$151>>2]|0;
      $187 = (($188) + ($186))|0;
      $189 = (($190) + ($188))|0;
      $191 = ($187|0)>($189|0);
      if ($191) {
       $206 = $249;$207 = $248;$250 = $190;$251 = $188;
      } else {
       $252 = $188;$253 = $190;$vi$02$i = $187;
       while(1) {
        $192 = HEAP32[$156>>2]|0;
        $193 = ($vi$02$i|0)<($192|0);
        if ($193) {
         $201 = $253;$202 = $252;
        } else {
         $194 = HEAP32[$157>>2]|0;
         $195 = ($vi$02$i|0)<($194|0);
         if (!($195)) {
          $254 = $253;$255 = $252;
          break;
         }
         $196 = HEAP32[$138>>2]|0;
         $197 = Math_imul($196, $ui$04$i)|0;
         $198 = (($197) + ($vi$02$i))|0;
         $199 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI24ConvexVsHeightfieldSweepE15testVertexIndexEj($overlapTraceSegment,$198)|0);
         if (!($199)) {
          label = 53;
          break L30;
         }
         $$pre11$i = HEAP32[$152>>2]|0;
         $$pre12$i = HEAP32[$142>>2]|0;
         $201 = $$pre11$i;$202 = $$pre12$i;
        }
        $200 = (($201) + ($202))|0;
        $203 = ($vi$02$i|0)<($200|0);
        if (!($203)) {
         $254 = $201;$255 = $202;
         break;
        }
        $204 = (($vi$02$i) + 1)|0;
        $252 = $202;$253 = $201;$vi$02$i = $204;
       }
       $$pre$i$pre = HEAP32[$149>>2]|0;
       $$pre8$i$pre = HEAP32[$140>>2]|0;
       $206 = $$pre$i$pre;$207 = $$pre8$i$pre;$250 = $254;$251 = $255;
      }
     }
     $205 = (($206) + ($207))|0;
     $208 = ($ui$04$i|0)<($205|0);
     if (!($208)) {
      break;
     }
     $209 = (($ui$04$i) + 1)|0;
     $188 = $251;$190 = $250;$248 = $207;$249 = $206;$ui$04$i = $209;
    }
    $$pre = HEAP32[$137>>2]|0;
    $211 = $$pre;
   }
   $210 = HEAP32[$211>>2]|0;
   $212 = (($210) + 8|0);
   $213 = HEAP32[$212>>2]|0;
   $214 = HEAP32[$26>>2]|0;
   $215 = (FUNCTION_TABLE_iiii[$213 & 2047]($211,$214,$153)|0);
   if (!($215)) {
    label = 53;
    break;
   }
   HEAP32[$26>>2] = 0;
  } else {
   $216 = HEAP32[$147>>2]|0;
   $217 = (($ui$0) - ($216))|0;
   HEAP32[$164>>2] = $217;
   $218 = (($216) + ($ui$0))|0;
   HEAP32[$144>>2] = $218;
   $219 = HEAP32[$150>>2]|0;
   $220 = (($vi$0) - ($219))|0;
   HEAP32[$145>>2] = $220;
   $221 = (($219) + ($vi$0))|0;
   HEAP32[$146>>2] = $221;
   $222 = HEAP32[$165>>2]|0;
   $223 = ($217|0)==($222|0);
   if ($223) {
    $225 = HEAP32[$151>>2]|0;
    $226 = ($220|0)==($225|0);
    if (!($226)) {
     HEAP8[$line$i>>0] = 1;
     $227 = ($220|0)<($225|0);
     $$1$i = $227 ? $220 : $221;
     HEAP32[$166>>2] = $$1$i;
     HEAP32[$167>>2] = $217;
     HEAP32[$168>>2] = $218;
    }
   } else {
    HEAP8[$line$i>>0] = 0;
    $224 = ($217|0)<($222|0);
    $$$i = $224 ? $217 : $218;
    HEAP32[$166>>2] = $$$i;
    HEAP32[$167>>2] = $220;
    HEAP32[$168>>2] = $221;
   }
   $228 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI24ConvexVsHeightfieldSweepE10visitCellsERKNS4_11OverlapLineE($overlapTraceSegment,$line$i)|0);
   if (!($228)) {
    label = 53;
    break;
   }
   $229 = HEAP32[$137>>2]|0;
   $230 = HEAP32[$229>>2]|0;
   $231 = (($230) + 8|0);
   $232 = HEAP32[$231>>2]|0;
   $233 = HEAP32[$26>>2]|0;
   $234 = (FUNCTION_TABLE_iiii[$232 & 2047]($229,$233,$153)|0);
   if (!($234)) {
    label = 53;
    break;
   }
   HEAP32[$26>>2] = 0;
   ;HEAP32[$165+0>>2]=HEAP32[$164+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$164+8>>2]|0;HEAP32[$165+12>>2]=HEAP32[$164+12>>2]|0;
  }
  if ($169) {
   $235 = (($ui$0) + ($103))|0;
   $236 = (($235) + ($103))|0;
   $237 = (Math_fround(($236|0)));
   $238 = !($237 < $158);
   $239 = !($237 >= $160);
   $or$cond = $238 & $239;
   if (!($or$cond)) {
    label = 53;
    break;
   }
   $240 = Math_fround($135 + $tu$0);
   $tu$1 = $240;$tv$1 = $tv$0;$ui$1 = $235;$vi$1 = $vi$0;
  } else {
   $241 = (($vi$0) + ($104))|0;
   $242 = (($241) + ($104))|0;
   $243 = (Math_fround(($242|0)));
   $244 = !($243 < $161);
   $245 = !($243 >= $163);
   $or$cond24 = $244 & $245;
   if (!($or$cond24)) {
    label = 53;
    break;
   }
   $246 = Math_fround($136 + $tv$0);
   $tu$1 = $tu$0;$tv$1 = $246;$ui$1 = $ui$0;$vi$1 = $241;
  }
  $247 = $170 < Math_fround(1.00010001659393310547);
  if ($247) {
   $tu$0 = $tu$1;$tv$0 = $tv$1;$ui$0 = $ui$1;$vi$0 = $vi$1;
  } else {
   label = 53;
   break;
  }
 }
 if ((label|0) == 53) {
  STACKTOP = sp;return;
 }
}
function __ZN24ConvexVsHeightfieldSweepD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z24sweepBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf($geom,$pose,$box,$unitDir,$distance,$sweepHit,$hintFlags,$inflation) {
 $geom = $geom|0;
 $pose = $pose|0;
 $box = $box|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $sweepHit = $sweepHit|0;
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 var $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$$i26$i$i$i = Math_fround(0), $$0 = 0, $$sroa$1$i$i$i = 0, $$sroa$138 = 0, $$tr = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0);
 var $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0);
 var $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0);
 var $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0);
 var $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0);
 var $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0);
 var $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0);
 var $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0);
 var $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0);
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0);
 var $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0);
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = Math_fround(0);
 var $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0);
 var $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0);
 var $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = Math_fround(0), $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0);
 var $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0);
 var $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = 0, $53 = 0;
 var $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $BoxToWorld = 0, $WorldToBoxV = 0, $boxAABBExtentInHfLocalSpace = 0, $boxV = 0, $centerLocalSpace = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i9 = Math_fround(0), $fabsf$i$i1$i = Math_fround(0), $fabsf$i$i1$i8 = Math_fround(0), $fabsf$i$i2$i = Math_fround(0);
 var $fabsf$i$i2$i7 = Math_fround(0), $fabsf$i$i3$i = Math_fround(0), $fabsf$i$i3$i6 = Math_fround(0), $fabsf$i$i4$i = Math_fround(0), $fabsf$i$i4$i1 = Math_fround(0), $fabsf$i$i5$i = Math_fround(0), $fabsf$i$i5$i2 = Math_fround(0), $fabsf$i$i6$i = Math_fround(0), $fabsf$i$i6$i3 = Math_fround(0), $fabsf$i$i7$i = Math_fround(0), $fabsf$i$i7$i4 = Math_fround(0), $fabsf$i$i8$i = Math_fround(0), $fabsf$i$i8$i5 = Math_fround(0), $hfUtil = 0, $phitmp = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $$sroa$1$i$i$i = sp + 192|0;
 $zero$sroa$1$i$i$i = sp + 348|0;
 $BoxToWorld = sp + 320|0;
 $WorldToBoxV = sp + 160|0;
 $boxV = sp;
 $hfUtil = sp + 360|0;
 $$sroa$138 = sp + 296|0;
 $centerLocalSpace = sp + 272|0;
 $boxAABBExtentInHfLocalSpace = sp + 308|0;
 $0 = sp + 284|0;
 $1 = Math_fround(HEAPF32[$box>>2]);
 $fabsf$i$i2$i = (Math_fround(Math_abs((Math_fround($1)))));
 $2 = (($box) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $fabsf$i$i5$i = (Math_fround(Math_abs((Math_fround($3)))));
 $4 = (($box) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $fabsf$i$i8$i = (Math_fround(Math_abs((Math_fround($5)))));
 $6 = (($box) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $fabsf$i$i7$i = (Math_fround(Math_abs((Math_fround($7)))));
 $8 = (($6) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $fabsf$i$i6$i = (Math_fround(Math_abs((Math_fround($9)))));
 $10 = (($6) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $fabsf$i$i4$i = (Math_fround(Math_abs((Math_fround($11)))));
 $12 = (($box) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $fabsf$i$i3$i = (Math_fround(Math_abs((Math_fround($13)))));
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $fabsf$i$i1$i = (Math_fround(Math_abs((Math_fround($15)))));
 $16 = (($12) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($17)))));
 $18 = (($box) + 48|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($box) + 52|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($box) + 56|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($fabsf$i$i2$i * $19);
 $25 = Math_fround($fabsf$i$i7$i * $21);
 $26 = Math_fround($24 + $25);
 $27 = Math_fround($fabsf$i$i3$i * $23);
 $28 = Math_fround($26 + $27);
 $29 = Math_fround($fabsf$i$i5$i * $19);
 $30 = Math_fround($fabsf$i$i6$i * $21);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($fabsf$i$i1$i * $23);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround($fabsf$i$i8$i * $19);
 $35 = Math_fround($fabsf$i$i4$i * $21);
 $36 = Math_fround($34 + $35);
 $37 = Math_fround($fabsf$i$i$i * $23);
 $38 = Math_fround($36 + $37);
 $39 = Math_fround($28 + $inflation);
 $40 = Math_fround($33 + $inflation);
 $41 = Math_fround($38 + $inflation);
 $42 = (($geom) + 20|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43 & 2;
 $45 = ($44<<24>>24)!=(0);
 __ZN5physx6PxQuatC2ERKNS_7PxMat33E($$sroa$1$i$i$i,$box);
 $46 = Math_fround(HEAPF32[$$sroa$1$i$i$i>>2]);
 HEAPF32[$BoxToWorld>>2] = $46;
 $47 = (($BoxToWorld) + 4|0);
 $48 = (($$sroa$1$i$i$i) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 HEAPF32[$47>>2] = $49;
 $50 = (($BoxToWorld) + 8|0);
 $51 = (($$sroa$1$i$i$i) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 HEAPF32[$50>>2] = $52;
 $53 = (($BoxToWorld) + 12|0);
 $54 = (($$sroa$1$i$i$i) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 HEAPF32[$53>>2] = $55;
 $56 = (($BoxToWorld) + 16|0);
 $57 = (($box) + 36|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 HEAPF32[$56>>2] = $58;
 $59 = (($BoxToWorld) + 20|0);
 $60 = (($box) + 40|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 HEAPF32[$59>>2] = $61;
 $62 = (($BoxToWorld) + 24|0);
 $63 = (($box) + 44|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 HEAPF32[$62>>2] = $64;
 $65 = Math_fround($58 * Math_fround(-2.0));
 $66 = Math_fround($61 * Math_fround(-2.0));
 $67 = Math_fround($64 * Math_fround(-2.0));
 $68 = Math_fround($55 * $55);
 $69 = Math_fround($68 + Math_fround(-0.5));
 $70 = Math_fround($65 * $46);
 $71 = Math_fround($66 * $49);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($67 * $52);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($65 * $69);
 $76 = Math_fround($67 * $49);
 $77 = Math_fround($66 * $52);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($55 * $78);
 $80 = Math_fround($75 - $79);
 $81 = Math_fround($46 * $74);
 $82 = Math_fround($81 + $80);
 $83 = Math_fround($66 * $69);
 $84 = Math_fround($65 * $52);
 $85 = Math_fround($67 * $46);
 $86 = Math_fround($84 - $85);
 $87 = Math_fround($55 * $86);
 $88 = Math_fround($83 - $87);
 $89 = Math_fround($49 * $74);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($67 * $69);
 $92 = Math_fround($66 * $46);
 $93 = Math_fround($65 * $49);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($55 * $94);
 $96 = Math_fround($91 - $95);
 $97 = Math_fround($52 * $74);
 $98 = Math_fround($96 + $97);
 $99 = Math_fround(-$46);
 $100 = Math_fround(-$49);
 $101 = Math_fround(-$52);
 HEAPF32[$WorldToBoxV>>2] = $99;
 $102 = (($WorldToBoxV) + 4|0);
 HEAPF32[$102>>2] = $100;
 $103 = (($WorldToBoxV) + 8|0);
 HEAPF32[$103>>2] = $101;
 $104 = (($WorldToBoxV) + 12|0);
 HEAPF32[$104>>2] = $55;
 $105 = (($WorldToBoxV) + 16|0);
 HEAPF32[$105>>2] = $82;
 $106 = (($WorldToBoxV) + 20|0);
 HEAPF32[$106>>2] = $90;
 $107 = (($WorldToBoxV) + 24|0);
 HEAPF32[$107>>2] = $98;
 $108 = (($WorldToBoxV) + 28|0);
 HEAPF32[$108>>2] = Math_fround(0.0);
 $109 = Math_fround(HEAPF32[$unitDir>>2]);
 $110 = Math_fround($109 * $distance);
 $111 = (($unitDir) + 4|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($112 * $distance);
 $114 = (($unitDir) + 8|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($115 * $distance);
 $117 = Math_fround($110 * Math_fround(2.0));
 $118 = Math_fround($113 * Math_fround(2.0));
 $119 = Math_fround($116 * Math_fround(2.0));
 $120 = Math_fround($117 * $99);
 $121 = Math_fround($118 * $100);
 $122 = Math_fround($120 + $121);
 $123 = Math_fround($119 * $101);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($69 * $117);
 $126 = Math_fround($119 * $100);
 $127 = Math_fround($118 * $101);
 $128 = Math_fround($126 - $127);
 $129 = Math_fround($55 * $128);
 $130 = Math_fround($125 + $129);
 $131 = Math_fround($124 * $99);
 $132 = Math_fround($131 + $130);
 $133 = Math_fround($69 * $118);
 $134 = Math_fround($117 * $101);
 $135 = Math_fround($119 * $99);
 $136 = Math_fround($134 - $135);
 $137 = Math_fround($55 * $136);
 $138 = Math_fround($133 + $137);
 $139 = Math_fround($124 * $100);
 $140 = Math_fround($139 + $138);
 $141 = Math_fround($69 * $119);
 $142 = Math_fround($118 * $99);
 $143 = Math_fround($117 * $100);
 $144 = Math_fround($142 - $143);
 $145 = Math_fround($55 * $144);
 $146 = Math_fround($141 + $145);
 $147 = Math_fround($124 * $101);
 $148 = Math_fround($146 + $147);
 ;HEAP32[$boxV+0>>2]=0|0;HEAP32[$boxV+4>>2]=0|0;HEAP32[$boxV+8>>2]=0|0;HEAP32[$boxV+12>>2]=0|0;
 $149 = Math_fround(HEAPF32[$18>>2]);
 $150 = Math_fround(HEAPF32[$20>>2]);
 $151 = Math_fround(HEAPF32[$22>>2]);
 $152 = (($boxV) + 64|0);
 $153 = (($boxV) + 80|0);
 HEAP32[$153>>2] = 3;
 $154 = (($boxV) + 16|0);
 $155 = (($boxV) + 20|0);
 ;HEAP32[$155+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $156 = (($boxV) + 32|0);
 $157 = (($boxV) + 36|0);
 $158 = (($boxV) + 48|0);
 HEAPF32[$158>>2] = Math_fround(0.0);
 $159 = (($boxV) + 52|0);
 ;HEAP32[$159+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$152+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$152+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$152+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $160 = (($boxV) + 144|0);
 HEAPF32[$160>>2] = $149;
 $161 = (($boxV) + 148|0);
 HEAPF32[$161>>2] = $150;
 $162 = (($boxV) + 152|0);
 HEAPF32[$162>>2] = $151;
 $163 = (($boxV) + 156|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = !($149 <= $150);
 $$$i26$i$i$i = $164 ? $150 : $149;
 $165 = !($$$i26$i$i$i <= $151);
 $166 = $165 ? $151 : $$$i26$i$i$i;
 $167 = !($149 >= $150);
 $$$i23$i$i$i = $167 ? $150 : $149;
 $168 = !($$$i23$i$i$i >= $151);
 $169 = $168 ? $151 : $$$i23$i$i$i;
 $170 = Math_fround($166 * Math_fround(0.150000005960464477539));
 $171 = Math_fround($169 * Math_fround(0.0299999993294477462769));
 $172 = $170 > $171;
 $$$i12$i$i$i = $172 ? $170 : $171;
 $173 = $166 > $$$i12$i$i$i;
 $$$i$i$i$i = $173 ? $$$i12$i$i$i : $166;
 HEAPF32[$154>>2] = $$$i$i$i$i;
 ;HEAP32[$155+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $174 = Math_fround($166 * Math_fround(0.0500000007450580596924));
 HEAPF32[$156>>2] = $174;
 ;HEAP32[$157+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $175 = (($sweepHit) + 40|0);
 HEAPF32[$175>>2] = Math_fround(3.40282346638528859812E+38);
 HEAP32[$$sroa$1$i$i$i>>2] = ((553960 + 8|0));
 $176 = (($hfUtil) + 12|0);
 $177 = (($geom) + 4|0);
 $178 = HEAP32[$177>>2]|0;
 HEAP32[$176>>2] = $178;
 $179 = (($hfUtil) + 16|0);
 HEAP32[$179>>2] = $geom;
 $180 = (($geom) + 8|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = Math_fround(Math_fround(1.0) / $181);
 $183 = (($hfUtil) + 4|0);
 HEAPF32[$183>>2] = $182;
 $184 = (($geom) + 12|0);
 $185 = Math_fround(HEAPF32[$184>>2]);
 $186 = Math_fround(Math_fround(1.0) / $185);
 HEAPF32[$hfUtil>>2] = $186;
 $187 = (($geom) + 16|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = Math_fround(Math_fround(1.0) / $188);
 $190 = (($hfUtil) + 8|0);
 HEAPF32[$190>>2] = $189;
 $191 = (($$sroa$1$i$i$i) + 4|0);
 HEAP32[$191>>2] = $WorldToBoxV;
 $192 = (($$sroa$1$i$i$i) + 68|0);
 HEAP8[$192>>0] = 0;
 $193 = (($$sroa$1$i$i$i) + 70|0);
 HEAP8[$193>>0] = 0;
 $194 = (($$sroa$1$i$i$i) + 8|0);
 HEAP32[$194>>2] = $pose;
 $195 = (($$sroa$1$i$i$i) + 12|0);
 HEAP32[$195>>2] = $hfUtil;
 $196 = (($$sroa$1$i$i$i) + 16|0);
 HEAP32[$196>>2] = $boxV;
 $197 = (($$sroa$1$i$i$i) + 48|0);
 HEAPF32[$197>>2] = $132;
 $198 = (($$sroa$1$i$i$i) + 52|0);
 HEAPF32[$198>>2] = $140;
 $199 = (($$sroa$1$i$i$i) + 56|0);
 HEAPF32[$199>>2] = $148;
 $200 = (($$sroa$1$i$i$i) + 60|0);
 HEAP32[$200>>2] = $sweepHit;
 $201 = (($$sroa$1$i$i$i) + 64|0);
 HEAPF32[$201>>2] = $inflation;
 $202 = (($$sroa$1$i$i$i) + 32|0);
 HEAPF32[$202>>2] = Math_fround(3.40282346638528859812E+38);
 $203 = (($$sroa$1$i$i$i) + 36|0);
 ;HEAP32[$203+0>>2]=HEAP32[$$sroa$138+0>>2]|0;HEAP32[$203+4>>2]=HEAP32[$$sroa$138+4>>2]|0;HEAP32[$203+8>>2]=HEAP32[$$sroa$138+8>>2]|0;
 $204 = HEAP8[$42>>0]|0;
 $205 = $204 & 2;
 $206 = ($205<<24>>24)==(0);
 if ($206) {
  $207 = HEAP16[$hintFlags>>1]|0;
  $208 = ($207&65535) >>> 7;
  $$tr = $208&255;
  $phitmp = $$tr & 1;
  $210 = $phitmp;
 } else {
  $210 = 1;
 }
 $209 = (($$sroa$1$i$i$i) + 69|0);
 HEAP8[$209>>0] = $210;
 $211 = (($pose) + 16|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($pose) + 20|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = (($pose) + 24|0);
 $216 = Math_fround(HEAPF32[$215>>2]);
 $217 = Math_fround($212 * Math_fround(-2.0));
 $218 = Math_fround($214 * Math_fround(-2.0));
 $219 = Math_fround($216 * Math_fround(-2.0));
 $220 = (($pose) + 12|0);
 $221 = Math_fround(HEAPF32[$220>>2]);
 $222 = Math_fround($221 * $221);
 $223 = Math_fround($222 + Math_fround(-0.5));
 $224 = Math_fround(HEAPF32[$pose>>2]);
 $225 = Math_fround($217 * $224);
 $226 = (($pose) + 4|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 $228 = Math_fround($218 * $227);
 $229 = Math_fround($225 + $228);
 $230 = (($pose) + 8|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = Math_fround($219 * $231);
 $233 = Math_fround($229 + $232);
 $234 = Math_fround($217 * $223);
 $235 = Math_fround($219 * $227);
 $236 = Math_fround($218 * $231);
 $237 = Math_fround($235 - $236);
 $238 = Math_fround($221 * $237);
 $239 = Math_fround($234 - $238);
 $240 = Math_fround($224 * $233);
 $241 = Math_fround($240 + $239);
 $242 = Math_fround($218 * $223);
 $243 = Math_fround($217 * $231);
 $244 = Math_fround($219 * $224);
 $245 = Math_fround($243 - $244);
 $246 = Math_fround($221 * $245);
 $247 = Math_fround($242 - $246);
 $248 = Math_fround($227 * $233);
 $249 = Math_fround($248 + $247);
 $250 = Math_fround($219 * $223);
 $251 = Math_fround($218 * $224);
 $252 = Math_fround($217 * $227);
 $253 = Math_fround($251 - $252);
 $254 = Math_fround($221 * $253);
 $255 = Math_fround($250 - $254);
 $256 = Math_fround($231 * $233);
 $257 = Math_fround($255 + $256);
 $258 = Math_fround(-$224);
 $259 = Math_fround(-$227);
 $260 = Math_fround(-$231);
 $261 = Math_fround(HEAPF32[$57>>2]);
 $262 = Math_fround($261 * Math_fround(2.0));
 $263 = Math_fround(HEAPF32[$60>>2]);
 $264 = Math_fround($263 * Math_fround(2.0));
 $265 = Math_fround(HEAPF32[$63>>2]);
 $266 = Math_fround($265 * Math_fround(2.0));
 $267 = Math_fround($262 * $258);
 $268 = Math_fround($264 * $259);
 $269 = Math_fround($267 + $268);
 $270 = Math_fround($266 * $260);
 $271 = Math_fround($269 + $270);
 $272 = Math_fround($223 * $262);
 $273 = Math_fround($266 * $259);
 $274 = Math_fround($264 * $260);
 $275 = Math_fround($273 - $274);
 $276 = Math_fround($221 * $275);
 $277 = Math_fround($272 + $276);
 $278 = Math_fround($271 * $258);
 $279 = Math_fround($278 + $277);
 $280 = Math_fround($223 * $264);
 $281 = Math_fround($262 * $260);
 $282 = Math_fround($266 * $258);
 $283 = Math_fround($281 - $282);
 $284 = Math_fround($221 * $283);
 $285 = Math_fround($280 + $284);
 $286 = Math_fround($271 * $259);
 $287 = Math_fround($286 + $285);
 $288 = Math_fround($223 * $266);
 $289 = Math_fround($264 * $258);
 $290 = Math_fround($262 * $259);
 $291 = Math_fround($289 - $290);
 $292 = Math_fround($221 * $291);
 $293 = Math_fround($288 + $292);
 $294 = Math_fround($271 * $260);
 $295 = Math_fround($293 + $294);
 $296 = Math_fround($241 + $279);
 $297 = Math_fround($249 + $287);
 $298 = Math_fround($257 + $295);
 HEAPF32[$centerLocalSpace>>2] = $296;
 $299 = (($centerLocalSpace) + 4|0);
 HEAPF32[$299>>2] = $297;
 $300 = (($centerLocalSpace) + 8|0);
 HEAPF32[$300>>2] = $298;
 $301 = Math_fround(HEAPF32[$unitDir>>2]);
 $302 = Math_fround($301 * Math_fround(2.0));
 $303 = Math_fround(HEAPF32[$111>>2]);
 $304 = Math_fround($303 * Math_fround(2.0));
 $305 = Math_fround(HEAPF32[$114>>2]);
 $306 = Math_fround($305 * Math_fround(2.0));
 $307 = Math_fround($302 * $258);
 $308 = Math_fround($304 * $259);
 $309 = Math_fround($307 + $308);
 $310 = Math_fround($306 * $260);
 $311 = Math_fround($309 + $310);
 $312 = Math_fround($223 * $302);
 $313 = Math_fround($306 * $259);
 $314 = Math_fround($304 * $260);
 $315 = Math_fround($313 - $314);
 $316 = Math_fround($221 * $315);
 $317 = Math_fround($312 + $316);
 $318 = Math_fround($311 * $258);
 $319 = Math_fround($318 + $317);
 $320 = Math_fround($223 * $304);
 $321 = Math_fround($302 * $260);
 $322 = Math_fround($306 * $258);
 $323 = Math_fround($321 - $322);
 $324 = Math_fround($221 * $323);
 $325 = Math_fround($320 + $324);
 $326 = Math_fround($311 * $259);
 $327 = Math_fround($326 + $325);
 $328 = Math_fround($223 * $306);
 $329 = Math_fround($304 * $258);
 $330 = Math_fround($302 * $259);
 $331 = Math_fround($329 - $330);
 $332 = Math_fround($221 * $331);
 $333 = Math_fround($328 + $332);
 $334 = Math_fround($311 * $260);
 $335 = Math_fround($333 + $334);
 $336 = Math_fround($258 - $224);
 $337 = Math_fround($259 - $227);
 $338 = Math_fround($260 - $231);
 $339 = Math_fround($336 * $258);
 $340 = Math_fround($337 * $259);
 $341 = Math_fround($338 * $260);
 $342 = Math_fround($336 * $259);
 $343 = Math_fround($336 * $260);
 $344 = Math_fround($221 * $336);
 $345 = Math_fround($337 * $260);
 $346 = Math_fround($221 * $337);
 $347 = Math_fround($221 * $338);
 $348 = Math_fround(Math_fround(1.0) - $340);
 $349 = Math_fround($348 - $341);
 $350 = Math_fround($342 + $347);
 $351 = Math_fround($343 - $346);
 $352 = Math_fround($342 - $347);
 $353 = Math_fround(Math_fround(1.0) - $339);
 $354 = Math_fround($353 - $341);
 $355 = Math_fround($344 + $345);
 $356 = Math_fround($343 + $346);
 $357 = Math_fround($345 - $344);
 $358 = Math_fround($353 - $340);
 $359 = Math_fround($39 * $349);
 $360 = Math_fround($39 * $350);
 $361 = Math_fround($39 * $351);
 $362 = Math_fround($40 * $352);
 $363 = Math_fround($40 * $354);
 $364 = Math_fround($40 * $355);
 $365 = Math_fround($41 * $356);
 $366 = Math_fround($41 * $357);
 $367 = Math_fround($41 * $358);
 $fabsf$i$i4$i1 = (Math_fround(Math_abs((Math_fround($359)))));
 $fabsf$i$i5$i2 = (Math_fround(Math_abs((Math_fround($362)))));
 $368 = Math_fround($fabsf$i$i4$i1 + $fabsf$i$i5$i2);
 $fabsf$i$i6$i3 = (Math_fround(Math_abs((Math_fround($365)))));
 $369 = Math_fround($368 + $fabsf$i$i6$i3);
 $fabsf$i$i7$i4 = (Math_fround(Math_abs((Math_fround($360)))));
 $fabsf$i$i8$i5 = (Math_fround(Math_abs((Math_fround($363)))));
 $370 = Math_fround($fabsf$i$i7$i4 + $fabsf$i$i8$i5);
 $fabsf$i$i3$i6 = (Math_fround(Math_abs((Math_fround($366)))));
 $371 = Math_fround($370 + $fabsf$i$i3$i6);
 $fabsf$i$i2$i7 = (Math_fround(Math_abs((Math_fround($361)))));
 $fabsf$i$i1$i8 = (Math_fround(Math_abs((Math_fround($364)))));
 $372 = Math_fround($fabsf$i$i2$i7 + $fabsf$i$i1$i8);
 $fabsf$i$i$i9 = (Math_fround(Math_abs((Math_fround($367)))));
 $373 = Math_fround($372 + $fabsf$i$i$i9);
 $374 = Math_fround($296 - $369);
 $375 = Math_fround($297 - $371);
 $376 = Math_fround($298 - $373);
 $377 = Math_fround($369 + $296);
 $378 = Math_fround($371 + $297);
 $379 = Math_fround($298 + $373);
 $380 = Math_fround($377 - $374);
 $381 = Math_fround($378 - $375);
 $382 = Math_fround($379 - $376);
 $383 = Math_fround($380 * Math_fround(0.5));
 $384 = Math_fround($381 * Math_fround(0.5));
 $385 = Math_fround($382 * Math_fround(0.5));
 HEAPF32[$boxAABBExtentInHfLocalSpace>>2] = $383;
 $386 = (($boxAABBExtentInHfLocalSpace) + 4|0);
 HEAPF32[$386>>2] = $384;
 $387 = (($boxAABBExtentInHfLocalSpace) + 8|0);
 HEAPF32[$387>>2] = $385;
 $388 = Math_fround($319 * $distance);
 $389 = Math_fround($327 * $distance);
 $390 = Math_fround($335 * $distance);
 $391 = Math_fround(HEAPF32[$centerLocalSpace>>2]);
 $392 = Math_fround($388 + $391);
 $393 = Math_fround(HEAPF32[$299>>2]);
 $394 = Math_fround($389 + $393);
 $395 = Math_fround(HEAPF32[$300>>2]);
 $396 = Math_fround($390 + $395);
 HEAPF32[$0>>2] = $392;
 $397 = (($0) + 4|0);
 HEAPF32[$397>>2] = $394;
 $398 = (($0) + 8|0);
 HEAPF32[$398>>2] = $396;
 __ZNK5physx2Gu15HeightFieldUtil12traceSegmentI21BoxTraceSegmentReportLb0ELb0ELb1EEEvRKNS_6PxVec3ES6_PT_PS5_($hfUtil,$centerLocalSpace,$0,$$sroa$1$i$i$i,$boxAABBExtentInHfLocalSpace);
 $399 = HEAP32[$192>>2]|0;
 $400 = $399&255;
 $401 = ($400<<24>>24)==(0);
 if ($401) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $402 = $399 & 16711680;
 $403 = ($402|0)==(0);
 if ($403) {
  $431 = Math_fround(HEAPF32[$175>>2]);
  $432 = Math_fround($431 * $distance);
  HEAPF32[$175>>2] = $432;
  $433 = (($sweepHit) + 28|0);
  $434 = Math_fround(HEAPF32[$433>>2]);
  $435 = Math_fround($434 * Math_fround(2.0));
  $436 = (($sweepHit) + 32|0);
  $437 = Math_fround(HEAPF32[$436>>2]);
  $438 = Math_fround($437 * Math_fround(2.0));
  $439 = (($sweepHit) + 36|0);
  $440 = Math_fround(HEAPF32[$439>>2]);
  $441 = Math_fround($440 * Math_fround(2.0));
  $442 = Math_fround(HEAPF32[$53>>2]);
  $443 = Math_fround($442 * $442);
  $444 = Math_fround($443 + Math_fround(-0.5));
  $445 = Math_fround(HEAPF32[$BoxToWorld>>2]);
  $446 = Math_fround($435 * $445);
  $447 = Math_fround(HEAPF32[$47>>2]);
  $448 = Math_fround($438 * $447);
  $449 = Math_fround($446 + $448);
  $450 = Math_fround(HEAPF32[$50>>2]);
  $451 = Math_fround($441 * $450);
  $452 = Math_fround($449 + $451);
  $453 = Math_fround($435 * $444);
  $454 = Math_fround($441 * $447);
  $455 = Math_fround($438 * $450);
  $456 = Math_fround($454 - $455);
  $457 = Math_fround($442 * $456);
  $458 = Math_fround($453 + $457);
  $459 = Math_fround($445 * $452);
  $460 = Math_fround($459 + $458);
  $461 = Math_fround($438 * $444);
  $462 = Math_fround($435 * $450);
  $463 = Math_fround($441 * $445);
  $464 = Math_fround($462 - $463);
  $465 = Math_fround($442 * $464);
  $466 = Math_fround($461 + $465);
  $467 = Math_fround($447 * $452);
  $468 = Math_fround($467 + $466);
  $469 = Math_fround($441 * $444);
  $470 = Math_fround($438 * $445);
  $471 = Math_fround($435 * $447);
  $472 = Math_fround($470 - $471);
  $473 = Math_fround($442 * $472);
  $474 = Math_fround($469 + $473);
  $475 = Math_fround($450 * $452);
  $476 = Math_fround($474 + $475);
  HEAPF32[$433>>2] = $460;
  HEAPF32[$436>>2] = $468;
  HEAPF32[$439>>2] = $476;
  $477 = (($sweepHit) + 16|0);
  $478 = Math_fround(HEAPF32[$477>>2]);
  $479 = Math_fround($478 * Math_fround(2.0));
  $480 = (($sweepHit) + 20|0);
  $481 = Math_fround(HEAPF32[$480>>2]);
  $482 = Math_fround($481 * Math_fround(2.0));
  $483 = (($sweepHit) + 24|0);
  $484 = Math_fround(HEAPF32[$483>>2]);
  $485 = Math_fround($484 * Math_fround(2.0));
  $486 = Math_fround($479 * $445);
  $487 = Math_fround($482 * $447);
  $488 = Math_fround($486 + $487);
  $489 = Math_fround($485 * $450);
  $490 = Math_fround($488 + $489);
  $491 = Math_fround($479 * $444);
  $492 = Math_fround($485 * $447);
  $493 = Math_fround($482 * $450);
  $494 = Math_fround($492 - $493);
  $495 = Math_fround($442 * $494);
  $496 = Math_fround($491 + $495);
  $497 = Math_fround($445 * $490);
  $498 = Math_fround($497 + $496);
  $499 = Math_fround($482 * $444);
  $500 = Math_fround($479 * $450);
  $501 = Math_fround($485 * $445);
  $502 = Math_fround($500 - $501);
  $503 = Math_fround($442 * $502);
  $504 = Math_fround($499 + $503);
  $505 = Math_fround($447 * $490);
  $506 = Math_fround($505 + $504);
  $507 = Math_fround($485 * $444);
  $508 = Math_fround($482 * $445);
  $509 = Math_fround($479 * $447);
  $510 = Math_fround($508 - $509);
  $511 = Math_fround($442 * $510);
  $512 = Math_fround($507 + $511);
  $513 = Math_fround($450 * $490);
  $514 = Math_fround($512 + $513);
  $515 = Math_fround(HEAPF32[$56>>2]);
  $516 = Math_fround($515 + $498);
  $517 = Math_fround(HEAPF32[$59>>2]);
  $518 = Math_fround($517 + $506);
  $519 = Math_fround(HEAPF32[$62>>2]);
  $520 = Math_fround($519 + $514);
  HEAPF32[$477>>2] = $516;
  HEAPF32[$480>>2] = $518;
  HEAPF32[$483>>2] = $520;
  $521 = (($sweepHit) + 12|0);
  HEAP16[$521>>1] = 7;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $404 = (($sweepHit) + 12|0);
 HEAP16[$404>>1] = 6;
 $405 = HEAP16[$hintFlags>>1]|0;
 $406 = $405 & 512;
 $407 = ($406<<16>>16)==(0);
 if ($407) {
  HEAPF32[$175>>2] = Math_fround(0.0);
  $422 = Math_fround(HEAPF32[$unitDir>>2]);
  $423 = Math_fround(-$422);
  $424 = Math_fround(HEAPF32[$111>>2]);
  $425 = Math_fround(-$424);
  $426 = Math_fround(HEAPF32[$114>>2]);
  $427 = Math_fround(-$426);
  $428 = (($sweepHit) + 28|0);
  HEAPF32[$428>>2] = $423;
  $429 = (($sweepHit) + 32|0);
  HEAPF32[$429>>2] = $425;
  $430 = (($sweepHit) + 36|0);
  HEAPF32[$430>>2] = $427;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $408 = (__ZN5physx2Gu25computeBox_HeightFieldMTDERKNS_21PxHeightFieldGeometryERKNS_11PxTransformERKNS0_3BoxES6_ffbjRNS_10PxSweepHitE($geom,$pose,$box,$BoxToWorld,$inflation,$distance,$45,1,$sweepHit)|0);
 if ($408) {
  $418 = HEAP16[$404>>1]|0;
  $419 = $418&65535;
  $420 = $419 | 1;
  $421 = $420&65535;
  HEAP16[$404>>1] = $421;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAPF32[$175>>2] = Math_fround(0.0);
  $409 = Math_fround(HEAPF32[$unitDir>>2]);
  $410 = Math_fround(-$409);
  $411 = Math_fround(HEAPF32[$111>>2]);
  $412 = Math_fround(-$411);
  $413 = Math_fround(HEAPF32[$114>>2]);
  $414 = Math_fround(-$413);
  $415 = (($sweepHit) + 28|0);
  HEAPF32[$415>>2] = $410;
  $416 = (($sweepHit) + 32|0);
  HEAPF32[$416>>2] = $412;
  $417 = (($sweepHit) + 36|0);
  HEAPF32[$417>>2] = $414;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK5physx2Gu15HeightFieldUtil12traceSegmentI21BoxTraceSegmentReportLb0ELb0ELb1EEEvRKNS_6PxVec3ES6_PT_PS5_($this,$aP0,$aP1,$aCallback,$overlapObjectExtent) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $aCallback = $aCallback|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 var $$$i = 0, $$1$i = 0, $$pre = 0, $$pre$i$pre = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre8$i$pre = 0, $$sink = Math_fround(0), $$sink1 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0;
 var $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0);
 var $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0);
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0);
 var $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $du$0 = Math_fround(0), $dv$0 = Math_fround(0), $expandu = 0, $expandv = 0, $fabsf$i$i = Math_fround(0), $fabsf$i$i4 = Math_fround(0), $fabsf$i$i7 = Math_fround(0), $fabsf$i$i8 = Math_fround(0), $line$i = 0, $localBounds = 0, $not$$i = 0, $not$1$i = 0, $or$cond = 0, $or$cond24 = 0, $overlapTraceSegment = 0;
 var $rayDir = 0, $tfar = 0, $tnear = 0, $tu$0 = Math_fround(0), $tu$1 = Math_fround(0), $tv$0 = Math_fround(0), $tv$1 = Math_fround(0), $ui$0 = 0, $ui$04$i = 0, $ui$1 = 0, $vi$0 = 0, $vi$02$i = 0, $vi$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $line$i = sp + 216|0;
 $localBounds = sp;
 $overlapTraceSegment = sp + 24|0;
 $expandu = sp + 184|0;
 $expandv = sp + 188|0;
 $rayDir = sp + 192|0;
 $tnear = sp + 204|0;
 $tfar = sp + 208|0;
 __ZNK5physx2Gu15HeightFieldUtil18computeLocalBoundsERNS_9PxBounds3E($this,$localBounds);
 $0 = Math_fround(HEAPF32[$localBounds>>2]);
 $1 = Math_fround(HEAPF32[$overlapObjectExtent>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($localBounds) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($overlapObjectExtent) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($localBounds) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($overlapObjectExtent) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 HEAPF32[$localBounds>>2] = $2;
 HEAPF32[$3>>2] = $7;
 HEAPF32[$8>>2] = $12;
 $13 = (($localBounds) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 + $1);
 $16 = (($localBounds) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 + $6);
 $19 = (($localBounds) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 + $11);
 HEAPF32[$13>>2] = $15;
 HEAPF32[$16>>2] = $18;
 HEAPF32[$19>>2] = $21;
 $22 = (($this) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP8[$overlapTraceSegment>>0] = 0;
 $24 = (($overlapTraceSegment) + 4|0);
 HEAP32[$24>>2] = $this;
 $25 = (($overlapTraceSegment) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = (($overlapTraceSegment) + 156|0);
 HEAP32[$26>>2] = 0;
 HEAPF32[$expandu>>2] = Math_fround(0.0);
 HEAPF32[$expandv>>2] = Math_fround(0.0);
 $27 = Math_fround(HEAPF32[$aP1>>2]);
 $28 = Math_fround(HEAPF32[$aP0>>2]);
 $29 = Math_fround($27 - $28);
 $30 = (($aP1) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($aP0) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($31 - $33);
 $35 = (($aP1) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($aP0) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 - $38);
 HEAPF32[$rayDir>>2] = $29;
 $40 = (($rayDir) + 4|0);
 HEAPF32[$40>>2] = $34;
 $41 = (($rayDir) + 8|0);
 HEAPF32[$41>>2] = $39;
 $42 = (__ZN5physx2Gu17intersectRayAABB2ERKNS_6PxVec3ES3_S3_S3_fRfS4_($localBounds,$13,$aP0,$rayDir,Math_fround(1.0),$tnear,$tfar)|0);
 if (!($42)) {
  STACKTOP = sp;return;
 }
 $43 = Math_fround(HEAPF32[$tnear>>2]);
 $44 = Math_fround(HEAPF32[$rayDir>>2]);
 $45 = Math_fround($43 * $44);
 $46 = Math_fround(HEAPF32[$41>>2]);
 $47 = Math_fround($43 * $46);
 $48 = Math_fround(HEAPF32[$aP0>>2]);
 $49 = Math_fround($45 + $48);
 $50 = Math_fround(HEAPF32[$37>>2]);
 $51 = Math_fround($47 + $50);
 $52 = Math_fround(HEAPF32[$tfar>>2]);
 $53 = Math_fround($44 * $52);
 $54 = Math_fround($46 * $52);
 $55 = Math_fround($48 + $53);
 $56 = Math_fround($50 + $54);
 __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI21BoxTraceSegmentReportE7prepareERKNS_6PxVec3ES7_S7_RfS8_($overlapTraceSegment,$aP0,$aP1,$overlapObjectExtent,$expandu,$expandv);
 $57 = HEAP32[$22>>2]|0;
 $58 = (($57) + 20|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 16|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = Math_fround(HEAPF32[$this>>2]);
 $63 = (($this) + 8|0);
 $64 = (($61) + -1)|0;
 $65 = (Math_fround(($64|0)));
 $66 = Math_fround($65 * Math_fround(0.999999880790710449218));
 $67 = (($59) + -1)|0;
 $68 = (Math_fround(($67|0)));
 $69 = Math_fround($68 * Math_fround(0.999999880790710449218));
 $70 = Math_fround($49 * $62);
 $71 = Math_fround(HEAPF32[$expandu>>2]);
 $72 = Math_fround(Math_fround(1.00000001168609742308E-7) - $71);
 $73 = $70 > $72;
 $74 = $73 ? $70 : $72;
 $75 = Math_fround($71 + $66);
 $76 = $74 < $75;
 $77 = $76 ? $74 : $75;
 $78 = Math_fround(HEAPF32[$63>>2]);
 $79 = Math_fround($51 * $78);
 $80 = Math_fround(HEAPF32[$expandv>>2]);
 $81 = Math_fround(Math_fround(1.00000001168609742308E-7) - $80);
 $82 = $79 > $81;
 $83 = $82 ? $79 : $81;
 $84 = Math_fround($69 + $80);
 $85 = $83 < $84;
 $86 = $85 ? $83 : $84;
 $87 = Math_fround($55 * $62);
 $88 = $87 > $72;
 $89 = $88 ? $87 : $72;
 $90 = $89 < $75;
 $91 = $90 ? $89 : $75;
 $92 = Math_fround($56 * $78);
 $93 = $92 > $81;
 $94 = $93 ? $92 : $81;
 $95 = $94 < $84;
 $96 = $95 ? $94 : $84;
 $97 = Math_fround($91 - $77);
 $98 = Math_fround($96 - $86);
 $99 = $97 >= Math_fround(0.0);
 $100 = $99 ? Math_fround(1.0) : Math_fround(-1.0);
 $101 = $98 >= Math_fround(0.0);
 $102 = $101 ? Math_fround(1.0) : Math_fround(-1.0);
 $103 = (~~(($100)));
 $104 = (~~(($102)));
 $fabsf$i$i8 = (Math_fround(Math_abs((Math_fround($97)))));
 $105 = $fabsf$i$i8 < Math_fround(1.00000001335143196002E-10);
 if ($105) {
  $106 = Math_fround($100 * Math_fround(1.00000001335143196002E-10));
  $du$0 = $106;
 } else {
  $du$0 = $97;
 }
 $fabsf$i$i7 = (Math_fround(Math_abs((Math_fround($98)))));
 $107 = $fabsf$i$i7 < Math_fround(1.00000001335143196002E-10);
 if ($107) {
  $108 = Math_fround($102 * Math_fround(1.00000001335143196002E-10));
  $dv$0 = $108;
 } else {
  $dv$0 = $98;
 }
 $109 = $du$0 > Math_fround(0.0);
 if ($109) {
  $110 = (Math_fround(Math_floor((Math_fround($77)))));
  $$sink = $110;
 } else {
  $111 = (Math_fround(Math_ceil((Math_fround($77)))));
  $$sink = $111;
 }
 $112 = (~~(($$sink)));
 $113 = $dv$0 > Math_fround(0.0);
 if ($113) {
  $114 = (Math_fround(Math_floor((Math_fround($86)))));
  $$sink1 = $114;
 } else {
  $115 = (Math_fround(Math_ceil((Math_fround($86)))));
  $$sink1 = $115;
 }
 $116 = (~~(($$sink1)));
 if ($109) {
  $117 = (Math_fround(Math_ceil((Math_fround($77)))));
  $118 = $117 == $77;
  if ($118) {
   $119 = Math_fround($117 + Math_fround(1.0));
   $130 = $119;
  } else {
   $130 = $117;
  }
 } else {
  $120 = (Math_fround(Math_floor((Math_fround($77)))));
  $121 = $120 == $77;
  if ($121) {
   $122 = Math_fround($120 + Math_fround(-1.0));
   $130 = $122;
  } else {
   $130 = $120;
  }
 }
 if ($113) {
  $123 = (Math_fround(Math_ceil((Math_fround($86)))));
  $124 = $123 == $86;
  if ($124) {
   $125 = Math_fround($123 + Math_fround(1.0));
   $133 = $125;
  } else {
   $133 = $123;
  }
 } else {
  $126 = (Math_fround(Math_floor((Math_fround($86)))));
  $127 = $126 == $86;
  if ($127) {
   $128 = Math_fround($126 + Math_fround(-1.0));
   $133 = $128;
  } else {
   $133 = $126;
  }
 }
 $129 = Math_fround($130 - $77);
 $131 = Math_fround($129 / $du$0);
 $132 = Math_fround($133 - $86);
 $134 = Math_fround($132 / $dv$0);
 $fabsf$i$i4 = (Math_fround(Math_abs((Math_fround($du$0)))));
 $135 = Math_fround(Math_fround(1.0) / $fabsf$i$i4);
 $fabsf$i$i = (Math_fround(Math_abs((Math_fround($dv$0)))));
 $136 = Math_fround(Math_fround(1.0) / $fabsf$i$i);
 $137 = (($overlapTraceSegment) + 12|0);
 $138 = (($overlapTraceSegment) + 48|0);
 $not$$i = ($103|0)<(1);
 $139 = $not$$i << 31 >> 31;
 $140 = (($overlapTraceSegment) + 52|0);
 $not$1$i = ($104|0)<(1);
 $141 = $not$1$i << 31 >> 31;
 $142 = (($overlapTraceSegment) + 56|0);
 $143 = (($overlapTraceSegment) + 76|0);
 $144 = (($overlapTraceSegment) + 80|0);
 $145 = (($overlapTraceSegment) + 84|0);
 $146 = (($overlapTraceSegment) + 88|0);
 $147 = (($overlapTraceSegment) + 16|0);
 $148 = (($overlapTraceSegment) + 60|0);
 $149 = (($overlapTraceSegment) + 64|0);
 $150 = (($overlapTraceSegment) + 20|0);
 $151 = (($overlapTraceSegment) + 68|0);
 $152 = (($overlapTraceSegment) + 72|0);
 $153 = (($overlapTraceSegment) + 92|0);
 $154 = (($overlapTraceSegment) + 32|0);
 $155 = (($overlapTraceSegment) + 36|0);
 $156 = (($overlapTraceSegment) + 40|0);
 $157 = (($overlapTraceSegment) + 44|0);
 $158 = Math_fround(Math_fround(0.0) - $71);
 $159 = (Math_fround(($61|0)));
 $160 = Math_fround($159 + $71);
 $161 = Math_fround(Math_fround(0.0) - $80);
 $162 = (Math_fround(($59|0)));
 $163 = Math_fround($162 + $80);
 $164 = (($overlapTraceSegment) + 76|0);
 $165 = (($overlapTraceSegment) + 60|0);
 $166 = (($line$i) + 4|0);
 $167 = (($line$i) + 8|0);
 $168 = (($line$i) + 12|0);
 $tu$0 = $131;$tv$0 = $134;$ui$0 = $112;$vi$0 = $116;
 L30: while(1) {
  $169 = $tu$0 < $tv$0;
  $170 = $169 ? $tu$0 : $tv$0;
  $171 = HEAP8[$overlapTraceSegment>>0]|0;
  $172 = ($171<<24>>24)==(0);
  if ($172) {
   HEAP8[$overlapTraceSegment>>0] = 1;
   HEAP32[$137>>2] = $aCallback;
   HEAP32[$138>>2] = $59;
   HEAP32[$140>>2] = $139;
   HEAP32[$142>>2] = $141;
   HEAP32[$143>>2] = 1;
   HEAP32[$144>>2] = -1;
   HEAP32[$145>>2] = 1;
   HEAP32[$146>>2] = -1;
   $173 = HEAP32[$147>>2]|0;
   $174 = (($ui$0) - ($173))|0;
   HEAP32[$148>>2] = $174;
   $175 = (($173) + ($ui$0))|0;
   HEAP32[$149>>2] = $175;
   $176 = HEAP32[$150>>2]|0;
   $177 = (($vi$0) - ($176))|0;
   HEAP32[$151>>2] = $177;
   $178 = (($176) + ($vi$0))|0;
   HEAP32[$152>>2] = $178;
   $179 = (($139) + ($174))|0;
   $180 = (($175) + ($139))|0;
   $181 = ($179|0)>($180|0);
   if ($181) {
    $211 = $aCallback;
   } else {
    $188 = $141;$190 = $178;$248 = $139;$249 = $175;$ui$04$i = $179;
    while(1) {
     $182 = HEAP32[$154>>2]|0;
     $183 = ($ui$04$i|0)<($182|0);
     if ($183) {
      $206 = $249;$207 = $248;$250 = $190;$251 = $188;
     } else {
      $184 = HEAP32[$155>>2]|0;
      $185 = ($ui$04$i|0)<($184|0);
      if (!($185)) {
       break;
      }
      $186 = HEAP32[$151>>2]|0;
      $187 = (($188) + ($186))|0;
      $189 = (($190) + ($188))|0;
      $191 = ($187|0)>($189|0);
      if ($191) {
       $206 = $249;$207 = $248;$250 = $190;$251 = $188;
      } else {
       $252 = $188;$253 = $190;$vi$02$i = $187;
       while(1) {
        $192 = HEAP32[$156>>2]|0;
        $193 = ($vi$02$i|0)<($192|0);
        if ($193) {
         $201 = $253;$202 = $252;
        } else {
         $194 = HEAP32[$157>>2]|0;
         $195 = ($vi$02$i|0)<($194|0);
         if (!($195)) {
          $254 = $253;$255 = $252;
          break;
         }
         $196 = HEAP32[$138>>2]|0;
         $197 = Math_imul($196, $ui$04$i)|0;
         $198 = (($197) + ($vi$02$i))|0;
         $199 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI21BoxTraceSegmentReportE15testVertexIndexEj($overlapTraceSegment,$198)|0);
         if (!($199)) {
          label = 53;
          break L30;
         }
         $$pre11$i = HEAP32[$152>>2]|0;
         $$pre12$i = HEAP32[$142>>2]|0;
         $201 = $$pre11$i;$202 = $$pre12$i;
        }
        $200 = (($201) + ($202))|0;
        $203 = ($vi$02$i|0)<($200|0);
        if (!($203)) {
         $254 = $201;$255 = $202;
         break;
        }
        $204 = (($vi$02$i) + 1)|0;
        $252 = $202;$253 = $201;$vi$02$i = $204;
       }
       $$pre$i$pre = HEAP32[$149>>2]|0;
       $$pre8$i$pre = HEAP32[$140>>2]|0;
       $206 = $$pre$i$pre;$207 = $$pre8$i$pre;$250 = $254;$251 = $255;
      }
     }
     $205 = (($206) + ($207))|0;
     $208 = ($ui$04$i|0)<($205|0);
     if (!($208)) {
      break;
     }
     $209 = (($ui$04$i) + 1)|0;
     $188 = $251;$190 = $250;$248 = $207;$249 = $206;$ui$04$i = $209;
    }
    $$pre = HEAP32[$137>>2]|0;
    $211 = $$pre;
   }
   $210 = HEAP32[$211>>2]|0;
   $212 = (($210) + 8|0);
   $213 = HEAP32[$212>>2]|0;
   $214 = HEAP32[$26>>2]|0;
   $215 = (FUNCTION_TABLE_iiii[$213 & 2047]($211,$214,$153)|0);
   if (!($215)) {
    label = 53;
    break;
   }
   HEAP32[$26>>2] = 0;
  } else {
   $216 = HEAP32[$147>>2]|0;
   $217 = (($ui$0) - ($216))|0;
   HEAP32[$164>>2] = $217;
   $218 = (($216) + ($ui$0))|0;
   HEAP32[$144>>2] = $218;
   $219 = HEAP32[$150>>2]|0;
   $220 = (($vi$0) - ($219))|0;
   HEAP32[$145>>2] = $220;
   $221 = (($219) + ($vi$0))|0;
   HEAP32[$146>>2] = $221;
   $222 = HEAP32[$165>>2]|0;
   $223 = ($217|0)==($222|0);
   if ($223) {
    $225 = HEAP32[$151>>2]|0;
    $226 = ($220|0)==($225|0);
    if (!($226)) {
     HEAP8[$line$i>>0] = 1;
     $227 = ($220|0)<($225|0);
     $$1$i = $227 ? $220 : $221;
     HEAP32[$166>>2] = $$1$i;
     HEAP32[$167>>2] = $217;
     HEAP32[$168>>2] = $218;
    }
   } else {
    HEAP8[$line$i>>0] = 0;
    $224 = ($217|0)<($222|0);
    $$$i = $224 ? $217 : $218;
    HEAP32[$166>>2] = $$$i;
    HEAP32[$167>>2] = $220;
    HEAP32[$168>>2] = $221;
   }
   $228 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI21BoxTraceSegmentReportE10visitCellsERKNS4_11OverlapLineE($overlapTraceSegment,$line$i)|0);
   if (!($228)) {
    label = 53;
    break;
   }
   $229 = HEAP32[$137>>2]|0;
   $230 = HEAP32[$229>>2]|0;
   $231 = (($230) + 8|0);
   $232 = HEAP32[$231>>2]|0;
   $233 = HEAP32[$26>>2]|0;
   $234 = (FUNCTION_TABLE_iiii[$232 & 2047]($229,$233,$153)|0);
   if (!($234)) {
    label = 53;
    break;
   }
   HEAP32[$26>>2] = 0;
   ;HEAP32[$165+0>>2]=HEAP32[$164+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$164+8>>2]|0;HEAP32[$165+12>>2]=HEAP32[$164+12>>2]|0;
  }
  if ($169) {
   $235 = (($ui$0) + ($103))|0;
   $236 = (($235) + ($103))|0;
   $237 = (Math_fround(($236|0)));
   $238 = !($237 < $158);
   $239 = !($237 >= $160);
   $or$cond = $238 & $239;
   if (!($or$cond)) {
    label = 53;
    break;
   }
   $240 = Math_fround($135 + $tu$0);
   $tu$1 = $240;$tv$1 = $tv$0;$ui$1 = $235;$vi$1 = $vi$0;
  } else {
   $241 = (($vi$0) + ($104))|0;
   $242 = (($241) + ($104))|0;
   $243 = (Math_fround(($242|0)));
   $244 = !($243 < $161);
   $245 = !($243 >= $163);
   $or$cond24 = $244 & $245;
   if (!($or$cond24)) {
    label = 53;
    break;
   }
   $246 = Math_fround($136 + $tv$0);
   $tu$1 = $tu$0;$tv$1 = $246;$ui$1 = $ui$0;$vi$1 = $241;
  }
  $247 = $170 < Math_fround(1.00010001659393310547);
  if ($247) {
   $tu$0 = $tu$1;$tv$0 = $tv$1;$ui$0 = $ui$1;$vi$0 = $vi$1;
  } else {
   label = 53;
   break;
  }
 }
 if ((label|0) == 53) {
  STACKTOP = sp;return;
 }
}
function __ZN21BoxTraceSegmentReportD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI21BoxTraceSegmentReportE7prepareERKNS_6PxVec3ES7_S7_RfS8_($this,$aP0,$aP1,$overlapObjectExtent,$expandu,$expandv) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 $expandu = $expandu|0;
 $expandv = $expandv|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($aP1) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($aP0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $1 < $3;
 $5 = $4 ? $1 : $3;
 $6 = (($overlapObjectExtent) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($8 * $12);
 $14 = (($this) + 24|0);
 HEAPF32[$14>>2] = $13;
 $15 = Math_fround(HEAPF32[$0>>2]);
 $16 = Math_fround(HEAPF32[$2>>2]);
 $17 = $15 > $16;
 $18 = $17 ? $15 : $16;
 $19 = Math_fround(HEAPF32[$6>>2]);
 $20 = Math_fround($19 + $18);
 $21 = Math_fround(HEAPF32[$11>>2]);
 $22 = Math_fround($20 * $21);
 $23 = (($this) + 28|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = Math_fround(HEAPF32[$aP1>>2]);
 $27 = Math_fround(HEAPF32[$aP0>>2]);
 $28 = $26 < $27;
 $29 = $28 ? $26 : $27;
 $30 = Math_fround(HEAPF32[$overlapObjectExtent>>2]);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround(HEAPF32[$10>>2]);
 $33 = Math_fround($31 * $32);
 $34 = (Math_fround(Math_floor((Math_fround($33)))));
 $35 = (~~(($34)));
 $36 = (($25) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + -2)|0;
 $39 = ($35|0)>(0);
 $40 = $39 ? $35 : 0;
 $41 = ($40|0)>($38|0);
 $42 = $41 ? $38 : $40;
 $43 = (($this) + 32|0);
 HEAP32[$43>>2] = $42;
 $44 = $26 > $27;
 $45 = $44 ? $26 : $27;
 $46 = Math_fround($30 + $45);
 $47 = Math_fround($46 * $32);
 $48 = (Math_fround(Math_ceil((Math_fround($47)))));
 $49 = (~~(($48)));
 $50 = HEAP32[$36>>2]|0;
 $51 = (($50) + -1)|0;
 $52 = ($49|0)>(0);
 $53 = $52 ? $49 : 0;
 $54 = ($53|0)>($51|0);
 $55 = $54 ? $51 : $53;
 $56 = (($this) + 36|0);
 HEAP32[$56>>2] = $55;
 $57 = (($aP1) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($aP0) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = $58 < $60;
 $62 = $61 ? $58 : $60;
 $63 = (($overlapObjectExtent) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($62 - $64);
 $66 = (($10) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($65 * $67);
 $69 = (Math_fround(Math_floor((Math_fround($68)))));
 $70 = (~~(($69)));
 $71 = (($25) + 20|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + -2)|0;
 $74 = ($70|0)>(0);
 $75 = $74 ? $70 : 0;
 $76 = ($75|0)>($73|0);
 $77 = $76 ? $73 : $75;
 $78 = (($this) + 40|0);
 HEAP32[$78>>2] = $77;
 $79 = $58 > $60;
 $80 = $79 ? $58 : $60;
 $81 = Math_fround($64 + $80);
 $82 = Math_fround($81 * $67);
 $83 = (Math_fround(Math_ceil((Math_fround($82)))));
 $84 = (~~(($83)));
 $85 = HEAP32[$71>>2]|0;
 $86 = (($85) + -1)|0;
 $87 = ($84|0)>(0);
 $88 = $87 ? $84 : 0;
 $89 = ($88|0)>($86|0);
 $90 = $89 ? $86 : $88;
 $91 = (($this) + 44|0);
 HEAP32[$91>>2] = $90;
 $92 = Math_fround($30 * $32);
 $93 = (Math_fround(Math_ceil((Math_fround($92)))));
 HEAPF32[$expandu>>2] = $93;
 $94 = Math_fround(HEAPF32[$63>>2]);
 $95 = HEAP32[$9>>2]|0;
 $96 = (($95) + 8|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($94 * $97);
 $99 = (Math_fround(Math_ceil((Math_fround($98)))));
 HEAPF32[$expandv>>2] = $99;
 $100 = Math_fround(HEAPF32[$expandu>>2]);
 $101 = (~~(($100)));
 $102 = (($101) + 1)|0;
 $103 = (($this) + 16|0);
 HEAP32[$103>>2] = $102;
 $104 = (~~(($99)));
 $105 = (($104) + 1)|0;
 $106 = (($this) + 20|0);
 HEAP32[$106>>2] = $105;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI21BoxTraceSegmentReportE10visitCellsERKNS4_11OverlapLineE($this,$line) {
 $this = $this|0;
 $line = $line|0;
 var $$0 = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $ui$04 = 0, $vi2$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($line) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($line) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)>($3|0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP8[$line>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $7 = (($line) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $39 = (($this) + 52|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + ($8))|0;
  $42 = (($this) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($41|0)<($43|0);
  if ($44) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $45 = (($this) + 36|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($41|0)<($46|0);
  if (!($47)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $48 = (($this) + 56|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + ($1))|0;
  $51 = (($this) + 44|0);
  $52 = (($49) + ($3))|0;
  $53 = ($50|0)>($52|0);
  if ($53) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $54 = (($this) + 40|0);
  $55 = (($this) + 48|0);
  $71 = $49;$72 = $3;$vi2$01 = $50;
  while(1) {
   $56 = HEAP32[$51>>2]|0;
   $57 = ($vi2$01|0)<($56|0);
   if (!($57)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $58 = HEAP32[$54>>2]|0;
   $59 = ($vi2$01|0)<($58|0);
   if ($59) {
    $65 = $71;$66 = $72;
   } else {
    $60 = HEAP32[$55>>2]|0;
    $61 = Math_imul($60, $41)|0;
    $62 = (($61) + ($vi2$01))|0;
    $63 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI21BoxTraceSegmentReportE15testVertexIndexEj($this,$62)|0);
    if (!($63)) {
     $$0 = 0;
     label = 23;
     break;
    }
    $$pre = HEAP32[$2>>2]|0;
    $$pre10 = HEAP32[$48>>2]|0;
    $65 = $$pre10;$66 = $$pre;
   }
   $64 = (($65) + ($66))|0;
   $67 = ($vi2$01|0)<($64|0);
   if (!($67)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $68 = (($vi2$01) + 1)|0;
   $71 = $65;$72 = $66;$vi2$01 = $68;
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $9 = (($this) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8))|0;
  $12 = (($this) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)<($13|0);
  if ($14) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $15 = (($this) + 44|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($11|0)<($16|0);
  if (!($17)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $18 = (($this) + 52|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($1))|0;
  $21 = (($this) + 36|0);
  $22 = (($19) + ($3))|0;
  $23 = ($20|0)>($22|0);
  if ($23) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $24 = (($this) + 32|0);
  $25 = (($this) + 48|0);
  $69 = $19;$70 = $3;$ui$04 = $20;
  while(1) {
   $26 = HEAP32[$21>>2]|0;
   $27 = ($ui$04|0)<($26|0);
   if (!($27)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $28 = HEAP32[$24>>2]|0;
   $29 = ($ui$04|0)<($28|0);
   if ($29) {
    $35 = $69;$36 = $70;
   } else {
    $30 = HEAP32[$25>>2]|0;
    $31 = Math_imul($30, $ui$04)|0;
    $32 = (($31) + ($11))|0;
    $33 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI21BoxTraceSegmentReportE15testVertexIndexEj($this,$32)|0);
    if (!($33)) {
     $$0 = 0;
     label = 23;
     break;
    }
    $$pre11 = HEAP32[$2>>2]|0;
    $$pre12 = HEAP32[$18>>2]|0;
    $35 = $$pre12;$36 = $$pre11;
   }
   $34 = (($35) + ($36))|0;
   $37 = ($ui$04|0)<($34|0);
   if (!($37)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $38 = (($ui$04) + 1)|0;
   $69 = $35;$70 = $36;$ui$04 = $38;
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 return 0|0;
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI21BoxTraceSegmentReportE15testVertexIndexEj($this,$vertexIndex) {
 $this = $this|0;
 $vertexIndex = $vertexIndex|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0;
 var $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($vertexIndex<<2)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = (Math_fround(($5<<16>>16)));
 $7 = (($vertexIndex) + 1)|0;
 $8 = (($3) + ($7<<2)|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = (Math_fround(($9<<16>>16)));
 $11 = (($this) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($vertexIndex))|0;
 $14 = (($3) + ($13<<2)|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = (Math_fround(($15<<16>>16)));
 $17 = (($13) + 1)|0;
 $18 = (($3) + ($17<<2)|0);
 $19 = HEAP16[$18>>1]|0;
 $20 = (Math_fround(($19<<16>>16)));
 $21 = (($this) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = $22 < $6;
 $24 = $22 < $10;
 $or$cond = $23 & $24;
 $25 = $22 < $16;
 $or$cond1 = $or$cond & $25;
 $26 = $22 < $20;
 $or$cond2 = $or$cond1 & $26;
 if ($or$cond2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = (($this) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = $28 > $6;
 $30 = $28 > $10;
 $or$cond3 = $29 & $30;
 $31 = $28 > $16;
 $or$cond4 = $or$cond3 & $31;
 $32 = $28 > $20;
 $or$cond5 = $or$cond4 & $32;
 if ($or$cond5) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = ((($3) + ($vertexIndex<<2)|0) + 2|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34 & 127;
 $36 = ($35<<24>>24)==(127);
 if ($36) {
  $53 = $3;
 } else {
  $37 = $vertexIndex << 1;
  $38 = (($this) + 156|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(16);
  do {
   if ($40) {
    $41 = (($this) + 12|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($this) + 92|0);
    $47 = (FUNCTION_TABLE_iiii[$45 & 2047]($42,16,$46)|0);
    if ($47) {
     HEAP32[$38>>2] = 0;
     $49 = 0;
     break;
    } else {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $49 = $39;
   }
  } while(0);
  $48 = ((($this) + ($49<<2)|0) + 92|0);
  HEAP32[$48>>2] = $37;
  $50 = HEAP32[$38>>2]|0;
  $51 = (($50) + 1)|0;
  HEAP32[$38>>2] = $51;
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre) + 36|0);
  $$pre9 = HEAP32[$$phi$trans$insert>>2]|0;
  $53 = $$pre9;
 }
 $52 = ((($53) + ($vertexIndex<<2)|0) + 3|0);
 $54 = HEAP8[$52>>0]|0;
 $55 = $54 & 127;
 $56 = ($55<<24>>24)==(127);
 if ($56) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $57 = $vertexIndex << 1;
 $58 = $57 | 1;
 $59 = (($this) + 156|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(16);
 do {
  if ($61) {
   $62 = (($this) + 12|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 8|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($this) + 92|0);
   $68 = (FUNCTION_TABLE_iiii[$66 & 2047]($63,16,$67)|0);
   if ($68) {
    HEAP32[$59>>2] = 0;
    $70 = 0;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $70 = $60;
  }
 } while(0);
 $69 = ((($this) + ($70<<2)|0) + 92|0);
 HEAP32[$69>>2] = $58;
 $71 = HEAP32[$59>>2]|0;
 $72 = (($71) + 1)|0;
 HEAP32[$59>>2] = $72;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI24ConvexVsHeightfieldSweepE7prepareERKNS_6PxVec3ES7_S7_RfS8_($this,$aP0,$aP1,$overlapObjectExtent,$expandu,$expandv) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 $expandu = $expandu|0;
 $expandv = $expandv|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($aP1) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($aP0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $1 < $3;
 $5 = $4 ? $1 : $3;
 $6 = (($overlapObjectExtent) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($8 * $12);
 $14 = (($this) + 24|0);
 HEAPF32[$14>>2] = $13;
 $15 = Math_fround(HEAPF32[$0>>2]);
 $16 = Math_fround(HEAPF32[$2>>2]);
 $17 = $15 > $16;
 $18 = $17 ? $15 : $16;
 $19 = Math_fround(HEAPF32[$6>>2]);
 $20 = Math_fround($19 + $18);
 $21 = Math_fround(HEAPF32[$11>>2]);
 $22 = Math_fround($20 * $21);
 $23 = (($this) + 28|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = Math_fround(HEAPF32[$aP1>>2]);
 $27 = Math_fround(HEAPF32[$aP0>>2]);
 $28 = $26 < $27;
 $29 = $28 ? $26 : $27;
 $30 = Math_fround(HEAPF32[$overlapObjectExtent>>2]);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround(HEAPF32[$10>>2]);
 $33 = Math_fround($31 * $32);
 $34 = (Math_fround(Math_floor((Math_fround($33)))));
 $35 = (~~(($34)));
 $36 = (($25) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + -2)|0;
 $39 = ($35|0)>(0);
 $40 = $39 ? $35 : 0;
 $41 = ($40|0)>($38|0);
 $42 = $41 ? $38 : $40;
 $43 = (($this) + 32|0);
 HEAP32[$43>>2] = $42;
 $44 = $26 > $27;
 $45 = $44 ? $26 : $27;
 $46 = Math_fround($30 + $45);
 $47 = Math_fround($46 * $32);
 $48 = (Math_fround(Math_ceil((Math_fround($47)))));
 $49 = (~~(($48)));
 $50 = HEAP32[$36>>2]|0;
 $51 = (($50) + -1)|0;
 $52 = ($49|0)>(0);
 $53 = $52 ? $49 : 0;
 $54 = ($53|0)>($51|0);
 $55 = $54 ? $51 : $53;
 $56 = (($this) + 36|0);
 HEAP32[$56>>2] = $55;
 $57 = (($aP1) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($aP0) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = $58 < $60;
 $62 = $61 ? $58 : $60;
 $63 = (($overlapObjectExtent) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($62 - $64);
 $66 = (($10) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($65 * $67);
 $69 = (Math_fround(Math_floor((Math_fround($68)))));
 $70 = (~~(($69)));
 $71 = (($25) + 20|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + -2)|0;
 $74 = ($70|0)>(0);
 $75 = $74 ? $70 : 0;
 $76 = ($75|0)>($73|0);
 $77 = $76 ? $73 : $75;
 $78 = (($this) + 40|0);
 HEAP32[$78>>2] = $77;
 $79 = $58 > $60;
 $80 = $79 ? $58 : $60;
 $81 = Math_fround($64 + $80);
 $82 = Math_fround($81 * $67);
 $83 = (Math_fround(Math_ceil((Math_fround($82)))));
 $84 = (~~(($83)));
 $85 = HEAP32[$71>>2]|0;
 $86 = (($85) + -1)|0;
 $87 = ($84|0)>(0);
 $88 = $87 ? $84 : 0;
 $89 = ($88|0)>($86|0);
 $90 = $89 ? $86 : $88;
 $91 = (($this) + 44|0);
 HEAP32[$91>>2] = $90;
 $92 = Math_fround($30 * $32);
 $93 = (Math_fround(Math_ceil((Math_fround($92)))));
 HEAPF32[$expandu>>2] = $93;
 $94 = Math_fround(HEAPF32[$63>>2]);
 $95 = HEAP32[$9>>2]|0;
 $96 = (($95) + 8|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($94 * $97);
 $99 = (Math_fround(Math_ceil((Math_fround($98)))));
 HEAPF32[$expandv>>2] = $99;
 $100 = Math_fround(HEAPF32[$expandu>>2]);
 $101 = (~~(($100)));
 $102 = (($101) + 1)|0;
 $103 = (($this) + 16|0);
 HEAP32[$103>>2] = $102;
 $104 = (~~(($99)));
 $105 = (($104) + 1)|0;
 $106 = (($this) + 20|0);
 HEAP32[$106>>2] = $105;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI24ConvexVsHeightfieldSweepE10visitCellsERKNS4_11OverlapLineE($this,$line) {
 $this = $this|0;
 $line = $line|0;
 var $$0 = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $ui$04 = 0, $vi2$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($line) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($line) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)>($3|0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP8[$line>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $7 = (($line) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $39 = (($this) + 52|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + ($8))|0;
  $42 = (($this) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($41|0)<($43|0);
  if ($44) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $45 = (($this) + 36|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($41|0)<($46|0);
  if (!($47)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $48 = (($this) + 56|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + ($1))|0;
  $51 = (($this) + 44|0);
  $52 = (($49) + ($3))|0;
  $53 = ($50|0)>($52|0);
  if ($53) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $54 = (($this) + 40|0);
  $55 = (($this) + 48|0);
  $71 = $49;$72 = $3;$vi2$01 = $50;
  while(1) {
   $56 = HEAP32[$51>>2]|0;
   $57 = ($vi2$01|0)<($56|0);
   if (!($57)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $58 = HEAP32[$54>>2]|0;
   $59 = ($vi2$01|0)<($58|0);
   if ($59) {
    $65 = $71;$66 = $72;
   } else {
    $60 = HEAP32[$55>>2]|0;
    $61 = Math_imul($60, $41)|0;
    $62 = (($61) + ($vi2$01))|0;
    $63 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI24ConvexVsHeightfieldSweepE15testVertexIndexEj($this,$62)|0);
    if (!($63)) {
     $$0 = 0;
     label = 23;
     break;
    }
    $$pre = HEAP32[$2>>2]|0;
    $$pre10 = HEAP32[$48>>2]|0;
    $65 = $$pre10;$66 = $$pre;
   }
   $64 = (($65) + ($66))|0;
   $67 = ($vi2$01|0)<($64|0);
   if (!($67)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $68 = (($vi2$01) + 1)|0;
   $71 = $65;$72 = $66;$vi2$01 = $68;
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $9 = (($this) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8))|0;
  $12 = (($this) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)<($13|0);
  if ($14) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $15 = (($this) + 44|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($11|0)<($16|0);
  if (!($17)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $18 = (($this) + 52|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($1))|0;
  $21 = (($this) + 36|0);
  $22 = (($19) + ($3))|0;
  $23 = ($20|0)>($22|0);
  if ($23) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $24 = (($this) + 32|0);
  $25 = (($this) + 48|0);
  $69 = $19;$70 = $3;$ui$04 = $20;
  while(1) {
   $26 = HEAP32[$21>>2]|0;
   $27 = ($ui$04|0)<($26|0);
   if (!($27)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $28 = HEAP32[$24>>2]|0;
   $29 = ($ui$04|0)<($28|0);
   if ($29) {
    $35 = $69;$36 = $70;
   } else {
    $30 = HEAP32[$25>>2]|0;
    $31 = Math_imul($30, $ui$04)|0;
    $32 = (($31) + ($11))|0;
    $33 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI24ConvexVsHeightfieldSweepE15testVertexIndexEj($this,$32)|0);
    if (!($33)) {
     $$0 = 0;
     label = 23;
     break;
    }
    $$pre11 = HEAP32[$2>>2]|0;
    $$pre12 = HEAP32[$18>>2]|0;
    $35 = $$pre12;$36 = $$pre11;
   }
   $34 = (($35) + ($36))|0;
   $37 = ($ui$04|0)<($34|0);
   if (!($37)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $38 = (($ui$04) + 1)|0;
   $69 = $35;$70 = $36;$ui$04 = $38;
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 return 0|0;
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI24ConvexVsHeightfieldSweepE15testVertexIndexEj($this,$vertexIndex) {
 $this = $this|0;
 $vertexIndex = $vertexIndex|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0;
 var $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($vertexIndex<<2)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = (Math_fround(($5<<16>>16)));
 $7 = (($vertexIndex) + 1)|0;
 $8 = (($3) + ($7<<2)|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = (Math_fround(($9<<16>>16)));
 $11 = (($this) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($vertexIndex))|0;
 $14 = (($3) + ($13<<2)|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = (Math_fround(($15<<16>>16)));
 $17 = (($13) + 1)|0;
 $18 = (($3) + ($17<<2)|0);
 $19 = HEAP16[$18>>1]|0;
 $20 = (Math_fround(($19<<16>>16)));
 $21 = (($this) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = $22 < $6;
 $24 = $22 < $10;
 $or$cond = $23 & $24;
 $25 = $22 < $16;
 $or$cond1 = $or$cond & $25;
 $26 = $22 < $20;
 $or$cond2 = $or$cond1 & $26;
 if ($or$cond2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = (($this) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = $28 > $6;
 $30 = $28 > $10;
 $or$cond3 = $29 & $30;
 $31 = $28 > $16;
 $or$cond4 = $or$cond3 & $31;
 $32 = $28 > $20;
 $or$cond5 = $or$cond4 & $32;
 if ($or$cond5) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = ((($3) + ($vertexIndex<<2)|0) + 2|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34 & 127;
 $36 = ($35<<24>>24)==(127);
 if ($36) {
  $53 = $3;
 } else {
  $37 = $vertexIndex << 1;
  $38 = (($this) + 156|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(16);
  do {
   if ($40) {
    $41 = (($this) + 12|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($this) + 92|0);
    $47 = (FUNCTION_TABLE_iiii[$45 & 2047]($42,16,$46)|0);
    if ($47) {
     HEAP32[$38>>2] = 0;
     $49 = 0;
     break;
    } else {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $49 = $39;
   }
  } while(0);
  $48 = ((($this) + ($49<<2)|0) + 92|0);
  HEAP32[$48>>2] = $37;
  $50 = HEAP32[$38>>2]|0;
  $51 = (($50) + 1)|0;
  HEAP32[$38>>2] = $51;
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre) + 36|0);
  $$pre9 = HEAP32[$$phi$trans$insert>>2]|0;
  $53 = $$pre9;
 }
 $52 = ((($53) + ($vertexIndex<<2)|0) + 3|0);
 $54 = HEAP8[$52>>0]|0;
 $55 = $54 & 127;
 $56 = ($55<<24>>24)==(127);
 if ($56) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $57 = $vertexIndex << 1;
 $58 = $57 | 1;
 $59 = (($this) + 156|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(16);
 do {
  if ($61) {
   $62 = (($this) + 12|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 8|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($this) + 92|0);
   $68 = (FUNCTION_TABLE_iiii[$66 & 2047]($63,16,$67)|0);
   if ($68) {
    HEAP32[$59>>2] = 0;
    $70 = 0;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $70 = $60;
  }
 } while(0);
 $69 = ((($this) + ($70<<2)|0) + 92|0);
 HEAP32[$69>>2] = $58;
 $71 = HEAP32[$59>>2]|0;
 $72 = (($71) + 1)|0;
 HEAP32[$59>>2] = $72;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI25CapsuleTraceSegmentReportE7prepareERKNS_6PxVec3ES7_S7_RfS8_($this,$aP0,$aP1,$overlapObjectExtent,$expandu,$expandv) {
 $this = $this|0;
 $aP0 = $aP0|0;
 $aP1 = $aP1|0;
 $overlapObjectExtent = $overlapObjectExtent|0;
 $expandu = $expandu|0;
 $expandv = $expandv|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($aP1) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($aP0) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $1 < $3;
 $5 = $4 ? $1 : $3;
 $6 = (($overlapObjectExtent) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($8 * $12);
 $14 = (($this) + 24|0);
 HEAPF32[$14>>2] = $13;
 $15 = Math_fround(HEAPF32[$0>>2]);
 $16 = Math_fround(HEAPF32[$2>>2]);
 $17 = $15 > $16;
 $18 = $17 ? $15 : $16;
 $19 = Math_fround(HEAPF32[$6>>2]);
 $20 = Math_fround($19 + $18);
 $21 = Math_fround(HEAPF32[$11>>2]);
 $22 = Math_fround($20 * $21);
 $23 = (($this) + 28|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($this) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = Math_fround(HEAPF32[$aP1>>2]);
 $27 = Math_fround(HEAPF32[$aP0>>2]);
 $28 = $26 < $27;
 $29 = $28 ? $26 : $27;
 $30 = Math_fround(HEAPF32[$overlapObjectExtent>>2]);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround(HEAPF32[$10>>2]);
 $33 = Math_fround($31 * $32);
 $34 = (Math_fround(Math_floor((Math_fround($33)))));
 $35 = (~~(($34)));
 $36 = (($25) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + -2)|0;
 $39 = ($35|0)>(0);
 $40 = $39 ? $35 : 0;
 $41 = ($40|0)>($38|0);
 $42 = $41 ? $38 : $40;
 $43 = (($this) + 32|0);
 HEAP32[$43>>2] = $42;
 $44 = $26 > $27;
 $45 = $44 ? $26 : $27;
 $46 = Math_fround($30 + $45);
 $47 = Math_fround($46 * $32);
 $48 = (Math_fround(Math_ceil((Math_fround($47)))));
 $49 = (~~(($48)));
 $50 = HEAP32[$36>>2]|0;
 $51 = (($50) + -1)|0;
 $52 = ($49|0)>(0);
 $53 = $52 ? $49 : 0;
 $54 = ($53|0)>($51|0);
 $55 = $54 ? $51 : $53;
 $56 = (($this) + 36|0);
 HEAP32[$56>>2] = $55;
 $57 = (($aP1) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($aP0) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = $58 < $60;
 $62 = $61 ? $58 : $60;
 $63 = (($overlapObjectExtent) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($62 - $64);
 $66 = (($10) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($65 * $67);
 $69 = (Math_fround(Math_floor((Math_fround($68)))));
 $70 = (~~(($69)));
 $71 = (($25) + 20|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + -2)|0;
 $74 = ($70|0)>(0);
 $75 = $74 ? $70 : 0;
 $76 = ($75|0)>($73|0);
 $77 = $76 ? $73 : $75;
 $78 = (($this) + 40|0);
 HEAP32[$78>>2] = $77;
 $79 = $58 > $60;
 $80 = $79 ? $58 : $60;
 $81 = Math_fround($64 + $80);
 $82 = Math_fround($81 * $67);
 $83 = (Math_fround(Math_ceil((Math_fround($82)))));
 $84 = (~~(($83)));
 $85 = HEAP32[$71>>2]|0;
 $86 = (($85) + -1)|0;
 $87 = ($84|0)>(0);
 $88 = $87 ? $84 : 0;
 $89 = ($88|0)>($86|0);
 $90 = $89 ? $86 : $88;
 $91 = (($this) + 44|0);
 HEAP32[$91>>2] = $90;
 $92 = Math_fround($30 * $32);
 $93 = (Math_fround(Math_ceil((Math_fround($92)))));
 HEAPF32[$expandu>>2] = $93;
 $94 = Math_fround(HEAPF32[$63>>2]);
 $95 = HEAP32[$9>>2]|0;
 $96 = (($95) + 8|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($94 * $97);
 $99 = (Math_fround(Math_ceil((Math_fround($98)))));
 HEAPF32[$expandv>>2] = $99;
 $100 = Math_fround(HEAPF32[$expandu>>2]);
 $101 = (~~(($100)));
 $102 = (($101) + 1)|0;
 $103 = (($this) + 16|0);
 HEAP32[$103>>2] = $102;
 $104 = (~~(($99)));
 $105 = (($104) + 1)|0;
 $106 = (($this) + 20|0);
 HEAP32[$106>>2] = $105;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI25CapsuleTraceSegmentReportE10visitCellsERKNS4_11OverlapLineE($this,$line) {
 $this = $this|0;
 $line = $line|0;
 var $$0 = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $ui$04 = 0, $vi2$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($line) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($line) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)>($3|0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP8[$line>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $7 = (($line) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $39 = (($this) + 52|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + ($8))|0;
  $42 = (($this) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($41|0)<($43|0);
  if ($44) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $45 = (($this) + 36|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($41|0)<($46|0);
  if (!($47)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $48 = (($this) + 56|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + ($1))|0;
  $51 = (($this) + 44|0);
  $52 = (($49) + ($3))|0;
  $53 = ($50|0)>($52|0);
  if ($53) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $54 = (($this) + 40|0);
  $55 = (($this) + 48|0);
  $71 = $49;$72 = $3;$vi2$01 = $50;
  while(1) {
   $56 = HEAP32[$51>>2]|0;
   $57 = ($vi2$01|0)<($56|0);
   if (!($57)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $58 = HEAP32[$54>>2]|0;
   $59 = ($vi2$01|0)<($58|0);
   if ($59) {
    $65 = $71;$66 = $72;
   } else {
    $60 = HEAP32[$55>>2]|0;
    $61 = Math_imul($60, $41)|0;
    $62 = (($61) + ($vi2$01))|0;
    $63 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI25CapsuleTraceSegmentReportE15testVertexIndexEj($this,$62)|0);
    if (!($63)) {
     $$0 = 0;
     label = 23;
     break;
    }
    $$pre = HEAP32[$2>>2]|0;
    $$pre10 = HEAP32[$48>>2]|0;
    $65 = $$pre10;$66 = $$pre;
   }
   $64 = (($65) + ($66))|0;
   $67 = ($vi2$01|0)<($64|0);
   if (!($67)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $68 = (($vi2$01) + 1)|0;
   $71 = $65;$72 = $66;$vi2$01 = $68;
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $9 = (($this) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8))|0;
  $12 = (($this) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)<($13|0);
  if ($14) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $15 = (($this) + 44|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($11|0)<($16|0);
  if (!($17)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $18 = (($this) + 52|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($1))|0;
  $21 = (($this) + 36|0);
  $22 = (($19) + ($3))|0;
  $23 = ($20|0)>($22|0);
  if ($23) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $24 = (($this) + 32|0);
  $25 = (($this) + 48|0);
  $69 = $19;$70 = $3;$ui$04 = $20;
  while(1) {
   $26 = HEAP32[$21>>2]|0;
   $27 = ($ui$04|0)<($26|0);
   if (!($27)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $28 = HEAP32[$24>>2]|0;
   $29 = ($ui$04|0)<($28|0);
   if ($29) {
    $35 = $69;$36 = $70;
   } else {
    $30 = HEAP32[$25>>2]|0;
    $31 = Math_imul($30, $ui$04)|0;
    $32 = (($31) + ($11))|0;
    $33 = (__ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI25CapsuleTraceSegmentReportE15testVertexIndexEj($this,$32)|0);
    if (!($33)) {
     $$0 = 0;
     label = 23;
     break;
    }
    $$pre11 = HEAP32[$2>>2]|0;
    $$pre12 = HEAP32[$18>>2]|0;
    $35 = $$pre12;$36 = $$pre11;
   }
   $34 = (($35) + ($36))|0;
   $37 = ($ui$04|0)<($34|0);
   if (!($37)) {
    $$0 = 1;
    label = 23;
    break;
   }
   $38 = (($ui$04) + 1)|0;
   $69 = $35;$70 = $36;$ui$04 = $38;
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 return 0|0;
}
function __ZN5physx2Gu15HeightFieldUtil19OverlapTraceSegmentI25CapsuleTraceSegmentReportE15testVertexIndexEj($this,$vertexIndex) {
 $this = $this|0;
 $vertexIndex = $vertexIndex|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0;
 var $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($vertexIndex<<2)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = (Math_fround(($5<<16>>16)));
 $7 = (($vertexIndex) + 1)|0;
 $8 = (($3) + ($7<<2)|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = (Math_fround(($9<<16>>16)));
 $11 = (($this) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($vertexIndex))|0;
 $14 = (($3) + ($13<<2)|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = (Math_fround(($15<<16>>16)));
 $17 = (($13) + 1)|0;
 $18 = (($3) + ($17<<2)|0);
 $19 = HEAP16[$18>>1]|0;
 $20 = (Math_fround(($19<<16>>16)));
 $21 = (($this) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = $22 < $6;
 $24 = $22 < $10;
 $or$cond = $23 & $24;
 $25 = $22 < $16;
 $or$cond1 = $or$cond & $25;
 $26 = $22 < $20;
 $or$cond2 = $or$cond1 & $26;
 if ($or$cond2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = (($this) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = $28 > $6;
 $30 = $28 > $10;
 $or$cond3 = $29 & $30;
 $31 = $28 > $16;
 $or$cond4 = $or$cond3 & $31;
 $32 = $28 > $20;
 $or$cond5 = $or$cond4 & $32;
 if ($or$cond5) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = ((($3) + ($vertexIndex<<2)|0) + 2|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34 & 127;
 $36 = ($35<<24>>24)==(127);
 if ($36) {
  $53 = $3;
 } else {
  $37 = $vertexIndex << 1;
  $38 = (($this) + 156|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(16);
  do {
   if ($40) {
    $41 = (($this) + 12|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($this) + 92|0);
    $47 = (FUNCTION_TABLE_iiii[$45 & 2047]($42,16,$46)|0);
    if ($47) {
     HEAP32[$38>>2] = 0;
     $49 = 0;
     break;
    } else {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $49 = $39;
   }
  } while(0);
  $48 = ((($this) + ($49<<2)|0) + 92|0);
  HEAP32[$48>>2] = $37;
  $50 = HEAP32[$38>>2]|0;
  $51 = (($50) + 1)|0;
  HEAP32[$38>>2] = $51;
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = (($$pre) + 36|0);
  $$pre9 = HEAP32[$$phi$trans$insert>>2]|0;
  $53 = $$pre9;
 }
 $52 = ((($53) + ($vertexIndex<<2)|0) + 3|0);
 $54 = HEAP8[$52>>0]|0;
 $55 = $54 & 127;
 $56 = ($55<<24>>24)==(127);
 if ($56) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $57 = $vertexIndex << 1;
 $58 = $57 | 1;
 $59 = (($this) + 156|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(16);
 do {
  if ($61) {
   $62 = (($this) + 12|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 8|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($this) + 92|0);
   $68 = (FUNCTION_TABLE_iiii[$66 & 2047]($63,16,$67)|0);
   if ($68) {
    HEAP32[$59>>2] = 0;
    $70 = 0;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $70 = $60;
  }
 } while(0);
 $69 = ((($this) + ($70<<2)|0) + 92|0);
 HEAP32[$69>>2] = $58;
 $71 = HEAP32[$59>>2]|0;
 $72 = (($71) + 1)|0;
 HEAP32[$59>>2] = $72;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN21BoxTraceSegmentReportD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN21BoxTraceSegmentReport7onEventEjPj($this,$nb,$indices) {
 $this = $this|0;
 $nb = $nb|0;
 $indices = $indices|0;
 var $$phi$trans$insert$pre = 0, $$phi$trans$insert$pre$phiZZZZ2D = 0, $$pre = 0, $$sroa$1$i$i = 0, $$sroa$113$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $closestA = 0, $currentTriangle = 0, $dir = 0, $i$0121 = 0, $normal = 0, $phitmp = 0;
 var $toi = 0, $triangle = 0, $zero = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $zero$sroa$1$i$i$i = sp + 304|0;
 $0 = sp + 240|0;
 $$sroa$113$i$i = sp + 256|0;
 $$sroa$1$i$i = sp + 316|0;
 $zero = sp + 224|0;
 $zeroV = sp + 64|0;
 $dir = sp + 48|0;
 $toi = sp + 32|0;
 $closestA = sp + 16|0;
 $normal = sp;
 $currentTriangle = sp + 268|0;
 $triangle = sp + 80|0;
 HEAPF32[$zero>>2] = Math_fround(0.0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $1 = (($this) + 48|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 56|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$dir>>2] = $2;
 $7 = (($dir) + 4|0);
 HEAPF32[$7>>2] = $4;
 $8 = (($dir) + 8|0);
 HEAPF32[$8>>2] = $6;
 $9 = (($dir) + 12|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = ($nb|0)==(0);
 L1: do {
  if ($10) {
   $$phi$trans$insert$pre = (($this) + 68|0);
   $$phi$trans$insert$pre$phiZZZZ2D = $$phi$trans$insert$pre;
   label = 12;
  } else {
   $11 = (($this) + 12|0);
   $12 = (($this) + 8|0);
   $13 = (($currentTriangle) + 4|0);
   $14 = (($currentTriangle) + 8|0);
   $15 = (($currentTriangle) + 12|0);
   $16 = (($currentTriangle) + 16|0);
   $17 = (($currentTriangle) + 20|0);
   $18 = (($currentTriangle) + 24|0);
   $19 = (($currentTriangle) + 28|0);
   $20 = (($currentTriangle) + 32|0);
   $21 = (($this) + 4|0);
   $22 = (($this) + 69|0);
   $23 = (($triangle) + 64|0);
   $24 = (($triangle) + 80|0);
   $25 = (($triangle) + 16|0);
   $26 = (($triangle) + 20|0);
   $27 = (($triangle) + 32|0);
   $28 = (($triangle) + 36|0);
   $29 = (($triangle) + 48|0);
   $30 = (($triangle) + 52|0);
   $31 = (($triangle) + 4|0);
   $32 = (($triangle) + 8|0);
   $33 = (($triangle) + 12|0);
   $34 = (($triangle) + 96|0);
   $35 = (($triangle) + 100|0);
   $36 = (($triangle) + 104|0);
   $37 = (($triangle) + 108|0);
   $38 = (($triangle) + 112|0);
   $39 = (($triangle) + 116|0);
   $40 = (($triangle) + 120|0);
   $41 = (($triangle) + 124|0);
   $42 = (($triangle) + 128|0);
   $43 = (($triangle) + 132|0);
   $44 = (($triangle) + 136|0);
   $45 = (($triangle) + 140|0);
   $46 = (($this) + 16|0);
   $47 = (($this) + 64|0);
   $48 = (($this) + 68|0);
   $49 = (($this) + 32|0);
   $50 = (($this) + 32|0);
   $51 = (($this) + 60|0);
   $52 = (($normal) + 4|0);
   $53 = (($normal) + 8|0);
   $54 = (($closestA) + 4|0);
   $55 = (($closestA) + 8|0);
   $i$0121 = 0;
   while(1) {
    $56 = (($indices) + ($i$0121<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = HEAP32[$11>>2]|0;
    $59 = HEAP32[$12>>2]|0;
    (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($58,$59,$currentTriangle,0,0,$57,1,1)|0);
    $60 = Math_fround(HEAPF32[$currentTriangle>>2]);
    $61 = Math_fround(HEAPF32[$13>>2]);
    $62 = Math_fround(HEAPF32[$14>>2]);
    $63 = Math_fround(HEAPF32[$15>>2]);
    $64 = Math_fround(HEAPF32[$16>>2]);
    $65 = Math_fround(HEAPF32[$17>>2]);
    $66 = Math_fround(HEAPF32[$18>>2]);
    $67 = Math_fround(HEAPF32[$19>>2]);
    $68 = Math_fround(HEAPF32[$20>>2]);
    $69 = HEAP32[$21>>2]|0;
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = (($69) + 4|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = (($69) + 8|0);
    $74 = Math_fround(HEAPF32[$73>>2]);
    $75 = (($69) + 12|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = (($69) + 16|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = (($69) + 20|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = (($69) + 24|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround($76 * $76);
    $84 = Math_fround($83 + Math_fround(-0.5));
    $85 = Math_fround($60 * $84);
    $86 = Math_fround($61 * $84);
    $87 = Math_fround($62 * $84);
    $88 = Math_fround($62 * $72);
    $89 = Math_fround($61 * $74);
    $90 = Math_fround($88 - $89);
    $91 = Math_fround($60 * $74);
    $92 = Math_fround($62 * $70);
    $93 = Math_fround($91 - $92);
    $94 = Math_fround($61 * $70);
    $95 = Math_fround($60 * $72);
    $96 = Math_fround($94 - $95);
    $97 = Math_fround($76 * $90);
    $98 = Math_fround($76 * $93);
    $99 = Math_fround($76 * $96);
    $100 = Math_fround($97 + $85);
    $101 = Math_fround($98 + $86);
    $102 = Math_fround($99 + $87);
    $103 = Math_fround($60 * $70);
    $104 = Math_fround($61 * $72);
    $105 = Math_fround($103 + $104);
    $106 = Math_fround($62 * $74);
    $107 = Math_fround($105 + $106);
    $108 = Math_fround($70 * $107);
    $109 = Math_fround($72 * $107);
    $110 = Math_fround($74 * $107);
    $111 = Math_fround($108 + $100);
    $112 = Math_fround($109 + $101);
    $113 = Math_fround($110 + $102);
    $114 = Math_fround($111 * Math_fround(2.0));
    $115 = Math_fround($112 * Math_fround(2.0));
    $116 = Math_fround($113 * Math_fround(2.0));
    $117 = Math_fround($78 + $114);
    $118 = Math_fround($80 + $115);
    $119 = Math_fround($82 + $116);
    $120 = Math_fround($63 * $84);
    $121 = Math_fround($64 * $84);
    $122 = Math_fround($65 * $84);
    $123 = Math_fround($65 * $72);
    $124 = Math_fround($64 * $74);
    $125 = Math_fround($123 - $124);
    $126 = Math_fround($63 * $74);
    $127 = Math_fround($65 * $70);
    $128 = Math_fround($126 - $127);
    $129 = Math_fround($64 * $70);
    $130 = Math_fround($63 * $72);
    $131 = Math_fround($129 - $130);
    $132 = Math_fround($76 * $125);
    $133 = Math_fround($76 * $128);
    $134 = Math_fround($76 * $131);
    $135 = Math_fround($132 + $120);
    $136 = Math_fround($133 + $121);
    $137 = Math_fround($134 + $122);
    $138 = Math_fround($63 * $70);
    $139 = Math_fround($64 * $72);
    $140 = Math_fround($138 + $139);
    $141 = Math_fround($65 * $74);
    $142 = Math_fround($140 + $141);
    $143 = Math_fround($70 * $142);
    $144 = Math_fround($72 * $142);
    $145 = Math_fround($74 * $142);
    $146 = Math_fround($143 + $135);
    $147 = Math_fround($144 + $136);
    $148 = Math_fround($145 + $137);
    $149 = Math_fround($146 * Math_fround(2.0));
    $150 = Math_fround($147 * Math_fround(2.0));
    $151 = Math_fround($148 * Math_fround(2.0));
    $152 = Math_fround($78 + $149);
    $153 = Math_fround($80 + $150);
    $154 = Math_fround($82 + $151);
    $155 = Math_fround($66 * $84);
    $156 = Math_fround($67 * $84);
    $157 = Math_fround($68 * $84);
    $158 = Math_fround($68 * $72);
    $159 = Math_fround($67 * $74);
    $160 = Math_fround($158 - $159);
    $161 = Math_fround($66 * $74);
    $162 = Math_fround($68 * $70);
    $163 = Math_fround($161 - $162);
    $164 = Math_fround($67 * $70);
    $165 = Math_fround($66 * $72);
    $166 = Math_fround($164 - $165);
    $167 = Math_fround($76 * $160);
    $168 = Math_fround($76 * $163);
    $169 = Math_fround($76 * $166);
    $170 = Math_fround($167 + $155);
    $171 = Math_fround($168 + $156);
    $172 = Math_fround($169 + $157);
    $173 = Math_fround($66 * $70);
    $174 = Math_fround($67 * $72);
    $175 = Math_fround($173 + $174);
    $176 = Math_fround($68 * $74);
    $177 = Math_fround($175 + $176);
    $178 = Math_fround($70 * $177);
    $179 = Math_fround($72 * $177);
    $180 = Math_fround($74 * $177);
    $181 = Math_fround($178 + $170);
    $182 = Math_fround($179 + $171);
    $183 = Math_fround($180 + $172);
    $184 = Math_fround($181 * Math_fround(2.0));
    $185 = Math_fround($182 * Math_fround(2.0));
    $186 = Math_fround($183 * Math_fround(2.0));
    $187 = Math_fround($78 + $184);
    $188 = Math_fround($80 + $185);
    $189 = Math_fround($82 + $186);
    $190 = HEAP8[$22>>0]|0;
    $191 = ($190<<24>>24)==(0);
    if ($191) {
     $192 = Math_fround($187 - $152);
     $193 = Math_fround($188 - $153);
     $194 = Math_fround($189 - $154);
     $195 = Math_fround($117 - $152);
     $196 = Math_fround($118 - $153);
     $197 = Math_fround($119 - $154);
     $198 = Math_fround($193 * $197);
     $199 = Math_fround($194 * $196);
     $200 = Math_fround($198 - $199);
     $201 = Math_fround($194 * $195);
     $202 = Math_fround($197 * $192);
     $203 = Math_fround($201 - $202);
     $204 = Math_fround($196 * $192);
     $205 = Math_fround($193 * $195);
     $206 = Math_fround($204 - $205);
     $207 = Math_fround(HEAPF32[$dir>>2]);
     $208 = Math_fround(HEAPF32[$7>>2]);
     $209 = Math_fround(HEAPF32[$8>>2]);
     $210 = Math_fround($200 * $207);
     $211 = Math_fround($203 * $208);
     $212 = Math_fround($210 + $211);
     $213 = Math_fround($206 * $209);
     $214 = Math_fround($212 + $213);
     $215 = Math_fround(HEAPF32[$zero>>2]);
     $216 = !($214 >= $215);
     if ($216) {
      label = 6;
     }
    } else {
     label = 6;
    }
    if ((label|0) == 6) {
     label = 0;
     HEAP32[$24>>2] = 7;
     HEAPF32[$29>>2] = Math_fround(0.0);
     ;HEAP32[$30+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
     ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
     ;HEAP32[$23+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$0+12>>2]|0;
     $217 = Math_fround($117 + $152);
     $218 = Math_fround($118 + $153);
     $219 = Math_fround($119 + $154);
     $220 = Math_fround($187 + $217);
     $221 = Math_fround($188 + $218);
     $222 = Math_fround($189 + $219);
     $223 = Math_fround($220 * Math_fround(0.333332985639572143555));
     $224 = Math_fround($221 * Math_fround(0.333332985639572143555));
     $225 = Math_fround($222 * Math_fround(0.333332985639572143555));
     HEAPF32[$triangle>>2] = $223;
     HEAPF32[$31>>2] = $224;
     HEAPF32[$32>>2] = $225;
     HEAPF32[$33>>2] = Math_fround(0.0);
     HEAPF32[$34>>2] = $117;
     HEAPF32[$35>>2] = $118;
     HEAPF32[$36>>2] = $119;
     HEAPF32[$37>>2] = Math_fround(0.0);
     HEAPF32[$38>>2] = $152;
     HEAPF32[$39>>2] = $153;
     HEAPF32[$40>>2] = $154;
     HEAPF32[$41>>2] = Math_fround(0.0);
     HEAPF32[$42>>2] = $187;
     HEAPF32[$43>>2] = $188;
     HEAPF32[$44>>2] = $189;
     HEAPF32[$45>>2] = Math_fround(0.0);
     HEAPF32[$25>>2] = Math_fround(0.0);
     ;HEAP32[$26+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
     HEAPF32[$27>>2] = Math_fround(3.40282346638528859812E+38);
     ;HEAP32[$28+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
     $226 = HEAP32[$46>>2]|0;
     $227 = Math_fround(HEAPF32[$47>>2]);
     $228 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_9TriangleVERNS0_4BoxVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($triangle,$226,$zero,$zeroV,$dir,$toi,$normal,$closestA,$227,0)|0);
     if ($228) {
      HEAP8[$48>>0] = 1;
      $229 = Math_fround(HEAPF32[$toi>>2]);
      $230 = Math_fround(HEAPF32[$zero>>2]);
      $231 = $229 > $230;
      if (!($231)) {
       break;
      }
      $232 = Math_fround(HEAPF32[$49>>2]);
      $233 = $232 > $229;
      if ($233) {
       ;HEAP32[$50+0>>2]=HEAP32[$toi+0>>2]|0;HEAP32[$50+4>>2]=HEAP32[$toi+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$toi+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$toi+12>>2]|0;
       $234 = HEAP32[$51>>2]|0;
       $235 = (($234) + 40|0);
       HEAPF32[$235>>2] = $229;
       $236 = Math_fround(HEAPF32[$normal>>2]);
       $237 = Math_fround(HEAPF32[$52>>2]);
       $238 = Math_fround(HEAPF32[$53>>2]);
       $239 = (($234) + 28|0);
       HEAPF32[$239>>2] = $236;
       $240 = (($234) + 32|0);
       HEAPF32[$240>>2] = $237;
       $241 = (($234) + 36|0);
       HEAPF32[$241>>2] = $238;
       $242 = Math_fround(HEAPF32[$closestA>>2]);
       $243 = Math_fround(HEAPF32[$54>>2]);
       $244 = Math_fround(HEAPF32[$55>>2]);
       $245 = (($234) + 16|0);
       HEAPF32[$245>>2] = $242;
       $246 = (($234) + 20|0);
       HEAPF32[$246>>2] = $243;
       $247 = (($234) + 24|0);
       HEAPF32[$247>>2] = $244;
       $248 = (($234) + 8|0);
       HEAP32[$248>>2] = $57;
      }
     }
    }
    $253 = (($i$0121) + 1)|0;
    $254 = ($253>>>0)<($nb>>>0);
    if ($254) {
     $i$0121 = $253;
    } else {
     $$phi$trans$insert$pre$phiZZZZ2D = $48;
     label = 12;
     break L1;
    }
   }
   $249 = HEAP32[$51>>2]|0;
   $250 = (($249) + 40|0);
   HEAPF32[$250>>2] = Math_fround(0.0);
   $251 = (($249) + 8|0);
   HEAP32[$251>>2] = $57;
   $252 = (($this) + 70|0);
   HEAP8[$252>>0] = 1;
  }
 } while(0);
 if ((label|0) == 12) {
  $$pre = HEAP8[$$phi$trans$insert$pre$phiZZZZ2D>>0]|0;
  $phitmp = ($$pre<<24>>24)==(0);
  if ($phitmp) {
   STACKTOP = sp;return 1;
  }
 }
 $255 = (($this) + 60|0);
 $256 = HEAP32[$255>>2]|0;
 $257 = (($256) + 28|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 $259 = Math_fround($258 * $258);
 $260 = (($256) + 32|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = Math_fround($261 * $261);
 $263 = Math_fround($259 + $262);
 $264 = (($256) + 36|0);
 $265 = Math_fround(HEAPF32[$264>>2]);
 $266 = Math_fround($265 * $265);
 $267 = Math_fround($263 + $266);
 $268 = (Math_fround(Math_sqrt((Math_fround($267)))));
 $269 = $268 > Math_fround(0.0);
 if ($269) {
  $270 = Math_fround(Math_fround(1.0) / $268);
  $271 = Math_fround($258 * $270);
  HEAPF32[$257>>2] = $271;
  $272 = Math_fround($261 * $270);
  HEAPF32[$260>>2] = $272;
  $273 = Math_fround($265 * $270);
  HEAPF32[$264>>2] = $273;
  $276 = $271;$279 = $272;$283 = $273;
 } else {
  $276 = $258;$279 = $261;$283 = $265;
 }
 $274 = Math_fround(HEAPF32[$1>>2]);
 $275 = Math_fround($276 * $274);
 $277 = Math_fround(HEAPF32[$3>>2]);
 $278 = Math_fround($279 * $277);
 $280 = Math_fround($275 + $278);
 $281 = Math_fround(HEAPF32[$5>>2]);
 $282 = Math_fround($283 * $281);
 $284 = Math_fround($280 + $282);
 $285 = $284 > Math_fround(0.0);
 if (!($285)) {
  STACKTOP = sp;return 1;
 }
 $286 = Math_fround(-$276);
 $287 = Math_fround(-$279);
 $288 = Math_fround(-$283);
 HEAPF32[$257>>2] = $286;
 HEAPF32[$260>>2] = $287;
 HEAPF32[$264>>2] = $288;
 STACKTOP = sp;return 1;
}
function __ZN24ConvexVsHeightfieldSweepC2ERN5physx2Gu15HeightFieldUtilERKNS1_14ConvexHullDataERKNS0_11PxMeshScaleERKNS0_11PxTransformESC_RKNS0_6PxVec3EfNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEEfbb($this,$hfUtil,$hull,$convexScale,$convexTrans,$hightFieldTrans,$unitDir,$distance,$hintFlags,$inflation,$aAnyHit,$isDoubleSided) {
 $this = $this|0;
 $hfUtil = $hfUtil|0;
 $hull = $hull|0;
 $convexScale = $convexScale|0;
 $convexTrans = $convexTrans|0;
 $hightFieldTrans = $hightFieldTrans|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $hintFlags = $hintFlags|0;
 $inflation = Math_fround($inflation);
 $aAnyHit = $aAnyHit|0;
 $isDoubleSided = $isDoubleSided|0;
 var $$$i$i$i = Math_fround(0), $$$i12$i$i = Math_fround(0), $$$i23$i$i = Math_fround(0), $$$i26$i$i = Math_fround(0), $$sroa$1$i$i1 = 0, $$sroa$3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0);
 var $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0;
 var $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $35 = Math_fround(0);
 var $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $dist$sroa$1 = 0, $vQuat = 0, $vScale = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 64|0;
 $$sroa$1$i$i1 = sp + 112|0;
 $$sroa$3$i$i = sp + 80|0;
 $1 = sp + 32|0;
 $dist$sroa$1 = sp + 96|0;
 $vScale = sp + 16|0;
 $vQuat = sp + 48|0;
 $2 = sp;
 HEAP32[$this>>2] = ((553984 + 8|0));
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = $hfUtil;
 $4 = (($this) + 64|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$sroa$1$i$i1+0>>2]=0|0;HEAP32[$$sroa$1$i$i1+4>>2]=0|0;HEAP32[$$sroa$1$i$i1+8>>2]=0|0;HEAP32[$$sroa$1$i$i1+12>>2]=0|0;
 ;HEAP32[$$sroa$3$i$i+0>>2]=0|0;HEAP32[$$sroa$3$i$i+4>>2]=0|0;HEAP32[$$sroa$3$i$i+8>>2]=0|0;HEAP32[$$sroa$3$i$i+12>>2]=0|0;
 $5 = (($this) + 16|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 20|0);
 ;HEAP32[$6+0>>2]=HEAP32[$$sroa$1$i$i1+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$$sroa$1$i$i1+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$$sroa$1$i$i1+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$$sroa$1$i$i1+12>>2]|0;
 $7 = (($this) + 36|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($this) + 40|0);
 ;HEAP32[$8+0>>2]=HEAP32[$$sroa$3$i$i+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$$sroa$3$i$i+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$$sroa$3$i$i+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$$sroa$3$i$i+12>>2]|0;
 $9 = (($this) + 56|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 60|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 $11 = (($this) + 80|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 84|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 88|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($this) + 92|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($this) + 96|0);
 ;HEAP32[$15+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$1+12>>2]|0;
 $16 = (($this) + 112|0);
 $17 = (($this) + 176|0);
 $18 = (($this) + 192|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 128|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($this) + 132|0);
 ;HEAP32[$20+0>>2]=HEAP32[$$sroa$1$i$i1+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$$sroa$1$i$i1+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$$sroa$1$i$i1+8>>2]|0;
 $21 = (($this) + 144|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($this) + 148|0);
 ;HEAP32[$22+0>>2]=HEAP32[$$sroa$1$i$i1+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$$sroa$1$i$i1+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$$sroa$1$i$i1+8>>2]|0;
 $23 = (($this) + 160|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($this) + 164|0);
 ;HEAP32[$24+0>>2]=HEAP32[$$sroa$1$i$i1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$$sroa$1$i$i1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$$sroa$1$i$i1+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$17+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$0+12>>2]|0;
 $25 = (($this) + 320|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 324|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 328|0);
 $28 = (($this) + 332|0);
 HEAP16[$28>>1] = 0;
 $29 = (($this) + 336|0);
 $30 = (($this) + 360|0);
 ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;HEAP32[$29+16>>2]=0|0;HEAP32[$29+20>>2]=0|0;
 HEAPF32[$30>>2] = Math_fround(3.40282346638528859812E+38);
 $31 = (($this) + 400|0);
 $32 = Math_fround(HEAPF32[$unitDir>>2]);
 HEAPF32[$31>>2] = $32;
 $33 = (($this) + 404|0);
 $34 = (($unitDir) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 HEAPF32[$33>>2] = $35;
 $36 = (($this) + 408|0);
 $37 = (($unitDir) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 HEAPF32[$36>>2] = $38;
 $39 = (($this) + 424|0);
 HEAPF32[$39>>2] = $inflation;
 $40 = (($this) + 428|0);
 $41 = HEAP16[$hintFlags>>1]|0;
 $42 = $41&65535;
 HEAP32[$40>>2] = $42;
 $43 = (($this) + 432|0);
 $44 = $aAnyHit&1;
 HEAP8[$43>>0] = $44;
 $45 = (($this) + 433|0);
 $46 = $isDoubleSided&1;
 HEAP8[$45>>0] = $46;
 $47 = (($this) + 434|0);
 HEAP8[$47>>0] = 0;
 $48 = (($this) + 435|0);
 HEAP8[$48>>0] = 0;
 HEAP32[$27>>2] = -1;
 HEAPF32[$30>>2] = $distance;
 $49 = Math_fround(HEAPF32[$unitDir>>2]);
 $50 = Math_fround(HEAPF32[$34>>2]);
 $51 = Math_fround(HEAPF32[$37>>2]);
 $52 = Math_fround(HEAPF32[$hightFieldTrans>>2]);
 $53 = (($hightFieldTrans) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($hightFieldTrans) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($hightFieldTrans) + 12|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($hightFieldTrans) + 16|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($59) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($59) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround(HEAPF32[$convexTrans>>2]);
 $66 = (($convexTrans) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($convexTrans) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($convexTrans) + 12|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($convexTrans) + 16|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($72) + 4|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($72) + 8|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround(-$65);
 $79 = Math_fround(-$67);
 $80 = Math_fround(-$69);
 $81 = Math_fround($60 - $73);
 $82 = Math_fround($62 - $75);
 $83 = Math_fround($64 - $77);
 $84 = Math_fround($71 * $71);
 $85 = Math_fround($84 + Math_fround(-0.5));
 $86 = Math_fround($85 * $81);
 $87 = Math_fround($85 * $82);
 $88 = Math_fround($85 * $83);
 $89 = Math_fround($83 * $79);
 $90 = Math_fround($82 * $80);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($81 * $80);
 $93 = Math_fround($83 * $78);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($82 * $78);
 $96 = Math_fround($81 * $79);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($71 * $91);
 $99 = Math_fround($71 * $94);
 $100 = Math_fround($71 * $97);
 $101 = Math_fround($86 + $98);
 $102 = Math_fround($87 + $99);
 $103 = Math_fround($88 + $100);
 $104 = Math_fround($81 * $78);
 $105 = Math_fround($82 * $79);
 $106 = Math_fround($104 + $105);
 $107 = Math_fround($83 * $80);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($108 * $78);
 $110 = Math_fround($108 * $79);
 $111 = Math_fround($108 * $80);
 $112 = Math_fround($109 + $101);
 $113 = Math_fround($110 + $102);
 $114 = Math_fround($103 + $111);
 $115 = Math_fround($112 * Math_fround(2.0));
 $116 = Math_fround($113 * Math_fround(2.0));
 $117 = Math_fround($114 * Math_fround(2.0));
 $118 = Math_fround($58 * $71);
 $119 = Math_fround($52 * $78);
 $120 = Math_fround($54 * $79);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($56 * $80);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($118 - $123);
 $125 = Math_fround($58 * $78);
 $126 = Math_fround($58 * $79);
 $127 = Math_fround($58 * $80);
 $128 = Math_fround($52 * $71);
 $129 = Math_fround($54 * $71);
 $130 = Math_fround($56 * $71);
 $131 = Math_fround($56 * $79);
 $132 = Math_fround($54 * $80);
 $133 = Math_fround($131 - $132);
 $134 = Math_fround($52 * $80);
 $135 = Math_fround($56 * $78);
 $136 = Math_fround($134 - $135);
 $137 = Math_fround($54 * $78);
 $138 = Math_fround($52 * $79);
 $139 = Math_fround($137 - $138);
 $140 = Math_fround($125 + $128);
 $141 = Math_fround($126 + $129);
 $142 = Math_fround($130 + $127);
 $143 = Math_fround($133 + $140);
 $144 = Math_fround($136 + $141);
 $145 = Math_fround($139 + $142);
 $146 = Math_fround($143 + $143);
 $147 = Math_fround($144 + $144);
 $148 = Math_fround($145 + $145);
 $149 = Math_fround($143 * $146);
 $150 = Math_fround($144 * $147);
 $151 = Math_fround($145 * $148);
 $152 = Math_fround($144 * $146);
 $153 = Math_fround($145 * $146);
 $154 = Math_fround($124 * $146);
 $155 = Math_fround($145 * $147);
 $156 = Math_fround($124 * $147);
 $157 = Math_fround($124 * $148);
 $158 = Math_fround(Math_fround(1.0) - $149);
 $159 = Math_fround(Math_fround(1.0) - $150);
 $160 = Math_fround($159 - $151);
 $161 = Math_fround($152 + $157);
 $162 = Math_fround($153 - $156);
 $163 = Math_fround($152 - $157);
 $164 = Math_fround($158 - $151);
 $165 = Math_fround($155 + $154);
 $166 = Math_fround($153 + $156);
 $167 = Math_fround($155 - $154);
 $168 = Math_fround($158 - $150);
 HEAPF32[$5>>2] = $160;
 HEAPF32[$6>>2] = $161;
 $169 = (($this) + 24|0);
 HEAPF32[$169>>2] = $162;
 $170 = (($this) + 28|0);
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = (($this) + 32|0);
 HEAPF32[$171>>2] = $163;
 HEAPF32[$7>>2] = $164;
 HEAPF32[$8>>2] = $165;
 $172 = (($this) + 44|0);
 HEAPF32[$172>>2] = Math_fround(0.0);
 $173 = (($this) + 48|0);
 HEAPF32[$173>>2] = $166;
 $174 = (($this) + 52|0);
 HEAPF32[$174>>2] = $167;
 HEAPF32[$9>>2] = $168;
 HEAPF32[$10>>2] = Math_fround(0.0);
 $175 = (($this) + 64|0);
 HEAPF32[$175>>2] = $115;
 $176 = (($this) + 68|0);
 HEAPF32[$176>>2] = $116;
 $177 = (($this) + 72|0);
 HEAPF32[$177>>2] = $117;
 $178 = (($this) + 76|0);
 HEAPF32[$178>>2] = Math_fround(0.0);
 HEAPF32[$11>>2] = $65;
 HEAPF32[$12>>2] = $67;
 HEAPF32[$13>>2] = $69;
 HEAPF32[$14>>2] = $71;
 $179 = (($this) + 96|0);
 HEAPF32[$179>>2] = $73;
 $180 = (($this) + 100|0);
 HEAPF32[$180>>2] = $75;
 $181 = (($this) + 104|0);
 HEAPF32[$181>>2] = $77;
 $182 = (($this) + 108|0);
 HEAPF32[$182>>2] = Math_fround(0.0);
 $183 = Math_fround($49 * $distance);
 $184 = Math_fround($50 * $distance);
 $185 = Math_fround($51 * $distance);
 $186 = Math_fround(-$183);
 $187 = Math_fround(-$184);
 $188 = Math_fround(-$185);
 $189 = Math_fround($85 * $186);
 $190 = Math_fround($85 * $187);
 $191 = Math_fround($85 * $188);
 $192 = Math_fround($67 * $188);
 $193 = Math_fround($69 * $187);
 $194 = Math_fround($192 - $193);
 $195 = Math_fround($69 * $186);
 $196 = Math_fround($65 * $188);
 $197 = Math_fround($195 - $196);
 $198 = Math_fround($65 * $187);
 $199 = Math_fround($67 * $186);
 $200 = Math_fround($198 - $199);
 $201 = Math_fround($71 * $194);
 $202 = Math_fround($71 * $197);
 $203 = Math_fround($71 * $200);
 $204 = Math_fround($189 - $201);
 $205 = Math_fround($190 - $202);
 $206 = Math_fround($191 - $203);
 $207 = Math_fround($65 * $186);
 $208 = Math_fround($67 * $187);
 $209 = Math_fround($207 + $208);
 $210 = Math_fround($69 * $188);
 $211 = Math_fround($209 + $210);
 $212 = Math_fround($65 * $211);
 $213 = Math_fround($67 * $211);
 $214 = Math_fround($69 * $211);
 $215 = Math_fround($212 + $204);
 $216 = Math_fround($213 + $205);
 $217 = Math_fround($214 + $206);
 $218 = Math_fround($215 * Math_fround(2.0));
 $219 = Math_fround($216 * Math_fround(2.0));
 $220 = Math_fround($217 * Math_fround(2.0));
 $221 = (($this) + 368|0);
 HEAPF32[$221>>2] = $218;
 $222 = (($this) + 372|0);
 HEAPF32[$222>>2] = $219;
 $223 = (($this) + 376|0);
 HEAPF32[$223>>2] = $220;
 $224 = (($this) + 380|0);
 HEAPF32[$224>>2] = Math_fround(0.0);
 $225 = (($this) + 384|0);
 HEAPF32[$225>>2] = $distance;
 $226 = (($this) + 388|0);
 ;HEAP32[$226+0>>2]=HEAP32[$dist$sroa$1+0>>2]|0;HEAP32[$226+4>>2]=HEAP32[$dist$sroa$1+4>>2]|0;HEAP32[$226+8>>2]=HEAP32[$dist$sroa$1+8>>2]|0;
 $227 = Math_fround(HEAPF32[$convexScale>>2]);
 $228 = (($convexScale) + 4|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = (($convexScale) + 8|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 HEAPF32[$vScale>>2] = $227;
 $232 = (($vScale) + 4|0);
 HEAPF32[$232>>2] = $229;
 $233 = (($vScale) + 8|0);
 HEAPF32[$233>>2] = $231;
 $234 = (($vScale) + 12|0);
 HEAPF32[$234>>2] = Math_fround(0.0);
 $235 = (($convexScale) + 12|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = (($235) + 4|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = (($235) + 8|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 $241 = (($235) + 12|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 HEAPF32[$vQuat>>2] = $236;
 $243 = (($vQuat) + 4|0);
 HEAPF32[$243>>2] = $238;
 $244 = (($vQuat) + 8|0);
 HEAPF32[$244>>2] = $240;
 $245 = (($vQuat) + 12|0);
 HEAPF32[$245>>2] = $242;
 $246 = Math_fround(HEAPF32[$unitDir>>2]);
 $247 = Math_fround($246 * Math_fround(2.0));
 $248 = Math_fround(HEAPF32[$34>>2]);
 $249 = Math_fround($248 * Math_fround(2.0));
 $250 = Math_fround(HEAPF32[$37>>2]);
 $251 = Math_fround($250 * Math_fround(2.0));
 $252 = (($hightFieldTrans) + 12|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = Math_fround($253 * $253);
 $255 = Math_fround($254 + Math_fround(-0.5));
 $256 = Math_fround(HEAPF32[$hightFieldTrans>>2]);
 $257 = Math_fround($247 * $256);
 $258 = (($hightFieldTrans) + 4|0);
 $259 = Math_fround(HEAPF32[$258>>2]);
 $260 = Math_fround($249 * $259);
 $261 = Math_fround($257 + $260);
 $262 = (($hightFieldTrans) + 8|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 $264 = Math_fround($251 * $263);
 $265 = Math_fround($261 + $264);
 $266 = Math_fround($247 * $255);
 $267 = Math_fround($251 * $259);
 $268 = Math_fround($249 * $263);
 $269 = Math_fround($267 - $268);
 $270 = Math_fround($253 * $269);
 $271 = Math_fround($266 - $270);
 $272 = Math_fround($256 * $265);
 $273 = Math_fround($272 + $271);
 $274 = Math_fround($249 * $255);
 $275 = Math_fround($247 * $263);
 $276 = Math_fround($251 * $256);
 $277 = Math_fround($275 - $276);
 $278 = Math_fround($253 * $277);
 $279 = Math_fround($274 - $278);
 $280 = Math_fround($259 * $265);
 $281 = Math_fround($280 + $279);
 $282 = Math_fround($251 * $255);
 $283 = Math_fround($249 * $256);
 $284 = Math_fround($247 * $259);
 $285 = Math_fround($283 - $284);
 $286 = Math_fround($253 * $285);
 $287 = Math_fround($282 - $286);
 $288 = Math_fround($263 * $265);
 $289 = Math_fround($287 + $288);
 $290 = (($this) + 412|0);
 HEAPF32[$290>>2] = $273;
 $291 = (($this) + 416|0);
 HEAPF32[$291>>2] = $281;
 $292 = (($this) + 420|0);
 HEAPF32[$292>>2] = $289;
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 $293 = (($hull) + 40|0);
 $294 = HEAP32[$293>>2]|0;
 $295 = (($hull) + 39|0);
 $296 = HEAP8[$295>>0]|0;
 $297 = $296&255;
 $298 = (($294) + (($297*20)|0)|0);
 $299 = (($hull) + 52|0);
 $300 = Math_fround(HEAPF32[$299>>2]);
 $301 = (($hull) + 56|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = (($hull) + 60|0);
 $304 = Math_fround(HEAPF32[$303>>2]);
 $305 = Math_fround($300 * $227);
 $306 = Math_fround($302 * $229);
 $307 = Math_fround($304 * $231);
 $308 = !($305 <= $306);
 $$$i26$i$i = $308 ? $306 : $305;
 $309 = !($$$i26$i$i <= $307);
 $310 = $309 ? $307 : $$$i26$i$i;
 $311 = !($305 >= $306);
 $$$i23$i$i = $311 ? $306 : $305;
 $312 = !($$$i23$i$i >= $307);
 $313 = $312 ? $307 : $$$i23$i$i;
 $314 = Math_fround($310 * Math_fround(0.20000000298023223877));
 $315 = Math_fround($313 * Math_fround(0.0500000007450580596924));
 $316 = $314 > $315;
 $$$i12$i$i = $316 ? $314 : $315;
 $317 = $310 > $$$i12$i$i;
 $$$i$i$i = $317 ? $$$i12$i$i : $310;
 HEAPF32[$19>>2] = $$$i$i$i;
 ;HEAP32[$20+0>>2]=HEAP32[$$sroa$1$i$i1+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$$sroa$1$i$i1+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$$sroa$1$i$i1+8>>2]|0;
 $318 = Math_fround($310 * Math_fround(0.100000001490116119385));
 HEAPF32[$21>>2] = $318;
 ;HEAP32[$22+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$0+8>>2]|0;
 $319 = (($this) + 208|0);
 $320 = (($this) + 256|0);
 __ZN5physx2Gu19ConstructSkewMatrixERKNS_6shdfnd3aos5Vec3VERKNS2_5Vec4VERNS2_6Mat33VESA_($vScale,$vQuat,$319,$320);
 $321 = (($this) + 312|0);
 HEAP32[$321>>2] = $298;
 $322 = (($hull) + 38|0);
 $323 = HEAP8[$322>>0]|0;
 $324 = (($this) + 316|0);
 HEAP8[$324>>0] = $323;
 ;HEAP32[$16+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$2+12>>2]|0;
 $325 = (($hull) + 44|0);
 $326 = HEAP32[$325>>2]|0;
 $327 = (($this) + 308|0);
 HEAP32[$327>>2] = $326;
 $328 = (($this) + 304|0);
 HEAP32[$328>>2] = $hull;
 $329 = HEAP32[$325>>2]|0;
 $330 = ($329|0)==(0|0);
 if ($330) {
  STACKTOP = sp;return;
 }
 $331 = (($329) + 16|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = HEAP32[$328>>2]|0;
 $334 = (($333) + 44|0);
 $335 = HEAP32[$334>>2]|0;
 $336 = (($335) + 16|0);
 $337 = HEAP32[$336>>2]|0;
 $338 = (($337) + 128|0);
 $339 = HEAP32[$328>>2]|0;
 $340 = (($339) + 44|0);
 $341 = HEAP32[$340>>2]|0;
 $342 = (($341) + 20|0);
 $343 = HEAP32[$342>>2]|0;
 STACKTOP = sp;return;
}
function __ZN24ConvexVsHeightfieldSweepD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN24ConvexVsHeightfieldSweep7onEventEjPj($this,$nbEntities,$entities) {
 $this = $this|0;
 $nbEntities = $nbEntities|0;
 $entities = $entities|0;
 var $$2 = 0, $$idx$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $$idx3 = 0, $$idx3$val = Math_fround(0), $$idx4 = 0, $$idx4$val = Math_fround(0), $$idx5 = 0, $$idx5$val = Math_fround(0), $$idx6 = 0, $$idx6$val = Math_fround(0), $$idx7 = 0, $$idx7$val = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0), $$idx9 = 0, $$idx9$val = Math_fround(0), $$sroa$1$i$i$i = 0, $$sroa$113$i$i$i = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $closestA$i = 0, $i$012 = 0, $idt = 0, $normal$i = 0, $or$cond = 0;
 var $phitmp = 0, $toi$i = 0, $tri = 0, $triangleV$i = 0, $zero$i = 0, $zero$sroa$1$i$i$i$i = 0, $zeroV$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $zero$sroa$1$i$i$i$i = sp + 328|0;
 $0 = sp + 80|0;
 $$sroa$113$i$i$i = sp + 316|0;
 $$sroa$1$i$i$i = sp + 304|0;
 $zeroV$i = sp + 48|0;
 $zero$i = sp + 16|0;
 $triangleV$i = sp + 96|0;
 $toi$i = sp;
 $closestA$i = sp + 32|0;
 $normal$i = sp + 64|0;
 $idt = sp + 276|0;
 $tri = sp + 240|0;
 HEAPF32[$idt>>2] = Math_fround(0.0);
 $1 = (($idt) + 4|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($idt) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($idt) + 12|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($idt) + 16|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($idt) + 20|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($idt) + 24|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = ($nbEntities|0)==(0);
 if ($7) {
  $$2 = 1;
  STACKTOP = sp;return ($$2|0);
 }
 $8 = (($this) + 4|0);
 $9 = (($this) + 112|0);
 $10 = (($this) + 368|0);
 $11 = (($this) + 360|0);
 $12 = (($this) + 433|0);
 $13 = (($this) + 424|0);
 $14 = (($this) + 434|0);
 $$idx2 = (($tri) + 4|0);
 $$idx3 = (($tri) + 8|0);
 $$idx4 = (($tri) + 12|0);
 $$idx5 = (($tri) + 16|0);
 $$idx6 = (($tri) + 20|0);
 $$idx7 = (($tri) + 24|0);
 $$idx8 = (($tri) + 28|0);
 $$idx9 = (($tri) + 32|0);
 $15 = (($this) + 412|0);
 $16 = (($this) + 416|0);
 $17 = (($this) + 420|0);
 $18 = (($this) + 64|0);
 $19 = (($this) + 68|0);
 $20 = (($this) + 72|0);
 $21 = (($this) + 16|0);
 $22 = (($this) + 32|0);
 $23 = (($this) + 48|0);
 $24 = (($this) + 20|0);
 $25 = (($this) + 36|0);
 $26 = (($this) + 52|0);
 $27 = (($this) + 24|0);
 $28 = (($this) + 40|0);
 $29 = (($this) + 56|0);
 $30 = (($triangleV$i) + 64|0);
 $31 = (($triangleV$i) + 80|0);
 $32 = (($triangleV$i) + 16|0);
 $33 = (($triangleV$i) + 20|0);
 $34 = (($triangleV$i) + 32|0);
 $35 = (($triangleV$i) + 36|0);
 $36 = (($triangleV$i) + 48|0);
 $37 = (($triangleV$i) + 52|0);
 $38 = (($triangleV$i) + 4|0);
 $39 = (($triangleV$i) + 8|0);
 $40 = (($triangleV$i) + 12|0);
 $41 = (($triangleV$i) + 96|0);
 $42 = (($triangleV$i) + 100|0);
 $43 = (($triangleV$i) + 104|0);
 $44 = (($triangleV$i) + 108|0);
 $45 = (($triangleV$i) + 112|0);
 $46 = (($triangleV$i) + 116|0);
 $47 = (($triangleV$i) + 120|0);
 $48 = (($triangleV$i) + 124|0);
 $49 = (($triangleV$i) + 128|0);
 $50 = (($triangleV$i) + 132|0);
 $51 = (($triangleV$i) + 136|0);
 $52 = (($triangleV$i) + 140|0);
 $53 = (($this) + 80|0);
 $54 = (($this) + 84|0);
 $55 = (($this) + 88|0);
 $56 = (($this) + 92|0);
 $57 = (($this) + 96|0);
 $58 = (($this) + 100|0);
 $59 = (($this) + 104|0);
 $60 = (($closestA$i) + 4|0);
 $61 = (($closestA$i) + 8|0);
 $62 = (($normal$i) + 4|0);
 $63 = (($normal$i) + 8|0);
 $64 = (($this) + 384|0);
 $65 = (($this) + 332|0);
 $66 = (($this) + 336|0);
 $67 = (($this) + 340|0);
 $68 = (($this) + 344|0);
 $69 = (($this) + 348|0);
 $70 = (($this) + 352|0);
 $71 = (($this) + 356|0);
 $72 = (($this) + 435|0);
 $73 = (($this) + 328|0);
 $74 = (($this) + 432|0);
 $75 = (($this) + 400|0);
 $76 = (($this) + 404|0);
 $77 = (($this) + 408|0);
 $i$012 = 0;
 L4: while(1) {
  $78 = HEAP32[$8>>2]|0;
  $79 = (($entities) + ($i$012<<2)|0);
  $80 = HEAP32[$79>>2]|0;
  (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($78,$idt,$tri,0,0,$80,0,0)|0);
  $81 = Math_fround(HEAPF32[$11>>2]);
  $82 = HEAP8[$12>>0]|0;
  $83 = ($82<<24>>24)==(0);
  $84 = Math_fround(HEAPF32[$13>>2]);
  $$idx$val = Math_fround(HEAPF32[$tri>>2]);
  $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
  $$idx3$val = Math_fround(HEAPF32[$$idx3>>2]);
  $$idx4$val = Math_fround(HEAPF32[$$idx4>>2]);
  $$idx5$val = Math_fround(HEAPF32[$$idx5>>2]);
  $$idx6$val = Math_fround(HEAPF32[$$idx6>>2]);
  $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
  $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
  $$idx9$val = Math_fround(HEAPF32[$$idx9>>2]);
  $85 = Math_fround($$idx4$val - $$idx$val);
  $86 = Math_fround($$idx5$val - $$idx2$val);
  $87 = Math_fround($$idx6$val - $$idx3$val);
  $88 = Math_fround($$idx7$val - $$idx4$val);
  $89 = Math_fround($$idx8$val - $$idx5$val);
  $90 = Math_fround($$idx9$val - $$idx6$val);
  if ($83) {
   $91 = Math_fround($86 * $88);
   $92 = Math_fround($85 * $89);
   $93 = Math_fround($85 * $90);
   $94 = Math_fround($87 * $88);
   $95 = Math_fround($87 * $89);
   $96 = Math_fround($86 * $90);
   $97 = Math_fround($92 - $91);
   $98 = Math_fround($94 - $93);
   $99 = Math_fround($96 - $95);
   $100 = Math_fround(HEAPF32[$15>>2]);
   $101 = Math_fround($99 * $100);
   $102 = Math_fround(HEAPF32[$16>>2]);
   $103 = Math_fround($98 * $102);
   $104 = Math_fround($101 + $103);
   $105 = Math_fround(HEAPF32[$17>>2]);
   $106 = Math_fround($97 * $105);
   $107 = Math_fround($104 + $106);
   $108 = !($107 <= Math_fround(0.0));
   if ($108) {
    label = 5;
   }
  } else {
   label = 5;
  }
  do {
   if ((label|0) == 5) {
    label = 0;
    ;HEAP32[$zeroV$i+0>>2]=0|0;HEAP32[$zeroV$i+4>>2]=0|0;HEAP32[$zeroV$i+8>>2]=0|0;HEAP32[$zeroV$i+12>>2]=0|0;
    HEAPF32[$zero$i>>2] = Math_fround(0.0);
    $109 = Math_fround(HEAPF32[$18>>2]);
    $110 = Math_fround(HEAPF32[$19>>2]);
    $111 = Math_fround(HEAPF32[$20>>2]);
    $112 = Math_fround(HEAPF32[$21>>2]);
    $113 = Math_fround($$idx$val * $112);
    $114 = Math_fround(HEAPF32[$22>>2]);
    $115 = Math_fround($$idx2$val * $114);
    $116 = Math_fround($113 + $115);
    $117 = Math_fround(HEAPF32[$23>>2]);
    $118 = Math_fround($$idx3$val * $117);
    $119 = Math_fround($116 + $118);
    $120 = Math_fround(HEAPF32[$24>>2]);
    $121 = Math_fround($$idx$val * $120);
    $122 = Math_fround(HEAPF32[$25>>2]);
    $123 = Math_fround($$idx2$val * $122);
    $124 = Math_fround($121 + $123);
    $125 = Math_fround(HEAPF32[$26>>2]);
    $126 = Math_fround($$idx3$val * $125);
    $127 = Math_fround($124 + $126);
    $128 = Math_fround(HEAPF32[$27>>2]);
    $129 = Math_fround($$idx$val * $128);
    $130 = Math_fround(HEAPF32[$28>>2]);
    $131 = Math_fround($$idx2$val * $130);
    $132 = Math_fround($129 + $131);
    $133 = Math_fround(HEAPF32[$29>>2]);
    $134 = Math_fround($$idx3$val * $133);
    $135 = Math_fround($132 + $134);
    $136 = Math_fround($109 + $119);
    $137 = Math_fround($110 + $127);
    $138 = Math_fround($111 + $135);
    $139 = Math_fround($$idx4$val * $112);
    $140 = Math_fround($$idx5$val * $114);
    $141 = Math_fround($139 + $140);
    $142 = Math_fround($$idx6$val * $117);
    $143 = Math_fround($141 + $142);
    $144 = Math_fround($$idx4$val * $120);
    $145 = Math_fround($$idx5$val * $122);
    $146 = Math_fround($144 + $145);
    $147 = Math_fround($$idx6$val * $125);
    $148 = Math_fround($146 + $147);
    $149 = Math_fround($$idx4$val * $128);
    $150 = Math_fround($$idx5$val * $130);
    $151 = Math_fround($149 + $150);
    $152 = Math_fround($$idx6$val * $133);
    $153 = Math_fround($151 + $152);
    $154 = Math_fround($109 + $143);
    $155 = Math_fround($110 + $148);
    $156 = Math_fround($111 + $153);
    $157 = Math_fround($$idx7$val * $112);
    $158 = Math_fround($$idx8$val * $114);
    $159 = Math_fround($157 + $158);
    $160 = Math_fround($$idx9$val * $117);
    $161 = Math_fround($159 + $160);
    $162 = Math_fround($$idx7$val * $120);
    $163 = Math_fround($$idx8$val * $122);
    $164 = Math_fround($162 + $163);
    $165 = Math_fround($$idx9$val * $125);
    $166 = Math_fround($164 + $165);
    $167 = Math_fround($$idx7$val * $128);
    $168 = Math_fround($$idx8$val * $130);
    $169 = Math_fround($167 + $168);
    $170 = Math_fround($$idx9$val * $133);
    $171 = Math_fround($169 + $170);
    $172 = Math_fround($109 + $161);
    $173 = Math_fround($110 + $166);
    $174 = Math_fround($111 + $171);
    HEAP32[$31>>2] = 7;
    HEAPF32[$36>>2] = Math_fround(0.0);
    ;HEAP32[$37+0>>2]=HEAP32[$zero$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$zero$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$zero$sroa$1$i$i$i$i+8>>2]|0;
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    ;HEAP32[$30+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$0+12>>2]|0;
    $175 = Math_fround($136 + $154);
    $176 = Math_fround($137 + $155);
    $177 = Math_fround($138 + $156);
    $178 = Math_fround($172 + $175);
    $179 = Math_fround($173 + $176);
    $180 = Math_fround($174 + $177);
    $181 = Math_fround($178 * Math_fround(0.333332985639572143555));
    $182 = Math_fround($179 * Math_fround(0.333332985639572143555));
    $183 = Math_fround($180 * Math_fround(0.333332985639572143555));
    HEAPF32[$triangleV$i>>2] = $181;
    HEAPF32[$38>>2] = $182;
    HEAPF32[$39>>2] = $183;
    HEAPF32[$40>>2] = Math_fround(0.0);
    HEAPF32[$41>>2] = $136;
    HEAPF32[$42>>2] = $137;
    HEAPF32[$43>>2] = $138;
    HEAPF32[$44>>2] = Math_fround(0.0);
    HEAPF32[$45>>2] = $154;
    HEAPF32[$46>>2] = $155;
    HEAPF32[$47>>2] = $156;
    HEAPF32[$48>>2] = Math_fround(0.0);
    HEAPF32[$49>>2] = $172;
    HEAPF32[$50>>2] = $173;
    HEAPF32[$51>>2] = $174;
    HEAPF32[$52>>2] = Math_fround(0.0);
    HEAPF32[$32>>2] = Math_fround(0.0);
    ;HEAP32[$33+0>>2]=HEAP32[$$sroa$113$i$i$i+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$$sroa$113$i$i$i+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$$sroa$113$i$i$i+8>>2]|0;
    HEAPF32[$34>>2] = Math_fround(3.40282346638528859812E+38);
    ;HEAP32[$35+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
    $184 = (__ZN5physx2Gu15GJKLocalRayCastERNS0_9TriangleVERNS0_11ConvexHullVERKNS_6shdfnd3aos6FloatVERKNS6_5Vec3VESC_RS7_RSA_SE_fb($triangleV$i,$9,$zero$i,$zeroV$i,$10,$toi$i,$normal$i,$closestA$i,$84,0)|0);
    if ($184) {
     $185 = Math_fround(HEAPF32[$53>>2]);
     $186 = Math_fround(HEAPF32[$54>>2]);
     $187 = Math_fround(HEAPF32[$55>>2]);
     $188 = Math_fround(HEAPF32[$56>>2]);
     $189 = Math_fround(HEAPF32[$57>>2]);
     $190 = Math_fround(HEAPF32[$58>>2]);
     $191 = Math_fround(HEAPF32[$59>>2]);
     $192 = Math_fround(HEAPF32[$closestA$i>>2]);
     $193 = Math_fround(HEAPF32[$60>>2]);
     $194 = Math_fround(HEAPF32[$61>>2]);
     $195 = Math_fround($188 * $188);
     $196 = Math_fround($195 + Math_fround(-0.5));
     $197 = Math_fround($196 * $192);
     $198 = Math_fround($196 * $193);
     $199 = Math_fround($196 * $194);
     $200 = Math_fround($186 * $194);
     $201 = Math_fround($187 * $193);
     $202 = Math_fround($200 - $201);
     $203 = Math_fround($187 * $192);
     $204 = Math_fround($185 * $194);
     $205 = Math_fround($203 - $204);
     $206 = Math_fround($185 * $193);
     $207 = Math_fround($186 * $192);
     $208 = Math_fround($206 - $207);
     $209 = Math_fround($188 * $202);
     $210 = Math_fround($188 * $205);
     $211 = Math_fround($188 * $208);
     $212 = Math_fround($197 + $209);
     $213 = Math_fround($198 + $210);
     $214 = Math_fround($199 + $211);
     $215 = Math_fround($185 * $192);
     $216 = Math_fround($186 * $193);
     $217 = Math_fround($215 + $216);
     $218 = Math_fround($187 * $194);
     $219 = Math_fround($217 + $218);
     $220 = Math_fround($185 * $219);
     $221 = Math_fround($186 * $219);
     $222 = Math_fround($187 * $219);
     $223 = Math_fround($220 + $212);
     $224 = Math_fround($221 + $213);
     $225 = Math_fround($214 + $222);
     $226 = Math_fround($223 * Math_fround(2.0));
     $227 = Math_fround($224 * Math_fround(2.0));
     $228 = Math_fround($225 * Math_fround(2.0));
     $229 = Math_fround($189 + $226);
     $230 = Math_fround($190 + $227);
     $231 = Math_fround($191 + $228);
     $232 = Math_fround(HEAPF32[$normal$i>>2]);
     $233 = Math_fround(HEAPF32[$62>>2]);
     $234 = Math_fround(HEAPF32[$63>>2]);
     $235 = Math_fround($196 * $232);
     $236 = Math_fround($196 * $233);
     $237 = Math_fround($196 * $234);
     $238 = Math_fround($186 * $234);
     $239 = Math_fround($187 * $233);
     $240 = Math_fround($238 - $239);
     $241 = Math_fround($187 * $232);
     $242 = Math_fround($185 * $234);
     $243 = Math_fround($241 - $242);
     $244 = Math_fround($185 * $233);
     $245 = Math_fround($186 * $232);
     $246 = Math_fround($244 - $245);
     $247 = Math_fround($188 * $240);
     $248 = Math_fround($188 * $243);
     $249 = Math_fround($188 * $246);
     $250 = Math_fround($235 + $247);
     $251 = Math_fround($236 + $248);
     $252 = Math_fround($237 + $249);
     $253 = Math_fround($185 * $232);
     $254 = Math_fround($186 * $233);
     $255 = Math_fround($253 + $254);
     $256 = Math_fround($187 * $234);
     $257 = Math_fround($255 + $256);
     $258 = Math_fround($185 * $257);
     $259 = Math_fround($186 * $257);
     $260 = Math_fround($187 * $257);
     $261 = Math_fround($258 + $250);
     $262 = Math_fround($259 + $251);
     $263 = Math_fround($252 + $260);
     $264 = Math_fround($261 * Math_fround(2.0));
     $265 = Math_fround($262 * Math_fround(2.0));
     $266 = Math_fround($263 * Math_fround(2.0));
     $267 = Math_fround($264 * $264);
     $268 = Math_fround($265 * $265);
     $269 = Math_fround($267 + $268);
     $270 = Math_fround($266 * $266);
     $271 = Math_fround($270 + $269);
     $272 = (Math_fround(Math_sqrt((Math_fround($271)))));
     $273 = Math_fround(Math_fround(1.0) / $272);
     $274 = Math_fround($273 * $264);
     $275 = Math_fround($273 * $265);
     $276 = Math_fround($273 * $266);
     $277 = Math_fround(HEAPF32[$zero$i>>2]);
     $278 = Math_fround(HEAPF32[$toi$i>>2]);
     $279 = !($277 >= $278);
     if ($279) {
      $286 = Math_fround(HEAPF32[$64>>2]);
      $287 = Math_fround($278 * $286);
      $288 = $287 < $81;
      if (!($288)) {
       break;
      }
      HEAP16[$65>>1] = 7;
      HEAPF32[$66>>2] = $229;
      HEAPF32[$67>>2] = $230;
      HEAPF32[$68>>2] = $231;
      HEAPF32[$69>>2] = $274;
      HEAPF32[$70>>2] = $275;
      HEAPF32[$71>>2] = $276;
      HEAPF32[$11>>2] = $287;
      $phitmp = $287 == Math_fround(0.0);
      $292 = $phitmp;
     } else {
      HEAP16[$65>>1] = 6;
      HEAPF32[$11>>2] = Math_fround(0.0);
      $280 = Math_fround(HEAPF32[$75>>2]);
      $281 = Math_fround(-$280);
      $282 = Math_fround(HEAPF32[$76>>2]);
      $283 = Math_fround(-$282);
      $284 = Math_fround(HEAPF32[$77>>2]);
      $285 = Math_fround(-$284);
      HEAPF32[$69>>2] = $281;
      HEAPF32[$70>>2] = $283;
      HEAPF32[$71>>2] = $285;
      HEAP8[$14>>0] = 1;
      $292 = 1;
     }
     HEAP8[$72>>0] = 1;
     $289 = HEAP32[$79>>2]|0;
     HEAP32[$73>>2] = $289;
     $290 = HEAP8[$74>>0]|0;
     $291 = ($290<<24>>24)!=(0);
     $or$cond = $291 | $292;
     if ($or$cond) {
      $$2 = 0;
      label = 12;
      break L4;
     }
    }
   }
  } while(0);
  $293 = (($i$012) + 1)|0;
  $294 = ($293>>>0)<($nbEntities>>>0);
  if ($294) {
   $i$012 = $293;
  } else {
   $$2 = 1;
   label = 12;
   break;
  }
 }
 if ((label|0) == 12) {
  STACKTOP = sp;return ($$2|0);
 }
 return 0|0;
}
function __ZN25CapsuleTraceSegmentReportD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN25CapsuleTraceSegmentReport7onEventEjPj($this,$nb,$indices) {
 $this = $this|0;
 $nb = $nb|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $faceIndex = 0, $i$01 = 0, $impact = 0;
 var $normal = 0, $t = 0, $tribuf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2352|0;
 $tribuf = sp + 40|0;
 $faceIndex = sp;
 $normal = sp + 4|0;
 $impact = sp + 16|0;
 $t = sp + 28|0;
 $0 = sp + 32|0;
 $1 = ($nb|0)==(0);
 if (!($1)) {
  $2 = (($this) + 32|0);
  $3 = (($this) + 28|0);
  $i$01 = 0;
  while(1) {
   $4 = (($indices) + ($i$01<<2)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = HEAP32[$2>>2]|0;
   $7 = HEAP32[$3>>2]|0;
   $8 = (($tribuf) + (($i$01*36)|0)|0);
   (__ZNK5physx2Gu15HeightFieldUtil11getTriangleERKNS_11PxTransformERNS_10PxTriangleEPjS7_jbb($6,$7,$8,0,0,$5,1,1)|0);
   $9 = (($i$01) + 1)|0;
   $exitcond = ($9|0)==($nb|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $9;
   }
  }
 }
 HEAP32[$faceIndex>>2] = -1;
 HEAPF32[$t>>2] = Math_fround(3.40282346638528859812E+38);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 12|0);
 $19 = (($this) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP16[$20>>1]|0;
 HEAP16[$0>>1] = $21;
 $22 = (($this) + 36|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)!=(0);
 $25 = (__ZN5physx2Gu21sweepCapsuleTrianglesEjPKNS_10PxTriangleERKNS0_7CapsuleERKNS_6PxVec3EfPKjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEERfRS7_SI_RjSF_bPKNS0_3BoxE($nb,$tribuf,$11,$13,$15,0,$18,$t,$normal,$impact,$faceIndex,$0,$24,0)|0);
 if (!($25)) {
  STACKTOP = sp;return 1;
 }
 $26 = Math_fround(HEAPF32[$t>>2]);
 $27 = HEAP32[$16>>2]|0;
 $28 = (($27) + 40|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = !($26 <= $29);
 if ($30) {
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$faceIndex>>2]|0;
 $32 = (($indices) + ($31<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($27) + 8|0);
 HEAP32[$34>>2] = $33;
 $35 = Math_fround(HEAPF32[$normal>>2]);
 $36 = (($27) + 28|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($normal) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($27) + 32|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($normal) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($27) + 36|0);
 HEAPF32[$42>>2] = $41;
 $43 = Math_fround(HEAPF32[$impact>>2]);
 $44 = (($27) + 16|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($impact) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($27) + 20|0);
 HEAPF32[$47>>2] = $46;
 $48 = (($impact) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($27) + 24|0);
 HEAPF32[$50>>2] = $49;
 $51 = Math_fround(HEAPF32[$t>>2]);
 HEAPF32[$28>>2] = $51;
 $52 = (($this) + 24|0);
 HEAP8[$52>>0] = 1;
 $53 = Math_fround(HEAPF32[$t>>2]);
 $54 = $53 == Math_fround(0.0);
 if (!($54)) {
  STACKTOP = sp;return 1;
 }
 $55 = (($this) + 25|0);
 HEAP8[$55>>0] = 1;
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu16pcmContactBoxBoxERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i$i$i$i$i = Math_fround(0), $$$i$i$i$i$i31 = Math_fround(0), $$$i$i$i43 = Math_fround(0), $$$i$i34 = Math_fround(0), $$$i12$i$i$i$i = Math_fround(0), $$$i12$i$i$i$i30 = Math_fround(0), $$$i23$i$i$i$i = Math_fround(0), $$$i23$i$i$i$i29 = Math_fround(0), $$$i26$i$i$i$i = Math_fround(0), $$$i26$i$i$i$i28 = Math_fround(0), $$1$i = 0, $$1$i$i$i = Math_fround(0), $$1$i$i$i$i = Math_fround(0), $$1$i$i423$i = Math_fround(0), $$1$i$i549$i = Math_fround(0), $$1$i$i675$i = Math_fround(0);
 var $$3 = 0, $$ph$i = Math_fround(0), $$ph3610$i = Math_fround(0), $$ph3611$i = Math_fround(0), $$ph3612$i = Math_fround(0), $$ph3613$i = Math_fround(0), $$ph3614$i = Math_fround(0), $$ph3615$i = Math_fround(0), $$ph3616$i = Math_fround(0), $$ph3617$i = Math_fround(0), $$ph3618$i = Math_fround(0), $$ph3619$i = Math_fround(0), $$ph3620$i = Math_fround(0), $$phi$trans$insert153 = 0, $$phi$trans$insert155 = 0, $$phi$trans$insert159 = 0, $$phi$trans$insert161 = 0, $$pre = Math_fround(0), $$pre$phi166Z2D = 0, $$pre$phi168Z2D = 0;
 var $$pre$phi170Z2D = 0, $$pre$phiZ2D = 0, $$pre154 = Math_fround(0), $$pre156 = Math_fround(0), $$pre158 = Math_fround(0), $$pre160 = Math_fround(0), $$pre162 = Math_fround(0), $$pre163 = Math_fround(0), $$pre164 = 0, $$pre165 = 0, $$pre167 = 0, $$pre169 = 0, $$sroa$151 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0);
 var $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = Math_fround(0), $1020 = Math_fround(0);
 var $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = Math_fround(0), $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0);
 var $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = Math_fround(0), $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0;
 var $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0);
 var $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = Math_fround(0), $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0);
 var $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = Math_fround(0);
 var $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0);
 var $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = Math_fround(0), $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0);
 var $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = Math_fround(0), $1160 = Math_fround(0), $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0;
 var $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = Math_fround(0), $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = Math_fround(0), $1180 = Math_fround(0), $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0);
 var $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = Math_fround(0), $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = Math_fround(0), $1190 = Math_fround(0), $1191 = Math_fround(0), $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = Math_fround(0), $1199 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $1200 = Math_fround(0);
 var $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = Math_fround(0), $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = Math_fround(0), $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = Math_fround(0), $1210 = Math_fround(0), $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = Math_fround(0), $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = Math_fround(0), $1217 = Math_fround(0), $1218 = Math_fround(0), $1219 = Math_fround(0);
 var $122 = Math_fround(0), $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = Math_fround(0), $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = Math_fround(0), $1229 = Math_fround(0), $123 = Math_fround(0), $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = Math_fround(0), $1233 = Math_fround(0), $1234 = Math_fround(0), $1235 = Math_fround(0), $1236 = Math_fround(0), $1237 = Math_fround(0);
 var $1238 = Math_fround(0), $1239 = Math_fround(0), $124 = Math_fround(0), $1240 = Math_fround(0), $1241 = Math_fround(0), $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = Math_fround(0), $1245 = Math_fround(0), $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = Math_fround(0), $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0), $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = Math_fround(0);
 var $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = Math_fround(0), $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0), $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0);
 var $1274 = Math_fround(0), $1275 = Math_fround(0), $1276 = Math_fround(0), $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = 0, $1280 = Math_fround(0), $1281 = Math_fround(0), $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0;
 var $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = Math_fround(0), $1298 = Math_fround(0), $1299 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = Math_fround(0), $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0);
 var $131 = Math_fround(0), $1310 = Math_fround(0), $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = Math_fround(0), $1314 = Math_fround(0), $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = Math_fround(0), $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = Math_fround(0), $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0);
 var $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = Math_fround(0), $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = Math_fround(0), $1340 = Math_fround(0), $1341 = Math_fround(0), $1342 = Math_fround(0), $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0);
 var $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = Math_fround(0), $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = Math_fround(0), $136 = Math_fround(0), $1360 = Math_fround(0), $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0);
 var $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = Math_fround(0), $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = Math_fround(0), $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = Math_fround(0), $1379 = Math_fround(0), $138 = Math_fround(0), $1380 = Math_fround(0), $1381 = Math_fround(0);
 var $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = Math_fround(0), $1390 = Math_fround(0), $1391 = Math_fround(0), $1392 = Math_fround(0), $1393 = Math_fround(0), $1394 = Math_fround(0), $1395 = Math_fround(0), $1396 = Math_fround(0), $1397 = Math_fround(0), $1398 = Math_fround(0), $1399 = Math_fround(0), $14 = 0;
 var $140 = Math_fround(0), $1400 = Math_fround(0), $1401 = Math_fround(0), $1402 = Math_fround(0), $1403 = Math_fround(0), $1404 = Math_fround(0), $1405 = Math_fround(0), $1406 = Math_fround(0), $1407 = Math_fround(0), $1408 = Math_fround(0), $1409 = Math_fround(0), $141 = Math_fround(0), $1410 = Math_fround(0), $1411 = Math_fround(0), $1412 = Math_fround(0), $1413 = Math_fround(0), $1414 = Math_fround(0), $1415 = Math_fround(0), $1416 = Math_fround(0), $1417 = Math_fround(0);
 var $1418 = Math_fround(0), $1419 = Math_fround(0), $142 = Math_fround(0), $1420 = Math_fround(0), $1421 = Math_fround(0), $1422 = Math_fround(0), $1423 = Math_fround(0), $1424 = Math_fround(0), $1425 = Math_fround(0), $1426 = Math_fround(0), $1427 = Math_fround(0), $1428 = Math_fround(0), $1429 = Math_fround(0), $143 = Math_fround(0), $1430 = Math_fround(0), $1431 = Math_fround(0), $1432 = Math_fround(0), $1433 = Math_fround(0), $1434 = Math_fround(0), $1435 = Math_fround(0);
 var $1436 = Math_fround(0), $1437 = Math_fround(0), $1438 = Math_fround(0), $1439 = Math_fround(0), $144 = Math_fround(0), $1440 = Math_fround(0), $1441 = Math_fround(0), $1442 = Math_fround(0), $1443 = Math_fround(0), $1444 = Math_fround(0), $1445 = Math_fround(0), $1446 = Math_fround(0), $1447 = Math_fround(0), $1448 = Math_fround(0), $1449 = Math_fround(0), $145 = Math_fround(0), $1450 = Math_fround(0), $1451 = Math_fround(0), $1452 = Math_fround(0), $1453 = Math_fround(0);
 var $1454 = Math_fround(0), $1455 = Math_fround(0), $1456 = Math_fround(0), $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = Math_fround(0), $1460 = Math_fround(0), $1461 = Math_fround(0), $1462 = Math_fround(0), $1463 = Math_fround(0), $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = Math_fround(0), $1467 = Math_fround(0), $1468 = Math_fround(0), $1469 = Math_fround(0), $147 = Math_fround(0), $1470 = Math_fround(0), $1471 = Math_fround(0);
 var $1472 = Math_fround(0), $1473 = Math_fround(0), $1474 = 0, $1475 = Math_fround(0), $1476 = 0, $1477 = Math_fround(0), $1478 = 0, $1479 = Math_fround(0), $148 = Math_fround(0), $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0), $1486 = Math_fround(0), $1487 = Math_fround(0), $1488 = Math_fround(0), $1489 = Math_fround(0), $149 = Math_fround(0);
 var $1490 = Math_fround(0), $1491 = Math_fround(0), $1492 = Math_fround(0), $1493 = Math_fround(0), $1494 = Math_fround(0), $1495 = 0, $1496 = 0, $1497 = 0, $1498 = Math_fround(0), $1499 = 0, $15 = 0, $150 = Math_fround(0), $1500 = Math_fround(0), $1501 = 0, $1502 = Math_fround(0), $1503 = Math_fround(0), $1504 = Math_fround(0), $1505 = Math_fround(0), $1506 = Math_fround(0), $1507 = Math_fround(0);
 var $1508 = Math_fround(0), $1509 = Math_fround(0), $151 = Math_fround(0), $1510 = Math_fround(0), $1511 = Math_fround(0), $1512 = Math_fround(0), $1513 = Math_fround(0), $1514 = Math_fround(0), $1515 = Math_fround(0), $1516 = Math_fround(0), $1517 = Math_fround(0), $1518 = Math_fround(0), $1519 = Math_fround(0), $152 = Math_fround(0), $1520 = Math_fround(0), $1521 = 0, $1522 = 0, $1523 = Math_fround(0), $1524 = 0, $1525 = Math_fround(0);
 var $1526 = 0, $1527 = Math_fround(0), $1528 = Math_fround(0), $1529 = Math_fround(0), $153 = Math_fround(0), $1530 = Math_fround(0), $1531 = Math_fround(0), $1532 = Math_fround(0), $1533 = Math_fround(0), $1534 = Math_fround(0), $1535 = Math_fround(0), $1536 = Math_fround(0), $1537 = Math_fround(0), $1538 = Math_fround(0), $1539 = Math_fround(0), $154 = 0, $1540 = Math_fround(0), $1541 = Math_fround(0), $1542 = Math_fround(0), $1543 = Math_fround(0);
 var $1544 = Math_fround(0), $1545 = Math_fround(0), $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = Math_fround(0), $1558 = 0, $1559 = Math_fround(0), $156 = 0, $1560 = 0, $1561 = Math_fround(0);
 var $1562 = Math_fround(0), $1563 = Math_fround(0), $1564 = Math_fround(0), $1565 = Math_fround(0), $1566 = Math_fround(0), $1567 = Math_fround(0), $1568 = Math_fround(0), $1569 = Math_fround(0), $157 = 0, $1570 = Math_fround(0), $1571 = Math_fround(0), $1572 = Math_fround(0), $1573 = Math_fround(0), $1574 = Math_fround(0), $1575 = Math_fround(0), $1576 = Math_fround(0), $1577 = Math_fround(0), $1578 = Math_fround(0), $1579 = Math_fround(0), $158 = 0;
 var $1580 = Math_fround(0), $1581 = Math_fround(0), $1582 = Math_fround(0), $1583 = Math_fround(0), $1584 = Math_fround(0), $1585 = Math_fround(0), $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = Math_fround(0);
 var $1599 = Math_fround(0), $16 = 0, $160 = 0, $1600 = Math_fround(0), $1601 = 0, $1602 = 0, $1603 = Math_fround(0), $1604 = 0, $1605 = 0, $1606 = Math_fround(0), $1607 = Math_fround(0), $1608 = Math_fround(0), $1609 = 0, $161 = 0, $1610 = 0, $1611 = Math_fround(0), $1612 = Math_fround(0), $1613 = Math_fround(0), $1614 = Math_fround(0), $1615 = Math_fround(0);
 var $1616 = Math_fround(0), $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = Math_fround(0), $1627 = Math_fround(0), $1628 = Math_fround(0), $1629 = 0, $163 = 0, $1630 = 0, $1631 = Math_fround(0), $1632 = 0, $1633 = 0;
 var $1634 = Math_fround(0), $1635 = Math_fround(0), $1636 = Math_fround(0), $1637 = 0, $1638 = 0, $1639 = Math_fround(0), $164 = 0, $1640 = Math_fround(0), $1641 = Math_fround(0), $1642 = Math_fround(0), $1643 = Math_fround(0), $1644 = Math_fround(0), $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = Math_fround(0), $1650 = 0, $1651 = 0;
 var $1652 = Math_fround(0), $1653 = 0, $1654 = Math_fround(0), $1655 = 0, $1656 = Math_fround(0), $1657 = Math_fround(0), $1658 = 0, $1659 = Math_fround(0), $166 = Math_fround(0), $1660 = 0, $1661 = Math_fround(0), $1662 = Math_fround(0), $1663 = Math_fround(0), $1664 = Math_fround(0), $1665 = Math_fround(0), $1666 = Math_fround(0), $1667 = Math_fround(0), $1668 = Math_fround(0), $1669 = Math_fround(0), $167 = Math_fround(0);
 var $1670 = Math_fround(0), $1671 = Math_fround(0), $1672 = Math_fround(0), $1673 = Math_fround(0), $1674 = Math_fround(0), $1675 = 0, $1676 = 0, $1677 = 0, $1678 = Math_fround(0), $1679 = 0, $168 = 0, $1680 = 0, $1681 = Math_fround(0), $1682 = Math_fround(0), $1683 = Math_fround(0), $1684 = Math_fround(0), $1685 = Math_fround(0), $1686 = Math_fround(0), $1687 = Math_fround(0), $1688 = Math_fround(0);
 var $1689 = Math_fround(0), $169 = 0, $1690 = Math_fround(0), $1691 = Math_fround(0), $1692 = Math_fround(0), $1693 = Math_fround(0), $1694 = Math_fround(0), $1695 = Math_fround(0), $1696 = Math_fround(0), $1697 = Math_fround(0), $1698 = Math_fround(0), $1699 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $1700 = Math_fround(0), $1701 = Math_fround(0), $1702 = Math_fround(0), $1703 = Math_fround(0), $1704 = Math_fround(0), $1705 = Math_fround(0);
 var $1706 = Math_fround(0), $1707 = Math_fround(0), $1708 = Math_fround(0), $1709 = Math_fround(0), $171 = Math_fround(0), $1710 = Math_fround(0), $1711 = Math_fround(0), $1712 = Math_fround(0), $1713 = Math_fround(0), $1714 = Math_fround(0), $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = Math_fround(0), $1720 = Math_fround(0), $1721 = 0, $1722 = Math_fround(0), $1723 = 0;
 var $1724 = Math_fround(0), $1725 = 0, $1726 = Math_fround(0), $1727 = 0, $1728 = 0, $1729 = 0, $173 = Math_fround(0), $1730 = Math_fround(0), $1731 = Math_fround(0), $1732 = Math_fround(0), $1733 = Math_fround(0), $1734 = Math_fround(0), $1735 = Math_fround(0), $1736 = Math_fround(0), $1737 = Math_fround(0), $1738 = Math_fround(0), $1739 = Math_fround(0), $174 = Math_fround(0), $1740 = Math_fround(0), $1741 = Math_fround(0);
 var $1742 = Math_fround(0), $1743 = Math_fround(0), $1744 = Math_fround(0), $1745 = Math_fround(0), $1746 = Math_fround(0), $1747 = Math_fround(0), $1748 = Math_fround(0), $1749 = Math_fround(0), $175 = 0, $1750 = Math_fround(0), $1751 = Math_fround(0), $1752 = Math_fround(0), $1753 = Math_fround(0), $1754 = Math_fround(0), $1755 = Math_fround(0), $1756 = Math_fround(0), $1757 = Math_fround(0), $1758 = Math_fround(0), $1759 = Math_fround(0), $176 = 0;
 var $1760 = Math_fround(0), $1761 = Math_fround(0), $1762 = Math_fround(0), $1763 = Math_fround(0), $1764 = Math_fround(0), $1765 = Math_fround(0), $1766 = Math_fround(0), $1767 = Math_fround(0), $1768 = Math_fround(0), $1769 = Math_fround(0), $177 = Math_fround(0), $1770 = Math_fround(0), $1771 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0;
 var $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0;
 var $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0;
 var $40 = 0, $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0);
 var $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0);
 var $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0);
 var $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0);
 var $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = Math_fround(0);
 var $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0);
 var $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = 0, $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0;
 var $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = 0, $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0);
 var $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = 0, $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = 0;
 var $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = 0, $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0;
 var $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = 0, $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = 0, $598 = 0;
 var $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = Math_fround(0), $602 = 0, $603 = Math_fround(0), $604 = 0, $605 = Math_fround(0), $606 = 0, $607 = 0, $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0);
 var $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0);
 var $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0);
 var $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0);
 var $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = Math_fround(0), $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $700 = 0, $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0);
 var $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0, $717 = 0, $718 = 0, $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = Math_fround(0), $740 = Math_fround(0), $741 = Math_fround(0);
 var $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = Math_fround(0);
 var $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0);
 var $779 = Math_fround(0), $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0);
 var $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = Math_fround(0), $82 = Math_fround(0), $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = Math_fround(0), $831 = Math_fround(0);
 var $832 = Math_fround(0), $833 = Math_fround(0), $834 = 0, $835 = 0, $836 = 0, $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0);
 var $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0);
 var $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0);
 var $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0);
 var $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = Math_fround(0), $920 = Math_fround(0), $921 = Math_fround(0);
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = Math_fround(0);
 var $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = Math_fround(0), $950 = Math_fround(0), $951 = Math_fround(0), $952 = 0, $953 = 0, $954 = 0, $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = 0;
 var $959 = 0, $96 = Math_fround(0), $960 = 0, $961 = 0, $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0);
 var $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = Math_fround(0), $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = Math_fround(0), $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0);
 var $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $aToB = 0, $boxExtents0 = 0, $boxExtents1 = 0, $closestA = 0, $closestB = 0, $contactDist = 0, $ea0$i = 0, $ea1$i = 0, $ea2$i = 0, $eb0$i = 0, $eb1$i = 0, $eb2$i = 0, $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i$i236$i = Math_fround(0), $fabsf$i$i$i295$i = Math_fround(0);
 var $fabsf$i$i$i356$i = Math_fround(0), $fabsf$i$i$i419$i = Math_fround(0), $fabsf$i$i$i482$i = Math_fround(0), $fabsf$i$i$i545$i = Math_fround(0), $fabsf$i$i$i608$i = Math_fround(0), $fabsf$i$i$i671$i = Math_fround(0), $fabsf$i$i$i702$i = Math_fround(0), $fabsf$i$i$i743$i = Math_fround(0), $fabsf$i$i$i784$i = Math_fround(0), $fabsf$i$i$i825$i = Math_fround(0), $fabsf$i$i$i862$i = Math_fround(0), $fabsf$i$i$i899$i = Math_fround(0), $feature$1$1$i = 0, $feature$1$2$i = 0, $feature$1$3$i = 0, $feature$1$4$i = 0, $feature$1$i = 0, $i56$03622$i = 0, $i57$03609$i = 0, $incidentFaceNormalInNew$i = 0;
 var $localB$i = 0, $localNormal$i = 0, $localNormal47$i = 0, $localNormal49$i = 0, $localNormal51$i = 0, $localNormal53$i = 0, $localNormal55$i = 0, $localNormalPen = 0, $localPointA = 0, $localPointB = 0, $normal = 0, $numContacts = 0, $penDep = 0, $projectBreakingThreshold = 0, $pts$i = 0, $replaceBreakingThreshold = 0, $status$0 = 0, $transf1 = 0, $transfV1 = 0, $transform1ToNew$i = 0;
 var $worldNormal = 0, $worldNormal2 = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1104|0;
 $ea0$i = sp + 880|0;
 $ea1$i = sp + 528|0;
 $ea2$i = sp + 544|0;
 $eb0$i = sp + 560|0;
 $eb1$i = sp + 720|0;
 $eb2$i = sp + 896|0;
 $incidentFaceNormalInNew$i = sp + 912|0;
 $pts$i = sp + 928|0;
 $transform1ToNew$i = sp + 992|0;
 $localNormal$i = sp + 1056|0;
 $0 = sp + 1072|0;
 $localNormal47$i = sp + 512|0;
 $1 = sp + 496|0;
 $localNormal49$i = sp + 480|0;
 $2 = sp + 464|0;
 $localNormal51$i = sp + 448|0;
 $localNormal53$i = sp + 432|0;
 $localNormal55$i = sp + 416|0;
 $localB$i = sp + 240|0;
 $contactDist = sp + 224|0;
 $boxExtents0 = sp + 208|0;
 $boxExtents1 = sp + 192|0;
 $transf1 = sp + 160|0;
 $aToB = sp + 80|0;
 $projectBreakingThreshold = sp + 64|0;
 $transfV1 = sp;
 $numContacts = sp + 1088|0;
 $worldNormal = sp + 144|0;
 $zeroV = sp + 256|0;
 $closestA = sp + 272|0;
 $closestB = sp + 288|0;
 $normal = sp + 304|0;
 $penDep = sp + 320|0;
 $$sroa$151 = sp + 1092|0;
 $replaceBreakingThreshold = sp + 336|0;
 $localPointA = sp + 352|0;
 $localPointB = sp + 368|0;
 $localNormalPen = sp + 384|0;
 $worldNormal2 = sp + 400|0;
 $3 = HEAP32[$cache>>2]|0;
 $4 = $3;
 $5 = $3;
 $6 = (($5) + 256|0);
 $7 = Math_fround(HEAPF32[$contactDistance>>2]);
 HEAPF32[$contactDist>>2] = $7;
 $8 = (($shape0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($shape0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($shape0) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$boxExtents0>>2] = $9;
 $14 = (($boxExtents0) + 4|0);
 HEAPF32[$14>>2] = $11;
 $15 = (($boxExtents0) + 8|0);
 HEAPF32[$15>>2] = $13;
 $16 = (($boxExtents0) + 12|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($shape1) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($shape1) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($shape1) + 12|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$boxExtents1>>2] = $18;
 $23 = (($boxExtents1) + 4|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($boxExtents1) + 8|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($boxExtents1) + 12|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = Math_fround(HEAPF32[$transform0>>2]);
 $27 = (($transform0) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($transform0) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($transform0) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($transform0) + 16|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($33) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($33) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(HEAPF32[$transform1>>2]);
 $40 = (($transform1) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($transform1) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($transform1) + 12|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($transform1) + 16|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($46) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($46) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$transf1>>2] = $39;
 $52 = (($transf1) + 4|0);
 HEAPF32[$52>>2] = $41;
 $53 = (($transf1) + 8|0);
 HEAPF32[$53>>2] = $43;
 $54 = (($transf1) + 12|0);
 HEAPF32[$54>>2] = $45;
 $55 = (($transf1) + 16|0);
 HEAPF32[$55>>2] = $47;
 $56 = (($transf1) + 20|0);
 HEAPF32[$56>>2] = $49;
 $57 = (($transf1) + 24|0);
 HEAPF32[$57>>2] = $51;
 $58 = (($transf1) + 28|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = Math_fround(-$39);
 $60 = Math_fround(-$41);
 $61 = Math_fround(-$43);
 $62 = Math_fround($34 - $47);
 $63 = Math_fround($36 - $49);
 $64 = Math_fround($38 - $51);
 $65 = Math_fround($45 * $45);
 $66 = Math_fround($65 + Math_fround(-0.5));
 $67 = Math_fround($66 * $62);
 $68 = Math_fround($66 * $63);
 $69 = Math_fround($66 * $64);
 $70 = Math_fround($64 * $60);
 $71 = Math_fround($63 * $61);
 $72 = Math_fround($70 - $71);
 $73 = Math_fround($62 * $61);
 $74 = Math_fround($64 * $59);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($63 * $59);
 $77 = Math_fround($62 * $60);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($45 * $72);
 $80 = Math_fround($45 * $75);
 $81 = Math_fround($45 * $78);
 $82 = Math_fround($67 + $79);
 $83 = Math_fround($68 + $80);
 $84 = Math_fround($69 + $81);
 $85 = Math_fround($62 * $59);
 $86 = Math_fround($63 * $60);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($64 * $61);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($89 * $59);
 $91 = Math_fround($89 * $60);
 $92 = Math_fround($89 * $61);
 $93 = Math_fround($90 + $82);
 $94 = Math_fround($91 + $83);
 $95 = Math_fround($84 + $92);
 $96 = Math_fround($93 * Math_fround(2.0));
 $97 = Math_fround($94 * Math_fround(2.0));
 $98 = Math_fround($95 * Math_fround(2.0));
 $99 = Math_fround($32 * $45);
 $100 = Math_fround($26 * $59);
 $101 = Math_fround($28 * $60);
 $102 = Math_fround($100 + $101);
 $103 = Math_fround($30 * $61);
 $104 = Math_fround($102 + $103);
 $105 = Math_fround($99 - $104);
 $106 = Math_fround($32 * $59);
 $107 = Math_fround($32 * $60);
 $108 = Math_fround($32 * $61);
 $109 = Math_fround($26 * $45);
 $110 = Math_fround($28 * $45);
 $111 = Math_fround($30 * $45);
 $112 = Math_fround($30 * $60);
 $113 = Math_fround($28 * $61);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($26 * $61);
 $116 = Math_fround($30 * $59);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($28 * $59);
 $119 = Math_fround($26 * $60);
 $120 = Math_fround($118 - $119);
 $121 = Math_fround($106 + $109);
 $122 = Math_fround($107 + $110);
 $123 = Math_fround($111 + $108);
 $124 = Math_fround($114 + $121);
 $125 = Math_fround($117 + $122);
 $126 = Math_fround($120 + $123);
 $127 = (($aToB) + 48|0);
 HEAPF32[$127>>2] = $96;
 $128 = (($aToB) + 52|0);
 HEAPF32[$128>>2] = $97;
 $129 = (($aToB) + 56|0);
 HEAPF32[$129>>2] = $98;
 $130 = (($aToB) + 60|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = Math_fround($124 + $124);
 $132 = Math_fround($125 + $125);
 $133 = Math_fround($126 + $126);
 $134 = Math_fround($124 * $131);
 $135 = Math_fround($125 * $132);
 $136 = Math_fround($126 * $133);
 $137 = Math_fround($125 * $131);
 $138 = Math_fround($126 * $131);
 $139 = Math_fround($105 * $131);
 $140 = Math_fround($126 * $132);
 $141 = Math_fround($105 * $132);
 $142 = Math_fround($105 * $133);
 $143 = Math_fround(Math_fround(1.0) - $134);
 $144 = Math_fround(Math_fround(1.0) - $135);
 $145 = Math_fround($144 - $136);
 $146 = Math_fround($137 + $142);
 $147 = Math_fround($138 - $141);
 $148 = Math_fround($137 - $142);
 $149 = Math_fround($143 - $136);
 $150 = Math_fround($140 + $139);
 $151 = Math_fround($138 + $141);
 $152 = Math_fround($140 - $139);
 $153 = Math_fround($143 - $135);
 HEAPF32[$aToB>>2] = $145;
 $154 = (($aToB) + 4|0);
 HEAPF32[$154>>2] = $146;
 $155 = (($aToB) + 8|0);
 HEAPF32[$155>>2] = $147;
 $156 = (($aToB) + 12|0);
 HEAPF32[$156>>2] = Math_fround(0.0);
 $157 = (($aToB) + 16|0);
 HEAPF32[$157>>2] = $148;
 $158 = (($aToB) + 20|0);
 HEAPF32[$158>>2] = $149;
 $159 = (($aToB) + 24|0);
 HEAPF32[$159>>2] = $150;
 $160 = (($aToB) + 28|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 $161 = (($aToB) + 32|0);
 HEAPF32[$161>>2] = $151;
 $162 = (($aToB) + 36|0);
 HEAPF32[$162>>2] = $152;
 $163 = (($aToB) + 40|0);
 HEAPF32[$163>>2] = $153;
 $164 = (($aToB) + 44|0);
 HEAPF32[$164>>2] = Math_fround(0.0);
 $165 = Math_fround(HEAPF32[$boxExtents0>>2]);
 $166 = Math_fround(HEAPF32[$14>>2]);
 $167 = Math_fround(HEAPF32[$15>>2]);
 $168 = !($165 <= $166);
 $$$i$i = $168 ? $166 : $165;
 $169 = !($$$i$i <= $167);
 $170 = $169 ? $167 : $$$i$i;
 $171 = Math_fround($170 * Math_fround(0.150000005960464477539));
 $172 = Math_fround(HEAPF32[$boxExtents1>>2]);
 $173 = Math_fround(HEAPF32[$23>>2]);
 $174 = Math_fround(HEAPF32[$24>>2]);
 $175 = !($172 <= $173);
 $$$i$i34 = $175 ? $173 : $172;
 $176 = !($$$i$i34 <= $174);
 $177 = $176 ? $174 : $$$i$i34;
 $178 = Math_fround($177 * Math_fround(0.150000005960464477539));
 $179 = $171 > $178;
 $$$i = $179 ? $178 : $171;
 $180 = (($4) + 32|0);
 $181 = HEAP8[$180>>0]|0;
 $182 = Math_fround($$$i * Math_fround(0.800000011920928955078));
 HEAPF32[$projectBreakingThreshold>>2] = $182;
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($4,$aToB,$projectBreakingThreshold,0);
 $183 = HEAP8[$180>>0]|0;
 $184 = ($183<<24>>24)==($181<<24>>24);
 if ($184) {
  $185 = $181&255;
  $186 = (554160 + ($185<<2)|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = Math_fround($$$i * $187);
  $189 = (($4) + 16|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($4) + 20|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = (($4) + 24|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = Math_fround($96 - $190);
  $196 = Math_fround($97 - $192);
  $197 = Math_fround($98 - $194);
  $198 = Math_fround(-$195);
  $199 = Math_fround(-$196);
  $200 = Math_fround(-$197);
  $201 = $195 > $198;
  $$$i$i$i$i = $201 ? $195 : $198;
  $202 = $196 > $199;
  $203 = $202 ? $196 : $199;
  $204 = $197 > $200;
  $$1$i$i$i$i = $204 ? $197 : $200;
  $205 = !($$$i$i$i$i >= $203);
  $$$i$i$i43 = $205 ? $203 : $$$i$i$i$i;
  $206 = !($$1$i$i$i$i >= Math_fround(0.0));
  $207 = $206 ? Math_fround(0.0) : $$$i$i$i$i;
  $208 = $$$i$i$i43 >= $207;
  $209 = $208 ? $$$i$i$i43 : $207;
  $210 = $209 > $188;
  if ($210) {
   $$pre$phi166Z2D = $189;$$pre$phi168Z2D = $191;$$pre$phi170Z2D = $193;
  } else {
   $211 = (($4) + 4|0);
   $212 = (($4) + 8|0);
   $213 = Math_fround(HEAPF32[$211>>2]);
   $214 = Math_fround(HEAPF32[$4>>2]);
   $215 = Math_fround($125 * $213);
   $216 = Math_fround($124 * $214);
   $217 = (($4) + 12|0);
   $218 = Math_fround(HEAPF32[$212>>2]);
   $219 = Math_fround($126 * $218);
   $220 = Math_fround($215 + $216);
   $221 = Math_fround(HEAPF32[$217>>2]);
   $222 = Math_fround($105 * $221);
   $223 = Math_fround($220 + $219);
   $224 = (554200 + ($185<<2)|0);
   $225 = Math_fround($223 + $222);
   $226 = Math_fround(HEAPF32[$224>>2]);
   $227 = $226 > $225;
   if ($227) {
    $$pre$phi166Z2D = $189;$$pre$phi168Z2D = $191;$$pre$phi170Z2D = $193;
   } else {
    $1771 = ($181<<24>>24)==(0);
    if ($1771) {
     $$3 = 0;
     STACKTOP = sp;return ($$3|0);
    }
    __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($worldNormal2,$4,$transf1);
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($4,$contactBuffer,$worldNormal2,$transf1);
    $$3 = 1;
    STACKTOP = sp;return ($$3|0);
   }
  }
 } else {
  $$pre165 = (($4) + 16|0);
  $$pre167 = (($4) + 20|0);
  $$pre169 = (($4) + 24|0);
  $$pre$phi166Z2D = $$pre165;$$pre$phi168Z2D = $$pre167;$$pre$phi170Z2D = $$pre169;
 }
 HEAPF32[$4>>2] = $124;
 $228 = (($4) + 4|0);
 HEAPF32[$228>>2] = $125;
 $229 = (($4) + 8|0);
 HEAPF32[$229>>2] = $126;
 $230 = (($4) + 12|0);
 HEAPF32[$230>>2] = $105;
 HEAPF32[$$pre$phi166Z2D>>2] = $96;
 HEAPF32[$$pre$phi168Z2D>>2] = $97;
 HEAPF32[$$pre$phi170Z2D>>2] = $98;
 $231 = (($4) + 28|0);
 HEAPF32[$231>>2] = Math_fround(0.0);
 $232 = Math_fround($26 + $26);
 $233 = Math_fround($28 + $28);
 $234 = Math_fround($30 + $30);
 $235 = Math_fround($26 * $232);
 $236 = Math_fround($28 * $233);
 $237 = Math_fround($30 * $234);
 $238 = Math_fround($232 * $28);
 $239 = Math_fround($232 * $30);
 $240 = Math_fround($232 * $32);
 $241 = Math_fround($233 * $30);
 $242 = Math_fround($233 * $32);
 $243 = Math_fround($234 * $32);
 $244 = Math_fround(Math_fround(1.0) - $235);
 $245 = Math_fround(Math_fround(1.0) - $236);
 $246 = Math_fround($245 - $237);
 $247 = Math_fround($238 + $243);
 $248 = Math_fround($239 - $242);
 $249 = Math_fround($238 - $243);
 $250 = Math_fround($244 - $237);
 $251 = Math_fround($241 + $240);
 $252 = Math_fround($239 + $242);
 $253 = Math_fround($241 - $240);
 $254 = Math_fround($244 - $236);
 $255 = (($transfV1) + 48|0);
 $256 = (($transf1) + 16|0);
 ;HEAP32[$255+0>>2]=HEAP32[$256+0>>2]|0;HEAP32[$255+4>>2]=HEAP32[$256+4>>2]|0;HEAP32[$255+8>>2]=HEAP32[$256+8>>2]|0;HEAP32[$255+12>>2]=HEAP32[$256+12>>2]|0;
 $257 = Math_fround(HEAPF32[$transf1>>2]);
 $258 = Math_fround(HEAPF32[$52>>2]);
 $259 = Math_fround(HEAPF32[$53>>2]);
 $260 = Math_fround(HEAPF32[$54>>2]);
 $261 = Math_fround($257 + $257);
 $262 = Math_fround($258 + $258);
 $263 = Math_fround($259 + $259);
 $264 = Math_fround($257 * $261);
 $265 = Math_fround($258 * $262);
 $266 = Math_fround($259 * $263);
 $267 = Math_fround($261 * $258);
 $268 = Math_fround($261 * $259);
 $269 = Math_fround($261 * $260);
 $270 = Math_fround($262 * $259);
 $271 = Math_fround($262 * $260);
 $272 = Math_fround($263 * $260);
 $273 = Math_fround(Math_fround(1.0) - $264);
 $274 = Math_fround(Math_fround(1.0) - $265);
 $275 = Math_fround($274 - $266);
 $276 = Math_fround($267 + $272);
 $277 = Math_fround($268 - $271);
 $278 = Math_fround($267 - $272);
 $279 = Math_fround($273 - $266);
 $280 = Math_fround($270 + $269);
 $281 = Math_fround($268 + $271);
 $282 = Math_fround($270 - $269);
 $283 = Math_fround($273 - $265);
 HEAPF32[$transfV1>>2] = $275;
 $284 = (($transfV1) + 4|0);
 HEAPF32[$284>>2] = $276;
 $285 = (($transfV1) + 8|0);
 HEAPF32[$285>>2] = $277;
 $286 = (($transfV1) + 12|0);
 HEAPF32[$286>>2] = Math_fround(0.0);
 $287 = (($transfV1) + 16|0);
 HEAPF32[$287>>2] = $278;
 $288 = (($transfV1) + 20|0);
 HEAPF32[$288>>2] = $279;
 $289 = (($transfV1) + 24|0);
 HEAPF32[$289>>2] = $280;
 $290 = (($transfV1) + 28|0);
 HEAPF32[$290>>2] = Math_fround(0.0);
 $291 = (($transfV1) + 32|0);
 HEAPF32[$291>>2] = $281;
 $292 = (($transfV1) + 36|0);
 HEAPF32[$292>>2] = $282;
 $293 = (($transfV1) + 40|0);
 HEAPF32[$293>>2] = $283;
 $294 = (($transfV1) + 44|0);
 HEAPF32[$294>>2] = Math_fround(0.0);
 HEAP32[$numContacts>>2] = 0;
 $295 = Math_fround(HEAPF32[$boxExtents0>>2]);
 HEAPF32[$ea0$i>>2] = $295;
 $296 = Math_fround(HEAPF32[$14>>2]);
 HEAPF32[$ea1$i>>2] = $296;
 $297 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$ea2$i>>2] = $297;
 $298 = Math_fround(HEAPF32[$boxExtents1>>2]);
 HEAPF32[$eb0$i>>2] = $298;
 $299 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$eb1$i>>2] = $299;
 $300 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$eb2$i>>2] = $300;
 $301 = (($transfV1) + 48|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = (($transfV1) + 52|0);
 $304 = Math_fround(HEAPF32[$303>>2]);
 $305 = (($transfV1) + 56|0);
 $306 = Math_fround(HEAPF32[$305>>2]);
 $307 = Math_fround($302 - $34);
 $308 = Math_fround($304 - $36);
 $309 = Math_fround($306 - $38);
 $310 = Math_fround($246 * $307);
 $311 = Math_fround($247 * $308);
 $312 = Math_fround($310 + $311);
 $313 = Math_fround($248 * $309);
 $314 = Math_fround($312 + $313);
 $315 = Math_fround($249 * $307);
 $316 = Math_fround($250 * $308);
 $317 = Math_fround($315 + $316);
 $318 = Math_fround($251 * $309);
 $319 = Math_fround($317 + $318);
 $320 = Math_fround($252 * $307);
 $321 = Math_fround($253 * $308);
 $322 = Math_fround($320 + $321);
 $323 = Math_fround($254 * $309);
 $324 = Math_fround($322 + $323);
 $325 = Math_fround(HEAPF32[$transfV1>>2]);
 $326 = Math_fround(HEAPF32[$284>>2]);
 $327 = Math_fround($246 * $325);
 $328 = Math_fround($247 * $326);
 $329 = Math_fround($327 + $328);
 $330 = Math_fround($248 * $277);
 $331 = Math_fround($329 + $330);
 $332 = Math_fround($249 * $325);
 $333 = Math_fround($250 * $326);
 $334 = Math_fround($332 + $333);
 $335 = Math_fround($251 * $277);
 $336 = Math_fround($334 + $335);
 $337 = Math_fround($252 * $325);
 $338 = Math_fround($253 * $326);
 $339 = Math_fround($337 + $338);
 $340 = Math_fround($254 * $277);
 $341 = Math_fround($339 + $340);
 $342 = Math_fround(HEAPF32[$287>>2]);
 $343 = Math_fround(HEAPF32[$288>>2]);
 $344 = Math_fround(HEAPF32[$289>>2]);
 $345 = Math_fround($246 * $342);
 $346 = Math_fround($247 * $343);
 $347 = Math_fround($345 + $346);
 $348 = Math_fround($248 * $344);
 $349 = Math_fround($347 + $348);
 $350 = Math_fround($249 * $342);
 $351 = Math_fround($250 * $343);
 $352 = Math_fround($350 + $351);
 $353 = Math_fround($251 * $344);
 $354 = Math_fround($352 + $353);
 $355 = Math_fround($252 * $342);
 $356 = Math_fround($253 * $343);
 $357 = Math_fround($355 + $356);
 $358 = Math_fround($254 * $344);
 $359 = Math_fround($357 + $358);
 $360 = Math_fround(HEAPF32[$291>>2]);
 $361 = Math_fround(HEAPF32[$292>>2]);
 $362 = Math_fround(HEAPF32[$293>>2]);
 $363 = Math_fround($246 * $360);
 $364 = Math_fround($247 * $361);
 $365 = Math_fround($363 + $364);
 $366 = Math_fround($248 * $362);
 $367 = Math_fround($365 + $366);
 $368 = Math_fround($249 * $360);
 $369 = Math_fround($250 * $361);
 $370 = Math_fround($368 + $369);
 $371 = Math_fround($251 * $362);
 $372 = Math_fround($370 + $371);
 $373 = Math_fround($252 * $360);
 $374 = Math_fround($253 * $361);
 $375 = Math_fround($373 + $374);
 $376 = Math_fround($254 * $362);
 $377 = Math_fround($375 + $376);
 $378 = Math_fround(-$331);
 $379 = Math_fround(-$336);
 $380 = Math_fround(-$341);
 $381 = $331 > $378;
 $382 = $336 > $379;
 $383 = $382 ? $336 : $379;
 $384 = $341 > $380;
 $$1$i$i$i = $384 ? $341 : $380;
 $385 = Math_fround($383 + Math_fround(9.99999997475242707878E-7));
 $386 = Math_fround(-$349);
 $387 = Math_fround(-$354);
 $388 = Math_fround(-$359);
 $389 = $349 > $386;
 $390 = $354 > $387;
 $391 = $390 ? $354 : $387;
 $392 = $359 > $388;
 $$1$i$i423$i = $392 ? $359 : $388;
 $393 = Math_fround($391 + Math_fround(9.99999997475242707878E-7));
 $394 = Math_fround(-$367);
 $395 = Math_fround(-$372);
 $396 = Math_fround(-$377);
 $397 = $367 > $394;
 $398 = $372 > $395;
 $399 = $398 ? $372 : $395;
 $400 = $377 > $396;
 $$1$i$i549$i = $400 ? $377 : $396;
 $401 = Math_fround($399 + Math_fround(9.99999997475242707878E-7));
 $402 = $389 ? $349 : $386;
 $$1$i$i675$i = $397 ? $367 : $394;
 $403 = Math_fround($402 + Math_fround(9.99999997475242707878E-7));
 $404 = Math_fround($$1$i$i423$i + Math_fround(9.99999997475242707878E-7));
 $$$i$i$i = $381 ? $331 : $378;
 $405 = Math_fround($$$i$i$i + Math_fround(9.99999997475242707878E-7));
 $406 = Math_fround($$1$i$i$i + Math_fround(9.99999997475242707878E-7));
 $407 = Math_fround($$1$i$i675$i + Math_fround(9.99999997475242707878E-7));
 $408 = Math_fround($$1$i$i549$i + Math_fround(9.99999997475242707878E-7));
 $409 = Math_fround(HEAPF32[$boxExtents1>>2]);
 $410 = Math_fround(HEAPF32[$23>>2]);
 $411 = Math_fround(HEAPF32[$24>>2]);
 $412 = Math_fround($405 * $409);
 $413 = Math_fround($410 * $403);
 $414 = Math_fround($411 * $407);
 $415 = Math_fround($413 + $414);
 $416 = Math_fround($412 + $415);
 $417 = Math_fround(HEAPF32[$ea0$i>>2]);
 $418 = Math_fround($417 + $416);
 $fabsf$i$i$i899$i = (Math_fround(Math_abs((Math_fround($314)))));
 $419 = Math_fround($418 - $fabsf$i$i$i899$i);
 $420 = Math_fround(HEAPF32[$contactDist>>2]);
 $421 = Math_fround($420 + $419);
 $422 = $421 < Math_fround(0.0);
 L11: do {
  if ($422) {
   $$1$i = 1;
  } else {
   $423 = Math_fround($385 * $409);
   $424 = Math_fround($410 * $393);
   $425 = Math_fround($411 * $401);
   $426 = Math_fround($424 + $425);
   $427 = Math_fround($423 + $426);
   $428 = Math_fround(HEAPF32[$ea1$i>>2]);
   $429 = Math_fround($427 + $428);
   $fabsf$i$i$i862$i = (Math_fround(Math_abs((Math_fround($319)))));
   $430 = Math_fround($429 - $fabsf$i$i$i862$i);
   $431 = Math_fround($420 + $430);
   $432 = $431 < Math_fround(0.0);
   if ($432) {
    $$1$i = 1;
   } else {
    $433 = Math_fround($406 * $409);
    $434 = Math_fround($410 * $404);
    $435 = Math_fround($411 * $408);
    $436 = Math_fround($434 + $435);
    $437 = Math_fround($433 + $436);
    $438 = Math_fround(HEAPF32[$ea2$i>>2]);
    $439 = Math_fround($437 + $438);
    $fabsf$i$i$i825$i = (Math_fround(Math_abs((Math_fround($324)))));
    $440 = Math_fround($439 - $fabsf$i$i$i825$i);
    $441 = Math_fround($420 + $440);
    $442 = $441 < Math_fround(0.0);
    if ($442) {
     $$1$i = 1;
    } else {
     $443 = Math_fround($314 * $331);
     $444 = Math_fround($319 * $336);
     $445 = Math_fround($443 + $444);
     $446 = Math_fround($324 * $341);
     $447 = Math_fround($446 + $445);
     $448 = Math_fround(HEAPF32[$boxExtents0>>2]);
     $449 = Math_fround(HEAPF32[$14>>2]);
     $450 = Math_fround(HEAPF32[$15>>2]);
     $451 = Math_fround($405 * $448);
     $452 = Math_fround($385 * $449);
     $453 = Math_fround($406 * $450);
     $454 = Math_fround($452 + $453);
     $455 = Math_fround($451 + $454);
     $456 = Math_fround(HEAPF32[$eb0$i>>2]);
     $457 = Math_fround($456 + $455);
     $fabsf$i$i$i784$i = (Math_fround(Math_abs((Math_fround($447)))));
     $458 = Math_fround($457 - $fabsf$i$i$i784$i);
     $459 = Math_fround($420 + $458);
     $460 = $459 < Math_fround(0.0);
     if ($460) {
      $$1$i = 1;
     } else {
      $461 = Math_fround($314 * $349);
      $462 = Math_fround($319 * $354);
      $463 = Math_fround($461 + $462);
      $464 = Math_fround($324 * $359);
      $465 = Math_fround($464 + $463);
      $466 = Math_fround($403 * $448);
      $467 = Math_fround($393 * $449);
      $468 = Math_fround($404 * $450);
      $469 = Math_fround($467 + $468);
      $470 = Math_fround($466 + $469);
      $471 = Math_fround(HEAPF32[$eb1$i>>2]);
      $472 = Math_fround($470 + $471);
      $fabsf$i$i$i743$i = (Math_fround(Math_abs((Math_fround($465)))));
      $473 = Math_fround($472 - $fabsf$i$i$i743$i);
      $474 = Math_fround($420 + $473);
      $475 = $474 < Math_fround(0.0);
      if ($475) {
       $$1$i = 1;
      } else {
       $476 = Math_fround($314 * $367);
       $477 = Math_fround($319 * $372);
       $478 = Math_fround($476 + $477);
       $479 = Math_fround($324 * $377);
       $480 = Math_fround($479 + $478);
       $481 = Math_fround($407 * $448);
       $482 = Math_fround($401 * $449);
       $483 = Math_fround($408 * $450);
       $484 = Math_fround($482 + $483);
       $485 = Math_fround($481 + $484);
       $486 = Math_fround($300 + $485);
       $fabsf$i$i$i702$i = (Math_fround(Math_abs((Math_fround($480)))));
       $487 = Math_fround($486 - $fabsf$i$i$i702$i);
       $488 = Math_fround($420 + $487);
       $489 = $488 < Math_fround(0.0);
       if ($489) {
        $$1$i = 1;
       } else {
        $490 = Math_fround($324 * $336);
        $491 = Math_fround($319 * $341);
        $492 = Math_fround($490 - $491);
        $fabsf$i$i$i671$i = (Math_fround(Math_abs((Math_fround($492)))));
        $493 = Math_fround($406 * $428);
        $494 = Math_fround($385 * $438);
        $495 = Math_fround($493 + $494);
        $496 = Math_fround($407 * $471);
        $497 = Math_fround($300 * $403);
        $498 = Math_fround($497 + $496);
        $499 = Math_fround($495 + $498);
        $500 = Math_fround($420 + $499);
        $501 = $fabsf$i$i$i671$i > $500;
        if ($501) {
         $$1$i = 1;
        } else {
         $502 = Math_fround($324 * $354);
         $503 = Math_fround($319 * $359);
         $504 = Math_fround($502 - $503);
         $fabsf$i$i$i608$i = (Math_fround(Math_abs((Math_fround($504)))));
         $505 = Math_fround($404 * $428);
         $506 = Math_fround($393 * $438);
         $507 = Math_fround($505 + $506);
         $508 = Math_fround($407 * $456);
         $509 = Math_fround($300 * $405);
         $510 = Math_fround($509 + $508);
         $511 = Math_fround($507 + $510);
         $512 = Math_fround($420 + $511);
         $513 = $fabsf$i$i$i608$i > $512;
         if ($513) {
          $$1$i = 1;
         } else {
          $514 = Math_fround($324 * $372);
          $515 = Math_fround($319 * $377);
          $516 = Math_fround($514 - $515);
          $fabsf$i$i$i545$i = (Math_fround(Math_abs((Math_fround($516)))));
          $517 = Math_fround($408 * $428);
          $518 = Math_fround($401 * $438);
          $519 = Math_fround($517 + $518);
          $520 = Math_fround($403 * $456);
          $521 = Math_fround($405 * $471);
          $522 = Math_fround($520 + $521);
          $523 = Math_fround($519 + $522);
          $524 = Math_fround($420 + $523);
          $525 = $fabsf$i$i$i545$i > $524;
          if ($525) {
           $$1$i = 1;
          } else {
           $526 = Math_fround($314 * $341);
           $527 = Math_fround($324 * $331);
           $528 = Math_fround($526 - $527);
           $fabsf$i$i$i482$i = (Math_fround(Math_abs((Math_fround($528)))));
           $529 = Math_fround($406 * $417);
           $530 = Math_fround($405 * $438);
           $531 = Math_fround($529 + $530);
           $532 = Math_fround($401 * $471);
           $533 = Math_fround($300 * $393);
           $534 = Math_fround($533 + $532);
           $535 = Math_fround($531 + $534);
           $536 = Math_fround($420 + $535);
           $537 = $fabsf$i$i$i482$i > $536;
           if ($537) {
            $$1$i = 1;
           } else {
            $538 = Math_fround($314 * $359);
            $539 = Math_fround($324 * $349);
            $540 = Math_fround($538 - $539);
            $fabsf$i$i$i419$i = (Math_fround(Math_abs((Math_fround($540)))));
            $541 = Math_fround($404 * $417);
            $542 = Math_fround($403 * $438);
            $543 = Math_fround($541 + $542);
            $544 = Math_fround($401 * $456);
            $545 = Math_fround($300 * $385);
            $546 = Math_fround($545 + $544);
            $547 = Math_fround($543 + $546);
            $548 = Math_fround($420 + $547);
            $549 = $fabsf$i$i$i419$i > $548;
            if ($549) {
             $$1$i = 1;
            } else {
             $550 = Math_fround($314 * $377);
             $551 = Math_fround($324 * $367);
             $552 = Math_fround($550 - $551);
             $fabsf$i$i$i356$i = (Math_fround(Math_abs((Math_fround($552)))));
             $553 = Math_fround($417 * $408);
             $554 = Math_fround($407 * $438);
             $555 = Math_fround($553 + $554);
             $556 = Math_fround($393 * $456);
             $557 = Math_fround($385 * $471);
             $558 = Math_fround($556 + $557);
             $559 = Math_fround($555 + $558);
             $560 = Math_fround($420 + $559);
             $561 = $fabsf$i$i$i356$i > $560;
             if ($561) {
              $$1$i = 1;
             } else {
              $562 = Math_fround($319 * $331);
              $563 = Math_fround($314 * $336);
              $564 = Math_fround($562 - $563);
              $fabsf$i$i$i295$i = (Math_fround(Math_abs((Math_fround($564)))));
              $565 = Math_fround($385 * $417);
              $566 = Math_fround($405 * $428);
              $567 = Math_fround($565 + $566);
              $568 = Math_fround($408 * $471);
              $569 = Math_fround($300 * $404);
              $570 = Math_fround($569 + $568);
              $571 = Math_fround($567 + $570);
              $572 = Math_fround($420 + $571);
              $573 = $fabsf$i$i$i295$i > $572;
              if ($573) {
               $$1$i = 1;
              } else {
               $574 = Math_fround($319 * $349);
               $575 = Math_fround($314 * $354);
               $576 = Math_fround($574 - $575);
               $fabsf$i$i$i236$i = (Math_fround(Math_abs((Math_fround($576)))));
               $577 = Math_fround($393 * $417);
               $578 = Math_fround($403 * $428);
               $579 = Math_fround($577 + $578);
               $580 = Math_fround($408 * $456);
               $581 = Math_fround($300 * $406);
               $582 = Math_fround($581 + $580);
               $583 = Math_fround($579 + $582);
               $584 = Math_fround($420 + $583);
               $585 = $fabsf$i$i$i236$i > $584;
               if ($585) {
                $$1$i = 1;
               } else {
                $586 = Math_fround($319 * $367);
                $587 = Math_fround($314 * $372);
                $588 = Math_fround($586 - $587);
                $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($588)))));
                $589 = Math_fround($417 * $401);
                $590 = Math_fround($407 * $428);
                $591 = Math_fround($589 + $590);
                $592 = Math_fround($404 * $456);
                $593 = Math_fround($406 * $471);
                $594 = Math_fround($592 + $593);
                $595 = Math_fround($591 + $594);
                $596 = Math_fround($420 + $595);
                $597 = $fabsf$i$i$i$i > $596;
                if ($597) {
                 $$1$i = 1;
                } else {
                 $598 = $421 > $431;
                 $599 = $598 ? $431 : $421;
                 $feature$1$i = $598&1;
                 $600 = $599 > $441;
                 $601 = $600 ? $441 : $599;
                 $feature$1$1$i = $600 ? 2 : $feature$1$i;
                 $602 = $601 > $459;
                 $603 = $602 ? $459 : $601;
                 $feature$1$2$i = $602 ? 3 : $feature$1$1$i;
                 $604 = $603 > $474;
                 $605 = $604 ? $474 : $603;
                 $feature$1$3$i = $604 ? 4 : $feature$1$2$i;
                 $606 = $605 > $488;
                 $feature$1$4$i = $606 ? 5 : $feature$1$3$i;
                 switch ($feature$1$4$i|0) {
                 case 0:  {
                  $607 = !($314 <= Math_fround(0.0));
                  if ($607) {
                   $617 = Math_fround(-$246);
                   $618 = Math_fround(-$247);
                   $619 = Math_fround(-$248);
                   $620 = Math_fround($246 * $417);
                   $621 = Math_fround($247 * $417);
                   $622 = Math_fround($248 * $417);
                   $623 = Math_fround($34 + $620);
                   $624 = Math_fround($36 + $621);
                   $625 = Math_fround($38 + $622);
                   $630 = $623;$632 = $624;$634 = $625;$636 = $252;$638 = $253;$641 = $254;$649 = $617;$651 = $618;$654 = $619;
                  } else {
                   $608 = Math_fround(-$252);
                   $609 = Math_fround(-$253);
                   $610 = Math_fround(-$254);
                   $611 = Math_fround($246 * $417);
                   $612 = Math_fround($247 * $417);
                   $613 = Math_fround($248 * $417);
                   $614 = Math_fround($34 - $611);
                   $615 = Math_fround($36 - $612);
                   $616 = Math_fround($38 - $613);
                   $630 = $614;$632 = $615;$634 = $616;$636 = $608;$638 = $609;$641 = $610;$649 = $246;$651 = $247;$654 = $248;
                  }
                  $626 = Math_fround(HEAPF32[$301>>2]);
                  $627 = Math_fround(HEAPF32[$303>>2]);
                  $628 = Math_fround(HEAPF32[$305>>2]);
                  $629 = Math_fround($626 - $630);
                  $631 = Math_fround($627 - $632);
                  $633 = Math_fround($628 - $634);
                  $635 = Math_fround($636 * $629);
                  $637 = Math_fround($638 * $631);
                  $639 = Math_fround($635 + $637);
                  $640 = Math_fround($641 * $633);
                  $642 = Math_fround($639 + $640);
                  $643 = Math_fround($249 * $629);
                  $644 = Math_fround($250 * $631);
                  $645 = Math_fround($643 + $644);
                  $646 = Math_fround($251 * $633);
                  $647 = Math_fround($645 + $646);
                  $648 = Math_fround($649 * $629);
                  $650 = Math_fround($651 * $631);
                  $652 = Math_fround($648 + $650);
                  $653 = Math_fround($654 * $633);
                  $655 = Math_fround($652 + $653);
                  $656 = Math_fround($325 * $636);
                  $657 = Math_fround($326 * $638);
                  $658 = Math_fround($657 + $656);
                  $659 = Math_fround($277 * $641);
                  $660 = Math_fround($659 + $658);
                  $661 = Math_fround($325 * $649);
                  $662 = Math_fround($326 * $651);
                  $663 = Math_fround($662 + $661);
                  $664 = Math_fround($277 * $654);
                  $665 = Math_fround($664 + $663);
                  $666 = Math_fround($342 * $636);
                  $667 = Math_fround($343 * $638);
                  $668 = Math_fround($667 + $666);
                  $669 = Math_fround($344 * $641);
                  $670 = Math_fround($669 + $668);
                  $671 = Math_fround($342 * $649);
                  $672 = Math_fround($343 * $651);
                  $673 = Math_fround($672 + $671);
                  $674 = Math_fround($344 * $654);
                  $675 = Math_fround($674 + $673);
                  $676 = Math_fround($360 * $636);
                  $677 = Math_fround($361 * $638);
                  $678 = Math_fround($677 + $676);
                  $679 = Math_fround($362 * $641);
                  $680 = Math_fround($679 + $678);
                  $681 = Math_fround($360 * $649);
                  $682 = Math_fround($361 * $651);
                  $683 = Math_fround($682 + $681);
                  $684 = Math_fround($362 * $654);
                  $685 = Math_fround($684 + $683);
                  $686 = (($transform1ToNew$i) + 48|0);
                  HEAPF32[$686>>2] = $642;
                  $687 = (($transform1ToNew$i) + 52|0);
                  HEAPF32[$687>>2] = $647;
                  $688 = (($transform1ToNew$i) + 56|0);
                  HEAPF32[$688>>2] = $655;
                  $689 = (($transform1ToNew$i) + 60|0);
                  HEAPF32[$689>>2] = Math_fround(0.0);
                  HEAPF32[$transform1ToNew$i>>2] = $660;
                  $690 = (($transform1ToNew$i) + 4|0);
                  HEAPF32[$690>>2] = $336;
                  $691 = (($transform1ToNew$i) + 8|0);
                  HEAPF32[$691>>2] = $665;
                  $692 = (($transform1ToNew$i) + 12|0);
                  HEAPF32[$692>>2] = Math_fround(0.0);
                  $693 = (($transform1ToNew$i) + 16|0);
                  HEAPF32[$693>>2] = $670;
                  $694 = (($transform1ToNew$i) + 20|0);
                  HEAPF32[$694>>2] = $354;
                  $695 = (($transform1ToNew$i) + 24|0);
                  HEAPF32[$695>>2] = $675;
                  $696 = (($transform1ToNew$i) + 28|0);
                  HEAPF32[$696>>2] = Math_fround(0.0);
                  $697 = (($transform1ToNew$i) + 32|0);
                  HEAPF32[$697>>2] = $680;
                  $698 = (($transform1ToNew$i) + 36|0);
                  HEAPF32[$698>>2] = $372;
                  $699 = (($transform1ToNew$i) + 40|0);
                  HEAPF32[$699>>2] = $685;
                  $700 = (($transform1ToNew$i) + 44|0);
                  HEAPF32[$700>>2] = Math_fround(0.0);
                  $701 = Math_fround($649 * $636);
                  $702 = Math_fround($651 * $638);
                  $703 = Math_fround($702 + $701);
                  $704 = Math_fround($654 * $641);
                  $705 = Math_fround($704 + $703);
                  $706 = Math_fround($249 * $649);
                  $707 = Math_fround($250 * $651);
                  $708 = Math_fround($707 + $706);
                  $709 = Math_fround($251 * $654);
                  $710 = Math_fround($709 + $708);
                  $711 = Math_fround($649 * $649);
                  $712 = Math_fround($651 * $651);
                  $713 = Math_fround($712 + $711);
                  $714 = Math_fround($654 * $654);
                  $715 = Math_fround($714 + $713);
                  HEAPF32[$localNormal$i>>2] = $705;
                  $716 = (($localNormal$i) + 4|0);
                  HEAPF32[$716>>2] = $710;
                  $717 = (($localNormal$i) + 8|0);
                  HEAPF32[$717>>2] = $715;
                  $718 = (($localNormal$i) + 12|0);
                  HEAPF32[$718>>2] = Math_fround(0.0);
                  $719 = Math_fround(-$705);
                  $720 = Math_fround(-$710);
                  $721 = Math_fround(-$715);
                  HEAPF32[$0>>2] = $719;
                  $722 = (($0) + 4|0);
                  HEAPF32[$722>>2] = $720;
                  $723 = (($0) + 8|0);
                  HEAPF32[$723>>2] = $721;
                  $724 = (($0) + 12|0);
                  HEAPF32[$724>>2] = Math_fround(0.0);
                  __ZN5physx2GuL18getIncidentPolygonEPNS_6shdfnd3aos5Vec3VERS3_RKS3_RKNS2_15PsMatTransformVES7_($pts$i,$incidentFaceNormalInNew$i,$0,$transform1ToNew$i,$boxExtents1);
                  __ZN5physx2GuL17calculateContactsERKNS_6shdfnd3aos6FloatVES5_PNS2_5Vec3VERKS6_S9_PNS0_17PersistentContactERjS5_($ea2$i,$ea1$i,$pts$i,$incidentFaceNormalInNew$i,$localNormal$i,$contactBuffer,$numContacts,$contactDist);
                  $1328 = $630;$1330 = $632;$1332 = $634;$1358 = $636;$1360 = $638;$1363 = $641;$1376 = $249;$1378 = $250;$1381 = $251;$1394 = $649;$1396 = $651;$1399 = $654;
                  break;
                 }
                 case 2:  {
                  $843 = !($324 <= Math_fround(0.0));
                  if ($843) {
                   $850 = Math_fround(-$252);
                   $851 = Math_fround(-$253);
                   $852 = Math_fround(-$254);
                   $853 = Math_fround(-$249);
                   $854 = Math_fround(-$250);
                   $855 = Math_fround(-$251);
                   $856 = Math_fround($252 * $438);
                   $857 = Math_fround($253 * $438);
                   $858 = Math_fround($254 * $438);
                   $859 = Math_fround($34 + $856);
                   $860 = Math_fround($36 + $857);
                   $861 = Math_fround($38 + $858);
                   $866 = $859;$868 = $860;$870 = $861;$877 = $853;$879 = $854;$882 = $855;$885 = $850;$887 = $851;$890 = $852;
                  } else {
                   $844 = Math_fround($252 * $438);
                   $845 = Math_fround($253 * $438);
                   $846 = Math_fround($254 * $438);
                   $847 = Math_fround($34 - $844);
                   $848 = Math_fround($36 - $845);
                   $849 = Math_fround($38 - $846);
                   $866 = $847;$868 = $848;$870 = $849;$877 = $249;$879 = $250;$882 = $251;$885 = $252;$887 = $253;$890 = $254;
                  }
                  $862 = Math_fround(HEAPF32[$301>>2]);
                  $863 = Math_fround(HEAPF32[$303>>2]);
                  $864 = Math_fround(HEAPF32[$305>>2]);
                  $865 = Math_fround($862 - $866);
                  $867 = Math_fround($863 - $868);
                  $869 = Math_fround($864 - $870);
                  $871 = Math_fround($246 * $865);
                  $872 = Math_fround($247 * $867);
                  $873 = Math_fround($871 + $872);
                  $874 = Math_fround($248 * $869);
                  $875 = Math_fround($873 + $874);
                  $876 = Math_fround($877 * $865);
                  $878 = Math_fround($879 * $867);
                  $880 = Math_fround($876 + $878);
                  $881 = Math_fround($882 * $869);
                  $883 = Math_fround($880 + $881);
                  $884 = Math_fround($885 * $865);
                  $886 = Math_fround($887 * $867);
                  $888 = Math_fround($884 + $886);
                  $889 = Math_fround($890 * $869);
                  $891 = Math_fround($888 + $889);
                  $892 = Math_fround($325 * $877);
                  $893 = Math_fround($326 * $879);
                  $894 = Math_fround($893 + $892);
                  $895 = Math_fround($277 * $882);
                  $896 = Math_fround($895 + $894);
                  $897 = Math_fround($325 * $885);
                  $898 = Math_fround($326 * $887);
                  $899 = Math_fround($898 + $897);
                  $900 = Math_fround($277 * $890);
                  $901 = Math_fround($900 + $899);
                  $902 = Math_fround($342 * $877);
                  $903 = Math_fround($343 * $879);
                  $904 = Math_fround($903 + $902);
                  $905 = Math_fround($344 * $882);
                  $906 = Math_fround($905 + $904);
                  $907 = Math_fround($342 * $885);
                  $908 = Math_fround($343 * $887);
                  $909 = Math_fround($908 + $907);
                  $910 = Math_fround($344 * $890);
                  $911 = Math_fround($910 + $909);
                  $912 = Math_fround($360 * $877);
                  $913 = Math_fround($361 * $879);
                  $914 = Math_fround($913 + $912);
                  $915 = Math_fround($362 * $882);
                  $916 = Math_fround($915 + $914);
                  $917 = Math_fround($360 * $885);
                  $918 = Math_fround($361 * $887);
                  $919 = Math_fround($918 + $917);
                  $920 = Math_fround($362 * $890);
                  $921 = Math_fround($920 + $919);
                  $922 = (($transform1ToNew$i) + 48|0);
                  HEAPF32[$922>>2] = $875;
                  $923 = (($transform1ToNew$i) + 52|0);
                  HEAPF32[$923>>2] = $883;
                  $924 = (($transform1ToNew$i) + 56|0);
                  HEAPF32[$924>>2] = $891;
                  $925 = (($transform1ToNew$i) + 60|0);
                  HEAPF32[$925>>2] = Math_fround(0.0);
                  HEAPF32[$transform1ToNew$i>>2] = $331;
                  $926 = (($transform1ToNew$i) + 4|0);
                  HEAPF32[$926>>2] = $896;
                  $927 = (($transform1ToNew$i) + 8|0);
                  HEAPF32[$927>>2] = $901;
                  $928 = (($transform1ToNew$i) + 12|0);
                  HEAPF32[$928>>2] = Math_fround(0.0);
                  $929 = (($transform1ToNew$i) + 16|0);
                  HEAPF32[$929>>2] = $349;
                  $930 = (($transform1ToNew$i) + 20|0);
                  HEAPF32[$930>>2] = $906;
                  $931 = (($transform1ToNew$i) + 24|0);
                  HEAPF32[$931>>2] = $911;
                  $932 = (($transform1ToNew$i) + 28|0);
                  HEAPF32[$932>>2] = Math_fround(0.0);
                  $933 = (($transform1ToNew$i) + 32|0);
                  HEAPF32[$933>>2] = $367;
                  $934 = (($transform1ToNew$i) + 36|0);
                  HEAPF32[$934>>2] = $916;
                  $935 = (($transform1ToNew$i) + 40|0);
                  HEAPF32[$935>>2] = $921;
                  $936 = (($transform1ToNew$i) + 44|0);
                  HEAPF32[$936>>2] = Math_fround(0.0);
                  $937 = Math_fround($246 * $885);
                  $938 = Math_fround($247 * $887);
                  $939 = Math_fround($938 + $937);
                  $940 = Math_fround($248 * $890);
                  $941 = Math_fround($940 + $939);
                  $942 = Math_fround($885 * $877);
                  $943 = Math_fround($887 * $879);
                  $944 = Math_fround($943 + $942);
                  $945 = Math_fround($890 * $882);
                  $946 = Math_fround($945 + $944);
                  $947 = Math_fround($885 * $885);
                  $948 = Math_fround($887 * $887);
                  $949 = Math_fround($948 + $947);
                  $950 = Math_fround($890 * $890);
                  $951 = Math_fround($950 + $949);
                  HEAPF32[$localNormal49$i>>2] = $941;
                  $952 = (($localNormal49$i) + 4|0);
                  HEAPF32[$952>>2] = $946;
                  $953 = (($localNormal49$i) + 8|0);
                  HEAPF32[$953>>2] = $951;
                  $954 = (($localNormal49$i) + 12|0);
                  HEAPF32[$954>>2] = Math_fround(0.0);
                  $955 = Math_fround(-$941);
                  $956 = Math_fround(-$946);
                  $957 = Math_fround(-$951);
                  HEAPF32[$2>>2] = $955;
                  $958 = (($2) + 4|0);
                  HEAPF32[$958>>2] = $956;
                  $959 = (($2) + 8|0);
                  HEAPF32[$959>>2] = $957;
                  $960 = (($2) + 12|0);
                  HEAPF32[$960>>2] = Math_fround(0.0);
                  __ZN5physx2GuL18getIncidentPolygonEPNS_6shdfnd3aos5Vec3VERS3_RKS3_RKNS2_15PsMatTransformVES7_($pts$i,$incidentFaceNormalInNew$i,$2,$transform1ToNew$i,$boxExtents1);
                  __ZN5physx2GuL17calculateContactsERKNS_6shdfnd3aos6FloatVES5_PNS2_5Vec3VERKS6_S9_PNS0_17PersistentContactERjS5_($ea0$i,$ea1$i,$pts$i,$incidentFaceNormalInNew$i,$localNormal49$i,$contactBuffer,$numContacts,$contactDist);
                  $1328 = $866;$1330 = $868;$1332 = $870;$1358 = $246;$1360 = $247;$1363 = $248;$1376 = $877;$1378 = $879;$1381 = $882;$1394 = $885;$1396 = $887;$1399 = $890;
                  break;
                 }
                 case 4:  {
                  $1079 = !($465 <= Math_fround(0.0));
                  $1080 = Math_fround(-$342);
                  $1081 = Math_fround(-$343);
                  $1082 = Math_fround(-$344);
                  if ($1079) {
                   $1092 = Math_fround(-$360);
                   $1093 = Math_fround(-$361);
                   $1094 = Math_fround(-$362);
                   $1095 = Math_fround(HEAPF32[$301>>2]);
                   $1096 = Math_fround(HEAPF32[$303>>2]);
                   $1097 = Math_fround(HEAPF32[$305>>2]);
                   $1098 = Math_fround($342 * $471);
                   $1099 = Math_fround($343 * $471);
                   $1100 = Math_fround($344 * $471);
                   $1101 = Math_fround($1095 - $1098);
                   $1102 = Math_fround($1096 - $1099);
                   $1103 = Math_fround($1097 - $1100);
                   $1105 = $1101;$1107 = $1102;$1109 = $1103;$1116 = $1092;$1118 = $1093;$1121 = $1094;$1124 = $342;$1126 = $343;$1129 = $344;$1177 = $1080;$1179 = $1081;$1182 = $1082;
                  } else {
                   $1083 = Math_fround(HEAPF32[$301>>2]);
                   $1084 = Math_fround(HEAPF32[$303>>2]);
                   $1085 = Math_fround(HEAPF32[$305>>2]);
                   $1086 = Math_fround($342 * $471);
                   $1087 = Math_fround($343 * $471);
                   $1088 = Math_fround($344 * $471);
                   $1089 = Math_fround($1086 + $1083);
                   $1090 = Math_fround($1087 + $1084);
                   $1091 = Math_fround($1088 + $1085);
                   $1105 = $1089;$1107 = $1090;$1109 = $1091;$1116 = $360;$1118 = $361;$1121 = $362;$1124 = $1080;$1126 = $1081;$1129 = $1082;$1177 = $342;$1179 = $343;$1182 = $344;
                  }
                  $1104 = Math_fround($34 - $1105);
                  $1106 = Math_fround($36 - $1107);
                  $1108 = Math_fround($38 - $1109);
                  $1110 = Math_fround($325 * $1104);
                  $1111 = Math_fround($326 * $1106);
                  $1112 = Math_fround($1111 + $1110);
                  $1113 = Math_fround($277 * $1108);
                  $1114 = Math_fround($1113 + $1112);
                  $1115 = Math_fround($1104 * $1116);
                  $1117 = Math_fround($1106 * $1118);
                  $1119 = Math_fround($1117 + $1115);
                  $1120 = Math_fround($1108 * $1121);
                  $1122 = Math_fround($1120 + $1119);
                  $1123 = Math_fround($1104 * $1124);
                  $1125 = Math_fround($1106 * $1126);
                  $1127 = Math_fround($1125 + $1123);
                  $1128 = Math_fround($1108 * $1129);
                  $1130 = Math_fround($1128 + $1127);
                  $1131 = Math_fround($246 * $1116);
                  $1132 = Math_fround($247 * $1118);
                  $1133 = Math_fround($1132 + $1131);
                  $1134 = Math_fround($248 * $1121);
                  $1135 = Math_fround($1134 + $1133);
                  $1136 = Math_fround($246 * $1124);
                  $1137 = Math_fround($247 * $1126);
                  $1138 = Math_fround($1137 + $1136);
                  $1139 = Math_fround($248 * $1129);
                  $1140 = Math_fround($1139 + $1138);
                  $1141 = Math_fround($249 * $1116);
                  $1142 = Math_fround($250 * $1118);
                  $1143 = Math_fround($1142 + $1141);
                  $1144 = Math_fround($251 * $1121);
                  $1145 = Math_fround($1144 + $1143);
                  $1146 = Math_fround($249 * $1124);
                  $1147 = Math_fround($250 * $1126);
                  $1148 = Math_fround($1147 + $1146);
                  $1149 = Math_fround($251 * $1129);
                  $1150 = Math_fround($1149 + $1148);
                  $1151 = Math_fround($252 * $1116);
                  $1152 = Math_fround($253 * $1118);
                  $1153 = Math_fround($1152 + $1151);
                  $1154 = Math_fround($254 * $1121);
                  $1155 = Math_fround($1154 + $1153);
                  $1156 = Math_fround($252 * $1124);
                  $1157 = Math_fround($253 * $1126);
                  $1158 = Math_fround($1157 + $1156);
                  $1159 = Math_fround($254 * $1129);
                  $1160 = Math_fround($1159 + $1158);
                  $1161 = (($transform1ToNew$i) + 48|0);
                  HEAPF32[$1161>>2] = $1114;
                  $1162 = (($transform1ToNew$i) + 52|0);
                  HEAPF32[$1162>>2] = $1122;
                  $1163 = (($transform1ToNew$i) + 56|0);
                  HEAPF32[$1163>>2] = $1130;
                  $1164 = (($transform1ToNew$i) + 60|0);
                  HEAPF32[$1164>>2] = Math_fround(0.0);
                  HEAPF32[$transform1ToNew$i>>2] = $331;
                  $1165 = (($transform1ToNew$i) + 4|0);
                  HEAPF32[$1165>>2] = $1135;
                  $1166 = (($transform1ToNew$i) + 8|0);
                  HEAPF32[$1166>>2] = $1140;
                  $1167 = (($transform1ToNew$i) + 12|0);
                  HEAPF32[$1167>>2] = Math_fround(0.0);
                  $1168 = (($transform1ToNew$i) + 16|0);
                  HEAPF32[$1168>>2] = $336;
                  $1169 = (($transform1ToNew$i) + 20|0);
                  HEAPF32[$1169>>2] = $1145;
                  $1170 = (($transform1ToNew$i) + 24|0);
                  HEAPF32[$1170>>2] = $1150;
                  $1171 = (($transform1ToNew$i) + 28|0);
                  HEAPF32[$1171>>2] = Math_fround(0.0);
                  $1172 = (($transform1ToNew$i) + 32|0);
                  HEAPF32[$1172>>2] = $341;
                  $1173 = (($transform1ToNew$i) + 36|0);
                  HEAPF32[$1173>>2] = $1155;
                  $1174 = (($transform1ToNew$i) + 40|0);
                  HEAPF32[$1174>>2] = $1160;
                  $1175 = (($transform1ToNew$i) + 44|0);
                  HEAPF32[$1175>>2] = Math_fround(0.0);
                  $1176 = Math_fround($325 * $1177);
                  $1178 = Math_fround($326 * $1179);
                  $1180 = Math_fround($1178 + $1176);
                  $1181 = Math_fround($277 * $1182);
                  $1183 = Math_fround($1181 + $1180);
                  $1184 = Math_fround($1177 * $1116);
                  $1185 = Math_fround($1179 * $1118);
                  $1186 = Math_fround($1185 + $1184);
                  $1187 = Math_fround($1182 * $1121);
                  $1188 = Math_fround($1187 + $1186);
                  $1189 = Math_fround($1177 * $1124);
                  $1190 = Math_fround($1179 * $1126);
                  $1191 = Math_fround($1190 + $1189);
                  $1192 = Math_fround($1182 * $1129);
                  $1193 = Math_fround($1192 + $1191);
                  HEAPF32[$localNormal53$i>>2] = $1183;
                  $1194 = (($localNormal53$i) + 4|0);
                  HEAPF32[$1194>>2] = $1188;
                  $1195 = (($localNormal53$i) + 8|0);
                  HEAPF32[$1195>>2] = $1193;
                  $1196 = (($localNormal53$i) + 12|0);
                  HEAPF32[$1196>>2] = Math_fround(0.0);
                  __ZN5physx2GuL18getIncidentPolygonEPNS_6shdfnd3aos5Vec3VERS3_RKS3_RKNS2_15PsMatTransformVES7_($pts$i,$incidentFaceNormalInNew$i,$localNormal53$i,$transform1ToNew$i,$boxExtents0);
                  __ZN5physx2GuL17calculateContactsERKNS_6shdfnd3aos6FloatVES5_PNS2_5Vec3VERKS6_S9_PNS0_17PersistentContactERjS5_($eb0$i,$eb2$i,$pts$i,$incidentFaceNormalInNew$i,$localNormal53$i,$contactBuffer,$numContacts,$contactDist);
                  $$ph$i = $1109;$$ph3610$i = $1107;$$ph3611$i = $1105;$$ph3612$i = $1129;$$ph3613$i = $1126;$$ph3614$i = $1124;$$ph3615$i = $1121;$$ph3616$i = $1118;$$ph3617$i = $1116;$$ph3618$i = $277;$$ph3619$i = $326;$$ph3620$i = $325;
                  label = 45;
                  break;
                 }
                 case 3:  {
                  $961 = !($447 <= Math_fround(0.0));
                  $962 = Math_fround(-$325);
                  $963 = Math_fround(-$326);
                  $964 = Math_fround(-$277);
                  if ($961) {
                   $974 = Math_fround(-$360);
                   $975 = Math_fround(-$361);
                   $976 = Math_fround(-$362);
                   $977 = Math_fround(HEAPF32[$301>>2]);
                   $978 = Math_fround(HEAPF32[$303>>2]);
                   $979 = Math_fround(HEAPF32[$305>>2]);
                   $980 = Math_fround($325 * $456);
                   $981 = Math_fround($326 * $456);
                   $982 = Math_fround($277 * $456);
                   $983 = Math_fround($977 - $980);
                   $984 = Math_fround($978 - $981);
                   $985 = Math_fround($979 - $982);
                   $1006 = $325;$1008 = $326;$1011 = $277;$1059 = $962;$1061 = $963;$1064 = $964;$987 = $983;$989 = $984;$991 = $985;$993 = $974;$995 = $975;$998 = $976;
                  } else {
                   $965 = Math_fround(HEAPF32[$301>>2]);
                   $966 = Math_fround(HEAPF32[$303>>2]);
                   $967 = Math_fround(HEAPF32[$305>>2]);
                   $968 = Math_fround($325 * $456);
                   $969 = Math_fround($326 * $456);
                   $970 = Math_fround($277 * $456);
                   $971 = Math_fround($968 + $965);
                   $972 = Math_fround($969 + $966);
                   $973 = Math_fround($970 + $967);
                   $1006 = $962;$1008 = $963;$1011 = $964;$1059 = $325;$1061 = $326;$1064 = $277;$987 = $971;$989 = $972;$991 = $973;$993 = $360;$995 = $361;$998 = $362;
                  }
                  $986 = Math_fround($34 - $987);
                  $988 = Math_fround($36 - $989);
                  $990 = Math_fround($38 - $991);
                  $992 = Math_fround($986 * $993);
                  $994 = Math_fround($988 * $995);
                  $996 = Math_fround($994 + $992);
                  $997 = Math_fround($990 * $998);
                  $999 = Math_fround($997 + $996);
                  $1000 = Math_fround($342 * $986);
                  $1001 = Math_fround($343 * $988);
                  $1002 = Math_fround($1001 + $1000);
                  $1003 = Math_fround($344 * $990);
                  $1004 = Math_fround($1003 + $1002);
                  $1005 = Math_fround($986 * $1006);
                  $1007 = Math_fround($988 * $1008);
                  $1009 = Math_fround($1007 + $1005);
                  $1010 = Math_fround($990 * $1011);
                  $1012 = Math_fround($1010 + $1009);
                  $1013 = Math_fround($246 * $993);
                  $1014 = Math_fround($247 * $995);
                  $1015 = Math_fround($1014 + $1013);
                  $1016 = Math_fround($248 * $998);
                  $1017 = Math_fround($1016 + $1015);
                  $1018 = Math_fround($246 * $1006);
                  $1019 = Math_fround($247 * $1008);
                  $1020 = Math_fround($1019 + $1018);
                  $1021 = Math_fround($248 * $1011);
                  $1022 = Math_fround($1021 + $1020);
                  $1023 = Math_fround($249 * $993);
                  $1024 = Math_fround($250 * $995);
                  $1025 = Math_fround($1024 + $1023);
                  $1026 = Math_fround($251 * $998);
                  $1027 = Math_fround($1026 + $1025);
                  $1028 = Math_fround($249 * $1006);
                  $1029 = Math_fround($250 * $1008);
                  $1030 = Math_fround($1029 + $1028);
                  $1031 = Math_fround($251 * $1011);
                  $1032 = Math_fround($1031 + $1030);
                  $1033 = Math_fround($252 * $993);
                  $1034 = Math_fround($253 * $995);
                  $1035 = Math_fround($1034 + $1033);
                  $1036 = Math_fround($254 * $998);
                  $1037 = Math_fround($1036 + $1035);
                  $1038 = Math_fround($252 * $1006);
                  $1039 = Math_fround($253 * $1008);
                  $1040 = Math_fround($1039 + $1038);
                  $1041 = Math_fround($254 * $1011);
                  $1042 = Math_fround($1041 + $1040);
                  $1043 = (($transform1ToNew$i) + 48|0);
                  HEAPF32[$1043>>2] = $999;
                  $1044 = (($transform1ToNew$i) + 52|0);
                  HEAPF32[$1044>>2] = $1004;
                  $1045 = (($transform1ToNew$i) + 56|0);
                  HEAPF32[$1045>>2] = $1012;
                  $1046 = (($transform1ToNew$i) + 60|0);
                  HEAPF32[$1046>>2] = Math_fround(0.0);
                  HEAPF32[$transform1ToNew$i>>2] = $1017;
                  $1047 = (($transform1ToNew$i) + 4|0);
                  HEAPF32[$1047>>2] = $349;
                  $1048 = (($transform1ToNew$i) + 8|0);
                  HEAPF32[$1048>>2] = $1022;
                  $1049 = (($transform1ToNew$i) + 12|0);
                  HEAPF32[$1049>>2] = Math_fround(0.0);
                  $1050 = (($transform1ToNew$i) + 16|0);
                  HEAPF32[$1050>>2] = $1027;
                  $1051 = (($transform1ToNew$i) + 20|0);
                  HEAPF32[$1051>>2] = $354;
                  $1052 = (($transform1ToNew$i) + 24|0);
                  HEAPF32[$1052>>2] = $1032;
                  $1053 = (($transform1ToNew$i) + 28|0);
                  HEAPF32[$1053>>2] = Math_fround(0.0);
                  $1054 = (($transform1ToNew$i) + 32|0);
                  HEAPF32[$1054>>2] = $1037;
                  $1055 = (($transform1ToNew$i) + 36|0);
                  HEAPF32[$1055>>2] = $359;
                  $1056 = (($transform1ToNew$i) + 40|0);
                  HEAPF32[$1056>>2] = $1042;
                  $1057 = (($transform1ToNew$i) + 44|0);
                  HEAPF32[$1057>>2] = Math_fround(0.0);
                  $1058 = Math_fround($1059 * $993);
                  $1060 = Math_fround($1061 * $995);
                  $1062 = Math_fround($1060 + $1058);
                  $1063 = Math_fround($1064 * $998);
                  $1065 = Math_fround($1063 + $1062);
                  $1066 = Math_fround($342 * $1059);
                  $1067 = Math_fround($343 * $1061);
                  $1068 = Math_fround($1067 + $1066);
                  $1069 = Math_fround($344 * $1064);
                  $1070 = Math_fround($1069 + $1068);
                  $1071 = Math_fround($1059 * $1006);
                  $1072 = Math_fround($1061 * $1008);
                  $1073 = Math_fround($1072 + $1071);
                  $1074 = Math_fround($1064 * $1011);
                  $1075 = Math_fround($1074 + $1073);
                  HEAPF32[$localNormal51$i>>2] = $1065;
                  $1076 = (($localNormal51$i) + 4|0);
                  HEAPF32[$1076>>2] = $1070;
                  $1077 = (($localNormal51$i) + 8|0);
                  HEAPF32[$1077>>2] = $1075;
                  $1078 = (($localNormal51$i) + 12|0);
                  HEAPF32[$1078>>2] = Math_fround(0.0);
                  __ZN5physx2GuL18getIncidentPolygonEPNS_6shdfnd3aos5Vec3VERS3_RKS3_RKNS2_15PsMatTransformVES7_($pts$i,$incidentFaceNormalInNew$i,$localNormal51$i,$transform1ToNew$i,$boxExtents0);
                  __ZN5physx2GuL17calculateContactsERKNS_6shdfnd3aos6FloatVES5_PNS2_5Vec3VERKS6_S9_PNS0_17PersistentContactERjS5_($eb2$i,$eb1$i,$pts$i,$incidentFaceNormalInNew$i,$localNormal51$i,$contactBuffer,$numContacts,$contactDist);
                  $$ph$i = $991;$$ph3610$i = $989;$$ph3611$i = $987;$$ph3612$i = $1011;$$ph3613$i = $1008;$$ph3614$i = $1006;$$ph3615$i = $344;$$ph3616$i = $343;$$ph3617$i = $342;$$ph3618$i = $998;$$ph3619$i = $995;$$ph3620$i = $993;
                  label = 45;
                  break;
                 }
                 case 5:  {
                  $1197 = !($480 <= Math_fround(0.0));
                  if ($1197) {
                   $1213 = Math_fround(-$360);
                   $1214 = Math_fround(-$361);
                   $1215 = Math_fround(-$362);
                   $1216 = Math_fround(HEAPF32[$301>>2]);
                   $1217 = Math_fround(HEAPF32[$303>>2]);
                   $1218 = Math_fround(HEAPF32[$305>>2]);
                   $1219 = Math_fround($300 * $360);
                   $1220 = Math_fround($300 * $361);
                   $1221 = Math_fround($300 * $362);
                   $1222 = Math_fround($1216 - $1219);
                   $1223 = Math_fround($1217 - $1220);
                   $1224 = Math_fround($1218 - $1221);
                   $1226 = $1222;$1228 = $1223;$1230 = $1224;$1237 = $342;$1239 = $343;$1242 = $344;$1245 = $360;$1247 = $361;$1250 = $362;$1298 = $1213;$1300 = $1214;$1303 = $1215;
                  } else {
                   $1198 = Math_fround(-$342);
                   $1199 = Math_fround(-$343);
                   $1200 = Math_fround(-$344);
                   $1201 = Math_fround(-$360);
                   $1202 = Math_fround(-$361);
                   $1203 = Math_fround(-$362);
                   $1204 = Math_fround(HEAPF32[$301>>2]);
                   $1205 = Math_fround(HEAPF32[$303>>2]);
                   $1206 = Math_fround(HEAPF32[$305>>2]);
                   $1207 = Math_fround($300 * $360);
                   $1208 = Math_fround($300 * $361);
                   $1209 = Math_fround($300 * $362);
                   $1210 = Math_fround($1207 + $1204);
                   $1211 = Math_fround($1208 + $1205);
                   $1212 = Math_fround($1209 + $1206);
                   $1226 = $1210;$1228 = $1211;$1230 = $1212;$1237 = $1198;$1239 = $1199;$1242 = $1200;$1245 = $1201;$1247 = $1202;$1250 = $1203;$1298 = $360;$1300 = $361;$1303 = $362;
                  }
                  $1225 = Math_fround($34 - $1226);
                  $1227 = Math_fround($36 - $1228);
                  $1229 = Math_fround($38 - $1230);
                  $1231 = Math_fround($325 * $1225);
                  $1232 = Math_fround($326 * $1227);
                  $1233 = Math_fround($1232 + $1231);
                  $1234 = Math_fround($277 * $1229);
                  $1235 = Math_fround($1234 + $1233);
                  $1236 = Math_fround($1225 * $1237);
                  $1238 = Math_fround($1227 * $1239);
                  $1240 = Math_fround($1238 + $1236);
                  $1241 = Math_fround($1229 * $1242);
                  $1243 = Math_fround($1241 + $1240);
                  $1244 = Math_fround($1225 * $1245);
                  $1246 = Math_fround($1227 * $1247);
                  $1248 = Math_fround($1246 + $1244);
                  $1249 = Math_fround($1229 * $1250);
                  $1251 = Math_fround($1249 + $1248);
                  $1252 = Math_fround($246 * $1237);
                  $1253 = Math_fround($247 * $1239);
                  $1254 = Math_fround($1253 + $1252);
                  $1255 = Math_fround($248 * $1242);
                  $1256 = Math_fround($1255 + $1254);
                  $1257 = Math_fround($246 * $1245);
                  $1258 = Math_fround($247 * $1247);
                  $1259 = Math_fround($1258 + $1257);
                  $1260 = Math_fround($248 * $1250);
                  $1261 = Math_fround($1260 + $1259);
                  $1262 = Math_fround($249 * $1237);
                  $1263 = Math_fround($250 * $1239);
                  $1264 = Math_fround($1263 + $1262);
                  $1265 = Math_fround($251 * $1242);
                  $1266 = Math_fround($1265 + $1264);
                  $1267 = Math_fround($249 * $1245);
                  $1268 = Math_fround($250 * $1247);
                  $1269 = Math_fround($1268 + $1267);
                  $1270 = Math_fround($251 * $1250);
                  $1271 = Math_fround($1270 + $1269);
                  $1272 = Math_fround($252 * $1237);
                  $1273 = Math_fround($253 * $1239);
                  $1274 = Math_fround($1273 + $1272);
                  $1275 = Math_fround($254 * $1242);
                  $1276 = Math_fround($1275 + $1274);
                  $1277 = Math_fround($252 * $1245);
                  $1278 = Math_fround($253 * $1247);
                  $1279 = Math_fround($1278 + $1277);
                  $1280 = Math_fround($254 * $1250);
                  $1281 = Math_fround($1280 + $1279);
                  $1282 = (($transform1ToNew$i) + 48|0);
                  HEAPF32[$1282>>2] = $1235;
                  $1283 = (($transform1ToNew$i) + 52|0);
                  HEAPF32[$1283>>2] = $1243;
                  $1284 = (($transform1ToNew$i) + 56|0);
                  HEAPF32[$1284>>2] = $1251;
                  $1285 = (($transform1ToNew$i) + 60|0);
                  HEAPF32[$1285>>2] = Math_fround(0.0);
                  HEAPF32[$transform1ToNew$i>>2] = $331;
                  $1286 = (($transform1ToNew$i) + 4|0);
                  HEAPF32[$1286>>2] = $1256;
                  $1287 = (($transform1ToNew$i) + 8|0);
                  HEAPF32[$1287>>2] = $1261;
                  $1288 = (($transform1ToNew$i) + 12|0);
                  HEAPF32[$1288>>2] = Math_fround(0.0);
                  $1289 = (($transform1ToNew$i) + 16|0);
                  HEAPF32[$1289>>2] = $336;
                  $1290 = (($transform1ToNew$i) + 20|0);
                  HEAPF32[$1290>>2] = $1266;
                  $1291 = (($transform1ToNew$i) + 24|0);
                  HEAPF32[$1291>>2] = $1271;
                  $1292 = (($transform1ToNew$i) + 28|0);
                  HEAPF32[$1292>>2] = Math_fround(0.0);
                  $1293 = (($transform1ToNew$i) + 32|0);
                  HEAPF32[$1293>>2] = $341;
                  $1294 = (($transform1ToNew$i) + 36|0);
                  HEAPF32[$1294>>2] = $1276;
                  $1295 = (($transform1ToNew$i) + 40|0);
                  HEAPF32[$1295>>2] = $1281;
                  $1296 = (($transform1ToNew$i) + 44|0);
                  HEAPF32[$1296>>2] = Math_fround(0.0);
                  $1297 = Math_fround($325 * $1298);
                  $1299 = Math_fround($326 * $1300);
                  $1301 = Math_fround($1299 + $1297);
                  $1302 = Math_fround($277 * $1303);
                  $1304 = Math_fround($1302 + $1301);
                  $1305 = Math_fround($1298 * $1237);
                  $1306 = Math_fround($1300 * $1239);
                  $1307 = Math_fround($1306 + $1305);
                  $1308 = Math_fround($1303 * $1242);
                  $1309 = Math_fround($1308 + $1307);
                  $1310 = Math_fround($1298 * $1245);
                  $1311 = Math_fround($1300 * $1247);
                  $1312 = Math_fround($1311 + $1310);
                  $1313 = Math_fround($1303 * $1250);
                  $1314 = Math_fround($1313 + $1312);
                  HEAPF32[$localNormal55$i>>2] = $1304;
                  $1315 = (($localNormal55$i) + 4|0);
                  HEAPF32[$1315>>2] = $1309;
                  $1316 = (($localNormal55$i) + 8|0);
                  HEAPF32[$1316>>2] = $1314;
                  $1317 = (($localNormal55$i) + 12|0);
                  HEAPF32[$1317>>2] = Math_fround(0.0);
                  __ZN5physx2GuL18getIncidentPolygonEPNS_6shdfnd3aos5Vec3VERS3_RKS3_RKNS2_15PsMatTransformVES7_($pts$i,$incidentFaceNormalInNew$i,$localNormal55$i,$transform1ToNew$i,$boxExtents0);
                  __ZN5physx2GuL17calculateContactsERKNS_6shdfnd3aos6FloatVES5_PNS2_5Vec3VERKS6_S9_PNS0_17PersistentContactERjS5_($eb0$i,$eb1$i,$pts$i,$incidentFaceNormalInNew$i,$localNormal55$i,$contactBuffer,$numContacts,$contactDist);
                  $$ph$i = $1230;$$ph3610$i = $1228;$$ph3611$i = $1226;$$ph3612$i = $1250;$$ph3613$i = $1247;$$ph3614$i = $1245;$$ph3615$i = $1242;$$ph3616$i = $1239;$$ph3617$i = $1237;$$ph3618$i = $277;$$ph3619$i = $326;$$ph3620$i = $325;
                  label = 45;
                  break;
                 }
                 case 1:  {
                  $725 = !($319 <= Math_fround(0.0));
                  if ($725) {
                   $735 = Math_fround(-$249);
                   $736 = Math_fround(-$250);
                   $737 = Math_fround(-$251);
                   $738 = Math_fround($249 * $428);
                   $739 = Math_fround($250 * $428);
                   $740 = Math_fround($251 * $428);
                   $741 = Math_fround($34 + $738);
                   $742 = Math_fround($36 + $739);
                   $743 = Math_fround($38 + $740);
                   $748 = $741;$750 = $742;$752 = $743;$759 = $252;$761 = $253;$764 = $254;$767 = $735;$769 = $736;$772 = $737;
                  } else {
                   $726 = Math_fround(-$252);
                   $727 = Math_fround(-$253);
                   $728 = Math_fround(-$254);
                   $729 = Math_fround($249 * $428);
                   $730 = Math_fround($250 * $428);
                   $731 = Math_fround($251 * $428);
                   $732 = Math_fround($34 - $729);
                   $733 = Math_fround($36 - $730);
                   $734 = Math_fround($38 - $731);
                   $748 = $732;$750 = $733;$752 = $734;$759 = $726;$761 = $727;$764 = $728;$767 = $249;$769 = $250;$772 = $251;
                  }
                  $744 = Math_fround(HEAPF32[$301>>2]);
                  $745 = Math_fround(HEAPF32[$303>>2]);
                  $746 = Math_fround(HEAPF32[$305>>2]);
                  $747 = Math_fround($744 - $748);
                  $749 = Math_fround($745 - $750);
                  $751 = Math_fround($746 - $752);
                  $753 = Math_fround($246 * $747);
                  $754 = Math_fround($247 * $749);
                  $755 = Math_fround($753 + $754);
                  $756 = Math_fround($248 * $751);
                  $757 = Math_fround($755 + $756);
                  $758 = Math_fround($759 * $747);
                  $760 = Math_fround($761 * $749);
                  $762 = Math_fround($758 + $760);
                  $763 = Math_fround($764 * $751);
                  $765 = Math_fround($762 + $763);
                  $766 = Math_fround($767 * $747);
                  $768 = Math_fround($769 * $749);
                  $770 = Math_fround($766 + $768);
                  $771 = Math_fround($772 * $751);
                  $773 = Math_fround($770 + $771);
                  $774 = Math_fround($325 * $759);
                  $775 = Math_fround($326 * $761);
                  $776 = Math_fround($775 + $774);
                  $777 = Math_fround($277 * $764);
                  $778 = Math_fround($777 + $776);
                  $779 = Math_fround($325 * $767);
                  $780 = Math_fround($326 * $769);
                  $781 = Math_fround($780 + $779);
                  $782 = Math_fround($277 * $772);
                  $783 = Math_fround($782 + $781);
                  $784 = Math_fround($342 * $759);
                  $785 = Math_fround($343 * $761);
                  $786 = Math_fround($785 + $784);
                  $787 = Math_fround($344 * $764);
                  $788 = Math_fround($787 + $786);
                  $789 = Math_fround($342 * $767);
                  $790 = Math_fround($343 * $769);
                  $791 = Math_fround($790 + $789);
                  $792 = Math_fround($344 * $772);
                  $793 = Math_fround($792 + $791);
                  $794 = Math_fround($360 * $759);
                  $795 = Math_fround($361 * $761);
                  $796 = Math_fround($795 + $794);
                  $797 = Math_fround($362 * $764);
                  $798 = Math_fround($797 + $796);
                  $799 = Math_fround($360 * $767);
                  $800 = Math_fround($361 * $769);
                  $801 = Math_fround($800 + $799);
                  $802 = Math_fround($362 * $772);
                  $803 = Math_fround($802 + $801);
                  $804 = (($transform1ToNew$i) + 48|0);
                  HEAPF32[$804>>2] = $757;
                  $805 = (($transform1ToNew$i) + 52|0);
                  HEAPF32[$805>>2] = $765;
                  $806 = (($transform1ToNew$i) + 56|0);
                  HEAPF32[$806>>2] = $773;
                  $807 = (($transform1ToNew$i) + 60|0);
                  HEAPF32[$807>>2] = Math_fround(0.0);
                  HEAPF32[$transform1ToNew$i>>2] = $331;
                  $808 = (($transform1ToNew$i) + 4|0);
                  HEAPF32[$808>>2] = $778;
                  $809 = (($transform1ToNew$i) + 8|0);
                  HEAPF32[$809>>2] = $783;
                  $810 = (($transform1ToNew$i) + 12|0);
                  HEAPF32[$810>>2] = Math_fround(0.0);
                  $811 = (($transform1ToNew$i) + 16|0);
                  HEAPF32[$811>>2] = $349;
                  $812 = (($transform1ToNew$i) + 20|0);
                  HEAPF32[$812>>2] = $788;
                  $813 = (($transform1ToNew$i) + 24|0);
                  HEAPF32[$813>>2] = $793;
                  $814 = (($transform1ToNew$i) + 28|0);
                  HEAPF32[$814>>2] = Math_fround(0.0);
                  $815 = (($transform1ToNew$i) + 32|0);
                  HEAPF32[$815>>2] = $367;
                  $816 = (($transform1ToNew$i) + 36|0);
                  HEAPF32[$816>>2] = $798;
                  $817 = (($transform1ToNew$i) + 40|0);
                  HEAPF32[$817>>2] = $803;
                  $818 = (($transform1ToNew$i) + 44|0);
                  HEAPF32[$818>>2] = Math_fround(0.0);
                  $819 = Math_fround($246 * $767);
                  $820 = Math_fround($247 * $769);
                  $821 = Math_fround($820 + $819);
                  $822 = Math_fround($248 * $772);
                  $823 = Math_fround($822 + $821);
                  $824 = Math_fround($767 * $759);
                  $825 = Math_fround($769 * $761);
                  $826 = Math_fround($825 + $824);
                  $827 = Math_fround($772 * $764);
                  $828 = Math_fround($827 + $826);
                  $829 = Math_fround($767 * $767);
                  $830 = Math_fround($769 * $769);
                  $831 = Math_fround($830 + $829);
                  $832 = Math_fround($772 * $772);
                  $833 = Math_fround($832 + $831);
                  HEAPF32[$localNormal47$i>>2] = $823;
                  $834 = (($localNormal47$i) + 4|0);
                  HEAPF32[$834>>2] = $828;
                  $835 = (($localNormal47$i) + 8|0);
                  HEAPF32[$835>>2] = $833;
                  $836 = (($localNormal47$i) + 12|0);
                  HEAPF32[$836>>2] = Math_fround(0.0);
                  $837 = Math_fround(-$823);
                  $838 = Math_fround(-$828);
                  $839 = Math_fround(-$833);
                  HEAPF32[$1>>2] = $837;
                  $840 = (($1) + 4|0);
                  HEAPF32[$840>>2] = $838;
                  $841 = (($1) + 8|0);
                  HEAPF32[$841>>2] = $839;
                  $842 = (($1) + 12|0);
                  HEAPF32[$842>>2] = Math_fround(0.0);
                  __ZN5physx2GuL18getIncidentPolygonEPNS_6shdfnd3aos5Vec3VERS3_RKS3_RKNS2_15PsMatTransformVES7_($pts$i,$incidentFaceNormalInNew$i,$1,$transform1ToNew$i,$boxExtents1);
                  __ZN5physx2GuL17calculateContactsERKNS_6shdfnd3aos6FloatVES5_PNS2_5Vec3VERKS6_S9_PNS0_17PersistentContactERjS5_($ea0$i,$ea2$i,$pts$i,$incidentFaceNormalInNew$i,$localNormal47$i,$contactBuffer,$numContacts,$contactDist);
                  $1328 = $748;$1330 = $750;$1332 = $752;$1358 = $246;$1360 = $247;$1363 = $248;$1376 = $759;$1378 = $761;$1381 = $764;$1394 = $767;$1396 = $769;$1399 = $772;
                  break;
                 }
                 default: {
                  $$1$i = 1;
                  break L11;
                 }
                 }
                 if ((label|0) == 45) {
                  $1318 = HEAP32[$numContacts>>2]|0;
                  $1319 = ($1318|0)==(0);
                  if ($1319) {
                   $1328 = $$ph3611$i;$1330 = $$ph3610$i;$1332 = $$ph$i;$1358 = $$ph3620$i;$1360 = $$ph3619$i;$1363 = $$ph3618$i;$1376 = $$ph3617$i;$1378 = $$ph3616$i;$1381 = $$ph3615$i;$1394 = $$ph3614$i;$1396 = $$ph3613$i;$1399 = $$ph3612$i;
                  } else {
                   $i56$03622$i = 0;
                   while(1) {
                    $1320 = ((($contactBuffer) + (($i56$03622$i*48)|0)|0) + 16|0);
                    ;HEAP32[$localB$i+0>>2]=HEAP32[$1320+0>>2]|0;HEAP32[$localB$i+4>>2]=HEAP32[$1320+4>>2]|0;HEAP32[$localB$i+8>>2]=HEAP32[$1320+8>>2]|0;HEAP32[$localB$i+12>>2]=HEAP32[$1320+12>>2]|0;
                    $1321 = (($contactBuffer) + (($i56$03622$i*48)|0)|0);
                    ;HEAP32[$1320+0>>2]=HEAP32[$1321+0>>2]|0;HEAP32[$1320+4>>2]=HEAP32[$1321+4>>2]|0;HEAP32[$1320+8>>2]=HEAP32[$1321+8>>2]|0;HEAP32[$1320+12>>2]=HEAP32[$1321+12>>2]|0;
                    ;HEAP32[$1321+0>>2]=HEAP32[$localB$i+0>>2]|0;HEAP32[$1321+4>>2]=HEAP32[$localB$i+4>>2]|0;HEAP32[$1321+8>>2]=HEAP32[$localB$i+8>>2]|0;HEAP32[$1321+12>>2]=HEAP32[$localB$i+12>>2]|0;
                    $1322 = (($i56$03622$i) + 1)|0;
                    $1323 = ($1322>>>0)<($1318>>>0);
                    if ($1323) {
                     $i56$03622$i = $1322;
                    } else {
                     $1328 = $$ph3611$i;$1330 = $$ph3610$i;$1332 = $$ph$i;$1358 = $$ph3620$i;$1360 = $$ph3619$i;$1363 = $$ph3618$i;$1376 = $$ph3617$i;$1378 = $$ph3616$i;$1381 = $$ph3615$i;$1394 = $$ph3614$i;$1396 = $$ph3613$i;$1399 = $$ph3612$i;
                     break;
                    }
                   }
                  }
                 }
                 $1324 = Math_fround(HEAPF32[$301>>2]);
                 $1325 = Math_fround(HEAPF32[$303>>2]);
                 $1326 = Math_fround(HEAPF32[$305>>2]);
                 $1327 = Math_fround($1328 - $1324);
                 $1329 = Math_fround($1330 - $1325);
                 $1331 = Math_fround($1332 - $1326);
                 $1333 = Math_fround(HEAPF32[$transfV1>>2]);
                 $1334 = Math_fround($1327 * $1333);
                 $1335 = Math_fround(HEAPF32[$284>>2]);
                 $1336 = Math_fround($1329 * $1335);
                 $1337 = Math_fround($1334 + $1336);
                 $1338 = Math_fround(HEAPF32[$285>>2]);
                 $1339 = Math_fround($1331 * $1338);
                 $1340 = Math_fround($1337 + $1339);
                 $1341 = Math_fround(HEAPF32[$287>>2]);
                 $1342 = Math_fround($1327 * $1341);
                 $1343 = Math_fround(HEAPF32[$288>>2]);
                 $1344 = Math_fround($1329 * $1343);
                 $1345 = Math_fround($1342 + $1344);
                 $1346 = Math_fround(HEAPF32[$289>>2]);
                 $1347 = Math_fround($1331 * $1346);
                 $1348 = Math_fround($1345 + $1347);
                 $1349 = Math_fround(HEAPF32[$291>>2]);
                 $1350 = Math_fround($1327 * $1349);
                 $1351 = Math_fround(HEAPF32[$292>>2]);
                 $1352 = Math_fround($1329 * $1351);
                 $1353 = Math_fround($1350 + $1352);
                 $1354 = Math_fround(HEAPF32[$293>>2]);
                 $1355 = Math_fround($1331 * $1354);
                 $1356 = Math_fround($1353 + $1355);
                 $1357 = Math_fround($1358 * $1333);
                 $1359 = Math_fround($1360 * $1335);
                 $1361 = Math_fround($1357 + $1359);
                 $1362 = Math_fround($1363 * $1338);
                 $1364 = Math_fround($1361 + $1362);
                 $1365 = Math_fround($1358 * $1341);
                 $1366 = Math_fround($1360 * $1343);
                 $1367 = Math_fround($1365 + $1366);
                 $1368 = Math_fround($1363 * $1346);
                 $1369 = Math_fround($1367 + $1368);
                 $1370 = Math_fround($1358 * $1349);
                 $1371 = Math_fround($1360 * $1351);
                 $1372 = Math_fround($1370 + $1371);
                 $1373 = Math_fround($1363 * $1354);
                 $1374 = Math_fround($1372 + $1373);
                 $1375 = Math_fround($1376 * $1333);
                 $1377 = Math_fround($1378 * $1335);
                 $1379 = Math_fround($1375 + $1377);
                 $1380 = Math_fround($1381 * $1338);
                 $1382 = Math_fround($1379 + $1380);
                 $1383 = Math_fround($1376 * $1341);
                 $1384 = Math_fround($1378 * $1343);
                 $1385 = Math_fround($1383 + $1384);
                 $1386 = Math_fround($1381 * $1346);
                 $1387 = Math_fround($1385 + $1386);
                 $1388 = Math_fround($1376 * $1349);
                 $1389 = Math_fround($1378 * $1351);
                 $1390 = Math_fround($1388 + $1389);
                 $1391 = Math_fround($1381 * $1354);
                 $1392 = Math_fround($1390 + $1391);
                 $1393 = Math_fround($1394 * $1333);
                 $1395 = Math_fround($1396 * $1335);
                 $1397 = Math_fround($1393 + $1395);
                 $1398 = Math_fround($1399 * $1338);
                 $1400 = Math_fround($1397 + $1398);
                 $1401 = Math_fround($1394 * $1341);
                 $1402 = Math_fround($1396 * $1343);
                 $1403 = Math_fround($1401 + $1402);
                 $1404 = Math_fround($1399 * $1346);
                 $1405 = Math_fround($1403 + $1404);
                 $1406 = Math_fround($1394 * $1349);
                 $1407 = Math_fround($1396 * $1351);
                 $1408 = Math_fround($1406 + $1407);
                 $1409 = Math_fround($1399 * $1354);
                 $1410 = Math_fround($1408 + $1409);
                 $1411 = Math_fround($1328 - $34);
                 $1412 = Math_fround($1330 - $36);
                 $1413 = Math_fround($1332 - $38);
                 $1414 = Math_fround($246 * $1411);
                 $1415 = Math_fround($247 * $1412);
                 $1416 = Math_fround($1415 + $1414);
                 $1417 = Math_fround($248 * $1413);
                 $1418 = Math_fround($1417 + $1416);
                 $1419 = Math_fround($249 * $1411);
                 $1420 = Math_fround($250 * $1412);
                 $1421 = Math_fround($1420 + $1419);
                 $1422 = Math_fround($251 * $1413);
                 $1423 = Math_fround($1422 + $1421);
                 $1424 = Math_fround($252 * $1411);
                 $1425 = Math_fround($253 * $1412);
                 $1426 = Math_fround($1425 + $1424);
                 $1427 = Math_fround($254 * $1413);
                 $1428 = Math_fround($1427 + $1426);
                 $1429 = Math_fround($246 * $1358);
                 $1430 = Math_fround($247 * $1360);
                 $1431 = Math_fround($1430 + $1429);
                 $1432 = Math_fround($248 * $1363);
                 $1433 = Math_fround($1432 + $1431);
                 $1434 = Math_fround($249 * $1358);
                 $1435 = Math_fround($250 * $1360);
                 $1436 = Math_fround($1435 + $1434);
                 $1437 = Math_fround($251 * $1363);
                 $1438 = Math_fround($1437 + $1436);
                 $1439 = Math_fround($252 * $1358);
                 $1440 = Math_fround($253 * $1360);
                 $1441 = Math_fround($1440 + $1439);
                 $1442 = Math_fround($254 * $1363);
                 $1443 = Math_fround($1442 + $1441);
                 $1444 = Math_fround($246 * $1376);
                 $1445 = Math_fround($247 * $1378);
                 $1446 = Math_fround($1445 + $1444);
                 $1447 = Math_fround($248 * $1381);
                 $1448 = Math_fround($1447 + $1446);
                 $1449 = Math_fround($249 * $1376);
                 $1450 = Math_fround($250 * $1378);
                 $1451 = Math_fround($1450 + $1449);
                 $1452 = Math_fround($251 * $1381);
                 $1453 = Math_fround($1452 + $1451);
                 $1454 = Math_fround($252 * $1376);
                 $1455 = Math_fround($253 * $1378);
                 $1456 = Math_fround($1455 + $1454);
                 $1457 = Math_fround($254 * $1381);
                 $1458 = Math_fround($1457 + $1456);
                 $1459 = Math_fround($246 * $1394);
                 $1460 = Math_fround($247 * $1396);
                 $1461 = Math_fround($1460 + $1459);
                 $1462 = Math_fround($248 * $1399);
                 $1463 = Math_fround($1462 + $1461);
                 $1464 = Math_fround($249 * $1394);
                 $1465 = Math_fround($250 * $1396);
                 $1466 = Math_fround($1465 + $1464);
                 $1467 = Math_fround($251 * $1399);
                 $1468 = Math_fround($1467 + $1466);
                 $1469 = Math_fround($252 * $1394);
                 $1470 = Math_fround($253 * $1396);
                 $1471 = Math_fround($1470 + $1469);
                 $1472 = Math_fround($254 * $1399);
                 $1473 = Math_fround($1472 + $1471);
                 $1474 = (($contactBuffer) + 32|0);
                 $1475 = Math_fround(HEAPF32[$1474>>2]);
                 $1476 = (($contactBuffer) + 36|0);
                 $1477 = Math_fround(HEAPF32[$1476>>2]);
                 $1478 = (($contactBuffer) + 40|0);
                 $1479 = Math_fround(HEAPF32[$1478>>2]);
                 $1480 = Math_fround($1364 * $1475);
                 $1481 = Math_fround($1382 * $1477);
                 $1482 = Math_fround($1480 + $1481);
                 $1483 = Math_fround($1400 * $1479);
                 $1484 = Math_fround($1482 + $1483);
                 $1485 = Math_fround($1369 * $1475);
                 $1486 = Math_fround($1387 * $1477);
                 $1487 = Math_fround($1485 + $1486);
                 $1488 = Math_fround($1405 * $1479);
                 $1489 = Math_fround($1487 + $1488);
                 $1490 = Math_fround($1475 * $1374);
                 $1491 = Math_fround($1392 * $1477);
                 $1492 = Math_fround($1490 + $1491);
                 $1493 = Math_fround($1410 * $1479);
                 $1494 = Math_fround($1492 + $1493);
                 $1495 = HEAP32[$numContacts>>2]|0;
                 $1496 = ($1495|0)==(0);
                 if ($1496) {
                  $$1$i = 0;
                 } else {
                  $i57$03609$i = 0;
                  while(1) {
                   $1497 = (($contactBuffer) + (($i57$03609$i*48)|0)|0);
                   $1498 = Math_fround(HEAPF32[$1497>>2]);
                   $1499 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 4|0);
                   $1500 = Math_fround(HEAPF32[$1499>>2]);
                   $1501 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 8|0);
                   $1502 = Math_fround(HEAPF32[$1501>>2]);
                   $1503 = Math_fround($1433 * $1498);
                   $1504 = Math_fround($1448 * $1500);
                   $1505 = Math_fround($1503 + $1504);
                   $1506 = Math_fround($1463 * $1502);
                   $1507 = Math_fround($1505 + $1506);
                   $1508 = Math_fround($1438 * $1498);
                   $1509 = Math_fround($1453 * $1500);
                   $1510 = Math_fround($1508 + $1509);
                   $1511 = Math_fround($1468 * $1502);
                   $1512 = Math_fround($1510 + $1511);
                   $1513 = Math_fround($1443 * $1498);
                   $1514 = Math_fround($1458 * $1500);
                   $1515 = Math_fround($1513 + $1514);
                   $1516 = Math_fround($1473 * $1502);
                   $1517 = Math_fround($1515 + $1516);
                   $1518 = Math_fround($1418 + $1507);
                   $1519 = Math_fround($1423 + $1512);
                   $1520 = Math_fround($1428 + $1517);
                   HEAPF32[$1497>>2] = $1518;
                   HEAPF32[$1499>>2] = $1519;
                   HEAPF32[$1501>>2] = $1520;
                   $1521 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 12|0);
                   HEAPF32[$1521>>2] = Math_fround(0.0);
                   $1522 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 16|0);
                   $1523 = Math_fround(HEAPF32[$1522>>2]);
                   $1524 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 20|0);
                   $1525 = Math_fround(HEAPF32[$1524>>2]);
                   $1526 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 24|0);
                   $1527 = Math_fround(HEAPF32[$1526>>2]);
                   $1528 = Math_fround($1364 * $1523);
                   $1529 = Math_fround($1382 * $1525);
                   $1530 = Math_fround($1528 + $1529);
                   $1531 = Math_fround($1400 * $1527);
                   $1532 = Math_fround($1530 + $1531);
                   $1533 = Math_fround($1369 * $1523);
                   $1534 = Math_fround($1387 * $1525);
                   $1535 = Math_fround($1533 + $1534);
                   $1536 = Math_fround($1405 * $1527);
                   $1537 = Math_fround($1535 + $1536);
                   $1538 = Math_fround($1374 * $1523);
                   $1539 = Math_fround($1392 * $1525);
                   $1540 = Math_fround($1538 + $1539);
                   $1541 = Math_fround($1410 * $1527);
                   $1542 = Math_fround($1540 + $1541);
                   $1543 = Math_fround($1340 + $1532);
                   $1544 = Math_fround($1348 + $1537);
                   $1545 = Math_fround($1356 + $1542);
                   HEAPF32[$1522>>2] = $1543;
                   HEAPF32[$1524>>2] = $1544;
                   HEAPF32[$1526>>2] = $1545;
                   $1546 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 28|0);
                   HEAPF32[$1546>>2] = Math_fround(0.0);
                   $1547 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 32|0);
                   HEAPF32[$1547>>2] = $1484;
                   $1548 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 36|0);
                   HEAPF32[$1548>>2] = $1489;
                   $1549 = ((($contactBuffer) + (($i57$03609$i*48)|0)|0) + 40|0);
                   HEAPF32[$1549>>2] = $1494;
                   $1550 = (($i57$03609$i) + 1)|0;
                   $1551 = ($1550>>>0)<($1495>>>0);
                   if ($1551) {
                    $i57$03609$i = $1550;
                   } else {
                    $$1$i = 0;
                    break;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ($$1$i) {
  $$3 = 0;
  STACKTOP = sp;return ($$3|0);
 }
 $1552 = HEAP32[$numContacts>>2]|0;
 $1553 = ($1552|0)==(0);
 if (!($1553)) {
  __ZN5physx2Gu25PersistentContactManifold24addBatchManifoldContactsEPKNS0_17PersistentContactEj($4,$contactBuffer,$1552);
  $1554 = (($4) + 44|0);
  $1555 = HEAP32[$1554>>2]|0;
  $1556 = (($1555) + 32|0);
  $1557 = Math_fround(HEAPF32[$1556>>2]);
  $1558 = (($1555) + 36|0);
  $1559 = Math_fround(HEAPF32[$1558>>2]);
  $1560 = (($1555) + 40|0);
  $1561 = Math_fround(HEAPF32[$1560>>2]);
  $1562 = Math_fround(HEAPF32[$transfV1>>2]);
  $1563 = Math_fround($1557 * $1562);
  $1564 = Math_fround(HEAPF32[$287>>2]);
  $1565 = Math_fround($1559 * $1564);
  $1566 = Math_fround($1563 + $1565);
  $1567 = Math_fround(HEAPF32[$291>>2]);
  $1568 = Math_fround($1561 * $1567);
  $1569 = Math_fround($1566 + $1568);
  $1570 = Math_fround(HEAPF32[$284>>2]);
  $1571 = Math_fround($1557 * $1570);
  $1572 = Math_fround(HEAPF32[$288>>2]);
  $1573 = Math_fround($1559 * $1572);
  $1574 = Math_fround($1571 + $1573);
  $1575 = Math_fround(HEAPF32[$292>>2]);
  $1576 = Math_fround($1561 * $1575);
  $1577 = Math_fround($1574 + $1576);
  $1578 = Math_fround(HEAPF32[$285>>2]);
  $1579 = Math_fround($1557 * $1578);
  $1580 = Math_fround(HEAPF32[$289>>2]);
  $1581 = Math_fround($1559 * $1580);
  $1582 = Math_fround($1579 + $1581);
  $1583 = Math_fround(HEAPF32[$293>>2]);
  $1584 = Math_fround($1561 * $1583);
  $1585 = Math_fround($1582 + $1584);
  HEAPF32[$worldNormal>>2] = $1569;
  $1586 = (($worldNormal) + 4|0);
  HEAPF32[$1586>>2] = $1577;
  $1587 = (($worldNormal) + 8|0);
  HEAPF32[$1587>>2] = $1585;
  $1588 = (($worldNormal) + 12|0);
  HEAPF32[$1588>>2] = Math_fround(0.0);
  __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_15PsMatTransformVE($4,$contactBuffer,$worldNormal,$transfV1);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
 }
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $1589 = (($eb0$i) + 64|0);
 ;HEAP32[$eb0$i+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$eb0$i+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$eb0$i+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$eb0$i+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $1590 = (($eb0$i) + 80|0);
 HEAP32[$1590>>2] = 3;
 $1591 = (($eb0$i) + 16|0);
 $1592 = (($eb0$i) + 20|0);
 ;HEAP32[$1592+0>>2]=HEAP32[$ea1$i+0>>2]|0;HEAP32[$1592+4>>2]=HEAP32[$ea1$i+4>>2]|0;HEAP32[$1592+8>>2]=HEAP32[$ea1$i+8>>2]|0;
 $1593 = (($eb0$i) + 32|0);
 $1594 = (($eb0$i) + 36|0);
 $1595 = (($eb0$i) + 48|0);
 $1596 = (($eb0$i) + 52|0);
 ;HEAP32[$ea0$i+0>>2]=0|0;HEAP32[$ea0$i+4>>2]=0|0;HEAP32[$ea0$i+8>>2]=0|0;HEAP32[$ea0$i+12>>2]=0|0;
 ;HEAP32[$1589+0>>2]=HEAP32[$ea0$i+0>>2]|0;HEAP32[$1589+4>>2]=HEAP32[$ea0$i+4>>2]|0;HEAP32[$1589+8>>2]=HEAP32[$ea0$i+8>>2]|0;HEAP32[$1589+12>>2]=HEAP32[$ea0$i+12>>2]|0;
 $1597 = (($eb0$i) + 144|0);
 ;HEAP32[$1597+0>>2]=HEAP32[$boxExtents0+0>>2]|0;HEAP32[$1597+4>>2]=HEAP32[$boxExtents0+4>>2]|0;HEAP32[$1597+8>>2]=HEAP32[$boxExtents0+8>>2]|0;HEAP32[$1597+12>>2]=HEAP32[$boxExtents0+12>>2]|0;
 $1598 = Math_fround(HEAPF32[$boxExtents0>>2]);
 $1599 = Math_fround(HEAPF32[$14>>2]);
 $1600 = Math_fround(HEAPF32[$15>>2]);
 $1601 = !($1598 <= $1599);
 $$$i26$i$i$i$i28 = $1601 ? $1599 : $1598;
 $1602 = !($$$i26$i$i$i$i28 <= $1600);
 $1603 = $1602 ? $1600 : $$$i26$i$i$i$i28;
 $1604 = !($1598 >= $1599);
 $$$i23$i$i$i$i29 = $1604 ? $1599 : $1598;
 $1605 = !($$$i23$i$i$i$i29 >= $1600);
 $1606 = $1605 ? $1600 : $$$i23$i$i$i$i29;
 $1607 = Math_fround($1603 * Math_fround(0.150000005960464477539));
 $1608 = Math_fround($1606 * Math_fround(0.0299999993294477462769));
 $1609 = $1607 > $1608;
 $$$i12$i$i$i$i30 = $1609 ? $1607 : $1608;
 $1610 = $1603 > $$$i12$i$i$i$i30;
 $$$i$i$i$i$i31 = $1610 ? $$$i12$i$i$i$i30 : $1603;
 HEAPF32[$1591>>2] = $$$i$i$i$i$i31;
 ;HEAP32[$1592+0>>2]=HEAP32[$ea1$i+0>>2]|0;HEAP32[$1592+4>>2]=HEAP32[$ea1$i+4>>2]|0;HEAP32[$1592+8>>2]=HEAP32[$ea1$i+8>>2]|0;
 $1611 = Math_fround($1603 * Math_fround(0.0500000007450580596924));
 HEAPF32[$1593>>2] = $1611;
 ;HEAP32[$1594+0>>2]=HEAP32[$ea0$i+0>>2]|0;HEAP32[$1594+4>>2]=HEAP32[$ea0$i+4>>2]|0;HEAP32[$1594+8>>2]=HEAP32[$ea0$i+8>>2]|0;
 $1612 = Math_fround($$$i$i$i$i$i31 * $$$i$i$i$i$i31);
 $1613 = Math_fround($1612 + $1612);
 $1614 = Math_fround($1612 + $1613);
 $1615 = (Math_fround(Math_sqrt((Math_fround($1614)))));
 $1616 = Math_fround($1615 - $$$i$i$i$i$i31);
 HEAPF32[$1595>>2] = $1616;
 ;HEAP32[$1596+0>>2]=HEAP32[$ea2$i+0>>2]|0;HEAP32[$1596+4>>2]=HEAP32[$ea2$i+4>>2]|0;HEAP32[$1596+8>>2]=HEAP32[$ea2$i+8>>2]|0;
 $1617 = (($eb1$i) + 64|0);
 ;HEAP32[$eb1$i+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$eb1$i+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$eb1$i+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$eb1$i+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $1618 = (($eb1$i) + 80|0);
 HEAP32[$1618>>2] = 3;
 $1619 = (($eb1$i) + 16|0);
 $1620 = (($eb1$i) + 20|0);
 ;HEAP32[$1620+0>>2]=HEAP32[$ea1$i+0>>2]|0;HEAP32[$1620+4>>2]=HEAP32[$ea1$i+4>>2]|0;HEAP32[$1620+8>>2]=HEAP32[$ea1$i+8>>2]|0;
 $1621 = (($eb1$i) + 32|0);
 $1622 = (($eb1$i) + 36|0);
 $1623 = (($eb1$i) + 48|0);
 $1624 = (($eb1$i) + 52|0);
 ;HEAP32[$ea0$i+0>>2]=0|0;HEAP32[$ea0$i+4>>2]=0|0;HEAP32[$ea0$i+8>>2]=0|0;HEAP32[$ea0$i+12>>2]=0|0;
 ;HEAP32[$1617+0>>2]=HEAP32[$ea0$i+0>>2]|0;HEAP32[$1617+4>>2]=HEAP32[$ea0$i+4>>2]|0;HEAP32[$1617+8>>2]=HEAP32[$ea0$i+8>>2]|0;HEAP32[$1617+12>>2]=HEAP32[$ea0$i+12>>2]|0;
 $1625 = (($eb1$i) + 144|0);
 ;HEAP32[$1625+0>>2]=HEAP32[$boxExtents1+0>>2]|0;HEAP32[$1625+4>>2]=HEAP32[$boxExtents1+4>>2]|0;HEAP32[$1625+8>>2]=HEAP32[$boxExtents1+8>>2]|0;HEAP32[$1625+12>>2]=HEAP32[$boxExtents1+12>>2]|0;
 $1626 = Math_fround(HEAPF32[$boxExtents1>>2]);
 $1627 = Math_fround(HEAPF32[$23>>2]);
 $1628 = Math_fround(HEAPF32[$24>>2]);
 $1629 = !($1626 <= $1627);
 $$$i26$i$i$i$i = $1629 ? $1627 : $1626;
 $1630 = !($$$i26$i$i$i$i <= $1628);
 $1631 = $1630 ? $1628 : $$$i26$i$i$i$i;
 $1632 = !($1626 >= $1627);
 $$$i23$i$i$i$i = $1632 ? $1627 : $1626;
 $1633 = !($$$i23$i$i$i$i >= $1628);
 $1634 = $1633 ? $1628 : $$$i23$i$i$i$i;
 $1635 = Math_fround($1631 * Math_fround(0.150000005960464477539));
 $1636 = Math_fround($1634 * Math_fround(0.0299999993294477462769));
 $1637 = $1635 > $1636;
 $$$i12$i$i$i$i = $1637 ? $1635 : $1636;
 $1638 = $1631 > $$$i12$i$i$i$i;
 $$$i$i$i$i$i = $1638 ? $$$i12$i$i$i$i : $1631;
 HEAPF32[$1619>>2] = $$$i$i$i$i$i;
 ;HEAP32[$1620+0>>2]=HEAP32[$ea1$i+0>>2]|0;HEAP32[$1620+4>>2]=HEAP32[$ea1$i+4>>2]|0;HEAP32[$1620+8>>2]=HEAP32[$ea1$i+8>>2]|0;
 $1639 = Math_fround($1631 * Math_fround(0.0500000007450580596924));
 HEAPF32[$1621>>2] = $1639;
 ;HEAP32[$1622+0>>2]=HEAP32[$ea0$i+0>>2]|0;HEAP32[$1622+4>>2]=HEAP32[$ea0$i+4>>2]|0;HEAP32[$1622+8>>2]=HEAP32[$ea0$i+8>>2]|0;
 $1640 = Math_fround($$$i$i$i$i$i * $$$i$i$i$i$i);
 $1641 = Math_fround($1640 + $1640);
 $1642 = Math_fround($1640 + $1641);
 $1643 = (Math_fround(Math_sqrt((Math_fround($1642)))));
 $1644 = Math_fround($1643 - $$$i$i$i$i$i);
 HEAPF32[$1623>>2] = $1644;
 ;HEAP32[$1624+0>>2]=HEAP32[$ea2$i+0>>2]|0;HEAP32[$1624+4>>2]=HEAP32[$ea2$i+4>>2]|0;HEAP32[$1624+8>>2]=HEAP32[$ea2$i+8>>2]|0;
 ;HEAP32[$closestA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closestB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penDep>>2] = Math_fround(0.0);
 $1645 = (($4) + 33|0);
 HEAP8[$1645>>0] = 0;
 $1646 = (($4) + 34|0);
 $1647 = (($4) + 38|0);
 $1648 = (__ZN5physx2Gu22GJKRelativePenetrationERKNS0_10ShrunkBoxVES3_RKNS_6shdfnd3aos15PsMatTransformVERKNS5_6FloatVERNS5_5Vec3VESD_SD_RS9_PhSF_Rh($eb0$i,$eb1$i,$aToB,$contactDist,$closestA,$closestB,$normal,$penDep,$1646,$1647,$1645)|0);
 $1649 = ($1648|0)==(6);
 if ($1649) {
  $1650 = (__ZN5physx2Gu22EPARelativePenetrationERKNS0_4BoxVES3_RKNS_6shdfnd3aos15PsMatTransformVERNS5_5Vec3VESA_SA_RNS5_6FloatVEPhSD_Rhb($eb0$i,$eb1$i,$aToB,$closestA,$closestB,$normal,$penDep,$1646,$1647,$1645,0)|0);
  $1651 = ($1650|0)==(6);
  if ($1651) {
   $1652 = Math_fround(HEAPF32[$closestB>>2]);
   $1653 = (($closestB) + 4|0);
   $1654 = Math_fround(HEAPF32[$1653>>2]);
   $1655 = (($closestB) + 8|0);
   $1656 = Math_fround(HEAPF32[$1655>>2]);
   $1657 = Math_fround(HEAPF32[$closestA>>2]);
   $1658 = (($closestA) + 4|0);
   $1659 = Math_fround(HEAPF32[$1658>>2]);
   $1660 = (($closestA) + 8|0);
   $1661 = Math_fround(HEAPF32[$1660>>2]);
   $1662 = Math_fround($1652 - $1657);
   $1663 = Math_fround($1654 - $1659);
   $1664 = Math_fround($1656 - $1661);
   $1665 = Math_fround($1662 * $1662);
   $1666 = Math_fround($1663 * $1663);
   $1667 = Math_fround($1665 + $1666);
   $1668 = Math_fround($1664 * $1664);
   $1669 = Math_fround($1667 + $1668);
   $1670 = (Math_fround(Math_sqrt((Math_fround($1669)))));
   $1671 = Math_fround(Math_fround(1.0) / $1670);
   $1672 = Math_fround($1662 * $1671);
   $1673 = Math_fround($1663 * $1671);
   $1674 = Math_fround($1664 * $1671);
   HEAPF32[$normal>>2] = $1672;
   $1675 = (($normal) + 4|0);
   HEAPF32[$1675>>2] = $1673;
   $1676 = (($normal) + 8|0);
   HEAPF32[$1676>>2] = $1674;
   $1677 = (($normal) + 12|0);
   HEAPF32[$1677>>2] = Math_fround(0.0);
   $1678 = Math_fround(-$1670);
   HEAPF32[$penDep>>2] = $1678;
   $1679 = (($penDep) + 4|0);
   ;HEAP32[$1679+0>>2]=HEAP32[$$sroa$151+0>>2]|0;HEAP32[$1679+4>>2]=HEAP32[$$sroa$151+4>>2]|0;HEAP32[$1679+8>>2]=HEAP32[$$sroa$151+8>>2]|0;
   $$pre$phiZ2D = $1677;$1686 = $1657;$1688 = $1659;$1690 = $1661;$1720 = $1672;$1722 = $1673;$1724 = $1674;$1726 = $1678;
  } else {
   $status$0 = $1650;
   label = 55;
  }
 } else {
  $status$0 = $1648;
  label = 55;
 }
 do {
  if ((label|0) == 55) {
   $1680 = ($status$0|0)==(1);
   if ($1680) {
    $$pre = Math_fround(HEAPF32[$closestA>>2]);
    $$phi$trans$insert153 = (($closestA) + 4|0);
    $$pre154 = Math_fround(HEAPF32[$$phi$trans$insert153>>2]);
    $$phi$trans$insert155 = (($closestA) + 8|0);
    $$pre156 = Math_fround(HEAPF32[$$phi$trans$insert155>>2]);
    $$pre158 = Math_fround(HEAPF32[$normal>>2]);
    $$phi$trans$insert159 = (($normal) + 4|0);
    $$pre160 = Math_fround(HEAPF32[$$phi$trans$insert159>>2]);
    $$phi$trans$insert161 = (($normal) + 8|0);
    $$pre162 = Math_fround(HEAPF32[$$phi$trans$insert161>>2]);
    $$pre163 = Math_fround(HEAPF32[$penDep>>2]);
    $$pre164 = (($normal) + 12|0);
    $$pre$phiZ2D = $$pre164;$1686 = $$pre;$1688 = $$pre154;$1690 = $$pre156;$1720 = $$pre158;$1722 = $$pre160;$1724 = $$pre162;$1726 = $$pre163;
    break;
   } else {
    $$3 = 0;
    STACKTOP = sp;return ($$3|0);
   }
  }
 } while(0);
 $1681 = Math_fround($$$i * Math_fround(0.0500000007450580596924));
 HEAPF32[$replaceBreakingThreshold>>2] = $1681;
 $1682 = Math_fround(HEAPF32[$127>>2]);
 $1683 = Math_fround(HEAPF32[$128>>2]);
 $1684 = Math_fround(HEAPF32[$129>>2]);
 $1685 = Math_fround($1686 - $1682);
 $1687 = Math_fround($1688 - $1683);
 $1689 = Math_fround($1690 - $1684);
 $1691 = Math_fround(HEAPF32[$aToB>>2]);
 $1692 = Math_fround($1685 * $1691);
 $1693 = Math_fround(HEAPF32[$154>>2]);
 $1694 = Math_fround($1687 * $1693);
 $1695 = Math_fround($1692 + $1694);
 $1696 = Math_fround(HEAPF32[$155>>2]);
 $1697 = Math_fround($1689 * $1696);
 $1698 = Math_fround($1695 + $1697);
 $1699 = Math_fround(HEAPF32[$157>>2]);
 $1700 = Math_fround($1685 * $1699);
 $1701 = Math_fround(HEAPF32[$158>>2]);
 $1702 = Math_fround($1687 * $1701);
 $1703 = Math_fround($1700 + $1702);
 $1704 = Math_fround(HEAPF32[$159>>2]);
 $1705 = Math_fround($1689 * $1704);
 $1706 = Math_fround($1703 + $1705);
 $1707 = Math_fround(HEAPF32[$161>>2]);
 $1708 = Math_fround($1685 * $1707);
 $1709 = Math_fround(HEAPF32[$162>>2]);
 $1710 = Math_fround($1687 * $1709);
 $1711 = Math_fround($1708 + $1710);
 $1712 = Math_fround(HEAPF32[$163>>2]);
 $1713 = Math_fround($1689 * $1712);
 $1714 = Math_fround($1711 + $1713);
 HEAPF32[$localPointA>>2] = $1698;
 $1715 = (($localPointA) + 4|0);
 HEAPF32[$1715>>2] = $1706;
 $1716 = (($localPointA) + 8|0);
 HEAPF32[$1716>>2] = $1714;
 $1717 = (($localPointA) + 12|0);
 HEAPF32[$1717>>2] = Math_fround(0.0);
 ;HEAP32[$localPointB+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$localPointB+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$localPointB+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$localPointB+12>>2]=HEAP32[$closestB+12>>2]|0;
 $1718 = (($normal) + 4|0);
 $1719 = (($normal) + 8|0);
 HEAPF32[$localNormalPen>>2] = $1720;
 $1721 = (($localNormalPen) + 4|0);
 HEAPF32[$1721>>2] = $1722;
 $1723 = (($localNormalPen) + 8|0);
 HEAPF32[$1723>>2] = $1724;
 $1725 = (($localNormalPen) + 12|0);
 HEAPF32[$1725>>2] = $1726;
 $1727 = (__ZN5physx2Gu25PersistentContactManifold16addManifoldPointERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($4,$localPointA,$localPointB,$localNormalPen,$replaceBreakingThreshold)|0);
 $1728 = HEAP32[$numContacts>>2]|0;
 $1729 = (($1728) + ($1727))|0;
 HEAP32[$numContacts>>2] = $1729;
 $1730 = Math_fround(HEAPF32[$transf1>>2]);
 $1731 = Math_fround(HEAPF32[$52>>2]);
 $1732 = Math_fround(HEAPF32[$53>>2]);
 $1733 = Math_fround(HEAPF32[$54>>2]);
 $1734 = Math_fround(HEAPF32[$normal>>2]);
 $1735 = Math_fround(HEAPF32[$1718>>2]);
 $1736 = Math_fround(HEAPF32[$1719>>2]);
 $1737 = Math_fround($1733 * $1733);
 $1738 = Math_fround($1737 + Math_fround(-0.5));
 $1739 = Math_fround($1734 * $1738);
 $1740 = Math_fround($1738 * $1735);
 $1741 = Math_fround($1738 * $1736);
 $1742 = Math_fround($1731 * $1736);
 $1743 = Math_fround($1732 * $1735);
 $1744 = Math_fround($1742 - $1743);
 $1745 = Math_fround($1732 * $1734);
 $1746 = Math_fround($1730 * $1736);
 $1747 = Math_fround($1745 - $1746);
 $1748 = Math_fround($1730 * $1735);
 $1749 = Math_fround($1731 * $1734);
 $1750 = Math_fround($1748 - $1749);
 $1751 = Math_fround($1733 * $1744);
 $1752 = Math_fround($1733 * $1747);
 $1753 = Math_fround($1733 * $1750);
 $1754 = Math_fround($1739 + $1751);
 $1755 = Math_fround($1740 + $1752);
 $1756 = Math_fround($1741 + $1753);
 $1757 = Math_fround($1730 * $1734);
 $1758 = Math_fround($1731 * $1735);
 $1759 = Math_fround($1757 + $1758);
 $1760 = Math_fround($1732 * $1736);
 $1761 = Math_fround($1759 + $1760);
 $1762 = Math_fround($1730 * $1761);
 $1763 = Math_fround($1731 * $1761);
 $1764 = Math_fround($1732 * $1761);
 $1765 = Math_fround($1762 + $1754);
 $1766 = Math_fround($1763 + $1755);
 $1767 = Math_fround($1756 + $1764);
 $1768 = Math_fround($1765 * Math_fround(2.0));
 $1769 = Math_fround($1766 * Math_fround(2.0));
 $1770 = Math_fround($1767 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $1768;
 HEAPF32[$1718>>2] = $1769;
 HEAPF32[$1719>>2] = $1770;
 HEAPF32[$$pre$phiZ2D>>2] = Math_fround(0.0);
 __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($4,$contactBuffer,$normal,$transf1);
 $$3 = 1;
 STACKTOP = sp;return ($$3|0);
}
function __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($this,$aToB,$projectBreakingThreshold,$0) {
 $this = $this|0;
 $aToB = $aToB|0;
 $projectBreakingThreshold = $projectBreakingThreshold|0;
 $0 = $0|0;
 var $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $i$0174 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $1 = Math_fround(HEAPF32[$projectBreakingThreshold>>2]);
 $2 = Math_fround($1 * $1);
 $3 = (($this) + 32|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = $4&255;
 $7 = (($this) + 44|0);
 $8 = (($aToB) + 48|0);
 $9 = (($aToB) + 52|0);
 $10 = (($aToB) + 56|0);
 $11 = (($aToB) + 16|0);
 $12 = (($aToB) + 32|0);
 $13 = (($aToB) + 4|0);
 $14 = (($aToB) + 20|0);
 $15 = (($aToB) + 36|0);
 $16 = (($aToB) + 8|0);
 $17 = (($aToB) + 24|0);
 $18 = (($aToB) + 40|0);
 $i$0174 = $6;
 while(1) {
  $19 = (($i$0174) + -1)|0;
  $20 = HEAP32[$7>>2]|0;
  $21 = Math_fround(HEAPF32[$8>>2]);
  $22 = Math_fround(HEAPF32[$9>>2]);
  $23 = Math_fround(HEAPF32[$10>>2]);
  $24 = (($20) + (($19*48)|0)|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($20) + (($19*48)|0)|0) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = ((($20) + (($19*48)|0)|0) + 8|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround(HEAPF32[$aToB>>2]);
  $31 = Math_fround($25 * $30);
  $32 = Math_fround(HEAPF32[$11>>2]);
  $33 = Math_fround($27 * $32);
  $34 = Math_fround($31 + $33);
  $35 = Math_fround(HEAPF32[$12>>2]);
  $36 = Math_fround($29 * $35);
  $37 = Math_fround($34 + $36);
  $38 = Math_fround(HEAPF32[$13>>2]);
  $39 = Math_fround($25 * $38);
  $40 = Math_fround(HEAPF32[$14>>2]);
  $41 = Math_fround($27 * $40);
  $42 = Math_fround($39 + $41);
  $43 = Math_fround(HEAPF32[$15>>2]);
  $44 = Math_fround($29 * $43);
  $45 = Math_fround($42 + $44);
  $46 = Math_fround(HEAPF32[$16>>2]);
  $47 = Math_fround($25 * $46);
  $48 = Math_fround(HEAPF32[$17>>2]);
  $49 = Math_fround($27 * $48);
  $50 = Math_fround($47 + $49);
  $51 = Math_fround(HEAPF32[$18>>2]);
  $52 = Math_fround($29 * $51);
  $53 = Math_fround($50 + $52);
  $54 = Math_fround($21 + $37);
  $55 = Math_fround($22 + $45);
  $56 = Math_fround($23 + $53);
  $57 = ((($20) + (($19*48)|0)|0) + 16|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = ((($20) + (($19*48)|0)|0) + 20|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = ((($20) + (($19*48)|0)|0) + 24|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = Math_fround($54 - $58);
  $64 = Math_fround($55 - $60);
  $65 = Math_fround($56 - $62);
  $66 = ((($20) + (($19*48)|0)|0) + 32|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($20) + (($19*48)|0)|0) + 36|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = ((($20) + (($19*48)|0)|0) + 40|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = Math_fround($63 * $67);
  $73 = Math_fround($64 * $69);
  $74 = Math_fround($72 + $73);
  $75 = Math_fround($65 * $71);
  $76 = Math_fround($74 + $75);
  $77 = Math_fround($67 * $76);
  $78 = Math_fround($69 * $76);
  $79 = Math_fround($71 * $76);
  $80 = Math_fround($54 - $77);
  $81 = Math_fround($55 - $78);
  $82 = Math_fround($56 - $79);
  $83 = Math_fround($58 - $80);
  $84 = Math_fround($60 - $81);
  $85 = Math_fround($62 - $82);
  $86 = Math_fround($83 * $83);
  $87 = Math_fround($84 * $84);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround($85 * $85);
  $90 = Math_fround($89 + $88);
  $91 = $90 > $2;
  if ($91) {
   $92 = HEAP8[$3>>0]|0;
   $93 = (($92) + -1)<<24>>24;
   HEAP8[$3>>0] = $93;
   $94 = (($20) + (($19*48)|0)|0);
   $95 = $93&255;
   $96 = (($20) + (($95*48)|0)|0);
   dest=$94+0|0; src=$96+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  } else {
   $98 = ((($20) + (($19*48)|0)|0) + 44|0);
   HEAPF32[$66>>2] = $67;
   HEAPF32[$68>>2] = $69;
   HEAPF32[$70>>2] = $71;
   HEAPF32[$98>>2] = $76;
  }
  $97 = ($19|0)==(0);
  if ($97) {
   break;
  } else {
   $i$0174 = $19;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($agg$result,$this,$trB) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $trB = $trB|0;
 var $$lcssa = Math_fround(0), $$lcssa40 = Math_fround(0), $$lcssa41 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, $i$042 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 36|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 40|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 32|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9&255)>(1);
 if ($10) {
  $11 = $9&255;
  $19 = $3;$21 = $5;$23 = $7;$i$042 = 1;
  while(1) {
   $12 = ((($1) + (($i$042*48)|0)|0) + 32|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = ((($1) + (($i$042*48)|0)|0) + 36|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = ((($1) + (($i$042*48)|0)|0) + 40|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround($19 + $13);
   $20 = Math_fround($21 + $15);
   $22 = Math_fround($23 + $17);
   $24 = (($i$042) + 1)|0;
   $25 = ($24>>>0)<($11>>>0);
   if ($25) {
    $19 = $18;$21 = $20;$23 = $22;$i$042 = $24;
   } else {
    $$lcssa = $22;$$lcssa40 = $20;$$lcssa41 = $18;
    break;
   }
  }
 } else {
  $$lcssa = $7;$$lcssa40 = $5;$$lcssa41 = $3;
 }
 $26 = Math_fround(HEAPF32[$trB>>2]);
 $27 = (($trB) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($trB) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($trB) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $32);
 $34 = Math_fround($33 + Math_fround(-0.5));
 $35 = Math_fround($$lcssa41 * $34);
 $36 = Math_fround($$lcssa40 * $34);
 $37 = Math_fround($$lcssa * $34);
 $38 = Math_fround($$lcssa * $28);
 $39 = Math_fround($$lcssa40 * $30);
 $40 = Math_fround($38 - $39);
 $41 = Math_fround($$lcssa41 * $30);
 $42 = Math_fround($$lcssa * $26);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($$lcssa40 * $26);
 $45 = Math_fround($$lcssa41 * $28);
 $46 = Math_fround($44 - $45);
 $47 = Math_fround($32 * $40);
 $48 = Math_fround($32 * $43);
 $49 = Math_fround($32 * $46);
 $50 = Math_fround($47 + $35);
 $51 = Math_fround($48 + $36);
 $52 = Math_fround($49 + $37);
 $53 = Math_fround($$lcssa41 * $26);
 $54 = Math_fround($$lcssa40 * $28);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($$lcssa * $30);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($26 * $57);
 $59 = Math_fround($28 * $57);
 $60 = Math_fround($30 * $57);
 $61 = Math_fround($58 + $50);
 $62 = Math_fround($59 + $51);
 $63 = Math_fround($60 + $52);
 $64 = Math_fround($61 * Math_fround(2.0));
 $65 = Math_fround($62 * Math_fround(2.0));
 $66 = Math_fround($63 * Math_fround(2.0));
 $67 = Math_fround($64 * $64);
 $68 = Math_fround($65 * $65);
 $69 = Math_fround($67 + $68);
 $70 = Math_fround($66 * $66);
 $71 = Math_fround($70 + $69);
 $72 = (Math_fround(Math_sqrt((Math_fround($71)))));
 $73 = Math_fround(Math_fround(1.0) / $72);
 $74 = Math_fround($73 * $64);
 $75 = Math_fround($73 * $65);
 $76 = Math_fround($73 * $66);
 HEAPF32[$agg$result>>2] = $74;
 $77 = (($agg$result) + 4|0);
 HEAPF32[$77>>2] = $75;
 $78 = (($agg$result) + 8|0);
 HEAPF32[$78>>2] = $76;
 $79 = (($agg$result) + 12|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2GuL18getIncidentPolygonEPNS_6shdfnd3aos5Vec3VERS3_RKS3_RKNS2_15PsMatTransformVES7_($pts,$faceNormal,$axis,$transf1To0,$extents) {
 $pts = $pts|0;
 $faceNormal = $faceNormal|0;
 $axis = $axis|0;
 $transf1To0 = $transf1To0|0;
 $extents = $extents|0;
 var $$in1$i = 0, $$in1$i121 = 0, $$in1$i189 = 0, $$in2$i = 0, $$in2$i123 = 0, $$in2$i191 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0);
 var $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0;
 var $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $b$a$i118 = 0, $b$a$i186 = 0, $b$a$i54 = 0, $fabsf$i$i$i = Math_fround(0), $fabsf$i$i$i204 = Math_fround(0), $fabsf$i$i$i209 = Math_fround(0), $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = sp + 48|0;
 $5 = sp + 64|0;
 $6 = Math_fround(HEAPF32[$extents>>2]);
 $7 = (($extents) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($extents) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$transf1To0>>2]);
 $12 = (($transf1To0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($transf1To0) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($transf1To0) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($transf1To0) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($transf1To0) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transf1To0) + 28|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($transf1To0) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($transf1To0) + 36|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($transf1To0) + 40|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($transf1To0) + 44|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(HEAPF32[$axis>>2]);
 $33 = (($axis) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($axis) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($11 * $32);
 $38 = Math_fround($13 * $34);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($15 * $36);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($17 * $32);
 $43 = Math_fround($19 * $34);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($21 * $36);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($25 * $32);
 $48 = Math_fround($27 * $34);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($29 * $36);
 $51 = Math_fround($49 + $50);
 $fabsf$i$i$i209 = (Math_fround(Math_abs((Math_fround($41)))));
 $fabsf$i$i$i204 = (Math_fround(Math_abs((Math_fround($46)))));
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($51)))));
 $52 = !($fabsf$i$i$i209 >= $fabsf$i$i$i204);
 $53 = !($fabsf$i$i$i209 >= $fabsf$i$i$i);
 $or$cond = $52 | $53;
 if (!($or$cond)) {
  $54 = (($transf1To0) + 12|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = $41 > Math_fround(0.0);
  $57 = Math_fround(-$11);
  $58 = Math_fround(-$13);
  $59 = Math_fround(-$15);
  HEAPF32[$1>>2] = $57;
  $60 = (($1) + 4|0);
  HEAPF32[$60>>2] = $58;
  $61 = (($1) + 8|0);
  HEAPF32[$61>>2] = $59;
  $62 = (($1) + 12|0);
  HEAPF32[$62>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = $11;
  $63 = (($0) + 4|0);
  HEAPF32[$63>>2] = $13;
  $64 = (($0) + 8|0);
  HEAPF32[$64>>2] = $15;
  $65 = (($0) + 12|0);
  HEAPF32[$65>>2] = $55;
  $b$a$i186 = $56 ? $1 : $0;
  $66 = Math_fround(HEAPF32[$b$a$i186>>2]);
  $$in1$i189 = (($b$a$i186) + 4|0);
  $67 = Math_fround(HEAPF32[$$in1$i189>>2]);
  $$in2$i191 = (($b$a$i186) + 8|0);
  $68 = Math_fround(HEAPF32[$$in2$i191>>2]);
  HEAPF32[$faceNormal>>2] = $66;
  $69 = (($faceNormal) + 4|0);
  HEAPF32[$69>>2] = $67;
  $70 = (($faceNormal) + 8|0);
  HEAPF32[$70>>2] = $68;
  $71 = (($faceNormal) + 12|0);
  HEAPF32[$71>>2] = Math_fround(0.0);
  $72 = Math_fround(-$6);
  $73 = $56 ? $72 : $6;
  $74 = Math_fround($11 * $73);
  $75 = Math_fround($13 * $73);
  $76 = Math_fround($15 * $73);
  $77 = Math_fround($8 * $17);
  $78 = Math_fround($8 * $19);
  $79 = Math_fround($8 * $21);
  $80 = Math_fround($10 * $25);
  $81 = Math_fround($10 * $27);
  $82 = Math_fround($10 * $29);
  $83 = (($transf1To0) + 48|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = (($transf1To0) + 52|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = (($transf1To0) + 56|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($74 + $84);
  $90 = Math_fround($75 + $86);
  $91 = Math_fround($76 + $88);
  $92 = Math_fround($77 + $80);
  $93 = Math_fround($78 + $81);
  $94 = Math_fround($79 + $82);
  $95 = Math_fround($77 - $80);
  $96 = Math_fround($78 - $81);
  $97 = Math_fround($79 - $82);
  $98 = Math_fround($92 + $89);
  $99 = Math_fround($93 + $90);
  $100 = Math_fround($94 + $91);
  HEAPF32[$pts>>2] = $98;
  $101 = (($pts) + 4|0);
  HEAPF32[$101>>2] = $99;
  $102 = (($pts) + 8|0);
  HEAPF32[$102>>2] = $100;
  $103 = (($pts) + 12|0);
  HEAPF32[$103>>2] = Math_fround(0.0);
  $104 = Math_fround($95 + $89);
  $105 = Math_fround($96 + $90);
  $106 = Math_fround($97 + $91);
  $107 = (($pts) + 16|0);
  HEAPF32[$107>>2] = $104;
  $108 = (($pts) + 20|0);
  HEAPF32[$108>>2] = $105;
  $109 = (($pts) + 24|0);
  HEAPF32[$109>>2] = $106;
  $110 = (($pts) + 28|0);
  HEAPF32[$110>>2] = Math_fround(0.0);
  $111 = Math_fround($89 - $92);
  $112 = Math_fround($90 - $93);
  $113 = Math_fround($91 - $94);
  $114 = (($pts) + 32|0);
  HEAPF32[$114>>2] = $111;
  $115 = (($pts) + 36|0);
  HEAPF32[$115>>2] = $112;
  $116 = (($pts) + 40|0);
  HEAPF32[$116>>2] = $113;
  $117 = (($pts) + 44|0);
  HEAPF32[$117>>2] = Math_fround(0.0);
  $118 = Math_fround($89 - $95);
  $119 = Math_fround($90 - $96);
  $120 = Math_fround($91 - $97);
  $121 = (($pts) + 48|0);
  HEAPF32[$121>>2] = $118;
  $122 = (($pts) + 52|0);
  HEAPF32[$122>>2] = $119;
  $123 = (($pts) + 56|0);
  HEAPF32[$123>>2] = $120;
  $124 = (($pts) + 60|0);
  HEAPF32[$124>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $125 = !($fabsf$i$i$i204 >= $fabsf$i$i$i);
 if ($125) {
  $195 = $51 > Math_fround(0.0);
  $196 = Math_fround(-$25);
  $197 = Math_fround(-$27);
  $198 = Math_fround(-$29);
  HEAPF32[$5>>2] = $196;
  $199 = (($5) + 4|0);
  HEAPF32[$199>>2] = $197;
  $200 = (($5) + 8|0);
  HEAPF32[$200>>2] = $198;
  $201 = (($5) + 12|0);
  HEAPF32[$201>>2] = Math_fround(0.0);
  HEAPF32[$4>>2] = $25;
  $202 = (($4) + 4|0);
  HEAPF32[$202>>2] = $27;
  $203 = (($4) + 8|0);
  HEAPF32[$203>>2] = $29;
  $204 = (($4) + 12|0);
  HEAPF32[$204>>2] = $31;
  $b$a$i54 = $195 ? $5 : $4;
  $205 = Math_fround(HEAPF32[$b$a$i54>>2]);
  $$in1$i = (($b$a$i54) + 4|0);
  $206 = Math_fround(HEAPF32[$$in1$i>>2]);
  $$in2$i = (($b$a$i54) + 8|0);
  $207 = Math_fround(HEAPF32[$$in2$i>>2]);
  HEAPF32[$faceNormal>>2] = $205;
  $208 = (($faceNormal) + 4|0);
  HEAPF32[$208>>2] = $206;
  $209 = (($faceNormal) + 8|0);
  HEAPF32[$209>>2] = $207;
  $210 = (($faceNormal) + 12|0);
  HEAPF32[$210>>2] = Math_fround(0.0);
  $211 = Math_fround(-$10);
  $212 = $195 ? $211 : $10;
  $213 = Math_fround($6 * $11);
  $214 = Math_fround($6 * $13);
  $215 = Math_fround($6 * $15);
  $216 = Math_fround($8 * $17);
  $217 = Math_fround($8 * $19);
  $218 = Math_fround($8 * $21);
  $219 = Math_fround($25 * $212);
  $220 = Math_fround($27 * $212);
  $221 = Math_fround($29 * $212);
  $222 = (($transf1To0) + 48|0);
  $223 = Math_fround(HEAPF32[$222>>2]);
  $224 = (($transf1To0) + 52|0);
  $225 = Math_fround(HEAPF32[$224>>2]);
  $226 = (($transf1To0) + 56|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = Math_fround($219 + $223);
  $229 = Math_fround($220 + $225);
  $230 = Math_fround($221 + $227);
  $231 = Math_fround($213 + $216);
  $232 = Math_fround($214 + $217);
  $233 = Math_fround($215 + $218);
  $234 = Math_fround($213 - $216);
  $235 = Math_fround($214 - $217);
  $236 = Math_fround($215 - $218);
  $237 = Math_fround($231 + $228);
  $238 = Math_fround($232 + $229);
  $239 = Math_fround($233 + $230);
  HEAPF32[$pts>>2] = $237;
  $240 = (($pts) + 4|0);
  HEAPF32[$240>>2] = $238;
  $241 = (($pts) + 8|0);
  HEAPF32[$241>>2] = $239;
  $242 = (($pts) + 12|0);
  HEAPF32[$242>>2] = Math_fround(0.0);
  $243 = Math_fround($234 + $228);
  $244 = Math_fround($235 + $229);
  $245 = Math_fround($236 + $230);
  $246 = (($pts) + 16|0);
  HEAPF32[$246>>2] = $243;
  $247 = (($pts) + 20|0);
  HEAPF32[$247>>2] = $244;
  $248 = (($pts) + 24|0);
  HEAPF32[$248>>2] = $245;
  $249 = (($pts) + 28|0);
  HEAPF32[$249>>2] = Math_fround(0.0);
  $250 = Math_fround($228 - $231);
  $251 = Math_fround($229 - $232);
  $252 = Math_fround($230 - $233);
  $253 = (($pts) + 32|0);
  HEAPF32[$253>>2] = $250;
  $254 = (($pts) + 36|0);
  HEAPF32[$254>>2] = $251;
  $255 = (($pts) + 40|0);
  HEAPF32[$255>>2] = $252;
  $256 = (($pts) + 44|0);
  HEAPF32[$256>>2] = Math_fround(0.0);
  $257 = Math_fround($228 - $234);
  $258 = Math_fround($229 - $235);
  $259 = Math_fround($230 - $236);
  $260 = (($pts) + 48|0);
  HEAPF32[$260>>2] = $257;
  $261 = (($pts) + 52|0);
  HEAPF32[$261>>2] = $258;
  $262 = (($pts) + 56|0);
  HEAPF32[$262>>2] = $259;
  $263 = (($pts) + 60|0);
  HEAPF32[$263>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 } else {
  $126 = $46 > Math_fround(0.0);
  $127 = Math_fround(-$17);
  $128 = Math_fround(-$19);
  $129 = Math_fround(-$21);
  HEAPF32[$3>>2] = $127;
  $130 = (($3) + 4|0);
  HEAPF32[$130>>2] = $128;
  $131 = (($3) + 8|0);
  HEAPF32[$131>>2] = $129;
  $132 = (($3) + 12|0);
  HEAPF32[$132>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = $17;
  $133 = (($2) + 4|0);
  HEAPF32[$133>>2] = $19;
  $134 = (($2) + 8|0);
  HEAPF32[$134>>2] = $21;
  $135 = (($2) + 12|0);
  HEAPF32[$135>>2] = $23;
  $b$a$i118 = $126 ? $3 : $2;
  $136 = Math_fround(HEAPF32[$b$a$i118>>2]);
  $$in1$i121 = (($b$a$i118) + 4|0);
  $137 = Math_fround(HEAPF32[$$in1$i121>>2]);
  $$in2$i123 = (($b$a$i118) + 8|0);
  $138 = Math_fround(HEAPF32[$$in2$i123>>2]);
  HEAPF32[$faceNormal>>2] = $136;
  $139 = (($faceNormal) + 4|0);
  HEAPF32[$139>>2] = $137;
  $140 = (($faceNormal) + 8|0);
  HEAPF32[$140>>2] = $138;
  $141 = (($faceNormal) + 12|0);
  HEAPF32[$141>>2] = Math_fround(0.0);
  $142 = Math_fround(-$8);
  $143 = $126 ? $142 : $8;
  $144 = Math_fround($6 * $11);
  $145 = Math_fround($6 * $13);
  $146 = Math_fround($6 * $15);
  $147 = Math_fround($17 * $143);
  $148 = Math_fround($19 * $143);
  $149 = Math_fround($21 * $143);
  $150 = Math_fround($10 * $25);
  $151 = Math_fround($10 * $27);
  $152 = Math_fround($10 * $29);
  $153 = (($transf1To0) + 48|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = (($transf1To0) + 52|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = (($transf1To0) + 56|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = Math_fround($147 + $154);
  $160 = Math_fround($148 + $156);
  $161 = Math_fround($149 + $158);
  $162 = Math_fround($144 + $150);
  $163 = Math_fround($145 + $151);
  $164 = Math_fround($146 + $152);
  $165 = Math_fround($144 - $150);
  $166 = Math_fround($145 - $151);
  $167 = Math_fround($146 - $152);
  $168 = Math_fround($162 + $159);
  $169 = Math_fround($163 + $160);
  $170 = Math_fround($164 + $161);
  HEAPF32[$pts>>2] = $168;
  $171 = (($pts) + 4|0);
  HEAPF32[$171>>2] = $169;
  $172 = (($pts) + 8|0);
  HEAPF32[$172>>2] = $170;
  $173 = (($pts) + 12|0);
  HEAPF32[$173>>2] = Math_fround(0.0);
  $174 = Math_fround($165 + $159);
  $175 = Math_fround($166 + $160);
  $176 = Math_fround($167 + $161);
  $177 = (($pts) + 16|0);
  HEAPF32[$177>>2] = $174;
  $178 = (($pts) + 20|0);
  HEAPF32[$178>>2] = $175;
  $179 = (($pts) + 24|0);
  HEAPF32[$179>>2] = $176;
  $180 = (($pts) + 28|0);
  HEAPF32[$180>>2] = Math_fround(0.0);
  $181 = Math_fround($159 - $162);
  $182 = Math_fround($160 - $163);
  $183 = Math_fround($161 - $164);
  $184 = (($pts) + 32|0);
  HEAPF32[$184>>2] = $181;
  $185 = (($pts) + 36|0);
  HEAPF32[$185>>2] = $182;
  $186 = (($pts) + 40|0);
  HEAPF32[$186>>2] = $183;
  $187 = (($pts) + 44|0);
  HEAPF32[$187>>2] = Math_fround(0.0);
  $188 = Math_fround($159 - $165);
  $189 = Math_fround($160 - $166);
  $190 = Math_fround($161 - $167);
  $191 = (($pts) + 48|0);
  HEAPF32[$191>>2] = $188;
  $192 = (($pts) + 52|0);
  HEAPF32[$192>>2] = $189;
  $193 = (($pts) + 56|0);
  HEAPF32[$193>>2] = $190;
  $194 = (($pts) + 60|0);
  HEAPF32[$194>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2GuL17calculateContactsERKNS_6shdfnd3aos6FloatVES5_PNS2_5Vec3VERKS6_S9_PNS0_17PersistentContactERjS5_($extentX,$extentY,$pts,$incidentFaceNormalInNew,$localNormal,$manifoldContacts,$numContacts,$contactDist) {
 $extentX = $extentX|0;
 $extentY = $extentY|0;
 $pts = $pts|0;
 $incidentFaceNormalInNew = $incidentFaceNormalInNew|0;
 $localNormal = $localNormal|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i203 = Math_fround(0), $$$i20$i = Math_fround(0), $$$i217 = Math_fround(0), $$$i217893912 = Math_fround(0), $$$i23$i = Math_fround(0), $$$i26$i = Math_fround(0), $$$i31$i = Math_fround(0), $$$i36$i = Math_fround(0), $$$i891914 = Math_fround(0), $$$not$i = 0, $$1$i$i = Math_fround(0), $$1$i$i$i = Math_fround(0), $$1$i$i204 = Math_fround(0), $$1$i37$i = Math_fround(0), $$404$not$i = 0, $$demorgan$i132 = 0, $$demorgan$i171 = 0;
 var $$demorgan$i93 = 0, $$in1$i$i = 0, $$in1$i61$i = 0, $$in2$i$i = 0, $$in2$i63$i = 0, $$not$i = 0, $$not901 = 0, $$not902 = 0, $$not904 = 0, $$off0899 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i136 = 0, $$phi$trans$insert$i175 = 0, $$phi$trans$insert$i97 = 0, $$pr = 0, $$pre = Math_fround(0), $$pre$i = Math_fround(0), $$pre$i137 = Math_fround(0), $$pre$i176 = Math_fround(0), $$pre$i98 = Math_fround(0);
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0);
 var $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0;
 var $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = Math_fround(0), $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0);
 var $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $48 = 0, $49 = 0;
 var $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0;
 var $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn3$i$i = 0, $a$pn3$i60$i = 0, $b$a$i$i = 0, $b$a$i58$i = 0, $b$a5$i$i = 0;
 var $b$a5$i62$i = 0, $brmerge$demorgan = 0, $brmerge903 = 0, $brmerge905 = 0, $exitcond = 0, $exitcond917 = 0, $extract$t = 0, $extract$t925 = 0, $i$0308$i = 0, $i$0308$i101 = 0, $i$0308$i140 = 0, $i$0308$i179 = 0, $i$0915 = 0, $intersectionPoints$0310$i = 0, $intersectionPoints$0310$i138 = 0, $intersectionPoints$0310$i177 = 0, $intersectionPoints$0310$i99 = 0, $intersectionPoints$1$i = 0, $intersectionPoints$1$i103 = 0, $intersectionPoints$1$i142 = 0;
 var $intersectionPoints$1$i181 = 0, $j$0309$i = 0, $j$0309$i$phi = 0, $j$0309$i100 = 0, $j$0309$i100$phi = 0, $j$0309$i139 = 0, $j$0309$i139$phi = 0, $j$0309$i178 = 0, $j$0309$i178$phi = 0, $not$$i131 = 0, $not$$i170 = 0, $not$$i92 = 0, $not$304$i = 0, $not$304$i133 = 0, $not$304$i172 = 0, $not$304$i94 = 0, $not$brmerge$i = 0, $notlhs$i = 0, $notlhs414$i = 0, $notlhs416$i = 0;
 var $notlhs419$i = 0, $notrhs$i = 0, $notrhs415$i = 0, $notrhs417$i = 0, $notrhs420$i = 0, $or$cond$i = 0, $or$cond406$i = 0, $pArea = 0, $pPenetration = 0, $rEnd$0908 = 0, $rEnd$0908$phi = 0, $rStart$0909 = 0, $tmp$i = 0, $tmp$i102 = 0, $tmp$i141 = 0, $tmp$i180 = 0, $zero$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $zero$i = sp + 48|0;
 $pPenetration = sp + 84|0;
 $pArea = sp + 80|0;
 $4 = Math_fround(HEAPF32[$extentX>>2]);
 $5 = Math_fround(HEAPF32[$extentY>>2]);
 $6 = (($localNormal) + 4|0);
 $7 = (($localNormal) + 8|0);
 $$$i217893912 = Math_fround(3.40282346638528859812E+38);$$$i891914 = Math_fround(-3.40282346638528859812E+38);$16 = Math_fround(3.40282346638528859812E+38);$20 = Math_fround(-3.40282346638528859812E+38);$i$0915 = 0;
 while(1) {
  $8 = (($pts) + ($i$0915<<4)|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = ((($pts) + ($i$0915<<4)|0) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = ((($pts) + ($i$0915<<4)|0) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = $$$i217893912 < $9;
  $$$i217 = $14 ? $$$i217893912 : $9;
  $15 = $16 < $11;
  $17 = $15 ? $16 : $11;
  $18 = $$$i891914 > $9;
  $$$i = $18 ? $$$i891914 : $9;
  $19 = $20 > $11;
  $21 = $19 ? $20 : $11;
  $22 = Math_fround(-$13);
  $23 = Math_fround(HEAPF32[$contactDist>>2]);
  $24 = $23 > $22;
  $25 = (($pPenetration) + ($i$0915)|0);
  do {
   if ($24) {
    HEAP8[$25>>0] = 1;
    $26 = Math_fround(-$9);
    $27 = Math_fround(-$11);
    $28 = $9 > $26;
    $$$i$i203 = $28 ? $9 : $26;
    $29 = $11 > $27;
    $30 = $29 ? $11 : $27;
    $31 = $13 > $22;
    $$1$i$i204 = $31 ? $13 : $22;
    $$not901 = !($4 >= $$$i$i203);
    $$not902 = !($5 >= $30);
    $brmerge903 = $$not901 | $$not902;
    $$not904 = !($$1$i$i204 <= Math_fround(3.40282346638528859812E+38));
    $brmerge905 = $brmerge903 | $$not904;
    $32 = (($pArea) + ($i$0915)|0);
    if ($brmerge905) {
     HEAP8[$32>>0] = 0;
     break;
    } else {
     HEAP8[$32>>0] = 1;
     $33 = HEAP32[$numContacts>>2]|0;
     $34 = (($manifoldContacts) + (($33*48)|0)|0);
     HEAPF32[$34>>2] = $9;
     $35 = ((($manifoldContacts) + (($33*48)|0)|0) + 4|0);
     HEAPF32[$35>>2] = $11;
     $36 = ((($manifoldContacts) + (($33*48)|0)|0) + 8|0);
     HEAPF32[$36>>2] = Math_fround(0.0);
     $37 = ((($manifoldContacts) + (($33*48)|0)|0) + 12|0);
     HEAPF32[$37>>2] = Math_fround(0.0);
     $38 = HEAP32[$numContacts>>2]|0;
     $39 = ((($manifoldContacts) + (($38*48)|0)|0) + 16|0);
     ;HEAP32[$39+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$8+12>>2]|0;
     $40 = HEAP32[$numContacts>>2]|0;
     $41 = (($40) + 1)|0;
     HEAP32[$numContacts>>2] = $41;
     $42 = Math_fround(HEAPF32[$localNormal>>2]);
     $43 = Math_fround(HEAPF32[$6>>2]);
     $44 = Math_fround(HEAPF32[$7>>2]);
     $45 = ((($manifoldContacts) + (($40*48)|0)|0) + 32|0);
     HEAPF32[$45>>2] = $42;
     $46 = ((($manifoldContacts) + (($40*48)|0)|0) + 36|0);
     HEAPF32[$46>>2] = $43;
     $47 = ((($manifoldContacts) + (($40*48)|0)|0) + 40|0);
     HEAPF32[$47>>2] = $44;
     $48 = ((($manifoldContacts) + (($40*48)|0)|0) + 44|0);
     HEAPF32[$48>>2] = $22;
     break;
    }
   } else {
    HEAP8[$25>>0] = 0;
    $49 = (($pArea) + ($i$0915)|0);
    HEAP8[$49>>0] = 0;
   }
  } while(0);
  $50 = (($i$0915) + 1)|0;
  $exitcond917 = ($50|0)==(4);
  if ($exitcond917) {
   break;
  } else {
   $$$i217893912 = $$$i217;$$$i891914 = $$$i;$16 = $17;$20 = $21;$i$0915 = $50;
  }
 }
 $51 = Math_fround(-$4);
 $52 = Math_fround(-$5);
 $53 = HEAP32[$numContacts>>2]|0;
 $54 = ($53|0)==(4);
 if ($54) {
  STACKTOP = sp;return;
 }
 $55 = (($incidentFaceNormalInNew) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround(HEAPF32[$extentX>>2]);
 $58 = Math_fround(HEAPF32[$extentY>>2]);
 $59 = $57 > $$$i;
 $not$$i170 = $$$i217 > $57;
 $$demorgan$i171 = $59 | $not$$i170;
 L14: do {
  if ($$demorgan$i171) {
   $125 = $57;
  } else {
   $60 = $58 > $21;
   $not$304$i172 = $17 > $58;
   $61 = $60 | $not$304$i172;
   if ($61) {
    $125 = $57;
   } else {
    $$phi$trans$insert$i175 = (($pts) + 52|0);
    $$pre$i176 = Math_fround(HEAPF32[$$phi$trans$insert$i175>>2]);
    $65 = $$pre$i176;$i$0308$i179 = 0;$intersectionPoints$0310$i177 = 0;$j$0309$i178 = 3;
    while(1) {
     $62 = ((($pts) + ($i$0308$i179<<4)|0) + 4|0);
     $63 = Math_fround(HEAPF32[$62>>2]);
     $64 = $65 > $58;
     $66 = $63 > $58;
     $tmp$i180 = $64 ^ $66;
     if ($tmp$i180) {
      $67 = (($pts) + ($i$0308$i179<<4)|0);
      $68 = (($pts) + ($j$0309$i178<<4)|0);
      $69 = Math_fround(HEAPF32[$68>>2]);
      $70 = Math_fround(HEAPF32[$67>>2]);
      $71 = Math_fround($70 - $69);
      $72 = Math_fround($63 - $65);
      $73 = Math_fround($58 - $65);
      $74 = Math_fround($73 * $71);
      $75 = Math_fround($72 * $69);
      $76 = Math_fround($57 * $72);
      $77 = Math_fround($75 + $74);
      $78 = !($72 > Math_fround(0.0));
      $79 = $78 ? $76 : $77;
      $80 = $78 ? $77 : $76;
      $81 = !($79 >= $80);
      if ($81) {
       $intersectionPoints$1$i181 = $intersectionPoints$0310$i177;
      } else {
       $82 = ($intersectionPoints$0310$i177|0)==(1);
       if ($82) {
        $125 = $57;
        break L14;
       }
       $83 = (($intersectionPoints$0310$i177) + 1)|0;
       $intersectionPoints$1$i181 = $83;
      }
     } else {
      $intersectionPoints$1$i181 = $intersectionPoints$0310$i177;
     }
     $84 = (($i$0308$i179) + 1)|0;
     $85 = ($84>>>0)<(4);
     if ($85) {
      $j$0309$i178$phi = $i$0308$i179;$65 = $63;$i$0308$i179 = $84;$intersectionPoints$0310$i177 = $intersectionPoints$1$i181;$j$0309$i178 = $j$0309$i178$phi;
     } else {
      break;
     }
    }
    $86 = ($intersectionPoints$1$i181|0)==(0);
    if ($86) {
     $125 = $57;
    } else {
     $87 = Math_fround(HEAPF32[$incidentFaceNormalInNew>>2]);
     $88 = (($incidentFaceNormalInNew) + 4|0);
     $89 = Math_fround(HEAPF32[$88>>2]);
     $90 = Math_fround(HEAPF32[$pts>>2]);
     $91 = (($pts) + 4|0);
     $92 = Math_fround(HEAPF32[$91>>2]);
     $93 = (($pts) + 8|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = Math_fround($90 - $57);
     $96 = Math_fround($92 - $58);
     $97 = Math_fround($87 * $95);
     $98 = Math_fround($89 * $96);
     $99 = Math_fround($97 + $98);
     $100 = Math_fround($56 * $94);
     $101 = Math_fround($100 + $99);
     $102 = Math_fround($101 / $56);
     $103 = Math_fround(-$102);
     $104 = Math_fround(HEAPF32[$contactDist>>2]);
     $105 = $104 > $103;
     if ($105) {
      $106 = (($manifoldContacts) + (($53*48)|0)|0);
      HEAPF32[$106>>2] = $57;
      $107 = ((($manifoldContacts) + (($53*48)|0)|0) + 4|0);
      HEAPF32[$107>>2] = $58;
      $108 = ((($manifoldContacts) + (($53*48)|0)|0) + 8|0);
      HEAPF32[$108>>2] = Math_fround(0.0);
      $109 = ((($manifoldContacts) + (($53*48)|0)|0) + 12|0);
      HEAPF32[$109>>2] = Math_fround(0.0);
      $110 = HEAP32[$numContacts>>2]|0;
      $111 = ((($manifoldContacts) + (($110*48)|0)|0) + 16|0);
      HEAPF32[$111>>2] = $57;
      $112 = ((($manifoldContacts) + (($110*48)|0)|0) + 20|0);
      HEAPF32[$112>>2] = $58;
      $113 = ((($manifoldContacts) + (($110*48)|0)|0) + 24|0);
      HEAPF32[$113>>2] = $102;
      $114 = ((($manifoldContacts) + (($110*48)|0)|0) + 28|0);
      HEAPF32[$114>>2] = Math_fround(0.0);
      $115 = HEAP32[$numContacts>>2]|0;
      $116 = (($115) + 1)|0;
      HEAP32[$numContacts>>2] = $116;
      $117 = Math_fround(HEAPF32[$localNormal>>2]);
      $118 = Math_fround(HEAPF32[$6>>2]);
      $119 = Math_fround(HEAPF32[$7>>2]);
      $120 = ((($manifoldContacts) + (($115*48)|0)|0) + 32|0);
      HEAPF32[$120>>2] = $117;
      $121 = ((($manifoldContacts) + (($115*48)|0)|0) + 36|0);
      HEAPF32[$121>>2] = $118;
      $122 = ((($manifoldContacts) + (($115*48)|0)|0) + 40|0);
      HEAPF32[$122>>2] = $119;
      $123 = ((($manifoldContacts) + (($115*48)|0)|0) + 44|0);
      HEAPF32[$123>>2] = $103;
      $$pre = Math_fround(HEAPF32[$extentX>>2]);
      $125 = $$pre;
     } else {
      $125 = $57;
     }
    }
   }
  }
 } while(0);
 $124 = $125 > $$$i;
 $not$$i131 = $$$i217 > $125;
 $$demorgan$i132 = $124 | $not$$i131;
 L28: do {
  if (!($$demorgan$i132)) {
   $126 = $21 < $52;
   $not$304$i133 = $17 > $52;
   $127 = $126 | $not$304$i133;
   if (!($127)) {
    $$phi$trans$insert$i136 = (($pts) + 52|0);
    $$pre$i137 = Math_fround(HEAPF32[$$phi$trans$insert$i136>>2]);
    $131 = $$pre$i137;$i$0308$i140 = 0;$intersectionPoints$0310$i138 = 0;$j$0309$i139 = 3;
    while(1) {
     $128 = ((($pts) + ($i$0308$i140<<4)|0) + 4|0);
     $129 = Math_fround(HEAPF32[$128>>2]);
     $130 = $131 > $52;
     $132 = $129 > $52;
     $tmp$i141 = $130 ^ $132;
     if ($tmp$i141) {
      $133 = (($pts) + ($i$0308$i140<<4)|0);
      $134 = (($pts) + ($j$0309$i139<<4)|0);
      $135 = Math_fround(HEAPF32[$134>>2]);
      $136 = Math_fround(HEAPF32[$133>>2]);
      $137 = Math_fround($136 - $135);
      $138 = Math_fround($129 - $131);
      $139 = Math_fround($52 - $131);
      $140 = Math_fround($139 * $137);
      $141 = Math_fround($138 * $135);
      $142 = Math_fround($125 * $138);
      $143 = Math_fround($141 + $140);
      $144 = !($138 > Math_fround(0.0));
      $145 = $144 ? $142 : $143;
      $146 = $144 ? $143 : $142;
      $147 = !($145 >= $146);
      if ($147) {
       $intersectionPoints$1$i142 = $intersectionPoints$0310$i138;
      } else {
       $148 = ($intersectionPoints$0310$i138|0)==(1);
       if ($148) {
        break L28;
       }
       $149 = (($intersectionPoints$0310$i138) + 1)|0;
       $intersectionPoints$1$i142 = $149;
      }
     } else {
      $intersectionPoints$1$i142 = $intersectionPoints$0310$i138;
     }
     $150 = (($i$0308$i140) + 1)|0;
     $151 = ($150>>>0)<(4);
     if ($151) {
      $j$0309$i139$phi = $i$0308$i140;$131 = $129;$i$0308$i140 = $150;$intersectionPoints$0310$i138 = $intersectionPoints$1$i142;$j$0309$i139 = $j$0309$i139$phi;
     } else {
      break;
     }
    }
    $152 = ($intersectionPoints$1$i142|0)==(0);
    if (!($152)) {
     $153 = Math_fround(HEAPF32[$incidentFaceNormalInNew>>2]);
     $154 = (($incidentFaceNormalInNew) + 4|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = Math_fround(HEAPF32[$55>>2]);
     $157 = Math_fround(HEAPF32[$pts>>2]);
     $158 = (($pts) + 4|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = (($pts) + 8|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = Math_fround($157 - $125);
     $163 = Math_fround($5 + $159);
     $164 = Math_fround($153 * $162);
     $165 = Math_fround($155 * $163);
     $166 = Math_fround($164 + $165);
     $167 = Math_fround($156 * $161);
     $168 = Math_fround($167 + $166);
     $169 = Math_fround($168 / $56);
     $170 = Math_fround(-$169);
     $171 = Math_fround(HEAPF32[$contactDist>>2]);
     $172 = $171 > $170;
     if ($172) {
      $173 = HEAP32[$numContacts>>2]|0;
      $174 = (($manifoldContacts) + (($173*48)|0)|0);
      HEAPF32[$174>>2] = $125;
      $175 = ((($manifoldContacts) + (($173*48)|0)|0) + 4|0);
      HEAPF32[$175>>2] = $52;
      $176 = ((($manifoldContacts) + (($173*48)|0)|0) + 8|0);
      HEAPF32[$176>>2] = Math_fround(0.0);
      $177 = ((($manifoldContacts) + (($173*48)|0)|0) + 12|0);
      HEAPF32[$177>>2] = Math_fround(0.0);
      $178 = HEAP32[$numContacts>>2]|0;
      $179 = ((($manifoldContacts) + (($178*48)|0)|0) + 16|0);
      HEAPF32[$179>>2] = $125;
      $180 = ((($manifoldContacts) + (($178*48)|0)|0) + 20|0);
      HEAPF32[$180>>2] = $52;
      $181 = ((($manifoldContacts) + (($178*48)|0)|0) + 24|0);
      HEAPF32[$181>>2] = $169;
      $182 = ((($manifoldContacts) + (($178*48)|0)|0) + 28|0);
      HEAPF32[$182>>2] = Math_fround(0.0);
      $183 = HEAP32[$numContacts>>2]|0;
      $184 = (($183) + 1)|0;
      HEAP32[$numContacts>>2] = $184;
      $185 = Math_fround(HEAPF32[$localNormal>>2]);
      $186 = Math_fround(HEAPF32[$6>>2]);
      $187 = Math_fround(HEAPF32[$7>>2]);
      $188 = ((($manifoldContacts) + (($183*48)|0)|0) + 32|0);
      HEAPF32[$188>>2] = $185;
      $189 = ((($manifoldContacts) + (($183*48)|0)|0) + 36|0);
      HEAPF32[$189>>2] = $186;
      $190 = ((($manifoldContacts) + (($183*48)|0)|0) + 40|0);
      HEAPF32[$190>>2] = $187;
      $191 = ((($manifoldContacts) + (($183*48)|0)|0) + 44|0);
      HEAPF32[$191>>2] = $170;
     }
    }
   }
  }
 } while(0);
 $192 = Math_fround(HEAPF32[$extentY>>2]);
 $193 = $$$i < $51;
 $not$$i92 = $$$i217 > $51;
 $$demorgan$i93 = $193 | $not$$i92;
 L42: do {
  if (!($$demorgan$i93)) {
   $194 = $192 > $21;
   $not$304$i94 = $17 > $192;
   $195 = $194 | $not$304$i94;
   L44: do {
    if (!($195)) {
     $$phi$trans$insert$i97 = (($pts) + 52|0);
     $$pre$i98 = Math_fround(HEAPF32[$$phi$trans$insert$i97>>2]);
     $199 = $$pre$i98;$i$0308$i101 = 0;$intersectionPoints$0310$i99 = 0;$j$0309$i100 = 3;
     while(1) {
      $196 = ((($pts) + ($i$0308$i101<<4)|0) + 4|0);
      $197 = Math_fround(HEAPF32[$196>>2]);
      $198 = $199 > $192;
      $200 = $197 > $192;
      $tmp$i102 = $198 ^ $200;
      if ($tmp$i102) {
       $201 = (($pts) + ($i$0308$i101<<4)|0);
       $202 = (($pts) + ($j$0309$i100<<4)|0);
       $203 = Math_fround(HEAPF32[$202>>2]);
       $204 = Math_fround(HEAPF32[$201>>2]);
       $205 = Math_fround($204 - $203);
       $206 = Math_fround($197 - $199);
       $207 = Math_fround($192 - $199);
       $208 = Math_fround($207 * $205);
       $209 = Math_fround($206 * $203);
       $210 = Math_fround($206 * $51);
       $211 = Math_fround($209 + $208);
       $212 = !($206 > Math_fround(0.0));
       $213 = $212 ? $210 : $211;
       $214 = $212 ? $211 : $210;
       $215 = !($213 >= $214);
       if ($215) {
        $intersectionPoints$1$i103 = $intersectionPoints$0310$i99;
       } else {
        $216 = ($intersectionPoints$0310$i99|0)==(1);
        if ($216) {
         break L44;
        }
        $217 = (($intersectionPoints$0310$i99) + 1)|0;
        $intersectionPoints$1$i103 = $217;
       }
      } else {
       $intersectionPoints$1$i103 = $intersectionPoints$0310$i99;
      }
      $218 = (($i$0308$i101) + 1)|0;
      $219 = ($218>>>0)<(4);
      if ($219) {
       $j$0309$i100$phi = $i$0308$i101;$199 = $197;$i$0308$i101 = $218;$intersectionPoints$0310$i99 = $intersectionPoints$1$i103;$j$0309$i100 = $j$0309$i100$phi;
      } else {
       break;
      }
     }
     $220 = ($intersectionPoints$1$i103|0)==(0);
     if (!($220)) {
      $221 = Math_fround(HEAPF32[$incidentFaceNormalInNew>>2]);
      $222 = (($incidentFaceNormalInNew) + 4|0);
      $223 = Math_fround(HEAPF32[$222>>2]);
      $224 = Math_fround(HEAPF32[$55>>2]);
      $225 = Math_fround(HEAPF32[$pts>>2]);
      $226 = (($pts) + 4|0);
      $227 = Math_fround(HEAPF32[$226>>2]);
      $228 = (($pts) + 8|0);
      $229 = Math_fround(HEAPF32[$228>>2]);
      $230 = Math_fround($4 + $225);
      $231 = Math_fround($227 - $192);
      $232 = Math_fround($221 * $230);
      $233 = Math_fround($223 * $231);
      $234 = Math_fround($232 + $233);
      $235 = Math_fround($224 * $229);
      $236 = Math_fround($235 + $234);
      $237 = Math_fround($236 / $56);
      $238 = Math_fround(-$237);
      $239 = Math_fround(HEAPF32[$contactDist>>2]);
      $240 = $239 > $238;
      if ($240) {
       $241 = HEAP32[$numContacts>>2]|0;
       $242 = (($manifoldContacts) + (($241*48)|0)|0);
       HEAPF32[$242>>2] = $51;
       $243 = ((($manifoldContacts) + (($241*48)|0)|0) + 4|0);
       HEAPF32[$243>>2] = $192;
       $244 = ((($manifoldContacts) + (($241*48)|0)|0) + 8|0);
       HEAPF32[$244>>2] = Math_fround(0.0);
       $245 = ((($manifoldContacts) + (($241*48)|0)|0) + 12|0);
       HEAPF32[$245>>2] = Math_fround(0.0);
       $246 = HEAP32[$numContacts>>2]|0;
       $247 = ((($manifoldContacts) + (($246*48)|0)|0) + 16|0);
       HEAPF32[$247>>2] = $51;
       $248 = ((($manifoldContacts) + (($246*48)|0)|0) + 20|0);
       HEAPF32[$248>>2] = $192;
       $249 = ((($manifoldContacts) + (($246*48)|0)|0) + 24|0);
       HEAPF32[$249>>2] = $237;
       $250 = ((($manifoldContacts) + (($246*48)|0)|0) + 28|0);
       HEAPF32[$250>>2] = Math_fround(0.0);
       $251 = HEAP32[$numContacts>>2]|0;
       $252 = (($251) + 1)|0;
       HEAP32[$numContacts>>2] = $252;
       $253 = Math_fround(HEAPF32[$localNormal>>2]);
       $254 = Math_fround(HEAPF32[$6>>2]);
       $255 = Math_fround(HEAPF32[$7>>2]);
       $256 = ((($manifoldContacts) + (($251*48)|0)|0) + 32|0);
       HEAPF32[$256>>2] = $253;
       $257 = ((($manifoldContacts) + (($251*48)|0)|0) + 36|0);
       HEAPF32[$257>>2] = $254;
       $258 = ((($manifoldContacts) + (($251*48)|0)|0) + 40|0);
       HEAPF32[$258>>2] = $255;
       $259 = ((($manifoldContacts) + (($251*48)|0)|0) + 44|0);
       HEAPF32[$259>>2] = $238;
      }
     }
    }
   } while(0);
   $260 = $21 < $52;
   $not$304$i = $17 > $52;
   $261 = $260 | $not$304$i;
   if (!($261)) {
    $$phi$trans$insert$i = (($pts) + 52|0);
    $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
    $265 = $$pre$i;$i$0308$i = 0;$intersectionPoints$0310$i = 0;$j$0309$i = 3;
    while(1) {
     $262 = ((($pts) + ($i$0308$i<<4)|0) + 4|0);
     $263 = Math_fround(HEAPF32[$262>>2]);
     $264 = $265 > $52;
     $266 = $263 > $52;
     $tmp$i = $264 ^ $266;
     if ($tmp$i) {
      $267 = (($pts) + ($i$0308$i<<4)|0);
      $268 = (($pts) + ($j$0309$i<<4)|0);
      $269 = Math_fround(HEAPF32[$268>>2]);
      $270 = Math_fround(HEAPF32[$267>>2]);
      $271 = Math_fround($270 - $269);
      $272 = Math_fround($263 - $265);
      $273 = Math_fround($52 - $265);
      $274 = Math_fround($273 * $271);
      $275 = Math_fround($272 * $269);
      $276 = Math_fround($272 * $51);
      $277 = Math_fround($275 + $274);
      $278 = !($272 > Math_fround(0.0));
      $279 = $278 ? $276 : $277;
      $280 = $278 ? $277 : $276;
      $281 = !($279 >= $280);
      if ($281) {
       $intersectionPoints$1$i = $intersectionPoints$0310$i;
      } else {
       $282 = ($intersectionPoints$0310$i|0)==(1);
       if ($282) {
        break L42;
       }
       $283 = (($intersectionPoints$0310$i) + 1)|0;
       $intersectionPoints$1$i = $283;
      }
     } else {
      $intersectionPoints$1$i = $intersectionPoints$0310$i;
     }
     $284 = (($i$0308$i) + 1)|0;
     $285 = ($284>>>0)<(4);
     if ($285) {
      $j$0309$i$phi = $i$0308$i;$265 = $263;$i$0308$i = $284;$intersectionPoints$0310$i = $intersectionPoints$1$i;$j$0309$i = $j$0309$i$phi;
     } else {
      break;
     }
    }
    $286 = ($intersectionPoints$1$i|0)==(0);
    if (!($286)) {
     $287 = Math_fround(HEAPF32[$incidentFaceNormalInNew>>2]);
     $288 = (($incidentFaceNormalInNew) + 4|0);
     $289 = Math_fround(HEAPF32[$288>>2]);
     $290 = Math_fround(HEAPF32[$55>>2]);
     $291 = Math_fround(HEAPF32[$pts>>2]);
     $292 = (($pts) + 4|0);
     $293 = Math_fround(HEAPF32[$292>>2]);
     $294 = (($pts) + 8|0);
     $295 = Math_fround(HEAPF32[$294>>2]);
     $296 = Math_fround($4 + $291);
     $297 = Math_fround($5 + $293);
     $298 = Math_fround($287 * $296);
     $299 = Math_fround($289 * $297);
     $300 = Math_fround($298 + $299);
     $301 = Math_fround($290 * $295);
     $302 = Math_fround($301 + $300);
     $303 = Math_fround($302 / $56);
     $304 = Math_fround(-$303);
     $305 = Math_fround(HEAPF32[$contactDist>>2]);
     $306 = $305 > $304;
     if ($306) {
      $307 = HEAP32[$numContacts>>2]|0;
      $308 = (($manifoldContacts) + (($307*48)|0)|0);
      HEAPF32[$308>>2] = $51;
      $309 = ((($manifoldContacts) + (($307*48)|0)|0) + 4|0);
      HEAPF32[$309>>2] = $52;
      $310 = ((($manifoldContacts) + (($307*48)|0)|0) + 8|0);
      HEAPF32[$310>>2] = Math_fround(0.0);
      $311 = ((($manifoldContacts) + (($307*48)|0)|0) + 12|0);
      HEAPF32[$311>>2] = Math_fround(0.0);
      $312 = HEAP32[$numContacts>>2]|0;
      $313 = ((($manifoldContacts) + (($312*48)|0)|0) + 16|0);
      HEAPF32[$313>>2] = $51;
      $314 = ((($manifoldContacts) + (($312*48)|0)|0) + 20|0);
      HEAPF32[$314>>2] = $52;
      $315 = ((($manifoldContacts) + (($312*48)|0)|0) + 24|0);
      HEAPF32[$315>>2] = $303;
      $316 = ((($manifoldContacts) + (($312*48)|0)|0) + 28|0);
      HEAPF32[$316>>2] = Math_fround(0.0);
      $317 = HEAP32[$numContacts>>2]|0;
      $318 = (($317) + 1)|0;
      HEAP32[$numContacts>>2] = $318;
      $319 = Math_fround(HEAPF32[$localNormal>>2]);
      $320 = Math_fround(HEAPF32[$6>>2]);
      $321 = Math_fround(HEAPF32[$7>>2]);
      $322 = ((($manifoldContacts) + (($317*48)|0)|0) + 32|0);
      HEAPF32[$322>>2] = $319;
      $323 = ((($manifoldContacts) + (($317*48)|0)|0) + 36|0);
      HEAPF32[$323>>2] = $320;
      $324 = ((($manifoldContacts) + (($317*48)|0)|0) + 40|0);
      HEAPF32[$324>>2] = $321;
      $325 = ((($manifoldContacts) + (($317*48)|0)|0) + 44|0);
      HEAPF32[$325>>2] = $304;
     }
    }
   }
  }
 } while(0);
 $326 = Math_fround(HEAPF32[$extentX>>2]);
 $327 = Math_fround(HEAPF32[$extentY>>2]);
 $328 = (($0) + 4|0);
 $329 = (($0) + 8|0);
 $330 = (($0) + 12|0);
 $331 = (($3) + 4|0);
 $332 = (($3) + 8|0);
 $333 = (($3) + 12|0);
 $334 = (($2) + 4|0);
 $335 = (($2) + 8|0);
 $336 = (($2) + 12|0);
 $rEnd$0908 = 3;$rStart$0909 = 0;
 while(1) {
  $337 = (($pts) + ($rStart$0909<<4)|0);
  $338 = Math_fround(HEAPF32[$337>>2]);
  $339 = ((($pts) + ($rStart$0909<<4)|0) + 4|0);
  $340 = Math_fround(HEAPF32[$339>>2]);
  $341 = ((($pts) + ($rStart$0909<<4)|0) + 8|0);
  $342 = Math_fround(HEAPF32[$341>>2]);
  $343 = (($pts) + ($rEnd$0908<<4)|0);
  $344 = Math_fround(HEAPF32[$343>>2]);
  $345 = ((($pts) + ($rEnd$0908<<4)|0) + 4|0);
  $346 = Math_fround(HEAPF32[$345>>2]);
  $347 = ((($pts) + ($rEnd$0908<<4)|0) + 8|0);
  $348 = Math_fround(HEAPF32[$347>>2]);
  $349 = (($pPenetration) + ($rStart$0909)|0);
  $350 = HEAP8[$349>>0]|0;
  $351 = ($350<<24>>24)==(0);
  $352 = (($pPenetration) + ($rEnd$0908)|0);
  $353 = HEAP8[$352>>0]|0;
  do {
   if ($351) {
    $354 = ($353<<24>>24)==(0);
    if (!($354)) {
     $$pr = HEAP8[$349>>0]|0;
     $355 = ($$pr<<24>>24)==(0);
     if ($355) {
      $359 = (($pArea) + ($rEnd$0908)|0);
      $360 = HEAP8[$359>>0]|0;
      $extract$t925 = ($360<<24>>24)!=(0);
      $$off0899 = $extract$t925;$474 = 0;
      label = 60;
      break;
     } else {
      $356 = (($pArea) + ($rStart$0909)|0);
      $357 = HEAP8[$356>>0]|0;
      $358 = ($357<<24>>24)!=(0);
      $367 = $358;
      label = 59;
      break;
     }
    }
   } else {
    $361 = (($pArea) + ($rStart$0909)|0);
    $362 = HEAP8[$361>>0]|0;
    $363 = ($362<<24>>24)!=(0);
    $364 = ($353<<24>>24)==(0);
    if ($364) {
     $$off0899 = 0;$474 = $363;
     label = 60;
    } else {
     $367 = $363;
     label = 59;
    }
   }
  } while(0);
  if ((label|0) == 59) {
   label = 0;
   $365 = (($pArea) + ($rEnd$0908)|0);
   $366 = HEAP8[$365>>0]|0;
   $extract$t = ($366<<24>>24)!=(0);
   $brmerge$demorgan = $367 & $extract$t;
   if (!($brmerge$demorgan)) {
    $$off0899 = $extract$t;$474 = $367;
    label = 60;
   }
  }
  if ((label|0) == 60) {
   label = 0;
   $368 = Math_fround($344 - $338);
   $369 = Math_fround($346 - $340);
   $370 = Math_fround($348 - $342);
   $371 = Math_fround(-$368);
   $372 = Math_fround(-$369);
   $373 = Math_fround(-$370);
   $374 = $368 > $371;
   $$$i$i$i = $374 ? $368 : $371;
   $375 = $369 > $372;
   $376 = $375 ? $369 : $372;
   $377 = $370 > $373;
   $$1$i$i$i = $377 ? $370 : $373;
   ;HEAP32[$zero$i+0>>2]=0|0;HEAP32[$zero$i+4>>2]=0|0;HEAP32[$zero$i+8>>2]=0|0;HEAP32[$zero$i+12>>2]=0|0;
   $378 = !($$$i$i$i < Math_fround(9.99999997475242707878E-7));
   $379 = !($376 < Math_fround(9.99999997475242707878E-7));
   $380 = !($$1$i$i$i < Math_fround(9.99999997475242707878E-7));
   $notlhs$i = !($338 < $51);
   $notrhs$i = !($338 > $326);
   $$$not$i = $notrhs$i & $notlhs$i;
   $381 = $378 | $$$not$i;
   $notlhs414$i = !($340 < $52);
   $notrhs415$i = !($340 > $327);
   $$not$i = $notrhs415$i & $notlhs414$i;
   $382 = $379 | $$not$i;
   $or$cond$i = $381 & $382;
   $notlhs416$i = !($342 < Math_fround(0.0));
   $notrhs417$i = !($342 > Math_fround(3.40282346638528859812E+38));
   $$404$not$i = $notrhs417$i & $notlhs416$i;
   $383 = $380 | $$404$not$i;
   $or$cond406$i = $or$cond$i & $383;
   if ($or$cond406$i) {
    $384 = Math_fround(Math_fround(1.0) / $368);
    $385 = Math_fround(Math_fround(1.0) / $369);
    $386 = Math_fround(Math_fround(1.0) / $370);
    ;HEAP32[$1+0>>2]=HEAP32[$zero$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$zero$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$zero$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$zero$i+12>>2]|0;
    $387 = Math_fround($51 - $338);
    $388 = Math_fround($52 - $340);
    $389 = Math_fround(Math_fround(0.0) - $342);
    $390 = Math_fround($387 * $384);
    $391 = Math_fround($388 * $385);
    $392 = Math_fround($389 * $386);
    HEAPF32[$0>>2] = $390;
    HEAPF32[$328>>2] = $391;
    HEAPF32[$329>>2] = $392;
    HEAPF32[$330>>2] = Math_fround(0.0);
    $b$a$i58$i = $378 ? $0 : $1;
    $393 = Math_fround(HEAPF32[$b$a$i58$i>>2]);
    $a$pn3$i60$i = $379 ? $0 : $1;
    $$in1$i61$i = (($a$pn3$i60$i) + 4|0);
    $394 = Math_fround(HEAPF32[$$in1$i61$i>>2]);
    $b$a5$i62$i = $380 ? $0 : $1;
    $$in2$i63$i = (($b$a5$i62$i) + 8|0);
    $395 = Math_fround(HEAPF32[$$in2$i63$i>>2]);
    $396 = Math_fround($326 - $338);
    $397 = Math_fround($327 - $340);
    $398 = Math_fround(Math_fround(3.40282346638528859812E+38) - $342);
    $399 = Math_fround($396 * $384);
    $400 = Math_fround($397 * $385);
    $401 = Math_fround($398 * $386);
    HEAPF32[$3>>2] = Math_fround(3.40282346638528859812E+38);
    HEAPF32[$331>>2] = Math_fround(3.40282346638528859812E+38);
    HEAPF32[$332>>2] = Math_fround(3.40282346638528859812E+38);
    HEAPF32[$333>>2] = Math_fround(0.0);
    HEAPF32[$2>>2] = $399;
    HEAPF32[$334>>2] = $400;
    HEAPF32[$335>>2] = $401;
    HEAPF32[$336>>2] = Math_fround(0.0);
    $b$a$i$i = $378 ? $2 : $3;
    $402 = Math_fround(HEAPF32[$b$a$i$i>>2]);
    $a$pn3$i$i = $379 ? $2 : $3;
    $$in1$i$i = (($a$pn3$i$i) + 4|0);
    $403 = Math_fround(HEAPF32[$$in1$i$i>>2]);
    $b$a5$i$i = $380 ? $2 : $3;
    $$in2$i$i = (($b$a5$i$i) + 8|0);
    $404 = Math_fround(HEAPF32[$$in2$i$i>>2]);
    $405 = $393 < $402;
    $$$i36$i = $405 ? $393 : $402;
    $406 = $394 < $403;
    $407 = $406 ? $394 : $403;
    $408 = $395 < $404;
    $$1$i37$i = $408 ? $395 : $404;
    $409 = $393 > $402;
    $$$i31$i = $409 ? $393 : $402;
    $410 = $394 > $403;
    $411 = $410 ? $394 : $403;
    $412 = $395 > $404;
    $$1$i$i = $412 ? $395 : $404;
    $413 = !($$$i36$i >= $407);
    $$$i26$i = $413 ? $407 : $$$i36$i;
    $414 = !($$$i26$i >= $$1$i37$i);
    $415 = $414 ? $$1$i37$i : $$$i26$i;
    $416 = !($$$i31$i <= $411);
    $$$i23$i = $416 ? $411 : $$$i31$i;
    $417 = !($$$i23$i <= $$1$i$i);
    $418 = $417 ? $$1$i$i : $$$i23$i;
    $419 = $415 > Math_fround(0.0);
    $$$i20$i = $419 ? $415 : Math_fround(0.0);
    $420 = $418 < Math_fround(1.0);
    $$$i$i = $420 ? $418 : Math_fround(1.0);
    $notlhs419$i = !($$$i20$i > $$$i$i);
    $notrhs420$i = !($$$i20$i > Math_fround(1.0));
    $not$brmerge$i = $notrhs420$i & $notlhs419$i;
    if ($not$brmerge$i) {
     if (!($474)) {
      $421 = Math_fround($368 * $$$i20$i);
      $422 = Math_fround($369 * $$$i20$i);
      $423 = Math_fround($370 * $$$i20$i);
      $424 = Math_fround($338 + $421);
      $425 = Math_fround($340 + $422);
      $426 = Math_fround($342 + $423);
      $427 = HEAP32[$numContacts>>2]|0;
      $428 = (($manifoldContacts) + (($427*48)|0)|0);
      HEAPF32[$428>>2] = $424;
      $429 = ((($manifoldContacts) + (($427*48)|0)|0) + 4|0);
      HEAPF32[$429>>2] = $425;
      $430 = ((($manifoldContacts) + (($427*48)|0)|0) + 8|0);
      HEAPF32[$430>>2] = Math_fround(0.0);
      $431 = ((($manifoldContacts) + (($427*48)|0)|0) + 12|0);
      HEAPF32[$431>>2] = Math_fround(0.0);
      $432 = HEAP32[$numContacts>>2]|0;
      $433 = ((($manifoldContacts) + (($432*48)|0)|0) + 16|0);
      HEAPF32[$433>>2] = $424;
      $434 = ((($manifoldContacts) + (($432*48)|0)|0) + 20|0);
      HEAPF32[$434>>2] = $425;
      $435 = ((($manifoldContacts) + (($432*48)|0)|0) + 24|0);
      HEAPF32[$435>>2] = $426;
      $436 = ((($manifoldContacts) + (($432*48)|0)|0) + 28|0);
      HEAPF32[$436>>2] = Math_fround(0.0);
      $437 = HEAP32[$numContacts>>2]|0;
      $438 = (($437) + 1)|0;
      HEAP32[$numContacts>>2] = $438;
      $439 = Math_fround(HEAPF32[$localNormal>>2]);
      $440 = Math_fround(HEAPF32[$6>>2]);
      $441 = Math_fround(HEAPF32[$7>>2]);
      $442 = Math_fround(-$426);
      $443 = ((($manifoldContacts) + (($437*48)|0)|0) + 32|0);
      HEAPF32[$443>>2] = $439;
      $444 = ((($manifoldContacts) + (($437*48)|0)|0) + 36|0);
      HEAPF32[$444>>2] = $440;
      $445 = ((($manifoldContacts) + (($437*48)|0)|0) + 40|0);
      HEAPF32[$445>>2] = $441;
      $446 = ((($manifoldContacts) + (($437*48)|0)|0) + 44|0);
      HEAPF32[$446>>2] = $442;
     }
     if (!($$off0899)) {
      $447 = Math_fround($368 * $$$i$i);
      $448 = Math_fround($369 * $$$i$i);
      $449 = Math_fround($370 * $$$i$i);
      $450 = Math_fround($338 + $447);
      $451 = Math_fround($340 + $448);
      $452 = Math_fround($342 + $449);
      $453 = HEAP32[$numContacts>>2]|0;
      $454 = (($manifoldContacts) + (($453*48)|0)|0);
      HEAPF32[$454>>2] = $450;
      $455 = ((($manifoldContacts) + (($453*48)|0)|0) + 4|0);
      HEAPF32[$455>>2] = $451;
      $456 = ((($manifoldContacts) + (($453*48)|0)|0) + 8|0);
      HEAPF32[$456>>2] = Math_fround(0.0);
      $457 = ((($manifoldContacts) + (($453*48)|0)|0) + 12|0);
      HEAPF32[$457>>2] = Math_fround(0.0);
      $458 = HEAP32[$numContacts>>2]|0;
      $459 = ((($manifoldContacts) + (($458*48)|0)|0) + 16|0);
      HEAPF32[$459>>2] = $450;
      $460 = ((($manifoldContacts) + (($458*48)|0)|0) + 20|0);
      HEAPF32[$460>>2] = $451;
      $461 = ((($manifoldContacts) + (($458*48)|0)|0) + 24|0);
      HEAPF32[$461>>2] = $452;
      $462 = ((($manifoldContacts) + (($458*48)|0)|0) + 28|0);
      HEAPF32[$462>>2] = Math_fround(0.0);
      $463 = HEAP32[$numContacts>>2]|0;
      $464 = (($463) + 1)|0;
      HEAP32[$numContacts>>2] = $464;
      $465 = Math_fround(HEAPF32[$localNormal>>2]);
      $466 = Math_fround(HEAPF32[$6>>2]);
      $467 = Math_fround(HEAPF32[$7>>2]);
      $468 = Math_fround(-$452);
      $469 = ((($manifoldContacts) + (($463*48)|0)|0) + 32|0);
      HEAPF32[$469>>2] = $465;
      $470 = ((($manifoldContacts) + (($463*48)|0)|0) + 36|0);
      HEAPF32[$470>>2] = $466;
      $471 = ((($manifoldContacts) + (($463*48)|0)|0) + 40|0);
      HEAPF32[$471>>2] = $467;
      $472 = ((($manifoldContacts) + (($463*48)|0)|0) + 44|0);
      HEAPF32[$472>>2] = $468;
     }
    }
   }
  }
  $473 = (($rStart$0909) + 1)|0;
  $exitcond = ($473|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $rEnd$0908$phi = $rStart$0909;$rStart$0909 = $473;$rEnd$0908 = $rEnd$0908$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu19pcmContactBoxConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i$i$i$i$i = Math_fround(0), $$$i$i36 = Math_fround(0), $$$i12$i$i$i$i = Math_fround(0), $$$i23$i$i$i$i = Math_fround(0), $$1 = 0, $$1$i$i$i$i = Math_fround(0), $$pre$phiZ2D = 0, $$sroa$1$i$i = 0, $$sroa$1$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0);
 var $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0;
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0;
 var $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0);
 var $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = 0;
 var $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0);
 var $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0;
 var $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0);
 var $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0);
 var $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0);
 var $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0);
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0);
 var $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0;
 var $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0);
 var $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = 0, $498 = Math_fround(0), $499 = 0, $5 = Math_fround(0), $50 = 0;
 var $500 = Math_fround(0), $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0;
 var $519 = 0, $52 = 0, $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0);
 var $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0);
 var $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0;
 var $573 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $box = 0, $closestA = 0, $closestB = 0, $contactDist = 0, $convexHull = 0, $doOverlapTest$1$off0138 = 0, $doOverlapTest3$1$off0 = 0, $localNormalPen = 0, $localNormalPen2 = 0, $localPointA1 = 0, $normal = 0, $numContacts = 0;
 var $penDep = 0, $projectBreakingThreshold = 0, $replaceBreakingThreshold = 0, $status$0 = 0, $supportMap = 0, $supportMap6 = 0, $transf0 = 0, $transf1 = 0, $vQuat = 0, $vScale = 0, $worldNormal = 0, $worldNormal9 = 0, $zero$sroa$1$i$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 848|0;
 $$sroa$1$i$i$i$i = sp + 736|0;
 $zero$sroa$1$i$i$i$i = sp + 780|0;
 $$sroa$1$i$i = sp + 768|0;
 $zeroV = sp + 704|0;
 $contactDist = sp + 720|0;
 $vScale = sp + 752|0;
 $transf0 = sp + 672|0;
 $transf1 = sp + 640|0;
 $aToB = sp + 576|0;
 $projectBreakingThreshold = sp + 560|0;
 $replaceBreakingThreshold = sp + 544|0;
 $closestA = sp;
 $closestB = sp + 272|0;
 $normal = sp + 16|0;
 $penDep = sp + 32|0;
 $vQuat = sp + 48|0;
 $convexHull = sp + 64|0;
 $box = sp + 288|0;
 $numContacts = sp + 812|0;
 $localNormalPen = sp + 448|0;
 $0 = sp + 464|0;
 $supportMap = sp + 816|0;
 $localPointA1 = sp + 480|0;
 $localNormalPen2 = sp + 496|0;
 $worldNormal = sp + 512|0;
 $supportMap6 = sp + 792|0;
 $worldNormal9 = sp + 528|0;
 $1 = HEAP32[$cache>>2]|0;
 $2 = $1;
 $3 = (($shape1) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $5 = Math_fround(HEAPF32[$contactDistance>>2]);
 HEAPF32[$contactDist>>2] = $5;
 $6 = (($shape0) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($shape0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($shape0) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($shape1) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($shape1) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($shape1) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$vScale>>2] = $13;
 $18 = (($vScale) + 4|0);
 HEAPF32[$18>>2] = $15;
 $19 = (($vScale) + 8|0);
 HEAPF32[$19>>2] = $17;
 $20 = (($vScale) + 12|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = Math_fround(HEAPF32[$transform0>>2]);
 $22 = (($transform0) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($transform0) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($transform0) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($transform0) + 16|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($28) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($28) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$transf0>>2] = $21;
 $34 = (($transf0) + 4|0);
 HEAPF32[$34>>2] = $23;
 $35 = (($transf0) + 8|0);
 HEAPF32[$35>>2] = $25;
 $36 = (($transf0) + 12|0);
 HEAPF32[$36>>2] = $27;
 $37 = (($transf0) + 16|0);
 HEAPF32[$37>>2] = $29;
 $38 = (($transf0) + 20|0);
 HEAPF32[$38>>2] = $31;
 $39 = (($transf0) + 24|0);
 HEAPF32[$39>>2] = $33;
 $40 = (($transf0) + 28|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = Math_fround(HEAPF32[$transform1>>2]);
 $42 = (($transform1) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($transform1) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($transform1) + 12|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($transform1) + 16|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($48) + 4|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($48) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 HEAPF32[$transf1>>2] = $41;
 $54 = (($transf1) + 4|0);
 HEAPF32[$54>>2] = $43;
 $55 = (($transf1) + 8|0);
 HEAPF32[$55>>2] = $45;
 $56 = (($transf1) + 12|0);
 HEAPF32[$56>>2] = $47;
 $57 = (($transf1) + 16|0);
 HEAPF32[$57>>2] = $49;
 $58 = (($transf1) + 20|0);
 HEAPF32[$58>>2] = $51;
 $59 = (($transf1) + 24|0);
 HEAPF32[$59>>2] = $53;
 $60 = (($transf1) + 28|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = Math_fround(-$41);
 $62 = Math_fround(-$43);
 $63 = Math_fround(-$45);
 $64 = Math_fround($29 - $49);
 $65 = Math_fround($31 - $51);
 $66 = Math_fround($33 - $53);
 $67 = Math_fround($47 * $47);
 $68 = Math_fround($67 + Math_fround(-0.5));
 $69 = Math_fround($68 * $64);
 $70 = Math_fround($68 * $65);
 $71 = Math_fround($68 * $66);
 $72 = Math_fround($66 * $62);
 $73 = Math_fround($65 * $63);
 $74 = Math_fround($72 - $73);
 $75 = Math_fround($64 * $63);
 $76 = Math_fround($66 * $61);
 $77 = Math_fround($75 - $76);
 $78 = Math_fround($65 * $61);
 $79 = Math_fround($64 * $62);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($47 * $74);
 $82 = Math_fround($47 * $77);
 $83 = Math_fround($47 * $80);
 $84 = Math_fround($69 + $81);
 $85 = Math_fround($70 + $82);
 $86 = Math_fround($71 + $83);
 $87 = Math_fround($64 * $61);
 $88 = Math_fround($65 * $62);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($66 * $63);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($91 * $61);
 $93 = Math_fround($91 * $62);
 $94 = Math_fround($91 * $63);
 $95 = Math_fround($92 + $84);
 $96 = Math_fround($93 + $85);
 $97 = Math_fround($86 + $94);
 $98 = Math_fround($95 * Math_fround(2.0));
 $99 = Math_fround($96 * Math_fround(2.0));
 $100 = Math_fround($97 * Math_fround(2.0));
 $101 = Math_fround($47 * $27);
 $102 = Math_fround($21 * $61);
 $103 = Math_fround($23 * $62);
 $104 = Math_fround($102 + $103);
 $105 = Math_fround($25 * $63);
 $106 = Math_fround($104 + $105);
 $107 = Math_fround($101 - $106);
 $108 = Math_fround($27 * $61);
 $109 = Math_fround($27 * $62);
 $110 = Math_fround($27 * $63);
 $111 = Math_fround($47 * $21);
 $112 = Math_fround($47 * $23);
 $113 = Math_fround($47 * $25);
 $114 = Math_fround($25 * $62);
 $115 = Math_fround($23 * $63);
 $116 = Math_fround($114 - $115);
 $117 = Math_fround($21 * $63);
 $118 = Math_fround($25 * $61);
 $119 = Math_fround($117 - $118);
 $120 = Math_fround($23 * $61);
 $121 = Math_fround($21 * $62);
 $122 = Math_fround($120 - $121);
 $123 = Math_fround($111 + $108);
 $124 = Math_fround($112 + $109);
 $125 = Math_fround($113 + $110);
 $126 = Math_fround($116 + $123);
 $127 = Math_fround($119 + $124);
 $128 = Math_fround($122 + $125);
 $129 = (($aToB) + 48|0);
 HEAPF32[$129>>2] = $98;
 $130 = (($aToB) + 52|0);
 HEAPF32[$130>>2] = $99;
 $131 = (($aToB) + 56|0);
 HEAPF32[$131>>2] = $100;
 $132 = (($aToB) + 60|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = Math_fround($126 + $126);
 $134 = Math_fround($127 + $127);
 $135 = Math_fround($128 + $128);
 $136 = Math_fround($126 * $133);
 $137 = Math_fround($127 * $134);
 $138 = Math_fround($128 * $135);
 $139 = Math_fround($127 * $133);
 $140 = Math_fround($128 * $133);
 $141 = Math_fround($107 * $133);
 $142 = Math_fround($128 * $134);
 $143 = Math_fround($107 * $134);
 $144 = Math_fround($107 * $135);
 $145 = Math_fround(Math_fround(1.0) - $136);
 $146 = Math_fround(Math_fround(1.0) - $137);
 $147 = Math_fround($146 - $138);
 $148 = Math_fround($139 + $144);
 $149 = Math_fround($140 - $143);
 $150 = Math_fround($139 - $144);
 $151 = Math_fround($145 - $138);
 $152 = Math_fround($142 + $141);
 $153 = Math_fround($140 + $143);
 $154 = Math_fround($142 - $141);
 $155 = Math_fround($145 - $137);
 HEAPF32[$aToB>>2] = $147;
 $156 = (($aToB) + 4|0);
 HEAPF32[$156>>2] = $148;
 $157 = (($aToB) + 8|0);
 HEAPF32[$157>>2] = $149;
 $158 = (($aToB) + 12|0);
 HEAPF32[$158>>2] = Math_fround(0.0);
 $159 = (($aToB) + 16|0);
 HEAPF32[$159>>2] = $150;
 $160 = (($aToB) + 20|0);
 HEAPF32[$160>>2] = $151;
 $161 = (($aToB) + 24|0);
 HEAPF32[$161>>2] = $152;
 $162 = (($aToB) + 28|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 $163 = (($aToB) + 32|0);
 HEAPF32[$163>>2] = $153;
 $164 = (($aToB) + 36|0);
 HEAPF32[$164>>2] = $154;
 $165 = (($aToB) + 40|0);
 HEAPF32[$165>>2] = $155;
 $166 = (($aToB) + 44|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = HEAP32[$3>>2]|0;
 $168 = (($167) + 52|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($167) + 56|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($167) + 60|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround(HEAPF32[$vScale>>2]);
 $175 = Math_fround(HEAPF32[$18>>2]);
 $176 = Math_fround(HEAPF32[$19>>2]);
 $177 = Math_fround($169 * $174);
 $178 = Math_fround($171 * $175);
 $179 = Math_fround($173 * $176);
 $180 = !($177 <= $178);
 $$$i$i36 = $180 ? $178 : $177;
 $181 = !($$$i$i36 <= $179);
 $182 = $181 ? $179 : $$$i$i36;
 $183 = Math_fround($182 * Math_fround(0.25));
 $184 = !($7 <= $9);
 $$$i$i = $184 ? $9 : $7;
 $185 = !($$$i$i <= $11);
 $186 = $185 ? $11 : $$$i$i;
 $187 = Math_fround($186 * Math_fround(0.150000005960464477539));
 $188 = $183 > $187;
 $$$i = $188 ? $187 : $183;
 $189 = Math_fround($$$i * Math_fround(0.800000011920928955078));
 HEAPF32[$projectBreakingThreshold>>2] = $189;
 $190 = (($2) + 32|0);
 $191 = HEAP8[$190>>0]|0;
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($2,$aToB,$projectBreakingThreshold,0);
 $192 = HEAP8[$190>>0]|0;
 $193 = ($192<<24>>24)==($191<<24>>24);
 if ($193) {
  $194 = $191&255;
  $195 = (554160 + ($194<<2)|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = Math_fround($$$i * $196);
  $198 = (($2) + 16|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = (($2) + 20|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (($2) + 24|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = Math_fround($98 - $199);
  $205 = Math_fround($99 - $201);
  $206 = Math_fround($100 - $203);
  $207 = Math_fround(-$204);
  $208 = Math_fround(-$205);
  $209 = Math_fround(-$206);
  $210 = $204 > $207;
  $$$i$i$i$i = $210 ? $204 : $207;
  $211 = $205 > $208;
  $212 = $211 ? $205 : $208;
  $213 = $206 > $209;
  $$1$i$i$i$i = $213 ? $206 : $209;
  $214 = !($$$i$i$i$i >= $212);
  $$$i$i$i = $214 ? $212 : $$$i$i$i$i;
  $215 = !($$1$i$i$i$i >= Math_fround(0.0));
  $216 = $215 ? Math_fround(0.0) : $$$i$i$i$i;
  $217 = $$$i$i$i >= $216;
  $218 = $217 ? $$$i$i$i : $216;
  $219 = $218 > $197;
  if (!($219)) {
   $220 = (($2) + 4|0);
   $221 = (($2) + 8|0);
   $222 = Math_fround(HEAPF32[$220>>2]);
   $223 = Math_fround(HEAPF32[$2>>2]);
   $224 = Math_fround($127 * $222);
   $225 = Math_fround($126 * $223);
   $226 = (($2) + 12|0);
   $227 = Math_fround(HEAPF32[$221>>2]);
   $228 = Math_fround($128 * $227);
   $229 = Math_fround($224 + $225);
   $230 = Math_fround(HEAPF32[$226>>2]);
   $231 = Math_fround($107 * $230);
   $232 = Math_fround($229 + $228);
   $233 = (554200 + ($194<<2)|0);
   $234 = Math_fround($232 + $231);
   $235 = Math_fround(HEAPF32[$233>>2]);
   $236 = $235 > $234;
   if (!($236)) {
    $573 = ($191<<24>>24)==(0);
    if ($573) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($worldNormal9,$2,$transf1);
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($2,$contactBuffer,$worldNormal9,$transf1);
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $237 = Math_fround($$$i * Math_fround(0.0500000007450580596924));
 HEAPF32[$replaceBreakingThreshold>>2] = $237;
 ;HEAP32[$closestA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closestB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penDep>>2] = Math_fround(0.0);
 $238 = (($shape1) + 16|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($shape1) + 20|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = (($shape1) + 24|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($shape1) + 28|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 HEAPF32[$vQuat>>2] = $239;
 $246 = (($vQuat) + 4|0);
 HEAPF32[$246>>2] = $241;
 $247 = (($vQuat) + 8|0);
 HEAPF32[$247>>2] = $243;
 $248 = (($vQuat) + 12|0);
 HEAPF32[$248>>2] = $245;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$167,$zeroV,$vScale,$vQuat);
 $249 = (($box) + 64|0);
 ;HEAP32[$box+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $250 = (($box) + 80|0);
 HEAP32[$250>>2] = 3;
 $251 = (($box) + 16|0);
 $252 = (($box) + 20|0);
 ;HEAP32[$252+0>>2]=HEAP32[$zero$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$252+4>>2]=HEAP32[$zero$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$252+8>>2]=HEAP32[$zero$sroa$1$i$i$i$i+8>>2]|0;
 $253 = (($box) + 32|0);
 $254 = (($box) + 36|0);
 $255 = (($box) + 48|0);
 $256 = (($box) + 52|0);
 ;HEAP32[$$sroa$1$i$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i$i+12>>2]=0|0;
 ;HEAP32[$249+0>>2]=HEAP32[$$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$249+4>>2]=HEAP32[$$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$249+8>>2]=HEAP32[$$sroa$1$i$i$i$i+8>>2]|0;HEAP32[$249+12>>2]=HEAP32[$$sroa$1$i$i$i$i+12>>2]|0;
 $257 = (($box) + 144|0);
 HEAPF32[$257>>2] = $7;
 $258 = (($box) + 148|0);
 HEAPF32[$258>>2] = $9;
 $259 = (($box) + 152|0);
 HEAPF32[$259>>2] = $11;
 $260 = (($box) + 156|0);
 HEAPF32[$260>>2] = Math_fround(0.0);
 $261 = !($7 >= $9);
 $$$i23$i$i$i$i = $261 ? $9 : $7;
 $262 = !($$$i23$i$i$i$i >= $11);
 $263 = $262 ? $11 : $$$i23$i$i$i$i;
 $264 = Math_fround($263 * Math_fround(0.0299999993294477462769));
 $265 = $187 > $264;
 $$$i12$i$i$i$i = $265 ? $187 : $264;
 $266 = $186 > $$$i12$i$i$i$i;
 $$$i$i$i$i$i = $266 ? $$$i12$i$i$i$i : $186;
 HEAPF32[$251>>2] = $$$i$i$i$i$i;
 ;HEAP32[$252+0>>2]=HEAP32[$zero$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$252+4>>2]=HEAP32[$zero$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$252+8>>2]=HEAP32[$zero$sroa$1$i$i$i$i+8>>2]|0;
 $267 = Math_fround($186 * Math_fround(0.0500000007450580596924));
 HEAPF32[$253>>2] = $267;
 ;HEAP32[$254+0>>2]=HEAP32[$$sroa$1$i$i$i$i+0>>2]|0;HEAP32[$254+4>>2]=HEAP32[$$sroa$1$i$i$i$i+4>>2]|0;HEAP32[$254+8>>2]=HEAP32[$$sroa$1$i$i$i$i+8>>2]|0;
 $268 = Math_fround($$$i$i$i$i$i * $$$i$i$i$i$i);
 $269 = Math_fround($268 + $268);
 $270 = Math_fround($268 + $269);
 $271 = (Math_fround(Math_sqrt((Math_fround($270)))));
 $272 = Math_fround($271 - $$$i$i$i$i$i);
 HEAPF32[$255>>2] = $272;
 ;HEAP32[$256+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$256+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$256+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
 $273 = Math_fround(HEAPF32[$12>>2]);
 $274 = $273 == Math_fround(1.0);
 if ($274) {
  $275 = Math_fround(HEAPF32[$14>>2]);
  $276 = $275 == Math_fround(1.0);
  if ($276) {
   $277 = Math_fround(HEAPF32[$16>>2]);
   $278 = $277 == Math_fround(1.0);
   if ($278) {
    $279 = (($2) + 34|0);
    $280 = (($2) + 38|0);
    $281 = (($2) + 33|0);
    $282 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_10ShrunkBoxVENS0_24ShrunkConvexHullNoScaleVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($box,$convexHull,$aToB,$contactDist,$closestA,$closestB,$normal,$penDep,$279,$280,$281)|0);
    $294 = 1;$status$0 = $282;
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  $283 = (($2) + 34|0);
  $284 = (($2) + 38|0);
  $285 = (($2) + 33|0);
  $286 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_10ShrunkBoxVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($box,$convexHull,$aToB,$contactDist,$closestA,$closestB,$normal,$penDep,$283,$284,$285)|0);
  $294 = 0;$status$0 = $286;
 }
 HEAPF32[$2>>2] = $126;
 $287 = (($2) + 4|0);
 HEAPF32[$287>>2] = $127;
 $288 = (($2) + 8|0);
 HEAPF32[$288>>2] = $128;
 $289 = (($2) + 12|0);
 HEAPF32[$289>>2] = $107;
 $290 = (($2) + 16|0);
 HEAPF32[$290>>2] = $98;
 $291 = (($2) + 20|0);
 HEAPF32[$291>>2] = $99;
 $292 = (($2) + 24|0);
 HEAPF32[$292>>2] = $100;
 $293 = (($2) + 28|0);
 HEAPF32[$293>>2] = Math_fround(0.0);
 HEAP32[$numContacts>>2] = 0;
 if ((($status$0|0) == 0)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 } else if ((($status$0|0) == 3)) {
  $295 = (__ZN5physx2GuL31fullContactsGenerationBoxConvexERKNS_6PxVec3ERKNS0_4BoxVERNS0_11ConvexHullVERKNS_6shdfnd3aos12PsTransformVESD_PNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNSA_5Vec3VERKNSA_6FloatVEbb($6,$box,$convexHull,$transf0,$transf1,$contactBuffer,$numContacts,$contactBuffer,$2,$normal,$contactDist,$294,0)|0);
  $$1 = $295;
  STACKTOP = sp;return ($$1|0);
 } else {
  $296 = HEAP8[$190>>0]|0;
  $297 = ($296<<24>>24)==(0);
  $298 = ($status$0|0)==(1);
  if ($297) {
   do {
    if ($298) {
     $461 = Math_fround(HEAPF32[$closestA>>2]);
     $462 = (($closestA) + 4|0);
     $463 = Math_fround(HEAPF32[$462>>2]);
     $464 = (($closestA) + 8|0);
     $465 = Math_fround(HEAPF32[$464>>2]);
     $466 = Math_fround(HEAPF32[$129>>2]);
     $467 = Math_fround(HEAPF32[$130>>2]);
     $468 = Math_fround(HEAPF32[$131>>2]);
     $469 = Math_fround($461 - $466);
     $470 = Math_fround($463 - $467);
     $471 = Math_fround($465 - $468);
     $472 = Math_fround(HEAPF32[$aToB>>2]);
     $473 = Math_fround($469 * $472);
     $474 = Math_fround(HEAPF32[$156>>2]);
     $475 = Math_fround($470 * $474);
     $476 = Math_fround($473 + $475);
     $477 = Math_fround(HEAPF32[$157>>2]);
     $478 = Math_fround($471 * $477);
     $479 = Math_fround($476 + $478);
     $480 = Math_fround(HEAPF32[$159>>2]);
     $481 = Math_fround($469 * $480);
     $482 = Math_fround(HEAPF32[$160>>2]);
     $483 = Math_fround($470 * $482);
     $484 = Math_fround($481 + $483);
     $485 = Math_fround(HEAPF32[$161>>2]);
     $486 = Math_fround($471 * $485);
     $487 = Math_fround($484 + $486);
     $488 = Math_fround(HEAPF32[$163>>2]);
     $489 = Math_fround($469 * $488);
     $490 = Math_fround(HEAPF32[$164>>2]);
     $491 = Math_fround($470 * $490);
     $492 = Math_fround($489 + $491);
     $493 = Math_fround(HEAPF32[$165>>2]);
     $494 = Math_fround($471 * $493);
     $495 = Math_fround($492 + $494);
     $496 = Math_fround(HEAPF32[$normal>>2]);
     $497 = (($normal) + 4|0);
     $498 = Math_fround(HEAPF32[$497>>2]);
     $499 = (($normal) + 8|0);
     $500 = Math_fround(HEAPF32[$499>>2]);
     $501 = Math_fround(HEAPF32[$penDep>>2]);
     HEAPF32[$contactBuffer>>2] = $479;
     $502 = (($contactBuffer) + 4|0);
     HEAPF32[$502>>2] = $487;
     $503 = (($contactBuffer) + 8|0);
     HEAPF32[$503>>2] = $495;
     $504 = (($contactBuffer) + 12|0);
     HEAPF32[$504>>2] = Math_fround(0.0);
     $505 = (($contactBuffer) + 16|0);
     ;HEAP32[$505+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$505+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$505+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$505+12>>2]=HEAP32[$closestB+12>>2]|0;
     HEAP32[$numContacts>>2] = 1;
     $506 = (($contactBuffer) + 32|0);
     HEAPF32[$506>>2] = $496;
     $507 = (($contactBuffer) + 36|0);
     HEAPF32[$507>>2] = $498;
     $508 = (($contactBuffer) + 40|0);
     HEAPF32[$508>>2] = $500;
     $509 = (($contactBuffer) + 44|0);
     HEAPF32[$509>>2] = $501;
     $doOverlapTest3$1$off0 = 0;
    } else {
     $510 = ($status$0|0)==(6);
     if ($510) {
      $511 = (($supportMap6) + 4|0);
      HEAP8[$511>>0] = 0;
      HEAP32[$supportMap6>>2] = ((550864 + 8|0));
      $512 = (($supportMap6) + 8|0);
      HEAP32[$512>>2] = $box;
      $513 = (($supportMap6) + 12|0);
      HEAP32[$513>>2] = $convexHull;
      $514 = (($supportMap6) + 16|0);
      HEAP32[$514>>2] = $aToB;
      $515 = (($2) + 34|0);
      $516 = (($2) + 38|0);
      $517 = (($2) + 33|0);
      $518 = HEAP8[$517>>0]|0;
      $519 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($box,$convexHull,$supportMap6,$515,$516,$518,$closestA,$closestB,$normal,$penDep,0)|0);
      if ((($519|0) == 6)) {
       $520 = Math_fround(HEAPF32[$closestA>>2]);
       $521 = (($closestA) + 4|0);
       $522 = Math_fround(HEAPF32[$521>>2]);
       $523 = (($closestA) + 8|0);
       $524 = Math_fround(HEAPF32[$523>>2]);
       $525 = Math_fround(HEAPF32[$129>>2]);
       $526 = Math_fround(HEAPF32[$130>>2]);
       $527 = Math_fround(HEAPF32[$131>>2]);
       $528 = Math_fround($520 - $525);
       $529 = Math_fround($522 - $526);
       $530 = Math_fround($524 - $527);
       $531 = Math_fround(HEAPF32[$aToB>>2]);
       $532 = Math_fround($528 * $531);
       $533 = Math_fround(HEAPF32[$156>>2]);
       $534 = Math_fround($529 * $533);
       $535 = Math_fround($532 + $534);
       $536 = Math_fround(HEAPF32[$157>>2]);
       $537 = Math_fround($530 * $536);
       $538 = Math_fround($535 + $537);
       $539 = Math_fround(HEAPF32[$159>>2]);
       $540 = Math_fround($528 * $539);
       $541 = Math_fround(HEAPF32[$160>>2]);
       $542 = Math_fround($529 * $541);
       $543 = Math_fround($540 + $542);
       $544 = Math_fround(HEAPF32[$161>>2]);
       $545 = Math_fround($530 * $544);
       $546 = Math_fround($543 + $545);
       $547 = Math_fround(HEAPF32[$163>>2]);
       $548 = Math_fround($528 * $547);
       $549 = Math_fround(HEAPF32[$164>>2]);
       $550 = Math_fround($529 * $549);
       $551 = Math_fround($548 + $550);
       $552 = Math_fround(HEAPF32[$165>>2]);
       $553 = Math_fround($530 * $552);
       $554 = Math_fround($551 + $553);
       $555 = Math_fround(HEAPF32[$normal>>2]);
       $556 = (($normal) + 4|0);
       $557 = Math_fround(HEAPF32[$556>>2]);
       $558 = (($normal) + 8|0);
       $559 = Math_fround(HEAPF32[$558>>2]);
       $560 = Math_fround(HEAPF32[$penDep>>2]);
       $561 = HEAP32[$numContacts>>2]|0;
       $562 = (($contactBuffer) + (($561*48)|0)|0);
       HEAPF32[$562>>2] = $538;
       $563 = ((($contactBuffer) + (($561*48)|0)|0) + 4|0);
       HEAPF32[$563>>2] = $546;
       $564 = ((($contactBuffer) + (($561*48)|0)|0) + 8|0);
       HEAPF32[$564>>2] = $554;
       $565 = ((($contactBuffer) + (($561*48)|0)|0) + 12|0);
       HEAPF32[$565>>2] = Math_fround(0.0);
       $566 = ((($contactBuffer) + (($561*48)|0)|0) + 16|0);
       ;HEAP32[$566+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$566+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$566+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$566+12>>2]=HEAP32[$closestB+12>>2]|0;
       $567 = (($561) + 1)|0;
       HEAP32[$numContacts>>2] = $567;
       $568 = ((($contactBuffer) + (($561*48)|0)|0) + 32|0);
       HEAPF32[$568>>2] = $555;
       $569 = ((($contactBuffer) + (($561*48)|0)|0) + 36|0);
       HEAPF32[$569>>2] = $557;
       $570 = ((($contactBuffer) + (($561*48)|0)|0) + 40|0);
       HEAPF32[$570>>2] = $559;
       $571 = ((($contactBuffer) + (($561*48)|0)|0) + 44|0);
       HEAPF32[$571>>2] = $560;
       $doOverlapTest3$1$off0 = 0;
       break;
      } else if ((($519|0) == 4)) {
       $doOverlapTest3$1$off0 = 1;
       break;
      } else {
       $doOverlapTest3$1$off0 = 0;
       break;
      }
     } else {
      $doOverlapTest3$1$off0 = 0;
     }
    }
   } while(0);
   $572 = (__ZN5physx2GuL31fullContactsGenerationBoxConvexERKNS_6PxVec3ERKNS0_4BoxVERNS0_11ConvexHullVERKNS_6shdfnd3aos12PsTransformVESD_PNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNSA_5Vec3VERKNSA_6FloatVEbb($6,$box,$convexHull,$transf0,$transf1,$contactBuffer,$numContacts,$contactBuffer,$2,$normal,$contactDist,$294,$doOverlapTest3$1$off0)|0);
   $$1 = $572;
   STACKTOP = sp;return ($$1|0);
  }
  do {
   if ($298) {
    $299 = Math_fround(HEAPF32[$closestA>>2]);
    $300 = (($closestA) + 4|0);
    $301 = Math_fround(HEAPF32[$300>>2]);
    $302 = (($closestA) + 8|0);
    $303 = Math_fround(HEAPF32[$302>>2]);
    $304 = Math_fround(HEAPF32[$129>>2]);
    $305 = Math_fround(HEAPF32[$130>>2]);
    $306 = Math_fround(HEAPF32[$131>>2]);
    $307 = Math_fround($299 - $304);
    $308 = Math_fround($301 - $305);
    $309 = Math_fround($303 - $306);
    $310 = Math_fround(HEAPF32[$aToB>>2]);
    $311 = Math_fround($307 * $310);
    $312 = Math_fround(HEAPF32[$156>>2]);
    $313 = Math_fround($308 * $312);
    $314 = Math_fround($311 + $313);
    $315 = Math_fround(HEAPF32[$157>>2]);
    $316 = Math_fround($309 * $315);
    $317 = Math_fround($314 + $316);
    $318 = Math_fround(HEAPF32[$159>>2]);
    $319 = Math_fround($307 * $318);
    $320 = Math_fround(HEAPF32[$160>>2]);
    $321 = Math_fround($308 * $320);
    $322 = Math_fround($319 + $321);
    $323 = Math_fround(HEAPF32[$161>>2]);
    $324 = Math_fround($309 * $323);
    $325 = Math_fround($322 + $324);
    $326 = Math_fround(HEAPF32[$163>>2]);
    $327 = Math_fround($307 * $326);
    $328 = Math_fround(HEAPF32[$164>>2]);
    $329 = Math_fround($308 * $328);
    $330 = Math_fround($327 + $329);
    $331 = Math_fround(HEAPF32[$165>>2]);
    $332 = Math_fround($309 * $331);
    $333 = Math_fround($330 + $332);
    $334 = Math_fround(HEAPF32[$normal>>2]);
    $335 = (($normal) + 4|0);
    $336 = Math_fround(HEAPF32[$335>>2]);
    $337 = (($normal) + 8|0);
    $338 = Math_fround(HEAPF32[$337>>2]);
    $339 = Math_fround(HEAPF32[$penDep>>2]);
    HEAPF32[$localNormalPen>>2] = $334;
    $340 = (($localNormalPen) + 4|0);
    HEAPF32[$340>>2] = $336;
    $341 = (($localNormalPen) + 8|0);
    HEAPF32[$341>>2] = $338;
    $342 = (($localNormalPen) + 12|0);
    HEAPF32[$342>>2] = $339;
    HEAPF32[$contactBuffer>>2] = $317;
    $343 = (($contactBuffer) + 4|0);
    HEAPF32[$343>>2] = $325;
    $344 = (($contactBuffer) + 8|0);
    HEAPF32[$344>>2] = $333;
    $345 = (($contactBuffer) + 12|0);
    HEAPF32[$345>>2] = Math_fround(0.0);
    $346 = (($contactBuffer) + 16|0);
    ;HEAP32[$346+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$346+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$346+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$346+12>>2]=HEAP32[$closestB+12>>2]|0;
    HEAP32[$numContacts>>2] = 1;
    $347 = (($contactBuffer) + 32|0);
    ;HEAP32[$347+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$347+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$347+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$347+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
    HEAPF32[$0>>2] = $317;
    $348 = (($0) + 4|0);
    HEAPF32[$348>>2] = $325;
    $349 = (($0) + 8|0);
    HEAPF32[$349>>2] = $333;
    $350 = (($0) + 12|0);
    HEAPF32[$350>>2] = Math_fround(0.0);
    (__ZN5physx2Gu25PersistentContactManifold16addManifoldPointERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($2,$0,$closestB,$localNormalPen,$replaceBreakingThreshold)|0);
    label = 16;
   } else {
    $351 = (($supportMap) + 4|0);
    HEAP8[$351>>0] = 0;
    HEAP32[$supportMap>>2] = ((550864 + 8|0));
    $352 = (($supportMap) + 8|0);
    HEAP32[$352>>2] = $box;
    $353 = (($supportMap) + 12|0);
    HEAP32[$353>>2] = $convexHull;
    $354 = (($supportMap) + 16|0);
    HEAP32[$354>>2] = $aToB;
    $355 = (($2) + 34|0);
    $356 = (($2) + 38|0);
    $357 = (($2) + 33|0);
    $358 = HEAP8[$357>>0]|0;
    $359 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($box,$convexHull,$supportMap,$355,$356,$358,$closestA,$closestB,$normal,$penDep,0)|0);
    if ((($359|0) == 4)) {
     $$pre$phiZ2D = $box;$doOverlapTest$1$off0138 = 1;
     break;
    } else if (!((($359|0) == 6))) {
     label = 16;
     break;
    }
    $360 = Math_fround(HEAPF32[$closestA>>2]);
    $361 = (($closestA) + 4|0);
    $362 = Math_fround(HEAPF32[$361>>2]);
    $363 = (($closestA) + 8|0);
    $364 = Math_fround(HEAPF32[$363>>2]);
    $365 = Math_fround(HEAPF32[$129>>2]);
    $366 = Math_fround(HEAPF32[$130>>2]);
    $367 = Math_fround(HEAPF32[$131>>2]);
    $368 = Math_fround($360 - $365);
    $369 = Math_fround($362 - $366);
    $370 = Math_fround($364 - $367);
    $371 = Math_fround(HEAPF32[$aToB>>2]);
    $372 = Math_fround($368 * $371);
    $373 = Math_fround(HEAPF32[$156>>2]);
    $374 = Math_fround($369 * $373);
    $375 = Math_fround($372 + $374);
    $376 = Math_fround(HEAPF32[$157>>2]);
    $377 = Math_fround($370 * $376);
    $378 = Math_fround($375 + $377);
    $379 = Math_fround(HEAPF32[$159>>2]);
    $380 = Math_fround($368 * $379);
    $381 = Math_fround(HEAPF32[$160>>2]);
    $382 = Math_fround($369 * $381);
    $383 = Math_fround($380 + $382);
    $384 = Math_fround(HEAPF32[$161>>2]);
    $385 = Math_fround($370 * $384);
    $386 = Math_fround($383 + $385);
    $387 = Math_fround(HEAPF32[$163>>2]);
    $388 = Math_fround($368 * $387);
    $389 = Math_fround(HEAPF32[$164>>2]);
    $390 = Math_fround($369 * $389);
    $391 = Math_fround($388 + $390);
    $392 = Math_fround(HEAPF32[$165>>2]);
    $393 = Math_fround($370 * $392);
    $394 = Math_fround($391 + $393);
    HEAPF32[$localPointA1>>2] = $378;
    $395 = (($localPointA1) + 4|0);
    HEAPF32[$395>>2] = $386;
    $396 = (($localPointA1) + 8|0);
    HEAPF32[$396>>2] = $394;
    $397 = (($localPointA1) + 12|0);
    HEAPF32[$397>>2] = Math_fround(0.0);
    $398 = Math_fround(HEAPF32[$normal>>2]);
    $399 = (($normal) + 4|0);
    $400 = Math_fround(HEAPF32[$399>>2]);
    $401 = (($normal) + 8|0);
    $402 = Math_fround(HEAPF32[$401>>2]);
    $403 = Math_fround(HEAPF32[$penDep>>2]);
    HEAPF32[$localNormalPen2>>2] = $398;
    $404 = (($localNormalPen2) + 4|0);
    HEAPF32[$404>>2] = $400;
    $405 = (($localNormalPen2) + 8|0);
    HEAPF32[$405>>2] = $402;
    $406 = (($localNormalPen2) + 12|0);
    HEAPF32[$406>>2] = $403;
    $407 = HEAP32[$numContacts>>2]|0;
    $408 = (($contactBuffer) + (($407*48)|0)|0);
    ;HEAP32[$408+0>>2]=HEAP32[$localPointA1+0>>2]|0;HEAP32[$408+4>>2]=HEAP32[$localPointA1+4>>2]|0;HEAP32[$408+8>>2]=HEAP32[$localPointA1+8>>2]|0;HEAP32[$408+12>>2]=HEAP32[$localPointA1+12>>2]|0;
    $409 = ((($contactBuffer) + (($407*48)|0)|0) + 16|0);
    ;HEAP32[$409+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$409+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$409+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$409+12>>2]=HEAP32[$closestB+12>>2]|0;
    $410 = (($407) + 1)|0;
    HEAP32[$numContacts>>2] = $410;
    $411 = ((($contactBuffer) + (($407*48)|0)|0) + 32|0);
    ;HEAP32[$411+0>>2]=HEAP32[$localNormalPen2+0>>2]|0;HEAP32[$411+4>>2]=HEAP32[$localNormalPen2+4>>2]|0;HEAP32[$411+8>>2]=HEAP32[$localNormalPen2+8>>2]|0;HEAP32[$411+12>>2]=HEAP32[$localNormalPen2+12>>2]|0;
    (__ZN5physx2Gu25PersistentContactManifold16addManifoldPointERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($2,$localPointA1,$closestB,$localNormalPen2,$replaceBreakingThreshold)|0);
    label = 16;
   }
  } while(0);
  do {
   if ((label|0) == 16) {
    $412 = HEAP8[$190>>0]|0;
    $413 = ($412&255)<($191&255);
    if ($413) {
     $$pre$phiZ2D = $box;$doOverlapTest$1$off0138 = 0;
     break;
    }
    $415 = Math_fround(HEAPF32[$transf1>>2]);
    $416 = Math_fround(HEAPF32[$54>>2]);
    $417 = Math_fround(HEAPF32[$55>>2]);
    $418 = Math_fround(HEAPF32[$56>>2]);
    $419 = Math_fround(HEAPF32[$normal>>2]);
    $420 = (($normal) + 4|0);
    $421 = Math_fround(HEAPF32[$420>>2]);
    $422 = (($normal) + 8|0);
    $423 = Math_fround(HEAPF32[$422>>2]);
    $424 = Math_fround($418 * $418);
    $425 = Math_fround($424 + Math_fround(-0.5));
    $426 = Math_fround($419 * $425);
    $427 = Math_fround($425 * $421);
    $428 = Math_fround($425 * $423);
    $429 = Math_fround($416 * $423);
    $430 = Math_fround($417 * $421);
    $431 = Math_fround($429 - $430);
    $432 = Math_fround($417 * $419);
    $433 = Math_fround($415 * $423);
    $434 = Math_fround($432 - $433);
    $435 = Math_fround($415 * $421);
    $436 = Math_fround($416 * $419);
    $437 = Math_fround($435 - $436);
    $438 = Math_fround($418 * $431);
    $439 = Math_fround($418 * $434);
    $440 = Math_fround($418 * $437);
    $441 = Math_fround($426 + $438);
    $442 = Math_fround($427 + $439);
    $443 = Math_fround($428 + $440);
    $444 = Math_fround($415 * $419);
    $445 = Math_fround($416 * $421);
    $446 = Math_fround($444 + $445);
    $447 = Math_fround($417 * $423);
    $448 = Math_fround($446 + $447);
    $449 = Math_fround($415 * $448);
    $450 = Math_fround($416 * $448);
    $451 = Math_fround($417 * $448);
    $452 = Math_fround($449 + $441);
    $453 = Math_fround($450 + $442);
    $454 = Math_fround($443 + $451);
    $455 = Math_fround($452 * Math_fround(2.0));
    $456 = Math_fround($453 * Math_fround(2.0));
    $457 = Math_fround($454 * Math_fround(2.0));
    HEAPF32[$worldNormal>>2] = $455;
    $458 = (($worldNormal) + 4|0);
    HEAPF32[$458>>2] = $456;
    $459 = (($worldNormal) + 8|0);
    HEAPF32[$459>>2] = $457;
    $460 = (($worldNormal) + 12|0);
    HEAPF32[$460>>2] = Math_fround(0.0);
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($2,$contactBuffer,$worldNormal,$transf1);
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
  } while(0);
  $414 = (__ZN5physx2GuL31fullContactsGenerationBoxConvexERKNS_6PxVec3ERKNS0_4BoxVERNS0_11ConvexHullVERKNS_6shdfnd3aos12PsTransformVESD_PNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNSA_5Vec3VERKNSA_6FloatVEbb($6,$$pre$phiZ2D,$convexHull,$transf0,$transf1,$contactBuffer,$numContacts,$contactBuffer,$2,$normal,$contactDist,$294,$doOverlapTest$1$off0138)|0);
  $$1 = $414;
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZN5physx2GuL31fullContactsGenerationBoxConvexERKNS_6PxVec3ERKNS0_4BoxVERNS0_11ConvexHullVERKNS_6shdfnd3aos12PsTransformVESD_PNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNSA_5Vec3VERKNSA_6FloatVEbb($halfExtents,$box,$convexHull,$transf0,$transf1,$manifoldContacts,$numContacts,$contactBuffer,$manifold,$normal,$contactDist,$idtScale,$doOverlapTest) {
 $halfExtents = $halfExtents|0;
 $box = $box|0;
 $convexHull = $convexHull|0;
 $transf0 = $transf0|0;
 $transf1 = $transf1|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactBuffer = $contactBuffer|0;
 $manifold = $manifold|0;
 $normal = $normal|0;
 $contactDist = $contactDist|0;
 $idtScale = $idtScale|0;
 $doOverlapTest = $doOverlapTest|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buff1 = 0, $identity = 0, $map0 = 0, $or$cond = 0, $polyBox0 = 0, $polyData0 = 0, $polyData1 = 0, $worldNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $polyData0 = sp + 488|0;
 $polyBox0 = sp + 264|0;
 $polyData1 = sp + 128|0;
 $identity = sp + 64|0;
 $map0 = sp;
 $buff1 = sp + 200|0;
 $worldNormal = sp + 112|0;
 __ZN5physx2Gu15PCMPolygonalBoxC2ERKNS_6PxVec3E($polyBox0,$halfExtents);
 __ZNK5physx2Gu15PCMPolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($polyBox0,$polyData0);
 $0 = (($polyData0) + 32|0);
 HEAP32[$0>>2] = 554136;
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHull,$idtScale,$polyData1);
 HEAPF32[$identity>>2] = Math_fround(1.0);
 $1 = (($identity) + 4|0);
 $2 = (($identity) + 20|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($identity) + 24|0);
 $4 = (($identity) + 40|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($identity) + 44|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($map0) + 32|0);
 HEAP32[$6>>2] = $transf0;
 $7 = (($map0) + 36|0);
 HEAP32[$7>>2] = $identity;
 $8 = (($map0) + 40|0);
 HEAP32[$8>>2] = $identity;
 $9 = (($map0) + 44|0);
 HEAP8[$9>>0] = 1;
 HEAP32[$map0>>2] = ((546776 + 8|0));
 $10 = (($map0) + 48|0);
 HEAP32[$10>>2] = $box;
 $11 = (($convexHull) + 96|0);
 $12 = (($convexHull) + 144|0);
 $13 = (($buff1) + 32|0);
 HEAP32[$13>>2] = $transf1;
 $14 = (($buff1) + 36|0);
 HEAP32[$14>>2] = $11;
 $15 = (($buff1) + 40|0);
 HEAP32[$15>>2] = $12;
 $16 = (($buff1) + 44|0);
 $17 = $idtScale&1;
 HEAP8[$16>>0] = $17;
 if ($idtScale) {
  HEAP32[$buff1>>2] = ((546744 + 8|0));
  $18 = (($buff1) + 48|0);
  HEAP32[$18>>2] = $convexHull;
 } else {
  HEAP32[$buff1>>2] = ((546712 + 8|0));
  $19 = (($buff1) + 48|0);
  HEAP32[$19>>2] = $convexHull;
 }
 $20 = HEAP32[$numContacts>>2]|0;
 $21 = (__ZN5physx2Gu27generateFullContactManifoldERNS0_13PolygonalDataES2_PNS0_12SupportLocalES4_PNS0_17PersistentContactERjRKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VEb($polyData0,$polyData1,$map0,$buff1,$manifoldContacts,$numContacts,$contactDist,$normal,$doOverlapTest)|0);
 if (!($21)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = HEAP32[$numContacts>>2]|0;
 $23 = ($22|0)!=($20|0);
 $24 = ($20|0)!=(0);
 $or$cond = $23 & $24;
 if ($or$cond) {
  $25 = (($22) + -1)|0;
  HEAP32[$numContacts>>2] = $25;
  $26 = (($manifoldContacts) + 48|0);
  $$02 = $26;$27 = $25;
 } else {
  $$02 = $manifoldContacts;$27 = $22;
 }
 __ZN5physx2Gu25PersistentContactManifold24addBatchManifoldContactsEPKNS0_17PersistentContactEj($manifold,$$02,$27);
 __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($worldNormal,$manifold,$transf1);
 __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($manifold,$contactBuffer,$worldNormal,$transf1);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu20pcmContactCapsuleBoxERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i$i27 = Math_fround(0), $$1 = 0, $$1$i$i$i$i = Math_fround(0), $$pre = 0, $$pre$phi153Z2D = 0, $$pre$phi155Z2D = 0, $$pre$phiZ2D = 0, $$pre152 = 0, $$pre154 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0);
 var $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0);
 var $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0;
 var $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0);
 var $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0;
 var $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0);
 var $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0);
 var $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0);
 var $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = 0, $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0);
 var $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0);
 var $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = 0, $463 = 0, $464 = 0, $465 = Math_fround(0);
 var $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0);
 var $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0);
 var $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0;
 var $aToB_ = 0, $box = 0, $capsule = 0, $capsuleRadius = 0, $closestA = 0, $closestB = 0, $contactDist = 0, $doOverlapTest$0$off0158 = 0, $localNormalPen3 = 0, $normal = 0, $numContacts = 0, $or$cond = 0, $penDep = 0, $projectBreakingThreshold = 0, $replaceBreakingThreshold = 0, $transf0 = 0, $transf1 = 0, $worldNormal = 0, $zero$sroa$1 = 0, $zero$sroa$1$i$i$i26 = 0;
 var $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 768|0;
 $zero$sroa$1$i$i$i26 = sp + 32|0;
 $0 = sp + 704|0;
 $zeroV = sp + 672|0;
 $contactDist = sp + 688|0;
 $transf0 = sp + 640|0;
 $transf1 = sp + 608|0;
 $aToB_ = sp + 544|0;
 $capsuleRadius = sp + 528|0;
 $projectBreakingThreshold = sp + 512|0;
 $closestA = sp + 16|0;
 $closestB = sp;
 $normal = sp + 64|0;
 $zero$sroa$1 = sp + 744|0;
 $penDep = sp + 48|0;
 $aToB = sp + 80|0;
 $box = sp + 144|0;
 $capsule = sp + 304|0;
 $numContacts = sp + 756|0;
 $1 = sp + 732|0;
 $2 = sp + 720|0;
 $replaceBreakingThreshold = sp + 448|0;
 $localNormalPen3 = sp + 464|0;
 $3 = sp + 480|0;
 $worldNormal = sp + 496|0;
 $4 = HEAP32[$cache>>2]|0;
 $5 = $4;
 $6 = $4;
 $7 = (($6) + 256|0);
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $8 = (($shape1) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($shape1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($shape1) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$contactDistance>>2]);
 HEAPF32[$contactDist>>2] = $14;
 $15 = Math_fround(HEAPF32[$transform0>>2]);
 $16 = (($transform0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($transform0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($transform0) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transform0) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($22) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($22) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$transf0>>2] = $15;
 $28 = (($transf0) + 4|0);
 HEAPF32[$28>>2] = $17;
 $29 = (($transf0) + 8|0);
 HEAPF32[$29>>2] = $19;
 $30 = (($transf0) + 12|0);
 HEAPF32[$30>>2] = $21;
 $31 = (($transf0) + 16|0);
 HEAPF32[$31>>2] = $23;
 $32 = (($transf0) + 20|0);
 HEAPF32[$32>>2] = $25;
 $33 = (($transf0) + 24|0);
 HEAPF32[$33>>2] = $27;
 $34 = (($transf0) + 28|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = Math_fround(HEAPF32[$transform1>>2]);
 $36 = (($transform1) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($transform1) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($transform1) + 12|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($transform1) + 16|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($42) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($42) + 8|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$transf1>>2] = $35;
 $48 = (($transf1) + 4|0);
 HEAPF32[$48>>2] = $37;
 $49 = (($transf1) + 8|0);
 HEAPF32[$49>>2] = $39;
 $50 = (($transf1) + 12|0);
 HEAPF32[$50>>2] = $41;
 $51 = (($transf1) + 16|0);
 HEAPF32[$51>>2] = $43;
 $52 = (($transf1) + 20|0);
 HEAPF32[$52>>2] = $45;
 $53 = (($transf1) + 24|0);
 HEAPF32[$53>>2] = $47;
 $54 = (($transf1) + 28|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = Math_fround(-$35);
 $56 = Math_fround(-$37);
 $57 = Math_fround(-$39);
 $58 = Math_fround($23 - $43);
 $59 = Math_fround($25 - $45);
 $60 = Math_fround($27 - $47);
 $61 = Math_fround($41 * $41);
 $62 = Math_fround($61 + Math_fround(-0.5));
 $63 = Math_fround($62 * $58);
 $64 = Math_fround($62 * $59);
 $65 = Math_fround($62 * $60);
 $66 = Math_fround($60 * $56);
 $67 = Math_fround($59 * $57);
 $68 = Math_fround($66 - $67);
 $69 = Math_fround($58 * $57);
 $70 = Math_fround($60 * $55);
 $71 = Math_fround($69 - $70);
 $72 = Math_fround($59 * $55);
 $73 = Math_fround($58 * $56);
 $74 = Math_fround($72 - $73);
 $75 = Math_fround($41 * $68);
 $76 = Math_fround($41 * $71);
 $77 = Math_fround($41 * $74);
 $78 = Math_fround($63 + $75);
 $79 = Math_fround($64 + $76);
 $80 = Math_fround($65 + $77);
 $81 = Math_fround($58 * $55);
 $82 = Math_fround($59 * $56);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($60 * $57);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($85 * $55);
 $87 = Math_fround($85 * $56);
 $88 = Math_fround($85 * $57);
 $89 = Math_fround($86 + $78);
 $90 = Math_fround($87 + $79);
 $91 = Math_fround($80 + $88);
 $92 = Math_fround($89 * Math_fround(2.0));
 $93 = Math_fround($90 * Math_fround(2.0));
 $94 = Math_fround($91 * Math_fround(2.0));
 $95 = Math_fround($41 * $21);
 $96 = Math_fround($15 * $55);
 $97 = Math_fround($17 * $56);
 $98 = Math_fround($96 + $97);
 $99 = Math_fround($19 * $57);
 $100 = Math_fround($98 + $99);
 $101 = Math_fround($95 - $100);
 $102 = Math_fround($21 * $55);
 $103 = Math_fround($21 * $56);
 $104 = Math_fround($21 * $57);
 $105 = Math_fround($41 * $15);
 $106 = Math_fround($41 * $17);
 $107 = Math_fround($41 * $19);
 $108 = Math_fround($19 * $56);
 $109 = Math_fround($17 * $57);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($15 * $57);
 $112 = Math_fround($19 * $55);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($17 * $55);
 $115 = Math_fround($15 * $56);
 $116 = Math_fround($114 - $115);
 $117 = Math_fround($105 + $102);
 $118 = Math_fround($106 + $103);
 $119 = Math_fround($107 + $104);
 $120 = Math_fround($110 + $117);
 $121 = Math_fround($113 + $118);
 $122 = Math_fround($116 + $119);
 $123 = (($aToB_) + 48|0);
 HEAPF32[$123>>2] = $92;
 $124 = (($aToB_) + 52|0);
 HEAPF32[$124>>2] = $93;
 $125 = (($aToB_) + 56|0);
 HEAPF32[$125>>2] = $94;
 $126 = (($aToB_) + 60|0);
 HEAPF32[$126>>2] = Math_fround(0.0);
 $127 = Math_fround($120 + $120);
 $128 = Math_fround($121 + $121);
 $129 = Math_fround($122 + $122);
 $130 = Math_fround($120 * $127);
 $131 = Math_fround($121 * $128);
 $132 = Math_fround($122 * $129);
 $133 = Math_fround($121 * $127);
 $134 = Math_fround($122 * $127);
 $135 = Math_fround($101 * $127);
 $136 = Math_fround($122 * $128);
 $137 = Math_fround($101 * $128);
 $138 = Math_fround($101 * $129);
 $139 = Math_fround(Math_fround(1.0) - $130);
 $140 = Math_fround(Math_fround(1.0) - $131);
 $141 = Math_fround($140 - $132);
 $142 = Math_fround($133 + $138);
 $143 = Math_fround($134 - $137);
 $144 = Math_fround($133 - $138);
 $145 = Math_fround($139 - $132);
 $146 = Math_fround($136 + $135);
 $147 = Math_fround($134 + $137);
 $148 = Math_fround($136 - $135);
 $149 = Math_fround($139 - $131);
 HEAPF32[$aToB_>>2] = $141;
 $150 = (($aToB_) + 4|0);
 HEAPF32[$150>>2] = $142;
 $151 = (($aToB_) + 8|0);
 HEAPF32[$151>>2] = $143;
 $152 = (($aToB_) + 12|0);
 HEAPF32[$152>>2] = Math_fround(0.0);
 $153 = (($aToB_) + 16|0);
 HEAPF32[$153>>2] = $144;
 $154 = (($aToB_) + 20|0);
 HEAPF32[$154>>2] = $145;
 $155 = (($aToB_) + 24|0);
 HEAPF32[$155>>2] = $146;
 $156 = (($aToB_) + 28|0);
 HEAPF32[$156>>2] = Math_fround(0.0);
 $157 = (($aToB_) + 32|0);
 HEAPF32[$157>>2] = $147;
 $158 = (($aToB_) + 36|0);
 HEAPF32[$158>>2] = $148;
 $159 = (($aToB_) + 40|0);
 HEAPF32[$159>>2] = $149;
 $160 = (($aToB_) + 44|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 $161 = (($shape0) + 4|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 HEAPF32[$capsuleRadius>>2] = $162;
 $163 = (($shape0) + 8|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = (($5) + 32|0);
 $166 = HEAP8[$165>>0]|0;
 $167 = !($9 <= $11);
 $$$i$i = $167 ? $11 : $9;
 $168 = !($$$i$i <= $13);
 $169 = $168 ? $13 : $$$i$i;
 $170 = Math_fround($169 * Math_fround(0.150000005960464477539));
 $171 = $170 > $162;
 $$$i = $171 ? $162 : $170;
 $172 = Math_fround($$$i * Math_fround(0.800000011920928955078));
 HEAPF32[$projectBreakingThreshold>>2] = $172;
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($5,$aToB_,$projectBreakingThreshold,0);
 $173 = HEAP8[$165>>0]|0;
 $174 = ($173<<24>>24)!=($166<<24>>24);
 if ($174) {
  $$pre = (($5) + 16|0);
  $$pre152 = (($5) + 20|0);
  $$pre154 = (($5) + 24|0);
  $$pre$phi153Z2D = $$pre152;$$pre$phi155Z2D = $$pre154;$$pre$phiZ2D = $$pre;
 } else {
  $175 = $166&255;
  $176 = (554184 + ($175<<2)|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround($$$i * $177);
  $179 = (($5) + 16|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = (($5) + 20|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = (($5) + 24|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = Math_fround($92 - $180);
  $186 = Math_fround($93 - $182);
  $187 = Math_fround($94 - $184);
  $188 = Math_fround(-$185);
  $189 = Math_fround(-$186);
  $190 = Math_fround(-$187);
  $191 = $185 > $188;
  $$$i$i$i$i27 = $191 ? $185 : $188;
  $192 = $186 > $189;
  $193 = $192 ? $186 : $189;
  $194 = $187 > $190;
  $$1$i$i$i$i = $194 ? $187 : $190;
  $195 = !($$$i$i$i$i27 >= $193);
  $$$i$i$i = $195 ? $193 : $$$i$i$i$i27;
  $196 = !($$1$i$i$i$i >= Math_fround(0.0));
  $197 = $196 ? Math_fround(0.0) : $$$i$i$i$i27;
  $198 = $$$i$i$i >= $197;
  $199 = $198 ? $$$i$i$i : $197;
  $200 = $199 > $178;
  if ($200) {
   $$pre$phi153Z2D = $181;$$pre$phi155Z2D = $183;$$pre$phiZ2D = $179;
  } else {
   $201 = (($5) + 4|0);
   $202 = (($5) + 8|0);
   $203 = Math_fround(HEAPF32[$201>>2]);
   $204 = Math_fround(HEAPF32[$5>>2]);
   $205 = Math_fround($121 * $203);
   $206 = Math_fround($120 * $204);
   $207 = (($5) + 12|0);
   $208 = Math_fround(HEAPF32[$202>>2]);
   $209 = Math_fround($122 * $208);
   $210 = Math_fround($205 + $206);
   $211 = Math_fround(HEAPF32[$207>>2]);
   $212 = Math_fround($101 * $211);
   $213 = Math_fround($210 + $209);
   $214 = (554224 + ($175<<2)|0);
   $215 = Math_fround($213 + $212);
   $216 = Math_fround(HEAPF32[$214>>2]);
   $217 = $216 > $215;
   if ($217) {
    $$pre$phi153Z2D = $181;$$pre$phi155Z2D = $183;$$pre$phiZ2D = $179;
   } else {
    $506 = ($166<<24>>24)==(0);
    if ($506) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($worldNormal,$5,$transf1);
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($5,$contactBuffer,$worldNormal,$transf0,$capsuleRadius);
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 ;HEAP32[$closestA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closestB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penDep>>2] = Math_fround(0.0);
 $218 = (($penDep) + 4|0);
 ;HEAP32[$218+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$218+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$218+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 HEAPF32[$5>>2] = $120;
 $219 = (($5) + 4|0);
 HEAPF32[$219>>2] = $121;
 $220 = (($5) + 8|0);
 HEAPF32[$220>>2] = $122;
 $221 = (($5) + 12|0);
 HEAPF32[$221>>2] = $101;
 HEAPF32[$$pre$phiZ2D>>2] = $92;
 HEAPF32[$$pre$phi153Z2D>>2] = $93;
 HEAPF32[$$pre$phi155Z2D>>2] = $94;
 $222 = (($5) + 28|0);
 HEAPF32[$222>>2] = Math_fround(0.0);
 $223 = (($aToB) + 48|0);
 HEAPF32[$223>>2] = $92;
 $224 = (($aToB) + 52|0);
 HEAPF32[$224>>2] = $93;
 $225 = (($aToB) + 56|0);
 HEAPF32[$225>>2] = $94;
 $226 = (($aToB) + 60|0);
 HEAPF32[$226>>2] = Math_fround(0.0);
 HEAPF32[$aToB>>2] = $141;
 $227 = (($aToB) + 4|0);
 HEAPF32[$227>>2] = $142;
 $228 = (($aToB) + 8|0);
 HEAPF32[$228>>2] = $143;
 $229 = (($aToB) + 12|0);
 HEAPF32[$229>>2] = Math_fround(0.0);
 $230 = (($aToB) + 16|0);
 HEAPF32[$230>>2] = $144;
 $231 = (($aToB) + 20|0);
 HEAPF32[$231>>2] = $145;
 $232 = (($aToB) + 24|0);
 HEAPF32[$232>>2] = $146;
 $233 = (($aToB) + 28|0);
 HEAPF32[$233>>2] = Math_fround(0.0);
 $234 = (($aToB) + 32|0);
 HEAPF32[$234>>2] = $147;
 $235 = (($aToB) + 36|0);
 HEAPF32[$235>>2] = $148;
 $236 = (($aToB) + 40|0);
 HEAPF32[$236>>2] = $149;
 $237 = (($aToB) + 44|0);
 HEAPF32[$237>>2] = Math_fround(0.0);
 $238 = (($transf1) + 16|0);
 $239 = (($box) + 64|0);
 ;HEAP32[$box+0>>2]=HEAP32[$238+0>>2]|0;HEAP32[$box+4>>2]=HEAP32[$238+4>>2]|0;HEAP32[$box+8>>2]=HEAP32[$238+8>>2]|0;HEAP32[$box+12>>2]=HEAP32[$238+12>>2]|0;
 $240 = (($box) + 80|0);
 HEAP32[$240>>2] = 3;
 $241 = (($box) + 16|0);
 $242 = (($box) + 20|0);
 $243 = (($box) + 32|0);
 $244 = (($box) + 36|0);
 $245 = (($box) + 48|0);
 HEAPF32[$245>>2] = Math_fround(0.0);
 $246 = (($box) + 52|0);
 ;HEAP32[$246+0>>2]=HEAP32[$zero$sroa$1$i$i$i26+0>>2]|0;HEAP32[$246+4>>2]=HEAP32[$zero$sroa$1$i$i$i26+4>>2]|0;HEAP32[$246+8>>2]=HEAP32[$zero$sroa$1$i$i$i26+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$239+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$239+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$239+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$239+12>>2]=HEAP32[$0+12>>2]|0;
 $247 = (($box) + 144|0);
 HEAPF32[$247>>2] = $9;
 $248 = (($box) + 148|0);
 HEAPF32[$248>>2] = $11;
 $249 = (($box) + 152|0);
 HEAPF32[$249>>2] = $13;
 $250 = (($box) + 156|0);
 HEAPF32[$250>>2] = Math_fround(0.0);
 $251 = Math_fround($169 * Math_fround(0.0500000007450580596924));
 HEAPF32[$243>>2] = $251;
 ;HEAP32[$244+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$244+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$244+8>>2]=HEAP32[$0+8>>2]|0;
 HEAPF32[$241>>2] = Math_fround(0.0);
 ;HEAP32[$242+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$242+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$242+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $252 = (($aToB) + 48|0);
 $253 = Math_fround($164 * Math_fround(0.0));
 $254 = Math_fround($164 * $141);
 $255 = Math_fround($253 * $144);
 $256 = Math_fround($254 + $255);
 $257 = Math_fround($253 * $147);
 $258 = Math_fround($256 + $257);
 $259 = Math_fround($164 * $142);
 $260 = Math_fround($253 * $145);
 $261 = Math_fround($259 + $260);
 $262 = Math_fround($253 * $148);
 $263 = Math_fround($261 + $262);
 $264 = Math_fround($164 * $143);
 $265 = Math_fround($253 * $146);
 $266 = Math_fround($264 + $265);
 $267 = Math_fround($253 * $149);
 $268 = Math_fround($266 + $267);
 $269 = (($capsule) + 64|0);
 ;HEAP32[$capsule+0>>2]=HEAP32[$252+0>>2]|0;HEAP32[$capsule+4>>2]=HEAP32[$252+4>>2]|0;HEAP32[$capsule+8>>2]=HEAP32[$252+8>>2]|0;HEAP32[$capsule+12>>2]=HEAP32[$252+12>>2]|0;
 $270 = (($capsule) + 80|0);
 HEAP32[$270>>2] = 4;
 $271 = (($capsule) + 48|0);
 HEAPF32[$271>>2] = Math_fround(0.0);
 $272 = (($capsule) + 52|0);
 ;HEAP32[$272+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$272+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$272+8>>2]=HEAP32[$0+8>>2]|0;
 $273 = (($capsule) + 128|0);
 ;HEAP32[$273+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$273+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$273+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$273+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 $274 = Math_fround(HEAPF32[$252>>2]);
 $275 = Math_fround(HEAPF32[$224>>2]);
 $276 = Math_fround(HEAPF32[$225>>2]);
 $277 = Math_fround($258 + $274);
 $278 = Math_fround($263 + $275);
 $279 = Math_fround($268 + $276);
 $280 = (($capsule) + 96|0);
 HEAPF32[$280>>2] = $277;
 $281 = (($capsule) + 100|0);
 HEAPF32[$281>>2] = $278;
 $282 = (($capsule) + 104|0);
 HEAPF32[$282>>2] = $279;
 $283 = (($capsule) + 108|0);
 HEAPF32[$283>>2] = Math_fround(0.0);
 $284 = Math_fround($274 - $258);
 $285 = Math_fround($275 - $263);
 $286 = Math_fround($276 - $268);
 $287 = (($capsule) + 112|0);
 HEAPF32[$287>>2] = $284;
 $288 = (($capsule) + 116|0);
 HEAPF32[$288>>2] = $285;
 $289 = (($capsule) + 120|0);
 HEAPF32[$289>>2] = $286;
 $290 = (($capsule) + 124|0);
 HEAPF32[$290>>2] = Math_fround(0.0);
 $291 = (($capsule) + 16|0);
 ;HEAP32[$291+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$291+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$291+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$291+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 $292 = (($capsule) + 32|0);
 ;HEAP32[$292+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$292+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$292+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$292+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 ;HEAP32[$zero$sroa$1$i$i$i26+0>>2]=4294967295|0;HEAP32[$zero$sroa$1$i$i$i26+4>>2]=4294967295|0;HEAP32[$zero$sroa$1$i$i$i26+8>>2]=4294967295|0;HEAP32[$zero$sroa$1$i$i$i26+12>>2]=4294967295|0;
 ;HEAP32[$269+0>>2]=HEAP32[$zero$sroa$1$i$i$i26+0>>2]|0;HEAP32[$269+4>>2]=HEAP32[$zero$sroa$1$i$i$i26+4>>2]|0;HEAP32[$269+8>>2]=HEAP32[$zero$sroa$1$i$i$i26+8>>2]|0;HEAP32[$269+12>>2]=HEAP32[$zero$sroa$1$i$i$i26+12>>2]|0;
 $293 = (($5) + 34|0);
 $294 = (($5) + 38|0);
 $295 = (($5) + 33|0);
 $296 = (__ZN5physx2Gu19GJKLocalPenetrationERKNS0_8CapsuleVERKNS0_4BoxVERKNS_6shdfnd3aos6FloatVERNS8_5Vec3VESD_SD_RS9_PhSF_Rhb($capsule,$box,$contactDist,$closestA,$closestB,$normal,$penDep,$293,$294,$295,1)|0);
 HEAP32[$numContacts>>2] = 0;
 do {
  if ((($296|0) == 1)) {
   $303 = Math_fround(HEAPF32[$closestA>>2]);
   $304 = (($closestA) + 4|0);
   $305 = Math_fround(HEAPF32[$304>>2]);
   $306 = (($closestA) + 8|0);
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = Math_fround($303 - $274);
   $309 = Math_fround($305 - $275);
   $310 = Math_fround($307 - $276);
   $311 = Math_fround(HEAPF32[$aToB>>2]);
   $312 = Math_fround($308 * $311);
   $313 = Math_fround(HEAPF32[$227>>2]);
   $314 = Math_fround($309 * $313);
   $315 = Math_fround($312 + $314);
   $316 = Math_fround(HEAPF32[$228>>2]);
   $317 = Math_fround($310 * $316);
   $318 = Math_fround($315 + $317);
   $319 = Math_fround(HEAPF32[$230>>2]);
   $320 = Math_fround($308 * $319);
   $321 = Math_fround(HEAPF32[$231>>2]);
   $322 = Math_fround($309 * $321);
   $323 = Math_fround($320 + $322);
   $324 = Math_fround(HEAPF32[$232>>2]);
   $325 = Math_fround($310 * $324);
   $326 = Math_fround($323 + $325);
   $327 = Math_fround(HEAPF32[$234>>2]);
   $328 = Math_fround($308 * $327);
   $329 = Math_fround(HEAPF32[$235>>2]);
   $330 = Math_fround($309 * $329);
   $331 = Math_fround($328 + $330);
   $332 = Math_fround(HEAPF32[$236>>2]);
   $333 = Math_fround($310 * $332);
   $334 = Math_fround($331 + $333);
   $335 = Math_fround(HEAPF32[$normal>>2]);
   $336 = (($normal) + 4|0);
   $337 = Math_fround(HEAPF32[$336>>2]);
   $338 = (($normal) + 8|0);
   $339 = Math_fround(HEAPF32[$338>>2]);
   $340 = Math_fround(HEAPF32[$penDep>>2]);
   HEAPF32[$contactBuffer>>2] = $318;
   $341 = (($contactBuffer) + 4|0);
   HEAPF32[$341>>2] = $326;
   $342 = (($contactBuffer) + 8|0);
   HEAPF32[$342>>2] = $334;
   $343 = (($contactBuffer) + 12|0);
   HEAPF32[$343>>2] = Math_fround(0.0);
   $344 = (($contactBuffer) + 16|0);
   ;HEAP32[$344+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$344+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$344+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$344+12>>2]=HEAP32[$closestB+12>>2]|0;
   HEAP32[$numContacts>>2] = 1;
   $345 = (($contactBuffer) + 32|0);
   HEAPF32[$345>>2] = $335;
   $346 = (($contactBuffer) + 36|0);
   HEAPF32[$346>>2] = $337;
   $347 = (($contactBuffer) + 40|0);
   HEAPF32[$347>>2] = $339;
   $348 = (($contactBuffer) + 44|0);
   HEAPF32[$348>>2] = $340;
   label = 10;
  } else if ((($296|0) == 0)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  } else if ((($296|0) == 3)) {
   $297 = Math_fround(HEAPF32[$8>>2]);
   HEAPF32[$1>>2] = $297;
   $298 = (($1) + 4|0);
   $299 = Math_fround(HEAPF32[$10>>2]);
   HEAPF32[$298>>2] = $299;
   $300 = (($1) + 8|0);
   $301 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$300>>2] = $301;
   $302 = (__ZN5physx2GuL32fullContactsGenerationCapsuleBoxERKNS0_8CapsuleVERKNS0_4BoxVENS_6PxVec3ERKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVESF_PNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNS9_5Vec3VERKNS9_6FloatVEb($capsule,$box,$1,$aToB,$transf0,$transf1,$contactBuffer,$numContacts,$contactBuffer,$5,$normal,$contactDist,0)|0);
   $$1 = $302;
   STACKTOP = sp;return ($$1|0);
  } else {
   $349 = (__ZN5physx2Gu19EPALocalPenetrationERKNS0_8CapsuleVERKNS0_4BoxVERNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEPhSD_Rhb($capsule,$box,$closestA,$closestB,$normal,$penDep,$293,$294,$295,1)|0);
   if ((($349|0) == 4)) {
    $doOverlapTest$0$off0158 = 1;
    break;
   } else if (!((($349|0) == 6))) {
    label = 10;
    break;
   }
   $350 = Math_fround(HEAPF32[$closestA>>2]);
   $351 = (($closestA) + 4|0);
   $352 = Math_fround(HEAPF32[$351>>2]);
   $353 = (($closestA) + 8|0);
   $354 = Math_fround(HEAPF32[$353>>2]);
   $355 = Math_fround(HEAPF32[$223>>2]);
   $356 = Math_fround(HEAPF32[$224>>2]);
   $357 = Math_fround(HEAPF32[$225>>2]);
   $358 = Math_fround($350 - $355);
   $359 = Math_fround($352 - $356);
   $360 = Math_fround($354 - $357);
   $361 = Math_fround(HEAPF32[$aToB>>2]);
   $362 = Math_fround($358 * $361);
   $363 = Math_fround(HEAPF32[$227>>2]);
   $364 = Math_fround($359 * $363);
   $365 = Math_fround($362 + $364);
   $366 = Math_fround(HEAPF32[$228>>2]);
   $367 = Math_fround($360 * $366);
   $368 = Math_fround($365 + $367);
   $369 = Math_fround(HEAPF32[$230>>2]);
   $370 = Math_fround($358 * $369);
   $371 = Math_fround(HEAPF32[$231>>2]);
   $372 = Math_fround($359 * $371);
   $373 = Math_fround($370 + $372);
   $374 = Math_fround(HEAPF32[$232>>2]);
   $375 = Math_fround($360 * $374);
   $376 = Math_fround($373 + $375);
   $377 = Math_fround(HEAPF32[$234>>2]);
   $378 = Math_fround($358 * $377);
   $379 = Math_fround(HEAPF32[$235>>2]);
   $380 = Math_fround($359 * $379);
   $381 = Math_fround($378 + $380);
   $382 = Math_fround(HEAPF32[$236>>2]);
   $383 = Math_fround($360 * $382);
   $384 = Math_fround($381 + $383);
   $385 = Math_fround(HEAPF32[$normal>>2]);
   $386 = (($normal) + 4|0);
   $387 = Math_fround(HEAPF32[$386>>2]);
   $388 = (($normal) + 8|0);
   $389 = Math_fround(HEAPF32[$388>>2]);
   $390 = Math_fround(HEAPF32[$penDep>>2]);
   $391 = HEAP32[$numContacts>>2]|0;
   $392 = (($contactBuffer) + (($391*48)|0)|0);
   HEAPF32[$392>>2] = $368;
   $393 = ((($contactBuffer) + (($391*48)|0)|0) + 4|0);
   HEAPF32[$393>>2] = $376;
   $394 = ((($contactBuffer) + (($391*48)|0)|0) + 8|0);
   HEAPF32[$394>>2] = $384;
   $395 = ((($contactBuffer) + (($391*48)|0)|0) + 12|0);
   HEAPF32[$395>>2] = Math_fround(0.0);
   $396 = ((($contactBuffer) + (($391*48)|0)|0) + 16|0);
   ;HEAP32[$396+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$396+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$396+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$396+12>>2]=HEAP32[$closestB+12>>2]|0;
   $397 = (($391) + 1)|0;
   HEAP32[$numContacts>>2] = $397;
   $398 = ((($contactBuffer) + (($391*48)|0)|0) + 32|0);
   HEAPF32[$398>>2] = $385;
   $399 = ((($contactBuffer) + (($391*48)|0)|0) + 36|0);
   HEAPF32[$399>>2] = $387;
   $400 = ((($contactBuffer) + (($391*48)|0)|0) + 40|0);
   HEAPF32[$400>>2] = $389;
   $401 = ((($contactBuffer) + (($391*48)|0)|0) + 44|0);
   HEAPF32[$401>>2] = $390;
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  $402 = ($166<<24>>24)==(0);
  $or$cond = $402 | $174;
  if ($or$cond) {
   $doOverlapTest$0$off0158 = 0;
  } else {
   $409 = Math_fround($$$i * Math_fround(0.100000001490116119385));
   HEAPF32[$replaceBreakingThreshold>>2] = $409;
   $410 = Math_fround(HEAPF32[$normal>>2]);
   $411 = (($normal) + 4|0);
   $412 = Math_fround(HEAPF32[$411>>2]);
   $413 = (($normal) + 8|0);
   $414 = Math_fround(HEAPF32[$413>>2]);
   $415 = (($normal) + 12|0);
   $416 = Math_fround(HEAPF32[$penDep>>2]);
   HEAPF32[$localNormalPen3>>2] = $410;
   $417 = (($localNormalPen3) + 4|0);
   HEAPF32[$417>>2] = $412;
   $418 = (($localNormalPen3) + 8|0);
   HEAPF32[$418>>2] = $414;
   $419 = (($localNormalPen3) + 12|0);
   HEAPF32[$419>>2] = $416;
   $420 = Math_fround(HEAPF32[$closestA>>2]);
   $421 = (($closestA) + 4|0);
   $422 = Math_fround(HEAPF32[$421>>2]);
   $423 = (($closestA) + 8|0);
   $424 = Math_fround(HEAPF32[$423>>2]);
   $425 = Math_fround($420 - $92);
   $426 = Math_fround($422 - $93);
   $427 = Math_fround($424 - $94);
   $428 = Math_fround($101 * $101);
   $429 = Math_fround($428 + Math_fround(-0.5));
   $430 = Math_fround($429 * $425);
   $431 = Math_fround($429 * $426);
   $432 = Math_fround($429 * $427);
   $433 = Math_fround($121 * $427);
   $434 = Math_fround($122 * $426);
   $435 = Math_fround($433 - $434);
   $436 = Math_fround($122 * $425);
   $437 = Math_fround($120 * $427);
   $438 = Math_fround($436 - $437);
   $439 = Math_fround($120 * $426);
   $440 = Math_fround($121 * $425);
   $441 = Math_fround($439 - $440);
   $442 = Math_fround($101 * $435);
   $443 = Math_fround($101 * $438);
   $444 = Math_fround($101 * $441);
   $445 = Math_fround($430 - $442);
   $446 = Math_fround($431 - $443);
   $447 = Math_fround($432 - $444);
   $448 = Math_fround($120 * $425);
   $449 = Math_fround($121 * $426);
   $450 = Math_fround($448 + $449);
   $451 = Math_fround($122 * $427);
   $452 = Math_fround($450 + $451);
   $453 = Math_fround($120 * $452);
   $454 = Math_fround($121 * $452);
   $455 = Math_fround($122 * $452);
   $456 = Math_fround($453 + $445);
   $457 = Math_fround($454 + $446);
   $458 = Math_fround($447 + $455);
   $459 = Math_fround($456 * Math_fround(2.0));
   $460 = Math_fround($457 * Math_fround(2.0));
   $461 = Math_fround($458 * Math_fround(2.0));
   HEAPF32[$3>>2] = $459;
   $462 = (($3) + 4|0);
   HEAPF32[$462>>2] = $460;
   $463 = (($3) + 8|0);
   HEAPF32[$463>>2] = $461;
   $464 = (($3) + 12|0);
   HEAPF32[$464>>2] = Math_fround(0.0);
   (__ZN5physx2Gu25PersistentContactManifold17addManifoldPoint2ERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($5,$3,$closestB,$localNormalPen3,$replaceBreakingThreshold)|0);
   $465 = Math_fround(HEAPF32[$transf1>>2]);
   $466 = Math_fround(HEAPF32[$48>>2]);
   $467 = Math_fround(HEAPF32[$49>>2]);
   $468 = Math_fround(HEAPF32[$50>>2]);
   $469 = Math_fround(HEAPF32[$normal>>2]);
   $470 = Math_fround(HEAPF32[$411>>2]);
   $471 = Math_fround(HEAPF32[$413>>2]);
   $472 = Math_fround($468 * $468);
   $473 = Math_fround($472 + Math_fround(-0.5));
   $474 = Math_fround($469 * $473);
   $475 = Math_fround($473 * $470);
   $476 = Math_fround($473 * $471);
   $477 = Math_fround($466 * $471);
   $478 = Math_fround($467 * $470);
   $479 = Math_fround($477 - $478);
   $480 = Math_fround($467 * $469);
   $481 = Math_fround($465 * $471);
   $482 = Math_fround($480 - $481);
   $483 = Math_fround($465 * $470);
   $484 = Math_fround($466 * $469);
   $485 = Math_fround($483 - $484);
   $486 = Math_fround($468 * $479);
   $487 = Math_fround($468 * $482);
   $488 = Math_fround($468 * $485);
   $489 = Math_fround($474 + $486);
   $490 = Math_fround($475 + $487);
   $491 = Math_fround($476 + $488);
   $492 = Math_fround($465 * $469);
   $493 = Math_fround($466 * $470);
   $494 = Math_fround($492 + $493);
   $495 = Math_fround($467 * $471);
   $496 = Math_fround($494 + $495);
   $497 = Math_fround($465 * $496);
   $498 = Math_fround($466 * $496);
   $499 = Math_fround($467 * $496);
   $500 = Math_fround($497 + $489);
   $501 = Math_fround($498 + $490);
   $502 = Math_fround($491 + $499);
   $503 = Math_fround($500 * Math_fround(2.0));
   $504 = Math_fround($501 * Math_fround(2.0));
   $505 = Math_fround($502 * Math_fround(2.0));
   HEAPF32[$normal>>2] = $503;
   HEAPF32[$411>>2] = $504;
   HEAPF32[$413>>2] = $505;
   HEAPF32[$415>>2] = Math_fround(0.0);
   __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($5,$contactBuffer,$normal,$transf0,$capsuleRadius);
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $403 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$2>>2] = $403;
 $404 = (($2) + 4|0);
 $405 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$404>>2] = $405;
 $406 = (($2) + 8|0);
 $407 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$406>>2] = $407;
 $408 = (__ZN5physx2GuL32fullContactsGenerationCapsuleBoxERKNS0_8CapsuleVERKNS0_4BoxVENS_6PxVec3ERKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVESF_PNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNS9_5Vec3VERKNS9_6FloatVEb($capsule,$box,$2,$aToB,$transf0,$transf1,$contactBuffer,$numContacts,$contactBuffer,$5,$normal,$contactDist,$doOverlapTest$0$off0158)|0);
 $$1 = $408;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx2GuL32fullContactsGenerationCapsuleBoxERKNS0_8CapsuleVERKNS0_4BoxVENS_6PxVec3ERKNS_6shdfnd3aos15PsMatTransformVERKNS9_12PsTransformVESF_PNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNS9_5Vec3VERKNS9_6FloatVEb($capsule,$box,$halfExtents,$aToB,$transf0,$transf1,$manifoldContacts,$numContacts,$contactBuffer,$manifold,$normal,$contactDist,$doOverlapTest) {
 $capsule = $capsule|0;
 $box = $box|0;
 $halfExtents = $halfExtents|0;
 $aToB = $aToB|0;
 $transf0 = $transf0|0;
 $transf1 = $transf1|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactBuffer = $contactBuffer|0;
 $manifold = $manifold|0;
 $normal = $normal|0;
 $contactDist = $contactDist|0;
 $doOverlapTest = $doOverlapTest|0;
 var $$0 = 0, $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $identity = 0, $map = 0, $polyBox = 0, $polyData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $polyData = sp + 336|0;
 $polyBox = sp + 112|0;
 $identity = sp;
 $map = sp + 48|0;
 __ZN5physx2Gu15PCMPolygonalBoxC2ERKNS_6PxVec3E($polyBox,$halfExtents);
 __ZNK5physx2Gu15PCMPolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($polyBox,$polyData);
 HEAPF32[$identity>>2] = Math_fround(1.0);
 $0 = (($identity) + 4|0);
 $1 = (($identity) + 20|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($identity) + 24|0);
 $3 = (($identity) + 40|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($identity) + 44|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($map) + 32|0);
 HEAP32[$5>>2] = $transf1;
 $6 = (($map) + 36|0);
 HEAP32[$6>>2] = $identity;
 $7 = (($map) + 40|0);
 HEAP32[$7>>2] = $identity;
 $8 = (($map) + 44|0);
 HEAP8[$8>>0] = 1;
 HEAP32[$map>>2] = ((546776 + 8|0));
 $9 = (($map) + 48|0);
 HEAP32[$9>>2] = $box;
 $10 = HEAP32[$numContacts>>2]|0;
 $11 = (__ZN5physx2Gu37generateCapsuleBoxFullContactManifoldERKNS0_8CapsuleVERNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVERNS9_5Vec3VEb($capsule,$polyData,$map,$aToB,$manifoldContacts,$numContacts,$contactDist,$normal,$doOverlapTest)|0);
 if (!($11)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ($10|0)==(0);
 $$pre = HEAP32[$numContacts>>2]|0;
 if ($12) {
  $$01 = $manifoldContacts;$16 = $$pre;
 } else {
  $13 = ($$pre|0)==($10|0);
  if ($13) {
   $$01 = $manifoldContacts;$16 = $10;
  } else {
   $14 = (($$pre) + -1)|0;
   HEAP32[$numContacts>>2] = $14;
   $15 = (($manifoldContacts) + 48|0);
   $$01 = $15;$16 = $14;
  }
 }
 __ZN5physx2Gu25PersistentContactManifold25addBatchManifoldContacts2EPKNS0_17PersistentContactEj($manifold,$$01,$16);
 $17 = Math_fround(HEAPF32[$transf1>>2]);
 $18 = (($transf1) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($transf1) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transf1) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(HEAPF32[$normal>>2]);
 $25 = (($normal) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($normal) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($23 * $23);
 $30 = Math_fround($29 + Math_fround(-0.5));
 $31 = Math_fround($24 * $30);
 $32 = Math_fround($30 * $26);
 $33 = Math_fround($30 * $28);
 $34 = Math_fround($19 * $28);
 $35 = Math_fround($21 * $26);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($21 * $24);
 $38 = Math_fround($17 * $28);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($17 * $26);
 $41 = Math_fround($19 * $24);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($23 * $36);
 $44 = Math_fround($23 * $39);
 $45 = Math_fround($23 * $42);
 $46 = Math_fround($31 + $43);
 $47 = Math_fround($32 + $44);
 $48 = Math_fround($33 + $45);
 $49 = Math_fround($17 * $24);
 $50 = Math_fround($19 * $26);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($21 * $28);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($17 * $53);
 $55 = Math_fround($19 * $53);
 $56 = Math_fround($21 * $53);
 $57 = Math_fround($54 + $46);
 $58 = Math_fround($55 + $47);
 $59 = Math_fround($48 + $56);
 $60 = Math_fround($57 * Math_fround(2.0));
 $61 = Math_fround($58 * Math_fround(2.0));
 $62 = Math_fround($59 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $60;
 HEAPF32[$25>>2] = $61;
 HEAPF32[$27>>2] = $62;
 $63 = (($normal) + 12|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($capsule) + 128|0);
 __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($manifold,$contactBuffer,$normal,$transf0,$64);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu23pcmContactCapsuleConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$1 = 0, $$1$i$i$i$i = Math_fround(0), $$pre = 0, $$pre$phi151Z2D = 0, $$pre$phi153Z2D = 0, $$pre$phiZ2D = 0, $$pre150 = 0, $$pre152 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0);
 var $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0;
 var $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0);
 var $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0);
 var $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0);
 var $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = Math_fround(0);
 var $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = Math_fround(0);
 var $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0);
 var $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0);
 var $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0);
 var $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = Math_fround(0), $443 = 0, $444 = Math_fround(0), $445 = 0, $446 = Math_fround(0), $447 = Math_fround(0);
 var $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0);
 var $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0);
 var $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0);
 var $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0);
 var $52 = Math_fround(0), $520 = Math_fround(0), $521 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $capsule = 0, $capsuleRadius = 0, $closestA = 0, $closestB = 0, $contactDist = 0;
 var $convexHull = 0, $doOverlapTest$1$off0156 = 0, $localNormalPen3 = 0, $normal = 0, $numContacts = 0, $or$cond = 0, $penDep = 0, $projectBreakingThreshold = 0, $replaceBreakingThreshold = 0, $status$0 = 0, $supportMap = 0, $transf0 = 0, $transf1 = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1 = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 768|0;
 $zero$sroa$1$i$i$i = sp + 740|0;
 $0 = sp + 704|0;
 $zeroV = sp + 624|0;
 $vScale = sp + 576|0;
 $contactDist = sp + 592|0;
 $capsuleRadius = sp + 608|0;
 $transf0 = sp + 640|0;
 $transf1 = sp + 672|0;
 $aToB = sp + 512|0;
 $projectBreakingThreshold = sp + 16|0;
 $closestA = sp;
 $closestB = sp + 64|0;
 $normal = sp + 32|0;
 $zero$sroa$1 = sp + 752|0;
 $penDep = sp + 48|0;
 $vQuat = sp + 80|0;
 $convexHull = sp + 96|0;
 $capsule = sp + 304|0;
 $numContacts = sp + 736|0;
 $supportMap = sp + 720|0;
 $replaceBreakingThreshold = sp + 448|0;
 $localNormalPen3 = sp + 464|0;
 $1 = sp + 480|0;
 $2 = sp + 496|0;
 $3 = HEAP32[$cache>>2]|0;
 $4 = $3;
 $5 = (($shape1) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $7 = (($shape1) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($shape1) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($shape1) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$vScale>>2] = $8;
 $13 = (($vScale) + 4|0);
 HEAPF32[$13>>2] = $10;
 $14 = (($vScale) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($vScale) + 12|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = Math_fround(HEAPF32[$contactDistance>>2]);
 HEAPF32[$contactDist>>2] = $16;
 $17 = (($shape0) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($shape0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$capsuleRadius>>2] = $20;
 $21 = HEAP32[$5>>2]|0;
 $22 = Math_fround(HEAPF32[$transform0>>2]);
 $23 = (($transform0) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($transform0) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($transform0) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($transform0) + 16|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($29) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($29) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$transf0>>2] = $22;
 $35 = (($transf0) + 4|0);
 HEAPF32[$35>>2] = $24;
 $36 = (($transf0) + 8|0);
 HEAPF32[$36>>2] = $26;
 $37 = (($transf0) + 12|0);
 HEAPF32[$37>>2] = $28;
 $38 = (($transf0) + 16|0);
 HEAPF32[$38>>2] = $30;
 $39 = (($transf0) + 20|0);
 HEAPF32[$39>>2] = $32;
 $40 = (($transf0) + 24|0);
 HEAPF32[$40>>2] = $34;
 $41 = (($transf0) + 28|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = Math_fround(HEAPF32[$transform1>>2]);
 $43 = (($transform1) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($transform1) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($transform1) + 12|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($transform1) + 16|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($49) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($49) + 8|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 HEAPF32[$transf1>>2] = $42;
 $55 = (($transf1) + 4|0);
 HEAPF32[$55>>2] = $44;
 $56 = (($transf1) + 8|0);
 HEAPF32[$56>>2] = $46;
 $57 = (($transf1) + 12|0);
 HEAPF32[$57>>2] = $48;
 $58 = (($transf1) + 16|0);
 HEAPF32[$58>>2] = $50;
 $59 = (($transf1) + 20|0);
 HEAPF32[$59>>2] = $52;
 $60 = (($transf1) + 24|0);
 HEAPF32[$60>>2] = $54;
 $61 = (($transf1) + 28|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = Math_fround(-$42);
 $63 = Math_fround(-$44);
 $64 = Math_fround(-$46);
 $65 = Math_fround($30 - $50);
 $66 = Math_fround($32 - $52);
 $67 = Math_fround($34 - $54);
 $68 = Math_fround($48 * $48);
 $69 = Math_fround($68 + Math_fround(-0.5));
 $70 = Math_fround($69 * $65);
 $71 = Math_fround($69 * $66);
 $72 = Math_fround($69 * $67);
 $73 = Math_fround($67 * $63);
 $74 = Math_fround($66 * $64);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($65 * $64);
 $77 = Math_fround($67 * $62);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($66 * $62);
 $80 = Math_fround($65 * $63);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($48 * $75);
 $83 = Math_fround($48 * $78);
 $84 = Math_fround($48 * $81);
 $85 = Math_fround($70 + $82);
 $86 = Math_fround($71 + $83);
 $87 = Math_fround($72 + $84);
 $88 = Math_fround($65 * $62);
 $89 = Math_fround($66 * $63);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround($67 * $64);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($92 * $62);
 $94 = Math_fround($92 * $63);
 $95 = Math_fround($92 * $64);
 $96 = Math_fround($93 + $85);
 $97 = Math_fround($94 + $86);
 $98 = Math_fround($87 + $95);
 $99 = Math_fround($96 * Math_fround(2.0));
 $100 = Math_fround($97 * Math_fround(2.0));
 $101 = Math_fround($98 * Math_fround(2.0));
 $102 = Math_fround($48 * $28);
 $103 = Math_fround($22 * $62);
 $104 = Math_fround($24 * $63);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($26 * $64);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround($102 - $107);
 $109 = Math_fround($28 * $62);
 $110 = Math_fround($28 * $63);
 $111 = Math_fround($28 * $64);
 $112 = Math_fround($48 * $22);
 $113 = Math_fround($48 * $24);
 $114 = Math_fround($48 * $26);
 $115 = Math_fround($26 * $63);
 $116 = Math_fround($24 * $64);
 $117 = Math_fround($115 - $116);
 $118 = Math_fround($22 * $64);
 $119 = Math_fround($26 * $62);
 $120 = Math_fround($118 - $119);
 $121 = Math_fround($24 * $62);
 $122 = Math_fround($22 * $63);
 $123 = Math_fround($121 - $122);
 $124 = Math_fround($112 + $109);
 $125 = Math_fround($113 + $110);
 $126 = Math_fround($114 + $111);
 $127 = Math_fround($117 + $124);
 $128 = Math_fround($120 + $125);
 $129 = Math_fround($123 + $126);
 $130 = (($aToB) + 48|0);
 HEAPF32[$130>>2] = $99;
 $131 = (($aToB) + 52|0);
 HEAPF32[$131>>2] = $100;
 $132 = (($aToB) + 56|0);
 HEAPF32[$132>>2] = $101;
 $133 = (($aToB) + 60|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = Math_fround($127 + $127);
 $135 = Math_fround($128 + $128);
 $136 = Math_fround($129 + $129);
 $137 = Math_fround($127 * $134);
 $138 = Math_fround($128 * $135);
 $139 = Math_fround($129 * $136);
 $140 = Math_fround($128 * $134);
 $141 = Math_fround($129 * $134);
 $142 = Math_fround($108 * $134);
 $143 = Math_fround($129 * $135);
 $144 = Math_fround($108 * $135);
 $145 = Math_fround($108 * $136);
 $146 = Math_fround(Math_fround(1.0) - $137);
 $147 = Math_fround(Math_fround(1.0) - $138);
 $148 = Math_fround($147 - $139);
 $149 = Math_fround($140 + $145);
 $150 = Math_fround($141 - $144);
 $151 = Math_fround($140 - $145);
 $152 = Math_fround($146 - $139);
 $153 = Math_fround($143 + $142);
 $154 = Math_fround($141 + $144);
 $155 = Math_fround($143 - $142);
 $156 = Math_fround($146 - $138);
 HEAPF32[$aToB>>2] = $148;
 $157 = (($aToB) + 4|0);
 HEAPF32[$157>>2] = $149;
 $158 = (($aToB) + 8|0);
 HEAPF32[$158>>2] = $150;
 $159 = (($aToB) + 12|0);
 HEAPF32[$159>>2] = Math_fround(0.0);
 $160 = (($aToB) + 16|0);
 HEAPF32[$160>>2] = $151;
 $161 = (($aToB) + 20|0);
 HEAPF32[$161>>2] = $152;
 $162 = (($aToB) + 24|0);
 HEAPF32[$162>>2] = $153;
 $163 = (($aToB) + 28|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = (($aToB) + 32|0);
 HEAPF32[$164>>2] = $154;
 $165 = (($aToB) + 36|0);
 HEAPF32[$165>>2] = $155;
 $166 = (($aToB) + 40|0);
 HEAPF32[$166>>2] = $156;
 $167 = (($aToB) + 44|0);
 HEAPF32[$167>>2] = Math_fround(0.0);
 $168 = (($21) + 52|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($21) + 56|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($21) + 60|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround(HEAPF32[$vScale>>2]);
 $175 = Math_fround(HEAPF32[$13>>2]);
 $176 = Math_fround(HEAPF32[$14>>2]);
 $177 = Math_fround($169 * $174);
 $178 = Math_fround($171 * $175);
 $179 = Math_fround($173 * $176);
 $180 = !($177 <= $178);
 $$$i$i = $180 ? $178 : $177;
 $181 = !($$$i$i <= $179);
 $182 = $181 ? $179 : $$$i$i;
 $183 = Math_fround($182 * Math_fround(0.25));
 $184 = Math_fround(HEAPF32[$capsuleRadius>>2]);
 $185 = Math_fround($184 * Math_fround(0.0500000007450580596924));
 $186 = $183 > $185;
 $$$i = $186 ? $185 : $183;
 $187 = (($4) + 32|0);
 $188 = HEAP8[$187>>0]|0;
 $189 = Math_fround($$$i * Math_fround(1.25));
 HEAPF32[$projectBreakingThreshold>>2] = $189;
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($4,$aToB,$projectBreakingThreshold,0);
 $190 = HEAP8[$187>>0]|0;
 $191 = ($190<<24>>24)!=($188<<24>>24);
 ;HEAP32[$closestA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closestB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penDep>>2] = Math_fround(0.0);
 $192 = (($penDep) + 4|0);
 ;HEAP32[$192+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$192+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$192+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 if ($191) {
  $$pre = (($4) + 16|0);
  $$pre150 = (($4) + 20|0);
  $$pre152 = (($4) + 24|0);
  $$pre$phi151Z2D = $$pre150;$$pre$phi153Z2D = $$pre152;$$pre$phiZ2D = $$pre;
 } else {
  $193 = HEAP8[$187>>0]|0;
  $194 = $193&255;
  $195 = (554184 + ($194<<2)|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = Math_fround($$$i * $196);
  $198 = (($4) + 16|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = (($4) + 20|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (($4) + 24|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = Math_fround($99 - $199);
  $205 = Math_fround($100 - $201);
  $206 = Math_fround($101 - $203);
  $207 = Math_fround(-$204);
  $208 = Math_fround(-$205);
  $209 = Math_fround(-$206);
  $210 = $204 > $207;
  $$$i$i$i$i = $210 ? $204 : $207;
  $211 = $205 > $208;
  $212 = $211 ? $205 : $208;
  $213 = $206 > $209;
  $$1$i$i$i$i = $213 ? $206 : $209;
  $214 = !($$$i$i$i$i >= $212);
  $$$i$i$i = $214 ? $212 : $$$i$i$i$i;
  $215 = !($$1$i$i$i$i >= Math_fround(0.0));
  $216 = $215 ? Math_fround(0.0) : $$$i$i$i$i;
  $217 = $$$i$i$i >= $216;
  $218 = $217 ? $$$i$i$i : $216;
  $219 = $218 > $197;
  if ($219) {
   $$pre$phi151Z2D = $200;$$pre$phi153Z2D = $202;$$pre$phiZ2D = $198;
  } else {
   $220 = (($4) + 4|0);
   $221 = (($4) + 8|0);
   $222 = Math_fround(HEAPF32[$220>>2]);
   $223 = Math_fround(HEAPF32[$4>>2]);
   $224 = Math_fround($128 * $222);
   $225 = Math_fround($127 * $223);
   $226 = (($4) + 12|0);
   $227 = Math_fround(HEAPF32[$221>>2]);
   $228 = Math_fround($129 * $227);
   $229 = Math_fround($224 + $225);
   $230 = Math_fround(HEAPF32[$226>>2]);
   $231 = Math_fround($108 * $230);
   $232 = Math_fround($229 + $228);
   $233 = (554224 + ($194<<2)|0);
   $234 = Math_fround($232 + $231);
   $235 = Math_fround(HEAPF32[$233>>2]);
   $236 = $235 > $234;
   if ($236) {
    $$pre$phi151Z2D = $200;$$pre$phi153Z2D = $202;$$pre$phiZ2D = $198;
   } else {
    $521 = ($193<<24>>24)==(0);
    if ($521) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($2,$4,$transf1);
    ;HEAP32[$normal+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$2+12>>2]|0;
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($4,$contactBuffer,$normal,$transf0,$capsuleRadius);
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 HEAPF32[$4>>2] = $127;
 $237 = (($4) + 4|0);
 HEAPF32[$237>>2] = $128;
 $238 = (($4) + 8|0);
 HEAPF32[$238>>2] = $129;
 $239 = (($4) + 12|0);
 HEAPF32[$239>>2] = $108;
 HEAPF32[$$pre$phiZ2D>>2] = $99;
 HEAPF32[$$pre$phi151Z2D>>2] = $100;
 HEAPF32[$$pre$phi153Z2D>>2] = $101;
 $240 = (($4) + 28|0);
 HEAPF32[$240>>2] = Math_fround(0.0);
 $241 = (($shape1) + 16|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 $243 = (($shape1) + 20|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = (($shape1) + 24|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = (($shape1) + 28|0);
 $248 = Math_fround(HEAPF32[$247>>2]);
 HEAPF32[$vQuat>>2] = $242;
 $249 = (($vQuat) + 4|0);
 HEAPF32[$249>>2] = $244;
 $250 = (($vQuat) + 8|0);
 HEAPF32[$250>>2] = $246;
 $251 = (($vQuat) + 12|0);
 HEAPF32[$251>>2] = $248;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$21,$zeroV,$vScale,$vQuat);
 $252 = (($convexHull) + 16|0);
 HEAPF32[$252>>2] = Math_fround(0.0);
 $253 = (($convexHull) + 20|0);
 ;HEAP32[$253+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$253+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$253+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 $254 = (($aToB) + 48|0);
 $255 = Math_fround($18 * Math_fround(0.0));
 $256 = Math_fround(HEAPF32[$aToB>>2]);
 $257 = Math_fround($18 * $256);
 $258 = Math_fround(HEAPF32[$160>>2]);
 $259 = Math_fround($255 * $258);
 $260 = Math_fround($257 + $259);
 $261 = Math_fround(HEAPF32[$164>>2]);
 $262 = Math_fround($255 * $261);
 $263 = Math_fround($260 + $262);
 $264 = Math_fround(HEAPF32[$157>>2]);
 $265 = Math_fround($18 * $264);
 $266 = Math_fround(HEAPF32[$161>>2]);
 $267 = Math_fround($255 * $266);
 $268 = Math_fround($265 + $267);
 $269 = Math_fround(HEAPF32[$165>>2]);
 $270 = Math_fround($255 * $269);
 $271 = Math_fround($268 + $270);
 $272 = Math_fround(HEAPF32[$158>>2]);
 $273 = Math_fround($18 * $272);
 $274 = Math_fround(HEAPF32[$162>>2]);
 $275 = Math_fround($255 * $274);
 $276 = Math_fround($273 + $275);
 $277 = Math_fround(HEAPF32[$166>>2]);
 $278 = Math_fround($255 * $277);
 $279 = Math_fround($276 + $278);
 $280 = (($capsule) + 64|0);
 ;HEAP32[$capsule+0>>2]=HEAP32[$254+0>>2]|0;HEAP32[$capsule+4>>2]=HEAP32[$254+4>>2]|0;HEAP32[$capsule+8>>2]=HEAP32[$254+8>>2]|0;HEAP32[$capsule+12>>2]=HEAP32[$254+12>>2]|0;
 $281 = (($capsule) + 80|0);
 HEAP32[$281>>2] = 4;
 $282 = (($capsule) + 48|0);
 HEAPF32[$282>>2] = Math_fround(0.0);
 $283 = (($capsule) + 52|0);
 ;HEAP32[$283+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$283+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$283+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $284 = (($capsule) + 128|0);
 ;HEAP32[$284+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$284+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$284+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$284+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 $285 = Math_fround(HEAPF32[$254>>2]);
 $286 = Math_fround(HEAPF32[$131>>2]);
 $287 = Math_fround(HEAPF32[$132>>2]);
 $288 = Math_fround($263 + $285);
 $289 = Math_fround($271 + $286);
 $290 = Math_fround($279 + $287);
 $291 = (($capsule) + 96|0);
 HEAPF32[$291>>2] = $288;
 $292 = (($capsule) + 100|0);
 HEAPF32[$292>>2] = $289;
 $293 = (($capsule) + 104|0);
 HEAPF32[$293>>2] = $290;
 $294 = (($capsule) + 108|0);
 HEAPF32[$294>>2] = Math_fround(0.0);
 $295 = Math_fround($285 - $263);
 $296 = Math_fround($286 - $271);
 $297 = Math_fround($287 - $279);
 $298 = (($capsule) + 112|0);
 HEAPF32[$298>>2] = $295;
 $299 = (($capsule) + 116|0);
 HEAPF32[$299>>2] = $296;
 $300 = (($capsule) + 120|0);
 HEAPF32[$300>>2] = $297;
 $301 = (($capsule) + 124|0);
 HEAPF32[$301>>2] = Math_fround(0.0);
 $302 = (($capsule) + 16|0);
 ;HEAP32[$302+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$302+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$302+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$302+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 $303 = (($capsule) + 32|0);
 ;HEAP32[$303+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$303+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$303+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$303+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 ;HEAP32[$280+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$280+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$280+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$280+12>>2]=HEAP32[$0+12>>2]|0;
 $304 = Math_fround(HEAPF32[$7>>2]);
 $305 = $304 == Math_fround(1.0);
 if ($305) {
  $306 = Math_fround(HEAPF32[$9>>2]);
  $307 = $306 == Math_fround(1.0);
  if ($307) {
   $308 = Math_fround(HEAPF32[$11>>2]);
   $309 = $308 == Math_fround(1.0);
   if ($309) {
    $310 = (($4) + 34|0);
    $311 = (($4) + 38|0);
    $312 = (($4) + 33|0);
    $313 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_18ConvexHullNoScaleVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($capsule,$convexHull,$contactDist,$closestA,$closestB,$normal,$penDep,$310,$311,$312,1)|0);
    $318 = 1;$status$0 = $313;
   } else {
    label = 9;
   }
  } else {
   label = 9;
  }
 } else {
  label = 9;
 }
 if ((label|0) == 9) {
  $314 = (($4) + 34|0);
  $315 = (($4) + 38|0);
  $316 = (($4) + 33|0);
  $317 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($capsule,$convexHull,$contactDist,$closestA,$closestB,$normal,$penDep,$314,$315,$316,1)|0);
  $318 = 0;$status$0 = $317;
 }
 HEAP32[$numContacts>>2] = 0;
 do {
  if ((($status$0|0) == 3)) {
   $319 = (__ZN5physx2GuL35fullContactsGenerationCapsuleConvexERKNS0_8CapsuleVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVESE_PNS0_17PersistentContactERjRNS0_13ContactBufferEbRNS0_25PersistentContactManifoldERNS8_5Vec3VERKNS8_6FloatVEb($capsule,$convexHull,$aToB,$transf0,$transf1,$contactBuffer,$numContacts,$contactBuffer,$318,$4,$normal,$contactDist,0)|0);
   $$1 = $319;
   STACKTOP = sp;return ($$1|0);
  } else if ((($status$0|0) == 0)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  } else if ((($status$0|0) == 1)) {
   $320 = Math_fround(HEAPF32[$closestA>>2]);
   $321 = (($closestA) + 4|0);
   $322 = Math_fround(HEAPF32[$321>>2]);
   $323 = (($closestA) + 8|0);
   $324 = Math_fround(HEAPF32[$323>>2]);
   $325 = Math_fround(HEAPF32[$130>>2]);
   $326 = Math_fround(HEAPF32[$131>>2]);
   $327 = Math_fround(HEAPF32[$132>>2]);
   $328 = Math_fround($320 - $325);
   $329 = Math_fround($322 - $326);
   $330 = Math_fround($324 - $327);
   $331 = Math_fround(HEAPF32[$aToB>>2]);
   $332 = Math_fround($328 * $331);
   $333 = Math_fround(HEAPF32[$157>>2]);
   $334 = Math_fround($329 * $333);
   $335 = Math_fround($332 + $334);
   $336 = Math_fround(HEAPF32[$158>>2]);
   $337 = Math_fround($330 * $336);
   $338 = Math_fround($335 + $337);
   $339 = Math_fround(HEAPF32[$160>>2]);
   $340 = Math_fround($328 * $339);
   $341 = Math_fround(HEAPF32[$161>>2]);
   $342 = Math_fround($329 * $341);
   $343 = Math_fround($340 + $342);
   $344 = Math_fround(HEAPF32[$162>>2]);
   $345 = Math_fround($330 * $344);
   $346 = Math_fround($343 + $345);
   $347 = Math_fround(HEAPF32[$164>>2]);
   $348 = Math_fround($328 * $347);
   $349 = Math_fround(HEAPF32[$165>>2]);
   $350 = Math_fround($329 * $349);
   $351 = Math_fround($348 + $350);
   $352 = Math_fround(HEAPF32[$166>>2]);
   $353 = Math_fround($330 * $352);
   $354 = Math_fround($351 + $353);
   $355 = Math_fround(HEAPF32[$normal>>2]);
   $356 = (($normal) + 4|0);
   $357 = Math_fround(HEAPF32[$356>>2]);
   $358 = (($normal) + 8|0);
   $359 = Math_fround(HEAPF32[$358>>2]);
   $360 = Math_fround(HEAPF32[$penDep>>2]);
   HEAPF32[$contactBuffer>>2] = $338;
   $361 = (($contactBuffer) + 4|0);
   HEAPF32[$361>>2] = $346;
   $362 = (($contactBuffer) + 8|0);
   HEAPF32[$362>>2] = $354;
   $363 = (($contactBuffer) + 12|0);
   HEAPF32[$363>>2] = Math_fround(0.0);
   $364 = (($contactBuffer) + 16|0);
   ;HEAP32[$364+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$364+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$364+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$364+12>>2]=HEAP32[$closestB+12>>2]|0;
   HEAP32[$numContacts>>2] = 1;
   $365 = (($contactBuffer) + 32|0);
   HEAPF32[$365>>2] = $355;
   $366 = (($contactBuffer) + 36|0);
   HEAPF32[$366>>2] = $357;
   $367 = (($contactBuffer) + 40|0);
   HEAPF32[$367>>2] = $359;
   $368 = (($contactBuffer) + 44|0);
   HEAPF32[$368>>2] = $360;
   label = 15;
  } else {
   $369 = (($supportMap) + 4|0);
   HEAP8[$369>>0] = 0;
   HEAP32[$supportMap>>2] = ((550992 + 8|0));
   $370 = (($supportMap) + 8|0);
   HEAP32[$370>>2] = $capsule;
   $371 = (($supportMap) + 12|0);
   HEAP32[$371>>2] = $convexHull;
   $372 = (($4) + 34|0);
   $373 = (($4) + 38|0);
   $374 = (($4) + 33|0);
   $375 = HEAP8[$374>>0]|0;
   $376 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($capsule,$convexHull,$supportMap,$372,$373,$375,$closestA,$closestB,$normal,$penDep,1)|0);
   if ((($376|0) == 4)) {
    $doOverlapTest$1$off0156 = 1;
    break;
   } else if (!((($376|0) == 6))) {
    label = 15;
    break;
   }
   $377 = Math_fround(HEAPF32[$closestA>>2]);
   $378 = (($closestA) + 4|0);
   $379 = Math_fround(HEAPF32[$378>>2]);
   $380 = (($closestA) + 8|0);
   $381 = Math_fround(HEAPF32[$380>>2]);
   $382 = Math_fround(HEAPF32[$130>>2]);
   $383 = Math_fround(HEAPF32[$131>>2]);
   $384 = Math_fround(HEAPF32[$132>>2]);
   $385 = Math_fround($377 - $382);
   $386 = Math_fround($379 - $383);
   $387 = Math_fround($381 - $384);
   $388 = Math_fround(HEAPF32[$aToB>>2]);
   $389 = Math_fround($385 * $388);
   $390 = Math_fround(HEAPF32[$157>>2]);
   $391 = Math_fround($386 * $390);
   $392 = Math_fround($389 + $391);
   $393 = Math_fround(HEAPF32[$158>>2]);
   $394 = Math_fround($387 * $393);
   $395 = Math_fround($392 + $394);
   $396 = Math_fround(HEAPF32[$160>>2]);
   $397 = Math_fround($385 * $396);
   $398 = Math_fround(HEAPF32[$161>>2]);
   $399 = Math_fround($386 * $398);
   $400 = Math_fround($397 + $399);
   $401 = Math_fround(HEAPF32[$162>>2]);
   $402 = Math_fround($387 * $401);
   $403 = Math_fround($400 + $402);
   $404 = Math_fround(HEAPF32[$164>>2]);
   $405 = Math_fround($385 * $404);
   $406 = Math_fround(HEAPF32[$165>>2]);
   $407 = Math_fround($386 * $406);
   $408 = Math_fround($405 + $407);
   $409 = Math_fround(HEAPF32[$166>>2]);
   $410 = Math_fround($387 * $409);
   $411 = Math_fround($408 + $410);
   $412 = Math_fround(HEAPF32[$normal>>2]);
   $413 = (($normal) + 4|0);
   $414 = Math_fround(HEAPF32[$413>>2]);
   $415 = (($normal) + 8|0);
   $416 = Math_fround(HEAPF32[$415>>2]);
   $417 = Math_fround(HEAPF32[$penDep>>2]);
   $418 = HEAP32[$numContacts>>2]|0;
   $419 = (($contactBuffer) + (($418*48)|0)|0);
   HEAPF32[$419>>2] = $395;
   $420 = ((($contactBuffer) + (($418*48)|0)|0) + 4|0);
   HEAPF32[$420>>2] = $403;
   $421 = ((($contactBuffer) + (($418*48)|0)|0) + 8|0);
   HEAPF32[$421>>2] = $411;
   $422 = ((($contactBuffer) + (($418*48)|0)|0) + 12|0);
   HEAPF32[$422>>2] = Math_fround(0.0);
   $423 = ((($contactBuffer) + (($418*48)|0)|0) + 16|0);
   ;HEAP32[$423+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$423+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$423+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$423+12>>2]=HEAP32[$closestB+12>>2]|0;
   $424 = (($418) + 1)|0;
   HEAP32[$numContacts>>2] = $424;
   $425 = ((($contactBuffer) + (($418*48)|0)|0) + 32|0);
   HEAPF32[$425>>2] = $412;
   $426 = ((($contactBuffer) + (($418*48)|0)|0) + 36|0);
   HEAPF32[$426>>2] = $414;
   $427 = ((($contactBuffer) + (($418*48)|0)|0) + 40|0);
   HEAPF32[$427>>2] = $416;
   $428 = ((($contactBuffer) + (($418*48)|0)|0) + 44|0);
   HEAPF32[$428>>2] = $417;
   label = 15;
  }
 } while(0);
 if ((label|0) == 15) {
  $429 = ($188<<24>>24)==(0);
  $or$cond = $429 | $191;
  if ($or$cond) {
   $doOverlapTest$1$off0156 = 0;
  } else {
   $431 = Math_fround($$$i * Math_fround(0.0500000007450580596924));
   HEAPF32[$replaceBreakingThreshold>>2] = $431;
   $432 = Math_fround(HEAPF32[$normal>>2]);
   $433 = (($normal) + 4|0);
   $434 = Math_fround(HEAPF32[$433>>2]);
   $435 = (($normal) + 8|0);
   $436 = Math_fround(HEAPF32[$435>>2]);
   $437 = (($normal) + 12|0);
   $438 = Math_fround(HEAPF32[$penDep>>2]);
   HEAPF32[$localNormalPen3>>2] = $432;
   $439 = (($localNormalPen3) + 4|0);
   HEAPF32[$439>>2] = $434;
   $440 = (($localNormalPen3) + 8|0);
   HEAPF32[$440>>2] = $436;
   $441 = (($localNormalPen3) + 12|0);
   HEAPF32[$441>>2] = $438;
   $442 = Math_fround(HEAPF32[$closestA>>2]);
   $443 = (($closestA) + 4|0);
   $444 = Math_fround(HEAPF32[$443>>2]);
   $445 = (($closestA) + 8|0);
   $446 = Math_fround(HEAPF32[$445>>2]);
   $447 = Math_fround(HEAPF32[$130>>2]);
   $448 = Math_fround(HEAPF32[$131>>2]);
   $449 = Math_fround(HEAPF32[$132>>2]);
   $450 = Math_fround($442 - $447);
   $451 = Math_fround($444 - $448);
   $452 = Math_fround($446 - $449);
   $453 = Math_fround(HEAPF32[$aToB>>2]);
   $454 = Math_fround($450 * $453);
   $455 = Math_fround(HEAPF32[$157>>2]);
   $456 = Math_fround($451 * $455);
   $457 = Math_fround($454 + $456);
   $458 = Math_fround(HEAPF32[$158>>2]);
   $459 = Math_fround($452 * $458);
   $460 = Math_fround($457 + $459);
   $461 = Math_fround(HEAPF32[$160>>2]);
   $462 = Math_fround($450 * $461);
   $463 = Math_fround(HEAPF32[$161>>2]);
   $464 = Math_fround($451 * $463);
   $465 = Math_fround($462 + $464);
   $466 = Math_fround(HEAPF32[$162>>2]);
   $467 = Math_fround($452 * $466);
   $468 = Math_fround($465 + $467);
   $469 = Math_fround(HEAPF32[$164>>2]);
   $470 = Math_fround($450 * $469);
   $471 = Math_fround(HEAPF32[$165>>2]);
   $472 = Math_fround($451 * $471);
   $473 = Math_fround($470 + $472);
   $474 = Math_fround(HEAPF32[$166>>2]);
   $475 = Math_fround($452 * $474);
   $476 = Math_fround($473 + $475);
   HEAPF32[$1>>2] = $460;
   $477 = (($1) + 4|0);
   HEAPF32[$477>>2] = $468;
   $478 = (($1) + 8|0);
   HEAPF32[$478>>2] = $476;
   $479 = (($1) + 12|0);
   HEAPF32[$479>>2] = Math_fround(0.0);
   (__ZN5physx2Gu25PersistentContactManifold17addManifoldPoint2ERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($4,$1,$closestB,$localNormalPen3,$replaceBreakingThreshold)|0);
   $480 = Math_fround(HEAPF32[$transf1>>2]);
   $481 = Math_fround(HEAPF32[$55>>2]);
   $482 = Math_fround(HEAPF32[$56>>2]);
   $483 = Math_fround(HEAPF32[$57>>2]);
   $484 = Math_fround(HEAPF32[$normal>>2]);
   $485 = Math_fround(HEAPF32[$433>>2]);
   $486 = Math_fround(HEAPF32[$435>>2]);
   $487 = Math_fround($483 * $483);
   $488 = Math_fround($487 + Math_fround(-0.5));
   $489 = Math_fround($484 * $488);
   $490 = Math_fround($488 * $485);
   $491 = Math_fround($488 * $486);
   $492 = Math_fround($481 * $486);
   $493 = Math_fround($482 * $485);
   $494 = Math_fround($492 - $493);
   $495 = Math_fround($482 * $484);
   $496 = Math_fround($480 * $486);
   $497 = Math_fround($495 - $496);
   $498 = Math_fround($480 * $485);
   $499 = Math_fround($481 * $484);
   $500 = Math_fround($498 - $499);
   $501 = Math_fround($483 * $494);
   $502 = Math_fround($483 * $497);
   $503 = Math_fround($483 * $500);
   $504 = Math_fround($489 + $501);
   $505 = Math_fround($490 + $502);
   $506 = Math_fround($491 + $503);
   $507 = Math_fround($480 * $484);
   $508 = Math_fround($481 * $485);
   $509 = Math_fround($507 + $508);
   $510 = Math_fround($482 * $486);
   $511 = Math_fround($509 + $510);
   $512 = Math_fround($480 * $511);
   $513 = Math_fround($481 * $511);
   $514 = Math_fround($482 * $511);
   $515 = Math_fround($512 + $504);
   $516 = Math_fround($513 + $505);
   $517 = Math_fround($506 + $514);
   $518 = Math_fround($515 * Math_fround(2.0));
   $519 = Math_fround($516 * Math_fround(2.0));
   $520 = Math_fround($517 * Math_fround(2.0));
   HEAPF32[$normal>>2] = $518;
   HEAPF32[$433>>2] = $519;
   HEAPF32[$435>>2] = $520;
   HEAPF32[$437>>2] = Math_fround(0.0);
   __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($4,$contactBuffer,$normal,$transf0,$capsuleRadius);
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $430 = (__ZN5physx2GuL35fullContactsGenerationCapsuleConvexERKNS0_8CapsuleVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVESE_PNS0_17PersistentContactERjRNS0_13ContactBufferEbRNS0_25PersistentContactManifoldERNS8_5Vec3VERKNS8_6FloatVEb($capsule,$convexHull,$aToB,$transf0,$transf1,$contactBuffer,$numContacts,$contactBuffer,$318,$4,$normal,$contactDist,$doOverlapTest$1$off0156)|0);
 $$1 = $430;
 STACKTOP = sp;return ($$1|0);
}
function __ZN5physx2GuL35fullContactsGenerationCapsuleConvexERKNS0_8CapsuleVERKNS0_11ConvexHullVERKNS_6shdfnd3aos15PsMatTransformVERKNS8_12PsTransformVESE_PNS0_17PersistentContactERjRNS0_13ContactBufferEbRNS0_25PersistentContactManifoldERNS8_5Vec3VERKNS8_6FloatVEb($capsule,$convexHull,$aToB,$transf0,$transf1,$manifoldContacts,$numContacts,$contactBuffer,$idtScale,$manifold,$normal,$contactDist,$doOverlapTest) {
 $capsule = $capsule|0;
 $convexHull = $convexHull|0;
 $aToB = $aToB|0;
 $transf0 = $transf0|0;
 $transf1 = $transf1|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactBuffer = $contactBuffer|0;
 $idtScale = $idtScale|0;
 $manifold = $manifold|0;
 $normal = $normal|0;
 $contactDist = $contactDist|0;
 $doOverlapTest = $doOverlapTest|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $buff = 0, $or$cond = 0, $polyData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $polyData = sp + 64|0;
 $buff = sp;
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHull,$idtScale,$polyData);
 $0 = (($convexHull) + 96|0);
 $1 = (($convexHull) + 144|0);
 $2 = (($buff) + 32|0);
 HEAP32[$2>>2] = $transf1;
 $3 = (($buff) + 36|0);
 HEAP32[$3>>2] = $0;
 $4 = (($buff) + 40|0);
 HEAP32[$4>>2] = $1;
 $5 = (($buff) + 44|0);
 $6 = $idtScale&1;
 HEAP8[$5>>0] = $6;
 if ($idtScale) {
  HEAP32[$buff>>2] = ((546744 + 8|0));
  $7 = (($buff) + 48|0);
  HEAP32[$7>>2] = $convexHull;
 } else {
  HEAP32[$buff>>2] = ((546712 + 8|0));
  $8 = (($buff) + 48|0);
  HEAP32[$8>>2] = $convexHull;
 }
 $9 = HEAP32[$numContacts>>2]|0;
 $10 = (__ZN5physx2Gu27generateFullContactManifoldERKNS0_8CapsuleVERNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVERNS9_5Vec3VEb($capsule,$polyData,$buff,$aToB,$manifoldContacts,$numContacts,$contactDist,$normal,$doOverlapTest)|0);
 if (!($10)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$numContacts>>2]|0;
 $12 = ($11|0)!=($9|0);
 $13 = ($9|0)!=(0);
 $or$cond = $12 & $13;
 if ($or$cond) {
  $14 = (($11) + -1)|0;
  HEAP32[$numContacts>>2] = $14;
  $15 = (($manifoldContacts) + 48|0);
  $$02 = $15;$16 = $14;
 } else {
  $$02 = $manifoldContacts;$16 = $11;
 }
 __ZN5physx2Gu25PersistentContactManifold25addBatchManifoldContacts2EPKNS0_17PersistentContactEj($manifold,$$02,$16);
 $17 = Math_fround(HEAPF32[$transf1>>2]);
 $18 = (($transf1) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($transf1) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($transf1) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(HEAPF32[$normal>>2]);
 $25 = (($normal) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($normal) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($23 * $23);
 $30 = Math_fround($29 + Math_fround(-0.5));
 $31 = Math_fround($24 * $30);
 $32 = Math_fround($30 * $26);
 $33 = Math_fround($30 * $28);
 $34 = Math_fround($19 * $28);
 $35 = Math_fround($21 * $26);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($21 * $24);
 $38 = Math_fround($17 * $28);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($17 * $26);
 $41 = Math_fround($19 * $24);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($23 * $36);
 $44 = Math_fround($23 * $39);
 $45 = Math_fround($23 * $42);
 $46 = Math_fround($31 + $43);
 $47 = Math_fround($32 + $44);
 $48 = Math_fround($33 + $45);
 $49 = Math_fround($17 * $24);
 $50 = Math_fround($19 * $26);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($21 * $28);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($17 * $53);
 $55 = Math_fround($19 * $53);
 $56 = Math_fround($21 * $53);
 $57 = Math_fround($54 + $46);
 $58 = Math_fround($55 + $47);
 $59 = Math_fround($48 + $56);
 $60 = Math_fround($57 * Math_fround(2.0));
 $61 = Math_fround($58 * Math_fround(2.0));
 $62 = Math_fround($59 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $60;
 HEAPF32[$25>>2] = $61;
 HEAPF32[$27>>2] = $62;
 $63 = (($normal) + 12|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($capsule) + 128|0);
 __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($manifold,$contactBuffer,$normal,$transf0,$64);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu24PCMMeshContactGeneration15processContactsEhb($this,$maxContactPerManifold,$isNotLastPatch) {
 $this = $this|0;
 $maxContactPerManifold = $maxContactPerManifold|0;
 $isNotLastPatch = $isNotLastPatch|0;
 var $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre$i1 = 0, $$pre23 = 0, $$pre24 = 0, $$pre58$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0;
 var $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $currentPatch$0$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i4 = 0;
 var $i$021$i = 0, $i$049$i = 0, $i$07 = 0, $i$08$i = 0, $j$0$i = 0, $j$07$i = 0, $k$044$i = 0, $l$042$i = 0, $l$1$i = 0, $or$cond$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 2324|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 2328|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>(1);
 if ($5) {
  $146 = $4;$i$08$i = 1;
  while(1) {
   $6 = (($i$08$i) + -1)|0;
   $7 = ((($this) + ($6<<2)|0) + 2048|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 32|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = ((($this) + ($i$08$i<<2)|0) + 2048|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 32|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = $10 > $14;
   if ($15) {
    HEAP32[$7>>2] = $12;
    HEAP32[$11>>2] = $8;
    $16 = (($i$08$i) + -2)|0;
    $17 = ($16|0)>(-1);
    L9: do {
     if ($17) {
      $j$07$i = $16;
      while(1) {
       $18 = Math_fround(HEAPF32[$13>>2]);
       $19 = ((($this) + ($j$07$i<<2)|0) + 2048|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($20) + 32|0);
       $22 = Math_fround(HEAPF32[$21>>2]);
       $23 = !($18 >= $22);
       if (!($23)) {
        break L9;
       }
       $24 = (($j$07$i) + 1)|0;
       $25 = ((($this) + ($24<<2)|0) + 2048|0);
       HEAP32[$25>>2] = $20;
       HEAP32[$19>>2] = $12;
       $26 = (($j$07$i) + -1)|0;
       $27 = ($j$07$i|0)>(0);
       if ($27) {
        $j$07$i = $26;
       } else {
        break;
       }
      }
     }
    } while(0);
    $$pre$i = HEAP32[$3>>2]|0;
    $$pr = $$pre$i;
   } else {
    $$pr = $146;
   }
   $28 = (($i$08$i) + 1)|0;
   $29 = ($28>>>0)<($$pr>>>0);
   if ($29) {
    $146 = $$pr;$i$08$i = $28;
   } else {
    $35 = $$pr;
    break;
   }
  }
 } else {
  $35 = $4;
 }
 $30 = (($this) + 2216|0);
 $31 = (($this) + 2048|0);
 $32 = (($this) + 2320|0);
 $33 = (($this) + 2224|0);
 $34 = ($35|0)==(0);
 if ($34) {
  $36 = HEAP32[$32>>2]|0;
  $37 = (($this) + 2240|0);
  $140 = $36;$141 = 0;$142 = $37;
 } else {
  $i$021$i = 0;
  while(1) {
   $38 = ((($this) + ($i$021$i<<2)|0) + 2048|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 24|0);
   HEAP32[$40>>2] = $39;
   $41 = (($39) + 20|0);
   HEAP32[$41>>2] = $39;
   $42 = (($39) + 52|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($39) + 48|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($43) - ($45))|0;
   $47 = (($39) + 56|0);
   HEAP32[$47>>2] = $46;
   $48 = (($39) + 16|0);
   HEAP32[$48>>2] = 0;
   $49 = (($39) + 4|0);
   $50 = (($39) + 8|0);
   $j$0$i = $i$021$i;
   while(1) {
    $51 = ($j$0$i|0)==(0);
    if ($51) {
     break;
    }
    $52 = (($j$0$i) + -1)|0;
    $53 = ((($this) + ($52<<2)|0) + 2048|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = Math_fround(HEAPF32[$39>>2]);
    $56 = Math_fround(HEAPF32[$49>>2]);
    $57 = Math_fround(HEAPF32[$50>>2]);
    $58 = (($54) + 24|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = (($59) + 4|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = (($59) + 8|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = Math_fround($55 * $60);
    $66 = Math_fround($56 * $62);
    $67 = Math_fround($65 + $66);
    $68 = Math_fround($57 * $64);
    $69 = Math_fround($67 + $68);
    $70 = Math_fround(HEAPF32[$33>>2]);
    $71 = !($69 >= $70);
    if ($71) {
     $j$0$i = $52;
    } else {
     label = 15;
     break;
    }
   }
   if ((label|0) == 15) {
    label = 0;
    $72 = (($54) + 16|0);
    HEAP32[$72>>2] = $39;
    $73 = (($59) + 20|0);
    HEAP32[$73>>2] = $39;
    $74 = HEAP32[$58>>2]|0;
    HEAP32[$40>>2] = $74;
    $75 = HEAP32[$58>>2]|0;
    $76 = (($75) + 56|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + ($46))|0;
    HEAP32[$76>>2] = $78;
   }
   $79 = (($i$021$i) + 1)|0;
   $exitcond$i4 = ($79|0)==($35|0);
   if ($exitcond$i4) {
    break;
   } else {
    $i$021$i = $79;
   }
  }
  $$pre = HEAP32[$3>>2]|0;
  $80 = HEAP32[$32>>2]|0;
  $81 = (($this) + 2240|0);
  $82 = ($$pre|0)==(0);
  if ($82) {
   $140 = $80;$141 = 0;$142 = $81;
  } else {
   $i$049$i = 0;
   while(1) {
    $83 = ((($this) + ($i$049$i<<2)|0) + 2048|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($84) + 24|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==($84|0);
    $88 = ($84|0)!=(0|0);
    $or$cond$i = $87 & $88;
    L31: do {
     if ($or$cond$i) {
      $currentPatch$0$i = $84;
      L32: while(1) {
       $89 = (($currentPatch$0$i) + 16|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = ($90|0)==(0|0);
       if ($91) {
        break L31;
       }
       $92 = (($currentPatch$0$i) + 48|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = (($currentPatch$0$i) + 52|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = ($93>>>0)<($95>>>0);
       if (!($96)) {
        $currentPatch$0$i = $90;
        continue;
       }
       $97 = (($90) + 48|0);
       $98 = (($90) + 52|0);
       $$pre$i1 = HEAP32[$98>>2]|0;
       $101 = $$pre$i1;$147 = $95;$k$044$i = $93;
       while(1) {
        $99 = HEAP32[$97>>2]|0;
        $100 = ($99>>>0)<($101>>>0);
        if ($100) {
         $102 = ((($80) + ($k$044$i<<6)|0) + 16|0);
         $103 = ((($80) + ($k$044$i<<6)|0) + 20|0);
         $104 = ((($80) + ($k$044$i<<6)|0) + 24|0);
         $126 = $101;$l$042$i = $99;
         while(1) {
          $105 = ((($80) + ($l$042$i<<6)|0) + 16|0);
          $106 = Math_fround(HEAPF32[$105>>2]);
          $107 = ((($80) + ($l$042$i<<6)|0) + 20|0);
          $108 = Math_fround(HEAPF32[$107>>2]);
          $109 = ((($80) + ($l$042$i<<6)|0) + 24|0);
          $110 = Math_fround(HEAPF32[$109>>2]);
          $111 = Math_fround(HEAPF32[$102>>2]);
          $112 = Math_fround(HEAPF32[$103>>2]);
          $113 = Math_fround(HEAPF32[$104>>2]);
          $114 = Math_fround($106 - $111);
          $115 = Math_fround($108 - $112);
          $116 = Math_fround($110 - $113);
          $117 = Math_fround($114 * $114);
          $118 = Math_fround($115 * $115);
          $119 = Math_fround($117 + $118);
          $120 = Math_fround($116 * $116);
          $121 = Math_fround($119 + $120);
          $122 = Math_fround(HEAPF32[$81>>2]);
          $123 = $122 > $121;
          if ($123) {
           $124 = (($80) + ($l$042$i<<6)|0);
           $125 = (($126) + -1)|0;
           $127 = (($80) + ($125<<6)|0);
           dest=$124+0|0; src=$127+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           $128 = HEAP32[$98>>2]|0;
           $129 = (($128) + -1)|0;
           HEAP32[$98>>2] = $129;
           $130 = (($l$042$i) + -1)|0;
           $133 = $129;$l$1$i = $130;
          } else {
           $133 = $126;$l$1$i = $l$042$i;
          }
          $131 = (($l$1$i) + 1)|0;
          $132 = ($131>>>0)<($133>>>0);
          if ($132) {
           $126 = $133;$l$042$i = $131;
          } else {
           break;
          }
         }
         $$pre58$i = HEAP32[$94>>2]|0;
         $136 = $$pre58$i;$148 = $133;
        } else {
         $136 = $147;$148 = $101;
        }
        $134 = (($k$044$i) + 1)|0;
        $135 = ($134>>>0)<($136>>>0);
        if ($135) {
         $101 = $148;$147 = $136;$k$044$i = $134;
        } else {
         $currentPatch$0$i = $90;
         continue L32;
        }
       }
      }
     }
    } while(0);
    $137 = (($i$049$i) + 1)|0;
    $exitcond$i = ($137|0)==($$pre|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$049$i = $137;
    }
   }
   $$pre23 = HEAP32[$32>>2]|0;
   $$pre24 = HEAP32[$3>>2]|0;
   $140 = $$pre23;$141 = $$pre24;$142 = $81;
  }
 }
 $138 = HEAP32[$30>>2]|0;
 $139 = HEAP32[$0>>2]|0;
 __ZN5physx2Gu33MultiplePersistentContactManifold24addManifoldContactPointsEPNS0_21MeshPersistentContactEjPPNS0_15PCMContactPatchEjRKNS_6shdfnd3aos6FloatVESB_h($138,$140,$139,$31,$141,$142,$33,$maxContactPerManifold);
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 if ($isNotLastPatch) {
  $i$07 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $143 = (($this) + ($i$07<<6)|0);
  $144 = ((($this) + ($i$07<<2)|0) + 2048|0);
  HEAP32[$144>>2] = $143;
  $145 = (($i$07) + 1)|0;
  $exitcond = ($145|0)==(32);
  if ($exitcond) {
   break;
  } else {
   $i$07 = $145;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu24PCMMeshContactGenerationC2ERKNS_6shdfnd3aos6FloatVES6_RKNS3_12PsTransformVES9_RNS0_33MultiplePersistentContactManifoldERNS0_13ContactBufferE($this,$contactDist,$replaceBreakingThreshold,$convexTransform,$meshTransform,$multiManifold,$contactBuffer) {
 $this = $this|0;
 $contactDist = $contactDist|0;
 $replaceBreakingThreshold = $replaceBreakingThreshold|0;
 $convexTransform = $convexTransform|0;
 $meshTransform = $meshTransform|0;
 $multiManifold = $multiManifold|0;
 $contactBuffer = $contactBuffer|0;
 var $$sroa$1 = 0, $$sroa$1$i$i4 = 0, $$sroa$16 = 0, $$sroa$3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $i$025 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp;
 $$sroa$1$i$i4 = sp + 56|0;
 $$sroa$3$i$i = sp + 16|0;
 $$sroa$16 = sp + 32|0;
 $$sroa$1 = sp + 44|0;
 $1 = (($this) + 2048|0);
 $3 = $this;
 while(1) {
  $2 = (($3) + 16|0);
  HEAP32[$2>>2] = 0;
  $4 = (($3) + 20|0);
  HEAP32[$4>>2] = 0;
  $5 = (($3) + 24|0);
  HEAP32[$5>>2] = $3;
  $6 = (($3) + 32|0);
  HEAPF32[$6>>2] = Math_fround(3.40282346638528859812E+38);
  $7 = (($3) + 36|0);
  ;HEAP32[$7+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$0+8>>2]|0;
  $8 = (($3) + 64|0);
  $9 = ($8|0)==($1|0);
  if ($9) {
   break;
  } else {
   $3 = $8;
  }
 }
 $10 = (($this) + 2176|0);
 ;HEAP32[$10+0>>2]=HEAP32[$contactDist+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$contactDist+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$contactDist+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$contactDist+12>>2]|0;
 $11 = (($this) + 2192|0);
 ;HEAP32[$11+0>>2]=HEAP32[$replaceBreakingThreshold+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$replaceBreakingThreshold+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$replaceBreakingThreshold+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$replaceBreakingThreshold+12>>2]|0;
 $12 = (($this) + 2208|0);
 HEAP32[$12>>2] = $convexTransform;
 $13 = (($this) + 2212|0);
 HEAP32[$13>>2] = $meshTransform;
 $14 = (($this) + 2216|0);
 HEAP32[$14>>2] = $multiManifold;
 $15 = (($this) + 2220|0);
 HEAP32[$15>>2] = $contactBuffer;
 $16 = (($this) + 2304|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$16+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$sroa$1$i$i4+0>>2]=0|0;HEAP32[$$sroa$1$i$i4+4>>2]=0|0;HEAP32[$$sroa$1$i$i4+8>>2]=0|0;HEAP32[$$sroa$1$i$i4+12>>2]=0|0;
 ;HEAP32[$$sroa$3$i$i+0>>2]=0|0;HEAP32[$$sroa$3$i$i+4>>2]=0|0;HEAP32[$$sroa$3$i$i+8>>2]=0|0;HEAP32[$$sroa$3$i$i+12>>2]=0|0;
 $17 = (($this) + 2256|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($this) + 2260|0);
 ;HEAP32[$18+0>>2]=HEAP32[$$sroa$1$i$i4+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$$sroa$1$i$i4+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$$sroa$1$i$i4+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$$sroa$1$i$i4+12>>2]|0;
 $19 = (($this) + 2276|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($this) + 2280|0);
 ;HEAP32[$20+0>>2]=HEAP32[$$sroa$3$i$i+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$$sroa$3$i$i+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$$sroa$3$i$i+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$$sroa$3$i$i+12>>2]|0;
 $21 = (($this) + 2296|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 2300|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 2328|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 2324|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 2332|0);
 HEAP32[$25>>2] = 0;
 $26 = Math_fround(HEAPF32[$convexTransform>>2]);
 $27 = (($convexTransform) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($convexTransform) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($convexTransform) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(-$26);
 $34 = Math_fround(-$28);
 $35 = Math_fround(-$30);
 $36 = (($meshTransform) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($meshTransform) + 20|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($meshTransform) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($convexTransform) + 16|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($convexTransform) + 20|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($convexTransform) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($37 - $43);
 $49 = Math_fround($39 - $45);
 $50 = Math_fround($41 - $47);
 $51 = Math_fround($32 * $32);
 $52 = Math_fround($51 + Math_fround(-0.5));
 $53 = Math_fround($52 * $48);
 $54 = Math_fround($52 * $49);
 $55 = Math_fround($52 * $50);
 $56 = Math_fround($50 * $34);
 $57 = Math_fround($49 * $35);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($48 * $35);
 $60 = Math_fround($50 * $33);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($49 * $33);
 $63 = Math_fround($48 * $34);
 $64 = Math_fround($62 - $63);
 $65 = Math_fround($32 * $58);
 $66 = Math_fround($32 * $61);
 $67 = Math_fround($32 * $64);
 $68 = Math_fround($53 + $65);
 $69 = Math_fround($54 + $66);
 $70 = Math_fround($55 + $67);
 $71 = Math_fround($48 * $33);
 $72 = Math_fround($49 * $34);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($50 * $35);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($75 * $33);
 $77 = Math_fround($75 * $34);
 $78 = Math_fround($75 * $35);
 $79 = Math_fround($76 + $68);
 $80 = Math_fround($77 + $69);
 $81 = Math_fround($70 + $78);
 $82 = Math_fround($79 * Math_fround(2.0));
 $83 = Math_fround($80 * Math_fround(2.0));
 $84 = Math_fround($81 * Math_fround(2.0));
 $85 = Math_fround(HEAPF32[$meshTransform>>2]);
 $86 = (($meshTransform) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($meshTransform) + 8|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($meshTransform) + 12|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($32 * $91);
 $93 = Math_fround($85 * $33);
 $94 = Math_fround($87 * $34);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($89 * $35);
 $97 = Math_fround($95 + $96);
 $98 = Math_fround($92 - $97);
 $99 = Math_fround($91 * $33);
 $100 = Math_fround($91 * $34);
 $101 = Math_fround($91 * $35);
 $102 = Math_fround($32 * $85);
 $103 = Math_fround($32 * $87);
 $104 = Math_fround($32 * $89);
 $105 = Math_fround($89 * $34);
 $106 = Math_fround($87 * $35);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($85 * $35);
 $109 = Math_fround($89 * $33);
 $110 = Math_fround($108 - $109);
 $111 = Math_fround($87 * $33);
 $112 = Math_fround($85 * $34);
 $113 = Math_fround($111 - $112);
 $114 = Math_fround($102 + $99);
 $115 = Math_fround($103 + $100);
 $116 = Math_fround($104 + $101);
 $117 = Math_fround($107 + $114);
 $118 = Math_fround($110 + $115);
 $119 = Math_fround($113 + $116);
 $120 = Math_fround($117 + $117);
 $121 = Math_fround($118 + $118);
 $122 = Math_fround($119 + $119);
 $123 = Math_fround($117 * $120);
 $124 = Math_fround($118 * $121);
 $125 = Math_fround($119 * $122);
 $126 = Math_fround($118 * $120);
 $127 = Math_fround($119 * $120);
 $128 = Math_fround($98 * $120);
 $129 = Math_fround($119 * $121);
 $130 = Math_fround($98 * $121);
 $131 = Math_fround($98 * $122);
 $132 = Math_fround(Math_fround(1.0) - $123);
 $133 = Math_fround(Math_fround(1.0) - $124);
 $134 = Math_fround($133 - $125);
 $135 = Math_fround($126 + $131);
 $136 = Math_fround($127 - $130);
 $137 = Math_fround($126 - $131);
 $138 = Math_fround($132 - $125);
 $139 = Math_fround($129 + $128);
 $140 = Math_fround($127 + $130);
 $141 = Math_fround($129 - $128);
 $142 = Math_fround($132 - $124);
 HEAPF32[$17>>2] = $134;
 HEAPF32[$18>>2] = $135;
 $143 = (($this) + 2264|0);
 HEAPF32[$143>>2] = $136;
 $144 = (($this) + 2268|0);
 HEAPF32[$144>>2] = Math_fround(0.0);
 $145 = (($this) + 2272|0);
 HEAPF32[$145>>2] = $137;
 HEAPF32[$19>>2] = $138;
 HEAPF32[$20>>2] = $139;
 $146 = (($this) + 2284|0);
 HEAPF32[$146>>2] = Math_fround(0.0);
 $147 = (($this) + 2288|0);
 HEAPF32[$147>>2] = $140;
 $148 = (($this) + 2292|0);
 HEAPF32[$148>>2] = $141;
 HEAPF32[$21>>2] = $142;
 HEAPF32[$22>>2] = Math_fround(0.0);
 $149 = (($this) + 2304|0);
 HEAPF32[$149>>2] = $82;
 $150 = (($this) + 2308|0);
 HEAPF32[$150>>2] = $83;
 $151 = (($this) + 2312|0);
 HEAPF32[$151>>2] = $84;
 $152 = (($this) + 2316|0);
 HEAPF32[$152>>2] = Math_fround(0.0);
 $i$025 = 0;
 while(1) {
  $153 = (($this) + ($i$025<<6)|0);
  $154 = ((($this) + ($i$025<<2)|0) + 2048|0);
  HEAP32[$154>>2] = $153;
  $155 = (($i$025) + 1)|0;
  $exitcond = ($155|0)==(32);
  if ($exitcond) {
   break;
  } else {
   $i$025 = $155;
  }
 }
 $156 = (($this) + 2320|0);
 HEAP32[$156>>2] = $contactBuffer;
 $157 = Math_fround(HEAPF32[$replaceBreakingThreshold>>2]);
 $158 = Math_fround($157 * $157);
 $159 = (($this) + 2240|0);
 HEAPF32[$159>>2] = $158;
 $160 = (($this) + 2244|0);
 ;HEAP32[$160+0>>2]=HEAP32[$$sroa$16+0>>2]|0;HEAP32[$160+4>>2]=HEAP32[$$sroa$16+4>>2]|0;HEAP32[$160+8>>2]=HEAP32[$$sroa$16+8>>2]|0;
 $161 = (($this) + 2224|0);
 HEAPF32[$161>>2] = Math_fround(0.995999991893768310546);
 $162 = (($this) + 2228|0);
 ;HEAP32[$162+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu21pcmContactCapsuleMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$1$i$i$i$i = Math_fround(0), $$sroa$19$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0;
 var $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = 0;
 var $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = Math_fround(0);
 var $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0;
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0);
 var $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = 0;
 var $509 = 0, $51 = Math_fround(0), $510 = Math_fround(0), $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0), $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $_maxPen$i = 0, $aToB = 0, $callback = 0, $capsule = 0, $capsuleRadius = 0, $capsuleTransform = 0, $contactDist = 0, $count$01$i$i$i = 0, $edgeFlags$05$i$i$i = 0, $hmd = 0, $i$04$i = 0, $i$1$i = 0, $meshScaling = 0, $meshTransform = 0, $projectBreakingThreshold = 0, $queryCapsule = 0, $refereshDistance = 0, $replaceBreakingThreshold = 0;
 var $triInds$04$i$i$i = 0, $vertInds$03$i$i$i = 0, $verts$02$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3808|0;
 $_maxPen$i = sp + 3440|0;
 $$sroa$19$i$i$i$i = sp + 3708|0;
 $capsuleRadius = sp + 3664|0;
 $contactDist = sp + 3648|0;
 $capsuleTransform = sp + 3616|0;
 $meshTransform = sp + 3584|0;
 $aToB = sp + 3504|0;
 $replaceBreakingThreshold = sp + 3568|0;
 $projectBreakingThreshold = sp + 3424|0;
 $refereshDistance = sp + 3408|0;
 $meshScaling = sp + 3736|0;
 $capsule = sp + 3264|0;
 $queryCapsule = sp + 3680|0;
 $callback = sp;
 $hmd = sp + 3720|0;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 & -16;
 $2 = $1;
 $3 = (($shape0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$capsuleRadius>>2] = $4;
 $5 = Math_fround(HEAPF32[$contactDistance>>2]);
 HEAPF32[$contactDist>>2] = $5;
 $6 = Math_fround(HEAPF32[$transform0>>2]);
 $7 = (($transform0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transform0) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transform0) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($13) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($13) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$capsuleTransform>>2] = $6;
 $19 = (($capsuleTransform) + 4|0);
 HEAPF32[$19>>2] = $8;
 $20 = (($capsuleTransform) + 8|0);
 HEAPF32[$20>>2] = $10;
 $21 = (($capsuleTransform) + 12|0);
 HEAPF32[$21>>2] = $12;
 $22 = (($capsuleTransform) + 16|0);
 HEAPF32[$22>>2] = $14;
 $23 = (($capsuleTransform) + 20|0);
 HEAPF32[$23>>2] = $16;
 $24 = (($capsuleTransform) + 24|0);
 HEAPF32[$24>>2] = $18;
 $25 = (($capsuleTransform) + 28|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = Math_fround(HEAPF32[$transform1>>2]);
 $27 = (($transform1) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($transform1) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($transform1) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($transform1) + 16|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($33) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($33) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 HEAPF32[$meshTransform>>2] = $26;
 $39 = (($meshTransform) + 4|0);
 HEAPF32[$39>>2] = $28;
 $40 = (($meshTransform) + 8|0);
 HEAPF32[$40>>2] = $30;
 $41 = (($meshTransform) + 12|0);
 HEAPF32[$41>>2] = $32;
 $42 = (($meshTransform) + 16|0);
 HEAPF32[$42>>2] = $34;
 $43 = (($meshTransform) + 20|0);
 HEAPF32[$43>>2] = $36;
 $44 = (($meshTransform) + 24|0);
 HEAPF32[$44>>2] = $38;
 $45 = (($meshTransform) + 28|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = Math_fround(-$26);
 $47 = Math_fround(-$28);
 $48 = Math_fround(-$30);
 $49 = Math_fround($14 - $34);
 $50 = Math_fround($16 - $36);
 $51 = Math_fround($18 - $38);
 $52 = Math_fround($32 * $32);
 $53 = Math_fround($52 + Math_fround(-0.5));
 $54 = Math_fround($53 * $49);
 $55 = Math_fround($53 * $50);
 $56 = Math_fround($53 * $51);
 $57 = Math_fround($51 * $47);
 $58 = Math_fround($50 * $48);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($49 * $48);
 $61 = Math_fround($51 * $46);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($50 * $46);
 $64 = Math_fround($49 * $47);
 $65 = Math_fround($63 - $64);
 $66 = Math_fround($32 * $59);
 $67 = Math_fround($32 * $62);
 $68 = Math_fround($32 * $65);
 $69 = Math_fround($54 + $66);
 $70 = Math_fround($55 + $67);
 $71 = Math_fround($56 + $68);
 $72 = Math_fround($49 * $46);
 $73 = Math_fround($50 * $47);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($51 * $48);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($76 * $46);
 $78 = Math_fround($76 * $47);
 $79 = Math_fround($76 * $48);
 $80 = Math_fround($77 + $69);
 $81 = Math_fround($78 + $70);
 $82 = Math_fround($71 + $79);
 $83 = Math_fround($80 * Math_fround(2.0));
 $84 = Math_fround($81 * Math_fround(2.0));
 $85 = Math_fround($82 * Math_fround(2.0));
 $86 = Math_fround($32 * $12);
 $87 = Math_fround($6 * $46);
 $88 = Math_fround($8 * $47);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($10 * $48);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($86 - $91);
 $93 = Math_fround($12 * $46);
 $94 = Math_fround($12 * $47);
 $95 = Math_fround($12 * $48);
 $96 = Math_fround($32 * $6);
 $97 = Math_fround($32 * $8);
 $98 = Math_fround($32 * $10);
 $99 = Math_fround($10 * $47);
 $100 = Math_fround($8 * $48);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($6 * $48);
 $103 = Math_fround($10 * $46);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($8 * $46);
 $106 = Math_fround($6 * $47);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($96 + $93);
 $109 = Math_fround($97 + $94);
 $110 = Math_fround($98 + $95);
 $111 = Math_fround($101 + $108);
 $112 = Math_fround($104 + $109);
 $113 = Math_fround($107 + $110);
 $114 = (($aToB) + 48|0);
 HEAPF32[$114>>2] = $83;
 $115 = (($aToB) + 52|0);
 HEAPF32[$115>>2] = $84;
 $116 = (($aToB) + 56|0);
 HEAPF32[$116>>2] = $85;
 $117 = (($aToB) + 60|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 $118 = Math_fround($111 + $111);
 $119 = Math_fround($112 + $112);
 $120 = Math_fround($113 + $113);
 $121 = Math_fround($111 * $118);
 $122 = Math_fround($112 * $119);
 $123 = Math_fround($113 * $120);
 $124 = Math_fround($112 * $118);
 $125 = Math_fround($113 * $118);
 $126 = Math_fround($92 * $118);
 $127 = Math_fround($113 * $119);
 $128 = Math_fround($92 * $119);
 $129 = Math_fround($92 * $120);
 $130 = Math_fround(Math_fround(1.0) - $121);
 $131 = Math_fround(Math_fround(1.0) - $122);
 $132 = Math_fround($131 - $123);
 $133 = Math_fround($124 + $129);
 $134 = Math_fround($125 - $128);
 $135 = Math_fround($124 - $129);
 $136 = Math_fround($130 - $123);
 $137 = Math_fround($127 + $126);
 $138 = Math_fround($125 + $128);
 $139 = Math_fround($127 - $126);
 $140 = Math_fround($130 - $122);
 HEAPF32[$aToB>>2] = $132;
 $141 = (($aToB) + 4|0);
 HEAPF32[$141>>2] = $133;
 $142 = (($aToB) + 8|0);
 HEAPF32[$142>>2] = $134;
 $143 = (($aToB) + 12|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = (($aToB) + 16|0);
 HEAPF32[$144>>2] = $135;
 $145 = (($aToB) + 20|0);
 HEAPF32[$145>>2] = $136;
 $146 = (($aToB) + 24|0);
 HEAPF32[$146>>2] = $137;
 $147 = (($aToB) + 28|0);
 HEAPF32[$147>>2] = Math_fround(0.0);
 $148 = (($aToB) + 32|0);
 HEAPF32[$148>>2] = $138;
 $149 = (($aToB) + 36|0);
 HEAPF32[$149>>2] = $139;
 $150 = (($aToB) + 40|0);
 HEAPF32[$150>>2] = $140;
 $151 = (($aToB) + 44|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = Math_fround(HEAPF32[$capsuleRadius>>2]);
 $153 = Math_fround($152 * Math_fround(0.00100000004749745130539));
 HEAPF32[$replaceBreakingThreshold>>2] = $153;
 $154 = Math_fround($152 * Math_fround(0.0500000007450580596924));
 HEAPF32[$projectBreakingThreshold>>2] = $154;
 $155 = (($2) + 53|0);
 $156 = HEAP8[$155>>0]|0;
 $157 = Math_fround(HEAPF32[$contactDist>>2]);
 $158 = Math_fround($152 + $157);
 HEAPF32[$refereshDistance>>2] = $158;
 $159 = (($2) + 52|0);
 $160 = HEAP8[$159>>0]|0;
 $161 = ($160<<24>>24)==(0);
 if (!($161)) {
  $162 = $160&255;
  $166 = $162;$i$04$i = 0;
  while(1) {
   $163 = ((($2) + ($i$04$i)|0) + 48|0);
   $164 = HEAP8[$163>>0]|0;
   $165 = (($166) + -2)|0;
   $167 = ($i$04$i>>>0)<($165>>>0);
   $168 = $167 ? $i$04$i : $165;
   $169 = (($168) + 1)|0;
   $170 = ((($2) + ($169)|0) + 48|0);
   $171 = HEAP8[$170>>0]|0;
   $172 = $171&255;
   $173 = ((($2) + (($172*400)|0)|0) + 64|0);
   $174 = HEAP8[$170>>0]|0;
   $175 = $174&255;
   $176 = ((($2) + (($175*400)|0)|0) + 192|0);
   $177 = HEAP8[$170>>0]|0;
   $178 = $177&255;
   $179 = ((($2) + (($178*400)|0)|0) + 320|0);
   $180 = $164&255;
   $181 = ((($2) + (($180*400)|0)|0) + 64|0);
   __ZN5physx2Gu31SinglePersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($_maxPen$i,$181,$aToB,$projectBreakingThreshold,$refereshDistance);
   $182 = ((($2) + (($180*400)|0)|0) + 448|0);
   $183 = HEAP32[$182>>2]|0;
   $184 = ($183|0)==(0);
   if ($184) {
    $185 = HEAP8[$159>>0]|0;
    $186 = (($185) + -1)<<24>>24;
    HEAP8[$159>>0] = $186;
    $187 = $186&255;
    $188 = ((($2) + ($187)|0) + 48|0);
    $189 = HEAP8[$188>>0]|0;
    HEAP8[$188>>0] = $164;
    HEAP8[$163>>0] = $189;
    $190 = (($i$04$i) + -1)|0;
    $i$1$i = $190;
   } else {
    $191 = Math_fround(HEAPF32[$_maxPen$i>>2]);
    $192 = ((($2) + ($180<<2)|0) + 32|0);
    HEAPF32[$192>>2] = $191;
    $i$1$i = $i$04$i;
   }
   $193 = (($i$1$i) + 1)|0;
   $194 = HEAP8[$159>>0]|0;
   $195 = $194&255;
   $196 = ($193>>>0)<($195>>>0);
   if ($196) {
    $166 = $195;$i$04$i = $193;
   } else {
    break;
   }
  }
 }
 $197 = HEAP8[$155>>0]|0;
 $198 = ($197<<24>>24)==($156<<24>>24);
 if ($198) {
  $199 = Math_fround(HEAPF32[$capsuleRadius>>2]);
  $200 = Math_fround($199 * Math_fround(0.0199999995529651641846));
  $201 = (($2) + 16|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($2) + 20|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = (($2) + 24|0);
  $206 = Math_fround(HEAPF32[$205>>2]);
  $207 = Math_fround($83 - $202);
  $208 = Math_fround($84 - $204);
  $209 = Math_fround($85 - $206);
  $210 = Math_fround(-$207);
  $211 = Math_fround(-$208);
  $212 = Math_fround(-$209);
  $213 = $207 > $210;
  $$$i$i$i$i = $213 ? $207 : $210;
  $214 = $208 > $211;
  $215 = $214 ? $208 : $211;
  $216 = $209 > $212;
  $$1$i$i$i$i = $216 ? $209 : $212;
  $217 = !($$$i$i$i$i >= $215);
  $$$i$i$i = $217 ? $215 : $$$i$i$i$i;
  $218 = !($$1$i$i$i$i >= Math_fround(0.0));
  $219 = $218 ? Math_fround(0.0) : $$$i$i$i$i;
  $220 = $$$i$i$i >= $219;
  $221 = $220 ? $$$i$i$i : $219;
  $222 = $221 > $200;
  if (!($222)) {
   $223 = (($2) + 4|0);
   $224 = (($2) + 8|0);
   $225 = Math_fround(HEAPF32[$223>>2]);
   $226 = Math_fround(HEAPF32[$2>>2]);
   $227 = Math_fround($112 * $225);
   $228 = Math_fround($111 * $226);
   $229 = (($2) + 12|0);
   $230 = Math_fround(HEAPF32[$224>>2]);
   $231 = Math_fround($113 * $230);
   $232 = Math_fround($227 + $228);
   $233 = Math_fround(HEAPF32[$229>>2]);
   $234 = Math_fround($92 * $233);
   $235 = Math_fround($232 + $231);
   $236 = Math_fround($235 + $234);
   $237 = $236 < Math_fround(0.999800026416778564453);
   if (!($237)) {
    $537 = (__ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVES8_RKNS5_6FloatVE($2,$contactBuffer,$capsuleTransform,$meshTransform,$capsuleRadius)|0);
    STACKTOP = sp;return ($537|0);
   }
  }
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $238 = (($meshScaling) + 4|0);
 HEAPF32[$238>>2] = Math_fround(0.0);
 $239 = (($meshScaling) + 8|0);
 HEAPF32[$239>>2] = Math_fround(0.0);
 $240 = (($meshScaling) + 12|0);
 HEAPF32[$240>>2] = Math_fround(0.0);
 $241 = (($meshScaling) + 16|0);
 HEAPF32[$241>>2] = Math_fround(1.0);
 $242 = (($meshScaling) + 20|0);
 HEAPF32[$242>>2] = Math_fround(0.0);
 $243 = (($meshScaling) + 24|0);
 HEAPF32[$243>>2] = Math_fround(0.0);
 $244 = (($meshScaling) + 28|0);
 HEAPF32[$244>>2] = Math_fround(0.0);
 $245 = (($meshScaling) + 32|0);
 HEAPF32[$245>>2] = Math_fround(1.0);
 $246 = (($meshScaling) + 36|0);
 HEAPF32[$246>>2] = Math_fround(1.0);
 $247 = (($meshScaling) + 40|0);
 HEAPF32[$247>>2] = Math_fround(0.0);
 $248 = (($meshScaling) + 44|0);
 HEAPF32[$248>>2] = Math_fround(0.0);
 $249 = (($meshScaling) + 48|0);
 HEAPF32[$249>>2] = Math_fround(0.0);
 $250 = (($meshScaling) + 52|0);
 HEAPF32[$250>>2] = Math_fround(1.0);
 $251 = (($meshScaling) + 56|0);
 HEAPF32[$251>>2] = Math_fround(0.0);
 $252 = (($meshScaling) + 60|0);
 HEAPF32[$252>>2] = Math_fround(0.0);
 $253 = (($meshScaling) + 64|0);
 HEAPF32[$253>>2] = Math_fround(0.0);
 $254 = (($meshScaling) + 68|0);
 HEAPF32[$254>>2] = Math_fround(1.0);
 $255 = (($shape1) + 4|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 $257 = $256 == Math_fround(1.0);
 if ($257) {
  $258 = (($shape1) + 8|0);
  $259 = Math_fround(HEAPF32[$258>>2]);
  $260 = $259 == Math_fround(1.0);
  if ($260) {
   $261 = (($shape1) + 12|0);
   $262 = Math_fround(HEAPF32[$261>>2]);
   $263 = $262 == Math_fround(1.0);
   if ($263) {
    $500 = 1;
   } else {
    label = 13;
   }
  } else {
   label = 13;
  }
 } else {
  label = 13;
 }
 if ((label|0) == 13) {
  $264 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$255,$264);
  $500 = 0;
 }
 $265 = Math_fround(HEAPF32[$transform0>>2]);
 $266 = Math_fround($265 * Math_fround(2.0));
 $267 = (($transform0) + 12|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = Math_fround($268 * Math_fround(2.0));
 $270 = Math_fround($268 * $269);
 $271 = Math_fround($270 + Math_fround(-1.0));
 $272 = Math_fround($265 * $266);
 $273 = Math_fround($272 + $271);
 $274 = (($transform0) + 8|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = Math_fround($275 * $269);
 $277 = (($transform0) + 4|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = Math_fround($266 * $278);
 $280 = Math_fround($276 + $279);
 $281 = Math_fround($269 * $278);
 $282 = Math_fround($266 * $275);
 $283 = Math_fround($282 - $281);
 $284 = (($shape0) + 8|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 $286 = Math_fround($285 * $273);
 $287 = Math_fround($285 * $280);
 $288 = Math_fround($285 * $283);
 $289 = Math_fround(HEAPF32[$13>>2]);
 $290 = Math_fround($289 + $286);
 $291 = (($transform0) + 20|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = Math_fround($292 + $287);
 $294 = (($transform0) + 24|0);
 $295 = Math_fround(HEAPF32[$294>>2]);
 $296 = Math_fround($288 + $295);
 $297 = Math_fround($289 - $286);
 $298 = Math_fround($292 - $287);
 $299 = Math_fround($295 - $288);
 $300 = Math_fround(HEAPF32[$33>>2]);
 $301 = Math_fround($290 - $300);
 $302 = (($transform1) + 20|0);
 $303 = Math_fround(HEAPF32[$302>>2]);
 $304 = Math_fround($293 - $303);
 $305 = (($transform1) + 24|0);
 $306 = Math_fround(HEAPF32[$305>>2]);
 $307 = Math_fround($296 - $306);
 $308 = Math_fround($301 * Math_fround(2.0));
 $309 = Math_fround($304 * Math_fround(2.0));
 $310 = Math_fround($307 * Math_fround(2.0));
 $311 = (($transform1) + 12|0);
 $312 = Math_fround(HEAPF32[$311>>2]);
 $313 = Math_fround($312 * $312);
 $314 = Math_fround($313 + Math_fround(-0.5));
 $315 = Math_fround(HEAPF32[$transform1>>2]);
 $316 = Math_fround($308 * $315);
 $317 = (($transform1) + 4|0);
 $318 = Math_fround(HEAPF32[$317>>2]);
 $319 = Math_fround($309 * $318);
 $320 = Math_fround($316 + $319);
 $321 = (($transform1) + 8|0);
 $322 = Math_fround(HEAPF32[$321>>2]);
 $323 = Math_fround($310 * $322);
 $324 = Math_fround($320 + $323);
 $325 = Math_fround($308 * $314);
 $326 = Math_fround($310 * $318);
 $327 = Math_fround($309 * $322);
 $328 = Math_fround($326 - $327);
 $329 = Math_fround($312 * $328);
 $330 = Math_fround($325 - $329);
 $331 = Math_fround($315 * $324);
 $332 = Math_fround($331 + $330);
 $333 = Math_fround($309 * $314);
 $334 = Math_fround($308 * $322);
 $335 = Math_fround($310 * $315);
 $336 = Math_fround($334 - $335);
 $337 = Math_fround($312 * $336);
 $338 = Math_fround($333 - $337);
 $339 = Math_fround($318 * $324);
 $340 = Math_fround($339 + $338);
 $341 = Math_fround($310 * $314);
 $342 = Math_fround($309 * $315);
 $343 = Math_fround($308 * $318);
 $344 = Math_fround($342 - $343);
 $345 = Math_fround($312 * $344);
 $346 = Math_fround($341 - $345);
 $347 = Math_fround($322 * $324);
 $348 = Math_fround($346 + $347);
 $349 = Math_fround($297 - $300);
 $350 = Math_fround($298 - $303);
 $351 = Math_fround($299 - $306);
 $352 = Math_fround($349 * Math_fround(2.0));
 $353 = Math_fround($350 * Math_fround(2.0));
 $354 = Math_fround($351 * Math_fround(2.0));
 $355 = Math_fround($352 * $315);
 $356 = Math_fround($353 * $318);
 $357 = Math_fround($355 + $356);
 $358 = Math_fround($354 * $322);
 $359 = Math_fround($357 + $358);
 $360 = Math_fround($352 * $314);
 $361 = Math_fround($354 * $318);
 $362 = Math_fround($353 * $322);
 $363 = Math_fround($361 - $362);
 $364 = Math_fround($312 * $363);
 $365 = Math_fround($360 - $364);
 $366 = Math_fround($315 * $359);
 $367 = Math_fround($366 + $365);
 $368 = Math_fround($353 * $314);
 $369 = Math_fround($352 * $322);
 $370 = Math_fround($354 * $315);
 $371 = Math_fround($369 - $370);
 $372 = Math_fround($312 * $371);
 $373 = Math_fround($368 - $372);
 $374 = Math_fround($318 * $359);
 $375 = Math_fround($374 + $373);
 $376 = Math_fround($354 * $314);
 $377 = Math_fround($353 * $315);
 $378 = Math_fround($352 * $318);
 $379 = Math_fround($377 - $378);
 $380 = Math_fround($312 * $379);
 $381 = Math_fround($376 - $380);
 $382 = Math_fround($322 * $359);
 $383 = Math_fround($381 + $382);
 $384 = Math_fround(HEAPF32[$3>>2]);
 $385 = Math_fround(HEAPF32[$contactDistance>>2]);
 $386 = Math_fround($384 + $385);
 $387 = Math_fround($289 - $300);
 $388 = Math_fround($292 - $303);
 $389 = Math_fround($295 - $306);
 $390 = Math_fround($387 * Math_fround(2.0));
 $391 = Math_fround($388 * Math_fround(2.0));
 $392 = Math_fround($389 * Math_fround(2.0));
 $393 = Math_fround($390 * $315);
 $394 = Math_fround($391 * $318);
 $395 = Math_fround($393 + $394);
 $396 = Math_fround($392 * $322);
 $397 = Math_fround($395 + $396);
 $398 = Math_fround($390 * $314);
 $399 = Math_fround($392 * $318);
 $400 = Math_fround($391 * $322);
 $401 = Math_fround($399 - $400);
 $402 = Math_fround($312 * $401);
 $403 = Math_fround($398 - $402);
 $404 = Math_fround($315 * $397);
 $405 = Math_fround($404 + $403);
 $406 = Math_fround($391 * $314);
 $407 = Math_fround($390 * $322);
 $408 = Math_fround($392 * $315);
 $409 = Math_fround($407 - $408);
 $410 = Math_fround($312 * $409);
 $411 = Math_fround($406 - $410);
 $412 = Math_fround($318 * $397);
 $413 = Math_fround($412 + $411);
 $414 = Math_fround($392 * $314);
 $415 = Math_fround($391 * $315);
 $416 = Math_fround($390 * $318);
 $417 = Math_fround($415 - $416);
 $418 = Math_fround($312 * $417);
 $419 = Math_fround($414 - $418);
 $420 = Math_fround($322 * $397);
 $421 = Math_fround($419 + $420);
 $422 = Math_fround($286 * Math_fround(2.0));
 $423 = Math_fround($287 * Math_fround(2.0));
 $424 = Math_fround($288 * Math_fround(2.0));
 $425 = Math_fround($422 * $315);
 $426 = Math_fround($423 * $318);
 $427 = Math_fround($425 + $426);
 $428 = Math_fround($424 * $322);
 $429 = Math_fround($427 + $428);
 $430 = Math_fround($422 * $314);
 $431 = Math_fround($424 * $318);
 $432 = Math_fround($423 * $322);
 $433 = Math_fround($431 - $432);
 $434 = Math_fround($312 * $433);
 $435 = Math_fround($430 - $434);
 $436 = Math_fround($315 * $429);
 $437 = Math_fround($436 + $435);
 $438 = Math_fround($423 * $314);
 $439 = Math_fround($422 * $322);
 $440 = Math_fround($424 * $315);
 $441 = Math_fround($439 - $440);
 $442 = Math_fround($312 * $441);
 $443 = Math_fround($438 - $442);
 $444 = Math_fround($318 * $429);
 $445 = Math_fround($444 + $443);
 $446 = Math_fround($424 * $314);
 $447 = Math_fround($423 * $315);
 $448 = Math_fround($422 * $318);
 $449 = Math_fround($447 - $448);
 $450 = Math_fround($312 * $449);
 $451 = Math_fround($446 - $450);
 $452 = Math_fround($322 * $429);
 $453 = Math_fround($451 + $452);
 $454 = (($capsule) + 64|0);
 HEAPF32[$capsule>>2] = $405;
 $455 = (($capsule) + 4|0);
 HEAPF32[$455>>2] = $413;
 $456 = (($capsule) + 8|0);
 HEAPF32[$456>>2] = $421;
 $457 = (($capsule) + 12|0);
 HEAPF32[$457>>2] = Math_fround(0.0);
 $458 = (($capsule) + 80|0);
 HEAP32[$458>>2] = 4;
 $459 = (($capsule) + 48|0);
 HEAPF32[$459>>2] = Math_fround(0.0);
 $460 = (($capsule) + 52|0);
 ;HEAP32[$460+0>>2]=HEAP32[$$sroa$19$i$i$i$i+0>>2]|0;HEAP32[$460+4>>2]=HEAP32[$$sroa$19$i$i$i$i+4>>2]|0;HEAP32[$460+8>>2]=HEAP32[$$sroa$19$i$i$i$i+8>>2]|0;
 $461 = (($capsule) + 128|0);
 ;HEAP32[$461+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$461+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$461+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$461+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 $462 = Math_fround($405 + $437);
 $463 = Math_fround($413 + $445);
 $464 = Math_fround($421 + $453);
 $465 = (($capsule) + 96|0);
 HEAPF32[$465>>2] = $462;
 $466 = (($capsule) + 100|0);
 HEAPF32[$466>>2] = $463;
 $467 = (($capsule) + 104|0);
 HEAPF32[$467>>2] = $464;
 $468 = (($capsule) + 108|0);
 HEAPF32[$468>>2] = Math_fround(0.0);
 $469 = Math_fround($405 - $437);
 $470 = Math_fround($413 - $445);
 $471 = Math_fround($421 - $453);
 $472 = (($capsule) + 112|0);
 HEAPF32[$472>>2] = $469;
 $473 = (($capsule) + 116|0);
 HEAPF32[$473>>2] = $470;
 $474 = (($capsule) + 120|0);
 HEAPF32[$474>>2] = $471;
 $475 = (($capsule) + 124|0);
 HEAPF32[$475>>2] = Math_fround(0.0);
 $476 = (($capsule) + 16|0);
 ;HEAP32[$476+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$476+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$476+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$476+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 $477 = (($capsule) + 32|0);
 ;HEAP32[$477+0>>2]=HEAP32[$capsuleRadius+0>>2]|0;HEAP32[$477+4>>2]=HEAP32[$capsuleRadius+4>>2]|0;HEAP32[$477+8>>2]=HEAP32[$capsuleRadius+8>>2]|0;HEAP32[$477+12>>2]=HEAP32[$capsuleRadius+12>>2]|0;
 ;HEAP32[$_maxPen$i+0>>2]=4294967295|0;HEAP32[$_maxPen$i+4>>2]=4294967295|0;HEAP32[$_maxPen$i+8>>2]=4294967295|0;HEAP32[$_maxPen$i+12>>2]=4294967295|0;
 ;HEAP32[$454+0>>2]=HEAP32[$_maxPen$i+0>>2]|0;HEAP32[$454+4>>2]=HEAP32[$_maxPen$i+4>>2]|0;HEAP32[$454+8>>2]=HEAP32[$_maxPen$i+8>>2]|0;HEAP32[$454+12>>2]=HEAP32[$_maxPen$i+12>>2]|0;
 HEAPF32[$queryCapsule>>2] = $332;
 $478 = (($queryCapsule) + 4|0);
 HEAPF32[$478>>2] = $340;
 $479 = (($queryCapsule) + 8|0);
 HEAPF32[$479>>2] = $348;
 $480 = (($queryCapsule) + 12|0);
 HEAPF32[$480>>2] = $367;
 $481 = (($queryCapsule) + 16|0);
 HEAPF32[$481>>2] = $375;
 $482 = (($queryCapsule) + 20|0);
 HEAPF32[$482>>2] = $383;
 $483 = (($queryCapsule) + 24|0);
 HEAPF32[$483>>2] = $386;
 $484 = (($shape1) + 40|0);
 $485 = HEAP32[$484>>2]|0;
 HEAP8[$159>>0] = 0;
 HEAPF32[$2>>2] = $111;
 $486 = (($2) + 4|0);
 HEAPF32[$486>>2] = $112;
 $487 = (($2) + 8|0);
 HEAPF32[$487>>2] = $113;
 $488 = (($2) + 12|0);
 HEAPF32[$488>>2] = $92;
 $489 = (($2) + 16|0);
 HEAPF32[$489>>2] = $83;
 $490 = (($2) + 20|0);
 HEAPF32[$490>>2] = $84;
 $491 = (($2) + 24|0);
 HEAPF32[$491>>2] = $85;
 $492 = (($2) + 28|0);
 HEAPF32[$492>>2] = Math_fround(0.0);
 $493 = (($485) + 152|0);
 $494 = HEAP32[$493>>2]|0;
 $495 = (($callback) + 4|0);
 HEAP32[$495>>2] = 2;
 $496 = (($callback) + 8|0);
 HEAP32[$496>>2] = $meshScaling;
 $497 = (($callback) + 12|0);
 HEAP32[$497>>2] = $494;
 $498 = (($callback) + 16|0);
 $499 = $500&1;
 HEAP8[$498>>0] = $499;
 $501 = (($callback) + 868|0);
 HEAP32[$501>>2] = 0;
 HEAP32[$callback>>2] = ((554032 + 8|0));
 $502 = (($callback) + 880|0);
 __ZN5physx2Gu24PCMMeshContactGenerationC2ERKNS_6shdfnd3aos6FloatVES6_RKNS3_12PsTransformVES9_RNS0_33MultiplePersistentContactManifoldERNS0_13ContactBufferE($502,$contactDist,$replaceBreakingThreshold,$capsuleTransform,$meshTransform,$2,$contactBuffer);
 $503 = (($callback) + 3248|0);
 HEAP32[$503>>2] = $capsule;
 $504 = (($capsule) + 128|0);
 $505 = Math_fround(HEAPF32[$504>>2]);
 $506 = Math_fround(HEAPF32[$contactDist>>2]);
 $507 = Math_fround($505 + $506);
 $508 = (($callback) + 3216|0);
 HEAPF32[$508>>2] = $507;
 $509 = (($callback) + 3220|0);
 ;HEAP32[$509+0>>2]=HEAP32[$$sroa$19$i$i$i$i+0>>2]|0;HEAP32[$509+4>>2]=HEAP32[$$sroa$19$i$i$i$i+4>>2]|0;HEAP32[$509+8>>2]=HEAP32[$$sroa$19$i$i$i$i+8>>2]|0;
 $510 = Math_fround($507 * $507);
 $511 = (($callback) + 3232|0);
 HEAPF32[$511>>2] = $510;
 $512 = (($callback) + 3236|0);
 ;HEAP32[$512+0>>2]=HEAP32[$_maxPen$i+0>>2]|0;HEAP32[$512+4>>2]=HEAP32[$_maxPen$i+4>>2]|0;HEAP32[$512+8>>2]=HEAP32[$_maxPen$i+8>>2]|0;
 __ZN5physx2Gu3Box6createERKNS0_7CapsuleE($_maxPen$i,$queryCapsule);
 if (!($500)) {
  $513 = (($_maxPen$i) + 36|0);
  $514 = (($_maxPen$i) + 48|0);
  __ZNK5physx2Cm23FastVertex2ShapeScaling20transformQueryBoundsERNS_6PxVec3ES3_RNS_7PxMat33E($meshScaling,$513,$514,$_maxPen$i);
 }
 $515 = (($485) + 16|0);
 $516 = HEAP32[$515>>2]|0;
 HEAP32[$hmd>>2] = $516;
 $517 = (($485) + 32|0);
 $518 = (($hmd) + 4|0);
 HEAP32[$518>>2] = $517;
 $519 = (($485) + 20|0);
 $520 = Math_fround(HEAPF32[$519>>2]);
 $521 = (($hmd) + 8|0);
 HEAPF32[$521>>2] = $520;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($_maxPen$i,1,$hmd,$callback,1);
 $522 = HEAP32[$501>>2]|0;
 $523 = ($522|0)==(0);
 if (!($523)) {
  $524 = (($callback) + 880|0);
  $525 = (($callback) + 852|0);
  $526 = (($callback) + 788|0);
  $527 = (($callback) + 596|0);
  $528 = (($callback) + 20|0);
  $count$01$i$i$i = $522;$edgeFlags$05$i$i$i = $525;$triInds$04$i$i$i = $526;$vertInds$03$i$i$i = $527;$verts$02$i$i$i = $528;
  while(1) {
   $529 = (($count$01$i$i$i) + -1)|0;
   $530 = HEAP32[$triInds$04$i$i$i>>2]|0;
   $531 = HEAP8[$edgeFlags$05$i$i$i>>0]|0;
   (__ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($524,$verts$02$i$i$i,$530,$531,$vertInds$03$i$i$i)|0);
   $532 = (($verts$02$i$i$i) + 36|0);
   $533 = (($vertInds$03$i$i$i) + 12|0);
   $534 = (($triInds$04$i$i$i) + 4|0);
   $535 = (($edgeFlags$05$i$i$i) + 1|0);
   $536 = ($529|0)==(0);
   if ($536) {
    break;
   } else {
    $count$01$i$i$i = $529;$edgeFlags$05$i$i$i = $535;$triInds$04$i$i$i = $534;$vertInds$03$i$i$i = $533;$verts$02$i$i$i = $532;
   }
  }
  HEAP32[$501>>2] = 0;
 }
 __ZN5physx2Gu24PCMMeshContactGeneration15processContactsEhb($502,3,0);
 $537 = (__ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVES8_RKNS5_6FloatVE($2,$contactBuffer,$capsuleTransform,$meshTransform,$capsuleRadius)|0);
 STACKTOP = sp;return ($537|0);
}
function __ZN5physx41PCMCapsuleVsMeshContactGenerationCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32PCMMeshContactGenerationCallbackINS_41PCMCapsuleVsMeshContactGenerationCallbackEE10processHitERKNS_12PxRaycastHitERKNS_6PxVec3ES9_S9_RfPKj($this,$hit,$v0,$v1,$v2,$0,$vinds) {
 $this = $this|0;
 $hit = $hit|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 $0 = $0|0;
 $vinds = $vinds|0;
 var $$phi$trans$insert11 = 0, $$phi$trans$insert13 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert17 = 0, $$phi$trans$insert19 = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert7 = 0, $$phi$trans$insert9 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre12 = Math_fround(0), $$pre14 = Math_fround(0), $$pre16 = Math_fround(0), $$pre18 = Math_fround(0), $$pre20 = Math_fround(0), $$pre22 = Math_fround(0), $$pre8 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0);
 var $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0);
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0);
 var $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0;
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $count$01$i$i = 0, $edgeFlags$05$i$i = 0, $triInds$04$i$i = 0, $v = 0, $vertInds$03$i$i = 0, $verts$02$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $v = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $27 = (($this) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = Math_fround(HEAPF32[$v0>>2]);
  $30 = Math_fround(HEAPF32[$28>>2]);
  $31 = Math_fround($29 * $30);
  $32 = (($28) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($29 * $33);
  $35 = (($28) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($29 * $36);
  $38 = (($v0) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($28) + 12|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($39 * $41);
  $43 = (($28) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($39 * $44);
  $46 = (($28) + 20|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($39 * $47);
  $49 = Math_fround($31 + $42);
  $50 = Math_fround($34 + $45);
  $51 = Math_fround($37 + $48);
  $52 = (($v0) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($28) + 24|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($53 * $55);
  $57 = (($28) + 28|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($53 * $58);
  $60 = (($28) + 32|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($53 * $61);
  $63 = Math_fround($49 + $56);
  $64 = Math_fround($50 + $59);
  $65 = Math_fround($51 + $62);
  HEAPF32[$v>>2] = $63;
  $66 = (($v) + 4|0);
  HEAPF32[$66>>2] = $64;
  $67 = (($v) + 8|0);
  HEAPF32[$67>>2] = $65;
  $68 = Math_fround(HEAPF32[$v1>>2]);
  $69 = Math_fround(HEAPF32[$28>>2]);
  $70 = Math_fround($68 * $69);
  $71 = Math_fround(HEAPF32[$32>>2]);
  $72 = Math_fround($68 * $71);
  $73 = Math_fround(HEAPF32[$35>>2]);
  $74 = Math_fround($68 * $73);
  $75 = (($v1) + 4|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround(HEAPF32[$40>>2]);
  $78 = Math_fround($76 * $77);
  $79 = Math_fround(HEAPF32[$43>>2]);
  $80 = Math_fround($76 * $79);
  $81 = Math_fround(HEAPF32[$46>>2]);
  $82 = Math_fround($76 * $81);
  $83 = Math_fround($70 + $78);
  $84 = Math_fround($72 + $80);
  $85 = Math_fround($74 + $82);
  $86 = (($v1) + 8|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = Math_fround(HEAPF32[$54>>2]);
  $89 = Math_fround($87 * $88);
  $90 = Math_fround(HEAPF32[$57>>2]);
  $91 = Math_fround($87 * $90);
  $92 = Math_fround(HEAPF32[$60>>2]);
  $93 = Math_fround($87 * $92);
  $94 = Math_fround($83 + $89);
  $95 = Math_fround($84 + $91);
  $96 = Math_fround($85 + $93);
  $97 = (($v) + 12|0);
  HEAPF32[$97>>2] = $94;
  $98 = (($v) + 16|0);
  HEAPF32[$98>>2] = $95;
  $99 = (($v) + 20|0);
  HEAPF32[$99>>2] = $96;
  $100 = Math_fround(HEAPF32[$v2>>2]);
  $101 = Math_fround(HEAPF32[$28>>2]);
  $102 = Math_fround($100 * $101);
  $103 = Math_fround(HEAPF32[$32>>2]);
  $104 = Math_fround($100 * $103);
  $105 = Math_fround(HEAPF32[$35>>2]);
  $106 = Math_fround($100 * $105);
  $107 = (($v2) + 4|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround(HEAPF32[$40>>2]);
  $110 = Math_fround($108 * $109);
  $111 = Math_fround(HEAPF32[$43>>2]);
  $112 = Math_fround($108 * $111);
  $113 = Math_fround(HEAPF32[$46>>2]);
  $114 = Math_fround($108 * $113);
  $115 = Math_fround($102 + $110);
  $116 = Math_fround($104 + $112);
  $117 = Math_fround($106 + $114);
  $118 = (($v2) + 8|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround(HEAPF32[$54>>2]);
  $121 = Math_fround($119 * $120);
  $122 = Math_fround(HEAPF32[$57>>2]);
  $123 = Math_fround($119 * $122);
  $124 = Math_fround(HEAPF32[$60>>2]);
  $125 = Math_fround($119 * $124);
  $126 = Math_fround($115 + $121);
  $127 = Math_fround($116 + $123);
  $128 = Math_fround($117 + $125);
  $129 = (($v) + 24|0);
  HEAPF32[$129>>2] = $126;
  $130 = (($v) + 28|0);
  HEAPF32[$130>>2] = $127;
  $131 = (($v) + 32|0);
  HEAPF32[$131>>2] = $128;
  $189 = $128;$190 = $127;$191 = $126;$192 = $96;$193 = $95;$194 = $94;$195 = $65;$196 = $64;$197 = $63;
 } else {
  $4 = Math_fround(HEAPF32[$v0>>2]);
  HEAPF32[$v>>2] = $4;
  $5 = (($v0) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($v) + 4|0);
  HEAPF32[$7>>2] = $6;
  $8 = (($v0) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($v) + 8|0);
  HEAPF32[$10>>2] = $9;
  $11 = Math_fround(HEAPF32[$v1>>2]);
  $12 = (($v) + 12|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($v1) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($v) + 16|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($v1) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($v) + 20|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround(HEAPF32[$v2>>2]);
  $20 = (($v) + 24|0);
  HEAPF32[$20>>2] = $19;
  $21 = (($v2) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($v) + 28|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($v2) + 8|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($v) + 32|0);
  HEAPF32[$26>>2] = $25;
  $189 = $25;$190 = $22;$191 = $19;$192 = $17;$193 = $14;$194 = $11;$195 = $9;$196 = $6;$197 = $4;
 }
 $132 = (($hit) + 8|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (($this) + 12|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = ($135|0)==(0|0);
 if ($136) {
  $188 = 56;
 } else {
  $137 = (($135) + ($133)|0);
  $138 = HEAP8[$137>>0]|0;
  $188 = $138;
 }
 $139 = (($this) + 868|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = ($140|0)==(16);
 if (!($141)) {
  $156 = $140;$159 = $197;$161 = $196;$163 = $195;$166 = $194;$168 = $193;$170 = $192;$173 = $191;$175 = $190;$177 = $189;
  $155 = (($156) + 1)|0;
  HEAP32[$139>>2] = $155;
  $157 = ($156*3)|0;
  $158 = ((($this) + (($157*12)|0)|0) + 20|0);
  HEAPF32[$158>>2] = $159;
  $160 = ((($this) + (($157*12)|0)|0) + 24|0);
  HEAPF32[$160>>2] = $161;
  $162 = ((($this) + (($157*12)|0)|0) + 28|0);
  HEAPF32[$162>>2] = $163;
  $164 = (($157) + 1)|0;
  $165 = ((($this) + (($164*12)|0)|0) + 20|0);
  HEAPF32[$165>>2] = $166;
  $167 = ((($this) + (($164*12)|0)|0) + 24|0);
  HEAPF32[$167>>2] = $168;
  $169 = ((($this) + (($164*12)|0)|0) + 28|0);
  HEAPF32[$169>>2] = $170;
  $171 = (($157) + 2)|0;
  $172 = ((($this) + (($171*12)|0)|0) + 20|0);
  HEAPF32[$172>>2] = $173;
  $174 = ((($this) + (($171*12)|0)|0) + 24|0);
  HEAPF32[$174>>2] = $175;
  $176 = ((($this) + (($171*12)|0)|0) + 28|0);
  HEAPF32[$176>>2] = $177;
  $178 = HEAP32[$vinds>>2]|0;
  $179 = ((($this) + ($157<<2)|0) + 596|0);
  HEAP32[$179>>2] = $178;
  $180 = (($vinds) + 4|0);
  $181 = HEAP32[$180>>2]|0;
  $182 = ((($this) + ($164<<2)|0) + 596|0);
  HEAP32[$182>>2] = $181;
  $183 = (($vinds) + 8|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ((($this) + ($171<<2)|0) + 596|0);
  HEAP32[$185>>2] = $184;
  $186 = ((($this) + ($156<<2)|0) + 788|0);
  HEAP32[$186>>2] = $133;
  $187 = ((($this) + ($156)|0) + 852|0);
  HEAP8[$187>>0] = $188;
  STACKTOP = sp;return 1;
 }
 $142 = (($this) + 880|0);
 $143 = (($this) + 852|0);
 $144 = (($this) + 788|0);
 $145 = (($this) + 596|0);
 $146 = (($this) + 20|0);
 $count$01$i$i = 16;$edgeFlags$05$i$i = $143;$triInds$04$i$i = $144;$vertInds$03$i$i = $145;$verts$02$i$i = $146;
 while(1) {
  $147 = (($count$01$i$i) + -1)|0;
  $148 = HEAP32[$triInds$04$i$i>>2]|0;
  $149 = HEAP8[$edgeFlags$05$i$i>>0]|0;
  (__ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($142,$verts$02$i$i,$148,$149,$vertInds$03$i$i)|0);
  $150 = (($verts$02$i$i) + 36|0);
  $151 = (($vertInds$03$i$i) + 12|0);
  $152 = (($triInds$04$i$i) + 4|0);
  $153 = (($edgeFlags$05$i$i) + 1|0);
  $154 = ($147|0)==(0);
  if ($154) {
   break;
  } else {
   $count$01$i$i = $147;$edgeFlags$05$i$i = $153;$triInds$04$i$i = $152;$vertInds$03$i$i = $151;$verts$02$i$i = $150;
  }
 }
 HEAP32[$139>>2] = 0;
 $$pre = Math_fround(HEAPF32[$v>>2]);
 $$phi$trans$insert7 = (($v) + 4|0);
 $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
 $$phi$trans$insert9 = (($v) + 8|0);
 $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert9>>2]);
 $$phi$trans$insert11 = (($v) + 12|0);
 $$pre12 = Math_fround(HEAPF32[$$phi$trans$insert11>>2]);
 $$phi$trans$insert13 = (($v) + 16|0);
 $$pre14 = Math_fround(HEAPF32[$$phi$trans$insert13>>2]);
 $$phi$trans$insert15 = (($v) + 20|0);
 $$pre16 = Math_fround(HEAPF32[$$phi$trans$insert15>>2]);
 $$phi$trans$insert17 = (($v) + 24|0);
 $$pre18 = Math_fround(HEAPF32[$$phi$trans$insert17>>2]);
 $$phi$trans$insert19 = (($v) + 28|0);
 $$pre20 = Math_fround(HEAPF32[$$phi$trans$insert19>>2]);
 $$phi$trans$insert21 = (($v) + 32|0);
 $$pre22 = Math_fround(HEAPF32[$$phi$trans$insert21>>2]);
 $156 = 0;$159 = $$pre;$161 = $$pre8;$163 = $$pre10;$166 = $$pre12;$168 = $$pre14;$170 = $$pre16;$173 = $$pre18;$175 = $$pre20;$177 = $$pre22;
 $155 = (($156) + 1)|0;
 HEAP32[$139>>2] = $155;
 $157 = ($156*3)|0;
 $158 = ((($this) + (($157*12)|0)|0) + 20|0);
 HEAPF32[$158>>2] = $159;
 $160 = ((($this) + (($157*12)|0)|0) + 24|0);
 HEAPF32[$160>>2] = $161;
 $162 = ((($this) + (($157*12)|0)|0) + 28|0);
 HEAPF32[$162>>2] = $163;
 $164 = (($157) + 1)|0;
 $165 = ((($this) + (($164*12)|0)|0) + 20|0);
 HEAPF32[$165>>2] = $166;
 $167 = ((($this) + (($164*12)|0)|0) + 24|0);
 HEAPF32[$167>>2] = $168;
 $169 = ((($this) + (($164*12)|0)|0) + 28|0);
 HEAPF32[$169>>2] = $170;
 $171 = (($157) + 2)|0;
 $172 = ((($this) + (($171*12)|0)|0) + 20|0);
 HEAPF32[$172>>2] = $173;
 $174 = ((($this) + (($171*12)|0)|0) + 24|0);
 HEAPF32[$174>>2] = $175;
 $176 = ((($this) + (($171*12)|0)|0) + 28|0);
 HEAPF32[$176>>2] = $177;
 $178 = HEAP32[$vinds>>2]|0;
 $179 = ((($this) + ($157<<2)|0) + 596|0);
 HEAP32[$179>>2] = $178;
 $180 = (($vinds) + 4|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ((($this) + ($164<<2)|0) + 596|0);
 HEAP32[$182>>2] = $181;
 $183 = (($vinds) + 8|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = ((($this) + ($171<<2)|0) + 596|0);
 HEAP32[$185>>2] = $184;
 $186 = ((($this) + ($156<<2)|0) + 788|0);
 HEAP32[$186>>2] = $133;
 $187 = ((($this) + ($156)|0) + 852|0);
 HEAP8[$187>>0] = $188;
 STACKTOP = sp;return 1;
}
function __ZN5physx41PCMCapsuleVsMeshContactGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32PCMConvexVsMeshContactGeneration18addContactsToPatchERKNS_6shdfnd3aos5Vec3VEjj($this,$patchNormal,$previousNumContacts,$_numContacts) {
 $this = $this|0;
 $patchNormal = $patchNormal|0;
 $previousNumContacts = $previousNumContacts|0;
 $_numContacts = $_numContacts|0;
 var $$$i = Math_fround(0), $$$i90 = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $$sroa$127 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0;
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$087 = 0, $i1$085 = 0, $j$084 = 0, $j$1 = 0, $maxPen = 0, $patchNormalInTriangle = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $patchNormalInTriangle = sp + 16|0;
 $maxPen = sp;
 $$sroa$127 = sp + 32|0;
 $0 = Math_fround(HEAPF32[$patchNormal>>2]);
 $1 = (($patchNormal) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($patchNormal) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 2256|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($0 * $6);
 $8 = (($this) + 2260|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($2 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($this) + 2264|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($4 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (($this) + 2272|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($0 * $17);
 $19 = (($this) + 2276|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($2 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($this) + 2280|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($4 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($this) + 2288|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($0 * $28);
 $30 = (($this) + 2292|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($2 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($this) + 2296|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($4 * $35);
 $37 = Math_fround($33 + $36);
 HEAPF32[$patchNormalInTriangle>>2] = $15;
 $38 = (($patchNormalInTriangle) + 4|0);
 HEAPF32[$38>>2] = $26;
 $39 = (($patchNormalInTriangle) + 8|0);
 HEAPF32[$39>>2] = $37;
 $40 = (($patchNormalInTriangle) + 12|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = ($_numContacts>>>0)>(4);
 if ($41) {
  $42 = (($this) + 2320|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + ($previousNumContacts<<6)|0);
  $45 = (__ZN5physx2Gu31SinglePersistentContactManifold14reduceContactsEPNS0_21MeshPersistentContactEj($44,$_numContacts)|0);
  $46 = (($45) + ($previousNumContacts))|0;
  $47 = (($this) + 2324|0);
  HEAP32[$47>>2] = $46;
  $50 = $46;
 } else {
  $$phi$trans$insert = (($this) + 2324|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $50 = $$pre;
 }
 HEAPF32[$maxPen>>2] = Math_fround(3.40282346638528859812E+38);
 $48 = (($this) + 2324|0);
 $49 = ($50>>>0)>($previousNumContacts>>>0);
 if ($49) {
  $51 = (($this) + 2320|0);
  $52 = (($this) + 2304|0);
  $53 = (($this) + 2308|0);
  $54 = (($this) + 2312|0);
  $55 = (($maxPen) + 4|0);
  $$$i90 = Math_fround(3.40282346638528859812E+38);$i$087 = $previousNumContacts;
  while(1) {
   $60 = HEAP32[$51>>2]|0;
   $61 = ((($60) + ($i$087<<6)|0) + 44|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = ((($60) + ($i$087<<6)|0) + 32|0);
   HEAPF32[$63>>2] = $15;
   $64 = ((($60) + ($i$087<<6)|0) + 36|0);
   HEAPF32[$64>>2] = $26;
   $65 = ((($60) + ($i$087<<6)|0) + 40|0);
   HEAPF32[$65>>2] = $37;
   $66 = HEAP32[$51>>2]|0;
   $67 = ((($66) + ($i$087<<6)|0) + 16|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = ((($66) + ($i$087<<6)|0) + 20|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = ((($66) + ($i$087<<6)|0) + 24|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = Math_fround(HEAPF32[$52>>2]);
   $74 = Math_fround(HEAPF32[$53>>2]);
   $75 = Math_fround(HEAPF32[$54>>2]);
   $76 = Math_fround($68 - $73);
   $77 = Math_fround($70 - $74);
   $78 = Math_fround($72 - $75);
   $79 = Math_fround(HEAPF32[$5>>2]);
   $80 = Math_fround($76 * $79);
   $81 = Math_fround(HEAPF32[$8>>2]);
   $82 = Math_fround($77 * $81);
   $83 = Math_fround($80 + $82);
   $84 = Math_fround(HEAPF32[$12>>2]);
   $85 = Math_fround($78 * $84);
   $86 = Math_fround($83 + $85);
   $87 = Math_fround(HEAPF32[$16>>2]);
   $88 = Math_fround($76 * $87);
   $89 = Math_fround(HEAPF32[$19>>2]);
   $90 = Math_fround($77 * $89);
   $91 = Math_fround($88 + $90);
   $92 = Math_fround(HEAPF32[$23>>2]);
   $93 = Math_fround($78 * $92);
   $94 = Math_fround($91 + $93);
   $95 = Math_fround(HEAPF32[$27>>2]);
   $96 = Math_fround($76 * $95);
   $97 = Math_fround(HEAPF32[$30>>2]);
   $98 = Math_fround($77 * $97);
   $99 = Math_fround($96 + $98);
   $100 = Math_fround(HEAPF32[$34>>2]);
   $101 = Math_fround($78 * $100);
   $102 = Math_fround($99 + $101);
   HEAPF32[$67>>2] = $86;
   HEAPF32[$69>>2] = $94;
   HEAPF32[$71>>2] = $102;
   $103 = ((($66) + ($i$087<<6)|0) + 28|0);
   HEAPF32[$103>>2] = Math_fround(0.0);
   $104 = $$$i90 > $62;
   $$$i = $104 ? $62 : $$$i90;
   ;HEAP32[$55+0>>2]=HEAP32[$$sroa$127+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$$sroa$127+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$$sroa$127+8>>2]|0;
   $105 = (($i$087) + 1)|0;
   $106 = HEAP32[$48>>2]|0;
   $107 = ($105>>>0)<($106>>>0);
   if ($107) {
    $$$i90 = $$$i;$i$087 = $105;
   } else {
    break;
   }
  }
  HEAPF32[$maxPen>>2] = $$$i;
  $57 = $106;
 } else {
  $57 = $50;
 }
 $56 = ($57>>>0)>($previousNumContacts>>>0);
 if ($56) {
  $58 = (($this) + 2320|0);
  $59 = (($this) + 2240|0);
  $112 = $57;$i1$085 = $previousNumContacts;
  while(1) {
   $109 = (($i1$085) + 1)|0;
   $111 = ($109>>>0)<($112>>>0);
   if ($111) {
    $138 = $112;$j$084 = $109;
    while(1) {
     $113 = HEAP32[$58>>2]|0;
     $114 = ((($113) + ($j$084<<6)|0) + 16|0);
     $115 = Math_fround(HEAPF32[$114>>2]);
     $116 = ((($113) + ($j$084<<6)|0) + 20|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = ((($113) + ($j$084<<6)|0) + 24|0);
     $119 = Math_fround(HEAPF32[$118>>2]);
     $120 = ((($113) + ($i1$085<<6)|0) + 16|0);
     $121 = Math_fround(HEAPF32[$120>>2]);
     $122 = ((($113) + ($i1$085<<6)|0) + 20|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     $124 = ((($113) + ($i1$085<<6)|0) + 24|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     $126 = Math_fround($115 - $121);
     $127 = Math_fround($117 - $123);
     $128 = Math_fround($119 - $125);
     $129 = Math_fround($126 * $126);
     $130 = Math_fround($127 * $127);
     $131 = Math_fround($129 + $130);
     $132 = Math_fround($128 * $128);
     $133 = Math_fround($131 + $132);
     $134 = Math_fround(HEAPF32[$59>>2]);
     $135 = $134 > $133;
     if ($135) {
      $136 = (($113) + ($j$084<<6)|0);
      $137 = (($138) + -1)|0;
      $139 = (($113) + ($137<<6)|0);
      dest=$136+0|0; src=$139+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $140 = HEAP32[$48>>2]|0;
      $141 = (($140) + -1)|0;
      HEAP32[$48>>2] = $141;
      $142 = (($j$084) + -1)|0;
      $145 = $141;$j$1 = $142;
     } else {
      $145 = $138;$j$1 = $j$084;
     }
     $143 = (($j$1) + 1)|0;
     $144 = ($143>>>0)<($145>>>0);
     if ($144) {
      $138 = $145;$j$084 = $143;
     } else {
      $110 = $145;
      break;
     }
    }
   } else {
    $110 = $112;
   }
   $108 = ($109>>>0)<($110>>>0);
   if ($108) {
    $112 = $110;$i1$085 = $109;
   } else {
    break;
   }
  }
 }
 __ZN5physx2Gu24PCMMeshContactGeneration23addManifoldPointToPatchERKNS_6shdfnd3aos5Vec3VERKNS3_6FloatVEj($this,$patchNormalInTriangle,$maxPen,$previousNumContacts);
 $146 = HEAP32[$48>>2]|0;
 $147 = ($146>>>0)>(15);
 if (!($147)) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Gu24PCMMeshContactGeneration15processContactsEhb($this,6,1);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu24PCMMeshContactGeneration23addManifoldPointToPatchERKNS_6shdfnd3aos5Vec3VERKNS3_6FloatVEj($this,$currentPatchNormal,$maxPen,$previousNumContacts) {
 $this = $this|0;
 $currentPatchNormal = $currentPatchNormal|0;
 $maxPen = $maxPen|0;
 $previousNumContacts = $previousNumContacts|0;
 var $$$i = Math_fround(0), $$pre = 0, $$pre94 = 0, $$pre95 = 0, $$pre98 = 0, $$pre99 = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0;
 var $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0;
 var $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0;
 var $i$092 = 0, $j$091 = 0, $j$1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$sroa$1 = sp;
 $0 = (($this) + 2328|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($1) + -1)|0;
  $4 = (($this) + ($3<<6)|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = ((($this) + ($3<<6)|0) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = ((($this) + ($3<<6)|0) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround(HEAPF32[$currentPatchNormal>>2]);
  $11 = (($currentPatchNormal) + 4|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($currentPatchNormal) + 8|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($5 * $10);
  $16 = Math_fround($7 * $12);
  $17 = Math_fround($15 + $16);
  $18 = Math_fround($9 * $14);
  $19 = Math_fround($17 + $18);
  $20 = (($this) + 2224|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = $19 > $21;
  if ($22) {
   $23 = ((($this) + ($3<<6)|0) + 48|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($this) + ($3<<6)|0) + 52|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($24>>>0)<($26>>>0);
   $28 = (($this) + 2324|0);
   if ($27) {
    $29 = (($this) + 2320|0);
    $30 = (($this) + 2240|0);
    $$pre = HEAP32[$28>>2]|0;
    $32 = $$pre;$90 = $26;$i$092 = $24;
    while(1) {
     $31 = ($32>>>0)>($previousNumContacts>>>0);
     if ($31) {
      $91 = $32;$j$091 = $previousNumContacts;
      while(1) {
       $33 = HEAP32[$29>>2]|0;
       $34 = ((($33) + ($j$091<<6)|0) + 16|0);
       $35 = Math_fround(HEAPF32[$34>>2]);
       $36 = ((($33) + ($j$091<<6)|0) + 20|0);
       $37 = Math_fround(HEAPF32[$36>>2]);
       $38 = ((($33) + ($j$091<<6)|0) + 24|0);
       $39 = Math_fround(HEAPF32[$38>>2]);
       $40 = ((($33) + ($i$092<<6)|0) + 16|0);
       $41 = Math_fround(HEAPF32[$40>>2]);
       $42 = ((($33) + ($i$092<<6)|0) + 20|0);
       $43 = Math_fround(HEAPF32[$42>>2]);
       $44 = ((($33) + ($i$092<<6)|0) + 24|0);
       $45 = Math_fround(HEAPF32[$44>>2]);
       $46 = Math_fround($35 - $41);
       $47 = Math_fround($37 - $43);
       $48 = Math_fround($39 - $45);
       $49 = Math_fround($46 * $46);
       $50 = Math_fround($47 * $47);
       $51 = Math_fround($49 + $50);
       $52 = Math_fround($48 * $48);
       $53 = Math_fround($51 + $52);
       $54 = Math_fround(HEAPF32[$30>>2]);
       $55 = $54 > $53;
       if ($55) {
        $56 = ((($33) + ($i$092<<6)|0) + 44|0);
        $57 = Math_fround(HEAPF32[$56>>2]);
        $58 = ((($33) + ($j$091<<6)|0) + 44|0);
        $59 = Math_fround(HEAPF32[$58>>2]);
        $60 = $57 > $59;
        if ($60) {
         $61 = (($33) + ($i$092<<6)|0);
         $62 = (($33) + ($j$091<<6)|0);
         dest=$61+0|0; src=$62+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
         $$pre94 = HEAP32[$29>>2]|0;
         $$pre95 = HEAP32[$28>>2]|0;
         $64 = $$pre94;$66 = $$pre95;
        } else {
         $64 = $33;$66 = $91;
        }
        $63 = (($64) + ($j$091<<6)|0);
        $65 = (($66) + -1)|0;
        $67 = (($64) + ($65<<6)|0);
        dest=$63+0|0; src=$67+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $68 = HEAP32[$28>>2]|0;
        $69 = (($68) + -1)|0;
        HEAP32[$28>>2] = $69;
        $70 = (($j$091) + -1)|0;
        $73 = $69;$j$1 = $70;
       } else {
        $73 = $91;$j$1 = $j$091;
       }
       $71 = (($j$1) + 1)|0;
       $72 = ($71>>>0)<($73>>>0);
       if ($72) {
        $91 = $73;$j$091 = $71;
       } else {
        break;
       }
      }
      $$pre99 = HEAP32[$25>>2]|0;
      $76 = $$pre99;$92 = $73;
     } else {
      $76 = $90;$92 = $32;
     }
     $74 = (($i$092) + 1)|0;
     $75 = ($74>>>0)<($76>>>0);
     if ($75) {
      $32 = $92;$90 = $76;$i$092 = $74;
     } else {
      $77 = $92;
      break;
     }
    }
   } else {
    $$pre98 = HEAP32[$28>>2]|0;
    $77 = $$pre98;
   }
   HEAP32[$25>>2] = $77;
   $78 = ((($this) + ($3<<6)|0) + 32|0);
   $79 = Math_fround(HEAPF32[$78>>2]);
   $80 = ((($this) + ($3<<6)|0) + 36|0);
   $81 = Math_fround(HEAPF32[$maxPen>>2]);
   $82 = $79 > $81;
   $$$i = $82 ? $81 : $79;
   HEAPF32[$78>>2] = $$$i;
   ;HEAP32[$80+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$80+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$80+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
   STACKTOP = sp;return;
  }
 }
 $83 = ((($this) + ($1<<6)|0) + 48|0);
 HEAP32[$83>>2] = $previousNumContacts;
 $84 = (($this) + 2324|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ((($this) + ($1<<6)|0) + 52|0);
 HEAP32[$86>>2] = $85;
 $87 = ((($this) + ($1<<6)|0) + 32|0);
 ;HEAP32[$87+0>>2]=HEAP32[$maxPen+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$maxPen+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$maxPen+8>>2]|0;HEAP32[$87+12>>2]=HEAP32[$maxPen+12>>2]|0;
 $88 = (($1) + 1)|0;
 HEAP32[$0>>2] = $88;
 $89 = (($this) + ($1<<6)|0);
 ;HEAP32[$89+0>>2]=HEAP32[$currentPatchNormal+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$currentPatchNormal+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$currentPatchNormal+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$currentPatchNormal+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32PCMConvexVsMeshContactGeneration20generateLastContactsEv($this) {
 $this = $this|0;
 var $$sroa$1$i$i = 0, $$sroa$113$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0;
 var $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$026 = 0, $index$0$i = 0, $index$0$i13 = 0, $index$0$i6 = 0, $index$01$i = 0, $index$01$i10 = 0, $index$01$i3 = 0, $localTriangle = 0, $patchNormal = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $zero$sroa$1$i$i$i = sp + 200|0;
 $0 = sp;
 $$sroa$113$i$i = sp + 188|0;
 $$sroa$1$i$i = sp + 176|0;
 $localTriangle = sp + 16|0;
 $patchNormal = sp + 160|0;
 $1 = (($this) + 3648|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($4>>>0) / 15)&-1;
 $7 = (($2) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($4>>>0)>(14);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($localTriangle) + 64|0);
 $11 = (($localTriangle) + 80|0);
 $12 = (($localTriangle) + 16|0);
 $13 = (($localTriangle) + 20|0);
 $14 = (($localTriangle) + 32|0);
 $15 = (($localTriangle) + 36|0);
 $16 = (($localTriangle) + 48|0);
 $17 = (($localTriangle) + 52|0);
 $18 = (($localTriangle) + 4|0);
 $19 = (($localTriangle) + 8|0);
 $20 = (($localTriangle) + 12|0);
 $21 = (($localTriangle) + 96|0);
 $22 = (($localTriangle) + 100|0);
 $23 = (($localTriangle) + 104|0);
 $24 = (($localTriangle) + 108|0);
 $25 = (($localTriangle) + 112|0);
 $26 = (($localTriangle) + 116|0);
 $27 = (($localTriangle) + 120|0);
 $28 = (($localTriangle) + 124|0);
 $29 = (($localTriangle) + 128|0);
 $30 = (($localTriangle) + 132|0);
 $31 = (($localTriangle) + 136|0);
 $32 = (($localTriangle) + 140|0);
 $33 = (($this) + 2324|0);
 $34 = (($this) + 2320|0);
 $35 = (($this) + 2176|0);
 $i$026 = 0;
 while(1) {
  $36 = ((($8) + (($i$026*60)|0)|0) + 36|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($8) + (($i$026*60)|0)|0) + 40|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ((($8) + (($i$026*60)|0)|0) + 44|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($8) + (($i$026*60)|0)|0) + 56|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = $43&255;
  $45 = $44 & 8;
  $46 = ($45|0)==(0);
  L9: do {
   if ($46) {
    $47 = ($37>>>0)<($39>>>0);
    $48 = $47 ? $37 : $39;
    $49 = $47 ? $39 : $37;
    $50 = $48 << 16;
    $51 = $50 | $49;
    $52 = $51 << 15;
    $53 = $52 ^ -1;
    $54 = (($51) + ($53))|0;
    $55 = $54 >>> 10;
    $56 = $55 ^ $54;
    $57 = ($56*9)|0;
    $58 = $57 >>> 6;
    $59 = $58 ^ $57;
    $60 = $59 << 11;
    $61 = $60 ^ -1;
    $62 = (($59) + ($61))|0;
    $63 = $62 >>> 16;
    $64 = $63 ^ $62;
    $65 = $64 & 127;
    $66 = ((($this) + ($65)|0) + 3488|0);
    $index$01$i10 = HEAP8[$66>>0]|0;
    $67 = ($index$01$i10<<24>>24)==(-1);
    if ($67) {
     label = 10;
    } else {
     $68 = $index$01$i10&255;
     $70 = $68;
     while(1) {
      $69 = ((($this) + ($70<<3)|0) + 2336|0);
      $71 = HEAP32[$69>>2]|0;
      $72 = ($71|0)==($48|0);
      if ($72) {
       $73 = ((($this) + ($70<<3)|0) + 2340|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($74|0)==($49|0);
       if ($75) {
        break L9;
       }
      }
      $76 = ((($this) + ($70)|0) + 3360|0);
      $index$0$i13 = HEAP8[$76>>0]|0;
      $77 = $index$0$i13&255;
      $78 = ($index$0$i13<<24>>24)==(-1);
      if ($78) {
       label = 10;
       break;
      } else {
       $70 = $77;
      }
     }
    }
   } else {
    label = 10;
   }
  } while(0);
  L17: do {
   if ((label|0) == 10) {
    label = 0;
    $79 = $44 & 16;
    $80 = ($79|0)==(0);
    if ($80) {
     $81 = ($39>>>0)<($41>>>0);
     $82 = $81 ? $39 : $41;
     $83 = $81 ? $41 : $39;
     $84 = $82 << 16;
     $85 = $84 | $83;
     $86 = $85 << 15;
     $87 = $86 ^ -1;
     $88 = (($85) + ($87))|0;
     $89 = $88 >>> 10;
     $90 = $89 ^ $88;
     $91 = ($90*9)|0;
     $92 = $91 >>> 6;
     $93 = $92 ^ $91;
     $94 = $93 << 11;
     $95 = $94 ^ -1;
     $96 = (($93) + ($95))|0;
     $97 = $96 >>> 16;
     $98 = $97 ^ $96;
     $99 = $98 & 127;
     $100 = ((($this) + ($99)|0) + 3488|0);
     $index$01$i3 = HEAP8[$100>>0]|0;
     $101 = ($index$01$i3<<24>>24)==(-1);
     if (!($101)) {
      $102 = $index$01$i3&255;
      $104 = $102;
      while(1) {
       $103 = ((($this) + ($104<<3)|0) + 2336|0);
       $105 = HEAP32[$103>>2]|0;
       $106 = ($105|0)==($82|0);
       if ($106) {
        $107 = ((($this) + ($104<<3)|0) + 2340|0);
        $108 = HEAP32[$107>>2]|0;
        $109 = ($108|0)==($83|0);
        if ($109) {
         break L17;
        }
       }
       $110 = ((($this) + ($104)|0) + 3360|0);
       $index$0$i6 = HEAP8[$110>>0]|0;
       $111 = $index$0$i6&255;
       $112 = ($index$0$i6<<24>>24)==(-1);
       if ($112) {
        break;
       } else {
        $104 = $111;
       }
      }
     }
    }
    $113 = $44 & 32;
    $114 = ($113|0)==(0);
    if ($114) {
     $115 = ($41>>>0)<($37>>>0);
     $116 = $115 ? $41 : $37;
     $117 = $115 ? $37 : $41;
     $118 = $116 << 16;
     $119 = $118 | $117;
     $120 = $119 << 15;
     $121 = $120 ^ -1;
     $122 = (($119) + ($121))|0;
     $123 = $122 >>> 10;
     $124 = $123 ^ $122;
     $125 = ($124*9)|0;
     $126 = $125 >>> 6;
     $127 = $126 ^ $125;
     $128 = $127 << 11;
     $129 = $128 ^ -1;
     $130 = (($127) + ($129))|0;
     $131 = $130 >>> 16;
     $132 = $131 ^ $130;
     $133 = $132 & 127;
     $134 = ((($this) + ($133)|0) + 3488|0);
     $index$01$i = HEAP8[$134>>0]|0;
     $135 = ($index$01$i<<24>>24)==(-1);
     if (!($135)) {
      $136 = $index$01$i&255;
      $138 = $136;
      while(1) {
       $137 = ((($this) + ($138<<3)|0) + 2336|0);
       $139 = HEAP32[$137>>2]|0;
       $140 = ($139|0)==($116|0);
       if ($140) {
        $141 = ((($this) + ($138<<3)|0) + 2340|0);
        $142 = HEAP32[$141>>2]|0;
        $143 = ($142|0)==($117|0);
        if ($143) {
         break L17;
        }
       }
       $144 = ((($this) + ($138)|0) + 3360|0);
       $index$0$i = HEAP8[$144>>0]|0;
       $145 = $index$0$i&255;
       $146 = ($index$0$i<<24>>24)==(-1);
       if ($146) {
        break;
       } else {
        $138 = $145;
       }
      }
     }
    }
    HEAP32[$11>>2] = 7;
    HEAPF32[$12>>2] = Math_fround(0.0);
    ;HEAP32[$13+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
    HEAPF32[$14>>2] = Math_fround(0.0);
    ;HEAP32[$15+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
    HEAPF32[$16>>2] = Math_fround(0.0);
    ;HEAP32[$17+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    ;HEAP32[$10+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$0+12>>2]|0;
    $147 = (($8) + (($i$026*60)|0)|0);
    $148 = Math_fround(HEAPF32[$147>>2]);
    $149 = ((($8) + (($i$026*60)|0)|0) + 4|0);
    $150 = Math_fround(HEAPF32[$149>>2]);
    $151 = ((($8) + (($i$026*60)|0)|0) + 8|0);
    $152 = Math_fround(HEAPF32[$151>>2]);
    $153 = ((($8) + (($i$026*60)|0)|0) + 12|0);
    $154 = Math_fround(HEAPF32[$153>>2]);
    $155 = ((($8) + (($i$026*60)|0)|0) + 16|0);
    $156 = Math_fround(HEAPF32[$155>>2]);
    $157 = ((($8) + (($i$026*60)|0)|0) + 20|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = ((($8) + (($i$026*60)|0)|0) + 24|0);
    $160 = Math_fround(HEAPF32[$159>>2]);
    $161 = ((($8) + (($i$026*60)|0)|0) + 28|0);
    $162 = Math_fround(HEAPF32[$161>>2]);
    $163 = ((($8) + (($i$026*60)|0)|0) + 32|0);
    $164 = Math_fround(HEAPF32[$163>>2]);
    $165 = Math_fround($148 + $154);
    $166 = Math_fround($150 + $156);
    $167 = Math_fround($152 + $158);
    $168 = Math_fround($165 + $160);
    $169 = Math_fround($166 + $162);
    $170 = Math_fround($167 + $164);
    $171 = Math_fround($168 * Math_fround(0.333332985639572143555));
    $172 = Math_fround($169 * Math_fround(0.333332985639572143555));
    $173 = Math_fround($170 * Math_fround(0.333332985639572143555));
    HEAPF32[$localTriangle>>2] = $171;
    HEAPF32[$18>>2] = $172;
    HEAPF32[$19>>2] = $173;
    HEAPF32[$20>>2] = Math_fround(0.0);
    HEAPF32[$21>>2] = $148;
    HEAPF32[$22>>2] = $150;
    HEAPF32[$23>>2] = $152;
    HEAPF32[$24>>2] = Math_fround(0.0);
    HEAPF32[$25>>2] = $154;
    HEAPF32[$26>>2] = $156;
    HEAPF32[$27>>2] = $158;
    HEAPF32[$28>>2] = Math_fround(0.0);
    HEAPF32[$29>>2] = $160;
    HEAPF32[$30>>2] = $162;
    HEAPF32[$31>>2] = $164;
    HEAPF32[$32>>2] = Math_fround(0.0);
    HEAPF32[$12>>2] = Math_fround(0.0);
    ;HEAP32[$13+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
    HEAPF32[$14>>2] = Math_fround(3.40282346638528859812E+38);
    ;HEAP32[$15+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
    $174 = HEAP32[$33>>2]|0;
    $175 = ((($8) + (($i$026*60)|0)|0) + 52|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = ((($8) + (($i$026*60)|0)|0) + 48|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = HEAP32[$34>>2]|0;
    (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration31generatePolyDataContactManifoldERNS0_9TriangleVEjjhPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERNS8_5Vec3VE($this,$localTriangle,$176,$178,$43,$179,$33,$35,$patchNormal)|0);
    $180 = HEAP32[$33>>2]|0;
    $181 = ($180|0)==($174|0);
    if (!($181)) {
     $182 = (($180) - ($174))|0;
     __ZN5physx2Gu32PCMConvexVsMeshContactGeneration18addContactsToPatchERKNS_6shdfnd3aos5Vec3VEjj($this,$patchNormal,$174,$182);
    }
   }
  } while(0);
  $183 = (($i$026) + 1)|0;
  $184 = ($183>>>0)<($6>>>0);
  if ($184) {
   $i$026 = $183;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32PCMConvexVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($this,$verts,$triangleIndex,$triFlags,$vertInds) {
 $this = $this|0;
 $verts = $verts|0;
 $triangleIndex = $triangleIndex|0;
 $triFlags = $triFlags|0;
 $vertInds = $vertInds|0;
 var $$0 = 0, $$sroa$1$i$i = 0, $$sroa$113$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0;
 var $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0;
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $identity = 0, $localTriangle = 0, $patchNormal = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $zero$sroa$1$i$i$i = sp + 16|0;
 $0 = sp + 272|0;
 $$sroa$113$i$i = sp + 288|0;
 $$sroa$1$i$i = sp + 328|0;
 $identity = sp + 80|0;
 $localTriangle = sp + 128|0;
 $patchNormal = sp;
 $1 = sp + 304|0;
 $2 = sp + 312|0;
 $3 = sp + 320|0;
 HEAPF32[$identity>>2] = Math_fround(1.0);
 $4 = (($identity) + 4|0);
 $5 = (($identity) + 20|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($identity) + 24|0);
 $7 = (($identity) + 40|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($identity) + 44|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = Math_fround(HEAPF32[$verts>>2]);
 $10 = (($verts) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($verts) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($verts) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($verts) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($verts) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($verts) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($verts) + 28|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($verts) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($15 - $9);
 $27 = Math_fround($17 - $11);
 $28 = Math_fround($19 - $13);
 $29 = Math_fround($21 - $9);
 $30 = Math_fround($23 - $11);
 $31 = Math_fround($25 - $13);
 $32 = Math_fround($27 * $31);
 $33 = Math_fround($28 * $30);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($28 * $29);
 $36 = Math_fround($26 * $31);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($26 * $30);
 $39 = Math_fround($27 * $29);
 $40 = Math_fround($38 - $39);
 $41 = Math_fround($34 * $34);
 $42 = Math_fround($37 * $37);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($40 * $40);
 $45 = Math_fround($44 + $43);
 $46 = (Math_fround(Math_sqrt((Math_fround($45)))));
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = Math_fround($47 * $34);
 $49 = Math_fround($47 * $37);
 $50 = Math_fround($40 * $47);
 $51 = Math_fround($9 * $48);
 $52 = Math_fround($11 * $49);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($13 * $50);
 $55 = Math_fround($54 + $53);
 $56 = (($this) + 3632|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($this) + 3636|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($this) + 3640|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($57 * $48);
 $63 = Math_fround($59 * $49);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($50 * $61);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($66 - $55);
 $68 = $67 < Math_fround(0.0);
 if ($68) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $69 = (($this) + 2304|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($this) + 2308|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($this) + 2312|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($this) + 2256|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($9 * $76);
 $78 = (($this) + 2272|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($11 * $79);
 $81 = Math_fround($77 + $80);
 $82 = (($this) + 2288|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($13 * $83);
 $85 = Math_fround($81 + $84);
 $86 = (($this) + 2260|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($9 * $87);
 $89 = (($this) + 2276|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($11 * $90);
 $92 = Math_fround($88 + $91);
 $93 = (($this) + 2292|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($13 * $94);
 $96 = Math_fround($92 + $95);
 $97 = (($this) + 2264|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($9 * $98);
 $100 = (($this) + 2280|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($11 * $101);
 $103 = Math_fround($99 + $102);
 $104 = (($this) + 2296|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($13 * $105);
 $107 = Math_fround($103 + $106);
 $108 = Math_fround($70 + $85);
 $109 = Math_fround($72 + $96);
 $110 = Math_fround($74 + $107);
 $111 = Math_fround($15 * $76);
 $112 = Math_fround($17 * $79);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($19 * $83);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($15 * $87);
 $117 = Math_fround($17 * $90);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($19 * $94);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($15 * $98);
 $122 = Math_fround($17 * $101);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($19 * $105);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($70 + $115);
 $127 = Math_fround($72 + $120);
 $128 = Math_fround($74 + $125);
 $129 = Math_fround($21 * $76);
 $130 = Math_fround($23 * $79);
 $131 = Math_fround($129 + $130);
 $132 = Math_fround($25 * $83);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround($21 * $87);
 $135 = Math_fround($23 * $90);
 $136 = Math_fround($134 + $135);
 $137 = Math_fround($25 * $94);
 $138 = Math_fround($136 + $137);
 $139 = Math_fround($21 * $98);
 $140 = Math_fround($23 * $101);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($25 * $105);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround($70 + $133);
 $145 = Math_fround($72 + $138);
 $146 = Math_fround($74 + $143);
 $147 = (($localTriangle) + 64|0);
 $148 = (($localTriangle) + 80|0);
 HEAP32[$148>>2] = 7;
 $149 = (($localTriangle) + 16|0);
 $150 = (($localTriangle) + 20|0);
 $151 = (($localTriangle) + 32|0);
 $152 = (($localTriangle) + 36|0);
 $153 = (($localTriangle) + 48|0);
 HEAPF32[$153>>2] = Math_fround(0.0);
 $154 = (($localTriangle) + 52|0);
 ;HEAP32[$154+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$154+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$154+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$147+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$147+12>>2]=HEAP32[$0+12>>2]|0;
 $155 = Math_fround($108 + $126);
 $156 = Math_fround($109 + $127);
 $157 = Math_fround($110 + $128);
 $158 = Math_fround($144 + $155);
 $159 = Math_fround($145 + $156);
 $160 = Math_fround($146 + $157);
 $161 = Math_fround($158 * Math_fround(0.333332985639572143555));
 $162 = Math_fround($159 * Math_fround(0.333332985639572143555));
 $163 = Math_fround($160 * Math_fround(0.333332985639572143555));
 HEAPF32[$localTriangle>>2] = $161;
 $164 = (($localTriangle) + 4|0);
 HEAPF32[$164>>2] = $162;
 $165 = (($localTriangle) + 8|0);
 HEAPF32[$165>>2] = $163;
 $166 = (($localTriangle) + 12|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = (($localTriangle) + 96|0);
 HEAPF32[$167>>2] = $108;
 $168 = (($localTriangle) + 100|0);
 HEAPF32[$168>>2] = $109;
 $169 = (($localTriangle) + 104|0);
 HEAPF32[$169>>2] = $110;
 $170 = (($localTriangle) + 108|0);
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = (($localTriangle) + 112|0);
 HEAPF32[$171>>2] = $126;
 $172 = (($localTriangle) + 116|0);
 HEAPF32[$172>>2] = $127;
 $173 = (($localTriangle) + 120|0);
 HEAPF32[$173>>2] = $128;
 $174 = (($localTriangle) + 124|0);
 HEAPF32[$174>>2] = Math_fround(0.0);
 $175 = (($localTriangle) + 128|0);
 HEAPF32[$175>>2] = $144;
 $176 = (($localTriangle) + 132|0);
 HEAPF32[$176>>2] = $145;
 $177 = (($localTriangle) + 136|0);
 HEAPF32[$177>>2] = $146;
 $178 = (($localTriangle) + 140|0);
 HEAPF32[$178>>2] = Math_fround(0.0);
 HEAPF32[$149>>2] = Math_fround(0.0);
 ;HEAP32[$150+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 HEAPF32[$151>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$152+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$152+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
 $179 = (($this) + 2208|0);
 $180 = HEAP32[$179>>2]|0;
 $181 = (($zero$sroa$1$i$i$i) + 32|0);
 HEAP32[$181>>2] = $180;
 $182 = (($zero$sroa$1$i$i$i) + 36|0);
 HEAP32[$182>>2] = $identity;
 $183 = (($zero$sroa$1$i$i$i) + 40|0);
 HEAP32[$183>>2] = $identity;
 $184 = (($zero$sroa$1$i$i$i) + 44|0);
 HEAP8[$184>>0] = 1;
 HEAP32[$zero$sroa$1$i$i$i>>2] = ((554056 + 8|0));
 $185 = (($zero$sroa$1$i$i$i) + 48|0);
 HEAP32[$185>>2] = $localTriangle;
 $186 = (($this) + 2324|0);
 $187 = HEAP32[$186>>2]|0;
 $188 = (($this) + 3652|0);
 $189 = HEAP32[$188>>2]|0;
 $190 = (($this) + 3656|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = (($this) + 2320|0);
 $193 = HEAP32[$192>>2]|0;
 $194 = (($this) + 2176|0);
 (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration35generateTriangleFullContactManifoldERNS0_9TriangleVEjPKjhRKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS2_EEPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERNSI_5Vec3VE($this,$localTriangle,$triangleIndex,$vertInds,$triFlags,$189,$zero$sroa$1$i$i$i,$191,$193,$186,$194,$patchNormal)|0);
 $195 = HEAP32[$186>>2]|0;
 $196 = (($195) - ($187))|0;
 $197 = ($195|0)==($187|0);
 if ($197) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $198 = $triFlags&255;
 $199 = $198 & 8;
 $200 = ($199|0)==(0);
 $201 = $198 & 16;
 $202 = ($201|0)==(0);
 $203 = $198 & 32;
 $204 = ($203|0)==(0);
 if ($200) {
  $205 = (($this) + 2336|0);
  $206 = HEAP32[$vertInds>>2]|0;
  $207 = (($vertInds) + 4|0);
  $208 = HEAP32[$207>>2]|0;
  $209 = ($206>>>0)<($208>>>0);
  $210 = $209 ? $206 : $208;
  HEAP32[$1>>2] = $210;
  $211 = $209 ? $208 : $206;
  $212 = (($1) + 4|0);
  HEAP32[$212>>2] = $211;
  (__ZN5physx2Gu8CacheMapINS0_10CachedEdgeELj128EE7addDataERKS2_($205,$1)|0);
 }
 if ($202) {
  $213 = (($this) + 2336|0);
  $214 = (($vertInds) + 4|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = (($vertInds) + 8|0);
  $217 = HEAP32[$216>>2]|0;
  $218 = ($215>>>0)<($217>>>0);
  $219 = $218 ? $215 : $217;
  HEAP32[$2>>2] = $219;
  $220 = $218 ? $217 : $215;
  $221 = (($2) + 4|0);
  HEAP32[$221>>2] = $220;
  (__ZN5physx2Gu8CacheMapINS0_10CachedEdgeELj128EE7addDataERKS2_($213,$2)|0);
 }
 if ($204) {
  $222 = (($this) + 2336|0);
  $223 = (($vertInds) + 8|0);
  $224 = HEAP32[$223>>2]|0;
  $225 = HEAP32[$vertInds>>2]|0;
  $226 = ($224>>>0)<($225>>>0);
  $227 = $226 ? $224 : $225;
  HEAP32[$3>>2] = $227;
  $228 = $226 ? $225 : $224;
  $229 = (($3) + 4|0);
  HEAP32[$229>>2] = $228;
  (__ZN5physx2Gu8CacheMapINS0_10CachedEdgeELj128EE7addDataERKS2_($222,$3)|0);
 }
 __ZN5physx2Gu32PCMConvexVsMeshContactGeneration18addContactsToPatchERKNS_6shdfnd3aos5Vec3VEjj($this,$patchNormal,$187,$196);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu16SupportLocalImplINS0_9TriangleVEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32PCMConvexVsMeshContactGeneration15processTriangleERKNS0_13PolygonalDataEPNS0_12SupportLocalEPKNS_6PxVec3EjhRKNS_6shdfnd3aos6FloatVEbRKNSB_12PsTransformVERKNSB_15PsMatTransformVEPNS0_21MeshPersistentContactERj($polyData,$polyMap,$verts,$triangleIndex,$triFlags,$inflation,$isDoubleSided,$convexTransform,$meshToConvex,$manifoldContacts,$numContacts) {
 $polyData = $polyData|0;
 $polyMap = $polyMap|0;
 $verts = $verts|0;
 $triangleIndex = $triangleIndex|0;
 $triFlags = $triFlags|0;
 $inflation = $inflation|0;
 $isDoubleSided = $isDoubleSided|0;
 $convexTransform = $convexTransform|0;
 $meshToConvex = $meshToConvex|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 var $$0 = 0, $$sroa$1$i$i = 0, $$sroa$113$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $identity = 0, $localTriangle = 0, $patchNormal = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $zero$sroa$1$i$i$i = sp + 224|0;
 $0 = sp;
 $$sroa$113$i$i = sp + 300|0;
 $$sroa$1$i$i = sp + 288|0;
 $identity = sp + 176|0;
 $localTriangle = sp + 32|0;
 $patchNormal = sp + 16|0;
 HEAPF32[$identity>>2] = Math_fround(1.0);
 $1 = (($identity) + 4|0);
 $2 = (($identity) + 20|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($identity) + 24|0);
 $4 = (($identity) + 40|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($identity) + 44|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = Math_fround(HEAPF32[$verts>>2]);
 $7 = (($verts) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($verts) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($verts) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($verts) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($verts) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($verts) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($verts) + 28|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($verts) + 32|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($meshToConvex) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($meshToConvex) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($meshToConvex) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$meshToConvex>>2]);
 $30 = Math_fround($6 * $29);
 $31 = (($meshToConvex) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($8 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($meshToConvex) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($10 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($meshToConvex) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($6 * $40);
 $42 = (($meshToConvex) + 20|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($8 * $43);
 $45 = Math_fround($41 + $44);
 $46 = (($meshToConvex) + 36|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($10 * $47);
 $49 = Math_fround($45 + $48);
 $50 = (($meshToConvex) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($6 * $51);
 $53 = (($meshToConvex) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($8 * $54);
 $56 = Math_fround($52 + $55);
 $57 = (($meshToConvex) + 40|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($10 * $58);
 $60 = Math_fround($56 + $59);
 $61 = Math_fround($24 + $38);
 $62 = Math_fround($26 + $49);
 $63 = Math_fround($28 + $60);
 $64 = Math_fround($12 * $29);
 $65 = Math_fround($14 * $32);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($16 * $36);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($12 * $40);
 $70 = Math_fround($14 * $43);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($16 * $47);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($12 * $51);
 $75 = Math_fround($14 * $54);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($16 * $58);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($24 + $68);
 $80 = Math_fround($26 + $73);
 $81 = Math_fround($28 + $78);
 $82 = Math_fround($18 * $29);
 $83 = Math_fround($20 * $32);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($22 * $36);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($18 * $40);
 $88 = Math_fround($20 * $43);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($22 * $47);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($18 * $51);
 $93 = Math_fround($20 * $54);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($22 * $58);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($24 + $86);
 $98 = Math_fround($26 + $91);
 $99 = Math_fround($28 + $96);
 $100 = Math_fround($79 - $61);
 $101 = Math_fround($80 - $62);
 $102 = Math_fround($81 - $63);
 $103 = Math_fround($97 - $61);
 $104 = Math_fround($98 - $62);
 $105 = Math_fround($99 - $63);
 $106 = Math_fround($101 * $105);
 $107 = Math_fround($104 * $102);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($103 * $102);
 $110 = Math_fround($100 * $105);
 $111 = Math_fround($109 - $110);
 $112 = Math_fround($100 * $104);
 $113 = Math_fround($103 * $101);
 $114 = Math_fround($112 - $113);
 $115 = Math_fround($108 * $108);
 $116 = Math_fround($111 * $111);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($114 * $114);
 $119 = Math_fround($118 + $117);
 $120 = (Math_fround(Math_sqrt((Math_fround($119)))));
 $121 = Math_fround(Math_fround(1.0) / $120);
 $122 = Math_fround($121 * $108);
 $123 = Math_fround($121 * $111);
 $124 = Math_fround($121 * $114);
 if (!($isDoubleSided)) {
  $125 = (($polyMap) + 20|0);
  $126 = (($polyMap) + 16|0);
  $127 = (($polyMap) + 24|0);
  $128 = Math_fround(HEAPF32[$125>>2]);
  $129 = Math_fround(HEAPF32[$126>>2]);
  $130 = Math_fround($123 * $128);
  $131 = Math_fround($122 * $129);
  $132 = Math_fround(HEAPF32[$127>>2]);
  $133 = Math_fround($62 * $123);
  $134 = Math_fround($61 * $122);
  $135 = Math_fround($124 * $132);
  $136 = Math_fround($130 + $131);
  $137 = Math_fround($63 * $124);
  $138 = Math_fround($134 + $133);
  $139 = Math_fround($136 + $135);
  $140 = Math_fround($137 + $138);
  $141 = Math_fround($139 - $140);
  $142 = $141 < Math_fround(0.0);
  if ($142) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $143 = (($localTriangle) + 64|0);
 $144 = (($localTriangle) + 80|0);
 HEAP32[$144>>2] = 7;
 $145 = (($localTriangle) + 16|0);
 $146 = (($localTriangle) + 20|0);
 $147 = (($localTriangle) + 32|0);
 $148 = (($localTriangle) + 36|0);
 $149 = (($localTriangle) + 48|0);
 HEAPF32[$149>>2] = Math_fround(0.0);
 $150 = (($localTriangle) + 52|0);
 ;HEAP32[$150+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 ;HEAP32[$143+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$143+12>>2]=HEAP32[$0+12>>2]|0;
 $151 = Math_fround($61 + $79);
 $152 = Math_fround($62 + $80);
 $153 = Math_fround($63 + $81);
 $154 = Math_fround($97 + $151);
 $155 = Math_fround($98 + $152);
 $156 = Math_fround($99 + $153);
 $157 = Math_fround($154 * Math_fround(0.333332985639572143555));
 $158 = Math_fround($155 * Math_fround(0.333332985639572143555));
 $159 = Math_fround($156 * Math_fround(0.333332985639572143555));
 HEAPF32[$localTriangle>>2] = $157;
 $160 = (($localTriangle) + 4|0);
 HEAPF32[$160>>2] = $158;
 $161 = (($localTriangle) + 8|0);
 HEAPF32[$161>>2] = $159;
 $162 = (($localTriangle) + 12|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 $163 = (($localTriangle) + 96|0);
 HEAPF32[$163>>2] = $61;
 $164 = (($localTriangle) + 100|0);
 HEAPF32[$164>>2] = $62;
 $165 = (($localTriangle) + 104|0);
 HEAPF32[$165>>2] = $63;
 $166 = (($localTriangle) + 108|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = (($localTriangle) + 112|0);
 HEAPF32[$167>>2] = $79;
 $168 = (($localTriangle) + 116|0);
 HEAPF32[$168>>2] = $80;
 $169 = (($localTriangle) + 120|0);
 HEAPF32[$169>>2] = $81;
 $170 = (($localTriangle) + 124|0);
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = (($localTriangle) + 128|0);
 HEAPF32[$171>>2] = $97;
 $172 = (($localTriangle) + 132|0);
 HEAPF32[$172>>2] = $98;
 $173 = (($localTriangle) + 136|0);
 HEAPF32[$173>>2] = $99;
 $174 = (($localTriangle) + 140|0);
 HEAPF32[$174>>2] = Math_fround(0.0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 ;HEAP32[$146+0>>2]=HEAP32[$$sroa$113$i$i+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$$sroa$113$i$i+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$$sroa$113$i$i+8>>2]|0;
 HEAPF32[$147>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$148+0>>2]=HEAP32[$$sroa$1$i$i+0>>2]|0;HEAP32[$148+4>>2]=HEAP32[$$sroa$1$i$i+4>>2]|0;HEAP32[$148+8>>2]=HEAP32[$$sroa$1$i$i+8>>2]|0;
 $175 = (($zero$sroa$1$i$i$i) + 32|0);
 HEAP32[$175>>2] = $convexTransform;
 $176 = (($zero$sroa$1$i$i$i) + 36|0);
 HEAP32[$176>>2] = $identity;
 $177 = (($zero$sroa$1$i$i$i) + 40|0);
 HEAP32[$177>>2] = $identity;
 $178 = (($zero$sroa$1$i$i$i) + 44|0);
 HEAP8[$178>>0] = 1;
 HEAP32[$zero$sroa$1$i$i$i>>2] = ((554056 + 8|0));
 $179 = (($zero$sroa$1$i$i$i) + 48|0);
 HEAP32[$179>>2] = $localTriangle;
 (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration35generateTriangleFullContactManifoldERNS0_9TriangleVEjhRKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS2_EEPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERNSG_5Vec3VE($localTriangle,$triangleIndex,$triFlags,$polyData,$zero$sroa$1$i$i$i,$polyMap,$manifoldContacts,$numContacts,$inflation,$patchNormal)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu32PCMSphereVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($this,$verts,$triangleIndex,$triFlags,$vertInds) {
 $this = $this|0;
 $verts = $verts|0;
 $triangleIndex = $triangleIndex|0;
 $triFlags = $triFlags|0;
 $vertInds = $vertInds|0;
 var $$0 = 0, $$lobit$i = 0, $$lobit1$i = 0, $$lobit2$i = 0, $$lobit3$i = 0, $$lobit5$i = 0, $$lobit7$i = 0, $$not$i = 0, $$not1326$i = 0, $$not1329$i = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0);
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0);
 var $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0);
 var $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0);
 var $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0;
 var $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0;
 var $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge$i = 0, $brmerge1328$i = 0, $brmerge1331$i = 0, $dist$sroa$1 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond1316$i = 0, $or$cond1318$i = 0, $phitmp$i = 0, $phitmp1332$i = 0, $phitmp1333$i = 0, $phitmp1334$i = 0, $phitmp4$i = 0, $phitmp6$i = 0, $zeroV = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $zeroV = sp;
 $dist$sroa$1 = sp + 16|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $0 = Math_fround(HEAPF32[$verts>>2]);
 $1 = (($verts) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($verts) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($verts) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($verts) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($verts) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($verts) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($verts) + 28|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($verts) + 32|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($6 - $0);
 $18 = Math_fround($8 - $2);
 $19 = Math_fround($10 - $4);
 $20 = Math_fround($12 - $0);
 $21 = Math_fround($14 - $2);
 $22 = Math_fround($16 - $4);
 $23 = Math_fround($18 * $22);
 $24 = Math_fround($19 * $21);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($19 * $20);
 $27 = Math_fround($17 * $22);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($17 * $21);
 $30 = Math_fround($18 * $20);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround($25 * $25);
 $33 = Math_fround($28 * $28);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($31 * $31);
 $36 = Math_fround($35 + $34);
 $37 = (Math_fround(Math_sqrt((Math_fround($36)))));
 $38 = Math_fround(Math_fround(1.0) / $37);
 $39 = Math_fround($38 * $25);
 $40 = Math_fround($38 * $28);
 $41 = Math_fround($31 * $38);
 $42 = Math_fround($0 * $39);
 $43 = Math_fround($2 * $40);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($4 * $41);
 $46 = Math_fround($45 + $44);
 $47 = (($this) + 2336|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($this) + 2340|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($this) + 2344|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($48 * $39);
 $54 = Math_fround($50 * $40);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($41 * $52);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($57 - $46);
 $59 = $58 < Math_fround(0.0);
 if ($59) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $60 = Math_fround($12 - $6);
 $61 = Math_fround($14 - $8);
 $62 = Math_fround($16 - $10);
 $63 = Math_fround($48 - $0);
 $64 = Math_fround($50 - $2);
 $65 = Math_fround($52 - $4);
 $66 = Math_fround($48 - $6);
 $67 = Math_fround($50 - $8);
 $68 = Math_fround($52 - $10);
 $69 = Math_fround($48 - $12);
 $70 = Math_fround($50 - $14);
 $71 = Math_fround($52 - $16);
 $72 = Math_fround($17 * $63);
 $73 = Math_fround($18 * $64);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($19 * $65);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($20 * $63);
 $78 = Math_fround($21 * $64);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($22 * $65);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($17 * $66);
 $83 = Math_fround($18 * $67);
 $84 = Math_fround($82 + $83);
 $85 = Math_fround($19 * $68);
 $86 = Math_fround($84 + $85);
 $87 = Math_fround($20 * $66);
 $88 = Math_fround($21 * $67);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($22 * $68);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($17 * $69);
 $93 = Math_fround($18 * $70);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($19 * $71);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($20 * $69);
 $98 = Math_fround($21 * $70);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($22 * $71);
 $101 = Math_fround($99 + $100);
 $102 = Math_fround($91 - $86);
 $103 = Math_fround($96 - $101);
 $104 = $76 < Math_fround(0.0);
 $105 = $81 < Math_fround(0.0);
 $or$cond$i = $104 & $105;
 do {
  if ($or$cond$i) {
   $106 = $triFlags&255;
   $107 = $106 & 8;
   $108 = ($107|0)==(0);
   if ($108) {
    $109 = $106 >>> 5;
    $$lobit7$i = $109 & 1;
    $phitmp6$i = $$lobit7$i&255;
    $332 = $phitmp6$i;
   } else {
    $332 = 1;
   }
   $110 = Math_fround($63 * $63);
   $111 = Math_fround($64 * $64);
   $112 = Math_fround($110 + $111);
   $113 = Math_fround($65 * $65);
   $114 = Math_fround($112 + $113);
   $226 = $0;$228 = $2;$230 = $4;$244 = $114;$251 = $332;
  } else {
   $115 = !($86 >= Math_fround(0.0));
   $116 = !($86 >= $91);
   $or$cond1316$i = $115 | $116;
   if (!($or$cond1316$i)) {
    $117 = $triFlags&255;
    $118 = $117 & 8;
    $119 = ($118|0)==(0);
    if ($119) {
     $120 = $117 >>> 4;
     $$lobit5$i = $120 & 1;
     $phitmp4$i = $$lobit5$i&255;
     $333 = $phitmp4$i;
    } else {
     $333 = 1;
    }
    $121 = Math_fround($66 * $66);
    $122 = Math_fround($67 * $67);
    $123 = Math_fround($121 + $122);
    $124 = Math_fround($68 * $68);
    $125 = Math_fround($123 + $124);
    $226 = $6;$228 = $8;$230 = $10;$244 = $125;$251 = $333;
    break;
   }
   $126 = !($101 >= Math_fround(0.0));
   $127 = !($101 >= $96);
   $or$cond1318$i = $126 | $127;
   if (!($or$cond1318$i)) {
    $128 = $triFlags&255;
    $129 = $128 & 16;
    $130 = ($129|0)==(0);
    if ($130) {
     $131 = $128 >>> 5;
     $$lobit3$i = $131 & 1;
     $phitmp$i = $$lobit3$i&255;
     $334 = $phitmp$i;
    } else {
     $334 = 1;
    }
    $132 = Math_fround($69 * $69);
    $133 = Math_fround($70 * $70);
    $134 = Math_fround($132 + $133);
    $135 = Math_fround($71 * $71);
    $136 = Math_fround($134 + $135);
    $226 = $12;$228 = $14;$230 = $16;$244 = $136;$251 = $334;
    break;
   }
   $137 = Math_fround($76 * $91);
   $138 = Math_fround($86 * $81);
   $139 = Math_fround($137 - $138);
   $140 = !($76 >= Math_fround(0.0));
   if (!($140)) {
    $phitmp1332$i = !($86 < Math_fround(0.0));
    $$not$i = !($139 < Math_fround(0.0));
    $brmerge$i = $$not$i | $phitmp1332$i;
    if (!($brmerge$i)) {
     $141 = ($triFlags&255) >>> 3;
     $$lobit2$i = $141 & 1;
     $142 = Math_fround($76 - $86);
     $143 = Math_fround($76 / $142);
     $144 = Math_fround($17 * $143);
     $145 = Math_fround($18 * $143);
     $146 = Math_fround($19 * $143);
     $147 = Math_fround($0 + $144);
     $148 = Math_fround($2 + $145);
     $149 = Math_fround($4 + $146);
     $150 = Math_fround($48 - $147);
     $151 = Math_fround($50 - $148);
     $152 = Math_fround($52 - $149);
     $153 = Math_fround($150 * $150);
     $154 = Math_fround($151 * $151);
     $155 = Math_fround($153 + $154);
     $156 = Math_fround($152 * $152);
     $157 = Math_fround($155 + $156);
     $226 = $147;$228 = $148;$230 = $149;$244 = $157;$251 = $$lobit2$i;
     break;
    }
   }
   $158 = Math_fround($86 * $101);
   $159 = Math_fround($96 * $91);
   $160 = Math_fround($158 - $159);
   $161 = !($91 >= $86);
   if (!($161)) {
    $phitmp1333$i = !($96 >= $101);
    $$not1326$i = !($160 < Math_fround(0.0));
    $brmerge1328$i = $$not1326$i | $phitmp1333$i;
    if (!($brmerge1328$i)) {
     $162 = ($triFlags&255) >>> 4;
     $$lobit1$i = $162 & 1;
     $163 = Math_fround($102 + $103);
     $164 = Math_fround($102 / $163);
     $165 = Math_fround($60 * $164);
     $166 = Math_fround($61 * $164);
     $167 = Math_fround($62 * $164);
     $168 = Math_fround($6 + $165);
     $169 = Math_fround($8 + $166);
     $170 = Math_fround($10 + $167);
     $171 = Math_fround($48 - $168);
     $172 = Math_fround($50 - $169);
     $173 = Math_fround($52 - $170);
     $174 = Math_fround($171 * $171);
     $175 = Math_fround($172 * $172);
     $176 = Math_fround($174 + $175);
     $177 = Math_fround($173 * $173);
     $178 = Math_fround($176 + $177);
     $226 = $168;$228 = $169;$230 = $170;$244 = $178;$251 = $$lobit1$i;
     break;
    }
   }
   $179 = Math_fround($96 * $81);
   $180 = Math_fround($76 * $101);
   $181 = Math_fround($179 - $180);
   $182 = !($81 >= Math_fround(0.0));
   if (!($182)) {
    $phitmp1334$i = !($101 < Math_fround(0.0));
    $$not1329$i = !($181 < Math_fround(0.0));
    $brmerge1331$i = $$not1329$i | $phitmp1334$i;
    if (!($brmerge1331$i)) {
     $183 = ($triFlags&255) >>> 5;
     $$lobit$i = $183 & 1;
     $184 = Math_fround($81 - $101);
     $185 = Math_fround($81 / $184);
     $186 = Math_fround($20 * $185);
     $187 = Math_fround($21 * $185);
     $188 = Math_fround($22 * $185);
     $189 = Math_fround($0 + $186);
     $190 = Math_fround($2 + $187);
     $191 = Math_fround($4 + $188);
     $192 = Math_fround($48 - $189);
     $193 = Math_fround($50 - $190);
     $194 = Math_fround($52 - $191);
     $195 = Math_fround($192 * $192);
     $196 = Math_fround($193 * $193);
     $197 = Math_fround($195 + $196);
     $198 = Math_fround($194 * $194);
     $199 = Math_fround($197 + $198);
     $226 = $189;$228 = $190;$230 = $191;$244 = $199;$251 = $$lobit$i;
     break;
    }
   }
   $200 = Math_fround($181 + $139);
   $201 = Math_fround($160 + $200);
   $202 = Math_fround(Math_fround(1.0) / $201);
   $203 = Math_fround($181 * $202);
   $204 = Math_fround($139 * $202);
   $205 = Math_fround($20 * $204);
   $206 = Math_fround($21 * $204);
   $207 = Math_fround($22 * $204);
   $208 = Math_fround($17 * $203);
   $209 = Math_fround($18 * $203);
   $210 = Math_fround($19 * $203);
   $211 = Math_fround($208 + $205);
   $212 = Math_fround($209 + $206);
   $213 = Math_fround($210 + $207);
   $214 = Math_fround($0 + $211);
   $215 = Math_fround($2 + $212);
   $216 = Math_fround($4 + $213);
   $217 = Math_fround($48 - $214);
   $218 = Math_fround($50 - $215);
   $219 = Math_fround($52 - $216);
   $220 = Math_fround($217 * $217);
   $221 = Math_fround($218 * $218);
   $222 = Math_fround($220 + $221);
   $223 = Math_fround($219 * $219);
   $224 = Math_fround($223 + $222);
   $226 = $214;$228 = $215;$230 = $216;$244 = $224;$251 = 1;
  }
 } while(0);
 $225 = Math_fround($48 - $226);
 $227 = Math_fround($50 - $228);
 $229 = Math_fround($52 - $230);
 $231 = Math_fround($225 * $225);
 $232 = Math_fround($227 * $227);
 $233 = Math_fround($231 + $232);
 $234 = Math_fround($229 * $229);
 $235 = Math_fround($233 + $234);
 $236 = (Math_fround(Math_sqrt((Math_fround($235)))));
 $237 = Math_fround(Math_fround(1.0) / $236);
 $238 = Math_fround($225 * $237);
 $239 = Math_fround($227 * $237);
 $240 = Math_fround($229 * $237);
 $241 = (($this) + 2368|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 $243 = $242 > $244;
 if (!($243)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $245 = Math_fround($40 * $239);
 $246 = Math_fround($39 * $238);
 $247 = Math_fround($41 * $240);
 $248 = Math_fround($246 + $245);
 $249 = Math_fround($247 + $248);
 $250 = ($251<<24>>24)!=(0);
 $252 = $249 > Math_fround(0.995999991893768310546);
 $or$cond = $250 | $252;
 if (!($or$cond)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $253 = (Math_fround(Math_sqrt((Math_fround($244)))));
 $254 = (($this) + 2328|0);
 $255 = HEAP32[$254>>2]|0;
 $256 = ($255|0)==(0);
 if ($256) {
  label = 30;
 } else {
  $257 = (($255) + -1)|0;
  $258 = (($this) + ($257<<6)|0);
  $259 = Math_fround(HEAPF32[$258>>2]);
  $260 = ((($this) + ($257<<6)|0) + 4|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = ((($this) + ($257<<6)|0) + 8|0);
  $263 = Math_fround(HEAPF32[$262>>2]);
  $264 = Math_fround($238 * $259);
  $265 = Math_fround($239 * $261);
  $266 = Math_fround($264 + $265);
  $267 = Math_fround($240 * $263);
  $268 = Math_fround($266 + $267);
  $269 = (($this) + 2224|0);
  $270 = Math_fround(HEAPF32[$269>>2]);
  $271 = $268 > $270;
  if ($271) {
   $272 = ((($this) + ($257<<6)|0) + 32|0);
   $273 = Math_fround(HEAPF32[$272>>2]);
   $274 = $273 > $253;
   if ($274) {
    $275 = ((($this) + ($257<<6)|0) + 36|0);
    $276 = ((($this) + ($257<<6)|0) + 48|0);
    $277 = HEAP32[$276>>2]|0;
    $278 = (($this) + 2320|0);
    $279 = HEAP32[$278>>2]|0;
    $280 = (($279) + ($277<<6)|0);
    ;HEAP32[$280+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$280+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$280+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$280+12>>2]=HEAP32[$zeroV+12>>2]|0;
    $281 = HEAP32[$276>>2]|0;
    $282 = HEAP32[$278>>2]|0;
    $283 = ((($282) + ($281<<6)|0) + 16|0);
    HEAPF32[$283>>2] = $226;
    $284 = ((($282) + ($281<<6)|0) + 20|0);
    HEAPF32[$284>>2] = $228;
    $285 = ((($282) + ($281<<6)|0) + 24|0);
    HEAPF32[$285>>2] = $230;
    $286 = ((($282) + ($281<<6)|0) + 28|0);
    HEAPF32[$286>>2] = Math_fround(0.0);
    $287 = HEAP32[$276>>2]|0;
    $288 = HEAP32[$278>>2]|0;
    $289 = ((($288) + ($287<<6)|0) + 32|0);
    HEAPF32[$289>>2] = $238;
    $290 = ((($288) + ($287<<6)|0) + 36|0);
    HEAPF32[$290>>2] = $239;
    $291 = ((($288) + ($287<<6)|0) + 40|0);
    HEAPF32[$291>>2] = $240;
    $292 = ((($288) + ($287<<6)|0) + 44|0);
    HEAPF32[$292>>2] = $253;
    $293 = HEAP32[$276>>2]|0;
    $294 = HEAP32[$278>>2]|0;
    $295 = ((($294) + ($293<<6)|0) + 48|0);
    HEAP32[$295>>2] = $triangleIndex;
    HEAPF32[$272>>2] = $253;
    ;HEAP32[$275+0>>2]=HEAP32[$dist$sroa$1+0>>2]|0;HEAP32[$275+4>>2]=HEAP32[$dist$sroa$1+4>>2]|0;HEAP32[$275+8>>2]=HEAP32[$dist$sroa$1+8>>2]|0;
   }
  } else {
   label = 30;
  }
 }
 if ((label|0) == 30) {
  $296 = (($this) + 2324|0);
  $297 = HEAP32[$296>>2]|0;
  $298 = (($this) + 2320|0);
  $299 = HEAP32[$298>>2]|0;
  $300 = (($299) + ($297<<6)|0);
  ;HEAP32[$300+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$300+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$300+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$300+12>>2]=HEAP32[$zeroV+12>>2]|0;
  $301 = HEAP32[$296>>2]|0;
  $302 = HEAP32[$298>>2]|0;
  $303 = ((($302) + ($301<<6)|0) + 16|0);
  HEAPF32[$303>>2] = $226;
  $304 = ((($302) + ($301<<6)|0) + 20|0);
  HEAPF32[$304>>2] = $228;
  $305 = ((($302) + ($301<<6)|0) + 24|0);
  HEAPF32[$305>>2] = $230;
  $306 = ((($302) + ($301<<6)|0) + 28|0);
  HEAPF32[$306>>2] = Math_fround(0.0);
  $307 = HEAP32[$296>>2]|0;
  $308 = HEAP32[$298>>2]|0;
  $309 = ((($308) + ($307<<6)|0) + 32|0);
  HEAPF32[$309>>2] = $238;
  $310 = ((($308) + ($307<<6)|0) + 36|0);
  HEAPF32[$310>>2] = $239;
  $311 = ((($308) + ($307<<6)|0) + 40|0);
  HEAPF32[$311>>2] = $240;
  $312 = ((($308) + ($307<<6)|0) + 44|0);
  HEAPF32[$312>>2] = $253;
  $313 = HEAP32[$296>>2]|0;
  $314 = (($313) + 1)|0;
  HEAP32[$296>>2] = $314;
  $315 = HEAP32[$298>>2]|0;
  $316 = ((($315) + ($313<<6)|0) + 48|0);
  HEAP32[$316>>2] = $triangleIndex;
  $317 = HEAP32[$296>>2]|0;
  $318 = (($317) + -1)|0;
  $319 = HEAP32[$254>>2]|0;
  $320 = ((($this) + ($319<<6)|0) + 48|0);
  HEAP32[$320>>2] = $318;
  $321 = ((($this) + ($319<<6)|0) + 52|0);
  HEAP32[$321>>2] = $317;
  $322 = ((($this) + ($319<<6)|0) + 32|0);
  HEAPF32[$322>>2] = $253;
  $323 = ((($this) + ($319<<6)|0) + 36|0);
  ;HEAP32[$323+0>>2]=HEAP32[$dist$sroa$1+0>>2]|0;HEAP32[$323+4>>2]=HEAP32[$dist$sroa$1+4>>2]|0;HEAP32[$323+8>>2]=HEAP32[$dist$sroa$1+8>>2]|0;
  $324 = (($319) + 1)|0;
  HEAP32[$254>>2] = $324;
  $325 = (($this) + ($319<<6)|0);
  HEAPF32[$325>>2] = $238;
  $326 = ((($this) + ($319<<6)|0) + 4|0);
  HEAPF32[$326>>2] = $239;
  $327 = ((($this) + ($319<<6)|0) + 8|0);
  HEAPF32[$327>>2] = $240;
  $328 = ((($this) + ($319<<6)|0) + 12|0);
  HEAPF32[$328>>2] = Math_fround(0.0);
 }
 $329 = (($this) + 2324|0);
 $330 = HEAP32[$329>>2]|0;
 $331 = ($330>>>0)>(15);
 if (!($331)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx2Gu24PCMMeshContactGeneration15processContactsEhb($this,1,1);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration10generateEEERKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES6_jS6_S6_PNS0_21MeshPersistentContactERj($this,$p,$q,$sqInflatedRadius,$normal,$triangleIndex,$a,$b,$manifoldContacts,$numContacts) {
 $this = $this|0;
 $p = $p|0;
 $q = $q|0;
 $sqInflatedRadius = $sqInflatedRadius|0;
 $normal = $normal|0;
 $triangleIndex = $triangleIndex|0;
 $a = $a|0;
 $b = $b|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($b) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($b) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$a>>2]);
 $6 = (($a) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($a) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($0 - $5);
 $11 = Math_fround($2 - $7);
 $12 = Math_fround($4 - $9);
 $13 = Math_fround(HEAPF32[$normal>>2]);
 $14 = (($normal) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($normal) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($11 * $17);
 $19 = Math_fround($12 * $15);
 $20 = Math_fround($18 - $19);
 $21 = Math_fround($12 * $13);
 $22 = Math_fround($10 * $17);
 $23 = Math_fround($21 - $22);
 $24 = Math_fround($10 * $15);
 $25 = Math_fround($11 * $13);
 $26 = Math_fround($24 - $25);
 $27 = Math_fround($5 * $20);
 $28 = Math_fround($7 * $23);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($9 * $26);
 $31 = Math_fround($30 + $29);
 $32 = Math_fround(HEAPF32[$p>>2]);
 $33 = (($p) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($p) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($32 * $20);
 $38 = Math_fround($23 * $34);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($26 * $36);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround(HEAPF32[$q>>2]);
 $43 = (($q) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($q) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($20 * $42);
 $48 = Math_fround($23 * $44);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($26 * $46);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($41 - $31);
 $53 = Math_fround($51 - $31);
 $54 = Math_fround($52 * $53);
 $55 = $54 > Math_fround(0.0);
 if ($55) {
  STACKTOP = sp;return;
 }
 $56 = Math_fround($42 - $32);
 $57 = Math_fround($44 - $34);
 $58 = Math_fround($46 - $36);
 $59 = Math_fround($20 * $56);
 $60 = Math_fround($23 * $57);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($26 * $58);
 $63 = Math_fround($61 + $62);
 $64 = $63 == Math_fround(0.0);
 if ($64) {
  STACKTOP = sp;return;
 }
 $65 = Math_fround($31 - $41);
 $66 = Math_fround($65 / $63);
 $67 = Math_fround($56 * $66);
 $68 = Math_fround($57 * $66);
 $69 = Math_fround($58 * $66);
 $70 = Math_fround($67 + $32);
 $71 = Math_fround($68 + $34);
 $72 = Math_fround($69 + $36);
 $73 = Math_fround($58 * $15);
 $74 = Math_fround($57 * $17);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($56 * $17);
 $77 = Math_fround($58 * $13);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($57 * $13);
 $80 = Math_fround($56 * $15);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($70 - $5);
 $83 = Math_fround($71 - $7);
 $84 = Math_fround($72 - $9);
 $85 = Math_fround($75 * $82);
 $86 = Math_fround($78 * $83);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($81 * $84);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($10 * $75);
 $91 = Math_fround($11 * $78);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($12 * $81);
 $94 = Math_fround($93 + $92);
 $95 = Math_fround($89 / $94);
 $96 = !($95 <= Math_fround(1.0));
 if ($96) {
  STACKTOP = sp;return;
 }
 $97 = !($95 >= Math_fround(0.0));
 if ($97) {
  STACKTOP = sp;return;
 }
 $98 = Math_fround($10 * $95);
 $99 = Math_fround($11 * $95);
 $100 = Math_fround($12 * $95);
 $101 = Math_fround($82 - $98);
 $102 = Math_fround($83 - $99);
 $103 = Math_fround($84 - $100);
 $104 = Math_fround($101 * $101);
 $105 = Math_fround($102 * $102);
 $106 = Math_fround($104 + $105);
 $107 = Math_fround($103 * $103);
 $108 = Math_fround($107 + $106);
 $109 = Math_fround(HEAPF32[$sqInflatedRadius>>2]);
 $110 = $109 > $108;
 if (!($110)) {
  STACKTOP = sp;return;
 }
 $111 = Math_fround($70 - $101);
 $112 = Math_fround($71 - $102);
 $113 = Math_fround($72 - $103);
 $114 = Math_fround($101 * $13);
 $115 = Math_fround($102 * $15);
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($103 * $17);
 $118 = Math_fround($116 + $117);
 $119 = HEAP32[$numContacts>>2]|0;
 $120 = (($manifoldContacts) + ($119<<6)|0);
 HEAPF32[$120>>2] = $70;
 $121 = ((($manifoldContacts) + ($119<<6)|0) + 4|0);
 HEAPF32[$121>>2] = $71;
 $122 = ((($manifoldContacts) + ($119<<6)|0) + 8|0);
 HEAPF32[$122>>2] = $72;
 $123 = ((($manifoldContacts) + ($119<<6)|0) + 12|0);
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = HEAP32[$numContacts>>2]|0;
 $125 = ((($manifoldContacts) + ($124<<6)|0) + 16|0);
 HEAPF32[$125>>2] = $111;
 $126 = ((($manifoldContacts) + ($124<<6)|0) + 20|0);
 HEAPF32[$126>>2] = $112;
 $127 = ((($manifoldContacts) + ($124<<6)|0) + 24|0);
 HEAPF32[$127>>2] = $113;
 $128 = ((($manifoldContacts) + ($124<<6)|0) + 28|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 $129 = HEAP32[$numContacts>>2]|0;
 $130 = Math_fround(HEAPF32[$normal>>2]);
 $131 = Math_fround(HEAPF32[$14>>2]);
 $132 = Math_fround(HEAPF32[$16>>2]);
 $133 = ((($manifoldContacts) + ($129<<6)|0) + 32|0);
 HEAPF32[$133>>2] = $130;
 $134 = ((($manifoldContacts) + ($129<<6)|0) + 36|0);
 HEAPF32[$134>>2] = $131;
 $135 = ((($manifoldContacts) + ($129<<6)|0) + 40|0);
 HEAPF32[$135>>2] = $132;
 $136 = ((($manifoldContacts) + ($129<<6)|0) + 44|0);
 HEAPF32[$136>>2] = $118;
 $137 = HEAP32[$numContacts>>2]|0;
 $138 = (($137) + 1)|0;
 HEAP32[$numContacts>>2] = $138;
 $139 = ((($manifoldContacts) + ($137<<6)|0) + 48|0);
 HEAP32[$139>>2] = $triangleIndex;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration13generateEEMTDERKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES6_jS6_S6_PNS0_21MeshPersistentContactERj($p,$q,$inflatedRadius,$normal,$triangleIndex,$a,$b,$manifoldContacts,$numContacts) {
 $p = $p|0;
 $q = $q|0;
 $inflatedRadius = $inflatedRadius|0;
 $normal = $normal|0;
 $triangleIndex = $triangleIndex|0;
 $a = $a|0;
 $b = $b|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 var $$$i$i = Math_fround(0), $$$i8$i = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($b) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($b) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$a>>2]);
 $6 = (($a) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($a) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($0 - $5);
 $11 = Math_fround($2 - $7);
 $12 = Math_fround($4 - $9);
 $13 = Math_fround(HEAPF32[$normal>>2]);
 $14 = (($normal) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($normal) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($11 * $17);
 $19 = Math_fround($12 * $15);
 $20 = Math_fround($18 - $19);
 $21 = Math_fround($12 * $13);
 $22 = Math_fround($10 * $17);
 $23 = Math_fround($21 - $22);
 $24 = Math_fround($10 * $15);
 $25 = Math_fround($11 * $13);
 $26 = Math_fround($24 - $25);
 $27 = Math_fround($5 * $20);
 $28 = Math_fround($7 * $23);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($9 * $26);
 $31 = Math_fround($30 + $29);
 $32 = Math_fround(HEAPF32[$p>>2]);
 $33 = (($p) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($p) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($32 * $20);
 $38 = Math_fround($23 * $34);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($26 * $36);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround(HEAPF32[$q>>2]);
 $43 = (($q) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($q) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($20 * $42);
 $48 = Math_fround($23 * $44);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($26 * $46);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($41 - $31);
 $53 = Math_fround($51 - $31);
 $54 = Math_fround($52 * $53);
 $55 = $54 > Math_fround(0.0);
 if ($55) {
  STACKTOP = sp;return;
 }
 $56 = Math_fround($42 - $32);
 $57 = Math_fround($44 - $34);
 $58 = Math_fround($46 - $36);
 $59 = Math_fround($20 * $56);
 $60 = Math_fround($23 * $57);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($26 * $58);
 $63 = Math_fround($61 + $62);
 $64 = $63 == Math_fround(0.0);
 if ($64) {
  STACKTOP = sp;return;
 }
 $65 = Math_fround($31 - $41);
 $66 = Math_fround($65 / $63);
 $67 = Math_fround($56 * $66);
 $68 = Math_fround($57 * $66);
 $69 = Math_fround($58 * $66);
 $70 = Math_fround($67 + $32);
 $71 = Math_fround($68 + $34);
 $72 = Math_fround($69 + $36);
 $73 = Math_fround($58 * $15);
 $74 = Math_fround($57 * $17);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($56 * $17);
 $77 = Math_fround($58 * $13);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($57 * $13);
 $80 = Math_fround($56 * $15);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($70 - $5);
 $83 = Math_fround($71 - $7);
 $84 = Math_fround($72 - $9);
 $85 = Math_fround($75 * $82);
 $86 = Math_fround($78 * $83);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($81 * $84);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($10 * $75);
 $91 = Math_fround($11 * $78);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($12 * $81);
 $94 = Math_fround($93 + $92);
 $95 = Math_fround($89 / $94);
 $96 = $95 > Math_fround(1.0);
 $$$i$i = $96 ? Math_fround(1.0) : $95;
 $97 = $$$i$i > Math_fround(0.0);
 $$$i8$i = $97 ? $$$i$i : Math_fround(0.0);
 $98 = Math_fround($10 * $$$i8$i);
 $99 = Math_fround($11 * $$$i8$i);
 $100 = Math_fround($12 * $$$i8$i);
 $101 = Math_fround($82 - $98);
 $102 = Math_fround($83 - $99);
 $103 = Math_fround($84 - $100);
 $104 = Math_fround($13 * $101);
 $105 = Math_fround($15 * $102);
 $106 = Math_fround($104 + $105);
 $107 = Math_fround($17 * $103);
 $108 = Math_fround($107 + $106);
 $109 = Math_fround(HEAPF32[$inflatedRadius>>2]);
 $110 = $109 > $108;
 if (!($110)) {
  STACKTOP = sp;return;
 }
 $111 = Math_fround($70 - $101);
 $112 = Math_fround($71 - $102);
 $113 = Math_fround($72 - $103);
 $114 = HEAP32[$numContacts>>2]|0;
 $115 = (($manifoldContacts) + ($114<<6)|0);
 HEAPF32[$115>>2] = $70;
 $116 = ((($manifoldContacts) + ($114<<6)|0) + 4|0);
 HEAPF32[$116>>2] = $71;
 $117 = ((($manifoldContacts) + ($114<<6)|0) + 8|0);
 HEAPF32[$117>>2] = $72;
 $118 = ((($manifoldContacts) + ($114<<6)|0) + 12|0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 $119 = HEAP32[$numContacts>>2]|0;
 $120 = ((($manifoldContacts) + ($119<<6)|0) + 16|0);
 HEAPF32[$120>>2] = $111;
 $121 = ((($manifoldContacts) + ($119<<6)|0) + 20|0);
 HEAPF32[$121>>2] = $112;
 $122 = ((($manifoldContacts) + ($119<<6)|0) + 24|0);
 HEAPF32[$122>>2] = $113;
 $123 = ((($manifoldContacts) + ($119<<6)|0) + 28|0);
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = HEAP32[$numContacts>>2]|0;
 $125 = Math_fround(HEAPF32[$normal>>2]);
 $126 = Math_fround(HEAPF32[$14>>2]);
 $127 = Math_fround(HEAPF32[$16>>2]);
 $128 = ((($manifoldContacts) + ($124<<6)|0) + 32|0);
 HEAPF32[$128>>2] = $125;
 $129 = ((($manifoldContacts) + ($124<<6)|0) + 36|0);
 HEAPF32[$129>>2] = $126;
 $130 = ((($manifoldContacts) + ($124<<6)|0) + 40|0);
 HEAPF32[$130>>2] = $127;
 $131 = ((($manifoldContacts) + ($124<<6)|0) + 44|0);
 HEAPF32[$131>>2] = $108;
 $132 = HEAP32[$numContacts>>2]|0;
 $133 = (($132) + 1)|0;
 HEAP32[$numContacts>>2] = $133;
 $134 = ((($manifoldContacts) + ($132<<6)|0) + 48|0);
 HEAP32[$134>>2] = $triangleIndex;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration16generateContactsERKNS_6shdfnd3aos5Vec3VES6_S6_S6_S6_jS6_S6_RKNS3_6FloatVEPNS0_21MeshPersistentContactERj($a,$b,$c,$planeNormal,$normal,$triangleIndex,$p,$q,$inflatedRadius,$manifoldContacts,$numContacts) {
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $planeNormal = $planeNormal|0;
 $normal = $normal|0;
 $triangleIndex = $triangleIndex|0;
 $p = $p|0;
 $q = $q|0;
 $inflatedRadius = $inflatedRadius|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 var $$$$i = 0, $$$$i101 = 0, $$$i = 0, $$$i100 = 0, $$pre = Math_fround(0), $$pre856 = Math_fround(0), $$pre857 = Math_fround(0), $$pre858 = Math_fround(0), $$pre859 = Math_fround(0), $$pre860 = Math_fround(0), $$pre861 = Math_fround(0), $$pre862 = Math_fround(0), $$pre863 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0);
 var $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0;
 var $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0;
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $closestP30 = 0, $closestP40 = 0, $not$$i = 0, $not$$i98 = 0, $not$169$i = 0, $not$169$i99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $closestP30 = sp + 16|0;
 $closestP40 = sp;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($b) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($b) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$a>>2]);
 $6 = (($a) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($a) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($0 - $5);
 $11 = Math_fround($2 - $7);
 $12 = Math_fround($4 - $9);
 $13 = Math_fround(HEAPF32[$c>>2]);
 $14 = (($c) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($c) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($13 - $5);
 $19 = Math_fround($15 - $7);
 $20 = Math_fround($17 - $9);
 $21 = Math_fround(HEAPF32[$p>>2]);
 $22 = (($p) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($p) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($21 - $5);
 $27 = Math_fround($23 - $7);
 $28 = Math_fround($25 - $9);
 $29 = Math_fround(HEAPF32[$q>>2]);
 $30 = (($q) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($q) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($29 - $5);
 $35 = Math_fround($31 - $7);
 $36 = Math_fround($33 - $9);
 $37 = Math_fround($10 * $10);
 $38 = Math_fround($11 * $11);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($12 * $12);
 $41 = Math_fround($39 + $40);
 $42 = Math_fround($10 * $18);
 $43 = Math_fround($11 * $19);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($12 * $20);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($18 * $18);
 $48 = Math_fround($19 * $19);
 $49 = Math_fround($47 + $48);
 $50 = Math_fround($20 * $20);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($41 * $51);
 $53 = Math_fround($46 * $46);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround(Math_fround(1.0) / $54);
 $56 = Math_fround(HEAPF32[$planeNormal>>2]);
 $57 = (($planeNormal) + 4|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($planeNormal) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($26 * $56);
 $62 = Math_fround($27 * $58);
 $63 = Math_fround(-$62);
 $64 = Math_fround($63 - $61);
 $65 = Math_fround($28 * $60);
 $66 = Math_fround($64 - $65);
 $67 = Math_fround(HEAPF32[$normal>>2]);
 $68 = (($normal) + 4|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($normal) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($56 * $67);
 $73 = Math_fround($58 * $69);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($60 * $71);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($66 / $76);
 $78 = Math_fround($77 * $67);
 $79 = Math_fround($77 * $69);
 $80 = Math_fround($77 * $71);
 $81 = Math_fround($78 + $21);
 $82 = Math_fround($79 + $23);
 $83 = Math_fround($80 + $25);
 ;HEAP32[$closestP30+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$closestP30+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$closestP30+8>>2]=HEAP32[$p+8>>2]|0;HEAP32[$closestP30+12>>2]=HEAP32[$p+12>>2]|0;
 $84 = Math_fround($81 - $5);
 $85 = Math_fround($82 - $7);
 $86 = Math_fround($83 - $9);
 $87 = Math_fround($10 * $84);
 $88 = Math_fround($11 * $85);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($12 * $86);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($18 * $84);
 $93 = Math_fround($19 * $85);
 $94 = Math_fround($92 + $93);
 $95 = Math_fround($20 * $86);
 $96 = Math_fround($94 + $95);
 $97 = Math_fround($51 * $91);
 $98 = Math_fround($46 * $96);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($55 * $99);
 $101 = Math_fround($41 * $96);
 $102 = Math_fround($46 * $91);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($55 * $103);
 $105 = $100 <= Math_fround(1.0);
 $not$$i98 = $100 >= Math_fround(0.0);
 $106 = $105 & $not$$i98;
 $107 = $104 <= Math_fround(1.0);
 $not$169$i99 = $104 >= Math_fround(0.0);
 $108 = $107 & $not$169$i99;
 $109 = Math_fround($100 + $104);
 $110 = $109 < Math_fround(1.0);
 $$$i100 = $110 & $108;
 $$$$i101 = $$$i100 & $106;
 if ($$$$i101) {
  $111 = Math_fround($61 + $62);
  $112 = Math_fround(HEAPF32[$inflatedRadius>>2]);
  $113 = Math_fround($111 + $65);
  $114 = $112 > $113;
  if ($114) {
   $115 = HEAP32[$numContacts>>2]|0;
   $116 = (($manifoldContacts) + ($115<<6)|0);
   ;HEAP32[$116+0>>2]=HEAP32[$closestP30+0>>2]|0;HEAP32[$116+4>>2]=HEAP32[$closestP30+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[$closestP30+8>>2]|0;HEAP32[$116+12>>2]=HEAP32[$closestP30+12>>2]|0;
   $117 = HEAP32[$numContacts>>2]|0;
   $118 = ((($manifoldContacts) + ($117<<6)|0) + 16|0);
   HEAPF32[$118>>2] = $81;
   $119 = ((($manifoldContacts) + ($117<<6)|0) + 20|0);
   HEAPF32[$119>>2] = $82;
   $120 = ((($manifoldContacts) + ($117<<6)|0) + 24|0);
   HEAPF32[$120>>2] = $83;
   $121 = ((($manifoldContacts) + ($117<<6)|0) + 28|0);
   HEAPF32[$121>>2] = Math_fround(0.0);
   $122 = HEAP32[$numContacts>>2]|0;
   $123 = Math_fround(HEAPF32[$normal>>2]);
   $124 = Math_fround(HEAPF32[$68>>2]);
   $125 = Math_fround(HEAPF32[$70>>2]);
   $126 = Math_fround(-$77);
   $127 = ((($manifoldContacts) + ($122<<6)|0) + 32|0);
   HEAPF32[$127>>2] = $123;
   $128 = ((($manifoldContacts) + ($122<<6)|0) + 36|0);
   HEAPF32[$128>>2] = $124;
   $129 = ((($manifoldContacts) + ($122<<6)|0) + 40|0);
   HEAPF32[$129>>2] = $125;
   $130 = ((($manifoldContacts) + ($122<<6)|0) + 44|0);
   HEAPF32[$130>>2] = $126;
   $131 = HEAP32[$numContacts>>2]|0;
   $132 = (($131) + 1)|0;
   HEAP32[$numContacts>>2] = $132;
   $133 = ((($manifoldContacts) + ($131<<6)|0) + 48|0);
   HEAP32[$133>>2] = $triangleIndex;
   $$pre = Math_fround(HEAPF32[$planeNormal>>2]);
   $$pre856 = Math_fround(HEAPF32[$57>>2]);
   $$pre857 = Math_fround(HEAPF32[$59>>2]);
   $$pre858 = Math_fround(HEAPF32[$normal>>2]);
   $$pre859 = Math_fround(HEAPF32[$68>>2]);
   $$pre860 = Math_fround(HEAPF32[$70>>2]);
   $$pre861 = Math_fround(HEAPF32[$q>>2]);
   $$pre862 = Math_fround(HEAPF32[$30>>2]);
   $$pre863 = Math_fround(HEAPF32[$32>>2]);
   $135 = $$pre;$137 = $$pre856;$141 = $$pre857;$145 = $$pre858;$147 = $$pre859;$149 = $$pre860;$151 = $$pre861;$153 = $$pre862;$155 = $$pre863;
  } else {
   $135 = $56;$137 = $58;$141 = $60;$145 = $67;$147 = $69;$149 = $71;$151 = $29;$153 = $31;$155 = $33;
  }
 } else {
  $135 = $56;$137 = $58;$141 = $60;$145 = $67;$147 = $69;$149 = $71;$151 = $29;$153 = $31;$155 = $33;
 }
 $134 = Math_fround($34 * $135);
 $136 = Math_fround($35 * $137);
 $138 = Math_fround(-$136);
 $139 = Math_fround($138 - $134);
 $140 = Math_fround($36 * $141);
 $142 = Math_fround($139 - $140);
 $143 = Math_fround($142 / $76);
 $144 = Math_fround($143 * $145);
 $146 = Math_fround($143 * $147);
 $148 = Math_fround($143 * $149);
 $150 = Math_fround($144 + $151);
 $152 = Math_fround($146 + $153);
 $154 = Math_fround($148 + $155);
 ;HEAP32[$closestP40+0>>2]=HEAP32[$q+0>>2]|0;HEAP32[$closestP40+4>>2]=HEAP32[$q+4>>2]|0;HEAP32[$closestP40+8>>2]=HEAP32[$q+8>>2]|0;HEAP32[$closestP40+12>>2]=HEAP32[$q+12>>2]|0;
 $156 = Math_fround(HEAPF32[$a>>2]);
 $157 = Math_fround(HEAPF32[$6>>2]);
 $158 = Math_fround(HEAPF32[$8>>2]);
 $159 = Math_fround($150 - $156);
 $160 = Math_fround($152 - $157);
 $161 = Math_fround($154 - $158);
 $162 = Math_fround($10 * $159);
 $163 = Math_fround($11 * $160);
 $164 = Math_fround($162 + $163);
 $165 = Math_fround($12 * $161);
 $166 = Math_fround($164 + $165);
 $167 = Math_fround($18 * $159);
 $168 = Math_fround($19 * $160);
 $169 = Math_fround($167 + $168);
 $170 = Math_fround($20 * $161);
 $171 = Math_fround($169 + $170);
 $172 = Math_fround($51 * $166);
 $173 = Math_fround($46 * $171);
 $174 = Math_fround($172 - $173);
 $175 = Math_fround($55 * $174);
 $176 = Math_fround($41 * $171);
 $177 = Math_fround($46 * $166);
 $178 = Math_fround($176 - $177);
 $179 = Math_fround($55 * $178);
 $180 = $175 <= Math_fround(1.0);
 $not$$i = $175 >= Math_fround(0.0);
 $181 = $180 & $not$$i;
 $182 = $179 <= Math_fround(1.0);
 $not$169$i = $179 >= Math_fround(0.0);
 $183 = $182 & $not$169$i;
 $184 = Math_fround($175 + $179);
 $185 = $184 < Math_fround(1.0);
 $$$i = $185 & $183;
 $$$$i = $$$i & $181;
 if (!($$$$i)) {
  STACKTOP = sp;return 0;
 }
 $186 = Math_fround($134 + $136);
 $187 = Math_fround(HEAPF32[$inflatedRadius>>2]);
 $188 = Math_fround($186 + $140);
 $189 = $187 > $188;
 if (!($189)) {
  STACKTOP = sp;return 0;
 }
 $190 = HEAP32[$numContacts>>2]|0;
 $191 = (($manifoldContacts) + ($190<<6)|0);
 ;HEAP32[$191+0>>2]=HEAP32[$closestP40+0>>2]|0;HEAP32[$191+4>>2]=HEAP32[$closestP40+4>>2]|0;HEAP32[$191+8>>2]=HEAP32[$closestP40+8>>2]|0;HEAP32[$191+12>>2]=HEAP32[$closestP40+12>>2]|0;
 $192 = HEAP32[$numContacts>>2]|0;
 $193 = ((($manifoldContacts) + ($192<<6)|0) + 16|0);
 HEAPF32[$193>>2] = $150;
 $194 = ((($manifoldContacts) + ($192<<6)|0) + 20|0);
 HEAPF32[$194>>2] = $152;
 $195 = ((($manifoldContacts) + ($192<<6)|0) + 24|0);
 HEAPF32[$195>>2] = $154;
 $196 = ((($manifoldContacts) + ($192<<6)|0) + 28|0);
 HEAPF32[$196>>2] = Math_fround(0.0);
 $197 = HEAP32[$numContacts>>2]|0;
 $198 = Math_fround(HEAPF32[$normal>>2]);
 $199 = Math_fround(HEAPF32[$68>>2]);
 $200 = Math_fround(HEAPF32[$70>>2]);
 $201 = Math_fround(-$143);
 $202 = ((($manifoldContacts) + ($197<<6)|0) + 32|0);
 HEAPF32[$202>>2] = $198;
 $203 = ((($manifoldContacts) + ($197<<6)|0) + 36|0);
 HEAPF32[$203>>2] = $199;
 $204 = ((($manifoldContacts) + ($197<<6)|0) + 40|0);
 HEAPF32[$204>>2] = $200;
 $205 = ((($manifoldContacts) + ($197<<6)|0) + 44|0);
 HEAPF32[$205>>2] = $201;
 $206 = HEAP32[$numContacts>>2]|0;
 $207 = (($206) + 1)|0;
 HEAP32[$numContacts>>2] = $207;
 $208 = ((($manifoldContacts) + ($206<<6)|0) + 48|0);
 HEAP32[$208>>2] = $triangleIndex;
 STACKTOP = sp;return 0;
}
function __ZN5physx2Gu33pcmDistanceSegmentTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_RNS2_6FloatVES7_S7_($agg$result,$p,$q,$a,$b,$c,$t,$u,$v) {
 $agg$result = $agg$result|0;
 $p = $p|0;
 $q = $q|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $t = $t|0;
 $u = $u|0;
 $v = $v|0;
 var $$ = 0, $$$$i = 0, $$$222$i = 0, $$$i = 0, $$222$i = 0, $$demorgan = 0, $$not232$i = 0, $$not234$i = 0, $$not239$i = 0, $$not241$i = 0, $$pre = Math_fround(0), $$pre1532 = Math_fround(0), $$pre1533 = Math_fround(0), $$pre1534 = Math_fround(0), $$pre1535 = Math_fround(0), $$pre1536 = Math_fround(0), $$sroa$1 = 0, $$sroa$1407 = 0, $$sroa$1409 = 0, $$sroa$1433 = 0;
 var $$sroa$1435 = 0, $$sroa$1437 = 0, $$sroa$1565 = 0, $$sroa$1567 = 0, $$sroa$1569 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0);
 var $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0);
 var $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0;
 var $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0);
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $ab = 0, $ac = 0, $bc = 0, $not$$i = 0, $not$$i270 = 0, $not$169$i = 0;
 var $not$231$i = 0, $not$233$i = 0, $not$240$i = 0, $pq = 0, $sqDist44 = 0, $sqDistPE$sroa$1 = 0, $t0$sroa$1 = 0, $t40 = 0, $t41 = 0, $tSeg$sroa$1 = 0, $uEdge$sroa$1 = 0, $v0$sroa$1 = 0, $vEdge$sroa$1 = 0, $w0$sroa$1 = 0, $zero$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $zero$sroa$1 = sp + 304|0;
 $pq = sp + 96|0;
 $ab = sp + 80|0;
 $ac = sp + 32|0;
 $bc = sp + 48|0;
 $t0$sroa$1 = sp + 292|0;
 $v0$sroa$1 = sp + 280|0;
 $w0$sroa$1 = sp + 268|0;
 $$sroa$1569 = sp + 256|0;
 $$sroa$1567 = sp + 244|0;
 $$sroa$1565 = sp + 232|0;
 $t40 = sp + 64|0;
 $t41 = sp + 16|0;
 $sqDist44 = sp;
 $sqDistPE$sroa$1 = sp + 172|0;
 $uEdge$sroa$1 = sp + 160|0;
 $vEdge$sroa$1 = sp + 112|0;
 $tSeg$sroa$1 = sp + 136|0;
 $$sroa$1437 = sp + 124|0;
 $$sroa$1435 = sp + 220|0;
 $$sroa$1433 = sp + 184|0;
 $$sroa$1409 = sp + 196|0;
 $$sroa$1407 = sp + 208|0;
 $$sroa$1 = sp + 148|0;
 $0 = Math_fround(HEAPF32[$q>>2]);
 $1 = (($q) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($q) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$p>>2]);
 $6 = (($p) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($p) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($0 - $5);
 $11 = Math_fround($2 - $7);
 $12 = Math_fround($4 - $9);
 HEAPF32[$pq>>2] = $10;
 $13 = (($pq) + 4|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($pq) + 8|0);
 HEAPF32[$14>>2] = $12;
 $15 = (($pq) + 12|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = Math_fround(HEAPF32[$b>>2]);
 $17 = (($b) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($b) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(HEAPF32[$a>>2]);
 $22 = (($a) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($a) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($16 - $21);
 $27 = Math_fround($18 - $23);
 $28 = Math_fround($20 - $25);
 HEAPF32[$ab>>2] = $26;
 $29 = (($ab) + 4|0);
 HEAPF32[$29>>2] = $27;
 $30 = (($ab) + 8|0);
 HEAPF32[$30>>2] = $28;
 $31 = (($ab) + 12|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = Math_fround(HEAPF32[$c>>2]);
 $33 = (($c) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($c) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($32 - $21);
 $38 = Math_fround($34 - $23);
 $39 = Math_fround($36 - $25);
 HEAPF32[$ac>>2] = $37;
 $40 = (($ac) + 4|0);
 HEAPF32[$40>>2] = $38;
 $41 = (($ac) + 8|0);
 HEAPF32[$41>>2] = $39;
 $42 = (($ac) + 12|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = Math_fround($32 - $16);
 $44 = Math_fround($34 - $18);
 $45 = Math_fround($36 - $20);
 HEAPF32[$bc>>2] = $43;
 $46 = (($bc) + 4|0);
 HEAPF32[$46>>2] = $44;
 $47 = (($bc) + 8|0);
 HEAPF32[$47>>2] = $45;
 $48 = (($bc) + 12|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = Math_fround($5 - $21);
 $50 = Math_fround($7 - $23);
 $51 = Math_fround($9 - $25);
 $52 = Math_fround($0 - $21);
 $53 = Math_fround($2 - $23);
 $54 = Math_fround($4 - $25);
 $55 = Math_fround($27 * $39);
 $56 = Math_fround($28 * $38);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($28 * $37);
 $59 = Math_fround($26 * $39);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($26 * $38);
 $62 = Math_fround($27 * $37);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($57 * $57);
 $65 = Math_fround($60 * $60);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($63 * $63);
 $68 = Math_fround($67 + $66);
 $69 = (Math_fround(Math_sqrt((Math_fround($68)))));
 $70 = Math_fround(Math_fround(1.0) / $69);
 $71 = Math_fround($57 * $70);
 $72 = Math_fround($60 * $70);
 $73 = Math_fround($63 * $70);
 $74 = Math_fround($26 * $26);
 $75 = Math_fround($27 * $27);
 $76 = Math_fround($28 * $28);
 $77 = Math_fround($26 * $37);
 $78 = Math_fround($27 * $38);
 $79 = Math_fround($28 * $39);
 $80 = Math_fround($37 * $37);
 $81 = Math_fround($38 * $38);
 $82 = Math_fround($39 * $39);
 $83 = Math_fround($49 * $71);
 $84 = Math_fround($50 * $72);
 $85 = Math_fround($51 * $73);
 $86 = Math_fround($74 + $75);
 $87 = Math_fround($77 + $78);
 $88 = Math_fround($80 + $81);
 $89 = Math_fround($83 + $84);
 $90 = Math_fround($86 + $76);
 $91 = Math_fround($87 + $79);
 $92 = Math_fround($88 + $82);
 $93 = Math_fround($85 + $89);
 $94 = Math_fround($90 * $92);
 $95 = Math_fround($91 * $91);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround(Math_fround(1.0) / $96);
 $98 = Math_fround($93 * $93);
 $99 = Math_fround($52 * $71);
 $100 = Math_fround($53 * $72);
 $101 = Math_fround($99 + $100);
 $102 = Math_fround($54 * $73);
 $103 = Math_fround($102 + $101);
 $104 = Math_fround($103 * $103);
 $105 = Math_fround($93 * $103);
 $106 = $105 < Math_fround(0.0);
 if ($106) {
  $107 = Math_fround(HEAPF32[$pq>>2]);
  $108 = Math_fround(HEAPF32[$13>>2]);
  $109 = Math_fround(HEAPF32[$14>>2]);
  $110 = Math_fround($71 * $107);
  $111 = Math_fround($72 * $108);
  $112 = Math_fround($110 + $111);
  $113 = Math_fround($73 * $109);
  $114 = Math_fround($112 + $113);
  $115 = Math_fround(Math_fround(1.0) / $114);
  $116 = Math_fround($93 * $115);
  $117 = Math_fround(-$116);
  $118 = Math_fround(HEAPF32[$p>>2]);
  $119 = Math_fround(HEAPF32[$6>>2]);
  $120 = Math_fround(HEAPF32[$8>>2]);
  $121 = Math_fround($107 * $117);
  $122 = Math_fround($108 * $117);
  $123 = Math_fround($109 * $117);
  $124 = Math_fround($121 + $118);
  $125 = Math_fround($122 + $119);
  $126 = Math_fround($123 + $120);
  $127 = Math_fround(HEAPF32[$a>>2]);
  $128 = Math_fround(HEAPF32[$22>>2]);
  $129 = Math_fround(HEAPF32[$24>>2]);
  $130 = Math_fround($124 - $127);
  $131 = Math_fround($125 - $128);
  $132 = Math_fround($126 - $129);
  $133 = Math_fround($130 * $26);
  $134 = Math_fround($131 * $27);
  $135 = Math_fround($133 + $134);
  $136 = Math_fround($132 * $28);
  $137 = Math_fround($135 + $136);
  $138 = Math_fround($130 * $37);
  $139 = Math_fround($131 * $38);
  $140 = Math_fround($138 + $139);
  $141 = Math_fround($132 * $39);
  $142 = Math_fround($140 + $141);
  $143 = Math_fround($92 * $137);
  $144 = Math_fround($91 * $142);
  $145 = Math_fround($143 - $144);
  $146 = Math_fround($97 * $145);
  $147 = Math_fround($90 * $142);
  $148 = Math_fround($91 * $137);
  $149 = Math_fround($147 - $148);
  $150 = Math_fround($97 * $149);
  $151 = $146 <= Math_fround(1.0);
  $not$$i270 = $146 >= Math_fround(0.0);
  $152 = $151 & $not$$i270;
  $153 = $150 <= Math_fround(1.0);
  $not$169$i = $150 >= Math_fround(0.0);
  $154 = $153 & $not$169$i;
  $155 = Math_fround($146 + $150);
  $156 = $155 < Math_fround(1.0);
  $$$i = $156 & $154;
  $$$$i = $$$i & $152;
  if ($$$$i) {
   HEAPF32[$t>>2] = $117;
   $157 = (($t) + 4|0);
   ;HEAP32[$157+0>>2]=HEAP32[$t0$sroa$1+0>>2]|0;HEAP32[$157+4>>2]=HEAP32[$t0$sroa$1+4>>2]|0;HEAP32[$157+8>>2]=HEAP32[$t0$sroa$1+8>>2]|0;
   HEAPF32[$u>>2] = $146;
   $158 = (($u) + 4|0);
   ;HEAP32[$158+0>>2]=HEAP32[$v0$sroa$1+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$v0$sroa$1+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$v0$sroa$1+8>>2]|0;
   HEAPF32[$v>>2] = $150;
   $159 = (($v) + 4|0);
   ;HEAP32[$159+0>>2]=HEAP32[$w0$sroa$1+0>>2]|0;HEAP32[$159+4>>2]=HEAP32[$w0$sroa$1+4>>2]|0;HEAP32[$159+8>>2]=HEAP32[$w0$sroa$1+8>>2]|0;
   HEAPF32[$agg$result>>2] = Math_fround(0.0);
   $160 = (($agg$result) + 4|0);
   ;HEAP32[$160+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$160+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$160+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
   STACKTOP = sp;return;
  } else {
   $165 = $118;$167 = $119;$169 = $120;$180 = $127;$182 = $128;$184 = $129;
  }
 } else {
  $$pre = Math_fround(HEAPF32[$p>>2]);
  $$pre1532 = Math_fround(HEAPF32[$6>>2]);
  $$pre1533 = Math_fround(HEAPF32[$8>>2]);
  $$pre1534 = Math_fround(HEAPF32[$a>>2]);
  $$pre1535 = Math_fround(HEAPF32[$22>>2]);
  $$pre1536 = Math_fround(HEAPF32[$24>>2]);
  $165 = $$pre;$167 = $$pre1532;$169 = $$pre1533;$180 = $$pre1534;$182 = $$pre1535;$184 = $$pre1536;
 }
 $161 = Math_fround($71 * $93);
 $162 = Math_fround($72 * $93);
 $163 = Math_fround($73 * $93);
 $164 = Math_fround($165 - $161);
 $166 = Math_fround($167 - $162);
 $168 = Math_fround($169 - $163);
 $170 = Math_fround(HEAPF32[$q>>2]);
 $171 = Math_fround(HEAPF32[$1>>2]);
 $172 = Math_fround(HEAPF32[$3>>2]);
 $173 = Math_fround($71 * $103);
 $174 = Math_fround($72 * $103);
 $175 = Math_fround($73 * $103);
 $176 = Math_fround($170 - $173);
 $177 = Math_fround($171 - $174);
 $178 = Math_fround($172 - $175);
 $179 = Math_fround($164 - $180);
 $181 = Math_fround($166 - $182);
 $183 = Math_fround($168 - $184);
 $185 = Math_fround($176 - $180);
 $186 = Math_fround($177 - $182);
 $187 = Math_fround($178 - $184);
 $188 = Math_fround($179 * $26);
 $189 = Math_fround($181 * $27);
 $190 = Math_fround($183 * $28);
 $191 = Math_fround($179 * $37);
 $192 = Math_fround($181 * $38);
 $193 = Math_fround($183 * $39);
 $194 = Math_fround($185 * $26);
 $195 = Math_fround($186 * $27);
 $196 = Math_fround($187 * $28);
 $197 = Math_fround($185 * $37);
 $198 = Math_fround($186 * $38);
 $199 = Math_fround($187 * $39);
 $200 = Math_fround($188 + $189);
 $201 = Math_fround($191 + $192);
 $202 = Math_fround($194 + $195);
 $203 = Math_fround($197 + $198);
 $204 = Math_fround($200 + $190);
 $205 = Math_fround($201 + $193);
 $206 = Math_fround($202 + $196);
 $207 = Math_fround($203 + $199);
 $208 = Math_fround($92 * $204);
 $209 = Math_fround($90 * $205);
 $210 = Math_fround($92 * $206);
 $211 = Math_fround($90 * $207);
 $212 = Math_fround($91 * $205);
 $213 = Math_fround($91 * $204);
 $214 = Math_fround($91 * $207);
 $215 = Math_fround($91 * $206);
 $216 = Math_fround($208 - $212);
 $217 = Math_fround($209 - $213);
 $218 = Math_fround($210 - $214);
 $219 = Math_fround($211 - $215);
 $220 = Math_fround($97 * $216);
 $221 = Math_fround($97 * $217);
 $222 = Math_fround($97 * $218);
 $223 = Math_fround($97 * $219);
 $224 = $220 <= Math_fround(1.0);
 $225 = $222 <= Math_fround(1.0);
 $226 = $221 <= Math_fround(1.0);
 $227 = $223 <= Math_fround(1.0);
 $228 = Math_fround($220 + $221);
 $229 = Math_fround($222 + $223);
 $230 = $228 < Math_fround(1.0);
 $231 = $229 < Math_fround(1.0);
 $$not232$i = $221 >= Math_fround(0.0);
 $not$231$i = $226 & $$not232$i;
 $$222$i = $230 & $not$231$i;
 $$not234$i = $223 >= Math_fround(0.0);
 $not$233$i = $227 & $$not234$i;
 $232 = $231 & $not$233$i;
 $$not239$i = $220 >= Math_fround(0.0);
 $not$$i = $224 & $$not239$i;
 $$$222$i = $$222$i & $not$$i;
 $$not241$i = $222 >= Math_fround(0.0);
 $not$240$i = $225 & $$not241$i;
 $233 = $232 & $not$240$i;
 $$ = $$$222$i & $233;
 if ($$) {
  $234 = !($104 > $98);
  $235 = $234 ? Math_fround(1.0) : Math_fround(0.0);
  HEAPF32[$t>>2] = $235;
  $236 = (($t) + 4|0);
  ;HEAP32[$236+0>>2]=HEAP32[$$sroa$1569+0>>2]|0;HEAP32[$236+4>>2]=HEAP32[$$sroa$1569+4>>2]|0;HEAP32[$236+8>>2]=HEAP32[$$sroa$1569+8>>2]|0;
  $237 = $234 ? $222 : $220;
  HEAPF32[$u>>2] = $237;
  $238 = (($u) + 4|0);
  ;HEAP32[$238+0>>2]=HEAP32[$$sroa$1567+0>>2]|0;HEAP32[$238+4>>2]=HEAP32[$$sroa$1567+4>>2]|0;HEAP32[$238+8>>2]=HEAP32[$$sroa$1567+8>>2]|0;
  $239 = $234 ? $223 : $221;
  HEAPF32[$v>>2] = $239;
  $240 = (($v) + 4|0);
  ;HEAP32[$240+0>>2]=HEAP32[$$sroa$1565+0>>2]|0;HEAP32[$240+4>>2]=HEAP32[$$sroa$1565+4>>2]|0;HEAP32[$240+8>>2]=HEAP32[$$sroa$1565+8>>2]|0;
  $241 = $234 ? $104 : $98;
  HEAPF32[$agg$result>>2] = $241;
  STACKTOP = sp;return;
 }
 __ZN5physx2Gu33pcmDistanceSegmentSegmentSquared4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_S5_S5_S5_S5_RNS2_5Vec4VES7_($sqDist44,$p,$pq,$a,$ab,$b,$bc,$a,$ac,$a,$ab,$t40,$t41);
 $242 = Math_fround(HEAPF32[$t40>>2]);
 $243 = (($t40) + 4|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = (($t40) + 8|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = Math_fround(HEAPF32[$t41>>2]);
 $248 = (($t41) + 4|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = (($t41) + 8|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = Math_fround(Math_fround(1.0) - $249);
 $253 = Math_fround(HEAPF32[$sqDist44>>2]);
 $254 = (($sqDist44) + 4|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = (($sqDist44) + 8|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = $255 > $253;
 $259 = $257 > $253;
 $260 = !($257 > $255);
 $261 = $260 ? $257 : $255;
 $$demorgan = $259 & $258;
 $262 = $$demorgan ? $253 : $261;
 $263 = $260 ? Math_fround(0.0) : $252;
 $264 = $$demorgan ? $247 : $263;
 $265 = $260 ? $251 : $249;
 $266 = $$demorgan ? Math_fround(0.0) : $265;
 $267 = $260 ? $246 : $244;
 $268 = $$demorgan ? $242 : $267;
 if ($$$222$i) {
  $269 = !($262 > $98);
  $270 = $269 ? $268 : Math_fround(0.0);
  HEAPF32[$t>>2] = $270;
  $271 = (($t) + 4|0);
  ;HEAP32[$271+0>>2]=HEAP32[$$sroa$1437+0>>2]|0;HEAP32[$271+4>>2]=HEAP32[$$sroa$1437+4>>2]|0;HEAP32[$271+8>>2]=HEAP32[$$sroa$1437+8>>2]|0;
  $272 = $269 ? $264 : $220;
  HEAPF32[$u>>2] = $272;
  $273 = (($u) + 4|0);
  ;HEAP32[$273+0>>2]=HEAP32[$$sroa$1435+0>>2]|0;HEAP32[$273+4>>2]=HEAP32[$$sroa$1435+4>>2]|0;HEAP32[$273+8>>2]=HEAP32[$$sroa$1435+8>>2]|0;
  $274 = $269 ? $266 : $221;
  HEAPF32[$v>>2] = $274;
  $275 = (($v) + 4|0);
  ;HEAP32[$275+0>>2]=HEAP32[$$sroa$1433+0>>2]|0;HEAP32[$275+4>>2]=HEAP32[$$sroa$1433+4>>2]|0;HEAP32[$275+8>>2]=HEAP32[$$sroa$1433+8>>2]|0;
  $276 = $269 ? $262 : $98;
  HEAPF32[$agg$result>>2] = $276;
  STACKTOP = sp;return;
 }
 if ($233) {
  $277 = !($262 > $104);
  $278 = $277 ? $268 : Math_fround(1.0);
  HEAPF32[$t>>2] = $278;
  $279 = (($t) + 4|0);
  ;HEAP32[$279+0>>2]=HEAP32[$$sroa$1409+0>>2]|0;HEAP32[$279+4>>2]=HEAP32[$$sroa$1409+4>>2]|0;HEAP32[$279+8>>2]=HEAP32[$$sroa$1409+8>>2]|0;
  $280 = $277 ? $264 : $222;
  HEAPF32[$u>>2] = $280;
  $281 = (($u) + 4|0);
  ;HEAP32[$281+0>>2]=HEAP32[$$sroa$1407+0>>2]|0;HEAP32[$281+4>>2]=HEAP32[$$sroa$1407+4>>2]|0;HEAP32[$281+8>>2]=HEAP32[$$sroa$1407+8>>2]|0;
  $282 = $277 ? $266 : $223;
  HEAPF32[$v>>2] = $282;
  $283 = (($v) + 4|0);
  ;HEAP32[$283+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$283+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$283+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
  $284 = $277 ? $262 : $104;
  HEAPF32[$agg$result>>2] = $284;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$t>>2] = $268;
  $285 = (($t) + 4|0);
  ;HEAP32[$285+0>>2]=HEAP32[$tSeg$sroa$1+0>>2]|0;HEAP32[$285+4>>2]=HEAP32[$tSeg$sroa$1+4>>2]|0;HEAP32[$285+8>>2]=HEAP32[$tSeg$sroa$1+8>>2]|0;
  HEAPF32[$u>>2] = $264;
  $286 = (($u) + 4|0);
  ;HEAP32[$286+0>>2]=HEAP32[$uEdge$sroa$1+0>>2]|0;HEAP32[$286+4>>2]=HEAP32[$uEdge$sroa$1+4>>2]|0;HEAP32[$286+8>>2]=HEAP32[$uEdge$sroa$1+8>>2]|0;
  HEAPF32[$v>>2] = $266;
  $287 = (($v) + 4|0);
  ;HEAP32[$287+0>>2]=HEAP32[$vEdge$sroa$1+0>>2]|0;HEAP32[$287+4>>2]=HEAP32[$vEdge$sroa$1+4>>2]|0;HEAP32[$287+8>>2]=HEAP32[$vEdge$sroa$1+8>>2]|0;
  HEAPF32[$agg$result>>2] = $262;
  $288 = (($agg$result) + 4|0);
  ;HEAP32[$288+0>>2]=HEAP32[$sqDistPE$sroa$1+0>>2]|0;HEAP32[$288+4>>2]=HEAP32[$sqDistPE$sroa$1+4>>2]|0;HEAP32[$288+8>>2]=HEAP32[$sqDistPE$sroa$1+8>>2]|0;
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu33pcmDistanceSegmentSegmentSquared4ERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_S5_S5_S5_S5_S5_RNS2_5Vec4VES7_($agg$result,$p,$d0,$p02,$d02,$p12,$d12,$p22,$d22,$p32,$d32,$s,$t) {
 $agg$result = $agg$result|0;
 $p = $p|0;
 $d0 = $d0|0;
 $p02 = $p02|0;
 $d02 = $d02|0;
 $p12 = $p12|0;
 $d12 = $d12|0;
 $p22 = $p22|0;
 $d22 = $d22|0;
 $p32 = $p32|0;
 $d32 = $d32|0;
 $s = $s|0;
 $t = $t|0;
 var $$$i$i = Math_fround(0), $$$i$i120 = Math_fround(0), $$$i$i88 = Math_fround(0), $$$i8$i = Math_fround(0), $$$i8$i122 = Math_fround(0), $$$i8$i90 = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i$i121 = Math_fround(0), $$1$i$i89 = Math_fround(0), $$1$i9$i = Math_fround(0), $$1$i9$i123 = Math_fround(0), $$1$i9$i91 = Math_fround(0), $$in1$i = 0, $$in2$i = 0, $$in3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0);
 var $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0);
 var $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0);
 var $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0);
 var $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0);
 var $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0;
 var $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0);
 var $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = Math_fround(0);
 var $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0);
 var $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0);
 var $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0);
 var $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0;
 var $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0);
 var $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0);
 var $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $a$pn4$i = 0, $a$pn6$i = 0, $b$a$i = 0, $b$a7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = Math_fround(HEAPF32[$d0>>2]);
 $3 = (($d0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($d0) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$p>>2]);
 $8 = (($p) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($p) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(HEAPF32[$d02>>2]);
 $13 = (($d02) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($d02) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$d12>>2]);
 $18 = (($d12) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($d12) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(HEAPF32[$d22>>2]);
 $23 = (($d22) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($d22) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(HEAPF32[$d32>>2]);
 $28 = (($d32) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($d32) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(HEAPF32[$p02>>2]);
 $33 = (($p02) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($p02) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$p12>>2]);
 $38 = (($p12) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($p12) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround(HEAPF32[$p22>>2]);
 $43 = (($p22) + 4|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($p22) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround(HEAPF32[$p32>>2]);
 $48 = (($p32) + 4|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($p32) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($7 - $32);
 $53 = Math_fround($7 - $37);
 $54 = Math_fround($7 - $42);
 $55 = Math_fround($7 - $47);
 $56 = Math_fround($9 - $34);
 $57 = Math_fround($9 - $39);
 $58 = Math_fround($9 - $44);
 $59 = Math_fround($9 - $49);
 $60 = Math_fround($11 - $36);
 $61 = Math_fround($11 - $41);
 $62 = Math_fround($11 - $46);
 $63 = Math_fround($11 - $51);
 $64 = Math_fround($2 * $2);
 $65 = Math_fround($4 * $4);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($6 * $6);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($14 * $14);
 $70 = Math_fround($19 * $19);
 $71 = Math_fround($24 * $24);
 $72 = Math_fround($29 * $29);
 $73 = Math_fround($12 * $12);
 $74 = Math_fround($17 * $17);
 $75 = Math_fround($22 * $22);
 $76 = Math_fround($27 * $27);
 $77 = Math_fround($73 + $69);
 $78 = Math_fround($74 + $70);
 $79 = Math_fround($75 + $71);
 $80 = Math_fround($76 + $72);
 $81 = Math_fround($16 * $16);
 $82 = Math_fround($21 * $21);
 $83 = Math_fround($26 * $26);
 $84 = Math_fround($31 * $31);
 $85 = Math_fround($81 + $77);
 $86 = Math_fround($82 + $78);
 $87 = Math_fround($83 + $79);
 $88 = Math_fround($84 + $80);
 $89 = Math_fround($4 * $14);
 $90 = Math_fround($4 * $19);
 $91 = Math_fround($4 * $24);
 $92 = Math_fround($4 * $29);
 $93 = Math_fround($2 * $12);
 $94 = Math_fround($2 * $17);
 $95 = Math_fround($2 * $22);
 $96 = Math_fround($2 * $27);
 $97 = Math_fround($93 + $89);
 $98 = Math_fround($94 + $90);
 $99 = Math_fround($95 + $91);
 $100 = Math_fround($96 + $92);
 $101 = Math_fround($6 * $16);
 $102 = Math_fround($6 * $21);
 $103 = Math_fround($6 * $26);
 $104 = Math_fround($6 * $31);
 $105 = Math_fround($101 + $97);
 $106 = Math_fround($102 + $98);
 $107 = Math_fround($103 + $99);
 $108 = Math_fround($104 + $100);
 $109 = Math_fround($4 * $56);
 $110 = Math_fround($4 * $57);
 $111 = Math_fround($4 * $58);
 $112 = Math_fround($4 * $59);
 $113 = Math_fround($2 * $52);
 $114 = Math_fround($2 * $53);
 $115 = Math_fround($2 * $54);
 $116 = Math_fround($2 * $55);
 $117 = Math_fround($113 + $109);
 $118 = Math_fround($114 + $110);
 $119 = Math_fround($115 + $111);
 $120 = Math_fround($116 + $112);
 $121 = Math_fround($6 * $60);
 $122 = Math_fround($6 * $61);
 $123 = Math_fround($6 * $62);
 $124 = Math_fround($6 * $63);
 $125 = Math_fround($121 + $117);
 $126 = Math_fround($122 + $118);
 $127 = Math_fround($123 + $119);
 $128 = Math_fround($124 + $120);
 $129 = Math_fround($14 * $56);
 $130 = Math_fround($19 * $57);
 $131 = Math_fround($24 * $58);
 $132 = Math_fround($29 * $59);
 $133 = Math_fround($12 * $52);
 $134 = Math_fround($17 * $53);
 $135 = Math_fround($22 * $54);
 $136 = Math_fround($27 * $55);
 $137 = Math_fround($133 + $129);
 $138 = Math_fround($134 + $130);
 $139 = Math_fround($135 + $131);
 $140 = Math_fround($136 + $132);
 $141 = Math_fround($16 * $60);
 $142 = Math_fround($21 * $61);
 $143 = Math_fround($26 * $62);
 $144 = Math_fround($31 * $63);
 $145 = Math_fround($141 + $137);
 $146 = Math_fround($142 + $138);
 $147 = Math_fround($143 + $139);
 $148 = Math_fround($144 + $140);
 $149 = Math_fround(Math_fround(1.0) / $68);
 $150 = Math_fround(Math_fround(1.0) / $85);
 $151 = Math_fround(Math_fround(1.0) / $86);
 $152 = Math_fround(Math_fround(1.0) / $87);
 $153 = Math_fround(Math_fround(1.0) / $88);
 $154 = Math_fround($85 * $68);
 $155 = Math_fround($86 * $68);
 $156 = Math_fround($87 * $68);
 $157 = Math_fround($88 * $68);
 $158 = Math_fround($105 * $105);
 $159 = Math_fround($106 * $106);
 $160 = Math_fround($107 * $107);
 $161 = Math_fround($108 * $108);
 $162 = Math_fround($154 - $158);
 $163 = Math_fround($155 - $159);
 $164 = Math_fround($156 - $160);
 $165 = Math_fround($157 - $161);
 $166 = Math_fround($105 * $145);
 $167 = Math_fround($106 * $146);
 $168 = Math_fround($107 * $147);
 $169 = Math_fround($108 * $148);
 $170 = Math_fround($85 * $125);
 $171 = Math_fround($86 * $126);
 $172 = Math_fround($87 * $127);
 $173 = Math_fround($88 * $128);
 $174 = Math_fround($166 - $170);
 $175 = Math_fround($167 - $171);
 $176 = Math_fround($168 - $172);
 $177 = Math_fround($169 - $173);
 $178 = Math_fround($174 / $162);
 $179 = Math_fround($175 / $163);
 $180 = Math_fround($176 / $164);
 $181 = Math_fround($177 / $165);
 $182 = $178 < Math_fround(1.0);
 $$$i$i120 = $182 ? $178 : Math_fround(1.0);
 $183 = $179 < Math_fround(1.0);
 $184 = $183 ? $179 : Math_fround(1.0);
 $185 = $180 < Math_fround(1.0);
 $$1$i$i121 = $185 ? $180 : Math_fround(1.0);
 $186 = $181 < Math_fround(1.0);
 $187 = $186 ? $181 : Math_fround(1.0);
 $188 = $$$i$i120 > Math_fround(0.0);
 $$$i8$i122 = $188 ? $$$i$i120 : Math_fround(0.0);
 $189 = $184 > Math_fround(0.0);
 $190 = $189 ? $184 : Math_fround(0.0);
 $191 = $$1$i$i121 > Math_fround(0.0);
 $$1$i9$i123 = $191 ? $$1$i$i121 : Math_fround(0.0);
 $192 = $187 > Math_fround(0.0);
 $193 = $192 ? $187 : Math_fround(0.0);
 $194 = $162 <= Math_fround(1.1920928955078125E-7);
 $195 = $163 <= Math_fround(1.1920928955078125E-7);
 $196 = $164 <= Math_fround(1.1920928955078125E-7);
 $197 = $165 <= Math_fround(1.1920928955078125E-7);
 HEAPF32[$1>>2] = Math_fround(0.5);
 $198 = (($1) + 4|0);
 HEAPF32[$198>>2] = Math_fround(0.5);
 $199 = (($1) + 8|0);
 HEAPF32[$199>>2] = Math_fround(0.5);
 $200 = (($1) + 12|0);
 HEAPF32[$200>>2] = Math_fround(0.5);
 HEAPF32[$0>>2] = $$$i8$i122;
 $201 = (($0) + 4|0);
 HEAPF32[$201>>2] = $190;
 $202 = (($0) + 8|0);
 HEAPF32[$202>>2] = $$1$i9$i123;
 $203 = (($0) + 12|0);
 HEAPF32[$203>>2] = $193;
 $b$a$i = $194 ? $1 : $0;
 $204 = Math_fround(HEAPF32[$b$a$i>>2]);
 $a$pn4$i = $195 ? $1 : $0;
 $$in1$i = (($a$pn4$i) + 4|0);
 $205 = Math_fround(HEAPF32[$$in1$i>>2]);
 $b$a7$i = $196 ? $1 : $0;
 $$in2$i = (($b$a7$i) + 8|0);
 $206 = Math_fround(HEAPF32[$$in2$i>>2]);
 $a$pn6$i = $197 ? $1 : $0;
 $$in3$i = (($a$pn6$i) + 12|0);
 $207 = Math_fround(HEAPF32[$$in3$i>>2]);
 $208 = Math_fround($105 * $204);
 $209 = Math_fround($106 * $205);
 $210 = Math_fround($107 * $206);
 $211 = Math_fround($108 * $207);
 $212 = Math_fround($145 + $208);
 $213 = Math_fround($146 + $209);
 $214 = Math_fround($147 + $210);
 $215 = Math_fround($148 + $211);
 $216 = Math_fround($150 * $212);
 $217 = Math_fround($151 * $213);
 $218 = Math_fround($152 * $214);
 $219 = Math_fround($153 * $215);
 $220 = $216 < Math_fround(1.0);
 $$$i$i88 = $220 ? $216 : Math_fround(1.0);
 $221 = $217 < Math_fround(1.0);
 $222 = $221 ? $217 : Math_fround(1.0);
 $223 = $218 < Math_fround(1.0);
 $$1$i$i89 = $223 ? $218 : Math_fround(1.0);
 $224 = $219 < Math_fround(1.0);
 $225 = $224 ? $219 : Math_fround(1.0);
 $226 = $$$i$i88 > Math_fround(0.0);
 $$$i8$i90 = $226 ? $$$i$i88 : Math_fround(0.0);
 $227 = $222 > Math_fround(0.0);
 $228 = $227 ? $222 : Math_fround(0.0);
 $229 = $$1$i$i89 > Math_fround(0.0);
 $$1$i9$i91 = $229 ? $$1$i$i89 : Math_fround(0.0);
 $230 = $225 > Math_fround(0.0);
 $231 = $230 ? $225 : Math_fround(0.0);
 $232 = Math_fround($105 * $$$i8$i90);
 $233 = Math_fround($106 * $228);
 $234 = Math_fround($107 * $$1$i9$i91);
 $235 = Math_fround($108 * $231);
 $236 = Math_fround($232 - $125);
 $237 = Math_fround($233 - $126);
 $238 = Math_fround($234 - $127);
 $239 = Math_fround($235 - $128);
 $240 = Math_fround($149 * $236);
 $241 = Math_fround($149 * $237);
 $242 = Math_fround($149 * $238);
 $243 = Math_fround($149 * $239);
 $244 = $240 < Math_fround(1.0);
 $$$i$i = $244 ? $240 : Math_fround(1.0);
 $245 = $241 < Math_fround(1.0);
 $246 = $245 ? $241 : Math_fround(1.0);
 $247 = $242 < Math_fround(1.0);
 $$1$i$i = $247 ? $242 : Math_fround(1.0);
 $248 = $243 < Math_fround(1.0);
 $249 = $248 ? $243 : Math_fround(1.0);
 $250 = $$$i$i > Math_fround(0.0);
 $$$i8$i = $250 ? $$$i$i : Math_fround(0.0);
 $251 = $246 > Math_fround(0.0);
 $252 = $251 ? $246 : Math_fround(0.0);
 $253 = $$1$i$i > Math_fround(0.0);
 $$1$i9$i = $253 ? $$1$i$i : Math_fround(0.0);
 $254 = $249 > Math_fround(0.0);
 $255 = $254 ? $249 : Math_fround(0.0);
 HEAPF32[$s>>2] = $$$i8$i;
 $256 = (($s) + 4|0);
 HEAPF32[$256>>2] = $252;
 $257 = (($s) + 8|0);
 HEAPF32[$257>>2] = $$1$i9$i;
 $258 = (($s) + 12|0);
 HEAPF32[$258>>2] = $255;
 HEAPF32[$t>>2] = $$$i8$i90;
 $259 = (($t) + 4|0);
 HEAPF32[$259>>2] = $228;
 $260 = (($t) + 8|0);
 HEAPF32[$260>>2] = $$1$i9$i91;
 $261 = (($t) + 12|0);
 HEAPF32[$261>>2] = $231;
 $262 = Math_fround($2 * $$$i8$i);
 $263 = Math_fround($2 * $252);
 $264 = Math_fround($2 * $$1$i9$i);
 $265 = Math_fround($2 * $255);
 $266 = Math_fround($7 + $262);
 $267 = Math_fround($7 + $263);
 $268 = Math_fround($7 + $264);
 $269 = Math_fround($7 + $265);
 $270 = Math_fround($4 * $$$i8$i);
 $271 = Math_fround($4 * $252);
 $272 = Math_fround($4 * $$1$i9$i);
 $273 = Math_fround($4 * $255);
 $274 = Math_fround($9 + $270);
 $275 = Math_fround($9 + $271);
 $276 = Math_fround($9 + $272);
 $277 = Math_fround($9 + $273);
 $278 = Math_fround($6 * $$$i8$i);
 $279 = Math_fround($6 * $252);
 $280 = Math_fround($6 * $$1$i9$i);
 $281 = Math_fround($6 * $255);
 $282 = Math_fround($11 + $278);
 $283 = Math_fround($11 + $279);
 $284 = Math_fround($11 + $280);
 $285 = Math_fround($11 + $281);
 $286 = Math_fround($12 * $$$i8$i90);
 $287 = Math_fround($17 * $228);
 $288 = Math_fround($22 * $$1$i9$i91);
 $289 = Math_fround($27 * $231);
 $290 = Math_fround($32 + $286);
 $291 = Math_fround($37 + $287);
 $292 = Math_fround($42 + $288);
 $293 = Math_fround($47 + $289);
 $294 = Math_fround($14 * $$$i8$i90);
 $295 = Math_fround($19 * $228);
 $296 = Math_fround($24 * $$1$i9$i91);
 $297 = Math_fround($29 * $231);
 $298 = Math_fround($34 + $294);
 $299 = Math_fround($39 + $295);
 $300 = Math_fround($44 + $296);
 $301 = Math_fround($49 + $297);
 $302 = Math_fround($16 * $$$i8$i90);
 $303 = Math_fround($21 * $228);
 $304 = Math_fround($26 * $$1$i9$i91);
 $305 = Math_fround($31 * $231);
 $306 = Math_fround($36 + $302);
 $307 = Math_fround($41 + $303);
 $308 = Math_fround($46 + $304);
 $309 = Math_fround($51 + $305);
 $310 = Math_fround($266 - $290);
 $311 = Math_fround($267 - $291);
 $312 = Math_fround($268 - $292);
 $313 = Math_fround($269 - $293);
 $314 = Math_fround($274 - $298);
 $315 = Math_fround($275 - $299);
 $316 = Math_fround($276 - $300);
 $317 = Math_fround($277 - $301);
 $318 = Math_fround($282 - $306);
 $319 = Math_fround($283 - $307);
 $320 = Math_fround($284 - $308);
 $321 = Math_fround($285 - $309);
 $322 = Math_fround($318 * $318);
 $323 = Math_fround($319 * $319);
 $324 = Math_fround($320 * $320);
 $325 = Math_fround($321 * $321);
 $326 = Math_fround($314 * $314);
 $327 = Math_fround($315 * $315);
 $328 = Math_fround($316 * $316);
 $329 = Math_fround($317 * $317);
 $330 = Math_fround($326 + $322);
 $331 = Math_fround($327 + $323);
 $332 = Math_fround($328 + $324);
 $333 = Math_fround($329 + $325);
 $334 = Math_fround($310 * $310);
 $335 = Math_fround($311 * $311);
 $336 = Math_fround($312 * $312);
 $337 = Math_fround($313 * $313);
 $338 = Math_fround($334 + $330);
 $339 = Math_fround($335 + $331);
 $340 = Math_fround($336 + $332);
 $341 = Math_fround($337 + $333);
 HEAPF32[$agg$result>>2] = $338;
 $342 = (($agg$result) + 4|0);
 HEAPF32[$342>>2] = $339;
 $343 = (($agg$result) + 8|0);
 HEAPF32[$343>>2] = $340;
 $344 = (($agg$result) + 12|0);
 HEAPF32[$344>>2] = $341;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($this,$verts,$triangleIndex,$triFlags,$vertInds) {
 $this = $this|0;
 $verts = $verts|0;
 $triangleIndex = $triangleIndex|0;
 $triFlags = $triFlags|0;
 $vertInds = $vertInds|0;
 var $$$i = Math_fround(0), $$$i376 = Math_fround(0), $$0 = 0, $$pre = 0, $$sroa$189 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0;
 var $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0);
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0;
 var $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $i$0373 = 0, $i1$0371 = 0, $j$0370 = 0, $j$1 = 0, $maxPen = 0, $n = 0, $p0 = 0, $p1 = 0, $p2 = 0;
 var $patchNormalInTriangle = 0, $sqDist = 0, $t = 0, $u = 0, $v = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $p0 = sp + 80|0;
 $p1 = sp + 144|0;
 $p2 = sp + 128|0;
 $n = sp + 112|0;
 $t = sp + 96|0;
 $u = sp + 64|0;
 $v = sp + 48|0;
 $sqDist = sp + 32|0;
 $patchNormalInTriangle = sp + 16|0;
 $maxPen = sp;
 $$sroa$189 = sp + 160|0;
 $0 = Math_fround(HEAPF32[$verts>>2]);
 $1 = (($verts) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($verts) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$p0>>2] = $0;
 $5 = (($p0) + 4|0);
 HEAPF32[$5>>2] = $2;
 $6 = (($p0) + 8|0);
 HEAPF32[$6>>2] = $4;
 $7 = (($p0) + 12|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($verts) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($verts) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($verts) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$p1>>2] = $9;
 $14 = (($p1) + 4|0);
 HEAPF32[$14>>2] = $11;
 $15 = (($p1) + 8|0);
 HEAPF32[$15>>2] = $13;
 $16 = (($p1) + 12|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($verts) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($verts) + 28|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($verts) + 32|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$p2>>2] = $18;
 $23 = (($p2) + 4|0);
 HEAPF32[$23>>2] = $20;
 $24 = (($p2) + 8|0);
 HEAPF32[$24>>2] = $22;
 $25 = (($p2) + 12|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = Math_fround($9 - $0);
 $27 = Math_fround($11 - $2);
 $28 = Math_fround($13 - $4);
 $29 = Math_fround($18 - $0);
 $30 = Math_fround($20 - $2);
 $31 = Math_fround($22 - $4);
 $32 = Math_fround($27 * $31);
 $33 = Math_fround($28 * $30);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($28 * $29);
 $36 = Math_fround($26 * $31);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($26 * $30);
 $39 = Math_fround($27 * $29);
 $40 = Math_fround($38 - $39);
 $41 = Math_fround($34 * $34);
 $42 = Math_fround($37 * $37);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($40 * $40);
 $45 = Math_fround($44 + $43);
 $46 = (Math_fround(Math_sqrt((Math_fround($45)))));
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = Math_fround($47 * $34);
 $49 = Math_fround($47 * $37);
 $50 = Math_fround($40 * $47);
 HEAPF32[$n>>2] = $48;
 $51 = (($n) + 4|0);
 HEAPF32[$51>>2] = $49;
 $52 = (($n) + 8|0);
 HEAPF32[$52>>2] = $50;
 $53 = (($n) + 12|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = Math_fround($0 * $48);
 $55 = Math_fround($2 * $49);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($4 * $50);
 $58 = Math_fround($56 + $57);
 $59 = (($this) + 2368|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($60) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($60) + 8|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($48 * $61);
 $67 = Math_fround($49 * $63);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($50 * $65);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($70 - $58);
 $72 = $71 < Math_fround(0.0);
 if ($72) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $73 = (($60) + 96|0);
 $74 = (($60) + 112|0);
 __ZN5physx2Gu33pcmDistanceSegmentTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_RNS2_6FloatVES7_S7_($sqDist,$73,$74,$p0,$p1,$p2,$t,$u,$v);
 $75 = (($this) + 2352|0);
 $76 = (($this) + 2352|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround(HEAPF32[$sqDist>>2]);
 $79 = $77 > $78;
 if (!($79)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $80 = Math_fround(HEAPF32[$u>>2]);
 $81 = $80 == Math_fround(0.0);
 do {
  if ($81) {
   $82 = Math_fround(HEAPF32[$v>>2]);
   $83 = $82 == Math_fround(0.0);
   if ($83) {
    $84 = $triFlags & 40;
    $85 = ($84<<24>>24)==(0);
    if ($85) {
     label = 16;
     break;
    } else {
     $128 = $82;
     label = 17;
     break;
    }
   }
   $86 = $82 == Math_fround(1.0);
   $87 = $triFlags&255;
   if ($86) {
    $88 = $87 & 48;
    $89 = ($88|0)==(0);
    if ($89) {
     label = 16;
     break;
    } else {
     $128 = $82;
     label = 17;
     break;
    }
   } else {
    $90 = $87 & 32;
    $91 = ($90|0)==(0);
    if ($91) {
     label = 16;
     break;
    } else {
     $128 = $82;
     label = 17;
     break;
    }
   }
  } else {
   $92 = $80 == Math_fround(1.0);
   $93 = Math_fround(HEAPF32[$v>>2]);
   $94 = $93 == Math_fround(0.0);
   if ($92) {
    if (!($94)) {
     $128 = $93;
     label = 17;
     break;
    }
    $95 = $triFlags & 24;
    $96 = ($95<<24>>24)==(0);
    if ($96) {
     label = 16;
     break;
    } else {
     $128 = $93;
     label = 17;
     break;
    }
   }
   if ($94) {
    $97 = $triFlags & 8;
    $98 = ($97<<24>>24)==(0);
    if ($98) {
     label = 16;
     break;
    } else {
     $128 = $93;
     label = 17;
     break;
    }
   }
   $99 = Math_fround($80 + $93);
   $100 = !($99 >= Math_fround(0.999899983406066894531));
   if ($100) {
    label = 16;
   } else {
    $101 = $triFlags & 16;
    $102 = ($101<<24>>24)==(0);
    if ($102) {
     label = 16;
    } else {
     $128 = $93;
     label = 17;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   ;HEAP32[$patchNormalInTriangle+0>>2]=HEAP32[$n+0>>2]|0;HEAP32[$patchNormalInTriangle+4>>2]=HEAP32[$n+4>>2]|0;HEAP32[$patchNormalInTriangle+8>>2]=HEAP32[$n+8>>2]|0;HEAP32[$patchNormalInTriangle+12>>2]=HEAP32[$n+12>>2]|0;
  }
  else if ((label|0) == 17) {
   $103 = $78 == Math_fround(0.0);
   if ($103) {
    ;HEAP32[$patchNormalInTriangle+0>>2]=HEAP32[$n+0>>2]|0;HEAP32[$patchNormalInTriangle+4>>2]=HEAP32[$n+4>>2]|0;HEAP32[$patchNormalInTriangle+8>>2]=HEAP32[$n+8>>2]|0;HEAP32[$patchNormalInTriangle+12>>2]=HEAP32[$n+12>>2]|0;
    break;
   } else {
    $104 = HEAP32[$59>>2]|0;
    $105 = (($104) + 112|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $107 = (($104) + 116|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $109 = (($104) + 120|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $111 = (($104) + 96|0);
    $112 = Math_fround(HEAPF32[$111>>2]);
    $113 = (($104) + 100|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = (($104) + 104|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = Math_fround($106 - $112);
    $118 = Math_fround($108 - $114);
    $119 = Math_fround($110 - $116);
    $120 = Math_fround(HEAPF32[$t>>2]);
    $121 = Math_fround($117 * $120);
    $122 = Math_fround($118 * $120);
    $123 = Math_fround($119 * $120);
    $124 = Math_fround($121 + $112);
    $125 = Math_fround($122 + $114);
    $126 = Math_fround($123 + $116);
    $127 = Math_fround($80 + $128);
    $129 = Math_fround(Math_fround(1.0) - $127);
    $130 = Math_fround(HEAPF32[$p0>>2]);
    $131 = Math_fround(HEAPF32[$5>>2]);
    $132 = Math_fround(HEAPF32[$6>>2]);
    $133 = Math_fround(HEAPF32[$p1>>2]);
    $134 = Math_fround(HEAPF32[$14>>2]);
    $135 = Math_fround(HEAPF32[$15>>2]);
    $136 = Math_fround(HEAPF32[$p2>>2]);
    $137 = Math_fround(HEAPF32[$23>>2]);
    $138 = Math_fround(HEAPF32[$24>>2]);
    $139 = Math_fround($136 * $128);
    $140 = Math_fround($137 * $128);
    $141 = Math_fround($138 * $128);
    $142 = Math_fround($133 * $80);
    $143 = Math_fround($134 * $80);
    $144 = Math_fround($135 * $80);
    $145 = Math_fround($142 + $139);
    $146 = Math_fround($143 + $140);
    $147 = Math_fround($144 + $141);
    $148 = Math_fround($130 * $129);
    $149 = Math_fround($131 * $129);
    $150 = Math_fround($129 * $132);
    $151 = Math_fround($148 + $145);
    $152 = Math_fround($149 + $146);
    $153 = Math_fround($150 + $147);
    $154 = Math_fround($124 - $151);
    $155 = Math_fround($125 - $152);
    $156 = Math_fround($126 - $153);
    $157 = Math_fround($154 * $154);
    $158 = Math_fround($155 * $155);
    $159 = Math_fround($157 + $158);
    $160 = Math_fround($156 * $156);
    $161 = Math_fround($160 + $159);
    $162 = (Math_fround(Math_sqrt((Math_fround($161)))));
    $163 = Math_fround(Math_fround(1.0) / $162);
    $164 = Math_fround($163 * $154);
    $165 = Math_fround($163 * $155);
    $166 = Math_fround($163 * $156);
    HEAPF32[$patchNormalInTriangle>>2] = $164;
    $167 = (($patchNormalInTriangle) + 4|0);
    HEAPF32[$167>>2] = $165;
    $168 = (($patchNormalInTriangle) + 8|0);
    HEAPF32[$168>>2] = $166;
    $169 = (($patchNormalInTriangle) + 12|0);
    HEAPF32[$169>>2] = Math_fround(0.0);
    break;
   }
  }
 } while(0);
 $170 = (($this) + 2324|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = HEAP32[$59>>2]|0;
 $173 = (($172) + 96|0);
 $174 = (($172) + 112|0);
 $175 = (($this) + 2336|0);
 $176 = (($this) + 2320|0);
 $177 = HEAP32[$176>>2]|0;
 (__ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration16generateContactsERKNS_6shdfnd3aos5Vec3VES6_S6_S6_S6_jS6_S6_RKNS3_6FloatVEPNS0_21MeshPersistentContactERj($p0,$p1,$p2,$n,$patchNormalInTriangle,$triangleIndex,$173,$174,$175,$177,$170)|0);
 $178 = HEAP32[$59>>2]|0;
 $179 = (($178) + 96|0);
 $180 = (($178) + 112|0);
 $181 = HEAP32[$176>>2]|0;
 __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration10generateEEERKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES6_jS6_S6_PNS0_21MeshPersistentContactERj(0,$179,$180,$75,$patchNormalInTriangle,$triangleIndex,$p0,$p1,$181,$170);
 __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration10generateEEERKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES6_jS6_S6_PNS0_21MeshPersistentContactERj(0,$179,$180,$75,$patchNormalInTriangle,$triangleIndex,$p1,$p2,$181,$170);
 __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration10generateEEERKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES6_jS6_S6_PNS0_21MeshPersistentContactERj(0,$179,$180,$75,$patchNormalInTriangle,$triangleIndex,$p0,$p2,$181,$170);
 $182 = HEAP32[$170>>2]|0;
 $183 = ($182|0)==($171|0);
 if ($183) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$maxPen>>2] = Math_fround(3.40282346638528859812E+38);
 $184 = ($171>>>0)<($182>>>0);
 if ($184) {
  $185 = (($this) + 2304|0);
  $186 = (($this) + 2308|0);
  $187 = (($this) + 2312|0);
  $188 = (($this) + 2256|0);
  $189 = (($this) + 2272|0);
  $190 = (($this) + 2288|0);
  $191 = (($this) + 2260|0);
  $192 = (($this) + 2276|0);
  $193 = (($this) + 2292|0);
  $194 = (($this) + 2264|0);
  $195 = (($this) + 2280|0);
  $196 = (($this) + 2296|0);
  $197 = (($maxPen) + 4|0);
  $$$i376 = Math_fround(3.40282346638528859812E+38);$i$0373 = $171;
  while(1) {
   $201 = HEAP32[$176>>2]|0;
   $202 = ((($201) + ($i$0373<<6)|0) + 44|0);
   $203 = Math_fround(HEAPF32[$202>>2]);
   $204 = Math_fround(HEAPF32[$185>>2]);
   $205 = Math_fround(HEAPF32[$186>>2]);
   $206 = Math_fround(HEAPF32[$187>>2]);
   $207 = (($201) + ($i$0373<<6)|0);
   $208 = Math_fround(HEAPF32[$207>>2]);
   $209 = ((($201) + ($i$0373<<6)|0) + 4|0);
   $210 = Math_fround(HEAPF32[$209>>2]);
   $211 = ((($201) + ($i$0373<<6)|0) + 8|0);
   $212 = Math_fround(HEAPF32[$211>>2]);
   $213 = Math_fround(HEAPF32[$188>>2]);
   $214 = Math_fround($208 * $213);
   $215 = Math_fround(HEAPF32[$189>>2]);
   $216 = Math_fround($210 * $215);
   $217 = Math_fround($214 + $216);
   $218 = Math_fround(HEAPF32[$190>>2]);
   $219 = Math_fround($212 * $218);
   $220 = Math_fround($217 + $219);
   $221 = Math_fround(HEAPF32[$191>>2]);
   $222 = Math_fround($208 * $221);
   $223 = Math_fround(HEAPF32[$192>>2]);
   $224 = Math_fround($210 * $223);
   $225 = Math_fround($222 + $224);
   $226 = Math_fround(HEAPF32[$193>>2]);
   $227 = Math_fround($212 * $226);
   $228 = Math_fround($225 + $227);
   $229 = Math_fround(HEAPF32[$194>>2]);
   $230 = Math_fround($208 * $229);
   $231 = Math_fround(HEAPF32[$195>>2]);
   $232 = Math_fround($210 * $231);
   $233 = Math_fround($230 + $232);
   $234 = Math_fround(HEAPF32[$196>>2]);
   $235 = Math_fround($212 * $234);
   $236 = Math_fround($233 + $235);
   $237 = Math_fround($204 + $220);
   $238 = Math_fround($205 + $228);
   $239 = Math_fround($206 + $236);
   HEAPF32[$207>>2] = $237;
   HEAPF32[$209>>2] = $238;
   HEAPF32[$211>>2] = $239;
   $240 = ((($201) + ($i$0373<<6)|0) + 12|0);
   HEAPF32[$240>>2] = Math_fround(0.0);
   $241 = $$$i376 > $203;
   $$$i = $241 ? $203 : $$$i376;
   ;HEAP32[$197+0>>2]=HEAP32[$$sroa$189+0>>2]|0;HEAP32[$197+4>>2]=HEAP32[$$sroa$189+4>>2]|0;HEAP32[$197+8>>2]=HEAP32[$$sroa$189+8>>2]|0;
   $242 = (($i$0373) + 1)|0;
   $243 = HEAP32[$170>>2]|0;
   $244 = ($242>>>0)<($243>>>0);
   if ($244) {
    $$$i376 = $$$i;$i$0373 = $242;
   } else {
    break;
   }
  }
  HEAPF32[$maxPen>>2] = $$$i;
  $199 = $243;
 } else {
  $199 = $182;
 }
 $198 = ($171>>>0)<($199>>>0);
 if ($198) {
  $200 = (($this) + 2240|0);
  $256 = $199;$i1$0371 = $171;
  while(1) {
   $248 = HEAP32[$176>>2]|0;
   $249 = ((($248) + ($i1$0371<<6)|0) + 16|0);
   $250 = Math_fround(HEAPF32[$249>>2]);
   $251 = ((($248) + ($i1$0371<<6)|0) + 20|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = ((($248) + ($i1$0371<<6)|0) + 24|0);
   $254 = Math_fround(HEAPF32[$253>>2]);
   $246 = (($i1$0371) + 1)|0;
   $255 = ($246>>>0)<($256>>>0);
   L44: do {
    if ($255) {
     $258 = $248;$276 = $256;$j$0370 = $246;
     while(1) {
      $257 = ((($258) + ($j$0370<<6)|0) + 16|0);
      $259 = Math_fround(HEAPF32[$257>>2]);
      $260 = ((($258) + ($j$0370<<6)|0) + 20|0);
      $261 = Math_fround(HEAPF32[$260>>2]);
      $262 = ((($258) + ($j$0370<<6)|0) + 24|0);
      $263 = Math_fround(HEAPF32[$262>>2]);
      $264 = Math_fround($259 - $250);
      $265 = Math_fround($261 - $252);
      $266 = Math_fround($263 - $254);
      $267 = Math_fround($264 * $264);
      $268 = Math_fround($265 * $265);
      $269 = Math_fround($267 + $268);
      $270 = Math_fround($266 * $266);
      $271 = Math_fround($269 + $270);
      $272 = Math_fround(HEAPF32[$200>>2]);
      $273 = $272 > $271;
      if ($273) {
       $274 = (($258) + ($j$0370<<6)|0);
       $275 = (($276) + -1)|0;
       $277 = (($258) + ($275<<6)|0);
       dest=$274+0|0; src=$277+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $278 = HEAP32[$170>>2]|0;
       $279 = (($278) + -1)|0;
       HEAP32[$170>>2] = $279;
       $280 = (($j$0370) + -1)|0;
       $283 = $279;$j$1 = $280;
      } else {
       $283 = $276;$j$1 = $j$0370;
      }
      $281 = (($j$1) + 1)|0;
      $282 = ($281>>>0)<($283>>>0);
      if (!($282)) {
       $247 = $283;
       break L44;
      }
      $$pre = HEAP32[$176>>2]|0;
      $258 = $$pre;$276 = $283;$j$0370 = $281;
     }
    } else {
     $247 = $256;
    }
   } while(0);
   $245 = ($246>>>0)<($247>>>0);
   if ($245) {
    $256 = $247;$i1$0371 = $246;
   } else {
    break;
   }
  }
 }
 __ZN5physx2Gu24PCMMeshContactGeneration23addManifoldPointToPatchERKNS_6shdfnd3aos5Vec3VERKNS3_6FloatVEj($this,$patchNormalInTriangle,$maxPen,$171);
 $284 = HEAP32[$170>>2]|0;
 $285 = ($284>>>0)>(15);
 if (!($285)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx2Gu24PCMMeshContactGeneration15processContactsEhb($this,3,1);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration15processTriangleERKNS0_9TriangleVEjRKNS0_8CapsuleVERKNS_6shdfnd3aos6FloatVEhPNS0_21MeshPersistentContactERj($triangleV,$triangleIndex,$capsule,$inflatedRadius,$trigFlag,$manifoldContacts,$numContacts) {
 $triangleV = $triangleV|0;
 $triangleIndex = $triangleIndex|0;
 $capsule = $capsule|0;
 $inflatedRadius = $inflatedRadius|0;
 $trigFlag = $trigFlag|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0);
 var $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0);
 var $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0;
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $n = 0, $p0 = 0, $p1 = 0, $p2 = 0, $patchNormalInTriangle = 0, $sqDist = 0, $t = 0, $u = 0, $v = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $p0 = sp + 128|0;
 $p1 = sp + 112|0;
 $p2 = sp + 96|0;
 $n = sp + 80|0;
 $t = sp + 64|0;
 $u = sp + 32|0;
 $v = sp + 16|0;
 $sqDist = sp;
 $patchNormalInTriangle = sp + 48|0;
 $0 = (($triangleV) + 96|0);
 ;HEAP32[$p0+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$p0+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$p0+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$p0+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (($triangleV) + 112|0);
 ;HEAP32[$p1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$p1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$p1+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$p1+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($triangleV) + 128|0);
 ;HEAP32[$p2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$p2+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$p2+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$p2+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($triangleV) + 112|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($triangleV) + 116|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($triangleV) + 120|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($triangleV) + 96|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($triangleV) + 100|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($triangleV) + 104|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($4 - $10);
 $16 = Math_fround($6 - $12);
 $17 = Math_fround($8 - $14);
 $18 = (($triangleV) + 128|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($triangleV) + 132|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($triangleV) + 136|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($19 - $10);
 $25 = Math_fround($21 - $12);
 $26 = Math_fround($23 - $14);
 $27 = Math_fround($16 * $26);
 $28 = Math_fround($17 * $25);
 $29 = Math_fround($27 - $28);
 $30 = Math_fround($17 * $24);
 $31 = Math_fround($15 * $26);
 $32 = Math_fround($30 - $31);
 $33 = Math_fround($15 * $25);
 $34 = Math_fround($16 * $24);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround($29 * $29);
 $37 = Math_fround($32 * $32);
 $38 = Math_fround($36 + $37);
 $39 = Math_fround($35 * $35);
 $40 = Math_fround($39 + $38);
 $41 = (Math_fround(Math_sqrt((Math_fround($40)))));
 $42 = Math_fround(Math_fround(1.0) / $41);
 $43 = Math_fround($42 * $29);
 $44 = Math_fround($42 * $32);
 $45 = Math_fround($35 * $42);
 HEAPF32[$n>>2] = $43;
 $46 = (($n) + 4|0);
 HEAPF32[$46>>2] = $44;
 $47 = (($n) + 8|0);
 HEAPF32[$47>>2] = $45;
 $48 = (($n) + 12|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = Math_fround(HEAPF32[$inflatedRadius>>2]);
 $50 = Math_fround($49 * $49);
 $51 = (($capsule) + 96|0);
 $52 = (($capsule) + 112|0);
 __ZN5physx2Gu33pcmDistanceSegmentTriangleSquaredERKNS_6shdfnd3aos5Vec3VES5_S5_S5_S5_RNS2_6FloatVES7_S7_($sqDist,$51,$52,$p0,$p1,$p2,$t,$u,$v);
 $53 = Math_fround(HEAPF32[$sqDist>>2]);
 $54 = $50 > $53;
 if (!($54)) {
  STACKTOP = sp;return 1;
 }
 $55 = Math_fround(HEAPF32[$u>>2]);
 $56 = $55 == Math_fround(0.0);
 do {
  if ($56) {
   $57 = Math_fround(HEAPF32[$v>>2]);
   $58 = $57 == Math_fround(0.0);
   if ($58) {
    $59 = $trigFlag & 40;
    $60 = ($59<<24>>24)==(0);
    if ($60) {
     label = 15;
     break;
    } else {
     $102 = $57;
     label = 16;
     break;
    }
   }
   $61 = $57 == Math_fround(1.0);
   $62 = $trigFlag&255;
   if ($61) {
    $63 = $62 & 48;
    $64 = ($63|0)==(0);
    if ($64) {
     label = 15;
     break;
    } else {
     $102 = $57;
     label = 16;
     break;
    }
   } else {
    $65 = $62 & 32;
    $66 = ($65|0)==(0);
    if ($66) {
     label = 15;
     break;
    } else {
     $102 = $57;
     label = 16;
     break;
    }
   }
  } else {
   $67 = $55 == Math_fround(1.0);
   $68 = Math_fround(HEAPF32[$v>>2]);
   $69 = $68 == Math_fround(0.0);
   if ($67) {
    if (!($69)) {
     $102 = $68;
     label = 16;
     break;
    }
    $70 = $trigFlag & 24;
    $71 = ($70<<24>>24)==(0);
    if ($71) {
     label = 15;
     break;
    } else {
     $102 = $68;
     label = 16;
     break;
    }
   }
   if ($69) {
    $72 = $trigFlag & 8;
    $73 = ($72<<24>>24)==(0);
    if ($73) {
     label = 15;
     break;
    } else {
     $102 = $68;
     label = 16;
     break;
    }
   }
   $74 = Math_fround($55 + $68);
   $75 = !($74 >= Math_fround(0.999899983406066894531));
   if ($75) {
    label = 15;
   } else {
    $76 = $trigFlag & 16;
    $77 = ($76<<24>>24)==(0);
    if ($77) {
     label = 15;
    } else {
     $102 = $68;
     label = 16;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   ;HEAP32[$patchNormalInTriangle+0>>2]=HEAP32[$n+0>>2]|0;HEAP32[$patchNormalInTriangle+4>>2]=HEAP32[$n+4>>2]|0;HEAP32[$patchNormalInTriangle+8>>2]=HEAP32[$n+8>>2]|0;HEAP32[$patchNormalInTriangle+12>>2]=HEAP32[$n+12>>2]|0;
  }
  else if ((label|0) == 16) {
   $78 = $53 == Math_fround(0.0);
   if ($78) {
    ;HEAP32[$patchNormalInTriangle+0>>2]=HEAP32[$n+0>>2]|0;HEAP32[$patchNormalInTriangle+4>>2]=HEAP32[$n+4>>2]|0;HEAP32[$patchNormalInTriangle+8>>2]=HEAP32[$n+8>>2]|0;HEAP32[$patchNormalInTriangle+12>>2]=HEAP32[$n+12>>2]|0;
    break;
   } else {
    $79 = (($capsule) + 112|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = (($capsule) + 116|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = (($capsule) + 120|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = (($capsule) + 96|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $87 = (($capsule) + 100|0);
    $88 = Math_fround(HEAPF32[$87>>2]);
    $89 = (($capsule) + 104|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = Math_fround($80 - $86);
    $92 = Math_fround($82 - $88);
    $93 = Math_fround($84 - $90);
    $94 = Math_fround(HEAPF32[$t>>2]);
    $95 = Math_fround($91 * $94);
    $96 = Math_fround($92 * $94);
    $97 = Math_fround($93 * $94);
    $98 = Math_fround($95 + $86);
    $99 = Math_fround($96 + $88);
    $100 = Math_fround($97 + $90);
    $101 = Math_fround($55 + $102);
    $103 = Math_fround(Math_fround(1.0) - $101);
    $104 = Math_fround(HEAPF32[$p0>>2]);
    $105 = (($p0) + 4|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $107 = (($p0) + 8|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $109 = Math_fround(HEAPF32[$p1>>2]);
    $110 = (($p1) + 4|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = (($p1) + 8|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = Math_fround(HEAPF32[$p2>>2]);
    $115 = (($p2) + 4|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = (($p2) + 8|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = Math_fround($114 * $102);
    $120 = Math_fround($116 * $102);
    $121 = Math_fround($118 * $102);
    $122 = Math_fround($109 * $55);
    $123 = Math_fround($111 * $55);
    $124 = Math_fround($113 * $55);
    $125 = Math_fround($122 + $119);
    $126 = Math_fround($123 + $120);
    $127 = Math_fround($124 + $121);
    $128 = Math_fround($104 * $103);
    $129 = Math_fround($106 * $103);
    $130 = Math_fround($103 * $108);
    $131 = Math_fround($128 + $125);
    $132 = Math_fround($129 + $126);
    $133 = Math_fround($130 + $127);
    $134 = Math_fround($98 - $131);
    $135 = Math_fround($99 - $132);
    $136 = Math_fround($100 - $133);
    $137 = Math_fround($134 * $134);
    $138 = Math_fround($135 * $135);
    $139 = Math_fround($137 + $138);
    $140 = Math_fround($136 * $136);
    $141 = Math_fround($140 + $139);
    $142 = (Math_fround(Math_sqrt((Math_fround($141)))));
    $143 = Math_fround(Math_fround(1.0) / $142);
    $144 = Math_fround($143 * $134);
    $145 = Math_fround($143 * $135);
    $146 = Math_fround($143 * $136);
    HEAPF32[$patchNormalInTriangle>>2] = $144;
    $147 = (($patchNormalInTriangle) + 4|0);
    HEAPF32[$147>>2] = $145;
    $148 = (($patchNormalInTriangle) + 8|0);
    HEAPF32[$148>>2] = $146;
    $149 = (($patchNormalInTriangle) + 12|0);
    HEAPF32[$149>>2] = Math_fround(0.0);
    break;
   }
  }
 } while(0);
 (__ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration16generateContactsERKNS_6shdfnd3aos5Vec3VES6_S6_S6_S6_jS6_S6_RKNS3_6FloatVEPNS0_21MeshPersistentContactERj($p0,$p1,$p2,$n,$patchNormalInTriangle,$triangleIndex,$51,$52,$inflatedRadius,$manifoldContacts,$numContacts)|0);
 __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration13generateEEMTDERKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES6_jS6_S6_PNS0_21MeshPersistentContactERj($51,$52,$inflatedRadius,$patchNormalInTriangle,$triangleIndex,$p0,$p1,$manifoldContacts,$numContacts);
 __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration13generateEEMTDERKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES6_jS6_S6_PNS0_21MeshPersistentContactERj($51,$52,$inflatedRadius,$patchNormalInTriangle,$triangleIndex,$p1,$p2,$manifoldContacts,$numContacts);
 __ZN5physx2Gu33PCMCapsuleVsMeshContactGeneration13generateEEMTDERKNS_6shdfnd3aos5Vec3VES6_RKNS3_6FloatVES6_jS6_S6_PNS0_21MeshPersistentContactERj($51,$52,$inflatedRadius,$patchNormalInTriangle,$triangleIndex,$p0,$p2,$manifoldContacts,$numContacts);
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu16SupportLocalImplINS0_9TriangleVEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_9TriangleVEE9doSupportERKNS_6shdfnd3aos5Vec3VE($agg$result,$this,$dir) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $dir = $dir|0;
 var $$in1$i$i = 0, $$in1$i19$i = 0, $$in2$i$i = 0, $$in2$i21$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = Math_fround(0), $b$a$i16$i = 0;
 var $phitmp164$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 96|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($5) + 100|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($5) + 104|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($5) + 108|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($5) + 112|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($5) + 116|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($5) + 120|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($5) + 124|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($5) + 128|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($5) + 132|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($5) + 136|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($5) + 140|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround(HEAPF32[$dir>>2]);
 $31 = (($dir) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($dir) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($7 * $30);
 $36 = Math_fround($9 * $32);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($11 * $34);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($15 * $30);
 $41 = Math_fround($17 * $32);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($19 * $34);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($23 * $30);
 $46 = Math_fround($25 * $32);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($27 * $34);
 $49 = Math_fround($47 + $48);
 $50 = $39 > $44;
 if ($50) {
  $51 = $39 > $49;
  $phitmp164$i = $51 ? $3 : $2;
  $69 = $phitmp164$i;
 } else {
  $69 = $2;
 }
 $52 = $44 > $49;
 HEAPF32[$1>>2] = $15;
 $53 = (($1) + 4|0);
 HEAPF32[$53>>2] = $17;
 $54 = (($1) + 8|0);
 HEAPF32[$54>>2] = $19;
 $55 = (($1) + 12|0);
 HEAPF32[$55>>2] = $21;
 HEAPF32[$0>>2] = $23;
 $56 = (($0) + 4|0);
 HEAPF32[$56>>2] = $25;
 $57 = (($0) + 8|0);
 HEAPF32[$57>>2] = $27;
 $58 = (($0) + 12|0);
 HEAPF32[$58>>2] = $29;
 $b$a$i16$i = $52 ? $1 : $0;
 $59 = Math_fround(HEAPF32[$b$a$i16$i>>2]);
 $$in1$i19$i = (($b$a$i16$i) + 4|0);
 $60 = Math_fround(HEAPF32[$$in1$i19$i>>2]);
 $$in2$i21$i = (($b$a$i16$i) + 8|0);
 $61 = Math_fround(HEAPF32[$$in2$i21$i>>2]);
 HEAPF32[$3>>2] = $7;
 $62 = (($3) + 4|0);
 HEAPF32[$62>>2] = $9;
 $63 = (($3) + 8|0);
 HEAPF32[$63>>2] = $11;
 $64 = (($3) + 12|0);
 HEAPF32[$64>>2] = $13;
 HEAPF32[$2>>2] = $59;
 $65 = (($2) + 4|0);
 HEAPF32[$65>>2] = $60;
 $66 = (($2) + 8|0);
 HEAPF32[$66>>2] = $61;
 $67 = (($2) + 12|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = Math_fround(HEAPF32[$69>>2]);
 $$in1$i$i = (($69) + 4|0);
 $70 = Math_fround(HEAPF32[$$in1$i$i>>2]);
 $$in2$i$i = (($69) + 8|0);
 $71 = Math_fround(HEAPF32[$$in2$i$i>>2]);
 HEAPF32[$agg$result>>2] = $68;
 $72 = (($agg$result) + 4|0);
 HEAPF32[$72>>2] = $70;
 $73 = (($agg$result) + 8|0);
 HEAPF32[$73>>2] = $71;
 $74 = (($agg$result) + 12|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_9TriangleVEE9doSupportERKNS_6shdfnd3aos5Vec3VERNS5_6FloatVESA_($this,$dir,$min,$max) {
 $this = $this|0;
 $dir = $dir|0;
 $min = $min|0;
 $max = $max|0;
 var $$$i$i = Math_fround(0), $$$i12$i = Math_fround(0), $$$i17$i = Math_fround(0), $$$i22$i = Math_fround(0), $$sroa$132$i = 0, $$sroa$136$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$sroa$136$i = sp + 12|0;
 $$sroa$132$i = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 96|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 100|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 104|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($1) + 112|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($1) + 116|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($1) + 120|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 128|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($1) + 132|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($1) + 136|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$dir>>2]);
 $21 = (($dir) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($dir) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($3 * $20);
 $26 = Math_fround($5 * $22);
 $27 = Math_fround($25 + $26);
 $28 = Math_fround($7 * $24);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($9 * $20);
 $31 = Math_fround($11 * $22);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($13 * $24);
 $34 = Math_fround($32 + $33);
 $35 = Math_fround($15 * $20);
 $36 = Math_fround($17 * $22);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($19 * $24);
 $39 = Math_fround($37 + $38);
 $40 = $34 > $39;
 $$$i22$i = $40 ? $34 : $39;
 $41 = $29 > $$$i22$i;
 $$$i17$i = $41 ? $29 : $$$i22$i;
 HEAPF32[$max>>2] = $$$i17$i;
 $42 = (($max) + 4|0);
 ;HEAP32[$42+0>>2]=HEAP32[$$sroa$136$i+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$$sroa$136$i+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$$sroa$136$i+8>>2]|0;
 $$$i12$i = $40 ? $39 : $34;
 $43 = $29 > $$$i12$i;
 $$$i$i = $43 ? $$$i12$i : $29;
 HEAPF32[$min>>2] = $$$i$i;
 $44 = (($min) + 4|0);
 ;HEAP32[$44+0>>2]=HEAP32[$$sroa$132$i+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$$sroa$132$i+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$$sroa$132$i+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu16SupportLocalImplINS0_9TriangleVEE13populateVertsEPKhjPKNS_6PxVec3EPNS_6shdfnd3aos5Vec3VE($this,$inds,$numInds,$originalVerts,$verts) {
 $this = $this|0;
 $inds = $inds|0;
 $numInds = $numInds|0;
 $originalVerts = $originalVerts|0;
 $verts = $verts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numInds|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i$01$i = 0;
 }
 while(1) {
  $1 = (($inds) + ($i$01$i)|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = $2&255;
  $4 = (($originalVerts) + (($3*12)|0)|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = ((($originalVerts) + (($3*12)|0)|0) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = ((($originalVerts) + (($3*12)|0)|0) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($verts) + ($i$01$i<<4)|0);
  HEAPF32[$10>>2] = $5;
  $11 = ((($verts) + ($i$01$i<<4)|0) + 4|0);
  HEAPF32[$11>>2] = $7;
  $12 = ((($verts) + ($i$01$i<<4)|0) + 8|0);
  HEAPF32[$12>>2] = $9;
  $13 = ((($verts) + ($i$01$i<<4)|0) + 12|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = (($i$01$i) + 1)|0;
  $exitcond$i = ($14|0)==($numInds|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $14;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu22pcmContactConvexConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i$i38 = Math_fround(0), $$1 = 0, $$1$i$i$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0);
 var $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0;
 var $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0);
 var $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0;
 var $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0;
 var $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0);
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0);
 var $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0);
 var $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0);
 var $362 = Math_fround(0), $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0;
 var $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0);
 var $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = 0, $415 = Math_fround(0);
 var $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = 0;
 var $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0);
 var $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0);
 var $470 = 0, $471 = Math_fround(0), $472 = Math_fround(0), $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = Math_fround(0), $490 = Math_fround(0), $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0);
 var $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0);
 var $524 = Math_fround(0), $525 = Math_fround(0), $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $closestA = 0, $closestB = 0, $contactDist = 0, $convexHull0 = 0, $convexHull1 = 0, $doOverlapTest$1$off0140 = 0, $doOverlapTest$3$off0 = 0, $localNormalPen = 0;
 var $localNormalPen2 = 0, $localPointA = 0, $localPointA1 = 0, $normal = 0, $numContacts = 0, $penDep = 0, $projectBreakingThreshold = 0, $replaceBreakingThreshold = 0, $status$0 = 0, $supportMap = 0, $supportMap5 = 0, $transf0 = 0, $transf1 = 0, $vQuat0 = 0, $vQuat1 = 0, $vScale0 = 0, $vScale1 = 0, $worldNormal = 0, $worldNormal8 = 0, $zero$sroa$1 = 0;
 var $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 896|0;
 $zero$sroa$1 = sp + 832|0;
 $zeroV = sp + 784|0;
 $vScale0 = sp + 800|0;
 $vScale1 = sp + 816|0;
 $contactDist = sp + 768|0;
 $transf0 = sp + 736|0;
 $transf1 = sp + 704|0;
 $aToB = sp + 640|0;
 $projectBreakingThreshold = sp + 624|0;
 $replaceBreakingThreshold = sp + 608|0;
 $vQuat0 = sp + 592|0;
 $vQuat1 = sp;
 $convexHull0 = sp + 272|0;
 $convexHull1 = sp + 16|0;
 $closestA = sp + 224|0;
 $closestB = sp + 240|0;
 $normal = sp + 256|0;
 $penDep = sp + 480|0;
 $numContacts = sp + 884|0;
 $localPointA = sp + 496|0;
 $localNormalPen = sp + 512|0;
 $supportMap = sp + 864|0;
 $localPointA1 = sp + 528|0;
 $localNormalPen2 = sp + 544|0;
 $worldNormal = sp + 560|0;
 $supportMap5 = sp + 844|0;
 $worldNormal8 = sp + 576|0;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0;
 $2 = (($shape0) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($shape1) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $6 = (($shape0) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($shape0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($shape0) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$vScale0>>2] = $7;
 $12 = (($vScale0) + 4|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($vScale0) + 8|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($vScale0) + 12|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($shape1) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($shape1) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($shape1) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 HEAPF32[$vScale1>>2] = $16;
 $21 = (($vScale1) + 4|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($vScale1) + 8|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($vScale1) + 12|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = Math_fround(HEAPF32[$contactDistance>>2]);
 HEAPF32[$contactDist>>2] = $24;
 $25 = Math_fround(HEAPF32[$transform0>>2]);
 $26 = (($transform0) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($transform0) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($transform0) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($transform0) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($32) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($32) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 HEAPF32[$transf0>>2] = $25;
 $38 = (($transf0) + 4|0);
 HEAPF32[$38>>2] = $27;
 $39 = (($transf0) + 8|0);
 HEAPF32[$39>>2] = $29;
 $40 = (($transf0) + 12|0);
 HEAPF32[$40>>2] = $31;
 $41 = (($transf0) + 16|0);
 HEAPF32[$41>>2] = $33;
 $42 = (($transf0) + 20|0);
 HEAPF32[$42>>2] = $35;
 $43 = (($transf0) + 24|0);
 HEAPF32[$43>>2] = $37;
 $44 = (($transf0) + 28|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = Math_fround(HEAPF32[$transform1>>2]);
 $46 = (($transform1) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($transform1) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($transform1) + 12|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($transform1) + 16|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($52) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($52) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 HEAPF32[$transf1>>2] = $45;
 $58 = (($transf1) + 4|0);
 HEAPF32[$58>>2] = $47;
 $59 = (($transf1) + 8|0);
 HEAPF32[$59>>2] = $49;
 $60 = (($transf1) + 12|0);
 HEAPF32[$60>>2] = $51;
 $61 = (($transf1) + 16|0);
 HEAPF32[$61>>2] = $53;
 $62 = (($transf1) + 20|0);
 HEAPF32[$62>>2] = $55;
 $63 = (($transf1) + 24|0);
 HEAPF32[$63>>2] = $57;
 $64 = (($transf1) + 28|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = Math_fround(-$45);
 $66 = Math_fround(-$47);
 $67 = Math_fround(-$49);
 $68 = Math_fround($33 - $53);
 $69 = Math_fround($35 - $55);
 $70 = Math_fround($37 - $57);
 $71 = Math_fround($51 * $51);
 $72 = Math_fround($71 + Math_fround(-0.5));
 $73 = Math_fround($72 * $68);
 $74 = Math_fround($72 * $69);
 $75 = Math_fround($72 * $70);
 $76 = Math_fround($70 * $66);
 $77 = Math_fround($69 * $67);
 $78 = Math_fround($76 - $77);
 $79 = Math_fround($68 * $67);
 $80 = Math_fround($70 * $65);
 $81 = Math_fround($79 - $80);
 $82 = Math_fround($69 * $65);
 $83 = Math_fround($68 * $66);
 $84 = Math_fround($82 - $83);
 $85 = Math_fround($51 * $78);
 $86 = Math_fround($51 * $81);
 $87 = Math_fround($51 * $84);
 $88 = Math_fround($73 + $85);
 $89 = Math_fround($74 + $86);
 $90 = Math_fround($75 + $87);
 $91 = Math_fround($68 * $65);
 $92 = Math_fround($69 * $66);
 $93 = Math_fround($91 + $92);
 $94 = Math_fround($70 * $67);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($95 * $65);
 $97 = Math_fround($95 * $66);
 $98 = Math_fround($95 * $67);
 $99 = Math_fround($96 + $88);
 $100 = Math_fround($97 + $89);
 $101 = Math_fround($90 + $98);
 $102 = Math_fround($99 * Math_fround(2.0));
 $103 = Math_fround($100 * Math_fround(2.0));
 $104 = Math_fround($101 * Math_fround(2.0));
 $105 = Math_fround($51 * $31);
 $106 = Math_fround($25 * $65);
 $107 = Math_fround($27 * $66);
 $108 = Math_fround($106 + $107);
 $109 = Math_fround($29 * $67);
 $110 = Math_fround($108 + $109);
 $111 = Math_fround($105 - $110);
 $112 = Math_fround($31 * $65);
 $113 = Math_fround($31 * $66);
 $114 = Math_fround($31 * $67);
 $115 = Math_fround($51 * $25);
 $116 = Math_fround($51 * $27);
 $117 = Math_fround($51 * $29);
 $118 = Math_fround($29 * $66);
 $119 = Math_fround($27 * $67);
 $120 = Math_fround($118 - $119);
 $121 = Math_fround($25 * $67);
 $122 = Math_fround($29 * $65);
 $123 = Math_fround($121 - $122);
 $124 = Math_fround($27 * $65);
 $125 = Math_fround($25 * $66);
 $126 = Math_fround($124 - $125);
 $127 = Math_fround($115 + $112);
 $128 = Math_fround($116 + $113);
 $129 = Math_fround($117 + $114);
 $130 = Math_fround($120 + $127);
 $131 = Math_fround($123 + $128);
 $132 = Math_fround($126 + $129);
 $133 = (($aToB) + 48|0);
 HEAPF32[$133>>2] = $102;
 $134 = (($aToB) + 52|0);
 HEAPF32[$134>>2] = $103;
 $135 = (($aToB) + 56|0);
 HEAPF32[$135>>2] = $104;
 $136 = (($aToB) + 60|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 $137 = Math_fround($130 + $130);
 $138 = Math_fround($131 + $131);
 $139 = Math_fround($132 + $132);
 $140 = Math_fround($130 * $137);
 $141 = Math_fround($131 * $138);
 $142 = Math_fround($132 * $139);
 $143 = Math_fround($131 * $137);
 $144 = Math_fround($132 * $137);
 $145 = Math_fround($111 * $137);
 $146 = Math_fround($132 * $138);
 $147 = Math_fround($111 * $138);
 $148 = Math_fround($111 * $139);
 $149 = Math_fround(Math_fround(1.0) - $140);
 $150 = Math_fround(Math_fround(1.0) - $141);
 $151 = Math_fround($150 - $142);
 $152 = Math_fround($143 + $148);
 $153 = Math_fround($144 - $147);
 $154 = Math_fround($143 - $148);
 $155 = Math_fround($149 - $142);
 $156 = Math_fround($146 + $145);
 $157 = Math_fround($144 + $147);
 $158 = Math_fround($146 - $145);
 $159 = Math_fround($149 - $141);
 HEAPF32[$aToB>>2] = $151;
 $160 = (($aToB) + 4|0);
 HEAPF32[$160>>2] = $152;
 $161 = (($aToB) + 8|0);
 HEAPF32[$161>>2] = $153;
 $162 = (($aToB) + 12|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 $163 = (($aToB) + 16|0);
 HEAPF32[$163>>2] = $154;
 $164 = (($aToB) + 20|0);
 HEAPF32[$164>>2] = $155;
 $165 = (($aToB) + 24|0);
 HEAPF32[$165>>2] = $156;
 $166 = (($aToB) + 28|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = (($aToB) + 32|0);
 HEAPF32[$167>>2] = $157;
 $168 = (($aToB) + 36|0);
 HEAPF32[$168>>2] = $158;
 $169 = (($aToB) + 40|0);
 HEAPF32[$169>>2] = $159;
 $170 = (($aToB) + 44|0);
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = HEAP32[$2>>2]|0;
 $172 = HEAP32[$4>>2]|0;
 $173 = (($171) + 52|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($171) + 56|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = (($171) + 60|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = Math_fround(HEAPF32[$vScale0>>2]);
 $180 = Math_fround(HEAPF32[$12>>2]);
 $181 = Math_fround(HEAPF32[$13>>2]);
 $182 = Math_fround($174 * $179);
 $183 = Math_fround($176 * $180);
 $184 = Math_fround($178 * $181);
 $185 = !($182 <= $183);
 $$$i$i38 = $185 ? $183 : $182;
 $186 = !($$$i$i38 <= $184);
 $187 = $186 ? $184 : $$$i$i38;
 $188 = Math_fround($187 * Math_fround(0.25));
 $189 = (($172) + 52|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($172) + 56|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($172) + 60|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround(HEAPF32[$vScale1>>2]);
 $196 = Math_fround(HEAPF32[$21>>2]);
 $197 = Math_fround(HEAPF32[$22>>2]);
 $198 = Math_fround($190 * $195);
 $199 = Math_fround($192 * $196);
 $200 = Math_fround($194 * $197);
 $201 = !($198 <= $199);
 $$$i$i = $201 ? $199 : $198;
 $202 = !($$$i$i <= $200);
 $203 = $202 ? $200 : $$$i$i;
 $204 = Math_fround($203 * Math_fround(0.25));
 $205 = (($1) + 32|0);
 $206 = HEAP8[$205>>0]|0;
 $207 = $188 > $204;
 $$$i = $207 ? $204 : $188;
 $208 = Math_fround($$$i * Math_fround(0.800000011920928955078));
 HEAPF32[$projectBreakingThreshold>>2] = $208;
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($1,$aToB,$projectBreakingThreshold,0);
 $209 = HEAP8[$205>>0]|0;
 $210 = ($209<<24>>24)==($206<<24>>24);
 if ($210) {
  $211 = $206&255;
  $212 = (554160 + ($211<<2)|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = Math_fround($$$i * $213);
  $215 = (($1) + 16|0);
  $216 = Math_fround(HEAPF32[$215>>2]);
  $217 = (($1) + 20|0);
  $218 = Math_fround(HEAPF32[$217>>2]);
  $219 = (($1) + 24|0);
  $220 = Math_fround(HEAPF32[$219>>2]);
  $221 = Math_fround($102 - $216);
  $222 = Math_fround($103 - $218);
  $223 = Math_fround($104 - $220);
  $224 = Math_fround(-$221);
  $225 = Math_fround(-$222);
  $226 = Math_fround(-$223);
  $227 = $221 > $224;
  $$$i$i$i$i = $227 ? $221 : $224;
  $228 = $222 > $225;
  $229 = $228 ? $222 : $225;
  $230 = $223 > $226;
  $$1$i$i$i$i = $230 ? $223 : $226;
  $231 = !($$$i$i$i$i >= $229);
  $$$i$i$i = $231 ? $229 : $$$i$i$i$i;
  $232 = !($$1$i$i$i$i >= Math_fround(0.0));
  $233 = $232 ? Math_fround(0.0) : $$$i$i$i$i;
  $234 = $$$i$i$i >= $233;
  $235 = $234 ? $$$i$i$i : $233;
  $236 = $235 > $214;
  if (!($236)) {
   $237 = (($1) + 4|0);
   $238 = (($1) + 8|0);
   $239 = Math_fround(HEAPF32[$237>>2]);
   $240 = Math_fround(HEAPF32[$1>>2]);
   $241 = Math_fround($131 * $239);
   $242 = Math_fround($130 * $240);
   $243 = (($1) + 12|0);
   $244 = Math_fround(HEAPF32[$238>>2]);
   $245 = Math_fround($132 * $244);
   $246 = Math_fround($241 + $242);
   $247 = Math_fround(HEAPF32[$243>>2]);
   $248 = Math_fround($111 * $247);
   $249 = Math_fround($246 + $245);
   $250 = (554200 + ($211<<2)|0);
   $251 = Math_fround($249 + $248);
   $252 = Math_fround(HEAPF32[$250>>2]);
   $253 = $252 > $251;
   if (!($253)) {
    $543 = ($206<<24>>24)==(0);
    if ($543) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($worldNormal8,$1,$transf1);
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($1,$contactBuffer,$worldNormal8,$transf1);
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $254 = Math_fround($$$i * Math_fround(0.0500000007450580596924));
 HEAPF32[$replaceBreakingThreshold>>2] = $254;
 $255 = Math_fround(HEAPF32[$6>>2]);
 $256 = $255 == Math_fround(1.0);
 if ($256) {
  $257 = Math_fround(HEAPF32[$8>>2]);
  $258 = $257 == Math_fround(1.0);
  if ($258) {
   $259 = Math_fround(HEAPF32[$10>>2]);
   $260 = $259 == Math_fround(1.0);
   $313 = $260;
  } else {
   $313 = 0;
  }
 } else {
  $313 = 0;
 }
 $261 = Math_fround(HEAPF32[$15>>2]);
 $262 = $261 == Math_fround(1.0);
 if ($262) {
  $263 = Math_fround(HEAPF32[$17>>2]);
  $264 = $263 == Math_fround(1.0);
  if ($264) {
   $265 = Math_fround(HEAPF32[$19>>2]);
   $266 = $265 == Math_fround(1.0);
   $314 = $266;
  } else {
   $314 = 0;
  }
 } else {
  $314 = 0;
 }
 $267 = (($shape0) + 16|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = (($shape0) + 20|0);
 $270 = Math_fround(HEAPF32[$269>>2]);
 $271 = (($shape0) + 24|0);
 $272 = Math_fround(HEAPF32[$271>>2]);
 $273 = (($shape0) + 28|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 HEAPF32[$vQuat0>>2] = $268;
 $275 = (($vQuat0) + 4|0);
 HEAPF32[$275>>2] = $270;
 $276 = (($vQuat0) + 8|0);
 HEAPF32[$276>>2] = $272;
 $277 = (($vQuat0) + 12|0);
 HEAPF32[$277>>2] = $274;
 $278 = (($shape1) + 16|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = (($shape1) + 20|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = (($shape1) + 24|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = (($shape1) + 28|0);
 $285 = Math_fround(HEAPF32[$284>>2]);
 HEAPF32[$vQuat1>>2] = $279;
 $286 = (($vQuat1) + 4|0);
 HEAPF32[$286>>2] = $281;
 $287 = (($vQuat1) + 8|0);
 HEAPF32[$287>>2] = $283;
 $288 = (($vQuat1) + 12|0);
 HEAPF32[$288>>2] = $285;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull0,$171,$zeroV,$vScale0,$vQuat0);
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull1,$172,$zeroV,$vScale1,$vQuat1);
 ;HEAP32[$closestA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closestB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penDep>>2] = Math_fround(0.0);
 $289 = (($penDep) + 4|0);
 ;HEAP32[$289+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$289+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$289+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 do {
  if ($313) {
   if ($314) {
    $290 = (($1) + 34|0);
    $291 = (($1) + 38|0);
    $292 = (($1) + 33|0);
    $293 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_24ShrunkConvexHullNoScaleVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($convexHull0,$convexHull1,$aToB,$contactDist,$closestA,$closestB,$normal,$penDep,$290,$291,$292)|0);
    $status$0 = $293;
    break;
   } else {
    $294 = (($1) + 34|0);
    $295 = (($1) + 38|0);
    $296 = (($1) + 33|0);
    $297 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_24ShrunkConvexHullNoScaleVENS0_17ShrunkConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($convexHull0,$convexHull1,$aToB,$contactDist,$closestA,$closestB,$normal,$penDep,$294,$295,$296)|0);
    $status$0 = $297;
    break;
   }
  } else {
   if ($314) {
    $298 = (($1) + 34|0);
    $299 = (($1) + 38|0);
    $300 = (($1) + 33|0);
    $301 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_17ShrunkConvexHullVENS0_24ShrunkConvexHullNoScaleVEEEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSB_6FloatVERNSB_5Vec3VESJ_SJ_RSF_PhSL_Rh($convexHull0,$convexHull1,$aToB,$contactDist,$closestB,$closestB,$normal,$penDep,$298,$299,$300)|0);
    $status$0 = $301;
    break;
   } else {
    $302 = (($1) + 34|0);
    $303 = (($1) + 38|0);
    $304 = (($1) + 33|0);
    $305 = (__ZN5physx2Gu22gjkRelativePenetrationINS0_17ShrunkConvexHullVES2_EEjRKT_RKT0_RKNS_6shdfnd3aos15PsMatTransformVERKNSA_6FloatVERNSA_5Vec3VESI_SI_RSE_PhSK_Rh($convexHull0,$convexHull1,$aToB,$contactDist,$closestB,$closestB,$normal,$penDep,$302,$303,$304)|0);
    $status$0 = $305;
    break;
   }
  }
 } while(0);
 HEAPF32[$1>>2] = $130;
 $306 = (($1) + 4|0);
 HEAPF32[$306>>2] = $131;
 $307 = (($1) + 8|0);
 HEAPF32[$307>>2] = $132;
 $308 = (($1) + 12|0);
 HEAPF32[$308>>2] = $111;
 $309 = (($1) + 16|0);
 HEAPF32[$309>>2] = $102;
 $310 = (($1) + 20|0);
 HEAPF32[$310>>2] = $103;
 $311 = (($1) + 24|0);
 HEAPF32[$311>>2] = $104;
 $312 = (($1) + 28|0);
 HEAPF32[$312>>2] = Math_fround(0.0);
 HEAP32[$numContacts>>2] = 0;
 if ((($status$0|0) == 0)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 } else if ((($status$0|0) == 3)) {
  $315 = (__ZN5physx2GuL34fullContactsGenerationConvexConvexERKNS0_11ConvexHullVERS1_RKNS_6shdfnd3aos12PsTransformVES9_bbPNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNS6_5Vec3VERKNS6_6FloatVEb($convexHull0,$convexHull1,$transf0,$transf1,$313,$314,$contactBuffer,$numContacts,$contactBuffer,$1,$normal,$contactDist,0)|0);
  $$1 = $315;
  STACKTOP = sp;return ($$1|0);
 } else {
  $316 = HEAP8[$205>>0]|0;
  $317 = ($316<<24>>24)==(0);
  $318 = ($status$0|0)==(1);
  if ($317) {
   do {
    if ($318) {
     $432 = Math_fround(HEAPF32[$closestA>>2]);
     $433 = (($closestA) + 4|0);
     $434 = Math_fround(HEAPF32[$433>>2]);
     $435 = (($closestA) + 8|0);
     $436 = Math_fround(HEAPF32[$435>>2]);
     $437 = Math_fround(HEAPF32[$133>>2]);
     $438 = Math_fround(HEAPF32[$134>>2]);
     $439 = Math_fround(HEAPF32[$135>>2]);
     $440 = Math_fround($432 - $437);
     $441 = Math_fround($434 - $438);
     $442 = Math_fround($436 - $439);
     $443 = Math_fround(HEAPF32[$aToB>>2]);
     $444 = Math_fround($440 * $443);
     $445 = Math_fround(HEAPF32[$160>>2]);
     $446 = Math_fround($441 * $445);
     $447 = Math_fround($444 + $446);
     $448 = Math_fround(HEAPF32[$161>>2]);
     $449 = Math_fround($442 * $448);
     $450 = Math_fround($447 + $449);
     $451 = Math_fround(HEAPF32[$163>>2]);
     $452 = Math_fround($440 * $451);
     $453 = Math_fround(HEAPF32[$164>>2]);
     $454 = Math_fround($441 * $453);
     $455 = Math_fround($452 + $454);
     $456 = Math_fround(HEAPF32[$165>>2]);
     $457 = Math_fround($442 * $456);
     $458 = Math_fround($455 + $457);
     $459 = Math_fround(HEAPF32[$167>>2]);
     $460 = Math_fround($440 * $459);
     $461 = Math_fround(HEAPF32[$168>>2]);
     $462 = Math_fround($441 * $461);
     $463 = Math_fround($460 + $462);
     $464 = Math_fround(HEAPF32[$169>>2]);
     $465 = Math_fround($442 * $464);
     $466 = Math_fround($463 + $465);
     $467 = Math_fround(HEAPF32[$normal>>2]);
     $468 = (($normal) + 4|0);
     $469 = Math_fround(HEAPF32[$468>>2]);
     $470 = (($normal) + 8|0);
     $471 = Math_fround(HEAPF32[$470>>2]);
     $472 = Math_fround(HEAPF32[$penDep>>2]);
     HEAPF32[$contactBuffer>>2] = $450;
     $473 = (($contactBuffer) + 4|0);
     HEAPF32[$473>>2] = $458;
     $474 = (($contactBuffer) + 8|0);
     HEAPF32[$474>>2] = $466;
     $475 = (($contactBuffer) + 12|0);
     HEAPF32[$475>>2] = Math_fround(0.0);
     $476 = (($contactBuffer) + 16|0);
     ;HEAP32[$476+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$476+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$476+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$476+12>>2]=HEAP32[$closestB+12>>2]|0;
     HEAP32[$numContacts>>2] = 1;
     $477 = (($contactBuffer) + 32|0);
     HEAPF32[$477>>2] = $467;
     $478 = (($contactBuffer) + 36|0);
     HEAPF32[$478>>2] = $469;
     $479 = (($contactBuffer) + 40|0);
     HEAPF32[$479>>2] = $471;
     $480 = (($contactBuffer) + 44|0);
     HEAPF32[$480>>2] = $472;
     $doOverlapTest$3$off0 = 0;
    } else {
     $481 = (($supportMap5) + 4|0);
     HEAP8[$481>>0] = 0;
     HEAP32[$supportMap5>>2] = ((550832 + 8|0));
     $482 = (($supportMap5) + 8|0);
     HEAP32[$482>>2] = $convexHull0;
     $483 = (($supportMap5) + 12|0);
     HEAP32[$483>>2] = $convexHull1;
     $484 = (($supportMap5) + 16|0);
     HEAP32[$484>>2] = $aToB;
     $485 = (($1) + 34|0);
     $486 = (($1) + 38|0);
     $487 = (($1) + 33|0);
     $488 = HEAP8[$487>>0]|0;
     $489 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($convexHull0,$convexHull1,$supportMap5,$485,$486,$488,$closestA,$closestB,$normal,$penDep,0)|0);
     if ((($489|0) == 6)) {
      $490 = Math_fround(HEAPF32[$closestA>>2]);
      $491 = (($closestA) + 4|0);
      $492 = Math_fround(HEAPF32[$491>>2]);
      $493 = (($closestA) + 8|0);
      $494 = Math_fround(HEAPF32[$493>>2]);
      $495 = Math_fround(HEAPF32[$133>>2]);
      $496 = Math_fround(HEAPF32[$134>>2]);
      $497 = Math_fround(HEAPF32[$135>>2]);
      $498 = Math_fround($490 - $495);
      $499 = Math_fround($492 - $496);
      $500 = Math_fround($494 - $497);
      $501 = Math_fround(HEAPF32[$aToB>>2]);
      $502 = Math_fround($498 * $501);
      $503 = Math_fround(HEAPF32[$160>>2]);
      $504 = Math_fround($499 * $503);
      $505 = Math_fround($502 + $504);
      $506 = Math_fround(HEAPF32[$161>>2]);
      $507 = Math_fround($500 * $506);
      $508 = Math_fround($505 + $507);
      $509 = Math_fround(HEAPF32[$163>>2]);
      $510 = Math_fround($498 * $509);
      $511 = Math_fround(HEAPF32[$164>>2]);
      $512 = Math_fround($499 * $511);
      $513 = Math_fround($510 + $512);
      $514 = Math_fround(HEAPF32[$165>>2]);
      $515 = Math_fround($500 * $514);
      $516 = Math_fround($513 + $515);
      $517 = Math_fround(HEAPF32[$167>>2]);
      $518 = Math_fround($498 * $517);
      $519 = Math_fround(HEAPF32[$168>>2]);
      $520 = Math_fround($499 * $519);
      $521 = Math_fround($518 + $520);
      $522 = Math_fround(HEAPF32[$169>>2]);
      $523 = Math_fround($500 * $522);
      $524 = Math_fround($521 + $523);
      $525 = Math_fround(HEAPF32[$normal>>2]);
      $526 = (($normal) + 4|0);
      $527 = Math_fround(HEAPF32[$526>>2]);
      $528 = (($normal) + 8|0);
      $529 = Math_fround(HEAPF32[$528>>2]);
      $530 = Math_fround(HEAPF32[$penDep>>2]);
      $531 = HEAP32[$numContacts>>2]|0;
      $532 = (($contactBuffer) + (($531*48)|0)|0);
      HEAPF32[$532>>2] = $508;
      $533 = ((($contactBuffer) + (($531*48)|0)|0) + 4|0);
      HEAPF32[$533>>2] = $516;
      $534 = ((($contactBuffer) + (($531*48)|0)|0) + 8|0);
      HEAPF32[$534>>2] = $524;
      $535 = ((($contactBuffer) + (($531*48)|0)|0) + 12|0);
      HEAPF32[$535>>2] = Math_fround(0.0);
      $536 = ((($contactBuffer) + (($531*48)|0)|0) + 16|0);
      ;HEAP32[$536+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$536+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$536+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$536+12>>2]=HEAP32[$closestB+12>>2]|0;
      $537 = (($531) + 1)|0;
      HEAP32[$numContacts>>2] = $537;
      $538 = ((($contactBuffer) + (($531*48)|0)|0) + 32|0);
      HEAPF32[$538>>2] = $525;
      $539 = ((($contactBuffer) + (($531*48)|0)|0) + 36|0);
      HEAPF32[$539>>2] = $527;
      $540 = ((($contactBuffer) + (($531*48)|0)|0) + 40|0);
      HEAPF32[$540>>2] = $529;
      $541 = ((($contactBuffer) + (($531*48)|0)|0) + 44|0);
      HEAPF32[$541>>2] = $530;
      $doOverlapTest$3$off0 = 0;
      break;
     } else if ((($489|0) == 4)) {
      $doOverlapTest$3$off0 = 1;
      break;
     } else {
      $doOverlapTest$3$off0 = 0;
      break;
     }
    }
   } while(0);
   $542 = (__ZN5physx2GuL34fullContactsGenerationConvexConvexERKNS0_11ConvexHullVERS1_RKNS_6shdfnd3aos12PsTransformVES9_bbPNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNS6_5Vec3VERKNS6_6FloatVEb($convexHull0,$convexHull1,$transf0,$transf1,$313,$314,$contactBuffer,$numContacts,$contactBuffer,$1,$normal,$contactDist,$doOverlapTest$3$off0)|0);
   $$1 = $542;
   STACKTOP = sp;return ($$1|0);
  }
  do {
   if ($318) {
    $319 = Math_fround(HEAPF32[$closestA>>2]);
    $320 = (($closestA) + 4|0);
    $321 = Math_fround(HEAPF32[$320>>2]);
    $322 = (($closestA) + 8|0);
    $323 = Math_fround(HEAPF32[$322>>2]);
    $324 = Math_fround(HEAPF32[$133>>2]);
    $325 = Math_fround(HEAPF32[$134>>2]);
    $326 = Math_fround(HEAPF32[$135>>2]);
    $327 = Math_fround($319 - $324);
    $328 = Math_fround($321 - $325);
    $329 = Math_fround($323 - $326);
    $330 = Math_fround(HEAPF32[$aToB>>2]);
    $331 = Math_fround($327 * $330);
    $332 = Math_fround(HEAPF32[$160>>2]);
    $333 = Math_fround($328 * $332);
    $334 = Math_fround($331 + $333);
    $335 = Math_fround(HEAPF32[$161>>2]);
    $336 = Math_fround($329 * $335);
    $337 = Math_fround($334 + $336);
    $338 = Math_fround(HEAPF32[$163>>2]);
    $339 = Math_fround($327 * $338);
    $340 = Math_fround(HEAPF32[$164>>2]);
    $341 = Math_fround($328 * $340);
    $342 = Math_fround($339 + $341);
    $343 = Math_fround(HEAPF32[$165>>2]);
    $344 = Math_fround($329 * $343);
    $345 = Math_fround($342 + $344);
    $346 = Math_fround(HEAPF32[$167>>2]);
    $347 = Math_fround($327 * $346);
    $348 = Math_fround(HEAPF32[$168>>2]);
    $349 = Math_fround($328 * $348);
    $350 = Math_fround($347 + $349);
    $351 = Math_fround(HEAPF32[$169>>2]);
    $352 = Math_fround($329 * $351);
    $353 = Math_fround($350 + $352);
    HEAPF32[$localPointA>>2] = $337;
    $354 = (($localPointA) + 4|0);
    HEAPF32[$354>>2] = $345;
    $355 = (($localPointA) + 8|0);
    HEAPF32[$355>>2] = $353;
    $356 = (($localPointA) + 12|0);
    HEAPF32[$356>>2] = Math_fround(0.0);
    $357 = Math_fround(HEAPF32[$normal>>2]);
    $358 = (($normal) + 4|0);
    $359 = Math_fround(HEAPF32[$358>>2]);
    $360 = (($normal) + 8|0);
    $361 = Math_fround(HEAPF32[$360>>2]);
    $362 = Math_fround(HEAPF32[$penDep>>2]);
    HEAPF32[$localNormalPen>>2] = $357;
    $363 = (($localNormalPen) + 4|0);
    HEAPF32[$363>>2] = $359;
    $364 = (($localNormalPen) + 8|0);
    HEAPF32[$364>>2] = $361;
    $365 = (($localNormalPen) + 12|0);
    HEAPF32[$365>>2] = $362;
    ;HEAP32[$contactBuffer+0>>2]=HEAP32[$localPointA+0>>2]|0;HEAP32[$contactBuffer+4>>2]=HEAP32[$localPointA+4>>2]|0;HEAP32[$contactBuffer+8>>2]=HEAP32[$localPointA+8>>2]|0;HEAP32[$contactBuffer+12>>2]=HEAP32[$localPointA+12>>2]|0;
    $366 = (($contactBuffer) + 16|0);
    ;HEAP32[$366+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$366+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$366+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$366+12>>2]=HEAP32[$closestB+12>>2]|0;
    HEAP32[$numContacts>>2] = 1;
    $367 = (($contactBuffer) + 32|0);
    ;HEAP32[$367+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$367+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$367+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$367+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
    (__ZN5physx2Gu25PersistentContactManifold16addManifoldPointERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($1,$localPointA,$closestB,$localNormalPen,$replaceBreakingThreshold)|0);
    label = 24;
   } else {
    $368 = (($supportMap) + 4|0);
    HEAP8[$368>>0] = 0;
    HEAP32[$supportMap>>2] = ((550832 + 8|0));
    $369 = (($supportMap) + 8|0);
    HEAP32[$369>>2] = $convexHull0;
    $370 = (($supportMap) + 12|0);
    HEAP32[$370>>2] = $convexHull1;
    $371 = (($supportMap) + 16|0);
    HEAP32[$371>>2] = $aToB;
    $372 = (($1) + 34|0);
    $373 = (($1) + 38|0);
    $374 = (($1) + 33|0);
    $375 = HEAP8[$374>>0]|0;
    $376 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($convexHull0,$convexHull1,$supportMap,$372,$373,$375,$closestA,$closestB,$normal,$penDep,0)|0);
    if ((($376|0) == 4)) {
     $doOverlapTest$1$off0140 = 1;
     break;
    } else if (!((($376|0) == 6))) {
     label = 24;
     break;
    }
    $377 = Math_fround(HEAPF32[$closestA>>2]);
    $378 = (($closestA) + 4|0);
    $379 = Math_fround(HEAPF32[$378>>2]);
    $380 = (($closestA) + 8|0);
    $381 = Math_fround(HEAPF32[$380>>2]);
    $382 = Math_fround(HEAPF32[$133>>2]);
    $383 = Math_fround(HEAPF32[$134>>2]);
    $384 = Math_fround(HEAPF32[$135>>2]);
    $385 = Math_fround($377 - $382);
    $386 = Math_fround($379 - $383);
    $387 = Math_fround($381 - $384);
    $388 = Math_fround(HEAPF32[$aToB>>2]);
    $389 = Math_fround($385 * $388);
    $390 = Math_fround(HEAPF32[$160>>2]);
    $391 = Math_fround($386 * $390);
    $392 = Math_fround($389 + $391);
    $393 = Math_fround(HEAPF32[$161>>2]);
    $394 = Math_fround($387 * $393);
    $395 = Math_fround($392 + $394);
    $396 = Math_fround(HEAPF32[$163>>2]);
    $397 = Math_fround($385 * $396);
    $398 = Math_fround(HEAPF32[$164>>2]);
    $399 = Math_fround($386 * $398);
    $400 = Math_fround($397 + $399);
    $401 = Math_fround(HEAPF32[$165>>2]);
    $402 = Math_fround($387 * $401);
    $403 = Math_fround($400 + $402);
    $404 = Math_fround(HEAPF32[$167>>2]);
    $405 = Math_fround($385 * $404);
    $406 = Math_fround(HEAPF32[$168>>2]);
    $407 = Math_fround($386 * $406);
    $408 = Math_fround($405 + $407);
    $409 = Math_fround(HEAPF32[$169>>2]);
    $410 = Math_fround($387 * $409);
    $411 = Math_fround($408 + $410);
    HEAPF32[$localPointA1>>2] = $395;
    $412 = (($localPointA1) + 4|0);
    HEAPF32[$412>>2] = $403;
    $413 = (($localPointA1) + 8|0);
    HEAPF32[$413>>2] = $411;
    $414 = (($localPointA1) + 12|0);
    HEAPF32[$414>>2] = Math_fround(0.0);
    $415 = Math_fround(HEAPF32[$normal>>2]);
    $416 = (($normal) + 4|0);
    $417 = Math_fround(HEAPF32[$416>>2]);
    $418 = (($normal) + 8|0);
    $419 = Math_fround(HEAPF32[$418>>2]);
    $420 = Math_fround(HEAPF32[$penDep>>2]);
    HEAPF32[$localNormalPen2>>2] = $415;
    $421 = (($localNormalPen2) + 4|0);
    HEAPF32[$421>>2] = $417;
    $422 = (($localNormalPen2) + 8|0);
    HEAPF32[$422>>2] = $419;
    $423 = (($localNormalPen2) + 12|0);
    HEAPF32[$423>>2] = $420;
    $424 = HEAP32[$numContacts>>2]|0;
    $425 = (($contactBuffer) + (($424*48)|0)|0);
    ;HEAP32[$425+0>>2]=HEAP32[$localPointA1+0>>2]|0;HEAP32[$425+4>>2]=HEAP32[$localPointA1+4>>2]|0;HEAP32[$425+8>>2]=HEAP32[$localPointA1+8>>2]|0;HEAP32[$425+12>>2]=HEAP32[$localPointA1+12>>2]|0;
    $426 = ((($contactBuffer) + (($424*48)|0)|0) + 16|0);
    ;HEAP32[$426+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$426+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$426+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$426+12>>2]=HEAP32[$closestB+12>>2]|0;
    $427 = (($424) + 1)|0;
    HEAP32[$numContacts>>2] = $427;
    $428 = ((($contactBuffer) + (($424*48)|0)|0) + 32|0);
    ;HEAP32[$428+0>>2]=HEAP32[$localNormalPen2+0>>2]|0;HEAP32[$428+4>>2]=HEAP32[$localNormalPen2+4>>2]|0;HEAP32[$428+8>>2]=HEAP32[$localNormalPen2+8>>2]|0;HEAP32[$428+12>>2]=HEAP32[$localNormalPen2+12>>2]|0;
    (__ZN5physx2Gu25PersistentContactManifold16addManifoldPointERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($1,$localPointA1,$closestB,$localNormalPen2,$replaceBreakingThreshold)|0);
    label = 24;
   }
  } while(0);
  if ((label|0) == 24) {
   $429 = HEAP8[$205>>0]|0;
   $430 = ($429&255)<($206&255);
   if ($430) {
    $doOverlapTest$1$off0140 = 0;
   } else {
    __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($worldNormal,$1,$transf1);
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($1,$contactBuffer,$worldNormal,$transf1);
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   }
  }
  $431 = (__ZN5physx2GuL34fullContactsGenerationConvexConvexERKNS0_11ConvexHullVERS1_RKNS_6shdfnd3aos12PsTransformVES9_bbPNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNS6_5Vec3VERKNS6_6FloatVEb($convexHull0,$convexHull1,$transf0,$transf1,$313,$314,$contactBuffer,$numContacts,$contactBuffer,$1,$normal,$contactDist,$doOverlapTest$1$off0140)|0);
  $$1 = $431;
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZN5physx2GuL34fullContactsGenerationConvexConvexERKNS0_11ConvexHullVERS1_RKNS_6shdfnd3aos12PsTransformVES9_bbPNS0_17PersistentContactERjRNS0_13ContactBufferERNS0_25PersistentContactManifoldERNS6_5Vec3VERKNS6_6FloatVEb($convexHull0,$convexHull1,$transf0,$transf1,$idtScale0,$idtScale1,$manifoldContacts,$numContacts,$contactBuffer,$manifold,$normal,$contactDist,$doOverlapTest) {
 $convexHull0 = $convexHull0|0;
 $convexHull1 = $convexHull1|0;
 $transf0 = $transf0|0;
 $transf1 = $transf1|0;
 $idtScale0 = $idtScale0|0;
 $idtScale1 = $idtScale1|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactBuffer = $contactBuffer|0;
 $manifold = $manifold|0;
 $normal = $normal|0;
 $contactDist = $contactDist|0;
 $doOverlapTest = $doOverlapTest|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buff0 = 0, $buff1 = 0, $or$cond = 0, $polyData0 = 0, $polyData1 = 0, $worldNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $polyData0 = sp + 216|0;
 $polyData1 = sp + 144|0;
 $buff0 = sp + 16|0;
 $buff1 = sp + 80|0;
 $worldNormal = sp;
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHull0,$idtScale0,$polyData0);
 __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHull1,$idtScale1,$polyData1);
 $0 = (($convexHull0) + 96|0);
 $1 = (($convexHull0) + 144|0);
 $2 = (($buff0) + 32|0);
 HEAP32[$2>>2] = $transf0;
 $3 = (($buff0) + 36|0);
 HEAP32[$3>>2] = $0;
 $4 = (($buff0) + 40|0);
 HEAP32[$4>>2] = $1;
 $5 = (($buff0) + 44|0);
 $6 = $idtScale0&1;
 HEAP8[$5>>0] = $6;
 if ($idtScale0) {
  HEAP32[$buff0>>2] = ((546744 + 8|0));
  $7 = (($buff0) + 48|0);
  HEAP32[$7>>2] = $convexHull0;
 } else {
  HEAP32[$buff0>>2] = ((546712 + 8|0));
  $8 = (($buff0) + 48|0);
  HEAP32[$8>>2] = $convexHull0;
 }
 $9 = (($convexHull1) + 96|0);
 $10 = (($convexHull1) + 144|0);
 $11 = (($buff1) + 32|0);
 HEAP32[$11>>2] = $transf1;
 $12 = (($buff1) + 36|0);
 HEAP32[$12>>2] = $9;
 $13 = (($buff1) + 40|0);
 HEAP32[$13>>2] = $10;
 $14 = (($buff1) + 44|0);
 $15 = $idtScale1&1;
 HEAP8[$14>>0] = $15;
 if ($idtScale1) {
  HEAP32[$buff1>>2] = ((546744 + 8|0));
  $16 = (($buff1) + 48|0);
  HEAP32[$16>>2] = $convexHull1;
 } else {
  HEAP32[$buff1>>2] = ((546712 + 8|0));
  $17 = (($buff1) + 48|0);
  HEAP32[$17>>2] = $convexHull1;
 }
 $18 = HEAP32[$numContacts>>2]|0;
 $19 = (__ZN5physx2Gu27generateFullContactManifoldERNS0_13PolygonalDataES2_PNS0_12SupportLocalES4_PNS0_17PersistentContactERjRKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VEb($polyData0,$polyData1,$buff0,$buff1,$manifoldContacts,$numContacts,$contactDist,$normal,$doOverlapTest)|0);
 if (!($19)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = HEAP32[$numContacts>>2]|0;
 $21 = ($20|0)!=($18|0);
 $22 = ($18|0)!=(0);
 $or$cond = $21 & $22;
 if ($or$cond) {
  $23 = (($20) + -1)|0;
  HEAP32[$numContacts>>2] = $23;
  $24 = (($manifoldContacts) + 48|0);
  $$02 = $24;$25 = $23;
 } else {
  $$02 = $manifoldContacts;$25 = $20;
 }
 __ZN5physx2Gu25PersistentContactManifold24addBatchManifoldContactsEPKNS0_17PersistentContactEj($manifold,$$02,$25);
 __ZN5physx2Gu25PersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($worldNormal,$manifold,$transf1);
 __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($manifold,$contactBuffer,$worldNormal,$transf1);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu20PCMContactConvexMeshERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERKNS_9PxBounds3ERKNS_24PxTriangleMeshGeometryLLERKNS_11PxTransformESJ_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESP_bbRNS0_33MultiplePersistentContactManifoldE($polyData,$polyMap,$minMargin,$hullAABB,$shapeMesh,$transform0,$transform1,$contactDistance,$contactBuffer,$convexScaling,$meshScaling,$idtConvexScale,$idtMeshScale,$multiManifold) {
 $polyData = $polyData|0;
 $polyMap = $polyMap|0;
 $minMargin = $minMargin|0;
 $hullAABB = $hullAABB|0;
 $shapeMesh = $shapeMesh|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = Math_fround($contactDistance);
 $contactBuffer = $contactBuffer|0;
 $convexScaling = $convexScaling|0;
 $meshScaling = $meshScaling|0;
 $idtConvexScale = $idtConvexScale|0;
 $idtMeshScale = $idtMeshScale|0;
 $multiManifold = $multiManifold|0;
 var $$$i$i$i$i = Math_fround(0), $$$i$i$i$i$i = Math_fround(0), $$1$i$i$i$i$i = Math_fround(0), $$not = 0, $$pre = 0, $$pre$phi27Z2D = 0, $$pre$phi29Z2D = 0, $$pre$phi31Z2D = 0, $$pre$phiZ2D = 0, $$pre26 = 0, $$pre28 = 0, $$pre30 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0);
 var $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0);
 var $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0;
 var $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0);
 var $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0);
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0;
 var $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0);
 var $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0);
 var $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0;
 var $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_maxPen$i = 0, $aToB = 0, $blockCallback = 0, $contactDist = 0, $convexTransform = 0, $count$01$i$i$i = 0, $delayedContacts = 0, $edgeFlags$05$i$i$i = 0, $hmd = 0, $hullOBB = 0, $i$04$i = 0, $i$1$i = 0;
 var $meshTransform = 0, $projectBreakingThreshold = 0, $replaceBreakingThreshold = 0, $scevgep$i$i$i$i$i$i = 0, $triInds$04$i$i$i = 0, $vertInds$03$i$i$i = 0, $verts$02$i$i$i = 0, $world1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5040|0;
 $_maxPen$i = sp + 4848|0;
 $contactDist = sp + 4832|0;
 $convexTransform = sp + 16|0;
 $meshTransform = sp + 48|0;
 $aToB = sp + 80|0;
 $replaceBreakingThreshold = sp + 144|0;
 $projectBreakingThreshold = sp;
 $world1 = sp + 4992|0;
 $hullOBB = sp + 4928|0;
 $hmd = sp + 4896|0;
 $delayedContacts = sp + 4912|0;
 $blockCallback = sp + 160|0;
 $0 = Math_fround(HEAPF32[$transform0>>2]);
 $1 = (($transform0) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($transform0) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($transform0) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($transform0) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($7) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($7) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(HEAPF32[$transform1>>2]);
 $14 = (($transform1) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($transform1) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($transform1) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($transform1) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($20) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($20) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 HEAPF32[$contactDist>>2] = $contactDistance;
 HEAPF32[$convexTransform>>2] = $0;
 $26 = (($convexTransform) + 4|0);
 HEAPF32[$26>>2] = $2;
 $27 = (($convexTransform) + 8|0);
 HEAPF32[$27>>2] = $4;
 $28 = (($convexTransform) + 12|0);
 HEAPF32[$28>>2] = $6;
 $29 = (($convexTransform) + 16|0);
 HEAPF32[$29>>2] = $8;
 $30 = (($convexTransform) + 20|0);
 HEAPF32[$30>>2] = $10;
 $31 = (($convexTransform) + 24|0);
 HEAPF32[$31>>2] = $12;
 $32 = (($convexTransform) + 28|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 HEAPF32[$meshTransform>>2] = $13;
 $33 = (($meshTransform) + 4|0);
 HEAPF32[$33>>2] = $15;
 $34 = (($meshTransform) + 8|0);
 HEAPF32[$34>>2] = $17;
 $35 = (($meshTransform) + 12|0);
 HEAPF32[$35>>2] = $19;
 $36 = (($meshTransform) + 16|0);
 HEAPF32[$36>>2] = $21;
 $37 = (($meshTransform) + 20|0);
 HEAPF32[$37>>2] = $23;
 $38 = (($meshTransform) + 24|0);
 HEAPF32[$38>>2] = $25;
 $39 = (($meshTransform) + 28|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = Math_fround(-$13);
 $41 = Math_fround(-$15);
 $42 = Math_fround(-$17);
 $43 = Math_fround($8 - $21);
 $44 = Math_fround($10 - $23);
 $45 = Math_fround($12 - $25);
 $46 = Math_fround($19 * $19);
 $47 = Math_fround($46 + Math_fround(-0.5));
 $48 = Math_fround($47 * $43);
 $49 = Math_fround($47 * $44);
 $50 = Math_fround($47 * $45);
 $51 = Math_fround($45 * $41);
 $52 = Math_fround($44 * $42);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($43 * $42);
 $55 = Math_fround($45 * $40);
 $56 = Math_fround($54 - $55);
 $57 = Math_fround($44 * $40);
 $58 = Math_fround($43 * $41);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($19 * $53);
 $61 = Math_fround($19 * $56);
 $62 = Math_fround($19 * $59);
 $63 = Math_fround($48 + $60);
 $64 = Math_fround($49 + $61);
 $65 = Math_fround($50 + $62);
 $66 = Math_fround($43 * $40);
 $67 = Math_fround($44 * $41);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($45 * $42);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($70 * $40);
 $72 = Math_fround($70 * $41);
 $73 = Math_fround($70 * $42);
 $74 = Math_fround($71 + $63);
 $75 = Math_fround($72 + $64);
 $76 = Math_fround($65 + $73);
 $77 = Math_fround($74 * Math_fround(2.0));
 $78 = Math_fround($75 * Math_fround(2.0));
 $79 = Math_fround($76 * Math_fround(2.0));
 $80 = Math_fround($19 * $6);
 $81 = Math_fround($0 * $40);
 $82 = Math_fround($2 * $41);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($4 * $42);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($80 - $85);
 $87 = Math_fround($6 * $40);
 $88 = Math_fround($6 * $41);
 $89 = Math_fround($6 * $42);
 $90 = Math_fround($19 * $0);
 $91 = Math_fround($19 * $2);
 $92 = Math_fround($19 * $4);
 $93 = Math_fround($4 * $41);
 $94 = Math_fround($2 * $42);
 $95 = Math_fround($93 - $94);
 $96 = Math_fround($0 * $42);
 $97 = Math_fround($4 * $40);
 $98 = Math_fround($96 - $97);
 $99 = Math_fround($2 * $40);
 $100 = Math_fround($0 * $41);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($90 + $87);
 $103 = Math_fround($91 + $88);
 $104 = Math_fround($92 + $89);
 $105 = Math_fround($95 + $102);
 $106 = Math_fround($98 + $103);
 $107 = Math_fround($101 + $104);
 $108 = (($aToB) + 48|0);
 HEAPF32[$108>>2] = $77;
 $109 = (($aToB) + 52|0);
 HEAPF32[$109>>2] = $78;
 $110 = (($aToB) + 56|0);
 HEAPF32[$110>>2] = $79;
 $111 = (($aToB) + 60|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = Math_fround($105 + $105);
 $113 = Math_fround($106 + $106);
 $114 = Math_fround($107 + $107);
 $115 = Math_fround($105 * $112);
 $116 = Math_fround($106 * $113);
 $117 = Math_fround($107 * $114);
 $118 = Math_fround($106 * $112);
 $119 = Math_fround($107 * $112);
 $120 = Math_fround($86 * $112);
 $121 = Math_fround($107 * $113);
 $122 = Math_fround($86 * $113);
 $123 = Math_fround($86 * $114);
 $124 = Math_fround(Math_fround(1.0) - $115);
 $125 = Math_fround(Math_fround(1.0) - $116);
 $126 = Math_fround($125 - $117);
 $127 = Math_fround($118 + $123);
 $128 = Math_fround($119 - $122);
 $129 = Math_fround($118 - $123);
 $130 = Math_fround($124 - $117);
 $131 = Math_fround($121 + $120);
 $132 = Math_fround($119 + $122);
 $133 = Math_fround($121 - $120);
 $134 = Math_fround($124 - $116);
 HEAPF32[$aToB>>2] = $126;
 $135 = (($aToB) + 4|0);
 HEAPF32[$135>>2] = $127;
 $136 = (($aToB) + 8|0);
 HEAPF32[$136>>2] = $128;
 $137 = (($aToB) + 12|0);
 HEAPF32[$137>>2] = Math_fround(0.0);
 $138 = (($aToB) + 16|0);
 HEAPF32[$138>>2] = $129;
 $139 = (($aToB) + 20|0);
 HEAPF32[$139>>2] = $130;
 $140 = (($aToB) + 24|0);
 HEAPF32[$140>>2] = $131;
 $141 = (($aToB) + 28|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 $142 = (($aToB) + 32|0);
 HEAPF32[$142>>2] = $132;
 $143 = (($aToB) + 36|0);
 HEAPF32[$143>>2] = $133;
 $144 = (($aToB) + 40|0);
 HEAPF32[$144>>2] = $134;
 $145 = (($aToB) + 44|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = Math_fround(HEAPF32[$minMargin>>2]);
 $147 = Math_fround($146 * Math_fround(0.0500000007450580596924));
 HEAPF32[$replaceBreakingThreshold>>2] = $147;
 $148 = (($multiManifold) + 53|0);
 $149 = HEAP8[$148>>0]|0;
 $150 = Math_fround($146 * Math_fround(0.20000000298023223877));
 $151 = (($multiManifold) + 16|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($multiManifold) + 20|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($multiManifold) + 24|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = Math_fround($77 - $152);
 $158 = Math_fround($78 - $154);
 $159 = Math_fround($79 - $156);
 $160 = Math_fround(-$157);
 $161 = Math_fround(-$158);
 $162 = Math_fround(-$159);
 $163 = $157 > $160;
 $$$i$i$i$i$i = $163 ? $157 : $160;
 $164 = $158 > $161;
 $165 = $164 ? $158 : $161;
 $166 = $159 > $162;
 $$1$i$i$i$i$i = $166 ? $159 : $162;
 $167 = !($$$i$i$i$i$i >= $165);
 $$$i$i$i$i = $167 ? $165 : $$$i$i$i$i$i;
 $168 = !($$1$i$i$i$i$i >= Math_fround(0.0));
 $169 = $168 ? Math_fround(0.0) : $$$i$i$i$i$i;
 $170 = $$$i$i$i$i >= $169;
 $171 = $170 ? $$$i$i$i$i : $169;
 $172 = $171 > $150;
 if ($172) {
  $$pre26 = (($multiManifold) + 4|0);
  $$pre28 = (($multiManifold) + 8|0);
  $$pre30 = (($multiManifold) + 12|0);
  $$pre$phi27Z2D = $$pre26;$$pre$phi29Z2D = $$pre28;$$pre$phi31Z2D = $$pre30;$$pre$phiZ2D = $multiManifold;
 } else {
  $173 = (($multiManifold) + 4|0);
  $174 = (($multiManifold) + 8|0);
  $175 = Math_fround(HEAPF32[$173>>2]);
  $176 = Math_fround(HEAPF32[$multiManifold>>2]);
  $177 = Math_fround($106 * $175);
  $178 = Math_fround($105 * $176);
  $179 = (($multiManifold) + 12|0);
  $180 = Math_fround(HEAPF32[$174>>2]);
  $181 = Math_fround($107 * $180);
  $182 = Math_fround($177 + $178);
  $183 = Math_fround(HEAPF32[$179>>2]);
  $184 = Math_fround($86 * $183);
  $185 = Math_fround($182 + $181);
  $186 = Math_fround($185 + $184);
  $187 = $186 < Math_fround(0.999800026416778564453);
  if ($187) {
   $$pre$phi27Z2D = $173;$$pre$phi29Z2D = $174;$$pre$phi31Z2D = $179;$$pre$phiZ2D = $multiManifold;
  } else {
   $188 = Math_fround($146 * Math_fround(0.800000011920928955078));
   HEAPF32[$projectBreakingThreshold>>2] = $188;
   $189 = (($multiManifold) + 52|0);
   $190 = HEAP8[$189>>0]|0;
   $191 = ($190<<24>>24)==(0);
   if ($191) {
    $415 = (__ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVE($multiManifold,$contactBuffer,$meshTransform)|0);
    STACKTOP = sp;return ($415|0);
   }
   $192 = $190&255;
   $196 = $192;$i$04$i = 0;
   while(1) {
    $193 = ((($multiManifold) + ($i$04$i)|0) + 48|0);
    $194 = HEAP8[$193>>0]|0;
    $195 = (($196) + -2)|0;
    $197 = ($i$04$i>>>0)<($195>>>0);
    $198 = $197 ? $i$04$i : $195;
    $199 = (($198) + 1)|0;
    $200 = ((($multiManifold) + ($199)|0) + 48|0);
    $201 = HEAP8[$200>>0]|0;
    $202 = $201&255;
    $203 = ((($multiManifold) + (($202*400)|0)|0) + 64|0);
    $204 = HEAP8[$200>>0]|0;
    $205 = $204&255;
    $206 = ((($multiManifold) + (($205*400)|0)|0) + 192|0);
    $207 = HEAP8[$200>>0]|0;
    $208 = $207&255;
    $209 = ((($multiManifold) + (($208*400)|0)|0) + 320|0);
    $210 = $194&255;
    $211 = ((($multiManifold) + (($210*400)|0)|0) + 64|0);
    __ZN5physx2Gu31SinglePersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($_maxPen$i,$211,$aToB,$projectBreakingThreshold,$contactDist);
    $212 = ((($multiManifold) + (($210*400)|0)|0) + 448|0);
    $213 = HEAP32[$212>>2]|0;
    $214 = ($213|0)==(0);
    if ($214) {
     $215 = HEAP8[$189>>0]|0;
     $216 = (($215) + -1)<<24>>24;
     HEAP8[$189>>0] = $216;
     $217 = $216&255;
     $218 = ((($multiManifold) + ($217)|0) + 48|0);
     $219 = HEAP8[$218>>0]|0;
     HEAP8[$218>>0] = $194;
     HEAP8[$193>>0] = $219;
     $220 = (($i$04$i) + -1)|0;
     $i$1$i = $220;
    } else {
     $221 = Math_fround(HEAPF32[$_maxPen$i>>2]);
     $222 = ((($multiManifold) + ($210<<2)|0) + 32|0);
     HEAPF32[$222>>2] = $221;
     $i$1$i = $i$04$i;
    }
    $223 = (($i$1$i) + 1)|0;
    $224 = HEAP8[$189>>0]|0;
    $225 = $224&255;
    $226 = ($223>>>0)<($225>>>0);
    if ($226) {
     $196 = $225;$i$04$i = $223;
    } else {
     break;
    }
   }
   $$pre = HEAP8[$148>>0]|0;
   $$not = ($$pre<<24>>24)==($149<<24>>24);
   if ($$not) {
    $415 = (__ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVE($multiManifold,$contactBuffer,$meshTransform)|0);
    STACKTOP = sp;return ($415|0);
   } else {
    $$pre$phi27Z2D = $173;$$pre$phi29Z2D = $174;$$pre$phi31Z2D = $179;$$pre$phiZ2D = $multiManifold;
   }
  }
 }
 $227 = (($multiManifold) + 52|0);
 HEAP8[$227>>0] = 0;
 HEAPF32[$$pre$phiZ2D>>2] = $105;
 HEAPF32[$$pre$phi27Z2D>>2] = $106;
 HEAPF32[$$pre$phi29Z2D>>2] = $107;
 HEAPF32[$$pre$phi31Z2D>>2] = $86;
 HEAPF32[$151>>2] = $77;
 HEAPF32[$153>>2] = $78;
 HEAPF32[$155>>2] = $79;
 $228 = (($multiManifold) + 28|0);
 HEAPF32[$228>>2] = Math_fround(0.0);
 $229 = (($shapeMesh) + 40|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = Math_fround(HEAPF32[$transform0>>2]);
 $232 = Math_fround($231 + $231);
 $233 = (($transform0) + 4|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = Math_fround($234 + $234);
 $236 = (($transform0) + 8|0);
 $237 = Math_fround(HEAPF32[$236>>2]);
 $238 = Math_fround($237 + $237);
 $239 = (($transform0) + 12|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 $241 = Math_fround($232 * $240);
 $242 = Math_fround($235 * $240);
 $243 = Math_fround($240 * $238);
 $244 = Math_fround($231 * $232);
 $245 = Math_fround($231 * $235);
 $246 = Math_fround($231 * $238);
 $247 = Math_fround($234 * $235);
 $248 = Math_fround($234 * $238);
 $249 = Math_fround($237 * $238);
 $250 = Math_fround(Math_fround(1.0) - $247);
 $251 = Math_fround($250 - $249);
 HEAPF32[$_maxPen$i>>2] = $251;
 $252 = Math_fround($245 + $243);
 $253 = (($_maxPen$i) + 4|0);
 HEAPF32[$253>>2] = $252;
 $254 = Math_fround($246 - $242);
 $255 = (($_maxPen$i) + 8|0);
 HEAPF32[$255>>2] = $254;
 $256 = Math_fround($245 - $243);
 $257 = (($_maxPen$i) + 12|0);
 HEAPF32[$257>>2] = $256;
 $258 = Math_fround(Math_fround(1.0) - $244);
 $259 = Math_fround($258 - $249);
 $260 = (($_maxPen$i) + 16|0);
 HEAPF32[$260>>2] = $259;
 $261 = Math_fround($248 + $241);
 $262 = (($_maxPen$i) + 20|0);
 HEAPF32[$262>>2] = $261;
 $263 = Math_fround($246 + $242);
 $264 = (($_maxPen$i) + 24|0);
 HEAPF32[$264>>2] = $263;
 $265 = Math_fround($248 - $241);
 $266 = (($_maxPen$i) + 28|0);
 HEAPF32[$266>>2] = $265;
 $267 = Math_fround($258 - $247);
 $268 = (($_maxPen$i) + 32|0);
 HEAPF32[$268>>2] = $267;
 $269 = (($_maxPen$i) + 36|0);
 $270 = (($_maxPen$i) + 40|0);
 $271 = (($_maxPen$i) + 44|0);
 $272 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$269>>2] = $272;
 $273 = (($transform0) + 20|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 HEAPF32[$270>>2] = $274;
 $275 = (($transform0) + 24|0);
 $276 = Math_fround(HEAPF32[$275>>2]);
 HEAPF32[$271>>2] = $276;
 $277 = Math_fround(HEAPF32[$transform1>>2]);
 $278 = Math_fround($277 + $277);
 $279 = (($transform1) + 4|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = Math_fround($280 + $280);
 $282 = (($transform1) + 8|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = Math_fround($283 + $283);
 $285 = (($transform1) + 12|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = Math_fround($278 * $286);
 $288 = Math_fround($281 * $286);
 $289 = Math_fround($286 * $284);
 $290 = Math_fround($277 * $278);
 $291 = Math_fround($277 * $281);
 $292 = Math_fround($277 * $284);
 $293 = Math_fround($280 * $281);
 $294 = Math_fround($280 * $284);
 $295 = Math_fround($283 * $284);
 $296 = Math_fround(Math_fround(1.0) - $293);
 $297 = Math_fround($296 - $295);
 HEAPF32[$world1>>2] = $297;
 $298 = Math_fround($291 + $289);
 $299 = (($world1) + 4|0);
 HEAPF32[$299>>2] = $298;
 $300 = Math_fround($292 - $288);
 $301 = (($world1) + 8|0);
 HEAPF32[$301>>2] = $300;
 $302 = Math_fround($291 - $289);
 $303 = (($world1) + 12|0);
 HEAPF32[$303>>2] = $302;
 $304 = Math_fround(Math_fround(1.0) - $290);
 $305 = Math_fround($304 - $295);
 $306 = (($world1) + 16|0);
 HEAPF32[$306>>2] = $305;
 $307 = Math_fround($294 + $287);
 $308 = (($world1) + 20|0);
 HEAPF32[$308>>2] = $307;
 $309 = Math_fround($292 + $288);
 $310 = (($world1) + 24|0);
 HEAPF32[$310>>2] = $309;
 $311 = Math_fround($294 - $287);
 $312 = (($world1) + 28|0);
 HEAPF32[$312>>2] = $311;
 $313 = Math_fround($304 - $293);
 $314 = (($world1) + 32|0);
 HEAPF32[$314>>2] = $313;
 $315 = (($world1) + 36|0);
 $316 = (($world1) + 40|0);
 $317 = (($world1) + 44|0);
 $318 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$315>>2] = $318;
 $319 = (($transform1) + 20|0);
 $320 = Math_fround(HEAPF32[$319>>2]);
 HEAPF32[$316>>2] = $320;
 $321 = (($transform1) + 24|0);
 $322 = Math_fround(HEAPF32[$321>>2]);
 HEAPF32[$317>>2] = $322;
 __ZN5physx2Gu14computeHullOBBERNS0_3BoxERKNS_9PxBounds3EfRKNS_11PxTransformERKNS_2Cm8Matrix34ESC_RKNS9_23FastVertex2ShapeScalingEb($hullOBB,$hullAABB,$contactDistance,$transform0,$_maxPen$i,$world1,$meshScaling,$idtMeshScale);
 $323 = (($230) + 16|0);
 $324 = HEAP32[$323>>2]|0;
 HEAP32[$hmd>>2] = $324;
 $325 = (($230) + 32|0);
 $326 = (($hmd) + 4|0);
 HEAP32[$326>>2] = $325;
 $327 = (($230) + 20|0);
 $328 = Math_fround(HEAPF32[$327>>2]);
 $329 = (($hmd) + 8|0);
 HEAPF32[$329>>2] = $328;
 __ZN5physx2Gu9ContainerC2Ev($delayedContacts);
 $330 = STACKTOP; STACKTOP = STACKTOP + 4352|0;;
 __ZN5physx2Gu9Container17InitSharedBuffersEjPjb($delayedContacts,1088,$330,1);
 $331 = (($230) + 152|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = (($blockCallback) + 4|0);
 HEAP32[$333>>2] = 2;
 $334 = (($blockCallback) + 8|0);
 HEAP32[$334>>2] = $meshScaling;
 $335 = (($blockCallback) + 12|0);
 HEAP32[$335>>2] = $332;
 $336 = (($blockCallback) + 16|0);
 $337 = $idtMeshScale&1;
 HEAP8[$336>>0] = $337;
 $338 = (($blockCallback) + 868|0);
 HEAP32[$338>>2] = 0;
 HEAP32[$blockCallback>>2] = ((554088 + 8|0));
 $339 = (($blockCallback) + 880|0);
 __ZN5physx2Gu24PCMMeshContactGenerationC2ERKNS_6shdfnd3aos6FloatVES6_RKNS3_12PsTransformVES9_RNS0_33MultiplePersistentContactManifoldERNS0_13ContactBufferE($339,$contactDist,$replaceBreakingThreshold,$convexTransform,$meshTransform,$multiManifold,$contactBuffer);
 $340 = (($blockCallback) + 4496|0);
 HEAP32[$340>>2] = 0;
 $scevgep$i$i$i$i$i$i = (($blockCallback) + 4368|0);
 dest=$scevgep$i$i$i$i$i$i+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $341 = (($blockCallback) + 4528|0);
 HEAP32[$341>>2] = $delayedContacts;
 $342 = (($blockCallback) + 4532|0);
 HEAP32[$342>>2] = $polyData;
 $343 = (($blockCallback) + 4536|0);
 HEAP32[$343>>2] = $polyMap;
 $344 = (($blockCallback) + 4540|0);
 HEAP32[$344>>2] = $convexScaling;
 $345 = (($blockCallback) + 4544|0);
 $346 = $idtConvexScale&1;
 HEAP8[$345>>0] = $346;
 $347 = Math_fround(HEAPF32[$polyData>>2]);
 $348 = (($polyData) + 4|0);
 $349 = Math_fround(HEAPF32[$348>>2]);
 $350 = (($polyData) + 8|0);
 $351 = Math_fround(HEAPF32[$350>>2]);
 $352 = (($blockCallback) + 3184|0);
 $353 = Math_fround(HEAPF32[$352>>2]);
 $354 = (($blockCallback) + 3188|0);
 $355 = Math_fround(HEAPF32[$354>>2]);
 $356 = (($blockCallback) + 3192|0);
 $357 = Math_fround(HEAPF32[$356>>2]);
 $358 = Math_fround($347 - $353);
 $359 = Math_fround($349 - $355);
 $360 = Math_fround($351 - $357);
 $361 = (($blockCallback) + 3136|0);
 $362 = Math_fround(HEAPF32[$361>>2]);
 $363 = Math_fround($358 * $362);
 $364 = (($blockCallback) + 3140|0);
 $365 = Math_fround(HEAPF32[$364>>2]);
 $366 = Math_fround($359 * $365);
 $367 = Math_fround($363 + $366);
 $368 = (($blockCallback) + 3144|0);
 $369 = Math_fround(HEAPF32[$368>>2]);
 $370 = Math_fround($360 * $369);
 $371 = Math_fround($367 + $370);
 $372 = (($blockCallback) + 3152|0);
 $373 = Math_fround(HEAPF32[$372>>2]);
 $374 = Math_fround($358 * $373);
 $375 = (($blockCallback) + 3156|0);
 $376 = Math_fround(HEAPF32[$375>>2]);
 $377 = Math_fround($359 * $376);
 $378 = Math_fround($374 + $377);
 $379 = (($blockCallback) + 3160|0);
 $380 = Math_fround(HEAPF32[$379>>2]);
 $381 = Math_fround($360 * $380);
 $382 = Math_fround($378 + $381);
 $383 = (($blockCallback) + 3168|0);
 $384 = Math_fround(HEAPF32[$383>>2]);
 $385 = Math_fround($358 * $384);
 $386 = (($blockCallback) + 3172|0);
 $387 = Math_fround(HEAPF32[$386>>2]);
 $388 = Math_fround($359 * $387);
 $389 = Math_fround($385 + $388);
 $390 = (($blockCallback) + 3176|0);
 $391 = Math_fround(HEAPF32[$390>>2]);
 $392 = Math_fround($360 * $391);
 $393 = Math_fround($389 + $392);
 $394 = (($blockCallback) + 4512|0);
 HEAPF32[$394>>2] = $371;
 $395 = (($blockCallback) + 4516|0);
 HEAPF32[$395>>2] = $382;
 $396 = (($blockCallback) + 4520|0);
 HEAPF32[$396>>2] = $393;
 $397 = (($blockCallback) + 4524|0);
 HEAPF32[$397>>2] = Math_fround(0.0);
 $398 = (($blockCallback) + 4560|0);
 __ZN5physx2Gu15OBBTriangleTestC2ERKNS0_3BoxE($398,$hullOBB);
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($hullOBB,1,$hmd,$blockCallback,1);
 $399 = HEAP32[$338>>2]|0;
 $400 = ($399|0)==(0);
 if (!($400)) {
  $401 = (($blockCallback) + 880|0);
  $402 = (($blockCallback) + 852|0);
  $403 = (($blockCallback) + 788|0);
  $404 = (($blockCallback) + 596|0);
  $405 = (($blockCallback) + 20|0);
  $count$01$i$i$i = $399;$edgeFlags$05$i$i$i = $402;$triInds$04$i$i$i = $403;$vertInds$03$i$i$i = $404;$verts$02$i$i$i = $405;
  while(1) {
   $406 = (($count$01$i$i$i) + -1)|0;
   $407 = HEAP32[$triInds$04$i$i$i>>2]|0;
   $408 = HEAP8[$edgeFlags$05$i$i$i>>0]|0;
   (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($401,$verts$02$i$i$i,$407,$408,$vertInds$03$i$i$i)|0);
   $409 = (($verts$02$i$i$i) + 36|0);
   $410 = (($vertInds$03$i$i$i) + 12|0);
   $411 = (($triInds$04$i$i$i) + 4|0);
   $412 = (($edgeFlags$05$i$i$i) + 1|0);
   $413 = ($406|0)==(0);
   if ($413) {
    break;
   } else {
    $count$01$i$i$i = $406;$edgeFlags$05$i$i$i = $412;$triInds$04$i$i$i = $411;$vertInds$03$i$i$i = $410;$verts$02$i$i$i = $409;
   }
  }
  HEAP32[$338>>2] = 0;
 }
 $414 = (($blockCallback) + 880|0);
 __ZN5physx2Gu32PCMConvexVsMeshContactGeneration20generateLastContactsEv($414);
 __ZN5physx2Gu24PCMMeshContactGeneration15processContactsEhb($414,6,0);
 __ZN5physx2Gu9ContainerD2Ev($delayedContacts);
 $415 = (__ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVE($multiManifold,$contactBuffer,$meshTransform)|0);
 STACKTOP = sp;return ($415|0);
}
function __ZN5physx40PCMConvexVsMeshContactGenerationCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu20pcmContactConvexMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i = Math_fround(0), $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0);
 var $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0);
 var $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $convexHull = 0, $convexMap = 0, $convexMargin = 0, $convexScaling = 0, $convexTransform = 0, $hullAABB = 0, $meshScaling = 0, $polyData = 0, $vQuat = 0, $vScale = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $convexTransform = sp + 336|0;
 $meshScaling = sp + 440|0;
 $convexScaling = sp + 368|0;
 $hullAABB = sp + 512|0;
 $polyData = sp + 536|0;
 $vScale = sp + 320|0;
 $convexMargin = sp + 240|0;
 $vQuat = sp + 224|0;
 $convexHull = sp + 16|0;
 $0 = sp;
 $convexMap = sp + 256|0;
 $1 = (($shape0) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$cache>>2]|0;
 $4 = $3 & -16;
 $5 = $4;
 $6 = Math_fround(HEAPF32[$transform0>>2]);
 $7 = (($transform0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($transform0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transform0) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transform0) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($13) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($13) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$convexTransform>>2] = $6;
 $19 = (($convexTransform) + 4|0);
 HEAPF32[$19>>2] = $8;
 $20 = (($convexTransform) + 8|0);
 HEAPF32[$20>>2] = $10;
 $21 = (($convexTransform) + 12|0);
 HEAPF32[$21>>2] = $12;
 $22 = (($convexTransform) + 16|0);
 HEAPF32[$22>>2] = $14;
 $23 = (($convexTransform) + 20|0);
 HEAPF32[$23>>2] = $16;
 $24 = (($convexTransform) + 24|0);
 HEAPF32[$24>>2] = $18;
 $25 = (($convexTransform) + 28|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($shape1) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = $27 == Math_fround(1.0);
 if ($28) {
  $29 = (($shape1) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = $30 == Math_fround(1.0);
  if ($31) {
   $32 = (($shape1) + 12|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = $33 == Math_fround(1.0);
   $112 = $34;
  } else {
   $112 = 0;
  }
 } else {
  $112 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $35 = (($meshScaling) + 4|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($meshScaling) + 8|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($meshScaling) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($meshScaling) + 16|0);
 HEAPF32[$38>>2] = Math_fround(1.0);
 $39 = (($meshScaling) + 20|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($meshScaling) + 24|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($meshScaling) + 28|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($meshScaling) + 32|0);
 HEAPF32[$42>>2] = Math_fround(1.0);
 $43 = (($meshScaling) + 36|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 $44 = (($meshScaling) + 40|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($meshScaling) + 44|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($meshScaling) + 48|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($meshScaling) + 52|0);
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (($meshScaling) + 56|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($meshScaling) + 60|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($meshScaling) + 64|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($meshScaling) + 68|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 if (!($112)) {
  $52 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$26,$52);
 }
 HEAPF32[$convexScaling>>2] = Math_fround(1.0);
 $53 = (($convexScaling) + 4|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($convexScaling) + 8|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($convexScaling) + 12|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($convexScaling) + 16|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($convexScaling) + 20|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($convexScaling) + 24|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($convexScaling) + 28|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($convexScaling) + 32|0);
 HEAPF32[$60>>2] = Math_fround(1.0);
 $61 = (($convexScaling) + 36|0);
 HEAPF32[$61>>2] = Math_fround(1.0);
 $62 = (($convexScaling) + 40|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($convexScaling) + 44|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($convexScaling) + 48|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = (($convexScaling) + 52|0);
 HEAPF32[$65>>2] = Math_fround(1.0);
 $66 = (($convexScaling) + 56|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($convexScaling) + 60|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($convexScaling) + 64|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($convexScaling) + 68|0);
 HEAPF32[$69>>2] = Math_fround(1.0);
 $70 = (__ZN5physx2Gu16getPCMConvexDataERKNS0_13GeometryUnionERNS_2Cm23FastVertex2ShapeScalingERNS_9PxBounds3ERNS0_13PolygonalDataE($shape0,$convexScaling,$hullAABB,$polyData)|0);
 $71 = (($shape0) + 4|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($shape0) + 8|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($shape0) + 12|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 HEAPF32[$vScale>>2] = $72;
 $77 = (($vScale) + 4|0);
 HEAPF32[$77>>2] = $74;
 $78 = (($vScale) + 8|0);
 HEAPF32[$78>>2] = $76;
 $79 = (($vScale) + 12|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($2) + 52|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($2) + 56|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($2) + 60|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($81 * $72);
 $87 = Math_fround($83 * $74);
 $88 = Math_fround($85 * $76);
 $89 = !($86 <= $87);
 $$$i$i = $89 ? $87 : $86;
 $90 = !($$$i$i <= $88);
 $91 = $90 ? $88 : $$$i$i;
 $92 = Math_fround($91 * Math_fround(0.25));
 HEAPF32[$convexMargin>>2] = $92;
 $93 = (($shape0) + 16|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($shape0) + 20|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($shape0) + 24|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($shape0) + 28|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 HEAPF32[$vQuat>>2] = $94;
 $101 = (($vQuat) + 4|0);
 HEAPF32[$101>>2] = $96;
 $102 = (($vQuat) + 8|0);
 HEAPF32[$102>>2] = $98;
 $103 = (($vQuat) + 12|0);
 HEAPF32[$103>>2] = $100;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$2,$0,$vScale,$vQuat);
 if ($70) {
  $104 = (($convexHull) + 96|0);
  $105 = (($convexHull) + 144|0);
  $106 = (($convexMap) + 32|0);
  HEAP32[$106>>2] = $convexTransform;
  $107 = (($convexMap) + 36|0);
  HEAP32[$107>>2] = $104;
  $108 = (($convexMap) + 40|0);
  HEAP32[$108>>2] = $105;
  $109 = (($convexMap) + 44|0);
  HEAP8[$109>>0] = 1;
  HEAP32[$convexMap>>2] = ((546744 + 8|0));
  $110 = (($convexMap) + 48|0);
  HEAP32[$110>>2] = $convexHull;
  $111 = Math_fround(HEAPF32[$contactDistance>>2]);
  $113 = (__ZN5physx2Gu20PCMContactConvexMeshERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERKNS_9PxBounds3ERKNS_24PxTriangleMeshGeometryLLERKNS_11PxTransformESJ_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESP_bbRNS0_33MultiplePersistentContactManifoldE($polyData,$convexMap,$convexMargin,$hullAABB,$shape1,$transform0,$transform1,$111,$contactBuffer,$convexScaling,$meshScaling,1,$112,$5)|0);
  $$0 = $113;
  STACKTOP = sp;return ($$0|0);
 } else {
  $114 = (($convexHull) + 96|0);
  $115 = (($convexHull) + 144|0);
  $116 = (($convexMap) + 32|0);
  HEAP32[$116>>2] = $convexTransform;
  $117 = (($convexMap) + 36|0);
  HEAP32[$117>>2] = $114;
  $118 = (($convexMap) + 40|0);
  HEAP32[$118>>2] = $115;
  $119 = (($convexMap) + 44|0);
  HEAP8[$119>>0] = 0;
  HEAP32[$convexMap>>2] = ((546712 + 8|0));
  $120 = (($convexMap) + 48|0);
  HEAP32[$120>>2] = $convexHull;
  $121 = Math_fround(HEAPF32[$contactDistance>>2]);
  $122 = (__ZN5physx2Gu20PCMContactConvexMeshERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERKNS_9PxBounds3ERKNS_24PxTriangleMeshGeometryLLERKNS_11PxTransformESJ_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESP_bbRNS0_33MultiplePersistentContactManifoldE($polyData,$convexMap,$convexMargin,$hullAABB,$shape1,$transform0,$transform1,$121,$contactBuffer,$convexScaling,$meshScaling,0,$112,$5)|0);
  $$0 = $122;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu17pcmContactBoxMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$$i12$i$i$i = Math_fround(0), $$$i23$i$i$i = Math_fround(0), $$pre = Math_fround(0), $$pre1 = Math_fround(0), $$pre2 = Math_fround(0), $$sroa$1$i$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0;
 var $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0);
 var $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $boxMap = 0, $boxTransform = 0, $boxV = 0, $hullAABB = 0, $identity = 0, $idtScaling = 0, $meshScaling = 0, $minMargin = 0, $zero$sroa$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 784|0;
 $$sroa$1$i$i$i = sp + 320|0;
 $zero$sroa$1$i$i$i = sp + 416|0;
 $hullAABB = sp + 392|0;
 $meshScaling = sp + 640|0;
 $idtScaling = sp + 712|0;
 $minMargin = sp + 304|0;
 $boxV = sp + 80|0;
 $boxTransform = sp + 48|0;
 $identity = sp;
 $boxMap = sp + 240|0;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 & -16;
 $2 = $1;
 $3 = (($shape0) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$4);
 $6 = (($shape0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(-$7);
 $9 = (($shape0) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(-$10);
 HEAPF32[$hullAABB>>2] = $5;
 $12 = (($hullAABB) + 4|0);
 HEAPF32[$12>>2] = $8;
 $13 = (($hullAABB) + 8|0);
 HEAPF32[$13>>2] = $11;
 $14 = (($hullAABB) + 12|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($hullAABB) + 16|0);
 HEAPF32[$15>>2] = $7;
 $16 = (($hullAABB) + 20|0);
 HEAPF32[$16>>2] = $10;
 $17 = (($shape1) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = $18 == Math_fround(1.0);
 if ($19) {
  $20 = (($shape1) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = $21 == Math_fround(1.0);
  if ($22) {
   $23 = (($shape1) + 12|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = $24 == Math_fround(1.0);
   $118 = $25;
  } else {
   $118 = 0;
  }
 } else {
  $118 = 0;
 }
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $26 = (($meshScaling) + 4|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($meshScaling) + 8|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($meshScaling) + 12|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($meshScaling) + 16|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = (($meshScaling) + 20|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($meshScaling) + 24|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($meshScaling) + 28|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($meshScaling) + 32|0);
 HEAPF32[$33>>2] = Math_fround(1.0);
 $34 = (($meshScaling) + 36|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (($meshScaling) + 40|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($meshScaling) + 44|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($meshScaling) + 48|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($meshScaling) + 52|0);
 HEAPF32[$38>>2] = Math_fround(1.0);
 $39 = (($meshScaling) + 56|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($meshScaling) + 60|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($meshScaling) + 64|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($meshScaling) + 68|0);
 HEAPF32[$42>>2] = Math_fround(1.0);
 if ($118) {
  $62 = $4;$63 = $7;$65 = $10;
 } else {
  $43 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$17,$43);
  $$pre = Math_fround(HEAPF32[$3>>2]);
  $$pre1 = Math_fround(HEAPF32[$6>>2]);
  $$pre2 = Math_fround(HEAPF32[$9>>2]);
  $62 = $$pre;$63 = $$pre1;$65 = $$pre2;
 }
 HEAPF32[$idtScaling>>2] = Math_fround(1.0);
 $44 = (($idtScaling) + 4|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($idtScaling) + 8|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($idtScaling) + 12|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($idtScaling) + 16|0);
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (($idtScaling) + 20|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($idtScaling) + 24|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($idtScaling) + 28|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($idtScaling) + 32|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 $52 = (($idtScaling) + 36|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($idtScaling) + 40|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($idtScaling) + 44|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($idtScaling) + 48|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($idtScaling) + 52|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($idtScaling) + 56|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($idtScaling) + 60|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($idtScaling) + 64|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($idtScaling) + 68|0);
 HEAPF32[$60>>2] = Math_fround(1.0);
 $61 = !($62 <= $63);
 $$$i$i = $61 ? $63 : $62;
 $64 = !($$$i$i <= $65);
 $66 = $64 ? $65 : $$$i$i;
 $67 = Math_fround($66 * Math_fround(0.150000005960464477539));
 HEAPF32[$minMargin>>2] = $67;
 ;HEAP32[$boxV+0>>2]=0|0;HEAP32[$boxV+4>>2]=0|0;HEAP32[$boxV+8>>2]=0|0;HEAP32[$boxV+12>>2]=0|0;
 $68 = (($boxV) + 64|0);
 $69 = (($boxV) + 80|0);
 HEAP32[$69>>2] = 3;
 $70 = (($boxV) + 16|0);
 $71 = (($boxV) + 20|0);
 ;HEAP32[$71+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $72 = (($boxV) + 32|0);
 $73 = (($boxV) + 36|0);
 $74 = (($boxV) + 48|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($boxV) + 52|0);
 ;HEAP32[$75+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 ;HEAP32[$$sroa$1$i$i$i+0>>2]=0|0;HEAP32[$$sroa$1$i$i$i+4>>2]=0|0;HEAP32[$$sroa$1$i$i$i+8>>2]=0|0;HEAP32[$$sroa$1$i$i$i+12>>2]=0|0;
 ;HEAP32[$68+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$68+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$68+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;HEAP32[$68+12>>2]=HEAP32[$$sroa$1$i$i$i+12>>2]|0;
 $76 = (($boxV) + 144|0);
 HEAPF32[$76>>2] = $62;
 $77 = (($boxV) + 148|0);
 HEAPF32[$77>>2] = $63;
 $78 = (($boxV) + 152|0);
 HEAPF32[$78>>2] = $65;
 $79 = (($boxV) + 156|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = !($62 >= $63);
 $$$i23$i$i$i = $80 ? $63 : $62;
 $81 = !($$$i23$i$i$i >= $65);
 $82 = $81 ? $65 : $$$i23$i$i$i;
 $83 = Math_fround($82 * Math_fround(0.0299999993294477462769));
 $84 = $67 > $83;
 $$$i12$i$i$i = $84 ? $67 : $83;
 $85 = $66 > $$$i12$i$i$i;
 $$$i$i$i$i = $85 ? $$$i12$i$i$i : $66;
 HEAPF32[$70>>2] = $$$i$i$i$i;
 ;HEAP32[$71+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
 $86 = Math_fround($66 * Math_fround(0.0500000007450580596924));
 HEAPF32[$72>>2] = $86;
 ;HEAP32[$73+0>>2]=HEAP32[$$sroa$1$i$i$i+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$$sroa$1$i$i$i+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$$sroa$1$i$i$i+8>>2]|0;
 $87 = Math_fround(HEAPF32[$transform0>>2]);
 $88 = (($transform0) + 4|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($transform0) + 8|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($transform0) + 12|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($transform0) + 16|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = (($94) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($94) + 8|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 HEAPF32[$boxTransform>>2] = $87;
 $100 = (($boxTransform) + 4|0);
 HEAPF32[$100>>2] = $89;
 $101 = (($boxTransform) + 8|0);
 HEAPF32[$101>>2] = $91;
 $102 = (($boxTransform) + 12|0);
 HEAPF32[$102>>2] = $93;
 $103 = (($boxTransform) + 16|0);
 HEAPF32[$103>>2] = $95;
 $104 = (($boxTransform) + 20|0);
 HEAPF32[$104>>2] = $97;
 $105 = (($boxTransform) + 24|0);
 HEAPF32[$105>>2] = $99;
 $106 = (($boxTransform) + 28|0);
 HEAPF32[$106>>2] = Math_fround(0.0);
 __ZN5physx2Gu15PCMPolygonalBoxC2ERKNS_6PxVec3E($zero$sroa$1$i$i$i,$3);
 __ZNK5physx2Gu15PCMPolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($zero$sroa$1$i$i$i,$$sroa$1$i$i$i);
 HEAPF32[$identity>>2] = Math_fround(1.0);
 $107 = (($identity) + 4|0);
 $108 = (($identity) + 20|0);
 ;HEAP32[$107+0>>2]=0|0;HEAP32[$107+4>>2]=0|0;HEAP32[$107+8>>2]=0|0;HEAP32[$107+12>>2]=0|0;
 HEAPF32[$108>>2] = Math_fround(1.0);
 $109 = (($identity) + 24|0);
 $110 = (($identity) + 40|0);
 ;HEAP32[$109+0>>2]=0|0;HEAP32[$109+4>>2]=0|0;HEAP32[$109+8>>2]=0|0;HEAP32[$109+12>>2]=0|0;
 HEAPF32[$110>>2] = Math_fround(1.0);
 $111 = (($identity) + 44|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = (($boxMap) + 32|0);
 HEAP32[$112>>2] = $boxTransform;
 $113 = (($boxMap) + 36|0);
 HEAP32[$113>>2] = $identity;
 $114 = (($boxMap) + 40|0);
 HEAP32[$114>>2] = $identity;
 $115 = (($boxMap) + 44|0);
 HEAP8[$115>>0] = 1;
 HEAP32[$boxMap>>2] = ((546776 + 8|0));
 $116 = (($boxMap) + 48|0);
 HEAP32[$116>>2] = $boxV;
 $117 = Math_fround(HEAPF32[$contactDistance>>2]);
 $119 = (__ZN5physx2Gu20PCMContactConvexMeshERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERKNS_9PxBounds3ERKNS_24PxTriangleMeshGeometryLLERKNS_11PxTransformESJ_fRNS0_13ContactBufferERKNS_2Cm23FastVertex2ShapeScalingESP_bbRNS0_33MultiplePersistentContactManifoldE($$sroa$1$i$i$i,$boxMap,$minMargin,$hullAABB,$shape1,$transform0,$transform1,$117,$contactBuffer,$idtScaling,$meshScaling,1,$118,$2)|0);
 STACKTOP = sp;return ($119|0);
}
function __ZN5physx2Gu32PCMMeshContactGenerationCallbackINS_40PCMConvexVsMeshContactGenerationCallbackEE10processHitERKNS_12PxRaycastHitERKNS_6PxVec3ES9_S9_RfPKj($this,$hit,$v0,$v1,$v2,$0,$vinds) {
 $this = $this|0;
 $hit = $hit|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 $0 = $0|0;
 $vinds = $vinds|0;
 var $$phi$trans$insert11 = 0, $$phi$trans$insert13 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert17 = 0, $$phi$trans$insert19 = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert7 = 0, $$phi$trans$insert9 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre12 = Math_fround(0), $$pre14 = Math_fround(0), $$pre16 = Math_fround(0), $$pre18 = Math_fround(0), $$pre20 = Math_fround(0), $$pre22 = Math_fround(0), $$pre8 = Math_fround(0), $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0);
 var $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $count$01$i$i = 0, $edgeFlags$05$i$i = 0, $triInds$04$i$i = 0;
 var $v = 0, $vertInds$03$i$i = 0, $verts$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $v = sp;
 $1 = (($this) + 4560|0);
 $2 = (__ZNK5physx2Gu15OBBTriangleTest10obbTriTestERKNS_6PxVec3ES4_S4_($1,$v0,$v1,$v2)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 16|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $30 = (($this) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = Math_fround(HEAPF32[$v0>>2]);
  $33 = Math_fround(HEAPF32[$31>>2]);
  $34 = Math_fround($32 * $33);
  $35 = (($31) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($32 * $36);
  $38 = (($31) + 8|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($32 * $39);
  $41 = (($v0) + 4|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($31) + 12|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($42 * $44);
  $46 = (($31) + 16|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($42 * $47);
  $49 = (($31) + 20|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($42 * $50);
  $52 = Math_fround($34 + $45);
  $53 = Math_fround($37 + $48);
  $54 = Math_fround($40 + $51);
  $55 = (($v0) + 8|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($31) + 24|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($56 * $58);
  $60 = (($31) + 28|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($56 * $61);
  $63 = (($31) + 32|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($56 * $64);
  $66 = Math_fround($52 + $59);
  $67 = Math_fround($53 + $62);
  $68 = Math_fround($54 + $65);
  HEAPF32[$v>>2] = $66;
  $69 = (($v) + 4|0);
  HEAPF32[$69>>2] = $67;
  $70 = (($v) + 8|0);
  HEAPF32[$70>>2] = $68;
  $71 = Math_fround(HEAPF32[$v1>>2]);
  $72 = Math_fround(HEAPF32[$31>>2]);
  $73 = Math_fround($71 * $72);
  $74 = Math_fround(HEAPF32[$35>>2]);
  $75 = Math_fround($71 * $74);
  $76 = Math_fround(HEAPF32[$38>>2]);
  $77 = Math_fround($71 * $76);
  $78 = (($v1) + 4|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround(HEAPF32[$43>>2]);
  $81 = Math_fround($79 * $80);
  $82 = Math_fround(HEAPF32[$46>>2]);
  $83 = Math_fround($79 * $82);
  $84 = Math_fround(HEAPF32[$49>>2]);
  $85 = Math_fround($79 * $84);
  $86 = Math_fround($73 + $81);
  $87 = Math_fround($75 + $83);
  $88 = Math_fround($77 + $85);
  $89 = (($v1) + 8|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = Math_fround(HEAPF32[$57>>2]);
  $92 = Math_fround($90 * $91);
  $93 = Math_fround(HEAPF32[$60>>2]);
  $94 = Math_fround($90 * $93);
  $95 = Math_fround(HEAPF32[$63>>2]);
  $96 = Math_fround($90 * $95);
  $97 = Math_fround($86 + $92);
  $98 = Math_fround($87 + $94);
  $99 = Math_fround($88 + $96);
  $100 = (($v) + 12|0);
  HEAPF32[$100>>2] = $97;
  $101 = (($v) + 16|0);
  HEAPF32[$101>>2] = $98;
  $102 = (($v) + 20|0);
  HEAPF32[$102>>2] = $99;
  $103 = Math_fround(HEAPF32[$v2>>2]);
  $104 = Math_fround(HEAPF32[$31>>2]);
  $105 = Math_fround($103 * $104);
  $106 = Math_fround(HEAPF32[$35>>2]);
  $107 = Math_fround($103 * $106);
  $108 = Math_fround(HEAPF32[$38>>2]);
  $109 = Math_fround($103 * $108);
  $110 = (($v2) + 4|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround(HEAPF32[$43>>2]);
  $113 = Math_fround($111 * $112);
  $114 = Math_fround(HEAPF32[$46>>2]);
  $115 = Math_fround($111 * $114);
  $116 = Math_fround(HEAPF32[$49>>2]);
  $117 = Math_fround($111 * $116);
  $118 = Math_fround($105 + $113);
  $119 = Math_fround($107 + $115);
  $120 = Math_fround($109 + $117);
  $121 = (($v2) + 8|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround(HEAPF32[$57>>2]);
  $124 = Math_fround($122 * $123);
  $125 = Math_fround(HEAPF32[$60>>2]);
  $126 = Math_fround($122 * $125);
  $127 = Math_fround(HEAPF32[$63>>2]);
  $128 = Math_fround($122 * $127);
  $129 = Math_fround($118 + $124);
  $130 = Math_fround($119 + $126);
  $131 = Math_fround($120 + $128);
  $132 = (($v) + 24|0);
  HEAPF32[$132>>2] = $129;
  $133 = (($v) + 28|0);
  HEAPF32[$133>>2] = $130;
  $134 = (($v) + 32|0);
  HEAPF32[$134>>2] = $131;
  $192 = $131;$193 = $130;$194 = $129;$195 = $99;$196 = $98;$197 = $97;$198 = $68;$199 = $67;$200 = $66;
 } else {
  $7 = Math_fround(HEAPF32[$v0>>2]);
  HEAPF32[$v>>2] = $7;
  $8 = (($v0) + 4|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($v) + 4|0);
  HEAPF32[$10>>2] = $9;
  $11 = (($v0) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($v) + 8|0);
  HEAPF32[$13>>2] = $12;
  $14 = Math_fround(HEAPF32[$v1>>2]);
  $15 = (($v) + 12|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($v1) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($v) + 16|0);
  HEAPF32[$18>>2] = $17;
  $19 = (($v1) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($v) + 20|0);
  HEAPF32[$21>>2] = $20;
  $22 = Math_fround(HEAPF32[$v2>>2]);
  $23 = (($v) + 24|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($v2) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($v) + 28|0);
  HEAPF32[$26>>2] = $25;
  $27 = (($v2) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($v) + 32|0);
  HEAPF32[$29>>2] = $28;
  $192 = $28;$193 = $25;$194 = $22;$195 = $20;$196 = $17;$197 = $14;$198 = $12;$199 = $9;$200 = $7;
 }
 $135 = (($hit) + 8|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = (($this) + 12|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = ($138|0)==(0|0);
 if ($139) {
  $191 = 56;
 } else {
  $140 = (($138) + ($136)|0);
  $141 = HEAP8[$140>>0]|0;
  $191 = $141;
 }
 $142 = (($this) + 868|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = ($143|0)==(16);
 if ($144) {
  $145 = (($this) + 880|0);
  $146 = (($this) + 852|0);
  $147 = (($this) + 788|0);
  $148 = (($this) + 596|0);
  $149 = (($this) + 20|0);
  $count$01$i$i = 16;$edgeFlags$05$i$i = $146;$triInds$04$i$i = $147;$vertInds$03$i$i = $148;$verts$02$i$i = $149;
  while(1) {
   $150 = (($count$01$i$i) + -1)|0;
   $151 = HEAP32[$triInds$04$i$i>>2]|0;
   $152 = HEAP8[$edgeFlags$05$i$i>>0]|0;
   (__ZN5physx2Gu32PCMConvexVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($145,$verts$02$i$i,$151,$152,$vertInds$03$i$i)|0);
   $153 = (($verts$02$i$i) + 36|0);
   $154 = (($vertInds$03$i$i) + 12|0);
   $155 = (($triInds$04$i$i) + 4|0);
   $156 = (($edgeFlags$05$i$i) + 1|0);
   $157 = ($150|0)==(0);
   if ($157) {
    break;
   } else {
    $count$01$i$i = $150;$edgeFlags$05$i$i = $156;$triInds$04$i$i = $155;$vertInds$03$i$i = $154;$verts$02$i$i = $153;
   }
  }
  HEAP32[$142>>2] = 0;
  $$pre = Math_fround(HEAPF32[$v>>2]);
  $$phi$trans$insert7 = (($v) + 4|0);
  $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
  $$phi$trans$insert9 = (($v) + 8|0);
  $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert9>>2]);
  $$phi$trans$insert11 = (($v) + 12|0);
  $$pre12 = Math_fround(HEAPF32[$$phi$trans$insert11>>2]);
  $$phi$trans$insert13 = (($v) + 16|0);
  $$pre14 = Math_fround(HEAPF32[$$phi$trans$insert13>>2]);
  $$phi$trans$insert15 = (($v) + 20|0);
  $$pre16 = Math_fround(HEAPF32[$$phi$trans$insert15>>2]);
  $$phi$trans$insert17 = (($v) + 24|0);
  $$pre18 = Math_fround(HEAPF32[$$phi$trans$insert17>>2]);
  $$phi$trans$insert19 = (($v) + 28|0);
  $$pre20 = Math_fround(HEAPF32[$$phi$trans$insert19>>2]);
  $$phi$trans$insert21 = (($v) + 32|0);
  $$pre22 = Math_fround(HEAPF32[$$phi$trans$insert21>>2]);
  $159 = 0;$162 = $$pre;$164 = $$pre8;$166 = $$pre10;$169 = $$pre12;$171 = $$pre14;$173 = $$pre16;$176 = $$pre18;$178 = $$pre20;$180 = $$pre22;
 } else {
  $159 = $143;$162 = $200;$164 = $199;$166 = $198;$169 = $197;$171 = $196;$173 = $195;$176 = $194;$178 = $193;$180 = $192;
 }
 $158 = (($159) + 1)|0;
 HEAP32[$142>>2] = $158;
 $160 = ($159*3)|0;
 $161 = ((($this) + (($160*12)|0)|0) + 20|0);
 HEAPF32[$161>>2] = $162;
 $163 = ((($this) + (($160*12)|0)|0) + 24|0);
 HEAPF32[$163>>2] = $164;
 $165 = ((($this) + (($160*12)|0)|0) + 28|0);
 HEAPF32[$165>>2] = $166;
 $167 = (($160) + 1)|0;
 $168 = ((($this) + (($167*12)|0)|0) + 20|0);
 HEAPF32[$168>>2] = $169;
 $170 = ((($this) + (($167*12)|0)|0) + 24|0);
 HEAPF32[$170>>2] = $171;
 $172 = ((($this) + (($167*12)|0)|0) + 28|0);
 HEAPF32[$172>>2] = $173;
 $174 = (($160) + 2)|0;
 $175 = ((($this) + (($174*12)|0)|0) + 20|0);
 HEAPF32[$175>>2] = $176;
 $177 = ((($this) + (($174*12)|0)|0) + 24|0);
 HEAPF32[$177>>2] = $178;
 $179 = ((($this) + (($174*12)|0)|0) + 28|0);
 HEAPF32[$179>>2] = $180;
 $181 = HEAP32[$vinds>>2]|0;
 $182 = ((($this) + ($160<<2)|0) + 596|0);
 HEAP32[$182>>2] = $181;
 $183 = (($vinds) + 4|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = ((($this) + ($167<<2)|0) + 596|0);
 HEAP32[$185>>2] = $184;
 $186 = (($vinds) + 8|0);
 $187 = HEAP32[$186>>2]|0;
 $188 = ((($this) + ($174<<2)|0) + 596|0);
 HEAP32[$188>>2] = $187;
 $189 = ((($this) + ($159<<2)|0) + 788|0);
 HEAP32[$189>>2] = $136;
 $190 = ((($this) + ($159)|0) + 852|0);
 HEAP8[$190>>0] = $191;
 STACKTOP = sp;return 1;
}
function __ZN5physx40PCMConvexVsMeshContactGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16buildPartialHullERKNS0_13PolygonalDataEPNS0_12SupportLocalERNS0_14SeparatingAxesERKNS_6shdfnd3aos5Vec3VESC_($polyData,$map,$validAxes,$planeP,$planeDir) {
 $polyData = $polyData|0;
 $map = $map|0;
 $validAxes = $validAxes|0;
 $planeP = $planeP|0;
 $planeDir = $planeDir|0;
 var $$phi$trans$insert200 = 0, $$phi$trans$insert202 = 0, $$phi$trans$insert204 = 0, $$phi$trans$insert206 = 0, $$phi$trans$insert208 = 0, $$phi$trans$insert210 = 0, $$phi$trans$insert212 = 0, $$phi$trans$insert214 = 0, $$pre = 0, $$pre195 = 0, $$pre197 = 0, $$pre198 = 0, $$pre199 = Math_fround(0), $$pre201 = Math_fround(0), $$pre203 = Math_fround(0), $$pre205 = Math_fround(0), $$pre207 = Math_fround(0), $$pre209 = Math_fround(0), $$pre211 = Math_fround(0), $$pre213 = Math_fround(0);
 var $$pre215 = Math_fround(0), $$pre216 = Math_fround(0), $$pre217 = Math_fround(0), $$pre218 = Math_fround(0), $$sum = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0;
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0;
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $i$0191 = 0, $iEnd$0190 = 0, $iEnd$0190$phi = 0, $iStart$0189 = 0, $or$cond = 0, $storemerge = Math_fround(0), $storemerge219 = Math_fround(0), $storemerge220 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$planeDir>>2]);
 $2 = (($planeDir) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($planeDir) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($1 * $1);
 $7 = Math_fround($3 * $3);
 $8 = Math_fround($6 + $7);
 $9 = Math_fround($5 * $5);
 $10 = Math_fround($8 + $9);
 $11 = (Math_fround(Math_sqrt((Math_fround($10)))));
 $12 = Math_fround(Math_fround(1.0) / $11);
 $13 = Math_fround($1 * $12);
 $14 = Math_fround($3 * $12);
 $15 = Math_fround($5 * $12);
 $16 = (($polyData) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($polyData) + 24|0);
 $20 = (($polyData) + 32|0);
 $21 = (($map) + 36|0);
 $22 = (($polyData) + 28|0);
 $23 = (($planeP) + 4|0);
 $24 = (($planeP) + 8|0);
 $25 = (($0) + 4|0);
 $26 = (($0) + 8|0);
 $163 = $17;$i$0191 = 0;
 while(1) {
  $27 = HEAP32[$19>>2]|0;
  $28 = HEAP32[$20>>2]|0;
  $29 = ((($27) + (($i$0191*20)|0)|0) + 16|0);
  $30 = HEAP16[$29>>1]|0;
  $31 = $30&65535;
  $32 = (($28) + ($31)|0);
  $33 = HEAP32[$21>>2]|0;
  $34 = HEAP8[$32>>0]|0;
  $35 = $34&255;
  $36 = HEAP32[$22>>2]|0;
  $37 = (($36) + (($35*12)|0)|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = ((($36) + (($35*12)|0)|0) + 4|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = ((($36) + (($35*12)|0)|0) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(HEAPF32[$33>>2]);
  $44 = Math_fround($38 * $43);
  $45 = (($33) + 16|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($40 * $46);
  $48 = Math_fround($44 + $47);
  $49 = (($33) + 32|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($42 * $50);
  $52 = Math_fround($48 + $51);
  $53 = (($33) + 4|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($38 * $54);
  $56 = (($33) + 20|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($40 * $57);
  $59 = Math_fround($55 + $58);
  $60 = (($33) + 36|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($42 * $61);
  $63 = Math_fround($59 + $62);
  $64 = (($33) + 8|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($38 * $65);
  $67 = (($33) + 24|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($40 * $68);
  $70 = Math_fround($66 + $69);
  $71 = (($33) + 40|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($42 * $72);
  $74 = Math_fround($70 + $73);
  $75 = ((($27) + (($i$0191*20)|0)|0) + 18|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = ($76<<24>>24)==(0);
  if ($77) {
   $162 = $163;
  } else {
   $78 = Math_fround(HEAPF32[$23>>2]);
   $79 = Math_fround(HEAPF32[$planeP>>2]);
   $80 = Math_fround($63 - $78);
   $81 = Math_fround($52 - $79);
   $82 = Math_fround(HEAPF32[$24>>2]);
   $83 = Math_fround($14 * $80);
   $84 = Math_fround($13 * $81);
   $85 = Math_fround($74 - $82);
   $86 = $76&255;
   $87 = Math_fround($15 * $85);
   $88 = Math_fround($84 + $83);
   $89 = (($86) + -1)|0;
   $90 = Math_fround($88 + $87);
   $102 = $43;$104 = $46;$107 = $50;$110 = $54;$112 = $57;$115 = $61;$118 = $65;$120 = $68;$123 = $72;$126 = $79;$128 = $78;$130 = $82;$137 = $90;$140 = $52;$142 = $63;$144 = $74;$164 = $76;$95 = $36;$iEnd$0190 = $89;$iStart$0189 = 0;
   while(1) {
    $$sum = (($iEnd$0190) + ($31))|0;
    $91 = (($28) + ($$sum)|0);
    $92 = HEAP8[$91>>0]|0;
    $93 = $92&255;
    $94 = (($95) + (($93*12)|0)|0);
    $96 = Math_fround(HEAPF32[$94>>2]);
    $97 = ((($95) + (($93*12)|0)|0) + 4|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = ((($95) + (($93*12)|0)|0) + 8|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $101 = Math_fround($96 * $102);
    $103 = Math_fround($98 * $104);
    $105 = Math_fround($101 + $103);
    $106 = Math_fround($100 * $107);
    $108 = Math_fround($105 + $106);
    $109 = Math_fround($96 * $110);
    $111 = Math_fround($98 * $112);
    $113 = Math_fround($109 + $111);
    $114 = Math_fround($100 * $115);
    $116 = Math_fround($113 + $114);
    $117 = Math_fround($96 * $118);
    $119 = Math_fround($98 * $120);
    $121 = Math_fround($117 + $119);
    $122 = Math_fround($100 * $123);
    $124 = Math_fround($121 + $122);
    $125 = Math_fround($108 - $126);
    $127 = Math_fround($116 - $128);
    $129 = Math_fround($124 - $130);
    $131 = Math_fround($13 * $125);
    $132 = Math_fround($14 * $127);
    $133 = Math_fround($131 + $132);
    $134 = Math_fround($15 * $129);
    $135 = Math_fround($133 + $134);
    $136 = $137 > Math_fround(0.0);
    $138 = $135 > Math_fround(0.0);
    $or$cond = $136 | $138;
    if ($or$cond) {
     $139 = Math_fround($140 - $108);
     $141 = Math_fround($142 - $116);
     $143 = Math_fround($144 - $124);
     $145 = Math_fround($139 * $139);
     $146 = Math_fround($141 * $141);
     $147 = Math_fround($145 + $146);
     $148 = Math_fround($143 * $143);
     $149 = Math_fround($147 + $148);
     $150 = $149 > Math_fround(0.0);
     if ($150) {
      $151 = (Math_fround(Math_sqrt((Math_fround($149)))));
      $152 = Math_fround(Math_fround(1.0) / $151);
      $153 = Math_fround($139 * $152);
      $154 = Math_fround($141 * $152);
      $155 = Math_fround($143 * $152);
      $storemerge = $155;$storemerge219 = $154;$storemerge220 = $153;
     } else {
      $storemerge = Math_fround(0.0);$storemerge219 = Math_fround(0.0);$storemerge220 = Math_fround(0.0);
     }
     HEAPF32[$0>>2] = $storemerge220;
     HEAPF32[$25>>2] = $storemerge219;
     HEAPF32[$26>>2] = $storemerge;
     (__ZN5physx2Gu14SeparatingAxes7addAxisERKNS_6PxVec3E($validAxes,$0)|0);
     $$pre195 = HEAP8[$75>>0]|0;
     $158 = $$pre195;
    } else {
     $158 = $164;
    }
    $156 = (($iStart$0189) + 1)|0;
    $157 = $158&255;
    $159 = ($156>>>0)<($157>>>0);
    if (!($159)) {
     break;
    }
    $$pre197 = HEAP32[$21>>2]|0;
    $$pre198 = HEAP32[$22>>2]|0;
    $$pre199 = Math_fround(HEAPF32[$$pre197>>2]);
    $$phi$trans$insert200 = (($$pre197) + 16|0);
    $$pre201 = Math_fround(HEAPF32[$$phi$trans$insert200>>2]);
    $$phi$trans$insert202 = (($$pre197) + 32|0);
    $$pre203 = Math_fround(HEAPF32[$$phi$trans$insert202>>2]);
    $$phi$trans$insert204 = (($$pre197) + 4|0);
    $$pre205 = Math_fround(HEAPF32[$$phi$trans$insert204>>2]);
    $$phi$trans$insert206 = (($$pre197) + 20|0);
    $$pre207 = Math_fround(HEAPF32[$$phi$trans$insert206>>2]);
    $$phi$trans$insert208 = (($$pre197) + 36|0);
    $$pre209 = Math_fround(HEAPF32[$$phi$trans$insert208>>2]);
    $$phi$trans$insert210 = (($$pre197) + 8|0);
    $$pre211 = Math_fround(HEAPF32[$$phi$trans$insert210>>2]);
    $$phi$trans$insert212 = (($$pre197) + 24|0);
    $$pre213 = Math_fround(HEAPF32[$$phi$trans$insert212>>2]);
    $$phi$trans$insert214 = (($$pre197) + 40|0);
    $$pre215 = Math_fround(HEAPF32[$$phi$trans$insert214>>2]);
    $$pre216 = Math_fround(HEAPF32[$planeP>>2]);
    $$pre217 = Math_fround(HEAPF32[$23>>2]);
    $$pre218 = Math_fround(HEAPF32[$24>>2]);
    $iEnd$0190$phi = $iStart$0189;$102 = $$pre199;$104 = $$pre201;$107 = $$pre203;$110 = $$pre205;$112 = $$pre207;$115 = $$pre209;$118 = $$pre211;$120 = $$pre213;$123 = $$pre215;$126 = $$pre216;$128 = $$pre217;$130 = $$pre218;$137 = $135;$140 = $108;$142 = $116;$144 = $124;$164 = $158;$95 = $$pre198;$iStart$0189 = $156;$iEnd$0190 = $iEnd$0190$phi;
   }
   $$pre = HEAP32[$16>>2]|0;
   $162 = $$pre;
  }
  $160 = (($i$0191) + 1)|0;
  $161 = ($160>>>0)<($162>>>0);
  if ($161) {
   $163 = $162;$i$0191 = $160;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu17generatedContactsERNS0_13PolygonalDataES2_RKNS0_15HullPolygonDataES5_PNS0_12SupportLocalES7_RKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVE($polyData0,$polyData1,$referencePolygon,$incidentPolygon,$map0,$map1,$transform0To1,$manifoldContacts,$numContacts,$contactDist) {
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $referencePolygon = $referencePolygon|0;
 $incidentPolygon = $incidentPolygon|0;
 $map0 = $map0|0;
 $map1 = $map1|0;
 $transform0To1 = $transform0To1|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 var $$$i = Math_fround(0), $$$i178 = Math_fround(0), $$$i178986$lcssa = Math_fround(0), $$$i1789861014 = Math_fround(0), $$$i184 = Math_fround(0), $$$i184988$lcssa = Math_fround(0), $$$i1849881012 = Math_fround(0), $$$i216 = Math_fround(0), $$$i216990$lcssa = Math_fround(0), $$$i2169901031 = Math_fround(0), $$$i222 = Math_fround(0), $$$i222992$lcssa = Math_fround(0), $$$i2229921029 = Math_fround(0), $$$i77 = Math_fround(0), $$$i83 = Math_fround(0), $$$i89 = Math_fround(0), $$demorgan = 0, $$demorgan$i = 0, $$demorgan$i158 = 0, $$lcssa1008 = Math_fround(0);
 var $$lcssa1009 = Math_fround(0), $$lcssa1010 = 0, $$lcssa1026 = Math_fround(0), $$lcssa1027 = Math_fround(0), $$phi$trans$insert$i = 0, $$phi$trans$insert$i162 = 0, $$pre = 0, $$pre$i = Math_fround(0), $$pre$i163 = Math_fround(0), $$pre1053 = 0, $$pre1056$pre = 0, $$pre1058 = 0, $$sroa$1471 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0;
 var $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0;
 var $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0);
 var $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0;
 var $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0);
 var $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0);
 var $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0);
 var $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = Math_fround(0), $356 = 0;
 var $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0);
 var $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0);
 var $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0;
 var $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0);
 var $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = 0, $456 = 0, $457 = 0, $458 = Math_fround(0), $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = 0;
 var $483 = Math_fround(0), $484 = Math_fround(0), $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0);
 var $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0);
 var $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0);
 var $555 = Math_fround(0), $556 = Math_fround(0), $557 = 0, $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0;
 var $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0;
 var $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = Math_fround(0), $608 = 0;
 var $609 = Math_fround(0), $61 = 0, $610 = 0, $611 = Math_fround(0), $612 = 0, $613 = Math_fround(0), $614 = 0, $615 = Math_fround(0), $616 = Math_fround(0), $617 = 0, $618 = 0, $619 = Math_fround(0), $62 = 0, $620 = 0, $621 = 0, $622 = Math_fround(0), $623 = 0, $624 = 0, $625 = 0, $626 = 0;
 var $627 = Math_fround(0), $628 = 0, $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = 0, $636 = Math_fround(0), $637 = 0, $638 = Math_fround(0), $639 = 0, $64 = 0, $640 = Math_fround(0), $641 = 0, $642 = 0, $643 = 0, $644 = 0;
 var $645 = 0, $646 = Math_fround(0), $647 = Math_fround(0), $648 = 0, $649 = 0, $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0);
 var $663 = Math_fround(0), $664 = Math_fround(0), $665 = 0, $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0);
 var $681 = 0, $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0);
 var $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = 0;
 var $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0);
 var $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0);
 var $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0;
 var $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $contactNormal = 0, $i$01032 = 0, $i$0308$i = 0;
 var $i$0308$i167 = 0, $i1$01016 = 0, $i2$01005 = 0, $iEnd$01004 = 0, $iEnd$01004$phi = 0, $iStart$01003 = 0, $inside$0$lcssa = 0, $inside$01015 = 0, $inside$1 = 0, $intersectionPoints$0310$i = 0, $intersectionPoints$0310$i165 = 0, $intersectionPoints$1$i = 0, $intersectionPoints$1$i169 = 0, $j$0309$i = 0, $j$0309$i$phi = 0, $j$0309$i166 = 0, $j$0309$i166$phi = 0, $not$ = 0, $not$$i = 0, $not$$i157 = 0;
 var $not$304$i = 0, $not$304$i159 = 0, $not$999 = 0, $or$cond = 0, $or$cond997 = 0, $phitmp = Math_fround(0), $phitmp1040 = Math_fround(0), $phitmp1041 = Math_fround(0), $phitmp1042 = Math_fround(0), $phitmp1043 = Math_fround(0), $phitmp1044 = Math_fround(0), $phitmp1045 = Math_fround(0), $phitmp1046 = Math_fround(0), $rEnd$01001 = 0, $rEnd$01001$phi = 0, $rStart$01000 = 0, $rot = 0, $tmp$i = 0, $tmp$i168 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $contactNormal = sp + 48|0;
 $rot = sp;
 $$sroa$1471 = sp + 64|0;
 $0 = (($polyData0) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($referencePolygon) + 16|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($1) + ($4)|0);
 $6 = (($map0) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = Math_fround(HEAPF32[$referencePolygon>>2]);
 $9 = (($referencePolygon) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($referencePolygon) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(HEAPF32[$7>>2]);
 $14 = Math_fround($8 * $13);
 $15 = (($7) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($10 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($7) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($12 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($7) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($8 * $24);
 $26 = (($7) + 20|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($10 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($7) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($12 * $31);
 $33 = Math_fround($29 + $32);
 $34 = (($7) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($8 * $35);
 $37 = (($7) + 36|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($10 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($7) + 40|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($12 * $42);
 $44 = Math_fround($40 + $43);
 $45 = Math_fround($22 * $22);
 $46 = Math_fround($33 * $33);
 $47 = Math_fround($45 + $46);
 $48 = Math_fround($44 * $44);
 $49 = Math_fround($47 + $48);
 $50 = (Math_fround(Math_sqrt((Math_fround($49)))));
 $51 = Math_fround(Math_fround(1.0) / $50);
 $52 = Math_fround($22 * $51);
 $53 = Math_fround($33 * $51);
 $54 = Math_fround($44 * $51);
 HEAPF32[$contactNormal>>2] = $52;
 $55 = (($contactNormal) + 4|0);
 HEAPF32[$55>>2] = $53;
 $56 = (($contactNormal) + 8|0);
 HEAPF32[$56>>2] = $54;
 $57 = (($contactNormal) + 12|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 __ZN5physx2Gu27findRotationMatrixFromZAxisERKNS_6shdfnd3aos5Vec3VE($rot,$contactNormal);
 $58 = (($polyData1) + 32|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($incidentPolygon) + 16|0);
 $61 = HEAP16[$60>>1]|0;
 $62 = $61&65535;
 $63 = (($59) + ($62)|0);
 $64 = (($referencePolygon) + 18|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = $65&255;
 $67 = $66 << 4;
 $68 = (($67) + 16)|0;
 $69 = STACKTOP; STACKTOP = STACKTOP + ((((1*$68)|0)+15)&-16)|0;;
 $70 = $69;
 $71 = (($70) + 15)|0;
 $72 = $71 & -16;
 $73 = $72;
 $74 = (($incidentPolygon) + 18|0);
 $75 = HEAP8[$74>>0]|0;
 $76 = $75&255;
 $77 = $76 << 4;
 $78 = (($77) + 16)|0;
 $79 = STACKTOP; STACKTOP = STACKTOP + ((((1*$78)|0)+15)&-16)|0;;
 $80 = $79;
 $81 = (($80) + 15)|0;
 $82 = $81 & -16;
 $83 = $82;
 $84 = STACKTOP; STACKTOP = STACKTOP + ((((1*$76)|0)+15)&-16)|0;;
 $85 = STACKTOP; STACKTOP = STACKTOP + ((((1*$78)|0)+15)&-16)|0;;
 $86 = $85;
 $87 = (($86) + 15)|0;
 $88 = $87 & -16;
 $89 = $88;
 $90 = HEAP32[$map0>>2]|0;
 $91 = (($90) + 16|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($polyData0) + 28|0);
 $94 = HEAP32[$93>>2]|0;
 FUNCTION_TABLE_viiiii[$92 & 255]($map0,$5,$66,$94,$73);
 $95 = HEAP32[$map1>>2]|0;
 $96 = (($95) + 16|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = HEAP8[$74>>0]|0;
 $99 = $98&255;
 $100 = (($polyData1) + 28|0);
 $101 = HEAP32[$100>>2]|0;
 FUNCTION_TABLE_viiiii[$97 & 255]($map1,$63,$99,$101,$83);
 $102 = $82;
 $103 = $82;
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($102) + 4|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($102) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = HEAP8[$64>>0]|0;
 $110 = ($109<<24>>24)==(0);
 if ($110) {
  $$$i216990$lcssa = Math_fround(-3.40282346638528859812E+38);$$$i222992$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa1026 = Math_fround(3.40282346638528859812E+38);$$lcssa1027 = Math_fround(-3.40282346638528859812E+38);
 } else {
  $111 = (($rot) + 16|0);
  $112 = (($rot) + 32|0);
  $113 = (($rot) + 4|0);
  $114 = (($rot) + 20|0);
  $115 = (($rot) + 36|0);
  $116 = (($rot) + 8|0);
  $117 = (($rot) + 24|0);
  $118 = (($rot) + 40|0);
  $$$i2169901031 = Math_fround(-3.40282346638528859812E+38);$$$i2229921029 = Math_fround(3.40282346638528859812E+38);$152 = Math_fround(3.40282346638528859812E+38);$156 = Math_fround(-3.40282346638528859812E+38);$i$01032 = 0;
  while(1) {
   $119 = (($73) + ($i$01032<<4)|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = ((($73) + ($i$01032<<4)|0) + 4|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = ((($73) + ($i$01032<<4)|0) + 8|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = ((($73) + ($i$01032<<4)|0) + 12|0);
   $126 = Math_fround(HEAPF32[$rot>>2]);
   $127 = Math_fround($120 * $126);
   $128 = Math_fround(HEAPF32[$111>>2]);
   $129 = Math_fround($122 * $128);
   $130 = Math_fround($127 + $129);
   $131 = Math_fround(HEAPF32[$112>>2]);
   $132 = Math_fround($124 * $131);
   $133 = Math_fround($130 + $132);
   $134 = Math_fround(HEAPF32[$113>>2]);
   $135 = Math_fround($120 * $134);
   $136 = Math_fround(HEAPF32[$114>>2]);
   $137 = Math_fround($122 * $136);
   $138 = Math_fround($135 + $137);
   $139 = Math_fround(HEAPF32[$115>>2]);
   $140 = Math_fround($124 * $139);
   $141 = Math_fround($138 + $140);
   $142 = Math_fround(HEAPF32[$116>>2]);
   $143 = Math_fround($120 * $142);
   $144 = Math_fround(HEAPF32[$117>>2]);
   $145 = Math_fround($122 * $144);
   $146 = Math_fround($143 + $145);
   $147 = Math_fround(HEAPF32[$118>>2]);
   $148 = Math_fround($124 * $147);
   $149 = Math_fround($146 + $148);
   HEAPF32[$119>>2] = $133;
   HEAPF32[$121>>2] = $141;
   HEAPF32[$123>>2] = $149;
   HEAPF32[$125>>2] = Math_fround(0.0);
   $150 = $$$i2229921029 < $133;
   $$$i222 = $150 ? $$$i2229921029 : $133;
   $151 = $152 < $141;
   $153 = $151 ? $152 : $141;
   $154 = $$$i2169901031 > $133;
   $$$i216 = $154 ? $$$i2169901031 : $133;
   $155 = $156 > $141;
   $157 = $155 ? $156 : $141;
   $158 = (($i$01032) + 1)|0;
   $159 = HEAP8[$64>>0]|0;
   $160 = $159&255;
   $161 = ($158>>>0)<($160>>>0);
   if ($161) {
    $$$i2169901031 = $$$i216;$$$i2229921029 = $$$i222;$152 = $153;$156 = $157;$i$01032 = $158;
   } else {
    break;
   }
  }
  $phitmp = Math_fround($$$i222 + Math_fround(-1.1920928955078125E-7));
  $phitmp1040 = Math_fround($153 + Math_fround(-1.1920928955078125E-7));
  $phitmp1041 = Math_fround($$$i216 + Math_fround(1.1920928955078125E-7));
  $phitmp1042 = Math_fround($157 + Math_fround(1.1920928955078125E-7));
  $$$i216990$lcssa = $phitmp1041;$$$i222992$lcssa = $phitmp;$$lcssa1026 = $phitmp1040;$$lcssa1027 = $phitmp1042;
 }
 $162 = $72;
 $163 = (($162) + 8|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = Math_fround(HEAPF32[$contactDist>>2]);
 $166 = Math_fround($164 + $165);
 $167 = HEAP8[$74>>0]|0;
 $168 = $167&255;
 $169 = ($167<<24>>24)==(0);
 if ($169) {
  $$$i178986$lcssa = Math_fround(-3.40282346638528859812E+38);$$$i184988$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa1008 = Math_fround(3.40282346638528859812E+38);$$lcssa1009 = Math_fround(-3.40282346638528859812E+38);$$lcssa1010 = $168;$777 = 0;$inside$0$lcssa = 0;
 } else {
  $170 = (($transform0To1) + 48|0);
  $171 = (($transform0To1) + 52|0);
  $172 = (($transform0To1) + 56|0);
  $173 = (($transform0To1) + 4|0);
  $174 = (($transform0To1) + 8|0);
  $175 = (($transform0To1) + 16|0);
  $176 = (($transform0To1) + 20|0);
  $177 = (($transform0To1) + 24|0);
  $178 = (($transform0To1) + 32|0);
  $179 = (($transform0To1) + 36|0);
  $180 = (($transform0To1) + 40|0);
  $181 = (($rot) + 16|0);
  $182 = (($rot) + 32|0);
  $183 = (($rot) + 4|0);
  $184 = (($rot) + 20|0);
  $185 = (($rot) + 36|0);
  $186 = (($rot) + 8|0);
  $187 = (($rot) + 24|0);
  $188 = (($rot) + 40|0);
  $$$i1789861014 = Math_fround(-3.40282346638528859812E+38);$$$i1849881012 = Math_fround(3.40282346638528859812E+38);$258 = Math_fround(3.40282346638528859812E+38);$262 = Math_fround(-3.40282346638528859812E+38);$i1$01016 = 0;$inside$01015 = 0;
  while(1) {
   $189 = (($83) + ($i1$01016<<4)|0);
   $190 = Math_fround(HEAPF32[$189>>2]);
   $191 = ((($83) + ($i1$01016<<4)|0) + 4|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = ((($83) + ($i1$01016<<4)|0) + 8|0);
   $194 = Math_fround(HEAPF32[$193>>2]);
   $195 = ((($83) + ($i1$01016<<4)|0) + 12|0);
   $196 = Math_fround(HEAPF32[$195>>2]);
   $197 = Math_fround(HEAPF32[$170>>2]);
   $198 = Math_fround(HEAPF32[$171>>2]);
   $199 = Math_fround(HEAPF32[$172>>2]);
   $200 = Math_fround($190 - $197);
   $201 = Math_fround($192 - $198);
   $202 = Math_fround($194 - $199);
   $203 = Math_fround(HEAPF32[$transform0To1>>2]);
   $204 = Math_fround($200 * $203);
   $205 = Math_fround(HEAPF32[$173>>2]);
   $206 = Math_fround($201 * $205);
   $207 = Math_fround($204 + $206);
   $208 = Math_fround(HEAPF32[$174>>2]);
   $209 = Math_fround($202 * $208);
   $210 = Math_fround($207 + $209);
   $211 = Math_fround(HEAPF32[$175>>2]);
   $212 = Math_fround($200 * $211);
   $213 = Math_fround(HEAPF32[$176>>2]);
   $214 = Math_fround($201 * $213);
   $215 = Math_fround($212 + $214);
   $216 = Math_fround(HEAPF32[$177>>2]);
   $217 = Math_fround($202 * $216);
   $218 = Math_fround($215 + $217);
   $219 = Math_fround(HEAPF32[$178>>2]);
   $220 = Math_fround($200 * $219);
   $221 = Math_fround(HEAPF32[$179>>2]);
   $222 = Math_fround($201 * $221);
   $223 = Math_fround($220 + $222);
   $224 = Math_fround(HEAPF32[$180>>2]);
   $225 = Math_fround($202 * $224);
   $226 = Math_fround($223 + $225);
   $227 = Math_fround(HEAPF32[$rot>>2]);
   $228 = Math_fround($210 * $227);
   $229 = Math_fround(HEAPF32[$181>>2]);
   $230 = Math_fround($218 * $229);
   $231 = Math_fround($228 + $230);
   $232 = Math_fround(HEAPF32[$182>>2]);
   $233 = Math_fround($226 * $232);
   $234 = Math_fround($231 + $233);
   $235 = Math_fround(HEAPF32[$183>>2]);
   $236 = Math_fround($210 * $235);
   $237 = Math_fround(HEAPF32[$184>>2]);
   $238 = Math_fround($218 * $237);
   $239 = Math_fround($236 + $238);
   $240 = Math_fround(HEAPF32[$185>>2]);
   $241 = Math_fround($226 * $240);
   $242 = Math_fround($239 + $241);
   $243 = Math_fround(HEAPF32[$186>>2]);
   $244 = Math_fround($210 * $243);
   $245 = Math_fround(HEAPF32[$187>>2]);
   $246 = Math_fround($218 * $245);
   $247 = Math_fround($244 + $246);
   $248 = Math_fround(HEAPF32[$188>>2]);
   $249 = Math_fround($226 * $248);
   $250 = Math_fround($247 + $249);
   HEAPF32[$189>>2] = $234;
   HEAPF32[$191>>2] = $242;
   HEAPF32[$193>>2] = $250;
   HEAPF32[$195>>2] = Math_fround(0.0);
   $251 = Math_fround($250 - $164);
   $252 = (($89) + ($i1$01016<<4)|0);
   HEAPF32[$252>>2] = $251;
   $253 = ((($89) + ($i1$01016<<4)|0) + 4|0);
   ;HEAP32[$253+0>>2]=HEAP32[$$sroa$1471+0>>2]|0;HEAP32[$253+4>>2]=HEAP32[$$sroa$1471+4>>2]|0;HEAP32[$253+8>>2]=HEAP32[$$sroa$1471+8>>2]|0;
   $254 = Math_fround(HEAPF32[$189>>2]);
   $255 = Math_fround(HEAPF32[$191>>2]);
   HEAPF32[$193>>2] = $164;
   HEAPF32[$195>>2] = Math_fround(0.0);
   $256 = $$$i1849881012 < $254;
   $$$i184 = $256 ? $$$i1849881012 : $254;
   $257 = $258 < $255;
   $259 = $257 ? $258 : $255;
   $260 = $$$i1789861014 > $254;
   $$$i178 = $260 ? $$$i1789861014 : $254;
   $261 = $262 > $255;
   $263 = $261 ? $262 : $255;
   $264 = $166 > $250;
   $265 = (($84) + ($i1$01016)|0);
   L11: do {
    if ($264) {
     HEAP8[$265>>0] = 1;
     $266 = HEAP8[$64>>0]|0;
     $267 = $266&255;
     $268 = Math_fround(HEAPF32[$189>>2]);
     $269 = Math_fround(HEAPF32[$191>>2]);
     $270 = $268 > $$$i216990$lcssa;
     $not$$i157 = $$$i222992$lcssa > $268;
     $$demorgan$i158 = $270 | $not$$i157;
     if ($$demorgan$i158) {
      $inside$1 = $inside$01015;
     } else {
      $271 = $269 > $$lcssa1027;
      $not$304$i159 = $$lcssa1026 > $269;
      $272 = $271 | $not$304$i159;
      $273 = ($266<<24>>24)==(0);
      $or$cond = $272 | $273;
      if ($or$cond) {
       $inside$1 = $inside$01015;
      } else {
       $274 = (($267) + -1)|0;
       $$phi$trans$insert$i162 = ((($73) + ($274<<4)|0) + 4|0);
       $$pre$i163 = Math_fround(HEAPF32[$$phi$trans$insert$i162>>2]);
       $278 = $$pre$i163;$i$0308$i167 = 0;$intersectionPoints$0310$i165 = 0;$j$0309$i166 = $274;
       while(1) {
        $275 = ((($73) + ($i$0308$i167<<4)|0) + 4|0);
        $276 = Math_fround(HEAPF32[$275>>2]);
        $277 = $278 > $269;
        $279 = $276 > $269;
        $tmp$i168 = $277 ^ $279;
        if ($tmp$i168) {
         $280 = (($73) + ($i$0308$i167<<4)|0);
         $281 = (($73) + ($j$0309$i166<<4)|0);
         $282 = Math_fround(HEAPF32[$281>>2]);
         $283 = Math_fround(HEAPF32[$280>>2]);
         $284 = Math_fround($283 - $282);
         $285 = Math_fround($276 - $278);
         $286 = Math_fround($269 - $278);
         $287 = Math_fround($286 * $284);
         $288 = Math_fround($285 * $282);
         $289 = Math_fround($268 * $285);
         $290 = Math_fround($288 + $287);
         $291 = !($285 > Math_fround(0.0));
         $292 = $291 ? $289 : $290;
         $293 = $291 ? $290 : $289;
         $294 = !($292 >= $293);
         if ($294) {
          $intersectionPoints$1$i169 = $intersectionPoints$0310$i165;
         } else {
          $295 = ($intersectionPoints$0310$i165|0)==(1);
          if ($295) {
           $inside$1 = $inside$01015;
           break L11;
          }
          $296 = (($intersectionPoints$0310$i165) + 1)|0;
          $intersectionPoints$1$i169 = $296;
         }
        } else {
         $intersectionPoints$1$i169 = $intersectionPoints$0310$i165;
        }
        $297 = (($i$0308$i167) + 1)|0;
        $298 = ($297>>>0)<($267>>>0);
        if ($298) {
         $j$0309$i166$phi = $i$0308$i167;$278 = $276;$i$0308$i167 = $297;$intersectionPoints$0310$i165 = $intersectionPoints$1$i169;$j$0309$i166 = $j$0309$i166$phi;
        } else {
         break;
        }
       }
       $299 = ($intersectionPoints$1$i169|0)==(0);
       if ($299) {
        $inside$1 = $inside$01015;
       } else {
        $300 = (($inside$01015) + 1)|0;
        $301 = Math_fround(HEAPF32[$contactNormal>>2]);
        $302 = Math_fround(HEAPF32[$55>>2]);
        $303 = Math_fround(HEAPF32[$56>>2]);
        $304 = Math_fround(HEAPF32[$252>>2]);
        $305 = HEAP32[$numContacts>>2]|0;
        $306 = (($manifoldContacts) + (($305*48)|0)|0);
        HEAPF32[$306>>2] = $190;
        $307 = ((($manifoldContacts) + (($305*48)|0)|0) + 4|0);
        HEAPF32[$307>>2] = $192;
        $308 = ((($manifoldContacts) + (($305*48)|0)|0) + 8|0);
        HEAPF32[$308>>2] = $194;
        $309 = ((($manifoldContacts) + (($305*48)|0)|0) + 12|0);
        HEAPF32[$309>>2] = $196;
        $310 = HEAP32[$numContacts>>2]|0;
        $311 = Math_fround(HEAPF32[$189>>2]);
        $312 = Math_fround(HEAPF32[$191>>2]);
        $313 = Math_fround(HEAPF32[$193>>2]);
        $314 = Math_fround(HEAPF32[$rot>>2]);
        $315 = Math_fround($311 * $314);
        $316 = Math_fround(HEAPF32[$183>>2]);
        $317 = Math_fround($312 * $316);
        $318 = Math_fround($315 + $317);
        $319 = Math_fround(HEAPF32[$186>>2]);
        $320 = Math_fround($313 * $319);
        $321 = Math_fround($318 + $320);
        $322 = Math_fround(HEAPF32[$181>>2]);
        $323 = Math_fround($311 * $322);
        $324 = Math_fround(HEAPF32[$184>>2]);
        $325 = Math_fround($312 * $324);
        $326 = Math_fround($323 + $325);
        $327 = Math_fround(HEAPF32[$187>>2]);
        $328 = Math_fround($313 * $327);
        $329 = Math_fround($326 + $328);
        $330 = Math_fround(HEAPF32[$182>>2]);
        $331 = Math_fround($311 * $330);
        $332 = Math_fround(HEAPF32[$185>>2]);
        $333 = Math_fround($312 * $332);
        $334 = Math_fround($331 + $333);
        $335 = Math_fround(HEAPF32[$188>>2]);
        $336 = Math_fround($313 * $335);
        $337 = Math_fround($334 + $336);
        $338 = ((($manifoldContacts) + (($310*48)|0)|0) + 16|0);
        HEAPF32[$338>>2] = $321;
        $339 = ((($manifoldContacts) + (($310*48)|0)|0) + 20|0);
        HEAPF32[$339>>2] = $329;
        $340 = ((($manifoldContacts) + (($310*48)|0)|0) + 24|0);
        HEAPF32[$340>>2] = $337;
        $341 = ((($manifoldContacts) + (($310*48)|0)|0) + 28|0);
        HEAPF32[$341>>2] = Math_fround(0.0);
        $342 = HEAP32[$numContacts>>2]|0;
        $343 = (($342) + 1)|0;
        HEAP32[$numContacts>>2] = $343;
        $344 = ((($manifoldContacts) + (($342*48)|0)|0) + 32|0);
        HEAPF32[$344>>2] = $301;
        $345 = ((($manifoldContacts) + (($342*48)|0)|0) + 36|0);
        HEAPF32[$345>>2] = $302;
        $346 = ((($manifoldContacts) + (($342*48)|0)|0) + 40|0);
        HEAPF32[$346>>2] = $303;
        $347 = ((($manifoldContacts) + (($342*48)|0)|0) + 44|0);
        HEAPF32[$347>>2] = $304;
        $inside$1 = $300;
       }
      }
     }
    } else {
     HEAP8[$265>>0] = 0;
     $inside$1 = $inside$01015;
    }
   } while(0);
   $348 = (($i1$01016) + 1)|0;
   $349 = HEAP8[$74>>0]|0;
   $350 = $349&255;
   $351 = ($348>>>0)<($350>>>0);
   if ($351) {
    $$$i1789861014 = $$$i178;$$$i1849881012 = $$$i184;$258 = $259;$262 = $263;$i1$01016 = $348;$inside$01015 = $inside$1;
   } else {
    break;
   }
  }
  $phitmp1043 = Math_fround($$$i184 + Math_fround(-1.1920928955078125E-7));
  $phitmp1044 = Math_fround($259 + Math_fround(-1.1920928955078125E-7));
  $phitmp1045 = Math_fround($$$i178 + Math_fround(1.1920928955078125E-7));
  $phitmp1046 = Math_fround($263 + Math_fround(1.1920928955078125E-7));
  $$$i178986$lcssa = $phitmp1045;$$$i184988$lcssa = $phitmp1043;$$lcssa1008 = $phitmp1044;$$lcssa1009 = $phitmp1046;$$lcssa1010 = $350;$777 = $349;$inside$0$lcssa = $inside$1;
 }
 $352 = ($inside$0$lcssa|0)==($$lcssa1010|0);
 if ($352) {
  STACKTOP = sp;return;
 }
 $353 = (($map1) + 40|0);
 $354 = HEAP32[$353>>2]|0;
 $355 = Math_fround(HEAPF32[$incidentPolygon>>2]);
 $356 = (($incidentPolygon) + 4|0);
 $357 = Math_fround(HEAPF32[$356>>2]);
 $358 = (($incidentPolygon) + 8|0);
 $359 = Math_fround(HEAPF32[$358>>2]);
 $360 = Math_fround(HEAPF32[$354>>2]);
 $361 = Math_fround($355 * $360);
 $362 = (($354) + 4|0);
 $363 = Math_fround(HEAPF32[$362>>2]);
 $364 = Math_fround($357 * $363);
 $365 = Math_fround($361 + $364);
 $366 = (($354) + 8|0);
 $367 = Math_fround(HEAPF32[$366>>2]);
 $368 = Math_fround($359 * $367);
 $369 = Math_fround($365 + $368);
 $370 = (($354) + 16|0);
 $371 = Math_fround(HEAPF32[$370>>2]);
 $372 = Math_fround($355 * $371);
 $373 = (($354) + 20|0);
 $374 = Math_fround(HEAPF32[$373>>2]);
 $375 = Math_fround($357 * $374);
 $376 = Math_fround($372 + $375);
 $377 = (($354) + 24|0);
 $378 = Math_fround(HEAPF32[$377>>2]);
 $379 = Math_fround($359 * $378);
 $380 = Math_fround($376 + $379);
 $381 = (($354) + 32|0);
 $382 = Math_fround(HEAPF32[$381>>2]);
 $383 = Math_fround($355 * $382);
 $384 = (($354) + 36|0);
 $385 = Math_fround(HEAPF32[$384>>2]);
 $386 = Math_fround($357 * $385);
 $387 = Math_fround($383 + $386);
 $388 = (($354) + 40|0);
 $389 = Math_fround(HEAPF32[$388>>2]);
 $390 = Math_fround($359 * $389);
 $391 = Math_fround($387 + $390);
 $392 = Math_fround($369 * $369);
 $393 = Math_fround($380 * $380);
 $394 = Math_fround($392 + $393);
 $395 = Math_fround($391 * $391);
 $396 = Math_fround($394 + $395);
 $397 = (Math_fround(Math_sqrt((Math_fround($396)))));
 $398 = Math_fround(Math_fround(1.0) / $397);
 $399 = Math_fround($369 * $398);
 $400 = Math_fround($380 * $398);
 $401 = Math_fround($391 * $398);
 $402 = Math_fround(HEAPF32[$contactNormal>>2]);
 $403 = Math_fround(HEAPF32[$55>>2]);
 $404 = Math_fround(HEAPF32[$56>>2]);
 $405 = Math_fround(HEAPF32[$transform0To1>>2]);
 $406 = Math_fround($402 * $405);
 $407 = (($transform0To1) + 16|0);
 $408 = Math_fround(HEAPF32[$407>>2]);
 $409 = Math_fround($403 * $408);
 $410 = Math_fround($406 + $409);
 $411 = (($transform0To1) + 32|0);
 $412 = Math_fround(HEAPF32[$411>>2]);
 $413 = Math_fround($404 * $412);
 $414 = Math_fround($410 + $413);
 $415 = (($transform0To1) + 4|0);
 $416 = Math_fround(HEAPF32[$415>>2]);
 $417 = Math_fround($402 * $416);
 $418 = (($transform0To1) + 20|0);
 $419 = Math_fround(HEAPF32[$418>>2]);
 $420 = Math_fround($403 * $419);
 $421 = Math_fround($417 + $420);
 $422 = (($transform0To1) + 36|0);
 $423 = Math_fround(HEAPF32[$422>>2]);
 $424 = Math_fround($404 * $423);
 $425 = Math_fround($421 + $424);
 $426 = (($transform0To1) + 8|0);
 $427 = Math_fround(HEAPF32[$426>>2]);
 $428 = Math_fround($402 * $427);
 $429 = (($transform0To1) + 24|0);
 $430 = Math_fround(HEAPF32[$429>>2]);
 $431 = Math_fround($403 * $430);
 $432 = Math_fround($428 + $431);
 $433 = (($transform0To1) + 40|0);
 $434 = Math_fround(HEAPF32[$433>>2]);
 $435 = Math_fround($404 * $434);
 $436 = Math_fround($432 + $435);
 $437 = HEAP8[$64>>0]|0;
 $438 = ($437<<24>>24)==(0);
 if ($438) {
  STACKTOP = sp;return;
 }
 $439 = (($rot) + 4|0);
 $440 = (($rot) + 8|0);
 $441 = (($rot) + 16|0);
 $442 = (($rot) + 20|0);
 $443 = (($rot) + 24|0);
 $444 = (($rot) + 32|0);
 $445 = (($rot) + 36|0);
 $446 = (($rot) + 40|0);
 $447 = (($transform0To1) + 48|0);
 $448 = (($transform0To1) + 52|0);
 $449 = (($transform0To1) + 56|0);
 $450 = Math_fround($399 * $414);
 $451 = Math_fround($400 * $425);
 $452 = Math_fround($450 + $451);
 $453 = Math_fround($401 * $436);
 $454 = Math_fround($452 + $453);
 $456 = $777;$778 = $437;$i2$01005 = 0;
 while(1) {
  $455 = $456&255;
  $457 = (($73) + ($i2$01005<<4)|0);
  $458 = Math_fround(HEAPF32[$457>>2]);
  $459 = ((($73) + ($i2$01005<<4)|0) + 4|0);
  $460 = Math_fround(HEAPF32[$459>>2]);
  $461 = $458 > $$$i178986$lcssa;
  $not$$i = $$$i184988$lcssa > $458;
  $$demorgan$i = $461 | $not$$i;
  L36: do {
   if ($$demorgan$i) {
    $582 = $778;
   } else {
    $462 = $460 > $$lcssa1009;
    $not$304$i = $$lcssa1008 > $460;
    $463 = $462 | $not$304$i;
    $464 = ($456<<24>>24)==(0);
    $or$cond997 = $463 | $464;
    if ($or$cond997) {
     $582 = $778;
    } else {
     $465 = (($455) + -1)|0;
     $$phi$trans$insert$i = ((($83) + ($465<<4)|0) + 4|0);
     $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
     $469 = $$pre$i;$i$0308$i = 0;$intersectionPoints$0310$i = 0;$j$0309$i = $465;
     while(1) {
      $466 = ((($83) + ($i$0308$i<<4)|0) + 4|0);
      $467 = Math_fround(HEAPF32[$466>>2]);
      $468 = $469 > $460;
      $470 = $467 > $460;
      $tmp$i = $468 ^ $470;
      if ($tmp$i) {
       $471 = (($83) + ($i$0308$i<<4)|0);
       $472 = (($83) + ($j$0309$i<<4)|0);
       $473 = Math_fround(HEAPF32[$472>>2]);
       $474 = Math_fround(HEAPF32[$471>>2]);
       $475 = Math_fround($474 - $473);
       $476 = Math_fround($467 - $469);
       $477 = Math_fround($460 - $469);
       $478 = Math_fround($477 * $475);
       $479 = Math_fround($476 * $473);
       $480 = Math_fround($458 * $476);
       $481 = Math_fround($479 + $478);
       $482 = !($476 > Math_fround(0.0));
       $483 = $482 ? $480 : $481;
       $484 = $482 ? $481 : $480;
       $485 = !($483 >= $484);
       if ($485) {
        $intersectionPoints$1$i = $intersectionPoints$0310$i;
       } else {
        $486 = ($intersectionPoints$0310$i|0)==(1);
        if ($486) {
         $582 = $778;
         break L36;
        }
        $487 = (($intersectionPoints$0310$i) + 1)|0;
        $intersectionPoints$1$i = $487;
       }
      } else {
       $intersectionPoints$1$i = $intersectionPoints$0310$i;
      }
      $488 = (($i$0308$i) + 1)|0;
      $489 = ($488>>>0)<($455>>>0);
      if ($489) {
       $j$0309$i$phi = $i$0308$i;$469 = $467;$i$0308$i = $488;$intersectionPoints$0310$i = $intersectionPoints$1$i;$j$0309$i = $j$0309$i$phi;
      } else {
       break;
      }
     }
     $490 = ($intersectionPoints$1$i|0)==(0);
     if ($490) {
      $582 = $778;
     } else {
      $491 = ((($73) + ($i2$01005<<4)|0) + 8|0);
      $492 = Math_fround(HEAPF32[$491>>2]);
      $493 = Math_fround(HEAPF32[$rot>>2]);
      $494 = Math_fround($458 * $493);
      $495 = Math_fround(HEAPF32[$439>>2]);
      $496 = Math_fround($460 * $495);
      $497 = Math_fround($494 + $496);
      $498 = Math_fround(HEAPF32[$440>>2]);
      $499 = Math_fround($492 * $498);
      $500 = Math_fround($497 + $499);
      $501 = Math_fround(HEAPF32[$441>>2]);
      $502 = Math_fround($458 * $501);
      $503 = Math_fround(HEAPF32[$442>>2]);
      $504 = Math_fround($460 * $503);
      $505 = Math_fround($502 + $504);
      $506 = Math_fround(HEAPF32[$443>>2]);
      $507 = Math_fround($492 * $506);
      $508 = Math_fround($505 + $507);
      $509 = Math_fround(HEAPF32[$444>>2]);
      $510 = Math_fround($458 * $509);
      $511 = Math_fround(HEAPF32[$445>>2]);
      $512 = Math_fround($460 * $511);
      $513 = Math_fround($510 + $512);
      $514 = Math_fround(HEAPF32[$446>>2]);
      $515 = Math_fround($492 * $514);
      $516 = Math_fround($513 + $515);
      $517 = Math_fround(HEAPF32[$447>>2]);
      $518 = Math_fround(HEAPF32[$448>>2]);
      $519 = Math_fround(HEAPF32[$449>>2]);
      $520 = Math_fround(HEAPF32[$transform0To1>>2]);
      $521 = Math_fround($500 * $520);
      $522 = Math_fround(HEAPF32[$407>>2]);
      $523 = Math_fround($508 * $522);
      $524 = Math_fround($521 + $523);
      $525 = Math_fround(HEAPF32[$411>>2]);
      $526 = Math_fround($516 * $525);
      $527 = Math_fround($524 + $526);
      $528 = Math_fround(HEAPF32[$415>>2]);
      $529 = Math_fround($500 * $528);
      $530 = Math_fround(HEAPF32[$418>>2]);
      $531 = Math_fround($508 * $530);
      $532 = Math_fround($529 + $531);
      $533 = Math_fround(HEAPF32[$422>>2]);
      $534 = Math_fround($516 * $533);
      $535 = Math_fround($532 + $534);
      $536 = Math_fround(HEAPF32[$426>>2]);
      $537 = Math_fround($500 * $536);
      $538 = Math_fround(HEAPF32[$429>>2]);
      $539 = Math_fround($508 * $538);
      $540 = Math_fround($537 + $539);
      $541 = Math_fround(HEAPF32[$433>>2]);
      $542 = Math_fround($516 * $541);
      $543 = Math_fround($540 + $542);
      $544 = Math_fround($517 + $527);
      $545 = Math_fround($518 + $535);
      $546 = Math_fround($519 + $543);
      $547 = Math_fround($104 - $544);
      $548 = Math_fround($106 - $545);
      $549 = Math_fround($108 - $546);
      $550 = Math_fround($399 * $547);
      $551 = Math_fround($400 * $548);
      $552 = Math_fround($550 + $551);
      $553 = Math_fround($401 * $549);
      $554 = Math_fround($552 + $553);
      $555 = Math_fround($554 / $454);
      $556 = Math_fround(HEAPF32[$contactDist>>2]);
      $557 = $555 > $556;
      if ($557) {
       $582 = $778;
      } else {
       $558 = Math_fround($414 * $555);
       $559 = Math_fround($425 * $555);
       $560 = Math_fround($436 * $555);
       $561 = Math_fround($544 + $558);
       $562 = Math_fround($545 + $559);
       $563 = Math_fround($560 + $546);
       $564 = HEAP32[$numContacts>>2]|0;
       $565 = (($manifoldContacts) + (($564*48)|0)|0);
       HEAPF32[$565>>2] = $561;
       $566 = ((($manifoldContacts) + (($564*48)|0)|0) + 4|0);
       HEAPF32[$566>>2] = $562;
       $567 = ((($manifoldContacts) + (($564*48)|0)|0) + 8|0);
       HEAPF32[$567>>2] = $563;
       $568 = ((($manifoldContacts) + (($564*48)|0)|0) + 12|0);
       HEAPF32[$568>>2] = Math_fround(0.0);
       $569 = HEAP32[$numContacts>>2]|0;
       $570 = ((($manifoldContacts) + (($569*48)|0)|0) + 16|0);
       HEAPF32[$570>>2] = $500;
       $571 = ((($manifoldContacts) + (($569*48)|0)|0) + 20|0);
       HEAPF32[$571>>2] = $508;
       $572 = ((($manifoldContacts) + (($569*48)|0)|0) + 24|0);
       HEAPF32[$572>>2] = $516;
       $573 = ((($manifoldContacts) + (($569*48)|0)|0) + 28|0);
       HEAPF32[$573>>2] = Math_fround(0.0);
       $574 = HEAP32[$numContacts>>2]|0;
       $575 = (($574) + 1)|0;
       HEAP32[$numContacts>>2] = $575;
       $576 = ((($manifoldContacts) + (($574*48)|0)|0) + 32|0);
       HEAPF32[$576>>2] = $402;
       $577 = ((($manifoldContacts) + (($574*48)|0)|0) + 36|0);
       HEAPF32[$577>>2] = $403;
       $578 = ((($manifoldContacts) + (($574*48)|0)|0) + 40|0);
       HEAPF32[$578>>2] = $404;
       $579 = ((($manifoldContacts) + (($574*48)|0)|0) + 44|0);
       HEAPF32[$579>>2] = $555;
       $$pre1053 = HEAP8[$64>>0]|0;
       $582 = $$pre1053;
      }
     }
    }
   }
  } while(0);
  $580 = (($i2$01005) + 1)|0;
  $581 = $582&255;
  $583 = ($580>>>0)<($581>>>0);
  if (!($583)) {
   break;
  }
  $$pre1058 = HEAP8[$74>>0]|0;
  $456 = $$pre1058;$778 = $582;$i2$01005 = $580;
 }
 $584 = ($582<<24>>24)==(0);
 if ($584) {
  STACKTOP = sp;return;
 }
 $585 = HEAP8[$74>>0]|0;
 $586 = ($585<<24>>24)==(0);
 if ($586) {
  STACKTOP = sp;return;
 }
 $587 = $585&255;
 $588 = (($587) + -1)|0;
 $589 = (($rot) + 4|0);
 $590 = (($rot) + 8|0);
 $591 = (($rot) + 16|0);
 $592 = (($rot) + 20|0);
 $593 = (($rot) + 24|0);
 $594 = (($rot) + 32|0);
 $595 = (($rot) + 36|0);
 $596 = (($rot) + 40|0);
 $597 = (($transform0To1) + 56|0);
 $598 = (($transform0To1) + 52|0);
 $599 = (($transform0To1) + 48|0);
 $624 = $582;$779 = $585;$780 = $582;$iEnd$01004 = $588;$iStart$01003 = 0;
 while(1) {
  $600 = (($84) + ($iStart$01003)|0);
  $601 = HEAP8[$600>>0]|0;
  $602 = ($601<<24>>24)==(0);
  if ($602) {
   $603 = (($84) + ($iEnd$01004)|0);
   $604 = HEAP8[$603>>0]|0;
   $605 = ($604<<24>>24)==(0);
   if ($605) {
    $775 = $779;$781 = $780;$782 = $624;
   } else {
    label = 42;
   }
  } else {
   label = 42;
  }
  if ((label|0) == 42) {
   label = 0;
   $606 = (($83) + ($iStart$01003<<4)|0);
   $607 = Math_fround(HEAPF32[$606>>2]);
   $608 = ((($83) + ($iStart$01003<<4)|0) + 4|0);
   $609 = Math_fround(HEAPF32[$608>>2]);
   $610 = (($83) + ($iEnd$01004<<4)|0);
   $611 = Math_fround(HEAPF32[$610>>2]);
   $612 = ((($83) + ($iEnd$01004<<4)|0) + 4|0);
   $613 = Math_fround(HEAPF32[$612>>2]);
   $614 = (($89) + ($iStart$01003<<4)|0);
   $615 = Math_fround(HEAPF32[$614>>2]);
   $616 = Math_fround($164 + $615);
   $617 = $607 < $611;
   $$$i89 = $617 ? $607 : $611;
   $618 = $609 < $613;
   $619 = $618 ? $609 : $613;
   $620 = $607 > $611;
   $$$i83 = $620 ? $607 : $611;
   $621 = $609 > $613;
   $622 = $621 ? $609 : $613;
   $623 = ($624<<24>>24)==(0);
   if ($623) {
    $775 = $779;$781 = $780;$782 = 0;
   } else {
    $625 = (($89) + ($iEnd$01004<<4)|0);
    $626 = $624&255;
    $627 = Math_fround(HEAPF32[$625>>2]);
    $628 = (($626) + -1)|0;
    $629 = Math_fround($164 + $627);
    $630 = Math_fround($611 - $607);
    $631 = Math_fround($613 - $609);
    $632 = Math_fround($629 - $616);
    $783 = $780;$rEnd$01001 = $628;$rStart$01000 = 0;
    while(1) {
     $633 = (($73) + ($rStart$01000<<4)|0);
     $634 = Math_fround(HEAPF32[$633>>2]);
     $635 = ((($73) + ($rStart$01000<<4)|0) + 4|0);
     $636 = Math_fround(HEAPF32[$635>>2]);
     $637 = (($73) + ($rEnd$01001<<4)|0);
     $638 = Math_fround(HEAPF32[$637>>2]);
     $639 = ((($73) + ($rEnd$01001<<4)|0) + 4|0);
     $640 = Math_fround(HEAPF32[$639>>2]);
     $641 = $634 < $638;
     $$$i77 = $641 ? $634 : $638;
     $642 = $634 > $638;
     $$$i = $642 ? $634 : $638;
     $643 = $$$i77 > $$$i83;
     $not$ = $$$i89 > $$$i;
     $$demorgan = $643 | $not$;
     if ($$demorgan) {
      $771 = $783;
     } else {
      $644 = $636 < $640;
      $645 = $636 > $640;
      $646 = $644 ? $636 : $640;
      $647 = $645 ? $636 : $640;
      $648 = $646 > $622;
      $not$999 = $619 > $647;
      $649 = $648 | $not$999;
      if ($649) {
       $771 = $783;
      } else {
       $650 = Math_fround($634 - $607);
       $651 = Math_fround($636 - $609);
       $652 = Math_fround($638 - $607);
       $653 = Math_fround($640 - $609);
       $654 = Math_fround($650 * $653);
       $655 = Math_fround($651 * $652);
       $656 = Math_fround($654 - $655);
       $657 = Math_fround($634 - $611);
       $658 = Math_fround($636 - $613);
       $659 = Math_fround($638 - $611);
       $660 = Math_fround($640 - $613);
       $661 = Math_fround($657 * $660);
       $662 = Math_fround($658 * $659);
       $663 = Math_fround($661 - $662);
       $664 = Math_fround($656 * $663);
       $665 = $664 < Math_fround(0.0);
       if ($665) {
        $666 = Math_fround($607 - $634);
        $667 = Math_fround($609 - $636);
        $668 = Math_fround($611 - $634);
        $669 = Math_fround($613 - $636);
        $670 = Math_fround($666 * $669);
        $671 = Math_fround($668 * $667);
        $672 = Math_fround($670 - $671);
        $673 = Math_fround($607 - $638);
        $674 = Math_fround($609 - $640);
        $675 = Math_fround($611 - $638);
        $676 = Math_fround($613 - $640);
        $677 = Math_fround($673 * $676);
        $678 = Math_fround($675 * $674);
        $679 = Math_fround($677 - $678);
        $680 = Math_fround($672 * $679);
        $681 = $680 < Math_fround(0.0);
        if ($681) {
         $682 = Math_fround($663 - $656);
         $683 = Math_fround($656 / $682);
         $684 = Math_fround($630 * $683);
         $685 = Math_fround($631 * $683);
         $686 = Math_fround($632 * $683);
         $687 = Math_fround($607 - $684);
         $688 = Math_fround($609 - $685);
         $689 = Math_fround($616 - $686);
         $690 = Math_fround(HEAPF32[$rot>>2]);
         $691 = Math_fround($690 * $687);
         $692 = Math_fround(HEAPF32[$589>>2]);
         $693 = Math_fround($692 * $688);
         $694 = Math_fround($691 + $693);
         $695 = Math_fround(HEAPF32[$590>>2]);
         $696 = Math_fround(HEAPF32[$591>>2]);
         $697 = Math_fround($687 * $696);
         $698 = Math_fround(HEAPF32[$592>>2]);
         $699 = Math_fround($688 * $698);
         $700 = Math_fround($697 + $699);
         $701 = Math_fround(HEAPF32[$593>>2]);
         $702 = Math_fround(HEAPF32[$594>>2]);
         $703 = Math_fround($687 * $702);
         $704 = Math_fround(HEAPF32[$595>>2]);
         $705 = Math_fround($688 * $704);
         $706 = Math_fround($703 + $705);
         $707 = Math_fround(HEAPF32[$596>>2]);
         $708 = Math_fround($689 * $695);
         $709 = Math_fround($694 + $708);
         $710 = Math_fround($689 * $701);
         $711 = Math_fround($700 + $710);
         $712 = Math_fround($689 * $707);
         $713 = Math_fround($706 + $712);
         $714 = Math_fround($689 - $164);
         $715 = Math_fround(HEAPF32[$contactDist>>2]);
         $716 = $714 > $715;
         if ($716) {
          $771 = $783;
         } else {
          $717 = Math_fround(HEAPF32[$429>>2]);
          $718 = Math_fround(HEAPF32[$426>>2]);
          $719 = Math_fround(HEAPF32[$418>>2]);
          $720 = Math_fround(HEAPF32[$415>>2]);
          $721 = Math_fround(HEAPF32[$407>>2]);
          $722 = Math_fround(HEAPF32[$transform0To1>>2]);
          $723 = Math_fround(HEAPF32[$433>>2]);
          $724 = Math_fround($711 * $717);
          $725 = Math_fround($709 * $718);
          $726 = Math_fround(HEAPF32[$422>>2]);
          $727 = Math_fround($711 * $719);
          $728 = Math_fround($709 * $720);
          $729 = Math_fround(HEAPF32[$411>>2]);
          $730 = Math_fround($711 * $721);
          $731 = Math_fround($709 * $722);
          $732 = Math_fround($713 * $723);
          $733 = Math_fround($724 + $725);
          $734 = Math_fround($713 * $726);
          $735 = Math_fround($727 + $728);
          $736 = Math_fround($713 * $729);
          $737 = Math_fround($730 + $731);
          $738 = Math_fround($733 + $732);
          $739 = Math_fround($735 + $734);
          $740 = Math_fround($737 + $736);
          $741 = Math_fround(HEAPF32[$597>>2]);
          $742 = Math_fround(HEAPF32[$598>>2]);
          $743 = Math_fround(HEAPF32[$599>>2]);
          $744 = Math_fround($164 * $707);
          $745 = Math_fround($164 * $701);
          $746 = Math_fround($164 * $695);
          $747 = Math_fround($738 + $741);
          $748 = Math_fround($739 + $742);
          $749 = Math_fround($740 + $743);
          $750 = Math_fround($706 + $744);
          $751 = Math_fround($700 + $745);
          $752 = Math_fround($694 + $746);
          $753 = HEAP32[$numContacts>>2]|0;
          $754 = (($manifoldContacts) + (($753*48)|0)|0);
          HEAPF32[$754>>2] = $749;
          $755 = ((($manifoldContacts) + (($753*48)|0)|0) + 4|0);
          HEAPF32[$755>>2] = $748;
          $756 = ((($manifoldContacts) + (($753*48)|0)|0) + 8|0);
          HEAPF32[$756>>2] = $747;
          $757 = ((($manifoldContacts) + (($753*48)|0)|0) + 12|0);
          HEAPF32[$757>>2] = Math_fround(0.0);
          $758 = HEAP32[$numContacts>>2]|0;
          $759 = ((($manifoldContacts) + (($758*48)|0)|0) + 16|0);
          HEAPF32[$759>>2] = $752;
          $760 = ((($manifoldContacts) + (($758*48)|0)|0) + 20|0);
          HEAPF32[$760>>2] = $751;
          $761 = ((($manifoldContacts) + (($758*48)|0)|0) + 24|0);
          HEAPF32[$761>>2] = $750;
          $762 = ((($manifoldContacts) + (($758*48)|0)|0) + 28|0);
          HEAPF32[$762>>2] = Math_fround(0.0);
          $763 = HEAP32[$numContacts>>2]|0;
          $764 = (($763) + 1)|0;
          HEAP32[$numContacts>>2] = $764;
          $765 = ((($manifoldContacts) + (($763*48)|0)|0) + 32|0);
          HEAPF32[$765>>2] = $402;
          $766 = ((($manifoldContacts) + (($763*48)|0)|0) + 36|0);
          HEAPF32[$766>>2] = $403;
          $767 = ((($manifoldContacts) + (($763*48)|0)|0) + 40|0);
          HEAPF32[$767>>2] = $404;
          $768 = ((($manifoldContacts) + (($763*48)|0)|0) + 44|0);
          HEAPF32[$768>>2] = $714;
          $$pre = HEAP8[$64>>0]|0;
          $771 = $$pre;
         }
        } else {
         $771 = $783;
        }
       } else {
        $771 = $783;
       }
      }
     }
     $769 = (($rStart$01000) + 1)|0;
     $770 = $771&255;
     $772 = ($769>>>0)<($770>>>0);
     if ($772) {
      $rEnd$01001$phi = $rStart$01000;$783 = $771;$rStart$01000 = $769;$rEnd$01001 = $rEnd$01001$phi;
     } else {
      break;
     }
    }
    $$pre1056$pre = HEAP8[$74>>0]|0;
    $775 = $$pre1056$pre;$781 = $771;$782 = $771;
   }
  }
  $773 = (($iStart$01003) + 1)|0;
  $774 = $775&255;
  $776 = ($773>>>0)<($774>>>0);
  if ($776) {
   $iEnd$01004$phi = $iStart$01003;$624 = $782;$779 = $775;$780 = $781;$iStart$01003 = $773;$iEnd$01004 = $iEnd$01004$phi;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu27generateFullContactManifoldERNS0_13PolygonalDataES2_PNS0_12SupportLocalES4_PNS0_17PersistentContactERjRKNS_6shdfnd3aos6FloatVERKNS9_5Vec3VEb($polyData0,$polyData1,$map0,$map1,$manifoldContacts,$numContacts,$contactDist,$normal,$doOverlapTest) {
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $map0 = $map0|0;
 $map1 = $map1|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $normal = $normal|0;
 $doOverlapTest = $doOverlapTest|0;
 var $$0 = 0, $$not = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0);
 var $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0;
 var $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0);
 var $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = 0;
 var $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0);
 var $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0);
 var $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0);
 var $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0);
 var $42 = Math_fround(0), $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0);
 var $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0);
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0);
 var $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge = 0, $doEdgeTest$0$off0 = 0, $feature0 = 0, $feature1 = 0, $i$064 = 0, $localPointB = 0, $minNormal = 0, $minOverlap = 0, $n = 0, $status = 0, $transform0To1V = 0;
 var $transform1To0V = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $transform1To0V = sp + 208|0;
 $transform0To1V = sp + 112|0;
 $status = sp + 272|0;
 $minOverlap = sp + 192|0;
 $minNormal = sp + 176|0;
 $feature0 = sp + 276|0;
 $feature1 = sp + 280|0;
 $n = sp + 96|0;
 $localPointB = sp + 64|0;
 $0 = sp + 48|0;
 $1 = sp + 32|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = sp + 80|0;
 $5 = (($map0) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($map1) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$6>>2]);
 $10 = (($6) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($6) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($6) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(-$9);
 $17 = Math_fround(-$11);
 $18 = Math_fround(-$13);
 $19 = (($8) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($8) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($8) + 24|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($6) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($6) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($6) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($20 - $26);
 $32 = Math_fround($22 - $28);
 $33 = Math_fround($24 - $30);
 $34 = Math_fround($15 * $15);
 $35 = Math_fround($34 + Math_fround(-0.5));
 $36 = Math_fround($35 * $31);
 $37 = Math_fround($35 * $32);
 $38 = Math_fround($35 * $33);
 $39 = Math_fround($33 * $17);
 $40 = Math_fround($32 * $18);
 $41 = Math_fround($39 - $40);
 $42 = Math_fround($31 * $18);
 $43 = Math_fround($33 * $16);
 $44 = Math_fround($42 - $43);
 $45 = Math_fround($32 * $16);
 $46 = Math_fround($31 * $17);
 $47 = Math_fround($45 - $46);
 $48 = Math_fround($15 * $41);
 $49 = Math_fround($15 * $44);
 $50 = Math_fround($15 * $47);
 $51 = Math_fround($36 + $48);
 $52 = Math_fround($37 + $49);
 $53 = Math_fround($38 + $50);
 $54 = Math_fround($31 * $16);
 $55 = Math_fround($32 * $17);
 $56 = Math_fround($54 + $55);
 $57 = Math_fround($33 * $18);
 $58 = Math_fround($56 + $57);
 $59 = Math_fround($58 * $16);
 $60 = Math_fround($58 * $17);
 $61 = Math_fround($58 * $18);
 $62 = Math_fround($59 + $51);
 $63 = Math_fround($60 + $52);
 $64 = Math_fround($53 + $61);
 $65 = Math_fround($62 * Math_fround(2.0));
 $66 = Math_fround($63 * Math_fround(2.0));
 $67 = Math_fround($64 * Math_fround(2.0));
 $68 = Math_fround(HEAPF32[$8>>2]);
 $69 = (($8) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($8) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($8) + 12|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($15 * $74);
 $76 = Math_fround($68 * $16);
 $77 = Math_fround($70 * $17);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($72 * $18);
 $80 = Math_fround($78 + $79);
 $81 = Math_fround($75 - $80);
 $82 = Math_fround($74 * $16);
 $83 = Math_fround($74 * $17);
 $84 = Math_fround($74 * $18);
 $85 = Math_fround($15 * $68);
 $86 = Math_fround($15 * $70);
 $87 = Math_fround($15 * $72);
 $88 = Math_fround($72 * $17);
 $89 = Math_fround($70 * $18);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($68 * $18);
 $92 = Math_fround($72 * $16);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($70 * $16);
 $95 = Math_fround($68 * $17);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($85 + $82);
 $98 = Math_fround($86 + $83);
 $99 = Math_fround($87 + $84);
 $100 = Math_fround($90 + $97);
 $101 = Math_fround($93 + $98);
 $102 = Math_fround($96 + $99);
 $103 = (($transform1To0V) + 48|0);
 HEAPF32[$103>>2] = $65;
 $104 = (($transform1To0V) + 52|0);
 HEAPF32[$104>>2] = $66;
 $105 = (($transform1To0V) + 56|0);
 HEAPF32[$105>>2] = $67;
 $106 = (($transform1To0V) + 60|0);
 HEAPF32[$106>>2] = Math_fround(0.0);
 $107 = Math_fround($100 + $100);
 $108 = Math_fround($101 + $101);
 $109 = Math_fround($102 + $102);
 $110 = Math_fround($100 * $107);
 $111 = Math_fround($101 * $108);
 $112 = Math_fround($102 * $109);
 $113 = Math_fround($101 * $107);
 $114 = Math_fround($102 * $107);
 $115 = Math_fround($81 * $107);
 $116 = Math_fround($102 * $108);
 $117 = Math_fround($81 * $108);
 $118 = Math_fround($81 * $109);
 $119 = Math_fround(Math_fround(1.0) - $110);
 $120 = Math_fround(Math_fround(1.0) - $111);
 $121 = Math_fround($120 - $112);
 $122 = Math_fround($113 + $118);
 $123 = Math_fround($114 - $117);
 $124 = Math_fround($113 - $118);
 $125 = Math_fround($119 - $112);
 $126 = Math_fround($116 + $115);
 $127 = Math_fround($114 + $117);
 $128 = Math_fround($116 - $115);
 $129 = Math_fround($119 - $111);
 HEAPF32[$transform1To0V>>2] = $121;
 $130 = (($transform1To0V) + 4|0);
 HEAPF32[$130>>2] = $122;
 $131 = (($transform1To0V) + 8|0);
 HEAPF32[$131>>2] = $123;
 $132 = (($transform1To0V) + 12|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = (($transform1To0V) + 16|0);
 HEAPF32[$133>>2] = $124;
 $134 = (($transform1To0V) + 20|0);
 HEAPF32[$134>>2] = $125;
 $135 = (($transform1To0V) + 24|0);
 HEAPF32[$135>>2] = $126;
 $136 = (($transform1To0V) + 28|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 $137 = (($transform1To0V) + 32|0);
 HEAPF32[$137>>2] = $127;
 $138 = (($transform1To0V) + 36|0);
 HEAPF32[$138>>2] = $128;
 $139 = (($transform1To0V) + 40|0);
 HEAPF32[$139>>2] = $129;
 $140 = (($transform1To0V) + 44|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $141 = HEAP32[$7>>2]|0;
 $142 = HEAP32[$5>>2]|0;
 $143 = Math_fround(HEAPF32[$141>>2]);
 $144 = (($141) + 4|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($141) + 8|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = (($141) + 12|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = Math_fround(-$143);
 $151 = Math_fround(-$145);
 $152 = Math_fround(-$147);
 $153 = (($142) + 16|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($142) + 20|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($142) + 24|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($141) + 16|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($141) + 20|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = (($141) + 24|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = Math_fround($154 - $160);
 $166 = Math_fround($156 - $162);
 $167 = Math_fround($158 - $164);
 $168 = Math_fround($149 * $149);
 $169 = Math_fround($168 + Math_fround(-0.5));
 $170 = Math_fround($169 * $165);
 $171 = Math_fround($169 * $166);
 $172 = Math_fround($169 * $167);
 $173 = Math_fround($167 * $151);
 $174 = Math_fround($166 * $152);
 $175 = Math_fround($173 - $174);
 $176 = Math_fround($165 * $152);
 $177 = Math_fround($167 * $150);
 $178 = Math_fround($176 - $177);
 $179 = Math_fround($166 * $150);
 $180 = Math_fround($165 * $151);
 $181 = Math_fround($179 - $180);
 $182 = Math_fround($149 * $175);
 $183 = Math_fround($149 * $178);
 $184 = Math_fround($149 * $181);
 $185 = Math_fround($170 + $182);
 $186 = Math_fround($171 + $183);
 $187 = Math_fround($172 + $184);
 $188 = Math_fround($165 * $150);
 $189 = Math_fround($166 * $151);
 $190 = Math_fround($188 + $189);
 $191 = Math_fround($167 * $152);
 $192 = Math_fround($190 + $191);
 $193 = Math_fround($192 * $150);
 $194 = Math_fround($192 * $151);
 $195 = Math_fround($192 * $152);
 $196 = Math_fround($193 + $185);
 $197 = Math_fround($194 + $186);
 $198 = Math_fround($187 + $195);
 $199 = Math_fround($196 * Math_fround(2.0));
 $200 = Math_fround($197 * Math_fround(2.0));
 $201 = Math_fround($198 * Math_fround(2.0));
 $202 = Math_fround(HEAPF32[$142>>2]);
 $203 = (($142) + 4|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = (($142) + 8|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = (($142) + 12|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = Math_fround($149 * $208);
 $210 = Math_fround($202 * $150);
 $211 = Math_fround($204 * $151);
 $212 = Math_fround($210 + $211);
 $213 = Math_fround($206 * $152);
 $214 = Math_fround($212 + $213);
 $215 = Math_fround($209 - $214);
 $216 = Math_fround($208 * $150);
 $217 = Math_fround($208 * $151);
 $218 = Math_fround($208 * $152);
 $219 = Math_fround($149 * $202);
 $220 = Math_fround($149 * $204);
 $221 = Math_fround($149 * $206);
 $222 = Math_fround($206 * $151);
 $223 = Math_fround($204 * $152);
 $224 = Math_fround($222 - $223);
 $225 = Math_fround($202 * $152);
 $226 = Math_fround($206 * $150);
 $227 = Math_fround($225 - $226);
 $228 = Math_fround($204 * $150);
 $229 = Math_fround($202 * $151);
 $230 = Math_fround($228 - $229);
 $231 = Math_fround($219 + $216);
 $232 = Math_fround($220 + $217);
 $233 = Math_fround($221 + $218);
 $234 = Math_fround($224 + $231);
 $235 = Math_fround($227 + $232);
 $236 = Math_fround($230 + $233);
 $237 = (($transform0To1V) + 48|0);
 HEAPF32[$237>>2] = $199;
 $238 = (($transform0To1V) + 52|0);
 HEAPF32[$238>>2] = $200;
 $239 = (($transform0To1V) + 56|0);
 HEAPF32[$239>>2] = $201;
 $240 = (($transform0To1V) + 60|0);
 HEAPF32[$240>>2] = Math_fround(0.0);
 $241 = Math_fround($234 + $234);
 $242 = Math_fround($235 + $235);
 $243 = Math_fround($236 + $236);
 $244 = Math_fround($234 * $241);
 $245 = Math_fround($235 * $242);
 $246 = Math_fround($236 * $243);
 $247 = Math_fround($235 * $241);
 $248 = Math_fround($236 * $241);
 $249 = Math_fround($215 * $241);
 $250 = Math_fround($236 * $242);
 $251 = Math_fround($215 * $242);
 $252 = Math_fround($215 * $243);
 $253 = Math_fround(Math_fround(1.0) - $244);
 $254 = Math_fround(Math_fround(1.0) - $245);
 $255 = Math_fround($254 - $246);
 $256 = Math_fround($247 + $252);
 $257 = Math_fround($248 - $251);
 $258 = Math_fround($247 - $252);
 $259 = Math_fround($253 - $246);
 $260 = Math_fround($250 + $249);
 $261 = Math_fround($248 + $251);
 $262 = Math_fround($250 - $249);
 $263 = Math_fround($253 - $245);
 HEAPF32[$transform0To1V>>2] = $255;
 $264 = (($transform0To1V) + 4|0);
 HEAPF32[$264>>2] = $256;
 $265 = (($transform0To1V) + 8|0);
 HEAPF32[$265>>2] = $257;
 $266 = (($transform0To1V) + 12|0);
 HEAPF32[$266>>2] = Math_fround(0.0);
 $267 = (($transform0To1V) + 16|0);
 HEAPF32[$267>>2] = $258;
 $268 = (($transform0To1V) + 20|0);
 HEAPF32[$268>>2] = $259;
 $269 = (($transform0To1V) + 24|0);
 HEAPF32[$269>>2] = $260;
 $270 = (($transform0To1V) + 28|0);
 HEAPF32[$270>>2] = Math_fround(0.0);
 $271 = (($transform0To1V) + 32|0);
 HEAPF32[$271>>2] = $261;
 $272 = (($transform0To1V) + 36|0);
 HEAPF32[$272>>2] = $262;
 $273 = (($transform0To1V) + 40|0);
 HEAPF32[$273>>2] = $263;
 $274 = (($transform0To1V) + 44|0);
 HEAPF32[$274>>2] = Math_fround(0.0);
 $275 = HEAP32[$numContacts>>2]|0;
 if (!($doOverlapTest)) {
  $417 = Math_fround(HEAPF32[$normal>>2]);
  $418 = (($normal) + 4|0);
  $419 = Math_fround(HEAPF32[$418>>2]);
  $420 = (($normal) + 8|0);
  $421 = Math_fround(HEAPF32[$420>>2]);
  $422 = Math_fround(-$417);
  $423 = Math_fround(-$419);
  $424 = Math_fround(-$421);
  HEAPF32[$3>>2] = $422;
  $425 = (($3) + 4|0);
  HEAPF32[$425>>2] = $423;
  $426 = (($3) + 8|0);
  HEAPF32[$426>>2] = $424;
  $427 = (($3) + 12|0);
  HEAPF32[$427>>2] = Math_fround(0.0);
  $428 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData1,$map1,$3)|0);
  $429 = Math_fround(HEAPF32[$normal>>2]);
  $430 = Math_fround(HEAPF32[$418>>2]);
  $431 = Math_fround(HEAPF32[$420>>2]);
  $432 = Math_fround(HEAPF32[$transform0To1V>>2]);
  $433 = Math_fround($429 * $432);
  $434 = Math_fround(HEAPF32[$264>>2]);
  $435 = Math_fround($430 * $434);
  $436 = Math_fround($433 + $435);
  $437 = Math_fround(HEAPF32[$265>>2]);
  $438 = Math_fround($431 * $437);
  $439 = Math_fround($436 + $438);
  $440 = Math_fround(HEAPF32[$267>>2]);
  $441 = Math_fround($429 * $440);
  $442 = Math_fround(HEAPF32[$268>>2]);
  $443 = Math_fround($430 * $442);
  $444 = Math_fround($441 + $443);
  $445 = Math_fround(HEAPF32[$269>>2]);
  $446 = Math_fround($431 * $445);
  $447 = Math_fround($444 + $446);
  $448 = Math_fround(HEAPF32[$271>>2]);
  $449 = Math_fround($429 * $448);
  $450 = Math_fround(HEAPF32[$272>>2]);
  $451 = Math_fround($430 * $450);
  $452 = Math_fround($449 + $451);
  $453 = Math_fround(HEAPF32[$273>>2]);
  $454 = Math_fround($431 * $453);
  $455 = Math_fround($452 + $454);
  HEAPF32[$4>>2] = $439;
  $456 = (($4) + 4|0);
  HEAPF32[$456>>2] = $447;
  $457 = (($4) + 8|0);
  HEAPF32[$457>>2] = $455;
  $458 = (($4) + 12|0);
  HEAPF32[$458>>2] = Math_fround(0.0);
  $459 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData0,$map0,$4)|0);
  $460 = (($polyData1) + 24|0);
  $461 = HEAP32[$460>>2]|0;
  $462 = (($461) + (($428*20)|0)|0);
  $463 = (($polyData0) + 24|0);
  $464 = HEAP32[$463>>2]|0;
  $465 = (($464) + (($459*20)|0)|0);
  __ZN5physx2Gu17generatedContactsERNS0_13PolygonalDataES2_RKNS0_15HullPolygonDataES5_PNS0_12SupportLocalES7_RKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVE($polyData1,$polyData0,$462,$465,$map1,$map0,$transform1To0V,$manifoldContacts,$numContacts,$contactDist);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$status>>2] = 0;
 HEAPF32[$minOverlap>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$minNormal+0>>2]=0|0;HEAP32[$minNormal+4>>2]=0|0;HEAP32[$minNormal+8>>2]=0|0;HEAP32[$minNormal+12>>2]=0|0;
 $276 = (__ZN5physx2GuL14testFaceNormalERKNS0_13PolygonalDataES3_PNS0_12SupportLocalES5_RKNS_6shdfnd3aos15PsMatTransformVESA_RKNS7_6FloatVERSB_RjRNS7_5Vec3VENS0_13FeatureStatusERSI_($polyData0,$polyData1,$map0,$map1,$transform0To1V,$transform1To0V,$contactDist,$minOverlap,$feature0,$minNormal,0,$status)|0);
 if (!($276)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $277 = (__ZN5physx2GuL14testFaceNormalERKNS0_13PolygonalDataES3_PNS0_12SupportLocalES5_RKNS_6shdfnd3aos15PsMatTransformVESA_RKNS7_6FloatVERSB_RjRNS7_5Vec3VENS0_13FeatureStatusERSI_($polyData1,$polyData0,$map1,$map0,$transform1To0V,$transform0To1V,$contactDist,$minOverlap,$feature1,$minNormal,1,$status)|0);
 if (!($277)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $278 = (($minNormal) + 4|0);
 $279 = (($minNormal) + 8|0);
 $280 = (($1) + 4|0);
 $281 = (($1) + 8|0);
 $282 = (($1) + 12|0);
 $283 = (($polyData0) + 24|0);
 $284 = (($2) + 4|0);
 $285 = (($2) + 8|0);
 $286 = (($2) + 12|0);
 $287 = (($polyData1) + 24|0);
 $288 = HEAP32[$feature0>>2]|0;
 $289 = (($n) + 4|0);
 $290 = (($n) + 8|0);
 $291 = (($n) + 12|0);
 $292 = HEAP32[$feature1>>2]|0;
 $293 = (($0) + 4|0);
 $294 = (($0) + 8|0);
 $295 = (($0) + 12|0);
 $doEdgeTest$0$off0 = 0;
 L11: while(1) {
  do {
   if ($doEdgeTest$0$off0) {
    $296 = (__ZN5physx2GuL14testEdgeNormalERKNS0_13PolygonalDataES3_PNS0_12SupportLocalES5_RKNS_6shdfnd3aos15PsMatTransformVESA_RKNS7_6FloatVERSB_RNS7_5Vec3VENS0_13FeatureStatusERSH_($polyData0,$polyData1,$map0,$map1,$transform0To1V,$transform1To0V,$contactDist,$minOverlap,$minNormal,$status)|0);
    if (!($296)) {
     $$0 = 0;
     label = 16;
     break L11;
    }
    $297 = HEAP32[$status>>2]|0;
    $298 = ($297|0)==(2);
    if ($298) {
     label = 13;
    } else {
     $$0 = 1;
     label = 16;
     break L11;
    }
   } else {
    $$pr = HEAP32[$status>>2]|0;
    if ((($$pr|0) == 1)) {
     $348 = HEAP32[$287>>2]|0;
     $349 = (($348) + (($292*20)|0)|0);
     $350 = Math_fround(HEAPF32[$minNormal>>2]);
     $351 = Math_fround(HEAPF32[$278>>2]);
     $352 = Math_fround(HEAPF32[$279>>2]);
     $353 = Math_fround(HEAPF32[$transform1To0V>>2]);
     $354 = Math_fround($350 * $353);
     $355 = Math_fround(HEAPF32[$133>>2]);
     $356 = Math_fround($351 * $355);
     $357 = Math_fround($354 + $356);
     $358 = Math_fround(HEAPF32[$137>>2]);
     $359 = Math_fround($352 * $358);
     $360 = Math_fround($357 + $359);
     $361 = Math_fround(HEAPF32[$130>>2]);
     $362 = Math_fround($350 * $361);
     $363 = Math_fround(HEAPF32[$134>>2]);
     $364 = Math_fround($351 * $363);
     $365 = Math_fround($362 + $364);
     $366 = Math_fround(HEAPF32[$138>>2]);
     $367 = Math_fround($352 * $366);
     $368 = Math_fround($365 + $367);
     $369 = Math_fround(HEAPF32[$131>>2]);
     $370 = Math_fround($350 * $369);
     $371 = Math_fround(HEAPF32[$135>>2]);
     $372 = Math_fround($351 * $371);
     $373 = Math_fround($370 + $372);
     $374 = Math_fround(HEAPF32[$139>>2]);
     $375 = Math_fround($352 * $374);
     $376 = Math_fround($373 + $375);
     HEAPF32[$0>>2] = $360;
     HEAPF32[$293>>2] = $368;
     HEAPF32[$294>>2] = $376;
     HEAPF32[$295>>2] = Math_fround(0.0);
     $377 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData0,$map0,$0)|0);
     $378 = HEAP32[$283>>2]|0;
     $379 = (($378) + (($377*20)|0)|0);
     __ZN5physx2Gu17generatedContactsERNS0_13PolygonalDataES2_RKNS0_15HullPolygonDataES5_PNS0_12SupportLocalES7_RKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVE($polyData1,$polyData0,$349,$379,$map1,$map0,$transform1To0V,$manifoldContacts,$numContacts,$contactDist);
     break;
    } else if (!((($$pr|0) == 0))) {
     label = 13;
     break;
    }
    $299 = HEAP32[$283>>2]|0;
    $300 = (($299) + (($288*20)|0)|0);
    $301 = Math_fround(HEAPF32[$minNormal>>2]);
    $302 = Math_fround(HEAPF32[$278>>2]);
    $303 = Math_fround(HEAPF32[$279>>2]);
    $304 = Math_fround(HEAPF32[$transform0To1V>>2]);
    $305 = Math_fround($301 * $304);
    $306 = Math_fround(HEAPF32[$267>>2]);
    $307 = Math_fround($302 * $306);
    $308 = Math_fround($305 + $307);
    $309 = Math_fround(HEAPF32[$271>>2]);
    $310 = Math_fround($303 * $309);
    $311 = Math_fround($308 + $310);
    $312 = Math_fround(HEAPF32[$264>>2]);
    $313 = Math_fround($301 * $312);
    $314 = Math_fround(HEAPF32[$268>>2]);
    $315 = Math_fround($302 * $314);
    $316 = Math_fround($313 + $315);
    $317 = Math_fround(HEAPF32[$272>>2]);
    $318 = Math_fround($303 * $317);
    $319 = Math_fround($316 + $318);
    $320 = Math_fround(HEAPF32[$265>>2]);
    $321 = Math_fround($301 * $320);
    $322 = Math_fround(HEAPF32[$269>>2]);
    $323 = Math_fround($302 * $322);
    $324 = Math_fround($321 + $323);
    $325 = Math_fround(HEAPF32[$273>>2]);
    $326 = Math_fround($303 * $325);
    $327 = Math_fround($324 + $326);
    HEAPF32[$n>>2] = $311;
    HEAPF32[$289>>2] = $319;
    HEAPF32[$290>>2] = $327;
    HEAPF32[$291>>2] = Math_fround(0.0);
    $328 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData1,$map1,$n)|0);
    $329 = HEAP32[$287>>2]|0;
    $330 = (($329) + (($328*20)|0)|0);
    __ZN5physx2Gu17generatedContactsERNS0_13PolygonalDataES2_RKNS0_15HullPolygonDataES5_PNS0_12SupportLocalES7_RKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVE($polyData0,$polyData1,$300,$330,$map0,$map1,$transform0To1V,$manifoldContacts,$numContacts,$contactDist);
    $331 = HEAP32[$numContacts>>2]|0;
    $332 = ($331|0)==($275|0);
    if (!($332)) {
     $333 = Math_fround(HEAPF32[$n>>2]);
     $334 = Math_fround(HEAPF32[$289>>2]);
     $335 = Math_fround(HEAPF32[$290>>2]);
     $336 = Math_fround(-$333);
     $337 = Math_fround(-$334);
     $338 = Math_fround(-$335);
     $339 = ($275>>>0)<($331>>>0);
     if ($339) {
      $i$064 = $275;
      while(1) {
       $340 = (($manifoldContacts) + (($i$064*48)|0)|0);
       $341 = ((($manifoldContacts) + (($i$064*48)|0)|0) + 16|0);
       ;HEAP32[$localPointB+0>>2]=HEAP32[$341+0>>2]|0;HEAP32[$localPointB+4>>2]=HEAP32[$341+4>>2]|0;HEAP32[$localPointB+8>>2]=HEAP32[$341+8>>2]|0;HEAP32[$localPointB+12>>2]=HEAP32[$341+12>>2]|0;
       ;HEAP32[$341+0>>2]=HEAP32[$340+0>>2]|0;HEAP32[$341+4>>2]=HEAP32[$340+4>>2]|0;HEAP32[$341+8>>2]=HEAP32[$340+8>>2]|0;HEAP32[$341+12>>2]=HEAP32[$340+12>>2]|0;
       ;HEAP32[$340+0>>2]=HEAP32[$localPointB+0>>2]|0;HEAP32[$340+4>>2]=HEAP32[$localPointB+4>>2]|0;HEAP32[$340+8>>2]=HEAP32[$localPointB+8>>2]|0;HEAP32[$340+12>>2]=HEAP32[$localPointB+12>>2]|0;
       $342 = ((($manifoldContacts) + (($i$064*48)|0)|0) + 32|0);
       HEAPF32[$342>>2] = $336;
       $343 = ((($manifoldContacts) + (($i$064*48)|0)|0) + 36|0);
       HEAPF32[$343>>2] = $337;
       $344 = ((($manifoldContacts) + (($i$064*48)|0)|0) + 40|0);
       HEAPF32[$344>>2] = $338;
       $345 = (($i$064) + 1)|0;
       $346 = HEAP32[$numContacts>>2]|0;
       $347 = ($345>>>0)<($346>>>0);
       if ($347) {
        $i$064 = $345;
       } else {
        break;
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 13) {
   label = 0;
   $380 = Math_fround(HEAPF32[$minNormal>>2]);
   $381 = Math_fround(HEAPF32[$278>>2]);
   $382 = Math_fround(HEAPF32[$279>>2]);
   $383 = Math_fround(-$380);
   $384 = Math_fround(-$381);
   $385 = Math_fround(-$382);
   HEAPF32[$1>>2] = $383;
   HEAPF32[$280>>2] = $384;
   HEAPF32[$281>>2] = $385;
   HEAPF32[$282>>2] = Math_fround(0.0);
   $386 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData0,$map0,$1)|0);
   $387 = HEAP32[$283>>2]|0;
   $388 = (($387) + (($386*20)|0)|0);
   $389 = Math_fround(HEAPF32[$transform0To1V>>2]);
   $390 = Math_fround($380 * $389);
   $391 = Math_fround(HEAPF32[$267>>2]);
   $392 = Math_fround($381 * $391);
   $393 = Math_fround($390 + $392);
   $394 = Math_fround(HEAPF32[$271>>2]);
   $395 = Math_fround($382 * $394);
   $396 = Math_fround($393 + $395);
   $397 = Math_fround(HEAPF32[$264>>2]);
   $398 = Math_fround($380 * $397);
   $399 = Math_fround(HEAPF32[$268>>2]);
   $400 = Math_fround($381 * $399);
   $401 = Math_fround($398 + $400);
   $402 = Math_fround(HEAPF32[$272>>2]);
   $403 = Math_fround($382 * $402);
   $404 = Math_fround($401 + $403);
   $405 = Math_fround(HEAPF32[$265>>2]);
   $406 = Math_fround($380 * $405);
   $407 = Math_fround(HEAPF32[$269>>2]);
   $408 = Math_fround($381 * $407);
   $409 = Math_fround($406 + $408);
   $410 = Math_fround(HEAPF32[$273>>2]);
   $411 = Math_fround($382 * $410);
   $412 = Math_fround($409 + $411);
   HEAPF32[$2>>2] = $396;
   HEAPF32[$284>>2] = $404;
   HEAPF32[$285>>2] = $412;
   HEAPF32[$286>>2] = Math_fround(0.0);
   $413 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData1,$map1,$2)|0);
   $414 = HEAP32[$287>>2]|0;
   $415 = (($414) + (($413*20)|0)|0);
   __ZN5physx2Gu17generatedContactsERNS0_13PolygonalDataES2_RKNS0_15HullPolygonDataES5_PNS0_12SupportLocalES7_RKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVE($polyData1,$polyData0,$415,$388,$map1,$map0,$transform1To0V,$manifoldContacts,$numContacts,$contactDist);
  }
  $416 = HEAP32[$numContacts>>2]|0;
  $$not = ($416|0)!=($275|0);
  $brmerge = $$not | $doEdgeTest$0$off0;
  if ($brmerge) {
   $$0 = 1;
   label = 16;
   break;
  } else {
   $doEdgeTest$0$off0 = 1;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2GuL14testFaceNormalERKNS0_13PolygonalDataES3_PNS0_12SupportLocalES5_RKNS_6shdfnd3aos15PsMatTransformVESA_RKNS7_6FloatVERSB_RjRNS7_5Vec3VENS0_13FeatureStatusERSI_($polyData0,$polyData1,$map0,$map1,$transform0To1,$transform1To0,$contactDist,$minOverlap,$feature,$faceNormal,$faceStatus,$status) {
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $map0 = $map0|0;
 $map1 = $map1|0;
 $transform0To1 = $transform0To1|0;
 $transform1To0 = $transform1To0|0;
 $contactDist = $contactDist|0;
 $minOverlap = $minOverlap|0;
 $feature = $feature|0;
 $faceNormal = $faceNormal|0;
 $faceStatus = $faceStatus|0;
 $status = $status|0;
 var $$$i = Math_fround(0), $$$i48 = Math_fround(0), $$$i65 = Math_fround(0), $$0 = 0, $$in1$i = 0, $$in2$i = 0, $$lcssa = Math_fround(0), $$lcssa408 = Math_fround(0), $$lcssa410 = Math_fround(0), $$lcssa412 = Math_fround(0), $$lcssa414 = Math_fround(0), $$sroa$1131 = 0, $$sroa$1133 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0);
 var $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0;
 var $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0);
 var $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0);
 var $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0);
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0);
 var $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $_feature$0$lcssa = 0, $_feature$0417 = 0, $_feature$1 = 0, $_minOverlap$sroa$1 = 0;
 var $a$pn3$i = 0, $b$a$i = 0, $b$a5$i = 0, $i$0418 = 0, $max1 = 0, $min1 = 0, $n1 = 0, $tempOverlap$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 16|0;
 $1 = sp + 64|0;
 $_minOverlap$sroa$1 = sp + 116|0;
 $min1 = sp + 32|0;
 $max1 = sp + 48|0;
 $n1 = sp;
 $$sroa$1133 = sp + 80|0;
 $$sroa$1131 = sp + 92|0;
 $tempOverlap$sroa$1 = sp + 104|0;
 $2 = Math_fround(HEAPF32[$faceNormal>>2]);
 $3 = (($faceNormal) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($faceNormal) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($faceNormal) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($transform1To0) + 48|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($transform1To0) + 52|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($transform1To0) + 56|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$polyData1>>2]);
 $16 = (($polyData1) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($polyData1) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$transform1To0>>2]);
 $21 = Math_fround($15 * $20);
 $22 = (($transform1To0) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($17 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($transform1To0) + 32|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($19 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($transform1To0) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($15 * $31);
 $33 = (($transform1To0) + 20|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($17 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($transform1To0) + 36|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($19 * $38);
 $40 = Math_fround($36 + $39);
 $41 = (($transform1To0) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($15 * $42);
 $44 = (($transform1To0) + 24|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($17 * $45);
 $47 = Math_fround($43 + $46);
 $48 = (($transform1To0) + 40|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($19 * $49);
 $51 = Math_fround($47 + $50);
 $52 = Math_fround($10 + $29);
 $53 = Math_fround($12 + $40);
 $54 = Math_fround($14 + $51);
 $55 = (($polyData1) + 40|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($polyData1) + 44|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($polyData1) + 48|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($polyData1) + 52|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround(-$58);
 $64 = Math_fround(-$60);
 $65 = Math_fround(-$62);
 $66 = (($polyData0) + 16|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0);
 L1: do {
  if ($68) {
   $$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa408 = $8;$$lcssa410 = $6;$$lcssa412 = $4;$$lcssa414 = $2;$_feature$0$lcssa = 0;
  } else {
   $69 = (($polyData0) + 24|0);
   $70 = (($polyData0) + 28|0);
   $71 = (($map0) + 40|0);
   $72 = (($transform0To1) + 16|0);
   $73 = (($transform0To1) + 32|0);
   $74 = (($transform0To1) + 4|0);
   $75 = (($transform0To1) + 20|0);
   $76 = (($transform0To1) + 36|0);
   $77 = (($transform0To1) + 8|0);
   $78 = (($transform0To1) + 24|0);
   $79 = (($transform0To1) + 40|0);
   $80 = (($n1) + 4|0);
   $81 = (($n1) + 8|0);
   $82 = (($n1) + 12|0);
   $83 = (($1) + 4|0);
   $84 = (($1) + 8|0);
   $85 = (($1) + 12|0);
   $86 = (($0) + 4|0);
   $87 = (($0) + 8|0);
   $88 = (($0) + 12|0);
   $89 = (($min1) + 4|0);
   $90 = (($max1) + 4|0);
   $208 = Math_fround(3.40282346638528859812E+38);$234 = $2;$235 = $4;$236 = $6;$237 = $8;$_feature$0417 = 0;$i$0418 = 0;
   while(1) {
    $91 = HEAP32[$69>>2]|0;
    $92 = ((($91) + (($i$0418*20)|0)|0) + 19|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = $93&255;
    $95 = HEAP32[$70>>2]|0;
    $96 = (($95) + (($94*12)|0)|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = ((($95) + (($94*12)|0)|0) + 4|0);
    $99 = Math_fround(HEAPF32[$98>>2]);
    $100 = ((($95) + (($94*12)|0)|0) + 8|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = ((($91) + (($i$0418*20)|0)|0) + 12|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = (($91) + (($i$0418*20)|0)|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = ((($91) + (($i$0418*20)|0)|0) + 4|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = ((($91) + (($i$0418*20)|0)|0) + 8|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = HEAP32[$71>>2]|0;
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = Math_fround($105 * $111);
    $113 = (($110) + 4|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = Math_fround($107 * $114);
    $116 = Math_fround($112 + $115);
    $117 = (($110) + 8|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = Math_fround($109 * $118);
    $120 = Math_fround($116 + $119);
    $121 = (($110) + 16|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = Math_fround($105 * $122);
    $124 = (($110) + 20|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = Math_fround($107 * $125);
    $127 = Math_fround($123 + $126);
    $128 = (($110) + 24|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = Math_fround($109 * $129);
    $131 = Math_fround($127 + $130);
    $132 = (($110) + 32|0);
    $133 = Math_fround(HEAPF32[$132>>2]);
    $134 = Math_fround($105 * $133);
    $135 = (($110) + 36|0);
    $136 = Math_fround(HEAPF32[$135>>2]);
    $137 = Math_fround($107 * $136);
    $138 = Math_fround($134 + $137);
    $139 = (($110) + 40|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = Math_fround($109 * $140);
    $142 = Math_fround($138 + $141);
    $143 = Math_fround($120 * $120);
    $144 = Math_fround($131 * $131);
    $145 = Math_fround($143 + $144);
    $146 = Math_fround($142 * $142);
    $147 = Math_fround($145 + $146);
    $148 = (Math_fround(Math_sqrt((Math_fround($147)))));
    $149 = Math_fround(Math_fround(1.0) / $148);
    $150 = Math_fround($97 * $105);
    $151 = Math_fround($99 * $107);
    $152 = Math_fround($150 + $151);
    $153 = Math_fround($101 * $109);
    $154 = Math_fround($152 + $153);
    $155 = Math_fround($154 * $149);
    $156 = Math_fround($103 * $149);
    $157 = Math_fround(-$156);
    $158 = Math_fround($120 * $149);
    $159 = Math_fround($131 * $149);
    $160 = Math_fround($149 * $142);
    $161 = Math_fround(HEAPF32[$transform0To1>>2]);
    $162 = Math_fround($158 * $161);
    $163 = Math_fround(HEAPF32[$72>>2]);
    $164 = Math_fround($159 * $163);
    $165 = Math_fround($162 + $164);
    $166 = Math_fround(HEAPF32[$73>>2]);
    $167 = Math_fround($160 * $166);
    $168 = Math_fround($165 + $167);
    $169 = Math_fround(HEAPF32[$74>>2]);
    $170 = Math_fround($158 * $169);
    $171 = Math_fround(HEAPF32[$75>>2]);
    $172 = Math_fround($159 * $171);
    $173 = Math_fround($170 + $172);
    $174 = Math_fround(HEAPF32[$76>>2]);
    $175 = Math_fround($160 * $174);
    $176 = Math_fround($173 + $175);
    $177 = Math_fround(HEAPF32[$77>>2]);
    $178 = Math_fround($158 * $177);
    $179 = Math_fround(HEAPF32[$78>>2]);
    $180 = Math_fround($159 * $179);
    $181 = Math_fround($178 + $180);
    $182 = Math_fround(HEAPF32[$79>>2]);
    $183 = Math_fround($160 * $182);
    $184 = Math_fround($181 + $183);
    HEAPF32[$n1>>2] = $168;
    HEAPF32[$80>>2] = $176;
    HEAPF32[$81>>2] = $184;
    HEAPF32[$82>>2] = Math_fround(0.0);
    $185 = $168 > Math_fround(0.0);
    $186 = $176 > Math_fround(0.0);
    $187 = $184 > Math_fround(0.0);
    HEAPF32[$1>>2] = $58;
    HEAPF32[$83>>2] = $60;
    HEAPF32[$84>>2] = $62;
    HEAPF32[$85>>2] = Math_fround(0.0);
    HEAPF32[$0>>2] = $63;
    HEAPF32[$86>>2] = $64;
    HEAPF32[$87>>2] = $65;
    HEAPF32[$88>>2] = Math_fround(0.0);
    $b$a$i = $185 ? $1 : $0;
    $188 = Math_fround(HEAPF32[$b$a$i>>2]);
    $a$pn3$i = $186 ? $1 : $0;
    $$in1$i = (($a$pn3$i) + 4|0);
    $189 = Math_fround(HEAPF32[$$in1$i>>2]);
    $b$a5$i = $187 ? $1 : $0;
    $$in2$i = (($b$a5$i) + 8|0);
    $190 = Math_fround(HEAPF32[$$in2$i>>2]);
    $191 = Math_fround($188 * $168);
    $192 = Math_fround($189 * $176);
    $193 = Math_fround($191 + $192);
    $194 = Math_fround($190 * $184);
    $195 = Math_fround($193 + $194);
    $196 = $195 > $56;
    $$$i65 = $196 ? $195 : $56;
    $197 = Math_fround($52 * $158);
    $198 = Math_fround($53 * $159);
    $199 = Math_fround($197 + $198);
    $200 = Math_fround($54 * $160);
    $201 = Math_fround($200 + $199);
    $202 = Math_fround($201 - $$$i65);
    $203 = Math_fround($201 + $$$i65);
    $204 = $155 > $202;
    $$$i48 = $204 ? $155 : $202;
    $205 = $203 < $157;
    $$$i = $205 ? $203 : $157;
    $206 = Math_fround($$$i - $$$i48);
    $207 = $206 > $208;
    if ($207) {
     $238 = $208;$239 = $237;$240 = $236;$241 = $235;$242 = $234;$_feature$1 = $_feature$0417;
    } else {
     $209 = Math_fround($10 * $158);
     $210 = Math_fround($12 * $159);
     $211 = Math_fround($209 + $210);
     $212 = Math_fround($14 * $160);
     $213 = Math_fround($212 + $211);
     $214 = HEAP32[$map1>>2]|0;
     $215 = (($214) + 12|0);
     $216 = HEAP32[$215>>2]|0;
     FUNCTION_TABLE_viiii[$216 & 511]($map1,$n1,$min1,$max1);
     $217 = Math_fround(HEAPF32[$min1>>2]);
     $218 = Math_fround($213 + $217);
     HEAPF32[$min1>>2] = $218;
     ;HEAP32[$89+0>>2]=HEAP32[$$sroa$1133+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$$sroa$1133+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$$sroa$1133+8>>2]|0;
     $219 = Math_fround(HEAPF32[$max1>>2]);
     $220 = Math_fround($213 + $219);
     HEAPF32[$max1>>2] = $220;
     ;HEAP32[$90+0>>2]=HEAP32[$$sroa$1131+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$$sroa$1131+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$$sroa$1131+8>>2]|0;
     $221 = Math_fround(HEAPF32[$contactDist>>2]);
     $222 = Math_fround($221 - $156);
     $223 = $218 > $222;
     if ($223) {
      $$0 = 0;
      label = 12;
      break;
     }
     $224 = Math_fround($221 + $220);
     $225 = $155 > $224;
     if ($225) {
      $$0 = 0;
      label = 12;
      break;
     }
     $226 = Math_fround($157 - $218);
     $227 = $208 > $226;
     if ($227) {
      ;HEAP32[$_minOverlap$sroa$1+0>>2]=HEAP32[$tempOverlap$sroa$1+0>>2]|0;HEAP32[$_minOverlap$sroa$1+4>>2]=HEAP32[$tempOverlap$sroa$1+4>>2]|0;HEAP32[$_minOverlap$sroa$1+8>>2]=HEAP32[$tempOverlap$sroa$1+8>>2]|0;
      $238 = $226;$239 = Math_fround(0.0);$240 = $160;$241 = $159;$242 = $158;$_feature$1 = $i$0418;
     } else {
      $238 = $208;$239 = $237;$240 = $236;$241 = $235;$242 = $234;$_feature$1 = $_feature$0417;
     }
    }
    $228 = (($i$0418) + 1)|0;
    $229 = HEAP32[$66>>2]|0;
    $230 = ($228>>>0)<($229>>>0);
    if ($230) {
     $208 = $238;$234 = $242;$235 = $241;$236 = $240;$237 = $239;$_feature$0417 = $_feature$1;$i$0418 = $228;
    } else {
     $$lcssa = $238;$$lcssa408 = $239;$$lcssa410 = $240;$$lcssa412 = $241;$$lcssa414 = $242;$_feature$0$lcssa = $_feature$1;
     break L1;
    }
   }
   if ((label|0) == 12) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $231 = Math_fround(HEAPF32[$minOverlap>>2]);
 $232 = $231 > $$lcssa;
 if ($232) {
  $233 = (($minOverlap) + 4|0);
  HEAPF32[$faceNormal>>2] = $$lcssa414;
  HEAPF32[$3>>2] = $$lcssa412;
  HEAPF32[$5>>2] = $$lcssa410;
  HEAPF32[$7>>2] = $$lcssa408;
  HEAPF32[$minOverlap>>2] = $$lcssa;
  ;HEAP32[$233+0>>2]=HEAP32[$_minOverlap$sroa$1+0>>2]|0;HEAP32[$233+4>>2]=HEAP32[$_minOverlap$sroa$1+4>>2]|0;HEAP32[$233+8>>2]=HEAP32[$_minOverlap$sroa$1+8>>2]|0;
  HEAP32[$status>>2] = $faceStatus;
 }
 HEAP32[$feature>>2] = $_feature$0$lcssa;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2GuL14testEdgeNormalERKNS0_13PolygonalDataES3_PNS0_12SupportLocalES5_RKNS_6shdfnd3aos15PsMatTransformVESA_RKNS7_6FloatVERSB_RNS7_5Vec3VENS0_13FeatureStatusERSH_($polyData0,$polyData1,$map0,$map1,$transform0To1,$transform1To0,$contactDist,$minOverlap,$edgeNormalIn0,$status) {
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $map0 = $map0|0;
 $map1 = $map1|0;
 $transform0To1 = $transform0To1|0;
 $transform1To0 = $transform1To0|0;
 $contactDist = $contactDist|0;
 $minOverlap = $minOverlap|0;
 $edgeNormalIn0 = $edgeNormalIn0|0;
 $status = $status|0;
 var $$$i$us = Math_fround(0), $$$i48$us = Math_fround(0), $$$i55$us = Math_fround(0), $$$i86$us = Math_fround(0), $$0 = 0, $$in1$i$us = 0, $$in1$i100$us = 0, $$in2$i$us = 0, $$in2$i102$us = 0, $$lcssa526 = Math_fround(0), $$sroa$1156 = 0, $$sroa$1158 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0;
 var $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0;
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0);
 var $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0);
 var $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0;
 var $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0);
 var $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0);
 var $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0);
 var $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0);
 var $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0);
 var $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0;
 var $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$pn3$i$us = 0;
 var $a$pn3$i99$us = 0, $b$a$i$us = 0, $b$a$i97$us = 0, $b$a5$i$us = 0, $b$a5$i101$us = 0, $dir0 = 0, $dir1 = 0, $i$0528 = 0, $i$0528$us = 0, $j$0525$us = 0, $mSA0 = 0, $mSA1 = 0, $max0 = 0, $max1 = 0, $min0 = 0, $min1 = 0, $n0 = 0, $n1 = 0, $overlap$sroa$1 = 0, $support0 = 0;
 var $support0In1 = 0, $support1 = 0, $support1In0 = 0, $tempOverlap$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 6464|0;
 $0 = sp + 48|0;
 $1 = sp + 224|0;
 $2 = sp + 240|0;
 $3 = sp + 208|0;
 $overlap$sroa$1 = sp + 6444|0;
 $min0 = sp + 192|0;
 $max0 = sp + 176|0;
 $min1 = sp + 32|0;
 $max1 = sp + 16|0;
 $dir0 = sp;
 $support0 = sp + 64|0;
 $dir1 = sp + 160|0;
 $support1 = sp + 80|0;
 $support0In1 = sp + 96|0;
 $support1In0 = sp + 112|0;
 $mSA0 = sp + 3368|0;
 $mSA1 = sp + 292|0;
 $n0 = sp + 128|0;
 $n1 = sp + 144|0;
 $$sroa$1158 = sp + 268|0;
 $$sroa$1156 = sp + 280|0;
 $tempOverlap$sroa$1 = sp + 256|0;
 $4 = Math_fround(HEAPF32[$minOverlap>>2]);
 $5 = (($minOverlap) + 4|0);
 ;HEAP32[$overlap$sroa$1+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$overlap$sroa$1+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$overlap$sroa$1+8>>2]=HEAP32[$5+8>>2]|0;
 $6 = Math_fround(HEAPF32[$polyData0>>2]);
 $7 = (($polyData0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($polyData0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$polyData1>>2]);
 $12 = (($polyData1) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($polyData1) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($transform1To0) + 48|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($transform1To0) + 52|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($transform1To0) + 56|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(HEAPF32[$transform1To0>>2]);
 $23 = Math_fround($11 * $22);
 $24 = (($transform1To0) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($13 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($transform1To0) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($15 * $29);
 $31 = Math_fround($27 + $30);
 $32 = (($transform1To0) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($11 * $33);
 $35 = (($transform1To0) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($13 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($transform1To0) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($15 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($transform1To0) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($11 * $44);
 $46 = (($transform1To0) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($13 * $47);
 $49 = Math_fround($45 + $48);
 $50 = (($transform1To0) + 40|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($15 * $51);
 $53 = Math_fround($49 + $52);
 $54 = Math_fround($17 + $31);
 $55 = Math_fround($19 + $42);
 $56 = Math_fround($21 + $53);
 $57 = Math_fround($54 - $6);
 $58 = Math_fround($55 - $8);
 $59 = Math_fround($56 - $10);
 $60 = (($polyData1) + 40|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($polyData1) + 44|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($polyData1) + 48|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($polyData1) + 52|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround(-$63);
 $69 = Math_fround(-$65);
 $70 = Math_fround(-$67);
 $71 = (($polyData0) + 40|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($polyData0) + 44|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($polyData0) + 48|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($polyData0) + 52|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround(-$74);
 $80 = Math_fround(-$76);
 $81 = Math_fround(-$78);
 HEAPF32[$dir0>>2] = $57;
 $82 = (($dir0) + 4|0);
 HEAPF32[$82>>2] = $58;
 $83 = (($dir0) + 8|0);
 HEAPF32[$83>>2] = $59;
 $84 = (($dir0) + 12|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 $85 = HEAP32[$map0>>2]|0;
 $86 = (($85) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 FUNCTION_TABLE_viii[$87 & 4095]($support0,$map0,$dir0);
 $88 = Math_fround(HEAPF32[$dir0>>2]);
 $89 = Math_fround(HEAPF32[$82>>2]);
 $90 = Math_fround(HEAPF32[$83>>2]);
 $91 = Math_fround(-$88);
 $92 = Math_fround(-$89);
 $93 = Math_fround(-$90);
 $94 = Math_fround(HEAPF32[$transform0To1>>2]);
 $95 = Math_fround($94 * $91);
 $96 = (($transform0To1) + 16|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 * $92);
 $99 = Math_fround($95 + $98);
 $100 = (($transform0To1) + 32|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($101 * $93);
 $103 = Math_fround($99 + $102);
 $104 = (($transform0To1) + 4|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($105 * $91);
 $107 = (($transform0To1) + 20|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($108 * $92);
 $110 = Math_fround($106 + $109);
 $111 = (($transform0To1) + 36|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($112 * $93);
 $114 = Math_fround($110 + $113);
 $115 = (($transform0To1) + 8|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($116 * $91);
 $118 = (($transform0To1) + 24|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($119 * $92);
 $121 = Math_fround($117 + $120);
 $122 = (($transform0To1) + 40|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($123 * $93);
 $125 = Math_fround($121 + $124);
 HEAPF32[$dir1>>2] = $103;
 $126 = (($dir1) + 4|0);
 HEAPF32[$126>>2] = $114;
 $127 = (($dir1) + 8|0);
 HEAPF32[$127>>2] = $125;
 $128 = (($dir1) + 12|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 $129 = HEAP32[$map1>>2]|0;
 $130 = (($129) + 8|0);
 $131 = HEAP32[$130>>2]|0;
 FUNCTION_TABLE_viii[$131 & 4095]($support1,$map1,$dir1);
 $132 = (($transform0To1) + 48|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($transform0To1) + 52|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($transform0To1) + 56|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = Math_fround(HEAPF32[$support0>>2]);
 $139 = (($support0) + 4|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($support0) + 8|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround(HEAPF32[$transform0To1>>2]);
 $144 = Math_fround($138 * $143);
 $145 = Math_fround(HEAPF32[$96>>2]);
 $146 = Math_fround($140 * $145);
 $147 = Math_fround($144 + $146);
 $148 = Math_fround(HEAPF32[$100>>2]);
 $149 = Math_fround($142 * $148);
 $150 = Math_fround($147 + $149);
 $151 = Math_fround(HEAPF32[$104>>2]);
 $152 = Math_fround($138 * $151);
 $153 = Math_fround(HEAPF32[$107>>2]);
 $154 = Math_fround($140 * $153);
 $155 = Math_fround($152 + $154);
 $156 = Math_fround(HEAPF32[$111>>2]);
 $157 = Math_fround($142 * $156);
 $158 = Math_fround($155 + $157);
 $159 = Math_fround(HEAPF32[$115>>2]);
 $160 = Math_fround($138 * $159);
 $161 = Math_fround(HEAPF32[$118>>2]);
 $162 = Math_fround($140 * $161);
 $163 = Math_fround($160 + $162);
 $164 = Math_fround(HEAPF32[$122>>2]);
 $165 = Math_fround($142 * $164);
 $166 = Math_fround($163 + $165);
 $167 = Math_fround($133 + $150);
 $168 = Math_fround($135 + $158);
 $169 = Math_fround($137 + $166);
 HEAPF32[$support0In1>>2] = $167;
 $170 = (($support0In1) + 4|0);
 HEAPF32[$170>>2] = $168;
 $171 = (($support0In1) + 8|0);
 HEAPF32[$171>>2] = $169;
 $172 = (($support0In1) + 12|0);
 HEAPF32[$172>>2] = Math_fround(0.0);
 $173 = Math_fround(HEAPF32[$16>>2]);
 $174 = Math_fround(HEAPF32[$18>>2]);
 $175 = Math_fround(HEAPF32[$20>>2]);
 $176 = Math_fround(HEAPF32[$support1>>2]);
 $177 = (($support1) + 4|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = (($support1) + 8|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = Math_fround(HEAPF32[$transform1To0>>2]);
 $182 = Math_fround($176 * $181);
 $183 = Math_fround(HEAPF32[$24>>2]);
 $184 = Math_fround($178 * $183);
 $185 = Math_fround($182 + $184);
 $186 = Math_fround(HEAPF32[$28>>2]);
 $187 = Math_fround($180 * $186);
 $188 = Math_fround($185 + $187);
 $189 = Math_fround(HEAPF32[$32>>2]);
 $190 = Math_fround($176 * $189);
 $191 = Math_fround(HEAPF32[$35>>2]);
 $192 = Math_fround($178 * $191);
 $193 = Math_fround($190 + $192);
 $194 = Math_fround(HEAPF32[$39>>2]);
 $195 = Math_fround($180 * $194);
 $196 = Math_fround($193 + $195);
 $197 = Math_fround(HEAPF32[$43>>2]);
 $198 = Math_fround($176 * $197);
 $199 = Math_fround(HEAPF32[$46>>2]);
 $200 = Math_fround($178 * $199);
 $201 = Math_fround($198 + $200);
 $202 = Math_fround(HEAPF32[$50>>2]);
 $203 = Math_fround($180 * $202);
 $204 = Math_fround($201 + $203);
 $205 = Math_fround($173 + $188);
 $206 = Math_fround($174 + $196);
 $207 = Math_fround($175 + $204);
 HEAPF32[$support1In0>>2] = $205;
 $208 = (($support1In0) + 4|0);
 HEAPF32[$208>>2] = $206;
 $209 = (($support1In0) + 8|0);
 HEAPF32[$209>>2] = $207;
 $210 = (($support1In0) + 12|0);
 HEAPF32[$210>>2] = Math_fround(0.0);
 HEAP32[$mSA0>>2] = 0;
 HEAP32[$mSA1>>2] = 0;
 __ZN5physx2Gu16buildPartialHullERKNS0_13PolygonalDataEPNS0_12SupportLocalERNS0_14SeparatingAxesERKNS_6shdfnd3aos5Vec3VESC_($polyData0,$map0,$mSA0,$support1In0,$dir0);
 __ZN5physx2Gu16buildPartialHullERKNS0_13PolygonalDataEPNS0_12SupportLocalERNS0_14SeparatingAxesERKNS_6shdfnd3aos5Vec3VESC_($polyData1,$map1,$mSA1,$support0In1,$dir1);
 $211 = HEAP32[$mSA0>>2]|0;
 $212 = HEAP32[$mSA1>>2]|0;
 $213 = ($211|0)==(0);
 L1: do {
  if ($213) {
   $$lcssa526 = $4;
  } else {
   $214 = ($212|0)==(0);
   $215 = (($n0) + 4|0);
   $216 = (($n0) + 8|0);
   $217 = (($n0) + 12|0);
   $218 = (($n1) + 4|0);
   $219 = (($n1) + 8|0);
   $220 = (($n1) + 12|0);
   $221 = (($1) + 4|0);
   $222 = (($1) + 8|0);
   $223 = (($1) + 12|0);
   $224 = (($0) + 4|0);
   $225 = (($0) + 8|0);
   $226 = (($0) + 12|0);
   $227 = (($3) + 4|0);
   $228 = (($3) + 8|0);
   $229 = (($3) + 12|0);
   $230 = (($2) + 4|0);
   $231 = (($2) + 8|0);
   $232 = (($2) + 12|0);
   $233 = (($min1) + 4|0);
   $234 = (($max1) + 4|0);
   if ($214) {
    $i$0528 = 0;
    while(1) {
     $383 = (($i$0528) + 1)|0;
     $384 = ($383>>>0)<($211>>>0);
     if ($384) {
      $i$0528 = $383;
     } else {
      $$lcssa526 = $4;
      break L1;
     }
    }
   } else {
    $385 = $4;$i$0528$us = 0;
   }
   L6: while(1) {
    $380 = ((($mSA0) + (($i$0528$us*12)|0)|0) + 4|0);
    $274 = Math_fround(HEAPF32[$380>>2]);
    $381 = ((($mSA0) + (($i$0528$us*12)|0)|0) + 8|0);
    $268 = Math_fround(HEAPF32[$381>>2]);
    $382 = ((($mSA0) + (($i$0528$us*12)|0)|0) + 12|0);
    $270 = Math_fround(HEAPF32[$382>>2]);
    $350 = $385;$j$0525$us = 0;
    while(1) {
     $237 = ((($mSA1) + (($j$0525$us*12)|0)|0) + 4|0);
     $238 = Math_fround(HEAPF32[$237>>2]);
     $239 = ((($mSA1) + (($j$0525$us*12)|0)|0) + 8|0);
     $240 = Math_fround(HEAPF32[$239>>2]);
     $241 = ((($mSA1) + (($j$0525$us*12)|0)|0) + 12|0);
     $242 = Math_fround(HEAPF32[$241>>2]);
     $243 = Math_fround(HEAPF32[$transform1To0>>2]);
     $244 = Math_fround($238 * $243);
     $245 = Math_fround(HEAPF32[$24>>2]);
     $246 = Math_fround($240 * $245);
     $247 = Math_fround($244 + $246);
     $248 = Math_fround(HEAPF32[$28>>2]);
     $249 = Math_fround($242 * $248);
     $250 = Math_fround($247 + $249);
     $251 = Math_fround(HEAPF32[$32>>2]);
     $252 = Math_fround($238 * $251);
     $253 = Math_fround(HEAPF32[$35>>2]);
     $254 = Math_fround($240 * $253);
     $255 = Math_fround($252 + $254);
     $256 = Math_fround(HEAPF32[$39>>2]);
     $257 = Math_fround($242 * $256);
     $258 = Math_fround($255 + $257);
     $259 = Math_fround(HEAPF32[$43>>2]);
     $260 = Math_fround($238 * $259);
     $261 = Math_fround(HEAPF32[$46>>2]);
     $262 = Math_fround($240 * $261);
     $263 = Math_fround($260 + $262);
     $264 = Math_fround(HEAPF32[$50>>2]);
     $265 = Math_fround($242 * $264);
     $266 = Math_fround($263 + $265);
     $267 = Math_fround($268 * $266);
     $269 = Math_fround($270 * $258);
     $271 = Math_fround($267 - $269);
     $272 = Math_fround($270 * $250);
     $273 = Math_fround($274 * $266);
     $275 = Math_fround($272 - $273);
     $276 = Math_fround($274 * $258);
     $277 = Math_fround($268 * $250);
     $278 = Math_fround($276 - $277);
     $279 = Math_fround($271 * $271);
     $280 = Math_fround($275 * $275);
     $281 = Math_fround($279 + $280);
     $282 = Math_fround($278 * $278);
     $283 = Math_fround($282 + $281);
     $284 = $283 < Math_fround(1.1920928955078125E-7);
     if ($284) {
      $386 = $350;
     } else {
      $285 = (Math_fround(Math_sqrt((Math_fround($283)))));
      $286 = Math_fround(Math_fround(1.0) / $285);
      $287 = Math_fround($271 * $286);
      $288 = Math_fround($275 * $286);
      $289 = Math_fround($278 * $286);
      HEAPF32[$n0>>2] = $287;
      HEAPF32[$215>>2] = $288;
      HEAPF32[$216>>2] = $289;
      HEAPF32[$217>>2] = Math_fround(0.0);
      $290 = Math_fround(HEAPF32[$transform0To1>>2]);
      $291 = Math_fround($287 * $290);
      $292 = Math_fround(HEAPF32[$96>>2]);
      $293 = Math_fround($288 * $292);
      $294 = Math_fround($291 + $293);
      $295 = Math_fround(HEAPF32[$100>>2]);
      $296 = Math_fround($289 * $295);
      $297 = Math_fround($294 + $296);
      $298 = Math_fround(HEAPF32[$104>>2]);
      $299 = Math_fround($287 * $298);
      $300 = Math_fround(HEAPF32[$107>>2]);
      $301 = Math_fround($288 * $300);
      $302 = Math_fround($299 + $301);
      $303 = Math_fround(HEAPF32[$111>>2]);
      $304 = Math_fround($289 * $303);
      $305 = Math_fround($302 + $304);
      $306 = Math_fround(HEAPF32[$115>>2]);
      $307 = Math_fround($287 * $306);
      $308 = Math_fround(HEAPF32[$118>>2]);
      $309 = Math_fround($288 * $308);
      $310 = Math_fround($307 + $309);
      $311 = Math_fround(HEAPF32[$122>>2]);
      $312 = Math_fround($289 * $311);
      $313 = Math_fround($310 + $312);
      HEAPF32[$n1>>2] = $297;
      HEAPF32[$218>>2] = $305;
      HEAPF32[$219>>2] = $313;
      HEAPF32[$220>>2] = Math_fround(0.0);
      $314 = $297 > Math_fround(0.0);
      $315 = $305 > Math_fround(0.0);
      $316 = $313 > Math_fround(0.0);
      HEAPF32[$1>>2] = $63;
      HEAPF32[$221>>2] = $65;
      HEAPF32[$222>>2] = $67;
      HEAPF32[$223>>2] = Math_fround(0.0);
      HEAPF32[$0>>2] = $68;
      HEAPF32[$224>>2] = $69;
      HEAPF32[$225>>2] = $70;
      HEAPF32[$226>>2] = Math_fround(0.0);
      $b$a$i97$us = $314 ? $1 : $0;
      $317 = Math_fround(HEAPF32[$b$a$i97$us>>2]);
      $a$pn3$i99$us = $315 ? $1 : $0;
      $$in1$i100$us = (($a$pn3$i99$us) + 4|0);
      $318 = Math_fround(HEAPF32[$$in1$i100$us>>2]);
      $b$a5$i101$us = $316 ? $1 : $0;
      $$in2$i102$us = (($b$a5$i101$us) + 8|0);
      $319 = Math_fround(HEAPF32[$$in2$i102$us>>2]);
      $320 = Math_fround($317 * $297);
      $321 = Math_fround($318 * $305);
      $322 = Math_fround($320 + $321);
      $323 = Math_fround($319 * $313);
      $324 = Math_fround($322 + $323);
      $325 = $324 > $61;
      $$$i86$us = $325 ? $324 : $61;
      $326 = Math_fround($57 * $287);
      $327 = Math_fround($58 * $288);
      $328 = Math_fround($326 + $327);
      $329 = Math_fround($59 * $289);
      $330 = Math_fround($328 + $329);
      $331 = Math_fround($330 - $$$i86$us);
      $332 = Math_fround($$$i86$us + $330);
      $333 = $287 > Math_fround(0.0);
      $334 = $288 > Math_fround(0.0);
      $335 = $289 > Math_fround(0.0);
      HEAPF32[$3>>2] = $74;
      HEAPF32[$227>>2] = $76;
      HEAPF32[$228>>2] = $78;
      HEAPF32[$229>>2] = Math_fround(0.0);
      HEAPF32[$2>>2] = $79;
      HEAPF32[$230>>2] = $80;
      HEAPF32[$231>>2] = $81;
      HEAPF32[$232>>2] = Math_fround(0.0);
      $b$a$i$us = $333 ? $3 : $2;
      $336 = Math_fround(HEAPF32[$b$a$i$us>>2]);
      $a$pn3$i$us = $334 ? $3 : $2;
      $$in1$i$us = (($a$pn3$i$us) + 4|0);
      $337 = Math_fround(HEAPF32[$$in1$i$us>>2]);
      $b$a5$i$us = $335 ? $3 : $2;
      $$in2$i$us = (($b$a5$i$us) + 8|0);
      $338 = Math_fround(HEAPF32[$$in2$i$us>>2]);
      $339 = Math_fround($336 * $287);
      $340 = Math_fround($337 * $288);
      $341 = Math_fround($339 + $340);
      $342 = Math_fround($338 * $289);
      $343 = Math_fround($341 + $342);
      $344 = $343 > $72;
      $$$i55$us = $344 ? $343 : $72;
      $345 = Math_fround(-$$$i55$us);
      $346 = $331 < $345;
      $$$i48$us = $346 ? $345 : $331;
      $347 = $$$i55$us > $332;
      $$$i$us = $347 ? $332 : $$$i55$us;
      $348 = Math_fround($$$i$us - $$$i48$us);
      $349 = $348 > $350;
      if ($349) {
       $386 = $350;
      } else {
       $351 = HEAP32[$map0>>2]|0;
       $352 = (($351) + 12|0);
       $353 = HEAP32[$352>>2]|0;
       FUNCTION_TABLE_viiii[$353 & 511]($map0,$n0,$min0,$max0);
       $354 = Math_fround(HEAPF32[$n0>>2]);
       $355 = Math_fround(HEAPF32[$215>>2]);
       $356 = Math_fround(HEAPF32[$216>>2]);
       $357 = Math_fround($17 * $354);
       $358 = Math_fround($19 * $355);
       $359 = Math_fround($357 + $358);
       $360 = Math_fround($21 * $356);
       $361 = Math_fround($359 + $360);
       $362 = HEAP32[$map1>>2]|0;
       $363 = (($362) + 12|0);
       $364 = HEAP32[$363>>2]|0;
       FUNCTION_TABLE_viiii[$364 & 511]($map1,$n1,$min1,$max1);
       $365 = Math_fround(HEAPF32[$min1>>2]);
       $366 = Math_fround($361 + $365);
       HEAPF32[$min1>>2] = $366;
       ;HEAP32[$233+0>>2]=HEAP32[$$sroa$1158+0>>2]|0;HEAP32[$233+4>>2]=HEAP32[$$sroa$1158+4>>2]|0;HEAP32[$233+8>>2]=HEAP32[$$sroa$1158+8>>2]|0;
       $367 = Math_fround(HEAPF32[$max1>>2]);
       $368 = Math_fround($361 + $367);
       HEAPF32[$max1>>2] = $368;
       ;HEAP32[$234+0>>2]=HEAP32[$$sroa$1156+0>>2]|0;HEAP32[$234+4>>2]=HEAP32[$$sroa$1156+4>>2]|0;HEAP32[$234+8>>2]=HEAP32[$$sroa$1156+8>>2]|0;
       $369 = Math_fround(HEAPF32[$max0>>2]);
       $370 = Math_fround(HEAPF32[$contactDist>>2]);
       $371 = Math_fround($369 + $370);
       $372 = $366 > $371;
       if ($372) {
        $$0 = 0;
        label = 14;
        break L6;
       }
       $373 = Math_fround($370 + $368);
       $374 = Math_fround(HEAPF32[$min0>>2]);
       $375 = $374 > $373;
       if ($375) {
        $$0 = 0;
        label = 14;
        break L6;
       }
       $376 = Math_fround($369 - $366);
       $377 = $350 > $376;
       if ($377) {
        ;HEAP32[$overlap$sroa$1+0>>2]=HEAP32[$tempOverlap$sroa$1+0>>2]|0;HEAP32[$overlap$sroa$1+4>>2]=HEAP32[$tempOverlap$sroa$1+4>>2]|0;HEAP32[$overlap$sroa$1+8>>2]=HEAP32[$tempOverlap$sroa$1+8>>2]|0;
        ;HEAP32[$edgeNormalIn0+0>>2]=HEAP32[$n0+0>>2]|0;HEAP32[$edgeNormalIn0+4>>2]=HEAP32[$n0+4>>2]|0;HEAP32[$edgeNormalIn0+8>>2]=HEAP32[$n0+8>>2]|0;HEAP32[$edgeNormalIn0+12>>2]=HEAP32[$n0+12>>2]|0;
        HEAP32[$status>>2] = 2;
        $386 = $376;
       } else {
        $386 = $350;
       }
      }
     }
     $378 = (($j$0525$us) + 1)|0;
     $379 = ($378>>>0)<($212>>>0);
     if ($379) {
      $350 = $386;$j$0525$us = $378;
     } else {
      break;
     }
    }
    $235 = (($i$0528$us) + 1)|0;
    $236 = ($235>>>0)<($211>>>0);
    if ($236) {
     $385 = $386;$i$0528$us = $235;
    } else {
     $$lcssa526 = $386;
     break L1;
    }
   }
   if ((label|0) == 14) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAPF32[$minOverlap>>2] = $$lcssa526;
 ;HEAP32[$5+0>>2]=HEAP32[$overlap$sroa$1+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$overlap$sroa$1+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$overlap$sroa$1+8>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData,$map,$normal) {
 $polyData = $polyData|0;
 $map = $map|0;
 $normal = $normal|0;
 var $$ = 0, $$lcssa = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0;
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0);
 var $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = 0, $151 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0;
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $closestEdge$0272 = 0, $closestEdge$1 = 0, $closestFaceIndex$0$lcssa = 0, $closestFaceIndex$0274 = 0, $closestFaceIndex$1 = 0, $closestFaceIndex$2 = 0;
 var $exitcond = 0, $i$0273 = 0, $i2$0271 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($map) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$normal>>2]);
 $3 = (($normal) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($normal) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$1>>2]);
 $8 = Math_fround($2 * $7);
 $9 = (($1) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($4 * $10);
 $12 = Math_fround($8 + $11);
 $13 = (($1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($6 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($1) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($2 * $18);
 $20 = (($1) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($4 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($1) + 24|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($6 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($1) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($2 * $29);
 $31 = (($1) + 36|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($4 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($1) + 40|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($6 * $36);
 $38 = Math_fround($34 + $37);
 $39 = Math_fround(-$16);
 $40 = Math_fround(-$27);
 $41 = Math_fround(-$38);
 $42 = (($polyData) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($43) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($43) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($16 * $44);
 $50 = Math_fround($27 * $46);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($38 * $48);
 $53 = Math_fround($51 + $52);
 $54 = (($polyData) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55>>>0)>(1);
 if ($56) {
  $69 = $53;$closestFaceIndex$0274 = 0;$i$0273 = 1;
  while(1) {
   $57 = (($43) + (($i$0273*20)|0)|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = ((($43) + (($i$0273*20)|0)|0) + 4|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = ((($43) + (($i$0273*20)|0)|0) + 8|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = Math_fround($16 * $58);
   $64 = Math_fround($27 * $60);
   $65 = Math_fround($63 + $64);
   $66 = Math_fround($38 * $62);
   $67 = Math_fround($65 + $66);
   $68 = $69 > $67;
   $70 = $68 ? $67 : $69;
   $closestFaceIndex$1 = $68 ? $i$0273 : $closestFaceIndex$0274;
   $71 = (($i$0273) + 1)|0;
   $72 = ($71>>>0)<($55>>>0);
   if ($72) {
    $69 = $70;$closestFaceIndex$0274 = $closestFaceIndex$1;$i$0273 = $71;
   } else {
    $$lcssa = $70;$closestFaceIndex$0$lcssa = $closestFaceIndex$1;
    break;
   }
  }
 } else {
  $$lcssa = $53;$closestFaceIndex$0$lcssa = 0;
 }
 $73 = (($polyData) + 20|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($polyData) + 36|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($74|0)==(0);
 if ($77) {
  $closestFaceIndex$2 = $closestFaceIndex$0$lcssa;
  STACKTOP = sp;return ($closestFaceIndex$2|0);
 }
 $78 = Math_fround($$lcssa * $$lcssa);
 $115 = $78;$closestEdge$0272 = -1;$i2$0271 = 0;
 while(1) {
  $79 = $i2$0271 << 1;
  $80 = (($76) + ($79)|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = $79 | 1;
  $83 = (($76) + ($82)|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = $81&255;
  $86 = (($43) + (($85*20)|0)|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = ((($43) + (($85*20)|0)|0) + 4|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = ((($43) + (($85*20)|0)|0) + 8|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = $84&255;
  $93 = (($43) + (($92*20)|0)|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = ((($43) + (($92*20)|0)|0) + 4|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = ((($43) + (($92*20)|0)|0) + 8|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = Math_fround($87 + $94);
  $100 = Math_fround($89 + $96);
  $101 = Math_fround($91 + $98);
  $102 = Math_fround($99 * $99);
  $103 = Math_fround($100 * $100);
  $104 = Math_fround($102 + $103);
  $105 = Math_fround($101 * $101);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($99 * $39);
  $108 = Math_fround($100 * $40);
  $109 = Math_fround($107 + $108);
  $110 = Math_fround($101 * $41);
  $111 = Math_fround($109 + $110);
  $112 = Math_fround($111 * $111);
  $113 = !($111 >= Math_fround(0.0));
  if ($113) {
   $151 = $115;$closestEdge$1 = $closestEdge$0272;
  } else {
   $114 = Math_fround($115 * $106);
   $116 = $112 > $114;
   if ($116) {
    $117 = Math_fround($112 / $106);
    $151 = $117;$closestEdge$1 = $i2$0271;
   } else {
    $151 = $115;$closestEdge$1 = $closestEdge$0272;
   }
  }
  $118 = (($i2$0271) + 1)|0;
  $exitcond = ($118|0)==($74|0);
  if ($exitcond) {
   break;
  } else {
   $115 = $151;$closestEdge$0272 = $closestEdge$1;$i2$0271 = $118;
  }
 }
 $119 = ($closestEdge$1|0)==(-1);
 if ($119) {
  $closestFaceIndex$2 = $closestFaceIndex$0$lcssa;
  STACKTOP = sp;return ($closestFaceIndex$2|0);
 }
 $120 = $closestEdge$1 << 1;
 $121 = (($76) + ($120)|0);
 $122 = HEAP8[$121>>0]|0;
 $123 = $122&255;
 $124 = $120 | 1;
 $125 = (($76) + ($124)|0);
 $126 = HEAP8[$125>>0]|0;
 $127 = $126&255;
 $128 = (($43) + (($123*20)|0)|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = ((($43) + (($123*20)|0)|0) + 4|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = ((($43) + (($123*20)|0)|0) + 8|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = (($43) + (($127*20)|0)|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = ((($43) + (($127*20)|0)|0) + 4|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = ((($43) + (($127*20)|0)|0) + 8|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($129 * $39);
 $141 = Math_fround($131 * $40);
 $142 = Math_fround($140 + $141);
 $143 = Math_fround($133 * $41);
 $144 = Math_fround($142 + $143);
 $145 = Math_fround($135 * $39);
 $146 = Math_fround($137 * $40);
 $147 = Math_fround($145 + $146);
 $148 = Math_fround($139 * $41);
 $149 = Math_fround($147 + $148);
 $150 = $144 > $149;
 $$ = $150 ? $123 : $127;
 $closestFaceIndex$2 = $$;
 STACKTOP = sp;return ($closestFaceIndex$2|0);
}
function __ZN5physx2Gu10computeMTDERNS0_13PolygonalDataES2_PNS0_12SupportLocalES4_RNS_6shdfnd3aos6FloatVERNS6_5Vec3VE($polyData0,$polyData1,$map0,$map1,$penDepth,$normal) {
 $polyData0 = $polyData0|0;
 $polyData1 = $polyData1|0;
 $map0 = $map0|0;
 $map1 = $map1|0;
 $penDepth = $penDepth|0;
 $normal = $normal|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0;
 var $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0;
 var $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = 0;
 var $278 = Math_fround(0), $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = Math_fround(0), $330 = Math_fround(0);
 var $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = 0, $377 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $contactDist = 0;
 var $feature0 = 0, $feature1 = 0, $minNormal = 0, $minOverlap = 0, $status = 0, $transform0To1V = 0, $transform1To0V = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $transform1To0V = sp + 112|0;
 $transform0To1V = sp;
 $status = sp + 184|0;
 $minOverlap = sp + 80|0;
 $minNormal = sp + 96|0;
 $contactDist = sp + 64|0;
 $feature0 = sp + 176|0;
 $feature1 = sp + 180|0;
 $0 = (($map0) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($map1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$1>>2]);
 $5 = (($1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($1) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(-$4);
 $12 = Math_fround(-$6);
 $13 = Math_fround(-$8);
 $14 = (($3) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($3) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($3) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($1) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($1) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($1) + 24|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($15 - $21);
 $27 = Math_fround($17 - $23);
 $28 = Math_fround($19 - $25);
 $29 = Math_fround($10 * $10);
 $30 = Math_fround($29 + Math_fround(-0.5));
 $31 = Math_fround($30 * $26);
 $32 = Math_fround($30 * $27);
 $33 = Math_fround($30 * $28);
 $34 = Math_fround($28 * $12);
 $35 = Math_fround($27 * $13);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($26 * $13);
 $38 = Math_fround($28 * $11);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($27 * $11);
 $41 = Math_fround($26 * $12);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($10 * $36);
 $44 = Math_fround($10 * $39);
 $45 = Math_fround($10 * $42);
 $46 = Math_fround($31 + $43);
 $47 = Math_fround($32 + $44);
 $48 = Math_fround($33 + $45);
 $49 = Math_fround($26 * $11);
 $50 = Math_fround($27 * $12);
 $51 = Math_fround($49 + $50);
 $52 = Math_fround($28 * $13);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($53 * $11);
 $55 = Math_fround($53 * $12);
 $56 = Math_fround($53 * $13);
 $57 = Math_fround($54 + $46);
 $58 = Math_fround($55 + $47);
 $59 = Math_fround($48 + $56);
 $60 = Math_fround($57 * Math_fround(2.0));
 $61 = Math_fround($58 * Math_fround(2.0));
 $62 = Math_fround($59 * Math_fround(2.0));
 $63 = Math_fround(HEAPF32[$3>>2]);
 $64 = (($3) + 4|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($3) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($3) + 12|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($10 * $69);
 $71 = Math_fround($63 * $11);
 $72 = Math_fround($65 * $12);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($67 * $13);
 $75 = Math_fround($73 + $74);
 $76 = Math_fround($70 - $75);
 $77 = Math_fround($69 * $11);
 $78 = Math_fround($69 * $12);
 $79 = Math_fround($69 * $13);
 $80 = Math_fround($10 * $63);
 $81 = Math_fround($10 * $65);
 $82 = Math_fround($10 * $67);
 $83 = Math_fround($67 * $12);
 $84 = Math_fround($65 * $13);
 $85 = Math_fround($83 - $84);
 $86 = Math_fround($63 * $13);
 $87 = Math_fround($67 * $11);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($65 * $11);
 $90 = Math_fround($63 * $12);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($80 + $77);
 $93 = Math_fround($81 + $78);
 $94 = Math_fround($82 + $79);
 $95 = Math_fround($85 + $92);
 $96 = Math_fround($88 + $93);
 $97 = Math_fround($91 + $94);
 $98 = (($transform1To0V) + 48|0);
 HEAPF32[$98>>2] = $60;
 $99 = (($transform1To0V) + 52|0);
 HEAPF32[$99>>2] = $61;
 $100 = (($transform1To0V) + 56|0);
 HEAPF32[$100>>2] = $62;
 $101 = (($transform1To0V) + 60|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = Math_fround($95 + $95);
 $103 = Math_fround($96 + $96);
 $104 = Math_fround($97 + $97);
 $105 = Math_fround($95 * $102);
 $106 = Math_fround($96 * $103);
 $107 = Math_fround($97 * $104);
 $108 = Math_fround($96 * $102);
 $109 = Math_fround($97 * $102);
 $110 = Math_fround($76 * $102);
 $111 = Math_fround($97 * $103);
 $112 = Math_fround($76 * $103);
 $113 = Math_fround($76 * $104);
 $114 = Math_fround(Math_fround(1.0) - $105);
 $115 = Math_fround(Math_fround(1.0) - $106);
 $116 = Math_fround($115 - $107);
 $117 = Math_fround($108 + $113);
 $118 = Math_fround($109 - $112);
 $119 = Math_fround($108 - $113);
 $120 = Math_fround($114 - $107);
 $121 = Math_fround($111 + $110);
 $122 = Math_fround($109 + $112);
 $123 = Math_fround($111 - $110);
 $124 = Math_fround($114 - $106);
 HEAPF32[$transform1To0V>>2] = $116;
 $125 = (($transform1To0V) + 4|0);
 HEAPF32[$125>>2] = $117;
 $126 = (($transform1To0V) + 8|0);
 HEAPF32[$126>>2] = $118;
 $127 = (($transform1To0V) + 12|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = (($transform1To0V) + 16|0);
 HEAPF32[$128>>2] = $119;
 $129 = (($transform1To0V) + 20|0);
 HEAPF32[$129>>2] = $120;
 $130 = (($transform1To0V) + 24|0);
 HEAPF32[$130>>2] = $121;
 $131 = (($transform1To0V) + 28|0);
 HEAPF32[$131>>2] = Math_fround(0.0);
 $132 = (($transform1To0V) + 32|0);
 HEAPF32[$132>>2] = $122;
 $133 = (($transform1To0V) + 36|0);
 HEAPF32[$133>>2] = $123;
 $134 = (($transform1To0V) + 40|0);
 HEAPF32[$134>>2] = $124;
 $135 = (($transform1To0V) + 44|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = HEAP32[$2>>2]|0;
 $137 = HEAP32[$0>>2]|0;
 $138 = Math_fround(HEAPF32[$136>>2]);
 $139 = (($136) + 4|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($136) + 8|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($136) + 12|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = Math_fround(-$138);
 $146 = Math_fround(-$140);
 $147 = Math_fround(-$142);
 $148 = (($137) + 16|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($137) + 20|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = (($137) + 24|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = (($136) + 16|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = (($136) + 20|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = (($136) + 24|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = Math_fround($149 - $155);
 $161 = Math_fround($151 - $157);
 $162 = Math_fround($153 - $159);
 $163 = Math_fround($144 * $144);
 $164 = Math_fround($163 + Math_fround(-0.5));
 $165 = Math_fround($164 * $160);
 $166 = Math_fround($164 * $161);
 $167 = Math_fround($164 * $162);
 $168 = Math_fround($162 * $146);
 $169 = Math_fround($161 * $147);
 $170 = Math_fround($168 - $169);
 $171 = Math_fround($160 * $147);
 $172 = Math_fround($162 * $145);
 $173 = Math_fround($171 - $172);
 $174 = Math_fround($161 * $145);
 $175 = Math_fround($160 * $146);
 $176 = Math_fround($174 - $175);
 $177 = Math_fround($144 * $170);
 $178 = Math_fround($144 * $173);
 $179 = Math_fround($144 * $176);
 $180 = Math_fround($165 + $177);
 $181 = Math_fround($166 + $178);
 $182 = Math_fround($167 + $179);
 $183 = Math_fround($160 * $145);
 $184 = Math_fround($161 * $146);
 $185 = Math_fround($183 + $184);
 $186 = Math_fround($162 * $147);
 $187 = Math_fround($185 + $186);
 $188 = Math_fround($187 * $145);
 $189 = Math_fround($187 * $146);
 $190 = Math_fround($187 * $147);
 $191 = Math_fround($188 + $180);
 $192 = Math_fround($189 + $181);
 $193 = Math_fround($182 + $190);
 $194 = Math_fround($191 * Math_fround(2.0));
 $195 = Math_fround($192 * Math_fround(2.0));
 $196 = Math_fround($193 * Math_fround(2.0));
 $197 = Math_fround(HEAPF32[$137>>2]);
 $198 = (($137) + 4|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($137) + 8|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = (($137) + 12|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = Math_fround($144 * $203);
 $205 = Math_fround($197 * $145);
 $206 = Math_fround($199 * $146);
 $207 = Math_fround($205 + $206);
 $208 = Math_fround($201 * $147);
 $209 = Math_fround($207 + $208);
 $210 = Math_fround($204 - $209);
 $211 = Math_fround($203 * $145);
 $212 = Math_fround($203 * $146);
 $213 = Math_fround($203 * $147);
 $214 = Math_fround($144 * $197);
 $215 = Math_fround($144 * $199);
 $216 = Math_fround($144 * $201);
 $217 = Math_fround($201 * $146);
 $218 = Math_fround($199 * $147);
 $219 = Math_fround($217 - $218);
 $220 = Math_fround($197 * $147);
 $221 = Math_fround($201 * $145);
 $222 = Math_fround($220 - $221);
 $223 = Math_fround($199 * $145);
 $224 = Math_fround($197 * $146);
 $225 = Math_fround($223 - $224);
 $226 = Math_fround($214 + $211);
 $227 = Math_fround($215 + $212);
 $228 = Math_fround($216 + $213);
 $229 = Math_fround($219 + $226);
 $230 = Math_fround($222 + $227);
 $231 = Math_fround($225 + $228);
 $232 = (($transform0To1V) + 48|0);
 HEAPF32[$232>>2] = $194;
 $233 = (($transform0To1V) + 52|0);
 HEAPF32[$233>>2] = $195;
 $234 = (($transform0To1V) + 56|0);
 HEAPF32[$234>>2] = $196;
 $235 = (($transform0To1V) + 60|0);
 HEAPF32[$235>>2] = Math_fround(0.0);
 $236 = Math_fround($229 + $229);
 $237 = Math_fround($230 + $230);
 $238 = Math_fround($231 + $231);
 $239 = Math_fround($229 * $236);
 $240 = Math_fround($230 * $237);
 $241 = Math_fround($231 * $238);
 $242 = Math_fround($230 * $236);
 $243 = Math_fround($231 * $236);
 $244 = Math_fround($210 * $236);
 $245 = Math_fround($231 * $237);
 $246 = Math_fround($210 * $237);
 $247 = Math_fround($210 * $238);
 $248 = Math_fround(Math_fround(1.0) - $239);
 $249 = Math_fround(Math_fround(1.0) - $240);
 $250 = Math_fround($249 - $241);
 $251 = Math_fround($242 + $247);
 $252 = Math_fround($243 - $246);
 $253 = Math_fround($242 - $247);
 $254 = Math_fround($248 - $241);
 $255 = Math_fround($245 + $244);
 $256 = Math_fround($243 + $246);
 $257 = Math_fround($245 - $244);
 $258 = Math_fround($248 - $240);
 HEAPF32[$transform0To1V>>2] = $250;
 $259 = (($transform0To1V) + 4|0);
 HEAPF32[$259>>2] = $251;
 $260 = (($transform0To1V) + 8|0);
 HEAPF32[$260>>2] = $252;
 $261 = (($transform0To1V) + 12|0);
 HEAPF32[$261>>2] = Math_fround(0.0);
 $262 = (($transform0To1V) + 16|0);
 HEAPF32[$262>>2] = $253;
 $263 = (($transform0To1V) + 20|0);
 HEAPF32[$263>>2] = $254;
 $264 = (($transform0To1V) + 24|0);
 HEAPF32[$264>>2] = $255;
 $265 = (($transform0To1V) + 28|0);
 HEAPF32[$265>>2] = Math_fround(0.0);
 $266 = (($transform0To1V) + 32|0);
 HEAPF32[$266>>2] = $256;
 $267 = (($transform0To1V) + 36|0);
 HEAPF32[$267>>2] = $257;
 $268 = (($transform0To1V) + 40|0);
 HEAPF32[$268>>2] = $258;
 $269 = (($transform0To1V) + 44|0);
 HEAPF32[$269>>2] = Math_fround(0.0);
 HEAP32[$status>>2] = 0;
 HEAPF32[$minOverlap>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$minNormal+0>>2]=0|0;HEAP32[$minNormal+4>>2]=0|0;HEAP32[$minNormal+8>>2]=0|0;HEAP32[$minNormal+12>>2]=0|0;
 HEAPF32[$contactDist>>2] = Math_fround(0.0);
 $270 = (__ZN5physx2GuL14testFaceNormalERKNS0_13PolygonalDataES3_PNS0_12SupportLocalES5_RKNS_6shdfnd3aos15PsMatTransformVESA_RKNS7_6FloatVERSB_RjRNS7_5Vec3VENS0_13FeatureStatusERSI_($polyData0,$polyData1,$map0,$map1,$transform0To1V,$transform1To0V,$contactDist,$minOverlap,$feature0,$minNormal,0,$status)|0);
 if (!($270)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $271 = (__ZN5physx2GuL14testFaceNormalERKNS0_13PolygonalDataES3_PNS0_12SupportLocalES5_RKNS_6shdfnd3aos15PsMatTransformVESA_RKNS7_6FloatVERSB_RjRNS7_5Vec3VENS0_13FeatureStatusERSI_($polyData1,$polyData0,$map1,$map0,$transform1To0V,$transform0To1V,$contactDist,$minOverlap,$feature1,$minNormal,1,$status)|0);
 if (!($271)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $272 = (__ZN5physx2GuL14testEdgeNormalERKNS0_13PolygonalDataES3_PNS0_12SupportLocalES5_RKNS_6shdfnd3aos15PsMatTransformVESA_RKNS7_6FloatVERSB_RNS7_5Vec3VENS0_13FeatureStatusERSH_($polyData0,$polyData1,$map0,$map1,$transform0To1V,$transform1To0V,$contactDist,$minOverlap,$minNormal,$status)|0);
 if (!($272)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$penDepth+0>>2]=HEAP32[$minOverlap+0>>2]|0;HEAP32[$penDepth+4>>2]=HEAP32[$minOverlap+4>>2]|0;HEAP32[$penDepth+8>>2]=HEAP32[$minOverlap+8>>2]|0;HEAP32[$penDepth+12>>2]=HEAP32[$minOverlap+12>>2]|0;
 $273 = HEAP32[$status>>2]|0;
 $274 = ($273|0)==(1);
 if ($274) {
  $275 = HEAP32[$2>>2]|0;
  $276 = Math_fround(HEAPF32[$275>>2]);
  $277 = (($275) + 4|0);
  $278 = Math_fround(HEAPF32[$277>>2]);
  $279 = (($275) + 8|0);
  $280 = Math_fround(HEAPF32[$279>>2]);
  $281 = (($275) + 12|0);
  $282 = Math_fround(HEAPF32[$281>>2]);
  $283 = Math_fround(HEAPF32[$minNormal>>2]);
  $284 = (($minNormal) + 4|0);
  $285 = Math_fround(HEAPF32[$284>>2]);
  $286 = (($minNormal) + 8|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $288 = Math_fround($282 * $282);
  $289 = Math_fround($288 + Math_fround(-0.5));
  $290 = Math_fround($283 * $289);
  $291 = Math_fround($289 * $285);
  $292 = Math_fround($289 * $287);
  $293 = Math_fround($278 * $287);
  $294 = Math_fround($280 * $285);
  $295 = Math_fround($293 - $294);
  $296 = Math_fround($280 * $283);
  $297 = Math_fround($276 * $287);
  $298 = Math_fround($296 - $297);
  $299 = Math_fround($276 * $285);
  $300 = Math_fround($278 * $283);
  $301 = Math_fround($299 - $300);
  $302 = Math_fround($282 * $295);
  $303 = Math_fround($282 * $298);
  $304 = Math_fround($282 * $301);
  $305 = Math_fround($290 + $302);
  $306 = Math_fround($291 + $303);
  $307 = Math_fround($292 + $304);
  $308 = Math_fround($276 * $283);
  $309 = Math_fround($278 * $285);
  $310 = Math_fround($308 + $309);
  $311 = Math_fround($280 * $287);
  $312 = Math_fround($310 + $311);
  $313 = Math_fround($276 * $312);
  $314 = Math_fround($278 * $312);
  $315 = Math_fround($280 * $312);
  $316 = Math_fround($313 + $305);
  $317 = Math_fround($314 + $306);
  $318 = Math_fround($307 + $315);
  $319 = Math_fround($316 * Math_fround(2.0));
  $320 = Math_fround($317 * Math_fround(2.0));
  $321 = Math_fround($318 * Math_fround(2.0));
  HEAPF32[$normal>>2] = $319;
  $322 = (($normal) + 4|0);
  HEAPF32[$322>>2] = $320;
  $323 = (($normal) + 8|0);
  HEAPF32[$323>>2] = $321;
  $324 = (($normal) + 12|0);
  HEAPF32[$324>>2] = Math_fround(0.0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $325 = HEAP32[$0>>2]|0;
  $326 = Math_fround(HEAPF32[$325>>2]);
  $327 = (($325) + 4|0);
  $328 = Math_fround(HEAPF32[$327>>2]);
  $329 = (($325) + 8|0);
  $330 = Math_fround(HEAPF32[$329>>2]);
  $331 = (($325) + 12|0);
  $332 = Math_fround(HEAPF32[$331>>2]);
  $333 = Math_fround(HEAPF32[$minNormal>>2]);
  $334 = (($minNormal) + 4|0);
  $335 = Math_fround(HEAPF32[$334>>2]);
  $336 = (($minNormal) + 8|0);
  $337 = Math_fround(HEAPF32[$336>>2]);
  $338 = Math_fround($332 * $332);
  $339 = Math_fround($338 + Math_fround(-0.5));
  $340 = Math_fround($333 * $339);
  $341 = Math_fround($339 * $335);
  $342 = Math_fround($339 * $337);
  $343 = Math_fround($328 * $337);
  $344 = Math_fround($330 * $335);
  $345 = Math_fround($343 - $344);
  $346 = Math_fround($330 * $333);
  $347 = Math_fround($326 * $337);
  $348 = Math_fround($346 - $347);
  $349 = Math_fround($326 * $335);
  $350 = Math_fround($328 * $333);
  $351 = Math_fround($349 - $350);
  $352 = Math_fround($332 * $345);
  $353 = Math_fround($332 * $348);
  $354 = Math_fround($332 * $351);
  $355 = Math_fround($340 + $352);
  $356 = Math_fround($341 + $353);
  $357 = Math_fround($342 + $354);
  $358 = Math_fround($326 * $333);
  $359 = Math_fround($328 * $335);
  $360 = Math_fround($358 + $359);
  $361 = Math_fround($330 * $337);
  $362 = Math_fround($360 + $361);
  $363 = Math_fround($326 * $362);
  $364 = Math_fround($328 * $362);
  $365 = Math_fround($330 * $362);
  $366 = Math_fround($363 + $355);
  $367 = Math_fround($364 + $356);
  $368 = Math_fround($357 + $365);
  $369 = Math_fround($366 * Math_fround(2.0));
  $370 = Math_fround($367 * Math_fround(2.0));
  $371 = Math_fround($368 * Math_fround(2.0));
  $372 = Math_fround(-$369);
  $373 = Math_fround(-$370);
  $374 = Math_fround(-$371);
  HEAPF32[$normal>>2] = $372;
  $375 = (($normal) + 4|0);
  HEAPF32[$375>>2] = $373;
  $376 = (($normal) + 8|0);
  HEAPF32[$376>>2] = $374;
  $377 = (($normal) + 12|0);
  HEAPF32[$377>>2] = Math_fround(0.0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu31generatedCapsuleBoxFaceContactsERKNS0_8CapsuleVERNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNSC_6FloatVERKNSC_5Vec3VE($capsule,$polyData,$referencePolygon,$map,$aToB,$manifoldContacts,$numContacts,$contactDist,$normal) {
 $capsule = $capsule|0;
 $polyData = $polyData|0;
 $referencePolygon = $referencePolygon|0;
 $map = $map|0;
 $aToB = $aToB|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $normal = $normal|0;
 var $$$i = Math_fround(0), $$$i475$lcssa = Math_fround(0), $$$i475491 = Math_fround(0), $$$i54 = Math_fround(0), $$$i54477$lcssa = Math_fround(0), $$$i54477489 = Math_fround(0), $$demorgan$i = 0, $$demorgan$i21 = 0, $$lcssa = Math_fround(0), $$lcssa487 = Math_fround(0), $$phi$trans$insert$i = 0, $$phi$trans$insert$i25 = 0, $$pre$i = Math_fround(0), $$pre$i26 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0;
 var $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0;
 var $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0;
 var $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0);
 var $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0);
 var $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0);
 var $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0);
 var $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0);
 var $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0);
 var $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0);
 var $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0;
 var $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0;
 var $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0;
 var $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0);
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0);
 var $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = 0;
 var $41 = Math_fround(0), $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0);
 var $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = 0, $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = 0, $445 = Math_fround(0);
 var $446 = Math_fround(0), $447 = Math_fround(0), $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0;
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0);
 var $brmerge = 0, $i$0308$i = 0, $i$0308$i30 = 0, $i$0492 = 0, $intersectionPoints$0310$i = 0, $intersectionPoints$0310$i28 = 0, $intersectionPoints$1$i = 0, $intersectionPoints$1$i32 = 0, $j$0309$i = 0, $j$0309$i$phi = 0, $j$0309$i29 = 0, $j$0309$i29$phi = 0, $not$$i = 0, $not$$i20 = 0, $not$304$i = 0, $not$304$i22 = 0, $or$cond = 0, $or$cond486 = 0, $planeNormal = 0, $rot = 0;
 var $tmp$i = 0, $tmp$i31 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $planeNormal = sp + 48|0;
 $rot = sp;
 $0 = (($capsule) + 128|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$contactDist>>2]);
 $3 = Math_fround($1 + $2);
 $4 = (($map) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_fround(HEAPF32[$referencePolygon>>2]);
 $7 = (($referencePolygon) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($referencePolygon) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$5>>2]);
 $12 = Math_fround($6 * $11);
 $13 = (($5) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($8 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($5) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($10 * $18);
 $20 = Math_fround($16 + $19);
 $21 = (($5) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($6 * $22);
 $24 = (($5) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($8 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($5) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($10 * $29);
 $31 = Math_fround($27 + $30);
 $32 = (($5) + 32|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($6 * $33);
 $35 = (($5) + 36|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($8 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($5) + 40|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($10 * $40);
 $42 = Math_fround($38 + $41);
 $43 = Math_fround($20 * $20);
 $44 = Math_fround($31 * $31);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($42 * $42);
 $47 = Math_fround($45 + $46);
 $48 = (Math_fround(Math_sqrt((Math_fround($47)))));
 $49 = Math_fround(Math_fround(1.0) / $48);
 $50 = Math_fround($20 * $49);
 $51 = Math_fround($31 * $49);
 $52 = Math_fround($42 * $49);
 HEAPF32[$planeNormal>>2] = $50;
 $53 = (($planeNormal) + 4|0);
 HEAPF32[$53>>2] = $51;
 $54 = (($planeNormal) + 8|0);
 HEAPF32[$54>>2] = $52;
 $55 = (($planeNormal) + 12|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($polyData) + 32|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($referencePolygon) + 16|0);
 $59 = HEAP16[$58>>1]|0;
 $60 = $59&65535;
 $61 = (($57) + ($60)|0);
 $62 = (($map) + 36|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP8[$61>>0]|0;
 $65 = $64&255;
 $66 = (($polyData) + 28|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + (($65*12)|0)|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = ((($67) + (($65*12)|0)|0) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = ((($67) + (($65*12)|0)|0) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround(HEAPF32[$63>>2]);
 $75 = Math_fround($69 * $74);
 $76 = (($63) + 16|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($71 * $77);
 $79 = Math_fround($75 + $78);
 $80 = (($63) + 32|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($73 * $81);
 $83 = Math_fround($79 + $82);
 $84 = (($63) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($69 * $85);
 $87 = (($63) + 20|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($71 * $88);
 $90 = Math_fround($86 + $89);
 $91 = (($63) + 36|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($73 * $92);
 $94 = Math_fround($90 + $93);
 $95 = (($63) + 8|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($69 * $96);
 $98 = (($63) + 24|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($71 * $99);
 $101 = Math_fround($97 + $100);
 $102 = (($63) + 40|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($73 * $103);
 $105 = Math_fround($101 + $104);
 $106 = (($capsule) + 96|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($capsule) + 100|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($capsule) + 104|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($107 - $83);
 $113 = Math_fround($109 - $94);
 $114 = Math_fround($111 - $105);
 $115 = Math_fround($50 * $112);
 $116 = Math_fround($51 * $113);
 $117 = Math_fround($115 + $116);
 $118 = Math_fround($52 * $114);
 $119 = Math_fround($117 + $118);
 $120 = (($capsule) + 112|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($capsule) + 116|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($capsule) + 120|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = Math_fround($121 - $83);
 $127 = Math_fround($123 - $94);
 $128 = Math_fround($125 - $105);
 $129 = Math_fround($50 * $126);
 $130 = Math_fround($51 * $127);
 $131 = Math_fround($129 + $130);
 $132 = Math_fround($52 * $128);
 $133 = Math_fround($131 + $132);
 $134 = Math_fround(HEAPF32[$normal>>2]);
 $135 = (($normal) + 4|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($normal) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($50 * $134);
 $140 = Math_fround($51 * $136);
 $141 = Math_fround($139 + $140);
 $142 = Math_fround($52 * $138);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround(Math_fround(1.0) / $143);
 $145 = Math_fround($119 * $144);
 $146 = Math_fround($133 * $144);
 $147 = $3 >= $145;
 $148 = $3 >= $146;
 $brmerge = $147 | $148;
 if (!($brmerge)) {
  STACKTOP = sp;return;
 }
 __ZN5physx2Gu27findRotationMatrixFromZAxisERKNS_6shdfnd3aos5Vec3VE($rot,$planeNormal);
 $149 = (($referencePolygon) + 18|0);
 $150 = HEAP8[$149>>0]|0;
 $151 = $150&255;
 $152 = $151 << 4;
 $153 = (($152) + 16)|0;
 $154 = STACKTOP; STACKTOP = STACKTOP + ((((1*$153)|0)+15)&-16)|0;;
 $155 = $154;
 $156 = (($155) + 15)|0;
 $157 = $156 & -16;
 $158 = $157;
 $159 = HEAP32[$map>>2]|0;
 $160 = (($159) + 16|0);
 $161 = HEAP32[$160>>2]|0;
 $162 = HEAP32[$66>>2]|0;
 FUNCTION_TABLE_viiiii[$161 & 255]($map,$61,$151,$162,$158);
 $163 = HEAP8[$149>>0]|0;
 $164 = ($163<<24>>24)==(0);
 if ($164) {
  $$$i475$lcssa = Math_fround(-3.40282346638528859812E+38);$$$i54477$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa487 = Math_fround(-3.40282346638528859812E+38);$250 = 0;
 } else {
  $165 = (($rot) + 16|0);
  $166 = (($rot) + 32|0);
  $167 = (($rot) + 4|0);
  $168 = (($rot) + 20|0);
  $169 = (($rot) + 36|0);
  $170 = (($rot) + 8|0);
  $171 = (($rot) + 24|0);
  $172 = (($rot) + 40|0);
  $$$i475491 = Math_fround(-3.40282346638528859812E+38);$$$i54477489 = Math_fround(3.40282346638528859812E+38);$206 = Math_fround(3.40282346638528859812E+38);$210 = Math_fround(-3.40282346638528859812E+38);$i$0492 = 0;
  while(1) {
   $173 = (($158) + ($i$0492<<4)|0);
   $174 = Math_fround(HEAPF32[$173>>2]);
   $175 = ((($158) + ($i$0492<<4)|0) + 4|0);
   $176 = Math_fround(HEAPF32[$175>>2]);
   $177 = ((($158) + ($i$0492<<4)|0) + 8|0);
   $178 = Math_fround(HEAPF32[$177>>2]);
   $179 = ((($158) + ($i$0492<<4)|0) + 12|0);
   $180 = Math_fround(HEAPF32[$rot>>2]);
   $181 = Math_fround($174 * $180);
   $182 = Math_fround(HEAPF32[$165>>2]);
   $183 = Math_fround($176 * $182);
   $184 = Math_fround($181 + $183);
   $185 = Math_fround(HEAPF32[$166>>2]);
   $186 = Math_fround($178 * $185);
   $187 = Math_fround($184 + $186);
   $188 = Math_fround(HEAPF32[$167>>2]);
   $189 = Math_fround($174 * $188);
   $190 = Math_fround(HEAPF32[$168>>2]);
   $191 = Math_fround($176 * $190);
   $192 = Math_fround($189 + $191);
   $193 = Math_fround(HEAPF32[$169>>2]);
   $194 = Math_fround($178 * $193);
   $195 = Math_fround($192 + $194);
   $196 = Math_fround(HEAPF32[$170>>2]);
   $197 = Math_fround($174 * $196);
   $198 = Math_fround(HEAPF32[$171>>2]);
   $199 = Math_fround($176 * $198);
   $200 = Math_fround($197 + $199);
   $201 = Math_fround(HEAPF32[$172>>2]);
   $202 = Math_fround($178 * $201);
   $203 = Math_fround($200 + $202);
   HEAPF32[$173>>2] = $187;
   HEAPF32[$175>>2] = $195;
   HEAPF32[$177>>2] = $203;
   HEAPF32[$179>>2] = Math_fround(0.0);
   $204 = $$$i54477489 < $187;
   $$$i54 = $204 ? $$$i54477489 : $187;
   $205 = $206 < $195;
   $207 = $205 ? $206 : $195;
   $208 = $$$i475491 > $187;
   $$$i = $208 ? $$$i475491 : $187;
   $209 = $210 > $195;
   $211 = $209 ? $210 : $195;
   $212 = (($i$0492) + 1)|0;
   $213 = HEAP8[$149>>0]|0;
   $214 = $213&255;
   $215 = ($212>>>0)<($214>>>0);
   if ($215) {
    $$$i475491 = $$$i;$$$i54477489 = $$$i54;$206 = $207;$210 = $211;$i$0492 = $212;
   } else {
    $$$i475$lcssa = $$$i;$$$i54477$lcssa = $$$i54;$$lcssa = $207;$$lcssa487 = $211;$250 = $213;
    break;
   }
  }
 }
 L9: do {
  if ($147) {
   $216 = Math_fround(HEAPF32[$normal>>2]);
   $217 = Math_fround(HEAPF32[$135>>2]);
   $218 = Math_fround(HEAPF32[$137>>2]);
   $219 = Math_fround(HEAPF32[$106>>2]);
   $220 = Math_fround(HEAPF32[$108>>2]);
   $221 = Math_fround(HEAPF32[$110>>2]);
   $222 = Math_fround($145 * $216);
   $223 = Math_fround($145 * $217);
   $224 = Math_fround($145 * $218);
   $225 = Math_fround($219 - $222);
   $226 = Math_fround($220 - $223);
   $227 = Math_fround($221 - $224);
   $228 = Math_fround(HEAPF32[$rot>>2]);
   $229 = Math_fround($225 * $228);
   $230 = (($rot) + 16|0);
   $231 = Math_fround(HEAPF32[$230>>2]);
   $232 = Math_fround($226 * $231);
   $233 = Math_fround($229 + $232);
   $234 = (($rot) + 32|0);
   $235 = Math_fround(HEAPF32[$234>>2]);
   $236 = Math_fround($227 * $235);
   $237 = Math_fround($233 + $236);
   $238 = (($rot) + 4|0);
   $239 = Math_fround(HEAPF32[$238>>2]);
   $240 = Math_fround($225 * $239);
   $241 = (($rot) + 20|0);
   $242 = Math_fround(HEAPF32[$241>>2]);
   $243 = Math_fround($226 * $242);
   $244 = Math_fround($240 + $243);
   $245 = (($rot) + 36|0);
   $246 = Math_fround(HEAPF32[$245>>2]);
   $247 = Math_fround($227 * $246);
   $248 = Math_fround($244 + $247);
   $249 = $250&255;
   $251 = $237 > $$$i475$lcssa;
   $not$$i20 = $$$i54477$lcssa > $237;
   $$demorgan$i21 = $251 | $not$$i20;
   if (!($$demorgan$i21)) {
    $252 = $248 > $$lcssa487;
    $not$304$i22 = $$lcssa > $248;
    $253 = $252 | $not$304$i22;
    $254 = ($250<<24>>24)==(0);
    $or$cond = $253 | $254;
    if (!($or$cond)) {
     $255 = (($249) + -1)|0;
     $$phi$trans$insert$i25 = ((($158) + ($255<<4)|0) + 4|0);
     $$pre$i26 = Math_fround(HEAPF32[$$phi$trans$insert$i25>>2]);
     $259 = $$pre$i26;$i$0308$i30 = 0;$intersectionPoints$0310$i28 = 0;$j$0309$i29 = $255;
     while(1) {
      $256 = ((($158) + ($i$0308$i30<<4)|0) + 4|0);
      $257 = Math_fround(HEAPF32[$256>>2]);
      $258 = $259 > $248;
      $260 = $257 > $248;
      $tmp$i31 = $258 ^ $260;
      if ($tmp$i31) {
       $261 = (($158) + ($i$0308$i30<<4)|0);
       $262 = (($158) + ($j$0309$i29<<4)|0);
       $263 = Math_fround(HEAPF32[$262>>2]);
       $264 = Math_fround(HEAPF32[$261>>2]);
       $265 = Math_fround($264 - $263);
       $266 = Math_fround($257 - $259);
       $267 = Math_fround($248 - $259);
       $268 = Math_fround($267 * $265);
       $269 = Math_fround($266 * $263);
       $270 = Math_fround($237 * $266);
       $271 = Math_fround($269 + $268);
       $272 = !($266 > Math_fround(0.0));
       $273 = $272 ? $270 : $271;
       $274 = $272 ? $271 : $270;
       $275 = !($273 >= $274);
       if ($275) {
        $intersectionPoints$1$i32 = $intersectionPoints$0310$i28;
       } else {
        $276 = ($intersectionPoints$0310$i28|0)==(1);
        if ($276) {
         break L9;
        }
        $277 = (($intersectionPoints$0310$i28) + 1)|0;
        $intersectionPoints$1$i32 = $277;
       }
      } else {
       $intersectionPoints$1$i32 = $intersectionPoints$0310$i28;
      }
      $278 = (($i$0308$i30) + 1)|0;
      $279 = ($278>>>0)<($249>>>0);
      if ($279) {
       $j$0309$i29$phi = $i$0308$i30;$259 = $257;$i$0308$i30 = $278;$intersectionPoints$0310$i28 = $intersectionPoints$1$i32;$j$0309$i29 = $j$0309$i29$phi;
      } else {
       break;
      }
     }
     $280 = ($intersectionPoints$1$i32|0)==(0);
     if (!($280)) {
      $281 = HEAP32[$numContacts>>2]|0;
      $282 = (($aToB) + 48|0);
      $283 = Math_fround(HEAPF32[$282>>2]);
      $284 = (($aToB) + 52|0);
      $285 = Math_fround(HEAPF32[$284>>2]);
      $286 = (($aToB) + 56|0);
      $287 = Math_fround(HEAPF32[$286>>2]);
      $288 = Math_fround($219 - $283);
      $289 = Math_fround($220 - $285);
      $290 = Math_fround($221 - $287);
      $291 = Math_fround(HEAPF32[$aToB>>2]);
      $292 = Math_fround($288 * $291);
      $293 = (($aToB) + 4|0);
      $294 = Math_fround(HEAPF32[$293>>2]);
      $295 = Math_fround($289 * $294);
      $296 = Math_fround($292 + $295);
      $297 = (($aToB) + 8|0);
      $298 = Math_fround(HEAPF32[$297>>2]);
      $299 = Math_fround($290 * $298);
      $300 = Math_fround($296 + $299);
      $301 = (($aToB) + 16|0);
      $302 = Math_fround(HEAPF32[$301>>2]);
      $303 = Math_fround($288 * $302);
      $304 = (($aToB) + 20|0);
      $305 = Math_fround(HEAPF32[$304>>2]);
      $306 = Math_fround($289 * $305);
      $307 = Math_fround($303 + $306);
      $308 = (($aToB) + 24|0);
      $309 = Math_fround(HEAPF32[$308>>2]);
      $310 = Math_fround($290 * $309);
      $311 = Math_fround($307 + $310);
      $312 = (($aToB) + 32|0);
      $313 = Math_fround(HEAPF32[$312>>2]);
      $314 = Math_fround($288 * $313);
      $315 = (($aToB) + 36|0);
      $316 = Math_fround(HEAPF32[$315>>2]);
      $317 = Math_fround($289 * $316);
      $318 = Math_fround($314 + $317);
      $319 = (($aToB) + 40|0);
      $320 = Math_fround(HEAPF32[$319>>2]);
      $321 = Math_fround($290 * $320);
      $322 = Math_fround($318 + $321);
      $323 = (($manifoldContacts) + (($281*48)|0)|0);
      HEAPF32[$323>>2] = $300;
      $324 = ((($manifoldContacts) + (($281*48)|0)|0) + 4|0);
      HEAPF32[$324>>2] = $311;
      $325 = ((($manifoldContacts) + (($281*48)|0)|0) + 8|0);
      HEAPF32[$325>>2] = $322;
      $326 = ((($manifoldContacts) + (($281*48)|0)|0) + 12|0);
      HEAPF32[$326>>2] = Math_fround(0.0);
      $327 = HEAP32[$numContacts>>2]|0;
      $328 = ((($manifoldContacts) + (($327*48)|0)|0) + 16|0);
      HEAPF32[$328>>2] = $225;
      $329 = ((($manifoldContacts) + (($327*48)|0)|0) + 20|0);
      HEAPF32[$329>>2] = $226;
      $330 = ((($manifoldContacts) + (($327*48)|0)|0) + 24|0);
      HEAPF32[$330>>2] = $227;
      $331 = ((($manifoldContacts) + (($327*48)|0)|0) + 28|0);
      HEAPF32[$331>>2] = Math_fround(0.0);
      $332 = HEAP32[$numContacts>>2]|0;
      $333 = (($332) + 1)|0;
      HEAP32[$numContacts>>2] = $333;
      $334 = Math_fround(HEAPF32[$normal>>2]);
      $335 = Math_fround(HEAPF32[$135>>2]);
      $336 = Math_fround(HEAPF32[$137>>2]);
      $337 = ((($manifoldContacts) + (($332*48)|0)|0) + 32|0);
      HEAPF32[$337>>2] = $334;
      $338 = ((($manifoldContacts) + (($332*48)|0)|0) + 36|0);
      HEAPF32[$338>>2] = $335;
      $339 = ((($manifoldContacts) + (($332*48)|0)|0) + 40|0);
      HEAPF32[$339>>2] = $336;
      $340 = ((($manifoldContacts) + (($332*48)|0)|0) + 44|0);
      HEAPF32[$340>>2] = $145;
     }
    }
   }
  }
 } while(0);
 if (!($148)) {
  STACKTOP = sp;return;
 }
 $341 = Math_fround(HEAPF32[$normal>>2]);
 $342 = Math_fround(HEAPF32[$135>>2]);
 $343 = Math_fround(HEAPF32[$137>>2]);
 $344 = Math_fround(HEAPF32[$120>>2]);
 $345 = Math_fround(HEAPF32[$122>>2]);
 $346 = Math_fround(HEAPF32[$124>>2]);
 $347 = Math_fround($146 * $341);
 $348 = Math_fround($146 * $342);
 $349 = Math_fround($146 * $343);
 $350 = Math_fround($344 - $347);
 $351 = Math_fround($345 - $348);
 $352 = Math_fround($346 - $349);
 $353 = Math_fround(HEAPF32[$rot>>2]);
 $354 = Math_fround($350 * $353);
 $355 = (($rot) + 16|0);
 $356 = Math_fround(HEAPF32[$355>>2]);
 $357 = Math_fround($351 * $356);
 $358 = Math_fround($354 + $357);
 $359 = (($rot) + 32|0);
 $360 = Math_fround(HEAPF32[$359>>2]);
 $361 = Math_fround($352 * $360);
 $362 = Math_fround($358 + $361);
 $363 = (($rot) + 4|0);
 $364 = Math_fround(HEAPF32[$363>>2]);
 $365 = Math_fround($350 * $364);
 $366 = (($rot) + 20|0);
 $367 = Math_fround(HEAPF32[$366>>2]);
 $368 = Math_fround($351 * $367);
 $369 = Math_fround($365 + $368);
 $370 = (($rot) + 36|0);
 $371 = Math_fround(HEAPF32[$370>>2]);
 $372 = Math_fround($352 * $371);
 $373 = Math_fround($369 + $372);
 $374 = HEAP8[$149>>0]|0;
 $375 = $374&255;
 $376 = $362 > $$$i475$lcssa;
 $not$$i = $$$i54477$lcssa > $362;
 $$demorgan$i = $376 | $not$$i;
 if ($$demorgan$i) {
  STACKTOP = sp;return;
 }
 $377 = $373 > $$lcssa487;
 $not$304$i = $$lcssa > $373;
 $378 = $377 | $not$304$i;
 $379 = ($374<<24>>24)==(0);
 $or$cond486 = $378 | $379;
 if ($or$cond486) {
  STACKTOP = sp;return;
 }
 $380 = (($375) + -1)|0;
 $$phi$trans$insert$i = ((($158) + ($380<<4)|0) + 4|0);
 $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
 $384 = $$pre$i;$i$0308$i = 0;$intersectionPoints$0310$i = 0;$j$0309$i = $380;
 while(1) {
  $381 = ((($158) + ($i$0308$i<<4)|0) + 4|0);
  $382 = Math_fround(HEAPF32[$381>>2]);
  $383 = $384 > $373;
  $385 = $382 > $373;
  $tmp$i = $383 ^ $385;
  if ($tmp$i) {
   $386 = (($158) + ($i$0308$i<<4)|0);
   $387 = (($158) + ($j$0309$i<<4)|0);
   $388 = Math_fround(HEAPF32[$387>>2]);
   $389 = Math_fround(HEAPF32[$386>>2]);
   $390 = Math_fround($389 - $388);
   $391 = Math_fround($382 - $384);
   $392 = Math_fround($373 - $384);
   $393 = Math_fround($392 * $390);
   $394 = Math_fround($391 * $388);
   $395 = Math_fround($362 * $391);
   $396 = Math_fround($394 + $393);
   $397 = !($391 > Math_fround(0.0));
   $398 = $397 ? $395 : $396;
   $399 = $397 ? $396 : $395;
   $400 = !($398 >= $399);
   if ($400) {
    $intersectionPoints$1$i = $intersectionPoints$0310$i;
   } else {
    $401 = ($intersectionPoints$0310$i|0)==(1);
    if ($401) {
     label = 27;
     break;
    }
    $402 = (($intersectionPoints$0310$i) + 1)|0;
    $intersectionPoints$1$i = $402;
   }
  } else {
   $intersectionPoints$1$i = $intersectionPoints$0310$i;
  }
  $403 = (($i$0308$i) + 1)|0;
  $404 = ($403>>>0)<($375>>>0);
  if ($404) {
   $j$0309$i$phi = $i$0308$i;$384 = $382;$i$0308$i = $403;$intersectionPoints$0310$i = $intersectionPoints$1$i;$j$0309$i = $j$0309$i$phi;
  } else {
   break;
  }
 }
 if ((label|0) == 27) {
  STACKTOP = sp;return;
 }
 $405 = ($intersectionPoints$1$i|0)==(0);
 if ($405) {
  STACKTOP = sp;return;
 }
 $406 = HEAP32[$numContacts>>2]|0;
 $407 = (($aToB) + 48|0);
 $408 = Math_fround(HEAPF32[$407>>2]);
 $409 = (($aToB) + 52|0);
 $410 = Math_fround(HEAPF32[$409>>2]);
 $411 = (($aToB) + 56|0);
 $412 = Math_fround(HEAPF32[$411>>2]);
 $413 = Math_fround($344 - $408);
 $414 = Math_fround($345 - $410);
 $415 = Math_fround($346 - $412);
 $416 = Math_fround(HEAPF32[$aToB>>2]);
 $417 = Math_fround($413 * $416);
 $418 = (($aToB) + 4|0);
 $419 = Math_fround(HEAPF32[$418>>2]);
 $420 = Math_fround($414 * $419);
 $421 = Math_fround($417 + $420);
 $422 = (($aToB) + 8|0);
 $423 = Math_fround(HEAPF32[$422>>2]);
 $424 = Math_fround($415 * $423);
 $425 = Math_fround($421 + $424);
 $426 = (($aToB) + 16|0);
 $427 = Math_fround(HEAPF32[$426>>2]);
 $428 = Math_fround($413 * $427);
 $429 = (($aToB) + 20|0);
 $430 = Math_fround(HEAPF32[$429>>2]);
 $431 = Math_fround($414 * $430);
 $432 = Math_fround($428 + $431);
 $433 = (($aToB) + 24|0);
 $434 = Math_fround(HEAPF32[$433>>2]);
 $435 = Math_fround($415 * $434);
 $436 = Math_fround($432 + $435);
 $437 = (($aToB) + 32|0);
 $438 = Math_fround(HEAPF32[$437>>2]);
 $439 = Math_fround($413 * $438);
 $440 = (($aToB) + 36|0);
 $441 = Math_fround(HEAPF32[$440>>2]);
 $442 = Math_fround($414 * $441);
 $443 = Math_fround($439 + $442);
 $444 = (($aToB) + 40|0);
 $445 = Math_fround(HEAPF32[$444>>2]);
 $446 = Math_fround($415 * $445);
 $447 = Math_fround($443 + $446);
 $448 = (($manifoldContacts) + (($406*48)|0)|0);
 HEAPF32[$448>>2] = $425;
 $449 = ((($manifoldContacts) + (($406*48)|0)|0) + 4|0);
 HEAPF32[$449>>2] = $436;
 $450 = ((($manifoldContacts) + (($406*48)|0)|0) + 8|0);
 HEAPF32[$450>>2] = $447;
 $451 = ((($manifoldContacts) + (($406*48)|0)|0) + 12|0);
 HEAPF32[$451>>2] = Math_fround(0.0);
 $452 = HEAP32[$numContacts>>2]|0;
 $453 = ((($manifoldContacts) + (($452*48)|0)|0) + 16|0);
 HEAPF32[$453>>2] = $350;
 $454 = ((($manifoldContacts) + (($452*48)|0)|0) + 20|0);
 HEAPF32[$454>>2] = $351;
 $455 = ((($manifoldContacts) + (($452*48)|0)|0) + 24|0);
 HEAPF32[$455>>2] = $352;
 $456 = ((($manifoldContacts) + (($452*48)|0)|0) + 28|0);
 HEAPF32[$456>>2] = Math_fround(0.0);
 $457 = HEAP32[$numContacts>>2]|0;
 $458 = (($457) + 1)|0;
 HEAP32[$numContacts>>2] = $458;
 $459 = Math_fround(HEAPF32[$normal>>2]);
 $460 = Math_fround(HEAPF32[$135>>2]);
 $461 = Math_fround(HEAPF32[$137>>2]);
 $462 = ((($manifoldContacts) + (($457*48)|0)|0) + 32|0);
 HEAPF32[$462>>2] = $459;
 $463 = ((($manifoldContacts) + (($457*48)|0)|0) + 36|0);
 HEAPF32[$463>>2] = $460;
 $464 = ((($manifoldContacts) + (($457*48)|0)|0) + 40|0);
 HEAPF32[$464>>2] = $461;
 $465 = ((($manifoldContacts) + (($457*48)|0)|0) + 44|0);
 HEAPF32[$465>>2] = $146;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu27generatedContactsEEContactsERKNS0_8CapsuleVERNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNSC_6FloatVERKNSC_5Vec3VE($capsule,$polyData,$referencePolygon,$map,$aToB,$manifoldContacts,$numContacts,$contactDist,$contactNormal) {
 $capsule = $capsule|0;
 $polyData = $polyData|0;
 $referencePolygon = $referencePolygon|0;
 $map = $map|0;
 $aToB = $aToB|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $contactNormal = $contactNormal|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0);
 var $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $or$cond$i = 0, $rEnd$011 = 0, $rEnd$011$phi = 0, $rStart$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($polyData) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($referencePolygon) + 16|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($1) + ($4)|0);
 $6 = (($referencePolygon) + 18|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 4;
 $10 = (($9) + 16)|0;
 $11 = STACKTOP; STACKTOP = STACKTOP + ((((1*$10)|0)+15)&-16)|0;;
 $12 = $11;
 $13 = (($12) + 15)|0;
 $14 = $13 & -16;
 $15 = $14;
 $16 = HEAP32[$map>>2]|0;
 $17 = (($16) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($polyData) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_viiiii[$18 & 255]($map,$5,$8,$20,$15);
 $21 = (($capsule) + 128|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround(HEAPF32[$contactDist>>2]);
 $24 = Math_fround($22 + $23);
 $25 = HEAP8[$6>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = $25&255;
 $28 = (($27) + -1)|0;
 $29 = (($contactNormal) + 4|0);
 $30 = (($contactNormal) + 8|0);
 $31 = (($capsule) + 96|0);
 $32 = (($capsule) + 100|0);
 $33 = (($capsule) + 104|0);
 $34 = (($capsule) + 112|0);
 $35 = (($capsule) + 116|0);
 $36 = (($capsule) + 120|0);
 $37 = (($aToB) + 48|0);
 $38 = (($aToB) + 52|0);
 $39 = (($aToB) + 56|0);
 $40 = (($aToB) + 4|0);
 $41 = (($aToB) + 8|0);
 $42 = (($aToB) + 16|0);
 $43 = (($aToB) + 20|0);
 $44 = (($aToB) + 24|0);
 $45 = (($aToB) + 32|0);
 $46 = (($aToB) + 36|0);
 $47 = (($aToB) + 40|0);
 $210 = $25;$rEnd$011 = $28;$rStart$010 = 0;
 while(1) {
  $48 = (($15) + ($rEnd$011<<4)|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = ((($15) + ($rEnd$011<<4)|0) + 4|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = ((($15) + ($rEnd$011<<4)|0) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($15) + ($rStart$010<<4)|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = ((($15) + ($rStart$010<<4)|0) + 4|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = ((($15) + ($rStart$010<<4)|0) + 8|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($49 - $55);
  $61 = Math_fround($51 - $57);
  $62 = Math_fround($53 - $59);
  $63 = Math_fround(HEAPF32[$contactNormal>>2]);
  $64 = Math_fround(HEAPF32[$29>>2]);
  $65 = Math_fround(HEAPF32[$30>>2]);
  $66 = Math_fround($61 * $65);
  $67 = Math_fround($62 * $64);
  $68 = Math_fround($66 - $67);
  $69 = Math_fround($62 * $63);
  $70 = Math_fround($60 * $65);
  $71 = Math_fround($69 - $70);
  $72 = Math_fround($60 * $64);
  $73 = Math_fround($61 * $63);
  $74 = Math_fround($72 - $73);
  $75 = Math_fround($55 * $68);
  $76 = Math_fround($57 * $71);
  $77 = Math_fround($75 + $76);
  $78 = Math_fround($59 * $74);
  $79 = Math_fround($78 + $77);
  $80 = Math_fround(HEAPF32[$31>>2]);
  $81 = Math_fround(HEAPF32[$32>>2]);
  $82 = Math_fround(HEAPF32[$33>>2]);
  $83 = Math_fround($80 * $68);
  $84 = Math_fround($71 * $81);
  $85 = Math_fround($83 + $84);
  $86 = Math_fround($74 * $82);
  $87 = Math_fround($85 + $86);
  $88 = Math_fround(HEAPF32[$34>>2]);
  $89 = Math_fround(HEAPF32[$35>>2]);
  $90 = Math_fround(HEAPF32[$36>>2]);
  $91 = Math_fround($68 * $88);
  $92 = Math_fround($71 * $89);
  $93 = Math_fround($91 + $92);
  $94 = Math_fround($74 * $90);
  $95 = Math_fround($93 + $94);
  $96 = Math_fround($87 - $79);
  $97 = Math_fround($95 - $79);
  $98 = Math_fround($96 * $97);
  $99 = $98 > Math_fround(0.0);
  if ($99) {
   $208 = $210;
  } else {
   $100 = Math_fround($88 - $80);
   $101 = Math_fround($89 - $81);
   $102 = Math_fround($90 - $82);
   $103 = Math_fround($68 * $100);
   $104 = Math_fround($71 * $101);
   $105 = Math_fround($103 + $104);
   $106 = Math_fround($74 * $102);
   $107 = Math_fround($105 + $106);
   $108 = $107 == Math_fround(0.0);
   if ($108) {
    $208 = $210;
   } else {
    $109 = Math_fround($79 - $87);
    $110 = Math_fround($109 / $107);
    $111 = Math_fround($100 * $110);
    $112 = Math_fround($101 * $110);
    $113 = Math_fround($102 * $110);
    $114 = Math_fround($80 + $111);
    $115 = Math_fround($81 + $112);
    $116 = Math_fround($82 + $113);
    $117 = Math_fround($64 * $102);
    $118 = Math_fround($65 * $101);
    $119 = Math_fround($117 - $118);
    $120 = Math_fround($65 * $100);
    $121 = Math_fround($63 * $102);
    $122 = Math_fround($120 - $121);
    $123 = Math_fround($63 * $101);
    $124 = Math_fround($64 * $100);
    $125 = Math_fround($123 - $124);
    $126 = Math_fround($114 - $55);
    $127 = Math_fround($115 - $57);
    $128 = Math_fround($116 - $59);
    $129 = Math_fround($119 * $126);
    $130 = Math_fround($122 * $127);
    $131 = Math_fround($129 + $130);
    $132 = Math_fround($125 * $128);
    $133 = Math_fround($132 + $131);
    $134 = Math_fround($60 * $119);
    $135 = Math_fround($61 * $122);
    $136 = Math_fround($134 + $135);
    $137 = Math_fround($62 * $125);
    $138 = Math_fround($137 + $136);
    $139 = Math_fround($133 / $138);
    $140 = $139 > Math_fround(1.00499999523162841797);
    $141 = $139 < Math_fround(-0.00499999988824129104614);
    $or$cond$i = $140 | $141;
    if ($or$cond$i) {
     $208 = $210;
    } else {
     $142 = Math_fround($60 * $139);
     $143 = Math_fround($61 * $139);
     $144 = Math_fround($62 * $139);
     $145 = Math_fround($126 - $142);
     $146 = Math_fround($127 - $143);
     $147 = Math_fround($128 - $144);
     $148 = Math_fround($63 * $145);
     $149 = Math_fround($64 * $146);
     $150 = Math_fround($148 + $149);
     $151 = Math_fround($65 * $147);
     $152 = Math_fround($151 + $150);
     $153 = !($24 >= $152);
     if ($153) {
      $208 = $210;
     } else {
      $154 = Math_fround($114 - $145);
      $155 = Math_fround($115 - $146);
      $156 = Math_fround($116 - $147);
      $157 = HEAP32[$numContacts>>2]|0;
      $158 = Math_fround(HEAPF32[$37>>2]);
      $159 = Math_fround(HEAPF32[$38>>2]);
      $160 = Math_fround(HEAPF32[$39>>2]);
      $161 = Math_fround($114 - $158);
      $162 = Math_fround($115 - $159);
      $163 = Math_fround($116 - $160);
      $164 = Math_fround(HEAPF32[$aToB>>2]);
      $165 = Math_fround($161 * $164);
      $166 = Math_fround(HEAPF32[$40>>2]);
      $167 = Math_fround($162 * $166);
      $168 = Math_fround($165 + $167);
      $169 = Math_fround(HEAPF32[$41>>2]);
      $170 = Math_fround($163 * $169);
      $171 = Math_fround($168 + $170);
      $172 = Math_fround(HEAPF32[$42>>2]);
      $173 = Math_fround($161 * $172);
      $174 = Math_fround(HEAPF32[$43>>2]);
      $175 = Math_fround($162 * $174);
      $176 = Math_fround($173 + $175);
      $177 = Math_fround(HEAPF32[$44>>2]);
      $178 = Math_fround($163 * $177);
      $179 = Math_fround($176 + $178);
      $180 = Math_fround(HEAPF32[$45>>2]);
      $181 = Math_fround($161 * $180);
      $182 = Math_fround(HEAPF32[$46>>2]);
      $183 = Math_fround($162 * $182);
      $184 = Math_fround($181 + $183);
      $185 = Math_fround(HEAPF32[$47>>2]);
      $186 = Math_fround($163 * $185);
      $187 = Math_fround($184 + $186);
      $188 = (($manifoldContacts) + (($157*48)|0)|0);
      HEAPF32[$188>>2] = $171;
      $189 = ((($manifoldContacts) + (($157*48)|0)|0) + 4|0);
      HEAPF32[$189>>2] = $179;
      $190 = ((($manifoldContacts) + (($157*48)|0)|0) + 8|0);
      HEAPF32[$190>>2] = $187;
      $191 = ((($manifoldContacts) + (($157*48)|0)|0) + 12|0);
      HEAPF32[$191>>2] = Math_fround(0.0);
      $192 = HEAP32[$numContacts>>2]|0;
      $193 = ((($manifoldContacts) + (($192*48)|0)|0) + 16|0);
      HEAPF32[$193>>2] = $154;
      $194 = ((($manifoldContacts) + (($192*48)|0)|0) + 20|0);
      HEAPF32[$194>>2] = $155;
      $195 = ((($manifoldContacts) + (($192*48)|0)|0) + 24|0);
      HEAPF32[$195>>2] = $156;
      $196 = ((($manifoldContacts) + (($192*48)|0)|0) + 28|0);
      HEAPF32[$196>>2] = Math_fround(0.0);
      $197 = HEAP32[$numContacts>>2]|0;
      $198 = (($197) + 1)|0;
      HEAP32[$numContacts>>2] = $198;
      $199 = Math_fround(HEAPF32[$contactNormal>>2]);
      $200 = Math_fround(HEAPF32[$29>>2]);
      $201 = Math_fround(HEAPF32[$30>>2]);
      $202 = ((($manifoldContacts) + (($197*48)|0)|0) + 32|0);
      HEAPF32[$202>>2] = $199;
      $203 = ((($manifoldContacts) + (($197*48)|0)|0) + 36|0);
      HEAPF32[$203>>2] = $200;
      $204 = ((($manifoldContacts) + (($197*48)|0)|0) + 40|0);
      HEAPF32[$204>>2] = $201;
      $205 = ((($manifoldContacts) + (($197*48)|0)|0) + 44|0);
      HEAPF32[$205>>2] = $152;
      $$pre = HEAP8[$6>>0]|0;
      $208 = $$pre;
     }
    }
   }
  }
  $206 = (($rStart$010) + 1)|0;
  $207 = $208&255;
  $209 = ($206>>>0)<($207>>>0);
  if ($209) {
   $rEnd$011$phi = $rStart$010;$210 = $208;$rStart$010 = $206;$rEnd$011 = $rEnd$011$phi;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu37generateCapsuleBoxFullContactManifoldERKNS0_8CapsuleVERNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVERNS9_5Vec3VEb($capsule,$polyData,$map,$aToB,$manifoldContacts,$numContacts,$contactDist,$normal,$doOverlapTest) {
 $capsule = $capsule|0;
 $polyData = $polyData|0;
 $map = $map|0;
 $aToB = $aToB|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $normal = $normal|0;
 $doOverlapTest = $doOverlapTest|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0);
 var $8 = Math_fround(0), $9 = Math_fround(0), $minOverlap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $minOverlap = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$numContacts>>2]|0;
 if ($doOverlapTest) {
  $2 = (__ZN5physx2GuL18testSATCapsulePolyERKNS0_8CapsuleVERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSB_RNSA_5Vec3VE($capsule,$polyData,$map,$contactDist,$minOverlap,$normal)|0);
  if (!($2)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $3 = Math_fround(HEAPF32[$normal>>2]);
 $4 = (($normal) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($normal) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(-$3);
 $9 = Math_fround(-$5);
 $10 = Math_fround(-$7);
 HEAPF32[$0>>2] = $8;
 $11 = (($0) + 4|0);
 HEAPF32[$11>>2] = $9;
 $12 = (($0) + 8|0);
 HEAPF32[$12>>2] = $10;
 $13 = (($0) + 12|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData,$map,$0)|0);
 $15 = (($polyData) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + (($14*20)|0)|0);
 __ZN5physx2Gu31generatedCapsuleBoxFaceContactsERKNS0_8CapsuleVERNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNSC_6FloatVERKNSC_5Vec3VE($capsule,$polyData,$17,$map,$aToB,$manifoldContacts,$numContacts,$contactDist,$normal);
 $18 = HEAP32[$numContacts>>2]|0;
 $19 = (($18) - ($1))|0;
 $20 = ($19>>>0)<(2);
 if (!($20)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN5physx2Gu27generatedContactsEEContactsERKNS0_8CapsuleVERNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNSC_6FloatVERKNSC_5Vec3VE($capsule,$polyData,$17,$map,$aToB,$manifoldContacts,$numContacts,$contactDist,$normal);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2GuL18testSATCapsulePolyERKNS0_8CapsuleVERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSB_RNSA_5Vec3VE($capsule,$polyData,$map,$contactDist,$minOverlap,$seperatingAxis) {
 $capsule = $capsule|0;
 $polyData = $polyData|0;
 $map = $map|0;
 $contactDist = $contactDist|0;
 $minOverlap = $minOverlap|0;
 $seperatingAxis = $seperatingAxis|0;
 var $$$i = Math_fround(0), $$$i104 = Math_fround(0), $$$i109 = Math_fround(0), $$$i41 = Math_fround(0), $$0 = 0, $$lcssa = Math_fround(0), $$lcssa562 = Math_fround(0), $$lcssa564 = Math_fround(0), $$lcssa566 = Math_fround(0), $$lcssa568 = Math_fround(0), $$lcssa576 = Math_fround(0), $$lcssa578 = Math_fround(0), $$lcssa580 = Math_fround(0), $$lcssa582 = Math_fround(0), $$lcssa584 = Math_fround(0), $$lcssa596 = Math_fround(0), $$lcssa598 = Math_fround(0), $$lcssa600 = Math_fround(0), $$lcssa602 = Math_fround(0), $$phi$trans$insert = 0;
 var $$phi$trans$insert637 = 0, $$phi$trans$insert639 = 0, $$phi$trans$insert641 = 0, $$phi$trans$insert643 = 0, $$phi$trans$insert645 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre624 = 0, $$pre625 = 0, $$pre626 = Math_fround(0), $$pre627 = Math_fround(0), $$pre628 = Math_fround(0), $$pre629 = Math_fround(0), $$pre630 = Math_fround(0), $$pre631 = Math_fround(0), $$pre632 = Math_fround(0), $$pre636 = Math_fround(0), $$pre638 = Math_fround(0), $$pre640 = Math_fround(0), $$pre642 = Math_fround(0);
 var $$pre644 = Math_fround(0), $$pre646 = Math_fround(0), $$sroa$1245 = 0, $$sroa$1249 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0;
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0;
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0;
 var $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $_minOverlap$sroa$1 = 0, $i$0606 = 0, $i1$0586 = 0, $lEnd$0571 = 0, $lEnd$0571$phi = 0, $lStart$0570 = 0, $max0 = 0, $min0 = 0;
 var $normal = 0, $tempOverlap$sroa$1 = 0, $tempOverlap6$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $_minOverlap$sroa$1 = sp + 96|0;
 $min0 = sp;
 $max0 = sp + 16|0;
 $$sroa$1249 = sp + 72|0;
 $$sroa$1245 = sp + 48|0;
 $tempOverlap$sroa$1 = sp + 60|0;
 $normal = sp + 32|0;
 $tempOverlap6$sroa$1 = sp + 84|0;
 $0 = (($polyData) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $$phi$trans$insert = (($capsule) + 112|0);
   $$pre636 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
   $$phi$trans$insert637 = (($capsule) + 116|0);
   $$pre638 = Math_fround(HEAPF32[$$phi$trans$insert637>>2]);
   $$phi$trans$insert639 = (($capsule) + 120|0);
   $$pre640 = Math_fround(HEAPF32[$$phi$trans$insert639>>2]);
   $$phi$trans$insert641 = (($capsule) + 96|0);
   $$pre642 = Math_fround(HEAPF32[$$phi$trans$insert641>>2]);
   $$phi$trans$insert643 = (($capsule) + 100|0);
   $$pre644 = Math_fround(HEAPF32[$$phi$trans$insert643>>2]);
   $$phi$trans$insert645 = (($capsule) + 104|0);
   $$pre646 = Math_fround(HEAPF32[$$phi$trans$insert645>>2]);
   $$lcssa596 = Math_fround(3.40282346638528859812E+38);$$lcssa598 = Math_fround(0.0);$$lcssa600 = Math_fround(1.0);$$lcssa602 = Math_fround(0.0);$114 = $$pre642;$115 = $$pre636;$117 = $$pre644;$118 = $$pre638;$120 = $$pre646;$121 = $$pre640;$123 = 0;
  } else {
   $3 = (($polyData) + 24|0);
   $4 = (($polyData) + 28|0);
   $5 = (($map) + 40|0);
   $6 = (($min0) + 4|0);
   $7 = (($max0) + 4|0);
   $8 = (($capsule) + 96|0);
   $9 = (($capsule) + 100|0);
   $10 = (($capsule) + 104|0);
   $11 = (($capsule) + 112|0);
   $12 = (($capsule) + 116|0);
   $13 = (($capsule) + 120|0);
   $14 = (($capsule) + 128|0);
   $$pre624 = HEAP32[$4>>2]|0;
   $$pre625 = HEAP32[$5>>2]|0;
   $$pre626 = Math_fround(HEAPF32[$8>>2]);
   $$pre627 = Math_fround(HEAPF32[$9>>2]);
   $$pre628 = Math_fround(HEAPF32[$10>>2]);
   $$pre629 = Math_fround(HEAPF32[$11>>2]);
   $$pre630 = Math_fround(HEAPF32[$12>>2]);
   $$pre631 = Math_fround(HEAPF32[$13>>2]);
   $$pre632 = Math_fround(HEAPF32[$14>>2]);
   $103 = Math_fround(3.40282346638528859812E+38);$264 = Math_fround(0.0);$265 = Math_fround(1.0);$266 = Math_fround(0.0);$i$0606 = 0;
   while(1) {
    $15 = HEAP32[$3>>2]|0;
    $16 = ((($15) + (($i$0606*20)|0)|0) + 19|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = $17&255;
    $19 = (($$pre624) + (($18*12)|0)|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = ((($$pre624) + (($18*12)|0)|0) + 4|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = ((($$pre624) + (($18*12)|0)|0) + 8|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = ((($15) + (($i$0606*20)|0)|0) + 12|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = (($15) + (($i$0606*20)|0)|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = ((($15) + (($i$0606*20)|0)|0) + 4|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = ((($15) + (($i$0606*20)|0)|0) + 8|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = Math_fround(HEAPF32[$$pre625>>2]);
    $34 = Math_fround($28 * $33);
    $35 = (($$pre625) + 4|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = Math_fround($30 * $36);
    $38 = Math_fround($34 + $37);
    $39 = (($$pre625) + 8|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = Math_fround($32 * $40);
    $42 = Math_fround($38 + $41);
    $43 = (($$pre625) + 16|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = Math_fround($28 * $44);
    $46 = (($$pre625) + 20|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = Math_fround($30 * $47);
    $49 = Math_fround($45 + $48);
    $50 = (($$pre625) + 24|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = Math_fround($32 * $51);
    $53 = Math_fround($49 + $52);
    $54 = (($$pre625) + 32|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = Math_fround($28 * $55);
    $57 = (($$pre625) + 36|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($30 * $58);
    $60 = Math_fround($56 + $59);
    $61 = (($$pre625) + 40|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = Math_fround($32 * $62);
    $64 = Math_fround($60 + $63);
    $65 = Math_fround($42 * $42);
    $66 = Math_fround($53 * $53);
    $67 = Math_fround($65 + $66);
    $68 = Math_fround($64 * $64);
    $69 = Math_fround($67 + $68);
    $70 = (Math_fround(Math_sqrt((Math_fround($69)))));
    $71 = Math_fround(Math_fround(1.0) / $70);
    $72 = Math_fround($42 * $71);
    $73 = Math_fround($53 * $71);
    $74 = Math_fround($71 * $64);
    $75 = Math_fround($20 * $28);
    $76 = Math_fround($22 * $30);
    $77 = Math_fround($75 + $76);
    $78 = Math_fround($24 * $32);
    $79 = Math_fround($77 + $78);
    $80 = Math_fround($79 * $71);
    HEAPF32[$min0>>2] = $80;
    ;HEAP32[$6+0>>2]=HEAP32[$$sroa$1249+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$$sroa$1249+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$$sroa$1249+8>>2]|0;
    $81 = Math_fround($26 * $71);
    $82 = Math_fround(-$81);
    HEAPF32[$max0>>2] = $82;
    ;HEAP32[$7+0>>2]=HEAP32[$$sroa$1245+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$$sroa$1245+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$$sroa$1245+8>>2]|0;
    $83 = Math_fround($72 * $$pre626);
    $84 = Math_fround($73 * $$pre627);
    $85 = Math_fround($83 + $84);
    $86 = Math_fround($74 * $$pre628);
    $87 = Math_fround($85 + $86);
    $88 = Math_fround($72 * $$pre629);
    $89 = Math_fround($73 * $$pre630);
    $90 = Math_fround($88 + $89);
    $91 = Math_fround($74 * $$pre631);
    $92 = Math_fround($90 + $91);
    $93 = $87 > $92;
    $$$i109 = $93 ? $92 : $87;
    $94 = Math_fround($$$i109 - $$pre632);
    $95 = Math_fround(HEAPF32[$contactDist>>2]);
    $96 = Math_fround($95 - $81);
    $97 = $94 > $96;
    if ($97) {
     $$0 = 0;
     label = 22;
     break;
    }
    $$$i104 = $93 ? $87 : $92;
    $98 = Math_fround($$pre632 + $$$i104);
    $99 = Math_fround($95 + $98);
    $100 = $80 > $99;
    if ($100) {
     $$0 = 0;
     label = 22;
     break;
    }
    $101 = Math_fround($82 - $94);
    $102 = $103 > $101;
    if ($102) {
     ;HEAP32[$_minOverlap$sroa$1+0>>2]=HEAP32[$tempOverlap$sroa$1+0>>2]|0;HEAP32[$_minOverlap$sroa$1+4>>2]=HEAP32[$tempOverlap$sroa$1+4>>2]|0;HEAP32[$_minOverlap$sroa$1+8>>2]=HEAP32[$tempOverlap$sroa$1+8>>2]|0;
     $267 = $101;$268 = $74;$269 = $73;$270 = $72;
    } else {
     $267 = $103;$268 = $266;$269 = $265;$270 = $264;
    }
    $104 = (($i$0606) + 1)|0;
    $105 = HEAP32[$0>>2]|0;
    $106 = ($104>>>0)<($105>>>0);
    if ($106) {
     $103 = $267;$264 = $270;$265 = $269;$266 = $268;$i$0606 = $104;
    } else {
     $$lcssa596 = $267;$$lcssa598 = $268;$$lcssa600 = $269;$$lcssa602 = $270;$114 = $$pre626;$115 = $$pre629;$117 = $$pre627;$118 = $$pre630;$120 = $$pre628;$121 = $$pre631;$123 = $105;
     break L1;
    }
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $107 = (($capsule) + 112|0);
 $108 = (($capsule) + 116|0);
 $109 = (($capsule) + 120|0);
 $110 = (($capsule) + 96|0);
 $111 = (($capsule) + 100|0);
 $112 = (($capsule) + 104|0);
 $113 = Math_fround($115 - $114);
 $116 = Math_fround($118 - $117);
 $119 = Math_fround($121 - $120);
 $122 = ($123|0)==(0);
 L15: do {
  if ($122) {
   $$lcssa576 = $$lcssa596;$$lcssa578 = Math_fround(0.0);$$lcssa580 = $$lcssa598;$$lcssa582 = $$lcssa600;$$lcssa584 = $$lcssa602;$$pre$phiZ2D = $_minOverlap$sroa$1;
  } else {
   $124 = (($polyData) + 24|0);
   $125 = (($polyData) + 32|0);
   $126 = (($polyData) + 28|0);
   $127 = (($map) + 40|0);
   $128 = (($normal) + 4|0);
   $129 = (($normal) + 8|0);
   $130 = (($normal) + 12|0);
   $131 = (($capsule) + 128|0);
   $271 = $123;$272 = $$lcssa602;$273 = $$lcssa600;$274 = $$lcssa598;$275 = Math_fround(0.0);$276 = $$lcssa596;$i1$0586 = 0;
   L17: while(1) {
    $132 = HEAP32[$124>>2]|0;
    $133 = HEAP32[$125>>2]|0;
    $134 = ((($132) + (($i1$0586*20)|0)|0) + 16|0);
    $135 = HEAP16[$134>>1]|0;
    $136 = $135&65535;
    $137 = ((($132) + (($i1$0586*20)|0)|0) + 18|0);
    $138 = HEAP8[$137>>0]|0;
    $139 = ($138<<24>>24)==(0);
    if ($139) {
     $$lcssa = $276;$$lcssa562 = $275;$$lcssa564 = $274;$$lcssa566 = $273;$$lcssa568 = $272;$259 = $271;
    } else {
     $140 = $138&255;
     $141 = (($140) + -1)|0;
     $251 = $276;$277 = $272;$278 = $273;$279 = $274;$280 = $275;$lEnd$0571 = $141;$lStart$0570 = 0;
     while(1) {
      $$sum = (($lStart$0570) + ($136))|0;
      $142 = (($133) + ($$sum)|0);
      $143 = HEAP8[$142>>0]|0;
      $144 = $143&255;
      $145 = HEAP32[$126>>2]|0;
      $146 = (($145) + (($144*12)|0)|0);
      $147 = Math_fround(HEAPF32[$146>>2]);
      $148 = ((($145) + (($144*12)|0)|0) + 4|0);
      $149 = Math_fround(HEAPF32[$148>>2]);
      $150 = ((($145) + (($144*12)|0)|0) + 8|0);
      $151 = Math_fround(HEAPF32[$150>>2]);
      $$sum1 = (($lEnd$0571) + ($136))|0;
      $152 = (($133) + ($$sum1)|0);
      $153 = HEAP8[$152>>0]|0;
      $154 = $153&255;
      $155 = (($145) + (($154*12)|0)|0);
      $156 = Math_fround(HEAPF32[$155>>2]);
      $157 = ((($145) + (($154*12)|0)|0) + 4|0);
      $158 = Math_fround(HEAPF32[$157>>2]);
      $159 = ((($145) + (($154*12)|0)|0) + 8|0);
      $160 = Math_fround(HEAPF32[$159>>2]);
      $161 = Math_fround($156 - $147);
      $162 = Math_fround($158 - $149);
      $163 = Math_fround($160 - $151);
      $164 = HEAP32[$127>>2]|0;
      $165 = Math_fround(HEAPF32[$164>>2]);
      $166 = Math_fround($161 * $165);
      $167 = (($164) + 4|0);
      $168 = Math_fround(HEAPF32[$167>>2]);
      $169 = Math_fround($162 * $168);
      $170 = Math_fround($166 + $169);
      $171 = (($164) + 8|0);
      $172 = Math_fround(HEAPF32[$171>>2]);
      $173 = Math_fround($163 * $172);
      $174 = Math_fround($170 + $173);
      $175 = (($164) + 16|0);
      $176 = Math_fround(HEAPF32[$175>>2]);
      $177 = Math_fround($161 * $176);
      $178 = (($164) + 20|0);
      $179 = Math_fround(HEAPF32[$178>>2]);
      $180 = Math_fround($162 * $179);
      $181 = Math_fround($177 + $180);
      $182 = (($164) + 24|0);
      $183 = Math_fround(HEAPF32[$182>>2]);
      $184 = Math_fround($163 * $183);
      $185 = Math_fround($181 + $184);
      $186 = (($164) + 32|0);
      $187 = Math_fround(HEAPF32[$186>>2]);
      $188 = Math_fround($161 * $187);
      $189 = (($164) + 36|0);
      $190 = Math_fround(HEAPF32[$189>>2]);
      $191 = Math_fround($162 * $190);
      $192 = Math_fround($188 + $191);
      $193 = (($164) + 40|0);
      $194 = Math_fround(HEAPF32[$193>>2]);
      $195 = Math_fround($163 * $194);
      $196 = Math_fround($192 + $195);
      $197 = Math_fround($116 * $196);
      $198 = Math_fround($119 * $185);
      $199 = Math_fround($197 - $198);
      $200 = Math_fround($119 * $174);
      $201 = Math_fround($113 * $196);
      $202 = Math_fround($200 - $201);
      $203 = Math_fround($113 * $185);
      $204 = Math_fround($116 * $174);
      $205 = Math_fround($203 - $204);
      $206 = Math_fround($199 * $199);
      $207 = Math_fround($202 * $202);
      $208 = Math_fround($206 + $207);
      $209 = Math_fround($205 * $205);
      $210 = Math_fround($209 + $208);
      $211 = (Math_fround(Math_sqrt((Math_fround($210)))));
      $212 = Math_fround(Math_fround(1.0) / $211);
      $213 = Math_fround($212 * $199);
      $214 = Math_fround($212 * $202);
      $215 = Math_fround($205 * $212);
      HEAPF32[$normal>>2] = $213;
      HEAPF32[$128>>2] = $214;
      HEAPF32[$129>>2] = $215;
      HEAPF32[$130>>2] = Math_fround(0.0);
      $216 = HEAP32[$map>>2]|0;
      $217 = (($216) + 12|0);
      $218 = HEAP32[$217>>2]|0;
      FUNCTION_TABLE_viiii[$218 & 511]($map,$normal,$min0,$max0);
      $219 = Math_fround(HEAPF32[$110>>2]);
      $220 = Math_fround(HEAPF32[$111>>2]);
      $221 = Math_fround(HEAPF32[$112>>2]);
      $222 = Math_fround(HEAPF32[$normal>>2]);
      $223 = Math_fround(HEAPF32[$128>>2]);
      $224 = Math_fround(HEAPF32[$129>>2]);
      $225 = Math_fround($219 * $222);
      $226 = Math_fround($220 * $223);
      $227 = Math_fround($225 + $226);
      $228 = Math_fround($221 * $224);
      $229 = Math_fround($227 + $228);
      $230 = Math_fround(HEAPF32[$107>>2]);
      $231 = Math_fround(HEAPF32[$108>>2]);
      $232 = Math_fround(HEAPF32[$109>>2]);
      $233 = Math_fround($222 * $230);
      $234 = Math_fround($223 * $231);
      $235 = Math_fround($233 + $234);
      $236 = Math_fround($224 * $232);
      $237 = Math_fround($235 + $236);
      $238 = $229 > $237;
      $$$i41 = $238 ? $237 : $229;
      $239 = Math_fround(HEAPF32[$131>>2]);
      $240 = Math_fround($$$i41 - $239);
      $241 = Math_fround(HEAPF32[$max0>>2]);
      $242 = Math_fround(HEAPF32[$contactDist>>2]);
      $243 = Math_fround($241 + $242);
      $244 = $240 > $243;
      if ($244) {
       $$0 = 0;
       label = 22;
       break L17;
      }
      $$$i = $238 ? $229 : $237;
      $245 = Math_fround($239 + $$$i);
      $246 = Math_fround($242 + $245);
      $247 = Math_fround(HEAPF32[$min0>>2]);
      $248 = $247 > $246;
      if ($248) {
       $$0 = 0;
       label = 22;
       break L17;
      }
      $249 = Math_fround($241 - $240);
      $250 = $251 > $249;
      if ($250) {
       ;HEAP32[$_minOverlap$sroa$1+0>>2]=HEAP32[$tempOverlap6$sroa$1+0>>2]|0;HEAP32[$_minOverlap$sroa$1+4>>2]=HEAP32[$tempOverlap6$sroa$1+4>>2]|0;HEAP32[$_minOverlap$sroa$1+8>>2]=HEAP32[$tempOverlap6$sroa$1+8>>2]|0;
       $252 = Math_fround(HEAPF32[$130>>2]);
       $281 = $249;$282 = $252;$283 = $224;$284 = $223;$285 = $222;
      } else {
       $281 = $251;$282 = $280;$283 = $279;$284 = $278;$285 = $277;
      }
      $253 = (($lStart$0570) + 1)|0;
      $254 = HEAP8[$137>>0]|0;
      $255 = $254&255;
      $256 = ($253>>>0)<($255>>>0);
      if ($256) {
       $lEnd$0571$phi = $lStart$0570;$251 = $281;$277 = $285;$278 = $284;$279 = $283;$280 = $282;$lStart$0570 = $253;$lEnd$0571 = $lEnd$0571$phi;
      } else {
       break;
      }
     }
     $$pre = HEAP32[$0>>2]|0;
     $$lcssa = $281;$$lcssa562 = $282;$$lcssa564 = $283;$$lcssa566 = $284;$$lcssa568 = $285;$259 = $$pre;
    }
    $257 = (($i1$0586) + 1)|0;
    $258 = ($257>>>0)<($259>>>0);
    if ($258) {
     $271 = $259;$272 = $$lcssa568;$273 = $$lcssa566;$274 = $$lcssa564;$275 = $$lcssa562;$276 = $$lcssa;$i1$0586 = $257;
    } else {
     $$lcssa576 = $$lcssa;$$lcssa578 = $$lcssa562;$$lcssa580 = $$lcssa564;$$lcssa582 = $$lcssa566;$$lcssa584 = $$lcssa568;$$pre$phiZ2D = $_minOverlap$sroa$1;
     break L15;
    }
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAPF32[$seperatingAxis>>2] = $$lcssa584;
 $260 = (($seperatingAxis) + 4|0);
 HEAPF32[$260>>2] = $$lcssa582;
 $261 = (($seperatingAxis) + 8|0);
 HEAPF32[$261>>2] = $$lcssa580;
 $262 = (($seperatingAxis) + 12|0);
 HEAPF32[$262>>2] = $$lcssa578;
 HEAPF32[$minOverlap>>2] = $$lcssa576;
 $263 = (($minOverlap) + 4|0);
 ;HEAP32[$263+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$263+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$263+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu27generateFullContactManifoldERKNS0_8CapsuleVERNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNS9_6FloatVERNS9_5Vec3VEb($capsule,$polyData,$map,$aToB,$manifoldContacts,$numContacts,$contactDist,$normal,$doOverlapTest) {
 $capsule = $capsule|0;
 $polyData = $polyData|0;
 $map = $map|0;
 $aToB = $aToB|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $normal = $normal|0;
 $doOverlapTest = $doOverlapTest|0;
 var $$0 = 0, $$demorgan$i$i = 0, $$demorgan$i39$i = 0, $$phi$trans$insert203$i = 0, $$phi$trans$insert205$i = 0, $$phi$trans$insert207$i = 0, $$phi$trans$insert209$i = 0, $$phi$trans$insert211$i = 0, $$phi$trans$insert213$i = 0, $$phi$trans$insert215$i = 0, $$phi$trans$insert217$i = 0, $$pre$i = 0, $$pre202$i = Math_fround(0), $$pre204$i = Math_fround(0), $$pre206$i = Math_fround(0), $$pre208$i = Math_fround(0), $$pre210$i = Math_fround(0), $$pre212$i = Math_fround(0), $$pre214$i = Math_fround(0), $$pre216$i = Math_fround(0);
 var $$pre218$i = Math_fround(0), $$pre219$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0;
 var $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0;
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0);
 var $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0);
 var $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0);
 var $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0);
 var $99 = Math_fround(0), $fabsf$i$i$i$i$i = Math_fround(0), $fabsf$i$i$i$i38$i = Math_fround(0), $k$0215$i$i = 0, $k$0215$i37$i = 0, $minOverlap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $minOverlap = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$numContacts>>2]|0;
 if ($doOverlapTest) {
  $2 = (__ZN5physx2GuL18testSATCapsulePolyERKNS0_8CapsuleVERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSB_RNSA_5Vec3VE($capsule,$polyData,$map,$contactDist,$minOverlap,$normal)|0);
  if (!($2)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $3 = (($capsule) + 128|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$contactDist>>2]);
 $6 = Math_fround($4 + $5);
 $7 = Math_fround(HEAPF32[$normal>>2]);
 $8 = (($normal) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($normal) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(-$7);
 $13 = Math_fround(-$9);
 $14 = Math_fround(-$11);
 $15 = (($map) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $12);
 $19 = (($16) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $13);
 $22 = Math_fround($18 + $21);
 $23 = (($16) + 32|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 * $14);
 $26 = Math_fround($22 + $25);
 $27 = (($16) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $12);
 $30 = (($16) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $13);
 $33 = Math_fround($29 + $32);
 $34 = (($16) + 36|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * $14);
 $37 = Math_fround($33 + $36);
 $38 = (($16) + 8|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $12);
 $41 = (($16) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($42 * $13);
 $44 = Math_fround($40 + $43);
 $45 = (($16) + 40|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 * $14);
 $48 = Math_fround($44 + $47);
 $49 = (($capsule) + 96|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($capsule) + 100|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($capsule) + 104|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($17 * $50);
 $56 = Math_fround($20 * $52);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($24 * $54);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($28 * $50);
 $61 = Math_fround($31 * $52);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($35 * $54);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($39 * $50);
 $66 = Math_fround($42 * $52);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($46 * $54);
 $69 = Math_fround($67 + $68);
 $70 = (($polyData) + 16|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0);
 L5: do {
  if ($72) {
   $112 = Math_fround(0.0);
   label = 10;
  } else {
   $73 = (($polyData) + 24|0);
   $74 = HEAP32[$73>>2]|0;
   $102 = Math_fround(0.0);$105 = Math_fround(1.0);$k$0215$i37$i = 0;
   while(1) {
    $77 = (($74) + (($k$0215$i37$i*20)|0)|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = ((($74) + (($k$0215$i37$i*20)|0)|0) + 4|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = ((($74) + (($k$0215$i37$i*20)|0)|0) + 8|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = ((($74) + (($k$0215$i37$i*20)|0)|0) + 12|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = Math_fround($26 * $78);
    $86 = Math_fround($37 * $80);
    $87 = Math_fround($85 + $86);
    $88 = Math_fround($48 * $82);
    $89 = Math_fround($87 + $88);
    $90 = Math_fround($59 * $78);
    $91 = Math_fround($64 * $80);
    $92 = Math_fround($90 + $91);
    $93 = Math_fround($69 * $82);
    $94 = Math_fround($92 + $93);
    $95 = Math_fround($84 + $94);
    $fabsf$i$i$i$i38$i = (Math_fround(Math_abs((Math_fround($89)))));
    $96 = $fabsf$i$i$i$i38$i < Math_fround(1.00000001168609742308E-7);
    if ($96) {
     $97 = $95 > Math_fround(0.0);
     if ($97) {
      $189 = $17;$191 = $20;$194 = $24;$197 = $28;$199 = $31;$202 = $35;$205 = $39;$207 = $42;$210 = $46;$213 = $71;
      break L5;
     } else {
      $109 = $102;$110 = $105;
     }
    } else {
     $98 = Math_fround($95 / $89);
     $99 = Math_fround(-$98);
     $100 = $89 < Math_fround(0.0);
     $101 = $102 < $99;
     $$demorgan$i39$i = $101 & $100;
     $103 = $$demorgan$i39$i ? $99 : $102;
     $104 = !($105 > $99);
     $106 = $100 | $104;
     $107 = $106 ? $105 : $99;
     $109 = $103;$110 = $107;
    }
    $108 = $109 > $110;
    $76 = (($k$0215$i37$i) + 1)|0;
    if ($108) {
     $189 = $17;$191 = $20;$194 = $24;$197 = $28;$199 = $31;$202 = $35;$205 = $39;$207 = $42;$210 = $46;$213 = $71;
     break L5;
    }
    $75 = ($76>>>0)<($71>>>0);
    if ($75) {
     $102 = $109;$105 = $110;$k$0215$i37$i = $76;
    } else {
     $112 = $109;
     label = 10;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $111 = !($6 >= $112);
  if ($111) {
   $189 = $17;$191 = $20;$194 = $24;$197 = $28;$199 = $31;$202 = $35;$205 = $39;$207 = $42;$210 = $46;$213 = $71;
  } else {
   $113 = HEAP32[$numContacts>>2]|0;
   $114 = (($aToB) + 48|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = (($aToB) + 52|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = (($aToB) + 56|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = Math_fround($50 - $115);
   $121 = Math_fround($52 - $117);
   $122 = Math_fround($54 - $119);
   $123 = Math_fround(HEAPF32[$aToB>>2]);
   $124 = Math_fround($120 * $123);
   $125 = (($aToB) + 4|0);
   $126 = Math_fround(HEAPF32[$125>>2]);
   $127 = Math_fround($121 * $126);
   $128 = Math_fround($124 + $127);
   $129 = (($aToB) + 8|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = Math_fround($122 * $130);
   $132 = Math_fround($128 + $131);
   $133 = (($aToB) + 16|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = Math_fround($120 * $134);
   $136 = (($aToB) + 20|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = Math_fround($121 * $137);
   $139 = Math_fround($135 + $138);
   $140 = (($aToB) + 24|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = Math_fround($122 * $141);
   $143 = Math_fround($139 + $142);
   $144 = (($aToB) + 32|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = Math_fround($120 * $145);
   $147 = (($aToB) + 36|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = Math_fround($121 * $148);
   $150 = Math_fround($146 + $149);
   $151 = (($aToB) + 40|0);
   $152 = Math_fround(HEAPF32[$151>>2]);
   $153 = Math_fround($122 * $152);
   $154 = Math_fround($150 + $153);
   $155 = (($manifoldContacts) + (($113*48)|0)|0);
   HEAPF32[$155>>2] = $132;
   $156 = ((($manifoldContacts) + (($113*48)|0)|0) + 4|0);
   HEAPF32[$156>>2] = $143;
   $157 = ((($manifoldContacts) + (($113*48)|0)|0) + 8|0);
   HEAPF32[$157>>2] = $154;
   $158 = ((($manifoldContacts) + (($113*48)|0)|0) + 12|0);
   HEAPF32[$158>>2] = Math_fround(0.0);
   $159 = HEAP32[$numContacts>>2]|0;
   $160 = Math_fround(HEAPF32[$49>>2]);
   $161 = Math_fround(HEAPF32[$51>>2]);
   $162 = Math_fround(HEAPF32[$53>>2]);
   $163 = Math_fround($112 * $12);
   $164 = Math_fround($112 * $13);
   $165 = Math_fround($112 * $14);
   $166 = Math_fround($163 + $160);
   $167 = Math_fround($164 + $161);
   $168 = Math_fround($165 + $162);
   $169 = ((($manifoldContacts) + (($159*48)|0)|0) + 16|0);
   HEAPF32[$169>>2] = $166;
   $170 = ((($manifoldContacts) + (($159*48)|0)|0) + 20|0);
   HEAPF32[$170>>2] = $167;
   $171 = ((($manifoldContacts) + (($159*48)|0)|0) + 24|0);
   HEAPF32[$171>>2] = $168;
   $172 = ((($manifoldContacts) + (($159*48)|0)|0) + 28|0);
   HEAPF32[$172>>2] = Math_fround(0.0);
   $173 = HEAP32[$numContacts>>2]|0;
   $174 = (($173) + 1)|0;
   HEAP32[$numContacts>>2] = $174;
   $175 = Math_fround(HEAPF32[$normal>>2]);
   $176 = Math_fround(HEAPF32[$8>>2]);
   $177 = Math_fround(HEAPF32[$10>>2]);
   $178 = ((($manifoldContacts) + (($173*48)|0)|0) + 32|0);
   HEAPF32[$178>>2] = $175;
   $179 = ((($manifoldContacts) + (($173*48)|0)|0) + 36|0);
   HEAPF32[$179>>2] = $176;
   $180 = ((($manifoldContacts) + (($173*48)|0)|0) + 40|0);
   HEAPF32[$180>>2] = $177;
   $181 = ((($manifoldContacts) + (($173*48)|0)|0) + 44|0);
   HEAPF32[$181>>2] = $112;
   $$pre$i = HEAP32[$15>>2]|0;
   $$pre202$i = Math_fround(HEAPF32[$$pre$i>>2]);
   $$phi$trans$insert203$i = (($$pre$i) + 16|0);
   $$pre204$i = Math_fround(HEAPF32[$$phi$trans$insert203$i>>2]);
   $$phi$trans$insert205$i = (($$pre$i) + 32|0);
   $$pre206$i = Math_fround(HEAPF32[$$phi$trans$insert205$i>>2]);
   $$phi$trans$insert207$i = (($$pre$i) + 4|0);
   $$pre208$i = Math_fround(HEAPF32[$$phi$trans$insert207$i>>2]);
   $$phi$trans$insert209$i = (($$pre$i) + 20|0);
   $$pre210$i = Math_fround(HEAPF32[$$phi$trans$insert209$i>>2]);
   $$phi$trans$insert211$i = (($$pre$i) + 36|0);
   $$pre212$i = Math_fround(HEAPF32[$$phi$trans$insert211$i>>2]);
   $$phi$trans$insert213$i = (($$pre$i) + 8|0);
   $$pre214$i = Math_fround(HEAPF32[$$phi$trans$insert213$i>>2]);
   $$phi$trans$insert215$i = (($$pre$i) + 24|0);
   $$pre216$i = Math_fround(HEAPF32[$$phi$trans$insert215$i>>2]);
   $$phi$trans$insert217$i = (($$pre$i) + 40|0);
   $$pre218$i = Math_fround(HEAPF32[$$phi$trans$insert217$i>>2]);
   $$pre219$i = HEAP32[$70>>2]|0;
   $189 = $$pre202$i;$191 = $$pre204$i;$194 = $$pre206$i;$197 = $$pre208$i;$199 = $$pre210$i;$202 = $$pre212$i;$205 = $$pre214$i;$207 = $$pre216$i;$210 = $$pre218$i;$213 = $$pre219$i;
  }
 }
 $182 = (($capsule) + 112|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = (($capsule) + 116|0);
 $185 = Math_fround(HEAPF32[$184>>2]);
 $186 = (($capsule) + 120|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = Math_fround($189 * $183);
 $190 = Math_fround($191 * $185);
 $192 = Math_fround($188 + $190);
 $193 = Math_fround($194 * $187);
 $195 = Math_fround($192 + $193);
 $196 = Math_fround($197 * $183);
 $198 = Math_fround($199 * $185);
 $200 = Math_fround($196 + $198);
 $201 = Math_fround($202 * $187);
 $203 = Math_fround($200 + $201);
 $204 = Math_fround($205 * $183);
 $206 = Math_fround($207 * $185);
 $208 = Math_fround($204 + $206);
 $209 = Math_fround($210 * $187);
 $211 = Math_fround($208 + $209);
 $212 = ($213|0)==(0);
 L18: do {
  if ($212) {
   $253 = Math_fround(0.0);
   label = 19;
  } else {
   $214 = (($polyData) + 24|0);
   $215 = HEAP32[$214>>2]|0;
   $243 = Math_fround(0.0);$246 = Math_fround(1.0);$k$0215$i$i = 0;
   while(1) {
    $218 = (($215) + (($k$0215$i$i*20)|0)|0);
    $219 = Math_fround(HEAPF32[$218>>2]);
    $220 = ((($215) + (($k$0215$i$i*20)|0)|0) + 4|0);
    $221 = Math_fround(HEAPF32[$220>>2]);
    $222 = ((($215) + (($k$0215$i$i*20)|0)|0) + 8|0);
    $223 = Math_fround(HEAPF32[$222>>2]);
    $224 = ((($215) + (($k$0215$i$i*20)|0)|0) + 12|0);
    $225 = Math_fround(HEAPF32[$224>>2]);
    $226 = Math_fround($26 * $219);
    $227 = Math_fround($37 * $221);
    $228 = Math_fround($226 + $227);
    $229 = Math_fround($48 * $223);
    $230 = Math_fround($228 + $229);
    $231 = Math_fround($195 * $219);
    $232 = Math_fround($203 * $221);
    $233 = Math_fround($231 + $232);
    $234 = Math_fround($211 * $223);
    $235 = Math_fround($233 + $234);
    $236 = Math_fround($225 + $235);
    $fabsf$i$i$i$i$i = (Math_fround(Math_abs((Math_fround($230)))));
    $237 = $fabsf$i$i$i$i$i < Math_fround(1.00000001168609742308E-7);
    if ($237) {
     $238 = $236 > Math_fround(0.0);
     if ($238) {
      break L18;
     } else {
      $250 = $243;$251 = $246;
     }
    } else {
     $239 = Math_fround($236 / $230);
     $240 = Math_fround(-$239);
     $241 = $230 < Math_fround(0.0);
     $242 = $243 < $240;
     $$demorgan$i$i = $242 & $241;
     $244 = $$demorgan$i$i ? $240 : $243;
     $245 = !($246 > $240);
     $247 = $241 | $245;
     $248 = $247 ? $246 : $240;
     $250 = $244;$251 = $248;
    }
    $249 = $250 > $251;
    $217 = (($k$0215$i$i) + 1)|0;
    if ($249) {
     break L18;
    }
    $216 = ($217>>>0)<($213>>>0);
    if ($216) {
     $243 = $250;$246 = $251;$k$0215$i$i = $217;
    } else {
     $253 = $250;
     label = 19;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $252 = !($6 >= $253);
  if (!($252)) {
   $254 = HEAP32[$numContacts>>2]|0;
   $255 = (($aToB) + 48|0);
   $256 = Math_fround(HEAPF32[$255>>2]);
   $257 = (($aToB) + 52|0);
   $258 = Math_fround(HEAPF32[$257>>2]);
   $259 = (($aToB) + 56|0);
   $260 = Math_fround(HEAPF32[$259>>2]);
   $261 = Math_fround($183 - $256);
   $262 = Math_fround($185 - $258);
   $263 = Math_fround($187 - $260);
   $264 = Math_fround(HEAPF32[$aToB>>2]);
   $265 = Math_fround($261 * $264);
   $266 = (($aToB) + 4|0);
   $267 = Math_fround(HEAPF32[$266>>2]);
   $268 = Math_fround($262 * $267);
   $269 = Math_fround($265 + $268);
   $270 = (($aToB) + 8|0);
   $271 = Math_fround(HEAPF32[$270>>2]);
   $272 = Math_fround($263 * $271);
   $273 = Math_fround($269 + $272);
   $274 = (($aToB) + 16|0);
   $275 = Math_fround(HEAPF32[$274>>2]);
   $276 = Math_fround($261 * $275);
   $277 = (($aToB) + 20|0);
   $278 = Math_fround(HEAPF32[$277>>2]);
   $279 = Math_fround($262 * $278);
   $280 = Math_fround($276 + $279);
   $281 = (($aToB) + 24|0);
   $282 = Math_fround(HEAPF32[$281>>2]);
   $283 = Math_fround($263 * $282);
   $284 = Math_fround($280 + $283);
   $285 = (($aToB) + 32|0);
   $286 = Math_fround(HEAPF32[$285>>2]);
   $287 = Math_fround($261 * $286);
   $288 = (($aToB) + 36|0);
   $289 = Math_fround(HEAPF32[$288>>2]);
   $290 = Math_fround($262 * $289);
   $291 = Math_fround($287 + $290);
   $292 = (($aToB) + 40|0);
   $293 = Math_fround(HEAPF32[$292>>2]);
   $294 = Math_fround($263 * $293);
   $295 = Math_fround($291 + $294);
   $296 = (($manifoldContacts) + (($254*48)|0)|0);
   HEAPF32[$296>>2] = $273;
   $297 = ((($manifoldContacts) + (($254*48)|0)|0) + 4|0);
   HEAPF32[$297>>2] = $284;
   $298 = ((($manifoldContacts) + (($254*48)|0)|0) + 8|0);
   HEAPF32[$298>>2] = $295;
   $299 = ((($manifoldContacts) + (($254*48)|0)|0) + 12|0);
   HEAPF32[$299>>2] = Math_fround(0.0);
   $300 = HEAP32[$numContacts>>2]|0;
   $301 = Math_fround(HEAPF32[$182>>2]);
   $302 = Math_fround(HEAPF32[$184>>2]);
   $303 = Math_fround(HEAPF32[$186>>2]);
   $304 = Math_fround($253 * $12);
   $305 = Math_fround($253 * $13);
   $306 = Math_fround($253 * $14);
   $307 = Math_fround($304 + $301);
   $308 = Math_fround($305 + $302);
   $309 = Math_fround($306 + $303);
   $310 = ((($manifoldContacts) + (($300*48)|0)|0) + 16|0);
   HEAPF32[$310>>2] = $307;
   $311 = ((($manifoldContacts) + (($300*48)|0)|0) + 20|0);
   HEAPF32[$311>>2] = $308;
   $312 = ((($manifoldContacts) + (($300*48)|0)|0) + 24|0);
   HEAPF32[$312>>2] = $309;
   $313 = ((($manifoldContacts) + (($300*48)|0)|0) + 28|0);
   HEAPF32[$313>>2] = Math_fround(0.0);
   $314 = HEAP32[$numContacts>>2]|0;
   $315 = (($314) + 1)|0;
   HEAP32[$numContacts>>2] = $315;
   $316 = Math_fround(HEAPF32[$normal>>2]);
   $317 = Math_fround(HEAPF32[$8>>2]);
   $318 = Math_fround(HEAPF32[$10>>2]);
   $319 = ((($manifoldContacts) + (($314*48)|0)|0) + 32|0);
   HEAPF32[$319>>2] = $316;
   $320 = ((($manifoldContacts) + (($314*48)|0)|0) + 36|0);
   HEAPF32[$320>>2] = $317;
   $321 = ((($manifoldContacts) + (($314*48)|0)|0) + 40|0);
   HEAPF32[$321>>2] = $318;
   $322 = ((($manifoldContacts) + (($314*48)|0)|0) + 44|0);
   HEAPF32[$322>>2] = $253;
  }
 }
 $323 = HEAP32[$numContacts>>2]|0;
 $324 = (($323) - ($1))|0;
 $325 = ($324>>>0)<(2);
 if (!($325)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $326 = Math_fround(HEAPF32[$normal>>2]);
 $327 = Math_fround(HEAPF32[$8>>2]);
 $328 = Math_fround(HEAPF32[$10>>2]);
 $329 = Math_fround(-$326);
 $330 = Math_fround(-$327);
 $331 = Math_fround(-$328);
 HEAPF32[$0>>2] = $329;
 $332 = (($0) + 4|0);
 HEAPF32[$332>>2] = $330;
 $333 = (($0) + 8|0);
 HEAPF32[$333>>2] = $331;
 $334 = (($0) + 12|0);
 HEAPF32[$334>>2] = Math_fround(0.0);
 $335 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData,$map,$0)|0);
 $336 = (($polyData) + 24|0);
 $337 = HEAP32[$336>>2]|0;
 $338 = (($337) + (($335*20)|0)|0);
 __ZN5physx2Gu27generatedContactsEEContactsERKNS0_8CapsuleVERNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalERKNS_6shdfnd3aos15PsMatTransformVEPNS0_17PersistentContactERjRKNSC_6FloatVERKNSC_5Vec3VE($capsule,$polyData,$338,$map,$aToB,$manifoldContacts,$numContacts,$contactDist,$normal);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu10computeMTDERKNS0_8CapsuleVERNS0_13PolygonalDataEPNS0_12SupportLocalERNS_6shdfnd3aos6FloatVERNS9_5Vec3VE($capsule,$polyData,$map,$penDepth,$normal) {
 $capsule = $capsule|0;
 $polyData = $polyData|0;
 $map = $map|0;
 $penDepth = $penDepth|0;
 $normal = $normal|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $contactDist = 0, $minOverlap = 0, $seperatingAxis = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $contactDist = sp + 32|0;
 $seperatingAxis = sp;
 $minOverlap = sp + 16|0;
 HEAPF32[$contactDist>>2] = Math_fround(0.0);
 $0 = (__ZN5physx2GuL18testSATCapsulePolyERKNS0_8CapsuleVERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSB_RNSA_5Vec3VE($capsule,$polyData,$map,$contactDist,$minOverlap,$seperatingAxis)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($map) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($2) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($2) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($2) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$seperatingAxis>>2]);
 $11 = (($seperatingAxis) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($seperatingAxis) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($9 * $9);
 $16 = Math_fround($15 + Math_fround(-0.5));
 $17 = Math_fround($10 * $16);
 $18 = Math_fround($16 * $12);
 $19 = Math_fround($16 * $14);
 $20 = Math_fround($5 * $14);
 $21 = Math_fround($7 * $12);
 $22 = Math_fround($20 - $21);
 $23 = Math_fround($7 * $10);
 $24 = Math_fround($3 * $14);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($3 * $12);
 $27 = Math_fround($5 * $10);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($9 * $22);
 $30 = Math_fround($9 * $25);
 $31 = Math_fround($9 * $28);
 $32 = Math_fround($17 + $29);
 $33 = Math_fround($18 + $30);
 $34 = Math_fround($19 + $31);
 $35 = Math_fround($3 * $10);
 $36 = Math_fround($5 * $12);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($7 * $14);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($3 * $39);
 $41 = Math_fround($5 * $39);
 $42 = Math_fround($7 * $39);
 $43 = Math_fround($40 + $32);
 $44 = Math_fround($41 + $33);
 $45 = Math_fround($34 + $42);
 $46 = Math_fround($43 * Math_fround(2.0));
 $47 = Math_fround($44 * Math_fround(2.0));
 $48 = Math_fround($45 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $46;
 $49 = (($normal) + 4|0);
 HEAPF32[$49>>2] = $47;
 $50 = (($normal) + 8|0);
 HEAPF32[$50>>2] = $48;
 $51 = (($normal) + 12|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 ;HEAP32[$penDepth+0>>2]=HEAP32[$minOverlap+0>>2]|0;HEAP32[$penDepth+4>>2]=HEAP32[$minOverlap+4>>2]|0;HEAP32[$penDepth+8>>2]=HEAP32[$minOverlap+8>>2]|0;HEAP32[$penDepth+12>>2]=HEAP32[$minOverlap+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu18pcmContactPlaneBoxERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$0 = 0, $$1$i$i$i$i = Math_fround(0), $$pre = 0, $$pre$phi1055Z2D = 0, $$pre$phi1057Z2D = 0, $$pre$phiZ2D = 0, $$pre1054 = 0, $$pre1056 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0);
 var $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0);
 var $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0);
 var $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0);
 var $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0);
 var $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0;
 var $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0);
 var $43 = Math_fround(0), $430 = Math_fround(0), $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = Math_fround(0);
 var $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = 0;
 var $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0);
 var $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0);
 var $501 = Math_fround(0), $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $negPlaneNormal = 0, $numContacts$0 = 0, $numContacts$1 = 0, $numContacts$2 = 0, $numContacts$3 = 0, $numContacts$4 = 0, $numContacts$5 = 0, $numContacts$6 = 0, $numContacts$7 = 0, $projectBreakingThreshold = 0, $transf1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $transf1 = sp + 96|0;
 $negPlaneNormal = sp;
 $projectBreakingThreshold = sp + 16|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$cache>>2]|0;
 $2 = $1;
 $3 = $1;
 $4 = (($3) + 256|0);
 $5 = Math_fround(HEAPF32[$transform1>>2]);
 $6 = (($transform1) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($transform1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($transform1) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($12) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$transform0>>2]);
 $19 = (($transform0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($transform0) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($25) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($25) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$transf1>>2] = $18;
 $31 = (($transf1) + 4|0);
 HEAPF32[$31>>2] = $20;
 $32 = (($transf1) + 8|0);
 HEAPF32[$32>>2] = $22;
 $33 = (($transf1) + 12|0);
 HEAPF32[$33>>2] = $24;
 $34 = (($transf1) + 16|0);
 HEAPF32[$34>>2] = $26;
 $35 = (($transf1) + 20|0);
 HEAPF32[$35>>2] = $28;
 $36 = (($transf1) + 24|0);
 HEAPF32[$36>>2] = $30;
 $37 = (($transf1) + 28|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = Math_fround(-$18);
 $39 = Math_fround(-$20);
 $40 = Math_fround(-$22);
 $41 = Math_fround($13 - $26);
 $42 = Math_fround($15 - $28);
 $43 = Math_fround($17 - $30);
 $44 = Math_fround($24 * $24);
 $45 = Math_fround($44 + Math_fround(-0.5));
 $46 = Math_fround($45 * $41);
 $47 = Math_fround($45 * $42);
 $48 = Math_fround($45 * $43);
 $49 = Math_fround($43 * $39);
 $50 = Math_fround($42 * $40);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($41 * $40);
 $53 = Math_fround($43 * $38);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($42 * $38);
 $56 = Math_fround($41 * $39);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($24 * $51);
 $59 = Math_fround($24 * $54);
 $60 = Math_fround($24 * $57);
 $61 = Math_fround($46 + $58);
 $62 = Math_fround($47 + $59);
 $63 = Math_fround($48 + $60);
 $64 = Math_fround($41 * $38);
 $65 = Math_fround($42 * $39);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($43 * $40);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($68 * $38);
 $70 = Math_fround($68 * $39);
 $71 = Math_fround($68 * $40);
 $72 = Math_fround($69 + $61);
 $73 = Math_fround($70 + $62);
 $74 = Math_fround($63 + $71);
 $75 = Math_fround($72 * Math_fround(2.0));
 $76 = Math_fround($73 * Math_fround(2.0));
 $77 = Math_fround($74 * Math_fround(2.0));
 $78 = Math_fround($11 * $24);
 $79 = Math_fround($5 * $38);
 $80 = Math_fround($7 * $39);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($9 * $40);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($78 - $83);
 $85 = Math_fround($11 * $38);
 $86 = Math_fround($11 * $39);
 $87 = Math_fround($11 * $40);
 $88 = Math_fround($5 * $24);
 $89 = Math_fround($7 * $24);
 $90 = Math_fround($9 * $24);
 $91 = Math_fround($9 * $39);
 $92 = Math_fround($7 * $40);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($5 * $40);
 $95 = Math_fround($9 * $38);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($7 * $38);
 $98 = Math_fround($5 * $39);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($85 + $88);
 $101 = Math_fround($86 + $89);
 $102 = Math_fround($90 + $87);
 $103 = Math_fround($93 + $100);
 $104 = Math_fround($96 + $101);
 $105 = Math_fround($99 + $102);
 $106 = Math_fround($18 * Math_fround(2.0));
 $107 = Math_fround($24 * Math_fround(2.0));
 $108 = Math_fround($18 * $106);
 $109 = Math_fround($106 * $20);
 $110 = Math_fround($106 * $22);
 $111 = Math_fround($24 * $107);
 $112 = Math_fround($22 * $107);
 $113 = Math_fround($20 * $107);
 $114 = Math_fround($108 + $111);
 $115 = Math_fround($109 + $112);
 $116 = Math_fround($110 - $113);
 $117 = Math_fround($114 + Math_fround(-1.0));
 $118 = Math_fround($117 * $117);
 $119 = Math_fround($115 * $115);
 $120 = Math_fround($119 + $118);
 $121 = Math_fround($116 * $116);
 $122 = Math_fround($121 + $120);
 $123 = (Math_fround(Math_sqrt((Math_fround($122)))));
 $124 = Math_fround(Math_fround(1.0) / $123);
 $125 = Math_fround($117 * $124);
 $126 = Math_fround(-$125);
 $127 = Math_fround($115 * $124);
 $128 = Math_fround(-$127);
 $129 = Math_fround($116 * $124);
 $130 = Math_fround(-$129);
 HEAPF32[$negPlaneNormal>>2] = $126;
 $131 = (($negPlaneNormal) + 4|0);
 HEAPF32[$131>>2] = $128;
 $132 = (($negPlaneNormal) + 8|0);
 HEAPF32[$132>>2] = $130;
 $133 = (($negPlaneNormal) + 12|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = Math_fround(HEAPF32[$contactDistance>>2]);
 $135 = (($shape1) + 4|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($shape1) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($shape1) + 12|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = !($136 <= $138);
 $$$i$i = $141 ? $138 : $136;
 $142 = !($$$i$i <= $140);
 $143 = $142 ? $140 : $$$i$i;
 $144 = Math_fround($143 * Math_fround(0.150000005960464477539));
 $145 = Math_fround($144 * Math_fround(0.20000000298023223877));
 HEAPF32[$projectBreakingThreshold>>2] = $145;
 $146 = (($2) + 32|0);
 $147 = HEAP8[$146>>0]|0;
 $148 = (($0) + 48|0);
 HEAPF32[$148>>2] = $75;
 $149 = (($0) + 52|0);
 HEAPF32[$149>>2] = $76;
 $150 = (($0) + 56|0);
 HEAPF32[$150>>2] = $77;
 $151 = (($0) + 60|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = Math_fround($103 + $103);
 $153 = Math_fround($104 + $104);
 $154 = Math_fround($105 + $105);
 $155 = Math_fround($103 * $152);
 $156 = Math_fround($104 * $153);
 $157 = Math_fround($105 * $154);
 $158 = Math_fround($104 * $152);
 $159 = Math_fround($105 * $152);
 $160 = Math_fround($84 * $152);
 $161 = Math_fround($105 * $153);
 $162 = Math_fround($84 * $153);
 $163 = Math_fround($84 * $154);
 $164 = Math_fround(Math_fround(1.0) - $155);
 $165 = Math_fround(Math_fround(1.0) - $156);
 $166 = Math_fround($165 - $157);
 $167 = Math_fround($158 + $163);
 $168 = Math_fround($159 - $162);
 $169 = Math_fround($158 - $163);
 $170 = Math_fround($164 - $157);
 $171 = Math_fround($161 + $160);
 $172 = Math_fround($159 + $162);
 $173 = Math_fround($161 - $160);
 $174 = Math_fround($164 - $156);
 HEAPF32[$0>>2] = $166;
 $175 = (($0) + 4|0);
 HEAPF32[$175>>2] = $167;
 $176 = (($0) + 8|0);
 HEAPF32[$176>>2] = $168;
 $177 = (($0) + 12|0);
 HEAPF32[$177>>2] = Math_fround(0.0);
 $178 = (($0) + 16|0);
 HEAPF32[$178>>2] = $169;
 $179 = (($0) + 20|0);
 HEAPF32[$179>>2] = $170;
 $180 = (($0) + 24|0);
 HEAPF32[$180>>2] = $171;
 $181 = (($0) + 28|0);
 HEAPF32[$181>>2] = Math_fround(0.0);
 $182 = (($0) + 32|0);
 HEAPF32[$182>>2] = $172;
 $183 = (($0) + 36|0);
 HEAPF32[$183>>2] = $173;
 $184 = (($0) + 40|0);
 HEAPF32[$184>>2] = $174;
 $185 = (($0) + 44|0);
 HEAPF32[$185>>2] = Math_fround(0.0);
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($2,$0,$projectBreakingThreshold,0);
 $186 = HEAP8[$146>>0]|0;
 $187 = ($186<<24>>24)==($147<<24>>24);
 if ($187) {
  $188 = $147&255;
  $189 = (554160 + ($188<<2)|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = Math_fround($144 * $190);
  $192 = (($2) + 16|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = (($2) + 20|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($2) + 24|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = Math_fround($75 - $193);
  $199 = Math_fround($76 - $195);
  $200 = Math_fround($77 - $197);
  $201 = Math_fround(-$198);
  $202 = Math_fround(-$199);
  $203 = Math_fround(-$200);
  $204 = $198 > $201;
  $$$i$i$i$i = $204 ? $198 : $201;
  $205 = $199 > $202;
  $206 = $205 ? $199 : $202;
  $207 = $200 > $203;
  $$1$i$i$i$i = $207 ? $200 : $203;
  $208 = !($$$i$i$i$i >= $206);
  $$$i$i$i = $208 ? $206 : $$$i$i$i$i;
  $209 = !($$1$i$i$i$i >= Math_fround(0.0));
  $210 = $209 ? Math_fround(0.0) : $$$i$i$i$i;
  $211 = $$$i$i$i >= $210;
  $212 = $211 ? $$$i$i$i : $210;
  $213 = $212 > $191;
  if ($213) {
   $$pre$phi1055Z2D = $194;$$pre$phi1057Z2D = $196;$$pre$phiZ2D = $192;
  } else {
   $214 = (($2) + 4|0);
   $215 = (($2) + 8|0);
   $216 = Math_fround(HEAPF32[$214>>2]);
   $217 = Math_fround(HEAPF32[$2>>2]);
   $218 = Math_fround($104 * $216);
   $219 = Math_fround($103 * $217);
   $220 = (($2) + 12|0);
   $221 = Math_fround(HEAPF32[$215>>2]);
   $222 = Math_fround($105 * $221);
   $223 = Math_fround($218 + $219);
   $224 = Math_fround(HEAPF32[$220>>2]);
   $225 = Math_fround($84 * $224);
   $226 = Math_fround($223 + $222);
   $227 = (554200 + ($188<<2)|0);
   $228 = Math_fround($226 + $225);
   $229 = Math_fround(HEAPF32[$227>>2]);
   $230 = $229 > $228;
   if ($230) {
    $$pre$phi1055Z2D = $194;$$pre$phi1057Z2D = $196;$$pre$phiZ2D = $192;
   } else {
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($2,$contactBuffer,$negPlaneNormal,$transf1);
    $$sink = HEAP8[$146>>0]|0;
    $$0 = ($$sink<<24>>24)!=(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } else {
  $$pre = (($2) + 16|0);
  $$pre1054 = (($2) + 20|0);
  $$pre1056 = (($2) + 24|0);
  $$pre$phi1055Z2D = $$pre1054;$$pre$phi1057Z2D = $$pre1056;$$pre$phiZ2D = $$pre;
 }
 HEAP8[$146>>0] = 0;
 HEAPF32[$2>>2] = $103;
 $231 = (($2) + 4|0);
 HEAPF32[$231>>2] = $104;
 $232 = (($2) + 8|0);
 HEAPF32[$232>>2] = $105;
 $233 = (($2) + 12|0);
 HEAPF32[$233>>2] = $84;
 HEAPF32[$$pre$phiZ2D>>2] = $75;
 HEAPF32[$$pre$phi1055Z2D>>2] = $76;
 HEAPF32[$$pre$phi1057Z2D>>2] = $77;
 $234 = (($2) + 28|0);
 HEAPF32[$234>>2] = Math_fround(0.0);
 $235 = Math_fround(-$136);
 $236 = Math_fround(-$138);
 $237 = Math_fround(-$140);
 $238 = Math_fround($166 * $136);
 $239 = Math_fround($167 * $136);
 $240 = Math_fround($168 * $136);
 $241 = Math_fround($169 * $138);
 $242 = Math_fround($170 * $138);
 $243 = Math_fround($171 * $138);
 $244 = Math_fround($172 * $140);
 $245 = Math_fround($173 * $140);
 $246 = Math_fround($174 * $140);
 $247 = Math_fround(-$244);
 $248 = Math_fround($238 + $241);
 $249 = Math_fround($239 + $242);
 $250 = Math_fround($240 + $243);
 $251 = Math_fround($238 - $241);
 $252 = Math_fround($244 + $248);
 $253 = Math_fround($248 - $244);
 $254 = Math_fround($244 + $251);
 $255 = Math_fround($251 - $244);
 $256 = Math_fround($244 - $251);
 $257 = Math_fround($247 - $251);
 $258 = Math_fround($244 - $248);
 $259 = Math_fround($247 - $248);
 $260 = Math_fround($134 - $75);
 $261 = $260 > $252;
 if ($261) {
  $262 = Math_fround($75 + $252);
  HEAPF32[$contactBuffer>>2] = $136;
  $263 = (($contactBuffer) + 4|0);
  HEAPF32[$263>>2] = $138;
  $264 = (($contactBuffer) + 8|0);
  HEAPF32[$264>>2] = $140;
  $265 = (($contactBuffer) + 12|0);
  HEAPF32[$265>>2] = Math_fround(0.0);
  $266 = Math_fround($249 + $245);
  $267 = Math_fround($250 + $246);
  $268 = Math_fround($76 + $266);
  $269 = Math_fround($77 + $267);
  $270 = Math_fround($262 * Math_fround(0.0));
  $271 = Math_fround($262 - $262);
  $272 = Math_fround($268 - $270);
  $273 = Math_fround($269 - $270);
  $274 = (($contactBuffer) + 16|0);
  HEAPF32[$274>>2] = $271;
  $275 = (($contactBuffer) + 20|0);
  HEAPF32[$275>>2] = $272;
  $276 = (($contactBuffer) + 24|0);
  HEAPF32[$276>>2] = $273;
  $277 = (($contactBuffer) + 28|0);
  HEAPF32[$277>>2] = Math_fround(0.0);
  $278 = (($contactBuffer) + 32|0);
  HEAPF32[$278>>2] = Math_fround(1.0);
  $279 = (($contactBuffer) + 36|0);
  HEAPF32[$279>>2] = Math_fround(0.0);
  $280 = (($contactBuffer) + 40|0);
  HEAPF32[$280>>2] = Math_fround(0.0);
  $281 = (($contactBuffer) + 44|0);
  HEAPF32[$281>>2] = $262;
  $numContacts$0 = 1;
 } else {
  $numContacts$0 = 0;
 }
 $282 = $260 > $253;
 if ($282) {
  $283 = Math_fround($75 + $253);
  $284 = (($contactBuffer) + (($numContacts$0*48)|0)|0);
  HEAPF32[$284>>2] = $136;
  $285 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 4|0);
  HEAPF32[$285>>2] = $138;
  $286 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 8|0);
  HEAPF32[$286>>2] = $237;
  $287 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 12|0);
  HEAPF32[$287>>2] = Math_fround(0.0);
  $288 = Math_fround($172 * $237);
  $289 = Math_fround($248 + $288);
  $290 = Math_fround($173 * $237);
  $291 = Math_fround($249 + $290);
  $292 = Math_fround($174 * $237);
  $293 = Math_fround($250 + $292);
  $294 = Math_fround($75 + $289);
  $295 = Math_fround($76 + $291);
  $296 = Math_fround($77 + $293);
  $297 = Math_fround($283 * Math_fround(0.0));
  $298 = Math_fround($294 - $283);
  $299 = Math_fround($295 - $297);
  $300 = Math_fround($296 - $297);
  $301 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 16|0);
  HEAPF32[$301>>2] = $298;
  $302 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 20|0);
  HEAPF32[$302>>2] = $299;
  $303 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 24|0);
  HEAPF32[$303>>2] = $300;
  $304 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 28|0);
  HEAPF32[$304>>2] = Math_fround(0.0);
  $305 = (($numContacts$0) + 1)|0;
  $306 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 32|0);
  HEAPF32[$306>>2] = Math_fround(1.0);
  $307 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 36|0);
  HEAPF32[$307>>2] = Math_fround(0.0);
  $308 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 40|0);
  HEAPF32[$308>>2] = Math_fround(0.0);
  $309 = ((($contactBuffer) + (($numContacts$0*48)|0)|0) + 44|0);
  HEAPF32[$309>>2] = $283;
  $numContacts$1 = $305;
 } else {
  $numContacts$1 = $numContacts$0;
 }
 $310 = $260 > $254;
 if ($310) {
  $311 = Math_fround($75 + $254);
  $312 = (($contactBuffer) + (($numContacts$1*48)|0)|0);
  HEAPF32[$312>>2] = $136;
  $313 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 4|0);
  HEAPF32[$313>>2] = $236;
  $314 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 8|0);
  HEAPF32[$314>>2] = $140;
  $315 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 12|0);
  HEAPF32[$315>>2] = Math_fround(0.0);
  $316 = Math_fround($169 * $236);
  $317 = Math_fround($238 + $316);
  $318 = Math_fround($244 + $317);
  $319 = Math_fround($170 * $236);
  $320 = Math_fround($239 + $319);
  $321 = Math_fround($245 + $320);
  $322 = Math_fround($171 * $236);
  $323 = Math_fround($240 + $322);
  $324 = Math_fround($246 + $323);
  $325 = Math_fround($75 + $318);
  $326 = Math_fround($76 + $321);
  $327 = Math_fround($77 + $324);
  $328 = Math_fround($311 * Math_fround(0.0));
  $329 = Math_fround($325 - $311);
  $330 = Math_fround($326 - $328);
  $331 = Math_fround($327 - $328);
  $332 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 16|0);
  HEAPF32[$332>>2] = $329;
  $333 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 20|0);
  HEAPF32[$333>>2] = $330;
  $334 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 24|0);
  HEAPF32[$334>>2] = $331;
  $335 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 28|0);
  HEAPF32[$335>>2] = Math_fround(0.0);
  $336 = (($numContacts$1) + 1)|0;
  $337 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 32|0);
  HEAPF32[$337>>2] = Math_fround(1.0);
  $338 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 36|0);
  HEAPF32[$338>>2] = Math_fround(0.0);
  $339 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 40|0);
  HEAPF32[$339>>2] = Math_fround(0.0);
  $340 = ((($contactBuffer) + (($numContacts$1*48)|0)|0) + 44|0);
  HEAPF32[$340>>2] = $311;
  $numContacts$2 = $336;
 } else {
  $numContacts$2 = $numContacts$1;
 }
 $341 = $260 > $255;
 if ($341) {
  $342 = Math_fround($75 + $255);
  $343 = (($contactBuffer) + (($numContacts$2*48)|0)|0);
  HEAPF32[$343>>2] = $136;
  $344 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 4|0);
  HEAPF32[$344>>2] = $236;
  $345 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 8|0);
  HEAPF32[$345>>2] = $237;
  $346 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 12|0);
  HEAPF32[$346>>2] = Math_fround(0.0);
  $347 = Math_fround($169 * $236);
  $348 = Math_fround($238 + $347);
  $349 = Math_fround($172 * $237);
  $350 = Math_fround($348 + $349);
  $351 = Math_fround($170 * $236);
  $352 = Math_fround($239 + $351);
  $353 = Math_fround($173 * $237);
  $354 = Math_fround($352 + $353);
  $355 = Math_fround($171 * $236);
  $356 = Math_fround($240 + $355);
  $357 = Math_fround($174 * $237);
  $358 = Math_fround($356 + $357);
  $359 = Math_fround($75 + $350);
  $360 = Math_fround($76 + $354);
  $361 = Math_fround($77 + $358);
  $362 = Math_fround($342 * Math_fround(0.0));
  $363 = Math_fround($359 - $342);
  $364 = Math_fround($360 - $362);
  $365 = Math_fround($361 - $362);
  $366 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 16|0);
  HEAPF32[$366>>2] = $363;
  $367 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 20|0);
  HEAPF32[$367>>2] = $364;
  $368 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 24|0);
  HEAPF32[$368>>2] = $365;
  $369 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 28|0);
  HEAPF32[$369>>2] = Math_fround(0.0);
  $370 = (($numContacts$2) + 1)|0;
  $371 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 32|0);
  HEAPF32[$371>>2] = Math_fround(1.0);
  $372 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 36|0);
  HEAPF32[$372>>2] = Math_fround(0.0);
  $373 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 40|0);
  HEAPF32[$373>>2] = Math_fround(0.0);
  $374 = ((($contactBuffer) + (($numContacts$2*48)|0)|0) + 44|0);
  HEAPF32[$374>>2] = $342;
  $numContacts$3 = $370;
 } else {
  $numContacts$3 = $numContacts$2;
 }
 $375 = $260 > $256;
 if ($375) {
  $376 = Math_fround($75 + $256);
  $377 = (($contactBuffer) + (($numContacts$3*48)|0)|0);
  HEAPF32[$377>>2] = $235;
  $378 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 4|0);
  HEAPF32[$378>>2] = $138;
  $379 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 8|0);
  HEAPF32[$379>>2] = $140;
  $380 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 12|0);
  HEAPF32[$380>>2] = Math_fround(0.0);
  $381 = Math_fround($166 * $235);
  $382 = Math_fround($381 + $241);
  $383 = Math_fround($382 + $244);
  $384 = Math_fround($167 * $235);
  $385 = Math_fround($384 + $242);
  $386 = Math_fround($385 + $245);
  $387 = Math_fround($168 * $235);
  $388 = Math_fround($387 + $243);
  $389 = Math_fround($388 + $246);
  $390 = Math_fround($75 + $383);
  $391 = Math_fround($76 + $386);
  $392 = Math_fround($77 + $389);
  $393 = Math_fround($376 * Math_fround(0.0));
  $394 = Math_fround($390 - $376);
  $395 = Math_fround($391 - $393);
  $396 = Math_fround($392 - $393);
  $397 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 16|0);
  HEAPF32[$397>>2] = $394;
  $398 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 20|0);
  HEAPF32[$398>>2] = $395;
  $399 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 24|0);
  HEAPF32[$399>>2] = $396;
  $400 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 28|0);
  HEAPF32[$400>>2] = Math_fround(0.0);
  $401 = (($numContacts$3) + 1)|0;
  $402 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 32|0);
  HEAPF32[$402>>2] = Math_fround(1.0);
  $403 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 36|0);
  HEAPF32[$403>>2] = Math_fround(0.0);
  $404 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 40|0);
  HEAPF32[$404>>2] = Math_fround(0.0);
  $405 = ((($contactBuffer) + (($numContacts$3*48)|0)|0) + 44|0);
  HEAPF32[$405>>2] = $376;
  $numContacts$4 = $401;
 } else {
  $numContacts$4 = $numContacts$3;
 }
 $406 = $260 > $257;
 if ($406) {
  $407 = Math_fround($75 + $257);
  $408 = (($contactBuffer) + (($numContacts$4*48)|0)|0);
  HEAPF32[$408>>2] = $235;
  $409 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 4|0);
  HEAPF32[$409>>2] = $138;
  $410 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 8|0);
  HEAPF32[$410>>2] = $237;
  $411 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 12|0);
  HEAPF32[$411>>2] = Math_fround(0.0);
  $412 = Math_fround($166 * $235);
  $413 = Math_fround($412 + $241);
  $414 = Math_fround($172 * $237);
  $415 = Math_fround($413 + $414);
  $416 = Math_fround($167 * $235);
  $417 = Math_fround($416 + $242);
  $418 = Math_fround($173 * $237);
  $419 = Math_fround($417 + $418);
  $420 = Math_fround($168 * $235);
  $421 = Math_fround($420 + $243);
  $422 = Math_fround($174 * $237);
  $423 = Math_fround($421 + $422);
  $424 = Math_fround($75 + $415);
  $425 = Math_fround($76 + $419);
  $426 = Math_fround($77 + $423);
  $427 = Math_fround($407 * Math_fround(0.0));
  $428 = Math_fround($424 - $407);
  $429 = Math_fround($425 - $427);
  $430 = Math_fround($426 - $427);
  $431 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 16|0);
  HEAPF32[$431>>2] = $428;
  $432 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 20|0);
  HEAPF32[$432>>2] = $429;
  $433 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 24|0);
  HEAPF32[$433>>2] = $430;
  $434 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 28|0);
  HEAPF32[$434>>2] = Math_fround(0.0);
  $435 = (($numContacts$4) + 1)|0;
  $436 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 32|0);
  HEAPF32[$436>>2] = Math_fround(1.0);
  $437 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 36|0);
  HEAPF32[$437>>2] = Math_fround(0.0);
  $438 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 40|0);
  HEAPF32[$438>>2] = Math_fround(0.0);
  $439 = ((($contactBuffer) + (($numContacts$4*48)|0)|0) + 44|0);
  HEAPF32[$439>>2] = $407;
  $numContacts$5 = $435;
 } else {
  $numContacts$5 = $numContacts$4;
 }
 $440 = $260 > $258;
 if ($440) {
  $441 = Math_fround($75 + $258);
  $442 = (($contactBuffer) + (($numContacts$5*48)|0)|0);
  HEAPF32[$442>>2] = $235;
  $443 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 4|0);
  HEAPF32[$443>>2] = $236;
  $444 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 8|0);
  HEAPF32[$444>>2] = $140;
  $445 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 12|0);
  HEAPF32[$445>>2] = Math_fround(0.0);
  $446 = Math_fround($166 * $235);
  $447 = Math_fround($169 * $236);
  $448 = Math_fround($446 + $447);
  $449 = Math_fround($244 + $448);
  $450 = Math_fround($167 * $235);
  $451 = Math_fround($170 * $236);
  $452 = Math_fround($450 + $451);
  $453 = Math_fround($245 + $452);
  $454 = Math_fround($168 * $235);
  $455 = Math_fround($171 * $236);
  $456 = Math_fround($454 + $455);
  $457 = Math_fround($246 + $456);
  $458 = Math_fround($75 + $449);
  $459 = Math_fround($76 + $453);
  $460 = Math_fround($77 + $457);
  $461 = Math_fround($441 * Math_fround(0.0));
  $462 = Math_fround($458 - $441);
  $463 = Math_fround($459 - $461);
  $464 = Math_fround($460 - $461);
  $465 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 16|0);
  HEAPF32[$465>>2] = $462;
  $466 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 20|0);
  HEAPF32[$466>>2] = $463;
  $467 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 24|0);
  HEAPF32[$467>>2] = $464;
  $468 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 28|0);
  HEAPF32[$468>>2] = Math_fround(0.0);
  $469 = (($numContacts$5) + 1)|0;
  $470 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 32|0);
  HEAPF32[$470>>2] = Math_fround(1.0);
  $471 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 36|0);
  HEAPF32[$471>>2] = Math_fround(0.0);
  $472 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 40|0);
  HEAPF32[$472>>2] = Math_fround(0.0);
  $473 = ((($contactBuffer) + (($numContacts$5*48)|0)|0) + 44|0);
  HEAPF32[$473>>2] = $441;
  $numContacts$6 = $469;
 } else {
  $numContacts$6 = $numContacts$5;
 }
 $474 = $260 > $259;
 if ($474) {
  $475 = Math_fround($75 + $259);
  $476 = (($contactBuffer) + (($numContacts$6*48)|0)|0);
  HEAPF32[$476>>2] = $235;
  $477 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 4|0);
  HEAPF32[$477>>2] = $236;
  $478 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 8|0);
  HEAPF32[$478>>2] = $237;
  $479 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 12|0);
  HEAPF32[$479>>2] = Math_fround(0.0);
  $480 = Math_fround($166 * $235);
  $481 = Math_fround($169 * $236);
  $482 = Math_fround($480 + $481);
  $483 = Math_fround($172 * $237);
  $484 = Math_fround($482 + $483);
  $485 = Math_fround($167 * $235);
  $486 = Math_fround($170 * $236);
  $487 = Math_fround($485 + $486);
  $488 = Math_fround($173 * $237);
  $489 = Math_fround($487 + $488);
  $490 = Math_fround($168 * $235);
  $491 = Math_fround($171 * $236);
  $492 = Math_fround($490 + $491);
  $493 = Math_fround($174 * $237);
  $494 = Math_fround($492 + $493);
  $495 = Math_fround($75 + $484);
  $496 = Math_fround($76 + $489);
  $497 = Math_fround($77 + $494);
  $498 = Math_fround($475 * Math_fround(0.0));
  $499 = Math_fround($495 - $475);
  $500 = Math_fround($496 - $498);
  $501 = Math_fround($497 - $498);
  $502 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 16|0);
  HEAPF32[$502>>2] = $499;
  $503 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 20|0);
  HEAPF32[$503>>2] = $500;
  $504 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 24|0);
  HEAPF32[$504>>2] = $501;
  $505 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 28|0);
  HEAPF32[$505>>2] = Math_fround(0.0);
  $506 = (($numContacts$6) + 1)|0;
  $507 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 32|0);
  HEAPF32[$507>>2] = Math_fround(1.0);
  $508 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 36|0);
  HEAPF32[$508>>2] = Math_fround(0.0);
  $509 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 40|0);
  HEAPF32[$509>>2] = Math_fround(0.0);
  $510 = ((($contactBuffer) + (($numContacts$6*48)|0)|0) + 44|0);
  HEAPF32[$510>>2] = $475;
  $numContacts$7 = $506;
 } else {
  $numContacts$7 = $numContacts$6;
 }
 __ZN5physx2Gu25PersistentContactManifold31addBatchManifoldContactsClusterEPKNS0_17PersistentContactEj($2,$contactBuffer,$numContacts$7);
 __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($2,$contactBuffer,$negPlaneNormal,$transf1);
 $$sink = HEAP8[$146>>0]|0;
 $$0 = ($$sink<<24>>24)!=(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22pcmContactPlaneCapsuleERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$0 = 0, $$1$i$i$i$i = Math_fround(0), $$pre = 0, $$pre$phi275Z2D = 0, $$pre$phi277Z2D = 0, $$pre$phiZ2D = 0, $$pre274 = 0, $$pre276 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0);
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0);
 var $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0;
 var $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0);
 var $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0);
 var $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0);
 var $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0);
 var $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0);
 var $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0;
 var $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0);
 var $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0);
 var $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), $localNormalPen = 0, $localNormalPen3 = 0, $localPointA = 0, $localPointA1 = 0, $localPointB = 0, $localPointB2 = 0, $negPlaneNormal = 0, $projectBreakingThreshold = 0, $radius = 0, $replaceBreakingThreshold = 0, $transf0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $transf0 = sp + 224|0;
 $negPlaneNormal = sp + 208|0;
 $radius = sp + 192|0;
 $replaceBreakingThreshold = sp + 176|0;
 $projectBreakingThreshold = sp + 160|0;
 $0 = sp + 96|0;
 $localPointA = sp + 80|0;
 $localPointB = sp + 48|0;
 $localNormalPen = sp + 32|0;
 $localPointA1 = sp + 16|0;
 $localPointB2 = sp;
 $localNormalPen3 = sp + 64|0;
 $1 = HEAP32[$cache>>2]|0;
 $2 = $1;
 $3 = $1;
 $4 = (($3) + 256|0);
 $5 = Math_fround(HEAPF32[$transform1>>2]);
 $6 = (($transform1) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($transform1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($transform1) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($12) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$transf0>>2] = $5;
 $18 = (($transf0) + 4|0);
 HEAPF32[$18>>2] = $7;
 $19 = (($transf0) + 8|0);
 HEAPF32[$19>>2] = $9;
 $20 = (($transf0) + 12|0);
 HEAPF32[$20>>2] = $11;
 $21 = (($transf0) + 16|0);
 HEAPF32[$21>>2] = $13;
 $22 = (($transf0) + 20|0);
 HEAPF32[$22>>2] = $15;
 $23 = (($transf0) + 24|0);
 HEAPF32[$23>>2] = $17;
 $24 = (($transf0) + 28|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = Math_fround(HEAPF32[$transform0>>2]);
 $26 = (($transform0) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($transform0) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($transform0) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($transform0) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($32) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($32) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround(-$25);
 $39 = Math_fround(-$27);
 $40 = Math_fround(-$29);
 $41 = Math_fround($13 - $33);
 $42 = Math_fround($15 - $35);
 $43 = Math_fround($17 - $37);
 $44 = Math_fround($31 * $31);
 $45 = Math_fround($44 + Math_fround(-0.5));
 $46 = Math_fround($45 * $41);
 $47 = Math_fround($45 * $42);
 $48 = Math_fround($45 * $43);
 $49 = Math_fround($43 * $39);
 $50 = Math_fround($42 * $40);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($41 * $40);
 $53 = Math_fround($43 * $38);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($42 * $38);
 $56 = Math_fround($41 * $39);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($31 * $51);
 $59 = Math_fround($31 * $54);
 $60 = Math_fround($31 * $57);
 $61 = Math_fround($46 + $58);
 $62 = Math_fround($47 + $59);
 $63 = Math_fround($48 + $60);
 $64 = Math_fround($41 * $38);
 $65 = Math_fround($42 * $39);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($43 * $40);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($68 * $38);
 $70 = Math_fround($68 * $39);
 $71 = Math_fround($68 * $40);
 $72 = Math_fround($69 + $61);
 $73 = Math_fround($70 + $62);
 $74 = Math_fround($63 + $71);
 $75 = Math_fround($72 * Math_fround(2.0));
 $76 = Math_fround($73 * Math_fround(2.0));
 $77 = Math_fround($74 * Math_fround(2.0));
 $78 = Math_fround($31 * $11);
 $79 = Math_fround($5 * $38);
 $80 = Math_fround($7 * $39);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($9 * $40);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($78 - $83);
 $85 = Math_fround($11 * $38);
 $86 = Math_fround($11 * $39);
 $87 = Math_fround($11 * $40);
 $88 = Math_fround($31 * $5);
 $89 = Math_fround($31 * $7);
 $90 = Math_fround($31 * $9);
 $91 = Math_fround($9 * $39);
 $92 = Math_fround($7 * $40);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($5 * $40);
 $95 = Math_fround($9 * $38);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($7 * $38);
 $98 = Math_fround($5 * $39);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($88 + $85);
 $101 = Math_fround($89 + $86);
 $102 = Math_fround($90 + $87);
 $103 = Math_fround($93 + $100);
 $104 = Math_fround($96 + $101);
 $105 = Math_fround($99 + $102);
 $106 = Math_fround($25 * Math_fround(2.0));
 $107 = Math_fround($31 * Math_fround(2.0));
 $108 = Math_fround($25 * $106);
 $109 = Math_fround($106 * $27);
 $110 = Math_fround($106 * $29);
 $111 = Math_fround($31 * $107);
 $112 = Math_fround($29 * $107);
 $113 = Math_fround($27 * $107);
 $114 = Math_fround($108 + $111);
 $115 = Math_fround($109 + $112);
 $116 = Math_fround($110 - $113);
 $117 = Math_fround($114 + Math_fround(-1.0));
 $118 = Math_fround($117 * $117);
 $119 = Math_fround($115 * $115);
 $120 = Math_fround($119 + $118);
 $121 = Math_fround($116 * $116);
 $122 = Math_fround($121 + $120);
 $123 = (Math_fround(Math_sqrt((Math_fround($122)))));
 $124 = Math_fround(Math_fround(1.0) / $123);
 $125 = Math_fround($117 * $124);
 $126 = Math_fround(-$125);
 $127 = Math_fround($115 * $124);
 $128 = Math_fround(-$127);
 $129 = Math_fround($116 * $124);
 $130 = Math_fround(-$129);
 HEAPF32[$negPlaneNormal>>2] = $126;
 $131 = (($negPlaneNormal) + 4|0);
 HEAPF32[$131>>2] = $128;
 $132 = (($negPlaneNormal) + 8|0);
 HEAPF32[$132>>2] = $130;
 $133 = (($negPlaneNormal) + 12|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = Math_fround(HEAPF32[$contactDistance>>2]);
 $135 = (($shape1) + 4|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 HEAPF32[$radius>>2] = $136;
 $137 = (($shape1) + 8|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($103 * Math_fround(2.0));
 $140 = Math_fround($84 * Math_fround(2.0));
 $141 = Math_fround($103 * $139);
 $142 = Math_fround($104 * $139);
 $143 = Math_fround($105 * $139);
 $144 = Math_fround($84 * $140);
 $145 = Math_fround($140 * $105);
 $146 = Math_fround($140 * $104);
 $147 = Math_fround($144 + $141);
 $148 = Math_fround($145 + $142);
 $149 = Math_fround($143 - $146);
 $150 = Math_fround($147 + Math_fround(-1.0));
 $151 = Math_fround($138 * $150);
 $152 = Math_fround($138 * $148);
 $153 = Math_fround($138 * $149);
 $154 = Math_fround($75 + $151);
 $155 = Math_fround($76 + $152);
 $156 = Math_fround($77 + $153);
 $157 = Math_fround($75 - $151);
 $158 = Math_fround($76 - $152);
 $159 = Math_fround($77 - $153);
 $160 = Math_fround($134 + $136);
 $161 = Math_fround($136 * Math_fround(0.00100000004749745130539));
 HEAPF32[$replaceBreakingThreshold>>2] = $161;
 $162 = Math_fround($136 * Math_fround(0.0500000007450580596924));
 HEAPF32[$projectBreakingThreshold>>2] = $162;
 $163 = (($2) + 32|0);
 $164 = HEAP8[$163>>0]|0;
 $165 = (($0) + 48|0);
 HEAPF32[$165>>2] = $75;
 $166 = (($0) + 52|0);
 HEAPF32[$166>>2] = $76;
 $167 = (($0) + 56|0);
 HEAPF32[$167>>2] = $77;
 $168 = (($0) + 60|0);
 HEAPF32[$168>>2] = Math_fround(0.0);
 $169 = Math_fround($103 + $103);
 $170 = Math_fround($104 + $104);
 $171 = Math_fround($105 + $105);
 $172 = Math_fround($103 * $169);
 $173 = Math_fround($104 * $170);
 $174 = Math_fround($105 * $171);
 $175 = Math_fround($104 * $169);
 $176 = Math_fround($105 * $169);
 $177 = Math_fround($84 * $169);
 $178 = Math_fround($105 * $170);
 $179 = Math_fround($84 * $170);
 $180 = Math_fround($84 * $171);
 $181 = Math_fround(Math_fround(1.0) - $172);
 $182 = Math_fround(Math_fround(1.0) - $173);
 $183 = Math_fround($182 - $174);
 $184 = Math_fround($175 + $180);
 $185 = Math_fround($176 - $179);
 $186 = Math_fround($175 - $180);
 $187 = Math_fround($181 - $174);
 $188 = Math_fround($178 + $177);
 $189 = Math_fround($176 + $179);
 $190 = Math_fround($178 - $177);
 $191 = Math_fround($181 - $173);
 HEAPF32[$0>>2] = $183;
 $192 = (($0) + 4|0);
 HEAPF32[$192>>2] = $184;
 $193 = (($0) + 8|0);
 HEAPF32[$193>>2] = $185;
 $194 = (($0) + 12|0);
 HEAPF32[$194>>2] = Math_fround(0.0);
 $195 = (($0) + 16|0);
 HEAPF32[$195>>2] = $186;
 $196 = (($0) + 20|0);
 HEAPF32[$196>>2] = $187;
 $197 = (($0) + 24|0);
 HEAPF32[$197>>2] = $188;
 $198 = (($0) + 28|0);
 HEAPF32[$198>>2] = Math_fround(0.0);
 $199 = (($0) + 32|0);
 HEAPF32[$199>>2] = $189;
 $200 = (($0) + 36|0);
 HEAPF32[$200>>2] = $190;
 $201 = (($0) + 40|0);
 HEAPF32[$201>>2] = $191;
 $202 = (($0) + 44|0);
 HEAPF32[$202>>2] = Math_fround(0.0);
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($2,$0,$projectBreakingThreshold,0);
 $203 = HEAP8[$163>>0]|0;
 $204 = ($203<<24>>24)==($164<<24>>24);
 if ($204) {
  $205 = Math_fround(HEAPF32[$radius>>2]);
  $206 = Math_fround($205 * Math_fround(0.0199999995529651641846));
  $207 = (($2) + 16|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = (($2) + 20|0);
  $210 = Math_fround(HEAPF32[$209>>2]);
  $211 = (($2) + 24|0);
  $212 = Math_fround(HEAPF32[$211>>2]);
  $213 = Math_fround($75 - $208);
  $214 = Math_fround($76 - $210);
  $215 = Math_fround($77 - $212);
  $216 = Math_fround(-$213);
  $217 = Math_fround(-$214);
  $218 = Math_fround(-$215);
  $219 = $213 > $216;
  $$$i$i$i$i = $219 ? $213 : $216;
  $220 = $214 > $217;
  $221 = $220 ? $214 : $217;
  $222 = $215 > $218;
  $$1$i$i$i$i = $222 ? $215 : $218;
  $223 = !($$$i$i$i$i >= $221);
  $$$i$i$i = $223 ? $221 : $$$i$i$i$i;
  $224 = !($$1$i$i$i$i >= Math_fround(0.0));
  $225 = $224 ? Math_fround(0.0) : $$$i$i$i$i;
  $226 = $$$i$i$i >= $225;
  $227 = $226 ? $$$i$i$i : $225;
  $228 = $227 > $206;
  if ($228) {
   $$pre$phi275Z2D = $209;$$pre$phi277Z2D = $211;$$pre$phiZ2D = $207;
  } else {
   $229 = (($2) + 4|0);
   $230 = (($2) + 8|0);
   $231 = Math_fround(HEAPF32[$229>>2]);
   $232 = Math_fround(HEAPF32[$2>>2]);
   $233 = Math_fround($104 * $231);
   $234 = Math_fround($103 * $232);
   $235 = (($2) + 12|0);
   $236 = Math_fround(HEAPF32[$230>>2]);
   $237 = Math_fround($105 * $236);
   $238 = Math_fround($233 + $234);
   $239 = Math_fround(HEAPF32[$235>>2]);
   $240 = Math_fround($84 * $239);
   $241 = Math_fround($238 + $237);
   $242 = Math_fround($241 + $240);
   $243 = $242 < Math_fround(0.999800026416778564453);
   if ($243) {
    $$pre$phi275Z2D = $209;$$pre$phi277Z2D = $211;$$pre$phiZ2D = $207;
   } else {
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($2,$contactBuffer,$negPlaneNormal,$transf0,$radius);
    $$sink = HEAP8[$163>>0]|0;
    $$0 = ($$sink<<24>>24)!=(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } else {
  $$pre = (($2) + 16|0);
  $$pre274 = (($2) + 20|0);
  $$pre276 = (($2) + 24|0);
  $$pre$phi275Z2D = $$pre274;$$pre$phi277Z2D = $$pre276;$$pre$phiZ2D = $$pre;
 }
 HEAP8[$163>>0] = 0;
 HEAPF32[$2>>2] = $103;
 $244 = (($2) + 4|0);
 HEAPF32[$244>>2] = $104;
 $245 = (($2) + 8|0);
 HEAPF32[$245>>2] = $105;
 $246 = (($2) + 12|0);
 HEAPF32[$246>>2] = $84;
 HEAPF32[$$pre$phiZ2D>>2] = $75;
 HEAPF32[$$pre$phi275Z2D>>2] = $76;
 HEAPF32[$$pre$phi277Z2D>>2] = $77;
 $247 = (($2) + 28|0);
 HEAPF32[$247>>2] = Math_fround(0.0);
 $248 = $160 > $154;
 if ($248) {
  $249 = Math_fround($154 - $75);
  $250 = Math_fround($155 - $76);
  $251 = Math_fround($156 - $77);
  $252 = Math_fround($84 * $84);
  $253 = Math_fround($252 + Math_fround(-0.5));
  $254 = Math_fround($253 * $249);
  $255 = Math_fround($253 * $250);
  $256 = Math_fround($253 * $251);
  $257 = Math_fround($104 * $251);
  $258 = Math_fround($105 * $250);
  $259 = Math_fround($257 - $258);
  $260 = Math_fround($105 * $249);
  $261 = Math_fround($103 * $251);
  $262 = Math_fround($260 - $261);
  $263 = Math_fround($103 * $250);
  $264 = Math_fround($104 * $249);
  $265 = Math_fround($263 - $264);
  $266 = Math_fround($84 * $259);
  $267 = Math_fround($84 * $262);
  $268 = Math_fround($84 * $265);
  $269 = Math_fround($254 - $266);
  $270 = Math_fround($255 - $267);
  $271 = Math_fround($256 - $268);
  $272 = Math_fround($103 * $249);
  $273 = Math_fround($104 * $250);
  $274 = Math_fround($273 + $272);
  $275 = Math_fround($105 * $251);
  $276 = Math_fround($275 + $274);
  $277 = Math_fround($103 * $276);
  $278 = Math_fround($104 * $276);
  $279 = Math_fround($105 * $276);
  $280 = Math_fround($269 + $277);
  $281 = Math_fround($278 + $270);
  $282 = Math_fround($271 + $279);
  $283 = Math_fround($280 * Math_fround(2.0));
  $284 = Math_fround($281 * Math_fround(2.0));
  $285 = Math_fround($282 * Math_fround(2.0));
  HEAPF32[$localPointA>>2] = $283;
  $286 = (($localPointA) + 4|0);
  HEAPF32[$286>>2] = $284;
  $287 = (($localPointA) + 8|0);
  HEAPF32[$287>>2] = $285;
  $288 = (($localPointA) + 12|0);
  HEAPF32[$288>>2] = Math_fround(0.0);
  $289 = Math_fround($154 * Math_fround(0.0));
  $290 = Math_fround($154 - $154);
  $291 = Math_fround($155 - $289);
  $292 = Math_fround($156 - $289);
  HEAPF32[$localPointB>>2] = $290;
  $293 = (($localPointB) + 4|0);
  HEAPF32[$293>>2] = $291;
  $294 = (($localPointB) + 8|0);
  HEAPF32[$294>>2] = $292;
  $295 = (($localPointB) + 12|0);
  HEAPF32[$295>>2] = Math_fround(0.0);
  HEAPF32[$localNormalPen>>2] = Math_fround(1.0);
  $296 = (($localNormalPen) + 4|0);
  HEAPF32[$296>>2] = Math_fround(0.0);
  $297 = (($localNormalPen) + 8|0);
  HEAPF32[$297>>2] = Math_fround(0.0);
  $298 = (($localNormalPen) + 12|0);
  HEAPF32[$298>>2] = $154;
  (__ZN5physx2Gu25PersistentContactManifold17addManifoldPoint2ERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($2,$localPointA,$localPointB,$localNormalPen,$replaceBreakingThreshold)|0);
 }
 $299 = $160 > $157;
 if ($299) {
  $300 = Math_fround($157 - $75);
  $301 = Math_fround($158 - $76);
  $302 = Math_fround($159 - $77);
  $303 = Math_fround($84 * $84);
  $304 = Math_fround($303 + Math_fround(-0.5));
  $305 = Math_fround($304 * $300);
  $306 = Math_fround($304 * $301);
  $307 = Math_fround($304 * $302);
  $308 = Math_fround($104 * $302);
  $309 = Math_fround($105 * $301);
  $310 = Math_fround($308 - $309);
  $311 = Math_fround($105 * $300);
  $312 = Math_fround($103 * $302);
  $313 = Math_fround($311 - $312);
  $314 = Math_fround($103 * $301);
  $315 = Math_fround($104 * $300);
  $316 = Math_fround($314 - $315);
  $317 = Math_fround($84 * $310);
  $318 = Math_fround($84 * $313);
  $319 = Math_fround($84 * $316);
  $320 = Math_fround($305 - $317);
  $321 = Math_fround($306 - $318);
  $322 = Math_fround($307 - $319);
  $323 = Math_fround($103 * $300);
  $324 = Math_fround($104 * $301);
  $325 = Math_fround($324 + $323);
  $326 = Math_fround($105 * $302);
  $327 = Math_fround($326 + $325);
  $328 = Math_fround($103 * $327);
  $329 = Math_fround($104 * $327);
  $330 = Math_fround($105 * $327);
  $331 = Math_fround($320 + $328);
  $332 = Math_fround($329 + $321);
  $333 = Math_fround($322 + $330);
  $334 = Math_fround($331 * Math_fround(2.0));
  $335 = Math_fround($332 * Math_fround(2.0));
  $336 = Math_fround($333 * Math_fround(2.0));
  HEAPF32[$localPointA1>>2] = $334;
  $337 = (($localPointA1) + 4|0);
  HEAPF32[$337>>2] = $335;
  $338 = (($localPointA1) + 8|0);
  HEAPF32[$338>>2] = $336;
  $339 = (($localPointA1) + 12|0);
  HEAPF32[$339>>2] = Math_fround(0.0);
  $340 = Math_fround($157 * Math_fround(0.0));
  $341 = Math_fround($157 - $157);
  $342 = Math_fround($158 - $340);
  $343 = Math_fround($159 - $340);
  HEAPF32[$localPointB2>>2] = $341;
  $344 = (($localPointB2) + 4|0);
  HEAPF32[$344>>2] = $342;
  $345 = (($localPointB2) + 8|0);
  HEAPF32[$345>>2] = $343;
  $346 = (($localPointB2) + 12|0);
  HEAPF32[$346>>2] = Math_fround(0.0);
  HEAPF32[$localNormalPen3>>2] = Math_fround(1.0);
  $347 = (($localNormalPen3) + 4|0);
  HEAPF32[$347>>2] = Math_fround(0.0);
  $348 = (($localNormalPen3) + 8|0);
  HEAPF32[$348>>2] = Math_fround(0.0);
  $349 = (($localNormalPen3) + 12|0);
  HEAPF32[$349>>2] = $157;
  (__ZN5physx2Gu25PersistentContactManifold17addManifoldPoint2ERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($2,$localPointA1,$localPointB2,$localNormalPen3,$replaceBreakingThreshold)|0);
 }
 __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($2,$contactBuffer,$negPlaneNormal,$transf0,$radius);
 $$sink = HEAP8[$163>>0]|0;
 $$0 = ($$sink<<24>>24)!=(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu21pcmContactPlaneConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$0 = 0, $$1$i$i$i$i = Math_fround(0), $$pre = 0, $$pre$phi129Z2D = 0, $$pre$phi131Z2D = 0, $$pre$phiZ2D = 0, $$pre128 = 0, $$pre130 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0);
 var $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0);
 var $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0);
 var $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0);
 var $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0);
 var $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0);
 var $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = Math_fround(0);
 var $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0);
 var $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = 0, $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0);
 var $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = Math_fround(0);
 var $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0);
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $indvars$iv = 0, $indvars$iv$next = 0, $lftr$wideiv = 0, $negPlaneNormal = 0, $numContacts$0$lcssa = 0;
 var $numContacts$0126 = 0, $numContacts$1 = 0, $projectBreakingThreshold = 0, $transf1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $transf1 = sp + 96|0;
 $negPlaneNormal = sp;
 $projectBreakingThreshold = sp + 16|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$cache>>2]|0;
 $2 = $1;
 $3 = $1;
 $4 = (($3) + 256|0);
 $5 = Math_fround(HEAPF32[$transform1>>2]);
 $6 = (($transform1) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($transform1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($transform1) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($transform1) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($12) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($12) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$transform0>>2]);
 $19 = (($transform0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($transform0) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($25) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($25) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$transf1>>2] = $18;
 $31 = (($transf1) + 4|0);
 HEAPF32[$31>>2] = $20;
 $32 = (($transf1) + 8|0);
 HEAPF32[$32>>2] = $22;
 $33 = (($transf1) + 12|0);
 HEAPF32[$33>>2] = $24;
 $34 = (($transf1) + 16|0);
 HEAPF32[$34>>2] = $26;
 $35 = (($transf1) + 20|0);
 HEAPF32[$35>>2] = $28;
 $36 = (($transf1) + 24|0);
 HEAPF32[$36>>2] = $30;
 $37 = (($transf1) + 28|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = Math_fround(-$18);
 $39 = Math_fround(-$20);
 $40 = Math_fround(-$22);
 $41 = Math_fround($13 - $26);
 $42 = Math_fround($15 - $28);
 $43 = Math_fround($17 - $30);
 $44 = Math_fround($24 * $24);
 $45 = Math_fround($44 + Math_fround(-0.5));
 $46 = Math_fround($45 * $41);
 $47 = Math_fround($45 * $42);
 $48 = Math_fround($45 * $43);
 $49 = Math_fround($43 * $39);
 $50 = Math_fround($42 * $40);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($41 * $40);
 $53 = Math_fround($43 * $38);
 $54 = Math_fround($52 - $53);
 $55 = Math_fround($42 * $38);
 $56 = Math_fround($41 * $39);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($24 * $51);
 $59 = Math_fround($24 * $54);
 $60 = Math_fround($24 * $57);
 $61 = Math_fround($46 + $58);
 $62 = Math_fround($47 + $59);
 $63 = Math_fround($48 + $60);
 $64 = Math_fround($41 * $38);
 $65 = Math_fround($42 * $39);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($43 * $40);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($68 * $38);
 $70 = Math_fround($68 * $39);
 $71 = Math_fround($68 * $40);
 $72 = Math_fround($69 + $61);
 $73 = Math_fround($70 + $62);
 $74 = Math_fround($63 + $71);
 $75 = Math_fround($72 * Math_fround(2.0));
 $76 = Math_fround($73 * Math_fround(2.0));
 $77 = Math_fround($74 * Math_fround(2.0));
 $78 = Math_fround($11 * $24);
 $79 = Math_fround($5 * $38);
 $80 = Math_fround($7 * $39);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($9 * $40);
 $83 = Math_fround($81 + $82);
 $84 = Math_fround($78 - $83);
 $85 = Math_fround($11 * $38);
 $86 = Math_fround($11 * $39);
 $87 = Math_fround($11 * $40);
 $88 = Math_fround($5 * $24);
 $89 = Math_fround($7 * $24);
 $90 = Math_fround($9 * $24);
 $91 = Math_fround($9 * $39);
 $92 = Math_fround($7 * $40);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($5 * $40);
 $95 = Math_fround($9 * $38);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($7 * $38);
 $98 = Math_fround($5 * $39);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($85 + $88);
 $101 = Math_fround($86 + $89);
 $102 = Math_fround($90 + $87);
 $103 = Math_fround($93 + $100);
 $104 = Math_fround($96 + $101);
 $105 = Math_fround($99 + $102);
 $106 = (($shape1) + 4|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($shape1) + 8|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($shape1) + 12|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($shape1) + 36|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($113) + 52|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($113) + 56|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($113) + 60|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($107 * $115);
 $121 = Math_fround($109 * $117);
 $122 = Math_fround($111 * $119);
 $123 = !($120 <= $121);
 $$$i$i = $123 ? $121 : $120;
 $124 = !($$$i$i <= $122);
 $125 = $124 ? $122 : $$$i$i;
 $126 = Math_fround($125 * Math_fround(0.25));
 $127 = Math_fround($18 * Math_fround(2.0));
 $128 = Math_fround($24 * Math_fround(2.0));
 $129 = Math_fround($18 * $127);
 $130 = Math_fround($127 * $20);
 $131 = Math_fround($127 * $22);
 $132 = Math_fround($24 * $128);
 $133 = Math_fround($22 * $128);
 $134 = Math_fround($20 * $128);
 $135 = Math_fround($129 + $132);
 $136 = Math_fround($130 + $133);
 $137 = Math_fround($131 - $134);
 $138 = Math_fround($135 + Math_fround(-1.0));
 $139 = Math_fround($138 * $138);
 $140 = Math_fround($136 * $136);
 $141 = Math_fround($140 + $139);
 $142 = Math_fround($137 * $137);
 $143 = Math_fround($142 + $141);
 $144 = (Math_fround(Math_sqrt((Math_fround($143)))));
 $145 = Math_fround(Math_fround(1.0) / $144);
 $146 = Math_fround($138 * $145);
 $147 = Math_fround($136 * $145);
 $148 = Math_fround($137 * $145);
 $149 = Math_fround(-$146);
 $150 = Math_fround(-$147);
 $151 = Math_fround(-$148);
 HEAPF32[$negPlaneNormal>>2] = $149;
 $152 = (($negPlaneNormal) + 4|0);
 HEAPF32[$152>>2] = $150;
 $153 = (($negPlaneNormal) + 8|0);
 HEAPF32[$153>>2] = $151;
 $154 = (($negPlaneNormal) + 12|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 $155 = Math_fround(HEAPF32[$contactDistance>>2]);
 $156 = Math_fround($126 * Math_fround(0.20000000298023223877));
 HEAPF32[$projectBreakingThreshold>>2] = $156;
 $157 = (($2) + 32|0);
 $158 = HEAP8[$157>>0]|0;
 $159 = (($0) + 48|0);
 HEAPF32[$159>>2] = $75;
 $160 = (($0) + 52|0);
 HEAPF32[$160>>2] = $76;
 $161 = (($0) + 56|0);
 HEAPF32[$161>>2] = $77;
 $162 = (($0) + 60|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 $163 = Math_fround($103 + $103);
 $164 = Math_fround($104 + $104);
 $165 = Math_fround($105 + $105);
 $166 = Math_fround($103 * $163);
 $167 = Math_fround($104 * $164);
 $168 = Math_fround($105 * $165);
 $169 = Math_fround($104 * $163);
 $170 = Math_fround($105 * $163);
 $171 = Math_fround($84 * $163);
 $172 = Math_fround($105 * $164);
 $173 = Math_fround($84 * $164);
 $174 = Math_fround($84 * $165);
 $175 = Math_fround(Math_fround(1.0) - $166);
 $176 = Math_fround(Math_fround(1.0) - $167);
 $177 = Math_fround($176 - $168);
 $178 = Math_fround($169 + $174);
 $179 = Math_fround($170 - $173);
 $180 = Math_fround($169 - $174);
 $181 = Math_fround($175 - $168);
 $182 = Math_fround($172 + $171);
 $183 = Math_fround($170 + $173);
 $184 = Math_fround($172 - $171);
 $185 = Math_fround($175 - $167);
 HEAPF32[$0>>2] = $177;
 $186 = (($0) + 4|0);
 HEAPF32[$186>>2] = $178;
 $187 = (($0) + 8|0);
 HEAPF32[$187>>2] = $179;
 $188 = (($0) + 12|0);
 HEAPF32[$188>>2] = Math_fround(0.0);
 $189 = (($0) + 16|0);
 HEAPF32[$189>>2] = $180;
 $190 = (($0) + 20|0);
 HEAPF32[$190>>2] = $181;
 $191 = (($0) + 24|0);
 HEAPF32[$191>>2] = $182;
 $192 = (($0) + 28|0);
 HEAPF32[$192>>2] = Math_fround(0.0);
 $193 = (($0) + 32|0);
 HEAPF32[$193>>2] = $183;
 $194 = (($0) + 36|0);
 HEAPF32[$194>>2] = $184;
 $195 = (($0) + 40|0);
 HEAPF32[$195>>2] = $185;
 $196 = (($0) + 44|0);
 HEAPF32[$196>>2] = Math_fround(0.0);
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($2,$0,$projectBreakingThreshold,0);
 $197 = HEAP8[$157>>0]|0;
 $198 = ($197<<24>>24)==($158<<24>>24);
 if ($198) {
  $199 = $158&255;
  $200 = (554160 + ($199<<2)|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = Math_fround($126 * $201);
  $203 = (($2) + 16|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = (($2) + 20|0);
  $206 = Math_fround(HEAPF32[$205>>2]);
  $207 = (($2) + 24|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = Math_fround($75 - $204);
  $210 = Math_fround($76 - $206);
  $211 = Math_fround($77 - $208);
  $212 = Math_fround(-$209);
  $213 = Math_fround(-$210);
  $214 = Math_fround(-$211);
  $215 = $209 > $212;
  $$$i$i$i$i = $215 ? $209 : $212;
  $216 = $210 > $213;
  $217 = $216 ? $210 : $213;
  $218 = $211 > $214;
  $$1$i$i$i$i = $218 ? $211 : $214;
  $219 = !($$$i$i$i$i >= $217);
  $$$i$i$i = $219 ? $217 : $$$i$i$i$i;
  $220 = !($$1$i$i$i$i >= Math_fround(0.0));
  $221 = $220 ? Math_fround(0.0) : $$$i$i$i$i;
  $222 = $$$i$i$i >= $221;
  $223 = $222 ? $$$i$i$i : $221;
  $224 = $223 > $202;
  if ($224) {
   $$pre$phi129Z2D = $205;$$pre$phi131Z2D = $207;$$pre$phiZ2D = $203;
  } else {
   $225 = (($2) + 4|0);
   $226 = (($2) + 8|0);
   $227 = Math_fround(HEAPF32[$225>>2]);
   $228 = Math_fround(HEAPF32[$2>>2]);
   $229 = Math_fround($104 * $227);
   $230 = Math_fround($103 * $228);
   $231 = (($2) + 12|0);
   $232 = Math_fround(HEAPF32[$226>>2]);
   $233 = Math_fround($105 * $232);
   $234 = Math_fround($229 + $230);
   $235 = Math_fround(HEAPF32[$231>>2]);
   $236 = Math_fround($84 * $235);
   $237 = Math_fround($234 + $233);
   $238 = (554200 + ($199<<2)|0);
   $239 = Math_fround($237 + $236);
   $240 = Math_fround(HEAPF32[$238>>2]);
   $241 = $240 > $239;
   if ($241) {
    $$pre$phi129Z2D = $205;$$pre$phi131Z2D = $207;$$pre$phiZ2D = $203;
   } else {
    __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($2,$contactBuffer,$negPlaneNormal,$transf1);
    $$sink = HEAP8[$157>>0]|0;
    $$0 = ($$sink<<24>>24)!=(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } else {
  $$pre = (($2) + 16|0);
  $$pre128 = (($2) + 20|0);
  $$pre130 = (($2) + 24|0);
  $$pre$phi129Z2D = $$pre128;$$pre$phi131Z2D = $$pre130;$$pre$phiZ2D = $$pre;
 }
 $242 = (($shape1) + 16|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($shape1) + 20|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = (($shape1) + 24|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = (($shape1) + 28|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = Math_fround($243 + $243);
 $251 = Math_fround($245 + $245);
 $252 = Math_fround($247 + $247);
 $253 = Math_fround($243 * $250);
 $254 = Math_fround($245 * $251);
 $255 = Math_fround($247 * $252);
 $256 = Math_fround($250 * $245);
 $257 = Math_fround($250 * $247);
 $258 = Math_fround($250 * $249);
 $259 = Math_fround($251 * $247);
 $260 = Math_fround($251 * $249);
 $261 = Math_fround($252 * $249);
 $262 = Math_fround(Math_fround(1.0) - $253);
 $263 = Math_fround(Math_fround(1.0) - $254);
 $264 = Math_fround($263 - $255);
 $265 = Math_fround($256 + $261);
 $266 = Math_fround($257 - $260);
 $267 = Math_fround($256 - $261);
 $268 = Math_fround($262 - $255);
 $269 = Math_fround($259 + $258);
 $270 = Math_fround($257 + $260);
 $271 = Math_fround($259 - $258);
 $272 = Math_fround($262 - $254);
 $273 = Math_fround($107 * $264);
 $274 = Math_fround($107 * $267);
 $275 = Math_fround($107 * $270);
 $276 = Math_fround($109 * $265);
 $277 = Math_fround($109 * $268);
 $278 = Math_fround($109 * $271);
 $279 = Math_fround($111 * $266);
 $280 = Math_fround($111 * $269);
 $281 = Math_fround($111 * $272);
 $282 = Math_fround($264 * $273);
 $283 = Math_fround($265 * $276);
 $284 = Math_fround($282 + $283);
 $285 = Math_fround($266 * $279);
 $286 = Math_fround($285 + $284);
 $287 = Math_fround($264 * $274);
 $288 = Math_fround($265 * $277);
 $289 = Math_fround($287 + $288);
 $290 = Math_fround($266 * $280);
 $291 = Math_fround($290 + $289);
 $292 = Math_fround($264 * $275);
 $293 = Math_fround($265 * $278);
 $294 = Math_fround($292 + $293);
 $295 = Math_fround($266 * $281);
 $296 = Math_fround($295 + $294);
 $297 = Math_fround($267 * $273);
 $298 = Math_fround($268 * $276);
 $299 = Math_fround($297 + $298);
 $300 = Math_fround($269 * $279);
 $301 = Math_fround($300 + $299);
 $302 = Math_fround($267 * $274);
 $303 = Math_fround($268 * $277);
 $304 = Math_fround($302 + $303);
 $305 = Math_fround($269 * $280);
 $306 = Math_fround($305 + $304);
 $307 = Math_fround($267 * $275);
 $308 = Math_fround($268 * $278);
 $309 = Math_fround($307 + $308);
 $310 = Math_fround($269 * $281);
 $311 = Math_fround($310 + $309);
 $312 = Math_fround($270 * $273);
 $313 = Math_fround($271 * $276);
 $314 = Math_fround($312 + $313);
 $315 = Math_fround($272 * $279);
 $316 = Math_fround($315 + $314);
 $317 = Math_fround($270 * $274);
 $318 = Math_fround($271 * $277);
 $319 = Math_fround($317 + $318);
 $320 = Math_fround($272 * $280);
 $321 = Math_fround($320 + $319);
 $322 = Math_fround($270 * $275);
 $323 = Math_fround($271 * $278);
 $324 = Math_fround($322 + $323);
 $325 = Math_fround($272 * $281);
 $326 = Math_fround($325 + $324);
 HEAP8[$157>>0] = 0;
 HEAPF32[$2>>2] = $103;
 $327 = (($2) + 4|0);
 HEAPF32[$327>>2] = $104;
 $328 = (($2) + 8|0);
 HEAPF32[$328>>2] = $105;
 $329 = (($2) + 12|0);
 HEAPF32[$329>>2] = $84;
 HEAPF32[$$pre$phiZ2D>>2] = $75;
 HEAPF32[$$pre$phi129Z2D>>2] = $76;
 HEAPF32[$$pre$phi131Z2D>>2] = $77;
 $330 = (($2) + 28|0);
 HEAPF32[$330>>2] = Math_fround(0.0);
 $331 = (($113) + 40|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = (($113) + 39|0);
 $334 = HEAP8[$333>>0]|0;
 $335 = $334&255;
 $336 = (($332) + (($335*20)|0)|0);
 $337 = (($113) + 38|0);
 $338 = HEAP8[$337>>0]|0;
 $339 = Math_fround($177 * $286);
 $340 = Math_fround($180 * $291);
 $341 = Math_fround($339 + $340);
 $342 = Math_fround($183 * $296);
 $343 = Math_fround($342 + $341);
 $344 = Math_fround($178 * $286);
 $345 = Math_fround($181 * $291);
 $346 = Math_fround($344 + $345);
 $347 = Math_fround($184 * $296);
 $348 = Math_fround($347 + $346);
 $349 = Math_fround($179 * $286);
 $350 = Math_fround($182 * $291);
 $351 = Math_fround($349 + $350);
 $352 = Math_fround($185 * $296);
 $353 = Math_fround($352 + $351);
 $354 = Math_fround($177 * $301);
 $355 = Math_fround($180 * $306);
 $356 = Math_fround($354 + $355);
 $357 = Math_fround($183 * $311);
 $358 = Math_fround($357 + $356);
 $359 = Math_fround($178 * $301);
 $360 = Math_fround($181 * $306);
 $361 = Math_fround($359 + $360);
 $362 = Math_fround($184 * $311);
 $363 = Math_fround($362 + $361);
 $364 = Math_fround($179 * $301);
 $365 = Math_fround($182 * $306);
 $366 = Math_fround($364 + $365);
 $367 = Math_fround($185 * $311);
 $368 = Math_fround($367 + $366);
 $369 = Math_fround($177 * $316);
 $370 = Math_fround($180 * $321);
 $371 = Math_fround($369 + $370);
 $372 = Math_fround($183 * $326);
 $373 = Math_fround($372 + $371);
 $374 = Math_fround($178 * $316);
 $375 = Math_fround($181 * $321);
 $376 = Math_fround($374 + $375);
 $377 = Math_fround($184 * $326);
 $378 = Math_fround($377 + $376);
 $379 = Math_fround($179 * $316);
 $380 = Math_fround($182 * $321);
 $381 = Math_fround($379 + $380);
 $382 = Math_fround($185 * $326);
 $383 = Math_fround($382 + $381);
 $384 = ($338<<24>>24)==(0);
 if ($384) {
  $numContacts$0$lcssa = 0;
 } else {
  $indvars$iv = 0;$numContacts$0126 = 0;
  while(1) {
   $385 = (($336) + (($indvars$iv*12)|0)|0);
   $386 = Math_fround(HEAPF32[$385>>2]);
   $387 = ((($336) + (($indvars$iv*12)|0)|0) + 4|0);
   $388 = Math_fround(HEAPF32[$387>>2]);
   $389 = ((($336) + (($indvars$iv*12)|0)|0) + 8|0);
   $390 = Math_fround(HEAPF32[$389>>2]);
   $391 = Math_fround($343 * $386);
   $392 = Math_fround($358 * $388);
   $393 = Math_fround($391 + $392);
   $394 = Math_fround($373 * $390);
   $395 = Math_fround($393 + $394);
   $396 = Math_fround($75 + $395);
   $397 = $155 > $396;
   if ($397) {
    $398 = Math_fround($368 * $388);
    $399 = Math_fround($353 * $386);
    $400 = Math_fround($363 * $388);
    $401 = Math_fround($348 * $386);
    $402 = Math_fround($383 * $390);
    $403 = Math_fround($399 + $398);
    $404 = Math_fround($378 * $390);
    $405 = Math_fround($401 + $400);
    $406 = Math_fround($403 + $402);
    $407 = Math_fround($405 + $404);
    $408 = Math_fround($77 + $406);
    $409 = Math_fround($76 + $407);
    $410 = Math_fround($286 * $386);
    $411 = Math_fround($301 * $388);
    $412 = Math_fround($410 + $411);
    $413 = Math_fround($316 * $390);
    $414 = Math_fround($412 + $413);
    $415 = Math_fround($291 * $386);
    $416 = Math_fround($306 * $388);
    $417 = Math_fround($415 + $416);
    $418 = Math_fround($321 * $390);
    $419 = Math_fround($417 + $418);
    $420 = Math_fround($296 * $386);
    $421 = Math_fround($311 * $388);
    $422 = Math_fround($420 + $421);
    $423 = Math_fround($326 * $390);
    $424 = Math_fround($422 + $423);
    $425 = (($contactBuffer) + (($numContacts$0126*48)|0)|0);
    HEAPF32[$425>>2] = $414;
    $426 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 4|0);
    HEAPF32[$426>>2] = $419;
    $427 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 8|0);
    HEAPF32[$427>>2] = $424;
    $428 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 12|0);
    HEAPF32[$428>>2] = Math_fround(0.0);
    $429 = Math_fround($396 * Math_fround(0.0));
    $430 = Math_fround($396 - $396);
    $431 = Math_fround($409 - $429);
    $432 = Math_fround($408 - $429);
    $433 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 16|0);
    HEAPF32[$433>>2] = $430;
    $434 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 20|0);
    HEAPF32[$434>>2] = $431;
    $435 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 24|0);
    HEAPF32[$435>>2] = $432;
    $436 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 28|0);
    HEAPF32[$436>>2] = Math_fround(0.0);
    $437 = (($numContacts$0126) + 1)|0;
    $438 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 32|0);
    HEAPF32[$438>>2] = Math_fround(1.0);
    $439 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 36|0);
    HEAPF32[$439>>2] = Math_fround(0.0);
    $440 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 40|0);
    HEAPF32[$440>>2] = Math_fround(0.0);
    $441 = ((($contactBuffer) + (($numContacts$0126*48)|0)|0) + 44|0);
    HEAPF32[$441>>2] = $396;
    $numContacts$1 = $437;
   } else {
    $numContacts$1 = $numContacts$0126;
   }
   $indvars$iv$next = (($indvars$iv) + 1)|0;
   $lftr$wideiv = $indvars$iv$next&255;
   $exitcond = ($lftr$wideiv<<24>>24)==($338<<24>>24);
   if ($exitcond) {
    $numContacts$0$lcssa = $numContacts$1;
    break;
   } else {
    $indvars$iv = $indvars$iv$next;$numContacts$0126 = $numContacts$1;
   }
  }
 }
 __ZN5physx2Gu25PersistentContactManifold24addBatchManifoldContactsEPKNS0_17PersistentContactEj($2,$contactBuffer,$numContacts$0$lcssa);
 __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($2,$contactBuffer,$negPlaneNormal,$transf1);
 $$sink = HEAP8[$157>>0]|0;
 $$0 = ($$sink<<24>>24)!=(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu22pcmContactSphereConvexERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$ = 0, $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$0 = 0, $$1$i$i$i$i = Math_fround(0), $$off = 0, $$pre = 0, $$pre$phi332Z2D = 0, $$pre$phi334Z2D = 0, $$pre$phiZ2D = 0, $$pre331 = 0, $$pre333 = 0, $$sroa$1104 = 0, $$sroa$182 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0);
 var $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0;
 var $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0);
 var $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0;
 var $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0);
 var $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0;
 var $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0);
 var $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0);
 var $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0);
 var $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0);
 var $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0);
 var $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = 0, $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0);
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $aToB = 0, $capsule = 0, $closestA = 0, $closestB = 0, $contactDist = 0, $convexHull = 0, $normal = 0, $penDep = 0;
 var $projectBreakingThreshold = 0, $sphereRadius$sroa$1 = 0, $status$0 = 0, $status$2 = 0, $supportMap = 0, $vQuat = 0, $vScale = 0, $zero$sroa$1 = 0, $zero$sroa$1$i$i$i = 0, $zeroV = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 656|0;
 $zero$sroa$1$i$i$i = sp + 640|0;
 $0 = sp + 560|0;
 $zeroV = sp + 528|0;
 $vScale = sp + 544|0;
 $sphereRadius$sroa$1 = sp + 628|0;
 $contactDist = sp + 512|0;
 $aToB = sp + 448|0;
 $projectBreakingThreshold = sp + 416|0;
 $closestA = sp + 432|0;
 $closestB = sp + 400|0;
 $normal = sp + 384|0;
 $zero$sroa$1 = sp + 588|0;
 $penDep = sp + 368|0;
 $vQuat = sp + 352|0;
 $convexHull = sp + 144|0;
 $capsule = sp;
 $supportMap = sp + 600|0;
 $$sroa$1104 = sp + 576|0;
 $$sroa$182 = sp + 616|0;
 $1 = HEAP32[$cache>>2]|0;
 $2 = $1;
 ;HEAP32[$zeroV+0>>2]=0|0;HEAP32[$zeroV+4>>2]=0|0;HEAP32[$zeroV+8>>2]=0|0;HEAP32[$zeroV+12>>2]=0|0;
 $3 = (($shape1) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($shape1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($shape1) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($shape1) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$vScale>>2] = $6;
 $11 = (($vScale) + 4|0);
 HEAPF32[$11>>2] = $8;
 $12 = (($vScale) + 8|0);
 HEAPF32[$12>>2] = $10;
 $13 = (($vScale) + 12|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($shape0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$contactDistance>>2]);
 HEAPF32[$contactDist>>2] = $16;
 $17 = HEAP32[$3>>2]|0;
 $18 = Math_fround(HEAPF32[$transform0>>2]);
 $19 = (($transform0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($transform0) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($25) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($25) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround(HEAPF32[$transform1>>2]);
 $32 = (($transform1) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($transform1) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($transform1) + 12|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($transform1) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($38) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($38) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround(-$31);
 $45 = Math_fround(-$33);
 $46 = Math_fround(-$35);
 $47 = Math_fround($26 - $39);
 $48 = Math_fround($28 - $41);
 $49 = Math_fround($30 - $43);
 $50 = Math_fround($37 * $37);
 $51 = Math_fround($50 + Math_fround(-0.5));
 $52 = Math_fround($51 * $47);
 $53 = Math_fround($51 * $48);
 $54 = Math_fround($51 * $49);
 $55 = Math_fround($49 * $45);
 $56 = Math_fround($48 * $46);
 $57 = Math_fround($55 - $56);
 $58 = Math_fround($47 * $46);
 $59 = Math_fround($49 * $44);
 $60 = Math_fround($58 - $59);
 $61 = Math_fround($48 * $44);
 $62 = Math_fround($47 * $45);
 $63 = Math_fround($61 - $62);
 $64 = Math_fround($37 * $57);
 $65 = Math_fround($37 * $60);
 $66 = Math_fround($37 * $63);
 $67 = Math_fround($52 + $64);
 $68 = Math_fround($53 + $65);
 $69 = Math_fround($54 + $66);
 $70 = Math_fround($47 * $44);
 $71 = Math_fround($48 * $45);
 $72 = Math_fround($70 + $71);
 $73 = Math_fround($49 * $46);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($74 * $44);
 $76 = Math_fround($74 * $45);
 $77 = Math_fround($74 * $46);
 $78 = Math_fround($75 + $67);
 $79 = Math_fround($76 + $68);
 $80 = Math_fround($69 + $77);
 $81 = Math_fround($78 * Math_fround(2.0));
 $82 = Math_fround($79 * Math_fround(2.0));
 $83 = Math_fround($80 * Math_fround(2.0));
 $84 = Math_fround($24 * $37);
 $85 = Math_fround($18 * $44);
 $86 = Math_fround($20 * $45);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($22 * $46);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($84 - $89);
 $91 = Math_fround($24 * $44);
 $92 = Math_fround($24 * $45);
 $93 = Math_fround($24 * $46);
 $94 = Math_fround($18 * $37);
 $95 = Math_fround($20 * $37);
 $96 = Math_fround($22 * $37);
 $97 = Math_fround($22 * $45);
 $98 = Math_fround($20 * $46);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($18 * $46);
 $101 = Math_fround($22 * $44);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($20 * $44);
 $104 = Math_fround($18 * $45);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($91 + $94);
 $107 = Math_fround($92 + $95);
 $108 = Math_fround($96 + $93);
 $109 = Math_fround($99 + $106);
 $110 = Math_fround($102 + $107);
 $111 = Math_fround($105 + $108);
 $112 = (($aToB) + 48|0);
 HEAPF32[$112>>2] = $81;
 $113 = (($aToB) + 52|0);
 HEAPF32[$113>>2] = $82;
 $114 = (($aToB) + 56|0);
 HEAPF32[$114>>2] = $83;
 $115 = (($aToB) + 60|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = Math_fround($109 + $109);
 $117 = Math_fround($110 + $110);
 $118 = Math_fround($111 + $111);
 $119 = Math_fround($109 * $116);
 $120 = Math_fround($110 * $117);
 $121 = Math_fround($111 * $118);
 $122 = Math_fround($110 * $116);
 $123 = Math_fround($111 * $116);
 $124 = Math_fround($90 * $116);
 $125 = Math_fround($111 * $117);
 $126 = Math_fround($90 * $117);
 $127 = Math_fround($90 * $118);
 $128 = Math_fround(Math_fround(1.0) - $119);
 $129 = Math_fround(Math_fround(1.0) - $120);
 $130 = Math_fround($129 - $121);
 $131 = Math_fround($122 + $127);
 $132 = Math_fround($123 - $126);
 $133 = Math_fround($122 - $127);
 $134 = Math_fround($128 - $121);
 $135 = Math_fround($125 + $124);
 $136 = Math_fround($123 + $126);
 $137 = Math_fround($125 - $124);
 $138 = Math_fround($128 - $120);
 HEAPF32[$aToB>>2] = $130;
 $139 = (($aToB) + 4|0);
 HEAPF32[$139>>2] = $131;
 $140 = (($aToB) + 8|0);
 HEAPF32[$140>>2] = $132;
 $141 = (($aToB) + 12|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 $142 = (($aToB) + 16|0);
 HEAPF32[$142>>2] = $133;
 $143 = (($aToB) + 20|0);
 HEAPF32[$143>>2] = $134;
 $144 = (($aToB) + 24|0);
 HEAPF32[$144>>2] = $135;
 $145 = (($aToB) + 28|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = (($aToB) + 32|0);
 HEAPF32[$146>>2] = $136;
 $147 = (($aToB) + 36|0);
 HEAPF32[$147>>2] = $137;
 $148 = (($aToB) + 40|0);
 HEAPF32[$148>>2] = $138;
 $149 = (($aToB) + 44|0);
 HEAPF32[$149>>2] = Math_fround(0.0);
 $150 = (($17) + 52|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = (($17) + 56|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = (($17) + 60|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = Math_fround(HEAPF32[$vScale>>2]);
 $157 = Math_fround(HEAPF32[$11>>2]);
 $158 = Math_fround(HEAPF32[$12>>2]);
 $159 = Math_fround($151 * $156);
 $160 = Math_fround($153 * $157);
 $161 = Math_fround($155 * $158);
 $162 = !($159 <= $160);
 $$$i$i = $162 ? $160 : $159;
 $163 = !($$$i$i <= $161);
 $164 = $163 ? $161 : $$$i$i;
 $165 = Math_fround($164 * Math_fround(0.25));
 $166 = (($2) + 32|0);
 $167 = HEAP8[$166>>0]|0;
 $168 = $165 > $15;
 $$$i = $168 ? $15 : $165;
 $169 = Math_fround($$$i * Math_fround(0.0500000007450580596924));
 HEAPF32[$projectBreakingThreshold>>2] = $169;
 __ZN5physx2Gu25PersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($2,$aToB,$projectBreakingThreshold,0);
 $170 = HEAP8[$166>>0]|0;
 $171 = ($170<<24>>24)==($167<<24>>24);
 ;HEAP32[$closestA+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestA+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestA+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestA+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$closestB+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$closestB+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$closestB+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$closestB+12>>2]=HEAP32[$zeroV+12>>2]|0;
 ;HEAP32[$normal+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$normal+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$normal+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$normal+12>>2]=HEAP32[$zeroV+12>>2]|0;
 HEAPF32[$penDep>>2] = Math_fround(0.0);
 $172 = (($penDep) + 4|0);
 ;HEAP32[$172+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
 if ($171) {
  $173 = HEAP8[$166>>0]|0;
  $174 = $173&255;
  $175 = (554184 + ($174<<2)|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = Math_fround($$$i * $176);
  $178 = (($2) + 16|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = (($2) + 20|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = (($2) + 24|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = Math_fround($81 - $179);
  $185 = Math_fround($82 - $181);
  $186 = Math_fround($83 - $183);
  $187 = Math_fround(-$184);
  $188 = Math_fround(-$185);
  $189 = Math_fround(-$186);
  $190 = $184 > $187;
  $$$i$i$i$i = $190 ? $184 : $187;
  $191 = $185 > $188;
  $192 = $191 ? $185 : $188;
  $193 = $186 > $189;
  $$1$i$i$i$i = $193 ? $186 : $189;
  $194 = !($$$i$i$i$i >= $192);
  $$$i$i$i = $194 ? $192 : $$$i$i$i$i;
  $195 = !($$1$i$i$i$i >= Math_fround(0.0));
  $196 = $195 ? Math_fround(0.0) : $$$i$i$i$i;
  $197 = $$$i$i$i >= $196;
  $198 = $197 ? $$$i$i$i : $196;
  $199 = $198 > $177;
  if ($199) {
   $$pre$phi332Z2D = $180;$$pre$phi334Z2D = $182;$$pre$phiZ2D = $178;
   label = 5;
  } else {
   $200 = ($167<<24>>24)!=(0);
   $201 = $200 ? 2 : 0;
   $202 = (($2) + 4|0);
   $203 = (($2) + 8|0);
   $204 = Math_fround(HEAPF32[$202>>2]);
   $205 = Math_fround(HEAPF32[$2>>2]);
   $206 = Math_fround($110 * $204);
   $207 = Math_fround($109 * $205);
   $208 = (($2) + 12|0);
   $209 = Math_fround(HEAPF32[$203>>2]);
   $210 = Math_fround($111 * $209);
   $211 = Math_fround($206 + $207);
   $212 = Math_fround(HEAPF32[$208>>2]);
   $213 = Math_fround($90 * $212);
   $214 = Math_fround($211 + $210);
   $215 = (554224 + ($174<<2)|0);
   $216 = Math_fround($214 + $213);
   $217 = Math_fround(HEAPF32[$215>>2]);
   $218 = $217 > $216;
   if ($218) {
    $$pre$phi332Z2D = $180;$$pre$phi334Z2D = $182;$$pre$phiZ2D = $178;
    label = 5;
   } else {
    $status$2 = $201;
    label = 15;
   }
  }
 } else {
  $$pre = (($2) + 16|0);
  $$pre331 = (($2) + 20|0);
  $$pre333 = (($2) + 24|0);
  $$pre$phi332Z2D = $$pre331;$$pre$phi334Z2D = $$pre333;$$pre$phiZ2D = $$pre;
  label = 5;
 }
 do {
  if ((label|0) == 5) {
   HEAPF32[$2>>2] = $109;
   $219 = (($2) + 4|0);
   HEAPF32[$219>>2] = $110;
   $220 = (($2) + 8|0);
   HEAPF32[$220>>2] = $111;
   $221 = (($2) + 12|0);
   HEAPF32[$221>>2] = $90;
   HEAPF32[$$pre$phiZ2D>>2] = $81;
   HEAPF32[$$pre$phi332Z2D>>2] = $82;
   HEAPF32[$$pre$phi334Z2D>>2] = $83;
   $222 = (($2) + 28|0);
   HEAPF32[$222>>2] = Math_fround(0.0);
   $223 = (($shape1) + 16|0);
   $224 = Math_fround(HEAPF32[$223>>2]);
   $225 = (($shape1) + 20|0);
   $226 = Math_fround(HEAPF32[$225>>2]);
   $227 = (($shape1) + 24|0);
   $228 = Math_fround(HEAPF32[$227>>2]);
   $229 = (($shape1) + 28|0);
   $230 = Math_fround(HEAPF32[$229>>2]);
   HEAPF32[$vQuat>>2] = $224;
   $231 = (($vQuat) + 4|0);
   HEAPF32[$231>>2] = $226;
   $232 = (($vQuat) + 8|0);
   HEAPF32[$232>>2] = $228;
   $233 = (($vQuat) + 12|0);
   HEAPF32[$233>>2] = $230;
   __ZN5physx2Gu11ConvexHullVC2EPKNS0_14ConvexHullDataERKNS_6shdfnd3aos5Vec3VES9_RKNS6_5Vec4VE($convexHull,$17,$zeroV,$vScale,$vQuat);
   $234 = (($convexHull) + 16|0);
   HEAPF32[$234>>2] = Math_fround(0.0);
   $235 = (($convexHull) + 20|0);
   ;HEAP32[$235+0>>2]=HEAP32[$zero$sroa$1+0>>2]|0;HEAP32[$235+4>>2]=HEAP32[$zero$sroa$1+4>>2]|0;HEAP32[$235+8>>2]=HEAP32[$zero$sroa$1+8>>2]|0;
   $236 = (($aToB) + 48|0);
   $237 = (($capsule) + 64|0);
   $238 = (($capsule) + 80|0);
   HEAP32[$238>>2] = 4;
   $239 = (($capsule) + 16|0);
   $240 = (($capsule) + 20|0);
   $241 = (($capsule) + 32|0);
   $242 = (($capsule) + 36|0);
   $243 = (($capsule) + 48|0);
   HEAPF32[$243>>2] = Math_fround(0.0);
   $244 = (($capsule) + 52|0);
   ;HEAP32[$244+0>>2]=HEAP32[$zero$sroa$1$i$i$i+0>>2]|0;HEAP32[$244+4>>2]=HEAP32[$zero$sroa$1$i$i$i+4>>2]|0;HEAP32[$244+8>>2]=HEAP32[$zero$sroa$1$i$i$i+8>>2]|0;
   $245 = (($capsule) + 96|0);
   $246 = (($capsule) + 112|0);
   ;HEAP32[$capsule+0>>2]=HEAP32[$236+0>>2]|0;HEAP32[$capsule+4>>2]=HEAP32[$236+4>>2]|0;HEAP32[$capsule+8>>2]=HEAP32[$236+8>>2]|0;HEAP32[$capsule+12>>2]=HEAP32[$236+12>>2]|0;
   $247 = (($capsule) + 128|0);
   HEAPF32[$247>>2] = $15;
   $248 = (($capsule) + 132|0);
   ;HEAP32[$248+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$248+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$248+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
   ;HEAP32[$245+0>>2]=HEAP32[$236+0>>2]|0;HEAP32[$245+4>>2]=HEAP32[$236+4>>2]|0;HEAP32[$245+8>>2]=HEAP32[$236+8>>2]|0;HEAP32[$245+12>>2]=HEAP32[$236+12>>2]|0;
   ;HEAP32[$246+0>>2]=HEAP32[$236+0>>2]|0;HEAP32[$246+4>>2]=HEAP32[$236+4>>2]|0;HEAP32[$246+8>>2]=HEAP32[$236+8>>2]|0;HEAP32[$246+12>>2]=HEAP32[$236+12>>2]|0;
   HEAPF32[$239>>2] = $15;
   ;HEAP32[$240+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$240+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$240+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
   HEAPF32[$241>>2] = $15;
   ;HEAP32[$242+0>>2]=HEAP32[$sphereRadius$sroa$1+0>>2]|0;HEAP32[$242+4>>2]=HEAP32[$sphereRadius$sroa$1+4>>2]|0;HEAP32[$242+8>>2]=HEAP32[$sphereRadius$sroa$1+8>>2]|0;
   ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
   ;HEAP32[$237+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$237+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$237+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$237+12>>2]=HEAP32[$0+12>>2]|0;
   $249 = Math_fround(HEAPF32[$5>>2]);
   $250 = $249 == Math_fround(1.0);
   if ($250) {
    $251 = Math_fround(HEAPF32[$7>>2]);
    $252 = $251 == Math_fround(1.0);
    if ($252) {
     $253 = Math_fround(HEAPF32[$9>>2]);
     $254 = $253 == Math_fround(1.0);
     if ($254) {
      $255 = (($2) + 34|0);
      $256 = (($2) + 38|0);
      $257 = (($2) + 33|0);
      $258 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_18ConvexHullNoScaleVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($capsule,$convexHull,$contactDist,$closestA,$closestB,$normal,$penDep,$255,$256,$257,1)|0);
      $status$0 = $258;
     } else {
      label = 9;
     }
    } else {
     label = 9;
    }
   } else {
    label = 9;
   }
   if ((label|0) == 9) {
    $259 = (($2) + 34|0);
    $260 = (($2) + 38|0);
    $261 = (($2) + 33|0);
    $262 = (__ZN5physx2Gu19gjkLocalPenetrationINS0_8CapsuleVENS0_11ConvexHullVEEEjRKT_RKT0_RKNS_6shdfnd3aos6FloatVERNSB_5Vec3VESG_SG_RSC_PhSI_Rhb($capsule,$convexHull,$contactDist,$closestA,$closestB,$normal,$penDep,$259,$260,$261,1)|0);
    $status$0 = $262;
   }
   if ((($status$0|0) == 6)) {
    $325 = (($supportMap) + 4|0);
    HEAP8[$325>>0] = 0;
    HEAP32[$supportMap>>2] = ((550992 + 8|0));
    $326 = (($supportMap) + 8|0);
    HEAP32[$326>>2] = $capsule;
    $327 = (($supportMap) + 12|0);
    HEAP32[$327>>2] = $convexHull;
    $328 = (($2) + 34|0);
    $329 = (($2) + 38|0);
    $330 = (($2) + 33|0);
    $331 = HEAP8[$330>>0]|0;
    $332 = (__ZN5physx2Gu14epaPenetrationERKNS0_7ConvexVES3_PNS0_17EPASupportMapPairEPhS6_hRNS_6shdfnd3aos5Vec3VESA_SA_RNS8_6FloatVEb($capsule,$convexHull,$supportMap,$328,$329,$331,$closestA,$closestB,$normal,$penDep,1)|0);
    $$off = (($332) + -5)|0;
    $333 = ($$off>>>0)<(2);
    $$ = $333 ? 1 : $332;
    $status$2 = $$;
    label = 15;
    break;
   } else if (!((($status$0|0) == 1))) {
    $status$2 = $status$0;
    label = 15;
    break;
   }
   $263 = (($convexHull) + 192|0);
   $264 = HEAP32[$263>>2]|0;
   $265 = (($264) + 24|0);
   $266 = Math_fround(HEAPF32[$265>>2]);
   $267 = (($264) + 28|0);
   $268 = Math_fround(HEAPF32[$267>>2]);
   $269 = (($264) + 32|0);
   $270 = Math_fround(HEAPF32[$269>>2]);
   $271 = (($convexHull) + 96|0);
   $272 = Math_fround(HEAPF32[$271>>2]);
   $273 = Math_fround($266 * $272);
   $274 = (($convexHull) + 112|0);
   $275 = Math_fround(HEAPF32[$274>>2]);
   $276 = Math_fround($268 * $275);
   $277 = Math_fround($273 + $276);
   $278 = (($convexHull) + 128|0);
   $279 = Math_fround(HEAPF32[$278>>2]);
   $280 = Math_fround($270 * $279);
   $281 = Math_fround($277 + $280);
   $282 = (($convexHull) + 100|0);
   $283 = Math_fround(HEAPF32[$282>>2]);
   $284 = Math_fround($266 * $283);
   $285 = (($convexHull) + 116|0);
   $286 = Math_fround(HEAPF32[$285>>2]);
   $287 = Math_fround($268 * $286);
   $288 = Math_fround($284 + $287);
   $289 = (($convexHull) + 132|0);
   $290 = Math_fround(HEAPF32[$289>>2]);
   $291 = Math_fround($270 * $290);
   $292 = Math_fround($288 + $291);
   $293 = (($convexHull) + 104|0);
   $294 = Math_fround(HEAPF32[$293>>2]);
   $295 = Math_fround($266 * $294);
   $296 = (($convexHull) + 120|0);
   $297 = Math_fround(HEAPF32[$296>>2]);
   $298 = Math_fround($268 * $297);
   $299 = Math_fround($295 + $298);
   $300 = (($convexHull) + 136|0);
   $301 = Math_fround(HEAPF32[$300>>2]);
   $302 = Math_fround($270 * $301);
   $303 = Math_fround($299 + $302);
   $304 = Math_fround(HEAPF32[$112>>2]);
   $305 = Math_fround(HEAPF32[$113>>2]);
   $306 = Math_fround(HEAPF32[$114>>2]);
   $307 = Math_fround($304 - $281);
   $308 = Math_fround($305 - $292);
   $309 = Math_fround($306 - $303);
   $310 = Math_fround(HEAPF32[$normal>>2]);
   $311 = (($normal) + 4|0);
   $312 = Math_fround(HEAPF32[$311>>2]);
   $313 = (($normal) + 8|0);
   $314 = Math_fround(HEAPF32[$313>>2]);
   $315 = Math_fround($307 * $310);
   $316 = Math_fround($308 * $312);
   $317 = Math_fround($315 + $316);
   $318 = Math_fround($309 * $314);
   $319 = Math_fround($317 + $318);
   $320 = $319 < Math_fround(0.0);
   if ($320) {
    $321 = (($normal) + 12|0);
    $322 = Math_fround(-$310);
    $323 = Math_fround(-$312);
    $324 = Math_fround(-$314);
    HEAPF32[$normal>>2] = $322;
    HEAPF32[$311>>2] = $323;
    HEAPF32[$313>>2] = $324;
    HEAPF32[$321>>2] = Math_fround(0.0);
   }
   $334 = (($2) + 44|0);
   $335 = HEAP32[$334>>2]|0;
   $340 = $335;
  }
 } while(0);
 if ((label|0) == 15) {
  $336 = ($status$2|0)==(0);
  if ($336) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $337 = (($2) + 44|0);
  $338 = HEAP32[$337>>2]|0;
  $339 = ($status$2|0)==(1);
  if ($339) {
   $340 = $338;
  } else {
   $410 = HEAP8[$166>>0]|0;
   $411 = ($410<<24>>24)==(0);
   if ($411) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $412 = (($338) + 32|0);
   $413 = Math_fround(HEAPF32[$412>>2]);
   $414 = (($338) + 36|0);
   $415 = Math_fround(HEAPF32[$414>>2]);
   $416 = (($338) + 40|0);
   $417 = Math_fround(HEAPF32[$416>>2]);
   $418 = (($338) + 44|0);
   $419 = Math_fround($51 * $413);
   $420 = Math_fround($51 * $415);
   $421 = Math_fround($51 * $417);
   $422 = Math_fround($33 * $417);
   $423 = Math_fround($35 * $415);
   $424 = Math_fround($422 - $423);
   $425 = Math_fround($35 * $413);
   $426 = Math_fround($31 * $417);
   $427 = Math_fround($425 - $426);
   $428 = Math_fround($31 * $415);
   $429 = Math_fround($33 * $413);
   $430 = Math_fround($428 - $429);
   $431 = Math_fround($37 * $424);
   $432 = Math_fround($37 * $427);
   $433 = Math_fround($37 * $430);
   $434 = Math_fround($419 + $431);
   $435 = Math_fround($420 + $432);
   $436 = Math_fround($421 + $433);
   $437 = Math_fround($31 * $413);
   $438 = Math_fround($33 * $415);
   $439 = Math_fround($437 + $438);
   $440 = Math_fround($35 * $417);
   $441 = Math_fround($439 + $440);
   $442 = Math_fround($31 * $441);
   $443 = Math_fround($33 * $441);
   $444 = Math_fround($35 * $441);
   $445 = Math_fround($442 + $434);
   $446 = Math_fround($443 + $435);
   $447 = Math_fround($436 + $444);
   $448 = Math_fround($445 * Math_fround(2.0));
   $449 = Math_fround($446 * Math_fround(2.0));
   $450 = Math_fround($447 * Math_fround(2.0));
   HEAPF32[$normal>>2] = $448;
   $451 = (($normal) + 4|0);
   HEAPF32[$451>>2] = $449;
   $452 = (($normal) + 8|0);
   HEAPF32[$452>>2] = $450;
   $453 = (($normal) + 12|0);
   HEAPF32[$453>>2] = Math_fround(0.0);
   $454 = Math_fround($15 * $448);
   $455 = Math_fround($15 * $449);
   $456 = Math_fround($15 * $450);
   $457 = Math_fround($26 - $454);
   $458 = Math_fround($28 - $455);
   $459 = Math_fround($30 - $456);
   $460 = Math_fround(HEAPF32[$418>>2]);
   $461 = Math_fround($460 - $15);
   HEAPF32[$penDep>>2] = $461;
   ;HEAP32[$172+0>>2]=HEAP32[$$sroa$182+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$$sroa$182+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$$sroa$182+8>>2]|0;
   $462 = (($contactBuffer) + 4096|0);
   $463 = HEAP32[$462>>2]|0;
   $464 = (($463) + 1)|0;
   HEAP32[$462>>2] = $464;
   $465 = (($contactBuffer) + ($463<<6)|0);
   HEAPF32[$465>>2] = $448;
   $466 = (($465) + 4|0);
   HEAPF32[$466>>2] = $449;
   $467 = (($465) + 8|0);
   HEAPF32[$467>>2] = $450;
   $468 = (($465) + 12|0);
   HEAPF32[$468>>2] = Math_fround(0.0);
   $469 = ((($contactBuffer) + ($463<<6)|0) + 16|0);
   HEAPF32[$469>>2] = $457;
   $470 = (($469) + 4|0);
   HEAPF32[$470>>2] = $458;
   $471 = (($469) + 8|0);
   HEAPF32[$471>>2] = $459;
   $472 = (($469) + 12|0);
   HEAPF32[$472>>2] = Math_fround(0.0);
   $473 = ((($contactBuffer) + ($463<<6)|0) + 12|0);
   HEAPF32[$473>>2] = $461;
   $474 = ((($contactBuffer) + ($463<<6)|0) + 48|0);
   HEAP32[$474>>2] = -1;
   $475 = ((($contactBuffer) + ($463<<6)|0) + 52|0);
   HEAP32[$475>>2] = -1;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 ;HEAP32[$340+0>>2]=HEAP32[$zeroV+0>>2]|0;HEAP32[$340+4>>2]=HEAP32[$zeroV+4>>2]|0;HEAP32[$340+8>>2]=HEAP32[$zeroV+8>>2]|0;HEAP32[$340+12>>2]=HEAP32[$zeroV+12>>2]|0;
 $341 = (($340) + 16|0);
 ;HEAP32[$341+0>>2]=HEAP32[$closestB+0>>2]|0;HEAP32[$341+4>>2]=HEAP32[$closestB+4>>2]|0;HEAP32[$341+8>>2]=HEAP32[$closestB+8>>2]|0;HEAP32[$341+12>>2]=HEAP32[$closestB+12>>2]|0;
 $342 = Math_fround(HEAPF32[$normal>>2]);
 $343 = (($normal) + 4|0);
 $344 = Math_fround(HEAPF32[$343>>2]);
 $345 = (($normal) + 8|0);
 $346 = Math_fround(HEAPF32[$345>>2]);
 $347 = (($normal) + 12|0);
 $348 = Math_fround(HEAPF32[$penDep>>2]);
 $349 = (($340) + 32|0);
 HEAPF32[$349>>2] = $342;
 $350 = (($340) + 36|0);
 HEAPF32[$350>>2] = $344;
 $351 = (($340) + 40|0);
 HEAPF32[$351>>2] = $346;
 $352 = (($340) + 44|0);
 HEAPF32[$352>>2] = $348;
 HEAP8[$166>>0] = 1;
 $353 = (($contactBuffer) + 4096|0);
 $354 = HEAP32[$353>>2]|0;
 $355 = (($354) + 1)|0;
 HEAP32[$353>>2] = $355;
 $356 = Math_fround(HEAPF32[$normal>>2]);
 $357 = Math_fround(HEAPF32[$343>>2]);
 $358 = Math_fround(HEAPF32[$345>>2]);
 $359 = Math_fround($51 * $356);
 $360 = Math_fround($51 * $357);
 $361 = Math_fround($51 * $358);
 $362 = Math_fround($33 * $358);
 $363 = Math_fround($35 * $357);
 $364 = Math_fround($362 - $363);
 $365 = Math_fround($35 * $356);
 $366 = Math_fround($31 * $358);
 $367 = Math_fround($365 - $366);
 $368 = Math_fround($31 * $357);
 $369 = Math_fround($33 * $356);
 $370 = Math_fround($368 - $369);
 $371 = Math_fround($37 * $364);
 $372 = Math_fround($37 * $367);
 $373 = Math_fround($37 * $370);
 $374 = Math_fround($359 + $371);
 $375 = Math_fround($360 + $372);
 $376 = Math_fround($361 + $373);
 $377 = Math_fround($31 * $356);
 $378 = Math_fround($33 * $357);
 $379 = Math_fround($377 + $378);
 $380 = Math_fround($35 * $358);
 $381 = Math_fround($379 + $380);
 $382 = Math_fround($31 * $381);
 $383 = Math_fround($33 * $381);
 $384 = Math_fround($35 * $381);
 $385 = Math_fround($382 + $374);
 $386 = Math_fround($383 + $375);
 $387 = Math_fround($376 + $384);
 $388 = Math_fround($385 * Math_fround(2.0));
 $389 = Math_fround($386 * Math_fround(2.0));
 $390 = Math_fround($387 * Math_fround(2.0));
 HEAPF32[$normal>>2] = $388;
 HEAPF32[$343>>2] = $389;
 HEAPF32[$345>>2] = $390;
 HEAPF32[$347>>2] = Math_fround(0.0);
 $391 = Math_fround($15 * $388);
 $392 = Math_fround($15 * $389);
 $393 = Math_fround($15 * $390);
 $394 = Math_fround($26 - $391);
 $395 = Math_fround($28 - $392);
 $396 = Math_fround($30 - $393);
 $397 = Math_fround(HEAPF32[$penDep>>2]);
 $398 = Math_fround($397 - $15);
 HEAPF32[$penDep>>2] = $398;
 ;HEAP32[$172+0>>2]=HEAP32[$$sroa$1104+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$$sroa$1104+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$$sroa$1104+8>>2]|0;
 $399 = (($contactBuffer) + ($354<<6)|0);
 HEAPF32[$399>>2] = $388;
 $400 = (($399) + 4|0);
 HEAPF32[$400>>2] = $389;
 $401 = (($399) + 8|0);
 HEAPF32[$401>>2] = $390;
 $402 = (($399) + 12|0);
 HEAPF32[$402>>2] = Math_fround(0.0);
 $403 = ((($contactBuffer) + ($354<<6)|0) + 16|0);
 HEAPF32[$403>>2] = $394;
 $404 = (($403) + 4|0);
 HEAPF32[$404>>2] = $395;
 $405 = (($403) + 8|0);
 HEAPF32[$405>>2] = $396;
 $406 = (($403) + 12|0);
 HEAPF32[$406>>2] = Math_fround(0.0);
 $407 = ((($contactBuffer) + ($354<<6)|0) + 12|0);
 HEAPF32[$407>>2] = $398;
 $408 = ((($contactBuffer) + ($354<<6)|0) + 48|0);
 HEAP32[$408>>2] = -1;
 $409 = ((($contactBuffer) + ($354<<6)|0) + 52|0);
 HEAP32[$409>>2] = -1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu20pcmContactSphereMeshERKNS0_13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS0_5CacheERNS0_13ContactBufferE($shape0,$shape1,$transform0,$transform1,$contactDistance,$cache,$contactBuffer) {
 $shape0 = $shape0|0;
 $shape1 = $shape1|0;
 $transform0 = $transform0|0;
 $transform1 = $transform1|0;
 $contactDistance = $contactDistance|0;
 $cache = $cache|0;
 $contactBuffer = $contactBuffer|0;
 var $$$i$i$i = Math_fround(0), $$$i$i$i$i = Math_fround(0), $$1$i$i$i$i = Math_fround(0), $$pre = Math_fround(0), $$pre35 = Math_fround(0), $$pre36 = Math_fround(0), $$pre37 = Math_fround(0), $$pre38 = Math_fround(0), $$pre39 = Math_fround(0), $$pre40 = Math_fround(0), $$pre41 = Math_fround(0), $$pre42 = Math_fround(0), $$pre43 = Math_fround(0), $$pre44 = Math_fround(0), $$pre45 = Math_fround(0), $$pre46 = Math_fround(0), $$pre47 = Math_fround(0), $$pre48 = Math_fround(0), $0 = 0, $1 = 0;
 var $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0);
 var $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0);
 var $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0);
 var $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0);
 var $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0;
 var $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0);
 var $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = 0;
 var $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = 0, $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0;
 var $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0);
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_maxPen$i = 0, $aToB = 0, $callback = 0, $contactDist = 0, $count$01$i$i$i = 0, $edgeFlags$05$i$i$i = 0;
 var $hmd = 0, $i$04$i = 0, $i$1$i = 0, $meshScaling = 0, $meshTransform = 0, $obb = 0, $obbCenter = 0, $obbExtents = 0, $projectBreakingThreshold = 0, $refereshDistance = 0, $replaceBreakingThreshold = 0, $sphereRadius = 0, $sphereTransform = 0, $triInds$04$i$i$i = 0, $vertInds$03$i$i$i = 0, $verts$02$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3696|0;
 $_maxPen$i = sp + 3280|0;
 $sphereRadius = sp + 3504|0;
 $contactDist = sp + 3488|0;
 $sphereTransform = sp + 3456|0;
 $meshTransform = sp + 3328|0;
 $aToB = sp + 3360|0;
 $replaceBreakingThreshold = sp + 3424|0;
 $projectBreakingThreshold = sp + 3440|0;
 $refereshDistance = sp + 3264|0;
 $meshScaling = sp + 3616|0;
 $callback = sp;
 $hmd = sp + 3520|0;
 $obbCenter = sp + 3532|0;
 $obbExtents = sp + 3544|0;
 $obb = sp + 3556|0;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 & -16;
 $2 = $1;
 $3 = Math_fround(HEAPF32[$transform0>>2]);
 $4 = (($transform0) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($transform0) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($transform0) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($transform0) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($10) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($10) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(HEAPF32[$transform1>>2]);
 $17 = (($transform1) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($transform1) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($transform1) + 12|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($transform1) + 16|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($23) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($23) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($shape0) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$sphereRadius>>2] = $30;
 $31 = Math_fround(HEAPF32[$contactDistance>>2]);
 HEAPF32[$contactDist>>2] = $31;
 HEAPF32[$sphereTransform>>2] = $3;
 $32 = (($sphereTransform) + 4|0);
 HEAPF32[$32>>2] = $5;
 $33 = (($sphereTransform) + 8|0);
 HEAPF32[$33>>2] = $7;
 $34 = (($sphereTransform) + 12|0);
 HEAPF32[$34>>2] = $9;
 $35 = (($sphereTransform) + 16|0);
 HEAPF32[$35>>2] = $11;
 $36 = (($sphereTransform) + 20|0);
 HEAPF32[$36>>2] = $13;
 $37 = (($sphereTransform) + 24|0);
 HEAPF32[$37>>2] = $15;
 $38 = (($sphereTransform) + 28|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 HEAPF32[$meshTransform>>2] = $16;
 $39 = (($meshTransform) + 4|0);
 HEAPF32[$39>>2] = $18;
 $40 = (($meshTransform) + 8|0);
 HEAPF32[$40>>2] = $20;
 $41 = (($meshTransform) + 12|0);
 HEAPF32[$41>>2] = $22;
 $42 = (($meshTransform) + 16|0);
 HEAPF32[$42>>2] = $24;
 $43 = (($meshTransform) + 20|0);
 HEAPF32[$43>>2] = $26;
 $44 = (($meshTransform) + 24|0);
 HEAPF32[$44>>2] = $28;
 $45 = (($meshTransform) + 28|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = Math_fround(-$16);
 $47 = Math_fround(-$18);
 $48 = Math_fround(-$20);
 $49 = Math_fround($11 - $24);
 $50 = Math_fround($13 - $26);
 $51 = Math_fround($15 - $28);
 $52 = Math_fround($22 * $22);
 $53 = Math_fround($52 + Math_fround(-0.5));
 $54 = Math_fround($53 * $49);
 $55 = Math_fround($53 * $50);
 $56 = Math_fround($53 * $51);
 $57 = Math_fround($51 * $47);
 $58 = Math_fround($50 * $48);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($49 * $48);
 $61 = Math_fround($51 * $46);
 $62 = Math_fround($60 - $61);
 $63 = Math_fround($50 * $46);
 $64 = Math_fround($49 * $47);
 $65 = Math_fround($63 - $64);
 $66 = Math_fround($22 * $59);
 $67 = Math_fround($22 * $62);
 $68 = Math_fround($22 * $65);
 $69 = Math_fround($54 + $66);
 $70 = Math_fround($55 + $67);
 $71 = Math_fround($56 + $68);
 $72 = Math_fround($49 * $46);
 $73 = Math_fround($50 * $47);
 $74 = Math_fround($72 + $73);
 $75 = Math_fround($51 * $48);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($76 * $46);
 $78 = Math_fround($76 * $47);
 $79 = Math_fround($76 * $48);
 $80 = Math_fround($77 + $69);
 $81 = Math_fround($78 + $70);
 $82 = Math_fround($71 + $79);
 $83 = Math_fround($80 * Math_fround(2.0));
 $84 = Math_fround($81 * Math_fround(2.0));
 $85 = Math_fround($82 * Math_fround(2.0));
 $86 = Math_fround($22 * $9);
 $87 = Math_fround($3 * $46);
 $88 = Math_fround($5 * $47);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($7 * $48);
 $91 = Math_fround($89 + $90);
 $92 = Math_fround($86 - $91);
 $93 = Math_fround($9 * $46);
 $94 = Math_fround($9 * $47);
 $95 = Math_fround($9 * $48);
 $96 = Math_fround($22 * $3);
 $97 = Math_fround($22 * $5);
 $98 = Math_fround($22 * $7);
 $99 = Math_fround($7 * $47);
 $100 = Math_fround($5 * $48);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround($3 * $48);
 $103 = Math_fround($7 * $46);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($5 * $46);
 $106 = Math_fround($3 * $47);
 $107 = Math_fround($105 - $106);
 $108 = Math_fround($96 + $93);
 $109 = Math_fround($97 + $94);
 $110 = Math_fround($98 + $95);
 $111 = Math_fround($101 + $108);
 $112 = Math_fround($104 + $109);
 $113 = Math_fround($107 + $110);
 $114 = (($aToB) + 48|0);
 HEAPF32[$114>>2] = $83;
 $115 = (($aToB) + 52|0);
 HEAPF32[$115>>2] = $84;
 $116 = (($aToB) + 56|0);
 HEAPF32[$116>>2] = $85;
 $117 = (($aToB) + 60|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 $118 = Math_fround($111 + $111);
 $119 = Math_fround($112 + $112);
 $120 = Math_fround($113 + $113);
 $121 = Math_fround($111 * $118);
 $122 = Math_fround($112 * $119);
 $123 = Math_fround($113 * $120);
 $124 = Math_fround($112 * $118);
 $125 = Math_fround($113 * $118);
 $126 = Math_fround($92 * $118);
 $127 = Math_fround($113 * $119);
 $128 = Math_fround($92 * $119);
 $129 = Math_fround($92 * $120);
 $130 = Math_fround(Math_fround(1.0) - $121);
 $131 = Math_fround(Math_fround(1.0) - $122);
 $132 = Math_fround($131 - $123);
 $133 = Math_fround($124 + $129);
 $134 = Math_fround($125 - $128);
 $135 = Math_fround($124 - $129);
 $136 = Math_fround($130 - $123);
 $137 = Math_fround($127 + $126);
 $138 = Math_fround($125 + $128);
 $139 = Math_fround($127 - $126);
 $140 = Math_fround($130 - $122);
 HEAPF32[$aToB>>2] = $132;
 $141 = (($aToB) + 4|0);
 HEAPF32[$141>>2] = $133;
 $142 = (($aToB) + 8|0);
 HEAPF32[$142>>2] = $134;
 $143 = (($aToB) + 12|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = (($aToB) + 16|0);
 HEAPF32[$144>>2] = $135;
 $145 = (($aToB) + 20|0);
 HEAPF32[$145>>2] = $136;
 $146 = (($aToB) + 24|0);
 HEAPF32[$146>>2] = $137;
 $147 = (($aToB) + 28|0);
 HEAPF32[$147>>2] = Math_fround(0.0);
 $148 = (($aToB) + 32|0);
 HEAPF32[$148>>2] = $138;
 $149 = (($aToB) + 36|0);
 HEAPF32[$149>>2] = $139;
 $150 = (($aToB) + 40|0);
 HEAPF32[$150>>2] = $140;
 $151 = (($aToB) + 44|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = Math_fround(HEAPF32[$sphereRadius>>2]);
 $153 = Math_fround($152 * Math_fround(0.00100000004749745130539));
 HEAPF32[$replaceBreakingThreshold>>2] = $153;
 $154 = Math_fround($152 * Math_fround(0.0500000007450580596924));
 HEAPF32[$projectBreakingThreshold>>2] = $154;
 $155 = (($2) + 53|0);
 $156 = HEAP8[$155>>0]|0;
 $157 = Math_fround(HEAPF32[$contactDist>>2]);
 $158 = Math_fround($152 + $157);
 HEAPF32[$refereshDistance>>2] = $158;
 $159 = (($2) + 52|0);
 $160 = HEAP8[$159>>0]|0;
 $161 = ($160<<24>>24)==(0);
 if (!($161)) {
  $162 = $160&255;
  $166 = $162;$i$04$i = 0;
  while(1) {
   $163 = ((($2) + ($i$04$i)|0) + 48|0);
   $164 = HEAP8[$163>>0]|0;
   $165 = (($166) + -2)|0;
   $167 = ($i$04$i>>>0)<($165>>>0);
   $168 = $167 ? $i$04$i : $165;
   $169 = (($168) + 1)|0;
   $170 = ((($2) + ($169)|0) + 48|0);
   $171 = HEAP8[$170>>0]|0;
   $172 = $171&255;
   $173 = ((($2) + (($172*400)|0)|0) + 64|0);
   $174 = HEAP8[$170>>0]|0;
   $175 = $174&255;
   $176 = ((($2) + (($175*400)|0)|0) + 192|0);
   $177 = HEAP8[$170>>0]|0;
   $178 = $177&255;
   $179 = ((($2) + (($178*400)|0)|0) + 320|0);
   $180 = $164&255;
   $181 = ((($2) + (($180*400)|0)|0) + 64|0);
   __ZN5physx2Gu31SinglePersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($_maxPen$i,$181,$aToB,$projectBreakingThreshold,$refereshDistance);
   $182 = ((($2) + (($180*400)|0)|0) + 448|0);
   $183 = HEAP32[$182>>2]|0;
   $184 = ($183|0)==(0);
   if ($184) {
    $185 = HEAP8[$159>>0]|0;
    $186 = (($185) + -1)<<24>>24;
    HEAP8[$159>>0] = $186;
    $187 = $186&255;
    $188 = ((($2) + ($187)|0) + 48|0);
    $189 = HEAP8[$188>>0]|0;
    HEAP8[$188>>0] = $164;
    HEAP8[$163>>0] = $189;
    $190 = (($i$04$i) + -1)|0;
    $i$1$i = $190;
   } else {
    $191 = Math_fround(HEAPF32[$_maxPen$i>>2]);
    $192 = ((($2) + ($180<<2)|0) + 32|0);
    HEAPF32[$192>>2] = $191;
    $i$1$i = $i$04$i;
   }
   $193 = (($i$1$i) + 1)|0;
   $194 = HEAP8[$159>>0]|0;
   $195 = $194&255;
   $196 = ($193>>>0)<($195>>>0);
   if ($196) {
    $166 = $195;$i$04$i = $193;
   } else {
    break;
   }
  }
 }
 $197 = HEAP8[$155>>0]|0;
 $198 = ($197<<24>>24)==($156<<24>>24);
 if ($198) {
  $199 = Math_fround(HEAPF32[$sphereRadius>>2]);
  $200 = Math_fround($199 * Math_fround(0.0199999995529651641846));
  $201 = (($2) + 16|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($2) + 20|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = (($2) + 24|0);
  $206 = Math_fround(HEAPF32[$205>>2]);
  $207 = Math_fround($83 - $202);
  $208 = Math_fround($84 - $204);
  $209 = Math_fround($85 - $206);
  $210 = Math_fround(-$207);
  $211 = Math_fround(-$208);
  $212 = Math_fround(-$209);
  $213 = $207 > $210;
  $$$i$i$i$i = $213 ? $207 : $210;
  $214 = $208 > $211;
  $215 = $214 ? $208 : $211;
  $216 = $209 > $212;
  $$1$i$i$i$i = $216 ? $209 : $212;
  $217 = !($$$i$i$i$i >= $215);
  $$$i$i$i = $217 ? $215 : $$$i$i$i$i;
  $218 = !($$1$i$i$i$i >= Math_fround(0.0));
  $219 = $218 ? Math_fround(0.0) : $$$i$i$i$i;
  $220 = $$$i$i$i >= $219;
  $221 = $220 ? $$$i$i$i : $219;
  $222 = $221 > $200;
  if (!($222)) {
   $223 = (($2) + 4|0);
   $224 = (($2) + 8|0);
   $225 = Math_fround(HEAPF32[$223>>2]);
   $226 = Math_fround(HEAPF32[$2>>2]);
   $227 = Math_fround($112 * $225);
   $228 = Math_fround($111 * $226);
   $229 = (($2) + 12|0);
   $230 = Math_fround(HEAPF32[$224>>2]);
   $231 = Math_fround($113 * $230);
   $232 = Math_fround($227 + $228);
   $233 = Math_fround(HEAPF32[$229>>2]);
   $234 = Math_fround($92 * $233);
   $235 = Math_fround($232 + $231);
   $236 = Math_fround($235 + $234);
   $237 = $236 < Math_fround(0.999800026416778564453);
   if (!($237)) {
    $415 = (__ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVES8_RKNS5_6FloatVE($2,$contactBuffer,$sphereTransform,$meshTransform,$sphereRadius)|0);
    STACKTOP = sp;return ($415|0);
   }
  }
 }
 $238 = Math_fround(HEAPF32[$10>>2]);
 $239 = Math_fround(HEAPF32[$23>>2]);
 $240 = Math_fround($238 - $239);
 $241 = (($transform0) + 20|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 $243 = (($transform1) + 20|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = Math_fround($242 - $244);
 $246 = (($transform0) + 24|0);
 $247 = Math_fround(HEAPF32[$246>>2]);
 $248 = (($transform1) + 24|0);
 $249 = Math_fround(HEAPF32[$248>>2]);
 $250 = Math_fround($247 - $249);
 $251 = Math_fround($240 * Math_fround(2.0));
 $252 = Math_fround($245 * Math_fround(2.0));
 $253 = Math_fround($250 * Math_fround(2.0));
 $254 = (($transform1) + 12|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = Math_fround($255 * $255);
 $257 = Math_fround($256 + Math_fround(-0.5));
 $258 = Math_fround(HEAPF32[$transform1>>2]);
 $259 = Math_fround($251 * $258);
 $260 = (($transform1) + 4|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = Math_fround($252 * $261);
 $263 = Math_fround($259 + $262);
 $264 = (($transform1) + 8|0);
 $265 = Math_fround(HEAPF32[$264>>2]);
 $266 = Math_fround($253 * $265);
 $267 = Math_fround($263 + $266);
 $268 = Math_fround($251 * $257);
 $269 = Math_fround($253 * $261);
 $270 = Math_fround($252 * $265);
 $271 = Math_fround($269 - $270);
 $272 = Math_fround($255 * $271);
 $273 = Math_fround($268 - $272);
 $274 = Math_fround($258 * $267);
 $275 = Math_fround($274 + $273);
 $276 = Math_fround($252 * $257);
 $277 = Math_fround($251 * $265);
 $278 = Math_fround($253 * $258);
 $279 = Math_fround($277 - $278);
 $280 = Math_fround($255 * $279);
 $281 = Math_fround($276 - $280);
 $282 = Math_fround($261 * $267);
 $283 = Math_fround($282 + $281);
 $284 = Math_fround($253 * $257);
 $285 = Math_fround($252 * $258);
 $286 = Math_fround($251 * $261);
 $287 = Math_fround($285 - $286);
 $288 = Math_fround($255 * $287);
 $289 = Math_fround($284 - $288);
 $290 = Math_fround($265 * $267);
 $291 = Math_fround($289 + $290);
 $292 = Math_fround(HEAPF32[$29>>2]);
 $293 = Math_fround(HEAPF32[$contactDistance>>2]);
 $294 = Math_fround($292 + $293);
 HEAPF32[$meshScaling>>2] = Math_fround(1.0);
 $295 = (($meshScaling) + 4|0);
 HEAPF32[$295>>2] = Math_fround(0.0);
 $296 = (($meshScaling) + 8|0);
 HEAPF32[$296>>2] = Math_fround(0.0);
 $297 = (($meshScaling) + 12|0);
 HEAPF32[$297>>2] = Math_fround(0.0);
 $298 = (($meshScaling) + 16|0);
 HEAPF32[$298>>2] = Math_fround(1.0);
 $299 = (($meshScaling) + 20|0);
 HEAPF32[$299>>2] = Math_fround(0.0);
 $300 = (($meshScaling) + 24|0);
 HEAPF32[$300>>2] = Math_fround(0.0);
 $301 = (($meshScaling) + 28|0);
 HEAPF32[$301>>2] = Math_fround(0.0);
 $302 = (($meshScaling) + 32|0);
 HEAPF32[$302>>2] = Math_fround(1.0);
 $303 = (($meshScaling) + 36|0);
 HEAPF32[$303>>2] = Math_fround(1.0);
 $304 = (($meshScaling) + 40|0);
 HEAPF32[$304>>2] = Math_fround(0.0);
 $305 = (($meshScaling) + 44|0);
 HEAPF32[$305>>2] = Math_fround(0.0);
 $306 = (($meshScaling) + 48|0);
 HEAPF32[$306>>2] = Math_fround(0.0);
 $307 = (($meshScaling) + 52|0);
 HEAPF32[$307>>2] = Math_fround(1.0);
 $308 = (($meshScaling) + 56|0);
 HEAPF32[$308>>2] = Math_fround(0.0);
 $309 = (($meshScaling) + 60|0);
 HEAPF32[$309>>2] = Math_fround(0.0);
 $310 = (($meshScaling) + 64|0);
 HEAPF32[$310>>2] = Math_fround(0.0);
 $311 = (($meshScaling) + 68|0);
 HEAPF32[$311>>2] = Math_fround(1.0);
 $312 = (($shape1) + 4|0);
 $313 = Math_fround(HEAPF32[$312>>2]);
 $314 = $313 == Math_fround(1.0);
 if ($314) {
  $315 = (($shape1) + 8|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = $316 == Math_fround(1.0);
  if ($317) {
   $318 = (($shape1) + 12|0);
   $319 = Math_fround(HEAPF32[$318>>2]);
   $320 = $319 == Math_fround(1.0);
   if ($320) {
    $338 = 1;
   } else {
    label = 13;
   }
  } else {
   label = 13;
  }
 } else {
  label = 13;
 }
 if ((label|0) == 13) {
  $321 = (($shape1) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($meshScaling,$312,$321);
  $338 = 0;
 }
 $322 = (($shape1) + 40|0);
 $323 = HEAP32[$322>>2]|0;
 HEAP8[$159>>0] = 0;
 HEAPF32[$2>>2] = $111;
 $324 = (($2) + 4|0);
 HEAPF32[$324>>2] = $112;
 $325 = (($2) + 8|0);
 HEAPF32[$325>>2] = $113;
 $326 = (($2) + 12|0);
 HEAPF32[$326>>2] = $92;
 $327 = (($2) + 16|0);
 HEAPF32[$327>>2] = $83;
 $328 = (($2) + 20|0);
 HEAPF32[$328>>2] = $84;
 $329 = (($2) + 24|0);
 HEAPF32[$329>>2] = $85;
 $330 = (($2) + 28|0);
 HEAPF32[$330>>2] = Math_fround(0.0);
 $331 = (($323) + 152|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = (($callback) + 4|0);
 HEAP32[$333>>2] = 2;
 $334 = (($callback) + 8|0);
 HEAP32[$334>>2] = $meshScaling;
 $335 = (($callback) + 12|0);
 HEAP32[$335>>2] = $332;
 $336 = (($callback) + 16|0);
 $337 = $338&1;
 HEAP8[$336>>0] = $337;
 $339 = (($callback) + 868|0);
 HEAP32[$339>>2] = 0;
 HEAP32[$callback>>2] = ((554112 + 8|0));
 $340 = (($callback) + 880|0);
 __ZN5physx2Gu24PCMMeshContactGenerationC2ERKNS_6shdfnd3aos6FloatVES6_RKNS3_12PsTransformVES9_RNS0_33MultiplePersistentContactManifoldERNS0_13ContactBufferE($340,$contactDist,$replaceBreakingThreshold,$sphereTransform,$meshTransform,$2,$contactBuffer);
 $341 = (($callback) + 3216|0);
 HEAPF32[$341>>2] = $275;
 $342 = (($callback) + 3220|0);
 HEAPF32[$342>>2] = $283;
 $343 = (($callback) + 3224|0);
 HEAPF32[$343>>2] = $291;
 $344 = (($callback) + 3228|0);
 HEAPF32[$344>>2] = Math_fround(0.0);
 $345 = (($callback) + 3232|0);
 ;HEAP32[$345+0>>2]=HEAP32[$sphereRadius+0>>2]|0;HEAP32[$345+4>>2]=HEAP32[$sphereRadius+4>>2]|0;HEAP32[$345+8>>2]=HEAP32[$sphereRadius+8>>2]|0;HEAP32[$345+12>>2]=HEAP32[$sphereRadius+12>>2]|0;
 $346 = Math_fround(HEAPF32[$sphereRadius>>2]);
 $347 = Math_fround(HEAPF32[$contactDist>>2]);
 $348 = Math_fround($346 + $347);
 $349 = Math_fround($348 * $348);
 $350 = (($callback) + 3248|0);
 HEAPF32[$350>>2] = $349;
 $351 = (($callback) + 3252|0);
 ;HEAP32[$351+0>>2]=HEAP32[$_maxPen$i+0>>2]|0;HEAP32[$351+4>>2]=HEAP32[$_maxPen$i+4>>2]|0;HEAP32[$351+8>>2]=HEAP32[$_maxPen$i+8>>2]|0;
 $352 = (($323) + 16|0);
 $353 = HEAP32[$352>>2]|0;
 HEAP32[$hmd>>2] = $353;
 $354 = (($323) + 32|0);
 $355 = (($hmd) + 4|0);
 HEAP32[$355>>2] = $354;
 $356 = (($323) + 20|0);
 $357 = Math_fround(HEAPF32[$356>>2]);
 $358 = (($hmd) + 8|0);
 HEAPF32[$358>>2] = $357;
 HEAPF32[$obbCenter>>2] = $275;
 $359 = (($obbCenter) + 4|0);
 HEAPF32[$359>>2] = $283;
 $360 = (($obbCenter) + 8|0);
 HEAPF32[$360>>2] = $291;
 HEAPF32[$obbExtents>>2] = $294;
 $361 = (($obbExtents) + 4|0);
 HEAPF32[$361>>2] = $294;
 $362 = (($obbExtents) + 8|0);
 HEAPF32[$362>>2] = $294;
 HEAPF32[$_maxPen$i>>2] = Math_fround(1.0);
 $363 = (($_maxPen$i) + 4|0);
 HEAPF32[$363>>2] = Math_fround(0.0);
 $364 = (($_maxPen$i) + 8|0);
 HEAPF32[$364>>2] = Math_fround(0.0);
 $365 = (($_maxPen$i) + 12|0);
 HEAPF32[$365>>2] = Math_fround(0.0);
 $366 = (($_maxPen$i) + 16|0);
 HEAPF32[$366>>2] = Math_fround(1.0);
 $367 = (($_maxPen$i) + 20|0);
 HEAPF32[$367>>2] = Math_fround(0.0);
 $368 = (($_maxPen$i) + 24|0);
 HEAPF32[$368>>2] = Math_fround(0.0);
 $369 = (($_maxPen$i) + 28|0);
 HEAPF32[$369>>2] = Math_fround(0.0);
 $370 = (($_maxPen$i) + 32|0);
 HEAPF32[$370>>2] = Math_fround(1.0);
 if ($338) {
  $371 = Math_fround(1.0);$373 = Math_fround(0.0);$375 = Math_fround(0.0);$377 = Math_fround(0.0);$379 = Math_fround(1.0);$381 = Math_fround(0.0);$383 = Math_fround(0.0);$385 = Math_fround(0.0);$387 = Math_fround(1.0);$389 = $275;$391 = $283;$393 = $291;$395 = $294;$397 = $294;$399 = $294;
 } else {
  __ZNK5physx2Cm23FastVertex2ShapeScaling20transformQueryBoundsERNS_6PxVec3ES3_RNS_7PxMat33E($meshScaling,$obbCenter,$obbExtents,$_maxPen$i);
  $$pre = Math_fround(HEAPF32[$_maxPen$i>>2]);
  $$pre35 = Math_fround(HEAPF32[$363>>2]);
  $$pre36 = Math_fround(HEAPF32[$364>>2]);
  $$pre37 = Math_fround(HEAPF32[$365>>2]);
  $$pre38 = Math_fround(HEAPF32[$366>>2]);
  $$pre39 = Math_fround(HEAPF32[$367>>2]);
  $$pre40 = Math_fround(HEAPF32[$368>>2]);
  $$pre41 = Math_fround(HEAPF32[$369>>2]);
  $$pre42 = Math_fround(HEAPF32[$370>>2]);
  $$pre43 = Math_fround(HEAPF32[$obbCenter>>2]);
  $$pre44 = Math_fround(HEAPF32[$359>>2]);
  $$pre45 = Math_fround(HEAPF32[$360>>2]);
  $$pre46 = Math_fround(HEAPF32[$obbExtents>>2]);
  $$pre47 = Math_fround(HEAPF32[$361>>2]);
  $$pre48 = Math_fround(HEAPF32[$362>>2]);
  $371 = $$pre;$373 = $$pre35;$375 = $$pre36;$377 = $$pre37;$379 = $$pre38;$381 = $$pre39;$383 = $$pre40;$385 = $$pre41;$387 = $$pre42;$389 = $$pre43;$391 = $$pre44;$393 = $$pre45;$395 = $$pre46;$397 = $$pre47;$399 = $$pre48;
 }
 HEAPF32[$obb>>2] = $371;
 $372 = (($obb) + 4|0);
 HEAPF32[$372>>2] = $373;
 $374 = (($obb) + 8|0);
 HEAPF32[$374>>2] = $375;
 $376 = (($obb) + 12|0);
 HEAPF32[$376>>2] = $377;
 $378 = (($obb) + 16|0);
 HEAPF32[$378>>2] = $379;
 $380 = (($obb) + 20|0);
 HEAPF32[$380>>2] = $381;
 $382 = (($obb) + 24|0);
 HEAPF32[$382>>2] = $383;
 $384 = (($obb) + 28|0);
 HEAPF32[$384>>2] = $385;
 $386 = (($obb) + 32|0);
 HEAPF32[$386>>2] = $387;
 $388 = (($obb) + 36|0);
 HEAPF32[$388>>2] = $389;
 $390 = (($obb) + 40|0);
 HEAPF32[$390>>2] = $391;
 $392 = (($obb) + 44|0);
 HEAPF32[$392>>2] = $393;
 $394 = (($obb) + 48|0);
 HEAPF32[$394>>2] = $395;
 $396 = (($obb) + 52|0);
 HEAPF32[$396>>2] = $397;
 $398 = (($obb) + 56|0);
 HEAPF32[$398>>2] = $399;
 __ZN5physx2Gu15MeshRayCollider10collideOBBERKNS0_3BoxEbRKNS0_17RTreeMidphaseDataERNS0_15MeshHitCallbackINS_12PxRaycastHitEEEb($obb,1,$hmd,$callback,1);
 $400 = HEAP32[$339>>2]|0;
 $401 = ($400|0)==(0);
 if (!($401)) {
  $402 = (($callback) + 880|0);
  $403 = (($callback) + 852|0);
  $404 = (($callback) + 788|0);
  $405 = (($callback) + 596|0);
  $406 = (($callback) + 20|0);
  $count$01$i$i$i = $400;$edgeFlags$05$i$i$i = $403;$triInds$04$i$i$i = $404;$vertInds$03$i$i$i = $405;$verts$02$i$i$i = $406;
  while(1) {
   $407 = (($count$01$i$i$i) + -1)|0;
   $408 = HEAP32[$triInds$04$i$i$i>>2]|0;
   $409 = HEAP8[$edgeFlags$05$i$i$i>>0]|0;
   (__ZN5physx2Gu32PCMSphereVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($402,$verts$02$i$i$i,$408,$409,$vertInds$03$i$i$i)|0);
   $410 = (($verts$02$i$i$i) + 36|0);
   $411 = (($vertInds$03$i$i$i) + 12|0);
   $412 = (($triInds$04$i$i$i) + 4|0);
   $413 = (($edgeFlags$05$i$i$i) + 1|0);
   $414 = ($407|0)==(0);
   if ($414) {
    break;
   } else {
    $count$01$i$i$i = $407;$edgeFlags$05$i$i$i = $413;$triInds$04$i$i$i = $412;$vertInds$03$i$i$i = $411;$verts$02$i$i$i = $410;
   }
  }
  HEAP32[$339>>2] = 0;
 }
 __ZN5physx2Gu24PCMMeshContactGeneration15processContactsEhb($340,1,0);
 $415 = (__ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVES8_RKNS5_6FloatVE($2,$contactBuffer,$sphereTransform,$meshTransform,$sphereRadius)|0);
 STACKTOP = sp;return ($415|0);
}
function __ZN5physx40PCMSphereVsMeshContactGenerationCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32PCMMeshContactGenerationCallbackINS_40PCMSphereVsMeshContactGenerationCallbackEE10processHitERKNS_12PxRaycastHitERKNS_6PxVec3ES9_S9_RfPKj($this,$hit,$v0,$v1,$v2,$0,$vinds) {
 $this = $this|0;
 $hit = $hit|0;
 $v0 = $v0|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 $0 = $0|0;
 $vinds = $vinds|0;
 var $$phi$trans$insert11 = 0, $$phi$trans$insert13 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert17 = 0, $$phi$trans$insert19 = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert7 = 0, $$phi$trans$insert9 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $$pre12 = Math_fround(0), $$pre14 = Math_fround(0), $$pre16 = Math_fround(0), $$pre18 = Math_fround(0), $$pre20 = Math_fround(0), $$pre22 = Math_fround(0), $$pre8 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0);
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0);
 var $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0);
 var $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0);
 var $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0;
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $count$01$i$i = 0, $edgeFlags$05$i$i = 0, $triInds$04$i$i = 0, $v = 0, $vertInds$03$i$i = 0, $verts$02$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $v = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $27 = (($this) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = Math_fround(HEAPF32[$v0>>2]);
  $30 = Math_fround(HEAPF32[$28>>2]);
  $31 = Math_fround($29 * $30);
  $32 = (($28) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($29 * $33);
  $35 = (($28) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($29 * $36);
  $38 = (($v0) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($28) + 12|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($39 * $41);
  $43 = (($28) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($39 * $44);
  $46 = (($28) + 20|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($39 * $47);
  $49 = Math_fround($31 + $42);
  $50 = Math_fround($34 + $45);
  $51 = Math_fround($37 + $48);
  $52 = (($v0) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($28) + 24|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($53 * $55);
  $57 = (($28) + 28|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($53 * $58);
  $60 = (($28) + 32|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($53 * $61);
  $63 = Math_fround($49 + $56);
  $64 = Math_fround($50 + $59);
  $65 = Math_fround($51 + $62);
  HEAPF32[$v>>2] = $63;
  $66 = (($v) + 4|0);
  HEAPF32[$66>>2] = $64;
  $67 = (($v) + 8|0);
  HEAPF32[$67>>2] = $65;
  $68 = Math_fround(HEAPF32[$v1>>2]);
  $69 = Math_fround(HEAPF32[$28>>2]);
  $70 = Math_fround($68 * $69);
  $71 = Math_fround(HEAPF32[$32>>2]);
  $72 = Math_fround($68 * $71);
  $73 = Math_fround(HEAPF32[$35>>2]);
  $74 = Math_fround($68 * $73);
  $75 = (($v1) + 4|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround(HEAPF32[$40>>2]);
  $78 = Math_fround($76 * $77);
  $79 = Math_fround(HEAPF32[$43>>2]);
  $80 = Math_fround($76 * $79);
  $81 = Math_fround(HEAPF32[$46>>2]);
  $82 = Math_fround($76 * $81);
  $83 = Math_fround($70 + $78);
  $84 = Math_fround($72 + $80);
  $85 = Math_fround($74 + $82);
  $86 = (($v1) + 8|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = Math_fround(HEAPF32[$54>>2]);
  $89 = Math_fround($87 * $88);
  $90 = Math_fround(HEAPF32[$57>>2]);
  $91 = Math_fround($87 * $90);
  $92 = Math_fround(HEAPF32[$60>>2]);
  $93 = Math_fround($87 * $92);
  $94 = Math_fround($83 + $89);
  $95 = Math_fround($84 + $91);
  $96 = Math_fround($85 + $93);
  $97 = (($v) + 12|0);
  HEAPF32[$97>>2] = $94;
  $98 = (($v) + 16|0);
  HEAPF32[$98>>2] = $95;
  $99 = (($v) + 20|0);
  HEAPF32[$99>>2] = $96;
  $100 = Math_fround(HEAPF32[$v2>>2]);
  $101 = Math_fround(HEAPF32[$28>>2]);
  $102 = Math_fround($100 * $101);
  $103 = Math_fround(HEAPF32[$32>>2]);
  $104 = Math_fround($100 * $103);
  $105 = Math_fround(HEAPF32[$35>>2]);
  $106 = Math_fround($100 * $105);
  $107 = (($v2) + 4|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround(HEAPF32[$40>>2]);
  $110 = Math_fround($108 * $109);
  $111 = Math_fround(HEAPF32[$43>>2]);
  $112 = Math_fround($108 * $111);
  $113 = Math_fround(HEAPF32[$46>>2]);
  $114 = Math_fround($108 * $113);
  $115 = Math_fround($102 + $110);
  $116 = Math_fround($104 + $112);
  $117 = Math_fround($106 + $114);
  $118 = (($v2) + 8|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround(HEAPF32[$54>>2]);
  $121 = Math_fround($119 * $120);
  $122 = Math_fround(HEAPF32[$57>>2]);
  $123 = Math_fround($119 * $122);
  $124 = Math_fround(HEAPF32[$60>>2]);
  $125 = Math_fround($119 * $124);
  $126 = Math_fround($115 + $121);
  $127 = Math_fround($116 + $123);
  $128 = Math_fround($117 + $125);
  $129 = (($v) + 24|0);
  HEAPF32[$129>>2] = $126;
  $130 = (($v) + 28|0);
  HEAPF32[$130>>2] = $127;
  $131 = (($v) + 32|0);
  HEAPF32[$131>>2] = $128;
  $189 = $128;$190 = $127;$191 = $126;$192 = $96;$193 = $95;$194 = $94;$195 = $65;$196 = $64;$197 = $63;
 } else {
  $4 = Math_fround(HEAPF32[$v0>>2]);
  HEAPF32[$v>>2] = $4;
  $5 = (($v0) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($v) + 4|0);
  HEAPF32[$7>>2] = $6;
  $8 = (($v0) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($v) + 8|0);
  HEAPF32[$10>>2] = $9;
  $11 = Math_fround(HEAPF32[$v1>>2]);
  $12 = (($v) + 12|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($v1) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($v) + 16|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($v1) + 8|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($v) + 20|0);
  HEAPF32[$18>>2] = $17;
  $19 = Math_fround(HEAPF32[$v2>>2]);
  $20 = (($v) + 24|0);
  HEAPF32[$20>>2] = $19;
  $21 = (($v2) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($v) + 28|0);
  HEAPF32[$23>>2] = $22;
  $24 = (($v2) + 8|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($v) + 32|0);
  HEAPF32[$26>>2] = $25;
  $189 = $25;$190 = $22;$191 = $19;$192 = $17;$193 = $14;$194 = $11;$195 = $9;$196 = $6;$197 = $4;
 }
 $132 = (($hit) + 8|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (($this) + 12|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = ($135|0)==(0|0);
 if ($136) {
  $188 = 56;
 } else {
  $137 = (($135) + ($133)|0);
  $138 = HEAP8[$137>>0]|0;
  $188 = $138;
 }
 $139 = (($this) + 868|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = ($140|0)==(16);
 if (!($141)) {
  $156 = $140;$159 = $197;$161 = $196;$163 = $195;$166 = $194;$168 = $193;$170 = $192;$173 = $191;$175 = $190;$177 = $189;
  $155 = (($156) + 1)|0;
  HEAP32[$139>>2] = $155;
  $157 = ($156*3)|0;
  $158 = ((($this) + (($157*12)|0)|0) + 20|0);
  HEAPF32[$158>>2] = $159;
  $160 = ((($this) + (($157*12)|0)|0) + 24|0);
  HEAPF32[$160>>2] = $161;
  $162 = ((($this) + (($157*12)|0)|0) + 28|0);
  HEAPF32[$162>>2] = $163;
  $164 = (($157) + 1)|0;
  $165 = ((($this) + (($164*12)|0)|0) + 20|0);
  HEAPF32[$165>>2] = $166;
  $167 = ((($this) + (($164*12)|0)|0) + 24|0);
  HEAPF32[$167>>2] = $168;
  $169 = ((($this) + (($164*12)|0)|0) + 28|0);
  HEAPF32[$169>>2] = $170;
  $171 = (($157) + 2)|0;
  $172 = ((($this) + (($171*12)|0)|0) + 20|0);
  HEAPF32[$172>>2] = $173;
  $174 = ((($this) + (($171*12)|0)|0) + 24|0);
  HEAPF32[$174>>2] = $175;
  $176 = ((($this) + (($171*12)|0)|0) + 28|0);
  HEAPF32[$176>>2] = $177;
  $178 = HEAP32[$vinds>>2]|0;
  $179 = ((($this) + ($157<<2)|0) + 596|0);
  HEAP32[$179>>2] = $178;
  $180 = (($vinds) + 4|0);
  $181 = HEAP32[$180>>2]|0;
  $182 = ((($this) + ($164<<2)|0) + 596|0);
  HEAP32[$182>>2] = $181;
  $183 = (($vinds) + 8|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ((($this) + ($171<<2)|0) + 596|0);
  HEAP32[$185>>2] = $184;
  $186 = ((($this) + ($156<<2)|0) + 788|0);
  HEAP32[$186>>2] = $133;
  $187 = ((($this) + ($156)|0) + 852|0);
  HEAP8[$187>>0] = $188;
  STACKTOP = sp;return 1;
 }
 $142 = (($this) + 880|0);
 $143 = (($this) + 852|0);
 $144 = (($this) + 788|0);
 $145 = (($this) + 596|0);
 $146 = (($this) + 20|0);
 $count$01$i$i = 16;$edgeFlags$05$i$i = $143;$triInds$04$i$i = $144;$vertInds$03$i$i = $145;$verts$02$i$i = $146;
 while(1) {
  $147 = (($count$01$i$i) + -1)|0;
  $148 = HEAP32[$triInds$04$i$i>>2]|0;
  $149 = HEAP8[$edgeFlags$05$i$i>>0]|0;
  (__ZN5physx2Gu32PCMSphereVsMeshContactGeneration15processTriangleEPKNS_6PxVec3EjhPKj($142,$verts$02$i$i,$148,$149,$vertInds$03$i$i)|0);
  $150 = (($verts$02$i$i) + 36|0);
  $151 = (($vertInds$03$i$i) + 12|0);
  $152 = (($triInds$04$i$i) + 4|0);
  $153 = (($edgeFlags$05$i$i) + 1|0);
  $154 = ($147|0)==(0);
  if ($154) {
   break;
  } else {
   $count$01$i$i = $147;$edgeFlags$05$i$i = $153;$triInds$04$i$i = $152;$vertInds$03$i$i = $151;$verts$02$i$i = $150;
  }
 }
 HEAP32[$139>>2] = 0;
 $$pre = Math_fround(HEAPF32[$v>>2]);
 $$phi$trans$insert7 = (($v) + 4|0);
 $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
 $$phi$trans$insert9 = (($v) + 8|0);
 $$pre10 = Math_fround(HEAPF32[$$phi$trans$insert9>>2]);
 $$phi$trans$insert11 = (($v) + 12|0);
 $$pre12 = Math_fround(HEAPF32[$$phi$trans$insert11>>2]);
 $$phi$trans$insert13 = (($v) + 16|0);
 $$pre14 = Math_fround(HEAPF32[$$phi$trans$insert13>>2]);
 $$phi$trans$insert15 = (($v) + 20|0);
 $$pre16 = Math_fround(HEAPF32[$$phi$trans$insert15>>2]);
 $$phi$trans$insert17 = (($v) + 24|0);
 $$pre18 = Math_fround(HEAPF32[$$phi$trans$insert17>>2]);
 $$phi$trans$insert19 = (($v) + 28|0);
 $$pre20 = Math_fround(HEAPF32[$$phi$trans$insert19>>2]);
 $$phi$trans$insert21 = (($v) + 32|0);
 $$pre22 = Math_fround(HEAPF32[$$phi$trans$insert21>>2]);
 $156 = 0;$159 = $$pre;$161 = $$pre8;$163 = $$pre10;$166 = $$pre12;$168 = $$pre14;$170 = $$pre16;$173 = $$pre18;$175 = $$pre20;$177 = $$pre22;
 $155 = (($156) + 1)|0;
 HEAP32[$139>>2] = $155;
 $157 = ($156*3)|0;
 $158 = ((($this) + (($157*12)|0)|0) + 20|0);
 HEAPF32[$158>>2] = $159;
 $160 = ((($this) + (($157*12)|0)|0) + 24|0);
 HEAPF32[$160>>2] = $161;
 $162 = ((($this) + (($157*12)|0)|0) + 28|0);
 HEAPF32[$162>>2] = $163;
 $164 = (($157) + 1)|0;
 $165 = ((($this) + (($164*12)|0)|0) + 20|0);
 HEAPF32[$165>>2] = $166;
 $167 = ((($this) + (($164*12)|0)|0) + 24|0);
 HEAPF32[$167>>2] = $168;
 $169 = ((($this) + (($164*12)|0)|0) + 28|0);
 HEAPF32[$169>>2] = $170;
 $171 = (($157) + 2)|0;
 $172 = ((($this) + (($171*12)|0)|0) + 20|0);
 HEAPF32[$172>>2] = $173;
 $174 = ((($this) + (($171*12)|0)|0) + 24|0);
 HEAPF32[$174>>2] = $175;
 $176 = ((($this) + (($171*12)|0)|0) + 28|0);
 HEAPF32[$176>>2] = $177;
 $178 = HEAP32[$vinds>>2]|0;
 $179 = ((($this) + ($157<<2)|0) + 596|0);
 HEAP32[$179>>2] = $178;
 $180 = (($vinds) + 4|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ((($this) + ($164<<2)|0) + 596|0);
 HEAP32[$182>>2] = $181;
 $183 = (($vinds) + 8|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = ((($this) + ($171<<2)|0) + 596|0);
 HEAP32[$185>>2] = $184;
 $186 = ((($this) + ($156<<2)|0) + 788|0);
 HEAP32[$186>>2] = $133;
 $187 = ((($this) + ($156)|0) + 852|0);
 HEAP8[$187>>0] = $188;
 STACKTOP = sp;return 1;
}
function __ZN5physx40PCMSphereVsMeshContactGenerationCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu15PCMPolygonalBoxC2ERKNS_6PxVec3E($this,$halfSide) {
 $this = $this|0;
 $halfSide = $halfSide|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $halfSide;
 $0 = Math_fround(HEAPF32[$halfSide>>2]);
 $1 = Math_fround(-$0);
 $2 = (($halfSide) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(-$3);
 $5 = (($halfSide) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 $8 = (($this) + 4|0);
 HEAPF32[$8>>2] = $1;
 $9 = (($this) + 8|0);
 HEAPF32[$9>>2] = $4;
 $10 = (($this) + 12|0);
 HEAPF32[$10>>2] = $7;
 $11 = (($this) + 16|0);
 HEAPF32[$11>>2] = $0;
 $12 = (($this) + 20|0);
 HEAPF32[$12>>2] = $4;
 $13 = (($this) + 24|0);
 HEAPF32[$13>>2] = $7;
 $14 = (($this) + 28|0);
 HEAPF32[$14>>2] = $0;
 $15 = (($this) + 32|0);
 HEAPF32[$15>>2] = $3;
 $16 = (($this) + 36|0);
 HEAPF32[$16>>2] = $7;
 $17 = (($this) + 40|0);
 HEAPF32[$17>>2] = $1;
 $18 = (($this) + 44|0);
 HEAPF32[$18>>2] = $3;
 $19 = (($this) + 48|0);
 HEAPF32[$19>>2] = $7;
 $20 = (($this) + 52|0);
 HEAPF32[$20>>2] = $1;
 $21 = (($this) + 56|0);
 HEAPF32[$21>>2] = $4;
 $22 = (($this) + 60|0);
 HEAPF32[$22>>2] = $6;
 $23 = (($this) + 64|0);
 HEAPF32[$23>>2] = $0;
 $24 = (($this) + 68|0);
 HEAPF32[$24>>2] = $4;
 $25 = (($this) + 72|0);
 HEAPF32[$25>>2] = $6;
 $26 = (($this) + 76|0);
 HEAPF32[$26>>2] = $0;
 $27 = (($this) + 80|0);
 HEAPF32[$27>>2] = $3;
 $28 = (($this) + 84|0);
 HEAPF32[$28>>2] = $6;
 $29 = (($this) + 88|0);
 HEAPF32[$29>>2] = $1;
 $30 = (($this) + 92|0);
 HEAPF32[$30>>2] = $3;
 $31 = (($this) + 96|0);
 HEAPF32[$31>>2] = $6;
 $32 = (($this) + 118|0);
 HEAP8[$32>>0] = 4;
 $33 = (($this) + 116|0);
 HEAP16[$33>>1] = 0;
 $34 = (($this) + 138|0);
 HEAP8[$34>>0] = 4;
 $35 = (($this) + 136|0);
 HEAP16[$35>>1] = 4;
 $36 = (($this) + 158|0);
 HEAP8[$36>>0] = 4;
 $37 = (($this) + 156|0);
 HEAP16[$37>>1] = 8;
 $38 = (($this) + 178|0);
 HEAP8[$38>>0] = 4;
 $39 = (($this) + 176|0);
 HEAP16[$39>>1] = 12;
 $40 = (($this) + 198|0);
 HEAP8[$40>>0] = 4;
 $41 = (($this) + 196|0);
 HEAP16[$41>>1] = 16;
 $42 = (($this) + 218|0);
 HEAP8[$42>>0] = 4;
 $43 = (($this) + 216|0);
 HEAP16[$43>>1] = 20;
 $44 = (($this) + 120|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 $45 = (($this) + 124|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($this) + 128|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = Math_fround(HEAPF32[$halfSide>>2]);
 $48 = Math_fround(-$47);
 $49 = (($this) + 132|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($this) + 160|0);
 HEAPF32[$50>>2] = Math_fround(-1.0);
 $51 = (($this) + 164|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($this) + 168|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = HEAP32[$this>>2]|0;
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround(-$54);
 $56 = (($this) + 172|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($this) + 139|0);
 HEAP8[$57>>0] = 0;
 $58 = (($this) + 179|0);
 HEAP8[$58>>0] = 1;
 $59 = (($this) + 180|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($this) + 184|0);
 HEAPF32[$60>>2] = Math_fround(1.0);
 $61 = (($this) + 188|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (($53) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(-$63);
 $65 = (($this) + 192|0);
 HEAPF32[$65>>2] = $64;
 $66 = (($this) + 200|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($this) + 204|0);
 HEAPF32[$67>>2] = Math_fround(-1.0);
 $68 = (($this) + 208|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = Math_fround(HEAPF32[$62>>2]);
 $70 = Math_fround(-$69);
 $71 = (($this) + 212|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($this) + 199|0);
 HEAP8[$72>>0] = 0;
 $73 = (($this) + 219|0);
 HEAP8[$73>>0] = 2;
 $74 = (($this) + 140|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($this) + 144|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($this) + 148|0);
 HEAPF32[$76>>2] = Math_fround(1.0);
 $77 = (($53) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround(-$78);
 $80 = (($this) + 152|0);
 HEAPF32[$80>>2] = $79;
 $81 = (($this) + 100|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 $82 = (($this) + 104|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = (($this) + 108|0);
 HEAPF32[$83>>2] = Math_fround(-1.0);
 $84 = Math_fround(HEAPF32[$77>>2]);
 $85 = Math_fround(-$84);
 $86 = (($this) + 112|0);
 HEAPF32[$86>>2] = $85;
 $87 = (($this) + 159|0);
 HEAP8[$87>>0] = 0;
 $88 = (($this) + 119|0);
 HEAP8[$88>>0] = 4;
 STACKTOP = sp;return;
}
function __ZNK5physx2Gu15PCMPolygonalBox16getPolygonalDataEPNS0_13PolygonalDataE($this,$dst) {
 $this = $this|0;
 $dst = $dst|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$dst>>2] = Math_fround(0.0);
 $0 = (($dst) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($dst) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($dst) + 12|0);
 HEAP32[$2>>2] = 8;
 $3 = (($dst) + 16|0);
 HEAP32[$3>>2] = 6;
 $4 = (($this) + 100|0);
 $5 = (($dst) + 24|0);
 HEAP32[$5>>2] = $4;
 $6 = (($dst) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 4|0);
 $8 = (($dst) + 28|0);
 HEAP32[$8>>2] = $7;
 $9 = (($dst) + 32|0);
 HEAP32[$9>>2] = 554136;
 $10 = (($dst) + 36|0);
 $11 = (($dst) + 60|0);
 HEAP32[$11>>2] = 0;
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16getPCMConvexDataERKNS0_11ConvexHullVEbRNS0_13PolygonalDataE($convexHull,$idtScale,$polyData) {
 $convexHull = $convexHull|0;
 $idtScale = $idtScale|0;
 $polyData = $polyData|0;
 var $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = Math_fround(0), $tmp2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($convexHull) + 192|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 24|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 28|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 32|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($convexHull) + 96|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($3 * $9);
 $11 = (($convexHull) + 112|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($5 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (($convexHull) + 128|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($convexHull) + 100|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($3 * $20);
 $22 = (($convexHull) + 116|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($5 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($convexHull) + 132|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($7 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($convexHull) + 104|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($3 * $31);
 $33 = (($convexHull) + 120|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($5 * $34);
 $36 = Math_fround($32 + $35);
 $37 = (($convexHull) + 136|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($7 * $38);
 $40 = Math_fround($36 + $39);
 HEAPF32[$polyData>>2] = $18;
 $41 = (($polyData) + 4|0);
 HEAPF32[$41>>2] = $29;
 $42 = (($polyData) + 8|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($1) + 38|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = $44&255;
 $46 = (($polyData) + 12|0);
 HEAP32[$46>>2] = $45;
 $47 = (($1) + 39|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48&255;
 $50 = (($polyData) + 16|0);
 HEAP32[$50>>2] = $49;
 $51 = (($1) + 36|0);
 $52 = HEAP16[$51>>1]|0;
 $53 = $52&65535;
 $54 = (($polyData) + 20|0);
 HEAP32[$54>>2] = $53;
 $55 = (($1) + 40|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($polyData) + 24|0);
 HEAP32[$57>>2] = $56;
 $58 = HEAP32[$55>>2]|0;
 $59 = HEAP8[$47>>0]|0;
 $60 = $59&255;
 $61 = (($58) + (($60*20)|0)|0);
 $62 = (($polyData) + 28|0);
 HEAP32[$62>>2] = $61;
 $63 = HEAP32[$55>>2]|0;
 $64 = HEAP8[$47>>0]|0;
 $65 = $64&255;
 $66 = (($63) + (($65*20)|0)|0);
 $67 = HEAP8[$43>>0]|0;
 $68 = $67&255;
 $69 = $53 << 1;
 $tmp2$i$i = ($68*15)|0;
 $$sum1$i$i = (($tmp2$i$i) + ($69))|0;
 $70 = (($66) + ($$sum1$i$i)|0);
 $71 = (($polyData) + 32|0);
 HEAP32[$71>>2] = $70;
 $72 = HEAP32[$55>>2]|0;
 $73 = HEAP8[$47>>0]|0;
 $74 = $73&255;
 $75 = (($72) + (($74*20)|0)|0);
 $76 = HEAP8[$43>>0]|0;
 $77 = $76&255;
 $78 = ($77*12)|0;
 $79 = (($75) + ($78)|0);
 $80 = (($polyData) + 36|0);
 HEAP32[$80>>2] = $79;
 $81 = (($1) + 44|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($polyData) + 56|0);
 HEAP32[$83>>2] = $82;
 $84 = (($polyData) + 40|0);
 $85 = (($1) + 48|0);
 ;HEAP32[$84+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$85+8>>2]|0;HEAP32[$84+12>>2]=HEAP32[$85+12>>2]|0;
 $86 = (($polyData) + 60|0);
 HEAP32[$86>>2] = 2584;
 if ($idtScale) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$84+0>>2]=0|0;HEAP32[$84+4>>2]=0|0;HEAP32[$84+8>>2]=0|0;HEAP32[$84+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu16getPCMConvexDataERKNS0_13GeometryUnionERNS_2Cm23FastVertex2ShapeScalingERNS_9PxBounds3ERNS0_13PolygonalDataE($shape,$scaling,$bounds,$polyData) {
 $shape = $shape|0;
 $scaling = $scaling|0;
 $bounds = $bounds|0;
 $polyData = $polyData|0;
 var $$sum1$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = Math_fround(0), $170 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $fabsf$i$i$i$i = Math_fround(0), $fabsf$i$i1$i$i = Math_fround(0), $fabsf$i$i2$i$i = Math_fround(0), $fabsf$i$i3$i$i = Math_fround(0), $fabsf$i$i4$i$i = Math_fround(0), $fabsf$i$i5$i$i = Math_fround(0), $fabsf$i$i6$i$i = Math_fround(0), $fabsf$i$i7$i$i = Math_fround(0);
 var $fabsf$i$i8$i$i = Math_fround(0), $tmp2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shape) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == Math_fround(1.0);
 if ($2) {
  $3 = (($shape) + 8|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(1.0);
  if ($5) {
   $6 = (($shape) + 12|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 == Math_fround(1.0);
   if ($8) {
    $170 = 1;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  $9 = (($shape) + 16|0);
  __ZN5physx2Cm23FastVertex2ShapeScaling4initERKNS_6PxVec3ERKNS_6PxQuatE($scaling,$0,$9);
  $170 = 0;
 }
 $10 = (($shape) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($11) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 + $14);
 $16 = (($11) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($11) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 + $19);
 $21 = (($11) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($11) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 + $24);
 $26 = Math_fround($15 * Math_fround(0.5));
 $27 = Math_fround($20 * Math_fround(0.5));
 $28 = Math_fround($25 * Math_fround(0.5));
 $29 = Math_fround(HEAPF32[$scaling>>2]);
 $30 = Math_fround($26 * $29);
 $31 = (($scaling) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($26 * $32);
 $34 = (($scaling) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($26 * $35);
 $37 = (($scaling) + 12|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($27 * $38);
 $40 = (($scaling) + 16|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($27 * $41);
 $43 = (($scaling) + 20|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($27 * $44);
 $46 = Math_fround($30 + $39);
 $47 = Math_fround($33 + $42);
 $48 = Math_fround($36 + $45);
 $49 = (($scaling) + 24|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($28 * $50);
 $52 = (($scaling) + 28|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($28 * $53);
 $55 = (($scaling) + 32|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($28 * $56);
 $58 = Math_fround($46 + $51);
 $59 = Math_fround($47 + $54);
 $60 = Math_fround($48 + $57);
 $61 = Math_fround($14 - $12);
 $62 = Math_fround($19 - $17);
 $63 = Math_fround($24 - $22);
 $64 = Math_fround($61 * Math_fround(0.5));
 $65 = Math_fround($62 * Math_fround(0.5));
 $66 = Math_fround($63 * Math_fround(0.5));
 $67 = Math_fround($64 * $29);
 $68 = Math_fround($64 * $32);
 $69 = Math_fround($64 * $35);
 $70 = Math_fround($65 * $38);
 $71 = Math_fround($65 * $41);
 $72 = Math_fround($65 * $44);
 $73 = Math_fround($66 * $50);
 $74 = Math_fround($66 * $53);
 $75 = Math_fround($66 * $56);
 $fabsf$i$i4$i$i = (Math_fround(Math_abs((Math_fround($67)))));
 $fabsf$i$i5$i$i = (Math_fround(Math_abs((Math_fround($70)))));
 $76 = Math_fround($fabsf$i$i4$i$i + $fabsf$i$i5$i$i);
 $fabsf$i$i6$i$i = (Math_fround(Math_abs((Math_fround($73)))));
 $77 = Math_fround($76 + $fabsf$i$i6$i$i);
 $fabsf$i$i7$i$i = (Math_fround(Math_abs((Math_fround($68)))));
 $fabsf$i$i8$i$i = (Math_fround(Math_abs((Math_fround($71)))));
 $78 = Math_fround($fabsf$i$i7$i$i + $fabsf$i$i8$i$i);
 $fabsf$i$i3$i$i = (Math_fround(Math_abs((Math_fround($74)))));
 $79 = Math_fround($78 + $fabsf$i$i3$i$i);
 $fabsf$i$i2$i$i = (Math_fround(Math_abs((Math_fround($69)))));
 $fabsf$i$i1$i$i = (Math_fround(Math_abs((Math_fround($72)))));
 $80 = Math_fround($fabsf$i$i2$i$i + $fabsf$i$i1$i$i);
 $fabsf$i$i$i$i = (Math_fround(Math_abs((Math_fround($75)))));
 $81 = Math_fround($80 + $fabsf$i$i$i$i);
 $82 = Math_fround($58 - $77);
 $83 = Math_fround($59 - $79);
 $84 = Math_fround($60 - $81);
 $85 = Math_fround($58 + $77);
 $86 = Math_fround($59 + $79);
 $87 = Math_fround($60 + $81);
 HEAPF32[$bounds>>2] = $82;
 $88 = (($bounds) + 4|0);
 HEAPF32[$88>>2] = $83;
 $89 = (($bounds) + 8|0);
 HEAPF32[$89>>2] = $84;
 $90 = (($bounds) + 12|0);
 HEAPF32[$90>>2] = $85;
 $91 = (($bounds) + 16|0);
 HEAPF32[$91>>2] = $86;
 $92 = (($bounds) + 20|0);
 HEAPF32[$92>>2] = $87;
 $93 = HEAP32[$10>>2]|0;
 $94 = (($93) + 24|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround(HEAPF32[$scaling>>2]);
 $97 = Math_fround($95 * $96);
 $98 = Math_fround(HEAPF32[$31>>2]);
 $99 = Math_fround($95 * $98);
 $100 = Math_fround(HEAPF32[$34>>2]);
 $101 = Math_fround($95 * $100);
 $102 = (($93) + 28|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround(HEAPF32[$37>>2]);
 $105 = Math_fround($103 * $104);
 $106 = Math_fround(HEAPF32[$40>>2]);
 $107 = Math_fround($103 * $106);
 $108 = Math_fround(HEAPF32[$43>>2]);
 $109 = Math_fround($103 * $108);
 $110 = Math_fround($97 + $105);
 $111 = Math_fround($99 + $107);
 $112 = Math_fround($101 + $109);
 $113 = (($93) + 32|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround(HEAPF32[$49>>2]);
 $116 = Math_fround($114 * $115);
 $117 = Math_fround(HEAPF32[$52>>2]);
 $118 = Math_fround($114 * $117);
 $119 = Math_fround(HEAPF32[$55>>2]);
 $120 = Math_fround($114 * $119);
 $121 = Math_fround($110 + $116);
 $122 = Math_fround($111 + $118);
 $123 = Math_fround($112 + $120);
 HEAPF32[$polyData>>2] = $121;
 $124 = (($polyData) + 4|0);
 HEAPF32[$124>>2] = $122;
 $125 = (($polyData) + 8|0);
 HEAPF32[$125>>2] = $123;
 $126 = (($93) + 38|0);
 $127 = HEAP8[$126>>0]|0;
 $128 = $127&255;
 $129 = (($polyData) + 12|0);
 HEAP32[$129>>2] = $128;
 $130 = (($93) + 39|0);
 $131 = HEAP8[$130>>0]|0;
 $132 = $131&255;
 $133 = (($polyData) + 16|0);
 HEAP32[$133>>2] = $132;
 $134 = (($93) + 36|0);
 $135 = HEAP16[$134>>1]|0;
 $136 = $135&65535;
 $137 = (($polyData) + 20|0);
 HEAP32[$137>>2] = $136;
 $138 = (($93) + 40|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = (($polyData) + 24|0);
 HEAP32[$140>>2] = $139;
 $141 = HEAP32[$138>>2]|0;
 $142 = HEAP8[$130>>0]|0;
 $143 = $142&255;
 $144 = (($141) + (($143*20)|0)|0);
 $145 = (($polyData) + 28|0);
 HEAP32[$145>>2] = $144;
 $146 = HEAP32[$138>>2]|0;
 $147 = HEAP8[$130>>0]|0;
 $148 = $147&255;
 $149 = (($146) + (($148*20)|0)|0);
 $150 = HEAP8[$126>>0]|0;
 $151 = $150&255;
 $152 = $136 << 1;
 $tmp2$i$i = ($151*15)|0;
 $$sum1$i$i = (($tmp2$i$i) + ($152))|0;
 $153 = (($149) + ($$sum1$i$i)|0);
 $154 = (($polyData) + 32|0);
 HEAP32[$154>>2] = $153;
 $155 = HEAP32[$138>>2]|0;
 $156 = HEAP8[$130>>0]|0;
 $157 = $156&255;
 $158 = (($155) + (($157*20)|0)|0);
 $159 = HEAP8[$126>>0]|0;
 $160 = $159&255;
 $161 = ($160*12)|0;
 $162 = (($158) + ($161)|0);
 $163 = (($polyData) + 36|0);
 HEAP32[$163>>2] = $162;
 $164 = (($93) + 44|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = (($polyData) + 56|0);
 HEAP32[$166>>2] = $165;
 $167 = (($polyData) + 40|0);
 $168 = (($93) + 48|0);
 ;HEAP32[$167+0>>2]=HEAP32[$168+0>>2]|0;HEAP32[$167+4>>2]=HEAP32[$168+4>>2]|0;HEAP32[$167+8>>2]=HEAP32[$168+8>>2]|0;HEAP32[$167+12>>2]=HEAP32[$168+12>>2]|0;
 $169 = (($polyData) + 60|0);
 HEAP32[$169>>2] = 2584;
 STACKTOP = sp;return ($170|0);
}
function __ZN5physx2GuL18gPCMHullPrefetchCBEjPKNS_6PxVec3E($numVerts,$verts) {
 $numVerts = $numVerts|0;
 $verts = $verts|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32PCMConvexVsMeshContactGeneration35generateTriangleFullContactManifoldERNS0_9TriangleVEjPKjhRKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS2_EEPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERNSI_5Vec3VE($this,$localTriangle,$triangleIndex,$triIndices,$triFlags,$polyData,$localTriMap,$polyMap,$manifoldContacts,$numContacts,$contactDist,$patchNormal) {
 $this = $this|0;
 $localTriangle = $localTriangle|0;
 $triangleIndex = $triangleIndex|0;
 $triIndices = $triIndices|0;
 $triFlags = $triFlags|0;
 $polyData = $polyData|0;
 $localTriMap = $localTriMap|0;
 $polyMap = $polyMap|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $patchNormal = $patchNormal|0;
 var $$0 = 0, $$pre$i = 0, $$sum = 0, $$sum130 = 0, $$sum131 = 0, $$sum132 = 0, $$sum133 = 0, $$sum134 = 0, $$sum135 = 0, $$sum136 = 0, $$sum137 = 0, $$sum138 = 0, $$sum139 = 0, $$sum140 = 0, $$sum141 = 0, $$sum142 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0;
 var $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0);
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0);
 var $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0);
 var $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0;
 var $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0);
 var $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0);
 var $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0);
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0);
 var $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0;
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0;
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $contactNormal4 = 0, $feature0 = 0, $feature1 = 0, $minNormal = 0, $minOverlap = 0, $n = 0;
 var $n2 = 0, $status = 0, $triNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $status = sp + 104|0;
 $minOverlap = sp;
 $minNormal = sp + 16|0;
 $feature0 = sp + 100|0;
 $feature1 = sp + 96|0;
 $triNormal = sp + 64|0;
 $n = sp + 48|0;
 $n2 = sp + 32|0;
 $contactNormal4 = sp + 80|0;
 HEAP32[$status>>2] = 0;
 HEAPF32[$minOverlap>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$minNormal+0>>2]=0|0;HEAP32[$minNormal+4>>2]=0|0;HEAP32[$minNormal+8>>2]=0|0;HEAP32[$minNormal+12>>2]=0|0;
 $0 = (__ZN5physxL22testTriangleFaceNormalERKNS_2Gu9TriangleVERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSE_RjRNSD_5Vec3VENS0_13FeatureStatusERSL_($localTriangle,$polyMap,$contactDist,$minOverlap,$feature0,$minNormal,$status)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN5physxL18testPolyFaceNormalERKNS_2Gu9TriangleVERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSE_RjRNSD_5Vec3VENS0_13FeatureStatusERSL_($polyData,$localTriMap,$polyMap,$contactDist,$minOverlap,$feature1,$minNormal,$status)|0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($polyData) + 24|0);
 $3 = (__ZN5physxL18testPolyEdgeNormalERKNS_2Gu9TriangleVEhRKNS0_15HullPolygonDataERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSH_RNSG_5Vec3VENS0_13FeatureStatusERSN_($localTriangle,$triFlags,$polyData,$localTriMap,$polyMap,$contactDist,$minOverlap,$minNormal,$status)|0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($localTriangle) + 112|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($localTriangle) + 116|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($localTriangle) + 120|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($localTriangle) + 96|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($localTriangle) + 100|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($localTriangle) + 104|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($5 - $11);
 $17 = Math_fround($7 - $13);
 $18 = Math_fround($9 - $15);
 $19 = (($localTriangle) + 128|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($localTriangle) + 132|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($localTriangle) + 136|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($20 - $11);
 $26 = Math_fround($22 - $13);
 $27 = Math_fround($24 - $15);
 $28 = Math_fround($17 * $27);
 $29 = Math_fround($18 * $26);
 $30 = Math_fround($28 - $29);
 $31 = Math_fround($18 * $25);
 $32 = Math_fround($16 * $27);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($16 * $26);
 $35 = Math_fround($17 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($30 * $30);
 $38 = Math_fround($33 * $33);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($36 * $36);
 $41 = Math_fround($40 + $39);
 $42 = (Math_fround(Math_sqrt((Math_fround($41)))));
 $43 = Math_fround(Math_fround(1.0) / $42);
 $44 = Math_fround($43 * $30);
 $45 = Math_fround($43 * $33);
 $46 = Math_fround($36 * $43);
 HEAPF32[$triNormal>>2] = $44;
 $47 = (($triNormal) + 4|0);
 HEAPF32[$47>>2] = $45;
 $48 = (($triNormal) + 8|0);
 HEAPF32[$48>>2] = $46;
 $49 = (($triNormal) + 12|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = HEAP32[$status>>2]|0;
 if ((($50|0) == 1)) {
  $96 = HEAP32[$feature1>>2]|0;
  $97 = HEAP32[$2>>2]|0;
  $98 = (($97) + (($96*20)|0)|0);
  $99 = (($polyMap) + 40|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = Math_fround(HEAPF32[$98>>2]);
  $102 = ((($97) + (($96*20)|0)|0) + 4|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = ((($97) + (($96*20)|0)|0) + 8|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround(HEAPF32[$100>>2]);
  $107 = Math_fround($101 * $106);
  $108 = (($100) + 4|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = Math_fround($103 * $109);
  $111 = Math_fround($107 + $110);
  $112 = (($100) + 8|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($105 * $113);
  $115 = Math_fround($111 + $114);
  $116 = (($100) + 16|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = Math_fround($101 * $117);
  $119 = (($100) + 20|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $121 = Math_fround($103 * $120);
  $122 = Math_fround($118 + $121);
  $123 = (($100) + 24|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = Math_fround($105 * $124);
  $126 = Math_fround($122 + $125);
  $127 = (($100) + 32|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = Math_fround($101 * $128);
  $130 = (($100) + 36|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  $132 = Math_fround($103 * $131);
  $133 = Math_fround($129 + $132);
  $134 = (($100) + 40|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = Math_fround($105 * $135);
  $137 = Math_fround($133 + $136);
  $138 = Math_fround($115 * $115);
  $139 = Math_fround($126 * $126);
  $140 = Math_fround($138 + $139);
  $141 = Math_fround($137 * $137);
  $142 = Math_fround($140 + $141);
  $143 = (Math_fround(Math_sqrt((Math_fround($142)))));
  $144 = Math_fround(Math_fround(1.0) / $143);
  $145 = Math_fround($115 * $144);
  $146 = Math_fround($126 * $144);
  $147 = Math_fround($137 * $144);
  $148 = Math_fround($145 * $44);
  $149 = Math_fround($146 * $45);
  $150 = Math_fround(-$149);
  $151 = Math_fround($150 - $148);
  $152 = Math_fround($147 * $46);
  $153 = Math_fround($151 - $152);
  $154 = $153 > Math_fround(0.70709997415542602539);
  if ($154) {
   ;HEAP32[$patchNormal+0>>2]=HEAP32[$triNormal+0>>2]|0;HEAP32[$patchNormal+4>>2]=HEAP32[$triNormal+4>>2]|0;HEAP32[$patchNormal+8>>2]=HEAP32[$triNormal+8>>2]|0;HEAP32[$patchNormal+12>>2]=HEAP32[$triNormal+12>>2]|0;
   __ZN5physxL25generatedTriangleContactsERKNS_2Gu9TriangleVEjhRKNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERKNSG_5Vec3VE($localTriangle,$triangleIndex,$triFlags,$polyData,$98,$polyMap,$manifoldContacts,$numContacts,$contactDist,$triNormal);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $155 = (($this) + 3648|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = (($156) + 4|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = (($158) + 15)|0;
  $160 = HEAP32[$156>>2]|0;
  $161 = ($159>>>0)>($160>>>0);
  if ($161) {
   (__ZN5physx2Gu9Container6ResizeEj($156,15)|0);
   $$pre$i = HEAP32[$157>>2]|0;
   $165 = $$pre$i;
  } else {
   $165 = $158;
  }
  $162 = (($156) + 8|0);
  $163 = HEAP32[$162>>2]|0;
  $164 = (($163) + ($165<<2)|0);
  $166 = (($165) + 15)|0;
  HEAP32[$157>>2] = $166;
  $$sum = (($165) + 12)|0;
  $167 = (($163) + ($$sum<<2)|0);
  HEAP32[$167>>2] = $triangleIndex;
  $$sum130 = (($165) + 13)|0;
  $168 = (($163) + ($$sum130<<2)|0);
  HEAP32[$168>>2] = $96;
  $$sum131 = (($165) + 14)|0;
  $169 = (($163) + ($$sum131<<2)|0);
  HEAP8[$169>>0] = $triFlags;
  $170 = HEAP32[$triIndices>>2]|0;
  $$sum132 = (($165) + 9)|0;
  $171 = (($163) + ($$sum132<<2)|0);
  HEAP32[$171>>2] = $170;
  $172 = (($triIndices) + 4|0);
  $173 = HEAP32[$172>>2]|0;
  $$sum133 = (($165) + 10)|0;
  $174 = (($163) + ($$sum133<<2)|0);
  HEAP32[$174>>2] = $173;
  $175 = (($triIndices) + 8|0);
  $176 = HEAP32[$175>>2]|0;
  $$sum134 = (($165) + 11)|0;
  $177 = (($163) + ($$sum134<<2)|0);
  HEAP32[$177>>2] = $176;
  $178 = Math_fround(HEAPF32[$10>>2]);
  $179 = Math_fround(HEAPF32[$12>>2]);
  $180 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$164>>2] = $178;
  $$sum135 = (($165) + 1)|0;
  $181 = (($163) + ($$sum135<<2)|0);
  HEAPF32[$181>>2] = $179;
  $$sum136 = (($165) + 2)|0;
  $182 = (($163) + ($$sum136<<2)|0);
  HEAPF32[$182>>2] = $180;
  $183 = Math_fround(HEAPF32[$4>>2]);
  $184 = Math_fround(HEAPF32[$6>>2]);
  $185 = Math_fround(HEAPF32[$8>>2]);
  $$sum137 = (($165) + 3)|0;
  $186 = (($163) + ($$sum137<<2)|0);
  HEAPF32[$186>>2] = $183;
  $$sum138 = (($165) + 4)|0;
  $187 = (($163) + ($$sum138<<2)|0);
  HEAPF32[$187>>2] = $184;
  $$sum139 = (($165) + 5)|0;
  $188 = (($163) + ($$sum139<<2)|0);
  HEAPF32[$188>>2] = $185;
  $189 = Math_fround(HEAPF32[$19>>2]);
  $190 = Math_fround(HEAPF32[$21>>2]);
  $191 = Math_fround(HEAPF32[$23>>2]);
  $$sum140 = (($165) + 6)|0;
  $192 = (($163) + ($$sum140<<2)|0);
  HEAPF32[$192>>2] = $189;
  $$sum141 = (($165) + 7)|0;
  $193 = (($163) + ($$sum141<<2)|0);
  HEAPF32[$193>>2] = $190;
  $$sum142 = (($165) + 8)|0;
  $194 = (($163) + ($$sum142<<2)|0);
  HEAPF32[$194>>2] = $191;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($50|0) == 0)) {
  $51 = (($polyMap) + 36|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = Math_fround(HEAPF32[$minNormal>>2]);
  $54 = (($minNormal) + 4|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($minNormal) + 8|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround(HEAPF32[$52>>2]);
  $59 = Math_fround($53 * $58);
  $60 = (($52) + 4|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($55 * $61);
  $63 = Math_fround($59 + $62);
  $64 = (($52) + 8|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($57 * $65);
  $67 = Math_fround($63 + $66);
  $68 = (($52) + 16|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($53 * $69);
  $71 = (($52) + 20|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($55 * $72);
  $74 = Math_fround($70 + $73);
  $75 = (($52) + 24|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($57 * $76);
  $78 = Math_fround($74 + $77);
  $79 = (($52) + 32|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = Math_fround($53 * $80);
  $82 = (($52) + 36|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($55 * $83);
  $85 = Math_fround($81 + $84);
  $86 = (($52) + 40|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = Math_fround($57 * $87);
  $89 = Math_fround($85 + $88);
  HEAPF32[$n>>2] = $67;
  $90 = (($n) + 4|0);
  HEAPF32[$90>>2] = $78;
  $91 = (($n) + 8|0);
  HEAPF32[$91>>2] = $89;
  $92 = (($n) + 12|0);
  HEAPF32[$92>>2] = Math_fround(0.0);
  $93 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData,$polyMap,$n)|0);
  $94 = HEAP32[$2>>2]|0;
  $95 = (($94) + (($93*20)|0)|0);
  ;HEAP32[$patchNormal+0>>2]=HEAP32[$triNormal+0>>2]|0;HEAP32[$patchNormal+4>>2]=HEAP32[$triNormal+4>>2]|0;HEAP32[$patchNormal+8>>2]=HEAP32[$triNormal+8>>2]|0;HEAP32[$patchNormal+12>>2]=HEAP32[$triNormal+12>>2]|0;
  __ZN5physxL25generatedTriangleContactsERKNS_2Gu9TriangleVEjhRKNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERKNSG_5Vec3VE($localTriangle,$triangleIndex,$triFlags,$polyData,$95,$polyMap,$manifoldContacts,$numContacts,$contactDist,$triNormal);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $195 = (($polyMap) + 36|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = Math_fround(HEAPF32[$minNormal>>2]);
  $198 = (($minNormal) + 4|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = (($minNormal) + 8|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = Math_fround(HEAPF32[$196>>2]);
  $203 = Math_fround($197 * $202);
  $204 = (($196) + 4|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = Math_fround($199 * $205);
  $207 = Math_fround($203 + $206);
  $208 = (($196) + 8|0);
  $209 = Math_fround(HEAPF32[$208>>2]);
  $210 = Math_fround($201 * $209);
  $211 = Math_fround($207 + $210);
  $212 = (($196) + 16|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = Math_fround($197 * $213);
  $215 = (($196) + 20|0);
  $216 = Math_fround(HEAPF32[$215>>2]);
  $217 = Math_fround($199 * $216);
  $218 = Math_fround($214 + $217);
  $219 = (($196) + 24|0);
  $220 = Math_fround(HEAPF32[$219>>2]);
  $221 = Math_fround($201 * $220);
  $222 = Math_fround($218 + $221);
  $223 = (($196) + 32|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = Math_fround($197 * $224);
  $226 = (($196) + 36|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = Math_fround($199 * $227);
  $229 = Math_fround($225 + $228);
  $230 = (($196) + 40|0);
  $231 = Math_fround(HEAPF32[$230>>2]);
  $232 = Math_fround($201 * $231);
  $233 = Math_fround($229 + $232);
  HEAPF32[$n2>>2] = $211;
  $234 = (($n2) + 4|0);
  HEAPF32[$234>>2] = $222;
  $235 = (($n2) + 8|0);
  HEAPF32[$235>>2] = $233;
  $236 = (($n2) + 12|0);
  HEAPF32[$236>>2] = Math_fround(0.0);
  $237 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData,$polyMap,$n2)|0);
  HEAP32[$feature1>>2] = $237;
  $238 = HEAP32[$2>>2]|0;
  $239 = (($238) + (($237*20)|0)|0);
  $240 = (($polyMap) + 40|0);
  $241 = HEAP32[$240>>2]|0;
  $242 = Math_fround(HEAPF32[$239>>2]);
  $243 = ((($238) + (($237*20)|0)|0) + 4|0);
  $244 = Math_fround(HEAPF32[$243>>2]);
  $245 = ((($238) + (($237*20)|0)|0) + 8|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround(HEAPF32[$241>>2]);
  $248 = Math_fround($242 * $247);
  $249 = (($241) + 4|0);
  $250 = Math_fround(HEAPF32[$249>>2]);
  $251 = Math_fround($244 * $250);
  $252 = Math_fround($248 + $251);
  $253 = (($241) + 8|0);
  $254 = Math_fround(HEAPF32[$253>>2]);
  $255 = Math_fround($246 * $254);
  $256 = Math_fround($252 + $255);
  $257 = (($241) + 16|0);
  $258 = Math_fround(HEAPF32[$257>>2]);
  $259 = Math_fround($242 * $258);
  $260 = (($241) + 20|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = Math_fround($244 * $261);
  $263 = Math_fround($259 + $262);
  $264 = (($241) + 24|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = Math_fround($246 * $265);
  $267 = Math_fround($263 + $266);
  $268 = (($241) + 32|0);
  $269 = Math_fround(HEAPF32[$268>>2]);
  $270 = Math_fround($242 * $269);
  $271 = (($241) + 36|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = Math_fround($244 * $272);
  $274 = Math_fround($270 + $273);
  $275 = (($241) + 40|0);
  $276 = Math_fround(HEAPF32[$275>>2]);
  $277 = Math_fround($246 * $276);
  $278 = Math_fround($274 + $277);
  $279 = Math_fround($256 * $256);
  $280 = Math_fround($267 * $267);
  $281 = Math_fround($279 + $280);
  $282 = Math_fround($278 * $278);
  $283 = Math_fround($281 + $282);
  $284 = (Math_fround(Math_sqrt((Math_fround($283)))));
  $285 = Math_fround(Math_fround(1.0) / $284);
  $286 = Math_fround($256 * $285);
  $287 = Math_fround($267 * $285);
  $288 = Math_fround($278 * $285);
  HEAPF32[$contactNormal4>>2] = $286;
  $289 = (($contactNormal4) + 4|0);
  HEAPF32[$289>>2] = $287;
  $290 = (($contactNormal4) + 8|0);
  HEAPF32[$290>>2] = $288;
  $291 = (($contactNormal4) + 12|0);
  HEAPF32[$291>>2] = Math_fround(0.0);
  $292 = Math_fround(-$286);
  $293 = Math_fround(-$287);
  $294 = Math_fround(-$288);
  HEAPF32[$patchNormal>>2] = $292;
  $295 = (($patchNormal) + 4|0);
  HEAPF32[$295>>2] = $293;
  $296 = (($patchNormal) + 8|0);
  HEAPF32[$296>>2] = $294;
  $297 = (($patchNormal) + 12|0);
  HEAPF32[$297>>2] = Math_fround(0.0);
  __ZN5physxL21generatedPolyContactsERKNS_2Gu13PolygonalDataERKNS0_15HullPolygonDataERKNS0_9TriangleVEjhPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERKNSG_5Vec3VE($polyData,$239,$localTriangle,$triangleIndex,$triFlags,$polyMap,$manifoldContacts,$numContacts,$contactDist,$contactNormal4);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physxL22testTriangleFaceNormalERKNS_2Gu9TriangleVERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSE_RjRNSD_5Vec3VENS0_13FeatureStatusERSL_($triangle,$polyMap,$contactDist,$minOverlap,$feature,$faceNormal,$status) {
 $triangle = $triangle|0;
 $polyMap = $polyMap|0;
 $contactDist = $contactDist|0;
 $minOverlap = $minOverlap|0;
 $feature = $feature|0;
 $faceNormal = $faceNormal|0;
 $status = $status|0;
 var $$0 = 0, $$sroa$12 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0;
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $max1 = 0, $min1 = 0, $triangleLocNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $min1 = sp + 32|0;
 $max1 = sp;
 $triangleLocNormal = sp + 16|0;
 $$sroa$12 = sp + 48|0;
 $0 = (($triangle) + 112|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($triangle) + 116|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($triangle) + 120|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($triangle) + 96|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($triangle) + 100|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($triangle) + 104|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($1 - $7);
 $13 = Math_fround($3 - $9);
 $14 = Math_fround($5 - $11);
 $15 = (($triangle) + 128|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($triangle) + 132|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($triangle) + 136|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($16 - $7);
 $22 = Math_fround($18 - $9);
 $23 = Math_fround($20 - $11);
 $24 = Math_fround($13 * $23);
 $25 = Math_fround($14 * $22);
 $26 = Math_fround($24 - $25);
 $27 = Math_fround($14 * $21);
 $28 = Math_fround($12 * $23);
 $29 = Math_fround($27 - $28);
 $30 = Math_fround($12 * $22);
 $31 = Math_fround($13 * $21);
 $32 = Math_fround($30 - $31);
 $33 = Math_fround($26 * $26);
 $34 = Math_fround($29 * $29);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($32 * $32);
 $37 = Math_fround($36 + $35);
 $38 = (Math_fround(Math_sqrt((Math_fround($37)))));
 $39 = Math_fround(Math_fround(1.0) / $38);
 $40 = Math_fround($39 * $26);
 $41 = Math_fround($39 * $29);
 $42 = Math_fround($32 * $39);
 HEAPF32[$triangleLocNormal>>2] = $40;
 $43 = (($triangleLocNormal) + 4|0);
 HEAPF32[$43>>2] = $41;
 $44 = (($triangleLocNormal) + 8|0);
 HEAPF32[$44>>2] = $42;
 $45 = (($triangleLocNormal) + 12|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = Math_fround($40 * $7);
 $47 = Math_fround($41 * $9);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($42 * $11);
 $50 = Math_fround($48 + $49);
 $51 = HEAP32[$polyMap>>2]|0;
 $52 = (($51) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_viiii[$53 & 511]($polyMap,$triangleLocNormal,$min1,$max1);
 $54 = Math_fround(HEAPF32[$min1>>2]);
 $55 = Math_fround(HEAPF32[$contactDist>>2]);
 $56 = Math_fround($50 + $55);
 $57 = $54 > $56;
 if ($57) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $58 = Math_fround(HEAPF32[$max1>>2]);
 $59 = Math_fround($55 + $58);
 $60 = $50 > $59;
 if ($60) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $61 = Math_fround($50 - $54);
 $62 = Math_fround($61 + Math_fround(-1.1920928955078125E-7));
 HEAPF32[$minOverlap>>2] = $62;
 $63 = (($minOverlap) + 4|0);
 ;HEAP32[$63+0>>2]=HEAP32[$$sroa$12+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$$sroa$12+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$$sroa$12+8>>2]|0;
 HEAP32[$status>>2] = 0;
 HEAP32[$feature>>2] = 0;
 ;HEAP32[$faceNormal+0>>2]=HEAP32[$triangleLocNormal+0>>2]|0;HEAP32[$faceNormal+4>>2]=HEAP32[$triangleLocNormal+4>>2]|0;HEAP32[$faceNormal+8>>2]=HEAP32[$triangleLocNormal+8>>2]|0;HEAP32[$faceNormal+12>>2]=HEAP32[$triangleLocNormal+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physxL18testPolyFaceNormalERKNS_2Gu9TriangleVERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSE_RjRNSD_5Vec3VENS0_13FeatureStatusERSL_($polyData,$triMap,$polyMap,$contactDist,$minOverlap,$feature,$faceNormal,$status) {
 $polyData = $polyData|0;
 $triMap = $triMap|0;
 $polyMap = $polyMap|0;
 $contactDist = $contactDist|0;
 $minOverlap = $minOverlap|0;
 $feature = $feature|0;
 $faceNormal = $faceNormal|0;
 $status = $status|0;
 var $$$i$i$i = Math_fround(0), $$$i$i$i83 = Math_fround(0), $$$i12$i$i = Math_fround(0), $$$i12$i$i82 = Math_fround(0), $$$i17$i$i = Math_fround(0), $$$i17$i$i81 = Math_fround(0), $$$i22$i$i = Math_fround(0), $$$i22$i$i80 = Math_fround(0), $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0);
 var $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0;
 var $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0);
 var $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0);
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0);
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0);
 var $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0);
 var $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_feature$0279 = 0, $_feature$1 = 0, $_feature$2257 = 0, $_feature$3 = 0, $_feature$4 = 0, $_minOverlap$sroa$1 = 0, $i$0278 = 0, $i1$0258 = 0, $tempOverlap$sroa$1 = 0, $tempOverlap6$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_minOverlap$sroa$1 = sp + 24|0;
 $tempOverlap$sroa$1 = sp;
 $tempOverlap6$sroa$1 = sp + 12|0;
 $0 = Math_fround(HEAPF32[$faceNormal>>2]);
 $1 = (($faceNormal) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($faceNormal) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($faceNormal) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($polyMap) + 44|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 $10 = (($polyData) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 L1: do {
  if ($9) {
   if ($12) {
    $211 = Math_fround(3.40282346638528859812E+38);$214 = $0;$215 = $2;$216 = $4;$217 = $6;$_feature$4 = 0;
   } else {
    $38 = (($polyData) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($polyData) + 28|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($polyMap) + 40|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = (($43) + 4|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = (($43) + 8|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = (($43) + 16|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = (($43) + 20|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = (($43) + 24|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = (($43) + 32|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = (($43) + 36|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = (($43) + 40|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = (($triMap) + 48|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($62) + 96|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = (($62) + 100|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = (($62) + 104|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = (($62) + 112|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = (($62) + 116|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = (($62) + 120|0);
    $74 = Math_fround(HEAPF32[$73>>2]);
    $75 = (($62) + 128|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = (($62) + 132|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = (($62) + 136|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = Math_fround(HEAPF32[$contactDist>>2]);
    $206 = Math_fround(3.40282346638528859812E+38);$222 = $0;$223 = $2;$224 = $4;$225 = $6;$_feature$2257 = 0;$i1$0258 = 0;
    while(1) {
     $132 = ((($39) + (($i1$0258*20)|0)|0) + 19|0);
     $133 = HEAP8[$132>>0]|0;
     $134 = $133&255;
     $135 = ((($39) + (($i1$0258*20)|0)|0) + 12|0);
     $136 = Math_fround(HEAPF32[$135>>2]);
     $137 = (($39) + (($i1$0258*20)|0)|0);
     $138 = Math_fround(HEAPF32[$137>>2]);
     $139 = ((($39) + (($i1$0258*20)|0)|0) + 4|0);
     $140 = Math_fround(HEAPF32[$139>>2]);
     $141 = ((($39) + (($i1$0258*20)|0)|0) + 8|0);
     $142 = Math_fround(HEAPF32[$141>>2]);
     $143 = Math_fround($138 * $44);
     $144 = Math_fround($140 * $46);
     $145 = Math_fround($143 + $144);
     $146 = Math_fround($142 * $48);
     $147 = Math_fround($145 + $146);
     $148 = Math_fround($138 * $50);
     $149 = Math_fround($140 * $52);
     $150 = Math_fround($148 + $149);
     $151 = Math_fround($142 * $54);
     $152 = Math_fround($150 + $151);
     $153 = Math_fround($138 * $56);
     $154 = Math_fround($140 * $58);
     $155 = Math_fround($153 + $154);
     $156 = Math_fround($142 * $60);
     $157 = Math_fround($155 + $156);
     $158 = Math_fround($147 * $147);
     $159 = Math_fround($152 * $152);
     $160 = Math_fround($158 + $159);
     $161 = Math_fround($157 * $157);
     $162 = Math_fround($160 + $161);
     $163 = (Math_fround(Math_sqrt((Math_fround($162)))));
     $164 = Math_fround(Math_fround(1.0) / $163);
     $165 = Math_fround($136 * $164);
     $166 = Math_fround(-$165);
     $167 = Math_fround($147 * $164);
     $168 = Math_fround($152 * $164);
     $169 = Math_fround($164 * $157);
     $170 = Math_fround($167 * $64);
     $171 = Math_fround($168 * $66);
     $172 = Math_fround($170 + $171);
     $173 = Math_fround($169 * $68);
     $174 = Math_fround($172 + $173);
     $175 = Math_fround($167 * $70);
     $176 = Math_fround($168 * $72);
     $177 = Math_fround($175 + $176);
     $178 = Math_fround($169 * $74);
     $179 = Math_fround($177 + $178);
     $180 = Math_fround($167 * $76);
     $181 = Math_fround($168 * $78);
     $182 = Math_fround($180 + $181);
     $183 = Math_fround($169 * $80);
     $184 = Math_fround($182 + $183);
     $185 = $179 > $184;
     $$$i22$i$i = $185 ? $179 : $184;
     $$$i12$i$i = $185 ? $184 : $179;
     $186 = $174 > $$$i12$i$i;
     $$$i$i$i = $186 ? $$$i12$i$i : $174;
     $187 = Math_fround($81 - $165);
     $188 = $$$i$i$i > $187;
     if ($188) {
      $$0 = 0;
      label = 19;
      break;
     }
     $189 = ((($41) + (($134*12)|0)|0) + 4|0);
     $190 = (($41) + (($134*12)|0)|0);
     $191 = ((($41) + (($134*12)|0)|0) + 8|0);
     $192 = Math_fround(HEAPF32[$189>>2]);
     $193 = Math_fround(HEAPF32[$190>>2]);
     $194 = Math_fround($140 * $192);
     $195 = Math_fround($138 * $193);
     $196 = Math_fround(HEAPF32[$191>>2]);
     $197 = $174 > $$$i22$i$i;
     $198 = Math_fround($142 * $196);
     $199 = Math_fround($194 + $195);
     $$$i17$i$i = $197 ? $174 : $$$i22$i$i;
     $200 = Math_fround($199 + $198);
     $201 = Math_fround($81 + $$$i17$i$i);
     $202 = Math_fround($164 * $200);
     $203 = $202 > $201;
     if ($203) {
      $$0 = 0;
      label = 19;
      break;
     }
     $204 = Math_fround($166 - $$$i$i$i);
     $205 = $206 > $204;
     if ($205) {
      ;HEAP32[$_minOverlap$sroa$1+0>>2]=HEAP32[$tempOverlap6$sroa$1+0>>2]|0;HEAP32[$_minOverlap$sroa$1+4>>2]=HEAP32[$tempOverlap6$sroa$1+4>>2]|0;HEAP32[$_minOverlap$sroa$1+8>>2]=HEAP32[$tempOverlap6$sroa$1+8>>2]|0;
      $231 = $204;$232 = Math_fround(0.0);$233 = $169;$234 = $168;$235 = $167;$_feature$3 = $i1$0258;
     } else {
      $231 = $206;$232 = $225;$233 = $224;$234 = $223;$235 = $222;$_feature$3 = $_feature$2257;
     }
     $207 = (($i1$0258) + 1)|0;
     $208 = ($207>>>0)<($11>>>0);
     if ($208) {
      $206 = $231;$222 = $235;$223 = $234;$224 = $233;$225 = $232;$_feature$2257 = $_feature$3;$i1$0258 = $207;
     } else {
      $211 = $231;$214 = $235;$215 = $234;$216 = $233;$217 = $232;$_feature$4 = $_feature$3;
      break L1;
     }
    }
    if ((label|0) == 19) {
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   if ($12) {
    $211 = Math_fround(3.40282346638528859812E+38);$214 = $0;$215 = $2;$216 = $4;$217 = $6;$_feature$4 = 0;
   } else {
    $13 = (($polyData) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($polyData) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($triMap) + 48|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 96|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = (($18) + 100|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = (($18) + 104|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = (($18) + 112|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = (($18) + 116|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = (($18) + 120|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = (($18) + 128|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = (($18) + 132|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($18) + 136|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = Math_fround(HEAPF32[$contactDist>>2]);
    $129 = Math_fround(3.40282346638528859812E+38);$218 = $0;$219 = $2;$220 = $4;$221 = $6;$_feature$0279 = 0;$i$0278 = 0;
    while(1) {
     $82 = ((($14) + (($i$0278*20)|0)|0) + 19|0);
     $83 = HEAP8[$82>>0]|0;
     $84 = $83&255;
     $85 = ((($14) + (($i$0278*20)|0)|0) + 12|0);
     $86 = Math_fround(HEAPF32[$85>>2]);
     $87 = (($14) + (($i$0278*20)|0)|0);
     $88 = Math_fround(HEAPF32[$87>>2]);
     $89 = ((($14) + (($i$0278*20)|0)|0) + 4|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     $91 = ((($14) + (($i$0278*20)|0)|0) + 8|0);
     $92 = Math_fround(HEAPF32[$91>>2]);
     $93 = Math_fround(-$86);
     $94 = Math_fround($88 * $20);
     $95 = Math_fround($90 * $22);
     $96 = Math_fround($94 + $95);
     $97 = Math_fround($92 * $24);
     $98 = Math_fround($96 + $97);
     $99 = Math_fround($88 * $26);
     $100 = Math_fround($90 * $28);
     $101 = Math_fround($99 + $100);
     $102 = Math_fround($92 * $30);
     $103 = Math_fround($101 + $102);
     $104 = Math_fround($88 * $32);
     $105 = Math_fround($90 * $34);
     $106 = Math_fround($104 + $105);
     $107 = Math_fround($92 * $36);
     $108 = Math_fround($106 + $107);
     $109 = $103 > $108;
     $$$i22$i$i80 = $109 ? $103 : $108;
     $$$i12$i$i82 = $109 ? $108 : $103;
     $110 = $98 > $$$i12$i$i82;
     $$$i$i$i83 = $110 ? $$$i12$i$i82 : $98;
     $111 = Math_fround($37 - $86);
     $112 = $$$i$i$i83 > $111;
     if ($112) {
      $$0 = 0;
      label = 19;
      break;
     }
     $113 = ((($16) + (($84*12)|0)|0) + 4|0);
     $114 = (($16) + (($84*12)|0)|0);
     $115 = ((($16) + (($84*12)|0)|0) + 8|0);
     $116 = Math_fround(HEAPF32[$113>>2]);
     $117 = Math_fround(HEAPF32[$114>>2]);
     $118 = $98 > $$$i22$i$i80;
     $119 = Math_fround($90 * $116);
     $120 = Math_fround($88 * $117);
     $121 = Math_fround(HEAPF32[$115>>2]);
     $$$i17$i$i81 = $118 ? $98 : $$$i22$i$i80;
     $122 = Math_fround($92 * $121);
     $123 = Math_fround($119 + $120);
     $124 = Math_fround($37 + $$$i17$i$i81);
     $125 = Math_fround($123 + $122);
     $126 = $125 > $124;
     if ($126) {
      $$0 = 0;
      label = 19;
      break;
     }
     $127 = Math_fround($93 - $$$i$i$i83);
     $128 = $129 > $127;
     if ($128) {
      ;HEAP32[$_minOverlap$sroa$1+0>>2]=HEAP32[$tempOverlap$sroa$1+0>>2]|0;HEAP32[$_minOverlap$sroa$1+4>>2]=HEAP32[$tempOverlap$sroa$1+4>>2]|0;HEAP32[$_minOverlap$sroa$1+8>>2]=HEAP32[$tempOverlap$sroa$1+8>>2]|0;
      $226 = $127;$227 = Math_fround(0.0);$228 = $92;$229 = $90;$230 = $88;$_feature$1 = $i$0278;
     } else {
      $226 = $129;$227 = $221;$228 = $220;$229 = $219;$230 = $218;$_feature$1 = $_feature$0279;
     }
     $130 = (($i$0278) + 1)|0;
     $131 = ($130>>>0)<($11>>>0);
     if ($131) {
      $129 = $226;$218 = $230;$219 = $229;$220 = $228;$221 = $227;$_feature$0279 = $_feature$1;$i$0278 = $130;
     } else {
      $211 = $226;$214 = $230;$215 = $229;$216 = $228;$217 = $227;$_feature$4 = $_feature$1;
      break L1;
     }
    }
    if ((label|0) == 19) {
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $209 = Math_fround(HEAPF32[$minOverlap>>2]);
 $210 = Math_fround($211 + Math_fround(1.1920928955078125E-7));
 $212 = $209 > $210;
 if ($212) {
  $213 = (($minOverlap) + 4|0);
  HEAPF32[$faceNormal>>2] = $214;
  HEAPF32[$1>>2] = $215;
  HEAPF32[$3>>2] = $216;
  HEAPF32[$5>>2] = $217;
  HEAPF32[$minOverlap>>2] = $211;
  ;HEAP32[$213+0>>2]=HEAP32[$_minOverlap$sroa$1+0>>2]|0;HEAP32[$213+4>>2]=HEAP32[$_minOverlap$sroa$1+4>>2]|0;HEAP32[$213+8>>2]=HEAP32[$_minOverlap$sroa$1+8>>2]|0;
  HEAP32[$status>>2] = 1;
 }
 HEAP32[$feature>>2] = $_feature$4;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physxL18testPolyEdgeNormalERKNS_2Gu9TriangleVEhRKNS0_15HullPolygonDataERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSH_RNSG_5Vec3VENS0_13FeatureStatusERSN_($triangle,$triFlags,$polyData,$triMap,$polyMap,$contactDist,$minOverlap,$minNormal,$status) {
 $triangle = $triangle|0;
 $triFlags = $triFlags|0;
 $polyData = $polyData|0;
 $triMap = $triMap|0;
 $polyMap = $polyMap|0;
 $contactDist = $contactDist|0;
 $minOverlap = $minOverlap|0;
 $minNormal = $minNormal|0;
 $status = $status|0;
 var $$$i$i$i$us = Math_fround(0), $$$i$i$us = Math_fround(0), $$$i12$i$i$us = Math_fround(0), $$$i17$i$i$us = Math_fround(0), $$$i22$i$i$us = Math_fround(0), $$0 = 0, $$1$i$i$us = Math_fround(0), $$lcssa409 = Math_fround(0), $$pre$pre$pre = 0, $$pre426$pre = 0, $$sum$us = 0, $$sum1$us = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0;
 var $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0);
 var $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0);
 var $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0;
 var $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0;
 var $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0);
 var $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0);
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$0412 = 0, $k$0402$us = 0, $lEnd$0406$us = 0, $lEnd$0406$us$phi = 0, $lStart$0405$us = 0, $max1 = 0, $min1 = 0, $n0 = 0, $nbTriangleAxes$1 = 0, $nbTriangleAxes$1$1 = 0, $nbTriangleAxes$1$2 = 0, $overlap$sroa$1 = 0, $tempOverlap$sroa$1 = 0, $triangleAxes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $overlap$sroa$1 = sp + 108|0;
 $min1 = sp;
 $max1 = sp + 16|0;
 $triangleAxes = sp + 32|0;
 $n0 = sp + 80|0;
 $tempOverlap$sroa$1 = sp + 96|0;
 $0 = Math_fround(HEAPF32[$minOverlap>>2]);
 $1 = (($minOverlap) + 4|0);
 ;HEAP32[$overlap$sroa$1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$overlap$sroa$1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$overlap$sroa$1+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($polyMap) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($triangle) + 96|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($triangle) + 100|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($triangle) + 104|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(HEAPF32[$3>>2]);
 $11 = Math_fround($5 * $10);
 $12 = (($3) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($7 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (($3) + 32|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($9 * $17);
 $19 = Math_fround($15 + $18);
 $20 = (($3) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($5 * $21);
 $23 = (($3) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($7 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (($3) + 36|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($9 * $28);
 $30 = Math_fround($26 + $29);
 $31 = (($3) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($5 * $32);
 $34 = (($3) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($7 * $35);
 $37 = Math_fround($33 + $36);
 $38 = (($3) + 40|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($9 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($triangle) + 112|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($triangle) + 116|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($triangle) + 120|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($10 * $43);
 $49 = Math_fround($13 * $45);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($17 * $47);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($21 * $43);
 $54 = Math_fround($24 * $45);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround($28 * $47);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($32 * $43);
 $59 = Math_fround($35 * $45);
 $60 = Math_fround($58 + $59);
 $61 = Math_fround($39 * $47);
 $62 = Math_fround($60 + $61);
 $63 = (($triangle) + 128|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($triangle) + 132|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($triangle) + 136|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($10 * $64);
 $70 = Math_fround($13 * $66);
 $71 = Math_fround($69 + $70);
 $72 = Math_fround($17 * $68);
 $73 = Math_fround($71 + $72);
 $74 = Math_fround($21 * $64);
 $75 = Math_fround($24 * $66);
 $76 = Math_fround($74 + $75);
 $77 = Math_fround($28 * $68);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($32 * $64);
 $80 = Math_fround($35 * $66);
 $81 = Math_fround($79 + $80);
 $82 = Math_fround($39 * $68);
 $83 = Math_fround($81 + $82);
 $84 = $triFlags&255;
 $85 = $84 & 32;
 $86 = ($85|0)==(0);
 if ($86) {
  $nbTriangleAxes$1 = 0;
 } else {
  $87 = Math_fround($73 - $19);
  $88 = Math_fround($78 - $30);
  $89 = Math_fround($83 - $41);
  HEAPF32[$triangleAxes>>2] = $87;
  $90 = (($triangleAxes) + 4|0);
  HEAPF32[$90>>2] = $88;
  $91 = (($triangleAxes) + 8|0);
  HEAPF32[$91>>2] = $89;
  $92 = (($triangleAxes) + 12|0);
  HEAPF32[$92>>2] = Math_fround(0.0);
  $nbTriangleAxes$1 = 1;
 }
 $93 = $84 & 8;
 $94 = ($93|0)==(0);
 if ($94) {
  $nbTriangleAxes$1$1 = $nbTriangleAxes$1;
 } else {
  $326 = (($nbTriangleAxes$1) + 1)|0;
  $327 = Math_fround($19 - $52);
  $328 = Math_fround($30 - $57);
  $329 = Math_fround($41 - $62);
  $330 = (($triangleAxes) + ($nbTriangleAxes$1<<4)|0);
  HEAPF32[$330>>2] = $327;
  $331 = ((($triangleAxes) + ($nbTriangleAxes$1<<4)|0) + 4|0);
  HEAPF32[$331>>2] = $328;
  $332 = ((($triangleAxes) + ($nbTriangleAxes$1<<4)|0) + 8|0);
  HEAPF32[$332>>2] = $329;
  $333 = ((($triangleAxes) + ($nbTriangleAxes$1<<4)|0) + 12|0);
  HEAPF32[$333>>2] = Math_fround(0.0);
  $nbTriangleAxes$1$1 = $326;
 }
 $334 = $84 & 16;
 $335 = ($334|0)==(0);
 if ($335) {
  $nbTriangleAxes$1$2 = $nbTriangleAxes$1$1;
 } else {
  $336 = (($nbTriangleAxes$1$1) + 1)|0;
  $337 = Math_fround($52 - $73);
  $338 = Math_fround($57 - $78);
  $339 = Math_fround($62 - $83);
  $340 = (($triangleAxes) + ($nbTriangleAxes$1$1<<4)|0);
  HEAPF32[$340>>2] = $337;
  $341 = ((($triangleAxes) + ($nbTriangleAxes$1$1<<4)|0) + 4|0);
  HEAPF32[$341>>2] = $338;
  $342 = ((($triangleAxes) + ($nbTriangleAxes$1$1<<4)|0) + 8|0);
  HEAPF32[$342>>2] = $339;
  $343 = ((($triangleAxes) + ($nbTriangleAxes$1$1<<4)|0) + 12|0);
  HEAPF32[$343>>2] = Math_fround(0.0);
  $nbTriangleAxes$1$2 = $336;
 }
 $344 = ($nbTriangleAxes$1$2|0)==(0);
 if ($344) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $95 = Math_fround($52 - $19);
 $96 = Math_fround($57 - $30);
 $97 = Math_fround($62 - $41);
 $98 = Math_fround($73 - $19);
 $99 = Math_fround($78 - $30);
 $100 = Math_fround($83 - $41);
 $101 = Math_fround($96 * $100);
 $102 = Math_fround($97 * $99);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($97 * $98);
 $105 = Math_fround($95 * $100);
 $106 = Math_fround($104 - $105);
 $107 = Math_fround($95 * $99);
 $108 = Math_fround($96 * $98);
 $109 = Math_fround($107 - $108);
 $110 = Math_fround($103 * $103);
 $111 = Math_fround($106 * $106);
 $112 = Math_fround($110 + $111);
 $113 = Math_fround($109 * $109);
 $114 = Math_fround($113 + $112);
 $115 = (Math_fround(Math_sqrt((Math_fround($114)))));
 $116 = Math_fround(Math_fround(1.0) / $115);
 $117 = Math_fround($116 * $103);
 $118 = Math_fround($116 * $106);
 $119 = Math_fround($109 * $116);
 $120 = Math_fround(HEAPF32[$4>>2]);
 $121 = Math_fround(HEAPF32[$6>>2]);
 $122 = Math_fround(HEAPF32[$8>>2]);
 $123 = Math_fround($120 * $117);
 $124 = Math_fround($118 * $121);
 $125 = Math_fround($123 + $124);
 $126 = Math_fround($119 * $122);
 $127 = Math_fround($125 + $126);
 $128 = (($polyData) + 16|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ($129|0)==(0);
 L13: do {
  if ($130) {
   $$lcssa409 = $0;
  } else {
   $131 = (($polyData) + 24|0);
   $132 = (($polyData) + 32|0);
   $133 = (($polyData) + 28|0);
   $134 = (($n0) + 4|0);
   $135 = (($n0) + 8|0);
   $136 = (($n0) + 12|0);
   $137 = (($triMap) + 48|0);
   $345 = $129;$346 = $0;$i$0412 = 0;
   L15: while(1) {
    $138 = HEAP32[$131>>2]|0;
    $139 = HEAP32[$132>>2]|0;
    $140 = ((($138) + (($i$0412*20)|0)|0) + 16|0);
    $141 = HEAP16[$140>>1]|0;
    $142 = $141&65535;
    $143 = (($138) + (($i$0412*20)|0)|0);
    $144 = Math_fround(HEAPF32[$143>>2]);
    $145 = ((($138) + (($i$0412*20)|0)|0) + 4|0);
    $146 = Math_fround(HEAPF32[$145>>2]);
    $147 = ((($138) + (($i$0412*20)|0)|0) + 8|0);
    $148 = Math_fround(HEAPF32[$147>>2]);
    $149 = Math_fround($117 * $144);
    $150 = Math_fround($118 * $146);
    $151 = Math_fround($149 + $150);
    $152 = Math_fround($119 * $148);
    $153 = Math_fround($151 + $152);
    $154 = $153 > Math_fround(0.0);
    if ($154) {
     $325 = $345;$347 = $346;
    } else {
     $155 = ((($138) + (($i$0412*20)|0)|0) + 18|0);
     $156 = HEAP8[$155>>0]|0;
     $157 = $156&255;
     $158 = (($157) + -1)|0;
     $159 = ($156<<24>>24)==(0);
     if ($159) {
      $325 = $345;$347 = $346;
     } else {
      $348 = $156;$349 = $346;$lEnd$0406$us = $158;$lStart$0405$us = 0;
      while(1) {
       $$sum$us = (($lStart$0405$us) + ($142))|0;
       $160 = (($139) + ($$sum$us)|0);
       $161 = HEAP8[$160>>0]|0;
       $162 = $161&255;
       $163 = HEAP32[$133>>2]|0;
       $164 = (($163) + (($162*12)|0)|0);
       $165 = Math_fround(HEAPF32[$164>>2]);
       $166 = ((($163) + (($162*12)|0)|0) + 4|0);
       $167 = Math_fround(HEAPF32[$166>>2]);
       $168 = ((($163) + (($162*12)|0)|0) + 8|0);
       $169 = Math_fround(HEAPF32[$168>>2]);
       $$sum1$us = (($lEnd$0406$us) + ($142))|0;
       $170 = (($139) + ($$sum1$us)|0);
       $171 = HEAP8[$170>>0]|0;
       $172 = $171&255;
       $173 = (($163) + (($172*12)|0)|0);
       $174 = Math_fround(HEAPF32[$173>>2]);
       $175 = ((($163) + (($172*12)|0)|0) + 4|0);
       $176 = Math_fround(HEAPF32[$175>>2]);
       $177 = ((($163) + (($172*12)|0)|0) + 8|0);
       $178 = Math_fround(HEAPF32[$177>>2]);
       $179 = Math_fround($117 * $165);
       $180 = Math_fround($118 * $167);
       $181 = Math_fround($179 + $180);
       $182 = Math_fround($119 * $169);
       $183 = Math_fround($181 + $182);
       $184 = Math_fround($183 - $127);
       $185 = Math_fround(HEAPF32[$contactDist>>2]);
       $186 = !($185 >= $184);
       if ($186) {
        $187 = Math_fround($118 * $176);
        $188 = Math_fround($117 * $174);
        $189 = Math_fround($119 * $178);
        $190 = Math_fround($188 + $187);
        $191 = Math_fround($190 + $189);
        $192 = Math_fround($191 - $127);
        $193 = !($185 >= $192);
        if ($193) {
         $321 = $348;$350 = $349;
        } else {
         label = 18;
        }
       } else {
        label = 18;
       }
       if ((label|0) == 18) {
        label = 0;
        $207 = Math_fround($174 - $165);
        $201 = Math_fround($176 - $167);
        $203 = Math_fround($178 - $169);
        $316 = $349;$k$0402$us = 0;
        while(1) {
         $194 = (($triangleAxes) + ($k$0402$us<<4)|0);
         $195 = Math_fround(HEAPF32[$194>>2]);
         $196 = ((($triangleAxes) + ($k$0402$us<<4)|0) + 4|0);
         $197 = Math_fround(HEAPF32[$196>>2]);
         $198 = ((($triangleAxes) + ($k$0402$us<<4)|0) + 8|0);
         $199 = Math_fround(HEAPF32[$198>>2]);
         $200 = Math_fround($201 * $199);
         $202 = Math_fround($203 * $197);
         $204 = Math_fround($200 - $202);
         $205 = Math_fround($203 * $195);
         $206 = Math_fround($207 * $199);
         $208 = Math_fround($205 - $206);
         $209 = Math_fround($207 * $197);
         $210 = Math_fround($201 * $195);
         $211 = Math_fround($209 - $210);
         $212 = Math_fround(-$204);
         $213 = Math_fround(-$208);
         $214 = Math_fround(-$211);
         $215 = $204 > $212;
         $$$i$i$us = $215 ? $204 : $212;
         $216 = $208 > $213;
         $217 = $216 ? $208 : $213;
         $218 = $211 > $214;
         $$1$i$i$us = $218 ? $211 : $214;
         $219 = $$$i$i$us < Math_fround(9.99999997475242707878E-7);
         $220 = $217 < Math_fround(9.99999997475242707878E-7);
         $221 = $219 & $220;
         $222 = $$1$i$i$us < Math_fround(9.99999997475242707878E-7);
         $223 = $221 & $222;
         if ($223) {
          $351 = $316;
         } else {
          $224 = HEAP32[$2>>2]|0;
          $225 = Math_fround(HEAPF32[$224>>2]);
          $226 = Math_fround($204 * $225);
          $227 = (($224) + 4|0);
          $228 = Math_fround(HEAPF32[$227>>2]);
          $229 = Math_fround($208 * $228);
          $230 = Math_fround($226 + $229);
          $231 = (($224) + 8|0);
          $232 = Math_fround(HEAPF32[$231>>2]);
          $233 = Math_fround($211 * $232);
          $234 = Math_fround($230 + $233);
          $235 = (($224) + 16|0);
          $236 = Math_fround(HEAPF32[$235>>2]);
          $237 = Math_fround($204 * $236);
          $238 = (($224) + 20|0);
          $239 = Math_fround(HEAPF32[$238>>2]);
          $240 = Math_fround($208 * $239);
          $241 = Math_fround($237 + $240);
          $242 = (($224) + 24|0);
          $243 = Math_fround(HEAPF32[$242>>2]);
          $244 = Math_fround($211 * $243);
          $245 = Math_fround($241 + $244);
          $246 = (($224) + 32|0);
          $247 = Math_fround(HEAPF32[$246>>2]);
          $248 = Math_fround($204 * $247);
          $249 = (($224) + 36|0);
          $250 = Math_fround(HEAPF32[$249>>2]);
          $251 = Math_fround($208 * $250);
          $252 = Math_fround($248 + $251);
          $253 = (($224) + 40|0);
          $254 = Math_fround(HEAPF32[$253>>2]);
          $255 = Math_fround($211 * $254);
          $256 = Math_fround($252 + $255);
          $257 = Math_fround($234 * $234);
          $258 = Math_fround($245 * $245);
          $259 = Math_fround($257 + $258);
          $260 = Math_fround($256 * $256);
          $261 = Math_fround($259 + $260);
          $262 = (Math_fround(Math_sqrt((Math_fround($261)))));
          $263 = Math_fround(Math_fround(1.0) / $262);
          $264 = Math_fround($234 * $263);
          $265 = Math_fround($245 * $263);
          $266 = Math_fround($256 * $263);
          HEAPF32[$n0>>2] = $264;
          HEAPF32[$134>>2] = $265;
          HEAPF32[$135>>2] = $266;
          HEAPF32[$136>>2] = Math_fround(0.0);
          $267 = HEAP32[$137>>2]|0;
          $268 = (($267) + 96|0);
          $269 = Math_fround(HEAPF32[$268>>2]);
          $270 = (($267) + 100|0);
          $271 = Math_fround(HEAPF32[$270>>2]);
          $272 = (($267) + 104|0);
          $273 = Math_fround(HEAPF32[$272>>2]);
          $274 = (($267) + 112|0);
          $275 = Math_fround(HEAPF32[$274>>2]);
          $276 = (($267) + 116|0);
          $277 = Math_fround(HEAPF32[$276>>2]);
          $278 = (($267) + 120|0);
          $279 = Math_fround(HEAPF32[$278>>2]);
          $280 = (($267) + 128|0);
          $281 = Math_fround(HEAPF32[$280>>2]);
          $282 = (($267) + 132|0);
          $283 = Math_fround(HEAPF32[$282>>2]);
          $284 = (($267) + 136|0);
          $285 = Math_fround(HEAPF32[$284>>2]);
          $286 = Math_fround($269 * $264);
          $287 = Math_fround($271 * $265);
          $288 = Math_fround($286 + $287);
          $289 = Math_fround($273 * $266);
          $290 = Math_fround($288 + $289);
          $291 = Math_fround($275 * $264);
          $292 = Math_fround($277 * $265);
          $293 = Math_fround($291 + $292);
          $294 = Math_fround($279 * $266);
          $295 = Math_fround($293 + $294);
          $296 = Math_fround($281 * $264);
          $297 = Math_fround($283 * $265);
          $298 = Math_fround($296 + $297);
          $299 = Math_fround($285 * $266);
          $300 = Math_fround($298 + $299);
          $301 = $295 > $300;
          $$$i22$i$i$us = $301 ? $295 : $300;
          $302 = $290 > $$$i22$i$i$us;
          $$$i17$i$i$us = $302 ? $290 : $$$i22$i$i$us;
          $$$i12$i$i$us = $301 ? $300 : $295;
          $303 = HEAP32[$polyMap>>2]|0;
          $304 = (($303) + 12|0);
          $305 = HEAP32[$304>>2]|0;
          FUNCTION_TABLE_viiii[$305 & 511]($polyMap,$n0,$min1,$max1);
          $306 = Math_fround(HEAPF32[$min1>>2]);
          $307 = Math_fround(HEAPF32[$contactDist>>2]);
          $308 = Math_fround($$$i17$i$i$us + $307);
          $309 = $306 > $308;
          if ($309) {
           $$0 = 0;
           label = 22;
           break L15;
          }
          $310 = Math_fround(HEAPF32[$max1>>2]);
          $311 = $290 > $$$i12$i$i$us;
          $312 = Math_fround($307 + $310);
          $$$i$i$i$us = $311 ? $$$i12$i$i$us : $290;
          $313 = $$$i$i$i$us > $312;
          if ($313) {
           $$0 = 0;
           label = 22;
           break L15;
          }
          $314 = Math_fround($$$i17$i$i$us - $306);
          $315 = $316 > $314;
          if ($315) {
           ;HEAP32[$overlap$sroa$1+0>>2]=HEAP32[$tempOverlap$sroa$1+0>>2]|0;HEAP32[$overlap$sroa$1+4>>2]=HEAP32[$tempOverlap$sroa$1+4>>2]|0;HEAP32[$overlap$sroa$1+8>>2]=HEAP32[$tempOverlap$sroa$1+8>>2]|0;
           ;HEAP32[$minNormal+0>>2]=HEAP32[$n0+0>>2]|0;HEAP32[$minNormal+4>>2]=HEAP32[$n0+4>>2]|0;HEAP32[$minNormal+8>>2]=HEAP32[$n0+8>>2]|0;HEAP32[$minNormal+12>>2]=HEAP32[$n0+12>>2]|0;
           HEAP32[$status>>2] = 2;
           $351 = $314;
          } else {
           $351 = $316;
          }
         }
         $317 = (($k$0402$us) + 1)|0;
         $318 = ($317>>>0)<($nbTriangleAxes$1$2>>>0);
         if ($318) {
          $316 = $351;$k$0402$us = $317;
         } else {
          break;
         }
        }
        $$pre426$pre = HEAP8[$155>>0]|0;
        $321 = $$pre426$pre;$350 = $351;
       }
       $319 = (($lStart$0405$us) + 1)|0;
       $320 = $321&255;
       $322 = ($319>>>0)<($320>>>0);
       if ($322) {
        $lEnd$0406$us$phi = $lStart$0405$us;$348 = $321;$349 = $350;$lStart$0405$us = $319;$lEnd$0406$us = $lEnd$0406$us$phi;
       } else {
        break;
       }
      }
      $$pre$pre$pre = HEAP32[$128>>2]|0;
      $325 = $$pre$pre$pre;$347 = $350;
     }
    }
    $323 = (($i$0412) + 1)|0;
    $324 = ($323>>>0)<($325>>>0);
    if ($324) {
     $345 = $325;$346 = $347;$i$0412 = $323;
    } else {
     $$lcssa409 = $347;
     break L13;
    }
   }
   if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAPF32[$minOverlap>>2] = $$lcssa409;
 ;HEAP32[$1+0>>2]=HEAP32[$overlap$sroa$1+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$overlap$sroa$1+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$overlap$sroa$1+8>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physxL25generatedTriangleContactsERKNS_2Gu9TriangleVEjhRKNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERKNSG_5Vec3VE($triangle,$triangleIndex,$_triFlags,$polyData1,$incidentPolygon,$map1,$manifoldContacts,$numContacts,$contactDist,$contactNormal) {
 $triangle = $triangle|0;
 $triangleIndex = $triangleIndex|0;
 $_triFlags = $_triFlags|0;
 $polyData1 = $polyData1|0;
 $incidentPolygon = $incidentPolygon|0;
 $map1 = $map1|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $contactNormal = $contactNormal|0;
 var $$$i = Math_fround(0), $$$i101 = Math_fround(0), $$$i107 = Math_fround(0), $$$i200 = Math_fround(0), $$$i2001056$lcssa = Math_fround(0), $$$i20010561084 = Math_fround(0), $$$i206 = Math_fround(0), $$$i2061058$lcssa = Math_fround(0), $$$i20610581082 = Math_fround(0), $$$i238 = Math_fround(0), $$$i238$1 = Math_fround(0), $$$i238$2 = Math_fround(0), $$$i244 = Math_fround(0), $$$i244$1 = Math_fround(0), $$$i244$2 = Math_fround(0), $$$i95 = Math_fround(0), $$demorgan = 0, $$demorgan$i = 0, $$demorgan$i180 = 0, $$lcssa = Math_fround(0);
 var $$lcssa1079 = Math_fround(0), $$lcssa1080 = 0, $$mask = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = Math_fround(0), $$pre$i185 = Math_fround(0), $$sroa$1505 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0;
 var $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0;
 var $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0);
 var $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0;
 var $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0);
 var $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0;
 var $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0);
 var $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = Math_fround(0);
 var $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0;
 var $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0);
 var $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = 0, $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0);
 var $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0);
 var $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0);
 var $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0);
 var $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = Math_fround(0), $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = 0, $487 = Math_fround(0);
 var $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = Math_fround(0), $491 = 0, $492 = 0, $493 = Math_fround(0), $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = Math_fround(0), $506 = 0, $507 = Math_fround(0), $508 = 0, $509 = Math_fround(0), $51 = Math_fround(0), $510 = 0, $511 = Math_fround(0), $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = Math_fround(0), $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = Math_fround(0);
 var $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0);
 var $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = Math_fround(0), $559 = 0;
 var $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0);
 var $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = 0, $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0);
 var $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = 0, $608 = 0, $609 = 0, $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0;
 var $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $a$01075 = 0, $exitcond = 0, $exitcond1103 = 0, $i$0308$i = 0, $i$0308$i189 = 0, $i1$01086 = 0, $i2$01077 = 0, $iEnd$01069 = 0, $iEnd$01069$phi = 0, $iStart$01068 = 0, $inside$0$lcssa = 0, $inside$01085 = 0, $inside$1 = 0, $intersectionPoints$0310$i = 0, $intersectionPoints$0310$i187 = 0;
 var $intersectionPoints$1$i = 0, $intersectionPoints$1$i191 = 0, $j$0309$i = 0, $j$0309$i$phi = 0, $j$0309$i188 = 0, $j$0309$i188$phi = 0, $not$ = 0, $not$$i = 0, $not$$i179 = 0, $not$1067 = 0, $not$304$i = 0, $not$304$i181 = 0, $or$cond = 0, $phitmp = Math_fround(0), $phitmp1100 = Math_fround(0), $phitmp1101 = Math_fround(0), $phitmp1102 = Math_fround(0), $points0In0 = 0, $rEnd$01072 = 0, $rEnd$01072$phi = 0;
 var $rStart$01071 = 0, $rot = 0, $tmp$i = 0, $tmp$i190 = 0, $triFlags$01076 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $rot = sp + 48|0;
 $points0In0 = sp;
 $$sroa$1505 = sp + 96|0;
 $0 = HEAP32[$numContacts>>2]|0;
 __ZN5physx2Gu27findRotationMatrixFromZAxisERKNS_6shdfnd3aos5Vec3VE($rot,$contactNormal);
 $1 = (($polyData1) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($incidentPolygon) + 16|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = (($2) + ($5)|0);
 $7 = (($incidentPolygon) + 18|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 << 4;
 $11 = (($10) + 16)|0;
 $12 = STACKTOP; STACKTOP = STACKTOP + ((((1*$11)|0)+15)&-16)|0;;
 $13 = $12;
 $14 = (($13) + 15)|0;
 $15 = $14 & -16;
 $16 = $15;
 $17 = STACKTOP; STACKTOP = STACKTOP + ((((1*$11)|0)+15)&-16)|0;;
 $18 = $17;
 $19 = (($18) + 15)|0;
 $20 = $19 & -16;
 $21 = STACKTOP; STACKTOP = STACKTOP + ((((1*$9)|0)+15)&-16)|0;;
 $22 = (($triangle) + 96|0);
 ;HEAP32[$points0In0+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$points0In0+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$points0In0+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$points0In0+12>>2]=HEAP32[$22+12>>2]|0;
 $23 = (($points0In0) + 16|0);
 $24 = (($triangle) + 112|0);
 ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;
 $25 = (($points0In0) + 32|0);
 $26 = (($triangle) + 128|0);
 ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;
 $27 = HEAP32[$map1>>2]|0;
 $28 = (($27) + 16|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($polyData1) + 28|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_viiiii[$29 & 255]($map1,$6,$9,$31,$16);
 $32 = Math_fround(HEAPF32[$rot>>2]);
 $33 = (($rot) + 16|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($rot) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($rot) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($rot) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($rot) + 36|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($rot) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($rot) + 24|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($rot) + 40|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround(HEAPF32[$points0In0>>2]);
 $50 = (($points0In0) + 4|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($points0In0) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($points0In0) + 12|0);
 $55 = Math_fround($49 * $32);
 $56 = Math_fround($51 * $34);
 $57 = Math_fround($55 + $56);
 $58 = Math_fround($53 * $36);
 $59 = Math_fround($57 + $58);
 $60 = Math_fround($49 * $38);
 $61 = Math_fround($51 * $40);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($53 * $42);
 $64 = Math_fround($62 + $63);
 $65 = Math_fround($49 * $44);
 $66 = Math_fround($51 * $46);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($53 * $48);
 $69 = Math_fround($67 + $68);
 HEAPF32[$points0In0>>2] = $59;
 HEAPF32[$50>>2] = $64;
 HEAPF32[$52>>2] = $69;
 HEAPF32[$54>>2] = Math_fround(0.0);
 $70 = $59 > Math_fround(3.40282346638528859812E+38);
 $$$i244 = $70 ? Math_fround(3.40282346638528859812E+38) : $59;
 $71 = $64 > Math_fround(3.40282346638528859812E+38);
 $72 = $71 ? Math_fround(3.40282346638528859812E+38) : $64;
 $73 = $59 < Math_fround(-3.40282346638528859812E+38);
 $$$i238 = $73 ? Math_fround(-3.40282346638528859812E+38) : $59;
 $74 = $64 < Math_fround(-3.40282346638528859812E+38);
 $75 = $74 ? Math_fround(-3.40282346638528859812E+38) : $64;
 $76 = (($points0In0) + 16|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($points0In0) + 20|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($points0In0) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($points0In0) + 28|0);
 $83 = Math_fround($77 * $32);
 $84 = Math_fround($79 * $34);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($81 * $36);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($77 * $38);
 $89 = Math_fround($79 * $40);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround($81 * $42);
 $92 = Math_fround($90 + $91);
 $93 = Math_fround($77 * $44);
 $94 = Math_fround($79 * $46);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($81 * $48);
 $97 = Math_fround($95 + $96);
 HEAPF32[$76>>2] = $87;
 HEAPF32[$78>>2] = $92;
 HEAPF32[$80>>2] = $97;
 HEAPF32[$82>>2] = Math_fround(0.0);
 $98 = $$$i244 < $87;
 $$$i244$1 = $98 ? $$$i244 : $87;
 $99 = $72 < $92;
 $100 = $99 ? $72 : $92;
 $101 = $$$i238 > $87;
 $$$i238$1 = $101 ? $$$i238 : $87;
 $102 = $75 > $92;
 $103 = $102 ? $75 : $92;
 $104 = (($points0In0) + 32|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($points0In0) + 36|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($points0In0) + 40|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($points0In0) + 44|0);
 $111 = Math_fround($105 * $32);
 $112 = Math_fround($107 * $34);
 $113 = Math_fround($111 + $112);
 $114 = Math_fround($109 * $36);
 $115 = Math_fround($113 + $114);
 $116 = Math_fround($105 * $38);
 $117 = Math_fround($107 * $40);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($109 * $42);
 $120 = Math_fround($118 + $119);
 $121 = Math_fround($105 * $44);
 $122 = Math_fround($107 * $46);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($109 * $48);
 $125 = Math_fround($123 + $124);
 HEAPF32[$104>>2] = $115;
 HEAPF32[$106>>2] = $120;
 HEAPF32[$108>>2] = $125;
 HEAPF32[$110>>2] = Math_fround(0.0);
 $126 = $$$i244$1 < $115;
 $$$i244$2 = $126 ? $$$i244$1 : $115;
 $127 = $100 < $120;
 $128 = $127 ? $100 : $120;
 $129 = $$$i238$1 > $115;
 $$$i238$2 = $129 ? $$$i238$1 : $115;
 $130 = $103 > $120;
 $131 = $130 ? $103 : $120;
 $132 = $20;
 $133 = Math_fround($$$i244$2 + Math_fround(-1.1920928955078125E-7));
 $134 = Math_fround($128 + Math_fround(-1.1920928955078125E-7));
 $135 = Math_fround($$$i238$2 + Math_fround(1.1920928955078125E-7));
 $136 = Math_fround($131 + Math_fround(1.1920928955078125E-7));
 $137 = Math_fround(HEAPF32[$contactDist>>2]);
 $138 = Math_fround($69 + $137);
 $139 = HEAP8[$7>>0]|0;
 $140 = $139&255;
 $141 = ($139<<24>>24)==(0);
 if ($141) {
  $$$i2001056$lcssa = Math_fround(-3.40282346638528859812E+38);$$$i2061058$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa1079 = Math_fround(-3.40282346638528859812E+38);$$lcssa1080 = $140;$inside$0$lcssa = 0;
 } else {
  $142 = (($contactNormal) + 4|0);
  $143 = (($contactNormal) + 8|0);
  $144 = (($triangle) + 96|0);
  $145 = (($triangle) + 100|0);
  $146 = (($triangle) + 104|0);
  $$$i20010561084 = Math_fround(-3.40282346638528859812E+38);$$$i20610581082 = Math_fround(3.40282346638528859812E+38);$186 = Math_fround(3.40282346638528859812E+38);$190 = Math_fround(-3.40282346638528859812E+38);$i1$01086 = 0;$inside$01085 = 0;
  while(1) {
   $147 = (($16) + ($i1$01086<<4)|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = ((($16) + ($i1$01086<<4)|0) + 4|0);
   $150 = Math_fround(HEAPF32[$149>>2]);
   $151 = ((($16) + ($i1$01086<<4)|0) + 8|0);
   $152 = Math_fround(HEAPF32[$151>>2]);
   $153 = ((($16) + ($i1$01086<<4)|0) + 12|0);
   $154 = Math_fround(HEAPF32[$153>>2]);
   $155 = Math_fround(HEAPF32[$rot>>2]);
   $156 = Math_fround($148 * $155);
   $157 = Math_fround(HEAPF32[$33>>2]);
   $158 = Math_fround($150 * $157);
   $159 = Math_fround($156 + $158);
   $160 = Math_fround(HEAPF32[$35>>2]);
   $161 = Math_fround($152 * $160);
   $162 = Math_fround($159 + $161);
   $163 = Math_fround(HEAPF32[$37>>2]);
   $164 = Math_fround($148 * $163);
   $165 = Math_fround(HEAPF32[$39>>2]);
   $166 = Math_fround($150 * $165);
   $167 = Math_fround($164 + $166);
   $168 = Math_fround(HEAPF32[$41>>2]);
   $169 = Math_fround($152 * $168);
   $170 = Math_fround($167 + $169);
   $171 = Math_fround(HEAPF32[$43>>2]);
   $172 = Math_fround($148 * $171);
   $173 = Math_fround(HEAPF32[$45>>2]);
   $174 = Math_fround($150 * $173);
   $175 = Math_fround($172 + $174);
   $176 = Math_fround(HEAPF32[$47>>2]);
   $177 = Math_fround($152 * $176);
   $178 = Math_fround($175 + $177);
   HEAPF32[$147>>2] = $162;
   HEAPF32[$149>>2] = $170;
   HEAPF32[$151>>2] = $178;
   HEAPF32[$153>>2] = Math_fround(0.0);
   $179 = Math_fround($178 - $69);
   $180 = (($132) + ($i1$01086<<4)|0);
   HEAPF32[$180>>2] = $179;
   $181 = ((($132) + ($i1$01086<<4)|0) + 4|0);
   ;HEAP32[$181+0>>2]=HEAP32[$$sroa$1505+0>>2]|0;HEAP32[$181+4>>2]=HEAP32[$$sroa$1505+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$$sroa$1505+8>>2]|0;
   $182 = Math_fround(HEAPF32[$147>>2]);
   $183 = Math_fround(HEAPF32[$149>>2]);
   HEAPF32[$151>>2] = $69;
   HEAPF32[$153>>2] = Math_fround(0.0);
   $184 = $$$i20610581082 < $182;
   $$$i206 = $184 ? $$$i20610581082 : $182;
   $185 = $186 < $183;
   $187 = $185 ? $186 : $183;
   $188 = $$$i20010561084 > $182;
   $$$i200 = $188 ? $$$i20010561084 : $182;
   $189 = $190 > $183;
   $191 = $189 ? $190 : $183;
   $192 = $138 > $178;
   L5: do {
    if ($192) {
     $193 = (($21) + ($i1$01086)|0);
     HEAP8[$193>>0] = 1;
     $194 = Math_fround(HEAPF32[$147>>2]);
     $195 = Math_fround(HEAPF32[$149>>2]);
     $196 = $194 > $135;
     $not$$i179 = $133 > $194;
     $$demorgan$i180 = $196 | $not$$i179;
     if ($$demorgan$i180) {
      $inside$1 = $inside$01085;
     } else {
      $197 = $195 > $136;
      $not$304$i181 = $134 > $195;
      $198 = $197 | $not$304$i181;
      if ($198) {
       $inside$1 = $inside$01085;
      } else {
       $$pre$i185 = Math_fround(HEAPF32[$106>>2]);
       $202 = $$pre$i185;$i$0308$i189 = 0;$intersectionPoints$0310$i187 = 0;$j$0309$i188 = 2;
       while(1) {
        $199 = ((($points0In0) + ($i$0308$i189<<4)|0) + 4|0);
        $200 = Math_fround(HEAPF32[$199>>2]);
        $201 = $202 > $195;
        $203 = $200 > $195;
        $tmp$i190 = $201 ^ $203;
        if ($tmp$i190) {
         $204 = (($points0In0) + ($i$0308$i189<<4)|0);
         $205 = (($points0In0) + ($j$0309$i188<<4)|0);
         $206 = Math_fround(HEAPF32[$205>>2]);
         $207 = Math_fround(HEAPF32[$204>>2]);
         $208 = Math_fround($207 - $206);
         $209 = Math_fround($200 - $202);
         $210 = Math_fround($195 - $202);
         $211 = Math_fround($210 * $208);
         $212 = Math_fround($209 * $206);
         $213 = Math_fround($194 * $209);
         $214 = Math_fround($212 + $211);
         $215 = !($209 > Math_fround(0.0));
         $216 = $215 ? $213 : $214;
         $217 = $215 ? $214 : $213;
         $218 = !($216 >= $217);
         if ($218) {
          $intersectionPoints$1$i191 = $intersectionPoints$0310$i187;
         } else {
          $219 = ($intersectionPoints$0310$i187|0)==(1);
          if ($219) {
           $inside$1 = $inside$01085;
           break L5;
          }
          $220 = (($intersectionPoints$0310$i187) + 1)|0;
          $intersectionPoints$1$i191 = $220;
         }
        } else {
         $intersectionPoints$1$i191 = $intersectionPoints$0310$i187;
        }
        $221 = (($i$0308$i189) + 1)|0;
        $222 = ($221>>>0)<(3);
        if ($222) {
         $j$0309$i188$phi = $i$0308$i189;$202 = $200;$i$0308$i189 = $221;$intersectionPoints$0310$i187 = $intersectionPoints$1$i191;$j$0309$i188 = $j$0309$i188$phi;
        } else {
         break;
        }
       }
       $223 = ($intersectionPoints$1$i191|0)==(0);
       if ($223) {
        $inside$1 = $inside$01085;
       } else {
        $224 = (($inside$01085) + 1)|0;
        $225 = Math_fround(HEAPF32[$contactNormal>>2]);
        $226 = Math_fround(HEAPF32[$142>>2]);
        $227 = Math_fround(HEAPF32[$143>>2]);
        $228 = Math_fround(HEAPF32[$144>>2]);
        $229 = Math_fround(HEAPF32[$145>>2]);
        $230 = Math_fround(HEAPF32[$146>>2]);
        $231 = Math_fround($228 - $148);
        $232 = Math_fround($229 - $150);
        $233 = Math_fround($230 - $152);
        $234 = Math_fround($225 * $231);
        $235 = Math_fround($226 * $232);
        $236 = Math_fround($234 + $235);
        $237 = Math_fround($227 * $233);
        $238 = Math_fround($236 + $237);
        $239 = Math_fround($225 * $238);
        $240 = Math_fround($226 * $238);
        $241 = Math_fround($227 * $238);
        $242 = Math_fround($148 + $239);
        $243 = Math_fround($150 + $240);
        $244 = Math_fround($152 + $241);
        $245 = Math_fround(-$238);
        $246 = HEAP32[$numContacts>>2]|0;
        $247 = (($manifoldContacts) + ($246<<6)|0);
        HEAPF32[$247>>2] = $148;
        $248 = ((($manifoldContacts) + ($246<<6)|0) + 4|0);
        HEAPF32[$248>>2] = $150;
        $249 = ((($manifoldContacts) + ($246<<6)|0) + 8|0);
        HEAPF32[$249>>2] = $152;
        $250 = ((($manifoldContacts) + ($246<<6)|0) + 12|0);
        HEAPF32[$250>>2] = $154;
        $251 = HEAP32[$numContacts>>2]|0;
        $252 = ((($manifoldContacts) + ($251<<6)|0) + 16|0);
        HEAPF32[$252>>2] = $242;
        $253 = ((($manifoldContacts) + ($251<<6)|0) + 20|0);
        HEAPF32[$253>>2] = $243;
        $254 = ((($manifoldContacts) + ($251<<6)|0) + 24|0);
        HEAPF32[$254>>2] = $244;
        $255 = ((($manifoldContacts) + ($251<<6)|0) + 28|0);
        HEAPF32[$255>>2] = Math_fround(0.0);
        $256 = HEAP32[$numContacts>>2]|0;
        $257 = ((($manifoldContacts) + ($256<<6)|0) + 32|0);
        HEAPF32[$257>>2] = $225;
        $258 = ((($manifoldContacts) + ($256<<6)|0) + 36|0);
        HEAPF32[$258>>2] = $226;
        $259 = ((($manifoldContacts) + ($256<<6)|0) + 40|0);
        HEAPF32[$259>>2] = $227;
        $260 = ((($manifoldContacts) + ($256<<6)|0) + 44|0);
        HEAPF32[$260>>2] = $245;
        $261 = HEAP32[$numContacts>>2]|0;
        $262 = (($261) + 1)|0;
        HEAP32[$numContacts>>2] = $262;
        $263 = ((($manifoldContacts) + ($261<<6)|0) + 48|0);
        HEAP32[$263>>2] = $triangleIndex;
        $inside$1 = $224;
       }
      }
     }
    } else {
     $inside$1 = $inside$01085;
    }
   } while(0);
   $264 = (($i1$01086) + 1)|0;
   $265 = HEAP8[$7>>0]|0;
   $266 = $265&255;
   $267 = ($264>>>0)<($266>>>0);
   if ($267) {
    $$$i20010561084 = $$$i200;$$$i20610581082 = $$$i206;$186 = $187;$190 = $191;$i1$01086 = $264;$inside$01085 = $inside$1;
   } else {
    break;
   }
  }
  $phitmp = Math_fround($$$i206 + Math_fround(-1.1920928955078125E-7));
  $phitmp1100 = Math_fround($187 + Math_fround(-1.1920928955078125E-7));
  $phitmp1101 = Math_fround($$$i200 + Math_fround(1.1920928955078125E-7));
  $phitmp1102 = Math_fround($191 + Math_fround(1.1920928955078125E-7));
  $$$i2001056$lcssa = $phitmp1101;$$$i2061058$lcssa = $phitmp;$$lcssa = $phitmp1100;$$lcssa1079 = $phitmp1102;$$lcssa1080 = $266;$inside$0$lcssa = $inside$1;
 }
 $268 = ($inside$0$lcssa|0)==($$lcssa1080|0);
 if ($268) {
  STACKTOP = sp;return;
 }
 $269 = (($map1) + 40|0);
 $270 = HEAP32[$269>>2]|0;
 $271 = Math_fround(HEAPF32[$incidentPolygon>>2]);
 $272 = (($incidentPolygon) + 4|0);
 $273 = Math_fround(HEAPF32[$272>>2]);
 $274 = (($incidentPolygon) + 8|0);
 $275 = Math_fround(HEAPF32[$274>>2]);
 $276 = Math_fround(HEAPF32[$270>>2]);
 $277 = Math_fround($271 * $276);
 $278 = (($270) + 4|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = Math_fround($273 * $279);
 $281 = Math_fround($277 + $280);
 $282 = (($270) + 8|0);
 $283 = Math_fround(HEAPF32[$282>>2]);
 $284 = Math_fround($275 * $283);
 $285 = Math_fround($281 + $284);
 $286 = (($270) + 16|0);
 $287 = Math_fround(HEAPF32[$286>>2]);
 $288 = Math_fround($271 * $287);
 $289 = (($270) + 20|0);
 $290 = Math_fround(HEAPF32[$289>>2]);
 $291 = Math_fround($273 * $290);
 $292 = Math_fround($288 + $291);
 $293 = (($270) + 24|0);
 $294 = Math_fround(HEAPF32[$293>>2]);
 $295 = Math_fround($275 * $294);
 $296 = Math_fround($292 + $295);
 $297 = (($270) + 32|0);
 $298 = Math_fround(HEAPF32[$297>>2]);
 $299 = Math_fround($271 * $298);
 $300 = (($270) + 36|0);
 $301 = Math_fround(HEAPF32[$300>>2]);
 $302 = Math_fround($273 * $301);
 $303 = Math_fround($299 + $302);
 $304 = (($270) + 40|0);
 $305 = Math_fround(HEAPF32[$304>>2]);
 $306 = Math_fround($275 * $305);
 $307 = Math_fround($303 + $306);
 $308 = Math_fround($285 * $285);
 $309 = Math_fround($296 * $296);
 $310 = Math_fround($308 + $309);
 $311 = Math_fround($307 * $307);
 $312 = Math_fround($310 + $311);
 $313 = (Math_fround(Math_sqrt((Math_fround($312)))));
 $314 = Math_fround(Math_fround(1.0) / $313);
 $315 = Math_fround($285 * $314);
 $316 = Math_fround($296 * $314);
 $317 = Math_fround($307 * $314);
 $318 = (($map1) + 36|0);
 $319 = HEAP32[$318>>2]|0;
 $320 = HEAP8[$6>>0]|0;
 $321 = $320&255;
 $322 = HEAP32[$30>>2]|0;
 $323 = (($322) + (($321*12)|0)|0);
 $324 = Math_fround(HEAPF32[$323>>2]);
 $325 = ((($322) + (($321*12)|0)|0) + 4|0);
 $326 = Math_fround(HEAPF32[$325>>2]);
 $327 = ((($322) + (($321*12)|0)|0) + 8|0);
 $328 = Math_fround(HEAPF32[$327>>2]);
 $329 = Math_fround(HEAPF32[$319>>2]);
 $330 = Math_fround($324 * $329);
 $331 = (($319) + 16|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = Math_fround($326 * $332);
 $334 = Math_fround($330 + $333);
 $335 = (($319) + 32|0);
 $336 = Math_fround(HEAPF32[$335>>2]);
 $337 = Math_fround($328 * $336);
 $338 = Math_fround($334 + $337);
 $339 = (($319) + 4|0);
 $340 = Math_fround(HEAPF32[$339>>2]);
 $341 = Math_fround($324 * $340);
 $342 = (($319) + 20|0);
 $343 = Math_fround(HEAPF32[$342>>2]);
 $344 = Math_fround($326 * $343);
 $345 = Math_fround($341 + $344);
 $346 = (($319) + 36|0);
 $347 = Math_fround(HEAPF32[$346>>2]);
 $348 = Math_fround($328 * $347);
 $349 = Math_fround($345 + $348);
 $350 = (($319) + 8|0);
 $351 = Math_fround(HEAPF32[$350>>2]);
 $352 = Math_fround($324 * $351);
 $353 = (($319) + 24|0);
 $354 = Math_fround(HEAPF32[$353>>2]);
 $355 = Math_fround($326 * $354);
 $356 = Math_fround($352 + $355);
 $357 = (($319) + 40|0);
 $358 = Math_fround(HEAPF32[$357>>2]);
 $359 = Math_fround($328 * $358);
 $360 = Math_fround($356 + $359);
 $361 = Math_fround($315 * $338);
 $362 = Math_fround($316 * $349);
 $363 = Math_fround($361 + $362);
 $364 = Math_fround($317 * $360);
 $365 = Math_fround($363 + $364);
 $366 = (($contactNormal) + 4|0);
 $367 = (($contactNormal) + 8|0);
 $i2$01077 = 0;
 while(1) {
  $368 = HEAP8[$7>>0]|0;
  $369 = $368&255;
  $370 = (($points0In0) + ($i2$01077<<4)|0);
  $371 = Math_fround(HEAPF32[$370>>2]);
  $372 = ((($points0In0) + ($i2$01077<<4)|0) + 4|0);
  $373 = Math_fround(HEAPF32[$372>>2]);
  $374 = $371 > $$$i2001056$lcssa;
  $not$$i = $$$i2061058$lcssa > $371;
  $$demorgan$i = $374 | $not$$i;
  L26: do {
   if (!($$demorgan$i)) {
    $375 = $373 > $$lcssa1079;
    $not$304$i = $$lcssa > $373;
    $376 = $375 | $not$304$i;
    $377 = ($368<<24>>24)==(0);
    $or$cond = $376 | $377;
    if (!($or$cond)) {
     $378 = (($369) + -1)|0;
     $$phi$trans$insert$i = ((($16) + ($378<<4)|0) + 4|0);
     $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
     $382 = $$pre$i;$i$0308$i = 0;$intersectionPoints$0310$i = 0;$j$0309$i = $378;
     while(1) {
      $379 = ((($16) + ($i$0308$i<<4)|0) + 4|0);
      $380 = Math_fround(HEAPF32[$379>>2]);
      $381 = $382 > $373;
      $383 = $380 > $373;
      $tmp$i = $381 ^ $383;
      if ($tmp$i) {
       $384 = (($16) + ($i$0308$i<<4)|0);
       $385 = (($16) + ($j$0309$i<<4)|0);
       $386 = Math_fround(HEAPF32[$385>>2]);
       $387 = Math_fround(HEAPF32[$384>>2]);
       $388 = Math_fround($387 - $386);
       $389 = Math_fround($380 - $382);
       $390 = Math_fround($373 - $382);
       $391 = Math_fround($390 * $388);
       $392 = Math_fround($389 * $386);
       $393 = Math_fround($371 * $389);
       $394 = Math_fround($392 + $391);
       $395 = !($389 > Math_fround(0.0));
       $396 = $395 ? $393 : $394;
       $397 = $395 ? $394 : $393;
       $398 = !($396 >= $397);
       if ($398) {
        $intersectionPoints$1$i = $intersectionPoints$0310$i;
       } else {
        $399 = ($intersectionPoints$0310$i|0)==(1);
        if ($399) {
         break L26;
        }
        $400 = (($intersectionPoints$0310$i) + 1)|0;
        $intersectionPoints$1$i = $400;
       }
      } else {
       $intersectionPoints$1$i = $intersectionPoints$0310$i;
      }
      $401 = (($i$0308$i) + 1)|0;
      $402 = ($401>>>0)<($369>>>0);
      if ($402) {
       $j$0309$i$phi = $i$0308$i;$382 = $380;$i$0308$i = $401;$intersectionPoints$0310$i = $intersectionPoints$1$i;$j$0309$i = $j$0309$i$phi;
      } else {
       break;
      }
     }
     $403 = ($intersectionPoints$1$i|0)==(0);
     if (!($403)) {
      $404 = ((($points0In0) + ($i2$01077<<4)|0) + 8|0);
      $405 = Math_fround(HEAPF32[$404>>2]);
      $406 = Math_fround(HEAPF32[$rot>>2]);
      $407 = Math_fround($371 * $406);
      $408 = Math_fround(HEAPF32[$37>>2]);
      $409 = Math_fround($373 * $408);
      $410 = Math_fround($407 + $409);
      $411 = Math_fround(HEAPF32[$43>>2]);
      $412 = Math_fround($405 * $411);
      $413 = Math_fround($410 + $412);
      $414 = Math_fround(HEAPF32[$33>>2]);
      $415 = Math_fround($371 * $414);
      $416 = Math_fround(HEAPF32[$39>>2]);
      $417 = Math_fround($373 * $416);
      $418 = Math_fround($415 + $417);
      $419 = Math_fround(HEAPF32[$45>>2]);
      $420 = Math_fround($405 * $419);
      $421 = Math_fround($418 + $420);
      $422 = Math_fround(HEAPF32[$35>>2]);
      $423 = Math_fround($371 * $422);
      $424 = Math_fround(HEAPF32[$41>>2]);
      $425 = Math_fround($373 * $424);
      $426 = Math_fround($423 + $425);
      $427 = Math_fround(HEAPF32[$47>>2]);
      $428 = Math_fround($405 * $427);
      $429 = Math_fround($426 + $428);
      $430 = Math_fround($315 * $413);
      $431 = Math_fround($316 * $421);
      $432 = Math_fround($430 + $431);
      $433 = Math_fround($317 * $429);
      $434 = Math_fround($432 + $433);
      $435 = Math_fround($434 - $365);
      $436 = Math_fround(HEAPF32[$contactDist>>2]);
      $437 = $435 > $436;
      if (!($437)) {
       $438 = Math_fround($315 * $435);
       $439 = Math_fround($316 * $435);
       $440 = Math_fround($317 * $435);
       $441 = Math_fround($413 - $438);
       $442 = Math_fround($421 - $439);
       $443 = Math_fround($429 - $440);
       $444 = Math_fround($441 - $413);
       $445 = Math_fround($442 - $421);
       $446 = Math_fround($443 - $429);
       $447 = Math_fround(HEAPF32[$contactNormal>>2]);
       $448 = Math_fround(HEAPF32[$366>>2]);
       $449 = Math_fround(HEAPF32[$367>>2]);
       $450 = Math_fround($444 * $447);
       $451 = Math_fround($445 * $448);
       $452 = Math_fround($450 + $451);
       $453 = Math_fround($446 * $449);
       $454 = Math_fround($452 + $453);
       $455 = HEAP32[$numContacts>>2]|0;
       $456 = (($manifoldContacts) + ($455<<6)|0);
       HEAPF32[$456>>2] = $441;
       $457 = ((($manifoldContacts) + ($455<<6)|0) + 4|0);
       HEAPF32[$457>>2] = $442;
       $458 = ((($manifoldContacts) + ($455<<6)|0) + 8|0);
       HEAPF32[$458>>2] = $443;
       $459 = ((($manifoldContacts) + ($455<<6)|0) + 12|0);
       HEAPF32[$459>>2] = Math_fround(0.0);
       $460 = HEAP32[$numContacts>>2]|0;
       $461 = ((($manifoldContacts) + ($460<<6)|0) + 16|0);
       HEAPF32[$461>>2] = $413;
       $462 = ((($manifoldContacts) + ($460<<6)|0) + 20|0);
       HEAPF32[$462>>2] = $421;
       $463 = ((($manifoldContacts) + ($460<<6)|0) + 24|0);
       HEAPF32[$463>>2] = $429;
       $464 = ((($manifoldContacts) + ($460<<6)|0) + 28|0);
       HEAPF32[$464>>2] = Math_fround(0.0);
       $465 = HEAP32[$numContacts>>2]|0;
       $466 = ((($manifoldContacts) + ($465<<6)|0) + 32|0);
       HEAPF32[$466>>2] = $447;
       $467 = ((($manifoldContacts) + ($465<<6)|0) + 36|0);
       HEAPF32[$467>>2] = $448;
       $468 = ((($manifoldContacts) + ($465<<6)|0) + 40|0);
       HEAPF32[$468>>2] = $449;
       $469 = ((($manifoldContacts) + ($465<<6)|0) + 44|0);
       HEAPF32[$469>>2] = $454;
       $470 = HEAP32[$numContacts>>2]|0;
       $471 = (($470) + 1)|0;
       HEAP32[$numContacts>>2] = $471;
       $472 = ((($manifoldContacts) + ($470<<6)|0) + 48|0);
       HEAP32[$472>>2] = $triangleIndex;
      }
     }
    }
   }
  } while(0);
  $473 = (($i2$01077) + 1)|0;
  $exitcond1103 = ($473|0)==(3);
  if ($exitcond1103) {
   $a$01075 = 0;$triFlags$01076 = $_triFlags;
   break;
  } else {
   $i2$01077 = $473;
  }
 }
 while(1) {
  $474 = $triFlags$01076&255;
  $$mask = $474 & 248;
  $475 = ($$mask|0)==(0);
  if (!($475)) {
   $rEnd$01072 = 2;$rStart$01071 = 0;
   while(1) {
    $476 = (($rEnd$01072) + 3)|0;
    $477 = 1 << $476;
    $478 = $477 & $474;
    $479 = ($478|0)==(0);
    if (!($479)) {
     $480 = (($points0In0) + ($rStart$01071<<4)|0);
     $481 = Math_fround(HEAPF32[$480>>2]);
     $482 = ((($points0In0) + ($rStart$01071<<4)|0) + 4|0);
     $483 = Math_fround(HEAPF32[$482>>2]);
     $484 = (($points0In0) + ($rEnd$01072<<4)|0);
     $485 = Math_fround(HEAPF32[$484>>2]);
     $486 = ((($points0In0) + ($rEnd$01072<<4)|0) + 4|0);
     $487 = Math_fround(HEAPF32[$486>>2]);
     $488 = $481 < $485;
     $$$i107 = $488 ? $481 : $485;
     $489 = $483 < $487;
     $490 = $489 ? $483 : $487;
     $491 = $481 > $485;
     $$$i101 = $491 ? $481 : $485;
     $492 = $483 > $487;
     $493 = $492 ? $483 : $487;
     $494 = HEAP8[$7>>0]|0;
     $495 = ($494<<24>>24)==(0);
     if (!($495)) {
      $496 = $494&255;
      $497 = (($496) + -1)|0;
      $636 = $494;$iEnd$01069 = $497;$iStart$01068 = 0;
      while(1) {
       $498 = (($21) + ($iStart$01068)|0);
       $499 = HEAP8[$498>>0]|0;
       $500 = ($499<<24>>24)==(0);
       if ($500) {
        $501 = (($21) + ($iEnd$01069)|0);
        $502 = HEAP8[$501>>0]|0;
        $503 = ($502<<24>>24)==(0);
        if ($503) {
         $627 = $636;
        } else {
         label = 36;
        }
       } else {
        label = 36;
       }
       if ((label|0) == 36) {
        label = 0;
        $504 = (($16) + ($iStart$01068<<4)|0);
        $505 = Math_fround(HEAPF32[$504>>2]);
        $506 = ((($16) + ($iStart$01068<<4)|0) + 4|0);
        $507 = Math_fround(HEAPF32[$506>>2]);
        $508 = (($16) + ($iEnd$01069<<4)|0);
        $509 = Math_fround(HEAPF32[$508>>2]);
        $510 = ((($16) + ($iEnd$01069<<4)|0) + 4|0);
        $511 = Math_fround(HEAPF32[$510>>2]);
        $512 = $505 < $509;
        $$$i95 = $512 ? $505 : $509;
        $513 = $505 > $509;
        $$$i = $513 ? $505 : $509;
        $514 = $$$i107 > $$$i;
        $not$ = $$$i95 > $$$i101;
        $$demorgan = $514 | $not$;
        if ($$demorgan) {
         $627 = $636;
        } else {
         $515 = $507 > $511;
         $516 = $515 ? $507 : $511;
         $517 = $507 < $511;
         $518 = $517 ? $507 : $511;
         $519 = $490 > $516;
         $not$1067 = $518 > $493;
         $520 = $519 | $not$1067;
         if ($520) {
          $627 = $636;
         } else {
          $521 = Math_fround($481 - $505);
          $522 = Math_fround($483 - $507);
          $523 = Math_fround($485 - $505);
          $524 = Math_fround($487 - $507);
          $525 = Math_fround($521 * $524);
          $526 = Math_fround($523 * $522);
          $527 = Math_fround($525 - $526);
          $528 = Math_fround($481 - $509);
          $529 = Math_fround($483 - $511);
          $530 = Math_fround($485 - $509);
          $531 = Math_fround($487 - $511);
          $532 = Math_fround($528 * $531);
          $533 = Math_fround($530 * $529);
          $534 = Math_fround($532 - $533);
          $535 = Math_fround($527 * $534);
          $536 = $535 < Math_fround(0.0);
          if ($536) {
           $537 = Math_fround($505 - $481);
           $538 = Math_fround($507 - $483);
           $539 = Math_fround($509 - $481);
           $540 = Math_fround($511 - $483);
           $541 = Math_fround($537 * $540);
           $542 = Math_fround($538 * $539);
           $543 = Math_fround($541 - $542);
           $544 = Math_fround($505 - $485);
           $545 = Math_fround($507 - $487);
           $546 = Math_fround($509 - $485);
           $547 = Math_fround($511 - $487);
           $548 = Math_fround($544 * $547);
           $549 = Math_fround($545 * $546);
           $550 = Math_fround($548 - $549);
           $551 = Math_fround($543 * $550);
           $552 = $551 < Math_fround(0.0);
           if ($552) {
            $553 = Math_fround($534 - $527);
            $554 = Math_fround(Math_fround(1.0) / $553);
            $555 = Math_fround($527 * $554);
            $556 = (($132) + ($iStart$01068<<4)|0);
            $557 = Math_fround(HEAPF32[$556>>2]);
            $558 = Math_fround($69 + $557);
            $559 = (($132) + ($iEnd$01069<<4)|0);
            $560 = Math_fround(HEAPF32[$559>>2]);
            $561 = Math_fround($69 + $560);
            $562 = Math_fround($509 - $505);
            $563 = Math_fround($511 - $507);
            $564 = Math_fround($561 - $558);
            $565 = Math_fround($555 * $562);
            $566 = Math_fround($555 * $563);
            $567 = Math_fround($555 * $564);
            $568 = Math_fround($505 - $565);
            $569 = Math_fround($507 - $566);
            $570 = Math_fround($558 - $567);
            $571 = Math_fround(HEAPF32[$rot>>2]);
            $572 = Math_fround($571 * $568);
            $573 = Math_fround(HEAPF32[$37>>2]);
            $574 = Math_fround($573 * $569);
            $575 = Math_fround($572 + $574);
            $576 = Math_fround(HEAPF32[$43>>2]);
            $577 = Math_fround(HEAPF32[$33>>2]);
            $578 = Math_fround($568 * $577);
            $579 = Math_fround(HEAPF32[$39>>2]);
            $580 = Math_fround($569 * $579);
            $581 = Math_fround($578 + $580);
            $582 = Math_fround(HEAPF32[$45>>2]);
            $583 = Math_fround(HEAPF32[$35>>2]);
            $584 = Math_fround($568 * $583);
            $585 = Math_fround(HEAPF32[$41>>2]);
            $586 = Math_fround($569 * $585);
            $587 = Math_fround($584 + $586);
            $588 = Math_fround(HEAPF32[$47>>2]);
            $589 = Math_fround($570 - $69);
            $590 = Math_fround(HEAPF32[$contactDist>>2]);
            $591 = $589 > $590;
            if ($591) {
             $627 = $636;
            } else {
             $592 = Math_fround($570 * $588);
             $593 = Math_fround($570 * $582);
             $594 = Math_fround($576 * $570);
             $595 = Math_fround($69 * $588);
             $596 = Math_fround($69 * $582);
             $597 = Math_fround($69 * $576);
             $598 = Math_fround($587 + $592);
             $599 = Math_fround($581 + $593);
             $600 = Math_fround($575 + $594);
             $601 = Math_fround($587 + $595);
             $602 = Math_fround($581 + $596);
             $603 = Math_fround($575 + $597);
             $604 = Math_fround(HEAPF32[$contactNormal>>2]);
             $605 = Math_fround(HEAPF32[$366>>2]);
             $606 = Math_fround(HEAPF32[$367>>2]);
             $607 = HEAP32[$numContacts>>2]|0;
             $608 = (($manifoldContacts) + ($607<<6)|0);
             HEAPF32[$608>>2] = $600;
             $609 = ((($manifoldContacts) + ($607<<6)|0) + 4|0);
             HEAPF32[$609>>2] = $599;
             $610 = ((($manifoldContacts) + ($607<<6)|0) + 8|0);
             HEAPF32[$610>>2] = $598;
             $611 = ((($manifoldContacts) + ($607<<6)|0) + 12|0);
             HEAPF32[$611>>2] = Math_fround(0.0);
             $612 = HEAP32[$numContacts>>2]|0;
             $613 = ((($manifoldContacts) + ($612<<6)|0) + 16|0);
             HEAPF32[$613>>2] = $603;
             $614 = ((($manifoldContacts) + ($612<<6)|0) + 20|0);
             HEAPF32[$614>>2] = $602;
             $615 = ((($manifoldContacts) + ($612<<6)|0) + 24|0);
             HEAPF32[$615>>2] = $601;
             $616 = ((($manifoldContacts) + ($612<<6)|0) + 28|0);
             HEAPF32[$616>>2] = Math_fround(0.0);
             $617 = HEAP32[$numContacts>>2]|0;
             $618 = ((($manifoldContacts) + ($617<<6)|0) + 32|0);
             HEAPF32[$618>>2] = $604;
             $619 = ((($manifoldContacts) + ($617<<6)|0) + 36|0);
             HEAPF32[$619>>2] = $605;
             $620 = ((($manifoldContacts) + ($617<<6)|0) + 40|0);
             HEAPF32[$620>>2] = $606;
             $621 = ((($manifoldContacts) + ($617<<6)|0) + 44|0);
             HEAPF32[$621>>2] = $589;
             $622 = HEAP32[$numContacts>>2]|0;
             $623 = (($622) + 1)|0;
             HEAP32[$numContacts>>2] = $623;
             $624 = ((($manifoldContacts) + ($622<<6)|0) + 48|0);
             HEAP32[$624>>2] = $triangleIndex;
             $$pre = HEAP8[$7>>0]|0;
             $627 = $$pre;
            }
           } else {
            $627 = $636;
           }
          } else {
           $627 = $636;
          }
         }
        }
       }
       $625 = (($iStart$01068) + 1)|0;
       $626 = $627&255;
       $628 = ($625>>>0)<($626>>>0);
       if ($628) {
        $iEnd$01069$phi = $iStart$01068;$636 = $627;$iStart$01068 = $625;$iEnd$01069 = $iEnd$01069$phi;
       } else {
        break;
       }
      }
     }
    }
    $629 = (($rStart$01071) + 1)|0;
    $exitcond = ($629|0)==(3);
    if ($exitcond) {
     break;
    } else {
     $rEnd$01072$phi = $rStart$01071;$rStart$01071 = $629;$rEnd$01072 = $rEnd$01072$phi;
    }
   }
  }
  $630 = HEAP32[$numContacts>>2]|0;
  $631 = ($0|0)==($630|0);
  if (!($631)) {
   label = 46;
   break;
  }
  $632 = $474 ^ 255;
  $633 = $632&255;
  $634 = (($a$01075) + 1)|0;
  $635 = ($634>>>0)<(2);
  if ($635) {
   $a$01075 = $634;$triFlags$01076 = $633;
  } else {
   label = 46;
   break;
  }
 }
 if ((label|0) == 46) {
  STACKTOP = sp;return;
 }
}
function __ZN5physxL21generatedPolyContactsERKNS_2Gu13PolygonalDataERKNS0_15HullPolygonDataERKNS0_9TriangleVEjhPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERKNSG_5Vec3VE($polyData0,$referencePolygon,$triangle,$triangleIndex,$triFlags,$map0,$manifoldContacts,$numContacts,$contactDist,$contactNormal) {
 $polyData0 = $polyData0|0;
 $referencePolygon = $referencePolygon|0;
 $triangle = $triangle|0;
 $triangleIndex = $triangleIndex|0;
 $triFlags = $triFlags|0;
 $map0 = $map0|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $contactNormal = $contactNormal|0;
 var $$$i = Math_fround(0), $$$i101 = Math_fround(0), $$$i107 = Math_fround(0), $$$i216 = Math_fround(0), $$$i21611261161 = Math_fround(0), $$$i222 = Math_fround(0), $$$i22211281159 = Math_fround(0), $$$i254 = Math_fround(0), $$$i2541130$lcssa = Math_fround(0), $$$i25411301169 = Math_fround(0), $$$i260 = Math_fround(0), $$$i2601132$lcssa = Math_fround(0), $$$i26011321167 = Math_fround(0), $$$i95 = Math_fround(0), $$demorgan = 0, $$demorgan$i = 0, $$demorgan$i198 = 0, $$lcssa1164 = Math_fround(0), $$lcssa1165 = Math_fround(0), $$phi$trans$insert$i = 0;
 var $$phi$trans$insert$i202 = 0, $$pre = Math_fround(0), $$pre$i = Math_fround(0), $$pre$i203 = Math_fround(0), $$pre1187 = Math_fround(0), $$pre1188 = Math_fround(0), $$pre1189 = Math_fround(0), $$pre1190 = Math_fround(0), $$pre1191 = Math_fround(0), $$pre1192 = Math_fround(0), $$pre1193 = Math_fround(0), $$pre1194 = Math_fround(0), $$pre1195 = Math_fround(0), $$pre1196 = 0, $$pre1197 = 0, $$pre1202 = 0, $$pre1204 = 0, $$pre1206 = 0, $$pre1208 = 0, $$pre1210 = 0;
 var $$pre1212 = 0, $$pre1214 = 0, $$pre1216 = 0, $$sroa$1541 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0;
 var $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0;
 var $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0);
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0);
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0);
 var $419 = 0, $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0);
 var $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = Math_fround(0), $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0);
 var $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0);
 var $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0);
 var $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0);
 var $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge = 0, $exitcond = 0, $exitcond1184 = 0, $i$01170 = 0, $i$0308$i = 0, $i$0308$i206 = 0, $i1$01163 = 0, $i2$01154 = 0;
 var $iEnd$01153 = 0, $iEnd$01153$phi = 0, $iStart$01151 = 0, $inside$01162 = 0, $inside$1 = 0, $intersectionPoints$0310$i = 0, $intersectionPoints$0310$i204 = 0, $intersectionPoints$1$i = 0, $intersectionPoints$1$i208 = 0, $j$0309$i = 0, $j$0309$i$phi = 0, $j$0309$i205 = 0, $j$0309$i205$phi = 0, $not$ = 0, $not$$i = 0, $not$$i197 = 0, $not$1147 = 0, $not$304$i = 0, $not$304$i199 = 0, $or$cond = 0;
 var $phitmp = Math_fround(0), $phitmp1178 = Math_fround(0), $phitmp1179 = Math_fround(0), $phitmp1180 = Math_fround(0), $phitmp1218 = 0, $points1In0 = 0, $points1In0Penetration = 0, $points1In0TValue = 0, $rEnd$01149 = 0, $rEnd$01149$phi = 0, $rStart$01148 = 0, $rot = 0, $tmp$i = 0, $tmp$i207 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $rot = sp + 96|0;
 $points1In0 = sp;
 $points1In0TValue = sp + 48|0;
 $points1In0Penetration = sp + 156|0;
 $$sroa$1541 = sp + 144|0;
 $0 = (($polyData0) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($referencePolygon) + 16|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = Math_fround(HEAPF32[$contactNormal>>2]);
 $6 = (($contactNormal) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($contactNormal) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(-$7);
 __ZN5physx2Gu27findRotationMatrixFromZAxisERKNS_6shdfnd3aos5Vec3VE($rot,$contactNormal);
 $11 = (($referencePolygon) + 18|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 4;
 $15 = (($14) + 16)|0;
 $16 = STACKTOP; STACKTOP = STACKTOP + ((((1*$15)|0)+15)&-16)|0;;
 $17 = $16;
 $18 = (($17) + 15)|0;
 $19 = $18 & -16;
 $20 = (($1) + ($4)|0);
 $21 = Math_fround(-$5);
 $22 = Math_fround(-$9);
 $23 = $19;
 $24 = HEAP32[$map0>>2]|0;
 $25 = (($24) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($polyData0) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_viiiii[$26 & 255]($map0,$20,$13,$28,$23);
 $29 = (($triangle) + 96|0);
 ;HEAP32[$points1In0+0>>2]=HEAP32[$29+0>>2]|0;HEAP32[$points1In0+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$points1In0+8>>2]=HEAP32[$29+8>>2]|0;HEAP32[$points1In0+12>>2]=HEAP32[$29+12>>2]|0;
 $30 = (($points1In0) + 16|0);
 $31 = (($triangle) + 112|0);
 ;HEAP32[$30+0>>2]=HEAP32[$31+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$31+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$31+12>>2]|0;
 $32 = (($points1In0) + 32|0);
 $33 = (($triangle) + 128|0);
 ;HEAP32[$32+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$33+12>>2]|0;
 $34 = $19;
 $35 = $19;
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($34) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($34) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = HEAP8[$11>>0]|0;
 $42 = ($41<<24>>24)==(0);
 $$pre1202 = (($rot) + 16|0);
 $$pre1204 = (($rot) + 32|0);
 $$pre1206 = (($rot) + 4|0);
 $$pre1208 = (($rot) + 20|0);
 $$pre1210 = (($rot) + 36|0);
 $$pre1212 = (($rot) + 8|0);
 $$pre1214 = (($rot) + 24|0);
 $$pre1216 = (($rot) + 40|0);
 if ($42) {
  $$$i2541130$lcssa = Math_fround(-3.40282346638528859812E+38);$$$i2601132$lcssa = Math_fround(3.40282346638528859812E+38);$$lcssa1164 = Math_fround(3.40282346638528859812E+38);$$lcssa1165 = Math_fround(-3.40282346638528859812E+38);$88 = $40;
 } else {
  $$$i25411301169 = Math_fround(-3.40282346638528859812E+38);$$$i26011321167 = Math_fround(3.40282346638528859812E+38);$76 = Math_fround(3.40282346638528859812E+38);$80 = Math_fround(-3.40282346638528859812E+38);$i$01170 = 0;
  while(1) {
   $43 = (($23) + ($i$01170<<4)|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = ((($23) + ($i$01170<<4)|0) + 4|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = ((($23) + ($i$01170<<4)|0) + 8|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = ((($23) + ($i$01170<<4)|0) + 12|0);
   $50 = Math_fround(HEAPF32[$rot>>2]);
   $51 = Math_fround($44 * $50);
   $52 = Math_fround(HEAPF32[$$pre1202>>2]);
   $53 = Math_fround($46 * $52);
   $54 = Math_fround($51 + $53);
   $55 = Math_fround(HEAPF32[$$pre1204>>2]);
   $56 = Math_fround($48 * $55);
   $57 = Math_fround($54 + $56);
   $58 = Math_fround(HEAPF32[$$pre1206>>2]);
   $59 = Math_fround($44 * $58);
   $60 = Math_fround(HEAPF32[$$pre1208>>2]);
   $61 = Math_fround($46 * $60);
   $62 = Math_fround($59 + $61);
   $63 = Math_fround(HEAPF32[$$pre1210>>2]);
   $64 = Math_fround($48 * $63);
   $65 = Math_fround($62 + $64);
   $66 = Math_fround(HEAPF32[$$pre1212>>2]);
   $67 = Math_fround($44 * $66);
   $68 = Math_fround(HEAPF32[$$pre1214>>2]);
   $69 = Math_fround($46 * $68);
   $70 = Math_fround($67 + $69);
   $71 = Math_fround(HEAPF32[$$pre1216>>2]);
   $72 = Math_fround($48 * $71);
   $73 = Math_fround($70 + $72);
   HEAPF32[$43>>2] = $57;
   HEAPF32[$45>>2] = $65;
   HEAPF32[$47>>2] = $73;
   HEAPF32[$49>>2] = Math_fround(0.0);
   $74 = $$$i26011321167 < $57;
   $$$i260 = $74 ? $$$i26011321167 : $57;
   $75 = $76 < $65;
   $77 = $75 ? $76 : $65;
   $78 = $$$i25411301169 > $57;
   $$$i254 = $78 ? $$$i25411301169 : $57;
   $79 = $80 > $65;
   $81 = $79 ? $80 : $65;
   $82 = (($i$01170) + 1)|0;
   $83 = HEAP8[$11>>0]|0;
   $84 = $83&255;
   $85 = ($82>>>0)<($84>>>0);
   if ($85) {
    $$$i25411301169 = $$$i254;$$$i26011321167 = $$$i260;$76 = $77;$80 = $81;$i$01170 = $82;
   } else {
    break;
   }
  }
  $phitmp = Math_fround($$$i260 + Math_fround(-1.1920928955078125E-7));
  $phitmp1178 = Math_fround($77 + Math_fround(-1.1920928955078125E-7));
  $phitmp1179 = Math_fround($$$i254 + Math_fround(1.1920928955078125E-7));
  $phitmp1180 = Math_fround($81 + Math_fround(1.1920928955078125E-7));
  $$pre = Math_fround(HEAPF32[$39>>2]);
  $$$i2541130$lcssa = $phitmp1179;$$$i2601132$lcssa = $phitmp;$$lcssa1164 = $phitmp1178;$$lcssa1165 = $phitmp1180;$88 = $$pre;
 }
 $86 = Math_fround(HEAPF32[$contactDist>>2]);
 $87 = Math_fround($88 + $86);
 $$pre1187 = Math_fround(HEAPF32[$rot>>2]);
 $$pre1188 = Math_fround(HEAPF32[$$pre1202>>2]);
 $$pre1189 = Math_fround(HEAPF32[$$pre1204>>2]);
 $$pre1190 = Math_fround(HEAPF32[$$pre1206>>2]);
 $$pre1191 = Math_fround(HEAPF32[$$pre1208>>2]);
 $$pre1192 = Math_fround(HEAPF32[$$pre1210>>2]);
 $$pre1193 = Math_fround(HEAPF32[$$pre1212>>2]);
 $$pre1194 = Math_fround(HEAPF32[$$pre1214>>2]);
 $$pre1195 = Math_fround(HEAPF32[$$pre1216>>2]);
 $$$i21611261161 = Math_fround(-3.40282346638528859812E+38);$$$i22211281159 = Math_fround(3.40282346638528859812E+38);$117 = Math_fround(3.40282346638528859812E+38);$121 = Math_fround(-3.40282346638528859812E+38);$i1$01163 = 0;$inside$01162 = 0;
 while(1) {
  $89 = (($points1In0) + ($i1$01163<<4)|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = ((($points1In0) + ($i1$01163<<4)|0) + 4|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = ((($points1In0) + ($i1$01163<<4)|0) + 8|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = ((($points1In0) + ($i1$01163<<4)|0) + 12|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = Math_fround($90 * $$pre1187);
  $98 = Math_fround($92 * $$pre1188);
  $99 = Math_fround($97 + $98);
  $100 = Math_fround($94 * $$pre1189);
  $101 = Math_fround($99 + $100);
  $102 = Math_fround($90 * $$pre1190);
  $103 = Math_fround($92 * $$pre1191);
  $104 = Math_fround($102 + $103);
  $105 = Math_fround($94 * $$pre1192);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($90 * $$pre1193);
  $108 = Math_fround($92 * $$pre1194);
  $109 = Math_fround($107 + $108);
  $110 = Math_fround($94 * $$pre1195);
  $111 = Math_fround($109 + $110);
  $112 = Math_fround($111 - $88);
  $113 = (($points1In0TValue) + ($i1$01163<<4)|0);
  HEAPF32[$113>>2] = $112;
  $114 = ((($points1In0TValue) + ($i1$01163<<4)|0) + 4|0);
  ;HEAP32[$114+0>>2]=HEAP32[$$sroa$1541+0>>2]|0;HEAP32[$114+4>>2]=HEAP32[$$sroa$1541+4>>2]|0;HEAP32[$114+8>>2]=HEAP32[$$sroa$1541+8>>2]|0;
  HEAPF32[$89>>2] = $101;
  HEAPF32[$91>>2] = $106;
  HEAPF32[$93>>2] = $88;
  HEAPF32[$95>>2] = Math_fround(0.0);
  $115 = $$$i22211281159 < $101;
  $$$i222 = $115 ? $$$i22211281159 : $101;
  $116 = $117 < $106;
  $118 = $116 ? $117 : $106;
  $119 = $$$i21611261161 > $101;
  $$$i216 = $119 ? $$$i21611261161 : $101;
  $120 = $121 > $106;
  $122 = $120 ? $121 : $106;
  $123 = $87 > $111;
  L8: do {
   if ($123) {
    $124 = (($points1In0Penetration) + ($i1$01163)|0);
    HEAP8[$124>>0] = 1;
    $125 = HEAP8[$11>>0]|0;
    $126 = $125&255;
    $127 = $101 > $$$i2541130$lcssa;
    $not$$i197 = $$$i2601132$lcssa > $101;
    $$demorgan$i198 = $127 | $not$$i197;
    if ($$demorgan$i198) {
     $inside$1 = $inside$01162;
    } else {
     $128 = $106 > $$lcssa1165;
     $not$304$i199 = $$lcssa1164 > $106;
     $129 = $128 | $not$304$i199;
     $130 = ($125<<24>>24)==(0);
     $or$cond = $129 | $130;
     if ($or$cond) {
      $inside$1 = $inside$01162;
     } else {
      $131 = (($126) + -1)|0;
      $$phi$trans$insert$i202 = ((($23) + ($131<<4)|0) + 4|0);
      $$pre$i203 = Math_fround(HEAPF32[$$phi$trans$insert$i202>>2]);
      $135 = $$pre$i203;$i$0308$i206 = 0;$intersectionPoints$0310$i204 = 0;$j$0309$i205 = $131;
      while(1) {
       $132 = ((($23) + ($i$0308$i206<<4)|0) + 4|0);
       $133 = Math_fround(HEAPF32[$132>>2]);
       $134 = $135 > $106;
       $136 = $133 > $106;
       $tmp$i207 = $134 ^ $136;
       if ($tmp$i207) {
        $137 = (($23) + ($i$0308$i206<<4)|0);
        $138 = (($23) + ($j$0309$i205<<4)|0);
        $139 = Math_fround(HEAPF32[$138>>2]);
        $140 = Math_fround(HEAPF32[$137>>2]);
        $141 = Math_fround($140 - $139);
        $142 = Math_fround($133 - $135);
        $143 = Math_fround($106 - $135);
        $144 = Math_fround($143 * $141);
        $145 = Math_fround($142 * $139);
        $146 = Math_fround($101 * $142);
        $147 = Math_fround($145 + $144);
        $148 = !($142 > Math_fround(0.0));
        $149 = $148 ? $146 : $147;
        $150 = $148 ? $147 : $146;
        $151 = !($149 >= $150);
        if ($151) {
         $intersectionPoints$1$i208 = $intersectionPoints$0310$i204;
        } else {
         $152 = ($intersectionPoints$0310$i204|0)==(1);
         if ($152) {
          $inside$1 = $inside$01162;
          break L8;
         }
         $153 = (($intersectionPoints$0310$i204) + 1)|0;
         $intersectionPoints$1$i208 = $153;
        }
       } else {
        $intersectionPoints$1$i208 = $intersectionPoints$0310$i204;
       }
       $154 = (($i$0308$i206) + 1)|0;
       $155 = ($154>>>0)<($126>>>0);
       if ($155) {
        $j$0309$i205$phi = $i$0308$i206;$135 = $133;$i$0308$i206 = $154;$intersectionPoints$0310$i204 = $intersectionPoints$1$i208;$j$0309$i205 = $j$0309$i205$phi;
       } else {
        break;
       }
      }
      $156 = ($intersectionPoints$1$i208|0)==(0);
      if ($156) {
       $inside$1 = $inside$01162;
      } else {
       $157 = (($inside$01162) + 1)|0;
       $158 = Math_fround(HEAPF32[$contactNormal>>2]);
       $159 = Math_fround(HEAPF32[$6>>2]);
       $160 = Math_fround(HEAPF32[$8>>2]);
       $161 = Math_fround($90 - $36);
       $162 = Math_fround($92 - $38);
       $163 = Math_fround($94 - $40);
       $164 = Math_fround($161 * $158);
       $165 = Math_fround($162 * $159);
       $166 = Math_fround($164 + $165);
       $167 = Math_fround($163 * $160);
       $168 = Math_fround($166 + $167);
       $169 = Math_fround($158 * $168);
       $170 = Math_fround($159 * $168);
       $171 = Math_fround($160 * $168);
       $172 = Math_fround($90 - $169);
       $173 = Math_fround($92 - $170);
       $174 = Math_fround($94 - $171);
       $175 = HEAP32[$numContacts>>2]|0;
       $176 = (($manifoldContacts) + ($175<<6)|0);
       HEAPF32[$176>>2] = $172;
       $177 = ((($manifoldContacts) + ($175<<6)|0) + 4|0);
       HEAPF32[$177>>2] = $173;
       $178 = ((($manifoldContacts) + ($175<<6)|0) + 8|0);
       HEAPF32[$178>>2] = $174;
       $179 = ((($manifoldContacts) + ($175<<6)|0) + 12|0);
       HEAPF32[$179>>2] = Math_fround(0.0);
       $180 = HEAP32[$numContacts>>2]|0;
       $181 = ((($manifoldContacts) + ($180<<6)|0) + 16|0);
       HEAPF32[$181>>2] = $90;
       $182 = ((($manifoldContacts) + ($180<<6)|0) + 20|0);
       HEAPF32[$182>>2] = $92;
       $183 = ((($manifoldContacts) + ($180<<6)|0) + 24|0);
       HEAPF32[$183>>2] = $94;
       $184 = ((($manifoldContacts) + ($180<<6)|0) + 28|0);
       HEAPF32[$184>>2] = $96;
       $185 = HEAP32[$numContacts>>2]|0;
       $186 = ((($manifoldContacts) + ($185<<6)|0) + 32|0);
       HEAPF32[$186>>2] = $21;
       $187 = ((($manifoldContacts) + ($185<<6)|0) + 36|0);
       HEAPF32[$187>>2] = $10;
       $188 = ((($manifoldContacts) + ($185<<6)|0) + 40|0);
       HEAPF32[$188>>2] = $22;
       $189 = ((($manifoldContacts) + ($185<<6)|0) + 44|0);
       HEAPF32[$189>>2] = $168;
       $190 = HEAP32[$numContacts>>2]|0;
       $191 = (($190) + 1)|0;
       HEAP32[$numContacts>>2] = $191;
       $192 = ((($manifoldContacts) + ($190<<6)|0) + 48|0);
       HEAP32[$192>>2] = $triangleIndex;
       $inside$1 = $157;
      }
     }
    }
   } else {
    $inside$1 = $inside$01162;
   }
  } while(0);
  $193 = (($i1$01163) + 1)|0;
  $exitcond1184 = ($193|0)==(3);
  if ($exitcond1184) {
   break;
  } else {
   $$$i21611261161 = $$$i216;$$$i22211281159 = $$$i222;$117 = $118;$121 = $122;$i1$01163 = $193;$inside$01162 = $inside$1;
  }
 }
 $194 = ($inside$1|0)==(3);
 if ($194) {
  STACKTOP = sp;return;
 }
 $195 = Math_fround($$$i222 + Math_fround(-1.1920928955078125E-7));
 $196 = Math_fround($118 + Math_fround(-1.1920928955078125E-7));
 $197 = Math_fround($$$i216 + Math_fround(1.1920928955078125E-7));
 $198 = Math_fround($122 + Math_fround(1.1920928955078125E-7));
 $199 = (($triangle) + 112|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = (($triangle) + 116|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($triangle) + 120|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = (($triangle) + 96|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = (($triangle) + 100|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($triangle) + 104|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = Math_fround($200 - $206);
 $212 = Math_fround($202 - $208);
 $213 = Math_fround($204 - $210);
 $214 = (($triangle) + 128|0);
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = (($triangle) + 132|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = (($triangle) + 136|0);
 $219 = Math_fround(HEAPF32[$218>>2]);
 $220 = Math_fround($215 - $206);
 $221 = Math_fround($217 - $208);
 $222 = Math_fround($219 - $210);
 $223 = Math_fround($212 * $222);
 $224 = Math_fround($213 * $221);
 $225 = Math_fround($223 - $224);
 $226 = Math_fround($213 * $220);
 $227 = Math_fround($211 * $222);
 $228 = Math_fround($226 - $227);
 $229 = Math_fround($211 * $221);
 $230 = Math_fround($212 * $220);
 $231 = Math_fround($229 - $230);
 $232 = Math_fround($225 * $225);
 $233 = Math_fround($228 * $228);
 $234 = Math_fround($232 + $233);
 $235 = Math_fround($231 * $231);
 $236 = Math_fround($235 + $234);
 $237 = (Math_fround(Math_sqrt((Math_fround($236)))));
 $238 = Math_fround(Math_fround(1.0) / $237);
 $239 = Math_fround($238 * $225);
 $240 = Math_fround($238 * $228);
 $241 = Math_fround($231 * $238);
 $242 = Math_fround($206 * $239);
 $243 = Math_fround($208 * $240);
 $244 = Math_fround($242 + $243);
 $245 = Math_fround($210 * $241);
 $246 = Math_fround($245 + $244);
 $247 = HEAP8[$11>>0]|0;
 $248 = ($247<<24>>24)==(0);
 if ($248) {
  STACKTOP = sp;return;
 }
 $$phi$trans$insert$i = (($points1In0) + 36|0);
 $543 = $247;$i2$01154 = 0;
 while(1) {
  $249 = (($23) + ($i2$01154<<4)|0);
  $250 = Math_fround(HEAPF32[$249>>2]);
  $251 = ((($23) + ($i2$01154<<4)|0) + 4|0);
  $252 = Math_fround(HEAPF32[$251>>2]);
  $253 = $250 > $197;
  $not$$i = $195 > $250;
  $$demorgan$i = $253 | $not$$i;
  L31: do {
   if ($$demorgan$i) {
    $402 = $543;
   } else {
    $254 = $252 > $198;
    $not$304$i = $196 > $252;
    $255 = $254 | $not$304$i;
    if ($255) {
     $402 = $543;
    } else {
     $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
     $259 = $$pre$i;$i$0308$i = 0;$intersectionPoints$0310$i = 0;$j$0309$i = 2;
     while(1) {
      $256 = ((($points1In0) + ($i$0308$i<<4)|0) + 4|0);
      $257 = Math_fround(HEAPF32[$256>>2]);
      $258 = $259 > $252;
      $260 = $257 > $252;
      $tmp$i = $258 ^ $260;
      if ($tmp$i) {
       $261 = (($points1In0) + ($i$0308$i<<4)|0);
       $262 = (($points1In0) + ($j$0309$i<<4)|0);
       $263 = Math_fround(HEAPF32[$262>>2]);
       $264 = Math_fround(HEAPF32[$261>>2]);
       $265 = Math_fround($264 - $263);
       $266 = Math_fround($257 - $259);
       $267 = Math_fround($252 - $259);
       $268 = Math_fround($267 * $265);
       $269 = Math_fround($266 * $263);
       $270 = Math_fround($250 * $266);
       $271 = Math_fround($269 + $268);
       $272 = !($266 > Math_fround(0.0));
       $273 = $272 ? $270 : $271;
       $274 = $272 ? $271 : $270;
       $275 = !($273 >= $274);
       if ($275) {
        $intersectionPoints$1$i = $intersectionPoints$0310$i;
       } else {
        $276 = ($intersectionPoints$0310$i|0)==(1);
        if ($276) {
         $402 = $543;
         break L31;
        }
        $277 = (($intersectionPoints$0310$i) + 1)|0;
        $intersectionPoints$1$i = $277;
       }
      } else {
       $intersectionPoints$1$i = $intersectionPoints$0310$i;
      }
      $278 = (($i$0308$i) + 1)|0;
      $279 = ($278>>>0)<(3);
      if ($279) {
       $j$0309$i$phi = $i$0308$i;$259 = $257;$i$0308$i = $278;$intersectionPoints$0310$i = $intersectionPoints$1$i;$j$0309$i = $j$0309$i$phi;
      } else {
       break;
      }
     }
     $280 = ($intersectionPoints$1$i|0)==(0);
     if ($280) {
      $402 = $543;
     } else {
      $281 = ((($23) + ($i2$01154<<4)|0) + 8|0);
      $282 = Math_fround(HEAPF32[$281>>2]);
      $283 = Math_fround($250 * $$pre1187);
      $284 = Math_fround($252 * $$pre1190);
      $285 = Math_fround($283 + $284);
      $286 = Math_fround($282 * $$pre1193);
      $287 = Math_fround($285 + $286);
      $288 = Math_fround($250 * $$pre1188);
      $289 = Math_fround($252 * $$pre1191);
      $290 = Math_fround($288 + $289);
      $291 = Math_fround($282 * $$pre1194);
      $292 = Math_fround($290 + $291);
      $293 = Math_fround($250 * $$pre1189);
      $294 = Math_fround($252 * $$pre1192);
      $295 = Math_fround($293 + $294);
      $296 = Math_fround($282 * $$pre1195);
      $297 = Math_fround($295 + $296);
      $298 = Math_fround($239 * $287);
      $299 = Math_fround($240 * $292);
      $300 = Math_fround($298 + $299);
      $301 = Math_fround($241 * $297);
      $302 = Math_fround($300 + $301);
      $303 = Math_fround($302 - $246);
      $304 = Math_fround(HEAPF32[$contactDist>>2]);
      $305 = $303 > $304;
      if ($305) {
       $402 = $543;
      } else {
       $306 = Math_fround($239 * $303);
       $307 = Math_fround($240 * $303);
       $308 = Math_fround($241 * $303);
       $309 = Math_fround($287 - $306);
       $310 = Math_fround($292 - $307);
       $311 = Math_fround($297 - $308);
       $312 = Math_fround(HEAPF32[$31>>2]);
       $313 = Math_fround(HEAPF32[$201>>2]);
       $314 = Math_fround(HEAPF32[$203>>2]);
       $315 = Math_fround(HEAPF32[$29>>2]);
       $316 = Math_fround(HEAPF32[$207>>2]);
       $317 = Math_fround(HEAPF32[$209>>2]);
       $318 = Math_fround($312 - $315);
       $319 = Math_fround($313 - $316);
       $320 = Math_fround($314 - $317);
       $321 = Math_fround(HEAPF32[$33>>2]);
       $322 = Math_fround(HEAPF32[$216>>2]);
       $323 = Math_fround(HEAPF32[$218>>2]);
       $324 = Math_fround($321 - $315);
       $325 = Math_fround($322 - $316);
       $326 = Math_fround($323 - $317);
       $327 = Math_fround($309 - $315);
       $328 = Math_fround($310 - $316);
       $329 = Math_fround($311 - $317);
       $330 = Math_fround($318 * $318);
       $331 = Math_fround($319 * $319);
       $332 = Math_fround($330 + $331);
       $333 = Math_fround($320 * $320);
       $334 = Math_fround($332 + $333);
       $335 = Math_fround($318 * $324);
       $336 = Math_fround($319 * $325);
       $337 = Math_fround($335 + $336);
       $338 = Math_fround($320 * $326);
       $339 = Math_fround($337 + $338);
       $340 = Math_fround($324 * $324);
       $341 = Math_fround($325 * $325);
       $342 = Math_fround($340 + $341);
       $343 = Math_fround($326 * $326);
       $344 = Math_fround($342 + $343);
       $345 = Math_fround($318 * $327);
       $346 = Math_fround($319 * $328);
       $347 = Math_fround($345 + $346);
       $348 = Math_fround($320 * $329);
       $349 = Math_fround($347 + $348);
       $350 = Math_fround($327 * $324);
       $351 = Math_fround($328 * $325);
       $352 = Math_fround($350 + $351);
       $353 = Math_fround($329 * $326);
       $354 = Math_fround($352 + $353);
       $355 = Math_fround($334 * $344);
       $356 = Math_fround($339 * $339);
       $357 = Math_fround($349 * $344);
       $358 = Math_fround($339 * $354);
       $359 = Math_fround($334 * $354);
       $360 = Math_fround($349 * $339);
       $361 = Math_fround($355 - $356);
       $362 = Math_fround(Math_fround(1.0) / $361);
       $363 = Math_fround($357 - $358);
       $364 = Math_fround($362 * $363);
       $365 = Math_fround($359 - $360);
       $366 = Math_fround($362 * $365);
       $367 = !($364 >= Math_fround(0.0));
       $368 = !($366 >= Math_fround(0.0));
       if ($368) {
        $370 = 1;
       } else {
        $369 = Math_fround($364 + $366);
        $phitmp1218 = !($369 <= Math_fround(1.0));
        $370 = $phitmp1218;
       }
       $brmerge = $367 | $370;
       if ($brmerge) {
        $402 = $543;
       } else {
        $371 = Math_fround($309 - $287);
        $372 = Math_fround($310 - $292);
        $373 = Math_fround($311 - $297);
        $374 = Math_fround(HEAPF32[$contactNormal>>2]);
        $375 = Math_fround(HEAPF32[$6>>2]);
        $376 = Math_fround(HEAPF32[$8>>2]);
        $377 = Math_fround($371 * $374);
        $378 = Math_fround($372 * $375);
        $379 = Math_fround($377 + $378);
        $380 = Math_fround($373 * $376);
        $381 = Math_fround($379 + $380);
        $382 = HEAP32[$numContacts>>2]|0;
        $383 = (($manifoldContacts) + ($382<<6)|0);
        HEAPF32[$383>>2] = $287;
        $384 = ((($manifoldContacts) + ($382<<6)|0) + 4|0);
        HEAPF32[$384>>2] = $292;
        $385 = ((($manifoldContacts) + ($382<<6)|0) + 8|0);
        HEAPF32[$385>>2] = $297;
        $386 = ((($manifoldContacts) + ($382<<6)|0) + 12|0);
        HEAPF32[$386>>2] = Math_fround(0.0);
        $387 = HEAP32[$numContacts>>2]|0;
        $388 = ((($manifoldContacts) + ($387<<6)|0) + 16|0);
        HEAPF32[$388>>2] = $309;
        $389 = ((($manifoldContacts) + ($387<<6)|0) + 20|0);
        HEAPF32[$389>>2] = $310;
        $390 = ((($manifoldContacts) + ($387<<6)|0) + 24|0);
        HEAPF32[$390>>2] = $311;
        $391 = ((($manifoldContacts) + ($387<<6)|0) + 28|0);
        HEAPF32[$391>>2] = Math_fround(0.0);
        $392 = HEAP32[$numContacts>>2]|0;
        $393 = ((($manifoldContacts) + ($392<<6)|0) + 32|0);
        HEAPF32[$393>>2] = $21;
        $394 = ((($manifoldContacts) + ($392<<6)|0) + 36|0);
        HEAPF32[$394>>2] = $10;
        $395 = ((($manifoldContacts) + ($392<<6)|0) + 40|0);
        HEAPF32[$395>>2] = $22;
        $396 = ((($manifoldContacts) + ($392<<6)|0) + 44|0);
        HEAPF32[$396>>2] = $381;
        $397 = HEAP32[$numContacts>>2]|0;
        $398 = (($397) + 1)|0;
        HEAP32[$numContacts>>2] = $398;
        $399 = ((($manifoldContacts) + ($397<<6)|0) + 48|0);
        HEAP32[$399>>2] = $triangleIndex;
        $$pre1197 = HEAP8[$11>>0]|0;
        $402 = $$pre1197;
       }
      }
     }
    }
   }
  } while(0);
  $400 = (($i2$01154) + 1)|0;
  $401 = $402&255;
  $403 = ($400>>>0)<($401>>>0);
  if ($403) {
   $543 = $402;$i2$01154 = $400;
  } else {
   break;
  }
 }
 $404 = ($402<<24>>24)==(0);
 if ($404) {
  STACKTOP = sp;return;
 } else {
  $426 = $402;$544 = $402;$iEnd$01153 = 2;$iStart$01151 = 0;
 }
 while(1) {
  $405 = (($points1In0Penetration) + ($iStart$01151)|0);
  $406 = HEAP8[$405>>0]|0;
  $407 = ($406<<24>>24)==(0);
  if ($407) {
   $408 = (($points1In0Penetration) + ($iEnd$01153)|0);
   $409 = HEAP8[$408>>0]|0;
   $410 = ($409<<24>>24)==(0);
   if ($410) {
    $545 = $544;$546 = $426;
   } else {
    label = 38;
   }
  } else {
   label = 38;
  }
  if ((label|0) == 38) {
   label = 0;
   $411 = (($points1In0) + ($iStart$01151<<4)|0);
   $412 = Math_fround(HEAPF32[$411>>2]);
   $413 = ((($points1In0) + ($iStart$01151<<4)|0) + 4|0);
   $414 = Math_fround(HEAPF32[$413>>2]);
   $415 = (($points1In0) + ($iEnd$01153<<4)|0);
   $416 = Math_fround(HEAPF32[$415>>2]);
   $417 = ((($points1In0) + ($iEnd$01153<<4)|0) + 4|0);
   $418 = Math_fround(HEAPF32[$417>>2]);
   $419 = $412 < $416;
   $$$i107 = $419 ? $412 : $416;
   $420 = $414 < $418;
   $421 = $420 ? $414 : $418;
   $422 = $412 > $416;
   $$$i101 = $422 ? $412 : $416;
   $423 = $414 > $418;
   $424 = $423 ? $414 : $418;
   $425 = ($426<<24>>24)==(0);
   if ($425) {
    $545 = $544;$546 = 0;
   } else {
    $427 = $426&255;
    $428 = (($427) + -1)|0;
    $429 = (($points1In0TValue) + ($iStart$01151<<4)|0);
    $430 = (($points1In0TValue) + ($iEnd$01153<<4)|0);
    $547 = $544;$rEnd$01149 = $428;$rStart$01148 = 0;
    while(1) {
     $431 = (($23) + ($rStart$01148<<4)|0);
     $432 = Math_fround(HEAPF32[$431>>2]);
     $433 = ((($23) + ($rStart$01148<<4)|0) + 4|0);
     $434 = Math_fround(HEAPF32[$433>>2]);
     $435 = (($23) + ($rEnd$01149<<4)|0);
     $436 = Math_fround(HEAPF32[$435>>2]);
     $437 = ((($23) + ($rEnd$01149<<4)|0) + 4|0);
     $438 = Math_fround(HEAPF32[$437>>2]);
     $439 = $432 < $436;
     $$$i95 = $439 ? $432 : $436;
     $440 = $432 > $436;
     $$$i = $440 ? $432 : $436;
     $441 = $$$i95 > $$$i101;
     $not$ = $$$i107 > $$$i;
     $$demorgan = $441 | $not$;
     if ($$demorgan) {
      $540 = $547;
     } else {
      $442 = $434 < $438;
      $443 = $434 > $438;
      $444 = $442 ? $434 : $438;
      $445 = $443 ? $434 : $438;
      $446 = $444 > $424;
      $not$1147 = $421 > $445;
      $447 = $446 | $not$1147;
      if ($447) {
       $540 = $547;
      } else {
       $448 = Math_fround($432 - $412);
       $449 = Math_fround($434 - $414);
       $450 = Math_fround($436 - $412);
       $451 = Math_fround($438 - $414);
       $452 = Math_fround($448 * $451);
       $453 = Math_fround($449 * $450);
       $454 = Math_fround($452 - $453);
       $455 = Math_fround($432 - $416);
       $456 = Math_fround($434 - $418);
       $457 = Math_fround($436 - $416);
       $458 = Math_fround($438 - $418);
       $459 = Math_fround($455 * $458);
       $460 = Math_fround($456 * $457);
       $461 = Math_fround($459 - $460);
       $462 = Math_fround($454 * $461);
       $463 = $462 < Math_fround(0.0);
       if ($463) {
        $464 = Math_fround($412 - $432);
        $465 = Math_fround($414 - $434);
        $466 = Math_fround($416 - $432);
        $467 = Math_fround($418 - $434);
        $468 = Math_fround($464 * $467);
        $469 = Math_fround($466 * $465);
        $470 = Math_fround($468 - $469);
        $471 = Math_fround($412 - $436);
        $472 = Math_fround($414 - $438);
        $473 = Math_fround($416 - $436);
        $474 = Math_fround($418 - $438);
        $475 = Math_fround($471 * $474);
        $476 = Math_fround($473 * $472);
        $477 = Math_fround($475 - $476);
        $478 = Math_fround($470 * $477);
        $479 = $478 < Math_fround(0.0);
        if ($479) {
         $480 = Math_fround($461 - $454);
         $481 = Math_fround(Math_fround(1.0) / $480);
         $482 = Math_fround($454 * $481);
         $483 = Math_fround(HEAPF32[$429>>2]);
         $484 = Math_fround($88 + $483);
         $485 = Math_fround(HEAPF32[$430>>2]);
         $486 = Math_fround($88 + $485);
         $487 = Math_fround($416 - $412);
         $488 = Math_fround($418 - $414);
         $489 = Math_fround($486 - $484);
         $490 = Math_fround($482 * $487);
         $491 = Math_fround($482 * $488);
         $492 = Math_fround($482 * $489);
         $493 = Math_fround($412 - $490);
         $494 = Math_fround($414 - $491);
         $495 = Math_fround($484 - $492);
         $496 = Math_fround($$pre1187 * $493);
         $497 = Math_fround($$pre1190 * $494);
         $498 = Math_fround($496 + $497);
         $499 = Math_fround($493 * $$pre1188);
         $500 = Math_fround($494 * $$pre1191);
         $501 = Math_fround($499 + $500);
         $502 = Math_fround($493 * $$pre1189);
         $503 = Math_fround($494 * $$pre1192);
         $504 = Math_fround($502 + $503);
         $505 = Math_fround($495 - $88);
         $506 = Math_fround(HEAPF32[$contactDist>>2]);
         $507 = $505 > $506;
         if ($507) {
          $540 = $547;
         } else {
          $508 = Math_fround($495 * $$pre1195);
          $509 = Math_fround($495 * $$pre1194);
          $510 = Math_fround($$pre1193 * $495);
          $511 = Math_fround($88 * $$pre1195);
          $512 = Math_fround($88 * $$pre1194);
          $513 = Math_fround($88 * $$pre1193);
          $514 = Math_fround($504 + $508);
          $515 = Math_fround($501 + $509);
          $516 = Math_fround($498 + $510);
          $517 = Math_fround($504 + $511);
          $518 = Math_fround($501 + $512);
          $519 = Math_fround($498 + $513);
          $520 = HEAP32[$numContacts>>2]|0;
          $521 = (($manifoldContacts) + ($520<<6)|0);
          HEAPF32[$521>>2] = $519;
          $522 = ((($manifoldContacts) + ($520<<6)|0) + 4|0);
          HEAPF32[$522>>2] = $518;
          $523 = ((($manifoldContacts) + ($520<<6)|0) + 8|0);
          HEAPF32[$523>>2] = $517;
          $524 = ((($manifoldContacts) + ($520<<6)|0) + 12|0);
          HEAPF32[$524>>2] = Math_fround(0.0);
          $525 = HEAP32[$numContacts>>2]|0;
          $526 = ((($manifoldContacts) + ($525<<6)|0) + 16|0);
          HEAPF32[$526>>2] = $516;
          $527 = ((($manifoldContacts) + ($525<<6)|0) + 20|0);
          HEAPF32[$527>>2] = $515;
          $528 = ((($manifoldContacts) + ($525<<6)|0) + 24|0);
          HEAPF32[$528>>2] = $514;
          $529 = ((($manifoldContacts) + ($525<<6)|0) + 28|0);
          HEAPF32[$529>>2] = Math_fround(0.0);
          $530 = HEAP32[$numContacts>>2]|0;
          $531 = ((($manifoldContacts) + ($530<<6)|0) + 32|0);
          HEAPF32[$531>>2] = $21;
          $532 = ((($manifoldContacts) + ($530<<6)|0) + 36|0);
          HEAPF32[$532>>2] = $10;
          $533 = ((($manifoldContacts) + ($530<<6)|0) + 40|0);
          HEAPF32[$533>>2] = $22;
          $534 = ((($manifoldContacts) + ($530<<6)|0) + 44|0);
          HEAPF32[$534>>2] = $505;
          $535 = HEAP32[$numContacts>>2]|0;
          $536 = (($535) + 1)|0;
          HEAP32[$numContacts>>2] = $536;
          $537 = ((($manifoldContacts) + ($535<<6)|0) + 48|0);
          HEAP32[$537>>2] = $triangleIndex;
          $$pre1196 = HEAP8[$11>>0]|0;
          $540 = $$pre1196;
         }
        } else {
         $540 = $547;
        }
       } else {
        $540 = $547;
       }
      }
     }
     $538 = (($rStart$01148) + 1)|0;
     $539 = $540&255;
     $541 = ($538>>>0)<($539>>>0);
     if ($541) {
      $rEnd$01149$phi = $rStart$01148;$547 = $540;$rStart$01148 = $538;$rEnd$01149 = $rEnd$01149$phi;
     } else {
      $545 = $540;$546 = $540;
      break;
     }
    }
   }
  }
  $542 = (($iStart$01151) + 1)|0;
  $exitcond = ($542|0)==(3);
  if ($exitcond) {
   break;
  } else {
   $iEnd$01153$phi = $iStart$01151;$426 = $546;$544 = $545;$iStart$01151 = $542;$iEnd$01153 = $iEnd$01153$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu32PCMConvexVsMeshContactGeneration35generateTriangleFullContactManifoldERNS0_9TriangleVEjhRKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS2_EEPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERNSG_5Vec3VE($localTriangle,$triangleIndex,$triFlags,$polyData,$localTriMap,$polyMap,$manifoldContacts,$numContacts,$contactDist,$patchNormal) {
 $localTriangle = $localTriangle|0;
 $triangleIndex = $triangleIndex|0;
 $triFlags = $triFlags|0;
 $polyData = $polyData|0;
 $localTriMap = $localTriMap|0;
 $polyMap = $polyMap|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $patchNormal = $patchNormal|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $feature0 = 0, $feature1 = 0, $minNormal = 0, $minOverlap = 0, $n = 0, $status = 0, $triNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $status = sp + 72|0;
 $minOverlap = sp;
 $minNormal = sp + 16|0;
 $feature0 = sp + 68|0;
 $feature1 = sp + 64|0;
 $triNormal = sp + 32|0;
 $n = sp + 48|0;
 HEAP32[$status>>2] = 0;
 HEAPF32[$minOverlap>>2] = Math_fround(3.40282346638528859812E+38);
 ;HEAP32[$minNormal+0>>2]=0|0;HEAP32[$minNormal+4>>2]=0|0;HEAP32[$minNormal+8>>2]=0|0;HEAP32[$minNormal+12>>2]=0|0;
 $0 = (__ZN5physxL22testTriangleFaceNormalERKNS_2Gu9TriangleVERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSE_RjRNSD_5Vec3VENS0_13FeatureStatusERSL_($localTriangle,$polyMap,$contactDist,$minOverlap,$feature0,$minNormal,$status)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN5physxL18testPolyFaceNormalERKNS_2Gu9TriangleVERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSE_RjRNSD_5Vec3VENS0_13FeatureStatusERSL_($polyData,$localTriMap,$polyMap,$contactDist,$minOverlap,$feature1,$minNormal,$status)|0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__ZN5physxL18testPolyEdgeNormalERKNS_2Gu9TriangleVEhRKNS0_15HullPolygonDataERKNS0_13PolygonalDataEPNS0_16SupportLocalImplIS1_EEPNS0_12SupportLocalERKNS_6shdfnd3aos6FloatVERSH_RNSG_5Vec3VENS0_13FeatureStatusERSN_($localTriangle,$triFlags,$polyData,$localTriMap,$polyMap,$contactDist,$minOverlap,$minNormal,$status)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($polyData) + 24|0);
 $4 = (($localTriangle) + 112|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($localTriangle) + 116|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($localTriangle) + 120|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($localTriangle) + 96|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($localTriangle) + 100|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($localTriangle) + 104|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($5 - $11);
 $17 = Math_fround($7 - $13);
 $18 = Math_fround($9 - $15);
 $19 = (($localTriangle) + 128|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($localTriangle) + 132|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($localTriangle) + 136|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($20 - $11);
 $26 = Math_fround($22 - $13);
 $27 = Math_fround($24 - $15);
 $28 = Math_fround($17 * $27);
 $29 = Math_fround($18 * $26);
 $30 = Math_fround($28 - $29);
 $31 = Math_fround($18 * $25);
 $32 = Math_fround($16 * $27);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($16 * $26);
 $35 = Math_fround($17 * $25);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($30 * $30);
 $38 = Math_fround($33 * $33);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($36 * $36);
 $41 = Math_fround($40 + $39);
 $42 = (Math_fround(Math_sqrt((Math_fround($41)))));
 $43 = Math_fround(Math_fround(1.0) / $42);
 $44 = Math_fround($43 * $30);
 $45 = Math_fround($43 * $33);
 $46 = Math_fround($36 * $43);
 HEAPF32[$triNormal>>2] = $44;
 $47 = (($triNormal) + 4|0);
 HEAPF32[$47>>2] = $45;
 $48 = (($triNormal) + 8|0);
 HEAPF32[$48>>2] = $46;
 $49 = (($triNormal) + 12|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 ;HEAP32[$patchNormal+0>>2]=HEAP32[$triNormal+0>>2]|0;HEAP32[$patchNormal+4>>2]=HEAP32[$triNormal+4>>2]|0;HEAP32[$patchNormal+8>>2]=HEAP32[$triNormal+8>>2]|0;HEAP32[$patchNormal+12>>2]=HEAP32[$triNormal+12>>2]|0;
 $50 = (($polyMap) + 36|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($44 * $52);
 $54 = (($51) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($45 * $55);
 $57 = Math_fround($53 + $56);
 $58 = (($51) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($46 * $59);
 $61 = Math_fround($57 + $60);
 $62 = (($51) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($44 * $63);
 $65 = (($51) + 20|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($45 * $66);
 $68 = Math_fround($64 + $67);
 $69 = (($51) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($46 * $70);
 $72 = Math_fround($68 + $71);
 $73 = (($51) + 32|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($44 * $74);
 $76 = (($51) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($45 * $77);
 $79 = Math_fround($75 + $78);
 $80 = (($51) + 40|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($46 * $81);
 $83 = Math_fround($79 + $82);
 HEAPF32[$n>>2] = $61;
 $84 = (($n) + 4|0);
 HEAPF32[$84>>2] = $72;
 $85 = (($n) + 8|0);
 HEAPF32[$85>>2] = $83;
 $86 = (($n) + 12|0);
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = (__ZN5physx2Gu15getPolygonIndexERKNS0_13PolygonalDataEPNS0_12SupportLocalERKNS_6shdfnd3aos5Vec3VE($polyData,$polyMap,$n)|0);
 $88 = HEAP32[$3>>2]|0;
 $89 = (($88) + (($87*20)|0)|0);
 __ZN5physxL25generatedTriangleContactsERKNS_2Gu9TriangleVEjhRKNS0_13PolygonalDataERKNS0_15HullPolygonDataEPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERKNSG_5Vec3VE($localTriangle,$triangleIndex,$triFlags,$polyData,$89,$polyMap,$manifoldContacts,$numContacts,$contactDist,$triNormal);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu32PCMConvexVsMeshContactGeneration31generatePolyDataContactManifoldERNS0_9TriangleVEjjhPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERNS8_5Vec3VE($this,$localTriangle,$featureIndex,$triangleIndex,$triFlags,$manifoldContacts,$numContacts,$contactDist,$patchNormal) {
 $this = $this|0;
 $localTriangle = $localTriangle|0;
 $featureIndex = $featureIndex|0;
 $triangleIndex = $triangleIndex|0;
 $triFlags = $triFlags|0;
 $manifoldContacts = $manifoldContacts|0;
 $numContacts = $numContacts|0;
 $contactDist = $contactDist|0;
 $patchNormal = $patchNormal|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $contactNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $contactNormal = sp;
 $0 = (($this) + 3652|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + (($featureIndex*20)|0)|0);
 $5 = (($this) + 3656|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$4>>2]);
 $10 = ((($3) + (($featureIndex*20)|0)|0) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = ((($3) + (($featureIndex*20)|0)|0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[$8>>2]);
 $15 = Math_fround($9 * $14);
 $16 = (($8) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($11 * $17);
 $19 = Math_fround($15 + $18);
 $20 = (($8) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($13 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($8) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($9 * $25);
 $27 = (($8) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($11 * $28);
 $30 = Math_fround($26 + $29);
 $31 = (($8) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($13 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($8) + 32|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($9 * $36);
 $38 = (($8) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($11 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($8) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($13 * $43);
 $45 = Math_fround($41 + $44);
 $46 = Math_fround($23 * $23);
 $47 = Math_fround($34 * $34);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($45 * $45);
 $50 = Math_fround($48 + $49);
 $51 = (Math_fround(Math_sqrt((Math_fround($50)))));
 $52 = Math_fround(Math_fround(1.0) / $51);
 $53 = Math_fround($23 * $52);
 $54 = Math_fround($34 * $52);
 $55 = Math_fround($45 * $52);
 HEAPF32[$contactNormal>>2] = $53;
 $56 = (($contactNormal) + 4|0);
 HEAPF32[$56>>2] = $54;
 $57 = (($contactNormal) + 8|0);
 HEAPF32[$57>>2] = $55;
 $58 = (($contactNormal) + 12|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = Math_fround(-$53);
 $60 = Math_fround(-$54);
 $61 = Math_fround(-$55);
 HEAPF32[$patchNormal>>2] = $59;
 $62 = (($patchNormal) + 4|0);
 HEAPF32[$62>>2] = $60;
 $63 = (($patchNormal) + 8|0);
 HEAPF32[$63>>2] = $61;
 $64 = (($patchNormal) + 12|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = HEAP32[$0>>2]|0;
 $66 = HEAP32[$5>>2]|0;
 __ZN5physxL21generatedPolyContactsERKNS_2Gu13PolygonalDataERKNS0_15HullPolygonDataERKNS0_9TriangleVEjhPNS0_12SupportLocalEPNS0_21MeshPersistentContactERjRKNS_6shdfnd3aos6FloatVERKNSG_5Vec3VE($65,$4,$localTriangle,$triangleIndex,$triFlags,$66,$manifoldContacts,$numContacts,$contactDist,$contactNormal);
 STACKTOP = sp;return 1;
}
function __ZN5physx2Gu27findRotationMatrixFromZAxisERKNS_6shdfnd3aos5Vec3VE($agg$result,$to) {
 $agg$result = $agg$result|0;
 $to = $to|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $fabsf$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($to) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $fabsf$i$i$i = (Math_fround(Math_abs((Math_fround($1)))));
 $2 = $fabsf$i$i$i < Math_fround(0.999899983406066894531);
 if ($2) {
  $3 = (($to) + 4|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = Math_fround(-$4);
  $6 = Math_fround(HEAPF32[$to>>2]);
  $7 = Math_fround($1 + Math_fround(1.0));
  $8 = Math_fround(Math_fround(1.0) / $7);
  $9 = Math_fround($8 * $5);
  $10 = Math_fround($6 * $9);
  $11 = Math_fround($9 * $5);
  $12 = Math_fround($1 + $11);
  $13 = Math_fround($6 * $6);
  $14 = Math_fround($8 * $13);
  $15 = Math_fround($1 + $14);
  $16 = Math_fround(-$6);
  HEAPF32[$agg$result>>2] = $12;
  $17 = (($agg$result) + 4|0);
  HEAPF32[$17>>2] = $10;
  $18 = (($agg$result) + 8|0);
  HEAPF32[$18>>2] = $6;
  $19 = (($agg$result) + 12|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = (($agg$result) + 16|0);
  HEAPF32[$20>>2] = $10;
  $21 = (($agg$result) + 20|0);
  HEAPF32[$21>>2] = $15;
  $22 = (($agg$result) + 24|0);
  HEAPF32[$22>>2] = $4;
  $23 = (($agg$result) + 28|0);
  HEAPF32[$23>>2] = Math_fround(0.0);
  $24 = (($agg$result) + 32|0);
  HEAPF32[$24>>2] = $16;
  $25 = (($agg$result) + 36|0);
  HEAPF32[$25>>2] = $5;
  $26 = (($agg$result) + 40|0);
  HEAPF32[$26>>2] = $1;
  $27 = (($agg$result) + 44|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 } else {
  $28 = Math_fround(HEAPF32[$to>>2]);
  $29 = (($to) + 4|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround(Math_fround(0.0) - $28);
  $32 = Math_fround(Math_fround(1.0) - $30);
  $33 = Math_fround(Math_fround(0.0) - $1);
  $34 = Math_fround($31 * $31);
  $35 = Math_fround($32 * $32);
  $36 = Math_fround($34 + $35);
  $37 = Math_fround($33 * $33);
  $38 = Math_fround($36 + $37);
  $39 = Math_fround($31 * Math_fround(0.0));
  $40 = Math_fround($39 + $32);
  $41 = Math_fround($33 * Math_fround(-1.0));
  $42 = Math_fround($40 + $41);
  $43 = Math_fround(Math_fround(2.0) / $38);
  $44 = Math_fround(-$43);
  $45 = Math_fround($42 * $44);
  $46 = Math_fround($45 * Math_fround(-1.0));
  $47 = Math_fround($31 * $44);
  $48 = Math_fround($32 * $44);
  $49 = Math_fround($33 * $44);
  $50 = Math_fround($31 * $46);
  $51 = Math_fround($32 * $46);
  $52 = Math_fround($33 * $46);
  $53 = Math_fround($50 * Math_fround(0.0));
  $54 = Math_fround($50 * Math_fround(-1.0));
  $55 = Math_fround($31 * $47);
  $56 = Math_fround($32 * $47);
  $57 = Math_fround($33 * $47);
  $58 = Math_fround($55 + $53);
  $59 = Math_fround($56 + $50);
  $60 = Math_fround($57 + $54);
  $61 = Math_fround($60 + Math_fround(0.0));
  $62 = Math_fround($58 + Math_fround(1.0));
  $63 = Math_fround($51 * Math_fround(0.0));
  $64 = Math_fround($51 * Math_fround(-1.0));
  $65 = Math_fround($31 * $48);
  $66 = Math_fround($32 * $48);
  $67 = Math_fround($33 * $48);
  $68 = Math_fround($65 + $63);
  $69 = Math_fround($66 + $51);
  $70 = Math_fround($67 + $64);
  $71 = Math_fround($69 + Math_fround(-1.0));
  $72 = Math_fround($70 + Math_fround(1.0));
  $73 = Math_fround($71 + Math_fround(1.0));
  $74 = Math_fround($52 * Math_fround(0.0));
  $75 = Math_fround($52 * Math_fround(-1.0));
  $76 = Math_fround($31 * $49);
  $77 = Math_fround($32 * $49);
  $78 = Math_fround($33 * $49);
  $79 = Math_fround($76 + $74);
  $80 = Math_fround($77 + $52);
  $81 = Math_fround($78 + $75);
  $82 = Math_fround($79 + Math_fround(0.0));
  $83 = Math_fround($80 + Math_fround(1.0));
  $84 = Math_fround($81 + Math_fround(-1.0));
  $85 = Math_fround($84 + Math_fround(1.0));
  HEAPF32[$agg$result>>2] = $62;
  $86 = (($agg$result) + 4|0);
  HEAPF32[$86>>2] = $59;
  $87 = (($agg$result) + 8|0);
  HEAPF32[$87>>2] = $61;
  $88 = (($agg$result) + 12|0);
  HEAPF32[$88>>2] = Math_fround(0.0);
  $89 = (($agg$result) + 16|0);
  HEAPF32[$89>>2] = $68;
  $90 = (($agg$result) + 20|0);
  HEAPF32[$90>>2] = $73;
  $91 = (($agg$result) + 24|0);
  HEAPF32[$91>>2] = $72;
  $92 = (($agg$result) + 28|0);
  HEAPF32[$92>>2] = Math_fround(0.0);
  $93 = (($agg$result) + 32|0);
  HEAPF32[$93>>2] = $82;
  $94 = (($agg$result) + 36|0);
  HEAPF32[$94>>2] = $83;
  $95 = (($agg$result) + 40|0);
  HEAPF32[$95>>2] = $85;
  $96 = (($agg$result) + 44|0);
  HEAPF32[$96>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZN5physx2Gu25PersistentContactManifold20reduceContactsForPCMERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VE($this,$localPointA,$localPointB,$localNormalPen) {
 $this = $this|0;
 $localPointA = $localPointA|0;
 $localPointB = $localPointB|0;
 $localNormalPen = $localNormalPen|0;
 var $$$i$i$i = Math_fround(0), $$$i8$i$i = Math_fround(0), $$not$i = 0, $$not1389$i = 0, $$not1392$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0;
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0);
 var $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0;
 var $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0;
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0);
 var $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0);
 var $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0);
 var $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0;
 var $40 = Math_fround(0), $400 = Math_fround(0), $401 = 0, $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0);
 var $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = Math_fround(0), $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0);
 var $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0);
 var $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = 0, $465 = 0, $466 = Math_fround(0), $467 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a$0176 = 0, $brmerge$i = 0, $brmerge1391$i = 0, $brmerge1394$i = 0, $chosen = 0, $exitcond = 0, $exitcond187 = 0;
 var $i3$0181 = 0, $i4$0178 = 0, $index$1 = 0, $index$1$1 = 0, $index$1$2 = 0, $index$1$3 = 0, $index$3 = 0, $index$3$1 = 0, $index$3$2 = 0, $index$3$3 = 0, $index$4180 = 0, $index$5 = 0, $index$6177 = 0, $index$7 = 0, $index$9$1 = 0, $index$9$2 = 0, $index$9$3 = 0, $notChosenIndex$0 = 0, $or$cond$i = 0, $or$cond1379$i = 0;
 var $or$cond1381$i = 0, $phitmp$i = 0, $phitmp1395$i = 0, $phitmp1396$i = 0, $tempContacts = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $chosen = sp + 240|0;
 $tempContacts = sp;
 ;HEAP8[$chosen+0>>0]=0|0;HEAP8[$chosen+1>>0]=0|0;HEAP8[$chosen+2>>0]=0|0;HEAP8[$chosen+3>>0]=0|0;HEAP8[$chosen+4>>0]=0|0;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 dest=$tempContacts+0|0; src=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($tempContacts) + 48|0);
 $3 = (($1) + 48|0);
 dest=$2+0|0; src=$3+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = (($tempContacts) + 96|0);
 $5 = (($1) + 96|0);
 dest=$4+0|0; src=$5+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = (($tempContacts) + 144|0);
 $7 = (($1) + 144|0);
 dest=$6+0|0; src=$7+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $8 = (($tempContacts) + 192|0);
 ;HEAP32[$8+0>>2]=HEAP32[$localPointA+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$localPointA+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$localPointA+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$localPointA+12>>2]|0;
 $9 = (($tempContacts) + 208|0);
 ;HEAP32[$9+0>>2]=HEAP32[$localPointB+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$localPointB+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$localPointB+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$localPointB+12>>2]|0;
 $10 = (($tempContacts) + 224|0);
 ;HEAP32[$10+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
 $11 = (($localNormalPen) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($tempContacts) + 44|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = $12 > $14;
 $16 = $15 ? $14 : $12;
 $index$1 = $15 ? 0 : 4;
 $17 = (($tempContacts) + 92|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = $16 > $18;
 $20 = $19 ? $18 : $16;
 $index$1$1 = $19 ? 1 : $index$1;
 $21 = (($tempContacts) + 140|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = $20 > $22;
 $24 = $23 ? $22 : $20;
 $index$1$2 = $23 ? 2 : $index$1$1;
 $25 = (($tempContacts) + 188|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = $24 > $26;
 $index$1$3 = $27 ? 3 : $index$1$2;
 $28 = (($chosen) + ($index$1$3)|0);
 HEAP8[$28>>0] = 1;
 $29 = (($tempContacts) + (($index$1$3*48)|0)|0);
 dest=$1+0|0; src=$29+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $30 = (($tempContacts) + 16|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($tempContacts) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($tempContacts) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = HEAP32[$0>>2]|0;
 $37 = (($36) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($36) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($36) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($31 - $38);
 $44 = Math_fround($33 - $40);
 $45 = Math_fround($35 - $42);
 $46 = Math_fround($43 * $43);
 $47 = Math_fround($44 * $44);
 $48 = Math_fround($46 + $47);
 $49 = Math_fround($45 * $45);
 $50 = Math_fround($48 + $49);
 $51 = (($chosen) + 1|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = ($52<<24>>24)==(0);
 if ($53) {
  $54 = (($tempContacts) + 64|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($tempContacts) + 68|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($tempContacts) + 72|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($55 - $38);
  $61 = Math_fround($57 - $40);
  $62 = Math_fround($59 - $42);
  $63 = Math_fround($60 * $60);
  $64 = Math_fround($61 * $61);
  $65 = Math_fround($63 + $64);
  $66 = Math_fround($62 * $62);
  $67 = Math_fround($65 + $66);
  $68 = $67 > $50;
  if ($68) {
   $424 = $67;$index$3 = 1;
  } else {
   $424 = $50;$index$3 = 0;
  }
 } else {
  $424 = $50;$index$3 = 0;
 }
 $69 = (($chosen) + 2|0);
 $70 = HEAP8[$69>>0]|0;
 $71 = ($70<<24>>24)==(0);
 if ($71) {
  $409 = (($tempContacts) + 112|0);
  $410 = Math_fround(HEAPF32[$409>>2]);
  $411 = (($tempContacts) + 116|0);
  $412 = Math_fround(HEAPF32[$411>>2]);
  $413 = (($tempContacts) + 120|0);
  $414 = Math_fround(HEAPF32[$413>>2]);
  $415 = Math_fround($410 - $38);
  $416 = Math_fround($412 - $40);
  $417 = Math_fround($414 - $42);
  $418 = Math_fround($415 * $415);
  $419 = Math_fround($416 * $416);
  $420 = Math_fround($418 + $419);
  $421 = Math_fround($417 * $417);
  $422 = Math_fround($420 + $421);
  $423 = $422 > $424;
  if ($423) {
   $443 = $422;$index$3$1 = 2;
  } else {
   $443 = $424;$index$3$1 = $index$3;
  }
 } else {
  $443 = $424;$index$3$1 = $index$3;
 }
 $425 = (($chosen) + 3|0);
 $426 = HEAP8[$425>>0]|0;
 $427 = ($426<<24>>24)==(0);
 if ($427) {
  $428 = (($tempContacts) + 160|0);
  $429 = Math_fround(HEAPF32[$428>>2]);
  $430 = (($tempContacts) + 164|0);
  $431 = Math_fround(HEAPF32[$430>>2]);
  $432 = (($tempContacts) + 168|0);
  $433 = Math_fround(HEAPF32[$432>>2]);
  $434 = Math_fround($429 - $38);
  $435 = Math_fround($431 - $40);
  $436 = Math_fround($433 - $42);
  $437 = Math_fround($434 * $434);
  $438 = Math_fround($435 * $435);
  $439 = Math_fround($437 + $438);
  $440 = Math_fround($436 * $436);
  $441 = Math_fround($439 + $440);
  $442 = $441 > $443;
  if ($442) {
   $462 = $441;$index$3$2 = 3;
  } else {
   $462 = $443;$index$3$2 = $index$3$1;
  }
 } else {
  $462 = $443;$index$3$2 = $index$3$1;
 }
 $444 = (($chosen) + 4|0);
 $445 = HEAP8[$444>>0]|0;
 $446 = ($445<<24>>24)==(0);
 if ($446) {
  $447 = (($tempContacts) + 208|0);
  $448 = Math_fround(HEAPF32[$447>>2]);
  $449 = (($tempContacts) + 212|0);
  $450 = Math_fround(HEAPF32[$449>>2]);
  $451 = (($tempContacts) + 216|0);
  $452 = Math_fround(HEAPF32[$451>>2]);
  $453 = Math_fround($448 - $38);
  $454 = Math_fround($450 - $40);
  $455 = Math_fround($452 - $42);
  $456 = Math_fround($453 * $453);
  $457 = Math_fround($454 * $454);
  $458 = Math_fround($456 + $457);
  $459 = Math_fround($455 * $455);
  $460 = Math_fround($458 + $459);
  $461 = $460 > $462;
  if ($461) {
   $index$3$3 = 4;
  } else {
   $index$3$3 = $index$3$2;
  }
 } else {
  $index$3$3 = $index$3$2;
 }
 $463 = (($chosen) + ($index$3$3)|0);
 HEAP8[$463>>0] = 1;
 $464 = (($36) + 48|0);
 $465 = (($tempContacts) + (($index$3$3*48)|0)|0);
 dest=$464+0|0; src=$465+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $127 = Math_fround(0.0);$i3$0181 = 0;$index$4180 = $index$3$3;
 while(1) {
  $72 = (($chosen) + ($i3$0181)|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = ($73<<24>>24)==(0);
  if ($74) {
   $75 = HEAP32[$0>>2]|0;
   $76 = ((($tempContacts) + (($i3$0181*48)|0)|0) + 16|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = ((($tempContacts) + (($i3$0181*48)|0)|0) + 20|0);
   $79 = Math_fround(HEAPF32[$78>>2]);
   $80 = ((($tempContacts) + (($i3$0181*48)|0)|0) + 24|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   $82 = (($75) + 16|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = (($75) + 20|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = (($75) + 24|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = Math_fround($77 - $83);
   $89 = Math_fround($79 - $85);
   $90 = Math_fround($81 - $87);
   $91 = (($75) + 64|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = (($75) + 68|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = (($75) + 72|0);
   $96 = Math_fround(HEAPF32[$95>>2]);
   $97 = Math_fround($92 - $83);
   $98 = Math_fround($94 - $85);
   $99 = Math_fround($96 - $87);
   $100 = Math_fround($88 * $97);
   $101 = Math_fround($89 * $98);
   $102 = Math_fround($100 + $101);
   $103 = Math_fround($90 * $99);
   $104 = Math_fround($102 + $103);
   $105 = Math_fround($97 * $97);
   $106 = Math_fround($98 * $98);
   $107 = Math_fround($105 + $106);
   $108 = Math_fround($99 * $99);
   $109 = Math_fround($107 + $108);
   $110 = Math_fround($104 / $109);
   $111 = $110 > Math_fround(1.0);
   $$$i$i$i = $111 ? Math_fround(1.0) : $110;
   $112 = $$$i$i$i > Math_fround(0.0);
   $$$i8$i$i = $112 ? $$$i$i$i : Math_fround(0.0);
   $113 = $109 != Math_fround(0.0);
   $114 = $113 ? $$$i8$i$i : Math_fround(0.0);
   $115 = Math_fround($97 * $114);
   $116 = Math_fround($98 * $114);
   $117 = Math_fround($99 * $114);
   $118 = Math_fround($88 - $115);
   $119 = Math_fround($89 - $116);
   $120 = Math_fround($90 - $117);
   $121 = Math_fround($118 * $118);
   $122 = Math_fround($119 * $119);
   $123 = Math_fround($121 + $122);
   $124 = Math_fround($120 * $120);
   $125 = Math_fround($124 + $123);
   $126 = $125 > $127;
   if ($126) {
    $466 = $125;$index$5 = $i3$0181;
   } else {
    $466 = $127;$index$5 = $index$4180;
   }
  } else {
   $466 = $127;$index$5 = $index$4180;
  }
  $128 = (($i3$0181) + 1)|0;
  $exitcond187 = ($128|0)==(5);
  if ($exitcond187) {
   break;
  } else {
   $127 = $466;$i3$0181 = $128;$index$4180 = $index$5;
  }
 }
 $129 = (($chosen) + ($index$5)|0);
 HEAP8[$129>>0] = 1;
 $130 = HEAP32[$0>>2]|0;
 $131 = (($130) + 96|0);
 $132 = (($tempContacts) + (($index$5*48)|0)|0);
 dest=$131+0|0; src=$132+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $319 = Math_fround(0.0);$i4$0178 = 0;$index$6177 = $index$5;
 while(1) {
  $133 = (($chosen) + ($i4$0178)|0);
  $134 = HEAP8[$133>>0]|0;
  $135 = ($134<<24>>24)==(0);
  if ($135) {
   $136 = HEAP32[$0>>2]|0;
   $137 = (($136) + 64|0);
   $138 = Math_fround(HEAPF32[$137>>2]);
   $139 = (($136) + 68|0);
   $140 = Math_fround(HEAPF32[$139>>2]);
   $141 = (($136) + 72|0);
   $142 = Math_fround(HEAPF32[$141>>2]);
   $143 = (($136) + 16|0);
   $144 = Math_fround(HEAPF32[$143>>2]);
   $145 = (($136) + 20|0);
   $146 = Math_fround(HEAPF32[$145>>2]);
   $147 = (($136) + 24|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = Math_fround($138 - $144);
   $150 = Math_fround($140 - $146);
   $151 = Math_fround($142 - $148);
   $152 = (($136) + 112|0);
   $153 = Math_fround(HEAPF32[$152>>2]);
   $154 = (($136) + 116|0);
   $155 = Math_fround(HEAPF32[$154>>2]);
   $156 = (($136) + 120|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $158 = Math_fround($153 - $144);
   $159 = Math_fround($155 - $146);
   $160 = Math_fround($157 - $148);
   $161 = Math_fround($153 - $138);
   $162 = Math_fround($155 - $140);
   $163 = Math_fround($157 - $142);
   $164 = ((($tempContacts) + (($i4$0178*48)|0)|0) + 16|0);
   $165 = Math_fround(HEAPF32[$164>>2]);
   $166 = ((($tempContacts) + (($i4$0178*48)|0)|0) + 20|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = ((($tempContacts) + (($i4$0178*48)|0)|0) + 24|0);
   $169 = Math_fround(HEAPF32[$168>>2]);
   $170 = Math_fround($165 - $144);
   $171 = Math_fround($167 - $146);
   $172 = Math_fround($169 - $148);
   $173 = Math_fround($165 - $138);
   $174 = Math_fround($167 - $140);
   $175 = Math_fround($169 - $142);
   $176 = Math_fround($165 - $153);
   $177 = Math_fround($167 - $155);
   $178 = Math_fround($169 - $157);
   $179 = Math_fround($149 * $170);
   $180 = Math_fround($150 * $171);
   $181 = Math_fround($179 + $180);
   $182 = Math_fround($151 * $172);
   $183 = Math_fround($181 + $182);
   $184 = Math_fround($158 * $170);
   $185 = Math_fround($159 * $171);
   $186 = Math_fround($184 + $185);
   $187 = Math_fround($160 * $172);
   $188 = Math_fround($186 + $187);
   $189 = Math_fround($149 * $173);
   $190 = Math_fround($150 * $174);
   $191 = Math_fround($189 + $190);
   $192 = Math_fround($151 * $175);
   $193 = Math_fround($191 + $192);
   $194 = Math_fround($158 * $173);
   $195 = Math_fround($159 * $174);
   $196 = Math_fround($194 + $195);
   $197 = Math_fround($160 * $175);
   $198 = Math_fround($196 + $197);
   $199 = Math_fround($149 * $176);
   $200 = Math_fround($150 * $177);
   $201 = Math_fround($199 + $200);
   $202 = Math_fround($151 * $178);
   $203 = Math_fround($201 + $202);
   $204 = Math_fround($158 * $176);
   $205 = Math_fround($159 * $177);
   $206 = Math_fround($204 + $205);
   $207 = Math_fround($160 * $178);
   $208 = Math_fround($206 + $207);
   $209 = Math_fround($198 - $193);
   $210 = Math_fround($203 - $208);
   $211 = $183 < Math_fround(0.0);
   $212 = $188 < Math_fround(0.0);
   $or$cond$i = $211 & $212;
   do {
    if ($or$cond$i) {
     $213 = Math_fround($170 * $170);
     $214 = Math_fround($171 * $171);
     $215 = Math_fround($213 + $214);
     $216 = Math_fround($172 * $172);
     $217 = Math_fround($215 + $216);
     $318 = $217;
    } else {
     $218 = !($193 >= Math_fround(0.0));
     $219 = !($193 >= $198);
     $or$cond1379$i = $218 | $219;
     if (!($or$cond1379$i)) {
      $220 = Math_fround($173 * $173);
      $221 = Math_fround($174 * $174);
      $222 = Math_fround($220 + $221);
      $223 = Math_fround($175 * $175);
      $224 = Math_fround($222 + $223);
      $318 = $224;
      break;
     }
     $225 = !($208 >= Math_fround(0.0));
     $226 = !($208 >= $203);
     $or$cond1381$i = $225 | $226;
     if (!($or$cond1381$i)) {
      $227 = Math_fround($176 * $176);
      $228 = Math_fround($177 * $177);
      $229 = Math_fround($227 + $228);
      $230 = Math_fround($178 * $178);
      $231 = Math_fround($229 + $230);
      $318 = $231;
      break;
     }
     $232 = Math_fround($183 * $198);
     $233 = Math_fround($193 * $188);
     $234 = Math_fround($232 - $233);
     $235 = !($183 >= Math_fround(0.0));
     if (!($235)) {
      $phitmp$i = !($193 < Math_fround(0.0));
      $$not$i = !($234 < Math_fround(0.0));
      $brmerge$i = $$not$i | $phitmp$i;
      if (!($brmerge$i)) {
       $236 = Math_fround($183 - $193);
       $237 = Math_fround($183 / $236);
       $238 = Math_fround($149 * $237);
       $239 = Math_fround($150 * $237);
       $240 = Math_fround($151 * $237);
       $241 = Math_fround($144 + $238);
       $242 = Math_fround($146 + $239);
       $243 = Math_fround($148 + $240);
       $244 = Math_fround($165 - $241);
       $245 = Math_fround($167 - $242);
       $246 = Math_fround($169 - $243);
       $247 = Math_fround($244 * $244);
       $248 = Math_fround($245 * $245);
       $249 = Math_fround($247 + $248);
       $250 = Math_fround($246 * $246);
       $251 = Math_fround($250 + $249);
       $318 = $251;
       break;
      }
     }
     $252 = Math_fround($193 * $208);
     $253 = Math_fround($203 * $198);
     $254 = Math_fround($252 - $253);
     $255 = !($198 >= $193);
     if (!($255)) {
      $phitmp1395$i = !($203 >= $208);
      $$not1389$i = !($254 < Math_fround(0.0));
      $brmerge1391$i = $$not1389$i | $phitmp1395$i;
      if (!($brmerge1391$i)) {
       $256 = Math_fround($209 + $210);
       $257 = Math_fround($209 / $256);
       $258 = Math_fround($161 * $257);
       $259 = Math_fround($162 * $257);
       $260 = Math_fround($163 * $257);
       $261 = Math_fround($138 + $258);
       $262 = Math_fround($140 + $259);
       $263 = Math_fround($142 + $260);
       $264 = Math_fround($165 - $261);
       $265 = Math_fround($167 - $262);
       $266 = Math_fround($169 - $263);
       $267 = Math_fround($264 * $264);
       $268 = Math_fround($265 * $265);
       $269 = Math_fround($267 + $268);
       $270 = Math_fround($266 * $266);
       $271 = Math_fround($270 + $269);
       $318 = $271;
       break;
      }
     }
     $272 = Math_fround($203 * $188);
     $273 = Math_fround($183 * $208);
     $274 = Math_fround($272 - $273);
     $275 = !($188 >= Math_fround(0.0));
     if (!($275)) {
      $phitmp1396$i = !($208 < Math_fround(0.0));
      $$not1392$i = !($274 < Math_fround(0.0));
      $brmerge1394$i = $$not1392$i | $phitmp1396$i;
      if (!($brmerge1394$i)) {
       $276 = Math_fround($188 - $208);
       $277 = Math_fround($188 / $276);
       $278 = Math_fround($158 * $277);
       $279 = Math_fround($159 * $277);
       $280 = Math_fround($160 * $277);
       $281 = Math_fround($144 + $278);
       $282 = Math_fround($146 + $279);
       $283 = Math_fround($148 + $280);
       $284 = Math_fround($165 - $281);
       $285 = Math_fround($167 - $282);
       $286 = Math_fround($169 - $283);
       $287 = Math_fround($284 * $284);
       $288 = Math_fround($285 * $285);
       $289 = Math_fround($287 + $288);
       $290 = Math_fround($286 * $286);
       $291 = Math_fround($290 + $289);
       $318 = $291;
       break;
      }
     }
     $292 = Math_fround($274 + $234);
     $293 = Math_fround($254 + $292);
     $294 = Math_fround(Math_fround(1.0) / $293);
     $295 = Math_fround($274 * $294);
     $296 = Math_fround($234 * $294);
     $297 = Math_fround($149 * $295);
     $298 = Math_fround($150 * $295);
     $299 = Math_fround($151 * $295);
     $300 = Math_fround($158 * $296);
     $301 = Math_fround($159 * $296);
     $302 = Math_fround($160 * $296);
     $303 = Math_fround($297 + $300);
     $304 = Math_fround($298 + $301);
     $305 = Math_fround($299 + $302);
     $306 = Math_fround($144 + $303);
     $307 = Math_fround($146 + $304);
     $308 = Math_fround($148 + $305);
     $309 = Math_fround($165 - $306);
     $310 = Math_fround($167 - $307);
     $311 = Math_fround($169 - $308);
     $312 = Math_fround($309 * $309);
     $313 = Math_fround($310 * $310);
     $314 = Math_fround($312 + $313);
     $315 = Math_fround($311 * $311);
     $316 = Math_fround($315 + $314);
     $318 = $316;
    }
   } while(0);
   $317 = $318 > $319;
   if ($317) {
    $467 = $318;$index$7 = $i4$0178;
   } else {
    $467 = $319;$index$7 = $index$6177;
   }
  } else {
   $467 = $319;$index$7 = $index$6177;
  }
  $320 = (($i4$0178) + 1)|0;
  $exitcond = ($320|0)==(5);
  if ($exitcond) {
   break;
  } else {
   $319 = $467;$i4$0178 = $320;$index$6177 = $index$7;
  }
 }
 $321 = (($chosen) + ($index$7)|0);
 $322 = HEAP8[$321>>0]|0;
 $323 = ($322<<24>>24)==(0);
 if (!($323)) {
  $324 = (($this) + 32|0);
  HEAP8[$324>>0] = 3;
  STACKTOP = sp;return 0;
 }
 HEAP8[$321>>0] = 1;
 $325 = HEAP32[$0>>2]|0;
 $326 = (($325) + 144|0);
 $327 = (($tempContacts) + (($index$7*48)|0)|0);
 dest=$326+0|0; src=$327+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $a$0176 = 0;
 while(1) {
  $330 = (($chosen) + ($a$0176)|0);
  $331 = HEAP8[$330>>0]|0;
  $332 = ($331<<24>>24)==(0);
  $329 = (($a$0176) + 1)|0;
  if ($332) {
   $notChosenIndex$0 = $a$0176;
   break;
  }
  $328 = ($329>>>0)<(5);
  if ($328) {
   $a$0176 = $329;
  } else {
   $notChosenIndex$0 = 0;
   break;
  }
 }
 $333 = HEAP32[$0>>2]|0;
 $334 = (($tempContacts) + (($notChosenIndex$0*48)|0)|0);
 $335 = Math_fround(HEAPF32[$334>>2]);
 $336 = ((($tempContacts) + (($notChosenIndex$0*48)|0)|0) + 4|0);
 $337 = Math_fround(HEAPF32[$336>>2]);
 $338 = ((($tempContacts) + (($notChosenIndex$0*48)|0)|0) + 8|0);
 $339 = Math_fround(HEAPF32[$338>>2]);
 $340 = Math_fround(HEAPF32[$333>>2]);
 $341 = (($333) + 4|0);
 $342 = Math_fround(HEAPF32[$341>>2]);
 $343 = (($333) + 8|0);
 $344 = Math_fround(HEAPF32[$343>>2]);
 $345 = Math_fround($340 - $335);
 $346 = Math_fround($342 - $337);
 $347 = Math_fround($344 - $339);
 $348 = Math_fround($345 * $345);
 $349 = Math_fround($346 * $346);
 $350 = Math_fround($348 + $349);
 $351 = Math_fround($347 * $347);
 $352 = Math_fround($350 + $351);
 $353 = $352 < Math_fround(3.40282346638528859812E+38);
 $354 = $353 ? $352 : Math_fround(3.40282346638528859812E+38);
 $355 = (($333) + 48|0);
 $356 = Math_fround(HEAPF32[$355>>2]);
 $357 = (($333) + 52|0);
 $358 = Math_fround(HEAPF32[$357>>2]);
 $359 = (($333) + 56|0);
 $360 = Math_fround(HEAPF32[$359>>2]);
 $361 = Math_fround($356 - $335);
 $362 = Math_fround($358 - $337);
 $363 = Math_fround($360 - $339);
 $364 = Math_fround($361 * $361);
 $365 = Math_fround($362 * $362);
 $366 = Math_fround($364 + $365);
 $367 = Math_fround($363 * $363);
 $368 = Math_fround($366 + $367);
 $369 = $354 > $368;
 $370 = $369 ? $368 : $354;
 $index$9$1 = $369&1;
 $371 = (($333) + 96|0);
 $372 = Math_fround(HEAPF32[$371>>2]);
 $373 = (($333) + 100|0);
 $374 = Math_fround(HEAPF32[$373>>2]);
 $375 = (($333) + 104|0);
 $376 = Math_fround(HEAPF32[$375>>2]);
 $377 = Math_fround($372 - $335);
 $378 = Math_fround($374 - $337);
 $379 = Math_fround($376 - $339);
 $380 = Math_fround($377 * $377);
 $381 = Math_fround($378 * $378);
 $382 = Math_fround($380 + $381);
 $383 = Math_fround($379 * $379);
 $384 = Math_fround($382 + $383);
 $385 = $370 > $384;
 $386 = $385 ? $384 : $370;
 $index$9$2 = $385 ? 2 : $index$9$1;
 $387 = (($333) + 144|0);
 $388 = Math_fround(HEAPF32[$387>>2]);
 $389 = (($333) + 148|0);
 $390 = Math_fround(HEAPF32[$389>>2]);
 $391 = (($333) + 152|0);
 $392 = Math_fround(HEAPF32[$391>>2]);
 $393 = Math_fround($388 - $335);
 $394 = Math_fround($390 - $337);
 $395 = Math_fround($392 - $339);
 $396 = Math_fround($393 * $393);
 $397 = Math_fround($394 * $394);
 $398 = Math_fround($396 + $397);
 $399 = Math_fround($395 * $395);
 $400 = Math_fround($398 + $399);
 $401 = $386 > $400;
 $index$9$3 = $401 ? 3 : $index$9$2;
 $402 = ((($333) + (($index$9$3*48)|0)|0) + 44|0);
 $403 = Math_fround(HEAPF32[$402>>2]);
 $404 = ((($tempContacts) + (($notChosenIndex$0*48)|0)|0) + 44|0);
 $405 = Math_fround(HEAPF32[$404>>2]);
 $406 = $403 > $405;
 if (!($406)) {
  STACKTOP = sp;return 0;
 }
 $407 = (($tempContacts) + (($notChosenIndex$0*48)|0)|0);
 $408 = (($333) + (($index$9$3*48)|0)|0);
 dest=$408+0|0; src=$407+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return 0;
}
function __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVE($this,$contactBuffer,$normal,$transf1) {
 $this = $this|0;
 $contactBuffer = $contactBuffer|0;
 $normal = $normal|0;
 $transf1 = $transf1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $contactCount$0$lcssa = 0, $contactCount$049 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $contactCount$0$lcssa = 0;
  $85 = (($contactBuffer) + 4096|0);
  HEAP32[$85>>2] = $contactCount$0$lcssa;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 44|0);
 $4 = (($transf1) + 4|0);
 $5 = (($transf1) + 8|0);
 $6 = (($transf1) + 12|0);
 $7 = (($transf1) + 16|0);
 $8 = (($transf1) + 20|0);
 $9 = (($transf1) + 24|0);
 $10 = (($normal) + 4|0);
 $11 = (($normal) + 8|0);
 $contactCount$049 = 0;
 while(1) {
  $12 = HEAP32[$3>>2]|0;
  $13 = Math_fround(HEAPF32[$transf1>>2]);
  $14 = Math_fround(HEAPF32[$4>>2]);
  $15 = Math_fround(HEAPF32[$5>>2]);
  $16 = Math_fround(HEAPF32[$6>>2]);
  $17 = Math_fround(HEAPF32[$7>>2]);
  $18 = Math_fround(HEAPF32[$8>>2]);
  $19 = Math_fround(HEAPF32[$9>>2]);
  $20 = ((($12) + (($contactCount$049*48)|0)|0) + 16|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = ((($12) + (($contactCount$049*48)|0)|0) + 20|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = ((($12) + (($contactCount$049*48)|0)|0) + 24|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($16 * $16);
  $27 = Math_fround($26 + Math_fround(-0.5));
  $28 = Math_fround($27 * $21);
  $29 = Math_fround($27 * $23);
  $30 = Math_fround($27 * $25);
  $31 = Math_fround($14 * $25);
  $32 = Math_fround($15 * $23);
  $33 = Math_fround($31 - $32);
  $34 = Math_fround($15 * $21);
  $35 = Math_fround($13 * $25);
  $36 = Math_fround($34 - $35);
  $37 = Math_fround($13 * $23);
  $38 = Math_fround($14 * $21);
  $39 = Math_fround($37 - $38);
  $40 = Math_fround($16 * $33);
  $41 = Math_fround($16 * $36);
  $42 = Math_fround($16 * $39);
  $43 = Math_fround($28 + $40);
  $44 = Math_fround($29 + $41);
  $45 = Math_fround($30 + $42);
  $46 = Math_fround($13 * $21);
  $47 = Math_fround($14 * $23);
  $48 = Math_fround($46 + $47);
  $49 = Math_fround($15 * $25);
  $50 = Math_fround($48 + $49);
  $51 = Math_fround($13 * $50);
  $52 = Math_fround($14 * $50);
  $53 = Math_fround($15 * $50);
  $54 = Math_fround($51 + $43);
  $55 = Math_fround($52 + $44);
  $56 = Math_fround($45 + $53);
  $57 = Math_fround($54 * Math_fround(2.0));
  $58 = Math_fround($55 * Math_fround(2.0));
  $59 = Math_fround($56 * Math_fround(2.0));
  $60 = Math_fround($17 + $57);
  $61 = Math_fround($18 + $58);
  $62 = Math_fround($19 + $59);
  $63 = ((($12) + (($contactCount$049*48)|0)|0) + 44|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($contactCount$049) + 1)|0;
  $66 = Math_fround(HEAPF32[$normal>>2]);
  $67 = Math_fround(HEAPF32[$10>>2]);
  $68 = Math_fround(HEAPF32[$11>>2]);
  $69 = (($contactBuffer) + ($contactCount$049<<6)|0);
  HEAPF32[$69>>2] = $66;
  $70 = (($69) + 4|0);
  HEAPF32[$70>>2] = $67;
  $71 = (($69) + 8|0);
  HEAPF32[$71>>2] = $68;
  $72 = (($69) + 12|0);
  HEAPF32[$72>>2] = Math_fround(0.0);
  $73 = ((($contactBuffer) + ($contactCount$049<<6)|0) + 16|0);
  HEAPF32[$73>>2] = $60;
  $74 = (($73) + 4|0);
  HEAPF32[$74>>2] = $61;
  $75 = (($73) + 8|0);
  HEAPF32[$75>>2] = $62;
  $76 = (($73) + 12|0);
  HEAPF32[$76>>2] = Math_fround(0.0);
  $77 = ((($contactBuffer) + ($contactCount$049<<6)|0) + 12|0);
  HEAPF32[$77>>2] = $64;
  $78 = ((($contactBuffer) + ($contactCount$049<<6)|0) + 48|0);
  HEAP32[$78>>2] = -1;
  $79 = ((($contactBuffer) + ($contactCount$049<<6)|0) + 52|0);
  HEAP32[$79>>2] = -1;
  $80 = HEAP8[$0>>0]|0;
  $81 = $80&255;
  $82 = ($65>>>0)<($81>>>0);
  $83 = ($65>>>0)<(64);
  $84 = $82 & $83;
  if ($84) {
   $contactCount$049 = $65;
  } else {
   $contactCount$0$lcssa = $65;
   break;
  }
 }
 $85 = (($contactBuffer) + 4096|0);
 HEAP32[$85>>2] = $contactCount$0$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_15PsMatTransformVE($this,$contactBuffer,$normal,$transf1) {
 $this = $this|0;
 $contactBuffer = $contactBuffer|0;
 $normal = $normal|0;
 $transf1 = $transf1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $contactCount$0$lcssa = 0, $contactCount$049 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $contactCount$0$lcssa = 0;
  $76 = (($contactBuffer) + 4096|0);
  HEAP32[$76>>2] = $contactCount$0$lcssa;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 44|0);
 $4 = (($transf1) + 48|0);
 $5 = (($transf1) + 52|0);
 $6 = (($transf1) + 56|0);
 $7 = (($transf1) + 16|0);
 $8 = (($transf1) + 32|0);
 $9 = (($transf1) + 4|0);
 $10 = (($transf1) + 20|0);
 $11 = (($transf1) + 36|0);
 $12 = (($transf1) + 8|0);
 $13 = (($transf1) + 24|0);
 $14 = (($transf1) + 40|0);
 $15 = (($normal) + 4|0);
 $16 = (($normal) + 8|0);
 $contactCount$049 = 0;
 while(1) {
  $17 = HEAP32[$3>>2]|0;
  $18 = Math_fround(HEAPF32[$4>>2]);
  $19 = Math_fround(HEAPF32[$5>>2]);
  $20 = Math_fround(HEAPF32[$6>>2]);
  $21 = ((($17) + (($contactCount$049*48)|0)|0) + 16|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = ((($17) + (($contactCount$049*48)|0)|0) + 20|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = ((($17) + (($contactCount$049*48)|0)|0) + 24|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround(HEAPF32[$transf1>>2]);
  $28 = Math_fround($22 * $27);
  $29 = Math_fround(HEAPF32[$7>>2]);
  $30 = Math_fround($24 * $29);
  $31 = Math_fround($28 + $30);
  $32 = Math_fround(HEAPF32[$8>>2]);
  $33 = Math_fround($26 * $32);
  $34 = Math_fround($31 + $33);
  $35 = Math_fround(HEAPF32[$9>>2]);
  $36 = Math_fround($22 * $35);
  $37 = Math_fround(HEAPF32[$10>>2]);
  $38 = Math_fround($24 * $37);
  $39 = Math_fround($36 + $38);
  $40 = Math_fround(HEAPF32[$11>>2]);
  $41 = Math_fround($26 * $40);
  $42 = Math_fround($39 + $41);
  $43 = Math_fround(HEAPF32[$12>>2]);
  $44 = Math_fround($22 * $43);
  $45 = Math_fround(HEAPF32[$13>>2]);
  $46 = Math_fround($24 * $45);
  $47 = Math_fround($44 + $46);
  $48 = Math_fround(HEAPF32[$14>>2]);
  $49 = Math_fround($26 * $48);
  $50 = Math_fround($47 + $49);
  $51 = Math_fround($18 + $34);
  $52 = Math_fround($19 + $42);
  $53 = Math_fround($20 + $50);
  $54 = ((($17) + (($contactCount$049*48)|0)|0) + 44|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($contactCount$049) + 1)|0;
  $57 = Math_fround(HEAPF32[$normal>>2]);
  $58 = Math_fround(HEAPF32[$15>>2]);
  $59 = Math_fround(HEAPF32[$16>>2]);
  $60 = (($contactBuffer) + ($contactCount$049<<6)|0);
  HEAPF32[$60>>2] = $57;
  $61 = (($60) + 4|0);
  HEAPF32[$61>>2] = $58;
  $62 = (($60) + 8|0);
  HEAPF32[$62>>2] = $59;
  $63 = (($60) + 12|0);
  HEAPF32[$63>>2] = Math_fround(0.0);
  $64 = ((($contactBuffer) + ($contactCount$049<<6)|0) + 16|0);
  HEAPF32[$64>>2] = $51;
  $65 = (($64) + 4|0);
  HEAPF32[$65>>2] = $52;
  $66 = (($64) + 8|0);
  HEAPF32[$66>>2] = $53;
  $67 = (($64) + 12|0);
  HEAPF32[$67>>2] = Math_fround(0.0);
  $68 = ((($contactBuffer) + ($contactCount$049<<6)|0) + 12|0);
  HEAPF32[$68>>2] = $55;
  $69 = ((($contactBuffer) + ($contactCount$049<<6)|0) + 48|0);
  HEAP32[$69>>2] = -1;
  $70 = ((($contactBuffer) + ($contactCount$049<<6)|0) + 52|0);
  HEAP32[$70>>2] = -1;
  $71 = HEAP8[$0>>0]|0;
  $72 = $71&255;
  $73 = ($56>>>0)<($72>>>0);
  $74 = ($56>>>0)<(64);
  $75 = $73 & $74;
  if ($75) {
   $contactCount$049 = $56;
  } else {
   $contactCount$0$lcssa = $56;
   break;
  }
 }
 $76 = (($contactBuffer) + 4096|0);
 HEAP32[$76>>2] = $contactCount$0$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos5Vec3VERKNS5_12PsTransformVERKNS5_6FloatVE($this,$contactBuffer,$normal,$transf0,$radius) {
 $this = $this|0;
 $contactBuffer = $contactBuffer|0;
 $normal = $normal|0;
 $transf0 = $transf0|0;
 $radius = $radius|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $contactCount$0$lcssa = 0, $contactCount$087 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $contactCount$0$lcssa = 0;
  $93 = (($contactBuffer) + 4096|0);
  HEAP32[$93>>2] = $contactCount$0$lcssa;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 44|0);
 $4 = (($normal) + 4|0);
 $5 = (($normal) + 8|0);
 $6 = (($transf0) + 4|0);
 $7 = (($transf0) + 8|0);
 $8 = (($transf0) + 12|0);
 $9 = (($transf0) + 16|0);
 $10 = (($transf0) + 20|0);
 $11 = (($transf0) + 24|0);
 $contactCount$087 = 0;
 while(1) {
  $12 = HEAP32[$3>>2]|0;
  $13 = Math_fround(HEAPF32[$normal>>2]);
  $14 = Math_fround(HEAPF32[$4>>2]);
  $15 = Math_fround(HEAPF32[$5>>2]);
  $16 = Math_fround(HEAPF32[$radius>>2]);
  $17 = Math_fround(HEAPF32[$transf0>>2]);
  $18 = Math_fround(HEAPF32[$6>>2]);
  $19 = Math_fround(HEAPF32[$7>>2]);
  $20 = Math_fround(HEAPF32[$8>>2]);
  $21 = Math_fround(HEAPF32[$9>>2]);
  $22 = Math_fround(HEAPF32[$10>>2]);
  $23 = Math_fround(HEAPF32[$11>>2]);
  $24 = (($12) + (($contactCount$087*48)|0)|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($12) + (($contactCount$087*48)|0)|0) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = ((($12) + (($contactCount$087*48)|0)|0) + 8|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($20 * $20);
  $31 = Math_fround($30 + Math_fround(-0.5));
  $32 = Math_fround($31 * $25);
  $33 = Math_fround($31 * $27);
  $34 = Math_fround($31 * $29);
  $35 = Math_fround($18 * $29);
  $36 = Math_fround($19 * $27);
  $37 = Math_fround($35 - $36);
  $38 = Math_fround($19 * $25);
  $39 = Math_fround($17 * $29);
  $40 = Math_fround($38 - $39);
  $41 = Math_fround($17 * $27);
  $42 = Math_fround($18 * $25);
  $43 = Math_fround($41 - $42);
  $44 = Math_fround($20 * $37);
  $45 = Math_fround($20 * $40);
  $46 = Math_fround($20 * $43);
  $47 = Math_fround($32 + $44);
  $48 = Math_fround($33 + $45);
  $49 = Math_fround($34 + $46);
  $50 = Math_fround($17 * $25);
  $51 = Math_fround($18 * $27);
  $52 = Math_fround($50 + $51);
  $53 = Math_fround($19 * $29);
  $54 = Math_fround($52 + $53);
  $55 = Math_fround($17 * $54);
  $56 = Math_fround($18 * $54);
  $57 = Math_fround($19 * $54);
  $58 = Math_fround($55 + $47);
  $59 = Math_fround($56 + $48);
  $60 = Math_fround($49 + $57);
  $61 = Math_fround($58 * Math_fround(2.0));
  $62 = Math_fround($59 * Math_fround(2.0));
  $63 = Math_fround($60 * Math_fround(2.0));
  $64 = Math_fround($21 + $61);
  $65 = Math_fround($22 + $62);
  $66 = Math_fround($23 + $63);
  $67 = Math_fround($13 * $16);
  $68 = Math_fround($14 * $16);
  $69 = Math_fround($15 * $16);
  $70 = Math_fround($64 - $67);
  $71 = Math_fround($65 - $68);
  $72 = Math_fround($66 - $69);
  $73 = ((($12) + (($contactCount$087*48)|0)|0) + 44|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($74 - $16);
  $76 = (($contactCount$087) + 1)|0;
  $77 = (($contactBuffer) + ($contactCount$087<<6)|0);
  HEAPF32[$77>>2] = $13;
  $78 = (($77) + 4|0);
  HEAPF32[$78>>2] = $14;
  $79 = (($77) + 8|0);
  HEAPF32[$79>>2] = $15;
  $80 = (($77) + 12|0);
  HEAPF32[$80>>2] = Math_fround(0.0);
  $81 = ((($contactBuffer) + ($contactCount$087<<6)|0) + 16|0);
  HEAPF32[$81>>2] = $70;
  $82 = (($81) + 4|0);
  HEAPF32[$82>>2] = $71;
  $83 = (($81) + 8|0);
  HEAPF32[$83>>2] = $72;
  $84 = (($81) + 12|0);
  HEAPF32[$84>>2] = Math_fround(0.0);
  $85 = ((($contactBuffer) + ($contactCount$087<<6)|0) + 12|0);
  HEAPF32[$85>>2] = $75;
  $86 = ((($contactBuffer) + ($contactCount$087<<6)|0) + 48|0);
  HEAP32[$86>>2] = -1;
  $87 = ((($contactBuffer) + ($contactCount$087<<6)|0) + 52|0);
  HEAP32[$87>>2] = -1;
  $88 = HEAP8[$0>>0]|0;
  $89 = $88&255;
  $90 = ($76>>>0)<($89>>>0);
  $91 = ($76>>>0)<(64);
  $92 = $90 & $91;
  if ($92) {
   $contactCount$087 = $76;
  } else {
   $contactCount$0$lcssa = $76;
   break;
  }
 }
 $93 = (($contactBuffer) + 4096|0);
 HEAP32[$93>>2] = $contactCount$0$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold24addBatchManifoldContactsEPKNS0_17PersistentContactEj($this,$manifoldContacts,$numPoints) {
 $this = $this|0;
 $manifoldContacts = $manifoldContacts|0;
 $numPoints = $numPoints|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numPoints>>>0)<(5);
 if (!($0)) {
  __ZN5physx2Gu25PersistentContactManifold19reduceBatchContactsEPKNS0_17PersistentContactEj($this,$manifoldContacts,$numPoints);
  $15 = (($this) + 32|0);
  HEAP8[$15>>0] = 4;
  STACKTOP = sp;return;
 }
 $1 = ($numPoints|0)==(0);
 if (!($1)) {
  $2 = (($this) + 44|0);
  $i$01 = 0;
  while(1) {
   $3 = HEAP32[$2>>2]|0;
   $4 = (($3) + (($i$01*48)|0)|0);
   $5 = (($manifoldContacts) + (($i$01*48)|0)|0);
   ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$5+12>>2]|0;
   $6 = HEAP32[$2>>2]|0;
   $7 = ((($6) + (($i$01*48)|0)|0) + 16|0);
   $8 = ((($manifoldContacts) + (($i$01*48)|0)|0) + 16|0);
   ;HEAP32[$7+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$8+12>>2]|0;
   $9 = HEAP32[$2>>2]|0;
   $10 = ((($9) + (($i$01*48)|0)|0) + 32|0);
   $11 = ((($manifoldContacts) + (($i$01*48)|0)|0) + 32|0);
   ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
   $12 = (($i$01) + 1)|0;
   $exitcond = ($12|0)==($numPoints|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $12;
   }
  }
 }
 $13 = $numPoints&255;
 $14 = (($this) + 32|0);
 HEAP8[$14>>0] = $13;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold19reduceBatchContactsEPKNS0_17PersistentContactEj($this,$manifoldPoints,$numPoints) {
 $this = $this|0;
 $manifoldPoints = $manifoldPoints|0;
 $numPoints = $numPoints|0;
 var $$lcssa = Math_fround(0), $$lcssa289 = Math_fround(0), $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0);
 var $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0);
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $brmerge = 0, $chosen = 0, $exitcond = 0, $exitcond312 = 0, $exitcond313 = 0, $exitcond314 = 0, $i$0305 = 0, $i1$0299 = 0, $i2$0292 = 0, $i4$0288 = 0, $index$0$lcssa = 0, $index$0304 = 0, $index$1 = 0, $index$2$lcssa = 0, $index$2298 = 0, $index$3 = 0, $index$4$lcssa = 0, $index$4290 = 0, $index$5 = 0, $index$6 = 0;
 var $index1$0$lcssa = 0, $index1$0291 = 0, $index1$1 = 0, $index1$2287 = 0, $index1$3 = 0, $index1$4 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $chosen = sp;
 _memset(($chosen|0),0,($numPoints|0))|0;
 $0 = ($numPoints>>>0)>(1);
 if ($0) {
  $1 = (($manifoldPoints) + 44|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $6 = $2;$i$0305 = 1;$index$0304 = 0;
  while(1) {
   $3 = ((($manifoldPoints) + (($i$0305*48)|0)|0) + 44|0);
   $4 = Math_fround(HEAPF32[$3>>2]);
   $5 = $6 > $4;
   $7 = $5 ? $4 : $6;
   $index$1 = $5 ? $i$0305 : $index$0304;
   $8 = (($i$0305) + 1)|0;
   $exitcond314 = ($8|0)==($numPoints|0);
   if ($exitcond314) {
    $index$0$lcssa = $index$1;
    break;
   } else {
    $6 = $7;$i$0305 = $8;$index$0304 = $index$1;
   }
  }
 } else {
  $index$0$lcssa = 0;
 }
 $9 = (($this) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($manifoldPoints) + (($index$0$lcssa*48)|0)|0);
 dest=$10+0|0; src=$11+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $12 = (($chosen) + ($index$0$lcssa)|0);
 HEAP8[$12>>0] = 1;
 $13 = (($manifoldPoints) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($manifoldPoints) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($manifoldPoints) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = HEAP32[$9>>2]|0;
 $20 = (($19) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($19) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($19) + 24|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 - $21);
 $27 = Math_fround($16 - $23);
 $28 = Math_fround($18 - $25);
 if ($0) {
  $29 = Math_fround($27 * $27);
  $30 = Math_fround($26 * $26);
  $31 = Math_fround($28 * $28);
  $32 = Math_fround($30 + $29);
  $33 = Math_fround($32 + $31);
  $49 = $33;$i1$0299 = 1;$index$2298 = 0;
  while(1) {
   $34 = ((($manifoldPoints) + (($i1$0299*48)|0)|0) + 16|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = ((($manifoldPoints) + (($i1$0299*48)|0)|0) + 20|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = ((($manifoldPoints) + (($i1$0299*48)|0)|0) + 24|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = Math_fround($35 - $21);
   $41 = Math_fround($37 - $23);
   $42 = Math_fround($39 - $25);
   $43 = Math_fround($40 * $40);
   $44 = Math_fround($41 * $41);
   $45 = Math_fround($43 + $44);
   $46 = Math_fround($42 * $42);
   $47 = Math_fround($45 + $46);
   $48 = $47 > $49;
   $50 = $48 ? $47 : $49;
   $index$3 = $48 ? $i1$0299 : $index$2298;
   $51 = (($i1$0299) + 1)|0;
   $exitcond313 = ($51|0)==($numPoints|0);
   if ($exitcond313) {
    $index$2$lcssa = $index$3;
    break;
   } else {
    $49 = $50;$i1$0299 = $51;$index$2298 = $index$3;
   }
  }
 } else {
  $index$2$lcssa = 0;
 }
 $52 = (($19) + 48|0);
 $53 = (($manifoldPoints) + (($index$2$lcssa*48)|0)|0);
 dest=$52+0|0; src=$53+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $54 = (($chosen) + ($index$2$lcssa)|0);
 HEAP8[$54>>0] = 1;
 $55 = HEAP32[$9>>2]|0;
 $56 = (($55) + 64|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($55) + 68|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($55) + 72|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($55) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($55) + 20|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($55) + 24|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($57 - $63);
 $69 = Math_fround($59 - $65);
 $70 = Math_fround($61 - $67);
 $71 = (($55) + 32|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($55) + 36|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($55) + 40|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($69 * $76);
 $78 = Math_fround($70 * $74);
 $79 = Math_fround($77 - $78);
 $80 = Math_fround($70 * $72);
 $81 = Math_fround($68 * $76);
 $82 = Math_fround($80 - $81);
 $83 = Math_fround($68 * $74);
 $84 = Math_fround($69 * $72);
 $85 = Math_fround($83 - $84);
 $86 = Math_fround($79 * $79);
 $87 = Math_fround($82 * $82);
 $88 = Math_fround($86 + $87);
 $89 = Math_fround($85 * $85);
 $90 = Math_fround($89 + $88);
 $91 = (Math_fround(Math_sqrt((Math_fround($90)))));
 $92 = Math_fround(Math_fround(1.0) / $91);
 $93 = Math_fround($79 * $92);
 $94 = Math_fround($82 * $92);
 $95 = Math_fround($85 * $92);
 $96 = ($numPoints|0)==(0);
 if ($96) {
  $$lcssa = Math_fround(-3.40282346638528859812E+38);$$lcssa289 = Math_fround(3.40282346638528859812E+38);$index$4$lcssa = -1;$index1$0$lcssa = -1;
 } else {
  $115 = Math_fround(-3.40282346638528859812E+38);$118 = Math_fround(3.40282346638528859812E+38);$i2$0292 = 0;$index$4290 = -1;$index1$0291 = -1;
  while(1) {
   $97 = (($chosen) + ($i2$0292)|0);
   $98 = HEAP8[$97>>0]|0;
   $99 = ($98<<24>>24)==(0);
   if ($99) {
    $100 = ((($manifoldPoints) + (($i2$0292*48)|0)|0) + 16|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = ((($manifoldPoints) + (($i2$0292*48)|0)|0) + 20|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = ((($manifoldPoints) + (($i2$0292*48)|0)|0) + 24|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = Math_fround($101 - $63);
    $107 = Math_fround($103 - $65);
    $108 = Math_fround($105 - $67);
    $109 = Math_fround($93 * $106);
    $110 = Math_fround($94 * $107);
    $111 = Math_fround($109 + $110);
    $112 = Math_fround($95 * $108);
    $113 = Math_fround($111 + $112);
    $114 = $113 > $115;
    $116 = $114 ? $113 : $115;
    $index$5 = $114 ? $i2$0292 : $index$4290;
    $117 = $118 > $113;
    if ($117) {
     $154 = $116;$155 = $113;$index$6 = $index$5;$index1$1 = $i2$0292;
    } else {
     $154 = $116;$155 = $118;$index$6 = $index$5;$index1$1 = $index1$0291;
    }
   } else {
    $154 = $115;$155 = $118;$index$6 = $index$4290;$index1$1 = $index1$0291;
   }
   $119 = (($i2$0292) + 1)|0;
   $exitcond312 = ($119|0)==($numPoints|0);
   if ($exitcond312) {
    $$lcssa = $154;$$lcssa289 = $155;$index$4$lcssa = $index$6;$index1$0$lcssa = $index1$1;
    break;
   } else {
    $115 = $154;$118 = $155;$i2$0292 = $119;$index$4290 = $index$6;$index1$0291 = $index1$1;
   }
  }
 }
 $120 = (($55) + 96|0);
 $121 = (($manifoldPoints) + (($index$4$lcssa*48)|0)|0);
 dest=$120+0|0; src=$121+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $122 = (($chosen) + ($index$4$lcssa)|0);
 HEAP8[$122>>0] = 1;
 $123 = Math_fround($$lcssa * $$lcssa289);
 $$not = !($123 > Math_fround(0.0));
 $brmerge = $$not | $96;
 if ($brmerge) {
  $index1$4 = $index1$0$lcssa;
  $151 = HEAP32[$9>>2]|0;
  $152 = (($151) + 144|0);
  $153 = (($manifoldPoints) + (($index1$4*48)|0)|0);
  dest=$152+0|0; src=$153+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 } else {
  $149 = Math_fround(-3.40282346638528859812E+38);$i4$0288 = 0;$index1$2287 = $index1$0$lcssa;
 }
 while(1) {
  $124 = (($chosen) + ($i4$0288)|0);
  $125 = HEAP8[$124>>0]|0;
  $126 = ($125<<24>>24)==(0);
  if ($126) {
   $127 = ((($manifoldPoints) + (($i4$0288*48)|0)|0) + 16|0);
   $128 = Math_fround(HEAPF32[$127>>2]);
   $129 = ((($manifoldPoints) + (($i4$0288*48)|0)|0) + 20|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = ((($manifoldPoints) + (($i4$0288*48)|0)|0) + 24|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = HEAP32[$9>>2]|0;
   $134 = (($133) + 16|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = (($133) + 20|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = (($133) + 24|0);
   $139 = Math_fround(HEAPF32[$138>>2]);
   $140 = Math_fround($128 - $135);
   $141 = Math_fround($130 - $137);
   $142 = Math_fround($132 - $139);
   $143 = Math_fround($93 * $140);
   $144 = Math_fround($94 * $141);
   $145 = Math_fround($143 + $144);
   $146 = Math_fround($95 * $142);
   $147 = Math_fround($145 + $146);
   $148 = $147 > $149;
   if ($148) {
    $156 = $147;$index1$3 = $i4$0288;
   } else {
    $156 = $149;$index1$3 = $index1$2287;
   }
  } else {
   $156 = $149;$index1$3 = $index1$2287;
  }
  $150 = (($i4$0288) + 1)|0;
  $exitcond = ($150|0)==($numPoints|0);
  if ($exitcond) {
   $index1$4 = $index1$3;
   break;
  } else {
   $149 = $156;$i4$0288 = $150;$index1$2287 = $index1$3;
  }
 }
 $151 = HEAP32[$9>>2]|0;
 $152 = (($151) + 144|0);
 $153 = (($manifoldPoints) + (($index1$4*48)|0)|0);
 dest=$152+0|0; src=$153+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold31addBatchManifoldContactsClusterEPKNS0_17PersistentContactEj($this,$manifoldContacts,$numPoints) {
 $this = $this|0;
 $manifoldContacts = $manifoldContacts|0;
 $numPoints = $numPoints|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numPoints>>>0)<(5);
 if (!($0)) {
  __ZN5physx2Gu25PersistentContactManifold26reduceBatchContactsClusterEPKNS0_17PersistentContactEj($this,$manifoldContacts,$numPoints);
  $15 = (($this) + 32|0);
  HEAP8[$15>>0] = 4;
  STACKTOP = sp;return;
 }
 $1 = ($numPoints|0)==(0);
 if (!($1)) {
  $2 = (($this) + 44|0);
  $i$01 = 0;
  while(1) {
   $3 = HEAP32[$2>>2]|0;
   $4 = (($3) + (($i$01*48)|0)|0);
   $5 = (($manifoldContacts) + (($i$01*48)|0)|0);
   ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$5+12>>2]|0;
   $6 = HEAP32[$2>>2]|0;
   $7 = ((($6) + (($i$01*48)|0)|0) + 16|0);
   $8 = ((($manifoldContacts) + (($i$01*48)|0)|0) + 16|0);
   ;HEAP32[$7+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$8+12>>2]|0;
   $9 = HEAP32[$2>>2]|0;
   $10 = ((($9) + (($i$01*48)|0)|0) + 32|0);
   $11 = ((($manifoldContacts) + (($i$01*48)|0)|0) + 32|0);
   ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
   $12 = (($i$01) + 1)|0;
   $exitcond = ($12|0)==($numPoints|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $12;
   }
  }
 }
 $13 = $numPoints&255;
 $14 = (($this) + 32|0);
 HEAP8[$14>>0] = $13;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold26reduceBatchContactsClusterEPKNS0_17PersistentContactEj($this,$manifoldPoints,$numPoints) {
 $this = $this|0;
 $manifoldPoints = $manifoldPoints|0;
 $numPoints = $numPoints|0;
 var $$lcssa = Math_fround(0), $$lcssa362 = Math_fround(0), $$not = 0, $$pre = 0, $$pre391 = 0, $$pre392 = 0, $$pre393 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0;
 var $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0;
 var $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0;
 var $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0);
 var $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0);
 var $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge = 0, $chosen = 0, $exitcond = 0, $exitcond385 = 0, $exitcond388 = 0, $exitcond389 = 0, $exitcond390 = 0, $i$0380 = 0, $i1$0374 = 0;
 var $i2$0365 = 0, $i4$0360 = 0, $i6$0357 = 0, $index$0$lcssa = 0, $index$0379 = 0, $index$1 = 0, $index$2$lcssa = 0, $index$2373 = 0, $index$3 = 0, $index$4$lcssa = 0, $index$4363 = 0, $index$5 = 0, $index$6 = 0, $index$8$1 = 0, $index$8$2 = 0, $index$8$3 = 0, $index1$0$lcssa = 0, $index1$0364 = 0, $index1$1 = 0, $index1$2359 = 0;
 var $index1$3 = 0, $index1$4 = 0, $indices = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $chosen = sp + 16|0;
 $indices = sp;
 _memset(($chosen|0),0,($numPoints|0))|0;
 $0 = ($numPoints|0)==(0);
 if ($0) {
  $index$0$lcssa = 0;
 } else {
  $13 = Math_fround(-3.40282346638528859812E+38);$i$0380 = 0;$index$0379 = 0;
  while(1) {
   $1 = ((($manifoldPoints) + (($i$0380*48)|0)|0) + 16|0);
   $2 = Math_fround(HEAPF32[$1>>2]);
   $3 = ((($manifoldPoints) + (($i$0380*48)|0)|0) + 20|0);
   $4 = Math_fround(HEAPF32[$3>>2]);
   $5 = ((($manifoldPoints) + (($i$0380*48)|0)|0) + 24|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = Math_fround($2 * $2);
   $8 = Math_fround($4 * $4);
   $9 = Math_fround($7 + $8);
   $10 = Math_fround($6 * $6);
   $11 = Math_fround($9 + $10);
   $12 = $11 > $13;
   $14 = $12 ? $11 : $13;
   $index$1 = $12 ? $i$0380 : $index$0379;
   $15 = (($i$0380) + 1)|0;
   $exitcond390 = ($15|0)==($numPoints|0);
   if ($exitcond390) {
    $index$0$lcssa = $index$1;
    break;
   } else {
    $13 = $14;$i$0380 = $15;$index$0379 = $index$1;
   }
  }
 }
 $16 = (($this) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($manifoldPoints) + (($index$0$lcssa*48)|0)|0);
 dest=$17+0|0; src=$18+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $19 = (($chosen) + ($index$0$lcssa)|0);
 HEAP8[$19>>0] = 1;
 HEAP32[$indices>>2] = $index$0$lcssa;
 $20 = (($manifoldPoints) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($manifoldPoints) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($manifoldPoints) + 24|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = HEAP32[$16>>2]|0;
 $27 = (($26) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($26) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($26) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($21 - $28);
 $34 = Math_fround($23 - $30);
 $35 = Math_fround($25 - $32);
 $36 = ($numPoints>>>0)>(1);
 if ($36) {
  $37 = Math_fround($34 * $34);
  $38 = Math_fround($33 * $33);
  $39 = Math_fround($35 * $35);
  $40 = Math_fround($38 + $37);
  $41 = Math_fround($40 + $39);
  $57 = $41;$i1$0374 = 1;$index$2373 = 0;
  while(1) {
   $42 = ((($manifoldPoints) + (($i1$0374*48)|0)|0) + 16|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = ((($manifoldPoints) + (($i1$0374*48)|0)|0) + 20|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = ((($manifoldPoints) + (($i1$0374*48)|0)|0) + 24|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = Math_fround($43 - $28);
   $49 = Math_fround($45 - $30);
   $50 = Math_fround($47 - $32);
   $51 = Math_fround($48 * $48);
   $52 = Math_fround($49 * $49);
   $53 = Math_fround($51 + $52);
   $54 = Math_fround($50 * $50);
   $55 = Math_fround($53 + $54);
   $56 = $55 > $57;
   $58 = $56 ? $55 : $57;
   $index$3 = $56 ? $i1$0374 : $index$2373;
   $59 = (($i1$0374) + 1)|0;
   $exitcond389 = ($59|0)==($numPoints|0);
   if ($exitcond389) {
    $index$2$lcssa = $index$3;
    break;
   } else {
    $57 = $58;$i1$0374 = $59;$index$2373 = $index$3;
   }
  }
 } else {
  $index$2$lcssa = 0;
 }
 $60 = (($26) + 48|0);
 $61 = (($manifoldPoints) + (($index$2$lcssa*48)|0)|0);
 dest=$60+0|0; src=$61+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $62 = (($chosen) + ($index$2$lcssa)|0);
 HEAP8[$62>>0] = 1;
 $63 = (($indices) + 4|0);
 HEAP32[$63>>2] = $index$2$lcssa;
 $64 = HEAP32[$16>>2]|0;
 $65 = (($64) + 64|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($64) + 68|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($64) + 72|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($64) + 16|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($64) + 20|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($64) + 24|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($66 - $72);
 $78 = Math_fround($68 - $74);
 $79 = Math_fround($70 - $76);
 $80 = (($64) + 32|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($64) + 36|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($64) + 40|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($78 * $85);
 $87 = Math_fround($79 * $83);
 $88 = Math_fround($86 - $87);
 $89 = Math_fround($79 * $81);
 $90 = Math_fround($77 * $85);
 $91 = Math_fround($89 - $90);
 $92 = Math_fround($77 * $83);
 $93 = Math_fround($78 * $81);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($88 * $88);
 $96 = Math_fround($91 * $91);
 $97 = Math_fround($95 + $96);
 $98 = Math_fround($94 * $94);
 $99 = Math_fround($98 + $97);
 $100 = (Math_fround(Math_sqrt((Math_fround($99)))));
 $101 = Math_fround(Math_fround(1.0) / $100);
 $102 = Math_fround($88 * $101);
 $103 = Math_fround($91 * $101);
 $104 = Math_fround($94 * $101);
 if ($0) {
  $$lcssa = Math_fround(-3.40282346638528859812E+38);$$lcssa362 = Math_fround(3.40282346638528859812E+38);$index$4$lcssa = -1;$index1$0$lcssa = -1;
 } else {
  $123 = Math_fround(-3.40282346638528859812E+38);$126 = Math_fround(3.40282346638528859812E+38);$i2$0365 = 0;$index$4363 = -1;$index1$0364 = -1;
  while(1) {
   $105 = (($chosen) + ($i2$0365)|0);
   $106 = HEAP8[$105>>0]|0;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $108 = ((($manifoldPoints) + (($i2$0365*48)|0)|0) + 16|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = ((($manifoldPoints) + (($i2$0365*48)|0)|0) + 20|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = ((($manifoldPoints) + (($i2$0365*48)|0)|0) + 24|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = Math_fround($109 - $72);
    $115 = Math_fround($111 - $74);
    $116 = Math_fround($113 - $76);
    $117 = Math_fround($102 * $114);
    $118 = Math_fround($103 * $115);
    $119 = Math_fround($117 + $118);
    $120 = Math_fround($104 * $116);
    $121 = Math_fround($119 + $120);
    $122 = $121 > $123;
    $124 = $122 ? $121 : $123;
    $index$5 = $122 ? $i2$0365 : $index$4363;
    $125 = $126 > $121;
    if ($125) {
     $261 = $124;$262 = $121;$index$6 = $index$5;$index1$1 = $i2$0365;
    } else {
     $261 = $124;$262 = $126;$index$6 = $index$5;$index1$1 = $index1$0364;
    }
   } else {
    $261 = $123;$262 = $126;$index$6 = $index$4363;$index1$1 = $index1$0364;
   }
   $127 = (($i2$0365) + 1)|0;
   $exitcond388 = ($127|0)==($numPoints|0);
   if ($exitcond388) {
    $$lcssa = $261;$$lcssa362 = $262;$index$4$lcssa = $index$6;$index1$0$lcssa = $index1$1;
    break;
   } else {
    $123 = $261;$126 = $262;$i2$0365 = $127;$index$4363 = $index$6;$index1$0364 = $index1$1;
   }
  }
 }
 $128 = (($64) + 96|0);
 $129 = (($manifoldPoints) + (($index$4$lcssa*48)|0)|0);
 dest=$128+0|0; src=$129+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $130 = (($chosen) + ($index$4$lcssa)|0);
 HEAP8[$130>>0] = 1;
 $131 = (($indices) + 8|0);
 HEAP32[$131>>2] = $index$4$lcssa;
 $132 = Math_fround($$lcssa * $$lcssa362);
 $$not = !($132 > Math_fround(0.0));
 $brmerge = $$not | $0;
 if ($brmerge) {
  $index1$4 = $index1$0$lcssa;
 } else {
  $158 = Math_fround(-3.40282346638528859812E+38);$i4$0360 = 0;$index1$2359 = $index1$0$lcssa;
  while(1) {
   $133 = (($chosen) + ($i4$0360)|0);
   $134 = HEAP8[$133>>0]|0;
   $135 = ($134<<24>>24)==(0);
   if ($135) {
    $136 = ((($manifoldPoints) + (($i4$0360*48)|0)|0) + 16|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = ((($manifoldPoints) + (($i4$0360*48)|0)|0) + 20|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = ((($manifoldPoints) + (($i4$0360*48)|0)|0) + 24|0);
    $141 = Math_fround(HEAPF32[$140>>2]);
    $142 = HEAP32[$16>>2]|0;
    $143 = (($142) + 16|0);
    $144 = Math_fround(HEAPF32[$143>>2]);
    $145 = (($142) + 20|0);
    $146 = Math_fround(HEAPF32[$145>>2]);
    $147 = (($142) + 24|0);
    $148 = Math_fround(HEAPF32[$147>>2]);
    $149 = Math_fround($137 - $144);
    $150 = Math_fround($139 - $146);
    $151 = Math_fround($141 - $148);
    $152 = Math_fround($102 * $149);
    $153 = Math_fround($103 * $150);
    $154 = Math_fround($152 + $153);
    $155 = Math_fround($104 * $151);
    $156 = Math_fround($154 + $155);
    $157 = $156 > $158;
    if ($157) {
     $263 = $156;$index1$3 = $i4$0360;
    } else {
     $263 = $158;$index1$3 = $index1$2359;
    }
   } else {
    $263 = $158;$index1$3 = $index1$2359;
   }
   $159 = (($i4$0360) + 1)|0;
   $exitcond385 = ($159|0)==($numPoints|0);
   if ($exitcond385) {
    $index1$4 = $index1$3;
    break;
   } else {
    $158 = $263;$i4$0360 = $159;$index1$2359 = $index1$3;
   }
  }
 }
 $160 = HEAP32[$16>>2]|0;
 $161 = (($160) + 144|0);
 $162 = (($manifoldPoints) + (($index1$4*48)|0)|0);
 dest=$161+0|0; src=$162+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $163 = (($chosen) + ($index1$4)|0);
 HEAP8[$163>>0] = 1;
 $164 = (($indices) + 12|0);
 HEAP32[$164>>2] = $index1$4;
 if ($0) {
  $248 = $index$0$lcssa;$252 = $index$2$lcssa;$256 = $index$4$lcssa;$260 = $index1$4;
  $246 = HEAP32[$16>>2]|0;
  $247 = (($manifoldPoints) + (($248*48)|0)|0);
  dest=$246+0|0; src=$247+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $249 = HEAP32[$16>>2]|0;
  $250 = (($249) + 48|0);
  $251 = (($manifoldPoints) + (($252*48)|0)|0);
  dest=$250+0|0; src=$251+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $253 = HEAP32[$16>>2]|0;
  $254 = (($253) + 96|0);
  $255 = (($manifoldPoints) + (($256*48)|0)|0);
  dest=$254+0|0; src=$255+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $257 = HEAP32[$16>>2]|0;
  $258 = (($257) + 144|0);
  $259 = (($manifoldPoints) + (($260*48)|0)|0);
  dest=$258+0|0; src=$259+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 } else {
  $i6$0357 = 0;
 }
 while(1) {
  $165 = (($chosen) + ($i6$0357)|0);
  $166 = HEAP8[$165>>0]|0;
  $167 = ($166<<24>>24)==(0);
  if ($167) {
   $168 = ((($manifoldPoints) + (($i6$0357*48)|0)|0) + 44|0);
   $169 = Math_fround(HEAPF32[$168>>2]);
   $170 = ((($manifoldPoints) + (($i6$0357*48)|0)|0) + 16|0);
   $171 = Math_fround(HEAPF32[$170>>2]);
   $172 = ((($manifoldPoints) + (($i6$0357*48)|0)|0) + 20|0);
   $173 = Math_fround(HEAPF32[$172>>2]);
   $174 = ((($manifoldPoints) + (($i6$0357*48)|0)|0) + 24|0);
   $175 = Math_fround(HEAPF32[$174>>2]);
   $176 = HEAP32[$16>>2]|0;
   $177 = (($176) + 16|0);
   $178 = Math_fround(HEAPF32[$177>>2]);
   $179 = (($176) + 20|0);
   $180 = Math_fround(HEAPF32[$179>>2]);
   $181 = (($176) + 24|0);
   $182 = Math_fround(HEAPF32[$181>>2]);
   $183 = Math_fround($171 - $178);
   $184 = Math_fround($173 - $180);
   $185 = Math_fround($175 - $182);
   $186 = Math_fround($183 * $183);
   $187 = Math_fround($184 * $184);
   $188 = Math_fround($186 + $187);
   $189 = Math_fround($185 * $185);
   $190 = Math_fround($188 + $189);
   $191 = $190 < Math_fround(3.40282346638528859812E+38);
   $192 = $191 ? $190 : Math_fround(3.40282346638528859812E+38);
   $193 = (($176) + 64|0);
   $194 = Math_fround(HEAPF32[$193>>2]);
   $195 = (($176) + 68|0);
   $196 = Math_fround(HEAPF32[$195>>2]);
   $197 = (($176) + 72|0);
   $198 = Math_fround(HEAPF32[$197>>2]);
   $199 = Math_fround($171 - $194);
   $200 = Math_fround($173 - $196);
   $201 = Math_fround($175 - $198);
   $202 = Math_fround($199 * $199);
   $203 = Math_fround($200 * $200);
   $204 = Math_fround($202 + $203);
   $205 = Math_fround($201 * $201);
   $206 = Math_fround($204 + $205);
   $207 = $192 > $206;
   $208 = $207 ? $206 : $192;
   $index$8$1 = $207&1;
   $209 = (($176) + 112|0);
   $210 = Math_fround(HEAPF32[$209>>2]);
   $211 = (($176) + 116|0);
   $212 = Math_fround(HEAPF32[$211>>2]);
   $213 = (($176) + 120|0);
   $214 = Math_fround(HEAPF32[$213>>2]);
   $215 = Math_fround($171 - $210);
   $216 = Math_fround($173 - $212);
   $217 = Math_fround($175 - $214);
   $218 = Math_fround($215 * $215);
   $219 = Math_fround($216 * $216);
   $220 = Math_fround($218 + $219);
   $221 = Math_fround($217 * $217);
   $222 = Math_fround($220 + $221);
   $223 = $208 > $222;
   $224 = $223 ? $222 : $208;
   $index$8$2 = $223 ? 2 : $index$8$1;
   $225 = (($176) + 160|0);
   $226 = Math_fround(HEAPF32[$225>>2]);
   $227 = (($176) + 164|0);
   $228 = Math_fround(HEAPF32[$227>>2]);
   $229 = (($176) + 168|0);
   $230 = Math_fround(HEAPF32[$229>>2]);
   $231 = Math_fround($171 - $226);
   $232 = Math_fround($173 - $228);
   $233 = Math_fround($175 - $230);
   $234 = Math_fround($231 * $231);
   $235 = Math_fround($232 * $232);
   $236 = Math_fround($234 + $235);
   $237 = Math_fround($233 * $233);
   $238 = Math_fround($236 + $237);
   $239 = $224 > $238;
   $index$8$3 = $239 ? 3 : $index$8$2;
   $240 = (($indices) + ($index$8$3<<2)|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = ((($manifoldPoints) + (($241*48)|0)|0) + 44|0);
   $243 = Math_fround(HEAPF32[$242>>2]);
   $244 = $243 > $169;
   if ($244) {
    HEAP32[$240>>2] = $i6$0357;
   }
  }
  $245 = (($i6$0357) + 1)|0;
  $exitcond = ($245|0)==($numPoints|0);
  if ($exitcond) {
   break;
  } else {
   $i6$0357 = $245;
  }
 }
 $$pre = HEAP32[$indices>>2]|0;
 $$pre391 = HEAP32[$63>>2]|0;
 $$pre392 = HEAP32[$131>>2]|0;
 $$pre393 = HEAP32[$164>>2]|0;
 $248 = $$pre;$252 = $$pre391;$256 = $$pre392;$260 = $$pre393;
 $246 = HEAP32[$16>>2]|0;
 $247 = (($manifoldPoints) + (($248*48)|0)|0);
 dest=$246+0|0; src=$247+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $249 = HEAP32[$16>>2]|0;
 $250 = (($249) + 48|0);
 $251 = (($manifoldPoints) + (($252*48)|0)|0);
 dest=$250+0|0; src=$251+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $253 = HEAP32[$16>>2]|0;
 $254 = (($253) + 96|0);
 $255 = (($manifoldPoints) + (($256*48)|0)|0);
 dest=$254+0|0; src=$255+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $257 = HEAP32[$16>>2]|0;
 $258 = (($257) + 144|0);
 $259 = (($manifoldPoints) + (($260*48)|0)|0);
 dest=$258+0|0; src=$259+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold20reduceBatchContacts2EPKNS0_17PersistentContactEj($this,$manifoldPoints,$numPoints) {
 $this = $this|0;
 $manifoldPoints = $manifoldPoints|0;
 $numPoints = $numPoints|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0);
 var $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $chosen = 0, $exitcond = 0, $exitcond215 = 0, $exitcond216 = 0, $i$0210 = 0, $i1$0204 = 0, $i2$0202 = 0, $index$0$lcssa = 0, $index$0209 = 0, $index$1 = 0, $index$2$lcssa = 0, $index$2203 = 0, $index$3 = 0, $secondIndex$0$i2$0 = 0, $secondIndex$0201 = 0;
 var $secondIndex$1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $chosen = sp;
 _memset(($chosen|0),0,($numPoints|0))|0;
 $0 = ($numPoints>>>0)>(1);
 if ($0) {
  $1 = (($manifoldPoints) + 44|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $6 = $2;$i$0210 = 1;$index$0209 = 0;
  while(1) {
   $3 = ((($manifoldPoints) + (($i$0210*48)|0)|0) + 44|0);
   $4 = Math_fround(HEAPF32[$3>>2]);
   $5 = $6 > $4;
   $7 = $5 ? $4 : $6;
   $index$1 = $5 ? $i$0210 : $index$0209;
   $8 = (($i$0210) + 1)|0;
   $exitcond216 = ($8|0)==($numPoints|0);
   if ($exitcond216) {
    $index$0$lcssa = $index$1;
    break;
   } else {
    $6 = $7;$i$0210 = $8;$index$0209 = $index$1;
   }
  }
 } else {
  $index$0$lcssa = 0;
 }
 $9 = (($this) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($manifoldPoints) + (($index$0$lcssa*48)|0)|0);
 dest=$10+0|0; src=$11+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $12 = (($chosen) + ($index$0$lcssa)|0);
 HEAP8[$12>>0] = 1;
 $13 = (($manifoldPoints) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($manifoldPoints) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($manifoldPoints) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = HEAP32[$9>>2]|0;
 $20 = (($19) + 16|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($19) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($19) + 24|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($14 - $21);
 $27 = Math_fround($16 - $23);
 $28 = Math_fround($18 - $25);
 if ($0) {
  $29 = Math_fround($27 * $27);
  $30 = Math_fround($26 * $26);
  $31 = Math_fround($28 * $28);
  $32 = Math_fround($30 + $29);
  $33 = Math_fround($32 + $31);
  $49 = $33;$i1$0204 = 1;$index$2203 = 0;
  while(1) {
   $34 = ((($manifoldPoints) + (($i1$0204*48)|0)|0) + 16|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = ((($manifoldPoints) + (($i1$0204*48)|0)|0) + 20|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = ((($manifoldPoints) + (($i1$0204*48)|0)|0) + 24|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = Math_fround($35 - $21);
   $41 = Math_fround($37 - $23);
   $42 = Math_fround($39 - $25);
   $43 = Math_fround($40 * $40);
   $44 = Math_fround($41 * $41);
   $45 = Math_fround($43 + $44);
   $46 = Math_fround($42 * $42);
   $47 = Math_fround($45 + $46);
   $48 = $47 > $49;
   $50 = $48 ? $47 : $49;
   $index$3 = $48 ? $i1$0204 : $index$2203;
   $51 = (($i1$0204) + 1)|0;
   $exitcond215 = ($51|0)==($numPoints|0);
   if ($exitcond215) {
    $index$2$lcssa = $index$3;
    break;
   } else {
    $49 = $50;$i1$0204 = $51;$index$2203 = $index$3;
   }
  }
 } else {
  $index$2$lcssa = 0;
 }
 $52 = (($19) + 48|0);
 $53 = (($manifoldPoints) + (($index$2$lcssa*48)|0)|0);
 dest=$52+0|0; src=$53+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $54 = (($chosen) + ($index$2$lcssa)|0);
 HEAP8[$54>>0] = 1;
 $55 = ((($manifoldPoints) + (($index$2$lcssa*48)|0)|0) + 44|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = ($numPoints|0)==(0);
 if ($57) {
  STACKTOP = sp;return;
 } else {
  $i2$0202 = 0;$secondIndex$0201 = $index$2$lcssa;
 }
 while(1) {
  $58 = (($chosen) + ($i2$0202)|0);
  $59 = HEAP8[$58>>0]|0;
  $60 = ($59<<24>>24)==(0);
  if ($60) {
   $61 = HEAP32[$9>>2]|0;
   $62 = (($61) + 16|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = (($61) + 20|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = (($61) + 24|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = ((($manifoldPoints) + (($i2$0202*48)|0)|0) + 16|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = ((($manifoldPoints) + (($i2$0202*48)|0)|0) + 20|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = ((($manifoldPoints) + (($i2$0202*48)|0)|0) + 24|0);
   $73 = Math_fround(HEAPF32[$72>>2]);
   $74 = Math_fround($63 - $69);
   $75 = Math_fround($65 - $71);
   $76 = Math_fround($67 - $73);
   $77 = (($61) + 64|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = (($61) + 68|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = (($61) + 72|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $83 = Math_fround($78 - $69);
   $84 = Math_fround($80 - $71);
   $85 = Math_fround($82 - $73);
   $86 = Math_fround($74 * $74);
   $87 = Math_fround($75 * $75);
   $88 = Math_fround($86 + $87);
   $89 = Math_fround($76 * $76);
   $90 = Math_fround($88 + $89);
   $91 = Math_fround($83 * $83);
   $92 = Math_fround($84 * $84);
   $93 = Math_fround($91 + $92);
   $94 = Math_fround($85 * $85);
   $95 = Math_fround($93 + $94);
   $96 = $90 > $95;
   if ($96) {
    $97 = ((($manifoldPoints) + (($i2$0202*48)|0)|0) + 44|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = $56 > $98;
    $secondIndex$0$i2$0 = $99 ? $i2$0202 : $secondIndex$0201;
    $secondIndex$1 = $secondIndex$0$i2$0;
   } else {
    $secondIndex$1 = $secondIndex$0201;
   }
  } else {
   $secondIndex$1 = $secondIndex$0201;
  }
  $100 = (($i2$0202) + 1)|0;
  $exitcond = ($100|0)==($numPoints|0);
  if ($exitcond) {
   break;
  } else {
   $i2$0202 = $100;$secondIndex$0201 = $secondIndex$1;
  }
 }
 $101 = ($secondIndex$1|0)==($index$2$lcssa|0);
 if ($101) {
  STACKTOP = sp;return;
 }
 $102 = HEAP32[$9>>2]|0;
 $103 = (($102) + 48|0);
 $104 = (($manifoldPoints) + (($secondIndex$1*48)|0)|0);
 dest=$103+0|0; src=$104+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN5physx2Gu25PersistentContactManifold16addManifoldPointERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($this,$localPointA,$localPointB,$localNormalPen,$replaceBreakingThreshold) {
 $this = $this|0;
 $localPointA = $localPointA|0;
 $localPointB = $localPointB|0;
 $localNormalPen = $localNormalPen|0;
 $replaceBreakingThreshold = $replaceBreakingThreshold|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $i$053$i = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$replaceBreakingThreshold>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($this) + 32|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $$phi$trans$insert = (($this) + 44|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if ($4) {
  $34 = 0;
 } else {
  $5 = Math_fround(HEAPF32[$localPointB>>2]);
  $6 = (($localPointB) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($localPointB) + 8|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $3&255;
  $i$053$i = 0;
  while(1) {
   $13 = ((($$pre) + (($i$053$i*48)|0)|0) + 16|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = ((($$pre) + (($i$053$i*48)|0)|0) + 20|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = ((($$pre) + (($i$053$i*48)|0)|0) + 24|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = Math_fround($14 - $5);
   $20 = Math_fround($16 - $7);
   $21 = Math_fround($18 - $9);
   $22 = Math_fround($19 * $19);
   $23 = Math_fround($20 * $20);
   $24 = Math_fround($22 + $23);
   $25 = Math_fround($21 * $21);
   $26 = Math_fround($24 + $25);
   $27 = $1 > $26;
   $12 = (($i$053$i) + 1)|0;
   if ($27) {
    label = 5;
    break;
   }
   $11 = ($12>>>0)<($10>>>0);
   if ($11) {
    $i$053$i = $12;
   } else {
    break;
   }
  }
  if ((label|0) == 5) {
   $28 = (($$pre) + (($i$053$i*48)|0)|0);
   ;HEAP32[$28+0>>2]=HEAP32[$localPointA+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$localPointA+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$localPointA+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$localPointA+12>>2]|0;
   $29 = HEAP32[$$phi$trans$insert>>2]|0;
   $30 = ((($29) + (($i$053$i*48)|0)|0) + 16|0);
   ;HEAP32[$30+0>>2]=HEAP32[$localPointB+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$localPointB+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$localPointB+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$localPointB+12>>2]|0;
   $31 = HEAP32[$$phi$trans$insert>>2]|0;
   $32 = ((($31) + (($i$053$i*48)|0)|0) + 32|0);
   ;HEAP32[$32+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $switch = ($3&255)<(4);
  if ($switch) {
   $34 = $3;
  } else {
   (__ZN5physx2Gu25PersistentContactManifold20reduceContactsForPCMERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VE($this,$localPointA,$localPointB,$localNormalPen)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $33 = $34&255;
 $35 = (($this) + 44|0);
 $36 = (($$pre) + (($33*48)|0)|0);
 ;HEAP32[$36+0>>2]=HEAP32[$localPointA+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$localPointA+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$localPointA+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$localPointA+12>>2]|0;
 $37 = HEAP8[$2>>0]|0;
 $38 = $37&255;
 $39 = HEAP32[$35>>2]|0;
 $40 = ((($39) + (($38*48)|0)|0) + 16|0);
 ;HEAP32[$40+0>>2]=HEAP32[$localPointB+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$localPointB+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$localPointB+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$localPointB+12>>2]|0;
 $41 = HEAP8[$2>>0]|0;
 $42 = (($41) + 1)<<24>>24;
 HEAP8[$2>>0] = $42;
 $43 = $41&255;
 $44 = HEAP32[$35>>2]|0;
 $45 = ((($44) + (($43*48)|0)|0) + 32|0);
 ;HEAP32[$45+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx2Gu25PersistentContactManifold17addManifoldPoint2ERKNS_6shdfnd3aos5Vec3VES6_RKNS3_5Vec4VERKNS3_6FloatVE($this,$localPointA,$localPointB,$localNormalPen,$replaceBreakingThreshold) {
 $this = $this|0;
 $localPointA = $localPointA|0;
 $localPointB = $localPointB|0;
 $localNormalPen = $localNormalPen|0;
 $replaceBreakingThreshold = $replaceBreakingThreshold|0;
 var $$0 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $i$053$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$replaceBreakingThreshold>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($this) + 32|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 L1: do {
  if ($4) {
   $$pre = $3&255;
   $$pre$phiZ2D = $$pre;
  } else {
   $5 = (($this) + 44|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = Math_fround(HEAPF32[$localPointB>>2]);
   $8 = (($localPointB) + 4|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = (($localPointB) + 8|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = $3&255;
   $i$053$i = 0;
   while(1) {
    $15 = ((($6) + (($i$053$i*48)|0)|0) + 16|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = ((($6) + (($i$053$i*48)|0)|0) + 20|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = ((($6) + (($i$053$i*48)|0)|0) + 24|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = Math_fround($16 - $7);
    $22 = Math_fround($18 - $9);
    $23 = Math_fround($20 - $11);
    $24 = Math_fround($21 * $21);
    $25 = Math_fround($22 * $22);
    $26 = Math_fround($24 + $25);
    $27 = Math_fround($23 * $23);
    $28 = Math_fround($26 + $27);
    $29 = $1 > $28;
    $14 = (($i$053$i) + 1)|0;
    if ($29) {
     break;
    }
    $13 = ($14>>>0)<($12>>>0);
    if ($13) {
     $i$053$i = $14;
    } else {
     $$pre$phiZ2D = $12;
     break L1;
    }
   }
   $30 = (($6) + (($i$053$i*48)|0)|0);
   ;HEAP32[$30+0>>2]=HEAP32[$localPointA+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$localPointA+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$localPointA+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$localPointA+12>>2]|0;
   $31 = HEAP32[$5>>2]|0;
   $32 = ((($31) + (($i$053$i*48)|0)|0) + 16|0);
   ;HEAP32[$32+0>>2]=HEAP32[$localPointB+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$localPointB+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$localPointB+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$localPointB+12>>2]|0;
   $33 = HEAP32[$5>>2]|0;
   $34 = ((($33) + (($i$053$i*48)|0)|0) + 32|0);
   ;HEAP32[$34+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 if ((($$pre$phiZ2D|0) == 2)) {
  $47 = Math_fround(HEAPF32[$localPointB>>2]);
  $48 = (($localPointB) + 4|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($localPointB) + 8|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($this) + 44|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 16|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($53) + 20|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($53) + 24|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($53) + 64|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($53) + 68|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($53) + 72|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($55 - $47);
  $67 = Math_fround($57 - $49);
  $68 = Math_fround($59 - $51);
  $69 = Math_fround($61 - $47);
  $70 = Math_fround($63 - $49);
  $71 = Math_fround($65 - $51);
  $72 = Math_fround($66 * $66);
  $73 = Math_fround($67 * $67);
  $74 = Math_fround($72 + $73);
  $75 = Math_fround($68 * $68);
  $76 = Math_fround($74 + $75);
  $77 = Math_fround($69 * $69);
  $78 = Math_fround($70 * $70);
  $79 = Math_fround($77 + $78);
  $80 = Math_fround($71 * $71);
  $81 = Math_fround($79 + $80);
  $82 = $76 > $81;
  if ($82) {
   $83 = (($53) + 48|0);
   ;HEAP32[$83+0>>2]=HEAP32[$localPointA+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$localPointA+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$localPointA+8>>2]|0;HEAP32[$83+12>>2]=HEAP32[$localPointA+12>>2]|0;
   $84 = HEAP32[$52>>2]|0;
   $85 = (($84) + 64|0);
   ;HEAP32[$85+0>>2]=HEAP32[$localPointB+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$localPointB+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$localPointB+8>>2]|0;HEAP32[$85+12>>2]=HEAP32[$localPointB+12>>2]|0;
   $86 = HEAP32[$52>>2]|0;
   $87 = (($86) + 80|0);
   ;HEAP32[$87+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$87+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   ;HEAP32[$53+0>>2]=HEAP32[$localPointA+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$localPointA+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$localPointA+8>>2]|0;HEAP32[$53+12>>2]=HEAP32[$localPointA+12>>2]|0;
   $88 = HEAP32[$52>>2]|0;
   $89 = (($88) + 16|0);
   ;HEAP32[$89+0>>2]=HEAP32[$localPointB+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$localPointB+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$localPointB+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$localPointB+12>>2]|0;
   $90 = HEAP32[$52>>2]|0;
   $91 = (($90) + 32|0);
   ;HEAP32[$91+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$91+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } else if ((($$pre$phiZ2D|0) == 1) | (($$pre$phiZ2D|0) == 0)) {
  $35 = (($this) + 44|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + (($$pre$phiZ2D*48)|0)|0);
  ;HEAP32[$37+0>>2]=HEAP32[$localPointA+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$localPointA+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$localPointA+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$localPointA+12>>2]|0;
  $38 = HEAP8[$2>>0]|0;
  $39 = $38&255;
  $40 = HEAP32[$35>>2]|0;
  $41 = ((($40) + (($39*48)|0)|0) + 16|0);
  ;HEAP32[$41+0>>2]=HEAP32[$localPointB+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$localPointB+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$localPointB+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$localPointB+12>>2]|0;
  $42 = HEAP8[$2>>0]|0;
  $43 = (($42) + 1)<<24>>24;
  HEAP8[$2>>0] = $43;
  $44 = $42&255;
  $45 = HEAP32[$35>>2]|0;
  $46 = ((($45) + (($44*48)|0)|0) + 32|0);
  ;HEAP32[$46+0>>2]=HEAP32[$localNormalPen+0>>2]|0;HEAP32[$46+4>>2]=HEAP32[$localNormalPen+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[$localNormalPen+8>>2]|0;HEAP32[$46+12>>2]=HEAP32[$localNormalPen+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5physx2Gu25PersistentContactManifold25addBatchManifoldContacts2EPKNS0_17PersistentContactEj($this,$manifoldContacts,$numPoints) {
 $this = $this|0;
 $manifoldContacts = $manifoldContacts|0;
 $numPoints = $numPoints|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($numPoints>>>0)<(3);
 if (!($0)) {
  __ZN5physx2Gu25PersistentContactManifold20reduceBatchContacts2EPKNS0_17PersistentContactEj($this,$manifoldContacts,$numPoints);
  $15 = (($this) + 32|0);
  HEAP8[$15>>0] = 2;
  STACKTOP = sp;return;
 }
 $1 = ($numPoints|0)==(0);
 if (!($1)) {
  $2 = (($this) + 44|0);
  $i$01 = 0;
  while(1) {
   $3 = HEAP32[$2>>2]|0;
   $4 = (($3) + (($i$01*48)|0)|0);
   $5 = (($manifoldContacts) + (($i$01*48)|0)|0);
   ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$5+12>>2]|0;
   $6 = HEAP32[$2>>2]|0;
   $7 = ((($6) + (($i$01*48)|0)|0) + 16|0);
   $8 = ((($manifoldContacts) + (($i$01*48)|0)|0) + 16|0);
   ;HEAP32[$7+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$8+12>>2]|0;
   $9 = HEAP32[$2>>2]|0;
   $10 = ((($9) + (($i$01*48)|0)|0) + 32|0);
   $11 = ((($manifoldContacts) + (($i$01*48)|0)|0) + 32|0);
   ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
   $12 = (($i$01) + 1)|0;
   $exitcond = ($12|0)==($numPoints|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $12;
   }
  }
 }
 $13 = $numPoints&255;
 $14 = (($this) + 32|0);
 HEAP8[$14>>0] = $13;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu31SinglePersistentContactManifold25reduceBatchContactsConvexEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($agg$result,$this,$manifoldContactExt,$numContacts,$patch) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $manifoldContactExt = $manifoldContactExt|0;
 $numContacts = $numContacts|0;
 $patch = $patch|0;
 var $$$i = Math_fround(0), $$$i$1 = Math_fround(0), $$$i$lcssa = Math_fround(0), $$$i$us = Math_fround(0), $$$i10 = Math_fround(0), $$$i10$1 = Math_fround(0), $$$i10$2 = Math_fround(0), $$$i10$3 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa$1 = Math_fround(0), $$lcssa459 = Math_fround(0), $$lcssa472 = Math_fround(0), $$lcssa473 = Math_fround(0), $$lcssa484 = Math_fround(0), $$lcssa485 = Math_fround(0), $$lcssa496 = Math_fround(0), $$lcssa510 = Math_fround(0), $$not = 0, $$phi$trans$insert = 0, $$phi$trans$insert531 = 0;
 var $$phi$trans$insert533 = 0, $$phi$trans$insert554 = 0, $$phi$trans$insert556 = 0, $$phi$trans$insert558 = 0, $$phi$trans$insert560 = 0, $$phi$trans$insert562 = 0, $$phi$trans$insert564 = 0, $$phi$trans$insert571 = 0, $$phi$trans$insert573 = 0, $$phi$trans$insert575 = 0, $$phi$trans$insert577 = 0, $$pre = Math_fround(0), $$pre532 = Math_fround(0), $$pre534 = Math_fround(0), $$pre538 = 0, $$pre539 = 0, $$pre540 = 0, $$pre541 = 0, $$pre555 = Math_fround(0), $$pre557 = Math_fround(0);
 var $$pre559 = Math_fround(0), $$pre561 = Math_fround(0), $$pre563 = Math_fround(0), $$pre565 = Math_fround(0), $$pre566 = 0, $$pre572 = 0, $$pre574 = 0, $$pre576 = 0, $$pre578 = 0, $$sroa$1 = 0, $$sroa$1111 = 0, $$sroa$1124 = 0, $$sroa$1160 = 0, $$sroa$1200 = 0, $$sroa$194 = 0, $$sroa$196 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0);
 var $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0;
 var $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0);
 var $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0;
 var $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0);
 var $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0);
 var $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0);
 var $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0);
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0);
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0);
 var $336 = Math_fround(0), $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $a$0453 = 0, $brmerge = 0;
 var $closest$1$1 = 0, $closest$1$2 = 0, $closest$1$3 = 0, $clusters = 0, $currentPatch$0519 = 0, $currentPatch$1504 = 0, $currentPatch$2486 = 0, $currentPatch$3468 = 0, $currentPatch$4455 = 0, $currentPatch$5437 = 0, $currentPatch$5437$1 = 0, $i$0511 = 0, $i10$0433 = 0, $i10$0433$1 = 0, $i2$0497 = 0, $i3$0475 = 0, $i5$0461 = 0, $index$0520 = 0, $index$1$lcssa = 0, $index$11438 = 0;
 var $index$11438$1 = 0, $index$12$lcssa = 0, $index$12$lcssa$1 = 0, $index$12434 = 0, $index$12434$1 = 0, $index$13 = 0, $index$13$1 = 0, $index$1512 = 0, $index$2 = 0, $index$3$lcssa = 0, $index$3505 = 0, $index$4$lcssa = 0, $index$4498 = 0, $index$5 = 0, $index$6$lcssa = 0, $index$6488 = 0, $index$7$lcssa = 0, $index$7476 = 0, $index$8 = 0, $index$9 = 0;
 var $index1$0$lcssa = 0, $index1$0487 = 0, $index1$1$lcssa = 0, $index1$1474 = 0, $index1$2 = 0, $index1$3469 = 0, $index1$4$lcssa = 0, $index1$4460 = 0, $index1$5 = 0, $index1$6 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $clusters = sp;
 $$sroa$1200 = sp + 200|0;
 $$sroa$1160 = sp + 128|0;
 $$sroa$1124 = sp + 140|0;
 $$sroa$1111 = sp + 152|0;
 $$sroa$196 = sp + 164|0;
 $$sroa$194 = sp + 176|0;
 $$sroa$1 = sp + 188|0;
 $0 = STACKTOP; STACKTOP = STACKTOP + ((((1*$numContacts)|0)+15)&-16)|0;;
 _memset(($0|0),0,($numContacts|0))|0;
 $1 = ($patch|0)==(0|0);
 if ($1) {
  $27 = -1;
 } else {
  $329 = Math_fround(-3.40282346638528859812E+38);$currentPatch$0519 = $patch;$index$0520 = -1;
  while(1) {
   $2 = (($currentPatch$0519) + 48|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($currentPatch$0519) + 52|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3>>>0)<($5>>>0);
   if ($6) {
    $19 = $329;$i$0511 = $3;$index$1512 = $index$0520;
    while(1) {
     $7 = ((($manifoldContactExt) + ($i$0511<<6)|0) + 16|0);
     $8 = Math_fround(HEAPF32[$7>>2]);
     $9 = ((($manifoldContactExt) + ($i$0511<<6)|0) + 20|0);
     $10 = Math_fround(HEAPF32[$9>>2]);
     $11 = ((($manifoldContactExt) + ($i$0511<<6)|0) + 24|0);
     $12 = Math_fround(HEAPF32[$11>>2]);
     $13 = Math_fround($8 * $8);
     $14 = Math_fround($10 * $10);
     $15 = Math_fround($13 + $14);
     $16 = Math_fround($12 * $12);
     $17 = Math_fround($15 + $16);
     $18 = $17 > $19;
     $20 = $18 ? $17 : $19;
     $index$2 = $18 ? $i$0511 : $index$1512;
     $21 = (($i$0511) + 1)|0;
     $22 = ($21>>>0)<($5>>>0);
     if ($22) {
      $19 = $20;$i$0511 = $21;$index$1512 = $index$2;
     } else {
      $$lcssa510 = $20;$index$1$lcssa = $index$2;
      break;
     }
    }
   } else {
    $$lcssa510 = $329;$index$1$lcssa = $index$0520;
   }
   $23 = (($currentPatch$0519) + 16|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    $27 = $index$1$lcssa;
    break;
   } else {
    $329 = $$lcssa510;$currentPatch$0519 = $24;$index$0520 = $index$1$lcssa;
   }
  }
 }
 $26 = (($0) + ($27)|0);
 HEAP8[$26>>0] = 1;
 HEAP32[$clusters>>2] = $27;
 $28 = (($clusters) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = ((($manifoldContactExt) + ($27<<6)|0) + 44|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($clusters) + 16|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($clusters) + 20|0);
 ;HEAP32[$32+0>>2]=HEAP32[$$sroa$1200+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$$sroa$1200+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$$sroa$1200+8>>2]|0;
 $33 = (($patch) + 48|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($manifoldContactExt) + ($34<<6)|0) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = ((($manifoldContactExt) + ($34<<6)|0) + 20|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = ((($manifoldContactExt) + ($34<<6)|0) + 24|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = ((($manifoldContactExt) + ($27<<6)|0) + 16|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = ((($manifoldContactExt) + ($27<<6)|0) + 20|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = ((($manifoldContactExt) + ($27<<6)|0) + 24|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($36 - $42);
 $48 = Math_fround($38 - $44);
 $49 = Math_fround($40 - $46);
 if ($1) {
  $89 = $36;$91 = $38;$93 = $40;$index$3$lcssa = $34;
 } else {
  $50 = Math_fround($48 * $48);
  $51 = Math_fround($47 * $47);
  $52 = Math_fround($49 * $49);
  $53 = Math_fround($51 + $50);
  $54 = Math_fround($53 + $52);
  $330 = $54;$58 = $34;$currentPatch$1504 = $patch;$index$3505 = $34;
  while(1) {
   $55 = (($currentPatch$1504) + 52|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($58>>>0)<($56>>>0);
   if ($57) {
    $74 = $330;$i2$0497 = $58;$index$4498 = $index$3505;
    while(1) {
     $59 = ((($manifoldContactExt) + ($i2$0497<<6)|0) + 16|0);
     $60 = Math_fround(HEAPF32[$59>>2]);
     $61 = ((($manifoldContactExt) + ($i2$0497<<6)|0) + 20|0);
     $62 = Math_fround(HEAPF32[$61>>2]);
     $63 = ((($manifoldContactExt) + ($i2$0497<<6)|0) + 24|0);
     $64 = Math_fround(HEAPF32[$63>>2]);
     $65 = Math_fround($60 - $42);
     $66 = Math_fround($62 - $44);
     $67 = Math_fround($64 - $46);
     $68 = Math_fround($65 * $65);
     $69 = Math_fround($66 * $66);
     $70 = Math_fround($68 + $69);
     $71 = Math_fround($67 * $67);
     $72 = Math_fround($70 + $71);
     $73 = $72 > $74;
     $75 = $73 ? $72 : $74;
     $index$5 = $73 ? $i2$0497 : $index$4498;
     $76 = (($i2$0497) + 1)|0;
     $77 = ($76>>>0)<($56>>>0);
     if ($77) {
      $74 = $75;$i2$0497 = $76;$index$4498 = $index$5;
     } else {
      $$lcssa496 = $75;$index$4$lcssa = $index$5;
      break;
     }
    }
   } else {
    $$lcssa496 = $330;$index$4$lcssa = $index$3505;
   }
   $78 = (($currentPatch$1504) + 16|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    break;
   }
   $$phi$trans$insert577 = (($79) + 48|0);
   $$pre578 = HEAP32[$$phi$trans$insert577>>2]|0;
   $330 = $$lcssa496;$58 = $$pre578;$currentPatch$1504 = $79;$index$3505 = $index$4$lcssa;
  }
  $$phi$trans$insert = ((($manifoldContactExt) + ($index$4$lcssa<<6)|0) + 16|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$phi$trans$insert531 = ((($manifoldContactExt) + ($index$4$lcssa<<6)|0) + 20|0);
  $$pre532 = Math_fround(HEAPF32[$$phi$trans$insert531>>2]);
  $$phi$trans$insert533 = ((($manifoldContactExt) + ($index$4$lcssa<<6)|0) + 24|0);
  $$pre534 = Math_fround(HEAPF32[$$phi$trans$insert533>>2]);
  $89 = $$pre;$91 = $$pre532;$93 = $$pre534;$index$3$lcssa = $index$4$lcssa;
 }
 $81 = (($0) + ($index$3$lcssa)|0);
 HEAP8[$81>>0] = 1;
 $82 = (($clusters) + 32|0);
 HEAP32[$82>>2] = $index$3$lcssa;
 $83 = (($clusters) + 36|0);
 HEAP32[$83>>2] = $index$3$lcssa;
 $84 = ((($manifoldContactExt) + ($index$3$lcssa<<6)|0) + 44|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($clusters) + 48|0);
 HEAPF32[$86>>2] = $85;
 $87 = (($clusters) + 52|0);
 ;HEAP32[$87+0>>2]=HEAP32[$$sroa$1160+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$$sroa$1160+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$$sroa$1160+8>>2]|0;
 $88 = Math_fround($89 - $42);
 $90 = Math_fround($91 - $44);
 $92 = Math_fround($93 - $46);
 $94 = ((($manifoldContactExt) + ($27<<6)|0) + 32|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = ((($manifoldContactExt) + ($27<<6)|0) + 36|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = ((($manifoldContactExt) + ($27<<6)|0) + 40|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($90 * $99);
 $101 = Math_fround($92 * $97);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($92 * $95);
 $104 = Math_fround($88 * $99);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($88 * $97);
 $107 = Math_fround($90 * $95);
 $108 = Math_fround($106 - $107);
 $109 = Math_fround($102 * $102);
 $110 = Math_fround($105 * $105);
 $111 = Math_fround($109 + $110);
 $112 = Math_fround($108 * $108);
 $113 = Math_fround($112 + $111);
 $114 = (Math_fround(Math_sqrt((Math_fround($113)))));
 $115 = Math_fround(Math_fround(1.0) / $114);
 $116 = Math_fround($102 * $115);
 $117 = Math_fround($105 * $115);
 $118 = Math_fround($108 * $115);
 L20: do {
  if ($1) {
   $$lcssa484 = Math_fround(-3.40282346638528859812E+38);$$lcssa485 = Math_fround(3.40282346638528859812E+38);$index$6$lcssa = -1;$index1$0$lcssa = -1;
  } else {
   $122 = $34;$331 = Math_fround(3.40282346638528859812E+38);$332 = Math_fround(-3.40282346638528859812E+38);$currentPatch$2486 = $patch;$index$6488 = -1;$index1$0487 = -1;
   while(1) {
    $119 = (($currentPatch$2486) + 52|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = ($122>>>0)<($120>>>0);
    if ($121) {
     $141 = $332;$144 = $331;$i3$0475 = $122;$index$7476 = $index$6488;$index1$1474 = $index1$0487;
     while(1) {
      $123 = (($0) + ($i3$0475)|0);
      $124 = HEAP8[$123>>0]|0;
      $125 = ($124<<24>>24)==(0);
      if ($125) {
       $126 = ((($manifoldContactExt) + ($i3$0475<<6)|0) + 16|0);
       $127 = Math_fround(HEAPF32[$126>>2]);
       $128 = ((($manifoldContactExt) + ($i3$0475<<6)|0) + 20|0);
       $129 = Math_fround(HEAPF32[$128>>2]);
       $130 = ((($manifoldContactExt) + ($i3$0475<<6)|0) + 24|0);
       $131 = Math_fround(HEAPF32[$130>>2]);
       $132 = Math_fround($127 - $42);
       $133 = Math_fround($129 - $44);
       $134 = Math_fround($131 - $46);
       $135 = Math_fround($116 * $132);
       $136 = Math_fround($117 * $133);
       $137 = Math_fround($135 + $136);
       $138 = Math_fround($118 * $134);
       $139 = Math_fround($137 + $138);
       $140 = $139 > $141;
       $142 = $140 ? $139 : $141;
       $index$8 = $140 ? $i3$0475 : $index$7476;
       $143 = $144 > $139;
       if ($143) {
        $333 = $142;$334 = $139;$index$9 = $index$8;$index1$2 = $i3$0475;
       } else {
        $333 = $142;$334 = $144;$index$9 = $index$8;$index1$2 = $index1$1474;
       }
      } else {
       $333 = $141;$334 = $144;$index$9 = $index$7476;$index1$2 = $index1$1474;
      }
      $145 = (($i3$0475) + 1)|0;
      $146 = ($145>>>0)<($120>>>0);
      if ($146) {
       $141 = $333;$144 = $334;$i3$0475 = $145;$index$7476 = $index$9;$index1$1474 = $index1$2;
      } else {
       $$lcssa472 = $333;$$lcssa473 = $334;$index$7$lcssa = $index$9;$index1$1$lcssa = $index1$2;
       break;
      }
     }
    } else {
     $$lcssa472 = $332;$$lcssa473 = $331;$index$7$lcssa = $index$6488;$index1$1$lcssa = $index1$0487;
    }
    $147 = (($currentPatch$2486) + 16|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ($148|0)==(0|0);
    if ($149) {
     $$lcssa484 = $$lcssa472;$$lcssa485 = $$lcssa473;$index$6$lcssa = $index$7$lcssa;$index1$0$lcssa = $index1$1$lcssa;
     break L20;
    }
    $$phi$trans$insert575 = (($148) + 48|0);
    $$pre576 = HEAP32[$$phi$trans$insert575>>2]|0;
    $122 = $$pre576;$331 = $$lcssa473;$332 = $$lcssa472;$currentPatch$2486 = $148;$index$6488 = $index$7$lcssa;$index1$0487 = $index1$1$lcssa;
   }
  }
 } while(0);
 $150 = (($0) + ($index$6$lcssa)|0);
 HEAP8[$150>>0] = 1;
 $151 = (($clusters) + 64|0);
 HEAP32[$151>>2] = $index$6$lcssa;
 $152 = (($clusters) + 68|0);
 HEAP32[$152>>2] = $index$6$lcssa;
 $153 = ((($manifoldContactExt) + ($index$6$lcssa<<6)|0) + 44|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($clusters) + 80|0);
 HEAPF32[$155>>2] = $154;
 $156 = (($clusters) + 84|0);
 ;HEAP32[$156+0>>2]=HEAP32[$$sroa$1124+0>>2]|0;HEAP32[$156+4>>2]=HEAP32[$$sroa$1124+4>>2]|0;HEAP32[$156+8>>2]=HEAP32[$$sroa$1124+8>>2]|0;
 $157 = Math_fround($$lcssa484 * $$lcssa485);
 $$not = !($157 > Math_fround(0.0));
 $brmerge = $$not | $1;
 L33: do {
  if ($brmerge) {
   $index1$6 = $index1$0$lcssa;
  } else {
   $161 = $34;$335 = Math_fround(-3.40282346638528859812E+38);$currentPatch$3468 = $patch;$index1$3469 = $index1$0$lcssa;
   while(1) {
    $158 = (($currentPatch$3468) + 52|0);
    $159 = HEAP32[$158>>2]|0;
    $160 = ($161>>>0)<($159>>>0);
    if ($160) {
     $180 = $335;$i5$0461 = $161;$index1$4460 = $index1$3469;
     while(1) {
      $162 = (($0) + ($i5$0461)|0);
      $163 = HEAP8[$162>>0]|0;
      $164 = ($163<<24>>24)==(0);
      if ($164) {
       $165 = ((($manifoldContactExt) + ($i5$0461<<6)|0) + 16|0);
       $166 = Math_fround(HEAPF32[$165>>2]);
       $167 = ((($manifoldContactExt) + ($i5$0461<<6)|0) + 20|0);
       $168 = Math_fround(HEAPF32[$167>>2]);
       $169 = ((($manifoldContactExt) + ($i5$0461<<6)|0) + 24|0);
       $170 = Math_fround(HEAPF32[$169>>2]);
       $171 = Math_fround($166 - $42);
       $172 = Math_fround($168 - $44);
       $173 = Math_fround($170 - $46);
       $174 = Math_fround($116 * $171);
       $175 = Math_fround($117 * $172);
       $176 = Math_fround($174 + $175);
       $177 = Math_fround($118 * $173);
       $178 = Math_fround($176 + $177);
       $179 = $178 > $180;
       if ($179) {
        $336 = $178;$index1$5 = $i5$0461;
       } else {
        $336 = $180;$index1$5 = $index1$4460;
       }
      } else {
       $336 = $180;$index1$5 = $index1$4460;
      }
      $181 = (($i5$0461) + 1)|0;
      $182 = ($181>>>0)<($159>>>0);
      if ($182) {
       $180 = $336;$i5$0461 = $181;$index1$4460 = $index1$5;
      } else {
       $$lcssa459 = $336;$index1$4$lcssa = $index1$5;
       break;
      }
     }
    } else {
     $$lcssa459 = $335;$index1$4$lcssa = $index1$3469;
    }
    $183 = (($currentPatch$3468) + 16|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = ($184|0)==(0|0);
    if ($185) {
     $index1$6 = $index1$4$lcssa;
     break L33;
    }
    $$phi$trans$insert571 = (($184) + 48|0);
    $$pre572 = HEAP32[$$phi$trans$insert571>>2]|0;
    $161 = $$pre572;$335 = $$lcssa459;$currentPatch$3468 = $184;$index1$3469 = $index1$4$lcssa;
   }
  }
 } while(0);
 $186 = (($0) + ($index1$6)|0);
 HEAP8[$186>>0] = 1;
 $187 = (($clusters) + 96|0);
 HEAP32[$187>>2] = $index1$6;
 $188 = (($clusters) + 100|0);
 HEAP32[$188>>2] = $index1$6;
 $189 = ((($manifoldContactExt) + ($index1$6<<6)|0) + 44|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($clusters) + 112|0);
 HEAPF32[$191>>2] = $190;
 $192 = (($clusters) + 116|0);
 ;HEAP32[$192+0>>2]=HEAP32[$$sroa$1111+0>>2]|0;HEAP32[$192+4>>2]=HEAP32[$$sroa$1111+4>>2]|0;HEAP32[$192+8>>2]=HEAP32[$$sroa$1111+8>>2]|0;
 if ($1) {
  $257 = $27;$263 = $index$3$lcssa;$270 = $index$6$lcssa;$277 = $index1$6;
 } else {
  $196 = $34;$currentPatch$4455 = $patch;
  while(1) {
   $193 = (($currentPatch$4455) + 52|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = ($196>>>0)<($194>>>0);
   if ($195) {
    $$phi$trans$insert554 = ((($manifoldContactExt) + ($index$6$lcssa<<6)|0) + 16|0);
    $$pre555 = Math_fround(HEAPF32[$$phi$trans$insert554>>2]);
    $$phi$trans$insert556 = ((($manifoldContactExt) + ($index$6$lcssa<<6)|0) + 20|0);
    $$pre557 = Math_fround(HEAPF32[$$phi$trans$insert556>>2]);
    $$phi$trans$insert558 = ((($manifoldContactExt) + ($index$6$lcssa<<6)|0) + 24|0);
    $$pre559 = Math_fround(HEAPF32[$$phi$trans$insert558>>2]);
    $$phi$trans$insert560 = ((($manifoldContactExt) + ($index1$6<<6)|0) + 16|0);
    $$pre561 = Math_fround(HEAPF32[$$phi$trans$insert560>>2]);
    $$phi$trans$insert562 = ((($manifoldContactExt) + ($index1$6<<6)|0) + 20|0);
    $$pre563 = Math_fround(HEAPF32[$$phi$trans$insert562>>2]);
    $$phi$trans$insert564 = ((($manifoldContactExt) + ($index1$6<<6)|0) + 24|0);
    $$pre565 = Math_fround(HEAPF32[$$phi$trans$insert564>>2]);
    $337 = $194;$a$0453 = $196;
    while(1) {
     $197 = ((($manifoldContactExt) + ($a$0453<<6)|0) + 16|0);
     $198 = Math_fround(HEAPF32[$197>>2]);
     $199 = ((($manifoldContactExt) + ($a$0453<<6)|0) + 20|0);
     $200 = Math_fround(HEAPF32[$199>>2]);
     $201 = ((($manifoldContactExt) + ($a$0453<<6)|0) + 24|0);
     $202 = Math_fround(HEAPF32[$201>>2]);
     $203 = Math_fround($42 - $198);
     $204 = Math_fround($44 - $200);
     $205 = Math_fround($46 - $202);
     $206 = Math_fround($203 * $203);
     $207 = Math_fround($204 * $204);
     $208 = Math_fround($206 + $207);
     $209 = Math_fround($205 * $205);
     $210 = Math_fround($208 + $209);
     $211 = $210 < Math_fround(3.40282346638528859812E+38);
     $212 = $211 ? $210 : Math_fround(3.40282346638528859812E+38);
     $213 = Math_fround($89 - $198);
     $214 = Math_fround($91 - $200);
     $215 = Math_fround($93 - $202);
     $216 = Math_fround($213 * $213);
     $217 = Math_fround($214 * $214);
     $218 = Math_fround($216 + $217);
     $219 = Math_fround($215 * $215);
     $220 = Math_fround($218 + $219);
     $221 = $212 > $220;
     $222 = $221 ? $220 : $212;
     $closest$1$1 = $221&1;
     $223 = Math_fround($$pre555 - $198);
     $224 = Math_fround($$pre557 - $200);
     $225 = Math_fround($$pre559 - $202);
     $226 = Math_fround($223 * $223);
     $227 = Math_fround($224 * $224);
     $228 = Math_fround($226 + $227);
     $229 = Math_fround($225 * $225);
     $230 = Math_fround($228 + $229);
     $231 = $222 > $230;
     $232 = $231 ? $230 : $222;
     $closest$1$2 = $231 ? 2 : $closest$1$1;
     $233 = Math_fround($$pre561 - $198);
     $234 = Math_fround($$pre563 - $200);
     $235 = Math_fround($$pre565 - $202);
     $236 = Math_fround($233 * $233);
     $237 = Math_fround($234 * $234);
     $238 = Math_fround($236 + $237);
     $239 = Math_fround($235 * $235);
     $240 = Math_fround($238 + $239);
     $241 = $232 > $240;
     $closest$1$3 = $241 ? 3 : $closest$1$2;
     $242 = ((($clusters) + ($closest$1$3<<5)|0) + 16|0);
     $243 = Math_fround(HEAPF32[$242>>2]);
     $244 = ((($manifoldContactExt) + ($a$0453<<6)|0) + 44|0);
     $245 = Math_fround(HEAPF32[$244>>2]);
     $246 = $243 > $245;
     if ($246) {
      $247 = ((($clusters) + ($closest$1$3<<5)|0) + 20|0);
      HEAPF32[$242>>2] = $245;
      ;HEAP32[$247+0>>2]=HEAP32[$$sroa$196+0>>2]|0;HEAP32[$247+4>>2]=HEAP32[$$sroa$196+4>>2]|0;HEAP32[$247+8>>2]=HEAP32[$$sroa$196+8>>2]|0;
      $248 = (($clusters) + ($closest$1$3<<5)|0);
      HEAP32[$248>>2] = $a$0453;
      $$pre566 = HEAP32[$193>>2]|0;
      $251 = $$pre566;
     } else {
      $251 = $337;
     }
     $249 = (($a$0453) + 1)|0;
     $250 = ($249>>>0)<($251>>>0);
     if ($250) {
      $337 = $251;$a$0453 = $249;
     } else {
      break;
     }
    }
   }
   $252 = (($currentPatch$4455) + 16|0);
   $253 = HEAP32[$252>>2]|0;
   $254 = ($253|0)==(0|0);
   if ($254) {
    break;
   }
   $$phi$trans$insert573 = (($253) + 48|0);
   $$pre574 = HEAP32[$$phi$trans$insert573>>2]|0;
   $196 = $$pre574;$currentPatch$4455 = $253;
  }
  $$pre538 = HEAP32[$clusters>>2]|0;
  $$pre539 = HEAP32[$82>>2]|0;
  $$pre540 = HEAP32[$151>>2]|0;
  $$pre541 = HEAP32[$187>>2]|0;
  $257 = $$pre538;$263 = $$pre539;$270 = $$pre540;$277 = $$pre541;
 }
 $255 = (($agg$result) + 4|0);
 _memset(($0|0),0,($numContacts|0))|0;
 $256 = (($0) + ($257)|0);
 HEAP8[$256>>0] = 1;
 $258 = (($manifoldContactExt) + ($257<<6)|0);
 dest=$this+0|0; src=$258+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $259 = ((($manifoldContactExt) + ($257<<6)|0) + 44|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = $260 < Math_fround(3.40282346638528859812E+38);
 $$$i10 = $261 ? $260 : Math_fround(3.40282346638528859812E+38);
 $262 = (($0) + ($263)|0);
 HEAP8[$262>>0] = 1;
 $264 = (($this) + 64|0);
 $265 = (($manifoldContactExt) + ($263<<6)|0);
 dest=$264+0|0; src=$265+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $266 = ((($manifoldContactExt) + ($263<<6)|0) + 44|0);
 $267 = Math_fround(HEAPF32[$266>>2]);
 $268 = $$$i10 > $267;
 $$$i10$1 = $268 ? $267 : $$$i10;
 $269 = (($0) + ($270)|0);
 HEAP8[$269>>0] = 1;
 $271 = (($this) + 128|0);
 $272 = (($manifoldContactExt) + ($270<<6)|0);
 dest=$271+0|0; src=$272+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $273 = ((($manifoldContactExt) + ($270<<6)|0) + 44|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 $275 = $$$i10$1 > $274;
 $$$i10$2 = $275 ? $274 : $$$i10$1;
 $276 = (($0) + ($277)|0);
 HEAP8[$276>>0] = 1;
 $278 = (($this) + 192|0);
 $279 = (($manifoldContactExt) + ($277<<6)|0);
 dest=$278+0|0; src=$279+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $280 = ((($manifoldContactExt) + ($277<<6)|0) + 44|0);
 $281 = Math_fround(HEAPF32[$280>>2]);
 $282 = $$$i10$2 > $281;
 $$$i10$3 = $282 ? $281 : $$$i10$2;
 ;HEAP32[$255+0>>2]=HEAP32[$$sroa$194+0>>2]|0;HEAP32[$255+4>>2]=HEAP32[$$sroa$194+4>>2]|0;HEAP32[$255+8>>2]=HEAP32[$$sroa$194+8>>2]|0;
 HEAPF32[$agg$result>>2] = $$$i10$3;
 if ($1) {
  $325 = (($this) + 256|0);
  $326 = (($manifoldContactExt) + ($index$6$lcssa<<6)|0);
  dest=$325+0|0; src=$326+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $327 = $$$i10$3 > Math_fround(3.40282346638528859812E+38);
  $$$i$us = $327 ? Math_fround(3.40282346638528859812E+38) : $$$i10$3;
  $328 = (($this) + 320|0);
  dest=$328+0|0; src=$326+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  ;HEAP32[$255+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$255+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$255+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
  HEAP8[$150>>0] = 1;
  $$$i$lcssa = $$$i$us;
  HEAPF32[$agg$result>>2] = $$$i$lcssa;
  STACKTOP = sp;return;
 } else {
  $338 = Math_fround(3.40282346638528859812E+38);$currentPatch$5437 = $patch;$index$11438 = $index$6$lcssa;
 }
 while(1) {
  $283 = (($currentPatch$5437) + 48|0);
  $284 = HEAP32[$283>>2]|0;
  $285 = (($currentPatch$5437) + 52|0);
  $286 = HEAP32[$285>>2]|0;
  $287 = ($284>>>0)<($286>>>0);
  if ($287) {
   $294 = $338;$i10$0433 = $284;$index$12434 = $index$11438;
   while(1) {
    $288 = (($0) + ($i10$0433)|0);
    $289 = HEAP8[$288>>0]|0;
    $290 = ($289<<24>>24)==(0);
    if ($290) {
     $291 = ((($manifoldContactExt) + ($i10$0433<<6)|0) + 44|0);
     $292 = Math_fround(HEAPF32[$291>>2]);
     $293 = $294 > $292;
     if ($293) {
      $339 = $292;$index$13 = $i10$0433;
     } else {
      $339 = $294;$index$13 = $index$12434;
     }
    } else {
     $339 = $294;$index$13 = $index$12434;
    }
    $295 = (($i10$0433) + 1)|0;
    $296 = ($295>>>0)<($286>>>0);
    if ($296) {
     $294 = $339;$i10$0433 = $295;$index$12434 = $index$13;
    } else {
     $$lcssa = $339;$index$12$lcssa = $index$13;
     break;
    }
   }
  } else {
   $$lcssa = $338;$index$12$lcssa = $index$11438;
  }
  $297 = (($currentPatch$5437) + 16|0);
  $298 = HEAP32[$297>>2]|0;
  $299 = ($298|0)==(0|0);
  if ($299) {
   break;
  } else {
   $338 = $$lcssa;$currentPatch$5437 = $298;$index$11438 = $index$12$lcssa;
  }
 }
 $300 = (($this) + 256|0);
 $301 = (($manifoldContactExt) + ($index$12$lcssa<<6)|0);
 dest=$300+0|0; src=$301+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $302 = $$$i10$3 > $$lcssa;
 $$$i = $302 ? $$lcssa : $$$i10$3;
 ;HEAP32[$255+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$255+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$255+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 $303 = (($0) + ($index$12$lcssa)|0);
 HEAP8[$303>>0] = 1;
 $340 = Math_fround(3.40282346638528859812E+38);$currentPatch$5437$1 = $patch;$index$11438$1 = $index$12$lcssa;
 while(1) {
  $304 = (($currentPatch$5437$1) + 48|0);
  $305 = HEAP32[$304>>2]|0;
  $306 = (($currentPatch$5437$1) + 52|0);
  $307 = HEAP32[$306>>2]|0;
  $308 = ($305>>>0)<($307>>>0);
  if ($308) {
   $315 = $340;$i10$0433$1 = $305;$index$12434$1 = $index$11438$1;
   while(1) {
    $309 = (($0) + ($i10$0433$1)|0);
    $310 = HEAP8[$309>>0]|0;
    $311 = ($310<<24>>24)==(0);
    if ($311) {
     $312 = ((($manifoldContactExt) + ($i10$0433$1<<6)|0) + 44|0);
     $313 = Math_fround(HEAPF32[$312>>2]);
     $314 = $315 > $313;
     if ($314) {
      $341 = $313;$index$13$1 = $i10$0433$1;
     } else {
      $341 = $315;$index$13$1 = $index$12434$1;
     }
    } else {
     $341 = $315;$index$13$1 = $index$12434$1;
    }
    $316 = (($i10$0433$1) + 1)|0;
    $317 = ($316>>>0)<($307>>>0);
    if ($317) {
     $315 = $341;$i10$0433$1 = $316;$index$12434$1 = $index$13$1;
    } else {
     $$lcssa$1 = $341;$index$12$lcssa$1 = $index$13$1;
     break;
    }
   }
  } else {
   $$lcssa$1 = $340;$index$12$lcssa$1 = $index$11438$1;
  }
  $318 = (($currentPatch$5437$1) + 16|0);
  $319 = HEAP32[$318>>2]|0;
  $320 = ($319|0)==(0|0);
  if ($320) {
   break;
  } else {
   $340 = $$lcssa$1;$currentPatch$5437$1 = $319;$index$11438$1 = $index$12$lcssa$1;
  }
 }
 $321 = (($this) + 320|0);
 $322 = (($manifoldContactExt) + ($index$12$lcssa$1<<6)|0);
 dest=$321+0|0; src=$322+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $323 = $$$i > $$lcssa$1;
 $$$i$1 = $323 ? $$lcssa$1 : $$$i;
 ;HEAP32[$255+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$255+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$255+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
 $324 = (($0) + ($index$12$lcssa$1)|0);
 HEAP8[$324>>0] = 1;
 $$$i$lcssa = $$$i$1;
 HEAPF32[$agg$result>>2] = $$$i$lcssa;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu31SinglePersistentContactManifold26reduceBatchContactsCapsuleEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($agg$result,$this,$manifoldContactExt,$numContacts,$patch) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $manifoldContactExt = $manifoldContactExt|0;
 $numContacts = $numContacts|0;
 $patch = $patch|0;
 var $$$i = Math_fround(0), $$$i12 = Math_fround(0), $$$i35 = Math_fround(0), $$lcssa = Math_fround(0), $$lcssa177 = Math_fround(0), $$lcssa191 = Math_fround(0), $$phi$trans$insert = 0, $$pre = 0, $$sroa$141 = 0, $$sroa$149 = 0, $$sroa$177 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0);
 var $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $currentPatch$0200 = 0, $currentPatch$1186 = 0, $currentPatch$2172 = 0, $i$0193 = 0, $i1$0179 = 0, $i2$0169 = 0;
 var $index$0$lcssa = 0, $index$0199 = 0, $index$1$lcssa = 0, $index$1192 = 0, $index$2 = 0, $index$3$lcssa = 0, $index$3185 = 0, $index$4$lcssa = 0, $index$4178 = 0, $index$5 = 0, $index$6$lcssa = 0, $index$6171 = 0, $index$7$lcssa = 0, $index$7168 = 0, $index$8 = 0, $max$sroa$1 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $max$sroa$1 = sp + 36|0;
 $$sroa$177 = sp;
 $$sroa$149 = sp + 12|0;
 $$sroa$141 = sp + 24|0;
 $0 = STACKTOP; STACKTOP = STACKTOP + ((((1*$numContacts)|0)+15)&-16)|0;;
 _memset(($0|0),0,($numContacts|0))|0;
 HEAPF32[$agg$result>>2] = Math_fround(3.40282346638528859812E+38);
 $1 = (($agg$result) + 4|0);
 ;HEAP32[$1+0>>2]=HEAP32[$max$sroa$1+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$max$sroa$1+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$max$sroa$1+8>>2]|0;
 $2 = ($patch|0)==(0|0);
 if ($2) {
  $index$0$lcssa = -1;
 } else {
  $99 = Math_fround(3.40282346638528859812E+38);$currentPatch$0200 = $patch;$index$0199 = -1;
  while(1) {
   $3 = (($currentPatch$0200) + 48|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($currentPatch$0200) + 52|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   if ($7) {
    $11 = $99;$i$0193 = $4;$index$1192 = $index$0199;
    while(1) {
     $8 = ((($manifoldContactExt) + ($i$0193<<6)|0) + 44|0);
     $9 = Math_fround(HEAPF32[$8>>2]);
     $10 = $11 > $9;
     $12 = $10 ? $9 : $11;
     $index$2 = $10 ? $i$0193 : $index$1192;
     $13 = (($i$0193) + 1)|0;
     $14 = ($13>>>0)<($6>>>0);
     if ($14) {
      $11 = $12;$i$0193 = $13;$index$1192 = $index$2;
     } else {
      $$lcssa191 = $12;$index$1$lcssa = $index$2;
      break;
     }
    }
   } else {
    $$lcssa191 = $99;$index$1$lcssa = $index$0199;
   }
   $15 = (($currentPatch$0200) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $index$0$lcssa = $index$1$lcssa;
    break;
   } else {
    $99 = $$lcssa191;$currentPatch$0200 = $16;$index$0199 = $index$1$lcssa;
   }
  }
 }
 $18 = (($0) + ($index$0$lcssa)|0);
 HEAP8[$18>>0] = 1;
 $19 = (($manifoldContactExt) + ($index$0$lcssa<<6)|0);
 dest=$this+0|0; src=$19+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $20 = ((($manifoldContactExt) + ($index$0$lcssa<<6)|0) + 44|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = $21 < Math_fround(3.40282346638528859812E+38);
 $$$i35 = $22 ? $21 : Math_fround(3.40282346638528859812E+38);
 HEAPF32[$agg$result>>2] = $$$i35;
 ;HEAP32[$1+0>>2]=HEAP32[$$sroa$177+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$sroa$177+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$sroa$177+8>>2]|0;
 $23 = (($patch) + 48|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($manifoldContactExt) + ($24<<6)|0) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = ((($manifoldContactExt) + ($24<<6)|0) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = ((($manifoldContactExt) + ($24<<6)|0) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($this) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 20|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($this) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($26 - $32);
 $38 = Math_fround($28 - $34);
 $39 = Math_fround($30 - $36);
 L9: do {
  if ($2) {
   $index$3$lcssa = $24;
  } else {
   $40 = Math_fround($38 * $38);
   $41 = Math_fround($37 * $37);
   $42 = Math_fround($39 * $39);
   $43 = Math_fround($41 + $40);
   $44 = Math_fround($43 + $42);
   $100 = $44;$48 = $24;$currentPatch$1186 = $patch;$index$3185 = $24;
   while(1) {
    $45 = (($currentPatch$1186) + 52|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($48>>>0)<($46>>>0);
    if ($47) {
     $64 = $100;$i1$0179 = $48;$index$4178 = $index$3185;
     while(1) {
      $49 = ((($manifoldContactExt) + ($i1$0179<<6)|0) + 16|0);
      $50 = Math_fround(HEAPF32[$49>>2]);
      $51 = ((($manifoldContactExt) + ($i1$0179<<6)|0) + 20|0);
      $52 = Math_fround(HEAPF32[$51>>2]);
      $53 = ((($manifoldContactExt) + ($i1$0179<<6)|0) + 24|0);
      $54 = Math_fround(HEAPF32[$53>>2]);
      $55 = Math_fround($50 - $32);
      $56 = Math_fround($52 - $34);
      $57 = Math_fround($54 - $36);
      $58 = Math_fround($55 * $55);
      $59 = Math_fround($56 * $56);
      $60 = Math_fround($58 + $59);
      $61 = Math_fround($57 * $57);
      $62 = Math_fround($60 + $61);
      $63 = $62 > $64;
      $65 = $63 ? $62 : $64;
      $index$5 = $63 ? $i1$0179 : $index$4178;
      $66 = (($i1$0179) + 1)|0;
      $67 = ($66>>>0)<($46>>>0);
      if ($67) {
       $64 = $65;$i1$0179 = $66;$index$4178 = $index$5;
      } else {
       $$lcssa177 = $65;$index$4$lcssa = $index$5;
       break;
      }
     }
    } else {
     $$lcssa177 = $100;$index$4$lcssa = $index$3185;
    }
    $68 = (($currentPatch$1186) + 16|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(0|0);
    if ($70) {
     $index$3$lcssa = $index$4$lcssa;
     break L9;
    }
    $$phi$trans$insert = (($69) + 48|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $100 = $$lcssa177;$48 = $$pre;$currentPatch$1186 = $69;$index$3185 = $index$4$lcssa;
   }
  }
 } while(0);
 $71 = (($0) + ($index$3$lcssa)|0);
 HEAP8[$71>>0] = 1;
 $72 = (($this) + 64|0);
 $73 = (($manifoldContactExt) + ($index$3$lcssa<<6)|0);
 dest=$72+0|0; src=$73+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $74 = ((($manifoldContactExt) + ($index$3$lcssa<<6)|0) + 44|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = $$$i35 > $75;
 $$$i12 = $76 ? $75 : $$$i35;
 HEAPF32[$agg$result>>2] = $$$i12;
 ;HEAP32[$1+0>>2]=HEAP32[$$sroa$149+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$sroa$149+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$sroa$149+8>>2]|0;
 if ($2) {
  $index$6$lcssa = $index$3$lcssa;
  $94 = (($this) + 128|0);
  $95 = (($manifoldContactExt) + ($index$6$lcssa<<6)|0);
  dest=$94+0|0; src=$95+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $96 = ((($manifoldContactExt) + ($index$6$lcssa<<6)|0) + 44|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = $$$i12 > $97;
  $$$i = $98 ? $97 : $$$i12;
  HEAPF32[$agg$result>>2] = $$$i;
  ;HEAP32[$1+0>>2]=HEAP32[$$sroa$141+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$sroa$141+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$sroa$141+8>>2]|0;
  STACKTOP = sp;return;
 } else {
  $101 = Math_fround(3.40282346638528859812E+38);$currentPatch$2172 = $patch;$index$6171 = $index$3$lcssa;
 }
 while(1) {
  $77 = (($currentPatch$2172) + 48|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($currentPatch$2172) + 52|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($78>>>0)<($80>>>0);
  if ($81) {
   $88 = $101;$i2$0169 = $78;$index$7168 = $index$6171;
   while(1) {
    $82 = (($0) + ($i2$0169)|0);
    $83 = HEAP8[$82>>0]|0;
    $84 = ($83<<24>>24)==(0);
    if ($84) {
     $85 = ((($manifoldContactExt) + ($i2$0169<<6)|0) + 44|0);
     $86 = Math_fround(HEAPF32[$85>>2]);
     $87 = $88 > $86;
     if ($87) {
      $102 = $86;$index$8 = $i2$0169;
     } else {
      $102 = $88;$index$8 = $index$7168;
     }
    } else {
     $102 = $88;$index$8 = $index$7168;
    }
    $89 = (($i2$0169) + 1)|0;
    $90 = ($89>>>0)<($80>>>0);
    if ($90) {
     $88 = $102;$i2$0169 = $89;$index$7168 = $index$8;
    } else {
     $$lcssa = $102;$index$7$lcssa = $index$8;
     break;
    }
   }
  } else {
   $$lcssa = $101;$index$7$lcssa = $index$6171;
  }
  $91 = (($currentPatch$2172) + 16|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92|0)==(0|0);
  if ($93) {
   $index$6$lcssa = $index$7$lcssa;
   break;
  } else {
   $101 = $$lcssa;$currentPatch$2172 = $92;$index$6171 = $index$7$lcssa;
  }
 }
 $94 = (($this) + 128|0);
 $95 = (($manifoldContactExt) + ($index$6$lcssa<<6)|0);
 dest=$94+0|0; src=$95+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $96 = ((($manifoldContactExt) + ($index$6$lcssa<<6)|0) + 44|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = $$$i12 > $97;
 $$$i = $98 ? $97 : $$$i12;
 HEAPF32[$agg$result>>2] = $$$i;
 ;HEAP32[$1+0>>2]=HEAP32[$$sroa$141+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$sroa$141+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$sroa$141+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu31SinglePersistentContactManifold14reduceContactsEPNS0_21MeshPersistentContactEj($manifoldPoints,$numPoints) {
 $manifoldPoints = $manifoldPoints|0;
 $numPoints = $numPoints|0;
 var $$lcssa = Math_fround(0), $$lcssa294 = Math_fround(0), $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = Math_fround(0);
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0;
 var $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $brmerge = 0, $exitcond = 0, $exitcond317 = 0, $exitcond318 = 0, $exitcond319 = 0, $i$0310 = 0, $i1$0303 = 0, $i2$0296 = 0, $i4$0293 = 0, $index$0$lcssa = 0, $index$0311 = 0, $index$1 = 0, $index$2$lcssa = 0, $index$2304 = 0, $index$3 = 0, $index$4$lcssa = 0;
 var $index$4297 = 0, $index$5 = 0, $index$6 = 0, $index1$0$lcssa = 0, $index1$0295 = 0, $index1$1 = 0, $index1$2292 = 0, $index1$3 = 0, $index1$4 = 0, $newManifold = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $newManifold = sp;
 $0 = STACKTOP; STACKTOP = STACKTOP + ((((1*$numPoints)|0)+15)&-16)|0;;
 _memset(($0|0),0,($numPoints|0))|0;
 $1 = ($numPoints|0)==(0);
 if ($1) {
  $index$0$lcssa = -1;
 } else {
  $5 = Math_fround(3.40282346638528859812E+38);$i$0310 = 0;$index$0311 = -1;
  while(1) {
   $2 = ((($manifoldPoints) + ($i$0310<<6)|0) + 44|0);
   $3 = Math_fround(HEAPF32[$2>>2]);
   $4 = $5 > $3;
   $6 = $4 ? $3 : $5;
   $index$1 = $4 ? $i$0310 : $index$0311;
   $7 = (($i$0310) + 1)|0;
   $exitcond319 = ($7|0)==($numPoints|0);
   if ($exitcond319) {
    $index$0$lcssa = $index$1;
    break;
   } else {
    $5 = $6;$i$0310 = $7;$index$0311 = $index$1;
   }
  }
 }
 $8 = (($manifoldPoints) + ($index$0$lcssa<<6)|0);
 dest=$newManifold+0|0; src=$8+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $9 = (($0) + ($index$0$lcssa)|0);
 HEAP8[$9>>0] = 1;
 $10 = (($manifoldPoints) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($manifoldPoints) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($manifoldPoints) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($newManifold) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($newManifold) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($newManifold) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($11 - $17);
 $23 = Math_fround($13 - $19);
 $24 = Math_fround($15 - $21);
 $25 = ($numPoints>>>0)>(1);
 if ($25) {
  $26 = Math_fround($23 * $23);
  $27 = Math_fround($22 * $22);
  $28 = Math_fround($24 * $24);
  $29 = Math_fround($27 + $26);
  $30 = Math_fround($29 + $28);
  $46 = $30;$i1$0303 = 1;$index$2304 = 0;
  while(1) {
   $31 = ((($manifoldPoints) + ($i1$0303<<6)|0) + 16|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = ((($manifoldPoints) + ($i1$0303<<6)|0) + 20|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = ((($manifoldPoints) + ($i1$0303<<6)|0) + 24|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = Math_fround($32 - $17);
   $38 = Math_fround($34 - $19);
   $39 = Math_fround($36 - $21);
   $40 = Math_fround($37 * $37);
   $41 = Math_fround($38 * $38);
   $42 = Math_fround($40 + $41);
   $43 = Math_fround($39 * $39);
   $44 = Math_fround($42 + $43);
   $45 = $44 > $46;
   $47 = $45 ? $44 : $46;
   $index$3 = $45 ? $i1$0303 : $index$2304;
   $48 = (($i1$0303) + 1)|0;
   $exitcond318 = ($48|0)==($numPoints|0);
   if ($exitcond318) {
    $index$2$lcssa = $index$3;
    break;
   } else {
    $46 = $47;$i1$0303 = $48;$index$2304 = $index$3;
   }
  }
 } else {
  $index$2$lcssa = 0;
 }
 $49 = (($newManifold) + 64|0);
 $50 = (($manifoldPoints) + ($index$2$lcssa<<6)|0);
 dest=$49+0|0; src=$50+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $51 = (($0) + ($index$2$lcssa)|0);
 HEAP8[$51>>0] = 1;
 $52 = (($newManifold) + 80|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($newManifold) + 84|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($newManifold) + 88|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($53 - $17);
 $59 = Math_fround($55 - $19);
 $60 = Math_fround($57 - $21);
 $61 = (($newManifold) + 32|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($newManifold) + 36|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($newManifold) + 40|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($59 * $66);
 $68 = Math_fround($60 * $64);
 $69 = Math_fround($67 - $68);
 $70 = Math_fround($60 * $62);
 $71 = Math_fround($58 * $66);
 $72 = Math_fround($70 - $71);
 $73 = Math_fround($58 * $64);
 $74 = Math_fround($59 * $62);
 $75 = Math_fround($73 - $74);
 $76 = Math_fround($69 * $69);
 $77 = Math_fround($72 * $72);
 $78 = Math_fround($76 + $77);
 $79 = Math_fround($75 * $75);
 $80 = Math_fround($79 + $78);
 $81 = (Math_fround(Math_sqrt((Math_fround($80)))));
 $82 = Math_fround(Math_fround(1.0) / $81);
 $83 = Math_fround($69 * $82);
 $84 = Math_fround($72 * $82);
 $85 = Math_fround($75 * $82);
 if ($1) {
  $$lcssa = Math_fround(-3.40282346638528859812E+38);$$lcssa294 = Math_fround(3.40282346638528859812E+38);$index$4$lcssa = -1;$index1$0$lcssa = -1;
 } else {
  $104 = Math_fround(-3.40282346638528859812E+38);$107 = Math_fround(3.40282346638528859812E+38);$i2$0296 = 0;$index$4297 = -1;$index1$0295 = -1;
  while(1) {
   $86 = (($0) + ($i2$0296)|0);
   $87 = HEAP8[$86>>0]|0;
   $88 = ($87<<24>>24)==(0);
   if ($88) {
    $89 = ((($manifoldPoints) + ($i2$0296<<6)|0) + 16|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = ((($manifoldPoints) + ($i2$0296<<6)|0) + 20|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = ((($manifoldPoints) + ($i2$0296<<6)|0) + 24|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $95 = Math_fround($90 - $17);
    $96 = Math_fround($92 - $19);
    $97 = Math_fround($94 - $21);
    $98 = Math_fround($83 * $95);
    $99 = Math_fround($84 * $96);
    $100 = Math_fround($98 + $99);
    $101 = Math_fround($85 * $97);
    $102 = Math_fround($100 + $101);
    $103 = $102 > $104;
    $105 = $103 ? $102 : $104;
    $index$5 = $103 ? $i2$0296 : $index$4297;
    $106 = $107 > $102;
    if ($106) {
     $138 = $105;$139 = $102;$index$6 = $index$5;$index1$1 = $i2$0296;
    } else {
     $138 = $105;$139 = $107;$index$6 = $index$5;$index1$1 = $index1$0295;
    }
   } else {
    $138 = $104;$139 = $107;$index$6 = $index$4297;$index1$1 = $index1$0295;
   }
   $108 = (($i2$0296) + 1)|0;
   $exitcond317 = ($108|0)==($numPoints|0);
   if ($exitcond317) {
    $$lcssa = $138;$$lcssa294 = $139;$index$4$lcssa = $index$6;$index1$0$lcssa = $index1$1;
    break;
   } else {
    $104 = $138;$107 = $139;$i2$0296 = $108;$index$4297 = $index$6;$index1$0295 = $index1$1;
   }
  }
 }
 $109 = (($0) + ($index$4$lcssa)|0);
 HEAP8[$109>>0] = 1;
 $110 = (($newManifold) + 128|0);
 $111 = (($manifoldPoints) + ($index$4$lcssa<<6)|0);
 dest=$110+0|0; src=$111+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $112 = Math_fround($$lcssa * $$lcssa294);
 $$not = !($112 > Math_fround(0.0));
 $brmerge = $$not | $1;
 if ($brmerge) {
  $index1$4 = $index1$0$lcssa;
  $133 = (($newManifold) + 192|0);
  $134 = (($manifoldPoints) + ($index1$4<<6)|0);
  dest=$133+0|0; src=$134+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$manifoldPoints+0|0; src=$newManifold+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $135 = (($manifoldPoints) + 64|0);
  dest=$135+0|0; src=$49+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $136 = (($manifoldPoints) + 128|0);
  dest=$136+0|0; src=$110+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $137 = (($manifoldPoints) + 192|0);
  dest=$137+0|0; src=$133+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return 4;
 } else {
  $131 = Math_fround(-3.40282346638528859812E+38);$i4$0293 = 0;$index1$2292 = $index1$0$lcssa;
 }
 while(1) {
  $113 = (($0) + ($i4$0293)|0);
  $114 = HEAP8[$113>>0]|0;
  $115 = ($114<<24>>24)==(0);
  if ($115) {
   $116 = ((($manifoldPoints) + ($i4$0293<<6)|0) + 16|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = ((($manifoldPoints) + ($i4$0293<<6)|0) + 20|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = ((($manifoldPoints) + ($i4$0293<<6)|0) + 24|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = Math_fround($117 - $17);
   $123 = Math_fround($119 - $19);
   $124 = Math_fround($121 - $21);
   $125 = Math_fround($83 * $122);
   $126 = Math_fround($84 * $123);
   $127 = Math_fround($125 + $126);
   $128 = Math_fround($85 * $124);
   $129 = Math_fround($127 + $128);
   $130 = $129 > $131;
   if ($130) {
    $140 = $129;$index1$3 = $i4$0293;
   } else {
    $140 = $131;$index1$3 = $index1$2292;
   }
  } else {
   $140 = $131;$index1$3 = $index1$2292;
  }
  $132 = (($i4$0293) + 1)|0;
  $exitcond = ($132|0)==($numPoints|0);
  if ($exitcond) {
   $index1$4 = $index1$3;
   break;
  } else {
   $131 = $140;$i4$0293 = $132;$index1$2292 = $index1$3;
  }
 }
 $133 = (($newManifold) + 192|0);
 $134 = (($manifoldPoints) + ($index1$4<<6)|0);
 dest=$133+0|0; src=$134+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$manifoldPoints+0|0; src=$newManifold+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $135 = (($manifoldPoints) + 64|0);
 dest=$135+0|0; src=$49+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $136 = (($manifoldPoints) + 128|0);
 dest=$136+0|0; src=$110+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $137 = (($manifoldPoints) + 192|0);
 dest=$137+0|0; src=$133+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return 4;
}
function __ZN5physx2Gu31SinglePersistentContactManifold20refreshContactPointsERKNS_6shdfnd3aos15PsMatTransformVERKNS3_6FloatVES9_($agg$result,$this,$aToB,$projectBreakingThreshold,$0) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $aToB = $aToB|0;
 $projectBreakingThreshold = $projectBreakingThreshold|0;
 $0 = $0|0;
 var $$$i = Math_fround(0), $$sroa$1 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0);
 var $i$0188 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$sroa$1 = sp;
 $1 = Math_fround(HEAPF32[$projectBreakingThreshold>>2]);
 $2 = Math_fround($1 * $1);
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $3 = (($this) + 384|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($aToB) + 48|0);
 $7 = (($aToB) + 52|0);
 $8 = (($aToB) + 56|0);
 $9 = (($aToB) + 16|0);
 $10 = (($aToB) + 32|0);
 $11 = (($aToB) + 4|0);
 $12 = (($aToB) + 20|0);
 $13 = (($aToB) + 36|0);
 $14 = (($aToB) + 8|0);
 $15 = (($aToB) + 24|0);
 $16 = (($aToB) + 40|0);
 $17 = (($agg$result) + 4|0);
 $97 = Math_fround(0.0);$i$0188 = $4;
 while(1) {
  $18 = (($i$0188) + -1)|0;
  $19 = Math_fround(HEAPF32[$6>>2]);
  $20 = Math_fround(HEAPF32[$7>>2]);
  $21 = Math_fround(HEAPF32[$8>>2]);
  $22 = (($this) + ($18<<6)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = ((($this) + ($18<<6)|0) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = ((($this) + ($18<<6)|0) + 8|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround(HEAPF32[$aToB>>2]);
  $29 = Math_fround($23 * $28);
  $30 = Math_fround(HEAPF32[$9>>2]);
  $31 = Math_fround($25 * $30);
  $32 = Math_fround($29 + $31);
  $33 = Math_fround(HEAPF32[$10>>2]);
  $34 = Math_fround($27 * $33);
  $35 = Math_fround($32 + $34);
  $36 = Math_fround(HEAPF32[$11>>2]);
  $37 = Math_fround($23 * $36);
  $38 = Math_fround(HEAPF32[$12>>2]);
  $39 = Math_fround($25 * $38);
  $40 = Math_fround($37 + $39);
  $41 = Math_fround(HEAPF32[$13>>2]);
  $42 = Math_fround($27 * $41);
  $43 = Math_fround($40 + $42);
  $44 = Math_fround(HEAPF32[$14>>2]);
  $45 = Math_fround($23 * $44);
  $46 = Math_fround(HEAPF32[$15>>2]);
  $47 = Math_fround($25 * $46);
  $48 = Math_fround($45 + $47);
  $49 = Math_fround(HEAPF32[$16>>2]);
  $50 = Math_fround($27 * $49);
  $51 = Math_fround($48 + $50);
  $52 = Math_fround($19 + $35);
  $53 = Math_fround($20 + $43);
  $54 = Math_fround($21 + $51);
  $55 = ((($this) + ($18<<6)|0) + 16|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = ((($this) + ($18<<6)|0) + 20|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = ((($this) + ($18<<6)|0) + 24|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($52 - $56);
  $62 = Math_fround($53 - $58);
  $63 = Math_fround($54 - $60);
  $64 = ((($this) + ($18<<6)|0) + 32|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($this) + ($18<<6)|0) + 36|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($this) + ($18<<6)|0) + 40|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($61 * $65);
  $71 = Math_fround($62 * $67);
  $72 = Math_fround($70 + $71);
  $73 = Math_fround($63 * $69);
  $74 = Math_fround($72 + $73);
  $75 = Math_fround($65 * $74);
  $76 = Math_fround($67 * $74);
  $77 = Math_fround($69 * $74);
  $78 = Math_fround($52 - $75);
  $79 = Math_fround($53 - $76);
  $80 = Math_fround($54 - $77);
  $81 = Math_fround($56 - $78);
  $82 = Math_fround($58 - $79);
  $83 = Math_fround($60 - $80);
  $84 = Math_fround($81 * $81);
  $85 = Math_fround($82 * $82);
  $86 = Math_fround($84 + $85);
  $87 = Math_fround($83 * $83);
  $88 = Math_fround($87 + $86);
  $89 = $88 > $2;
  if ($89) {
   $90 = HEAP32[$3>>2]|0;
   $91 = (($90) + -1)|0;
   HEAP32[$3>>2] = $91;
   $92 = (($this) + ($18<<6)|0);
   $93 = (($this) + ($91<<6)|0);
   dest=$92+0|0; src=$93+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $98 = $97;
  } else {
   $95 = ((($this) + ($18<<6)|0) + 44|0);
   HEAPF32[$64>>2] = $65;
   HEAPF32[$66>>2] = $67;
   HEAPF32[$68>>2] = $69;
   HEAPF32[$95>>2] = $74;
   $96 = $97 > $74;
   $$$i = $96 ? $74 : $97;
   HEAPF32[$agg$result>>2] = $$$i;
   ;HEAP32[$17+0>>2]=HEAP32[$$sroa$1+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$$sroa$1+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$$sroa$1+8>>2]|0;
   $98 = $$$i;
  }
  $94 = ($18|0)==(0);
  if ($94) {
   break;
  } else {
   $97 = $98;$i$0188 = $18;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx2Gu33MultiplePersistentContactManifold24addManifoldContactPointsEPNS0_21MeshPersistentContactEjPPNS0_15PCMContactPatchEjRKNS_6shdfnd3aos6FloatVESB_h($this,$manifoldContact,$numManifoldContacts,$contactPatch,$numPatch,$sqReplaceBreakingThreshold,$acceptanceEpsilon,$maxContactsPerManifold) {
 $this = $this|0;
 $manifoldContact = $manifoldContact|0;
 $numManifoldContacts = $numManifoldContacts|0;
 $contactPatch = $contactPatch|0;
 $numPatch = $numPatch|0;
 $sqReplaceBreakingThreshold = $sqReplaceBreakingThreshold|0;
 $acceptanceEpsilon = $acceptanceEpsilon|0;
 $maxContactsPerManifold = $maxContactsPerManifold|0;
 var $$$i = Math_fround(0), $$lcssa$i = Math_fround(0), $$lcssa40$i = Math_fround(0), $$lcssa41$i = Math_fround(0), $$sroa$1138 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0;
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0);
 var $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $_maxPen = 0, $_maxPen4 = 0, $_maxPen6 = 0, $_maxPen9 = 0, $currentPatch$011$i$i$i = 0, $currentPatch$011$i$i$i4 = 0, $currentPatch$011$i$i$i52 = 0, $currentPatch$011$i$i$i97 = 0, $currentPatch$03$i = 0, $currentPatch$03$i111 = 0, $currentPatch$03$i121 = 0, $currentPatch$03$i18 = 0, $currentPatch$03$i30 = 0, $currentPatch$03$i39 = 0, $currentPatch$03$i66 = 0, $currentPatch$03$i82 = 0, $exitcond = 0, $exitcond$i$i = 0;
 var $exitcond$i$i104 = 0, $exitcond$i$i11 = 0, $exitcond$i$i59 = 0, $i$0181 = 0, $i$042$i = 0, $i$09$i$i$i = 0, $i$09$i$i$i100 = 0, $i$09$i$i$i55 = 0, $i$09$i$i$i7 = 0, $i1$0217 = 0, $index$0$lcssa$i$i$i = 0, $index$0$lcssa$i$i$i107 = 0, $index$0$lcssa$i$i$i14 = 0, $index$0$lcssa$i$i$i62 = 0, $index$010$i$i$i = 0, $index$010$i$i$i5 = 0, $index$010$i$i$i53 = 0, $index$010$i$i$i98 = 0, $index$1$lcssa$i$i$i = 0, $index$1$lcssa$i$i$i105 = 0;
 var $index$1$lcssa$i$i$i12 = 0, $index$1$lcssa$i$i$i60 = 0, $index$18$i$i$i = 0, $index$18$i$i$i101 = 0, $index$18$i$i$i56 = 0, $index$18$i$i$i8 = 0, $index$2$i$i$i = 0, $index$2$i$i$i10 = 0, $index$2$i$i$i103 = 0, $index$2$i$i$i58 = 0, $index7$0185 = 0, $index7$1 = 0, $j$02$i = 0, $j$02$i113 = 0, $j$02$i123 = 0, $j$02$i20 = 0, $j$02$i32 = 0, $j$02$i41 = 0, $j$02$i68 = 0, $j$02$i84 = 0;
 var $j$0203 = 0, $j8$0186 = 0, $k$0210 = 0, $max$sroa$1$i$i$i = 0, $pen$sroa$1$i$i$i = 0, $phitmp = 0, $tempNumContacts$04$i = 0, $tempNumContacts$04$i110 = 0, $tempNumContacts$04$i120 = 0, $tempNumContacts$04$i17 = 0, $tempNumContacts$04$i29 = 0, $tempNumContacts$04$i38 = 0, $tempNumContacts$04$i65 = 0, $tempNumContacts$04$i81 = 0, $tempNumContacts$1$lcssa$i = 0, $tempNumContacts$1$lcssa$i116 = 0, $tempNumContacts$1$lcssa$i126 = 0, $tempNumContacts$1$lcssa$i23 = 0, $tempNumContacts$1$lcssa$i35 = 0, $tempNumContacts$1$lcssa$i44 = 0;
 var $tempNumContacts$1$lcssa$i71 = 0, $tempNumContacts$1$lcssa$i87 = 0, $tempNumContacts$11$i = 0, $tempNumContacts$11$i114 = 0, $tempNumContacts$11$i124 = 0, $tempNumContacts$11$i21 = 0, $tempNumContacts$11$i33 = 0, $tempNumContacts$11$i42 = 0, $tempNumContacts$11$i69 = 0, $tempNumContacts$11$i85 = 0, $tempPatch = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $max$sroa$1$i$i$i = sp + 152|0;
 $pen$sroa$1$i$i$i = sp + 140|0;
 $_maxPen = sp + 16|0;
 $tempPatch = sp + 32|0;
 $$sroa$1138 = sp + 128|0;
 $_maxPen4 = sp + 96|0;
 $_maxPen6 = sp;
 $_maxPen9 = sp + 112|0;
 $0 = (($this) + 52|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = ($numPatch|0)==(0);
  if ($3) {
   STACKTOP = sp;return;
  }
  $4 = $maxContactsPerManifold&255;
  $5 = (($_maxPen) + 4|0);
  $12 = 0;$i$0181 = 0;
  while(1) {
   $6 = (($contactPatch) + ($i$0181<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 24|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==($7|0);
   if ($10) {
    $11 = ($12&255)<(4);
    if (!($11)) {
     label = 107;
     break;
    }
    $13 = $12&255;
    $14 = ((($this) + ($13)|0) + 48|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = $15&255;
    $17 = ((($this) + (($16*400)|0)|0) + 64|0);
    do {
     if ((($4|0) == 3)) {
      $34 = (($7) + 56|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35>>>0)<(4);
      if ($36) {
       $currentPatch$03$i18 = $7;$tempNumContacts$04$i17 = 0;
      } else {
       __ZN5physx2Gu31SinglePersistentContactManifold26reduceBatchContactsCapsuleEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($_maxPen,$17,$manifoldContact,$numManifoldContacts,$7);
       $53 = ((($this) + (($16*400)|0)|0) + 448|0);
       HEAP32[$53>>2] = 3;
       break;
      }
      while(1) {
       $37 = (($currentPatch$03$i18) + 48|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = (($currentPatch$03$i18) + 52|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = ($38>>>0)<($40>>>0);
       if ($41) {
        $j$02$i20 = $38;$tempNumContacts$11$i21 = $tempNumContacts$04$i17;
        while(1) {
         $42 = (($tempNumContacts$11$i21) + 1)|0;
         $43 = (((($this) + (($16*400)|0)|0) + ($tempNumContacts$11$i21<<6)|0) + 64|0);
         $44 = (($manifoldContact) + ($j$02$i20<<6)|0);
         dest=$43+0|0; src=$44+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
         $45 = (($j$02$i20) + 1)|0;
         $46 = HEAP32[$39>>2]|0;
         $47 = ($45>>>0)<($46>>>0);
         if ($47) {
          $j$02$i20 = $45;$tempNumContacts$11$i21 = $42;
         } else {
          $tempNumContacts$1$lcssa$i23 = $42;
          break;
         }
        }
       } else {
        $tempNumContacts$1$lcssa$i23 = $tempNumContacts$04$i17;
       }
       $48 = (($currentPatch$03$i18) + 16|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = ($49|0)==(0|0);
       if ($50) {
        break;
       } else {
        $currentPatch$03$i18 = $49;$tempNumContacts$04$i17 = $tempNumContacts$1$lcssa$i23;
       }
      }
      $51 = ((($this) + (($16*400)|0)|0) + 448|0);
      HEAP32[$51>>2] = $tempNumContacts$1$lcssa$i23;
      $52 = (($7) + 32|0);
      ;HEAP32[$_maxPen+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$_maxPen+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$_maxPen+8>>2]=HEAP32[$52+8>>2]|0;HEAP32[$_maxPen+12>>2]=HEAP32[$52+12>>2]|0;
     } else if ((($4|0) == 1)) {
      HEAPF32[$_maxPen>>2] = Math_fround(3.40282346638528859812E+38);
      ;HEAP32[$5+0>>2]=HEAP32[$max$sroa$1$i$i$i+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$max$sroa$1$i$i$i+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$max$sroa$1$i$i$i+8>>2]|0;
      $18 = ($7|0)==(0|0);
      if ($18) {
       $index$0$lcssa$i$i$i14 = -1;
      } else {
       $385 = Math_fround(3.40282346638528859812E+38);$currentPatch$011$i$i$i4 = $7;$index$010$i$i$i5 = -1;
       while(1) {
        $19 = (($currentPatch$011$i$i$i4) + 48|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = (($currentPatch$011$i$i$i4) + 52|0);
        $22 = HEAP32[$21>>2]|0;
        $23 = ($20>>>0)<($22>>>0);
        if ($23) {
         $27 = $385;$i$09$i$i$i7 = $20;$index$18$i$i$i8 = $index$010$i$i$i5;
         while(1) {
          $24 = ((($manifoldContact) + ($i$09$i$i$i7<<6)|0) + 44|0);
          $25 = Math_fround(HEAPF32[$24>>2]);
          $26 = $27 > $25;
          if ($26) {
           HEAPF32[$_maxPen>>2] = $25;
           ;HEAP32[$5+0>>2]=HEAP32[$pen$sroa$1$i$i$i+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$pen$sroa$1$i$i$i+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$pen$sroa$1$i$i$i+8>>2]|0;
           $387 = $25;$index$2$i$i$i10 = $i$09$i$i$i7;
          } else {
           $387 = $27;$index$2$i$i$i10 = $index$18$i$i$i8;
          }
          $28 = (($i$09$i$i$i7) + 1)|0;
          $exitcond$i$i11 = ($28|0)==($22|0);
          if ($exitcond$i$i11) {
           $386 = $387;$index$1$lcssa$i$i$i12 = $index$2$i$i$i10;
           break;
          } else {
           $27 = $387;$i$09$i$i$i7 = $28;$index$18$i$i$i8 = $index$2$i$i$i10;
          }
         }
        } else {
         $386 = $385;$index$1$lcssa$i$i$i12 = $index$010$i$i$i5;
        }
        $29 = (($currentPatch$011$i$i$i4) + 16|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = ($30|0)==(0|0);
        if ($31) {
         $index$0$lcssa$i$i$i14 = $index$1$lcssa$i$i$i12;
         break;
        } else {
         $385 = $386;$currentPatch$011$i$i$i4 = $30;$index$010$i$i$i5 = $index$1$lcssa$i$i$i12;
        }
       }
      }
      $32 = (($manifoldContact) + ($index$0$lcssa$i$i$i14<<6)|0);
      dest=$17+0|0; src=$32+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $33 = ((($this) + (($16*400)|0)|0) + 448|0);
      HEAP32[$33>>2] = 1;
     } else {
      $54 = (($7) + 56|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ($55>>>0)<(7);
      if ($56) {
       $currentPatch$03$i30 = $7;$tempNumContacts$04$i29 = 0;
      } else {
       __ZN5physx2Gu31SinglePersistentContactManifold25reduceBatchContactsConvexEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($_maxPen,$17,$manifoldContact,$numManifoldContacts,$7);
       $73 = ((($this) + (($16*400)|0)|0) + 448|0);
       HEAP32[$73>>2] = 6;
       break;
      }
      while(1) {
       $57 = (($currentPatch$03$i30) + 48|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($currentPatch$03$i30) + 52|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ($58>>>0)<($60>>>0);
       if ($61) {
        $j$02$i32 = $58;$tempNumContacts$11$i33 = $tempNumContacts$04$i29;
        while(1) {
         $62 = (($tempNumContacts$11$i33) + 1)|0;
         $63 = (((($this) + (($16*400)|0)|0) + ($tempNumContacts$11$i33<<6)|0) + 64|0);
         $64 = (($manifoldContact) + ($j$02$i32<<6)|0);
         dest=$63+0|0; src=$64+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
         $65 = (($j$02$i32) + 1)|0;
         $66 = HEAP32[$59>>2]|0;
         $67 = ($65>>>0)<($66>>>0);
         if ($67) {
          $j$02$i32 = $65;$tempNumContacts$11$i33 = $62;
         } else {
          $tempNumContacts$1$lcssa$i35 = $62;
          break;
         }
        }
       } else {
        $tempNumContacts$1$lcssa$i35 = $tempNumContacts$04$i29;
       }
       $68 = (($currentPatch$03$i30) + 16|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ($69|0)==(0|0);
       if ($70) {
        break;
       } else {
        $currentPatch$03$i30 = $69;$tempNumContacts$04$i29 = $tempNumContacts$1$lcssa$i35;
       }
      }
      $71 = ((($this) + (($16*400)|0)|0) + 448|0);
      HEAP32[$71>>2] = $tempNumContacts$1$lcssa$i35;
      $72 = (($7) + 32|0);
      ;HEAP32[$_maxPen+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$_maxPen+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$_maxPen+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$_maxPen+12>>2]=HEAP32[$72+12>>2]|0;
     }
    } while(0);
    $74 = Math_fround(HEAPF32[$_maxPen>>2]);
    $75 = HEAP8[$0>>0]|0;
    $76 = $75&255;
    $77 = ((($this) + ($76)|0) + 48|0);
    $78 = HEAP8[$77>>0]|0;
    $79 = $78&255;
    $80 = ((($this) + ($79<<2)|0) + 32|0);
    HEAPF32[$80>>2] = $74;
    $81 = HEAP8[$0>>0]|0;
    $82 = (($81) + 1)<<24>>24;
    HEAP8[$0>>0] = $82;
    $384 = $82;
   } else {
    $384 = $12;
   }
   $83 = (($i$0181) + 1)|0;
   $84 = ($83>>>0)<($numPatch>>>0);
   if ($84) {
    $12 = $384;$i$0181 = $83;
   } else {
    label = 107;
    break;
   }
  }
  if ((label|0) == 107) {
   STACKTOP = sp;return;
  }
 }
 $85 = (($tempPatch) + 16|0);
 HEAP32[$85>>2] = 0;
 $86 = (($tempPatch) + 20|0);
 HEAP32[$86>>2] = 0;
 $87 = (($tempPatch) + 24|0);
 HEAP32[$87>>2] = $tempPatch;
 $88 = (($tempPatch) + 32|0);
 HEAPF32[$88>>2] = Math_fround(3.40282346638528859812E+38);
 $89 = (($tempPatch) + 36|0);
 ;HEAP32[$89+0>>2]=HEAP32[$max$sroa$1$i$i$i+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$max$sroa$1$i$i$i+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$max$sroa$1$i$i$i+8>>2]|0;
 $90 = ($numPatch|0)==(0);
 if ($90) {
  STACKTOP = sp;return;
 }
 $91 = $maxContactsPerManifold&255;
 $92 = (($_maxPen6) + 4|0);
 $93 = (($tempPatch) + 48|0);
 $94 = (($tempPatch) + 52|0);
 $95 = (($tempPatch) + 4|0);
 $96 = (($tempPatch) + 8|0);
 $97 = (($tempPatch) + 12|0);
 $98 = (($_maxPen4) + 4|0);
 $i1$0217 = 0;
 L53: while(1) {
  $99 = (($contactPatch) + ($i1$0217<<2)|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($100) + 24|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)==($100|0);
  L55: do {
   if ($103) {
    $104 = HEAP8[$0>>0]|0;
    $105 = $104&255;
    $106 = ($104<<24>>24)==(0);
    do {
     if (!($106)) {
      $107 = Math_fround(HEAPF32[$100>>2]);
      $108 = (($100) + 4|0);
      $109 = Math_fround(HEAPF32[$108>>2]);
      $110 = (($100) + 8|0);
      $111 = Math_fround(HEAPF32[$110>>2]);
      $112 = Math_fround(HEAPF32[$acceptanceEpsilon>>2]);
      $j$0203 = 0;
      while(1) {
       $115 = ((($this) + ($j$0203)|0) + 48|0);
       $116 = HEAP8[$115>>0]|0;
       $117 = $116&255;
       $118 = ((($this) + (($117*400)|0)|0) + 64|0);
       $119 = ((($this) + (($117*400)|0)|0) + 96|0);
       $120 = Math_fround(HEAPF32[$119>>2]);
       $121 = ((($this) + (($117*400)|0)|0) + 100|0);
       $122 = Math_fround(HEAPF32[$121>>2]);
       $123 = ((($this) + (($117*400)|0)|0) + 104|0);
       $124 = Math_fround(HEAPF32[$123>>2]);
       $125 = ((($this) + (($117*400)|0)|0) + 448|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = ($126>>>0)>(1);
       if ($127) {
        $135 = $120;$137 = $122;$139 = $124;$i$042$i = 1;
        while(1) {
         $128 = (((($this) + (($117*400)|0)|0) + ($i$042$i<<6)|0) + 96|0);
         $129 = Math_fround(HEAPF32[$128>>2]);
         $130 = (((($this) + (($117*400)|0)|0) + ($i$042$i<<6)|0) + 100|0);
         $131 = Math_fround(HEAPF32[$130>>2]);
         $132 = (((($this) + (($117*400)|0)|0) + ($i$042$i<<6)|0) + 104|0);
         $133 = Math_fround(HEAPF32[$132>>2]);
         $134 = Math_fround($135 + $129);
         $136 = Math_fround($137 + $131);
         $138 = Math_fround($139 + $133);
         $140 = (($i$042$i) + 1)|0;
         $exitcond = ($140|0)==($126|0);
         if ($exitcond) {
          $$lcssa$i = $138;$$lcssa40$i = $136;$$lcssa41$i = $134;
          break;
         } else {
          $135 = $134;$137 = $136;$139 = $138;$i$042$i = $140;
         }
        }
       } else {
        $$lcssa$i = $124;$$lcssa40$i = $122;$$lcssa41$i = $120;
       }
       $141 = Math_fround($$lcssa41$i * $$lcssa41$i);
       $142 = Math_fround($$lcssa40$i * $$lcssa40$i);
       $143 = Math_fround($141 + $142);
       $144 = Math_fround($$lcssa$i * $$lcssa$i);
       $145 = Math_fround($144 + $143);
       $146 = (Math_fround(Math_sqrt((Math_fround($145)))));
       $147 = Math_fround(Math_fround(1.0) / $146);
       $148 = Math_fround($$lcssa41$i * $147);
       $149 = Math_fround($$lcssa40$i * $147);
       $150 = Math_fround($$lcssa$i * $147);
       $151 = Math_fround($107 * $148);
       $152 = Math_fround($149 * $109);
       $153 = Math_fround($151 + $152);
       $154 = Math_fround($150 * $111);
       $155 = Math_fround($153 + $154);
       $156 = !($155 >= $112);
       $114 = (($j$0203) + 1)|0;
       if (!($156)) {
        break;
       }
       $113 = ($114>>>0)<($105>>>0);
       if ($113) {
        $j$0203 = $114;
       } else {
        label = 60;
        break;
       }
      }
      if ((label|0) == 60) {
       label = 0;
       $phitmp = ($104&255)<(4);
       if ($phitmp) {
        break;
       } else {
        break L53;
       }
      }
      $157 = ($126|0)==(0);
      if ($157) {
       $165 = 0;
      } else {
       $k$0210 = 0;
       while(1) {
        $158 = (($k$0210) + ($numManifoldContacts))|0;
        $159 = (($manifoldContact) + ($158<<6)|0);
        $160 = (((($this) + (($117*400)|0)|0) + ($k$0210<<6)|0) + 64|0);
        dest=$159+0|0; src=$160+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $161 = (($k$0210) + 1)|0;
        $162 = HEAP32[$125>>2]|0;
        $163 = ($161>>>0)<($162>>>0);
        if ($163) {
         $k$0210 = $161;
        } else {
         $165 = $162;
         break;
        }
       }
      }
      HEAP32[$93>>2] = $numManifoldContacts;
      $164 = (($165) + ($numManifoldContacts))|0;
      HEAP32[$94>>2] = $164;
      HEAPF32[$tempPatch>>2] = $148;
      HEAPF32[$95>>2] = $149;
      HEAPF32[$96>>2] = $150;
      HEAPF32[$97>>2] = Math_fround(0.0);
      HEAP32[$87>>2] = $100;
      HEAP32[$85>>2] = 0;
      $166 = (($100) + 20|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = (($167) + 16|0);
      HEAP32[$168>>2] = $tempPatch;
      $169 = (($100) + 56|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = (($170) + ($165))|0;
      HEAP32[$169>>2] = $171;
      $172 = (($100) + 32|0);
      $173 = Math_fround(HEAPF32[$172>>2]);
      $174 = (($100) + 36|0);
      $175 = HEAP8[$115>>0]|0;
      $176 = $175&255;
      $177 = ((($this) + ($176<<2)|0) + 32|0);
      $178 = Math_fround(HEAPF32[$177>>2]);
      $179 = $173 > $178;
      $$$i = $179 ? $178 : $173;
      HEAPF32[$172>>2] = $$$i;
      ;HEAP32[$174+0>>2]=HEAP32[$$sroa$1138+0>>2]|0;HEAP32[$174+4>>2]=HEAP32[$$sroa$1138+4>>2]|0;HEAP32[$174+8>>2]=HEAP32[$$sroa$1138+8>>2]|0;
      $180 = HEAP32[$125>>2]|0;
      $181 = (($180) + ($numManifoldContacts))|0;
      do {
       if ((($91|0) == 1)) {
        HEAPF32[$_maxPen4>>2] = Math_fround(3.40282346638528859812E+38);
        ;HEAP32[$98+0>>2]=HEAP32[$max$sroa$1$i$i$i+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$max$sroa$1$i$i$i+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$max$sroa$1$i$i$i+8>>2]|0;
        $182 = ($100|0)==(0|0);
        if ($182) {
         $index$0$lcssa$i$i$i107 = -1;
        } else {
         $388 = Math_fround(3.40282346638528859812E+38);$currentPatch$011$i$i$i97 = $100;$index$010$i$i$i98 = -1;
         while(1) {
          $183 = (($currentPatch$011$i$i$i97) + 48|0);
          $184 = HEAP32[$183>>2]|0;
          $185 = (($currentPatch$011$i$i$i97) + 52|0);
          $186 = HEAP32[$185>>2]|0;
          $187 = ($184>>>0)<($186>>>0);
          if ($187) {
           $191 = $388;$i$09$i$i$i100 = $184;$index$18$i$i$i101 = $index$010$i$i$i98;
           while(1) {
            $188 = ((($manifoldContact) + ($i$09$i$i$i100<<6)|0) + 44|0);
            $189 = Math_fround(HEAPF32[$188>>2]);
            $190 = $191 > $189;
            if ($190) {
             HEAPF32[$_maxPen4>>2] = $189;
             ;HEAP32[$98+0>>2]=HEAP32[$pen$sroa$1$i$i$i+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$pen$sroa$1$i$i$i+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$pen$sroa$1$i$i$i+8>>2]|0;
             $390 = $189;$index$2$i$i$i103 = $i$09$i$i$i100;
            } else {
             $390 = $191;$index$2$i$i$i103 = $index$18$i$i$i101;
            }
            $192 = (($i$09$i$i$i100) + 1)|0;
            $exitcond$i$i104 = ($192|0)==($186|0);
            if ($exitcond$i$i104) {
             $389 = $390;$index$1$lcssa$i$i$i105 = $index$2$i$i$i103;
             break;
            } else {
             $191 = $390;$i$09$i$i$i100 = $192;$index$18$i$i$i101 = $index$2$i$i$i103;
            }
           }
          } else {
           $389 = $388;$index$1$lcssa$i$i$i105 = $index$010$i$i$i98;
          }
          $193 = (($currentPatch$011$i$i$i97) + 16|0);
          $194 = HEAP32[$193>>2]|0;
          $195 = ($194|0)==(0|0);
          if ($195) {
           $index$0$lcssa$i$i$i107 = $index$1$lcssa$i$i$i105;
           break;
          } else {
           $388 = $389;$currentPatch$011$i$i$i97 = $194;$index$010$i$i$i98 = $index$1$lcssa$i$i$i105;
          }
         }
        }
        $196 = (($manifoldContact) + ($index$0$lcssa$i$i$i107<<6)|0);
        dest=$118+0|0; src=$196+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        HEAP32[$125>>2] = 1;
       } else if ((($91|0) == 3)) {
        $197 = ($171>>>0)<(4);
        if ($197) {
         $currentPatch$03$i111 = $100;$tempNumContacts$04$i110 = 0;
        } else {
         __ZN5physx2Gu31SinglePersistentContactManifold26reduceBatchContactsCapsuleEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($_maxPen4,$118,$manifoldContact,$181,$100);
         HEAP32[$125>>2] = 3;
         break;
        }
        while(1) {
         $198 = (($currentPatch$03$i111) + 48|0);
         $199 = HEAP32[$198>>2]|0;
         $200 = (($currentPatch$03$i111) + 52|0);
         $201 = HEAP32[$200>>2]|0;
         $202 = ($199>>>0)<($201>>>0);
         if ($202) {
          $j$02$i113 = $199;$tempNumContacts$11$i114 = $tempNumContacts$04$i110;
          while(1) {
           $203 = (($tempNumContacts$11$i114) + 1)|0;
           $204 = (((($this) + (($117*400)|0)|0) + ($tempNumContacts$11$i114<<6)|0) + 64|0);
           $205 = (($manifoldContact) + ($j$02$i113<<6)|0);
           dest=$204+0|0; src=$205+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           $206 = (($j$02$i113) + 1)|0;
           $207 = HEAP32[$200>>2]|0;
           $208 = ($206>>>0)<($207>>>0);
           if ($208) {
            $j$02$i113 = $206;$tempNumContacts$11$i114 = $203;
           } else {
            $tempNumContacts$1$lcssa$i116 = $203;
            break;
           }
          }
         } else {
          $tempNumContacts$1$lcssa$i116 = $tempNumContacts$04$i110;
         }
         $209 = (($currentPatch$03$i111) + 16|0);
         $210 = HEAP32[$209>>2]|0;
         $211 = ($210|0)==(0|0);
         if ($211) {
          break;
         } else {
          $currentPatch$03$i111 = $210;$tempNumContacts$04$i110 = $tempNumContacts$1$lcssa$i116;
         }
        }
        HEAP32[$125>>2] = $tempNumContacts$1$lcssa$i116;
        $212 = (($100) + 32|0);
        ;HEAP32[$_maxPen4+0>>2]=HEAP32[$212+0>>2]|0;HEAP32[$_maxPen4+4>>2]=HEAP32[$212+4>>2]|0;HEAP32[$_maxPen4+8>>2]=HEAP32[$212+8>>2]|0;HEAP32[$_maxPen4+12>>2]=HEAP32[$212+12>>2]|0;
       } else {
        $213 = ($171>>>0)<(7);
        if ($213) {
         $currentPatch$03$i121 = $100;$tempNumContacts$04$i120 = 0;
        } else {
         __ZN5physx2Gu31SinglePersistentContactManifold25reduceBatchContactsConvexEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($_maxPen4,$118,$manifoldContact,$181,$100);
         HEAP32[$125>>2] = 6;
         break;
        }
        while(1) {
         $214 = (($currentPatch$03$i121) + 48|0);
         $215 = HEAP32[$214>>2]|0;
         $216 = (($currentPatch$03$i121) + 52|0);
         $217 = HEAP32[$216>>2]|0;
         $218 = ($215>>>0)<($217>>>0);
         if ($218) {
          $j$02$i123 = $215;$tempNumContacts$11$i124 = $tempNumContacts$04$i120;
          while(1) {
           $219 = (($tempNumContacts$11$i124) + 1)|0;
           $220 = (((($this) + (($117*400)|0)|0) + ($tempNumContacts$11$i124<<6)|0) + 64|0);
           $221 = (($manifoldContact) + ($j$02$i123<<6)|0);
           dest=$220+0|0; src=$221+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           $222 = (($j$02$i123) + 1)|0;
           $223 = HEAP32[$216>>2]|0;
           $224 = ($222>>>0)<($223>>>0);
           if ($224) {
            $j$02$i123 = $222;$tempNumContacts$11$i124 = $219;
           } else {
            $tempNumContacts$1$lcssa$i126 = $219;
            break;
           }
          }
         } else {
          $tempNumContacts$1$lcssa$i126 = $tempNumContacts$04$i120;
         }
         $225 = (($currentPatch$03$i121) + 16|0);
         $226 = HEAP32[$225>>2]|0;
         $227 = ($226|0)==(0|0);
         if ($227) {
          break;
         } else {
          $currentPatch$03$i121 = $226;$tempNumContacts$04$i120 = $tempNumContacts$1$lcssa$i126;
         }
        }
        HEAP32[$125>>2] = $tempNumContacts$1$lcssa$i126;
        $228 = (($100) + 32|0);
        ;HEAP32[$_maxPen4+0>>2]=HEAP32[$228+0>>2]|0;HEAP32[$_maxPen4+4>>2]=HEAP32[$228+4>>2]|0;HEAP32[$_maxPen4+8>>2]=HEAP32[$228+8>>2]|0;HEAP32[$_maxPen4+12>>2]=HEAP32[$228+12>>2]|0;
       }
      } while(0);
      $229 = Math_fround(HEAPF32[$_maxPen4>>2]);
      $230 = HEAP8[$115>>0]|0;
      $231 = $230&255;
      $232 = ((($this) + ($231<<2)|0) + 32|0);
      HEAPF32[$232>>2] = $229;
      break L55;
     }
    } while(0);
    $234 = ((($this) + ($105)|0) + 48|0);
    $235 = HEAP8[$234>>0]|0;
    $236 = $235&255;
    $237 = ((($this) + (($236*400)|0)|0) + 64|0);
    do {
     if ((($91|0) == 1)) {
      HEAPF32[$_maxPen6>>2] = Math_fround(3.40282346638528859812E+38);
      ;HEAP32[$92+0>>2]=HEAP32[$max$sroa$1$i$i$i+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$max$sroa$1$i$i$i+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$max$sroa$1$i$i$i+8>>2]|0;
      $238 = ($100|0)==(0|0);
      if ($238) {
       $index$0$lcssa$i$i$i62 = -1;
      } else {
       $391 = Math_fround(3.40282346638528859812E+38);$currentPatch$011$i$i$i52 = $100;$index$010$i$i$i53 = -1;
       while(1) {
        $239 = (($currentPatch$011$i$i$i52) + 48|0);
        $240 = HEAP32[$239>>2]|0;
        $241 = (($currentPatch$011$i$i$i52) + 52|0);
        $242 = HEAP32[$241>>2]|0;
        $243 = ($240>>>0)<($242>>>0);
        if ($243) {
         $247 = $391;$i$09$i$i$i55 = $240;$index$18$i$i$i56 = $index$010$i$i$i53;
         while(1) {
          $244 = ((($manifoldContact) + ($i$09$i$i$i55<<6)|0) + 44|0);
          $245 = Math_fround(HEAPF32[$244>>2]);
          $246 = $247 > $245;
          if ($246) {
           HEAPF32[$_maxPen6>>2] = $245;
           ;HEAP32[$92+0>>2]=HEAP32[$pen$sroa$1$i$i$i+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$pen$sroa$1$i$i$i+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$pen$sroa$1$i$i$i+8>>2]|0;
           $393 = $245;$index$2$i$i$i58 = $i$09$i$i$i55;
          } else {
           $393 = $247;$index$2$i$i$i58 = $index$18$i$i$i56;
          }
          $248 = (($i$09$i$i$i55) + 1)|0;
          $exitcond$i$i59 = ($248|0)==($242|0);
          if ($exitcond$i$i59) {
           $392 = $393;$index$1$lcssa$i$i$i60 = $index$2$i$i$i58;
           break;
          } else {
           $247 = $393;$i$09$i$i$i55 = $248;$index$18$i$i$i56 = $index$2$i$i$i58;
          }
         }
        } else {
         $392 = $391;$index$1$lcssa$i$i$i60 = $index$010$i$i$i53;
        }
        $249 = (($currentPatch$011$i$i$i52) + 16|0);
        $250 = HEAP32[$249>>2]|0;
        $251 = ($250|0)==(0|0);
        if ($251) {
         $index$0$lcssa$i$i$i62 = $index$1$lcssa$i$i$i60;
         break;
        } else {
         $391 = $392;$currentPatch$011$i$i$i52 = $250;$index$010$i$i$i53 = $index$1$lcssa$i$i$i60;
        }
       }
      }
      $252 = (($manifoldContact) + ($index$0$lcssa$i$i$i62<<6)|0);
      dest=$237+0|0; src=$252+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $253 = ((($this) + (($236*400)|0)|0) + 448|0);
      HEAP32[$253>>2] = 1;
     } else if ((($91|0) == 3)) {
      $254 = (($100) + 56|0);
      $255 = HEAP32[$254>>2]|0;
      $256 = ($255>>>0)<(4);
      if ($256) {
       $currentPatch$03$i66 = $100;$tempNumContacts$04$i65 = 0;
      } else {
       __ZN5physx2Gu31SinglePersistentContactManifold26reduceBatchContactsCapsuleEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($_maxPen6,$237,$manifoldContact,$numManifoldContacts,$100);
       $273 = ((($this) + (($236*400)|0)|0) + 448|0);
       HEAP32[$273>>2] = 3;
       break;
      }
      while(1) {
       $257 = (($currentPatch$03$i66) + 48|0);
       $258 = HEAP32[$257>>2]|0;
       $259 = (($currentPatch$03$i66) + 52|0);
       $260 = HEAP32[$259>>2]|0;
       $261 = ($258>>>0)<($260>>>0);
       if ($261) {
        $j$02$i68 = $258;$tempNumContacts$11$i69 = $tempNumContacts$04$i65;
        while(1) {
         $262 = (($tempNumContacts$11$i69) + 1)|0;
         $263 = (((($this) + (($236*400)|0)|0) + ($tempNumContacts$11$i69<<6)|0) + 64|0);
         $264 = (($manifoldContact) + ($j$02$i68<<6)|0);
         dest=$263+0|0; src=$264+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
         $265 = (($j$02$i68) + 1)|0;
         $266 = HEAP32[$259>>2]|0;
         $267 = ($265>>>0)<($266>>>0);
         if ($267) {
          $j$02$i68 = $265;$tempNumContacts$11$i69 = $262;
         } else {
          $tempNumContacts$1$lcssa$i71 = $262;
          break;
         }
        }
       } else {
        $tempNumContacts$1$lcssa$i71 = $tempNumContacts$04$i65;
       }
       $268 = (($currentPatch$03$i66) + 16|0);
       $269 = HEAP32[$268>>2]|0;
       $270 = ($269|0)==(0|0);
       if ($270) {
        break;
       } else {
        $currentPatch$03$i66 = $269;$tempNumContacts$04$i65 = $tempNumContacts$1$lcssa$i71;
       }
      }
      $271 = ((($this) + (($236*400)|0)|0) + 448|0);
      HEAP32[$271>>2] = $tempNumContacts$1$lcssa$i71;
      $272 = (($100) + 32|0);
      ;HEAP32[$_maxPen6+0>>2]=HEAP32[$272+0>>2]|0;HEAP32[$_maxPen6+4>>2]=HEAP32[$272+4>>2]|0;HEAP32[$_maxPen6+8>>2]=HEAP32[$272+8>>2]|0;HEAP32[$_maxPen6+12>>2]=HEAP32[$272+12>>2]|0;
     } else {
      $274 = (($100) + 56|0);
      $275 = HEAP32[$274>>2]|0;
      $276 = ($275>>>0)<(7);
      if ($276) {
       $currentPatch$03$i82 = $100;$tempNumContacts$04$i81 = 0;
      } else {
       __ZN5physx2Gu31SinglePersistentContactManifold25reduceBatchContactsConvexEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($_maxPen6,$237,$manifoldContact,$numManifoldContacts,$100);
       $293 = ((($this) + (($236*400)|0)|0) + 448|0);
       HEAP32[$293>>2] = 6;
       break;
      }
      while(1) {
       $277 = (($currentPatch$03$i82) + 48|0);
       $278 = HEAP32[$277>>2]|0;
       $279 = (($currentPatch$03$i82) + 52|0);
       $280 = HEAP32[$279>>2]|0;
       $281 = ($278>>>0)<($280>>>0);
       if ($281) {
        $j$02$i84 = $278;$tempNumContacts$11$i85 = $tempNumContacts$04$i81;
        while(1) {
         $282 = (($tempNumContacts$11$i85) + 1)|0;
         $283 = (((($this) + (($236*400)|0)|0) + ($tempNumContacts$11$i85<<6)|0) + 64|0);
         $284 = (($manifoldContact) + ($j$02$i84<<6)|0);
         dest=$283+0|0; src=$284+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
         $285 = (($j$02$i84) + 1)|0;
         $286 = HEAP32[$279>>2]|0;
         $287 = ($285>>>0)<($286>>>0);
         if ($287) {
          $j$02$i84 = $285;$tempNumContacts$11$i85 = $282;
         } else {
          $tempNumContacts$1$lcssa$i87 = $282;
          break;
         }
        }
       } else {
        $tempNumContacts$1$lcssa$i87 = $tempNumContacts$04$i81;
       }
       $288 = (($currentPatch$03$i82) + 16|0);
       $289 = HEAP32[$288>>2]|0;
       $290 = ($289|0)==(0|0);
       if ($290) {
        break;
       } else {
        $currentPatch$03$i82 = $289;$tempNumContacts$04$i81 = $tempNumContacts$1$lcssa$i87;
       }
      }
      $291 = ((($this) + (($236*400)|0)|0) + 448|0);
      HEAP32[$291>>2] = $tempNumContacts$1$lcssa$i87;
      $292 = (($100) + 32|0);
      ;HEAP32[$_maxPen6+0>>2]=HEAP32[$292+0>>2]|0;HEAP32[$_maxPen6+4>>2]=HEAP32[$292+4>>2]|0;HEAP32[$_maxPen6+8>>2]=HEAP32[$292+8>>2]|0;HEAP32[$_maxPen6+12>>2]=HEAP32[$292+12>>2]|0;
     }
    } while(0);
    $294 = Math_fround(HEAPF32[$_maxPen6>>2]);
    $295 = HEAP8[$0>>0]|0;
    $296 = $295&255;
    $297 = ((($this) + ($296)|0) + 48|0);
    $298 = HEAP8[$297>>0]|0;
    $299 = $298&255;
    $300 = ((($this) + ($299<<2)|0) + 32|0);
    HEAPF32[$300>>2] = $294;
    $301 = HEAP8[$0>>0]|0;
    $302 = (($301) + 1)<<24>>24;
    HEAP8[$0>>0] = $302;
   }
  } while(0);
  $382 = (($i1$0217) + 1)|0;
  $383 = ($382>>>0)<($numPatch>>>0);
  if ($383) {
   $i1$0217 = $382;
  } else {
   label = 107;
   break;
  }
 }
 if ((label|0) == 107) {
  STACKTOP = sp;return;
 }
 $233 = $104&255;
 $index7$0185 = 0;$j8$0186 = 1;
 while(1) {
  $303 = ((($this) + ($j8$0186)|0) + 48|0);
  $304 = HEAP8[$303>>0]|0;
  $305 = $304&255;
  $306 = ((($this) + ($305<<2)|0) + 32|0);
  $307 = Math_fround(HEAPF32[$306>>2]);
  $308 = ((($this) + ($index7$0185)|0) + 48|0);
  $309 = HEAP8[$308>>0]|0;
  $310 = $309&255;
  $311 = ((($this) + ($310<<2)|0) + 32|0);
  $312 = Math_fround(HEAPF32[$311>>2]);
  $313 = $307 > $312;
  $index7$1 = $313 ? $j8$0186 : $index7$0185;
  $314 = (($j8$0186) + 1)|0;
  $315 = ($314>>>0)<($233>>>0);
  if ($315) {
   $index7$0185 = $index7$1;$j8$0186 = $314;
  } else {
   break;
  }
 }
 $316 = ((($this) + ($index7$1)|0) + 48|0);
 $317 = HEAP8[$316>>0]|0;
 $318 = $317&255;
 $319 = ((($this) + ($318<<2)|0) + 32|0);
 $320 = Math_fround(HEAPF32[$319>>2]);
 $321 = (($100) + 32|0);
 $322 = Math_fround(HEAPF32[$321>>2]);
 $323 = $320 > $322;
 if (!($323)) {
  STACKTOP = sp;return;
 }
 $324 = ((($this) + (($318*400)|0)|0) + 64|0);
 $325 = ((($this) + (($318*400)|0)|0) + 448|0);
 HEAP32[$325>>2] = 0;
 do {
  if ((($91|0) == 3)) {
   $342 = (($100) + 56|0);
   $343 = HEAP32[$342>>2]|0;
   $344 = ($343>>>0)<(4);
   if ($344) {
    $currentPatch$03$i = $100;$tempNumContacts$04$i = 0;
   } else {
    __ZN5physx2Gu31SinglePersistentContactManifold26reduceBatchContactsCapsuleEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($_maxPen9,$324,$manifoldContact,$numManifoldContacts,$100);
    HEAP32[$325>>2] = 3;
    break;
   }
   while(1) {
    $345 = (($currentPatch$03$i) + 48|0);
    $346 = HEAP32[$345>>2]|0;
    $347 = (($currentPatch$03$i) + 52|0);
    $348 = HEAP32[$347>>2]|0;
    $349 = ($346>>>0)<($348>>>0);
    if ($349) {
     $j$02$i = $346;$tempNumContacts$11$i = $tempNumContacts$04$i;
     while(1) {
      $350 = (($tempNumContacts$11$i) + 1)|0;
      $351 = (((($this) + (($318*400)|0)|0) + ($tempNumContacts$11$i<<6)|0) + 64|0);
      $352 = (($manifoldContact) + ($j$02$i<<6)|0);
      dest=$351+0|0; src=$352+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $353 = (($j$02$i) + 1)|0;
      $354 = HEAP32[$347>>2]|0;
      $355 = ($353>>>0)<($354>>>0);
      if ($355) {
       $j$02$i = $353;$tempNumContacts$11$i = $350;
      } else {
       $tempNumContacts$1$lcssa$i = $350;
       break;
      }
     }
    } else {
     $tempNumContacts$1$lcssa$i = $tempNumContacts$04$i;
    }
    $356 = (($currentPatch$03$i) + 16|0);
    $357 = HEAP32[$356>>2]|0;
    $358 = ($357|0)==(0|0);
    if ($358) {
     break;
    } else {
     $currentPatch$03$i = $357;$tempNumContacts$04$i = $tempNumContacts$1$lcssa$i;
    }
   }
   HEAP32[$325>>2] = $tempNumContacts$1$lcssa$i;
   $359 = (($100) + 32|0);
   ;HEAP32[$_maxPen9+0>>2]=HEAP32[$359+0>>2]|0;HEAP32[$_maxPen9+4>>2]=HEAP32[$359+4>>2]|0;HEAP32[$_maxPen9+8>>2]=HEAP32[$359+8>>2]|0;HEAP32[$_maxPen9+12>>2]=HEAP32[$359+12>>2]|0;
  } else if ((($91|0) == 1)) {
   HEAPF32[$_maxPen9>>2] = Math_fround(3.40282346638528859812E+38);
   $326 = (($_maxPen9) + 4|0);
   ;HEAP32[$326+0>>2]=HEAP32[$max$sroa$1$i$i$i+0>>2]|0;HEAP32[$326+4>>2]=HEAP32[$max$sroa$1$i$i$i+4>>2]|0;HEAP32[$326+8>>2]=HEAP32[$max$sroa$1$i$i$i+8>>2]|0;
   $327 = ($100|0)==(0|0);
   if ($327) {
    $index$0$lcssa$i$i$i = -1;
   } else {
    $394 = Math_fround(3.40282346638528859812E+38);$currentPatch$011$i$i$i = $100;$index$010$i$i$i = -1;
    while(1) {
     $328 = (($currentPatch$011$i$i$i) + 48|0);
     $329 = HEAP32[$328>>2]|0;
     $330 = (($currentPatch$011$i$i$i) + 52|0);
     $331 = HEAP32[$330>>2]|0;
     $332 = ($329>>>0)<($331>>>0);
     if ($332) {
      $336 = $394;$i$09$i$i$i = $329;$index$18$i$i$i = $index$010$i$i$i;
      while(1) {
       $333 = ((($manifoldContact) + ($i$09$i$i$i<<6)|0) + 44|0);
       $334 = Math_fround(HEAPF32[$333>>2]);
       $335 = $336 > $334;
       if ($335) {
        HEAPF32[$_maxPen9>>2] = $334;
        ;HEAP32[$326+0>>2]=HEAP32[$pen$sroa$1$i$i$i+0>>2]|0;HEAP32[$326+4>>2]=HEAP32[$pen$sroa$1$i$i$i+4>>2]|0;HEAP32[$326+8>>2]=HEAP32[$pen$sroa$1$i$i$i+8>>2]|0;
        $396 = $334;$index$2$i$i$i = $i$09$i$i$i;
       } else {
        $396 = $336;$index$2$i$i$i = $index$18$i$i$i;
       }
       $337 = (($i$09$i$i$i) + 1)|0;
       $exitcond$i$i = ($337|0)==($331|0);
       if ($exitcond$i$i) {
        $395 = $396;$index$1$lcssa$i$i$i = $index$2$i$i$i;
        break;
       } else {
        $336 = $396;$i$09$i$i$i = $337;$index$18$i$i$i = $index$2$i$i$i;
       }
      }
     } else {
      $395 = $394;$index$1$lcssa$i$i$i = $index$010$i$i$i;
     }
     $338 = (($currentPatch$011$i$i$i) + 16|0);
     $339 = HEAP32[$338>>2]|0;
     $340 = ($339|0)==(0|0);
     if ($340) {
      $index$0$lcssa$i$i$i = $index$1$lcssa$i$i$i;
      break;
     } else {
      $394 = $395;$currentPatch$011$i$i$i = $339;$index$010$i$i$i = $index$1$lcssa$i$i$i;
     }
    }
   }
   $341 = (($manifoldContact) + ($index$0$lcssa$i$i$i<<6)|0);
   dest=$324+0|0; src=$341+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$325>>2] = 1;
  } else {
   $360 = (($100) + 56|0);
   $361 = HEAP32[$360>>2]|0;
   $362 = ($361>>>0)<(7);
   if ($362) {
    $currentPatch$03$i39 = $100;$tempNumContacts$04$i38 = 0;
   } else {
    __ZN5physx2Gu31SinglePersistentContactManifold25reduceBatchContactsConvexEPKNS0_21MeshPersistentContactEjRNS0_15PCMContactPatchE($_maxPen9,$324,$manifoldContact,$numManifoldContacts,$100);
    HEAP32[$325>>2] = 6;
    break;
   }
   while(1) {
    $363 = (($currentPatch$03$i39) + 48|0);
    $364 = HEAP32[$363>>2]|0;
    $365 = (($currentPatch$03$i39) + 52|0);
    $366 = HEAP32[$365>>2]|0;
    $367 = ($364>>>0)<($366>>>0);
    if ($367) {
     $j$02$i41 = $364;$tempNumContacts$11$i42 = $tempNumContacts$04$i38;
     while(1) {
      $368 = (($tempNumContacts$11$i42) + 1)|0;
      $369 = (((($this) + (($318*400)|0)|0) + ($tempNumContacts$11$i42<<6)|0) + 64|0);
      $370 = (($manifoldContact) + ($j$02$i41<<6)|0);
      dest=$369+0|0; src=$370+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $371 = (($j$02$i41) + 1)|0;
      $372 = HEAP32[$365>>2]|0;
      $373 = ($371>>>0)<($372>>>0);
      if ($373) {
       $j$02$i41 = $371;$tempNumContacts$11$i42 = $368;
      } else {
       $tempNumContacts$1$lcssa$i44 = $368;
       break;
      }
     }
    } else {
     $tempNumContacts$1$lcssa$i44 = $tempNumContacts$04$i38;
    }
    $374 = (($currentPatch$03$i39) + 16|0);
    $375 = HEAP32[$374>>2]|0;
    $376 = ($375|0)==(0|0);
    if ($376) {
     break;
    } else {
     $currentPatch$03$i39 = $375;$tempNumContacts$04$i38 = $tempNumContacts$1$lcssa$i44;
    }
   }
   HEAP32[$325>>2] = $tempNumContacts$1$lcssa$i44;
   $377 = (($100) + 32|0);
   ;HEAP32[$_maxPen9+0>>2]=HEAP32[$377+0>>2]|0;HEAP32[$_maxPen9+4>>2]=HEAP32[$377+4>>2]|0;HEAP32[$_maxPen9+8>>2]=HEAP32[$377+8>>2]|0;HEAP32[$_maxPen9+12>>2]=HEAP32[$377+12>>2]|0;
  }
 } while(0);
 $378 = Math_fround(HEAPF32[$_maxPen9>>2]);
 $379 = HEAP8[$316>>0]|0;
 $380 = $379&255;
 $381 = ((($this) + ($380<<2)|0) + 32|0);
 HEAPF32[$381>>2] = $378;
 STACKTOP = sp;return;
}
function __ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVE($this,$contactBuffer,$meshTransform) {
 $this = $this|0;
 $contactBuffer = $contactBuffer|0;
 $meshTransform = $meshTransform|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $contactCount$0$lcssa = 0, $contactCount$051 = 0, $contactCount$1$lcssa = 0, $contactCount$149 = 0, $exitcond = 0, $i$050 = 0, $j$048 = 0, $normal = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $normal = sp;
 $0 = (($this) + 53|0);
 HEAP8[$0>>0] = 0;
 $1 = (($this) + 52|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $contactCount$0$lcssa = 0;
  $104 = (($contactBuffer) + 4096|0);
  HEAP32[$104>>2] = $contactCount$0$lcssa;
  $105 = ($contactCount$0$lcssa|0)!=(0);
  STACKTOP = sp;return ($105|0);
 }
 $4 = (($meshTransform) + 4|0);
 $5 = (($meshTransform) + 8|0);
 $6 = (($meshTransform) + 12|0);
 $7 = (($meshTransform) + 16|0);
 $8 = (($meshTransform) + 20|0);
 $9 = (($meshTransform) + 24|0);
 $10 = (($normal) + 4|0);
 $11 = (($normal) + 8|0);
 $19 = 0;$contactCount$051 = 0;$i$050 = 0;
 while(1) {
  $12 = ((($this) + ($i$050)|0) + 48|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = ((($this) + (($14*400)|0)|0) + 64|0);
  $16 = ((($this) + (($14*400)|0)|0) + 448|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $19&255;
  $20 = (($18) + ($17))|0;
  $21 = $20&255;
  HEAP8[$0>>0] = $21;
  __ZN5physx2Gu31SinglePersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($normal,$15,$meshTransform);
  $22 = ($17|0)!=(0);
  $23 = ($contactCount$051>>>0)<(64);
  $24 = $22 & $23;
  if ($24) {
   $25 = Math_fround(HEAPF32[$normal>>2]);
   $26 = Math_fround(HEAPF32[$10>>2]);
   $27 = Math_fround(HEAPF32[$11>>2]);
   $28 = (0 - ($17))|0;
   $29 = (($contactCount$051) + -64)|0;
   $30 = ($29>>>0)<($28>>>0);
   $umax = $30 ? $28 : $29;
   $31 = (0 - ($umax))|0;
   $contactCount$149 = $contactCount$051;$j$048 = 0;
   while(1) {
    $32 = Math_fround(HEAPF32[$meshTransform>>2]);
    $33 = Math_fround(HEAPF32[$4>>2]);
    $34 = Math_fround(HEAPF32[$5>>2]);
    $35 = Math_fround(HEAPF32[$6>>2]);
    $36 = Math_fround(HEAPF32[$7>>2]);
    $37 = Math_fround(HEAPF32[$8>>2]);
    $38 = Math_fround(HEAPF32[$9>>2]);
    $39 = (((($this) + (($14*400)|0)|0) + ($j$048<<6)|0) + 80|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = (((($this) + (($14*400)|0)|0) + ($j$048<<6)|0) + 84|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = (((($this) + (($14*400)|0)|0) + ($j$048<<6)|0) + 88|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = Math_fround($35 * $35);
    $46 = Math_fround($45 + Math_fround(-0.5));
    $47 = Math_fround($46 * $40);
    $48 = Math_fround($46 * $42);
    $49 = Math_fround($46 * $44);
    $50 = Math_fround($33 * $44);
    $51 = Math_fround($34 * $42);
    $52 = Math_fround($50 - $51);
    $53 = Math_fround($34 * $40);
    $54 = Math_fround($32 * $44);
    $55 = Math_fround($53 - $54);
    $56 = Math_fround($32 * $42);
    $57 = Math_fround($33 * $40);
    $58 = Math_fround($56 - $57);
    $59 = Math_fround($35 * $52);
    $60 = Math_fround($35 * $55);
    $61 = Math_fround($35 * $58);
    $62 = Math_fround($47 + $59);
    $63 = Math_fround($48 + $60);
    $64 = Math_fround($49 + $61);
    $65 = Math_fround($32 * $40);
    $66 = Math_fround($33 * $42);
    $67 = Math_fround($65 + $66);
    $68 = Math_fround($34 * $44);
    $69 = Math_fround($67 + $68);
    $70 = Math_fround($32 * $69);
    $71 = Math_fround($33 * $69);
    $72 = Math_fround($34 * $69);
    $73 = Math_fround($70 + $62);
    $74 = Math_fround($71 + $63);
    $75 = Math_fround($64 + $72);
    $76 = Math_fround($73 * Math_fround(2.0));
    $77 = Math_fround($74 * Math_fround(2.0));
    $78 = Math_fround($75 * Math_fround(2.0));
    $79 = Math_fround($36 + $76);
    $80 = Math_fround($37 + $77);
    $81 = Math_fround($38 + $78);
    $82 = (((($this) + (($14*400)|0)|0) + ($j$048<<6)|0) + 108|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = (($contactCount$149) + 1)|0;
    $85 = (($contactBuffer) + ($contactCount$149<<6)|0);
    HEAPF32[$85>>2] = $25;
    $86 = (($85) + 4|0);
    HEAPF32[$86>>2] = $26;
    $87 = (($85) + 8|0);
    HEAPF32[$87>>2] = $27;
    $88 = (($85) + 12|0);
    HEAPF32[$88>>2] = Math_fround(0.0);
    $89 = ((($contactBuffer) + ($contactCount$149<<6)|0) + 16|0);
    HEAPF32[$89>>2] = $79;
    $90 = (($89) + 4|0);
    HEAPF32[$90>>2] = $80;
    $91 = (($89) + 8|0);
    HEAPF32[$91>>2] = $81;
    $92 = (($89) + 12|0);
    HEAPF32[$92>>2] = Math_fround(0.0);
    $93 = ((($contactBuffer) + ($contactCount$149<<6)|0) + 12|0);
    HEAPF32[$93>>2] = $83;
    $94 = ((($contactBuffer) + ($contactCount$149<<6)|0) + 48|0);
    HEAP32[$94>>2] = -1;
    $95 = (((($this) + (($14*400)|0)|0) + ($j$048<<6)|0) + 112|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ((($contactBuffer) + ($contactCount$149<<6)|0) + 52|0);
    HEAP32[$97>>2] = $96;
    $98 = (($j$048) + 1)|0;
    $exitcond = ($98|0)==($31|0);
    if ($exitcond) {
     break;
    } else {
     $contactCount$149 = $84;$j$048 = $98;
    }
   }
   $99 = (($contactCount$051) - ($umax))|0;
   $contactCount$1$lcssa = $99;
  } else {
   $contactCount$1$lcssa = $contactCount$051;
  }
  $100 = (($i$050) + 1)|0;
  $101 = HEAP8[$1>>0]|0;
  $102 = $101&255;
  $103 = ($100>>>0)<($102>>>0);
  if (!($103)) {
   $contactCount$0$lcssa = $contactCount$1$lcssa;
   break;
  }
  $$pre = HEAP8[$0>>0]|0;
  $19 = $$pre;$contactCount$051 = $contactCount$1$lcssa;$i$050 = $100;
 }
 $104 = (($contactBuffer) + 4096|0);
 HEAP32[$104>>2] = $contactCount$0$lcssa;
 $105 = ($contactCount$0$lcssa|0)!=(0);
 STACKTOP = sp;return ($105|0);
}
function __ZN5physx2Gu31SinglePersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($agg$result,$this,$trB) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $trB = $trB|0;
 var $$lcssa = Math_fround(0), $$lcssa40 = Math_fround(0), $$lcssa41 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $i$042 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 36|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 384|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7>>>0)>(1);
 if ($8) {
  $16 = $1;$18 = $3;$20 = $5;$i$042 = 1;
  while(1) {
   $9 = ((($this) + ($i$042<<6)|0) + 32|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = ((($this) + ($i$042<<6)|0) + 36|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = ((($this) + ($i$042<<6)|0) + 40|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = Math_fround($16 + $10);
   $17 = Math_fround($18 + $12);
   $19 = Math_fround($20 + $14);
   $21 = (($i$042) + 1)|0;
   $22 = ($21>>>0)<($7>>>0);
   if ($22) {
    $16 = $15;$18 = $17;$20 = $19;$i$042 = $21;
   } else {
    $$lcssa = $19;$$lcssa40 = $17;$$lcssa41 = $15;
    break;
   }
  }
 } else {
  $$lcssa = $5;$$lcssa40 = $3;$$lcssa41 = $1;
 }
 $23 = Math_fround(HEAPF32[$trB>>2]);
 $24 = (($trB) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($trB) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($trB) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $29);
 $31 = Math_fround($30 + Math_fround(-0.5));
 $32 = Math_fround($$lcssa41 * $31);
 $33 = Math_fround($$lcssa40 * $31);
 $34 = Math_fround($$lcssa * $31);
 $35 = Math_fround($$lcssa * $25);
 $36 = Math_fround($$lcssa40 * $27);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($$lcssa41 * $27);
 $39 = Math_fround($$lcssa * $23);
 $40 = Math_fround($38 - $39);
 $41 = Math_fround($$lcssa40 * $23);
 $42 = Math_fround($$lcssa41 * $25);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($29 * $37);
 $45 = Math_fround($29 * $40);
 $46 = Math_fround($29 * $43);
 $47 = Math_fround($44 + $32);
 $48 = Math_fround($45 + $33);
 $49 = Math_fround($46 + $34);
 $50 = Math_fround($$lcssa41 * $23);
 $51 = Math_fround($$lcssa40 * $25);
 $52 = Math_fround($50 + $51);
 $53 = Math_fround($$lcssa * $27);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($23 * $54);
 $56 = Math_fround($25 * $54);
 $57 = Math_fround($27 * $54);
 $58 = Math_fround($55 + $47);
 $59 = Math_fround($56 + $48);
 $60 = Math_fround($57 + $49);
 $61 = Math_fround($58 * Math_fround(2.0));
 $62 = Math_fround($59 * Math_fround(2.0));
 $63 = Math_fround($60 * Math_fround(2.0));
 $64 = Math_fround($61 * $61);
 $65 = Math_fround($62 * $62);
 $66 = Math_fround($64 + $65);
 $67 = Math_fround($63 * $63);
 $68 = Math_fround($67 + $66);
 $69 = (Math_fround(Math_sqrt((Math_fround($68)))));
 $70 = Math_fround(Math_fround(1.0) / $69);
 $71 = Math_fround($70 * $61);
 $72 = Math_fround($70 * $62);
 $73 = Math_fround($70 * $63);
 HEAPF32[$agg$result>>2] = $71;
 $74 = (($agg$result) + 4|0);
 HEAPF32[$74>>2] = $72;
 $75 = (($agg$result) + 8|0);
 HEAPF32[$75>>2] = $73;
 $76 = (($agg$result) + 12|0);
 HEAPF32[$76>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5physx2Gu33MultiplePersistentContactManifold34addManifoldContactsToContactBufferERNS0_13ContactBufferERKNS_6shdfnd3aos12PsTransformVES8_RKNS5_6FloatVE($this,$contactBuffer,$trA,$trB,$radius) {
 $this = $this|0;
 $contactBuffer = $contactBuffer|0;
 $trA = $trA|0;
 $trB = $trB|0;
 $radius = $radius|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $contactCount$0$lcssa = 0, $contactCount$089 = 0, $contactCount$1$lcssa = 0, $contactCount$187 = 0, $exitcond = 0;
 var $i$088 = 0, $j$086 = 0, $normal = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $normal = sp;
 $0 = (($this) + 53|0);
 HEAP8[$0>>0] = 0;
 $1 = (($this) + 52|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $contactCount$0$lcssa = 0;
  $112 = (($contactBuffer) + 4096|0);
  HEAP32[$112>>2] = $contactCount$0$lcssa;
  $113 = ($contactCount$0$lcssa|0)!=(0);
  STACKTOP = sp;return ($113|0);
 }
 $4 = (($normal) + 4|0);
 $5 = (($normal) + 8|0);
 $6 = (($trA) + 4|0);
 $7 = (($trA) + 8|0);
 $8 = (($trA) + 12|0);
 $9 = (($trA) + 16|0);
 $10 = (($trA) + 20|0);
 $11 = (($trA) + 24|0);
 $19 = 0;$contactCount$089 = 0;$i$088 = 0;
 while(1) {
  $12 = ((($this) + ($i$088)|0) + 48|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = ((($this) + (($14*400)|0)|0) + 64|0);
  $16 = ((($this) + (($14*400)|0)|0) + 448|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $19&255;
  $20 = (($18) + ($17))|0;
  $21 = $20&255;
  HEAP8[$0>>0] = $21;
  __ZN5physx2Gu31SinglePersistentContactManifold14getWorldNormalERKNS_6shdfnd3aos12PsTransformVE($normal,$15,$trB);
  $22 = ($17|0)!=(0);
  $23 = ($contactCount$089>>>0)<(64);
  $24 = $22 & $23;
  if ($24) {
   $25 = Math_fround(HEAPF32[$normal>>2]);
   $26 = Math_fround(HEAPF32[$4>>2]);
   $27 = Math_fround(HEAPF32[$5>>2]);
   $28 = (0 - ($17))|0;
   $29 = (($contactCount$089) + -64)|0;
   $30 = ($29>>>0)<($28>>>0);
   $umax = $30 ? $28 : $29;
   $31 = (0 - ($umax))|0;
   $contactCount$187 = $contactCount$089;$j$086 = 0;
   while(1) {
    $32 = Math_fround(HEAPF32[$radius>>2]);
    $33 = Math_fround(HEAPF32[$trA>>2]);
    $34 = Math_fround(HEAPF32[$6>>2]);
    $35 = Math_fround(HEAPF32[$7>>2]);
    $36 = Math_fround(HEAPF32[$8>>2]);
    $37 = Math_fround(HEAPF32[$9>>2]);
    $38 = Math_fround(HEAPF32[$10>>2]);
    $39 = Math_fround(HEAPF32[$11>>2]);
    $40 = (((($this) + (($14*400)|0)|0) + ($j$086<<6)|0) + 64|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = (((($this) + (($14*400)|0)|0) + ($j$086<<6)|0) + 68|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = (((($this) + (($14*400)|0)|0) + ($j$086<<6)|0) + 72|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = Math_fround($36 * $36);
    $47 = Math_fround($46 + Math_fround(-0.5));
    $48 = Math_fround($47 * $41);
    $49 = Math_fround($47 * $43);
    $50 = Math_fround($47 * $45);
    $51 = Math_fround($34 * $45);
    $52 = Math_fround($35 * $43);
    $53 = Math_fround($51 - $52);
    $54 = Math_fround($35 * $41);
    $55 = Math_fround($33 * $45);
    $56 = Math_fround($54 - $55);
    $57 = Math_fround($33 * $43);
    $58 = Math_fround($34 * $41);
    $59 = Math_fround($57 - $58);
    $60 = Math_fround($36 * $53);
    $61 = Math_fround($36 * $56);
    $62 = Math_fround($36 * $59);
    $63 = Math_fround($48 + $60);
    $64 = Math_fround($49 + $61);
    $65 = Math_fround($50 + $62);
    $66 = Math_fround($33 * $41);
    $67 = Math_fround($34 * $43);
    $68 = Math_fround($66 + $67);
    $69 = Math_fround($35 * $45);
    $70 = Math_fround($68 + $69);
    $71 = Math_fround($33 * $70);
    $72 = Math_fround($34 * $70);
    $73 = Math_fround($35 * $70);
    $74 = Math_fround($71 + $63);
    $75 = Math_fround($72 + $64);
    $76 = Math_fround($65 + $73);
    $77 = Math_fround($74 * Math_fround(2.0));
    $78 = Math_fround($75 * Math_fround(2.0));
    $79 = Math_fround($76 * Math_fround(2.0));
    $80 = Math_fround($37 + $77);
    $81 = Math_fround($38 + $78);
    $82 = Math_fround($39 + $79);
    $83 = Math_fround($25 * $32);
    $84 = Math_fround($26 * $32);
    $85 = Math_fround($27 * $32);
    $86 = Math_fround($80 - $83);
    $87 = Math_fround($81 - $84);
    $88 = Math_fround($82 - $85);
    $89 = (((($this) + (($14*400)|0)|0) + ($j$086<<6)|0) + 108|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = Math_fround($90 - $32);
    $92 = (($contactCount$187) + 1)|0;
    $93 = (($contactBuffer) + ($contactCount$187<<6)|0);
    HEAPF32[$93>>2] = $25;
    $94 = (($93) + 4|0);
    HEAPF32[$94>>2] = $26;
    $95 = (($93) + 8|0);
    HEAPF32[$95>>2] = $27;
    $96 = (($93) + 12|0);
    HEAPF32[$96>>2] = Math_fround(0.0);
    $97 = ((($contactBuffer) + ($contactCount$187<<6)|0) + 16|0);
    HEAPF32[$97>>2] = $86;
    $98 = (($97) + 4|0);
    HEAPF32[$98>>2] = $87;
    $99 = (($97) + 8|0);
    HEAPF32[$99>>2] = $88;
    $100 = (($97) + 12|0);
    HEAPF32[$100>>2] = Math_fround(0.0);
    $101 = ((($contactBuffer) + ($contactCount$187<<6)|0) + 12|0);
    HEAPF32[$101>>2] = $91;
    $102 = ((($contactBuffer) + ($contactCount$187<<6)|0) + 48|0);
    HEAP32[$102>>2] = -1;
    $103 = (((($this) + (($14*400)|0)|0) + ($j$086<<6)|0) + 112|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ((($contactBuffer) + ($contactCount$187<<6)|0) + 52|0);
    HEAP32[$105>>2] = $104;
    $106 = (($j$086) + 1)|0;
    $exitcond = ($106|0)==($31|0);
    if ($exitcond) {
     break;
    } else {
     $contactCount$187 = $92;$j$086 = $106;
    }
   }
   $107 = (($contactCount$089) - ($umax))|0;
   $contactCount$1$lcssa = $107;
  } else {
   $contactCount$1$lcssa = $contactCount$089;
  }
  $108 = (($i$088) + 1)|0;
  $109 = HEAP8[$1>>0]|0;
  $110 = $109&255;
  $111 = ($108>>>0)<($110>>>0);
  if (!($111)) {
   $contactCount$0$lcssa = $contactCount$1$lcssa;
   break;
  }
  $$pre = HEAP8[$0>>0]|0;
  $19 = $$pre;$contactCount$089 = $contactCount$1$lcssa;$i$088 = $108;
 }
 $112 = (($contactBuffer) + 4096|0);
 HEAP32[$112>>2] = $contactCount$0$lcssa;
 $113 = ($contactCount$0$lcssa|0)!=(0);
 STACKTOP = sp;return ($113|0);
}
function __ZN5physx6shdfnd21atomicCompareExchangeEPViii($dest,$exch,$comp) {
 $dest = $dest|0;
 $exch = $exch|0;
 $comp = $comp|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$dest>>2]|0;if (($0|0) == ($comp|0)) HEAP32[$dest>>2] = $exch;
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx6shdfnd15atomicIncrementEPVi($val) {
 $val = $val|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$val>>2]|0;HEAP32[$val>>2] = (($0+1)|0);
 $1 = (($0) + 1)|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd15atomicDecrementEPVi($val) {
 $val = $val|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$val>>2]|0;HEAP32[$val>>2] = (($0-1)|0);
 $1 = (($0) + -1)|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd9atomicAddEPVii($val,$delta) {
 $val = $val|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$val>>2]|0;HEAP32[$val>>2] = (($0+$delta)|0);
 $1 = (($0) + ($delta))|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx6shdfnd9atomicMaxEPVii($val,$val2) {
 $val = $val|0;
 $val2 = $val2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $val2$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 while(1) {
  $0 = HEAP32[$val>>2]|0;
  $1 = ($0|0)<($val2|0);
  $val2$ = $1 ? $val2 : $0;
  $2 = HEAP32[$val>>2]|0;if (($2|0) == ($0|0)) HEAP32[$val>>2] = $val2$;
  $3 = ($2|0)==($0|0);
  if ($3) {
   break;
  }
 }
 $4 = HEAP32[$val>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN5physx6shdfnd14atomicExchangeEPVii($val,$val2) {
 $val = $val|0;
 $val2 = $val2|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 while(1) {
  $0 = HEAP32[$val>>2]|0;
  $1 = HEAP32[$val>>2]|0;if (($1|0) == ($0|0)) HEAP32[$val>>2] = $val2;
  $2 = ($1|0)==($0|0);
  if ($2) {
   break;
  }
 }
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx6shdfnd8FPUGuardC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8FPUGuardD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9MutexImplC2Ev($this) {
 $this = $this|0;
 var $attr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $attr = sp;
 (_pthread_mutexattr_init(($attr|0))|0);
 (_pthread_mutexattr_settype(($attr|0),1)|0);
 (_pthread_mutex_init(($this|0),($attr|0))|0);
 (_pthread_mutexattr_destroy(($attr|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9MutexImplD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_destroy(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9MutexImpl4lockEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_lock(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9MutexImpl6unlockEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_unlock(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9MutexImpl7getSizeEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (554240|0);
}
function __ZN5physx6shdfnd13ReadWriteLockC2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 1|0;
 $1 = sp;
 $2 = (__ZN5physx6shdfnd9Allocator8allocateEjPKci($1,8,554248,124)|0);
 HEAP32[$this>>2] = $2;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = $2;
  $4 = (($5) + 4|0);
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZN5physx6shdfnd6MutexTINS0_19ReflectionAllocatorINS0_9MutexImplEEEEC2ERKS4_($2,$0);
 $$pre = HEAP32[$this>>2]|0;
 $5 = $$pre;
 $4 = (($5) + 4|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd13ReadWriteLockD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 (_pthread_mutex_destroy(($2|0))|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vii[$8 & 4095]($5,$3);
 }
 $9 = HEAP32[$this>>2]|0;
 __ZN5physx6shdfnd9Allocator10deallocateEPv($0,$9);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd13ReadWriteLock10lockReaderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (_pthread_mutex_lock(($1|0))|0);
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 4|0);
 (__ZN5physx6shdfnd15atomicIncrementEPVi($3)|0);
 $4 = HEAP32[$this>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 (_pthread_mutex_unlock(($5|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd13ReadWriteLock10lockWriterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (_pthread_mutex_lock(($1|0))|0);
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 4|0);
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd13ReadWriteLock12unlockReaderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 4|0);
 (__ZN5physx6shdfnd15atomicDecrementEPVi($1)|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd13ReadWriteLock12unlockWriterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (_pthread_mutex_unlock(($1|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd6MutexTINS0_19ReflectionAllocatorINS0_9MutexImplEEEEC2ERKS4_($this,$alloc) {
 $this = $this|0;
 $alloc = $alloc|0;
 var $$$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $attr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $attr$i = sp;
 $0 = (__ZN5physx6shdfnd12getAllocatorEv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z15PxGetFoundationv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $$$i$i = $8 ? 554448 : 554416;
 $9 = (FUNCTION_TABLE_iiiiii[$3 & 255]($0,28,$$$i$i,554336,111)|0);
 HEAP32[$this>>2] = $9;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 (_pthread_mutexattr_init(($attr$i|0))|0);
 (_pthread_mutexattr_settype(($attr$i|0),1)|0);
 (_pthread_mutex_init(($9|0),($attr$i|0))|0);
 (_pthread_mutexattr_destroy(($attr$i|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd7PAUtilsC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd7PAUtilsD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9SListImplC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9SListImplD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9SListImpl4pushEPNS0_10SListEntryE($this,$entry) {
 $this = $this|0;
 $entry = $entry|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = 1;
 $2 = ($1|0)==(0);
 if (!($2)) {
  while(1) {
   $5 = HEAP32[$0>>2]|0;
   $6 = ($5|0)==(0);
   if (!($6)) {
    continue;
   }
   $3 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = 1;
   $4 = ($3|0)==(0);
   if ($4) {
    break;
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 HEAP32[$entry>>2] = $7;
 HEAP32[$this>>2] = $entry;
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd9SListImpl3popEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = 1;
 $2 = ($1|0)==(0);
 if (!($2)) {
  while(1) {
   $5 = HEAP32[$0>>2]|0;
   $6 = ($5|0)==(0);
   if (!($6)) {
    continue;
   }
   $3 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = 1;
   $4 = ($3|0)==(0);
   if ($4) {
    break;
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return ($7|0);
 }
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$this>>2] = $9;
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx6shdfnd9SListImpl5flushEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = 1;
 $2 = ($1|0)==(0);
 if (!($2)) {
  while(1) {
   $5 = HEAP32[$0>>2]|0;
   $6 = ($5|0)==(0);
   if (!($6)) {
    continue;
   }
   $3 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = 1;
   $4 = ($3|0)==(0);
   if ($4) {
    break;
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = 0;
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return ($7|0);
}
function __ZN5physx6shdfnd9SListImpl7getSizeEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (554576|0);
}
function __ZN5physx6shdfnd8SyncImpl7getSizeEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (554584|0);
}
function __ZN5physx6shdfnd8SyncImplC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_init(($this|0),(0|0))|0);
 $0 = (($this) + 24|0);
 (_pthread_cond_init(($0|0),(0|0))|0);
 $1 = (($this) + 76|0);
 HEAP8[$1>>0] = 0;
 $2 = (($this) + 72|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8SyncImplD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 (_pthread_cond_destroy(($0|0))|0);
 (_pthread_mutex_destroy(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8SyncImpl5resetEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_lock(($this|0))|0);
 $0 = (($this) + 76|0);
 HEAP8[$0>>0] = 0;
 (_pthread_mutex_unlock(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8SyncImpl3setEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_lock(($this|0))|0);
 $0 = (($this) + 76|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  (_pthread_mutex_unlock(($this|0))|0);
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 1;
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 HEAP32[$3>>2] = $5;
 $6 = (($this) + 24|0);
 (_pthread_cond_broadcast(($6|0))|0);
 (_pthread_mutex_unlock(($this|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd8SyncImpl4waitEj($this,$ms) {
 $this = $this|0;
 $ms = $ms|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $phitmp4 = 0;
 var $tp = 0, $ts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ts = sp + 8|0;
 $tp = sp;
 (_pthread_mutex_lock(($this|0))|0);
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 76|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 L1: do {
  if ($4) {
   $5 = ($ms|0)==(-1);
   if ($5) {
    $6 = (($this) + 24|0);
    while(1) {
     $7 = HEAP8[$2>>0]|0;
     $8 = ($7<<24>>24)==(0);
     if (!($8)) {
      break L1;
     }
     $9 = HEAP32[$0>>2]|0;
     $10 = ($1|0)==($9|0);
     if (!($10)) {
      break L1;
     }
     $11 = (_pthread_cond_wait(($6|0),($this|0))|0);
     $phitmp4 = ($11|0)==(0);
     if (!($phitmp4)) {
      break;
     }
    }
   } else {
    (_gettimeofday(($tp|0),(0|0))|0);
    $12 = (($ms>>>0) / 1000)&-1;
    $13 = Math_imul($12, -1000)|0;
    $14 = (($13) + ($ms))|0;
    $15 = ($14*1000)|0;
    $16 = (($tp) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + ($17))|0;
    $19 = (($18>>>0) / 1000000)&-1;
    $20 = Math_imul($19, -1000000)|0;
    $21 = (($18) + ($20))|0;
    $22 = HEAP32[$tp>>2]|0;
    $23 = (($19) + ($12))|0;
    $24 = (($23) + ($22))|0;
    HEAP32[$ts>>2] = $24;
    $25 = ($21*1000)|0;
    $26 = (($ts) + 4|0);
    HEAP32[$26>>2] = $25;
    $27 = (($this) + 24|0);
    while(1) {
     $28 = HEAP8[$2>>0]|0;
     $29 = ($28<<24>>24)==(0);
     if (!($29)) {
      break L1;
     }
     $30 = HEAP32[$0>>2]|0;
     $31 = ($1|0)==($30|0);
     if (!($31)) {
      break L1;
     }
     $32 = (_pthread_cond_timedwait(($27|0),($this|0),($ts|0))|0);
     $phitmp = ($32|0)==(0);
     if (!($phitmp)) {
      break;
     }
    }
   }
  }
 } while(0);
 $33 = HEAP8[$2>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  $37 = 1;
  (_pthread_mutex_unlock(($this|0))|0);
  STACKTOP = sp;return ($37|0);
 }
 $35 = HEAP32[$0>>2]|0;
 $36 = ($1|0)!=($35|0);
 $37 = $36;
 (_pthread_mutex_unlock(($this|0))|0);
 STACKTOP = sp;return ($37|0);
}
function __ZN5physx6shdfnd10ThreadImpl5getIdEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_self()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx6shdfnd8TlsAllocEv() {
 var $0 = 0, $key = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $key = sp;
 (_pthread_key_create(($key|0),(0|0))|0);
 $0 = HEAP32[$key>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx6shdfnd7TlsFreeEj($index) {
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_key_delete(($index|0))|0);
 STACKTOP = sp;return;
}
function __ZN5physx6shdfnd6TlsGetEj($index) {
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_getspecific(($index|0))|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5physx6shdfnd6TlsSetEjPv($index,$value) {
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_pthread_setspecific(($index|0),($value|0))|0);
 $1 = ($0|0)==(0);
 $2 = $1&1;
 STACKTOP = sp;return ($2|0);
}
function __ZN5physx6shdfnd4Time22getCurrentCounterValueEv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mCurrTimeInt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mCurrTimeInt = sp;
 (_clock_gettime(0,($mCurrTimeInt|0))|0);
 $0 = HEAP32[$mCurrTimeInt>>2]|0;
 $1 = ($0|0)<(0);
 $2 = $1 << 31 >> 31;
 $3 = (___muldi3(($0|0),($2|0),1000000000,0)|0);
 $4 = tempRet0;
 $5 = (($mCurrTimeInt) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)<(0);
 $8 = $7 << 31 >> 31;
 $9 = (_i64Add(($3|0),($4|0),($6|0),($8|0))|0);
 $10 = tempRet0;
 tempRet0 = $10;
 STACKTOP = sp;return ($9|0);
}
function __Znwj10MemLabelIdbiPKci($size,$label,$set_root,$align,$file,$line) {
 $size = $size|0;
 $label = $label|0;
 $set_root = $set_root|0;
 $align = $align|0;
 $file = $file|0;
 $line = $line|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 $2 = (__Z16GetMemoryManagerv()|0);
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($2,$size,$align,$$byval_copy,0,$file,$line)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z15malloc_internaljj10MemLabelIdiPKci($size,$align,$label,$allocateOptions,$file,$line) {
 $size = $size|0;
 $align = $align|0;
 $label = $label|0;
 $allocateOptions = $allocateOptions|0;
 $file = $file|0;
 $line = $line|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z16GetMemoryManagerv()|0);
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($1,$size,$align,$$byval_copy,$allocateOptions,$file,$line)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZdlPv10MemLabelIdbiPKci($p,$label,$0,$1,$2,$3) {
 $p = $p|0;
 $label = $label|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$byval_copy = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $4 = sp;
 $5 = HEAP32[$label>>2]|0;
 $6 = (__Z16GetMemoryManagerv()|0);
 HEAP32[$4>>2] = $5;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;
 __ZN13MemoryManager10DeallocateEPv10MemLabelId($6,$p,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z19free_alloc_internalPv10MemLabelId($ptr,$label) {
 $ptr = $ptr|0;
 $label = $label|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z16GetMemoryManagerv()|0);
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN13MemoryManager10DeallocateEPv10MemLabelId($1,$ptr,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z16GetMemoryManagerv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond3$i = 0, $i$02$i = 0, $i1$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[559440>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $27 = $0;
  STACKTOP = sp;return ($27|0);
 }
 __Z22InitializeMemoryLabelsv();
 $2 = HEAP32[559432>>2]|0;
 $3 = (($2) + 2752|0);
 HEAP32[559432>>2] = $3;
 $4 = ($3>>>0)>(((554592 + 4840|0))>>>0);
 if ($4) {
  _llvm_trap();
  // unreachable;
 }
 $5 = ($2|0)==(0|0);
 if ($5) {
  $26 = 0;
 } else {
  HEAP32[$2>>2] = 0;
  $6 = (($2) + 5|0);
  HEAP8[$6>>0] = 0;
  $7 = (($2) + 6|0);
  HEAP8[$7>>0] = 0;
  $8 = (($2) + 8|0);
  HEAP32[$8>>2] = 0;
  $9 = (($2) + 12|0);
  HEAP32[$9>>2] = 0;
  $10 = (($2) + 20|0);
  $11 = (($2) + 2276|0);
  _memset(($11|0),0,400)|0;
  _memset(($10|0),0,196)|0;
  $12 = HEAP32[559432>>2]|0;
  $13 = (($12) + 80|0);
  HEAP32[559432>>2] = $13;
  $14 = ($13>>>0)>(((554592 + 4840|0))>>>0);
  if ($14) {
   _llvm_trap();
   // unreachable;
  }
  $15 = ($12|0)==(0|0);
  if ($15) {
   $17 = 0;
  } else {
   __ZN20DynamicHeapAllocatorI17LowLevelAllocatorEC1EjjbP15BucketAllocatorPKc($12,1048576,0,1,0,559456);
   $17 = $12;
  }
  $16 = (($2) + 16|0);
  HEAP32[$16>>2] = $17;
  $18 = (($2) + 2268|0);
  HEAP32[$18>>2] = 0;
  $i$02$i = 0;
  while(1) {
   $19 = (($i$02$i) + 1)|0;
   $20 = $19;
   $21 = ((($2) + ($i$02$i<<2)|0) + 220|0);
   HEAP32[$21>>2] = $20;
   $exitcond3$i = ($19|0)==(512);
   if ($exitcond3$i) {
    $i1$01$i = 0;
    break;
   } else {
    $i$02$i = $19;
   }
  }
  while(1) {
   $22 = HEAP32[$16>>2]|0;
   $23 = ((($2) + ($i1$01$i<<2)|0) + 2276|0);
   HEAP32[$23>>2] = $22;
   $24 = (($i1$01$i) + 1)|0;
   $exitcond$i = ($24|0)==(100);
   if ($exitcond$i) {
    break;
   } else {
    $i1$01$i = $24;
   }
  }
  $25 = (($2) + 2676|0);
  HEAP32[$25>>2] = -1;
  $26 = $2;
 }
 HEAP32[559440>>2] = $26;
 $27 = $26;
 STACKTOP = sp;return ($27|0);
}
function __ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($this,$size,$align,$label,$allocateOptions,$file,$line) {
 $this = $this|0;
 $size = $size|0;
 $align = $align|0;
 $label = $label|0;
 $allocateOptions = $allocateOptions|0;
 $file = $file|0;
 $line = $line|0;
 var $$0 = 0, $$0$i = 0, $$0$in$i = 0, $$byval_copy1 = 0, $$size = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($size|0)==(0);
 $$size = $2 ? 1 : $size;
 $3 = (($align) + -1)|0;
 $4 = $3 | 15;
 $5 = (($4) + 1)|0;
 $6 = (($this) + 6|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = HEAP32[$label>>2]|0;
 $10 = ($9|0)==(90);
 if ($8) {
  if ($10) {
   $11 = (($this) + 20|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 1)|0;
   HEAP32[$11>>2] = $13;
  }
  $14 = (($this) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (FUNCTION_TABLE_iiii[$18 & 2047]($15,$$size,$5)|0);
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 }
 if ($10) {
  $20 = (($this) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (__ZN12TLSAllocatorI14StackAllocatorE8AllocateEji($21,$$size,$5)|0);
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $$0 = $22;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$1>>2] = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  $24 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($this,$$size,$5,$$byval_copy1,$allocateOptions,$file,$line)|0);
  $$0 = $24;
  STACKTOP = sp;return ($$0|0);
 }
 $25 = ($9|0)<(100);
 if ($25) {
  $26 = ((($this) + ($9<<2)|0) + 2276|0);
  $$0$in$i = $26;
 } else {
  $27 = (($9) + -100)|0;
  $28 = ((($this) + ($27<<2)|0) + 220|0);
  $$0$in$i = $28;
 }
 $$0$i = HEAP32[$$0$in$i>>2]|0;
 $29 = HEAP32[$$0$i>>2]|0;
 $30 = (($29) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($$0$i,$$size,$5)|0);
 $33 = $allocateOptions & 1;
 $34 = ($33|0)!=(0);
 $35 = ($32|0)==(0|0);
 $or$cond = $34 & $35;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($35)) {
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $9;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z16OutOfMemoryErrorji10MemLabelIdiPKc($$size,$5,$$byval_copy1,$line,$file);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __Z16realloc_internalPvji10MemLabelIdiPKci($ptr,$size,$align,$label,$allocateOptions,$file,$line) {
 $ptr = $ptr|0;
 $size = $size|0;
 $align = $align|0;
 $label = $label|0;
 $allocateOptions = $allocateOptions|0;
 $file = $file|0;
 $line = $line|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z16GetMemoryManagerv()|0);
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__ZN13MemoryManager10ReallocateEPvji10MemLabelIdiPKci($1,$ptr,$size,$align,$$byval_copy,$allocateOptions,$file,$line)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN13MemoryManager10ReallocateEPvji10MemLabelIdiPKci($this,$ptr,$size,$align,$label,$allocateOptions,$file,$line) {
 $this = $this|0;
 $ptr = $ptr|0;
 $size = $size|0;
 $align = $align|0;
 $label = $label|0;
 $allocateOptions = $allocateOptions|0;
 $file = $file|0;
 $line = $line|0;
 var $$0 = 0, $$0$i = 0, $$0$in$i = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = ($ptr|0)==(0|0);
 if ($5) {
  $6 = HEAP32[$label>>2]|0;
  HEAP32[$1>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  $7 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($this,$size,$align,$$byval_copy4,$allocateOptions,$file,$line)|0);
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ($size|0)==(0);
 if ($8) {
  $9 = HEAP32[$label>>2]|0;
  HEAP32[$2>>2] = $9;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN13MemoryManager10DeallocateEPv10MemLabelId($this,$ptr,$$byval_copy4);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($align) + -1)|0;
 $11 = $10 | 15;
 $12 = (($11) + 1)|0;
 $13 = (($this) + 6|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $16 = (($this) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_iiiii[$20 & 511]($17,$ptr,$size,$12)|0);
  $$0 = $21;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = HEAP32[$label>>2]|0;
 $23 = ($22|0)==(90);
 if ($23) {
  $24 = (($this) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (__ZN12TLSAllocatorI14StackAllocatorE10ReallocateEPvji($25,$ptr,$size,$12)|0);
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   $$0 = $26;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$3>>2] = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
  $28 = (__ZN13MemoryManager10ReallocateEPvji10MemLabelIdiPKci($this,$ptr,$size,$12,$$byval_copy4,$allocateOptions,$file,$line)|0);
  $$0 = $28;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = ($22|0)<(100);
 if ($29) {
  $30 = ((($this) + ($22<<2)|0) + 2276|0);
  $$0$in$i = $30;
 } else {
  $31 = (($22) + -100)|0;
  $32 = ((($this) + ($31<<2)|0) + 220|0);
  $$0$in$i = $32;
 }
 $$0$i = HEAP32[$$0$in$i>>2]|0;
 $33 = HEAP32[$$0$i>>2]|0;
 $34 = (($33) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (FUNCTION_TABLE_iii[$35 & 4095]($$0$i,$ptr)|0);
 if ($36) {
  $55 = HEAP32[$$0$i>>2]|0;
  $56 = (($55) + 16|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (FUNCTION_TABLE_iiiii[$57 & 511]($$0$i,$ptr,$size,$12)|0);
  $59 = $allocateOptions & 1;
  $60 = ($59|0)!=(0);
  $61 = ($58|0)==(0|0);
  $or$cond1 = $60 & $61;
  if ($or$cond1) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  if (!($61)) {
   $$0 = $58;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$0>>2] = $22;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  __Z16OutOfMemoryErrorji10MemLabelIdiPKc($size,$12,$$byval_copy4,$line,$file);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$4>>2] = $22;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
 $37 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($this,$size,$12,$$byval_copy4,$allocateOptions,$file,$line)|0);
 $38 = $allocateOptions & 1;
 $39 = ($38|0)!=(0);
 $40 = ($37|0)==(0|0);
 $or$cond = $39 & $40;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = (__ZN13MemoryManager25GetAllocatorContainingPtrEPKv($this,$ptr)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 32|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (FUNCTION_TABLE_iii[$44 & 4095]($41,$ptr)|0);
 $46 = ($45>>>0)<($size>>>0);
 $47 = $46 ? $45 : $size;
 _memcpy(($37|0),($ptr|0),($47|0))|0;
 $48 = (__ZN13MemoryManager25GetAllocatorContainingPtrEPKv($this,$ptr)|0);
 $49 = ($48|0)==(0|0);
 if (!($49)) {
  $50 = HEAP32[$48>>2]|0;
  $51 = (($50) + 20|0);
  $52 = HEAP32[$51>>2]|0;
  FUNCTION_TABLE_vii[$52 & 4095]($48,$ptr);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 }
 $53 = HEAP8[$13>>0]|0;
 $54 = ($53<<24>>24)==(0);
 if ($54) {
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 }
 _free($ptr);
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MemoryManager10DeallocateEPv10MemLabelId($this,$ptr,$label) {
 $this = $this|0;
 $ptr = $ptr|0;
 $label = $label|0;
 var $$0$i = 0, $$0$in$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($ptr|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 6|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $5 = HEAP32[$label>>2]|0;
 $6 = ($5|0)==(90);
 if ($4) {
  if ($6) {
   $7 = (($this) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + -1)|0;
   HEAP32[$7>>2] = $9;
  }
  $10 = (__ZN13MemoryManager25GetAllocatorContainingPtrEPKv($this,$ptr)|0);
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$10>>2]|0;
   $13 = (($12) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vii[$14 & 4095]($10,$ptr);
   STACKTOP = sp;return;
  }
  $15 = HEAP8[$2>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   STACKTOP = sp;return;
  }
  _free($ptr);
  STACKTOP = sp;return;
 }
 if ($6) {
  $17 = (($this) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (__ZN12TLSAllocatorI14StackAllocatorE13TryDeallocateEPv($18,$ptr)|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN13MemoryManager10DeallocateEPv10MemLabelId($this,$ptr,$$byval_copy);
  STACKTOP = sp;return;
 }
 $20 = ($5|0)<(100);
 if ($20) {
  $21 = ((($this) + ($5<<2)|0) + 2276|0);
  $$0$in$i = $21;
 } else {
  $22 = (($5) + -100)|0;
  $23 = ((($this) + ($22<<2)|0) + 220|0);
  $$0$in$i = $23;
 }
 $$0$i = HEAP32[$$0$in$i>>2]|0;
 $24 = HEAP32[$$0$i>>2]|0;
 $25 = (($24) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (FUNCTION_TABLE_iii[$26 & 4095]($$0$i,$ptr)|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (__ZN13MemoryManager25GetAllocatorContainingPtrEPKv($this,$ptr)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + 20|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vii[$32 & 4095]($28,$ptr);
  STACKTOP = sp;return;
 }
 $33 = HEAP8[$2>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if ($34) {
  STACKTOP = sp;return;
 }
 _free($ptr);
 STACKTOP = sp;return;
}
function __ZN13MemoryManager16StaticInitializeEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetMemoryManagerv()|0);
 __ZN13MemoryManager16ThreadInitializeEj($0,0);
 STACKTOP = sp;return;
}
function __ZN13MemoryManager16ThreadInitializeEj($this,$tempSize) {
 $this = $this|0;
 $tempSize = $tempSize|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tempAllocatorSize$0 = 0, $tempAllocatorSize$0$tempSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 5|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  __ZN13MemoryManager30InitializeMainThreadAllocatorsEv($this);
  $tempAllocatorSize$0 = 131072;
 } else {
  $tempAllocatorSize$0 = 65536;
 }
 $4 = ($tempSize|0)==(0);
 $tempAllocatorSize$0$tempSize = $4 ? $tempAllocatorSize$0 : $tempSize;
 $5 = HEAP32[628240>>2]|0;
 $6 = (__Z16GetMemoryManagerv()|0);
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $7 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($6,64,16,$$byval_copy1,0,559568,804)|0);
 __THREW__ = 0;
 invoke_viii(1614,($7|0),($tempAllocatorSize$0$tempSize|0),(559472|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 72|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vii[$14 & 4095]($11,$7);
  STACKTOP = sp;return;
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __THREW__ = 0;
 $17 = (invoke_i(54)|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 }
 HEAP32[$0>>2] = $5;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1615,($17|0),($7|0),($$byval_copy1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZN13MemoryManager30InitializeMainThreadAllocatorsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[559432>>2]|0;
 $1 = (($0) + 544|0);
 HEAP32[559432>>2] = $1;
 $2 = ($1>>>0)>(((554592 + 4840|0))>>>0);
 if ($2) {
  _llvm_trap();
  // unreachable;
 }
 $3 = ($0|0)==(0|0);
 if ($3) {
  $5 = 0;
 } else {
  __ZN12TLSAllocatorI14StackAllocatorEC1EPKc($0,559472);
  $5 = $0;
 }
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = $5;
 $6 = HEAP32[559432>>2]|0;
 $7 = (($6) + 80|0);
 HEAP32[559432>>2] = $7;
 $8 = ($7>>>0)>(((554592 + 4840|0))>>>0);
 if ($8) {
  _llvm_trap();
  // unreachable;
 }
 $9 = ($6|0)==(0|0);
 if ($9) {
  $13 = 0;
 } else {
  __ZN21UnityDefaultAllocatorI17LowLevelAllocatorEC1EPKc($6,559496);
  $13 = $6;
 }
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$this>>2] = $11;
 $12 = ((($this) + ($10<<2)|0) + 24|0);
 HEAP32[$12>>2] = $13;
 $i$05 = 0;
 while(1) {
  $14 = ((($this) + ($i$05<<2)|0) + 2276|0);
  HEAP32[$14>>2] = $13;
  $15 = (($i$05) + 1)|0;
  $exitcond = ($15|0)==(100);
  if ($exitcond) {
   break;
  } else {
   $i$05 = $15;
  }
 }
 $16 = HEAP32[$4>>2]|0;
 $17 = (($this) + 2636|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP32[559432>>2]|0;
 $19 = (($18) + 80|0);
 HEAP32[559432>>2] = $19;
 $20 = ($19>>>0)>(((554592 + 4840|0))>>>0);
 if ($20) {
  _llvm_trap();
  // unreachable;
 }
 $21 = ($18|0)==(0|0);
 if ($21) {
  $25 = 0;
 } else {
  __ZN21UnityDefaultAllocatorI17LowLevelAllocatorEC1EPKc($18,559512);
  $25 = $18;
 }
 $22 = HEAP32[$this>>2]|0;
 $23 = (($22) + 1)|0;
 HEAP32[$this>>2] = $23;
 $24 = ((($this) + ($22<<2)|0) + 24|0);
 HEAP32[$24>>2] = $25;
 $26 = HEAP32[559432>>2]|0;
 $27 = (($26) + 80|0);
 HEAP32[559432>>2] = $27;
 $28 = ($27>>>0)>(((554592 + 4840|0))>>>0);
 if ($28) {
  _llvm_trap();
  // unreachable;
 }
 $29 = ($26|0)==(0|0);
 if ($29) {
  $33 = 0;
 } else {
  __ZN21UnityDefaultAllocatorI17LowLevelAllocatorEC1EPKc($26,559536);
  $33 = $26;
 }
 $30 = HEAP32[$this>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$this>>2] = $31;
 $32 = ((($this) + ($30<<2)|0) + 24|0);
 HEAP32[$32>>2] = $33;
 $34 = HEAP32[559432>>2]|0;
 $35 = (($34) + 80|0);
 HEAP32[559432>>2] = $35;
 $36 = ($35>>>0)>(((554592 + 4840|0))>>>0);
 if ($36) {
  _llvm_trap();
  // unreachable;
 }
 $37 = ($34|0)==(0|0);
 if ($37) {
  $41 = 0;
 } else {
  __ZN21UnityDefaultAllocatorI17LowLevelAllocatorEC1EPKc($34,559552);
  $41 = $34;
 }
 $38 = HEAP32[$this>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$this>>2] = $39;
 $40 = ((($this) + ($38<<2)|0) + 24|0);
 HEAP32[$40>>2] = $41;
 $42 = (($this) + 2328|0);
 HEAP32[$42>>2] = $33;
 $43 = (($this) + 2320|0);
 HEAP32[$43>>2] = $33;
 $44 = (($this) + 2308|0);
 HEAP32[$44>>2] = $33;
 $45 = (($this) + 2316|0);
 HEAP32[$45>>2] = $33;
 $46 = (($this) + 2312|0);
 HEAP32[$46>>2] = $33;
 $47 = (($this) + 2304|0);
 HEAP32[$47>>2] = $33;
 $48 = (($this) + 2444|0);
 HEAP32[$48>>2] = $25;
 $49 = (($this) + 2484|0);
 HEAP32[$49>>2] = $41;
 $50 = (($this) + 2480|0);
 HEAP32[$50>>2] = $41;
 $51 = (($this) + 2476|0);
 HEAP32[$51>>2] = $41;
 $52 = (($this) + 5|0);
 HEAP8[$52>>0] = 1;
 $53 = (($this) + 6|0);
 HEAP8[$53>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN13MemoryManager16LowLevelAllocateEj($size) {
 $size = $size|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_malloc($size)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13MemoryManager17LowLevelCAllocateEjj($count,$size) {
 $count = $count|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_imul($size, $count)|0;
 $1 = (_malloc($0)|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  _memset(($1|0),0,($0|0))|0;
 }
 STACKTOP = sp;return ($1|0);
}
function __ZN13MemoryManager18LowLevelReallocateEPvjj($p,$size,$oldSize) {
 $p = $p|0;
 $size = $size|0;
 $oldSize = $oldSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_realloc($p,$size)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13MemoryManager12LowLevelFreeEPvj($p,$oldSize) {
 $p = $p|0;
 $oldSize = $oldSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($p|0)==(0|0);
 if (!($0)) {
  _free($p);
 }
 STACKTOP = sp;return;
}
function __ZN13MemoryManager16FrameMaintenanceEb($this,$cleanup) {
 $this = $this|0;
 $cleanup = $cleanup|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$cleanup);
 $5 = HEAP32[$this>>2]|0;
 $6 = ($5|0)>(0);
 if ($6) {
  $i$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $7 = ((($this) + ($i$01<<2)|0) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 80|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($8,$cleanup);
  $12 = (($i$01) + 1)|0;
  $13 = HEAP32[$this>>2]|0;
  $14 = ($12|0)<($13|0);
  if ($14) {
   $i$01 = $12;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z16OutOfMemoryErrorji10MemLabelIdiPKc($size,$align,$label,$line,$file) {
 $size = $size|0;
 $align = $align|0;
 $label = $label|0;
 $line = $line|0;
 $file = $file|0;
 var $$0 = 0, $$01 = 0, $$byval_copy19 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $str = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr8 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy19 = sp;
 $0 = sp + 84|0;
 $1 = sp + 80|0;
 $2 = sp + 76|0;
 $3 = sp + 72|0;
 $4 = sp + 68|0;
 $5 = sp + 88|0;
 $6 = sp + 48|0;
 $str = sp + 36|0;
 $7 = sp + 24|0;
 $8 = sp + 12|0;
 $9 = sp + 52|0;
 $10 = sp + 64|0;
 ;HEAP32[$str+0>>2]=0|0;HEAP32[$str+4>>2]=0|0;HEAP32[$str+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2585,($str|0),30720);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if ($12) {
   label = 46;
  } else {
   __THREW__ = 0;
   invoke_viii(1616,($7|0),(559576|0),($$byval_copy19|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 46;
   } else {
    $15 = HEAP8[$7>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     $22 = (($7) + 1|0);
     $23 = $15&255;
     $24 = $23 >>> 1;
     $25 = $22;$26 = $24;
    } else {
     $18 = (($7) + 8|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($7) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $25 = $19;$26 = $21;
    }
    __THREW__ = 0;
    (invoke_iiii(1529,($str|0),($25|0),($26|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $138 = ___cxa_find_matching_catch()|0;
     $139 = tempRet0;
     $140 = HEAP8[$7>>0]|0;
     $141 = $140 & 1;
     $142 = ($141<<24>>24)==(0);
     if ($142) {
      $$0 = $139;$$01 = $138;
      break;
     }
     $143 = (($7) + 8|0);
     $144 = HEAP32[$143>>2]|0;
     __THREW__ = 0;
     $145 = (invoke_i(54)|0);
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      $150 = ___cxa_find_matching_catch()|0;
      $151 = tempRet0;
      ___cxa_call_unexpected(($150|0));
      // unreachable;
     }
     HEAP32[$3>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_viii(1615,($145|0),($144|0),($$byval_copy19|0));
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     if (!($149)) {
      $$0 = $139;$$01 = $138;
      break;
     }
     $150 = ___cxa_find_matching_catch()|0;
     $151 = tempRet0;
     ___cxa_call_unexpected(($150|0));
     // unreachable;
    }
    $29 = HEAP8[$7>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if (!($31)) {
     $32 = (($7) + 8|0);
     $33 = HEAP32[$32>>2]|0;
     __THREW__ = 0;
     $34 = (invoke_i(54)|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $39 = ___cxa_find_matching_catch()|0;
      $40 = tempRet0;
      ___cxa_call_unexpected(($39|0));
      // unreachable;
     }
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_viii(1615,($34|0),($33|0),($$byval_copy19|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $39 = ___cxa_find_matching_catch()|0;
      $40 = tempRet0;
      ___cxa_call_unexpected(($39|0));
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_i(54)|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 46;
    } else {
     $43 = HEAP32[$label>>2]|0;
     $44 = ($43|0)<(100);
     if ($44) {
      $45 = (629936 + ($43<<2)|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = $46;
     } else {
      $47 = 559840;
     }
     __THREW__ = 0;
     HEAP32[$$byval_copy19>>2] = $size;
     $vararg_ptr3 = (($$byval_copy19) + 4|0);
     HEAP32[$vararg_ptr3>>2] = $align;
     $vararg_ptr4 = (($$byval_copy19) + 8|0);
     HEAP32[$vararg_ptr4>>2] = $47;
     invoke_viii(1616,($8|0),(559632|0),($$byval_copy19|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      label = 46;
     } else {
      $50 = HEAP8[$8>>0]|0;
      $51 = $50 & 1;
      $52 = ($51<<24>>24)==(0);
      if ($52) {
       $57 = (($8) + 1|0);
       $58 = $50&255;
       $59 = $58 >>> 1;
       $60 = $57;$61 = $59;
      } else {
       $53 = (($8) + 8|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = (($8) + 4|0);
       $56 = HEAP32[$55>>2]|0;
       $60 = $54;$61 = $56;
      }
      __THREW__ = 0;
      (invoke_iiii(1529,($str|0),($60|0),($61|0))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       $152 = ___cxa_find_matching_catch()|0;
       $153 = tempRet0;
       $154 = HEAP8[$8>>0]|0;
       $155 = $154 & 1;
       $156 = ($155<<24>>24)==(0);
       if ($156) {
        $$0 = $153;$$01 = $152;
        break;
       }
       $157 = (($8) + 8|0);
       $158 = HEAP32[$157>>2]|0;
       __THREW__ = 0;
       $159 = (invoke_i(54)|0);
       $160 = __THREW__; __THREW__ = 0;
       $161 = $160&1;
       if ($161) {
        $164 = ___cxa_find_matching_catch()|0;
        $165 = tempRet0;
        ___cxa_call_unexpected(($164|0));
        // unreachable;
       }
       HEAP32[$4>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
       invoke_viii(1615,($159|0),($158|0),($$byval_copy19|0));
       $162 = __THREW__; __THREW__ = 0;
       $163 = $162&1;
       if (!($163)) {
        $$0 = $153;$$01 = $152;
        break;
       }
       $164 = ___cxa_find_matching_catch()|0;
       $165 = tempRet0;
       ___cxa_call_unexpected(($164|0));
       // unreachable;
      }
      $64 = HEAP8[$8>>0]|0;
      $65 = $64 & 1;
      $66 = ($65<<24>>24)==(0);
      if (!($66)) {
       $67 = (($8) + 8|0);
       $68 = HEAP32[$67>>2]|0;
       __THREW__ = 0;
       $69 = (invoke_i(54)|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        $74 = ___cxa_find_matching_catch()|0;
        $75 = tempRet0;
        ___cxa_call_unexpected(($74|0));
        // unreachable;
       }
       HEAP32[$1>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_viii(1615,($69|0),($68|0),($$byval_copy19|0));
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        $74 = ___cxa_find_matching_catch()|0;
        $75 = tempRet0;
        ___cxa_call_unexpected(($74|0));
        // unreachable;
       }
      }
      __THREW__ = 0;
      HEAP32[$$byval_copy19>>2] = $line;
      $vararg_ptr8 = (($$byval_copy19) + 4|0);
      HEAP32[$vararg_ptr8>>2] = $file;
      invoke_viii(1616,($9|0),(559696|0),($$byval_copy19|0));
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       label = 46;
      } else {
       $78 = HEAP8[$9>>0]|0;
       $79 = $78 & 1;
       $80 = ($79<<24>>24)==(0);
       if ($80) {
        $85 = (($9) + 1|0);
        $86 = $78&255;
        $87 = $86 >>> 1;
        $88 = $85;$89 = $87;
       } else {
        $81 = (($9) + 8|0);
        $82 = HEAP32[$81>>2]|0;
        $83 = (($9) + 4|0);
        $84 = HEAP32[$83>>2]|0;
        $88 = $82;$89 = $84;
       }
       __THREW__ = 0;
       (invoke_iiii(1529,($str|0),($88|0),($89|0))|0);
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        $166 = ___cxa_find_matching_catch()|0;
        $167 = tempRet0;
        $168 = HEAP8[$9>>0]|0;
        $169 = $168 & 1;
        $170 = ($169<<24>>24)==(0);
        if ($170) {
         $$0 = $167;$$01 = $166;
         break;
        }
        $171 = (($9) + 8|0);
        $172 = HEAP32[$171>>2]|0;
        __THREW__ = 0;
        $173 = (invoke_i(54)|0);
        $174 = __THREW__; __THREW__ = 0;
        $175 = $174&1;
        if ($175) {
         $178 = ___cxa_find_matching_catch()|0;
         $179 = tempRet0;
         ___cxa_call_unexpected(($178|0));
         // unreachable;
        }
        HEAP32[$5>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$5+0>>2]|0;
        invoke_viii(1615,($173|0),($172|0),($$byval_copy19|0));
        $176 = __THREW__; __THREW__ = 0;
        $177 = $176&1;
        if (!($177)) {
         $$0 = $167;$$01 = $166;
         break;
        }
        $178 = ___cxa_find_matching_catch()|0;
        $179 = tempRet0;
        ___cxa_call_unexpected(($178|0));
        // unreachable;
       }
       $92 = HEAP8[$9>>0]|0;
       $93 = $92 & 1;
       $94 = ($93<<24>>24)==(0);
       if (!($94)) {
        $95 = (($9) + 8|0);
        $96 = HEAP32[$95>>2]|0;
        __THREW__ = 0;
        $97 = (invoke_i(54)|0);
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         $102 = ___cxa_find_matching_catch()|0;
         $103 = tempRet0;
         ___cxa_call_unexpected(($102|0));
         // unreachable;
        }
        HEAP32[$2>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_viii(1615,($97|0),($96|0),($$byval_copy19|0));
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         $102 = ___cxa_find_matching_catch()|0;
         $103 = tempRet0;
         ___cxa_call_unexpected(($102|0));
         // unreachable;
        }
       }
       HEAP32[$10>>2] = $43;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$10+0>>2]|0;
       invoke_vii(2586,($str|0),($$byval_copy19|0));
       $104 = __THREW__; __THREW__ = 0;
       $105 = $104&1;
       if ($105) {
        label = 46;
       } else {
        $106 = HEAP8[$str>>0]|0;
        $107 = $106 & 1;
        $108 = ($107<<24>>24)==(0);
        if ($108) {
         $111 = (($str) + 1|0);
         $112 = $111;
        } else {
         $109 = (($str) + 8|0);
         $110 = HEAP32[$109>>2]|0;
         $112 = $110;
        }
        __THREW__ = 0;
        HEAP32[$$byval_copy19>>2] = $112;
        invoke_vii(2587,(559736|0),($$byval_copy19|0));
        $113 = __THREW__; __THREW__ = 0;
        $114 = $113&1;
        if ($114) {
         label = 46;
        } else {
         $115 = HEAP8[$str>>0]|0;
         $116 = $115 & 1;
         $117 = ($116<<24>>24)==(0);
         if ($117) {
          $120 = (($str) + 1|0);
          $121 = $120;
         } else {
          $118 = (($str) + 8|0);
          $119 = HEAP32[$118>>2]|0;
          $121 = $119;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,($121|0),0,(559568|0),919,32785,0,0,(0|0));
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 46;
          break;
         }
         $124 = HEAP8[$str>>0]|0;
         $125 = $124 & 1;
         $126 = ($125<<24>>24)==(0);
         if ($126) {
          STACKTOP = sp;return;
         }
         $127 = (($str) + 8|0);
         $128 = HEAP32[$127>>2]|0;
         __THREW__ = 0;
         $129 = (invoke_i(54)|0);
         $130 = __THREW__; __THREW__ = 0;
         $131 = $130&1;
         if ($131) {
          $134 = ___cxa_find_matching_catch()|0;
          $135 = tempRet0;
          ___cxa_call_unexpected(($134|0));
          // unreachable;
         }
         HEAP32[$3>>2] = 90;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
         invoke_viii(1615,($129|0),($128|0),($$byval_copy19|0));
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          $134 = ___cxa_find_matching_catch()|0;
          $135 = tempRet0;
          ___cxa_call_unexpected(($134|0));
          // unreachable;
         } else {
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 46) {
  $136 = ___cxa_find_matching_catch()|0;
  $137 = tempRet0;
  $$0 = $137;$$01 = $136;
 }
 $180 = HEAP8[$str>>0]|0;
 $181 = $180 & 1;
 $182 = ($181<<24>>24)==(0);
 if ($182) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $183 = (($str) + 8|0);
 $184 = HEAP32[$183>>2]|0;
 __THREW__ = 0;
 $185 = (invoke_i(54)|0);
 $186 = __THREW__; __THREW__ = 0;
 $187 = $186&1;
 if ($187) {
  $190 = ___cxa_find_matching_catch()|0;
  $191 = tempRet0;
  ___cxa_call_unexpected(($190|0));
  // unreachable;
 }
 HEAP32[$6>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_viii(1615,($185|0),($184|0),($$byval_copy19|0));
 $188 = __THREW__; __THREW__ = 0;
 $189 = $188&1;
 if ($189) {
  $190 = ___cxa_find_matching_catch()|0;
  $191 = tempRet0;
  ___cxa_call_unexpected(($190|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE7reserveEj($this,$__res_arg) {
 $this = $this|0;
 $__res_arg = $__res_arg|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_data$0 = 0, $__new_data$1 = 0, $__now_long$0$off0 = 0, $__p$0 = 0, $__was_long$0$off0 = 0, $phitmp$i = 0, $phitmp$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($__res_arg>>>0)>(2147483631);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $10 = $3;$24 = 10;
 } else {
  $6 = HEAP32[$this>>2]|0;
  $7 = $6 & -2;
  $phitmp$i = (($7) + -1)|0;
  $8 = $6&255;
  $10 = $8;$24 = $phitmp$i;
 }
 $9 = $10 & 1;
 $11 = ($9<<24>>24)==(0);
 if ($11) {
  $14 = $10&255;
  $15 = $14 >>> 1;
  $17 = $15;
 } else {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $17 = $13;
 }
 $16 = ($17>>>0)>($__res_arg>>>0);
 $18 = $16 ? $17 : $__res_arg;
 $19 = ($18>>>0)<(11);
 if ($19) {
  $23 = 10;
 } else {
  $20 = (($18) + 16)|0;
  $21 = $20 & -16;
  $phitmp$i1 = (($21) + -1)|0;
  $23 = $phitmp$i1;
 }
 $22 = ($23|0)==($24|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $25 = ($23|0)==(10);
 do {
  if ($25) {
   $26 = (($this) + 1|0);
   $27 = (($this) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   $48 = $10;$__new_data$1 = $26;$__now_long$0$off0 = 0;$__p$0 = $28;$__was_long$0$off0 = 1;
  } else {
   $29 = ($23>>>0)>($24>>>0);
   $30 = (($23) + 1)|0;
   do {
    if ($29) {
     $31 = (__Z16GetMemoryManagerv()|0);
     HEAP32[$0>>2] = 90;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $32 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($31,$30,16,$$byval_copy2,0,559568,79)|0);
     $__new_data$0 = $32;
    } else {
     __THREW__ = 0;
     $33 = (invoke_i(54)|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      HEAP32[$0>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
      $36 = (invoke_iiiiiiii(107,($33|0),($30|0),16,($$byval_copy2|0),0,(559568|0),79)|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $__new_data$0 = $36;
       break;
      }
     }
     $39 = ___cxa_find_matching_catch(0|0)|0;
     $40 = tempRet0;
     (___cxa_begin_catch(($39|0))|0);
     ___cxa_end_catch();
     STACKTOP = sp;return;
    }
   } while(0);
   $41 = HEAP8[$this>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $46 = (($this) + 1|0);
    $48 = $41;$__new_data$1 = $__new_data$0;$__now_long$0$off0 = 1;$__p$0 = $46;$__was_long$0$off0 = 0;
    break;
   } else {
    $44 = (($this) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $48 = $41;$__new_data$1 = $__new_data$0;$__now_long$0$off0 = 1;$__p$0 = $45;$__was_long$0$off0 = 1;
    break;
   }
  }
 } while(0);
 $47 = $48 & 1;
 $49 = ($47<<24>>24)==(0);
 if ($49) {
  $52 = $48&255;
  $53 = $52 >>> 1;
  $55 = $53;
 } else {
  $50 = (($this) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $55 = $51;
 }
 $54 = (($55) + 1)|0;
 _memcpy(($__new_data$1|0),($__p$0|0),($54|0))|0;
 if ($__was_long$0$off0) {
  __THREW__ = 0;
  $56 = (invoke_i(54)|0);
  $57 = __THREW__; __THREW__ = 0;
  $58 = $57&1;
  if ($58) {
   $61 = ___cxa_find_matching_catch()|0;
   $62 = tempRet0;
   ___cxa_call_unexpected(($61|0));
   // unreachable;
  }
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viii(1615,($56|0),($__p$0|0),($$byval_copy2|0));
  $59 = __THREW__; __THREW__ = 0;
  $60 = $59&1;
  if ($60) {
   $61 = ___cxa_find_matching_catch()|0;
   $62 = tempRet0;
   ___cxa_call_unexpected(($61|0));
   // unreachable;
  }
 }
 if ($__now_long$0$off0) {
  $63 = (($23) + 1)|0;
  $64 = $63 | 1;
  HEAP32[$this>>2] = $64;
  $65 = (($this) + 4|0);
  HEAP32[$65>>2] = $17;
  $66 = (($this) + 8|0);
  HEAP32[$66>>2] = $__new_data$1;
  STACKTOP = sp;return;
 } else {
  $67 = $17 << 1;
  $68 = $67&255;
  HEAP8[$this>>0] = $68;
  STACKTOP = sp;return;
 }
}
function __Z12FormatStringINSt3__112basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEET_PKcz($agg$result,$format,$varargs) {
 $agg$result = $agg$result|0;
 $format = $format|0;
 $varargs = $varargs|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i = 0, $buffer = 0, $va = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 10272|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $buffer = sp + 32|0;
 $va = sp + 8|0;
 HEAP32[$va>>2] = $varargs;
 __Z13VFormatBufferPciPKcPi($buffer,10240,$format,$va);
 $1 = (_strlen(($buffer|0))|0);
 $2 = ($1>>>0)>(2147483631);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$agg$result>>0] = $5;
  $6 = (($agg$result) + 1|0);
  $__p$0$i$i = $6;
  _memcpy(($__p$0$i$i|0),($buffer|0),($1|0))|0;
  $14 = (($__p$0$i$i) + ($1)|0);
  HEAP8[$14>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Z16GetMemoryManagerv()|0);
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $10 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($9,$8,16,$$byval_copy,0,559568,79)|0);
  $11 = (($agg$result) + 8|0);
  HEAP32[$11>>2] = $10;
  $12 = $8 | 1;
  HEAP32[$agg$result>>2] = $12;
  $13 = (($agg$result) + 4|0);
  HEAP32[$13>>2] = $1;
  $__p$0$i$i = $10;
  _memcpy(($__p$0$i$i|0),($buffer|0),($1|0))|0;
  $14 = (($__p$0$i$i) + ($1)|0);
  HEAP8[$14>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __Z21PrintShortMemoryStatsRNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEE10MemLabelId($str,$label) {
 $str = $str|0;
 $label = $label|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy4 = sp;
 $0 = sp + 32|0;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 $3 = (__Z16GetMemoryManagerv()|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6appendEPKcj($str,559848,17)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($2) + 1|0);
 $7 = (($2) + 8|0);
 $8 = (($2) + 4|0);
 $i$04 = 0;
 while(1) {
  $9 = ((($3) + ($i$04<<2)|0) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$10>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (FUNCTION_TABLE_ii[$14 & 4095]($10)|0);
   $16 = HEAP32[$10>>2]|0;
   $17 = (($16) + 44|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (FUNCTION_TABLE_ii[$18 & 4095]($10)|0);
   $20 = HEAP32[$10>>2]|0;
   $21 = (($20) + 52|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (FUNCTION_TABLE_ii[$22 & 4095]($10)|0);
   $24 = HEAP32[$10>>2]|0;
   $25 = (($24) + 48|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (FUNCTION_TABLE_ii[$26 & 4095]($10)|0);
   HEAP32[$$byval_copy4>>2] = $15;
   $vararg_ptr1 = (($$byval_copy4) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $19;
   $vararg_ptr2 = (($$byval_copy4) + 8|0);
   HEAP32[$vararg_ptr2>>2] = $23;
   $vararg_ptr3 = (($$byval_copy4) + 12|0);
   HEAP32[$vararg_ptr3>>2] = $27;
   __Z12FormatStringINSt3__112basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEET_PKcz($2,559872,$$byval_copy4);
   $28 = HEAP8[$2>>0]|0;
   $29 = $28 & 1;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $33 = $28&255;
    $34 = $33 >>> 1;
    $35 = $6;$36 = $34;
   } else {
    $31 = HEAP32[$7>>2]|0;
    $32 = HEAP32[$8>>2]|0;
    $35 = $31;$36 = $32;
   }
   __THREW__ = 0;
   (invoke_iiii(1529,($str|0),($35|0),($36|0))|0);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 13;
    break;
   }
   $39 = HEAP8[$2>>0]|0;
   $40 = $39 & 1;
   $41 = ($40<<24>>24)==(0);
   if (!($41)) {
    $42 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    $43 = (invoke_i(54)|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     label = 11;
     break;
    }
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viii(1615,($43|0),($42|0),($$byval_copy4|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 11;
     break;
    }
   }
  }
  $50 = (($i$04) + 1)|0;
  $51 = HEAP32[$3>>2]|0;
  $52 = ($50|0)<($51|0);
  if ($52) {
   $i$04 = $50;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 11) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 }
 else if ((label|0) == 13) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  $55 = HEAP8[$2>>0]|0;
  $56 = $55 & 1;
  $57 = ($56<<24>>24)==(0);
  if ($57) {
   ___resumeException($53|0);
   // unreachable;
  }
  $58 = HEAP32[$7>>2]|0;
  __THREW__ = 0;
  $59 = (invoke_i(54)|0);
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if ($61) {
   $64 = ___cxa_find_matching_catch()|0;
   $65 = tempRet0;
   ___cxa_call_unexpected(($64|0));
   // unreachable;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viii(1615,($59|0),($58|0),($$byval_copy4|0));
  $62 = __THREW__; __THREW__ = 0;
  $63 = $62&1;
  if ($63) {
   $64 = ___cxa_find_matching_catch()|0;
   $65 = tempRet0;
   ___cxa_call_unexpected(($64|0));
   // unreachable;
  } else {
   ___resumeException($53|0);
   // unreachable;
  }
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZN13MemoryManager31DisallowAllocationsOnThisThreadEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13MemoryManager30ReallowAllocationsOnThisThreadEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13MemoryManager12GetAllocatorE10MemLabelId($this,$label) {
 $this = $this|0;
 $label = $label|0;
 var $$0 = 0, $$0$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$label>>2]|0;
 $1 = ($0|0)<(100);
 if ($1) {
  $2 = ((($this) + ($0<<2)|0) + 2276|0);
  $$0$in = $2;
 } else {
  $3 = (($0) + -100)|0;
  $4 = ((($this) + ($3<<2)|0) + 220|0);
  $$0$in = $4;
 }
 $$0 = HEAP32[$$0$in>>2]|0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MemoryManager25GetAllocatorContainingPtrEPKv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $i1$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)>(0);
 L1: do {
  if ($1) {
   $i$04 = 0;
   while(1) {
    $2 = ((($this) + ($i$04<<2)|0) + 24|0);
    $3 = HEAP32[$2>>2]|0;
    $4 = ($3|0)==(0|0);
    if (!($4)) {
     $5 = HEAP32[$3>>2]|0;
     $6 = (($5) + 36|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = (FUNCTION_TABLE_ii[$7 & 4095]($3)|0);
     if ($8) {
      $9 = HEAP32[$2>>2]|0;
      $10 = HEAP32[$9>>2]|0;
      $11 = (($10) + 28|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = (FUNCTION_TABLE_iii[$12 & 4095]($9,$ptr)|0);
      if ($13) {
       break;
      }
     }
    }
    $15 = (($i$04) + 1)|0;
    $16 = HEAP32[$this>>2]|0;
    $17 = ($15|0)<($16|0);
    if ($17) {
     $i$04 = $15;
    } else {
     break L1;
    }
   }
   $14 = HEAP32[$2>>2]|0;
   $$1 = $14;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_iii[$22 & 4095]($19,$ptr)|0);
 if ($23) {
  $24 = HEAP32[$18>>2]|0;
  $$1 = $24;
  STACKTOP = sp;return ($$1|0);
 } else {
  $i1$02 = 0;
 }
 while(1) {
  $25 = ((($this) + ($i1$02<<2)|0) + 220|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26>>>0)>((512)>>>0);
  if ($27) {
   $28 = HEAP32[$26>>2]|0;
   $29 = (($28) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (FUNCTION_TABLE_iii[$30 & 4095]($26,$ptr)|0);
   if ($31) {
    label = 11;
    break;
   }
  }
  $33 = (($i1$02) + 1)|0;
  $34 = ($33|0)<(512);
  if ($34) {
   $i1$02 = $33;
  } else {
   break;
  }
 }
 if ((label|0) == 11) {
  $32 = HEAP32[$25>>2]|0;
  $$1 = $32;
  STACKTOP = sp;return ($$1|0);
 }
 $35 = (($this) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $38 = HEAP32[$36>>2]|0;
 $39 = (($38) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (FUNCTION_TABLE_iii[$40 & 4095]($36,$ptr)|0);
 if (!($41)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $42 = HEAP32[$35>>2]|0;
 $$1 = $42;
 STACKTOP = sp;return ($$1|0);
}
function __Z32register_external_gfx_allocationPvjjPKci($ptr,$size,$related,$file,$line) {
 $ptr = $ptr|0;
 $size = $size|0;
 $related = $related|0;
 $file = $file|0;
 $line = $line|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01 = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0;
 var $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer = sp;
 $0 = sp + 40|0;
 $1 = sp + 28|0;
 $2 = HEAP32[559744>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __THREW__ = 0;
  $4 = (invoke_ii(2988,12)|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($4) + 4|0);
   HEAP32[$7>>2] = 0;
   $8 = (($4) + 8|0);
   HEAP32[$8>>2] = 0;
   HEAP32[$4>>2] = $7;
   HEAP32[559744>>2] = $4;
   $12 = $4;
   label = 5;
  }
 } else {
  $12 = $2;
  label = 5;
 }
 L4: do {
  if ((label|0) == 5) {
   $11 = (($12) + 4|0);
   $13 = HEAP32[$11>>2]|0;
   $14 = (($12) + 4|0);
   $15 = ($13|0)==(0|0);
   do {
    if (!($15)) {
     $$0$ph7$i$i$i = $14;$$01$ph6$i$in$i$i = $13;
     L7: while(1) {
      $$013$i$in$i$i = $$01$ph6$i$in$i$i;
      while(1) {
       $16 = (($$013$i$in$i$i) + 16|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = ($17>>>0)<($ptr>>>0);
       if (!($18)) {
        break;
       }
       $21 = (($$013$i$in$i$i) + 4|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($22|0)==(0|0);
       if ($23) {
        $$0$ph5$i$i$i = $$0$ph7$i$i$i;
        break L7;
       } else {
        $$013$i$in$i$i = $22;
       }
      }
      $19 = HEAP32[$$013$i$in$i$i>>2]|0;
      $20 = ($19|0)==(0|0);
      if ($20) {
       $$0$ph5$i$i$i = $$013$i$in$i$i;
       break;
      } else {
       $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $19;
      }
     }
     $24 = ($$0$ph5$i$i$i|0)==($14|0);
     if (!($24)) {
      $25 = (($$0$ph5$i$i$i) + 16|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26>>>0)>($ptr>>>0);
      $28 = ($$0$ph5$i$i$i|0)==($14|0);
      $or$cond = $27 | $28;
      if (!($or$cond)) {
       $29 = (($$0$ph5$i$i$i) + 28|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = (($$0$ph5$i$i$i) + 32|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($$0$ph5$i$i$i) + 20|0);
       $34 = HEAP32[$33>>2]|0;
       __THREW__ = 0;
       HEAP32[$vararg_buffer>>2] = $ptr;
       $vararg_ptr1 = (($vararg_buffer) + 4|0);
       HEAP32[$vararg_ptr1>>2] = $30;
       $vararg_ptr2 = (($vararg_buffer) + 8|0);
       HEAP32[$vararg_ptr2>>2] = $32;
       $vararg_ptr3 = (($vararg_buffer) + 12|0);
       HEAP32[$vararg_ptr3>>2] = $34;
       $vararg_ptr4 = (($vararg_buffer) + 16|0);
       HEAP32[$vararg_ptr4>>2] = $file;
       $vararg_ptr5 = (($vararg_buffer) + 20|0);
       HEAP32[$vararg_ptr5>>2] = $line;
       $vararg_ptr6 = (($vararg_buffer) + 24|0);
       HEAP32[$vararg_ptr6>>2] = $size;
       invoke_viii(1617,($1|0),(559752|0),($vararg_buffer|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break L4;
       }
       $37 = HEAP8[$1>>0]|0;
       $38 = $37 & 1;
       $39 = ($38<<24>>24)==(0);
       if ($39) {
        $42 = (($1) + 1|0);
        $43 = $42;
       } else {
        $40 = (($1) + 8|0);
        $41 = HEAP32[$40>>2]|0;
        $43 = $41;
       }
       __THREW__ = 0;
       invoke_viiiiiiii(21,($43|0),0,(559568|0),1185,1,0,0,(0|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        $46 = HEAP8[$1>>0]|0;
        $47 = $46 & 1;
        $48 = ($47<<24>>24)==(0);
        if ($48) {
         break;
        }
        $49 = (($1) + 8|0);
        $50 = HEAP32[$49>>2]|0;
        __ZdlPv($50);
        break;
       }
       $51 = ___cxa_find_matching_catch()|0;
       $52 = tempRet0;
       $53 = HEAP8[$1>>0]|0;
       $54 = $53 & 1;
       $55 = ($54<<24>>24)==(0);
       if ($55) {
        $$01 = $51;$$02 = $52;
        ___resumeException($$01|0);
        // unreachable;
       }
       $56 = (($1) + 8|0);
       $57 = HEAP32[$56>>2]|0;
       __ZdlPv($57);
       $$01 = $51;$$02 = $52;
       ___resumeException($$01|0);
       // unreachable;
      }
     }
    }
   } while(0);
   $58 = ($related|0)==(0);
   if ($58) {
    $59 = $ptr;
    $$0 = $59;
   } else {
    $$0 = $related;
   }
   $60 = HEAP32[559744>>2]|0;
   HEAP32[$0>>2] = $ptr;
   $61 = (($0) + 4|0);
   HEAP32[$61>>2] = $size;
   $62 = (($0) + 8|0);
   HEAP32[$62>>2] = $$0;
   $63 = (($0) + 12|0);
   HEAP32[$63>>2] = $file;
   $64 = (($0) + 16|0);
   HEAP32[$64>>2] = $line;
   __THREW__ = 0;
   invoke_viii(1618,($vararg_buffer|0),($60|0),($0|0));
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if (!($66)) {
    $67 = HEAP32[559448>>2]|0;
    $68 = (($67) + ($size))|0;
    HEAP32[559448>>2] = $68;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $$01 = $9;$$02 = $10;
 ___resumeException($$01|0);
 // unreachable;
}
function __Z34register_external_gfx_deallocationPvPKci($ptr,$file,$line) {
 $ptr = $ptr|0;
 $file = $file|0;
 $line = $line|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$i$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($ptr|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[559744>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = (__Znwj(12)|0);
  $5 = (($4) + 4|0);
  HEAP32[$5>>2] = 0;
  $6 = (($4) + 8|0);
  HEAP32[$6>>2] = 0;
  HEAP32[$4>>2] = $5;
  HEAP32[559744>>2] = $4;
  $8 = $4;
 } else {
  $8 = $2;
 }
 $7 = (($8) + 4|0);
 $9 = HEAP32[$7>>2]|0;
 $10 = (($8) + 4|0);
 $11 = ($9|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 } else {
  $$0$ph7$i$i$i = $10;$$01$ph6$i$in$i$i = $9;
 }
 L9: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $12 = (($$013$i$in$i$i) + 16|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13>>>0)<($ptr>>>0);
   if (!($14)) {
    break;
   }
   $17 = (($$013$i$in$i$i) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L9;
   } else {
    $$013$i$in$i$i = $18;
   }
  }
  $15 = HEAP32[$$013$i$in$i$i>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $15;
  }
 }
 $20 = ($$0$ph5$i$i$i|0)==($10|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = (($$0$ph5$i$i$i) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22>>>0)>($ptr>>>0);
 $24 = ($$0$ph5$i$i$i|0)==($10|0);
 $or$cond = $23 | $24;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $25 = (($$0$ph5$i$i$i) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[559448>>2]|0;
 $28 = (($27) - ($26))|0;
 HEAP32[559448>>2] = $28;
 $29 = HEAP32[559744>>2]|0;
 $30 = (($$0$ph5$i$i$i) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $$01$i$i$i$i = $$0$ph5$i$i$i;
  while(1) {
   $35 = (($$01$i$i$i$i) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==($$01$i$i$i$i|0);
   if ($38) {
    $$0$i$i$i$i = $36;
    break;
   } else {
    $$01$i$i$i$i = $36;
   }
  }
 } else {
  $$0$i$i$i$i$i = $31;
  while(1) {
   $33 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    $$0$i$i$i$i = $$0$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i = $33;
   }
  }
 }
 $39 = HEAP32[$29>>2]|0;
 $40 = ($39|0)==($$0$ph5$i$i$i|0);
 if ($40) {
  HEAP32[$29>>2] = $$0$i$i$i$i;
 }
 $41 = (($29) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + -1)|0;
 HEAP32[$41>>2] = $43;
 $44 = (($29) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($45,$$0$ph5$i$i$i);
 __THREW__ = 0;
 $46 = (invoke_i(54)|0);
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 }
 HEAP32[$0>>2] = 51;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1615,($46|0),($$0$ph5$i$i$i|0),($$byval_copy|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6appendEPKcj($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $14 = 10;$7 = $0;
 } else {
  $3 = HEAP32[$this>>2]|0;
  $4 = $3 & -2;
  $phitmp$i = (($4) + -1)|0;
  $5 = $3&255;
  $14 = $phitmp$i;$7 = $5;
 }
 $6 = $7 & 1;
 $8 = ($6<<24>>24)==(0);
 if ($8) {
  $11 = $7&255;
  $12 = $11 >>> 1;
  $15 = $12;
 } else {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $15 = $10;
 }
 $13 = (($14) - ($15))|0;
 $16 = ($13>>>0)<($__n>>>0);
 if ($16) {
  $33 = (($__n) - ($14))|0;
  $34 = (($33) + ($15))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$14,$34,$15,$15,0,$__n,$__s);
  STACKTOP = sp;return ($this|0);
 }
 $17 = ($__n|0)==(0);
 if ($17) {
  STACKTOP = sp;return ($this|0);
 }
 $18 = $7 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $22 = (($this) + 1|0);
  $24 = $22;
 } else {
  $20 = (($this) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $24 = $21;
 }
 $23 = (($24) + ($15)|0);
 _memcpy(($23|0),($__s|0),($__n|0))|0;
 $25 = (($15) + ($__n))|0;
 $26 = HEAP8[$this>>0]|0;
 $27 = $26 & 1;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  $30 = $25 << 1;
  $31 = $30&255;
  HEAP8[$this>>0] = $31;
 } else {
  $29 = (($this) + 4|0);
  HEAP32[$29>>2] = $25;
 }
 $32 = (($24) + ($25)|0);
 HEAP8[$32>>0] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add,$__p_new_stuff) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 $__p_new_stuff = $__p_new_stuff|0;
 var $$byval_copy1 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (2147483630 - ($__old_cap))|0;
 $2 = ($1>>>0)<($__delta_cap>>>0);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($this) + 1|0);
  $21 = $8;
 } else {
  $6 = (($this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $21 = $7;
 }
 $9 = ($__old_cap>>>0)<(1073741799);
 if ($9) {
  $10 = (($__delta_cap) + ($__old_cap))|0;
  $11 = $__old_cap << 1;
  $12 = ($10>>>0)<($11>>>0);
  $13 = $12 ? $11 : $10;
  $14 = ($13>>>0)<(11);
  if ($14) {
   $18 = 11;
  } else {
   $15 = (($13) + 16)|0;
   $16 = $15 & -16;
   $18 = $16;
  }
 } else {
  $18 = 2147483631;
 }
 $17 = (__Z16GetMemoryManagerv()|0);
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $19 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($17,$18,16,$$byval_copy1,0,559568,79)|0);
 $20 = ($__n_copy|0)==(0);
 if (!($20)) {
  _memcpy(($19|0),($21|0),($__n_copy|0))|0;
 }
 $22 = ($__n_add|0)==(0);
 if (!($22)) {
  $23 = (($19) + ($__n_copy)|0);
  _memcpy(($23|0),($__p_new_stuff|0),($__n_add|0))|0;
 }
 $24 = (($__old_sz) - ($__n_del))|0;
 $25 = ($24|0)==($__n_copy|0);
 if (!($25)) {
  $26 = (($24) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $27 = (($19) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $28 = (($21) + ($$sum1)|0);
  _memcpy(($27|0),($28|0),($26|0))|0;
 }
 $29 = ($__old_cap|0)==(10);
 if ($29) {
  $37 = (($this) + 8|0);
  HEAP32[$37>>2] = $19;
  $38 = $18 | 1;
  HEAP32[$this>>2] = $38;
  $39 = (($24) + ($__n_add))|0;
  $40 = (($this) + 4|0);
  HEAP32[$40>>2] = $39;
  $41 = (($19) + ($39)|0);
  HEAP8[$41>>0] = 0;
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 $30 = (invoke_i(54)|0);
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1615,($30|0),($21|0),($$byval_copy1|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 } else {
  $37 = (($this) + 8|0);
  HEAP32[$37>>2] = $19;
  $38 = $18 | 1;
  HEAP32[$this>>2] = $38;
  $39 = (($24) + ($__n_add))|0;
  $40 = (($this) + 4|0);
  HEAP32[$40>>2] = $39;
  $41 = (($19) + ($39)|0);
  HEAP8[$41>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIPv17ExternalAllocInfoEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier51ELi16EEE15__insert_uniqueERKS4_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$22 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4>>>0)<($6>>>0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6>>>0)<($4>>>0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $32 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $31 = (($agg$result) + 4|0);
  HEAP8[$31>>0] = $32;
  STACKTOP = sp;return;
 }
 $17 = (__Z16GetMemoryManagerv()|0);
 HEAP32[$0>>2] = 51;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $18 = (__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci($17,36,16,$$byval_copy,0,559568,79)|0);
 $19 = (($18) + 16|0);
 ;HEAP32[$19+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$19+16>>2]=HEAP32[$__v+16>>2]|0;
 HEAP32[$18>>2] = 0;
 $20 = (($18) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($18) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $18;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $18;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $32 = 1;$__r$0 = $18;
 HEAP32[$agg$result>>2] = $__r$0;
 $31 = (($agg$result) + 4|0);
 HEAP8[$31>>0] = $32;
 STACKTOP = sp;return;
}
function __ZN13BaseAllocatorC2EPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((559928 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $name;
 $1 = (($this) + 12|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;
 $2 = HEAP32[560024>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[560024>>2] = $3;
 $4 = HEAP32[560024>>2]|0;
 $5 = (($this) + 8|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN13BaseAllocator13TryDeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 4095]($this,$p)|0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($this,$p);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13BaseAllocatorD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13BaseAllocatorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK13BaseAllocator7GetNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13BaseAllocator10IsAssignedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN13BaseAllocator14CheckIntegrityEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK13BaseAllocator22GetAllocatedMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13BaseAllocator21GetReservedMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13BaseAllocator26GetPeakAllocatedMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13BaseAllocator24GetBookKeepingMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13BaseAllocator22GetNumberOfAllocationsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN13BaseAllocator17GetFreeBlockCountEPii($this,$freeCount,$size) {
 $this = $this|0;
 $freeCount = $freeCount|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13BaseAllocator17GetUsedBlockCountEPii($this,$usedCount,$size) {
 $this = $this|0;
 $usedCount = $usedCount|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13BaseAllocator16ThreadInitializeEPS_($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13BaseAllocator13ThreadCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13BaseAllocator16FrameMaintenanceEb($this,$cleanup) {
 $this = $this|0;
 $cleanup = $cleanup|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK13BaseAllocator16IsDelayedReleaseEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN21UnityDefaultAllocatorI17LowLevelAllocatorEC1EPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN13BaseAllocatorC2EPKc($this,$name);
 HEAP32[$this>>2] = ((560032 + 8|0));
 $0 = (($this) + 32|0);
 dest=$0+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN21UnityDefaultAllocatorI17LowLevelAllocatorE8AllocateEji($this,$size,$align) {
 $this = $this|0;
 $size = $size|0;
 $align = $align|0;
 var $$0 = 0, $$not$i$i$i = 0, $$sum$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($size) + 3)|0;
 $1 = (($0) + ($align))|0;
 $2 = (__ZN17LowLevelAllocator6MallocEj($1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = $2;
 $5 = (($align) + -1)|0;
 $$not$i$i$i = (-4 - ($4))|0;
 $6 = $$not$i$i$i & $5;
 $7 = (($2) + ($6)|0);
 $8 = ($6|0)==(0);
 if ($8) {
  $9 = HEAP32[$7>>2]|0;
  $10 = $9 & -2;
  HEAP32[$7>>2] = $10;
  $16 = $10;$18 = $7;
 } else {
  _memset(($2|0),-86,($6|0))|0;
  $11 = HEAP32[$7>>2]|0;
  $12 = $11 | 1;
  HEAP32[$7>>2] = $12;
  $$sum$i$i = (($6) + -4)|0;
  $13 = (($2) + ($$sum$i$i)|0);
  HEAP32[$13>>2] = $6;
  $16 = $12;$18 = $7;
 }
 $14 = $size << 1;
 $15 = $16 & 1;
 $17 = $15 | $14;
 HEAP32[$18>>2] = $17;
 $$sum$i = (($6) + 4)|0;
 $19 = (($2) + ($$sum$i)|0);
 $20 = HEAP32[$7>>2]|0;
 $21 = $20 >>> 1;
 $22 = (($this) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + ($21))|0;
 HEAP32[$22>>2] = $24;
 $25 = (($this) + 28|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 19)|0;
 HEAP32[$25>>2] = $27;
 $28 = (($this) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($24>>>0)>($29>>>0);
 if ($30) {
  HEAP32[$28>>2] = $24;
 }
 $31 = (($this) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 1)|0;
 HEAP32[$31>>2] = $33;
 $34 = (($21) + 19)|0;
 $35 = (($this) + 20|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + ($36))|0;
 HEAP32[$35>>2] = $37;
 (__ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE14AllocationPageIL11RequestType0EEEbPKv($this,$19)|0);
 $$0 = $19;
 STACKTOP = sp;return ($$0|0);
}
function __ZN21UnityDefaultAllocatorI17LowLevelAllocatorE10ReallocateEPvji($this,$p,$size,$align) {
 $this = $this|0;
 $p = $p|0;
 $size = $size|0;
 $align = $align|0;
 var $$0 = 0, $$neg1$i = 0, $$not$i = 0, $$sum = 0, $$sum$i = 0, $$sum$i$i = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($p|0)==(0|0);
 if ($0) {
  $1 = HEAP32[$this>>2]|0;
  $2 = (($1) + 12|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (FUNCTION_TABLE_iiii[$3 & 2047]($this,$size,$align)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($p) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 1;
 $8 = ($7|0)==(0);
 if ($8) {
  $12 = 0;
 } else {
  $9 = (($p) + -8|0);
  $10 = HEAP32[$9>>2]|0;
  $12 = $10;
 }
 $11 = (0 - ($12))|0;
 $13 = (($5) + ($11)|0);
 $14 = $6 >>> 1;
 $15 = (($this) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) - ($14))|0;
 HEAP32[$15>>2] = $17;
 $18 = (($this) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + -19)|0;
 HEAP32[$18>>2] = $20;
 $21 = (($this) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + -1)|0;
 HEAP32[$21>>2] = $23;
 $24 = (($this) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $$neg1$i = (-19 - ($14))|0;
 $26 = (($$neg1$i) + ($25))|0;
 HEAP32[$24>>2] = $26;
 (__ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE14AllocationPageIL11RequestType1EEEbPKv($this,$p)|0);
 $27 = HEAP32[$5>>2]|0;
 $28 = $27 >>> 1;
 $29 = $27 & 1;
 $30 = ($29|0)==(0);
 if ($30) {
  $42 = 0;
 } else {
  $31 = (($p) + -8|0);
  $32 = HEAP32[$31>>2]|0;
  $42 = $32;
 }
 $33 = (($size) + 3)|0;
 $34 = (($33) + ($align))|0;
 $35 = (($28) + 23)|0;
 $36 = (__ZN17LowLevelAllocator7ReallocEPvjj($13,$34,$35)|0);
 $37 = ($36|0)==(0|0);
 if ($37) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = $36;
 $39 = (($align) + -1)|0;
 $$not$i = (-4 - ($38))|0;
 $40 = $$not$i & $39;
 $41 = ($40|0)==($42|0);
 if (!($41)) {
  $$sum = (($42) + 4)|0;
  $43 = (($36) + ($$sum)|0);
  $$sum1 = (($40) + 4)|0;
  $44 = (($36) + ($$sum1)|0);
  $45 = ($28>>>0)>($size>>>0);
  $46 = $45 ? $size : $28;
  _memmove(($44|0),($43|0),($46|0))|0;
 }
 $47 = (($36) + ($40)|0);
 $48 = ($40|0)==(0);
 if ($48) {
  $49 = HEAP32[$47>>2]|0;
  $50 = $49 & -2;
  HEAP32[$47>>2] = $50;
  $56 = $50;$58 = $47;
 } else {
  _memset(($36|0),-86,($40|0))|0;
  $51 = HEAP32[$47>>2]|0;
  $52 = $51 | 1;
  HEAP32[$47>>2] = $52;
  $$sum$i$i = (($40) + -4)|0;
  $53 = (($36) + ($$sum$i$i)|0);
  HEAP32[$53>>2] = $40;
  $56 = $52;$58 = $47;
 }
 $54 = $size << 1;
 $55 = $56 & 1;
 $57 = $55 | $54;
 HEAP32[$58>>2] = $57;
 $$sum$i = (($40) + 4)|0;
 $59 = (($36) + ($$sum$i)|0);
 $60 = HEAP32[$47>>2]|0;
 $61 = $60 >>> 1;
 $62 = HEAP32[$15>>2]|0;
 $63 = (($62) + ($61))|0;
 HEAP32[$15>>2] = $63;
 $64 = HEAP32[$18>>2]|0;
 $65 = (($64) + 19)|0;
 HEAP32[$18>>2] = $65;
 $66 = (($this) + 24|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($63>>>0)>($67>>>0);
 if ($68) {
  HEAP32[$66>>2] = $63;
 }
 $69 = HEAP32[$21>>2]|0;
 $70 = (($69) + 1)|0;
 HEAP32[$21>>2] = $70;
 $71 = (($61) + 19)|0;
 $72 = HEAP32[$24>>2]|0;
 $73 = (($71) + ($72))|0;
 HEAP32[$24>>2] = $73;
 (__ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE14AllocationPageIL11RequestType0EEEbPKv($this,$59)|0);
 $$0 = $59;
 STACKTOP = sp;return ($$0|0);
}
function __ZN21UnityDefaultAllocatorI17LowLevelAllocatorE10DeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$neg1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($p|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($p) + -4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 if ($4) {
  $8 = 0;
 } else {
  $5 = (($p) + -8|0);
  $6 = HEAP32[$5>>2]|0;
  $8 = $6;
 }
 $7 = (0 - ($8))|0;
 $9 = (($1) + ($7)|0);
 $10 = $2 >>> 1;
 $11 = (($this) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) - ($10))|0;
 HEAP32[$11>>2] = $13;
 $14 = (($this) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -19)|0;
 HEAP32[$14>>2] = $16;
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + -1)|0;
 HEAP32[$17>>2] = $19;
 $20 = (($this) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $$neg1$i = (-19 - ($10))|0;
 $22 = (($$neg1$i) + ($21))|0;
 HEAP32[$20>>2] = $22;
 (__ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE14AllocationPageIL11RequestType1EEEbPKv($this,$p)|0);
 $23 = HEAP32[$1>>2]|0;
 $24 = $23 >>> 1;
 $25 = (($24) + 23)|0;
 __ZN17LowLevelAllocator4FreeEPvj($9,$25);
 STACKTOP = sp;return;
}
function __ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE8ContainsEPKv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $p;
 $1 = (($this) + 36|0);
 $2 = $0 >>> 18;
 $3 = $2 & 127;
 $4 = $0 >>> 13;
 $5 = $4 & 31;
 $6 = $0 >>> 9;
 $7 = $6 & 15;
 $8 = $0 >>> 4;
 $9 = $8 & 31;
 $10 = HEAP32[$1>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $$0$i = 0;
 } else {
  $12 = $0 >>> 25;
  $13 = (($10) + ($12<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $$0$i = 0;
  } else {
   $16 = (($14) + ($3<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $$0$i = 0;
   } else {
    $19 = (($17) + ($5<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     $$0$i = 0;
    } else {
     $22 = (($20) + ($7<<2)|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = 1 << $9;
     $25 = $23 & $24;
     $26 = ($25|0)!=(0);
     $$0$i = $26;
    }
   }
  }
 }
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE10GetPtrSizeEPKv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ptr) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 1;
 STACKTOP = sp;return ($2|0);
}
function __ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE14AllocationPageIL11RequestType0EEEbPKv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert4 = 0, $$phi$trans$insert6 = 0, $$phi$trans$insert8 = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $$pre5 = 0, $$pre7 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $p;
 $1 = (($this) + 36|0);
 $2 = $0 >>> 25;
 $3 = $0 >>> 18;
 $4 = $3 & 127;
 $5 = $0 >>> 13;
 $6 = $5 & 31;
 $7 = $0 >>> 9;
 $8 = $7 & 15;
 $9 = $0 >>> 4;
 $10 = $9 & 31;
 $11 = HEAP32[$1>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = (__ZN13MemoryManager17LowLevelCAllocateEjj(129,4)|0);
  HEAP32[$1>>2] = $13;
  $14 = (($this) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 516)|0;
  HEAP32[$14>>2] = $16;
  $17 = (($13) + 512|0);
  HEAP32[$17>>2] = 0;
  $$pre = HEAP32[$1>>2]|0;
  $19 = $$pre;
 } else {
  $19 = $11;
 }
 $18 = (($19) + ($2<<2)|0);
 $20 = HEAP32[$18>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $22 = (__ZN13MemoryManager17LowLevelCAllocateEjj(129,4)|0);
  $23 = HEAP32[$1>>2]|0;
  $24 = (($23) + ($2<<2)|0);
  HEAP32[$24>>2] = $22;
  $25 = (($this) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 516)|0;
  HEAP32[$25>>2] = $27;
  $28 = HEAP32[$1>>2]|0;
  $29 = (($28) + ($2<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 512|0);
  HEAP32[$31>>2] = 0;
  $$pre1 = HEAP32[$1>>2]|0;
  $$phi$trans$insert = (($$pre1) + ($2<<2)|0);
  $$pre2 = HEAP32[$$phi$trans$insert>>2]|0;
  $33 = $$pre2;
 } else {
  $33 = $20;
 }
 $32 = (($33) + ($4<<2)|0);
 $34 = HEAP32[$32>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $36 = (__ZN13MemoryManager17LowLevelCAllocateEjj(33,4)|0);
  $37 = HEAP32[$1>>2]|0;
  $38 = (($37) + ($2<<2)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + ($4<<2)|0);
  HEAP32[$40>>2] = $36;
  $41 = (($this) + 28|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + 132)|0;
  HEAP32[$41>>2] = $43;
  $44 = HEAP32[$1>>2]|0;
  $45 = (($44) + ($2<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + ($4<<2)|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 128|0);
  HEAP32[$49>>2] = 0;
  $$pre3 = HEAP32[$1>>2]|0;
  $$phi$trans$insert4 = (($$pre3) + ($2<<2)|0);
  $$pre5 = HEAP32[$$phi$trans$insert4>>2]|0;
  $$phi$trans$insert6 = (($$pre5) + ($4<<2)|0);
  $$pre7 = HEAP32[$$phi$trans$insert6>>2]|0;
  $51 = $$pre7;
 } else {
  $51 = $34;
 }
 $50 = (($51) + ($6<<2)|0);
 $52 = HEAP32[$50>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  $54 = (__ZN13MemoryManager17LowLevelCAllocateEjj(17,4)|0);
  $55 = HEAP32[$1>>2]|0;
  $56 = (($55) + ($2<<2)|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($57) + ($4<<2)|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + ($6<<2)|0);
  HEAP32[$60>>2] = $54;
  $61 = (($this) + 28|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($62) + 68)|0;
  HEAP32[$61>>2] = $63;
  $64 = HEAP32[$1>>2]|0;
  $65 = (($64) + ($2<<2)|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + ($4<<2)|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($68) + ($6<<2)|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($70) + 64|0);
  HEAP32[$71>>2] = 0;
  $73 = $70;$74 = 1;$76 = $68;
 } else {
  $$phi$trans$insert8 = (($52) + 64|0);
  $$pre9 = HEAP32[$$phi$trans$insert8>>2]|0;
  $phitmp = (($$pre9) + 1)|0;
  $73 = $52;$74 = $phitmp;$76 = $51;
 }
 $72 = (($73) + 64|0);
 HEAP32[$72>>2] = $74;
 $75 = (($76) + 128|0);
 $77 = HEAP32[$75>>2]|0;
 $78 = (($77) + 4|0);
 HEAP32[$75>>2] = $78;
 $79 = HEAP32[$1>>2]|0;
 $80 = (($79) + ($2<<2)|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + 512|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($83) + 4|0);
 HEAP32[$82>>2] = $84;
 $85 = HEAP32[$1>>2]|0;
 $86 = (($85) + 512|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($87) + 4|0);
 HEAP32[$86>>2] = $88;
 $89 = 1 << $10;
 $90 = HEAP32[$1>>2]|0;
 $91 = (($90) + ($2<<2)|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($92) + ($4<<2)|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($94) + ($6<<2)|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (($96) + ($8<<2)|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = $98 | $89;
 HEAP32[$97>>2] = $99;
 STACKTOP = sp;return 1;
}
function __ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE14AllocationPageIL11RequestType1EEEbPKv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert2 = 0, $$pre = 0, $$pre1 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $p;
 $1 = (($this) + 36|0);
 $2 = $0 >>> 25;
 $3 = $0 >>> 18;
 $4 = $3 & 127;
 $5 = $0 >>> 13;
 $6 = $5 & 31;
 $7 = $0 >>> 9;
 $8 = $7 & 15;
 $9 = $0 >>> 4;
 $10 = $9 & 31;
 $11 = 1 << $10;
 $12 = $11 ^ -1;
 $13 = HEAP32[$1>>2]|0;
 $14 = (($13) + ($2<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($4<<2)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($6<<2)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($8<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 & $12;
 HEAP32[$20>>2] = $22;
 $23 = (($19) + 64|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + -1)|0;
 HEAP32[$23>>2] = $25;
 $26 = ($25|0)==(0);
 if ($26) {
  $27 = (($this) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + -68)|0;
  HEAP32[$27>>2] = $29;
  __ZN13MemoryManager12LowLevelFreeEPvj($19,68);
  $30 = HEAP32[$1>>2]|0;
  $31 = (($30) + ($2<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + ($4<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($6<<2)|0);
  HEAP32[$35>>2] = 0;
  $$pre = HEAP32[$1>>2]|0;
  $$phi$trans$insert = (($$pre) + ($2<<2)|0);
  $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
  $$phi$trans$insert2 = (($$pre1) + ($4<<2)|0);
  $$pre3 = HEAP32[$$phi$trans$insert2>>2]|0;
  $37 = $$pre3;
 } else {
  $37 = $17;
 }
 $36 = (($37) + 128|0);
 $38 = HEAP32[$36>>2]|0;
 $39 = (($38) + -4|0);
 HEAP32[$36>>2] = $39;
 $40 = HEAP32[$1>>2]|0;
 $41 = (($40) + ($2<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 512|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + -4|0);
 HEAP32[$43>>2] = $45;
 $46 = HEAP32[$1>>2]|0;
 $47 = (($46) + 512|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + -4|0);
 HEAP32[$47>>2] = $49;
 STACKTOP = sp;return 1;
}
function __ZN21UnityDefaultAllocatorI17LowLevelAllocatorED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN21UnityDefaultAllocatorI17LowLevelAllocatorED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __Z22ValidateTlsfAllocationPvjiS_($memptr,$0,$isused,$1) {
 $memptr = $memptr|0;
 $0 = $0|0;
 $isused = $isused|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN20DynamicHeapAllocatorI17LowLevelAllocatorEC1EjjbP15BucketAllocatorPKc($this,$poolIncrementSize,$splitLimit,$useLocking,$bucketAllocator,$name) {
 $this = $this|0;
 $poolIncrementSize = $poolIncrementSize|0;
 $splitLimit = $splitLimit|0;
 $useLocking = $useLocking|0;
 $bucketAllocator = $bucketAllocator|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13BaseAllocatorC2EPKc($this,$name);
 HEAP32[$this>>2] = ((560128 + 8|0));
 $0 = (($this) + 32|0);
 HEAP32[$0>>2] = $bucketAllocator;
 $1 = (($this) + 40|0);
 $2 = (($this) + 44|0);
 HEAP32[$1>>2] = $1;
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 48|0);
 $4 = (($this) + 52|0);
 HEAP32[$3>>2] = $3;
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 57|0);
 $6 = $useLocking&1;
 HEAP8[$5>>0] = $6;
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = $splitLimit;
 $8 = (($this) + 60|0);
 HEAP32[$8>>2] = $poolIncrementSize;
 $9 = (($this) + 64|0);
 HEAP32[$9>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20DynamicHeapAllocatorI17LowLevelAllocatorED0Ev($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi23$i$iZ2D = 0, $$pre20$i$i = 0, $$pre21$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$i$i$index = 0, $lpad$phi$i$i$index2 = 0, $node$01$i$i$i = 0, $node$01$i4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560128 + 8|0));
 $0 = (($this) + 40|0);
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 do {
  if ($3) {
   $17 = $2;
  } else {
   $7 = $2;
   while(1) {
    __THREW__ = 0;
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    $6 = (($7) + 12|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = (($7) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    invoke_vii(2588,($8|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = (($7) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($0|0);
    if ($15) {
     label = 5;
     break;
    } else {
     $7 = $14;
    }
   }
   if ((label|0) == 5) {
    $$pre$i$i = HEAP32[$1>>2]|0;
    $17 = $$pre$i$i;
    break;
   }
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   $$pre21$i$i = (($this) + 52|0);
   $$pre$phi$i$iZ2D = $$pre21$i$i;$$pre$phi23$i$iZ2D = $0;$lpad$phi$i$i$index = $44;$lpad$phi$i$i$index2 = $45;
   HEAP32[$$pre$phi$i$iZ2D>>2] = 0;
   $46 = (($this) + 48|0);
   HEAP32[$46>>2] = 0;
   HEAP32[$1>>2] = 0;
   HEAP32[$$pre$phi23$i$iZ2D>>2] = 0;
   __ZdlPv($this);
   ___resumeException($lpad$phi$i$i$index|0);
   // unreachable;
  }
 } while(0);
 $16 = ($17|0)==($0|0);
 if (!($16)) {
  $node$01$i4$i$i = $17;
  while(1) {
   $18 = (($node$01$i4$i$i) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$node$01$i4$i$i>>2] = 0;
   HEAP32[$18>>2] = 0;
   $20 = ($19|0)==($0|0);
   if ($20) {
    break;
   } else {
    $node$01$i4$i$i = $19;
   }
  }
 }
 HEAP32[$1>>2] = $0;
 HEAP32[$0>>2] = $0;
 $21 = (($this) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 48|0);
 $24 = ($22|0)==($23|0);
 do {
  if ($24) {
   $38 = $22;
  } else {
   $28 = $22;
   while(1) {
    __THREW__ = 0;
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = (($28) + 12|0);
    $29 = HEAP32[$27>>2]|0;
    $30 = (($28) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vii(2588,($29|0),($31|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($28) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==($23|0);
    if ($36) {
     label = 12;
     break;
    } else {
     $28 = $35;
    }
   }
   if ((label|0) == 12) {
    $$pre20$i$i = HEAP32[$21>>2]|0;
    $38 = $$pre20$i$i;
    break;
   }
   $42 = ___cxa_find_matching_catch()|0;
   $43 = tempRet0;
   $$pre$phi$i$iZ2D = $21;$$pre$phi23$i$iZ2D = $0;$lpad$phi$i$i$index = $42;$lpad$phi$i$i$index2 = $43;
   HEAP32[$$pre$phi$i$iZ2D>>2] = 0;
   $46 = (($this) + 48|0);
   HEAP32[$46>>2] = 0;
   HEAP32[$1>>2] = 0;
   HEAP32[$$pre$phi23$i$iZ2D>>2] = 0;
   __ZdlPv($this);
   ___resumeException($lpad$phi$i$i$index|0);
   // unreachable;
  }
 } while(0);
 $37 = ($38|0)==($23|0);
 if ($37) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 } else {
  $node$01$i$i$i = $38;
 }
 while(1) {
  $39 = (($node$01$i$i$i) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$node$01$i$i$i>>2] = 0;
  HEAP32[$39>>2] = 0;
  $41 = ($40|0)==($23|0);
  if ($41) {
   break;
  } else {
   $node$01$i$i$i = $40;
  }
 }
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN20DynamicHeapAllocatorI17LowLevelAllocatorED1Ev($this) {
 $this = $this|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre$phi23$iZ2D = 0, $$pre20$i = 0, $$pre21$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index2 = 0, $node$01$i$i = 0, $node$01$i4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560128 + 8|0));
 $0 = (($this) + 40|0);
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 do {
  if ($3) {
   $17 = $2;
  } else {
   $7 = $2;
   while(1) {
    __THREW__ = 0;
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    $6 = (($7) + 12|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = (($7) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    invoke_vii(2588,($8|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = (($7) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($0|0);
    if ($15) {
     label = 5;
     break;
    } else {
     $7 = $14;
    }
   }
   if ((label|0) == 5) {
    $$pre$i = HEAP32[$1>>2]|0;
    $17 = $$pre$i;
    break;
   }
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   $$pre21$i = (($this) + 52|0);
   $$pre$phi$iZ2D = $$pre21$i;$$pre$phi23$iZ2D = $0;$lpad$phi$i$index = $44;$lpad$phi$i$index2 = $45;
   HEAP32[$$pre$phi$iZ2D>>2] = 0;
   $46 = (($this) + 48|0);
   HEAP32[$46>>2] = 0;
   HEAP32[$1>>2] = 0;
   HEAP32[$$pre$phi23$iZ2D>>2] = 0;
   ___resumeException($lpad$phi$i$index|0);
   // unreachable;
  }
 } while(0);
 $16 = ($17|0)==($0|0);
 if (!($16)) {
  $node$01$i4$i = $17;
  while(1) {
   $18 = (($node$01$i4$i) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$node$01$i4$i>>2] = 0;
   HEAP32[$18>>2] = 0;
   $20 = ($19|0)==($0|0);
   if ($20) {
    break;
   } else {
    $node$01$i4$i = $19;
   }
  }
 }
 HEAP32[$1>>2] = $0;
 HEAP32[$0>>2] = $0;
 $21 = (($this) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 48|0);
 $24 = ($22|0)==($23|0);
 do {
  if ($24) {
   $38 = $22;
  } else {
   $28 = $22;
   while(1) {
    __THREW__ = 0;
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = (($28) + 12|0);
    $29 = HEAP32[$27>>2]|0;
    $30 = (($28) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vii(2588,($29|0),($31|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($28) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==($23|0);
    if ($36) {
     label = 12;
     break;
    } else {
     $28 = $35;
    }
   }
   if ((label|0) == 12) {
    $$pre20$i = HEAP32[$21>>2]|0;
    $38 = $$pre20$i;
    break;
   }
   $42 = ___cxa_find_matching_catch()|0;
   $43 = tempRet0;
   $$pre$phi$iZ2D = $21;$$pre$phi23$iZ2D = $0;$lpad$phi$i$index = $42;$lpad$phi$i$index2 = $43;
   HEAP32[$$pre$phi$iZ2D>>2] = 0;
   $46 = (($this) + 48|0);
   HEAP32[$46>>2] = 0;
   HEAP32[$1>>2] = 0;
   HEAP32[$$pre$phi23$iZ2D>>2] = 0;
   ___resumeException($lpad$phi$i$index|0);
   // unreachable;
  }
 } while(0);
 $37 = ($38|0)==($23|0);
 if ($37) {
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
  STACKTOP = sp;return;
 } else {
  $node$01$i$i = $38;
 }
 while(1) {
  $39 = (($node$01$i$i) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$node$01$i$i>>2] = 0;
  HEAP32[$39>>2] = 0;
  $41 = ($40|0)==($23|0);
  if ($41) {
   break;
  } else {
   $node$01$i$i = $40;
  }
 }
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN20DynamicHeapAllocatorI17LowLevelAllocatorE8AllocateEji($this,$size,$align) {
 $this = $this|0;
 $size = $size|0;
 $align = $align|0;
 var $$$i = 0, $$0 = 0, $$1$i = 0, $$2$i = 0, $$allocatePoolSize$0 = 0, $$c = 0, $$mask$i = 0, $$mask$i$v = 0, $$not$i$i = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocatePoolSize$016 = 0, $base$1$i = 0;
 var $base$2$i = 0, $newRealPtr$412 = 0, $realSize$0 = 0, $realSize$113 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($size) + -1)|0;
 $1 = (($0) + ($align))|0;
 $2 = (0 - ($align))|0;
 $3 = $1 & $2;
 $4 = ($3>>>0)>(32);
 if ($4) {
  $5 = ($3>>>0)>(2097151);
  $$mask$i$v = $5 ? 21 : 5;
  $$mask$i = $3 >>> $$mask$i$v;
  $$$i = $5 ? 16 : 0;
  $6 = $$mask$i & 65280;
  $7 = ($6|0)==(0);
  if ($7) {
   $$1$i = $$mask$i;$base$1$i = $$$i;
  } else {
   $8 = $$$i | 8;
   $9 = $$mask$i >>> 8;
   $$1$i = $9;$base$1$i = $8;
  }
  $10 = $$1$i & 240;
  $11 = ($10|0)==(0);
  if ($11) {
   $$2$i = $$1$i;$base$2$i = $base$1$i;
  } else {
   $12 = (($base$1$i) + 4)|0;
   $13 = $$1$i >>> 4;
   $$2$i = $13;$base$2$i = $12;
  }
  $14 = (560304 + ($$2$i)|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15 << 24 >> 24;
  $17 = (($16) + ($base$2$i))|0;
  $18 = 1 << $17;
  $19 = (($3) + -1)|0;
  $20 = (($19) + ($18))|0;
  $21 = (0 - ($18))|0;
  $22 = $20 & $21;
  $realSize$0 = $22;
 } else {
  $realSize$0 = $3;
 }
 $23 = (($this) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)>($realSize$0>>>0);
 $26 = (($this) + 40|0);
 $27 = (($this) + 48|0);
 $28 = $25 ? $26 : $27;
 $29 = (($28) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==($28|0);
 if ($31) {
  label = 9;
 } else {
  $32 = (($30) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (_tlsf_memalign($33,$align,$realSize$0)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   label = 9;
  } else {
   $newRealPtr$412 = $34;$realSize$113 = $realSize$0;
  }
 }
 L12: do {
  if ((label|0) == 9) {
   $36 = (($this) + 60|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = $37 >>> 2;
   $39 = ($38>>>0)>($size>>>0);
   L14: do {
    if ($39) {
     $40 = HEAP32[$23>>2]|0;
     $41 = ($40>>>0)>($realSize$0>>>0);
     $42 = $41 ? $26 : $27;
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==($42|0);
     L16: do {
      if (!($44)) {
       $46 = $43;
       while(1) {
        $48 = (($46) + 8|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = (_tlsf_memalign($49,$align,$realSize$0)|0);
        $51 = ($50|0)==(0|0);
        if (!($51)) {
         break;
        }
        $45 = HEAP32[$46>>2]|0;
        $47 = ($45|0)==($42|0);
        if ($47) {
         break L16;
        } else {
         $46 = $45;
        }
       }
       $52 = (($42) + 4|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($46|0)==($53|0);
       if ($54) {
        $newRealPtr$412 = $50;$realSize$113 = $realSize$0;
        break L12;
       }
       $55 = HEAP32[$46>>2]|0;
       $56 = ($55|0)==(0|0);
       $57 = (($46) + 4|0);
       if (!($56)) {
        $58 = HEAP32[$57>>2]|0;
        $59 = (($55) + 4|0);
        HEAP32[$59>>2] = $58;
        $60 = HEAP32[$46>>2]|0;
        $61 = HEAP32[$57>>2]|0;
        HEAP32[$61>>2] = $60;
        HEAP32[$46>>2] = 0;
        HEAP32[$57>>2] = 0;
       }
       $62 = HEAP32[$53>>2]|0;
       HEAP32[$46>>2] = $62;
       HEAP32[$57>>2] = $53;
       $63 = (($62) + 4|0);
       HEAP32[$63>>2] = $46;
       $64 = HEAP32[$57>>2]|0;
       HEAP32[$64>>2] = $46;
       $65 = ($50|0)==(0|0);
       if (!($65)) {
        $newRealPtr$412 = $50;$realSize$113 = $realSize$0;
        break L12;
       }
      }
     } while(0);
     $66 = HEAP32[$36>>2]|0;
     $67 = $size << 1;
     $allocatePoolSize$016 = $66;
     while(1) {
      $68 = ($allocatePoolSize$016>>>0)>($67>>>0);
      if (!($68)) {
       break L14;
      }
      $69 = (__ZN17LowLevelAllocator6MallocEj($allocatePoolSize$016)|0);
      $70 = ($69|0)==(0|0);
      $71 = $70&1;
      $$allocatePoolSize$0 = $allocatePoolSize$016 >>> $71;
      if ($70) {
       $allocatePoolSize$016 = $$allocatePoolSize$0;
      } else {
       break;
      }
     }
     $72 = (($this) + 20|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = (($73) + ($$allocatePoolSize$0))|0;
     HEAP32[$72>>2] = $74;
     $75 = (__ZN17LowLevelAllocator6MallocEj(24)|0);
     ;HEAP32[$75+0>>2]=0|0;HEAP32[$75+4>>2]=0|0;HEAP32[$75+8>>2]=0|0;HEAP32[$75+12>>2]=0|0;HEAP32[$75+16>>2]=0|0;HEAP32[$75+20>>2]=0|0;
     HEAP32[$75>>2] = 0;
     $76 = (($75) + 4|0);
     HEAP32[$76>>2] = 0;
     $77 = (($75) + 12|0);
     HEAP32[$77>>2] = $69;
     $78 = (($75) + 16|0);
     HEAP32[$78>>2] = $$allocatePoolSize$0;
     $79 = (_tlsf_create($69,$$allocatePoolSize$0)|0);
     $80 = (($75) + 8|0);
     HEAP32[$80>>2] = $79;
     $81 = (($75) + 20|0);
     HEAP32[$81>>2] = 0;
     $82 = (($42) + 4|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($75|0)==($83|0);
     if (!($84)) {
      $85 = HEAP32[$75>>2]|0;
      $86 = ($85|0)==(0|0);
      if (!($86)) {
       $87 = HEAP32[$76>>2]|0;
       $88 = (($85) + 4|0);
       HEAP32[$88>>2] = $87;
       $89 = HEAP32[$75>>2]|0;
       $90 = HEAP32[$76>>2]|0;
       HEAP32[$90>>2] = $89;
       HEAP32[$75>>2] = 0;
       HEAP32[$76>>2] = 0;
      }
      $91 = HEAP32[$83>>2]|0;
      HEAP32[$75>>2] = $91;
      HEAP32[$76>>2] = $83;
      $92 = (($91) + 4|0);
      HEAP32[$92>>2] = $75;
      $93 = HEAP32[$76>>2]|0;
      HEAP32[$93>>2] = $75;
     }
     $94 = HEAP32[$23>>2]|0;
     $95 = ($94>>>0)>($realSize$0>>>0);
     $96 = $95 ? $26 : $27;
     $97 = (($96) + 4|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($98) + 8|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = (_tlsf_memalign($100,$align,$realSize$0)|0);
     $102 = ($101|0)==(0|0);
     if (!($102)) {
      $newRealPtr$412 = $101;$realSize$113 = $realSize$0;
      break L12;
     }
    }
   } while(0);
   $103 = (($size) + 3)|0;
   $104 = (($103) + ($align))|0;
   $105 = (__ZN17LowLevelAllocator6MallocEj(20)|0);
   $106 = (__ZN17LowLevelAllocator6MallocEj($104)|0);
   $107 = (($105) + 4|0);
   HEAP32[$107>>2] = $106;
   $108 = ($106|0)==(0|0);
   if ($108) {
    _printf_console(560224,$vararg_buffer);
    __ZN17LowLevelAllocator4FreeEPvj($105,20);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $109 = (($105) + 12|0);
   HEAP32[$109>>2] = $104;
   $110 = (($105) + 16|0);
   HEAP32[$110>>2] = $size;
   $111 = (($this) + 20|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = (($112) + ($size))|0;
   HEAP32[$111>>2] = $113;
   $114 = (($this) + 64|0);
   $115 = HEAP32[$114>>2]|0;
   HEAP32[$105>>2] = $115;
   HEAP32[$114>>2] = $105;
   $116 = HEAP32[$107>>2]|0;
   $117 = ($105|0)==(0|0);
   if ($117) {
    $newRealPtr$412 = $116;$realSize$113 = $104;
   } else {
    $136 = $116;
    $137 = (($align) + -1)|0;
    $$not$i$i = (-4 - ($136))|0;
    $138 = $$not$i$i & $137;
    $139 = (($116) + ($138)|0);
    $140 = ($138|0)==(0);
    if ($140) {
     $141 = HEAP32[$139>>2]|0;
     $142 = $141 & -2;
     HEAP32[$139>>2] = $142;
     $148 = $142;$150 = $139;
    } else {
     _memset(($116|0),-86,($138|0))|0;
     $143 = HEAP32[$139>>2]|0;
     $144 = $143 | 1;
     HEAP32[$139>>2] = $144;
     $$sum$i = (($138) + -4)|0;
     $145 = (($116) + ($$sum$i)|0);
     HEAP32[$145>>2] = $138;
     $148 = $144;$150 = $139;
    }
    $146 = $size << 1;
    $147 = $148 & 1;
    $149 = $147 | $146;
    HEAP32[$150>>2] = $149;
    $$sum = (($138) + 4)|0;
    $151 = (($116) + ($$sum)|0);
    $152 = (($105) + 8|0);
    HEAP32[$152>>2] = $151;
    $153 = HEAP32[$109>>2]|0;
    $154 = (($153) - ($size))|0;
    $155 = (($this) + 16|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = (($156) + ($size))|0;
    HEAP32[$155>>2] = $157;
    $158 = (($this) + 28|0);
    $159 = HEAP32[$158>>2]|0;
    $160 = (($154) + ($159))|0;
    HEAP32[$158>>2] = $160;
    $161 = (($this) + 24|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = ($157>>>0)>($162>>>0);
    if ($163) {
     HEAP32[$161>>2] = $157;
    }
    $164 = (($this) + 12|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = (($165) + 1)|0;
    HEAP32[$164>>2] = $166;
    $$0 = $151;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $118 = HEAP32[$23>>2]|0;
 $119 = ($118>>>0)>($realSize$113>>>0);
 $120 = $119 ? $26 : $27;
 $121 = (($120) + 4|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($122) + 20|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($124) + 1)|0;
 $$c = $125;
 HEAP32[$123>>2] = $$c;
 $126 = (_tlsf_block_size($newRealPtr$412)|0);
 $127 = (($this) + 16|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = (($128) + ($126))|0;
 HEAP32[$127>>2] = $129;
 $130 = (($this) + 24|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ($129>>>0)>($131>>>0);
 if ($132) {
  HEAP32[$130>>2] = $129;
 }
 $133 = (($this) + 12|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = (($134) + 1)|0;
 HEAP32[$133>>2] = $135;
 $$0 = $newRealPtr$412;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20DynamicHeapAllocatorI17LowLevelAllocatorE10ReallocateEPvji($this,$p,$size,$align) {
 $this = $this|0;
 $p = $p|0;
 $size = $size|0;
 $align = $align|0;
 var $$0 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($p|0)==(0|0);
 if ($0) {
  $1 = HEAP32[$this>>2]|0;
  $2 = (($1) + 12|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (FUNCTION_TABLE_iiii[$3 & 2047]($this,$size,$align)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($size|0)==(0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  $7 = (($6) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vii[$8 & 4095]($this,$p);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($this) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 40|0);
 $12 = ($10|0)==($11|0);
 L9: do {
  if ($12) {
   label = 9;
  } else {
   $14 = $10;
   while(1) {
    $13 = (($14) + 12|0);
    $15 = HEAP32[$13>>2]|0;
    $16 = ($15>>>0)>($p>>>0);
    if (!($16)) {
     $17 = (($14) + 16|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($15) + ($18)|0);
     $20 = ($19>>>0)>($p>>>0);
     if ($20) {
      $$sink = $14;
      label = 13;
      break L9;
     }
    }
    $21 = (($14) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($11|0);
    if ($23) {
     label = 9;
     break;
    } else {
     $14 = $22;
    }
   }
  }
 } while(0);
 L15: do {
  if ((label|0) == 9) {
   $24 = (($this) + 52|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($this) + 48|0);
   $27 = ($25|0)==($26|0);
   if ($27) {
    label = 19;
   } else {
    $29 = $25;
    while(1) {
     $28 = (($29) + 12|0);
     $30 = HEAP32[$28>>2]|0;
     $31 = ($30>>>0)>($p>>>0);
     if (!($31)) {
      $32 = (($29) + 16|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($30) + ($33)|0);
      $35 = ($34>>>0)>($p>>>0);
      if ($35) {
       $$sink = $29;
       label = 13;
       break L15;
      }
     }
     $36 = (($29) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==($26|0);
     if ($38) {
      label = 19;
      break;
     } else {
      $29 = $37;
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 13) {
   $39 = ($$sink|0)==(0|0);
   if ($39) {
    label = 19;
   } else {
    $40 = (_tlsf_block_size($p)|0);
    $41 = (($size) + -1)|0;
    $42 = (($41) + ($align))|0;
    $43 = (0 - ($align))|0;
    $44 = $42 & $43;
    $45 = (($$sink) + 8|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (_tlsf_realloc_align($46,$p,$align,$44)|0);
    $48 = ($47|0)==(0|0);
    if ($48) {
     $57 = ($40|0)==(0);
     if ($57) {
      label = 19;
      break;
     } else {
      $67 = $40;
      break;
     }
    }
    $49 = (_tlsf_block_size($47)|0);
    $50 = (($this) + 16|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) + ($49))|0;
    HEAP32[$50>>2] = $52;
    $53 = (($this) + 24|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($52>>>0)>($54>>>0);
    if ($55) {
     HEAP32[$53>>2] = $52;
    }
    $56 = (($52) - ($40))|0;
    HEAP32[$50>>2] = $56;
    $$0 = $47;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $58 = (($p) + -4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $59 >>> 1;
  $67 = $60;
 }
 $61 = HEAP32[$this>>2]|0;
 $62 = (($61) + 12|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (FUNCTION_TABLE_iiii[$63 & 2047]($this,$size,$align)|0);
 $65 = ($64|0)==(0|0);
 if (!($65)) {
  $66 = ($67>>>0)>($size>>>0);
  $68 = $66 ? $size : $67;
  _memcpy(($64|0),($p|0),($68|0))|0;
 }
 $69 = HEAP32[$this>>2]|0;
 $70 = (($69) + 20|0);
 $71 = HEAP32[$70>>2]|0;
 FUNCTION_TABLE_vii[$71 & 4095]($this,$p);
 $$0 = $64;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20DynamicHeapAllocatorI17LowLevelAllocatorE10DeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_iii[$2 & 4095]($this,$p)|0);
 STACKTOP = sp;return;
}
function __ZN20DynamicHeapAllocatorI17LowLevelAllocatorE13TryDeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $$c = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $alloc$0 = 0, $alloc$04 = 0, $alloc$06 = 0, $prev$05 = 0, $prev$05$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($p|0)==(0|0);
 if ($0) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 40|0);
 $4 = ($2|0)==($3|0);
 L4: do {
  if ($4) {
   label = 6;
  } else {
   $6 = $2;
   while(1) {
    $5 = (($6) + 12|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7>>>0)>($p>>>0);
    if (!($8)) {
     $9 = (($6) + 16|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = (($7) + ($10)|0);
     $12 = ($11>>>0)>($p>>>0);
     if ($12) {
      $$sink = $6;
      label = 10;
      break L4;
     }
    }
    $13 = (($6) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($3|0);
    if ($15) {
     label = 6;
     break;
    } else {
     $6 = $14;
    }
   }
  }
 } while(0);
 L10: do {
  if ((label|0) == 6) {
   $16 = (($this) + 52|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($this) + 48|0);
   $19 = ($17|0)==($18|0);
   if (!($19)) {
    $21 = $17;
    while(1) {
     $20 = (($21) + 12|0);
     $22 = HEAP32[$20>>2]|0;
     $23 = ($22>>>0)>($p>>>0);
     if (!($23)) {
      $24 = (($21) + 16|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($22) + ($25)|0);
      $27 = ($26>>>0)>($p>>>0);
      if ($27) {
       $$sink = $21;
       label = 10;
       break L10;
      }
     }
     $28 = (($21) + 4|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($29|0)==($18|0);
     if ($30) {
      break;
     } else {
      $21 = $29;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $31 = ($$sink|0)==(0|0);
  if (!($31)) {
   $32 = (_tlsf_block_size($p)|0);
   $33 = (($this) + 16|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) - ($32))|0;
   HEAP32[$33>>2] = $35;
   $36 = (($this) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + -1)|0;
   HEAP32[$36>>2] = $38;
   $39 = (($$sink) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + -1)|0;
   $$c = $41;
   HEAP32[$39>>2] = $$c;
   $42 = (($$sink) + 8|0);
   $43 = HEAP32[$42>>2]|0;
   _tlsf_free($43,$p);
   $44 = HEAP32[$39>>2]|0;
   $45 = ($44|0)==(0);
   if (!($45)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $46 = HEAP32[$$sink>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    $48 = (($$sink) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($46) + 4|0);
    HEAP32[$50>>2] = $49;
    $51 = HEAP32[$$sink>>2]|0;
    $52 = HEAP32[$48>>2]|0;
    HEAP32[$52>>2] = $51;
    HEAP32[$$sink>>2] = 0;
    HEAP32[$48>>2] = 0;
   }
   $53 = (($$sink) + 12|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($$sink) + 16|0);
   $56 = HEAP32[$55>>2]|0;
   __ZN17LowLevelAllocator4FreeEPvj($54,$56);
   $57 = HEAP32[$55>>2]|0;
   $58 = (($this) + 20|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) - ($57))|0;
   HEAP32[$58>>2] = $60;
   __ZN17LowLevelAllocator4FreeEPvj($$sink,24);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $61 = (($this) + 64|0);
 $alloc$04 = HEAP32[$61>>2]|0;
 $62 = ($alloc$04|0)==(0|0);
 if ($62) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $alloc$06 = $alloc$04;$prev$05 = 0;
 }
 while(1) {
  $64 = (($alloc$06) + 8|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==($p|0);
  if ($66) {
   break;
  }
  $alloc$0 = HEAP32[$alloc$06>>2]|0;
  $63 = ($alloc$0|0)==(0|0);
  if ($63) {
   $$0 = 0;
   label = 22;
   break;
  } else {
   $prev$05$phi = $alloc$06;$alloc$06 = $alloc$0;$prev$05 = $prev$05$phi;
  }
 }
 if ((label|0) == 22) {
  STACKTOP = sp;return ($$0|0);
 }
 $67 = (($alloc$06) + 16|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($alloc$06) + 12|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($this) + 16|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) - ($68))|0;
 HEAP32[$71>>2] = $73;
 $74 = (($this) + 28|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($68) - ($70))|0;
 $77 = (($76) + ($75))|0;
 HEAP32[$74>>2] = $77;
 $78 = (($this) + 12|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($79) + -1)|0;
 HEAP32[$78>>2] = $80;
 $81 = ($prev$05|0)==(0|0);
 $82 = HEAP32[$alloc$06>>2]|0;
 if ($81) {
  HEAP32[$61>>2] = $82;
 } else {
  HEAP32[$prev$05>>2] = $82;
 }
 $83 = HEAP32[$67>>2]|0;
 $84 = (($this) + 20|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($85) - ($83))|0;
 HEAP32[$84>>2] = $86;
 $87 = (($alloc$06) + 4|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = HEAP32[$69>>2]|0;
 __ZN17LowLevelAllocator4FreeEPvj($88,$89);
 __ZN17LowLevelAllocator4FreeEPvj($alloc$06,20);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK20DynamicHeapAllocatorI17LowLevelAllocatorE8ContainsEPKv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $alloc$0 = 0;
 var $alloc$01 = 0, $alloc$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = ($1|0)==($2|0);
 L1: do {
  if ($3) {
   label = 5;
  } else {
   $5 = $1;
   while(1) {
    $4 = (($5) + 12|0);
    $6 = HEAP32[$4>>2]|0;
    $7 = ($6>>>0)>($p>>>0);
    if (!($7)) {
     $8 = (($5) + 16|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($6) + ($9)|0);
     $11 = ($10>>>0)>($p>>>0);
     if ($11) {
      $$sink = $5;
      label = 9;
      break L1;
     }
    }
    $12 = (($5) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==($2|0);
    if ($14) {
     label = 5;
     break;
    } else {
     $5 = $13;
    }
   }
  }
 } while(0);
 L7: do {
  if ((label|0) == 5) {
   $15 = (($this) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($this) + 48|0);
   $18 = ($16|0)==($17|0);
   if (!($18)) {
    $20 = $16;
    while(1) {
     $19 = (($20) + 12|0);
     $21 = HEAP32[$19>>2]|0;
     $22 = ($21>>>0)>($p>>>0);
     if (!($22)) {
      $23 = (($20) + 16|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($21) + ($24)|0);
      $26 = ($25>>>0)>($p>>>0);
      if ($26) {
       $$sink = $20;
       label = 9;
       break L7;
      }
     }
     $27 = (($20) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($17|0);
     if ($29) {
      break;
     } else {
      $20 = $28;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $30 = ($$sink|0)==(0|0);
  if (!($30)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $31 = (($this) + 64|0);
 $alloc$01 = HEAP32[$31>>2]|0;
 $32 = ($alloc$01|0)==(0|0);
 if ($32) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $alloc$02 = $alloc$01;
 }
 while(1) {
  $34 = (($alloc$02) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==($p|0);
  if ($36) {
   $$0 = 1;
   label = 13;
   break;
  }
  $alloc$0 = HEAP32[$alloc$02>>2]|0;
  $33 = ($alloc$0|0)==(0|0);
  if ($33) {
   $$0 = 0;
   label = 13;
   break;
  } else {
   $alloc$02 = $alloc$0;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK20DynamicHeapAllocatorI17LowLevelAllocatorE10GetPtrSizeEPKv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $$0 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = ($1|0)==($2|0);
 L1: do {
  if ($3) {
   label = 5;
  } else {
   $5 = $1;
   while(1) {
    $4 = (($5) + 12|0);
    $6 = HEAP32[$4>>2]|0;
    $7 = ($6>>>0)>($ptr>>>0);
    if (!($7)) {
     $8 = (($5) + 16|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($6) + ($9)|0);
     $11 = ($10>>>0)>($ptr>>>0);
     if ($11) {
      $$sink = $5;
      label = 9;
      break L1;
     }
    }
    $12 = (($5) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==($2|0);
    if ($14) {
     label = 5;
     break;
    } else {
     $5 = $13;
    }
   }
  }
 } while(0);
 L7: do {
  if ((label|0) == 5) {
   $15 = (($this) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($this) + 48|0);
   $18 = ($16|0)==($17|0);
   if (!($18)) {
    $20 = $16;
    while(1) {
     $19 = (($20) + 12|0);
     $21 = HEAP32[$19>>2]|0;
     $22 = ($21>>>0)>($ptr>>>0);
     if (!($22)) {
      $23 = (($20) + 16|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($21) + ($24)|0);
      $26 = ($25>>>0)>($ptr>>>0);
      if ($26) {
       $$sink = $20;
       label = 9;
       break L7;
      }
     }
     $27 = (($20) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($17|0);
     if ($29) {
      break;
     } else {
      $20 = $28;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $30 = ($$sink|0)==(0|0);
  if (!($30)) {
   $31 = (_tlsf_block_size($ptr)|0);
   $$0 = $31;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $32 = (($ptr) + -4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 >>> 1;
 $$0 = $34;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20DynamicHeapAllocatorI17LowLevelAllocatorE14CheckIntegrityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = ($1|0)==($2|0);
 if (!($3)) {
  $5 = $1;
  while(1) {
   $4 = (($5) + 4|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = ($6|0)==($2|0);
   if ($7) {
    break;
   } else {
    $5 = $6;
   }
  }
 }
 $8 = (($this) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 48|0);
 $11 = ($9|0)==($10|0);
 if (!($11)) {
  $15 = $9;
  while(1) {
   $14 = (($15) + 4|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = ($16|0)==($10|0);
   if ($17) {
    break;
   } else {
    $15 = $16;
   }
  }
 }
 $12 = HEAP32[$0>>2]|0;
 $13 = ($12|0)==($2|0);
 if (!($13)) {
  $21 = $12;
  while(1) {
   $20 = (($21) + 8|0);
   $22 = HEAP32[$20>>2]|0;
   _tlsf_walk_heap($22,328,0);
   $23 = (($21) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==($2|0);
   if ($25) {
    break;
   } else {
    $21 = $24;
   }
  }
 }
 $18 = HEAP32[$8>>2]|0;
 $19 = ($18|0)==($10|0);
 if ($19) {
  STACKTOP = sp;return 1;
 } else {
  $27 = $18;
 }
 while(1) {
  $26 = (($27) + 8|0);
  $28 = HEAP32[$26>>2]|0;
  _tlsf_walk_heap($28,328,0);
  $29 = (($27) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==($10|0);
  if ($31) {
   break;
  } else {
   $27 = $30;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN17LowLevelAllocator6MallocEj($size) {
 $size = $size|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13MemoryManager16LowLevelAllocateEj($size)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN17LowLevelAllocator7ReallocEPvjj($ptr,$size,$oldSize) {
 $ptr = $ptr|0;
 $size = $size|0;
 $oldSize = $oldSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13MemoryManager18LowLevelReallocateEPvjj($ptr,$size,$oldSize)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN17LowLevelAllocator4FreeEPvj($ptr,$oldSize) {
 $ptr = $ptr|0;
 $oldSize = $oldSize|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MemoryManager12LowLevelFreeEPvj($ptr,$oldSize);
 STACKTOP = sp;return;
}
function __ZN14StackAllocatorC2EjPKc($this,$blockSize,$name) {
 $this = $this|0;
 $blockSize = $blockSize|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13BaseAllocatorC2EPKc($this,$name);
 HEAP32[$this>>2] = ((560320 + 8|0));
 $0 = (($this) + 32|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 36|0);
 HEAP32[$1>>2] = $blockSize;
 $2 = (($this) + 40|0);
 HEAP32[$2>>2] = 0;
 $3 = (__ZN13MemoryManager16LowLevelAllocateEj($blockSize)|0);
 HEAP32[$0>>2] = $3;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = $blockSize;
 $5 = (($this) + 48|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN14StackAllocatorD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560320 + 8|0));
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vii(2589,($1|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZdlPv($this);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN14StackAllocatorD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560320 + 8|0));
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN13MemoryManager12LowLevelFreeEPvj($1,$3);
 STACKTOP = sp;return;
}
function __ZN14StackAllocator8AllocateEji($this,$size,$align) {
 $this = $this|0;
 $size = $size|0;
 $align = $align|0;
 var $$0$i = 0, $$align = 0, $$byval_copy = 0, $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $ptr$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = $align & 7;
 $2 = ($1|0)!=(0);
 $$align = $2 ? 8 : $align;
 $3 = (($$align) + 7)|0;
 $4 = (0 - ($$align))|0;
 $5 = $3 & $4;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (($this) + 32|0);
  $10 = HEAP32[$9>>2]|0;
  $$0$i = $10;$21 = $10;
 } else {
  $11 = (($7) + -4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 >>> 1;
  $14 = (($7) + ($13)|0);
  $$phi$trans$insert = (($this) + 32|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$0$i = $14;$21 = $$pre;
 }
 $15 = (($$align) + -1)|0;
 $16 = $$0$i;
 $17 = (($16) + ($15))|0;
 $18 = $17 & $4;
 $19 = $18;
 $20 = $21;
 $22 = (($18) - ($20))|0;
 $23 = (($this) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22>>>0)<($24>>>0);
 if ($25) {
  $26 = (($size) + -1)|0;
  $27 = (($26) + ($$align))|0;
  $28 = (($27) + ($5))|0;
  $29 = $28 & $4;
  $30 = (($24) - ($22))|0;
  $31 = ($30>>>0)<($29>>>0);
  if (!($31)) {
   $32 = (($19) + ($5)|0);
   $$sum = (($5) + -8)|0;
   $33 = (($19) + ($$sum)|0);
   $$sum1 = (($5) + -4)|0;
   $34 = (($19) + ($$sum1)|0);
   $35 = $size << 1;
   HEAP32[$34>>2] = $35;
   $36 = HEAP32[$6>>2]|0;
   HEAP32[$33>>2] = $36;
   HEAP32[$6>>2] = $32;
   $37 = (($this) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + ($size))|0;
   HEAP32[$37>>2] = $39;
   $40 = (($this) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 8)|0;
   HEAP32[$40>>2] = $42;
   $43 = (($this) + 24|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($39>>>0)>($44>>>0);
   if ($45) {
    HEAP32[$43>>2] = $39;
   }
   $46 = (($this) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($47) + 1)|0;
   HEAP32[$46>>2] = $48;
   $ptr$0 = $32;
   STACKTOP = sp;return ($ptr$0|0);
  }
 }
 $49 = (__Z16GetMemoryManagerv()|0);
 $50 = HEAP32[628416>>2]|0;
 HEAP32[$0>>2] = $50;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $51 = (__ZN13MemoryManager12GetAllocatorE10MemLabelId($49,$$byval_copy)|0);
 $52 = $15 | 15;
 $53 = (($52) + 1)|0;
 $54 = HEAP32[$51>>2]|0;
 $55 = (($54) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (FUNCTION_TABLE_iiii[$56 & 2047]($51,$size,$53)|0);
 $58 = ($57|0)==(0|0);
 if ($58) {
  $ptr$0 = 0;
  STACKTOP = sp;return ($ptr$0|0);
 }
 $59 = HEAP32[$51>>2]|0;
 $60 = (($59) + 32|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (FUNCTION_TABLE_iii[$61 & 4095]($51,$57)|0);
 $63 = (($this) + 48|0);
 $64 = $63;
 $65 = $64;
 $66 = HEAP32[$65>>2]|0;
 $67 = (($64) + 4)|0;
 $68 = $67;
 $69 = HEAP32[$68>>2]|0;
 $70 = (_i64Add(($66|0),($69|0),($62|0),0)|0);
 $71 = tempRet0;
 $72 = $63;
 $73 = $72;
 HEAP32[$73>>2] = $70;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP32[$75>>2] = $71;
 $76 = (($this) + 56|0);
 $77 = $76;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = (($77) + 4)|0;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = ($71|0)>($82|0);
 $84 = ($71|0)==($82|0);
 $85 = ($70>>>0)>($79>>>0);
 $86 = $84 & $85;
 $87 = $83 | $86;
 if (!($87)) {
  $ptr$0 = $57;
  STACKTOP = sp;return ($ptr$0|0);
 }
 $88 = $76;
 $89 = $88;
 HEAP32[$89>>2] = $70;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $71;
 $ptr$0 = $57;
 STACKTOP = sp;return ($ptr$0|0);
}
function __ZN14StackAllocator10ReallocateEPvji($this,$p,$size,$align) {
 $this = $this|0;
 $p = $p|0;
 $size = $size|0;
 $align = $align|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$align = 0, $$byval_copy = 0, $$phi$trans$insert = 0, $$phi$trans$insert2 = 0, $$phi$trans$insert4 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = $align & 7;
 $2 = ($1|0)!=(0);
 $$align = $2 ? 8 : $align;
 $3 = ($p|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiii[$6 & 2047]($this,$size,$$align)|0);
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (($this) + 32|0);
  $12 = HEAP32[$11>>2]|0;
  $$0$i = $12;$24 = $12;
 } else {
  $13 = (($9) + -4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 >>> 1;
  $16 = (($9) + ($15)|0);
  $$phi$trans$insert = (($this) + 32|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$0$i = $16;$24 = $$pre;
 }
 $17 = (($$align) + -1)|0;
 $18 = $$0$i;
 $19 = (($18) + ($17))|0;
 $20 = (0 - ($$align))|0;
 $21 = $19 & $20;
 $22 = (($this) + 32|0);
 $23 = $24;
 $25 = (($21) - ($23))|0;
 $26 = (($this) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($25>>>0)>($27>>>0);
 $29 = (($27) - ($25))|0;
 $$ = $28 ? 0 : $29;
 $30 = HEAP32[$this>>2]|0;
 $31 = (($30) + 32|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_iii[$32 & 4095]($this,$p)|0);
 $34 = HEAP32[$22>>2]|0;
 $35 = ($34>>>0)>($p>>>0);
 if (!($35)) {
  $36 = HEAP32[$26>>2]|0;
  $37 = (($34) + ($36)|0);
  $38 = ($37>>>0)>($p>>>0);
  if ($38) {
   $39 = HEAP32[$8>>2]|0;
   $40 = ($39|0)!=($p|0);
   $41 = ($33>>>0)<($size>>>0);
   $or$cond = $40 & $41;
   if (!($or$cond)) {
    $42 = $p;
    $43 = (($17) + ($42))|0;
    $44 = $43 & $20;
    $45 = $44;
    $46 = ($45|0)==($p|0);
    if ($46) {
     $47 = (($$) + ($33))|0;
     $48 = ($47>>>0)>($size>>>0);
     if ($48) {
      $49 = (($p) + -4|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = $size << 1;
      $52 = $50 & 1;
      $53 = $52 | $51;
      HEAP32[$49>>2] = $53;
      $54 = (($this) + 16|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = (($55) - ($33))|0;
      $57 = (($this) + 12|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (($58) + -1)|0;
      HEAP32[$57>>2] = $59;
      $60 = (($56) + ($size))|0;
      HEAP32[$54>>2] = $60;
      $61 = (($this) + 24|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($60>>>0)>($62>>>0);
      if ($63) {
       HEAP32[$61>>2] = $60;
      }
      HEAP32[$57>>2] = $58;
      $$0 = $p;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   $64 = HEAP32[$this>>2]|0;
   $65 = (($64) + 12|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (FUNCTION_TABLE_iiii[$66 & 2047]($this,$size,$$align)|0);
   $68 = ($67|0)==(0|0);
   if (!($68)) {
    $69 = $41 ? $33 : $size;
    _memcpy(($67|0),($p|0),($69|0))|0;
   }
   $70 = HEAP32[$this>>2]|0;
   $71 = (($70) + 20|0);
   $72 = HEAP32[$71>>2]|0;
   FUNCTION_TABLE_vii[$72 & 4095]($this,$p);
   $$0 = $67;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $73 = (__Z16GetMemoryManagerv()|0);
 $74 = HEAP32[628416>>2]|0;
 HEAP32[$0>>2] = $74;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $75 = (__ZN13MemoryManager12GetAllocatorE10MemLabelId($73,$$byval_copy)|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + 32|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (FUNCTION_TABLE_iii[$78 & 4095]($75,$p)|0);
 $80 = $17 | 15;
 $81 = (($80) + 1)|0;
 $82 = HEAP32[$75>>2]|0;
 $83 = (($82) + 16|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (FUNCTION_TABLE_iiiii[$84 & 511]($75,$p,$size,$81)|0);
 $86 = ($85|0)==(0|0);
 if ($86) {
  $$phi$trans$insert2 = (($this) + 48|0);
  $87 = $$phi$trans$insert2;
  $88 = $87;
  $89 = HEAP32[$88>>2]|0;
  $90 = (($87) + 4)|0;
  $91 = $90;
  $92 = HEAP32[$91>>2]|0;
  $$phi$trans$insert4 = (($this) + 56|0);
  $93 = $$phi$trans$insert4;
  $94 = $93;
  $95 = HEAP32[$94>>2]|0;
  $96 = (($93) + 4)|0;
  $97 = $96;
  $98 = HEAP32[$97>>2]|0;
  $133 = $89;$134 = $92;$142 = $98;$145 = $95;
 } else {
  $99 = HEAP32[$75>>2]|0;
  $100 = (($99) + 32|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (FUNCTION_TABLE_iii[$101 & 4095]($75,$85)|0);
  $103 = (($this) + 48|0);
  $104 = $103;
  $105 = $104;
  $106 = HEAP32[$105>>2]|0;
  $107 = (($104) + 4)|0;
  $108 = $107;
  $109 = HEAP32[$108>>2]|0;
  $110 = (_i64Add(($106|0),($109|0),($102|0),0)|0);
  $111 = tempRet0;
  $112 = $103;
  $113 = $112;
  HEAP32[$113>>2] = $110;
  $114 = (($112) + 4)|0;
  $115 = $114;
  HEAP32[$115>>2] = $111;
  $116 = (($this) + 56|0);
  $117 = $116;
  $118 = $117;
  $119 = HEAP32[$118>>2]|0;
  $120 = (($117) + 4)|0;
  $121 = $120;
  $122 = HEAP32[$121>>2]|0;
  $123 = ($111|0)>($122|0);
  $124 = ($111|0)==($122|0);
  $125 = ($110>>>0)>($119>>>0);
  $126 = $124 & $125;
  $127 = $123 | $126;
  if ($127) {
   $128 = $116;
   $129 = $128;
   HEAP32[$129>>2] = $110;
   $130 = (($128) + 4)|0;
   $131 = $130;
   HEAP32[$131>>2] = $111;
   $133 = $110;$134 = $111;$142 = $111;$145 = $110;
  } else {
   $133 = $110;$134 = $111;$142 = $122;$145 = $119;
  }
 }
 $132 = (($this) + 48|0);
 $135 = (_i64Subtract(($133|0),($134|0),($79|0),0)|0);
 $136 = tempRet0;
 $137 = $132;
 $138 = $137;
 HEAP32[$138>>2] = $135;
 $139 = (($137) + 4)|0;
 $140 = $139;
 HEAP32[$140>>2] = $136;
 $141 = ($136|0)>($142|0);
 $143 = ($136|0)==($142|0);
 $144 = ($135>>>0)>($145>>>0);
 $146 = $143 & $144;
 $147 = $141 | $146;
 if (!($147)) {
  $$0 = $85;
  STACKTOP = sp;return ($$0|0);
 }
 $148 = (($this) + 56|0);
 $149 = $148;
 $150 = $149;
 HEAP32[$150>>2] = $135;
 $151 = (($149) + 4)|0;
 $152 = $151;
 HEAP32[$152>>2] = $136;
 $$0 = $85;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14StackAllocator13TryDeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($p|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return 1;
 }
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($p|0);
 if ($4) {
  $5 = HEAP32[$this>>2]|0;
  $6 = (($5) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_iii[$7 & 4095]($this,$p)|0);
  $9 = (($this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) - ($8))|0;
  HEAP32[$9>>2] = $11;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + -8)|0;
  HEAP32[$12>>2] = $14;
  $15 = (($this) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + -1)|0;
  HEAP32[$15>>2] = $17;
  $$pre = HEAP32[$2>>2]|0;
  $19 = $$pre;
  while(1) {
   $18 = (($19) + -8|0);
   $20 = HEAP32[$18>>2]|0;
   HEAP32[$2>>2] = $20;
   $21 = ($20|0)==(0|0);
   if ($21) {
    label = 12;
    break;
   }
   $22 = (($20) + -4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = $23 & 1;
   $25 = ($24|0)==(0);
   if ($25) {
    label = 12;
    break;
   } else {
    $19 = $20;
   }
  }
  if ((label|0) == 12) {
   STACKTOP = sp;return 1;
  }
 }
 $26 = (($this) + 32|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27>>>0)>($p>>>0);
 if (!($28)) {
  $29 = (($this) + 36|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($27) + ($30)|0);
  $32 = ($31>>>0)>($p>>>0);
  if ($32) {
   $33 = HEAP32[$this>>2]|0;
   $34 = (($33) + 32|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (FUNCTION_TABLE_iii[$35 & 4095]($this,$p)|0);
   $37 = (($this) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) - ($36))|0;
   HEAP32[$37>>2] = $39;
   $40 = (($this) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + -8)|0;
   HEAP32[$40>>2] = $42;
   $43 = (($this) + 12|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + -1)|0;
   HEAP32[$43>>2] = $45;
   $46 = (($p) + -4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | 1;
   HEAP32[$46>>2] = $48;
   STACKTOP = sp;return 1;
  }
 }
 $49 = (__Z16GetMemoryManagerv()|0);
 $50 = HEAP32[628416>>2]|0;
 HEAP32[$0>>2] = $50;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $51 = (__ZN13MemoryManager12GetAllocatorE10MemLabelId($49,$$byval_copy)|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (FUNCTION_TABLE_iii[$54 & 4095]($51,$p)|0);
 $56 = (($this) + 48|0);
 $57 = $56;
 $58 = $57;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 4)|0;
 $61 = $60;
 $62 = HEAP32[$61>>2]|0;
 $63 = (_i64Subtract(($59|0),($62|0),($55|0),0)|0);
 $64 = tempRet0;
 $65 = $56;
 $66 = $65;
 HEAP32[$66>>2] = $63;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $64;
 $69 = (($this) + 56|0);
 $70 = $69;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = (($70) + 4)|0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = ($64|0)>($75|0);
 $77 = ($64|0)==($75|0);
 $78 = ($63>>>0)>($72>>>0);
 $79 = $77 & $78;
 $80 = $76 | $79;
 if ($80) {
  $81 = $69;
  $82 = $81;
  HEAP32[$82>>2] = $63;
  $83 = (($81) + 4)|0;
  $84 = $83;
  HEAP32[$84>>2] = $64;
 }
 $85 = HEAP32[$51>>2]|0;
 $86 = (($85) + 20|0);
 $87 = HEAP32[$86>>2]|0;
 FUNCTION_TABLE_vii[$87 & 4095]($51,$p);
 STACKTOP = sp;return 1;
}
function __ZN14StackAllocator16FrameMaintenanceEb($this,$cleanup) {
 $this = $this|0;
 $cleanup = $cleanup|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $x$0$be$i = 0, $x$0$lcssa$i = 0, $x$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = ($6|0)==(0);
 $11 = ($9|0)==(0);
 $12 = $10 & $11;
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 56|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = ($16|0)==(0);
 $21 = ($19|0)==(0);
 $22 = $20 & $21;
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (($this) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (_i64Add(($24|0),0,($16|0),($19|0))|0);
 $26 = tempRet0;
 $27 = ($25>>>0)>(1);
 if ($27) {
  $x$01$i = 1;
  while(1) {
   $28 = ($x$01$i>>>0)<(1048577);
   $29 = $x$01$i << 1;
   $30 = (($x$01$i) + 1048576)|0;
   $x$0$be$i = $28 ? $29 : $30;
   $31 = ($x$0$be$i>>>0)<($25>>>0);
   if ($31) {
    $x$01$i = $x$0$be$i;
   } else {
    $x$0$lcssa$i = $x$0$be$i;
    break;
   }
  }
 } else {
  $x$0$lcssa$i = 1;
 }
 $32 = (($this) + 32|0);
 $33 = HEAP32[$32>>2]|0;
 __ZN13MemoryManager12LowLevelFreeEPvj($33,$24);
 $34 = (__ZN13MemoryManager16LowLevelAllocateEj($x$0$lcssa$i)|0);
 HEAP32[$32>>2] = $34;
 HEAP32[$23>>2] = $x$0$lcssa$i;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNK14StackAllocator20IsOverflowAllocationEPKv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z16GetMemoryManagerv()|0);
 $2 = HEAP32[628416>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__ZN13MemoryManager12GetAllocatorE10MemLabelId($1,$$byval_copy)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iii[$6 & 4095]($3,$p)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN14StackAllocator10DeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_iii[$2 & 4095]($this,$p)|0);
 STACKTOP = sp;return;
}
function __ZNK14StackAllocator8ContainsEPKv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $$byval_copy = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($p|0)!=(0|0);
 $$phi$trans$insert = (($this) + 40|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 $2 = ($$pre|0)==($p|0);
 $or$cond = $1 & $2;
 if ($or$cond) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($$pre|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5>>>0)>($p>>>0);
  if (!($6)) {
   $7 = (($this) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + ($8)|0);
   $10 = ($9>>>0)>($p>>>0);
   if ($10) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = (__Z16GetMemoryManagerv()|0);
 $12 = HEAP32[628416>>2]|0;
 HEAP32[$0>>2] = $12;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $13 = (__ZN13MemoryManager12GetAllocatorE10MemLabelId($11,$$byval_copy)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_iii[$16 & 4095]($13,$p)|0);
 $$0 = $17;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK14StackAllocator10GetPtrSizeEPKv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ptr) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 1;
 STACKTOP = sp;return ($2|0);
}
function __ZN12TLSAllocatorI14StackAllocatorEC1EPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13BaseAllocatorC2EPKc($this,$name);
 HEAP32[$this>>2] = ((560416 + 8|0));
 $0 = HEAP32[560512>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = 1;
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(560520,0,560600,19,1,0,0,0);
  $$pre$i = HEAP32[560512>>2]|0;
  $phitmp$i = (($$pre$i) + 1)|0;
  $2 = $phitmp$i;
 }
 HEAP32[560512>>2] = $2;
 $3 = (($this) + 32|0);
 _memset(($3|0),0,512)|0;
 STACKTOP = sp;return;
}
function __ZN12TLSAllocatorI14StackAllocatorED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560416 + 8|0));
 $0 = HEAP32[560512>>2]|0;
 $1 = (($0) + -1)|0;
 HEAP32[560512>>2] = $1;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN12TLSAllocatorI14StackAllocatorED1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560416 + 8|0));
 $0 = HEAP32[560512>>2]|0;
 $1 = (($0) + -1)|0;
 HEAP32[560512>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN12TLSAllocatorI14StackAllocatorE8AllocateEji($this,$size,$align) {
 $this = $this|0;
 $size = $size|0;
 $align = $align|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560608>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = (__ZN14StackAllocator8AllocateEji($0,$size,$align)|0);
  $$0 = $2;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN12TLSAllocatorI14StackAllocatorE10ReallocateEPvji($this,$p,$size,$align) {
 $this = $this|0;
 $p = $p|0;
 $size = $size|0;
 $align = $align|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560608>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = (__ZN14StackAllocator10ReallocateEPvji($0,$p,$size,$align)|0);
  $$0 = $2;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN12TLSAllocatorI14StackAllocatorE10DeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560608>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iii[$3 & 4095]($0,$p)|0);
 STACKTOP = sp;return;
}
function __ZN12TLSAllocatorI14StackAllocatorE13TryDeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560608>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = (__ZN14StackAllocator13TryDeallocateEPv($0,$p)|0);
  $$0 = $2;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK12TLSAllocatorI14StackAllocatorE8ContainsEPKv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560608>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = ($p|0)!=(0|0);
  $$phi$trans$insert$i = (($0) + 40|0);
  $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
  $3 = ($$pre$i|0)==($p|0);
  $or$cond$i = $2 & $3;
  if ($or$cond$i) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $4 = ($$pre$i|0)==(0|0);
  if (!($4)) {
   $5 = (($0) + 32|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6>>>0)>($p>>>0);
   if (!($7)) {
    $8 = (($0) + 36|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($6) + ($9)|0);
    $11 = ($10>>>0)>($p>>>0);
    if ($11) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $12 = (__ZNK14StackAllocator20IsOverflowAllocationEPKv($0,$p)|0);
  if ($12) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK12TLSAllocatorI14StackAllocatorE10GetPtrSizeEPKv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ptr) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 1;
 STACKTOP = sp;return ($2|0);
}
function __ZNK12TLSAllocatorI14StackAllocatorE10IsAssignedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560608>>2]|0;
 $1 = ($0|0)!=(0|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12TLSAllocatorI14StackAllocatorE14CheckIntegrityEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK12TLSAllocatorI14StackAllocatorE22GetAllocatedMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $allocated$01 = 0, $allocated$1 = 0, $exitcond = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $allocated$01 = 0;$i$02 = 0;
 while(1) {
  $0 = ((($this) + ($i$02<<2)|0) + 32|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(0|0);
  if ($2) {
   $allocated$1 = $allocated$01;
  } else {
   $3 = (($1) + 16|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + ($allocated$01))|0;
   $allocated$1 = $5;
  }
  $6 = (($i$02) + 1)|0;
  $exitcond = ($6|0)==(128);
  if ($exitcond) {
   break;
  } else {
   $allocated$01 = $allocated$1;$i$02 = $6;
  }
 }
 STACKTOP = sp;return ($allocated$1|0);
}
function __ZNK12TLSAllocatorI14StackAllocatorE24GetBookKeepingMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $exitcond = 0, $i$02 = 0, $total$01 = 0, $total$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$02 = 0;$total$01 = 0;
 while(1) {
  $0 = ((($this) + ($i$02<<2)|0) + 32|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(0|0);
  if ($2) {
   $total$1 = $total$01;
  } else {
   $3 = (($1) + 28|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + ($total$01))|0;
   $total$1 = $5;
  }
  $6 = (($i$02) + 1)|0;
  $exitcond = ($6|0)==(128);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $6;$total$01 = $total$1;
  }
 }
 STACKTOP = sp;return ($total$1|0);
}
function __ZNK12TLSAllocatorI14StackAllocatorE21GetReservedMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $exitcond = 0, $i$02 = 0, $total$01 = 0, $total$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$02 = 0;$total$01 = 0;
 while(1) {
  $0 = ((($this) + ($i$02<<2)|0) + 32|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(0|0);
  if ($2) {
   $total$1 = $total$01;
  } else {
   $3 = (($1) + 20|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + ($total$01))|0;
   $total$1 = $5;
  }
  $6 = (($i$02) + 1)|0;
  $exitcond = ($6|0)==(128);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $6;$total$01 = $total$1;
  }
 }
 STACKTOP = sp;return ($total$1|0);
}
function __ZN12TLSAllocatorI14StackAllocatorE16ThreadInitializeEP13BaseAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[560608>>2] = $allocator;
 $i$01 = 0;
 while(1) {
  $2 = ((($this) + ($i$01<<2)|0) + 32|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  $1 = (($i$01) + 1)|0;
  if ($4) {
   break;
  }
  $0 = ($1|0)<(128);
  if ($0) {
   $i$01 = $1;
  } else {
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $allocator;
 STACKTOP = sp;return;
}
function __ZN12TLSAllocatorI14StackAllocatorE13ThreadCleanupEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[560608>>2]|0;
 HEAP32[560608>>2] = 0;
 $i$03 = 0;
 while(1) {
  $4 = ((($this) + ($i$03<<2)|0) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($1|0);
  $3 = (($i$03) + 1)|0;
  if ($6) {
   label = 4;
   break;
  }
  $2 = ($3|0)<(128);
  if ($2) {
   $i$03 = $3;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$4>>2] = 0;
 }
 $7 = HEAP32[628240>>2]|0;
 $8 = ($1|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$1>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 4095]($1);
 }
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN12TLSAllocatorI14StackAllocatorE16FrameMaintenanceEb($this,$cleanup) {
 $this = $this|0;
 $cleanup = $cleanup|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560608>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($0,$cleanup);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a1306() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[560616>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 HEAP32[560608>>2] = 0;
 $2 = 560616;
 $3 = $2;
 HEAP32[$3>>2] = 1;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17BaseObjectManager16StaticInitializeEv() {
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $6;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 $7 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy6,1,16,560648,106)|0);
 HEAP32[560656>>2] = $7;
 $8 = HEAP32[628384>>2]|0;
 HEAP32[$2>>2] = $8;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
 $9 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy6,0,16,560648,108)|0);
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($9) + 8|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$9>>2] = $10;
 HEAP32[560664>>2] = $9;
 $12 = HEAP32[628384>>2]|0;
 HEAP32[$3>>2] = $12;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
 $13 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy6,0,16,560648,109)|0);
 $14 = (($13) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = (($13) + 8|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$13>>2] = $14;
 HEAP32[560672>>2] = $13;
 $16 = HEAP32[628384>>2]|0;
 HEAP32[$4>>2] = $16;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
 $17 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy6,0,16,560648,110)|0);
 $18 = HEAP32[628384>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($17) + 8|0);
 HEAP32[$19>>2] = 0;
 $20 = (($17) + 12|0);
 HEAP32[$20>>2] = 0;
 $21 = (($17) + 4|0);
 HEAP32[$21>>2] = 0;
 HEAP32[560680>>2] = $17;
 $22 = HEAP32[628384>>2]|0;
 HEAP32[$5>>2] = $22;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
 $23 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy6,0,16,560648,111)|0);
 $24 = HEAP32[628384>>2]|0;
 HEAP32[$23>>2] = $24;
 $25 = (($23) + 8|0);
 HEAP32[$25>>2] = 0;
 $26 = (($23) + 12|0);
 HEAP32[$26>>2] = 0;
 $27 = (($23) + 4|0);
 HEAP32[$27>>2] = 0;
 HEAP32[560688>>2] = $23;
 $28 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $28;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 $29 = (__Znwj10MemLabelIdbiPKci(52,$$byval_copy6,0,16,560648,934)|0);
 __THREW__ = 0;
 invoke_vii(2590,($29|0),131072);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if (!($31)) {
  HEAP32[560624>>2] = $29;
  STACKTOP = sp;return;
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($29|0),($$byval_copy6|0),0,16,(560648|0),934);
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch(0|0)|0;
  $37 = tempRet0;
  ___clang_call_terminate($36);
  // unreachable;
 } else {
  ___resumeException($32|0);
  // unreachable;
 }
}
function __ZN17BaseObjectManager13StaticDestroyEv() {
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[560624>>2]|0;
 $4 = HEAP32[628384>>2]|0;
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  $6 = (($3) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   HEAP32[$2>>2] = 58;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy8);
  }
 }
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy8);
 HEAP32[560624>>2] = 0;
 $9 = HEAP32[560664>>2]|0;
 $10 = HEAP32[628384>>2]|0;
 $11 = ($9|0)==(0|0);
 if (!($11)) {
  $12 = (($9) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIPciEENS_19__map_value_compareIS2_S3_15smaller_cstringLb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($9,$13);
 }
 HEAP32[$0>>2] = $10;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy8);
 HEAP32[560664>>2] = 0;
 $14 = HEAP32[560672>>2]|0;
 $15 = HEAP32[628384>>2]|0;
 $16 = ($14|0)==(0|0);
 if (!($16)) {
  $17 = (($14) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiN6Object4RTTIEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($14,$18);
 }
 HEAP32[$0>>2] = $15;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($14,$$byval_copy8);
 HEAP32[560672>>2] = 0;
 $19 = HEAP32[560680>>2]|0;
 $20 = HEAP32[628384>>2]|0;
 $21 = ($19|0)==(0|0);
 if (!($21)) {
  $22 = (($19) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$0>>2] = $24;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($23,$$byval_copy8);
 }
 HEAP32[$1>>2] = $20;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy8);
 HEAP32[560680>>2] = 0;
 $25 = HEAP32[560688>>2]|0;
 $26 = HEAP32[628384>>2]|0;
 $27 = ($25|0)==(0|0);
 if ($27) {
  HEAP32[$1>>2] = $26;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy8);
  HEAP32[560688>>2] = 0;
  $31 = HEAP32[560656>>2]|0;
  $32 = HEAP32[628384>>2]|0;
  HEAP32[$0>>2] = $32;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy8);
  HEAP32[560656>>2] = 0;
  STACKTOP = sp;return;
 }
 $28 = (($25) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$25>>2]|0;
 HEAP32[$0>>2] = $30;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($29,$$byval_copy8);
 HEAP32[$1>>2] = $26;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy8);
 HEAP32[560688>>2] = 0;
 $31 = HEAP32[560656>>2]|0;
 $32 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $32;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy8);
 HEAP32[560656>>2] = 0;
 STACKTOP = sp;return;
}
function __Z18LockObjectCreationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z20UnlockObjectCreationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($id,$localIdentifier) {
 $id = $id|0;
 $localIdentifier = $localIdentifier|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20GetPersistentManagerv()|0);
 __ZN17PersistentManager51InstanceIDToLocalSerializedObjectIdentifierInternalEiR31LocalSerializedObjectIdentifier($0,$id,$localIdentifier);
 STACKTOP = sp;return;
}
function __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID) {
 $localIdentifier = $localIdentifier|0;
 $instanceID = $instanceID|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20GetPersistentManagerv()|0);
 __ZN17PersistentManager51LocalSerializedObjectIdentifierToInstanceIDInternalERK31LocalSerializedObjectIdentifierRi($0,$localIdentifier,$instanceID);
 STACKTOP = sp;return;
}
function __Z31ReadObjectFromPersistentManageri($instanceID) {
 $instanceID = $instanceID|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($instanceID|0)<(1);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__Z20GetPersistentManagerv()|0);
 $2 = (__ZN17PersistentManager10ReadObjectEi($1,$instanceID)|0);
 $$0 = $2;
 STACKTOP = sp;return ($$0|0);
}
function __Z38PreallocateObjectFromPersistentManagerib($instanceID,$threadedLoading) {
 $instanceID = $instanceID|0;
 $threadedLoading = $threadedLoading|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $obj$0 = 0, $pos$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 if ($threadedLoading) {
  $36 = (__Z20GetPersistentManagerv()|0);
  $37 = (__ZN17PersistentManager25PreallocateObjectThreadedEi($36,$instanceID)|0);
  $obj$0 = $37;
  STACKTOP = sp;return ($obj$0|0);
 }
 $1 = ($instanceID|0)==(0);
 if ($1) {
  $obj$0 = 0;
  STACKTOP = sp;return ($obj$0|0);
 }
 HEAP32[$0>>2] = $instanceID;
 $2 = HEAP32[560624>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($2) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $9 = (($2) + 28|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($2) + 32|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + ($12<<3)|0);
    $29 = $13;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$2,$0);
    $14 = HEAP32[$pos$i$i$i>>2]|0;
    $15 = ($14|0)==(-1);
    $16 = (($2) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    if ($15) {
     $18 = (($2) + 32|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($17) + ($19<<3)|0);
     $29 = $20;
     break;
    } else {
     $21 = (($17) + ($14<<3)|0);
     $29 = $21;
     break;
    }
   }
  } while(0);
  $22 = HEAP32[560624>>2]|0;
  $23 = (($22) + 28|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($22) + 32|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + ($26<<3)|0);
  $28 = ($29|0)==($27|0);
  if (!($28)) {
   $30 = (($29) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $obj$0 = $31;
    STACKTOP = sp;return ($obj$0|0);
   }
  }
 }
 $33 = ($instanceID|0)<(1);
 if ($33) {
  $obj$0 = 0;
  STACKTOP = sp;return ($obj$0|0);
 }
 $34 = (__Z20GetPersistentManagerv()|0);
 $35 = (__ZN17PersistentManager10ReadObjectEi($34,$instanceID)|0);
 $obj$0 = $35;
 STACKTOP = sp;return ($obj$0|0);
}
function __Z43DestroyWithoutLoadingButDontDestroyFromFilei($instanceID) {
 $instanceID = $instanceID|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (__Z20GetPersistentManagerv()|0);
 __ZN17PersistentManager22MakeObjectUnpersistentEi13UnpersistMode($1,$instanceID,0);
 HEAP32[$0>>2] = $instanceID;
 $2 = HEAP32[560624>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 do {
  if ($8) {
   $9 = (($2) + 28|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($2) + 32|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($10) + ($12<<3)|0);
   $29 = $13;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$2,$0);
   $14 = HEAP32[$$byval_copy>>2]|0;
   $15 = ($14|0)==(-1);
   $16 = (($2) + 28|0);
   $17 = HEAP32[$16>>2]|0;
   if ($15) {
    $18 = (($2) + 32|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($17) + ($19<<3)|0);
    $29 = $20;
    break;
   } else {
    $21 = (($17) + ($14<<3)|0);
    $29 = $21;
    break;
   }
  }
 } while(0);
 $22 = HEAP32[560624>>2]|0;
 $23 = (($22) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 32|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + ($26<<3)|0);
 $28 = ($29|0)==($27|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $30 = (($29) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 __Z28delete_object_internal_step1P6Object($31);
 $33 = (($31) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 4095;
 $36 = HEAP32[$31>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vi[$37 & 4095]($31);
 HEAP32[$0>>2] = $35;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z19DestroySingleObjectP6Object($o) {
 $o = $o|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($o|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($o) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1048576;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (__Z20GetPersistentManagerv()|0);
  $7 = (($o) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  __ZN17PersistentManager22MakeObjectUnpersistentEi13UnpersistMode($6,$8,1);
 }
 __Z28delete_object_internal_step1P6Object($o);
 $9 = HEAP32[$2>>2]|0;
 $10 = $9 & 4095;
 $11 = HEAP32[$o>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vi[$12 & 4095]($o);
 HEAP32[$0>>2] = $10;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($o,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN6ObjectC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560696 + 8|0));
 $0 = HEAP32[$label>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $0 & 4095;
 $4 = $2 & -2097152;
 $5 = $4 | $3;
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 16|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 20|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$1>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN6Object22CalculateCachedClassIDEPS_($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$obj>>2]|0;
 $1 = (($0) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($obj)|0);
 $4 = (($obj) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3 << 21;
 $7 = $5 & 2097151;
 $8 = $7 | $6;
 HEAP32[$4>>2] = $8;
 STACKTOP = sp;return ($obj|0);
}
function __ZN6Object18RegisterInstanceIDEPS_($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = HEAP32[560624>>2]|0;
 $3 = (($obj) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = $obj;
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($2,1,0);
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS5_($1,$2,$0);
 STACKTOP = sp;return;
}
function __ZN6Object24RegisterInstanceIDNoLockEPS_($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = HEAP32[$obj>>2]|0;
 $3 = (($2) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($obj)|0);
 $6 = (($obj) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5 << 21;
 $9 = $7 & 2097151;
 $10 = $9 | $8;
 HEAP32[$6>>2] = $10;
 $11 = HEAP32[560624>>2]|0;
 $12 = (($obj) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$0>>2] = $13;
 $14 = (($0) + 4|0);
 HEAP32[$14>>2] = $obj;
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($11,1,0);
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS5_($1,$11,$0);
 STACKTOP = sp;return;
}
function __ZN6Object27AllocateAndAssignInstanceIDEPS_($obj) {
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = HEAP32[560800>>2]|0;
 $3 = (($2) + -2)|0;
 HEAP32[560800>>2] = $3;
 $4 = (($obj) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = HEAP32[$obj>>2]|0;
 $6 = (($5) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($obj)|0);
 $9 = (($obj) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $8 << 21;
 $12 = $10 & 2097151;
 $13 = $12 | $11;
 HEAP32[$9>>2] = $13;
 $14 = HEAP32[560624>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = $15;
 $16 = (($0) + 4|0);
 HEAP32[$16>>2] = $obj;
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($14,1,0);
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS5_($1,$14,$0);
 STACKTOP = sp;return ($obj|0);
}
function __Z28delete_object_internal_step1P6Object($object) {
 $object = $object|0;
 var $$phi$trans$insert$i$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($object) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$1>>2]|0;
  __ZN12EventManager11InvokeEventEP10EventEntryPvi($4,$object,2);
  $5 = (__Z15GetEventManagerv()|0);
  $6 = HEAP32[$1>>2]|0;
  __ZN12EventManager11RemoveEventEP10EventEntry($5,$6);
  HEAP32[$1>>2] = 0;
 }
 $7 = HEAP32[560624>>2]|0;
 $8 = (($object) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $9;
 $10 = (($7) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($7) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)==($13|0);
 do {
  if ($14) {
   $15 = (($7) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($7) + 32|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($16) + ($18<<3)|0);
   $29 = $16;$30 = $18;$32 = $19;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$7,$0);
   $20 = HEAP32[$pos$i$i$i>>2]|0;
   $21 = ($20|0)==(-1);
   $22 = (($7) + 28|0);
   $23 = HEAP32[$22>>2]|0;
   if ($21) {
    $24 = (($7) + 32|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + ($25<<3)|0);
    $29 = $23;$30 = $25;$32 = $26;
    break;
   } else {
    $27 = (($23) + ($20<<3)|0);
    $$phi$trans$insert$i$i = (($7) + 32|0);
    $$pre$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
    $29 = $23;$30 = $$pre$i$i;$32 = $27;
    break;
   }
  }
 } while(0);
 $28 = (($29) + ($30<<3)|0);
 $31 = ($32|0)==($28|0);
 if (!($31)) {
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $34 = (($7) + 12|0);
   $35 = $34;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $38 = (($35) + 4)|0;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = $32;
   $42 = $41;
   HEAP32[$42>>2] = $37;
   $43 = (($41) + 4)|0;
   $44 = $43;
   HEAP32[$44>>2] = $40;
  }
  $45 = HEAP32[$12>>2]|0;
  $46 = (($45) + 1)|0;
  HEAP32[$12>>2] = $46;
  $47 = (($7) + 48|0);
  HEAP8[$47>>0] = 1;
 }
 $48 = (0|0)==(0|0);
 if (!($48)) {
  $49 = HEAP32[$8>>2]|0;
  abort /* segfault, call an absolute addr */ (($49|0));
 }
 $50 = HEAP32[$object>>2]|0;
 $51 = (($50) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vi[$52 & 4095]($object);
 HEAP32[$8>>2] = 0;
 $53 = (($object) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0|0);
 if ($55) {
  STACKTOP = sp;return;
 }
 __ZN9Scripting31SetInstanceIDOnScriptingWrapperEP15ScriptingObjecti($54,0);
 $56 = HEAP32[$object>>2]|0;
 $57 = (($56) + 56|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_vii[$58 & 4095]($object,0);
 STACKTOP = sp;return;
}
function __ZN6ObjectD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN6ObjectD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object15SetIsPersistentEb($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $p&1;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $0 << 20;
 $4 = $2 & -1048577;
 $5 = $4 | $3;
 HEAP32[$1>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN6Object24SetCachedScriptingObjectEP15ScriptingObject($this,$object) {
 $this = $this|0;
 $object = $object|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($object|0)==(0|0);
 if (!($0)) {
  $1 = (__Z22scripting_gchandle_newP15ScriptingObject($object)|0);
  $2 = (($this) + 16|0);
  HEAP32[$2>>2] = $1;
  $3 = (($this) + 20|0);
  HEAP32[$3>>2] = $object;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 __ZN9Scripting30SetCachedPtrOnScriptingWrapperEP15ScriptingObjectPv($5,0);
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 __Z23scripting_gchandle_freei($8);
 HEAP32[$7>>2] = 0;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6Object13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP8[$0>>0] = 12;
 $1 = (($0) + 1|0);
 ;HEAP8[$1+0>>0]=HEAP8[560808+0>>0]|0;HEAP8[$1+1>>0]=HEAP8[560808+1>>0]|0;HEAP8[$1+2>>0]=HEAP8[560808+2>>0]|0;HEAP8[$1+3>>0]=HEAP8[560808+3>>0]|0;HEAP8[$1+4>>0]=HEAP8[560808+4>>0]|0;HEAP8[$1+5>>0]=HEAP8[560808+5>>0]|0;
 $2 = (($0) + 7|0);
 HEAP8[$2>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,0,-1,($0|0),24,(0|0),1,0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $12 = HEAP8[$0>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   ___resumeException($10|0);
   // unreachable;
  }
  $15 = (($0) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  __ZdlPv($16);
  ___resumeException($10|0);
  // unreachable;
 } else {
  $5 = HEAP8[$0>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   STACKTOP = sp;return;
  }
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
  STACKTOP = sp;return;
 }
}
function __ZN6Object13RegisterClassEiiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEiPFPS_10MemLabelId18ObjectCreationModeEbb($inClassID,$inBaseClass,$inName,$byteSize,$inFunc,$isAbstract,$isSealed) {
 $inClassID = $inClassID|0;
 $inBaseClass = $inBaseClass|0;
 $inName = $inName|0;
 $byteSize = $byteSize|0;
 $inFunc = $inFunc|0;
 $isAbstract = $isAbstract|0;
 $isSealed = $isSealed|0;
 var $$ = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 HEAP32[$0>>2] = $inClassID;
 $2 = HEAP32[560672>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4|0);
 $6 = ($4|0)==(0|0);
 if ($6) {
  label = 15;
 } else {
  $$0$ph7$i$i$i$i = $5;$$01$ph6$i$in$i$i$i = $4;
  L2: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i$i) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<($inClassID|0);
    if (!($9)) {
     break;
    }
    $12 = (($$013$i$in$i$i$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i$i = $13;
    }
   }
   $10 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $10;
   }
  }
  $15 = ($$0$ph5$i$i$i$i|0)==($5|0);
  if (!($15)) {
   $16 = (($$0$ph5$i$i$i$i) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>($inClassID|0);
   if (!($18)) {
    STACKTOP = sp;return;
   }
  }
  if ($6) {
   label = 15;
  } else {
   $$0$ph7$i$i$i = $5;$$01$ph6$i$in$i$i = $4;
   L13: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $19 = (($$013$i$in$i$i) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)<($inBaseClass|0);
     if (!($21)) {
      break;
     }
     $24 = (($$013$i$in$i$i) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     if ($26) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L13;
     } else {
      $$013$i$in$i$i = $25;
     }
    }
    $22 = HEAP32[$$013$i$in$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $22;
    }
   }
   $27 = ($$0$ph5$i$i$i|0)==($5|0);
   if ($27) {
    label = 15;
   } else {
    $28 = (($$0$ph5$i$i$i) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)>($inBaseClass|0);
    if ($30) {
     label = 15;
    } else {
     $35 = $$0$ph5$i$i$i;
    }
   }
  }
 }
 if ((label|0) == 15) {
  $35 = $5;
 }
 $31 = (__ZNSt3__13mapIiN6Object4RTTIENS_4lessIiEE13stl_allocatorINS_4pairIKiS2_EEL18MemLabelIdentifier1ELi16EEEixERS7_($2,$0)|0);
 $32 = HEAP32[560672>>2]|0;
 $33 = (($32) + 4|0);
 $34 = ($35|0)==($33|0);
 $36 = (($35) + 20|0);
 $$ = $34 ? 0 : $36;
 HEAP32[$31>>2] = $$;
 $37 = (($31) + 4|0);
 HEAP32[$37>>2] = $inFunc;
 $38 = (($31) + 12|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($38,$inName)|0);
 $39 = HEAP32[$0>>2]|0;
 $40 = (($31) + 8|0);
 HEAP32[$40>>2] = $39;
 $41 = (($31) + 28|0);
 $42 = $isAbstract&1;
 HEAP8[$41>>0] = $42;
 $43 = (($31) + 24|0);
 HEAP32[$43>>2] = $byteSize;
 $44 = (($31) + 29|0);
 $45 = $isSealed&1;
 HEAP8[$44>>0] = $45;
 $46 = HEAP32[560664>>2]|0;
 $47 = HEAP8[$38>>0]|0;
 $48 = $47 & 1;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  $52 = (($38) + 1|0);
  $53 = $52;
 } else {
  $50 = (($31) + 20|0);
  $51 = HEAP32[$50>>2]|0;
  $53 = $51;
 }
 HEAP32[$1>>2] = $53;
 $54 = (__ZNSt3__13mapIPci15smaller_cstringNS_9allocatorINS_4pairIKS1_iEEEEEixERS5_($46,$1)|0);
 HEAP32[$54>>2] = $39;
 STACKTOP = sp;return;
}
function __ZN6Object13ClassIDToRTTIEi($classID) {
 $classID = $classID|0;
 var $$ = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560672>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $5 = (($$013$i$in$i$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<($classID|0);
    if (!($7)) {
     break;
    }
    $10 = (($$013$i$in$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $11;
    }
   }
   $8 = HEAP32[$$013$i$in$i$i>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $8;
   }
  }
  $13 = ($$0$ph5$i$i$i|0)==($3|0);
  if (!($13)) {
   $14 = (($$0$ph5$i$i$i) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>($classID|0);
   if (!($16)) {
    $18 = $$0$ph5$i$i$i;
    $17 = ($18|0)==($3|0);
    $19 = (($18) + 20|0);
    $$ = $17 ? 0 : $19;
    STACKTOP = sp;return ($$|0);
   }
  }
 }
 $18 = $3;
 $17 = ($18|0)==($3|0);
 $19 = (($18) + 20|0);
 $$ = $17 ? 0 : $19;
 STACKTOP = sp;return ($$|0);
}
function __ZNSt3__13mapIiN6Object4RTTIENS_4lessIiEE13stl_allocatorINS_4pairIKiS2_EEL18MemLabelIdentifier1ELi16EEEixERS7_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$23 = $14;
  } else {
   $4 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)<($6|0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6|0)<($4|0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$23 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $__r$0 = $15;
  $32 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($32|0);
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $17 = (__Z15malloc_internaljj10MemLabelIdiPKci(52,16,$$byval_copy,0,560648,79)|0);
 $18 = (($17) + 16|0);
 $19 = HEAP32[$__k>>2]|0;
 HEAP32[$18>>2] = $19;
 $20 = (($17) + 20|0);
 ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;HEAP32[$20+16>>2]=0|0;HEAP32[$20+20>>2]=0|0;HEAP32[$20+24>>2]=0|0;HEAP32[$20+28>>2]=0|0;
 HEAP32[$17>>2] = 0;
 $21 = (($17) + 4|0);
 HEAP32[$21>>2] = 0;
 $22 = (($17) + 8|0);
 HEAP32[$22>>2] = $23;
 HEAP32[$$0$i>>2] = $17;
 $24 = HEAP32[$this>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $28 = $17;
 } else {
  HEAP32[$this>>2] = $25;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $28 = $$pre$i;
 }
 $27 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 $__r$0 = $17;
 $32 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($32|0);
}
function __ZNSt3__13mapIPci15smaller_cstringNS_9allocatorINS_4pairIKS1_iEEEEEixERS5_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $15 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $15;
   $$0$i = $15;$24 = $15;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (_strcmp($3,$5)|0);
    $7 = ($6|0)<(0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = (_strcmp($5,$3)|0);
    $11 = ($10|0)<(0);
    if (!($11)) {
     label = 9;
     break;
    }
    $12 = (($__nd$0$in$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $13;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$24 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $12;$24 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$24 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $16 = HEAP32[$$0$i>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $__r$0 = $16;
  $33 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($33|0);
 }
 $18 = (__Znwj(24)|0);
 $19 = (($18) + 16|0);
 $20 = HEAP32[$__k>>2]|0;
 HEAP32[$19>>2] = $20;
 $21 = (($18) + 20|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$18>>2] = 0;
 $22 = (($18) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = (($18) + 8|0);
 HEAP32[$23>>2] = $24;
 HEAP32[$$0$i>>2] = $18;
 $25 = HEAP32[$this>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $29 = $18;
 } else {
  HEAP32[$this>>2] = $26;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $29 = $$pre$i;
 }
 $28 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$29);
 $30 = (($this) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 1)|0;
 HEAP32[$30>>2] = $32;
 $__r$0 = $18;
 $33 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($33|0);
}
function __ZN6Object7ProduceEii10MemLabelId18ObjectCreationMode($classID,$instanceID,$memLabel,$mode) {
 $classID = $classID|0;
 $instanceID = $instanceID|0;
 $memLabel = $memLabel|0;
 $mode = $mode|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 $3 = HEAP32[560672>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4|0);
 $7 = ($5|0)==(0|0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$ph7$i$i$i = $6;$$01$ph6$i$in$i$i = $5;
 }
 L3: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $8 = (($$013$i$in$i$i) + 16|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)<($classID|0);
   if (!($10)) {
    break;
   }
   $13 = (($$013$i$in$i$i) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L3;
   } else {
    $$013$i$in$i$i = $14;
   }
  }
  $11 = HEAP32[$$013$i$in$i$i>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $11;
  }
 }
 $16 = ($$0$ph5$i$i$i|0)==($6|0);
 if ($16) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = (($$0$ph5$i$i$i) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)>($classID|0);
 $20 = ($$0$ph5$i$i$i|0)==($6|0);
 $or$cond = $19 | $20;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($$0$ph5$i$i$i) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = ($instanceID|0)==(0);
 $25 = HEAP32[$memLabel>>2]|0;
 if ($24) {
  HEAP32[$2>>2] = $25;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  $52 = (FUNCTION_TABLE_iii[$22 & 4095]($$byval_copy1,$mode)|0);
  $53 = ($mode|0)==(2);
  $54 = HEAP32[560800>>2]|0;
  $55 = (($54) + -2)|0;
  HEAP32[560800>>2] = $55;
  $56 = (($52) + 4|0);
  HEAP32[$56>>2] = $55;
  $57 = HEAP32[$52>>2]|0;
  $58 = (($57) + 52|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (FUNCTION_TABLE_ii[$59 & 4095]($52)|0);
  $61 = (($52) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = $60 << 21;
  $64 = $62 & 2097151;
  $65 = $64 | $63;
  HEAP32[$61>>2] = $65;
  if ($53) {
   $66 = HEAP32[560624>>2]|0;
   $67 = HEAP32[$56>>2]|0;
   HEAP32[$$byval_copy1>>2] = $67;
   $68 = (($$byval_copy1) + 4|0);
   HEAP32[$68>>2] = $52;
   __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($66,1,0);
   __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS5_($0,$66,$$byval_copy1);
   $$0 = $52;
   STACKTOP = sp;return ($$0|0);
  } else {
   $69 = HEAP32[560624>>2]|0;
   $70 = HEAP32[$56>>2]|0;
   HEAP32[$$byval_copy1>>2] = $70;
   $71 = (($$byval_copy1) + 4|0);
   HEAP32[$71>>2] = $52;
   __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($69,1,0);
   __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS5_($0,$69,$$byval_copy1);
   $$0 = $52;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$1>>2] = $25;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $26 = (FUNCTION_TABLE_iii[$22 & 4095]($$byval_copy1,$mode)|0);
 $27 = ($26|0)==(0|0);
 if ($27) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = (($26) + 4|0);
 HEAP32[$28>>2] = $instanceID;
 $29 = HEAP32[$26>>2]|0;
 $30 = (($29) + 52|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_ii[$31 & 4095]($26)|0);
 $33 = (($26) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $32 << 21;
 $36 = $34 & 2097151;
 $37 = $36 | $35;
 HEAP32[$33>>2] = $37;
 if ((($mode|0) == 2)) {
  $41 = HEAP32[$26>>2]|0;
  $42 = (($41) + 52|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (FUNCTION_TABLE_ii[$43 & 4095]($26)|0);
  $45 = HEAP32[$33>>2]|0;
  $46 = $44 << 21;
  $47 = $45 & 2097151;
  $48 = $47 | $46;
  HEAP32[$33>>2] = $48;
  $49 = HEAP32[560624>>2]|0;
  $50 = HEAP32[$28>>2]|0;
  HEAP32[$$byval_copy1>>2] = $50;
  $51 = (($$byval_copy1) + 4|0);
  HEAP32[$51>>2] = $26;
  __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($49,1,0);
  __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS5_($0,$49,$$byval_copy1);
  $$0 = $26;
  STACKTOP = sp;return ($$0|0);
 } else if ((($mode|0) == 0)) {
  $38 = HEAP32[560624>>2]|0;
  $39 = HEAP32[$28>>2]|0;
  HEAP32[$$byval_copy1>>2] = $39;
  $40 = (($$byval_copy1) + 4|0);
  HEAP32[$40>>2] = $26;
  __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($38,1,0);
  __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS5_($0,$38,$$byval_copy1);
  $$0 = $26;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = $26;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6Object22CheckInstanceIDsLoadedEPii($instanceIDs,$size) {
 $instanceIDs = $instanceIDs|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $exitcond = 0, $i$01 = 0, $not$$i$i = 0, $pos$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i = sp;
 $0 = ($size|0)>(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $i$01 = 0;
 while(1) {
  $1 = HEAP32[560624>>2]|0;
  $2 = (($instanceIDs) + ($i$01<<2)|0);
  __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i,$1,$2);
  $3 = HEAP32[$pos$i$i>>2]|0;
  $not$$i$i = ($3|0)==(-1);
  if (!($not$$i$i)) {
   HEAP32[$2>>2] = 0;
  }
  $4 = (($i$01) + 1)|0;
  $exitcond = ($4|0)==($size|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6Object21IDToPointerThreadSafeEi($inInstanceID) {
 $inInstanceID = $inInstanceID|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 HEAP32[$0>>2] = $inInstanceID;
 $1 = HEAP32[560624>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $3 = (($1) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 do {
  if ($7) {
   $8 = (($1) + 28|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($1) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + ($11<<3)|0);
   $28 = $12;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$1,$0);
   $13 = HEAP32[$pos$i$i$i>>2]|0;
   $14 = ($13|0)==(-1);
   $15 = (($1) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   if ($14) {
    $17 = (($1) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + ($18<<3)|0);
    $28 = $19;
    break;
   } else {
    $20 = (($16) + ($13<<3)|0);
    $28 = $20;
    break;
   }
  }
 } while(0);
 $21 = HEAP32[560624>>2]|0;
 $22 = (($21) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 32|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + ($25<<3)|0);
 $27 = ($28|0)==($26|0);
 if ($27) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $29 = (($28) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $$0$i = $30;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN6Object24IDToPointerNoThreadCheckEi($inInstanceID) {
 $inInstanceID = $inInstanceID|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i = sp + 8|0;
 $0 = sp;
 HEAP32[$0>>2] = $inInstanceID;
 $1 = HEAP32[560624>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($1) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 do {
  if ($7) {
   $8 = (($1) + 28|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($1) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + ($11<<3)|0);
   $28 = $12;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i,$1,$0);
   $13 = HEAP32[$pos$i$i>>2]|0;
   $14 = ($13|0)==(-1);
   $15 = (($1) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   if ($14) {
    $17 = (($1) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + ($18<<3)|0);
    $28 = $19;
    break;
   } else {
    $20 = (($16) + ($13<<3)|0);
    $28 = $20;
    break;
   }
  }
 } while(0);
 $21 = HEAP32[560624>>2]|0;
 $22 = (($21) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 32|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + ($25<<3)|0);
 $27 = ($28|0)==($26|0);
 if ($27) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($28) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $$0 = $30;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6Object21FindAllDerivedClassesEiPNSt3__16vectorIiNS0_9allocatorIiEEEEb($classID,$derivedClasses,$onlyNonAbstract) {
 $classID = $classID|0;
 $derivedClasses = $derivedClasses|0;
 $onlyNonAbstract = $onlyNonAbstract|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560672>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($0) + 4|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($derivedClasses) + 4|0);
 $5 = (($derivedClasses) + 8|0);
 $7 = $1;
 L4: while(1) {
  $6 = (($7) + 16|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = HEAP32[560640>>2]|0;
  $10 = Math_imul($9, $8)|0;
  $11 = (($10) + ($classID))|0;
  $12 = $11 >> 5;
  $13 = $12 << 5;
  $14 = (($11) - ($13))|0;
  $15 = HEAP32[560632>>2]|0;
  $16 = (($15) + ($12<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = 1 << $14;
  $19 = $18 & $17;
  $20 = ($19|0)==(0);
  do {
   if (!($20)) {
    if ($onlyNonAbstract) {
     $21 = (($7) + 48|0);
     $22 = HEAP8[$21>>0]|0;
     $23 = ($22<<24>>24)==(0);
     if (!($23)) {
      break;
     }
    }
    $24 = HEAP32[$4>>2]|0;
    $25 = HEAP32[$5>>2]|0;
    $26 = ($24|0)==($25|0);
    if (!($26)) {
     $27 = ($24|0)==(0|0);
     if (!($27)) {
      HEAP32[$24>>2] = $8;
     }
     $28 = (($24) + 4|0);
     HEAP32[$4>>2] = $28;
     break;
    }
    $29 = HEAP32[$derivedClasses>>2]|0;
    $30 = $24;
    $31 = $29;
    $32 = (($30) - ($31))|0;
    $33 = $32 >> 2;
    $34 = (($33) + 1)|0;
    $35 = ($34>>>0)>(1073741823);
    if ($35) {
     label = 11;
     break L4;
    }
    $36 = ($33>>>0)<(536870911);
    if ($36) {
     $37 = $32 >> 1;
     $38 = ($37>>>0)<($34>>>0);
     $39 = $38 ? $34 : $37;
     $40 = ($39|0)==(0);
     if ($40) {
      $$0$i3$i$i = 0;$44 = 0;
     } else {
      $$0$i2$i$i = $39;
      label = 14;
     }
    } else {
     $$0$i2$i$i = 1073741823;
     label = 14;
    }
    if ((label|0) == 14) {
     label = 0;
     $41 = $$0$i2$i$i << 2;
     $42 = (__Znwj($41)|0);
     $$0$i3$i$i = $$0$i2$i$i;$44 = $42;
    }
    $43 = (($44) + ($33<<2)|0);
    $45 = (($44) + ($$0$i3$i$i<<2)|0);
    $46 = ($43|0)==(0|0);
    if (!($46)) {
     $47 = HEAP32[$6>>2]|0;
     HEAP32[$43>>2] = $47;
    }
    $48 = (($44) + ($34<<2)|0);
    _memcpy(($44|0),($29|0),($32|0))|0;
    HEAP32[$derivedClasses>>2] = $44;
    HEAP32[$4>>2] = $48;
    HEAP32[$5>>2] = $45;
    $49 = ($29|0)==(0|0);
    if (!($49)) {
     __ZdlPv($29);
    }
   }
  } while(0);
  $50 = (($7) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0|0);
  if ($52) {
   $$01$i$i$i$i = $7;
   while(1) {
    $55 = (($$01$i$i$i$i) + 8|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$56>>2]|0;
    $58 = ($57|0)==($$01$i$i$i$i|0);
    if ($58) {
     $$0$i$i$i$i = $56;
     break;
    } else {
     $$01$i$i$i$i = $56;
    }
   }
  } else {
   $$0$i$i$i$i$i = $51;
   while(1) {
    $53 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $53;
    }
   }
  }
  $59 = HEAP32[560672>>2]|0;
  $60 = (($59) + 4|0);
  $61 = ($$0$i$i$i$i|0)==($60|0);
  if ($61) {
   label = 25;
   break;
  }
  $7 = $$0$i$i$i$i;
 }
 if ((label|0) == 11) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 25) {
  STACKTOP = sp;return;
 }
}
function __ZN6Object21FindAllDerivedObjectsEiPNSt3__16vectorIiNS0_9allocatorIiEEEEb($classID,$derivedObjects,$sorted) {
 $classID = $classID|0;
 $derivedObjects = $derivedObjects|0;
 $sorted = $sorted|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 3|0;
 $$byval_copy = sp;
 $0 = sp + 1|0;
 $1 = sp + 2|0;
 $2 = HEAP32[560624>>2]|0;
 ;HEAP8[$$byval_copy+0>>0]=HEAP8[$0+0>>0]|0;
 ;HEAP8[$$byval_copy1+0>>0]=HEAP8[$1+0>>0]|0;
 $3 = (__Z25FindAllDerivedObjectsImplI13GetConstFirstNSt3__16vectorIiNS1_9allocatorIiEEEENS1_4lessIiEEEiRK28InstanceIdToObjectPtrHashMapiT_PT0_bT1_($2,$classID,$$byval_copy,$derivedObjects,$sorted,$$byval_copy1)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z25FindAllDerivedObjectsImplI13GetConstFirstNSt3__16vectorIiNS1_9allocatorIiEEEENS1_4lessIiEEEiRK28InstanceIdToObjectPtrHashMapiT_PT0_bT1_($objmap,$classID,$getter,$derivedObjects,$sorted,$pred) {
 $objmap = $objmap|0;
 $classID = $classID|0;
 $getter = $getter|0;
 $derivedObjects = $derivedObjects|0;
 $sorted = $sorted|0;
 $pred = $pred|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$__r$0$i$i = 0, $$be = 0, $$ph18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__r$01$i$i = 0, $count$020 = 0, $count$1 = 0, $or$cond = 0, $sorted$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($derivedObjects|0)==(0|0);
 $2 = (($objmap) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($objmap) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5<<3)|0);
 $7 = ($5|0)==(0);
 if ($1) {
  L3: do {
   if ($7) {
    $25 = $3;
   } else {
    $8 = (($objmap) + 20|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($objmap) + 8|0);
    $11 = (($objmap) + 4|0);
    $12 = (($objmap) + 12|0);
    $14 = $3;
    while(1) {
     $13 = HEAP32[$14>>2]|0;
     $15 = ($9|0)==($13|0);
     if (!($15)) {
      $16 = HEAP8[$10>>0]|0;
      $17 = ($16<<24>>24)==(0);
      if ($17) {
       $25 = $14;
       break L3;
      }
      $18 = HEAP32[$11>>2]|0;
      $19 = ($18|0)==(0);
      if ($19) {
       $25 = $14;
       break L3;
      }
      $20 = HEAP32[$12>>2]|0;
      $21 = ($20|0)==($13|0);
      if (!($21)) {
       $25 = $14;
       break L3;
      }
     }
     $22 = (($14) + 8|0);
     $23 = ($22|0)==($6|0);
     if ($23) {
      $$0 = 0;
      break;
     } else {
      $14 = $22;
     }
    }
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $24 = ($25|0)==($6|0);
  if ($24) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $26 = HEAP32[560640>>2]|0;
  $27 = HEAP32[560632>>2]|0;
  $28 = (($objmap) + 20|0);
  $29 = (($objmap) + 8|0);
  $30 = (($objmap) + 4|0);
  $31 = (($objmap) + 12|0);
  $33 = $25;$__r$01$i$i = 0;
  L17: while(1) {
   $32 = (($33) + 4|0);
   $34 = HEAP32[$32>>2]|0;
   $35 = (($34) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = $36 >>> 21;
   $38 = Math_imul($37, $26)|0;
   $39 = (($38) + ($classID))|0;
   $40 = $39 >> 5;
   $41 = $40 << 5;
   $42 = (($39) - ($41))|0;
   $43 = (($27) + ($40<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = 1 << $42;
   $46 = $45 & $44;
   $47 = ($46|0)!=(0);
   $48 = $47&1;
   $$__r$0$i$i = (($48) + ($__r$01$i$i))|0;
   $49 = (($33) + 8|0);
   $50 = ($49|0)==($6|0);
   if ($50) {
    $$0 = $$__r$0$i$i;
    label = 53;
    break;
   }
   $53 = HEAP32[$28>>2]|0;
   $52 = $49;
   while(1) {
    $54 = HEAP32[$52>>2]|0;
    $55 = ($53|0)==($54|0);
    if (!($55)) {
     $56 = HEAP8[$29>>0]|0;
     $57 = ($56<<24>>24)==(0);
     if ($57) {
      break;
     }
     $58 = HEAP32[$30>>2]|0;
     $59 = ($58|0)==(0);
     if ($59) {
      break;
     }
     $60 = HEAP32[$31>>2]|0;
     $61 = ($60|0)==($54|0);
     if (!($61)) {
      break;
     }
    }
    $62 = (($52) + 8|0);
    $63 = ($62|0)==($6|0);
    if ($63) {
     $$0 = $$__r$0$i$i;
     label = 53;
     break L17;
    } else {
     $52 = $62;
    }
   }
   $51 = ($52|0)==($6|0);
   if ($51) {
    $$0 = $$__r$0$i$i;
    label = 53;
    break;
   } else {
    $33 = $52;$__r$01$i$i = $$__r$0$i$i;
   }
  }
  if ((label|0) == 53) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 L33: do {
  if ($7) {
   $$ph18 = $3;
  } else {
   $64 = (($objmap) + 20|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($objmap) + 8|0);
   $67 = (($objmap) + 4|0);
   $68 = (($objmap) + 12|0);
   $70 = $3;
   while(1) {
    $69 = HEAP32[$70>>2]|0;
    $71 = ($65|0)==($69|0);
    if (!($71)) {
     $72 = HEAP8[$66>>0]|0;
     $73 = ($72<<24>>24)==(0);
     if ($73) {
      $$ph18 = $70;
      break L33;
     }
     $74 = HEAP32[$67>>2]|0;
     $75 = ($74|0)==(0);
     if ($75) {
      $$ph18 = $70;
      break L33;
     }
     $76 = HEAP32[$68>>2]|0;
     $77 = ($76|0)==($69|0);
     if (!($77)) {
      $$ph18 = $70;
      break L33;
     }
    }
    $78 = (($70) + 8|0);
    $79 = ($78|0)==($6|0);
    if ($79) {
     $$0 = 0;
     break;
    } else {
     $70 = $78;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $80 = ($$ph18|0)==($6|0);
 if ($80) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $81 = (($objmap) + 20|0);
 $82 = (($objmap) + 8|0);
 $83 = (($objmap) + 4|0);
 $84 = (($objmap) + 12|0);
 $85 = (($derivedObjects) + 4|0);
 $86 = (($derivedObjects) + 8|0);
 $88 = $$ph18;$count$020 = 0;
 while(1) {
  $87 = (($88) + 4|0);
  $89 = HEAP32[$87>>2]|0;
  $90 = (($89) + 8|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = $91 >>> 21;
  $93 = HEAP32[560640>>2]|0;
  $94 = Math_imul($93, $92)|0;
  $95 = (($94) + ($classID))|0;
  $96 = $95 >> 5;
  $97 = $96 << 5;
  $98 = (($95) - ($97))|0;
  $99 = HEAP32[560632>>2]|0;
  $100 = (($99) + ($96<<2)|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = 1 << $98;
  $103 = $102 & $101;
  $104 = ($103|0)==(0);
  if ($104) {
   $count$1 = $count$020;
  } else {
   $105 = HEAP32[$85>>2]|0;
   $106 = HEAP32[$86>>2]|0;
   $107 = ($105|0)==($106|0);
   if ($107) {
    $111 = HEAP32[$derivedObjects>>2]|0;
    $112 = $105;
    $113 = $111;
    $114 = (($112) - ($113))|0;
    $115 = $114 >> 2;
    $116 = (($115) + 1)|0;
    $117 = ($116>>>0)>(1073741823);
    if ($117) {
     label = 34;
     break;
    }
    $118 = ($115>>>0)<(536870911);
    if ($118) {
     $119 = $114 >> 1;
     $120 = ($119>>>0)<($116>>>0);
     $121 = $120 ? $116 : $119;
     $122 = ($121|0)==(0);
     if ($122) {
      $$0$i3$i$i = 0;$126 = 0;
     } else {
      $$0$i2$i$i = $121;
      label = 37;
     }
    } else {
     $$0$i2$i$i = 1073741823;
     label = 37;
    }
    if ((label|0) == 37) {
     label = 0;
     $123 = $$0$i2$i$i << 2;
     $124 = (__Znwj($123)|0);
     $$0$i3$i$i = $$0$i2$i$i;$126 = $124;
    }
    $125 = (($126) + ($115<<2)|0);
    $127 = (($126) + ($$0$i3$i$i<<2)|0);
    $128 = ($125|0)==(0|0);
    if (!($128)) {
     $129 = HEAP32[$88>>2]|0;
     HEAP32[$125>>2] = $129;
    }
    $130 = (($126) + ($116<<2)|0);
    _memcpy(($126|0),($111|0),($114|0))|0;
    HEAP32[$derivedObjects>>2] = $126;
    HEAP32[$85>>2] = $130;
    HEAP32[$86>>2] = $127;
    $131 = ($111|0)==(0|0);
    if (!($131)) {
     __ZdlPv($111);
    }
   } else {
    $108 = ($105|0)==(0|0);
    if (!($108)) {
     $109 = HEAP32[$88>>2]|0;
     HEAP32[$105>>2] = $109;
    }
    $110 = (($105) + 4|0);
    HEAP32[$85>>2] = $110;
   }
   $132 = (($count$020) + 1)|0;
   $count$1 = $132;
  }
  $133 = (($88) + 8|0);
  $134 = ($133|0)==($6|0);
  L69: do {
   if ($134) {
    $$be = $6;
   } else {
    $139 = HEAP32[$81>>2]|0;
    $141 = $133;
    while(1) {
     $140 = HEAP32[$141>>2]|0;
     $142 = ($139|0)==($140|0);
     if (!($142)) {
      $143 = HEAP8[$82>>0]|0;
      $144 = ($143<<24>>24)==(0);
      if ($144) {
       $$be = $141;
       break L69;
      }
      $145 = HEAP32[$83>>2]|0;
      $146 = ($145|0)==(0);
      if ($146) {
       $$be = $141;
       break L69;
      }
      $147 = HEAP32[$84>>2]|0;
      $148 = ($147|0)==($140|0);
      if (!($148)) {
       $$be = $141;
       break L69;
      }
     }
     $149 = (($141) + 8|0);
     $150 = ($149|0)==($6|0);
     if ($150) {
      $$be = $6;
      break;
     } else {
      $141 = $149;
     }
    }
   }
  } while(0);
  $135 = HEAP32[$2>>2]|0;
  $136 = HEAP32[$4>>2]|0;
  $137 = (($135) + ($136<<3)|0);
  $138 = ($$be|0)==($137|0);
  if ($138) {
   break;
  } else {
   $88 = $$be;$count$020 = $count$1;
  }
 }
 if ((label|0) == 34) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $sorted$not = $sorted ^ 1;
 $151 = ($count$1|0)==(0);
 $or$cond = $151 | $sorted$not;
 if ($or$cond) {
  $$0 = $count$1;
  STACKTOP = sp;return ($$0|0);
 }
 $152 = HEAP32[$derivedObjects>>2]|0;
 $153 = (($derivedObjects) + 4|0);
 $154 = HEAP32[$153>>2]|0;
 __ZNSt3__16__sortIRNS_4lessIiEEPiEEvT0_S5_T_($152,$154,$0);
 $$0 = $count$1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6Object17FindObjectsOfTypeEiPNSt3__16vectorIPS_NS0_9allocatorIS2_EEEEb($classID,$derivedObjects,$sorted) {
 $classID = $classID|0;
 $derivedObjects = $derivedObjects|0;
 $sorted = $sorted|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 3|0;
 $$byval_copy = sp;
 $0 = sp + 1|0;
 $1 = sp + 2|0;
 $2 = HEAP32[560624>>2]|0;
 ;HEAP8[$$byval_copy+0>>0]=HEAP8[$0+0>>0]|0;
 ;HEAP8[$$byval_copy1+0>>0]=HEAP8[$1+0>>0]|0;
 $3 = (__Z25FindAllDerivedObjectsImplI14GetConstSecondNSt3__16vectorIP6ObjectNS1_9allocatorIS4_EEEE17CompareInstanceIDEiRK28InstanceIdToObjectPtrHashMapiT_PT0_bT1_($2,$classID,$$byval_copy,$derivedObjects,$sorted,$$byval_copy1)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z25FindAllDerivedObjectsImplI14GetConstSecondNSt3__16vectorIP6ObjectNS1_9allocatorIS4_EEEE17CompareInstanceIDEiRK28InstanceIdToObjectPtrHashMapiT_PT0_bT1_($objmap,$classID,$getter,$derivedObjects,$sorted,$pred) {
 $objmap = $objmap|0;
 $classID = $classID|0;
 $getter = $getter|0;
 $derivedObjects = $derivedObjects|0;
 $sorted = $sorted|0;
 $pred = $pred|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$__r$0$i$i = 0, $$be = 0, $$ph18 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__r$01$i$i = 0, $count$020 = 0, $count$1 = 0, $or$cond = 0, $sorted$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($derivedObjects|0)==(0|0);
 $2 = (($objmap) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($objmap) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5<<3)|0);
 $7 = ($5|0)==(0);
 if ($1) {
  L3: do {
   if ($7) {
    $25 = $3;
   } else {
    $8 = (($objmap) + 20|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($objmap) + 8|0);
    $11 = (($objmap) + 4|0);
    $12 = (($objmap) + 12|0);
    $14 = $3;
    while(1) {
     $13 = HEAP32[$14>>2]|0;
     $15 = ($9|0)==($13|0);
     if (!($15)) {
      $16 = HEAP8[$10>>0]|0;
      $17 = ($16<<24>>24)==(0);
      if ($17) {
       $25 = $14;
       break L3;
      }
      $18 = HEAP32[$11>>2]|0;
      $19 = ($18|0)==(0);
      if ($19) {
       $25 = $14;
       break L3;
      }
      $20 = HEAP32[$12>>2]|0;
      $21 = ($20|0)==($13|0);
      if (!($21)) {
       $25 = $14;
       break L3;
      }
     }
     $22 = (($14) + 8|0);
     $23 = ($22|0)==($6|0);
     if ($23) {
      $$0 = 0;
      break;
     } else {
      $14 = $22;
     }
    }
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $24 = ($25|0)==($6|0);
  if ($24) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $26 = HEAP32[560640>>2]|0;
  $27 = HEAP32[560632>>2]|0;
  $28 = (($objmap) + 20|0);
  $29 = (($objmap) + 8|0);
  $30 = (($objmap) + 4|0);
  $31 = (($objmap) + 12|0);
  $33 = $25;$__r$01$i$i = 0;
  L17: while(1) {
   $32 = (($33) + 4|0);
   $34 = HEAP32[$32>>2]|0;
   $35 = (($34) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = $36 >>> 21;
   $38 = Math_imul($37, $26)|0;
   $39 = (($38) + ($classID))|0;
   $40 = $39 >> 5;
   $41 = $40 << 5;
   $42 = (($39) - ($41))|0;
   $43 = (($27) + ($40<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = 1 << $42;
   $46 = $45 & $44;
   $47 = ($46|0)!=(0);
   $48 = $47&1;
   $$__r$0$i$i = (($48) + ($__r$01$i$i))|0;
   $49 = (($33) + 8|0);
   $50 = ($49|0)==($6|0);
   if ($50) {
    $$0 = $$__r$0$i$i;
    label = 53;
    break;
   }
   $53 = HEAP32[$28>>2]|0;
   $52 = $49;
   while(1) {
    $54 = HEAP32[$52>>2]|0;
    $55 = ($53|0)==($54|0);
    if (!($55)) {
     $56 = HEAP8[$29>>0]|0;
     $57 = ($56<<24>>24)==(0);
     if ($57) {
      break;
     }
     $58 = HEAP32[$30>>2]|0;
     $59 = ($58|0)==(0);
     if ($59) {
      break;
     }
     $60 = HEAP32[$31>>2]|0;
     $61 = ($60|0)==($54|0);
     if (!($61)) {
      break;
     }
    }
    $62 = (($52) + 8|0);
    $63 = ($62|0)==($6|0);
    if ($63) {
     $$0 = $$__r$0$i$i;
     label = 53;
     break L17;
    } else {
     $52 = $62;
    }
   }
   $51 = ($52|0)==($6|0);
   if ($51) {
    $$0 = $$__r$0$i$i;
    label = 53;
    break;
   } else {
    $33 = $52;$__r$01$i$i = $$__r$0$i$i;
   }
  }
  if ((label|0) == 53) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 L33: do {
  if ($7) {
   $$ph18 = $3;
  } else {
   $64 = (($objmap) + 20|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($objmap) + 8|0);
   $67 = (($objmap) + 4|0);
   $68 = (($objmap) + 12|0);
   $70 = $3;
   while(1) {
    $69 = HEAP32[$70>>2]|0;
    $71 = ($65|0)==($69|0);
    if (!($71)) {
     $72 = HEAP8[$66>>0]|0;
     $73 = ($72<<24>>24)==(0);
     if ($73) {
      $$ph18 = $70;
      break L33;
     }
     $74 = HEAP32[$67>>2]|0;
     $75 = ($74|0)==(0);
     if ($75) {
      $$ph18 = $70;
      break L33;
     }
     $76 = HEAP32[$68>>2]|0;
     $77 = ($76|0)==($69|0);
     if (!($77)) {
      $$ph18 = $70;
      break L33;
     }
    }
    $78 = (($70) + 8|0);
    $79 = ($78|0)==($6|0);
    if ($79) {
     $$0 = 0;
     break;
    } else {
     $70 = $78;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $80 = ($$ph18|0)==($6|0);
 if ($80) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $81 = (($objmap) + 20|0);
 $82 = (($objmap) + 8|0);
 $83 = (($objmap) + 4|0);
 $84 = (($objmap) + 12|0);
 $85 = (($derivedObjects) + 4|0);
 $86 = (($derivedObjects) + 8|0);
 $88 = $$ph18;$count$020 = 0;
 while(1) {
  $87 = (($88) + 4|0);
  $89 = HEAP32[$87>>2]|0;
  $90 = (($89) + 8|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = $91 >>> 21;
  $93 = HEAP32[560640>>2]|0;
  $94 = Math_imul($93, $92)|0;
  $95 = (($94) + ($classID))|0;
  $96 = $95 >> 5;
  $97 = $96 << 5;
  $98 = (($95) - ($97))|0;
  $99 = HEAP32[560632>>2]|0;
  $100 = (($99) + ($96<<2)|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = 1 << $98;
  $103 = $102 & $101;
  $104 = ($103|0)==(0);
  if ($104) {
   $count$1 = $count$020;
  } else {
   $105 = HEAP32[$85>>2]|0;
   $106 = HEAP32[$86>>2]|0;
   $107 = ($105|0)==($106|0);
   if ($107) {
    $111 = HEAP32[$derivedObjects>>2]|0;
    $112 = $105;
    $113 = $111;
    $114 = (($112) - ($113))|0;
    $115 = $114 >> 2;
    $116 = (($115) + 1)|0;
    $117 = ($116>>>0)>(1073741823);
    if ($117) {
     label = 34;
     break;
    }
    $118 = ($115>>>0)<(536870911);
    if ($118) {
     $119 = $114 >> 1;
     $120 = ($119>>>0)<($116>>>0);
     $121 = $120 ? $116 : $119;
     $122 = ($121|0)==(0);
     if ($122) {
      $$0$i3$i$i = 0;$126 = 0;
     } else {
      $$0$i2$i$i = $121;
      label = 37;
     }
    } else {
     $$0$i2$i$i = 1073741823;
     label = 37;
    }
    if ((label|0) == 37) {
     label = 0;
     $123 = $$0$i2$i$i << 2;
     $124 = (__Znwj($123)|0);
     $$0$i3$i$i = $$0$i2$i$i;$126 = $124;
    }
    $125 = (($126) + ($115<<2)|0);
    $127 = (($126) + ($$0$i3$i$i<<2)|0);
    $128 = ($125|0)==(0|0);
    if (!($128)) {
     $129 = HEAP32[$87>>2]|0;
     HEAP32[$125>>2] = $129;
    }
    $130 = (($126) + ($116<<2)|0);
    _memcpy(($126|0),($111|0),($114|0))|0;
    HEAP32[$derivedObjects>>2] = $126;
    HEAP32[$85>>2] = $130;
    HEAP32[$86>>2] = $127;
    $131 = ($111|0)==(0|0);
    if (!($131)) {
     __ZdlPv($111);
    }
   } else {
    $108 = ($105|0)==(0|0);
    if ($108) {
     $110 = 0;
    } else {
     HEAP32[$105>>2] = $89;
     $$pre$i = HEAP32[$85>>2]|0;
     $110 = $$pre$i;
    }
    $109 = (($110) + 4|0);
    HEAP32[$85>>2] = $109;
   }
   $132 = (($count$020) + 1)|0;
   $count$1 = $132;
  }
  $133 = (($88) + 8|0);
  $134 = ($133|0)==($6|0);
  L69: do {
   if ($134) {
    $$be = $6;
   } else {
    $139 = HEAP32[$81>>2]|0;
    $141 = $133;
    while(1) {
     $140 = HEAP32[$141>>2]|0;
     $142 = ($139|0)==($140|0);
     if (!($142)) {
      $143 = HEAP8[$82>>0]|0;
      $144 = ($143<<24>>24)==(0);
      if ($144) {
       $$be = $141;
       break L69;
      }
      $145 = HEAP32[$83>>2]|0;
      $146 = ($145|0)==(0);
      if ($146) {
       $$be = $141;
       break L69;
      }
      $147 = HEAP32[$84>>2]|0;
      $148 = ($147|0)==($140|0);
      if (!($148)) {
       $$be = $141;
       break L69;
      }
     }
     $149 = (($141) + 8|0);
     $150 = ($149|0)==($6|0);
     if ($150) {
      $$be = $6;
      break;
     } else {
      $141 = $149;
     }
    }
   }
  } while(0);
  $135 = HEAP32[$2>>2]|0;
  $136 = HEAP32[$4>>2]|0;
  $137 = (($135) + ($136<<3)|0);
  $138 = ($$be|0)==($137|0);
  if ($138) {
   break;
  } else {
   $88 = $$be;$count$020 = $count$1;
  }
 }
 if ((label|0) == 34) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $sorted$not = $sorted ^ 1;
 $151 = ($count$1|0)==(0);
 $or$cond = $151 | $sorted$not;
 if ($or$cond) {
  $$0 = $count$1;
  STACKTOP = sp;return ($$0|0);
 }
 $152 = HEAP32[$derivedObjects>>2]|0;
 $153 = (($derivedObjects) + 4|0);
 $154 = HEAP32[$153>>2]|0;
 __ZNSt3__16__sortIR17CompareInstanceIDPP6ObjectEEvT0_S6_T_($152,$154,$0);
 $$0 = $count$1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6Object15ClassIDToStringEi($ID) {
 $ID = $ID|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_ZZN6Object15ClassIDToStringEiE11emptyString$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[560832>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  ;HEAP32[560816+0>>2]=0|0;HEAP32[560816+4>>2]=0|0;HEAP32[560816+8>>2]=0|0;
  HEAP8[560832>>0] = 1;
 }
 $2 = HEAP32[560672>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4|0);
 $6 = ($4|0)==(0|0);
 if ($6) {
  label = 10;
 } else {
  $$0$ph7$i$i$i = $5;$$01$ph6$i$in$i$i = $4;
  L5: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<($ID|0);
    if (!($9)) {
     break;
    }
    $12 = (($$013$i$in$i$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L5;
    } else {
     $$013$i$in$i$i = $13;
    }
   }
   $10 = HEAP32[$$013$i$in$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $10;
   }
  }
  $15 = ($$0$ph5$i$i$i|0)==($5|0);
  if ($15) {
   label = 10;
  } else {
   $16 = (($$0$ph5$i$i$i) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>($ID|0);
   if ($18) {
    label = 10;
   } else {
    $20 = $$0$ph5$i$i$i;
   }
  }
 }
 if ((label|0) == 10) {
  $20 = $5;
 }
 $19 = ($20|0)==($5|0);
 $21 = (($20) + 32|0);
 $_ZZN6Object15ClassIDToStringEiE11emptyString$ = $19 ? 560816 : $21;
 STACKTOP = sp;return ($_ZZN6Object15ClassIDToStringEiE11emptyString$|0);
}
function __Z7ToLowerINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_($agg$result,$input) {
 $agg$result = $agg$result|0;
 $input = $input|0;
 var $$0$i = 0, $$ph = 0, $$pre = 0, $$pre$phi6Z2D = 0, $$pre$phi8Z2D = 0, $$pre$phiZ2D = 0, $$pre2$pre$phiZZ2D = 0, $$pre5 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $v$off$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$input>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$input+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$input+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$input+8>>2]|0;
  $$pre = HEAP8[$agg$result>>0]|0;
  $$pre$phiZ2D = $agg$result;$21 = $$pre;
 } else {
  $3 = (($input) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($input) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6>>>0)>(4294967279);
  if ($7) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $8 = ($6>>>0)<(11);
  if ($8) {
   $9 = $6 << 1;
   $10 = $9&255;
   HEAP8[$agg$result>>0] = $10;
   $11 = (($agg$result) + 1|0);
   $$pre2$pre$phiZZ2D = $agg$result;$45 = $10;$__p$0$i$i$i = $11;
  } else {
   $12 = (($6) + 16)|0;
   $13 = $12 & -16;
   $14 = (__Znwj($13)|0);
   $15 = (($agg$result) + 8|0);
   HEAP32[$15>>2] = $14;
   $16 = $13 | 1;
   HEAP32[$agg$result>>2] = $16;
   $17 = (($agg$result) + 4|0);
   HEAP32[$17>>2] = $6;
   $18 = $16&255;
   $$pre2$pre$phiZZ2D = $agg$result;$45 = $18;$__p$0$i$i$i = $14;
  }
  _memcpy(($__p$0$i$i$i|0),($4|0),($6|0))|0;
  $19 = (($__p$0$i$i$i) + ($6)|0);
  HEAP8[$19>>0] = 0;
  $$pre$phiZ2D = $$pre2$pre$phiZZ2D;$21 = $45;
 }
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($22) {
  $25 = (($agg$result) + 1|0);
  $$pre7 = (($agg$result) + 8|0);
  $$ph = $25;$$pre$phi6Z2D = $25;$$pre$phi8Z2D = $$pre7;
 } else {
  $23 = (($agg$result) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $$pre5 = (($agg$result) + 1|0);
  $$ph = $24;$$pre$phi6Z2D = $$pre5;$$pre$phi8Z2D = $23;
 }
 $26 = (($agg$result) + 4|0);
 $38 = $$ph;
 while(1) {
  $27 = HEAP8[$$pre$phiZ2D>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $32 = $27&255;
   $33 = $32 >>> 1;
   $35 = $$pre$phi6Z2D;$36 = $33;
  } else {
   $30 = HEAP32[$$pre$phi8Z2D>>2]|0;
   $31 = HEAP32[$26>>2]|0;
   $35 = $30;$36 = $31;
  }
  $34 = (($35) + ($36)|0);
  $37 = ($38|0)==($34|0);
  if ($37) {
   break;
  }
  $39 = HEAP8[$38>>0]|0;
  $v$off$i = (($39) + -65)<<24>>24;
  $40 = ($v$off$i&255)<(26);
  if ($40) {
   $41 = $39&255;
   $42 = $41 | 32;
   $43 = $42&255;
   $$0$i = $43;
  } else {
   $$0$i = $39;
  }
  HEAP8[$38>>0] = $$0$i;
  $44 = (($38) + 1|0);
  $38 = $44;
 }
 STACKTOP = sp;return;
}
function __ZN6Object15StringToClassIDEPKc($classString) {
 $classString = $classString|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560664>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4|0);
 $4 = ($2|0)==(0|0);
 if ($4) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
 }
 L3: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $5 = (($$013$i$in$i$i) + 16|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (_strcmp($6,$classString)|0);
   $8 = ($7|0)<(0);
   if (!($8)) {
    break;
   }
   $11 = (($$013$i$in$i$i) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L3;
   } else {
    $$013$i$in$i$i = $12;
   }
  }
  $9 = HEAP32[$$013$i$in$i$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
  }
 }
 $14 = ($$0$ph5$i$i$i|0)==($3|0);
 if ($14) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($$0$ph5$i$i$i) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (_strcmp($classString,$16)|0);
 $18 = ($17|0)<(0);
 $19 = ($$0$ph5$i$i$i|0)==($3|0);
 $or$cond = $18 | $19;
 if ($or$cond) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = (($$0$ph5$i$i$i) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $$0 = $21;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK6Object12GetClassNameEv($this) {
 $this = $this|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_ZZN6Object15ClassIDToStringEiE11emptyString$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 21;
 $3 = HEAP8[560832>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  ;HEAP32[560816+0>>2]=0|0;HEAP32[560816+4>>2]=0|0;HEAP32[560816+8>>2]=0|0;
  HEAP8[560832>>0] = 1;
 }
 $5 = HEAP32[560672>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4|0);
 $9 = ($7|0)==(0|0);
 if ($9) {
  label = 10;
 } else {
  $$0$ph7$i$i$i$i = $8;$$01$ph6$i$in$i$i$i = $7;
  L5: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $10 = (($$013$i$in$i$i$i) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)<($2|0);
    if (!($12)) {
     break;
    }
    $15 = (($$013$i$in$i$i$i) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L5;
    } else {
     $$013$i$in$i$i$i = $16;
    }
   }
   $13 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $13;
   }
  }
  $18 = ($$0$ph5$i$i$i$i|0)==($8|0);
  if ($18) {
   label = 10;
  } else {
   $19 = (($$0$ph5$i$i$i$i) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)>($2|0);
   if ($21) {
    label = 10;
   } else {
    $23 = $$0$ph5$i$i$i$i;
   }
  }
 }
 if ((label|0) == 10) {
  $23 = $8;
 }
 $22 = ($23|0)==($8|0);
 $24 = (($23) + 32|0);
 $_ZZN6Object15ClassIDToStringEiE11emptyString$$i = $22 ? 560816 : $24;
 STACKTOP = sp;return ($_ZZN6Object15ClassIDToStringEiE11emptyString$$i|0);
}
function __ZN6Object15GetSuperClassIDEi($classID) {
 $classID = $classID|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560672>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4|0);
 $4 = ($2|0)==(0|0);
 if ($4) {
  label = 8;
 } else {
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $5 = (($$013$i$in$i$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<($classID|0);
    if (!($7)) {
     break;
    }
    $10 = (($$013$i$in$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $11;
    }
   }
   $8 = HEAP32[$$013$i$in$i$i>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $8;
   }
  }
  $13 = ($$0$ph5$i$i$i|0)==($3|0);
  if ($13) {
   label = 8;
  } else {
   $14 = (($$0$ph5$i$i$i) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>($classID|0);
   if ($16) {
    label = 8;
   } else {
    $18 = $$0$ph5$i$i$i;
   }
  }
 }
 if ((label|0) == 8) {
  $18 = $3;
 }
 $17 = (($18) + 20|0);
 $19 = HEAP32[$17>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($19) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $$0 = $22;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6Object20InitializeAllClassesEv() {
 var $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i9 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i3 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i4 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i6 = 0, $$pre = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$037 = 0, $i1$031 = 0, $j$027 = 0, $j$027$us = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560840>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$0>>2]|0;
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $116 = $3;$7 = $4;$i$037 = 0;
  while(1) {
   $6 = (($7) + (($i$037*20)|0)|0);
   $8 = HEAP32[$6>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $12 = $116;$14 = $7;
   } else {
    FUNCTION_TABLE_v[$8 & 1023]();
    $$pre = HEAP32[$2>>2]|0;
    $$pre45 = HEAP32[$0>>2]|0;
    $12 = $$pre;$14 = $$pre45;
   }
   $10 = (($i$037) + 1)|0;
   $11 = $12;
   $13 = $14;
   $15 = (($11) - ($13))|0;
   $16 = (($15|0) / 20)&-1;
   $17 = ($10>>>0)<($16>>>0);
   if ($17) {
    $116 = $12;$7 = $14;$i$037 = $10;
   } else {
    break;
   }
  }
 }
 HEAP32[560640>>2] = 291;
 $18 = HEAP32[560688>>2]|0;
 __ZN14dynamic_bitset6resizeEjb($18,84681,0);
 $19 = HEAP32[560688>>2]|0;
 $20 = (($19) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[560632>>2] = $21;
 $22 = HEAP32[560680>>2]|0;
 $23 = HEAP32[560640>>2]|0;
 __ZN14dynamic_bitset6resizeEjb($22,$23,0);
 $24 = HEAP32[560640>>2]|0;
 $25 = ($24|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = HEAP32[560672>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4|0);
 $30 = ($28|0)==(0|0);
 $31 = HEAP32[560680>>2]|0;
 $32 = (($31) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[560688>>2]|0;
 $35 = (($34) + 4|0);
 $i1$031 = 0;
 while(1) {
  if ($30) {
   label = 15;
  } else {
   $$0$ph7$i$i$i3 = $29;$$01$ph6$i$in$i$i4 = $28;
   L17: while(1) {
    $$013$i$in$i$i6 = $$01$ph6$i$in$i$i4;
    while(1) {
     $36 = (($$013$i$in$i$i6) + 16|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)<($i1$031|0);
     if (!($38)) {
      break;
     }
     $41 = (($$013$i$in$i$i6) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0|0);
     if ($43) {
      $$0$ph5$i$i$i9 = $$0$ph7$i$i$i3;
      break L17;
     } else {
      $$013$i$in$i$i6 = $42;
     }
    }
    $39 = HEAP32[$$013$i$in$i$i6>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$0$ph5$i$i$i9 = $$013$i$in$i$i6;
     break;
    } else {
     $$0$ph7$i$i$i3 = $$013$i$in$i$i6;$$01$ph6$i$in$i$i4 = $39;
    }
   }
   $44 = ($$0$ph5$i$i$i9|0)==($29|0);
   if ($44) {
    label = 15;
   } else {
    $45 = (($$0$ph5$i$i$i9) + 16|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($i1$031|0)<($46|0);
    if ($47) {
     label = 15;
    } else {
     $50 = ($$0$ph5$i$i$i9|0)==($29|0);
     $51 = $i1$031 & 31;
     $52 = 1 << $51;
     if ($50) {
      $117 = $$0$ph5$i$i$i9;$58 = $52;
      label = 18;
     } else {
      $53 = $i1$031 >>> 5;
      $54 = (($33) + ($53<<2)|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = $55 | $52;
      HEAP32[$54>>2] = $56;
      $67 = $52;$71 = $$0$ph5$i$i$i9;
     }
    }
   }
  }
  if ((label|0) == 15) {
   label = 0;
   $48 = $i1$031 & 31;
   $49 = 1 << $48;
   $117 = $29;$58 = $49;
   label = 18;
  }
  if ((label|0) == 18) {
   label = 0;
   $57 = $58 ^ -1;
   $59 = $i1$031 >>> 5;
   $60 = (($33) + ($59<<2)|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $61 & $57;
   HEAP32[$60>>2] = $62;
   $67 = $58;$71 = $117;
  }
  $63 = $i1$031 >>> 5;
  $64 = (($33) + ($63<<2)|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = $65 & $67;
  $68 = ($66|0)==(0);
  $$pre46 = HEAP32[560640>>2]|0;
  L32: do {
   if ($68) {
    $115 = $$pre46;
   } else {
    $69 = ($$pre46|0)==(0);
    if ($69) {
     $115 = 0;
    } else {
     $70 = (($71) + 20|0);
     if ($30) {
      $j$027$us = 0;
      while(1) {
       $72 = (($j$027$us) + 1)|0;
       $73 = HEAP32[560640>>2]|0;
       $74 = ($72>>>0)<($73>>>0);
       if ($74) {
        $j$027$us = $72;
       } else {
        $115 = $73;
        break L32;
       }
      }
     } else {
      $89 = $$pre46;$j$027 = 0;
     }
     while(1) {
      $$0$ph7$i$i$i = $29;$$01$ph6$i$in$i$i = $28;
      L40: while(1) {
       $$013$i$in$i$i = $$01$ph6$i$in$i$i;
       while(1) {
        $75 = (($$013$i$in$i$i) + 16|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($76|0)<($j$027|0);
        if (!($77)) {
         break;
        }
        $80 = (($$013$i$in$i$i) + 4|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = ($81|0)==(0|0);
        if ($82) {
         $$0$ph5$i$i$i = $$0$ph7$i$i$i;
         break L40;
        } else {
         $$013$i$in$i$i = $81;
        }
       }
       $78 = HEAP32[$$013$i$in$i$i>>2]|0;
       $79 = ($78|0)==(0|0);
       if ($79) {
        $$0$ph5$i$i$i = $$013$i$in$i$i;
        break;
       } else {
        $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $78;
       }
      }
      $83 = ($$0$ph5$i$i$i|0)==($29|0);
      do {
       if (!($83)) {
        $84 = (($$0$ph5$i$i$i) + 16|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = ($j$027|0)<($85|0);
        $87 = ($$0$ph5$i$i$i|0)==($29|0);
        $or$cond = $86 | $87;
        if (!($or$cond)) {
         $88 = Math_imul($89, $i1$031)|0;
         $90 = (($88) + ($j$027))|0;
         $91 = (($$0$ph5$i$i$i) + 20|0);
         $i$01$i = $70;
         while(1) {
          $92 = ($i$01$i|0)==($91|0);
          if ($92) {
           label = 33;
           break;
          }
          $93 = HEAP32[$i$01$i>>2]|0;
          $94 = ($93|0)==(0|0);
          if ($94) {
           label = 34;
           break;
          } else {
           $i$01$i = $93;
          }
         }
         if ((label|0) == 33) {
          label = 0;
          $95 = $90 & 31;
          $96 = 1 << $95;
          $97 = $90 >>> 5;
          $98 = HEAP32[$35>>2]|0;
          $99 = (($98) + ($97<<2)|0);
          $100 = HEAP32[$99>>2]|0;
          $101 = $100 | $96;
          HEAP32[$99>>2] = $101;
          break;
         }
         else if ((label|0) == 34) {
          label = 0;
          $102 = $90 & 31;
          $103 = 1 << $102;
          $104 = $103 ^ -1;
          $105 = $90 >>> 5;
          $106 = HEAP32[$35>>2]|0;
          $107 = (($106) + ($105<<2)|0);
          $108 = HEAP32[$107>>2]|0;
          $109 = $108 & $104;
          HEAP32[$107>>2] = $109;
          break;
         }
        }
       }
      } while(0);
      $110 = (($j$027) + 1)|0;
      $111 = HEAP32[560640>>2]|0;
      $112 = ($110>>>0)<($111>>>0);
      if ($112) {
       $89 = $111;$j$027 = $110;
      } else {
       $115 = $111;
       break;
      }
     }
    }
   }
  } while(0);
  $113 = (($i1$031) + 1)|0;
  $114 = ($113>>>0)<($115>>>0);
  if ($114) {
   $i1$031 = $113;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14dynamic_bitset6resizeEjb($this,$num_bits,$value) {
 $this = $this|0;
 $num_bits = $num_bits|0;
 $value = $value|0;
 var $$012$i$i$i$i = 0, $$03$i$i$i$i = 0, $$byval_copy3 = 0, $$idx = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0;
 var $i$05$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($num_bits|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = ($num_bits|0)==(0);
 if ($7) {
  HEAP32[$4>>2] = 0;
  $8 = (($this) + 12|0);
  HEAP32[$8>>2] = 0;
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$this>>2]|0;
  HEAP32[$0>>2] = $11;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($10,$$byval_copy3);
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return;
 }
 $12 = (($num_bits) + 31)|0;
 $13 = $12 >>> 5;
 $14 = $13 << 2;
 $15 = HEAP32[$this>>2]|0;
 HEAP32[$1>>2] = $15;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy3,0,560648,399)|0);
 $17 = HEAP32[$4>>2]|0;
 $18 = ($17>>>0)>($num_bits>>>0);
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 if ($18) {
  _memmove(($16|0),($20|0),($14|0))|0;
  $21 = HEAP32[$19>>2]|0;
  HEAP32[$19>>2] = $16;
  $22 = HEAP32[$this>>2]|0;
  HEAP32[$2>>2] = $22;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($21,$$byval_copy3);
  $$pre8 = (($this) + 12|0);
  $$pre$phiZ2D = $$pre8;
 } else {
  $23 = (($this) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $$idx = $24 << 2;
  _memmove(($16|0),($20|0),($$idx|0))|0;
  $25 = $value << 31 >> 31;
  $26 = HEAP32[$23>>2]|0;
  $27 = Math_imul($26, -4)|0;
  $28 = (($27) + ($14))|0;
  $29 = ($28|0)>(0);
  if ($29) {
   $30 = (($16) + ($26<<2)|0);
   $31 = $28 >> 2;
   $$012$i$i$i$i = $31;$$03$i$i$i$i = $30;
   while(1) {
    HEAP32[$$03$i$i$i$i>>2] = $25;
    $32 = (($$03$i$i$i$i) + 4|0);
    $33 = (($$012$i$i$i$i) + -1)|0;
    $34 = ($33|0)>(0);
    if ($34) {
     $$012$i$i$i$i = $33;$$03$i$i$i$i = $32;
    } else {
     break;
    }
   }
   $$pre = HEAP32[$23>>2]|0;
   $38 = $$pre;
  } else {
   $38 = $26;
  }
  $35 = HEAP32[$19>>2]|0;
  HEAP32[$19>>2] = $16;
  $36 = HEAP32[$4>>2]|0;
  $37 = $38 << 5;
  $39 = ($36>>>0)<($37>>>0);
  if ($39) {
   if ($value) {
    $i$05$us = $36;
    while(1) {
     $40 = $i$05$us & 31;
     $41 = 1 << $40;
     $42 = $i$05$us >>> 5;
     $43 = (($16) + ($42<<2)|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = $44 | $41;
     HEAP32[$43>>2] = $45;
     $$pre6 = HEAP32[$23>>2]|0;
     $46 = (($i$05$us) + 1)|0;
     $47 = $$pre6 << 5;
     $48 = ($46>>>0)<($47>>>0);
     if ($48) {
      $i$05$us = $46;
     } else {
      break;
     }
    }
   } else {
    $i$05 = $36;
    while(1) {
     $49 = $i$05 & 31;
     $50 = 1 << $49;
     $51 = $50 ^ -1;
     $52 = $i$05 >>> 5;
     $53 = (($16) + ($52<<2)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = $54 & $51;
     HEAP32[$53>>2] = $55;
     $$pre7 = HEAP32[$23>>2]|0;
     $56 = (($i$05) + 1)|0;
     $57 = $$pre7 << 5;
     $58 = ($56>>>0)<($57>>>0);
     if ($58) {
      $i$05 = $56;
     } else {
      break;
     }
    }
   }
  }
  $59 = ($35|0)==(0|0);
  if ($59) {
   $$pre$phiZ2D = $23;
  } else {
   $60 = HEAP32[$this>>2]|0;
   HEAP32[$3>>2] = $60;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($35,$$byval_copy3);
   $$pre$phiZ2D = $23;
  }
 }
 HEAP32[$4>>2] = $num_bits;
 HEAP32[$$pre$phiZ2D>>2] = $13;
 $61 = $num_bits & 31;
 $62 = ($61|0)==(0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = -1 << $61;
 $64 = $63 ^ -1;
 $65 = (($13) + -1)|0;
 $66 = HEAP32[$19>>2]|0;
 $67 = (($66) + ($65<<2)|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68 & $64;
 HEAP32[$67>>2] = $69;
 STACKTOP = sp;return;
}
function __ZN6Object19CallInitializeClassEv() {
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560840>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $17 = $2;$6 = $3;$i$01 = 0;
 }
 while(1) {
  $5 = ((($6) + (($i$01*20)|0)|0) + 8|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $11 = $17;$13 = $6;
  } else {
   FUNCTION_TABLE_v[$7 & 1023]();
   $$pre = HEAP32[$1>>2]|0;
   $$pre2 = HEAP32[$0>>2]|0;
   $11 = $$pre;$13 = $$pre2;
  }
  $9 = (($i$01) + 1)|0;
  $10 = $11;
  $12 = $13;
  $14 = (($10) - ($12))|0;
  $15 = (($14|0) / 20)&-1;
  $16 = ($9>>>0)<($15>>>0);
  if ($16) {
   $17 = $11;$6 = $13;$i$01 = $9;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6Object23CallPostInitializeClassEv() {
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560840>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $17 = $2;$6 = $3;$i$01 = 0;
 }
 while(1) {
  $5 = ((($6) + (($i$01*20)|0)|0) + 12|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $11 = $17;$13 = $6;
  } else {
   FUNCTION_TABLE_v[$7 & 1023]();
   $$pre = HEAP32[$1>>2]|0;
   $$pre2 = HEAP32[$0>>2]|0;
   $11 = $$pre;$13 = $$pre2;
  }
  $9 = (($i$01) + 1)|0;
  $10 = $11;
  $12 = $13;
  $14 = (($10) - ($12))|0;
  $15 = (($14|0) / 20)&-1;
  $16 = ($9>>>0)<($15>>>0);
  if ($16) {
   $17 = $11;$6 = $13;$i$01 = $9;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6Object8AddEventEPFvPvS0_iES0_($this,$callback,$userData) {
 $this = $this|0;
 $callback = $callback|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetEventManagerv()|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN12EventManager8AddEventEPFvPvS0_iES0_P10EventEntry($0,$callback,$userData,$2)|0);
 HEAP32[$1>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN6Object11RemoveEventEPFvPvS0_iES0_($this,$callback,$userData) {
 $this = $this|0;
 $callback = $callback|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetEventManagerv()|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN12EventManager11RemoveEventEP10EventEntryPFvPvS2_iES2_($0,$2,$callback,$userData)|0);
 HEAP32[$1>>2] = $3;
 STACKTOP = sp;return;
}
function __ZNK6Object8HasEventEPFvPvS0_iEPKv($this,$callback,$userData) {
 $this = $this|0;
 $callback = $callback|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN12EventManager8HasEventEP10EventEntryPFvPvS2_iEPKv($1,$callback,$userData)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6Object11InvokeEventEi($this,$eventType) {
 $this = $this|0;
 $eventType = $eventType|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN12EventManager11InvokeEventEP10EventEntryPvi($1,$this,$eventType);
 STACKTOP = sp;return;
}
function __Z17IsObjectAvailablei($instanceID) {
 $instanceID = $instanceID|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 HEAP32[$0>>2] = $instanceID;
 $1 = HEAP32[560624>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 36|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  do {
   if ($7) {
    $8 = (($1) + 28|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($1) + 32|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($9) + ($11<<3)|0);
    $28 = $12;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$1,$0);
    $13 = HEAP32[$pos$i$i$i>>2]|0;
    $14 = ($13|0)==(-1);
    $15 = (($1) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    if ($14) {
     $17 = (($1) + 32|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($16) + ($18<<3)|0);
     $28 = $19;
     break;
    } else {
     $20 = (($16) + ($13<<3)|0);
     $28 = $20;
     break;
    }
   }
  } while(0);
  $21 = HEAP32[560624>>2]|0;
  $22 = (($21) + 28|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21) + 32|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + ($25<<3)|0);
  $27 = ($28|0)==($26|0);
  if (!($27)) {
   $29 = (($28) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $32 = (__Z20GetPersistentManagerv()|0);
 $33 = (__ZN17PersistentManager17IsObjectAvailableEi($32,$instanceID)|0);
 $$0 = $33;
 STACKTOP = sp;return ($$0|0);
}
function __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_($classID,$registerClass,$initClass,$postInitClass,$cleanupClass) {
 $classID = $classID|0;
 $registerClass = $registerClass|0;
 $initClass = $initClass|0;
 $postInitClass = $postInitClass|0;
 $cleanupClass = $cleanupClass|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $buffer = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 528|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 $1 = HEAP32[560840>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[628384>>2]|0;
  HEAP32[$0>>2] = $3;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $4 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,560648,1303)|0);
  HEAP32[$4>>2] = 0;
  $5 = (($4) + 4|0);
  HEAP32[$5>>2] = 0;
  $6 = (($4) + 8|0);
  HEAP32[$6>>2] = 0;
  HEAP32[560840>>2] = $4;
  $8 = $4;
 } else {
  $8 = $1;
 }
 $7 = (($8) + 4|0);
 $9 = HEAP32[$7>>2]|0;
 $10 = HEAP32[$8>>2]|0;
 $11 = $9;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = (($13|0) / 20)&-1;
 $15 = ($14|0)>($classID|0);
 do {
  if (!($15)) {
   $16 = (($classID) + 1)|0;
   $17 = ($14>>>0)<($16>>>0);
   if ($17) {
    $18 = (($16) - ($14))|0;
    __ZNSt3__16vectorI27RegisterClassCallbackStruct13stl_allocatorIS1_L18MemLabelIdentifier1ELi16EEE8__appendEj($8,$18);
    break;
   }
   $19 = ($14>>>0)>($16>>>0);
   if ($19) {
    $20 = (($10) + (($16*20)|0)|0);
    $21 = ($9|0)==($20|0);
    if (!($21)) {
     $__new_last2$i$i$i = $20;
     $scevgep$i$i$i = (($9) + -20|0);
     $22 = (0 - ($__new_last2$i$i$i))|0;
     $uglygep$i$i$i = (($scevgep$i$i$i) + ($22)|0);
     $uglygep3$i$i$i = $uglygep$i$i$i;
     $23 = (($uglygep3$i$i$i>>>0) / 20)&-1;
     $24 = $23 ^ -1;
     $scevgep4$i$i$i = (($9) + (($24*20)|0)|0);
     HEAP32[$7>>2] = $scevgep4$i$i$i;
    }
   }
  }
 } while(0);
 $25 = HEAP32[560840>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + (($classID*20)|0)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $30 = ((($26) + (($classID*20)|0)|0) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0|0);
  if ($32) {
   $33 = ((($26) + (($classID*20)|0)|0) + 12|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    $36 = ((($26) + (($classID*20)|0)|0) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     $40 = $26;
     $39 = (($40) + (($classID*20)|0)|0);
     HEAP32[$39>>2] = $registerClass;
     $41 = HEAP32[$25>>2]|0;
     $42 = ((($41) + (($classID*20)|0)|0) + 8|0);
     HEAP32[$42>>2] = $initClass;
     $43 = HEAP32[$25>>2]|0;
     $44 = ((($43) + (($classID*20)|0)|0) + 12|0);
     HEAP32[$44>>2] = $postInitClass;
     $45 = HEAP32[$25>>2]|0;
     $46 = ((($45) + (($classID*20)|0)|0) + 16|0);
     HEAP32[$46>>2] = $cleanupClass;
     STACKTOP = sp;return;
    }
   }
  }
 }
 HEAP32[$$byval_copy>>2] = $classID;
 (_snprintf($buffer,512,560848,$$byval_copy)|0);
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE($buffer,0,560648,1313,32785,0,0,0);
 $$pre = HEAP32[$25>>2]|0;
 $40 = $$pre;
 $39 = (($40) + (($classID*20)|0)|0);
 HEAP32[$39>>2] = $registerClass;
 $41 = HEAP32[$25>>2]|0;
 $42 = ((($41) + (($classID*20)|0)|0) + 8|0);
 HEAP32[$42>>2] = $initClass;
 $43 = HEAP32[$25>>2]|0;
 $44 = ((($43) + (($classID*20)|0)|0) + 12|0);
 HEAP32[$44>>2] = $postInitClass;
 $45 = HEAP32[$25>>2]|0;
 $46 = ((($45) + (($classID*20)|0)|0) + 16|0);
 HEAP32[$46>>2] = $cleanupClass;
 STACKTOP = sp;return;
}
function __Z30SetDisableImmediateDestructionb($disable) {
 $disable = $disable|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $disable&1;
 HEAP8[560912>>0] = $0;
 STACKTOP = sp;return;
}
function __Z30GetDisableImmediateDestructionv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[560912>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 STACKTOP = sp;return ($1|0);
}
function __Z28delete_object_internal_step2P6Object($p) {
 $p = $p|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($p) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 4095;
 $4 = HEAP32[$p>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($p);
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($p,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN6Object19DoneLoadingManagersEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[560800>>2]|0;
 $1 = ($0|0)>(-10000);
 if ($1) {
  HEAP32[560800>>2] = -10000;
 }
 STACKTOP = sp;return;
}
function __ZNK6Object14GetMemoryLabelEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4095;
 STACKTOP = sp;return ($2|0);
}
function __ZNK6Object20GetRuntimeMemorySizeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6Object17MainThreadCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object21AwakeFromLoadThreadedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object16CheckConsistencyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object5ResetEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object10SmartResetEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK6Object7GetNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (560648|0);
}
function __ZN6Object7SetNameEPKc($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object39ShouldIgnoreInGarbageDependencyTrackingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6Object12SetHideFlagsEi($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $flags << 14;
 $3 = $2 & 1032192;
 $4 = $1 & -1032193;
 $5 = $4 | $3;
 HEAP32[$0>>2] = $5;
 STACKTOP = sp;return;
}
function __ZNK6Object25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK6Object25GetNeedsPerObjectTypeTreeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6Object23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object23VirtualRedirectTransferER17RemapPPtrTransfer($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object23VirtualRedirectTransferER13ProxyTransfer($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object23VirtualRedirectTransferER14SafeBinaryRead($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object23VirtualRedirectTransferER19StreamedBinaryWriteILb1EE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Object8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI27RegisterClassCallbackStruct13stl_allocatorIS1_L18MemLabelIdentifier1ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 20)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 20|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = (($18|0) / 20)&-1;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = (($22|0) / 20)&-1;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $23 << 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = ($$0$i56*20)|0;
  HEAP32[$0>>2] = 1;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,560648,79)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + (($19*20)|0)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $36 = 0;
  } else {
   ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;
   $36 = $34;
  }
  $35 = (($36) + 20|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $35;
  }
 }
 $39 = (($32) + (($$0$i57*20)|0)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = (($44|0) / -20)&-1;
 $$sum = (($45) + ($19))|0;
 $46 = (($32) + (($$sum*20)|0)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $35;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__sortIR17CompareInstanceIDPP6ObjectEEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$011 = 0, $__i$02$i = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__k$0$i = 0, $__k$0$lcssa$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 2;
   switch ($4|0) {
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 83;
    break L1;
    break;
   }
   default: {
   }
   }
   $62 = ($3|0)<(124);
   if ($62) {
    label = 21;
    break L1;
   }
   $96 = ($3|0)>(3996);
   $97 = (($4|0) / 2)&-1;
   $98 = (($$0) + ($97<<2)|0);
   do {
    if ($96) {
     $99 = (($4|0) / 4)&-1;
     $100 = (($$0) + ($99<<2)|0);
     $$sum = (($99) + ($97))|0;
     $101 = (($$0) + ($$sum<<2)|0);
     $102 = (__ZNSt3__17__sort4IR17CompareInstanceIDPP6ObjectEEjT0_S6_S6_S6_T_($$0,$100,$98,$101,0)|0);
     $103 = HEAP32[$1>>2]|0;
     $104 = HEAP32[$101>>2]|0;
     $105 = (($103) + 4|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = (($104) + 4|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = ($106|0)<($108|0);
     if ($109) {
      HEAP32[$101>>2] = $103;
      HEAP32[$1>>2] = $104;
      $110 = HEAP32[$101>>2]|0;
      $111 = HEAP32[$98>>2]|0;
      $112 = (($110) + 4|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = (($111) + 4|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ($113|0)<($115|0);
      if (!($116)) {
       $117 = (($102) + 1)|0;
       $__n_swaps$0 = $117;
       break;
      }
      HEAP32[$98>>2] = $110;
      HEAP32[$101>>2] = $111;
      $118 = HEAP32[$98>>2]|0;
      $119 = HEAP32[$100>>2]|0;
      $120 = (($118) + 4|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = (($119) + 4|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = ($121|0)<($123|0);
      if (!($124)) {
       $125 = (($102) + 2)|0;
       $__n_swaps$0 = $125;
       break;
      }
      HEAP32[$100>>2] = $118;
      HEAP32[$98>>2] = $119;
      $126 = (($102) + 3)|0;
      $127 = HEAP32[$100>>2]|0;
      $128 = HEAP32[$$0>>2]|0;
      $129 = (($127) + 4|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = (($128) + 4|0);
      $132 = HEAP32[$131>>2]|0;
      $133 = ($130|0)<($132|0);
      if ($133) {
       HEAP32[$$0>>2] = $127;
       HEAP32[$100>>2] = $128;
       $134 = (($102) + 4)|0;
       $__n_swaps$0 = $134;
      } else {
       $__n_swaps$0 = $126;
      }
     } else {
      $__n_swaps$0 = $102;
     }
    } else {
     $135 = HEAP32[$98>>2]|0;
     $136 = HEAP32[$$0>>2]|0;
     $137 = (($135) + 4|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = (($136) + 4|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = ($138|0)<($140|0);
     $142 = HEAP32[$1>>2]|0;
     $143 = (($142) + 4|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = ($144|0)<($138|0);
     if (!($141)) {
      if (!($145)) {
       $__n_swaps$0 = 0;
       break;
      }
      HEAP32[$98>>2] = $142;
      HEAP32[$1>>2] = $135;
      $146 = HEAP32[$98>>2]|0;
      $147 = HEAP32[$$0>>2]|0;
      $148 = (($146) + 4|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = (($147) + 4|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = ($149|0)<($151|0);
      if (!($152)) {
       $__n_swaps$0 = 1;
       break;
      }
      HEAP32[$$0>>2] = $146;
      HEAP32[$98>>2] = $147;
      $__n_swaps$0 = 2;
      break;
     }
     if ($145) {
      HEAP32[$$0>>2] = $142;
      HEAP32[$1>>2] = $136;
      $__n_swaps$0 = 1;
      break;
     }
     HEAP32[$$0>>2] = $135;
     HEAP32[$98>>2] = $136;
     $153 = HEAP32[$1>>2]|0;
     $154 = (($153) + 4|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = ($155|0)<($140|0);
     if ($156) {
      HEAP32[$98>>2] = $153;
      HEAP32[$1>>2] = $136;
      $__n_swaps$0 = 2;
     } else {
      $__n_swaps$0 = 1;
     }
    }
   } while(0);
   $157 = HEAP32[$$0>>2]|0;
   $158 = HEAP32[$98>>2]|0;
   $159 = (($157) + 4|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = (($158) + 4|0);
   $162 = HEAP32[$161>>2]|0;
   $163 = ($160|0)<($162|0);
   do {
    if ($163) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $164 = (($__j$0) + -4|0);
      $165 = ($$0|0)==($164|0);
      if ($165) {
       break;
      }
      $193 = HEAP32[$164>>2]|0;
      $194 = (($193) + 4|0);
      $195 = HEAP32[$194>>2]|0;
      $196 = ($195|0)<($162|0);
      if ($196) {
       label = 66;
       break;
      } else {
       $__j$0 = $164;
      }
     }
     if ((label|0) == 66) {
      label = 0;
      HEAP32[$$0>>2] = $193;
      HEAP32[$164>>2] = $157;
      $197 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $164;$__n_swaps$3 = $197;
      break;
     }
     $166 = (($$0) + 4|0);
     $167 = HEAP32[$1>>2]|0;
     $168 = (($167) + 4|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = ($160|0)<($169|0);
     if ($170) {
      $__i$1 = $166;
     } else {
      $171 = ($166|0)==($1|0);
      if ($171) {
       label = 83;
       break L1;
      } else {
       $__i$011 = $166;
      }
      while(1) {
       $174 = HEAP32[$__i$011>>2]|0;
       $175 = (($174) + 4|0);
       $176 = HEAP32[$175>>2]|0;
       $177 = ($160|0)<($176|0);
       $173 = (($__i$011) + 4|0);
       if ($177) {
        break;
       }
       $172 = ($173|0)==($1|0);
       if ($172) {
        label = 83;
        break L1;
       } else {
        $__i$011 = $173;
       }
      }
      HEAP32[$__i$011>>2] = $167;
      HEAP32[$1>>2] = $174;
      $__i$1 = $173;
     }
     $178 = ($__i$1|0)==($1|0);
     if ($178) {
      label = 83;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $179 = HEAP32[$$0>>2]|0;
      $180 = (($179) + 4|0);
      $181 = HEAP32[$180>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $182 = HEAP32[$__i$2>>2]|0;
       $183 = (($182) + 4|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = ($181|0)<($184|0);
       $186 = (($__i$2) + 4|0);
       if ($185) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $186;
       }
      }
      while(1) {
       $187 = (($__j$2) + -4|0);
       $188 = HEAP32[$187>>2]|0;
       $189 = (($188) + 4|0);
       $190 = HEAP32[$189>>2]|0;
       $191 = ($181|0)<($190|0);
       if ($191) {
        $__j$2 = $187;
       } else {
        break;
       }
      }
      $192 = ($__i$2>>>0)<($187>>>0);
      if (!($192)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__i$2>>2] = $188;
      HEAP32[$187>>2] = $182;
      $__i$2$ph = $186;$__j$1$ph = $187;
     }
    }
   } while(0);
   $198 = (($$0) + 4|0);
   $199 = ($198>>>0)<($__j$3>>>0);
   L51: do {
    if ($199) {
     $__i$3$ph = $198;$__j$4$ph = $__j$3;$__m$0$ph = $98;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $200 = HEAP32[$__m$0$ph>>2]|0;
      $201 = (($200) + 4|0);
      $202 = HEAP32[$201>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $203 = HEAP32[$__i$3>>2]|0;
       $204 = (($203) + 4|0);
       $205 = HEAP32[$204>>2]|0;
       $206 = ($205|0)<($202|0);
       $207 = (($__i$3) + 4|0);
       if ($206) {
        $__i$3 = $207;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $208 = (($__j$5) + -4|0);
       $209 = HEAP32[$208>>2]|0;
       $210 = (($209) + 4|0);
       $211 = HEAP32[$210>>2]|0;
       $212 = ($211|0)<($202|0);
       if ($212) {
        break;
       } else {
        $__j$5 = $208;
       }
      }
      $213 = ($__i$3>>>0)>($208>>>0);
      if ($213) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L51;
      }
      HEAP32[$__i$3>>2] = $209;
      HEAP32[$208>>2] = $203;
      $214 = (($__n_swaps$4$ph) + 1)|0;
      $215 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $215 ? $208 : $__m$0$ph;
      $__i$3$ph = $207;$__j$4$ph = $208;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $214;
     }
    } else {
     $__i$4 = $198;$__m$2 = $98;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $216 = ($__i$4|0)==($__m$2|0);
   if ($216) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $217 = HEAP32[$__m$2>>2]|0;
    $218 = HEAP32[$__i$4>>2]|0;
    $219 = (($217) + 4|0);
    $220 = HEAP32[$219>>2]|0;
    $221 = (($218) + 4|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = ($220|0)<($222|0);
    if ($223) {
     HEAP32[$__i$4>>2] = $217;
     HEAP32[$__m$2>>2] = $218;
     $224 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $224;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $225 = ($__n_swaps$6|0)==(0);
   if ($225) {
    $226 = (__ZNSt3__127__insertion_sort_incompleteIR17CompareInstanceIDPP6ObjectEEbT0_S6_T_($$0,$__i$4,0)|0);
    $227 = (($__i$4) + 4|0);
    $228 = (__ZNSt3__127__insertion_sort_incompleteIR17CompareInstanceIDPP6ObjectEEbT0_S6_T_($227,$$01$ph,0)|0);
    if ($228) {
     label = 78;
     break;
    }
    if ($226) {
     $$0 = $227;
     continue;
    }
   }
   $229 = $__i$4;
   $230 = (($229) - ($2))|0;
   $231 = (($0) - ($229))|0;
   $232 = ($230|0)<($231|0);
   if (!($232)) {
    label = 82;
    break;
   }
   __ZNSt3__16__sortIR17CompareInstanceIDPP6ObjectEEvT0_S6_T_($$0,$__i$4,$__comp);
   $233 = (($__i$4) + 4|0);
   $$0 = $233;
  }
  if ((label|0) == 78) {
   label = 0;
   if ($226) {
    label = 83;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 82) {
   label = 0;
   $234 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIR17CompareInstanceIDPP6ObjectEEvT0_S6_T_($234,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = (($5) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)<($10|0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $5;
  HEAP32[$1>>2] = $6;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $12 = (($$0) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$$0>>2]|0;
  $15 = (($13) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($16|0)<($18|0);
  $20 = HEAP32[$1>>2]|0;
  $21 = (($20) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)<($16|0);
  if (!($19)) {
   if (!($23)) {
    STACKTOP = sp;return;
   }
   HEAP32[$12>>2] = $20;
   HEAP32[$1>>2] = $13;
   $24 = HEAP32[$12>>2]|0;
   $25 = HEAP32[$$0>>2]|0;
   $26 = (($24) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)<($29|0);
   if (!($30)) {
    STACKTOP = sp;return;
   }
   HEAP32[$$0>>2] = $24;
   HEAP32[$12>>2] = $25;
   STACKTOP = sp;return;
  }
  if ($23) {
   HEAP32[$$0>>2] = $20;
   HEAP32[$1>>2] = $14;
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $13;
  HEAP32[$12>>2] = $14;
  $31 = HEAP32[$1>>2]|0;
  $32 = (($31) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)<($18|0);
  if (!($34)) {
   STACKTOP = sp;return;
  }
  HEAP32[$12>>2] = $31;
  HEAP32[$1>>2] = $14;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $35 = (($$0) + 4|0);
  $36 = (($$0) + 8|0);
  (__ZNSt3__17__sort4IR17CompareInstanceIDPP6ObjectEEjT0_S6_S6_S6_T_($$0,$35,$36,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $37 = (($$0) + 4|0);
  $38 = (($$0) + 8|0);
  $39 = (($$0) + 12|0);
  (__ZNSt3__17__sort4IR17CompareInstanceIDPP6ObjectEEjT0_S6_S6_S6_T_($$0,$37,$38,$39,0)|0);
  $40 = HEAP32[$1>>2]|0;
  $41 = HEAP32[$39>>2]|0;
  $42 = (($40) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($43|0)<($45|0);
  if (!($46)) {
   STACKTOP = sp;return;
  }
  HEAP32[$39>>2] = $40;
  HEAP32[$1>>2] = $41;
  $47 = HEAP32[$39>>2]|0;
  $48 = HEAP32[$38>>2]|0;
  $49 = (($47) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($48) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($50|0)<($52|0);
  if (!($53)) {
   STACKTOP = sp;return;
  }
  HEAP32[$38>>2] = $47;
  HEAP32[$39>>2] = $48;
  $54 = HEAP32[$37>>2]|0;
  $55 = (($54) + 4|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($50|0)<($56|0);
  if (!($57)) {
   STACKTOP = sp;return;
  }
  HEAP32[$37>>2] = $47;
  HEAP32[$38>>2] = $54;
  $58 = HEAP32[$$0>>2]|0;
  $59 = (($58) + 4|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($50|0)<($60|0);
  if (!($61)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $47;
  HEAP32[$37>>2] = $58;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $63 = (($$0) + 8|0);
  $64 = (($$0) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = HEAP32[$$0>>2]|0;
  $67 = (($65) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($66) + 4|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($68|0)<($70|0);
  $72 = HEAP32[$63>>2]|0;
  $73 = (($72) + 4|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74|0)<($68|0);
  do {
   if ($71) {
    if ($75) {
     HEAP32[$$0>>2] = $72;
     HEAP32[$63>>2] = $66;
     $235 = $66;
     break;
    }
    HEAP32[$$0>>2] = $65;
    HEAP32[$64>>2] = $66;
    $77 = ($74|0)<($70|0);
    if ($77) {
     HEAP32[$64>>2] = $72;
     HEAP32[$63>>2] = $66;
     $235 = $66;
    } else {
     $235 = $72;
    }
   } else {
    if ($75) {
     HEAP32[$64>>2] = $72;
     HEAP32[$63>>2] = $65;
     $76 = ($74|0)<($70|0);
     if ($76) {
      HEAP32[$$0>>2] = $72;
      HEAP32[$64>>2] = $66;
      $235 = $65;
     } else {
      $235 = $65;
     }
    } else {
     $235 = $72;
    }
   }
  } while(0);
  $78 = (($$0) + 12|0);
  $79 = ($78|0)==($$01$ph|0);
  if ($79) {
   STACKTOP = sp;return;
  } else {
   $84 = $235;$__i$02$i = $78;$__j$01$i = $63;
  }
  while(1) {
   $80 = HEAP32[$__i$02$i>>2]|0;
   $81 = (($80) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($84) + 4|0);
   $85 = HEAP32[$83>>2]|0;
   $86 = ($82|0)<($85|0);
   if ($86) {
    $87 = $84;$__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     HEAP32[$__j$1$i>>2] = $87;
     $88 = ($__k$0$i|0)==($$0|0);
     if ($88) {
      $__k$0$lcssa$i = $$0;
      break;
     }
     $89 = (($__k$0$i) + -4|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = (($90) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($82|0)<($92|0);
     if ($93) {
      $__j$1$i$phi = $__k$0$i;$87 = $90;$__k$0$i = $89;$__j$1$i = $__j$1$i$phi;
     } else {
      $__k$0$lcssa$i = $__k$0$i;
      break;
     }
    }
    HEAP32[$__k$0$lcssa$i>>2] = $80;
   }
   $94 = (($__i$02$i) + 4|0);
   $95 = ($94|0)==($$01$ph|0);
   if ($95) {
    break;
   }
   $$pre$i = HEAP32[$__i$02$i>>2]|0;
   $__j$01$i$phi = $__i$02$i;$84 = $$pre$i;$__i$02$i = $94;$__j$01$i = $__j$01$i$phi;
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 83) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IR17CompareInstanceIDPP6ObjectEEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)<($5|0);
 $7 = HEAP32[$__x3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)<($3|0);
 do {
  if ($6) {
   if ($10) {
    HEAP32[$__x1>>2] = $7;
    HEAP32[$__x3>>2] = $1;
    $$0$i = 1;$26 = $1;
    break;
   }
   HEAP32[$__x1>>2] = $0;
   HEAP32[$__x2>>2] = $1;
   $18 = HEAP32[$__x3>>2]|0;
   $19 = (($18) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)<($5|0);
   if ($21) {
    HEAP32[$__x2>>2] = $18;
    HEAP32[$__x3>>2] = $1;
    $$0$i = 2;$26 = $1;
   } else {
    $$0$i = 1;$26 = $18;
   }
  } else {
   if ($10) {
    HEAP32[$__x2>>2] = $7;
    HEAP32[$__x3>>2] = $0;
    $11 = HEAP32[$__x2>>2]|0;
    $12 = HEAP32[$__x1>>2]|0;
    $13 = (($11) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($14|0)<($16|0);
    if ($17) {
     HEAP32[$__x1>>2] = $11;
     HEAP32[$__x2>>2] = $12;
     $$pre = HEAP32[$__x3>>2]|0;
     $$0$i = 2;$26 = $$pre;
    } else {
     $$0$i = 1;$26 = $0;
    }
   } else {
    $$0$i = 0;$26 = $7;
   }
  }
 } while(0);
 $22 = HEAP32[$__x4>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($26) + 4|0);
 $27 = HEAP32[$25>>2]|0;
 $28 = ($24|0)<($27|0);
 if (!($28)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $22;
 HEAP32[$__x4>>2] = $26;
 $29 = (($$0$i) + 1)|0;
 $30 = HEAP32[$__x3>>2]|0;
 $31 = HEAP32[$__x2>>2]|0;
 $32 = (($30) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)<($35|0);
 if (!($36)) {
  $__r$0 = $29;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $30;
 HEAP32[$__x3>>2] = $31;
 $37 = (($$0$i) + 2)|0;
 $38 = HEAP32[$__x2>>2]|0;
 $39 = HEAP32[$__x1>>2]|0;
 $40 = (($38) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($41|0)<($43|0);
 if (!($44)) {
  $__r$0 = $37;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $38;
 HEAP32[$__x2>>2] = $39;
 $45 = (($$0$i) + 3)|0;
 $__r$0 = $45;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIR17CompareInstanceIDPP6ObjectEEbT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$05 = 0, $__count$1 = 0, $__i$06 = 0, $__j$04 = 0, $__j$04$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 2:  {
  $4 = (($__last) + -4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = (($5) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)<($10|0);
  if (!($11)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $39 = (($__first) + 4|0);
  $40 = (($__first) + 8|0);
  $41 = (($__first) + 12|0);
  $42 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IR17CompareInstanceIDPP6ObjectEEjT0_S6_S6_S6_T_($__first,$39,$40,$41,0)|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = HEAP32[$41>>2]|0;
  $45 = (($43) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($44) + 4|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($46|0)<($48|0);
  if (!($49)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$41>>2] = $43;
  HEAP32[$42>>2] = $44;
  $50 = HEAP32[$41>>2]|0;
  $51 = HEAP32[$40>>2]|0;
  $52 = (($50) + 4|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($53|0)<($55|0);
  if (!($56)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$40>>2] = $50;
  HEAP32[$41>>2] = $51;
  $57 = HEAP32[$39>>2]|0;
  $58 = (($57) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($53|0)<($59|0);
  if (!($60)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$39>>2] = $50;
  HEAP32[$40>>2] = $57;
  $61 = HEAP32[$__first>>2]|0;
  $62 = (($61) + 4|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($53|0)<($63|0);
  if (!($64)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $50;
  HEAP32[$39>>2] = $61;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $36 = (($__first) + 4|0);
  $37 = (($__first) + 8|0);
  $38 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IR17CompareInstanceIDPP6ObjectEEjT0_S6_S6_S6_T_($__first,$36,$37,$38,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $12 = (($__first) + 4|0);
  $13 = (($__last) + -4|0);
  $14 = HEAP32[$12>>2]|0;
  $15 = HEAP32[$__first>>2]|0;
  $16 = (($14) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($17|0)<($19|0);
  $21 = HEAP32[$13>>2]|0;
  $22 = (($21) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)<($17|0);
  if (!($20)) {
   if (!($24)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$12>>2] = $21;
   HEAP32[$13>>2] = $14;
   $25 = HEAP32[$12>>2]|0;
   $26 = HEAP32[$__first>>2]|0;
   $27 = (($25) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($28|0)<($30|0);
   if (!($31)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__first>>2] = $25;
   HEAP32[$12>>2] = $26;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($24) {
   HEAP32[$__first>>2] = $21;
   HEAP32[$13>>2] = $15;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $14;
  HEAP32[$12>>2] = $15;
  $32 = HEAP32[$13>>2]|0;
  $33 = (($32) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)<($19|0);
  if (!($35)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$12>>2] = $32;
  HEAP32[$13>>2] = $15;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $65 = (($__first) + 8|0);
  $66 = (($__first) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$__first>>2]|0;
  $69 = (($67) + 4|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($68) + 4|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($70|0)<($72|0);
  $74 = HEAP32[$65>>2]|0;
  $75 = (($74) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)<($70|0);
  do {
   if ($73) {
    if ($77) {
     HEAP32[$__first>>2] = $74;
     HEAP32[$65>>2] = $68;
     $102 = $68;
     break;
    }
    HEAP32[$__first>>2] = $67;
    HEAP32[$66>>2] = $68;
    $79 = ($76|0)<($72|0);
    if ($79) {
     HEAP32[$66>>2] = $74;
     HEAP32[$65>>2] = $68;
     $102 = $68;
    } else {
     $102 = $74;
    }
   } else {
    if ($77) {
     HEAP32[$66>>2] = $74;
     HEAP32[$65>>2] = $67;
     $78 = ($76|0)<($72|0);
     if ($78) {
      HEAP32[$__first>>2] = $74;
      HEAP32[$66>>2] = $68;
      $102 = $67;
     } else {
      $102 = $67;
     }
    } else {
     $102 = $74;
    }
   }
  } while(0);
  $80 = (($__first) + 12|0);
  $81 = ($80|0)==($__last|0);
  if ($81) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $86 = $102;$__count$05 = 0;$__i$06 = $80;$__j$04 = $65;
  }
  while(1) {
   $82 = HEAP32[$__i$06>>2]|0;
   $83 = (($82) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($86) + 4|0);
   $87 = HEAP32[$85>>2]|0;
   $88 = ($84|0)<($87|0);
   if ($88) {
    $89 = $86;$__j$1 = $__i$06;$__k$0 = $__j$04;
    while(1) {
     HEAP32[$__j$1>>2] = $89;
     $90 = ($__k$0|0)==($__first|0);
     if ($90) {
      $__k$0$lcssa = $__first;
      break;
     }
     $91 = (($__k$0) + -4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = (($92) + 4|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ($84|0)<($94|0);
     if ($95) {
      $__j$1$phi = $__k$0;$89 = $92;$__k$0 = $91;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $82;
    $96 = (($__count$05) + 1)|0;
    $97 = ($96|0)==(8);
    if ($97) {
     break;
    } else {
     $__count$1 = $96;
    }
   } else {
    $__count$1 = $__count$05;
   }
   $100 = (($__i$06) + 4|0);
   $101 = ($100|0)==($__last|0);
   if ($101) {
    $$0 = 1;
    label = 34;
    break;
   }
   $$pre = HEAP32[$__i$06>>2]|0;
   $__j$04$phi = $__i$06;$86 = $$pre;$__count$05 = $__count$1;$__i$06 = $100;$__j$04 = $__j$04$phi;
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  $98 = (($__i$06) + 4|0);
  $99 = ($98|0)==($__last|0);
  $$0 = $99;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16__sortIRNS_4lessIiEEPiEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$i3 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$011 = 0, $__i$02$i = 0, $__i$1 = 0;
 var $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__k$0$i = 0, $__k$0$lcssa$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0;
 var $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 2;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 5:  {
    label = 26;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 84;
    break L1;
    break;
   }
   default: {
   }
   }
   $39 = ($3|0)<(124);
   if ($39) {
    label = 28;
    break L1;
   }
   $61 = ($3|0)>(3996);
   $62 = (($4|0) / 2)&-1;
   $63 = (($$0) + ($62<<2)|0);
   do {
    if ($61) {
     $64 = (($4|0) / 4)&-1;
     $65 = (($$0) + ($64<<2)|0);
     $$sum = (($64) + ($62))|0;
     $66 = (($$0) + ($$sum<<2)|0);
     $67 = (__ZNSt3__17__sort5IRNS_4lessIiEEPiEEjT0_S5_S5_S5_S5_T_($$0,$65,$63,$66,$1,0)|0);
     $__n_swaps$0 = $67;
    } else {
     $68 = HEAP32[$63>>2]|0;
     $69 = HEAP32[$$0>>2]|0;
     $70 = ($68|0)<($69|0);
     $71 = HEAP32[$1>>2]|0;
     $72 = ($71|0)<($68|0);
     if (!($70)) {
      if (!($72)) {
       $__n_swaps$0 = 0;
       break;
      }
      HEAP32[$63>>2] = $71;
      HEAP32[$1>>2] = $68;
      $73 = HEAP32[$63>>2]|0;
      $74 = HEAP32[$$0>>2]|0;
      $75 = ($73|0)<($74|0);
      if (!($75)) {
       $__n_swaps$0 = 1;
       break;
      }
      HEAP32[$$0>>2] = $73;
      HEAP32[$63>>2] = $74;
      $__n_swaps$0 = 2;
      break;
     }
     if ($72) {
      HEAP32[$$0>>2] = $71;
      HEAP32[$1>>2] = $69;
      $__n_swaps$0 = 1;
      break;
     }
     HEAP32[$$0>>2] = $68;
     HEAP32[$63>>2] = $69;
     $76 = HEAP32[$1>>2]|0;
     $77 = ($76|0)<($69|0);
     if ($77) {
      HEAP32[$63>>2] = $76;
      HEAP32[$1>>2] = $69;
      $__n_swaps$0 = 2;
     } else {
      $__n_swaps$0 = 1;
     }
    }
   } while(0);
   $78 = HEAP32[$$0>>2]|0;
   $79 = HEAP32[$63>>2]|0;
   $80 = ($78|0)<($79|0);
   do {
    if ($80) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $81 = (($__j$0) + -4|0);
      $82 = ($$0|0)==($81|0);
      if ($82) {
       break;
      }
      $100 = HEAP32[$81>>2]|0;
      $101 = ($100|0)<($79|0);
      if ($101) {
       label = 67;
       break;
      } else {
       $__j$0 = $81;
      }
     }
     if ((label|0) == 67) {
      label = 0;
      HEAP32[$$0>>2] = $100;
      HEAP32[$81>>2] = $78;
      $102 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $81;$__n_swaps$3 = $102;
      break;
     }
     $83 = (($$0) + 4|0);
     $84 = HEAP32[$1>>2]|0;
     $85 = ($78|0)<($84|0);
     if ($85) {
      $__i$1 = $83;
     } else {
      $86 = ($83|0)==($1|0);
      if ($86) {
       label = 84;
       break L1;
      } else {
       $__i$011 = $83;
      }
      while(1) {
       $89 = HEAP32[$__i$011>>2]|0;
       $90 = ($78|0)<($89|0);
       $88 = (($__i$011) + 4|0);
       if ($90) {
        break;
       }
       $87 = ($88|0)==($1|0);
       if ($87) {
        label = 84;
        break L1;
       } else {
        $__i$011 = $88;
       }
      }
      HEAP32[$__i$011>>2] = $84;
      HEAP32[$1>>2] = $89;
      $__i$1 = $88;
     }
     $91 = ($__i$1|0)==($1|0);
     if ($91) {
      label = 84;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $92 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $93 = HEAP32[$__i$2>>2]|0;
       $94 = ($92|0)<($93|0);
       $95 = (($__i$2) + 4|0);
       if ($94) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $95;
       }
      }
      while(1) {
       $96 = (($__j$2) + -4|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = ($92|0)<($97|0);
       if ($98) {
        $__j$2 = $96;
       } else {
        break;
       }
      }
      $99 = ($__i$2>>>0)<($96>>>0);
      if (!($99)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__i$2>>2] = $97;
      HEAP32[$96>>2] = $93;
      $__i$2$ph = $95;$__j$1$ph = $96;
     }
    }
   } while(0);
   $103 = (($$0) + 4|0);
   $104 = ($103>>>0)<($__j$3>>>0);
   L43: do {
    if ($104) {
     $__i$3$ph = $103;$__j$4$ph = $__j$3;$__m$0$ph = $63;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $105 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $106 = HEAP32[$__i$3>>2]|0;
       $107 = ($106|0)<($105|0);
       $108 = (($__i$3) + 4|0);
       if ($107) {
        $__i$3 = $108;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $109 = (($__j$5) + -4|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = ($110|0)<($105|0);
       if ($111) {
        break;
       } else {
        $__j$5 = $109;
       }
      }
      $112 = ($__i$3>>>0)>($109>>>0);
      if ($112) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L43;
      }
      HEAP32[$__i$3>>2] = $110;
      HEAP32[$109>>2] = $106;
      $113 = (($__n_swaps$4$ph) + 1)|0;
      $114 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $114 ? $109 : $__m$0$ph;
      $__i$3$ph = $108;$__j$4$ph = $109;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $113;
     }
    } else {
     $__i$4 = $103;$__m$2 = $63;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $115 = ($__i$4|0)==($__m$2|0);
   if ($115) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $116 = HEAP32[$__m$2>>2]|0;
    $117 = HEAP32[$__i$4>>2]|0;
    $118 = ($116|0)<($117|0);
    if ($118) {
     HEAP32[$__i$4>>2] = $116;
     HEAP32[$__m$2>>2] = $117;
     $119 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $119;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $120 = ($__n_swaps$6|0)==(0);
   if ($120) {
    $121 = (__ZNSt3__127__insertion_sort_incompleteIRNS_4lessIiEEPiEEbT0_S5_T_($$0,$__i$4,0)|0);
    $122 = (($__i$4) + 4|0);
    $123 = (__ZNSt3__127__insertion_sort_incompleteIRNS_4lessIiEEPiEEbT0_S5_T_($122,$$01$ph,0)|0);
    if ($123) {
     label = 79;
     break;
    }
    if ($121) {
     $$0 = $122;
     continue;
    }
   }
   $124 = $__i$4;
   $125 = (($124) - ($2))|0;
   $126 = (($0) - ($124))|0;
   $127 = ($125|0)<($126|0);
   if (!($127)) {
    label = 83;
    break;
   }
   __ZNSt3__16__sortIRNS_4lessIiEEPiEEvT0_S5_T_($$0,$__i$4,$__comp);
   $128 = (($__i$4) + 4|0);
   $$0 = $128;
  }
  if ((label|0) == 79) {
   label = 0;
   if ($121) {
    label = 84;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 83) {
   label = 0;
   $129 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIRNS_4lessIiEEPiEEvT0_S5_T_($129,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $5;
  HEAP32[$1>>2] = $6;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $8 = (($$0) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$$0>>2]|0;
  $11 = ($9|0)<($10|0);
  $12 = HEAP32[$1>>2]|0;
  $13 = ($12|0)<($9|0);
  if (!($11)) {
   if (!($13)) {
    STACKTOP = sp;return;
   }
   HEAP32[$8>>2] = $12;
   HEAP32[$1>>2] = $9;
   $14 = HEAP32[$8>>2]|0;
   $15 = HEAP32[$$0>>2]|0;
   $16 = ($14|0)<($15|0);
   if (!($16)) {
    STACKTOP = sp;return;
   }
   HEAP32[$$0>>2] = $14;
   HEAP32[$8>>2] = $15;
   STACKTOP = sp;return;
  }
  if ($13) {
   HEAP32[$$0>>2] = $12;
   HEAP32[$1>>2] = $10;
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $9;
  HEAP32[$8>>2] = $10;
  $17 = HEAP32[$1>>2]|0;
  $18 = ($17|0)<($10|0);
  if (!($18)) {
   STACKTOP = sp;return;
  }
  HEAP32[$8>>2] = $17;
  HEAP32[$1>>2] = $10;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $19 = (($$0) + 4|0);
  $20 = (($$0) + 8|0);
  $21 = HEAP32[$19>>2]|0;
  $22 = HEAP32[$$0>>2]|0;
  $23 = ($21|0)<($22|0);
  $24 = HEAP32[$20>>2]|0;
  $25 = ($24|0)<($21|0);
  do {
   if ($23) {
    if ($25) {
     HEAP32[$$0>>2] = $24;
     HEAP32[$20>>2] = $22;
     $30 = $22;
     break;
    }
    HEAP32[$$0>>2] = $21;
    HEAP32[$19>>2] = $22;
    $27 = ($24|0)<($22|0);
    if ($27) {
     HEAP32[$19>>2] = $24;
     HEAP32[$20>>2] = $22;
     $30 = $22;
    } else {
     $30 = $24;
    }
   } else {
    if ($25) {
     HEAP32[$19>>2] = $24;
     HEAP32[$20>>2] = $21;
     $26 = ($24|0)<($22|0);
     if ($26) {
      HEAP32[$$0>>2] = $24;
      HEAP32[$19>>2] = $22;
      $30 = $21;
     } else {
      $30 = $21;
     }
    } else {
     $30 = $24;
    }
   }
  } while(0);
  $28 = HEAP32[$1>>2]|0;
  $29 = ($28|0)<($30|0);
  if (!($29)) {
   STACKTOP = sp;return;
  }
  HEAP32[$20>>2] = $28;
  HEAP32[$1>>2] = $30;
  $31 = HEAP32[$20>>2]|0;
  $32 = HEAP32[$19>>2]|0;
  $33 = ($31|0)<($32|0);
  if (!($33)) {
   STACKTOP = sp;return;
  }
  HEAP32[$19>>2] = $31;
  HEAP32[$20>>2] = $32;
  $34 = HEAP32[$$0>>2]|0;
  $35 = ($31|0)<($34|0);
  if (!($35)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $31;
  HEAP32[$19>>2] = $34;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 26) {
  $36 = (($$0) + 4|0);
  $37 = (($$0) + 8|0);
  $38 = (($$0) + 12|0);
  (__ZNSt3__17__sort5IRNS_4lessIiEEPiEEjT0_S5_S5_S5_S5_T_($$0,$36,$37,$38,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 28) {
  $40 = (($$0) + 8|0);
  $41 = (($$0) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$$0>>2]|0;
  $44 = ($42|0)<($43|0);
  $45 = HEAP32[$40>>2]|0;
  $46 = ($45|0)<($42|0);
  do {
   if ($44) {
    if ($46) {
     HEAP32[$$0>>2] = $45;
     HEAP32[$40>>2] = $43;
     $130 = $43;
     break;
    }
    HEAP32[$$0>>2] = $42;
    HEAP32[$41>>2] = $43;
    $48 = ($45|0)<($43|0);
    if ($48) {
     HEAP32[$41>>2] = $45;
     HEAP32[$40>>2] = $43;
     $130 = $43;
    } else {
     $130 = $45;
    }
   } else {
    if ($46) {
     HEAP32[$41>>2] = $45;
     HEAP32[$40>>2] = $42;
     $47 = ($45|0)<($43|0);
     if ($47) {
      HEAP32[$$0>>2] = $45;
      HEAP32[$41>>2] = $43;
      $130 = $42;
     } else {
      $130 = $42;
     }
    } else {
     $130 = $45;
    }
   }
  } while(0);
  $49 = (($$0) + 12|0);
  $50 = ($49|0)==($$01$ph|0);
  if ($50) {
   STACKTOP = sp;return;
  } else {
   $53 = $130;$__i$02$i = $49;$__j$01$i = $40;
  }
  while(1) {
   $51 = HEAP32[$__i$02$i>>2]|0;
   $52 = ($51|0)<($53|0);
   if ($52) {
    $54 = $53;$__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     HEAP32[$__j$1$i>>2] = $54;
     $55 = ($__k$0$i|0)==($$0|0);
     if ($55) {
      $__k$0$lcssa$i = $$0;
      break;
     }
     $56 = (($__k$0$i) + -4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($51|0)<($57|0);
     if ($58) {
      $__j$1$i$phi = $__k$0$i;$54 = $57;$__k$0$i = $56;$__j$1$i = $__j$1$i$phi;
     } else {
      $__k$0$lcssa$i = $__k$0$i;
      break;
     }
    }
    HEAP32[$__k$0$lcssa$i>>2] = $51;
   }
   $59 = (($__i$02$i) + 4|0);
   $60 = ($59|0)==($$01$ph|0);
   if ($60) {
    break;
   }
   $$pre$i3 = HEAP32[$__i$02$i>>2]|0;
   $__j$01$i$phi = $__i$02$i;$53 = $$pre$i3;$__i$02$i = $59;$__j$01$i = $__j$01$i$phi;
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 84) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort5IRNS_4lessIiEEPiEEjT0_S5_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $$0$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__r$0 = 0, $__r$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3|0)<($0|0);
 do {
  if ($2) {
   if ($4) {
    HEAP32[$__x1>>2] = $3;
    HEAP32[$__x3>>2] = $1;
    $$0$i$i = 1;$12 = $1;
    break;
   }
   HEAP32[$__x1>>2] = $0;
   HEAP32[$__x2>>2] = $1;
   $8 = HEAP32[$__x3>>2]|0;
   $9 = ($8|0)<($1|0);
   if ($9) {
    HEAP32[$__x2>>2] = $8;
    HEAP32[$__x3>>2] = $1;
    $$0$i$i = 2;$12 = $1;
   } else {
    $$0$i$i = 1;$12 = $8;
   }
  } else {
   if ($4) {
    HEAP32[$__x2>>2] = $3;
    HEAP32[$__x3>>2] = $0;
    $5 = HEAP32[$__x2>>2]|0;
    $6 = HEAP32[$__x1>>2]|0;
    $7 = ($5|0)<($6|0);
    if ($7) {
     HEAP32[$__x1>>2] = $5;
     HEAP32[$__x2>>2] = $6;
     $$pre$i = HEAP32[$__x3>>2]|0;
     $$0$i$i = 2;$12 = $$pre$i;
    } else {
     $$0$i$i = 1;$12 = $0;
    }
   } else {
    $$0$i$i = 0;$12 = $3;
   }
  }
 } while(0);
 $10 = HEAP32[$__x4>>2]|0;
 $11 = ($10|0)<($12|0);
 do {
  if ($11) {
   HEAP32[$__x3>>2] = $10;
   HEAP32[$__x4>>2] = $12;
   $13 = (($$0$i$i) + 1)|0;
   $14 = HEAP32[$__x3>>2]|0;
   $15 = HEAP32[$__x2>>2]|0;
   $16 = ($14|0)<($15|0);
   if ($16) {
    HEAP32[$__x2>>2] = $14;
    HEAP32[$__x3>>2] = $15;
    $17 = HEAP32[$__x2>>2]|0;
    $18 = HEAP32[$__x1>>2]|0;
    $19 = ($17|0)<($18|0);
    if ($19) {
     HEAP32[$__x1>>2] = $17;
     HEAP32[$__x2>>2] = $18;
     $21 = (($$0$i$i) + 3)|0;
     $__r$0$i = $21;
     break;
    } else {
     $20 = (($$0$i$i) + 2)|0;
     $__r$0$i = $20;
     break;
    }
   } else {
    $__r$0$i = $13;
   }
  } else {
   $__r$0$i = $$0$i$i;
  }
 } while(0);
 $22 = HEAP32[$__x5>>2]|0;
 $23 = HEAP32[$__x4>>2]|0;
 $24 = ($22|0)<($23|0);
 if (!($24)) {
  $__r$0 = $__r$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x4>>2] = $22;
 HEAP32[$__x5>>2] = $23;
 $25 = (($__r$0$i) + 1)|0;
 $26 = HEAP32[$__x4>>2]|0;
 $27 = HEAP32[$__x3>>2]|0;
 $28 = ($26|0)<($27|0);
 if (!($28)) {
  $__r$0 = $25;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $26;
 HEAP32[$__x4>>2] = $27;
 $29 = (($__r$0$i) + 2)|0;
 $30 = HEAP32[$__x3>>2]|0;
 $31 = HEAP32[$__x2>>2]|0;
 $32 = ($30|0)<($31|0);
 if (!($32)) {
  $__r$0 = $29;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $30;
 HEAP32[$__x3>>2] = $31;
 $33 = (($__r$0$i) + 3)|0;
 $34 = HEAP32[$__x2>>2]|0;
 $35 = HEAP32[$__x1>>2]|0;
 $36 = ($34|0)<($35|0);
 if (!($36)) {
  $__r$0 = $33;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $34;
 HEAP32[$__x2>>2] = $35;
 $37 = (($__r$0$i) + 4)|0;
 $__r$0 = $37;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_4lessIiEEPiEEbT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$05 = 0, $__count$1 = 0, $__i$06 = 0, $__j$04 = 0, $__j$04$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 5:  {
  $38 = (($__first) + 4|0);
  $39 = (($__first) + 8|0);
  $40 = (($__first) + 12|0);
  $41 = (($__last) + -4|0);
  (__ZNSt3__17__sort5IRNS_4lessIiEEPiEEjT0_S5_S5_S5_S5_T_($__first,$38,$39,$40,$41,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $20 = (($__first) + 4|0);
  $21 = (($__first) + 8|0);
  $22 = (($__last) + -4|0);
  $23 = HEAP32[$20>>2]|0;
  $24 = HEAP32[$__first>>2]|0;
  $25 = ($23|0)<($24|0);
  $26 = HEAP32[$21>>2]|0;
  $27 = ($26|0)<($23|0);
  do {
   if ($25) {
    if ($27) {
     HEAP32[$__first>>2] = $26;
     HEAP32[$21>>2] = $24;
     $32 = $24;
     break;
    }
    HEAP32[$__first>>2] = $23;
    HEAP32[$20>>2] = $24;
    $29 = ($26|0)<($24|0);
    if ($29) {
     HEAP32[$20>>2] = $26;
     HEAP32[$21>>2] = $24;
     $32 = $24;
    } else {
     $32 = $26;
    }
   } else {
    if ($27) {
     HEAP32[$20>>2] = $26;
     HEAP32[$21>>2] = $23;
     $28 = ($26|0)<($24|0);
     if ($28) {
      HEAP32[$__first>>2] = $26;
      HEAP32[$20>>2] = $24;
      $32 = $23;
     } else {
      $32 = $23;
     }
    } else {
     $32 = $26;
    }
   }
  } while(0);
  $30 = HEAP32[$22>>2]|0;
  $31 = ($30|0)<($32|0);
  if (!($31)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$21>>2] = $30;
  HEAP32[$22>>2] = $32;
  $33 = HEAP32[$21>>2]|0;
  $34 = HEAP32[$20>>2]|0;
  $35 = ($33|0)<($34|0);
  if (!($35)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$20>>2] = $33;
  HEAP32[$21>>2] = $34;
  $36 = HEAP32[$__first>>2]|0;
  $37 = ($33|0)<($36|0);
  if (!($37)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $33;
  HEAP32[$20>>2] = $36;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $8 = (($__first) + 4|0);
  $9 = (($__last) + -4|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$__first>>2]|0;
  $12 = ($10|0)<($11|0);
  $13 = HEAP32[$9>>2]|0;
  $14 = ($13|0)<($10|0);
  if (!($12)) {
   if (!($14)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$8>>2] = $13;
   HEAP32[$9>>2] = $10;
   $15 = HEAP32[$8>>2]|0;
   $16 = HEAP32[$__first>>2]|0;
   $17 = ($15|0)<($16|0);
   if (!($17)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__first>>2] = $15;
   HEAP32[$8>>2] = $16;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($14) {
   HEAP32[$__first>>2] = $13;
   HEAP32[$9>>2] = $11;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $10;
  HEAP32[$8>>2] = $11;
  $18 = HEAP32[$9>>2]|0;
  $19 = ($18|0)<($11|0);
  if (!($19)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$8>>2] = $18;
  HEAP32[$9>>2] = $11;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $42 = (($__first) + 8|0);
  $43 = (($__first) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = HEAP32[$__first>>2]|0;
  $46 = ($44|0)<($45|0);
  $47 = HEAP32[$42>>2]|0;
  $48 = ($47|0)<($44|0);
  do {
   if ($46) {
    if ($48) {
     HEAP32[$__first>>2] = $47;
     HEAP32[$42>>2] = $45;
     $67 = $45;
     break;
    }
    HEAP32[$__first>>2] = $44;
    HEAP32[$43>>2] = $45;
    $50 = ($47|0)<($45|0);
    if ($50) {
     HEAP32[$43>>2] = $47;
     HEAP32[$42>>2] = $45;
     $67 = $45;
    } else {
     $67 = $47;
    }
   } else {
    if ($48) {
     HEAP32[$43>>2] = $47;
     HEAP32[$42>>2] = $44;
     $49 = ($47|0)<($45|0);
     if ($49) {
      HEAP32[$__first>>2] = $47;
      HEAP32[$43>>2] = $45;
      $67 = $44;
     } else {
      $67 = $44;
     }
    } else {
     $67 = $47;
    }
   }
  } while(0);
  $51 = (($__first) + 12|0);
  $52 = ($51|0)==($__last|0);
  if ($52) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $55 = $67;$__count$05 = 0;$__i$06 = $51;$__j$04 = $42;
  }
  while(1) {
   $53 = HEAP32[$__i$06>>2]|0;
   $54 = ($53|0)<($55|0);
   if ($54) {
    $56 = $55;$__j$1 = $__i$06;$__k$0 = $__j$04;
    while(1) {
     HEAP32[$__j$1>>2] = $56;
     $57 = ($__k$0|0)==($__first|0);
     if ($57) {
      $__k$0$lcssa = $__first;
      break;
     }
     $58 = (($__k$0) + -4|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($53|0)<($59|0);
     if ($60) {
      $__j$1$phi = $__k$0;$56 = $59;$__k$0 = $58;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $53;
    $61 = (($__count$05) + 1)|0;
    $62 = ($61|0)==(8);
    if ($62) {
     break;
    } else {
     $__count$1 = $61;
    }
   } else {
    $__count$1 = $__count$05;
   }
   $65 = (($__i$06) + 4|0);
   $66 = ($65|0)==($__last|0);
   if ($66) {
    $$0 = 1;
    label = 41;
    break;
   }
   $$pre = HEAP32[$__i$06>>2]|0;
   $__j$04$phi = $__i$06;$55 = $$pre;$__count$05 = $__count$1;$__i$06 = $65;$__j$04 = $__j$04$phi;
  }
  if ((label|0) == 41) {
   STACKTOP = sp;return ($$0|0);
  }
  $63 = (($__i$06) + 4|0);
  $64 = ($63|0)==($__last|0);
  $$0 = $64;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($agg$result,$this,$key) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $key = $key|0;
 var $$ = 0, $$lcssa2$ph = 0, $$lcssa214 = 0, $$lcssa3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $num_probes$04 = 0, $num_probes$04$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$key>>2]|0;
 $4 = (($3) + 2127912214)|0;
 $5 = $3 << 12;
 $6 = (($4) + ($5))|0;
 $7 = $6 ^ -949894596;
 $8 = $6 >>> 19;
 $9 = $7 ^ $8;
 $10 = (($9) + 374761393)|0;
 $11 = $9 << 5;
 $12 = (($10) + ($11))|0;
 $13 = (($12) + -744332180)|0;
 $14 = $12 << 9;
 $15 = $13 ^ $14;
 $16 = (($15) + -42973499)|0;
 $17 = $15 << 3;
 $18 = (($16) + ($17))|0;
 $19 = $18 ^ -1252372727;
 $20 = $18 >>> 16;
 $21 = $19 ^ $20;
 $22 = $21 & $2;
 $23 = (($this) + 20|0);
 $24 = (($this) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($22<<3)|0);
 $27 = HEAP32[$23>>2]|0;
 $28 = HEAP32[$26>>2]|0;
 $29 = ($27|0)==($28|0);
 L1: do {
  if ($29) {
   $$lcssa2$ph = $22;
   label = 5;
  } else {
   $30 = (($this) + 8|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   $33 = (($this) + 4|0);
   $34 = (($this) + 12|0);
   L3: do {
    if ($32) {
     $36 = $28;$39 = $22;$num_probes$04$us = 0;
     while(1) {
      $35 = ($3|0)==($36|0);
      if ($35) {
       $$lcssa3 = $39;
       break L3;
      }
      $37 = (($num_probes$04$us) + 1)|0;
      $38 = (($37) + ($39))|0;
      $40 = $38 & $2;
      $41 = (($25) + ($40<<3)|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($27|0)==($42|0);
      if ($43) {
       $$lcssa2$ph = $40;
       label = 5;
       break L1;
      } else {
       $36 = $42;$39 = $40;$num_probes$04$us = $37;
      }
     }
    } else {
     $53 = $28;$55 = -1;$56 = $22;$num_probes$04 = 0;
     while(1) {
      $49 = HEAP32[$33>>2]|0;
      $50 = ($49|0)==(0);
      if ($50) {
       label = 12;
      } else {
       $51 = HEAP32[$34>>2]|0;
       $52 = ($51|0)==($53|0);
       if ($52) {
        $54 = ($55|0)==(-1);
        $$ = $54 ? $56 : $55;
        $46 = $$;
       } else {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       label = 0;
       $57 = ($3|0)==($53|0);
       if ($57) {
        $$lcssa3 = $56;
        break L3;
       } else {
        $46 = $55;
       }
      }
      $59 = (($num_probes$04) + 1)|0;
      $60 = (($59) + ($56))|0;
      $61 = $60 & $2;
      $62 = (($25) + ($61<<3)|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($27|0)==($63|0);
      if ($64) {
       break;
      } else {
       $53 = $63;$55 = $46;$56 = $61;$num_probes$04 = $59;
      }
     }
     $45 = ($46|0)==(-1);
     HEAP32[$agg$result>>2] = -1;
     $47 = (($agg$result) + 4|0);
     if ($45) {
      $$lcssa214 = $61;$48 = $47;
      break L1;
     }
     HEAP32[$47>>2] = $46;
     STACKTOP = sp;return;
    }
   } while(0);
   HEAP32[$agg$result>>2] = $$lcssa3;
   $58 = (($agg$result) + 4|0);
   HEAP32[$58>>2] = -1;
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 5) {
  HEAP32[$agg$result>>2] = -1;
  $44 = (($agg$result) + 4|0);
  $$lcssa214 = $$lcssa2$ph;$48 = $44;
 }
 HEAP32[$48>>2] = $$lcssa214;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($this,$delta,$min_buckets_wanted) {
 $this = $this|0;
 $delta = $delta|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sz$0$i = 0, $sz$0$i1 = 0, $tmp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 48|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12maybe_shrinkEv($this);
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)>($min_buckets_wanted>>>0);
 $7 = (($this) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $9 = (($8) + ($delta))|0;
  $10 = (($this) + 44|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9>>>0)>($11>>>0);
  if (!($12)) {
   STACKTOP = sp;return;
  }
 }
 $13 = (($this) + 36|0);
 $14 = (($8) + ($delta))|0;
 $15 = (Math_fround(($14>>>0)));
 $sz$0$i = 32;
 while(1) {
  $16 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($16)) {
   $17 = (Math_fround(($sz$0$i>>>0)));
   $18 = Math_fround($17 * Math_fround(0.5));
   $19 = !($15 >= $18);
   if ($19) {
    break;
   }
  }
  $20 = $sz$0$i << 1;
  $sz$0$i = $20;
 }
 $21 = ($sz$0$i>>>0)>($5>>>0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($14) - ($23))|0;
 $25 = (Math_fround(($24>>>0)));
 $sz$0$i1 = 32;
 while(1) {
  $26 = ($sz$0$i1>>>0)<($min_buckets_wanted>>>0);
  if (!($26)) {
   $27 = (Math_fround(($sz$0$i1>>>0)));
   $28 = Math_fround($27 * Math_fround(0.5));
   $29 = !($25 >= $28);
   if ($29) {
    break;
   }
  }
  $30 = $sz$0$i1 << 1;
  $sz$0$i1 = $30;
 }
 $31 = (($tmp) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = (($tmp) + 8|0);
 $33 = (($this) + 8|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = (($tmp) + 9|0);
 $36 = (($this) + 9|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP8[$35>>0] = $37;
 $38 = (($tmp) + 12|0);
 $39 = (($this) + 12|0);
 $40 = $39;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 4)|0;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = $38;
 $47 = $46;
 HEAP32[$47>>2] = $42;
 $48 = (($46) + 4)|0;
 $49 = $48;
 HEAP32[$49>>2] = $45;
 $50 = (($tmp) + 20|0);
 $51 = (($this) + 20|0);
 $52 = $51;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($52) + 4)|0;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = $50;
 $59 = $58;
 HEAP32[$59>>2] = $54;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $57;
 $62 = (($tmp) + 28|0);
 ;HEAP32[$62+0>>2]=0|0;HEAP32[$62+4>>2]=0|0;HEAP32[$62+8>>2]=0|0;HEAP32[$62+12>>2]=0|0;HEAP32[$62+16>>2]=0|0;HEAP8[$62+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E9copy_fromERKSF_j($tmp,$this,$sz$0$i1);
 $63 = HEAP32[$22>>2]|0;
 $64 = HEAP32[$31>>2]|0;
 HEAP32[$22>>2] = $64;
 HEAP32[$31>>2] = $63;
 $65 = HEAP8[$33>>0]|0;
 $66 = HEAP16[$32>>1]|0;
 $67 = $66&255;
 HEAP8[$33>>0] = $67;
 HEAP8[$32>>0] = $65;
 $68 = HEAP8[$36>>0]|0;
 $69 = ($66&65535) >>> 8;
 $70 = $69&255;
 HEAP8[$36>>0] = $70;
 HEAP8[$35>>0] = $68;
 $71 = $39;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($71) + 4)|0;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = $38;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = (($77) + 4)|0;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = $39;
 $84 = $83;
 HEAP32[$84>>2] = $79;
 $85 = (($83) + 4)|0;
 $86 = $85;
 HEAP32[$86>>2] = $82;
 $87 = $38;
 $88 = $87;
 HEAP32[$88>>2] = $73;
 $89 = (($87) + 4)|0;
 $90 = $89;
 HEAP32[$90>>2] = $76;
 $91 = $51;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = (($91) + 4)|0;
 $95 = $94;
 $96 = HEAP32[$95>>2]|0;
 $97 = $50;
 $98 = $97;
 $99 = HEAP32[$98>>2]|0;
 $100 = (($97) + 4)|0;
 $101 = $100;
 $102 = HEAP32[$101>>2]|0;
 $103 = $51;
 $104 = $103;
 HEAP32[$104>>2] = $99;
 $105 = (($103) + 4)|0;
 $106 = $105;
 HEAP32[$106>>2] = $102;
 $107 = $50;
 $108 = $107;
 HEAP32[$108>>2] = $93;
 $109 = (($107) + 4)|0;
 $110 = $109;
 HEAP32[$110>>2] = $96;
 $111 = (($this) + 28|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = HEAP32[$62>>2]|0;
 HEAP32[$111>>2] = $113;
 HEAP32[$62>>2] = $112;
 $114 = (($tmp) + 32|0);
 $115 = HEAP32[$4>>2]|0;
 $116 = HEAP32[$114>>2]|0;
 HEAP32[$4>>2] = $116;
 HEAP32[$114>>2] = $115;
 $117 = (($tmp) + 36|0);
 $118 = HEAP32[$13>>2]|0;
 $119 = HEAP32[$117>>2]|0;
 HEAP32[$13>>2] = $119;
 HEAP32[$117>>2] = $118;
 $120 = (Math_fround(($116>>>0)));
 $121 = Math_fround($120 * Math_fround(0.5));
 $122 = (~~(($121))>>>0);
 $123 = (($this) + 44|0);
 HEAP32[$123>>2] = $122;
 $124 = Math_fround($120 * Math_fround(0.20000000298023223877));
 $125 = (~~(($124))>>>0);
 $126 = (($this) + 40|0);
 HEAP32[$126>>2] = $125;
 HEAP8[$1>>0] = 0;
 $127 = (Math_fround(($115>>>0)));
 $128 = Math_fround($127 * Math_fround(0.5));
 $129 = (~~(($128))>>>0);
 $130 = (($tmp) + 44|0);
 HEAP32[$130>>2] = $129;
 $131 = Math_fround($127 * Math_fround(0.20000000298023223877));
 $132 = (~~(($131))>>>0);
 $133 = (($tmp) + 40|0);
 HEAP32[$133>>2] = $132;
 $134 = (($tmp) + 48|0);
 HEAP8[$134>>0] = 0;
 $135 = ($112|0)==(0|0);
 if ($135) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($112,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS5_($agg$result,$this,$obj) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $obj = $obj|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos = sp;
 __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos,$this,$obj);
 $0 = HEAP32[$pos>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  $2 = (($this) + 28|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + ($0<<3)|0);
  $5 = (($this) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + ($6<<3)|0);
  HEAP32[$agg$result>>2] = $this;
  $8 = (($agg$result) + 4|0);
  HEAP32[$8>>2] = $4;
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $7;
  $10 = (($agg$result) + 12|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($pos) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  label = 7;
 } else {
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if ($18) {
   label = 7;
  } else {
   $19 = (($this) + 12|0);
   $20 = (($this) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($12<<3)|0);
   $23 = HEAP32[$19>>2]|0;
   $24 = HEAP32[$22>>2]|0;
   $25 = ($23|0)==($24|0);
   if ($25) {
    $26 = (($17) + -1)|0;
    HEAP32[$16>>2] = $26;
    $32 = $21;
   } else {
    label = 7;
   }
  }
 }
 if ((label|0) == 7) {
  $27 = (($this) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 1)|0;
  HEAP32[$27>>2] = $29;
  $$phi$trans$insert = (($this) + 28|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $32 = $$pre;
 }
 $30 = (($this) + 28|0);
 $31 = (($32) + ($12<<3)|0);
 $33 = ($31|0)==(0|0);
 if (!($33)) {
  $34 = $obj;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 4)|0;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = $31;
  $41 = $40;
  HEAP32[$41>>2] = $36;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = $39;
 }
 $44 = HEAP32[$30>>2]|0;
 $45 = (($44) + ($12<<3)|0);
 $46 = (($this) + 32|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($44) + ($47<<3)|0);
 HEAP32[$agg$result>>2] = $this;
 $49 = (($agg$result) + 4|0);
 HEAP32[$49>>2] = $45;
 $50 = (($agg$result) + 8|0);
 HEAP32[$50>>2] = $48;
 $51 = (($agg$result) + 12|0);
 HEAP8[$51>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12maybe_shrinkEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sz$0 = 0, $sz$0$in = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) - ($4))|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if (!($8)) {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 $9 = (($this) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)>(32);
 if ($11) {
  $sz$0$in = $10;
 } else {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $sz$0 = $sz$0$in >>> 1;
  $12 = ($sz$0$in>>>0)<(66);
  if ($12) {
   break;
  }
  $13 = (Math_fround(($5>>>0)));
  $14 = (Math_fround(($sz$0>>>0)));
  $15 = Math_fround($14 * Math_fround(0.20000000298023223877));
  $16 = $13 < $15;
  if ($16) {
   $sz$0$in = $sz$0;
  } else {
   break;
  }
 }
 $17 = (($tmp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($tmp) + 8|0);
 $19 = (($this) + 8|0);
 $20 = HEAP8[$19>>0]|0;
 HEAP8[$18>>0] = $20;
 $21 = (($tmp) + 9|0);
 $22 = (($this) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 HEAP8[$21>>0] = $23;
 $24 = (($tmp) + 12|0);
 $25 = (($this) + 12|0);
 $26 = $25;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $24;
 $33 = $32;
 HEAP32[$33>>2] = $28;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $31;
 $36 = (($tmp) + 20|0);
 $37 = (($this) + 20|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $36;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 $48 = (($tmp) + 28|0);
 ;HEAP32[$48+0>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;HEAP8[$48+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E9copy_fromERKSF_j($tmp,$this,$sz$0);
 $49 = HEAP32[$3>>2]|0;
 $50 = HEAP32[$17>>2]|0;
 HEAP32[$3>>2] = $50;
 HEAP32[$17>>2] = $49;
 $51 = HEAP8[$19>>0]|0;
 $52 = HEAP16[$18>>1]|0;
 $53 = $52&255;
 HEAP8[$19>>0] = $53;
 HEAP8[$18>>0] = $51;
 $54 = HEAP8[$22>>0]|0;
 $55 = ($52&65535) >>> 8;
 $56 = $55&255;
 HEAP8[$22>>0] = $56;
 HEAP8[$21>>0] = $54;
 $57 = $25;
 $58 = $57;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 4)|0;
 $61 = $60;
 $62 = HEAP32[$61>>2]|0;
 $63 = $24;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $25;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $24;
 $74 = $73;
 HEAP32[$74>>2] = $59;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $62;
 $77 = $37;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = (($77) + 4)|0;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = $36;
 $84 = $83;
 $85 = HEAP32[$84>>2]|0;
 $86 = (($83) + 4)|0;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = $37;
 $90 = $89;
 HEAP32[$90>>2] = $85;
 $91 = (($89) + 4)|0;
 $92 = $91;
 HEAP32[$92>>2] = $88;
 $93 = $36;
 $94 = $93;
 HEAP32[$94>>2] = $79;
 $95 = (($93) + 4)|0;
 $96 = $95;
 HEAP32[$96>>2] = $82;
 $97 = (($this) + 28|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$48>>2]|0;
 HEAP32[$97>>2] = $99;
 HEAP32[$48>>2] = $98;
 $100 = (($tmp) + 32|0);
 $101 = HEAP32[$9>>2]|0;
 $102 = HEAP32[$100>>2]|0;
 HEAP32[$9>>2] = $102;
 HEAP32[$100>>2] = $101;
 $103 = (($tmp) + 36|0);
 $104 = HEAP32[$1>>2]|0;
 $105 = HEAP32[$103>>2]|0;
 HEAP32[$1>>2] = $105;
 HEAP32[$103>>2] = $104;
 $106 = (Math_fround(($102>>>0)));
 $107 = Math_fround($106 * Math_fround(0.5));
 $108 = (~~(($107))>>>0);
 $109 = (($this) + 44|0);
 HEAP32[$109>>2] = $108;
 $110 = Math_fround($106 * Math_fround(0.20000000298023223877));
 $111 = (~~(($110))>>>0);
 HEAP32[$6>>2] = $111;
 $112 = (($this) + 48|0);
 HEAP8[$112>>0] = 0;
 $113 = (Math_fround(($101>>>0)));
 $114 = Math_fround($113 * Math_fround(0.5));
 $115 = (~~(($114))>>>0);
 $116 = (($tmp) + 44|0);
 HEAP32[$116>>2] = $115;
 $117 = Math_fround($113 * Math_fround(0.20000000298023223877));
 $118 = (~~(($117))>>>0);
 $119 = (($tmp) + 40|0);
 HEAP32[$119>>2] = $118;
 $120 = (($tmp) + 48|0);
 HEAP8[$120>>0] = 0;
 $121 = ($98|0)==(0|0);
 if ($121) {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($98,$$byval_copy);
 $122 = (($this) + 48|0);
 HEAP8[$122>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E9copy_fromERKSF_j($this,$ht,$min_buckets_wanted) {
 $this = $this|0;
 $ht = $ht|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$01$i$i$i = 0, $$01$i$i$i4 = 0, $$012$i$i = 0, $$03$i$i = 0, $$be = 0, $$byval_copy3 = 0, $$ph11 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucknum$0 = 0, $bucknum$0$lcssa = 0, $bucknum$07 = 0, $bucknum$09 = 0, $num_probes$08 = 0, $sz$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = 32;
 $3 = (($this) + 44|0);
 HEAP32[$3>>2] = 16;
 $4 = (($this) + 40|0);
 HEAP32[$4>>2] = 6;
 $5 = (($this) + 48|0);
 HEAP8[$5>>0] = 0;
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Z15malloc_internaljj10MemLabelIdiPKci(256,16,$$byval_copy3,0,560648,79)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy3);
 }
 HEAP32[$1>>2] = $6;
 $9 = HEAP32[$2>>2]|0;
 $10 = (($6) + ($9<<3)|0);
 $11 = ($6|0)==($10|0);
 if (!($11)) {
  $12 = (($this) + 20|0);
  $$01$i$i$i = $6;
  while(1) {
   $13 = ($$01$i$i$i|0)==(0|0);
   if (!($13)) {
    $14 = $12;
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + 4)|0;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = $$01$i$i$i;
    $21 = $20;
    HEAP32[$21>>2] = $16;
    $22 = (($20) + 4)|0;
    $23 = $22;
    HEAP32[$23>>2] = $19;
   }
   $24 = (($$01$i$i$i) + 8|0);
   $25 = ($24|0)==($10|0);
   if ($25) {
    break;
   } else {
    $$01$i$i$i = $24;
   }
  }
 }
 $26 = (($this) + 36|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 4|0);
 HEAP32[$27>>2] = 0;
 $28 = (($ht) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($ht) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) - ($31))|0;
 $33 = (Math_fround(($32>>>0)));
 $sz$0$i = 32;
 while(1) {
  $34 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($34)) {
   $35 = (Math_fround(($sz$0$i>>>0)));
   $36 = Math_fround($35 * Math_fround(0.5));
   $37 = !($33 >= $36);
   if ($37) {
    break;
   }
  }
  $38 = $sz$0$i << 1;
  $sz$0$i = $38;
 }
 $39 = HEAP32[$2>>2]|0;
 $40 = ($sz$0$i>>>0)>($39>>>0);
 if ($40) {
  $41 = $sz$0$i << 3;
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($41,16,$$byval_copy3,0,560648,79)|0);
  $43 = HEAP32[$1>>2]|0;
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   $45 = HEAP32[$2>>2]|0;
   $46 = (($43) + ($45<<3)|0);
   $47 = ($45|0)==(0);
   if ($47) {
    $62 = $43;
   } else {
    $$012$i$i = $42;$$03$i$i = $43;
    while(1) {
     $48 = ($$012$i$i|0)==(0|0);
     if (!($48)) {
      $49 = $$03$i$i;
      $50 = $49;
      $51 = HEAP32[$50>>2]|0;
      $52 = (($49) + 4)|0;
      $53 = $52;
      $54 = HEAP32[$53>>2]|0;
      $55 = $$012$i$i;
      $56 = $55;
      HEAP32[$56>>2] = $51;
      $57 = (($55) + 4)|0;
      $58 = $57;
      HEAP32[$58>>2] = $54;
     }
     $59 = (($$03$i$i) + 8|0);
     $60 = (($$012$i$i) + 8|0);
     $61 = ($59|0)==($46|0);
     if ($61) {
      break;
     } else {
      $$012$i$i = $60;$$03$i$i = $59;
     }
    }
    $$pre$i = HEAP32[$1>>2]|0;
    $62 = $$pre$i;
   }
   HEAP32[$0>>2] = 58;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($62,$$byval_copy3);
  }
  $63 = HEAP32[$2>>2]|0;
  $64 = (($42) + ($sz$0$i<<3)|0);
  $65 = ($63|0)==($sz$0$i|0);
  if (!($65)) {
   $66 = (($42) + ($63<<3)|0);
   $67 = (($this) + 20|0);
   $$01$i$i$i4 = $66;
   while(1) {
    $68 = ($$01$i$i$i4|0)==(0|0);
    if (!($68)) {
     $69 = $67;
     $70 = $69;
     $71 = HEAP32[$70>>2]|0;
     $72 = (($69) + 4)|0;
     $73 = $72;
     $74 = HEAP32[$73>>2]|0;
     $75 = $$01$i$i$i4;
     $76 = $75;
     HEAP32[$76>>2] = $71;
     $77 = (($75) + 4)|0;
     $78 = $77;
     HEAP32[$78>>2] = $74;
    }
    $79 = (($$01$i$i$i4) + 8|0);
    $80 = ($79|0)==($64|0);
    if ($80) {
     break;
    } else {
     $$01$i$i$i4 = $79;
    }
   }
  }
  HEAP32[$1>>2] = $42;
  HEAP32[$2>>2] = $sz$0$i;
  $81 = (~~(($36))>>>0);
  HEAP32[$3>>2] = $81;
  $82 = Math_fround($35 * Math_fround(0.20000000298023223877));
  $83 = (~~(($82))>>>0);
  HEAP32[$4>>2] = $83;
  HEAP8[$5>>0] = 0;
  $174 = $sz$0$i;
 } else {
  $174 = $39;
 }
 $84 = (($ht) + 28|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($ht) + 32|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($85) + ($87<<3)|0);
 $89 = ($87|0)==(0);
 L40: do {
  if ($89) {
   $$ph11 = $85;
  } else {
   $90 = (($ht) + 20|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($ht) + 8|0);
   $93 = (($ht) + 12|0);
   $95 = $85;
   while(1) {
    $94 = HEAP32[$95>>2]|0;
    $96 = ($91|0)==($94|0);
    if (!($96)) {
     $97 = HEAP8[$92>>0]|0;
     $98 = ($97<<24>>24)==(0);
     if ($98) {
      $$ph11 = $95;
      break L40;
     }
     $99 = HEAP32[$30>>2]|0;
     $100 = ($99|0)==(0);
     if ($100) {
      $$ph11 = $95;
      break L40;
     }
     $101 = HEAP32[$93>>2]|0;
     $102 = ($101|0)==($94|0);
     if (!($102)) {
      $$ph11 = $95;
      break L40;
     }
    }
    $103 = (($95) + 8|0);
    $104 = ($103|0)==($88|0);
    if ($104) {
     break;
    } else {
     $95 = $103;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $105 = ($$ph11|0)==($88|0);
 if ($105) {
  STACKTOP = sp;return;
 }
 $106 = (($this) + 20|0);
 $107 = (($ht) + 20|0);
 $108 = (($ht) + 8|0);
 $109 = (($ht) + 12|0);
 $111 = $174;$113 = $$ph11;
 while(1) {
  $110 = (($111) + -1)|0;
  $112 = HEAP32[$113>>2]|0;
  $114 = (($112) + 2127912214)|0;
  $115 = $112 << 12;
  $116 = (($114) + ($115))|0;
  $117 = $116 ^ -949894596;
  $118 = $116 >>> 19;
  $119 = $117 ^ $118;
  $120 = (($119) + 374761393)|0;
  $121 = $119 << 5;
  $122 = (($120) + ($121))|0;
  $123 = (($122) + -744332180)|0;
  $124 = $122 << 9;
  $125 = $123 ^ $124;
  $126 = (($125) + -42973499)|0;
  $127 = $125 << 3;
  $128 = (($126) + ($127))|0;
  $129 = $128 ^ -1252372727;
  $130 = $128 >>> 16;
  $131 = $129 ^ $130;
  $bucknum$07 = $131 & $110;
  $132 = HEAP32[$1>>2]|0;
  $133 = (($132) + ($bucknum$07<<3)|0);
  $134 = HEAP32[$106>>2]|0;
  $135 = HEAP32[$133>>2]|0;
  $136 = ($134|0)==($135|0);
  if ($136) {
   $bucknum$0$lcssa = $bucknum$07;
  } else {
   $bucknum$09 = $bucknum$07;$num_probes$08 = 0;
   while(1) {
    $137 = (($num_probes$08) + 1)|0;
    $138 = (($137) + ($bucknum$09))|0;
    $bucknum$0 = $138 & $110;
    $139 = (($132) + ($bucknum$0<<3)|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = ($134|0)==($140|0);
    if ($141) {
     $bucknum$0$lcssa = $bucknum$0;
     break;
    } else {
     $bucknum$09 = $bucknum$0;$num_probes$08 = $137;
    }
   }
  }
  $142 = (($132) + ($bucknum$0$lcssa<<3)|0);
  $143 = ($142|0)==(0|0);
  if (!($143)) {
   $144 = $113;
   $145 = $144;
   $146 = HEAP32[$145>>2]|0;
   $147 = (($144) + 4)|0;
   $148 = $147;
   $149 = HEAP32[$148>>2]|0;
   $150 = $142;
   $151 = $150;
   HEAP32[$151>>2] = $146;
   $152 = (($150) + 4)|0;
   $153 = $152;
   HEAP32[$153>>2] = $149;
  }
  $154 = HEAP32[$26>>2]|0;
  $155 = (($154) + 1)|0;
  HEAP32[$26>>2] = $155;
  $156 = (($113) + 8|0);
  $157 = ($156|0)==($88|0);
  L63: do {
   if ($157) {
    $$be = $88;
   } else {
    $162 = HEAP32[$107>>2]|0;
    $164 = $156;
    while(1) {
     $163 = HEAP32[$164>>2]|0;
     $165 = ($162|0)==($163|0);
     if (!($165)) {
      $166 = HEAP8[$108>>0]|0;
      $167 = ($166<<24>>24)==(0);
      if ($167) {
       $$be = $164;
       break L63;
      }
      $168 = HEAP32[$30>>2]|0;
      $169 = ($168|0)==(0);
      if ($169) {
       $$be = $164;
       break L63;
      }
      $170 = HEAP32[$109>>2]|0;
      $171 = ($170|0)==($163|0);
      if (!($171)) {
       $$be = $164;
       break L63;
      }
     }
     $172 = (($164) + 8|0);
     $173 = ($172|0)==($88|0);
     if ($173) {
      $$be = $88;
      break;
     } else {
      $164 = $172;
     }
    }
   }
  } while(0);
  $158 = HEAP32[$84>>2]|0;
  $159 = HEAP32[$86>>2]|0;
  $160 = (($158) + ($159<<3)|0);
  $161 = ($$be|0)==($160|0);
  if ($161) {
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $111 = $$pre;$113 = $$be;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIiN6Object4RTTIEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN6Object4RTTIEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN6Object4RTTIEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$4);
 $5 = (($__nd) + 32|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 40|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_call_unexpected(($13|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIPciEENS_19__map_value_compareIS2_S3_15smaller_cstringLb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIPciEENS_19__map_value_compareIS2_S3_15smaller_cstringLb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIPciEENS_19__map_value_compareIS2_S3_15smaller_cstringLb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN28InstanceIdToObjectPtrHashMapC2Ei($this,$n) {
 $this = $this|0;
 $n = $n|0;
 var $$01$i$i$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $sz$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 8|0);
 HEAP8[$3>>0] = 0;
 $4 = (($this) + 9|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 12|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;
 $sz$0$i$i$i$i = 32;
 while(1) {
  $6 = ($sz$0$i$i$i$i>>>0)<($n>>>0);
  if (!($6)) {
   $7 = (Math_fround(($sz$0$i$i$i$i>>>0)));
   $8 = Math_fround($7 * Math_fround(0.5));
   $9 = !($8 <= Math_fround(0.0));
   if ($9) {
    break;
   }
  }
  $10 = $sz$0$i$i$i$i << 1;
  $sz$0$i$i$i$i = $10;
 }
 $11 = (($this) + 32|0);
 HEAP32[$11>>2] = $sz$0$i$i$i$i;
 $12 = (($this) + 36|0);
 HEAP32[$12>>2] = 0;
 $13 = (~~(($8))>>>0);
 $14 = (($this) + 44|0);
 HEAP32[$14>>2] = $13;
 $15 = Math_fround($7 * Math_fround(0.20000000298023223877));
 $16 = (~~(($15))>>>0);
 $17 = (($this) + 40|0);
 HEAP32[$17>>2] = $16;
 $18 = (($this) + 48|0);
 HEAP8[$18>>0] = 0;
 HEAP8[$4>>0] = 1;
 $19 = (($this) + 20|0);
 $20 = $19;
 $21 = $20;
 HEAP32[$21>>2] = -1;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 $24 = $sz$0$i$i$i$i << 3;
 HEAP32[$1>>2] = 58;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $25 = (invoke_iiiiiii(102,($24|0),16,($$byval_copy1|0),0,(560648|0),79)|0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if (!($27)) {
  $28 = (($this) + 28|0);
  HEAP32[$28>>2] = $25;
  $29 = HEAP32[$11>>2]|0;
  $30 = (($25) + ($29<<3)|0);
  $31 = ($25|0)==($30|0);
  if (!($31)) {
   $$01$i$i$i$i = $25;
   while(1) {
    $32 = ($$01$i$i$i$i|0)==(0|0);
    if (!($32)) {
     $33 = $19;
     $34 = $33;
     $35 = HEAP32[$34>>2]|0;
     $36 = (($33) + 4)|0;
     $37 = $36;
     $38 = HEAP32[$37>>2]|0;
     $39 = $$01$i$i$i$i;
     $40 = $39;
     HEAP32[$40>>2] = $35;
     $41 = (($39) + 4)|0;
     $42 = $41;
     HEAP32[$42>>2] = $38;
    }
    $43 = (($$01$i$i$i$i) + 8|0);
    $44 = ($43|0)==($30|0);
    if ($44) {
     break;
    } else {
     $$01$i$i$i$i = $43;
    }
   }
  }
  __THREW__ = 0;
  invoke_vi(3373,($this|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if (!($46)) {
   HEAP8[$3>>0] = 1;
   $47 = (($this) + 12|0);
   $48 = $47;
   $49 = $48;
   HEAP32[$49>>2] = -2;
   $50 = (($48) + 4)|0;
   $51 = $50;
   HEAP32[$51>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $52 = ___cxa_find_matching_catch()|0;
 $53 = tempRet0;
 $54 = (($this) + 28|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($52|0);
  // unreachable;
 }
 HEAP32[$0>>2] = 58;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($55|0),($$byval_copy1|0));
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if ($58) {
  $59 = ___cxa_find_matching_catch(0|0)|0;
  $60 = tempRet0;
  ___clang_call_terminate($59);
  // unreachable;
 } else {
  ___resumeException($52|0);
  // unreachable;
 }
}
function __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E14squash_deletedEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($tmp) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($tmp) + 8|0);
 $6 = (($this) + 8|0);
 $7 = HEAP8[$6>>0]|0;
 HEAP8[$5>>0] = $7;
 $8 = (($tmp) + 9|0);
 $9 = (($this) + 9|0);
 $10 = HEAP8[$9>>0]|0;
 HEAP8[$8>>0] = $10;
 $11 = (($tmp) + 12|0);
 $12 = (($this) + 12|0);
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $11;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 $23 = (($tmp) + 20|0);
 $24 = (($this) + 20|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $23;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = (($tmp) + 28|0);
 ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;HEAP8[$35+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E9copy_fromERKSF_j($tmp,$this,0);
 $36 = HEAP32[$1>>2]|0;
 $37 = HEAP32[$4>>2]|0;
 HEAP32[$1>>2] = $37;
 HEAP32[$4>>2] = $36;
 $38 = HEAP8[$6>>0]|0;
 $39 = HEAP16[$5>>1]|0;
 $40 = $39&255;
 HEAP8[$6>>0] = $40;
 HEAP8[$5>>0] = $38;
 $41 = HEAP8[$9>>0]|0;
 $42 = ($39&65535) >>> 8;
 $43 = $42&255;
 HEAP8[$9>>0] = $43;
 HEAP8[$8>>0] = $41;
 $44 = $12;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = (($44) + 4)|0;
 $48 = $47;
 $49 = HEAP32[$48>>2]|0;
 $50 = $11;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 4)|0;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = $12;
 $57 = $56;
 HEAP32[$57>>2] = $52;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = $55;
 $60 = $11;
 $61 = $60;
 HEAP32[$61>>2] = $46;
 $62 = (($60) + 4)|0;
 $63 = $62;
 HEAP32[$63>>2] = $49;
 $64 = $24;
 $65 = $64;
 $66 = HEAP32[$65>>2]|0;
 $67 = (($64) + 4)|0;
 $68 = $67;
 $69 = HEAP32[$68>>2]|0;
 $70 = $23;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = (($70) + 4)|0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = $24;
 $77 = $76;
 HEAP32[$77>>2] = $72;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $75;
 $80 = $23;
 $81 = $80;
 HEAP32[$81>>2] = $66;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $69;
 $84 = (($this) + 28|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = HEAP32[$35>>2]|0;
 HEAP32[$84>>2] = $86;
 HEAP32[$35>>2] = $85;
 $87 = (($this) + 32|0);
 $88 = (($tmp) + 32|0);
 $89 = HEAP32[$87>>2]|0;
 $90 = HEAP32[$88>>2]|0;
 HEAP32[$87>>2] = $90;
 HEAP32[$88>>2] = $89;
 $91 = (($this) + 36|0);
 $92 = (($tmp) + 36|0);
 $93 = HEAP32[$91>>2]|0;
 $94 = HEAP32[$92>>2]|0;
 HEAP32[$91>>2] = $94;
 HEAP32[$92>>2] = $93;
 $95 = (Math_fround(($90>>>0)));
 $96 = Math_fround($95 * Math_fround(0.5));
 $97 = (~~(($96))>>>0);
 $98 = (($this) + 44|0);
 HEAP32[$98>>2] = $97;
 $99 = Math_fround($95 * Math_fround(0.20000000298023223877));
 $100 = (~~(($99))>>>0);
 $101 = (($this) + 40|0);
 HEAP32[$101>>2] = $100;
 $102 = (($this) + 48|0);
 HEAP8[$102>>0] = 0;
 $103 = (Math_fround(($89>>>0)));
 $104 = Math_fround($103 * Math_fround(0.5));
 $105 = (~~(($104))>>>0);
 $106 = (($tmp) + 44|0);
 HEAP32[$106>>2] = $105;
 $107 = Math_fround($103 * Math_fround(0.20000000298023223877));
 $108 = (~~(($107))>>>0);
 $109 = (($tmp) + 40|0);
 HEAP32[$109>>2] = $108;
 $110 = (($tmp) + 48|0);
 HEAP8[$110>>0] = 0;
 $111 = ($85|0)==(0|0);
 if ($111) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($85,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN7Cursors20RenderSoftwareCursorEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $hotSpotOffset = 0, $preserveMVP = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$byval_copy = sp + 220|0;
 $preserveMVP = sp;
 $hotSpotOffset = sp + 192|0;
 $0 = sp + 200|0;
 $1 = sp + 216|0;
 $2 = (__ZN7Cursors17GetSoftwareCursorEv()|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__Z16GetScreenManagerv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 __ZN22DeviceMVPMatricesStateC2Ev($preserveMVP);
 __THREW__ = 0;
 invoke_v(76);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __THREW__ = 0;
  $11 = (invoke_i(55)|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = (($11) + 100|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = (($11) + 104|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   __THREW__ = 0;
   invoke_vi(3374,($hotSpotOffset|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = Math_fround(HEAPF32[$hotSpotOffset>>2]);
    $21 = Math_fround($15 - $20);
    $22 = (($hotSpotOffset) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = Math_fround($17 + $23);
    $25 = (~~(($21)));
    $26 = (Math_fround(($25|0)));
    $27 = (~~(($24)));
    $28 = (Math_fround(($27|0)));
    $29 = HEAP32[$2>>2]|0;
    $30 = (($29) + 116|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_ii($31|0,($2|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = HEAP32[$2>>2]|0;
     $36 = (($35) + 120|0);
     $37 = HEAP32[$36>>2]|0;
     __THREW__ = 0;
     $38 = (invoke_ii($37|0,($2|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = (Math_fround(($32|0)));
      $42 = (0 - ($38))|0;
      $43 = (Math_fround(($42|0)));
      HEAPF32[$0>>2] = $26;
      $44 = (($0) + 8|0);
      HEAPF32[$44>>2] = $41;
      $45 = (($0) + 4|0);
      HEAPF32[$45>>2] = $28;
      $46 = (($0) + 12|0);
      HEAPF32[$46>>2] = $43;
      HEAP32[$1>>2] = -2139062144;
      __THREW__ = 0;
      ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_viiii(329,($0|0),($2|0),($tmpcast$byval_copy|0),(0|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if (!($48)) {
       __ZN22DeviceMVPMatricesStateD2Ev($preserveMVP);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $49 = ___cxa_find_matching_catch()|0;
 $50 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3375,($preserveMVP|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch(0|0)|0;
  $54 = tempRet0;
  ___clang_call_terminate($53);
  // unreachable;
 } else {
  ___resumeException($49|0);
  // unreachable;
 }
}
function __Z29RegisterClass_EditorExtensionv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(18,77,0,0,0);
 STACKTOP = sp;return;
}
function __ZN15EditorExtension13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(0)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN6Object13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 15;
 dest=$3+0|0; src=560920+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 15|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,18,0,($0|0),24,(2349|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN15EditorExtension7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(24,$$byval_copy2,1,16,561040,55)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1619,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((560936 + 8|0));
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(561040|0),55);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK15EditorExtension25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 18;
}
function __ZN15EditorExtension15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15EditorExtensionD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560936 + 8|0));
 STACKTOP = sp;return;
}
function __ZN15EditorExtensionD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560936 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __Z15GetEventManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[561048>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN12EventManager16StaticInitializeEv() {
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628240>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,561056,16)|0);
 $4 = HEAP32[628480>>2]|0;
 HEAP32[$0>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(98,($3|0),0,(561064|0),12,4096,($$byval_copy2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[561048>>2] = $3;
  STACKTOP = sp;return;
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),0,16,(561056|0),16);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN12EventManager13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[561048>>2]|0;
 $2 = HEAP32[628240>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN10MemoryPoolD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[561048>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12EventManager8AddEventEPFvPvS0_iES0_P10EventEntry($this,$callback,$userData,$previousIndex) {
 $this = $this|0;
 $callback = $callback|0;
 $userData = $userData|0;
 $previousIndex = $previousIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($previousIndex|0)==(0|0);
 $1 = (__ZN10MemoryPool8AllocateEv($this)|0);
 if ($0) {
  HEAP32[$1>>2] = $userData;
  $2 = (($1) + 8|0);
  HEAP32[$2>>2] = $callback;
  $3 = (($1) + 4|0);
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return ($1|0);
 } else {
  $4 = (($1) + 8|0);
  HEAP32[$4>>2] = $callback;
  HEAP32[$1>>2] = $userData;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $previousIndex;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZN12EventManager11RemoveEventEP10EventEntry($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$01 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($index|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $$01 = $index;
 while(1) {
  $1 = (($$01) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  __ZN10MemoryPool10DeallocateEPv($this,$$01);
  $3 = ($2|0)==(0|0);
  if ($3) {
   break;
  } else {
   $$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12EventManager8HasEventEP10EventEntryPFvPvS2_iEPKv($index,$callback,$userData) {
 $index = $index|0;
 $callback = $callback|0;
 $userData = $userData|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $curIndex$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($index|0)==(0|0);
 L1: do {
  if ($0) {
   $$0 = 0;
  } else {
   $curIndex$01 = $index;
   while(1) {
    $1 = (($curIndex$01) + 8|0);
    $2 = HEAP32[$1>>2]|0;
    $3 = ($2|0)==($callback|0);
    if ($3) {
     $4 = HEAP32[$curIndex$01>>2]|0;
     $5 = ($4|0)==($userData|0);
     if ($5) {
      $$0 = 1;
      break L1;
     }
    }
    $6 = (($curIndex$01) + 4|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $$0 = 0;
     break;
    } else {
     $curIndex$01 = $7;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN12EventManager11RemoveEventEP10EventEntryPFvPvS2_iES2_($this,$index,$callback,$userData) {
 $this = $this|0;
 $index = $index|0;
 $callback = $callback|0;
 $userData = $userData|0;
 var $$0 = 0, $$index = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curEvent$04 = 0, $previousIndex$03 = 0, $previousIndex$03$phi = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($index|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $curEvent$04 = $index;$previousIndex$03 = 0;
 }
 while(1) {
  $1 = (($curEvent$04) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==($callback|0);
  if ($3) {
   $4 = HEAP32[$curEvent$04>>2]|0;
   $5 = ($4|0)==($userData|0);
   if ($5) {
    break;
   }
  }
  $11 = (($curEvent$04) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $$0 = $index;
   label = 8;
   break;
  } else {
   $previousIndex$03$phi = $curEvent$04;$curEvent$04 = $12;$previousIndex$03 = $previousIndex$03$phi;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($curEvent$04) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN10MemoryPool10DeallocateEPv($this,$curEvent$04);
 $8 = ($previousIndex$03|0)==(0|0);
 if (!($8)) {
  $9 = (($previousIndex$03) + 4|0);
  HEAP32[$9>>2] = $7;
 }
 $10 = ($curEvent$04|0)==($index|0);
 $$index = $10 ? $7 : $index;
 $$0 = $$index;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12EventManager11InvokeEventEP10EventEntryPvi($index,$senderUserData,$eventType) {
 $index = $index|0;
 $senderUserData = $senderUserData|0;
 $eventType = $eventType|0;
 var $$01 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($index|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $$01 = $index;
 }
 while(1) {
  $1 = (($$01) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($$01) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$$01>>2]|0;
  FUNCTION_TABLE_viii[$4 & 4095]($5,$senderUserData,$eventType);
  $6 = ($2|0)==(0|0);
  if ($6) {
   break;
  } else {
   $$01 = $2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11GameManager15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11GameManager17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$01 = 0;
 while(1) {
  $0 = (__Z17GetManagerContextv()|0);
  $1 = (($0) + ($i$01<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==($this|0);
  if ($3) {
   __Z22SetManagerPtrInContextiP6Object($i$01,0);
  }
  $4 = (($i$01) + 1)|0;
  $exitcond = ($4|0)==(20);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK17GlobalGameManager7GetNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6Object12GetClassNameEv($this)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
  STACKTOP = sp;return ($7|0);
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
  STACKTOP = sp;return ($7|0);
 }
 return 0|0;
}
function __Z22GetGameManagerIfExistsi($index) {
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24GetManagerPtrFromContexti($index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN16LevelGameManagerC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN6ObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((561080 + 8|0));
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN6ObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((561192 + 8|0));
 STACKTOP = sp;return;
}
function __Z30RegisterClass_LevelGameManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(3,78,0,0,0);
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(9)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11GameManager13RegisterClassEv();
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 16;
 dest=$3+0|0; src=561304+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 16|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,3,9,($0|0),24,(2350|0),1,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN11GameManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(0)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN6Object13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 11;
 dest=$3+0|0; src=561352+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 11|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,9,0,($0|0),24,(2351|0),1,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN16LevelGameManager7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK16LevelGameManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 3;
}
function __ZN17GlobalGameManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(9)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11GameManager13RegisterClassEv();
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 17;
 dest=$3+0|0; src=561328+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 17|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,6,9,($0|0),24,(2352|0),1,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN17GlobalGameManager7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK17GlobalGameManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 6;
}
function __Z25RegisterClass_GameManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(9,79,0,0,0);
 STACKTOP = sp;return;
}
function __ZN11GameManager7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK11GameManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 9;
}
function __ZN16LevelGameManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,561368,561304,$this,0);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,561368,561304,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,561368,561328,$this,0);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,561368,561328,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11GameManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561376 + 8|0));
 STACKTOP = sp;return;
}
function __ZN11GameManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN11GameManager24NetworkOnApplicationQuitEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11GameManager13NetworkUpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561376 + 8|0));
 STACKTOP = sp;return;
}
function __ZN16LevelGameManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK16LevelGameManager7GetNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6Object12GetClassNameEv($this)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
  STACKTOP = sp;return ($7|0);
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
  STACKTOP = sp;return ($7|0);
 }
 return 0|0;
}
function __ZNK16LevelGameManager19ShouldWriteForBuildEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN17GlobalGameManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561376 + 8|0));
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5Unity10GameObject8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phi4Z2D = 0, $$pre$phiZ2D = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $p$i$i$i = 0, $p$i$i$i2 = 0, $size$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i1 = sp;
 $p$i$i$i2 = sp + 24|0;
 $p$i$i$i = sp + 16|0;
 __ZN13ProxyTransfer10SetVersionEi($transfer,4);
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($this) + 24|0);
  $4 = HEAP32[580760>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562376,$4,$3,65601);
  HEAP32[$p$i$i$i>>2] = 0;
  $5 = (($p$i$i$i) + 4|0);
  HEAP32[$5>>2] = 0;
  __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,562392,562392,$p$i$i$i2,0);
  $6 = HEAP32[580608>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562368,$6,$p$i$i$i,0);
  $7 = HEAP32[580576>>2]|0;
  $8 = HEAP32[580592>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$7,$8,$p$i$i$i,0);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($11) + (($13*24)|0)|0) + 12|0);
  HEAP32[$14>>2] = 4;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $15 = (($p$i$i$i) + 4|0);
  $16 = HEAP32[580656>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$16,562400,$15,0);
  $17 = (($size$i$i$i$i1) + 8|0);
  $18 = $17;
  $19 = $18;
  HEAP32[$19>>2] = 0;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = 0;
  HEAP32[$size$i$i$i$i1>>2] = 0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562312,$8,$size$i$i$i$i1,1);
  $22 = HEAP32[$9>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$12>>2]|0;
  $25 = ((($23) + (($24*24)|0)|0) + 12|0);
  HEAP32[$25>>2] = 4;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $26 = HEAP32[580688>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562328,$26,$17,1);
  $27 = HEAP32[$9>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$12>>2]|0;
  $30 = ((($28) + (($29*24)|0)|0) + 12|0);
  HEAP32[$30>>2] = 8;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $$pre$phi4Z2D = $12;$$pre$phiZ2D = $9;
 } else {
  $$pre = (($transfer) + 12|0);
  $$pre3 = (($transfer) + 20|0);
  $$pre$phi4Z2D = $$pre3;$$pre$phiZ2D = $$pre;
 }
 $31 = (($this) + 40|0);
 $32 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,561488,$32,$31,0);
 $33 = HEAP32[$$pre$phiZ2D>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $37 = (($this) + 56|0);
 $38 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,561496,$38,$37,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,562392,562392,$size$i$i$i$i1,1);
 $39 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562368,$39,$p$i$i$i2,0);
 $40 = HEAP32[$$pre$phiZ2D>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = (($this) + 44|0);
 $45 = HEAP32[580720>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,561504,$45,$44,0);
 $46 = HEAP32[$$pre$phiZ2D>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $49 = ((($47) + (($48*24)|0)|0) + 12|0);
 HEAP32[$49>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $50 = (($this) + 46|0);
 $51 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,561512,$51,$50,0);
 $52 = HEAP32[$$pre$phiZ2D>>2]|0;
 $53 = HEAP32[$52>>2]|0;
 $54 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $55 = ((($53) + (($54*24)|0)|0) + 12|0);
 HEAP32[$55>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $converter$i$i$i = 0, $tempStr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 28|0;
 $0 = sp;
 $tempStr$i = sp + 4|0;
 $1 = sp + 16|0;
 $converter$i$i = sp + 20|0;
 $converter$i$i$i = sp + 24|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,4);
 $2 = HEAP32[$transfer>>2]|0;
 $3 = $2 & 16384;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($this) + 24|0);
  $6 = HEAP32[580760>>2]|0;
  $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,562376,$6,$converter$i$i$i,1)|0);
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = ($7|0)>(0);
   if ($9) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEEEvRT_17TransferMetaFlags($transfer,$5,0);
   } else {
    $10 = HEAP32[$converter$i$i$i>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     (FUNCTION_TABLE_iii[$10 & 4095]($5,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 }
 $12 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$12,561488,0);
 $13 = (($this) + 56|0);
 $14 = HEAP32[580712>>2]|0;
 $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,561496,$14,$converter$i$i,1)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = ($15|0)>(0);
  do {
   if ($17) {
    ;HEAP32[$tempStr$i+0>>2]=0|0;HEAP32[$tempStr$i+4>>2]=0|0;HEAP32[$tempStr$i+8>>2]=0|0;
    __THREW__ = 0;
    invoke_viii(1620,($transfer|0),($tempStr$i|0),0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $31 = HEAP8[$tempStr$i>>0]|0;
     $32 = $31 & 1;
     $33 = ($32<<24>>24)==(0);
     if ($33) {
      $36 = (($tempStr$i) + 1|0);
      $38 = $36;
     } else {
      $34 = (($tempStr$i) + 8|0);
      $35 = HEAP32[$34>>2]|0;
      $38 = $35;
     }
     $37 = HEAP32[628448>>2]|0;
     HEAP32[$1>>2] = $37;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_viii(1621,($13|0),($38|0),($$byval_copy2|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = HEAP8[$tempStr$i>>0]|0;
      $42 = $41 & 1;
      $43 = ($42<<24>>24)==(0);
      if ($43) {
       break;
      }
      $44 = (($tempStr$i) + 8|0);
      $45 = HEAP32[$44>>2]|0;
      HEAP32[$0>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($45|0),($$byval_copy2|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       break;
      }
      $48 = ___cxa_find_matching_catch()|0;
      $49 = tempRet0;
      ___cxa_call_unexpected(($48|0));
      // unreachable;
     }
    }
    $20 = ___cxa_find_matching_catch()|0;
    $21 = tempRet0;
    $22 = HEAP8[$tempStr$i>>0]|0;
    $23 = $22 & 1;
    $24 = ($23<<24>>24)==(0);
    if ($24) {
     ___resumeException($20|0);
     // unreachable;
    }
    $25 = (($tempStr$i) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($26|0),($$byval_copy2|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $29 = ___cxa_find_matching_catch()|0;
     $30 = tempRet0;
     ___cxa_call_unexpected(($29|0));
     // unreachable;
    } else {
     ___resumeException($20|0);
     // unreachable;
    }
   } else {
    $50 = HEAP32[$converter$i$i>>2]|0;
    $51 = ($50|0)==(0|0);
    if (!($51)) {
     (FUNCTION_TABLE_iii[$50 & 4095]($13,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $52 = (($this) + 44|0);
 $53 = HEAP32[580720>>2]|0;
 $54 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,561504,$53,$$byval_copy2,0)|0);
 $55 = ($54|0)==(0);
 if (!($55)) {
  $56 = ($54|0)>(0);
  if ($56) {
   $57 = (($transfer) + 12|0);
   $58 = (($transfer) + 80|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 12|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($transfer) + 16|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($transfer) + 28|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($transfer) + 32|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = Math_imul($67, $65)|0;
   $$sum$i$i$i = (($61) - ($68))|0;
   $69 = (($63) + ($$sum$i$i$i)|0);
   HEAP32[$57>>2] = $69;
   $70 = ($$sum$i$i$i|0)<(0);
   if ($70) {
    label = 30;
   } else {
    $$sum1$i$i$i = (($$sum$i$i$i) + 2)|0;
    $71 = (($63) + ($$sum1$i$i$i)|0);
    $72 = (($transfer) + 20|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($71>>>0)>($73>>>0);
    if ($74) {
     label = 30;
    } else {
     $75 = HEAP16[$69>>1]|0;
     HEAP16[$52>>1] = $75;
     HEAP32[$57>>2] = $71;
    }
   }
   if ((label|0) == 30) {
    __ZN12CachedReader15UpdateReadCacheEPvj($57,$52,2);
   }
   $76 = HEAP32[$transfer>>2]|0;
   $77 = $76 & 512;
   $78 = ($77|0)==(0);
   if (!($78)) {
    $79 = HEAP16[$52>>1]|0;
    $80 = $79&65535;
    $81 = $80 << 8;
    $82 = $80 >>> 8;
    $83 = $81 | $82;
    $84 = $83&65535;
    HEAP16[$52>>1] = $84;
   }
  } else {
   $85 = HEAP32[$$byval_copy2>>2]|0;
   $86 = ($85|0)==(0|0);
   if (!($86)) {
    (FUNCTION_TABLE_iii[$85 & 4095]($52,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $87 = (($this) + 46|0);
 $88 = HEAP32[580544>>2]|0;
 $89 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,561512,$88,$$byval_copy2,0)|0);
 $90 = ($89|0)==(0);
 if (!($90)) {
  $91 = ($89|0)>(0);
  do {
   if ($91) {
    $92 = (($transfer) + 12|0);
    $93 = (($transfer) + 80|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($94) + 12|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($transfer) + 16|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (($transfer) + 28|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($transfer) + 32|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = Math_imul($102, $100)|0;
    $$sum$i$i$i$i$i = (($96) - ($103))|0;
    $104 = (($98) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$92>>2] = $104;
    $105 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($105)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $106 = (($98) + ($$sum1$i$i$i$i$i)|0);
     $107 = (($transfer) + 20|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = ($106>>>0)>($108>>>0);
     if (!($109)) {
      $110 = HEAP8[$104>>0]|0;
      HEAP8[$87>>0] = $110;
      $111 = HEAP32[$92>>2]|0;
      $112 = (($111) + 1|0);
      HEAP32[$92>>2] = $112;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($92,$87,1);
   } else {
    $113 = HEAP32[$$byval_copy2>>2]|0;
    $114 = ($113|0)==(0|0);
    if (!($114)) {
     (FUNCTION_TABLE_iii[$113 & 4095]($87,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $115 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,3)|0);
 if (!($115)) {
  STACKTOP = sp;return;
 }
 $116 = (($this) + 8|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = $117 & 1048576;
 $119 = ($118|0)==(0);
 if ($119) {
  STACKTOP = sp;return;
 }
 HEAP8[$87>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580752>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  $5 = (($this) + 12|0);
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $13)|0;
  $$sum$i$i$i = (($9) - ($16))|0;
  $17 = (($11) + ($$sum$i$i$i)|0);
  HEAP32[$5>>2] = $17;
  $18 = ($$sum$i$i$i|0)<(0);
  if ($18) {
   label = 6;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
   $19 = (($11) + ($$sum1$i$i$i)|0);
   $20 = (($this) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19>>>0)>($21>>>0);
   if ($22) {
    label = 6;
   } else {
    $23 = HEAP32[$17>>2]|0;
    HEAP32[$data>>2] = $23;
    HEAP32[$5>>2] = $19;
   }
  }
  if ((label|0) == 6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,4);
  }
  $24 = HEAP32[$this>>2]|0;
  $25 = $24 & 512;
  $26 = ($25|0)==(0);
  if (!($26)) {
   $27 = HEAP32[$data>>2]|0;
   $28 = (_llvm_bswap_i32(($27|0))|0);
   HEAP32[$data>>2] = $28;
  }
 } else {
  $29 = HEAP32[$converter$i>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   (FUNCTION_TABLE_iii[$29 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $1 = sp + 16|0;
 $2 = HEAP32[$transfer>>2]|0;
 $3 = $2 & 16384;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($this) + 24|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEEEvRT_17TransferMetaFlags($transfer,$5,0);
 }
 $6 = (($this) + 40|0);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($7,$6,4);
 } else {
  $13 = HEAP32[$8>>2]|0;
  HEAP32[$6>>2] = $13;
  HEAP32[$7>>2] = $9;
 }
 $14 = (($this) + 56|0);
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1622,($transfer|0),($tempStr$i$i|0),0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  __THREW__ = 0;
  invoke_vi(3376,($transfer|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   $30 = HEAP8[$tempStr$i$i>>0]|0;
   $31 = $30 & 1;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $35 = (($tempStr$i$i) + 1|0);
    $37 = $35;
   } else {
    $33 = (($tempStr$i$i) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $37 = $34;
   }
   $36 = HEAP32[628448>>2]|0;
   HEAP32[$1>>2] = $36;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1621,($14|0),($37|0),($$byval_copy2|0));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    $40 = HEAP8[$tempStr$i$i>>0]|0;
    $41 = $40 & 1;
    $42 = ($41<<24>>24)==(0);
    if (!($42)) {
     $43 = (($tempStr$i$i) + 8|0);
     $44 = HEAP32[$43>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($44|0),($$byval_copy2|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      $47 = ___cxa_find_matching_catch()|0;
      $48 = tempRet0;
      ___cxa_call_unexpected(($47|0));
      // unreachable;
     }
    }
    $49 = (($this) + 44|0);
    $50 = HEAP32[$7>>2]|0;
    $51 = (($50) + 2|0);
    $52 = HEAP32[$10>>2]|0;
    $53 = ($51>>>0)>($52>>>0);
    if ($53) {
     __ZN12CachedReader15UpdateReadCacheEPvj($7,$49,2);
     $$pre = HEAP32[$7>>2]|0;
     $$pre1 = HEAP32[$10>>2]|0;
     $57 = $$pre;$59 = $$pre1;
    } else {
     $54 = HEAP16[$50>>1]|0;
     HEAP16[$49>>1] = $54;
     HEAP32[$7>>2] = $51;
     $57 = $51;$59 = $52;
    }
    $55 = (($this) + 46|0);
    $56 = (($57) + 1|0);
    $58 = ($56>>>0)>($59>>>0);
    if ($58) {
     __ZN12CachedReader15UpdateReadCacheEPvj($7,$55,1);
     STACKTOP = sp;return;
    } else {
     $60 = HEAP8[$57>>0]|0;
     HEAP8[$55>>0] = $60;
     $61 = HEAP32[$7>>2]|0;
     $62 = (($61) + 1|0);
     HEAP32[$7>>2] = $62;
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $19 = HEAP8[$tempStr$i$i>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  ___resumeException($17|0);
  // unreachable;
 }
 $22 = (($tempStr$i$i) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($23|0),($$byval_copy2|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  ___cxa_call_unexpected(($26|0));
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN5Unity10GameObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $1 = sp + 16|0;
 $2 = HEAP32[$transfer>>2]|0;
 $3 = $2 & 16384;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($this) + 24|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEEEvRT_17TransferMetaFlags($transfer,$5,0);
 }
 $6 = (($this) + 40|0);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($7,$6,4);
  $$pre$i$i$i = HEAP32[$6>>2]|0;
  $14 = $$pre$i$i$i;
 } else {
  $13 = HEAP32[$8>>2]|0;
  HEAP32[$6>>2] = $13;
  HEAP32[$7>>2] = $9;
  $14 = $13;
 }
 $15 = (_llvm_bswap_i32(($14|0))|0);
 HEAP32[$6>>2] = $15;
 $16 = (($this) + 56|0);
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1623,($transfer|0),($tempStr$i$i|0),0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  __THREW__ = 0;
  invoke_vi(3377,($transfer|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if (!($31)) {
   $32 = HEAP8[$tempStr$i$i>>0]|0;
   $33 = $32 & 1;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    $37 = (($tempStr$i$i) + 1|0);
    $39 = $37;
   } else {
    $35 = (($tempStr$i$i) + 8|0);
    $36 = HEAP32[$35>>2]|0;
    $39 = $36;
   }
   $38 = HEAP32[628448>>2]|0;
   HEAP32[$1>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1621,($16|0),($39|0),($$byval_copy2|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    $42 = HEAP8[$tempStr$i$i>>0]|0;
    $43 = $42 & 1;
    $44 = ($43<<24>>24)==(0);
    if (!($44)) {
     $45 = (($tempStr$i$i) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($46|0),($$byval_copy2|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $49 = ___cxa_find_matching_catch()|0;
      $50 = tempRet0;
      ___cxa_call_unexpected(($49|0));
      // unreachable;
     }
    }
    $51 = (($this) + 44|0);
    $52 = HEAP32[$7>>2]|0;
    $53 = (($52) + 2|0);
    $54 = HEAP32[$10>>2]|0;
    $55 = ($53>>>0)>($54>>>0);
    if ($55) {
     __ZN12CachedReader15UpdateReadCacheEPvj($7,$51,2);
     $$pre$i$i$i1 = HEAP16[$51>>1]|0;
     $$pre = HEAP32[$7>>2]|0;
     $$pre2 = HEAP32[$10>>2]|0;
     $58 = $$pre$i$i$i1;$65 = $$pre;$67 = $$pre2;
    } else {
     $56 = HEAP16[$52>>1]|0;
     HEAP16[$51>>1] = $56;
     HEAP32[$7>>2] = $53;
     $58 = $56;$65 = $53;$67 = $54;
    }
    $57 = $58&65535;
    $59 = $57 << 8;
    $60 = $57 >>> 8;
    $61 = $59 | $60;
    $62 = $61&65535;
    HEAP16[$51>>1] = $62;
    $63 = (($this) + 46|0);
    $64 = (($65) + 1|0);
    $66 = ($64>>>0)>($67>>>0);
    if ($66) {
     __ZN12CachedReader15UpdateReadCacheEPvj($7,$63,1);
     STACKTOP = sp;return;
    } else {
     $68 = HEAP8[$65>>0]|0;
     HEAP8[$63>>0] = $68;
     $69 = HEAP32[$7>>2]|0;
     $70 = (($69) + 1|0);
     HEAP32[$7>>2] = $70;
     STACKTOP = sp;return;
    }
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $21 = HEAP8[$tempStr$i$i>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  ___resumeException($19|0);
  // unreachable;
 }
 $24 = (($tempStr$i$i) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy2|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  ___cxa_call_unexpected(($28|0));
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN5Unity10GameObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$phi4Z2D = 0, $$pre$phi6Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre2 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0;
 var $9 = 0, $i$01$i$i$i = 0, $size$i$i$i = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $size$i$i$i = sp + 16|0;
 $1 = HEAP32[$transfer>>2]|0;
 $2 = $1 & 16384;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  HEAP32[$size$i$i$i>>2] = $5;
  $6 = (($transfer) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 4|0);
  $9 = (($transfer) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8>>>0)<($10>>>0);
  if ($11) {
   HEAP32[$7>>2] = $5;
   HEAP32[$6>>2] = $8;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$size$i$i$i,4);
  }
  $12 = (($this) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$4>>2]|0;
  $15 = (($13) + ($14<<3)|0);
  $16 = ($14|0)==(0);
  if ($16) {
   $$pre$phi4Z2D = $6;$$pre$phi6Z2D = $9;$$pre$phiZ2D = $6;
  } else {
   $i$01$i$i$i = $13;
   while(1) {
    $17 = HEAP32[$6>>2]|0;
    $18 = (($17) + 4|0);
    $19 = HEAP32[$9>>2]|0;
    $20 = ($18>>>0)<($19>>>0);
    if ($20) {
     $21 = HEAP32[$i$01$i$i$i>>2]|0;
     HEAP32[$17>>2] = $21;
     HEAP32[$6>>2] = $18;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$i$01$i$i$i,4);
    }
    $22 = (($i$01$i$i$i) + 4|0);
    __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($22,$transfer);
    $23 = (($i$01$i$i$i) + 8|0);
    $24 = ($23|0)==($15|0);
    if ($24) {
     $$pre$phi4Z2D = $6;$$pre$phi6Z2D = $9;$$pre$phiZ2D = $6;
     break;
    } else {
     $i$01$i$i$i = $23;
    }
   }
  }
 } else {
  $$pre2 = (($transfer) + 12|0);
  $$pre5 = (($transfer) + 20|0);
  $$pre$phi4Z2D = $$pre2;$$pre$phi6Z2D = $$pre5;$$pre$phiZ2D = $$pre2;
 }
 $25 = (($this) + 40|0);
 $26 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$$pre$phi6Z2D>>2]|0;
 $29 = ($27>>>0)<($28>>>0);
 if ($29) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$26>>2] = $30;
  HEAP32[$$pre$phi4Z2D>>2] = $27;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($$pre$phiZ2D,$25,4);
 }
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 $31 = (($this) + 56|0);
 $32 = HEAP32[$31>>2]|0;
 __THREW__ = 0;
 (invoke_iii(2353,($tempStr$i$i|0),($32|0))|0);
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if (!($34)) {
  __THREW__ = 0;
  invoke_viii(1624,($transfer|0),($tempStr$i$i|0),0);
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if (!($47)) {
   __THREW__ = 0;
   invoke_vi(3378,($transfer|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    $50 = HEAP8[$tempStr$i$i>>0]|0;
    $51 = $50 & 1;
    $52 = ($51<<24>>24)==(0);
    if (!($52)) {
     $53 = (($tempStr$i$i) + 8|0);
     $54 = HEAP32[$53>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($54|0),($$byval_copy1|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      $57 = ___cxa_find_matching_catch()|0;
      $58 = tempRet0;
      ___cxa_call_unexpected(($57|0));
      // unreachable;
     }
    }
    $59 = (($this) + 44|0);
    $60 = HEAP32[$$pre$phi4Z2D>>2]|0;
    $61 = (($60) + 2|0);
    $62 = HEAP32[$$pre$phi6Z2D>>2]|0;
    $63 = ($61>>>0)<($62>>>0);
    if ($63) {
     $64 = HEAP16[$59>>1]|0;
     HEAP16[$60>>1] = $64;
     HEAP32[$$pre$phi4Z2D>>2] = $61;
     $67 = $61;$69 = $62;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($$pre$phiZ2D,$59,2);
     $$pre = HEAP32[$$pre$phi4Z2D>>2]|0;
     $$pre1 = HEAP32[$$pre$phi6Z2D>>2]|0;
     $67 = $$pre;$69 = $$pre1;
    }
    $65 = (($this) + 46|0);
    $66 = (($67) + 1|0);
    $68 = ($66>>>0)<($69>>>0);
    if ($68) {
     $70 = HEAP8[$65>>0]|0;
     HEAP8[$67>>0] = $70;
     $71 = HEAP32[$$pre$phi4Z2D>>2]|0;
     $72 = (($71) + 1|0);
     HEAP32[$$pre$phi4Z2D>>2] = $72;
     STACKTOP = sp;return;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($$pre$phiZ2D,$65,1);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 $37 = HEAP8[$tempStr$i$i>>0]|0;
 $38 = $37 & 1;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  ___resumeException($35|0);
  // unreachable;
 }
 $40 = (($tempStr$i$i) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy1|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 } else {
  ___resumeException($35|0);
  // unreachable;
 }
}
function __ZN5Unity10GameObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$i4$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,65601);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<3)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $9 = (($transfer) + 12|0);
  $10 = (($transfer) + 28|0);
  $11 = (($transfer) + 32|0);
  $i$01$i$i2$i$i = $4;
  while(1) {
   $12 = (($i$01$i$i2$i$i) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$0$i$i$i$i$i$i4$i$i = 0;
   } else {
    $15 = (($13) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $$0$i$i$i$i$i$i4$i$i = $16;
   }
   $17 = HEAP32[$9>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$10>>2]|0;
   $21 = (FUNCTION_TABLE_iiii[$19 & 2047]($17,$$0$i$i$i$i$i$i4$i$i,$20)|0);
   $22 = HEAP8[$11>>0]|0;
   $23 = ($22<<24>>24)==(0);
   if (!($23)) {
    $24 = (__Z38PreallocateObjectFromPersistentManagerib($21,0)|0);
    HEAP32[$12>>2] = $24;
   }
   $25 = (($i$01$i$i2$i$i) + 8|0);
   $26 = ($25|0)==($7|0);
   if ($26) {
    break;
   } else {
    $i$01$i$i2$i$i = $25;
   }
  }
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $localIdentifier$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,561528,562344,$3,65601);
 $4 = (($localIdentifier$i$i$i) + 8|0);
 $5 = $4;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $9 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562312,$9,$localIdentifier$i$i$i,1);
 $10 = (($transfer) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($transfer) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($12) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562328,$16,$4,1);
 $17 = HEAP32[$10>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$13>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,561528,562344,$converter$i$i,1)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ($4|0)>(0);
 if ($6) {
  __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI14SafeBinaryReadEEvRT_($3,$transfer);
 } else {
  $7 = HEAP32[$converter$i$i>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   (FUNCTION_TABLE_iii[$7 & 4095]($3,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($3,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($3,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($3,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,65601);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0$i$i$i = 0;
 } else {
  $6 = (($4) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $$0$i$i$i = $7;
 }
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($transfer) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiii[$11 & 2047]($9,$$0$i$i$i,$13)|0);
 $15 = (($transfer) + 32|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if (!($17)) {
  $18 = (__Z38PreallocateObjectFromPersistentManagerib($14,0)|0);
  HEAP32[$3>>2] = $18;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObjectC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy6 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN6ObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy6,$mode);
 HEAP32[$this>>2] = ((561552 + 8|0));
 $2 = (($this) + 24|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 28|0);
 HEAP32[$3>>2] = $1;
 $4 = (($this) + 32|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 56|0);
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 invoke_vi(3379,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = (($this) + 60|0);
  HEAP32[$9>>2] = 0;
  $10 = (($this) + 64|0);
  HEAP32[$10>>2] = 0;
  $11 = (($this) + 68|0);
  HEAP32[$11>>2] = $this;
  $12 = (($this) + 52|0);
  HEAP32[$12>>2] = 0;
  $13 = (($this) + 48|0);
  HEAP8[$13>>0] = 0;
  $14 = (($this) + 49|0);
  HEAP8[$14>>0] = 0;
  $15 = (($this) + 44|0);
  HEAP16[$15>>1] = 0;
  $16 = (($this) + 46|0);
  HEAP8[$16>>0] = 0;
  $17 = (($this) + 47|0);
  HEAP8[$17>>0] = -1;
  STACKTOP = sp;return;
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $20 = HEAP32[$5>>2]|0;
 $21 = ($20|0)>(-1);
 if ($21) {
  $22 = HEAP32[$2>>2]|0;
  $23 = HEAP32[$3>>2]|0;
  HEAP32[$0>>2] = $23;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($22|0),($$byval_copy6|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   HEAP32[$2>>2] = 0;
   label = 6;
  }
 } else {
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    ___resumeException($18|0);
    // unreachable;
   }
   $30 = ___cxa_find_matching_catch(0|0)|0;
   $31 = tempRet0;
   __THREW__ = 0;
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $34 = ___cxa_find_matching_catch(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $30;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 $36 = ___cxa_find_matching_catch(0|0)|0;
 $37 = tempRet0;
 $eh$lpad$body$indexZ2D = $36;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN5Unity10GameObject5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 44|0);
 HEAP16[$1>>1] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject21WillDestroyGameObjectEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAP8[$0>>0] = 1;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + ($4<<3)|0);
 $6 = ($4|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $2;
 }
 while(1) {
  $7 = (($i$01) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 100|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($8);
  $12 = (($i$01) + 8|0);
  $13 = ($12|0)==($5|0);
  if ($13) {
   break;
  } else {
   $i$01 = $12;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$pre$i = 0, $$pre$i$i = 0, $$pre2$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $i$01$i$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 $2 = (($this) + 48|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  HEAP32[$0>>2] = 0;
  $5 = (($this) + 24|0);
  $6 = (($this) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = HEAP32[$5>>2]|0;
   $40 = 0;$41 = $7;$42 = $9;$i$01$i$i = $9;
   while(1) {
    $10 = (($i$01$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $21 = $42;$22 = $41;$25 = $40;
    } else {
     $13 = HEAP32[$11>>2]|0;
     $14 = (($13) + 92|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (FUNCTION_TABLE_ii[$15 & 4095]($11)|0);
     $17 = HEAP32[$0>>2]|0;
     $18 = $17 | $16;
     HEAP32[$0>>2] = $18;
     $$pre$i$i = HEAP32[$5>>2]|0;
     $$pre2$i$i = HEAP32[$6>>2]|0;
     $21 = $$pre$i$i;$22 = $$pre2$i$i;$25 = $18;
    }
    $19 = (($i$01$i$i) + 8|0);
    $20 = (($21) + ($22<<3)|0);
    $23 = ($19|0)==($20|0);
    if ($23) {
     break;
    } else {
     $40 = $25;$41 = $22;$42 = $21;$i$01$i$i = $19;
    }
   }
   $24 = ($1|0)==($25|0);
   $26 = ($22|0)==(0);
   $or$cond$i = $24 | $26;
   if (!($or$cond$i)) {
    $43 = $22;$44 = $21;$i$01$i = $21;
    while(1) {
     $27 = (($i$01$i) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==(0|0);
     if ($29) {
      $36 = $44;$37 = $43;
     } else {
      $30 = HEAP32[$28>>2]|0;
      $31 = (($30) + 96|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = HEAP32[$0>>2]|0;
      FUNCTION_TABLE_vii[$32 & 4095]($28,$33);
      $$pre$i = HEAP32[$5>>2]|0;
      $$pre2$i = HEAP32[$6>>2]|0;
      $36 = $$pre$i;$37 = $$pre2$i;
     }
     $34 = (($i$01$i) + 8|0);
     $35 = (($36) + ($37<<3)|0);
     $38 = ($34|0)==($35|0);
     if ($38) {
      break;
     } else {
      $43 = $37;$44 = $36;$i$01$i = $34;
     }
    }
   }
  }
 }
 __ZN5Unity10GameObject18UpdateActiveGONodeEv($this);
 $39 = (0|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 abort /* segfault, call an absolute addr */ (($this|0));
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject25SetSupportedMessagesDirtyEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i = 0, $$pre2 = 0, $$pre2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$01$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 $2 = (($this) + 48|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 0;
 $5 = (($this) + 24|0);
 $6 = (($this) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $25 = 0;$27 = 0;
 } else {
  $9 = HEAP32[$5>>2]|0;
  $41 = 0;$42 = $7;$43 = $9;$i$01$i = $9;
  while(1) {
   $10 = (($i$01$i) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $21 = $43;$22 = $42;$44 = $41;
   } else {
    $13 = HEAP32[$11>>2]|0;
    $14 = (($13) + 92|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (FUNCTION_TABLE_ii[$15 & 4095]($11)|0);
    $17 = HEAP32[$0>>2]|0;
    $18 = $17 | $16;
    HEAP32[$0>>2] = $18;
    $$pre$i = HEAP32[$5>>2]|0;
    $$pre2$i = HEAP32[$6>>2]|0;
    $21 = $$pre$i;$22 = $$pre2$i;$44 = $18;
   }
   $19 = (($i$01$i) + 8|0);
   $20 = (($21) + ($22<<3)|0);
   $23 = ($19|0)==($20|0);
   if ($23) {
    $25 = $44;$27 = $22;
    break;
   } else {
    $41 = $44;$42 = $22;$43 = $21;$i$01$i = $19;
   }
  }
 }
 $24 = ($1|0)==($25|0);
 $26 = ($27|0)==(0);
 $or$cond = $24 | $26;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $28 = HEAP32[$5>>2]|0;
 $45 = $27;$46 = $28;$i$01 = $28;
 while(1) {
  $29 = (($i$01) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   $38 = $46;$39 = $45;
  } else {
   $32 = HEAP32[$30>>2]|0;
   $33 = (($32) + 96|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$0>>2]|0;
   FUNCTION_TABLE_vii[$34 & 4095]($30,$35);
   $$pre = HEAP32[$5>>2]|0;
   $$pre2 = HEAP32[$6>>2]|0;
   $38 = $$pre;$39 = $$pre2;
  }
  $36 = (($i$01) + 8|0);
  $37 = (($38) + ($39<<3)|0);
  $40 = ($36|0)==($37|0);
  if ($40) {
   break;
  } else {
   $45 = $39;$46 = $38;$i$01 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject18UpdateActiveGONodeEv($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $$pre$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 64|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (__ZNK5Unity10GameObject8IsActiveEv($this)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 44|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = ($10<<16>>16)==(0);
 $12 = HEAP32[562264>>2]|0;
 if ($11) {
  $23 = (($12) + 8|0);
  $24 = ($0|0)==($23|0);
  if ($24) {
   STACKTOP = sp;return;
  }
  $25 = HEAP32[$0>>2]|0;
  $26 = ($25|0)==(0|0);
  $$pre$i$i = (($this) + 64|0);
  if (!($26)) {
   $27 = HEAP32[$$pre$i$i>>2]|0;
   $28 = (($25) + 4|0);
   HEAP32[$28>>2] = $27;
   $29 = HEAP32[$0>>2]|0;
   $30 = HEAP32[$$pre$i$i>>2]|0;
   HEAP32[$30>>2] = $29;
   HEAP32[$0>>2] = 0;
   HEAP32[$$pre$i$i>>2] = 0;
  }
  $31 = HEAP32[$23>>2]|0;
  HEAP32[$0>>2] = $31;
  HEAP32[$$pre$i$i>>2] = $23;
  $32 = (($31) + 4|0);
  HEAP32[$32>>2] = $0;
  $33 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$33>>2] = $0;
  STACKTOP = sp;return;
 } else {
  $13 = ($0|0)==($12|0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = HEAP32[$0>>2]|0;
  $15 = ($14|0)==(0|0);
  $$pre$i$i1 = (($this) + 64|0);
  if (!($15)) {
   $16 = HEAP32[$$pre$i$i1>>2]|0;
   $17 = (($14) + 4|0);
   HEAP32[$17>>2] = $16;
   $18 = HEAP32[$0>>2]|0;
   $19 = HEAP32[$$pre$i$i1>>2]|0;
   HEAP32[$19>>2] = $18;
   HEAP32[$0>>2] = 0;
   HEAP32[$$pre$i$i1>>2] = 0;
  }
  $20 = HEAP32[$12>>2]|0;
  HEAP32[$0>>2] = $20;
  HEAP32[$$pre$i$i1>>2] = $12;
  $21 = (($20) + 4|0);
  HEAP32[$21>>2] = $0;
  $22 = HEAP32[$$pre$i$i1>>2]|0;
  HEAP32[$22>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __ZNK5Unity10GameObject22CountDerivedComponentsEi($this,$compareClassID) {
 $this = $this|0;
 $compareClassID = $compareClassID|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$0$lcssa = 0, $count$01 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $count$0$lcssa = 0;
  STACKTOP = sp;return ($count$0$lcssa|0);
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[560640>>2]|0;
 $6 = HEAP32[560632>>2]|0;
 $7 = (($4) + ($1<<3)|0);
 $count$01 = 0;$i$02 = $4;
 while(1) {
  $8 = HEAP32[$i$02>>2]|0;
  $9 = Math_imul($5, $8)|0;
  $10 = (($9) + ($compareClassID))|0;
  $11 = $10 >> 5;
  $12 = $11 << 5;
  $13 = (($10) - ($12))|0;
  $14 = (($6) + ($11<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = 1 << $13;
  $17 = $16 & $15;
  $18 = ($17|0)!=(0);
  $19 = $18&1;
  $20 = (($19) + ($count$01))|0;
  $21 = (($i$02) + 8|0);
  $22 = ($21|0)==($7|0);
  if ($22) {
   $count$0$lcssa = $20;
   break;
  } else {
   $count$01 = $20;$i$02 = $21;
  }
 }
 STACKTOP = sp;return ($count$0$lcssa|0);
}
function __ZNK5Unity10GameObject27FindConflictingComponentPtrEi($this,$classID) {
 $this = $this|0;
 $classID = $classID|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z25FindConflictingComponentsi($classID)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[560640>>2]|0;
 $11 = HEAP32[560632>>2]|0;
 $i$02 = $6;
 L7: while(1) {
  $12 = HEAP32[$i$02>>2]|0;
  $13 = Math_imul($10, $12)|0;
  $17 = $1;
  while(1) {
   $16 = HEAP32[$17>>2]|0;
   $18 = (($13) + ($16))|0;
   $19 = $18 >> 5;
   $20 = $19 << 5;
   $21 = (($18) - ($20))|0;
   $22 = (($11) + ($19<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = 1 << $21;
   $25 = $24 & $23;
   $26 = ($25|0)==(0);
   $15 = (($17) + 4|0);
   if (!($26)) {
    break L7;
   }
   $14 = ($15|0)==($3|0);
   if ($14) {
    break;
   } else {
    $17 = $15;
   }
  }
  $29 = (($i$02) + 8|0);
  $30 = (($6) + ($8<<3)|0);
  $31 = ($29|0)==($30|0);
  if ($31) {
   $$0 = 0;
   label = 9;
   break;
  } else {
   $i$02 = $29;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return ($$0|0);
 }
 $27 = (($i$02) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $$0 = $28;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity10GameObject7SetNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 56|0);
 $2 = (__ZNK6Object14GetMemoryLabelEv($this)|0);
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN14ConstantString6assignEPKc10MemLabelId($1,$name,$$byval_copy);
 $3 = (0|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 abort /* segfault, call an absolute addr */ (($this|0));
 STACKTOP = sp;return;
}
function __ZNK5Unity10GameObject8IsActiveEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $$0$in = 0, $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$i$i = 0;
 var $i$02$i$i2 = 0, $phitmp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 47|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(-1);
 L1: do {
  if ($2) {
   $3 = (($this) + 46|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $10 = 0;
   } else {
    $6 = (($this) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = $7 >>> 20;
    $$lobit = $8 & 1;
    $9 = $$lobit ^ 1;
    $$ = $9&255;
    $10 = $$;
   }
   HEAP8[$0>>0] = $10;
   $11 = (($this) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 32|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($12) + ($14<<3)|0);
   $16 = ($14|0)==(0);
   if ($16) {
    $$0$in = $10;
   } else {
    $i$02$i$i2 = $12;
    while(1) {
     $17 = HEAP32[$i$02$i$i2>>2]|0;
     if ((($17|0) == 4) | (($17|0) == 224)) {
      break;
     }
     $18 = (($i$02$i$i2) + 8|0);
     $19 = ($18|0)==($15|0);
     if ($19) {
      $$0$in = $10;
      break L1;
     } else {
      $i$02$i$i2 = $18;
     }
    }
    $20 = (($i$02$i$i2) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     $$0$in = $10;
    } else {
     $i$02$i$i = $12;
     while(1) {
      $23 = HEAP32[$i$02$i$i>>2]|0;
      if ((($23|0) == 4) | (($23|0) == 224)) {
       break;
      }
      $29 = (($i$02$i$i) + 8|0);
      $i$02$i$i = $29;
     }
     $24 = (($i$02$i$i) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($25) + 156|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==(0|0);
     if ($28) {
      $$0$in = $10;
     } else {
      $30 = ($10<<24>>24)==(0);
      if ($30) {
       $34 = 0;
      } else {
       $31 = (($27) + 24|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (__ZNK5Unity10GameObject8IsActiveEv($32)|0);
       $phitmp1 = $33&1;
       $34 = $phitmp1;
      }
      HEAP8[$0>>0] = $34;
      $$0$in = $34;
     }
    }
   }
  } else {
   $$0$in = $1;
  }
 } while(0);
 $$0 = ($$0$in<<24>>24)!=(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity20GetGameObjectManagerEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[562264>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5Unity10GameObject32ActivateAwakeRecursivelyInternalENS_19DeactivateOperationER18AwakeFromLoadQueue($this,$deactivateOperation,$queue) {
 $this = $this|0;
 $deactivateOperation = $deactivateOperation|0;
 $queue = $queue|0;
 var $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $changed$0$off0 = 0, $i$02$i$i = 0, $i$04 = 0, $i1$02 = 0, $i1$02$us = 0, $state$0$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 49|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(561656,0,561712,184,1,$4,0,0);
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 1;
 $5 = (($this) + 47|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(-1);
 if ($7) {
  $11 = (__ZNK5Unity10GameObject8IsActiveEv($this)|0);
  $changed$0$off0 = 1;$state$0$off0 = $11;
 } else {
  $8 = ($6<<24>>24)!=(0);
  HEAP8[$5>>0] = -1;
  $9 = (__ZNK5Unity10GameObject8IsActiveEv($this)|0);
  $10 = $8 ^ $9;
  $changed$0$off0 = $10;$state$0$off0 = $9;
 }
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 32|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + ($15<<3)|0);
 $17 = ($15|0)==(0);
 L9: do {
  if (!($17)) {
   $i$02$i$i = $13;
   while(1) {
    $18 = HEAP32[$i$02$i$i>>2]|0;
    if ((($18|0) == 4) | (($18|0) == 224)) {
     break;
    }
    $19 = (($i$02$i$i) + 8|0);
    $20 = ($19|0)==($16|0);
    if ($20) {
     break L9;
    } else {
     $i$02$i$i = $19;
    }
   }
   $21 = (($i$02$i$i) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    $24 = (($22) + 148|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)>(0);
    if ($26) {
     $27 = (($22) + 140|0);
     $i$04 = 0;
     while(1) {
      $28 = HEAP32[$27>>2]|0;
      $29 = (($28) + ($i$04<<2)|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($30) + 24|0);
      $32 = HEAP32[$31>>2]|0;
      __ZN5Unity10GameObject32ActivateAwakeRecursivelyInternalENS_19DeactivateOperationER18AwakeFromLoadQueue($32,$deactivateOperation,$queue);
      $33 = (($i$04) + 1)|0;
      $34 = HEAP32[$24>>2]|0;
      $35 = ($33|0)<($34|0);
      if ($35) {
       $i$04 = $33;
      } else {
       break;
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ($changed$0$off0) {
   $36 = HEAP32[$14>>2]|0;
   $37 = ($36|0)==(0);
   if (!($37)) {
    if ($state$0$off0) {
     $i1$02$us = 0;
     while(1) {
      $38 = HEAP32[$12>>2]|0;
      $39 = ((($38) + ($i1$02$us<<3)|0) + 4|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + 24|0);
      HEAP32[$41>>2] = $this;
      $42 = HEAP32[$12>>2]|0;
      $43 = ((($42) + ($i1$02$us<<3)|0) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      __ZN18AwakeFromLoadQueue3AddER6ObjectPK8TypeTreeb17AwakeFromLoadMode($queue,$44,0,0,-1);
      $$pre = HEAP32[$14>>2]|0;
      $45 = (($i1$02$us) + 1)|0;
      $46 = ($45>>>0)<($$pre>>>0);
      if ($46) {
       $i1$02$us = $45;
      } else {
       break;
      }
     }
    } else {
     $i1$02 = 0;
     while(1) {
      $47 = HEAP32[$12>>2]|0;
      $48 = ((($47) + ($i1$02<<3)|0) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = HEAP32[$49>>2]|0;
      $51 = (($50) + 104|0);
      $52 = HEAP32[$51>>2]|0;
      FUNCTION_TABLE_vii[$52 & 4095]($49,$deactivateOperation);
      $$pre9 = HEAP32[$14>>2]|0;
      $53 = (($i1$02) + 1)|0;
      $54 = ($53>>>0)<($$pre9>>>0);
      if ($54) {
       $i1$02 = $53;
      } else {
       break;
      }
     }
    }
   }
   if ($state$0$off0) {
    __ZN5Unity10GameObject18UpdateActiveGONodeEv($this);
    break;
   }
   $55 = (($this) + 60|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    $58 = (($this) + 64|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($56) + 4|0);
    HEAP32[$60>>2] = $59;
    $61 = HEAP32[$55>>2]|0;
    $62 = HEAP32[$58>>2]|0;
    HEAP32[$62>>2] = $61;
    HEAP32[$55>>2] = 0;
    HEAP32[$58>>2] = 0;
   }
  }
 } while(0);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject24ActivateAwakeRecursivelyENS_19DeactivateOperationE($this,$deactivateOperation) {
 $this = $this|0;
 $deactivateOperation = $deactivateOperation|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $queue = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy4 = sp + 140|0;
 $0 = sp;
 $1 = sp + 4|0;
 $queue = sp + 8|0;
 $2 = sp + 136|0;
 $3 = HEAP32[628512>>2]|0;
 HEAP32[$2>>2] = $3;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN18AwakeFromLoadQueueC2E10MemLabelId($queue,$$byval_copy4);
 __THREW__ = 0;
 invoke_viii(1625,($this|0),($deactivateOperation|0),($queue|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  invoke_viii(1626,($queue|0),8,0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($queue) + 128|0);
   $10 = $8;
   while(1) {
    $9 = (($10) + -16|0);
    $11 = (($10) + -4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)>(-1);
    if ($13) {
     $14 = HEAP32[$9>>2]|0;
     $15 = (($10) + -12|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$1>>2] = $16;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($14|0),($$byval_copy4|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     HEAP32[$9>>2] = 0;
    }
    $19 = ($9|0)==($queue|0);
    if ($19) {
     label = 16;
     break;
    } else {
     $10 = $9;
    }
   }
   if ((label|0) == 16) {
    STACKTOP = sp;return;
   }
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   $22 = ($queue|0)==($9|0);
   if ($22) {
    ___resumeException($20|0);
    // unreachable;
   }
   $24 = $9;
   while(1) {
    $23 = (($24) + -16|0);
    $25 = (($24) + -4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)>(-1);
    if ($27) {
     $28 = HEAP32[$23>>2]|0;
     $29 = (($24) + -12|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$0>>2] = $30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($28|0),($$byval_copy4|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      label = 15;
      break;
     }
     HEAP32[$23>>2] = 0;
    }
    $33 = ($23|0)==($queue|0);
    if ($33) {
     label = 14;
     break;
    } else {
     $24 = $23;
    }
   }
   if ((label|0) == 14) {
    ___resumeException($20|0);
    // unreachable;
   }
   else if ((label|0) == 15) {
    $34 = ___cxa_find_matching_catch(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = (($queue) + 128|0);
 $40 = $38;
 while(1) {
  $39 = (($40) + -16|0);
  $41 = (($40) + -4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)>(-1);
  if ($43) {
   $44 = HEAP32[$39>>2]|0;
   $45 = (($40) + -12|0);
   $46 = HEAP32[$45>>2]|0;
   HEAP32[$1>>2] = $46;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($44|0),($$byval_copy4|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    break;
   }
   HEAP32[$39>>2] = 0;
  }
  $49 = ($39|0)==($queue|0);
  if ($49) {
   label = 29;
   break;
  } else {
   $40 = $39;
  }
 }
 if ((label|0) == 29) {
  ___resumeException($36|0);
  // unreachable;
 }
 $50 = ___cxa_find_matching_catch(0|0)|0;
 $51 = tempRet0;
 $52 = ($queue|0)==($39|0);
 if ($52) {
  ___clang_call_terminate($50);
  // unreachable;
 }
 $54 = $39;
 while(1) {
  $53 = (($54) + -16|0);
  $55 = (($54) + -4|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)>(-1);
  if ($57) {
   $58 = HEAP32[$53>>2]|0;
   $59 = (($54) + -12|0);
   $60 = HEAP32[$59>>2]|0;
   HEAP32[$0>>2] = $60;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($58|0),($$byval_copy4|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    label = 28;
    break;
   }
   HEAP32[$53>>2] = 0;
  }
  $63 = ($53|0)==($queue|0);
  if ($63) {
   label = 30;
   break;
  } else {
   $54 = $53;
  }
 }
 if ((label|0) == 28) {
  $64 = ___cxa_find_matching_catch(0|0)|0;
  $65 = tempRet0;
  ___clang_call_terminate($64);
  // unreachable;
 }
 else if ((label|0) == 30) {
  ___clang_call_terminate($50);
  // unreachable;
 }
}
function __ZN5Unity10GameObject20AddComponentInternalEPNS_9ComponentE($this,$com) {
 $this = $this|0;
 $com = $com|0;
 var $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i3 = 0, $$pre2$i = 0, $$pre2$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $data$i = 0;
 var $i$01$i = 0, $i$01$i$i = 0, $i$01$i$i2 = 0, $inData$c$i$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $data$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = (($com) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 21;
 HEAP32[$0>>2] = $4;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = $com;
 __ZN13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EE9push_backERKS6_($1,$0);
 $6 = HEAP32[$com>>2]|0;
 $7 = (($6) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 14;
 $12 = $11 & 63;
 FUNCTION_TABLE_vii[$8 & 4095]($com,$12);
 $13 = (($com) + 24|0);
 HEAP32[$13>>2] = $this;
 $14 = (__ZNK5Unity10GameObject8IsActiveEv($this)|0);
 $15 = HEAP32[$com>>2]|0;
 $16 = (($15) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 if ($14) {
  FUNCTION_TABLE_vii[$17 & 4095]($com,8);
 } else {
  FUNCTION_TABLE_vii[$17 & 4095]($com,0);
 }
 $18 = (($data$i) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = (($data$i) + 4|0);
 $inData$c$i$i = $com;
 HEAP32[$19>>2] = $inData$c$i$i;
 HEAP32[$data$i>>2] = 2;
 $20 = HEAP32[((564640 + 8|0))>>2]|0;
 $21 = (($this) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $57 = 0;
 } else {
  $24 = (($this) + 24|0);
  $88 = $22;$i$01$i$i2 = 0;
  while(1) {
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + ($i$01$i$i2<<3)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[561544>>2]|0;
   $29 = (($28) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = Math_imul($30, $20)|0;
   $32 = (($31) + ($27))|0;
   $33 = $32 >>> 5;
   $34 = (($28) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + ($33<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = $32 & 31;
   $39 = 1 << $38;
   $40 = $39 & $37;
   $41 = ($40|0)==(0);
   if ($41) {
    $49 = $88;
   } else {
    $42 = ((($25) + ($i$01$i$i2<<3)|0) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($28) + 16|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($45) + ($27<<5)|0);
    __ZN16MessageForwarder13HandleMessageEPviR11MessageData($46,$43,$20,$data$i);
    $$pre$i$i3 = HEAP32[$21>>2]|0;
    $49 = $$pre$i$i3;
   }
   $47 = (($i$01$i$i2) + 1)|0;
   $48 = ($47>>>0)<($49>>>0);
   if ($48) {
    $88 = $49;$i$01$i$i2 = $47;
   } else {
    $57 = $49;
    break;
   }
  }
 }
 $50 = (($this) + 52|0);
 $51 = HEAP32[$50>>2]|0;
 HEAP32[$50>>2] = 0;
 $52 = (($this) + 48|0);
 $53 = HEAP8[$52>>0]|0;
 $54 = ($53<<24>>24)==(0);
 if (!($54)) {
  STACKTOP = sp;return;
 }
 HEAP32[$50>>2] = 0;
 $55 = (($this) + 24|0);
 $56 = ($57|0)==(0);
 if ($56) {
  STACKTOP = sp;return;
 }
 $58 = HEAP32[$55>>2]|0;
 $89 = 0;$90 = $57;$91 = $58;$i$01$i$i = $58;
 while(1) {
  $59 = (($i$01$i$i) + 4|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(0|0);
  if ($61) {
   $70 = $91;$71 = $90;$74 = $89;
  } else {
   $62 = HEAP32[$60>>2]|0;
   $63 = (($62) + 92|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (FUNCTION_TABLE_ii[$64 & 4095]($60)|0);
   $66 = HEAP32[$50>>2]|0;
   $67 = $66 | $65;
   HEAP32[$50>>2] = $67;
   $$pre$i$i = HEAP32[$55>>2]|0;
   $$pre2$i$i = HEAP32[$21>>2]|0;
   $70 = $$pre$i$i;$71 = $$pre2$i$i;$74 = $67;
  }
  $68 = (($i$01$i$i) + 8|0);
  $69 = (($70) + ($71<<3)|0);
  $72 = ($68|0)==($69|0);
  if ($72) {
   break;
  } else {
   $89 = $74;$90 = $71;$91 = $70;$i$01$i$i = $68;
  }
 }
 $73 = ($51|0)==($74|0);
 $75 = ($71|0)==(0);
 $or$cond$i = $73 | $75;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 } else {
  $92 = $71;$93 = $70;$i$01$i = $70;
 }
 while(1) {
  $76 = (($i$01$i) + 4|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = ($77|0)==(0|0);
  if ($78) {
   $85 = $93;$86 = $92;
  } else {
   $79 = HEAP32[$77>>2]|0;
   $80 = (($79) + 96|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = HEAP32[$50>>2]|0;
   FUNCTION_TABLE_vii[$81 & 4095]($77,$82);
   $$pre$i = HEAP32[$55>>2]|0;
   $$pre2$i = HEAP32[$21>>2]|0;
   $85 = $$pre$i;$86 = $$pre2$i;
  }
  $83 = (($i$01$i) + 8|0);
  $84 = (($85) + ($86<<3)|0);
  $87 = ($83|0)==($84|0);
  if ($87) {
   break;
  } else {
   $92 = $86;$93 = $85;$i$01$i = $83;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EE9push_backERKS6_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if (!($7)) {
  $26 = $3;
  $25 = (($26) + -1)|0;
  $27 = HEAP32[$this>>2]|0;
  $28 = HEAP32[$t>>2]|0;
  $29 = (($27) + ($25<<3)|0);
  HEAP32[$29>>2] = $28;
  $30 = (($t) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($27) + ($25<<3)|0) + 4|0);
  HEAP32[$32>>2] = $31;
  STACKTOP = sp;return;
 }
 $8 = $5 << 1;
 $9 = ($8|0)==(0);
 $10 = $9 ? 1 : $8;
 $11 = ($6>>>0)<($10>>>0);
 do {
  if ($11) {
   $12 = ($5|0)>(-1);
   if ($12) {
    HEAP32[$4>>2] = $10;
    $13 = HEAP32[$this>>2]|0;
    $14 = $10 << 3;
    $15 = (($this) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,561712,370)|0);
    HEAP32[$this>>2] = $17;
    break;
   } else {
    $18 = $10 << 3;
    $19 = (($this) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,561712,352)|0);
    $22 = HEAP32[$this>>2]|0;
    $23 = HEAP32[$1>>2]|0;
    $24 = $23 << 3;
    _memcpy(($21|0),($22|0),($24|0))|0;
    HEAP32[$4>>2] = $10;
    HEAP32[$this>>2] = $21;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$1>>2]|0;
 $26 = $$pre$i;
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$t>>2]|0;
 $29 = (($27) + ($25<<3)|0);
 HEAP32[$29>>2] = $28;
 $30 = (($t) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($27) + ($25<<3)|0) + 4|0);
 HEAP32[$32>>2] = $31;
 STACKTOP = sp;return;
}
function __ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($this,$classID) {
 $this = $this|0;
 $classID = $classID|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<3)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$02 = $1;
 }
 while(1) {
  $8 = HEAP32[$i$02>>2]|0;
  $9 = ($8|0)==($classID|0);
  $7 = (($i$02) + 8|0);
  if ($9) {
   break;
  }
  $6 = ($7|0)==($4|0);
  if ($6) {
   $$0 = 0;
   label = 5;
   break;
  } else {
   $i$02 = $7;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($i$02) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $$0 = $11;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5Unity10GameObject23QueryComponentTransformEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<3)|0);
 $5 = ($3|0)==(0);
 L1: do {
  if ($5) {
   $$0 = 0;
  } else {
   $i$02 = $1;
   while(1) {
    $6 = HEAP32[$i$02>>2]|0;
    if ((($6|0) == 4) | (($6|0) == 224)) {
     break;
    }
    $9 = (($i$02) + 8|0);
    $10 = ($9|0)==($4|0);
    if ($10) {
     $$0 = 0;
     break L1;
    } else {
     $i$02 = $9;
    }
   }
   $7 = (($i$02) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $$0 = $8;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5Unity10GameObject28QueryComponentImplementationEi($this,$classID) {
 $this = $this|0;
 $classID = $classID|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<3)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[560640>>2]|0;
 $7 = HEAP32[560632>>2]|0;
 $i$02 = $1;
 while(1) {
  $10 = HEAP32[$i$02>>2]|0;
  $11 = Math_imul($6, $10)|0;
  $12 = (($11) + ($classID))|0;
  $13 = $12 >> 5;
  $14 = $13 << 5;
  $15 = (($12) - ($14))|0;
  $16 = (($7) + ($13<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = 1 << $15;
  $19 = $18 & $17;
  $20 = ($19|0)==(0);
  $9 = (($i$02) + 8|0);
  if (!($20)) {
   break;
  }
  $8 = ($9|0)==($4|0);
  if ($8) {
   $$0 = 0;
   label = 6;
   break;
  } else {
   $i$02 = $9;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($i$02) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $$0 = $22;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity10GameObject22RemoveComponentAtIndexEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$pre$i = 0, $$pre$i$i = 0, $$pre2$i = 0, $$pre2$i$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $i$01$i$i = 0, $neg = 0;
 var $or$cond$i = 0, $tmp = 0, $tmp4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index<<3)|0);
 $3 = ((($1) + ($index<<3)|0) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $$sum = (($index) + 1)|0;
 $5 = (($1) + ($$sum<<3)|0);
 $6 = (($this) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $neg = $index ^ 536870911;
 $tmp = (($7) + ($neg))|0;
 $tmp4 = $tmp << 3;
 _memmove(($2|0),($5|0),($tmp4|0))|0;
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + -1)|0;
 HEAP32[$6>>2] = $9;
 $10 = (($4) + 24|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$11>>2] = 0;
 $13 = (($this) + 48|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 HEAP32[$11>>2] = 0;
 $16 = ($9|0)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$0>>2]|0;
 $47 = 0;$48 = $9;$49 = $17;$i$01$i$i = $17;
 while(1) {
  $18 = (($i$01$i$i) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $29 = $49;$30 = $48;$33 = $47;
  } else {
   $21 = HEAP32[$19>>2]|0;
   $22 = (($21) + 92|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (FUNCTION_TABLE_ii[$23 & 4095]($19)|0);
   $25 = HEAP32[$11>>2]|0;
   $26 = $25 | $24;
   HEAP32[$11>>2] = $26;
   $$pre$i$i = HEAP32[$0>>2]|0;
   $$pre2$i$i = HEAP32[$6>>2]|0;
   $29 = $$pre$i$i;$30 = $$pre2$i$i;$33 = $26;
  }
  $27 = (($i$01$i$i) + 8|0);
  $28 = (($29) + ($30<<3)|0);
  $31 = ($27|0)==($28|0);
  if ($31) {
   break;
  } else {
   $47 = $33;$48 = $30;$49 = $29;$i$01$i$i = $27;
  }
 }
 $32 = ($12|0)==($33|0);
 $34 = ($30|0)==(0);
 $or$cond$i = $32 | $34;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 } else {
  $50 = $30;$51 = $29;$i$01$i = $29;
 }
 while(1) {
  $35 = (($i$01$i) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   $44 = $51;$45 = $50;
  } else {
   $38 = HEAP32[$36>>2]|0;
   $39 = (($38) + 96|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vii[$40 & 4095]($36,$41);
   $$pre$i = HEAP32[$0>>2]|0;
   $$pre2$i = HEAP32[$6>>2]|0;
   $44 = $$pre$i;$45 = $$pre2$i;
  }
  $42 = (($i$01$i) + 8|0);
  $43 = (($44) + ($45<<3)|0);
  $46 = ($42|0)==($43|0);
  if ($46) {
   break;
  } else {
   $50 = $45;$51 = $44;$i$01$i = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject17GetComponentIndexEPNS_9ComponentE($this,$component) {
 $this = $this|0;
 $component = $component|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 L1: do {
  if ($2) {
   $3 = (($this) + 24|0);
   $4 = HEAP32[$3>>2]|0;
   $i$01 = 0;
   while(1) {
    $7 = ((($4) + ($i$01<<3)|0) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==($component|0);
    $6 = (($i$01) + 1)|0;
    if ($9) {
     $$0 = $i$01;
     break L1;
    }
    $5 = ($6|0)<($1|0);
    if ($5) {
     $i$01 = $6;
    } else {
     $$0 = -1;
     break;
    }
   }
  } else {
   $$0 = -1;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity10GameObject8ActivateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5Unity10GameObject8IsActiveEv($this)|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 46|0);
 HEAP8[$1>>0] = 1;
 __ZN5Unity10GameObject24ActivateAwakeRecursivelyENS_19DeactivateOperationE($this,0);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject10DeactivateENS_19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5Unity10GameObject8IsActiveEv($this)|0);
 $1 = (($this) + 46|0);
 if ($0) {
  HEAP8[$1>>0] = 0;
  __ZN5Unity10GameObject24ActivateAwakeRecursivelyENS_19DeactivateOperationE($this,$operation);
  STACKTOP = sp;return;
 }
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 HEAP8[$1>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject13SetSelfActiveEb($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5Unity10GameObject8IsActiveEv($this)|0);
 do {
  if ($state) {
   if (!($0)) {
    $1 = (($this) + 46|0);
    HEAP8[$1>>0] = 1;
    __ZN5Unity10GameObject24ActivateAwakeRecursivelyENS_19DeactivateOperationE($this,0);
   }
  } else {
   $2 = (($this) + 46|0);
   if ($0) {
    HEAP8[$2>>0] = 0;
    __ZN5Unity10GameObject24ActivateAwakeRecursivelyENS_19DeactivateOperationE($this,0);
    break;
   }
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if (!($4)) {
    HEAP8[$2>>0] = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject20AddComponentInternalERS0_RNS_9ComponentE($gameObject,$clone) {
 $gameObject = $gameObject|0;
 $clone = $clone|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($gameObject) + 24|0);
 $2 = (($clone) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 21;
 HEAP32[$0>>2] = $4;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = $clone;
 __ZN13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EE9push_backERKS6_($1,$0);
 $6 = (($clone) + 24|0);
 HEAP32[$6>>2] = $gameObject;
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject21EnsureUniqueTransformEbb($this,$baseTransformPriority,$allowPersistentChanges) {
 $this = $this|0;
 $baseTransformPriority = $baseTransformPriority|0;
 $allowPersistentChanges = $allowPersistentChanges|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $baseTransformPriority$not = 0, $index$010 = 0, $index$2 = 0, $or$cond = 0, $or$cond5 = 0, $primaryIndex$012 = 0, $primaryIndex$2 = 0, $primaryIndex$3 = 0, $primaryTransform$013 = 0, $primaryTransform$2 = 0, $transformMerged$0$off011 = 0, $transformMerged$1$off0 = 0;
 var $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __Z6FormatPKcz($0,561720,$vararg_buffer1);
  label = 17;
 } else {
  $4 = (($this) + 24|0);
  $baseTransformPriority$not = $baseTransformPriority ^ 1;
  $5 = (($this) + 8|0);
  $index$010 = 0;$primaryIndex$012 = 0;$primaryTransform$013 = 0;$transformMerged$0$off011 = 0;
  L4: while(1) {
   $6 = HEAP32[$4>>2]|0;
   $7 = ((($6) + ($index$010<<3)|0) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   do {
    if ($9) {
     $index$2 = $index$010;$primaryIndex$2 = $primaryIndex$012;$primaryTransform$2 = $primaryTransform$013;$transformMerged$1$off0 = $transformMerged$0$off011;
    } else {
     $10 = (($8) + 8|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = $11 >>> 21;
     if ((($12|0) == 4) | (($12|0) == 224)) {
      $13 = ($primaryTransform$013|0)==(0|0);
      if ($13) {
       $index$2 = $index$010;$primaryIndex$2 = $index$010;$primaryTransform$2 = $8;$transformMerged$1$off0 = $transformMerged$0$off011;
      } else {
       if (!($allowPersistentChanges)) {
        $14 = HEAP32[$5>>2]|0;
        $15 = $14 & 1048576;
        $16 = ($15|0)==(0);
        if (!($16)) {
         label = 29;
         break L4;
        }
       }
       $17 = (($primaryTransform$013) + 8|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = $18 >>> 21;
       $20 = ($12|0)==($19|0);
       $or$cond = $transformMerged$0$off011 | $20;
       if ($or$cond) {
        __ZN5UnityL24MergeTransformComponentsER9TransformS1_b($8,$primaryTransform$013,0);
        $21 = (($index$010) + -1)|0;
        __ZN5Unity10GameObject22RemoveComponentAtIndexEi($this,$index$010);
        __Z19DestroySingleObjectP6Object($8);
        $index$2 = $21;$primaryIndex$2 = $primaryIndex$012;$primaryTransform$2 = $primaryTransform$013;$transformMerged$1$off0 = $transformMerged$0$off011;
        break;
       }
       $22 = ($19|0)==(224);
       $or$cond5 = $22 & $baseTransformPriority$not;
       if ($or$cond5) {
        __ZN5UnityL24MergeTransformComponentsER9TransformS1_b($8,$primaryTransform$013,1);
        $23 = (($index$010) + -1)|0;
        __ZN5Unity10GameObject22RemoveComponentAtIndexEi($this,$index$010);
        __Z19DestroySingleObjectP6Object($8);
        $index$2 = $23;$primaryIndex$2 = $primaryIndex$012;$primaryTransform$2 = $primaryTransform$013;$transformMerged$1$off0 = 1;
        break;
       } else {
        __ZN5UnityL24MergeTransformComponentsER9TransformS1_b($primaryTransform$013,$8,1);
        __ZN5Unity10GameObject22RemoveComponentAtIndexEi($this,$primaryIndex$012);
        $24 = (($index$010) + -1)|0;
        __Z19DestroySingleObjectP6Object($primaryTransform$013);
        $index$2 = $24;$primaryIndex$2 = $24;$primaryTransform$2 = $8;$transformMerged$1$off0 = 1;
        break;
       }
      }
     } else {
      $index$2 = $index$010;$primaryIndex$2 = $primaryIndex$012;$primaryTransform$2 = $primaryTransform$013;$transformMerged$1$off0 = $transformMerged$0$off011;
     }
    }
   } while(0);
   $25 = (($index$2) + 1)|0;
   $26 = HEAP32[$1>>2]|0;
   $27 = ($25>>>0)<($26>>>0);
   if ($27) {
    $index$010 = $25;$primaryIndex$012 = $primaryIndex$2;$primaryTransform$013 = $primaryTransform$2;$transformMerged$0$off011 = $transformMerged$1$off0;
   } else {
    break;
   }
  }
  if ((label|0) == 29) {
   STACKTOP = sp;return;
  }
  $28 = ($primaryTransform$2|0)==(0|0);
  if ($28) {
   __Z6FormatPKcz($0,561720,$vararg_buffer1);
   $29 = ($this|0)==(0|0);
   if ($29) {
    $39 = 0;
    label = 18;
   } else {
    label = 17;
   }
  } else {
   $primaryIndex$3 = $primaryIndex$2;
  }
 }
 if ((label|0) == 17) {
  $30 = (($this) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $39 = $31;
  label = 18;
 }
 do {
  if ((label|0) == 18) {
   $32 = HEAP8[$0>>0]|0;
   $33 = $32 & 1;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    $37 = (($0) + 1|0);
    $38 = $37;
   } else {
    $35 = (($0) + 8|0);
    $36 = HEAP32[$35>>2]|0;
    $38 = $36;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($38|0),0,(561712|0),730,1,($39|0),0,(0|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    $42 = HEAP8[$0>>0]|0;
    $43 = $42 & 1;
    $44 = ($43<<24>>24)==(0);
    if (!($44)) {
     $45 = (($0) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     __ZdlPv($46);
    }
    (__Z21AddComponentUncheckedRN5Unity10GameObjectEiP14ScriptingClassPNSt3__112basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE($this,4,0,0)|0);
    $47 = HEAP32[$1>>2]|0;
    $48 = (($47) + -1)|0;
    $primaryIndex$3 = $48;
    break;
   }
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $51 = HEAP8[$0>>0]|0;
   $52 = $51 & 1;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    ___resumeException($49|0);
    // unreachable;
   }
   $54 = (($0) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   __ZdlPv($55);
   ___resumeException($49|0);
   // unreachable;
  }
 } while(0);
 $56 = ($primaryIndex$3|0)==(0);
 if ($56) {
  STACKTOP = sp;return;
 }
 $57 = (($this) + 24|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + ($primaryIndex$3<<3)|0);
 $60 = ((($58) + ($primaryIndex$3<<3)|0) + 4|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$59>>2]|0;
 $63 = HEAP32[$58>>2]|0;
 HEAP32[$59>>2] = $63;
 $64 = (($58) + 4|0);
 $65 = HEAP32[$64>>2]|0;
 HEAP32[$60>>2] = $65;
 $66 = HEAP32[$57>>2]|0;
 HEAP32[$66>>2] = $62;
 $67 = (($66) + 4|0);
 HEAP32[$67>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN5UnityL24MergeTransformComponentsER9TransformS1_b($source,$target,$mergeTRS) {
 $source = $source|0;
 $target = $target|0;
 $mergeTRS = $mergeTRS|0;
 var $$byval_copy2 = 0, $$mask = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0);
 var $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $index$03 = 0;
 var $index1$01 = 0, $localRotation = 0, $localScale = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy2 = sp + 36|0;
 $0 = sp;
 $localRotation = sp + 8|0;
 $localScale = sp + 24|0;
 $1 = (($source) + 44|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($source) + 48|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($source) + 52|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($source) + 28|0);
 ;HEAP32[$localRotation+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$localRotation+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$localRotation+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$localRotation+12>>2]=HEAP32[$7+12>>2]|0;
 $8 = (($source) + 56|0);
 ;HEAP32[$localScale+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$localScale+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$localScale+8>>2]=HEAP32[$8+8>>2]|0;
 $9 = (($source) + 156|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 L1: do {
  if (!($11)) {
   HEAP32[$9>>2] = 0;
   $12 = (($10) + 148|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0);
   if (!($14)) {
    $15 = (($10) + 140|0);
    $16 = HEAP32[$15>>2]|0;
    $index$03 = 0;
    while(1) {
     $19 = (($16) + ($index$03<<2)|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==($source|0);
     $18 = (($index$03) + 1)|0;
     if ($21) {
      break;
     }
     $17 = ($18>>>0)<($13>>>0);
     if ($17) {
      $index$03 = $18;
     } else {
      break L1;
     }
    }
    $22 = (($target) + 156|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     HEAP32[$19>>2] = $target;
     HEAP32[$22>>2] = $10;
     break;
    } else {
     __ZN9Transform10ClearChildEPS_($10,$source);
     break;
    }
   }
  }
 } while(0);
 $25 = (($source) + 140|0);
 $26 = (($source) + 148|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if (!($28)) {
  $29 = (($target) + 140|0);
  $30 = (($target) + 148|0);
  $31 = (($target) + 152|0);
  $32 = (($target) + 140|0);
  $33 = (($target) + 144|0);
  $index1$01 = 0;
  while(1) {
   $34 = HEAP32[$25>>2]|0;
   $35 = (($34) + ($index1$01<<2)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = (__ZN9Transform4FindEPKS_($target,$36)|0);
    $39 = HEAP32[$29>>2]|0;
    $40 = HEAP32[$30>>2]|0;
    $41 = (($39) + ($40<<2)|0);
    $42 = ($38|0)==($41|0);
    if ($42) {
     $43 = (($36) + 156|0);
     HEAP32[$43>>2] = $target;
     $44 = (($40) + 1)|0;
     HEAP32[$30>>2] = $44;
     $45 = HEAP32[$31>>2]|0;
     $46 = $45 & 2147483647;
     $47 = ($44>>>0)>($46>>>0);
     if ($47) {
      $48 = $45 << 1;
      $49 = ($48|0)==(0);
      $50 = $49 ? 1 : $48;
      $51 = ($46>>>0)<($50>>>0);
      do {
       if ($51) {
        $52 = ($45|0)>(-1);
        if ($52) {
         HEAP32[$31>>2] = $50;
         $53 = HEAP32[$32>>2]|0;
         $54 = $50 << 2;
         $55 = HEAP32[$33>>2]|0;
         HEAP32[$0>>2] = $55;
         ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
         $56 = (__Z16realloc_internalPvji10MemLabelIdiPKci($53,$54,4,$$byval_copy2,0,561712,370)|0);
         HEAP32[$32>>2] = $56;
         break;
        } else {
         $57 = $50 << 2;
         $58 = HEAP32[$33>>2]|0;
         HEAP32[$0>>2] = $58;
         ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
         $59 = (__Z15malloc_internaljj10MemLabelIdiPKci($57,4,$$byval_copy2,0,561712,352)|0);
         $60 = HEAP32[$32>>2]|0;
         $61 = HEAP32[$30>>2]|0;
         $62 = $61 << 2;
         _memcpy(($59|0),($60|0),($62|0))|0;
         HEAP32[$31>>2] = $50;
         HEAP32[$32>>2] = $59;
         break;
        }
       }
      } while(0);
      $$pre$i$i = HEAP32[$30>>2]|0;
      $64 = $$pre$i$i;
     } else {
      $64 = $44;
     }
     $63 = (($64) + -1)|0;
     $65 = HEAP32[$32>>2]|0;
     $66 = (($65) + ($63<<2)|0);
     HEAP32[$66>>2] = $36;
    }
   }
   $67 = (($index1$01) + 1)|0;
   $68 = HEAP32[$26>>2]|0;
   $69 = ($67>>>0)<($68>>>0);
   if ($69) {
    $index1$01 = $67;
   } else {
    break;
   }
  }
 }
 $70 = (($source) + 152|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)>(-1);
 if ($72) {
  $73 = HEAP32[$25>>2]|0;
  $74 = (($source) + 144|0);
  $75 = HEAP32[$74>>2]|0;
  HEAP32[$0>>2] = $75;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($73,$$byval_copy2);
  HEAP32[$25>>2] = 0;
 }
 HEAP32[$26>>2] = 0;
 HEAP32[$70>>2] = 0;
 if (!($mergeTRS)) {
  STACKTOP = sp;return;
 }
 $76 = (($target) + 44|0);
 HEAPF32[$76>>2] = $2;
 $77 = (($target) + 48|0);
 HEAPF32[$77>>2] = $4;
 $78 = (($target) + 52|0);
 HEAPF32[$78>>2] = $6;
 $79 = (($target) + 135|0);
 $80 = HEAP8[$79>>0]|0;
 $81 = $80&255;
 $82 = $81 | 1;
 $83 = $82&255;
 HEAP8[$79>>0] = $83;
 $84 = (($target) + 8|0);
 $85 = HEAP32[$84>>2]|0;
 $$mask = $85 & -2097152;
 $86 = ($$mask|0)==(469762048);
 do {
  if ($86) {
   $87 = (($target) + 192|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = Math_fround($2 - $88);
   $90 = $89 < Math_fround(0.0);
   if ($90) {
    $91 = Math_fround(-$89);
    $104 = $91;
   } else {
    $104 = $89;
   }
   $92 = $88 < Math_fround(0.0);
   if ($92) {
    $93 = Math_fround(-$88);
    $97 = $93;
   } else {
    $97 = $88;
   }
   $94 = $2 < Math_fround(0.0);
   if ($94) {
    $95 = Math_fround(-$2);
    $98 = $95;
   } else {
    $98 = $2;
   }
   $96 = $97 < $98;
   $99 = $96 ? $98 : $97;
   $100 = Math_fround($99 * Math_fround(9.99999997475242707878E-7));
   $101 = $100 < Math_fround(7.99999979790300130844E-5);
   $102 = $101 ? Math_fround(7.99999979790300130844E-5) : $100;
   $103 = $104 < $102;
   if ($103) {
    $105 = (($target) + 196|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $107 = Math_fround($4 - $106);
    $108 = $107 < Math_fround(0.0);
    if ($108) {
     $109 = Math_fround(-$107);
     $122 = $109;
    } else {
     $122 = $107;
    }
    $110 = $106 < Math_fround(0.0);
    if ($110) {
     $111 = Math_fround(-$106);
     $115 = $111;
    } else {
     $115 = $106;
    }
    $112 = $4 < Math_fround(0.0);
    if ($112) {
     $113 = Math_fround(-$4);
     $116 = $113;
    } else {
     $116 = $4;
    }
    $114 = $115 < $116;
    $117 = $114 ? $116 : $115;
    $118 = Math_fround($117 * Math_fround(9.99999997475242707878E-7));
    $119 = $118 < Math_fround(7.99999979790300130844E-5);
    $120 = $119 ? Math_fround(7.99999979790300130844E-5) : $118;
    $121 = $122 < $120;
    if ($121) {
     $131 = $83;
     break;
    }
   }
   $123 = (HEAPF32[tempDoublePtr>>2]=$2,HEAP32[tempDoublePtr>>2]|0);
   $124 = (HEAPF32[tempDoublePtr>>2]=$4,HEAP32[tempDoublePtr>>2]|0);
   $125 = $87;
   $126 = $125;
   HEAP32[$126>>2] = $123;
   $127 = (($125) + 4)|0;
   $128 = $127;
   HEAP32[$128>>2] = $124;
   __ZN2UI13RectTransform9DirtyRectEv($target);
   $$pre = HEAP8[$79>>0]|0;
   $131 = $$pre;
  } else {
   $131 = $83;
  }
 } while(0);
 $129 = (($target) + 28|0);
 ;HEAP32[$129+0>>2]=HEAP32[$localRotation+0>>2]|0;HEAP32[$129+4>>2]=HEAP32[$localRotation+4>>2]|0;HEAP32[$129+8>>2]=HEAP32[$localRotation+8>>2]|0;HEAP32[$129+12>>2]=HEAP32[$localRotation+12>>2]|0;
 $130 = $131&255;
 $132 = (($target) + 56|0);
 ;HEAP32[$132+0>>2]=HEAP32[$localScale+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$localScale+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$localScale+8>>2]|0;
 $133 = $130 | 10;
 $134 = $133&255;
 HEAP8[$79>>0] = $134;
 __ZN9Transform24RecalculateTransformTypeEv($target);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$0$i21 = 0, $$0$i7 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$76 = 0, $$77 = 0, $$78 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre2$i = 0, $$pre2$i$i = 0;
 var $$pre74 = 0, $$pre75 = 0, $$sum = 0, $$sum37 = 0, $$sum40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$01$i$i = 0, $i$067 = 0, $i$1$ph72 = 0, $i$254 = 0, $i$3$ph71 = 0, $j$0$ph62 = 0, $neg = 0, $neg44 = 0, $neg47 = 0, $or$cond$i = 0, $tmp = 0, $tmp43 = 0;
 var $tmp45 = 0, $tmp46 = 0, $tmp48 = 0, $tmp49 = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $vararg_buffer3 = sp;
 $0 = sp + 84|0;
 $1 = sp + 72|0;
 $2 = sp + 60|0;
 $3 = sp + 96|0;
 $4 = sp + 24|0;
 $5 = sp + 12|0;
 $6 = sp + 36|0;
 $7 = sp + 48|0;
 $8 = (($this) + 24|0);
 $9 = (($this) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 L1: do {
  if (!($11)) {
   $12 = (($this) + 8|0);
   $13 = (($this) + 56|0);
   $14 = (($0) + 1|0);
   $15 = (($0) + 8|0);
   $16 = (($this) + 4|0);
   $32 = $10;$i$067 = 0;
   L3: while(1) {
    $25 = HEAP32[$8>>2]|0;
    $26 = ((($25) + ($i$067<<3)|0) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     $$0$i = 0;
    } else {
     $29 = (($27) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $$0$i = $30;
    }
    $18 = (($i$067) + 1)|0;
    $31 = ($18>>>0)<($32>>>0);
    L8: do {
     if ($31) {
      $313 = $25;$314 = $32;$j$0$ph62 = $18;
      while(1) {
       $$sum40 = (($j$0$ph62) + 1)|0;
       $neg = $j$0$ph62 ^ 536870911;
       $34 = $313;$88 = $314;
       while(1) {
        $33 = ((($34) + ($j$0$ph62<<3)|0) + 4|0);
        $35 = HEAP32[$33>>2]|0;
        $36 = ($35|0)==(0|0);
        if ($36) {
         $$0$i7 = 0;
        } else {
         $37 = (($35) + 4|0);
         $38 = HEAP32[$37>>2]|0;
         $$0$i7 = $38;
        }
        $39 = ($$0$i|0)==($$0$i7|0);
        if (!($39)) {
         break;
        }
        $40 = HEAP32[$12>>2]|0;
        $41 = $40 >>> 21;
        $42 = (__ZN6Object15ClassIDToStringEi($41)|0);
        $43 = HEAP8[$42>>0]|0;
        $44 = $43 & 1;
        $45 = ($44<<24>>24)==(0);
        if ($45) {
         $48 = (($42) + 1|0);
         $60 = $48;
        } else {
         $46 = (($42) + 8|0);
         $47 = HEAP32[$46>>2]|0;
         $60 = $47;
        }
        $49 = HEAP32[$13>>2]|0;
        $50 = HEAP32[$8>>2]|0;
        $51 = (($50) + ($i$067<<3)|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = (__ZN6Object15ClassIDToStringEi($52)|0);
        $54 = HEAP8[$53>>0]|0;
        $55 = $54 & 1;
        $56 = ($55<<24>>24)==(0);
        if ($56) {
         $59 = (($53) + 1|0);
         $61 = $59;
        } else {
         $57 = (($53) + 8|0);
         $58 = HEAP32[$57>>2]|0;
         $61 = $58;
        }
        HEAP32[$vararg_buffer3>>2] = $60;
        $vararg_ptr1 = (($vararg_buffer3) + 4|0);
        HEAP32[$vararg_ptr1>>2] = $49;
        $vararg_ptr2 = (($vararg_buffer3) + 8|0);
        HEAP32[$vararg_ptr2>>2] = $61;
        __Z6FormatPKcz($0,561792,$vararg_buffer3);
        $62 = HEAP32[$16>>2]|0;
        $63 = HEAP8[$0>>0]|0;
        $64 = $63 & 1;
        $65 = ($64<<24>>24)==(0);
        $66 = HEAP32[$15>>2]|0;
        $67 = $65 ? $14 : $66;
        __THREW__ = 0;
        invoke_viiiiiiii(21,($67|0),0,(561712|0),761,1,($62|0),0,(0|0));
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         label = 24;
         break L3;
        }
        $70 = HEAP8[$0>>0]|0;
        $71 = $70 & 1;
        $72 = ($71<<24>>24)==(0);
        if (!($72)) {
         $73 = HEAP32[$15>>2]|0;
         __ZdlPv($73);
        }
        $74 = HEAP32[$8>>2]|0;
        $75 = (($74) + ($j$0$ph62<<3)|0);
        $76 = (($74) + ($$sum40<<3)|0);
        $77 = HEAP32[$9>>2]|0;
        $tmp = (($77) + ($neg))|0;
        $tmp43 = $tmp << 3;
        _memmove(($75|0),($76|0),($tmp43|0))|0;
        $78 = HEAP32[$9>>2]|0;
        $79 = (($78) + -1)|0;
        HEAP32[$9>>2] = $79;
        $80 = ($j$0$ph62>>>0)<($79>>>0);
        if (!($80)) {
         $19 = $79;
         break L8;
        }
        $$pre75 = HEAP32[$8>>2]|0;
        $34 = $$pre75;$88 = $79;
       }
       $87 = ($$sum40>>>0)<($88>>>0);
       if ($87) {
        $313 = $34;$314 = $88;$j$0$ph62 = $$sum40;
       } else {
        $19 = $88;
        break;
       }
      }
     } else {
      $19 = $32;
     }
    } while(0);
    $17 = ($18>>>0)<($19>>>0);
    if ($17) {
     $32 = $19;$i$067 = $18;
    } else {
     break;
    }
   }
   if ((label|0) == 24) {
    $81 = ___cxa_find_matching_catch()|0;
    $82 = tempRet0;
    $83 = HEAP8[$0>>0]|0;
    $84 = $83 & 1;
    $85 = ($84<<24>>24)==(0);
    if ($85) {
     $$3 = $81;$$34 = $82;
     ___resumeException($$3|0);
     // unreachable;
    }
    $86 = HEAP32[$15>>2]|0;
    __ZdlPv($86);
    $$3 = $81;$$34 = $82;
    ___resumeException($$3|0);
    // unreachable;
   }
   $20 = ($19|0)==(0);
   if (!($20)) {
    $21 = ($this|0)==(0|0);
    $22 = (($1) + 1|0);
    $23 = (($1) + 8|0);
    $24 = (($this) + 4|0);
    $i$1$ph72 = 0;
    L40: while(1) {
     $$sum37 = (($i$1$ph72) + 1)|0;
     $neg44 = $i$1$ph72 ^ 536870911;
     while(1) {
      $91 = HEAP32[$8>>2]|0;
      $92 = ((($91) + ($i$1$ph72<<3)|0) + 4|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = ($93|0)==(0|0);
      if ($94) {
       $$0$i21 = 0;
      } else {
       $95 = (($93) + 4|0);
       $96 = HEAP32[$95>>2]|0;
       $$0$i21 = $96;
      }
      $97 = (__Z17IsObjectAvailablei($$0$i21)|0);
      if ($97) {
       break;
      }
      $98 = HEAP32[$8>>2]|0;
      $99 = (($98) + ($i$1$ph72<<3)|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = ($100|0)==(17);
      if ($101) {
       __Z43DestroyWithoutLoadingButDontDestroyFromFilei($$0$i21);
      } else {
       $102 = (__ZN6Object15ClassIDToStringEi($100)|0);
       $103 = HEAP8[$102>>0]|0;
       $104 = $103 & 1;
       $105 = ($104<<24>>24)==(0);
       if ($105) {
        $108 = (($102) + 1|0);
        $109 = $108;
       } else {
        $106 = (($102) + 8|0);
        $107 = HEAP32[$106>>2]|0;
        $109 = $107;
       }
       HEAP32[$vararg_buffer3>>2] = $109;
       __Z6FormatPKcz($1,561880,$vararg_buffer3);
       if ($21) {
        $115 = 0;
       } else {
        $110 = HEAP32[$24>>2]|0;
        $115 = $110;
       }
       $111 = HEAP8[$1>>0]|0;
       $112 = $111 & 1;
       $113 = ($112<<24>>24)==(0);
       $114 = HEAP32[$23>>2]|0;
       $$ = $113 ? $22 : $114;
       __THREW__ = 0;
       invoke_viiiiiiii(21,($$|0),0,(561712|0),784,1,($115|0),0,(0|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 42;
        break L40;
       }
       $118 = HEAP8[$1>>0]|0;
       $119 = $118 & 1;
       $120 = ($119<<24>>24)==(0);
       if (!($120)) {
        $121 = HEAP32[$23>>2]|0;
        __ZdlPv($121);
       }
      }
      $128 = HEAP32[$8>>2]|0;
      $129 = (($128) + ($i$1$ph72<<3)|0);
      $130 = (($128) + ($$sum37<<3)|0);
      $131 = HEAP32[$9>>2]|0;
      $tmp45 = (($131) + ($neg44))|0;
      $tmp46 = $tmp45 << 3;
      _memmove(($129|0),($130|0),($tmp46|0))|0;
      $132 = HEAP32[$9>>2]|0;
      $133 = (($132) + -1)|0;
      HEAP32[$9>>2] = $133;
      $134 = ($i$1$ph72>>>0)<($133>>>0);
      if (!($134)) {
       $90 = $133;
       break L40;
      }
     }
     $135 = HEAP32[$9>>2]|0;
     $136 = ($$sum37>>>0)<($135>>>0);
     if ($136) {
      $i$1$ph72 = $$sum37;
     } else {
      $90 = $135;
      break;
     }
    }
    if ((label|0) == 42) {
     $122 = ___cxa_find_matching_catch()|0;
     $123 = tempRet0;
     $124 = HEAP8[$1>>0]|0;
     $125 = $124 & 1;
     $126 = ($125<<24>>24)==(0);
     if ($126) {
      $$3 = $122;$$34 = $123;
      ___resumeException($$3|0);
      // unreachable;
     }
     $127 = HEAP32[$23>>2]|0;
     __ZdlPv($127);
     $$3 = $122;$$34 = $123;
     ___resumeException($$3|0);
     // unreachable;
    }
    $89 = ($90|0)==(0);
    if (!($89)) {
     $$pre = HEAP32[$8>>2]|0;
     $315 = $90;$i$254 = 0;
     while(1) {
      $150 = ((($$pre) + ($i$254<<3)|0) + 4|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = (($$pre) + ($i$254<<3)|0);
      $153 = HEAP32[$152>>2]|0;
      $154 = (($151) + 8|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = $155 >>> 21;
      $157 = ($153|0)==($156|0);
      if ($157) {
       $138 = $315;
      } else {
       HEAP32[$152>>2] = $156;
       $$pre74 = HEAP32[$9>>2]|0;
       $138 = $$pre74;
      }
      $158 = (($i$254) + 1)|0;
      $159 = ($158>>>0)<($138>>>0);
      if ($159) {
       $315 = $138;$i$254 = $158;
      } else {
       break;
      }
     }
     $137 = ($138|0)==(0);
     if (!($137)) {
      $139 = (($this) + 4|0);
      $140 = (($6) + 1|0);
      $141 = (($7) + 8|0);
      $142 = (($6) + 8|0);
      $143 = ($this|0)==(0|0);
      $144 = (($2) + 1|0);
      $145 = (($3) + 8|0);
      $146 = (($2) + 8|0);
      $147 = (($4) + 1|0);
      $148 = (($5) + 8|0);
      $149 = (($4) + 8|0);
      $316 = $138;$i$3$ph71 = 0;
      L77: while(1) {
       $$sum = (($i$3$ph71) + 1)|0;
       $neg47 = $i$3$ph71 ^ 536870911;
       $168 = $316;
       L79: while(1) {
        $160 = HEAP32[$8>>2]|0;
        $161 = ((($160) + ($i$3$ph71<<3)|0) + 4|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = ($162|0)==(0|0);
        do {
         if ($163) {
          $235 = (($160) + ($i$3$ph71<<3)|0);
          $236 = HEAP32[$235>>2]|0;
          $237 = (__ZN6Object15ClassIDToStringEi($236)|0);
          __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($7,562016,$237);
          __THREW__ = 0;
          invoke_viii(1627,($6|0),($7|0),(562048|0));
          $238 = __THREW__; __THREW__ = 0;
          $239 = $238&1;
          if ($239) {
           label = 90;
           break L77;
          }
          $240 = HEAP32[$139>>2]|0;
          $241 = HEAP8[$6>>0]|0;
          $242 = $241 & 1;
          $243 = ($242<<24>>24)==(0);
          $244 = HEAP32[$142>>2]|0;
          $$78 = $243 ? $140 : $244;
          __THREW__ = 0;
          invoke_viiiiiiii(21,($$78|0),0,(561712|0),836,1,($240|0),0,(0|0));
          $245 = __THREW__; __THREW__ = 0;
          $246 = $245&1;
          if ($246) {
           label = 91;
           break L77;
          }
          $247 = HEAP8[$6>>0]|0;
          $248 = $247 & 1;
          $249 = ($248<<24>>24)==(0);
          if (!($249)) {
           $250 = HEAP32[$142>>2]|0;
           __ZdlPv($250);
          }
          $251 = HEAP8[$7>>0]|0;
          $252 = $251 & 1;
          $253 = ($252<<24>>24)==(0);
          if ($253) {
           label = 95;
          } else {
           $254 = HEAP32[$141>>2]|0;
           __ZdlPv($254);
           label = 95;
          }
         } else {
          $164 = (($162) + 24|0);
          $165 = HEAP32[$164>>2]|0;
          $166 = ($165|0)==($this|0);
          if ($166) {
           break L79;
          }
          $169 = ($165|0)==(0|0);
          if ($169) {
           HEAP32[$164>>2] = $this;
           $170 = (__ZNK6Object12GetClassNameEv($162)|0);
           __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($3,561952,$170);
           __THREW__ = 0;
           invoke_viii(1627,($2|0),($3|0),(561968|0));
           $171 = __THREW__; __THREW__ = 0;
           $172 = $171&1;
           if ($172) {
            label = 65;
            break L77;
           }
           if ($143) {
            $178 = 0;
           } else {
            $173 = HEAP32[$139>>2]|0;
            $178 = $173;
           }
           $174 = HEAP8[$2>>0]|0;
           $175 = $174 & 1;
           $176 = ($175<<24>>24)==(0);
           $177 = HEAP32[$146>>2]|0;
           $$76 = $176 ? $144 : $177;
           __THREW__ = 0;
           invoke_viiiiiiii(21,($$76|0),0,(561712|0),825,1,($178|0),0,(0|0));
           $179 = __THREW__; __THREW__ = 0;
           $180 = $179&1;
           if ($180) {
            label = 66;
            break L77;
           }
           $181 = HEAP8[$2>>0]|0;
           $182 = $181 & 1;
           $183 = ($182<<24>>24)==(0);
           if (!($183)) {
            $184 = HEAP32[$146>>2]|0;
            __ZdlPv($184);
           }
           $185 = HEAP8[$3>>0]|0;
           $186 = $185 & 1;
           $187 = ($186<<24>>24)==(0);
           if ($187) {
            break;
           }
           $188 = HEAP32[$145>>2]|0;
           __ZdlPv($188);
           break;
          }
          $201 = (__ZNK6Object12GetClassNameEv($162)|0);
          __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($5,562016,$201);
          __THREW__ = 0;
          invoke_viii(1627,($4|0),($5|0),(562048|0));
          $202 = __THREW__; __THREW__ = 0;
          $203 = $202&1;
          if ($203) {
           label = 79;
           break L77;
          }
          if ($143) {
           $209 = 0;
          } else {
           $204 = HEAP32[$139>>2]|0;
           $209 = $204;
          }
          $205 = HEAP8[$4>>0]|0;
          $206 = $205 & 1;
          $207 = ($206<<24>>24)==(0);
          $208 = HEAP32[$149>>2]|0;
          $$77 = $207 ? $147 : $208;
          __THREW__ = 0;
          invoke_viiiiiiii(21,($$77|0),0,(561712|0),830,1,($209|0),0,(0|0));
          $210 = __THREW__; __THREW__ = 0;
          $211 = $210&1;
          if ($211) {
           label = 80;
           break L77;
          }
          $212 = HEAP8[$4>>0]|0;
          $213 = $212 & 1;
          $214 = ($213<<24>>24)==(0);
          if (!($214)) {
           $215 = HEAP32[$149>>2]|0;
           __ZdlPv($215);
          }
          $216 = HEAP8[$5>>0]|0;
          $217 = $216 & 1;
          $218 = ($217<<24>>24)==(0);
          if (!($218)) {
           $219 = HEAP32[$148>>2]|0;
           __ZdlPv($219);
          }
          $220 = HEAP32[$162>>2]|0;
          $221 = (($220) + 44|0);
          $222 = HEAP32[$221>>2]|0;
          FUNCTION_TABLE_vii[$222 & 4095]($162,61);
          label = 95;
         }
        } while(0);
        if ((label|0) == 95) {
         label = 0;
         $267 = HEAP32[$8>>2]|0;
         $268 = (($267) + ($i$3$ph71<<3)|0);
         $269 = (($267) + ($$sum<<3)|0);
         $270 = HEAP32[$9>>2]|0;
         $tmp48 = (($270) + ($neg47))|0;
         $tmp49 = $tmp48 << 3;
         _memmove(($268|0),($269|0),($tmp49|0))|0;
         $271 = HEAP32[$9>>2]|0;
         $272 = (($271) + -1)|0;
         HEAP32[$9>>2] = $272;
        }
        $273 = HEAP32[$9>>2]|0;
        $274 = ($i$3$ph71>>>0)<($273>>>0);
        if ($274) {
         $168 = $273;
        } else {
         break L1;
        }
       }
       $167 = ($$sum>>>0)<($168>>>0);
       if ($167) {
        $316 = $168;$i$3$ph71 = $$sum;
       } else {
        break L1;
       }
      }
      if ((label|0) == 65) {
       $189 = ___cxa_find_matching_catch()|0;
       $190 = tempRet0;
       $$0 = $189;$$01 = $190;
       label = 68;
      }
      else if ((label|0) == 66) {
       $191 = ___cxa_find_matching_catch()|0;
       $192 = tempRet0;
       $193 = HEAP8[$2>>0]|0;
       $194 = $193 & 1;
       $195 = ($194<<24>>24)==(0);
       if ($195) {
        $$0 = $191;$$01 = $192;
        label = 68;
       } else {
        $196 = HEAP32[$146>>2]|0;
        __ZdlPv($196);
        $$0 = $191;$$01 = $192;
        label = 68;
       }
      }
      else if ((label|0) == 79) {
       $223 = ___cxa_find_matching_catch()|0;
       $224 = tempRet0;
       $$1 = $223;$$12 = $224;
       label = 82;
      }
      else if ((label|0) == 80) {
       $225 = ___cxa_find_matching_catch()|0;
       $226 = tempRet0;
       $227 = HEAP8[$4>>0]|0;
       $228 = $227 & 1;
       $229 = ($228<<24>>24)==(0);
       if ($229) {
        $$1 = $225;$$12 = $226;
        label = 82;
       } else {
        $230 = HEAP32[$149>>2]|0;
        __ZdlPv($230);
        $$1 = $225;$$12 = $226;
        label = 82;
       }
      }
      else if ((label|0) == 90) {
       $255 = ___cxa_find_matching_catch()|0;
       $256 = tempRet0;
       $$2 = $255;$$23 = $256;
       label = 93;
      }
      else if ((label|0) == 91) {
       $257 = ___cxa_find_matching_catch()|0;
       $258 = tempRet0;
       $259 = HEAP8[$6>>0]|0;
       $260 = $259 & 1;
       $261 = ($260<<24>>24)==(0);
       if ($261) {
        $$2 = $257;$$23 = $258;
        label = 93;
       } else {
        $262 = HEAP32[$142>>2]|0;
        __ZdlPv($262);
        $$2 = $257;$$23 = $258;
        label = 93;
       }
      }
      if ((label|0) == 68) {
       $197 = HEAP8[$3>>0]|0;
       $198 = $197 & 1;
       $199 = ($198<<24>>24)==(0);
       if ($199) {
        $$3 = $$0;$$34 = $$01;
        ___resumeException($$3|0);
        // unreachable;
       }
       $200 = HEAP32[$145>>2]|0;
       __ZdlPv($200);
       $$3 = $$0;$$34 = $$01;
       ___resumeException($$3|0);
       // unreachable;
      }
      else if ((label|0) == 82) {
       $231 = HEAP8[$5>>0]|0;
       $232 = $231 & 1;
       $233 = ($232<<24>>24)==(0);
       if ($233) {
        $$3 = $$1;$$34 = $$12;
        ___resumeException($$3|0);
        // unreachable;
       }
       $234 = HEAP32[$148>>2]|0;
       __ZdlPv($234);
       $$3 = $$1;$$34 = $$12;
       ___resumeException($$3|0);
       // unreachable;
      }
      else if ((label|0) == 93) {
       $263 = HEAP8[$7>>0]|0;
       $264 = $263 & 1;
       $265 = ($264<<24>>24)==(0);
       if ($265) {
        $$3 = $$2;$$34 = $$23;
        ___resumeException($$3|0);
        // unreachable;
       }
       $266 = HEAP32[$141>>2]|0;
       __ZdlPv($266);
       $$3 = $$2;$$34 = $$23;
       ___resumeException($$3|0);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 __ZN5Unity10GameObject21EnsureUniqueTransformEbb($this,0,0);
 $275 = (($this) + 52|0);
 $276 = HEAP32[$275>>2]|0;
 HEAP32[$275>>2] = 0;
 $277 = (($this) + 48|0);
 $278 = HEAP8[$277>>0]|0;
 $279 = ($278<<24>>24)==(0);
 if (!($279)) {
  STACKTOP = sp;return;
 }
 HEAP32[$275>>2] = 0;
 $280 = (($this) + 24|0);
 $281 = HEAP32[$9>>2]|0;
 $282 = ($281|0)==(0);
 if ($282) {
  STACKTOP = sp;return;
 }
 $283 = HEAP32[$280>>2]|0;
 $317 = 0;$318 = $281;$319 = $283;$i$01$i$i = $283;
 while(1) {
  $284 = (($i$01$i$i) + 4|0);
  $285 = HEAP32[$284>>2]|0;
  $286 = ($285|0)==(0|0);
  if ($286) {
   $295 = $319;$296 = $318;$299 = $317;
  } else {
   $287 = HEAP32[$285>>2]|0;
   $288 = (($287) + 92|0);
   $289 = HEAP32[$288>>2]|0;
   $290 = (FUNCTION_TABLE_ii[$289 & 4095]($285)|0);
   $291 = HEAP32[$275>>2]|0;
   $292 = $291 | $290;
   HEAP32[$275>>2] = $292;
   $$pre$i$i = HEAP32[$280>>2]|0;
   $$pre2$i$i = HEAP32[$9>>2]|0;
   $295 = $$pre$i$i;$296 = $$pre2$i$i;$299 = $292;
  }
  $293 = (($i$01$i$i) + 8|0);
  $294 = (($295) + ($296<<3)|0);
  $297 = ($293|0)==($294|0);
  if ($297) {
   break;
  } else {
   $317 = $299;$318 = $296;$319 = $295;$i$01$i$i = $293;
  }
 }
 $298 = ($276|0)==($299|0);
 $300 = ($296|0)==(0);
 $or$cond$i = $298 | $300;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 } else {
  $320 = $296;$321 = $295;$i$01$i = $295;
 }
 while(1) {
  $301 = (($i$01$i) + 4|0);
  $302 = HEAP32[$301>>2]|0;
  $303 = ($302|0)==(0|0);
  if ($303) {
   $310 = $321;$311 = $320;
  } else {
   $304 = HEAP32[$302>>2]|0;
   $305 = (($304) + 96|0);
   $306 = HEAP32[$305>>2]|0;
   $307 = HEAP32[$275>>2]|0;
   FUNCTION_TABLE_vii[$306 & 4095]($302,$307);
   $$pre$i = HEAP32[$280>>2]|0;
   $$pre2$i = HEAP32[$9>>2]|0;
   $310 = $$pre$i;$311 = $$pre2$i;
  }
  $308 = (($i$01$i) + 8|0);
  $309 = (($310) + ($311<<3)|0);
  $312 = ($308|0)==($309|0);
  if ($312) {
   break;
  } else {
   $320 = $311;$321 = $310;$i$01$i = $308;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData($this,$messageIdentifier,$messageData) {
 $this = $this|0;
 $messageIdentifier = $messageIdentifier|0;
 $messageData = $messageData|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($messageIdentifier) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 24|0);
 $31 = $3;$i$01 = 0;
 while(1) {
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($i$01<<3)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[561544>>2]|0;
  $10 = (($9) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = Math_imul($11, $1)|0;
  $13 = (($12) + ($8))|0;
  $14 = $13 >>> 5;
  $15 = (($9) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($14<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $13 & 31;
  $20 = 1 << $19;
  $21 = $20 & $18;
  $22 = ($21|0)==(0);
  if ($22) {
   $30 = $31;
  } else {
   $23 = ((($6) + ($i$01<<3)|0) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($9) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + ($8<<5)|0);
   __ZN16MessageForwarder13HandleMessageEPviR11MessageData($27,$24,$1,$messageData);
   $$pre = HEAP32[$2>>2]|0;
   $30 = $$pre;
  }
  $28 = (($i$01) + 1)|0;
  $29 = ($28>>>0)<($30>>>0);
  if ($29) {
   $31 = $30;$i$01 = $28;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject6SetTagEj($this,$tag) {
 $this = $this|0;
 $tag = $tag|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 $0 = $tag&65535;
 $1 = (($this) + 44|0);
 HEAP16[$1>>1] = $0;
 __ZN5Unity10GameObject18UpdateActiveGONodeEv($this);
 $2 = (($data) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($data) + 4|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$data>>2] = 0;
 $4 = HEAP32[((564552 + 8|0))>>2]|0;
 $5 = (($this) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 24|0);
 $34 = $6;$i$01$i = 0;
 while(1) {
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($i$01$i<<3)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[561544>>2]|0;
  $13 = (($12) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = Math_imul($14, $4)|0;
  $16 = (($15) + ($11))|0;
  $17 = $16 >>> 5;
  $18 = (($12) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($17<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $16 & 31;
  $23 = 1 << $22;
  $24 = $23 & $21;
  $25 = ($24|0)==(0);
  if ($25) {
   $33 = $34;
  } else {
   $26 = ((($9) + ($i$01$i<<3)|0) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($12) + 16|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + ($11<<5)|0);
   __ZN16MessageForwarder13HandleMessageEPviR11MessageData($30,$27,$4,$data);
   $$pre$i = HEAP32[$5>>2]|0;
   $33 = $$pre$i;
  }
  $31 = (($i$01$i) + 1)|0;
  $32 = ($31>>>0)<($33>>>0);
  if ($32) {
   $34 = $33;$i$01$i = $31;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject12SetHideFlagsEi($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $flags << 14;
 $3 = $2 & 1032192;
 $4 = $1 & -1032193;
 $5 = $4 | $3;
 HEAP32[$0>>2] = $5;
 $6 = (($this) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 24|0);
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($10) + ($i$01<<3)|0) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 44|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vii[$15 & 4095]($12,$flags);
  $16 = (($i$01) + 1)|0;
  $17 = HEAP32[$6>>2]|0;
  $18 = ($16>>>0)<($17>>>0);
  if ($18) {
   $i$01 = $16;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK5Unity10GameObject38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($this,$gc) {
 $this = $this|0;
 $gc = $gc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<3)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $1;
 }
 while(1) {
  $6 = (($i$01) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __Z16MarkObjectAsRootRK6ObjectR27GarbageCollectorThreadState($7,$gc);
  $8 = (($i$01) + 8|0);
  $9 = ($8|0)==($4|0);
  if ($9) {
   break;
  } else {
   $i$01 = $8;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject21SetIsStaticDeprecatedEb($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject23InvokeDestroyedCallbackEPS0_($go) {
 $go = $go|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0|0)==(0|0);
 if (!($0)) {
  abort /* segfault, call an absolute addr */ (($go|0));
 }
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi($classID,$messageIdentifier,$message,$typeId) {
 $classID = $classID|0;
 $messageIdentifier = $messageIdentifier|0;
 $message = $message|0;
 $typeId = $typeId|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[562064>>2]|0;
 $1 = (__ZN5UnityL28GetHighestGOComponentClassIDEv()|0);
 $2 = ($1|0)>($classID|0);
 $3 = $2 ? $1 : $classID;
 $4 = (($3) + 1)|0;
 __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE6resizeEj($0,$4);
 $5 = HEAP32[562064>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($classID<<5)|0);
 $8 = (($messageIdentifier) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN16MessageForwarder23RegisterMessageCallbackEiPFvPviR11MessageDataEi($7,$9,$message,$typeId);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE6resizeEj($this,$__sz) {
 $this = $this|0;
 $__sz = $__sz|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i4$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 5;
 $7 = ($6>>>0)<($__sz>>>0);
 if ($7) {
  $8 = (($__sz) - ($6))|0;
  __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE8__appendEj($this,$8);
  STACKTOP = sp;return;
 }
 $9 = ($6>>>0)>($__sz>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($2) + ($__sz<<5)|0);
 $11 = ($1|0)==($10|0);
 if ($11) {
  STACKTOP = sp;return;
 } else {
  $13 = $1;
 }
 while(1) {
  $12 = (($13) + -32|0);
  HEAP32[$0>>2] = $12;
  $14 = (($13) + -20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $17 = (($13) + -16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==($15|0);
   if (!($19)) {
    $__new_last2$i$i$i$i$i$i$i$i$i$i$i = $15;
    $scevgep$i$i$i$i$i$i$i$i$i$i$i = (($18) + -4|0);
    $20 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i) + ($20)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i;
    $21 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i >>> 2;
    $22 = $21 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i$i$i = (($18) + ($22<<2)|0);
    HEAP32[$17>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($15);
  }
  $23 = HEAP32[$12>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   $27 = (($13) + -28|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==($23|0);
   if (!($29)) {
    $__new_last2$i$i$i$i$i1$i$i$i$i$i$i = $23;
    $scevgep$i$i$i$i$i2$i$i$i$i$i$i = (($28) + -4|0);
    $30 = (0 - ($__new_last2$i$i$i$i$i1$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i4$i$i$i$i$i$i = (($scevgep$i$i$i$i$i2$i$i$i$i$i$i) + ($30)|0);
    $uglygep3$i$i$i$i$i5$i$i$i$i$i$i = $uglygep$i$i$i$i$i4$i$i$i$i$i$i;
    $31 = $uglygep3$i$i$i$i$i5$i$i$i$i$i$i >>> 2;
    $32 = $31 ^ -1;
    $scevgep4$i$i$i$i$i6$i$i$i$i$i$i = (($28) + ($32<<2)|0);
    HEAP32[$27>>2] = $scevgep4$i$i$i$i$i6$i$i$i$i$i$i;
   }
   __ZdlPv($23);
  }
  $25 = HEAP32[$0>>2]|0;
  $26 = ($25|0)==($10|0);
  if ($26) {
   break;
  } else {
   $13 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5UnityL28GetHighestGOComponentClassIDEv() {
 var $$0 = 0, $$lcssa10 = 0, $$pre = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i1 = 0;
 var $classes = 0, $i$012 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $classes = sp;
 $0 = HEAP32[562416>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$classes>>2] = 0;
 $2 = (($classes) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($classes) + 8|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1628,2,($classes|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $22 = HEAP32[$classes>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   ___resumeException($20|0);
   // unreachable;
  }
  $24 = HEAP32[$2>>2]|0;
  $25 = ($24|0)==($22|0);
  if (!($25)) {
   $__new_last2$i$i$i$i$i1 = $22;
   $scevgep$i$i$i$i$i2 = (($24) + -4|0);
   $26 = (0 - ($__new_last2$i$i$i$i$i1))|0;
   $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($26)|0);
   $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
   $27 = $uglygep3$i$i$i$i$i5 >>> 2;
   $28 = $27 ^ -1;
   $scevgep4$i$i$i$i$i6 = (($24) + ($28<<2)|0);
   HEAP32[$2>>2] = $scevgep4$i$i$i$i$i6;
  }
  __ZdlPv($22);
  ___resumeException($20|0);
  // unreachable;
 }
 $6 = HEAP32[$2>>2]|0;
 $7 = HEAP32[$classes>>2]|0;
 $8 = $7;
 $9 = ($6|0)==($7|0);
 if ($9) {
  $$pre15 = HEAP32[562416>>2]|0;
  $$lcssa10 = $6;$34 = $$pre15;
 } else {
  $10 = $6;
  $11 = (($10) - ($8))|0;
  $12 = $11 >> 2;
  $$pre = HEAP32[562416>>2]|0;
  $16 = $$pre;$i$012 = 0;
  while(1) {
   $13 = (($7) + ($i$012<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($16|0)<($14|0);
   $17 = $15 ? $14 : $16;
   HEAP32[562416>>2] = $17;
   $18 = (($i$012) + 1)|0;
   $19 = ($18>>>0)<($12>>>0);
   if ($19) {
    $16 = $17;$i$012 = $18;
   } else {
    $$lcssa10 = $7;$34 = $17;
    break;
   }
  }
 }
 $29 = ($$lcssa10|0)==(0|0);
 if ($29) {
  $$0 = $34;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = ($6|0)==($$lcssa10|0);
 if (!($30)) {
  $scevgep$i$i$i$i$i = (($6) + -4|0);
  $31 = (0 - ($8))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($31)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $32 = $uglygep3$i$i$i$i$i >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i = (($6) + ($33<<2)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($$lcssa10);
 $$0 = $34;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity10GameObject26RegisterAllMessagesHandlerEiPFvPviR11MessageDataEPFbS1_iS3_E($classID,$message,$canHandleNotification) {
 $classID = $classID|0;
 $message = $message|0;
 $canHandleNotification = $canHandleNotification|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[562064>>2]|0;
 $1 = (__ZN5UnityL28GetHighestGOComponentClassIDEv()|0);
 $2 = ($1|0)>($classID|0);
 $3 = $2 ? $1 : $classID;
 $4 = (($3) + 1)|0;
 __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE6resizeEj($0,$4);
 $5 = HEAP32[562064>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($classID<<5)|0);
 __ZN16MessageForwarder27RegisterAllMessagesCallbackEPFvPviR11MessageDataEPFbS0_iS2_E($7,$message,$canHandleNotification);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject25InitializeMessageHandlersEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__new_last2$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i1$i = 0, $__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i = 0, $classID$015$i = 0, $classes$i = 0, $i$017$i = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index3 = 0, $phitmp$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2$i = 0, $scevgep$i$i$i$i$i2$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6$i = 0, $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i = 0, $superClassID$0$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4$i = 0;
 var $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5$i = 0, $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $classes$i = sp;
 $0 = HEAP32[562064>>2]|0;
 HEAP32[$classes$i>>2] = 0;
 $1 = (($classes$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($classes$i) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1628,0,($classes$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   label = 7;
  } else {
   $5 = HEAP32[$1>>2]|0;
   $6 = HEAP32[$classes$i>>2]|0;
   $7 = ($5|0)==($6|0);
   if ($7) {
    $32 = 1;
   } else {
    $8 = $5;
    $9 = $6;
    $10 = (($8) - ($9))|0;
    $11 = $10 >> 2;
    $15 = 0;$i$017$i = 0;
    while(1) {
     $12 = (($6) + ($i$017$i<<2)|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)<($15|0);
     $16 = $14 ? $15 : $13;
     $17 = (($i$017$i) + 1)|0;
     $18 = ($17>>>0)<($11>>>0);
     if ($18) {
      $15 = $16;$i$017$i = $17;
     } else {
      break;
     }
    }
    $phitmp$i = (($16) + 1)|0;
    $32 = $phitmp$i;
   }
   __THREW__ = 0;
   invoke_vii(2592,($0|0),($32|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 7;
   } else {
    $35 = (($0) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$0>>2]|0;
    $38 = ($36|0)==($37|0);
    L10: do {
     if (!($38)) {
      $classID$015$i = 0;
      L11: while(1) {
       __THREW__ = 0;
       $39 = (invoke_ii(3213,($classID$015$i|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        label = 6;
        break;
       }
       $42 = ($39|0)==(0|0);
       L14: do {
        if (!($42)) {
         __THREW__ = 0;
         $43 = (invoke_ii(3214,($classID$015$i|0))|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          label = 6;
          break L11;
         } else {
          $superClassID$0$i = $43;
         }
         while(1) {
          $46 = ($superClassID$0$i|0)==(0);
          if ($46) {
           break L14;
          }
          $47 = HEAP32[$0>>2]|0;
          $48 = (($47) + ($classID$015$i<<5)|0);
          $49 = (($47) + ($superClassID$0$i<<5)|0);
          __THREW__ = 0;
          invoke_vii(2593,($48|0),($49|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           label = 5;
           break L11;
          }
          __THREW__ = 0;
          $52 = (invoke_ii(3214,($superClassID$0$i|0))|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           label = 5;
           break L11;
          } else {
           $superClassID$0$i = $52;
          }
         }
        }
       } while(0);
       $55 = (($classID$015$i) + 1)|0;
       $56 = HEAP32[$35>>2]|0;
       $57 = HEAP32[$0>>2]|0;
       $58 = $56;
       $59 = $57;
       $60 = (($58) - ($59))|0;
       $61 = $60 >> 5;
       $62 = ($55>>>0)<($61>>>0);
       if ($62) {
        $classID$015$i = $55;
       } else {
        break L10;
       }
      }
      if ((label|0) == 5) {
       $19 = ___cxa_find_matching_catch()|0;
       $20 = tempRet0;
       $lpad$phi$i$index = $19;$lpad$phi$i$index3 = $20;
       break L1;
      }
      else if ((label|0) == 6) {
       $21 = ___cxa_find_matching_catch()|0;
       $22 = tempRet0;
       $lpad$phi$i$index = $21;$lpad$phi$i$index3 = $22;
       break L1;
      }
     }
    } while(0);
    $63 = HEAP32[$classes$i>>2]|0;
    $64 = ($63|0)==(0|0);
    if (!($64)) {
     $65 = HEAP32[$1>>2]|0;
     $66 = ($65|0)==($63|0);
     if (!($66)) {
      $__new_last2$i$i$i$i$i$i = $63;
      $scevgep$i$i$i$i$i$i = (($65) + -4|0);
      $67 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($67)|0);
      $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
      $68 = $uglygep3$i$i$i$i$i$i >>> 2;
      $69 = $68 ^ -1;
      $scevgep4$i$i$i$i$i$i = (($65) + ($69<<2)|0);
      HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i;
     }
     __ZdlPv($63);
    }
    $70 = HEAP32[561544>>2]|0;
    $71 = HEAP32[562064>>2]|0;
    __ZN14MessageHandler10InitializeERKNSt3__16vectorI16MessageForwarder13stl_allocatorIS2_L18MemLabelIdentifier1ELi8EEEE($70,$71);
    $72 = HEAP32[562064>>2]|0;
    $73 = HEAP32[$72>>2]|0;
    $74 = (($72) + 4|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($75|0)==($73|0);
    if ($76) {
     STACKTOP = sp;return;
    } else {
     $78 = $75;
    }
    while(1) {
     $77 = (($78) + -32|0);
     HEAP32[$74>>2] = $77;
     $79 = (($78) + -20|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==(0|0);
     if (!($81)) {
      $82 = (($78) + -16|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ($83|0)==($80|0);
      if (!($84)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = $80;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = (($83) + -4|0);
       $85 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i) + ($85)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i;
       $86 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
       $87 = $86 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = (($83) + ($87<<2)|0);
       HEAP32[$82>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i;
      }
      __ZdlPv($80);
     }
     $88 = HEAP32[$77>>2]|0;
     $89 = ($88|0)==(0|0);
     if (!($89)) {
      $92 = (($78) + -28|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = ($93|0)==($88|0);
      if (!($94)) {
       $__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i = $88;
       $scevgep$i$i$i$i$i2$i$i$i$i$i$i$i = (($93) + -4|0);
       $95 = (0 - ($__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i2$i$i$i$i$i$i$i) + ($95)|0);
       $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i;
       $96 = $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i >>> 2;
       $97 = $96 ^ -1;
       $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i = (($93) + ($97<<2)|0);
       HEAP32[$92>>2] = $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i;
      }
      __ZdlPv($88);
     }
     $90 = HEAP32[$74>>2]|0;
     $91 = ($90|0)==($73|0);
     if ($91) {
      break;
     } else {
      $78 = $90;
     }
    }
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  $lpad$phi$i$index = $23;$lpad$phi$i$index3 = $24;
 }
 $25 = HEAP32[$classes$i>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  ___resumeException($lpad$phi$i$index|0);
  // unreachable;
 }
 $27 = HEAP32[$1>>2]|0;
 $28 = ($27|0)==($25|0);
 if (!($28)) {
  $__new_last2$i$i$i$i$i1$i = $25;
  $scevgep$i$i$i$i$i2$i = (($27) + -4|0);
  $29 = (0 - ($__new_last2$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i2$i) + ($29)|0);
  $uglygep3$i$i$i$i$i5$i = $uglygep$i$i$i$i$i4$i;
  $30 = $uglygep3$i$i$i$i$i5$i >>> 2;
  $31 = $30 ^ -1;
  $scevgep4$i$i$i$i$i6$i = (($27) + ($31<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i6$i;
 }
 __ZdlPv($25);
 ___resumeException($lpad$phi$i$index|0);
 // unreachable;
}
function __ZN5Unity10GameObject28InitializeMessageIdentifiersEv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628224>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(60,$$byval_copy1,0,16,561712,1139)|0);
 $4 = HEAP32[628216>>2]|0;
 HEAP32[$3>>2] = $4;
 $5 = (($3) + 4|0);
 $6 = (($3) + 36|0);
 HEAP32[$6>>2] = 0;
 $7 = (($3) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = (($3) + 44|0);
 HEAP32[$8>>2] = 0;
 $9 = (($3) + 52|0);
 HEAP32[$9>>2] = 0;
 $10 = (($3) + 56|0);
 HEAP32[$10>>2] = 0;
 $11 = (($3) + 48|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$11>>2] = $9;
 HEAP32[561544>>2] = $3;
 $12 = HEAP32[628224>>2]|0;
 HEAP32[$1>>2] = $12;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $13 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy1,0,16,561712,1140)|0);
 HEAP32[$13>>2] = 0;
 $14 = (($13) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = (($13) + 8|0);
 HEAP32[$15>>2] = 0;
 HEAP32[562064>>2] = $13;
 $16 = HEAP32[561544>>2]|0;
 __ZN14MessageHandler28InitializeMessageIdentifiersEv($16);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject17GetMessageHandlerEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[561544>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5Unity10GameObject15InitializeClassEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy,0,16,561712,1344)|0);
 $3 = (($2) + 4|0);
 HEAP32[$2>>2] = $2;
 HEAP32[$3>>2] = $2;
 $4 = (($2) + 8|0);
 $5 = (($2) + 12|0);
 HEAP32[$4>>2] = $4;
 HEAP32[$5>>2] = $4;
 HEAP32[562264>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject12CleanupClassEv() {
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[562264>>2]|0;
 $3 = HEAP32[628384>>2]|0;
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 }
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy3);
 HEAP32[562264>>2] = 0;
 $5 = HEAP32[561544>>2]|0;
 $6 = HEAP32[628224>>2]|0;
 $7 = ($5|0)==(0|0);
 if (!($7)) {
  $8 = (($5) + 48|0);
  $9 = (($5) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($8,$10);
  $11 = (($5) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = (($5) + 40|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==($12|0);
   if (!($16)) {
    $__new_last2$i$i$i$i$i$i$i$i = $12;
    $scevgep$i$i$i$i$i$i$i$i = (($15) + -20|0);
    $17 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($17)|0);
    $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
    $18 = (($uglygep3$i$i$i$i$i$i$i$i>>>0) / 20)&-1;
    $19 = $18 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i = (($15) + (($19*20)|0)|0);
    HEAP32[$14>>2] = $scevgep4$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($12);
  }
  $20 = (($5) + 16|0);
  __ZNSt3__113__vector_baseI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEED2Ev($20);
  $21 = (($5) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$5>>2]|0;
  HEAP32[$0>>2] = $23;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($22,$$byval_copy3);
 }
 HEAP32[$1>>2] = $6;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy3);
 HEAP32[561544>>2] = 0;
 $24 = HEAP32[562064>>2]|0;
 $25 = HEAP32[628224>>2]|0;
 $26 = ($24|0)==(0|0);
 if ($26) {
  HEAP32[$0>>2] = $25;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($24,$$byval_copy3);
  HEAP32[562064>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZNSt3__113__vector_baseI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEED2Ev($24);
 HEAP32[$0>>2] = $25;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($24,$$byval_copy3);
 HEAP32[562064>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject17WillHandleMessageERK17MessageIdentifier($this,$messageIdentifier) {
 $this = $this|0;
 $messageIdentifier = $messageIdentifier|0;
 var $$0 = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($messageIdentifier) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 24|0);
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$2>>2]|0;
 $30 = $4;$31 = $6;$i$01 = $6;
 while(1) {
  $7 = HEAP32[$i$01>>2]|0;
  $8 = HEAP32[561544>>2]|0;
  $9 = (($8) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = Math_imul($10, $1)|0;
  $12 = (($11) + ($7))|0;
  $13 = $12 >>> 5;
  $14 = (($8) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + ($13<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $12 & 31;
  $19 = 1 << $18;
  $20 = $19 & $17;
  $21 = ($20|0)==(0);
  if ($21) {
   $27 = $31;$28 = $30;
  } else {
   $22 = (($i$01) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (__ZN14MessageHandler17WillHandleMessageEPvii($8,$23,$7,$1)|0);
   if ($24) {
    $$0 = 1;
    label = 7;
    break;
   }
   $$pre = HEAP32[$2>>2]|0;
   $$pre5 = HEAP32[$3>>2]|0;
   $27 = $$pre;$28 = $$pre5;
  }
  $25 = (($i$01) + 8|0);
  $26 = (($27) + ($28<<3)|0);
  $29 = ($25|0)==($26|0);
  if ($29) {
   $$0 = 0;
   label = 7;
   break;
  } else {
   $30 = $28;$31 = $27;$i$01 = $25;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5Unity10GameObject25TransformParentHasChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 47|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(-1);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN5Unity10GameObject24ActivateAwakeRecursivelyENS_19DeactivateOperationE($this,0);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject14CopyPropertiesERS0_($this,$dest) {
 $this = $this|0;
 $dest = $dest|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($dest) + 40|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 44|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = (($dest) + 44|0);
 HEAP16[$5>>1] = $4;
 $6 = (($this) + 46|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = (($dest) + 46|0);
 HEAP8[$8>>0] = $7;
 $9 = (($dest) + 47|0);
 HEAP8[$9>>0] = -1;
 $10 = (($dest) + 56|0);
 $11 = (($this) + 56|0);
 __ZN14ConstantStringaSERKS_($10,$11);
 STACKTOP = sp;return;
}
function __ZN5Unity17SendMessageDirectER6ObjectRK17MessageIdentifierR11MessageData($target,$messageIdentifier,$messageData) {
 $target = $target|0;
 $messageIdentifier = $messageIdentifier|0;
 $messageData = $messageData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($target) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 21;
 $3 = HEAP32[561544>>2]|0;
 $4 = (($messageIdentifier) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = Math_imul($7, $5)|0;
 $9 = (($8) + ($2))|0;
 $10 = $9 >>> 5;
 $11 = (($3) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($10<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $9 & 31;
 $16 = 1 << $15;
 $17 = $16 & $14;
 $18 = ($17|0)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($3) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($2<<5)|0);
 __ZN16MessageForwarder13HandleMessageEPviR11MessageData($21,$target,$5,$messageData);
 STACKTOP = sp;return;
}
function __ZNK5Unity9Component7GetNameEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__ZNK6Object12GetClassNameEv($this)|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $11 = (($5) + 1|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 } else {
  $9 = (($5) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5Unity9Component7SetNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($1,$name);
 STACKTOP = sp;return;
}
function __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN6ObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((562072 + 8|0));
 $2 = (($this) + 24|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity9Component15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,$messageID,$messageData) {
 $this = $this|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($messageID) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($1) + 24|0);
 $34 = $6;$i$01$i = 0;
 while(1) {
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($i$01$i<<3)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[561544>>2]|0;
  $13 = (($12) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = Math_imul($14, $4)|0;
  $16 = (($15) + ($11))|0;
  $17 = $16 >>> 5;
  $18 = (($12) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + ($17<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $16 & 31;
  $23 = 1 << $22;
  $24 = $23 & $21;
  $25 = ($24|0)==(0);
  if ($25) {
   $33 = $34;
  } else {
   $26 = ((($9) + ($i$01$i<<3)|0) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($12) + 16|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + ($11<<5)|0);
   __ZN16MessageForwarder13HandleMessageEPviR11MessageData($30,$27,$4,$messageData);
   $$pre$i = HEAP32[$5>>2]|0;
   $33 = $$pre$i;
  }
  $31 = (($i$01$i) + 1)|0;
  $32 = ($31>>>0)<($33>>>0);
  if ($32) {
   $34 = $33;$i$01$i = $31;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity9Component13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5Unity9Component38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($this,$gc) {
 $this = $this|0;
 $gc = $gc|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = (($1) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $$0$i = $4;
 }
 __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($$0$i,$gc);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component16CheckConsistencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 L4: do {
  if ($6) {
   $7 = (($2) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $i$02 = 0;
   while(1) {
    $11 = ((($8) + ($i$02<<3)|0) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($this|0);
    $10 = (($i$02) + 1)|0;
    if ($13) {
     break;
    }
    $9 = ($10|0)<($5|0);
    if ($9) {
     $i$02 = $10;
    } else {
     break L4;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $14 = (__ZNK6Object12GetClassNameEv($this)|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $20 = (($14) + 1|0);
  $21 = $20;
 } else {
  $18 = (($14) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $21 = $19;
 }
 HEAP32[$vararg_buffer>>2] = $21;
 __Z6FormatPKcz($0,562192,$vararg_buffer);
 $22 = (($2) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP8[$0>>0]|0;
 $25 = $24 & 1;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $29 = (($0) + 1|0);
  $30 = $29;
 } else {
  $27 = (($0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  $30 = $28;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($30|0),0,(561712|0),1322,1,($23|0),0,(0|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  $40 = HEAP8[$0>>0]|0;
  $41 = $40 & 1;
  $42 = ($41<<24>>24)==(0);
  if ($42) {
   ___resumeException($38|0);
   // unreachable;
  }
  $43 = (($0) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  __ZdlPv($44);
  ___resumeException($38|0);
  // unreachable;
 } else {
  $33 = HEAP8[$0>>0]|0;
  $34 = $33 & 1;
  $35 = ($34<<24>>24)==(0);
  if (!($35)) {
   $36 = (($0) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   __ZdlPv($37);
  }
  __ZN5Unity10GameObject20AddComponentInternalEPNS_9ComponentE($2,$this);
  STACKTOP = sp;return;
 }
}
function __ZN5Unity10GameObject23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562272,562280,$this,0);
 __ZN5Unity10GameObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,562272,562280,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN5Unity10GameObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,562272,562296,$this,0);
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i$i = sp + 4|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,562272,562296,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  $3 = HEAP32[$transfer>>2]|0;
  $4 = $3 & 16384;
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = (($this) + 24|0);
   $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,561528,562344,$converter$i$i$i$i,1)|0);
   $8 = ($7|0)==(0);
   if (!($8)) {
    $9 = ($7|0)>(0);
    if ($9) {
     __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI14SafeBinaryReadEEvRT_($6,$transfer);
    } else {
     $10 = HEAP32[$converter$i$i$i$i>>2]|0;
     $11 = ($10|0)==(0|0);
     if (!($11)) {
      (FUNCTION_TABLE_iii[$10 & 4095]($6,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
  }
 } else {
  $12 = HEAP32[$converter$i$i>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   (FUNCTION_TABLE_iii[$12 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($3,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($3,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($3,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity9Component23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,65601);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0$i$i$i$i$i$i = 0;
 } else {
  $6 = (($4) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $$0$i$i$i$i$i$i = $7;
 }
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($transfer) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiii[$11 & 2047]($9,$$0$i$i$i$i$i$i,$13)|0);
 $15 = (($transfer) + 32|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if (!($17)) {
  $18 = (__Z38PreallocateObjectFromPersistentManagerib($14,0)|0);
  HEAP32[$3>>2] = $18;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObject13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(18)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN15EditorExtension13RegisterClassEv();
 }
 HEAP8[$0>>0] = 20;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=562280+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 11|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,1,18,($0|0),72,(2354|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN5Unity10GameObject7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(72,$$byval_copy2,1,16,561712,90)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1629,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(561712|0),90);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK5Unity10GameObject25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN5Unity9Component13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(18)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN15EditorExtension13RegisterClassEv();
 }
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=562296+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,2,18,($0|0),28,(2355|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN5Unity9Component7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(28,$$byval_copy2,1,16,561712,327)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1619,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((562072 + 8|0));
  $6 = (($3) + 24|0);
  HEAP32[$6>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(561712|0),327);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK5Unity9Component25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2;
}
function __Z23RegisterClass_Componentv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(2,80,0,0,0);
 STACKTOP = sp;return;
}
function __Z24RegisterClass_GameObjectv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(1,81,82,0,83);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObjectD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObjectD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5Unity10GameObjectD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3380,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK5Unity10GameObject7GetNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN5Unity9ComponentD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560936 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __THREW__ = 0;
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch(0|0)|0;
  $7 = tempRet0;
  ___clang_call_terminate($6);
  // unreachable;
 } else {
  ___resumeException($2|0);
  // unreachable;
 }
}
function __ZN5Unity9ComponentD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((560936 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __THREW__ = 0;
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch(0|0)|0;
   $7 = tempRet0;
   ___clang_call_terminate($6);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $3;$eh$lpad$body$indexZ2D = $2;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
 __ZdlPv($this);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN5Unity9Component26CalculateSupportedMessagesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN5Unity9Component26SupportedMessagesDidChangeEi($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5Unity9Component20WillDestroyComponentEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5Unity9Component10DeactivateENS_19DeactivateOperationE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i3 = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = HEAP32[$this>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($7) {
  if ($9) {
   $35 = 0;
  } else {
   $33 = (($8) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = $34;
  }
  HEAP32[$localIdentifier>>2] = $35;
  $36 = $0;
  $37 = $36;
  HEAP32[$37>>2] = 0;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = 0;
  $40 = (($transfer) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 4|0);
  $43 = (($transfer) + 20|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42>>>0)<($44>>>0);
  if ($45) {
   HEAP32[$41>>2] = $35;
   HEAP32[$40>>2] = $42;
   $47 = $42;$49 = $44;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($40,$localIdentifier,4);
   $$pre = HEAP32[$40>>2]|0;
   $$pre5 = HEAP32[$43>>2]|0;
   $47 = $$pre;$49 = $$pre5;
  }
  $46 = (($47) + 8|0);
  $48 = ($46>>>0)<($49>>>0);
  if ($48) {
   $50 = $0;
   $51 = $50;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($50) + 4)|0;
   $54 = $53;
   $55 = HEAP32[$54>>2]|0;
   $56 = $47;
   $57 = $56;
   HEAP32[$57>>2] = $52;
   $58 = (($56) + 4)|0;
   $59 = $58;
   HEAP32[$59>>2] = $55;
   HEAP32[$40>>2] = $46;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($40,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  if ($9) {
   $$0$i3 = 0;
  } else {
   $10 = (($8) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $$0$i3 = $11;
  }
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($$0$i3,$localIdentifier);
  $12 = (($transfer) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 4|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)<($16>>>0);
  if ($17) {
   $18 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$13>>2] = $18;
   HEAP32[$12>>2] = $14;
   $20 = $14;$22 = $16;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($12,$localIdentifier,4);
   $$pre6 = HEAP32[$12>>2]|0;
   $$pre7 = HEAP32[$15>>2]|0;
   $20 = $$pre6;$22 = $$pre7;
  }
  $19 = (($20) + 8|0);
  $21 = ($19>>>0)<($22>>>0);
  if ($21) {
   $23 = $0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + 4)|0;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = $20;
   $30 = $29;
   HEAP32[$30>>2] = $25;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = $28;
   HEAP32[$12>>2] = $19;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($12,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $39 = (($transfer) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 4|0);
  $42 = (($transfer) + 20|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($41>>>0)>($43>>>0);
  if ($44) {
   __ZN12CachedReader15UpdateReadCacheEPvj($39,$localIdentifier,4);
   $$pre$i$i$i1 = HEAP32[$localIdentifier>>2]|0;
   $$pre = HEAP32[$39>>2]|0;
   $$pre13 = HEAP32[$42>>2]|0;
   $46 = $$pre$i$i$i1;$49 = $$pre;$51 = $$pre13;
  } else {
   $45 = HEAP32[$40>>2]|0;
   HEAP32[$localIdentifier>>2] = $45;
   HEAP32[$39>>2] = $41;
   $46 = $45;$49 = $41;$51 = $43;
  }
  $47 = (_llvm_bswap_i32(($46|0))|0);
  HEAP32[$localIdentifier>>2] = $47;
  $48 = (($49) + 8|0);
  $50 = ($48>>>0)>($51>>>0);
  if ($50) {
   __ZN12CachedReader15UpdateReadCacheEPvj($39,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre14 = HEAP32[$localIdentifier>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$62 = $$pre$i$i$i;$64 = $$pre3$i$i$i;$66 = $$pre14;
  } else {
   $52 = $49;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = $0;
   $59 = $58;
   HEAP32[$59>>2] = $54;
   $60 = (($58) + 4)|0;
   $61 = $60;
   HEAP32[$61>>2] = $57;
   HEAP32[$39>>2] = $48;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$62 = $54;$64 = $57;$66 = $47;
  }
  $63 = (_llvm_bswap_i32(($62|0))|0);
  $65 = (_llvm_bswap_i32(($64|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $65;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $63;
  $67 = (__Z38PreallocateObjectFromPersistentManagerib($66,0)|0);
  HEAP32[$this>>2] = $67;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  $10 = (($transfer) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 4|0);
  $13 = (($transfer) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12>>>0)>($14>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre15 = HEAP32[$10>>2]|0;
   $$pre16 = HEAP32[$13>>2]|0;
   $17 = $$pre$i$i$i11;$20 = $$pre15;$22 = $$pre16;
  } else {
   $16 = HEAP32[$11>>2]|0;
   HEAP32[$localIdentifier>>2] = $16;
   HEAP32[$10>>2] = $12;
   $17 = $16;$20 = $12;$22 = $14;
  }
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$localIdentifier>>2] = $18;
  $19 = (($20) + 8|0);
  $21 = ($19>>>0)>($22>>>0);
  if ($21) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$33 = $$pre$i$i$i5;$35 = $$pre3$i$i$i7;
  } else {
   $23 = $20;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + 4)|0;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = $0;
   $30 = $29;
   HEAP32[$30>>2] = $25;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = $28;
   HEAP32[$10>>2] = $19;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$33 = $25;$35 = $28;
  }
  $34 = (_llvm_bswap_i32(($33|0))|0);
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $36;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $34;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $37 = HEAP32[$instanceID>>2]|0;
  $38 = (__Z38PreallocateObjectFromPersistentManagerib($37,$9)|0);
  HEAP32[$this>>2] = $38;
  STACKTOP = sp;return;
 }
}
function __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $33 = (($transfer) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 4|0);
  $36 = (($transfer) + 20|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($35>>>0)>($37>>>0);
  if ($38) {
   __ZN12CachedReader15UpdateReadCacheEPvj($33,$localIdentifier,4);
   $$pre = HEAP32[$33>>2]|0;
   $$pre3 = HEAP32[$36>>2]|0;
   $41 = $$pre;$43 = $$pre3;
  } else {
   $39 = HEAP32[$34>>2]|0;
   HEAP32[$localIdentifier>>2] = $39;
   HEAP32[$33>>2] = $35;
   $41 = $35;$43 = $37;
  }
  $40 = (($41) + 8|0);
  $42 = ($40>>>0)>($43>>>0);
  if ($42) {
   __ZN12CachedReader15UpdateReadCacheEPvj($33,$0,8);
  } else {
   $44 = $41;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 4)|0;
   $48 = $47;
   $49 = HEAP32[$48>>2]|0;
   $50 = $0;
   $51 = $50;
   HEAP32[$51>>2] = $46;
   $52 = (($50) + 4)|0;
   $53 = $52;
   HEAP32[$53>>2] = $49;
   HEAP32[$33>>2] = $40;
  }
  $54 = HEAP32[$localIdentifier>>2]|0;
  $55 = (__Z38PreallocateObjectFromPersistentManagerib($54,0)|0);
  HEAP32[$this>>2] = $55;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  $10 = (($transfer) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 4|0);
  $13 = (($transfer) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12>>>0)>($14>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$localIdentifier,4);
   $$pre4 = HEAP32[$10>>2]|0;
   $$pre5 = HEAP32[$13>>2]|0;
   $18 = $$pre4;$20 = $$pre5;
  } else {
   $16 = HEAP32[$11>>2]|0;
   HEAP32[$localIdentifier>>2] = $16;
   HEAP32[$10>>2] = $12;
   $18 = $12;$20 = $14;
  }
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$0,8);
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$10>>2] = $17;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $31 = HEAP32[$instanceID>>2]|0;
  $32 = (__Z38PreallocateObjectFromPersistentManagerib($31,$9)|0);
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN12ImmediatePtrIN5Unity10GameObjectEE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,562312,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,562328,0);
  $12 = HEAP32[$localIdentifier>>2]|0;
  $13 = (__Z38PreallocateObjectFromPersistentManagerib($12,0)|0);
  HEAP32[$this>>2] = $13;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,562312,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,562328,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $10 = HEAP32[$instanceID>>2]|0;
  $11 = (__Z38PreallocateObjectFromPersistentManagerib($10,$9)|0);
  HEAP32[$this>>2] = $11;
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580592>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  $5 = (($this) + 12|0);
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $13)|0;
  $$sum$i$i$i = (($9) - ($16))|0;
  $17 = (($11) + ($$sum$i$i$i)|0);
  HEAP32[$5>>2] = $17;
  $18 = ($$sum$i$i$i|0)<(0);
  if ($18) {
   label = 6;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
   $19 = (($11) + ($$sum1$i$i$i)|0);
   $20 = (($this) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19>>>0)>($21>>>0);
   if ($22) {
    label = 6;
   } else {
    $23 = HEAP32[$17>>2]|0;
    HEAP32[$data>>2] = $23;
    HEAP32[$5>>2] = $19;
   }
  }
  if ((label|0) == 6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,4);
  }
  $24 = HEAP32[$this>>2]|0;
  $25 = $24 & 512;
  $26 = ($25|0)==(0);
  if (!($26)) {
   $27 = HEAP32[$data>>2]|0;
   $28 = (_llvm_bswap_i32(($27|0))|0);
   HEAP32[$data>>2] = $28;
  }
 } else {
  $29 = HEAP32[$converter$i>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   (FUNCTION_TABLE_iii[$29 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580688>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  $5 = (($this) + 12|0);
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $13)|0;
  $$sum$i$i$i = (($9) - ($16))|0;
  $17 = (($11) + ($$sum$i$i$i)|0);
  HEAP32[$5>>2] = $17;
  $18 = ($$sum$i$i$i|0)<(0);
  if ($18) {
   label = 6;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 8)|0;
   $19 = (($11) + ($$sum1$i$i$i)|0);
   $20 = (($this) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19>>>0)>($21>>>0);
   if ($22) {
    label = 6;
   } else {
    $23 = $17;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 4)|0;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = $data;
    $30 = $29;
    HEAP32[$30>>2] = $25;
    $31 = (($29) + 4)|0;
    $32 = $31;
    HEAP32[$32>>2] = $28;
    HEAP32[$5>>2] = $19;
   }
  }
  if ((label|0) == 6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,8);
  }
  $33 = HEAP32[$this>>2]|0;
  $34 = $33 & 512;
  $35 = ($34|0)==(0);
  if (!($35)) {
   $36 = HEAP32[$data>>2]|0;
   $37 = (_llvm_bswap_i32(($36|0))|0);
   $38 = (($data) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (_llvm_bswap_i32(($39|0))|0);
   HEAP32[$data>>2] = $40;
   HEAP32[$38>>2] = $37;
  }
 } else {
  $41 = HEAP32[$converter$i>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   (FUNCTION_TABLE_iii[$41 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6assignEPKc($this,$__s) {
 $this = $this|0;
 $__s = $__s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($__s|0))|0);
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $10 = $1;$8 = 10;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 & -2;
  $phitmp$i$i = (($5) + -1)|0;
  $6 = $4&255;
  $10 = $6;$8 = $phitmp$i$i;
 }
 $7 = ($8>>>0)<($0>>>0);
 $9 = $10 & 1;
 $11 = ($9<<24>>24)==(0);
 if ($7) {
  if ($11) {
   $25 = $10&255;
   $26 = $25 >>> 1;
   $28 = $26;
  } else {
   $23 = (($this) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $28 = $24;
  }
  $27 = (($0) - ($8))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$8,$27,$28,0,$28,$0,$__s);
  STACKTOP = sp;return ($this|0);
 }
 if ($11) {
  $14 = (($this) + 1|0);
  $15 = $14;
 } else {
  $12 = (($this) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $15 = $13;
 }
 _memmove(($15|0),($__s|0),($0|0))|0;
 $16 = (($15) + ($0)|0);
 HEAP8[$16>>0] = 0;
 $17 = HEAP8[$this>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $21 = $0 << 1;
  $22 = $21&255;
  HEAP8[$this>>0] = $22;
  STACKTOP = sp;return ($this|0);
 } else {
  $20 = (($this) + 4|0);
  HEAP32[$20>>2] = $0;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ph = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = HEAP8[$data>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $8 = $7;
 } else {
  $4 = (($data) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $8 = $5;
 }
 HEAP32[$size>>2] = $8;
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = (($this) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  HEAP32[$10>>2] = $8;
  HEAP32[$9>>2] = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$size,4);
 }
 $15 = HEAP8[$data>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $23 = $15&255;
  $24 = $23 >>> 1;
  $25 = ((($data) + ($24)|0) + 1|0);
  $26 = (($data) + 1|0);
  $$ph = $26;$28 = $25;
 } else {
  $18 = (($data) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($data) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($19) + ($21)|0);
  $$ph = $19;$28 = $22;
 }
 $27 = ($$ph|0)==($28|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $34 = $$ph;
 }
 while(1) {
  $29 = HEAP32[$9>>2]|0;
  $30 = (($29) + 1|0);
  $31 = HEAP32[$12>>2]|0;
  $32 = ($30>>>0)<($31>>>0);
  if ($32) {
   $33 = HEAP8[$34>>0]|0;
   HEAP8[$29>>0] = $33;
   $35 = HEAP32[$9>>2]|0;
   $36 = (($35) + 1|0);
   HEAP32[$9>>2] = $36;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$34,1);
  }
  $37 = (($34) + 1|0);
  $38 = ($37|0)==($28|0);
  if ($38) {
   break;
  } else {
   $34 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i3 = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = HEAP32[$this>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($7) {
  if ($9) {
   $35 = 0;
  } else {
   $33 = (($8) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = $34;
  }
  HEAP32[$localIdentifier>>2] = $35;
  $36 = $0;
  $37 = $36;
  HEAP32[$37>>2] = 0;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = 0;
  $40 = (($transfer) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 4|0);
  $43 = (($transfer) + 20|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42>>>0)<($44>>>0);
  if ($45) {
   HEAP32[$41>>2] = $35;
   HEAP32[$40>>2] = $42;
   $47 = $42;$49 = $44;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($40,$localIdentifier,4);
   $$pre = HEAP32[$40>>2]|0;
   $$pre5 = HEAP32[$43>>2]|0;
   $47 = $$pre;$49 = $$pre5;
  }
  $46 = (($47) + 8|0);
  $48 = ($46>>>0)<($49>>>0);
  if ($48) {
   $50 = $0;
   $51 = $50;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($50) + 4)|0;
   $54 = $53;
   $55 = HEAP32[$54>>2]|0;
   $56 = $47;
   $57 = $56;
   HEAP32[$57>>2] = $52;
   $58 = (($56) + 4)|0;
   $59 = $58;
   HEAP32[$59>>2] = $55;
   HEAP32[$40>>2] = $46;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($40,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  if ($9) {
   $$0$i3 = 0;
  } else {
   $10 = (($8) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $$0$i3 = $11;
  }
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($$0$i3,$localIdentifier);
  $12 = (($transfer) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 4|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)<($16>>>0);
  if ($17) {
   $18 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$13>>2] = $18;
   HEAP32[$12>>2] = $14;
   $20 = $14;$22 = $16;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($12,$localIdentifier,4);
   $$pre6 = HEAP32[$12>>2]|0;
   $$pre7 = HEAP32[$15>>2]|0;
   $20 = $$pre6;$22 = $$pre7;
  }
  $19 = (($20) + 8|0);
  $21 = ($19>>>0)<($22>>>0);
  if ($21) {
   $23 = $0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + 4)|0;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = $20;
   $30 = $29;
   HEAP32[$30>>2] = $25;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = $28;
   HEAP32[$12>>2] = $19;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($12,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ph = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$20 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$20 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $22 = $$pre$i$i$i4;
 } else {
  $21 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $21;
  HEAP32[$1>>2] = $6;
  $22 = $21;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$size1>>2] = $23;
 $24 = HEAP8[$data>>0]|0;
 $25 = $24 & 1;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $29 = $24&255;
  $30 = $29 >>> 1;
  $32 = $30;
 } else {
  $27 = (($data) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $32 = $28;
 }
 $31 = ($32>>>0)<($23>>>0);
 do {
  if ($31) {
   $33 = (($23) - ($32))|0;
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6appendEjc($data,$33,1)|0);
  } else {
   if ($26) {
    $38 = ((($data) + ($23)|0) + 1|0);
    HEAP8[$38>>0] = 0;
    $39 = $23 << 1;
    $40 = $39&255;
    HEAP8[$data>>0] = $40;
    break;
   } else {
    $34 = (($data) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + ($23)|0);
    HEAP8[$36>>0] = 0;
    $37 = (($data) + 4|0);
    HEAP32[$37>>2] = $23;
    break;
   }
  }
 } while(0);
 $41 = HEAP8[$data>>0]|0;
 $42 = $41 & 1;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  $49 = $41&255;
  $50 = $49 >>> 1;
  $51 = ((($data) + ($50)|0) + 1|0);
  $52 = (($data) + 1|0);
  $$ph = $52;$54 = $51;
 } else {
  $44 = (($data) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($data) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + ($47)|0);
  $$ph = $45;$54 = $48;
 }
 $53 = ($$ph|0)==($54|0);
 if ($53) {
  STACKTOP = sp;return;
 } else {
  $60 = $$ph;
 }
 while(1) {
  $55 = HEAP32[$1>>2]|0;
  $56 = (($55) + 1|0);
  $57 = HEAP32[$7>>2]|0;
  $58 = ($56>>>0)>($57>>>0);
  if ($58) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$60,1);
  } else {
   $59 = HEAP8[$55>>0]|0;
   HEAP8[$60>>0] = $59;
   $61 = HEAP32[$1>>2]|0;
   $62 = (($61) + 1|0);
   HEAP32[$1>>2] = $62;
  }
  $63 = (($60) + 1|0);
  $64 = ($63|0)==($54|0);
  if ($64) {
   break;
  } else {
   $60 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6appendEjc($this,$__n,$__c) {
 $this = $this|0;
 $__n = $__n|0;
 $__c = $__c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)==(0);
 if ($0) {
  STACKTOP = sp;return ($this|0);
 }
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $15 = 10;$8 = $1;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 & -2;
  $phitmp$i = (($5) + -1)|0;
  $6 = $4&255;
  $15 = $phitmp$i;$8 = $6;
 }
 $7 = $8 & 1;
 $9 = ($7<<24>>24)==(0);
 if ($9) {
  $12 = $8&255;
  $13 = $12 >>> 1;
  $16 = $13;
 } else {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $16 = $11;
 }
 $14 = (($15) - ($16))|0;
 $17 = ($14>>>0)<($__n>>>0);
 if ($17) {
  $18 = (($__n) - ($15))|0;
  $19 = (($18) + ($16))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE9__grow_byEjjjjjj($this,$15,$19,$16,$16,0,0);
  $$pre = HEAP8[$this>>0]|0;
  $21 = $$pre;
 } else {
  $21 = $8;
 }
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($22) {
  $25 = (($this) + 1|0);
  $27 = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $27 = $24;
 }
 $26 = (($27) + ($16)|0);
 _memset(($26|0),($__c|0),($__n|0))|0;
 $28 = (($16) + ($__n))|0;
 $29 = HEAP8[$this>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $33 = $28 << 1;
  $34 = $33&255;
  HEAP8[$this>>0] = $34;
 } else {
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $28;
 }
 $35 = (($27) + ($28)|0);
 HEAP8[$35>>0] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE9__grow_byEjjjjjj($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 var $$byval_copy1 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (2147483631 - ($__old_cap))|0;
 $2 = ($1>>>0)<($__delta_cap>>>0);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($this) + 1|0);
  $20 = $8;
 } else {
  $6 = (($this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $20 = $7;
 }
 $9 = ($__old_cap>>>0)<(1073741799);
 if ($9) {
  $10 = (($__delta_cap) + ($__old_cap))|0;
  $11 = $__old_cap << 1;
  $12 = ($10>>>0)<($11>>>0);
  $13 = $12 ? $11 : $10;
  $14 = ($13>>>0)<(11);
  if ($14) {
   $17 = 11;
  } else {
   $15 = (($13) + 16)|0;
   $16 = $15 & -16;
   $17 = $16;
  }
 } else {
  $17 = 2147483631;
 }
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($17,16,$$byval_copy1,0,561712,79)|0);
 $19 = ($__n_copy|0)==(0);
 if (!($19)) {
  _memcpy(($18|0),($20|0),($__n_copy|0))|0;
 }
 $21 = (($__old_sz) - ($__n_del))|0;
 $22 = ($21|0)==($__n_copy|0);
 if (!($22)) {
  $23 = (($21) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $24 = (($18) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $25 = (($20) + ($$sum1)|0);
  _memcpy(($24|0),($25|0),($23|0))|0;
 }
 $26 = ($__old_cap|0)==(10);
 if ($26) {
  $31 = (($this) + 8|0);
  HEAP32[$31>>2] = $18;
  $32 = $17 | 1;
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($20|0),($$byval_copy1|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  ___cxa_call_unexpected(($29|0));
  // unreachable;
 } else {
  $31 = (($this) + 8|0);
  HEAP32[$31>>2] = $18;
  $32 = $17 | 1;
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEE19ResizeSTLStyleArrayERS8_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<3)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   $44 = HEAP32[$3>>2]|0;
   $45 = (($44) + 4|0);
   $46 = HEAP32[$9>>2]|0;
   $47 = ($45>>>0)>($46>>>0);
   if ($47) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$04,4);
    $$pre$i$i$i$i$i = HEAP32[$i$04>>2]|0;
    $49 = $$pre$i$i$i$i$i;
   } else {
    $48 = HEAP32[$44>>2]|0;
    HEAP32[$i$04>>2] = $48;
    HEAP32[$3>>2] = $45;
    $49 = $48;
   }
   $50 = (_llvm_bswap_i32(($49|0))|0);
   HEAP32[$i$04>>2] = $50;
   $51 = (($i$04) + 4|0);
   __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($51,$this);
   $52 = (($i$04) + 8|0);
   $53 = ($52|0)==($42|0);
   if ($53) {
    break;
   } else {
    $i$04 = $52;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre5 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre6 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i1;$23 = $$pre6;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = $23 << 3;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = $22 >> 3;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEE19ResizeSTLStyleArrayERS8_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 3;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,561712,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 3;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,561712,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 3;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<3)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<3)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   $30 = (($$01$i$i) + 4|0);
   HEAP32[$30>>2] = 0;
   HEAP32[$$01$i$i>>2] = 0;
  }
  $31 = (($$01$i$i) + 8|0);
  $32 = ($31|0)==($25|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $39 = (($transfer) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 4|0);
  $42 = (($transfer) + 20|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($41>>>0)>($43>>>0);
  if ($44) {
   __ZN12CachedReader15UpdateReadCacheEPvj($39,$localIdentifier,4);
   $$pre$i$i$i1 = HEAP32[$localIdentifier>>2]|0;
   $$pre = HEAP32[$39>>2]|0;
   $$pre13 = HEAP32[$42>>2]|0;
   $46 = $$pre$i$i$i1;$49 = $$pre;$51 = $$pre13;
  } else {
   $45 = HEAP32[$40>>2]|0;
   HEAP32[$localIdentifier>>2] = $45;
   HEAP32[$39>>2] = $41;
   $46 = $45;$49 = $41;$51 = $43;
  }
  $47 = (_llvm_bswap_i32(($46|0))|0);
  HEAP32[$localIdentifier>>2] = $47;
  $48 = (($49) + 8|0);
  $50 = ($48>>>0)>($51>>>0);
  if ($50) {
   __ZN12CachedReader15UpdateReadCacheEPvj($39,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre14 = HEAP32[$localIdentifier>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$62 = $$pre$i$i$i;$64 = $$pre3$i$i$i;$66 = $$pre14;
  } else {
   $52 = $49;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = $0;
   $59 = $58;
   HEAP32[$59>>2] = $54;
   $60 = (($58) + 4)|0;
   $61 = $60;
   HEAP32[$61>>2] = $57;
   HEAP32[$39>>2] = $48;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$62 = $54;$64 = $57;$66 = $47;
  }
  $63 = (_llvm_bswap_i32(($62|0))|0);
  $65 = (_llvm_bswap_i32(($64|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $65;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $63;
  $67 = (__Z38PreallocateObjectFromPersistentManagerib($66,0)|0);
  HEAP32[$this>>2] = $67;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  $10 = (($transfer) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 4|0);
  $13 = (($transfer) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12>>>0)>($14>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre15 = HEAP32[$10>>2]|0;
   $$pre16 = HEAP32[$13>>2]|0;
   $17 = $$pre$i$i$i11;$20 = $$pre15;$22 = $$pre16;
  } else {
   $16 = HEAP32[$11>>2]|0;
   HEAP32[$localIdentifier>>2] = $16;
   HEAP32[$10>>2] = $12;
   $17 = $16;$20 = $12;$22 = $14;
  }
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$localIdentifier>>2] = $18;
  $19 = (($20) + 8|0);
  $21 = ($19>>>0)>($22>>>0);
  if ($21) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$33 = $$pre$i$i$i5;$35 = $$pre3$i$i$i7;
  } else {
   $23 = $20;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + 4)|0;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = $0;
   $30 = $29;
   HEAP32[$30>>2] = $25;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = $28;
   HEAP32[$10>>2] = $19;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$33 = $25;$35 = $28;
  }
  $34 = (_llvm_bswap_i32(($33|0))|0);
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $36;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $34;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $37 = HEAP32[$instanceID>>2]|0;
  $38 = (__Z38PreallocateObjectFromPersistentManagerib($37,$9)|0);
  HEAP32[$this>>2] = $38;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $17 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $17 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$17,$16)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $28 = $$pre;
 } else {
  $18 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $18;
  HEAP32[$1>>2] = $6;
  $28 = $18;
 }
 $19 = HEAP8[$data>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $24 = $19&255;
  $25 = $24 >>> 1;
  $27 = $25;
 } else {
  $22 = (($data) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $27 = $23;
 }
 $26 = ($27>>>0)<($28>>>0);
 do {
  if ($26) {
   $29 = (($28) - ($27))|0;
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6appendEjc($data,$29,1)|0);
  } else {
   if ($21) {
    $34 = ((($data) + ($28)|0) + 1|0);
    HEAP8[$34>>0] = 0;
    $35 = $28 << 1;
    $36 = $35&255;
    HEAP8[$data>>0] = $36;
    break;
   } else {
    $30 = (($data) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + ($28)|0);
    HEAP8[$32>>0] = 0;
    $33 = (($data) + 4|0);
    HEAP32[$33>>2] = $28;
    break;
   }
  }
 } while(0);
 $37 = HEAP32[$size1>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = HEAP8[$data>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  $44 = (($data) + 1|0);
  $45 = $44;
 } else {
  $42 = (($data) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $45 = $43;
 }
 __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$45,$37);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEE19ResizeSTLStyleArrayERS8_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<3)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   $40 = HEAP32[$3>>2]|0;
   $41 = (($40) + 4|0);
   $42 = HEAP32[$9>>2]|0;
   $43 = ($41>>>0)>($42>>>0);
   if ($43) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$02,4);
   } else {
    $44 = HEAP32[$40>>2]|0;
    HEAP32[$i$02>>2] = $44;
    HEAP32[$3>>2] = $41;
   }
   $45 = (($i$02) + 4|0);
   __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($45,$this);
   $46 = (($i$02) + 8|0);
   $47 = ($46|0)==($38|0);
   if ($47) {
    break;
   } else {
    $i$02 = $46;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre3 = HEAP32[$3>>2]|0;
   $$pre4 = HEAP32[$9>>2]|0;
   $14 = $$pre3;$16 = $$pre4;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $14 = $8;$16 = $10;
  }
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre5 = HEAP32[$offset>>2]|0;
   $20 = $$pre5;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$3>>2] = $13;
   $20 = $17;
  }
  $18 = HEAP32[$size>>2]|0;
  $19 = $18 << 3;
  $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
  $22 = (($data) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>(-1);
  if ($24) {
   $25 = HEAP32[$data>>2]|0;
   $26 = (($data) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $28 = $19 >> 3;
  $29 = (($data) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $28 | -2147483648;
  HEAP32[$22>>2] = $30;
  HEAP32[$data>>2] = $21;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $33 = (($transfer) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 4|0);
  $36 = (($transfer) + 20|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($35>>>0)>($37>>>0);
  if ($38) {
   __ZN12CachedReader15UpdateReadCacheEPvj($33,$localIdentifier,4);
   $$pre = HEAP32[$33>>2]|0;
   $$pre3 = HEAP32[$36>>2]|0;
   $41 = $$pre;$43 = $$pre3;
  } else {
   $39 = HEAP32[$34>>2]|0;
   HEAP32[$localIdentifier>>2] = $39;
   HEAP32[$33>>2] = $35;
   $41 = $35;$43 = $37;
  }
  $40 = (($41) + 8|0);
  $42 = ($40>>>0)>($43>>>0);
  if ($42) {
   __ZN12CachedReader15UpdateReadCacheEPvj($33,$0,8);
  } else {
   $44 = $41;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 4)|0;
   $48 = $47;
   $49 = HEAP32[$48>>2]|0;
   $50 = $0;
   $51 = $50;
   HEAP32[$51>>2] = $46;
   $52 = (($50) + 4)|0;
   $53 = $52;
   HEAP32[$53>>2] = $49;
   HEAP32[$33>>2] = $40;
  }
  $54 = HEAP32[$localIdentifier>>2]|0;
  $55 = (__Z38PreallocateObjectFromPersistentManagerib($54,0)|0);
  HEAP32[$this>>2] = $55;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  $10 = (($transfer) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 4|0);
  $13 = (($transfer) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12>>>0)>($14>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$localIdentifier,4);
   $$pre4 = HEAP32[$10>>2]|0;
   $$pre5 = HEAP32[$13>>2]|0;
   $18 = $$pre4;$20 = $$pre5;
  } else {
   $16 = HEAP32[$11>>2]|0;
   HEAP32[$localIdentifier>>2] = $16;
   HEAP32[$10>>2] = $12;
   $18 = $12;$20 = $14;
  }
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$0,8);
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$10>>2] = $17;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $31 = HEAP32[$instanceID>>2]|0;
  $32 = (__Z38PreallocateObjectFromPersistentManagerib($31,$9)|0);
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__112basic_stringIcNS1_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ph = 0, $$ph8 = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = HEAP8[$data>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = $2&255;
  $8 = $7 >>> 1;
  $9 = $8;
 } else {
  $5 = (($data) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $9 = $6;
 }
 HEAP32[$size>>2] = $9;
 $10 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,562392,562392,$size)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$size>>2]|0;
 $12 = HEAP8[$data>>0]|0;
 $13 = $12 & 1;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $17 = $12&255;
  $18 = $17 >>> 1;
  $20 = $18;
 } else {
  $15 = (($data) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $20 = $16;
 }
 $19 = ($20>>>0)<($11>>>0);
 do {
  if ($19) {
   $21 = (($11) - ($20))|0;
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6appendEjc($data,$21,1)|0);
  } else {
   if ($14) {
    $26 = ((($data) + ($11)|0) + 1|0);
    HEAP8[$26>>0] = 0;
    $27 = $11 << 1;
    $28 = $27&255;
    HEAP8[$data>>0] = $28;
    break;
   } else {
    $22 = (($data) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + ($11)|0);
    HEAP8[$24>>0] = 0;
    $25 = (($data) + 4|0);
    HEAP32[$25>>2] = $11;
    break;
   }
  }
 } while(0);
 $29 = HEAP8[$data>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $36 = (($data) + 1|0);
  $37 = $29&255;
  $38 = $37 >>> 1;
  $40 = $36;$41 = $38;
 } else {
  $32 = (($data) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($data) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $40 = $33;$41 = $35;
 }
 $39 = (($40) + ($41)|0);
 $42 = HEAP32[$size>>2]|0;
 $43 = ($42|0)==(0);
 L23: do {
  if (!($43)) {
   $44 = HEAP32[580552>>2]|0;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,562368,$44,0,0)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if (!($53)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $107 = HEAP8[$data>>0]|0;
    $108 = $107 & 1;
    $109 = ($108<<24>>24)==(0);
    if ($109) {
     $112 = (($data) + 1|0);
     $$ph8 = $112;
    } else {
     $110 = (($data) + 8|0);
     $111 = HEAP32[$110>>2]|0;
     $$ph8 = $111;
    }
    $113 = ($$ph8|0)==($39|0);
    if ($113) {
     break;
    } else {
     $114 = $$ph8;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIcEEvRT_PKc17TransferMetaFlags($this,$114,562368,0);
     $115 = (($114) + 1|0);
     $116 = ($115|0)==($39|0);
     if ($116) {
      break L23;
     } else {
      $114 = $115;
     }
    }
   }
   $54 = HEAP32[$46>>2]|0;
   $55 = (($54) + 12|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = HEAP8[$data>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    $62 = (($data) + 1|0);
    $$ph = $62;
   } else {
    $60 = (($data) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    $$ph = $61;
   }
   $63 = ($$ph|0)==($39|0);
   L38: do {
    if (!($63)) {
     $64 = (($this) + 12|0);
     $65 = (($this) + 16|0);
     $66 = (($this) + 28|0);
     $67 = (($this) + 32|0);
     $68 = (($this) + 20|0);
     $102 = $$ph;$70 = 0;$73 = $54;
     while(1) {
      $69 = Math_imul($70, $50)|0;
      $71 = (($69) + ($56))|0;
      $72 = (($73) + 20|0);
      HEAP32[$72>>2] = $71;
      $74 = (($73) + 12|0);
      HEAP32[$74>>2] = $71;
      $75 = (($73) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$73);
      $76 = $1;
      $77 = $76;
      $78 = HEAP32[$77>>2]|0;
      $79 = (($76) + 4)|0;
      $80 = $79;
      $81 = HEAP32[$80>>2]|0;
      $82 = $75;
      $83 = $82;
      HEAP32[$83>>2] = $78;
      $84 = (($82) + 4)|0;
      $85 = $84;
      HEAP32[$85>>2] = $81;
      $86 = HEAP32[$51>>2]|0;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($87) + 1)|0;
      HEAP32[$86>>2] = $88;
      $89 = HEAP32[$46>>2]|0;
      $90 = (($89) + 12|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = HEAP32[$65>>2]|0;
      $93 = HEAP32[$66>>2]|0;
      $94 = HEAP32[$67>>2]|0;
      $95 = Math_imul($94, $93)|0;
      $$sum$i$i$i = (($91) - ($95))|0;
      $96 = (($92) + ($$sum$i$i$i)|0);
      HEAP32[$64>>2] = $96;
      $97 = ($$sum$i$i$i|0)<(0);
      if ($97) {
       label = 26;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
       $98 = (($92) + ($$sum1$i$i$i)|0);
       $99 = HEAP32[$68>>2]|0;
       $100 = ($98>>>0)>($99>>>0);
       if ($100) {
        label = 26;
       } else {
        $101 = HEAP8[$96>>0]|0;
        HEAP8[$102>>0] = $101;
        $103 = HEAP32[$64>>2]|0;
        $104 = (($103) + 1|0);
        HEAP32[$64>>2] = $104;
       }
      }
      if ((label|0) == 26) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($64,$102,1);
      }
      $105 = (($102) + 1|0);
      $106 = ($105|0)==($39|0);
      if ($106) {
       break L38;
      }
      $$pre = HEAP32[$51>>2]|0;
      $$pre10 = HEAP32[$$pre>>2]|0;
      $$pre11 = HEAP32[$46>>2]|0;
      $102 = $105;$70 = $$pre10;$73 = $$pre11;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferIcEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i$i = 0, $$sum1$i$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580552>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 do {
  if ($4) {
   $5 = (($this) + 12|0);
   $6 = (($this) + 80|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($this) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($this) + 32|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = Math_imul($15, $13)|0;
   $$sum$i$i$i$i = (($9) - ($16))|0;
   $17 = (($11) + ($$sum$i$i$i$i)|0);
   HEAP32[$5>>2] = $17;
   $18 = ($$sum$i$i$i$i|0)<(0);
   if (!($18)) {
    $$sum1$i$i$i$i = (($$sum$i$i$i$i) + 1)|0;
    $19 = (($11) + ($$sum1$i$i$i$i)|0);
    $20 = (($this) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($19>>>0)>($21>>>0);
    if (!($22)) {
     $23 = HEAP8[$17>>0]|0;
     HEAP8[$data>>0] = $23;
     $24 = HEAP32[$5>>2]|0;
     $25 = (($24) + 1|0);
     HEAP32[$5>>2] = $25;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,1);
  } else {
   $26 = HEAP32[$converter$i>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    (FUNCTION_TABLE_iii[$26 & 4095]($data,$this)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $converter$i$i = 0;
 var $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $converter$i$i = sp + 16|0;
 $size = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,562392,562392,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayINSt3__14pairIi12ImmediatePtrIN5Unity9ComponentEEEELj4EEE19ResizeSTLStyleArrayERS8_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<3)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580608>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,562368,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $29 = HEAP32[580576>>2]|0;
      $30 = HEAP32[580656>>2]|0;
      $32 = 0;$35 = $24;$i$03 = $27;
      while(1) {
       $31 = Math_imul($32, $20)|0;
       $33 = (($31) + ($26))|0;
       $34 = (($35) + 20|0);
       HEAP32[$34>>2] = $33;
       $36 = (($35) + 12|0);
       HEAP32[$36>>2] = $33;
       $37 = (($35) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$35);
       $38 = $2;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = (($38) + 4)|0;
       $42 = $41;
       $43 = HEAP32[$42>>2]|0;
       $44 = $37;
       $45 = $44;
       HEAP32[$45>>2] = $40;
       $46 = (($44) + 4)|0;
       $47 = $46;
       HEAP32[$47>>2] = $43;
       $48 = HEAP32[$21>>2]|0;
       $49 = HEAP32[$48>>2]|0;
       $50 = (($49) + 1)|0;
       HEAP32[$48>>2] = $50;
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$i$03,$29,0);
       $51 = (($i$03) + 4|0);
       $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$30,562400,$$byval_copy,1)|0);
       $53 = ($52|0)==(0);
       if (!($53)) {
        $54 = ($52|0)>(0);
        if ($54) {
         __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI14SafeBinaryReadEEvRT_($51,$this);
        } else {
         $55 = HEAP32[$$byval_copy>>2]|0;
         $56 = ($55|0)==(0|0);
         if (!($56)) {
          (FUNCTION_TABLE_iii[$55 & 4095]($51,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $57 = (($i$03) + 8|0);
       $58 = ($57|0)==($11|0);
       if ($58) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre7 = HEAP32[$$pre>>2]|0;
       $$pre8 = HEAP32[$16>>2]|0;
       $32 = $$pre7;$35 = $$pre8;$i$03 = $57;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $59 = HEAP32[$data>>2]|0;
   $60 = ($59|0)==($11|0);
   if (!($60)) {
    $61 = HEAP32[580576>>2]|0;
    $62 = HEAP32[580656>>2]|0;
    $i$14 = $59;
    while(1) {
     $63 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,562368,$14,$converter$i$i,1)|0);
     $64 = ($63|0)==(0);
     if (!($64)) {
      $65 = ($63|0)>(0);
      if ($65) {
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$i$14,$61,0);
       $66 = (($i$14) + 4|0);
       $67 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$62,562400,$$byval_copy,1)|0);
       $68 = ($67|0)==(0);
       if (!($68)) {
        $69 = ($67|0)>(0);
        if ($69) {
         __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI14SafeBinaryReadEEvRT_($66,$this);
        } else {
         $70 = HEAP32[$$byval_copy>>2]|0;
         $71 = ($70|0)==(0|0);
         if (!($71)) {
          (FUNCTION_TABLE_iii[$70 & 4095]($66,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $72 = HEAP32[$converter$i$i>>2]|0;
       $73 = ($72|0)==(0|0);
       if (!($73)) {
        (FUNCTION_TABLE_iii[$72 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $74 = (($i$14) + 8|0);
     $75 = ($74|0)==($11|0);
     if ($75) {
      break;
     } else {
      $i$14 = $74;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN12ImmediatePtrIN5Unity9ComponentEE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,562312,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,562328,0);
  $12 = HEAP32[$localIdentifier>>2]|0;
  $13 = (__Z38PreallocateObjectFromPersistentManagerib($12,0)|0);
  HEAP32[$this>>2] = $13;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,562312,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,562328,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $10 = HEAP32[$instanceID>>2]|0;
  $11 = (__Z38PreallocateObjectFromPersistentManagerib($10,$9)|0);
  HEAP32[$this>>2] = $11;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__vector_baseI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  $27 = $1;
 } else {
  $7 = $4;
  while(1) {
   $6 = (($7) + -32|0);
   HEAP32[$3>>2] = $6;
   $8 = (($7) + -20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($7) + -16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($9|0);
    if (!($13)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i = $9;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i = (($12) + -4|0);
     $14 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i) + ($14)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i;
     $15 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i >>> 2;
     $16 = $15 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i = (($12) + ($16<<2)|0);
     HEAP32[$11>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($9);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $21 = (($7) + -28|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($17|0);
    if (!($23)) {
     $__new_last2$i$i$i$i$i1$i$i$i$i$i$i = $17;
     $scevgep$i$i$i$i$i2$i$i$i$i$i$i = (($22) + -4|0);
     $24 = (0 - ($__new_last2$i$i$i$i$i1$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i4$i$i$i$i$i$i = (($scevgep$i$i$i$i$i2$i$i$i$i$i$i) + ($24)|0);
     $uglygep3$i$i$i$i$i5$i$i$i$i$i$i = $uglygep$i$i$i$i$i4$i$i$i$i$i$i;
     $25 = $uglygep3$i$i$i$i$i5$i$i$i$i$i$i >>> 2;
     $26 = $25 ^ -1;
     $scevgep4$i$i$i$i$i6$i$i$i$i$i$i = (($22) + ($26<<2)|0);
     HEAP32[$21>>2] = $scevgep4$i$i$i$i$i6$i$i$i$i$i$i;
    }
    __ZdlPv($17);
   }
   $19 = HEAP32[$3>>2]|0;
   $20 = ($19|0)==($1|0);
   if ($20) {
    break;
   } else {
    $7 = $19;
   }
  }
  $$pre = HEAP32[$this>>2]|0;
  $27 = $$pre;
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  ___cxa_call_unexpected(($30|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($__nd) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i16 = 0, $$0$i17 = 0, $$0$i3 = 0, $$byval_copy = 0, $$pre1$i = 0, $$pre1$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__v = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 5;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    __ZN16MessageForwarderC2Ev($11);
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 32|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = (($this) + 8|0);
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($6) - ($18))|0;
 $20 = $19 >> 5;
 $21 = (($20) + ($__n))|0;
 $22 = ($21|0)<(0);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($5) - ($18))|0;
 $24 = $23 >> 5;
 $25 = ($24>>>0)<(1073741823);
 if ($25) {
  $28 = $23 >> 4;
  $29 = ($28>>>0)<($21>>>0);
  $30 = $29 ? $21 : $28;
  $31 = (($__v) + 12|0);
  HEAP32[$31>>2] = 0;
  $32 = (($__v) + 16|0);
  HEAP32[$32>>2] = $16;
  $33 = ($30|0)==(0);
  if ($33) {
   $$0$i17 = 0;$36 = 0;$41 = $31;
  } else {
   $$0$i16 = $30;$55 = $31;
   label = 10;
  }
 } else {
  $26 = (($__v) + 12|0);
  HEAP32[$26>>2] = 0;
  $27 = (($__v) + 16|0);
  HEAP32[$27>>2] = $16;
  $$0$i16 = 2147483647;$55 = $26;
  label = 10;
 }
 if ((label|0) == 10) {
  $34 = $$0$i16 << 5;
  HEAP32[$0>>2] = 1;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $35 = (__Z15malloc_internaljj10MemLabelIdiPKci($34,8,$$byval_copy,0,561712,79)|0);
  $$0$i17 = $$0$i16;$36 = $35;$41 = $55;
 }
 HEAP32[$__v>>2] = $36;
 $37 = (($36) + ($20<<5)|0);
 $38 = (($__v) + 8|0);
 HEAP32[$38>>2] = $37;
 $39 = (($__v) + 4|0);
 HEAP32[$39>>2] = $37;
 $40 = (($36) + ($$0$i17<<5)|0);
 HEAP32[$41>>2] = $40;
 $$0$i3 = $__n;$$pre1$i4 = $37;
 while(1) {
  $42 = ($$pre1$i4|0)==(0|0);
  if ($42) {
   $46 = 0;
  } else {
   __THREW__ = 0;
   invoke_vi(3381,($$pre1$i4|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    label = 18;
    break;
   } else {
    $46 = $$pre1$i4;
   }
  }
  $45 = (($46) + 32|0);
  HEAP32[$38>>2] = $45;
  $47 = (($$0$i3) + -1)|0;
  $48 = ($47|0)==(0);
  if ($48) {
   break;
  } else {
   $$0$i3 = $47;$$pre1$i4 = $45;
  }
 }
 if ((label|0) == 18) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $lpad$phi$index = $51;$lpad$phi$index2 = $52;
  __ZNSt3__114__split_bufferI16MessageForwarderR13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEED2Ev($__v);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(2594,($this|0),($__v|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  $lpad$phi$index = $53;$lpad$phi$index2 = $54;
  __ZNSt3__114__split_bufferI16MessageForwarderR13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEED2Ev($__v);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 } else {
  __ZNSt3__114__split_bufferI16MessageForwarderR13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEED2Ev($__v);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS4_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i$i$i$i$i = 0, $$06$i = 0, $$pre = 0, $$pre15 = 0, $$pre2$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__v) + 4|0);
 $4 = ($2|0)==($0|0);
 $$pre15 = HEAP32[$3>>2]|0;
 if ($4) {
  $74 = $$pre15;$75 = $0;
  HEAP32[$this>>2] = $74;
  HEAP32[$3>>2] = $75;
  $76 = (($__v) + 8|0);
  $77 = HEAP32[$1>>2]|0;
  $78 = HEAP32[$76>>2]|0;
  HEAP32[$1>>2] = $78;
  HEAP32[$76>>2] = $77;
  $79 = (($this) + 8|0);
  $80 = (($__v) + 12|0);
  $81 = HEAP32[$79>>2]|0;
  $82 = HEAP32[$80>>2]|0;
  HEAP32[$79>>2] = $82;
  HEAP32[$80>>2] = $81;
  $83 = HEAP32[$3>>2]|0;
  HEAP32[$__v>>2] = $83;
  STACKTOP = sp;return;
 } else {
  $$06$i = $2;$7 = $$pre15;
 }
 while(1) {
  $5 = (($$06$i) + -32|0);
  $6 = (($7) + -32|0);
  HEAP32[$6>>2] = 0;
  $8 = (($7) + -28|0);
  HEAP32[$8>>2] = 0;
  $9 = (($7) + -24|0);
  HEAP32[$9>>2] = 0;
  $10 = (($$06$i) + -28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$5>>2]|0;
  $13 = $11;
  $14 = $12;
  $15 = (($13) - ($14))|0;
  $16 = $15 >> 2;
  $17 = ($16|0)==(0);
  if (!($17)) {
   $18 = ($16>>>0)>(1073741823);
   if ($18) {
    label = 4;
    break;
   }
   __THREW__ = 0;
   $21 = (invoke_ii(2988,($15|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    label = 11;
    break;
   }
   HEAP32[$8>>2] = $21;
   HEAP32[$6>>2] = $21;
   $24 = (($21) + ($16<<2)|0);
   HEAP32[$9>>2] = $24;
   $25 = HEAP32[$5>>2]|0;
   $26 = HEAP32[$10>>2]|0;
   $27 = ($25|0)==($26|0);
   if (!($27)) {
    $$01$i$i$i$i$i = $25;$29 = $21;
    while(1) {
     $28 = ($29|0)==(0|0);
     if ($28) {
      $32 = 0;
     } else {
      $30 = HEAP32[$$01$i$i$i$i$i>>2]|0;
      HEAP32[$29>>2] = $30;
      $$pre2$i$i$i$i$i = HEAP32[$8>>2]|0;
      $32 = $$pre2$i$i$i$i$i;
     }
     $31 = (($32) + 4|0);
     HEAP32[$8>>2] = $31;
     $33 = (($$01$i$i$i$i$i) + 4|0);
     $34 = ($33|0)==($26|0);
     if ($34) {
      break;
     } else {
      $$01$i$i$i$i$i = $33;$29 = $31;
     }
    }
   }
  }
  $46 = (($7) + -20|0);
  $47 = (($$06$i) + -20|0);
  __THREW__ = 0;
  invoke_vii(2595,($46|0),($47|0));
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  if ($49) {
   label = 19;
   break;
  }
  $59 = (($7) + -8|0);
  $60 = (($$06$i) + -8|0);
  $61 = $60;
  $62 = $61;
  $63 = HEAP32[$62>>2]|0;
  $64 = (($61) + 4)|0;
  $65 = $64;
  $66 = HEAP32[$65>>2]|0;
  $67 = $59;
  $68 = $67;
  HEAP32[$68>>2] = $63;
  $69 = (($67) + 4)|0;
  $70 = $69;
  HEAP32[$70>>2] = $66;
  $71 = HEAP32[$3>>2]|0;
  $72 = (($71) + -32|0);
  HEAP32[$3>>2] = $72;
  $73 = ($5|0)==($0|0);
  if ($73) {
   label = 25;
   break;
  } else {
   $$06$i = $5;$7 = $72;
  }
 }
 do {
  if ((label|0) == 4) {
   __THREW__ = 0;
   invoke_vi(3308,0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $37 = ___cxa_find_matching_catch()|0;
    $38 = tempRet0;
    $lpad$phi$i$index = $37;$lpad$phi$i$index2 = $38;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 11) {
   $35 = ___cxa_find_matching_catch()|0;
   $36 = tempRet0;
   $lpad$phi$i$index = $35;$lpad$phi$i$index2 = $36;
  }
  else if ((label|0) == 19) {
   $50 = ___cxa_find_matching_catch()|0;
   $51 = tempRet0;
   $52 = HEAP32[$6>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    ___resumeException($50|0);
    // unreachable;
   }
   $54 = HEAP32[$8>>2]|0;
   $55 = ($54|0)==($52|0);
   if (!($55)) {
    $__new_last2$i$i$i$i$i$i$i$i$i = $52;
    $scevgep$i$i$i$i$i$i$i$i$i = (($54) + -4|0);
    $56 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($56)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
    $57 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 2;
    $58 = $57 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i = (($54) + ($58<<2)|0);
    HEAP32[$8>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($52);
   ___resumeException($50|0);
   // unreachable;
  }
  else if ((label|0) == 25) {
   $$pre = HEAP32[$this>>2]|0;
   $74 = $72;$75 = $$pre;
   HEAP32[$this>>2] = $74;
   HEAP32[$3>>2] = $75;
   $76 = (($__v) + 8|0);
   $77 = HEAP32[$1>>2]|0;
   $78 = HEAP32[$76>>2]|0;
   HEAP32[$1>>2] = $78;
   HEAP32[$76>>2] = $77;
   $79 = (($this) + 8|0);
   $80 = (($__v) + 12|0);
   $81 = HEAP32[$79>>2]|0;
   $82 = HEAP32[$80>>2]|0;
   HEAP32[$79>>2] = $82;
   HEAP32[$80>>2] = $81;
   $83 = HEAP32[$3>>2]|0;
   HEAP32[$__v>>2] = $83;
   STACKTOP = sp;return;
  }
 } while(0);
 $39 = HEAP32[$6>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  ___resumeException($lpad$phi$i$index|0);
  // unreachable;
 }
 $41 = HEAP32[$8>>2]|0;
 $42 = ($41|0)==($39|0);
 if (!($42)) {
  $__new_last2$i$i$i$i$i$i$i = $39;
  $scevgep$i$i$i$i$i$i$i = (($41) + -4|0);
  $43 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($43)|0);
  $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
  $44 = $uglygep3$i$i$i$i$i$i$i >>> 2;
  $45 = $44 ^ -1;
  $scevgep4$i$i$i$i$i$i$i = (($41) + ($45<<2)|0);
  HEAP32[$8>>2] = $scevgep4$i$i$i$i$i$i$i;
 }
 __ZdlPv($39);
 ___resumeException($lpad$phi$i$index|0);
 // unreachable;
}
function __ZNSt3__114__split_bufferI16MessageForwarderR13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $7 = $4;
  while(1) {
   $6 = (($7) + -32|0);
   HEAP32[$3>>2] = $6;
   $8 = (($7) + -20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($7) + -16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($9|0);
    if (!($13)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = $9;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = (($12) + -4|0);
     $14 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i) + ($14)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i;
     $15 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
     $16 = $15 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = (($12) + ($16<<2)|0);
     HEAP32[$11>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($9);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $21 = (($7) + -28|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($17|0);
    if (!($23)) {
     $__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i = $17;
     $scevgep$i$i$i$i$i2$i$i$i$i$i$i$i = (($22) + -4|0);
     $24 = (0 - ($__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i2$i$i$i$i$i$i$i) + ($24)|0);
     $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i;
     $25 = $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i >>> 2;
     $26 = $25 ^ -1;
     $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i = (($22) + ($26<<2)|0);
     HEAP32[$21>>2] = $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i;
    }
    __ZdlPv($17);
   }
   $19 = HEAP32[$3>>2]|0;
   $20 = ($19|0)==($2|0);
   if ($20) {
    break;
   } else {
    $7 = $19;
   }
  }
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  ___cxa_call_unexpected(($31|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIiNS_9allocatorIiEEEC2ERKS3_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__first3$i = 0;
 var $__new_last2$i$i$i = 0, $scevgep$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep5$i = 0, $uglygep$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, $uglygep4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($__x) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$__x>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3308,0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   // unreachable;
  }
 } else {
  __THREW__ = 0;
  $13 = (invoke_ii(2988,($7|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   HEAP32[$0>>2] = $13;
   HEAP32[$this>>2] = $13;
   $16 = (($13) + ($8<<2)|0);
   HEAP32[$1>>2] = $16;
   $17 = HEAP32[$__x>>2]|0;
   $18 = HEAP32[$2>>2]|0;
   $19 = ($17|0)==($18|0);
   if ($19) {
    STACKTOP = sp;return;
   }
   $__first3$i = $17;
   $scevgep$i = (($18) + -4|0);
   $20 = (0 - ($__first3$i))|0;
   $uglygep$i = (($scevgep$i) + ($20)|0);
   $uglygep4$i = $uglygep$i;
   $21 = $uglygep4$i >>> 2;
   $$01$i = $17;$23 = $13;
   while(1) {
    $22 = ($23|0)==(0|0);
    if (!($22)) {
     $24 = HEAP32[$$01$i>>2]|0;
     HEAP32[$23>>2] = $24;
    }
    $25 = (($23) + 4|0);
    $26 = (($$01$i) + 4|0);
    $27 = ($26|0)==($18|0);
    if ($27) {
     break;
    } else {
     $$01$i = $26;$23 = $25;
    }
   }
   $28 = (($21) + 1)|0;
   $scevgep5$i = (($13) + ($28<<2)|0);
   HEAP32[$0>>2] = $scevgep5$i;
   STACKTOP = sp;return;
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$this>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$0>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i = $31;
  $scevgep$i$i$i = (($33) + -4|0);
  $35 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($35)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $36 = $uglygep3$i$i$i >>> 2;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i = (($33) + ($37<<2)|0);
  HEAP32[$0>>2] = $scevgep4$i$i$i;
 }
 __ZdlPv($31);
 ___resumeException($29|0);
 // unreachable;
}
function __ZN5Unity10GameObjectD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy6 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((561552 + 8|0));
 $2 = (($this) + 56|0);
 __THREW__ = 0;
 invoke_vi(3382,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $26 = (($this) + 36|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)>(-1);
   if ($28) {
    $29 = (($this) + 24|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($this) + 28|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$0>>2] = $32;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($30|0),($$byval_copy6|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     HEAP32[$29>>2] = 0;
     $$1 = $25;$$12 = $24;
     label = 14;
    }
   } else {
    $$1 = $25;$$12 = $24;
    label = 14;
   }
  } else {
   $5 = (($this) + 36|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)>(-1);
   do {
    if ($7) {
     $8 = (($this) + 24|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($this) + 28|0);
     $11 = HEAP32[$10>>2]|0;
     HEAP32[$1>>2] = $11;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($9|0),($$byval_copy6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      $22 = ___cxa_find_matching_catch()|0;
      $23 = tempRet0;
      $$1 = $23;$$12 = $22;
      label = 14;
      break L1;
     } else {
      HEAP32[$8>>2] = 0;
      break;
     }
    }
   } while(0);
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    STACKTOP = sp;return;
   }
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   __THREW__ = 0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $20 = ___cxa_find_matching_catch(0|0)|0;
    $21 = tempRet0;
    ___clang_call_terminate($20);
    // unreachable;
   } else {
    ___resumeException($16|0);
    // unreachable;
   }
  }
 } while(0);
 do {
  if ((label|0) == 14) {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    __THREW__ = 0;
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    ___resumeException($$12|0);
    // unreachable;
   }
   $39 = ___cxa_find_matching_catch(0|0)|0;
   $40 = tempRet0;
   __THREW__ = 0;
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $43 = ___cxa_find_matching_catch(0|0)|0;
    $44 = tempRet0;
    ___clang_call_terminate($43);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $39;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 $45 = ___cxa_find_matching_catch(0|0)|0;
 $46 = tempRet0;
 $eh$lpad$body$indexZ2D = $45;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __Z14IsWorldPlayingv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1)!=(0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14ManagerContext17InitializeClassesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $scevgep = (($this) + 80|0);
 dest=$scevgep+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (__ZN6Object15StringToClassIDEPKc(562424)|0);
 HEAP32[$scevgep>>2] = $0;
 $1 = (__ZN6Object15StringToClassIDEPKc(562440)|0);
 $2 = (($this) + 84|0);
 HEAP32[$2>>2] = $1;
 $3 = (__ZN6Object15StringToClassIDEPKc(562456)|0);
 $4 = (($this) + 88|0);
 HEAP32[$4>>2] = $3;
 $5 = (__ZN6Object15StringToClassIDEPKc(562472)|0);
 $6 = (($this) + 92|0);
 HEAP32[$6>>2] = $5;
 $7 = (__ZN6Object15StringToClassIDEPKc(562488)|0);
 $8 = (($this) + 96|0);
 HEAP32[$8>>2] = $7;
 $9 = (__ZN6Object15StringToClassIDEPKc(562504)|0);
 $10 = (($this) + 100|0);
 HEAP32[$10>>2] = $9;
 $11 = (__ZN6Object15StringToClassIDEPKc(562520)|0);
 $12 = (($this) + 104|0);
 HEAP32[$12>>2] = $11;
 $13 = (__ZN6Object15StringToClassIDEPKc(562544)|0);
 $14 = (($this) + 108|0);
 HEAP32[$14>>2] = $13;
 $15 = (__ZN6Object15StringToClassIDEPKc(562560)|0);
 $16 = (($this) + 112|0);
 HEAP32[$16>>2] = $15;
 $17 = (__ZN6Object15StringToClassIDEPKc(562584)|0);
 $18 = (($this) + 116|0);
 HEAP32[$18>>2] = $17;
 $19 = (__ZN6Object15StringToClassIDEPKc(562600)|0);
 $20 = (($this) + 120|0);
 HEAP32[$20>>2] = $19;
 $21 = (__ZN6Object15StringToClassIDEPKc(562616)|0);
 $22 = (($this) + 124|0);
 HEAP32[$22>>2] = $21;
 $23 = (__ZN6Object15StringToClassIDEPKc(562632)|0);
 $24 = (($this) + 128|0);
 HEAP32[$24>>2] = $23;
 $25 = (__ZN6Object15StringToClassIDEPKc(562648)|0);
 $26 = (($this) + 132|0);
 HEAP32[$26>>2] = $25;
 $27 = (__ZN6Object15StringToClassIDEPKc(562664)|0);
 $28 = (($this) + 136|0);
 HEAP32[$28>>2] = $27;
 $29 = (__ZN6Object15StringToClassIDEPKc(562688)|0);
 $30 = (($this) + 140|0);
 HEAP32[$30>>2] = $29;
 $31 = (__ZN6Object15StringToClassIDEPKc(562704)|0);
 $32 = (($this) + 144|0);
 HEAP32[$32>>2] = $31;
 $33 = (__ZN6Object15StringToClassIDEPKc(562720)|0);
 $34 = (($this) + 148|0);
 HEAP32[$34>>2] = $33;
 $35 = (__ZN6Object15StringToClassIDEPKc(562736)|0);
 $36 = (($this) + 152|0);
 HEAP32[$36>>2] = $35;
 $37 = (__ZN6Object15StringToClassIDEPKc(562760)|0);
 $38 = (($this) + 156|0);
 HEAP32[$38>>2] = $37;
 STACKTOP = sp;return;
}
function __Z21GetManagerFromContexti($index) {
 $index = $index|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (562776 + ($index<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z31ManagerContextInitializeClassesv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14ManagerContext17InitializeClassesEv(562776);
 STACKTOP = sp;return;
}
function __Z24GetManagerPtrFromContexti($index) {
 $index = $index|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (562776 + ($index<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z22SetManagerPtrInContextiP6Object($index,$ptr) {
 $index = $index|0;
 $ptr = $ptr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (562776 + ($index<<2)|0);
 HEAP32[$0>>2] = $ptr;
 STACKTOP = sp;return;
}
function __Z17GetManagerContextv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (562776|0);
}
function __Z24CollectLevelGameManagersR13dynamic_arrayIiLj4EEb($outputObjects,$stripManagersNotNeededForBuild) {
 $outputObjects = $outputObjects|0;
 $stripManagersNotNeededForBuild = $stripManagersNotNeededForBuild|0;
 var $$byval_copy3 = 0, $$pre$i$i = 0, $$pre$i$i$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $exitcond = 0, $exitcond2 = 0, $i$01 = 0, $i$01$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (__Z17GetManagerContextv()|0);
 $2 = (($outputObjects) + 8|0);
 $3 = (($outputObjects) + 12|0);
 $4 = (($outputObjects) + 4|0);
 if ($stripManagersNotNeededForBuild) {
  $i$01$us = 0;
 } else {
  $i$01 = 0;
  while(1) {
   $54 = (($1) + ($i$01<<2)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    $57 = (($55) + 8|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = $58 >>> 21;
    $60 = HEAP32[560640>>2]|0;
    $61 = Math_imul($60, $59)|0;
    $62 = (($61) + 3)|0;
    $63 = $62 >> 5;
    $64 = $63 << 5;
    $65 = (($62) - ($64))|0;
    $66 = HEAP32[560632>>2]|0;
    $67 = (($66) + ($63<<2)|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = 1 << $65;
    $70 = $69 & $68;
    $71 = ($70|0)==(0);
    if (!($71)) {
     $72 = (($55) + 4|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = HEAP32[$2>>2]|0;
     $75 = (($74) + 1)|0;
     HEAP32[$2>>2] = $75;
     $76 = HEAP32[$3>>2]|0;
     $77 = $76 & 2147483647;
     $78 = ($75>>>0)>($77>>>0);
     if ($78) {
      $79 = $76 << 1;
      $80 = ($79|0)==(0);
      $81 = $80 ? 1 : $79;
      $82 = ($77>>>0)<($81>>>0);
      do {
       if ($82) {
        $83 = ($76|0)>(-1);
        if ($83) {
         HEAP32[$3>>2] = $81;
         $84 = HEAP32[$outputObjects>>2]|0;
         $85 = $81 << 2;
         $86 = HEAP32[$4>>2]|0;
         HEAP32[$0>>2] = $86;
         ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
         $87 = (__Z16realloc_internalPvji10MemLabelIdiPKci($84,$85,4,$$byval_copy3,0,562936,370)|0);
         HEAP32[$outputObjects>>2] = $87;
         break;
        } else {
         $88 = $81 << 2;
         $89 = HEAP32[$4>>2]|0;
         HEAP32[$0>>2] = $89;
         ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
         $90 = (__Z15malloc_internaljj10MemLabelIdiPKci($88,4,$$byval_copy3,0,562936,352)|0);
         $91 = HEAP32[$outputObjects>>2]|0;
         $92 = HEAP32[$2>>2]|0;
         $93 = $92 << 2;
         _memcpy(($90|0),($91|0),($93|0))|0;
         HEAP32[$3>>2] = $81;
         HEAP32[$outputObjects>>2] = $90;
         break;
        }
       }
      } while(0);
      $$pre$i$i = HEAP32[$2>>2]|0;
      $95 = $$pre$i$i;
     } else {
      $95 = $75;
     }
     $94 = (($95) + -1)|0;
     $96 = HEAP32[$outputObjects>>2]|0;
     $97 = (($96) + ($94<<2)|0);
     HEAP32[$97>>2] = $73;
    }
   }
   $98 = (($i$01) + 1)|0;
   $exitcond = ($98|0)==(20);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $98;
   }
  }
  STACKTOP = sp;return;
 }
 while(1) {
  $5 = (($1) + ($i$01$us<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (($6) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 >>> 21;
   $11 = HEAP32[560640>>2]|0;
   $12 = Math_imul($11, $10)|0;
   $13 = (($12) + 3)|0;
   $14 = $13 >> 5;
   $15 = $14 << 5;
   $16 = (($13) - ($15))|0;
   $17 = HEAP32[560632>>2]|0;
   $18 = (($17) + ($14<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = 1 << $16;
   $21 = $20 & $19;
   $22 = ($21|0)==(0);
   if (!($22)) {
    $23 = HEAP32[$6>>2]|0;
    $24 = (($23) + 100|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (FUNCTION_TABLE_ii[$25 & 4095]($6)|0);
    if ($26) {
     $27 = (($6) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = HEAP32[$2>>2]|0;
     $30 = (($29) + 1)|0;
     HEAP32[$2>>2] = $30;
     $31 = HEAP32[$3>>2]|0;
     $32 = $31 & 2147483647;
     $33 = ($30>>>0)>($32>>>0);
     if ($33) {
      $34 = $31 << 1;
      $35 = ($34|0)==(0);
      $36 = $35 ? 1 : $34;
      $37 = ($32>>>0)<($36>>>0);
      do {
       if ($37) {
        $38 = ($31|0)>(-1);
        if ($38) {
         HEAP32[$3>>2] = $36;
         $45 = HEAP32[$outputObjects>>2]|0;
         $46 = $36 << 2;
         $47 = HEAP32[$4>>2]|0;
         HEAP32[$0>>2] = $47;
         ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
         $48 = (__Z16realloc_internalPvji10MemLabelIdiPKci($45,$46,4,$$byval_copy3,0,562936,370)|0);
         HEAP32[$outputObjects>>2] = $48;
         break;
        } else {
         $39 = $36 << 2;
         $40 = HEAP32[$4>>2]|0;
         HEAP32[$0>>2] = $40;
         ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
         $41 = (__Z15malloc_internaljj10MemLabelIdiPKci($39,4,$$byval_copy3,0,562936,352)|0);
         $42 = HEAP32[$outputObjects>>2]|0;
         $43 = HEAP32[$2>>2]|0;
         $44 = $43 << 2;
         _memcpy(($41|0),($42|0),($44|0))|0;
         HEAP32[$3>>2] = $36;
         HEAP32[$outputObjects>>2] = $41;
         break;
        }
       }
      } while(0);
      $$pre$i$i$us = HEAP32[$2>>2]|0;
      $50 = $$pre$i$i$us;
     } else {
      $50 = $30;
     }
     $49 = (($50) + -1)|0;
     $51 = HEAP32[$outputObjects>>2]|0;
     $52 = (($51) + ($49<<2)|0);
     HEAP32[$52>>2] = $28;
    }
   }
  }
  $53 = (($i$01$us) + 1)|0;
  $exitcond2 = ($53|0)==(20);
  if ($exitcond2) {
   break;
  } else {
   $i$01$us = $53;
  }
 }
 STACKTOP = sp;return;
}
function __Z20DestroyLevelManagersv() {
 var $$0$i = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$03 = 0, $loadedLevelManagers = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $loadedLevelManagers = sp + 8|0;
 HEAP32[$loadedLevelManagers>>2] = 0;
 $1 = (($loadedLevelManagers) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($loadedLevelManagers) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($loadedLevelManagers) + 4|0);
 HEAP32[$3>>2] = 61;
 __THREW__ = 0;
 invoke_vii(2596,($loadedLevelManagers|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   $47 = ___cxa_find_matching_catch()|0;
   $48 = tempRet0;
   $lpad$phi$index = $47;$lpad$phi$index2 = $48;
  } else {
   $6 = HEAP32[$loadedLevelManagers>>2]|0;
   $7 = HEAP32[$1>>2]|0;
   $8 = ($7|0)==(0);
   L3: do {
    if (!($8)) {
     $i$03 = $6;
     while(1) {
      $9 = HEAP32[$i$03>>2]|0;
      HEAP32[$0>>2] = $9;
      $10 = HEAP32[560624>>2]|0;
      $11 = ($10|0)==(0|0);
      if ($11) {
       $$0$i = 0;
      } else {
       $12 = (($10) + 36|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = (($10) + 4|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = ($13|0)==($15|0);
       do {
        if ($16) {
         $17 = (($10) + 28|0);
         $18 = HEAP32[$17>>2]|0;
         $19 = (($10) + 32|0);
         $20 = HEAP32[$19>>2]|0;
         $21 = (($18) + ($20<<3)|0);
         $37 = $21;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy6,$10,$0);
         $22 = HEAP32[$$byval_copy6>>2]|0;
         $23 = ($22|0)==(-1);
         $24 = (($10) + 28|0);
         $25 = HEAP32[$24>>2]|0;
         if ($23) {
          $26 = (($10) + 32|0);
          $27 = HEAP32[$26>>2]|0;
          $28 = (($25) + ($27<<3)|0);
          $37 = $28;
          break;
         } else {
          $29 = (($25) + ($22<<3)|0);
          $37 = $29;
          break;
         }
        }
       } while(0);
       $30 = HEAP32[560624>>2]|0;
       $31 = (($30) + 28|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($30) + 32|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + ($34<<3)|0);
       $36 = ($37|0)==($35|0);
       if ($36) {
        $$0$i = 0;
       } else {
        $38 = (($37) + 4|0);
        $39 = HEAP32[$38>>2]|0;
        $$0$i = $39;
       }
      }
      __THREW__ = 0;
      invoke_vii(2597,($$0$i|0),0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      $42 = (($i$03) + 4|0);
      $43 = (($6) + ($7<<2)|0);
      $44 = ($42|0)==($43|0);
      if ($44) {
       break L3;
      } else {
       $i$03 = $42;
      }
     }
     $45 = ___cxa_find_matching_catch()|0;
     $46 = tempRet0;
     $lpad$phi$index = $45;$lpad$phi$index2 = $46;
     break L1;
    }
   } while(0);
   $55 = HEAP32[$2>>2]|0;
   $56 = ($55|0)>(-1);
   if (!($56)) {
    STACKTOP = sp;return;
   }
   $57 = HEAP32[$3>>2]|0;
   HEAP32[$0>>2] = $57;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy6);
   HEAP32[$loadedLevelManagers>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $49 = HEAP32[$2>>2]|0;
 $50 = ($49|0)>(-1);
 if (!($50)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $51 = HEAP32[$loadedLevelManagers>>2]|0;
 $52 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $52;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($51|0),($$byval_copy6|0));
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 if ($54) {
  $58 = ___cxa_find_matching_catch(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 }
 HEAP32[$loadedLevelManagers>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z26PlayerLoadSettingsAndInputRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$dataFile) {
 $agg$result = $agg$result|0;
 $dataFile = $dataFile|0;
 var $$0$i = 0, $$0$i1215 = 0, $$neg2$i$i$i$i$i$i = 0, $$pre = 0, $$sum$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i$i = 0, $__len$03$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i2 = 0, $i$020 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $managers = 0, $managers$idx$val = 0, $managers$idx1$val = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep4$i$i$i$i$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i6 = 0, $vararg_buffer = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 24|0;
 $managers = sp + 8|0;
 $1 = (($managers) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($managers) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($managers) + 12|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2598,($dataFile|0),($managers|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   label = 29;
  } else {
   __THREW__ = 0;
   $6 = (invoke_i(56)|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 29;
   } else {
    $managers$idx$val = HEAP32[$1>>2]|0;
    $managers$idx1$val = HEAP32[$2>>2]|0;
    $9 = $managers$idx1$val;
    $10 = $managers$idx$val;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 3;
    $13 = ($12|0)==(0);
    $i$020 = 0;
    L4: while(1) {
     $16 = (562944 + ($i$020<<2)|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ((($6) + ($17<<2)|0) + 80|0);
     $19 = HEAP32[$18>>2]|0;
     if ($13) {
      $29 = $managers$idx$val;
     } else {
      $22 = $managers$idx$val;$__len$03$i$i$i$i$i$i = $12;
      while(1) {
       $20 = (($__len$03$i$i$i$i$i$i|0) / 2)&-1;
       $21 = (($22) + ($20<<3)|0);
       $23 = HEAP32[$21>>2]|0;
       $24 = ($23|0)<($19|0);
       if ($24) {
        $$sum$i$i$i$i$i$i = (($20) + 1)|0;
        $25 = (($22) + ($$sum$i$i$i$i$i$i<<3)|0);
        $$neg2$i$i$i$i$i$i = (($__len$03$i$i$i$i$i$i) + -1)|0;
        $26 = (($$neg2$i$i$i$i$i$i) - ($20))|0;
        $122 = $25;$__len$0$be$i$i$i$i$i$i = $26;
       } else {
        $122 = $22;$__len$0$be$i$i$i$i$i$i = $20;
       }
       $27 = ($__len$0$be$i$i$i$i$i$i|0)==(0);
       if ($27) {
        $29 = $122;
        break;
       } else {
        $22 = $122;$__len$03$i$i$i$i$i$i = $__len$0$be$i$i$i$i$i$i;
       }
      }
     }
     $28 = ($29|0)==($managers$idx1$val|0);
     L13: do {
      if ($28) {
       $$0$i = 0;
      } else {
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)>($19|0);
       if ($31) {
        $$0$i = 0;
       } else {
        $32 = (($29) + 4|0);
        $33 = HEAP32[$32>>2]|0;
        $34 = ($33|0)==(0);
        do {
         if (!($34)) {
          HEAP32[$0>>2] = $33;
          $35 = HEAP32[560624>>2]|0;
          $36 = ($35|0)==(0|0);
          if ($36) {
           label = 20;
          } else {
           $37 = (($35) + 36|0);
           $38 = HEAP32[$37>>2]|0;
           $39 = (($35) + 4|0);
           $40 = HEAP32[$39>>2]|0;
           $41 = ($38|0)==($40|0);
           do {
            if ($41) {
             $42 = (($35) + 28|0);
             $43 = HEAP32[$42>>2]|0;
             $44 = (($35) + 32|0);
             $45 = HEAP32[$44>>2]|0;
             $46 = (($43) + ($45<<3)|0);
             $62 = $46;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$35,$0);
             $47 = HEAP32[$vararg_buffer>>2]|0;
             $48 = ($47|0)==(-1);
             $49 = (($35) + 28|0);
             $50 = HEAP32[$49>>2]|0;
             if ($48) {
              $51 = (($35) + 32|0);
              $52 = HEAP32[$51>>2]|0;
              $53 = (($50) + ($52<<3)|0);
              $62 = $53;
              break;
             } else {
              $54 = (($50) + ($47<<3)|0);
              $62 = $54;
              break;
             }
            }
           } while(0);
           $55 = HEAP32[560624>>2]|0;
           $56 = (($55) + 28|0);
           $57 = HEAP32[$56>>2]|0;
           $58 = (($55) + 32|0);
           $59 = HEAP32[$58>>2]|0;
           $60 = (($57) + ($59<<3)|0);
           $61 = ($62|0)==($60|0);
           if ($61) {
            label = 20;
           } else {
            $63 = (($62) + 4|0);
            $64 = HEAP32[$63>>2]|0;
            $65 = ($64|0)==(0|0);
            if ($65) {
             label = 20;
            } else {
             $$0$i1215 = $64;
            }
           }
          }
          if ((label|0) == 20) {
           label = 0;
           __THREW__ = 0;
           $66 = (invoke_ii(3215,($33|0))|0);
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 28;
            break L4;
           }
           $69 = ($66|0)==(0|0);
           if ($69) {
            break;
           } else {
            $$0$i1215 = $66;
           }
          }
          $70 = (($$0$i1215) + 8|0);
          $71 = HEAP32[$70>>2]|0;
          $72 = $71 >>> 21;
          $73 = HEAP32[560640>>2]|0;
          $74 = Math_imul($73, $72)|0;
          $75 = $74 >> 5;
          $76 = $75 << 5;
          $77 = (($74) - ($76))|0;
          $78 = HEAP32[560632>>2]|0;
          $79 = (($78) + ($75<<2)|0);
          $80 = HEAP32[$79>>2]|0;
          $81 = 1 << $77;
          $82 = $81 & $80;
          $83 = ($82|0)==(0);
          if (!($83)) {
           $$0$i = $$0$i1215;
           break L13;
          }
         }
        } while(0);
        $$0$i = 0;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vii(2599,($17|0),($$0$i|0));
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if ($85) {
      label = 28;
      break;
     }
     $86 = (($6) + ($17<<2)|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = ($87|0)==(0|0);
     if ($88) {
      label = 27;
      break;
     }
     $89 = (($87) + 8|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = $90 >>> 21;
     $92 = HEAP32[560640>>2]|0;
     $93 = Math_imul($92, $91)|0;
     $94 = (($93) + ($19))|0;
     $95 = $94 >> 5;
     $96 = $95 << 5;
     $97 = (($94) - ($96))|0;
     $98 = HEAP32[560632>>2]|0;
     $99 = (($98) + ($95<<2)|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = 1 << $97;
     $102 = $101 & $100;
     $103 = ($102|0)==(0);
     $15 = (($i$020) + 1)|0;
     if ($103) {
      label = 27;
      break;
     }
     $14 = ($15>>>0)<(5);
     if ($14) {
      $i$020 = $15;
     } else {
      label = 34;
      break;
     }
    }
    if ((label|0) == 27) {
     __THREW__ = 0;
     HEAP32[$vararg_buffer>>2] = $17;
     $vararg_ptr6 = (($vararg_buffer) + 4|0);
     HEAP32[$vararg_ptr6>>2] = $i$020;
     invoke_viii(1617,($agg$result|0),(562968|0),($vararg_buffer|0));
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      label = 29;
      break;
     }
    }
    else if ((label|0) == 28) {
     $106 = ___cxa_find_matching_catch()|0;
     $107 = tempRet0;
     $111 = $managers$idx$val;$lpad$phi$index = $106;$lpad$phi$index2 = $107;
     break;
    }
    else if ((label|0) == 34) {
     ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
    }
    $117 = ($managers$idx$val|0)==(0|0);
    if ($117) {
     STACKTOP = sp;return;
    }
    $118 = ($managers$idx1$val|0)==($managers$idx$val|0);
    if (!($118)) {
     $scevgep$i$i$i$i$i$i$i$i$i = (($managers$idx1$val) + -8|0);
     $119 = (0 - ($10))|0;
     $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($119)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
     $120 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
     $121 = $120 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i = (($managers$idx1$val) + ($121<<3)|0);
     HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($managers$idx$val);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 29) {
  $108 = ___cxa_find_matching_catch()|0;
  $109 = tempRet0;
  $$pre = HEAP32[$1>>2]|0;
  $111 = $$pre;$lpad$phi$index = $108;$lpad$phi$index2 = $109;
 }
 $110 = ($111|0)==(0|0);
 if ($110) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $112 = HEAP32[$2>>2]|0;
 $113 = ($112|0)==($111|0);
 if (!($113)) {
  $__new_last2$i$i$i$i$i$i$i$i$i2 = $111;
  $scevgep$i$i$i$i$i$i$i$i$i3 = (($112) + -8|0);
  $114 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i$i$i3) + ($114)|0);
  $uglygep3$i$i$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i$i$i5;
  $115 = $uglygep3$i$i$i$i$i$i$i$i$i6 >>> 3;
  $116 = $115 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i$i7 = (($112) + ($116<<3)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i$i$i7;
 }
 __ZdlPv($111);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZL21ExtractGlobalManagersRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER10vector_mapIiiNS_4lessIiEENS3_INS_4pairIiiEEEEE($path,$managers) {
 $path = $path|0;
 $managers = $managers|0;
 var $$0 = 0, $$01 = 0, $$byval_copy8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $classID = 0, $classIDs = 0, $i$012 = 0;
 var $instanceID = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $sourceFileIDs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy8 = sp;
 $0 = sp + 56|0;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $sourceFileIDs = sp + 16|0;
 $classIDs = sp + 32|0;
 $classID = sp + 48|0;
 $instanceID = sp + 52|0;
 $3 = (__Z20GetPersistentManagerv()|0);
 __ZN17PersistentManager4LockEv($3);
 $4 = HEAP32[628512>>2]|0;
 HEAP32[$sourceFileIDs>>2] = 0;
 $5 = (($sourceFileIDs) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($sourceFileIDs) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($sourceFileIDs) + 12|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$classIDs>>2] = 0;
 $8 = (($classIDs) + 4|0);
 HEAP32[$8>>2] = $4;
 $9 = (($classIDs) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($classIDs) + 12|0);
 HEAP32[$10>>2] = 0;
 __THREW__ = 0;
 $11 = (invoke_i(57)|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L1: do {
  if ($13) {
   label = 11;
  } else {
   __THREW__ = 0;
   invoke_viiii(330,($11|0),($path|0),($sourceFileIDs|0),($classIDs|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 11;
   } else {
    $16 = HEAP32[$6>>2]|0;
    $17 = ($16|0)==(0);
    L4: do {
     if (!($17)) {
      $92 = $16;$i$012 = 0;
      while(1) {
       $18 = HEAP32[$sourceFileIDs>>2]|0;
       $19 = (($18) + ($i$012<<3)|0);
       $20 = $19;
       $21 = $20;
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + 4)|0;
       $24 = $23;
       $25 = HEAP32[$24>>2]|0;
       $26 = HEAP32[$classIDs>>2]|0;
       $27 = (($26) + ($i$012<<2)|0);
       $28 = HEAP32[$27>>2]|0;
       HEAP32[$classID>>2] = $28;
       $29 = HEAP32[560640>>2]|0;
       $30 = Math_imul($29, $28)|0;
       $31 = (($30) + 6)|0;
       $32 = $31 >> 5;
       $33 = $32 << 5;
       $34 = (($31) - ($33))|0;
       $35 = HEAP32[560632>>2]|0;
       $36 = (($35) + ($32<<2)|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = 1 << $34;
       $39 = $38 & $37;
       $40 = ($39|0)==(0);
       if ($40) {
        $63 = $92;
       } else {
        __THREW__ = 0;
        $41 = (invoke_i(57)|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        $44 = (invoke_iiiii(230,($41|0),($path|0),($22|0),($25|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        HEAP32[$instanceID>>2] = $44;
        __THREW__ = 0;
        invoke_viii(1630,($managers|0),($classID|0),($instanceID|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        $$pre = HEAP32[$6>>2]|0;
        $63 = $$pre;
       }
       $61 = (($i$012) + 1)|0;
       $62 = ($61>>>0)<($63>>>0);
       if ($62) {
        $92 = $63;$i$012 = $61;
       } else {
        break L4;
       }
      }
      $51 = ___cxa_find_matching_catch()|0;
      $52 = tempRet0;
      $lpad$phi$index = $51;$lpad$phi$index2 = $52;
      label = 12;
      break L1;
     }
    } while(0);
    $64 = (($managers) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($managers) + 8|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = HEAP8[$managers>>0]|0;
    HEAP8[$$byval_copy8>>0] = $68;
    __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEvT0_SC_T_($65,$67,$$byval_copy8);
    __THREW__ = 0;
    $69 = (invoke_i(57)|0);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     label = 11;
    } else {
     __THREW__ = 0;
     invoke_vi(3383,($69|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      label = 11;
     } else {
      $74 = HEAP32[$10>>2]|0;
      $75 = ($74|0)>(-1);
      do {
       if ($75) {
        $76 = HEAP32[$classIDs>>2]|0;
        $77 = HEAP32[$8>>2]|0;
        HEAP32[$1>>2] = $77;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($76|0),($$byval_copy8|0));
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         $49 = ___cxa_find_matching_catch()|0;
         $50 = tempRet0;
         $$0 = $49;$$01 = $50;
         break L1;
        } else {
         HEAP32[$classIDs>>2] = 0;
         break;
        }
       }
      } while(0);
      $80 = HEAP32[$7>>2]|0;
      $81 = ($80|0)>(-1);
      if (!($81)) {
       STACKTOP = sp;return;
      }
      $82 = HEAP32[$sourceFileIDs>>2]|0;
      $83 = HEAP32[$5>>2]|0;
      HEAP32[$0>>2] = $83;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($82,$$byval_copy8);
      HEAP32[$sourceFileIDs>>2] = 0;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  $lpad$phi$index = $53;$lpad$phi$index2 = $54;
  label = 12;
 }
 do {
  if ((label|0) == 12) {
   $55 = HEAP32[$10>>2]|0;
   $56 = ($55|0)>(-1);
   if ($56) {
    $57 = HEAP32[$classIDs>>2]|0;
    $58 = HEAP32[$8>>2]|0;
    HEAP32[$0>>2] = $58;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy8|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     $90 = ___cxa_find_matching_catch(0|0)|0;
     $91 = tempRet0;
     ___clang_call_terminate($90);
     // unreachable;
    } else {
     HEAP32[$classIDs>>2] = 0;
     $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
     break;
    }
   } else {
    $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
   }
  }
 } while(0);
 $84 = HEAP32[$7>>2]|0;
 $85 = ($84|0)>(-1);
 if (!($85)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $86 = HEAP32[$sourceFileIDs>>2]|0;
 $87 = HEAP32[$5>>2]|0;
 HEAP32[$2>>2] = $87;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($86|0),($$byval_copy8|0));
 $88 = __THREW__; __THREW__ = 0;
 $89 = $88&1;
 if ($89) {
  $90 = ___cxa_find_matching_catch(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 }
 HEAP32[$sourceFileIDs>>2] = 0;
 ___resumeException($$0|0);
 // unreachable;
}
function __Z24PlayerLoadGlobalManagersPKc($agg$result,$dataFile) {
 $agg$result = $agg$result|0;
 $dataFile = $dataFile|0;
 var $$0 = 0, $$0$i1526 = 0, $$01 = 0, $$byval_copy = 0, $$neg2$i$i$i$i$i$i = 0, $$sum$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i$i = 0, $__len$03$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i = 0, $i$027 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $manager$0 = 0, $managers = 0, $managers$idx$val = 0, $managers$idx2$val = 0, $resetError = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i8 = 0;
 var $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp;
 $0 = sp + 56|0;
 $1 = sp + 8|0;
 $managers = sp + 16|0;
 $2 = sp + 32|0;
 $resetError = sp + 44|0;
 $3 = (($managers) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($managers) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($managers) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (_strlen(($dataFile|0))|0);
 $7 = ($6>>>0)>(4294967279);
 do {
  if ($7) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 42;
   } else {
    // unreachable;
   }
  } else {
   $10 = ($6>>>0)<(11);
   if ($10) {
    $11 = $6 << 1;
    $12 = $11&255;
    HEAP8[$2>>0] = $12;
    $13 = (($2) + 1|0);
    $__p$0$i$i$i = $13;
   } else {
    $14 = (($6) + 16)|0;
    $15 = $14 & -16;
    __THREW__ = 0;
    $16 = (invoke_ii(2988,($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 42;
     break;
    }
    $19 = (($2) + 8|0);
    HEAP32[$19>>2] = $16;
    $20 = $15 | 1;
    HEAP32[$2>>2] = $20;
    $21 = (($2) + 4|0);
    HEAP32[$21>>2] = $6;
    $__p$0$i$i$i = $16;
   }
   _memcpy(($__p$0$i$i$i|0),($dataFile|0),($6|0))|0;
   $22 = (($__p$0$i$i$i) + ($6)|0);
   HEAP8[$22>>0] = 0;
   __THREW__ = 0;
   invoke_vii(2598,($2|0),($managers|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $140 = ___cxa_find_matching_catch()|0;
    $141 = tempRet0;
    $142 = HEAP8[$2>>0]|0;
    $143 = $142 & 1;
    $144 = ($143<<24>>24)==(0);
    if ($144) {
     $$0 = $140;$$01 = $141;
     break;
    }
    $145 = (($2) + 8|0);
    $146 = HEAP32[$145>>2]|0;
    __ZdlPv($146);
    $$0 = $140;$$01 = $141;
    break;
   }
   $25 = HEAP8[$2>>0]|0;
   $26 = $25 & 1;
   $27 = ($26<<24>>24)==(0);
   if (!($27)) {
    $28 = (($2) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    __ZdlPv($29);
   }
   $managers$idx$val = HEAP32[$3>>2]|0;
   $managers$idx2$val = HEAP32[$4>>2]|0;
   $30 = $managers$idx2$val;
   $31 = $managers$idx$val;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = ($33|0)==(0);
   $i$027 = 0;
   L15: while(1) {
    __THREW__ = 0;
    $35 = (invoke_i(56)|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 41;
     break;
    }
    $38 = ((($35) + ($i$027<<2)|0) + 80|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(-1);
    L18: do {
     if ($40) {
      $manager$0 = 0;
     } else {
      if ($34) {
       $50 = $managers$idx$val;
      } else {
       $43 = $managers$idx$val;$__len$03$i$i$i$i$i$i = $33;
       while(1) {
        $41 = (($__len$03$i$i$i$i$i$i|0) / 2)&-1;
        $42 = (($43) + ($41<<3)|0);
        $44 = HEAP32[$42>>2]|0;
        $45 = ($44|0)<($39|0);
        if ($45) {
         $$sum$i$i$i$i$i$i = (($41) + 1)|0;
         $46 = (($43) + ($$sum$i$i$i$i$i$i<<3)|0);
         $$neg2$i$i$i$i$i$i = (($__len$03$i$i$i$i$i$i) + -1)|0;
         $47 = (($$neg2$i$i$i$i$i$i) - ($41))|0;
         $197 = $46;$__len$0$be$i$i$i$i$i$i = $47;
        } else {
         $197 = $43;$__len$0$be$i$i$i$i$i$i = $41;
        }
        $48 = ($__len$0$be$i$i$i$i$i$i|0)==(0);
        if ($48) {
         $50 = $197;
         break;
        } else {
         $43 = $197;$__len$03$i$i$i$i$i$i = $__len$0$be$i$i$i$i$i$i;
        }
       }
      }
      $49 = ($50|0)==($managers$idx2$val|0);
      do {
       if (!($49)) {
        $51 = HEAP32[$50>>2]|0;
        $52 = ($51|0)>($39|0);
        if (!($52)) {
         $53 = (($50) + 4|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = ($54|0)==(0);
         if (!($55)) {
          HEAP32[$1>>2] = $54;
          $56 = HEAP32[560624>>2]|0;
          $57 = ($56|0)==(0|0);
          if ($57) {
           label = 29;
          } else {
           $58 = (($56) + 36|0);
           $59 = HEAP32[$58>>2]|0;
           $60 = (($56) + 4|0);
           $61 = HEAP32[$60>>2]|0;
           $62 = ($59|0)==($61|0);
           do {
            if ($62) {
             $63 = (($56) + 28|0);
             $64 = HEAP32[$63>>2]|0;
             $65 = (($56) + 32|0);
             $66 = HEAP32[$65>>2]|0;
             $67 = (($64) + ($66<<3)|0);
             $83 = $67;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$56,$1);
             $68 = HEAP32[$$byval_copy>>2]|0;
             $69 = ($68|0)==(-1);
             $70 = (($56) + 28|0);
             $71 = HEAP32[$70>>2]|0;
             if ($69) {
              $72 = (($56) + 32|0);
              $73 = HEAP32[$72>>2]|0;
              $74 = (($71) + ($73<<3)|0);
              $83 = $74;
              break;
             } else {
              $75 = (($71) + ($68<<3)|0);
              $83 = $75;
              break;
             }
            }
           } while(0);
           $76 = HEAP32[560624>>2]|0;
           $77 = (($76) + 28|0);
           $78 = HEAP32[$77>>2]|0;
           $79 = (($76) + 32|0);
           $80 = HEAP32[$79>>2]|0;
           $81 = (($78) + ($80<<3)|0);
           $82 = ($83|0)==($81|0);
           if ($82) {
            label = 29;
           } else {
            $84 = (($83) + 4|0);
            $85 = HEAP32[$84>>2]|0;
            $86 = ($85|0)==(0|0);
            if ($86) {
             label = 29;
            } else {
             $$0$i1526 = $85;
            }
           }
          }
          if ((label|0) == 29) {
           label = 0;
           __THREW__ = 0;
           $87 = (invoke_ii(3215,($54|0))|0);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            label = 41;
            break L15;
           }
           $90 = ($87|0)==(0|0);
           if ($90) {
            break;
           } else {
            $$0$i1526 = $87;
           }
          }
          $91 = (($$0$i1526) + 8|0);
          $92 = HEAP32[$91>>2]|0;
          $93 = $92 >>> 21;
          $94 = HEAP32[560640>>2]|0;
          $95 = Math_imul($94, $93)|0;
          $96 = $95 >> 5;
          $97 = $96 << 5;
          $98 = (($95) - ($97))|0;
          $99 = HEAP32[560632>>2]|0;
          $100 = (($99) + ($96<<2)|0);
          $101 = HEAP32[$100>>2]|0;
          $102 = 1 << $98;
          $103 = $102 & $101;
          $104 = ($103|0)==(0);
          if (!($104)) {
           $manager$0 = $$0$i1526;
           break L18;
          }
         }
        }
       }
      } while(0);
      $105 = HEAP32[628384>>2]|0;
      HEAP32[$0>>2] = $105;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $106 = (invoke_iiiii(231,($39|0),0,($$byval_copy|0),0)|0);
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       label = 41;
       break L15;
      }
      $109 = HEAP32[$106>>2]|0;
      $110 = (($109) + 24|0);
      $111 = HEAP32[$110>>2]|0;
      __THREW__ = 0;
      invoke_vi($111|0,($106|0));
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       label = 41;
       break L15;
      }
      $114 = HEAP32[$106>>2]|0;
      $115 = (($114) + 12|0);
      $116 = HEAP32[$115>>2]|0;
      __THREW__ = 0;
      invoke_vii($116|0,($106|0),0);
      $117 = __THREW__; __THREW__ = 0;
      $118 = $117&1;
      if ($118) {
       label = 41;
       break L15;
      }
      __THREW__ = 0;
      $119 = (invoke_ii(3216,($39|0))|0);
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       label = 41;
       break L15;
      }
      $122 = HEAP32[$106>>2]|0;
      $123 = (($122) + 36|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = HEAP8[$119>>0]|0;
      $126 = $125 & 1;
      $127 = ($126<<24>>24)==(0);
      if ($127) {
       $130 = (($119) + 1|0);
       $131 = $130;
      } else {
       $128 = (($119) + 8|0);
       $129 = HEAP32[$128>>2]|0;
       $131 = $129;
      }
      __THREW__ = 0;
      invoke_vii($124|0,($106|0),($131|0));
      $132 = __THREW__; __THREW__ = 0;
      $133 = $132&1;
      if ($133) {
       label = 41;
       break L15;
      }
      __THREW__ = 0;
      HEAP32[$$byval_copy>>2] = $39;
      invoke_vii(2587,(563024|0),($$byval_copy|0));
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       label = 41;
       break L15;
      } else {
       $manager$0 = $106;
      }
     }
    } while(0);
    __THREW__ = 0;
    invoke_vii(2599,($i$027|0),($manager$0|0));
    $147 = __THREW__; __THREW__ = 0;
    $148 = $147&1;
    if ($148) {
     label = 41;
     break;
    }
    $149 = (($i$027) + 1)|0;
    $150 = ($149|0)<(15);
    if ($150) {
     $i$027 = $149;
    } else {
     break;
    }
   }
   if ((label|0) == 41) {
    $136 = ___cxa_find_matching_catch()|0;
    $137 = tempRet0;
    $lpad$phi$index = $136;$lpad$phi$index2 = $137;
    label = 43;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3384,($resetError|0));
   $151 = __THREW__; __THREW__ = 0;
   $152 = $151&1;
   if ($152) {
    label = 42;
   } else {
    $153 = HEAP8[$resetError>>0]|0;
    $154 = $153 & 1;
    $155 = ($154<<24>>24)==(0);
    if ($155) {
     $158 = $153&255;
     $159 = $158 >>> 1;
     $161 = $159;
    } else {
     $156 = (($resetError) + 4|0);
     $157 = HEAP32[$156>>2]|0;
     $161 = $157;
    }
    $160 = ($161|0)==(0);
    if ($160) {
     __THREW__ = 0;
     $175 = (invoke_i(57)|0);
     $176 = __THREW__; __THREW__ = 0;
     $177 = $176&1;
     if ($177) {
      label = 57;
     } else {
      __THREW__ = 0;
      invoke_vi(3385,($175|0));
      $178 = __THREW__; __THREW__ = 0;
      $179 = $178&1;
      if ($179) {
       label = 57;
      } else {
       ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
      }
     }
    } else {
     if ($155) {
      $164 = (($resetError) + 1|0);
      $165 = $164;
     } else {
      $162 = (($resetError) + 8|0);
      $163 = HEAP32[$162>>2]|0;
      $165 = $163;
     }
     __THREW__ = 0;
     HEAP32[$$byval_copy>>2] = $165;
     invoke_viii(1617,($agg$result|0),(563072|0),($$byval_copy|0));
     $166 = __THREW__; __THREW__ = 0;
     $167 = $166&1;
     if ($167) {
      label = 57;
     }
    }
    if ((label|0) == 57) {
     $168 = ___cxa_find_matching_catch()|0;
     $169 = tempRet0;
     $170 = HEAP8[$resetError>>0]|0;
     $171 = $170 & 1;
     $172 = ($171<<24>>24)==(0);
     if ($172) {
      $$0 = $168;$$01 = $169;
      break;
     }
     $173 = (($resetError) + 8|0);
     $174 = HEAP32[$173>>2]|0;
     __ZdlPv($174);
     $$0 = $168;$$01 = $169;
     break;
    }
    $180 = HEAP8[$resetError>>0]|0;
    $181 = $180 & 1;
    $182 = ($181<<24>>24)==(0);
    if (!($182)) {
     $183 = (($resetError) + 8|0);
     $184 = HEAP32[$183>>2]|0;
     __ZdlPv($184);
    }
    $185 = ($managers$idx$val|0)==(0|0);
    if ($185) {
     STACKTOP = sp;return;
    }
    $186 = ($managers$idx2$val|0)==($managers$idx$val|0);
    if (!($186)) {
     $scevgep$i$i$i$i$i$i$i$i$i4 = (($managers$idx2$val) + -8|0);
     $187 = (0 - ($31))|0;
     $uglygep$i$i$i$i$i$i$i$i$i6 = (($scevgep$i$i$i$i$i$i$i$i$i4) + ($187)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i7 = $uglygep$i$i$i$i$i$i$i$i$i6;
     $188 = $uglygep3$i$i$i$i$i$i$i$i$i7 >>> 3;
     $189 = $188 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i8 = (($managers$idx2$val) + ($189<<3)|0);
     HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i$i$i$i8;
    }
    __ZdlPv($managers$idx$val);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 42) {
  $138 = ___cxa_find_matching_catch()|0;
  $139 = tempRet0;
  $lpad$phi$index = $138;$lpad$phi$index2 = $139;
  label = 43;
 }
 if ((label|0) == 43) {
  $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
 }
 $190 = HEAP32[$3>>2]|0;
 $191 = ($190|0)==(0|0);
 if ($191) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $192 = HEAP32[$4>>2]|0;
 $193 = ($192|0)==($190|0);
 if (!($193)) {
  $__new_last2$i$i$i$i$i$i$i$i$i = $190;
  $scevgep$i$i$i$i$i$i$i$i$i = (($192) + -8|0);
  $194 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($194)|0);
  $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
  $195 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
  $196 = $195 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i$i = (($192) + ($196<<3)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
 }
 __ZdlPv($190);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z29ResetManagerContextFromLoadedv($agg$result) {
 $agg$result = $agg$result|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$lcssa = 0, $$lcssa42 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i4 = 0, $allManagers = 0, $i$059 = 0;
 var $j$045 = 0, $lpad$phi$index = 0, $lpad$phi$index8 = 0, $lpad$phi51$index = 0, $lpad$phi51$index2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $allManagers = sp + 24|0;
 $0 = sp;
 $1 = sp + 12|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 $2 = (invoke_i(56)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  $$2 = $24;$$23 = $23;
 } else {
  HEAP32[$allManagers>>2] = 0;
  $5 = (($allManagers) + 4|0);
  HEAP32[$5>>2] = 0;
  $6 = (($allManagers) + 8|0);
  HEAP32[$6>>2] = 0;
  __THREW__ = 0;
  (invoke_iiii(1530,9,($allManagers|0),0)|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  L3: do {
   if ($8) {
    $27 = ___cxa_find_matching_catch()|0;
    $28 = tempRet0;
    $lpad$phi51$index = $27;$lpad$phi51$index2 = $28;
    label = 10;
   } else {
    $9 = (($0) + 1|0);
    $10 = (($0) + 8|0);
    $11 = (($0) + 4|0);
    $12 = (($1) + 1|0);
    $13 = (($1) + 8|0);
    $14 = (($1) + 4|0);
    $i$059 = 0;
    L5: while(1) {
     __THREW__ = 0;
     invoke_vii(2599,($i$059|0),(0|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 8;
      break;
     }
     $17 = ((($2) + ($i$059<<2)|0) + 80|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(-1);
     do {
      if (!($19)) {
       $20 = HEAP32[$5>>2]|0;
       $21 = HEAP32[$allManagers>>2]|0;
       $22 = ($20|0)==($21|0);
       L10: do {
        if ($22) {
         $$lcssa = 0;$$lcssa42 = 0;
        } else {
         $30 = $21;$38 = $18;$49 = 0;$50 = 0;$56 = 0;$j$045 = 0;
         while(1) {
          $29 = (($30) + ($j$045<<2)|0);
          $31 = HEAP32[$29>>2]|0;
          $32 = (($31) + 8|0);
          $33 = HEAP32[$32>>2]|0;
          $34 = $33 >>> 21;
          $35 = HEAP32[560640>>2]|0;
          $36 = Math_imul($35, $34)|0;
          $37 = (($36) + ($38))|0;
          $39 = $37 >> 5;
          $40 = $39 << 5;
          $41 = (($37) - ($40))|0;
          $42 = HEAP32[560632>>2]|0;
          $43 = (($42) + ($39<<2)|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = 1 << $41;
          $46 = $45 & $44;
          $47 = ($46|0)==(0);
          do {
           if ($47) {
            $181 = $50;$182 = $49;$183 = $56;
           } else {
            $48 = ($49|0)==($50|0);
            if (!($48)) {
             $51 = ($49|0)==(0|0);
             if ($51) {
              $53 = 0;
             } else {
              HEAP32[$49>>2] = $31;
              $53 = $49;
             }
             $52 = (($53) + 4|0);
             $181 = $50;$182 = $52;$183 = $56;
             break;
            }
            $54 = $49;
            $55 = $56;
            $57 = (($54) - ($55))|0;
            $58 = $57 >> 2;
            $59 = (($58) + 1)|0;
            $60 = ($59>>>0)>(1073741823);
            if ($60) {
             label = 17;
             break L5;
            }
            $63 = ($58>>>0)<(536870911);
            if ($63) {
             $64 = $57 >> 1;
             $65 = ($64>>>0)<($59>>>0);
             $66 = $65 ? $59 : $64;
             $67 = ($66|0)==(0);
             if ($67) {
              $$0$i3$i$i = 0;$73 = 0;
             } else {
              $$0$i2$i$i = $66;
              label = 21;
             }
            } else {
             $$0$i2$i$i = 1073741823;
             label = 21;
            }
            if ((label|0) == 21) {
             label = 0;
             $68 = $$0$i2$i$i << 2;
             __THREW__ = 0;
             $69 = (invoke_ii(2988,($68|0))|0);
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if ($71) {
              label = 27;
              break L5;
             }
             $$0$i3$i$i = $$0$i2$i$i;$73 = $69;
            }
            $72 = (($73) + ($58<<2)|0);
            $74 = (($73) + ($$0$i3$i$i<<2)|0);
            $75 = ($72|0)==(0|0);
            if (!($75)) {
             $76 = HEAP32[$29>>2]|0;
             HEAP32[$72>>2] = $76;
            }
            $77 = (($73) + ($59<<2)|0);
            _memcpy(($73|0),($56|0),($57|0))|0;
            $78 = ($56|0)==(0|0);
            if ($78) {
             $181 = $74;$182 = $77;$183 = $73;
            } else {
             __ZdlPv($56);
             $181 = $74;$182 = $77;$183 = $73;
            }
           }
          } while(0);
          $85 = (($j$045) + 1)|0;
          $86 = HEAP32[$5>>2]|0;
          $87 = HEAP32[$allManagers>>2]|0;
          $88 = $86;
          $89 = $87;
          $90 = (($88) - ($89))|0;
          $91 = $90 >> 2;
          $92 = ($85>>>0)<($91>>>0);
          if (!($92)) {
           $$lcssa = $182;$$lcssa42 = $183;
           break L10;
          }
          $$pre = HEAP32[$17>>2]|0;
          $30 = $87;$38 = $$pre;$49 = $182;$50 = $181;$56 = $183;$j$045 = $85;
         }
        }
       } while(0);
       $93 = $$lcssa;
       $94 = $$lcssa42;
       $95 = (($93) - ($94))|0;
       $96 = $95 >> 2;
       $97 = ($96|0)==(1);
       if ($97) {
        $98 = HEAP32[$$lcssa42>>2]|0;
        __THREW__ = 0;
        invoke_vii(2599,($i$059|0),($98|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 28;
         break L5;
        }
       } else {
        $101 = ($96|0)==(0);
        $102 = ($i$059|0)<(15);
        if ($101) {
         if ($102) {
          $103 = HEAP32[$17>>2]|0;
          __THREW__ = 0;
          $104 = (invoke_ii(3216,($103|0))|0);
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           label = 28;
           break L5;
          }
          __THREW__ = 0;
          invoke_viii(1631,($0|0),(563104|0),($104|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if ($108) {
           label = 28;
           break L5;
          }
          $109 = HEAP8[$0>>0]|0;
          $110 = $109 & 1;
          $111 = ($110<<24>>24)==(0);
          if ($111) {
           $114 = $109&255;
           $115 = $114 >>> 1;
           $116 = $9;$117 = $115;
          } else {
           $112 = HEAP32[$10>>2]|0;
           $113 = HEAP32[$11>>2]|0;
           $116 = $112;$117 = $113;
          }
          __THREW__ = 0;
          (invoke_iiii(1480,($agg$result|0),($116|0),($117|0))|0);
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          if ($119) {
           label = 45;
           break L5;
          }
          $120 = HEAP8[$0>>0]|0;
          $121 = $120 & 1;
          $122 = ($121<<24>>24)==(0);
          if (!($122)) {
           $123 = HEAP32[$10>>2]|0;
           __ZdlPv($123);
          }
         }
        } else {
         if ($102) {
          $130 = HEAP32[$17>>2]|0;
          __THREW__ = 0;
          $131 = (invoke_ii(3216,($130|0))|0);
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           label = 28;
           break L5;
          }
          __THREW__ = 0;
          invoke_viii(1631,($1|0),(563120|0),($131|0));
          $134 = __THREW__; __THREW__ = 0;
          $135 = $134&1;
          if ($135) {
           label = 28;
           break L5;
          }
          $136 = HEAP8[$1>>0]|0;
          $137 = $136 & 1;
          $138 = ($137<<24>>24)==(0);
          if ($138) {
           $141 = $136&255;
           $142 = $141 >>> 1;
           $143 = $12;$144 = $142;
          } else {
           $139 = HEAP32[$13>>2]|0;
           $140 = HEAP32[$14>>2]|0;
           $143 = $139;$144 = $140;
          }
          __THREW__ = 0;
          (invoke_iiii(1480,($agg$result|0),($143|0),($144|0))|0);
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          if ($146) {
           label = 56;
           break L5;
          }
          $147 = HEAP8[$1>>0]|0;
          $148 = $147 & 1;
          $149 = ($148<<24>>24)==(0);
          if (!($149)) {
           $150 = HEAP32[$13>>2]|0;
           __ZdlPv($150);
          }
         }
        }
        $157 = ($$lcssa42|0)==(0|0);
        if ($157) {
         break;
        }
       }
       __ZdlPv($$lcssa42);
      }
     } while(0);
     $158 = (($i$059) + 1)|0;
     $159 = ($158|0)<(20);
     if ($159) {
      $i$059 = $158;
     } else {
      label = 63;
      break;
     }
    }
    do {
     if ((label|0) == 8) {
      $25 = ___cxa_find_matching_catch()|0;
      $26 = tempRet0;
      $lpad$phi51$index = $25;$lpad$phi51$index2 = $26;
      label = 10;
      break L3;
     }
     else if ((label|0) == 17) {
      __THREW__ = 0;
      invoke_vi(3308,0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       $83 = ___cxa_find_matching_catch()|0;
       $84 = tempRet0;
       $184 = $56;$lpad$phi$index = $83;$lpad$phi$index8 = $84;
       label = 30;
       break;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 27) {
      $79 = ___cxa_find_matching_catch()|0;
      $80 = tempRet0;
      $184 = $56;$lpad$phi$index = $79;$lpad$phi$index8 = $80;
      label = 30;
     }
     else if ((label|0) == 28) {
      $81 = ___cxa_find_matching_catch()|0;
      $82 = tempRet0;
      $184 = $$lcssa42;$lpad$phi$index = $81;$lpad$phi$index8 = $82;
      label = 30;
     }
     else if ((label|0) == 45) {
      $124 = ___cxa_find_matching_catch()|0;
      $125 = tempRet0;
      $126 = HEAP8[$0>>0]|0;
      $127 = $126 & 1;
      $128 = ($127<<24>>24)==(0);
      if ($128) {
       $$0 = $125;$$01 = $124;$161 = $$lcssa42;
      } else {
       $129 = HEAP32[$10>>2]|0;
       __ZdlPv($129);
       $$0 = $125;$$01 = $124;$161 = $$lcssa42;
      }
     }
     else if ((label|0) == 56) {
      $151 = ___cxa_find_matching_catch()|0;
      $152 = tempRet0;
      $153 = HEAP8[$1>>0]|0;
      $154 = $153 & 1;
      $155 = ($154<<24>>24)==(0);
      if ($155) {
       $$0 = $152;$$01 = $151;$161 = $$lcssa42;
      } else {
       $156 = HEAP32[$13>>2]|0;
       __ZdlPv($156);
       $$0 = $152;$$01 = $151;$161 = $$lcssa42;
      }
     }
     else if ((label|0) == 63) {
      $162 = HEAP32[$allManagers>>2]|0;
      $163 = ($162|0)==(0|0);
      if ($163) {
       STACKTOP = sp;return;
      }
      $164 = HEAP32[$5>>2]|0;
      $165 = ($164|0)==($162|0);
      if (!($165)) {
       $__new_last2$i$i$i$i$i4 = $162;
       $scevgep$i$i$i$i$i5 = (($164) + -4|0);
       $166 = (0 - ($__new_last2$i$i$i$i$i4))|0;
       $uglygep$i$i$i$i$i7 = (($scevgep$i$i$i$i$i5) + ($166)|0);
       $uglygep3$i$i$i$i$i8 = $uglygep$i$i$i$i$i7;
       $167 = $uglygep3$i$i$i$i$i8 >>> 2;
       $168 = $167 ^ -1;
       $scevgep4$i$i$i$i$i9 = (($164) + ($168<<2)|0);
       HEAP32[$5>>2] = $scevgep4$i$i$i$i$i9;
      }
      __ZdlPv($162);
      STACKTOP = sp;return;
     }
    } while(0);
    if ((label|0) == 30) {
     $$0 = $lpad$phi$index8;$$01 = $lpad$phi$index;$161 = $184;
    }
    $160 = ($161|0)==(0|0);
    if ($160) {
     $$1 = $$0;$$12 = $$01;
    } else {
     __ZdlPv($161);
     $$1 = $$0;$$12 = $$01;
    }
   }
  } while(0);
  if ((label|0) == 10) {
   $$1 = $lpad$phi51$index2;$$12 = $lpad$phi51$index;
  }
  $169 = HEAP32[$allManagers>>2]|0;
  $170 = ($169|0)==(0|0);
  if ($170) {
   $$2 = $$1;$$23 = $$12;
  } else {
   $171 = HEAP32[$5>>2]|0;
   $172 = ($171|0)==($169|0);
   if (!($172)) {
    $__new_last2$i$i$i$i$i = $169;
    $scevgep$i$i$i$i$i = (($171) + -4|0);
    $173 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($173)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $174 = $uglygep3$i$i$i$i$i >>> 2;
    $175 = $174 ^ -1;
    $scevgep4$i$i$i$i$i = (($171) + ($175<<2)|0);
    HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($169);
   $$2 = $$1;$$23 = $$12;
  }
 }
 $176 = HEAP8[$agg$result>>0]|0;
 $177 = $176 & 1;
 $178 = ($177<<24>>24)==(0);
 if ($178) {
  ___resumeException($$23|0);
  // unreachable;
 }
 $179 = (($agg$result) + 8|0);
 $180 = HEAP32[$179>>2]|0;
 __ZdlPv($180);
 ___resumeException($$23|0);
 // unreachable;
}
function __Z12LoadManagersR18AwakeFromLoadQueue($awakeFromLoadQueue) {
 $awakeFromLoadQueue = $awakeFromLoadQueue|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i3 = 0, $i$024 = 0, $i1$019 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $managers = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i8 = 0, $temp = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 48|0;
 $0 = sp;
 $managers = sp + 4|0;
 $temp = sp + 16|0;
 $1 = sp + 28|0;
 $2 = sp + 32|0;
 __ZN18AwakeFromLoadQueue30PersistentManagerAwakeFromLoadEi17AwakeFromLoadMode($awakeFromLoadQueue,0,3);
 __ZN18AwakeFromLoadQueue10ClearQueueEi($awakeFromLoadQueue,0);
 $3 = (($managers) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($managers) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($managers) + 4|0);
 HEAP32[$managers>>2] = $5;
 HEAP32[$temp>>2] = 0;
 $6 = (($temp) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($temp) + 8|0);
 HEAP32[$7>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,9,($temp|0),0)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   label = 9;
  } else {
   $10 = HEAP32[$6>>2]|0;
   $11 = HEAP32[$temp>>2]|0;
   $12 = ($10|0)==($11|0);
   L3: do {
    if (!($12)) {
     $14 = $11;$i$024 = 0;
     while(1) {
      $13 = (($14) + ($i$024<<2)|0);
      $15 = HEAP32[$13>>2]|0;
      $16 = (($15) + 8|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = $17 >>> 21;
      HEAP32[$1>>2] = $18;
      __THREW__ = 0;
      $19 = (invoke_iii(2356,($managers|0),($1|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      $22 = HEAP32[$temp>>2]|0;
      $23 = (($22) + ($i$024<<2)|0);
      __THREW__ = 0;
      invoke_viii(1632,($$byval_copy|0),($19|0),($23|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = (($i$024) + 1)|0;
      $27 = HEAP32[$6>>2]|0;
      $28 = HEAP32[$temp>>2]|0;
      $29 = $27;
      $30 = $28;
      $31 = (($29) - ($30))|0;
      $32 = $31 >> 2;
      $33 = ($26>>>0)<($32>>>0);
      if ($33) {
       $14 = $28;$i$024 = $26;
      } else {
       break L3;
      }
     }
     $36 = ___cxa_find_matching_catch()|0;
     $37 = tempRet0;
     $lpad$phi$index = $36;$lpad$phi$index3 = $37;
     label = 10;
     break L1;
    }
   } while(0);
   __THREW__ = 0;
   $40 = (invoke_i(56)|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    label = 9;
   } else {
    $43 = (($2) + 1|0);
    $44 = (($2) + 8|0);
    $i1$019 = 0;
    L12: while(1) {
     __THREW__ = 0;
     invoke_vii(2599,($i1$019|0),(0|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 7;
      break;
     }
     $47 = ((($40) + ($i1$019<<2)|0) + 80|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(-1);
     do {
      if (!($49)) {
       __THREW__ = 0;
       $50 = (invoke_iii(2356,($managers|0),($47|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        label = 7;
        break L12;
       }
       $53 = (($50) + 8|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = ($54|0)==(1);
       if ($55) {
        $56 = HEAP32[$50>>2]|0;
        $57 = (($56) + 16|0);
        $58 = HEAP32[$57>>2]|0;
        __THREW__ = 0;
        invoke_vii(2599,($i1$019|0),($58|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 7;
         break L12;
        } else {
         break;
        }
       }
       $61 = ($54|0)==(0);
       $62 = HEAP32[$47>>2]|0;
       if (!($61)) {
        __THREW__ = 0;
        $94 = (invoke_ii(3216,($62|0))|0);
        $95 = __THREW__; __THREW__ = 0;
        $96 = $95&1;
        if ($96) {
         label = 7;
         break L12;
        }
        __THREW__ = 0;
        invoke_viii(1631,($2|0),(563144|0),($94|0));
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if ($98) {
         label = 7;
         break L12;
        }
        $99 = HEAP8[$2>>0]|0;
        $100 = $99 & 1;
        $101 = ($100<<24>>24)==(0);
        $102 = HEAP32[$44>>2]|0;
        $$ = $101 ? $43 : $102;
        __THREW__ = 0;
        invoke_viiiiiiii(21,($$|0),0,(562936|0),267,1,0,0,(0|0));
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 34;
         break L12;
        }
        $105 = HEAP8[$2>>0]|0;
        $106 = $105 & 1;
        $107 = ($106<<24>>24)==(0);
        if (!($107)) {
         $108 = HEAP32[$44>>2]|0;
         __ZdlPv($108);
        }
        $109 = HEAP32[$50>>2]|0;
        $110 = (($109) + 16|0);
        $111 = HEAP32[$110>>2]|0;
        __THREW__ = 0;
        invoke_vii(2599,($i1$019|0),($111|0));
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         label = 7;
         break L12;
        } else {
         break;
        }
       }
       $63 = HEAP32[628384>>2]|0;
       HEAP32[$0>>2] = $63;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       $64 = (invoke_iiiii(231,($62|0),0,($$byval_copy|0),0)|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        label = 7;
        break L12;
       }
       $67 = HEAP32[$64>>2]|0;
       $68 = (($67) + 24|0);
       $69 = HEAP32[$68>>2]|0;
       __THREW__ = 0;
       invoke_vi($69|0,($64|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 7;
        break L12;
       }
       $72 = HEAP32[$64>>2]|0;
       $73 = (($72) + 12|0);
       $74 = HEAP32[$73>>2]|0;
       __THREW__ = 0;
       invoke_vii($74|0,($64|0),0);
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        label = 7;
        break L12;
       }
       __THREW__ = 0;
       $77 = (invoke_ii(3216,($62|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 7;
        break L12;
       }
       $80 = HEAP32[$64>>2]|0;
       $81 = (($80) + 36|0);
       $82 = HEAP32[$81>>2]|0;
       $83 = HEAP8[$77>>0]|0;
       $84 = $83 & 1;
       $85 = ($84<<24>>24)==(0);
       if ($85) {
        $88 = (($77) + 1|0);
        $89 = $88;
       } else {
        $86 = (($77) + 8|0);
        $87 = HEAP32[$86>>2]|0;
        $89 = $87;
       }
       __THREW__ = 0;
       invoke_vii($82|0,($64|0),($89|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        label = 7;
        break L12;
       }
       __THREW__ = 0;
       invoke_vii(2599,($i1$019|0),($64|0));
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        label = 7;
        break L12;
       }
      }
     } while(0);
     $120 = (($i1$019) + 1)|0;
     $121 = ($120|0)<(20);
     if ($121) {
      $i1$019 = $120;
     } else {
      label = 37;
      break;
     }
    }
    if ((label|0) == 7) {
     $34 = ___cxa_find_matching_catch()|0;
     $35 = tempRet0;
     $lpad$phi$index = $34;$lpad$phi$index3 = $35;
     label = 10;
     break;
    }
    else if ((label|0) == 34) {
     $114 = ___cxa_find_matching_catch()|0;
     $115 = tempRet0;
     $116 = HEAP8[$2>>0]|0;
     $117 = $116 & 1;
     $118 = ($117<<24>>24)==(0);
     if ($118) {
      $$0 = $114;$$01 = $115;
      break;
     }
     $119 = HEAP32[$44>>2]|0;
     __ZdlPv($119);
     $$0 = $114;$$01 = $115;
     break;
    }
    else if ((label|0) == 37) {
     $122 = HEAP32[$temp>>2]|0;
     $123 = ($122|0)==(0|0);
     if ($123) {
      $129 = HEAP32[$3>>2]|0;
      __ZNSt3__16__treeINS_12__value_typeIiNS_3setIP11GameManagerNS_4lessIS4_EENS_9allocatorIS4_EEEEEENS_19__map_value_compareIiSA_NS5_IiEELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($managers,$129);
      STACKTOP = sp;return;
     }
     $124 = HEAP32[$6>>2]|0;
     $125 = ($124|0)==($122|0);
     if (!($125)) {
      $__new_last2$i$i$i$i$i3 = $122;
      $scevgep$i$i$i$i$i4 = (($124) + -4|0);
      $126 = (0 - ($__new_last2$i$i$i$i$i3))|0;
      $uglygep$i$i$i$i$i6 = (($scevgep$i$i$i$i$i4) + ($126)|0);
      $uglygep3$i$i$i$i$i7 = $uglygep$i$i$i$i$i6;
      $127 = $uglygep3$i$i$i$i$i7 >>> 2;
      $128 = $127 ^ -1;
      $scevgep4$i$i$i$i$i8 = (($124) + ($128<<2)|0);
      HEAP32[$6>>2] = $scevgep4$i$i$i$i$i8;
     }
     __ZdlPv($122);
     $129 = HEAP32[$3>>2]|0;
     __ZNSt3__16__treeINS_12__value_typeIiNS_3setIP11GameManagerNS_4lessIS4_EENS_9allocatorIS4_EEEEEENS_19__map_value_compareIiSA_NS5_IiEELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($managers,$129);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  $lpad$phi$index = $38;$lpad$phi$index3 = $39;
  label = 10;
 }
 if ((label|0) == 10) {
  $$0 = $lpad$phi$index;$$01 = $lpad$phi$index3;
 }
 $130 = HEAP32[$temp>>2]|0;
 $131 = ($130|0)==(0|0);
 if ($131) {
  $137 = HEAP32[$3>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiNS_3setIP11GameManagerNS_4lessIS4_EENS_9allocatorIS4_EEEEEENS_19__map_value_compareIiSA_NS5_IiEELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($managers,$137);
  ___resumeException($$0|0);
  // unreachable;
 }
 $132 = HEAP32[$6>>2]|0;
 $133 = ($132|0)==($130|0);
 if (!($133)) {
  $__new_last2$i$i$i$i$i = $130;
  $scevgep$i$i$i$i$i = (($132) + -4|0);
  $134 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($134)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $135 = $uglygep3$i$i$i$i$i >>> 2;
  $136 = $135 ^ -1;
  $scevgep4$i$i$i$i$i = (($132) + ($136<<2)|0);
  HEAP32[$6>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($130);
 $137 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiNS_3setIP11GameManagerNS_4lessIS4_EENS_9allocatorIS4_EEEEEENS_19__map_value_compareIiSA_NS5_IiEELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($managers,$137);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNSt3__13mapIiNS_3setIP11GameManagerNS_4lessIS3_EENS_9allocatorIS3_EEEENS4_IiEENS6_INS_4pairIKiS8_EEEEEixERSB_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$24 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$24 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$24 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$24 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $33 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($33|0);
 }
 $16 = (__Znwj(32)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 $20 = (($16) + 24|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 28|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$19>>2] = $20;
 HEAP32[$16>>2] = 0;
 $22 = (($16) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = (($16) + 8|0);
 HEAP32[$23>>2] = $24;
 HEAP32[$$0$i>>2] = $16;
 $25 = HEAP32[$this>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $29 = $16;
 } else {
  HEAP32[$this>>2] = $26;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $29 = $$pre$i;
 }
 $28 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$29);
 $30 = (($this) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 1)|0;
 HEAP32[$30>>2] = $32;
 $__r$0 = $16;
 $33 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($33|0);
}
function __ZNSt3__16__treeIP11GameManagerNS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3>>>0)<($5>>>0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5>>>0)<($3>>>0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $31 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $30 = (($agg$result) + 4|0);
  HEAP8[$30>>0] = $31;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(20)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__v>>2]|0;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $31 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $30 = (($agg$result) + 4|0);
 HEAP8[$30>>0] = $31;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeIP11GameManagerNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeIP11GameManagerNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeIP11GameManagerNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIiNS_3setIP11GameManagerNS_4lessIS4_EENS_9allocatorIS4_EEEEEENS_19__map_value_compareIiSA_NS5_IiEELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiNS_3setIP11GameManagerNS_4lessIS4_EENS_9allocatorIS4_EEEEEENS_19__map_value_compareIiSA_NS5_IiEELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiNS_3setIP11GameManagerNS_4lessIS4_EENS_9allocatorIS4_EEEEEENS_19__map_value_compareIiSA_NS5_IiEELb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$3);
  $4 = (($__nd) + 20|0);
  $5 = (($__nd) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  __ZNSt3__16__treeIP11GameManagerNS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($4,$6);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN10vector_mapIiiNSt3__14lessIiEENS0_9allocatorINS0_4pairIiiEEEEE13push_unsortedERKiS9_($this,$x,$value) {
 $this = $this|0;
 $x = $x|0;
 $value = $value|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$x>>2]|0;
 $1 = HEAP32[$value>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = ($3|0)==(0|0);
  if ($7) {
   $13 = 0;
  } else {
   $8 = $3;
   $9 = $8;
   HEAP32[$9>>2] = $0;
   $10 = (($8) + 4)|0;
   $11 = $10;
   HEAP32[$11>>2] = $1;
   $$pre$i = HEAP32[$2>>2]|0;
   $13 = $$pre$i;
  }
  $12 = (($13) + 8|0);
  HEAP32[$2>>2] = $12;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $3;
 $17 = $15;
 $18 = (($16) - ($17))|0;
 $19 = $18 >> 3;
 $20 = (($19) + 1)|0;
 $21 = ($20>>>0)>(536870911);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = ($19>>>0)<(268435455);
 if ($22) {
  $23 = $18 >> 2;
  $24 = ($23>>>0)<($20>>>0);
  $25 = $24 ? $20 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i3$i$i = 0;$30 = 0;
  } else {
   $$0$i2$i$i = $25;
   label = 9;
  }
 } else {
  $$0$i2$i$i = 536870911;
  label = 9;
 }
 if ((label|0) == 9) {
  $27 = $$0$i2$i$i << 3;
  $28 = (__Znwj($27)|0);
  $$0$i3$i$i = $$0$i2$i$i;$30 = $28;
 }
 $29 = (($30) + ($19<<3)|0);
 $31 = (($30) + ($$0$i3$i$i<<3)|0);
 $32 = ($29|0)==(0|0);
 if (!($32)) {
  $33 = $29;
  $34 = $33;
  HEAP32[$34>>2] = $0;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = $1;
 }
 $37 = (($30) + ($20<<3)|0);
 _memcpy(($30|0),($15|0),($18|0))|0;
 HEAP32[$14>>2] = $30;
 HEAP32[$2>>2] = $37;
 HEAP32[$4>>2] = $31;
 $38 = ($15|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEvT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$013 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0;
 var $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $2 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $3 = $$0;
   $4 = (($0) - ($3))|0;
   $5 = $4 >> 3;
   switch ($5|0) {
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 70;
    break L1;
    break;
   }
   default: {
   }
   }
   $66 = ($4|0)<(56);
   if ($66) {
    label = 21;
    break L1;
   }
   $67 = ($4|0)>(7992);
   $68 = (($5|0) / 2)&-1;
   $69 = (($$0) + ($68<<3)|0);
   do {
    if ($67) {
     $70 = (($5|0) / 4)&-1;
     $71 = (($$0) + ($70<<3)|0);
     $$sum = (($70) + ($68))|0;
     $72 = (($$0) + ($$sum<<3)|0);
     $73 = (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEjT0_SC_SC_SC_T_($$0,$71,$69,$72,$__comp)|0);
     $74 = HEAP32[$1>>2]|0;
     $75 = HEAP32[$72>>2]|0;
     $76 = ($74|0)<($75|0);
     if (!($76)) {
      $$pre$phiZ2D = $69;$__n_swaps$0 = $73;
      break;
     }
     HEAP32[$72>>2] = $74;
     HEAP32[$1>>2] = $75;
     $77 = ((($$0) + ($$sum<<3)|0) + 4|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$2>>2]|0;
     HEAP32[$77>>2] = $79;
     HEAP32[$2>>2] = $78;
     $80 = HEAP32[$72>>2]|0;
     $81 = HEAP32[$69>>2]|0;
     $82 = ($80|0)<($81|0);
     if (!($82)) {
      $83 = (($73) + 1)|0;
      $$pre$phiZ2D = $69;$__n_swaps$0 = $83;
      break;
     }
     HEAP32[$69>>2] = $80;
     HEAP32[$72>>2] = $81;
     $84 = ((($$0) + ($68<<3)|0) + 4|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = HEAP32[$77>>2]|0;
     HEAP32[$84>>2] = $86;
     HEAP32[$77>>2] = $85;
     $87 = HEAP32[$69>>2]|0;
     $88 = HEAP32[$71>>2]|0;
     $89 = ($87|0)<($88|0);
     if (!($89)) {
      $90 = (($73) + 2)|0;
      $$pre$phiZ2D = $69;$__n_swaps$0 = $90;
      break;
     }
     HEAP32[$71>>2] = $87;
     HEAP32[$69>>2] = $88;
     $91 = ((($$0) + ($70<<3)|0) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = HEAP32[$84>>2]|0;
     HEAP32[$91>>2] = $93;
     HEAP32[$84>>2] = $92;
     $94 = (($73) + 3)|0;
     $95 = HEAP32[$71>>2]|0;
     $96 = HEAP32[$$0>>2]|0;
     $97 = ($95|0)<($96|0);
     if ($97) {
      HEAP32[$$0>>2] = $95;
      HEAP32[$71>>2] = $96;
      $98 = (($$0) + 4|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = HEAP32[$91>>2]|0;
      HEAP32[$98>>2] = $100;
      HEAP32[$91>>2] = $99;
      $101 = (($73) + 4)|0;
      $$pre$phiZ2D = $69;$__n_swaps$0 = $101;
     } else {
      $$pre$phiZ2D = $69;$__n_swaps$0 = $94;
     }
    } else {
     $102 = HEAP32[$69>>2]|0;
     $103 = HEAP32[$$0>>2]|0;
     $104 = ($102|0)<($103|0);
     $105 = HEAP32[$1>>2]|0;
     $106 = ($105|0)<($102|0);
     if (!($104)) {
      if (!($106)) {
       $$pre$phiZ2D = $69;$__n_swaps$0 = 0;
       break;
      }
      HEAP32[$69>>2] = $105;
      HEAP32[$1>>2] = $102;
      $107 = ((($$0) + ($68<<3)|0) + 4|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = HEAP32[$2>>2]|0;
      HEAP32[$107>>2] = $109;
      HEAP32[$2>>2] = $108;
      $110 = HEAP32[$69>>2]|0;
      $111 = HEAP32[$$0>>2]|0;
      $112 = ($110|0)<($111|0);
      if (!($112)) {
       $$pre$phiZ2D = $69;$__n_swaps$0 = 1;
       break;
      }
      HEAP32[$$0>>2] = $110;
      HEAP32[$69>>2] = $111;
      $113 = (($$0) + 4|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = HEAP32[$107>>2]|0;
      HEAP32[$113>>2] = $115;
      HEAP32[$107>>2] = $114;
      $$pre$phiZ2D = $69;$__n_swaps$0 = 2;
      break;
     }
     if ($106) {
      HEAP32[$$0>>2] = $105;
      HEAP32[$1>>2] = $103;
      $116 = (($$0) + 4|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = HEAP32[$2>>2]|0;
      HEAP32[$116>>2] = $118;
      HEAP32[$2>>2] = $117;
      $$pre$phiZ2D = $69;$__n_swaps$0 = 1;
      break;
     }
     HEAP32[$$0>>2] = $102;
     HEAP32[$69>>2] = $103;
     $119 = (($$0) + 4|0);
     $120 = ((($$0) + ($68<<3)|0) + 4|0);
     $121 = HEAP32[$119>>2]|0;
     $122 = HEAP32[$120>>2]|0;
     HEAP32[$119>>2] = $122;
     HEAP32[$120>>2] = $121;
     $123 = HEAP32[$1>>2]|0;
     $124 = ($123|0)<($103|0);
     if ($124) {
      HEAP32[$69>>2] = $123;
      HEAP32[$1>>2] = $103;
      $125 = HEAP32[$120>>2]|0;
      $126 = HEAP32[$2>>2]|0;
      HEAP32[$120>>2] = $126;
      HEAP32[$2>>2] = $125;
      $$pre$phiZ2D = $69;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $69;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $127 = HEAP32[$$0>>2]|0;
   $128 = HEAP32[$$pre$phiZ2D>>2]|0;
   $129 = ($127|0)<($128|0);
   do {
    if ($129) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $130 = (($__j$0) + -8|0);
      $131 = ($$0|0)==($130|0);
      if ($131) {
       break;
      }
      $156 = HEAP32[$130>>2]|0;
      $157 = ($156|0)<($128|0);
      if ($157) {
       label = 53;
       break;
      } else {
       $__j$0 = $130;
      }
     }
     if ((label|0) == 53) {
      label = 0;
      HEAP32[$$0>>2] = $156;
      HEAP32[$130>>2] = $127;
      $158 = (($$0) + 4|0);
      $159 = (($__j$0) + -4|0);
      $160 = HEAP32[$158>>2]|0;
      $161 = HEAP32[$159>>2]|0;
      HEAP32[$158>>2] = $161;
      HEAP32[$159>>2] = $160;
      $162 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $130;$__n_swaps$3 = $162;
      break;
     }
     $132 = (($$0) + 8|0);
     $133 = HEAP32[$1>>2]|0;
     $134 = ($127|0)<($133|0);
     if ($134) {
      $__i$1 = $132;
     } else {
      $135 = ($132|0)==($1|0);
      if ($135) {
       label = 70;
       break L1;
      } else {
       $__i$013 = $132;
      }
      while(1) {
       $138 = HEAP32[$__i$013>>2]|0;
       $139 = ($127|0)<($138|0);
       $137 = (($__i$013) + 8|0);
       if ($139) {
        break;
       }
       $136 = ($137|0)==($1|0);
       if ($136) {
        label = 70;
        break L1;
       } else {
        $__i$013 = $137;
       }
      }
      HEAP32[$__i$013>>2] = $133;
      HEAP32[$1>>2] = $138;
      $140 = (($__i$013) + 4|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = HEAP32[$2>>2]|0;
      HEAP32[$140>>2] = $142;
      HEAP32[$2>>2] = $141;
      $__i$1 = $137;
     }
     $143 = ($__i$1|0)==($1|0);
     if ($143) {
      label = 70;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $144 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $145 = HEAP32[$__i$2>>2]|0;
       $146 = ($144|0)<($145|0);
       $147 = (($__i$2) + 8|0);
       if ($146) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $147;
       }
      }
      while(1) {
       $148 = (($__j$2) + -8|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = ($144|0)<($149|0);
       if ($150) {
        $__j$2 = $148;
       } else {
        break;
       }
      }
      $151 = ($__i$2>>>0)<($148>>>0);
      if (!($151)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__i$2>>2] = $149;
      HEAP32[$148>>2] = $145;
      $152 = (($__i$2) + 4|0);
      $153 = (($__j$2) + -4|0);
      $154 = HEAP32[$152>>2]|0;
      $155 = HEAP32[$153>>2]|0;
      HEAP32[$152>>2] = $155;
      HEAP32[$153>>2] = $154;
      $__i$2$ph = $147;$__j$1$ph = $148;
     }
    }
   } while(0);
   $163 = (($$0) + 8|0);
   $164 = ($163>>>0)<($__j$3>>>0);
   L53: do {
    if ($164) {
     $__i$3$ph = $163;$__j$4$ph = $__j$3;$__m$0$ph = $69;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $165 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $166 = HEAP32[$__i$3>>2]|0;
       $167 = ($166|0)<($165|0);
       $168 = (($__i$3) + 8|0);
       if ($167) {
        $__i$3 = $168;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $169 = (($__j$5) + -8|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = ($170|0)<($165|0);
       if ($171) {
        break;
       } else {
        $__j$5 = $169;
       }
      }
      $172 = ($__i$3>>>0)>($169>>>0);
      if ($172) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L53;
      }
      HEAP32[$__i$3>>2] = $170;
      HEAP32[$169>>2] = $166;
      $173 = (($__i$3) + 4|0);
      $174 = (($__j$5) + -4|0);
      $175 = HEAP32[$173>>2]|0;
      $176 = HEAP32[$174>>2]|0;
      HEAP32[$173>>2] = $176;
      HEAP32[$174>>2] = $175;
      $177 = (($__n_swaps$4$ph) + 1)|0;
      $178 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $178 ? $169 : $__m$0$ph;
      $__i$3$ph = $168;$__j$4$ph = $169;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $177;
     }
    } else {
     $__i$4 = $163;$__m$2 = $69;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $179 = ($__i$4|0)==($__m$2|0);
   if ($179) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $180 = HEAP32[$__m$2>>2]|0;
    $181 = HEAP32[$__i$4>>2]|0;
    $182 = ($180|0)<($181|0);
    if ($182) {
     HEAP32[$__i$4>>2] = $180;
     HEAP32[$__m$2>>2] = $181;
     $183 = (($__i$4) + 4|0);
     $184 = (($__m$2) + 4|0);
     $185 = HEAP32[$183>>2]|0;
     $186 = HEAP32[$184>>2]|0;
     HEAP32[$183>>2] = $186;
     HEAP32[$184>>2] = $185;
     $187 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $187;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $188 = ($__n_swaps$6|0)==(0);
   if ($188) {
    $189 = (__ZNSt3__127__insertion_sort_incompleteIRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEbT0_SC_T_($$0,$__i$4,$__comp)|0);
    $190 = (($__i$4) + 8|0);
    $191 = (__ZNSt3__127__insertion_sort_incompleteIRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEbT0_SC_T_($190,$$01$ph,$__comp)|0);
    if ($191) {
     label = 65;
     break;
    }
    if ($189) {
     $$0 = $190;
     continue;
    }
   }
   $192 = $__i$4;
   $193 = (($192) - ($3))|0;
   $194 = (($0) - ($192))|0;
   $195 = ($193|0)<($194|0);
   if (!($195)) {
    label = 69;
    break;
   }
   __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEvT0_SC_T_($$0,$__i$4,$__comp);
   $196 = (($__i$4) + 8|0);
   $$0 = $196;
  }
  if ((label|0) == 65) {
   label = 0;
   if ($189) {
    label = 70;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 69) {
   label = 0;
   $197 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEvT0_SC_T_($197,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $6 = (($$01$ph) + -8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$$0>>2]|0;
  $9 = ($7|0)<($8|0);
  if (!($9)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $7;
  HEAP32[$6>>2] = $8;
  $10 = (($$0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$10>>2] = $12;
  HEAP32[$2>>2] = $11;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $13 = (($$0) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$$0>>2]|0;
  $16 = ($14|0)<($15|0);
  $17 = (($$01$ph) + -8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)<($14|0);
  if (!($16)) {
   if (!($19)) {
    STACKTOP = sp;return;
   }
   HEAP32[$13>>2] = $18;
   HEAP32[$17>>2] = $14;
   $20 = (($$0) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$2>>2]|0;
   HEAP32[$20>>2] = $22;
   HEAP32[$2>>2] = $21;
   $23 = HEAP32[$13>>2]|0;
   $24 = HEAP32[$$0>>2]|0;
   $25 = ($23|0)<($24|0);
   if (!($25)) {
    STACKTOP = sp;return;
   }
   HEAP32[$$0>>2] = $23;
   HEAP32[$13>>2] = $24;
   $26 = (($$0) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$20>>2]|0;
   HEAP32[$26>>2] = $28;
   HEAP32[$20>>2] = $27;
   STACKTOP = sp;return;
  }
  if ($19) {
   HEAP32[$$0>>2] = $18;
   HEAP32[$17>>2] = $15;
   $29 = (($$0) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$2>>2]|0;
   HEAP32[$29>>2] = $31;
   HEAP32[$2>>2] = $30;
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $14;
  HEAP32[$13>>2] = $15;
  $32 = (($$0) + 4|0);
  $33 = (($$0) + 12|0);
  $34 = HEAP32[$32>>2]|0;
  $35 = HEAP32[$33>>2]|0;
  HEAP32[$32>>2] = $35;
  HEAP32[$33>>2] = $34;
  $36 = HEAP32[$17>>2]|0;
  $37 = ($36|0)<($15|0);
  if (!($37)) {
   STACKTOP = sp;return;
  }
  HEAP32[$13>>2] = $36;
  HEAP32[$17>>2] = $15;
  $38 = HEAP32[$33>>2]|0;
  $39 = HEAP32[$2>>2]|0;
  HEAP32[$33>>2] = $39;
  HEAP32[$2>>2] = $38;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $40 = (($$0) + 8|0);
  $41 = (($$0) + 16|0);
  (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEjT0_SC_SC_SC_T_($$0,$40,$41,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $42 = (($$0) + 8|0);
  $43 = (($$0) + 16|0);
  $44 = (($$0) + 24|0);
  (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEjT0_SC_SC_SC_T_($$0,$42,$43,$44,$__comp)|0);
  $45 = (($$01$ph) + -8|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$44>>2]|0;
  $48 = ($46|0)<($47|0);
  if (!($48)) {
   STACKTOP = sp;return;
  }
  HEAP32[$44>>2] = $46;
  HEAP32[$45>>2] = $47;
  $49 = (($$0) + 28|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = HEAP32[$2>>2]|0;
  HEAP32[$49>>2] = $51;
  HEAP32[$2>>2] = $50;
  $52 = HEAP32[$44>>2]|0;
  $53 = HEAP32[$43>>2]|0;
  $54 = ($52|0)<($53|0);
  if (!($54)) {
   STACKTOP = sp;return;
  }
  HEAP32[$43>>2] = $52;
  HEAP32[$44>>2] = $53;
  $55 = (($$0) + 20|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = HEAP32[$49>>2]|0;
  HEAP32[$55>>2] = $57;
  HEAP32[$49>>2] = $56;
  $58 = HEAP32[$42>>2]|0;
  $59 = ($52|0)<($58|0);
  if (!($59)) {
   STACKTOP = sp;return;
  }
  HEAP32[$42>>2] = $52;
  HEAP32[$43>>2] = $58;
  $60 = (($$0) + 12|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$60>>2] = $57;
  HEAP32[$55>>2] = $61;
  $62 = HEAP32[$$0>>2]|0;
  $63 = ($52|0)<($62|0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $52;
  HEAP32[$42>>2] = $62;
  $64 = (($$0) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  HEAP32[$64>>2] = $57;
  HEAP32[$60>>2] = $65;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEvT0_SC_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 70) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEjT0_SC_SC_SC_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3|0)<($0|0);
 do {
  if ($2) {
   if ($4) {
    HEAP32[$__x1>>2] = $3;
    HEAP32[$__x3>>2] = $1;
    $15 = (($__x1) + 4|0);
    $16 = (($__x3) + 4|0);
    $17 = HEAP32[$15>>2]|0;
    $18 = HEAP32[$16>>2]|0;
    HEAP32[$15>>2] = $18;
    HEAP32[$16>>2] = $17;
    $$0$i = 1;
    break;
   }
   HEAP32[$__x1>>2] = $0;
   HEAP32[$__x2>>2] = $1;
   $19 = (($__x1) + 4|0);
   $20 = (($__x2) + 4|0);
   $21 = HEAP32[$19>>2]|0;
   $22 = HEAP32[$20>>2]|0;
   HEAP32[$19>>2] = $22;
   HEAP32[$20>>2] = $21;
   $23 = HEAP32[$__x3>>2]|0;
   $24 = HEAP32[$__x2>>2]|0;
   $25 = ($23|0)<($24|0);
   if ($25) {
    HEAP32[$__x2>>2] = $23;
    HEAP32[$__x3>>2] = $24;
    $26 = (($__x3) + 4|0);
    $27 = HEAP32[$20>>2]|0;
    $28 = HEAP32[$26>>2]|0;
    HEAP32[$20>>2] = $28;
    HEAP32[$26>>2] = $27;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($4) {
    HEAP32[$__x2>>2] = $3;
    HEAP32[$__x3>>2] = $0;
    $5 = (($__x2) + 4|0);
    $6 = (($__x3) + 4|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = HEAP32[$6>>2]|0;
    HEAP32[$5>>2] = $8;
    HEAP32[$6>>2] = $7;
    $9 = HEAP32[$__x2>>2]|0;
    $10 = HEAP32[$__x1>>2]|0;
    $11 = ($9|0)<($10|0);
    if ($11) {
     HEAP32[$__x1>>2] = $9;
     HEAP32[$__x2>>2] = $10;
     $12 = (($__x1) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = HEAP32[$5>>2]|0;
     HEAP32[$12>>2] = $14;
     HEAP32[$5>>2] = $13;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $29 = HEAP32[$__x4>>2]|0;
 $30 = HEAP32[$__x3>>2]|0;
 $31 = ($29|0)<($30|0);
 if (!($31)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $29;
 HEAP32[$__x4>>2] = $30;
 $32 = (($__x3) + 4|0);
 $33 = (($__x4) + 4|0);
 $34 = HEAP32[$32>>2]|0;
 $35 = HEAP32[$33>>2]|0;
 HEAP32[$32>>2] = $35;
 HEAP32[$33>>2] = $34;
 $36 = (($$0$i) + 1)|0;
 $37 = HEAP32[$__x3>>2]|0;
 $38 = HEAP32[$__x2>>2]|0;
 $39 = ($37|0)<($38|0);
 if (!($39)) {
  $__r$0 = $36;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $37;
 HEAP32[$__x3>>2] = $38;
 $40 = (($__x2) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$32>>2]|0;
 HEAP32[$40>>2] = $42;
 HEAP32[$32>>2] = $41;
 $43 = (($$0$i) + 2)|0;
 $44 = HEAP32[$__x2>>2]|0;
 $45 = HEAP32[$__x1>>2]|0;
 $46 = ($44|0)<($45|0);
 if (!($46)) {
  $__r$0 = $43;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $44;
 HEAP32[$__x2>>2] = $45;
 $47 = (($__x1) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$40>>2]|0;
 HEAP32[$47>>2] = $49;
 HEAP32[$40>>2] = $48;
 $50 = (($$0$i) + 3)|0;
 $__r$0 = $50;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEvT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$03 = 0, $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 16|0);
 $1 = (($__first) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = ($2|0)<($3|0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)<($2|0);
 do {
  if ($4) {
   if ($6) {
    HEAP32[$__first>>2] = $5;
    HEAP32[$0>>2] = $3;
    $14 = (($__first) + 4|0);
    $15 = (($__first) + 20|0);
    $16 = HEAP32[$14>>2]|0;
    $17 = HEAP32[$15>>2]|0;
    HEAP32[$14>>2] = $17;
    HEAP32[$15>>2] = $16;
    $46 = $3;
    break;
   }
   HEAP32[$__first>>2] = $2;
   HEAP32[$1>>2] = $3;
   $18 = (($__first) + 4|0);
   $19 = (($__first) + 12|0);
   $20 = HEAP32[$18>>2]|0;
   $21 = HEAP32[$19>>2]|0;
   HEAP32[$18>>2] = $21;
   HEAP32[$19>>2] = $20;
   $22 = ($5|0)<($3|0);
   if ($22) {
    HEAP32[$1>>2] = $5;
    HEAP32[$0>>2] = $3;
    $23 = (($__first) + 20|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$19>>2] = $24;
    HEAP32[$23>>2] = $20;
    $46 = $3;
   } else {
    $46 = $5;
   }
  } else {
   if ($6) {
    HEAP32[$1>>2] = $5;
    HEAP32[$0>>2] = $2;
    $7 = (($__first) + 12|0);
    $8 = (($__first) + 20|0);
    $9 = HEAP32[$7>>2]|0;
    $10 = HEAP32[$8>>2]|0;
    HEAP32[$7>>2] = $10;
    HEAP32[$8>>2] = $9;
    $11 = ($5|0)<($3|0);
    if ($11) {
     HEAP32[$__first>>2] = $5;
     HEAP32[$1>>2] = $3;
     $12 = (($__first) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     HEAP32[$12>>2] = $10;
     HEAP32[$7>>2] = $13;
     $46 = $2;
    } else {
     $46 = $2;
    }
   } else {
    $46 = $5;
   }
  }
 } while(0);
 $25 = (($__first) + 24|0);
 $26 = ($25|0)==($__last|0);
 if ($26) {
  STACKTOP = sp;return;
 } else {
  $29 = $46;$__i$03 = $25;$__j$02 = $0;
 }
 while(1) {
  $27 = HEAP32[$__i$03>>2]|0;
  $28 = ($27|0)<($29|0);
  if ($28) {
   $30 = $__i$03;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $29;$__j$1 = $__i$03;$__k$0 = $__j$02;
   while(1) {
    HEAP32[$__j$1>>2] = $36;
    $37 = (($__k$0) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($__j$1) + 4|0);
    HEAP32[$39>>2] = $38;
    $40 = ($__k$0|0)==($__first|0);
    if ($40) {
     break;
    }
    $41 = (($__k$0) + -8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($32|0)<($42|0);
    if ($43) {
     $__j$1$phi = $__k$0;$36 = $42;$__k$0 = $41;$__j$1 = $__j$1$phi;
    } else {
     break;
    }
   }
   HEAP32[$__k$0>>2] = $32;
   HEAP32[$37>>2] = $35;
  }
  $44 = (($__i$03) + 8|0);
  $45 = ($44|0)==($__last|0);
  if ($45) {
   break;
  }
  $$pre = HEAP32[$__i$03>>2]|0;
  $__j$02$phi = $__i$03;$29 = $$pre;$__i$03 = $44;$__j$02 = $__j$02$phi;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEbT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__count$06 = 0, $__count$1 = 0, $__i$07 = 0, $__j$05 = 0, $__j$05$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $8 = (($__first) + 4|0);
  $9 = (($__last) + -4|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $11;
  HEAP32[$9>>2] = $10;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $42 = (($__first) + 8|0);
  $43 = (($__first) + 16|0);
  $44 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEjT0_SC_SC_SC_T_($__first,$42,$43,$44,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $45 = (($__first) + 8|0);
  $46 = (($__first) + 16|0);
  $47 = (($__first) + 24|0);
  (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEENS_9allocatorINS_4pairIiiEEEEE13value_compareEPS6_EEjT0_SC_SC_SC_T_($__first,$45,$46,$47,$__comp)|0);
  $48 = (($__last) + -8|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = HEAP32[$47>>2]|0;
  $51 = ($49|0)<($50|0);
  if (!($51)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$47>>2] = $49;
  HEAP32[$48>>2] = $50;
  $52 = (($__first) + 28|0);
  $53 = (($__last) + -4|0);
  $54 = HEAP32[$52>>2]|0;
  $55 = HEAP32[$53>>2]|0;
  HEAP32[$52>>2] = $55;
  HEAP32[$53>>2] = $54;
  $56 = HEAP32[$47>>2]|0;
  $57 = HEAP32[$46>>2]|0;
  $58 = ($56|0)<($57|0);
  if (!($58)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$46>>2] = $56;
  HEAP32[$47>>2] = $57;
  $59 = (($__first) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$52>>2]|0;
  HEAP32[$59>>2] = $61;
  HEAP32[$52>>2] = $60;
  $62 = HEAP32[$45>>2]|0;
  $63 = ($56|0)<($62|0);
  if (!($63)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$45>>2] = $56;
  HEAP32[$46>>2] = $62;
  $64 = (($__first) + 12|0);
  $65 = HEAP32[$64>>2]|0;
  HEAP32[$64>>2] = $61;
  HEAP32[$59>>2] = $65;
  $66 = HEAP32[$__first>>2]|0;
  $67 = ($56|0)<($66|0);
  if (!($67)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $56;
  HEAP32[$45>>2] = $66;
  $68 = (($__first) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  HEAP32[$68>>2] = $61;
  HEAP32[$64>>2] = $69;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $12 = (($__first) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$__first>>2]|0;
  $15 = ($13|0)<($14|0);
  $16 = (($__last) + -8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)<($13|0);
  if (!($15)) {
   if (!($18)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$12>>2] = $17;
   HEAP32[$16>>2] = $13;
   $19 = (($__first) + 12|0);
   $20 = (($__last) + -4|0);
   $21 = HEAP32[$19>>2]|0;
   $22 = HEAP32[$20>>2]|0;
   HEAP32[$19>>2] = $22;
   HEAP32[$20>>2] = $21;
   $23 = HEAP32[$12>>2]|0;
   $24 = HEAP32[$__first>>2]|0;
   $25 = ($23|0)<($24|0);
   if (!($25)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__first>>2] = $23;
   HEAP32[$12>>2] = $24;
   $26 = (($__first) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$19>>2]|0;
   HEAP32[$26>>2] = $28;
   HEAP32[$19>>2] = $27;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($18) {
   HEAP32[$__first>>2] = $17;
   HEAP32[$16>>2] = $14;
   $29 = (($__first) + 4|0);
   $30 = (($__last) + -4|0);
   $31 = HEAP32[$29>>2]|0;
   $32 = HEAP32[$30>>2]|0;
   HEAP32[$29>>2] = $32;
   HEAP32[$30>>2] = $31;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $13;
  HEAP32[$12>>2] = $14;
  $33 = (($__first) + 4|0);
  $34 = (($__first) + 12|0);
  $35 = HEAP32[$33>>2]|0;
  $36 = HEAP32[$34>>2]|0;
  HEAP32[$33>>2] = $36;
  HEAP32[$34>>2] = $35;
  $37 = HEAP32[$16>>2]|0;
  $38 = ($37|0)<($14|0);
  if (!($38)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$12>>2] = $37;
  HEAP32[$16>>2] = $14;
  $39 = (($__last) + -4|0);
  $40 = HEAP32[$34>>2]|0;
  $41 = HEAP32[$39>>2]|0;
  HEAP32[$34>>2] = $41;
  HEAP32[$39>>2] = $40;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $70 = (($__first) + 16|0);
  $71 = (($__first) + 8|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = HEAP32[$__first>>2]|0;
  $74 = ($72|0)<($73|0);
  $75 = HEAP32[$70>>2]|0;
  $76 = ($75|0)<($72|0);
  do {
   if ($74) {
    if ($76) {
     HEAP32[$__first>>2] = $75;
     HEAP32[$70>>2] = $73;
     $84 = (($__first) + 4|0);
     $85 = (($__first) + 20|0);
     $86 = HEAP32[$84>>2]|0;
     $87 = HEAP32[$85>>2]|0;
     HEAP32[$84>>2] = $87;
     HEAP32[$85>>2] = $86;
     $120 = $73;
     break;
    }
    HEAP32[$__first>>2] = $72;
    HEAP32[$71>>2] = $73;
    $88 = (($__first) + 4|0);
    $89 = (($__first) + 12|0);
    $90 = HEAP32[$88>>2]|0;
    $91 = HEAP32[$89>>2]|0;
    HEAP32[$88>>2] = $91;
    HEAP32[$89>>2] = $90;
    $92 = ($75|0)<($73|0);
    if ($92) {
     HEAP32[$71>>2] = $75;
     HEAP32[$70>>2] = $73;
     $93 = (($__first) + 20|0);
     $94 = HEAP32[$93>>2]|0;
     HEAP32[$89>>2] = $94;
     HEAP32[$93>>2] = $90;
     $120 = $73;
    } else {
     $120 = $75;
    }
   } else {
    if ($76) {
     HEAP32[$71>>2] = $75;
     HEAP32[$70>>2] = $72;
     $77 = (($__first) + 12|0);
     $78 = (($__first) + 20|0);
     $79 = HEAP32[$77>>2]|0;
     $80 = HEAP32[$78>>2]|0;
     HEAP32[$77>>2] = $80;
     HEAP32[$78>>2] = $79;
     $81 = ($75|0)<($73|0);
     if ($81) {
      HEAP32[$__first>>2] = $75;
      HEAP32[$71>>2] = $73;
      $82 = (($__first) + 4|0);
      $83 = HEAP32[$82>>2]|0;
      HEAP32[$82>>2] = $80;
      HEAP32[$77>>2] = $83;
      $120 = $72;
     } else {
      $120 = $72;
     }
    } else {
     $120 = $75;
    }
   }
  } while(0);
  $95 = (($__first) + 24|0);
  $96 = ($95|0)==($__last|0);
  if ($96) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $99 = $120;$__count$06 = 0;$__i$07 = $95;$__j$05 = $70;
  }
  while(1) {
   $97 = HEAP32[$__i$07>>2]|0;
   $98 = ($97|0)<($99|0);
   if ($98) {
    $100 = $__i$07;
    $101 = $100;
    $102 = HEAP32[$101>>2]|0;
    $103 = (($100) + 4)|0;
    $104 = $103;
    $105 = HEAP32[$104>>2]|0;
    $106 = $99;$__j$1 = $__i$07;$__k$0 = $__j$05;
    while(1) {
     HEAP32[$__j$1>>2] = $106;
     $107 = (($__k$0) + 4|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = (($__j$1) + 4|0);
     HEAP32[$109>>2] = $108;
     $110 = ($__k$0|0)==($__first|0);
     if ($110) {
      break;
     }
     $111 = (($__k$0) + -8|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ($102|0)<($112|0);
     if ($113) {
      $__j$1$phi = $__k$0;$106 = $112;$__k$0 = $111;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    HEAP32[$__k$0>>2] = $102;
    HEAP32[$107>>2] = $105;
    $114 = (($__count$06) + 1)|0;
    $115 = ($114|0)==(8);
    if ($115) {
     break;
    } else {
     $__count$1 = $114;
    }
   } else {
    $__count$1 = $__count$06;
   }
   $118 = (($__i$07) + 8|0);
   $119 = ($118|0)==($__last|0);
   if ($119) {
    $$0 = 1;
    label = 35;
    break;
   }
   $$pre = HEAP32[$__i$07>>2]|0;
   $__j$05$phi = $__i$07;$99 = $$pre;$__count$06 = $__count$1;$__i$07 = $118;$__j$05 = $__j$05$phi;
  }
  if ((label|0) == 35) {
   STACKTOP = sp;return ($$0|0);
  }
  $116 = (($__i$07) + 8|0);
  $117 = ($116|0)==($__last|0);
  $$0 = $117;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN16MessageForwarderC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN16MessageForwarder13HandleMessageEPviR11MessageData($this,$receiver,$messageID,$messageData) {
 $this = $this|0;
 $receiver = $receiver|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $messagePtr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)>($messageID|0);
 if ($9) {
  $10 = (($4) + ($messageID<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  $$ = $12 ? $1 : $11;
  $messagePtr$0 = $$;
 } else {
  $messagePtr$0 = $1;
 }
 FUNCTION_TABLE_viii[$messagePtr$0 & 4095]($receiver,$messageID,$messageData);
 STACKTOP = sp;return;
}
function __ZN16MessageForwarder23RegisterMessageCallbackEiPFvPviR11MessageDataEi($this,$messageID,$message,$classId) {
 $this = $this|0;
 $messageID = $messageID|0;
 $message = $message|0;
 $classId = $classId|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i = 0, $__new_last2$i$i$i1 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i2 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i6 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i4 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)>($messageID|0);
 do {
  if (!($9)) {
   $10 = (($messageID) + 1)|0;
   HEAP32[$0>>2] = 0;
   $11 = ($8>>>0)<($10>>>0);
   if ($11) {
    $12 = (($10) - ($8))|0;
    __ZNSt3__16vectorIPFvPviR11MessageDataENS_9allocatorIS5_EEE8__appendEjRKS5_($this,$12,$0);
   } else {
    $13 = ($8>>>0)>($10>>>0);
    if ($13) {
     $14 = (($4) + ($10<<2)|0);
     $15 = ($3|0)==($14|0);
     if (!($15)) {
      $__new_last2$i$i$i1 = $14;
      $scevgep$i$i$i2 = (($3) + -4|0);
      $16 = (0 - ($__new_last2$i$i$i1))|0;
      $uglygep$i$i$i4 = (($scevgep$i$i$i2) + ($16)|0);
      $uglygep3$i$i$i5 = $uglygep$i$i$i4;
      $17 = $uglygep3$i$i$i5 >>> 2;
      $18 = $17 ^ -1;
      $scevgep4$i$i$i6 = (($3) + ($18<<2)|0);
      HEAP32[$2>>2] = $scevgep4$i$i$i6;
     }
    }
   }
   $19 = (($this) + 12|0);
   HEAP32[$1>>2] = 0;
   $20 = (($this) + 16|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$19>>2]|0;
   $23 = $21;
   $24 = $22;
   $25 = (($23) - ($24))|0;
   $26 = $25 >> 2;
   $27 = ($26>>>0)<($10>>>0);
   if ($27) {
    $28 = (($10) - ($26))|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE8__appendEjRKi($19,$28,$1);
    break;
   }
   $29 = ($26>>>0)>($10>>>0);
   if ($29) {
    $30 = (($22) + ($10<<2)|0);
    $31 = ($21|0)==($30|0);
    if (!($31)) {
     $__new_last2$i$i$i = $30;
     $scevgep$i$i$i = (($21) + -4|0);
     $32 = (0 - ($__new_last2$i$i$i))|0;
     $uglygep$i$i$i = (($scevgep$i$i$i) + ($32)|0);
     $uglygep3$i$i$i = $uglygep$i$i$i;
     $33 = $uglygep3$i$i$i >>> 2;
     $34 = $33 ^ -1;
     $scevgep4$i$i$i = (($21) + ($34<<2)|0);
     HEAP32[$20>>2] = $scevgep4$i$i$i;
    }
   }
  }
 } while(0);
 $35 = HEAP32[$this>>2]|0;
 $36 = (($35) + ($messageID<<2)|0);
 HEAP32[$36>>2] = $message;
 $37 = (($this) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + ($messageID<<2)|0);
 HEAP32[$39>>2] = $classId;
 STACKTOP = sp;return;
}
function __ZN16MessageForwarder27RegisterAllMessagesCallbackEPFvPviR11MessageDataEPFbS0_iS2_E($this,$message,$canHandle) {
 $this = $this|0;
 $message = $message|0;
 $canHandle = $canHandle|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 HEAP32[$0>>2] = $message;
 $1 = (($this) + 28|0);
 HEAP32[$1>>2] = $canHandle;
 STACKTOP = sp;return;
}
function __ZN16MessageForwarder15AddBaseMessagesERKS_($this,$baseClass) {
 $this = $this|0;
 $baseClass = $baseClass|0;
 var $$pre = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $i$08 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = (($baseClass) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$baseClass>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = $14 >> 2;
 $16 = ($8>>>0)<($15>>>0);
 $17 = $16 ? $15 : $8;
 HEAP32[$0>>2] = 0;
 if ($16) {
  $18 = (($17) - ($8))|0;
  __ZNSt3__16vectorIPFvPviR11MessageDataENS_9allocatorIS5_EEE8__appendEjRKS5_($this,$18,$0);
 }
 $19 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $20 = (($this) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$19>>2]|0;
 $23 = $21;
 $24 = $22;
 $25 = (($23) - ($24))|0;
 $26 = $25 >> 2;
 $27 = ($26>>>0)<($17>>>0);
 if ($27) {
  $28 = (($17) - ($26))|0;
  __ZNSt3__16vectorIiNS_9allocatorIiEEE8__appendEjRKi($19,$28,$1);
 } else {
  $29 = ($26>>>0)>($17>>>0);
  if ($29) {
   $30 = (($22) + ($17<<2)|0);
   $31 = ($21|0)==($30|0);
   if (!($31)) {
    $__new_last2$i$i$i = $30;
    $scevgep$i$i$i = (($21) + -4|0);
    $32 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($32)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $33 = $uglygep3$i$i$i >>> 2;
    $34 = $33 ^ -1;
    $scevgep4$i$i$i = (($21) + ($34<<2)|0);
    HEAP32[$20>>2] = $scevgep4$i$i$i;
   }
  }
 }
 $35 = HEAP32[$2>>2]|0;
 $36 = HEAP32[$this>>2]|0;
 $37 = ($35|0)==($36|0);
 if (!($37)) {
  $38 = (($baseClass) + 12|0);
  $40 = $36;$70 = $35;$i$08 = 0;
  while(1) {
   $39 = (($40) + ($i$08<<2)|0);
   $41 = HEAP32[$39>>2]|0;
   $42 = ($41|0)==(0|0);
   if ($42) {
    $43 = HEAP32[$9>>2]|0;
    $44 = HEAP32[$baseClass>>2]|0;
    $45 = $43;
    $46 = $44;
    $47 = (($45) - ($46))|0;
    $48 = $47 >> 2;
    $49 = ($i$08>>>0)<($48>>>0);
    if ($49) {
     $50 = (($44) + ($i$08<<2)|0);
     $51 = HEAP32[$50>>2]|0;
     HEAP32[$39>>2] = $51;
     $52 = HEAP32[$38>>2]|0;
     $53 = (($52) + ($i$08<<2)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = HEAP32[$19>>2]|0;
     $56 = (($55) + ($i$08<<2)|0);
     HEAP32[$56>>2] = $54;
     $$pre = HEAP32[$2>>2]|0;
     $$pre9 = HEAP32[$this>>2]|0;
     $59 = $$pre;$61 = $$pre9;
    } else {
     $59 = $70;$61 = $40;
    }
   } else {
    $59 = $70;$61 = $40;
   }
   $57 = (($i$08) + 1)|0;
   $58 = $59;
   $60 = $61;
   $62 = (($58) - ($60))|0;
   $63 = $62 >> 2;
   $64 = ($57>>>0)<($63>>>0);
   if ($64) {
    $40 = $61;$70 = $59;$i$08 = $57;
   } else {
    break;
   }
  }
 }
 $65 = (($this) + 24|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  STACKTOP = sp;return;
 }
 $68 = (($baseClass) + 24|0);
 $69 = HEAP32[$68>>2]|0;
 HEAP32[$65>>2] = $69;
 STACKTOP = sp;return;
}
function __ZN14MessageHandler28InitializeMessageIdentifiersEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01 = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__new_last2$i$i$i = 0, $__new_last2$i$i$i2 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i14 = 0, $index$027 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i3 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i7 = 0, $sortedMessages = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i5 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $sortedMessages = sp + 24|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = (__ZN17MessageIdentifier21GetRegisteredMessagesEv()|0);
 __ZN17MessageIdentifier17GetSortedMessagesEb($sortedMessages,0);
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 if (!($7)) {
  $__new_last2$i$i$i = $4;
  $scevgep$i$i$i = (($6) + -20|0);
  $8 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($8)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $9 = (($uglygep3$i$i$i>>>0) / 20)&-1;
  $10 = $9 ^ -1;
  $scevgep4$i$i$i = (($6) + (($10*20)|0)|0);
  HEAP32[$5>>2] = $scevgep4$i$i$i;
 }
 $11 = (($this) + 48|0);
 $12 = (($this) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($11,$13);
 $14 = (($this) + 56|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 52|0);
 HEAP32[$11>>2] = $15;
 HEAP32[$15>>2] = 0;
 $16 = (($sortedMessages) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$5>>2]|0;
 $19 = HEAP32[$3>>2]|0;
 $20 = $18;
 $21 = $19;
 $22 = (($20) - ($21))|0;
 $23 = (($22|0) / 20)&-1;
 $24 = ($23>>>0)<($17>>>0);
 if ($24) {
  $25 = (($17) - ($23))|0;
  __THREW__ = 0;
  invoke_vii(2600,($3|0),($25|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   label = 17;
  } else {
   label = 8;
  }
 } else {
  $28 = ($23>>>0)>($17>>>0);
  if ($28) {
   $29 = (($19) + (($17*20)|0)|0);
   $30 = ($18|0)==($29|0);
   if ($30) {
    label = 8;
   } else {
    $__new_last2$i$i$i2 = $29;
    $scevgep$i$i$i3 = (($18) + -20|0);
    $31 = (0 - ($__new_last2$i$i$i2))|0;
    $uglygep$i$i$i5 = (($scevgep$i$i$i3) + ($31)|0);
    $uglygep3$i$i$i6 = $uglygep$i$i$i5;
    $32 = (($uglygep3$i$i$i6>>>0) / 20)&-1;
    $33 = $32 ^ -1;
    $scevgep4$i$i$i7 = (($18) + (($33*20)|0)|0);
    HEAP32[$5>>2] = $scevgep4$i$i$i7;
    label = 8;
   }
  } else {
   label = 8;
  }
 }
 L9: do {
  if ((label|0) == 8) {
   $34 = HEAP32[$sortedMessages>>2]|0;
   $35 = (($sortedMessages) + 4|0);
   $36 = ($34|0)==($35|0);
   L11: do {
    if (!($36)) {
     $38 = $34;$index$027 = 0;
     while(1) {
      $37 = (($38) + 16|0);
      __THREW__ = 0;
      $39 = (invoke_iii(2357,($11|0),($37|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      HEAP32[$39>>2] = $index$027;
      $42 = HEAP32[$3>>2]|0;
      $43 = (($42) + (($index$027*20)|0)|0);
      $44 = (($38) + 28|0);
      ;HEAP32[$43+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$44+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$44+12>>2]|0;HEAP32[$43+16>>2]=HEAP32[$44+16>>2]|0;
      $45 = HEAP32[$3>>2]|0;
      $46 = ((($45) + (($index$027*20)|0)|0) + 8|0);
      HEAP32[$46>>2] = $index$027;
      $47 = (($index$027) + 1)|0;
      $48 = (($38) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       $$01$i$i$i$i = $38;
       while(1) {
        $53 = (($$01$i$i$i$i) + 8|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = HEAP32[$54>>2]|0;
        $56 = ($55|0)==($$01$i$i$i$i|0);
        if ($56) {
         $$0$i$i$i$i = $54;
         break;
        } else {
         $$01$i$i$i$i = $54;
        }
       }
      } else {
       $$0$i$i$i$i$i = $49;
       while(1) {
        $51 = HEAP32[$$0$i$i$i$i$i>>2]|0;
        $52 = ($51|0)==(0|0);
        if ($52) {
         $$0$i$i$i$i = $$0$i$i$i$i$i;
         break;
        } else {
         $$0$i$i$i$i$i = $51;
        }
       }
      }
      $57 = ($$0$i$i$i$i|0)==($35|0);
      if ($57) {
       break L11;
      } else {
       $38 = $$0$i$i$i$i;$index$027 = $47;
      }
     }
     $60 = ___cxa_find_matching_catch()|0;
     $61 = tempRet0;
     $lpad$phi$index = $60;$lpad$phi$index3 = $61;
     break L9;
    }
   } while(0);
   $64 = (($2) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==($2|0);
   if ($66) {
    $131 = (($sortedMessages) + 4|0);
    $132 = HEAP32[$131>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($sortedMessages,$132);
    STACKTOP = sp;return;
   }
   $67 = (($0) + 1|0);
   $68 = (($1) + 1|0);
   $69 = (($1) + 8|0);
   $70 = (($1) + 4|0);
   $71 = (($0) + 8|0);
   $72 = (($0) + 4|0);
   $74 = $65;
   while(1) {
    $73 = (($74) + 8|0);
    $75 = HEAP32[$73>>2]|0;
    $76 = HEAP32[$75>>2]|0;
    $77 = (_strlen(($76|0))|0);
    $78 = ($77>>>0)>(4294967279);
    if ($78) {
     label = 22;
     break;
    }
    $81 = ($77>>>0)<(11);
    if ($81) {
     $82 = $77 << 1;
     $83 = $82&255;
     HEAP8[$0>>0] = $83;
     $94 = $83;$__p$0$i$i$i14 = $67;
    } else {
     $84 = (($77) + 16)|0;
     $85 = $84 & -16;
     __THREW__ = 0;
     $86 = (invoke_ii(2988,($85|0))|0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 15;
      break;
     }
     HEAP32[$71>>2] = $86;
     $89 = $85 | 1;
     HEAP32[$0>>2] = $89;
     HEAP32[$72>>2] = $77;
     $90 = $89&255;
     $94 = $90;$__p$0$i$i$i14 = $86;
    }
    _memcpy(($__p$0$i$i$i14|0),($76|0),($77|0))|0;
    $91 = (($__p$0$i$i$i14) + ($77)|0);
    HEAP8[$91>>0] = 0;
    $92 = (__ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE14__count_uniqueIS7_EEjRKT_($11,$0)|0);
    $93 = $94 & 1;
    $95 = ($93<<24>>24)==(0);
    if (!($95)) {
     $96 = HEAP32[$71>>2]|0;
     __ZdlPv($96);
    }
    $97 = ($92|0)==(0);
    if (!($97)) {
     $98 = HEAP32[$75>>2]|0;
     $99 = (_strlen(($98|0))|0);
     $100 = ($99>>>0)>(4294967279);
     if ($100) {
      label = 32;
      break;
     }
     $103 = ($99>>>0)<(11);
     if ($103) {
      $104 = $99 << 1;
      $105 = $104&255;
      HEAP8[$1>>0] = $105;
      $__p$0$i$i$i = $68;
     } else {
      $106 = (($99) + 16)|0;
      $107 = $106 & -16;
      __THREW__ = 0;
      $108 = (invoke_ii(2988,($107|0))|0);
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       label = 15;
       break;
      }
      HEAP32[$69>>2] = $108;
      $111 = $107 | 1;
      HEAP32[$1>>2] = $111;
      HEAP32[$70>>2] = $99;
      $__p$0$i$i$i = $108;
     }
     _memcpy(($__p$0$i$i$i|0),($98|0),($99|0))|0;
     $112 = (($__p$0$i$i$i) + ($99)|0);
     HEAP8[$112>>0] = 0;
     __THREW__ = 0;
     $113 = (invoke_iii(2357,($11|0),($1|0))|0);
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if ($115) {
      label = 41;
      break;
     }
     $116 = HEAP32[$113>>2]|0;
     $117 = (($75) + 8|0);
     HEAP32[$117>>2] = $116;
     $118 = HEAP8[$1>>0]|0;
     $119 = $118 & 1;
     $120 = ($119<<24>>24)==(0);
     if (!($120)) {
      $121 = HEAP32[$69>>2]|0;
      __ZdlPv($121);
     }
    }
    $128 = (($74) + 4|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = ($129|0)==($2|0);
    if ($130) {
     label = 44;
     break;
    } else {
     $74 = $129;
    }
   }
   if ((label|0) == 15) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    $lpad$phi$index = $58;$lpad$phi$index3 = $59;
    break;
   }
   else if ((label|0) == 22) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     label = 17;
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 32) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     label = 17;
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 41) {
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    $124 = HEAP8[$1>>0]|0;
    $125 = $124 & 1;
    $126 = ($125<<24>>24)==(0);
    if ($126) {
     $$0 = $122;$$01 = $123;
     $133 = (($sortedMessages) + 4|0);
     $134 = HEAP32[$133>>2]|0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($sortedMessages,$134);
     ___resumeException($$0|0);
     // unreachable;
    }
    $127 = HEAP32[$69>>2]|0;
    __ZdlPv($127);
    $$0 = $122;$$01 = $123;
    $133 = (($sortedMessages) + 4|0);
    $134 = HEAP32[$133>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($sortedMessages,$134);
    ___resumeException($$0|0);
    // unreachable;
   }
   else if ((label|0) == 44) {
    $131 = (($sortedMessages) + 4|0);
    $132 = HEAP32[$131>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($sortedMessages,$132);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $62 = ___cxa_find_matching_catch()|0;
  $63 = tempRet0;
  $lpad$phi$index = $62;$lpad$phi$index3 = $63;
 }
 $$0 = $lpad$phi$index;$$01 = $lpad$phi$index3;
 $133 = (($sortedMessages) + 4|0);
 $134 = HEAP32[$133>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($sortedMessages,$134);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiNS_4lessIS6_EENS4_INS_4pairIKS6_iEEEEEixERSA_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (__ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiNS_4lessIS6_EENS4_INS_4pairIKS6_iEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERSA_($this,$__parent,$__k)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $__r$0 = $1;
  $44 = (($__r$0) + 28|0);
  STACKTOP = sp;return ($44|0);
 }
 $3 = (__Znwj(32)|0);
 $4 = (($3) + 16|0);
 $5 = HEAP8[$__k>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 L4: do {
  if ($7) {
   ;HEAP32[$4+0>>2]=HEAP32[$__k+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__k+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__k+8>>2]|0;
  } else {
   $8 = (($__k) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($__k) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11>>>0)>(4294967279);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    } else {
     $15 = ($11>>>0)<(11);
     if ($15) {
      $16 = $11 << 1;
      $17 = $16&255;
      HEAP8[$4>>0] = $17;
      $18 = (($3) + 17|0);
      $__p$0$i$i$i$i$i = $18;
     } else {
      $19 = (($11) + 16)|0;
      $20 = $19 & -16;
      __THREW__ = 0;
      $21 = (invoke_ii(2988,($20|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      $24 = (($3) + 24|0);
      HEAP32[$24>>2] = $21;
      $25 = $20 | 1;
      HEAP32[$4>>2] = $25;
      $26 = (($3) + 20|0);
      HEAP32[$26>>2] = $11;
      $__p$0$i$i$i$i$i = $21;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($9|0),($11|0))|0;
     $27 = (($__p$0$i$i$i$i$i) + ($11)|0);
     HEAP8[$27>>0] = 0;
     break L4;
    }
   } while(0);
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = ($3|0)==(0|0);
   if ($30) {
    ___resumeException($28|0);
    // unreachable;
   }
   __ZdlPv($3);
   ___resumeException($28|0);
   // unreachable;
  }
 } while(0);
 $31 = (($3) + 28|0);
 HEAP32[$31>>2] = 0;
 $32 = HEAP32[$__parent>>2]|0;
 HEAP32[$3>>2] = 0;
 $33 = (($3) + 4|0);
 HEAP32[$33>>2] = 0;
 $34 = (($3) + 8|0);
 HEAP32[$34>>2] = $32;
 HEAP32[$0>>2] = $3;
 $35 = HEAP32[$this>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $40 = $3;
 } else {
  HEAP32[$this>>2] = $36;
  $$pre$i = HEAP32[$0>>2]|0;
  $40 = $$pre$i;
 }
 $38 = (($this) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($39,$40);
 $41 = (($this) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 1)|0;
 HEAP32[$41>>2] = $43;
 $__r$0 = $3;
 $44 = (($__r$0) + 28|0);
 STACKTOP = sp;return ($44|0);
}
function __ZN14MessageHandler10InitializeERKNSt3__16vectorI16MessageForwarder13stl_allocatorIS2_L18MemLabelIdentifier1ELi8EEEE($this,$receivers) {
 $this = $this|0;
 $receivers = $receivers|0;
 var $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $$pre12 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $buffy = 0, $c$09 = 0, $m$06 = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4112|0;
 $vararg_buffer = sp;
 $buffy = sp + 16|0;
 $0 = (($this) + 16|0);
 $1 = ($0|0)==($receivers|0);
 if ($1) {
  $$pre13 = (($receivers) + 4|0);
  $$pre$phi15Z2D = $receivers;$$pre$phiZ2D = $$pre13;
 } else {
  $2 = HEAP32[$receivers>>2]|0;
  $3 = (($receivers) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($0,$2,$4);
  $$pre$phi15Z2D = $receivers;$$pre$phiZ2D = $3;
 }
 $5 = (($this) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$$pre$phiZ2D>>2]|0;
 $9 = HEAP32[$$pre$phi15Z2D>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 5;
 $14 = (($this) + 28|0);
 HEAP32[$14>>2] = $13;
 $15 = Math_imul($13, $6)|0;
 __ZN14dynamic_bitset6resizeEjb($this,$15,0);
 $16 = HEAP32[$14>>2]|0;
 $17 = ($16|0)>(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($this) + 36|0);
 $19 = (($this) + 4|0);
 $$pre = HEAP32[$7>>2]|0;
 $21 = $$pre;$83 = $16;$c$09 = 0;
 while(1) {
  $20 = ($21|0)>(0);
  if ($20) {
   $m$06 = 0;
   while(1) {
    $22 = HEAP32[$0>>2]|0;
    $23 = HEAP32[$18>>2]|0;
    $24 = ((($23) + (($m$06*20)|0)|0) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($22) + ($c$09<<5)|0) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($22) + ($c$09<<5)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = $27;
    $31 = $29;
    $32 = (($30) - ($31))|0;
    $33 = $32 >> 2;
    $34 = ($25|0)<($33|0);
    if ($34) {
     $35 = (($29) + ($25<<2)|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      label = 9;
     } else {
      label = 11;
     }
    } else {
     label = 9;
    }
    if ((label|0) == 9) {
     label = 0;
     $38 = ((($22) + ($c$09<<5)|0) + 24|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      label = 14;
     } else {
      $41 = ((($23) + (($m$06*20)|0)|0) + 16|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = $42 & 1;
      $44 = ($43|0)==(0);
      if ($44) {
       label = 14;
      } else {
       label = 11;
      }
     }
    }
    do {
     if ((label|0) == 11) {
      label = 0;
      $45 = ($33|0)>($m$06|0);
      if ($45) {
       $46 = ((($22) + ($c$09<<5)|0) + 12|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + ($m$06<<2)|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = ((($23) + (($m$06*20)|0)|0) + 12|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = ($49|0)==(0);
       $53 = ($51|0)==($49|0);
       $or$cond = $52 | $53;
       if (!($or$cond)) {
        $54 = (($23) + (($m$06*20)|0)|0);
        $55 = HEAP32[$54>>2]|0;
        HEAP32[$vararg_buffer>>2] = $55;
        $vararg_ptr1 = (($vararg_buffer) + 4|0);
        HEAP32[$vararg_ptr1>>2] = $c$09;
        $vararg_ptr2 = (($vararg_buffer) + 8|0);
        HEAP32[$vararg_ptr2>>2] = $49;
        $vararg_ptr3 = (($vararg_buffer) + 12|0);
        HEAP32[$vararg_ptr3>>2] = $51;
        (_snprintf($buffy,4096,563184,$vararg_buffer)|0);
        __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE($buffy,0,563320,150,1,0,0,0);
        label = 14;
        break;
       }
      }
      $67 = HEAP32[$14>>2]|0;
      $68 = Math_imul($67, $m$06)|0;
      $69 = (($68) + ($c$09))|0;
      $70 = $69 & 31;
      $71 = 1 << $70;
      $72 = $69 >>> 5;
      $73 = HEAP32[$19>>2]|0;
      $74 = (($73) + ($72<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = $71 | $75;
      HEAP32[$74>>2] = $76;
     }
    } while(0);
    if ((label|0) == 14) {
     label = 0;
     $56 = HEAP32[$14>>2]|0;
     $57 = Math_imul($56, $m$06)|0;
     $58 = (($57) + ($c$09))|0;
     $59 = $58 & 31;
     $60 = 1 << $59;
     $61 = $60 ^ -1;
     $62 = $58 >>> 5;
     $63 = HEAP32[$19>>2]|0;
     $64 = (($63) + ($62<<2)|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = $65 & $61;
     HEAP32[$64>>2] = $66;
    }
    $77 = (($m$06) + 1)|0;
    $78 = HEAP32[$7>>2]|0;
    $79 = ($77|0)<($78|0);
    if ($79) {
     $m$06 = $77;
    } else {
     break;
    }
   }
   $$pre12 = HEAP32[$14>>2]|0;
   $82 = $$pre12;$84 = $78;
  } else {
   $82 = $83;$84 = $21;
  }
  $80 = (($c$09) + 1)|0;
  $81 = ($80|0)<($82|0);
  if ($81) {
   $21 = $84;$83 = $82;$c$09 = $80;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14MessageHandler17WillHandleMessageEPvii($this,$receiver,$classID,$messageID) {
 $this = $this|0;
 $receiver = $receiver|0;
 $classID = $classID|0;
 $messageID = $messageID|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i = sp;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + (($messageID*20)|0)|0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($1) + ($classID<<5)|0) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + ($classID<<5)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($5|0)<($13|0);
 if ($14) {
  $15 = (($9) + ($5<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $$0$i = 1;
   STACKTOP = sp;return ($$0$i|0);
  }
 }
 $18 = ((($1) + ($classID<<5)|0) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $21 = ((($3) + (($messageID*20)|0)|0) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 & 1;
 $24 = ($23|0)==(0);
 if ($24) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $25 = (($data$i) + 8|0);
 HEAP32[$25>>2] = 0;
 $26 = (($data$i) + 4|0);
 HEAP32[$26>>2] = 0;
 HEAP32[$data$i>>2] = 0;
 $27 = ((($1) + ($classID<<5)|0) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_iiii[$28 & 2047]($receiver,$5,$data$i)|0);
 $$0$i = $29;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN14MessageHandler15MessageIDToNameEi($this,$messageID) {
 $this = $this|0;
 $messageID = $messageID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($messageID*20)|0)|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN14MessageHandler20MessageIDToParameterEi($this,$messageID) {
 $this = $this|0;
 $messageID = $messageID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + (($messageID*20)|0)|0) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN14MessageHandler28MessageIDToMessageIdentifierEi($agg$result,$this,$messageID) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $messageID = $messageID|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($messageID*20)|0)|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$2+16>>2]|0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$i = 0, $$$i$i$i$i = 0, $$$i$i$i$i$i = 0, $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = HEAP8[$__v>>0]|0;
  $5 = $4 & 1;
  $6 = ($5<<24>>24)==(0);
  $7 = $4&255;
  $8 = $7 >>> 1;
  $9 = (($__v) + 1|0);
  $10 = (($__v) + 8|0);
  $11 = (($__v) + 4|0);
  $$0$ph7$i = $2;$$01$ph6$i$in = $1;
  L3: while(1) {
   $$013$i$in = $$01$ph6$i$in;
   while(1) {
    $12 = (($$013$i$in) + 16|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     $18 = $13&255;
     $19 = $18 >>> 1;
     $27 = $19;
    } else {
     $16 = (($$013$i$in) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $27 = $17;
    }
    if ($6) {
     $26 = $8;
    } else {
     $20 = HEAP32[$11>>2]|0;
     $26 = $20;
    }
    if ($15) {
     $23 = (($12) + 1|0);
     $29 = $23;
    } else {
     $21 = (($$013$i$in) + 24|0);
     $22 = HEAP32[$21>>2]|0;
     $29 = $22;
    }
    if ($6) {
     $30 = $9;
    } else {
     $24 = HEAP32[$10>>2]|0;
     $30 = $24;
    }
    $25 = ($26>>>0)<($27>>>0);
    $28 = $25 ? $26 : $27;
    $31 = (_memcmp($29,$30,$28)|0);
    $32 = ($31|0)==(0);
    if ($32) {
     $33 = ($27>>>0)<($26>>>0);
     $$$i$i$i$i$i = $25&1;
     $$$$i$i$i$i$i = $33 ? -1 : $$$i$i$i$i$i;
     $35 = $$$$i$i$i$i$i;
    } else {
     $35 = $31;
    }
    $34 = ($35|0)<(0);
    if (!($34)) {
     break;
    }
    $38 = (($$013$i$in) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$0$ph5$i = $$0$ph7$i;
     break L3;
    } else {
     $$013$i$in = $39;
    }
   }
   $36 = HEAP32[$$013$i$in>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    $$0$ph5$i = $$013$i$in;
    break;
   } else {
    $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $36;
   }
  }
  $41 = ($$0$ph5$i|0)==($2|0);
  if (!($41)) {
   $42 = (($$0$ph5$i) + 16|0);
   if ($6) {
    $57 = $8;
   } else {
    $43 = HEAP32[$11>>2]|0;
    $57 = $43;
   }
   $44 = HEAP8[$42>>0]|0;
   $45 = $44 & 1;
   $46 = ($45<<24>>24)==(0);
   if ($46) {
    $49 = $44&255;
    $50 = $49 >>> 1;
    $56 = $50;
   } else {
    $47 = (($$0$ph5$i) + 20|0);
    $48 = HEAP32[$47>>2]|0;
    $56 = $48;
   }
   if ($6) {
    $59 = $9;
   } else {
    $51 = HEAP32[$10>>2]|0;
    $59 = $51;
   }
   if ($46) {
    $54 = (($42) + 1|0);
    $60 = $54;
   } else {
    $52 = (($$0$ph5$i) + 24|0);
    $53 = HEAP32[$52>>2]|0;
    $60 = $53;
   }
   $55 = ($56>>>0)<($57>>>0);
   $58 = $55 ? $56 : $57;
   $61 = (_memcmp($59,$60,$58)|0);
   $62 = ($61|0)==(0);
   if ($62) {
    $63 = ($57>>>0)<($56>>>0);
    $$$i$i$i$i = $55&1;
    $$$$i$i$i$i = $63 ? -1 : $$$i$i$i$i;
    $65 = $$$$i$i$i$i;
   } else {
    $65 = $61;
   }
   $64 = ($65|0)<(0);
   if (!($64)) {
    HEAP32[$agg$result>>2] = $$0$ph5$i;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i2 = 0, $$0$lcssa$i$i = 0, $$012$i$i = 0, $$03$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1$i$i$i$i$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep4$i$i$i$i$i6$i$i$i$i$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5$i$i$i$i$i$i = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = $__last;
 $2 = $__first;
 $3 = (($1) - ($2))|0;
 $4 = $3 >> 5;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$this>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 5;
 $12 = ($4>>>0)>($11>>>0);
 if ($12) {
  __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE10deallocateEv($this);
  $72 = ($3|0)<(0);
  if ($72) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $73 = HEAP32[$5>>2]|0;
  $74 = HEAP32[$this>>2]|0;
  $75 = $73;
  $76 = $74;
  $77 = (($75) - ($76))|0;
  $78 = $77 >> 5;
  $79 = ($78>>>0)<(1073741823);
  if ($79) {
   $80 = $77 >> 4;
   $81 = ($80>>>0)<($4>>>0);
   $82 = $81 ? $4 : $80;
   $83 = ($82|0)<(0);
   if ($83) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i2 = $82;
   }
  } else {
   $$0$i2 = 2147483647;
  }
  $84 = $$0$i2 << 5;
  HEAP32[$0>>2] = 1;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $85 = (__Z15malloc_internaljj10MemLabelIdiPKci($84,8,$$byval_copy,0,563320,79)|0);
  $86 = (($this) + 4|0);
  HEAP32[$86>>2] = $85;
  HEAP32[$this>>2] = $85;
  $87 = (($85) + ($$0$i2<<5)|0);
  HEAP32[$5>>2] = $87;
  __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_($this,$__first,$__last);
  STACKTOP = sp;return;
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 5;
 $18 = ($4>>>0)>($17>>>0);
 if ($18) {
  $19 = (($__first) + ($17<<5)|0);
  $21 = $19;$__growing$0$off0 = 1;
 } else {
  $21 = $__last;$__growing$0$off0 = 0;
 }
 $20 = ($21|0)==($__first|0);
 if ($20) {
  $$0$lcssa$i$i = $7;
 } else {
  $scevgep$i$i = (($21) + -32|0);
  $22 = (0 - ($2))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($22)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $7;
  while(1) {
   $23 = ($$03$i$i|0)==($$012$i$i|0);
   if (!($23)) {
    $24 = HEAP32[$$012$i$i>>2]|0;
    $25 = (($$012$i$i) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    __ZNSt3__16vectorIPFvPviR11MessageDataENS_9allocatorIS5_EEE6assignIPS5_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS5_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($$03$i$i,$24,$26);
    $27 = (($$03$i$i) + 12|0);
    $28 = (($$012$i$i) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($$012$i$i) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6assignIPiEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIiNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($27,$29,$31);
   }
   $32 = (($$03$i$i) + 24|0);
   $33 = (($$012$i$i) + 24|0);
   $34 = $33;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $32;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   $44 = (($$012$i$i) + 32|0);
   $45 = (($$03$i$i) + 32|0);
   $46 = ($44|0)==($21|0);
   if ($46) {
    break;
   } else {
    $$012$i$i = $44;$$03$i$i = $45;
   }
  }
  $47 = $uglygep6$i$i >>> 5;
  $48 = (($47) + 1)|0;
  $scevgep7$i$i = (($7) + ($48<<5)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if ($__growing$0$off0) {
  __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_($this,$21,$__last);
  STACKTOP = sp;return;
 }
 $49 = HEAP32[$13>>2]|0;
 $50 = ($49|0)==($$0$lcssa$i$i|0);
 if ($50) {
  STACKTOP = sp;return;
 } else {
  $52 = $49;
 }
 while(1) {
  $51 = (($52) + -32|0);
  HEAP32[$13>>2] = $51;
  $53 = (($52) + -20|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = (($52) + -16|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==($54|0);
   if (!($58)) {
    $__new_last2$i$i$i$i$i$i$i$i$i$i$i = $54;
    $scevgep$i$i$i$i$i$i$i$i$i$i$i = (($57) + -4|0);
    $59 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i) + ($59)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i;
    $60 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i >>> 2;
    $61 = $60 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i$i$i = (($57) + ($61<<2)|0);
    HEAP32[$56>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($54);
  }
  $62 = HEAP32[$51>>2]|0;
  $63 = ($62|0)==(0|0);
  if (!($63)) {
   $66 = (($52) + -28|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==($62|0);
   if (!($68)) {
    $__new_last2$i$i$i$i$i1$i$i$i$i$i$i = $62;
    $scevgep$i$i$i$i$i2$i$i$i$i$i$i = (($67) + -4|0);
    $69 = (0 - ($__new_last2$i$i$i$i$i1$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i4$i$i$i$i$i$i = (($scevgep$i$i$i$i$i2$i$i$i$i$i$i) + ($69)|0);
    $uglygep3$i$i$i$i$i5$i$i$i$i$i$i = $uglygep$i$i$i$i$i4$i$i$i$i$i$i;
    $70 = $uglygep3$i$i$i$i$i5$i$i$i$i$i$i >>> 2;
    $71 = $70 ^ -1;
    $scevgep4$i$i$i$i$i6$i$i$i$i$i$i = (($67) + ($71<<2)|0);
    HEAP32[$66>>2] = $scevgep4$i$i$i$i$i6$i$i$i$i$i$i;
   }
   __ZdlPv($62);
  }
  $64 = HEAP32[$13>>2]|0;
  $65 = ($64|0)==($$0$lcssa$i$i|0);
  if ($65) {
   break;
  } else {
   $52 = $64;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$01$i$i$i$i = 0, $$06 = 0, $$pre = 0, $$pre13 = 0, $$pre2$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 4|0);
 $$pre = HEAP32[$1>>2]|0;
 $$06 = $__first;$3 = $$pre;
 while(1) {
  $2 = ($3|0)==(0|0);
  if ($2) {
   $68 = 0;
  } else {
   HEAP32[$3>>2] = 0;
   $4 = (($3) + 4|0);
   HEAP32[$4>>2] = 0;
   $5 = (($3) + 8|0);
   HEAP32[$5>>2] = 0;
   $6 = (($$06) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$$06>>2]|0;
   $9 = $7;
   $10 = $8;
   $11 = (($9) - ($10))|0;
   $12 = $11 >> 2;
   $13 = ($12|0)==(0);
   if (!($13)) {
    $14 = ($12>>>0)>(1073741823);
    if ($14) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(2988,($11|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 13;
     break;
    }
    HEAP32[$4>>2] = $17;
    HEAP32[$3>>2] = $17;
    $20 = (($17) + ($12<<2)|0);
    HEAP32[$5>>2] = $20;
    $21 = HEAP32[$$06>>2]|0;
    $22 = HEAP32[$6>>2]|0;
    $23 = ($21|0)==($22|0);
    if (!($23)) {
     $$01$i$i$i$i = $21;$25 = $17;
     while(1) {
      $24 = ($25|0)==(0|0);
      if ($24) {
       $28 = 0;
      } else {
       $26 = HEAP32[$$01$i$i$i$i>>2]|0;
       HEAP32[$25>>2] = $26;
       $$pre2$i$i$i$i = HEAP32[$4>>2]|0;
       $28 = $$pre2$i$i$i$i;
      }
      $27 = (($28) + 4|0);
      HEAP32[$4>>2] = $27;
      $29 = (($$01$i$i$i$i) + 4|0);
      $30 = ($29|0)==($22|0);
      if ($30) {
       break;
      } else {
       $$01$i$i$i$i = $29;$25 = $27;
      }
     }
    }
   }
   $42 = (($3) + 12|0);
   $43 = (($$06) + 12|0);
   __THREW__ = 0;
   invoke_vii(2595,($42|0),($43|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    label = 21;
    break;
   }
   $55 = (($3) + 24|0);
   $56 = (($$06) + 24|0);
   $57 = $56;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + 4)|0;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = $55;
   $64 = $63;
   HEAP32[$64>>2] = $59;
   $65 = (($63) + 4)|0;
   $66 = $65;
   HEAP32[$66>>2] = $62;
   $$pre13 = HEAP32[$1>>2]|0;
   $68 = $$pre13;
  }
  $67 = (($68) + 32|0);
  HEAP32[$1>>2] = $67;
  $69 = (($$06) + 32|0);
  $70 = ($69|0)==($__last|0);
  if ($70) {
   label = 28;
   break;
  } else {
   $$06 = $69;$3 = $67;
  }
 }
 do {
  if ((label|0) == 6) {
   __THREW__ = 0;
   invoke_vi(3308,0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $33 = ___cxa_find_matching_catch()|0;
    $34 = tempRet0;
    $lpad$phi$index = $33;$lpad$phi$index2 = $34;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 13) {
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   $lpad$phi$index = $31;$lpad$phi$index2 = $32;
  }
  else if ((label|0) == 21) {
   $46 = ___cxa_find_matching_catch()|0;
   $47 = tempRet0;
   $48 = HEAP32[$3>>2]|0;
   $49 = ($48|0)==(0|0);
   if ($49) {
    ___resumeException($46|0);
    // unreachable;
   }
   $50 = HEAP32[$4>>2]|0;
   $51 = ($50|0)==($48|0);
   if (!($51)) {
    $__new_last2$i$i$i$i$i$i$i$i = $48;
    $scevgep$i$i$i$i$i$i$i$i = (($50) + -4|0);
    $52 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($52)|0);
    $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
    $53 = $uglygep3$i$i$i$i$i$i$i$i >>> 2;
    $54 = $53 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i = (($50) + ($54<<2)|0);
    HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($48);
   ___resumeException($46|0);
   // unreachable;
  }
  else if ((label|0) == 28) {
   STACKTOP = sp;return;
  }
 } while(0);
 $35 = HEAP32[$3>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $37 = HEAP32[$4>>2]|0;
 $38 = ($37|0)==($35|0);
 if (!($38)) {
  $__new_last2$i$i$i$i$i$i = $35;
  $scevgep$i$i$i$i$i$i = (($37) + -4|0);
  $39 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($39)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $40 = $uglygep3$i$i$i$i$i$i >>> 2;
  $41 = $40 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($37) + ($41<<2)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i;
 }
 __ZdlPv($35);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE10deallocateEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if ($5) {
  $27 = $1;
 } else {
  $7 = $4;
  while(1) {
   $6 = (($7) + -32|0);
   HEAP32[$3>>2] = $6;
   $8 = (($7) + -20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($7) + -16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($9|0);
    if (!($13)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = $9;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = (($12) + -4|0);
     $14 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i) + ($14)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i;
     $15 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
     $16 = $15 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = (($12) + ($16<<2)|0);
     HEAP32[$11>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($9);
   }
   $17 = HEAP32[$6>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $21 = (($7) + -28|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($17|0);
    if (!($23)) {
     $__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i = $17;
     $scevgep$i$i$i$i$i2$i$i$i$i$i$i$i = (($22) + -4|0);
     $24 = (0 - ($__new_last2$i$i$i$i$i1$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i2$i$i$i$i$i$i$i) + ($24)|0);
     $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i4$i$i$i$i$i$i$i;
     $25 = $uglygep3$i$i$i$i$i5$i$i$i$i$i$i$i >>> 2;
     $26 = $25 ^ -1;
     $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i = (($22) + ($26<<2)|0);
     HEAP32[$21>>2] = $scevgep4$i$i$i$i$i6$i$i$i$i$i$i$i;
    }
    __ZdlPv($17);
   }
   $19 = HEAP32[$3>>2]|0;
   $20 = ($19|0)==($1|0);
   if ($20) {
    break;
   } else {
    $7 = $19;
   }
  }
  $$pre = HEAP32[$this>>2]|0;
  $27 = $$pre;
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  ___cxa_call_unexpected(($30|0));
  // unreachable;
 }
 $32 = (($this) + 8|0);
 HEAP32[$32>>2] = 0;
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIiNS_9allocatorIiEEE6assignIPiEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIiNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i13 = 0, $$01$i = 0, $$01$i8 = 0, $$promoted$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i3 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0;
 var $scevgep5$i = 0, $scevgep5$i10 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i5 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep4$i = 0, $uglygep4$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = $15 >> 2;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $30 = $__last;
   $31 = (($30) - ($1))|0;
   $32 = $31 >> 2;
   _memmove(($6|0),($__first|0),($31|0))|0;
   $33 = (($6) + ($32<<2)|0);
   $34 = HEAP32[$12>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -4|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = $uglygep3$i$i >>> 2;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + ($38<<2)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + ($16<<2)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $20 = $18;
  $$promoted$i2 = HEAP32[$12>>2]|0;
  $scevgep$i3 = (($__last) + -4|0);
  $21 = (0 - ($20))|0;
  $uglygep$i5 = (($scevgep$i3) + ($21)|0);
  $uglygep4$i6 = $uglygep$i5;
  $22 = $uglygep4$i6 >>> 2;
  $$01$i8 = $18;$24 = $$promoted$i2;
  while(1) {
   $23 = ($24|0)==(0|0);
   if (!($23)) {
    $25 = HEAP32[$$01$i8>>2]|0;
    HEAP32[$24>>2] = $25;
   }
   $26 = (($24) + 4|0);
   $27 = (($$01$i8) + 4|0);
   $28 = ($27|0)==($__last|0);
   if ($28) {
    break;
   } else {
    $$01$i8 = $27;$24 = $26;
   }
  }
  $29 = (($22) + 1)|0;
  $scevgep5$i10 = (($$promoted$i2) + ($29<<2)|0);
  HEAP32[$12>>2] = $scevgep5$i10;
  STACKTOP = sp;return;
 }
 $39 = ($6|0)==(0|0);
 if ($39) {
  $48 = $5;
 } else {
  $40 = (($this) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==($6|0);
  if (!($42)) {
   $scevgep$i$i$i$i = (($41) + -4|0);
   $43 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $44 = $uglygep3$i$i$i$i >>> 2;
   $45 = $44 ^ -1;
   $scevgep4$i$i$i$i = (($41) + ($45<<2)|0);
   HEAP32[$40>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$40>>2] = 0;
  HEAP32[$this>>2] = 0;
  $48 = 0;
 }
 $46 = ($3>>>0)>(1073741823);
 if ($46) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $47 = $48;
 $49 = $47 >> 2;
 $50 = ($49>>>0)<(536870911);
 if ($50) {
  $51 = $47 >> 1;
  $52 = ($51>>>0)<($3>>>0);
  $53 = $52 ? $3 : $51;
  $54 = ($53>>>0)>(1073741823);
  if ($54) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i13 = $53;
  }
 } else {
  $$0$i13 = 1073741823;
 }
 $55 = $$0$i13 << 2;
 $56 = (__Znwj($55)|0);
 $57 = (($this) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$this>>2] = $56;
 $58 = (($56) + ($$0$i13<<2)|0);
 HEAP32[$4>>2] = $58;
 $59 = ($__first|0)==($__last|0);
 if ($59) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($__last) + -4|0);
 $60 = (0 - ($1))|0;
 $uglygep$i = (($scevgep$i) + ($60)|0);
 $uglygep4$i = $uglygep$i;
 $61 = $uglygep4$i >>> 2;
 $$01$i = $__first;$63 = $56;
 while(1) {
  $62 = ($63|0)==(0|0);
  if (!($62)) {
   $64 = HEAP32[$$01$i>>2]|0;
   HEAP32[$63>>2] = $64;
  }
  $65 = (($63) + 4|0);
  $66 = (($$01$i) + 4|0);
  $67 = ($66|0)==($__last|0);
  if ($67) {
   break;
  } else {
   $$01$i = $66;$63 = $65;
  }
 }
 $68 = (($61) + 1)|0;
 $scevgep5$i = (($56) + ($68<<2)|0);
 HEAP32[$57>>2] = $scevgep5$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIPFvPviR11MessageDataENS_9allocatorIS5_EEE6assignIPS5_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS5_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = $15 >> 2;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $27 = $__last;
   $28 = (($27) - ($1))|0;
   $29 = $28 >> 2;
   _memmove(($6|0),($__first|0),($28|0))|0;
   $30 = (($6) + ($29<<2)|0);
   $31 = HEAP32[$12>>2]|0;
   $32 = ($31|0)==($30|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $30;
   $scevgep$i$i = (($31) + -4|0);
   $33 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($33)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $34 = $uglygep3$i$i >>> 2;
   $35 = $34 ^ -1;
   $scevgep4$i$i = (($31) + ($35<<2)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + ($16<<2)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$12>>2]|0;
  $$01$i3 = $18;$21 = $$pre$i1;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $24 = 0;
   } else {
    $22 = HEAP32[$$01$i3>>2]|0;
    HEAP32[$21>>2] = $22;
    $$pre2$i4 = HEAP32[$12>>2]|0;
    $24 = $$pre2$i4;
   }
   $23 = (($24) + 4|0);
   HEAP32[$12>>2] = $23;
   $25 = (($$01$i3) + 4|0);
   $26 = ($25|0)==($__last|0);
   if ($26) {
    break;
   } else {
    $$01$i3 = $25;$21 = $23;
   }
  }
  STACKTOP = sp;return;
 }
 $36 = ($6|0)==(0|0);
 if ($36) {
  $45 = $5;
 } else {
  $37 = (($this) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==($6|0);
  if (!($39)) {
   $scevgep$i$i$i$i = (($38) + -4|0);
   $40 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($40)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $41 = $uglygep3$i$i$i$i >>> 2;
   $42 = $41 ^ -1;
   $scevgep4$i$i$i$i = (($38) + ($42<<2)|0);
   HEAP32[$37>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$37>>2] = 0;
  HEAP32[$this>>2] = 0;
  $45 = 0;
 }
 $43 = ($3>>>0)>(1073741823);
 if ($43) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $44 = $45;
 $46 = $44 >> 2;
 $47 = ($46>>>0)<(536870911);
 if ($47) {
  $48 = $44 >> 1;
  $49 = ($48>>>0)<($3>>>0);
  $50 = $49 ? $3 : $48;
  $51 = ($50>>>0)>(1073741823);
  if ($51) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $50;
  }
 } else {
  $$0$i7 = 1073741823;
 }
 $52 = $$0$i7 << 2;
 $53 = (__Znwj($52)|0);
 $54 = (($this) + 4|0);
 HEAP32[$54>>2] = $53;
 HEAP32[$this>>2] = $53;
 $55 = (($53) + ($$0$i7<<2)|0);
 HEAP32[$4>>2] = $55;
 $56 = ($__first|0)==($__last|0);
 if ($56) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$58 = $53;
 }
 while(1) {
  $57 = ($58|0)==(0|0);
  if ($57) {
   $61 = 0;
  } else {
   $59 = HEAP32[$$01$i>>2]|0;
   HEAP32[$58>>2] = $59;
   $$pre2$i = HEAP32[$54>>2]|0;
   $61 = $$pre2$i;
  }
  $60 = (($61) + 4|0);
  HEAP32[$54>>2] = $60;
  $62 = (($$01$i) + 4|0);
  $63 = ($62|0)==($__last|0);
  if ($63) {
   break;
  } else {
   $$01$i = $62;$58 = $60;
  }
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE14__count_uniqueIS7_EEjRKT_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__rt$0$in = 0, $__rt$0$in$in$be = 0, $__rt$0$in6 = 0, $__rt$0$in7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $__rt$0$in6 = HEAP32[$0>>2]|0;
 $1 = ($__rt$0$in6|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP8[$__k>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 $5 = $2&255;
 $6 = $5 >>> 1;
 $7 = (($__k) + 1|0);
 $8 = (($__k) + 8|0);
 $9 = (($__k) + 4|0);
 $__rt$0$in7 = $__rt$0$in6;
 while(1) {
  $10 = (($__rt$0$in7) + 16|0);
  if ($4) {
   $25 = $6;
  } else {
   $11 = HEAP32[$9>>2]|0;
   $25 = $11;
  }
  $12 = HEAP8[$10>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $17 = $12&255;
   $18 = $17 >>> 1;
   $24 = $18;
  } else {
   $15 = (($__rt$0$in7) + 20|0);
   $16 = HEAP32[$15>>2]|0;
   $24 = $16;
  }
  if ($4) {
   $27 = $7;
  } else {
   $19 = HEAP32[$8>>2]|0;
   $27 = $19;
  }
  if ($14) {
   $22 = (($10) + 1|0);
   $28 = $22;
  } else {
   $20 = (($__rt$0$in7) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $28 = $21;
  }
  $23 = ($24>>>0)<($25>>>0);
  $26 = $23 ? $24 : $25;
  $29 = (_memcmp($27,$28,$26)|0);
  $30 = ($29|0)==(0);
  if ($30) {
   $31 = ($25>>>0)<($24>>>0);
   $$$i$i$i$i4 = $23&1;
   $$$$i$i$i$i5 = $31 ? -1 : $$$i$i$i$i4;
   $33 = $$$$i$i$i$i5;
  } else {
   $33 = $29;
  }
  $32 = ($33|0)<(0);
  if ($32) {
   $__rt$0$in$in$be = $__rt$0$in7;
  } else {
   if ($14) {
    $36 = $12&255;
    $37 = $36 >>> 1;
    $45 = $37;
   } else {
    $34 = (($__rt$0$in7) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $45 = $35;
   }
   if ($4) {
    $44 = $6;
   } else {
    $38 = HEAP32[$9>>2]|0;
    $44 = $38;
   }
   if ($14) {
    $41 = (($10) + 1|0);
    $47 = $41;
   } else {
    $39 = (($__rt$0$in7) + 24|0);
    $40 = HEAP32[$39>>2]|0;
    $47 = $40;
   }
   if ($4) {
    $48 = $7;
   } else {
    $42 = HEAP32[$8>>2]|0;
    $48 = $42;
   }
   $43 = ($44>>>0)<($45>>>0);
   $46 = $43 ? $44 : $45;
   $49 = (_memcmp($47,$48,$46)|0);
   $50 = ($49|0)==(0);
   if ($50) {
    $51 = ($45>>>0)<($44>>>0);
    $$$i$i$i$i = $43&1;
    $$$$i$i$i$i = $51 ? -1 : $$$i$i$i$i;
    $53 = $$$$i$i$i$i;
   } else {
    $53 = $49;
   }
   $52 = ($53|0)<(0);
   if (!($52)) {
    $$0 = 1;
    label = 32;
    break;
   }
   $54 = (($__rt$0$in7) + 4|0);
   $__rt$0$in$in$be = $54;
  }
  $__rt$0$in = HEAP32[$__rt$0$in$in$be>>2]|0;
  $55 = ($__rt$0$in|0)==(0|0);
  if ($55) {
   $$0 = 0;
   label = 32;
   break;
  } else {
   $__rt$0$in7 = $__rt$0$in;
  }
 }
 if ((label|0) == 32) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiNS_4lessIS6_EENS4_INS_4pairIKS6_iEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERSA_($this,$__parent,$__k) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__k = $__k|0;
 var $$$$i$i$i = 0, $$$$i$i$i$us = 0, $$$$i$i$i5 = 0, $$$$i$i$i5$us = 0, $$$i$i$i = 0, $$$i$i$i$us = 0, $$$i$i$i4 = 0, $$$i$i$i4$us = 0, $$0 = 0, $$lcssa = 0, $$lcssa9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__nd$0$in = 0, $__nd$0$in$lcssa = 0, $__nd$0$in$lcssa7 = 0, $__nd$0$in$lcssa8 = 0, $__nd$0$in$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $97 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $97;
  $$0 = $97;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__k>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__k) + 1|0);
 $9 = (($__k) + 8|0);
 $10 = (($__k) + 4|0);
 L5: do {
  if ($5) {
   $__nd$0$in$us = $1;
   while(1) {
    $11 = (($__nd$0$in$us) + 16|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = $12 & 1;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     $19 = $12&255;
     $20 = $19 >>> 1;
     $21 = (($11) + 1|0);
     $23 = $20;$25 = $21;
    } else {
     $15 = (($__nd$0$in$us) + 20|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($__nd$0$in$us) + 24|0);
     $18 = HEAP32[$17>>2]|0;
     $23 = $16;$25 = $18;
    }
    $22 = ($23>>>0)<($7>>>0);
    $24 = $22 ? $23 : $7;
    $26 = (_memcmp($8,$25,$24)|0);
    $27 = ($26|0)==(0);
    if ($27) {
     $28 = ($7>>>0)<($23>>>0);
     $$$i$i$i4$us = $22&1;
     $$$$i$i$i5$us = $28 ? -1 : $$$i$i$i4$us;
     $30 = $$$$i$i$i5$us;
    } else {
     $30 = $26;
    }
    $29 = ($30|0)<(0);
    if ($29) {
     $50 = HEAP32[$__nd$0$in$us>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      $$lcssa9 = $__nd$0$in$us;$__nd$0$in$lcssa8 = $__nd$0$in$us;
      label = 24;
      break;
     } else {
      $__nd$0$in$us = $50;
      continue;
     }
    }
    if ($14) {
     $35 = $12&255;
     $36 = $35 >>> 1;
     $37 = (($11) + 1|0);
     $39 = $36;$41 = $37;
    } else {
     $31 = (($__nd$0$in$us) + 20|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($__nd$0$in$us) + 24|0);
     $34 = HEAP32[$33>>2]|0;
     $39 = $32;$41 = $34;
    }
    $38 = ($7>>>0)<($39>>>0);
    $40 = $38 ? $7 : $39;
    $42 = (_memcmp($41,$8,$40)|0);
    $43 = ($42|0)==(0);
    if ($43) {
     $44 = ($39>>>0)<($7>>>0);
     $$$i$i$i$us = $38&1;
     $$$$i$i$i$us = $44 ? -1 : $$$i$i$i$us;
     $46 = $$$$i$i$i$us;
    } else {
     $46 = $42;
    }
    $45 = ($46|0)<(0);
    if (!($45)) {
     $__nd$0$in$lcssa = $__nd$0$in$us;
     label = 33;
     break L5;
    }
    $47 = (($__nd$0$in$us) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     $$lcssa = $47;$__nd$0$in$lcssa7 = $__nd$0$in$us;
     label = 32;
     break;
    } else {
     $__nd$0$in$us = $48;
    }
   }
  } else {
   $__nd$0$in = $1;
   while(1) {
    $52 = (($__nd$0$in) + 16|0);
    $53 = HEAP32[$10>>2]|0;
    $54 = HEAP8[$52>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if ($56) {
     $61 = $54&255;
     $62 = $61 >>> 1;
     $63 = (($52) + 1|0);
     $66 = $62;$68 = $63;
    } else {
     $57 = (($__nd$0$in) + 20|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($__nd$0$in) + 24|0);
     $60 = HEAP32[$59>>2]|0;
     $66 = $58;$68 = $60;
    }
    $64 = HEAP32[$9>>2]|0;
    $65 = ($66>>>0)<($53>>>0);
    $67 = $65 ? $66 : $53;
    $69 = (_memcmp($64,$68,$67)|0);
    $70 = ($69|0)==(0);
    if ($70) {
     $71 = ($53>>>0)<($66>>>0);
     $$$i$i$i4 = $65&1;
     $$$$i$i$i5 = $71 ? -1 : $$$i$i$i4;
     $73 = $$$$i$i$i5;
    } else {
     $73 = $69;
    }
    $72 = ($73|0)<(0);
    if ($72) {
     $74 = HEAP32[$__nd$0$in>>2]|0;
     $75 = ($74|0)==(0|0);
     if ($75) {
      $$lcssa9 = $__nd$0$in;$__nd$0$in$lcssa8 = $__nd$0$in;
      label = 24;
      break;
     } else {
      $__nd$0$in = $74;
      continue;
     }
    }
    if ($56) {
     $80 = $54&255;
     $81 = $80 >>> 1;
     $82 = (($52) + 1|0);
     $86 = $81;$88 = $82;
    } else {
     $76 = (($__nd$0$in) + 20|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($__nd$0$in) + 24|0);
     $79 = HEAP32[$78>>2]|0;
     $86 = $77;$88 = $79;
    }
    $83 = HEAP32[$10>>2]|0;
    $84 = HEAP32[$9>>2]|0;
    $85 = ($83>>>0)<($86>>>0);
    $87 = $85 ? $83 : $86;
    $89 = (_memcmp($88,$84,$87)|0);
    $90 = ($89|0)==(0);
    if ($90) {
     $91 = ($86>>>0)<($83>>>0);
     $$$i$i$i = $85&1;
     $$$$i$i$i = $91 ? -1 : $$$i$i$i;
     $93 = $$$$i$i$i;
    } else {
     $93 = $89;
    }
    $92 = ($93|0)<(0);
    if (!($92)) {
     $__nd$0$in$lcssa = $__nd$0$in;
     label = 33;
     break L5;
    }
    $94 = (($__nd$0$in) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0|0);
    if ($96) {
     $$lcssa = $94;$__nd$0$in$lcssa7 = $__nd$0$in;
     label = 32;
     break;
    } else {
     $__nd$0$in = $95;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa8;
  $$0 = $$lcssa9;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa7;
  $$0 = $$lcssa;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16vectorI17MessageIdentifierNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 20)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $15 = 0;
   } else {
    $11 = (($10) + 8|0);
    HEAP32[$11>>2] = -1;
    $12 = (($10) + 4|0);
    HEAP32[$12>>2] = 0;
    HEAP32[$10>>2] = 0;
    $13 = (($10) + 16|0);
    HEAP32[$13>>2] = 1;
    $$pre1$i = HEAP32[$2>>2]|0;
    $15 = $$pre1$i;
   }
   $14 = (($15) + 20|0);
   HEAP32[$2>>2] = $14;
   $16 = (($$0$i) + -1)|0;
   $17 = ($16|0)==(0);
   if ($17) {
    break;
   } else {
    $$0$i = $16;$10 = $14;
   }
  }
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = $18;
 $20 = (($5) - ($19))|0;
 $21 = (($20|0) / 20)&-1;
 $22 = (($21) + ($__n))|0;
 $23 = ($22>>>0)>(214748364);
 if ($23) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $24 = (($4) - ($19))|0;
 $25 = (($24|0) / 20)&-1;
 $26 = ($25>>>0)<(107374182);
 if ($26) {
  $27 = $25 << 1;
  $28 = ($27>>>0)<($22>>>0);
  $29 = $28 ? $22 : $27;
  $30 = ($29|0)==(0);
  if ($30) {
   $$0$i57 = 0;$34 = 0;
  } else {
   $$0$i56 = $29;
   label = 9;
  }
 } else {
  $$0$i56 = 214748364;
  label = 9;
 }
 if ((label|0) == 9) {
  $31 = ($$0$i56*20)|0;
  $32 = (__Znwj($31)|0);
  $$0$i57 = $$0$i56;$34 = $32;
 }
 $33 = (($34) + (($21*20)|0)|0);
 $$0$i2 = $__n;$36 = $33;
 while(1) {
  $35 = ($36|0)==(0|0);
  if ($35) {
   $41 = 0;
  } else {
   $37 = (($36) + 8|0);
   HEAP32[$37>>2] = -1;
   $38 = (($36) + 4|0);
   HEAP32[$38>>2] = 0;
   HEAP32[$36>>2] = 0;
   $39 = (($36) + 16|0);
   HEAP32[$39>>2] = 1;
   $41 = $36;
  }
  $40 = (($41) + 20|0);
  $42 = (($$0$i2) + -1)|0;
  $43 = ($42|0)==(0);
  if ($43) {
   break;
  } else {
   $$0$i2 = $42;$36 = $40;
  }
 }
 $44 = (($34) + (($$0$i57*20)|0)|0);
 $45 = HEAP32[$this>>2]|0;
 $46 = HEAP32[$2>>2]|0;
 $47 = $46;
 $48 = $45;
 $49 = (($47) - ($48))|0;
 $50 = (($49|0) / -20)&-1;
 $$sum = (($50) + ($21))|0;
 $51 = (($34) + (($$sum*20)|0)|0);
 _memcpy(($51|0),($45|0),($49|0))|0;
 HEAP32[$this>>2] = $51;
 HEAP32[$2>>2] = $40;
 HEAP32[$0>>2] = $44;
 $52 = ($45|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 __ZdlPv($45);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIiNS_9allocatorIiEEE8__appendEjRKi($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    $11 = HEAP32[$__x>>2]|0;
    HEAP32[$10>>2] = $11;
   }
   $12 = (($10) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  $29 = (__Znwj($28)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   $34 = HEAP32[$__x>>2]|0;
   HEAP32[$33>>2] = $34;
  }
  $35 = (($33) + 4|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $35;
  }
 }
 $38 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 _memcpy(($31|0),($15|0),($17|0))|0;
 HEAP32[$this>>2] = $31;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $38;
 $39 = ($15|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIPFvPviR11MessageDataENS_9allocatorIS5_EEE8__appendEjRKS5_($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $13 = 0;
   } else {
    $11 = HEAP32[$__x>>2]|0;
    HEAP32[$10>>2] = $11;
    $$pre1$i = HEAP32[$2>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 4|0);
   HEAP32[$2>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$10 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($5) - ($17))|0;
 $19 = $18 >> 2;
 $20 = (($19) + ($__n))|0;
 $21 = ($20>>>0)>(1073741823);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($4) - ($17))|0;
 $23 = $22 >> 2;
 $24 = ($23>>>0)<(536870911);
 if ($24) {
  $25 = $22 >> 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 1073741823;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = $$0$i56 << 2;
  $30 = (__Znwj($29)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + ($19<<2)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $37 = 0;
  } else {
   $35 = HEAP32[$__x>>2]|0;
   HEAP32[$34>>2] = $35;
   $37 = $34;
  }
  $36 = (($37) + 4|0);
  $38 = (($$0$i2) + -1)|0;
  $39 = ($38|0)==(0);
  if ($39) {
   break;
  } else {
   $$0$i2 = $38;$34 = $36;
  }
 }
 $40 = (($32) + ($$0$i57<<2)|0);
 $41 = HEAP32[$this>>2]|0;
 $42 = HEAP32[$2>>2]|0;
 $43 = $42;
 $44 = $41;
 $45 = (($43) - ($44))|0;
 $46 = $45 >> 2;
 $$sum = (($19) - ($46))|0;
 $47 = (($32) + ($$sum<<2)|0);
 _memcpy(($47|0),($41|0),($45|0))|0;
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $36;
 HEAP32[$0>>2] = $40;
 $48 = ($41|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($41);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($__nd) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZN17MessageIdentifier21GetRegisteredMessagesEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[563328>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN17MessageIdentifier17GetSortedMessagesEb($agg$result,$notificationMessages) {
 $agg$result = $agg$result|0;
 $notificationMessages = $notificationMessages|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$96 = 0, $$97 = 0, $$pre = 0, $$pre92 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i13 = 0, $__p$0$i$i$i7 = 0;
 var $eh$lpad$body$index19Z2D = 0, $eh$lpad$body$indexZ2D = 0, $error = 0, $error1 = 0, $error2 = 0, $found = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi64$index = 0, $lpad$phi64$index7 = 0, $lpad$phi69$index = 0, $lpad$phi69$index12 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $0 = sp + 184|0;
 $1 = sp + 152|0;
 $2 = sp;
 $found = sp + 144|0;
 $3 = sp + 132|0;
 $4 = sp + 56|0;
 $5 = sp + 88|0;
 $6 = sp + 44|0;
 $error = sp + 32|0;
 $error1 = sp + 20|0;
 $error2 = sp + 120|0;
 $7 = (($agg$result) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($agg$result) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($agg$result) + 4|0);
 HEAP32[$agg$result>>2] = $9;
 $10 = HEAP32[563328>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($10|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($3) + 1|0);
 $15 = (($6) + 1|0);
 $16 = (($5) + 12|0);
 $17 = (($4) + 12|0);
 $18 = (($1) + 12|0);
 $19 = (($6) + 8|0);
 $20 = (($5) + 8|0);
 $21 = (($4) + 8|0);
 $22 = (($1) + 8|0);
 $23 = (($4) + 4|0);
 $24 = (($1) + 1|0);
 $25 = (($1) + 4|0);
 $26 = (($5) + 4|0);
 $27 = (($4) + 1|0);
 $28 = (($6) + 4|0);
 $29 = (($5) + 1|0);
 $30 = (($error2) + 8|0);
 $31 = (($error2) + 4|0);
 $32 = (($error2) + 1|0);
 $33 = (($error1) + 8|0);
 $34 = (($error1) + 4|0);
 $35 = (($error1) + 1|0);
 $36 = (($error) + 8|0);
 $37 = (($error) + 4|0);
 $38 = (($error) + 1|0);
 $39 = (($3) + 8|0);
 $40 = (($3) + 4|0);
 $42 = $12;
 L4: while(1) {
  $41 = (($42) + 8|0);
  $43 = HEAP32[$41>>2]|0;
  $44 = (($43) + 16|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $45 & 2;
  $47 = ($46|0)!=(0);
  $48 = $47 ^ $notificationMessages;
  do {
   if (!($48)) {
    $53 = HEAP32[$43>>2]|0;
    $54 = (_strlen(($53|0))|0);
    $55 = ($54>>>0)>(4294967279);
    if ($55) {
     label = 8;
     break L4;
    }
    $58 = ($54>>>0)<(11);
    if ($58) {
     $59 = $54 << 1;
     $60 = $59&255;
     HEAP8[$3>>0] = $60;
     $__p$0$i$i$i7 = $14;
    } else {
     $61 = (($54) + 16)|0;
     $62 = $61 & -16;
     __THREW__ = 0;
     $63 = (invoke_ii(2988,($62|0))|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      label = 4;
      break L4;
     }
     HEAP32[$39>>2] = $63;
     $66 = $62 | 1;
     HEAP32[$3>>2] = $66;
     HEAP32[$40>>2] = $54;
     $__p$0$i$i$i7 = $63;
    }
    _memcpy(($__p$0$i$i$i7|0),($53|0),($54|0))|0;
    $67 = (($__p$0$i$i$i7) + ($54)|0);
    HEAP8[$67>>0] = 0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE4findIS7_EENS_15__tree_iteratorIS9_PNS_11__tree_nodeIS9_PvEEiEERKT_($found,$agg$result,$3);
    $68 = HEAP8[$3>>0]|0;
    $69 = $68 & 1;
    $70 = ($69<<24>>24)==(0);
    if (!($70)) {
     $71 = HEAP32[$39>>2]|0;
     __ZdlPv($71);
    }
    $72 = HEAP32[$found>>2]|0;
    $73 = ($72|0)==($9|0);
    if (!($73)) {
     $188 = (($43) + 12|0);
     $189 = HEAP32[$188>>2]|0;
     $190 = (($72) + 40|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = ($189|0)==($191|0);
     if (!($192)) {
      __THREW__ = 0;
      $193 = (invoke_ii(2988,64)|0);
      $194 = __THREW__; __THREW__ = 0;
      $195 = $194&1;
      if ($195) {
       label = 4;
       break L4;
      }
      HEAP32[$36>>2] = $193;
      HEAP32[$error>>2] = 65;
      HEAP32[$37>>2] = 50;
      dest=$193+0|0; src=563336+0|0; stop=dest+50|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $196 = (($193) + 50|0);
      HEAP8[$196>>0] = 0;
      $197 = HEAP32[$43>>2]|0;
      $198 = (_strlen(($197|0))|0);
      __THREW__ = 0;
      (invoke_iiii(1480,($error|0),($197|0),($198|0))|0);
      $199 = __THREW__; __THREW__ = 0;
      $200 = $199&1;
      if ($200) {
       label = 86;
       break L4;
      }
      __THREW__ = 0;
      (invoke_iiii(1480,($error|0),(563392|0),89)|0);
      $201 = __THREW__; __THREW__ = 0;
      $202 = $201&1;
      if ($202) {
       label = 86;
       break L4;
      }
      $203 = HEAP8[$error>>0]|0;
      $204 = $203 & 1;
      $205 = ($204<<24>>24)==(0);
      $206 = HEAP32[$36>>2]|0;
      $$ = $205 ? $38 : $206;
      __THREW__ = 0;
      invoke_viiiiiiii(21,($$|0),0,(563488|0),56,1,0,0,(0|0));
      $207 = __THREW__; __THREW__ = 0;
      $208 = $207&1;
      if ($208) {
       label = 86;
       break L4;
      }
      $209 = HEAP8[$error>>0]|0;
      $210 = $209 & 1;
      $211 = ($210<<24>>24)==(0);
      if (!($211)) {
       $212 = HEAP32[$36>>2]|0;
       __ZdlPv($212);
      }
     }
     $219 = (($43) + 4|0);
     $220 = HEAP32[$219>>2]|0;
     $221 = (($72) + 32|0);
     $222 = HEAP32[$221>>2]|0;
     $223 = ($220|0)==($222|0);
     if (!($223)) {
      __THREW__ = 0;
      $224 = (invoke_ii(2988,64)|0);
      $225 = __THREW__; __THREW__ = 0;
      $226 = $225&1;
      if ($226) {
       label = 4;
       break L4;
      }
      HEAP32[$33>>2] = $224;
      HEAP32[$error1>>2] = 65;
      HEAP32[$34>>2] = 50;
      dest=$224+0|0; src=563336+0|0; stop=dest+50|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $227 = (($224) + 50|0);
      HEAP8[$227>>0] = 0;
      $228 = HEAP32[$43>>2]|0;
      $229 = (_strlen(($228|0))|0);
      __THREW__ = 0;
      (invoke_iiii(1480,($error1|0),($228|0),($229|0))|0);
      $230 = __THREW__; __THREW__ = 0;
      $231 = $230&1;
      if ($231) {
       label = 95;
       break L4;
      }
      __THREW__ = 0;
      (invoke_iiii(1480,($error1|0),(563392|0),89)|0);
      $232 = __THREW__; __THREW__ = 0;
      $233 = $232&1;
      if ($233) {
       label = 95;
       break L4;
      }
      $234 = HEAP8[$error1>>0]|0;
      $235 = $234 & 1;
      $236 = ($235<<24>>24)==(0);
      $237 = HEAP32[$33>>2]|0;
      $$96 = $236 ? $35 : $237;
      __THREW__ = 0;
      invoke_viiiiiiii(21,($$96|0),0,(563488|0),64,1,0,0,(0|0));
      $238 = __THREW__; __THREW__ = 0;
      $239 = $238&1;
      if ($239) {
       label = 95;
       break L4;
      }
      $240 = HEAP8[$error1>>0]|0;
      $241 = $240 & 1;
      $242 = ($241<<24>>24)==(0);
      if (!($242)) {
       $243 = HEAP32[$33>>2]|0;
       __ZdlPv($243);
      }
     }
     $250 = HEAP32[$44>>2]|0;
     $251 = (($72) + 44|0);
     $252 = HEAP32[$251>>2]|0;
     $253 = ($250|0)==($252|0);
     if ($253) {
      break;
     }
     __THREW__ = 0;
     $254 = (invoke_ii(2988,48)|0);
     $255 = __THREW__; __THREW__ = 0;
     $256 = $255&1;
     if ($256) {
      label = 4;
      break L4;
     }
     HEAP32[$30>>2] = $254;
     HEAP32[$error2>>2] = 49;
     HEAP32[$31>>2] = 46;
     dest=$254+0|0; src=563496+0|0; stop=dest+46|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $257 = (($254) + 46|0);
     HEAP8[$257>>0] = 0;
     $258 = HEAP32[$43>>2]|0;
     $259 = (_strlen(($258|0))|0);
     __THREW__ = 0;
     (invoke_iiii(1480,($error2|0),($258|0),($259|0))|0);
     $260 = __THREW__; __THREW__ = 0;
     $261 = $260&1;
     if ($261) {
      label = 103;
      break L4;
     }
     $262 = HEAP8[$error2>>0]|0;
     $263 = $262 & 1;
     $264 = ($263<<24>>24)==(0);
     $265 = HEAP32[$30>>2]|0;
     $$97 = $264 ? $32 : $265;
     __THREW__ = 0;
     invoke_viiiiiiii(21,($$97|0),0,(563488|0),71,1,0,0,(0|0));
     $266 = __THREW__; __THREW__ = 0;
     $267 = $266&1;
     if ($267) {
      label = 103;
      break L4;
     }
     $268 = HEAP8[$error2>>0]|0;
     $269 = $268 & 1;
     $270 = ($269<<24>>24)==(0);
     if ($270) {
      break;
     }
     $271 = HEAP32[$30>>2]|0;
     __ZdlPv($271);
     break;
    }
    $74 = HEAP32[$43>>2]|0;
    $75 = (_strlen(($74|0))|0);
    $76 = ($75>>>0)>(4294967279);
    if ($76) {
     label = 18;
     break L4;
    }
    $79 = ($75>>>0)<(11);
    if ($79) {
     $80 = $75 << 1;
     $81 = $80&255;
     HEAP8[$6>>0] = $81;
     $91 = $81;$__p$0$i$i$i13 = $15;
    } else {
     $82 = (($75) + 16)|0;
     $83 = $82 & -16;
     __THREW__ = 0;
     $84 = (invoke_ii(2988,($83|0))|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      label = 4;
      break L4;
     }
     HEAP32[$19>>2] = $84;
     $87 = $83 | 1;
     HEAP32[$6>>2] = $87;
     HEAP32[$28>>2] = $75;
     $88 = $87&255;
     $91 = $88;$__p$0$i$i$i13 = $84;
    }
    _memcpy(($__p$0$i$i$i13|0),($74|0),($75|0))|0;
    $89 = (($__p$0$i$i$i13) + ($75)|0);
    HEAP8[$89>>0] = 0;
    ;HEAP32[$2+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$43+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$43+16>>2]|0;
    $90 = $91 & 1;
    $92 = ($90<<24>>24)==(0);
    if ($92) {
     ;HEAP32[$5+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;
     $$pre = HEAP8[$5>>0]|0;
     $110 = $$pre;
    } else {
     $93 = HEAP32[$19>>2]|0;
     $94 = HEAP32[$28>>2]|0;
     $95 = ($94>>>0)>(4294967279);
     if ($95) {
      label = 27;
      break L4;
     }
     $98 = ($94>>>0)<(11);
     if ($98) {
      $99 = $94 << 1;
      $100 = $99&255;
      HEAP8[$5>>0] = $100;
      $282 = $100;$__p$0$i$i$i$i$i$i = $29;
     } else {
      $101 = (($94) + 16)|0;
      $102 = $101 & -16;
      __THREW__ = 0;
      $103 = (invoke_ii(2988,($102|0))|0);
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       label = 65;
       break L4;
      }
      HEAP32[$20>>2] = $103;
      $106 = $102 | 1;
      HEAP32[$5>>2] = $106;
      HEAP32[$26>>2] = $94;
      $107 = $106&255;
      $282 = $107;$__p$0$i$i$i$i$i$i = $103;
     }
     _memcpy(($__p$0$i$i$i$i$i$i|0),($93|0),($94|0))|0;
     $108 = (($__p$0$i$i$i$i$i$i) + ($94)|0);
     HEAP8[$108>>0] = 0;
     $110 = $282;
    }
    ;HEAP32[$16+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$16+16>>2]=HEAP32[$2+16>>2]|0;
    $109 = $110 & 1;
    $111 = ($109<<24>>24)==(0);
    if ($111) {
     ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;
     $$pre92 = HEAP8[$4>>0]|0;
     $129 = $$pre92;
    } else {
     $112 = HEAP32[$20>>2]|0;
     $113 = HEAP32[$26>>2]|0;
     $114 = ($113>>>0)>(4294967279);
     if ($114) {
      label = 37;
      break L4;
     }
     $117 = ($113>>>0)<(11);
     if ($117) {
      $118 = $113 << 1;
      $119 = $118&255;
      HEAP8[$4>>0] = $119;
      $283 = $119;$__p$0$i$i$i$i$i = $27;
     } else {
      $120 = (($113) + 16)|0;
      $121 = $120 & -16;
      __THREW__ = 0;
      $122 = (invoke_ii(2988,($121|0))|0);
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       label = 68;
       break L4;
      }
      HEAP32[$21>>2] = $122;
      $125 = $121 | 1;
      HEAP32[$4>>2] = $125;
      HEAP32[$23>>2] = $113;
      $126 = $125&255;
      $283 = $126;$__p$0$i$i$i$i$i = $122;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($112|0),($113|0))|0;
     $127 = (($__p$0$i$i$i$i$i) + ($113)|0);
     HEAP8[$127>>0] = 0;
     $129 = $283;
    }
    ;HEAP32[$17+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$16+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$16+16>>2]|0;
    $128 = $129 & 1;
    $130 = ($128<<24>>24)==(0);
    if ($130) {
     ;HEAP32[$1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$4+8>>2]|0;
    } else {
     $131 = HEAP32[$21>>2]|0;
     $132 = HEAP32[$23>>2]|0;
     $133 = ($132>>>0)>(4294967279);
     if ($133) {
      label = 47;
      break L4;
     }
     $136 = ($132>>>0)<(11);
     if ($136) {
      $137 = $132 << 1;
      $138 = $137&255;
      HEAP8[$1>>0] = $138;
      $__p$0$i$i$i$i$i$i$i$i = $24;
     } else {
      $139 = (($132) + 16)|0;
      $140 = $139 & -16;
      __THREW__ = 0;
      $141 = (invoke_ii(2988,($140|0))|0);
      $142 = __THREW__; __THREW__ = 0;
      $143 = $142&1;
      if ($143) {
       label = 71;
       break L4;
      }
      HEAP32[$22>>2] = $141;
      $144 = $140 | 1;
      HEAP32[$1>>2] = $144;
      HEAP32[$25>>2] = $132;
      $__p$0$i$i$i$i$i$i$i$i = $141;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($131|0),($132|0))|0;
     $145 = (($__p$0$i$i$i$i$i$i$i$i) + ($132)|0);
     HEAP8[$145>>0] = 0;
    }
    ;HEAP32[$18+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$17+12>>2]|0;HEAP32[$18+16>>2]=HEAP32[$17+16>>2]|0;
    __THREW__ = 0;
    invoke_viii(1633,($0|0),($agg$result|0),($1|0));
    $146 = __THREW__; __THREW__ = 0;
    $147 = $146&1;
    if ($147) {
     label = 57;
     break L4;
    }
    $148 = HEAP8[$1>>0]|0;
    $149 = $148 & 1;
    $150 = ($149<<24>>24)==(0);
    if (!($150)) {
     $151 = HEAP32[$22>>2]|0;
     __ZdlPv($151);
    }
    $158 = $129 & 1;
    $159 = ($158<<24>>24)==(0);
    if (!($159)) {
     $160 = HEAP32[$21>>2]|0;
     __ZdlPv($160);
    }
    $161 = $110 & 1;
    $162 = ($161<<24>>24)==(0);
    if (!($162)) {
     $163 = HEAP32[$20>>2]|0;
     __ZdlPv($163);
    }
    $164 = $91 & 1;
    $165 = ($164<<24>>24)==(0);
    if (!($165)) {
     $166 = HEAP32[$19>>2]|0;
     __ZdlPv($166);
    }
   }
  } while(0);
  $278 = (($42) + 4|0);
  $279 = HEAP32[$278>>2]|0;
  $280 = ($279|0)==($10|0);
  if ($280) {
   label = 106;
   break;
  } else {
   $42 = $279;
  }
 }
 switch (label|0) {
  case 4: {
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $lpad$phi$index = $49;$lpad$phi$index2 = $50;
   label = 6;
   break;
  }
  case 8: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    label = 5;
   } else {
    // unreachable;
   }
   break;
  }
  case 18: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    label = 5;
   } else {
    // unreachable;
   }
   break;
  }
  case 27: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $169 = ___cxa_find_matching_catch()|0;
    $170 = tempRet0;
    $lpad$phi64$index = $169;$lpad$phi64$index7 = $170;
    label = 67;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 37: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $115 = __THREW__; __THREW__ = 0;
   $116 = $115&1;
   if ($116) {
    $173 = ___cxa_find_matching_catch()|0;
    $174 = tempRet0;
    $lpad$phi69$index = $173;$lpad$phi69$index12 = $174;
    label = 70;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 47: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $134 = __THREW__; __THREW__ = 0;
   $135 = $134&1;
   if ($135) {
    $177 = ___cxa_find_matching_catch()|0;
    $178 = tempRet0;
    $eh$lpad$body$index19Z2D = $178;$eh$lpad$body$indexZ2D = $177;
    label = 73;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 57: {
   $152 = ___cxa_find_matching_catch()|0;
   $153 = tempRet0;
   $154 = HEAP8[$1>>0]|0;
   $155 = $154 & 1;
   $156 = ($155<<24>>24)==(0);
   if ($156) {
    $eh$lpad$body$index19Z2D = $153;$eh$lpad$body$indexZ2D = $152;
    label = 73;
   } else {
    $157 = HEAP32[$22>>2]|0;
    __ZdlPv($157);
    $eh$lpad$body$index19Z2D = $153;$eh$lpad$body$indexZ2D = $152;
    label = 73;
   }
   break;
  }
  case 65: {
   $167 = ___cxa_find_matching_catch()|0;
   $168 = tempRet0;
   $lpad$phi64$index = $167;$lpad$phi64$index7 = $168;
   label = 67;
   break;
  }
  case 68: {
   $171 = ___cxa_find_matching_catch()|0;
   $172 = tempRet0;
   $lpad$phi69$index = $171;$lpad$phi69$index12 = $172;
   label = 70;
   break;
  }
  case 71: {
   $175 = ___cxa_find_matching_catch()|0;
   $176 = tempRet0;
   $eh$lpad$body$index19Z2D = $176;$eh$lpad$body$indexZ2D = $175;
   label = 73;
   break;
  }
  case 86: {
   $213 = ___cxa_find_matching_catch()|0;
   $214 = tempRet0;
   $215 = HEAP8[$error>>0]|0;
   $216 = $215 & 1;
   $217 = ($216<<24>>24)==(0);
   if ($217) {
    $$2 = $213;$$23 = $214;
   } else {
    $218 = HEAP32[$36>>2]|0;
    __ZdlPv($218);
    $$2 = $213;$$23 = $214;
   }
   break;
  }
  case 95: {
   $244 = ___cxa_find_matching_catch()|0;
   $245 = tempRet0;
   $246 = HEAP8[$error1>>0]|0;
   $247 = $246 & 1;
   $248 = ($247<<24>>24)==(0);
   if ($248) {
    $$2 = $244;$$23 = $245;
   } else {
    $249 = HEAP32[$33>>2]|0;
    __ZdlPv($249);
    $$2 = $244;$$23 = $245;
   }
   break;
  }
  case 103: {
   $272 = ___cxa_find_matching_catch()|0;
   $273 = tempRet0;
   $274 = HEAP8[$error2>>0]|0;
   $275 = $274 & 1;
   $276 = ($275<<24>>24)==(0);
   if ($276) {
    $$2 = $272;$$23 = $273;
   } else {
    $277 = HEAP32[$30>>2]|0;
    __ZdlPv($277);
    $$2 = $272;$$23 = $273;
   }
   break;
  }
  case 106: {
   STACKTOP = sp;return;
   break;
  }
 }
 if ((label|0) == 5) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $lpad$phi$index = $51;$lpad$phi$index2 = $52;
  label = 6;
 }
 else if ((label|0) == 67) {
  $$1 = $lpad$phi64$index;$$12 = $lpad$phi64$index7;
  label = 77;
 }
 else if ((label|0) == 70) {
  $$0 = $lpad$phi69$index;$$01 = $lpad$phi69$index12;
  label = 75;
 }
 else if ((label|0) == 73) {
  $179 = $129 & 1;
  $180 = ($179<<24>>24)==(0);
  if ($180) {
   $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index19Z2D;
   label = 75;
  } else {
   $181 = HEAP32[$21>>2]|0;
   __ZdlPv($181);
   $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index19Z2D;
   label = 75;
  }
 }
 if ((label|0) == 6) {
  $$2 = $lpad$phi$index;$$23 = $lpad$phi$index2;
 }
 else if ((label|0) == 75) {
  $182 = $110 & 1;
  $183 = ($182<<24>>24)==(0);
  if ($183) {
   $$1 = $$0;$$12 = $$01;
   label = 77;
  } else {
   $184 = HEAP32[$20>>2]|0;
   __ZdlPv($184);
   $$1 = $$0;$$12 = $$01;
   label = 77;
  }
 }
 if ((label|0) == 77) {
  $185 = $91 & 1;
  $186 = ($185<<24>>24)==(0);
  if ($186) {
   $$2 = $$1;$$23 = $$12;
  } else {
   $187 = HEAP32[$19>>2]|0;
   __ZdlPv($187);
   $$2 = $$1;$$23 = $$12;
  }
 }
 $281 = HEAP32[$7>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($agg$result,$281);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE15__insert_uniqueERKS9_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE12__find_equalIS9_EERPNS_16__tree_node_baseIPvEESL_RKT_($this,$__parent,$__v)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $46 = 0;$__r$0 = $1;
  HEAP32[$agg$result>>2] = $__r$0;
  $45 = (($agg$result) + 4|0);
  HEAP8[$45>>0] = $46;
  STACKTOP = sp;return;
 }
 $3 = (__Znwj(48)|0);
 $4 = (($3) + 16|0);
 $5 = HEAP8[$__v>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 L4: do {
  if ($7) {
   ;HEAP32[$4+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__v+8>>2]|0;
  } else {
   $8 = (($__v) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($__v) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11>>>0)>(4294967279);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    } else {
     $15 = ($11>>>0)<(11);
     if ($15) {
      $16 = $11 << 1;
      $17 = $16&255;
      HEAP8[$4>>0] = $17;
      $18 = (($3) + 17|0);
      $__p$0$i$i$i$i$i$i$i$i$i = $18;
     } else {
      $19 = (($11) + 16)|0;
      $20 = $19 & -16;
      __THREW__ = 0;
      $21 = (invoke_ii(2988,($20|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      $24 = (($3) + 24|0);
      HEAP32[$24>>2] = $21;
      $25 = $20 | 1;
      HEAP32[$4>>2] = $25;
      $26 = (($3) + 20|0);
      HEAP32[$26>>2] = $11;
      $__p$0$i$i$i$i$i$i$i$i$i = $21;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($9|0),($11|0))|0;
     $27 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($11)|0);
     HEAP8[$27>>0] = 0;
     break L4;
    }
   } while(0);
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = ($3|0)==(0|0);
   if ($30) {
    ___resumeException($28|0);
    // unreachable;
   }
   __ZdlPv($3);
   ___resumeException($28|0);
   // unreachable;
  }
 } while(0);
 $31 = (($3) + 28|0);
 $32 = (($__v) + 12|0);
 ;HEAP32[$31+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$32+12>>2]|0;HEAP32[$31+16>>2]=HEAP32[$32+16>>2]|0;
 $33 = HEAP32[$__parent>>2]|0;
 HEAP32[$3>>2] = 0;
 $34 = (($3) + 4|0);
 HEAP32[$34>>2] = 0;
 $35 = (($3) + 8|0);
 HEAP32[$35>>2] = $33;
 HEAP32[$0>>2] = $3;
 $36 = HEAP32[$this>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  $41 = $3;
 } else {
  HEAP32[$this>>2] = $37;
  $$pre$i = HEAP32[$0>>2]|0;
  $41 = $$pre$i;
 }
 $39 = (($this) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($40,$41);
 $42 = (($this) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 1)|0;
 HEAP32[$42>>2] = $44;
 $46 = 1;$__r$0 = $3;
 HEAP32[$agg$result>>2] = $__r$0;
 $45 = (($agg$result) + 4|0);
 HEAP8[$45>>0] = $46;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE12__find_equalIS9_EERPNS_16__tree_node_baseIPvEESL_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $60 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $60;
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 $__nd$0$in = $1;
 while(1) {
  $11 = (($__nd$0$in) + 16|0);
  if ($5) {
   $26 = $7;
  } else {
   $12 = HEAP32[$10>>2]|0;
   $26 = $12;
  }
  $13 = HEAP8[$11>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $25 = $19;
  } else {
   $16 = (($__nd$0$in) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $25 = $17;
  }
  if ($5) {
   $28 = $8;
  } else {
   $20 = HEAP32[$9>>2]|0;
   $28 = $20;
  }
  if ($15) {
   $23 = (($11) + 1|0);
   $29 = $23;
  } else {
   $21 = (($__nd$0$in) + 24|0);
   $22 = HEAP32[$21>>2]|0;
   $29 = $22;
  }
  $24 = ($25>>>0)<($26>>>0);
  $27 = $24 ? $25 : $26;
  $30 = (_memcmp($28,$29,$27)|0);
  $31 = ($30|0)==(0);
  if ($31) {
   $32 = ($26>>>0)<($25>>>0);
   $$$i$i$i$i4 = $24&1;
   $$$$i$i$i$i5 = $32 ? -1 : $$$i$i$i$i4;
   $34 = $$$$i$i$i$i5;
  } else {
   $34 = $30;
  }
  $33 = ($34|0)<(0);
  if ($33) {
   $35 = HEAP32[$__nd$0$in>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 17;
    break;
   } else {
    $__nd$0$in = $35;
    continue;
   }
  }
  if ($15) {
   $39 = $13&255;
   $40 = $39 >>> 1;
   $48 = $40;
  } else {
   $37 = (($__nd$0$in) + 20|0);
   $38 = HEAP32[$37>>2]|0;
   $48 = $38;
  }
  if ($5) {
   $47 = $7;
  } else {
   $41 = HEAP32[$10>>2]|0;
   $47 = $41;
  }
  if ($15) {
   $44 = (($11) + 1|0);
   $50 = $44;
  } else {
   $42 = (($__nd$0$in) + 24|0);
   $43 = HEAP32[$42>>2]|0;
   $50 = $43;
  }
  if ($5) {
   $51 = $8;
  } else {
   $45 = HEAP32[$9>>2]|0;
   $51 = $45;
  }
  $46 = ($47>>>0)<($48>>>0);
  $49 = $46 ? $47 : $48;
  $52 = (_memcmp($50,$51,$49)|0);
  $53 = ($52|0)==(0);
  if ($53) {
   $54 = ($48>>>0)<($47>>>0);
   $$$i$i$i$i = $46&1;
   $$$$i$i$i$i = $54 ? -1 : $$$i$i$i$i;
   $56 = $$$$i$i$i$i;
  } else {
   $56 = $52;
  }
  $55 = ($56|0)<(0);
  if (!($55)) {
   label = 33;
   break;
  }
  $57 = (($__nd$0$in) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   label = 32;
   break;
  } else {
   $__nd$0$in = $58;
  }
 }
 if ((label|0) == 17) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $57;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE4findIS7_EENS_15__tree_iteratorIS9_PNS_11__tree_nodeIS9_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE13__lower_boundIS7_EENS_15__tree_iteratorIS9_PNS_11__tree_nodeIS9_PvEEiEERKT_SL_SL_($__p,$this,$__v,$1,$2);
 $3 = HEAP32[$__p>>2]|0;
 $4 = ($3|0)==($2|0);
 if (!($4)) {
  $5 = (($3) + 16|0);
  $6 = HEAP8[$__v>>0]|0;
  $7 = $6 & 1;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $11 = $6&255;
   $12 = $11 >>> 1;
   $28 = $12;
  } else {
   $9 = (($__v) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $28 = $10;
  }
  $13 = HEAP8[$5>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $27 = $19;
  } else {
   $16 = (($3) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $27 = $17;
  }
  if ($8) {
   $22 = (($__v) + 1|0);
   $30 = $22;
  } else {
   $20 = (($__v) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $30 = $21;
  }
  if ($15) {
   $25 = (($5) + 1|0);
   $31 = $25;
  } else {
   $23 = (($3) + 24|0);
   $24 = HEAP32[$23>>2]|0;
   $31 = $24;
  }
  $26 = ($27>>>0)<($28>>>0);
  $29 = $26 ? $27 : $28;
  $32 = (_memcmp($30,$31,$29)|0);
  $33 = ($32|0)==(0);
  if ($33) {
   $34 = ($28>>>0)<($27>>>0);
   $$$i$i$i$i = $26&1;
   $$$$i$i$i$i = $34 ? -1 : $$$i$i$i$i;
   $36 = $$$$i$i$i$i;
  } else {
   $36 = $32;
  }
  $35 = ($36|0)<(0);
  if (!($35)) {
   HEAP32[$agg$result>>2] = $3;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE13__lower_boundIS7_EENS_15__tree_iteratorIS9_PNS_11__tree_nodeIS9_PvEEiEERKT_SL_SL_($agg$result,$this,$__v,$__root,$__result) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 $__root = $__root|0;
 $__result = $__result|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0$ph6 = 0, $$0$ph9 = 0, $$01$lcssa2 = 0, $$01$ph8 = 0, $$013 = 0, $$013$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__root|0)==(0|0);
 if ($0) {
  $$0$ph6 = $__result;
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
 $1 = HEAP8[$__v>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 $4 = $1&255;
 $5 = $4 >>> 1;
 $6 = (($__v) + 1|0);
 $7 = (($__v) + 8|0);
 $8 = (($__v) + 4|0);
 $$0$ph9 = $__result;$$01$ph8 = $__root;
 L4: while(1) {
  L6: do {
   if ($3) {
    $$013$us = $$01$ph8;
    while(1) {
     $9 = (($$013$us) + 16|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 & 1;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $17 = $10&255;
      $18 = $17 >>> 1;
      $19 = (($9) + 1|0);
      $21 = $18;$23 = $19;
     } else {
      $13 = (($$013$us) + 20|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($$013$us) + 24|0);
      $16 = HEAP32[$15>>2]|0;
      $21 = $14;$23 = $16;
     }
     $20 = ($5>>>0)<($21>>>0);
     $22 = $20 ? $5 : $21;
     $24 = (_memcmp($23,$6,$22)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = ($21>>>0)<($5>>>0);
      $$$i$i$i$i$us = $20&1;
      $$$$i$i$i$i$us = $26 ? -1 : $$$i$i$i$i$us;
      $28 = $$$$i$i$i$i$us;
     } else {
      $28 = $24;
     }
     $27 = ($28|0)<(0);
     if (!($27)) {
      $$01$lcssa2 = $$013$us;
      break L6;
     }
     $29 = (($$013$us) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013$us = $30;
     }
    }
   } else {
    $$013 = $$01$ph8;
    while(1) {
     $32 = (($$013) + 16|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if ($35) {
      $40 = $33&255;
      $41 = $40 >>> 1;
      $42 = (($32) + 1|0);
      $46 = $41;$48 = $42;
     } else {
      $36 = (($$013) + 20|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($$013) + 24|0);
      $39 = HEAP32[$38>>2]|0;
      $46 = $37;$48 = $39;
     }
     $43 = HEAP32[$8>>2]|0;
     $44 = HEAP32[$7>>2]|0;
     $45 = ($43>>>0)<($46>>>0);
     $47 = $45 ? $43 : $46;
     $49 = (_memcmp($48,$44,$47)|0);
     $50 = ($49|0)==(0);
     if ($50) {
      $51 = ($46>>>0)<($43>>>0);
      $$$i$i$i$i = $45&1;
      $$$$i$i$i$i = $51 ? -1 : $$$i$i$i$i;
      $53 = $$$$i$i$i$i;
     } else {
      $53 = $49;
     }
     $52 = ($53|0)<(0);
     if (!($52)) {
      $$01$lcssa2 = $$013;
      break L6;
     }
     $56 = (($$013) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013 = $57;
     }
    }
   }
  } while(0);
  $54 = HEAP32[$$01$lcssa2>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$0$ph6 = $$01$lcssa2;
   label = 19;
   break;
  } else {
   $$0$ph9 = $$01$lcssa2;$$01$ph8 = $54;
  }
 }
 if ((label|0) == 19) {
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
}
function __GLOBAL__I_a1532() {
 var $$byval_copy66 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0;
 var $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0;
 var $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0;
 var $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0;
 var $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0;
 var $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0;
 var $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0;
 var $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0;
 var $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0;
 var $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0;
 var $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0;
 var $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0;
 var $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0;
 var $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0;
 var $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0;
 var $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0;
 var $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy66 = sp + 4|0;
 $0 = sp;
 HEAP32[563544>>2] = 563568;
 HEAP32[((563544 + 12|0))>>2] = 56;
 HEAP32[((563544 + 4|0))>>2] = 0;
 HEAP32[((563544 + 8|0))>>2] = -1;
 HEAP32[((563544 + 16|0))>>2] = 1;
 $1 = HEAP32[563328>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (__Znwj(12)|0);
  HEAP32[$3>>2] = $3;
  $4 = (($3) + 4|0);
  HEAP32[$4>>2] = $3;
  $5 = (($3) + 8|0);
  HEAP32[$5>>2] = 0;
  HEAP32[563328>>2] = $3;
  $9 = $3;
 } else {
  $9 = $1;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $7 = (($6) + 8|0);
 HEAP32[$7>>2] = 563544;
 $8 = HEAP32[$9>>2]|0;
 $10 = (($8) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = HEAP32[$9>>2]|0;
 HEAP32[$6>>2] = $11;
 HEAP32[$9>>2] = $6;
 $12 = (($6) + 4|0);
 HEAP32[$12>>2] = $9;
 $13 = (($9) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1)|0;
 HEAP32[$13>>2] = $15;
 HEAP32[563584>>2] = 563608;
 HEAP32[((563584 + 12|0))>>2] = 56;
 HEAP32[((563584 + 4|0))>>2] = 0;
 HEAP32[((563584 + 8|0))>>2] = -1;
 HEAP32[((563584 + 16|0))>>2] = 1;
 $16 = HEAP32[563328>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $18 = (__Znwj(12)|0);
  HEAP32[$18>>2] = $18;
  $19 = (($18) + 4|0);
  HEAP32[$19>>2] = $18;
  $20 = (($18) + 8|0);
  HEAP32[$20>>2] = 0;
  HEAP32[563328>>2] = $18;
  $24 = $18;
 } else {
  $24 = $16;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $21 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $22 = (($21) + 8|0);
 HEAP32[$22>>2] = 563584;
 $23 = HEAP32[$24>>2]|0;
 $25 = (($23) + 4|0);
 HEAP32[$25>>2] = $21;
 $26 = HEAP32[$24>>2]|0;
 HEAP32[$21>>2] = $26;
 HEAP32[$24>>2] = $21;
 $27 = (($21) + 4|0);
 HEAP32[$27>>2] = $24;
 $28 = (($24) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 HEAP32[563624>>2] = 563648;
 HEAP32[((563624 + 12|0))>>2] = 56;
 HEAP32[((563624 + 4|0))>>2] = 0;
 HEAP32[((563624 + 8|0))>>2] = -1;
 HEAP32[((563624 + 16|0))>>2] = 1;
 $31 = HEAP32[563328>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $33 = (__Znwj(12)|0);
  HEAP32[$33>>2] = $33;
  $34 = (($33) + 4|0);
  HEAP32[$34>>2] = $33;
  $35 = (($33) + 8|0);
  HEAP32[$35>>2] = 0;
  HEAP32[563328>>2] = $33;
  $39 = $33;
 } else {
  $39 = $31;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $36 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $37 = (($36) + 8|0);
 HEAP32[$37>>2] = 563624;
 $38 = HEAP32[$39>>2]|0;
 $40 = (($38) + 4|0);
 HEAP32[$40>>2] = $36;
 $41 = HEAP32[$39>>2]|0;
 HEAP32[$36>>2] = $41;
 HEAP32[$39>>2] = $36;
 $42 = (($36) + 4|0);
 HEAP32[$42>>2] = $39;
 $43 = (($39) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 1)|0;
 HEAP32[$43>>2] = $45;
 HEAP32[563664>>2] = 563688;
 HEAP32[((563664 + 12|0))>>2] = 100004;
 HEAP32[((563664 + 4|0))>>2] = 0;
 HEAP32[((563664 + 8|0))>>2] = -1;
 HEAP32[((563664 + 16|0))>>2] = 1;
 $46 = HEAP32[563328>>2]|0;
 $47 = ($46|0)==(0|0);
 if ($47) {
  $48 = (__Znwj(12)|0);
  HEAP32[$48>>2] = $48;
  $49 = (($48) + 4|0);
  HEAP32[$49>>2] = $48;
  $50 = (($48) + 8|0);
  HEAP32[$50>>2] = 0;
  HEAP32[563328>>2] = $48;
  $54 = $48;
 } else {
  $54 = $46;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $51 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $52 = (($51) + 8|0);
 HEAP32[$52>>2] = 563664;
 $53 = HEAP32[$54>>2]|0;
 $55 = (($53) + 4|0);
 HEAP32[$55>>2] = $51;
 $56 = HEAP32[$54>>2]|0;
 HEAP32[$51>>2] = $56;
 HEAP32[$54>>2] = $51;
 $57 = (($51) + 4|0);
 HEAP32[$57>>2] = $54;
 $58 = (($54) + 8|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$58>>2] = $60;
 HEAP32[563712>>2] = 563736;
 HEAP32[((563712 + 12|0))>>2] = 100004;
 HEAP32[((563712 + 4|0))>>2] = 0;
 HEAP32[((563712 + 8|0))>>2] = -1;
 HEAP32[((563712 + 16|0))>>2] = 1;
 $61 = HEAP32[563328>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  $63 = (__Znwj(12)|0);
  HEAP32[$63>>2] = $63;
  $64 = (($63) + 4|0);
  HEAP32[$64>>2] = $63;
  $65 = (($63) + 8|0);
  HEAP32[$65>>2] = 0;
  HEAP32[563328>>2] = $63;
  $69 = $63;
 } else {
  $69 = $61;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $66 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $67 = (($66) + 8|0);
 HEAP32[$67>>2] = 563712;
 $68 = HEAP32[$69>>2]|0;
 $70 = (($68) + 4|0);
 HEAP32[$70>>2] = $66;
 $71 = HEAP32[$69>>2]|0;
 HEAP32[$66>>2] = $71;
 HEAP32[$69>>2] = $66;
 $72 = (($66) + 4|0);
 HEAP32[$72>>2] = $69;
 $73 = (($69) + 8|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($74) + 1)|0;
 HEAP32[$73>>2] = $75;
 HEAP32[563752>>2] = 563776;
 HEAP32[((563752 + 12|0))>>2] = 100004;
 HEAP32[((563752 + 4|0))>>2] = 0;
 HEAP32[((563752 + 8|0))>>2] = -1;
 HEAP32[((563752 + 16|0))>>2] = 1;
 $76 = HEAP32[563328>>2]|0;
 $77 = ($76|0)==(0|0);
 if ($77) {
  $78 = (__Znwj(12)|0);
  HEAP32[$78>>2] = $78;
  $79 = (($78) + 4|0);
  HEAP32[$79>>2] = $78;
  $80 = (($78) + 8|0);
  HEAP32[$80>>2] = 0;
  HEAP32[563328>>2] = $78;
  $84 = $78;
 } else {
  $84 = $76;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $81 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $82 = (($81) + 8|0);
 HEAP32[$82>>2] = 563752;
 $83 = HEAP32[$84>>2]|0;
 $85 = (($83) + 4|0);
 HEAP32[$85>>2] = $81;
 $86 = HEAP32[$84>>2]|0;
 HEAP32[$81>>2] = $86;
 HEAP32[$84>>2] = $81;
 $87 = (($81) + 4|0);
 HEAP32[$87>>2] = $84;
 $88 = (($84) + 8|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + 1)|0;
 HEAP32[$88>>2] = $90;
 HEAP32[563792>>2] = 563816;
 HEAP32[((563792 + 12|0))>>2] = 100007;
 HEAP32[((563792 + 4|0))>>2] = 0;
 HEAP32[((563792 + 8|0))>>2] = -1;
 HEAP32[((563792 + 16|0))>>2] = 1;
 $91 = HEAP32[563328>>2]|0;
 $92 = ($91|0)==(0|0);
 if ($92) {
  $93 = (__Znwj(12)|0);
  HEAP32[$93>>2] = $93;
  $94 = (($93) + 4|0);
  HEAP32[$94>>2] = $93;
  $95 = (($93) + 8|0);
  HEAP32[$95>>2] = 0;
  HEAP32[563328>>2] = $93;
  $99 = $93;
 } else {
  $99 = $91;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $96 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $97 = (($96) + 8|0);
 HEAP32[$97>>2] = 563792;
 $98 = HEAP32[$99>>2]|0;
 $100 = (($98) + 4|0);
 HEAP32[$100>>2] = $96;
 $101 = HEAP32[$99>>2]|0;
 HEAP32[$96>>2] = $101;
 HEAP32[$99>>2] = $96;
 $102 = (($96) + 4|0);
 HEAP32[$102>>2] = $99;
 $103 = (($99) + 8|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + 1)|0;
 HEAP32[$103>>2] = $105;
 HEAP32[563840>>2] = 563864;
 HEAP32[((563840 + 12|0))>>2] = 100007;
 HEAP32[((563840 + 4|0))>>2] = 0;
 HEAP32[((563840 + 8|0))>>2] = -1;
 HEAP32[((563840 + 16|0))>>2] = 1;
 $106 = HEAP32[563328>>2]|0;
 $107 = ($106|0)==(0|0);
 if ($107) {
  $108 = (__Znwj(12)|0);
  HEAP32[$108>>2] = $108;
  $109 = (($108) + 4|0);
  HEAP32[$109>>2] = $108;
  $110 = (($108) + 8|0);
  HEAP32[$110>>2] = 0;
  HEAP32[563328>>2] = $108;
  $114 = $108;
 } else {
  $114 = $106;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $111 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $112 = (($111) + 8|0);
 HEAP32[$112>>2] = 563840;
 $113 = HEAP32[$114>>2]|0;
 $115 = (($113) + 4|0);
 HEAP32[$115>>2] = $111;
 $116 = HEAP32[$114>>2]|0;
 HEAP32[$111>>2] = $116;
 HEAP32[$114>>2] = $111;
 $117 = (($111) + 4|0);
 HEAP32[$117>>2] = $114;
 $118 = (($114) + 8|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (($119) + 1)|0;
 HEAP32[$118>>2] = $120;
 HEAP32[563888>>2] = 563912;
 HEAP32[((563888 + 12|0))>>2] = 100007;
 HEAP32[((563888 + 4|0))>>2] = 0;
 HEAP32[((563888 + 8|0))>>2] = -1;
 HEAP32[((563888 + 16|0))>>2] = 1;
 $121 = HEAP32[563328>>2]|0;
 $122 = ($121|0)==(0|0);
 if ($122) {
  $123 = (__Znwj(12)|0);
  HEAP32[$123>>2] = $123;
  $124 = (($123) + 4|0);
  HEAP32[$124>>2] = $123;
  $125 = (($123) + 8|0);
  HEAP32[$125>>2] = 0;
  HEAP32[563328>>2] = $123;
  $129 = $123;
 } else {
  $129 = $121;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $126 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $127 = (($126) + 8|0);
 HEAP32[$127>>2] = 563888;
 $128 = HEAP32[$129>>2]|0;
 $130 = (($128) + 4|0);
 HEAP32[$130>>2] = $126;
 $131 = HEAP32[$129>>2]|0;
 HEAP32[$126>>2] = $131;
 HEAP32[$129>>2] = $126;
 $132 = (($126) + 4|0);
 HEAP32[$132>>2] = $129;
 $133 = (($129) + 8|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = (($134) + 1)|0;
 HEAP32[$133>>2] = $135;
 HEAP32[563936>>2] = 563960;
 HEAP32[((563936 + 12|0))>>2] = 53;
 HEAP32[((563936 + 4|0))>>2] = 0;
 HEAP32[((563936 + 8|0))>>2] = -1;
 HEAP32[((563936 + 16|0))>>2] = 1;
 $136 = HEAP32[563328>>2]|0;
 $137 = ($136|0)==(0|0);
 if ($137) {
  $138 = (__Znwj(12)|0);
  HEAP32[$138>>2] = $138;
  $139 = (($138) + 4|0);
  HEAP32[$139>>2] = $138;
  $140 = (($138) + 8|0);
  HEAP32[$140>>2] = 0;
  HEAP32[563328>>2] = $138;
  $144 = $138;
 } else {
  $144 = $136;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $141 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $142 = (($141) + 8|0);
 HEAP32[$142>>2] = 563936;
 $143 = HEAP32[$144>>2]|0;
 $145 = (($143) + 4|0);
 HEAP32[$145>>2] = $141;
 $146 = HEAP32[$144>>2]|0;
 HEAP32[$141>>2] = $146;
 HEAP32[$144>>2] = $141;
 $147 = (($141) + 4|0);
 HEAP32[$147>>2] = $144;
 $148 = (($144) + 8|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = (($149) + 1)|0;
 HEAP32[$148>>2] = $150;
 HEAP32[563984>>2] = 564008;
 HEAP32[((563984 + 12|0))>>2] = 53;
 HEAP32[((563984 + 4|0))>>2] = 0;
 HEAP32[((563984 + 8|0))>>2] = -1;
 HEAP32[((563984 + 16|0))>>2] = 1;
 $151 = HEAP32[563328>>2]|0;
 $152 = ($151|0)==(0|0);
 if ($152) {
  $153 = (__Znwj(12)|0);
  HEAP32[$153>>2] = $153;
  $154 = (($153) + 4|0);
  HEAP32[$154>>2] = $153;
  $155 = (($153) + 8|0);
  HEAP32[$155>>2] = 0;
  HEAP32[563328>>2] = $153;
  $159 = $153;
 } else {
  $159 = $151;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $156 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $157 = (($156) + 8|0);
 HEAP32[$157>>2] = 563984;
 $158 = HEAP32[$159>>2]|0;
 $160 = (($158) + 4|0);
 HEAP32[$160>>2] = $156;
 $161 = HEAP32[$159>>2]|0;
 HEAP32[$156>>2] = $161;
 HEAP32[$159>>2] = $156;
 $162 = (($156) + 4|0);
 HEAP32[$162>>2] = $159;
 $163 = (($159) + 8|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = (($164) + 1)|0;
 HEAP32[$163>>2] = $165;
 HEAP32[564024>>2] = 564048;
 HEAP32[((564024 + 12|0))>>2] = 53;
 HEAP32[((564024 + 4|0))>>2] = 0;
 HEAP32[((564024 + 8|0))>>2] = -1;
 HEAP32[((564024 + 16|0))>>2] = 1;
 $166 = HEAP32[563328>>2]|0;
 $167 = ($166|0)==(0|0);
 if ($167) {
  $168 = (__Znwj(12)|0);
  HEAP32[$168>>2] = $168;
  $169 = (($168) + 4|0);
  HEAP32[$169>>2] = $168;
  $170 = (($168) + 8|0);
  HEAP32[$170>>2] = 0;
  HEAP32[563328>>2] = $168;
  $174 = $168;
 } else {
  $174 = $166;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $171 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $172 = (($171) + 8|0);
 HEAP32[$172>>2] = 564024;
 $173 = HEAP32[$174>>2]|0;
 $175 = (($173) + 4|0);
 HEAP32[$175>>2] = $171;
 $176 = HEAP32[$174>>2]|0;
 HEAP32[$171>>2] = $176;
 HEAP32[$174>>2] = $171;
 $177 = (($171) + 4|0);
 HEAP32[$177>>2] = $174;
 $178 = (($174) + 8|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = (($179) + 1)|0;
 HEAP32[$178>>2] = $180;
 HEAP32[564064>>2] = 564088;
 HEAP32[((564064 + 12|0))>>2] = 100002;
 HEAP32[((564064 + 4|0))>>2] = 0;
 HEAP32[((564064 + 8|0))>>2] = -1;
 HEAP32[((564064 + 16|0))>>2] = 1;
 $181 = HEAP32[563328>>2]|0;
 $182 = ($181|0)==(0|0);
 if ($182) {
  $183 = (__Znwj(12)|0);
  HEAP32[$183>>2] = $183;
  $184 = (($183) + 4|0);
  HEAP32[$184>>2] = $183;
  $185 = (($183) + 8|0);
  HEAP32[$185>>2] = 0;
  HEAP32[563328>>2] = $183;
  $189 = $183;
 } else {
  $189 = $181;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $186 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $187 = (($186) + 8|0);
 HEAP32[$187>>2] = 564064;
 $188 = HEAP32[$189>>2]|0;
 $190 = (($188) + 4|0);
 HEAP32[$190>>2] = $186;
 $191 = HEAP32[$189>>2]|0;
 HEAP32[$186>>2] = $191;
 HEAP32[$189>>2] = $186;
 $192 = (($186) + 4|0);
 HEAP32[$192>>2] = $189;
 $193 = (($189) + 8|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = (($194) + 1)|0;
 HEAP32[$193>>2] = $195;
 HEAP32[564104>>2] = 564128;
 HEAP32[((564104 + 12|0))>>2] = 100000;
 HEAP32[((564104 + 4|0))>>2] = 0;
 HEAP32[((564104 + 8|0))>>2] = -1;
 HEAP32[((564104 + 16|0))>>2] = 0;
 $196 = HEAP32[563328>>2]|0;
 $197 = ($196|0)==(0|0);
 if ($197) {
  $198 = (__Znwj(12)|0);
  HEAP32[$198>>2] = $198;
  $199 = (($198) + 4|0);
  HEAP32[$199>>2] = $198;
  $200 = (($198) + 8|0);
  HEAP32[$200>>2] = 0;
  HEAP32[563328>>2] = $198;
  $204 = $198;
 } else {
  $204 = $196;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $201 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $202 = (($201) + 8|0);
 HEAP32[$202>>2] = 564104;
 $203 = HEAP32[$204>>2]|0;
 $205 = (($203) + 4|0);
 HEAP32[$205>>2] = $201;
 $206 = HEAP32[$204>>2]|0;
 HEAP32[$201>>2] = $206;
 HEAP32[$204>>2] = $201;
 $207 = (($201) + 4|0);
 HEAP32[$207>>2] = $204;
 $208 = (($204) + 8|0);
 $209 = HEAP32[$208>>2]|0;
 $210 = (($209) + 1)|0;
 HEAP32[$208>>2] = $210;
 HEAP32[564152>>2] = 564176;
 HEAP32[((564152 + 12|0))>>2] = 0;
 HEAP32[((564152 + 4|0))>>2] = 0;
 HEAP32[((564152 + 8|0))>>2] = -1;
 HEAP32[((564152 + 16|0))>>2] = 1;
 $211 = HEAP32[563328>>2]|0;
 $212 = ($211|0)==(0|0);
 if ($212) {
  $213 = (__Znwj(12)|0);
  HEAP32[$213>>2] = $213;
  $214 = (($213) + 4|0);
  HEAP32[$214>>2] = $213;
  $215 = (($213) + 8|0);
  HEAP32[$215>>2] = 0;
  HEAP32[563328>>2] = $213;
  $219 = $213;
 } else {
  $219 = $211;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $216 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $217 = (($216) + 8|0);
 HEAP32[$217>>2] = 564152;
 $218 = HEAP32[$219>>2]|0;
 $220 = (($218) + 4|0);
 HEAP32[$220>>2] = $216;
 $221 = HEAP32[$219>>2]|0;
 HEAP32[$216>>2] = $221;
 HEAP32[$219>>2] = $216;
 $222 = (($216) + 4|0);
 HEAP32[$222>>2] = $219;
 $223 = (($219) + 8|0);
 $224 = HEAP32[$223>>2]|0;
 $225 = (($224) + 1)|0;
 HEAP32[$223>>2] = $225;
 HEAP32[564208>>2] = 564232;
 HEAP32[((564208 + 12|0))>>2] = 0;
 HEAP32[((564208 + 4|0))>>2] = 0;
 HEAP32[((564208 + 8|0))>>2] = -1;
 HEAP32[((564208 + 16|0))>>2] = 1;
 $226 = HEAP32[563328>>2]|0;
 $227 = ($226|0)==(0|0);
 if ($227) {
  $228 = (__Znwj(12)|0);
  HEAP32[$228>>2] = $228;
  $229 = (($228) + 4|0);
  HEAP32[$229>>2] = $228;
  $230 = (($228) + 8|0);
  HEAP32[$230>>2] = 0;
  HEAP32[563328>>2] = $228;
  $234 = $228;
 } else {
  $234 = $226;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $231 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $232 = (($231) + 8|0);
 HEAP32[$232>>2] = 564208;
 $233 = HEAP32[$234>>2]|0;
 $235 = (($233) + 4|0);
 HEAP32[$235>>2] = $231;
 $236 = HEAP32[$234>>2]|0;
 HEAP32[$231>>2] = $236;
 HEAP32[$234>>2] = $231;
 $237 = (($231) + 4|0);
 HEAP32[$237>>2] = $234;
 $238 = (($234) + 8|0);
 $239 = HEAP32[$238>>2]|0;
 $240 = (($239) + 1)|0;
 HEAP32[$238>>2] = $240;
 HEAP32[564264>>2] = 564288;
 HEAP32[((564264 + 12|0))>>2] = 0;
 HEAP32[((564264 + 4|0))>>2] = 0;
 HEAP32[((564264 + 8|0))>>2] = -1;
 HEAP32[((564264 + 16|0))>>2] = 1;
 $241 = HEAP32[563328>>2]|0;
 $242 = ($241|0)==(0|0);
 if ($242) {
  $243 = (__Znwj(12)|0);
  HEAP32[$243>>2] = $243;
  $244 = (($243) + 4|0);
  HEAP32[$244>>2] = $243;
  $245 = (($243) + 8|0);
  HEAP32[$245>>2] = 0;
  HEAP32[563328>>2] = $243;
  $249 = $243;
 } else {
  $249 = $241;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $246 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $247 = (($246) + 8|0);
 HEAP32[$247>>2] = 564264;
 $248 = HEAP32[$249>>2]|0;
 $250 = (($248) + 4|0);
 HEAP32[$250>>2] = $246;
 $251 = HEAP32[$249>>2]|0;
 HEAP32[$246>>2] = $251;
 HEAP32[$249>>2] = $246;
 $252 = (($246) + 4|0);
 HEAP32[$252>>2] = $249;
 $253 = (($249) + 8|0);
 $254 = HEAP32[$253>>2]|0;
 $255 = (($254) + 1)|0;
 HEAP32[$253>>2] = $255;
 HEAP32[564320>>2] = 564344;
 HEAP32[((564320 + 12|0))>>2] = 1;
 HEAP32[((564320 + 4|0))>>2] = 0;
 HEAP32[((564320 + 8|0))>>2] = -1;
 HEAP32[((564320 + 16|0))>>2] = 1;
 $256 = HEAP32[563328>>2]|0;
 $257 = ($256|0)==(0|0);
 if ($257) {
  $258 = (__Znwj(12)|0);
  HEAP32[$258>>2] = $258;
  $259 = (($258) + 4|0);
  HEAP32[$259>>2] = $258;
  $260 = (($258) + 8|0);
  HEAP32[$260>>2] = 0;
  HEAP32[563328>>2] = $258;
  $264 = $258;
 } else {
  $264 = $256;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $261 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $262 = (($261) + 8|0);
 HEAP32[$262>>2] = 564320;
 $263 = HEAP32[$264>>2]|0;
 $265 = (($263) + 4|0);
 HEAP32[$265>>2] = $261;
 $266 = HEAP32[$264>>2]|0;
 HEAP32[$261>>2] = $266;
 HEAP32[$264>>2] = $261;
 $267 = (($261) + 4|0);
 HEAP32[$267>>2] = $264;
 $268 = (($264) + 8|0);
 $269 = HEAP32[$268>>2]|0;
 $270 = (($269) + 1)|0;
 HEAP32[$268>>2] = $270;
 HEAP32[564368>>2] = 564392;
 HEAP32[((564368 + 12|0))>>2] = 0;
 HEAP32[((564368 + 4|0))>>2] = 0;
 HEAP32[((564368 + 8|0))>>2] = -1;
 HEAP32[((564368 + 16|0))>>2] = 0;
 $271 = HEAP32[563328>>2]|0;
 $272 = ($271|0)==(0|0);
 if ($272) {
  $273 = (__Znwj(12)|0);
  HEAP32[$273>>2] = $273;
  $274 = (($273) + 4|0);
  HEAP32[$274>>2] = $273;
  $275 = (($273) + 8|0);
  HEAP32[$275>>2] = 0;
  HEAP32[563328>>2] = $273;
  $279 = $273;
 } else {
  $279 = $271;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $276 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $277 = (($276) + 8|0);
 HEAP32[$277>>2] = 564368;
 $278 = HEAP32[$279>>2]|0;
 $280 = (($278) + 4|0);
 HEAP32[$280>>2] = $276;
 $281 = HEAP32[$279>>2]|0;
 HEAP32[$276>>2] = $281;
 HEAP32[$279>>2] = $276;
 $282 = (($276) + 4|0);
 HEAP32[$282>>2] = $279;
 $283 = (($279) + 8|0);
 $284 = HEAP32[$283>>2]|0;
 $285 = (($284) + 1)|0;
 HEAP32[$283>>2] = $285;
 HEAP32[564416>>2] = 564440;
 HEAP32[((564416 + 12|0))>>2] = 43;
 HEAP32[((564416 + 4|0))>>2] = 0;
 HEAP32[((564416 + 8|0))>>2] = -1;
 HEAP32[((564416 + 16|0))>>2] = 0;
 $286 = HEAP32[563328>>2]|0;
 $287 = ($286|0)==(0|0);
 if ($287) {
  $288 = (__Znwj(12)|0);
  HEAP32[$288>>2] = $288;
  $289 = (($288) + 4|0);
  HEAP32[$289>>2] = $288;
  $290 = (($288) + 8|0);
  HEAP32[$290>>2] = 0;
  HEAP32[563328>>2] = $288;
  $294 = $288;
 } else {
  $294 = $286;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $291 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $292 = (($291) + 8|0);
 HEAP32[$292>>2] = 564416;
 $293 = HEAP32[$294>>2]|0;
 $295 = (($293) + 4|0);
 HEAP32[$295>>2] = $291;
 $296 = HEAP32[$294>>2]|0;
 HEAP32[$291>>2] = $296;
 HEAP32[$294>>2] = $291;
 $297 = (($291) + 4|0);
 HEAP32[$297>>2] = $294;
 $298 = (($294) + 8|0);
 $299 = HEAP32[$298>>2]|0;
 $300 = (($299) + 1)|0;
 HEAP32[$298>>2] = $300;
 HEAP32[564464>>2] = 564488;
 HEAP32[((564464 + 12|0))>>2] = 0;
 HEAP32[((564464 + 4|0))>>2] = 0;
 HEAP32[((564464 + 8|0))>>2] = -1;
 HEAP32[((564464 + 16|0))>>2] = 0;
 $301 = HEAP32[563328>>2]|0;
 $302 = ($301|0)==(0|0);
 if ($302) {
  $303 = (__Znwj(12)|0);
  HEAP32[$303>>2] = $303;
  $304 = (($303) + 4|0);
  HEAP32[$304>>2] = $303;
  $305 = (($303) + 8|0);
  HEAP32[$305>>2] = 0;
  HEAP32[563328>>2] = $303;
  $309 = $303;
 } else {
  $309 = $301;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $306 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $307 = (($306) + 8|0);
 HEAP32[$307>>2] = 564464;
 $308 = HEAP32[$309>>2]|0;
 $310 = (($308) + 4|0);
 HEAP32[$310>>2] = $306;
 $311 = HEAP32[$309>>2]|0;
 HEAP32[$306>>2] = $311;
 HEAP32[$309>>2] = $306;
 $312 = (($306) + 4|0);
 HEAP32[$312>>2] = $309;
 $313 = (($309) + 8|0);
 $314 = HEAP32[$313>>2]|0;
 $315 = (($314) + 1)|0;
 HEAP32[$313>>2] = $315;
 HEAP32[564512>>2] = 564536;
 HEAP32[((564512 + 12|0))>>2] = 0;
 HEAP32[((564512 + 4|0))>>2] = 0;
 HEAP32[((564512 + 8|0))>>2] = -1;
 HEAP32[((564512 + 16|0))>>2] = 0;
 $316 = HEAP32[563328>>2]|0;
 $317 = ($316|0)==(0|0);
 if ($317) {
  $318 = (__Znwj(12)|0);
  HEAP32[$318>>2] = $318;
  $319 = (($318) + 4|0);
  HEAP32[$319>>2] = $318;
  $320 = (($318) + 8|0);
  HEAP32[$320>>2] = 0;
  HEAP32[563328>>2] = $318;
  $324 = $318;
 } else {
  $324 = $316;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $321 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $322 = (($321) + 8|0);
 HEAP32[$322>>2] = 564512;
 $323 = HEAP32[$324>>2]|0;
 $325 = (($323) + 4|0);
 HEAP32[$325>>2] = $321;
 $326 = HEAP32[$324>>2]|0;
 HEAP32[$321>>2] = $326;
 HEAP32[$324>>2] = $321;
 $327 = (($321) + 4|0);
 HEAP32[$327>>2] = $324;
 $328 = (($324) + 8|0);
 $329 = HEAP32[$328>>2]|0;
 $330 = (($329) + 1)|0;
 HEAP32[$328>>2] = $330;
 HEAP32[564552>>2] = 564576;
 HEAP32[((564552 + 12|0))>>2] = 0;
 HEAP32[((564552 + 4|0))>>2] = 0;
 HEAP32[((564552 + 8|0))>>2] = -1;
 HEAP32[((564552 + 16|0))>>2] = 0;
 $331 = HEAP32[563328>>2]|0;
 $332 = ($331|0)==(0|0);
 if ($332) {
  $333 = (__Znwj(12)|0);
  HEAP32[$333>>2] = $333;
  $334 = (($333) + 4|0);
  HEAP32[$334>>2] = $333;
  $335 = (($333) + 8|0);
  HEAP32[$335>>2] = 0;
  HEAP32[563328>>2] = $333;
  $339 = $333;
 } else {
  $339 = $331;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $336 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $337 = (($336) + 8|0);
 HEAP32[$337>>2] = 564552;
 $338 = HEAP32[$339>>2]|0;
 $340 = (($338) + 4|0);
 HEAP32[$340>>2] = $336;
 $341 = HEAP32[$339>>2]|0;
 HEAP32[$336>>2] = $341;
 HEAP32[$339>>2] = $336;
 $342 = (($336) + 4|0);
 HEAP32[$342>>2] = $339;
 $343 = (($339) + 8|0);
 $344 = HEAP32[$343>>2]|0;
 $345 = (($344) + 1)|0;
 HEAP32[$343>>2] = $345;
 HEAP32[564592>>2] = 564616;
 HEAP32[((564592 + 12|0))>>2] = 0;
 HEAP32[((564592 + 4|0))>>2] = 0;
 HEAP32[((564592 + 8|0))>>2] = -1;
 HEAP32[((564592 + 16|0))>>2] = 2;
 $346 = HEAP32[563328>>2]|0;
 $347 = ($346|0)==(0|0);
 if ($347) {
  $348 = (__Znwj(12)|0);
  HEAP32[$348>>2] = $348;
  $349 = (($348) + 4|0);
  HEAP32[$349>>2] = $348;
  $350 = (($348) + 8|0);
  HEAP32[$350>>2] = 0;
  HEAP32[563328>>2] = $348;
  $354 = $348;
 } else {
  $354 = $346;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $351 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $352 = (($351) + 8|0);
 HEAP32[$352>>2] = 564592;
 $353 = HEAP32[$354>>2]|0;
 $355 = (($353) + 4|0);
 HEAP32[$355>>2] = $351;
 $356 = HEAP32[$354>>2]|0;
 HEAP32[$351>>2] = $356;
 HEAP32[$354>>2] = $351;
 $357 = (($351) + 4|0);
 HEAP32[$357>>2] = $354;
 $358 = (($354) + 8|0);
 $359 = HEAP32[$358>>2]|0;
 $360 = (($359) + 1)|0;
 HEAP32[$358>>2] = $360;
 HEAP32[564640>>2] = 564664;
 HEAP32[((564640 + 12|0))>>2] = 2;
 HEAP32[((564640 + 4|0))>>2] = 0;
 HEAP32[((564640 + 8|0))>>2] = -1;
 HEAP32[((564640 + 16|0))>>2] = 0;
 $361 = HEAP32[563328>>2]|0;
 $362 = ($361|0)==(0|0);
 if ($362) {
  $363 = (__Znwj(12)|0);
  HEAP32[$363>>2] = $363;
  $364 = (($363) + 4|0);
  HEAP32[$364>>2] = $363;
  $365 = (($363) + 8|0);
  HEAP32[$365>>2] = 0;
  HEAP32[563328>>2] = $363;
  $369 = $363;
 } else {
  $369 = $361;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $366 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $367 = (($366) + 8|0);
 HEAP32[$367>>2] = 564640;
 $368 = HEAP32[$369>>2]|0;
 $370 = (($368) + 4|0);
 HEAP32[$370>>2] = $366;
 $371 = HEAP32[$369>>2]|0;
 HEAP32[$366>>2] = $371;
 HEAP32[$369>>2] = $366;
 $372 = (($366) + 4|0);
 HEAP32[$372>>2] = $369;
 $373 = (($369) + 8|0);
 $374 = HEAP32[$373>>2]|0;
 $375 = (($374) + 1)|0;
 HEAP32[$373>>2] = $375;
 HEAP32[564688>>2] = 564712;
 HEAP32[((564688 + 12|0))>>2] = 0;
 HEAP32[((564688 + 4|0))>>2] = 0;
 HEAP32[((564688 + 8|0))>>2] = -1;
 HEAP32[((564688 + 16|0))>>2] = 1;
 $376 = HEAP32[563328>>2]|0;
 $377 = ($376|0)==(0|0);
 if ($377) {
  $378 = (__Znwj(12)|0);
  HEAP32[$378>>2] = $378;
  $379 = (($378) + 4|0);
  HEAP32[$379>>2] = $378;
  $380 = (($378) + 8|0);
  HEAP32[$380>>2] = 0;
  HEAP32[563328>>2] = $378;
  $384 = $378;
 } else {
  $384 = $376;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $381 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $382 = (($381) + 8|0);
 HEAP32[$382>>2] = 564688;
 $383 = HEAP32[$384>>2]|0;
 $385 = (($383) + 4|0);
 HEAP32[$385>>2] = $381;
 $386 = HEAP32[$384>>2]|0;
 HEAP32[$381>>2] = $386;
 HEAP32[$384>>2] = $381;
 $387 = (($381) + 4|0);
 HEAP32[$387>>2] = $384;
 $388 = (($384) + 8|0);
 $389 = HEAP32[$388>>2]|0;
 $390 = (($389) + 1)|0;
 HEAP32[$388>>2] = $390;
 HEAP32[564728>>2] = 564752;
 HEAP32[((564728 + 12|0))>>2] = 0;
 HEAP32[((564728 + 4|0))>>2] = 0;
 HEAP32[((564728 + 8|0))>>2] = -1;
 HEAP32[((564728 + 16|0))>>2] = 1;
 $391 = HEAP32[563328>>2]|0;
 $392 = ($391|0)==(0|0);
 if ($392) {
  $393 = (__Znwj(12)|0);
  HEAP32[$393>>2] = $393;
  $394 = (($393) + 4|0);
  HEAP32[$394>>2] = $393;
  $395 = (($393) + 8|0);
  HEAP32[$395>>2] = 0;
  HEAP32[563328>>2] = $393;
  $399 = $393;
 } else {
  $399 = $391;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $396 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $397 = (($396) + 8|0);
 HEAP32[$397>>2] = 564728;
 $398 = HEAP32[$399>>2]|0;
 $400 = (($398) + 4|0);
 HEAP32[$400>>2] = $396;
 $401 = HEAP32[$399>>2]|0;
 HEAP32[$396>>2] = $401;
 HEAP32[$399>>2] = $396;
 $402 = (($396) + 4|0);
 HEAP32[$402>>2] = $399;
 $403 = (($399) + 8|0);
 $404 = HEAP32[$403>>2]|0;
 $405 = (($404) + 1)|0;
 HEAP32[$403>>2] = $405;
 HEAP32[564776>>2] = 564800;
 HEAP32[((564776 + 12|0))>>2] = 0;
 HEAP32[((564776 + 4|0))>>2] = 0;
 HEAP32[((564776 + 8|0))>>2] = -1;
 HEAP32[((564776 + 16|0))>>2] = 5;
 $406 = HEAP32[563328>>2]|0;
 $407 = ($406|0)==(0|0);
 if ($407) {
  $408 = (__Znwj(12)|0);
  HEAP32[$408>>2] = $408;
  $409 = (($408) + 4|0);
  HEAP32[$409>>2] = $408;
  $410 = (($408) + 8|0);
  HEAP32[$410>>2] = 0;
  HEAP32[563328>>2] = $408;
  $414 = $408;
 } else {
  $414 = $406;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $411 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $412 = (($411) + 8|0);
 HEAP32[$412>>2] = 564776;
 $413 = HEAP32[$414>>2]|0;
 $415 = (($413) + 4|0);
 HEAP32[$415>>2] = $411;
 $416 = HEAP32[$414>>2]|0;
 HEAP32[$411>>2] = $416;
 HEAP32[$414>>2] = $411;
 $417 = (($411) + 4|0);
 HEAP32[$417>>2] = $414;
 $418 = (($414) + 8|0);
 $419 = HEAP32[$418>>2]|0;
 $420 = (($419) + 1)|0;
 HEAP32[$418>>2] = $420;
 HEAP32[564824>>2] = 564848;
 HEAP32[((564824 + 12|0))>>2] = 0;
 HEAP32[((564824 + 4|0))>>2] = 0;
 HEAP32[((564824 + 8|0))>>2] = -1;
 HEAP32[((564824 + 16|0))>>2] = 5;
 $421 = HEAP32[563328>>2]|0;
 $422 = ($421|0)==(0|0);
 if ($422) {
  $423 = (__Znwj(12)|0);
  HEAP32[$423>>2] = $423;
  $424 = (($423) + 4|0);
  HEAP32[$424>>2] = $423;
  $425 = (($423) + 8|0);
  HEAP32[$425>>2] = 0;
  HEAP32[563328>>2] = $423;
  $429 = $423;
 } else {
  $429 = $421;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $426 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $427 = (($426) + 8|0);
 HEAP32[$427>>2] = 564824;
 $428 = HEAP32[$429>>2]|0;
 $430 = (($428) + 4|0);
 HEAP32[$430>>2] = $426;
 $431 = HEAP32[$429>>2]|0;
 HEAP32[$426>>2] = $431;
 HEAP32[$429>>2] = $426;
 $432 = (($426) + 4|0);
 HEAP32[$432>>2] = $429;
 $433 = (($429) + 8|0);
 $434 = HEAP32[$433>>2]|0;
 $435 = (($434) + 1)|0;
 HEAP32[$433>>2] = $435;
 HEAP32[564864>>2] = 564888;
 HEAP32[((564864 + 12|0))>>2] = 0;
 HEAP32[((564864 + 4|0))>>2] = 0;
 HEAP32[((564864 + 8|0))>>2] = -1;
 HEAP32[((564864 + 16|0))>>2] = 5;
 $436 = HEAP32[563328>>2]|0;
 $437 = ($436|0)==(0|0);
 if ($437) {
  $438 = (__Znwj(12)|0);
  HEAP32[$438>>2] = $438;
  $439 = (($438) + 4|0);
  HEAP32[$439>>2] = $438;
  $440 = (($438) + 8|0);
  HEAP32[$440>>2] = 0;
  HEAP32[563328>>2] = $438;
  $444 = $438;
 } else {
  $444 = $436;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $441 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $442 = (($441) + 8|0);
 HEAP32[$442>>2] = 564864;
 $443 = HEAP32[$444>>2]|0;
 $445 = (($443) + 4|0);
 HEAP32[$445>>2] = $441;
 $446 = HEAP32[$444>>2]|0;
 HEAP32[$441>>2] = $446;
 HEAP32[$444>>2] = $441;
 $447 = (($441) + 4|0);
 HEAP32[$447>>2] = $444;
 $448 = (($444) + 8|0);
 $449 = HEAP32[$448>>2]|0;
 $450 = (($449) + 1)|0;
 HEAP32[$448>>2] = $450;
 HEAP32[564904>>2] = 564928;
 HEAP32[((564904 + 12|0))>>2] = 0;
 HEAP32[((564904 + 4|0))>>2] = 0;
 HEAP32[((564904 + 8|0))>>2] = -1;
 HEAP32[((564904 + 16|0))>>2] = 5;
 $451 = HEAP32[563328>>2]|0;
 $452 = ($451|0)==(0|0);
 if ($452) {
  $453 = (__Znwj(12)|0);
  HEAP32[$453>>2] = $453;
  $454 = (($453) + 4|0);
  HEAP32[$454>>2] = $453;
  $455 = (($453) + 8|0);
  HEAP32[$455>>2] = 0;
  HEAP32[563328>>2] = $453;
  $459 = $453;
 } else {
  $459 = $451;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $456 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $457 = (($456) + 8|0);
 HEAP32[$457>>2] = 564904;
 $458 = HEAP32[$459>>2]|0;
 $460 = (($458) + 4|0);
 HEAP32[$460>>2] = $456;
 $461 = HEAP32[$459>>2]|0;
 HEAP32[$456>>2] = $461;
 HEAP32[$459>>2] = $456;
 $462 = (($456) + 4|0);
 HEAP32[$462>>2] = $459;
 $463 = (($459) + 8|0);
 $464 = HEAP32[$463>>2]|0;
 $465 = (($464) + 1)|0;
 HEAP32[$463>>2] = $465;
 HEAP32[564944>>2] = 564968;
 HEAP32[((564944 + 12|0))>>2] = 100003;
 HEAP32[((564944 + 4|0))>>2] = 0;
 HEAP32[((564944 + 8|0))>>2] = -1;
 HEAP32[((564944 + 16|0))>>2] = 1;
 $466 = HEAP32[563328>>2]|0;
 $467 = ($466|0)==(0|0);
 if ($467) {
  $468 = (__Znwj(12)|0);
  HEAP32[$468>>2] = $468;
  $469 = (($468) + 4|0);
  HEAP32[$469>>2] = $468;
  $470 = (($468) + 8|0);
  HEAP32[$470>>2] = 0;
  HEAP32[563328>>2] = $468;
  $474 = $468;
 } else {
  $474 = $466;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $471 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $472 = (($471) + 8|0);
 HEAP32[$472>>2] = 564944;
 $473 = HEAP32[$474>>2]|0;
 $475 = (($473) + 4|0);
 HEAP32[$475>>2] = $471;
 $476 = HEAP32[$474>>2]|0;
 HEAP32[$471>>2] = $476;
 HEAP32[$474>>2] = $471;
 $477 = (($471) + 4|0);
 HEAP32[$477>>2] = $474;
 $478 = (($474) + 8|0);
 $479 = HEAP32[$478>>2]|0;
 $480 = (($479) + 1)|0;
 HEAP32[$478>>2] = $480;
 HEAP32[564992>>2] = 565016;
 HEAP32[((564992 + 12|0))>>2] = 0;
 HEAP32[((564992 + 4|0))>>2] = 0;
 HEAP32[((564992 + 8|0))>>2] = -1;
 HEAP32[((564992 + 16|0))>>2] = 5;
 $481 = HEAP32[563328>>2]|0;
 $482 = ($481|0)==(0|0);
 if ($482) {
  $483 = (__Znwj(12)|0);
  HEAP32[$483>>2] = $483;
  $484 = (($483) + 4|0);
  HEAP32[$484>>2] = $483;
  $485 = (($483) + 8|0);
  HEAP32[$485>>2] = 0;
  HEAP32[563328>>2] = $483;
  $489 = $483;
 } else {
  $489 = $481;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $486 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $487 = (($486) + 8|0);
 HEAP32[$487>>2] = 564992;
 $488 = HEAP32[$489>>2]|0;
 $490 = (($488) + 4|0);
 HEAP32[$490>>2] = $486;
 $491 = HEAP32[$489>>2]|0;
 HEAP32[$486>>2] = $491;
 HEAP32[$489>>2] = $486;
 $492 = (($486) + 4|0);
 HEAP32[$492>>2] = $489;
 $493 = (($489) + 8|0);
 $494 = HEAP32[$493>>2]|0;
 $495 = (($494) + 1)|0;
 HEAP32[$493>>2] = $495;
 HEAP32[565032>>2] = 565056;
 HEAP32[((565032 + 12|0))>>2] = 100006;
 HEAP32[((565032 + 4|0))>>2] = 0;
 HEAP32[((565032 + 8|0))>>2] = -1;
 HEAP32[((565032 + 16|0))>>2] = 0;
 $496 = HEAP32[563328>>2]|0;
 $497 = ($496|0)==(0|0);
 if ($497) {
  $498 = (__Znwj(12)|0);
  HEAP32[$498>>2] = $498;
  $499 = (($498) + 4|0);
  HEAP32[$499>>2] = $498;
  $500 = (($498) + 8|0);
  HEAP32[$500>>2] = 0;
  HEAP32[563328>>2] = $498;
  $504 = $498;
 } else {
  $504 = $496;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $501 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $502 = (($501) + 8|0);
 HEAP32[$502>>2] = 565032;
 $503 = HEAP32[$504>>2]|0;
 $505 = (($503) + 4|0);
 HEAP32[$505>>2] = $501;
 $506 = HEAP32[$504>>2]|0;
 HEAP32[$501>>2] = $506;
 HEAP32[$504>>2] = $501;
 $507 = (($501) + 4|0);
 HEAP32[$507>>2] = $504;
 $508 = (($504) + 8|0);
 $509 = HEAP32[$508>>2]|0;
 $510 = (($509) + 1)|0;
 HEAP32[$508>>2] = $510;
 HEAP32[565080>>2] = 565104;
 HEAP32[((565080 + 12|0))>>2] = 100000;
 HEAP32[((565080 + 4|0))>>2] = 0;
 HEAP32[((565080 + 8|0))>>2] = -1;
 HEAP32[((565080 + 16|0))>>2] = 5;
 $511 = HEAP32[563328>>2]|0;
 $512 = ($511|0)==(0|0);
 if ($512) {
  $513 = (__Znwj(12)|0);
  HEAP32[$513>>2] = $513;
  $514 = (($513) + 4|0);
  HEAP32[$514>>2] = $513;
  $515 = (($513) + 8|0);
  HEAP32[$515>>2] = 0;
  HEAP32[563328>>2] = $513;
  $519 = $513;
 } else {
  $519 = $511;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $516 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $517 = (($516) + 8|0);
 HEAP32[$517>>2] = 565080;
 $518 = HEAP32[$519>>2]|0;
 $520 = (($518) + 4|0);
 HEAP32[$520>>2] = $516;
 $521 = HEAP32[$519>>2]|0;
 HEAP32[$516>>2] = $521;
 HEAP32[$519>>2] = $516;
 $522 = (($516) + 4|0);
 HEAP32[$522>>2] = $519;
 $523 = (($519) + 8|0);
 $524 = HEAP32[$523>>2]|0;
 $525 = (($524) + 1)|0;
 HEAP32[$523>>2] = $525;
 HEAP32[565120>>2] = 565144;
 HEAP32[((565120 + 12|0))>>2] = 0;
 HEAP32[((565120 + 4|0))>>2] = 0;
 HEAP32[((565120 + 8|0))>>2] = -1;
 HEAP32[((565120 + 16|0))>>2] = 0;
 $526 = HEAP32[563328>>2]|0;
 $527 = ($526|0)==(0|0);
 if ($527) {
  $528 = (__Znwj(12)|0);
  HEAP32[$528>>2] = $528;
  $529 = (($528) + 4|0);
  HEAP32[$529>>2] = $528;
  $530 = (($528) + 8|0);
  HEAP32[$530>>2] = 0;
  HEAP32[563328>>2] = $528;
  $534 = $528;
 } else {
  $534 = $526;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $531 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $532 = (($531) + 8|0);
 HEAP32[$532>>2] = 565120;
 $533 = HEAP32[$534>>2]|0;
 $535 = (($533) + 4|0);
 HEAP32[$535>>2] = $531;
 $536 = HEAP32[$534>>2]|0;
 HEAP32[$531>>2] = $536;
 HEAP32[$534>>2] = $531;
 $537 = (($531) + 4|0);
 HEAP32[$537>>2] = $534;
 $538 = (($534) + 8|0);
 $539 = HEAP32[$538>>2]|0;
 $540 = (($539) + 1)|0;
 HEAP32[$538>>2] = $540;
 HEAP32[565168>>2] = 565192;
 HEAP32[((565168 + 12|0))>>2] = 50;
 HEAP32[((565168 + 4|0))>>2] = 0;
 HEAP32[((565168 + 8|0))>>2] = -1;
 HEAP32[((565168 + 16|0))>>2] = 0;
 $541 = HEAP32[563328>>2]|0;
 $542 = ($541|0)==(0|0);
 if ($542) {
  $543 = (__Znwj(12)|0);
  HEAP32[$543>>2] = $543;
  $544 = (($543) + 4|0);
  HEAP32[$544>>2] = $543;
  $545 = (($543) + 8|0);
  HEAP32[$545>>2] = 0;
  HEAP32[563328>>2] = $543;
  $549 = $543;
 } else {
  $549 = $541;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $546 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $547 = (($546) + 8|0);
 HEAP32[$547>>2] = 565168;
 $548 = HEAP32[$549>>2]|0;
 $550 = (($548) + 4|0);
 HEAP32[$550>>2] = $546;
 $551 = HEAP32[$549>>2]|0;
 HEAP32[$546>>2] = $551;
 HEAP32[$549>>2] = $546;
 $552 = (($546) + 4|0);
 HEAP32[$552>>2] = $549;
 $553 = (($549) + 8|0);
 $554 = HEAP32[$553>>2]|0;
 $555 = (($554) + 1)|0;
 HEAP32[$553>>2] = $555;
 HEAP32[565224>>2] = 565248;
 HEAP32[((565224 + 12|0))>>2] = 100000;
 HEAP32[((565224 + 4|0))>>2] = 565272;
 HEAP32[((565224 + 8|0))>>2] = -1;
 HEAP32[((565224 + 16|0))>>2] = 1;
 $556 = HEAP32[563328>>2]|0;
 $557 = ($556|0)==(0|0);
 if ($557) {
  $558 = (__Znwj(12)|0);
  HEAP32[$558>>2] = $558;
  $559 = (($558) + 4|0);
  HEAP32[$559>>2] = $558;
  $560 = (($558) + 8|0);
  HEAP32[$560>>2] = 0;
  HEAP32[563328>>2] = $558;
  $564 = $558;
 } else {
  $564 = $556;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $561 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $562 = (($561) + 8|0);
 HEAP32[$562>>2] = 565224;
 $563 = HEAP32[$564>>2]|0;
 $565 = (($563) + 4|0);
 HEAP32[$565>>2] = $561;
 $566 = HEAP32[$564>>2]|0;
 HEAP32[$561>>2] = $566;
 HEAP32[$564>>2] = $561;
 $567 = (($561) + 4|0);
 HEAP32[$567>>2] = $564;
 $568 = (($564) + 8|0);
 $569 = HEAP32[$568>>2]|0;
 $570 = (($569) + 1)|0;
 HEAP32[$568>>2] = $570;
 HEAP32[565288>>2] = 565312;
 HEAP32[((565288 + 12|0))>>2] = 100000;
 HEAP32[((565288 + 4|0))>>2] = 565272;
 HEAP32[((565288 + 8|0))>>2] = -1;
 HEAP32[((565288 + 16|0))>>2] = 1;
 $571 = HEAP32[563328>>2]|0;
 $572 = ($571|0)==(0|0);
 if ($572) {
  $573 = (__Znwj(12)|0);
  HEAP32[$573>>2] = $573;
  $574 = (($573) + 4|0);
  HEAP32[$574>>2] = $573;
  $575 = (($573) + 8|0);
  HEAP32[$575>>2] = 0;
  HEAP32[563328>>2] = $573;
  $579 = $573;
 } else {
  $579 = $571;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $576 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $577 = (($576) + 8|0);
 HEAP32[$577>>2] = 565288;
 $578 = HEAP32[$579>>2]|0;
 $580 = (($578) + 4|0);
 HEAP32[$580>>2] = $576;
 $581 = HEAP32[$579>>2]|0;
 HEAP32[$576>>2] = $581;
 HEAP32[$579>>2] = $576;
 $582 = (($576) + 4|0);
 HEAP32[$582>>2] = $579;
 $583 = (($579) + 8|0);
 $584 = HEAP32[$583>>2]|0;
 $585 = (($584) + 1)|0;
 HEAP32[$583>>2] = $585;
 HEAP32[565336>>2] = 565360;
 HEAP32[((565336 + 12|0))>>2] = 0;
 HEAP32[((565336 + 4|0))>>2] = 0;
 HEAP32[((565336 + 8|0))>>2] = -1;
 HEAP32[((565336 + 16|0))>>2] = 1;
 $586 = HEAP32[563328>>2]|0;
 $587 = ($586|0)==(0|0);
 if ($587) {
  $588 = (__Znwj(12)|0);
  HEAP32[$588>>2] = $588;
  $589 = (($588) + 4|0);
  HEAP32[$589>>2] = $588;
  $590 = (($588) + 8|0);
  HEAP32[$590>>2] = 0;
  HEAP32[563328>>2] = $588;
  $594 = $588;
 } else {
  $594 = $586;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $591 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $592 = (($591) + 8|0);
 HEAP32[$592>>2] = 565336;
 $593 = HEAP32[$594>>2]|0;
 $595 = (($593) + 4|0);
 HEAP32[$595>>2] = $591;
 $596 = HEAP32[$594>>2]|0;
 HEAP32[$591>>2] = $596;
 HEAP32[$594>>2] = $591;
 $597 = (($591) + 4|0);
 HEAP32[$597>>2] = $594;
 $598 = (($594) + 8|0);
 $599 = HEAP32[$598>>2]|0;
 $600 = (($599) + 1)|0;
 HEAP32[$598>>2] = $600;
 HEAP32[565384>>2] = 565408;
 HEAP32[((565384 + 12|0))>>2] = 100000;
 HEAP32[((565384 + 4|0))>>2] = 565272;
 HEAP32[((565384 + 8|0))>>2] = -1;
 HEAP32[((565384 + 16|0))>>2] = 1;
 $601 = HEAP32[563328>>2]|0;
 $602 = ($601|0)==(0|0);
 if ($602) {
  $603 = (__Znwj(12)|0);
  HEAP32[$603>>2] = $603;
  $604 = (($603) + 4|0);
  HEAP32[$604>>2] = $603;
  $605 = (($603) + 8|0);
  HEAP32[$605>>2] = 0;
  HEAP32[563328>>2] = $603;
  $609 = $603;
 } else {
  $609 = $601;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $606 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $607 = (($606) + 8|0);
 HEAP32[$607>>2] = 565384;
 $608 = HEAP32[$609>>2]|0;
 $610 = (($608) + 4|0);
 HEAP32[$610>>2] = $606;
 $611 = HEAP32[$609>>2]|0;
 HEAP32[$606>>2] = $611;
 HEAP32[$609>>2] = $606;
 $612 = (($606) + 4|0);
 HEAP32[$612>>2] = $609;
 $613 = (($609) + 8|0);
 $614 = HEAP32[$613>>2]|0;
 $615 = (($614) + 1)|0;
 HEAP32[$613>>2] = $615;
 HEAP32[565432>>2] = 565456;
 HEAP32[((565432 + 12|0))>>2] = 100000;
 HEAP32[((565432 + 4|0))>>2] = 565488;
 HEAP32[((565432 + 8|0))>>2] = -1;
 HEAP32[((565432 + 16|0))>>2] = 1;
 $616 = HEAP32[563328>>2]|0;
 $617 = ($616|0)==(0|0);
 if ($617) {
  $618 = (__Znwj(12)|0);
  HEAP32[$618>>2] = $618;
  $619 = (($618) + 4|0);
  HEAP32[$619>>2] = $618;
  $620 = (($618) + 8|0);
  HEAP32[$620>>2] = 0;
  HEAP32[563328>>2] = $618;
  $624 = $618;
 } else {
  $624 = $616;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $621 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $622 = (($621) + 8|0);
 HEAP32[$622>>2] = 565432;
 $623 = HEAP32[$624>>2]|0;
 $625 = (($623) + 4|0);
 HEAP32[$625>>2] = $621;
 $626 = HEAP32[$624>>2]|0;
 HEAP32[$621>>2] = $626;
 HEAP32[$624>>2] = $621;
 $627 = (($621) + 4|0);
 HEAP32[$627>>2] = $624;
 $628 = (($624) + 8|0);
 $629 = HEAP32[$628>>2]|0;
 $630 = (($629) + 1)|0;
 HEAP32[$628>>2] = $630;
 HEAP32[565512>>2] = 565536;
 HEAP32[((565512 + 12|0))>>2] = 100000;
 HEAP32[((565512 + 4|0))>>2] = 565560;
 HEAP32[((565512 + 8|0))>>2] = -1;
 HEAP32[((565512 + 16|0))>>2] = 1;
 $631 = HEAP32[563328>>2]|0;
 $632 = ($631|0)==(0|0);
 if ($632) {
  $633 = (__Znwj(12)|0);
  HEAP32[$633>>2] = $633;
  $634 = (($633) + 4|0);
  HEAP32[$634>>2] = $633;
  $635 = (($633) + 8|0);
  HEAP32[$635>>2] = 0;
  HEAP32[563328>>2] = $633;
  $639 = $633;
 } else {
  $639 = $631;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $636 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $637 = (($636) + 8|0);
 HEAP32[$637>>2] = 565512;
 $638 = HEAP32[$639>>2]|0;
 $640 = (($638) + 4|0);
 HEAP32[$640>>2] = $636;
 $641 = HEAP32[$639>>2]|0;
 HEAP32[$636>>2] = $641;
 HEAP32[$639>>2] = $636;
 $642 = (($636) + 4|0);
 HEAP32[$642>>2] = $639;
 $643 = (($639) + 8|0);
 $644 = HEAP32[$643>>2]|0;
 $645 = (($644) + 1)|0;
 HEAP32[$643>>2] = $645;
 HEAP32[565584>>2] = 565608;
 HEAP32[((565584 + 12|0))>>2] = 100000;
 HEAP32[((565584 + 4|0))>>2] = 565560;
 HEAP32[((565584 + 8|0))>>2] = -1;
 HEAP32[((565584 + 16|0))>>2] = 1;
 $646 = HEAP32[563328>>2]|0;
 $647 = ($646|0)==(0|0);
 if ($647) {
  $648 = (__Znwj(12)|0);
  HEAP32[$648>>2] = $648;
  $649 = (($648) + 4|0);
  HEAP32[$649>>2] = $648;
  $650 = (($648) + 8|0);
  HEAP32[$650>>2] = 0;
  HEAP32[563328>>2] = $648;
  $654 = $648;
 } else {
  $654 = $646;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $651 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $652 = (($651) + 8|0);
 HEAP32[$652>>2] = 565584;
 $653 = HEAP32[$654>>2]|0;
 $655 = (($653) + 4|0);
 HEAP32[$655>>2] = $651;
 $656 = HEAP32[$654>>2]|0;
 HEAP32[$651>>2] = $656;
 HEAP32[$654>>2] = $651;
 $657 = (($651) + 4|0);
 HEAP32[$657>>2] = $654;
 $658 = (($654) + 8|0);
 $659 = HEAP32[$658>>2]|0;
 $660 = (($659) + 1)|0;
 HEAP32[$658>>2] = $660;
 HEAP32[565640>>2] = 565664;
 HEAP32[((565640 + 12|0))>>2] = 100000;
 HEAP32[((565640 + 4|0))>>2] = 565488;
 HEAP32[((565640 + 8|0))>>2] = -1;
 HEAP32[((565640 + 16|0))>>2] = 1;
 $661 = HEAP32[563328>>2]|0;
 $662 = ($661|0)==(0|0);
 if ($662) {
  $663 = (__Znwj(12)|0);
  HEAP32[$663>>2] = $663;
  $664 = (($663) + 4|0);
  HEAP32[$664>>2] = $663;
  $665 = (($663) + 8|0);
  HEAP32[$665>>2] = 0;
  HEAP32[563328>>2] = $663;
  $669 = $663;
 } else {
  $669 = $661;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $666 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $667 = (($666) + 8|0);
 HEAP32[$667>>2] = 565640;
 $668 = HEAP32[$669>>2]|0;
 $670 = (($668) + 4|0);
 HEAP32[$670>>2] = $666;
 $671 = HEAP32[$669>>2]|0;
 HEAP32[$666>>2] = $671;
 HEAP32[$669>>2] = $666;
 $672 = (($666) + 4|0);
 HEAP32[$672>>2] = $669;
 $673 = (($669) + 8|0);
 $674 = HEAP32[$673>>2]|0;
 $675 = (($674) + 1)|0;
 HEAP32[$673>>2] = $675;
 HEAP32[565696>>2] = 565720;
 HEAP32[((565696 + 12|0))>>2] = 100000;
 HEAP32[((565696 + 4|0))>>2] = 565744;
 HEAP32[((565696 + 8|0))>>2] = -1;
 HEAP32[((565696 + 16|0))>>2] = 1;
 $676 = HEAP32[563328>>2]|0;
 $677 = ($676|0)==(0|0);
 if ($677) {
  $678 = (__Znwj(12)|0);
  HEAP32[$678>>2] = $678;
  $679 = (($678) + 4|0);
  HEAP32[$679>>2] = $678;
  $680 = (($678) + 8|0);
  HEAP32[$680>>2] = 0;
  HEAP32[563328>>2] = $678;
  $684 = $678;
 } else {
  $684 = $676;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $681 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $682 = (($681) + 8|0);
 HEAP32[$682>>2] = 565696;
 $683 = HEAP32[$684>>2]|0;
 $685 = (($683) + 4|0);
 HEAP32[$685>>2] = $681;
 $686 = HEAP32[$684>>2]|0;
 HEAP32[$681>>2] = $686;
 HEAP32[$684>>2] = $681;
 $687 = (($681) + 4|0);
 HEAP32[$687>>2] = $684;
 $688 = (($684) + 8|0);
 $689 = HEAP32[$688>>2]|0;
 $690 = (($689) + 1)|0;
 HEAP32[$688>>2] = $690;
 HEAP32[565768>>2] = 565792;
 HEAP32[((565768 + 12|0))>>2] = 100000;
 HEAP32[((565768 + 4|0))>>2] = 0;
 HEAP32[((565768 + 8|0))>>2] = -1;
 HEAP32[((565768 + 16|0))>>2] = 1;
 $691 = HEAP32[563328>>2]|0;
 $692 = ($691|0)==(0|0);
 if ($692) {
  $693 = (__Znwj(12)|0);
  HEAP32[$693>>2] = $693;
  $694 = (($693) + 4|0);
  HEAP32[$694>>2] = $693;
  $695 = (($693) + 8|0);
  HEAP32[$695>>2] = 0;
  HEAP32[563328>>2] = $693;
  $699 = $693;
 } else {
  $699 = $691;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $696 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $697 = (($696) + 8|0);
 HEAP32[$697>>2] = 565768;
 $698 = HEAP32[$699>>2]|0;
 $700 = (($698) + 4|0);
 HEAP32[$700>>2] = $696;
 $701 = HEAP32[$699>>2]|0;
 HEAP32[$696>>2] = $701;
 HEAP32[$699>>2] = $696;
 $702 = (($696) + 4|0);
 HEAP32[$702>>2] = $699;
 $703 = (($699) + 8|0);
 $704 = HEAP32[$703>>2]|0;
 $705 = (($704) + 1)|0;
 HEAP32[$703>>2] = $705;
 HEAP32[565816>>2] = 565840;
 HEAP32[((565816 + 12|0))>>2] = 100001;
 HEAP32[((565816 + 4|0))>>2] = 0;
 HEAP32[((565816 + 8|0))>>2] = -1;
 HEAP32[((565816 + 16|0))>>2] = 1;
 $706 = HEAP32[563328>>2]|0;
 $707 = ($706|0)==(0|0);
 if ($707) {
  $708 = (__Znwj(12)|0);
  HEAP32[$708>>2] = $708;
  $709 = (($708) + 4|0);
  HEAP32[$709>>2] = $708;
  $710 = (($708) + 8|0);
  HEAP32[$710>>2] = 0;
  HEAP32[563328>>2] = $708;
  $714 = $708;
 } else {
  $714 = $706;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $711 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $712 = (($711) + 8|0);
 HEAP32[$712>>2] = 565816;
 $713 = HEAP32[$714>>2]|0;
 $715 = (($713) + 4|0);
 HEAP32[$715>>2] = $711;
 $716 = HEAP32[$714>>2]|0;
 HEAP32[$711>>2] = $716;
 HEAP32[$714>>2] = $711;
 $717 = (($711) + 4|0);
 HEAP32[$717>>2] = $714;
 $718 = (($714) + 8|0);
 $719 = HEAP32[$718>>2]|0;
 $720 = (($719) + 1)|0;
 HEAP32[$718>>2] = $720;
 HEAP32[565864>>2] = 565888;
 HEAP32[((565864 + 12|0))>>2] = 100001;
 HEAP32[((565864 + 4|0))>>2] = 0;
 HEAP32[((565864 + 8|0))>>2] = -1;
 HEAP32[((565864 + 16|0))>>2] = 1;
 $721 = HEAP32[563328>>2]|0;
 $722 = ($721|0)==(0|0);
 if ($722) {
  $723 = (__Znwj(12)|0);
  HEAP32[$723>>2] = $723;
  $724 = (($723) + 4|0);
  HEAP32[$724>>2] = $723;
  $725 = (($723) + 8|0);
  HEAP32[$725>>2] = 0;
  HEAP32[563328>>2] = $723;
  $729 = $723;
 } else {
  $729 = $721;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $726 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $727 = (($726) + 8|0);
 HEAP32[$727>>2] = 565864;
 $728 = HEAP32[$729>>2]|0;
 $730 = (($728) + 4|0);
 HEAP32[$730>>2] = $726;
 $731 = HEAP32[$729>>2]|0;
 HEAP32[$726>>2] = $731;
 HEAP32[$729>>2] = $726;
 $732 = (($726) + 4|0);
 HEAP32[$732>>2] = $729;
 $733 = (($729) + 8|0);
 $734 = HEAP32[$733>>2]|0;
 $735 = (($734) + 1)|0;
 HEAP32[$733>>2] = $735;
 HEAP32[565912>>2] = 565936;
 HEAP32[((565912 + 12|0))>>2] = 0;
 HEAP32[((565912 + 4|0))>>2] = 0;
 HEAP32[((565912 + 8|0))>>2] = -1;
 HEAP32[((565912 + 16|0))>>2] = 1;
 $736 = HEAP32[563328>>2]|0;
 $737 = ($736|0)==(0|0);
 if ($737) {
  $738 = (__Znwj(12)|0);
  HEAP32[$738>>2] = $738;
  $739 = (($738) + 4|0);
  HEAP32[$739>>2] = $738;
  $740 = (($738) + 8|0);
  HEAP32[$740>>2] = 0;
  HEAP32[563328>>2] = $738;
  $744 = $738;
 } else {
  $744 = $736;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $741 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $742 = (($741) + 8|0);
 HEAP32[$742>>2] = 565912;
 $743 = HEAP32[$744>>2]|0;
 $745 = (($743) + 4|0);
 HEAP32[$745>>2] = $741;
 $746 = HEAP32[$744>>2]|0;
 HEAP32[$741>>2] = $746;
 HEAP32[$744>>2] = $741;
 $747 = (($741) + 4|0);
 HEAP32[$747>>2] = $744;
 $748 = (($744) + 8|0);
 $749 = HEAP32[$748>>2]|0;
 $750 = (($749) + 1)|0;
 HEAP32[$748>>2] = $750;
 HEAP32[565960>>2] = 565984;
 HEAP32[((565960 + 12|0))>>2] = 100000;
 HEAP32[((565960 + 4|0))>>2] = 566008;
 HEAP32[((565960 + 8|0))>>2] = -1;
 HEAP32[((565960 + 16|0))>>2] = 1;
 $751 = HEAP32[563328>>2]|0;
 $752 = ($751|0)==(0|0);
 if ($752) {
  $753 = (__Znwj(12)|0);
  HEAP32[$753>>2] = $753;
  $754 = (($753) + 4|0);
  HEAP32[$754>>2] = $753;
  $755 = (($753) + 8|0);
  HEAP32[$755>>2] = 0;
  HEAP32[563328>>2] = $753;
  $759 = $753;
 } else {
  $759 = $751;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $756 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $757 = (($756) + 8|0);
 HEAP32[$757>>2] = 565960;
 $758 = HEAP32[$759>>2]|0;
 $760 = (($758) + 4|0);
 HEAP32[$760>>2] = $756;
 $761 = HEAP32[$759>>2]|0;
 HEAP32[$756>>2] = $761;
 HEAP32[$759>>2] = $756;
 $762 = (($756) + 4|0);
 HEAP32[$762>>2] = $759;
 $763 = (($759) + 8|0);
 $764 = HEAP32[$763>>2]|0;
 $765 = (($764) + 1)|0;
 HEAP32[$763>>2] = $765;
 HEAP32[566032>>2] = 566056;
 HEAP32[((566032 + 12|0))>>2] = 0;
 HEAP32[((566032 + 4|0))>>2] = 0;
 HEAP32[((566032 + 8|0))>>2] = -1;
 HEAP32[((566032 + 16|0))>>2] = 0;
 $766 = HEAP32[563328>>2]|0;
 $767 = ($766|0)==(0|0);
 if ($767) {
  $768 = (__Znwj(12)|0);
  HEAP32[$768>>2] = $768;
  $769 = (($768) + 4|0);
  HEAP32[$769>>2] = $768;
  $770 = (($768) + 8|0);
  HEAP32[$770>>2] = 0;
  HEAP32[563328>>2] = $768;
  $774 = $768;
 } else {
  $774 = $766;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $771 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $772 = (($771) + 8|0);
 HEAP32[$772>>2] = 566032;
 $773 = HEAP32[$774>>2]|0;
 $775 = (($773) + 4|0);
 HEAP32[$775>>2] = $771;
 $776 = HEAP32[$774>>2]|0;
 HEAP32[$771>>2] = $776;
 HEAP32[$774>>2] = $771;
 $777 = (($771) + 4|0);
 HEAP32[$777>>2] = $774;
 $778 = (($774) + 8|0);
 $779 = HEAP32[$778>>2]|0;
 $780 = (($779) + 1)|0;
 HEAP32[$778>>2] = $780;
 HEAP32[566088>>2] = 566112;
 HEAP32[((566088 + 12|0))>>2] = 0;
 HEAP32[((566088 + 4|0))>>2] = 0;
 HEAP32[((566088 + 8|0))>>2] = -1;
 HEAP32[((566088 + 16|0))>>2] = 0;
 $781 = HEAP32[563328>>2]|0;
 $782 = ($781|0)==(0|0);
 if ($782) {
  $783 = (__Znwj(12)|0);
  HEAP32[$783>>2] = $783;
  $784 = (($783) + 4|0);
  HEAP32[$784>>2] = $783;
  $785 = (($783) + 8|0);
  HEAP32[$785>>2] = 0;
  HEAP32[563328>>2] = $783;
  $789 = $783;
 } else {
  $789 = $781;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $786 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $787 = (($786) + 8|0);
 HEAP32[$787>>2] = 566088;
 $788 = HEAP32[$789>>2]|0;
 $790 = (($788) + 4|0);
 HEAP32[$790>>2] = $786;
 $791 = HEAP32[$789>>2]|0;
 HEAP32[$786>>2] = $791;
 HEAP32[$789>>2] = $786;
 $792 = (($786) + 4|0);
 HEAP32[$792>>2] = $789;
 $793 = (($789) + 8|0);
 $794 = HEAP32[$793>>2]|0;
 $795 = (($794) + 1)|0;
 HEAP32[$793>>2] = $795;
 HEAP32[566136>>2] = 566160;
 HEAP32[((566136 + 12|0))>>2] = 100005;
 HEAP32[((566136 + 4|0))>>2] = 0;
 HEAP32[((566136 + 8|0))>>2] = -1;
 HEAP32[((566136 + 16|0))>>2] = 4;
 $796 = HEAP32[563328>>2]|0;
 $797 = ($796|0)==(0|0);
 if ($797) {
  $798 = (__Znwj(12)|0);
  HEAP32[$798>>2] = $798;
  $799 = (($798) + 4|0);
  HEAP32[$799>>2] = $798;
  $800 = (($798) + 8|0);
  HEAP32[$800>>2] = 0;
  HEAP32[563328>>2] = $798;
  $804 = $798;
 } else {
  $804 = $796;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $801 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $802 = (($801) + 8|0);
 HEAP32[$802>>2] = 566136;
 $803 = HEAP32[$804>>2]|0;
 $805 = (($803) + 4|0);
 HEAP32[$805>>2] = $801;
 $806 = HEAP32[$804>>2]|0;
 HEAP32[$801>>2] = $806;
 HEAP32[$804>>2] = $801;
 $807 = (($801) + 4|0);
 HEAP32[$807>>2] = $804;
 $808 = (($804) + 8|0);
 $809 = HEAP32[$808>>2]|0;
 $810 = (($809) + 1)|0;
 HEAP32[$808>>2] = $810;
 HEAP32[566184>>2] = 566208;
 HEAP32[((566184 + 12|0))>>2] = 0;
 HEAP32[((566184 + 4|0))>>2] = 0;
 HEAP32[((566184 + 8|0))>>2] = -1;
 HEAP32[((566184 + 16|0))>>2] = 0;
 $811 = HEAP32[563328>>2]|0;
 $812 = ($811|0)==(0|0);
 if ($812) {
  $813 = (__Znwj(12)|0);
  HEAP32[$813>>2] = $813;
  $814 = (($813) + 4|0);
  HEAP32[$814>>2] = $813;
  $815 = (($813) + 8|0);
  HEAP32[$815>>2] = 0;
  HEAP32[563328>>2] = $813;
  $819 = $813;
 } else {
  $819 = $811;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $816 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $817 = (($816) + 8|0);
 HEAP32[$817>>2] = 566184;
 $818 = HEAP32[$819>>2]|0;
 $820 = (($818) + 4|0);
 HEAP32[$820>>2] = $816;
 $821 = HEAP32[$819>>2]|0;
 HEAP32[$816>>2] = $821;
 HEAP32[$819>>2] = $816;
 $822 = (($816) + 4|0);
 HEAP32[$822>>2] = $819;
 $823 = (($819) + 8|0);
 $824 = HEAP32[$823>>2]|0;
 $825 = (($824) + 1)|0;
 HEAP32[$823>>2] = $825;
 HEAP32[566232>>2] = 566256;
 HEAP32[((566232 + 12|0))>>2] = 0;
 HEAP32[((566232 + 4|0))>>2] = 0;
 HEAP32[((566232 + 8|0))>>2] = -1;
 HEAP32[((566232 + 16|0))>>2] = 1;
 $826 = HEAP32[563328>>2]|0;
 $827 = ($826|0)==(0|0);
 if ($827) {
  $828 = (__Znwj(12)|0);
  HEAP32[$828>>2] = $828;
  $829 = (($828) + 4|0);
  HEAP32[$829>>2] = $828;
  $830 = (($828) + 8|0);
  HEAP32[$830>>2] = 0;
  HEAP32[563328>>2] = $828;
  $834 = $828;
 } else {
  $834 = $826;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $831 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $832 = (($831) + 8|0);
 HEAP32[$832>>2] = 566232;
 $833 = HEAP32[$834>>2]|0;
 $835 = (($833) + 4|0);
 HEAP32[$835>>2] = $831;
 $836 = HEAP32[$834>>2]|0;
 HEAP32[$831>>2] = $836;
 HEAP32[$834>>2] = $831;
 $837 = (($831) + 4|0);
 HEAP32[$837>>2] = $834;
 $838 = (($834) + 8|0);
 $839 = HEAP32[$838>>2]|0;
 $840 = (($839) + 1)|0;
 HEAP32[$838>>2] = $840;
 HEAP32[566280>>2] = 566304;
 HEAP32[((566280 + 12|0))>>2] = 0;
 HEAP32[((566280 + 4|0))>>2] = 0;
 HEAP32[((566280 + 8|0))>>2] = -1;
 HEAP32[((566280 + 16|0))>>2] = 0;
 $841 = HEAP32[563328>>2]|0;
 $842 = ($841|0)==(0|0);
 if ($842) {
  $843 = (__Znwj(12)|0);
  HEAP32[$843>>2] = $843;
  $844 = (($843) + 4|0);
  HEAP32[$844>>2] = $843;
  $845 = (($843) + 8|0);
  HEAP32[$845>>2] = 0;
  HEAP32[563328>>2] = $843;
  $849 = $843;
 } else {
  $849 = $841;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $846 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $847 = (($846) + 8|0);
 HEAP32[$847>>2] = 566280;
 $848 = HEAP32[$849>>2]|0;
 $850 = (($848) + 4|0);
 HEAP32[$850>>2] = $846;
 $851 = HEAP32[$849>>2]|0;
 HEAP32[$846>>2] = $851;
 HEAP32[$849>>2] = $846;
 $852 = (($846) + 4|0);
 HEAP32[$852>>2] = $849;
 $853 = (($849) + 8|0);
 $854 = HEAP32[$853>>2]|0;
 $855 = (($854) + 1)|0;
 HEAP32[$853>>2] = $855;
 HEAP32[566328>>2] = 566352;
 HEAP32[((566328 + 12|0))>>2] = 100008;
 HEAP32[((566328 + 4|0))>>2] = 0;
 HEAP32[((566328 + 8|0))>>2] = -1;
 HEAP32[((566328 + 16|0))>>2] = 0;
 $856 = HEAP32[563328>>2]|0;
 $857 = ($856|0)==(0|0);
 if ($857) {
  $858 = (__Znwj(12)|0);
  HEAP32[$858>>2] = $858;
  $859 = (($858) + 4|0);
  HEAP32[$859>>2] = $858;
  $860 = (($858) + 8|0);
  HEAP32[$860>>2] = 0;
  HEAP32[563328>>2] = $858;
  $864 = $858;
 } else {
  $864 = $856;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $861 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $862 = (($861) + 8|0);
 HEAP32[$862>>2] = 566328;
 $863 = HEAP32[$864>>2]|0;
 $865 = (($863) + 4|0);
 HEAP32[$865>>2] = $861;
 $866 = HEAP32[$864>>2]|0;
 HEAP32[$861>>2] = $866;
 HEAP32[$864>>2] = $861;
 $867 = (($861) + 4|0);
 HEAP32[$867>>2] = $864;
 $868 = (($864) + 8|0);
 $869 = HEAP32[$868>>2]|0;
 $870 = (($869) + 1)|0;
 HEAP32[$868>>2] = $870;
 HEAP32[566376>>2] = 566400;
 HEAP32[((566376 + 12|0))>>2] = 100009;
 HEAP32[((566376 + 4|0))>>2] = 0;
 HEAP32[((566376 + 8|0))>>2] = -1;
 HEAP32[((566376 + 16|0))>>2] = 0;
 $871 = HEAP32[563328>>2]|0;
 $872 = ($871|0)==(0|0);
 if ($872) {
  $873 = (__Znwj(12)|0);
  HEAP32[$873>>2] = $873;
  $874 = (($873) + 4|0);
  HEAP32[$874>>2] = $873;
  $875 = (($873) + 8|0);
  HEAP32[$875>>2] = 0;
  HEAP32[563328>>2] = $873;
  $879 = $873;
 } else {
  $879 = $871;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $876 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $877 = (($876) + 8|0);
 HEAP32[$877>>2] = 566376;
 $878 = HEAP32[$879>>2]|0;
 $880 = (($878) + 4|0);
 HEAP32[$880>>2] = $876;
 $881 = HEAP32[$879>>2]|0;
 HEAP32[$876>>2] = $881;
 HEAP32[$879>>2] = $876;
 $882 = (($876) + 4|0);
 HEAP32[$882>>2] = $879;
 $883 = (($879) + 8|0);
 $884 = HEAP32[$883>>2]|0;
 $885 = (($884) + 1)|0;
 HEAP32[$883>>2] = $885;
 HEAP32[566424>>2] = 566448;
 HEAP32[((566424 + 12|0))>>2] = 100009;
 HEAP32[((566424 + 4|0))>>2] = 0;
 HEAP32[((566424 + 8|0))>>2] = -1;
 HEAP32[((566424 + 16|0))>>2] = 0;
 $886 = HEAP32[563328>>2]|0;
 $887 = ($886|0)==(0|0);
 if ($887) {
  $888 = (__Znwj(12)|0);
  HEAP32[$888>>2] = $888;
  $889 = (($888) + 4|0);
  HEAP32[$889>>2] = $888;
  $890 = (($888) + 8|0);
  HEAP32[$890>>2] = 0;
  HEAP32[563328>>2] = $888;
  $894 = $888;
 } else {
  $894 = $886;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $891 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $892 = (($891) + 8|0);
 HEAP32[$892>>2] = 566424;
 $893 = HEAP32[$894>>2]|0;
 $895 = (($893) + 4|0);
 HEAP32[$895>>2] = $891;
 $896 = HEAP32[$894>>2]|0;
 HEAP32[$891>>2] = $896;
 HEAP32[$894>>2] = $891;
 $897 = (($891) + 4|0);
 HEAP32[$897>>2] = $894;
 $898 = (($894) + 8|0);
 $899 = HEAP32[$898>>2]|0;
 $900 = (($899) + 1)|0;
 HEAP32[$898>>2] = $900;
 HEAP32[566472>>2] = 566496;
 HEAP32[((566472 + 12|0))>>2] = 100009;
 HEAP32[((566472 + 4|0))>>2] = 0;
 HEAP32[((566472 + 8|0))>>2] = -1;
 HEAP32[((566472 + 16|0))>>2] = 0;
 $901 = HEAP32[563328>>2]|0;
 $902 = ($901|0)==(0|0);
 if ($902) {
  $903 = (__Znwj(12)|0);
  HEAP32[$903>>2] = $903;
  $904 = (($903) + 4|0);
  HEAP32[$904>>2] = $903;
  $905 = (($903) + 8|0);
  HEAP32[$905>>2] = 0;
  HEAP32[563328>>2] = $903;
  $909 = $903;
 } else {
  $909 = $901;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $906 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $907 = (($906) + 8|0);
 HEAP32[$907>>2] = 566472;
 $908 = HEAP32[$909>>2]|0;
 $910 = (($908) + 4|0);
 HEAP32[$910>>2] = $906;
 $911 = HEAP32[$909>>2]|0;
 HEAP32[$906>>2] = $911;
 HEAP32[$909>>2] = $906;
 $912 = (($906) + 4|0);
 HEAP32[$912>>2] = $909;
 $913 = (($909) + 8|0);
 $914 = HEAP32[$913>>2]|0;
 $915 = (($914) + 1)|0;
 HEAP32[$913>>2] = $915;
 HEAP32[566536>>2] = 566560;
 HEAP32[((566536 + 12|0))>>2] = 100009;
 HEAP32[((566536 + 4|0))>>2] = 0;
 HEAP32[((566536 + 8|0))>>2] = -1;
 HEAP32[((566536 + 16|0))>>2] = 0;
 $916 = HEAP32[563328>>2]|0;
 $917 = ($916|0)==(0|0);
 if ($917) {
  $918 = (__Znwj(12)|0);
  HEAP32[$918>>2] = $918;
  $919 = (($918) + 4|0);
  HEAP32[$919>>2] = $918;
  $920 = (($918) + 8|0);
  HEAP32[$920>>2] = 0;
  HEAP32[563328>>2] = $918;
  $924 = $918;
 } else {
  $924 = $916;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $921 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $922 = (($921) + 8|0);
 HEAP32[$922>>2] = 566536;
 $923 = HEAP32[$924>>2]|0;
 $925 = (($923) + 4|0);
 HEAP32[$925>>2] = $921;
 $926 = HEAP32[$924>>2]|0;
 HEAP32[$921>>2] = $926;
 HEAP32[$924>>2] = $921;
 $927 = (($921) + 4|0);
 HEAP32[$927>>2] = $924;
 $928 = (($924) + 8|0);
 $929 = HEAP32[$928>>2]|0;
 $930 = (($929) + 1)|0;
 HEAP32[$928>>2] = $930;
 HEAP32[566600>>2] = 566624;
 HEAP32[((566600 + 12|0))>>2] = 1102;
 HEAP32[((566600 + 4|0))>>2] = 0;
 HEAP32[((566600 + 8|0))>>2] = -1;
 HEAP32[((566600 + 16|0))>>2] = 0;
 $931 = HEAP32[563328>>2]|0;
 $932 = ($931|0)==(0|0);
 if ($932) {
  $933 = (__Znwj(12)|0);
  HEAP32[$933>>2] = $933;
  $934 = (($933) + 4|0);
  HEAP32[$934>>2] = $933;
  $935 = (($933) + 8|0);
  HEAP32[$935>>2] = 0;
  HEAP32[563328>>2] = $933;
  $939 = $933;
 } else {
  $939 = $931;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $936 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $937 = (($936) + 8|0);
 HEAP32[$937>>2] = 566600;
 $938 = HEAP32[$939>>2]|0;
 $940 = (($938) + 4|0);
 HEAP32[$940>>2] = $936;
 $941 = HEAP32[$939>>2]|0;
 HEAP32[$936>>2] = $941;
 HEAP32[$939>>2] = $936;
 $942 = (($936) + 4|0);
 HEAP32[$942>>2] = $939;
 $943 = (($939) + 8|0);
 $944 = HEAP32[$943>>2]|0;
 $945 = (($944) + 1)|0;
 HEAP32[$943>>2] = $945;
 HEAP32[566648>>2] = 566672;
 HEAP32[((566648 + 12|0))>>2] = 1107;
 HEAP32[((566648 + 4|0))>>2] = 0;
 HEAP32[((566648 + 8|0))>>2] = -1;
 HEAP32[((566648 + 16|0))>>2] = 0;
 $946 = HEAP32[563328>>2]|0;
 $947 = ($946|0)==(0|0);
 if ($947) {
  $948 = (__Znwj(12)|0);
  HEAP32[$948>>2] = $948;
  $949 = (($948) + 4|0);
  HEAP32[$949>>2] = $948;
  $950 = (($948) + 8|0);
  HEAP32[$950>>2] = 0;
  HEAP32[563328>>2] = $948;
  $954 = $948;
 } else {
  $954 = $946;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $951 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $952 = (($951) + 8|0);
 HEAP32[$952>>2] = 566648;
 $953 = HEAP32[$954>>2]|0;
 $955 = (($953) + 4|0);
 HEAP32[$955>>2] = $951;
 $956 = HEAP32[$954>>2]|0;
 HEAP32[$951>>2] = $956;
 HEAP32[$954>>2] = $951;
 $957 = (($951) + 4|0);
 HEAP32[$957>>2] = $954;
 $958 = (($954) + 8|0);
 $959 = HEAP32[$958>>2]|0;
 $960 = (($959) + 1)|0;
 HEAP32[$958>>2] = $960;
 HEAP32[566696>>2] = 566720;
 HEAP32[((566696 + 12|0))>>2] = 0;
 HEAP32[((566696 + 4|0))>>2] = 0;
 HEAP32[((566696 + 8|0))>>2] = -1;
 HEAP32[((566696 + 16|0))>>2] = 1;
 $961 = HEAP32[563328>>2]|0;
 $962 = ($961|0)==(0|0);
 if ($962) {
  $963 = (__Znwj(12)|0);
  HEAP32[$963>>2] = $963;
  $964 = (($963) + 4|0);
  HEAP32[$964>>2] = $963;
  $965 = (($963) + 8|0);
  HEAP32[$965>>2] = 0;
  HEAP32[563328>>2] = $963;
  $969 = $963;
 } else {
  $969 = $961;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $966 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $967 = (($966) + 8|0);
 HEAP32[$967>>2] = 566696;
 $968 = HEAP32[$969>>2]|0;
 $970 = (($968) + 4|0);
 HEAP32[$970>>2] = $966;
 $971 = HEAP32[$969>>2]|0;
 HEAP32[$966>>2] = $971;
 HEAP32[$969>>2] = $966;
 $972 = (($966) + 4|0);
 HEAP32[$972>>2] = $969;
 $973 = (($969) + 8|0);
 $974 = HEAP32[$973>>2]|0;
 $975 = (($974) + 1)|0;
 HEAP32[$973>>2] = $975;
 HEAP32[566752>>2] = 566776;
 HEAP32[((566752 + 12|0))>>2] = 100000;
 HEAP32[((566752 + 4|0))>>2] = 0;
 HEAP32[((566752 + 8|0))>>2] = -1;
 HEAP32[((566752 + 16|0))>>2] = 1;
 $976 = HEAP32[563328>>2]|0;
 $977 = ($976|0)==(0|0);
 if ($977) {
  $978 = (__Znwj(12)|0);
  HEAP32[$978>>2] = $978;
  $979 = (($978) + 4|0);
  HEAP32[$979>>2] = $978;
  $980 = (($978) + 8|0);
  HEAP32[$980>>2] = 0;
  HEAP32[563328>>2] = $978;
  $984 = $978;
 } else {
  $984 = $976;
 }
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $981 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $982 = (($981) + 8|0);
 HEAP32[$982>>2] = 566752;
 $983 = HEAP32[$984>>2]|0;
 $985 = (($983) + 4|0);
 HEAP32[$985>>2] = $981;
 $986 = HEAP32[$984>>2]|0;
 HEAP32[$981>>2] = $986;
 HEAP32[$984>>2] = $981;
 $987 = (($981) + 4|0);
 HEAP32[$987>>2] = $984;
 $988 = (($984) + 8|0);
 $989 = HEAP32[$988>>2]|0;
 $990 = (($989) + 1)|0;
 HEAP32[$988>>2] = $990;
 HEAP32[566792>>2] = 566816;
 HEAP32[((566792 + 12|0))>>2] = 0;
 HEAP32[((566792 + 4|0))>>2] = 0;
 HEAP32[((566792 + 8|0))>>2] = -1;
 HEAP32[((566792 + 16|0))>>2] = 1;
 $991 = HEAP32[563328>>2]|0;
 $992 = ($991|0)==(0|0);
 if (!($992)) {
  $999 = $991;
  HEAP32[$0>>2] = 1;
  ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
  $996 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
  $997 = (($996) + 8|0);
  HEAP32[$997>>2] = 566792;
  $998 = HEAP32[$999>>2]|0;
  $1000 = (($998) + 4|0);
  HEAP32[$1000>>2] = $996;
  $1001 = HEAP32[$999>>2]|0;
  HEAP32[$996>>2] = $1001;
  HEAP32[$999>>2] = $996;
  $1002 = (($996) + 4|0);
  HEAP32[$1002>>2] = $999;
  $1003 = (($999) + 8|0);
  $1004 = HEAP32[$1003>>2]|0;
  $1005 = (($1004) + 1)|0;
  HEAP32[$1003>>2] = $1005;
  STACKTOP = sp;return;
 }
 $993 = (__Znwj(12)|0);
 HEAP32[$993>>2] = $993;
 $994 = (($993) + 4|0);
 HEAP32[$994>>2] = $993;
 $995 = (($993) + 8|0);
 HEAP32[$995>>2] = 0;
 HEAP32[563328>>2] = $993;
 $999 = $993;
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
 $996 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy66,0,563488,79)|0);
 $997 = (($996) + 8|0);
 HEAP32[$997>>2] = 566792;
 $998 = HEAP32[$999>>2]|0;
 $1000 = (($998) + 4|0);
 HEAP32[$1000>>2] = $996;
 $1001 = HEAP32[$999>>2]|0;
 HEAP32[$996>>2] = $1001;
 HEAP32[$999>>2] = $996;
 $1002 = (($996) + 4|0);
 HEAP32[$1002>>2] = $999;
 $1003 = (($999) + 8|0);
 $1004 = HEAP32[$1003>>2]|0;
 $1005 = (($1004) + 1)|0;
 HEAP32[$1003>>2] = $1005;
 STACKTOP = sp;return;
}
function __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN6ObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((566840 + 8|0));
 $2 = (($this) + 24|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_vi(3379,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 HEAP32[$this>>2] = ((560936 + 8|0));
 __THREW__ = 0;
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  __THREW__ = 0;
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   $eh$lpad$body$indexZ2D = $11;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  ___resumeException($5|0);
  // unreachable;
 }
 $17 = ___cxa_find_matching_catch(0|0)|0;
 $18 = tempRet0;
 $eh$lpad$body$indexZ2D = $17;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN11NamedObject15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11NamedObject7SetNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (_strcmp($2,$name)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__ZNK6Object14GetMemoryLabelEv($this)|0);
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN14ConstantString6assignEPKc10MemLabelId($1,$name,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z25RegisterClass_NamedObjectv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(130,84,0,0,0);
 STACKTOP = sp;return;
}
function __ZN11NamedObject13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(18)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN15EditorExtension13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 11;
 dest=$3+0|0; src=566944+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 11|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,130,18,($0|0),28,(2358|0),1,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN11NamedObject7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK11NamedObject25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 130;
}
function __ZN11NamedObject23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $p$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i$i = sp;
 $p$i$i$i$i$i$i = sp + 4|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,566960,566944,$this,0);
 $0 = (($this) + 24|0);
 $1 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,566968,$1,$0,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,566984,566984,$size$i$i$i$i$i$i$i,1);
 $2 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,566976,$2,$p$i$i$i$i$i$i,0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11NamedObject23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,566960,566944,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11NamedObject23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11NamedObject23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11NamedObject23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $tempStr$i$i$i$i$i = sp + 4|0;
 ;HEAP32[$tempStr$i$i$i$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i$i$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i$i$i$i+8>>2]=0|0;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 (invoke_iii(2353,($tempStr$i$i$i$i$i|0),($2|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viii(1624,($transfer|0),($tempStr$i$i$i$i$i|0),0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   invoke_vi(3378,($transfer|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP8[$tempStr$i$i$i$i$i>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     STACKTOP = sp;return;
    }
    $23 = (($tempStr$i$i$i$i$i) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($24|0),($$byval_copy1|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     ___cxa_call_unexpected(($27|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $7 = HEAP8[$tempStr$i$i$i$i$i>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  ___resumeException($5|0);
  // unreachable;
 }
 $10 = (($tempStr$i$i$i$i$i) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($11|0),($$byval_copy1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  ___cxa_call_unexpected(($14|0));
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN11NamedObject23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,566968,$1,$0,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,566984,566984,$size$i$i$i$i,1);
 $2 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,566976,$2,$p$i$i$i,0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $converter$i$i = 0, $tempStr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 24|0;
 $0 = sp;
 $tempStr$i = sp + 4|0;
 $1 = sp + 16|0;
 $converter$i$i = sp + 20|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[580712>>2]|0;
 $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,566968,$3,$converter$i$i,1)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ($4|0)>(0);
 do {
  if ($6) {
   ;HEAP32[$tempStr$i+0>>2]=0|0;HEAP32[$tempStr$i+4>>2]=0|0;HEAP32[$tempStr$i+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viii(1620,($transfer|0),($tempStr$i|0),0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $20 = HEAP8[$tempStr$i>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $25 = (($tempStr$i) + 1|0);
     $27 = $25;
    } else {
     $23 = (($tempStr$i) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $27 = $24;
    }
    $26 = HEAP32[628448>>2]|0;
    HEAP32[$1>>2] = $26;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viii(1621,($2|0),($27|0),($$byval_copy2|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = HEAP8[$tempStr$i>>0]|0;
     $31 = $30 & 1;
     $32 = ($31<<24>>24)==(0);
     if ($32) {
      break;
     }
     $33 = (($tempStr$i) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($34|0),($$byval_copy2|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      break;
     }
     $37 = ___cxa_find_matching_catch()|0;
     $38 = tempRet0;
     ___cxa_call_unexpected(($37|0));
     // unreachable;
    }
   }
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   $11 = HEAP8[$tempStr$i>>0]|0;
   $12 = $11 & 1;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    ___resumeException($9|0);
    // unreachable;
   }
   $14 = (($tempStr$i) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($15|0),($$byval_copy2|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   } else {
    ___resumeException($9|0);
    // unreachable;
   }
  } else {
   $39 = HEAP32[$converter$i$i>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    (FUNCTION_TABLE_iii[$39 & 4095]($2,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $1 = sp + 16|0;
 $2 = (($this) + 24|0);
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1622,($transfer|0),($tempStr$i$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3376,($transfer|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $18 = HEAP8[$tempStr$i$i>>0]|0;
   $19 = $18 & 1;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $23 = (($tempStr$i$i) + 1|0);
    $25 = $23;
   } else {
    $21 = (($tempStr$i$i) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $25 = $22;
   }
   $24 = HEAP32[628448>>2]|0;
   HEAP32[$1>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1621,($2|0),($25|0),($$byval_copy2|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP8[$tempStr$i$i>>0]|0;
    $29 = $28 & 1;
    $30 = ($29<<24>>24)==(0);
    if ($30) {
     STACKTOP = sp;return;
    }
    $31 = (($tempStr$i$i) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($32|0),($$byval_copy2|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $7 = HEAP8[$tempStr$i$i>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  ___resumeException($5|0);
  // unreachable;
 }
 $10 = (($tempStr$i$i) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($11|0),($$byval_copy2|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  ___cxa_call_unexpected(($14|0));
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $1 = sp + 16|0;
 $2 = (($this) + 24|0);
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1623,($transfer|0),($tempStr$i$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3377,($transfer|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $18 = HEAP8[$tempStr$i$i>>0]|0;
   $19 = $18 & 1;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $23 = (($tempStr$i$i) + 1|0);
    $25 = $23;
   } else {
    $21 = (($tempStr$i$i) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $25 = $22;
   }
   $24 = HEAP32[628448>>2]|0;
   HEAP32[$1>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1621,($2|0),($25|0),($$byval_copy2|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP8[$tempStr$i$i>>0]|0;
    $29 = $28 & 1;
    $30 = ($29<<24>>24)==(0);
    if ($30) {
     STACKTOP = sp;return;
    }
    $31 = (($tempStr$i$i) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($32|0),($$byval_copy2|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $7 = HEAP8[$tempStr$i$i>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  ___resumeException($5|0);
  // unreachable;
 }
 $10 = (($tempStr$i$i) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($11|0),($$byval_copy2|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  ___cxa_call_unexpected(($14|0));
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 (invoke_iii(2353,($tempStr$i$i|0),($2|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viii(1624,($transfer|0),($tempStr$i$i|0),0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   invoke_vi(3378,($transfer|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP8[$tempStr$i$i>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     STACKTOP = sp;return;
    }
    $23 = (($tempStr$i$i) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($24|0),($$byval_copy1|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     ___cxa_call_unexpected(($27|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $7 = HEAP8[$tempStr$i$i>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  ___resumeException($5|0);
  // unreachable;
 }
 $10 = (($tempStr$i$i) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($11|0),($$byval_copy1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  ___cxa_call_unexpected(($14|0));
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11NamedObjectD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((566840 + 8|0));
 $0 = (($this) + 24|0);
 __THREW__ = 0;
 invoke_vi(3382,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   STACKTOP = sp;return;
  }
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __THREW__ = 0;
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch(0|0)|0;
   $10 = tempRet0;
   ___clang_call_terminate($9);
   // unreachable;
  } else {
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 HEAP32[$this>>2] = ((560936 + 8|0));
 __THREW__ = 0;
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $17 = ___cxa_find_matching_catch(0|0)|0;
  $18 = tempRet0;
  __THREW__ = 0;
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $21 = ___cxa_find_matching_catch(0|0)|0;
   $22 = tempRet0;
   ___clang_call_terminate($21);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $17;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  ___resumeException($11|0);
  // unreachable;
 }
 $23 = ___cxa_find_matching_catch(0|0)|0;
 $24 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $23;
 ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
 // unreachable;
}
function __ZN11NamedObjectD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$indexZ2D = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((566840 + 8|0));
 $0 = (($this) + 24|0);
 __THREW__ = 0;
 invoke_vi(3382,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $17 = ___cxa_find_matching_catch(0|0)|0;
   $18 = tempRet0;
   __THREW__ = 0;
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch(0|0)|0;
    $22 = tempRet0;
    ___clang_call_terminate($21);
    // unreachable;
   } else {
    $eh$lpad$body$i$i$indexZ2D = $17;
    ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $eh$lpad$body$index8Z2D = $12;$eh$lpad$body$indexZ2D = $11;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $23 = ___cxa_find_matching_catch(0|0)|0;
  $24 = tempRet0;
  $eh$lpad$body$i$i$indexZ2D = $23;
  ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __THREW__ = 0;
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $9 = ___cxa_find_matching_catch(0|0)|0;
    $10 = tempRet0;
    ___clang_call_terminate($9);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $6;$eh$lpad$body$indexZ2D = $5;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  $eh$lpad$body$index8Z2D = $28;$eh$lpad$body$indexZ2D = $27;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNK11NamedObject7GetNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN10TagManagerC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy17 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy17 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $6;
 ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy17,$mode);
 HEAP32[$this>>2] = ((567008 + 8|0));
 $7 = (($this) + 40|0);
 $8 = (($this) + 424|0);
 $9 = (($this) + 424|0);
 $10 = (($this) + 428|0);
 _memset(($7|0),0,400)|0;
 $11 = HEAP32[628392>>2]|0;
 HEAP32[$2>>2] = $11;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$2+0>>2]|0;
 $12 = (invoke_iiiiiii(103,4,($$byval_copy17|0),1,16,(567120|0),27)|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  $15 = (($this) + 32|0);
  HEAP32[$15>>2] = $12;
  $16 = HEAP32[628392>>2]|0;
  HEAP32[$3>>2] = $16;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$3+0>>2]|0;
  $17 = (invoke_iiiiiii(103,12,($$byval_copy17|0),0,16,(567120|0),29)|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = (($17) + 4|0);
   HEAP32[$20>>2] = 0;
   $21 = (($17) + 8|0);
   HEAP32[$21>>2] = 0;
   HEAP32[$17>>2] = $20;
   $22 = (($this) + 24|0);
   HEAP32[$22>>2] = $17;
   $23 = HEAP32[628392>>2]|0;
   HEAP32[$4>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$4+0>>2]|0;
   $24 = (invoke_iiiiiii(103,12,($$byval_copy17|0),0,16,(567120|0),30)|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = (($24) + 4|0);
    HEAP32[$27>>2] = 0;
    $28 = (($24) + 8|0);
    HEAP32[$28>>2] = 0;
    HEAP32[$24>>2] = $27;
    $29 = (($this) + 28|0);
    HEAP32[$29>>2] = $24;
    $30 = HEAP32[628392>>2]|0;
    HEAP32[$5>>2] = $30;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$5+0>>2]|0;
    $31 = (invoke_iiiiiii(103,12,($$byval_copy17|0),0,16,(567120|0),31)|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     $34 = (($31) + 4|0);
     HEAP32[$34>>2] = 0;
     $35 = (($31) + 8|0);
     HEAP32[$35>>2] = 0;
     HEAP32[$31>>2] = $34;
     $36 = (($this) + 36|0);
     HEAP32[$36>>2] = $31;
     STACKTOP = sp;return;
    }
   }
  }
 }
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 $39 = HEAP32[$9>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  $58 = $8;
 } else {
  $41 = HEAP32[$10>>2]|0;
  $42 = ($41|0)==($39|0);
  do {
   if ($42) {
    $56 = $39;
   } else {
    $44 = $41;
    while(1) {
     $43 = (($44) + -20|0);
     HEAP32[$10>>2] = $43;
     $45 = HEAP8[$43>>0]|0;
     $46 = $45 & 1;
     $47 = ($46<<24>>24)==(0);
     if ($47) {
      $49 = $43;
     } else {
      $50 = (($44) + -12|0);
      $51 = HEAP32[$50>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($51|0),($$byval_copy17|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 13;
       break;
      }
      $$pre$i$i$i$i$i = HEAP32[$10>>2]|0;
      $49 = $$pre$i$i$i$i$i;
     }
     $48 = ($49|0)==($39|0);
     if ($48) {
      label = 14;
      break;
     } else {
      $44 = $49;
     }
    }
    if ((label|0) == 13) {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     ___cxa_call_unexpected(($54|0));
     // unreachable;
    }
    else if ((label|0) == 14) {
     $$pre$i$i$i = HEAP32[$9>>2]|0;
     $56 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($56);
  $58 = $8;
 }
 while(1) {
  $57 = (($58) + -12|0);
  $59 = HEAP8[$57>>0]|0;
  $60 = $59 & 1;
  $61 = ($60<<24>>24)==(0);
  if (!($61)) {
   $62 = (($58) + -4|0);
   $63 = HEAP32[$62>>2]|0;
   __ZdlPv($63);
  }
  $64 = ($57|0)==($7|0);
  if ($64) {
   break;
  } else {
   $58 = $57;
  }
 }
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $77 = ___cxa_find_matching_catch(0|0)|0;
  $78 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if ($80) {
   $83 = ___cxa_find_matching_catch(0|0)|0;
   $84 = tempRet0;
   __THREW__ = 0;
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    $87 = ___cxa_find_matching_catch(0|0)|0;
    $88 = tempRet0;
    ___clang_call_terminate($87);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $83;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $81 = __THREW__; __THREW__ = 0;
  $82 = $81&1;
  if (!($82)) {
   $eh$lpad$body$indexZ2D = $77;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
  $89 = ___cxa_find_matching_catch(0|0)|0;
  $90 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $89;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if ($68) {
   $69 = ___cxa_find_matching_catch(0|0)|0;
   $70 = tempRet0;
   __THREW__ = 0;
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch(0|0)|0;
    $74 = tempRet0;
    ___clang_call_terminate($73);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $69;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $75 = __THREW__; __THREW__ = 0;
  $76 = $75&1;
  if (!($76)) {
   ___resumeException($37|0);
   // unreachable;
  }
  $91 = ___cxa_find_matching_catch(0|0)|0;
  $92 = tempRet0;
  $eh$lpad$body$indexZ2D = $91;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __ZN10TagManager15ThreadedCleanupEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$017 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[628392>>2]|0;
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  $6 = (($3) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($3,$7);
 }
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy3);
 HEAP32[$2>>2] = 0;
 $8 = (($this) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[628392>>2]|0;
 $11 = ($9|0)==(0|0);
 if (!($11)) {
  $12 = (($9) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($9,$13);
 }
 HEAP32[$0>>2] = $10;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy3);
 HEAP32[$8>>2] = 0;
 $14 = (($this) + 36|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[628392>>2]|0;
 $17 = ($15|0)==(0|0);
 if (!($17)) {
  $18 = (($15) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($15,$19);
 }
 HEAP32[$0>>2] = $16;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($15,$$byval_copy3);
 HEAP32[$14>>2] = 0;
 $20 = (($1) + 8|0);
 $i$017 = 0;
 while(1) {
  $21 = ((($this) + (($i$017*12)|0)|0) + 40|0);
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
  __THREW__ = 0;
  (invoke_iii(2233,($21|0),($1|0))|0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   break;
  }
  $24 = HEAP8[$1>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if (!($26)) {
   $27 = HEAP32[$20>>2]|0;
   __ZdlPv($27);
  }
  $28 = (($i$017) + 1)|0;
  $29 = ($28|0)<(32);
  if ($29) {
   $i$017 = $28;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  $36 = (($this) + 32|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[628392>>2]|0;
  HEAP32[$0>>2] = $38;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy3);
  HEAP32[$36>>2] = 0;
  STACKTOP = sp;return;
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 $32 = HEAP8[$1>>0]|0;
 $33 = $32 & 1;
 $34 = ($33<<24>>24)==(0);
 if ($34) {
  ___resumeException($30|0);
  // unreachable;
 }
 $35 = HEAP32[$20>>2]|0;
 __ZdlPv($35);
 ___resumeException($30|0);
 // unreachable;
}
function __ZN10TagManager23AddDefaultLayerIfNeededEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $layer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy4 = sp + 52|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $layer = sp + 12|0;
 $3 = sp + 32|0;
 $4 = sp + 44|0;
 $5 = sp + 48|0;
 $6 = (($this) + 424|0);
 $7 = (($this) + 428|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$6>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 20)&-1;
 $14 = ($8|0)==($9|0);
 L1: do {
  if (!($14)) {
   $i$06 = 0;
   while(1) {
    $17 = ((($9) + (($i$06*20)|0)|0) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0);
    $16 = (($i$06) + 1)|0;
    if ($19) {
     break;
    }
    $15 = ($16|0)==($13|0);
    if ($15) {
     break L1;
    } else {
     $i$06 = $16;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 ;HEAP32[$layer+0>>2]=0|0;HEAP32[$layer+4>>2]=0|0;HEAP32[$layer+8>>2]=0|0;
 $20 = (($layer) + 12|0);
 HEAP32[$20>>2] = 1;
 $21 = (($layer) + 16|0);
 HEAP8[$21>>0] = 0;
 HEAP8[$3>>0] = 14;
 $22 = (($3) + 1|0);
 ;HEAP8[$22+0>>0]=HEAP8[567368+0>>0]|0;HEAP8[$22+1>>0]=HEAP8[567368+1>>0]|0;HEAP8[$22+2>>0]=HEAP8[567368+2>>0]|0;HEAP8[$22+3>>0]=HEAP8[567368+3>>0]|0;HEAP8[$22+4>>0]=HEAP8[567368+4>>0]|0;HEAP8[$22+5>>0]=HEAP8[567368+5>>0]|0;HEAP8[$22+6>>0]=HEAP8[567368+6>>0]|0;
 $23 = (($3) + 8|0);
 HEAP8[$23>>0] = 0;
 __THREW__ = 0;
 (invoke_iii(2359,($layer|0),($3|0))|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if ($25) {
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $51 = HEAP8[$3>>0]|0;
   $52 = $51 & 1;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    $$0 = $50;$$01 = $49;
   } else {
    $54 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($54|0),($$byval_copy4|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     $57 = ___cxa_find_matching_catch()|0;
     $58 = tempRet0;
     ___cxa_call_unexpected(($57|0));
     // unreachable;
    } else {
     $$0 = $50;$$01 = $49;
    }
   }
  } else {
   $26 = HEAP8[$3>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if (!($28)) {
    $29 = HEAP32[$23>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($29|0),($$byval_copy4|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     $32 = ___cxa_find_matching_catch()|0;
     $33 = tempRet0;
     ___cxa_call_unexpected(($32|0));
     // unreachable;
    }
   }
   HEAP32[$20>>2] = 0;
   $34 = HEAP32[$6>>2]|0;
   HEAP32[$4>>2] = $34;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viiii(331,($5|0),($6|0),($$byval_copy4|0),($layer|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $47 = ___cxa_find_matching_catch()|0;
    $48 = tempRet0;
    $$0 = $48;$$01 = $47;
    break;
   }
   $37 = (($this) + 436|0);
   HEAP32[$37>>2] = 0;
   $38 = HEAP8[$layer>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    STACKTOP = sp;return;
   }
   $41 = (($layer) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($42|0),($$byval_copy4|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $45 = ___cxa_find_matching_catch()|0;
    $46 = tempRet0;
    ___cxa_call_unexpected(($45|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $59 = HEAP8[$layer>>0]|0;
 $60 = $59 & 1;
 $61 = ($60<<24>>24)==(0);
 if ($61) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $62 = (($layer) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 HEAP32[$2>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($63|0),($$byval_copy4|0));
 $64 = __THREW__; __THREW__ = 0;
 $65 = $64&1;
 if ($65) {
  $66 = ___cxa_find_matching_catch()|0;
  $67 = tempRet0;
  ___cxa_call_unexpected(($66|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE6insertENS_11__wrap_iterIPKS1_EERS6_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i14 = 0, $$0$i15 = 0, $$byval_copy10 = 0, $$byval_copy15 = 0, $$pre = 0, $$pre11 = 0, $$pre12 = 0, $$pre7$i = 0, $$sum = 0, $$sum13 = 0, $$sum18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0 = 0, $__p$0$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $__t$i = 0, $__v = 0, $__xr$0 = 0;
 var $eh$lpad$body16$index4Z2D = 0, $eh$lpad$body16$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy15 = sp + 60|0;
 $$byval_copy10 = sp;
 $0 = sp + 4|0;
 $__t$i = sp + 8|0;
 $1 = sp + 28|0;
 $2 = sp + 32|0;
 $3 = sp + 36|0;
 $__v = sp + 40|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = HEAP32[$__position>>2]|0;
 $6 = $5;
 $7 = $4;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 20)&-1;
 $10 = (($4) + (($9*20)|0)|0);
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)<($14>>>0);
 if ($15) {
  $16 = ($10|0)==($12|0);
  if (!($16)) {
   $$sum = (($9) + 1)|0;
   $46 = (($4) + (($$sum*20)|0)|0);
   __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE12__move_rangeEPS1_S5_S5_($this,$10,$12,$46);
   $47 = ($10>>>0)>($__x>>>0);
   if ($47) {
    $__xr$0 = $__x;
   } else {
    $48 = HEAP32[$11>>2]|0;
    $49 = ($48>>>0)>($__x>>>0);
    $50 = (($__x) + 20|0);
    $$ = $49 ? $50 : $__x;
    $__xr$0 = $$;
   }
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($10,$__xr$0)|0);
   $51 = ((($4) + (($9*20)|0)|0) + 12|0);
   $52 = (($__xr$0) + 12|0);
   ;HEAP32[$51+0>>2]=HEAP32[$52+0>>2]|0;HEAP8[$51+4>>0]=HEAP8[$52+4>>0]|0;
   $__p$0 = $10;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $17 = ($10|0)==(0|0);
  if ($17) {
   $45 = 0;
  } else {
   $18 = HEAP8[$__x>>0]|0;
   $19 = $18 & 1;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $25 = (($__x) + 1|0);
    $26 = $18&255;
    $27 = $26 >>> 1;
    $29 = $27;$40 = $25;
   } else {
    $21 = (($__x) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($__x) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $29 = $24;$40 = $22;
   }
   $28 = ($29>>>0)>(2147483631);
   if ($28) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $30 = ($29>>>0)<(11);
   if ($30) {
    $31 = $29 << 1;
    $32 = $31&255;
    HEAP8[$10>>0] = $32;
    $33 = (($10) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $33;
   } else {
    $34 = (($29) + 16)|0;
    $35 = $34 & -16;
    HEAP32[$$byval_copy10>>2] = 59;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$$byval_copy10+0>>2]|0;
    $36 = (__Z15malloc_internaljj10MemLabelIdiPKci($35,16,$$byval_copy15,0,567120,79)|0);
    $37 = ((($4) + (($9*20)|0)|0) + 8|0);
    HEAP32[$37>>2] = $36;
    $38 = $35 | 1;
    HEAP32[$10>>2] = $38;
    $39 = ((($4) + (($9*20)|0)|0) + 4|0);
    HEAP32[$39>>2] = $29;
    $__p$0$i$i$i$i$i$i$i = $36;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($40|0),($29|0))|0;
   $41 = (($__p$0$i$i$i$i$i$i$i) + ($29)|0);
   HEAP8[$41>>0] = 0;
   $42 = ((($4) + (($9*20)|0)|0) + 12|0);
   $43 = (($__x) + 12|0);
   ;HEAP32[$42+0>>2]=HEAP32[$43+0>>2]|0;HEAP8[$42+4>>0]=HEAP8[$43+4>>0]|0;
   $$pre = HEAP32[$11>>2]|0;
   $45 = $$pre;
  }
  $44 = (($45) + 20|0);
  HEAP32[$11>>2] = $44;
  $__p$0 = $10;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $53 = (($this) + 8|0);
 $54 = $12;
 $55 = (($54) - ($7))|0;
 $56 = (($55|0) / 20)&-1;
 $57 = (($56) + 1)|0;
 $58 = ($57>>>0)>(214748364);
 if ($58) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $59 = $14;
 $60 = (($59) - ($7))|0;
 $61 = (($60|0) / 20)&-1;
 $62 = ($61>>>0)<(107374182);
 if ($62) {
  $66 = $61 << 1;
  $67 = ($66>>>0)<($57>>>0);
  $68 = $67 ? $57 : $66;
  $69 = (($8|0) / 20)&-1;
  $70 = (($__v) + 12|0);
  HEAP32[$70>>2] = 0;
  $71 = (($__v) + 16|0);
  HEAP32[$71>>2] = $53;
  $72 = ($68|0)==(0);
  if ($72) {
   $$0$i15 = 0;$75 = 0;$77 = $69;$81 = $70;
  } else {
   $$0$i14 = $68;$200 = $70;$201 = $69;
   label = 22;
  }
 } else {
  $63 = (($8|0) / 20)&-1;
  $64 = (($__v) + 12|0);
  HEAP32[$64>>2] = 0;
  $65 = (($__v) + 16|0);
  HEAP32[$65>>2] = $53;
  $$0$i14 = 214748364;$200 = $64;$201 = $63;
  label = 22;
 }
 if ((label|0) == 22) {
  $73 = ($$0$i14*20)|0;
  $74 = (__Znwj($73)|0);
  $$0$i15 = $$0$i14;$75 = $74;$77 = $201;$81 = $200;
 }
 HEAP32[$__v>>2] = $75;
 $76 = (($75) + (($77*20)|0)|0);
 $78 = (($__v) + 8|0);
 HEAP32[$78>>2] = $76;
 $79 = (($__v) + 4|0);
 HEAP32[$79>>2] = $76;
 $80 = (($75) + (($$0$i15*20)|0)|0);
 HEAP32[$81>>2] = $80;
 $82 = ($77|0)==($$0$i15|0);
 do {
  if ($82) {
   $83 = ($8|0)>(0);
   $84 = (($8|0) / 20)&-1;
   if ($83) {
    $85 = (($84) + 1)|0;
    $86 = (($85|0) / -2)&-1;
    $$sum13 = (($77) + ($86))|0;
    $87 = (($75) + (($$sum13*20)|0)|0);
    HEAP32[$78>>2] = $87;
    $$sum18 = (($77) + ($86))|0;
    $88 = (($75) + (($$sum18*20)|0)|0);
    HEAP32[$79>>2] = $88;
    $130 = $87;
    label = 38;
    break;
   }
   $89 = $84 << 1;
   $90 = ($89|0)==(0);
   $91 = $90 ? 1 : $89;
   $92 = (($__t$i) + 12|0);
   $93 = (($__t$i) + 16|0);
   HEAP32[$93>>2] = $53;
   $94 = ($91*20)|0;
   __THREW__ = 0;
   $95 = (invoke_ii(2988,($94|0))|0);
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    label = 59;
   } else {
    $98 = $91 >>> 2;
    HEAP32[$__t$i>>2] = $95;
    $99 = (($95) + (($98*20)|0)|0);
    $100 = (($__t$i) + 8|0);
    HEAP32[$100>>2] = $99;
    $101 = (($__t$i) + 4|0);
    HEAP32[$101>>2] = $99;
    $102 = (($95) + (($91*20)|0)|0);
    HEAP32[$92>>2] = $102;
    HEAP32[$1>>2] = $76;
    HEAP32[$2>>2] = $76;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viii(1634,($__t$i|0),($$byval_copy10|0),($$byval_copy15|0));
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if (!($104)) {
     $105 = HEAP32[$__t$i>>2]|0;
     HEAP32[$__v>>2] = $105;
     HEAP32[$__t$i>>2] = $75;
     $106 = HEAP32[$101>>2]|0;
     HEAP32[$79>>2] = $106;
     HEAP32[$101>>2] = $76;
     $107 = HEAP32[$100>>2]|0;
     HEAP32[$78>>2] = $107;
     HEAP32[$100>>2] = $76;
     $108 = HEAP32[$92>>2]|0;
     HEAP32[$81>>2] = $108;
     HEAP32[$92>>2] = $76;
     $109 = ($75|0)==(0|0);
     if ($109) {
      $130 = $107;
      label = 38;
      break;
     }
     __ZdlPv($75);
     $130 = $107;
     label = 38;
     break;
    }
    $110 = ___cxa_find_matching_catch()|0;
    $111 = tempRet0;
    $112 = HEAP32[$101>>2]|0;
    $113 = HEAP32[$100>>2]|0;
    $114 = ($113|0)==($112|0);
    L45: do {
     if (!($114)) {
      $116 = $113;
      while(1) {
       $115 = (($116) + -20|0);
       HEAP32[$100>>2] = $115;
       $117 = HEAP8[$115>>0]|0;
       $118 = $117 & 1;
       $119 = ($118<<24>>24)==(0);
       if (!($119)) {
        $121 = (($116) + -12|0);
        $122 = HEAP32[$121>>2]|0;
        HEAP32[$$byval_copy10>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$$byval_copy10+0>>2]|0;
        invoke_vii(2591,($122|0),($$byval_copy15|0));
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if ($124) {
         break;
        }
       }
       $120 = ($115|0)==($112|0);
       if ($120) {
        break L45;
       } else {
        $116 = $115;
       }
      }
      $125 = ___cxa_find_matching_catch()|0;
      $126 = tempRet0;
      ___cxa_call_unexpected(($125|0));
      // unreachable;
     }
    } while(0);
    $127 = HEAP32[$__t$i>>2]|0;
    $128 = ($127|0)==(0|0);
    if ($128) {
     $eh$lpad$body16$index4Z2D = $111;$eh$lpad$body16$indexZ2D = $110;
    } else {
     __ZdlPv($127);
     $eh$lpad$body16$index4Z2D = $111;$eh$lpad$body16$indexZ2D = $110;
    }
   }
  } else {
   $130 = $76;
   label = 38;
  }
 } while(0);
 do {
  if ((label|0) == 38) {
   $129 = ($130|0)==(0|0);
   if ($129) {
    $162 = 0;
   } else {
    $131 = HEAP8[$__x>>0]|0;
    $132 = $131 & 1;
    $133 = ($132<<24>>24)==(0);
    if ($133) {
     $138 = (($__x) + 1|0);
     $139 = $131&255;
     $140 = $139 >>> 1;
     $142 = $140;$157 = $138;
    } else {
     $134 = (($__x) + 8|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = (($__x) + 4|0);
     $137 = HEAP32[$136>>2]|0;
     $142 = $137;$157 = $135;
    }
    $141 = ($142>>>0)>(2147483631);
    if ($141) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if ($144) {
      label = 59;
      break;
     }
     // unreachable;
    }
    $145 = ($142>>>0)<(11);
    if ($145) {
     $146 = $142 << 1;
     $147 = $146&255;
     HEAP8[$130>>0] = $147;
     $148 = (($130) + 1|0);
     $__p$0$i$i$i$i$i$i$i$i = $148;
    } else {
     $149 = (($142) + 16)|0;
     $150 = $149 & -16;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
     $151 = (invoke_iiiiiii(102,($150|0),16,($$byval_copy15|0),0,(567120|0),79)|0);
     $152 = __THREW__; __THREW__ = 0;
     $153 = $152&1;
     if ($153) {
      label = 59;
      break;
     }
     $154 = (($130) + 8|0);
     HEAP32[$154>>2] = $151;
     $155 = $150 | 1;
     HEAP32[$130>>2] = $155;
     $156 = (($130) + 4|0);
     HEAP32[$156>>2] = $142;
     $__p$0$i$i$i$i$i$i$i$i = $151;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($157|0),($142|0))|0;
    $158 = (($__p$0$i$i$i$i$i$i$i$i) + ($142)|0);
    HEAP8[$158>>0] = 0;
    $159 = (($130) + 12|0);
    $160 = (($__x) + 12|0);
    ;HEAP32[$159+0>>2]=HEAP32[$160+0>>2]|0;HEAP8[$159+4>>0]=HEAP8[$160+4>>0]|0;
    $$pre7$i = HEAP32[$78>>2]|0;
    $162 = $$pre7$i;
   }
   $161 = (($162) + 20|0);
   HEAP32[$78>>2] = $161;
   __THREW__ = 0;
   $163 = (invoke_iiii(1531,($this|0),($__v|0),($10|0))|0);
   $164 = __THREW__; __THREW__ = 0;
   $165 = $164&1;
   if ($165) {
    label = 59;
   } else {
    $166 = HEAP32[$79>>2]|0;
    $167 = HEAP32[$78>>2]|0;
    $168 = ($167|0)==($166|0);
    L74: do {
     if (!($168)) {
      $170 = $167;
      while(1) {
       $169 = (($170) + -20|0);
       HEAP32[$78>>2] = $169;
       $171 = HEAP8[$169>>0]|0;
       $172 = $171 & 1;
       $173 = ($172<<24>>24)==(0);
       if (!($173)) {
        $175 = (($170) + -12|0);
        $176 = HEAP32[$175>>2]|0;
        HEAP32[$$byval_copy10>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$$byval_copy10+0>>2]|0;
        invoke_vii(2591,($176|0),($$byval_copy15|0));
        $177 = __THREW__; __THREW__ = 0;
        $178 = $177&1;
        if ($178) {
         break;
        }
       }
       $174 = ($169|0)==($166|0);
       if ($174) {
        break L74;
       } else {
        $170 = $169;
       }
      }
      $179 = ___cxa_find_matching_catch()|0;
      $180 = tempRet0;
      ___cxa_call_unexpected(($179|0));
      // unreachable;
     }
    } while(0);
    $181 = HEAP32[$__v>>2]|0;
    $182 = ($181|0)==(0|0);
    if ($182) {
     $__p$0 = $163;
     HEAP32[$agg$result>>2] = $__p$0;
     STACKTOP = sp;return;
    }
    __ZdlPv($181);
    $__p$0 = $163;
    HEAP32[$agg$result>>2] = $__p$0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 L87: do {
  if ((label|0) == 59) {
   $183 = ___cxa_find_matching_catch()|0;
   $184 = tempRet0;
   $$pre11 = HEAP32[$79>>2]|0;
   $$pre12 = HEAP32[$78>>2]|0;
   $185 = ($$pre12|0)==($$pre11|0);
   if ($185) {
    $eh$lpad$body16$index4Z2D = $184;$eh$lpad$body16$indexZ2D = $183;
   } else {
    $187 = $$pre12;
    while(1) {
     $186 = (($187) + -20|0);
     HEAP32[$78>>2] = $186;
     $188 = HEAP8[$186>>0]|0;
     $189 = $188 & 1;
     $190 = ($189<<24>>24)==(0);
     if (!($190)) {
      $192 = (($187) + -12|0);
      $193 = HEAP32[$192>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($193|0),($$byval_copy15|0));
      $194 = __THREW__; __THREW__ = 0;
      $195 = $194&1;
      if ($195) {
       break;
      }
     }
     $191 = ($186|0)==($$pre11|0);
     if ($191) {
      $eh$lpad$body16$index4Z2D = $184;$eh$lpad$body16$indexZ2D = $183;
      break L87;
     } else {
      $187 = $186;
     }
    }
    $196 = ___cxa_find_matching_catch()|0;
    $197 = tempRet0;
    ___cxa_call_unexpected(($196|0));
    // unreachable;
   }
  }
 } while(0);
 $198 = HEAP32[$__v>>2]|0;
 $199 = ($198|0)==(0|0);
 if ($199) {
  ___resumeException($eh$lpad$body16$indexZ2D|0);
  // unreachable;
 }
 __ZdlPv($198);
 ___resumeException($eh$lpad$body16$indexZ2D|0);
 // unreachable;
}
function __ZN10TagManager11RegisterTagEjRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$tag,$name) {
 $this = $this|0;
 $tag = $tag|0;
 $name = $name|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$5 = 0, $$56 = 0, $$6 = 0, $$67 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$phi64Z2D = 0, $$pre$phi66Z2D = 0, $$pre$phi68Z2D = 0, $$pre$phi70Z2D = 0;
 var $$pre$phi72Z2D = 0, $$pre$phiZ2D = 0, $$pre57 = 0, $$pre59 = 0, $$pre61 = 0, $$pre62$pre$phiZZ2D = 0, $$pre63$pre$phiZZ2D = 0, $$pre65$pre$phiZZ2D = 0, $$pre67$pre$phiZZ2D = 0, $$pre69$pre$phiZZ2D = 0, $$pre71$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i38 = 0, $__p$0$i$i$i$i$i$i28 = 0, $__p$0$i$i$i$i$i33 = 0, $__p$0$i$i$i24 = 0, $__parent$i$i = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body43$index10Z2D = 0, $eh$lpad$body43$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $0 = sp + 184|0;
 $1 = sp + 168|0;
 $__parent$i$i = sp + 164|0;
 $2 = sp + 152|0;
 $3 = sp + 136|0;
 $4 = sp + 120|0;
 $5 = sp + 104|0;
 $6 = sp + 92|0;
 $7 = sp + 68|0;
 $8 = sp + 56|0;
 $9 = sp + 40|0;
 $10 = sp + 24|0;
 $11 = sp + 12|0;
 $12 = sp;
 $13 = sp + 80|0;
 $14 = HEAP8[$name>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $19 = $14&255;
  $20 = $19 >>> 1;
  $22 = $20;
 } else {
  $17 = (($name) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $22 = $18;
 }
 $21 = ($22|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $23 = (($this) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 if ($16) {
  ;HEAP32[$6+0>>2]=HEAP32[$name+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$name+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$name+8>>2]|0;
  $$pre = HEAP8[$6>>0]|0;
  $$pre$phiZ2D = $6;$43 = $$pre;
 } else {
  $25 = (($name) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($name) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28>>>0)>(4294967279);
  if ($29) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $30 = ($28>>>0)<(11);
  if ($30) {
   $31 = $28 << 1;
   $32 = $31&255;
   HEAP8[$6>>0] = $32;
   $33 = (($6) + 1|0);
   $$pre62$pre$phiZZ2D = $6;$406 = $32;$__p$0$i$i$i = $33;
  } else {
   $34 = (($28) + 16)|0;
   $35 = $34 & -16;
   $36 = (__Znwj($35)|0);
   $37 = (($6) + 8|0);
   HEAP32[$37>>2] = $36;
   $38 = $35 | 1;
   HEAP32[$6>>2] = $38;
   $39 = (($6) + 4|0);
   HEAP32[$39>>2] = $28;
   $40 = $38&255;
   $$pre62$pre$phiZZ2D = $6;$406 = $40;$__p$0$i$i$i = $36;
  }
  _memcpy(($__p$0$i$i$i|0),($26|0),($28|0))|0;
  $41 = (($__p$0$i$i$i) + ($28)|0);
  HEAP8[$41>>0] = 0;
  $$pre$phiZ2D = $$pre62$pre$phiZZ2D;$43 = $406;
 }
 $42 = $43 & 1;
 $44 = ($42<<24>>24)==(0);
 L19: do {
  if ($44) {
   ;HEAP32[$5+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
   $$pre57 = HEAP8[$5>>0]|0;
   $$pre$phi64Z2D = $5;$68 = $$pre57;
   label = 23;
  } else {
   $45 = (($6) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($6) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48>>>0)>(4294967279);
   do {
    if ($49) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if (!($51)) {
      // unreachable;
     }
    } else {
     $52 = ($48>>>0)<(11);
     if ($52) {
      $53 = $48 << 1;
      $54 = $53&255;
      HEAP8[$5>>0] = $54;
      $55 = (($5) + 1|0);
      $$pre63$pre$phiZZ2D = $5;$407 = $54;$__p$0$i$i$i$i$i$i = $55;
     } else {
      $56 = (($48) + 16)|0;
      $57 = $56 & -16;
      __THREW__ = 0;
      $58 = (invoke_ii(2988,($57|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
      $61 = (($5) + 8|0);
      HEAP32[$61>>2] = $58;
      $62 = $57 | 1;
      HEAP32[$5>>2] = $62;
      $63 = (($5) + 4|0);
      HEAP32[$63>>2] = $48;
      $64 = $62&255;
      $$pre63$pre$phiZZ2D = $5;$407 = $64;$__p$0$i$i$i$i$i$i = $58;
     }
     _memcpy(($__p$0$i$i$i$i$i$i|0),($46|0),($48|0))|0;
     $65 = (($__p$0$i$i$i$i$i$i) + ($48)|0);
     HEAP8[$65>>0] = 0;
     $$pre$phi64Z2D = $$pre63$pre$phiZZ2D;$68 = $407;
     label = 23;
     break L19;
    }
   } while(0);
   $197 = ___cxa_find_matching_catch()|0;
   $198 = tempRet0;
   $$1 = $198;$$12 = $197;
  }
 } while(0);
 if ((label|0) == 23) {
  $66 = (($5) + 12|0);
  HEAP32[$66>>2] = $tag;
  $67 = $68 & 1;
  $69 = ($67<<24>>24)==(0);
  L34: do {
   if ($69) {
    ;HEAP32[$4+0>>2]=HEAP32[$$pre$phi64Z2D+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$$pre$phi64Z2D+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$$pre$phi64Z2D+8>>2]|0;
    $$pre59 = HEAP8[$4>>0]|0;
    $$pre$phi66Z2D = $4;$93 = $$pre59;
    label = 33;
   } else {
    $70 = (($5) + 8|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($5) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73>>>0)>(4294967279);
    do {
     if ($74) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if (!($76)) {
       // unreachable;
      }
     } else {
      $77 = ($73>>>0)<(11);
      if ($77) {
       $78 = $73 << 1;
       $79 = $78&255;
       HEAP8[$4>>0] = $79;
       $80 = (($4) + 1|0);
       $$pre65$pre$phiZZ2D = $4;$408 = $79;$__p$0$i$i$i$i$i = $80;
      } else {
       $81 = (($73) + 16)|0;
       $82 = $81 & -16;
       __THREW__ = 0;
       $83 = (invoke_ii(2988,($82|0))|0);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       $86 = (($4) + 8|0);
       HEAP32[$86>>2] = $83;
       $87 = $82 | 1;
       HEAP32[$4>>2] = $87;
       $88 = (($4) + 4|0);
       HEAP32[$88>>2] = $73;
       $89 = $87&255;
       $$pre65$pre$phiZZ2D = $4;$408 = $89;$__p$0$i$i$i$i$i = $83;
      }
      _memcpy(($__p$0$i$i$i$i$i|0),($71|0),($73|0))|0;
      $90 = (($__p$0$i$i$i$i$i) + ($73)|0);
      HEAP8[$90>>0] = 0;
      $$pre$phi66Z2D = $$pre65$pre$phiZZ2D;$93 = $408;
      label = 33;
      break L34;
     }
    } while(0);
    $199 = ___cxa_find_matching_catch()|0;
    $200 = tempRet0;
    $$0 = $200;$$01 = $199;
   }
  } while(0);
  if ((label|0) == 33) {
   $91 = (($4) + 12|0);
   HEAP32[$91>>2] = $tag;
   $92 = $93 & 1;
   $94 = ($92<<24>>24)==(0);
   L49: do {
    if ($94) {
     ;HEAP32[$3+0>>2]=HEAP32[$$pre$phi66Z2D+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$$pre$phi66Z2D+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$$pre$phi66Z2D+8>>2]|0;
     label = 43;
    } else {
     $95 = (($4) + 8|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($4) + 4|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = ($98>>>0)>(4294967279);
     do {
      if ($99) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if (!($101)) {
        // unreachable;
       }
      } else {
       $102 = ($98>>>0)<(11);
       if ($102) {
        $103 = $98 << 1;
        $104 = $103&255;
        HEAP8[$3>>0] = $104;
        $105 = (($3) + 1|0);
        $__p$0$i$i$i$i$i$i$i$i = $105;
       } else {
        $106 = (($98) + 16)|0;
        $107 = $106 & -16;
        __THREW__ = 0;
        $108 = (invoke_ii(2988,($107|0))|0);
        $109 = __THREW__; __THREW__ = 0;
        $110 = $109&1;
        if ($110) {
         break;
        }
        $111 = (($3) + 8|0);
        HEAP32[$111>>2] = $108;
        $112 = $107 | 1;
        HEAP32[$3>>2] = $112;
        $113 = (($3) + 4|0);
        HEAP32[$113>>2] = $98;
        $__p$0$i$i$i$i$i$i$i$i = $108;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($96|0),($98|0))|0;
       $114 = (($__p$0$i$i$i$i$i$i$i$i) + ($98)|0);
       HEAP8[$114>>0] = 0;
       label = 43;
       break L49;
      }
     } while(0);
     $201 = ___cxa_find_matching_catch()|0;
     $202 = tempRet0;
     $eh$lpad$body$index3Z2D = $202;$eh$lpad$body$indexZ2D = $201;
    }
   } while(0);
   do {
    if ((label|0) == 43) {
     $115 = (($3) + 12|0);
     HEAP32[$115>>2] = $tag;
     $116 = (__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE12__find_equalIS8_EERPNS_16__tree_node_baseIPvEESM_RKT_($24,$__parent$i$i,$3)|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ($117|0)==(0|0);
     if ($118) {
      __THREW__ = 0;
      invoke_viii(1635,($2|0),($24|0),($3|0));
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       $139 = ___cxa_find_matching_catch()|0;
       $140 = tempRet0;
       $141 = HEAP8[$3>>0]|0;
       $142 = $141 & 1;
       $143 = ($142<<24>>24)==(0);
       if ($143) {
        $eh$lpad$body$index3Z2D = $140;$eh$lpad$body$indexZ2D = $139;
        break;
       }
       $144 = (($3) + 8|0);
       $145 = HEAP32[$144>>2]|0;
       __ZdlPv($145);
       $eh$lpad$body$index3Z2D = $140;$eh$lpad$body$indexZ2D = $139;
       break;
      }
      $121 = HEAP32[$2>>2]|0;
      HEAP32[$2>>2] = 0;
      $122 = HEAP32[$__parent$i$i>>2]|0;
      HEAP32[$121>>2] = 0;
      $123 = (($121) + 4|0);
      HEAP32[$123>>2] = 0;
      $124 = (($121) + 8|0);
      HEAP32[$124>>2] = $122;
      HEAP32[$116>>2] = $121;
      $125 = HEAP32[$24>>2]|0;
      $126 = HEAP32[$125>>2]|0;
      $127 = ($126|0)==(0|0);
      if ($127) {
       $130 = $121;
      } else {
       HEAP32[$24>>2] = $126;
       $$pre$i$i$i = HEAP32[$116>>2]|0;
       $130 = $$pre$i$i$i;
      }
      $128 = (($24) + 4|0);
      $129 = HEAP32[$128>>2]|0;
      __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($129,$130);
      $131 = (($24) + 8|0);
      $132 = HEAP32[$131>>2]|0;
      $133 = (($132) + 1)|0;
      HEAP32[$131>>2] = $133;
      $147 = 1;
     } else {
      $147 = 0;
     }
     $134 = HEAP8[$3>>0]|0;
     $135 = $134 & 1;
     $136 = ($135<<24>>24)==(0);
     if (!($136)) {
      $137 = (($3) + 8|0);
      $138 = HEAP32[$137>>2]|0;
      __ZdlPv($138);
     }
     $146 = ($147<<24>>24)==(0);
     if ($146) {
      $148 = HEAP8[$name>>0]|0;
      $149 = $148 & 1;
      $150 = ($149<<24>>24)==(0);
      if ($150) {
       $153 = $148&255;
       $154 = $153 >>> 1;
       $156 = $154;
      } else {
       $151 = (($name) + 4|0);
       $152 = HEAP32[$151>>2]|0;
       $156 = $152;
      }
      $155 = ($156|0)!=(0);
      $409 = $155;
     } else {
      $409 = 0;
     }
     $157 = HEAP8[$$pre$phi66Z2D>>0]|0;
     $158 = $157 & 1;
     $159 = ($158<<24>>24)==(0);
     if (!($159)) {
      $160 = (($4) + 8|0);
      $161 = HEAP32[$160>>2]|0;
      __ZdlPv($161);
     }
     $162 = HEAP8[$$pre$phi64Z2D>>0]|0;
     $163 = $162 & 1;
     $164 = ($163<<24>>24)==(0);
     if (!($164)) {
      $165 = (($5) + 8|0);
      $166 = HEAP32[$165>>2]|0;
      __ZdlPv($166);
     }
     $167 = HEAP8[$$pre$phiZ2D>>0]|0;
     $168 = $167 & 1;
     $169 = ($168<<24>>24)==(0);
     if (!($169)) {
      $170 = (($6) + 8|0);
      $171 = HEAP32[$170>>2]|0;
      __ZdlPv($171);
     }
     L93: do {
      if ($409) {
       __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($8,567128,$name);
       __THREW__ = 0;
       invoke_viii(1627,($7|0),($8|0),(567160|0));
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       do {
        if ($173) {
         $218 = ___cxa_find_matching_catch()|0;
         $219 = tempRet0;
         $$2 = $219;$$23 = $218;
        } else {
         $174 = ($this|0)==(0|0);
         if ($174) {
          $184 = 0;
         } else {
          $175 = (($this) + 4|0);
          $176 = HEAP32[$175>>2]|0;
          $184 = $176;
         }
         $177 = HEAP8[$7>>0]|0;
         $178 = $177 & 1;
         $179 = ($178<<24>>24)==(0);
         if ($179) {
          $182 = (($7) + 1|0);
          $183 = $182;
         } else {
          $180 = (($7) + 8|0);
          $181 = HEAP32[$180>>2]|0;
          $183 = $181;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,($183|0),0,(567120|0),83,4,($184|0),0,(0|0));
         $185 = __THREW__; __THREW__ = 0;
         $186 = $185&1;
         if ($186) {
          $220 = ___cxa_find_matching_catch()|0;
          $221 = tempRet0;
          $222 = HEAP8[$7>>0]|0;
          $223 = $222 & 1;
          $224 = ($223<<24>>24)==(0);
          if ($224) {
           $$2 = $221;$$23 = $220;
           break;
          }
          $225 = (($7) + 8|0);
          $226 = HEAP32[$225>>2]|0;
          __ZdlPv($226);
          $$2 = $221;$$23 = $220;
          break;
         }
         $187 = HEAP8[$7>>0]|0;
         $188 = $187 & 1;
         $189 = ($188<<24>>24)==(0);
         if (!($189)) {
          $190 = (($7) + 8|0);
          $191 = HEAP32[$190>>2]|0;
          __ZdlPv($191);
         }
         $192 = HEAP8[$8>>0]|0;
         $193 = $192 & 1;
         $194 = ($193<<24>>24)==(0);
         if ($194) {
          break L93;
         }
         $195 = (($8) + 8|0);
         $196 = HEAP32[$195>>2]|0;
         __ZdlPv($196);
         break L93;
        }
       } while(0);
       $227 = HEAP8[$8>>0]|0;
       $228 = $227 & 1;
       $229 = ($228<<24>>24)==(0);
       if ($229) {
        $$6 = $$2;$$67 = $$23;
        ___resumeException($$67|0);
        // unreachable;
       }
       $230 = (($8) + 8|0);
       $231 = HEAP32[$230>>2]|0;
       __ZdlPv($231);
       $$6 = $$2;$$67 = $$23;
       ___resumeException($$67|0);
       // unreachable;
      }
     } while(0);
     $232 = (($this) + 28|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = HEAP8[$name>>0]|0;
     $235 = $234 & 1;
     $236 = ($235<<24>>24)==(0);
     if ($236) {
      ;HEAP32[$11+0>>2]=HEAP32[$name+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$name+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$name+8>>2]|0;
      $$pre61 = HEAP8[$11>>0]|0;
      $$pre$phi68Z2D = $11;$256 = $$pre61;
     } else {
      $237 = (($name) + 8|0);
      $238 = HEAP32[$237>>2]|0;
      $239 = (($name) + 4|0);
      $240 = HEAP32[$239>>2]|0;
      $241 = ($240>>>0)>(4294967279);
      if ($241) {
       __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
       // unreachable;
      }
      $242 = ($240>>>0)<(11);
      if ($242) {
       $243 = $240 << 1;
       $244 = $243&255;
       HEAP8[$11>>0] = $244;
       $245 = (($11) + 1|0);
       $$pre67$pre$phiZZ2D = $11;$410 = $244;$__p$0$i$i$i24 = $245;
      } else {
       $246 = (($240) + 16)|0;
       $247 = $246 & -16;
       $248 = (__Znwj($247)|0);
       $249 = (($11) + 8|0);
       HEAP32[$249>>2] = $248;
       $250 = $247 | 1;
       HEAP32[$11>>2] = $250;
       $251 = (($11) + 4|0);
       HEAP32[$251>>2] = $240;
       $252 = $250&255;
       $$pre67$pre$phiZZ2D = $11;$410 = $252;$__p$0$i$i$i24 = $248;
      }
      _memcpy(($__p$0$i$i$i24|0),($238|0),($240|0))|0;
      $253 = (($__p$0$i$i$i24) + ($240)|0);
      HEAP8[$253>>0] = 0;
      $$pre$phi68Z2D = $$pre67$pre$phiZZ2D;$256 = $410;
     }
     HEAP32[$10>>2] = $tag;
     $254 = (($10) + 4|0);
     $255 = $256 & 1;
     $257 = ($255<<24>>24)==(0);
     L130: do {
      if ($257) {
       ;HEAP32[$254+0>>2]=HEAP32[$$pre$phi68Z2D+0>>2]|0;HEAP32[$254+4>>2]=HEAP32[$$pre$phi68Z2D+4>>2]|0;HEAP32[$254+8>>2]=HEAP32[$$pre$phi68Z2D+8>>2]|0;
       $$pre$phi70Z2D = $254;
       label = 107;
      } else {
       $258 = (($11) + 8|0);
       $259 = HEAP32[$258>>2]|0;
       $260 = (($11) + 4|0);
       $261 = HEAP32[$260>>2]|0;
       $262 = ($261>>>0)>(4294967279);
       do {
        if ($262) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $263 = __THREW__; __THREW__ = 0;
         $264 = $263&1;
         if ($264) {
          break;
         }
         // unreachable;
        } else {
         $265 = ($261>>>0)<(11);
         if ($265) {
          $266 = $261 << 1;
          $267 = $266&255;
          HEAP8[$254>>0] = $267;
          $268 = (($254) + 1|0);
          $$pre69$pre$phiZZ2D = $254;$__p$0$i$i$i$i$i$i28 = $268;
         } else {
          $269 = (($261) + 16)|0;
          $270 = $269 & -16;
          __THREW__ = 0;
          $271 = (invoke_ii(2988,($270|0))|0);
          $272 = __THREW__; __THREW__ = 0;
          $273 = $272&1;
          if ($273) {
           break;
          }
          $274 = (($10) + 12|0);
          HEAP32[$274>>2] = $271;
          $275 = $270 | 1;
          HEAP32[$254>>2] = $275;
          $276 = (($10) + 8|0);
          HEAP32[$276>>2] = $261;
          $$pre69$pre$phiZZ2D = $254;$__p$0$i$i$i$i$i$i28 = $271;
         }
         _memcpy(($__p$0$i$i$i$i$i$i28|0),($259|0),($261|0))|0;
         $277 = (($__p$0$i$i$i$i$i$i28) + ($261)|0);
         HEAP8[$277>>0] = 0;
         $$pre$phi70Z2D = $$pre69$pre$phiZZ2D;
         label = 107;
         break L130;
        }
       } while(0);
       $377 = ___cxa_find_matching_catch()|0;
       $378 = tempRet0;
       $$4 = $378;$$45 = $377;
      }
     } while(0);
     do {
      if ((label|0) == 107) {
       HEAP32[$9>>2] = $tag;
       $278 = (($9) + 4|0);
       $279 = HEAP8[$$pre$phi70Z2D>>0]|0;
       $280 = $279 & 1;
       $281 = ($280<<24>>24)==(0);
       L145: do {
        if ($281) {
         ;HEAP32[$278+0>>2]=HEAP32[$$pre$phi70Z2D+0>>2]|0;HEAP32[$278+4>>2]=HEAP32[$$pre$phi70Z2D+4>>2]|0;HEAP32[$278+8>>2]=HEAP32[$$pre$phi70Z2D+8>>2]|0;
         $$pre$phi72Z2D = $278;
         label = 117;
        } else {
         $282 = (($10) + 12|0);
         $283 = HEAP32[$282>>2]|0;
         $284 = (($10) + 8|0);
         $285 = HEAP32[$284>>2]|0;
         $286 = ($285>>>0)>(4294967279);
         do {
          if ($286) {
           __THREW__ = 0;
           invoke_vi(3309,0);
           $287 = __THREW__; __THREW__ = 0;
           $288 = $287&1;
           if ($288) {
            break;
           }
           // unreachable;
          } else {
           $289 = ($285>>>0)<(11);
           if ($289) {
            $290 = $285 << 1;
            $291 = $290&255;
            HEAP8[$278>>0] = $291;
            $292 = (($278) + 1|0);
            $$pre71$pre$phiZZ2D = $278;$__p$0$i$i$i$i$i33 = $292;
           } else {
            $293 = (($285) + 16)|0;
            $294 = $293 & -16;
            __THREW__ = 0;
            $295 = (invoke_ii(2988,($294|0))|0);
            $296 = __THREW__; __THREW__ = 0;
            $297 = $296&1;
            if ($297) {
             break;
            }
            $298 = (($9) + 12|0);
            HEAP32[$298>>2] = $295;
            $299 = $294 | 1;
            HEAP32[$278>>2] = $299;
            $300 = (($9) + 8|0);
            HEAP32[$300>>2] = $285;
            $$pre71$pre$phiZZ2D = $278;$__p$0$i$i$i$i$i33 = $295;
           }
           _memcpy(($__p$0$i$i$i$i$i33|0),($283|0),($285|0))|0;
           $301 = (($__p$0$i$i$i$i$i33) + ($285)|0);
           HEAP8[$301>>0] = 0;
           $$pre$phi72Z2D = $$pre71$pre$phiZZ2D;
           label = 117;
           break L145;
          }
         } while(0);
         $379 = ___cxa_find_matching_catch()|0;
         $380 = tempRet0;
         $$3 = $380;$$34 = $379;
        }
       } while(0);
       do {
        if ((label|0) == 117) {
         HEAP32[$1>>2] = $tag;
         $302 = (($1) + 4|0);
         $303 = HEAP8[$$pre$phi72Z2D>>0]|0;
         $304 = $303 & 1;
         $305 = ($304<<24>>24)==(0);
         L160: do {
          if ($305) {
           ;HEAP32[$302+0>>2]=HEAP32[$$pre$phi72Z2D+0>>2]|0;HEAP32[$302+4>>2]=HEAP32[$$pre$phi72Z2D+4>>2]|0;HEAP32[$302+8>>2]=HEAP32[$$pre$phi72Z2D+8>>2]|0;
           label = 127;
          } else {
           $306 = (($9) + 12|0);
           $307 = HEAP32[$306>>2]|0;
           $308 = (($9) + 8|0);
           $309 = HEAP32[$308>>2]|0;
           $310 = ($309>>>0)>(4294967279);
           do {
            if ($310) {
             __THREW__ = 0;
             invoke_vi(3309,0);
             $311 = __THREW__; __THREW__ = 0;
             $312 = $311&1;
             if ($312) {
              break;
             }
             // unreachable;
            } else {
             $313 = ($309>>>0)<(11);
             if ($313) {
              $314 = $309 << 1;
              $315 = $314&255;
              HEAP8[$302>>0] = $315;
              $316 = (($302) + 1|0);
              $__p$0$i$i$i$i$i$i$i$i38 = $316;
             } else {
              $317 = (($309) + 16)|0;
              $318 = $317 & -16;
              __THREW__ = 0;
              $319 = (invoke_ii(2988,($318|0))|0);
              $320 = __THREW__; __THREW__ = 0;
              $321 = $320&1;
              if ($321) {
               break;
              }
              $322 = (($1) + 12|0);
              HEAP32[$322>>2] = $319;
              $323 = $318 | 1;
              HEAP32[$302>>2] = $323;
              $324 = (($1) + 8|0);
              HEAP32[$324>>2] = $309;
              $__p$0$i$i$i$i$i$i$i$i38 = $319;
             }
             _memcpy(($__p$0$i$i$i$i$i$i$i$i38|0),($307|0),($309|0))|0;
             $325 = (($__p$0$i$i$i$i$i$i$i$i38) + ($309)|0);
             HEAP8[$325>>0] = 0;
             label = 127;
             break L160;
            }
           } while(0);
           $381 = ___cxa_find_matching_catch()|0;
           $382 = tempRet0;
           $eh$lpad$body43$index10Z2D = $382;$eh$lpad$body43$indexZ2D = $381;
          }
         } while(0);
         do {
          if ((label|0) == 127) {
           HEAP32[$1>>2] = $tag;
           __THREW__ = 0;
           invoke_viii(1636,($0|0),($233|0),($1|0));
           $326 = __THREW__; __THREW__ = 0;
           $327 = $326&1;
           if ($327) {
            $335 = ___cxa_find_matching_catch()|0;
            $336 = tempRet0;
            $337 = HEAP8[$302>>0]|0;
            $338 = $337 & 1;
            $339 = ($338<<24>>24)==(0);
            if ($339) {
             $eh$lpad$body43$index10Z2D = $336;$eh$lpad$body43$indexZ2D = $335;
             break;
            }
            $340 = (($1) + 12|0);
            $341 = HEAP32[$340>>2]|0;
            __ZdlPv($341);
            $eh$lpad$body43$index10Z2D = $336;$eh$lpad$body43$indexZ2D = $335;
            break;
           }
           $328 = (($0) + 4|0);
           $329 = HEAP8[$328>>0]|0;
           $330 = HEAP8[$302>>0]|0;
           $331 = $330 & 1;
           $332 = ($331<<24>>24)==(0);
           if (!($332)) {
            $333 = (($1) + 12|0);
            $334 = HEAP32[$333>>2]|0;
            __ZdlPv($334);
           }
           $342 = ($329<<24>>24)==(0);
           if (!($305)) {
            $343 = (($9) + 12|0);
            $344 = HEAP32[$343>>2]|0;
            __ZdlPv($344);
           }
           if (!($281)) {
            $345 = (($10) + 12|0);
            $346 = HEAP32[$345>>2]|0;
            __ZdlPv($346);
           }
           $347 = HEAP8[$$pre$phi68Z2D>>0]|0;
           $348 = $347 & 1;
           $349 = ($348<<24>>24)==(0);
           if (!($349)) {
            $350 = (($11) + 8|0);
            $351 = HEAP32[$350>>2]|0;
            __ZdlPv($351);
           }
           if (!($342)) {
            STACKTOP = sp;return;
           }
           __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($13,567184,$name);
           __THREW__ = 0;
           invoke_viii(1627,($12|0),($13|0),(567160|0));
           $352 = __THREW__; __THREW__ = 0;
           $353 = $352&1;
           do {
            if ($353) {
             $392 = ___cxa_find_matching_catch()|0;
             $393 = tempRet0;
             $$5 = $393;$$56 = $392;
            } else {
             $354 = ($this|0)==(0|0);
             if ($354) {
              $364 = 0;
             } else {
              $355 = (($this) + 4|0);
              $356 = HEAP32[$355>>2]|0;
              $364 = $356;
             }
             $357 = HEAP8[$12>>0]|0;
             $358 = $357 & 1;
             $359 = ($358<<24>>24)==(0);
             if ($359) {
              $362 = (($12) + 1|0);
              $363 = $362;
             } else {
              $360 = (($12) + 8|0);
              $361 = HEAP32[$360>>2]|0;
              $363 = $361;
             }
             __THREW__ = 0;
             invoke_viiiiiiii(21,($363|0),0,(567120|0),86,4,($364|0),0,(0|0));
             $365 = __THREW__; __THREW__ = 0;
             $366 = $365&1;
             if ($366) {
              $394 = ___cxa_find_matching_catch()|0;
              $395 = tempRet0;
              $396 = HEAP8[$12>>0]|0;
              $397 = $396 & 1;
              $398 = ($397<<24>>24)==(0);
              if ($398) {
               $$5 = $395;$$56 = $394;
               break;
              }
              $399 = (($12) + 8|0);
              $400 = HEAP32[$399>>2]|0;
              __ZdlPv($400);
              $$5 = $395;$$56 = $394;
              break;
             }
             $367 = HEAP8[$12>>0]|0;
             $368 = $367 & 1;
             $369 = ($368<<24>>24)==(0);
             if (!($369)) {
              $370 = (($12) + 8|0);
              $371 = HEAP32[$370>>2]|0;
              __ZdlPv($371);
             }
             $372 = HEAP8[$13>>0]|0;
             $373 = $372 & 1;
             $374 = ($373<<24>>24)==(0);
             if ($374) {
              STACKTOP = sp;return;
             }
             $375 = (($13) + 8|0);
             $376 = HEAP32[$375>>2]|0;
             __ZdlPv($376);
             STACKTOP = sp;return;
            }
           } while(0);
           $401 = HEAP8[$13>>0]|0;
           $402 = $401 & 1;
           $403 = ($402<<24>>24)==(0);
           if ($403) {
            $$6 = $$5;$$67 = $$56;
            ___resumeException($$67|0);
            // unreachable;
           }
           $404 = (($13) + 8|0);
           $405 = HEAP32[$404>>2]|0;
           __ZdlPv($405);
           $$6 = $$5;$$67 = $$56;
           ___resumeException($$67|0);
           // unreachable;
          }
         } while(0);
         if ($305) {
          $$3 = $eh$lpad$body43$index10Z2D;$$34 = $eh$lpad$body43$indexZ2D;
          break;
         }
         $383 = (($9) + 12|0);
         $384 = HEAP32[$383>>2]|0;
         __ZdlPv($384);
         $$3 = $eh$lpad$body43$index10Z2D;$$34 = $eh$lpad$body43$indexZ2D;
        }
       } while(0);
       if ($281) {
        $$4 = $$3;$$45 = $$34;
        break;
       }
       $385 = (($10) + 12|0);
       $386 = HEAP32[$385>>2]|0;
       __ZdlPv($386);
       $$4 = $$3;$$45 = $$34;
      }
     } while(0);
     $387 = HEAP8[$$pre$phi68Z2D>>0]|0;
     $388 = $387 & 1;
     $389 = ($388<<24>>24)==(0);
     if ($389) {
      $$6 = $$4;$$67 = $$45;
      ___resumeException($$67|0);
      // unreachable;
     }
     $390 = (($11) + 8|0);
     $391 = HEAP32[$390>>2]|0;
     __ZdlPv($391);
     $$6 = $$4;$$67 = $$45;
     ___resumeException($$67|0);
     // unreachable;
    }
   } while(0);
   $203 = HEAP8[$$pre$phi66Z2D>>0]|0;
   $204 = $203 & 1;
   $205 = ($204<<24>>24)==(0);
   if ($205) {
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
   } else {
    $206 = (($4) + 8|0);
    $207 = HEAP32[$206>>2]|0;
    __ZdlPv($207);
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
   }
  }
  $208 = HEAP8[$$pre$phi64Z2D>>0]|0;
  $209 = $208 & 1;
  $210 = ($209<<24>>24)==(0);
  if ($210) {
   $$1 = $$0;$$12 = $$01;
  } else {
   $211 = (($5) + 8|0);
   $212 = HEAP32[$211>>2]|0;
   __ZdlPv($212);
   $$1 = $$0;$$12 = $$01;
  }
 }
 $213 = HEAP8[$$pre$phiZ2D>>0]|0;
 $214 = $213 & 1;
 $215 = ($214<<24>>24)==(0);
 if ($215) {
  $$6 = $$1;$$67 = $$12;
  ___resumeException($$67|0);
  // unreachable;
 }
 $216 = (($6) + 8|0);
 $217 = HEAP32[$216>>2]|0;
 __ZdlPv($217);
 $$6 = $$1;$$67 = $$12;
 ___resumeException($$67|0);
 // unreachable;
}
function __ZN10TagManager13RegisterLayerEjRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$tag,$name) {
 $this = $this|0;
 $tag = $tag|0;
 $name = $name|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$phi33Z2D = 0, $$pre$phi35Z2D = 0, $$pre$phiZ2D = 0, $$pre28 = 0, $$pre30 = 0, $$pre31$pre$phiZZ2D = 0, $$pre32$pre$phiZZ2D = 0, $$pre34$pre$phiZZ2D = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $__parent$i$i = 0, $eh$lpad$body$index3Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $__parent$i$i = sp + 124|0;
 $0 = sp + 112|0;
 $1 = sp + 96|0;
 $2 = sp + 80|0;
 $3 = sp + 64|0;
 $4 = sp + 48|0;
 $5 = sp + 24|0;
 $6 = sp + 12|0;
 $7 = sp;
 $8 = sp + 36|0;
 $9 = (($this) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP8[$name>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  ;HEAP32[$4+0>>2]=HEAP32[$name+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$name+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$name+8>>2]|0;
  $$pre = HEAP8[$4>>0]|0;
  $$pre$phiZ2D = $4;$32 = $$pre;
 } else {
  $14 = (($name) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($name) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17>>>0)>(4294967279);
  if ($18) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $19 = ($17>>>0)<(11);
  if ($19) {
   $20 = $17 << 1;
   $21 = $20&255;
   HEAP8[$4>>0] = $21;
   $22 = (($4) + 1|0);
   $$pre31$pre$phiZZ2D = $4;$270 = $21;$__p$0$i$i$i = $22;
  } else {
   $23 = (($17) + 16)|0;
   $24 = $23 & -16;
   $25 = (__Znwj($24)|0);
   $26 = (($4) + 8|0);
   HEAP32[$26>>2] = $25;
   $27 = $24 | 1;
   HEAP32[$4>>2] = $27;
   $28 = (($4) + 4|0);
   HEAP32[$28>>2] = $17;
   $29 = $27&255;
   $$pre31$pre$phiZZ2D = $4;$270 = $29;$__p$0$i$i$i = $25;
  }
  _memcpy(($__p$0$i$i$i|0),($15|0),($17|0))|0;
  $30 = (($__p$0$i$i$i) + ($17)|0);
  HEAP8[$30>>0] = 0;
  $$pre$phiZ2D = $$pre31$pre$phiZZ2D;$32 = $270;
 }
 $31 = $32 & 1;
 $33 = ($31<<24>>24)==(0);
 L12: do {
  if ($33) {
   ;HEAP32[$3+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
   $$pre28 = HEAP8[$3>>0]|0;
   $$pre$phi33Z2D = $3;$57 = $$pre28;
   label = 19;
  } else {
   $34 = (($4) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($4) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37>>>0)>(4294967279);
   do {
    if ($38) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      // unreachable;
     }
    } else {
     $41 = ($37>>>0)<(11);
     if ($41) {
      $42 = $37 << 1;
      $43 = $42&255;
      HEAP8[$3>>0] = $43;
      $44 = (($3) + 1|0);
      $$pre32$pre$phiZZ2D = $3;$271 = $43;$__p$0$i$i$i$i$i$i = $44;
     } else {
      $45 = (($37) + 16)|0;
      $46 = $45 & -16;
      __THREW__ = 0;
      $47 = (invoke_ii(2988,($46|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      $50 = (($3) + 8|0);
      HEAP32[$50>>2] = $47;
      $51 = $46 | 1;
      HEAP32[$3>>2] = $51;
      $52 = (($3) + 4|0);
      HEAP32[$52>>2] = $37;
      $53 = $51&255;
      $$pre32$pre$phiZZ2D = $3;$271 = $53;$__p$0$i$i$i$i$i$i = $47;
     }
     _memcpy(($__p$0$i$i$i$i$i$i|0),($35|0),($37|0))|0;
     $54 = (($__p$0$i$i$i$i$i$i) + ($37)|0);
     HEAP8[$54>>0] = 0;
     $$pre$phi33Z2D = $$pre32$pre$phiZZ2D;$57 = $271;
     label = 19;
     break L12;
    }
   } while(0);
   $186 = ___cxa_find_matching_catch()|0;
   $187 = tempRet0;
   $$1 = $187;$$12 = $186;
  }
 } while(0);
 if ((label|0) == 19) {
  $55 = (($3) + 12|0);
  HEAP32[$55>>2] = $tag;
  $56 = $57 & 1;
  $58 = ($56<<24>>24)==(0);
  L27: do {
   if ($58) {
    ;HEAP32[$2+0>>2]=HEAP32[$$pre$phi33Z2D+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$$pre$phi33Z2D+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$$pre$phi33Z2D+8>>2]|0;
    $$pre30 = HEAP8[$2>>0]|0;
    $$pre$phi35Z2D = $2;$82 = $$pre30;
    label = 29;
   } else {
    $59 = (($3) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($3) + 4|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($62>>>0)>(4294967279);
    do {
     if ($63) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if (!($65)) {
       // unreachable;
      }
     } else {
      $66 = ($62>>>0)<(11);
      if ($66) {
       $67 = $62 << 1;
       $68 = $67&255;
       HEAP8[$2>>0] = $68;
       $69 = (($2) + 1|0);
       $$pre34$pre$phiZZ2D = $2;$272 = $68;$__p$0$i$i$i$i$i = $69;
      } else {
       $70 = (($62) + 16)|0;
       $71 = $70 & -16;
       __THREW__ = 0;
       $72 = (invoke_ii(2988,($71|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($2) + 8|0);
       HEAP32[$75>>2] = $72;
       $76 = $71 | 1;
       HEAP32[$2>>2] = $76;
       $77 = (($2) + 4|0);
       HEAP32[$77>>2] = $62;
       $78 = $76&255;
       $$pre34$pre$phiZZ2D = $2;$272 = $78;$__p$0$i$i$i$i$i = $72;
      }
      _memcpy(($__p$0$i$i$i$i$i|0),($60|0),($62|0))|0;
      $79 = (($__p$0$i$i$i$i$i) + ($62)|0);
      HEAP8[$79>>0] = 0;
      $$pre$phi35Z2D = $$pre34$pre$phiZZ2D;$82 = $272;
      label = 29;
      break L27;
     }
    } while(0);
    $188 = ___cxa_find_matching_catch()|0;
    $189 = tempRet0;
    $$0 = $189;$$01 = $188;
   }
  } while(0);
  if ((label|0) == 29) {
   $80 = (($2) + 12|0);
   HEAP32[$80>>2] = $tag;
   $81 = $82 & 1;
   $83 = ($81<<24>>24)==(0);
   L42: do {
    if ($83) {
     ;HEAP32[$1+0>>2]=HEAP32[$$pre$phi35Z2D+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$pre$phi35Z2D+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$pre$phi35Z2D+8>>2]|0;
     label = 39;
    } else {
     $84 = (($2) + 8|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = (($2) + 4|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = ($87>>>0)>(4294967279);
     do {
      if ($88) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if (!($90)) {
        // unreachable;
       }
      } else {
       $91 = ($87>>>0)<(11);
       if ($91) {
        $92 = $87 << 1;
        $93 = $92&255;
        HEAP8[$1>>0] = $93;
        $94 = (($1) + 1|0);
        $__p$0$i$i$i$i$i$i$i$i = $94;
       } else {
        $95 = (($87) + 16)|0;
        $96 = $95 & -16;
        __THREW__ = 0;
        $97 = (invoke_ii(2988,($96|0))|0);
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         break;
        }
        $100 = (($1) + 8|0);
        HEAP32[$100>>2] = $97;
        $101 = $96 | 1;
        HEAP32[$1>>2] = $101;
        $102 = (($1) + 4|0);
        HEAP32[$102>>2] = $87;
        $__p$0$i$i$i$i$i$i$i$i = $97;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($85|0),($87|0))|0;
       $103 = (($__p$0$i$i$i$i$i$i$i$i) + ($87)|0);
       HEAP8[$103>>0] = 0;
       label = 39;
       break L42;
      }
     } while(0);
     $190 = ___cxa_find_matching_catch()|0;
     $191 = tempRet0;
     $eh$lpad$body$index3Z2D = $191;$eh$lpad$body$indexZ2D = $190;
    }
   } while(0);
   do {
    if ((label|0) == 39) {
     $104 = (($1) + 12|0);
     HEAP32[$104>>2] = $tag;
     $105 = (__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE12__find_equalIS8_EERPNS_16__tree_node_baseIPvEESM_RKT_($10,$__parent$i$i,$1)|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ($106|0)==(0|0);
     if ($107) {
      __THREW__ = 0;
      invoke_viii(1635,($0|0),($10|0),($1|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       $128 = ___cxa_find_matching_catch()|0;
       $129 = tempRet0;
       $130 = HEAP8[$1>>0]|0;
       $131 = $130 & 1;
       $132 = ($131<<24>>24)==(0);
       if ($132) {
        $eh$lpad$body$index3Z2D = $129;$eh$lpad$body$indexZ2D = $128;
        break;
       }
       $133 = (($1) + 8|0);
       $134 = HEAP32[$133>>2]|0;
       __ZdlPv($134);
       $eh$lpad$body$index3Z2D = $129;$eh$lpad$body$indexZ2D = $128;
       break;
      }
      $110 = HEAP32[$0>>2]|0;
      HEAP32[$0>>2] = 0;
      $111 = HEAP32[$__parent$i$i>>2]|0;
      HEAP32[$110>>2] = 0;
      $112 = (($110) + 4|0);
      HEAP32[$112>>2] = 0;
      $113 = (($110) + 8|0);
      HEAP32[$113>>2] = $111;
      HEAP32[$105>>2] = $110;
      $114 = HEAP32[$10>>2]|0;
      $115 = HEAP32[$114>>2]|0;
      $116 = ($115|0)==(0|0);
      if ($116) {
       $119 = $110;
      } else {
       HEAP32[$10>>2] = $115;
       $$pre$i$i$i = HEAP32[$105>>2]|0;
       $119 = $$pre$i$i$i;
      }
      $117 = (($10) + 4|0);
      $118 = HEAP32[$117>>2]|0;
      __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($118,$119);
      $120 = (($10) + 8|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = (($121) + 1)|0;
      HEAP32[$120>>2] = $122;
      $136 = 1;
     } else {
      $136 = 0;
     }
     $123 = HEAP8[$1>>0]|0;
     $124 = $123 & 1;
     $125 = ($124<<24>>24)==(0);
     if (!($125)) {
      $126 = (($1) + 8|0);
      $127 = HEAP32[$126>>2]|0;
      __ZdlPv($127);
     }
     $135 = ($136<<24>>24)==(0);
     if ($135) {
      $137 = HEAP8[$name>>0]|0;
      $138 = $137 & 1;
      $139 = ($138<<24>>24)==(0);
      if ($139) {
       $142 = $137&255;
       $143 = $142 >>> 1;
       $145 = $143;
      } else {
       $140 = (($name) + 4|0);
       $141 = HEAP32[$140>>2]|0;
       $145 = $141;
      }
      $144 = ($145|0)!=(0);
      $273 = $144;
     } else {
      $273 = 0;
     }
     $146 = HEAP8[$$pre$phi35Z2D>>0]|0;
     $147 = $146 & 1;
     $148 = ($147<<24>>24)==(0);
     if (!($148)) {
      $149 = (($2) + 8|0);
      $150 = HEAP32[$149>>2]|0;
      __ZdlPv($150);
     }
     $151 = HEAP8[$$pre$phi33Z2D>>0]|0;
     $152 = $151 & 1;
     $153 = ($152<<24>>24)==(0);
     if (!($153)) {
      $154 = (($3) + 8|0);
      $155 = HEAP32[$154>>2]|0;
      __ZdlPv($155);
     }
     $156 = HEAP8[$$pre$phiZ2D>>0]|0;
     $157 = $156 & 1;
     $158 = ($157<<24>>24)==(0);
     if (!($158)) {
      $159 = (($4) + 8|0);
      $160 = HEAP32[$159>>2]|0;
      __ZdlPv($160);
     }
     L86: do {
      if ($273) {
       __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($6,567224,$name);
       __THREW__ = 0;
       invoke_viii(1627,($5|0),($6|0),(567160|0));
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       do {
        if ($162) {
         $207 = ___cxa_find_matching_catch()|0;
         $208 = tempRet0;
         $$2 = $208;$$23 = $207;
        } else {
         $163 = ($this|0)==(0|0);
         if ($163) {
          $173 = 0;
         } else {
          $164 = (($this) + 4|0);
          $165 = HEAP32[$164>>2]|0;
          $173 = $165;
         }
         $166 = HEAP8[$5>>0]|0;
         $167 = $166 & 1;
         $168 = ($167<<24>>24)==(0);
         if ($168) {
          $171 = (($5) + 1|0);
          $172 = $171;
         } else {
          $169 = (($5) + 8|0);
          $170 = HEAP32[$169>>2]|0;
          $172 = $170;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,($172|0),0,(567120|0),93,4,($173|0),0,(0|0));
         $174 = __THREW__; __THREW__ = 0;
         $175 = $174&1;
         if ($175) {
          $209 = ___cxa_find_matching_catch()|0;
          $210 = tempRet0;
          $211 = HEAP8[$5>>0]|0;
          $212 = $211 & 1;
          $213 = ($212<<24>>24)==(0);
          if ($213) {
           $$2 = $210;$$23 = $209;
           break;
          }
          $214 = (($5) + 8|0);
          $215 = HEAP32[$214>>2]|0;
          __ZdlPv($215);
          $$2 = $210;$$23 = $209;
          break;
         }
         $176 = HEAP8[$5>>0]|0;
         $177 = $176 & 1;
         $178 = ($177<<24>>24)==(0);
         if (!($178)) {
          $179 = (($5) + 8|0);
          $180 = HEAP32[$179>>2]|0;
          __ZdlPv($180);
         }
         $181 = HEAP8[$6>>0]|0;
         $182 = $181 & 1;
         $183 = ($182<<24>>24)==(0);
         if ($183) {
          break L86;
         }
         $184 = (($6) + 8|0);
         $185 = HEAP32[$184>>2]|0;
         __ZdlPv($185);
         break L86;
        }
       } while(0);
       $216 = HEAP8[$6>>0]|0;
       $217 = $216 & 1;
       $218 = ($217<<24>>24)==(0);
       if ($218) {
        $$4 = $$2;$$45 = $$23;
        ___resumeException($$45|0);
        // unreachable;
       }
       $219 = (($6) + 8|0);
       $220 = HEAP32[$219>>2]|0;
       __ZdlPv($220);
       $$4 = $$2;$$45 = $$23;
       ___resumeException($$45|0);
       // unreachable;
      }
     } while(0);
     $221 = ((($this) + (($tag*12)|0)|0) + 40|0);
     $222 = HEAP8[$221>>0]|0;
     $223 = $222 & 1;
     $224 = ($223<<24>>24)==(0);
     if ($224) {
      $227 = $222&255;
      $228 = $227 >>> 1;
      $230 = $228;
     } else {
      $225 = ((($this) + (($tag*12)|0)|0) + 44|0);
      $226 = HEAP32[$225>>2]|0;
      $230 = $226;
     }
     $229 = ($230|0)==(0);
     if ($229) {
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($221,$name)|0);
      STACKTOP = sp;return;
     }
     __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($8,567256,$name);
     __THREW__ = 0;
     invoke_viii(1627,($7|0),($8|0),(567160|0));
     $231 = __THREW__; __THREW__ = 0;
     $232 = $231&1;
     do {
      if ($232) {
       $256 = ___cxa_find_matching_catch()|0;
       $257 = tempRet0;
       $$3 = $257;$$34 = $256;
      } else {
       $233 = ($this|0)==(0|0);
       if ($233) {
        $243 = 0;
       } else {
        $234 = (($this) + 4|0);
        $235 = HEAP32[$234>>2]|0;
        $243 = $235;
       }
       $236 = HEAP8[$7>>0]|0;
       $237 = $236 & 1;
       $238 = ($237<<24>>24)==(0);
       if ($238) {
        $241 = (($7) + 1|0);
        $242 = $241;
       } else {
        $239 = (($7) + 8|0);
        $240 = HEAP32[$239>>2]|0;
        $242 = $240;
       }
       __THREW__ = 0;
       invoke_viiiiiiii(21,($242|0),0,(567120|0),98,4,($243|0),0,(0|0));
       $244 = __THREW__; __THREW__ = 0;
       $245 = $244&1;
       if ($245) {
        $258 = ___cxa_find_matching_catch()|0;
        $259 = tempRet0;
        $260 = HEAP8[$7>>0]|0;
        $261 = $260 & 1;
        $262 = ($261<<24>>24)==(0);
        if ($262) {
         $$3 = $259;$$34 = $258;
         break;
        }
        $263 = (($7) + 8|0);
        $264 = HEAP32[$263>>2]|0;
        __ZdlPv($264);
        $$3 = $259;$$34 = $258;
        break;
       }
       $246 = HEAP8[$7>>0]|0;
       $247 = $246 & 1;
       $248 = ($247<<24>>24)==(0);
       if (!($248)) {
        $249 = (($7) + 8|0);
        $250 = HEAP32[$249>>2]|0;
        __ZdlPv($250);
       }
       $251 = HEAP8[$8>>0]|0;
       $252 = $251 & 1;
       $253 = ($252<<24>>24)==(0);
       if ($253) {
        STACKTOP = sp;return;
       }
       $254 = (($8) + 8|0);
       $255 = HEAP32[$254>>2]|0;
       __ZdlPv($255);
       STACKTOP = sp;return;
      }
     } while(0);
     $265 = HEAP8[$8>>0]|0;
     $266 = $265 & 1;
     $267 = ($266<<24>>24)==(0);
     if ($267) {
      $$4 = $$3;$$45 = $$34;
      ___resumeException($$45|0);
      // unreachable;
     }
     $268 = (($8) + 8|0);
     $269 = HEAP32[$268>>2]|0;
     __ZdlPv($269);
     $$4 = $$3;$$45 = $$34;
     ___resumeException($$45|0);
     // unreachable;
    }
   } while(0);
   $192 = HEAP8[$$pre$phi35Z2D>>0]|0;
   $193 = $192 & 1;
   $194 = ($193<<24>>24)==(0);
   if ($194) {
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
   } else {
    $195 = (($2) + 8|0);
    $196 = HEAP32[$195>>2]|0;
    __ZdlPv($196);
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
   }
  }
  $197 = HEAP8[$$pre$phi33Z2D>>0]|0;
  $198 = $197 & 1;
  $199 = ($198<<24>>24)==(0);
  if ($199) {
   $$1 = $$0;$$12 = $$01;
  } else {
   $200 = (($3) + 8|0);
   $201 = HEAP32[$200>>2]|0;
   __ZdlPv($201);
   $$1 = $$0;$$12 = $$01;
  }
 }
 $202 = HEAP8[$$pre$phiZ2D>>0]|0;
 $203 = $202 & 1;
 $204 = ($203<<24>>24)==(0);
 if ($204) {
  $$4 = $$1;$$45 = $$12;
  ___resumeException($$45|0);
  // unreachable;
 }
 $205 = (($4) + 8|0);
 $206 = HEAP32[$205>>2]|0;
 __ZdlPv($206);
 $$4 = $$1;$$45 = $$12;
 ___resumeException($$45|0);
 // unreachable;
}
function __ZN10TagManager32RegisterDefaultTagsAndLayerMasksEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$063 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy4 = sp + 196|0;
 $0 = sp + 192|0;
 $1 = sp + 188|0;
 $2 = sp + 184|0;
 $3 = sp + 180|0;
 $4 = sp + 176|0;
 $5 = sp + 156|0;
 $6 = sp + 144|0;
 $7 = sp + 132|0;
 $8 = sp + 120|0;
 $9 = sp + 108|0;
 $10 = sp + 36|0;
 $11 = sp;
 $12 = sp + 12|0;
 $13 = sp + 24|0;
 $14 = sp + 48|0;
 $15 = sp + 60|0;
 $16 = sp + 72|0;
 $17 = sp + 84|0;
 $18 = sp + 96|0;
 $19 = (($this) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($20,$22);
 $23 = (($20) + 8|0);
 HEAP32[$23>>2] = 0;
 $24 = (($20) + 4|0);
 HEAP32[$20>>2] = $24;
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 28|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($26,$28);
 $29 = (($26) + 8|0);
 HEAP32[$29>>2] = 0;
 $30 = (($26) + 4|0);
 HEAP32[$26>>2] = $30;
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 36|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($32,$34);
 $35 = (($32) + 8|0);
 HEAP32[$35>>2] = 0;
 $36 = (($32) + 4|0);
 HEAP32[$32>>2] = $36;
 HEAP32[$36>>2] = 0;
 $i$063 = 0;
 while(1) {
  $37 = ((($this) + (($i$063*12)|0)|0) + 40|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if ($40) {
   $44 = (($37) + 1|0);
   HEAP8[$44>>0] = 0;
   HEAP8[$37>>0] = 0;
  } else {
   $41 = ((($this) + (($i$063*12)|0)|0) + 48|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP8[$42>>0] = 0;
   $43 = ((($this) + (($i$063*12)|0)|0) + 44|0);
   HEAP32[$43>>2] = 0;
  }
  $45 = (($i$063) + 1)|0;
  $exitcond = ($45|0)==(32);
  if ($exitcond) {
   break;
  } else {
   $i$063 = $45;
  }
 }
 $46 = (($this) + 424|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($this) + 428|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==($47|0);
 L8: do {
  if (!($50)) {
   $52 = $49;
   while(1) {
    $51 = (($52) + -20|0);
    HEAP32[$48>>2] = $51;
    $53 = HEAP8[$51>>0]|0;
    $54 = $53 & 1;
    $55 = ($54<<24>>24)==(0);
    if ($55) {
     $57 = $51;
    } else {
     $58 = (($52) + -12|0);
     $59 = HEAP32[$58>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($59|0),($$byval_copy4|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     $$pre$i$i$i = HEAP32[$48>>2]|0;
     $57 = $$pre$i$i$i;
    }
    $56 = ($57|0)==($47|0);
    if ($56) {
     break L8;
    } else {
     $52 = $57;
    }
   }
   $62 = ___cxa_find_matching_catch()|0;
   $63 = tempRet0;
   ___cxa_call_unexpected(($62|0));
   // unreachable;
  }
 } while(0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
 $64 = (($5) + 12|0);
 HEAP32[$64>>2] = 1;
 $65 = (($5) + 16|0);
 HEAP8[$65>>0] = 0;
 $66 = (($this) + 432|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($47|0)==($67|0);
 if ($68) {
  __THREW__ = 0;
  invoke_vii(2601,($46|0),($5|0));
  $74 = __THREW__; __THREW__ = 0;
  $75 = $74&1;
  if ($75) {
   $213 = ___cxa_find_matching_catch()|0;
   $214 = tempRet0;
   $215 = HEAP8[$5>>0]|0;
   $216 = $215 & 1;
   $217 = ($216<<24>>24)==(0);
   if ($217) {
    $$0 = $214;$$01 = $213;
    ___resumeException($$01|0);
    // unreachable;
   }
   $218 = (($5) + 8|0);
   $219 = HEAP32[$218>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($219|0),($$byval_copy4|0));
   $220 = __THREW__; __THREW__ = 0;
   $221 = $220&1;
   if ($221) {
    $222 = ___cxa_find_matching_catch()|0;
    $223 = tempRet0;
    ___cxa_call_unexpected(($222|0));
    // unreachable;
   } else {
    $$0 = $214;$$01 = $213;
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } else {
  $69 = ($47|0)==(0|0);
  if ($69) {
   $73 = 0;
  } else {
   HEAP8[$47>>0] = 0;
   $70 = (($47) + 1|0);
   HEAP8[$70>>0] = 0;
   $71 = (($47) + 12|0);
   ;HEAP32[$71+0>>2]=HEAP32[$64+0>>2]|0;HEAP8[$71+4>>0]=HEAP8[$64+4>>0]|0;
   $$pre$i = HEAP32[$48>>2]|0;
   $73 = $$pre$i;
  }
  $72 = (($73) + 20|0);
  HEAP32[$48>>2] = $72;
 }
 $76 = HEAP8[$5>>0]|0;
 $77 = $76 & 1;
 $78 = ($77<<24>>24)==(0);
 if (!($78)) {
  $79 = (($5) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  HEAP32[$3>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($80|0),($$byval_copy4|0));
  $81 = __THREW__; __THREW__ = 0;
  $82 = $81&1;
  if ($82) {
   $83 = ___cxa_find_matching_catch()|0;
   $84 = tempRet0;
   ___cxa_call_unexpected(($83|0));
   // unreachable;
  }
 }
 $85 = HEAP32[$46>>2]|0;
 HEAP8[$6>>0] = 14;
 $86 = (($6) + 1|0);
 ;HEAP8[$86+0>>0]=HEAP8[567368+0>>0]|0;HEAP8[$86+1>>0]=HEAP8[567368+1>>0]|0;HEAP8[$86+2>>0]=HEAP8[567368+2>>0]|0;HEAP8[$86+3>>0]=HEAP8[567368+3>>0]|0;HEAP8[$86+4>>0]=HEAP8[567368+4>>0]|0;HEAP8[$86+5>>0]=HEAP8[567368+5>>0]|0;HEAP8[$86+6>>0]=HEAP8[567368+6>>0]|0;
 $87 = (($6) + 8|0);
 HEAP8[$87>>0] = 0;
 __THREW__ = 0;
 (invoke_iii(2359,($85|0),($6|0))|0);
 $88 = __THREW__; __THREW__ = 0;
 $89 = $88&1;
 if ($89) {
  $224 = ___cxa_find_matching_catch()|0;
  $225 = tempRet0;
  $226 = HEAP8[$6>>0]|0;
  $227 = $226 & 1;
  $228 = ($227<<24>>24)==(0);
  if ($228) {
   $$0 = $225;$$01 = $224;
   ___resumeException($$01|0);
   // unreachable;
  }
  $229 = HEAP32[$87>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($229|0),($$byval_copy4|0));
  $230 = __THREW__; __THREW__ = 0;
  $231 = $230&1;
  if ($231) {
   $232 = ___cxa_find_matching_catch()|0;
   $233 = tempRet0;
   ___cxa_call_unexpected(($232|0));
   // unreachable;
  } else {
   $$0 = $225;$$01 = $224;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $90 = HEAP8[$6>>0]|0;
 $91 = $90 & 1;
 $92 = ($91<<24>>24)==(0);
 if (!($92)) {
  $93 = HEAP32[$87>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($93|0),($$byval_copy4|0));
  $94 = __THREW__; __THREW__ = 0;
  $95 = $94&1;
  if ($95) {
   $96 = ___cxa_find_matching_catch()|0;
   $97 = tempRet0;
   ___cxa_call_unexpected(($96|0));
   // unreachable;
  }
 }
 $98 = (($85) + 12|0);
 HEAP32[$98>>2] = 0;
 $99 = (($this) + 436|0);
 HEAP32[$99>>2] = 0;
 HEAP8[$7>>0] = 16;
 $100 = (($7) + 1|0);
 $101 = $100;
 $102 = $101;
 HEAP8[$102>>0]=1635020373&255;HEAP8[$102+1>>0]=(1635020373>>8)&255;HEAP8[$102+2>>0]=(1635020373>>16)&255;HEAP8[$102+3>>0]=1635020373>>24;
 $103 = (($101) + 4)|0;
 $104 = $103;
 HEAP8[$104>>0]=1684367207&255;HEAP8[$104+1>>0]=(1684367207>>8)&255;HEAP8[$104+2>>0]=(1684367207>>16)&255;HEAP8[$104+3>>0]=1684367207>>24;
 $105 = (($7) + 9|0);
 HEAP8[$105>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1637,($this|0),0,($7|0));
 $106 = __THREW__; __THREW__ = 0;
 $107 = $106&1;
 if ($107) {
  $234 = ___cxa_find_matching_catch()|0;
  $235 = tempRet0;
  $236 = HEAP8[$7>>0]|0;
  $237 = $236 & 1;
  $238 = ($237<<24>>24)==(0);
  if ($238) {
   $$0 = $235;$$01 = $234;
   ___resumeException($$01|0);
   // unreachable;
  }
  $239 = (($7) + 8|0);
  $240 = HEAP32[$239>>2]|0;
  __ZdlPv($240);
  $$0 = $235;$$01 = $234;
  ___resumeException($$01|0);
  // unreachable;
 }
 $108 = HEAP8[$7>>0]|0;
 $109 = $108 & 1;
 $110 = ($109<<24>>24)==(0);
 if (!($110)) {
  $111 = (($7) + 8|0);
  $112 = HEAP32[$111>>2]|0;
  __ZdlPv($112);
 }
 HEAP8[$8>>0] = 14;
 $113 = (($8) + 1|0);
 ;HEAP8[$113+0>>0]=HEAP8[567296+0>>0]|0;HEAP8[$113+1>>0]=HEAP8[567296+1>>0]|0;HEAP8[$113+2>>0]=HEAP8[567296+2>>0]|0;HEAP8[$113+3>>0]=HEAP8[567296+3>>0]|0;HEAP8[$113+4>>0]=HEAP8[567296+4>>0]|0;HEAP8[$113+5>>0]=HEAP8[567296+5>>0]|0;HEAP8[$113+6>>0]=HEAP8[567296+6>>0]|0;
 $114 = (($8) + 8|0);
 HEAP8[$114>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1637,($this|0),1,($8|0));
 $115 = __THREW__; __THREW__ = 0;
 $116 = $115&1;
 if ($116) {
  $241 = ___cxa_find_matching_catch()|0;
  $242 = tempRet0;
  $243 = HEAP8[$8>>0]|0;
  $244 = $243 & 1;
  $245 = ($244<<24>>24)==(0);
  if ($245) {
   $$0 = $242;$$01 = $241;
   ___resumeException($$01|0);
   // unreachable;
  }
  $246 = HEAP32[$114>>2]|0;
  __ZdlPv($246);
  $$0 = $242;$$01 = $241;
  ___resumeException($$01|0);
  // unreachable;
 }
 $117 = HEAP8[$8>>0]|0;
 $118 = $117 & 1;
 $119 = ($118<<24>>24)==(0);
 if (!($119)) {
  $120 = HEAP32[$114>>2]|0;
  __ZdlPv($120);
 }
 HEAP8[$9>>0] = 12;
 $121 = (($9) + 1|0);
 ;HEAP8[$121+0>>0]=HEAP8[567304+0>>0]|0;HEAP8[$121+1>>0]=HEAP8[567304+1>>0]|0;HEAP8[$121+2>>0]=HEAP8[567304+2>>0]|0;HEAP8[$121+3>>0]=HEAP8[567304+3>>0]|0;HEAP8[$121+4>>0]=HEAP8[567304+4>>0]|0;HEAP8[$121+5>>0]=HEAP8[567304+5>>0]|0;
 $122 = (($9) + 7|0);
 HEAP8[$122>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1637,($this|0),2,($9|0));
 $123 = __THREW__; __THREW__ = 0;
 $124 = $123&1;
 if ($124) {
  $247 = ___cxa_find_matching_catch()|0;
  $248 = tempRet0;
  $249 = HEAP8[$9>>0]|0;
  $250 = $249 & 1;
  $251 = ($250<<24>>24)==(0);
  if ($251) {
   $$0 = $248;$$01 = $247;
   ___resumeException($$01|0);
   // unreachable;
  }
  $252 = (($9) + 8|0);
  $253 = HEAP32[$252>>2]|0;
  __ZdlPv($253);
  $$0 = $248;$$01 = $247;
  ___resumeException($$01|0);
  // unreachable;
 }
 $125 = HEAP8[$9>>0]|0;
 $126 = $125 & 1;
 $127 = ($126<<24>>24)==(0);
 if (!($127)) {
  $128 = (($9) + 8|0);
  $129 = HEAP32[$128>>2]|0;
  __ZdlPv($129);
 }
 HEAP8[$10>>0] = 20;
 $130 = (($10) + 1|0);
 dest=$130+0|0; src=567312+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $131 = (($10) + 11|0);
 HEAP8[$131>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1637,($this|0),3,($10|0));
 $132 = __THREW__; __THREW__ = 0;
 $133 = $132&1;
 if ($133) {
  $254 = ___cxa_find_matching_catch()|0;
  $255 = tempRet0;
  $256 = HEAP8[$10>>0]|0;
  $257 = $256 & 1;
  $258 = ($257<<24>>24)==(0);
  if ($258) {
   $$0 = $255;$$01 = $254;
   ___resumeException($$01|0);
   // unreachable;
  }
  $259 = (($10) + 8|0);
  $260 = HEAP32[$259>>2]|0;
  __ZdlPv($260);
  $$0 = $255;$$01 = $254;
  ___resumeException($$01|0);
  // unreachable;
 }
 $134 = HEAP8[$10>>0]|0;
 $135 = $134 & 1;
 $136 = ($135<<24>>24)==(0);
 if (!($136)) {
  $137 = (($10) + 8|0);
  $138 = HEAP32[$137>>2]|0;
  __ZdlPv($138);
 }
 HEAP8[$11>>0] = 20;
 $139 = (($11) + 1|0);
 dest=$139+0|0; src=567328+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $140 = (($11) + 11|0);
 HEAP8[$140>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1637,($this|0),5,($11|0));
 $141 = __THREW__; __THREW__ = 0;
 $142 = $141&1;
 if ($142) {
  $261 = ___cxa_find_matching_catch()|0;
  $262 = tempRet0;
  $263 = HEAP8[$11>>0]|0;
  $264 = $263 & 1;
  $265 = ($264<<24>>24)==(0);
  if ($265) {
   $$0 = $262;$$01 = $261;
   ___resumeException($$01|0);
   // unreachable;
  }
  $266 = (($11) + 8|0);
  $267 = HEAP32[$266>>2]|0;
  __ZdlPv($267);
  $$0 = $262;$$01 = $261;
  ___resumeException($$01|0);
  // unreachable;
 }
 $143 = HEAP8[$11>>0]|0;
 $144 = $143 & 1;
 $145 = ($144<<24>>24)==(0);
 if (!($145)) {
  $146 = (($11) + 8|0);
  $147 = HEAP32[$146>>2]|0;
  __ZdlPv($147);
 }
 $148 = (__Znwj(16)|0);
 $149 = (($12) + 8|0);
 HEAP32[$149>>2] = $148;
 HEAP32[$12>>2] = 17;
 $150 = (($12) + 4|0);
 HEAP32[$150>>2] = 14;
 dest=$148+0|0; src=567344+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $151 = (($148) + 14|0);
 HEAP8[$151>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1637,($this|0),7,($12|0));
 $152 = __THREW__; __THREW__ = 0;
 $153 = $152&1;
 if ($153) {
  $268 = ___cxa_find_matching_catch()|0;
  $269 = tempRet0;
  $270 = HEAP8[$12>>0]|0;
  $271 = $270 & 1;
  $272 = ($271<<24>>24)==(0);
  if ($272) {
   $$0 = $269;$$01 = $268;
   ___resumeException($$01|0);
   // unreachable;
  }
  $273 = HEAP32[$149>>2]|0;
  __ZdlPv($273);
  $$0 = $269;$$01 = $268;
  ___resumeException($$01|0);
  // unreachable;
 }
 $154 = HEAP8[$12>>0]|0;
 $155 = $154 & 1;
 $156 = ($155<<24>>24)==(0);
 if (!($156)) {
  $157 = HEAP32[$149>>2]|0;
  __ZdlPv($157);
 }
 HEAP8[$13>>0] = 12;
 $158 = (($13) + 1|0);
 ;HEAP8[$158+0>>0]=HEAP8[567360+0>>0]|0;HEAP8[$158+1>>0]=HEAP8[567360+1>>0]|0;HEAP8[$158+2>>0]=HEAP8[567360+2>>0]|0;HEAP8[$158+3>>0]=HEAP8[567360+3>>0]|0;HEAP8[$158+4>>0]=HEAP8[567360+4>>0]|0;HEAP8[$158+5>>0]=HEAP8[567360+5>>0]|0;
 $159 = (($13) + 7|0);
 HEAP8[$159>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1637,($this|0),6,($13|0));
 $160 = __THREW__; __THREW__ = 0;
 $161 = $160&1;
 if ($161) {
  $274 = ___cxa_find_matching_catch()|0;
  $275 = tempRet0;
  $276 = HEAP8[$13>>0]|0;
  $277 = $276 & 1;
  $278 = ($277<<24>>24)==(0);
  if ($278) {
   $$0 = $275;$$01 = $274;
   ___resumeException($$01|0);
   // unreachable;
  }
  $279 = (($13) + 8|0);
  $280 = HEAP32[$279>>2]|0;
  __ZdlPv($280);
  $$0 = $275;$$01 = $274;
  ___resumeException($$01|0);
  // unreachable;
 }
 $162 = HEAP8[$13>>0]|0;
 $163 = $162 & 1;
 $164 = ($163<<24>>24)==(0);
 if (!($164)) {
  $165 = (($13) + 8|0);
  $166 = HEAP32[$165>>2]|0;
  __ZdlPv($166);
 }
 HEAP8[$14>>0] = 14;
 $167 = (($14) + 1|0);
 ;HEAP8[$167+0>>0]=HEAP8[567368+0>>0]|0;HEAP8[$167+1>>0]=HEAP8[567368+1>>0]|0;HEAP8[$167+2>>0]=HEAP8[567368+2>>0]|0;HEAP8[$167+3>>0]=HEAP8[567368+3>>0]|0;HEAP8[$167+4>>0]=HEAP8[567368+4>>0]|0;HEAP8[$167+5>>0]=HEAP8[567368+5>>0]|0;HEAP8[$167+6>>0]=HEAP8[567368+6>>0]|0;
 $168 = (($14) + 8|0);
 HEAP8[$168>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1638,($this|0),0,($14|0));
 $169 = __THREW__; __THREW__ = 0;
 $170 = $169&1;
 if ($170) {
  $281 = ___cxa_find_matching_catch()|0;
  $282 = tempRet0;
  $283 = HEAP8[$14>>0]|0;
  $284 = $283 & 1;
  $285 = ($284<<24>>24)==(0);
  if ($285) {
   $$0 = $282;$$01 = $281;
   ___resumeException($$01|0);
   // unreachable;
  }
  $286 = HEAP32[$168>>2]|0;
  __ZdlPv($286);
  $$0 = $282;$$01 = $281;
  ___resumeException($$01|0);
  // unreachable;
 }
 $171 = HEAP8[$14>>0]|0;
 $172 = $171 & 1;
 $173 = ($172<<24>>24)==(0);
 if (!($173)) {
  $174 = HEAP32[$168>>2]|0;
  __ZdlPv($174);
 }
 $175 = (__Znwj(16)|0);
 $176 = (($15) + 8|0);
 HEAP32[$176>>2] = $175;
 HEAP32[$15>>2] = 17;
 $177 = (($15) + 4|0);
 HEAP32[$177>>2] = 13;
 dest=$175+0|0; src=567376+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $178 = (($175) + 13|0);
 HEAP8[$178>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1638,($this|0),1,($15|0));
 $179 = __THREW__; __THREW__ = 0;
 $180 = $179&1;
 if ($180) {
  $287 = ___cxa_find_matching_catch()|0;
  $288 = tempRet0;
  $289 = HEAP8[$15>>0]|0;
  $290 = $289 & 1;
  $291 = ($290<<24>>24)==(0);
  if ($291) {
   $$0 = $288;$$01 = $287;
   ___resumeException($$01|0);
   // unreachable;
  }
  $292 = HEAP32[$176>>2]|0;
  __ZdlPv($292);
  $$0 = $288;$$01 = $287;
  ___resumeException($$01|0);
  // unreachable;
 }
 $181 = HEAP8[$15>>0]|0;
 $182 = $181 & 1;
 $183 = ($182<<24>>24)==(0);
 if (!($183)) {
  $184 = HEAP32[$176>>2]|0;
  __ZdlPv($184);
 }
 $185 = (__Znwj(16)|0);
 $186 = (($16) + 8|0);
 HEAP32[$186>>2] = $185;
 HEAP32[$16>>2] = 17;
 $187 = (($16) + 4|0);
 HEAP32[$187>>2] = 14;
 dest=$185+0|0; src=567392+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $188 = (($185) + 14|0);
 HEAP8[$188>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1638,($this|0),2,($16|0));
 $189 = __THREW__; __THREW__ = 0;
 $190 = $189&1;
 if ($190) {
  $293 = ___cxa_find_matching_catch()|0;
  $294 = tempRet0;
  $295 = HEAP8[$16>>0]|0;
  $296 = $295 & 1;
  $297 = ($296<<24>>24)==(0);
  if ($297) {
   $$0 = $294;$$01 = $293;
   ___resumeException($$01|0);
   // unreachable;
  }
  $298 = HEAP32[$186>>2]|0;
  __ZdlPv($298);
  $$0 = $294;$$01 = $293;
  ___resumeException($$01|0);
  // unreachable;
 }
 $191 = HEAP8[$16>>0]|0;
 $192 = $191 & 1;
 $193 = ($192<<24>>24)==(0);
 if (!($193)) {
  $194 = HEAP32[$186>>2]|0;
  __ZdlPv($194);
 }
 HEAP8[$17>>0] = 10;
 $195 = (($17) + 1|0);
 ;HEAP8[$195+0>>0]=HEAP8[567408+0>>0]|0;HEAP8[$195+1>>0]=HEAP8[567408+1>>0]|0;HEAP8[$195+2>>0]=HEAP8[567408+2>>0]|0;HEAP8[$195+3>>0]=HEAP8[567408+3>>0]|0;HEAP8[$195+4>>0]=HEAP8[567408+4>>0]|0;
 $196 = (($17) + 6|0);
 HEAP8[$196>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1638,($this|0),4,($17|0));
 $197 = __THREW__; __THREW__ = 0;
 $198 = $197&1;
 if ($198) {
  $299 = ___cxa_find_matching_catch()|0;
  $300 = tempRet0;
  $301 = HEAP8[$17>>0]|0;
  $302 = $301 & 1;
  $303 = ($302<<24>>24)==(0);
  if ($303) {
   $$0 = $300;$$01 = $299;
   ___resumeException($$01|0);
   // unreachable;
  }
  $304 = (($17) + 8|0);
  $305 = HEAP32[$304>>2]|0;
  __ZdlPv($305);
  $$0 = $300;$$01 = $299;
  ___resumeException($$01|0);
  // unreachable;
 }
 $199 = HEAP8[$17>>0]|0;
 $200 = $199 & 1;
 $201 = ($200<<24>>24)==(0);
 if (!($201)) {
  $202 = (($17) + 8|0);
  $203 = HEAP32[$202>>2]|0;
  __ZdlPv($203);
 }
 HEAP8[$18>>0] = 4;
 $204 = (($18) + 1|0);
 HEAP8[$204>>0]=18773&255;HEAP8[$204+1>>0]=18773>>8;
 $205 = (($18) + 3|0);
 HEAP8[$205>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1638,($this|0),5,($18|0));
 $206 = __THREW__; __THREW__ = 0;
 $207 = $206&1;
 if ($207) {
  $306 = ___cxa_find_matching_catch()|0;
  $307 = tempRet0;
  $308 = HEAP8[$18>>0]|0;
  $309 = $308 & 1;
  $310 = ($309<<24>>24)==(0);
  if ($310) {
   $$0 = $307;$$01 = $306;
   ___resumeException($$01|0);
   // unreachable;
  }
  $311 = (($18) + 8|0);
  $312 = HEAP32[$311>>2]|0;
  __ZdlPv($312);
  $$0 = $307;$$01 = $306;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $208 = HEAP8[$18>>0]|0;
  $209 = $208 & 1;
  $210 = ($209<<24>>24)==(0);
  if ($210) {
   STACKTOP = sp;return;
  }
  $211 = (($18) + 8|0);
  $212 = HEAP32[$211>>2]|0;
  __ZdlPv($212);
  STACKTOP = sp;return;
 }
}
function __ZN10TagManager11StringToTagERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$tag) {
 $this = $this|0;
 $tag = $tag|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $i = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($i,$1,$tag);
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$i>>2]|0;
 $5 = ($4|0)==($3|0);
 if ($5) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($4) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10TagManager13StringToLayerERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$tag) {
 $this = $this|0;
 $tag = $tag|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $i = sp;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($i,$1,$tag);
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$i>>2]|0;
 $5 = ($4|0)==($3|0);
 if ($5) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($4) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10TagManager13LayerToStringEj($this,$layer) {
 $this = $this|0;
 $layer = $layer|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($layer>>>0)>(31);
 if ($0) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(567416,0,567120,275,1,0,0,0);
  $$0 = 566992;
  STACKTOP = sp;return ($$0|0);
 } else {
  $1 = ((($this) + (($layer*12)|0)|0) + 40|0);
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10TagManager32GetSortingLayerValueFromUniqueIDEi($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($id|0)==(0);
 L1: do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (($this) + 428|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = (($this) + 424|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($2|0)==($4|0);
   if ($5) {
    $$0 = 0;
   } else {
    $i$02 = 0;
    while(1) {
     $12 = ((($4) + (($i$02*20)|0)|0) + 12|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==($id|0);
     $11 = (($i$02) + 1)|0;
     if ($14) {
      break;
     }
     $6 = $2;
     $7 = $4;
     $8 = (($6) - ($7))|0;
     $9 = (($8|0) / 20)&-1;
     $10 = ($11>>>0)<($9>>>0);
     if ($10) {
      $i$02 = $11;
     } else {
      $$0 = 0;
      break L1;
     }
    }
    $15 = (($this) + 436|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($i$02) - ($16))|0;
    $$0 = $17;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z24RegisterClass_TagManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(78,85,0,0,0);
 STACKTOP = sp;return;
}
function __ZN10TagManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 HEAP8[$0>>0] = 20;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=567448+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 11|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,78,6,($0|0),440,(2360|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN10TagManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(440,$$byval_copy2,1,16,567120,77)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1639,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(567120|0),77);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK10TagManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 78;
}
function __ZN10TagManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567464,567448,$this,0);
 __ZN10TagManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10TagManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,567464,567448,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN10TagManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10TagManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10TagManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10TagManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10TagManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10TagManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10TagManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10TagManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10TagManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z13GetTagManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(2)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN10TagManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10TagManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN10TagManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3386,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN10TagManager39ShouldIgnoreInGarbageDependencyTrackingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN10TagManager6UpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10TagManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$1 = 0, $$12 = 0, $$byval_copy15 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i14 = 0, $$pre$i$i$i$i$i28 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i30 = 0, $$pre40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $i3$039 = 0, $layers = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi38$index = 0, $lpad$phi38$index7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy15 = sp + 44|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $layers = sp + 20|0;
 $5 = sp + 32|0;
 HEAP32[$layers>>2] = 0;
 $6 = (($layers) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($layers) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($5) + 1|0);
 $9 = (($5) + 8|0);
 $10 = (($5) + 4|0);
 $i3$039 = 0;
 while(1) {
  $11 = ((($this) + (($i3$039*12)|0)|0) + 40|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $19 = (($11) + 1|0);
   $20 = $12&255;
   $21 = $20 >>> 1;
   $23 = $21;$36 = $19;
  } else {
   $15 = ((($this) + (($i3$039*12)|0)|0) + 48|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($this) + (($i3$039*12)|0)|0) + 44|0);
   $18 = HEAP32[$17>>2]|0;
   $23 = $18;$36 = $16;
  }
  $22 = ($23>>>0)>(2147483631);
  if ($22) {
   label = 6;
   break;
  }
  $26 = ($23>>>0)<(11);
  if ($26) {
   $27 = $23 << 1;
   $28 = $27&255;
   HEAP8[$5>>0] = $28;
   $43 = $28;$__p$0$i$i$i$i = $8;
  } else {
   $29 = (($23) + 16)|0;
   $30 = $29 & -16;
   HEAP32[$3>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;
   $31 = (invoke_iiiiiii(102,($30|0),16,($$byval_copy15|0),0,(567120|0),79)|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    label = 32;
    break;
   }
   HEAP32[$9>>2] = $31;
   $34 = $30 | 1;
   HEAP32[$5>>2] = $34;
   HEAP32[$10>>2] = $23;
   $35 = $34&255;
   $43 = $35;$__p$0$i$i$i$i = $31;
  }
  _memcpy(($__p$0$i$i$i$i|0),($36|0),($23|0))|0;
  $37 = (($__p$0$i$i$i$i) + ($23)|0);
  HEAP8[$37>>0] = 0;
  $38 = HEAP32[$6>>2]|0;
  $39 = HEAP32[$7>>2]|0;
  $40 = ($38|0)==($39|0);
  if ($40) {
   __THREW__ = 0;
   invoke_vii(2602,($layers|0),($5|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 35;
    break;
   }
   $$pre40 = HEAP8[$5>>0]|0;
   $72 = $$pre40;
  } else {
   $41 = ($38|0)==(0|0);
   if ($41) {
    $68 = 0;
   } else {
    $42 = $43 & 1;
    $44 = ($42<<24>>24)==(0);
    if ($44) {
     $47 = $43&255;
     $48 = $47 >>> 1;
     $50 = $48;$65 = $8;
    } else {
     $45 = HEAP32[$9>>2]|0;
     $46 = HEAP32[$10>>2]|0;
     $50 = $46;$65 = $45;
    }
    $49 = ($50>>>0)>(2147483631);
    if ($49) {
     label = 18;
     break;
    }
    $53 = ($50>>>0)<(11);
    if ($53) {
     $54 = $50 << 1;
     $55 = $54&255;
     HEAP8[$38>>0] = $55;
     $56 = (($38) + 1|0);
     $__p$0$i$i$i$i$i$i = $56;
    } else {
     $57 = (($50) + 16)|0;
     $58 = $57 & -16;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
     $59 = (invoke_iiiiiii(102,($58|0),16,($$byval_copy15|0),0,(567120|0),79)|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 35;
      break;
     }
     $62 = (($38) + 8|0);
     HEAP32[$62>>2] = $59;
     $63 = $58 | 1;
     HEAP32[$38>>2] = $63;
     $64 = (($38) + 4|0);
     HEAP32[$64>>2] = $50;
     $__p$0$i$i$i$i$i$i = $59;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($65|0),($50|0))|0;
    $66 = (($__p$0$i$i$i$i$i$i) + ($50)|0);
    HEAP8[$66>>0] = 0;
    $$pre$i = HEAP32[$6>>2]|0;
    $68 = $$pre$i;
   }
   $67 = (($68) + 12|0);
   HEAP32[$6>>2] = $67;
   $72 = $43;
  }
  $71 = $72 & 1;
  $73 = ($71<<24>>24)==(0);
  if (!($73)) {
   $74 = HEAP32[$9>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($74|0),($$byval_copy15|0));
   $75 = __THREW__; __THREW__ = 0;
   $76 = $75&1;
   if ($76) {
    label = 30;
    break;
   }
  }
  $79 = (($i3$039) + 1)|0;
  $80 = ($79|0)<(32);
  if ($80) {
   $i3$039 = $79;
  } else {
   label = 40;
   break;
  }
 }
 do {
  if ((label|0) == 6) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $83 = ___cxa_find_matching_catch()|0;
    $84 = tempRet0;
    $lpad$phi$index = $83;$lpad$phi$index2 = $84;
    label = 34;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 18) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    $87 = ___cxa_find_matching_catch()|0;
    $88 = tempRet0;
    $90 = $43;$lpad$phi38$index = $87;$lpad$phi38$index7 = $88;
    label = 37;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 30) {
   $77 = ___cxa_find_matching_catch()|0;
   $78 = tempRet0;
   ___cxa_call_unexpected(($77|0));
   // unreachable;
  }
  else if ((label|0) == 32) {
   $81 = ___cxa_find_matching_catch()|0;
   $82 = tempRet0;
   $lpad$phi$index = $81;$lpad$phi$index2 = $82;
   label = 34;
  }
  else if ((label|0) == 35) {
   $85 = ___cxa_find_matching_catch()|0;
   $86 = tempRet0;
   $$pre = HEAP8[$5>>0]|0;
   $90 = $$pre;$lpad$phi38$index = $85;$lpad$phi38$index7 = $86;
   label = 37;
  }
  else if ((label|0) == 40) {
   $97 = HEAP32[$layers>>2]|0;
   $98 = ($97|0)==(0|0);
   if ($98) {
    STACKTOP = sp;return;
   }
   $99 = HEAP32[$6>>2]|0;
   $100 = ($99|0)==($97|0);
   do {
    if ($100) {
     $114 = $97;
    } else {
     $102 = $99;
     while(1) {
      $101 = (($102) + -12|0);
      HEAP32[$6>>2] = $101;
      $103 = HEAP8[$101>>0]|0;
      $104 = $103 & 1;
      $105 = ($104<<24>>24)==(0);
      if ($105) {
       $107 = $101;
      } else {
       $108 = (($102) + -4|0);
       $109 = HEAP32[$108>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($109|0),($$byval_copy15|0));
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if ($111) {
        label = 47;
        break;
       }
       $$pre$i$i$i$i$i28 = HEAP32[$6>>2]|0;
       $107 = $$pre$i$i$i$i$i28;
      }
      $106 = ($107|0)==($97|0);
      if ($106) {
       label = 48;
       break;
      } else {
       $102 = $107;
      }
     }
     if ((label|0) == 47) {
      $112 = ___cxa_find_matching_catch()|0;
      $113 = tempRet0;
      ___cxa_call_unexpected(($112|0));
      // unreachable;
     }
     else if ((label|0) == 48) {
      $$pre$i$i$i30 = HEAP32[$layers>>2]|0;
      $114 = $$pre$i$i$i30;
      break;
     }
    }
   } while(0);
   __ZdlPv($114);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 34) {
  $$1 = $lpad$phi$index;$$12 = $lpad$phi$index2;
 }
 else if ((label|0) == 37) {
  $89 = $90 & 1;
  $91 = ($89<<24>>24)==(0);
  if ($91) {
   $$1 = $lpad$phi38$index;$$12 = $lpad$phi38$index7;
  } else {
   $92 = HEAP32[$9>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($92|0),($$byval_copy15|0));
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $95 = ___cxa_find_matching_catch()|0;
    $96 = tempRet0;
    ___cxa_call_unexpected(($95|0));
    // unreachable;
   } else {
    $$1 = $lpad$phi38$index;$$12 = $lpad$phi38$index7;
   }
  }
 }
 $115 = HEAP32[$layers>>2]|0;
 $116 = ($115|0)==(0|0);
 if ($116) {
  ___resumeException($$1|0);
  // unreachable;
 }
 $117 = HEAP32[$6>>2]|0;
 $118 = ($117|0)==($115|0);
 do {
  if ($118) {
   $132 = $115;
  } else {
   $120 = $117;
   while(1) {
    $119 = (($120) + -12|0);
    HEAP32[$6>>2] = $119;
    $121 = HEAP8[$119>>0]|0;
    $122 = $121 & 1;
    $123 = ($122<<24>>24)==(0);
    if ($123) {
     $125 = $119;
    } else {
     $126 = (($120) + -4|0);
     $127 = HEAP32[$126>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($127|0),($$byval_copy15|0));
     $128 = __THREW__; __THREW__ = 0;
     $129 = $128&1;
     if ($129) {
      label = 57;
      break;
     }
     $$pre$i$i$i$i$i14 = HEAP32[$6>>2]|0;
     $125 = $$pre$i$i$i$i$i14;
    }
    $124 = ($125|0)==($115|0);
    if ($124) {
     label = 58;
     break;
    } else {
     $120 = $125;
    }
   }
   if ((label|0) == 57) {
    $130 = ___cxa_find_matching_catch()|0;
    $131 = tempRet0;
    ___cxa_call_unexpected(($130|0));
    // unreachable;
   }
   else if ((label|0) == 58) {
    $$pre$i$i$i16 = HEAP32[$layers>>2]|0;
    $132 = $$pre$i$i$i16;
    break;
   }
  }
 } while(0);
 __ZdlPv($132);
 ___resumeException($$1|0);
 // unreachable;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add,$__p_new_stuff) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 $__p_new_stuff = $__p_new_stuff|0;
 var $$byval_copy1 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (2147483630 - ($__old_cap))|0;
 $2 = ($1>>>0)<($__delta_cap>>>0);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($this) + 1|0);
  $20 = $8;
 } else {
  $6 = (($this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $20 = $7;
 }
 $9 = ($__old_cap>>>0)<(1073741799);
 if ($9) {
  $10 = (($__delta_cap) + ($__old_cap))|0;
  $11 = $__old_cap << 1;
  $12 = ($10>>>0)<($11>>>0);
  $13 = $12 ? $11 : $10;
  $14 = ($13>>>0)<(11);
  if ($14) {
   $17 = 11;
  } else {
   $15 = (($13) + 16)|0;
   $16 = $15 & -16;
   $17 = $16;
  }
 } else {
  $17 = 2147483631;
 }
 HEAP32[$0>>2] = 59;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($17,16,$$byval_copy1,0,567120,79)|0);
 $19 = ($__n_copy|0)==(0);
 if (!($19)) {
  _memcpy(($18|0),($20|0),($__n_copy|0))|0;
 }
 $21 = ($__n_add|0)==(0);
 if (!($21)) {
  $22 = (($18) + ($__n_copy)|0);
  _memcpy(($22|0),($__p_new_stuff|0),($__n_add|0))|0;
 }
 $23 = (($__old_sz) - ($__n_del))|0;
 $24 = ($23|0)==($__n_copy|0);
 if (!($24)) {
  $25 = (($23) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $26 = (($18) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $27 = (($20) + ($$sum1)|0);
  _memcpy(($26|0),($27|0),($25|0))|0;
 }
 $28 = ($__old_cap|0)==(10);
 if ($28) {
  $33 = (($this) + 8|0);
  HEAP32[$33>>2] = $18;
  $34 = $17 | 1;
  HEAP32[$this>>2] = $34;
  $35 = (($23) + ($__n_add))|0;
  $36 = (($this) + 4|0);
  HEAP32[$36>>2] = $35;
  $37 = (($18) + ($35)|0);
  HEAP8[$37>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($20|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  ___cxa_call_unexpected(($31|0));
  // unreachable;
 } else {
  $33 = (($this) + 8|0);
  HEAP32[$33>>2] = $18;
  $34 = $17 | 1;
  HEAP32[$this>>2] = $34;
  $35 = (($23) + ($__n_add))|0;
  $36 = (($this) + 4|0);
  HEAP32[$36>>2] = $35;
  $37 = (($18) + ($35)|0);
  HEAP8[$37>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i8 = 0, $$0$i9 = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = (($9) + 1)|0;
 $11 = ($10>>>0)>(357913941);
 if ($11) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($7))|0;
 $16 = (($15|0) / 12)&-1;
 $17 = ($16>>>0)<(178956970);
 if ($17) {
  $20 = $16 << 1;
  $21 = ($20>>>0)<($10>>>0);
  $22 = $21 ? $10 : $20;
  $23 = (($__v) + 12|0);
  HEAP32[$23>>2] = 0;
  $24 = (($__v) + 16|0);
  HEAP32[$24>>2] = $2;
  $25 = ($22|0)==(0);
  if ($25) {
   $$0$i9 = 0;$28 = 0;$33 = $23;
  } else {
   $$0$i8 = $22;$103 = $23;
   label = 6;
  }
 } else {
  $18 = (($__v) + 12|0);
  HEAP32[$18>>2] = 0;
  $19 = (($__v) + 16|0);
  HEAP32[$19>>2] = $2;
  $$0$i8 = 357913941;$103 = $18;
  label = 6;
 }
 if ((label|0) == 6) {
  $26 = ($$0$i8*12)|0;
  $27 = (__Znwj($26)|0);
  $$0$i9 = $$0$i8;$28 = $27;$33 = $103;
 }
 HEAP32[$__v>>2] = $28;
 $29 = (($28) + (($9*12)|0)|0);
 $30 = (($__v) + 8|0);
 HEAP32[$30>>2] = $29;
 $31 = (($__v) + 4|0);
 HEAP32[$31>>2] = $29;
 $32 = (($28) + (($$0$i9*12)|0)|0);
 HEAP32[$33>>2] = $32;
 $34 = ($29|0)==(0|0);
 do {
  if ($34) {
   $64 = 0;
   label = 19;
  } else {
   $35 = HEAP8[$__x>>0]|0;
   $36 = $35 & 1;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    $42 = (($__x) + 1|0);
    $43 = $35&255;
    $44 = $43 >>> 1;
    $46 = $44;$61 = $42;
   } else {
    $38 = (($__x) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($__x) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $46 = $41;$61 = $39;
   }
   $45 = ($46>>>0)>(2147483631);
   if ($45) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    // unreachable;
   }
   $49 = ($46>>>0)<(11);
   if ($49) {
    $50 = $46 << 1;
    $51 = $50&255;
    HEAP8[$29>>0] = $51;
    $52 = (($29) + 1|0);
    $__p$0$i$i$i$i$i = $52;
   } else {
    $53 = (($46) + 16)|0;
    $54 = $53 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $55 = (invoke_iiiiiii(102,($54|0),16,($$byval_copy2|0),0,(567120|0),79)|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = ((($28) + (($9*12)|0)|0) + 8|0);
    HEAP32[$58>>2] = $55;
    $59 = $54 | 1;
    HEAP32[$29>>2] = $59;
    $60 = ((($28) + (($9*12)|0)|0) + 4|0);
    HEAP32[$60>>2] = $46;
    $__p$0$i$i$i$i$i = $55;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($61|0),($46|0))|0;
   $62 = (($__p$0$i$i$i$i$i) + ($46)|0);
   HEAP8[$62>>0] = 0;
   $$pre = HEAP32[$30>>2]|0;
   $64 = $$pre;
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  $63 = (($64) + 12|0);
  HEAP32[$30>>2] = $63;
  __THREW__ = 0;
  invoke_vii(2603,($this|0),($__v|0));
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if (!($66)) {
   $67 = HEAP32[$31>>2]|0;
   $68 = HEAP32[$30>>2]|0;
   $69 = ($68|0)==($67|0);
   L28: do {
    if (!($69)) {
     $71 = $68;
     while(1) {
      $70 = (($71) + -12|0);
      HEAP32[$30>>2] = $70;
      $72 = HEAP8[$70>>0]|0;
      $73 = $72 & 1;
      $74 = ($73<<24>>24)==(0);
      if (!($74)) {
       $76 = (($71) + -4|0);
       $77 = HEAP32[$76>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($77|0),($$byval_copy2|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
      }
      $75 = ($70|0)==($67|0);
      if ($75) {
       break L28;
      } else {
       $71 = $70;
      }
     }
     $80 = ___cxa_find_matching_catch()|0;
     $81 = tempRet0;
     ___cxa_call_unexpected(($80|0));
     // unreachable;
    }
   } while(0);
   $82 = HEAP32[$__v>>2]|0;
   $83 = ($82|0)==(0|0);
   if ($83) {
    STACKTOP = sp;return;
   }
   __ZdlPv($82);
   STACKTOP = sp;return;
  }
 }
 $84 = ___cxa_find_matching_catch()|0;
 $85 = tempRet0;
 $86 = HEAP32[$31>>2]|0;
 $87 = HEAP32[$30>>2]|0;
 $88 = ($87|0)==($86|0);
 L42: do {
  if (!($88)) {
   $90 = $87;
   while(1) {
    $89 = (($90) + -12|0);
    HEAP32[$30>>2] = $89;
    $91 = HEAP8[$89>>0]|0;
    $92 = $91 & 1;
    $93 = ($92<<24>>24)==(0);
    if (!($93)) {
     $95 = (($90) + -4|0);
     $96 = HEAP32[$95>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($96|0),($$byval_copy2|0));
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      break;
     }
    }
    $94 = ($89|0)==($86|0);
    if ($94) {
     break L42;
    } else {
     $90 = $89;
    }
   }
   $99 = ___cxa_find_matching_catch()|0;
   $100 = tempRet0;
   ___cxa_call_unexpected(($99|0));
   // unreachable;
  }
 } while(0);
 $101 = HEAP32[$__v>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  ___resumeException($84|0);
  // unreachable;
 }
 __ZdlPv($101);
 ___resumeException($84|0);
 // unreachable;
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__v) + 4|0);
 $5 = ($3|0)==($1|0);
 do {
  if ($5) {
   $$pre1 = HEAP32[$4>>2]|0;
   $36 = $$pre1;$37 = $1;
  } else {
   $$pre$i = HEAP32[$4>>2]|0;
   $$01$i = $3;$7 = $$pre$i;
   while(1) {
    $6 = (($7) + -12|0);
    $8 = (($$01$i) + -12|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9 & 1;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $16 = (($8) + 1|0);
     $17 = $9&255;
     $18 = $17 >>> 1;
     $20 = $18;$31 = $16;
    } else {
     $12 = (($$01$i) + -4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($$01$i) + -8|0);
     $15 = HEAP32[$14>>2]|0;
     $20 = $15;$31 = $13;
    }
    $19 = ($20>>>0)>(2147483631);
    if ($19) {
     label = 8;
     break;
    }
    $21 = ($20>>>0)<(11);
    if ($21) {
     $22 = $20 << 1;
     $23 = $22&255;
     HEAP8[$6>>0] = $23;
     $24 = (($6) + 1|0);
     $__p$0$i$i$i$i$i$i = $24;
    } else {
     $25 = (($20) + 16)|0;
     $26 = $25 & -16;
     HEAP32[$0>>2] = 59;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $27 = (__Z15malloc_internaljj10MemLabelIdiPKci($26,16,$$byval_copy,0,567120,79)|0);
     $28 = (($7) + -4|0);
     HEAP32[$28>>2] = $27;
     $29 = $26 | 1;
     HEAP32[$6>>2] = $29;
     $30 = (($7) + -8|0);
     HEAP32[$30>>2] = $20;
     $__p$0$i$i$i$i$i$i = $27;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($31|0),($20|0))|0;
    $32 = (($__p$0$i$i$i$i$i$i) + ($20)|0);
    HEAP8[$32>>0] = 0;
    $33 = HEAP32[$4>>2]|0;
    $34 = (($33) + -12|0);
    HEAP32[$4>>2] = $34;
    $35 = ($8|0)==($1|0);
    if ($35) {
     label = 13;
     break;
    } else {
     $$01$i = $8;$7 = $34;
    }
   }
   if ((label|0) == 8) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre = HEAP32[$this>>2]|0;
    $36 = $34;$37 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $36;
 HEAP32[$4>>2] = $37;
 $38 = (($__v) + 8|0);
 $39 = HEAP32[$2>>2]|0;
 $40 = HEAP32[$38>>2]|0;
 HEAP32[$2>>2] = $40;
 HEAP32[$38>>2] = $39;
 $41 = (($this) + 8|0);
 $42 = (($__v) + 12|0);
 $43 = HEAP32[$41>>2]|0;
 $44 = HEAP32[$42>>2]|0;
 HEAP32[$41>>2] = $44;
 HEAP32[$42>>2] = $43;
 $45 = HEAP32[$4>>2]|0;
 HEAP32[$__v>>2] = $45;
 STACKTOP = sp;return;
}
function __ZN10TagManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i19 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i13 = 0, $$01$i$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i14 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i16 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy35 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0;
 var $$pre$i$i$i$i$i59 = 0, $$pre$i$i$i$i$i6 = 0, $$pre$i$i$i$i$i67 = 0, $$pre$i$i$i61 = 0, $$pre$i$i$i69 = 0, $$pre$i$i$i8 = 0, $$pre$i41 = 0, $$pre111 = 0, $$pre112 = 0, $$pre113 = 0, $$pre114 = 0, $$pre115 = 0, $$pre116 = 0, $$pre117 = 0, $$pre118 = 0, $$pre119 = 0, $$pre120 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i40 = 0, $__p$0$i$i$i$i33 = 0, $i3$081 = 0, $layers = 0, $lpad$phi$index = 0, $lpad$phi$index15 = 0, $lpad$phi80$index = 0, $lpad$phi80$index21 = 0, $lpad$phi86$index = 0;
 var $lpad$phi86$index3 = 0, $lpad$phi96$index = 0, $lpad$phi96$index9 = 0, $size$i$i$i = 0, $size$i$i$i50 = 0, $tags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy35 = sp + 100|0;
 $0 = sp + 96|0;
 $1 = sp + 92|0;
 $size$i$i$i50 = sp + 88|0;
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 72|0;
 $size$i$i$i = sp + 68|0;
 $6 = sp + 64|0;
 $7 = sp + 48|0;
 $8 = sp + 44|0;
 $9 = sp + 40|0;
 $10 = sp + 36|0;
 $tags = sp + 24|0;
 $11 = sp + 12|0;
 $layers = sp;
 $12 = sp + 52|0;
 HEAP32[$tags>>2] = 0;
 $13 = (($tags) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($tags) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4|0);
 $20 = ($18|0)==(0|0);
 L1: do {
  if ($20) {
   $139 = 0;$141 = 0;
   label = 57;
  } else {
   $$0$ph7$i$i$i = $19;$$01$ph6$i$in$i$i = $18;
   L2: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $21 = (($$013$i$in$i$i) + 16|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22>>>0)<(20000);
     if (!($23)) {
      break;
     }
     $26 = (($$013$i$in$i$i) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==(0|0);
     if ($28) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L2;
     } else {
      $$013$i$in$i$i = $27;
     }
    }
    $24 = HEAP32[$$013$i$in$i$i>>2]|0;
    $25 = ($24|0)==(0|0);
    if ($25) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $24;
    }
   }
   L9: do {
    if ($20) {
     $$0$ph5$i$i$i19 = $19;
    } else {
     $$0$ph7$i$i$i13 = $19;$$01$ph6$i$in$i$i14 = $18;
     while(1) {
      $$013$i$in$i$i16 = $$01$ph6$i$in$i$i14;
      while(1) {
       $29 = (($$013$i$in$i$i16) + 16|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30>>>0)>(30000);
       if ($31) {
        break;
       }
       $34 = (($$013$i$in$i$i16) + 4|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = ($35|0)==(0|0);
       if ($36) {
        $$0$ph5$i$i$i19 = $$0$ph7$i$i$i13;
        break L9;
       } else {
        $$013$i$in$i$i16 = $35;
       }
      }
      $32 = HEAP32[$$013$i$in$i$i16>>2]|0;
      $33 = ($32|0)==(0|0);
      if ($33) {
       $$0$ph5$i$i$i19 = $$013$i$in$i$i16;
       break;
      } else {
       $$0$ph7$i$i$i13 = $$013$i$in$i$i16;$$01$ph6$i$in$i$i14 = $32;
      }
     }
    }
   } while(0);
   $37 = ($$0$ph5$i$i$i|0)==($$0$ph5$i$i$i19|0);
   if ($37) {
    $139 = 0;$141 = 0;
    label = 57;
   } else {
    $38 = (($11) + 1|0);
    $39 = (($11) + 8|0);
    $40 = (($11) + 4|0);
    $42 = $$0$ph5$i$i$i;
    while(1) {
     $41 = (($42) + 20|0);
     $43 = HEAP8[$41>>0]|0;
     $44 = $43 & 1;
     $45 = ($44<<24>>24)==(0);
     if ($45) {
      $50 = (($41) + 1|0);
      $51 = $43&255;
      $52 = $51 >>> 1;
      $54 = $52;$67 = $50;
     } else {
      $46 = (($42) + 28|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = (($42) + 24|0);
      $49 = HEAP32[$48>>2]|0;
      $54 = $49;$67 = $47;
     }
     $53 = ($54>>>0)>(2147483631);
     if ($53) {
      label = 17;
      break;
     }
     $57 = ($54>>>0)<(11);
     if ($57) {
      $58 = $54 << 1;
      $59 = $58&255;
      HEAP8[$11>>0] = $59;
      $74 = $59;$__p$0$i$i$i$i = $38;
     } else {
      $60 = (($54) + 16)|0;
      $61 = $60 & -16;
      HEAP32[$9>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$9+0>>2]|0;
      $62 = (invoke_iiiiiii(102,($61|0),16,($$byval_copy35|0),0,(567120|0),79)|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       label = 48;
       break;
      }
      HEAP32[$39>>2] = $62;
      $65 = $61 | 1;
      HEAP32[$11>>2] = $65;
      HEAP32[$40>>2] = $54;
      $66 = $65&255;
      $74 = $66;$__p$0$i$i$i$i = $62;
     }
     _memcpy(($__p$0$i$i$i$i|0),($67|0),($54|0))|0;
     $68 = (($__p$0$i$i$i$i) + ($54)|0);
     HEAP8[$68>>0] = 0;
     $69 = HEAP32[$13>>2]|0;
     $70 = HEAP32[$14>>2]|0;
     $71 = ($69|0)==($70|0);
     if ($71) {
      __THREW__ = 0;
      invoke_vii(2602,($tags|0),($11|0));
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       label = 51;
       break;
      }
      $$pre120 = HEAP8[$11>>0]|0;
      $103 = $$pre120;
     } else {
      $72 = ($69|0)==(0|0);
      if ($72) {
       $99 = 0;
      } else {
       $73 = $74 & 1;
       $75 = ($73<<24>>24)==(0);
       if ($75) {
        $78 = $74&255;
        $79 = $78 >>> 1;
        $81 = $79;$96 = $38;
       } else {
        $76 = HEAP32[$39>>2]|0;
        $77 = HEAP32[$40>>2]|0;
        $81 = $77;$96 = $76;
       }
       $80 = ($81>>>0)>(2147483631);
       if ($80) {
        label = 29;
        break;
       }
       $84 = ($81>>>0)<(11);
       if ($84) {
        $85 = $81 << 1;
        $86 = $85&255;
        HEAP8[$69>>0] = $86;
        $87 = (($69) + 1|0);
        $__p$0$i$i$i$i$i$i = $87;
       } else {
        $88 = (($81) + 16)|0;
        $89 = $88 & -16;
        HEAP32[$8>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$8+0>>2]|0;
        $90 = (invoke_iiiiiii(102,($89|0),16,($$byval_copy35|0),0,(567120|0),79)|0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         label = 51;
         break;
        }
        $93 = (($69) + 8|0);
        HEAP32[$93>>2] = $90;
        $94 = $89 | 1;
        HEAP32[$69>>2] = $94;
        $95 = (($69) + 4|0);
        HEAP32[$95>>2] = $81;
        $__p$0$i$i$i$i$i$i = $90;
       }
       _memcpy(($__p$0$i$i$i$i$i$i|0),($96|0),($81|0))|0;
       $97 = (($__p$0$i$i$i$i$i$i) + ($81)|0);
       HEAP8[$97>>0] = 0;
       $$pre$i = HEAP32[$13>>2]|0;
       $99 = $$pre$i;
      }
      $98 = (($99) + 12|0);
      HEAP32[$13>>2] = $98;
      $103 = $74;
     }
     $102 = $103 & 1;
     $104 = ($102<<24>>24)==(0);
     if (!($104)) {
      $105 = HEAP32[$39>>2]|0;
      HEAP32[$7>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$7+0>>2]|0;
      invoke_vii(2591,($105|0),($$byval_copy35|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       label = 41;
       break;
      }
     }
     $110 = (($42) + 4|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ($111|0)==(0|0);
     if ($112) {
      $$01$i$i$i$i = $42;
      while(1) {
       $115 = (($$01$i$i$i$i) + 8|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = HEAP32[$116>>2]|0;
       $118 = ($117|0)==($$01$i$i$i$i|0);
       if ($118) {
        $$0$i$i$i$i = $116;
        break;
       } else {
        $$01$i$i$i$i = $116;
       }
      }
     } else {
      $$0$i$i$i$i$i = $111;
      while(1) {
       $113 = HEAP32[$$0$i$i$i$i$i>>2]|0;
       $114 = ($113|0)==(0|0);
       if ($114) {
        $$0$i$i$i$i = $$0$i$i$i$i$i;
        break;
       } else {
        $$0$i$i$i$i$i = $113;
       }
      }
     }
     $119 = ($$0$i$i$i$i|0)==($$0$ph5$i$i$i19|0);
     if ($119) {
      label = 56;
      break;
     } else {
      $42 = $$0$i$i$i$i;
     }
    }
    do {
     if ((label|0) == 17) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 49;
       break L1;
      }
      // unreachable;
     }
     else if ((label|0) == 29) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       $128 = ___cxa_find_matching_catch()|0;
       $129 = tempRet0;
       $131 = $74;$lpad$phi96$index = $128;$lpad$phi96$index9 = $129;
       break;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 41) {
      $108 = ___cxa_find_matching_catch()|0;
      $109 = tempRet0;
      ___cxa_call_unexpected(($108|0));
      // unreachable;
     }
     else if ((label|0) == 48) {
      $122 = ___cxa_find_matching_catch()|0;
      $123 = tempRet0;
      $lpad$phi86$index = $122;$lpad$phi86$index3 = $123;
      label = 50;
      break L1;
     }
     else if ((label|0) == 51) {
      $126 = ___cxa_find_matching_catch()|0;
      $127 = tempRet0;
      $$pre114 = HEAP8[$11>>0]|0;
      $131 = $$pre114;$lpad$phi96$index = $126;$lpad$phi96$index9 = $127;
     }
     else if ((label|0) == 56) {
      $$pre = HEAP32[$13>>2]|0;
      $$pre111 = HEAP32[$tags>>2]|0;
      $139 = $$pre;$141 = $$pre111;
      label = 57;
      break L1;
     }
    } while(0);
    $130 = $131 & 1;
    $132 = ($130<<24>>24)==(0);
    if ($132) {
     $$2 = $lpad$phi96$index;$$23 = $lpad$phi96$index9;
    } else {
     $133 = HEAP32[$39>>2]|0;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($133|0),($$byval_copy35|0));
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      $136 = ___cxa_find_matching_catch()|0;
      $137 = tempRet0;
      ___cxa_call_unexpected(($136|0));
      // unreachable;
     } else {
      $$2 = $lpad$phi96$index;$$23 = $lpad$phi96$index9;
     }
    }
   }
  }
 } while(0);
 L72: do {
  if ((label|0) == 57) {
   $138 = $139;
   $140 = $141;
   $142 = (($138) - ($140))|0;
   $143 = (($142|0) / 12)&-1;
   HEAP32[$size$i$i$i>>2] = $143;
   $144 = (($transfer) + 12|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = (($145) + 4|0);
   $147 = (($transfer) + 20|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = ($146>>>0)<($148>>>0);
   if ($149) {
    HEAP32[$145>>2] = $143;
    HEAP32[$144>>2] = $146;
    $153 = $141;$154 = $139;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($144|0),($size$i$i$i|0),4);
    $150 = __THREW__; __THREW__ = 0;
    $151 = $150&1;
    if ($151) {
     label = 49;
     break;
    }
    $$pre115 = HEAP32[$13>>2]|0;
    $$pre116 = HEAP32[$tags>>2]|0;
    $153 = $$pre116;$154 = $$pre115;
   }
   $152 = ($153|0)==($154|0);
   L79: do {
    if (!($152)) {
     $155 = $153;
     while(1) {
      __THREW__ = 0;
      invoke_viii(1641,($transfer|0),($155|0),0);
      $156 = __THREW__; __THREW__ = 0;
      $157 = $156&1;
      if ($157) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3378,($transfer|0));
      $158 = __THREW__; __THREW__ = 0;
      $159 = $158&1;
      if ($159) {
       break;
      }
      $160 = (($155) + 12|0);
      $161 = ($160|0)==($154|0);
      if ($161) {
       break L79;
      } else {
       $155 = $160;
      }
     }
     $120 = ___cxa_find_matching_catch()|0;
     $121 = tempRet0;
     $lpad$phi86$index = $120;$lpad$phi86$index3 = $121;
     label = 50;
     break L72;
    }
   } while(0);
   HEAP32[$layers>>2] = 0;
   $162 = (($layers) + 4|0);
   HEAP32[$162>>2] = 0;
   $163 = (($layers) + 8|0);
   HEAP32[$163>>2] = 0;
   $164 = (($12) + 1|0);
   $165 = (($12) + 8|0);
   $166 = (($12) + 4|0);
   $i3$081 = 0;
   while(1) {
    $167 = ((($this) + (($i3$081*12)|0)|0) + 40|0);
    $168 = HEAP8[$167>>0]|0;
    $169 = $168 & 1;
    $170 = ($169<<24>>24)==(0);
    if ($170) {
     $175 = (($167) + 1|0);
     $176 = $168&255;
     $177 = $176 >>> 1;
     $179 = $177;$192 = $175;
    } else {
     $171 = ((($this) + (($i3$081*12)|0)|0) + 48|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = ((($this) + (($i3$081*12)|0)|0) + 44|0);
     $174 = HEAP32[$173>>2]|0;
     $179 = $174;$192 = $172;
    }
    $178 = ($179>>>0)>(2147483631);
    if ($178) {
     label = 70;
     break;
    }
    $182 = ($179>>>0)<(11);
    if ($182) {
     $183 = $179 << 1;
     $184 = $183&255;
     HEAP8[$12>>0] = $184;
     $199 = $184;$__p$0$i$i$i$i33 = $164;
    } else {
     $185 = (($179) + 16)|0;
     $186 = $185 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$5+0>>2]|0;
     $187 = (invoke_iiiiiii(102,($186|0),16,($$byval_copy35|0),0,(567120|0),79)|0);
     $188 = __THREW__; __THREW__ = 0;
     $189 = $188&1;
     if ($189) {
      label = 97;
      break;
     }
     HEAP32[$165>>2] = $187;
     $190 = $186 | 1;
     HEAP32[$12>>2] = $190;
     HEAP32[$166>>2] = $179;
     $191 = $190&255;
     $199 = $191;$__p$0$i$i$i$i33 = $187;
    }
    _memcpy(($__p$0$i$i$i$i33|0),($192|0),($179|0))|0;
    $193 = (($__p$0$i$i$i$i33) + ($179)|0);
    HEAP8[$193>>0] = 0;
    $194 = HEAP32[$162>>2]|0;
    $195 = HEAP32[$163>>2]|0;
    $196 = ($194|0)==($195|0);
    if ($196) {
     __THREW__ = 0;
     invoke_vii(2602,($layers|0),($12|0));
     $225 = __THREW__; __THREW__ = 0;
     $226 = $225&1;
     if ($226) {
      label = 100;
      break;
     }
     $$pre117 = HEAP8[$12>>0]|0;
     $228 = $$pre117;
    } else {
     $197 = ($194|0)==(0|0);
     if ($197) {
      $224 = 0;
     } else {
      $198 = $199 & 1;
      $200 = ($198<<24>>24)==(0);
      if ($200) {
       $203 = $199&255;
       $204 = $203 >>> 1;
       $206 = $204;$221 = $164;
      } else {
       $201 = HEAP32[$165>>2]|0;
       $202 = HEAP32[$166>>2]|0;
       $206 = $202;$221 = $201;
      }
      $205 = ($206>>>0)>(2147483631);
      if ($205) {
       label = 82;
       break;
      }
      $209 = ($206>>>0)<(11);
      if ($209) {
       $210 = $206 << 1;
       $211 = $210&255;
       HEAP8[$194>>0] = $211;
       $212 = (($194) + 1|0);
       $__p$0$i$i$i$i$i$i40 = $212;
      } else {
       $213 = (($206) + 16)|0;
       $214 = $213 & -16;
       HEAP32[$4>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$4+0>>2]|0;
       $215 = (invoke_iiiiiii(102,($214|0),16,($$byval_copy35|0),0,(567120|0),79)|0);
       $216 = __THREW__; __THREW__ = 0;
       $217 = $216&1;
       if ($217) {
        label = 100;
        break;
       }
       $218 = (($194) + 8|0);
       HEAP32[$218>>2] = $215;
       $219 = $214 | 1;
       HEAP32[$194>>2] = $219;
       $220 = (($194) + 4|0);
       HEAP32[$220>>2] = $206;
       $__p$0$i$i$i$i$i$i40 = $215;
      }
      _memcpy(($__p$0$i$i$i$i$i$i40|0),($221|0),($206|0))|0;
      $222 = (($__p$0$i$i$i$i$i$i40) + ($206)|0);
      HEAP8[$222>>0] = 0;
      $$pre$i41 = HEAP32[$162>>2]|0;
      $224 = $$pre$i41;
     }
     $223 = (($224) + 12|0);
     HEAP32[$162>>2] = $223;
     $228 = $199;
    }
    $227 = $228 & 1;
    $229 = ($227<<24>>24)==(0);
    if (!($229)) {
     $230 = HEAP32[$165>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($230|0),($$byval_copy35|0));
     $231 = __THREW__; __THREW__ = 0;
     $232 = $231&1;
     if ($232) {
      label = 94;
      break;
     }
    }
    $235 = (($i3$081) + 1)|0;
    $236 = ($235|0)<(32);
    if ($236) {
     $i3$081 = $235;
    } else {
     label = 105;
     break;
    }
   }
   L119: do {
    if ((label|0) == 70) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $180 = __THREW__; __THREW__ = 0;
     $181 = $180&1;
     if ($181) {
      label = 98;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 82) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $207 = __THREW__; __THREW__ = 0;
     $208 = $207&1;
     if ($208) {
      $245 = ___cxa_find_matching_catch()|0;
      $246 = tempRet0;
      $248 = $199;$lpad$phi80$index = $245;$lpad$phi80$index21 = $246;
      label = 102;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 94) {
     $233 = ___cxa_find_matching_catch()|0;
     $234 = tempRet0;
     ___cxa_call_unexpected(($233|0));
     // unreachable;
    }
    else if ((label|0) == 97) {
     $239 = ___cxa_find_matching_catch()|0;
     $240 = tempRet0;
     $lpad$phi$index = $239;$lpad$phi$index15 = $240;
     label = 99;
    }
    else if ((label|0) == 100) {
     $243 = ___cxa_find_matching_catch()|0;
     $244 = tempRet0;
     $$pre113 = HEAP8[$12>>0]|0;
     $248 = $$pre113;$lpad$phi80$index = $243;$lpad$phi80$index21 = $244;
     label = 102;
    }
    else if ((label|0) == 105) {
     $255 = HEAP32[$162>>2]|0;
     $256 = HEAP32[$layers>>2]|0;
     $257 = $255;
     $258 = $256;
     $259 = (($257) - ($258))|0;
     $260 = (($259|0) / 12)&-1;
     HEAP32[$size$i$i$i50>>2] = $260;
     $261 = HEAP32[$144>>2]|0;
     $262 = (($261) + 4|0);
     $263 = HEAP32[$147>>2]|0;
     $264 = ($262>>>0)<($263>>>0);
     if ($264) {
      HEAP32[$261>>2] = $260;
      HEAP32[$144>>2] = $262;
      $268 = $256;$269 = $255;
     } else {
      __THREW__ = 0;
      invoke_viii(1640,($144|0),($size$i$i$i50|0),4);
      $265 = __THREW__; __THREW__ = 0;
      $266 = $265&1;
      if ($266) {
       label = 98;
       break;
      }
      $$pre118 = HEAP32[$162>>2]|0;
      $$pre119 = HEAP32[$layers>>2]|0;
      $268 = $$pre119;$269 = $$pre118;
     }
     $267 = ($268|0)==($269|0);
     do {
      if ($267) {
       $278 = $268;
      } else {
       $270 = $268;
       while(1) {
        __THREW__ = 0;
        invoke_viii(1641,($transfer|0),($270|0),0);
        $271 = __THREW__; __THREW__ = 0;
        $272 = $271&1;
        if ($272) {
         label = 96;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3378,($transfer|0));
        $273 = __THREW__; __THREW__ = 0;
        $274 = $273&1;
        if ($274) {
         label = 96;
         break;
        }
        $275 = (($270) + 12|0);
        $276 = ($275|0)==($269|0);
        if ($276) {
         label = 113;
         break;
        } else {
         $270 = $275;
        }
       }
       if ((label|0) == 96) {
        $237 = ___cxa_find_matching_catch()|0;
        $238 = tempRet0;
        $lpad$phi$index = $237;$lpad$phi$index15 = $238;
        label = 99;
        break L119;
       }
       else if ((label|0) == 113) {
        $$pre112 = HEAP32[$layers>>2]|0;
        $278 = $$pre112;
        break;
       }
      }
     } while(0);
     $277 = ($278|0)==(0|0);
     if (!($277)) {
      $279 = HEAP32[$162>>2]|0;
      $280 = ($279|0)==($278|0);
      do {
       if ($280) {
        $294 = $278;
       } else {
        $282 = $279;
        while(1) {
         $281 = (($282) + -12|0);
         HEAP32[$162>>2] = $281;
         $283 = HEAP8[$281>>0]|0;
         $284 = $283 & 1;
         $285 = ($284<<24>>24)==(0);
         if ($285) {
          $287 = $281;
         } else {
          $288 = (($282) + -4|0);
          $289 = HEAP32[$288>>2]|0;
          HEAP32[$1>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$1+0>>2]|0;
          invoke_vii(2591,($289|0),($$byval_copy35|0));
          $290 = __THREW__; __THREW__ = 0;
          $291 = $290&1;
          if ($291) {
           label = 121;
           break;
          }
          $$pre$i$i$i$i$i59 = HEAP32[$162>>2]|0;
          $287 = $$pre$i$i$i$i$i59;
         }
         $286 = ($287|0)==($278|0);
         if ($286) {
          label = 122;
          break;
         } else {
          $282 = $287;
         }
        }
        if ((label|0) == 121) {
         $292 = ___cxa_find_matching_catch()|0;
         $293 = tempRet0;
         ___cxa_call_unexpected(($292|0));
         // unreachable;
        }
        else if ((label|0) == 122) {
         $$pre$i$i$i61 = HEAP32[$layers>>2]|0;
         $294 = $$pre$i$i$i61;
         break;
        }
       }
      } while(0);
      __ZdlPv($294);
     }
     $313 = (($this) + 424|0);
     __THREW__ = 0;
     invoke_viii(1642,($transfer|0),($313|0),0);
     $314 = __THREW__; __THREW__ = 0;
     $315 = $314&1;
     if ($315) {
      label = 49;
      break L72;
     }
     $316 = HEAP32[$tags>>2]|0;
     $317 = ($316|0)==(0|0);
     if ($317) {
      STACKTOP = sp;return;
     }
     $318 = HEAP32[$13>>2]|0;
     $319 = ($318|0)==($316|0);
     do {
      if ($319) {
       $333 = $316;
      } else {
       $321 = $318;
       while(1) {
        $320 = (($321) + -12|0);
        HEAP32[$13>>2] = $320;
        $322 = HEAP8[$320>>0]|0;
        $323 = $322 & 1;
        $324 = ($323<<24>>24)==(0);
        if ($324) {
         $326 = $320;
        } else {
         $327 = (($321) + -4|0);
         $328 = HEAP32[$327>>2]|0;
         HEAP32[$0>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($328|0),($$byval_copy35|0));
         $329 = __THREW__; __THREW__ = 0;
         $330 = $329&1;
         if ($330) {
          label = 142;
          break;
         }
         $$pre$i$i$i$i$i6 = HEAP32[$13>>2]|0;
         $326 = $$pre$i$i$i$i$i6;
        }
        $325 = ($326|0)==($316|0);
        if ($325) {
         label = 143;
         break;
        } else {
         $321 = $326;
        }
       }
       if ((label|0) == 142) {
        $331 = ___cxa_find_matching_catch()|0;
        $332 = tempRet0;
        ___cxa_call_unexpected(($331|0));
        // unreachable;
       }
       else if ((label|0) == 143) {
        $$pre$i$i$i8 = HEAP32[$tags>>2]|0;
        $333 = $$pre$i$i$i8;
        break;
       }
      }
     } while(0);
     __ZdlPv($333);
     STACKTOP = sp;return;
    }
   } while(0);
   if ((label|0) == 98) {
    $241 = ___cxa_find_matching_catch()|0;
    $242 = tempRet0;
    $lpad$phi$index = $241;$lpad$phi$index15 = $242;
    label = 99;
   }
   else if ((label|0) == 102) {
    $247 = $248 & 1;
    $249 = ($247<<24>>24)==(0);
    if ($249) {
     $$1 = $lpad$phi80$index;$$12 = $lpad$phi80$index21;
    } else {
     $250 = HEAP32[$165>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($250|0),($$byval_copy35|0));
     $251 = __THREW__; __THREW__ = 0;
     $252 = $251&1;
     if ($252) {
      $253 = ___cxa_find_matching_catch()|0;
      $254 = tempRet0;
      ___cxa_call_unexpected(($253|0));
      // unreachable;
     } else {
      $$1 = $lpad$phi80$index;$$12 = $lpad$phi80$index21;
     }
    }
   }
   if ((label|0) == 99) {
    $$1 = $lpad$phi$index;$$12 = $lpad$phi$index15;
   }
   $295 = HEAP32[$layers>>2]|0;
   $296 = ($295|0)==(0|0);
   if ($296) {
    $$2 = $$1;$$23 = $$12;
   } else {
    $297 = HEAP32[$162>>2]|0;
    $298 = ($297|0)==($295|0);
    do {
     if ($298) {
      $312 = $295;
     } else {
      $300 = $297;
      while(1) {
       $299 = (($300) + -12|0);
       HEAP32[$162>>2] = $299;
       $301 = HEAP8[$299>>0]|0;
       $302 = $301 & 1;
       $303 = ($302<<24>>24)==(0);
       if ($303) {
        $305 = $299;
       } else {
        $306 = (($300) + -4|0);
        $307 = HEAP32[$306>>2]|0;
        HEAP32[$0>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($307|0),($$byval_copy35|0));
        $308 = __THREW__; __THREW__ = 0;
        $309 = $308&1;
        if ($309) {
         label = 131;
         break;
        }
        $$pre$i$i$i$i$i67 = HEAP32[$162>>2]|0;
        $305 = $$pre$i$i$i$i$i67;
       }
       $304 = ($305|0)==($295|0);
       if ($304) {
        label = 132;
        break;
       } else {
        $300 = $305;
       }
      }
      if ((label|0) == 131) {
       $310 = ___cxa_find_matching_catch()|0;
       $311 = tempRet0;
       ___cxa_call_unexpected(($310|0));
       // unreachable;
      }
      else if ((label|0) == 132) {
       $$pre$i$i$i69 = HEAP32[$layers>>2]|0;
       $312 = $$pre$i$i$i69;
       break;
      }
     }
    } while(0);
    __ZdlPv($312);
    $$2 = $$1;$$23 = $$12;
   }
  }
 } while(0);
 if ((label|0) == 49) {
  $124 = ___cxa_find_matching_catch()|0;
  $125 = tempRet0;
  $lpad$phi86$index = $124;$lpad$phi86$index3 = $125;
  label = 50;
 }
 if ((label|0) == 50) {
  $$2 = $lpad$phi86$index;$$23 = $lpad$phi86$index3;
 }
 $334 = HEAP32[$tags>>2]|0;
 $335 = ($334|0)==(0|0);
 if ($335) {
  ___resumeException($$2|0);
  // unreachable;
 }
 $336 = HEAP32[$13>>2]|0;
 $337 = ($336|0)==($334|0);
 do {
  if ($337) {
   $351 = $334;
  } else {
   $339 = $336;
   while(1) {
    $338 = (($339) + -12|0);
    HEAP32[$13>>2] = $338;
    $340 = HEAP8[$338>>0]|0;
    $341 = $340 & 1;
    $342 = ($341<<24>>24)==(0);
    if ($342) {
     $344 = $338;
    } else {
     $345 = (($339) + -4|0);
     $346 = HEAP32[$345>>2]|0;
     HEAP32[$10>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$10+0>>2]|0;
     invoke_vii(2591,($346|0),($$byval_copy35|0));
     $347 = __THREW__; __THREW__ = 0;
     $348 = $347&1;
     if ($348) {
      label = 153;
      break;
     }
     $$pre$i$i$i$i$i = HEAP32[$13>>2]|0;
     $344 = $$pre$i$i$i$i$i;
    }
    $343 = ($344|0)==($334|0);
    if ($343) {
     label = 154;
     break;
    } else {
     $339 = $344;
    }
   }
   if ((label|0) == 153) {
    $349 = ___cxa_find_matching_catch()|0;
    $350 = tempRet0;
    ___cxa_call_unexpected(($349|0));
    // unreachable;
   }
   else if ((label|0) == 154) {
    $$pre$i$i$i = HEAP32[$tags>>2]|0;
    $351 = $$pre$i$i$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($351);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SortingLayerEntryNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$data>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 20)&-1;
 HEAP32[$size>>2] = $7;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size,4);
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$data>>2]|0;
 $16 = ($15|0)==($14|0);
 if ($16) {
  STACKTOP = sp;return;
 } else {
  $17 = $15;
 }
 while(1) {
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$17,0);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($this);
  $18 = (($17) + 12|0);
  $19 = HEAP32[$8>>2]|0;
  $20 = (($19) + 4|0);
  $21 = HEAP32[$11>>2]|0;
  $22 = ($20>>>0)<($21>>>0);
  if ($22) {
   $23 = HEAP32[$18>>2]|0;
   HEAP32[$19>>2] = $23;
   HEAP32[$8>>2] = $20;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$18,4);
  }
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($this);
  $24 = (($17) + 20|0);
  $25 = ($24|0)==($14|0);
  if ($25) {
   break;
  } else {
   $17 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ph = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = HEAP8[$data>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $8 = $7;
 } else {
  $4 = (($data) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $8 = $5;
 }
 HEAP32[$size>>2] = $8;
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = (($this) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  HEAP32[$10>>2] = $8;
  HEAP32[$9>>2] = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$size,4);
 }
 $15 = HEAP8[$data>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $23 = $15&255;
  $24 = $23 >>> 1;
  $25 = ((($data) + ($24)|0) + 1|0);
  $26 = (($data) + 1|0);
  $$ph = $26;$28 = $25;
 } else {
  $18 = (($data) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($data) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($19) + ($21)|0);
  $$ph = $19;$28 = $22;
 }
 $27 = ($$ph|0)==($28|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $34 = $$ph;
 }
 while(1) {
  $29 = HEAP32[$9>>2]|0;
  $30 = (($29) + 1|0);
  $31 = HEAP32[$12>>2]|0;
  $32 = ($30>>>0)<($31>>>0);
  if ($32) {
   $33 = HEAP8[$34>>0]|0;
   HEAP8[$29>>0] = $33;
   $35 = HEAP32[$9>>2]|0;
   $36 = (($35) + 1|0);
   HEAP32[$9>>2] = $36;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$34,1);
  }
  $37 = (($34) + 1|0);
  $38 = ($37|0)==($28|0);
  if ($38) {
   break;
  } else {
   $34 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __ZN10TagManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy24 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i36 = 0, $$pre$i$i$i$i$i44 = 0, $$pre$i$i$i$i$i6 = 0, $$pre$i$i$i38 = 0, $$pre$i$i$i46 = 0, $$pre$i$i$i8 = 0, $$pre72 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i16 = 0, $__p$0$i$i$i$i28 = 0, $i$02$i = 0, $i1$068 = 0, $i3$062 = 0, $i4$054 = 0, $layers = 0, $lpad$phi$index = 0, $lpad$phi$index8 = 0, $lpad$phi61$index = 0, $lpad$phi61$index14 = 0, $lpad$phi67$index = 0, $lpad$phi67$index2 = 0, $tags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy24 = sp + 88|0;
 $0 = sp + 84|0;
 $1 = sp + 80|0;
 $2 = sp + 76|0;
 $3 = sp + 72|0;
 $4 = sp + 68|0;
 $5 = sp + 64|0;
 $6 = sp + 48|0;
 $tags = sp + 36|0;
 $7 = sp + 24|0;
 $layers = sp + 12|0;
 $8 = sp;
 $9 = sp + 52|0;
 HEAP32[$tags>>2] = 0;
 $10 = (($tags) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($tags) + 8|0);
 HEAP32[$11>>2] = 0;
 __THREW__ = 0;
 invoke_vi(3387,($this|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L1: do {
  if ($13) {
   label = 3;
  } else {
   __THREW__ = 0;
   invoke_viii(1643,($transfer|0),($tags|0),0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    label = 3;
   } else {
    $20 = HEAP32[$10>>2]|0;
    $21 = HEAP32[$tags>>2]|0;
    $22 = ($20|0)==($21|0);
    L4: do {
     if (!($22)) {
      $23 = (($7) + 1|0);
      $24 = (($7) + 8|0);
      $25 = (($7) + 4|0);
      $27 = $21;$i1$068 = 0;
      while(1) {
       $26 = (($27) + (($i1$068*12)|0)|0);
       $28 = HEAP8[$26>>0]|0;
       $29 = $28 & 1;
       $30 = ($29<<24>>24)==(0);
       if ($30) {
        $31 = (($26) + 1|0);
        $32 = $28&255;
        $33 = $32 >>> 1;
        $42 = $33;$51 = $31;
       } else {
        $34 = ((($27) + (($i1$068*12)|0)|0) + 8|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = ((($27) + (($i1$068*12)|0)|0) + 4|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = ($37>>>0)>(4294967279);
        if ($38) {
         label = 11;
         break;
        } else {
         $42 = $37;$51 = $35;
        }
       }
       $41 = ($42>>>0)<(11);
       if ($41) {
        $43 = $42 << 1;
        $44 = $43&255;
        HEAP8[$7>>0] = $44;
        $__p$0$i$i$i$i = $23;
       } else {
        $45 = (($42) + 16)|0;
        $46 = $45 & -16;
        __THREW__ = 0;
        $47 = (invoke_ii(2988,($46|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 2;
         break;
        }
        HEAP32[$24>>2] = $47;
        $50 = $46 | 1;
        HEAP32[$7>>2] = $50;
        HEAP32[$25>>2] = $42;
        $__p$0$i$i$i$i = $47;
       }
       _memcpy(($__p$0$i$i$i$i|0),($51|0),($42|0))|0;
       $52 = (($__p$0$i$i$i$i) + ($42)|0);
       HEAP8[$52>>0] = 0;
       $53 = (($i1$068) + 20000)|0;
       __THREW__ = 0;
       invoke_viii(1637,($this|0),($53|0),($7|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 21;
        break;
       }
       $56 = HEAP8[$7>>0]|0;
       $57 = $56 & 1;
       $58 = ($57<<24>>24)==(0);
       if (!($58)) {
        $59 = HEAP32[$24>>2]|0;
        __ZdlPv($59);
       }
       $60 = (($i1$068) + 1)|0;
       $61 = HEAP32[$10>>2]|0;
       $62 = HEAP32[$tags>>2]|0;
       $63 = $61;
       $64 = $62;
       $65 = (($63) - ($64))|0;
       $66 = (($65|0) / 12)&-1;
       $67 = ($60>>>0)<($66>>>0);
       if ($67) {
        $27 = $62;$i1$068 = $60;
       } else {
        break L4;
       }
      }
      if ((label|0) == 2) {
       $14 = ___cxa_find_matching_catch()|0;
       $15 = tempRet0;
       $lpad$phi67$index = $14;$lpad$phi67$index2 = $15;
       label = 4;
       break L1;
      }
      else if ((label|0) == 11) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        label = 3;
        break L1;
       }
       // unreachable;
      }
      else if ((label|0) == 21) {
       $68 = ___cxa_find_matching_catch()|0;
       $69 = tempRet0;
       $70 = HEAP8[$7>>0]|0;
       $71 = $70 & 1;
       $72 = ($71<<24>>24)==(0);
       if ($72) {
        $$2 = $68;$$23 = $69;
        break L1;
       }
       $73 = HEAP32[$24>>2]|0;
       __ZdlPv($73);
       $$2 = $68;$$23 = $69;
       break L1;
      }
     }
    } while(0);
    HEAP32[$layers>>2] = 0;
    $74 = (($layers) + 4|0);
    HEAP32[$74>>2] = 0;
    $75 = (($layers) + 8|0);
    HEAP32[$75>>2] = 0;
    $76 = (($8) + 1|0);
    $77 = (($8) + 8|0);
    $78 = (($8) + 4|0);
    $i3$062 = 0;
    while(1) {
     $79 = ((($this) + (($i3$062*12)|0)|0) + 40|0);
     $80 = HEAP8[$79>>0]|0;
     $81 = $80 & 1;
     $82 = ($81<<24>>24)==(0);
     if ($82) {
      $87 = (($79) + 1|0);
      $88 = $80&255;
      $89 = $88 >>> 1;
      $104 = $87;$91 = $89;
     } else {
      $83 = ((($this) + (($i3$062*12)|0)|0) + 48|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = ((($this) + (($i3$062*12)|0)|0) + 44|0);
      $86 = HEAP32[$85>>2]|0;
      $104 = $84;$91 = $86;
     }
     $90 = ($91>>>0)>(2147483631);
     if ($90) {
      label = 28;
      break;
     }
     $94 = ($91>>>0)<(11);
     if ($94) {
      $95 = $91 << 1;
      $96 = $95&255;
      HEAP8[$8>>0] = $96;
      $111 = $96;$__p$0$i$i$i$i16 = $76;
     } else {
      $97 = (($91) + 16)|0;
      $98 = $97 & -16;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$5+0>>2]|0;
      $99 = (invoke_iiiiiii(102,($98|0),16,($$byval_copy24|0),0,(567120|0),79)|0);
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       label = 55;
       break;
      }
      HEAP32[$77>>2] = $99;
      $102 = $98 | 1;
      HEAP32[$8>>2] = $102;
      HEAP32[$78>>2] = $91;
      $103 = $102&255;
      $111 = $103;$__p$0$i$i$i$i16 = $99;
     }
     _memcpy(($__p$0$i$i$i$i16|0),($104|0),($91|0))|0;
     $105 = (($__p$0$i$i$i$i16) + ($91)|0);
     HEAP8[$105>>0] = 0;
     $106 = HEAP32[$74>>2]|0;
     $107 = HEAP32[$75>>2]|0;
     $108 = ($106|0)==($107|0);
     if ($108) {
      __THREW__ = 0;
      invoke_vii(2602,($layers|0),($8|0));
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       label = 58;
       break;
      }
      $$pre72 = HEAP8[$8>>0]|0;
      $140 = $$pre72;
     } else {
      $109 = ($106|0)==(0|0);
      if ($109) {
       $136 = 0;
      } else {
       $110 = $111 & 1;
       $112 = ($110<<24>>24)==(0);
       if ($112) {
        $115 = $111&255;
        $116 = $115 >>> 1;
        $118 = $116;$133 = $76;
       } else {
        $113 = HEAP32[$77>>2]|0;
        $114 = HEAP32[$78>>2]|0;
        $118 = $114;$133 = $113;
       }
       $117 = ($118>>>0)>(2147483631);
       if ($117) {
        label = 40;
        break;
       }
       $121 = ($118>>>0)<(11);
       if ($121) {
        $122 = $118 << 1;
        $123 = $122&255;
        HEAP8[$106>>0] = $123;
        $124 = (($106) + 1|0);
        $__p$0$i$i$i$i$i$i = $124;
       } else {
        $125 = (($118) + 16)|0;
        $126 = $125 & -16;
        HEAP32[$4>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$4+0>>2]|0;
        $127 = (invoke_iiiiiii(102,($126|0),16,($$byval_copy24|0),0,(567120|0),79)|0);
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if ($129) {
         label = 58;
         break;
        }
        $130 = (($106) + 8|0);
        HEAP32[$130>>2] = $127;
        $131 = $126 | 1;
        HEAP32[$106>>2] = $131;
        $132 = (($106) + 4|0);
        HEAP32[$132>>2] = $118;
        $__p$0$i$i$i$i$i$i = $127;
       }
       _memcpy(($__p$0$i$i$i$i$i$i|0),($133|0),($118|0))|0;
       $134 = (($__p$0$i$i$i$i$i$i) + ($118)|0);
       HEAP8[$134>>0] = 0;
       $$pre$i = HEAP32[$74>>2]|0;
       $136 = $$pre$i;
      }
      $135 = (($136) + 12|0);
      HEAP32[$74>>2] = $135;
      $140 = $111;
     }
     $139 = $140 & 1;
     $141 = ($139<<24>>24)==(0);
     if (!($141)) {
      $142 = HEAP32[$77>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($142|0),($$byval_copy24|0));
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       label = 52;
       break;
      }
     }
     $147 = (($i3$062) + 1)|0;
     $148 = ($147|0)<(32);
     if ($148) {
      $i3$062 = $147;
     } else {
      label = 63;
      break;
     }
    }
    do {
     if ((label|0) == 28) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       label = 56;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 40) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       $157 = ___cxa_find_matching_catch()|0;
       $158 = tempRet0;
       $160 = $111;$lpad$phi61$index = $157;$lpad$phi61$index14 = $158;
       label = 60;
       break;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 52) {
      $145 = ___cxa_find_matching_catch()|0;
      $146 = tempRet0;
      ___cxa_call_unexpected(($145|0));
      // unreachable;
     }
     else if ((label|0) == 55) {
      $151 = ___cxa_find_matching_catch()|0;
      $152 = tempRet0;
      $lpad$phi$index = $151;$lpad$phi$index8 = $152;
      label = 57;
     }
     else if ((label|0) == 58) {
      $155 = ___cxa_find_matching_catch()|0;
      $156 = tempRet0;
      $$pre = HEAP8[$8>>0]|0;
      $160 = $$pre;$lpad$phi61$index = $155;$lpad$phi61$index14 = $156;
      label = 60;
     }
     else if ((label|0) == 63) {
      __THREW__ = 0;
      invoke_viii(1643,($transfer|0),($layers|0),0);
      $167 = __THREW__; __THREW__ = 0;
      $168 = $167&1;
      if ($168) {
       label = 56;
      } else {
       $169 = HEAP32[$layers>>2]|0;
       $170 = (($9) + 1|0);
       $171 = (($9) + 8|0);
       $172 = (($9) + 4|0);
       $174 = $169;$i4$054 = 8;
       while(1) {
        $173 = (($174) + (($i4$054*12)|0)|0);
        $175 = HEAP8[$173>>0]|0;
        $176 = $175 & 1;
        $177 = ($176<<24>>24)==(0);
        if ($177) {
         $178 = (($173) + 1|0);
         $179 = $175&255;
         $180 = $179 >>> 1;
         $189 = $180;$198 = $178;
        } else {
         $181 = ((($174) + (($i4$054*12)|0)|0) + 8|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = ((($174) + (($i4$054*12)|0)|0) + 4|0);
         $184 = HEAP32[$183>>2]|0;
         $185 = ($184>>>0)>(4294967279);
         if ($185) {
          label = 68;
          break;
         } else {
          $189 = $184;$198 = $182;
         }
        }
        $188 = ($189>>>0)<(11);
        if ($188) {
         $190 = $189 << 1;
         $191 = $190&255;
         HEAP8[$9>>0] = $191;
         $__p$0$i$i$i$i28 = $170;
        } else {
         $192 = (($189) + 16)|0;
         $193 = $192 & -16;
         __THREW__ = 0;
         $194 = (invoke_ii(2988,($193|0))|0);
         $195 = __THREW__; __THREW__ = 0;
         $196 = $195&1;
         if ($196) {
          label = 54;
          break;
         }
         HEAP32[$171>>2] = $194;
         $197 = $193 | 1;
         HEAP32[$9>>2] = $197;
         HEAP32[$172>>2] = $189;
         $__p$0$i$i$i$i28 = $194;
        }
        _memcpy(($__p$0$i$i$i$i28|0),($198|0),($189|0))|0;
        $199 = (($__p$0$i$i$i$i28) + ($189)|0);
        HEAP8[$199>>0] = 0;
        __THREW__ = 0;
        invoke_viii(1638,($this|0),($i4$054|0),($9|0));
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         label = 78;
         break;
        }
        $202 = HEAP8[$9>>0]|0;
        $203 = $202 & 1;
        $204 = ($203<<24>>24)==(0);
        if (!($204)) {
         $205 = HEAP32[$171>>2]|0;
         __ZdlPv($205);
        }
        $206 = (($i4$054) + 1)|0;
        $207 = ($206|0)<(32);
        $208 = HEAP32[$layers>>2]|0;
        if ($207) {
         $174 = $208;$i4$054 = $206;
        } else {
         label = 80;
         break;
        }
       }
       if ((label|0) == 54) {
        $149 = ___cxa_find_matching_catch()|0;
        $150 = tempRet0;
        $lpad$phi$index = $149;$lpad$phi$index8 = $150;
        label = 57;
        break;
       }
       else if ((label|0) == 68) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $186 = __THREW__; __THREW__ = 0;
        $187 = $186&1;
        if ($187) {
         label = 56;
         break;
        }
        // unreachable;
       }
       else if ((label|0) == 78) {
        $209 = ___cxa_find_matching_catch()|0;
        $210 = tempRet0;
        $211 = HEAP8[$9>>0]|0;
        $212 = $211 & 1;
        $213 = ($212<<24>>24)==(0);
        if ($213) {
         $$1 = $209;$$12 = $210;
         break;
        }
        $214 = HEAP32[$171>>2]|0;
        __ZdlPv($214);
        $$1 = $209;$$12 = $210;
        break;
       }
       else if ((label|0) == 80) {
        $215 = ($208|0)==(0|0);
        if (!($215)) {
         $216 = HEAP32[$74>>2]|0;
         $217 = ($216|0)==($208|0);
         do {
          if ($217) {
           $231 = $208;
          } else {
           $219 = $216;
           while(1) {
            $218 = (($219) + -12|0);
            HEAP32[$74>>2] = $218;
            $220 = HEAP8[$218>>0]|0;
            $221 = $220 & 1;
            $222 = ($221<<24>>24)==(0);
            if ($222) {
             $224 = $218;
            } else {
             $225 = (($219) + -4|0);
             $226 = HEAP32[$225>>2]|0;
             HEAP32[$1>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;
             invoke_vii(2591,($226|0),($$byval_copy24|0));
             $227 = __THREW__; __THREW__ = 0;
             $228 = $227&1;
             if ($228) {
              label = 87;
              break;
             }
             $$pre$i$i$i$i$i36 = HEAP32[$74>>2]|0;
             $224 = $$pre$i$i$i$i$i36;
            }
            $223 = ($224|0)==($208|0);
            if ($223) {
             label = 88;
             break;
            } else {
             $219 = $224;
            }
           }
           if ((label|0) == 87) {
            $229 = ___cxa_find_matching_catch()|0;
            $230 = tempRet0;
            ___cxa_call_unexpected(($229|0));
            // unreachable;
           }
           else if ((label|0) == 88) {
            $$pre$i$i$i38 = HEAP32[$layers>>2]|0;
            $231 = $$pre$i$i$i38;
            break;
           }
          }
         } while(0);
         __ZdlPv($231);
        }
        $250 = (($this) + 424|0);
        __THREW__ = 0;
        invoke_viii(1644,($transfer|0),($250|0),0);
        $251 = __THREW__; __THREW__ = 0;
        $252 = $251&1;
        if ($252) {
         label = 3;
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3388,($this|0));
        $253 = __THREW__; __THREW__ = 0;
        $254 = $253&1;
        if ($254) {
         label = 3;
         break L1;
        }
        $255 = (($this) + 436|0);
        HEAP32[$255>>2] = 0;
        $256 = (($this) + 428|0);
        $257 = HEAP32[$256>>2]|0;
        $258 = (($this) + 424|0);
        $259 = HEAP32[$258>>2]|0;
        $260 = $257;
        $261 = $259;
        $262 = (($260) - ($261))|0;
        $263 = (($262|0) / 20)&-1;
        $264 = ($257|0)==($259|0);
        L104: do {
         if (!($264)) {
          $i$02$i = 0;
          while(1) {
           $267 = ((($259) + (($i$02$i*20)|0)|0) + 12|0);
           $268 = HEAP32[$267>>2]|0;
           $269 = ($268|0)==(0);
           $266 = (($i$02$i) + 1)|0;
           if ($269) {
            break;
           }
           $265 = ($266|0)==($263|0);
           if ($265) {
            break L104;
           } else {
            $i$02$i = $266;
           }
          }
          HEAP32[$255>>2] = $i$02$i;
         }
        } while(0);
        $270 = HEAP32[$tags>>2]|0;
        $271 = ($270|0)==(0|0);
        if ($271) {
         STACKTOP = sp;return;
        }
        $272 = HEAP32[$10>>2]|0;
        $273 = ($272|0)==($270|0);
        do {
         if ($273) {
          $287 = $270;
         } else {
          $275 = $272;
          while(1) {
           $274 = (($275) + -12|0);
           HEAP32[$10>>2] = $274;
           $276 = HEAP8[$274>>0]|0;
           $277 = $276 & 1;
           $278 = ($277<<24>>24)==(0);
           if ($278) {
            $280 = $274;
           } else {
            $281 = (($275) + -4|0);
            $282 = HEAP32[$281>>2]|0;
            HEAP32[$0>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
            invoke_vii(2591,($282|0),($$byval_copy24|0));
            $283 = __THREW__; __THREW__ = 0;
            $284 = $283&1;
            if ($284) {
             label = 113;
             break;
            }
            $$pre$i$i$i$i$i6 = HEAP32[$10>>2]|0;
            $280 = $$pre$i$i$i$i$i6;
           }
           $279 = ($280|0)==($270|0);
           if ($279) {
            label = 114;
            break;
           } else {
            $275 = $280;
           }
          }
          if ((label|0) == 113) {
           $285 = ___cxa_find_matching_catch()|0;
           $286 = tempRet0;
           ___cxa_call_unexpected(($285|0));
           // unreachable;
          }
          else if ((label|0) == 114) {
           $$pre$i$i$i8 = HEAP32[$tags>>2]|0;
           $287 = $$pre$i$i$i8;
           break;
          }
         }
        } while(0);
        __ZdlPv($287);
        STACKTOP = sp;return;
       }
      }
     }
    } while(0);
    if ((label|0) == 56) {
     $153 = ___cxa_find_matching_catch()|0;
     $154 = tempRet0;
     $lpad$phi$index = $153;$lpad$phi$index8 = $154;
     label = 57;
    }
    else if ((label|0) == 60) {
     $159 = $160 & 1;
     $161 = ($159<<24>>24)==(0);
     if ($161) {
      $$1 = $lpad$phi61$index;$$12 = $lpad$phi61$index14;
     } else {
      $162 = HEAP32[$77>>2]|0;
      HEAP32[$2>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($162|0),($$byval_copy24|0));
      $163 = __THREW__; __THREW__ = 0;
      $164 = $163&1;
      if ($164) {
       $165 = ___cxa_find_matching_catch()|0;
       $166 = tempRet0;
       ___cxa_call_unexpected(($165|0));
       // unreachable;
      } else {
       $$1 = $lpad$phi61$index;$$12 = $lpad$phi61$index14;
      }
     }
    }
    if ((label|0) == 57) {
     $$1 = $lpad$phi$index;$$12 = $lpad$phi$index8;
    }
    $232 = HEAP32[$layers>>2]|0;
    $233 = ($232|0)==(0|0);
    if ($233) {
     $$2 = $$1;$$23 = $$12;
    } else {
     $234 = HEAP32[$74>>2]|0;
     $235 = ($234|0)==($232|0);
     do {
      if ($235) {
       $249 = $232;
      } else {
       $237 = $234;
       while(1) {
        $236 = (($237) + -12|0);
        HEAP32[$74>>2] = $236;
        $238 = HEAP8[$236>>0]|0;
        $239 = $238 & 1;
        $240 = ($239<<24>>24)==(0);
        if ($240) {
         $242 = $236;
        } else {
         $243 = (($237) + -4|0);
         $244 = HEAP32[$243>>2]|0;
         HEAP32[$0>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($244|0),($$byval_copy24|0));
         $245 = __THREW__; __THREW__ = 0;
         $246 = $245&1;
         if ($246) {
          label = 97;
          break;
         }
         $$pre$i$i$i$i$i44 = HEAP32[$74>>2]|0;
         $242 = $$pre$i$i$i$i$i44;
        }
        $241 = ($242|0)==($232|0);
        if ($241) {
         label = 98;
         break;
        } else {
         $237 = $242;
        }
       }
       if ((label|0) == 97) {
        $247 = ___cxa_find_matching_catch()|0;
        $248 = tempRet0;
        ___cxa_call_unexpected(($247|0));
        // unreachable;
       }
       else if ((label|0) == 98) {
        $$pre$i$i$i46 = HEAP32[$layers>>2]|0;
        $249 = $$pre$i$i$i46;
        break;
       }
      }
     } while(0);
     __ZdlPv($249);
     $$2 = $$1;$$23 = $$12;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $lpad$phi67$index = $16;$lpad$phi67$index2 = $17;
  label = 4;
 }
 if ((label|0) == 4) {
  $$2 = $lpad$phi67$index;$$23 = $lpad$phi67$index2;
 }
 $288 = HEAP32[$tags>>2]|0;
 $289 = ($288|0)==(0|0);
 if ($289) {
  ___resumeException($$2|0);
  // unreachable;
 }
 $290 = HEAP32[$10>>2]|0;
 $291 = ($290|0)==($288|0);
 do {
  if ($291) {
   $305 = $288;
  } else {
   $293 = $290;
   while(1) {
    $292 = (($293) + -12|0);
    HEAP32[$10>>2] = $292;
    $294 = HEAP8[$292>>0]|0;
    $295 = $294 & 1;
    $296 = ($295<<24>>24)==(0);
    if ($296) {
     $298 = $292;
    } else {
     $299 = (($293) + -4|0);
     $300 = HEAP32[$299>>2]|0;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($300|0),($$byval_copy24|0));
     $301 = __THREW__; __THREW__ = 0;
     $302 = $301&1;
     if ($302) {
      label = 124;
      break;
     }
     $$pre$i$i$i$i$i = HEAP32[$10>>2]|0;
     $298 = $$pre$i$i$i$i$i;
    }
    $297 = ($298|0)==($288|0);
    if ($297) {
     label = 125;
     break;
    } else {
     $293 = $298;
    }
   }
   if ((label|0) == 124) {
    $303 = ___cxa_find_matching_catch()|0;
    $304 = tempRet0;
    ___cxa_call_unexpected(($303|0));
    // unreachable;
   }
   else if ((label|0) == 125) {
    $$pre$i$i$i = HEAP32[$tags>>2]|0;
    $305 = $$pre$i$i$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($305);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17SortingLayerEntryNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = ($21*20)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i3;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorI17SortingLayerEntryNS0_9allocatorIS2_EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $29 = $27;
 }
 while(1) {
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$29,0);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
  $30 = (($29) + 12|0);
  $31 = HEAP32[$1>>2]|0;
  $32 = (($31) + 4|0);
  $33 = HEAP32[$7>>2]|0;
  $34 = ($32>>>0)>($33>>>0);
  if ($34) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$30,4);
   $$pre$i$i$i$i$i$i = HEAP32[$30>>2]|0;
   $36 = $$pre$i$i$i$i$i$i;
  } else {
   $35 = HEAP32[$31>>2]|0;
   HEAP32[$30>>2] = $35;
   HEAP32[$1>>2] = $32;
   $36 = $35;
  }
  $37 = (_llvm_bswap_i32(($36|0))|0);
  HEAP32[$30>>2] = $37;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
  $38 = (($29) + 20|0);
  $39 = ($38|0)==($26|0);
  if ($39) {
   break;
  } else {
   $29 = $38;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI17SortingLayerEntryNS0_9allocatorIS2_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy5 = 0, $$byval_copy8 = 0, $$idx = 0, $$pre = 0, $$pre$i$i$i$i$i16 = 0, $$pre$i$i$i$i$i8 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i5 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $temp = 0, $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 44|0;
 $$byval_copy5 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $temp = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $temp1 = sp + 32|0;
 $4 = (($v) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$v>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 20)&-1;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $95 = ($10>>>0)>($sz>>>0);
  if (!($95)) {
   STACKTOP = sp;return;
  }
  $96 = (($6) + (($sz*20)|0)|0);
  HEAP32[$temp1>>2] = 0;
  $97 = (($temp1) + 4|0);
  HEAP32[$97>>2] = 0;
  $98 = (($temp1) + 8|0);
  HEAP32[$98>>2] = 0;
  $$idx = ($sz*20)|0;
  $99 = (($$idx|0) / 20)&-1;
  $100 = ($sz|0)==(0);
  do {
   if ($100) {
    $128 = $6;$129 = 0;$130 = $5;$131 = 0;$134 = 0;
   } else {
    $101 = ($99>>>0)>(214748364);
    if ($101) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if (!($103)) {
      // unreachable;
     }
    } else {
     __THREW__ = 0;
     $104 = (invoke_ii(2988,($$idx|0))|0);
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if (!($106)) {
      HEAP32[$97>>2] = $104;
      HEAP32[$temp1>>2] = $104;
      $107 = (($104) + (($99*20)|0)|0);
      HEAP32[$98>>2] = $107;
      HEAP32[$0>>2] = $6;
      HEAP32[$1>>2] = $96;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_viii(1646,($temp1|0),($$byval_copy5|0),($$byval_copy8|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if (!($109)) {
       $$pre36 = HEAP32[$temp1>>2]|0;
       $$pre37 = HEAP32[$v>>2]|0;
       $$pre38 = HEAP32[$97>>2]|0;
       $$pre39 = HEAP32[$4>>2]|0;
       $$pre40 = HEAP32[$98>>2]|0;
       $128 = $$pre37;$129 = $$pre36;$130 = $$pre39;$131 = $$pre38;$134 = $$pre40;
       break;
      }
     }
    }
    $110 = ___cxa_find_matching_catch()|0;
    $111 = tempRet0;
    $112 = HEAP32[$temp1>>2]|0;
    $113 = ($112|0)==(0|0);
    if ($113) {
     ___resumeException($110|0);
     // unreachable;
    }
    $114 = HEAP32[$97>>2]|0;
    $115 = ($114|0)==($112|0);
    L18: do {
     if (!($115)) {
      $117 = $114;
      while(1) {
       $116 = (($117) + -20|0);
       HEAP32[$97>>2] = $116;
       $118 = HEAP8[$116>>0]|0;
       $119 = $118 & 1;
       $120 = ($119<<24>>24)==(0);
       if (!($120)) {
        $122 = (($117) + -12|0);
        $123 = HEAP32[$122>>2]|0;
        HEAP32[$$byval_copy5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
        invoke_vii(2591,($123|0),($$byval_copy8|0));
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break;
        }
       }
       $121 = ($116|0)==($112|0);
       if ($121) {
        break L18;
       } else {
        $117 = $116;
       }
      }
      $126 = ___cxa_find_matching_catch()|0;
      $127 = tempRet0;
      ___cxa_call_unexpected(($126|0));
      // unreachable;
     }
    } while(0);
    __ZdlPv($112);
    ___resumeException($110|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$temp1>>2] = $128;
  HEAP32[$v>>2] = $129;
  HEAP32[$97>>2] = $130;
  HEAP32[$4>>2] = $131;
  $132 = (($v) + 8|0);
  $133 = HEAP32[$132>>2]|0;
  HEAP32[$98>>2] = $133;
  HEAP32[$132>>2] = $134;
  $135 = ($128|0)==(0|0);
  if ($135) {
   STACKTOP = sp;return;
  }
  $136 = ($130|0)==($128|0);
  L32: do {
   if (!($136)) {
    $138 = $130;
    while(1) {
     $137 = (($138) + -20|0);
     HEAP32[$97>>2] = $137;
     $139 = HEAP8[$137>>0]|0;
     $140 = $139 & 1;
     $141 = ($140<<24>>24)==(0);
     if (!($141)) {
      $143 = (($138) + -12|0);
      $144 = HEAP32[$143>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($144|0),($$byval_copy8|0));
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       break;
      }
     }
     $142 = ($137|0)==($128|0);
     if ($142) {
      break L32;
     } else {
      $138 = $137;
     }
    }
    $147 = ___cxa_find_matching_catch()|0;
    $148 = tempRet0;
    ___cxa_call_unexpected(($147|0));
    // unreachable;
   }
  } while(0);
  __ZdlPv($128);
  STACKTOP = sp;return;
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 20)&-1;
 $17 = ($16|0)==($sz|0);
 if ($17) {
  $94 = (($sz) - ($10))|0;
  __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE8__appendEj($v,$94);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $18 = (($temp) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($temp) + 8|0);
 HEAP32[$19>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2604,($temp|0),($sz|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L47: do {
  if (!($21)) {
   $22 = HEAP32[$v>>2]|0;
   HEAP32[$2>>2] = $22;
   $23 = HEAP32[$4>>2]|0;
   HEAP32[$3>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viii(1645,($temp|0),($$byval_copy5|0),($$byval_copy8|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$18>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = (($30|0) / 20)&-1;
    $32 = ($31>>>0)<($sz>>>0);
    L50: do {
     if ($32) {
      $33 = (($sz) - ($31))|0;
      __THREW__ = 0;
      invoke_vii(2605,($temp|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L47;
      }
      $$pre = HEAP32[$18>>2]|0;
      $55 = $$pre;
     } else {
      $36 = ($31>>>0)>($sz>>>0);
      if ($36) {
       $37 = (($27) + (($sz*20)|0)|0);
       $38 = ($26|0)==($37|0);
       if ($38) {
        $55 = $26;
       } else {
        $40 = $26;
        while(1) {
         $39 = (($40) + -20|0);
         HEAP32[$18>>2] = $39;
         $41 = HEAP8[$39>>0]|0;
         $42 = $41 & 1;
         $43 = ($42<<24>>24)==(0);
         if ($43) {
          $45 = $39;
         } else {
          $46 = (($40) + -12|0);
          $47 = HEAP32[$46>>2]|0;
          HEAP32[$0>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($47|0),($$byval_copy8|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          $$pre$i$i$i5 = HEAP32[$18>>2]|0;
          $45 = $$pre$i$i$i5;
         }
         $44 = ($45|0)==($37|0);
         if ($44) {
          $55 = $37;
          break L50;
         } else {
          $40 = $45;
         }
        }
        $50 = ___cxa_find_matching_catch()|0;
        $51 = tempRet0;
        ___cxa_call_unexpected(($50|0));
        // unreachable;
       }
      } else {
       $55 = $26;
      }
     }
    } while(0);
    $52 = HEAP32[$temp>>2]|0;
    $53 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $53;
    HEAP32[$v>>2] = $52;
    $54 = HEAP32[$4>>2]|0;
    HEAP32[$18>>2] = $54;
    HEAP32[$4>>2] = $55;
    $56 = HEAP32[$19>>2]|0;
    $57 = HEAP32[$12>>2]|0;
    HEAP32[$19>>2] = $57;
    HEAP32[$12>>2] = $56;
    $58 = ($53|0)==(0|0);
    if ($58) {
     STACKTOP = sp;return;
    }
    $59 = ($54|0)==($53|0);
    do {
     if ($59) {
      $73 = $53;
     } else {
      $61 = $54;
      while(1) {
       $60 = (($61) + -20|0);
       HEAP32[$18>>2] = $60;
       $62 = HEAP8[$60>>0]|0;
       $63 = $62 & 1;
       $64 = ($63<<24>>24)==(0);
       if ($64) {
        $66 = $60;
       } else {
        $67 = (($61) + -12|0);
        $68 = HEAP32[$67>>2]|0;
        HEAP32[$$byval_copy5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
        invoke_vii(2591,($68|0),($$byval_copy8|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 23;
         break;
        }
        $$pre$i$i$i$i$i8 = HEAP32[$18>>2]|0;
        $66 = $$pre$i$i$i$i$i8;
       }
       $65 = ($66|0)==($53|0);
       if ($65) {
        label = 24;
        break;
       } else {
        $61 = $66;
       }
      }
      if ((label|0) == 23) {
       $71 = ___cxa_find_matching_catch()|0;
       $72 = tempRet0;
       ___cxa_call_unexpected(($71|0));
       // unreachable;
      }
      else if ((label|0) == 24) {
       $$pre$i$i$i10 = HEAP32[$temp>>2]|0;
       $73 = $$pre$i$i$i10;
       break;
      }
     }
    } while(0);
    __ZdlPv($73);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $74 = ___cxa_find_matching_catch()|0;
 $75 = tempRet0;
 $76 = HEAP32[$temp>>2]|0;
 $77 = ($76|0)==(0|0);
 if ($77) {
  ___resumeException($74|0);
  // unreachable;
 }
 $78 = HEAP32[$18>>2]|0;
 $79 = ($78|0)==($76|0);
 do {
  if ($79) {
   $93 = $76;
  } else {
   $81 = $78;
   while(1) {
    $80 = (($81) + -20|0);
    HEAP32[$18>>2] = $80;
    $82 = HEAP8[$80>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if ($84) {
     $86 = $80;
    } else {
     $87 = (($81) + -12|0);
     $88 = HEAP32[$87>>2]|0;
     HEAP32[$$byval_copy5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
     invoke_vii(2591,($88|0),($$byval_copy8|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 33;
      break;
     }
     $$pre$i$i$i$i$i16 = HEAP32[$18>>2]|0;
     $86 = $$pre$i$i$i$i$i16;
    }
    $85 = ($86|0)==($76|0);
    if ($85) {
     label = 34;
     break;
    } else {
     $81 = $86;
    }
   }
   if ((label|0) == 33) {
    $91 = ___cxa_find_matching_catch()|0;
    $92 = tempRet0;
    ___cxa_call_unexpected(($91|0));
    // unreachable;
   }
   else if ((label|0) == 34) {
    $$pre$i$i$i18 = HEAP32[$temp>>2]|0;
    $93 = $$pre$i$i$i18;
    break;
   }
  }
 } while(0);
 __ZdlPv($93);
 ___resumeException($74|0);
 // unreachable;
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 20)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 20)&-1;
 $15 = (($__v) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($__v) + 16|0);
 HEAP32[$16>>2] = $9;
 $17 = ($__n|0)==(0);
 if ($17) {
  $20 = 0;
 } else {
  $18 = ($__n*20)|0;
  $19 = (__Znwj($18)|0);
  $20 = $19;
 }
 HEAP32[$__v>>2] = $20;
 $21 = (($20) + (($14*20)|0)|0);
 $22 = (($__v) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($__v) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = (($20) + (($__n*20)|0)|0);
 HEAP32[$15>>2] = $24;
 __THREW__ = 0;
 invoke_vii(2606,($this|0),($__v|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $46 = HEAP32[$23>>2]|0;
  $47 = HEAP32[$22>>2]|0;
  $48 = ($47|0)==($46|0);
  L23: do {
   if (!($48)) {
    $50 = $47;
    while(1) {
     $49 = (($50) + -20|0);
     HEAP32[$22>>2] = $49;
     $51 = HEAP8[$49>>0]|0;
     $52 = $51 & 1;
     $53 = ($52<<24>>24)==(0);
     if (!($53)) {
      $55 = (($50) + -12|0);
      $56 = HEAP32[$55>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($56|0),($$byval_copy1|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
     }
     $54 = ($49|0)==($46|0);
     if ($54) {
      break L23;
     } else {
      $50 = $49;
     }
    }
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    ___cxa_call_unexpected(($59|0));
    // unreachable;
   }
  } while(0);
  $61 = HEAP32[$__v>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   ___resumeException($44|0);
   // unreachable;
  }
  __ZdlPv($61);
  ___resumeException($44|0);
  // unreachable;
 } else {
  $27 = HEAP32[$23>>2]|0;
  $28 = HEAP32[$22>>2]|0;
  $29 = ($28|0)==($27|0);
  L9: do {
   if (!($29)) {
    $31 = $28;
    while(1) {
     $30 = (($31) + -20|0);
     HEAP32[$22>>2] = $30;
     $32 = HEAP8[$30>>0]|0;
     $33 = $32 & 1;
     $34 = ($33<<24>>24)==(0);
     if (!($34)) {
      $36 = (($31) + -12|0);
      $37 = HEAP32[$36>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($37|0),($$byval_copy1|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
     }
     $35 = ($30|0)==($27|0);
     if ($35) {
      break L9;
     } else {
      $31 = $30;
     }
    }
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
  } while(0);
  $42 = HEAP32[$__v>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   STACKTOP = sp;return;
  }
  __ZdlPv($42);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i10 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 24|0;
 $$byval_copy4 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = HEAP32[$__first>>2]|0;
 $6 = HEAP32[$__last>>2]|0;
 $7 = $6;
 $8 = $5;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 20)&-1;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$this>>2]|0;
 $14 = $12;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 20)&-1;
 $18 = ($10>>>0)>($17>>>0);
 if ($18) {
  $52 = ($13|0)==(0|0);
  if ($52) {
   $72 = $12;
  } else {
   $53 = (($this) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==($13|0);
   do {
    if ($55) {
     $69 = $13;
    } else {
     $57 = $54;
     while(1) {
      $56 = (($57) + -20|0);
      HEAP32[$53>>2] = $56;
      $58 = HEAP8[$56>>0]|0;
      $59 = $58 & 1;
      $60 = ($59<<24>>24)==(0);
      if ($60) {
       $62 = $56;
      } else {
       $63 = (($57) + -12|0);
       $64 = HEAP32[$63>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($64|0),($$byval_copy5|0));
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$53>>2]|0;
       $62 = $$pre$i$i$i$i;
      }
      $61 = ($62|0)==($13|0);
      if ($61) {
       label = 25;
       break;
      } else {
       $57 = $62;
      }
     }
     if ((label|0) == 24) {
      $67 = ___cxa_find_matching_catch()|0;
      $68 = tempRet0;
      ___cxa_call_unexpected(($67|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $69 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($69);
   HEAP32[$11>>2] = 0;
   HEAP32[$53>>2] = 0;
   HEAP32[$this>>2] = 0;
   $72 = 0;
  }
  $70 = ($10>>>0)>(214748364);
  if ($70) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $71 = $72;
  $73 = (($71|0) / 20)&-1;
  $74 = ($73>>>0)<(107374182);
  if ($74) {
   $75 = $73 << 1;
   $76 = ($75>>>0)<($10>>>0);
   $77 = $76 ? $10 : $75;
   $78 = ($77>>>0)>(214748364);
   if ($78) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i10 = $77;
   }
  } else {
   $$0$i10 = 214748364;
  }
  $79 = ($$0$i10*20)|0;
  $80 = (__Znwj($79)|0);
  $81 = (($this) + 4|0);
  HEAP32[$81>>2] = $80;
  HEAP32[$this>>2] = $80;
  $82 = (($80) + (($$0$i10*20)|0)|0);
  HEAP32[$11>>2] = $82;
  HEAP32[$3>>2] = $5;
  HEAP32[$4>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
  __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 $22 = (($21) - ($15))|0;
 $23 = (($22|0) / 20)&-1;
 $24 = ($10>>>0)>($23>>>0);
 if ($24) {
  $25 = (($5) + (($23*20)|0)|0);
  $27 = $25;$__growing$0$off0 = 1;
 } else {
  $27 = $6;$__growing$0$off0 = 0;
 }
 $26 = ($5|0)==($27|0);
 if ($26) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i = (($27) + -20|0);
  $28 = (0 - ($8))|0;
  $uglygep$i = (($scevgep$i) + ($28)|0);
  $uglygep16$i = $uglygep$i;
  $29 = (($uglygep16$i>>>0) / 20)&-1;
  $$01$i$i = $13;$30 = $5;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($$01$i$i,$30)|0);
   $31 = (($$01$i$i) + 12|0);
   $32 = (($30) + 12|0);
   ;HEAP32[$31+0>>2]=HEAP32[$32+0>>2]|0;HEAP8[$31+4>>0]=HEAP8[$32+4>>0]|0;
   $33 = (($30) + 20|0);
   $34 = (($$01$i$i) + 20|0);
   $35 = ($33|0)==($27|0);
   if ($35) {
    break;
   } else {
    $$01$i$i = $34;$30 = $33;
   }
  }
  $36 = (($29) + 1)|0;
  $scevgep17$i = (($13) + (($36*20)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  HEAP32[$1>>2] = $27;
  HEAP32[$2>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$19>>2]|0;
 $38 = ($37|0)==($$0$lcssa$i$i|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $40 = $37;
 while(1) {
  $39 = (($40) + -20|0);
  HEAP32[$19>>2] = $39;
  $41 = HEAP8[$39>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   $45 = $39;
  } else {
   $46 = (($40) + -12|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$$byval_copy4>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy4+0>>2]|0;
   invoke_vii(2591,($47|0),($$byval_copy5|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    label = 16;
    break;
   }
   $$pre$i$i = HEAP32[$19>>2]|0;
   $45 = $$pre$i$i;
  }
  $44 = ($45|0)==($$0$lcssa$i$i|0);
  if ($44) {
   label = 33;
   break;
  } else {
   $40 = $45;
  }
 }
 if ((label|0) == 16) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  ___cxa_call_unexpected(($50|0));
  // unreachable;
 }
 else if ((label|0) == 33) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$byval_copy = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 while(1) {
  $5 = ($6|0)==(0|0);
  if ($5) {
   $35 = 0;$37 = $8;
  } else {
   $7 = HEAP8[$8>>0]|0;
   $9 = $7 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $15 = (($8) + 1|0);
    $16 = $7&255;
    $17 = $16 >>> 1;
    $19 = $17;$30 = $15;
   } else {
    $11 = (($8) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($8) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $19 = $14;$30 = $12;
   }
   $18 = ($19>>>0)>(2147483631);
   if ($18) {
    label = 8;
    break;
   }
   $20 = ($19>>>0)<(11);
   if ($20) {
    $21 = $19 << 1;
    $22 = $21&255;
    HEAP8[$6>>0] = $22;
    $23 = (($6) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $23;
   } else {
    $24 = (($19) + 16)|0;
    $25 = $24 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy,0,567120,79)|0);
    $27 = (($6) + 8|0);
    HEAP32[$27>>2] = $26;
    $28 = $25 | 1;
    HEAP32[$6>>2] = $28;
    $29 = (($6) + 4|0);
    HEAP32[$29>>2] = $19;
    $__p$0$i$i$i$i$i$i$i = $26;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($30|0),($19|0))|0;
   $31 = (($__p$0$i$i$i$i$i$i$i) + ($19)|0);
   HEAP8[$31>>0] = 0;
   $32 = (($6) + 12|0);
   $33 = (($8) + 12|0);
   ;HEAP32[$32+0>>2]=HEAP32[$33+0>>2]|0;HEAP8[$32+4>>0]=HEAP8[$33+4>>0]|0;
   $$pre1 = HEAP32[$4>>2]|0;
   $$pre2 = HEAP32[$__first>>2]|0;
   $35 = $$pre1;$37 = $$pre2;
  }
  $34 = (($35) + 20|0);
  HEAP32[$4>>2] = $34;
  $36 = (($37) + 20|0);
  HEAP32[$__first>>2] = $36;
  $38 = ($36|0)==($2|0);
  if ($38) {
   label = 14;
   break;
  } else {
   $6 = $34;$8 = $36;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i714 = 0, $$0$i715 = 0, $$0$i9 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$pre1$i1113 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 20)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $15 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
    $12 = (($11) + 12|0);
    HEAP32[$12>>2] = 1;
    $13 = (($11) + 16|0);
    HEAP8[$13>>0] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $15 = $$pre1$i;
   }
   $14 = (($15) + 20|0);
   HEAP32[$3>>2] = $14;
   $16 = (($$0$i) + -1)|0;
   $17 = ($16|0)==(0);
   if ($17) {
    break;
   } else {
    $$0$i = $16;$11 = $14;
   }
  }
  STACKTOP = sp;return;
 }
 $18 = (($this) + 8|0);
 $19 = HEAP32[$this>>2]|0;
 $20 = $19;
 $21 = (($6) - ($20))|0;
 $22 = (($21|0) / 20)&-1;
 $23 = (($22) + ($__n))|0;
 $24 = ($23>>>0)>(214748364);
 if ($24) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $25 = (($5) - ($20))|0;
 $26 = (($25|0) / 20)&-1;
 $27 = ($26>>>0)<(107374182);
 if ($27) {
  $30 = $26 << 1;
  $31 = ($30>>>0)<($23>>>0);
  $32 = $31 ? $23 : $30;
  $33 = (($__v) + 12|0);
  HEAP32[$33>>2] = 0;
  $34 = (($__v) + 16|0);
  HEAP32[$34>>2] = $18;
  $35 = ($32|0)==(0);
  if ($35) {
   $$0$i715 = 0;$38 = 0;$43 = $33;
  } else {
   $$0$i714 = $32;$89 = $33;
   label = 10;
  }
 } else {
  $28 = (($__v) + 12|0);
  HEAP32[$28>>2] = 0;
  $29 = (($__v) + 16|0);
  HEAP32[$29>>2] = $18;
  $$0$i714 = 214748364;$89 = $28;
  label = 10;
 }
 if ((label|0) == 10) {
  $36 = ($$0$i714*20)|0;
  $37 = (__Znwj($36)|0);
  $$0$i715 = $$0$i714;$38 = $37;$43 = $89;
 }
 HEAP32[$__v>>2] = $38;
 $39 = (($38) + (($22*20)|0)|0);
 $40 = (($__v) + 8|0);
 HEAP32[$40>>2] = $39;
 $41 = (($__v) + 4|0);
 HEAP32[$41>>2] = $39;
 $42 = (($38) + (($$0$i715*20)|0)|0);
 HEAP32[$43>>2] = $42;
 $$0$i9 = $__n;$$pre1$i1113 = $39;
 while(1) {
  $44 = ($$pre1$i1113|0)==(0|0);
  if ($44) {
   $48 = 0;
  } else {
   ;HEAP32[$$pre1$i1113+0>>2]=0|0;HEAP32[$$pre1$i1113+4>>2]=0|0;HEAP32[$$pre1$i1113+8>>2]=0|0;
   $45 = (($$pre1$i1113) + 12|0);
   HEAP32[$45>>2] = 1;
   $46 = (($$pre1$i1113) + 16|0);
   HEAP8[$46>>0] = 0;
   $48 = $$pre1$i1113;
  }
  $47 = (($48) + 20|0);
  $49 = (($$0$i9) + -1)|0;
  $50 = ($49|0)==(0);
  if ($50) {
   break;
  } else {
   $$0$i9 = $49;$$pre1$i1113 = $47;
  }
 }
 HEAP32[$40>>2] = $47;
 __THREW__ = 0;
 invoke_vii(2606,($this|0),($__v|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $70 = ___cxa_find_matching_catch()|0;
  $71 = tempRet0;
  $72 = HEAP32[$41>>2]|0;
  $73 = HEAP32[$40>>2]|0;
  $74 = ($73|0)==($72|0);
  L40: do {
   if (!($74)) {
    $76 = $73;
    while(1) {
     $75 = (($76) + -20|0);
     HEAP32[$40>>2] = $75;
     $77 = HEAP8[$75>>0]|0;
     $78 = $77 & 1;
     $79 = ($78<<24>>24)==(0);
     if (!($79)) {
      $81 = (($76) + -12|0);
      $82 = HEAP32[$81>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($82|0),($$byval_copy1|0));
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if ($84) {
       break;
      }
     }
     $80 = ($75|0)==($72|0);
     if ($80) {
      break L40;
     } else {
      $76 = $75;
     }
    }
    $85 = ___cxa_find_matching_catch()|0;
    $86 = tempRet0;
    ___cxa_call_unexpected(($85|0));
    // unreachable;
   }
  } while(0);
  $87 = HEAP32[$__v>>2]|0;
  $88 = ($87|0)==(0|0);
  if ($88) {
   ___resumeException($70|0);
   // unreachable;
  }
  __ZdlPv($87);
  ___resumeException($70|0);
  // unreachable;
 } else {
  $53 = HEAP32[$41>>2]|0;
  $54 = HEAP32[$40>>2]|0;
  $55 = ($54|0)==($53|0);
  L26: do {
   if (!($55)) {
    $57 = $54;
    while(1) {
     $56 = (($57) + -20|0);
     HEAP32[$40>>2] = $56;
     $58 = HEAP8[$56>>0]|0;
     $59 = $58 & 1;
     $60 = ($59<<24>>24)==(0);
     if (!($60)) {
      $62 = (($57) + -12|0);
      $63 = HEAP32[$62>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($63|0),($$byval_copy1|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
     }
     $61 = ($56|0)==($53|0);
     if ($61) {
      break L26;
     } else {
      $57 = $56;
     }
    }
    $66 = ___cxa_find_matching_catch()|0;
    $67 = tempRet0;
    ___cxa_call_unexpected(($66|0));
    // unreachable;
   }
  } while(0);
  $68 = HEAP32[$__v>>2]|0;
  $69 = ($68|0)==(0|0);
  if ($69) {
   STACKTOP = sp;return;
  }
  __ZdlPv($68);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__v) + 4|0);
 $5 = ($3|0)==($1|0);
 do {
  if ($5) {
   $$pre1 = HEAP32[$4>>2]|0;
   $38 = $$pre1;$39 = $1;
  } else {
   $$pre$i = HEAP32[$4>>2]|0;
   $$01$i = $3;$7 = $$pre$i;
   while(1) {
    $6 = (($7) + -20|0);
    $8 = (($$01$i) + -20|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9 & 1;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $16 = (($8) + 1|0);
     $17 = $9&255;
     $18 = $17 >>> 1;
     $20 = $18;$31 = $16;
    } else {
     $12 = (($$01$i) + -12|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($$01$i) + -16|0);
     $15 = HEAP32[$14>>2]|0;
     $20 = $15;$31 = $13;
    }
    $19 = ($20>>>0)>(2147483631);
    if ($19) {
     label = 8;
     break;
    }
    $21 = ($20>>>0)<(11);
    if ($21) {
     $22 = $20 << 1;
     $23 = $22&255;
     HEAP8[$6>>0] = $23;
     $24 = (($6) + 1|0);
     $__p$0$i$i$i$i$i$i$i$i = $24;
    } else {
     $25 = (($20) + 16)|0;
     $26 = $25 & -16;
     HEAP32[$0>>2] = 59;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $27 = (__Z15malloc_internaljj10MemLabelIdiPKci($26,16,$$byval_copy,0,567120,79)|0);
     $28 = (($7) + -12|0);
     HEAP32[$28>>2] = $27;
     $29 = $26 | 1;
     HEAP32[$6>>2] = $29;
     $30 = (($7) + -16|0);
     HEAP32[$30>>2] = $20;
     $__p$0$i$i$i$i$i$i$i$i = $27;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($31|0),($20|0))|0;
    $32 = (($__p$0$i$i$i$i$i$i$i$i) + ($20)|0);
    HEAP8[$32>>0] = 0;
    $33 = (($7) + -8|0);
    $34 = (($$01$i) + -8|0);
    ;HEAP32[$33+0>>2]=HEAP32[$34+0>>2]|0;HEAP8[$33+4>>0]=HEAP8[$34+4>>0]|0;
    $35 = HEAP32[$4>>2]|0;
    $36 = (($35) + -20|0);
    HEAP32[$4>>2] = $36;
    $37 = ($8|0)==($1|0);
    if ($37) {
     label = 13;
     break;
    } else {
     $$01$i = $8;$7 = $36;
    }
   }
   if ((label|0) == 8) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre = HEAP32[$this>>2]|0;
    $38 = $36;$39 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $38;
 HEAP32[$4>>2] = $39;
 $40 = (($__v) + 8|0);
 $41 = HEAP32[$2>>2]|0;
 $42 = HEAP32[$40>>2]|0;
 HEAP32[$2>>2] = $42;
 HEAP32[$40>>2] = $41;
 $43 = (($this) + 8|0);
 $44 = (($__v) + 12|0);
 $45 = HEAP32[$43>>2]|0;
 $46 = HEAP32[$44>>2]|0;
 HEAP32[$43>>2] = $46;
 HEAP32[$44>>2] = $45;
 $47 = HEAP32[$4>>2]|0;
 HEAP32[$__v>>2] = $47;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ph = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$20 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$20 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $22 = $$pre$i$i$i4;
 } else {
  $21 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $21;
  HEAP32[$1>>2] = $6;
  $22 = $21;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$size1>>2] = $23;
 $24 = HEAP8[$data>>0]|0;
 $25 = $24 & 1;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $29 = $24&255;
  $30 = $29 >>> 1;
  $32 = $30;
 } else {
  $27 = (($data) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $32 = $28;
 }
 $31 = ($32>>>0)<($23>>>0);
 do {
  if ($31) {
   $33 = (($23) - ($32))|0;
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6appendEjc($data,$33,1)|0);
  } else {
   if ($26) {
    $38 = ((($data) + ($23)|0) + 1|0);
    HEAP8[$38>>0] = 0;
    $39 = $23 << 1;
    $40 = $39&255;
    HEAP8[$data>>0] = $40;
    break;
   } else {
    $34 = (($data) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + ($23)|0);
    HEAP8[$36>>0] = 0;
    $37 = (($data) + 4|0);
    HEAP32[$37>>2] = $23;
    break;
   }
  }
 } while(0);
 $41 = HEAP8[$data>>0]|0;
 $42 = $41 & 1;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  $49 = $41&255;
  $50 = $49 >>> 1;
  $51 = ((($data) + ($50)|0) + 1|0);
  $52 = (($data) + 1|0);
  $$ph = $52;$54 = $51;
 } else {
  $44 = (($data) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($data) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + ($47)|0);
  $$ph = $45;$54 = $48;
 }
 $53 = ($$ph|0)==($54|0);
 if ($53) {
  STACKTOP = sp;return;
 } else {
  $60 = $$ph;
 }
 while(1) {
  $55 = HEAP32[$1>>2]|0;
  $56 = (($55) + 1|0);
  $57 = HEAP32[$7>>2]|0;
  $58 = ($56>>>0)>($57>>>0);
  if ($58) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$60,1);
  } else {
   $59 = HEAP8[$55>>0]|0;
   HEAP8[$60>>0] = $59;
   $61 = HEAP32[$1>>2]|0;
   $62 = (($61) + 1|0);
   HEAP32[$1>>2] = $62;
  }
  $63 = (($60) + 1|0);
  $64 = ($63|0)==($54|0);
  if ($64) {
   break;
  } else {
   $60 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6appendEjc($this,$__n,$__c) {
 $this = $this|0;
 $__n = $__n|0;
 $__c = $__c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)==(0);
 if ($0) {
  STACKTOP = sp;return ($this|0);
 }
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $15 = 10;$8 = $1;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 & -2;
  $phitmp$i = (($5) + -1)|0;
  $6 = $4&255;
  $15 = $phitmp$i;$8 = $6;
 }
 $7 = $8 & 1;
 $9 = ($7<<24>>24)==(0);
 if ($9) {
  $12 = $8&255;
  $13 = $12 >>> 1;
  $16 = $13;
 } else {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $16 = $11;
 }
 $14 = (($15) - ($16))|0;
 $17 = ($14>>>0)<($__n>>>0);
 if ($17) {
  $18 = (($__n) - ($15))|0;
  $19 = (($18) + ($16))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE9__grow_byEjjjjjj($this,$15,$19,$16,$16,0,0);
  $$pre = HEAP8[$this>>0]|0;
  $21 = $$pre;
 } else {
  $21 = $8;
 }
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($22) {
  $25 = (($this) + 1|0);
  $27 = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $27 = $24;
 }
 $26 = (($27) + ($16)|0);
 _memset(($26|0),($__c|0),($__n|0))|0;
 $28 = (($16) + ($__n))|0;
 $29 = HEAP8[$this>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $33 = $28 << 1;
  $34 = $33&255;
  HEAP8[$this>>0] = $34;
 } else {
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $28;
 }
 $35 = (($27) + ($28)|0);
 HEAP8[$35>>0] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE9__grow_byEjjjjjj($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 var $$byval_copy1 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (2147483631 - ($__old_cap))|0;
 $2 = ($1>>>0)<($__delta_cap>>>0);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($this) + 1|0);
  $20 = $8;
 } else {
  $6 = (($this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $20 = $7;
 }
 $9 = ($__old_cap>>>0)<(1073741799);
 if ($9) {
  $10 = (($__delta_cap) + ($__old_cap))|0;
  $11 = $__old_cap << 1;
  $12 = ($10>>>0)<($11>>>0);
  $13 = $12 ? $11 : $10;
  $14 = ($13>>>0)<(11);
  if ($14) {
   $17 = 11;
  } else {
   $15 = (($13) + 16)|0;
   $16 = $15 & -16;
   $17 = $16;
  }
 } else {
  $17 = 2147483631;
 }
 HEAP32[$0>>2] = 59;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($17,16,$$byval_copy1,0,567120,79)|0);
 $19 = ($__n_copy|0)==(0);
 if (!($19)) {
  _memcpy(($18|0),($20|0),($__n_copy|0))|0;
 }
 $21 = (($__old_sz) - ($__n_del))|0;
 $22 = ($21|0)==($__n_copy|0);
 if (!($22)) {
  $23 = (($21) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $24 = (($18) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $25 = (($20) + ($$sum1)|0);
  _memcpy(($24|0),($25|0),($23|0))|0;
 }
 $26 = ($__old_cap|0)==(10);
 if ($26) {
  $31 = (($this) + 8|0);
  HEAP32[$31>>2] = $18;
  $32 = $17 | 1;
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($20|0),($$byval_copy1|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  ___cxa_call_unexpected(($29|0));
  // unreachable;
 } else {
  $31 = (($this) + 8|0);
  HEAP32[$31>>2] = $18;
  $32 = $17 | 1;
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI8UnityStrNS0_9allocatorIS2_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$29,0);
   __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
   $30 = (($29) + 12|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI8UnityStrNS0_9allocatorIS2_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy5 = 0, $$byval_copy8 = 0, $$idx = 0, $$pre = 0, $$pre$i$i$i$i$i16 = 0, $$pre$i$i$i$i$i8 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i5 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $temp = 0, $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 44|0;
 $$byval_copy5 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $temp = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $temp1 = sp + 32|0;
 $4 = (($v) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$v>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $95 = ($10>>>0)>($sz>>>0);
  if (!($95)) {
   STACKTOP = sp;return;
  }
  $96 = (($6) + (($sz*12)|0)|0);
  HEAP32[$temp1>>2] = 0;
  $97 = (($temp1) + 4|0);
  HEAP32[$97>>2] = 0;
  $98 = (($temp1) + 8|0);
  HEAP32[$98>>2] = 0;
  $$idx = ($sz*12)|0;
  $99 = (($$idx|0) / 12)&-1;
  $100 = ($sz|0)==(0);
  do {
   if ($100) {
    $128 = $6;$129 = 0;$130 = $5;$131 = 0;$134 = 0;
   } else {
    $101 = ($99>>>0)>(357913941);
    if ($101) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if (!($103)) {
      // unreachable;
     }
    } else {
     __THREW__ = 0;
     $104 = (invoke_ii(2988,($$idx|0))|0);
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if (!($106)) {
      HEAP32[$97>>2] = $104;
      HEAP32[$temp1>>2] = $104;
      $107 = (($104) + (($99*12)|0)|0);
      HEAP32[$98>>2] = $107;
      HEAP32[$0>>2] = $6;
      HEAP32[$1>>2] = $96;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_viii(1648,($temp1|0),($$byval_copy5|0),($$byval_copy8|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if (!($109)) {
       $$pre36 = HEAP32[$temp1>>2]|0;
       $$pre37 = HEAP32[$v>>2]|0;
       $$pre38 = HEAP32[$97>>2]|0;
       $$pre39 = HEAP32[$4>>2]|0;
       $$pre40 = HEAP32[$98>>2]|0;
       $128 = $$pre37;$129 = $$pre36;$130 = $$pre39;$131 = $$pre38;$134 = $$pre40;
       break;
      }
     }
    }
    $110 = ___cxa_find_matching_catch()|0;
    $111 = tempRet0;
    $112 = HEAP32[$temp1>>2]|0;
    $113 = ($112|0)==(0|0);
    if ($113) {
     ___resumeException($110|0);
     // unreachable;
    }
    $114 = HEAP32[$97>>2]|0;
    $115 = ($114|0)==($112|0);
    L18: do {
     if (!($115)) {
      $117 = $114;
      while(1) {
       $116 = (($117) + -12|0);
       HEAP32[$97>>2] = $116;
       $118 = HEAP8[$116>>0]|0;
       $119 = $118 & 1;
       $120 = ($119<<24>>24)==(0);
       if (!($120)) {
        $122 = (($117) + -4|0);
        $123 = HEAP32[$122>>2]|0;
        HEAP32[$$byval_copy5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
        invoke_vii(2591,($123|0),($$byval_copy8|0));
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break;
        }
       }
       $121 = ($116|0)==($112|0);
       if ($121) {
        break L18;
       } else {
        $117 = $116;
       }
      }
      $126 = ___cxa_find_matching_catch()|0;
      $127 = tempRet0;
      ___cxa_call_unexpected(($126|0));
      // unreachable;
     }
    } while(0);
    __ZdlPv($112);
    ___resumeException($110|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$temp1>>2] = $128;
  HEAP32[$v>>2] = $129;
  HEAP32[$97>>2] = $130;
  HEAP32[$4>>2] = $131;
  $132 = (($v) + 8|0);
  $133 = HEAP32[$132>>2]|0;
  HEAP32[$98>>2] = $133;
  HEAP32[$132>>2] = $134;
  $135 = ($128|0)==(0|0);
  if ($135) {
   STACKTOP = sp;return;
  }
  $136 = ($130|0)==($128|0);
  L32: do {
   if (!($136)) {
    $138 = $130;
    while(1) {
     $137 = (($138) + -12|0);
     HEAP32[$97>>2] = $137;
     $139 = HEAP8[$137>>0]|0;
     $140 = $139 & 1;
     $141 = ($140<<24>>24)==(0);
     if (!($141)) {
      $143 = (($138) + -4|0);
      $144 = HEAP32[$143>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($144|0),($$byval_copy8|0));
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       break;
      }
     }
     $142 = ($137|0)==($128|0);
     if ($142) {
      break L32;
     } else {
      $138 = $137;
     }
    }
    $147 = ___cxa_find_matching_catch()|0;
    $148 = tempRet0;
    ___cxa_call_unexpected(($147|0));
    // unreachable;
   }
  } while(0);
  __ZdlPv($128);
  STACKTOP = sp;return;
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 12)&-1;
 $17 = ($16|0)==($sz|0);
 if ($17) {
  $94 = (($sz) - ($10))|0;
  __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE8__appendEj($v,$94);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $18 = (($temp) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($temp) + 8|0);
 HEAP32[$19>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2607,($temp|0),($sz|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L47: do {
  if (!($21)) {
   $22 = HEAP32[$v>>2]|0;
   HEAP32[$2>>2] = $22;
   $23 = HEAP32[$4>>2]|0;
   HEAP32[$3>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viii(1647,($temp|0),($$byval_copy5|0),($$byval_copy8|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$18>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = (($30|0) / 12)&-1;
    $32 = ($31>>>0)<($sz>>>0);
    L50: do {
     if ($32) {
      $33 = (($sz) - ($31))|0;
      __THREW__ = 0;
      invoke_vii(2608,($temp|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L47;
      }
      $$pre = HEAP32[$18>>2]|0;
      $55 = $$pre;
     } else {
      $36 = ($31>>>0)>($sz>>>0);
      if ($36) {
       $37 = (($27) + (($sz*12)|0)|0);
       $38 = ($26|0)==($37|0);
       if ($38) {
        $55 = $26;
       } else {
        $40 = $26;
        while(1) {
         $39 = (($40) + -12|0);
         HEAP32[$18>>2] = $39;
         $41 = HEAP8[$39>>0]|0;
         $42 = $41 & 1;
         $43 = ($42<<24>>24)==(0);
         if ($43) {
          $45 = $39;
         } else {
          $46 = (($40) + -4|0);
          $47 = HEAP32[$46>>2]|0;
          HEAP32[$0>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($47|0),($$byval_copy8|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          $$pre$i$i$i5 = HEAP32[$18>>2]|0;
          $45 = $$pre$i$i$i5;
         }
         $44 = ($45|0)==($37|0);
         if ($44) {
          $55 = $37;
          break L50;
         } else {
          $40 = $45;
         }
        }
        $50 = ___cxa_find_matching_catch()|0;
        $51 = tempRet0;
        ___cxa_call_unexpected(($50|0));
        // unreachable;
       }
      } else {
       $55 = $26;
      }
     }
    } while(0);
    $52 = HEAP32[$temp>>2]|0;
    $53 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $53;
    HEAP32[$v>>2] = $52;
    $54 = HEAP32[$4>>2]|0;
    HEAP32[$18>>2] = $54;
    HEAP32[$4>>2] = $55;
    $56 = HEAP32[$19>>2]|0;
    $57 = HEAP32[$12>>2]|0;
    HEAP32[$19>>2] = $57;
    HEAP32[$12>>2] = $56;
    $58 = ($53|0)==(0|0);
    if ($58) {
     STACKTOP = sp;return;
    }
    $59 = ($54|0)==($53|0);
    do {
     if ($59) {
      $73 = $53;
     } else {
      $61 = $54;
      while(1) {
       $60 = (($61) + -12|0);
       HEAP32[$18>>2] = $60;
       $62 = HEAP8[$60>>0]|0;
       $63 = $62 & 1;
       $64 = ($63<<24>>24)==(0);
       if ($64) {
        $66 = $60;
       } else {
        $67 = (($61) + -4|0);
        $68 = HEAP32[$67>>2]|0;
        HEAP32[$$byval_copy5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
        invoke_vii(2591,($68|0),($$byval_copy8|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 23;
         break;
        }
        $$pre$i$i$i$i$i8 = HEAP32[$18>>2]|0;
        $66 = $$pre$i$i$i$i$i8;
       }
       $65 = ($66|0)==($53|0);
       if ($65) {
        label = 24;
        break;
       } else {
        $61 = $66;
       }
      }
      if ((label|0) == 23) {
       $71 = ___cxa_find_matching_catch()|0;
       $72 = tempRet0;
       ___cxa_call_unexpected(($71|0));
       // unreachable;
      }
      else if ((label|0) == 24) {
       $$pre$i$i$i10 = HEAP32[$temp>>2]|0;
       $73 = $$pre$i$i$i10;
       break;
      }
     }
    } while(0);
    __ZdlPv($73);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $74 = ___cxa_find_matching_catch()|0;
 $75 = tempRet0;
 $76 = HEAP32[$temp>>2]|0;
 $77 = ($76|0)==(0|0);
 if ($77) {
  ___resumeException($74|0);
  // unreachable;
 }
 $78 = HEAP32[$18>>2]|0;
 $79 = ($78|0)==($76|0);
 do {
  if ($79) {
   $93 = $76;
  } else {
   $81 = $78;
   while(1) {
    $80 = (($81) + -12|0);
    HEAP32[$18>>2] = $80;
    $82 = HEAP8[$80>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if ($84) {
     $86 = $80;
    } else {
     $87 = (($81) + -4|0);
     $88 = HEAP32[$87>>2]|0;
     HEAP32[$$byval_copy5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
     invoke_vii(2591,($88|0),($$byval_copy8|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 33;
      break;
     }
     $$pre$i$i$i$i$i16 = HEAP32[$18>>2]|0;
     $86 = $$pre$i$i$i$i$i16;
    }
    $85 = ($86|0)==($76|0);
    if ($85) {
     label = 34;
     break;
    } else {
     $81 = $86;
    }
   }
   if ((label|0) == 33) {
    $91 = ___cxa_find_matching_catch()|0;
    $92 = tempRet0;
    ___cxa_call_unexpected(($91|0));
    // unreachable;
   }
   else if ((label|0) == 34) {
    $$pre$i$i$i18 = HEAP32[$temp>>2]|0;
    $93 = $$pre$i$i$i18;
    break;
   }
  }
 } while(0);
 __ZdlPv($93);
 ___resumeException($74|0);
 // unreachable;
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 12)&-1;
 $15 = (($__v) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($__v) + 16|0);
 HEAP32[$16>>2] = $9;
 $17 = ($__n|0)==(0);
 if ($17) {
  $20 = 0;
 } else {
  $18 = ($__n*12)|0;
  $19 = (__Znwj($18)|0);
  $20 = $19;
 }
 HEAP32[$__v>>2] = $20;
 $21 = (($20) + (($14*12)|0)|0);
 $22 = (($__v) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($__v) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = (($20) + (($__n*12)|0)|0);
 HEAP32[$15>>2] = $24;
 __THREW__ = 0;
 invoke_vii(2603,($this|0),($__v|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $46 = HEAP32[$23>>2]|0;
  $47 = HEAP32[$22>>2]|0;
  $48 = ($47|0)==($46|0);
  L23: do {
   if (!($48)) {
    $50 = $47;
    while(1) {
     $49 = (($50) + -12|0);
     HEAP32[$22>>2] = $49;
     $51 = HEAP8[$49>>0]|0;
     $52 = $51 & 1;
     $53 = ($52<<24>>24)==(0);
     if (!($53)) {
      $55 = (($50) + -4|0);
      $56 = HEAP32[$55>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($56|0),($$byval_copy1|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
     }
     $54 = ($49|0)==($46|0);
     if ($54) {
      break L23;
     } else {
      $50 = $49;
     }
    }
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    ___cxa_call_unexpected(($59|0));
    // unreachable;
   }
  } while(0);
  $61 = HEAP32[$__v>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   ___resumeException($44|0);
   // unreachable;
  }
  __ZdlPv($61);
  ___resumeException($44|0);
  // unreachable;
 } else {
  $27 = HEAP32[$23>>2]|0;
  $28 = HEAP32[$22>>2]|0;
  $29 = ($28|0)==($27|0);
  L9: do {
   if (!($29)) {
    $31 = $28;
    while(1) {
     $30 = (($31) + -12|0);
     HEAP32[$22>>2] = $30;
     $32 = HEAP8[$30>>0]|0;
     $33 = $32 & 1;
     $34 = ($33<<24>>24)==(0);
     if (!($34)) {
      $36 = (($31) + -4|0);
      $37 = HEAP32[$36>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($37|0),($$byval_copy1|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
     }
     $35 = ($30|0)==($27|0);
     if ($35) {
      break L9;
     } else {
      $31 = $30;
     }
    }
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
  } while(0);
  $42 = HEAP32[$__v>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   STACKTOP = sp;return;
  }
  __ZdlPv($42);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i10 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 24|0;
 $$byval_copy4 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = HEAP32[$__first>>2]|0;
 $6 = HEAP32[$__last>>2]|0;
 $7 = $6;
 $8 = $5;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$this>>2]|0;
 $14 = $12;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = ($10>>>0)>($17>>>0);
 if ($18) {
  $50 = ($13|0)==(0|0);
  if ($50) {
   $70 = $12;
  } else {
   $51 = (($this) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==($13|0);
   do {
    if ($53) {
     $67 = $13;
    } else {
     $55 = $52;
     while(1) {
      $54 = (($55) + -12|0);
      HEAP32[$51>>2] = $54;
      $56 = HEAP8[$54>>0]|0;
      $57 = $56 & 1;
      $58 = ($57<<24>>24)==(0);
      if ($58) {
       $60 = $54;
      } else {
       $61 = (($55) + -4|0);
       $62 = HEAP32[$61>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($62|0),($$byval_copy5|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$51>>2]|0;
       $60 = $$pre$i$i$i$i;
      }
      $59 = ($60|0)==($13|0);
      if ($59) {
       label = 25;
       break;
      } else {
       $55 = $60;
      }
     }
     if ((label|0) == 24) {
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      ___cxa_call_unexpected(($65|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $67 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($67);
   HEAP32[$11>>2] = 0;
   HEAP32[$51>>2] = 0;
   HEAP32[$this>>2] = 0;
   $70 = 0;
  }
  $68 = ($10>>>0)>(357913941);
  if ($68) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $69 = $70;
  $71 = (($69|0) / 12)&-1;
  $72 = ($71>>>0)<(178956970);
  if ($72) {
   $73 = $71 << 1;
   $74 = ($73>>>0)<($10>>>0);
   $75 = $74 ? $10 : $73;
   $76 = ($75>>>0)>(357913941);
   if ($76) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i10 = $75;
   }
  } else {
   $$0$i10 = 357913941;
  }
  $77 = ($$0$i10*12)|0;
  $78 = (__Znwj($77)|0);
  $79 = (($this) + 4|0);
  HEAP32[$79>>2] = $78;
  HEAP32[$this>>2] = $78;
  $80 = (($78) + (($$0$i10*12)|0)|0);
  HEAP32[$11>>2] = $80;
  HEAP32[$3>>2] = $5;
  HEAP32[$4>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
  __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 $22 = (($21) - ($15))|0;
 $23 = (($22|0) / 12)&-1;
 $24 = ($10>>>0)>($23>>>0);
 if ($24) {
  $25 = (($5) + (($23*12)|0)|0);
  $27 = $25;$__growing$0$off0 = 1;
 } else {
  $27 = $6;$__growing$0$off0 = 0;
 }
 $26 = ($5|0)==($27|0);
 if ($26) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i = (($27) + -12|0);
  $28 = (0 - ($8))|0;
  $uglygep$i = (($scevgep$i) + ($28)|0);
  $uglygep16$i = $uglygep$i;
  $29 = (($uglygep16$i>>>0) / 12)&-1;
  $$01$i$i = $13;$30 = $5;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($$01$i$i,$30)|0);
   $31 = (($30) + 12|0);
   $32 = (($$01$i$i) + 12|0);
   $33 = ($31|0)==($27|0);
   if ($33) {
    break;
   } else {
    $$01$i$i = $32;$30 = $31;
   }
  }
  $34 = (($29) + 1)|0;
  $scevgep17$i = (($13) + (($34*12)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  HEAP32[$1>>2] = $27;
  HEAP32[$2>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $35 = HEAP32[$19>>2]|0;
 $36 = ($35|0)==($$0$lcssa$i$i|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $38 = $35;
 while(1) {
  $37 = (($38) + -12|0);
  HEAP32[$19>>2] = $37;
  $39 = HEAP8[$37>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $43 = $37;
  } else {
   $44 = (($38) + -4|0);
   $45 = HEAP32[$44>>2]|0;
   HEAP32[$$byval_copy4>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy4+0>>2]|0;
   invoke_vii(2591,($45|0),($$byval_copy5|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    label = 16;
    break;
   }
   $$pre$i$i = HEAP32[$19>>2]|0;
   $43 = $$pre$i$i;
  }
  $42 = ($43|0)==($$0$lcssa$i$i|0);
  if ($42) {
   label = 33;
   break;
  } else {
   $38 = $43;
  }
 }
 if ((label|0) == 16) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 }
 else if ((label|0) == 33) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$byval_copy = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 while(1) {
  $5 = ($6|0)==(0|0);
  if ($5) {
   $33 = 0;$35 = $8;
  } else {
   $7 = HEAP8[$8>>0]|0;
   $9 = $7 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $15 = (($8) + 1|0);
    $16 = $7&255;
    $17 = $16 >>> 1;
    $19 = $17;$30 = $15;
   } else {
    $11 = (($8) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($8) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $19 = $14;$30 = $12;
   }
   $18 = ($19>>>0)>(2147483631);
   if ($18) {
    label = 8;
    break;
   }
   $20 = ($19>>>0)<(11);
   if ($20) {
    $21 = $19 << 1;
    $22 = $21&255;
    HEAP8[$6>>0] = $22;
    $23 = (($6) + 1|0);
    $__p$0$i$i$i$i$i = $23;
   } else {
    $24 = (($19) + 16)|0;
    $25 = $24 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy,0,567120,79)|0);
    $27 = (($6) + 8|0);
    HEAP32[$27>>2] = $26;
    $28 = $25 | 1;
    HEAP32[$6>>2] = $28;
    $29 = (($6) + 4|0);
    HEAP32[$29>>2] = $19;
    $__p$0$i$i$i$i$i = $26;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($30|0),($19|0))|0;
   $31 = (($__p$0$i$i$i$i$i) + ($19)|0);
   HEAP8[$31>>0] = 0;
   $$pre1 = HEAP32[$4>>2]|0;
   $$pre2 = HEAP32[$__first>>2]|0;
   $33 = $$pre1;$35 = $$pre2;
  }
  $32 = (($33) + 12|0);
  HEAP32[$4>>2] = $32;
  $34 = (($35) + 12|0);
  HEAP32[$__first>>2] = $34;
  $36 = ($34|0)==($2|0);
  if ($36) {
   label = 14;
   break;
  } else {
   $6 = $32;$8 = $34;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i714 = 0, $$0$i715 = 0, $$0$i9 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$pre1$i1113 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 12|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = (($this) + 8|0);
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($6) - ($18))|0;
 $20 = (($19|0) / 12)&-1;
 $21 = (($20) + ($__n))|0;
 $22 = ($21>>>0)>(357913941);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($5) - ($18))|0;
 $24 = (($23|0) / 12)&-1;
 $25 = ($24>>>0)<(178956970);
 if ($25) {
  $28 = $24 << 1;
  $29 = ($28>>>0)<($21>>>0);
  $30 = $29 ? $21 : $28;
  $31 = (($__v) + 12|0);
  HEAP32[$31>>2] = 0;
  $32 = (($__v) + 16|0);
  HEAP32[$32>>2] = $16;
  $33 = ($30|0)==(0);
  if ($33) {
   $$0$i715 = 0;$36 = 0;$41 = $31;
  } else {
   $$0$i714 = $30;$85 = $31;
   label = 10;
  }
 } else {
  $26 = (($__v) + 12|0);
  HEAP32[$26>>2] = 0;
  $27 = (($__v) + 16|0);
  HEAP32[$27>>2] = $16;
  $$0$i714 = 357913941;$85 = $26;
  label = 10;
 }
 if ((label|0) == 10) {
  $34 = ($$0$i714*12)|0;
  $35 = (__Znwj($34)|0);
  $$0$i715 = $$0$i714;$36 = $35;$41 = $85;
 }
 HEAP32[$__v>>2] = $36;
 $37 = (($36) + (($20*12)|0)|0);
 $38 = (($__v) + 8|0);
 HEAP32[$38>>2] = $37;
 $39 = (($__v) + 4|0);
 HEAP32[$39>>2] = $37;
 $40 = (($36) + (($$0$i715*12)|0)|0);
 HEAP32[$41>>2] = $40;
 $$0$i9 = $__n;$$pre1$i1113 = $37;
 while(1) {
  $42 = ($$pre1$i1113|0)==(0|0);
  if ($42) {
   $44 = 0;
  } else {
   ;HEAP32[$$pre1$i1113+0>>2]=0|0;HEAP32[$$pre1$i1113+4>>2]=0|0;HEAP32[$$pre1$i1113+8>>2]=0|0;
   $44 = $$pre1$i1113;
  }
  $43 = (($44) + 12|0);
  $45 = (($$0$i9) + -1)|0;
  $46 = ($45|0)==(0);
  if ($46) {
   break;
  } else {
   $$0$i9 = $45;$$pre1$i1113 = $43;
  }
 }
 HEAP32[$38>>2] = $43;
 __THREW__ = 0;
 invoke_vii(2603,($this|0),($__v|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $66 = ___cxa_find_matching_catch()|0;
  $67 = tempRet0;
  $68 = HEAP32[$39>>2]|0;
  $69 = HEAP32[$38>>2]|0;
  $70 = ($69|0)==($68|0);
  L40: do {
   if (!($70)) {
    $72 = $69;
    while(1) {
     $71 = (($72) + -12|0);
     HEAP32[$38>>2] = $71;
     $73 = HEAP8[$71>>0]|0;
     $74 = $73 & 1;
     $75 = ($74<<24>>24)==(0);
     if (!($75)) {
      $77 = (($72) + -4|0);
      $78 = HEAP32[$77>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($78|0),($$byval_copy1|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       break;
      }
     }
     $76 = ($71|0)==($68|0);
     if ($76) {
      break L40;
     } else {
      $72 = $71;
     }
    }
    $81 = ___cxa_find_matching_catch()|0;
    $82 = tempRet0;
    ___cxa_call_unexpected(($81|0));
    // unreachable;
   }
  } while(0);
  $83 = HEAP32[$__v>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   ___resumeException($66|0);
   // unreachable;
  }
  __ZdlPv($83);
  ___resumeException($66|0);
  // unreachable;
 } else {
  $49 = HEAP32[$39>>2]|0;
  $50 = HEAP32[$38>>2]|0;
  $51 = ($50|0)==($49|0);
  L26: do {
   if (!($51)) {
    $53 = $50;
    while(1) {
     $52 = (($53) + -12|0);
     HEAP32[$38>>2] = $52;
     $54 = HEAP8[$52>>0]|0;
     $55 = $54 & 1;
     $56 = ($55<<24>>24)==(0);
     if (!($56)) {
      $58 = (($53) + -4|0);
      $59 = HEAP32[$58>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($59|0),($$byval_copy1|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break;
      }
     }
     $57 = ($52|0)==($49|0);
     if ($57) {
      break L26;
     } else {
      $53 = $52;
     }
    }
    $62 = ___cxa_find_matching_catch()|0;
    $63 = tempRet0;
    ___cxa_call_unexpected(($62|0));
    // unreachable;
   }
  } while(0);
  $64 = HEAP32[$__v>>2]|0;
  $65 = ($64|0)==(0|0);
  if ($65) {
   STACKTOP = sp;return;
  }
  __ZdlPv($64);
  STACKTOP = sp;return;
 }
}
function __ZN10TagManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy24 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i36 = 0, $$pre$i$i$i$i$i44 = 0, $$pre$i$i$i$i$i6 = 0, $$pre$i$i$i38 = 0, $$pre$i$i$i46 = 0, $$pre$i$i$i8 = 0, $$pre72 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i16 = 0, $__p$0$i$i$i$i28 = 0, $i$02$i = 0, $i1$068 = 0, $i3$062 = 0, $i4$054 = 0, $layers = 0, $lpad$phi$index = 0, $lpad$phi$index8 = 0, $lpad$phi61$index = 0, $lpad$phi61$index14 = 0, $lpad$phi67$index = 0, $lpad$phi67$index2 = 0, $tags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy24 = sp + 88|0;
 $0 = sp + 84|0;
 $1 = sp + 80|0;
 $2 = sp + 76|0;
 $3 = sp + 72|0;
 $4 = sp + 68|0;
 $5 = sp + 64|0;
 $6 = sp + 48|0;
 $tags = sp + 36|0;
 $7 = sp + 24|0;
 $layers = sp + 12|0;
 $8 = sp;
 $9 = sp + 52|0;
 HEAP32[$tags>>2] = 0;
 $10 = (($tags) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($tags) + 8|0);
 HEAP32[$11>>2] = 0;
 __THREW__ = 0;
 invoke_vi(3387,($this|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L1: do {
  if ($13) {
   label = 3;
  } else {
   __THREW__ = 0;
   invoke_viii(1649,($transfer|0),($tags|0),0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    label = 3;
   } else {
    $20 = HEAP32[$10>>2]|0;
    $21 = HEAP32[$tags>>2]|0;
    $22 = ($20|0)==($21|0);
    L4: do {
     if (!($22)) {
      $23 = (($7) + 1|0);
      $24 = (($7) + 8|0);
      $25 = (($7) + 4|0);
      $27 = $21;$i1$068 = 0;
      while(1) {
       $26 = (($27) + (($i1$068*12)|0)|0);
       $28 = HEAP8[$26>>0]|0;
       $29 = $28 & 1;
       $30 = ($29<<24>>24)==(0);
       if ($30) {
        $31 = (($26) + 1|0);
        $32 = $28&255;
        $33 = $32 >>> 1;
        $42 = $33;$51 = $31;
       } else {
        $34 = ((($27) + (($i1$068*12)|0)|0) + 8|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = ((($27) + (($i1$068*12)|0)|0) + 4|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = ($37>>>0)>(4294967279);
        if ($38) {
         label = 11;
         break;
        } else {
         $42 = $37;$51 = $35;
        }
       }
       $41 = ($42>>>0)<(11);
       if ($41) {
        $43 = $42 << 1;
        $44 = $43&255;
        HEAP8[$7>>0] = $44;
        $__p$0$i$i$i$i = $23;
       } else {
        $45 = (($42) + 16)|0;
        $46 = $45 & -16;
        __THREW__ = 0;
        $47 = (invoke_ii(2988,($46|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 2;
         break;
        }
        HEAP32[$24>>2] = $47;
        $50 = $46 | 1;
        HEAP32[$7>>2] = $50;
        HEAP32[$25>>2] = $42;
        $__p$0$i$i$i$i = $47;
       }
       _memcpy(($__p$0$i$i$i$i|0),($51|0),($42|0))|0;
       $52 = (($__p$0$i$i$i$i) + ($42)|0);
       HEAP8[$52>>0] = 0;
       $53 = (($i1$068) + 20000)|0;
       __THREW__ = 0;
       invoke_viii(1637,($this|0),($53|0),($7|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 21;
        break;
       }
       $56 = HEAP8[$7>>0]|0;
       $57 = $56 & 1;
       $58 = ($57<<24>>24)==(0);
       if (!($58)) {
        $59 = HEAP32[$24>>2]|0;
        __ZdlPv($59);
       }
       $60 = (($i1$068) + 1)|0;
       $61 = HEAP32[$10>>2]|0;
       $62 = HEAP32[$tags>>2]|0;
       $63 = $61;
       $64 = $62;
       $65 = (($63) - ($64))|0;
       $66 = (($65|0) / 12)&-1;
       $67 = ($60>>>0)<($66>>>0);
       if ($67) {
        $27 = $62;$i1$068 = $60;
       } else {
        break L4;
       }
      }
      if ((label|0) == 2) {
       $14 = ___cxa_find_matching_catch()|0;
       $15 = tempRet0;
       $lpad$phi67$index = $14;$lpad$phi67$index2 = $15;
       label = 4;
       break L1;
      }
      else if ((label|0) == 11) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        label = 3;
        break L1;
       }
       // unreachable;
      }
      else if ((label|0) == 21) {
       $68 = ___cxa_find_matching_catch()|0;
       $69 = tempRet0;
       $70 = HEAP8[$7>>0]|0;
       $71 = $70 & 1;
       $72 = ($71<<24>>24)==(0);
       if ($72) {
        $$2 = $68;$$23 = $69;
        break L1;
       }
       $73 = HEAP32[$24>>2]|0;
       __ZdlPv($73);
       $$2 = $68;$$23 = $69;
       break L1;
      }
     }
    } while(0);
    HEAP32[$layers>>2] = 0;
    $74 = (($layers) + 4|0);
    HEAP32[$74>>2] = 0;
    $75 = (($layers) + 8|0);
    HEAP32[$75>>2] = 0;
    $76 = (($8) + 1|0);
    $77 = (($8) + 8|0);
    $78 = (($8) + 4|0);
    $i3$062 = 0;
    while(1) {
     $79 = ((($this) + (($i3$062*12)|0)|0) + 40|0);
     $80 = HEAP8[$79>>0]|0;
     $81 = $80 & 1;
     $82 = ($81<<24>>24)==(0);
     if ($82) {
      $87 = (($79) + 1|0);
      $88 = $80&255;
      $89 = $88 >>> 1;
      $104 = $87;$91 = $89;
     } else {
      $83 = ((($this) + (($i3$062*12)|0)|0) + 48|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = ((($this) + (($i3$062*12)|0)|0) + 44|0);
      $86 = HEAP32[$85>>2]|0;
      $104 = $84;$91 = $86;
     }
     $90 = ($91>>>0)>(2147483631);
     if ($90) {
      label = 28;
      break;
     }
     $94 = ($91>>>0)<(11);
     if ($94) {
      $95 = $91 << 1;
      $96 = $95&255;
      HEAP8[$8>>0] = $96;
      $111 = $96;$__p$0$i$i$i$i16 = $76;
     } else {
      $97 = (($91) + 16)|0;
      $98 = $97 & -16;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$5+0>>2]|0;
      $99 = (invoke_iiiiiii(102,($98|0),16,($$byval_copy24|0),0,(567120|0),79)|0);
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       label = 55;
       break;
      }
      HEAP32[$77>>2] = $99;
      $102 = $98 | 1;
      HEAP32[$8>>2] = $102;
      HEAP32[$78>>2] = $91;
      $103 = $102&255;
      $111 = $103;$__p$0$i$i$i$i16 = $99;
     }
     _memcpy(($__p$0$i$i$i$i16|0),($104|0),($91|0))|0;
     $105 = (($__p$0$i$i$i$i16) + ($91)|0);
     HEAP8[$105>>0] = 0;
     $106 = HEAP32[$74>>2]|0;
     $107 = HEAP32[$75>>2]|0;
     $108 = ($106|0)==($107|0);
     if ($108) {
      __THREW__ = 0;
      invoke_vii(2602,($layers|0),($8|0));
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       label = 58;
       break;
      }
      $$pre72 = HEAP8[$8>>0]|0;
      $140 = $$pre72;
     } else {
      $109 = ($106|0)==(0|0);
      if ($109) {
       $136 = 0;
      } else {
       $110 = $111 & 1;
       $112 = ($110<<24>>24)==(0);
       if ($112) {
        $115 = $111&255;
        $116 = $115 >>> 1;
        $118 = $116;$133 = $76;
       } else {
        $113 = HEAP32[$77>>2]|0;
        $114 = HEAP32[$78>>2]|0;
        $118 = $114;$133 = $113;
       }
       $117 = ($118>>>0)>(2147483631);
       if ($117) {
        label = 40;
        break;
       }
       $121 = ($118>>>0)<(11);
       if ($121) {
        $122 = $118 << 1;
        $123 = $122&255;
        HEAP8[$106>>0] = $123;
        $124 = (($106) + 1|0);
        $__p$0$i$i$i$i$i$i = $124;
       } else {
        $125 = (($118) + 16)|0;
        $126 = $125 & -16;
        HEAP32[$4>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$4+0>>2]|0;
        $127 = (invoke_iiiiiii(102,($126|0),16,($$byval_copy24|0),0,(567120|0),79)|0);
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if ($129) {
         label = 58;
         break;
        }
        $130 = (($106) + 8|0);
        HEAP32[$130>>2] = $127;
        $131 = $126 | 1;
        HEAP32[$106>>2] = $131;
        $132 = (($106) + 4|0);
        HEAP32[$132>>2] = $118;
        $__p$0$i$i$i$i$i$i = $127;
       }
       _memcpy(($__p$0$i$i$i$i$i$i|0),($133|0),($118|0))|0;
       $134 = (($__p$0$i$i$i$i$i$i) + ($118)|0);
       HEAP8[$134>>0] = 0;
       $$pre$i = HEAP32[$74>>2]|0;
       $136 = $$pre$i;
      }
      $135 = (($136) + 12|0);
      HEAP32[$74>>2] = $135;
      $140 = $111;
     }
     $139 = $140 & 1;
     $141 = ($139<<24>>24)==(0);
     if (!($141)) {
      $142 = HEAP32[$77>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($142|0),($$byval_copy24|0));
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       label = 52;
       break;
      }
     }
     $147 = (($i3$062) + 1)|0;
     $148 = ($147|0)<(32);
     if ($148) {
      $i3$062 = $147;
     } else {
      label = 63;
      break;
     }
    }
    do {
     if ((label|0) == 28) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       label = 56;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 40) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       $157 = ___cxa_find_matching_catch()|0;
       $158 = tempRet0;
       $160 = $111;$lpad$phi61$index = $157;$lpad$phi61$index14 = $158;
       label = 60;
       break;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 52) {
      $145 = ___cxa_find_matching_catch()|0;
      $146 = tempRet0;
      ___cxa_call_unexpected(($145|0));
      // unreachable;
     }
     else if ((label|0) == 55) {
      $151 = ___cxa_find_matching_catch()|0;
      $152 = tempRet0;
      $lpad$phi$index = $151;$lpad$phi$index8 = $152;
      label = 57;
     }
     else if ((label|0) == 58) {
      $155 = ___cxa_find_matching_catch()|0;
      $156 = tempRet0;
      $$pre = HEAP8[$8>>0]|0;
      $160 = $$pre;$lpad$phi61$index = $155;$lpad$phi61$index14 = $156;
      label = 60;
     }
     else if ((label|0) == 63) {
      __THREW__ = 0;
      invoke_viii(1649,($transfer|0),($layers|0),0);
      $167 = __THREW__; __THREW__ = 0;
      $168 = $167&1;
      if ($168) {
       label = 56;
      } else {
       $169 = HEAP32[$layers>>2]|0;
       $170 = (($9) + 1|0);
       $171 = (($9) + 8|0);
       $172 = (($9) + 4|0);
       $174 = $169;$i4$054 = 8;
       while(1) {
        $173 = (($174) + (($i4$054*12)|0)|0);
        $175 = HEAP8[$173>>0]|0;
        $176 = $175 & 1;
        $177 = ($176<<24>>24)==(0);
        if ($177) {
         $178 = (($173) + 1|0);
         $179 = $175&255;
         $180 = $179 >>> 1;
         $189 = $180;$198 = $178;
        } else {
         $181 = ((($174) + (($i4$054*12)|0)|0) + 8|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = ((($174) + (($i4$054*12)|0)|0) + 4|0);
         $184 = HEAP32[$183>>2]|0;
         $185 = ($184>>>0)>(4294967279);
         if ($185) {
          label = 68;
          break;
         } else {
          $189 = $184;$198 = $182;
         }
        }
        $188 = ($189>>>0)<(11);
        if ($188) {
         $190 = $189 << 1;
         $191 = $190&255;
         HEAP8[$9>>0] = $191;
         $__p$0$i$i$i$i28 = $170;
        } else {
         $192 = (($189) + 16)|0;
         $193 = $192 & -16;
         __THREW__ = 0;
         $194 = (invoke_ii(2988,($193|0))|0);
         $195 = __THREW__; __THREW__ = 0;
         $196 = $195&1;
         if ($196) {
          label = 54;
          break;
         }
         HEAP32[$171>>2] = $194;
         $197 = $193 | 1;
         HEAP32[$9>>2] = $197;
         HEAP32[$172>>2] = $189;
         $__p$0$i$i$i$i28 = $194;
        }
        _memcpy(($__p$0$i$i$i$i28|0),($198|0),($189|0))|0;
        $199 = (($__p$0$i$i$i$i28) + ($189)|0);
        HEAP8[$199>>0] = 0;
        __THREW__ = 0;
        invoke_viii(1638,($this|0),($i4$054|0),($9|0));
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         label = 78;
         break;
        }
        $202 = HEAP8[$9>>0]|0;
        $203 = $202 & 1;
        $204 = ($203<<24>>24)==(0);
        if (!($204)) {
         $205 = HEAP32[$171>>2]|0;
         __ZdlPv($205);
        }
        $206 = (($i4$054) + 1)|0;
        $207 = ($206|0)<(32);
        $208 = HEAP32[$layers>>2]|0;
        if ($207) {
         $174 = $208;$i4$054 = $206;
        } else {
         label = 80;
         break;
        }
       }
       if ((label|0) == 54) {
        $149 = ___cxa_find_matching_catch()|0;
        $150 = tempRet0;
        $lpad$phi$index = $149;$lpad$phi$index8 = $150;
        label = 57;
        break;
       }
       else if ((label|0) == 68) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $186 = __THREW__; __THREW__ = 0;
        $187 = $186&1;
        if ($187) {
         label = 56;
         break;
        }
        // unreachable;
       }
       else if ((label|0) == 78) {
        $209 = ___cxa_find_matching_catch()|0;
        $210 = tempRet0;
        $211 = HEAP8[$9>>0]|0;
        $212 = $211 & 1;
        $213 = ($212<<24>>24)==(0);
        if ($213) {
         $$1 = $209;$$12 = $210;
         break;
        }
        $214 = HEAP32[$171>>2]|0;
        __ZdlPv($214);
        $$1 = $209;$$12 = $210;
        break;
       }
       else if ((label|0) == 80) {
        $215 = ($208|0)==(0|0);
        if (!($215)) {
         $216 = HEAP32[$74>>2]|0;
         $217 = ($216|0)==($208|0);
         do {
          if ($217) {
           $231 = $208;
          } else {
           $219 = $216;
           while(1) {
            $218 = (($219) + -12|0);
            HEAP32[$74>>2] = $218;
            $220 = HEAP8[$218>>0]|0;
            $221 = $220 & 1;
            $222 = ($221<<24>>24)==(0);
            if ($222) {
             $224 = $218;
            } else {
             $225 = (($219) + -4|0);
             $226 = HEAP32[$225>>2]|0;
             HEAP32[$1>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;
             invoke_vii(2591,($226|0),($$byval_copy24|0));
             $227 = __THREW__; __THREW__ = 0;
             $228 = $227&1;
             if ($228) {
              label = 87;
              break;
             }
             $$pre$i$i$i$i$i36 = HEAP32[$74>>2]|0;
             $224 = $$pre$i$i$i$i$i36;
            }
            $223 = ($224|0)==($208|0);
            if ($223) {
             label = 88;
             break;
            } else {
             $219 = $224;
            }
           }
           if ((label|0) == 87) {
            $229 = ___cxa_find_matching_catch()|0;
            $230 = tempRet0;
            ___cxa_call_unexpected(($229|0));
            // unreachable;
           }
           else if ((label|0) == 88) {
            $$pre$i$i$i38 = HEAP32[$layers>>2]|0;
            $231 = $$pre$i$i$i38;
            break;
           }
          }
         } while(0);
         __ZdlPv($231);
        }
        $250 = (($this) + 424|0);
        __THREW__ = 0;
        invoke_viii(1650,($transfer|0),($250|0),0);
        $251 = __THREW__; __THREW__ = 0;
        $252 = $251&1;
        if ($252) {
         label = 3;
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3388,($this|0));
        $253 = __THREW__; __THREW__ = 0;
        $254 = $253&1;
        if ($254) {
         label = 3;
         break L1;
        }
        $255 = (($this) + 436|0);
        HEAP32[$255>>2] = 0;
        $256 = (($this) + 428|0);
        $257 = HEAP32[$256>>2]|0;
        $258 = (($this) + 424|0);
        $259 = HEAP32[$258>>2]|0;
        $260 = $257;
        $261 = $259;
        $262 = (($260) - ($261))|0;
        $263 = (($262|0) / 20)&-1;
        $264 = ($257|0)==($259|0);
        L108: do {
         if (!($264)) {
          $i$02$i = 0;
          while(1) {
           $267 = ((($259) + (($i$02$i*20)|0)|0) + 12|0);
           $268 = HEAP32[$267>>2]|0;
           $269 = ($268|0)==(0);
           $266 = (($i$02$i) + 1)|0;
           if ($269) {
            break;
           }
           $265 = ($266|0)==($263|0);
           if ($265) {
            break L108;
           } else {
            $i$02$i = $266;
           }
          }
          HEAP32[$255>>2] = $i$02$i;
         }
        } while(0);
        $270 = HEAP32[$tags>>2]|0;
        $271 = ($270|0)==(0|0);
        if ($271) {
         STACKTOP = sp;return;
        }
        $272 = HEAP32[$10>>2]|0;
        $273 = ($272|0)==($270|0);
        do {
         if ($273) {
          $287 = $270;
         } else {
          $275 = $272;
          while(1) {
           $274 = (($275) + -12|0);
           HEAP32[$10>>2] = $274;
           $276 = HEAP8[$274>>0]|0;
           $277 = $276 & 1;
           $278 = ($277<<24>>24)==(0);
           if ($278) {
            $280 = $274;
           } else {
            $281 = (($275) + -4|0);
            $282 = HEAP32[$281>>2]|0;
            HEAP32[$0>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
            invoke_vii(2591,($282|0),($$byval_copy24|0));
            $283 = __THREW__; __THREW__ = 0;
            $284 = $283&1;
            if ($284) {
             label = 113;
             break;
            }
            $$pre$i$i$i$i$i6 = HEAP32[$10>>2]|0;
            $280 = $$pre$i$i$i$i$i6;
           }
           $279 = ($280|0)==($270|0);
           if ($279) {
            label = 114;
            break;
           } else {
            $275 = $280;
           }
          }
          if ((label|0) == 113) {
           $285 = ___cxa_find_matching_catch()|0;
           $286 = tempRet0;
           ___cxa_call_unexpected(($285|0));
           // unreachable;
          }
          else if ((label|0) == 114) {
           $$pre$i$i$i8 = HEAP32[$tags>>2]|0;
           $287 = $$pre$i$i$i8;
           break;
          }
         }
        } while(0);
        __ZdlPv($287);
        STACKTOP = sp;return;
       }
      }
     }
    } while(0);
    if ((label|0) == 56) {
     $153 = ___cxa_find_matching_catch()|0;
     $154 = tempRet0;
     $lpad$phi$index = $153;$lpad$phi$index8 = $154;
     label = 57;
    }
    else if ((label|0) == 60) {
     $159 = $160 & 1;
     $161 = ($159<<24>>24)==(0);
     if ($161) {
      $$1 = $lpad$phi61$index;$$12 = $lpad$phi61$index14;
     } else {
      $162 = HEAP32[$77>>2]|0;
      HEAP32[$2>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($162|0),($$byval_copy24|0));
      $163 = __THREW__; __THREW__ = 0;
      $164 = $163&1;
      if ($164) {
       $165 = ___cxa_find_matching_catch()|0;
       $166 = tempRet0;
       ___cxa_call_unexpected(($165|0));
       // unreachable;
      } else {
       $$1 = $lpad$phi61$index;$$12 = $lpad$phi61$index14;
      }
     }
    }
    if ((label|0) == 57) {
     $$1 = $lpad$phi$index;$$12 = $lpad$phi$index8;
    }
    $232 = HEAP32[$layers>>2]|0;
    $233 = ($232|0)==(0|0);
    if ($233) {
     $$2 = $$1;$$23 = $$12;
    } else {
     $234 = HEAP32[$74>>2]|0;
     $235 = ($234|0)==($232|0);
     do {
      if ($235) {
       $249 = $232;
      } else {
       $237 = $234;
       while(1) {
        $236 = (($237) + -12|0);
        HEAP32[$74>>2] = $236;
        $238 = HEAP8[$236>>0]|0;
        $239 = $238 & 1;
        $240 = ($239<<24>>24)==(0);
        if ($240) {
         $242 = $236;
        } else {
         $243 = (($237) + -4|0);
         $244 = HEAP32[$243>>2]|0;
         HEAP32[$0>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($244|0),($$byval_copy24|0));
         $245 = __THREW__; __THREW__ = 0;
         $246 = $245&1;
         if ($246) {
          label = 97;
          break;
         }
         $$pre$i$i$i$i$i44 = HEAP32[$74>>2]|0;
         $242 = $$pre$i$i$i$i$i44;
        }
        $241 = ($242|0)==($232|0);
        if ($241) {
         label = 98;
         break;
        } else {
         $237 = $242;
        }
       }
       if ((label|0) == 97) {
        $247 = ___cxa_find_matching_catch()|0;
        $248 = tempRet0;
        ___cxa_call_unexpected(($247|0));
        // unreachable;
       }
       else if ((label|0) == 98) {
        $$pre$i$i$i46 = HEAP32[$layers>>2]|0;
        $249 = $$pre$i$i$i46;
        break;
       }
      }
     } while(0);
     __ZdlPv($249);
     $$2 = $$1;$$23 = $$12;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $lpad$phi67$index = $16;$lpad$phi67$index2 = $17;
  label = 4;
 }
 if ((label|0) == 4) {
  $$2 = $lpad$phi67$index;$$23 = $lpad$phi67$index2;
 }
 $288 = HEAP32[$tags>>2]|0;
 $289 = ($288|0)==(0|0);
 if ($289) {
  ___resumeException($$2|0);
  // unreachable;
 }
 $290 = HEAP32[$10>>2]|0;
 $291 = ($290|0)==($288|0);
 do {
  if ($291) {
   $305 = $288;
  } else {
   $293 = $290;
   while(1) {
    $292 = (($293) + -12|0);
    HEAP32[$10>>2] = $292;
    $294 = HEAP8[$292>>0]|0;
    $295 = $294 & 1;
    $296 = ($295<<24>>24)==(0);
    if ($296) {
     $298 = $292;
    } else {
     $299 = (($293) + -4|0);
     $300 = HEAP32[$299>>2]|0;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($300|0),($$byval_copy24|0));
     $301 = __THREW__; __THREW__ = 0;
     $302 = $301&1;
     if ($302) {
      label = 124;
      break;
     }
     $$pre$i$i$i$i$i = HEAP32[$10>>2]|0;
     $298 = $$pre$i$i$i$i$i;
    }
    $297 = ($298|0)==($288|0);
    if ($297) {
     label = 125;
     break;
    } else {
     $293 = $298;
    }
   }
   if ((label|0) == 124) {
    $303 = ___cxa_find_matching_catch()|0;
    $304 = tempRet0;
    ___cxa_call_unexpected(($303|0));
    // unreachable;
   }
   else if ((label|0) == 125) {
    $$pre$i$i$i = HEAP32[$tags>>2]|0;
    $305 = $$pre$i$i$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($305);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SortingLayerEntryNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = ($16*20)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $20 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $20 = $19;
 }
 __Z14resize_trimmedINSt3__16vectorI17SortingLayerEntryNS0_9allocatorIS2_EEEEEvRT_j($data,$20);
 $21 = (($data) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$data>>2]|0;
 $24 = ($23|0)==($22|0);
 if ($24) {
  STACKTOP = sp;return;
 } else {
  $25 = $23;
 }
 while(1) {
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$25,0);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
  $26 = (($25) + 12|0);
  $27 = HEAP32[$1>>2]|0;
  $28 = (($27) + 4|0);
  $29 = HEAP32[$7>>2]|0;
  $30 = ($28>>>0)>($29>>>0);
  if ($30) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  } else {
   $31 = HEAP32[$27>>2]|0;
   HEAP32[$26>>2] = $31;
   HEAP32[$1>>2] = $28;
  }
  __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
  $32 = (($25) + 20|0);
  $33 = ($32|0)==($22|0);
  if ($33) {
   break;
  } else {
   $25 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $17 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $17 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$17,$16)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $28 = $$pre;
 } else {
  $18 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $18;
  HEAP32[$1>>2] = $6;
  $28 = $18;
 }
 $19 = HEAP8[$data>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $24 = $19&255;
  $25 = $24 >>> 1;
  $27 = $25;
 } else {
  $22 = (($data) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $27 = $23;
 }
 $26 = ($27>>>0)<($28>>>0);
 do {
  if ($26) {
   $29 = (($28) - ($27))|0;
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6appendEjc($data,$29,1)|0);
  } else {
   if ($21) {
    $34 = ((($data) + ($28)|0) + 1|0);
    HEAP8[$34>>0] = 0;
    $35 = $28 << 1;
    $36 = $35&255;
    HEAP8[$data>>0] = $36;
    break;
   } else {
    $30 = (($data) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + ($28)|0);
    HEAP8[$32>>0] = 0;
    $33 = (($data) + 4|0);
    HEAP32[$33>>2] = $28;
    break;
   }
  }
 } while(0);
 $37 = HEAP32[$size1>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = HEAP8[$data>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  $44 = (($data) + 1|0);
  $45 = $44;
 } else {
  $42 = (($data) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $45 = $43;
 }
 __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$45,$37);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI8UnityStrNS0_9allocatorIS2_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$25,0);
   __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
   $26 = (($25) + 12|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10TagManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy34 = 0, $$not = 0, $$not4 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i59 = 0, $$pre$i$i$i$i$i67 = 0, $$pre$i$i$i$i$i80 = 0, $$pre$i$i$i61 = 0, $$pre$i$i$i69 = 0, $$pre$i$i$i82 = 0, $$pre117 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i22 = 0, $__p$0$i$i$i$i34 = 0, $__p$0$i$i$i$i51 = 0, $bitnames = 0, $brmerge = 0, $converter$i$i = 0, $converter$i$i14 = 0, $converter$i$i42 = 0, $i$02$i = 0, $i1$0113 = 0, $i2$088 = 0, $i3$0105 = 0, $i4$096 = 0, $layers = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0;
 var $lpad$phi104$index = 0, $lpad$phi104$index19 = 0, $lpad$phi112$index = 0, $lpad$phi112$index2 = 0, $lpad$phi95$index = 0, $lpad$phi95$index13 = 0, $name = 0, $phitmp$i$i = 0, $tags = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $$byval_copy34 = sp;
 $0 = sp + 504|0;
 $1 = sp + 500|0;
 $2 = sp + 496|0;
 $converter$i$i42 = sp + 492|0;
 $3 = sp + 488|0;
 $4 = sp + 484|0;
 $5 = sp + 480|0;
 $6 = sp + 476|0;
 $7 = sp + 472|0;
 $8 = sp + 36|0;
 $converter$i$i14 = sp + 508|0;
 $converter$i$i = sp + 4|0;
 $9 = sp + 8|0;
 $tags = sp + 12|0;
 $10 = sp + 460|0;
 $bitnames = sp + 40|0;
 $name = sp + 512|0;
 $11 = sp + 424|0;
 $layers = sp + 436|0;
 $12 = sp + 448|0;
 $13 = sp + 24|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 HEAP32[$tags>>2] = 0;
 $14 = (($tags) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = (($tags) + 8|0);
 HEAP32[$15>>2] = 0;
 __THREW__ = 0;
 invoke_vi(3387,($this|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 L1: do {
  if ($17) {
   label = 3;
  } else {
   $22 = HEAP32[580760>>2]|0;
   __THREW__ = 0;
   $23 = (invoke_iiiiii(192,($transfer|0),(567472|0),($22|0),($converter$i$i|0),1)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 3;
   } else {
    $26 = ($23|0)==(0);
    if (!($26)) {
     $27 = ($23|0)>(0);
     if ($27) {
      __THREW__ = 0;
      invoke_viii(1651,($transfer|0),($tags|0),0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 3;
       break;
      }
     } else {
      $30 = HEAP32[$converter$i$i>>2]|0;
      $31 = ($30|0)==(0|0);
      if (!($31)) {
       __THREW__ = 0;
       (invoke_iii($30|0,($tags|0),($transfer|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        label = 3;
        break;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3389,($transfer|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 3;
      break;
     }
    }
    $36 = (($transfer) + 136|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = ($37<<24>>24)==(0);
    L12: do {
     if (!($38)) {
      $39 = HEAP32[$14>>2]|0;
      $40 = HEAP32[$tags>>2]|0;
      $41 = ($39|0)==($40|0);
      if (!($41)) {
       $42 = (($10) + 1|0);
       $43 = (($10) + 8|0);
       $44 = (($10) + 4|0);
       $46 = $40;$i1$0113 = 0;
       while(1) {
        $45 = (($46) + (($i1$0113*12)|0)|0);
        $47 = HEAP8[$45>>0]|0;
        $48 = $47 & 1;
        $49 = ($48<<24>>24)==(0);
        if ($49) {
         $50 = (($45) + 1|0);
         $51 = $47&255;
         $52 = $51 >>> 1;
         $61 = $52;$70 = $50;
        } else {
         $53 = ((($46) + (($i1$0113*12)|0)|0) + 8|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = ((($46) + (($i1$0113*12)|0)|0) + 4|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($56>>>0)>(4294967279);
         if ($57) {
          label = 18;
          break;
         } else {
          $61 = $56;$70 = $54;
         }
        }
        $60 = ($61>>>0)<(11);
        if ($60) {
         $62 = $61 << 1;
         $63 = $62&255;
         HEAP8[$10>>0] = $63;
         $__p$0$i$i$i$i = $42;
        } else {
         $64 = (($61) + 16)|0;
         $65 = $64 & -16;
         __THREW__ = 0;
         $66 = (invoke_ii(2988,($65|0))|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          label = 2;
          break;
         }
         HEAP32[$43>>2] = $66;
         $69 = $65 | 1;
         HEAP32[$10>>2] = $69;
         HEAP32[$44>>2] = $61;
         $__p$0$i$i$i$i = $66;
        }
        _memcpy(($__p$0$i$i$i$i|0),($70|0),($61|0))|0;
        $71 = (($__p$0$i$i$i$i) + ($61)|0);
        HEAP8[$71>>0] = 0;
        $72 = (($i1$0113) + 20000)|0;
        __THREW__ = 0;
        invoke_viii(1637,($this|0),($72|0),($10|0));
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 28;
         break;
        }
        $75 = HEAP8[$10>>0]|0;
        $76 = $75 & 1;
        $77 = ($76<<24>>24)==(0);
        if (!($77)) {
         $78 = HEAP32[$43>>2]|0;
         __ZdlPv($78);
        }
        $79 = (($i1$0113) + 1)|0;
        $80 = HEAP32[$14>>2]|0;
        $81 = HEAP32[$tags>>2]|0;
        $82 = $80;
        $83 = $81;
        $84 = (($82) - ($83))|0;
        $85 = (($84|0) / 12)&-1;
        $86 = ($79>>>0)<($85>>>0);
        if ($86) {
         $46 = $81;$i1$0113 = $79;
        } else {
         break L12;
        }
       }
       if ((label|0) == 2) {
        $18 = ___cxa_find_matching_catch()|0;
        $19 = tempRet0;
        $lpad$phi112$index = $18;$lpad$phi112$index2 = $19;
        label = 4;
        break L1;
       }
       else if ((label|0) == 18) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 3;
         break L1;
        }
        // unreachable;
       }
       else if ((label|0) == 28) {
        $87 = ___cxa_find_matching_catch()|0;
        $88 = tempRet0;
        $89 = HEAP8[$10>>0]|0;
        $90 = $89 & 1;
        $91 = ($90<<24>>24)==(0);
        if ($91) {
         $$2 = $87;$$23 = $88;
         break L1;
        }
        $92 = HEAP32[$43>>2]|0;
        __ZdlPv($92);
        $$2 = $87;$$23 = $88;
        break L1;
       }
      }
     }
    } while(0);
    __THREW__ = 0;
    $93 = (invoke_iii(2361,($transfer|0),1)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 3;
    } else {
     L38: do {
      if ($93) {
       $96 = (($bitnames) + 384|0);
       _memset(($bitnames|0),0,384)|0;
       $97 = HEAP32[580712>>2]|0;
       $98 = (($11) + 1|0);
       $99 = (($11) + 8|0);
       $100 = (($11) + 4|0);
       $i2$088 = 0;
       L40: while(1) {
        $101 = ($i2$088|0)>(7);
        if ($101) {
         HEAP32[$$byval_copy34>>2] = $i2$088;
         (_snprintf($name,64,567480,$$byval_copy34)|0);
        } else {
         HEAP32[$$byval_copy34>>2] = $i2$088;
         (_snprintf($name,64,567496,$$byval_copy34)|0);
        }
        $106 = (($bitnames) + (($i2$088*12)|0)|0);
        $107 = ((($this) + (($i2$088*12)|0)|0) + 40|0);
        $108 = HEAP8[$107>>0]|0;
        $109 = $108 & 1;
        $110 = ($109<<24>>24)==(0);
        if ($110) {
         $115 = (($107) + 1|0);
         $116 = $108&255;
         $117 = $116 >>> 1;
         $126 = $117;$134 = $115;
        } else {
         $111 = ((($this) + (($i2$088*12)|0)|0) + 48|0);
         $112 = HEAP32[$111>>2]|0;
         $113 = ((($this) + (($i2$088*12)|0)|0) + 44|0);
         $114 = HEAP32[$113>>2]|0;
         $126 = $114;$134 = $112;
        }
        $118 = HEAP8[$106>>0]|0;
        $119 = $118 & 1;
        $120 = ($119<<24>>24)==(0);
        if ($120) {
         $125 = 10;$128 = $118;
        } else {
         $121 = HEAP32[$106>>2]|0;
         $122 = $121 & -2;
         $phitmp$i$i = (($122) + -1)|0;
         $123 = $121&255;
         $125 = $phitmp$i$i;$128 = $123;
        }
        $124 = ($125>>>0)<($126>>>0);
        $127 = $128 & 1;
        $129 = ($127<<24>>24)==(0);
        do {
         if ($124) {
          if ($129) {
           $144 = $128&255;
           $145 = $144 >>> 1;
           $147 = $145;
          } else {
           $142 = ((($bitnames) + (($i2$088*12)|0)|0) + 4|0);
           $143 = HEAP32[$142>>2]|0;
           $147 = $143;
          }
          $146 = (($126) - ($125))|0;
          __THREW__ = 0;
          invoke_viiiiiiii(22,($106|0),($125|0),($146|0),($147|0),0,($147|0),($126|0),($134|0));
          $148 = __THREW__; __THREW__ = 0;
          $149 = $148&1;
          if ($149) {
           label = 36;
           break L40;
          }
         } else {
          if ($129) {
           $132 = (($106) + 1|0);
           $133 = $132;
          } else {
           $130 = ((($bitnames) + (($i2$088*12)|0)|0) + 8|0);
           $131 = HEAP32[$130>>2]|0;
           $133 = $131;
          }
          _memmove(($133|0),($134|0),($126|0))|0;
          $135 = (($133) + ($126)|0);
          HEAP8[$135>>0] = 0;
          $136 = HEAP8[$106>>0]|0;
          $137 = $136 & 1;
          $138 = ($137<<24>>24)==(0);
          if ($138) {
           $140 = $126 << 1;
           $141 = $140&255;
           HEAP8[$106>>0] = $141;
           break;
          } else {
           $139 = ((($bitnames) + (($i2$088*12)|0)|0) + 4|0);
           HEAP32[$139>>2] = $126;
           break;
          }
         }
        } while(0);
        __THREW__ = 0;
        $150 = (invoke_iiiiii(192,($transfer|0),($name|0),($97|0),($converter$i$i14|0),0)|0);
        $151 = __THREW__; __THREW__ = 0;
        $152 = $151&1;
        if ($152) {
         label = 36;
         break;
        }
        $153 = ($150|0)==(0);
        if (!($153)) {
         $154 = ($150|0)>(0);
         if ($154) {
          __THREW__ = 0;
          invoke_viii(1652,($transfer|0),($106|0),0);
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           label = 36;
           break;
          }
         } else {
          $157 = HEAP32[$converter$i$i14>>2]|0;
          $158 = ($157|0)==(0|0);
          if (!($158)) {
           __THREW__ = 0;
           (invoke_iii($157|0,($106|0),($transfer|0))|0);
           $159 = __THREW__; __THREW__ = 0;
           $160 = $159&1;
           if ($160) {
            label = 36;
            break;
           }
          }
         }
         __THREW__ = 0;
         invoke_vi(3389,($transfer|0));
         $161 = __THREW__; __THREW__ = 0;
         $162 = $161&1;
         if ($162) {
          label = 36;
          break;
         }
        }
        $163 = HEAP8[$36>>0]|0;
        $$not = ($163<<24>>24)==(0);
        $$not4 = $101 ^ 1;
        $brmerge = $$not | $$not4;
        do {
         if (!($brmerge)) {
          $164 = HEAP8[$106>>0]|0;
          $165 = $164 & 1;
          $166 = ($165<<24>>24)==(0);
          if ($166) {
           $167 = (($106) + 1|0);
           $168 = $164&255;
           $169 = $168 >>> 1;
           $178 = $169;$187 = $167;
          } else {
           $170 = ((($bitnames) + (($i2$088*12)|0)|0) + 8|0);
           $171 = HEAP32[$170>>2]|0;
           $172 = ((($bitnames) + (($i2$088*12)|0)|0) + 4|0);
           $173 = HEAP32[$172>>2]|0;
           $174 = ($173>>>0)>(4294967279);
           if ($174) {
            label = 67;
            break L40;
           } else {
            $178 = $173;$187 = $171;
           }
          }
          $177 = ($178>>>0)<(11);
          if ($177) {
           $179 = $178 << 1;
           $180 = $179&255;
           HEAP8[$11>>0] = $180;
           $__p$0$i$i$i$i22 = $98;
          } else {
           $181 = (($178) + 16)|0;
           $182 = $181 & -16;
           __THREW__ = 0;
           $183 = (invoke_ii(2988,($182|0))|0);
           $184 = __THREW__; __THREW__ = 0;
           $185 = $184&1;
           if ($185) {
            label = 36;
            break L40;
           }
           HEAP32[$99>>2] = $183;
           $186 = $182 | 1;
           HEAP32[$11>>2] = $186;
           HEAP32[$100>>2] = $178;
           $__p$0$i$i$i$i22 = $183;
          }
          _memcpy(($__p$0$i$i$i$i22|0),($187|0),($178|0))|0;
          $188 = (($__p$0$i$i$i$i22) + ($178)|0);
          HEAP8[$188>>0] = 0;
          __THREW__ = 0;
          invoke_viii(1638,($this|0),($i2$088|0),($11|0));
          $189 = __THREW__; __THREW__ = 0;
          $190 = $189&1;
          if ($190) {
           label = 76;
           break L40;
          }
          $191 = HEAP8[$11>>0]|0;
          $192 = $191 & 1;
          $193 = ($192<<24>>24)==(0);
          if ($193) {
           break;
          }
          $194 = HEAP32[$99>>2]|0;
          __ZdlPv($194);
         }
        } while(0);
        $201 = (($i2$088) + 1)|0;
        $202 = ($201|0)<(32);
        if ($202) {
         $i2$088 = $201;
        } else {
         label = 33;
         break;
        }
       }
       do {
        if ((label|0) == 33) {
         $204 = $96;
         while(1) {
          $203 = (($204) + -12|0);
          $205 = HEAP8[$203>>0]|0;
          $206 = $205 & 1;
          $207 = ($206<<24>>24)==(0);
          if (!($207)) {
           $208 = (($204) + -4|0);
           $209 = HEAP32[$208>>2]|0;
           HEAP32[$8>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$8+0>>2]|0;
           invoke_vii(2591,($209|0),($$byval_copy34|0));
           $210 = __THREW__; __THREW__ = 0;
           $211 = $210&1;
           if ($211) {
            break;
           }
          }
          $214 = ($203|0)==($bitnames|0);
          if ($214) {
           break L38;
          } else {
           $204 = $203;
          }
         }
         $212 = ___cxa_find_matching_catch()|0;
         $213 = tempRet0;
         ___cxa_call_unexpected(($212|0));
         // unreachable;
        }
        else if ((label|0) == 36) {
         $102 = ___cxa_find_matching_catch()|0;
         $103 = tempRet0;
         $lpad$phi$index = $102;$lpad$phi$index7 = $103;
         label = 38;
        }
        else if ((label|0) == 67) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          $104 = ___cxa_find_matching_catch()|0;
          $105 = tempRet0;
          $lpad$phi$index = $104;$lpad$phi$index7 = $105;
          label = 38;
          break;
         } else {
          // unreachable;
         }
        }
        else if ((label|0) == 76) {
         $195 = ___cxa_find_matching_catch()|0;
         $196 = tempRet0;
         $197 = HEAP8[$11>>0]|0;
         $198 = $197 & 1;
         $199 = ($198<<24>>24)==(0);
         if ($199) {
          $$0 = $195;$$01 = $196;
         } else {
          $200 = HEAP32[$99>>2]|0;
          __ZdlPv($200);
          $$0 = $195;$$01 = $196;
         }
        }
       } while(0);
       if ((label|0) == 38) {
        $$0 = $lpad$phi$index;$$01 = $lpad$phi$index7;
       }
       $216 = $96;
       while(1) {
        $215 = (($216) + -12|0);
        $217 = HEAP8[$215>>0]|0;
        $218 = $217 & 1;
        $219 = ($218<<24>>24)==(0);
        if (!($219)) {
         $220 = (($216) + -4|0);
         $221 = HEAP32[$220>>2]|0;
         HEAP32[$7>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$7+0>>2]|0;
         invoke_vii(2591,($221|0),($$byval_copy34|0));
         $222 = __THREW__; __THREW__ = 0;
         $223 = $222&1;
         if ($223) {
          break;
         }
        }
        $226 = ($215|0)==($bitnames|0);
        if ($226) {
         $$2 = $$0;$$23 = $$01;
         break L1;
        } else {
         $216 = $215;
        }
       }
       $224 = ___cxa_find_matching_catch()|0;
       $225 = tempRet0;
       ___cxa_call_unexpected(($224|0));
       // unreachable;
      } else {
       HEAP32[$layers>>2] = 0;
       $227 = (($layers) + 4|0);
       HEAP32[$227>>2] = 0;
       $228 = (($layers) + 8|0);
       HEAP32[$228>>2] = 0;
       $229 = (($12) + 1|0);
       $230 = (($12) + 8|0);
       $231 = (($12) + 4|0);
       $i3$0105 = 0;
       while(1) {
        $232 = ((($this) + (($i3$0105*12)|0)|0) + 40|0);
        $233 = HEAP8[$232>>0]|0;
        $234 = $233 & 1;
        $235 = ($234<<24>>24)==(0);
        if ($235) {
         $240 = (($232) + 1|0);
         $241 = $233&255;
         $242 = $241 >>> 1;
         $244 = $242;$257 = $240;
        } else {
         $236 = ((($this) + (($i3$0105*12)|0)|0) + 48|0);
         $237 = HEAP32[$236>>2]|0;
         $238 = ((($this) + (($i3$0105*12)|0)|0) + 44|0);
         $239 = HEAP32[$238>>2]|0;
         $244 = $239;$257 = $237;
        }
        $243 = ($244>>>0)>(2147483631);
        if ($243) {
         label = 93;
         break;
        }
        $247 = ($244>>>0)<(11);
        if ($247) {
         $248 = $244 << 1;
         $249 = $248&255;
         HEAP8[$12>>0] = $249;
         $264 = $249;$__p$0$i$i$i$i34 = $229;
        } else {
         $250 = (($244) + 16)|0;
         $251 = $250 & -16;
         HEAP32[$6>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$6+0>>2]|0;
         $252 = (invoke_iiiiiii(102,($251|0),16,($$byval_copy34|0),0,(567120|0),79)|0);
         $253 = __THREW__; __THREW__ = 0;
         $254 = $253&1;
         if ($254) {
          label = 120;
          break;
         }
         HEAP32[$230>>2] = $252;
         $255 = $251 | 1;
         HEAP32[$12>>2] = $255;
         HEAP32[$231>>2] = $244;
         $256 = $255&255;
         $264 = $256;$__p$0$i$i$i$i34 = $252;
        }
        _memcpy(($__p$0$i$i$i$i34|0),($257|0),($244|0))|0;
        $258 = (($__p$0$i$i$i$i34) + ($244)|0);
        HEAP8[$258>>0] = 0;
        $259 = HEAP32[$227>>2]|0;
        $260 = HEAP32[$228>>2]|0;
        $261 = ($259|0)==($260|0);
        if ($261) {
         __THREW__ = 0;
         invoke_vii(2602,($layers|0),($12|0));
         $290 = __THREW__; __THREW__ = 0;
         $291 = $290&1;
         if ($291) {
          label = 123;
          break;
         }
         $$pre117 = HEAP8[$12>>0]|0;
         $293 = $$pre117;
        } else {
         $262 = ($259|0)==(0|0);
         if ($262) {
          $289 = 0;
         } else {
          $263 = $264 & 1;
          $265 = ($263<<24>>24)==(0);
          if ($265) {
           $268 = $264&255;
           $269 = $268 >>> 1;
           $271 = $269;$286 = $229;
          } else {
           $266 = HEAP32[$230>>2]|0;
           $267 = HEAP32[$231>>2]|0;
           $271 = $267;$286 = $266;
          }
          $270 = ($271>>>0)>(2147483631);
          if ($270) {
           label = 105;
           break;
          }
          $274 = ($271>>>0)<(11);
          if ($274) {
           $275 = $271 << 1;
           $276 = $275&255;
           HEAP8[$259>>0] = $276;
           $277 = (($259) + 1|0);
           $__p$0$i$i$i$i$i$i = $277;
          } else {
           $278 = (($271) + 16)|0;
           $279 = $278 & -16;
           HEAP32[$5>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$5+0>>2]|0;
           $280 = (invoke_iiiiiii(102,($279|0),16,($$byval_copy34|0),0,(567120|0),79)|0);
           $281 = __THREW__; __THREW__ = 0;
           $282 = $281&1;
           if ($282) {
            label = 123;
            break;
           }
           $283 = (($259) + 8|0);
           HEAP32[$283>>2] = $280;
           $284 = $279 | 1;
           HEAP32[$259>>2] = $284;
           $285 = (($259) + 4|0);
           HEAP32[$285>>2] = $271;
           $__p$0$i$i$i$i$i$i = $280;
          }
          _memcpy(($__p$0$i$i$i$i$i$i|0),($286|0),($271|0))|0;
          $287 = (($__p$0$i$i$i$i$i$i) + ($271)|0);
          HEAP8[$287>>0] = 0;
          $$pre$i = HEAP32[$227>>2]|0;
          $289 = $$pre$i;
         }
         $288 = (($289) + 12|0);
         HEAP32[$227>>2] = $288;
         $293 = $264;
        }
        $292 = $293 & 1;
        $294 = ($292<<24>>24)==(0);
        if (!($294)) {
         $295 = HEAP32[$230>>2]|0;
         HEAP32[$4>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$4+0>>2]|0;
         invoke_vii(2591,($295|0),($$byval_copy34|0));
         $296 = __THREW__; __THREW__ = 0;
         $297 = $296&1;
         if ($297) {
          label = 117;
          break;
         }
        }
        $300 = (($i3$0105) + 1)|0;
        $301 = ($300|0)<(32);
        if ($301) {
         $i3$0105 = $300;
        } else {
         label = 128;
         break;
        }
       }
       L149: do {
        if ((label|0) == 93) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $245 = __THREW__; __THREW__ = 0;
         $246 = $245&1;
         if ($246) {
          label = 121;
         } else {
          // unreachable;
         }
        }
        else if ((label|0) == 105) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $272 = __THREW__; __THREW__ = 0;
         $273 = $272&1;
         if ($273) {
          $310 = ___cxa_find_matching_catch()|0;
          $311 = tempRet0;
          $313 = $264;$lpad$phi104$index = $310;$lpad$phi104$index19 = $311;
          label = 125;
          break;
         } else {
          // unreachable;
         }
        }
        else if ((label|0) == 117) {
         $298 = ___cxa_find_matching_catch()|0;
         $299 = tempRet0;
         ___cxa_call_unexpected(($298|0));
         // unreachable;
        }
        else if ((label|0) == 120) {
         $304 = ___cxa_find_matching_catch()|0;
         $305 = tempRet0;
         $lpad$phi95$index = $304;$lpad$phi95$index13 = $305;
         label = 122;
        }
        else if ((label|0) == 123) {
         $308 = ___cxa_find_matching_catch()|0;
         $309 = tempRet0;
         $$pre = HEAP8[$12>>0]|0;
         $313 = $$pre;$lpad$phi104$index = $308;$lpad$phi104$index19 = $309;
         label = 125;
        }
        else if ((label|0) == 128) {
         __THREW__ = 0;
         $320 = (invoke_iiiiii(192,($transfer|0),(567520|0),($22|0),($converter$i$i42|0),1)|0);
         $321 = __THREW__; __THREW__ = 0;
         $322 = $321&1;
         if ($322) {
          label = 121;
         } else {
          $323 = ($320|0)==(0);
          if (!($323)) {
           $324 = ($320|0)>(0);
           if ($324) {
            __THREW__ = 0;
            invoke_viii(1651,($transfer|0),($layers|0),0);
            $325 = __THREW__; __THREW__ = 0;
            $326 = $325&1;
            if ($326) {
             label = 121;
             break;
            }
           } else {
            $327 = HEAP32[$converter$i$i42>>2]|0;
            $328 = ($327|0)==(0|0);
            if (!($328)) {
             __THREW__ = 0;
             (invoke_iii($327|0,($layers|0),($transfer|0))|0);
             $329 = __THREW__; __THREW__ = 0;
             $330 = $329&1;
             if ($330) {
              label = 121;
              break;
             }
            }
           }
           __THREW__ = 0;
           invoke_vi(3389,($transfer|0));
           $331 = __THREW__; __THREW__ = 0;
           $332 = $331&1;
           if ($332) {
            label = 121;
            break;
           }
          }
          $333 = HEAP8[$36>>0]|0;
          $334 = ($333<<24>>24)==(0);
          L169: do {
           if (!($334)) {
            $335 = (($13) + 1|0);
            $336 = (($13) + 8|0);
            $337 = (($13) + 4|0);
            $i4$096 = 8;
            while(1) {
             $338 = HEAP32[$layers>>2]|0;
             $339 = (($338) + (($i4$096*12)|0)|0);
             $340 = HEAP8[$339>>0]|0;
             $341 = $340 & 1;
             $342 = ($341<<24>>24)==(0);
             if ($342) {
              $343 = (($339) + 1|0);
              $344 = $340&255;
              $345 = $344 >>> 1;
              $354 = $345;$363 = $343;
             } else {
              $346 = ((($338) + (($i4$096*12)|0)|0) + 8|0);
              $347 = HEAP32[$346>>2]|0;
              $348 = ((($338) + (($i4$096*12)|0)|0) + 4|0);
              $349 = HEAP32[$348>>2]|0;
              $350 = ($349>>>0)>(4294967279);
              if ($350) {
               label = 140;
               break;
              } else {
               $354 = $349;$363 = $347;
              }
             }
             $353 = ($354>>>0)<(11);
             if ($353) {
              $355 = $354 << 1;
              $356 = $355&255;
              HEAP8[$13>>0] = $356;
              $__p$0$i$i$i$i51 = $335;
             } else {
              $357 = (($354) + 16)|0;
              $358 = $357 & -16;
              __THREW__ = 0;
              $359 = (invoke_ii(2988,($358|0))|0);
              $360 = __THREW__; __THREW__ = 0;
              $361 = $360&1;
              if ($361) {
               label = 119;
               break;
              }
              HEAP32[$336>>2] = $359;
              $362 = $358 | 1;
              HEAP32[$13>>2] = $362;
              HEAP32[$337>>2] = $354;
              $__p$0$i$i$i$i51 = $359;
             }
             _memcpy(($__p$0$i$i$i$i51|0),($363|0),($354|0))|0;
             $364 = (($__p$0$i$i$i$i51) + ($354)|0);
             HEAP8[$364>>0] = 0;
             __THREW__ = 0;
             invoke_viii(1638,($this|0),($i4$096|0),($13|0));
             $365 = __THREW__; __THREW__ = 0;
             $366 = $365&1;
             if ($366) {
              label = 150;
              break;
             }
             $367 = HEAP8[$13>>0]|0;
             $368 = $367 & 1;
             $369 = ($368<<24>>24)==(0);
             if (!($369)) {
              $370 = HEAP32[$336>>2]|0;
              __ZdlPv($370);
             }
             $371 = (($i4$096) + 1)|0;
             $372 = ($371|0)<(32);
             if ($372) {
              $i4$096 = $371;
             } else {
              break L169;
             }
            }
            if ((label|0) == 119) {
             $302 = ___cxa_find_matching_catch()|0;
             $303 = tempRet0;
             $lpad$phi95$index = $302;$lpad$phi95$index13 = $303;
             label = 122;
             break L149;
            }
            else if ((label|0) == 140) {
             __THREW__ = 0;
             invoke_vi(3309,0);
             $351 = __THREW__; __THREW__ = 0;
             $352 = $351&1;
             if ($352) {
              label = 121;
              break L149;
             }
             // unreachable;
            }
            else if ((label|0) == 150) {
             $373 = ___cxa_find_matching_catch()|0;
             $374 = tempRet0;
             $375 = HEAP8[$13>>0]|0;
             $376 = $375 & 1;
             $377 = ($376<<24>>24)==(0);
             if ($377) {
              $$1 = $373;$$12 = $374;
              break L149;
             }
             $378 = HEAP32[$336>>2]|0;
             __ZdlPv($378);
             $$1 = $373;$$12 = $374;
             break L149;
            }
           }
          } while(0);
          $379 = HEAP32[$layers>>2]|0;
          $380 = ($379|0)==(0|0);
          if ($380) {
           break L38;
          }
          $381 = HEAP32[$227>>2]|0;
          $382 = ($381|0)==($379|0);
          do {
           if ($382) {
            $396 = $379;
           } else {
            $384 = $381;
            while(1) {
             $383 = (($384) + -12|0);
             HEAP32[$227>>2] = $383;
             $385 = HEAP8[$383>>0]|0;
             $386 = $385 & 1;
             $387 = ($386<<24>>24)==(0);
             if ($387) {
              $389 = $383;
             } else {
              $390 = (($384) + -4|0);
              $391 = HEAP32[$390>>2]|0;
              HEAP32[$2>>2] = 59;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$2+0>>2]|0;
              invoke_vii(2591,($391|0),($$byval_copy34|0));
              $392 = __THREW__; __THREW__ = 0;
              $393 = $392&1;
              if ($393) {
               label = 159;
               break;
              }
              $$pre$i$i$i$i$i59 = HEAP32[$227>>2]|0;
              $389 = $$pre$i$i$i$i$i59;
             }
             $388 = ($389|0)==($379|0);
             if ($388) {
              label = 160;
              break;
             } else {
              $384 = $389;
             }
            }
            if ((label|0) == 159) {
             $394 = ___cxa_find_matching_catch()|0;
             $395 = tempRet0;
             ___cxa_call_unexpected(($394|0));
             // unreachable;
            }
            else if ((label|0) == 160) {
             $$pre$i$i$i61 = HEAP32[$layers>>2]|0;
             $396 = $$pre$i$i$i61;
             break;
            }
           }
          } while(0);
          __ZdlPv($396);
          break L38;
         }
        }
       } while(0);
       if ((label|0) == 121) {
        $306 = ___cxa_find_matching_catch()|0;
        $307 = tempRet0;
        $lpad$phi95$index = $306;$lpad$phi95$index13 = $307;
        label = 122;
       }
       else if ((label|0) == 125) {
        $312 = $313 & 1;
        $314 = ($312<<24>>24)==(0);
        if ($314) {
         $$1 = $lpad$phi104$index;$$12 = $lpad$phi104$index19;
        } else {
         $315 = HEAP32[$230>>2]|0;
         HEAP32[$3>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$3+0>>2]|0;
         invoke_vii(2591,($315|0),($$byval_copy34|0));
         $316 = __THREW__; __THREW__ = 0;
         $317 = $316&1;
         if ($317) {
          $318 = ___cxa_find_matching_catch()|0;
          $319 = tempRet0;
          ___cxa_call_unexpected(($318|0));
          // unreachable;
         } else {
          $$1 = $lpad$phi104$index;$$12 = $lpad$phi104$index19;
         }
        }
       }
       if ((label|0) == 122) {
        $$1 = $lpad$phi95$index;$$12 = $lpad$phi95$index13;
       }
       $397 = HEAP32[$layers>>2]|0;
       $398 = ($397|0)==(0|0);
       if ($398) {
        $$2 = $$1;$$23 = $$12;
        break L1;
       }
       $399 = HEAP32[$227>>2]|0;
       $400 = ($399|0)==($397|0);
       do {
        if ($400) {
         $414 = $397;
        } else {
         $402 = $399;
         while(1) {
          $401 = (($402) + -12|0);
          HEAP32[$227>>2] = $401;
          $403 = HEAP8[$401>>0]|0;
          $404 = $403 & 1;
          $405 = ($404<<24>>24)==(0);
          if ($405) {
           $407 = $401;
          } else {
           $408 = (($402) + -4|0);
           $409 = HEAP32[$408>>2]|0;
           HEAP32[$1>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
           invoke_vii(2591,($409|0),($$byval_copy34|0));
           $410 = __THREW__; __THREW__ = 0;
           $411 = $410&1;
           if ($411) {
            label = 169;
            break;
           }
           $$pre$i$i$i$i$i67 = HEAP32[$227>>2]|0;
           $407 = $$pre$i$i$i$i$i67;
          }
          $406 = ($407|0)==($397|0);
          if ($406) {
           label = 170;
           break;
          } else {
           $402 = $407;
          }
         }
         if ((label|0) == 169) {
          $412 = ___cxa_find_matching_catch()|0;
          $413 = tempRet0;
          ___cxa_call_unexpected(($412|0));
          // unreachable;
         }
         else if ((label|0) == 170) {
          $$pre$i$i$i69 = HEAP32[$layers>>2]|0;
          $414 = $$pre$i$i$i69;
          break;
         }
        }
       } while(0);
       __ZdlPv($414);
       $$2 = $$1;$$23 = $$12;
       break L1;
      }
     } while(0);
     $415 = (($this) + 424|0);
     __THREW__ = 0;
     $416 = (invoke_iiiiii(192,($transfer|0),(567528|0),($22|0),($0|0),1)|0);
     $417 = __THREW__; __THREW__ = 0;
     $418 = $417&1;
     if ($418) {
      label = 3;
     } else {
      $419 = ($416|0)==(0);
      if (!($419)) {
       $420 = ($416|0)>(0);
       if ($420) {
        __THREW__ = 0;
        invoke_viii(1653,($transfer|0),($415|0),0);
        $421 = __THREW__; __THREW__ = 0;
        $422 = $421&1;
        if ($422) {
         label = 3;
         break;
        }
       } else {
        $423 = HEAP32[$0>>2]|0;
        $424 = ($423|0)==(0|0);
        if (!($424)) {
         __THREW__ = 0;
         (invoke_iii($423|0,($415|0),($transfer|0))|0);
         $425 = __THREW__; __THREW__ = 0;
         $426 = $425&1;
         if ($426) {
          label = 3;
          break;
         }
        }
       }
       __THREW__ = 0;
       invoke_vi(3389,($transfer|0));
       $427 = __THREW__; __THREW__ = 0;
       $428 = $427&1;
       if ($428) {
        label = 3;
        break;
       }
      }
      __THREW__ = 0;
      invoke_vi(3388,($this|0));
      $429 = __THREW__; __THREW__ = 0;
      $430 = $429&1;
      if ($430) {
       label = 3;
      } else {
       $431 = (($this) + 436|0);
       HEAP32[$431>>2] = 0;
       $432 = (($this) + 428|0);
       $433 = HEAP32[$432>>2]|0;
       $434 = (($this) + 424|0);
       $435 = HEAP32[$434>>2]|0;
       $436 = $433;
       $437 = $435;
       $438 = (($436) - ($437))|0;
       $439 = (($438|0) / 20)&-1;
       $440 = ($433|0)==($435|0);
       L238: do {
        if (!($440)) {
         $i$02$i = 0;
         while(1) {
          $443 = ((($435) + (($i$02$i*20)|0)|0) + 12|0);
          $444 = HEAP32[$443>>2]|0;
          $445 = ($444|0)==(0);
          $442 = (($i$02$i) + 1)|0;
          if ($445) {
           break;
          }
          $441 = ($442|0)==($439|0);
          if ($441) {
           break L238;
          } else {
           $i$02$i = $442;
          }
         }
         HEAP32[$431>>2] = $i$02$i;
        }
       } while(0);
       $446 = HEAP32[$tags>>2]|0;
       $447 = ($446|0)==(0|0);
       if ($447) {
        STACKTOP = sp;return;
       }
       $448 = HEAP32[$14>>2]|0;
       $449 = ($448|0)==($446|0);
       do {
        if ($449) {
         $463 = $446;
        } else {
         $451 = $448;
         while(1) {
          $450 = (($451) + -12|0);
          HEAP32[$14>>2] = $450;
          $452 = HEAP8[$450>>0]|0;
          $453 = $452 & 1;
          $454 = ($453<<24>>24)==(0);
          if ($454) {
           $456 = $450;
          } else {
           $457 = (($451) + -4|0);
           $458 = HEAP32[$457>>2]|0;
           HEAP32[$0>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($458|0),($$byval_copy34|0));
           $459 = __THREW__; __THREW__ = 0;
           $460 = $459&1;
           if ($460) {
            label = 191;
            break;
           }
           $$pre$i$i$i$i$i80 = HEAP32[$14>>2]|0;
           $456 = $$pre$i$i$i$i$i80;
          }
          $455 = ($456|0)==($446|0);
          if ($455) {
           label = 192;
           break;
          } else {
           $451 = $456;
          }
         }
         if ((label|0) == 191) {
          $461 = ___cxa_find_matching_catch()|0;
          $462 = tempRet0;
          ___cxa_call_unexpected(($461|0));
          // unreachable;
         }
         else if ((label|0) == 192) {
          $$pre$i$i$i82 = HEAP32[$tags>>2]|0;
          $463 = $$pre$i$i$i82;
          break;
         }
        }
       } while(0);
       __ZdlPv($463);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $lpad$phi112$index = $20;$lpad$phi112$index2 = $21;
  label = 4;
 }
 if ((label|0) == 4) {
  $$2 = $lpad$phi112$index;$$23 = $lpad$phi112$index2;
 }
 $464 = HEAP32[$tags>>2]|0;
 $465 = ($464|0)==(0|0);
 if ($465) {
  ___resumeException($$2|0);
  // unreachable;
 }
 $466 = HEAP32[$14>>2]|0;
 $467 = ($466|0)==($464|0);
 do {
  if ($467) {
   $481 = $464;
  } else {
   $469 = $466;
   while(1) {
    $468 = (($469) + -12|0);
    HEAP32[$14>>2] = $468;
    $470 = HEAP8[$468>>0]|0;
    $471 = $470 & 1;
    $472 = ($471<<24>>24)==(0);
    if ($472) {
     $474 = $468;
    } else {
     $475 = (($469) + -4|0);
     $476 = HEAP32[$475>>2]|0;
     HEAP32[$9>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$9+0>>2]|0;
     invoke_vii(2591,($476|0),($$byval_copy34|0));
     $477 = __THREW__; __THREW__ = 0;
     $478 = $477&1;
     if ($478) {
      label = 202;
      break;
     }
     $$pre$i$i$i$i$i = HEAP32[$14>>2]|0;
     $474 = $$pre$i$i$i$i$i;
    }
    $473 = ($474|0)==($464|0);
    if ($473) {
     label = 203;
     break;
    } else {
     $469 = $474;
    }
   }
   if ((label|0) == 202) {
    $479 = ___cxa_find_matching_catch()|0;
    $480 = tempRet0;
    ___cxa_call_unexpected(($479|0));
    // unreachable;
   }
   else if ((label|0) == 203) {
    $$pre$i$i$i = HEAP32[$tags>>2]|0;
    $481 = $$pre$i$i$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($481);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI17SortingLayerEntryNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i$i$i2 = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 20)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,567576,567576,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI17SortingLayerEntryNS0_9allocatorIS2_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,567544,567584,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $28 = HEAP32[580712>>2]|0;
      $30 = 0;$33 = $23;$52 = $26;
      while(1) {
       $29 = Math_imul($30, $19)|0;
       $31 = (($29) + ($25))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$20>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       $49 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,567552,$28,$converter$i$i$i$i2,0)|0);
       $50 = ($49|0)==(0);
       if (!($50)) {
        $51 = ($49|0)>(0);
        if ($51) {
         __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$52,0);
        } else {
         $53 = HEAP32[$converter$i$i$i$i2>>2]|0;
         $54 = ($53|0)==(0|0);
         if (!($54)) {
          (FUNCTION_TABLE_iii[$53 & 4095]($52,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $55 = (($52) + 12|0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$55,567560,0);
       $56 = (($52) + 20|0);
       $57 = ($56|0)==($11|0);
       if ($57) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre10 = HEAP32[$$pre>>2]|0;
       $$pre11 = HEAP32[$15>>2]|0;
       $30 = $$pre10;$33 = $$pre11;$52 = $56;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $58 = HEAP32[$data>>2]|0;
   $59 = ($58|0)==($11|0);
   if (!($59)) {
    $60 = HEAP32[580712>>2]|0;
    $67 = $58;
    while(1) {
     $61 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,567544,567584,$converter$i$i,1)|0);
     $62 = ($61|0)==(0);
     if (!($62)) {
      $63 = ($61|0)>(0);
      if ($63) {
       $64 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,567552,$60,$converter$i$i$i$i2,0)|0);
       $65 = ($64|0)==(0);
       if (!($65)) {
        $66 = ($64|0)>(0);
        if ($66) {
         __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$67,0);
        } else {
         $68 = HEAP32[$converter$i$i$i$i2>>2]|0;
         $69 = ($68|0)==(0|0);
         if (!($69)) {
          (FUNCTION_TABLE_iii[$68 & 4095]($67,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $70 = (($67) + 12|0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$70,567560,0);
      } else {
       $71 = HEAP32[$converter$i$i>>2]|0;
       $72 = ($71|0)==(0|0);
       if (!($72)) {
        (FUNCTION_TABLE_iii[$71 & 4095]($67,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $73 = (($67) + 20|0);
     $74 = ($73|0)==($11|0);
     if ($74) {
      break;
     } else {
      $67 = $73;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ph = 0, $$ph8 = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = HEAP8[$data>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = $2&255;
  $8 = $7 >>> 1;
  $9 = $8;
 } else {
  $5 = (($data) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $9 = $6;
 }
 HEAP32[$size>>2] = $9;
 $10 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,567576,567576,$size)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$size>>2]|0;
 $12 = HEAP8[$data>>0]|0;
 $13 = $12 & 1;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $17 = $12&255;
  $18 = $17 >>> 1;
  $20 = $18;
 } else {
  $15 = (($data) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $20 = $16;
 }
 $19 = ($20>>>0)<($11>>>0);
 do {
  if ($19) {
   $21 = (($11) - ($20))|0;
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6appendEjc($data,$21,1)|0);
  } else {
   if ($14) {
    $26 = ((($data) + ($11)|0) + 1|0);
    HEAP8[$26>>0] = 0;
    $27 = $11 << 1;
    $28 = $27&255;
    HEAP8[$data>>0] = $28;
    break;
   } else {
    $22 = (($data) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + ($11)|0);
    HEAP8[$24>>0] = 0;
    $25 = (($data) + 4|0);
    HEAP32[$25>>2] = $11;
    break;
   }
  }
 } while(0);
 $29 = HEAP8[$data>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $36 = (($data) + 1|0);
  $37 = $29&255;
  $38 = $37 >>> 1;
  $40 = $36;$41 = $38;
 } else {
  $32 = (($data) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($data) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $40 = $33;$41 = $35;
 }
 $39 = (($40) + ($41)|0);
 $42 = HEAP32[$size>>2]|0;
 $43 = ($42|0)==(0);
 L23: do {
  if (!($43)) {
   $44 = HEAP32[580552>>2]|0;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,567544,$44,0,0)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if (!($53)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $107 = HEAP8[$data>>0]|0;
    $108 = $107 & 1;
    $109 = ($108<<24>>24)==(0);
    if ($109) {
     $112 = (($data) + 1|0);
     $$ph8 = $112;
    } else {
     $110 = (($data) + 8|0);
     $111 = HEAP32[$110>>2]|0;
     $$ph8 = $111;
    }
    $113 = ($$ph8|0)==($39|0);
    if ($113) {
     break;
    } else {
     $114 = $$ph8;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIcEEvRT_PKc17TransferMetaFlags($this,$114,567544,0);
     $115 = (($114) + 1|0);
     $116 = ($115|0)==($39|0);
     if ($116) {
      break L23;
     } else {
      $114 = $115;
     }
    }
   }
   $54 = HEAP32[$46>>2]|0;
   $55 = (($54) + 12|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = HEAP8[$data>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    $62 = (($data) + 1|0);
    $$ph = $62;
   } else {
    $60 = (($data) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    $$ph = $61;
   }
   $63 = ($$ph|0)==($39|0);
   L38: do {
    if (!($63)) {
     $64 = (($this) + 12|0);
     $65 = (($this) + 16|0);
     $66 = (($this) + 28|0);
     $67 = (($this) + 32|0);
     $68 = (($this) + 20|0);
     $102 = $$ph;$70 = 0;$73 = $54;
     while(1) {
      $69 = Math_imul($70, $50)|0;
      $71 = (($69) + ($56))|0;
      $72 = (($73) + 20|0);
      HEAP32[$72>>2] = $71;
      $74 = (($73) + 12|0);
      HEAP32[$74>>2] = $71;
      $75 = (($73) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$73);
      $76 = $1;
      $77 = $76;
      $78 = HEAP32[$77>>2]|0;
      $79 = (($76) + 4)|0;
      $80 = $79;
      $81 = HEAP32[$80>>2]|0;
      $82 = $75;
      $83 = $82;
      HEAP32[$83>>2] = $78;
      $84 = (($82) + 4)|0;
      $85 = $84;
      HEAP32[$85>>2] = $81;
      $86 = HEAP32[$51>>2]|0;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($87) + 1)|0;
      HEAP32[$86>>2] = $88;
      $89 = HEAP32[$46>>2]|0;
      $90 = (($89) + 12|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = HEAP32[$65>>2]|0;
      $93 = HEAP32[$66>>2]|0;
      $94 = HEAP32[$67>>2]|0;
      $95 = Math_imul($94, $93)|0;
      $$sum$i$i$i = (($91) - ($95))|0;
      $96 = (($92) + ($$sum$i$i$i)|0);
      HEAP32[$64>>2] = $96;
      $97 = ($$sum$i$i$i|0)<(0);
      if ($97) {
       label = 26;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
       $98 = (($92) + ($$sum1$i$i$i)|0);
       $99 = HEAP32[$68>>2]|0;
       $100 = ($98>>>0)>($99>>>0);
       if ($100) {
        label = 26;
       } else {
        $101 = HEAP8[$96>>0]|0;
        HEAP8[$102>>0] = $101;
        $103 = HEAP32[$64>>2]|0;
        $104 = (($103) + 1|0);
        HEAP32[$64>>2] = $104;
       }
      }
      if ((label|0) == 26) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($64,$102,1);
      }
      $105 = (($102) + 1|0);
      $106 = ($105|0)==($39|0);
      if ($106) {
       break L38;
      }
      $$pre = HEAP32[$51>>2]|0;
      $$pre10 = HEAP32[$$pre>>2]|0;
      $$pre11 = HEAP32[$46>>2]|0;
      $102 = $105;$70 = $$pre10;$73 = $$pre11;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,567576,567576,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI8UnityStrNS0_9allocatorIS2_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580712>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,567544,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$49 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$49,0);
       $50 = (($49) + 12|0);
       $51 = ($50|0)==($11|0);
       if ($51) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$16>>2]|0;
       $30 = $$pre9;$33 = $$pre10;$49 = $50;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $52 = HEAP32[$data>>2]|0;
   $53 = ($52|0)==($11|0);
   if (!($53)) {
    $57 = $52;
    while(1) {
     $54 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,567544,$14,$converter$i$i,0)|0);
     $55 = ($54|0)==(0);
     if (!($55)) {
      $56 = ($54|0)>(0);
      if ($56) {
       __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$57,0);
      } else {
       $58 = HEAP32[$converter$i$i>>2]|0;
       $59 = ($58|0)==(0|0);
       if (!($59)) {
        (FUNCTION_TABLE_iii[$58 & 4095]($57,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $60 = (($57) + 12|0);
     $61 = ($60|0)==($11|0);
     if ($61) {
      break;
     } else {
      $57 = $60;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN10TagManager8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy26 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i20 = 0, $$pre$i$i$i$i$i28 = 0, $$pre$i$i$i$i$i6 = 0, $$pre$i$i$i22 = 0, $$pre$i$i$i30 = 0, $$pre$i$i$i8 = 0, $$pre42 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i3$041 = 0, $layers = 0, $lpad$phi$index = 0, $lpad$phi$index9 = 0, $lpad$phi40$index = 0, $lpad$phi40$index14 = 0, $p$i$i$i = 0, $tags = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy26 = sp + 92|0;
 $0 = sp + 88|0;
 $1 = sp + 84|0;
 $p$i$i$i = sp + 64|0;
 $2 = sp + 60|0;
 $3 = sp + 56|0;
 $4 = sp + 52|0;
 $5 = sp + 48|0;
 $6 = sp + 32|0;
 $7 = sp + 28|0;
 $8 = sp + 24|0;
 $tags = sp + 12|0;
 $layers = sp;
 $9 = sp + 36|0;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 HEAP32[$tags>>2] = 0;
 $10 = (($tags) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($tags) + 8|0);
 HEAP32[$11>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(332,($transfer|0),($tags|0),(567472|0),2048);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L1: do {
  if ($13) {
   label = 2;
  } else {
   HEAP32[$layers>>2] = 0;
   $16 = (($layers) + 4|0);
   HEAP32[$16>>2] = 0;
   $17 = (($layers) + 8|0);
   HEAP32[$17>>2] = 0;
   $18 = (($9) + 1|0);
   $19 = (($9) + 8|0);
   $20 = (($9) + 4|0);
   $i3$041 = 0;
   while(1) {
    $21 = ((($this) + (($i3$041*12)|0)|0) + 40|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = $22 & 1;
    $24 = ($23<<24>>24)==(0);
    if ($24) {
     $29 = (($21) + 1|0);
     $30 = $22&255;
     $31 = $30 >>> 1;
     $33 = $31;$46 = $29;
    } else {
     $25 = ((($this) + (($i3$041*12)|0)|0) + 48|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ((($this) + (($i3$041*12)|0)|0) + 44|0);
     $28 = HEAP32[$27>>2]|0;
     $33 = $28;$46 = $26;
    }
    $32 = ($33>>>0)>(2147483631);
    if ($32) {
     label = 9;
     break;
    }
    $36 = ($33>>>0)<(11);
    if ($36) {
     $37 = $33 << 1;
     $38 = $37&255;
     HEAP8[$9>>0] = $38;
     $53 = $38;$__p$0$i$i$i$i = $18;
    } else {
     $39 = (($33) + 16)|0;
     $40 = $39 & -16;
     HEAP32[$7>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$7+0>>2]|0;
     $41 = (invoke_iiiiiii(102,($40|0),16,($$byval_copy26|0),0,(567120|0),79)|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      label = 35;
      break;
     }
     HEAP32[$19>>2] = $41;
     $44 = $40 | 1;
     HEAP32[$9>>2] = $44;
     HEAP32[$20>>2] = $33;
     $45 = $44&255;
     $53 = $45;$__p$0$i$i$i$i = $41;
    }
    _memcpy(($__p$0$i$i$i$i|0),($46|0),($33|0))|0;
    $47 = (($__p$0$i$i$i$i) + ($33)|0);
    HEAP8[$47>>0] = 0;
    $48 = HEAP32[$16>>2]|0;
    $49 = HEAP32[$17>>2]|0;
    $50 = ($48|0)==($49|0);
    if ($50) {
     __THREW__ = 0;
     invoke_vii(2602,($layers|0),($9|0));
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if ($80) {
      label = 38;
      break;
     }
     $$pre42 = HEAP8[$9>>0]|0;
     $82 = $$pre42;
    } else {
     $51 = ($48|0)==(0|0);
     if ($51) {
      $78 = 0;
     } else {
      $52 = $53 & 1;
      $54 = ($52<<24>>24)==(0);
      if ($54) {
       $57 = $53&255;
       $58 = $57 >>> 1;
       $60 = $58;$75 = $18;
      } else {
       $55 = HEAP32[$19>>2]|0;
       $56 = HEAP32[$20>>2]|0;
       $60 = $56;$75 = $55;
      }
      $59 = ($60>>>0)>(2147483631);
      if ($59) {
       label = 21;
       break;
      }
      $63 = ($60>>>0)<(11);
      if ($63) {
       $64 = $60 << 1;
       $65 = $64&255;
       HEAP8[$48>>0] = $65;
       $66 = (($48) + 1|0);
       $__p$0$i$i$i$i$i$i = $66;
      } else {
       $67 = (($60) + 16)|0;
       $68 = $67 & -16;
       HEAP32[$6>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$6+0>>2]|0;
       $69 = (invoke_iiiiiii(102,($68|0),16,($$byval_copy26|0),0,(567120|0),79)|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 38;
        break;
       }
       $72 = (($48) + 8|0);
       HEAP32[$72>>2] = $69;
       $73 = $68 | 1;
       HEAP32[$48>>2] = $73;
       $74 = (($48) + 4|0);
       HEAP32[$74>>2] = $60;
       $__p$0$i$i$i$i$i$i = $69;
      }
      _memcpy(($__p$0$i$i$i$i$i$i|0),($75|0),($60|0))|0;
      $76 = (($__p$0$i$i$i$i$i$i) + ($60)|0);
      HEAP8[$76>>0] = 0;
      $$pre$i = HEAP32[$16>>2]|0;
      $78 = $$pre$i;
     }
     $77 = (($78) + 12|0);
     HEAP32[$16>>2] = $77;
     $82 = $53;
    }
    $81 = $82 & 1;
    $83 = ($81<<24>>24)==(0);
    if (!($83)) {
     $84 = HEAP32[$19>>2]|0;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($84|0),($$byval_copy26|0));
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      label = 33;
      break;
     }
    }
    $89 = (($i3$041) + 1)|0;
    $90 = ($89|0)<(32);
    if ($90) {
     $i3$041 = $89;
    } else {
     label = 43;
     break;
    }
   }
   do {
    if ((label|0) == 9) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 36;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 21) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      $97 = ___cxa_find_matching_catch()|0;
      $98 = tempRet0;
      $100 = $53;$lpad$phi40$index = $97;$lpad$phi40$index14 = $98;
      label = 40;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 33) {
     $87 = ___cxa_find_matching_catch()|0;
     $88 = tempRet0;
     ___cxa_call_unexpected(($87|0));
     // unreachable;
    }
    else if ((label|0) == 35) {
     $91 = ___cxa_find_matching_catch()|0;
     $92 = tempRet0;
     $lpad$phi$index = $91;$lpad$phi$index9 = $92;
     label = 37;
    }
    else if ((label|0) == 38) {
     $95 = ___cxa_find_matching_catch()|0;
     $96 = tempRet0;
     $$pre = HEAP8[$9>>0]|0;
     $100 = $$pre;$lpad$phi40$index = $95;$lpad$phi40$index14 = $96;
     label = 40;
    }
    else if ((label|0) == 43) {
     __THREW__ = 0;
     invoke_viiii(332,($transfer|0),($layers|0),(567520|0),2048);
     $107 = __THREW__; __THREW__ = 0;
     $108 = $107&1;
     if ($108) {
      label = 36;
     } else {
      $109 = HEAP32[$layers>>2]|0;
      $110 = ($109|0)==(0|0);
      if (!($110)) {
       $111 = HEAP32[$16>>2]|0;
       $112 = ($111|0)==($109|0);
       do {
        if ($112) {
         $126 = $109;
        } else {
         $114 = $111;
         while(1) {
          $113 = (($114) + -12|0);
          HEAP32[$16>>2] = $113;
          $115 = HEAP8[$113>>0]|0;
          $116 = $115 & 1;
          $117 = ($116<<24>>24)==(0);
          if ($117) {
           $119 = $113;
          } else {
           $120 = (($114) + -4|0);
           $121 = HEAP32[$120>>2]|0;
           HEAP32[$3>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$3+0>>2]|0;
           invoke_vii(2591,($121|0),($$byval_copy26|0));
           $122 = __THREW__; __THREW__ = 0;
           $123 = $122&1;
           if ($123) {
            label = 51;
            break;
           }
           $$pre$i$i$i$i$i20 = HEAP32[$16>>2]|0;
           $119 = $$pre$i$i$i$i$i20;
          }
          $118 = ($119|0)==($109|0);
          if ($118) {
           label = 52;
           break;
          } else {
           $114 = $119;
          }
         }
         if ((label|0) == 51) {
          $124 = ___cxa_find_matching_catch()|0;
          $125 = tempRet0;
          ___cxa_call_unexpected(($124|0));
          // unreachable;
         }
         else if ((label|0) == 52) {
          $$pre$i$i$i22 = HEAP32[$layers>>2]|0;
          $126 = $$pre$i$i$i22;
          break;
         }
        }
       } while(0);
       __ZdlPv($126);
      }
      $145 = (($this) + 424|0);
      $146 = HEAP32[580760>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(86,($transfer|0),(567528|0),($146|0),($145|0),0);
      $147 = __THREW__; __THREW__ = 0;
      $148 = $147&1;
      if ($148) {
       label = 2;
       break L1;
      }
      ;HEAP32[$p$i$i$i+0>>2]=0|0;HEAP32[$p$i$i$i+4>>2]=0|0;HEAP32[$p$i$i$i+8>>2]=0|0;
      $149 = (($p$i$i$i) + 12|0);
      HEAP32[$149>>2] = 1;
      $150 = (($p$i$i$i) + 16|0);
      HEAP8[$150>>0] = 0;
      __THREW__ = 0;
      invoke_viii(1654,($transfer|0),($p$i$i$i|0),0);
      $151 = __THREW__; __THREW__ = 0;
      $152 = $151&1;
      if ($152) {
       $162 = ___cxa_find_matching_catch()|0;
       $163 = tempRet0;
       $164 = HEAP8[$p$i$i$i>>0]|0;
       $165 = $164 & 1;
       $166 = ($165<<24>>24)==(0);
       if ($166) {
        $eh$lpad$body$index3Z2D = $163;$eh$lpad$body$indexZ2D = $162;
        label = 3;
        break L1;
       }
       $167 = (($p$i$i$i) + 8|0);
       $168 = HEAP32[$167>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($168|0),($$byval_copy26|0));
       $169 = __THREW__; __THREW__ = 0;
       $170 = $169&1;
       if (!($170)) {
        $eh$lpad$body$index3Z2D = $163;$eh$lpad$body$indexZ2D = $162;
        label = 3;
        break L1;
       }
       $171 = ___cxa_find_matching_catch()|0;
       $172 = tempRet0;
       ___cxa_call_unexpected(($171|0));
       // unreachable;
      }
      $153 = HEAP8[$p$i$i$i>>0]|0;
      $154 = $153 & 1;
      $155 = ($154<<24>>24)==(0);
      if (!($155)) {
       $156 = (($p$i$i$i) + 8|0);
       $157 = HEAP32[$156>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($157|0),($$byval_copy26|0));
       $158 = __THREW__; __THREW__ = 0;
       $159 = $158&1;
       if ($159) {
        $160 = ___cxa_find_matching_catch()|0;
        $161 = tempRet0;
        ___cxa_call_unexpected(($160|0));
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_vi(3390,($transfer|0));
      $173 = __THREW__; __THREW__ = 0;
      $174 = $173&1;
      if ($174) {
       label = 2;
       break L1;
      }
      $175 = HEAP32[$tags>>2]|0;
      $176 = ($175|0)==(0|0);
      if ($176) {
       STACKTOP = sp;return;
      }
      $177 = HEAP32[$10>>2]|0;
      $178 = ($177|0)==($175|0);
      do {
       if ($178) {
        $192 = $175;
       } else {
        $180 = $177;
        while(1) {
         $179 = (($180) + -12|0);
         HEAP32[$10>>2] = $179;
         $181 = HEAP8[$179>>0]|0;
         $182 = $181 & 1;
         $183 = ($182<<24>>24)==(0);
         if ($183) {
          $185 = $179;
         } else {
          $186 = (($180) + -4|0);
          $187 = HEAP32[$186>>2]|0;
          HEAP32[$1>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$1+0>>2]|0;
          invoke_vii(2591,($187|0),($$byval_copy26|0));
          $188 = __THREW__; __THREW__ = 0;
          $189 = $188&1;
          if ($189) {
           label = 80;
           break;
          }
          $$pre$i$i$i$i$i6 = HEAP32[$10>>2]|0;
          $185 = $$pre$i$i$i$i$i6;
         }
         $184 = ($185|0)==($175|0);
         if ($184) {
          label = 81;
          break;
         } else {
          $180 = $185;
         }
        }
        if ((label|0) == 80) {
         $190 = ___cxa_find_matching_catch()|0;
         $191 = tempRet0;
         ___cxa_call_unexpected(($190|0));
         // unreachable;
        }
        else if ((label|0) == 81) {
         $$pre$i$i$i8 = HEAP32[$tags>>2]|0;
         $192 = $$pre$i$i$i8;
         break;
        }
       }
      } while(0);
      __ZdlPv($192);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 36) {
    $93 = ___cxa_find_matching_catch()|0;
    $94 = tempRet0;
    $lpad$phi$index = $93;$lpad$phi$index9 = $94;
    label = 37;
   }
   else if ((label|0) == 40) {
    $99 = $100 & 1;
    $101 = ($99<<24>>24)==(0);
    if ($101) {
     $$1 = $lpad$phi40$index;$$12 = $lpad$phi40$index14;
    } else {
     $102 = HEAP32[$19>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($102|0),($$byval_copy26|0));
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      $105 = ___cxa_find_matching_catch()|0;
      $106 = tempRet0;
      ___cxa_call_unexpected(($105|0));
      // unreachable;
     } else {
      $$1 = $lpad$phi40$index;$$12 = $lpad$phi40$index14;
     }
    }
   }
   if ((label|0) == 37) {
    $$1 = $lpad$phi$index;$$12 = $lpad$phi$index9;
   }
   $127 = HEAP32[$layers>>2]|0;
   $128 = ($127|0)==(0|0);
   if ($128) {
    $$2 = $$1;$$23 = $$12;
   } else {
    $129 = HEAP32[$16>>2]|0;
    $130 = ($129|0)==($127|0);
    do {
     if ($130) {
      $144 = $127;
     } else {
      $132 = $129;
      while(1) {
       $131 = (($132) + -12|0);
       HEAP32[$16>>2] = $131;
       $133 = HEAP8[$131>>0]|0;
       $134 = $133 & 1;
       $135 = ($134<<24>>24)==(0);
       if ($135) {
        $137 = $131;
       } else {
        $138 = (($132) + -4|0);
        $139 = HEAP32[$138>>2]|0;
        HEAP32[$2>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($139|0),($$byval_copy26|0));
        $140 = __THREW__; __THREW__ = 0;
        $141 = $140&1;
        if ($141) {
         label = 61;
         break;
        }
        $$pre$i$i$i$i$i28 = HEAP32[$16>>2]|0;
        $137 = $$pre$i$i$i$i$i28;
       }
       $136 = ($137|0)==($127|0);
       if ($136) {
        label = 62;
        break;
       } else {
        $132 = $137;
       }
      }
      if ((label|0) == 61) {
       $142 = ___cxa_find_matching_catch()|0;
       $143 = tempRet0;
       ___cxa_call_unexpected(($142|0));
       // unreachable;
      }
      else if ((label|0) == 62) {
       $$pre$i$i$i30 = HEAP32[$layers>>2]|0;
       $144 = $$pre$i$i$i30;
       break;
      }
     }
    } while(0);
    __ZdlPv($144);
    $$2 = $$1;$$23 = $$12;
   }
  }
 } while(0);
 if ((label|0) == 2) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $eh$lpad$body$index3Z2D = $15;$eh$lpad$body$indexZ2D = $14;
  label = 3;
 }
 if ((label|0) == 3) {
  $$2 = $eh$lpad$body$indexZ2D;$$23 = $eh$lpad$body$index3Z2D;
 }
 $193 = HEAP32[$tags>>2]|0;
 $194 = ($193|0)==(0|0);
 if ($194) {
  ___resumeException($$2|0);
  // unreachable;
 }
 $195 = HEAP32[$10>>2]|0;
 $196 = ($195|0)==($193|0);
 do {
  if ($196) {
   $210 = $193;
  } else {
   $198 = $195;
   while(1) {
    $197 = (($198) + -12|0);
    HEAP32[$10>>2] = $197;
    $199 = HEAP8[$197>>0]|0;
    $200 = $199 & 1;
    $201 = ($200<<24>>24)==(0);
    if ($201) {
     $203 = $197;
    } else {
     $204 = (($198) + -4|0);
     $205 = HEAP32[$204>>2]|0;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$8+0>>2]|0;
     invoke_vii(2591,($205|0),($$byval_copy26|0));
     $206 = __THREW__; __THREW__ = 0;
     $207 = $206&1;
     if ($207) {
      label = 91;
      break;
     }
     $$pre$i$i$i$i$i = HEAP32[$10>>2]|0;
     $203 = $$pre$i$i$i$i$i;
    }
    $202 = ($203|0)==($193|0);
    if ($202) {
     label = 92;
     break;
    } else {
     $198 = $203;
    }
   }
   if ((label|0) == 91) {
    $208 = ___cxa_find_matching_catch()|0;
    $209 = tempRet0;
    ___cxa_call_unexpected(($208|0));
    // unreachable;
   }
   else if ((label|0) == 92) {
    $$pre$i$i$i = HEAP32[$tags>>2]|0;
    $210 = $$pre$i$i$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($210);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $p$i$i$i$i = 0, $size$i = 0, $size$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $size$i$i$i$i$i = sp;
 $p$i$i$i$i = sp + 28|0;
 $size$i = sp + 16|0;
 $0 = sp + 20|0;
 $p$i$i = sp + 4|0;
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$1,$data,$metaFlag);
 ;HEAP32[$p$i$i+0>>2]=0|0;HEAP32[$p$i$i+4>>2]=0|0;HEAP32[$p$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(567576|0),(567576|0),($size$i|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = HEAP32[580712>>2]|0;
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(567544|0),($4|0),($p$i$i|0),0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_viiiii(87,($this|0),(567576|0),(567576|0),($size$i$i$i$i$i|0),1);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[580552>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($this|0),(567544|0),($9|0),($p$i$i$i$i|0),0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($this) + 12|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = HEAP32[$13>>2]|0;
     $15 = (($this) + 20|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ((($14) + (($16*24)|0)|0) + 12|0);
     HEAP32[$17>>2] = 1;
     __THREW__ = 0;
     invoke_vi(3390,($this|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3391,($this|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       invoke_vi(3392,($this|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3390,($this|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         invoke_vi(3391,($this|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          $28 = HEAP8[$p$i$i>>0]|0;
          $29 = $28 & 1;
          $30 = ($29<<24>>24)==(0);
          if ($30) {
           __ZN13ProxyTransfer11EndTransferEv($this);
           STACKTOP = sp;return;
          }
          $31 = (($p$i$i) + 8|0);
          $32 = HEAP32[$31>>2]|0;
          HEAP32[$size$i$i$i$i$i>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i$i+0>>2]|0;
          invoke_vii(2591,($32|0),($$byval_copy1|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           $35 = ___cxa_find_matching_catch()|0;
           $36 = tempRet0;
           ___cxa_call_unexpected(($35|0));
           // unreachable;
          } else {
           __ZN13ProxyTransfer11EndTransferEv($this);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 $39 = HEAP8[$p$i$i>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  ___resumeException($37|0);
  // unreachable;
 }
 $42 = (($p$i$i) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($43|0),($$byval_copy1|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  ___resumeException($37|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer32TransferSTLStyleArrayWithElementI17SortingLayerEntryEEvRT_17TransferMetaFlags($this,$elementType,$metaFlag) {
 $this = $this|0;
 $elementType = $elementType|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0, $size = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp + 4|0;
 $p$i$i$i = sp + 8|0;
 $size = sp;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,567576,567576,$size,$metaFlag);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,567544,567584,$elementType,0);
 $0 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,567552,$0,$elementType,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,567576,567576,$size$i$i$i$i,1);
 $1 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,567544,$1,$p$i$i$i,0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer5AlignEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $8 = (($elementType) + 12|0);
 $9 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,567560,$9,$8,0);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer5AlignEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$i = 0, $$$i$i$i$i = 0, $$$i$i$i$i$i = 0, $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = HEAP8[$__v>>0]|0;
  $5 = $4 & 1;
  $6 = ($5<<24>>24)==(0);
  $7 = $4&255;
  $8 = $7 >>> 1;
  $9 = (($__v) + 1|0);
  $10 = (($__v) + 8|0);
  $11 = (($__v) + 4|0);
  $$0$ph7$i = $2;$$01$ph6$i$in = $1;
  L3: while(1) {
   $$013$i$in = $$01$ph6$i$in;
   while(1) {
    $12 = (($$013$i$in) + 16|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     $18 = $13&255;
     $19 = $18 >>> 1;
     $27 = $19;
    } else {
     $16 = (($$013$i$in) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $27 = $17;
    }
    if ($6) {
     $26 = $8;
    } else {
     $20 = HEAP32[$11>>2]|0;
     $26 = $20;
    }
    if ($15) {
     $23 = (($12) + 1|0);
     $29 = $23;
    } else {
     $21 = (($$013$i$in) + 24|0);
     $22 = HEAP32[$21>>2]|0;
     $29 = $22;
    }
    if ($6) {
     $30 = $9;
    } else {
     $24 = HEAP32[$10>>2]|0;
     $30 = $24;
    }
    $25 = ($26>>>0)<($27>>>0);
    $28 = $25 ? $26 : $27;
    $31 = (_memcmp($29,$30,$28)|0);
    $32 = ($31|0)==(0);
    if ($32) {
     $33 = ($27>>>0)<($26>>>0);
     $$$i$i$i$i$i = $25&1;
     $$$$i$i$i$i$i = $33 ? -1 : $$$i$i$i$i$i;
     $35 = $$$$i$i$i$i$i;
    } else {
     $35 = $31;
    }
    $34 = ($35|0)<(0);
    if (!($34)) {
     break;
    }
    $38 = (($$013$i$in) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$0$ph5$i = $$0$ph7$i;
     break L3;
    } else {
     $$013$i$in = $39;
    }
   }
   $36 = HEAP32[$$013$i$in>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    $$0$ph5$i = $$013$i$in;
    break;
   } else {
    $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $36;
   }
  }
  $41 = ($$0$ph5$i|0)==($2|0);
  if (!($41)) {
   $42 = (($$0$ph5$i) + 16|0);
   if ($6) {
    $57 = $8;
   } else {
    $43 = HEAP32[$11>>2]|0;
    $57 = $43;
   }
   $44 = HEAP8[$42>>0]|0;
   $45 = $44 & 1;
   $46 = ($45<<24>>24)==(0);
   if ($46) {
    $49 = $44&255;
    $50 = $49 >>> 1;
    $56 = $50;
   } else {
    $47 = (($$0$ph5$i) + 20|0);
    $48 = HEAP32[$47>>2]|0;
    $56 = $48;
   }
   if ($6) {
    $59 = $9;
   } else {
    $51 = HEAP32[$10>>2]|0;
    $59 = $51;
   }
   if ($46) {
    $54 = (($42) + 1|0);
    $60 = $54;
   } else {
    $52 = (($$0$ph5$i) + 24|0);
    $53 = HEAP32[$52>>2]|0;
    $60 = $53;
   }
   $55 = ($56>>>0)<($57>>>0);
   $58 = $55 ? $56 : $57;
   $61 = (_memcmp($59,$60,$58)|0);
   $62 = ($61|0)==(0);
   if ($62) {
    $63 = ($57>>>0)<($56>>>0);
    $$$i$i$i$i = $55&1;
    $$$$i$i$i$i = $63 ? -1 : $$$i$i$i$i;
    $65 = $$$$i$i$i$i;
   } else {
    $65 = $61;
   }
   $64 = ($65|0)<(0);
   if (!($64)) {
    HEAP32[$agg$result>>2] = $$0$ph5$i;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i8 = 0, $$0$i9 = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i$i = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 20)&-1;
 $10 = (($9) + 1)|0;
 $11 = ($10>>>0)>(214748364);
 if ($11) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($7))|0;
 $16 = (($15|0) / 20)&-1;
 $17 = ($16>>>0)<(107374182);
 if ($17) {
  $20 = $16 << 1;
  $21 = ($20>>>0)<($10>>>0);
  $22 = $21 ? $10 : $20;
  $23 = (($__v) + 12|0);
  HEAP32[$23>>2] = 0;
  $24 = (($__v) + 16|0);
  HEAP32[$24>>2] = $2;
  $25 = ($22|0)==(0);
  if ($25) {
   $$0$i9 = 0;$28 = 0;$33 = $23;
  } else {
   $$0$i8 = $22;$105 = $23;
   label = 6;
  }
 } else {
  $18 = (($__v) + 12|0);
  HEAP32[$18>>2] = 0;
  $19 = (($__v) + 16|0);
  HEAP32[$19>>2] = $2;
  $$0$i8 = 214748364;$105 = $18;
  label = 6;
 }
 if ((label|0) == 6) {
  $26 = ($$0$i8*20)|0;
  $27 = (__Znwj($26)|0);
  $$0$i9 = $$0$i8;$28 = $27;$33 = $105;
 }
 HEAP32[$__v>>2] = $28;
 $29 = (($28) + (($9*20)|0)|0);
 $30 = (($__v) + 8|0);
 HEAP32[$30>>2] = $29;
 $31 = (($__v) + 4|0);
 HEAP32[$31>>2] = $29;
 $32 = (($28) + (($$0$i9*20)|0)|0);
 HEAP32[$33>>2] = $32;
 $34 = ($29|0)==(0|0);
 do {
  if ($34) {
   $66 = 0;
   label = 19;
  } else {
   $35 = HEAP8[$__x>>0]|0;
   $36 = $35 & 1;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    $42 = (($__x) + 1|0);
    $43 = $35&255;
    $44 = $43 >>> 1;
    $46 = $44;$61 = $42;
   } else {
    $38 = (($__x) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($__x) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $46 = $41;$61 = $39;
   }
   $45 = ($46>>>0)>(2147483631);
   if ($45) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    // unreachable;
   }
   $49 = ($46>>>0)<(11);
   if ($49) {
    $50 = $46 << 1;
    $51 = $50&255;
    HEAP8[$29>>0] = $51;
    $52 = (($29) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $52;
   } else {
    $53 = (($46) + 16)|0;
    $54 = $53 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $55 = (invoke_iiiiiii(102,($54|0),16,($$byval_copy2|0),0,(567120|0),79)|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = ((($28) + (($9*20)|0)|0) + 8|0);
    HEAP32[$58>>2] = $55;
    $59 = $54 | 1;
    HEAP32[$29>>2] = $59;
    $60 = ((($28) + (($9*20)|0)|0) + 4|0);
    HEAP32[$60>>2] = $46;
    $__p$0$i$i$i$i$i$i$i = $55;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($61|0),($46|0))|0;
   $62 = (($__p$0$i$i$i$i$i$i$i) + ($46)|0);
   HEAP8[$62>>0] = 0;
   $63 = ((($28) + (($9*20)|0)|0) + 12|0);
   $64 = (($__x) + 12|0);
   ;HEAP32[$63+0>>2]=HEAP32[$64+0>>2]|0;HEAP8[$63+4>>0]=HEAP8[$64+4>>0]|0;
   $$pre = HEAP32[$30>>2]|0;
   $66 = $$pre;
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  $65 = (($66) + 20|0);
  HEAP32[$30>>2] = $65;
  __THREW__ = 0;
  invoke_vii(2606,($this|0),($__v|0));
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if (!($68)) {
   $69 = HEAP32[$31>>2]|0;
   $70 = HEAP32[$30>>2]|0;
   $71 = ($70|0)==($69|0);
   L28: do {
    if (!($71)) {
     $73 = $70;
     while(1) {
      $72 = (($73) + -20|0);
      HEAP32[$30>>2] = $72;
      $74 = HEAP8[$72>>0]|0;
      $75 = $74 & 1;
      $76 = ($75<<24>>24)==(0);
      if (!($76)) {
       $78 = (($73) + -12|0);
       $79 = HEAP32[$78>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($79|0),($$byval_copy2|0));
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
      }
      $77 = ($72|0)==($69|0);
      if ($77) {
       break L28;
      } else {
       $73 = $72;
      }
     }
     $82 = ___cxa_find_matching_catch()|0;
     $83 = tempRet0;
     ___cxa_call_unexpected(($82|0));
     // unreachable;
    }
   } while(0);
   $84 = HEAP32[$__v>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    STACKTOP = sp;return;
   }
   __ZdlPv($84);
   STACKTOP = sp;return;
  }
 }
 $86 = ___cxa_find_matching_catch()|0;
 $87 = tempRet0;
 $88 = HEAP32[$31>>2]|0;
 $89 = HEAP32[$30>>2]|0;
 $90 = ($89|0)==($88|0);
 L42: do {
  if (!($90)) {
   $92 = $89;
   while(1) {
    $91 = (($92) + -20|0);
    HEAP32[$30>>2] = $91;
    $93 = HEAP8[$91>>0]|0;
    $94 = $93 & 1;
    $95 = ($94<<24>>24)==(0);
    if (!($95)) {
     $97 = (($92) + -12|0);
     $98 = HEAP32[$97>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($98|0),($$byval_copy2|0));
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      break;
     }
    }
    $96 = ($91|0)==($88|0);
    if ($96) {
     break L42;
    } else {
     $92 = $91;
    }
   }
   $101 = ___cxa_find_matching_catch()|0;
   $102 = tempRet0;
   ___cxa_call_unexpected(($101|0));
   // unreachable;
  }
 } while(0);
 $103 = HEAP32[$__v>>2]|0;
 $104 = ($103|0)==(0|0);
 if ($104) {
  ___resumeException($86|0);
  // unreachable;
 }
 __ZdlPv($103);
 ___resumeException($86|0);
 // unreachable;
}
function __ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$4);
 $5 = (($__nd) + 20|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_call_unexpected(($13|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$4);
 $5 = (($__nd) + 16|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_call_unexpected(($13|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE15__insert_uniqueERKS8_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp + 12|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$20 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4>>>0)<($6>>>0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6>>>0)<($4>>>0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $30 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 __ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE16__construct_nodeERKS8_($0,$this,$__v);
 $17 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$17>>2] = 0;
 $18 = (($17) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $17;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $17;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $17;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE16__construct_nodeERKS8_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Z15malloc_internaljj10MemLabelIdiPKci(32,16,$$byval_copy1,0,567120,79)|0);
 $3 = $1;
 $4 = (($2) + 16|0);
 $5 = HEAP32[$__v>>2]|0;
 HEAP32[$4>>2] = $5;
 $6 = (($2) + 20|0);
 $7 = (($__v) + 4|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  ;HEAP32[$6+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$7+8>>2]|0;
  $31 = HEAP32[$__v>>2]|0;
  HEAP32[$4>>2] = $31;
  HEAP32[$agg$result>>2] = $2;
  $32 = (($agg$result) + 4|0);
  $33 = $32;
  $34 = $33;
  HEAP32[$34>>2] = $3;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = 1;
  STACKTOP = sp;return;
 }
 $11 = (($__v) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($__v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14>>>0)>(4294967279);
 do {
  if ($15) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    // unreachable;
   }
  } else {
   $18 = ($14>>>0)<(11);
   if ($18) {
    $19 = $14 << 1;
    $20 = $19&255;
    HEAP8[$6>>0] = $20;
    $21 = (($2) + 21|0);
    $__p$0$i$i$i$i$i$i$i$i = $21;
   } else {
    $22 = (($14) + 16)|0;
    $23 = $22 & -16;
    __THREW__ = 0;
    $24 = (invoke_ii(2988,($23|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = (($2) + 28|0);
    HEAP32[$27>>2] = $24;
    $28 = $23 | 1;
    HEAP32[$6>>2] = $28;
    $29 = (($2) + 24|0);
    HEAP32[$29>>2] = $14;
    $__p$0$i$i$i$i$i$i$i$i = $24;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($12|0),($14|0))|0;
   $30 = (($__p$0$i$i$i$i$i$i$i$i) + ($14)|0);
   HEAP8[$30>>0] = 0;
   $31 = HEAP32[$__v>>2]|0;
   HEAP32[$4>>2] = $31;
   HEAP32[$agg$result>>2] = $2;
   $32 = (($agg$result) + 4|0);
   $33 = $32;
   $34 = $33;
   HEAP32[$34>>2] = $3;
   $35 = (($33) + 4)|0;
   $36 = $35;
   HEAP32[$36>>2] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 $39 = ($2|0)==(0|0);
 if ($39) {
  ___resumeException($37|0);
  // unreachable;
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($2|0),($$byval_copy1|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  ___cxa_call_unexpected(($42|0));
  // unreachable;
 } else {
  ___resumeException($37|0);
  // unreachable;
 }
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE12__find_equalIS8_EERPNS_16__tree_node_baseIPvEESM_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$$i$i$i$i5 = 0, $$$$i$i$i$i5$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$$i$i$i$i4 = 0, $$$i$i$i$i4$us = 0, $$0 = 0, $$lcssa = 0, $$lcssa9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__nd$0$in = 0, $__nd$0$in$lcssa = 0, $__nd$0$in$lcssa7 = 0, $__nd$0$in$lcssa8 = 0, $__nd$0$in$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $97 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $97;
  $$0 = $97;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 L5: do {
  if ($5) {
   $__nd$0$in$us = $1;
   while(1) {
    $11 = (($__nd$0$in$us) + 16|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = $12 & 1;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     $19 = $12&255;
     $20 = $19 >>> 1;
     $21 = (($11) + 1|0);
     $23 = $20;$25 = $21;
    } else {
     $15 = (($__nd$0$in$us) + 20|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($__nd$0$in$us) + 24|0);
     $18 = HEAP32[$17>>2]|0;
     $23 = $16;$25 = $18;
    }
    $22 = ($23>>>0)<($7>>>0);
    $24 = $22 ? $23 : $7;
    $26 = (_memcmp($8,$25,$24)|0);
    $27 = ($26|0)==(0);
    if ($27) {
     $28 = ($7>>>0)<($23>>>0);
     $$$i$i$i$i4$us = $22&1;
     $$$$i$i$i$i5$us = $28 ? -1 : $$$i$i$i$i4$us;
     $30 = $$$$i$i$i$i5$us;
    } else {
     $30 = $26;
    }
    $29 = ($30|0)<(0);
    if ($29) {
     $50 = HEAP32[$__nd$0$in$us>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      $$lcssa9 = $__nd$0$in$us;$__nd$0$in$lcssa8 = $__nd$0$in$us;
      label = 24;
      break;
     } else {
      $__nd$0$in$us = $50;
      continue;
     }
    }
    if ($14) {
     $35 = $12&255;
     $36 = $35 >>> 1;
     $37 = (($11) + 1|0);
     $39 = $36;$41 = $37;
    } else {
     $31 = (($__nd$0$in$us) + 20|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($__nd$0$in$us) + 24|0);
     $34 = HEAP32[$33>>2]|0;
     $39 = $32;$41 = $34;
    }
    $38 = ($7>>>0)<($39>>>0);
    $40 = $38 ? $7 : $39;
    $42 = (_memcmp($41,$8,$40)|0);
    $43 = ($42|0)==(0);
    if ($43) {
     $44 = ($39>>>0)<($7>>>0);
     $$$i$i$i$i$us = $38&1;
     $$$$i$i$i$i$us = $44 ? -1 : $$$i$i$i$i$us;
     $46 = $$$$i$i$i$i$us;
    } else {
     $46 = $42;
    }
    $45 = ($46|0)<(0);
    if (!($45)) {
     $__nd$0$in$lcssa = $__nd$0$in$us;
     label = 33;
     break L5;
    }
    $47 = (($__nd$0$in$us) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     $$lcssa = $47;$__nd$0$in$lcssa7 = $__nd$0$in$us;
     label = 32;
     break;
    } else {
     $__nd$0$in$us = $48;
    }
   }
  } else {
   $__nd$0$in = $1;
   while(1) {
    $52 = (($__nd$0$in) + 16|0);
    $53 = HEAP32[$10>>2]|0;
    $54 = HEAP8[$52>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if ($56) {
     $61 = $54&255;
     $62 = $61 >>> 1;
     $63 = (($52) + 1|0);
     $66 = $62;$68 = $63;
    } else {
     $57 = (($__nd$0$in) + 20|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($__nd$0$in) + 24|0);
     $60 = HEAP32[$59>>2]|0;
     $66 = $58;$68 = $60;
    }
    $64 = HEAP32[$9>>2]|0;
    $65 = ($66>>>0)<($53>>>0);
    $67 = $65 ? $66 : $53;
    $69 = (_memcmp($64,$68,$67)|0);
    $70 = ($69|0)==(0);
    if ($70) {
     $71 = ($53>>>0)<($66>>>0);
     $$$i$i$i$i4 = $65&1;
     $$$$i$i$i$i5 = $71 ? -1 : $$$i$i$i$i4;
     $73 = $$$$i$i$i$i5;
    } else {
     $73 = $69;
    }
    $72 = ($73|0)<(0);
    if ($72) {
     $74 = HEAP32[$__nd$0$in>>2]|0;
     $75 = ($74|0)==(0|0);
     if ($75) {
      $$lcssa9 = $__nd$0$in;$__nd$0$in$lcssa8 = $__nd$0$in;
      label = 24;
      break;
     } else {
      $__nd$0$in = $74;
      continue;
     }
    }
    if ($56) {
     $80 = $54&255;
     $81 = $80 >>> 1;
     $82 = (($52) + 1|0);
     $86 = $81;$88 = $82;
    } else {
     $76 = (($__nd$0$in) + 20|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($__nd$0$in) + 24|0);
     $79 = HEAP32[$78>>2]|0;
     $86 = $77;$88 = $79;
    }
    $83 = HEAP32[$10>>2]|0;
    $84 = HEAP32[$9>>2]|0;
    $85 = ($83>>>0)<($86>>>0);
    $87 = $85 ? $83 : $86;
    $89 = (_memcmp($88,$84,$87)|0);
    $90 = ($89|0)==(0);
    if ($90) {
     $91 = ($86>>>0)<($83>>>0);
     $$$i$i$i$i = $85&1;
     $$$$i$i$i$i = $91 ? -1 : $$$i$i$i$i;
     $93 = $$$$i$i$i$i;
    } else {
     $93 = $89;
    }
    $92 = ($93|0)<(0);
    if (!($92)) {
     $__nd$0$in$lcssa = $__nd$0$in;
     label = 33;
     break L5;
    }
    $94 = (($__nd$0$in) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0|0);
    if ($96) {
     $$lcssa = $94;$__nd$0$in$lcssa7 = $__nd$0$in;
     label = 32;
     break;
    } else {
     $__nd$0$in = $95;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa8;
  $$0 = $$lcssa9;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa7;
  $$0 = $$lcssa;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE16__construct_nodeERKS8_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP32[$0>>2] = 1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Z15malloc_internaljj10MemLabelIdiPKci(32,16,$$byval_copy1,0,567120,79)|0);
 $3 = $1;
 $4 = (($2) + 16|0);
 $5 = HEAP8[$__v>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  ;HEAP32[$4+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__v+8>>2]|0;
  $28 = (($2) + 28|0);
  $29 = (($__v) + 12|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$28>>2] = $30;
  HEAP32[$agg$result>>2] = $2;
  $31 = (($agg$result) + 4|0);
  $32 = $31;
  $33 = $32;
  HEAP32[$33>>2] = $3;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP32[$35>>2] = 1;
  STACKTOP = sp;return;
 }
 $8 = (($__v) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__v) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)>(4294967279);
 do {
  if ($12) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    // unreachable;
   }
  } else {
   $15 = ($11>>>0)<(11);
   if ($15) {
    $16 = $11 << 1;
    $17 = $16&255;
    HEAP8[$4>>0] = $17;
    $18 = (($2) + 17|0);
    $__p$0$i$i$i$i$i$i$i$i = $18;
   } else {
    $19 = (($11) + 16)|0;
    $20 = $19 & -16;
    __THREW__ = 0;
    $21 = (invoke_ii(2988,($20|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = (($2) + 24|0);
    HEAP32[$24>>2] = $21;
    $25 = $20 | 1;
    HEAP32[$4>>2] = $25;
    $26 = (($2) + 20|0);
    HEAP32[$26>>2] = $11;
    $__p$0$i$i$i$i$i$i$i$i = $21;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($9|0),($11|0))|0;
   $27 = (($__p$0$i$i$i$i$i$i$i$i) + ($11)|0);
   HEAP8[$27>>0] = 0;
   $28 = (($2) + 28|0);
   $29 = (($__v) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$28>>2] = $30;
   HEAP32[$agg$result>>2] = $2;
   $31 = (($agg$result) + 4|0);
   $32 = $31;
   $33 = $32;
   HEAP32[$33>>2] = $3;
   $34 = (($32) + 4)|0;
   $35 = $34;
   HEAP32[$35>>2] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = ($2|0)==(0|0);
 if ($38) {
  ___resumeException($36|0);
  // unreachable;
 }
 HEAP32[$0>>2] = 1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($2|0),($$byval_copy1|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  ___cxa_call_unexpected(($41|0));
  // unreachable;
 } else {
  ___resumeException($36|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE12__move_rangeEPS1_S5_S5_($this,$__from_s,$__from_e,$__to) {
 $this = $this|0;
 $__from_s = $__from_s|0;
 $__from_e = $__from_e|0;
 $__to = $__to|0;
 var $$012$i$i = 0, $$03$i$i = 0, $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$01 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $__to;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 20)&-1;
 $7 = (($__from_s) + (($6*20)|0)|0);
 $8 = ($7>>>0)<($__from_e>>>0);
 L1: do {
  if ($8) {
   $10 = $2;$__i$01 = $7;
   while(1) {
    $9 = ($10|0)==(0|0);
    if ($9) {
     $39 = 0;
    } else {
     $11 = HEAP8[$__i$01>>0]|0;
     $12 = $11 & 1;
     $13 = ($12<<24>>24)==(0);
     if ($13) {
      $18 = (($__i$01) + 1|0);
      $19 = $11&255;
      $20 = $19 >>> 1;
      $22 = $20;$33 = $18;
     } else {
      $14 = (($__i$01) + 8|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($__i$01) + 4|0);
      $17 = HEAP32[$16>>2]|0;
      $22 = $17;$33 = $15;
     }
     $21 = ($22>>>0)>(2147483631);
     if ($21) {
      break;
     }
     $23 = ($22>>>0)<(11);
     if ($23) {
      $24 = $22 << 1;
      $25 = $24&255;
      HEAP8[$10>>0] = $25;
      $26 = (($10) + 1|0);
      $__p$0$i$i$i$i$i$i$i = $26;
     } else {
      $27 = (($22) + 16)|0;
      $28 = $27 & -16;
      HEAP32[$0>>2] = 59;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy,0,567120,79)|0);
      $30 = (($10) + 8|0);
      HEAP32[$30>>2] = $29;
      $31 = $28 | 1;
      HEAP32[$10>>2] = $31;
      $32 = (($10) + 4|0);
      HEAP32[$32>>2] = $22;
      $__p$0$i$i$i$i$i$i$i = $29;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($33|0),($22|0))|0;
     $34 = (($__p$0$i$i$i$i$i$i$i) + ($22)|0);
     HEAP8[$34>>0] = 0;
     $35 = (($10) + 12|0);
     $36 = (($__i$01) + 12|0);
     ;HEAP32[$35+0>>2]=HEAP32[$36+0>>2]|0;HEAP8[$35+4>>0]=HEAP8[$36+4>>0]|0;
     $$pre = HEAP32[$1>>2]|0;
     $39 = $$pre;
    }
    $37 = (($__i$01) + 20|0);
    $38 = (($39) + 20|0);
    HEAP32[$1>>2] = $38;
    $40 = ($37>>>0)<($__from_e>>>0);
    if ($40) {
     $10 = $38;$__i$01 = $37;
    } else {
     break L1;
    }
   }
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
 } while(0);
 $41 = ($2|0)==($__to|0);
 if ($41) {
  STACKTOP = sp;return;
 } else {
  $$012$i$i = $7;$$03$i$i = $2;
 }
 while(1) {
  $42 = (($$03$i$i) + -20|0);
  $43 = (($$012$i$i) + -20|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($42,$43)|0);
  $44 = (($$03$i$i) + -8|0);
  $45 = (($$012$i$i) + -8|0);
  ;HEAP32[$44+0>>2]=HEAP32[$45+0>>2]|0;HEAP8[$44+4>>0]=HEAP8[$45+4>>0]|0;
  $46 = ($43|0)==($__from_s|0);
  if ($46) {
   break;
  } else {
   $$012$i$i = $43;$$03$i$i = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EEPS1_($this,$__v,$__p) {
 $this = $this|0;
 $__v = $__v|0;
 $__p = $__p|0;
 var $$01$i = 0, $$01$i3 = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($__v) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==($__p|0);
 L1: do {
  if ($4) {
   $82 = $2;
  } else {
   $$01$i3 = $__p;$6 = $2;
   while(1) {
    $5 = (($6) + -20|0);
    $7 = (($$01$i3) + -20|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $15 = (($7) + 1|0);
     $16 = $8&255;
     $17 = $16 >>> 1;
     $19 = $17;$30 = $15;
    } else {
     $11 = (($$01$i3) + -12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($$01$i3) + -16|0);
     $14 = HEAP32[$13>>2]|0;
     $19 = $14;$30 = $12;
    }
    $18 = ($19>>>0)>(2147483631);
    if ($18) {
     break;
    }
    $20 = ($19>>>0)<(11);
    if ($20) {
     $21 = $19 << 1;
     $22 = $21&255;
     HEAP8[$5>>0] = $22;
     $23 = (($5) + 1|0);
     $__p$0$i$i$i$i$i$i$i$i7 = $23;
    } else {
     $24 = (($19) + 16)|0;
     $25 = $24 & -16;
     HEAP32[$0>>2] = 59;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy1,0,567120,79)|0);
     $27 = (($6) + -12|0);
     HEAP32[$27>>2] = $26;
     $28 = $25 | 1;
     HEAP32[$5>>2] = $28;
     $29 = (($6) + -16|0);
     HEAP32[$29>>2] = $19;
     $__p$0$i$i$i$i$i$i$i$i7 = $26;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i7|0),($30|0),($19|0))|0;
    $31 = (($__p$0$i$i$i$i$i$i$i$i7) + ($19)|0);
    HEAP8[$31>>0] = 0;
    $32 = (($6) + -8|0);
    $33 = (($$01$i3) + -8|0);
    ;HEAP32[$32+0>>2]=HEAP32[$33+0>>2]|0;HEAP8[$32+4>>0]=HEAP8[$33+4>>0]|0;
    $34 = HEAP32[$1>>2]|0;
    $35 = (($34) + -20|0);
    HEAP32[$1>>2] = $35;
    $36 = ($7|0)==($3|0);
    if ($36) {
     $82 = $35;
     break L1;
    } else {
     $$01$i3 = $7;$6 = $35;
    }
   }
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
 } while(0);
 $37 = (($this) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($__v) + 8|0);
 $40 = ($38|0)==($__p|0);
 if ($40) {
  $74 = $82;
  $73 = HEAP32[$this>>2]|0;
  HEAP32[$this>>2] = $74;
  HEAP32[$1>>2] = $73;
  $75 = HEAP32[$37>>2]|0;
  $76 = HEAP32[$39>>2]|0;
  HEAP32[$37>>2] = $76;
  HEAP32[$39>>2] = $75;
  $77 = (($this) + 8|0);
  $78 = (($__v) + 12|0);
  $79 = HEAP32[$77>>2]|0;
  $80 = HEAP32[$78>>2]|0;
  HEAP32[$77>>2] = $80;
  HEAP32[$78>>2] = $79;
  $81 = HEAP32[$1>>2]|0;
  HEAP32[$__v>>2] = $81;
  STACKTOP = sp;return ($2|0);
 }
 $$pre$i = HEAP32[$39>>2]|0;
 $$01$i = $__p;$42 = $$pre$i;
 while(1) {
  $41 = ($42|0)==(0|0);
  if ($41) {
   $71 = 0;
  } else {
   $43 = HEAP8[$$01$i>>0]|0;
   $44 = $43 & 1;
   $45 = ($44<<24>>24)==(0);
   if ($45) {
    $50 = (($$01$i) + 1|0);
    $51 = $43&255;
    $52 = $51 >>> 1;
    $54 = $52;$65 = $50;
   } else {
    $46 = (($$01$i) + 8|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($$01$i) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $54 = $49;$65 = $47;
   }
   $53 = ($54>>>0)>(2147483631);
   if ($53) {
    label = 19;
    break;
   }
   $55 = ($54>>>0)<(11);
   if ($55) {
    $56 = $54 << 1;
    $57 = $56&255;
    HEAP8[$42>>0] = $57;
    $58 = (($42) + 1|0);
    $__p$0$i$i$i$i$i$i$i$i = $58;
   } else {
    $59 = (($54) + 16)|0;
    $60 = $59 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $61 = (__Z15malloc_internaljj10MemLabelIdiPKci($60,16,$$byval_copy1,0,567120,79)|0);
    $62 = (($42) + 8|0);
    HEAP32[$62>>2] = $61;
    $63 = $60 | 1;
    HEAP32[$42>>2] = $63;
    $64 = (($42) + 4|0);
    HEAP32[$64>>2] = $54;
    $__p$0$i$i$i$i$i$i$i$i = $61;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($65|0),($54|0))|0;
   $66 = (($__p$0$i$i$i$i$i$i$i$i) + ($54)|0);
   HEAP8[$66>>0] = 0;
   $67 = (($42) + 12|0);
   $68 = (($$01$i) + 12|0);
   ;HEAP32[$67+0>>2]=HEAP32[$68+0>>2]|0;HEAP8[$67+4>>0]=HEAP8[$68+4>>0]|0;
   $$pre3$i = HEAP32[$39>>2]|0;
   $71 = $$pre3$i;
  }
  $69 = (($$01$i) + 20|0);
  $70 = (($71) + 20|0);
  HEAP32[$39>>2] = $70;
  $72 = ($69|0)==($38|0);
  if ($72) {
   break;
  } else {
   $$01$i = $69;$42 = $70;
  }
 }
 if ((label|0) == 19) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $$pre = HEAP32[$1>>2]|0;
 $74 = $$pre;
 $73 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $74;
 HEAP32[$1>>2] = $73;
 $75 = HEAP32[$37>>2]|0;
 $76 = HEAP32[$39>>2]|0;
 HEAP32[$37>>2] = $76;
 HEAP32[$39>>2] = $75;
 $77 = (($this) + 8|0);
 $78 = (($__v) + 12|0);
 $79 = HEAP32[$77>>2]|0;
 $80 = HEAP32[$78>>2]|0;
 HEAP32[$77>>2] = $80;
 HEAP32[$78>>2] = $79;
 $81 = HEAP32[$1>>2]|0;
 HEAP32[$__v>>2] = $81;
 STACKTOP = sp;return ($2|0);
}
function __ZNSt3__114__split_bufferI17SortingLayerEntryRNS_9allocatorIS1_EEE18__construct_at_endINS_13move_iteratorIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$byval_copy = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 8|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 while(1) {
  $5 = ($6|0)==(0|0);
  if ($5) {
   $35 = 0;$37 = $8;
  } else {
   $7 = HEAP8[$8>>0]|0;
   $9 = $7 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $15 = (($8) + 1|0);
    $16 = $7&255;
    $17 = $16 >>> 1;
    $19 = $17;$30 = $15;
   } else {
    $11 = (($8) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($8) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $19 = $14;$30 = $12;
   }
   $18 = ($19>>>0)>(2147483631);
   if ($18) {
    label = 8;
    break;
   }
   $20 = ($19>>>0)<(11);
   if ($20) {
    $21 = $19 << 1;
    $22 = $21&255;
    HEAP8[$6>>0] = $22;
    $23 = (($6) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $23;
   } else {
    $24 = (($19) + 16)|0;
    $25 = $24 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy,0,567120,79)|0);
    $27 = (($6) + 8|0);
    HEAP32[$27>>2] = $26;
    $28 = $25 | 1;
    HEAP32[$6>>2] = $28;
    $29 = (($6) + 4|0);
    HEAP32[$29>>2] = $19;
    $__p$0$i$i$i$i$i$i$i = $26;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($30|0),($19|0))|0;
   $31 = (($__p$0$i$i$i$i$i$i$i) + ($19)|0);
   HEAP8[$31>>0] = 0;
   $32 = (($6) + 12|0);
   $33 = (($8) + 12|0);
   ;HEAP32[$32+0>>2]=HEAP32[$33+0>>2]|0;HEAP8[$32+4>>0]=HEAP8[$33+4>>0]|0;
   $$pre1 = HEAP32[$4>>2]|0;
   $$pre2 = HEAP32[$__first>>2]|0;
   $35 = $$pre1;$37 = $$pre2;
  }
  $34 = (($35) + 20|0);
  HEAP32[$4>>2] = $34;
  $36 = (($37) + 20|0);
  HEAP32[$__first>>2] = $36;
  $38 = ($36|0)==($2|0);
  if ($38) {
   label = 14;
   break;
  } else {
   $6 = $34;$8 = $36;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZN10TagManagerD2Ev($this) {
 $this = $this|0;
 var $$byval_copy18 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i5 = 0, $$pre$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i14$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy18 = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((567008 + 8|0));
 __THREW__ = 0;
 invoke_vi(3393,($this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($this) + 424|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($this) + 428|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($4|0);
   do {
    if ($8) {
     $22 = $4;
    } else {
     $10 = $7;
     while(1) {
      $9 = (($10) + -20|0);
      HEAP32[$6>>2] = $9;
      $11 = HEAP8[$9>>0]|0;
      $12 = $11 & 1;
      $13 = ($12<<24>>24)==(0);
      if ($13) {
       $15 = $9;
      } else {
       $16 = (($10) + -12|0);
       $17 = HEAP32[$16>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($17|0),($$byval_copy18|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        label = 9;
        break;
       }
       $$pre$i$i$i$i$i = HEAP32[$6>>2]|0;
       $15 = $$pre$i$i$i$i$i;
      }
      $14 = ($15|0)==($4|0);
      if ($14) {
       label = 10;
       break;
      } else {
       $10 = $15;
      }
     }
     if ((label|0) == 9) {
      $20 = ___cxa_find_matching_catch()|0;
      $21 = tempRet0;
      ___cxa_call_unexpected(($20|0));
      // unreachable;
     }
     else if ((label|0) == 10) {
      $$pre$i$i$i = HEAP32[$3>>2]|0;
      $22 = $$pre$i$i$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($22);
  }
  $23 = (($this) + 40|0);
  $24 = (($this) + 424|0);
  $26 = $24;
  while(1) {
   $25 = (($26) + -12|0);
   $27 = HEAP8[$25>>0]|0;
   $28 = $27 & 1;
   $29 = ($28<<24>>24)==(0);
   if (!($29)) {
    $30 = (($26) + -4|0);
    $31 = HEAP32[$30>>2]|0;
    __ZdlPv($31);
   }
   $32 = ($25|0)==($23|0);
   if ($32) {
    break;
   } else {
    $26 = $25;
   }
  }
  HEAP32[$this>>2] = ((561192 + 8|0));
  __THREW__ = 0;
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if (!($34)) {
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    STACKTOP = sp;return;
   }
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   __THREW__ = 0;
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $41 = ___cxa_find_matching_catch(0|0)|0;
    $42 = tempRet0;
    ___clang_call_terminate($41);
    // unreachable;
   } else {
    ___resumeException($37|0);
    // unreachable;
   }
  }
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $49 = ___cxa_find_matching_catch(0|0)|0;
   $50 = tempRet0;
   __THREW__ = 0;
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    $53 = ___cxa_find_matching_catch(0|0)|0;
    $54 = tempRet0;
    ___clang_call_terminate($53);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $49;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $47 = __THREW__; __THREW__ = 0;
  $48 = $47&1;
  if (!($48)) {
   ___resumeException($43|0);
   // unreachable;
  }
  $55 = ___cxa_find_matching_catch(0|0)|0;
  $56 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $55;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 }
 $57 = ___cxa_find_matching_catch()|0;
 $58 = tempRet0;
 $59 = (($this) + 424|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0|0);
 if (!($61)) {
  $62 = (($this) + 428|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($63|0)==($60|0);
  do {
   if ($64) {
    $78 = $60;
   } else {
    $66 = $63;
    while(1) {
     $65 = (($66) + -20|0);
     HEAP32[$62>>2] = $65;
     $67 = HEAP8[$65>>0]|0;
     $68 = $67 & 1;
     $69 = ($68<<24>>24)==(0);
     if ($69) {
      $71 = $65;
     } else {
      $72 = (($66) + -12|0);
      $73 = HEAP32[$72>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($73|0),($$byval_copy18|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 36;
       break;
      }
      $$pre$i$i$i$i$i5 = HEAP32[$62>>2]|0;
      $71 = $$pre$i$i$i$i$i5;
     }
     $70 = ($71|0)==($60|0);
     if ($70) {
      label = 37;
      break;
     } else {
      $66 = $71;
     }
    }
    if ((label|0) == 36) {
     $76 = ___cxa_find_matching_catch()|0;
     $77 = tempRet0;
     ___cxa_call_unexpected(($76|0));
     // unreachable;
    }
    else if ((label|0) == 37) {
     $$pre$i$i$i7 = HEAP32[$59>>2]|0;
     $78 = $$pre$i$i$i7;
     break;
    }
   }
  } while(0);
  __ZdlPv($78);
 }
 $79 = (($this) + 40|0);
 $80 = (($this) + 424|0);
 $82 = $80;
 while(1) {
  $81 = (($82) + -12|0);
  $83 = HEAP8[$81>>0]|0;
  $84 = $83 & 1;
  $85 = ($84<<24>>24)==(0);
  if (!($85)) {
   $86 = (($82) + -4|0);
   $87 = HEAP32[$86>>2]|0;
   __ZdlPv($87);
  }
  $88 = ($81|0)==($79|0);
  if ($88) {
   break;
  } else {
   $82 = $81;
  }
 }
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $101 = ___cxa_find_matching_catch(0|0)|0;
  $102 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $103 = __THREW__; __THREW__ = 0;
  $104 = $103&1;
  if ($104) {
   $107 = ___cxa_find_matching_catch(0|0)|0;
   $108 = tempRet0;
   __THREW__ = 0;
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    $111 = ___cxa_find_matching_catch(0|0)|0;
    $112 = tempRet0;
    ___clang_call_terminate($111);
    // unreachable;
   } else {
    $eh$lpad$body$i14$indexZ2D = $107;
    ___clang_call_terminate($eh$lpad$body$i14$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if (!($106)) {
   $eh$lpad$body$indexZ2D = $101;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
  $113 = ___cxa_find_matching_catch(0|0)|0;
  $114 = tempRet0;
  $eh$lpad$body$i14$indexZ2D = $113;
  ___clang_call_terminate($eh$lpad$body$i14$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $91 = __THREW__; __THREW__ = 0;
  $92 = $91&1;
  if ($92) {
   $93 = ___cxa_find_matching_catch(0|0)|0;
   $94 = tempRet0;
   __THREW__ = 0;
   $95 = __THREW__; __THREW__ = 0;
   $96 = $95&1;
   if ($96) {
    $97 = ___cxa_find_matching_catch(0|0)|0;
    $98 = tempRet0;
    ___clang_call_terminate($97);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $93;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $99 = __THREW__; __THREW__ = 0;
  $100 = $99&1;
  if (!($100)) {
   ___resumeException($57|0);
   // unreachable;
  }
  $115 = ___cxa_find_matching_catch(0|0)|0;
  $116 = tempRet0;
  $eh$lpad$body$indexZ2D = $115;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($this,$__str) {
 $this = $this|0;
 $__str = $__str|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==($__str|0);
 if ($0) {
  STACKTOP = sp;return ($this|0);
 }
 $1 = HEAP8[$__str>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $8 = (($__str) + 1|0);
  $9 = $1&255;
  $10 = $9 >>> 1;
  $19 = $10;$27 = $8;
 } else {
  $4 = (($__str) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($__str) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $19 = $7;$27 = $5;
 }
 $11 = HEAP8[$this>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $18 = 10;$21 = $11;
 } else {
  $14 = HEAP32[$this>>2]|0;
  $15 = $14 & -2;
  $phitmp$i$i$i = (($15) + -1)|0;
  $16 = $14&255;
  $18 = $phitmp$i$i$i;$21 = $16;
 }
 $17 = ($18>>>0)<($19>>>0);
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($17) {
  if ($22) {
   $37 = $21&255;
   $38 = $37 >>> 1;
   $40 = $38;
  } else {
   $35 = (($this) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $40 = $36;
  }
  $39 = (($19) - ($18))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$18,$39,$40,0,$40,$19,$27);
  STACKTOP = sp;return ($this|0);
 }
 if ($22) {
  $25 = (($this) + 1|0);
  $26 = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $26 = $24;
 }
 _memmove(($26|0),($27|0),($19|0))|0;
 $28 = (($26) + ($19)|0);
 HEAP8[$28>>0] = 0;
 $29 = HEAP8[$this>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $33 = $19 << 1;
  $34 = $33&255;
  HEAP8[$this>>0] = $34;
  STACKTOP = sp;return ($this|0);
 } else {
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $19;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZN10GUIElement7HitTestERK8Vector2fRK5RectTIfE($this,$screenSpacePosition,$cameraRect) {
 $this = $this|0;
 $screenSpacePosition = $screenSpacePosition|0;
 $cameraRect = $cameraRect|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0);
 var $rect = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $rect = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($rect,$this,$cameraRect);
 $3 = Math_fround(HEAPF32[$screenSpacePosition>>2]);
 $4 = (($screenSpacePosition) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$rect>>2]);
 $7 = !($6 <= $3);
 if ($7) {
  $19 = 0;
  STACKTOP = sp;return ($19|0);
 }
 $8 = (($rect) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($6 + $9);
 $11 = $10 > $3;
 if (!($11)) {
  $19 = 0;
  STACKTOP = sp;return ($19|0);
 }
 $12 = (($rect) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = !($13 <= $5);
 if ($14) {
  $19 = 0;
  STACKTOP = sp;return ($19|0);
 }
 $15 = (($rect) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($13 + $16);
 $18 = $17 > $5;
 $19 = $18;
 STACKTOP = sp;return ($19|0);
}
function __ZN9Behaviour6UpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Behaviour11FixedUpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Behaviour10LateUpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN5Unity9ComponentD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((562072 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   STACKTOP = sp;return;
  }
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __THREW__ = 0;
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   ___resumeException($4|0);
   // unreachable;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 HEAP32[$this>>2] = ((560936 + 8|0));
 __THREW__ = 0;
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$indexZ2D = $16;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  ___resumeException($10|0);
  // unreachable;
 }
 $22 = ___cxa_find_matching_catch(0|0)|0;
 $23 = tempRet0;
 $eh$lpad$body$indexZ2D = $22;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN9BehaviourD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((589992 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __ZN5Unity9ComponentD2Ev($this);
  STACKTOP = sp;return;
 }
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3394,($this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch(0|0)|0;
  $7 = tempRet0;
  ___clang_call_terminate($6);
  // unreachable;
 } else {
  ___resumeException($2|0);
  // unreachable;
 }
}
function __ZN9BehaviourD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i5$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body2$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((589992 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  HEAP32[$this>>2] = ((562072 + 8|0));
  __THREW__ = 0;
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $16 = ___cxa_find_matching_catch(0|0)|0;
   $17 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $22 = ___cxa_find_matching_catch(0|0)|0;
    $23 = tempRet0;
    __THREW__ = 0;
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     $26 = ___cxa_find_matching_catch(0|0)|0;
     $27 = tempRet0;
     ___clang_call_terminate($26);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $22;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $eh$lpad$body2$indexZ2D = $16;
    ___clang_call_terminate($eh$lpad$body2$indexZ2D);
    // unreachable;
   }
   $28 = ___cxa_find_matching_catch(0|0)|0;
   $29 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $28;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  } else {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $8 = ___cxa_find_matching_catch(0|0)|0;
    $9 = tempRet0;
    __THREW__ = 0;
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     $12 = ___cxa_find_matching_catch(0|0)|0;
     $13 = tempRet0;
     ___clang_call_terminate($12);
     // unreachable;
    } else {
     $eh$lpad$body2$indexZ2D = $8;
     ___clang_call_terminate($eh$lpad$body2$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $eh$lpad$body$index21Z2D = $3;$eh$lpad$body$indexZ2D = $2;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $30 = ___cxa_find_matching_catch(0|0)|0;
   $31 = tempRet0;
   $eh$lpad$body2$indexZ2D = $30;
   ___clang_call_terminate($eh$lpad$body2$indexZ2D);
   // unreachable;
  }
 } else {
  HEAP32[$this>>2] = ((562072 + 8|0));
  __THREW__ = 0;
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $50 = ___cxa_find_matching_catch(0|0)|0;
    $51 = tempRet0;
    __THREW__ = 0;
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch(0|0)|0;
     $55 = tempRet0;
     ___clang_call_terminate($54);
     // unreachable;
    } else {
     $eh$lpad$body$i5$indexZ2D = $50;
     ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    $eh$lpad$body$index21Z2D = $45;$eh$lpad$body$indexZ2D = $44;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $56 = ___cxa_find_matching_catch(0|0)|0;
   $57 = tempRet0;
   $eh$lpad$body$i5$indexZ2D = $56;
   ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
   // unreachable;
  } else {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $36 = ___cxa_find_matching_catch()|0;
    $37 = tempRet0;
    __THREW__ = 0;
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     $40 = ___cxa_find_matching_catch(0|0)|0;
     $41 = tempRet0;
     ___clang_call_terminate($40);
     // unreachable;
    } else {
     $eh$lpad$body$index21Z2D = $37;$eh$lpad$body$indexZ2D = $36;
     __ZdlPv($this);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    __ZdlPv($this);
    STACKTOP = sp;return;
   }
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $eh$lpad$body$index21Z2D = $59;$eh$lpad$body$indexZ2D = $58;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
}
function __ZN8GUILayer15InitializeClassEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(24)|0);
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$0>>2] = $1;
 $3 = (($0) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($0) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($0) + 20|0);
 HEAP32[$5>>2] = 0;
 HEAP32[567608>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN8GUILayer12CleanupClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last1$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep2$i$i$i$i$i$i$i = 0, $scevgep23$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[567608>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($0) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $__new_last1$i$i$i$i$i$i$i = $3;
   $scevgep$i$i$i$i$i$i$i = (($6) + -8|0);
   $8 = (0 - ($__new_last1$i$i$i$i$i$i$i))|0;
   $scevgep2$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($8)|0);
   $scevgep23$i$i$i$i$i$i$i = $scevgep2$i$i$i$i$i$i$i;
   $9 = $scevgep23$i$i$i$i$i$i$i >>> 3;
   $10 = $9 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($6) + ($10<<3)|0);
   HEAP32[$5>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 $11 = (($0) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$12);
 __ZdlPv($0);
 STACKTOP = sp;return;
}
function __ZN8GUILayer14RenderGUILayerEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $cameraRect = 0, $elements = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy8 = sp + 48|0;
 $$byval_copy = sp + 12|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 16|0;
 $elements = sp + 20|0;
 $cameraRect = sp + 32|0;
 $3 = HEAP32[567608>>2]|0;
 __ZN11delayed_setI4PPtrI10GUIElementENSt3__13setIS2_NS3_4lessIS2_EE11memory_poolIS2_EEEE13apply_delayedEv($3);
 $4 = HEAP32[567608>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$4>>2]|0;
 $9 = (($4) + 4|0);
 HEAP32[$1>>2] = $8;
 HEAP32[$0>>2] = $9;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 __ZNSt3__16vectorIP10GUIElement13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEC2INS_21__tree_const_iteratorI4PPtrIS1_EPNS_11__tree_nodeISA_PvEEiEEEET_NS_9enable_ifIXaasr21__is_forward_iteratorISG_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISG_E9referenceEEE5valueESG_E4typeE($elements,$$byval_copy,$$byval_copy8);
 $10 = HEAP32[$elements>>2]|0;
 $11 = (($elements) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$$byval_copy>>2] = 2362;
 __THREW__ = 0;
 invoke_viii(1655,($10|0),($12|0),($$byval_copy|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 L4: do {
  if ($14) {
   label = 9;
  } else {
   $15 = (($this) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   $17 = (invoke_iii(2363,($16|0),20)|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    label = 9;
   } else {
    $20 = (($17) + 412|0);
    $21 = HEAP32[$20>>2]|0;
    __THREW__ = 0;
    invoke_viii(1656,($cameraRect|0),($17|0),1);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 9;
    } else {
     $24 = ($10|0)==($12|0);
     L8: do {
      if (!($24)) {
       $26 = $10;
       while(1) {
        $25 = HEAP32[$26>>2]|0;
        $27 = (($25) + 24|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($28) + 40|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = 1 << $30;
        $32 = $31 & $21;
        $33 = ($32|0)==(0);
        if (!($33)) {
         $34 = HEAP32[$25>>2]|0;
         $35 = (($34) + 132|0);
         $36 = HEAP32[$35>>2]|0;
         __THREW__ = 0;
         invoke_vii($36|0,($25|0),($cameraRect|0));
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break;
         }
        }
        $52 = (($26) + 4|0);
        $53 = ($52|0)==($12|0);
        if ($53) {
         break L8;
        } else {
         $26 = $52;
        }
       }
       $39 = ___cxa_find_matching_catch()|0;
       $40 = tempRet0;
       $lpad$phi$index = $39;$lpad$phi$index2 = $40;
       break L4;
      }
     } while(0);
     $54 = ($10|0)==(0|0);
     if ($54) {
      STACKTOP = sp;return;
     }
     if (!($24)) {
      $__new_last2$i$i$i$i$i = $10;
      $scevgep$i$i$i$i$i = (($12) + -4|0);
      $55 = (0 - ($__new_last2$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($55)|0);
      $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
      $56 = $uglygep3$i$i$i$i$i >>> 2;
      $57 = $56 ^ -1;
      $scevgep4$i$i$i$i$i = (($12) + ($57<<2)|0);
      HEAP32[$11>>2] = $scevgep4$i$i$i$i$i;
     }
     HEAP32[$$byval_copy>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
     invoke_vii(2591,($10|0),($$byval_copy8|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      $60 = ___cxa_find_matching_catch()|0;
      $61 = tempRet0;
      ___cxa_call_unexpected(($60|0));
      // unreachable;
     } else {
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  $lpad$phi$index = $41;$lpad$phi$index2 = $42;
 }
 $43 = ($10|0)==(0|0);
 if ($43) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $44 = ($12|0)==($10|0);
 if (!($44)) {
  $__new_last2$i$i$i$i$i1 = $10;
  $scevgep$i$i$i$i$i2 = (($12) + -4|0);
  $45 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($45)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $46 = $uglygep3$i$i$i$i$i5 >>> 2;
  $47 = $46 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($12) + ($47<<2)|0);
  HEAP32[$11>>2] = $scevgep4$i$i$i$i$i6;
 }
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($10|0),($$byval_copy8|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  ___cxa_call_unexpected(($50|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN11delayed_setI4PPtrI10GUIElementENSt3__13setIS2_NS3_4lessIS2_EE11memory_poolIS2_EEEE13apply_delayedEv($this) {
 $this = $this|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__new_last1$i$i$i = 0, $scevgep2$i$i$i = 0, $scevgep23$i$i$i = 0, $scevgep4$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 4|0);
 $8 = (($this) + 4|0);
 $10 = $3;
 while(1) {
  $9 = HEAP8[$10>>0]|0;
  $11 = ($9<<24>>24)==(0);
  $12 = (($10) + 4|0);
  if ($11) {
   $13 = HEAP32[$7>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    $15 = HEAP32[$12>>2]|0;
    $$0$ph7$i$i$i$i = $8;$$01$ph6$i$in$i$i$i = $13;
    L10: while(1) {
     $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
     while(1) {
      $16 = (($$013$i$in$i$i$i) + 16|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17|0)<($15|0);
      if (!($18)) {
       break;
      }
      $21 = (($$013$i$in$i$i$i) + 4|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22|0)==(0|0);
      if ($23) {
       $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
       break L10;
      } else {
       $$013$i$in$i$i$i = $22;
      }
     }
     $19 = HEAP32[$$013$i$in$i$i$i>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
      break;
     } else {
      $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $19;
     }
    }
    $24 = ($$0$ph5$i$i$i$i|0)==($8|0);
    if (!($24)) {
     $25 = (($$0$ph5$i$i$i$i) + 16|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($15|0)<($26|0);
     if (!($27)) {
      HEAP32[$0>>2] = $$0$ph5$i$i$i$i;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE5eraseENS_21__tree_const_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEE($1,$this,$$byval_copy);
     }
    }
   }
  } else {
   __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE15__insert_uniqueERKS3_($$byval_copy,$this,$12);
  }
  $28 = (($10) + 8|0);
  $29 = HEAP32[$4>>2]|0;
  $30 = ($28|0)==($29|0);
  if ($30) {
   break;
  } else {
   $10 = $28;
  }
 }
 $$pre = HEAP32[$2>>2]|0;
 $31 = ($28|0)==($$pre|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $__new_last1$i$i$i = $$pre;
 $32 = (0 - ($__new_last1$i$i$i))|0;
 $scevgep2$i$i$i = (($10) + ($32)|0);
 $scevgep23$i$i$i = $scevgep2$i$i$i;
 $33 = $scevgep23$i$i$i >>> 3;
 $$sum = (0 - ($33))|0;
 $scevgep4$i$i$i = (($10) + ($$sum<<3)|0);
 HEAP32[$4>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __Z14SortGUIByDepthP10GUIElementS0_($lhs,$rhs) {
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($lhs) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($1)|0);
 $3 = (($2) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($rhs) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($6)|0);
 $8 = (($7) + 52|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = $4 < $9;
 STACKTOP = sp;return ($10|0);
}
function __ZN8GUILayer7HitTestERK8Vector2f($this,$screenPosition) {
 $this = $this|0;
 $screenPosition = $screenPosition|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0;
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $cameraRect = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond1 = 0, $or$cond1$not = 0, $or$cond2 = 0, $pos$i$i$i$i = 0, $temp$0$i7 = 0, $topmost$05 = 0, $topmost$1 = 0, $topmostZ$04 = Math_fround(0), $topmostZ$1 = Math_fround(0), $viewportPos = 0, $viewportPos3D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i$i = sp + 56|0;
 $0 = sp;
 $viewportPos3D = sp + 4|0;
 $1 = sp + 16|0;
 $viewportPos = sp + 32|0;
 $cameraRect = sp + 40|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($3,20)|0);
 $5 = Math_fround(HEAPF32[$screenPosition>>2]);
 $6 = (($screenPosition) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($4) + 456|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$1>>2] = $5;
 $10 = (($1) + 4|0);
 HEAPF32[$10>>2] = $7;
 $11 = (($1) + 8|0);
 HEAPF32[$11>>2] = $9;
 __ZNK6Camera21ScreenToViewportPointERK8Vector3f($viewportPos3D,$4,$1);
 $12 = Math_fround(HEAPF32[$viewportPos3D>>2]);
 $13 = (($viewportPos3D) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$viewportPos>>2] = $12;
 $15 = (($viewportPos) + 4|0);
 HEAPF32[$15>>2] = $14;
 $notlhs = !($12 >= Math_fround(0.0));
 $notrhs = !($12 < Math_fround(1.0));
 $or$cond$not = $notrhs | $notlhs;
 $16 = !($14 >= Math_fround(0.0));
 $or$cond1 = $or$cond$not | $16;
 $or$cond1$not = $or$cond1 ^ 1;
 $17 = $14 < Math_fround(1.0);
 $or$cond2 = $17 & $or$cond1$not;
 if (!($or$cond2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZNK6Camera13GetCameraRectEb($cameraRect,$4,1);
 $18 = (__Z16GetRenderManagerv()|0);
 $19 = (($18) + 64|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($18) + 68|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround(HEAPF32[$viewportPos>>2]);
 $24 = Math_fround($20 * $23);
 HEAPF32[$viewportPos>>2] = $24;
 $25 = Math_fround(HEAPF32[$15>>2]);
 $26 = Math_fround($22 * $25);
 HEAPF32[$15>>2] = $26;
 $27 = (($4) + 412|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 & -5;
 $30 = HEAP32[567608>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($30) + 4|0);
 $33 = ($31|0)==($32|0);
 if ($33) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $35 = $31;$topmost$05 = 0;$topmostZ$04 = Math_fround(-inf);
 while(1) {
  $34 = (($35) + 16|0);
  $36 = HEAP32[$34>>2]|0;
  $37 = ($36|0)==(0);
  do {
   if ($37) {
    $topmost$1 = $topmost$05;$topmostZ$1 = $topmostZ$04;
   } else {
    HEAP32[$0>>2] = $36;
    $38 = HEAP32[560624>>2]|0;
    $39 = ($38|0)==(0|0);
    if ($39) {
     label = 14;
    } else {
     $40 = (($38) + 36|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($38) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($41|0)==($43|0);
     do {
      if ($44) {
       $45 = (($38) + 28|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = (($38) + 32|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = (($46) + ($48<<3)|0);
       $65 = $49;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$38,$0);
       $50 = HEAP32[$pos$i$i$i$i>>2]|0;
       $51 = ($50|0)==(-1);
       $52 = (($38) + 28|0);
       $53 = HEAP32[$52>>2]|0;
       if ($51) {
        $54 = (($38) + 32|0);
        $55 = HEAP32[$54>>2]|0;
        $56 = (($53) + ($55<<3)|0);
        $65 = $56;
        break;
       } else {
        $57 = (($53) + ($50<<3)|0);
        $65 = $57;
        break;
       }
      }
     } while(0);
     $58 = HEAP32[560624>>2]|0;
     $59 = (($58) + 28|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (($58) + 32|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($60) + ($62<<3)|0);
     $64 = ($65|0)==($63|0);
     if ($64) {
      label = 14;
     } else {
      $66 = (($65) + 4|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       label = 14;
      } else {
       $$in = $67;$temp$0$i7 = $67;
      }
     }
    }
    if ((label|0) == 14) {
     label = 0;
     $69 = HEAP32[$34>>2]|0;
     $70 = (__Z31ReadObjectFromPersistentManageri($69)|0);
     $71 = ($70|0)==(0|0);
     if ($71) {
      $topmost$1 = $topmost$05;$topmostZ$1 = $topmostZ$04;
      break;
     } else {
      $$in = $70;$temp$0$i7 = $70;
     }
    }
    $72 = (($temp$0$i7) + 24|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($73) + 40|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = 1 << $75;
    $77 = $29 & $76;
    $78 = ($77|0)==(0);
    if ($78) {
     $topmost$1 = $topmost$05;$topmostZ$1 = $topmostZ$04;
    } else {
     $79 = (__ZN10GUIElement7HitTestERK8Vector2fRK5RectTIfE($$in,$viewportPos,$cameraRect)|0);
     if ($79) {
      $80 = HEAP32[$72>>2]|0;
      $81 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($80)|0);
      $82 = (($81) + 52|0);
      $83 = Math_fround(HEAPF32[$82>>2]);
      $84 = $83 > $topmostZ$04;
      if ($84) {
       $topmost$1 = $$in;$topmostZ$1 = $83;
      } else {
       $topmost$1 = $topmost$05;$topmostZ$1 = $topmostZ$04;
      }
     } else {
      $topmost$1 = $topmost$05;$topmostZ$1 = $topmostZ$04;
     }
    }
   }
  } while(0);
  $85 = (($35) + 4|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($86|0)==(0|0);
  if ($87) {
   $$01$i$i = $35;
   while(1) {
    $90 = (($$01$i$i) + 8|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==($$01$i$i|0);
    if ($93) {
     $$0$i$i = $91;
     break;
    } else {
     $$01$i$i = $91;
    }
   }
  } else {
   $$0$i$i$i = $86;
   while(1) {
    $88 = HEAP32[$$0$i$i$i>>2]|0;
    $89 = ($88|0)==(0|0);
    if ($89) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $88;
    }
   }
  }
  $94 = ($$0$i$i|0)==($32|0);
  if ($94) {
   $$0 = $topmost$1;
   break;
  } else {
   $35 = $$0$i$i;$topmost$05 = $topmost$1;$topmostZ$04 = $topmostZ$1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z22RegisterClass_GUILayerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(92,86,87,0,88);
 STACKTOP = sp;return;
}
function __ZN8GUILayer13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 HEAP8[$0>>0] = 16;
 $3 = (($0) + 1|0);
 $4 = $3;
 $5 = $4;
 HEAP8[$5>>0]=1279874375&255;HEAP8[$5+1>>0]=(1279874375>>8)&255;HEAP8[$5+2>>0]=(1279874375>>16)&255;HEAP8[$5+3>>0]=1279874375>>24;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP8[$7>>0]=1919252833&255;HEAP8[$7+1>>0]=(1919252833>>8)&255;HEAP8[$7+2>>0]=(1919252833>>16)&255;HEAP8[$7+3>>0]=1919252833>>24;
 $8 = (($0) + 9|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,92,8,($0|0),32,(2364|0),0,0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return;
 }
}
function __ZN8GUILayer7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(32,$$byval_copy2,1,16,567760,13)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = (($3) + 28|0);
  HEAP8[$6>>0] = 1;
  $7 = (($3) + 29|0);
  HEAP8[$7>>0] = 0;
  HEAP32[$3>>2] = ((567616 + 8|0));
  STACKTOP = sp;return ($3|0);
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(567760|0),13);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($8|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK8GUILayer25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 92;
}
function __ZN8GUILayerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((589992 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __ZN5Unity9ComponentD2Ev($this);
  STACKTOP = sp;return;
 }
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3394,($this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch(0|0)|0;
  $7 = tempRet0;
  ___clang_call_terminate($6);
  // unreachable;
 } else {
  ___resumeException($2|0);
  // unreachable;
 }
}
function __ZN8GUILayerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i5$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body8$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((589992 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  HEAP32[$this>>2] = ((562072 + 8|0));
  __THREW__ = 0;
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $16 = ___cxa_find_matching_catch(0|0)|0;
   $17 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $22 = ___cxa_find_matching_catch(0|0)|0;
    $23 = tempRet0;
    __THREW__ = 0;
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     $26 = ___cxa_find_matching_catch(0|0)|0;
     $27 = tempRet0;
     ___clang_call_terminate($26);
     // unreachable;
    } else {
     $eh$lpad$body$i5$indexZ2D = $22;
     ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $eh$lpad$body8$indexZ2D = $16;
    ___clang_call_terminate($eh$lpad$body8$indexZ2D);
    // unreachable;
   }
   $28 = ___cxa_find_matching_catch(0|0)|0;
   $29 = tempRet0;
   $eh$lpad$body$i5$indexZ2D = $28;
   ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
   // unreachable;
  } else {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $8 = ___cxa_find_matching_catch(0|0)|0;
    $9 = tempRet0;
    __THREW__ = 0;
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     $12 = ___cxa_find_matching_catch(0|0)|0;
     $13 = tempRet0;
     ___clang_call_terminate($12);
     // unreachable;
    } else {
     $eh$lpad$body8$indexZ2D = $8;
     ___clang_call_terminate($eh$lpad$body8$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $eh$lpad$body$index21Z2D = $3;$eh$lpad$body$indexZ2D = $2;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $30 = ___cxa_find_matching_catch(0|0)|0;
   $31 = tempRet0;
   $eh$lpad$body8$indexZ2D = $30;
   ___clang_call_terminate($eh$lpad$body8$indexZ2D);
   // unreachable;
  }
 } else {
  HEAP32[$this>>2] = ((562072 + 8|0));
  __THREW__ = 0;
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $50 = ___cxa_find_matching_catch(0|0)|0;
    $51 = tempRet0;
    __THREW__ = 0;
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch(0|0)|0;
     $55 = tempRet0;
     ___clang_call_terminate($54);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $50;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    $eh$lpad$body$index21Z2D = $45;$eh$lpad$body$indexZ2D = $44;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $56 = ___cxa_find_matching_catch(0|0)|0;
   $57 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $56;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  } else {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $36 = ___cxa_find_matching_catch()|0;
    $37 = tempRet0;
    __THREW__ = 0;
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     $40 = ___cxa_find_matching_catch(0|0)|0;
     $41 = tempRet0;
     ___clang_call_terminate($40);
     // unreachable;
    } else {
     $eh$lpad$body$index21Z2D = $37;$eh$lpad$body$indexZ2D = $36;
     __ZdlPv($this);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    __ZdlPv($this);
    STACKTOP = sp;return;
   }
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $eh$lpad$body$index21Z2D = $59;$eh$lpad$body$indexZ2D = $58;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
}
function __ZN8GUILayer12AddToManagerEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN8GUILayer17RemoveFromManagerEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRPFbP10GUIElementS2_EPS2_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$09 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0;
 var $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 2;
   switch ($4|0) {
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 70;
    break L1;
    break;
   }
   default: {
   }
   }
   $63 = ($3|0)<(124);
   if ($63) {
    label = 21;
    break L1;
   }
   $64 = ($3|0)>(3996);
   $65 = (($4|0) / 2)&-1;
   $66 = (($$0) + ($65<<2)|0);
   do {
    if ($64) {
     $67 = (($4|0) / 4)&-1;
     $68 = (($$0) + ($67<<2)|0);
     $$sum = (($67) + ($65))|0;
     $69 = (($$0) + ($$sum<<2)|0);
     $70 = (__ZNSt3__17__sort4IRPFbP10GUIElementS2_EPS2_EEjT0_S7_S7_S7_T_($$0,$68,$66,$69,$__comp)|0);
     $71 = HEAP32[$__comp>>2]|0;
     $72 = HEAP32[$1>>2]|0;
     $73 = HEAP32[$69>>2]|0;
     $74 = (FUNCTION_TABLE_iii[$71 & 4095]($72,$73)|0);
     if ($74) {
      $75 = HEAP32[$69>>2]|0;
      $76 = HEAP32[$1>>2]|0;
      HEAP32[$69>>2] = $76;
      HEAP32[$1>>2] = $75;
      $77 = HEAP32[$__comp>>2]|0;
      $78 = HEAP32[$69>>2]|0;
      $79 = HEAP32[$66>>2]|0;
      $80 = (FUNCTION_TABLE_iii[$77 & 4095]($78,$79)|0);
      if (!($80)) {
       $81 = (($70) + 1)|0;
       $__n_swaps$0 = $81;
       break;
      }
      $82 = HEAP32[$66>>2]|0;
      $83 = HEAP32[$69>>2]|0;
      HEAP32[$66>>2] = $83;
      HEAP32[$69>>2] = $82;
      $84 = HEAP32[$__comp>>2]|0;
      $85 = HEAP32[$66>>2]|0;
      $86 = HEAP32[$68>>2]|0;
      $87 = (FUNCTION_TABLE_iii[$84 & 4095]($85,$86)|0);
      if (!($87)) {
       $88 = (($70) + 2)|0;
       $__n_swaps$0 = $88;
       break;
      }
      $89 = HEAP32[$68>>2]|0;
      $90 = HEAP32[$66>>2]|0;
      HEAP32[$68>>2] = $90;
      HEAP32[$66>>2] = $89;
      $91 = HEAP32[$__comp>>2]|0;
      $92 = HEAP32[$68>>2]|0;
      $93 = HEAP32[$$0>>2]|0;
      $94 = (FUNCTION_TABLE_iii[$91 & 4095]($92,$93)|0);
      if ($94) {
       $96 = HEAP32[$$0>>2]|0;
       $97 = HEAP32[$68>>2]|0;
       HEAP32[$$0>>2] = $97;
       HEAP32[$68>>2] = $96;
       $98 = (($70) + 4)|0;
       $__n_swaps$0 = $98;
       break;
      } else {
       $95 = (($70) + 3)|0;
       $__n_swaps$0 = $95;
       break;
      }
     } else {
      $__n_swaps$0 = $70;
     }
    } else {
     $99 = HEAP32[$__comp>>2]|0;
     $100 = HEAP32[$66>>2]|0;
     $101 = HEAP32[$$0>>2]|0;
     $102 = (FUNCTION_TABLE_iii[$99 & 4095]($100,$101)|0);
     $103 = HEAP32[$__comp>>2]|0;
     $104 = HEAP32[$1>>2]|0;
     $105 = HEAP32[$66>>2]|0;
     $106 = (FUNCTION_TABLE_iii[$103 & 4095]($104,$105)|0);
     if (!($102)) {
      if (!($106)) {
       $__n_swaps$0 = 0;
       break;
      }
      $107 = HEAP32[$66>>2]|0;
      $108 = HEAP32[$1>>2]|0;
      HEAP32[$66>>2] = $108;
      HEAP32[$1>>2] = $107;
      $109 = HEAP32[$__comp>>2]|0;
      $110 = HEAP32[$66>>2]|0;
      $111 = HEAP32[$$0>>2]|0;
      $112 = (FUNCTION_TABLE_iii[$109 & 4095]($110,$111)|0);
      if (!($112)) {
       $__n_swaps$0 = 1;
       break;
      }
      $113 = HEAP32[$$0>>2]|0;
      $114 = HEAP32[$66>>2]|0;
      HEAP32[$$0>>2] = $114;
      HEAP32[$66>>2] = $113;
      $__n_swaps$0 = 2;
      break;
     }
     $115 = HEAP32[$$0>>2]|0;
     if ($106) {
      $116 = HEAP32[$1>>2]|0;
      HEAP32[$$0>>2] = $116;
      HEAP32[$1>>2] = $115;
      $__n_swaps$0 = 1;
      break;
     }
     $117 = HEAP32[$66>>2]|0;
     HEAP32[$$0>>2] = $117;
     HEAP32[$66>>2] = $115;
     $118 = HEAP32[$__comp>>2]|0;
     $119 = HEAP32[$1>>2]|0;
     $120 = (FUNCTION_TABLE_iii[$118 & 4095]($119,$115)|0);
     if ($120) {
      $121 = HEAP32[$66>>2]|0;
      $122 = HEAP32[$1>>2]|0;
      HEAP32[$66>>2] = $122;
      HEAP32[$1>>2] = $121;
      $__n_swaps$0 = 2;
     } else {
      $__n_swaps$0 = 1;
     }
    }
   } while(0);
   $123 = HEAP32[$__comp>>2]|0;
   $124 = HEAP32[$$0>>2]|0;
   $125 = HEAP32[$66>>2]|0;
   $126 = (FUNCTION_TABLE_iii[$123 & 4095]($124,$125)|0);
   do {
    if ($126) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $127 = (($__j$0) + -4|0);
      $128 = ($$0|0)==($127|0);
      if ($128) {
       break;
      }
      $157 = HEAP32[$__comp>>2]|0;
      $158 = HEAP32[$127>>2]|0;
      $159 = HEAP32[$66>>2]|0;
      $160 = (FUNCTION_TABLE_iii[$157 & 4095]($158,$159)|0);
      if ($160) {
       label = 53;
       break;
      } else {
       $__j$0 = $127;
      }
     }
     if ((label|0) == 53) {
      label = 0;
      $161 = HEAP32[$$0>>2]|0;
      $162 = HEAP32[$127>>2]|0;
      HEAP32[$$0>>2] = $162;
      HEAP32[$127>>2] = $161;
      $163 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $127;$__n_swaps$3 = $163;
      break;
     }
     $129 = (($$0) + 4|0);
     $130 = HEAP32[$__comp>>2]|0;
     $131 = HEAP32[$$0>>2]|0;
     $132 = HEAP32[$1>>2]|0;
     $133 = (FUNCTION_TABLE_iii[$130 & 4095]($131,$132)|0);
     if ($133) {
      $__i$1 = $129;
     } else {
      $134 = ($129|0)==($1|0);
      if ($134) {
       label = 70;
       break L1;
      } else {
       $__i$09 = $129;
      }
      while(1) {
       $137 = HEAP32[$__comp>>2]|0;
       $138 = HEAP32[$$0>>2]|0;
       $139 = HEAP32[$__i$09>>2]|0;
       $140 = (FUNCTION_TABLE_iii[$137 & 4095]($138,$139)|0);
       $136 = (($__i$09) + 4|0);
       if ($140) {
        break;
       }
       $135 = ($136|0)==($1|0);
       if ($135) {
        label = 70;
        break L1;
       } else {
        $__i$09 = $136;
       }
      }
      $141 = HEAP32[$__i$09>>2]|0;
      $142 = HEAP32[$1>>2]|0;
      HEAP32[$__i$09>>2] = $142;
      HEAP32[$1>>2] = $141;
      $__i$1 = $136;
     }
     $143 = ($__i$1|0)==($1|0);
     if ($143) {
      label = 70;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $144 = HEAP32[$__comp>>2]|0;
       $145 = HEAP32[$$0>>2]|0;
       $146 = HEAP32[$__i$2>>2]|0;
       $147 = (FUNCTION_TABLE_iii[$144 & 4095]($145,$146)|0);
       $148 = (($__i$2) + 4|0);
       if ($147) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $148;
       }
      }
      while(1) {
       $149 = HEAP32[$__comp>>2]|0;
       $150 = HEAP32[$$0>>2]|0;
       $151 = (($__j$2) + -4|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = (FUNCTION_TABLE_iii[$149 & 4095]($150,$152)|0);
       if ($153) {
        $__j$2 = $151;
       } else {
        break;
       }
      }
      $154 = ($__i$2>>>0)<($151>>>0);
      if (!($154)) {
       $$0 = $__i$2;
       continue L3;
      }
      $155 = HEAP32[$__i$2>>2]|0;
      $156 = HEAP32[$151>>2]|0;
      HEAP32[$__i$2>>2] = $156;
      HEAP32[$151>>2] = $155;
      $__i$2$ph = $148;$__j$1$ph = $151;
     }
    }
   } while(0);
   $164 = (($$0) + 4|0);
   $165 = ($164>>>0)<($__j$3>>>0);
   L53: do {
    if ($165) {
     $__i$3$ph = $164;$__j$4$ph = $__j$3;$__m$0$ph = $66;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $166 = HEAP32[$__comp>>2]|0;
       $167 = HEAP32[$__i$3>>2]|0;
       $168 = HEAP32[$__m$0$ph>>2]|0;
       $169 = (FUNCTION_TABLE_iii[$166 & 4095]($167,$168)|0);
       $170 = (($__i$3) + 4|0);
       if ($169) {
        $__i$3 = $170;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $171 = HEAP32[$__comp>>2]|0;
       $172 = (($__j$5) + -4|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = HEAP32[$__m$0$ph>>2]|0;
       $175 = (FUNCTION_TABLE_iii[$171 & 4095]($173,$174)|0);
       if ($175) {
        break;
       } else {
        $__j$5 = $172;
       }
      }
      $176 = ($__i$3>>>0)>($172>>>0);
      if ($176) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L53;
      }
      $177 = HEAP32[$__i$3>>2]|0;
      $178 = HEAP32[$172>>2]|0;
      HEAP32[$__i$3>>2] = $178;
      HEAP32[$172>>2] = $177;
      $179 = (($__n_swaps$4$ph) + 1)|0;
      $180 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $180 ? $172 : $__m$0$ph;
      $__i$3$ph = $170;$__j$4$ph = $172;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $179;
     }
    } else {
     $__i$4 = $164;$__m$2 = $66;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $181 = ($__i$4|0)==($__m$2|0);
   if ($181) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $182 = HEAP32[$__comp>>2]|0;
    $183 = HEAP32[$__m$2>>2]|0;
    $184 = HEAP32[$__i$4>>2]|0;
    $185 = (FUNCTION_TABLE_iii[$182 & 4095]($183,$184)|0);
    if ($185) {
     $186 = HEAP32[$__i$4>>2]|0;
     $187 = HEAP32[$__m$2>>2]|0;
     HEAP32[$__i$4>>2] = $187;
     HEAP32[$__m$2>>2] = $186;
     $188 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $188;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $189 = ($__n_swaps$6|0)==(0);
   if ($189) {
    $190 = (__ZNSt3__127__insertion_sort_incompleteIRPFbP10GUIElementS2_EPS2_EEbT0_S7_T_($$0,$__i$4,$__comp)|0);
    $191 = (($__i$4) + 4|0);
    $192 = (__ZNSt3__127__insertion_sort_incompleteIRPFbP10GUIElementS2_EPS2_EEbT0_S7_T_($191,$$01$ph,$__comp)|0);
    if ($192) {
     label = 65;
     break;
    }
    if ($190) {
     $$0 = $191;
     continue;
    }
   }
   $193 = $__i$4;
   $194 = (($193) - ($2))|0;
   $195 = (($0) - ($193))|0;
   $196 = ($194|0)<($195|0);
   if (!($196)) {
    label = 69;
    break;
   }
   __ZNSt3__16__sortIRPFbP10GUIElementS2_EPS2_EEvT0_S7_T_($$0,$__i$4,$__comp);
   $197 = (($__i$4) + 4|0);
   $$0 = $197;
  }
  if ((label|0) == 65) {
   label = 0;
   if ($190) {
    label = 70;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 69) {
   label = 0;
   $198 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIRPFbP10GUIElementS2_EPS2_EEvT0_S7_T_($198,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$__comp>>2]|0;
  $6 = HEAP32[$1>>2]|0;
  $7 = HEAP32[$$0>>2]|0;
  $8 = (FUNCTION_TABLE_iii[$5 & 4095]($6,$7)|0);
  if (!($8)) {
   STACKTOP = sp;return;
  }
  $9 = HEAP32[$$0>>2]|0;
  $10 = HEAP32[$1>>2]|0;
  HEAP32[$$0>>2] = $10;
  HEAP32[$1>>2] = $9;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $11 = (($$0) + 4|0);
  $12 = HEAP32[$__comp>>2]|0;
  $13 = HEAP32[$11>>2]|0;
  $14 = HEAP32[$$0>>2]|0;
  $15 = (FUNCTION_TABLE_iii[$12 & 4095]($13,$14)|0);
  $16 = HEAP32[$__comp>>2]|0;
  $17 = HEAP32[$1>>2]|0;
  $18 = HEAP32[$11>>2]|0;
  $19 = (FUNCTION_TABLE_iii[$16 & 4095]($17,$18)|0);
  if (!($15)) {
   if (!($19)) {
    STACKTOP = sp;return;
   }
   $20 = HEAP32[$11>>2]|0;
   $21 = HEAP32[$1>>2]|0;
   HEAP32[$11>>2] = $21;
   HEAP32[$1>>2] = $20;
   $22 = HEAP32[$__comp>>2]|0;
   $23 = HEAP32[$11>>2]|0;
   $24 = HEAP32[$$0>>2]|0;
   $25 = (FUNCTION_TABLE_iii[$22 & 4095]($23,$24)|0);
   if (!($25)) {
    STACKTOP = sp;return;
   }
   $26 = HEAP32[$$0>>2]|0;
   $27 = HEAP32[$11>>2]|0;
   HEAP32[$$0>>2] = $27;
   HEAP32[$11>>2] = $26;
   STACKTOP = sp;return;
  }
  $28 = HEAP32[$$0>>2]|0;
  if ($19) {
   $29 = HEAP32[$1>>2]|0;
   HEAP32[$$0>>2] = $29;
   HEAP32[$1>>2] = $28;
   STACKTOP = sp;return;
  }
  $30 = HEAP32[$11>>2]|0;
  HEAP32[$$0>>2] = $30;
  HEAP32[$11>>2] = $28;
  $31 = HEAP32[$__comp>>2]|0;
  $32 = HEAP32[$1>>2]|0;
  $33 = (FUNCTION_TABLE_iii[$31 & 4095]($32,$28)|0);
  if (!($33)) {
   STACKTOP = sp;return;
  }
  $34 = HEAP32[$11>>2]|0;
  $35 = HEAP32[$1>>2]|0;
  HEAP32[$11>>2] = $35;
  HEAP32[$1>>2] = $34;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $36 = (($$0) + 4|0);
  $37 = (($$0) + 8|0);
  (__ZNSt3__17__sort4IRPFbP10GUIElementS2_EPS2_EEjT0_S7_S7_S7_T_($$0,$36,$37,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $38 = (($$0) + 4|0);
  $39 = (($$0) + 8|0);
  $40 = (($$0) + 12|0);
  (__ZNSt3__17__sort4IRPFbP10GUIElementS2_EPS2_EEjT0_S7_S7_S7_T_($$0,$38,$39,$40,$__comp)|0);
  $41 = HEAP32[$__comp>>2]|0;
  $42 = HEAP32[$1>>2]|0;
  $43 = HEAP32[$40>>2]|0;
  $44 = (FUNCTION_TABLE_iii[$41 & 4095]($42,$43)|0);
  if (!($44)) {
   STACKTOP = sp;return;
  }
  $45 = HEAP32[$40>>2]|0;
  $46 = HEAP32[$1>>2]|0;
  HEAP32[$40>>2] = $46;
  HEAP32[$1>>2] = $45;
  $47 = HEAP32[$__comp>>2]|0;
  $48 = HEAP32[$40>>2]|0;
  $49 = HEAP32[$39>>2]|0;
  $50 = (FUNCTION_TABLE_iii[$47 & 4095]($48,$49)|0);
  if (!($50)) {
   STACKTOP = sp;return;
  }
  $51 = HEAP32[$39>>2]|0;
  $52 = HEAP32[$40>>2]|0;
  HEAP32[$39>>2] = $52;
  HEAP32[$40>>2] = $51;
  $53 = HEAP32[$__comp>>2]|0;
  $54 = HEAP32[$38>>2]|0;
  $55 = (FUNCTION_TABLE_iii[$53 & 4095]($52,$54)|0);
  if (!($55)) {
   STACKTOP = sp;return;
  }
  $56 = HEAP32[$38>>2]|0;
  $57 = HEAP32[$39>>2]|0;
  HEAP32[$38>>2] = $57;
  HEAP32[$39>>2] = $56;
  $58 = HEAP32[$__comp>>2]|0;
  $59 = HEAP32[$$0>>2]|0;
  $60 = (FUNCTION_TABLE_iii[$58 & 4095]($57,$59)|0);
  if (!($60)) {
   STACKTOP = sp;return;
  }
  $61 = HEAP32[$$0>>2]|0;
  $62 = HEAP32[$38>>2]|0;
  HEAP32[$$0>>2] = $62;
  HEAP32[$38>>2] = $61;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IRPFbP10GUIElementS2_EPS2_EEvT0_S7_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 70) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRPFbP10GUIElementS2_EPS2_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__c>>2]|0;
 $1 = HEAP32[$__x2>>2]|0;
 $2 = HEAP32[$__x1>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$0 & 4095]($1,$2)|0);
 $4 = HEAP32[$__c>>2]|0;
 $5 = HEAP32[$__x3>>2]|0;
 $6 = HEAP32[$__x2>>2]|0;
 $7 = (FUNCTION_TABLE_iii[$4 & 4095]($5,$6)|0);
 do {
  if ($3) {
   $16 = HEAP32[$__x1>>2]|0;
   if ($7) {
    $17 = HEAP32[$__x3>>2]|0;
    HEAP32[$__x1>>2] = $17;
    HEAP32[$__x3>>2] = $16;
    $$0$i = 1;
    break;
   }
   $18 = HEAP32[$__x2>>2]|0;
   HEAP32[$__x1>>2] = $18;
   HEAP32[$__x2>>2] = $16;
   $19 = HEAP32[$__c>>2]|0;
   $20 = HEAP32[$__x3>>2]|0;
   $21 = (FUNCTION_TABLE_iii[$19 & 4095]($20,$16)|0);
   if ($21) {
    $22 = HEAP32[$__x2>>2]|0;
    $23 = HEAP32[$__x3>>2]|0;
    HEAP32[$__x2>>2] = $23;
    HEAP32[$__x3>>2] = $22;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($7) {
    $8 = HEAP32[$__x2>>2]|0;
    $9 = HEAP32[$__x3>>2]|0;
    HEAP32[$__x2>>2] = $9;
    HEAP32[$__x3>>2] = $8;
    $10 = HEAP32[$__c>>2]|0;
    $11 = HEAP32[$__x2>>2]|0;
    $12 = HEAP32[$__x1>>2]|0;
    $13 = (FUNCTION_TABLE_iii[$10 & 4095]($11,$12)|0);
    if ($13) {
     $14 = HEAP32[$__x1>>2]|0;
     $15 = HEAP32[$__x2>>2]|0;
     HEAP32[$__x1>>2] = $15;
     HEAP32[$__x2>>2] = $14;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $24 = HEAP32[$__c>>2]|0;
 $25 = HEAP32[$__x4>>2]|0;
 $26 = HEAP32[$__x3>>2]|0;
 $27 = (FUNCTION_TABLE_iii[$24 & 4095]($25,$26)|0);
 if (!($27)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $28 = HEAP32[$__x3>>2]|0;
 $29 = HEAP32[$__x4>>2]|0;
 HEAP32[$__x3>>2] = $29;
 HEAP32[$__x4>>2] = $28;
 $30 = (($$0$i) + 1)|0;
 $31 = HEAP32[$__c>>2]|0;
 $32 = HEAP32[$__x3>>2]|0;
 $33 = HEAP32[$__x2>>2]|0;
 $34 = (FUNCTION_TABLE_iii[$31 & 4095]($32,$33)|0);
 if (!($34)) {
  $__r$0 = $30;
  STACKTOP = sp;return ($__r$0|0);
 }
 $35 = HEAP32[$__x2>>2]|0;
 $36 = HEAP32[$__x3>>2]|0;
 HEAP32[$__x2>>2] = $36;
 HEAP32[$__x3>>2] = $35;
 $37 = (($$0$i) + 2)|0;
 $38 = HEAP32[$__c>>2]|0;
 $39 = HEAP32[$__x2>>2]|0;
 $40 = HEAP32[$__x1>>2]|0;
 $41 = (FUNCTION_TABLE_iii[$38 & 4095]($39,$40)|0);
 if (!($41)) {
  $__r$0 = $37;
  STACKTOP = sp;return ($__r$0|0);
 }
 $42 = HEAP32[$__x1>>2]|0;
 $43 = HEAP32[$__x2>>2]|0;
 HEAP32[$__x1>>2] = $43;
 HEAP32[$__x2>>2] = $42;
 $44 = (($$0$i) + 3)|0;
 $__r$0 = $44;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRPFbP10GUIElementS2_EPS2_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 8|0);
 $1 = (($__first) + 4|0);
 $2 = HEAP32[$__comp>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$__first>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$2 & 4095]($3,$4)|0);
 $6 = HEAP32[$__comp>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$1>>2]|0;
 $9 = (FUNCTION_TABLE_iii[$6 & 4095]($7,$8)|0);
 do {
  if ($5) {
   $17 = HEAP32[$__first>>2]|0;
   if ($9) {
    $18 = HEAP32[$0>>2]|0;
    HEAP32[$__first>>2] = $18;
    HEAP32[$0>>2] = $17;
    break;
   }
   $19 = HEAP32[$1>>2]|0;
   HEAP32[$__first>>2] = $19;
   HEAP32[$1>>2] = $17;
   $20 = HEAP32[$__comp>>2]|0;
   $21 = HEAP32[$0>>2]|0;
   $22 = (FUNCTION_TABLE_iii[$20 & 4095]($21,$17)|0);
   if ($22) {
    $23 = HEAP32[$1>>2]|0;
    $24 = HEAP32[$0>>2]|0;
    HEAP32[$1>>2] = $24;
    HEAP32[$0>>2] = $23;
   }
  } else {
   if ($9) {
    $10 = HEAP32[$1>>2]|0;
    $11 = HEAP32[$0>>2]|0;
    HEAP32[$1>>2] = $11;
    HEAP32[$0>>2] = $10;
    $12 = HEAP32[$__comp>>2]|0;
    $13 = HEAP32[$__first>>2]|0;
    $14 = (FUNCTION_TABLE_iii[$12 & 4095]($11,$13)|0);
    if ($14) {
     $15 = HEAP32[$__first>>2]|0;
     $16 = HEAP32[$1>>2]|0;
     HEAP32[$__first>>2] = $16;
     HEAP32[$1>>2] = $15;
    }
   }
  }
 } while(0);
 $25 = (($__first) + 12|0);
 $26 = ($25|0)==($__last|0);
 if ($26) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $25;$__j$01 = $0;
 }
 while(1) {
  $27 = HEAP32[$__comp>>2]|0;
  $28 = HEAP32[$__i$02>>2]|0;
  $29 = HEAP32[$__j$01>>2]|0;
  $30 = (FUNCTION_TABLE_iii[$27 & 4095]($28,$29)|0);
  if ($30) {
   $31 = HEAP32[$__i$02>>2]|0;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    $32 = HEAP32[$__k$0>>2]|0;
    HEAP32[$__j$1>>2] = $32;
    $33 = ($__k$0|0)==($__first|0);
    if ($33) {
     $__k$0$lcssa = $__first;
     break;
    }
    $34 = HEAP32[$__comp>>2]|0;
    $35 = (($__k$0) + -4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (FUNCTION_TABLE_iii[$34 & 4095]($31,$36)|0);
    if ($37) {
     $__j$1$phi = $__k$0;$__k$0 = $35;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAP32[$__k$0$lcssa>>2] = $31;
  }
  $38 = (($__i$02) + 4|0);
  $39 = ($38|0)==($__last|0);
  if ($39) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $38;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbP10GUIElementS2_EPS2_EEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$05 = 0, $__count$1 = 0, $__i$06 = 0, $__j$04 = 0, $__j$04$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 4:  {
  $37 = (($__first) + 4|0);
  $38 = (($__first) + 8|0);
  $39 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IRPFbP10GUIElementS2_EPS2_EEjT0_S7_S7_S7_T_($__first,$37,$38,$39,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $40 = (($__first) + 4|0);
  $41 = (($__first) + 8|0);
  $42 = (($__first) + 12|0);
  $43 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IRPFbP10GUIElementS2_EPS2_EEjT0_S7_S7_S7_T_($__first,$40,$41,$42,$__comp)|0);
  $44 = HEAP32[$__comp>>2]|0;
  $45 = HEAP32[$43>>2]|0;
  $46 = HEAP32[$42>>2]|0;
  $47 = (FUNCTION_TABLE_iii[$44 & 4095]($45,$46)|0);
  if (!($47)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $48 = HEAP32[$42>>2]|0;
  $49 = HEAP32[$43>>2]|0;
  HEAP32[$42>>2] = $49;
  HEAP32[$43>>2] = $48;
  $50 = HEAP32[$__comp>>2]|0;
  $51 = HEAP32[$42>>2]|0;
  $52 = HEAP32[$41>>2]|0;
  $53 = (FUNCTION_TABLE_iii[$50 & 4095]($51,$52)|0);
  if (!($53)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $54 = HEAP32[$41>>2]|0;
  $55 = HEAP32[$42>>2]|0;
  HEAP32[$41>>2] = $55;
  HEAP32[$42>>2] = $54;
  $56 = HEAP32[$__comp>>2]|0;
  $57 = HEAP32[$40>>2]|0;
  $58 = (FUNCTION_TABLE_iii[$56 & 4095]($55,$57)|0);
  if (!($58)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $59 = HEAP32[$40>>2]|0;
  $60 = HEAP32[$41>>2]|0;
  HEAP32[$40>>2] = $60;
  HEAP32[$41>>2] = $59;
  $61 = HEAP32[$__comp>>2]|0;
  $62 = HEAP32[$__first>>2]|0;
  $63 = (FUNCTION_TABLE_iii[$61 & 4095]($60,$62)|0);
  if (!($63)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $64 = HEAP32[$__first>>2]|0;
  $65 = HEAP32[$40>>2]|0;
  HEAP32[$__first>>2] = $65;
  HEAP32[$40>>2] = $64;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (($__last) + -4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$__first>>2]|0;
  $8 = (FUNCTION_TABLE_iii[$4 & 4095]($6,$7)|0);
  if (!($8)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $9 = HEAP32[$__first>>2]|0;
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$__first>>2] = $10;
  HEAP32[$5>>2] = $9;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $11 = (($__first) + 4|0);
  $12 = (($__last) + -4|0);
  $13 = HEAP32[$__comp>>2]|0;
  $14 = HEAP32[$11>>2]|0;
  $15 = HEAP32[$__first>>2]|0;
  $16 = (FUNCTION_TABLE_iii[$13 & 4095]($14,$15)|0);
  $17 = HEAP32[$__comp>>2]|0;
  $18 = HEAP32[$12>>2]|0;
  $19 = HEAP32[$11>>2]|0;
  $20 = (FUNCTION_TABLE_iii[$17 & 4095]($18,$19)|0);
  if (!($16)) {
   if (!($20)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $21 = HEAP32[$11>>2]|0;
   $22 = HEAP32[$12>>2]|0;
   HEAP32[$11>>2] = $22;
   HEAP32[$12>>2] = $21;
   $23 = HEAP32[$__comp>>2]|0;
   $24 = HEAP32[$11>>2]|0;
   $25 = HEAP32[$__first>>2]|0;
   $26 = (FUNCTION_TABLE_iii[$23 & 4095]($24,$25)|0);
   if (!($26)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $27 = HEAP32[$__first>>2]|0;
   $28 = HEAP32[$11>>2]|0;
   HEAP32[$__first>>2] = $28;
   HEAP32[$11>>2] = $27;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $29 = HEAP32[$__first>>2]|0;
  if ($20) {
   $30 = HEAP32[$12>>2]|0;
   HEAP32[$__first>>2] = $30;
   HEAP32[$12>>2] = $29;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $31 = HEAP32[$11>>2]|0;
  HEAP32[$__first>>2] = $31;
  HEAP32[$11>>2] = $29;
  $32 = HEAP32[$__comp>>2]|0;
  $33 = HEAP32[$12>>2]|0;
  $34 = (FUNCTION_TABLE_iii[$32 & 4095]($33,$29)|0);
  if (!($34)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $35 = HEAP32[$11>>2]|0;
  $36 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $36;
  HEAP32[$12>>2] = $35;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $66 = (($__first) + 8|0);
  $67 = (($__first) + 4|0);
  $68 = HEAP32[$__comp>>2]|0;
  $69 = HEAP32[$67>>2]|0;
  $70 = HEAP32[$__first>>2]|0;
  $71 = (FUNCTION_TABLE_iii[$68 & 4095]($69,$70)|0);
  $72 = HEAP32[$__comp>>2]|0;
  $73 = HEAP32[$66>>2]|0;
  $74 = HEAP32[$67>>2]|0;
  $75 = (FUNCTION_TABLE_iii[$72 & 4095]($73,$74)|0);
  do {
   if ($71) {
    $83 = HEAP32[$__first>>2]|0;
    if ($75) {
     $84 = HEAP32[$66>>2]|0;
     HEAP32[$__first>>2] = $84;
     HEAP32[$66>>2] = $83;
     break;
    }
    $85 = HEAP32[$67>>2]|0;
    HEAP32[$__first>>2] = $85;
    HEAP32[$67>>2] = $83;
    $86 = HEAP32[$__comp>>2]|0;
    $87 = HEAP32[$66>>2]|0;
    $88 = (FUNCTION_TABLE_iii[$86 & 4095]($87,$83)|0);
    if ($88) {
     $89 = HEAP32[$67>>2]|0;
     $90 = HEAP32[$66>>2]|0;
     HEAP32[$67>>2] = $90;
     HEAP32[$66>>2] = $89;
    }
   } else {
    if ($75) {
     $76 = HEAP32[$67>>2]|0;
     $77 = HEAP32[$66>>2]|0;
     HEAP32[$67>>2] = $77;
     HEAP32[$66>>2] = $76;
     $78 = HEAP32[$__comp>>2]|0;
     $79 = HEAP32[$__first>>2]|0;
     $80 = (FUNCTION_TABLE_iii[$78 & 4095]($77,$79)|0);
     if ($80) {
      $81 = HEAP32[$__first>>2]|0;
      $82 = HEAP32[$67>>2]|0;
      HEAP32[$__first>>2] = $82;
      HEAP32[$67>>2] = $81;
     }
    }
   }
  } while(0);
  $91 = (($__first) + 12|0);
  $92 = ($91|0)==($__last|0);
  if ($92) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$05 = 0;$__i$06 = $91;$__j$04 = $66;
  }
  while(1) {
   $93 = HEAP32[$__comp>>2]|0;
   $94 = HEAP32[$__i$06>>2]|0;
   $95 = HEAP32[$__j$04>>2]|0;
   $96 = (FUNCTION_TABLE_iii[$93 & 4095]($94,$95)|0);
   if ($96) {
    $97 = HEAP32[$__i$06>>2]|0;
    $__j$1 = $__i$06;$__k$0 = $__j$04;
    while(1) {
     $98 = HEAP32[$__k$0>>2]|0;
     HEAP32[$__j$1>>2] = $98;
     $99 = ($__k$0|0)==($__first|0);
     if ($99) {
      $__k$0$lcssa = $__first;
      break;
     }
     $100 = HEAP32[$__comp>>2]|0;
     $101 = (($__k$0) + -4|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = (FUNCTION_TABLE_iii[$100 & 4095]($97,$102)|0);
     if ($103) {
      $__j$1$phi = $__k$0;$__k$0 = $101;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $97;
    $104 = (($__count$05) + 1)|0;
    $105 = ($104|0)==(8);
    if ($105) {
     break;
    } else {
     $__count$1 = $104;
    }
   } else {
    $__count$1 = $__count$05;
   }
   $108 = (($__i$06) + 4|0);
   $109 = ($108|0)==($__last|0);
   if ($109) {
    $$0 = 1;
    label = 34;
    break;
   } else {
    $__j$04$phi = $__i$06;$__count$05 = $__count$1;$__i$06 = $108;$__j$04 = $__j$04$phi;
   }
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  $106 = (($__i$06) + 4|0);
  $107 = ($106|0)==($__last|0);
  $$0 = $107;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16vectorIP10GUIElement13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEC2INS_21__tree_const_iteratorI4PPtrIS1_EPNS_11__tree_nodeISA_PvEEiEEEET_NS_9enable_ifIXaasr21__is_forward_iteratorISG_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISG_E9referenceEEE5valueESG_E4typeE($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy1 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__r$02$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $$byval_copy1 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 HEAP32[$this>>2] = 0;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[$__first>>2]|0;
 $6 = HEAP32[$__last>>2]|0;
 $7 = ($5|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $10 = $5;$__r$02$i$i = 0;
 }
 while(1) {
  $8 = (($__r$02$i$i) + 1)|0;
  $9 = (($10) + 4|0);
  $11 = HEAP32[$9>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $$01$i$i$i$i = $10;
   while(1) {
    $15 = (($$01$i$i$i$i) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==($$01$i$i$i$i|0);
    if ($18) {
     $$0$i$i$i$i = $16;
     break;
    } else {
     $$01$i$i$i$i = $16;
    }
   }
  } else {
   $$0$i$i$i$i$i = $11;
   while(1) {
    $13 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $13;
    }
   }
  }
  $19 = ($$0$i$i$i$i|0)==($6|0);
  if ($19) {
   break;
  } else {
   $10 = $$0$i$i$i$i;$__r$02$i$i = $8;
  }
 }
 $20 = ($8|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = ($8|0)<(0);
 if ($21) {
  __THREW__ = 0;
  invoke_vi(3308,0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if (!($23)) {
   // unreachable;
  }
 } else {
  $24 = $8 << 2;
  HEAP32[$$byval_copy1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$$byval_copy1+0>>2]|0;
  $25 = (invoke_iiiiiii(102,($24|0),16,($$byval_copy3|0),0,(567760|0),79)|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   HEAP32[$3>>2] = $25;
   HEAP32[$this>>2] = $25;
   $28 = (($25) + ($8<<2)|0);
   HEAP32[$4>>2] = $28;
   HEAP32[$1>>2] = $5;
   HEAP32[$2>>2] = $6;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viii(1658,($this|0),($$byval_copy1|0),($$byval_copy3|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    STACKTOP = sp;return;
   }
  }
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $33 = HEAP32[$this>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  ___resumeException($31|0);
  // unreachable;
 }
 $35 = HEAP32[$3>>2]|0;
 $36 = ($35|0)==($33|0);
 if (!($36)) {
  $__new_last2$i$i$i = $33;
  $scevgep$i$i$i = (($35) + -4|0);
  $37 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($37)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $38 = $uglygep3$i$i$i >>> 2;
  $39 = $38 ^ -1;
  $scevgep4$i$i$i = (($35) + ($39<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy3|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  ___cxa_call_unexpected(($42|0));
  // unreachable;
 } else {
  ___resumeException($31|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIP10GUIElement13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE18__construct_at_endINS_21__tree_const_iteratorI4PPtrIS1_EPNS_11__tree_nodeISA_PvEEiEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESH_SH_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i1 = 0, $$01$i$i = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i$i = 0, $temp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 while(1) {
  $5 = ($6|0)==(0|0);
  if ($5) {
   $45 = 0;$47 = $8;
  } else {
   $7 = (($8) + 16|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = ($9|0)==(0);
   if ($10) {
    $$0$i$i1 = 0;
   } else {
    HEAP32[$0>>2] = $9;
    $11 = HEAP32[560624>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 13;
    } else {
     $13 = (($11) + 36|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($11) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     do {
      if ($17) {
       $18 = (($11) + 28|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($11) + 32|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($19) + ($21<<3)|0);
       $38 = $22;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$11,$0);
       $23 = HEAP32[$pos$i$i$i$i$i>>2]|0;
       $24 = ($23|0)==(-1);
       $25 = (($11) + 28|0);
       $26 = HEAP32[$25>>2]|0;
       if ($24) {
        $27 = (($11) + 32|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($26) + ($28<<3)|0);
        $38 = $29;
        break;
       } else {
        $30 = (($26) + ($23<<3)|0);
        $38 = $30;
        break;
       }
      }
     } while(0);
     $31 = HEAP32[560624>>2]|0;
     $32 = (($31) + 28|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + 32|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($33) + ($35<<3)|0);
     $37 = ($38|0)==($36|0);
     if ($37) {
      label = 13;
     } else {
      $39 = (($38) + 4|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       label = 13;
      } else {
       $temp$0$i$i = $40;
      }
     }
    }
    if ((label|0) == 13) {
     label = 0;
     $42 = HEAP32[$7>>2]|0;
     $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
     $temp$0$i$i = $43;
    }
    $$0$i$i1 = $temp$0$i$i;
   }
   HEAP32[$6>>2] = $$0$i$i1;
   $$pre3 = HEAP32[$4>>2]|0;
   $$pre4 = HEAP32[$__first>>2]|0;
   $45 = $$pre3;$47 = $$pre4;
  }
  $44 = (($45) + 4|0);
  HEAP32[$4>>2] = $44;
  $46 = (($47) + 4|0);
  $48 = HEAP32[$46>>2]|0;
  $49 = ($48|0)==(0|0);
  if ($49) {
   $$01$i$i = $47;
   while(1) {
    $52 = (($$01$i$i) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)==($$01$i$i|0);
    if ($55) {
     $$0$i$i = $53;
     break;
    } else {
     $$01$i$i = $53;
    }
   }
  } else {
   $$0$i$i$i = $48;
   while(1) {
    $50 = HEAP32[$$0$i$i$i>>2]|0;
    $51 = ($50|0)==(0|0);
    if ($51) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $50;
    }
   }
  }
  HEAP32[$__first>>2] = $$0$i$i;
  $56 = ($$0$i$i|0)==($2|0);
  if ($56) {
   break;
  } else {
   $6 = $44;$8 = $$0$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE5eraseENS_21__tree_const_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEE($agg$result,$this,$__p) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__p = $__p|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$__p>>2]|0;
 HEAP32[$agg$result>>2] = $2;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$01$i$i = $2;
  while(1) {
   $8 = (($$01$i$i) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($$01$i$i|0);
   if ($11) {
    $$0$i$i = $9;
    break;
   } else {
    $$01$i$i = $9;
   }
  }
 } else {
  $$0$i$i$i = $4;
  while(1) {
   $6 = HEAP32[$$0$i$i$i>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $$0$i$i = $$0$i$i$i;
    break;
   } else {
    $$0$i$i$i = $6;
   }
  }
 }
 HEAP32[$agg$result>>2] = $$0$i$i;
 $12 = HEAP32[$this>>2]|0;
 $13 = ($12|0)==($2|0);
 if ($13) {
  HEAP32[$this>>2] = $$0$i$i;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($18,$2);
 $19 = HEAP8[567776>>0]|0;
 $20 = ($19<<24>>24)==(0);
 do {
  if ($20) {
   $21 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   $22 = (invoke_iiiiiii(103,40,($$byval_copy7|0),0,16,(567760|0),141)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[628480>>2]|0;
    HEAP32[$1>>2] = $25;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viiiiii(98,($22|0),1,(567784|0),20,32768,($$byval_copy7|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     HEAP32[567768>>2] = $22;
     __THREW__ = 0;
     invoke_vi(3395,($22|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $36 = 567776;
     $37 = $36;
     HEAP32[$37>>2] = 1;
     $38 = (($36) + 4)|0;
     $39 = $38;
     HEAP32[$39>>2] = 0;
     label = 14;
     break;
    }
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viiiiii(97,($22|0),($$byval_copy7|0),0,16,(567760|0),141);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     $32 = ___cxa_find_matching_catch(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $28;
     ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
     // unreachable;
    }
   }
  } else {
   label = 14;
  }
 } while(0);
 if ((label|0) == 14) {
  $40 = HEAP32[567768>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($40|0),($2|0));
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if (!($42)) {
   STACKTOP = sp;return;
  }
 }
 $43 = ___cxa_find_matching_catch()|0;
 $44 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $43;
 ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
 // unreachable;
}
function __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp + 12|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$20 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)<($6|0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6|0)<($4|0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $30 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE16__construct_nodeERKS3_($0,$this,$__v);
 $17 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$17>>2] = 0;
 $18 = (($17) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $17;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $17;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $17;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE16__construct_nodeERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP8[567776>>0]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   $5 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $5;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $6 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,567760,141)|0);
   $7 = HEAP32[628480>>2]|0;
   HEAP32[$1>>2] = $7;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(98,($6|0),1,(567784|0),20,32768,($$byval_copy2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    HEAP32[567768>>2] = $6;
    __ZN10MemoryPool24RegisterStaticMemoryPoolEPS_($6);
    $16 = 567776;
    $17 = $16;
    HEAP32[$17>>2] = 1;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP32[$19>>2] = 0;
    break;
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viiiiii(97,($6|0),($$byval_copy2|0),0,16,(567760|0),141);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch(0|0)|0;
    $15 = tempRet0;
    ___clang_call_terminate($14);
    // unreachable;
   } else {
    ___resumeException($10|0);
    // unreachable;
   }
  }
 } while(0);
 $20 = HEAP32[567768>>2]|0;
 $21 = (__ZN10MemoryPool8AllocateEj($20,20)|0);
 $22 = $2;
 $23 = (($21) + 16|0);
 $24 = HEAP32[$__v>>2]|0;
 HEAP32[$23>>2] = $24;
 HEAP32[$agg$result>>2] = $21;
 $25 = (($agg$result) + 4|0);
 $26 = $25;
 $27 = $26;
 HEAP32[$27>>2] = $22;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($__nd|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
 $4 = (($__nd) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeI4PPtrI10GUIElementENS_4lessIS3_EE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$5);
 $6 = HEAP8[567776>>0]|0;
 $7 = ($6<<24>>24)==(0);
 do {
  if ($7) {
   $8 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $8;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   $9 = (invoke_iiiiiii(103,40,($$byval_copy7|0),0,16,(567760|0),141)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[628480>>2]|0;
    HEAP32[$1>>2] = $12;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viiiiii(98,($9|0),1,(567784|0),20,32768,($$byval_copy7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     HEAP32[567768>>2] = $9;
     __THREW__ = 0;
     invoke_vi(3395,($9|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     $23 = 567776;
     $24 = $23;
     HEAP32[$24>>2] = 1;
     $25 = (($23) + 4)|0;
     $26 = $25;
     HEAP32[$26>>2] = 0;
     label = 9;
     break;
    }
    $15 = ___cxa_find_matching_catch()|0;
    $16 = tempRet0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viiiiii(97,($9|0),($$byval_copy7|0),0,16,(567760|0),141);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     $19 = ___cxa_find_matching_catch(0|0)|0;
     $20 = tempRet0;
     ___clang_call_terminate($19);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $15;
     ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
     // unreachable;
    }
   }
  } else {
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  $27 = HEAP32[567768>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($27|0),($__nd|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   STACKTOP = sp;return;
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $30;
 ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
 // unreachable;
}
function __ZL20InitializeGUIShadersv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[567848>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 26;
 dest=$3+0|0; src=568120+0|0; stop=dest+26|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 26|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 $7 = (invoke_i(58)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  $10 = (invoke_iiii(1532,($7|0),48,($0|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP8[$0>>0]|0;
   $14 = $13 & 1;
   $15 = ($14<<24>>24)==(0);
   if (!($15)) {
    $16 = HEAP32[$4>>2]|0;
    __ZdlPv($16);
   }
   $17 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($10,61,0)|0);
   HEAP32[567848>>2] = $17;
   $18 = (__ZN5Unity8Material9GetShaderEv($17)|0);
   HEAP32[567840>>2] = $18;
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $21 = HEAP8[$0>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  ___resumeException($19|0);
  // unreachable;
 }
 $24 = HEAP32[$4>>2]|0;
 __ZdlPv($24);
 ___resumeException($19|0);
 // unreachable;
}
function __Z14DrawGUITextureRK5RectTIfEP7Texture11ColorRGBA32PN5Unity8MaterialE($screenRect,$texture,$color,$material) {
 $screenRect = $screenRect|0;
 $texture = $texture|0;
 $color = $color|0;
 $material = $material|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$i$byval_copy = sp + 20|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = HEAP32[$color>>2]|0;
 HEAPF32[$0>>2] = Math_fround(0.0);
 $3 = (($0) + 8|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($0) + 4|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($0) + 12|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 HEAP32[$1>>2] = $2;
 ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __Z14DrawGUITextureRK5RectTIfEP7TextureS2_iiii11ColorRGBA32PN5Unity8MaterialE($screenRect,$texture,$0,0,0,0,0,$tmpcast$i$byval_copy,$material);
 STACKTOP = sp;return;
}
function __Z14DrawGUITextureRK5RectTIfEP7Textureiiii11ColorRGBA32PN5Unity8MaterialE($screenRect,$texture,$leftBorder,$rightBorder,$topBorder,$bottomBorder,$color,$material) {
 $screenRect = $screenRect|0;
 $texture = $texture|0;
 $leftBorder = $leftBorder|0;
 $rightBorder = $rightBorder|0;
 $topBorder = $topBorder|0;
 $bottomBorder = $bottomBorder|0;
 $color = $color|0;
 $material = $material|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 20|0;
 $0 = sp;
 $1 = sp + 16|0;
 HEAPF32[$0>>2] = Math_fround(0.0);
 $2 = (($0) + 8|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($0) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($0) + 12|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = HEAP32[$color>>2]|0;
 HEAP32[$1>>2] = $5;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __Z14DrawGUITextureRK5RectTIfEP7TextureS2_iiii11ColorRGBA32PN5Unity8MaterialE($screenRect,$texture,$0,$leftBorder,$rightBorder,$topBorder,$bottomBorder,$tmpcast$byval_copy,$material);
 STACKTOP = sp;return;
}
function __Z14DrawGUITextureRK5RectTIfEP7TextureS2_iiii11ColorRGBA32PN5Unity8MaterialE($screenRect,$tex,$sourceRect,$leftBorder,$rightBorder,$topBorder,$bottomBorder,$color,$material) {
 $screenRect = $screenRect|0;
 $tex = $tex|0;
 $sourceRect = $sourceRect|0;
 $leftBorder = $leftBorder|0;
 $rightBorder = $rightBorder|0;
 $topBorder = $topBorder|0;
 $bottomBorder = $bottomBorder|0;
 $color = $color|0;
 $material = $material|0;
 var $$0 = 0, $$in = 0, $$in$in = 0, $$in7 = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre$phiZ2D = 0, $$sink$i$i$i = Math_fround(0), $$sink$i$i1$i = Math_fround(0), $$sink$i$i3$i = Math_fround(0), $$sink$i$i5$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0;
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$06 = 0, $ibPtr$i = 0, $vbPtr$i = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vbPtr$i = sp + 4|0;
 $ibPtr$i = sp;
 __ZL20InitializeGUIShadersv();
 $0 = ($tex|0)==(0|0);
 if ($0) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(567856,0,567888,496,1,0,0,0);
  STACKTOP = sp;return;
 }
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = HEAP8[((640792 + 258|0))>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $9 = HEAP32[$color>>2]|0;
  $10 = $9&255;
  $11 = $9 >>> 8;
  $12 = $11&255;
  $13 = $9 >>> 16;
  $$in$in = $9;$$in7 = $13;$$pre$phiZ2D = $color;$18 = $12;$22 = $10;
 } else {
  $4 = (($color) + 2|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = (($color) + 1|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = HEAP32[$color>>2]|0;
  $$in$in = $8;$$in7 = $8;$$pre$phiZ2D = $color;$18 = $7;$22 = $5;
 }
 $$in = $$in$in & -16777216;
 $14 = $$in7 << 16;
 $15 = $14 & 16711680;
 $16 = $15 | $$in;
 $17 = $18&255;
 $19 = $17 << 8;
 $20 = $16 | $19;
 $21 = $22&255;
 $23 = $20 | $21;
 HEAP32[$$pre$phiZ2D>>2] = $23;
 $24 = HEAP32[$tex>>2]|0;
 $25 = (($24) + 104|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (FUNCTION_TABLE_ii[$26 & 4095]($tex)|0);
 $28 = (Math_fround(($27|0)));
 $29 = Math_fround(Math_fround(1.0) / $28);
 $30 = HEAP32[$tex>>2]|0;
 $31 = (($30) + 108|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 4095]($tex)|0);
 $34 = (Math_fround(($33|0)));
 $35 = Math_fround(Math_fround(1.0) / $34);
 $36 = Math_fround(HEAPF32[$screenRect>>2]);
 $37 = Math_fround($36 + Math_fround(0.5));
 $38 = !($37 >= Math_fround(0.0));
 if ($38) {
  $39 = Math_fround($37 + Math_fround(-0.999999940395355224609));
  $$sink$i$i$i = $39;
 } else {
  $$sink$i$i$i = $37;
 }
 $40 = (~~(($$sink$i$i$i)));
 $41 = (Math_fround(($40|0)));
 $42 = (($screenRect) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($36 + $43);
 $45 = Math_fround($44 + Math_fround(0.5));
 $46 = !($45 >= Math_fround(0.0));
 if ($46) {
  $47 = Math_fround($45 + Math_fround(-0.999999940395355224609));
  $$sink$i$i1$i = $47;
 } else {
  $$sink$i$i1$i = $45;
 }
 $48 = (~~(($$sink$i$i1$i)));
 $49 = (Math_fround(($48|0)));
 $50 = (($screenRect) + 4|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($screenRect) + 12|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($51 + $53);
 $55 = Math_fround($54 + Math_fround(0.5));
 $56 = !($55 >= Math_fround(0.0));
 if ($56) {
  $57 = Math_fround($55 + Math_fround(-0.999999940395355224609));
  $$sink$i$i5$i = $57;
 } else {
  $$sink$i$i5$i = $55;
 }
 $58 = (~~(($$sink$i$i5$i)));
 $59 = (Math_fround(($58|0)));
 $60 = Math_fround($51 + Math_fround(0.5));
 $61 = !($60 >= Math_fround(0.0));
 if ($61) {
  $62 = Math_fround($60 + Math_fround(-0.999999940395355224609));
  $$sink$i$i3$i = $62;
 } else {
  $$sink$i$i3$i = $60;
 }
 $63 = (~~(($$sink$i$i3$i)));
 $64 = (Math_fround(($63|0)));
 $65 = Math_fround(HEAPF32[$sourceRect>>2]);
 $66 = (($sourceRect) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($65 + $67);
 $69 = (($sourceRect) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($sourceRect) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($70 + $72);
 $74 = (__Z12GetGfxDevicev()|0);
 $75 = (__ZN9GfxDevice13GetDynamicVBOEv($74)|0);
 $76 = $rightBorder | $leftBorder;
 $77 = $76 | $topBorder;
 $78 = $77 | $bottomBorder;
 $79 = ($78|0)==(0);
 do {
  if ($79) {
   $80 = HEAP32[$75>>2]|0;
   $81 = (($80) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (FUNCTION_TABLE_iiiiiiii[$82 & 127]($75,24,4,6,0,$vbPtr$i,$ibPtr$i)|0);
   if ($83) {
    $84 = HEAP32[$vbPtr$i>>2]|0;
    HEAPF32[$84>>2] = $41;
    $85 = (($84) + 4|0);
    HEAPF32[$85>>2] = $59;
    $86 = (($84) + 8|0);
    HEAPF32[$86>>2] = Math_fround(0.0);
    $87 = (($84) + 12|0);
    HEAP32[$87>>2] = $23;
    $88 = (($84) + 16|0);
    HEAPF32[$88>>2] = $65;
    $89 = (($84) + 20|0);
    HEAPF32[$89>>2] = $70;
    $90 = (($84) + 24|0);
    HEAPF32[$90>>2] = $49;
    $91 = (($84) + 28|0);
    HEAPF32[$91>>2] = $59;
    $92 = (($84) + 32|0);
    HEAPF32[$92>>2] = Math_fround(0.0);
    $93 = (($84) + 36|0);
    HEAP32[$93>>2] = $23;
    $94 = (($84) + 40|0);
    HEAPF32[$94>>2] = $68;
    $95 = (($84) + 44|0);
    HEAPF32[$95>>2] = $70;
    $96 = (($84) + 48|0);
    HEAPF32[$96>>2] = $41;
    $97 = (($84) + 52|0);
    HEAPF32[$97>>2] = $64;
    $98 = (($84) + 56|0);
    HEAPF32[$98>>2] = Math_fround(0.0);
    $99 = (($84) + 60|0);
    HEAP32[$99>>2] = $23;
    $100 = (($84) + 64|0);
    HEAPF32[$100>>2] = $65;
    $101 = (($84) + 68|0);
    HEAPF32[$101>>2] = $73;
    $102 = (($84) + 72|0);
    HEAPF32[$102>>2] = $49;
    $103 = (($84) + 76|0);
    HEAPF32[$103>>2] = $64;
    $104 = (($84) + 80|0);
    HEAPF32[$104>>2] = Math_fround(0.0);
    $105 = (($84) + 84|0);
    HEAP32[$105>>2] = $23;
    $106 = (($84) + 88|0);
    HEAPF32[$106>>2] = $68;
    $107 = (($84) + 92|0);
    HEAPF32[$107>>2] = $73;
    $108 = HEAP32[$ibPtr$i>>2]|0;
    ;HEAP16[$108+0>>1]=HEAP16[567992+0>>1]|0;HEAP16[$108+2>>1]=HEAP16[567992+2>>1]|0;HEAP16[$108+4>>1]=HEAP16[567992+4>>1]|0;HEAP16[$108+6>>1]=HEAP16[567992+6>>1]|0;HEAP16[$108+8>>1]=HEAP16[567992+8>>1]|0;HEAP16[$108+10>>1]=HEAP16[567992+10>>1]|0;
    $109 = HEAP32[$75>>2]|0;
    $110 = (($109) + 12|0);
    $111 = HEAP32[$110>>2]|0;
    FUNCTION_TABLE_viii[$111 & 4095]($75,4,6);
    break;
   } else {
    STACKTOP = sp;return;
   }
  } else {
   $112 = (Math_fround(($leftBorder|0)));
   $113 = Math_fround($112 + $41);
   $114 = (Math_fround(($rightBorder|0)));
   $115 = Math_fround($49 - $114);
   $116 = (Math_fround(($bottomBorder|0)));
   $117 = Math_fround($59 - $116);
   $118 = (Math_fround(($topBorder|0)));
   $119 = Math_fround($118 + $64);
   $120 = Math_fround($112 * $29);
   $121 = Math_fround($120 + $65);
   $122 = Math_fround($114 * $29);
   $123 = Math_fround($68 - $122);
   $124 = Math_fround($116 * $35);
   $125 = Math_fround($124 + $70);
   $126 = Math_fround($118 * $35);
   $127 = Math_fround($73 - $126);
   $128 = HEAP32[$75>>2]|0;
   $129 = (($128) + 8|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = (FUNCTION_TABLE_iiiiiiii[$130 & 127]($75,24,16,54,0,$vbPtr$i,$ibPtr$i)|0);
   if ($131) {
    $132 = HEAP32[$vbPtr$i>>2]|0;
    HEAPF32[$132>>2] = $41;
    $133 = (($132) + 4|0);
    HEAPF32[$133>>2] = $59;
    $134 = (($132) + 8|0);
    HEAPF32[$134>>2] = Math_fround(0.0);
    $135 = (($132) + 12|0);
    HEAP32[$135>>2] = $23;
    $136 = (($132) + 16|0);
    HEAPF32[$136>>2] = $65;
    $137 = (($132) + 20|0);
    HEAPF32[$137>>2] = $70;
    $138 = (($132) + 24|0);
    HEAPF32[$138>>2] = $113;
    $139 = (($132) + 28|0);
    HEAPF32[$139>>2] = $59;
    $140 = (($132) + 32|0);
    HEAPF32[$140>>2] = Math_fround(0.0);
    $141 = (($132) + 36|0);
    HEAP32[$141>>2] = $23;
    $142 = (($132) + 40|0);
    HEAPF32[$142>>2] = $121;
    $143 = (($132) + 44|0);
    HEAPF32[$143>>2] = $70;
    $144 = (($132) + 48|0);
    HEAPF32[$144>>2] = $115;
    $145 = (($132) + 52|0);
    HEAPF32[$145>>2] = $59;
    $146 = (($132) + 56|0);
    HEAPF32[$146>>2] = Math_fround(0.0);
    $147 = (($132) + 60|0);
    HEAP32[$147>>2] = $23;
    $148 = (($132) + 64|0);
    HEAPF32[$148>>2] = $123;
    $149 = (($132) + 68|0);
    HEAPF32[$149>>2] = $70;
    $150 = (($132) + 72|0);
    HEAPF32[$150>>2] = $49;
    $151 = (($132) + 76|0);
    HEAPF32[$151>>2] = $59;
    $152 = (($132) + 80|0);
    HEAPF32[$152>>2] = Math_fround(0.0);
    $153 = (($132) + 84|0);
    HEAP32[$153>>2] = $23;
    $154 = (($132) + 88|0);
    HEAPF32[$154>>2] = $68;
    $155 = (($132) + 92|0);
    HEAPF32[$155>>2] = $70;
    $156 = (($132) + 96|0);
    HEAPF32[$156>>2] = $41;
    $157 = (($132) + 100|0);
    HEAPF32[$157>>2] = $117;
    $158 = (($132) + 104|0);
    HEAPF32[$158>>2] = Math_fround(0.0);
    $159 = (($132) + 108|0);
    HEAP32[$159>>2] = $23;
    $160 = (($132) + 112|0);
    HEAPF32[$160>>2] = $65;
    $161 = (($132) + 116|0);
    HEAPF32[$161>>2] = $125;
    $162 = (($132) + 120|0);
    HEAPF32[$162>>2] = $113;
    $163 = (($132) + 124|0);
    HEAPF32[$163>>2] = $117;
    $164 = (($132) + 128|0);
    HEAPF32[$164>>2] = Math_fround(0.0);
    $165 = (($132) + 132|0);
    HEAP32[$165>>2] = $23;
    $166 = (($132) + 136|0);
    HEAPF32[$166>>2] = $121;
    $167 = (($132) + 140|0);
    HEAPF32[$167>>2] = $125;
    $168 = (($132) + 144|0);
    HEAPF32[$168>>2] = $115;
    $169 = (($132) + 148|0);
    HEAPF32[$169>>2] = $117;
    $170 = (($132) + 152|0);
    HEAPF32[$170>>2] = Math_fround(0.0);
    $171 = (($132) + 156|0);
    HEAP32[$171>>2] = $23;
    $172 = (($132) + 160|0);
    HEAPF32[$172>>2] = $123;
    $173 = (($132) + 164|0);
    HEAPF32[$173>>2] = $125;
    $174 = (($132) + 168|0);
    HEAPF32[$174>>2] = $49;
    $175 = (($132) + 172|0);
    HEAPF32[$175>>2] = $117;
    $176 = (($132) + 176|0);
    HEAPF32[$176>>2] = Math_fround(0.0);
    $177 = (($132) + 180|0);
    HEAP32[$177>>2] = $23;
    $178 = (($132) + 184|0);
    HEAPF32[$178>>2] = $68;
    $179 = (($132) + 188|0);
    HEAPF32[$179>>2] = $125;
    $180 = (($132) + 192|0);
    HEAPF32[$180>>2] = $41;
    $181 = (($132) + 196|0);
    HEAPF32[$181>>2] = $119;
    $182 = (($132) + 200|0);
    HEAPF32[$182>>2] = Math_fround(0.0);
    $183 = (($132) + 204|0);
    HEAP32[$183>>2] = $23;
    $184 = (($132) + 208|0);
    HEAPF32[$184>>2] = $65;
    $185 = (($132) + 212|0);
    HEAPF32[$185>>2] = $127;
    $186 = (($132) + 216|0);
    HEAPF32[$186>>2] = $113;
    $187 = (($132) + 220|0);
    HEAPF32[$187>>2] = $119;
    $188 = (($132) + 224|0);
    HEAPF32[$188>>2] = Math_fround(0.0);
    $189 = (($132) + 228|0);
    HEAP32[$189>>2] = $23;
    $190 = (($132) + 232|0);
    HEAPF32[$190>>2] = $121;
    $191 = (($132) + 236|0);
    HEAPF32[$191>>2] = $127;
    $192 = (($132) + 240|0);
    HEAPF32[$192>>2] = $115;
    $193 = (($132) + 244|0);
    HEAPF32[$193>>2] = $119;
    $194 = (($132) + 248|0);
    HEAPF32[$194>>2] = Math_fround(0.0);
    $195 = (($132) + 252|0);
    HEAP32[$195>>2] = $23;
    $196 = (($132) + 256|0);
    HEAPF32[$196>>2] = $123;
    $197 = (($132) + 260|0);
    HEAPF32[$197>>2] = $127;
    $198 = (($132) + 264|0);
    HEAPF32[$198>>2] = $49;
    $199 = (($132) + 268|0);
    HEAPF32[$199>>2] = $119;
    $200 = (($132) + 272|0);
    HEAPF32[$200>>2] = Math_fround(0.0);
    $201 = (($132) + 276|0);
    HEAP32[$201>>2] = $23;
    $202 = (($132) + 280|0);
    HEAPF32[$202>>2] = $68;
    $203 = (($132) + 284|0);
    HEAPF32[$203>>2] = $127;
    $204 = (($132) + 288|0);
    HEAPF32[$204>>2] = $41;
    $205 = (($132) + 292|0);
    HEAPF32[$205>>2] = $64;
    $206 = (($132) + 296|0);
    HEAPF32[$206>>2] = Math_fround(0.0);
    $207 = (($132) + 300|0);
    HEAP32[$207>>2] = $23;
    $208 = (($132) + 304|0);
    HEAPF32[$208>>2] = $65;
    $209 = (($132) + 308|0);
    HEAPF32[$209>>2] = $73;
    $210 = (($132) + 312|0);
    HEAPF32[$210>>2] = $113;
    $211 = (($132) + 316|0);
    HEAPF32[$211>>2] = $64;
    $212 = (($132) + 320|0);
    HEAPF32[$212>>2] = Math_fround(0.0);
    $213 = (($132) + 324|0);
    HEAP32[$213>>2] = $23;
    $214 = (($132) + 328|0);
    HEAPF32[$214>>2] = $121;
    $215 = (($132) + 332|0);
    HEAPF32[$215>>2] = $73;
    $216 = (($132) + 336|0);
    HEAPF32[$216>>2] = $115;
    $217 = (($132) + 340|0);
    HEAPF32[$217>>2] = $64;
    $218 = (($132) + 344|0);
    HEAPF32[$218>>2] = Math_fround(0.0);
    $219 = (($132) + 348|0);
    HEAP32[$219>>2] = $23;
    $220 = (($132) + 352|0);
    HEAPF32[$220>>2] = $123;
    $221 = (($132) + 356|0);
    HEAPF32[$221>>2] = $73;
    $222 = HEAP32[$vbPtr$i>>2]|0;
    $223 = (($222) + 360|0);
    HEAPF32[$223>>2] = $49;
    $224 = (($222) + 364|0);
    HEAPF32[$224>>2] = $64;
    $225 = (($222) + 368|0);
    HEAPF32[$225>>2] = Math_fround(0.0);
    $226 = (($222) + 372|0);
    HEAP32[$226>>2] = $23;
    $227 = (($222) + 376|0);
    HEAPF32[$227>>2] = $68;
    $228 = (($222) + 380|0);
    HEAPF32[$228>>2] = $73;
    $229 = HEAP32[$ibPtr$i>>2]|0;
    dest=$229+0|0; src=568008+0|0; stop=dest+108|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
    $230 = HEAP32[$75>>2]|0;
    $231 = (($230) + 12|0);
    $232 = HEAP32[$231>>2]|0;
    FUNCTION_TABLE_viii[$232 & 4095]($75,16,54);
    break;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $233 = ($material|0)==(0|0);
 if ($233) {
  $239 = HEAP32[567848>>2]|0;
  $240 = (($239) + 32|0);
  $241 = HEAP32[$240>>2]|0;
  $242 = ($241|0)==(0|0);
  if ($242) {
   __ZN5Unity8Material15BuildPropertiesEv($239);
   $$pre$i3 = HEAP32[$240>>2]|0;
   $244 = $$pre$i3;
  } else {
   $244 = $241;
  }
  $243 = (($239) + 36|0);
  HEAP8[$243>>0] = 1;
  __Z21HandleGUITexturePropsPN9ShaderLab13PropertySheetEP7Texture($244,$tex);
  $245 = HEAP32[567848>>2]|0;
  $$0 = $245;
 } else {
  $234 = (($material) + 32|0);
  $235 = HEAP32[$234>>2]|0;
  $236 = ($235|0)==(0|0);
  if ($236) {
   __ZN5Unity8Material15BuildPropertiesEv($material);
   $$pre$i = HEAP32[$234>>2]|0;
   $238 = $$pre$i;
  } else {
   $238 = $235;
  }
  $237 = (($material) + 36|0);
  HEAP8[$237>>0] = 1;
  __Z21HandleGUITexturePropsPN9ShaderLab13PropertySheetEP7Texture($238,$tex);
  $$0 = $material;
 }
 $246 = (__ZN5Unity8Material12GetPassCountEv($$0)|0);
 $247 = (__ZN9GfxDevice13GetDynamicVBOEv($1)|0);
 $248 = ($246|0)>(0);
 if (!($248)) {
  STACKTOP = sp;return;
 }
 $i$06 = 0;
 while(1) {
  $249 = HEAP32[652824>>2]|0;
  $250 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($$0,$i$06,$249,0,0)|0);
  $251 = ($250|0)==(0|0);
  if (!($251)) {
   $252 = HEAP32[$247>>2]|0;
   $253 = (($252) + 16|0);
   $254 = HEAP32[$253>>2]|0;
   $255 = (($250) + 4|0);
   $256 = HEAP32[$255>>2]|0;
   $257 = HEAP32[567832>>2]|0;
   $258 = ($257|0)==(0|0);
   if ($258) {
    $259 = (__Z26GetMeshVertexFormatManagerv()|0);
    $260 = HEAP32[567824>>2]|0;
    $261 = (__ZN23MeshVertexFormatManager10GetDefaultEj($259,$260)|0);
    HEAP32[567832>>2] = $261;
    $262 = $261;
   } else {
    $262 = $257;
   }
   $263 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($262,$256,0)|0);
   FUNCTION_TABLE_viii[$254 & 4095]($247,$250,$263);
  }
  $264 = (($i$06) + 1)|0;
  $exitcond = ($264|0)==($246|0);
  if ($exitcond) {
   break;
  } else {
   $i$06 = $264;
  }
 }
 STACKTOP = sp;return;
}
function __Z21HandleGUITexturePropsPN9ShaderLab13PropertySheetEP7Texture($sheet,$texture) {
 $sheet = $sheet|0;
 $texture = $texture|0;
 var $$ = 0, $$$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $brmerge = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($sheet,567800,$texture)|0);
 $1 = HEAP32[$texture>>2]|0;
 $2 = (($1) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($texture)|0);
 $5 = HEAP32[$texture>>2]|0;
 $6 = (($5) + 108|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($texture)|0);
 $9 = (($sheet) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($sheet) + 48|0);
 $12 = ($10|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[567800>>2]|0;
 $$0$ph7$i$i$i$i = $11;$$01$ph6$i$in$i$i$i = $10;
 L4: while(1) {
  $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
  while(1) {
   $14 = (($$013$i$in$i$i$i) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)<($13|0);
   if (!($16)) {
    break;
   }
   $19 = (($$013$i$in$i$i$i) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
    break L4;
   } else {
    $$013$i$in$i$i$i = $20;
   }
  }
  $17 = HEAP32[$$013$i$in$i$i$i>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
   break;
  } else {
   $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $17;
  }
 }
 $22 = ($$0$ph5$i$i$i$i|0)==($11|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (($$0$ph5$i$i$i$i) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($13|0)<($24|0);
 $26 = (($$0$ph5$i$i$i$i) + 20|0);
 $$$i = $25 ? 0 : $26;
 if ($25) {
  STACKTOP = sp;return;
 }
 $27 = (($$$i) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($texture) + 64|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($texture) + 68|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($4) + -1)|0;
 $35 = $34 & $4;
 $36 = ($35|0)==(0);
 if ($36) {
  $37 = (($8) + -1)|0;
  $38 = $37 & $8;
  $39 = ($38|0)==(0);
  $44 = $39;
 } else {
  $44 = 0;
 }
 $40 = HEAP32[$texture>>2]|0;
 $41 = (($40) + 92|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (FUNCTION_TABLE_ii[$42 & 4095]($texture)|0);
 $$not = ($43|0)!=(2);
 $brmerge = $$not | $44;
 if (!($brmerge)) {
  $45 = HEAP32[$texture>>2]|0;
  $46 = (($45) + 112|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (FUNCTION_TABLE_ii[$47 & 4095]($texture)|0);
  if (!($48)) {
   $49 = (__ZN7Texture21GetMasterTextureLimitEv()|0);
   $50 = HEAP32[$texture>>2]|0;
   $51 = (($50) + 124|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (FUNCTION_TABLE_ii[$52 & 4095]($texture)|0);
   $$ = $53 ? $49 : 0;
   $54 = $8 >> $$;
   $55 = HEAP32[$texture>>2]|0;
   $56 = (($55) + 116|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (FUNCTION_TABLE_ii[$57 & 4095]($texture)|0);
   $59 = $58 >> $$;
   $60 = HEAP32[$texture>>2]|0;
   $61 = (($60) + 120|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (FUNCTION_TABLE_ii[$62 & 4095]($texture)|0);
   $64 = $63 >> $$;
   $65 = ($59|0)>(0);
   if ($65) {
    $66 = $4 >> $$;
    $67 = (Math_fround(($66|0)));
    $68 = (Math_fround(($59|0)));
    $69 = Math_fround($67 / $68);
    $75 = $69;
   } else {
    $75 = Math_fround(1.0);
   }
   $70 = ($64|0)>(0);
   if ($70) {
    $71 = (Math_fround(($54|0)));
    $72 = (Math_fround(($64|0)));
    $73 = Math_fround($71 / $72);
    $77 = $73;
   } else {
    $77 = Math_fround(1.0);
   }
   $74 = Math_fround($31 * $75);
   $76 = Math_fround($33 * $77);
   $78 = HEAP32[$$$i>>2]|0;
   $79 = HEAP32[$texture>>2]|0;
   $80 = (($79) + 100|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (FUNCTION_TABLE_ii[$81 & 4095]($texture)|0);
   HEAP32[$0>>2] = $82;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __ZN9ShaderLab6TexEnv19OverrideTextureInfoE9TextureIDff($78,$$byval_copy,$74,$76);
   $83 = HEAP32[$27>>2]|0;
   HEAPF32[$83>>2] = $74;
   $84 = (($83) + 4|0);
   HEAPF32[$84>>2] = $76;
   $85 = (($83) + 8|0);
   HEAPF32[$85>>2] = Math_fround(0.0);
   $86 = (($83) + 12|0);
   HEAPF32[$86>>2] = Math_fround(0.0);
   STACKTOP = sp;return;
  }
 }
 $87 = HEAP32[$27>>2]|0;
 HEAPF32[$87>>2] = $31;
 $88 = (($87) + 4|0);
 HEAPF32[$88>>2] = $33;
 $89 = (($87) + 8|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 $90 = (($87) + 12|0);
 HEAPF32[$90>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN5RectTIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI7TextureE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN5RectTIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i3 = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $this;$12 = $$pre;$14 = $$pre16;$8 = $$pre$i$i$i3;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i8 = HEAP32[$10>>2]|0;
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $10;$17 = $$pre$i$i$i8;$21 = $$pre17;$23 = $$pre18;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i13 = HEAP32[$19>>2]|0;
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $19;$26 = $$pre$i$i$i13;$30 = $$pre19;$32 = $$pre20;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i = HEAP32[$28>>2]|0;
  $$pre$phi$i$i$iZ2D = $28;$35 = $$pre$i$i$i;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $36;
  STACKTOP = sp;return;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $28;$35 = $34;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $36;
  STACKTOP = sp;return;
 }
}
function __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i3 = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $this;$12 = $$pre;$14 = $$pre16;$8 = $$pre$i$i$i3;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i8 = HEAP32[$10>>2]|0;
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $10;$17 = $$pre$i$i$i8;$21 = $$pre17;$23 = $$pre18;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i13 = HEAP32[$19>>2]|0;
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $19;$26 = $$pre$i$i$i13;$30 = $$pre19;$32 = $$pre20;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i = HEAP32[$28>>2]|0;
  $$pre$phi$i$i$iZ2D = $28;$35 = $$pre$i$i$i;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $36;
  STACKTOP = sp;return;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $28;$35 = $34;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $36;
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI7TextureE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN5RectTIfE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI7TextureE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580584>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  $5 = (($this) + 12|0);
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $13)|0;
  $$sum$i$i$i = (($9) - ($16))|0;
  $17 = (($11) + ($$sum$i$i$i)|0);
  HEAP32[$5>>2] = $17;
  $18 = ($$sum$i$i$i|0)<(0);
  if ($18) {
   label = 6;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
   $19 = (($11) + ($$sum1$i$i$i)|0);
   $20 = (($this) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19>>>0)>($21>>>0);
   if ($22) {
    label = 6;
   } else {
    $23 = Math_fround(HEAPF32[$17>>2]);
    HEAPF32[$data>>2] = $23;
    HEAP32[$5>>2] = $19;
   }
  }
  if ((label|0) == 6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,4);
  }
  $24 = HEAP32[$this>>2]|0;
  $25 = $24 & 512;
  $26 = ($25|0)==(0);
  if (!($26)) {
   $27 = HEAP32[$data>>2]|0;
   $28 = (_llvm_bswap_i32(($27|0))|0);
   HEAP32[$data>>2] = $28;
  }
 } else {
  $29 = HEAP32[$converter$i>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   (FUNCTION_TABLE_iii[$29 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI7TextureE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,567960,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,567976,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,567960,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,567976,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN5RectTIfE8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567896,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567904,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567912,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567920,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = (__ZNK16TypeTreeIterator7GetNodeEv($0)|0);
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 | 2097152;
 $5 = (($transfer) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($transfer) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($7) + (($9*24)|0)|0) + 20|0);
 HEAP32[$10>>2] = $4;
 $11 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567928,$11,$this,1);
 $12 = HEAP32[$5>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$8>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567936,$11,$16,1);
 $17 = HEAP32[$5>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$8>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $21 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567944,$11,$21,1);
 $22 = HEAP32[$5>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$8>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $26 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,567952,$11,$26,1);
 $27 = HEAP32[$5>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$8>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9BehaviourD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i2$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((589992 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$this>>2] = ((562072 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    STACKTOP = sp;return;
   }
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __THREW__ = 0;
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $10 = ___cxa_find_matching_catch(0|0)|0;
    $11 = tempRet0;
    ___clang_call_terminate($10);
    // unreachable;
   } else {
    ___resumeException($6|0);
    // unreachable;
   }
  }
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   $18 = ___cxa_find_matching_catch(0|0)|0;
   $19 = tempRet0;
   __THREW__ = 0;
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch(0|0)|0;
    $23 = tempRet0;
    ___clang_call_terminate($22);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $18;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   ___resumeException($12|0);
   // unreachable;
  }
  $24 = ___cxa_find_matching_catch(0|0)|0;
  $25 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $24;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 }
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 HEAP32[$this>>2] = ((562072 + 8|0));
 __THREW__ = 0;
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $40 = ___cxa_find_matching_catch(0|0)|0;
  $41 = tempRet0;
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   $46 = ___cxa_find_matching_catch(0|0)|0;
   $47 = tempRet0;
   __THREW__ = 0;
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $50 = ___cxa_find_matching_catch(0|0)|0;
    $51 = tempRet0;
    ___clang_call_terminate($50);
    // unreachable;
   } else {
    $eh$lpad$body$i2$indexZ2D = $46;
    ___clang_call_terminate($eh$lpad$body$i2$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $44 = __THREW__; __THREW__ = 0;
  $45 = $44&1;
  if (!($45)) {
   $eh$lpad$body$indexZ2D = $40;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
  $52 = ___cxa_find_matching_catch(0|0)|0;
  $53 = tempRet0;
  $eh$lpad$body$i2$indexZ2D = $52;
  ___clang_call_terminate($eh$lpad$body$i2$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch(0|0)|0;
   $33 = tempRet0;
   __THREW__ = 0;
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $36 = ___cxa_find_matching_catch(0|0)|0;
    $37 = tempRet0;
    ___clang_call_terminate($36);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $32;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if (!($39)) {
   ___resumeException($26|0);
   // unreachable;
  }
  $54 = ___cxa_find_matching_catch(0|0)|0;
  $55 = tempRet0;
  $eh$lpad$body$indexZ2D = $54;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __GLOBAL__I_a1629() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,567808);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[567800>>2] = $1;
 HEAP32[567824>>2] = 13;
 HEAP32[567832>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13BatchRendererC2ER15RenderLoopStats($this,$stats) {
 $this = $this|0;
 $stats = $stats|0;
 var $$byval_copy12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy12 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = HEAP32[628512>>2]|0;
 HEAP32[$this>>2] = 0;
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 20|0);
 HEAP32[$10>>2] = $5;
 $11 = (($this) + 24|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 32|0);
 $14 = HEAP32[641904>>2]|0;
 HEAP32[$13>>2] = $14;
 $15 = (($this) + 36|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 40|0);
 HEAP32[$16>>2] = 0;
 $17 = HEAP32[628512>>2]|0;
 $18 = (($this) + 44|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 48|0);
 HEAP32[$19>>2] = $17;
 $20 = (($this) + 52|0);
 $21 = (($this) + 56|0);
 $22 = (($this) + 72|0);
 ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;
 HEAP32[$22>>2] = $stats;
 __THREW__ = 0;
 $23 = (invoke_i(59)|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if (!($25)) {
   __THREW__ = 0;
   invoke_vii(2610,($this|0),($23|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[$21>>2]|0;
    $29 = $28 & 2147483520;
    $30 = ($29>>>0)<(128);
    if (!($30)) {
     $44 = (($this) + 68|0);
     HEAP8[$44>>0] = 1;
     STACKTOP = sp;return;
    }
    $31 = ($28|0)>(-1);
    if ($31) {
     HEAP32[$21>>2] = 128;
     $32 = HEAP32[$18>>2]|0;
     $33 = HEAP32[$19>>2]|0;
     HEAP32[$1>>2] = $33;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
     $34 = (invoke_iiiiiiii(108,($32|0),9728,4,($$byval_copy12|0),0,(568152|0),370)|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     HEAP32[$18>>2] = $34;
     $44 = (($this) + 68|0);
     HEAP8[$44>>0] = 1;
     STACKTOP = sp;return;
    } else {
     $37 = HEAP32[$19>>2]|0;
     HEAP32[$2>>2] = $37;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
     $38 = (invoke_iiiiiii(102,9728,4,($$byval_copy12|0),0,(568152|0),352)|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     $41 = HEAP32[$18>>2]|0;
     $42 = HEAP32[$20>>2]|0;
     $43 = ($42*76)|0;
     _memcpy(($38|0),($41|0),($43|0))|0;
     HEAP32[$21>>2] = 128;
     HEAP32[$18>>2] = $38;
     $44 = (($this) + 68|0);
     HEAP8[$44>>0] = 1;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $45 = ___cxa_find_matching_catch()|0;
 $46 = tempRet0;
 $47 = HEAP32[$21>>2]|0;
 $48 = ($47|0)>(-1);
 if ($48) {
  $49 = HEAP32[$18>>2]|0;
  $50 = HEAP32[$19>>2]|0;
  HEAP32[$0>>2] = $50;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($49|0),($$byval_copy12|0));
  $51 = __THREW__; __THREW__ = 0;
  $52 = $51&1;
  if (!($52)) {
   HEAP32[$18>>2] = 0;
   label = 13;
  }
 } else {
  label = 13;
 }
 if ((label|0) == 13) {
  $53 = HEAP32[$12>>2]|0;
  $54 = ($53|0)>(-1);
  do {
   if ($54) {
    $55 = HEAP32[$9>>2]|0;
    $56 = HEAP32[$10>>2]|0;
    HEAP32[$4>>2] = $56;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($55|0),($$byval_copy12|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if (!($58)) {
     HEAP32[$9>>2] = 0;
     break;
    }
    $65 = ___cxa_find_matching_catch(0|0)|0;
    $66 = tempRet0;
    $67 = HEAP32[$8>>2]|0;
    $68 = ($67|0)>(-1);
    if (!($68)) {
     $eh$lpad$body$indexZ2D = $65;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
    $69 = HEAP32[$this>>2]|0;
    $70 = HEAP32[$6>>2]|0;
    HEAP32[$0>>2] = $70;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($69|0),($$byval_copy12|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     $73 = ___cxa_find_matching_catch(0|0)|0;
     $74 = tempRet0;
     ___clang_call_terminate($73);
     // unreachable;
    }
    HEAP32[$this>>2] = 0;
    $eh$lpad$body$indexZ2D = $65;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  } while(0);
  $59 = HEAP32[$8>>2]|0;
  $60 = ($59|0)>(-1);
  if (!($60)) {
   ___resumeException($45|0);
   // unreachable;
  }
  $61 = HEAP32[$this>>2]|0;
  $62 = HEAP32[$6>>2]|0;
  HEAP32[$3>>2] = $62;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($61|0),($$byval_copy12|0));
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if (!($64)) {
   HEAP32[$this>>2] = 0;
   ___resumeException($45|0);
   // unreachable;
  }
 }
 $75 = ___cxa_find_matching_catch(0|0)|0;
 $76 = tempRet0;
 $eh$lpad$body$indexZ2D = $75;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN13BatchRenderer3AddER12BaseRendererRK13TransformInfoiPK14ChannelAssigns($this,$renderer,$transformInfo,$subsetIndex,$channels) {
 $this = $this|0;
 $renderer = $renderer|0;
 $transformInfo = $transformInfo|0;
 $subsetIndex = $subsetIndex|0;
 $channels = $channels|0;
 var $$byval_copy1 = 0, $$not = 0, $$off0 = 0, $$off0$not = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $brmerge = 0, $extract$t = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  __ZN28ApplyBuiltinInstanceProperty30PerformFlushMaterialPropertiesEv($this);
 }
 $4 = (($channels) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$renderer>>2]|0;
 $7 = (($6) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($renderer)|0);
 if ($9) {
  $10 = $5 & 1;
  $extract$t = ($10|0)!=(0);
  $$off0 = $extract$t;
 } else {
  $$off0 = 0;
 }
 $11 = (($renderer) + 40|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = (($this) + 60|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($channels|0);
 if ($16) {
  $17 = (($this) + 64|0);
  $18 = HEAP32[$17>>2]|0;
  $$not = ($18|0)!=($13|0);
  $$off0$not = $$off0 ^ 1;
  $brmerge = $$not | $$off0$not;
  if ($brmerge) {
   label = 7;
  }
 } else {
  label = 7;
 }
 if ((label|0) == 7) {
  $19 = (($this) + 52|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if (!($21)) {
   $22 = (($this) + 44|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($20|0)==(1);
   if ($24) {
    $25 = (($23) + 72|0);
    $26 = HEAP32[$25>>2]|0;
    __Z17SetupObjectMatrixRK10Matrix4x4fi($23,$26);
    $27 = (($23) + 64|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$28>>2]|0;
    $30 = (($29) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($23) + 68|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_viii[$31 & 4095]($28,$33,$34);
   } else {
    HEAP32[$$byval_copy1>>2] = $23;
    $35 = (($$byval_copy1) + 4|0);
    HEAP32[$35>>2] = $20;
    $36 = (($this) + 68|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = ($37<<24>>24)==(0);
    if ($38) {
     $43 = 0;$49 = $15;
    } else {
     $39 = (__Z16GetBuildSettingsv()|0);
     $40 = (($39) + 95|0);
     $41 = HEAP8[$40>>0]|0;
     $$pre = HEAP32[$14>>2]|0;
     $43 = $41;$49 = $$pre;
    }
    $42 = (($$byval_copy1) + 8|0);
    HEAP8[$42>>0] = $43;
    $44 = (($23) + 64|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    FUNCTION_TABLE_viii[$48 & 4095]($45,$$byval_copy1,$49);
   }
   HEAP32[$19>>2] = 0;
  }
  HEAP32[$14>>2] = $channels;
  $50 = (($this) + 64|0);
  HEAP32[$50>>2] = $13;
 }
 if (!($$off0)) {
  $85 = (($transformInfo) + 112|0);
  $86 = HEAP32[$85>>2]|0;
  __Z17SetupObjectMatrixRK10Matrix4x4fi($transformInfo,$86);
  $87 = HEAP32[$renderer>>2]|0;
  $88 = (($87) + 8|0);
  $89 = HEAP32[$88>>2]|0;
  FUNCTION_TABLE_viii[$89 & 4095]($renderer,$subsetIndex,$channels);
  STACKTOP = sp;return;
 }
 $51 = (($this) + 44|0);
 $52 = (($this) + 52|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$52>>2] = $54;
 $55 = (($this) + 56|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = $56 & 2147483647;
 $58 = ($54>>>0)>($57>>>0);
 if ($58) {
  $59 = $56 << 1;
  $60 = ($59|0)==(0);
  $61 = $60 ? 1 : $59;
  $62 = ($57>>>0)<($61>>>0);
  do {
   if ($62) {
    $63 = ($56|0)>(-1);
    if ($63) {
     HEAP32[$55>>2] = $61;
     $64 = HEAP32[$51>>2]|0;
     $65 = ($61*76)|0;
     $66 = (($this) + 48|0);
     $67 = HEAP32[$66>>2]|0;
     HEAP32[$0>>2] = $67;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $68 = (__Z16realloc_internalPvji10MemLabelIdiPKci($64,$65,4,$$byval_copy1,0,568152,370)|0);
     HEAP32[$51>>2] = $68;
     break;
    } else {
     $69 = ($61*76)|0;
     $70 = (($this) + 48|0);
     $71 = HEAP32[$70>>2]|0;
     HEAP32[$0>>2] = $71;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $72 = (__Z15malloc_internaljj10MemLabelIdiPKci($69,4,$$byval_copy1,0,568152,352)|0);
     $73 = HEAP32[$51>>2]|0;
     $74 = HEAP32[$52>>2]|0;
     $75 = ($74*76)|0;
     _memcpy(($72|0),($73|0),($75|0))|0;
     HEAP32[$55>>2] = $61;
     HEAP32[$51>>2] = $72;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$52>>2]|0;
  $77 = $$pre$i;
 } else {
  $77 = $54;
 }
 $76 = (($77) + -1)|0;
 $78 = HEAP32[$51>>2]|0;
 $79 = (($78) + (($76*76)|0)|0);
 $80 = ((($78) + (($76*76)|0)|0) + 64|0);
 HEAP32[$80>>2] = $renderer;
 $81 = ((($78) + (($76*76)|0)|0) + 68|0);
 HEAP32[$81>>2] = $subsetIndex;
 dest=$79+0|0; src=$transformInfo+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $82 = (($transformInfo) + 112|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ((($78) + (($76*76)|0)|0) + 72|0);
 HEAP32[$84>>2] = $83;
 STACKTOP = sp;return;
}
function __ZN13BatchRenderer5FlushEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $batchData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $batchData = sp;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($1|0)==(1);
 if ($5) {
  $6 = (($4) + 72|0);
  $7 = HEAP32[$6>>2]|0;
  __Z17SetupObjectMatrixRK10Matrix4x4fi($4,$7);
  $8 = (($4) + 64|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($4) + 68|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($this) + 60|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viii[$12 & 4095]($9,$14,$16);
 } else {
  HEAP32[$batchData>>2] = $4;
  $17 = (($batchData) + 4|0);
  HEAP32[$17>>2] = $1;
  $18 = (($this) + 68|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   $25 = 0;
  } else {
   $21 = (__Z16GetBuildSettingsv()|0);
   $22 = (($21) + 95|0);
   $23 = HEAP8[$22>>0]|0;
   $25 = $23;
  }
  $24 = (($batchData) + 8|0);
  HEAP8[$24>>0] = $25;
  $26 = (($4) + 64|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 16|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($this) + 60|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_viii[$30 & 4095]($27,$batchData,$32);
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13BatchRenderer12RenderSingleER12BaseRendererRK13TransformInfoiPK14ChannelAssigns($this,$renderer,$transformInfo,$subsetIndex,$channels) {
 $this = $this|0;
 $renderer = $renderer|0;
 $transformInfo = $transformInfo|0;
 $subsetIndex = $subsetIndex|0;
 $channels = $channels|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN28ApplyBuiltinInstanceProperty30PerformFlushMaterialPropertiesEv($this);
 }
 $3 = (($transformInfo) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 __Z17SetupObjectMatrixRK10Matrix4x4fi($transformInfo,$4);
 $5 = HEAP32[$renderer>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_viii[$7 & 4095]($renderer,$subsetIndex,$channels);
 STACKTOP = sp;return;
}
function __ZN28ApplyBuiltinInstanceProperty4InitER9GfxDevice($this,$inputDevice) {
 $this = $this|0;
 $inputDevice = $inputDevice|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = $inputDevice;
 $1 = (($inputDevice) + 4|0);
 $2 = (($this) + 36|0);
 HEAP32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN28ApplyBuiltinInstanceProperty30PerformFlushMaterialPropertiesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 216|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$this);
 $5 = (($this) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[641904>>2]|0;
 $8 = (($this) + 32|0);
 HEAP32[$8>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNK23ForwardShaderRenderLoop19SetLightShadowPropsERK5LightP7TextureRK10Matrix4x4fbRN9ShaderLab17ShaderPassContextE($this,$light,$shadowMap,$shadowMatrix,$useDualInForward,$passContext) {
 $this = $this|0;
 $light = $light|0;
 $shadowMap = $shadowMap|0;
 $shadowMatrix = $shadowMatrix|0;
 $useDualInForward = $useDualInForward|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = Math_fround(0), $lightFade = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $lightFade = sp;
 $0 = (($light) + 124|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($passContext) + 20|0);
 $3 = (__Z12GetGfxDevicev()|0);
 $4 = (($3) + 3044|0);
 __Z13CopyMatrixREFPKfPf($shadowMatrix,$4);
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($2,568160,$shadowMap)|0);
 $5 = (($light) + 216|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(2);
 if ($7) {
  $8 = (($light) + 104|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($light) + 108|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($light) + 112|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($light) + 188|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround(Math_fround(1.0) / $15);
  $17 = (($3) + 644|0);
  HEAPF32[$17>>2] = $9;
  $18 = (($3) + 648|0);
  HEAPF32[$18>>2] = $11;
  $19 = (($3) + 652|0);
  HEAPF32[$19>>2] = $13;
  $20 = (($3) + 656|0);
  HEAPF32[$20>>2] = $16;
 }
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 168|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($this) + 172|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 __Z24CalculateLightShadowFadeRK6CamerafffR8Vector4f($22,$1,$24,$26,$lightFade);
 $27 = (($3) + 676|0);
 ;HEAP32[$27+0>>2]=HEAP32[$lightFade+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$lightFade+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$lightFade+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$lightFade+12>>2]|0;
 if ($useDualInForward) {
  $28 = (($lightFade) + 12|0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  $29 = (($lightFade) + 8|0);
  HEAPF32[$29>>2] = Math_fround(0.0);
 }
 $30 = (($3) + 772|0);
 ;HEAP32[$30+0>>2]=HEAP32[$lightFade+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$lightFade+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$lightFade+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$lightFade+12>>2]|0;
 $31 = HEAP32[$shadowMap>>2]|0;
 $32 = (($31) + 116|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 4095]($shadowMap)|0);
 $35 = (Math_fround(($34|0)));
 $36 = Math_fround(Math_fround(0.5) / $35);
 $37 = HEAP32[$shadowMap>>2]|0;
 $38 = (($37) + 120|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (FUNCTION_TABLE_ii[$39 & 4095]($shadowMap)|0);
 $41 = (Math_fround(($40|0)));
 $42 = Math_fround(Math_fround(0.5) / $41);
 $43 = Math_fround(-$36);
 $44 = Math_fround(-$42);
 $45 = (($3) + 708|0);
 HEAPF32[$45>>2] = $43;
 $46 = (($3) + 712|0);
 HEAPF32[$46>>2] = $44;
 $47 = (($3) + 716|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($3) + 720|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($3) + 724|0);
 HEAPF32[$49>>2] = $36;
 $50 = (($3) + 728|0);
 HEAPF32[$50>>2] = $44;
 $51 = (($3) + 732|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($3) + 736|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($3) + 740|0);
 HEAPF32[$53>>2] = $43;
 $54 = (($3) + 744|0);
 HEAPF32[$54>>2] = $42;
 $55 = (($3) + 748|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($3) + 752|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($3) + 756|0);
 HEAPF32[$57>>2] = $36;
 $58 = (($3) + 760|0);
 HEAPF32[$58>>2] = $42;
 $59 = (($3) + 764|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($3) + 768|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN23ForwardShaderRenderLoop16PerformRenderingEPK11ActiveLightP13RenderTextureRK14ShadowCullDatabbbb($this,$mainDirShadowLight,$existingShadowMap,$shadowCullData,$disableDynamicBatching,$sRGBrenderTarget,$clearFrameBuffer,$opaque) {
 $this = $this|0;
 $mainDirShadowLight = $mainDirShadowLight|0;
 $existingShadowMap = $existingShadowMap|0;
 $shadowCullData = $shadowCullData|0;
 $disableDynamicBatching = $disableDynamicBatching|0;
 $sRGBrenderTarget = $sRGBrenderTarget|0;
 $clearFrameBuffer = $clearFrameBuffer|0;
 $opaque = $opaque|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i18 = 0, $$0$i$i$i$i8 = 0, $$0$i$i$i12 = 0, $$0$i$i$i22 = 0, $$0$i25 = 0, $$01$i$i$i = 0, $$01$i$i$i10 = 0, $$01$i$i$i20 = 0, $$04 = 0, $$05 = 0, $$1 = 0, $$existingShadowMap = 0, $$lcssa30 = 0, $$lcssa66 = 0, $$mainDirShadowLight = 0, $$pre = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0);
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = Math_fround(0), $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $batchRenderer = 0, $camData = 0, $channels$071 = 0, $channels$2 = 0;
 var $channels$3 = 0, $currentMaxQueue$072 = 0, $currentMaxQueue$1 = 0, $defaultReflection = 0, $disableDynamicBatching$ = 0, $fadeCenterAndType = 0, $i$01$i$i$i = 0, $i$01$i$i$i$i = 0, $index$070 = 0, $it$076 = 0, $it5$035 = 0, $lightNo$059 = 0, $lightmapSTCache = 0, $lpad$phi$index = 0, $lpad$phi$index6 = 0, $not$ = 0, $oldScissorRect = 0, $or$cond = 0, $or$cond6 = 0, $or$cond99 = 0;
 var $prevRenderState = 0, $reflectionProbeCache = 0, $reflectionSample = 0, $rs = 0, $shConstantCache = 0, $shouldResetPass$0$off0 = 0, $sl$01$i = 0, $sl$050 = 0, $stats = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1552|0;
 $oldScissorRect = sp + 1520|0;
 $camData = sp + 792|0;
 $fadeCenterAndType = sp + 776|0;
 $prevRenderState = sp + 736|0;
 $stats = sp + 1536|0;
 $batchRenderer = sp + 656|0;
 $shConstantCache = sp + 432|0;
 $reflectionProbeCache = sp + 260|0;
 $lightmapSTCache = sp + 248|0;
 $defaultReflection = sp + 124|0;
 $reflectionSample = sp;
 $rs = sp + 392|0;
 $0 = (__Z16GetRenderManagerv()|0);
 $1 = (($0) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 92|0);
 $4 = HEAP32[652824>>2]|0;
 __Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE($4);
 $5 = (__Z12GetGfxDevicev()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 192|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095]($oldScissorRect,$5);
 $9 = HEAP32[$5>>2]|0;
 $10 = (($9) + 188|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($5)|0);
 $13 = (__Z13GetGISettingsv()|0);
 $14 = (($13) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (__Z12GetGfxDevicev()|0);
 $17 = (($16) + 692|0);
 HEAPF32[$17>>2] = $15;
 $18 = (($16) + 696|0);
 HEAPF32[$18>>2] = $15;
 $19 = (($16) + 700|0);
 HEAPF32[$19>>2] = $15;
 $20 = (($16) + 704|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (__Z21GetSoftShadowsEnabledv()|0);
 _memcpy(($camData|0),($shadowCullData|0),612)|0;
 $22 = ($mainDirShadowLight|0)!=(0|0);
 if ($22) {
  $595 = 1;
 } else {
  $23 = (($this) + 160|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)!=(0);
  $595 = $25;
 }
 $26 = (__Z19GetLightmapSettingsv()|0);
 $27 = (__ZNK16LightmapSettings28GetUseDualLightmapsInForwardEv($26)|0);
 $28 = HEAP8[((640792 + 250|0))>>0]|0;
 $29 = ($28<<24>>24)==(0);
 $$existingShadowMap = $29 ? 0 : $existingShadowMap;
 $30 = HEAP32[$this>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 168|0);
 $33 = (($this) + 172|0);
 __Z33CalculateLightShadowCenterAndTypeRK6CameraR8Vector4fRfS4_($31,$fadeCenterAndType,$32,$33);
 $34 = (($5) + 932|0);
 ;HEAP32[$34+0>>2]=HEAP32[$fadeCenterAndType+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$fadeCenterAndType+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$fadeCenterAndType+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$fadeCenterAndType+12>>2]|0;
 do {
  if ($22) {
   $35 = ($$existingShadowMap|0)==(0|0);
   if (!($35)) {
    $64 = (($this) + 60|0);
    HEAP32[$64>>2] = $$existingShadowMap;
    $$1 = $mainDirShadowLight;
    break;
   }
   $36 = (($this) + 56|0);
   $37 = (($this) + 128|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($38 + Math_fround(-0.00999999977648258209228));
   HEAPF32[$37>>2] = $39;
   $40 = (($this) + 132|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = Math_fround($41 + Math_fround(-0.00999999977648258209228));
   HEAPF32[$40>>2] = $42;
   $43 = (($this) + 136|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = Math_fround($44 + Math_fround(-0.00999999977648258209228));
   HEAPF32[$43>>2] = $45;
   $46 = (($this) + 140|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = Math_fround($47 + Math_fround(0.00999999977648258209228));
   HEAPF32[$46>>2] = $48;
   $49 = (($this) + 144|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = Math_fround($50 + Math_fround(0.00999999977648258209228));
   HEAPF32[$49>>2] = $51;
   $52 = (($this) + 148|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = Math_fround($53 + Math_fround(0.00999999977648258209228));
   HEAPF32[$52>>2] = $54;
   HEAP32[$36>>2] = $mainDirShadowLight;
   __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(1);
   __THREW__ = 0;
   invoke_viiiiiii(64,($this|0),($36|0),($camData|0),($21|0),($27|0),($clearFrameBuffer|0),($4|0));
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if (!($56)) {
    $57 = (($this) + 60|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($58|0)==(0|0);
    $$mainDirShadowLight = $59 ? 0 : $mainDirShadowLight;
    __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(0);
    $$1 = $$mainDirShadowLight;
    break;
   }
   $60 = ___cxa_find_matching_catch()|0;
   $61 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3396,0);
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if ($63) {
    $593 = ___cxa_find_matching_catch(0|0)|0;
    $594 = tempRet0;
    ___clang_call_terminate($593);
    // unreachable;
   } else {
    $$04 = $60;$$05 = $61;
    ___resumeException($$04|0);
    // unreachable;
   }
  } else {
   $$1 = 0;
  }
 } while(0);
 $65 = (($this) + 152|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($this) + 160|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + (($68*96)|0)|0);
 $70 = ($68|0)==(0);
 if (!($70)) {
  $it$076 = $66;
  while(1) {
   $71 = (($it$076) + 72|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = Math_fround($72 + Math_fround(-0.00999999977648258209228));
   HEAPF32[$71>>2] = $73;
   $74 = (($it$076) + 76|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = Math_fround($75 + Math_fround(-0.00999999977648258209228));
   HEAPF32[$74>>2] = $76;
   $77 = (($it$076) + 80|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = Math_fround($78 + Math_fround(-0.00999999977648258209228));
   HEAPF32[$77>>2] = $79;
   $80 = (($it$076) + 84|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   $82 = Math_fround($81 + Math_fround(0.00999999977648258209228));
   HEAPF32[$80>>2] = $82;
   $83 = (($it$076) + 88|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   $85 = Math_fround($84 + Math_fround(0.00999999977648258209228));
   HEAPF32[$83>>2] = $85;
   $86 = (($it$076) + 92|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = Math_fround($87 + Math_fround(0.00999999977648258209228));
   HEAPF32[$86>>2] = $88;
   __ZN23ForwardShaderRenderLoop21RenderLightShadowMapsER16ForwardShadowMapR16ShadowCameraDatabbbRN9ShaderLab17ShaderPassContextE($this,$it$076,$camData,$21,0,$clearFrameBuffer,$4);
   $89 = (($it$076) + 96|0);
   $90 = ($89|0)==($69|0);
   if ($90) {
    break;
   } else {
    $it$076 = $89;
   }
  }
 }
 if ($595) {
  $91 = HEAP32[$this>>2]|0;
  $92 = HEAP32[$91>>2]|0;
  __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($92,$4,2);
  __Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE($4);
 }
 $93 = (__Z17GetRenderSettingsv()|0);
 $94 = (__Z19GetLightmapSettingsv()|0);
 __Z14SetupLightmapsRK16LightmapSettings($94);
 $95 = (($this) + 48|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = HEAP32[$this>>2]|0;
 $98 = (($97) + 108|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = HEAP32[$5>>2]|0;
 $101 = (($100) + 100|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = (($97) + 12|0);
 FUNCTION_TABLE_vii[$102 & 4095]($5,$103);
 $104 = (($prevRenderState) + 8|0);
 HEAPF32[$104>>2] = Math_fround(-1.0);
 HEAP32[$prevRenderState>>2] = 0;
 $105 = (($prevRenderState) + 4|0);
 HEAP32[$105>>2] = 0;
 $106 = (($prevRenderState) + 20|0);
 HEAP32[$106>>2] = -1;
 $107 = (($prevRenderState) + 12|0);
 $108 = (($107) + 2|0);
 HEAP16[$108>>1] = 255;
 HEAP16[$107>>1] = 255;
 $109 = (($prevRenderState) + 16|0);
 HEAP32[$109>>2] = -1;
 $110 = (($prevRenderState) + 24|0);
 HEAP32[$110>>2] = 11;
 $111 = (($prevRenderState) + 28|0);
 HEAP32[$111>>2] = -1;
 $112 = (($prevRenderState) + 32|0);
 HEAP32[$112>>2] = 0;
 $113 = (($prevRenderState) + 36|0);
 HEAP32[$113>>2] = -1;
 $114 = HEAP32[$5>>2]|0;
 $115 = (($114) + 72|0);
 $116 = HEAP32[$115>>2]|0;
 FUNCTION_TABLE_vii[$116 & 4095]($5,$sRGBrenderTarget);
 if ($clearFrameBuffer) {
  $117 = HEAP32[$this>>2]|0;
  $118 = HEAP32[$117>>2]|0;
  __ZN6Camera13ClearNoSkyboxEb($118,0);
 } else {
  $119 = HEAP32[$5>>2]|0;
  $120 = (($119) + 408|0);
  $121 = HEAP32[$120>>2]|0;
  FUNCTION_TABLE_vi[$121 & 4095]($5);
 }
 __ZNK14RenderSettings12SetupAmbientEv($93);
 $122 = HEAP32[$this>>2]|0;
 $123 = HEAP32[$122>>2]|0;
 $124 = $opaque ? 10 : 16;
 $125 = (($123) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($125,$124,$4);
 __ZN13BatchRendererC2ER15RenderLoopStats($batchRenderer,$stats);
 __THREW__ = 0;
 invoke_viii(1659,($shConstantCache|0),($batchRenderer|0),($stats|0));
 $126 = __THREW__; __THREW__ = 0;
 $127 = $126&1;
 L27: do {
  if ($127) {
   label = 40;
  } else {
   __THREW__ = 0;
   invoke_viii(1660,($reflectionProbeCache|0),($batchRenderer|0),($stats|0));
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    label = 40;
   } else {
    __THREW__ = 0;
    invoke_viii(1661,($lightmapSTCache|0),($batchRenderer|0),($stats|0));
    $130 = __THREW__; __THREW__ = 0;
    $131 = $130&1;
    if ($131) {
     label = 40;
    } else {
     __THREW__ = 0;
     $132 = (invoke_i(60)|0);
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if ($134) {
      label = 40;
     } else {
      __THREW__ = 0;
      invoke_vii(2611,($defaultReflection|0),($132|0));
      $135 = __THREW__; __THREW__ = 0;
      $136 = $135&1;
      if ($136) {
       label = 40;
      } else {
       __THREW__ = 0;
       invoke_vi(3397,($reflectionSample|0));
       $137 = __THREW__; __THREW__ = 0;
       $138 = $137&1;
       if ($138) {
        label = 40;
       } else {
        $139 = ($96|0)==(0);
        L34: do {
         if ($139) {
          $$lcssa66 = $2;
         } else {
          $140 = (($this) + 40|0);
          $141 = (($this) + 4|0);
          $142 = (($this) + 8|0);
          $143 = (($this) + 24|0);
          $144 = (($rs) + 8|0);
          $145 = (($rs) + 4|0);
          $146 = (($rs) + 20|0);
          $147 = (($rs) + 16|0);
          $148 = (($rs) + 12|0);
          $149 = (($rs) + 24|0);
          $150 = (($rs) + 28|0);
          $151 = (($rs) + 32|0);
          $152 = (($rs) + 36|0);
          $153 = (($shConstantCache) + 108|0);
          $154 = (($shConstantCache) + 216|0);
          $155 = (($this) + 56|0);
          $156 = (($rs) + 12|0);
          $157 = ($$1|0)==(0|0);
          $158 = (($this) + 60|0);
          $159 = (($this) + 64|0);
          $160 = (($reflectionProbeCache) + 128|0);
          $182 = $2;$channels$071 = 0;$currentMaxQueue$072 = $99;$index$070 = 0;
          L36: while(1) {
           $161 = HEAP32[$140>>2]|0;
           $162 = HEAP32[$141>>2]|0;
           $163 = (($161) + ($index$070<<3)|0);
           $164 = HEAP32[$163>>2]|0;
           $165 = HEAP32[$162>>2]|0;
           $166 = HEAP32[$142>>2]|0;
           $167 = (($166) + ($164<<2)|0);
           $168 = HEAP32[$167>>2]|0;
           $169 = HEAP32[$143>>2]|0;
           $170 = (($169) + ($168)|0);
           $171 = ((($165) + (($164*44)|0)|0) + 4|0);
           $172 = HEAP16[$171>>1]|0;
           $173 = $172 << 16 >> 16;
           $174 = ($173|0)>($currentMaxQueue$072|0);
           L38: do {
            if ($174) {
             __THREW__ = 0;
             invoke_vi(3398,($batchRenderer|0));
             $175 = __THREW__; __THREW__ = 0;
             $176 = $175&1;
             if ($176) {
              label = 39;
              break L36;
             }
             $177 = HEAP32[$this>>2]|0;
             $178 = (($177) + 105|0);
             $179 = HEAP8[$178>>0]|0;
             $180 = ($179<<24>>24)==(0);
             if ($180) {
              $181 = ($182|0)==($3|0);
              if ($181) {
               $596 = $3;$currentMaxQueue$1 = $173;
              } else {
               $184 = $182;
               while(1) {
                $183 = (($184) + 16|0);
                $185 = HEAP32[$183>>2]|0;
                $186 = ($185|0)>($173|0);
                if ($186) {
                 $596 = $184;$currentMaxQueue$1 = $173;
                 break L38;
                }
                $187 = (($184) + 20|0);
                $188 = HEAP32[$187>>2]|0;
                $189 = HEAP32[$188>>2]|0;
                $190 = HEAP32[$189>>2]|0;
                $191 = HEAP32[$this>>2]|0;
                $192 = (($191) + 4|0);
                $193 = HEAP32[$192>>2]|0;
                __THREW__ = 0;
                invoke_viii($190|0,($188|0),($193|0),($4|0));
                $194 = __THREW__; __THREW__ = 0;
                $195 = $194&1;
                if ($195) {
                 label = 37;
                 break L36;
                }
                $196 = (($184) + 4|0);
                $197 = HEAP32[$196>>2]|0;
                $198 = ($197|0)==(0|0);
                if ($198) {
                 $$01$i$i$i20 = $184;
                 while(1) {
                  $201 = (($$01$i$i$i20) + 8|0);
                  $202 = HEAP32[$201>>2]|0;
                  $203 = HEAP32[$202>>2]|0;
                  $204 = ($203|0)==($$01$i$i$i20|0);
                  if ($204) {
                   $$0$i$i$i22 = $202;
                   break;
                  } else {
                   $$01$i$i$i20 = $202;
                  }
                 }
                } else {
                 $$0$i$i$i$i18 = $197;
                 while(1) {
                  $199 = HEAP32[$$0$i$i$i$i18>>2]|0;
                  $200 = ($199|0)==(0|0);
                  if ($200) {
                   $$0$i$i$i22 = $$0$i$i$i$i18;
                   break;
                  } else {
                   $$0$i$i$i$i18 = $199;
                  }
                 }
                }
                $205 = ($$0$i$i$i22|0)==($3|0);
                if ($205) {
                 $596 = $$0$i$i$i22;$currentMaxQueue$1 = $173;
                 break;
                } else {
                 $184 = $$0$i$i$i22;
                }
               }
              }
             } else {
              $596 = $182;$currentMaxQueue$1 = $173;
             }
            } else {
             $596 = $182;$currentMaxQueue$1 = $currentMaxQueue$072;
            }
           } while(0);
           $220 = ((($165) + (($164*44)|0)|0) + 32|0);
           $221 = HEAP32[$220>>2]|0;
           $222 = ((($165) + (($164*44)|0)|0) + 6|0);
           $223 = HEAP16[$222>>1]|0;
           $224 = (($221) + 120|0);
           $225 = Math_fround(HEAPF32[$224>>2]);
           HEAPF32[$144>>2] = $225;
           $226 = (($165) + (($164*44)|0)|0);
           $227 = HEAP32[$226>>2]|0;
           HEAP32[$rs>>2] = $227;
           $228 = ((($165) + (($164*44)|0)|0) + 36|0);
           $229 = HEAP32[$228>>2]|0;
           HEAP32[$145>>2] = $229;
           $230 = ((($165) + (($164*44)|0)|0) + 8|0);
           $231 = HEAP16[$230>>1]|0;
           $232 = $231 << 16 >> 16;
           HEAP32[$146>>2] = $232;
           $233 = (($221) + 116|0);
           $234 = HEAP32[$233>>2]|0;
           $235 = (($234) + 168|0);
           $236 = HEAP32[$235>>2]|0;
           $237 = ($236|0)==(0|0);
           if ($237) {
            $240 = 0;
           } else {
            $238 = (($236) + 32|0);
            $239 = HEAP32[$238>>2]|0;
            $240 = $239;
           }
           HEAP32[$147>>2] = $240;
           $241 = ((($165) + (($164*44)|0)|0) + 12|0);
           $242 = HEAP32[$241>>2]|0;
           HEAP32[$148>>2] = $242;
           $243 = ((($161) + ($index$070<<3)|0) + 4|0);
           $244 = HEAP32[$243>>2]|0;
           $245 = $244 >>> 8;
           $246 = $245 & 255;
           HEAP32[$149>>2] = $246;
           $247 = $244 & 255;
           HEAP32[$150>>2] = $247;
           HEAP32[$151>>2] = $170;
           if ($595) {
            $248 = HEAP32[$233>>2]|0;
            $249 = (($248) + 42|0);
            $250 = HEAP8[$249>>0]|0;
            $251 = ($250<<24>>24)==(0);
            if ($251) {
             $260 = 0;
            } else {
             $252 = HEAP32[$this>>2]|0;
             $253 = (($252) + 8|0);
             $254 = HEAP32[$253>>2]|0;
             $255 = (($221) + 64|0);
             __THREW__ = 0;
             $256 = (invoke_iii(2365,($254|0),($255|0))|0);
             $257 = __THREW__; __THREW__ = 0;
             $258 = $257&1;
             if ($258) {
              label = 39;
              break;
             } else {
              $260 = $256;
             }
            }
           } else {
            $260 = 0;
           }
           $259 = $260&1;
           HEAP32[$152>>2] = $259;
           $261 = HEAP32[$243>>2]|0;
           $262 = $261 & 33554432;
           $263 = HEAP32[$233>>2]|0;
           $264 = HEAP32[$263>>2]|0;
           $265 = (($264) + 52|0);
           $266 = HEAP32[$265>>2]|0;
           __THREW__ = 0;
           $267 = (invoke_ii($266|0,($263|0))|0);
           $268 = __THREW__; __THREW__ = 0;
           $269 = $268&1;
           if ($269) {
            label = 39;
            break;
           }
           $270 = ($267|0)==(0);
           if ($270) {
            $not$ = ($262|0)!=(0);
            $disableDynamicBatching$ = $not$ | $disableDynamicBatching;
            $597 = $disableDynamicBatching$;
           } else {
            $597 = 0;
           }
           $271 = HEAP32[$149>>2]|0;
           $272 = ($271|0)==(5);
           do {
            if ($272) {
             label = 52;
            } else {
             $273 = (__ZNK24ForwardShaderRenderStateeqERKS_($rs,$prevRenderState)|0);
             if (!($273)) {
              label = 52;
              break;
             }
             if (!($597)) {
              $279 = HEAP32[$145>>2]|0;
              $280 = Math_fround(HEAPF32[$144>>2]);
              __THREW__ = 0;
              $281 = (invoke_iif(27,($279|0),(+$280))|0);
              $282 = __THREW__; __THREW__ = 0;
              $283 = $282&1;
              if ($283) {
               label = 39;
               break L36;
              }
              if (!($281)) {
               $shouldResetPass$0$off0 = 0;
               break;
              }
             }
             __THREW__ = 0;
             invoke_vi(3398,($batchRenderer|0));
             $284 = __THREW__; __THREW__ = 0;
             $285 = $284&1;
             if ($285) {
              label = 39;
              break L36;
             } else {
              $shouldResetPass$0$off0 = 0;
             }
            }
           } while(0);
           if ((label|0) == 52) {
            label = 0;
            __THREW__ = 0;
            invoke_vi(3398,($batchRenderer|0));
            $274 = __THREW__; __THREW__ = 0;
            $275 = $274&1;
            if ($275) {
             label = 39;
             break;
            }
            dest=$prevRenderState+0|0; src=$rs+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
            $276 = Math_fround(HEAPF32[$144>>2]);
            __THREW__ = 0;
            invoke_viif(41,($5|0),($4|0),(+$276));
            $277 = __THREW__; __THREW__ = 0;
            $278 = $277&1;
            if ($278) {
             label = 39;
             break;
            } else {
             $shouldResetPass$0$off0 = 1;
            }
           }
           $286 = HEAP32[$233>>2]|0;
           __THREW__ = 0;
           invoke_vii(2612,($lightmapSTCache|0),($286|0));
           $287 = __THREW__; __THREW__ = 0;
           $288 = $287&1;
           if ($288) {
            label = 39;
            break;
           }
           $289 = HEAP32[$149>>2]|0;
           $290 = ($289|0)==(4);
           L77: do {
            if ($290) {
             $291 = HEAP32[$151>>2]|0;
             $i$01$i$i$i = 0;
             while(1) {
              $294 = (($153) + ($i$01$i$i$i<<2)|0);
              $295 = HEAP32[$294>>2]|0;
              $296 = (($291) + ($i$01$i$i$i<<2)|0);
              $297 = HEAP32[$296>>2]|0;
              $298 = ($295|0)==($297|0);
              $293 = (($i$01$i$i$i) + 1)|0;
              if (!($298)) {
               break;
              }
              $292 = ($293|0)<(27);
              if ($292) {
               $i$01$i$i$i = $293;
              } else {
               break L77;
              }
             }
             dest=$153+0|0; src=$291+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
             $299 = HEAP32[$154>>2]|0;
             __THREW__ = 0;
             invoke_vii(2613,($299|0),($291|0));
             $300 = __THREW__; __THREW__ = 0;
             $301 = $300&1;
             if ($301) {
              label = 39;
              break L36;
             }
            } else {
             $i$01$i$i$i$i = 0;
             while(1) {
              $304 = (($153) + ($i$01$i$i$i$i<<2)|0);
              $305 = HEAP32[$304>>2]|0;
              $306 = (($shConstantCache) + ($i$01$i$i$i$i<<2)|0);
              $307 = HEAP32[$306>>2]|0;
              $308 = ($305|0)==($307|0);
              $303 = (($i$01$i$i$i$i) + 1)|0;
              if (!($308)) {
               break;
              }
              $302 = ($303|0)<(27);
              if ($302) {
               $i$01$i$i$i$i = $303;
              } else {
               break L77;
              }
             }
             dest=$153+0|0; src=$shConstantCache+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
             $309 = HEAP32[$154>>2]|0;
             __THREW__ = 0;
             invoke_vii(2613,($309|0),($shConstantCache|0));
             $310 = __THREW__; __THREW__ = 0;
             $311 = $310&1;
             if ($311) {
              label = 39;
              break L36;
             }
            }
           } while(0);
           $312 = HEAP32[$233>>2]|0;
           $313 = (($221) + 64|0);
           __THREW__ = 0;
           invoke_viiii(333,($312|0),($313|0),($defaultReflection|0),($reflectionSample|0));
           $314 = __THREW__; __THREW__ = 0;
           $315 = $314&1;
           if ($315) {
            label = 39;
            break;
           }
           $316 = (_memcmp($reflectionProbeCache,$reflectionSample,124)|0);
           $317 = ($316|0)==(0);
           if (!($317)) {
            dest=$reflectionProbeCache+0|0; src=$reflectionSample+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
            $318 = HEAP32[$160>>2]|0;
            __THREW__ = 0;
            invoke_vii(2614,($318|0),($reflectionSample|0));
            $319 = __THREW__; __THREW__ = 0;
            $320 = $319&1;
            if ($320) {
             label = 39;
             break;
            }
           }
           $321 = HEAP32[$149>>2]|0;
           $322 = ($321|0)==(5);
           do {
            if ($322) {
             $323 = HEAP32[$151>>2]|0;
             $324 = (($323) + 112|0);
             $325 = HEAP32[$324>>2]|0;
             $326 = (($323) + 128|0);
             $327 = ($325|0)>(0);
             if (!($327)) {
              $channels$3 = $channels$071;
              break;
             }
             $328 = (($325) + -1)|0;
             $329 = $223&65535;
             $lightNo$059 = 0;
             while(1) {
              $330 = (($326) + ($lightNo$059<<2)|0);
              $331 = HEAP32[$330>>2]|0;
              $332 = HEAP32[$331>>2]|0;
              $333 = ($lightNo$059|0)==($328|0);
              if ($333) {
               $334 = HEAP32[$151>>2]|0;
               $335 = (($334) + 120|0);
               $336 = Math_fround(HEAPF32[$335>>2]);
               $337 = $336;
              } else {
               $337 = Math_fround(1.0);
              }
              __THREW__ = 0;
              invoke_vif(183,($332|0),(+$337));
              $338 = __THREW__; __THREW__ = 0;
              $339 = $338&1;
              if ($339) {
               label = 38;
               break L36;
              }
              $340 = (($332) + 216|0);
              $341 = HEAP32[$340>>2]|0;
              $342 = ($341|0)==(1);
              if (!($342)) {
               $343 = (($331) + 48|0);
               $344 = HEAP32[$this>>2]|0;
               $345 = (($344) + 76|0);
               __THREW__ = 0;
               invoke_viiii(334,($343|0),($345|0),0,($5|0));
               $346 = __THREW__; __THREW__ = 0;
               $347 = $346&1;
               if ($347) {
                label = 38;
                break L36;
               }
              }
              $348 = HEAP32[$152>>2]|0;
              $349 = ($348|0)==(0);
              L104: do {
               if (!($349)) {
                $350 = (($332) + 116|0);
                $351 = HEAP32[$350>>2]|0;
                $352 = ($351|0)==(0);
                if ($352) {
                 break;
                }
                $353 = HEAP32[$155>>2]|0;
                $354 = ($353|0)==($331|0);
                if ($354) {
                 $$0$i25 = $155;
                } else {
                 $355 = HEAP32[$65>>2]|0;
                 $356 = HEAP32[$67>>2]|0;
                 $357 = (($355) + (($356*96)|0)|0);
                 $358 = ($356|0)==(0);
                 if ($358) {
                  break;
                 } else {
                  $sl$01$i = $355;
                 }
                 while(1) {
                  $361 = HEAP32[$sl$01$i>>2]|0;
                  $362 = ($361|0)==($331|0);
                  $360 = (($sl$01$i) + 96|0);
                  if ($362) {
                   break;
                  }
                  $359 = ($360|0)==($357|0);
                  if ($359) {
                   break L104;
                  } else {
                   $sl$01$i = $360;
                  }
                 }
                 $363 = ($sl$01$i|0)==(0|0);
                 if ($363) {
                  break;
                 } else {
                  $$0$i25 = $sl$01$i;
                 }
                }
                $364 = (($$0$i25) + 4|0);
                $365 = HEAP32[$364>>2]|0;
                $366 = ($365|0)==(0|0);
                if ($366) {
                 break;
                }
                $367 = HEAP32[$331>>2]|0;
                $368 = (($$0$i25) + 8|0);
                __THREW__ = 0;
                invoke_viiiiii(99,($this|0),($367|0),($365|0),($368|0),0,($4|0));
                $369 = __THREW__; __THREW__ = 0;
                $370 = $369&1;
                if ($370) {
                 label = 38;
                 break L36;
                }
                $371 = (($367) + 216|0);
                $372 = HEAP32[$371>>2]|0;
                $373 = (($367) + 116|0);
                $374 = HEAP32[$373>>2]|0;
                $375 = ($372|0)==(1);
                __THREW__ = 0;
                invoke_viiiii(88,($4|0),($372|0),($374|0),($375|0),($21|0));
                $376 = __THREW__; __THREW__ = 0;
                $377 = $376&1;
                if ($377) {
                 label = 38;
                 break L36;
                }
               }
              } while(0);
              $378 = HEAP32[$rs>>2]|0;
              $379 = HEAP32[$150>>2]|0;
              $380 = HEAP32[$145>>2]|0;
              $381 = HEAP32[$146>>2]|0;
              __THREW__ = 0;
              $382 = (invoke_iiiiii(193,($378|0),($379|0),($380|0),($4|0),($381|0))|0);
              $383 = __THREW__; __THREW__ = 0;
              $384 = $383&1;
              if ($384) {
               label = 38;
               break L36;
              }
              $385 = ($382|0)==(0|0);
              if (!($385)) {
               $386 = HEAP32[$233>>2]|0;
               __THREW__ = 0;
               invoke_viiiii(89,($batchRenderer|0),($386|0),($221|0),($329|0),($382|0));
               $387 = __THREW__; __THREW__ = 0;
               $388 = $387&1;
               if ($388) {
                label = 38;
                break L36;
               }
              }
              $389 = HEAP32[$152>>2]|0;
              $390 = ($389|0)==(0);
              do {
               if (!($390)) {
                $391 = (($332) + 116|0);
                $392 = HEAP32[$391>>2]|0;
                $393 = ($392|0)==(0);
                if ($393) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3400,($4|0));
                $394 = __THREW__; __THREW__ = 0;
                $395 = $394&1;
                if ($395) {
                 label = 38;
                 break L36;
                }
               }
              } while(0);
              $396 = HEAP32[$340>>2]|0;
              $397 = ($396|0)==(1);
              if (!($397)) {
               __THREW__ = 0;
               invoke_viii(1662,($12|0),($oldScissorRect|0),($5|0));
               $398 = __THREW__; __THREW__ = 0;
               $399 = $398&1;
               if ($399) {
                label = 38;
                break L36;
               }
              }
              $400 = (($lightNo$059) + 1)|0;
              $401 = ($400|0)<($325|0);
              if ($401) {
               $lightNo$059 = $400;
              } else {
               $channels$3 = $382;
               break;
              }
             }
            } else {
             if ($shouldResetPass$0$off0) {
              L131: do {
               switch ($321|0) {
               case 0:  {
                $402 = HEAP32[$5>>2]|0;
                $403 = (($402) + 244|0);
                $404 = HEAP32[$403>>2]|0;
                __THREW__ = 0;
                invoke_vii($404|0,($5|0),0);
                $405 = __THREW__; __THREW__ = 0;
                $406 = $405&1;
                if ($406) {
                 label = 39;
                 break L36;
                }
                __THREW__ = 0;
                invoke_vii(2615,($94|0),($156|0));
                $407 = __THREW__; __THREW__ = 0;
                $408 = $407&1;
                if ($408) {
                 label = 39;
                 break L36;
                }
                break;
               }
               case 3: case 2: case 1:  {
                $463 = HEAP32[$5>>2]|0;
                $464 = (($463) + 96|0);
                $465 = HEAP32[$464>>2]|0;
                __THREW__ = 0;
                invoke_vii($465|0,($5|0),(616552|0));
                $466 = __THREW__; __THREW__ = 0;
                $467 = $466&1;
                if ($467) {
                 label = 39;
                 break L36;
                }
                __THREW__ = 0;
                invoke_vii(2615,($94|0),($156|0));
                $468 = __THREW__; __THREW__ = 0;
                $469 = $468&1;
                if ($469) {
                 label = 39;
                 break L36;
                }
                $470 = HEAP32[$151>>2]|0;
                $471 = (($470) + 116|0);
                $472 = HEAP32[$471>>2]|0;
                $473 = (($470) + 128|0);
                __THREW__ = 0;
                invoke_vii(2616,($472|0),($473|0));
                $474 = __THREW__; __THREW__ = 0;
                $475 = $474&1;
                if ($475) {
                 label = 39;
                 break L36;
                }
                break;
               }
               case 4:  {
                $409 = HEAP32[$5>>2]|0;
                $410 = (($409) + 96|0);
                $411 = HEAP32[$410>>2]|0;
                __THREW__ = 0;
                invoke_vii($411|0,($5|0),(616552|0));
                $412 = __THREW__; __THREW__ = 0;
                $413 = $412&1;
                if ($413) {
                 label = 39;
                 break L36;
                }
                $414 = HEAP32[$151>>2]|0;
                __THREW__ = 0;
                invoke_vi(3401,($414|0));
                $415 = __THREW__; __THREW__ = 0;
                $416 = $415&1;
                if ($416) {
                 label = 39;
                 break L36;
                }
                __THREW__ = 0;
                invoke_vii(2615,($94|0),($156|0));
                $417 = __THREW__; __THREW__ = 0;
                $418 = $417&1;
                if ($418) {
                 label = 39;
                 break L36;
                }
                $419 = HEAP32[$152>>2]|0;
                $420 = ($419|0)==(0);
                $or$cond = $420 | $157;
                do {
                 if (!($or$cond)) {
                  $421 = HEAP32[$151>>2]|0;
                  $422 = (($421) + 108|0);
                  $423 = HEAP32[$422>>2]|0;
                  $424 = ($423|0)==($$1|0);
                  if (!($424)) {
                   break;
                  }
                  $425 = HEAP32[$$1>>2]|0;
                  $426 = HEAP32[$158>>2]|0;
                  __THREW__ = 0;
                  invoke_viiiiii(99,($this|0),($425|0),($426|0),($159|0),0,($4|0));
                  $427 = __THREW__; __THREW__ = 0;
                  $428 = $427&1;
                  if ($428) {
                   label = 39;
                   break L36;
                  }
                  $429 = (($425) + 216|0);
                  $430 = HEAP32[$429>>2]|0;
                  $431 = (($425) + 116|0);
                  $432 = HEAP32[$431>>2]|0;
                  __THREW__ = 0;
                  invoke_viiiii(88,($4|0),($430|0),($432|0),1,($21|0));
                  $433 = __THREW__; __THREW__ = 0;
                  $434 = $433&1;
                  if ($434) {
                   label = 39;
                   break L36;
                  } else {
                   break L131;
                  }
                 }
                } while(0);
                if ($420) {
                 break L131;
                }
                $435 = HEAP32[$151>>2]|0;
                $436 = (($435) + 108|0);
                $437 = HEAP32[$436>>2]|0;
                $438 = ($437|0)==(0|0);
                if ($438) {
                 break L131;
                }
                $439 = HEAP32[$437>>2]|0;
                $440 = (($439) + 116|0);
                $441 = HEAP32[$440>>2]|0;
                $442 = ($441|0)==(0);
                if ($442) {
                 break L131;
                }
                $443 = HEAP32[$65>>2]|0;
                $444 = HEAP32[$67>>2]|0;
                $445 = (($443) + (($444*96)|0)|0);
                $446 = ($444|0)==(0);
                if ($446) {
                 break L131;
                } else {
                 $sl$050 = $443;
                }
                while(1) {
                 $447 = HEAP32[$sl$050>>2]|0;
                 $448 = ($447|0)==($437|0);
                 if ($448) {
                  $449 = (($sl$050) + 4|0);
                  $450 = HEAP32[$449>>2]|0;
                  $451 = ($450|0)==(0|0);
                  if (!($451)) {
                   break;
                  }
                 }
                 $461 = (($sl$050) + 96|0);
                 $462 = ($461|0)==($445|0);
                 if ($462) {
                  break L131;
                 } else {
                  $sl$050 = $461;
                 }
                }
                $452 = (($sl$050) + 8|0);
                __THREW__ = 0;
                invoke_viiiiii(99,($this|0),($439|0),($450|0),($452|0),0,($4|0));
                $453 = __THREW__; __THREW__ = 0;
                $454 = $453&1;
                if ($454) {
                 label = 39;
                 break L36;
                }
                $455 = (($439) + 216|0);
                $456 = HEAP32[$455>>2]|0;
                $457 = HEAP32[$440>>2]|0;
                $458 = ($456|0)==(1);
                __THREW__ = 0;
                invoke_viiiii(88,($4|0),($456|0),($457|0),($458|0),($21|0));
                $459 = __THREW__; __THREW__ = 0;
                $460 = $459&1;
                if ($460) {
                 label = 39;
                 break L36;
                }
                break;
               }
               default: {
               }
               }
              } while(0);
              $476 = HEAP32[$226>>2]|0;
              $477 = HEAP32[$150>>2]|0;
              $478 = HEAP32[$145>>2]|0;
              $479 = HEAP32[$146>>2]|0;
              __THREW__ = 0;
              $480 = (invoke_iiiiii(193,($476|0),($477|0),($478|0),($4|0),($479|0))|0);
              $481 = __THREW__; __THREW__ = 0;
              $482 = $481&1;
              if ($482) {
               label = 39;
               break L36;
              } else {
               $channels$2 = $480;
              }
             } else {
              $channels$2 = $channels$071;
             }
             $483 = ($channels$2|0)==(0|0);
             if (!($483)) {
              $484 = HEAP32[$233>>2]|0;
              $485 = $223&65535;
              __THREW__ = 0;
              invoke_viiiii(90,($batchRenderer|0),($484|0),($221|0),($485|0),($channels$2|0));
              $486 = __THREW__; __THREW__ = 0;
              $487 = $486&1;
              if ($487) {
               label = 39;
               break L36;
              }
             }
             $488 = HEAP32[$149>>2]|0;
             $489 = ($488|0)==(4);
             if (!($489)) {
              $channels$3 = $channels$2;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3400,($4|0));
             $490 = __THREW__; __THREW__ = 0;
             $491 = $490&1;
             if ($491) {
              label = 39;
              break L36;
             } else {
              $channels$3 = $channels$2;
             }
            }
           } while(0);
           $492 = (($index$070) + 1)|0;
           $493 = ($492>>>0)<($96>>>0);
           if ($493) {
            $182 = $596;$channels$071 = $channels$3;$currentMaxQueue$072 = $currentMaxQueue$1;$index$070 = $492;
           } else {
            $$lcssa66 = $596;
            break L34;
           }
          }
          if ((label|0) == 37) {
           $210 = ___cxa_find_matching_catch()|0;
           $211 = tempRet0;
           $lpad$phi$index = $210;$lpad$phi$index6 = $211;
           break L27;
          }
          else if ((label|0) == 38) {
           $212 = ___cxa_find_matching_catch()|0;
           $213 = tempRet0;
           $lpad$phi$index = $212;$lpad$phi$index6 = $213;
           break L27;
          }
          else if ((label|0) == 39) {
           $214 = ___cxa_find_matching_catch()|0;
           $215 = tempRet0;
           $lpad$phi$index = $214;$lpad$phi$index6 = $215;
           break L27;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3398,($batchRenderer|0));
        $494 = __THREW__; __THREW__ = 0;
        $495 = $494&1;
        if ($495) {
         label = 40;
        } else {
         __THREW__ = 0;
         invoke_vi(3400,($4|0));
         $496 = __THREW__; __THREW__ = 0;
         $497 = $496&1;
         if ($497) {
          label = 40;
         } else {
          __THREW__ = 0;
          invoke_viii(1662,($12|0),($oldScissorRect|0),($5|0));
          $498 = __THREW__; __THREW__ = 0;
          $499 = $498&1;
          if ($499) {
           label = 40;
          } else {
           $500 = (($this) + 60|0);
           $501 = HEAP32[$500>>2]|0;
           $502 = ($501|0)==(0|0);
           $503 = ($501|0)==($$existingShadowMap|0);
           $or$cond6 = $502 | $503;
           if (!($or$cond6)) {
            __THREW__ = 0;
            $504 = (invoke_i(61)|0);
            $505 = __THREW__; __THREW__ = 0;
            $506 = $505&1;
            if ($506) {
             label = 40;
             break;
            }
            $507 = HEAP32[$500>>2]|0;
            __THREW__ = 0;
            invoke_vii(2617,($504|0),($507|0));
            $508 = __THREW__; __THREW__ = 0;
            $509 = $508&1;
            if ($509) {
             label = 40;
             break;
            }
           }
           $510 = HEAP32[$65>>2]|0;
           $511 = HEAP32[$67>>2]|0;
           $512 = (($510) + (($511*96)|0)|0);
           $513 = ($511|0)==(0);
           L175: do {
            if (!($513)) {
             $it5$035 = $510;
             while(1) {
              $514 = (($it5$035) + 4|0);
              $515 = HEAP32[$514>>2]|0;
              $516 = ($515|0)==(0|0);
              if (!($516)) {
               __THREW__ = 0;
               $517 = (invoke_i(61)|0);
               $518 = __THREW__; __THREW__ = 0;
               $519 = $518&1;
               if ($519) {
                break;
               }
               $520 = HEAP32[$514>>2]|0;
               __THREW__ = 0;
               invoke_vii(2617,($517|0),($520|0));
               $521 = __THREW__; __THREW__ = 0;
               $522 = $521&1;
               if ($522) {
                break;
               }
              }
              $523 = (($it5$035) + 96|0);
              $524 = ($523|0)==($512|0);
              if ($524) {
               break L175;
              } else {
               $it5$035 = $523;
              }
             }
             $208 = ___cxa_find_matching_catch()|0;
             $209 = tempRet0;
             $lpad$phi$index = $208;$lpad$phi$index6 = $209;
             break L27;
            }
           } while(0);
           $525 = HEAP32[$this>>2]|0;
           $526 = (($525) + 105|0);
           $527 = HEAP8[$526>>0]|0;
           $528 = ($527<<24>>24)!=(0);
           $529 = ($$lcssa66|0)==($3|0);
           $or$cond99 = $528 | $529;
           L184: do {
            if (!($or$cond99)) {
             $530 = (($525) + 108|0);
             $531 = HEAP32[$530>>2]|0;
             $534 = $$lcssa66;
             while(1) {
              $533 = (($534) + 16|0);
              $535 = HEAP32[$533>>2]|0;
              $536 = ($535|0)<($531|0);
              if (!($536)) {
               $$lcssa30 = $534;
               break;
              }
              $537 = (($534) + 4|0);
              $538 = HEAP32[$537>>2]|0;
              $539 = ($538|0)==(0|0);
              if ($539) {
               $$01$i$i$i10 = $534;
               while(1) {
                $542 = (($$01$i$i$i10) + 8|0);
                $543 = HEAP32[$542>>2]|0;
                $544 = HEAP32[$543>>2]|0;
                $545 = ($544|0)==($$01$i$i$i10|0);
                if ($545) {
                 $$0$i$i$i12 = $543;
                 break;
                } else {
                 $$01$i$i$i10 = $543;
                }
               }
              } else {
               $$0$i$i$i$i8 = $538;
               while(1) {
                $540 = HEAP32[$$0$i$i$i$i8>>2]|0;
                $541 = ($540|0)==(0|0);
                if ($541) {
                 $$0$i$i$i12 = $$0$i$i$i$i8;
                 break;
                } else {
                 $$0$i$i$i$i8 = $540;
                }
               }
              }
              $546 = ($$0$i$i$i12|0)==($3|0);
              if ($546) {
               $$lcssa30 = $$0$i$i$i12;
               break;
              } else {
               $534 = $$0$i$i$i12;
              }
             }
             $532 = ($$lcssa30|0)==($3|0);
             if ($532) {
              break;
             } else {
              $548 = $$lcssa30;$551 = $525;
             }
             while(1) {
              $547 = (($548) + 16|0);
              $549 = HEAP32[$547>>2]|0;
              $550 = (($551) + 112|0);
              $552 = HEAP32[$550>>2]|0;
              $553 = ($549|0)<($552|0);
              if (!($553)) {
               break L184;
              }
              $554 = (($548) + 20|0);
              $555 = HEAP32[$554>>2]|0;
              $556 = HEAP32[$555>>2]|0;
              $557 = HEAP32[$556>>2]|0;
              $558 = (($551) + 4|0);
              $559 = HEAP32[$558>>2]|0;
              __THREW__ = 0;
              invoke_viii($557|0,($555|0),($559|0),($4|0));
              $560 = __THREW__; __THREW__ = 0;
              $561 = $560&1;
              if ($561) {
               break;
              }
              $562 = (($548) + 4|0);
              $563 = HEAP32[$562>>2]|0;
              $564 = ($563|0)==(0|0);
              if ($564) {
               $$01$i$i$i = $548;
               while(1) {
                $567 = (($$01$i$i$i) + 8|0);
                $568 = HEAP32[$567>>2]|0;
                $569 = HEAP32[$568>>2]|0;
                $570 = ($569|0)==($$01$i$i$i|0);
                if ($570) {
                 $$0$i$i$i = $568;
                 break;
                } else {
                 $$01$i$i$i = $568;
                }
               }
              } else {
               $$0$i$i$i$i = $563;
               while(1) {
                $565 = HEAP32[$$0$i$i$i$i>>2]|0;
                $566 = ($565|0)==(0|0);
                if ($566) {
                 $$0$i$i$i = $$0$i$i$i$i;
                 break;
                } else {
                 $$0$i$i$i$i = $565;
                }
               }
              }
              $571 = ($$0$i$i$i|0)==($3|0);
              if ($571) {
               break L184;
              }
              $$pre = HEAP32[$this>>2]|0;
              $548 = $$0$i$i$i;$551 = $$pre;
             }
             $206 = ___cxa_find_matching_catch()|0;
             $207 = tempRet0;
             $lpad$phi$index = $206;$lpad$phi$index6 = $207;
             break L27;
            }
           } while(0);
           __THREW__ = 0;
           $572 = (invoke_i(59)|0);
           $573 = __THREW__; __THREW__ = 0;
           $574 = $573&1;
           if ($574) {
            label = 40;
           } else {
            $575 = HEAP32[$572>>2]|0;
            $576 = (($575) + 72|0);
            $577 = HEAP32[$576>>2]|0;
            __THREW__ = 0;
            invoke_vii($577|0,($572|0),0);
            $578 = __THREW__; __THREW__ = 0;
            $579 = $578&1;
            if ($579) {
             label = 40;
             break;
            }
            $580 = HEAP32[$5>>2]|0;
            $581 = (($580) + 100|0);
            $582 = HEAP32[$581>>2]|0;
            $583 = HEAP32[$this>>2]|0;
            $584 = (($583) + 12|0);
            __THREW__ = 0;
            invoke_vii($582|0,($5|0),($584|0));
            $585 = __THREW__; __THREW__ = 0;
            $586 = $585&1;
            if ($586) {
             label = 40;
             break;
            }
            $587 = HEAP32[$this>>2]|0;
            $588 = HEAP32[$587>>2]|0;
            $589 = $opaque ? 11 : 17;
            $590 = (($588) + 636|0);
            __THREW__ = 0;
            invoke_viii(1663,($590|0),($589|0),($4|0));
            $591 = __THREW__; __THREW__ = 0;
            $592 = $591&1;
            if ($592) {
             label = 40;
             break;
            }
            __ZN13BatchRendererD1Ev($batchRenderer);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 40) {
  $216 = ___cxa_find_matching_catch()|0;
  $217 = tempRet0;
  $lpad$phi$index = $216;$lpad$phi$index6 = $217;
 }
 __THREW__ = 0;
 invoke_vi(3399,($batchRenderer|0));
 $218 = __THREW__; __THREW__ = 0;
 $219 = $218&1;
 if ($219) {
  $593 = ___cxa_find_matching_catch(0|0)|0;
  $594 = tempRet0;
  ___clang_call_terminate($593);
  // unreachable;
 } else {
  $$04 = $lpad$phi$index;$$05 = $lpad$phi$index6;
  ___resumeException($$04|0);
  // unreachable;
 }
}
function __ZN23ForwardShaderRenderLoop21RenderLightShadowMapsER16ForwardShadowMapR16ShadowCameraDatabbbRN9ShaderLab17ShaderPassContextE($this,$shadowMap,$camData,$enableSoftShadows,$useDualInForward,$clearFrameBuffer,$passContext) {
 $this = $this|0;
 $shadowMap = $shadowMap|0;
 $camData = $camData|0;
 $enableSoftShadows = $enableSoftShadows|0;
 $useDualInForward = $useDualInForward|0;
 $clearFrameBuffer = $clearFrameBuffer|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $shadowMatrices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $0 = sp + 256|0;
 $shadowMatrices = sp;
 $1 = HEAP32[$shadowMap>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 216|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 116|0);
 $6 = HEAP32[$5>>2]|0;
 __Z18SetShadowsKeywordsRN9ShaderLab17ShaderPassContextE9LightType10ShadowTypebb($passContext,$4,$6,0,$enableSoftShadows);
 $7 = (__Z12GetGfxDevicev()|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = (($11) + 12|0);
 FUNCTION_TABLE_vii[$10 & 4095]($7,$12);
 $13 = HEAP32[$shadowMap>>2]|0;
 $14 = (($shadowMap) + 72|0);
 $15 = (__Z16RenderShadowMapsR16ShadowCameraDataRK11ActiveLightRK10MinMaxAABBRN9ShaderLab17ShaderPassContextEP10Matrix4x4f($camData,$13,$14,$passContext,$shadowMatrices)|0);
 $16 = (($shadowMap) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = (($shadowMap) + 8|0);
 __Z13CopyMatrixREFPKfPf($shadowMatrices,$17);
 $18 = HEAP8[((640792 + 250|0))>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if (!($19)) {
  $20 = HEAP32[$16>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = HEAP32[$3>>2]|0;
   $23 = ($22|0)==(1);
   if ($23) {
    $24 = HEAP32[$5>>2]|0;
    __Z18SetShadowsKeywordsRN9ShaderLab17ShaderPassContextE9LightType10ShadowTypebb($passContext,1,$24,0,$enableSoftShadows);
    $25 = HEAP32[$16>>2]|0;
    $26 = (($camData) + 616|0);
    $27 = (($camData) + 656|0);
    $28 = HEAP32[$this>>2]|0;
    $29 = HEAP32[$28>>2]|0;
    __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($29,$passContext,0);
    __ZNK23ForwardShaderRenderLoop19SetLightShadowPropsERK5LightP7TextureRK10Matrix4x4fbRN9ShaderLab17ShaderPassContextE($this,$2,$25,$shadowMatrices,$useDualInForward,$passContext);
    $30 = (($25) + 100|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (Math_fround(($31|0)));
    $33 = (($25) + 104|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (Math_fround(($34|0)));
    HEAPF32[$0>>2] = $32;
    $36 = (($0) + 4|0);
    HEAPF32[$36>>2] = $35;
    __Z29SetCascadedShadowShaderParamsPK10Matrix4x4fPKfPK8Vector4fRK8Vector2f($shadowMatrices,$26,$27,$0);
    __ZNK5Light19SetPropsToShaderLabEf($2,Math_fround(1.0));
    $37 = HEAP32[$this>>2]|0;
    $38 = HEAP32[$37>>2]|0;
    $39 = (($2) + 132|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = (($2) + 136|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = HEAP32[$5>>2]|0;
    $44 = (__Z27ComputeScreenSpaceShadowMapRK6CameraP13RenderTextureff10ShadowTypeRN9ShaderLab17ShaderPassContextE($38,$25,$40,$42,$43,$passContext)|0);
    HEAP32[$16>>2] = $44;
    STACKTOP = sp;return;
   }
  }
 }
 __Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE($passContext);
 STACKTOP = sp;return;
}
function __ZN13BatchRendererD1Ev($this) {
 $this = $this|0;
 var $$byval_copy13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy13 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 do {
  if ($5) {
   $6 = (($this) + 44|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($this) + 48|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$2>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($7|0),($$byval_copy13|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$6>>2] = 0;
    break;
   }
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   $14 = (($this) + 28|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>(-1);
   do {
    if ($16) {
     $17 = (($this) + 16|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($this) + 20|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$1>>2] = $20;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($18|0),($$byval_copy13|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      HEAP32[$17>>2] = 0;
      break;
     }
     $31 = ___cxa_find_matching_catch(0|0)|0;
     $32 = tempRet0;
     $33 = (($this) + 12|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)>(-1);
     if (!($35)) {
      $eh$lpad$body$indexZ2D = $31;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
     $36 = HEAP32[$this>>2]|0;
     $37 = (($this) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     HEAP32[$0>>2] = $38;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($36|0),($$byval_copy13|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      $41 = ___cxa_find_matching_catch(0|0)|0;
      $42 = tempRet0;
      ___clang_call_terminate($41);
      // unreachable;
     }
     HEAP32[$this>>2] = 0;
     $eh$lpad$body$indexZ2D = $31;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   } while(0);
   $23 = (($this) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)>(-1);
   if (!($25)) {
    ___resumeException($12|0);
    // unreachable;
   }
   $26 = HEAP32[$this>>2]|0;
   $27 = (($this) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$0>>2] = $28;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($26|0),($$byval_copy13|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $43 = ___cxa_find_matching_catch(0|0)|0;
    $44 = tempRet0;
    $eh$lpad$body$indexZ2D = $43;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   } else {
    HEAP32[$this>>2] = 0;
    ___resumeException($12|0);
    // unreachable;
   }
  }
 } while(0);
 $45 = (($this) + 28|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)>(-1);
 do {
  if ($47) {
   $48 = (($this) + 16|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($this) + 20|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$1>>2] = $51;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($49|0),($$byval_copy13|0));
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if (!($53)) {
    HEAP32[$48>>2] = 0;
    break;
   }
   $60 = ___cxa_find_matching_catch()|0;
   $61 = tempRet0;
   $62 = (($this) + 12|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)>(-1);
   if (!($64)) {
    ___resumeException($60|0);
    // unreachable;
   }
   $65 = HEAP32[$this>>2]|0;
   $66 = (($this) + 4|0);
   $67 = HEAP32[$66>>2]|0;
   HEAP32[$0>>2] = $67;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($65|0),($$byval_copy13|0));
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    $70 = ___cxa_find_matching_catch(0|0)|0;
    $71 = tempRet0;
    ___clang_call_terminate($70);
    // unreachable;
   }
   HEAP32[$this>>2] = 0;
   ___resumeException($60|0);
   // unreachable;
  }
 } while(0);
 $54 = (($this) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)>(-1);
 if (!($56)) {
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$this>>2]|0;
 $58 = (($this) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 HEAP32[$0>>2] = $59;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($57,$$byval_copy13);
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __Z25DoForwardShaderRenderLoopR17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EEbbP13RenderTextureR12ActiveLightsbb($ctx,$objects,$opaque,$disableDynamicBatching,$mainShadowMap,$activeLights,$linearLighting,$clearFrameBuffer) {
 $ctx = $ctx|0;
 $objects = $objects|0;
 $opaque = $opaque|0;
 $disableDynamicBatching = $disableDynamicBatching|0;
 $mainShadowMap = $mainShadowMap|0;
 $activeLights = $activeLights|0;
 $linearLighting = $linearLighting|0;
 $clearFrameBuffer = $clearFrameBuffer|0;
 var $$ = 0, $$0$i22 = 0, $$0$i22$us = 0, $$0$i22$us52 = 0, $$80 = 0, $$83 = 0, $$byval_copy15 = 0, $$mainDirShadowLight$0 = 0, $$not$i = 0, $$not$i9 = 0, $$not1 = 0, $$not12$i = 0, $$not12$i12$us43 = 0, $$not14$i = 0, $$not14$i14 = 0, $$not14$i14$us45 = 0, $$not16$i = 0, $$not16$i17 = 0, $$not16$i17$us47 = 0, $$off$i = 0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $$pre73 = 0, $$pre76 = 0, $$pre77 = 0, $$suitablePasses$0 = 0, $$suitablePasses$0$us = 0, $$suitablePasses$0$us53 = 0, $$sum = 0, $$sum33 = 0, $$sum35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0;
 var $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0);
 var $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0);
 var $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0);
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge$i = 0, $brmerge13$i = 0, $brmerge15$i = 0, $brmerge15$i16 = 0, $brmerge15$i16$us46 = 0, $brmerge17$i = 0, $brmerge17$i18 = 0, $brmerge17$i18$us48 = 0, $exitcond$i = 0, $firstPassFlag$059 = 0, $firstPassFlag$1 = 0, $fwdLightsParams = 0, $hasAddLights$not$i = 0, $hasAddLights$not$i20 = 0, $isLightmapped$not$i = 0, $it$067 = 0;
 var $lightNo$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, $mainDirShadowLight$0$lcssa = 0, $mainDirShadowLight$070 = 0, $mainDirShadowLight$2 = 0, $mainDirShadowLight$3 = 0, $mainDirShadowLight$4 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i21$us = 0, $or$cond$i24 = 0, $or$cond$us = 0, $or$cond$us54 = 0, $or$cond18$i = 0, $or$cond18$i19 = 0, $or$cond18$i19$us49 = 0, $or$cond78 = 0, $or$cond79 = 0, $or$cond81 = 0;
 var $or$cond82 = 0, $pass$038 = 0, $pass$038$us = 0, $pass$038$us39 = 0, $pass1$060 = 0, $queue = 0, $roIndex$068 = 0, $ss$032 = 0, $suitablePasses$0$lcssa = 0, $suitablePasses$037 = 0, $suitablePasses$037$us = 0, $suitablePasses$037$us40 = 0, $useRGBM$not$i15 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $$byval_copy15 = sp;
 $0 = sp + 320|0;
 $1 = sp + 316|0;
 $2 = sp + 312|0;
 $3 = sp + 308|0;
 $4 = sp + 324|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $queue = sp + 16|0;
 $fwdLightsParams = sp + 192|0;
 $7 = (__Z18GetQualitySettingsv()|0);
 $8 = (($7) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (Math_fround(__ZN15QualitySettings29GetShadowDistanceForRenderingEv()));
 if ($opaque) {
  $13 = HEAP32[$ctx>>2]|0;
  $14 = (__ZNK6Camera21CalculateCanDoShadowsEv($13)|0);
  if ($14) {
   $15 = (__Z16GetBuildSettingsv()|0);
   $16 = (($15) + 103|0);
   $17 = HEAP8[$16>>0]|0;
   $18 = ($17<<24>>24)!=(0);
   $232 = 0;$449 = $18;
  } else {
   $232 = 1;$449 = 0;
  }
 } else {
  $232 = 1;$449 = 0;
 }
 $19 = HEAP32[((640792 + 104|0))>>2]|0;
 $20 = ($19|0)>(2);
 if ($20) {
  $21 = HEAP8[((640792 + 254|0))>>0]|0;
  $22 = ($21<<24>>24)!=(0);
  $113 = $22;
 } else {
  $113 = 0;
 }
 $23 = HEAP32[628512>>2]|0;
 $24 = (($queue) + 8|0);
 HEAP32[$24>>2] = 0;
 $25 = (($queue) + 12|0);
 HEAP32[$25>>2] = $23;
 $26 = (($queue) + 16|0);
 HEAP32[$26>>2] = 0;
 $27 = (($queue) + 20|0);
 HEAP32[$27>>2] = 0;
 $28 = (($queue) + 24|0);
 HEAP32[$28>>2] = 0;
 $29 = (($queue) + 28|0);
 HEAP32[$29>>2] = $23;
 $30 = (($queue) + 32|0);
 HEAP32[$30>>2] = 0;
 $31 = (($queue) + 36|0);
 HEAP32[$31>>2] = 0;
 $32 = (($queue) + 40|0);
 HEAP32[$32>>2] = 0;
 $33 = (($queue) + 44|0);
 HEAP32[$33>>2] = $23;
 $34 = (($queue) + 48|0);
 $35 = (($queue) + 128|0);
 $36 = (($queue) + 140|0);
 $37 = (($queue) + 144|0);
 $38 = (($queue) + 148|0);
 ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;
 ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
 ;HEAP32[$35+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[616664+8>>2]|0;
 $39 = Math_fround(HEAPF32[616664>>2]);
 $40 = Math_fround(-$39);
 $41 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $42 = Math_fround(-$41);
 $43 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $44 = Math_fround(-$43);
 HEAPF32[$36>>2] = $40;
 HEAPF32[$37>>2] = $42;
 HEAPF32[$38>>2] = $44;
 $45 = (($queue) + 152|0);
 HEAP32[$45>>2] = 0;
 $46 = (($queue) + 156|0);
 HEAP32[$46>>2] = $23;
 $47 = (($queue) + 160|0);
 HEAP32[$47>>2] = 0;
 $48 = (($queue) + 164|0);
 HEAP32[$48>>2] = 0;
 HEAP32[$queue>>2] = $ctx;
 $49 = (($queue) + 4|0);
 HEAP32[$49>>2] = $objects;
 $50 = (($queue) + 8|0);
 $51 = (($objects) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0);
 if ($53) {
  label = 9;
 } else {
  HEAP32[$27>>2] = $52;
  $54 = $52 << 2;
  HEAP32[$6>>2] = $23;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$6+0>>2]|0;
  $55 = (invoke_iiiiiiii(108,(0|0),($54|0),4,($$byval_copy15|0),0,(568192|0),370)|0);
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   label = 38;
  } else {
   HEAP32[$50>>2] = $55;
   label = 9;
  }
 }
 L11: do {
  if ((label|0) == 9) {
   $58 = (($queue) + 24|0);
   $59 = HEAP32[$51>>2]|0;
   $60 = ($59*140)|0;
   $61 = HEAP32[$31>>2]|0;
   $62 = $61 & 2147483647;
   $63 = ($62>>>0)<($60>>>0);
   do {
    if ($63) {
     $64 = ($61|0)>(-1);
     if ($64) {
      HEAP32[$31>>2] = $60;
      $65 = HEAP32[$58>>2]|0;
      $66 = HEAP32[$29>>2]|0;
      HEAP32[$4>>2] = $66;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$4+0>>2]|0;
      $67 = (invoke_iiiiiiii(108,($65|0),($60|0),1,($$byval_copy15|0),0,(568192|0),370)|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 38;
       break L11;
      }
      HEAP32[$58>>2] = $67;
      break;
     } else {
      $70 = HEAP32[$29>>2]|0;
      HEAP32[$5>>2] = $70;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$5+0>>2]|0;
      $71 = (invoke_iiiiiii(102,($60|0),1,($$byval_copy15|0),0,(568192|0),352)|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       label = 38;
       break L11;
      }
      $74 = HEAP32[$58>>2]|0;
      $75 = HEAP32[$30>>2]|0;
      _memcpy(($71|0),($74|0),($75|0))|0;
      HEAP32[$31>>2] = $60;
      HEAP32[$58>>2] = $71;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   $76 = (invoke_i(62)|0);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    label = 38;
   } else {
    $79 = (($ctx) + 4|0);
    $80 = HEAP32[$79>>2]|0;
    __THREW__ = 0;
    $81 = (invoke_i(63)|0);
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 38;
    } else {
     HEAP8[$fwdLightsParams>>0] = 0;
     $84 = (($fwdLightsParams) + 4|0);
     $85 = (($fwdLightsParams) + 8|0);
     dest=$84+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     __THREW__ = 0;
     $86 = (invoke_i(64)|0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 38;
     } else {
      __THREW__ = 0;
      $89 = (invoke_ii(3217,($86|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       label = 38;
      } else {
       $92 = ($89|0)==(1);
       $93 = $92&1;
       $94 = HEAP8[$fwdLightsParams>>0]|0;
       $95 = ($93 << 1)&255;
       $96 = $94 & -3;
       $97 = $96 | $95;
       HEAP8[$fwdLightsParams>>0] = $97;
       $98 = ((($11) + (($9*96)|0)|0) + 12|0);
       $99 = HEAP32[$98>>2]|0;
       HEAP32[$84>>2] = $99;
       $100 = (($81) + 296|0);
       dest=$85+0|0; src=$100+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $101 = HEAP32[$objects>>2]|0;
       $102 = HEAP32[$51>>2]|0;
       $103 = (($101) + (($102*44)|0)|0);
       $104 = (($80) + 184|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = ($105|0)==(0|0);
       if ($106) {
        $110 = $101;
       } else {
        __THREW__ = 0;
        invoke_vi(3402,($104|0));
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 38;
         break;
        }
        $$pre76 = HEAP32[$objects>>2]|0;
        $110 = $$pre76;
       }
       $109 = ($110|0)==($103|0);
       L29: do {
        if ($109) {
         $$pre77 = (($queue) + 40|0);
         $$pre$phiZ2D = $$pre77;$mainDirShadowLight$0$lcssa = 0;
        } else {
         $111 = (($80) + 92|0);
         $112 = (($80) + 216|0);
         $useRGBM$not$i15 = $113 ^ 1;
         $114 = (($queue) + 40|0);
         $115 = (($queue) + 52|0);
         $116 = (($ctx) + 8|0);
         $117 = (($ctx) + 12|0);
         $118 = (($queue) + 152|0);
         $119 = (($queue) + 132|0);
         $120 = (($queue) + 136|0);
         $121 = (($80) + 208|0);
         $122 = (($80) + 192|0);
         $it$067 = $110;$mainDirShadowLight$070 = 0;$roIndex$068 = 0;
         L31: while(1) {
          $123 = (($it$067) + 32|0);
          $124 = HEAP32[$123>>2]|0;
          $125 = HEAP32[$111>>2]|0;
          $126 = $124;
          $127 = $125;
          $128 = (($126) - ($127))|0;
          $129 = $128 >> 7;
          $130 = (($124) + 116|0);
          $131 = HEAP32[$130>>2]|0;
          $132 = (($it$067) + 12|0);
          $133 = HEAP16[$132>>1]|0;
          $$off$i = (($133) + -254)<<16>>16;
          $134 = ($$off$i&65535)>(1);
          $135 = $134&1;
          $136 = HEAP8[$fwdLightsParams>>0]|0;
          $137 = $136 & -2;
          $138 = $135 | $137;
          HEAP8[$fwdLightsParams>>0] = $138;
          $139 = (($it$067) + 36|0);
          $140 = HEAP32[$139>>2]|0;
          $141 = (($140) + 52|0);
          $142 = HEAP32[$141>>2]|0;
          $143 = HEAP32[$26>>2]|0;
          $144 = (($143) + 1)|0;
          HEAP32[$26>>2] = $144;
          $145 = HEAP32[$27>>2]|0;
          $146 = $145 & 2147483647;
          $147 = ($144>>>0)>($146>>>0);
          if ($147) {
           $148 = $145 << 1;
           $149 = ($148|0)==(0);
           $150 = $149 ? 1 : $148;
           $151 = ($146>>>0)<($150>>>0);
           do {
            if ($151) {
             $152 = ($145|0)>(-1);
             if ($152) {
              HEAP32[$27>>2] = $150;
              $153 = HEAP32[$50>>2]|0;
              $154 = $150 << 2;
              $155 = HEAP32[$25>>2]|0;
              HEAP32[$0>>2] = $155;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
              $156 = (invoke_iiiiiiii(108,($153|0),($154|0),4,($$byval_copy15|0),0,(568192|0),370)|0);
              $157 = __THREW__; __THREW__ = 0;
              $158 = $157&1;
              if ($158) {
               label = 37;
               break L31;
              }
              HEAP32[$50>>2] = $156;
              break;
             } else {
              $159 = $150 << 2;
              $160 = HEAP32[$25>>2]|0;
              HEAP32[$1>>2] = $160;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;
              $161 = (invoke_iiiiiii(102,($159|0),4,($$byval_copy15|0),0,(568192|0),352)|0);
              $162 = __THREW__; __THREW__ = 0;
              $163 = $162&1;
              if ($163) {
               label = 37;
               break L31;
              }
              $164 = HEAP32[$50>>2]|0;
              $165 = HEAP32[$26>>2]|0;
              $166 = $165 << 2;
              _memcpy(($161|0),($164|0),($166|0))|0;
              HEAP32[$27>>2] = $150;
              HEAP32[$50>>2] = $161;
              break;
             }
            }
           } while(0);
           $$pre$i = HEAP32[$26>>2]|0;
           $$pre = HEAP8[$fwdLightsParams>>0]|0;
           $168 = $$pre$i;$171 = $$pre;
          } else {
           $168 = $144;$171 = $138;
          }
          $167 = (($168) + -1)|0;
          $169 = HEAP32[$50>>2]|0;
          $170 = $171 & -5;
          HEAP8[$fwdLightsParams>>0] = $170;
          $172 = (($it$067) + 8|0);
          $173 = HEAP16[$172>>1]|0;
          $174 = ($173<<16>>16)==(-1);
          do {
           if ($174) {
            $175 = (($142) + 20|0);
            $176 = HEAP32[$175>>2]|0;
            $177 = ($176|0)==(-1);
            if ($177) {
             $188 = $171 & 1;
             $189 = $188&255;
             $190 = ((($142) + ($189<<2)|0) + 12|0);
             $191 = HEAP32[$190>>2]|0;
             $192 = $171 | 4;
             HEAP8[$fwdLightsParams>>0] = $192;
             $193 = ($191|0)==(-1);
             if ($193) {
              $mainDirShadowLight$4 = $mainDirShadowLight$070;
              break;
             } else {
              $ss$032 = $191;
             }
            } else {
             $ss$032 = $176;
            }
            $194 = $ss$032&65535;
            HEAP16[$172>>1] = $194;
            $$pre73 = HEAP8[$fwdLightsParams>>0]|0;
            $196 = $194;$201 = $$pre73;
            label = 42;
           } else {
            $196 = $173;$201 = $170;
            label = 42;
           }
          } while(0);
          do {
           if ((label|0) == 42) {
            label = 0;
            $195 = $196 << 16 >> 16;
            $197 = HEAP32[$142>>2]|0;
            $198 = (($197) + ($195<<2)|0);
            $199 = HEAP32[$198>>2]|0;
            $200 = $201 & -9;
            HEAP8[$fwdLightsParams>>0] = $200;
            $202 = $201 & 4;
            $203 = ($202<<24>>24)==(0);
            if ($203) {
             $204 = (($199) + 40|0);
             $205 = HEAP8[$204>>0]|0;
             $206 = ($205 << 3)&255;
             $207 = $206 | $200;
             $208 = $207 ^ 8;
             HEAP8[$fwdLightsParams>>0] = $208;
            }
            $209 = HEAP32[$30>>2]|0;
            $210 = (($169) + ($167<<2)|0);
            HEAP32[$210>>2] = $209;
            $211 = HEAP32[$112>>2]|0;
            $212 = ($211|0)==(0);
            if ($212) {
             $222 = 0;$223 = 0;
            } else {
             $213 = HEAP32[$121>>2]|0;
             $214 = (($213) + ($129<<2)|0);
             $215 = HEAP32[$214>>2]|0;
             $216 = (($129) + 1)|0;
             $217 = (($213) + ($216<<2)|0);
             $218 = HEAP32[$217>>2]|0;
             $219 = (($218) - ($215))|0;
             $220 = HEAP32[$122>>2]|0;
             $221 = (($220) + ($215<<3)|0);
             $222 = $221;$223 = $219;
            }
            __THREW__ = 0;
            invoke_viiiiii(100,($58|0),($222|0),($223|0),($activeLights|0),($124|0),($fwdLightsParams|0));
            $224 = __THREW__; __THREW__ = 0;
            $225 = $224&1;
            if ($225) {
             label = 37;
             break L31;
            }
            $226 = HEAP32[$58>>2]|0;
            $$sum = (($209) + 112)|0;
            $227 = (($226) + ($$sum)|0);
            $228 = HEAP32[$227>>2]|0;
            $229 = ($228|0)!=(0);
            $230 = (($131) + 42|0);
            $231 = HEAP8[$230>>0]|0;
            $$not1 = ($231<<24>>24)==(0);
            $brmerge = $232 | $$not1;
            do {
             if ($brmerge) {
              $mainDirShadowLight$3 = $mainDirShadowLight$070;
             } else {
              $233 = HEAP32[$116>>2]|0;
              $234 = (($124) + 64|0);
              __THREW__ = 0;
              $235 = (invoke_iii(2365,($233|0),($234|0))|0);
              $236 = __THREW__; __THREW__ = 0;
              $237 = $236&1;
              if ($237) {
               label = 37;
               break L31;
              }
              if (!($235)) {
               $mainDirShadowLight$3 = $mainDirShadowLight$070;
               break;
              }
              $$sum33 = (($209) + 108)|0;
              $238 = (($226) + ($$sum33)|0);
              $239 = HEAP32[$238>>2]|0;
              $240 = ($239|0)==(0|0);
              do {
               if ($240) {
                $mainDirShadowLight$2 = $mainDirShadowLight$070;
               } else {
                $241 = HEAP32[$239>>2]|0;
                $242 = (($241) + 116|0);
                $243 = HEAP32[$242>>2]|0;
                $244 = ($243|0)==(0);
                if ($244) {
                 $mainDirShadowLight$2 = $mainDirShadowLight$070;
                 break;
                }
                $245 = ($mainDirShadowLight$070|0)==(0|0);
                $$mainDirShadowLight$0 = $245 ? $239 : $mainDirShadowLight$070;
                $246 = ($$mainDirShadowLight$0|0)==($239|0);
                if ($246) {
                 $247 = Math_fround(HEAPF32[$234>>2]);
                 $248 = (($124) + 76|0);
                 $249 = Math_fround(HEAPF32[$248>>2]);
                 $250 = Math_fround($247 + $249);
                 $251 = (($124) + 68|0);
                 $252 = Math_fround(HEAPF32[$251>>2]);
                 $253 = (($124) + 80|0);
                 $254 = Math_fround(HEAPF32[$253>>2]);
                 $255 = Math_fround($252 + $254);
                 $256 = (($124) + 72|0);
                 $257 = Math_fround(HEAPF32[$256>>2]);
                 $258 = (($124) + 84|0);
                 $259 = Math_fround(HEAPF32[$258>>2]);
                 $260 = Math_fround($257 + $259);
                 $261 = Math_fround(HEAPF32[$35>>2]);
                 $262 = $250 < $261;
                 $263 = $262 ? $250 : $261;
                 $264 = Math_fround(HEAPF32[$119>>2]);
                 $265 = $255 < $264;
                 $266 = $265 ? $255 : $264;
                 $267 = Math_fround(HEAPF32[$120>>2]);
                 $268 = $260 < $267;
                 $269 = $268 ? $260 : $267;
                 HEAPF32[$35>>2] = $263;
                 HEAPF32[$119>>2] = $266;
                 HEAPF32[$120>>2] = $269;
                 $270 = Math_fround(HEAPF32[$36>>2]);
                 $271 = $270 < $250;
                 $272 = $271 ? $250 : $270;
                 $273 = Math_fround(HEAPF32[$37>>2]);
                 $274 = $273 < $255;
                 $275 = $274 ? $255 : $273;
                 $276 = Math_fround(HEAPF32[$38>>2]);
                 $277 = $276 < $260;
                 $278 = $277 ? $260 : $276;
                 HEAPF32[$36>>2] = $272;
                 HEAPF32[$37>>2] = $275;
                 HEAPF32[$38>>2] = $278;
                 $279 = Math_fround(HEAPF32[$234>>2]);
                 $280 = Math_fround(HEAPF32[$248>>2]);
                 $281 = Math_fround($279 - $280);
                 $282 = Math_fround(HEAPF32[$251>>2]);
                 $283 = Math_fround(HEAPF32[$253>>2]);
                 $284 = Math_fround($282 - $283);
                 $285 = Math_fround(HEAPF32[$256>>2]);
                 $286 = Math_fround(HEAPF32[$258>>2]);
                 $287 = Math_fround($285 - $286);
                 $288 = $281 < $263;
                 $289 = $288 ? $281 : $263;
                 $290 = $284 < $266;
                 $291 = $290 ? $284 : $266;
                 $292 = $287 < $269;
                 $293 = $292 ? $287 : $269;
                 HEAPF32[$35>>2] = $289;
                 HEAPF32[$119>>2] = $291;
                 HEAPF32[$120>>2] = $293;
                 $294 = $272 < $281;
                 $295 = $294 ? $281 : $272;
                 $296 = $275 < $284;
                 $297 = $296 ? $284 : $275;
                 $298 = $278 < $287;
                 $299 = $298 ? $287 : $278;
                 HEAPF32[$36>>2] = $295;
                 HEAPF32[$37>>2] = $297;
                 HEAPF32[$38>>2] = $299;
                 $mainDirShadowLight$2 = $239;
                 break;
                } else {
                 __THREW__ = 0;
                 invoke_viiifi(3,($234|0),($239|0),($117|0),(+$12),($118|0));
                 $300 = __THREW__; __THREW__ = 0;
                 $301 = $300&1;
                 if ($301) {
                  label = 37;
                  break L31;
                 } else {
                  $mainDirShadowLight$2 = $$mainDirShadowLight$0;
                  break;
                 }
                }
               }
              } while(0);
              if (!($449)) {
               $mainDirShadowLight$3 = $mainDirShadowLight$2;
               break;
              }
              $302 = (($199) + 41|0);
              $303 = HEAP8[$302>>0]|0;
              $304 = ($303<<24>>24)==(0);
              if ($304) {
               $mainDirShadowLight$3 = $mainDirShadowLight$2;
               break;
              }
              $305 = HEAP32[$227>>2]|0;
              $$sum35 = (($209) + 128)|0;
              $306 = (($226) + ($$sum35)|0);
              $307 = ($305|0)>(0);
              if ($307) {
               $lightNo$01$i = 0;
              } else {
               $mainDirShadowLight$3 = $mainDirShadowLight$2;
               break;
              }
              while(1) {
               $308 = (($306) + ($lightNo$01$i<<2)|0);
               $309 = HEAP32[$308>>2]|0;
               $310 = HEAP32[$309>>2]|0;
               $311 = (($310) + 116|0);
               $312 = HEAP32[$311>>2]|0;
               $313 = ($312|0)==(0);
               do {
                if (!($313)) {
                 $314 = (($309) + 8|0);
                 $315 = HEAP8[$314>>0]|0;
                 $316 = ($315<<24>>24)==(0);
                 $317 = ($309|0)==($mainDirShadowLight$2|0);
                 $or$cond$i24 = $316 | $317;
                 if ($or$cond$i24) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiifi(3,($234|0),($309|0),($117|0),(+$12),($118|0));
                 $318 = __THREW__; __THREW__ = 0;
                 $319 = $318&1;
                 if ($319) {
                  label = 35;
                  break L31;
                 }
                }
               } while(0);
               $320 = (($lightNo$01$i) + 1)|0;
               $exitcond$i = ($320|0)==($305|0);
               if ($exitcond$i) {
                $mainDirShadowLight$3 = $mainDirShadowLight$2;
                break;
               } else {
                $lightNo$01$i = $320;
               }
              }
             }
            } while(0);
            $321 = (($199) + 16|0);
            $322 = HEAP32[$321>>2]|0;
            $323 = ($322|0)>(0);
            if (!($323)) {
             $mainDirShadowLight$4 = $mainDirShadowLight$3;
             break;
            }
            $324 = HEAP32[$199>>2]|0;
            $325 = HEAP8[$fwdLightsParams>>0]|0;
            $326 = $325 & 4;
            $327 = ($326<<24>>24)==(0);
            $hasAddLights$not$i20 = $229 ^ 1;
            if ($327) {
             $pass$038$us = 0;$suitablePasses$037$us = 0;
             while(1) {
              $330 = (($324) + ($pass$038$us<<2)|0);
              $331 = HEAP32[$330>>2]|0;
              $332 = (($331) + 660|0);
              $333 = HEAP32[$332>>2]|0;
              $334 = (($331) + 584|0);
              $335 = HEAP32[$334>>2]|0;
              $336 = $333 & $76;
              $337 = ($336|0)==($333|0);
              do {
               if ($337) {
                if (!((($335|0) == 0) | (($335|0) == 4) | (($335|0) == 5))) {
                 $$0$i22$us = 0;
                 break;
                }
                $338 = ($335|0)==(5);
                $or$cond$i21$us = $338 & $hasAddLights$not$i20;
                $339 = $or$cond$i21$us&1;
                $$ = $339 ^ 1;
                $$0$i22$us = $$;
               } else {
                $$0$i22$us = 0;
               }
              } while(0);
              $$suitablePasses$0$us = (($$0$i22$us) + ($suitablePasses$037$us))|0;
              $340 = (($pass$038$us) + 1)|0;
              $341 = ($340|0)<($322|0);
              $342 = ($$suitablePasses$0$us|0)<(2);
              $or$cond$us = $341 & $342;
              if ($or$cond$us) {
               $pass$038$us = $340;$suitablePasses$037$us = $$suitablePasses$0$us;
              } else {
               $suitablePasses$0$lcssa = $$suitablePasses$0$us;
               break;
              }
             }
            } else {
             $328 = $325 & 1;
             $329 = ($328<<24>>24)==(0);
             if ($329) {
              $pass$038$us39 = 0;$suitablePasses$037$us40 = 0;
              while(1) {
               $343 = (($324) + ($pass$038$us39<<2)|0);
               $344 = HEAP32[$343>>2]|0;
               $345 = (($344) + 660|0);
               $346 = HEAP32[$345>>2]|0;
               $347 = (($344) + 584|0);
               $348 = HEAP32[$347>>2]|0;
               $349 = $346 & $76;
               $350 = ($349|0)!=($346|0);
               $351 = ($348>>>0)>(3);
               $or$cond78 = $350 | $351;
               $352 = $348 & -2;
               $$not12$i12$us43 = ($352|0)==(2);
               $or$cond79 = $or$cond78 | $$not12$i12$us43;
               if ($or$cond79) {
                $$0$i22$us52 = 0;
               } else {
                $$not14$i14$us45 = ($348|0)!=(2);
                $brmerge15$i16$us46 = $$not14$i14$us45 | $useRGBM$not$i15;
                $$not16$i17$us47 = ($348|0)!=(3);
                $brmerge17$i18$us48 = $$not16$i17$us47 | $113;
                $or$cond18$i19$us49 = $brmerge15$i16$us46 & $brmerge17$i18$us48;
                $$80 = $or$cond18$i19$us49&1;
                $$0$i22$us52 = $$80;
               }
               $$suitablePasses$0$us53 = (($$0$i22$us52) + ($suitablePasses$037$us40))|0;
               $353 = (($pass$038$us39) + 1)|0;
               $354 = ($353|0)<($322|0);
               $355 = ($$suitablePasses$0$us53|0)<(2);
               $or$cond$us54 = $354 & $355;
               if ($or$cond$us54) {
                $pass$038$us39 = $353;$suitablePasses$037$us40 = $$suitablePasses$0$us53;
               } else {
                $suitablePasses$0$lcssa = $$suitablePasses$0$us53;
                break;
               }
              }
             } else {
              $pass$038 = 0;$suitablePasses$037 = 0;
              while(1) {
               $356 = (($324) + ($pass$038<<2)|0);
               $357 = HEAP32[$356>>2]|0;
               $358 = (($357) + 660|0);
               $359 = HEAP32[$358>>2]|0;
               $360 = (($357) + 584|0);
               $361 = HEAP32[$360>>2]|0;
               $362 = $359 & $76;
               $363 = ($362|0)!=($359|0);
               $364 = ($361>>>0)>(3);
               $or$cond81 = $363 | $364;
               $$not$i9 = ($361|0)==(1);
               $or$cond82 = $or$cond81 | $$not$i9;
               if ($or$cond82) {
                $$0$i22 = 0;
               } else {
                $$not14$i14 = ($361|0)!=(2);
                $brmerge15$i16 = $$not14$i14 | $useRGBM$not$i15;
                $$not16$i17 = ($361|0)!=(3);
                $brmerge17$i18 = $$not16$i17 | $113;
                $or$cond18$i19 = $brmerge15$i16 & $brmerge17$i18;
                $$83 = $or$cond18$i19&1;
                $$0$i22 = $$83;
               }
               $$suitablePasses$0 = (($$0$i22) + ($suitablePasses$037))|0;
               $365 = (($pass$038) + 1)|0;
               $366 = ($365|0)<($322|0);
               $367 = ($$suitablePasses$0|0)<(2);
               $or$cond = $366 & $367;
               if ($or$cond) {
                $pass$038 = $365;$suitablePasses$037 = $$suitablePasses$0;
               } else {
                $suitablePasses$0$lcssa = $$suitablePasses$0;
                break;
               }
              }
             }
            }
            $368 = ($suitablePasses$0$lcssa|0)>(1);
            $369 = $368 ? 33554432 : 0;
            if (!($323)) {
             $mainDirShadowLight$4 = $mainDirShadowLight$3;
             break;
            }
            $hasAddLights$not$i = $229 ^ 1;
            $firstPassFlag$059 = 16777216;$pass1$060 = 0;
            while(1) {
             $370 = HEAP32[$199>>2]|0;
             $371 = (($370) + ($pass1$060<<2)|0);
             $372 = HEAP32[$371>>2]|0;
             $373 = (($372) + 660|0);
             $374 = HEAP32[$373>>2]|0;
             $375 = (($372) + 584|0);
             $376 = HEAP32[$375>>2]|0;
             $377 = HEAP8[$fwdLightsParams>>0]|0;
             $378 = $377 & 1;
             $379 = ($378<<24>>24)!=(0);
             $380 = $374 & $76;
             $381 = ($380|0)==($374|0);
             do {
              if ($381) {
               $382 = $377 & 4;
               $383 = ($382<<24>>24)==(0);
               if ($383) {
                if (!((($376|0) == 0) | (($376|0) == 4) | (($376|0) == 5))) {
                 $firstPassFlag$1 = $firstPassFlag$059;
                 break;
                }
                $386 = ($376|0)==(5);
                $or$cond$i = $386 & $hasAddLights$not$i;
                if ($or$cond$i) {
                 $firstPassFlag$1 = $firstPassFlag$059;
                 break;
                }
               } else {
                $384 = ($376>>>0)>(3);
                if ($384) {
                 $firstPassFlag$1 = $firstPassFlag$059;
                 break;
                }
                $$not$i = ($376|0)!=(1);
                $isLightmapped$not$i = $379 ^ 1;
                $brmerge$i = $$not$i | $isLightmapped$not$i;
                if (!($brmerge$i)) {
                 $firstPassFlag$1 = $firstPassFlag$059;
                 break;
                }
                $385 = $376 & -2;
                $$not12$i = ($385|0)!=(2);
                $brmerge13$i = $$not12$i | $379;
                if (!($brmerge13$i)) {
                 $firstPassFlag$1 = $firstPassFlag$059;
                 break;
                }
                $$not14$i = ($376|0)!=(2);
                $brmerge15$i = $$not14$i | $useRGBM$not$i15;
                $$not16$i = ($376|0)!=(3);
                $brmerge17$i = $$not16$i | $113;
                $or$cond18$i = $brmerge15$i & $brmerge17$i;
                if (!($or$cond18$i)) {
                 $firstPassFlag$1 = $firstPassFlag$059;
                 break;
                }
               }
               $387 = $pass1$060 & 255;
               $388 = $376 << 8;
               $389 = $firstPassFlag$059 | $369;
               $390 = $389 | $387;
               $391 = $390 | $388;
               $392 = HEAP32[$34>>2]|0;
               $393 = (($392) + 1)|0;
               HEAP32[$34>>2] = $393;
               $394 = HEAP32[$115>>2]|0;
               $395 = $394 & 2147483647;
               $396 = ($393>>>0)>($395>>>0);
               if ($396) {
                $397 = $394 << 1;
                $398 = ($397|0)==(0);
                $399 = $398 ? 1 : $397;
                $400 = ($395>>>0)<($399>>>0);
                do {
                 if ($400) {
                  $401 = ($394|0)>(-1);
                  if ($401) {
                   HEAP32[$115>>2] = $399;
                   $402 = HEAP32[$114>>2]|0;
                   $403 = $399 << 3;
                   $404 = HEAP32[$33>>2]|0;
                   HEAP32[$2>>2] = $404;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
                   $405 = (invoke_iiiiiiii(108,($402|0),($403|0),4,($$byval_copy15|0),0,(568192|0),370)|0);
                   $406 = __THREW__; __THREW__ = 0;
                   $407 = $406&1;
                   if ($407) {
                    label = 36;
                    break L31;
                   }
                   HEAP32[$114>>2] = $405;
                   break;
                  } else {
                   $408 = $399 << 3;
                   $409 = HEAP32[$33>>2]|0;
                   HEAP32[$3>>2] = $409;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;
                   $410 = (invoke_iiiiiii(102,($408|0),4,($$byval_copy15|0),0,(568192|0),352)|0);
                   $411 = __THREW__; __THREW__ = 0;
                   $412 = $411&1;
                   if ($412) {
                    label = 36;
                    break L31;
                   }
                   $413 = HEAP32[$114>>2]|0;
                   $414 = HEAP32[$34>>2]|0;
                   $415 = $414 << 3;
                   _memcpy(($410|0),($413|0),($415|0))|0;
                   HEAP32[$115>>2] = $399;
                   HEAP32[$114>>2] = $410;
                   break;
                  }
                 }
                } while(0);
                $$pre$i$i = HEAP32[$34>>2]|0;
                $417 = $$pre$i$i;
               } else {
                $417 = $393;
               }
               $416 = (($417) + -1)|0;
               $418 = HEAP32[$114>>2]|0;
               $419 = (($418) + ($416<<3)|0);
               $420 = $419;
               $421 = $420;
               HEAP32[$421>>2] = $roIndex$068;
               $422 = (($420) + 4)|0;
               $423 = $422;
               HEAP32[$423>>2] = $391;
               $firstPassFlag$1 = 0;
              } else {
               $firstPassFlag$1 = $firstPassFlag$059;
              }
             } while(0);
             $424 = (($pass1$060) + 1)|0;
             $425 = ($424|0)<($322|0);
             if ($425) {
              $firstPassFlag$059 = $firstPassFlag$1;$pass1$060 = $424;
             } else {
              $mainDirShadowLight$4 = $mainDirShadowLight$3;
              break;
             }
            }
           }
          } while(0);
          $426 = (($it$067) + 44|0);
          $427 = ($426|0)==($103|0);
          if ($427) {
           $$pre$phiZ2D = $114;$mainDirShadowLight$0$lcssa = $mainDirShadowLight$4;
           break L29;
          }
          $428 = (($roIndex$068) + 1)|0;
          $it$067 = $426;$mainDirShadowLight$070 = $mainDirShadowLight$4;$roIndex$068 = $428;
         }
         if ((label|0) == 35) {
          $178 = ___cxa_find_matching_catch()|0;
          $179 = tempRet0;
          $lpad$phi$index = $178;$lpad$phi$index4 = $179;
          break L11;
         }
         else if ((label|0) == 36) {
          $180 = ___cxa_find_matching_catch()|0;
          $181 = tempRet0;
          $lpad$phi$index = $180;$lpad$phi$index4 = $181;
          break L11;
         }
         else if ((label|0) == 37) {
          $182 = ___cxa_find_matching_catch()|0;
          $183 = tempRet0;
          $lpad$phi$index = $182;$lpad$phi$index4 = $183;
          break L11;
         }
        }
       } while(0);
       if ($opaque) {
        $429 = HEAP32[$$pre$phiZ2D>>2]|0;
        $430 = HEAP32[$34>>2]|0;
        $431 = (($429) + ($430<<3)|0);
        HEAP32[$$byval_copy15>>2] = $queue;
        __ZNSt3__16__sortIRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEvT0_S7_T_($429,$431,$$byval_copy15);
       } else {
        $432 = HEAP32[$$pre$phiZ2D>>2]|0;
        $433 = HEAP32[$34>>2]|0;
        $434 = (($432) + ($433<<3)|0);
        HEAP32[$$byval_copy15>>2] = $queue;
        __ZNSt3__16__sortIRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEvT0_S7_T_($432,$434,$$byval_copy15);
       }
       $435 = HEAP32[$ctx>>2]|0;
       $436 = (($435) + 348|0);
       $437 = HEAP32[$436>>2]|0;
       $438 = (($ctx) + 8|0);
       $439 = HEAP32[$438>>2]|0;
       if ($linearLighting) {
        $440 = ($437|0)==(0|0);
        if ($440) {
         $444 = 1;
        } else {
         $441 = (($437) + 130|0);
         $442 = HEAP8[$441>>0]|0;
         $443 = ($442<<24>>24)!=(0);
         $444 = $443;
        }
       } else {
        $444 = 0;
       }
       __THREW__ = 0;
       invoke_viiiiiiii(23,($queue|0),($mainDirShadowLight$0$lcssa|0),($mainShadowMap|0),($439|0),($disableDynamicBatching|0),($444|0),($clearFrameBuffer|0),($opaque|0));
       $445 = __THREW__; __THREW__ = 0;
       $446 = $445&1;
       if ($446) {
        label = 38;
       } else {
        __ZN23ForwardShaderRenderLoopD2Ev($queue);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 38) {
  $184 = ___cxa_find_matching_catch()|0;
  $185 = tempRet0;
  $lpad$phi$index = $184;$lpad$phi$index4 = $185;
 }
 __THREW__ = 0;
 invoke_vi(3403,($queue|0));
 $186 = __THREW__; __THREW__ = 0;
 $187 = $186&1;
 if ($187) {
  $447 = ___cxa_find_matching_catch(0|0)|0;
  $448 = tempRet0;
  ___clang_call_terminate($447);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZL24PutAdditionalShadowLightRK4AABBRK11ActiveLightRK10Matrix4x4ffR13dynamic_arrayI16ForwardShadowMapLj4EE($bounds,$light,$cameraMatrix,$shadowDistance,$outShadowMaps) {
 $bounds = $bounds|0;
 $light = $light|0;
 $cameraMatrix = $cameraMatrix|0;
 $shadowDistance = Math_fround($shadowDistance);
 $outShadowMaps = $outShadowMaps|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0;
 var $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0;
 var $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0;
 var $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0;
 var $lightPos$i = 0, $sl$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $lightPos$i = sp + 4|0;
 $1 = HEAP32[$outShadowMaps>>2]|0;
 $2 = (($outShadowMaps) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + (($3*96)|0)|0);
 $5 = ($3|0)==(0);
 L1: do {
  if (!($5)) {
   $sl$04 = $1;
   while(1) {
    $8 = HEAP32[$sl$04>>2]|0;
    $9 = ($8|0)==($light|0);
    $7 = (($sl$04) + 96|0);
    if ($9) {
     break;
    }
    $6 = ($7|0)==($4|0);
    if ($6) {
     break L1;
    } else {
     $sl$04 = $7;
    }
   }
   $98 = Math_fround(HEAPF32[$bounds>>2]);
   $99 = (($bounds) + 12|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = Math_fround($98 + $100);
   $102 = (($bounds) + 4|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = (($bounds) + 16|0);
   $105 = Math_fround(HEAPF32[$104>>2]);
   $106 = Math_fround($103 + $105);
   $107 = (($bounds) + 8|0);
   $108 = Math_fround(HEAPF32[$107>>2]);
   $109 = (($bounds) + 20|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = Math_fround($108 + $110);
   $112 = (($sl$04) + 72|0);
   $113 = Math_fround(HEAPF32[$112>>2]);
   $114 = $101 < $113;
   $115 = $114 ? $101 : $113;
   $116 = (($sl$04) + 76|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = $106 < $117;
   $119 = $118 ? $106 : $117;
   $120 = (($sl$04) + 80|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = $111 < $121;
   $123 = $122 ? $111 : $121;
   HEAPF32[$112>>2] = $115;
   HEAPF32[$116>>2] = $119;
   HEAPF32[$120>>2] = $123;
   $124 = (($sl$04) + 84|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = $125 < $101;
   $127 = $126 ? $101 : $125;
   $128 = (($sl$04) + 88|0);
   $129 = Math_fround(HEAPF32[$128>>2]);
   $130 = $129 < $106;
   $131 = $130 ? $106 : $129;
   $132 = (($sl$04) + 92|0);
   $133 = Math_fround(HEAPF32[$132>>2]);
   $134 = $133 < $111;
   $135 = $134 ? $111 : $133;
   HEAPF32[$124>>2] = $127;
   HEAPF32[$128>>2] = $131;
   HEAPF32[$132>>2] = $135;
   $136 = Math_fround(HEAPF32[$bounds>>2]);
   $137 = Math_fround(HEAPF32[$99>>2]);
   $138 = Math_fround($136 - $137);
   $139 = Math_fround(HEAPF32[$102>>2]);
   $140 = Math_fround(HEAPF32[$104>>2]);
   $141 = Math_fround($139 - $140);
   $142 = Math_fround(HEAPF32[$107>>2]);
   $143 = Math_fround(HEAPF32[$109>>2]);
   $144 = Math_fround($142 - $143);
   $145 = $138 < $115;
   $146 = $145 ? $138 : $115;
   $147 = $141 < $119;
   $148 = $147 ? $141 : $119;
   $149 = $144 < $123;
   $150 = $149 ? $144 : $123;
   HEAPF32[$112>>2] = $146;
   HEAPF32[$116>>2] = $148;
   HEAPF32[$120>>2] = $150;
   $151 = $127 < $138;
   $152 = $151 ? $138 : $127;
   $153 = $131 < $141;
   $154 = $153 ? $141 : $131;
   $155 = $135 < $144;
   $156 = $155 ? $144 : $135;
   HEAPF32[$124>>2] = $152;
   HEAPF32[$128>>2] = $154;
   HEAPF32[$132>>2] = $156;
   STACKTOP = sp;return;
  }
 } while(0);
 $10 = HEAP32[$light>>2]|0;
 $11 = (($10) + 216|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(1);
 do {
  if ($13) {
   $42 = $3;
  } else {
   $14 = (($10) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($15)|0);
   __ZNK9Transform11GetPositionEv($lightPos$i,$16);
   $17 = Math_fround(HEAPF32[$lightPos$i>>2]);
   $18 = (($lightPos$i) + 4|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = (($lightPos$i) + 8|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = (($cameraMatrix) + 8|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($17 * $23);
   $25 = (($cameraMatrix) + 24|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = Math_fround($19 * $26);
   $28 = Math_fround($24 + $27);
   $29 = (($cameraMatrix) + 40|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = Math_fround($21 * $30);
   $32 = Math_fround($28 + $31);
   $33 = (($cameraMatrix) + 56|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = Math_fround($34 + $32);
   $36 = Math_fround(-$35);
   $37 = (($10) + 188|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($36 - $38);
   $40 = $39 > $shadowDistance;
   if ($40) {
    STACKTOP = sp;return;
   } else {
    $$pre = HEAP32[$2>>2]|0;
    $42 = $$pre;
    break;
   }
  }
 } while(0);
 $41 = (($42) + 1)|0;
 HEAP32[$2>>2] = $41;
 $43 = (($outShadowMaps) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 & 2147483647;
 $46 = ($41>>>0)>($45>>>0);
 if ($46) {
  $47 = $44 << 1;
  $48 = ($47|0)==(0);
  $49 = $48 ? 1 : $47;
  $50 = ($45>>>0)<($49>>>0);
  do {
   if ($50) {
    $51 = ($44|0)>(-1);
    if ($51) {
     HEAP32[$43>>2] = $49;
     $52 = HEAP32[$outShadowMaps>>2]|0;
     $53 = ($49*96)|0;
     $54 = (($outShadowMaps) + 4|0);
     $55 = HEAP32[$54>>2]|0;
     HEAP32[$0>>2] = $55;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $56 = (__Z16realloc_internalPvji10MemLabelIdiPKci($52,$53,4,$$byval_copy1,0,568192,370)|0);
     HEAP32[$outShadowMaps>>2] = $56;
     break;
    } else {
     $57 = ($49*96)|0;
     $58 = (($outShadowMaps) + 4|0);
     $59 = HEAP32[$58>>2]|0;
     HEAP32[$0>>2] = $59;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($57,4,$$byval_copy1,0,568192,352)|0);
     $61 = HEAP32[$outShadowMaps>>2]|0;
     $62 = HEAP32[$2>>2]|0;
     $63 = ($62*96)|0;
     _memcpy(($60|0),($61|0),($63|0))|0;
     HEAP32[$43>>2] = $49;
     HEAP32[$outShadowMaps>>2] = $60;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$2>>2]|0;
  $65 = $$pre$i;
 } else {
  $65 = $41;
 }
 $64 = (($65) + -1)|0;
 $66 = HEAP32[$outShadowMaps>>2]|0;
 $67 = (($66) + (($64*96)|0)|0);
 HEAP32[$67>>2] = $light;
 $68 = Math_fround(HEAPF32[$bounds>>2]);
 $69 = (($bounds) + 12|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($68 - $70);
 $72 = (($bounds) + 4|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($bounds) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($73 - $75);
 $77 = (($bounds) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($bounds) + 20|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($78 - $80);
 $82 = ((($66) + (($64*96)|0)|0) + 72|0);
 HEAPF32[$82>>2] = $71;
 $83 = ((($66) + (($64*96)|0)|0) + 76|0);
 HEAPF32[$83>>2] = $76;
 $84 = ((($66) + (($64*96)|0)|0) + 80|0);
 HEAPF32[$84>>2] = $81;
 $85 = Math_fround(HEAPF32[$bounds>>2]);
 $86 = Math_fround(HEAPF32[$69>>2]);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround(HEAPF32[$72>>2]);
 $89 = Math_fround(HEAPF32[$74>>2]);
 $90 = Math_fround($88 + $89);
 $91 = Math_fround(HEAPF32[$77>>2]);
 $92 = Math_fround(HEAPF32[$79>>2]);
 $93 = Math_fround($91 + $92);
 $94 = ((($66) + (($64*96)|0)|0) + 84|0);
 HEAPF32[$94>>2] = $87;
 $95 = ((($66) + (($64*96)|0)|0) + 88|0);
 HEAPF32[$95>>2] = $90;
 $96 = ((($66) + (($64*96)|0)|0) + 92|0);
 HEAPF32[$96>>2] = $93;
 $97 = ((($66) + (($64*96)|0)|0) + 4|0);
 HEAP32[$97>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$02$i = 0, $__i$07 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__k$0$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 5:  {
    label = 11;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 54;
    break L1;
    break;
   }
   default: {
   }
   }
   $89 = ($3|0)<(248);
   if ($89) {
    label = 13;
    break L1;
   }
   $130 = ($3|0)>(7992);
   $131 = (($4|0) / 2)&-1;
   $132 = (($$0) + ($131<<3)|0);
   if ($130) {
    $133 = (($4|0) / 4)&-1;
    $134 = (($$0) + ($133<<3)|0);
    $$sum = (($133) + ($131))|0;
    $135 = (($$0) + ($$sum<<3)|0);
    $136 = (__ZNSt3__17__sort5IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_S7_S7_T_($$0,$134,$132,$135,$1,$__comp)|0);
    $__n_swaps$0 = $136;
   } else {
    $137 = (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($$0,$132,$1,$__comp)|0);
    $__n_swaps$0 = $137;
   }
   $138 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$$0,$132)|0);
   do {
    if ($138) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $139 = (($__j$0) + -8|0);
      $140 = ($$0|0)==($139|0);
      if ($140) {
       break;
      }
      $193 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$139,$132)|0);
      if ($193) {
       label = 37;
       break;
      } else {
       $__j$0 = $139;
      }
     }
     if ((label|0) == 37) {
      label = 0;
      $194 = $$0;
      $195 = $194;
      $196 = HEAP32[$195>>2]|0;
      $197 = (($194) + 4)|0;
      $198 = $197;
      $199 = HEAP32[$198>>2]|0;
      $200 = $139;
      $201 = $200;
      $202 = HEAP32[$201>>2]|0;
      $203 = (($200) + 4)|0;
      $204 = $203;
      $205 = HEAP32[$204>>2]|0;
      $206 = $$0;
      $207 = $206;
      HEAP32[$207>>2] = $202;
      $208 = (($206) + 4)|0;
      $209 = $208;
      HEAP32[$209>>2] = $205;
      $210 = $139;
      $211 = $210;
      HEAP32[$211>>2] = $196;
      $212 = (($210) + 4)|0;
      $213 = $212;
      HEAP32[$213>>2] = $199;
      $214 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $139;$__n_swaps$3 = $214;
      break;
     }
     $141 = (($$0) + 8|0);
     $142 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$$0,$1)|0);
     if ($142) {
      $__i$1 = $141;
     } else {
      $143 = ($141|0)==($1|0);
      if ($143) {
       label = 54;
       break L1;
      } else {
       $__i$07 = $141;
      }
      while(1) {
       $146 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$$0,$__i$07)|0);
       $145 = (($__i$07) + 8|0);
       if ($146) {
        break;
       }
       $144 = ($145|0)==($1|0);
       if ($144) {
        label = 54;
        break L1;
       } else {
        $__i$07 = $145;
       }
      }
      $147 = $__i$07;
      $148 = $147;
      $149 = HEAP32[$148>>2]|0;
      $150 = (($147) + 4)|0;
      $151 = $150;
      $152 = HEAP32[$151>>2]|0;
      $153 = $1;
      $154 = $153;
      $155 = HEAP32[$154>>2]|0;
      $156 = (($153) + 4)|0;
      $157 = $156;
      $158 = HEAP32[$157>>2]|0;
      $159 = $__i$07;
      $160 = $159;
      HEAP32[$160>>2] = $155;
      $161 = (($159) + 4)|0;
      $162 = $161;
      HEAP32[$162>>2] = $158;
      $163 = $1;
      $164 = $163;
      HEAP32[$164>>2] = $149;
      $165 = (($163) + 4)|0;
      $166 = $165;
      HEAP32[$166>>2] = $152;
      $__i$1 = $145;
     }
     $167 = ($__i$1|0)==($1|0);
     if ($167) {
      label = 54;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $168 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$$0,$__i$2)|0);
       $169 = (($__i$2) + 8|0);
       if ($168) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $169;
       }
      }
      while(1) {
       $170 = (($__j$2) + -8|0);
       $171 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$$0,$170)|0);
       if ($171) {
        $__j$2 = $170;
       } else {
        break;
       }
      }
      $172 = ($__i$2>>>0)<($170>>>0);
      if (!($172)) {
       $$0 = $__i$2;
       continue L3;
      }
      $173 = $__i$2;
      $174 = $173;
      $175 = HEAP32[$174>>2]|0;
      $176 = (($173) + 4)|0;
      $177 = $176;
      $178 = HEAP32[$177>>2]|0;
      $179 = $170;
      $180 = $179;
      $181 = HEAP32[$180>>2]|0;
      $182 = (($179) + 4)|0;
      $183 = $182;
      $184 = HEAP32[$183>>2]|0;
      $185 = $__i$2;
      $186 = $185;
      HEAP32[$186>>2] = $181;
      $187 = (($185) + 4)|0;
      $188 = $187;
      HEAP32[$188>>2] = $184;
      $189 = $170;
      $190 = $189;
      HEAP32[$190>>2] = $175;
      $191 = (($189) + 4)|0;
      $192 = $191;
      HEAP32[$192>>2] = $178;
      $__i$2$ph = $169;$__j$1$ph = $170;
     }
    }
   } while(0);
   $215 = (($$0) + 8|0);
   $216 = ($215>>>0)<($__j$3>>>0);
   L34: do {
    if ($216) {
     $__i$3$ph = $215;$__j$4$ph = $__j$3;$__m$0$ph = $132;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $217 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$__i$3,$__m$0$ph)|0);
       $218 = (($__i$3) + 8|0);
       if ($217) {
        $__i$3 = $218;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $219 = (($__j$5) + -8|0);
       $220 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$219,$__m$0$ph)|0);
       if ($220) {
        break;
       } else {
        $__j$5 = $219;
       }
      }
      $221 = ($__i$3>>>0)>($219>>>0);
      if ($221) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $222 = $__i$3;
      $223 = $222;
      $224 = HEAP32[$223>>2]|0;
      $225 = (($222) + 4)|0;
      $226 = $225;
      $227 = HEAP32[$226>>2]|0;
      $228 = $219;
      $229 = $228;
      $230 = HEAP32[$229>>2]|0;
      $231 = (($228) + 4)|0;
      $232 = $231;
      $233 = HEAP32[$232>>2]|0;
      $234 = $__i$3;
      $235 = $234;
      HEAP32[$235>>2] = $230;
      $236 = (($234) + 4)|0;
      $237 = $236;
      HEAP32[$237>>2] = $233;
      $238 = $219;
      $239 = $238;
      HEAP32[$239>>2] = $224;
      $240 = (($238) + 4)|0;
      $241 = $240;
      HEAP32[$241>>2] = $227;
      $242 = (($__n_swaps$4$ph) + 1)|0;
      $243 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $243 ? $219 : $__m$0$ph;
      $__i$3$ph = $218;$__j$4$ph = $219;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $242;
     }
    } else {
     $__i$4 = $215;$__m$2 = $132;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $244 = ($__i$4|0)==($__m$2|0);
   if ($244) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $245 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$__m$2,$__i$4)|0);
    if ($245) {
     $246 = $__i$4;
     $247 = $246;
     $248 = HEAP32[$247>>2]|0;
     $249 = (($246) + 4)|0;
     $250 = $249;
     $251 = HEAP32[$250>>2]|0;
     $252 = $__m$2;
     $253 = $252;
     $254 = HEAP32[$253>>2]|0;
     $255 = (($252) + 4)|0;
     $256 = $255;
     $257 = HEAP32[$256>>2]|0;
     $258 = $__i$4;
     $259 = $258;
     HEAP32[$259>>2] = $254;
     $260 = (($258) + 4)|0;
     $261 = $260;
     HEAP32[$261>>2] = $257;
     $262 = $__m$2;
     $263 = $262;
     HEAP32[$263>>2] = $248;
     $264 = (($262) + 4)|0;
     $265 = $264;
     HEAP32[$265>>2] = $251;
     $266 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $266;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $267 = ($__n_swaps$6|0)==(0);
   if ($267) {
    $268 = (__ZNSt3__127__insertion_sort_incompleteIRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEbT0_S7_T_($$0,$__i$4,$__comp)|0);
    $269 = (($__i$4) + 8|0);
    $270 = (__ZNSt3__127__insertion_sort_incompleteIRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEbT0_S7_T_($269,$$01$ph,$__comp)|0);
    if ($270) {
     label = 49;
     break;
    }
    if ($268) {
     $$0 = $269;
     continue;
    }
   }
   $271 = $__i$4;
   $272 = (($271) - ($2))|0;
   $273 = (($0) - ($271))|0;
   $274 = ($272|0)<($273|0);
   if (!($274)) {
    label = 53;
    break;
   }
   __ZNSt3__16__sortIRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEvT0_S7_T_($$0,$__i$4,$__comp);
   $275 = (($__i$4) + 8|0);
   $$0 = $275;
  }
  if ((label|0) == 49) {
   label = 0;
   if ($268) {
    label = 54;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 53) {
   label = 0;
   $276 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEvT0_S7_T_($276,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$1,$$0)|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = $$0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $1;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $$0;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $1;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $26 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($$0,$26,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $27 = (($$0) + 8|0);
  $28 = (($$0) + 16|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($$0,$27,$28,$__comp)|0);
  $29 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$1,$28)|0);
  if (!($29)) {
   STACKTOP = sp;return;
  }
  $30 = $28;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 4)|0;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = $1;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $28;
  $43 = $42;
  HEAP32[$43>>2] = $38;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $41;
  $46 = $1;
  $47 = $46;
  HEAP32[$47>>2] = $32;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $35;
  $50 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$28,$27)|0);
  if (!($50)) {
   STACKTOP = sp;return;
  }
  $51 = $27;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $28;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = (($57) + 4)|0;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = $27;
  $64 = $63;
  HEAP32[$64>>2] = $59;
  $65 = (($63) + 4)|0;
  $66 = $65;
  HEAP32[$66>>2] = $62;
  $67 = $28;
  $68 = $67;
  HEAP32[$68>>2] = $53;
  $69 = (($67) + 4)|0;
  $70 = $69;
  HEAP32[$70>>2] = $56;
  $71 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$27,$$0)|0);
  if (!($71)) {
   STACKTOP = sp;return;
  }
  $72 = $$0;
  $73 = $72;
  $74 = HEAP32[$73>>2]|0;
  $75 = (($72) + 4)|0;
  $76 = $75;
  $77 = HEAP32[$76>>2]|0;
  $78 = $$0;
  $79 = $78;
  HEAP32[$79>>2] = $59;
  $80 = (($78) + 4)|0;
  $81 = $80;
  HEAP32[$81>>2] = $62;
  $82 = $27;
  $83 = $82;
  HEAP32[$83>>2] = $74;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $77;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  $86 = (($$0) + 8|0);
  $87 = (($$0) + 16|0);
  $88 = (($$0) + 24|0);
  (__ZNSt3__17__sort5IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_S7_S7_T_($$0,$86,$87,$88,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 13) {
  $90 = (($$0) + 16|0);
  $91 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($$0,$91,$90,$__comp)|0);
  $92 = (($$0) + 24|0);
  $93 = ($92|0)==($$01$ph|0);
  if ($93) {
   STACKTOP = sp;return;
  } else {
   $__i$02$i = $92;$__j$01$i = $90;
  }
  while(1) {
   $94 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$__i$02$i,$__j$01$i)|0);
   if ($94) {
    $95 = $__i$02$i;
    $96 = $95;
    $97 = HEAP32[$96>>2]|0;
    $98 = (($95) + 4)|0;
    $99 = $98;
    $100 = HEAP32[$99>>2]|0;
    $101 = $__t$i;
    $102 = $101;
    HEAP32[$102>>2] = $97;
    $103 = (($101) + 4)|0;
    $104 = $103;
    HEAP32[$104>>2] = $100;
    $__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     $105 = $__k$0$i;
     $106 = $105;
     $107 = HEAP32[$106>>2]|0;
     $108 = (($105) + 4)|0;
     $109 = $108;
     $110 = HEAP32[$109>>2]|0;
     $111 = $__j$1$i;
     $112 = $111;
     HEAP32[$112>>2] = $107;
     $113 = (($111) + 4)|0;
     $114 = $113;
     HEAP32[$114>>2] = $110;
     $115 = ($__k$0$i|0)==($$0|0);
     if ($115) {
      break;
     }
     $116 = (($__k$0$i) + -8|0);
     $117 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$__t$i,$116)|0);
     if ($117) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $116;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $118 = $__t$i;
    $119 = $118;
    $120 = HEAP32[$119>>2]|0;
    $121 = (($118) + 4)|0;
    $122 = $121;
    $123 = HEAP32[$122>>2]|0;
    $124 = $__k$0$i;
    $125 = $124;
    HEAP32[$125>>2] = $120;
    $126 = (($124) + 4)|0;
    $127 = $126;
    HEAP32[$127>>2] = $123;
   }
   $128 = (($__i$02$i) + 8|0);
   $129 = ($128|0)==($$01$ph|0);
   if ($129) {
    break;
   } else {
    $__j$01$i$phi = $__i$02$i;$__i$02$i = $128;$__j$01$i = $__j$01$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 54) {
  STACKTOP = sp;return;
 }
}
function __ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($this,$ra,$rb) {
 $this = $this|0;
 $ra = $ra|0;
 $rb = $rb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$ra>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$rb>>2]|0;
 $6 = ((($4) + (($3*44)|0)|0) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($4) + (($5*44)|0)|0) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if (!($10)) {
  $11 = ($7>>>0)<($9>>>0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ((($4) + (($3*44)|0)|0) + 4|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = ((($4) + (($5*44)|0)|0) + 4|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = ($13<<16>>16)==($15<<16>>16);
 if (!($16)) {
  $17 = ($13<<16>>16)<($15<<16>>16);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = ((($4) + (($3*44)|0)|0) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($4) + (($5*44)|0)|0) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = $19 != $21;
 if ($22) {
  $23 = $19 < $21;
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = ((($4) + (($3*44)|0)|0) + 16|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = ((($4) + (($5*44)|0)|0) + 16|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = ($25<<16>>16)==($27<<16>>16);
 if (!($28)) {
  $29 = ($25&65535)<($27&65535);
  $$0 = $29;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (($ra) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($rb) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $31 & 16777216;
 $35 = $33 & 16777216;
 $36 = ($34|0)==($35|0);
 if (!($36)) {
  $37 = ($34>>>0)>($35>>>0);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = ((($4) + (($3*44)|0)|0) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($4) + (($5*44)|0)|0) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)==($41|0);
 if (!($42)) {
  $43 = ($39>>>0)<($41>>>0);
  $$0 = $43;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = ((($4) + (($3*44)|0)|0) + 20|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($4) + (($5*44)|0)|0) + 20|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($45|0)==($47|0);
 if (!($48)) {
  $49 = ($45|0)>($47|0);
  $$0 = $49;
  STACKTOP = sp;return ($$0|0);
 }
 $50 = ((($4) + (($3*44)|0)|0) + 36|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($4) + (($5*44)|0)|0) + 36|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($51|0)==($53|0);
 if (!($54)) {
  $55 = (($51) + 4|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($53) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($56|0)<($58|0);
  $$0 = $59;
  STACKTOP = sp;return ($$0|0);
 }
 $60 = (($4) + (($3*44)|0)|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($4) + (($5*44)|0)|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($61|0)==($63|0);
 if (!($64)) {
  $65 = (($61) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($63) + 4|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($66|0)<($68|0);
  $$0 = $69;
  STACKTOP = sp;return ($$0|0);
 }
 $70 = $31 & 255;
 $71 = $33 & 255;
 $72 = ($70|0)==($71|0);
 if ($72) {
  $74 = ($3|0)<($5|0);
  $$0 = $74;
  STACKTOP = sp;return ($$0|0);
 } else {
  $73 = ($70>>>0)<($71>>>0);
  $$0 = $73;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__y,$__x)|0);
 $1 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__z,$__y)|0);
 if (!($0)) {
  if (!($1)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $2 = $__y;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__z;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__y;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__z;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__y,$__x)|0);
  if (!($22)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $23 = $__x;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $__y;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 4)|0;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = $__x;
  $36 = $35;
  HEAP32[$36>>2] = $31;
  $37 = (($35) + 4)|0;
  $38 = $37;
  HEAP32[$38>>2] = $34;
  $39 = $__y;
  $40 = $39;
  HEAP32[$40>>2] = $25;
  $41 = (($39) + 4)|0;
  $42 = $41;
  HEAP32[$42>>2] = $28;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = $__x;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 if ($1) {
  $49 = $__z;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $__x;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = $__z;
  $60 = $59;
  HEAP32[$60>>2] = $45;
  $61 = (($59) + 4)|0;
  $62 = $61;
  HEAP32[$62>>2] = $48;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = $__y;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $__x;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $__y;
 $74 = $73;
 HEAP32[$74>>2] = $45;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $48;
 $77 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__z,$__y)|0);
 if (!($77)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = $__z;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__y;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__z;
 $89 = $88;
 HEAP32[$89>>2] = $45;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $48;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort5IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__r$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__x4,$__x3)|0);
 if ($1) {
  $2 = $__x3;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__x4;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__x3;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__x4;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (($0) + 1)|0;
  $23 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__x3,$__x2)|0);
  if ($23) {
   $24 = $__x2;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 4)|0;
   $28 = $27;
   $29 = HEAP32[$28>>2]|0;
   $30 = $__x3;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $__x2;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
   $40 = $__x3;
   $41 = $40;
   HEAP32[$41>>2] = $26;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $29;
   $44 = (($0) + 2)|0;
   $45 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__x2,$__x1)|0);
   if ($45) {
    $46 = $__x1;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4)|0;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = $__x2;
    $53 = $52;
    $54 = HEAP32[$53>>2]|0;
    $55 = (($52) + 4)|0;
    $56 = $55;
    $57 = HEAP32[$56>>2]|0;
    $58 = $__x1;
    $59 = $58;
    HEAP32[$59>>2] = $54;
    $60 = (($58) + 4)|0;
    $61 = $60;
    HEAP32[$61>>2] = $57;
    $62 = $__x2;
    $63 = $62;
    HEAP32[$63>>2] = $48;
    $64 = (($62) + 4)|0;
    $65 = $64;
    HEAP32[$65>>2] = $51;
    $66 = (($0) + 3)|0;
    $__r$0$i = $66;
   } else {
    $__r$0$i = $44;
   }
  } else {
   $__r$0$i = $22;
  }
 } else {
  $__r$0$i = $0;
 }
 $67 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__x5,$__x4)|0);
 if (!($67)) {
  $__r$0 = $__r$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $68 = $__x4;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = $__x5;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = (($74) + 4)|0;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = $__x4;
 $81 = $80;
 HEAP32[$81>>2] = $76;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $79;
 $84 = $__x5;
 $85 = $84;
 HEAP32[$85>>2] = $70;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $73;
 $88 = (($__r$0$i) + 1)|0;
 $89 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__x4,$__x3)|0);
 if (!($89)) {
  $__r$0 = $88;
  STACKTOP = sp;return ($__r$0|0);
 }
 $90 = $__x3;
 $91 = $90;
 $92 = HEAP32[$91>>2]|0;
 $93 = (($90) + 4)|0;
 $94 = $93;
 $95 = HEAP32[$94>>2]|0;
 $96 = $__x4;
 $97 = $96;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($96) + 4)|0;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = $__x3;
 $103 = $102;
 HEAP32[$103>>2] = $98;
 $104 = (($102) + 4)|0;
 $105 = $104;
 HEAP32[$105>>2] = $101;
 $106 = $__x4;
 $107 = $106;
 HEAP32[$107>>2] = $92;
 $108 = (($106) + 4)|0;
 $109 = $108;
 HEAP32[$109>>2] = $95;
 $110 = (($__r$0$i) + 2)|0;
 $111 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__x3,$__x2)|0);
 if (!($111)) {
  $__r$0 = $110;
  STACKTOP = sp;return ($__r$0|0);
 }
 $112 = $__x2;
 $113 = $112;
 $114 = HEAP32[$113>>2]|0;
 $115 = (($112) + 4)|0;
 $116 = $115;
 $117 = HEAP32[$116>>2]|0;
 $118 = $__x3;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = (($118) + 4)|0;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = $__x2;
 $125 = $124;
 HEAP32[$125>>2] = $120;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $123;
 $128 = $__x3;
 $129 = $128;
 HEAP32[$129>>2] = $114;
 $130 = (($128) + 4)|0;
 $131 = $130;
 HEAP32[$131>>2] = $117;
 $132 = (($__r$0$i) + 3)|0;
 $133 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__c,$__x2,$__x1)|0);
 if (!($133)) {
  $__r$0 = $132;
  STACKTOP = sp;return ($__r$0|0);
 }
 $134 = $__x1;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = (($134) + 4)|0;
 $138 = $137;
 $139 = HEAP32[$138>>2]|0;
 $140 = $__x2;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $__x1;
 $147 = $146;
 HEAP32[$147>>2] = $142;
 $148 = (($146) + 4)|0;
 $149 = $148;
 HEAP32[$149>>2] = $145;
 $150 = $__x2;
 $151 = $150;
 HEAP32[$151>>2] = $136;
 $152 = (($150) + 4)|0;
 $153 = $152;
 HEAP32[$153>>2] = $139;
 $154 = (($__r$0$i) + 4)|0;
 $__r$0 = $154;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0;
 var $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 2:  {
  $4 = (($__last) + -8|0);
  $5 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$4,$__first)|0);
  if (!($5)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $6 = $__first;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $4;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $__first;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $4;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $28 = (($__first) + 8|0);
  $29 = (($__first) + 16|0);
  $30 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($__first,$28,$29,$__comp)|0);
  $31 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$30,$29)|0);
  if (!($31)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $32 = $29;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $30;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 4)|0;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = $29;
  $45 = $44;
  HEAP32[$45>>2] = $40;
  $46 = (($44) + 4)|0;
  $47 = $46;
  HEAP32[$47>>2] = $43;
  $48 = $30;
  $49 = $48;
  HEAP32[$49>>2] = $34;
  $50 = (($48) + 4)|0;
  $51 = $50;
  HEAP32[$51>>2] = $37;
  $52 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$29,$28)|0);
  if (!($52)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $53 = $28;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($53) + 4)|0;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = $29;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) + 4)|0;
  $63 = $62;
  $64 = HEAP32[$63>>2]|0;
  $65 = $28;
  $66 = $65;
  HEAP32[$66>>2] = $61;
  $67 = (($65) + 4)|0;
  $68 = $67;
  HEAP32[$68>>2] = $64;
  $69 = $29;
  $70 = $69;
  HEAP32[$70>>2] = $55;
  $71 = (($69) + 4)|0;
  $72 = $71;
  HEAP32[$72>>2] = $58;
  $73 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$28,$__first)|0);
  if (!($73)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $74 = $__first;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + 4)|0;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = $__first;
  $81 = $80;
  HEAP32[$81>>2] = $61;
  $82 = (($80) + 4)|0;
  $83 = $82;
  HEAP32[$83>>2] = $64;
  $84 = $28;
  $85 = $84;
  HEAP32[$85>>2] = $76;
  $86 = (($84) + 4)|0;
  $87 = $86;
  HEAP32[$87>>2] = $79;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $88 = (($__first) + 8|0);
  $89 = (($__first) + 16|0);
  $90 = (($__first) + 24|0);
  $91 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_S7_S7_T_($__first,$88,$89,$90,$91,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $26 = (($__first) + 8|0);
  $27 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($__first,$26,$27,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $92 = (($__first) + 16|0);
  $93 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb0EEEP14RenderPassDataEEjT0_S7_S7_T_($__first,$93,$92,$__comp)|0);
  $94 = (($__first) + 24|0);
  $95 = ($94|0)==($__last|0);
  if ($95) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $94;$__j$02 = $92;
  }
  while(1) {
   $96 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$__i$04,$__j$02)|0);
   if ($96) {
    $97 = $__i$04;
    $98 = $97;
    $99 = HEAP32[$98>>2]|0;
    $100 = (($97) + 4)|0;
    $101 = $100;
    $102 = HEAP32[$101>>2]|0;
    $103 = $__t;
    $104 = $103;
    HEAP32[$104>>2] = $99;
    $105 = (($103) + 4)|0;
    $106 = $105;
    HEAP32[$106>>2] = $102;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $107 = $__k$0;
     $108 = $107;
     $109 = HEAP32[$108>>2]|0;
     $110 = (($107) + 4)|0;
     $111 = $110;
     $112 = HEAP32[$111>>2]|0;
     $113 = $__j$1;
     $114 = $113;
     HEAP32[$114>>2] = $109;
     $115 = (($113) + 4)|0;
     $116 = $115;
     HEAP32[$116>>2] = $112;
     $117 = ($__k$0|0)==($__first|0);
     if ($117) {
      break;
     }
     $118 = (($__k$0) + -8|0);
     $119 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb0EEclERK14RenderPassDataS4_($__comp,$__t,$118)|0);
     if ($119) {
      $__j$1$phi = $__k$0;$__k$0 = $118;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $120 = $__t;
    $121 = $120;
    $122 = HEAP32[$121>>2]|0;
    $123 = (($120) + 4)|0;
    $124 = $123;
    $125 = HEAP32[$124>>2]|0;
    $126 = $__k$0;
    $127 = $126;
    HEAP32[$127>>2] = $122;
    $128 = (($126) + 4)|0;
    $129 = $128;
    HEAP32[$129>>2] = $125;
    $130 = (($__count$03) + 1)|0;
    $131 = ($130|0)==(8);
    if ($131) {
     break;
    } else {
     $__count$1 = $130;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $134 = (($__i$04) + 8|0);
   $135 = ($134|0)==($__last|0);
   if ($135) {
    $$0 = 1;
    label = 18;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $134;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 18) {
   STACKTOP = sp;return ($$0|0);
  }
  $132 = (($__i$04) + 8|0);
  $133 = ($132|0)==($__last|0);
  $$0 = $133;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16__sortIRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$02$i = 0, $__i$07 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__k$0$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 54;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 5:  {
    label = 11;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   default: {
   }
   }
   $89 = ($3|0)<(248);
   if ($89) {
    label = 13;
    break L1;
   }
   $130 = ($3|0)>(7992);
   $131 = (($4|0) / 2)&-1;
   $132 = (($$0) + ($131<<3)|0);
   if ($130) {
    $133 = (($4|0) / 4)&-1;
    $134 = (($$0) + ($133<<3)|0);
    $$sum = (($133) + ($131))|0;
    $135 = (($$0) + ($$sum<<3)|0);
    $136 = (__ZNSt3__17__sort5IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_S7_S7_T_($$0,$134,$132,$135,$1,$__comp)|0);
    $__n_swaps$0 = $136;
   } else {
    $137 = (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($$0,$132,$1,$__comp)|0);
    $__n_swaps$0 = $137;
   }
   $138 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$$0,$132)|0);
   do {
    if ($138) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $139 = (($__j$0) + -8|0);
      $140 = ($$0|0)==($139|0);
      if ($140) {
       break;
      }
      $193 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$139,$132)|0);
      if ($193) {
       label = 37;
       break;
      } else {
       $__j$0 = $139;
      }
     }
     if ((label|0) == 37) {
      label = 0;
      $194 = $$0;
      $195 = $194;
      $196 = HEAP32[$195>>2]|0;
      $197 = (($194) + 4)|0;
      $198 = $197;
      $199 = HEAP32[$198>>2]|0;
      $200 = $139;
      $201 = $200;
      $202 = HEAP32[$201>>2]|0;
      $203 = (($200) + 4)|0;
      $204 = $203;
      $205 = HEAP32[$204>>2]|0;
      $206 = $$0;
      $207 = $206;
      HEAP32[$207>>2] = $202;
      $208 = (($206) + 4)|0;
      $209 = $208;
      HEAP32[$209>>2] = $205;
      $210 = $139;
      $211 = $210;
      HEAP32[$211>>2] = $196;
      $212 = (($210) + 4)|0;
      $213 = $212;
      HEAP32[$213>>2] = $199;
      $214 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $139;$__n_swaps$3 = $214;
      break;
     }
     $141 = (($$0) + 8|0);
     $142 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$$0,$1)|0);
     if ($142) {
      $__i$1 = $141;
     } else {
      $143 = ($141|0)==($1|0);
      if ($143) {
       label = 54;
       break L1;
      } else {
       $__i$07 = $141;
      }
      while(1) {
       $146 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$$0,$__i$07)|0);
       $145 = (($__i$07) + 8|0);
       if ($146) {
        break;
       }
       $144 = ($145|0)==($1|0);
       if ($144) {
        label = 54;
        break L1;
       } else {
        $__i$07 = $145;
       }
      }
      $147 = $__i$07;
      $148 = $147;
      $149 = HEAP32[$148>>2]|0;
      $150 = (($147) + 4)|0;
      $151 = $150;
      $152 = HEAP32[$151>>2]|0;
      $153 = $1;
      $154 = $153;
      $155 = HEAP32[$154>>2]|0;
      $156 = (($153) + 4)|0;
      $157 = $156;
      $158 = HEAP32[$157>>2]|0;
      $159 = $__i$07;
      $160 = $159;
      HEAP32[$160>>2] = $155;
      $161 = (($159) + 4)|0;
      $162 = $161;
      HEAP32[$162>>2] = $158;
      $163 = $1;
      $164 = $163;
      HEAP32[$164>>2] = $149;
      $165 = (($163) + 4)|0;
      $166 = $165;
      HEAP32[$166>>2] = $152;
      $__i$1 = $145;
     }
     $167 = ($__i$1|0)==($1|0);
     if ($167) {
      label = 54;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $168 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$$0,$__i$2)|0);
       $169 = (($__i$2) + 8|0);
       if ($168) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $169;
       }
      }
      while(1) {
       $170 = (($__j$2) + -8|0);
       $171 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$$0,$170)|0);
       if ($171) {
        $__j$2 = $170;
       } else {
        break;
       }
      }
      $172 = ($__i$2>>>0)<($170>>>0);
      if (!($172)) {
       $$0 = $__i$2;
       continue L3;
      }
      $173 = $__i$2;
      $174 = $173;
      $175 = HEAP32[$174>>2]|0;
      $176 = (($173) + 4)|0;
      $177 = $176;
      $178 = HEAP32[$177>>2]|0;
      $179 = $170;
      $180 = $179;
      $181 = HEAP32[$180>>2]|0;
      $182 = (($179) + 4)|0;
      $183 = $182;
      $184 = HEAP32[$183>>2]|0;
      $185 = $__i$2;
      $186 = $185;
      HEAP32[$186>>2] = $181;
      $187 = (($185) + 4)|0;
      $188 = $187;
      HEAP32[$188>>2] = $184;
      $189 = $170;
      $190 = $189;
      HEAP32[$190>>2] = $175;
      $191 = (($189) + 4)|0;
      $192 = $191;
      HEAP32[$192>>2] = $178;
      $__i$2$ph = $169;$__j$1$ph = $170;
     }
    }
   } while(0);
   $215 = (($$0) + 8|0);
   $216 = ($215>>>0)<($__j$3>>>0);
   L34: do {
    if ($216) {
     $__i$3$ph = $215;$__j$4$ph = $__j$3;$__m$0$ph = $132;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $217 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$__i$3,$__m$0$ph)|0);
       $218 = (($__i$3) + 8|0);
       if ($217) {
        $__i$3 = $218;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $219 = (($__j$5) + -8|0);
       $220 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$219,$__m$0$ph)|0);
       if ($220) {
        break;
       } else {
        $__j$5 = $219;
       }
      }
      $221 = ($__i$3>>>0)>($219>>>0);
      if ($221) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $222 = $__i$3;
      $223 = $222;
      $224 = HEAP32[$223>>2]|0;
      $225 = (($222) + 4)|0;
      $226 = $225;
      $227 = HEAP32[$226>>2]|0;
      $228 = $219;
      $229 = $228;
      $230 = HEAP32[$229>>2]|0;
      $231 = (($228) + 4)|0;
      $232 = $231;
      $233 = HEAP32[$232>>2]|0;
      $234 = $__i$3;
      $235 = $234;
      HEAP32[$235>>2] = $230;
      $236 = (($234) + 4)|0;
      $237 = $236;
      HEAP32[$237>>2] = $233;
      $238 = $219;
      $239 = $238;
      HEAP32[$239>>2] = $224;
      $240 = (($238) + 4)|0;
      $241 = $240;
      HEAP32[$241>>2] = $227;
      $242 = (($__n_swaps$4$ph) + 1)|0;
      $243 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $243 ? $219 : $__m$0$ph;
      $__i$3$ph = $218;$__j$4$ph = $219;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $242;
     }
    } else {
     $__i$4 = $215;$__m$2 = $132;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $244 = ($__i$4|0)==($__m$2|0);
   if ($244) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $245 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$__m$2,$__i$4)|0);
    if ($245) {
     $246 = $__i$4;
     $247 = $246;
     $248 = HEAP32[$247>>2]|0;
     $249 = (($246) + 4)|0;
     $250 = $249;
     $251 = HEAP32[$250>>2]|0;
     $252 = $__m$2;
     $253 = $252;
     $254 = HEAP32[$253>>2]|0;
     $255 = (($252) + 4)|0;
     $256 = $255;
     $257 = HEAP32[$256>>2]|0;
     $258 = $__i$4;
     $259 = $258;
     HEAP32[$259>>2] = $254;
     $260 = (($258) + 4)|0;
     $261 = $260;
     HEAP32[$261>>2] = $257;
     $262 = $__m$2;
     $263 = $262;
     HEAP32[$263>>2] = $248;
     $264 = (($262) + 4)|0;
     $265 = $264;
     HEAP32[$265>>2] = $251;
     $266 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $266;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $267 = ($__n_swaps$6|0)==(0);
   if ($267) {
    $268 = (__ZNSt3__127__insertion_sort_incompleteIRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEbT0_S7_T_($$0,$__i$4,$__comp)|0);
    $269 = (($__i$4) + 8|0);
    $270 = (__ZNSt3__127__insertion_sort_incompleteIRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEbT0_S7_T_($269,$$01$ph,$__comp)|0);
    if ($270) {
     label = 49;
     break;
    }
    if ($268) {
     $$0 = $269;
     continue;
    }
   }
   $271 = $__i$4;
   $272 = (($271) - ($2))|0;
   $273 = (($0) - ($271))|0;
   $274 = ($272|0)<($273|0);
   if (!($274)) {
    label = 53;
    break;
   }
   __ZNSt3__16__sortIRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEvT0_S7_T_($$0,$__i$4,$__comp);
   $275 = (($__i$4) + 8|0);
   $$0 = $275;
  }
  if ((label|0) == 49) {
   label = 0;
   if ($268) {
    label = 54;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 53) {
   label = 0;
   $276 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEvT0_S7_T_($276,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$1,$$0)|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = $$0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $1;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $$0;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $1;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $26 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($$0,$26,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $27 = (($$0) + 8|0);
  $28 = (($$0) + 16|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($$0,$27,$28,$__comp)|0);
  $29 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$1,$28)|0);
  if (!($29)) {
   STACKTOP = sp;return;
  }
  $30 = $28;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 4)|0;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = $1;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $28;
  $43 = $42;
  HEAP32[$43>>2] = $38;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $41;
  $46 = $1;
  $47 = $46;
  HEAP32[$47>>2] = $32;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $35;
  $50 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$28,$27)|0);
  if (!($50)) {
   STACKTOP = sp;return;
  }
  $51 = $27;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $28;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = (($57) + 4)|0;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = $27;
  $64 = $63;
  HEAP32[$64>>2] = $59;
  $65 = (($63) + 4)|0;
  $66 = $65;
  HEAP32[$66>>2] = $62;
  $67 = $28;
  $68 = $67;
  HEAP32[$68>>2] = $53;
  $69 = (($67) + 4)|0;
  $70 = $69;
  HEAP32[$70>>2] = $56;
  $71 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$27,$$0)|0);
  if (!($71)) {
   STACKTOP = sp;return;
  }
  $72 = $$0;
  $73 = $72;
  $74 = HEAP32[$73>>2]|0;
  $75 = (($72) + 4)|0;
  $76 = $75;
  $77 = HEAP32[$76>>2]|0;
  $78 = $$0;
  $79 = $78;
  HEAP32[$79>>2] = $59;
  $80 = (($78) + 4)|0;
  $81 = $80;
  HEAP32[$81>>2] = $62;
  $82 = $27;
  $83 = $82;
  HEAP32[$83>>2] = $74;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $77;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  $86 = (($$0) + 8|0);
  $87 = (($$0) + 16|0);
  $88 = (($$0) + 24|0);
  (__ZNSt3__17__sort5IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_S7_S7_T_($$0,$86,$87,$88,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 13) {
  $90 = (($$0) + 16|0);
  $91 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($$0,$91,$90,$__comp)|0);
  $92 = (($$0) + 24|0);
  $93 = ($92|0)==($$01$ph|0);
  if ($93) {
   STACKTOP = sp;return;
  } else {
   $__i$02$i = $92;$__j$01$i = $90;
  }
  while(1) {
   $94 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$__i$02$i,$__j$01$i)|0);
   if ($94) {
    $95 = $__i$02$i;
    $96 = $95;
    $97 = HEAP32[$96>>2]|0;
    $98 = (($95) + 4)|0;
    $99 = $98;
    $100 = HEAP32[$99>>2]|0;
    $101 = $__t$i;
    $102 = $101;
    HEAP32[$102>>2] = $97;
    $103 = (($101) + 4)|0;
    $104 = $103;
    HEAP32[$104>>2] = $100;
    $__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     $105 = $__k$0$i;
     $106 = $105;
     $107 = HEAP32[$106>>2]|0;
     $108 = (($105) + 4)|0;
     $109 = $108;
     $110 = HEAP32[$109>>2]|0;
     $111 = $__j$1$i;
     $112 = $111;
     HEAP32[$112>>2] = $107;
     $113 = (($111) + 4)|0;
     $114 = $113;
     HEAP32[$114>>2] = $110;
     $115 = ($__k$0$i|0)==($$0|0);
     if ($115) {
      break;
     }
     $116 = (($__k$0$i) + -8|0);
     $117 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$__t$i,$116)|0);
     if ($117) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $116;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $118 = $__t$i;
    $119 = $118;
    $120 = HEAP32[$119>>2]|0;
    $121 = (($118) + 4)|0;
    $122 = $121;
    $123 = HEAP32[$122>>2]|0;
    $124 = $__k$0$i;
    $125 = $124;
    HEAP32[$125>>2] = $120;
    $126 = (($124) + 4)|0;
    $127 = $126;
    HEAP32[$127>>2] = $123;
   }
   $128 = (($__i$02$i) + 8|0);
   $129 = ($128|0)==($$01$ph|0);
   if ($129) {
    break;
   } else {
    $__j$01$i$phi = $__i$02$i;$__i$02$i = $128;$__j$01$i = $__j$01$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 54) {
  STACKTOP = sp;return;
 }
}
function __ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($this,$ra,$rb) {
 $this = $this|0;
 $ra = $ra|0;
 $rb = $rb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$ra>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$rb>>2]|0;
 $6 = ((($4) + (($3*44)|0)|0) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($4) + (($5*44)|0)|0) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if (!($10)) {
  $11 = ($7>>>0)<($9>>>0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ((($4) + (($3*44)|0)|0) + 4|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = ((($4) + (($5*44)|0)|0) + 4|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = ($13<<16>>16)==($15<<16>>16);
 if (!($16)) {
  $17 = ($13<<16>>16)<($15<<16>>16);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($ra) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($rb) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $19 & 16777216;
 $23 = $21 & 16777216;
 $24 = ($22|0)==($23|0);
 if (!($24)) {
  $25 = ($22>>>0)>($23>>>0);
  $$0 = $25;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = ((($4) + (($3*44)|0)|0) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($4) + (($5*44)|0)|0) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27|0)==($29|0);
 if (!($30)) {
  $31 = ($27>>>0)<($29>>>0);
  $$0 = $31;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = ((($4) + (($3*44)|0)|0) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($4) + (($5*44)|0)|0) + 20|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)==($35|0);
 if (!($36)) {
  $37 = ($33|0)>($35|0);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = ((($4) + (($3*44)|0)|0) + 36|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($4) + (($5*44)|0)|0) + 36|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)==($41|0);
 if (!($42)) {
  $43 = (($39) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($41) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($44|0)<($46|0);
  $$0 = $47;
  STACKTOP = sp;return ($$0|0);
 }
 $48 = (($4) + (($3*44)|0)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($4) + (($5*44)|0)|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($49|0)==($51|0);
 if (!($52)) {
  $53 = (($49) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($51) + 4|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($54|0)<($56|0);
  $$0 = $57;
  STACKTOP = sp;return ($$0|0);
 }
 $58 = $19 & 255;
 $59 = $21 & 255;
 $60 = ($58|0)==($59|0);
 if (!($60)) {
  $61 = ($58>>>0)<($59>>>0);
  $$0 = $61;
  STACKTOP = sp;return ($$0|0);
 }
 $62 = ((($4) + (($3*44)|0)|0) + 24|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = ((($4) + (($5*44)|0)|0) + 24|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = $63 != $65;
 if ($66) {
  $67 = $63 > $65;
  $$0 = $67;
  STACKTOP = sp;return ($$0|0);
 }
 $68 = ((($4) + (($3*44)|0)|0) + 16|0);
 $69 = HEAP16[$68>>1]|0;
 $70 = ((($4) + (($5*44)|0)|0) + 16|0);
 $71 = HEAP16[$70>>1]|0;
 $72 = ($69<<16>>16)==($71<<16>>16);
 if ($72) {
  $74 = ($3|0)<($5|0);
  $$0 = $74;
  STACKTOP = sp;return ($$0|0);
 } else {
  $73 = ($69&65535)>($71&65535);
  $$0 = $73;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__y,$__x)|0);
 $1 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__z,$__y)|0);
 if (!($0)) {
  if (!($1)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $2 = $__y;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__z;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__y;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__z;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__y,$__x)|0);
  if (!($22)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $23 = $__x;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $__y;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 4)|0;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = $__x;
  $36 = $35;
  HEAP32[$36>>2] = $31;
  $37 = (($35) + 4)|0;
  $38 = $37;
  HEAP32[$38>>2] = $34;
  $39 = $__y;
  $40 = $39;
  HEAP32[$40>>2] = $25;
  $41 = (($39) + 4)|0;
  $42 = $41;
  HEAP32[$42>>2] = $28;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = $__x;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 if ($1) {
  $49 = $__z;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $__x;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = $__z;
  $60 = $59;
  HEAP32[$60>>2] = $45;
  $61 = (($59) + 4)|0;
  $62 = $61;
  HEAP32[$62>>2] = $48;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = $__y;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $__x;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $__y;
 $74 = $73;
 HEAP32[$74>>2] = $45;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $48;
 $77 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__z,$__y)|0);
 if (!($77)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = $__z;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__y;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__z;
 $89 = $88;
 HEAP32[$89>>2] = $45;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $48;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort5IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__r$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__x4,$__x3)|0);
 if ($1) {
  $2 = $__x3;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__x4;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__x3;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__x4;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (($0) + 1)|0;
  $23 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__x3,$__x2)|0);
  if ($23) {
   $24 = $__x2;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 4)|0;
   $28 = $27;
   $29 = HEAP32[$28>>2]|0;
   $30 = $__x3;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $__x2;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
   $40 = $__x3;
   $41 = $40;
   HEAP32[$41>>2] = $26;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $29;
   $44 = (($0) + 2)|0;
   $45 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__x2,$__x1)|0);
   if ($45) {
    $46 = $__x1;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4)|0;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = $__x2;
    $53 = $52;
    $54 = HEAP32[$53>>2]|0;
    $55 = (($52) + 4)|0;
    $56 = $55;
    $57 = HEAP32[$56>>2]|0;
    $58 = $__x1;
    $59 = $58;
    HEAP32[$59>>2] = $54;
    $60 = (($58) + 4)|0;
    $61 = $60;
    HEAP32[$61>>2] = $57;
    $62 = $__x2;
    $63 = $62;
    HEAP32[$63>>2] = $48;
    $64 = (($62) + 4)|0;
    $65 = $64;
    HEAP32[$65>>2] = $51;
    $66 = (($0) + 3)|0;
    $__r$0$i = $66;
   } else {
    $__r$0$i = $44;
   }
  } else {
   $__r$0$i = $22;
  }
 } else {
  $__r$0$i = $0;
 }
 $67 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__x5,$__x4)|0);
 if (!($67)) {
  $__r$0 = $__r$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $68 = $__x4;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = $__x5;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = (($74) + 4)|0;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = $__x4;
 $81 = $80;
 HEAP32[$81>>2] = $76;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $79;
 $84 = $__x5;
 $85 = $84;
 HEAP32[$85>>2] = $70;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $73;
 $88 = (($__r$0$i) + 1)|0;
 $89 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__x4,$__x3)|0);
 if (!($89)) {
  $__r$0 = $88;
  STACKTOP = sp;return ($__r$0|0);
 }
 $90 = $__x3;
 $91 = $90;
 $92 = HEAP32[$91>>2]|0;
 $93 = (($90) + 4)|0;
 $94 = $93;
 $95 = HEAP32[$94>>2]|0;
 $96 = $__x4;
 $97 = $96;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($96) + 4)|0;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = $__x3;
 $103 = $102;
 HEAP32[$103>>2] = $98;
 $104 = (($102) + 4)|0;
 $105 = $104;
 HEAP32[$105>>2] = $101;
 $106 = $__x4;
 $107 = $106;
 HEAP32[$107>>2] = $92;
 $108 = (($106) + 4)|0;
 $109 = $108;
 HEAP32[$109>>2] = $95;
 $110 = (($__r$0$i) + 2)|0;
 $111 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__x3,$__x2)|0);
 if (!($111)) {
  $__r$0 = $110;
  STACKTOP = sp;return ($__r$0|0);
 }
 $112 = $__x2;
 $113 = $112;
 $114 = HEAP32[$113>>2]|0;
 $115 = (($112) + 4)|0;
 $116 = $115;
 $117 = HEAP32[$116>>2]|0;
 $118 = $__x3;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = (($118) + 4)|0;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = $__x2;
 $125 = $124;
 HEAP32[$125>>2] = $120;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $123;
 $128 = $__x3;
 $129 = $128;
 HEAP32[$129>>2] = $114;
 $130 = (($128) + 4)|0;
 $131 = $130;
 HEAP32[$131>>2] = $117;
 $132 = (($__r$0$i) + 3)|0;
 $133 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__c,$__x2,$__x1)|0);
 if (!($133)) {
  $__r$0 = $132;
  STACKTOP = sp;return ($__r$0|0);
 }
 $134 = $__x1;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = (($134) + 4)|0;
 $138 = $137;
 $139 = HEAP32[$138>>2]|0;
 $140 = $__x2;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $__x1;
 $147 = $146;
 HEAP32[$147>>2] = $142;
 $148 = (($146) + 4)|0;
 $149 = $148;
 HEAP32[$149>>2] = $145;
 $150 = $__x2;
 $151 = $150;
 HEAP32[$151>>2] = $136;
 $152 = (($150) + 4)|0;
 $153 = $152;
 HEAP32[$153>>2] = $139;
 $154 = (($__r$0$i) + 4)|0;
 $__r$0 = $154;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0;
 var $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 5:  {
  $88 = (($__first) + 8|0);
  $89 = (($__first) + 16|0);
  $90 = (($__first) + 24|0);
  $91 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_S7_S7_T_($__first,$88,$89,$90,$91,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $28 = (($__first) + 8|0);
  $29 = (($__first) + 16|0);
  $30 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($__first,$28,$29,$__comp)|0);
  $31 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$30,$29)|0);
  if (!($31)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $32 = $29;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $30;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 4)|0;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = $29;
  $45 = $44;
  HEAP32[$45>>2] = $40;
  $46 = (($44) + 4)|0;
  $47 = $46;
  HEAP32[$47>>2] = $43;
  $48 = $30;
  $49 = $48;
  HEAP32[$49>>2] = $34;
  $50 = (($48) + 4)|0;
  $51 = $50;
  HEAP32[$51>>2] = $37;
  $52 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$29,$28)|0);
  if (!($52)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $53 = $28;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($53) + 4)|0;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = $29;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) + 4)|0;
  $63 = $62;
  $64 = HEAP32[$63>>2]|0;
  $65 = $28;
  $66 = $65;
  HEAP32[$66>>2] = $61;
  $67 = (($65) + 4)|0;
  $68 = $67;
  HEAP32[$68>>2] = $64;
  $69 = $29;
  $70 = $69;
  HEAP32[$70>>2] = $55;
  $71 = (($69) + 4)|0;
  $72 = $71;
  HEAP32[$72>>2] = $58;
  $73 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$28,$__first)|0);
  if (!($73)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $74 = $__first;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + 4)|0;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = $__first;
  $81 = $80;
  HEAP32[$81>>2] = $61;
  $82 = (($80) + 4)|0;
  $83 = $82;
  HEAP32[$83>>2] = $64;
  $84 = $28;
  $85 = $84;
  HEAP32[$85>>2] = $76;
  $86 = (($84) + 4)|0;
  $87 = $86;
  HEAP32[$87>>2] = $79;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -8|0);
  $5 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$4,$__first)|0);
  if (!($5)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $6 = $__first;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $4;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $__first;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $4;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $26 = (($__first) + 8|0);
  $27 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($__first,$26,$27,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $92 = (($__first) + 16|0);
  $93 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardShaderRenderLoop18RenderObjectSorterILb1EEEP14RenderPassDataEEjT0_S7_S7_T_($__first,$93,$92,$__comp)|0);
  $94 = (($__first) + 24|0);
  $95 = ($94|0)==($__last|0);
  if ($95) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $94;$__j$02 = $92;
  }
  while(1) {
   $96 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$__i$04,$__j$02)|0);
   if ($96) {
    $97 = $__i$04;
    $98 = $97;
    $99 = HEAP32[$98>>2]|0;
    $100 = (($97) + 4)|0;
    $101 = $100;
    $102 = HEAP32[$101>>2]|0;
    $103 = $__t;
    $104 = $103;
    HEAP32[$104>>2] = $99;
    $105 = (($103) + 4)|0;
    $106 = $105;
    HEAP32[$106>>2] = $102;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $107 = $__k$0;
     $108 = $107;
     $109 = HEAP32[$108>>2]|0;
     $110 = (($107) + 4)|0;
     $111 = $110;
     $112 = HEAP32[$111>>2]|0;
     $113 = $__j$1;
     $114 = $113;
     HEAP32[$114>>2] = $109;
     $115 = (($113) + 4)|0;
     $116 = $115;
     HEAP32[$116>>2] = $112;
     $117 = ($__k$0|0)==($__first|0);
     if ($117) {
      break;
     }
     $118 = (($__k$0) + -8|0);
     $119 = (__ZNK23ForwardShaderRenderLoop18RenderObjectSorterILb1EEclERK14RenderPassDataS4_($__comp,$__t,$118)|0);
     if ($119) {
      $__j$1$phi = $__k$0;$__k$0 = $118;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $120 = $__t;
    $121 = $120;
    $122 = HEAP32[$121>>2]|0;
    $123 = (($120) + 4)|0;
    $124 = $123;
    $125 = HEAP32[$124>>2]|0;
    $126 = $__k$0;
    $127 = $126;
    HEAP32[$127>>2] = $122;
    $128 = (($126) + 4)|0;
    $129 = $128;
    HEAP32[$129>>2] = $125;
    $130 = (($__count$03) + 1)|0;
    $131 = ($130|0)==(8);
    if ($131) {
     break;
    } else {
     $__count$1 = $130;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $134 = (($__i$04) + 8|0);
   $135 = ($134|0)==($__last|0);
   if ($135) {
    $$0 = 1;
    label = 18;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $134;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 18) {
   STACKTOP = sp;return ($$0|0);
  }
  $132 = (($__i$04) + 8|0);
  $133 = ($132|0)==($__last|0);
  $$0 = $133;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN23ForwardShaderRenderLoopD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = (($this) + 164|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 do {
  if ($8) {
   $9 = (($this) + 152|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 156|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$5>>2] = $12;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($10|0),($$byval_copy6|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$9>>2] = 0;
    label = 4;
    break;
   }
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $42 = (($this) + 52|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)>(-1);
   if ($44) {
    $45 = (($this) + 40|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($this) + 44|0);
    $48 = HEAP32[$47>>2]|0;
    HEAP32[$2>>2] = $48;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($46|0),($$byval_copy6|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     $73 = ___cxa_find_matching_catch(0|0)|0;
     $74 = tempRet0;
     ___clang_call_terminate($73);
     // unreachable;
    } else {
     HEAP32[$45>>2] = 0;
     $$0 = $41;$$01 = $40;
     label = 18;
     break;
    }
   } else {
    $$0 = $41;$$01 = $40;
    label = 18;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $15 = (($this) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(-1);
   do {
    if ($17) {
     $18 = (($this) + 40|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($this) + 44|0);
     $21 = HEAP32[$20>>2]|0;
     HEAP32[$4>>2] = $21;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($19|0),($$byval_copy6|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $51 = ___cxa_find_matching_catch()|0;
      $52 = tempRet0;
      $$0 = $52;$$01 = $51;
      label = 18;
      break L10;
     } else {
      HEAP32[$18>>2] = 0;
      break;
     }
    }
   } while(0);
   $24 = (($this) + 36|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(-1);
   do {
    if ($26) {
     $27 = (($this) + 24|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($this) + 28|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$3>>2] = $30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($28|0),($$byval_copy6|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $53 = ___cxa_find_matching_catch()|0;
      $54 = tempRet0;
      $$1 = $54;$$12 = $53;
      break L10;
     } else {
      HEAP32[$27>>2] = 0;
      break;
     }
    }
   } while(0);
   $33 = (($this) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)>(-1);
   if (!($35)) {
    STACKTOP = sp;return;
   }
   $36 = (($this) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($this) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$0>>2] = $39;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy6);
   HEAP32[$36>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 18) {
   $55 = (($this) + 36|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)>(-1);
   if ($57) {
    $58 = (($this) + 24|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($this) + 28|0);
    $61 = HEAP32[$60>>2]|0;
    HEAP32[$1>>2] = $61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($59|0),($$byval_copy6|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $73 = ___cxa_find_matching_catch(0|0)|0;
     $74 = tempRet0;
     ___clang_call_terminate($73);
     // unreachable;
    } else {
     HEAP32[$58>>2] = 0;
     $$1 = $$0;$$12 = $$01;
     break;
    }
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 $64 = (($this) + 20|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)>(-1);
 if (!($66)) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $67 = (($this) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($this) + 12|0);
 $70 = HEAP32[$69>>2]|0;
 HEAP32[$0>>2] = $70;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($68|0),($$byval_copy6|0));
 $71 = __THREW__; __THREW__ = 0;
 $72 = $71&1;
 if ($72) {
  $73 = ___cxa_find_matching_catch(0|0)|0;
  $74 = tempRet0;
  ___clang_call_terminate($73);
  // unreachable;
 }
 HEAP32[$67>>2] = 0;
 ___resumeException($$12|0);
 // unreachable;
}
function __ZNK24ForwardShaderRenderStateeqERKS_($this,$rhs) {
 $this = $this|0;
 $rhs = $rhs|0;
 var $$0 = 0, $$sink$i$i$i = Math_fround(0), $$sink$i1$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $i$02$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==($rhs|0);
 if ($0) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$this>>2]|0;
 $2 = HEAP32[$rhs>>2]|0;
 $3 = ($1|0)==($2|0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($rhs) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 if (!($8)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($rhs) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 if (!($13)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($this) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($rhs) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = $15 > Math_fround(0.0);
 $19 = $18&1;
 $20 = $15 < Math_fround(0.0);
 $21 = $20&1;
 $22 = (($19) - ($21))|0;
 $23 = $17 > Math_fround(0.0);
 $24 = $23&1;
 $25 = $17 < Math_fround(0.0);
 $26 = $25&1;
 $27 = (($24) - ($26))|0;
 $28 = ($22|0)==($27|0);
 if (!($28)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = ($22|0)<(0);
 if ($29) {
  $30 = Math_fround($15 - $17);
  $31 = $30 < Math_fround(0.0);
  if ($31) {
   $32 = Math_fround(-$30);
   $34 = $32;
  } else {
   $34 = $30;
  }
  $33 = !($34 <= Math_fround(9.99999997475242707878E-7));
  if ($33) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $35 = Math_fround($15 * Math_fround(16.0));
  $36 = !($35 >= Math_fround(0.0));
  if ($36) {
   $37 = Math_fround($35 + Math_fround(-0.999999940395355224609));
   $$sink$i1$i$i = $37;
  } else {
   $$sink$i1$i$i = $35;
  }
  $38 = (~~(($$sink$i1$i$i)));
  $39 = Math_fround($17 * Math_fround(16.0));
  $40 = !($39 >= Math_fround(0.0));
  if ($40) {
   $41 = Math_fround($39 + Math_fround(-0.999999940395355224609));
   $$sink$i$i$i = $41;
  } else {
   $$sink$i$i$i = $39;
  }
  $42 = (~~(($$sink$i$i$i)));
  $43 = ($38|0)==($42|0);
  if (!($43)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $44 = (($this) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($rhs) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($45|0)==($47|0);
 if (!($48)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = (($this) + 16|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($rhs) + 16|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($50|0)==($52|0);
 if (!($53)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $54 = (($this) + 32|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($rhs) + 32|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($55|0)==(0|0);
 $59 = ($57|0)==(0|0);
 $or$cond$i = $58 | $59;
 if ($or$cond$i) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $60 = (($55) + 108|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($57) + 108|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($61|0)==($63|0);
 if (!($64)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $65 = (($55) + 116|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($57) + 116|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($66|0)==($68|0);
 if (!($69)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $70 = (($55) + 112|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($57) + 112|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($71|0)==($73|0);
 if (!($74)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $75 = (($71) + ($66))|0;
 $76 = (($55) + 128|0);
 $77 = (($57) + 128|0);
 $78 = ($75|0)>(0);
 L49: do {
  if ($78) {
   $i$02$i = 0;
   while(1) {
    $81 = (($76) + ($i$02$i<<2)|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($77) + ($i$02$i<<2)|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    $80 = (($i$02$i) + 1)|0;
    if (!($85)) {
     $$0 = 0;
     break;
    }
    $79 = ($80|0)<($75|0);
    if ($79) {
     $i$02$i = $80;
    } else {
     break L49;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $86 = (($55) + 120|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($57) + 120|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($87 - $89);
 $91 = $90 < Math_fround(0.0);
 if ($91) {
  $92 = Math_fround(-$90);
  $94 = $92;
 } else {
  $94 = $90;
 }
 $93 = !($94 <= Math_fround(9.99999997475242707878E-7));
 if ($93) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $95 = (($55) + 124|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($57) + 124|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($96 - $98);
 $100 = $99 < Math_fround(0.0);
 if ($100) {
  $101 = Math_fround(-$99);
  $103 = $101;
 } else {
  $103 = $99;
 }
 $102 = !($103 <= Math_fround(9.99999997475242707878E-7));
 if ($102) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $104 = (($this) + 24|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($rhs) + 24|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = ($105|0)==($107|0);
 if (!($108)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $109 = (($this) + 28|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = (($rhs) + 28|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ($110|0)==($112|0);
 if (!($113)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $114 = (($this) + 36|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (($rhs) + 36|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ($115|0)==($117|0);
 $$0 = $118;
 STACKTOP = sp;return ($$0|0);
}
function __GLOBAL__I_a1638() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568168);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[568160>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN23ForwardVertexRenderLoop16PerformRenderingEbbb($this,$sSRGBRenderTarget,$clearFrameBuffer,$opaque) {
 $this = $this|0;
 $sSRGBRenderTarget = $sSRGBRenderTarget|0;
 $clearFrameBuffer = $clearFrameBuffer|0;
 $opaque = $opaque|0;
 var $$ = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i12 = 0, $$0$i$i$i$i4 = 0, $$0$i$i$i16 = 0, $$0$i$i$i8 = 0, $$01$i$i$i = 0, $$01$i$i$i14 = 0, $$01$i$i$i6 = 0, $$lcssa22 = 0, $$lcssa37 = 0, $$pre$pre = 0, $$pre57 = 0, $$sink$i$i$i = Math_fround(0), $$sink$i1$i$i = Math_fround(0), $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $batchRenderer = 0, $brmerge = 0, $channels$041 = 0, $channels$1 = 0, $currentMaxQueue$042 = 0, $currentMaxQueue$1 = 0, $i$02$i$i$i = 0, $i$040 = 0;
 var $lightmapSTCache = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, $or$cond = 0, $or$cond$i$i$i = 0, $resetPass$0$off0 = 0, $rs = 0, $stats = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $stats = sp + 120|0;
 $batchRenderer = sp;
 $lightmapSTCache = sp + 76|0;
 $rs = sp + 88|0;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (__Z17GetRenderSettingsv()|0);
 $2 = HEAP32[652824>>2]|0;
 $3 = (__Z16GetRenderManagerv()|0);
 $4 = (($3) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 92|0);
 $7 = (__Z19GetLightmapSettingsv()|0);
 $8 = (($this) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 108|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$0>>2]|0;
 $14 = (($13) + 100|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($10) + 12|0);
 FUNCTION_TABLE_vii[$15 & 4095]($0,$16);
 $17 = HEAP32[$0>>2]|0;
 $18 = (($17) + 72|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vii[$19 & 4095]($0,$sSRGBRenderTarget);
 if ($clearFrameBuffer) {
  $20 = HEAP32[$this>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  __ZN6Camera13ClearNoSkyboxEb($21,0);
 }
 __ZNK14RenderSettings12SetupAmbientEv($1);
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = $opaque ? 10 : 16;
 $25 = (($23) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($25,$24,$2);
 __ZN13BatchRendererC2ER15RenderLoopStats($batchRenderer,$stats);
 __THREW__ = 0;
 invoke_viii(1661,($lightmapSTCache|0),($batchRenderer|0),($stats|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 L4: do {
  if ($27) {
   label = 20;
  } else {
   $28 = ($9|0)==(0);
   L6: do {
    if ($28) {
     $$lcssa37 = $5;
    } else {
     $29 = (($this) + 40|0);
     $30 = (($this) + 4|0);
     $31 = (($this) + 8|0);
     $32 = (($this) + 24|0);
     $33 = (($rs) + 8|0);
     $34 = (($rs) + 4|0);
     $35 = (($rs) + 20|0);
     $36 = (($rs) + 16|0);
     $37 = (($rs) + 12|0);
     $38 = (($rs) + 24|0);
     $39 = (($rs) + 28|0);
     $40 = (($rs) + 12|0);
     $135 = 0;$138 = 0;$141 = -1;$149 = Math_fround(-1.0);$172 = 16711935;$175 = -1;$179 = 0;$62 = $5;$channels$041 = 0;$currentMaxQueue$042 = $12;$i$040 = 0;
     L8: while(1) {
      $41 = HEAP32[$29>>2]|0;
      $42 = HEAP32[$30>>2]|0;
      $43 = (($41) + ($i$040<<3)|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = HEAP32[$42>>2]|0;
      $46 = HEAP32[$31>>2]|0;
      $47 = (($46) + ($44<<2)|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = HEAP32[$32>>2]|0;
      $50 = (($49) + ($48)|0);
      $51 = ((($45) + (($44*44)|0)|0) + 4|0);
      $52 = HEAP16[$51>>1]|0;
      $53 = $52 << 16 >> 16;
      $54 = ($53|0)>($currentMaxQueue$042|0);
      L10: do {
       if ($54) {
        __THREW__ = 0;
        invoke_vi(3398,($batchRenderer|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 19;
         break L8;
        }
        $57 = HEAP32[$this>>2]|0;
        $58 = (($57) + 105|0);
        $59 = HEAP8[$58>>0]|0;
        $60 = ($59<<24>>24)==(0);
        if ($60) {
         $61 = ($62|0)==($6|0);
         if ($61) {
          $307 = $6;$currentMaxQueue$1 = $53;
         } else {
          $64 = $62;
          while(1) {
           $63 = (($64) + 16|0);
           $65 = HEAP32[$63>>2]|0;
           $66 = ($65|0)>($53|0);
           if ($66) {
            $307 = $64;$currentMaxQueue$1 = $53;
            break L10;
           }
           $67 = (($64) + 20|0);
           $68 = HEAP32[$67>>2]|0;
           $69 = HEAP32[$68>>2]|0;
           $70 = HEAP32[$69>>2]|0;
           $71 = HEAP32[$this>>2]|0;
           $72 = (($71) + 4|0);
           $73 = HEAP32[$72>>2]|0;
           __THREW__ = 0;
           invoke_viii($70|0,($68|0),($73|0),($2|0));
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if ($75) {
            label = 18;
            break L8;
           }
           $76 = (($64) + 4|0);
           $77 = HEAP32[$76>>2]|0;
           $78 = ($77|0)==(0|0);
           if ($78) {
            $$01$i$i$i14 = $64;
            while(1) {
             $81 = (($$01$i$i$i14) + 8|0);
             $82 = HEAP32[$81>>2]|0;
             $83 = HEAP32[$82>>2]|0;
             $84 = ($83|0)==($$01$i$i$i14|0);
             if ($84) {
              $$0$i$i$i16 = $82;
              break;
             } else {
              $$01$i$i$i14 = $82;
             }
            }
           } else {
            $$0$i$i$i$i12 = $77;
            while(1) {
             $79 = HEAP32[$$0$i$i$i$i12>>2]|0;
             $80 = ($79|0)==(0|0);
             if ($80) {
              $$0$i$i$i16 = $$0$i$i$i$i12;
              break;
             } else {
              $$0$i$i$i$i12 = $79;
             }
            }
           }
           $85 = ($$0$i$i$i16|0)==($6|0);
           if ($85) {
            $307 = $$0$i$i$i16;$currentMaxQueue$1 = $53;
            break;
           } else {
            $64 = $$0$i$i$i16;
           }
          }
         }
        } else {
         $307 = $62;$currentMaxQueue$1 = $53;
        }
       } else {
        $307 = $62;$currentMaxQueue$1 = $currentMaxQueue$042;
       }
      } while(0);
      $96 = ((($45) + (($44*44)|0)|0) + 32|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = ((($45) + (($44*44)|0)|0) + 6|0);
      $99 = HEAP16[$98>>1]|0;
      $100 = (($97) + 120|0);
      $101 = Math_fround(HEAPF32[$100>>2]);
      HEAPF32[$33>>2] = $101;
      $102 = (($45) + (($44*44)|0)|0);
      $103 = HEAP32[$102>>2]|0;
      HEAP32[$rs>>2] = $103;
      $104 = ((($45) + (($44*44)|0)|0) + 36|0);
      $105 = HEAP32[$104>>2]|0;
      HEAP32[$34>>2] = $105;
      $106 = ((($45) + (($44*44)|0)|0) + 8|0);
      $107 = HEAP16[$106>>1]|0;
      $108 = $107 << 16 >> 16;
      HEAP32[$35>>2] = $108;
      $109 = (($97) + 116|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = (($110) + 168|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = ($112|0)==(0|0);
      if ($113) {
       $116 = 0;
      } else {
       $114 = (($112) + 32|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = $115;
      }
      HEAP32[$36>>2] = $116;
      $117 = ((($45) + (($44*44)|0)|0) + 12|0);
      $118 = HEAP32[$117>>2]|0;
      HEAP32[$37>>2] = $118;
      $119 = ((($41) + ($i$040<<3)|0) + 4|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = $120 & 255;
      HEAP32[$38>>2] = $121;
      HEAP32[$39>>2] = $50;
      $122 = HEAP32[$119>>2]|0;
      $123 = HEAP32[$109>>2]|0;
      $124 = HEAP32[$123>>2]|0;
      $125 = (($124) + 52|0);
      $126 = HEAP32[$125>>2]|0;
      __THREW__ = 0;
      $127 = (invoke_ii($126|0,($123|0))|0);
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if ($129) {
       label = 19;
       break;
      }
      $130 = $122 & 131072;
      $131 = ($130|0)!=(0);
      $132 = ($127|0)==(0);
      $$ = $132 & $131;
      $133 = HEAP32[$rs>>2]|0;
      $134 = ($133|0)==($135|0);
      L30: do {
       if ($134) {
        $136 = HEAP32[$34>>2]|0;
        $137 = ($136|0)==($138|0);
        if ($137) {
         $139 = HEAP32[$35>>2]|0;
         $140 = ($139|0)==($141|0);
         if ($140) {
          $142 = Math_fround(HEAPF32[$33>>2]);
          $143 = $142 > Math_fround(0.0);
          $144 = $143&1;
          $145 = $142 < Math_fround(0.0);
          $146 = $145&1;
          $147 = (($144) - ($146))|0;
          $148 = $149 > Math_fround(0.0);
          $150 = $148&1;
          $151 = $149 < Math_fround(0.0);
          $152 = $151&1;
          $153 = (($150) - ($152))|0;
          $154 = ($147|0)==($153|0);
          if ($154) {
           $155 = ($147|0)<(0);
           if ($155) {
            $156 = Math_fround($142 - $149);
            $157 = $156 < Math_fround(0.0);
            if ($157) {
             $158 = Math_fround(-$156);
             $160 = $158;
            } else {
             $160 = $156;
            }
            $159 = !($160 <= Math_fround(9.99999997475242707878E-7));
            if ($159) {
             label = 45;
             break;
            }
           } else {
            $161 = Math_fround($142 * Math_fround(16.0));
            $162 = !($161 >= Math_fround(0.0));
            if ($162) {
             $163 = Math_fround($161 + Math_fround(-0.999999940395355224609));
             $$sink$i1$i$i = $163;
            } else {
             $$sink$i1$i$i = $161;
            }
            $164 = (~~(($$sink$i1$i$i)));
            $165 = Math_fround($149 * Math_fround(16.0));
            $166 = !($165 >= Math_fround(0.0));
            if ($166) {
             $167 = Math_fround($165 + Math_fround(-0.999999940395355224609));
             $$sink$i$i$i = $167;
            } else {
             $$sink$i$i$i = $165;
            }
            $168 = (~~(($$sink$i$i$i)));
            $169 = ($164|0)==($168|0);
            if (!($169)) {
             label = 45;
             break;
            }
           }
           $170 = HEAP32[$37>>2]|0;
           $171 = ($170|0)==($172|0);
           if ($171) {
            $173 = HEAP32[$36>>2]|0;
            $174 = ($173|0)==($175|0);
            if ($174) {
             $176 = HEAP32[$39>>2]|0;
             $177 = ($176|0)==(0|0);
             $178 = ($179|0)==(0|0);
             $or$cond$i$i$i = $177 | $178;
             if ($or$cond$i$i$i) {
              label = 45;
             } else {
              $180 = HEAP32[$176>>2]|0;
              $181 = HEAP32[$179>>2]|0;
              $182 = ($180|0)==($181|0);
              if ($182) {
               $183 = ($180|0)>(0);
               if ($183) {
                $i$02$i$i$i = 0;
                while(1) {
                 $$sum$i$i$i = (($i$02$i$i$i) + 1)|0;
                 $185 = (($176) + ($$sum$i$i$i<<2)|0);
                 $186 = HEAP32[$185>>2]|0;
                 $187 = (($179) + ($$sum$i$i$i<<2)|0);
                 $188 = HEAP32[$187>>2]|0;
                 $189 = ($186|0)==($188|0);
                 if (!($189)) {
                  label = 45;
                  break L30;
                 }
                 $184 = ($$sum$i$i$i|0)<($180|0);
                 if ($184) {
                  $i$02$i$i$i = $$sum$i$i$i;
                 } else {
                  break;
                 }
                }
               }
               __THREW__ = 0;
               $201 = (invoke_iif(27,($138|0),(+$142))|0);
               $202 = __THREW__; __THREW__ = 0;
               $203 = $202&1;
               if ($203) {
                label = 19;
                break L8;
               }
               $brmerge = $201 | $$;
               if (!($brmerge)) {
                $308 = $179;$309 = $141;$310 = $175;$311 = $172;$312 = $149;$313 = $138;$314 = $135;$resetPass$0$off0 = 0;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3398,($batchRenderer|0));
               $204 = __THREW__; __THREW__ = 0;
               $205 = $204&1;
               if ($205) {
                label = 19;
                break L8;
               } else {
                $308 = $179;$309 = $141;$310 = $175;$311 = $172;$312 = $149;$313 = $138;$314 = $135;$resetPass$0$off0 = 0;
               }
              } else {
               label = 45;
              }
             }
            } else {
             label = 45;
            }
           } else {
            label = 45;
           }
          } else {
           label = 45;
          }
         } else {
          label = 45;
         }
        } else {
         label = 45;
        }
       } else {
        label = 45;
       }
      } while(0);
      if ((label|0) == 45) {
       label = 0;
       __THREW__ = 0;
       invoke_vi(3398,($batchRenderer|0));
       $190 = __THREW__; __THREW__ = 0;
       $191 = $190&1;
       if ($191) {
        label = 19;
        break;
       }
       $192 = HEAP32[$rs>>2]|0;
       $193 = HEAP32[$34>>2]|0;
       $194 = Math_fround(HEAPF32[$33>>2]);
       $195 = HEAP32[$37>>2]|0;
       $196 = HEAP32[$36>>2]|0;
       $197 = HEAP32[$35>>2]|0;
       $198 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       invoke_viif(41,($0|0),($2|0),(+$194));
       $199 = __THREW__; __THREW__ = 0;
       $200 = $199&1;
       if ($200) {
        label = 19;
        break;
       } else {
        $308 = $198;$309 = $197;$310 = $196;$311 = $195;$312 = $194;$313 = $193;$314 = $192;$resetPass$0$off0 = 1;
       }
      }
      $206 = HEAP32[$0>>2]|0;
      $207 = (($206) + 96|0);
      $208 = HEAP32[$207>>2]|0;
      __THREW__ = 0;
      invoke_vii($208|0,($0|0),(616552|0));
      $209 = __THREW__; __THREW__ = 0;
      $210 = $209&1;
      if ($210) {
       label = 19;
       break;
      }
      $211 = HEAP32[$109>>2]|0;
      __THREW__ = 0;
      invoke_vii(2612,($lightmapSTCache|0),($211|0));
      $212 = __THREW__; __THREW__ = 0;
      $213 = $212&1;
      if ($213) {
       label = 19;
       break;
      }
      $214 = HEAP32[$109>>2]|0;
      __THREW__ = 0;
      invoke_viii(1664,($lightmapSTCache|0),($214|0),($0|0));
      $215 = __THREW__; __THREW__ = 0;
      $216 = $215&1;
      if ($216) {
       label = 19;
       break;
      }
      if ($resetPass$0$off0) {
       __THREW__ = 0;
       invoke_vii(2615,($7|0),($40|0));
       $217 = __THREW__; __THREW__ = 0;
       $218 = $217&1;
       if ($218) {
        label = 19;
        break;
       }
       $219 = HEAP32[$39>>2]|0;
       $220 = HEAP32[$219>>2]|0;
       $221 = (($219) + 4|0);
       __THREW__ = 0;
       invoke_vii(2616,($220|0),($221|0));
       $222 = __THREW__; __THREW__ = 0;
       $223 = $222&1;
       if ($223) {
        label = 19;
        break;
       }
       $224 = HEAP32[$rs>>2]|0;
       $225 = HEAP32[$38>>2]|0;
       $226 = HEAP32[$34>>2]|0;
       $227 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       $228 = (invoke_iiiiii(193,($224|0),($225|0),($226|0),($2|0),($227|0))|0);
       $229 = __THREW__; __THREW__ = 0;
       $230 = $229&1;
       if ($230) {
        label = 19;
        break;
       } else {
        $channels$1 = $228;
       }
      } else {
       $channels$1 = $channels$041;
      }
      $231 = ($channels$1|0)==(0|0);
      if (!($231)) {
       $232 = HEAP32[$109>>2]|0;
       $233 = $99&65535;
       __THREW__ = 0;
       invoke_viiiii(90,($batchRenderer|0),($232|0),($97|0),($233|0),($channels$1|0));
       $234 = __THREW__; __THREW__ = 0;
       $235 = $234&1;
       if ($235) {
        label = 19;
        break;
       }
      }
      $236 = (($i$040) + 1)|0;
      $237 = ($236>>>0)<($9>>>0);
      if ($237) {
       $135 = $314;$138 = $313;$141 = $309;$149 = $312;$172 = $311;$175 = $310;$179 = $308;$62 = $307;$channels$041 = $channels$1;$currentMaxQueue$042 = $currentMaxQueue$1;$i$040 = $236;
      } else {
       $$lcssa37 = $307;
       break L6;
      }
     }
     if ((label|0) == 18) {
      $88 = ___cxa_find_matching_catch()|0;
      $89 = tempRet0;
      $lpad$phi$index = $88;$lpad$phi$index4 = $89;
      break L4;
     }
     else if ((label|0) == 19) {
      $90 = ___cxa_find_matching_catch()|0;
      $91 = tempRet0;
      $lpad$phi$index = $90;$lpad$phi$index4 = $91;
      break L4;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3398,($batchRenderer|0));
   $238 = __THREW__; __THREW__ = 0;
   $239 = $238&1;
   if ($239) {
    label = 20;
   } else {
    $240 = HEAP32[$0>>2]|0;
    $241 = (($240) + 72|0);
    $242 = HEAP32[$241>>2]|0;
    __THREW__ = 0;
    invoke_vii($242|0,($0|0),0);
    $243 = __THREW__; __THREW__ = 0;
    $244 = $243&1;
    if ($244) {
     label = 20;
    } else {
     $245 = HEAP32[$0>>2]|0;
     $246 = (($245) + 100|0);
     $247 = HEAP32[$246>>2]|0;
     $248 = HEAP32[$this>>2]|0;
     $249 = (($248) + 12|0);
     __THREW__ = 0;
     invoke_vii($247|0,($0|0),($249|0));
     $250 = __THREW__; __THREW__ = 0;
     $251 = $250&1;
     if ($251) {
      label = 20;
     } else {
      $252 = HEAP32[$this>>2]|0;
      $253 = (($252) + 105|0);
      $254 = HEAP8[$253>>0]|0;
      $255 = ($254<<24>>24)!=(0);
      $256 = ($$lcssa37|0)==($6|0);
      $or$cond = $255 | $256;
      L81: do {
       if ($or$cond) {
        $300 = $252;
       } else {
        $257 = (($252) + 108|0);
        $258 = HEAP32[$257>>2]|0;
        $261 = $$lcssa37;
        while(1) {
         $260 = (($261) + 16|0);
         $262 = HEAP32[$260>>2]|0;
         $263 = ($262|0)<($258|0);
         if (!($263)) {
          $$lcssa22 = $261;
          break;
         }
         $264 = (($261) + 4|0);
         $265 = HEAP32[$264>>2]|0;
         $266 = ($265|0)==(0|0);
         if ($266) {
          $$01$i$i$i6 = $261;
          while(1) {
           $269 = (($$01$i$i$i6) + 8|0);
           $270 = HEAP32[$269>>2]|0;
           $271 = HEAP32[$270>>2]|0;
           $272 = ($271|0)==($$01$i$i$i6|0);
           if ($272) {
            $$0$i$i$i8 = $270;
            break;
           } else {
            $$01$i$i$i6 = $270;
           }
          }
         } else {
          $$0$i$i$i$i4 = $265;
          while(1) {
           $267 = HEAP32[$$0$i$i$i$i4>>2]|0;
           $268 = ($267|0)==(0|0);
           if ($268) {
            $$0$i$i$i8 = $$0$i$i$i$i4;
            break;
           } else {
            $$0$i$i$i$i4 = $267;
           }
          }
         }
         $273 = ($$0$i$i$i8|0)==($6|0);
         if ($273) {
          $$lcssa22 = $$0$i$i$i8;
          break;
         } else {
          $261 = $$0$i$i$i8;
         }
        }
        $259 = ($$lcssa22|0)==($6|0);
        if ($259) {
         $300 = $252;
        } else {
         $275 = $$lcssa22;$278 = $252;
         while(1) {
          $274 = (($275) + 16|0);
          $276 = HEAP32[$274>>2]|0;
          $277 = (($278) + 112|0);
          $279 = HEAP32[$277>>2]|0;
          $280 = ($276|0)<($279|0);
          if (!($280)) {
           $300 = $278;
           break L81;
          }
          $281 = (($275) + 20|0);
          $282 = HEAP32[$281>>2]|0;
          $283 = HEAP32[$282>>2]|0;
          $284 = HEAP32[$283>>2]|0;
          $285 = (($278) + 4|0);
          $286 = HEAP32[$285>>2]|0;
          __THREW__ = 0;
          invoke_viii($284|0,($282|0),($286|0),($2|0));
          $287 = __THREW__; __THREW__ = 0;
          $288 = $287&1;
          if ($288) {
           label = 17;
           break;
          }
          $289 = (($275) + 4|0);
          $290 = HEAP32[$289>>2]|0;
          $291 = ($290|0)==(0|0);
          if ($291) {
           $$01$i$i$i = $275;
           while(1) {
            $294 = (($$01$i$i$i) + 8|0);
            $295 = HEAP32[$294>>2]|0;
            $296 = HEAP32[$295>>2]|0;
            $297 = ($296|0)==($$01$i$i$i|0);
            if ($297) {
             $$0$i$i$i = $295;
             break;
            } else {
             $$01$i$i$i = $295;
            }
           }
          } else {
           $$0$i$i$i$i = $290;
           while(1) {
            $292 = HEAP32[$$0$i$i$i$i>>2]|0;
            $293 = ($292|0)==(0|0);
            if ($293) {
             $$0$i$i$i = $$0$i$i$i$i;
             break;
            } else {
             $$0$i$i$i$i = $292;
            }
           }
          }
          $298 = ($$0$i$i$i|0)==($6|0);
          if ($298) {
           label = 80;
           break;
          }
          $$pre57 = HEAP32[$this>>2]|0;
          $275 = $$0$i$i$i;$278 = $$pre57;
         }
         if ((label|0) == 17) {
          $86 = ___cxa_find_matching_catch()|0;
          $87 = tempRet0;
          $lpad$phi$index = $86;$lpad$phi$index4 = $87;
          break L4;
         }
         else if ((label|0) == 80) {
          $$pre$pre = HEAP32[$this>>2]|0;
          $300 = $$pre$pre;
          break;
         }
        }
       }
      } while(0);
      $299 = HEAP32[$300>>2]|0;
      $301 = $opaque ? 11 : 17;
      $302 = (($299) + 636|0);
      __THREW__ = 0;
      invoke_viii(1663,($302|0),($301|0),($2|0));
      $303 = __THREW__; __THREW__ = 0;
      $304 = $303&1;
      if ($304) {
       label = 20;
      } else {
       __ZN13BatchRendererD1Ev($batchRenderer);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $92 = ___cxa_find_matching_catch()|0;
  $93 = tempRet0;
  $lpad$phi$index = $92;$lpad$phi$index4 = $93;
 }
 __THREW__ = 0;
 invoke_vi(3399,($batchRenderer|0));
 $94 = __THREW__; __THREW__ = 0;
 $95 = $94&1;
 if ($95) {
  $305 = ___cxa_find_matching_catch(0|0)|0;
  $306 = tempRet0;
  ___clang_call_terminate($305);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z25DoForwardVertexRenderLoopR17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EEbR12ActiveLightsbb($ctx,$objects,$opaque,$activeLights,$linearLighting,$clearFrameBuffer) {
 $ctx = $ctx|0;
 $objects = $objects|0;
 $opaque = $opaque|0;
 $activeLights = $activeLights|0;
 $linearLighting = $linearLighting|0;
 $clearFrameBuffer = $clearFrameBuffer|0;
 var $$$i$us = 0, $$$i$us54 = 0, $$$i40 = 0, $$0$i = 0, $$0$i11 = 0, $$01$i = 0, $$01$i18 = 0, $$byval_copy30 = 0, $$not$i$us = 0, $$not$i31 = 0, $$not10$i$us = 0, $$not10$i$us51 = 0, $$not10$i36 = 0, $$not12$i$us = 0, $$not12$i$us53 = 0, $$not12$i39 = 0, $$not8$i$us = 0, $$not8$i34 = 0, $$pre = 0, $$pre$i = 0;
 var $$pre$i25 = 0, $$suitablePasses$0$us = 0, $$suitablePasses$0$us56 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $brmerge$i33 = 0, $brmerge11$i$us = 0, $brmerge11$i$us52 = 0, $brmerge11$i38 = 0, $brmerge9$i35 = 0, $eh$lpad$body$indexZ2D = 0, $firstPassFlag$059 = 0, $firstPassFlag$1 = 0, $isLightmapped$not$i32 = 0, $it$065 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$us = 0, $or$cond$i$us48 = 0;
 var $or$cond$i30$not = 0, $or$cond$not = 0, $or$cond$us = 0, $or$cond$us57 = 0, $or$cond42 = 0, $or$cond73 = 0, $or$cond74 = 0, $or$cond74$not = 0, $or$cond75 = 0, $or$cond76 = 0, $pass$045$us = 0, $pass$045$us46 = 0, $pass1$060 = 0, $queue = 0, $roIndex$066 = 0, $suitablePasses$0$lcssa = 0, $suitablePasses$044$us = 0, $suitablePasses$044$us47 = 0, $useRGBM$not$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy30 = sp;
 $0 = sp + 108|0;
 $1 = sp + 104|0;
 $2 = sp + 100|0;
 $3 = sp + 96|0;
 $4 = sp + 92|0;
 $5 = sp + 88|0;
 $6 = sp + 112|0;
 $7 = sp + 20|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 4|0;
 $12 = sp + 24|0;
 $queue = sp + 32|0;
 $13 = HEAP32[628512>>2]|0;
 $14 = (($queue) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($queue) + 12|0);
 HEAP32[$15>>2] = $13;
 $16 = (($queue) + 16|0);
 HEAP32[$16>>2] = 0;
 $17 = (($queue) + 20|0);
 HEAP32[$17>>2] = 0;
 $18 = (($queue) + 24|0);
 HEAP32[$18>>2] = 0;
 $19 = (($queue) + 28|0);
 HEAP32[$19>>2] = $13;
 $20 = (($queue) + 32|0);
 HEAP32[$20>>2] = 0;
 $21 = (($queue) + 36|0);
 HEAP32[$21>>2] = 0;
 $22 = (($queue) + 40|0);
 HEAP32[$22>>2] = 0;
 $23 = (($queue) + 44|0);
 HEAP32[$23>>2] = $13;
 $24 = (($queue) + 48|0);
 HEAP32[$24>>2] = 0;
 $25 = (($queue) + 52|0);
 HEAP32[$25>>2] = 0;
 HEAP32[$queue>>2] = $ctx;
 $26 = (($queue) + 4|0);
 HEAP32[$26>>2] = $objects;
 $27 = (($queue) + 8|0);
 $28 = (($objects) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if ($30) {
  label = 4;
 } else {
  HEAP32[$17>>2] = $29;
  $31 = $29 << 2;
  HEAP32[$12>>2] = $13;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$12+0>>2]|0;
  $32 = (invoke_iiiiiiii(108,(0|0),($31|0),4,($$byval_copy30|0),0,(568200|0),370)|0);
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   label = 39;
  } else {
   HEAP32[$27>>2] = $32;
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $35 = (($queue) + 40|0);
   $36 = HEAP32[$28>>2]|0;
   $37 = HEAP32[$25>>2]|0;
   $38 = $37 & 2147483647;
   $39 = ($38>>>0)<($36>>>0);
   do {
    if ($39) {
     $40 = ($37|0)>(-1);
     if ($40) {
      HEAP32[$25>>2] = $36;
      $41 = HEAP32[$35>>2]|0;
      $42 = $36 << 3;
      $43 = HEAP32[$23>>2]|0;
      HEAP32[$10>>2] = $43;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$10+0>>2]|0;
      $44 = (invoke_iiiiiiii(108,($41|0),($42|0),4,($$byval_copy30|0),0,(568200|0),370)|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 39;
       break L4;
      }
      HEAP32[$35>>2] = $44;
      break;
     } else {
      $47 = $36 << 3;
      $48 = HEAP32[$23>>2]|0;
      HEAP32[$11>>2] = $48;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$11+0>>2]|0;
      $49 = (invoke_iiiiiii(102,($47|0),4,($$byval_copy30|0),0,(568200|0),352)|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 39;
       break L4;
      }
      $52 = HEAP32[$35>>2]|0;
      $53 = HEAP32[$24>>2]|0;
      $54 = $53 << 3;
      _memcpy(($49|0),($52|0),($54|0))|0;
      HEAP32[$25>>2] = $36;
      HEAP32[$35>>2] = $49;
      break;
     }
    }
   } while(0);
   $55 = (($queue) + 24|0);
   $56 = HEAP32[$28>>2]|0;
   $57 = $56 << 4;
   $58 = HEAP32[$21>>2]|0;
   $59 = $58 & 2147483647;
   $60 = ($59>>>0)<($57>>>0);
   do {
    if ($60) {
     $61 = ($58|0)>(-1);
     if ($61) {
      HEAP32[$21>>2] = $57;
      $62 = HEAP32[$55>>2]|0;
      $63 = HEAP32[$19>>2]|0;
      HEAP32[$8>>2] = $63;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$8+0>>2]|0;
      $64 = (invoke_iiiiiiii(108,($62|0),($57|0),1,($$byval_copy30|0),0,(568200|0),370)|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       label = 39;
       break L4;
      }
      HEAP32[$55>>2] = $64;
      break;
     } else {
      $67 = HEAP32[$19>>2]|0;
      HEAP32[$9>>2] = $67;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$9+0>>2]|0;
      $68 = (invoke_iiiiiii(102,($57|0),1,($$byval_copy30|0),0,(568200|0),352)|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 39;
       break L4;
      }
      $71 = HEAP32[$55>>2]|0;
      $72 = HEAP32[$20>>2]|0;
      _memcpy(($68|0),($71|0),($72|0))|0;
      HEAP32[$21>>2] = $57;
      HEAP32[$55>>2] = $68;
      break;
     }
    }
   } while(0);
   $73 = (($ctx) + 4|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_i(62)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 39;
   } else {
    __THREW__ = 0;
    $78 = (invoke_i(64)|0);
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     label = 39;
    } else {
     $81 = HEAP32[((640792 + 104|0))>>2]|0;
     $82 = ($81|0)>(2);
     if ($82) {
      $83 = HEAP8[((640792 + 254|0))>>0]|0;
      $84 = ($83<<24>>24)!=(0);
      $99 = $84;
     } else {
      $99 = 0;
     }
     $85 = HEAP32[$objects>>2]|0;
     $86 = HEAP32[$28>>2]|0;
     $87 = (($85) + (($86*44)|0)|0);
     $88 = (($74) + 184|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = ($89|0)==(0|0);
     if ($90) {
      $94 = $85;
     } else {
      __THREW__ = 0;
      invoke_vi(3402,($88|0));
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       label = 39;
       break;
      }
      $$pre = HEAP32[$objects>>2]|0;
      $94 = $$pre;
     }
     $93 = ($94|0)==($87|0);
     L31: do {
      if (!($93)) {
       $95 = (($74) + 92|0);
       $96 = (($78) + 28|0);
       $97 = (($78) + 24|0);
       $98 = (($74) + 216|0);
       $useRGBM$not$i = $99 ^ 1;
       $100 = (($74) + 208|0);
       $101 = (($74) + 192|0);
       $102 = (($78) + 40|0);
       $it$065 = $94;$roIndex$066 = 0;
       L33: while(1) {
        $103 = (($it$065) + 32|0);
        $104 = HEAP32[$103>>2]|0;
        $105 = HEAP32[$16>>2]|0;
        $106 = (($105) + 1)|0;
        HEAP32[$16>>2] = $106;
        $107 = HEAP32[$17>>2]|0;
        $108 = $107 & 2147483647;
        $109 = ($106>>>0)>($108>>>0);
        if ($109) {
         $110 = $107 << 1;
         $111 = ($110|0)==(0);
         $112 = $111 ? 1 : $110;
         $113 = ($108>>>0)<($112>>>0);
         do {
          if ($113) {
           $114 = ($107|0)>(-1);
           if ($114) {
            HEAP32[$17>>2] = $112;
            $115 = HEAP32[$27>>2]|0;
            $116 = $112 << 2;
            $117 = HEAP32[$15>>2]|0;
            HEAP32[$6>>2] = $117;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$6+0>>2]|0;
            $118 = (invoke_iiiiiiii(108,($115|0),($116|0),4,($$byval_copy30|0),0,(568200|0),370)|0);
            $119 = __THREW__; __THREW__ = 0;
            $120 = $119&1;
            if ($120) {
             label = 38;
             break L33;
            }
            HEAP32[$27>>2] = $118;
            break;
           } else {
            $121 = $112 << 2;
            $122 = HEAP32[$15>>2]|0;
            HEAP32[$7>>2] = $122;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$7+0>>2]|0;
            $123 = (invoke_iiiiiii(102,($121|0),4,($$byval_copy30|0),0,(568200|0),352)|0);
            $124 = __THREW__; __THREW__ = 0;
            $125 = $124&1;
            if ($125) {
             label = 38;
             break L33;
            }
            $126 = HEAP32[$27>>2]|0;
            $127 = HEAP32[$16>>2]|0;
            $128 = $127 << 2;
            _memcpy(($123|0),($126|0),($128|0))|0;
            HEAP32[$17>>2] = $112;
            HEAP32[$27>>2] = $123;
            break;
           }
          }
         } while(0);
         $$pre$i = HEAP32[$16>>2]|0;
         $130 = $$pre$i;
        } else {
         $130 = $106;
        }
        $129 = (($130) + -1)|0;
        $131 = HEAP32[$27>>2]|0;
        $132 = HEAP32[$95>>2]|0;
        $133 = $104;
        $134 = $132;
        $135 = (($133) - ($134))|0;
        $136 = $135 >> 7;
        $137 = (($104) + 116|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = (($138) + 36|0);
        $140 = HEAP16[$139>>1]|0;
        $141 = $140&65535;
        $142 = HEAP32[$96>>2]|0;
        $143 = ($142|0)>($141|0);
        if ($143) {
         $144 = HEAP32[$97>>2]|0;
         $145 = (($144) + ($141<<3)|0);
         $$0$i11 = $145;
        } else {
         $$0$i11 = $102;
        }
        $146 = HEAP32[$$0$i11>>2]|0;
        $147 = ($146|0)!=(0);
        $148 = (($it$065) + 36|0);
        $149 = HEAP32[$148>>2]|0;
        $150 = (($149) + 52|0);
        $151 = HEAP32[$150>>2]|0;
        $152 = (($it$065) + 8|0);
        $153 = HEAP16[$152>>1]|0;
        $154 = ($153<<16>>16)==(-1);
        if ($154) {
         $155 = $147&1;
         $156 = ((($151) + ($155<<2)|0) + 12|0);
         $157 = HEAP32[$156>>2]|0;
         $158 = ($157|0)==(-1);
         if (!($158)) {
          $201 = $157&65535;
          HEAP16[$152>>1] = $201;
          label = 59;
         }
        } else {
         label = 59;
        }
        do {
         if ((label|0) == 59) {
          label = 0;
          $202 = HEAP32[$20>>2]|0;
          $203 = (($131) + ($129<<2)|0);
          HEAP32[$203>>2] = $202;
          $204 = HEAP32[$98>>2]|0;
          $205 = ($204|0)==(0);
          if ($205) {
           $218 = 0;$219 = 0;
          } else {
           $206 = HEAP32[$100>>2]|0;
           $207 = (($206) + ($136<<2)|0);
           $208 = HEAP32[$207>>2]|0;
           $209 = (($136) + 1)|0;
           $210 = (($206) + ($209<<2)|0);
           $211 = HEAP32[$210>>2]|0;
           $212 = (($211) - ($208))|0;
           $213 = HEAP32[$101>>2]|0;
           $214 = (($213) + ($208<<3)|0);
           $218 = $214;$219 = $212;
          }
          __THREW__ = 0;
          $215 = (invoke_i(65)|0);
          $216 = __THREW__; __THREW__ = 0;
          $217 = $216&1;
          if ($217) {
           label = 38;
           break L33;
          }
          __THREW__ = 0;
          invoke_viiiiii(101,($215|0),($55|0),($218|0),($219|0),($activeLights|0),($104|0));
          $220 = __THREW__; __THREW__ = 0;
          $221 = $220&1;
          if ($221) {
           label = 38;
           break L33;
          }
          $222 = HEAP16[$152>>1]|0;
          $223 = $222 << 16 >> 16;
          $224 = HEAP32[$151>>2]|0;
          $225 = (($224) + ($223<<2)|0);
          $226 = HEAP32[$225>>2]|0;
          $227 = (($226) + 16|0);
          $228 = HEAP32[$227>>2]|0;
          $229 = ($228|0)>(0);
          if ($229) {
           $230 = HEAP32[$226>>2]|0;
           if ($147) {
            $pass$045$us46 = 0;$suitablePasses$044$us47 = 0;
            while(1) {
             $246 = (($230) + ($pass$045$us46<<2)|0);
             $247 = HEAP32[$246>>2]|0;
             $248 = (($247) + 660|0);
             $249 = HEAP32[$248>>2]|0;
             $250 = (($247) + 584|0);
             $251 = HEAP32[$250>>2]|0;
             $252 = $249 & $75;
             $253 = ($252|0)!=($249|0);
             $254 = ($251>>>0)>(3);
             $or$cond$i$us48 = $253 | $254;
             $$not$i$us = ($251|0)==(1);
             $or$cond74 = $or$cond$i$us48 | $$not$i$us;
             $or$cond74$not = $or$cond74 ^ 1;
             $$not10$i$us51 = ($251|0)!=(2);
             $brmerge11$i$us52 = $$not10$i$us51 | $useRGBM$not$i;
             $or$cond75 = $brmerge11$i$us52 & $or$cond74$not;
             if ($or$cond75) {
              $$not12$i$us53 = ($251|0)!=(3);
              $$$i$us54 = $$not12$i$us53 | $99;
              $256 = $$$i$us54;
             } else {
              $256 = 0;
             }
             $255 = $256&1;
             $$suitablePasses$0$us56 = (($255) + ($suitablePasses$044$us47))|0;
             $257 = (($pass$045$us46) + 1)|0;
             $258 = ($257|0)<($228|0);
             $259 = ($$suitablePasses$0$us56|0)<(2);
             $or$cond$us57 = $258 & $259;
             if ($or$cond$us57) {
              $pass$045$us46 = $257;$suitablePasses$044$us47 = $$suitablePasses$0$us56;
             } else {
              $suitablePasses$0$lcssa = $$suitablePasses$0$us56;
              break;
             }
            }
           } else {
            $pass$045$us = 0;$suitablePasses$044$us = 0;
            while(1) {
             $231 = (($230) + ($pass$045$us<<2)|0);
             $232 = HEAP32[$231>>2]|0;
             $233 = (($232) + 660|0);
             $234 = HEAP32[$233>>2]|0;
             $235 = (($232) + 584|0);
             $236 = HEAP32[$235>>2]|0;
             $237 = $234 & $75;
             $238 = ($237|0)!=($234|0);
             $239 = ($236>>>0)>(3);
             $or$cond$i$us = $238 | $239;
             $240 = $236 & -2;
             $$not8$i$us = ($240|0)==(2);
             $or$cond = $or$cond$i$us | $$not8$i$us;
             $or$cond$not = $or$cond ^ 1;
             $$not10$i$us = ($236|0)!=(2);
             $brmerge11$i$us = $$not10$i$us | $useRGBM$not$i;
             $or$cond73 = $brmerge11$i$us & $or$cond$not;
             if ($or$cond73) {
              $$not12$i$us = ($236|0)!=(3);
              $$$i$us = $$not12$i$us | $99;
              $242 = $$$i$us;
             } else {
              $242 = 0;
             }
             $241 = $242&1;
             $$suitablePasses$0$us = (($241) + ($suitablePasses$044$us))|0;
             $243 = (($pass$045$us) + 1)|0;
             $244 = ($243|0)<($228|0);
             $245 = ($$suitablePasses$0$us|0)<(2);
             $or$cond$us = $244 & $245;
             if ($or$cond$us) {
              $pass$045$us = $243;$suitablePasses$044$us = $$suitablePasses$0$us;
             } else {
              $suitablePasses$0$lcssa = $$suitablePasses$0$us;
              break;
             }
            }
           }
           $260 = ($suitablePasses$0$lcssa|0)>(1);
           $261 = $260 ? 131072 : 0;
           if (!($229)) {
            break;
           }
           $isLightmapped$not$i32 = $147 ^ 1;
           $firstPassFlag$059 = 65536;$pass1$060 = 0;
           while(1) {
            $262 = HEAP32[$226>>2]|0;
            $263 = (($262) + ($pass1$060<<2)|0);
            $264 = HEAP32[$263>>2]|0;
            $265 = (($264) + 660|0);
            $266 = HEAP32[$265>>2]|0;
            $267 = (($264) + 584|0);
            $268 = HEAP32[$267>>2]|0;
            $269 = $266 & $75;
            $notlhs = ($269|0)==($266|0);
            $notrhs = ($268>>>0)<(4);
            $or$cond$i30$not = $notrhs & $notlhs;
            $$not$i31 = ($268|0)!=(1);
            $brmerge$i33 = $$not$i31 | $isLightmapped$not$i32;
            $or$cond76 = $or$cond$i30$not & $brmerge$i33;
            do {
             if ($or$cond76) {
              $270 = $268 & -2;
              $$not8$i34 = ($270|0)!=(2);
              $brmerge9$i35 = $$not8$i34 | $147;
              if (!($brmerge9$i35)) {
               $firstPassFlag$1 = $firstPassFlag$059;
               break;
              }
              $$not10$i36 = ($268|0)!=(2);
              $brmerge11$i38 = $$not10$i36 | $useRGBM$not$i;
              $$not12$i39 = ($268|0)!=(3);
              $$$i40 = $$not12$i39 | $99;
              $or$cond42 = $brmerge11$i38 & $$$i40;
              if (!($or$cond42)) {
               $firstPassFlag$1 = $firstPassFlag$059;
               break;
              }
              $271 = HEAP32[$24>>2]|0;
              $272 = (($271) + 1)|0;
              HEAP32[$24>>2] = $272;
              $273 = HEAP32[$25>>2]|0;
              $274 = $273 & 2147483647;
              $275 = ($272>>>0)>($274>>>0);
              if ($275) {
               $276 = $273 << 1;
               $277 = ($276|0)==(0);
               $278 = $277 ? 1 : $276;
               $279 = ($274>>>0)<($278>>>0);
               do {
                if ($279) {
                 $280 = ($273|0)>(-1);
                 if ($280) {
                  HEAP32[$25>>2] = $278;
                  $281 = HEAP32[$35>>2]|0;
                  $282 = $278 << 3;
                  $283 = HEAP32[$23>>2]|0;
                  HEAP32[$0>>2] = $283;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$0+0>>2]|0;
                  $284 = (invoke_iiiiiiii(108,($281|0),($282|0),4,($$byval_copy30|0),0,(568200|0),370)|0);
                  $285 = __THREW__; __THREW__ = 0;
                  $286 = $285&1;
                  if ($286) {
                   label = 37;
                   break L33;
                  }
                  HEAP32[$35>>2] = $284;
                  break;
                 } else {
                  $287 = $278 << 3;
                  $288 = HEAP32[$23>>2]|0;
                  HEAP32[$1>>2] = $288;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$1+0>>2]|0;
                  $289 = (invoke_iiiiiii(102,($287|0),4,($$byval_copy30|0),0,(568200|0),352)|0);
                  $290 = __THREW__; __THREW__ = 0;
                  $291 = $290&1;
                  if ($291) {
                   label = 37;
                   break L33;
                  }
                  $292 = HEAP32[$35>>2]|0;
                  $293 = HEAP32[$24>>2]|0;
                  $294 = $293 << 3;
                  _memcpy(($289|0),($292|0),($294|0))|0;
                  HEAP32[$25>>2] = $278;
                  HEAP32[$35>>2] = $289;
                  break;
                 }
                }
               } while(0);
               $$pre$i25 = HEAP32[$24>>2]|0;
               $296 = $$pre$i25;
              } else {
               $296 = $272;
              }
              $295 = (($296) + -1)|0;
              $297 = HEAP32[$35>>2]|0;
              $298 = (($297) + ($295<<3)|0);
              HEAP32[$298>>2] = $roIndex$066;
              $299 = $pass1$060 & 255;
              $300 = $firstPassFlag$059 | $261;
              $301 = $300 | $299;
              $302 = ((($297) + ($295<<3)|0) + 4|0);
              HEAP32[$302>>2] = $301;
              $firstPassFlag$1 = 0;
             } else {
              $firstPassFlag$1 = $firstPassFlag$059;
             }
            } while(0);
            $303 = (($pass1$060) + 1)|0;
            $304 = ($303|0)<($228|0);
            if ($304) {
             $firstPassFlag$059 = $firstPassFlag$1;$pass1$060 = $303;
            } else {
             break;
            }
           }
          }
         }
        } while(0);
        $305 = (($it$065) + 44|0);
        $306 = ($305|0)==($87|0);
        if ($306) {
         break L31;
        }
        $307 = (($roIndex$066) + 1)|0;
        $it$065 = $305;$roIndex$066 = $307;
       }
       if ((label|0) == 37) {
        $159 = ___cxa_find_matching_catch()|0;
        $160 = tempRet0;
        $lpad$phi$index = $159;$lpad$phi$index3 = $160;
        break L4;
       }
       else if ((label|0) == 38) {
        $161 = ___cxa_find_matching_catch()|0;
        $162 = tempRet0;
        $lpad$phi$index = $161;$lpad$phi$index3 = $162;
        break L4;
       }
      }
     } while(0);
     if ($opaque) {
      $308 = HEAP32[$35>>2]|0;
      $309 = HEAP32[$24>>2]|0;
      $310 = (($308) + ($309<<3)|0);
      HEAP32[$$byval_copy30>>2] = $queue;
      __ZNSt3__16__sortIRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEvT0_S7_T_($308,$310,$$byval_copy30);
     } else {
      $311 = HEAP32[$35>>2]|0;
      $312 = HEAP32[$24>>2]|0;
      $313 = (($311) + ($312<<3)|0);
      HEAP32[$$byval_copy30>>2] = $queue;
      __ZNSt3__16__sortIRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEvT0_S7_T_($311,$313,$$byval_copy30);
     }
     $314 = HEAP32[$ctx>>2]|0;
     $315 = (($314) + 348|0);
     $316 = HEAP32[$315>>2]|0;
     if ($linearLighting) {
      $317 = ($316|0)==(0|0);
      if ($317) {
       $321 = 1;
      } else {
       $318 = (($316) + 130|0);
       $319 = HEAP8[$318>>0]|0;
       $320 = ($319<<24>>24)!=(0);
       $321 = $320;
      }
     } else {
      $321 = 0;
     }
     __THREW__ = 0;
     invoke_viiii(335,($queue|0),($321|0),($clearFrameBuffer|0),($opaque|0));
     $322 = __THREW__; __THREW__ = 0;
     $323 = $322&1;
     if ($323) {
      label = 39;
     } else {
      $324 = HEAP32[$25>>2]|0;
      $325 = ($324|0)>(-1);
      do {
       if ($325) {
        $326 = HEAP32[$22>>2]|0;
        $327 = HEAP32[$23>>2]|0;
        HEAP32[$3>>2] = $327;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($326|0),($$byval_copy30|0));
        $328 = __THREW__; __THREW__ = 0;
        $329 = $328&1;
        if (!($329)) {
         HEAP32[$22>>2] = 0;
         label = 98;
         break;
        }
        $340 = ___cxa_find_matching_catch()|0;
        $341 = tempRet0;
        $342 = HEAP32[$21>>2]|0;
        $343 = ($342|0)>(-1);
        if ($343) {
         $344 = HEAP32[$18>>2]|0;
         $345 = HEAP32[$19>>2]|0;
         HEAP32[$1>>2] = $345;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$1+0>>2]|0;
         invoke_vii(2591,($344|0),($$byval_copy30|0));
         $346 = __THREW__; __THREW__ = 0;
         $347 = $346&1;
         if ($347) {
          $356 = ___cxa_find_matching_catch(0|0)|0;
          $357 = tempRet0;
          ___clang_call_terminate($356);
          // unreachable;
         } else {
          HEAP32[$18>>2] = 0;
          $$0$i = $341;$$01$i = $340;
          break;
         }
        } else {
         $$0$i = $341;$$01$i = $340;
        }
       } else {
        label = 98;
       }
      } while(0);
      L115: do {
       if ((label|0) == 98) {
        $330 = HEAP32[$21>>2]|0;
        $331 = ($330|0)>(-1);
        do {
         if ($331) {
          $332 = HEAP32[$18>>2]|0;
          $333 = HEAP32[$19>>2]|0;
          HEAP32[$2>>2] = $333;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$2+0>>2]|0;
          invoke_vii(2591,($332|0),($$byval_copy30|0));
          $334 = __THREW__; __THREW__ = 0;
          $335 = $334&1;
          if ($335) {
           $348 = ___cxa_find_matching_catch()|0;
           $349 = tempRet0;
           $$0$i = $349;$$01$i = $348;
           break L115;
          } else {
           HEAP32[$18>>2] = 0;
           break;
          }
         }
        } while(0);
        $336 = HEAP32[$17>>2]|0;
        $337 = ($336|0)>(-1);
        if (!($337)) {
         STACKTOP = sp;return;
        }
        $338 = HEAP32[$14>>2]|0;
        $339 = HEAP32[$15>>2]|0;
        HEAP32[$0>>2] = $339;
        ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$0+0>>2]|0;
        __Z19free_alloc_internalPv10MemLabelId($338,$$byval_copy30);
        HEAP32[$14>>2] = 0;
        STACKTOP = sp;return;
       }
      } while(0);
      $350 = HEAP32[$17>>2]|0;
      $351 = ($350|0)>(-1);
      if (!($351)) {
       ___resumeException($$01$i|0);
       // unreachable;
      }
      $352 = HEAP32[$14>>2]|0;
      $353 = HEAP32[$15>>2]|0;
      HEAP32[$0>>2] = $353;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($352|0),($$byval_copy30|0));
      $354 = __THREW__; __THREW__ = 0;
      $355 = $354&1;
      if ($355) {
       $356 = ___cxa_find_matching_catch(0|0)|0;
       $357 = tempRet0;
       ___clang_call_terminate($356);
       // unreachable;
      }
      HEAP32[$14>>2] = 0;
      ___resumeException($$01$i|0);
      // unreachable;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 39) {
  $163 = ___cxa_find_matching_catch()|0;
  $164 = tempRet0;
  $lpad$phi$index = $163;$lpad$phi$index3 = $164;
 }
 $165 = HEAP32[$25>>2]|0;
 $166 = ($165|0)>(-1);
 do {
  if ($166) {
   $167 = HEAP32[$22>>2]|0;
   $168 = HEAP32[$23>>2]|0;
   HEAP32[$5>>2] = $168;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($167|0),($$byval_copy30|0));
   $169 = __THREW__; __THREW__ = 0;
   $170 = $169&1;
   if (!($170)) {
    HEAP32[$22>>2] = 0;
    label = 43;
    break;
   }
   $183 = ___cxa_find_matching_catch(0|0)|0;
   $184 = tempRet0;
   $185 = HEAP32[$21>>2]|0;
   $186 = ($185|0)>(-1);
   if ($186) {
    $187 = HEAP32[$18>>2]|0;
    $188 = HEAP32[$19>>2]|0;
    HEAP32[$3>>2] = $188;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($187|0),($$byval_copy30|0));
    $189 = __THREW__; __THREW__ = 0;
    $190 = $189&1;
    if ($190) {
     $199 = ___cxa_find_matching_catch(0|0)|0;
     $200 = tempRet0;
     ___clang_call_terminate($199);
     // unreachable;
    } else {
     HEAP32[$18>>2] = 0;
     $$01$i18 = $183;
     break;
    }
   } else {
    $$01$i18 = $183;
   }
  } else {
   label = 43;
  }
 } while(0);
 L147: do {
  if ((label|0) == 43) {
   $171 = HEAP32[$21>>2]|0;
   $172 = ($171|0)>(-1);
   do {
    if ($172) {
     $173 = HEAP32[$18>>2]|0;
     $174 = HEAP32[$19>>2]|0;
     HEAP32[$4>>2] = $174;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($173|0),($$byval_copy30|0));
     $175 = __THREW__; __THREW__ = 0;
     $176 = $175&1;
     if ($176) {
      $191 = ___cxa_find_matching_catch(0|0)|0;
      $192 = tempRet0;
      $$01$i18 = $191;
      break L147;
     } else {
      HEAP32[$18>>2] = 0;
      break;
     }
    }
   } while(0);
   $177 = HEAP32[$17>>2]|0;
   $178 = ($177|0)>(-1);
   if (!($178)) {
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $179 = HEAP32[$14>>2]|0;
   $180 = HEAP32[$15>>2]|0;
   HEAP32[$2>>2] = $180;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($179|0),($$byval_copy30|0));
   $181 = __THREW__; __THREW__ = 0;
   $182 = $181&1;
   if ($182) {
    $358 = ___cxa_find_matching_catch(0|0)|0;
    $359 = tempRet0;
    $eh$lpad$body$indexZ2D = $358;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   } else {
    HEAP32[$14>>2] = 0;
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
  }
 } while(0);
 $193 = HEAP32[$17>>2]|0;
 $194 = ($193|0)>(-1);
 do {
  if ($194) {
   $195 = HEAP32[$14>>2]|0;
   $196 = HEAP32[$15>>2]|0;
   HEAP32[$2>>2] = $196;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($195|0),($$byval_copy30|0));
   $197 = __THREW__; __THREW__ = 0;
   $198 = $197&1;
   if ($198) {
    $199 = ___cxa_find_matching_catch(0|0)|0;
    $200 = tempRet0;
    ___clang_call_terminate($199);
    // unreachable;
   } else {
    HEAP32[$14>>2] = 0;
    break;
   }
  }
 } while(0);
 $eh$lpad$body$indexZ2D = $$01$i18;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZNSt3__16__sortIRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$02$i = 0, $__i$07 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__k$0$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 11;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 54;
    break L1;
    break;
   }
   default: {
   }
   }
   $89 = ($3|0)<(248);
   if ($89) {
    label = 13;
    break L1;
   }
   $130 = ($3|0)>(7992);
   $131 = (($4|0) / 2)&-1;
   $132 = (($$0) + ($131<<3)|0);
   if ($130) {
    $133 = (($4|0) / 4)&-1;
    $134 = (($$0) + ($133<<3)|0);
    $$sum = (($133) + ($131))|0;
    $135 = (($$0) + ($$sum<<3)|0);
    $136 = (__ZNSt3__17__sort5IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_S7_S7_T_($$0,$134,$132,$135,$1,$__comp)|0);
    $__n_swaps$0 = $136;
   } else {
    $137 = (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($$0,$132,$1,$__comp)|0);
    $__n_swaps$0 = $137;
   }
   $138 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$$0,$132)|0);
   do {
    if ($138) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $139 = (($__j$0) + -8|0);
      $140 = ($$0|0)==($139|0);
      if ($140) {
       break;
      }
      $193 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$139,$132)|0);
      if ($193) {
       label = 37;
       break;
      } else {
       $__j$0 = $139;
      }
     }
     if ((label|0) == 37) {
      label = 0;
      $194 = $$0;
      $195 = $194;
      $196 = HEAP32[$195>>2]|0;
      $197 = (($194) + 4)|0;
      $198 = $197;
      $199 = HEAP32[$198>>2]|0;
      $200 = $139;
      $201 = $200;
      $202 = HEAP32[$201>>2]|0;
      $203 = (($200) + 4)|0;
      $204 = $203;
      $205 = HEAP32[$204>>2]|0;
      $206 = $$0;
      $207 = $206;
      HEAP32[$207>>2] = $202;
      $208 = (($206) + 4)|0;
      $209 = $208;
      HEAP32[$209>>2] = $205;
      $210 = $139;
      $211 = $210;
      HEAP32[$211>>2] = $196;
      $212 = (($210) + 4)|0;
      $213 = $212;
      HEAP32[$213>>2] = $199;
      $214 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $139;$__n_swaps$3 = $214;
      break;
     }
     $141 = (($$0) + 8|0);
     $142 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$$0,$1)|0);
     if ($142) {
      $__i$1 = $141;
     } else {
      $143 = ($141|0)==($1|0);
      if ($143) {
       label = 54;
       break L1;
      } else {
       $__i$07 = $141;
      }
      while(1) {
       $146 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$$0,$__i$07)|0);
       $145 = (($__i$07) + 8|0);
       if ($146) {
        break;
       }
       $144 = ($145|0)==($1|0);
       if ($144) {
        label = 54;
        break L1;
       } else {
        $__i$07 = $145;
       }
      }
      $147 = $__i$07;
      $148 = $147;
      $149 = HEAP32[$148>>2]|0;
      $150 = (($147) + 4)|0;
      $151 = $150;
      $152 = HEAP32[$151>>2]|0;
      $153 = $1;
      $154 = $153;
      $155 = HEAP32[$154>>2]|0;
      $156 = (($153) + 4)|0;
      $157 = $156;
      $158 = HEAP32[$157>>2]|0;
      $159 = $__i$07;
      $160 = $159;
      HEAP32[$160>>2] = $155;
      $161 = (($159) + 4)|0;
      $162 = $161;
      HEAP32[$162>>2] = $158;
      $163 = $1;
      $164 = $163;
      HEAP32[$164>>2] = $149;
      $165 = (($163) + 4)|0;
      $166 = $165;
      HEAP32[$166>>2] = $152;
      $__i$1 = $145;
     }
     $167 = ($__i$1|0)==($1|0);
     if ($167) {
      label = 54;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $168 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$$0,$__i$2)|0);
       $169 = (($__i$2) + 8|0);
       if ($168) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $169;
       }
      }
      while(1) {
       $170 = (($__j$2) + -8|0);
       $171 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$$0,$170)|0);
       if ($171) {
        $__j$2 = $170;
       } else {
        break;
       }
      }
      $172 = ($__i$2>>>0)<($170>>>0);
      if (!($172)) {
       $$0 = $__i$2;
       continue L3;
      }
      $173 = $__i$2;
      $174 = $173;
      $175 = HEAP32[$174>>2]|0;
      $176 = (($173) + 4)|0;
      $177 = $176;
      $178 = HEAP32[$177>>2]|0;
      $179 = $170;
      $180 = $179;
      $181 = HEAP32[$180>>2]|0;
      $182 = (($179) + 4)|0;
      $183 = $182;
      $184 = HEAP32[$183>>2]|0;
      $185 = $__i$2;
      $186 = $185;
      HEAP32[$186>>2] = $181;
      $187 = (($185) + 4)|0;
      $188 = $187;
      HEAP32[$188>>2] = $184;
      $189 = $170;
      $190 = $189;
      HEAP32[$190>>2] = $175;
      $191 = (($189) + 4)|0;
      $192 = $191;
      HEAP32[$192>>2] = $178;
      $__i$2$ph = $169;$__j$1$ph = $170;
     }
    }
   } while(0);
   $215 = (($$0) + 8|0);
   $216 = ($215>>>0)<($__j$3>>>0);
   L34: do {
    if ($216) {
     $__i$3$ph = $215;$__j$4$ph = $__j$3;$__m$0$ph = $132;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $217 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$__i$3,$__m$0$ph)|0);
       $218 = (($__i$3) + 8|0);
       if ($217) {
        $__i$3 = $218;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $219 = (($__j$5) + -8|0);
       $220 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$219,$__m$0$ph)|0);
       if ($220) {
        break;
       } else {
        $__j$5 = $219;
       }
      }
      $221 = ($__i$3>>>0)>($219>>>0);
      if ($221) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $222 = $__i$3;
      $223 = $222;
      $224 = HEAP32[$223>>2]|0;
      $225 = (($222) + 4)|0;
      $226 = $225;
      $227 = HEAP32[$226>>2]|0;
      $228 = $219;
      $229 = $228;
      $230 = HEAP32[$229>>2]|0;
      $231 = (($228) + 4)|0;
      $232 = $231;
      $233 = HEAP32[$232>>2]|0;
      $234 = $__i$3;
      $235 = $234;
      HEAP32[$235>>2] = $230;
      $236 = (($234) + 4)|0;
      $237 = $236;
      HEAP32[$237>>2] = $233;
      $238 = $219;
      $239 = $238;
      HEAP32[$239>>2] = $224;
      $240 = (($238) + 4)|0;
      $241 = $240;
      HEAP32[$241>>2] = $227;
      $242 = (($__n_swaps$4$ph) + 1)|0;
      $243 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $243 ? $219 : $__m$0$ph;
      $__i$3$ph = $218;$__j$4$ph = $219;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $242;
     }
    } else {
     $__i$4 = $215;$__m$2 = $132;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $244 = ($__i$4|0)==($__m$2|0);
   if ($244) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $245 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$__m$2,$__i$4)|0);
    if ($245) {
     $246 = $__i$4;
     $247 = $246;
     $248 = HEAP32[$247>>2]|0;
     $249 = (($246) + 4)|0;
     $250 = $249;
     $251 = HEAP32[$250>>2]|0;
     $252 = $__m$2;
     $253 = $252;
     $254 = HEAP32[$253>>2]|0;
     $255 = (($252) + 4)|0;
     $256 = $255;
     $257 = HEAP32[$256>>2]|0;
     $258 = $__i$4;
     $259 = $258;
     HEAP32[$259>>2] = $254;
     $260 = (($258) + 4)|0;
     $261 = $260;
     HEAP32[$261>>2] = $257;
     $262 = $__m$2;
     $263 = $262;
     HEAP32[$263>>2] = $248;
     $264 = (($262) + 4)|0;
     $265 = $264;
     HEAP32[$265>>2] = $251;
     $266 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $266;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $267 = ($__n_swaps$6|0)==(0);
   if ($267) {
    $268 = (__ZNSt3__127__insertion_sort_incompleteIRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEbT0_S7_T_($$0,$__i$4,$__comp)|0);
    $269 = (($__i$4) + 8|0);
    $270 = (__ZNSt3__127__insertion_sort_incompleteIRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEbT0_S7_T_($269,$$01$ph,$__comp)|0);
    if ($270) {
     label = 49;
     break;
    }
    if ($268) {
     $$0 = $269;
     continue;
    }
   }
   $271 = $__i$4;
   $272 = (($271) - ($2))|0;
   $273 = (($0) - ($271))|0;
   $274 = ($272|0)<($273|0);
   if (!($274)) {
    label = 53;
    break;
   }
   __ZNSt3__16__sortIRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEvT0_S7_T_($$0,$__i$4,$__comp);
   $275 = (($__i$4) + 8|0);
   $$0 = $275;
  }
  if ((label|0) == 49) {
   label = 0;
   if ($268) {
    label = 54;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 53) {
   label = 0;
   $276 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEvT0_S7_T_($276,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$1,$$0)|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = $$0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $1;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $$0;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $1;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $26 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($$0,$26,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $27 = (($$0) + 8|0);
  $28 = (($$0) + 16|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($$0,$27,$28,$__comp)|0);
  $29 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$1,$28)|0);
  if (!($29)) {
   STACKTOP = sp;return;
  }
  $30 = $28;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 4)|0;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = $1;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $28;
  $43 = $42;
  HEAP32[$43>>2] = $38;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $41;
  $46 = $1;
  $47 = $46;
  HEAP32[$47>>2] = $32;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $35;
  $50 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$28,$27)|0);
  if (!($50)) {
   STACKTOP = sp;return;
  }
  $51 = $27;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $28;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = (($57) + 4)|0;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = $27;
  $64 = $63;
  HEAP32[$64>>2] = $59;
  $65 = (($63) + 4)|0;
  $66 = $65;
  HEAP32[$66>>2] = $62;
  $67 = $28;
  $68 = $67;
  HEAP32[$68>>2] = $53;
  $69 = (($67) + 4)|0;
  $70 = $69;
  HEAP32[$70>>2] = $56;
  $71 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$27,$$0)|0);
  if (!($71)) {
   STACKTOP = sp;return;
  }
  $72 = $$0;
  $73 = $72;
  $74 = HEAP32[$73>>2]|0;
  $75 = (($72) + 4)|0;
  $76 = $75;
  $77 = HEAP32[$76>>2]|0;
  $78 = $$0;
  $79 = $78;
  HEAP32[$79>>2] = $59;
  $80 = (($78) + 4)|0;
  $81 = $80;
  HEAP32[$81>>2] = $62;
  $82 = $27;
  $83 = $82;
  HEAP32[$83>>2] = $74;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $77;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  $86 = (($$0) + 8|0);
  $87 = (($$0) + 16|0);
  $88 = (($$0) + 24|0);
  (__ZNSt3__17__sort5IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_S7_S7_T_($$0,$86,$87,$88,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 13) {
  $90 = (($$0) + 16|0);
  $91 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($$0,$91,$90,$__comp)|0);
  $92 = (($$0) + 24|0);
  $93 = ($92|0)==($$01$ph|0);
  if ($93) {
   STACKTOP = sp;return;
  } else {
   $__i$02$i = $92;$__j$01$i = $90;
  }
  while(1) {
   $94 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$__i$02$i,$__j$01$i)|0);
   if ($94) {
    $95 = $__i$02$i;
    $96 = $95;
    $97 = HEAP32[$96>>2]|0;
    $98 = (($95) + 4)|0;
    $99 = $98;
    $100 = HEAP32[$99>>2]|0;
    $101 = $__t$i;
    $102 = $101;
    HEAP32[$102>>2] = $97;
    $103 = (($101) + 4)|0;
    $104 = $103;
    HEAP32[$104>>2] = $100;
    $__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     $105 = $__k$0$i;
     $106 = $105;
     $107 = HEAP32[$106>>2]|0;
     $108 = (($105) + 4)|0;
     $109 = $108;
     $110 = HEAP32[$109>>2]|0;
     $111 = $__j$1$i;
     $112 = $111;
     HEAP32[$112>>2] = $107;
     $113 = (($111) + 4)|0;
     $114 = $113;
     HEAP32[$114>>2] = $110;
     $115 = ($__k$0$i|0)==($$0|0);
     if ($115) {
      break;
     }
     $116 = (($__k$0$i) + -8|0);
     $117 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$__t$i,$116)|0);
     if ($117) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $116;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $118 = $__t$i;
    $119 = $118;
    $120 = HEAP32[$119>>2]|0;
    $121 = (($118) + 4)|0;
    $122 = $121;
    $123 = HEAP32[$122>>2]|0;
    $124 = $__k$0$i;
    $125 = $124;
    HEAP32[$125>>2] = $120;
    $126 = (($124) + 4)|0;
    $127 = $126;
    HEAP32[$127>>2] = $123;
   }
   $128 = (($__i$02$i) + 8|0);
   $129 = ($128|0)==($$01$ph|0);
   if ($129) {
    break;
   } else {
    $__j$01$i$phi = $__i$02$i;$__i$02$i = $128;$__j$01$i = $__j$01$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 54) {
  STACKTOP = sp;return;
 }
}
function __ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($this,$ra,$rb) {
 $this = $this|0;
 $ra = $ra|0;
 $rb = $rb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$ra>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$rb>>2]|0;
 $6 = ((($4) + (($3*44)|0)|0) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($4) + (($5*44)|0)|0) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if (!($10)) {
  $11 = ($7>>>0)<($9>>>0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ((($4) + (($3*44)|0)|0) + 4|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = ((($4) + (($5*44)|0)|0) + 4|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = ($13<<16>>16)==($15<<16>>16);
 if (!($16)) {
  $17 = ($13<<16>>16)<($15<<16>>16);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = ((($4) + (($3*44)|0)|0) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($4) + (($5*44)|0)|0) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = $19 != $21;
 if ($22) {
  $23 = $19 < $21;
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = ((($4) + (($3*44)|0)|0) + 16|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = ((($4) + (($5*44)|0)|0) + 16|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = ($25<<16>>16)==($27<<16>>16);
 if (!($28)) {
  $29 = ($25&65535)<($27&65535);
  $$0 = $29;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (($ra) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($rb) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $31 & 65536;
 $35 = $33 & 65536;
 $36 = ($34|0)==($35|0);
 if (!($36)) {
  $37 = ($34>>>0)>($35>>>0);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = ((($4) + (($3*44)|0)|0) + 12|0);
 $39 = HEAP16[$38>>1]|0;
 $40 = ((($4) + (($5*44)|0)|0) + 12|0);
 $41 = HEAP16[$40>>1]|0;
 $42 = ($39<<16>>16)==($41<<16>>16);
 if (!($42)) {
  $43 = ($39&65535)<($41&65535);
  $$0 = $43;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = ((($4) + (($3*44)|0)|0) + 20|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($4) + (($5*44)|0)|0) + 20|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($45|0)==($47|0);
 if (!($48)) {
  $49 = ($45|0)<($47|0);
  $$0 = $49;
  STACKTOP = sp;return ($$0|0);
 }
 $50 = (($4) + (($3*44)|0)|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($4) + (($5*44)|0)|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($51|0)==($53|0);
 if (!($54)) {
  $55 = (($51) + 4|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($53) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($56|0)<($58|0);
  $$0 = $59;
  STACKTOP = sp;return ($$0|0);
 }
 $60 = $31 & 255;
 $61 = $33 & 255;
 $62 = ($60|0)==($61|0);
 if ($62) {
  $64 = ($3|0)<($5|0);
  $$0 = $64;
  STACKTOP = sp;return ($$0|0);
 } else {
  $63 = ($60>>>0)<($61>>>0);
  $$0 = $63;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__y,$__x)|0);
 $1 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__z,$__y)|0);
 if (!($0)) {
  if (!($1)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $2 = $__y;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__z;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__y;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__z;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__y,$__x)|0);
  if (!($22)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $23 = $__x;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $__y;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 4)|0;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = $__x;
  $36 = $35;
  HEAP32[$36>>2] = $31;
  $37 = (($35) + 4)|0;
  $38 = $37;
  HEAP32[$38>>2] = $34;
  $39 = $__y;
  $40 = $39;
  HEAP32[$40>>2] = $25;
  $41 = (($39) + 4)|0;
  $42 = $41;
  HEAP32[$42>>2] = $28;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = $__x;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 if ($1) {
  $49 = $__z;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $__x;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = $__z;
  $60 = $59;
  HEAP32[$60>>2] = $45;
  $61 = (($59) + 4)|0;
  $62 = $61;
  HEAP32[$62>>2] = $48;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = $__y;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $__x;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $__y;
 $74 = $73;
 HEAP32[$74>>2] = $45;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $48;
 $77 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__z,$__y)|0);
 if (!($77)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = $__z;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__y;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__z;
 $89 = $88;
 HEAP32[$89>>2] = $45;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $48;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort5IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__r$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__x4,$__x3)|0);
 if ($1) {
  $2 = $__x3;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__x4;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__x3;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__x4;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (($0) + 1)|0;
  $23 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__x3,$__x2)|0);
  if ($23) {
   $24 = $__x2;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 4)|0;
   $28 = $27;
   $29 = HEAP32[$28>>2]|0;
   $30 = $__x3;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $__x2;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
   $40 = $__x3;
   $41 = $40;
   HEAP32[$41>>2] = $26;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $29;
   $44 = (($0) + 2)|0;
   $45 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__x2,$__x1)|0);
   if ($45) {
    $46 = $__x1;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4)|0;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = $__x2;
    $53 = $52;
    $54 = HEAP32[$53>>2]|0;
    $55 = (($52) + 4)|0;
    $56 = $55;
    $57 = HEAP32[$56>>2]|0;
    $58 = $__x1;
    $59 = $58;
    HEAP32[$59>>2] = $54;
    $60 = (($58) + 4)|0;
    $61 = $60;
    HEAP32[$61>>2] = $57;
    $62 = $__x2;
    $63 = $62;
    HEAP32[$63>>2] = $48;
    $64 = (($62) + 4)|0;
    $65 = $64;
    HEAP32[$65>>2] = $51;
    $66 = (($0) + 3)|0;
    $__r$0$i = $66;
   } else {
    $__r$0$i = $44;
   }
  } else {
   $__r$0$i = $22;
  }
 } else {
  $__r$0$i = $0;
 }
 $67 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__x5,$__x4)|0);
 if (!($67)) {
  $__r$0 = $__r$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $68 = $__x4;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = $__x5;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = (($74) + 4)|0;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = $__x4;
 $81 = $80;
 HEAP32[$81>>2] = $76;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $79;
 $84 = $__x5;
 $85 = $84;
 HEAP32[$85>>2] = $70;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $73;
 $88 = (($__r$0$i) + 1)|0;
 $89 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__x4,$__x3)|0);
 if (!($89)) {
  $__r$0 = $88;
  STACKTOP = sp;return ($__r$0|0);
 }
 $90 = $__x3;
 $91 = $90;
 $92 = HEAP32[$91>>2]|0;
 $93 = (($90) + 4)|0;
 $94 = $93;
 $95 = HEAP32[$94>>2]|0;
 $96 = $__x4;
 $97 = $96;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($96) + 4)|0;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = $__x3;
 $103 = $102;
 HEAP32[$103>>2] = $98;
 $104 = (($102) + 4)|0;
 $105 = $104;
 HEAP32[$105>>2] = $101;
 $106 = $__x4;
 $107 = $106;
 HEAP32[$107>>2] = $92;
 $108 = (($106) + 4)|0;
 $109 = $108;
 HEAP32[$109>>2] = $95;
 $110 = (($__r$0$i) + 2)|0;
 $111 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__x3,$__x2)|0);
 if (!($111)) {
  $__r$0 = $110;
  STACKTOP = sp;return ($__r$0|0);
 }
 $112 = $__x2;
 $113 = $112;
 $114 = HEAP32[$113>>2]|0;
 $115 = (($112) + 4)|0;
 $116 = $115;
 $117 = HEAP32[$116>>2]|0;
 $118 = $__x3;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = (($118) + 4)|0;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = $__x2;
 $125 = $124;
 HEAP32[$125>>2] = $120;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $123;
 $128 = $__x3;
 $129 = $128;
 HEAP32[$129>>2] = $114;
 $130 = (($128) + 4)|0;
 $131 = $130;
 HEAP32[$131>>2] = $117;
 $132 = (($__r$0$i) + 3)|0;
 $133 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__c,$__x2,$__x1)|0);
 if (!($133)) {
  $__r$0 = $132;
  STACKTOP = sp;return ($__r$0|0);
 }
 $134 = $__x1;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = (($134) + 4)|0;
 $138 = $137;
 $139 = HEAP32[$138>>2]|0;
 $140 = $__x2;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $__x1;
 $147 = $146;
 HEAP32[$147>>2] = $142;
 $148 = (($146) + 4)|0;
 $149 = $148;
 HEAP32[$149>>2] = $145;
 $150 = $__x2;
 $151 = $150;
 HEAP32[$151>>2] = $136;
 $152 = (($150) + 4)|0;
 $153 = $152;
 HEAP32[$153>>2] = $139;
 $154 = (($__r$0$i) + 4)|0;
 $__r$0 = $154;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0;
 var $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 5:  {
  $88 = (($__first) + 8|0);
  $89 = (($__first) + 16|0);
  $90 = (($__first) + 24|0);
  $91 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_S7_S7_T_($__first,$88,$89,$90,$91,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -8|0);
  $5 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$4,$__first)|0);
  if (!($5)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $6 = $__first;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $4;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $__first;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $4;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $26 = (($__first) + 8|0);
  $27 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($__first,$26,$27,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $28 = (($__first) + 8|0);
  $29 = (($__first) + 16|0);
  $30 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($__first,$28,$29,$__comp)|0);
  $31 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$30,$29)|0);
  if (!($31)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $32 = $29;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $30;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 4)|0;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = $29;
  $45 = $44;
  HEAP32[$45>>2] = $40;
  $46 = (($44) + 4)|0;
  $47 = $46;
  HEAP32[$47>>2] = $43;
  $48 = $30;
  $49 = $48;
  HEAP32[$49>>2] = $34;
  $50 = (($48) + 4)|0;
  $51 = $50;
  HEAP32[$51>>2] = $37;
  $52 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$29,$28)|0);
  if (!($52)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $53 = $28;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($53) + 4)|0;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = $29;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) + 4)|0;
  $63 = $62;
  $64 = HEAP32[$63>>2]|0;
  $65 = $28;
  $66 = $65;
  HEAP32[$66>>2] = $61;
  $67 = (($65) + 4)|0;
  $68 = $67;
  HEAP32[$68>>2] = $64;
  $69 = $29;
  $70 = $69;
  HEAP32[$70>>2] = $55;
  $71 = (($69) + 4)|0;
  $72 = $71;
  HEAP32[$72>>2] = $58;
  $73 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$28,$__first)|0);
  if (!($73)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $74 = $__first;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + 4)|0;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = $__first;
  $81 = $80;
  HEAP32[$81>>2] = $61;
  $82 = (($80) + 4)|0;
  $83 = $82;
  HEAP32[$83>>2] = $64;
  $84 = $28;
  $85 = $84;
  HEAP32[$85>>2] = $76;
  $86 = (($84) + 4)|0;
  $87 = $86;
  HEAP32[$87>>2] = $79;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $92 = (($__first) + 16|0);
  $93 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb0EEEP10RPDataVLitEEjT0_S7_S7_T_($__first,$93,$92,$__comp)|0);
  $94 = (($__first) + 24|0);
  $95 = ($94|0)==($__last|0);
  if ($95) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $94;$__j$02 = $92;
  }
  while(1) {
   $96 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$__i$04,$__j$02)|0);
   if ($96) {
    $97 = $__i$04;
    $98 = $97;
    $99 = HEAP32[$98>>2]|0;
    $100 = (($97) + 4)|0;
    $101 = $100;
    $102 = HEAP32[$101>>2]|0;
    $103 = $__t;
    $104 = $103;
    HEAP32[$104>>2] = $99;
    $105 = (($103) + 4)|0;
    $106 = $105;
    HEAP32[$106>>2] = $102;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $107 = $__k$0;
     $108 = $107;
     $109 = HEAP32[$108>>2]|0;
     $110 = (($107) + 4)|0;
     $111 = $110;
     $112 = HEAP32[$111>>2]|0;
     $113 = $__j$1;
     $114 = $113;
     HEAP32[$114>>2] = $109;
     $115 = (($113) + 4)|0;
     $116 = $115;
     HEAP32[$116>>2] = $112;
     $117 = ($__k$0|0)==($__first|0);
     if ($117) {
      break;
     }
     $118 = (($__k$0) + -8|0);
     $119 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb0EEclERK10RPDataVLitS4_($__comp,$__t,$118)|0);
     if ($119) {
      $__j$1$phi = $__k$0;$__k$0 = $118;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $120 = $__t;
    $121 = $120;
    $122 = HEAP32[$121>>2]|0;
    $123 = (($120) + 4)|0;
    $124 = $123;
    $125 = HEAP32[$124>>2]|0;
    $126 = $__k$0;
    $127 = $126;
    HEAP32[$127>>2] = $122;
    $128 = (($126) + 4)|0;
    $129 = $128;
    HEAP32[$129>>2] = $125;
    $130 = (($__count$03) + 1)|0;
    $131 = ($130|0)==(8);
    if ($131) {
     break;
    } else {
     $__count$1 = $130;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $134 = (($__i$04) + 8|0);
   $135 = ($134|0)==($__last|0);
   if ($135) {
    $$0 = 1;
    label = 18;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $134;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 18) {
   STACKTOP = sp;return ($$0|0);
  }
  $132 = (($__i$04) + 8|0);
  $133 = ($132|0)==($__last|0);
  $$0 = $133;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16__sortIRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$02$i = 0, $__i$07 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__k$0$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 5:  {
    label = 11;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 54;
    break L1;
    break;
   }
   default: {
   }
   }
   $89 = ($3|0)<(248);
   if ($89) {
    label = 13;
    break L1;
   }
   $130 = ($3|0)>(7992);
   $131 = (($4|0) / 2)&-1;
   $132 = (($$0) + ($131<<3)|0);
   if ($130) {
    $133 = (($4|0) / 4)&-1;
    $134 = (($$0) + ($133<<3)|0);
    $$sum = (($133) + ($131))|0;
    $135 = (($$0) + ($$sum<<3)|0);
    $136 = (__ZNSt3__17__sort5IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_S7_S7_T_($$0,$134,$132,$135,$1,$__comp)|0);
    $__n_swaps$0 = $136;
   } else {
    $137 = (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($$0,$132,$1,$__comp)|0);
    $__n_swaps$0 = $137;
   }
   $138 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$$0,$132)|0);
   do {
    if ($138) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $139 = (($__j$0) + -8|0);
      $140 = ($$0|0)==($139|0);
      if ($140) {
       break;
      }
      $193 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$139,$132)|0);
      if ($193) {
       label = 37;
       break;
      } else {
       $__j$0 = $139;
      }
     }
     if ((label|0) == 37) {
      label = 0;
      $194 = $$0;
      $195 = $194;
      $196 = HEAP32[$195>>2]|0;
      $197 = (($194) + 4)|0;
      $198 = $197;
      $199 = HEAP32[$198>>2]|0;
      $200 = $139;
      $201 = $200;
      $202 = HEAP32[$201>>2]|0;
      $203 = (($200) + 4)|0;
      $204 = $203;
      $205 = HEAP32[$204>>2]|0;
      $206 = $$0;
      $207 = $206;
      HEAP32[$207>>2] = $202;
      $208 = (($206) + 4)|0;
      $209 = $208;
      HEAP32[$209>>2] = $205;
      $210 = $139;
      $211 = $210;
      HEAP32[$211>>2] = $196;
      $212 = (($210) + 4)|0;
      $213 = $212;
      HEAP32[$213>>2] = $199;
      $214 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $139;$__n_swaps$3 = $214;
      break;
     }
     $141 = (($$0) + 8|0);
     $142 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$$0,$1)|0);
     if ($142) {
      $__i$1 = $141;
     } else {
      $143 = ($141|0)==($1|0);
      if ($143) {
       label = 54;
       break L1;
      } else {
       $__i$07 = $141;
      }
      while(1) {
       $146 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$$0,$__i$07)|0);
       $145 = (($__i$07) + 8|0);
       if ($146) {
        break;
       }
       $144 = ($145|0)==($1|0);
       if ($144) {
        label = 54;
        break L1;
       } else {
        $__i$07 = $145;
       }
      }
      $147 = $__i$07;
      $148 = $147;
      $149 = HEAP32[$148>>2]|0;
      $150 = (($147) + 4)|0;
      $151 = $150;
      $152 = HEAP32[$151>>2]|0;
      $153 = $1;
      $154 = $153;
      $155 = HEAP32[$154>>2]|0;
      $156 = (($153) + 4)|0;
      $157 = $156;
      $158 = HEAP32[$157>>2]|0;
      $159 = $__i$07;
      $160 = $159;
      HEAP32[$160>>2] = $155;
      $161 = (($159) + 4)|0;
      $162 = $161;
      HEAP32[$162>>2] = $158;
      $163 = $1;
      $164 = $163;
      HEAP32[$164>>2] = $149;
      $165 = (($163) + 4)|0;
      $166 = $165;
      HEAP32[$166>>2] = $152;
      $__i$1 = $145;
     }
     $167 = ($__i$1|0)==($1|0);
     if ($167) {
      label = 54;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $168 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$$0,$__i$2)|0);
       $169 = (($__i$2) + 8|0);
       if ($168) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $169;
       }
      }
      while(1) {
       $170 = (($__j$2) + -8|0);
       $171 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$$0,$170)|0);
       if ($171) {
        $__j$2 = $170;
       } else {
        break;
       }
      }
      $172 = ($__i$2>>>0)<($170>>>0);
      if (!($172)) {
       $$0 = $__i$2;
       continue L3;
      }
      $173 = $__i$2;
      $174 = $173;
      $175 = HEAP32[$174>>2]|0;
      $176 = (($173) + 4)|0;
      $177 = $176;
      $178 = HEAP32[$177>>2]|0;
      $179 = $170;
      $180 = $179;
      $181 = HEAP32[$180>>2]|0;
      $182 = (($179) + 4)|0;
      $183 = $182;
      $184 = HEAP32[$183>>2]|0;
      $185 = $__i$2;
      $186 = $185;
      HEAP32[$186>>2] = $181;
      $187 = (($185) + 4)|0;
      $188 = $187;
      HEAP32[$188>>2] = $184;
      $189 = $170;
      $190 = $189;
      HEAP32[$190>>2] = $175;
      $191 = (($189) + 4)|0;
      $192 = $191;
      HEAP32[$192>>2] = $178;
      $__i$2$ph = $169;$__j$1$ph = $170;
     }
    }
   } while(0);
   $215 = (($$0) + 8|0);
   $216 = ($215>>>0)<($__j$3>>>0);
   L34: do {
    if ($216) {
     $__i$3$ph = $215;$__j$4$ph = $__j$3;$__m$0$ph = $132;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $217 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$__i$3,$__m$0$ph)|0);
       $218 = (($__i$3) + 8|0);
       if ($217) {
        $__i$3 = $218;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $219 = (($__j$5) + -8|0);
       $220 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$219,$__m$0$ph)|0);
       if ($220) {
        break;
       } else {
        $__j$5 = $219;
       }
      }
      $221 = ($__i$3>>>0)>($219>>>0);
      if ($221) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $222 = $__i$3;
      $223 = $222;
      $224 = HEAP32[$223>>2]|0;
      $225 = (($222) + 4)|0;
      $226 = $225;
      $227 = HEAP32[$226>>2]|0;
      $228 = $219;
      $229 = $228;
      $230 = HEAP32[$229>>2]|0;
      $231 = (($228) + 4)|0;
      $232 = $231;
      $233 = HEAP32[$232>>2]|0;
      $234 = $__i$3;
      $235 = $234;
      HEAP32[$235>>2] = $230;
      $236 = (($234) + 4)|0;
      $237 = $236;
      HEAP32[$237>>2] = $233;
      $238 = $219;
      $239 = $238;
      HEAP32[$239>>2] = $224;
      $240 = (($238) + 4)|0;
      $241 = $240;
      HEAP32[$241>>2] = $227;
      $242 = (($__n_swaps$4$ph) + 1)|0;
      $243 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $243 ? $219 : $__m$0$ph;
      $__i$3$ph = $218;$__j$4$ph = $219;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $242;
     }
    } else {
     $__i$4 = $215;$__m$2 = $132;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $244 = ($__i$4|0)==($__m$2|0);
   if ($244) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $245 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$__m$2,$__i$4)|0);
    if ($245) {
     $246 = $__i$4;
     $247 = $246;
     $248 = HEAP32[$247>>2]|0;
     $249 = (($246) + 4)|0;
     $250 = $249;
     $251 = HEAP32[$250>>2]|0;
     $252 = $__m$2;
     $253 = $252;
     $254 = HEAP32[$253>>2]|0;
     $255 = (($252) + 4)|0;
     $256 = $255;
     $257 = HEAP32[$256>>2]|0;
     $258 = $__i$4;
     $259 = $258;
     HEAP32[$259>>2] = $254;
     $260 = (($258) + 4)|0;
     $261 = $260;
     HEAP32[$261>>2] = $257;
     $262 = $__m$2;
     $263 = $262;
     HEAP32[$263>>2] = $248;
     $264 = (($262) + 4)|0;
     $265 = $264;
     HEAP32[$265>>2] = $251;
     $266 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $266;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $267 = ($__n_swaps$6|0)==(0);
   if ($267) {
    $268 = (__ZNSt3__127__insertion_sort_incompleteIRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEbT0_S7_T_($$0,$__i$4,$__comp)|0);
    $269 = (($__i$4) + 8|0);
    $270 = (__ZNSt3__127__insertion_sort_incompleteIRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEbT0_S7_T_($269,$$01$ph,$__comp)|0);
    if ($270) {
     label = 49;
     break;
    }
    if ($268) {
     $$0 = $269;
     continue;
    }
   }
   $271 = $__i$4;
   $272 = (($271) - ($2))|0;
   $273 = (($0) - ($271))|0;
   $274 = ($272|0)<($273|0);
   if (!($274)) {
    label = 53;
    break;
   }
   __ZNSt3__16__sortIRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEvT0_S7_T_($$0,$__i$4,$__comp);
   $275 = (($__i$4) + 8|0);
   $$0 = $275;
  }
  if ((label|0) == 49) {
   label = 0;
   if ($268) {
    label = 54;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 53) {
   label = 0;
   $276 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEvT0_S7_T_($276,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$1,$$0)|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = $$0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $1;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $$0;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $1;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $26 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($$0,$26,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $27 = (($$0) + 8|0);
  $28 = (($$0) + 16|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($$0,$27,$28,$__comp)|0);
  $29 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$1,$28)|0);
  if (!($29)) {
   STACKTOP = sp;return;
  }
  $30 = $28;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 4)|0;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = $1;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $28;
  $43 = $42;
  HEAP32[$43>>2] = $38;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $41;
  $46 = $1;
  $47 = $46;
  HEAP32[$47>>2] = $32;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $35;
  $50 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$28,$27)|0);
  if (!($50)) {
   STACKTOP = sp;return;
  }
  $51 = $27;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $28;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = (($57) + 4)|0;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = $27;
  $64 = $63;
  HEAP32[$64>>2] = $59;
  $65 = (($63) + 4)|0;
  $66 = $65;
  HEAP32[$66>>2] = $62;
  $67 = $28;
  $68 = $67;
  HEAP32[$68>>2] = $53;
  $69 = (($67) + 4)|0;
  $70 = $69;
  HEAP32[$70>>2] = $56;
  $71 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$27,$$0)|0);
  if (!($71)) {
   STACKTOP = sp;return;
  }
  $72 = $$0;
  $73 = $72;
  $74 = HEAP32[$73>>2]|0;
  $75 = (($72) + 4)|0;
  $76 = $75;
  $77 = HEAP32[$76>>2]|0;
  $78 = $$0;
  $79 = $78;
  HEAP32[$79>>2] = $59;
  $80 = (($78) + 4)|0;
  $81 = $80;
  HEAP32[$81>>2] = $62;
  $82 = $27;
  $83 = $82;
  HEAP32[$83>>2] = $74;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $77;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  $86 = (($$0) + 8|0);
  $87 = (($$0) + 16|0);
  $88 = (($$0) + 24|0);
  (__ZNSt3__17__sort5IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_S7_S7_T_($$0,$86,$87,$88,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 13) {
  $90 = (($$0) + 16|0);
  $91 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($$0,$91,$90,$__comp)|0);
  $92 = (($$0) + 24|0);
  $93 = ($92|0)==($$01$ph|0);
  if ($93) {
   STACKTOP = sp;return;
  } else {
   $__i$02$i = $92;$__j$01$i = $90;
  }
  while(1) {
   $94 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$__i$02$i,$__j$01$i)|0);
   if ($94) {
    $95 = $__i$02$i;
    $96 = $95;
    $97 = HEAP32[$96>>2]|0;
    $98 = (($95) + 4)|0;
    $99 = $98;
    $100 = HEAP32[$99>>2]|0;
    $101 = $__t$i;
    $102 = $101;
    HEAP32[$102>>2] = $97;
    $103 = (($101) + 4)|0;
    $104 = $103;
    HEAP32[$104>>2] = $100;
    $__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     $105 = $__k$0$i;
     $106 = $105;
     $107 = HEAP32[$106>>2]|0;
     $108 = (($105) + 4)|0;
     $109 = $108;
     $110 = HEAP32[$109>>2]|0;
     $111 = $__j$1$i;
     $112 = $111;
     HEAP32[$112>>2] = $107;
     $113 = (($111) + 4)|0;
     $114 = $113;
     HEAP32[$114>>2] = $110;
     $115 = ($__k$0$i|0)==($$0|0);
     if ($115) {
      break;
     }
     $116 = (($__k$0$i) + -8|0);
     $117 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$__t$i,$116)|0);
     if ($117) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $116;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $118 = $__t$i;
    $119 = $118;
    $120 = HEAP32[$119>>2]|0;
    $121 = (($118) + 4)|0;
    $122 = $121;
    $123 = HEAP32[$122>>2]|0;
    $124 = $__k$0$i;
    $125 = $124;
    HEAP32[$125>>2] = $120;
    $126 = (($124) + 4)|0;
    $127 = $126;
    HEAP32[$127>>2] = $123;
   }
   $128 = (($__i$02$i) + 8|0);
   $129 = ($128|0)==($$01$ph|0);
   if ($129) {
    break;
   } else {
    $__j$01$i$phi = $__i$02$i;$__i$02$i = $128;$__j$01$i = $__j$01$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 54) {
  STACKTOP = sp;return;
 }
}
function __ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($this,$ra,$rb) {
 $this = $this|0;
 $ra = $ra|0;
 $rb = $rb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$ra>>2]|0;
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$rb>>2]|0;
 $6 = ((($4) + (($3*44)|0)|0) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($4) + (($5*44)|0)|0) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if (!($10)) {
  $11 = ($7>>>0)<($9>>>0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ((($4) + (($3*44)|0)|0) + 4|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = ((($4) + (($5*44)|0)|0) + 4|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = ($13<<16>>16)==($15<<16>>16);
 if (!($16)) {
  $17 = ($13<<16>>16)<($15<<16>>16);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($ra) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($rb) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $19 & 65536;
 $23 = $21 & 65536;
 $24 = ($22|0)==($23|0);
 if (!($24)) {
  $25 = ($22>>>0)>($23>>>0);
  $$0 = $25;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = ((($4) + (($3*44)|0)|0) + 12|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = ((($4) + (($5*44)|0)|0) + 12|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = ($27<<16>>16)==($29<<16>>16);
 if (!($30)) {
  $31 = ($27&65535)<($29&65535);
  $$0 = $31;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = ((($4) + (($3*44)|0)|0) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($4) + (($5*44)|0)|0) + 20|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)==($35|0);
 if (!($36)) {
  $37 = ($33|0)<($35|0);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = (($4) + (($3*44)|0)|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($4) + (($5*44)|0)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)==($41|0);
 if (!($42)) {
  $43 = (($39) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($41) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($44|0)<($46|0);
  $$0 = $47;
  STACKTOP = sp;return ($$0|0);
 }
 $48 = $19 & 255;
 $49 = $21 & 255;
 $50 = ($48|0)==($49|0);
 if (!($50)) {
  $51 = ($48>>>0)<($49>>>0);
  $$0 = $51;
  STACKTOP = sp;return ($$0|0);
 }
 $52 = ((($4) + (($3*44)|0)|0) + 24|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = ((($4) + (($5*44)|0)|0) + 24|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = $53 != $55;
 if ($56) {
  $57 = $53 > $55;
  $$0 = $57;
  STACKTOP = sp;return ($$0|0);
 }
 $58 = ((($4) + (($3*44)|0)|0) + 16|0);
 $59 = HEAP16[$58>>1]|0;
 $60 = ((($4) + (($5*44)|0)|0) + 16|0);
 $61 = HEAP16[$60>>1]|0;
 $62 = ($59<<16>>16)==($61<<16>>16);
 if ($62) {
  $64 = ($3|0)<($5|0);
  $$0 = $64;
  STACKTOP = sp;return ($$0|0);
 } else {
  $63 = ($59&65535)>($61&65535);
  $$0 = $63;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__y,$__x)|0);
 $1 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__z,$__y)|0);
 if (!($0)) {
  if (!($1)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $2 = $__y;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__z;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__y;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__z;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__y,$__x)|0);
  if (!($22)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $23 = $__x;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $__y;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 4)|0;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = $__x;
  $36 = $35;
  HEAP32[$36>>2] = $31;
  $37 = (($35) + 4)|0;
  $38 = $37;
  HEAP32[$38>>2] = $34;
  $39 = $__y;
  $40 = $39;
  HEAP32[$40>>2] = $25;
  $41 = (($39) + 4)|0;
  $42 = $41;
  HEAP32[$42>>2] = $28;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = $__x;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 if ($1) {
  $49 = $__z;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $__x;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = $__z;
  $60 = $59;
  HEAP32[$60>>2] = $45;
  $61 = (($59) + 4)|0;
  $62 = $61;
  HEAP32[$62>>2] = $48;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = $__y;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $__x;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $__y;
 $74 = $73;
 HEAP32[$74>>2] = $45;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $48;
 $77 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__z,$__y)|0);
 if (!($77)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = $__z;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__y;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__z;
 $89 = $88;
 HEAP32[$89>>2] = $45;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $48;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort5IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__r$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__x4,$__x3)|0);
 if ($1) {
  $2 = $__x3;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__x4;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__x3;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__x4;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (($0) + 1)|0;
  $23 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__x3,$__x2)|0);
  if ($23) {
   $24 = $__x2;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 4)|0;
   $28 = $27;
   $29 = HEAP32[$28>>2]|0;
   $30 = $__x3;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $__x2;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
   $40 = $__x3;
   $41 = $40;
   HEAP32[$41>>2] = $26;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $29;
   $44 = (($0) + 2)|0;
   $45 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__x2,$__x1)|0);
   if ($45) {
    $46 = $__x1;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4)|0;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = $__x2;
    $53 = $52;
    $54 = HEAP32[$53>>2]|0;
    $55 = (($52) + 4)|0;
    $56 = $55;
    $57 = HEAP32[$56>>2]|0;
    $58 = $__x1;
    $59 = $58;
    HEAP32[$59>>2] = $54;
    $60 = (($58) + 4)|0;
    $61 = $60;
    HEAP32[$61>>2] = $57;
    $62 = $__x2;
    $63 = $62;
    HEAP32[$63>>2] = $48;
    $64 = (($62) + 4)|0;
    $65 = $64;
    HEAP32[$65>>2] = $51;
    $66 = (($0) + 3)|0;
    $__r$0$i = $66;
   } else {
    $__r$0$i = $44;
   }
  } else {
   $__r$0$i = $22;
  }
 } else {
  $__r$0$i = $0;
 }
 $67 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__x5,$__x4)|0);
 if (!($67)) {
  $__r$0 = $__r$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $68 = $__x4;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = $__x5;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = (($74) + 4)|0;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = $__x4;
 $81 = $80;
 HEAP32[$81>>2] = $76;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $79;
 $84 = $__x5;
 $85 = $84;
 HEAP32[$85>>2] = $70;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $73;
 $88 = (($__r$0$i) + 1)|0;
 $89 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__x4,$__x3)|0);
 if (!($89)) {
  $__r$0 = $88;
  STACKTOP = sp;return ($__r$0|0);
 }
 $90 = $__x3;
 $91 = $90;
 $92 = HEAP32[$91>>2]|0;
 $93 = (($90) + 4)|0;
 $94 = $93;
 $95 = HEAP32[$94>>2]|0;
 $96 = $__x4;
 $97 = $96;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($96) + 4)|0;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = $__x3;
 $103 = $102;
 HEAP32[$103>>2] = $98;
 $104 = (($102) + 4)|0;
 $105 = $104;
 HEAP32[$105>>2] = $101;
 $106 = $__x4;
 $107 = $106;
 HEAP32[$107>>2] = $92;
 $108 = (($106) + 4)|0;
 $109 = $108;
 HEAP32[$109>>2] = $95;
 $110 = (($__r$0$i) + 2)|0;
 $111 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__x3,$__x2)|0);
 if (!($111)) {
  $__r$0 = $110;
  STACKTOP = sp;return ($__r$0|0);
 }
 $112 = $__x2;
 $113 = $112;
 $114 = HEAP32[$113>>2]|0;
 $115 = (($112) + 4)|0;
 $116 = $115;
 $117 = HEAP32[$116>>2]|0;
 $118 = $__x3;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = (($118) + 4)|0;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = $__x2;
 $125 = $124;
 HEAP32[$125>>2] = $120;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $123;
 $128 = $__x3;
 $129 = $128;
 HEAP32[$129>>2] = $114;
 $130 = (($128) + 4)|0;
 $131 = $130;
 HEAP32[$131>>2] = $117;
 $132 = (($__r$0$i) + 3)|0;
 $133 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__c,$__x2,$__x1)|0);
 if (!($133)) {
  $__r$0 = $132;
  STACKTOP = sp;return ($__r$0|0);
 }
 $134 = $__x1;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = (($134) + 4)|0;
 $138 = $137;
 $139 = HEAP32[$138>>2]|0;
 $140 = $__x2;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $__x1;
 $147 = $146;
 HEAP32[$147>>2] = $142;
 $148 = (($146) + 4)|0;
 $149 = $148;
 HEAP32[$149>>2] = $145;
 $150 = $__x2;
 $151 = $150;
 HEAP32[$151>>2] = $136;
 $152 = (($150) + 4)|0;
 $153 = $152;
 HEAP32[$153>>2] = $139;
 $154 = (($__r$0$i) + 4)|0;
 $__r$0 = $154;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0;
 var $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 5:  {
  $88 = (($__first) + 8|0);
  $89 = (($__first) + 16|0);
  $90 = (($__first) + 24|0);
  $91 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_S7_S7_T_($__first,$88,$89,$90,$91,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $28 = (($__first) + 8|0);
  $29 = (($__first) + 16|0);
  $30 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($__first,$28,$29,$__comp)|0);
  $31 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$30,$29)|0);
  if (!($31)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $32 = $29;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $30;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 4)|0;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = $29;
  $45 = $44;
  HEAP32[$45>>2] = $40;
  $46 = (($44) + 4)|0;
  $47 = $46;
  HEAP32[$47>>2] = $43;
  $48 = $30;
  $49 = $48;
  HEAP32[$49>>2] = $34;
  $50 = (($48) + 4)|0;
  $51 = $50;
  HEAP32[$51>>2] = $37;
  $52 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$29,$28)|0);
  if (!($52)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $53 = $28;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($53) + 4)|0;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = $29;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) + 4)|0;
  $63 = $62;
  $64 = HEAP32[$63>>2]|0;
  $65 = $28;
  $66 = $65;
  HEAP32[$66>>2] = $61;
  $67 = (($65) + 4)|0;
  $68 = $67;
  HEAP32[$68>>2] = $64;
  $69 = $29;
  $70 = $69;
  HEAP32[$70>>2] = $55;
  $71 = (($69) + 4)|0;
  $72 = $71;
  HEAP32[$72>>2] = $58;
  $73 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$28,$__first)|0);
  if (!($73)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $74 = $__first;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + 4)|0;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = $__first;
  $81 = $80;
  HEAP32[$81>>2] = $61;
  $82 = (($80) + 4)|0;
  $83 = $82;
  HEAP32[$83>>2] = $64;
  $84 = $28;
  $85 = $84;
  HEAP32[$85>>2] = $76;
  $86 = (($84) + 4)|0;
  $87 = $86;
  HEAP32[$87>>2] = $79;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $26 = (($__first) + 8|0);
  $27 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($__first,$26,$27,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -8|0);
  $5 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$4,$__first)|0);
  if (!($5)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $6 = $__first;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $4;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $__first;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $4;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $92 = (($__first) + 16|0);
  $93 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRN23ForwardVertexRenderLoop18RenderObjectSorterILb1EEEP10RPDataVLitEEjT0_S7_S7_T_($__first,$93,$92,$__comp)|0);
  $94 = (($__first) + 24|0);
  $95 = ($94|0)==($__last|0);
  if ($95) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $94;$__j$02 = $92;
  }
  while(1) {
   $96 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$__i$04,$__j$02)|0);
   if ($96) {
    $97 = $__i$04;
    $98 = $97;
    $99 = HEAP32[$98>>2]|0;
    $100 = (($97) + 4)|0;
    $101 = $100;
    $102 = HEAP32[$101>>2]|0;
    $103 = $__t;
    $104 = $103;
    HEAP32[$104>>2] = $99;
    $105 = (($103) + 4)|0;
    $106 = $105;
    HEAP32[$106>>2] = $102;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $107 = $__k$0;
     $108 = $107;
     $109 = HEAP32[$108>>2]|0;
     $110 = (($107) + 4)|0;
     $111 = $110;
     $112 = HEAP32[$111>>2]|0;
     $113 = $__j$1;
     $114 = $113;
     HEAP32[$114>>2] = $109;
     $115 = (($113) + 4)|0;
     $116 = $115;
     HEAP32[$116>>2] = $112;
     $117 = ($__k$0|0)==($__first|0);
     if ($117) {
      break;
     }
     $118 = (($__k$0) + -8|0);
     $119 = (__ZNK23ForwardVertexRenderLoop18RenderObjectSorterILb1EEclERK10RPDataVLitS4_($__comp,$__t,$118)|0);
     if ($119) {
      $__j$1$phi = $__k$0;$__k$0 = $118;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $120 = $__t;
    $121 = $120;
    $122 = HEAP32[$121>>2]|0;
    $123 = (($120) + 4)|0;
    $124 = $123;
    $125 = HEAP32[$124>>2]|0;
    $126 = $__k$0;
    $127 = $126;
    HEAP32[$127>>2] = $122;
    $128 = (($126) + 4)|0;
    $129 = $128;
    HEAP32[$129>>2] = $125;
    $130 = (($__count$03) + 1)|0;
    $131 = ($130|0)==(8);
    if ($131) {
     break;
    } else {
     $__count$1 = $130;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $134 = (($__i$04) + 8|0);
   $135 = ($134|0)==($__last|0);
   if ($135) {
    $$0 = 1;
    label = 18;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $134;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 18) {
   STACKTOP = sp;return ($$0|0);
  }
  $132 = (($__i$04) + 8|0);
  $133 = ($132|0)==($__last|0);
  $$0 = $133;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __Z31ResolveDepthIntoTextureIfNeededR9GfxDeviceR10RenderLoop17DepthBufferFormatRP13RenderTextureP9TextureIDPb($device,$renderLoop,$depthFormat,$outDepthRT,$outDepthTextureID,$outDepthWasCopied) {
 $device = $device|0;
 $renderLoop = $renderLoop|0;
 $depthFormat = $depthFormat|0;
 $outDepthRT = $outDepthRT|0;
 $outDepthTextureID = $outDepthTextureID|0;
 $outDepthWasCopied = $outDepthWasCopied|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = (($device) + 5928|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(11);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (__Z22GetRenderBufferManagerv()|0);
 $6 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($5,-1,-1,$depthFormat,1,4,1,1)|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 4095]($6,568232);
 }
 __ZN7Texture13SetFilterModeEi($6,0);
 $11 = (($6) + 140|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 $14 = (($6) + 148|0);
 if ($13) {
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   (__ZN13RenderTexture6CreateEv($6)|0);
  }
 }
 __Z23AddRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureTypeP13RenderTexture($renderLoop,6,$6);
 $17 = HEAP32[$device>>2]|0;
 $18 = (($17) + 416|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$11>>2]|0;
 HEAP32[$0>>2] = $20;
 $21 = HEAP32[$14>>2]|0;
 HEAP32[$1>>2] = $21;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_viii[$19 & 4095]($device,$$byval_copy,$$byval_copy1);
 HEAP32[$outDepthRT>>2] = $6;
 $22 = (($6) + 44|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$outDepthTextureID>>2] = $23;
 HEAP8[$outDepthWasCopied>>0] = 1;
 STACKTOP = sp;return;
}
function __Z9LightMaskRK5LightRK14LightingLayers($l,$lightingLayers) {
 $l = $l|0;
 $lightingLayers = $lightingLayers|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bit$02 = 0, $lightExcludeLayers$01 = 0, $mask$0$lcssa = 0, $mask$03 = 0, $mask$1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($l) + 180|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $mask$0$lcssa = 0;
  STACKTOP = sp;return ($mask$0$lcssa|0);
 }
 $3 = $1 ^ -1;
 $bit$02 = 0;$lightExcludeLayers$01 = $3;$mask$03 = 0;
 while(1) {
  $4 = $lightExcludeLayers$01 & 1;
  $5 = ($4|0)==(0);
  if ($5) {
   $mask$1 = $mask$03;
  } else {
   $6 = ((($lightingLayers) + ($bit$02<<2)|0) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(-1);
   if ($8) {
    $mask$1 = $mask$03;
   } else {
    $9 = 1 << $7;
    $10 = $9 | $mask$03;
    $mask$1 = $10;
   }
  }
  $11 = $lightExcludeLayers$01 >>> 1;
  $12 = (($bit$02) + 1)|0;
  $13 = ($11|0)==(0);
  if ($13) {
   $mask$0$lcssa = $mask$1;
   break;
  } else {
   $bit$02 = $12;$lightExcludeLayers$01 = $11;$mask$03 = $mask$1;
  }
 }
 STACKTOP = sp;return ($mask$0$lcssa|0);
}
function __Z23CalculateLightingLayersv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $layers$0$ = 0, $layers$0$lcssa = 0, $layers$01 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetLightManagerv()|0);
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  $layers$0$lcssa = 0;
  STACKTOP = sp;return ($layers$0$lcssa|0);
 } else {
  $5 = $2;$layers$01 = -1;
 }
 while(1) {
  $4 = (($5) + 148|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = ($6|0)==(0);
  $8 = $7 ? -1 : $6;
  $layers$0$ = $8 & $layers$01;
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($0|0);
  if ($11) {
   break;
  } else {
   $5 = $10;$layers$01 = $layers$0$;
  }
 }
 $phitmp = $layers$0$ ^ -1;
 $layers$0$lcssa = $phitmp;
 STACKTOP = sp;return ($layers$0$lcssa|0);
}
function __Z15RenderLightGeomRK17RenderLoopContextRK11ActiveLightRK8Vector3fRK10Matrix4x4fbPK14ChannelAssigns($ctx,$light,$lightPos,$lightMatrix,$renderAsQuad,$channels) {
 $ctx = $ctx|0;
 $light = $light|0;
 $lightPos = $lightPos|0;
 $lightMatrix = $lightMatrix|0;
 $renderAsQuad = $renderAsQuad|0;
 $channels = $channels|0;
 var $$not = 0, $$not1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0);
 var $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0);
 var $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0);
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0;
 var $brmerge2 = 0, $m = 0, $pos$i$i$i$i9 = 0, $ray1 = 0, $ray2 = 0, $ray3 = 0, $ray4 = 0, $temp$0$i$sink = 0, $temp$0$i13 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $pos$i$i$i$i9 = sp + 320|0;
 $0 = sp + 280|0;
 $1 = sp + 216|0;
 $2 = sp + 176|0;
 $m = sp + 112|0;
 $3 = sp + 96|0;
 $ray1 = sp + 84|0;
 $4 = sp + 72|0;
 $ray2 = sp + 48|0;
 $5 = sp + 36|0;
 $ray3 = sp + 24|0;
 $6 = sp + 12|0;
 $ray4 = sp;
 $7 = sp + 60|0;
 $8 = (__Z12GetGfxDevicev()|0);
 $9 = HEAP32[$light>>2]|0;
 $10 = (($9) + 188|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = HEAP32[$ctx>>2]|0;
 $13 = (Math_fround(__ZNK6Camera17GetProjectionNearEv($12)));
 $14 = Math_fround($13 * Math_fround(1.00100004673004150391));
 $15 = (($9) + 216|0);
 $16 = HEAP32[$15>>2]|0;
 $$not = ($16|0)!=(2);
 $brmerge = $$not | $renderAsQuad;
 if (!($brmerge)) {
  __ZN14ChannelAssignsC2Ev($0);
  __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($0,0,0);
  __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($0,1,2);
  (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($m,$lightPos)|0);
  HEAPF32[$m>>2] = $11;
  $17 = (($m) + 20|0);
  HEAPF32[$17>>2] = $11;
  $18 = (($m) + 40|0);
  HEAPF32[$18>>2] = $11;
  $19 = (($light) + 60|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = $20 > Math_fround(0.25);
  do {
   if ($21) {
    $22 = HEAP32[568216>>2]|0;
    HEAP32[$2>>2] = $22;
    $23 = HEAP32[560624>>2]|0;
    $24 = ($23|0)==(0|0);
    if (!($24)) {
     $25 = (($23) + 36|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($23) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($26|0)==($28|0);
     do {
      if ($29) {
       $30 = (($23) + 28|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = (($23) + 32|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = (($31) + ($33<<3)|0);
       $50 = $34;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i9,$23,$2);
       $35 = HEAP32[$pos$i$i$i$i9>>2]|0;
       $36 = ($35|0)==(-1);
       $37 = (($23) + 28|0);
       $38 = HEAP32[$37>>2]|0;
       if ($36) {
        $39 = (($23) + 32|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = (($38) + ($40<<3)|0);
        $50 = $41;
        break;
       } else {
        $42 = (($38) + ($35<<3)|0);
        $50 = $42;
        break;
       }
      }
     } while(0);
     $43 = HEAP32[560624>>2]|0;
     $44 = (($43) + 28|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($43) + 32|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (($45) + ($47<<3)|0);
     $49 = ($50|0)==($48|0);
     if (!($49)) {
      $51 = (($50) + 4|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = ($52|0)==(0|0);
      if (!($53)) {
       $temp$0$i$sink = $52;
       break;
      }
     }
    }
    $54 = HEAP32[568216>>2]|0;
    $55 = (__Z31ReadObjectFromPersistentManageri($54)|0);
    $temp$0$i$sink = $55;
   } else {
    $56 = HEAP32[568208>>2]|0;
    HEAP32[$1>>2] = $56;
    $57 = HEAP32[560624>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = (($57) + 36|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (($57) + 4|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($60|0)==($62|0);
     do {
      if ($63) {
       $64 = (($57) + 28|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = (($57) + 32|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($65) + ($67<<3)|0);
       $84 = $68;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i9,$57,$1);
       $69 = HEAP32[$pos$i$i$i$i9>>2]|0;
       $70 = ($69|0)==(-1);
       $71 = (($57) + 28|0);
       $72 = HEAP32[$71>>2]|0;
       if ($70) {
        $73 = (($57) + 32|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = (($72) + ($74<<3)|0);
        $84 = $75;
        break;
       } else {
        $76 = (($72) + ($69<<3)|0);
        $84 = $76;
        break;
       }
      }
     } while(0);
     $77 = HEAP32[560624>>2]|0;
     $78 = (($77) + 28|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($77) + 32|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($79) + ($81<<3)|0);
     $83 = ($84|0)==($82|0);
     if (!($83)) {
      $85 = (($84) + 4|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = ($86|0)==(0|0);
      if (!($87)) {
       $temp$0$i$sink = $86;
       break;
      }
     }
    }
    $88 = HEAP32[568208>>2]|0;
    $89 = (__Z31ReadObjectFromPersistentManageri($88)|0);
    $temp$0$i$sink = $89;
   }
  } while(0);
  __ZN8DrawUtil8DrawMeshERK14ChannelAssignsR4MeshRK10Matrix4x4fi($0,$temp$0$i$sink,$m,-1);
  STACKTOP = sp;return;
 }
 $$not1 = ($16|0)!=(0);
 $brmerge2 = $$not1 | $renderAsQuad;
 if (!($brmerge2)) {
  dest=$1+0|0; src=$lightMatrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  __ZN14ChannelAssignsC2Ev($2);
  __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($2,0,0);
  __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($2,1,2);
  $90 = (($9) + 200|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($11 / $91);
  HEAPF32[$3>>2] = $92;
  $93 = (($3) + 4|0);
  HEAPF32[$93>>2] = $92;
  $94 = (($3) + 8|0);
  HEAPF32[$94>>2] = $11;
  (__ZN10Matrix4x4f5ScaleERK8Vector3f($1,$3)|0);
  $95 = HEAP32[568224>>2]|0;
  HEAP32[$0>>2] = $95;
  $96 = HEAP32[560624>>2]|0;
  $97 = ($96|0)==(0|0);
  if ($97) {
   label = 31;
  } else {
   $98 = (($96) + 36|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (($96) + 4|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($99|0)==($101|0);
   do {
    if ($102) {
     $103 = (($96) + 28|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = (($96) + 32|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = (($104) + ($106<<3)|0);
     $123 = $107;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i9,$96,$0);
     $108 = HEAP32[$pos$i$i$i$i9>>2]|0;
     $109 = ($108|0)==(-1);
     $110 = (($96) + 28|0);
     $111 = HEAP32[$110>>2]|0;
     if ($109) {
      $112 = (($96) + 32|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = (($111) + ($113<<3)|0);
      $123 = $114;
      break;
     } else {
      $115 = (($111) + ($108<<3)|0);
      $123 = $115;
      break;
     }
    }
   } while(0);
   $116 = HEAP32[560624>>2]|0;
   $117 = (($116) + 28|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($116) + 32|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = (($118) + ($120<<3)|0);
   $122 = ($123|0)==($121|0);
   if ($122) {
    label = 31;
   } else {
    $124 = (($123) + 4|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ($125|0)==(0|0);
    if ($126) {
     label = 31;
    } else {
     $temp$0$i13 = $125;
    }
   }
  }
  if ((label|0) == 31) {
   $127 = HEAP32[568224>>2]|0;
   $128 = (__Z31ReadObjectFromPersistentManageri($127)|0);
   $temp$0$i13 = $128;
  }
  __ZN8DrawUtil8DrawMeshERK14ChannelAssignsR4MeshRK10Matrix4x4fi($2,$temp$0$i13,$1,-1);
  STACKTOP = sp;return;
 }
 __ZN27DeviceViewProjMatricesStateC2Ev($pos$i$i$i$i9);
 $129 = HEAP32[$ctx>>2]|0;
 $130 = (($light) + 48|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($light) + 56|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($131 + $133);
 $135 = (($light) + 52|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($light) + 60|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($136 + $138);
 HEAPF32[$4>>2] = $131;
 $140 = (($4) + 4|0);
 HEAPF32[$140>>2] = $136;
 $141 = (($4) + 8|0);
 HEAPF32[$141>>2] = $14;
 __THREW__ = 0;
 invoke_viii(1665,($ray1|0),($129|0),($4|0));
 $142 = __THREW__; __THREW__ = 0;
 $143 = $142&1;
 if (!($143)) {
  HEAPF32[$5>>2] = $131;
  $144 = (($5) + 4|0);
  HEAPF32[$144>>2] = $139;
  $145 = (($5) + 8|0);
  HEAPF32[$145>>2] = $14;
  __THREW__ = 0;
  invoke_viii(1665,($ray2|0),($129|0),($5|0));
  $146 = __THREW__; __THREW__ = 0;
  $147 = $146&1;
  if (!($147)) {
   HEAPF32[$6>>2] = $134;
   $148 = (($6) + 4|0);
   HEAPF32[$148>>2] = $139;
   $149 = (($6) + 8|0);
   HEAPF32[$149>>2] = $14;
   __THREW__ = 0;
   invoke_viii(1665,($ray3|0),($129|0),($6|0));
   $150 = __THREW__; __THREW__ = 0;
   $151 = $150&1;
   if (!($151)) {
    HEAPF32[$7>>2] = $134;
    $152 = (($7) + 4|0);
    HEAPF32[$152>>2] = $136;
    $153 = (($7) + 8|0);
    HEAPF32[$153>>2] = $14;
    __THREW__ = 0;
    invoke_viii(1665,($ray4|0),($129|0),($7|0));
    $154 = __THREW__; __THREW__ = 0;
    $155 = $154&1;
    if (!($155)) {
     __THREW__ = 0;
     $156 = (Math_fround(+(invoke_fi(225,($129|0)))));
     $157 = __THREW__; __THREW__ = 0;
     $158 = $157&1;
     if (!($158)) {
      __THREW__ = 0;
      invoke_vffi(1,0.0,(+$156),1);
      $159 = __THREW__; __THREW__ = 0;
      $160 = $159&1;
      if (!($160)) {
       $161 = HEAP32[$8>>2]|0;
       $162 = (($161) + 580|0);
       $163 = HEAP32[$162>>2]|0;
       __THREW__ = 0;
       invoke_viii($163|0,($8|0),2,($channels|0));
       $164 = __THREW__; __THREW__ = 0;
       $165 = $164&1;
       if (!($165)) {
        $166 = HEAP32[$8>>2]|0;
        $167 = (($166) + 564|0);
        $168 = HEAP32[$167>>2]|0;
        $169 = Math_fround(HEAPF32[$ray1>>2]);
        $170 = (($ray1) + 4|0);
        $171 = Math_fround(HEAPF32[$170>>2]);
        $172 = (($ray1) + 8|0);
        $173 = Math_fround(HEAPF32[$172>>2]);
        __THREW__ = 0;
        invoke_vifff($168|0,($8|0),(+$169),(+$171),(+$173));
        $174 = __THREW__; __THREW__ = 0;
        $175 = $174&1;
        if (!($175)) {
         $176 = HEAP32[$8>>2]|0;
         $177 = (($176) + 560|0);
         $178 = HEAP32[$177>>2]|0;
         __THREW__ = 0;
         invoke_vifff($178|0,($8|0),(+$131),(+$136),0.0);
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if (!($180)) {
          $181 = HEAP32[$8>>2]|0;
          $182 = (($181) + 564|0);
          $183 = HEAP32[$182>>2]|0;
          $184 = Math_fround(HEAPF32[$ray2>>2]);
          $185 = (($ray2) + 4|0);
          $186 = Math_fround(HEAPF32[$185>>2]);
          $187 = (($ray2) + 8|0);
          $188 = Math_fround(HEAPF32[$187>>2]);
          __THREW__ = 0;
          invoke_vifff($183|0,($8|0),(+$184),(+$186),(+$188));
          $189 = __THREW__; __THREW__ = 0;
          $190 = $189&1;
          if (!($190)) {
           $191 = HEAP32[$8>>2]|0;
           $192 = (($191) + 560|0);
           $193 = HEAP32[$192>>2]|0;
           __THREW__ = 0;
           invoke_vifff($193|0,($8|0),(+$131),(+$139),0.0);
           $194 = __THREW__; __THREW__ = 0;
           $195 = $194&1;
           if (!($195)) {
            $196 = HEAP32[$8>>2]|0;
            $197 = (($196) + 564|0);
            $198 = HEAP32[$197>>2]|0;
            $199 = Math_fround(HEAPF32[$ray3>>2]);
            $200 = (($ray3) + 4|0);
            $201 = Math_fround(HEAPF32[$200>>2]);
            $202 = (($ray3) + 8|0);
            $203 = Math_fround(HEAPF32[$202>>2]);
            __THREW__ = 0;
            invoke_vifff($198|0,($8|0),(+$199),(+$201),(+$203));
            $204 = __THREW__; __THREW__ = 0;
            $205 = $204&1;
            if (!($205)) {
             $206 = HEAP32[$8>>2]|0;
             $207 = (($206) + 560|0);
             $208 = HEAP32[$207>>2]|0;
             __THREW__ = 0;
             invoke_vifff($208|0,($8|0),(+$134),(+$139),0.0);
             $209 = __THREW__; __THREW__ = 0;
             $210 = $209&1;
             if (!($210)) {
              $211 = HEAP32[$8>>2]|0;
              $212 = (($211) + 564|0);
              $213 = HEAP32[$212>>2]|0;
              $214 = Math_fround(HEAPF32[$ray4>>2]);
              $215 = (($ray4) + 4|0);
              $216 = Math_fround(HEAPF32[$215>>2]);
              $217 = (($ray4) + 8|0);
              $218 = Math_fround(HEAPF32[$217>>2]);
              __THREW__ = 0;
              invoke_vifff($213|0,($8|0),(+$214),(+$216),(+$218));
              $219 = __THREW__; __THREW__ = 0;
              $220 = $219&1;
              if (!($220)) {
               $221 = HEAP32[$8>>2]|0;
               $222 = (($221) + 560|0);
               $223 = HEAP32[$222>>2]|0;
               __THREW__ = 0;
               invoke_vifff($223|0,($8|0),(+$134),(+$136),0.0);
               $224 = __THREW__; __THREW__ = 0;
               $225 = $224&1;
               if (!($225)) {
                $226 = HEAP32[$8>>2]|0;
                $227 = (($226) + 584|0);
                $228 = HEAP32[$227>>2]|0;
                __THREW__ = 0;
                invoke_vi($228|0,($8|0));
                $229 = __THREW__; __THREW__ = 0;
                $230 = $229&1;
                if (!($230)) {
                 __ZN27DeviceViewProjMatricesStateD2Ev($pos$i$i$i$i9);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $231 = ___cxa_find_matching_catch()|0;
 $232 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3404,($pos$i$i$i$i9|0));
 $233 = __THREW__; __THREW__ = 0;
 $234 = $233&1;
 if ($234) {
  $235 = ___cxa_find_matching_catch(0|0)|0;
  $236 = tempRet0;
  ___clang_call_terminate($235);
  // unreachable;
 } else {
  ___resumeException($231|0);
  // unreachable;
 }
}
function __Z15InitLightMeshesv() {
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $phitmp$i = 0, $phitmp$i26 = 0, $phitmp$i9 = 0, $pos$i$i$i$i21 = 0, $storemerge = 0, $storemerge44 = 0, $storemerge45 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i$i21 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 24|0;
 $5 = sp + 36|0;
 $6 = HEAP32[568208>>2]|0;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   label = 11;
  } else {
   HEAP32[$2>>2] = $6;
   $8 = HEAP32[560624>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = (($8) + 36|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($8) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    do {
     if ($14) {
      $15 = (($8) + 28|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($8) + 32|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($16) + ($18<<3)|0);
      $35 = $19;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i21,$8,$2);
      $20 = HEAP32[$pos$i$i$i$i21>>2]|0;
      $21 = ($20|0)==(-1);
      $22 = (($8) + 28|0);
      $23 = HEAP32[$22>>2]|0;
      if ($21) {
       $24 = (($8) + 32|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (($23) + ($25<<3)|0);
       $35 = $26;
       break;
      } else {
       $27 = (($23) + ($20<<3)|0);
       $35 = $27;
       break;
      }
     }
    } while(0);
    $28 = HEAP32[560624>>2]|0;
    $29 = (($28) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 32|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + ($32<<3)|0);
    $34 = ($35|0)==($33|0);
    if (!($34)) {
     $36 = (($35) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==(0|0);
     if (!($38)) {
      break;
     }
    }
   }
   $39 = HEAP32[568208>>2]|0;
   $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
   $phitmp$i = ($40|0)==(0|0);
   if ($phitmp$i) {
    label = 11;
   }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $41 = (__Znwj(16)|0);
   $42 = (($3) + 8|0);
   HEAP32[$42>>2] = $41;
   HEAP32[$3>>2] = 17;
   $43 = (($3) + 4|0);
   HEAP32[$43>>2] = 15;
   dest=$41+0|0; src=568248+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $44 = (($41) + 15|0);
   HEAP8[$44>>0] = 0;
   __THREW__ = 0;
   $45 = (invoke_i(58)|0);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if (!($47)) {
    __THREW__ = 0;
    $48 = (invoke_iiii(1532,($45|0),43,($3|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if (!($50)) {
     $51 = ($48|0)==(0|0);
     if ($51) {
      $storemerge45 = 0;
     } else {
      $52 = (($48) + 4|0);
      $53 = HEAP32[$52>>2]|0;
      $storemerge45 = $53;
     }
     HEAP32[568208>>2] = $storemerge45;
     $54 = HEAP8[$3>>0]|0;
     $55 = $54 & 1;
     $56 = ($55<<24>>24)==(0);
     if ($56) {
      break;
     }
     $57 = HEAP32[$42>>2]|0;
     __ZdlPv($57);
     break;
    }
   }
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $60 = HEAP8[$3>>0]|0;
   $61 = $60 & 1;
   $62 = ($61<<24>>24)==(0);
   if ($62) {
    $$0 = $59;$$01 = $58;
    ___resumeException($$01|0);
    // unreachable;
   }
   $63 = HEAP32[$42>>2]|0;
   __ZdlPv($63);
   $$0 = $59;$$01 = $58;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $64 = HEAP32[568216>>2]|0;
 $65 = ($64|0)==(0);
 do {
  if ($65) {
   label = 29;
  } else {
   HEAP32[$1>>2] = $64;
   $66 = HEAP32[560624>>2]|0;
   $67 = ($66|0)==(0|0);
   if (!($67)) {
    $68 = (($66) + 36|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($66) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($69|0)==($71|0);
    do {
     if ($72) {
      $73 = (($66) + 28|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = (($66) + 32|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = (($74) + ($76<<3)|0);
      $93 = $77;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i21,$66,$1);
      $78 = HEAP32[$pos$i$i$i$i21>>2]|0;
      $79 = ($78|0)==(-1);
      $80 = (($66) + 28|0);
      $81 = HEAP32[$80>>2]|0;
      if ($79) {
       $82 = (($66) + 32|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = (($81) + ($83<<3)|0);
       $93 = $84;
       break;
      } else {
       $85 = (($81) + ($78<<3)|0);
       $93 = $85;
       break;
      }
     }
    } while(0);
    $86 = HEAP32[560624>>2]|0;
    $87 = (($86) + 28|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = (($86) + 32|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = (($88) + ($90<<3)|0);
    $92 = ($93|0)==($91|0);
    if (!($92)) {
     $94 = (($93) + 4|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($95|0)==(0|0);
     if (!($96)) {
      break;
     }
    }
   }
   $97 = HEAP32[568216>>2]|0;
   $98 = (__Z31ReadObjectFromPersistentManageri($97)|0);
   $phitmp$i9 = ($98|0)==(0|0);
   if ($phitmp$i9) {
    label = 29;
   }
  }
 } while(0);
 do {
  if ((label|0) == 29) {
   $99 = (__Znwj(16)|0);
   $100 = (($4) + 8|0);
   HEAP32[$100>>2] = $99;
   HEAP32[$4>>2] = 17;
   $101 = (($4) + 4|0);
   HEAP32[$101>>2] = 13;
   dest=$99+0|0; src=568264+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $102 = (($99) + 13|0);
   HEAP8[$102>>0] = 0;
   __THREW__ = 0;
   $103 = (invoke_i(58)|0);
   $104 = __THREW__; __THREW__ = 0;
   $105 = $104&1;
   if (!($105)) {
    __THREW__ = 0;
    $106 = (invoke_iiii(1532,($103|0),43,($4|0))|0);
    $107 = __THREW__; __THREW__ = 0;
    $108 = $107&1;
    if (!($108)) {
     $109 = ($106|0)==(0|0);
     if ($109) {
      $storemerge44 = 0;
     } else {
      $110 = (($106) + 4|0);
      $111 = HEAP32[$110>>2]|0;
      $storemerge44 = $111;
     }
     HEAP32[568216>>2] = $storemerge44;
     $112 = HEAP8[$4>>0]|0;
     $113 = $112 & 1;
     $114 = ($113<<24>>24)==(0);
     if ($114) {
      break;
     }
     $115 = HEAP32[$100>>2]|0;
     __ZdlPv($115);
     break;
    }
   }
   $116 = ___cxa_find_matching_catch()|0;
   $117 = tempRet0;
   $118 = HEAP8[$4>>0]|0;
   $119 = $118 & 1;
   $120 = ($119<<24>>24)==(0);
   if ($120) {
    $$0 = $117;$$01 = $116;
    ___resumeException($$01|0);
    // unreachable;
   }
   $121 = HEAP32[$100>>2]|0;
   __ZdlPv($121);
   $$0 = $117;$$01 = $116;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $122 = HEAP32[568224>>2]|0;
 $123 = ($122|0)==(0);
 if (!($123)) {
  HEAP32[$0>>2] = $122;
  $124 = HEAP32[560624>>2]|0;
  $125 = ($124|0)==(0|0);
  if (!($125)) {
   $126 = (($124) + 36|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($124) + 4|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($127|0)==($129|0);
   do {
    if ($130) {
     $131 = (($124) + 28|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = (($124) + 32|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($132) + ($134<<3)|0);
     $151 = $135;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i21,$124,$0);
     $136 = HEAP32[$pos$i$i$i$i21>>2]|0;
     $137 = ($136|0)==(-1);
     $138 = (($124) + 28|0);
     $139 = HEAP32[$138>>2]|0;
     if ($137) {
      $140 = (($124) + 32|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = (($139) + ($141<<3)|0);
      $151 = $142;
      break;
     } else {
      $143 = (($139) + ($136<<3)|0);
      $151 = $143;
      break;
     }
    }
   } while(0);
   $144 = HEAP32[560624>>2]|0;
   $145 = (($144) + 28|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = (($144) + 32|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = (($146) + ($148<<3)|0);
   $150 = ($151|0)==($149|0);
   if (!($150)) {
    $152 = (($151) + 4|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = ($153|0)==(0|0);
    if (!($154)) {
     STACKTOP = sp;return;
    }
   }
  }
  $155 = HEAP32[568224>>2]|0;
  $156 = (__Z31ReadObjectFromPersistentManageri($155)|0);
  $phitmp$i26 = ($156|0)==(0|0);
  if (!($phitmp$i26)) {
   STACKTOP = sp;return;
  }
 }
 $157 = (__Znwj(16)|0);
 $158 = (($5) + 8|0);
 HEAP32[$158>>2] = $157;
 HEAP32[$5>>2] = 17;
 $159 = (($5) + 4|0);
 HEAP32[$159>>2] = 11;
 dest=$157+0|0; src=568280+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $160 = (($157) + 11|0);
 HEAP8[$160>>0] = 0;
 __THREW__ = 0;
 $161 = (invoke_i(58)|0);
 $162 = __THREW__; __THREW__ = 0;
 $163 = $162&1;
 if (!($163)) {
  __THREW__ = 0;
  $164 = (invoke_iiii(1532,($161|0),43,($5|0))|0);
  $165 = __THREW__; __THREW__ = 0;
  $166 = $165&1;
  if (!($166)) {
   $167 = ($164|0)==(0|0);
   if ($167) {
    $storemerge = 0;
   } else {
    $168 = (($164) + 4|0);
    $169 = HEAP32[$168>>2]|0;
    $storemerge = $169;
   }
   HEAP32[568224>>2] = $storemerge;
   $170 = HEAP8[$5>>0]|0;
   $171 = $170 & 1;
   $172 = ($171<<24>>24)==(0);
   if ($172) {
    STACKTOP = sp;return;
   }
   $173 = HEAP32[$158>>2]|0;
   __ZdlPv($173);
   STACKTOP = sp;return;
  }
 }
 $174 = ___cxa_find_matching_catch()|0;
 $175 = tempRet0;
 $176 = HEAP8[$5>>0]|0;
 $177 = $176 & 1;
 $178 = ($177<<24>>24)==(0);
 if ($178) {
  $$0 = $175;$$01 = $174;
  ___resumeException($$01|0);
  // unreachable;
 }
 $179 = HEAP32[$158>>2]|0;
 __ZdlPv($179);
 $$0 = $175;$$01 = $174;
 ___resumeException($$01|0);
 // unreachable;
}
function __Z19RenderBasePassDepthRK17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EERS2_I17PrePassRenderDataLj4EERN9ShaderLab17ShaderPassContextE($ctx,$renderData,$plainRenderPasses,$passContext) {
 $ctx = $ctx|0;
 $renderData = $renderData|0;
 $plainRenderPasses = $plainRenderPasses|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $black = 0, $exitcond = 0, $exitcond4 = 0, $i$02 = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $black = sp;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (__Z22GetRenderBufferManagerv()|0);
 $2 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($1,-1,-1,2,1,0,1,1)|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = (($4) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($2,568296);
 }
 __ZN7Texture13SetFilterModeEi($2,0);
 $7 = (($2) + 140|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (($2) + 148|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   (__ZN13RenderTexture6CreateEv($2)|0);
  }
 }
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($2,0,-1,0);
 $13 = (($ctx) + 116|0);
 $14 = HEAP32[$13>>2]|0;
 __Z23AddRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureTypeP13RenderTexture($14,7,$2);
 ;HEAP32[$black+0>>2]=0|0;HEAP32[$black+4>>2]=0|0;HEAP32[$black+8>>2]=0|0;HEAP32[$black+12>>2]=0|0;
 __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE(7,$black,Math_fround(1.0),0,$passContext);
 $15 = HEAP32[$0>>2]|0;
 $16 = (($15) + 100|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($ctx) + 12|0);
 FUNCTION_TABLE_vii[$17 & 4095]($0,$18);
 $19 = (($renderData) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return ($2|0);
 }
 $i$02 = 0;
 while(1) {
  $22 = HEAP32[$plainRenderPasses>>2]|0;
  $23 = (($22) + ($i$02<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$renderData>>2]|0;
  $26 = ((($25) + (($24*44)|0)|0) + 36|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 52|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 24|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(-1);
  if (!($32)) {
   $33 = ((($25) + (($24*44)|0)|0) + 32|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + 120|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   __Z12SetupLODFadeR9GfxDeviceRN9ShaderLab17ShaderPassContextEf($0,$passContext,$36);
   $37 = HEAP32[$26>>2]|0;
   $38 = (($37) + 52|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + ($31<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 16|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)>(0);
   if ($45) {
    $46 = (($25) + (($24*44)|0)|0);
    $47 = (($34) + 112|0);
    $48 = (($34) + 116|0);
    $49 = ((($25) + (($24*44)|0)|0) + 6|0);
    $p$01 = 0;
    while(1) {
     $50 = HEAP32[$42>>2]|0;
     $51 = (($50) + ($p$01<<2)|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (($52) + 584|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==(6);
     if ($55) {
      $56 = HEAP32[$46>>2]|0;
      $57 = (__ZN5Unity8Material17SetPassWithShaderEiP6ShaderRN9ShaderLab17ShaderPassContextEi($56,$p$01,$27,$passContext,$31)|0);
      $58 = ($57|0)==(0|0);
      if (!($58)) {
       $59 = HEAP32[$47>>2]|0;
       __Z17SetupObjectMatrixRK10Matrix4x4fi($34,$59);
       $60 = HEAP32[$48>>2]|0;
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 8|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = HEAP16[$49>>1]|0;
       $65 = $64&65535;
       FUNCTION_TABLE_viii[$63 & 4095]($60,$65,$57);
      }
     }
     $66 = (($p$01) + 1)|0;
     $exitcond = ($66|0)==($44|0);
     if ($exitcond) {
      break;
     } else {
      $p$01 = $66;
     }
    }
   }
  }
  $67 = (($i$02) + 1)|0;
  $exitcond4 = ($67|0)==($20|0);
  if ($exitcond4) {
   break;
  } else {
   $i$02 = $67;
  }
 }
 STACKTOP = sp;return ($2|0);
}
function __Z22AssignCookieToMaterialRK5LightPN5Unity8MaterialE($light,$lightMaterial) {
 $light = $light|0;
 $lightMaterial = $lightMaterial|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $temp$0$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($light) + 176|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 do {
  if (!($5)) {
   HEAP32[$0>>2] = $4;
   $6 = HEAP32[560624>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    label = 10;
   } else {
    $8 = (($6) + 36|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($6) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($9|0)==($11|0);
    do {
     if ($12) {
      $13 = (($6) + 28|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($6) + 32|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($14) + ($16<<3)|0);
      $33 = $17;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$6,$0);
      $18 = HEAP32[$$byval_copy1>>2]|0;
      $19 = ($18|0)==(-1);
      $20 = (($6) + 28|0);
      $21 = HEAP32[$20>>2]|0;
      if ($19) {
       $22 = (($6) + 32|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = (($21) + ($23<<3)|0);
       $33 = $24;
       break;
      } else {
       $25 = (($21) + ($18<<3)|0);
       $33 = $25;
       break;
      }
     }
    } while(0);
    $26 = HEAP32[560624>>2]|0;
    $27 = (($26) + 28|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + 32|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + ($30<<3)|0);
    $32 = ($33|0)==($31|0);
    if ($32) {
     label = 10;
    } else {
     $34 = (($33) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)==(0|0);
     if ($36) {
      label = 10;
     } else {
      $temp$0$i$i2 = $35;
     }
    }
   }
   if ((label|0) == 10) {
    $37 = HEAP32[$3>>2]|0;
    $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
    $39 = ($38|0)==(0|0);
    if ($39) {
     break;
    } else {
     $temp$0$i$i2 = $38;
    }
   }
   $40 = HEAP32[568320>>2]|0;
   HEAP32[$1>>2] = $40;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($lightMaterial,$$byval_copy1,$temp$0$i$i2);
   STACKTOP = sp;return;
  }
 } while(0);
 $41 = (($light) + 216|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 $44 = HEAP32[568344>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  $46 = (__Z17GetRenderSettingsv()|0);
  $47 = (__ZNK14RenderSettings20GetDefaultSpotCookieEv($46)|0);
  HEAP32[568344>>2] = $47;
  $49 = $47;
 } else {
  $49 = $44;
 }
 $48 = HEAP32[568320>>2]|0;
 HEAP32[$2>>2] = $48;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($lightMaterial,$$byval_copy1,$49);
 STACKTOP = sp;return;
}
function __Z29RenderForwardObjectsIntoDepthRK17RenderLoopContextP13RenderTextureP13dynamic_arrayI16RenderObjectDataLj4EE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseESC_iib($ctx,$rt,$forwardRenderedObjects,$rtColorSurface,$rtDepthSurface,$width,$height,$cameraNeedsDepthTexture) {
 $ctx = $ctx|0;
 $rt = $rt|0;
 $forwardRenderedObjects = $forwardRenderedObjects|0;
 $rtColorSurface = $rtColorSurface|0;
 $rtDepthSurface = $rtDepthSurface|0;
 $width = $width|0;
 $height = $height|0;
 $cameraNeedsDepthTexture = $cameraNeedsDepthTexture|0;
 var $$0 = 0, $$byval_copy10 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $forwardRenderedShadowReceivers = 0, $i$08 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy10 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $forwardRenderedShadowReceivers = sp + 16|0;
 $4 = sp + 32|0;
 $5 = sp + 40|0;
 $6 = ($forwardRenderedObjects|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($forwardRenderedObjects) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 HEAP32[$forwardRenderedShadowReceivers>>2] = 0;
 $10 = (($forwardRenderedShadowReceivers) + 8|0);
 HEAP32[$10>>2] = 0;
 $11 = (($forwardRenderedShadowReceivers) + 12|0);
 HEAP32[$11>>2] = 0;
 $12 = (($forwardRenderedShadowReceivers) + 4|0);
 HEAP32[$12>>2] = 61;
 do {
  if ($cameraNeedsDepthTexture) {
   $$0 = $forwardRenderedObjects;
   label = 26;
  } else {
   $13 = $8 >>> 2;
   $14 = ($13|0)==(0);
   if ($14) {
    $105 = 0;
   } else {
    HEAP32[$11>>2] = $13;
    $15 = ($13*44)|0;
    HEAP32[$3>>2] = 61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
    $16 = (invoke_iiiiiiii(108,(0|0),($15|0),4,($$byval_copy10|0),0,(568472|0),370)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 10;
     break;
    }
    HEAP32[$forwardRenderedShadowReceivers>>2] = $16;
    $105 = $16;
   }
   $57 = $105;$i$08 = 0;
   L13: while(1) {
    $19 = HEAP32[$forwardRenderedObjects>>2]|0;
    $20 = (($19) + (($i$08*44)|0)|0);
    $21 = ((($19) + (($i$08*44)|0)|0) + 32|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + 116|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($24) + 42|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if ($27) {
     $106 = $57;
    } else {
     $38 = ((($19) + (($i$08*44)|0)|0) + 36|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + 52|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + 20|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(-1);
     if ($44) {
      $106 = $57;
     } else {
      $45 = HEAP32[$10>>2]|0;
      $46 = (($45) + 1)|0;
      HEAP32[$10>>2] = $46;
      $47 = HEAP32[$11>>2]|0;
      $48 = $47 & 2147483647;
      $49 = ($46>>>0)>($48>>>0);
      if ($49) {
       $50 = $47 << 1;
       $51 = ($50|0)==(0);
       $52 = $51 ? 1 : $50;
       $53 = ($48>>>0)<($52>>>0);
       do {
        if ($53) {
         $54 = ($47|0)>(-1);
         if ($54) {
          HEAP32[$11>>2] = $52;
          $55 = ($52*44)|0;
          $56 = HEAP32[$12>>2]|0;
          HEAP32[$0>>2] = $56;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
          $58 = (invoke_iiiiiiii(108,($57|0),($55|0),4,($$byval_copy10|0),0,(568472|0),370)|0);
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           label = 9;
           break L13;
          }
          HEAP32[$forwardRenderedShadowReceivers>>2] = $58;
          $107 = $58;
          break;
         } else {
          $61 = ($52*44)|0;
          $62 = HEAP32[$12>>2]|0;
          HEAP32[$1>>2] = $62;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
          $63 = (invoke_iiiiiii(102,($61|0),4,($$byval_copy10|0),0,(568472|0),352)|0);
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           label = 9;
           break L13;
          }
          $66 = HEAP32[$forwardRenderedShadowReceivers>>2]|0;
          $67 = HEAP32[$10>>2]|0;
          $68 = ($67*44)|0;
          _memcpy(($63|0),($66|0),($68|0))|0;
          HEAP32[$11>>2] = $52;
          HEAP32[$forwardRenderedShadowReceivers>>2] = $63;
          $107 = $63;
          break;
         }
        } else {
         $107 = $57;
        }
       } while(0);
       $$pre$i$i = HEAP32[$10>>2]|0;
       $70 = $$pre$i$i;$72 = $107;
      } else {
       $70 = $46;$72 = $57;
      }
      $69 = (($70) + -1)|0;
      $71 = (($72) + (($69*44)|0)|0);
      dest=$71+0|0; src=$20+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $106 = $72;
     }
    }
    $73 = (($i$08) + 1)|0;
    $74 = ($73>>>0)<($8>>>0);
    if ($74) {
     $57 = $106;$i$08 = $73;
    } else {
     label = 25;
     break;
    }
   }
   if ((label|0) == 9) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    $lpad$phi$index = $28;$lpad$phi$index2 = $29;
    break;
   }
   else if ((label|0) == 25) {
    $75 = HEAP32[$10>>2]|0;
    $76 = ($75|0)==(0);
    if ($76) {
     label = 32;
     break;
    } else {
     $$0 = $forwardRenderedShadowReceivers;
     label = 26;
     break;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 26) {
   $77 = HEAP32[$rtDepthSurface>>2]|0;
   HEAP32[$4>>2] = $77;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$4+0>>2]|0;
   (invoke_iiiiiiii(109,1,($rtColorSurface|0),($$byval_copy10|0),($rt|0),0,-1,0)|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 10;
   } else {
    __THREW__ = 0;
    $80 = (invoke_i(59)|0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     label = 10;
    } else {
     $83 = HEAP8[((640792 + 279|0))>>0]|0;
     $84 = ($83<<24>>24)==(0);
     if (!($84)) {
      $85 = HEAP32[$80>>2]|0;
      $86 = (($85) + 644|0);
      $87 = HEAP32[$86>>2]|0;
      __THREW__ = 0;
      invoke_viff($87|0,($80|0),1.0,0.0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       label = 10;
       break;
      }
     }
     HEAP32[$5>>2] = 0;
     $90 = (($5) + 4|0);
     HEAP32[$90>>2] = -1;
     $91 = HEAP32[652824>>2]|0;
     __THREW__ = 0;
     invoke_viiii(336,($$0|0),($5|0),1,($91|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      label = 10;
     } else {
      $94 = HEAP32[$80>>2]|0;
      $95 = (($94) + 644|0);
      $96 = HEAP32[$95>>2]|0;
      __THREW__ = 0;
      invoke_viff($96|0,($80|0),0.0,0.0);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       label = 10;
      } else {
       label = 32;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $lpad$phi$index = $30;$lpad$phi$index2 = $31;
 }
 else if ((label|0) == 32) {
  $99 = HEAP32[$11>>2]|0;
  $100 = ($99|0)>(-1);
  if (!($100)) {
   STACKTOP = sp;return;
  }
  $101 = HEAP32[$forwardRenderedShadowReceivers>>2]|0;
  $102 = HEAP32[$12>>2]|0;
  HEAP32[$0>>2] = $102;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($101,$$byval_copy10);
  HEAP32[$forwardRenderedShadowReceivers>>2] = 0;
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$11>>2]|0;
 $33 = ($32|0)>(-1);
 if (!($33)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $34 = HEAP32[$forwardRenderedShadowReceivers>>2]|0;
 $35 = HEAP32[$12>>2]|0;
 HEAP32[$2>>2] = $35;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy10|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $103 = ___cxa_find_matching_catch(0|0)|0;
  $104 = tempRet0;
  ___clang_call_terminate($103);
  // unreachable;
 }
 HEAP32[$forwardRenderedShadowReceivers>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z26CombineDepthNormalsTextureRK17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EE($ctx,$remainingObjects) {
 $ctx = $ctx|0;
 $remainingObjects = $remainingObjects|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = HEAP32[568352>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (__Z15GetScriptMapperv()|0);
  $6 = (__Znwj(48)|0);
  $7 = (($1) + 8|0);
  HEAP32[$7>>2] = $6;
  HEAP32[$1>>2] = 49;
  $8 = (($1) + 4|0);
  HEAP32[$8>>2] = 35;
  dest=$6+0|0; src=568360+0|0; stop=dest+35|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $9 = (($6) + 35|0);
  HEAP8[$9>>0] = 0;
  __THREW__ = 0;
  $10 = (invoke_iii(2366,($5|0),($1|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $19 = ___cxa_find_matching_catch()|0;
   $20 = tempRet0;
   $21 = HEAP8[$1>>0]|0;
   $22 = $21 & 1;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    ___resumeException($19|0);
    // unreachable;
   }
   $24 = HEAP32[$7>>2]|0;
   __ZdlPv($24);
   ___resumeException($19|0);
   // unreachable;
  }
  $13 = HEAP8[$1>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if (!($15)) {
   $16 = HEAP32[$7>>2]|0;
   __ZdlPv($16);
  }
  $17 = ($10|0)==(0|0);
  if ($17) {
   $$pr = HEAP32[568352>>2]|0;
   $26 = $$pr;
  } else {
   $18 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($10,61,0)|0);
   HEAP32[568352>>2] = $18;
   $26 = $18;
  }
  $25 = ($26|0)==(0|0);
  if ($25) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $27 = (__Z22GetRenderBufferManagerv()|0);
 $28 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($27,-1,-1,0,0,0,1,1)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  __ZN7Texture13SetFilterModeEi($28,0);
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + 36|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vii[$32 & 4095]($28,568400);
 }
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($28,0,-1,0);
 HEAPF32[$2>>2] = Math_fround(0.5);
 $33 = (($2) + 4|0);
 HEAPF32[$33>>2] = Math_fround(0.5);
 $34 = (($2) + 8|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (($2) + 12|0);
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = HEAP32[652824>>2]|0;
 __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE(1,$2,Math_fround(1.0),0,$36);
 $37 = HEAP32[568352>>2]|0;
 __ZN12ImageFilters4BlitEP7TextureP13RenderTexturePN5Unity8MaterialEib11CubemapFace(0,$28,$37,0,0,-1);
 $38 = (($ctx) + 116|0);
 $39 = HEAP32[$38>>2]|0;
 __Z23AddRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureTypeP13RenderTexture($39,4,$28);
 $40 = HEAP8[568432>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  HEAP32[$0>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568440);
  $42 = HEAP32[$0>>2]|0;
  HEAP32[568424>>2] = $42;
  HEAP8[568432>>0] = 1;
 }
 $43 = HEAP32[652824>>2]|0;
 $44 = (($43) + 20|0);
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($44,568424,$28)|0);
 $$0 = $28;
 STACKTOP = sp;return ($$0|0);
}
function __GLOBAL__I_a1651() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[568208>>2] = 0;
 HEAP32[568216>>2] = 0;
 HEAP32[568224>>2] = 0;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568328);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[568320>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN17PrePassRenderLoop14RenderLightingER12ActiveLightsP13RenderTexture9TextureIDS3_RS3_RK8Vector4fRK14LightingLayersR10MinMaxAABBPS3_($this,$activeLights,$rtMain,$depthTextureID,$rtNormalsSpec,$rtLight,$lightFade,$lightingLayers,$receiverBounds,$outMainShadowMap) {
 $this = $this|0;
 $activeLights = $activeLights|0;
 $rtMain = $rtMain|0;
 $depthTextureID = $depthTextureID|0;
 $rtNormalsSpec = $rtNormalsSpec|0;
 $rtLight = $rtLight|0;
 $lightFade = $lightFade|0;
 $lightingLayers = $lightingLayers|0;
 $receiverBounds = $receiverBounds|0;
 $outMainShadowMap = $outMainShadowMap|0;
 var $$ = Math_fround(0), $$$pre = 0, $$0 = 0, $$01 = 0, $$6 = Math_fround(0), $$byval_copy6 = 0, $$pr = 0, $$pre = 0, $$pre11 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $black = 0, $camData = 0, $it$07 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $preserveMVP = 0, $white = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 976|0;
 $$byval_copy6 = sp + 972|0;
 $camData = sp;
 $0 = sp + 724|0;
 $1 = sp + 728|0;
 $preserveMVP = sp + 744|0;
 $white = sp + 936|0;
 $black = sp + 952|0;
 $2 = sp + 968|0;
 HEAP32[$outMainShadowMap>>2] = 0;
 $3 = (__Z18GetQualitySettingsv()|0);
 $4 = (($3) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7) + (($5*96)|0)|0) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__Z19GetLightmapSettingsv()|0);
 $11 = (__ZNK16LightmapSettings22GetLightmapsModeLegacyEv($10)|0);
 $12 = HEAP32[$this>>2]|0;
 $13 = (($12) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 _memcpy(($camData|0),($14|0),612)|0;
 $15 = HEAP32[652824>>2]|0;
 $16 = Math_fround(HEAPF32[$receiverBounds>>2]);
 $17 = Math_fround($16 + Math_fround(-0.00999999977648258209228));
 HEAPF32[$receiverBounds>>2] = $17;
 $18 = (($receiverBounds) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 + Math_fround(-0.00999999977648258209228));
 HEAPF32[$18>>2] = $20;
 $21 = (($receiverBounds) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 + Math_fround(-0.00999999977648258209228));
 HEAPF32[$21>>2] = $23;
 $24 = (($receiverBounds) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + Math_fround(0.00999999977648258209228));
 HEAPF32[$24>>2] = $26;
 $27 = (($receiverBounds) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 + Math_fround(0.00999999977648258209228));
 HEAPF32[$27>>2] = $29;
 $30 = (($receiverBounds) + 20|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 + Math_fround(0.00999999977648258209228));
 HEAPF32[$30>>2] = $32;
 $33 = (__Z19GetGraphicsSettingsv()|0);
 $34 = (($33) + 32|0);
 __ZNK21BuiltinShaderSettings22CreateMaterialIfNeededEPPN5Unity8MaterialEi($34,568656,2);
 $35 = HEAP32[568656>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 __Z15InitLightMeshesv();
 $37 = HEAP8[568672>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  HEAP32[$$byval_copy6>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy6,568680);
  $39 = HEAP32[$$byval_copy6>>2]|0;
  HEAP32[568664>>2] = $39;
  HEAP8[568672>>0] = 1;
 }
 $40 = HEAP8[568712>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  HEAP32[$$byval_copy6>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy6,568720);
  $42 = HEAP32[$$byval_copy6>>2]|0;
  HEAP32[568704>>2] = $42;
  HEAP8[568712>>0] = 1;
 }
 $43 = HEAP32[$rtNormalsSpec>>2]|0;
 $44 = (($43) + 116|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (FUNCTION_TABLE_ii[$45 & 4095]($rtNormalsSpec)|0);
 $47 = HEAP32[$rtNormalsSpec>>2]|0;
 $48 = (($47) + 120|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (FUNCTION_TABLE_ii[$49 & 4095]($rtNormalsSpec)|0);
 $51 = HEAP8[((640792 + 248|0))>>0]|0;
 $52 = ($51<<24>>24)==(0);
 $$pre11 = (($15) + 20|0);
 if (!($52)) {
  $53 = HEAP32[$depthTextureID>>2]|0;
  HEAP32[$0>>2] = $53;
  $54 = (($rtMain) + 72|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($rtMain) + 76|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($rtMain) + 64|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($rtMain) + 68|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN9ShaderLab13PropertySheet16SetRectTextureIDERKNS_16FastPropertyNameE9TextureIDiiffff($$pre11,568664,$$byval_copy6,$46,$50,$55,$57,$59,$61);
 }
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($$pre11,568704,$rtNormalsSpec)|0);
 $62 = (__Z12GetGfxDevicev()|0);
 $63 = (__Z12GetGfxDevicev()|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 88|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (FUNCTION_TABLE_ii[$66 & 4095]($63)|0);
 $68 = HEAP32[$63>>2]|0;
 $69 = (($68) + 84|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_vii[$70 & 4095]($63,0);
 $71 = HEAP32[$62>>2]|0;
 $72 = (($71) + 136|0);
 $73 = HEAP32[$72>>2]|0;
 __THREW__ = 0;
 invoke_vii($73|0,($62|0),0);
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 L13: do {
  if ($75) {
   label = 16;
  } else {
   $76 = HEAP32[$62>>2]|0;
   $77 = (($76) + 40|0);
   $78 = HEAP32[$77>>2]|0;
   HEAP8[$1>>0] = 0;
   $79 = (($1) + 1|0);
   HEAP8[$79>>0] = -1;
   $80 = (($1) + 2|0);
   HEAP8[$80>>0] = -1;
   $81 = (($1) + 4|0);
   HEAP8[$81>>0] = 8;
   $82 = (($1) + 5|0);
   HEAP8[$82>>0] = 0;
   $83 = (($1) + 6|0);
   HEAP8[$83>>0] = 0;
   $84 = (($1) + 7|0);
   HEAP8[$84>>0] = 0;
   $85 = (($1) + 8|0);
   HEAP8[$85>>0] = 8;
   $86 = (($1) + 9|0);
   HEAP8[$86>>0] = 0;
   $87 = (($1) + 10|0);
   HEAP8[$87>>0] = 0;
   $88 = (($1) + 11|0);
   HEAP8[$88>>0] = 0;
   __THREW__ = 0;
   $89 = (invoke_iii($78|0,($62|0),($1|0))|0);
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    label = 16;
   } else {
    __THREW__ = 0;
    invoke_vi(3405,($preserveMVP|0));
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     label = 16;
    } else {
     $94 = HEAP32[$62>>2]|0;
     $95 = (($94) + 96|0);
     $96 = HEAP32[$95>>2]|0;
     __THREW__ = 0;
     invoke_vii($96|0,($62|0),(616552|0));
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     L17: do {
      if ($98) {
       label = 18;
      } else {
       $99 = HEAP32[$this>>2]|0;
       $100 = HEAP32[$99>>2]|0;
       $101 = (($100) + 636|0);
       __THREW__ = 0;
       invoke_viii(1663,($101|0),6,($15|0));
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if ($103) {
        label = 18;
       } else {
        $104 = (($activeLights) + 16|0);
        $105 = HEAP8[$104>>0]|0;
        $106 = ($105<<24>>24)==(0);
        $$pre = HEAP32[$activeLights>>2]|0;
        $$$pre = $106 ? 0 : $$pre;
        $107 = (($activeLights) + 8|0);
        $108 = HEAP32[$107>>2]|0;
        $109 = (($$pre) + (($108*108)|0)|0);
        $110 = ($108|0)==(0);
        L20: do {
         if (!($110)) {
          $it$07 = $$pre;
          while(1) {
           $111 = (($it$07) + 9|0);
           $112 = HEAP8[$111>>0]|0;
           $113 = ($112<<24>>24)==(0);
           $114 = ($it$07|0)==($$$pre|0);
           $or$cond = $113 | $114;
           if (!($or$cond)) {
            $123 = HEAP32[$this>>2]|0;
            __THREW__ = 0;
            (invoke_iiiiiiiiiiiiiii(1,($123|0),($camData|0),($9|0),($11|0),($rtLight|0),($rtMain|0),($89|0),($receiverBounds|0),($preserveMVP|0),($lightFade|0),($lightingLayers|0),($it$07|0),0,($15|0))|0);
            $124 = __THREW__; __THREW__ = 0;
            $125 = $124&1;
            if ($125) {
             break;
            }
           }
           $126 = (($it$07) + 108|0);
           $127 = ($126|0)==($109|0);
           if ($127) {
            break L20;
           } else {
            $it$07 = $126;
           }
          }
          $117 = ___cxa_find_matching_catch()|0;
          $118 = tempRet0;
          $lpad$phi$index = $117;$lpad$phi$index2 = $118;
          break L17;
         }
        } while(0);
        $128 = ($$$pre|0)==(0|0);
        if (!($128)) {
         $129 = HEAP32[$this>>2]|0;
         __THREW__ = 0;
         $130 = (invoke_iiiiiiiiiiiiiii(1,($129|0),($camData|0),($9|0),($11|0),($rtLight|0),($rtMain|0),($89|0),($receiverBounds|0),($preserveMVP|0),($lightFade|0),($lightingLayers|0),($$$pre|0),1,($15|0))|0);
         $131 = __THREW__; __THREW__ = 0;
         $132 = $131&1;
         if ($132) {
          label = 18;
          break;
         }
         $133 = ($130|0)==(0|0);
         if (!($133)) {
          $134 = HEAP32[$this>>2]|0;
          $135 = (($134) + 116|0);
          $136 = HEAP32[$135>>2]|0;
          __THREW__ = 0;
          invoke_viii(1666,($136|0),5,($130|0));
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if ($138) {
           label = 18;
           break;
          }
          HEAP32[$outMainShadowMap>>2] = $130;
         }
        }
        __THREW__ = 0;
        invoke_vi(3400,($15|0));
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         label = 18;
        } else {
         $141 = $lightFade;
         $142 = $141;
         $143 = HEAP32[$142>>2]|0;
         $144 = (($141) + 4)|0;
         $145 = $144;
         $146 = HEAP32[$145>>2]|0;
         $147 = (($lightFade) + 8|0);
         $148 = Math_fround(HEAPF32[$147>>2]);
         $149 = (($lightFade) + 12|0);
         $150 = Math_fround(HEAPF32[$149>>2]);
         __THREW__ = 0;
         $151 = (invoke_i(64)|0);
         $152 = __THREW__; __THREW__ = 0;
         $153 = $152&1;
         if ($153) {
          label = 18;
         } else {
          __THREW__ = 0;
          $154 = (invoke_ii(3217,($151|0))|0);
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           label = 18;
          } else {
           $157 = ($154|0)==(1);
           $$ = $157 ? $150 : Math_fround(1.0);
           $$6 = $157 ? $148 : Math_fround(1.0);
           $158 = (($62) + 676|0);
           $159 = $158;
           $160 = $159;
           HEAP32[$160>>2] = $143;
           $161 = (($159) + 4)|0;
           $162 = $161;
           HEAP32[$162>>2] = $146;
           $163 = (($62) + 684|0);
           HEAPF32[$163>>2] = $$6;
           $164 = (($62) + 688|0);
           HEAPF32[$164>>2] = $$;
           $165 = HEAP32[$62>>2]|0;
           $166 = (($165) + 64|0);
           $167 = HEAP32[$166>>2]|0;
           __THREW__ = 0;
           invoke_viii($167|0,($62|0),($89|0),0);
           $168 = __THREW__; __THREW__ = 0;
           $169 = $168&1;
           if ($169) {
            label = 18;
           } else {
            $170 = HEAP32[$rtLight>>2]|0;
            $171 = ($170|0)==(0|0);
            if ($171) {
             __THREW__ = 0;
             $172 = (invoke_i(61)|0);
             $173 = __THREW__; __THREW__ = 0;
             $174 = $173&1;
             if ($174) {
              label = 18;
              break;
             }
             __THREW__ = 0;
             $175 = (invoke_iiiiiiiii(37,($172|0),16,16,0,0,0,1,1)|0);
             $176 = __THREW__; __THREW__ = 0;
             $177 = $176&1;
             if ($177) {
              label = 18;
              break;
             }
             HEAP32[$rtLight>>2] = $175;
             $178 = ($175|0)==(0|0);
             if ($178) {
              $184 = 0;
             } else {
              $179 = HEAP32[$175>>2]|0;
              $180 = (($179) + 36|0);
              $181 = HEAP32[$180>>2]|0;
              __THREW__ = 0;
              invoke_vii($181|0,($175|0),(568744|0));
              $182 = __THREW__; __THREW__ = 0;
              $183 = $182&1;
              if ($183) {
               label = 18;
               break;
              }
              $$pre9 = HEAP32[$rtLight>>2]|0;
              $184 = $$pre9;
             }
             __THREW__ = 0;
             invoke_viiii(337,($184|0),0,-1,0);
             $185 = __THREW__; __THREW__ = 0;
             $186 = $185&1;
             if ($186) {
              label = 18;
              break;
             }
             HEAPF32[$white>>2] = Math_fround(1.0);
             $187 = (($white) + 4|0);
             HEAPF32[$187>>2] = Math_fround(1.0);
             $188 = (($white) + 8|0);
             HEAPF32[$188>>2] = Math_fround(1.0);
             $189 = (($white) + 12|0);
             HEAPF32[$189>>2] = Math_fround(1.0);
             ;HEAP32[$black+0>>2]=0|0;HEAP32[$black+4>>2]=0|0;HEAP32[$black+8>>2]=0|0;HEAP32[$black+12>>2]=0|0;
             $190 = HEAP32[$this>>2]|0;
             $191 = HEAP32[$190>>2]|0;
             $192 = (($191) + 620|0);
             $193 = HEAP8[$192>>0]|0;
             $194 = ($193<<24>>24)!=(0);
             $195 = $194 ? $black : $white;
             __THREW__ = 0;
             invoke_viifii(3,1,($195|0),1.0,0,($15|0));
             $196 = __THREW__; __THREW__ = 0;
             $197 = $196&1;
             if ($197) {
              label = 18;
              break;
             }
             $198 = HEAP32[$62>>2]|0;
             $199 = (($198) + 412|0);
             $200 = HEAP32[$199>>2]|0;
             $201 = (($rtMain) + 148|0);
             $202 = HEAP32[$201>>2]|0;
             HEAP32[$2>>2] = $202;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
             invoke_vii($200|0,($62|0),($$byval_copy6|0));
             $203 = __THREW__; __THREW__ = 0;
             $204 = $203&1;
             if ($204) {
              label = 18;
              break;
             }
             $$pr = HEAP32[$rtLight>>2]|0;
             $205 = ($$pr|0)==(0|0);
             if (!($205)) {
              $209 = $$pr;
              label = 41;
             }
            } else {
             $209 = $170;
             label = 41;
            }
            if ((label|0) == 41) {
             $206 = HEAP32[$this>>2]|0;
             $207 = (($206) + 116|0);
             $208 = HEAP32[$207>>2]|0;
             __THREW__ = 0;
             invoke_viii(1666,($208|0),9,($209|0));
             $210 = __THREW__; __THREW__ = 0;
             $211 = $210&1;
             if ($211) {
              label = 18;
              break;
             }
            }
            $212 = HEAP32[$this>>2]|0;
            $213 = HEAP32[$212>>2]|0;
            $214 = (($213) + 636|0);
            __THREW__ = 0;
            invoke_viii(1663,($214|0),7,($15|0));
            $215 = __THREW__; __THREW__ = 0;
            $216 = $215&1;
            if ($216) {
             label = 18;
            } else {
             __THREW__ = 0;
             invoke_vi(3375,($preserveMVP|0));
             $217 = __THREW__; __THREW__ = 0;
             $218 = $217&1;
             if ($218) {
              label = 16;
              break L13;
             }
             $219 = (__Z12GetGfxDevicev()|0);
             $220 = HEAP32[$219>>2]|0;
             $221 = (($220) + 84|0);
             $222 = HEAP32[$221>>2]|0;
             FUNCTION_TABLE_vii[$222 & 4095]($219,$67);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 18) {
      $119 = ___cxa_find_matching_catch()|0;
      $120 = tempRet0;
      $lpad$phi$index = $119;$lpad$phi$index2 = $120;
     }
     __THREW__ = 0;
     invoke_vi(3375,($preserveMVP|0));
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if ($122) {
      $231 = ___cxa_find_matching_catch(0|0)|0;
      $232 = tempRet0;
      ___clang_call_terminate($231);
      // unreachable;
     } else {
      $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $115 = ___cxa_find_matching_catch()|0;
  $116 = tempRet0;
  $$0 = $115;$$01 = $116;
 }
 __THREW__ = 0;
 $223 = (invoke_i(59)|0);
 $224 = __THREW__; __THREW__ = 0;
 $225 = $224&1;
 if ($225) {
  $231 = ___cxa_find_matching_catch(0|0)|0;
  $232 = tempRet0;
  ___clang_call_terminate($231);
  // unreachable;
 }
 $226 = HEAP32[$223>>2]|0;
 $227 = (($226) + 84|0);
 $228 = HEAP32[$227>>2]|0;
 __THREW__ = 0;
 invoke_vii($228|0,($223|0),($67|0));
 $229 = __THREW__; __THREW__ = 0;
 $230 = $229&1;
 if ($230) {
  $231 = ___cxa_find_matching_catch(0|0)|0;
  $232 = tempRet0;
  ___clang_call_terminate($231);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZL11RenderLightRK17RenderLoopContextRK14ShadowCullDataN15QualitySettings13ShadowQualityEN16LightmapSettings19LightmapsModeLegacyERP13RenderTextureSA_iiPK18DeviceStencilStateRK10MinMaxAABBRK22DeviceMVPMatricesStateRK8Vector4fRK14LightingLayersRK11ActiveLightbRN9ShaderLab17ShaderPassContextE($ctx,$shadowCullData,$shadowQuality,$lightmapsMode,$rtLight,$rtMain,$devStDisabled,$receiverBounds,$mvpState,$lightFade,$lightingLayers,$light,$returnShadowMap,$passContext) {
 $ctx = $ctx|0;
 $shadowCullData = $shadowCullData|0;
 $shadowQuality = $shadowQuality|0;
 $lightmapsMode = $lightmapsMode|0;
 $rtLight = $rtLight|0;
 $rtMain = $rtMain|0;
 $devStDisabled = $devStDisabled|0;
 $receiverBounds = $receiverBounds|0;
 $mvpState = $mvpState|0;
 $lightFade = $lightFade|0;
 $lightingLayers = $lightingLayers|0;
 $light = $light|0;
 $returnShadowMap = $returnShadowMap|0;
 $passContext = $passContext|0;
 var $$ = 0, $$$i = 0, $$0$i = 0, $$0$i$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$19 = Math_fround(0), $$20 = Math_fround(0), $$21 = Math_fround(0), $$22 = Math_fround(0), $$6 = 0, $$6$ = 0, $$byval_copy4 = 0, $$in = 0, $$not3 = 0, $$not4 = 0, $$not7 = 0;
 var $$ph = 0, $$ph29 = 0, $$pre = 0, $$pre$i = 0, $$pre34 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0;
 var $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0);
 var $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0);
 var $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0);
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0;
 var $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $black = 0, $black$white = 0, $blendstate = 0, $brmerge = 0, $brmerge5 = 0, $brmerge8 = 0, $brmerge9 = 0, $channels2$0 = 0, $depthstate = 0, $depthstate4 = 0, $lightCol = 0, $lightMatrix = 0, $lightPassAddBits = 0, $lightPassCount$0 = 0, $lightPos = 0, $lightShadows$0 = 0, $lightShadows1$0 = 0, $lightStencil = 0;
 var $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $phitmp = 0, $pp$030 = 0, $rasterstate = 0, $rasterstate3 = 0, $rtSurfaceColor = 0, $rtSurfaceMainColor = 0, $shadowMap$0 = 0, $shadowMap$1 = 0, $shadowMap$2 = 0, $shadowMatrices = 0, $stencil = 0, $stencilRef$0 = 0, $storemerge24 = 0, $temp1 = 0, $temp2 = 0, $temp3 = 0, $temp4 = 0;
 var $white = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1584|0;
 $$byval_copy4 = sp + 408|0;
 $lightMatrix = sp + 1504|0;
 $lightPos = sp + 1488|0;
 $rtSurfaceColor = sp + 1484|0;
 $rtSurfaceMainColor = sp + 1480|0;
 $white = sp + 1464|0;
 $black = sp + 1448|0;
 $0 = sp + 1440|0;
 $lightCol = sp + 1424|0;
 $temp1 = sp + 1360|0;
 $temp2 = sp + 1296|0;
 $temp3 = sp + 1232|0;
 $1 = sp + 1220|0;
 $2 = sp + 1208|0;
 $temp4 = sp + 484|0;
 $3 = sp + 472|0;
 $4 = sp + 396|0;
 $5 = sp + 344|0;
 $6 = sp + 328|0;
 $7 = sp + 320|0;
 $shadowMatrices = sp + 48|0;
 $8 = sp + 312|0;
 $9 = sp + 304|0;
 $10 = sp + 40|0;
 $11 = sp + 308|0;
 $lightPassAddBits = sp + 32|0;
 $blendstate = sp + 360|0;
 $rasterstate = sp + 16|0;
 $depthstate = sp + 1570|0;
 $lightStencil = sp + 372|0;
 $stencil = sp + 384|0;
 $rasterstate3 = sp;
 $depthstate4 = sp + 1568|0;
 $12 = HEAP32[$light>>2]|0;
 $13 = (($12) + 216|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(3);
 if ($15) {
  $$0$i = 2;
 } else {
  $16 = (($12) + 221|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $$0$i = 0;
  } else {
   $19 = (($12) + 212|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(1);
   $$$i = $21 ? 1 : 2;
   $$0$i = $$$i;
  }
 }
 $22 = (($12) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($23)|0);
 __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($lightMatrix,$24);
 $25 = (($lightMatrix) + 48|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($lightMatrix) + 52|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($lightMatrix) + 56|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$lightPos>>2] = $26;
 $31 = (($lightPos) + 4|0);
 HEAPF32[$31>>2] = $28;
 $32 = (($lightPos) + 8|0);
 HEAPF32[$32>>2] = $30;
 $33 = (($12) + 116|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = HEAP32[$13>>2]|0;
  $37 = ($36|0)==(1);
  if ($37) {
   $lightShadows$0 = $34;
  } else {
   $38 = (__Z16GetBuildSettingsv()|0);
   $39 = (($38) + 103|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   $$ = $41 ? 0 : $34;
   $lightShadows$0 = $$;
  }
  $42 = ($lightShadows$0|0)>(1);
  if ($42) {
   (__Z21GetSoftShadowsEnabledv()|0);
  }
 }
 $43 = (__Z12GetGfxDevicev()|0);
 HEAP32[$rtSurfaceColor>>2] = 0;
 $44 = (($rtMain) + 148|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($rtMain) + 140|0);
 $47 = HEAP32[$46>>2]|0;
 HEAP32[$rtSurfaceMainColor>>2] = $47;
 $48 = HEAP32[$ctx>>2]|0;
 $49 = (($48) + 620|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = ($50<<24>>24)!=(0);
 HEAPF32[$white>>2] = Math_fround(1.0);
 $52 = (($white) + 4|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($white) + 8|0);
 HEAPF32[$53>>2] = Math_fround(1.0);
 $54 = (($white) + 12|0);
 HEAPF32[$54>>2] = Math_fround(1.0);
 ;HEAP32[$black+0>>2]=0|0;HEAP32[$black+4>>2]=0|0;HEAP32[$black+8>>2]=0|0;HEAP32[$black+12>>2]=0|0;
 $55 = HEAP32[$rtLight>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  $57 = (__Z22GetRenderBufferManagerv()|0);
  if ($51) {
   $58 = (__Z12GetGfxDevicev()|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 676|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (FUNCTION_TABLE_ii[$61 & 4095]($58)|0);
   $63 = $62;
  } else {
   $63 = 0;
  }
  $64 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($57,-1,-1,0,$63,0,1,1)|0);
  HEAP32[$rtLight>>2] = $64;
  $65 = ($64|0)==(0|0);
  if ($65) {
   $70 = 0;
  } else {
   $66 = HEAP32[$64>>2]|0;
   $67 = (($66) + 36|0);
   $68 = HEAP32[$67>>2]|0;
   FUNCTION_TABLE_vii[$68 & 4095]($64,568800);
   $$pre = HEAP32[$rtLight>>2]|0;
   $70 = $$pre;
  }
  $69 = (($70) + 140|0);
  $71 = HEAP32[$69>>2]|0;
  $72 = ($71|0)==(0|0);
  if ($72) {
   $73 = (($70) + 148|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    (__ZN13RenderTexture6CreateEv($70)|0);
    $$pre34 = HEAP32[$rtLight>>2]|0;
    $76 = $$pre34;
   } else {
    $76 = $70;
   }
  } else {
   $76 = $70;
  }
  __ZN7Texture13SetFilterModeEi($76,0);
  $77 = HEAP32[$rtLight>>2]|0;
  $78 = (($77) + 140|0);
  $79 = HEAP32[$78>>2]|0;
  HEAP32[$rtSurfaceColor>>2] = $79;
  HEAP32[$0>>2] = $45;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rtSurfaceColor,$$byval_copy4,$77,0,-1,4)|0);
  $black$white = $51 ? $black : $white;
  __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE(1,$black$white,Math_fround(1.0),0,$passContext);
  $$pre35 = HEAP32[$rtLight>>2]|0;
  $81 = $$pre35;
 } else {
  $81 = $55;
 }
 $80 = (($81) + 140|0);
 $82 = HEAP32[$80>>2]|0;
 HEAP32[$rtSurfaceColor>>2] = $82;
 __ZN5Light15SetLightKeywordEv($12);
 $83 = (($lightMatrix) + 32|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($lightMatrix) + 36|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($lightMatrix) + 40|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (__Z19GetActiveColorSpacev()|0);
 $90 = ($89|0)==(1);
 $91 = (($12) + 140|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 do {
  if ($90) {
   $93 = !($92 <= Math_fround(0.0404499992728233337402));
   do {
    if ($93) {
     $95 = $92 < Math_fround(1.0);
     if ($95) {
      $96 = Math_fround($92 + Math_fround(0.054999999701976776123));
      $97 = Math_fround($96 / Math_fround(1.05499994754791259766));
      $98 = (Math_fround(+(Math_pow((+$97),2.40000009536743164063))));
      $$0$i$i$i = $98;
      break;
     } else {
      $99 = (Math_fround(+(Math_pow((+$92),2.40000009536743164063))));
      $$0$i$i$i = $99;
      break;
     }
    } else {
     $94 = Math_fround($92 / Math_fround(12.9200000762939453125));
     $$0$i$i$i = $94;
    }
   } while(0);
   $100 = (($12) + 144|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = !($101 <= Math_fround(0.0404499992728233337402));
   do {
    if ($102) {
     $104 = $101 < Math_fround(1.0);
     if ($104) {
      $105 = Math_fround($101 + Math_fround(0.054999999701976776123));
      $106 = Math_fround($105 / Math_fround(1.05499994754791259766));
      $107 = (Math_fround(+(Math_pow((+$106),2.40000009536743164063))));
      $$0$i3$i$i = $107;
      break;
     } else {
      $108 = (Math_fround(+(Math_pow((+$101),2.40000009536743164063))));
      $$0$i3$i$i = $108;
      break;
     }
    } else {
     $103 = Math_fround($101 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i = $103;
    }
   } while(0);
   $109 = (($12) + 148|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = !($110 <= Math_fround(0.0404499992728233337402));
   if (!($111)) {
    $112 = Math_fround($110 / Math_fround(12.9200000762939453125));
    $126 = $$0$i$i$i;$128 = $$0$i3$i$i;$130 = $112;
    break;
   }
   $113 = $110 < Math_fround(1.0);
   if ($113) {
    $114 = Math_fround($110 + Math_fround(0.054999999701976776123));
    $115 = Math_fround($114 / Math_fround(1.05499994754791259766));
    $116 = (Math_fround(+(Math_pow((+$115),2.40000009536743164063))));
    $126 = $$0$i$i$i;$128 = $$0$i3$i$i;$130 = $116;
    break;
   } else {
    $117 = (Math_fround(+(Math_pow((+$110),2.40000009536743164063))));
    $126 = $$0$i$i$i;$128 = $$0$i3$i$i;$130 = $117;
    break;
   }
  } else {
   $118 = (($12) + 144|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = (($12) + 148|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $126 = $92;$128 = $119;$130 = $121;
  }
 } while(0);
 $$in = (($12) + 152|0);
 $122 = Math_fround(HEAPF32[$$in>>2]);
 $123 = (($12) + 184|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = Math_fround($126 * $124);
 $127 = Math_fround($128 * $124);
 $129 = Math_fround($130 * $124);
 $131 = Math_fround($122 * $124);
 $132 = Math_fround($125 * Math_fround(2.0));
 $133 = Math_fround($127 * Math_fround(2.0));
 $134 = Math_fround($129 * Math_fround(2.0));
 $135 = Math_fround($131 * Math_fround(2.0));
 HEAPF32[$lightCol>>2] = $132;
 $136 = (($lightCol) + 4|0);
 HEAPF32[$136>>2] = $133;
 $137 = (($lightCol) + 8|0);
 HEAPF32[$137>>2] = $134;
 $138 = (($lightCol) + 12|0);
 HEAPF32[$138>>2] = $135;
 $139 = HEAP32[$13>>2]|0;
 if ((($139|0) == 2)) {
  $150 = (($12) + 40|0);
  $151 = (($43) + 3556|0);
  dest=$151+0|0; src=$150+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 } else if ((($139|0) == 0)) {
  $140 = (($12) + 40|0);
  dest=$$byval_copy4+0|0; src=$140+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  HEAPF32[$1>>2] = Math_fround(-0.5);
  $141 = (($1) + 4|0);
  HEAPF32[$141>>2] = Math_fround(-0.5);
  $142 = (($1) + 8|0);
  HEAPF32[$142>>2] = Math_fround(1.0);
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($temp1,$1)|0);
  HEAPF32[$2>>2] = Math_fround(0.5);
  $143 = (($2) + 4|0);
  HEAPF32[$143>>2] = Math_fround(0.5);
  $144 = (($2) + 8|0);
  HEAPF32[$144>>2] = Math_fround(0.0);
  (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($temp2,$2)|0);
  $145 = (($12) + 200|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($12) + 188|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  (__ZN10Matrix4x4f19SetPerspectiveCotanEfff($temp3,$146,Math_fround(0.0),$148)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp2,$temp3,$temp4);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp4,$temp1,$temp2);
  $149 = (($43) + 3556|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp2,$$byval_copy4,$149);
 } else if ((($139|0) == 1)) {
  $152 = (($12) + 196|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  $154 = Math_fround(Math_fround(1.0) / $153);
  HEAPF32[$3>>2] = $154;
  $155 = (($3) + 4|0);
  HEAPF32[$155>>2] = $154;
  $156 = (($3) + 8|0);
  HEAPF32[$156>>2] = Math_fround(0.0);
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($temp1,$3)|0);
  HEAPF32[$4>>2] = Math_fround(0.5);
  $157 = (($4) + 4|0);
  HEAPF32[$157>>2] = Math_fround(0.5);
  $158 = (($4) + 8|0);
  HEAPF32[$158>>2] = Math_fround(0.0);
  (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($temp2,$4)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp2,$temp1,$temp3);
  $159 = (($12) + 40|0);
  $160 = (($43) + 3556|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp3,$159,$160);
 }
 $161 = HEAP32[568656>>2]|0;
 __Z22AssignCookieToMaterialRK5LightPN5Unity8MaterialE($12,$161);
 $162 = (($light) + 20|0);
 $163 = HEAP8[$162>>0]|0;
 $164 = ($163<<24>>24)==(0);
 if ($164) {
  label = 41;
 } else {
  $165 = (($light) + 21|0);
  $166 = HEAP8[$165>>0]|0;
  $167 = ($166<<24>>24)==(0);
  if ($167) {
   label = 41;
  } else {
   $172 = 1;
  }
 }
 if ((label|0) == 41) {
  $168 = HEAP32[$13>>2]|0;
  $169 = ($168|0)==(1);
  $172 = $169;
 }
 $170 = (($passContext) + 20|0);
 $171 = $172 ? Math_fround(1.0) : Math_fround(0.0);
 __ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf($170,568600,$171);
 $173 = Math_fround(HEAPF32[$lightPos>>2]);
 $174 = Math_fround(HEAPF32[$31>>2]);
 $175 = Math_fround(HEAPF32[$32>>2]);
 $176 = (($12) + 188|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = Math_fround($177 * $177);
 $179 = Math_fround(Math_fround(1.0) / $178);
 HEAPF32[$5>>2] = $173;
 $180 = (($5) + 4|0);
 HEAPF32[$180>>2] = $174;
 $181 = (($5) + 8|0);
 HEAPF32[$181>>2] = $175;
 $182 = (($5) + 12|0);
 HEAPF32[$182>>2] = $179;
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($170,568480,$5);
 HEAPF32[$6>>2] = $84;
 $183 = (($6) + 4|0);
 HEAPF32[$183>>2] = $86;
 $184 = (($6) + 8|0);
 HEAPF32[$184>>2] = $88;
 $185 = (($6) + 12|0);
 HEAPF32[$185>>2] = Math_fround(0.0);
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($170,568504,$6);
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($170,568528,$lightCol);
 $186 = HEAP32[568656>>2]|0;
 HEAP32[$$byval_copy4>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy4,568816);
 $187 = HEAP32[$$byval_copy4>>2]|0;
 HEAP32[$7>>2] = $187;
 $188 = (__ZN10builtintex21GetAttenuationTextureEv()|0);
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$7+0>>2]|0;
 __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($186,$$byval_copy4,$188);
 _memcpy(($temp4|0),($shadowCullData|0),612)|0;
 $189 = (($light) + 4|0);
 $190 = HEAP32[$189>>2]|0;
 $191 = ($190|0)==(0|0);
 do {
  if ($191) {
   label = 59;
  } else {
   $192 = Math_fround(HEAPF32[$receiverBounds>>2]);
   $193 = Math_fround(HEAPF32[616664>>2]);
   $194 = $192 == $193;
   if ($194) {
    $195 = (($receiverBounds) + 4|0);
    $196 = Math_fround(HEAPF32[$195>>2]);
    $197 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
    $198 = $196 == $197;
    if ($198) {
     $199 = (($receiverBounds) + 8|0);
     $200 = Math_fround(HEAPF32[$199>>2]);
     $201 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
     $202 = $200 == $201;
     if ($202) {
      label = 59;
      break;
     }
    }
   }
   $203 = Math_fround(-$193);
   $204 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
   $205 = Math_fround(-$204);
   $206 = (($receiverBounds) + 12|0);
   $207 = Math_fround(HEAPF32[$206>>2]);
   $208 = $207 == $203;
   if ($208) {
    $209 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
    $210 = Math_fround(-$209);
    $211 = (($receiverBounds) + 16|0);
    $212 = Math_fround(HEAPF32[$211>>2]);
    $213 = $212 == $210;
    if ($213) {
     $214 = (($receiverBounds) + 20|0);
     $215 = Math_fround(HEAPF32[$214>>2]);
     $phitmp = $215 == $205;
     $217 = $phitmp;
    } else {
     $217 = 0;
    }
   } else {
    $217 = 0;
   }
   $216 = ($shadowQuality|0)==(0);
   $or$cond = $217 | $216;
   if ($or$cond) {
    label = 59;
   } else {
    $218 = HEAP32[$33>>2]|0;
    $219 = ($shadowQuality|0)!=(1);
    $220 = ($218|0)==(0);
    $or$cond1 = $219 | $220;
    $lightShadows1$0 = $or$cond1 ? $218 : 1;
    $221 = HEAP32[$13>>2]|0;
    __Z18SetShadowsKeywordsRN9ShaderLab17ShaderPassContextE9LightType10ShadowTypebb($passContext,$221,$lightShadows1$0,0,1);
    $222 = HEAP32[$43>>2]|0;
    $223 = (($222) + 100|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = (($ctx) + 12|0);
    FUNCTION_TABLE_vii[$224 & 4095]($43,$225);
    $226 = HEAP32[$43>>2]|0;
    $227 = (($226) + 64|0);
    $228 = HEAP32[$227>>2]|0;
    FUNCTION_TABLE_viii[$228 & 4095]($43,$devStDisabled,0);
    $229 = HEAP32[$43>>2]|0;
    $230 = (($229) + 408|0);
    $231 = HEAP32[$230>>2]|0;
    FUNCTION_TABLE_vi[$231 & 4095]($43);
    $232 = (__Z16RenderShadowMapsR16ShadowCameraDataRK11ActiveLightRK10MinMaxAABBRN9ShaderLab17ShaderPassContextEP10Matrix4x4f($temp4,$light,$receiverBounds,$passContext,$shadowMatrices)|0);
    $233 = ($232|0)==(0|0);
    do {
     if ($233) {
      __Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE($passContext);
      $shadowMap$1 = 0;
     } else {
      $234 = (($12) + 124|0);
      $235 = Math_fround(HEAPF32[$234>>2]);
      $236 = Math_fround(Math_fround(1.0) - $235);
      $237 = (($43) + 772|0);
      HEAPF32[$237>>2] = $236;
      $238 = (($43) + 776|0);
      HEAPF32[$238>>2] = Math_fround(0.0);
      $239 = (($43) + 780|0);
      HEAPF32[$239>>2] = Math_fround(0.0);
      $240 = (($43) + 784|0);
      HEAPF32[$240>>2] = Math_fround(0.0);
      $241 = HEAP32[$13>>2]|0;
      if ((($241|0) == 1)) {
       $242 = (($43) + 3044|0);
       dest=$242+0|0; src=$shadowMatrices+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $243 = (($temp4) + 616|0);
       $244 = (($temp4) + 656|0);
       $245 = (($232) + 100|0);
       $246 = HEAP32[$245>>2]|0;
       $247 = (Math_fround(($246|0)));
       $248 = (($232) + 104|0);
       $249 = HEAP32[$248>>2]|0;
       $250 = (Math_fround(($249|0)));
       HEAPF32[$8>>2] = $247;
       $251 = (($8) + 4|0);
       HEAPF32[$251>>2] = $250;
       __Z29SetCascadedShadowShaderParamsPK10Matrix4x4fPKfPK8Vector4fRK8Vector2f($shadowMatrices,$243,$244,$8);
       $252 = HEAP32[$ctx>>2]|0;
       $253 = (($12) + 132|0);
       $254 = Math_fround(HEAPF32[$253>>2]);
       $255 = (($12) + 136|0);
       $256 = Math_fround(HEAPF32[$255>>2]);
       $257 = (__Z27ComputeScreenSpaceShadowMapRK6CameraP13RenderTextureff10ShadowTypeRN9ShaderLab17ShaderPassContextE($252,$232,$254,$256,$lightShadows1$0,$passContext)|0);
       $shadowMap$0 = $257;
      } else if ((($241|0) == 0)) {
       $258 = (($43) + 3044|0);
       dest=$258+0|0; src=$shadowMatrices+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $shadowMap$0 = $232;
      } else {
       $shadowMap$0 = $232;
      }
      $259 = HEAP32[$shadowMap$0>>2]|0;
      $260 = (($259) + 116|0);
      $261 = HEAP32[$260>>2]|0;
      $262 = (FUNCTION_TABLE_ii[$261 & 4095]($shadowMap$0)|0);
      $263 = (Math_fround(($262|0)));
      $264 = Math_fround(Math_fround(0.5) / $263);
      $265 = HEAP32[$shadowMap$0>>2]|0;
      $266 = (($265) + 120|0);
      $267 = HEAP32[$266>>2]|0;
      $268 = (FUNCTION_TABLE_ii[$267 & 4095]($shadowMap$0)|0);
      $269 = (Math_fround(($268|0)));
      $270 = Math_fround(Math_fround(0.5) / $269);
      $271 = Math_fround(-$264);
      $272 = Math_fround(-$270);
      $273 = (($43) + 708|0);
      HEAPF32[$273>>2] = $271;
      $274 = (($43) + 712|0);
      HEAPF32[$274>>2] = $272;
      $275 = (($43) + 716|0);
      HEAPF32[$275>>2] = Math_fround(0.0);
      $276 = (($43) + 720|0);
      HEAPF32[$276>>2] = Math_fround(0.0);
      $277 = (($43) + 724|0);
      HEAPF32[$277>>2] = $264;
      $278 = (($43) + 728|0);
      HEAPF32[$278>>2] = $272;
      $279 = (($43) + 732|0);
      HEAPF32[$279>>2] = Math_fround(0.0);
      $280 = (($43) + 736|0);
      HEAPF32[$280>>2] = Math_fround(0.0);
      $281 = (($43) + 740|0);
      HEAPF32[$281>>2] = $271;
      $282 = (($43) + 744|0);
      HEAPF32[$282>>2] = $270;
      $283 = (($43) + 748|0);
      HEAPF32[$283>>2] = Math_fround(0.0);
      $284 = (($43) + 752|0);
      HEAPF32[$284>>2] = Math_fround(0.0);
      $285 = (($43) + 756|0);
      HEAPF32[$285>>2] = $264;
      $286 = (($43) + 760|0);
      HEAPF32[$286>>2] = $270;
      $287 = (($43) + 764|0);
      HEAPF32[$287>>2] = Math_fround(0.0);
      $288 = (($43) + 768|0);
      HEAPF32[$288>>2] = Math_fround(0.0);
      $289 = HEAP32[568656>>2]|0;
      $290 = HEAP32[568624>>2]|0;
      HEAP32[$9>>2] = $290;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$9+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($289,$$byval_copy4,$shadowMap$0);
      $291 = HEAP32[$rtLight>>2]|0;
      $292 = ($291|0)==(0|0);
      if ($292) {
       HEAP32[$11>>2] = $45;
       ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$11+0>>2]|0;
       (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rtSurfaceMainColor,$$byval_copy4,$rtMain,0,-1,0)|0);
       $shadowMap$1 = $shadowMap$0;
       break;
      } else {
       HEAP32[$10>>2] = $45;
       ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$10+0>>2]|0;
       (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rtSurfaceColor,$$byval_copy4,$291,0,-1,0)|0);
       $shadowMap$1 = $shadowMap$0;
       break;
      }
     }
    } while(0);
    $293 = HEAP32[$43>>2]|0;
    $294 = (($293) + 104|0);
    $295 = HEAP32[$294>>2]|0;
    $296 = (($mvpState) + 128|0);
    FUNCTION_TABLE_vii[$295 & 4095]($43,$296);
    $297 = HEAP32[$43>>2]|0;
    $298 = (($297) + 100|0);
    $299 = HEAP32[$298>>2]|0;
    $300 = (($mvpState) + 64|0);
    FUNCTION_TABLE_vii[$299 & 4095]($43,$300);
    __Z27SetClippingPlaneShaderPropsv();
    $301 = HEAP32[$43>>2]|0;
    $302 = (($301) + 136|0);
    $303 = HEAP32[$302>>2]|0;
    FUNCTION_TABLE_vii[$303 & 4095]($43,0);
    $shadowMap$2 = $shadowMap$1;
   }
  }
 } while(0);
 if ((label|0) == 59) {
  __Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE($passContext);
  $shadowMap$2 = 0;
 }
 $304 = $lightPassAddBits;
 $305 = $304;
 HEAP32[$305>>2] = 64;
 $306 = (($304) + 4)|0;
 $307 = $306;
 HEAP32[$307>>2] = 0;
 $308 = ($$0$i|0)==(0);
 if ($308) {
  HEAP32[$lightPassAddBits>>2] = 0;
  $lightPassCount$0 = 1;
 } else {
  $309 = ($$0$i|0)!=(1);
  $310 = ($lightmapsMode|0)==(1);
  $or$cond2 = $309 | $310;
  if ($or$cond2) {
   $lightPassCount$0 = 2;
  } else {
   HEAP32[$lightPassAddBits>>2] = 64;
   $lightPassCount$0 = 1;
  }
 }
 $311 = HEAP8[$162>>0]|0;
 $312 = ($311<<24>>24)==(0);
 $313 = (($light) + 21|0);
 do {
  if ($312) {
   $314 = HEAP8[$313>>0]|0;
   $$not3 = ($314<<24>>24)!=(0);
   $$not4 = $308 ^ 1;
   $brmerge = $$not3 | $$not4;
   if ($brmerge) {
    label = 68;
   } else {
    $315 = HEAP32[$13>>2]|0;
    $316 = ($315|0)==(0);
    if ($316) {
     $317 = (__Z9LightMaskRK5LightRK14LightingLayers($12,$lightingLayers)|0);
     $363 = $317;
    } else {
     $319 = ($315|0)==(2);
     $320 = (__Z9LightMaskRK5LightRK14LightingLayers($12,$lightingLayers)|0);
     if ($319) {
      $363 = $320;
     } else {
      $$ph = $320;$$ph29 = 0;
      break;
     }
    }
    $321 = (__ZN5Unity8Material10GetDefaultEv()|0);
    $322 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($321,0,$passContext,0,1)|0);
    $323 = (($blendstate) + 4|0);
    HEAP8[$323>>0] = 1;
    $324 = (($blendstate) + 5|0);
    HEAP8[$324>>0] = 0;
    $325 = (($blendstate) + 6|0);
    HEAP8[$325>>0] = 1;
    $326 = (($blendstate) + 7|0);
    ;HEAP8[$326+0>>0]=0|0;HEAP8[$326+1>>0]=0|0;HEAP8[$326+2>>0]=0|0;HEAP8[$326+3>>0]=0|0;HEAP8[$326+4>>0]=0|0;
    HEAP32[$blendstate>>2] = 0;
    $327 = HEAP32[$43>>2]|0;
    $328 = (($327) + 52|0);
    $329 = HEAP32[$328>>2]|0;
    $330 = (($327) + 32|0);
    $331 = HEAP32[$330>>2]|0;
    $332 = (FUNCTION_TABLE_iii[$331 & 4095]($43,$blendstate)|0);
    FUNCTION_TABLE_viif[$329 & 63]($43,$332,Math_fround(0.0));
    $333 = $rasterstate;
    $334 = $333;
    HEAP32[$334>>2] = 0;
    $335 = (($333) + 4)|0;
    $336 = $335;
    HEAP32[$336>>2] = 0;
    $337 = (($rasterstate) + 4|0);
    HEAP32[$337>>2] = 0;
    $338 = (($rasterstate) + 8|0);
    HEAPF32[$338>>2] = Math_fround(0.0);
    HEAP32[$rasterstate>>2] = 0;
    $339 = HEAP32[$43>>2]|0;
    $340 = (($339) + 56|0);
    $341 = HEAP32[$340>>2]|0;
    $342 = (($339) + 44|0);
    $343 = HEAP32[$342>>2]|0;
    $344 = (FUNCTION_TABLE_iii[$343 & 4095]($43,$rasterstate)|0);
    FUNCTION_TABLE_vii[$341 & 4095]($43,$344);
    $345 = (($depthstate) + 1|0);
    HEAP8[$depthstate>>0] = 0;
    HEAP8[$345>>0] = 4;
    $346 = HEAP32[$43>>2]|0;
    $347 = (($346) + 60|0);
    $348 = HEAP32[$347>>2]|0;
    $349 = (($346) + 36|0);
    $350 = HEAP32[$349>>2]|0;
    $351 = (FUNCTION_TABLE_iii[$350 & 4095]($43,$depthstate)|0);
    FUNCTION_TABLE_vii[$348 & 4095]($43,$351);
    $352 = (($lightStencil) + 1|0);
    $353 = (($lightStencil) + 2|0);
    $354 = (($lightStencil) + 4|0);
    $355 = (($lightStencil) + 5|0);
    $356 = (($lightStencil) + 6|0);
    HEAP8[$356>>0] = 0;
    $357 = (($lightStencil) + 7|0);
    $358 = (($lightStencil) + 8|0);
    $359 = (($lightStencil) + 9|0);
    $360 = (($lightStencil) + 10|0);
    HEAP8[$360>>0] = 0;
    $361 = (($lightStencil) + 11|0);
    HEAP8[$lightStencil>>0] = 1;
    HEAP8[$352>>0] = -1;
    HEAP8[$353>>0] = 16;
    HEAP8[$361>>0] = 5;
    HEAP8[$357>>0] = 5;
    HEAP8[$359>>0] = 0;
    HEAP8[$355>>0] = 0;
    $362 = ($363|0)!=(0);
    $364 = $362 ? 6 : 8;
    HEAP8[$358>>0] = $364;
    HEAP8[$354>>0] = $364;
    $365 = HEAP32[$43>>2]|0;
    $366 = (($365) + 64|0);
    $367 = HEAP32[$366>>2]|0;
    $368 = (($365) + 40|0);
    $369 = HEAP32[$368>>2]|0;
    $370 = (FUNCTION_TABLE_iii[$369 & 4095]($43,$lightStencil)|0);
    $371 = $363 | 192;
    FUNCTION_TABLE_viii[$367 & 4095]($43,$370,$371);
    __Z15RenderLightGeomRK17RenderLoopContextRK11ActiveLightRK8Vector3fRK10Matrix4x4fbPK14ChannelAssigns($ctx,$light,$lightPos,$lightMatrix,$172,$322);
    HEAP32[$blendstate>>2] = 15;
    $372 = HEAP32[$43>>2]|0;
    $373 = (($372) + 52|0);
    $374 = HEAP32[$373>>2]|0;
    $375 = (($372) + 32|0);
    $376 = HEAP32[$375>>2]|0;
    $377 = (FUNCTION_TABLE_iii[$376 & 4095]($43,$blendstate)|0);
    FUNCTION_TABLE_viif[$374 & 63]($43,$377,Math_fround(0.0));
    $$ph = $363;$$ph29 = 1;
   }
  } else {
   label = 68;
  }
 } while(0);
 if ((label|0) == 68) {
  $318 = (__Z9LightMaskRK5LightRK14LightingLayers($12,$lightingLayers)|0);
  $$ph = $318;$$ph29 = 0;
 }
 $378 = (($lightFade) + 8|0);
 $379 = (($lightFade) + 12|0);
 $380 = (($lightFade) + 4|0);
 $381 = (($12) + 124|0);
 $382 = (($43) + 676|0);
 $383 = (($43) + 684|0);
 $384 = (($43) + 688|0);
 $385 = (($43) + 772|0);
 $386 = (($43) + 776|0);
 $387 = (($43) + 780|0);
 $388 = (($43) + 784|0);
 $389 = (($stencil) + 1|0);
 $390 = (($stencil) + 2|0);
 $391 = (($stencil) + 4|0);
 $392 = (($stencil) + 5|0);
 $393 = (($stencil) + 6|0);
 $394 = (($stencil) + 7|0);
 $395 = (($stencil) + 8|0);
 $396 = (($stencil) + 9|0);
 $397 = (($stencil) + 10|0);
 $398 = (($stencil) + 11|0);
 $399 = ($$0$i|0)==(1);
 $$6 = $399 ? -64 : -128;
 $$not7 = $399 ^ 1;
 $400 = (($rasterstate3) + 4|0);
 $401 = (($rasterstate3) + 8|0);
 $402 = (($depthstate4) + 1|0);
 $403 = $$6&255;
 $404 = $403 | 32;
 $405 = $404&255;
 $pp$030 = 0;
 while(1) {
  $406 = $lightFade;
  $407 = $406;
  $408 = HEAP32[$407>>2]|0;
  $409 = (($406) + 4)|0;
  $410 = $409;
  $411 = HEAP32[$410>>2]|0;
  $412 = Math_fround(HEAPF32[$378>>2]);
  $413 = Math_fround(HEAPF32[$379>>2]);
  $414 = Math_fround(HEAPF32[$380>>2]);
  $415 = Math_fround(HEAPF32[$381>>2]);
  $416 = Math_fround(Math_fround(1.0) - $415);
  $417 = ($pp$030|0)==(0);
  $brmerge5 = $417 | $308;
  $$19 = $brmerge5 ? Math_fround(0.0) : $413;
  $$20 = $brmerge5 ? Math_fround(0.0) : $412;
  $$21 = $brmerge5 ? $413 : Math_fround(0.0);
  $$22 = $brmerge5 ? $412 : Math_fround(0.0);
  $418 = $382;
  $419 = $418;
  HEAP32[$419>>2] = $408;
  $420 = (($418) + 4)|0;
  $421 = $420;
  HEAP32[$421>>2] = $411;
  HEAPF32[$383>>2] = $$20;
  HEAPF32[$384>>2] = $$19;
  HEAPF32[$385>>2] = $416;
  HEAPF32[$386>>2] = $414;
  HEAPF32[$387>>2] = $$22;
  HEAPF32[$388>>2] = $$21;
  $422 = HEAP32[568656>>2]|0;
  $423 = (($422) + 32|0);
  $424 = HEAP32[$423>>2]|0;
  $425 = ($424|0)==(0|0);
  if ($425) {
   __ZN5Unity8Material15BuildPropertiesEv($422);
   $$pre$i = HEAP32[$423>>2]|0;
   $427 = $$pre$i;
  } else {
   $427 = $424;
  }
  $426 = (($427) + 48|0);
  $428 = HEAP32[$426>>2]|0;
  $429 = (($427) + 48|0);
  $430 = ($428|0)==(0|0);
  if (!($430)) {
   $431 = HEAP32[568552>>2]|0;
   $$0$ph7$i$i$i$i = $429;$$01$ph6$i$in$i$i$i = $428;
   L106: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $432 = (($$013$i$in$i$i$i) + 16|0);
     $433 = HEAP32[$432>>2]|0;
     $434 = ($433|0)<($431|0);
     if (!($434)) {
      break;
     }
     $437 = (($$013$i$in$i$i$i) + 4|0);
     $438 = HEAP32[$437>>2]|0;
     $439 = ($438|0)==(0|0);
     if ($439) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L106;
     } else {
      $$013$i$in$i$i$i = $438;
     }
    }
    $435 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $436 = ($435|0)==(0|0);
    if ($436) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $435;
    }
   }
   $440 = ($$0$ph5$i$i$i$i|0)==($429|0);
   if (!($440)) {
    $441 = (($$0$ph5$i$i$i$i) + 16|0);
    $442 = HEAP32[$441>>2]|0;
    $443 = ($431|0)<($442|0);
    if (!($443)) {
     $444 = (($$0$ph5$i$i$i$i) + 20|0);
     $445 = HEAP32[$444>>2]|0;
     $446 = ($445|0)==(0|0);
     if (!($446)) {
      __ZN9ShaderLab6TexEnv21TextureMipBiasChangedEf($445,Math_fround(-8.0));
     }
    }
   }
  }
  $447 = HEAP32[$ctx>>2]|0;
  $448 = (($447) + 620|0);
  $449 = HEAP8[$448>>0]|0;
  $450 = ($449<<24>>24)==(0);
  $451 = HEAP32[568656>>2]|0;
  if ($450) {
   $453 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($451,0,$passContext,0,1)|0);
   $channels2$0 = $453;
  } else {
   $452 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($451,1,$passContext,0,1)|0);
   $channels2$0 = $452;
  }
  HEAP8[$389>>0] = -1;
  HEAP8[$390>>0] = -1;
  HEAP8[$392>>0] = 0;
  HEAP8[$393>>0] = 0;
  HEAP8[$394>>0] = 0;
  HEAP8[$396>>0] = 0;
  HEAP8[$397>>0] = 0;
  HEAP8[$398>>0] = 0;
  HEAP8[$stencil>>0] = 1;
  HEAP8[$395>>0] = 3;
  HEAP8[$391>>0] = 3;
  $brmerge8 = $417 | $$not7;
  $$6$ = $brmerge8 ? $$6 : $405;
  $454 = $$6$&255;
  $455 = $454 | $$ph;
  $456 = $455&255;
  HEAP8[$389>>0] = $456;
  $457 = (($lightPassAddBits) + ($pp$030<<2)|0);
  $458 = HEAP32[$457>>2]|0;
  $459 = (($458) + 128)|0;
  if ($$ph29) {
   HEAP8[$390>>0] = 16;
   HEAP8[$398>>0] = 1;
   HEAP8[$394>>0] = 1;
   HEAP8[$396>>0] = 1;
   HEAP8[$392>>0] = 1;
   HEAP8[$397>>0] = 1;
   HEAP8[$393>>0] = 1;
   $460 = $455 | 16;
   $461 = $460&255;
   HEAP8[$389>>0] = $461;
   $462 = $459 | 16;
   $stencilRef$0 = $462;
  } else {
   $stencilRef$0 = $459;
  }
  $463 = HEAP32[$43>>2]|0;
  $464 = (($463) + 40|0);
  $465 = HEAP32[$464>>2]|0;
  $466 = (FUNCTION_TABLE_iii[$465 & 4095]($43,$stencil)|0);
  $467 = HEAP32[$43>>2]|0;
  $468 = (($467) + 64|0);
  $469 = HEAP32[$468>>2]|0;
  FUNCTION_TABLE_viii[$469 & 4095]($43,$466,$stencilRef$0);
  $470 = $rasterstate3;
  $471 = $470;
  HEAP32[$471>>2] = 0;
  $472 = (($470) + 4)|0;
  $473 = $472;
  HEAP32[$473>>2] = 0;
  HEAP32[$rasterstate3>>2] = 2;
  HEAP32[$400>>2] = 0;
  HEAPF32[$401>>2] = Math_fround(0.0);
  HEAP8[$402>>0] = 2;
  HEAP8[$depthstate4>>0] = 0;
  $474 = HEAP8[$162>>0]|0;
  $475 = ($474<<24>>24)==(0);
  if ($475) {
   $storemerge24 = 4;
  } else {
   $476 = HEAP8[$313>>0]|0;
   $477 = ($476<<24>>24)==(0);
   if ($477) {
    $478 = HEAP32[$13>>2]|0;
    if ((($478|0) == 2) | (($478|0) == 0)) {
     HEAP32[$rasterstate3>>2] = 1;
     $storemerge24 = 5;
    } else {
     $storemerge24 = 4;
    }
   } else {
    $storemerge24 = 4;
   }
  }
  HEAP8[$402>>0] = $storemerge24;
  $479 = HEAP32[$43>>2]|0;
  $480 = (($479) + 56|0);
  $481 = HEAP32[$480>>2]|0;
  $482 = (($479) + 44|0);
  $483 = HEAP32[$482>>2]|0;
  $484 = (FUNCTION_TABLE_iii[$483 & 4095]($43,$rasterstate3)|0);
  FUNCTION_TABLE_vii[$481 & 4095]($43,$484);
  $485 = HEAP32[$43>>2]|0;
  $486 = (($485) + 60|0);
  $487 = HEAP32[$486>>2]|0;
  $488 = (($485) + 36|0);
  $489 = HEAP32[$488>>2]|0;
  $490 = (FUNCTION_TABLE_iii[$489 & 4095]($43,$depthstate4)|0);
  FUNCTION_TABLE_vii[$487 & 4095]($43,$490);
  __Z15RenderLightGeomRK17RenderLoopContextRK11ActiveLightRK8Vector3fRK10Matrix4x4fbPK14ChannelAssigns($ctx,$light,$lightPos,$lightMatrix,$172,$channels2$0);
  $491 = (($pp$030) + 1)|0;
  $492 = ($491|0)<($lightPassCount$0|0);
  if ($492) {
   $pp$030 = $491;
  } else {
   break;
  }
 }
 $493 = ($shadowMap$2|0)==(0|0);
 $brmerge9 = $493 | $returnShadowMap;
 if ($brmerge9) {
  $495 = $returnShadowMap ? $shadowMap$2 : 0;
  STACKTOP = sp;return ($495|0);
 }
 $494 = (__Z22GetRenderBufferManagerv()|0);
 __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($494,$shadowMap$2);
 $495 = $returnShadowMap ? $shadowMap$2 : 0;
 STACKTOP = sp;return ($495|0);
}
function __ZN17PrePassRenderLoop14RenderBasePassEP13RenderTextureRK14LightingLayersR13dynamic_arrayI16RenderObjectDataLj4EER10MinMaxAABB($this,$rtMain,$lightingLayers,$outRemainingObjects,$receiverBounds) {
 $this = $this|0;
 $rtMain = $rtMain|0;
 $lightingLayers = $lightingLayers|0;
 $outRemainingObjects = $outRemainingObjects|0;
 $receiverBounds = $receiverBounds|0;
 var $$ = 0, $$7 = 0, $$8 = 0, $$byval_copy13 = 0, $$off$i = 0, $$off0 = 0, $$off0$ = 0, $$old20 = 0, $$pre = 0, $$pre$i = 0, $$sink$i$i$i = Math_fround(0), $$sink$i1$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0);
 var $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0);
 var $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0);
 var $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0);
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0);
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0;
 var $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0);
 var $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = 0, $402 = Math_fround(0), $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = Math_fround(0);
 var $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0);
 var $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = Math_fround(0), $473 = 0, $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = Math_fround(0), $478 = Math_fround(0), $479 = 0, $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = 0, $483 = Math_fround(0);
 var $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = Math_fround(0), $497 = 0, $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = 0, $500 = Math_fround(0);
 var $501 = 0, $502 = Math_fround(0), $503 = 0, $504 = Math_fround(0), $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = 0, $535 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $batchRenderer = 0, $black = 0, $channels$043 = 0, $channels$132 = 0, $channels$132$us = 0, $channels$2 = 0, $channels$2$us = 0, $channels$3 = 0, $channels$3$us = 0, $channels$4 = 0, $defaultReflection = 0, $i$040 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index4 = 0, $notlhs = 0, $notlhs23 = 0, $notrhs = 0, $notrhs24 = 0, $or$cond = 0, $or$cond$us = 0, $or$cond16 = 0, $or$cond17 = 0, $or$cond18$not = 0, $or$cond19$not = 0, $or$cond21 = 0, $or$cond22 = 0, $p$033 = 0, $p$033$us = 0, $phitmp1 = 0, $prevPassIndex$042 = 0, $prevPassIndex$131 = 0, $prevPassIndex$131$us = 0;
 var $prevPassIndex$4 = 0, $prevPassIndex$4$us = 0, $prevPassIndex$5 = 0, $prevStencilRef$041 = 0, $prevStencilRef$130 = 0, $prevStencilRef$130$us = 0, $prevStencilRef$3 = 0, $prevStencilRef$3$us = 0, $prevStencilRef$4 = 0, $prevStencilRef$4$us = 0, $prevStencilRef$5 = 0, $reflection = 0, $reflectionProbeCache = 0, $resetPass$0$off0 = 0, $resetPass$1$off029 = 0, $resetPass$1$off029$us = 0, $resetPass$2$off014 = 0, $resetPass$2$off014$us = 0, $resetPass$3$off0 = 0, $resetPass$3$off0$us = 0;
 var $rtSurfaceColor = 0, $stRender = 0, $stats = 0, $stencilRef$0$ = 0, $stencilRef$0$$us = 0, $stencilRef$2 = 0, $stencilRef$2$us = 0, $withinShadowDistance$0$off0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $$byval_copy13 = sp + 504|0;
 $0 = sp + 500|0;
 $1 = sp + 496|0;
 $stRender = sp + 484|0;
 $rtSurfaceColor = sp + 480|0;
 $2 = sp + 352|0;
 $black = sp + 336|0;
 $defaultReflection = sp + 208|0;
 $stats = sp + 508|0;
 $batchRenderer = sp + 132|0;
 $reflectionProbeCache = sp;
 $reflection = sp + 356|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 580|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = HEAP32[652824>>2]|0;
 $9 = (__Z12GetGfxDevicev()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 136|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vii[$12 & 4095]($9,0);
 $13 = (($stRender) + 1|0);
 HEAP8[$13>>0] = -1;
 $14 = (($stRender) + 2|0);
 $15 = (($stRender) + 4|0);
 HEAP8[$15>>0] = 8;
 $16 = (($stRender) + 5|0);
 $17 = (($stRender) + 6|0);
 HEAP8[$17>>0] = 0;
 $18 = (($stRender) + 7|0);
 HEAP8[$18>>0] = 0;
 $19 = (($stRender) + 8|0);
 HEAP8[$19>>0] = 8;
 $20 = (($stRender) + 9|0);
 $21 = (($stRender) + 10|0);
 HEAP8[$21>>0] = 0;
 $22 = (($stRender) + 11|0);
 HEAP8[$22>>0] = 0;
 HEAP8[$14>>0] = -17;
 HEAP8[$stRender>>0] = 1;
 HEAP8[$20>>0] = 2;
 HEAP8[$16>>0] = 2;
 $23 = HEAP32[$9>>2]|0;
 $24 = (($23) + 40|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_iii[$25 & 4095]($9,$stRender)|0);
 $27 = (__Z22GetRenderBufferManagerv()|0);
 $28 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($27,-1,-1,0,0,0,1,1)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + 36|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vii[$32 & 4095]($28,568768);
 }
 __ZN7Texture13SetFilterModeEi($28,0);
 $33 = (($28) + 140|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $36 = (($28) + 148|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   (__ZN13RenderTexture6CreateEv($28)|0);
   $$pre = HEAP32[$33>>2]|0;
   $39 = $$pre;
  } else {
   $39 = 0;
  }
 } else {
  $39 = $34;
 }
 HEAP32[$rtSurfaceColor>>2] = $39;
 $40 = (($rtMain) + 148|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$this>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 376|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(4);
 $$ = $46 ? 1 : 7;
 $$7 = $46 ? 4 : 12;
 HEAP32[$2>>2] = $41;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$2+0>>2]|0;
 (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rtSurfaceColor,$$byval_copy13,$28,0,-1,$$7)|0);
 $47 = HEAP32[$this>>2]|0;
 $48 = (($47) + 116|0);
 $49 = HEAP32[$48>>2]|0;
 __Z23AddRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureTypeP13RenderTexture($49,8,$28);
 ;HEAP32[$black+0>>2]=0|0;HEAP32[$black+4>>2]=0|0;HEAP32[$black+8>>2]=0|0;HEAP32[$black+12>>2]=0|0;
 __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE($$,$black,Math_fround(1.0),0,$8);
 $50 = HEAP32[$9>>2]|0;
 $51 = (($50) + 100|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$this>>2]|0;
 $54 = (($53) + 12|0);
 FUNCTION_TABLE_vii[$52 & 4095]($9,$54);
 $55 = HEAP32[$this>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($57,4,$8);
 $58 = (__Z19GetReflectionProbesv()|0);
 __ZNK16ReflectionProbes16GetDefaultSampleEv($defaultReflection,$58);
 $59 = (__Z19GetLightmapSettingsv()|0);
 $60 = (__ZNK16LightmapSettings19AreLightProbesBakedEv($59)|0);
 if ($60) {
  $61 = (__ZNK16LightmapSettings22GetLightmapsModeLegacyEv($59)|0);
  $62 = ($61|0)==(1);
  if ($62) {
   $63 = (($59) + 84|0);
   $64 = HEAP32[$63>>2]|0;
   $phitmp1 = ($64|0)!=(2);
   $$off0 = $phitmp1;
  } else {
   $$off0 = 1;
  }
 } else {
  $$off0 = 0;
 }
 $65 = (__ZNK16LightmapSettings23HasLightProbeTetrahedraEv($59)|0);
 $$off0$ = $65 & $$off0;
 $66 = (($this) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 8|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = $69 >>> 4;
 $71 = (($outRemainingObjects) + 12|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $72 & 2147483647;
 $74 = ($73>>>0)<($70>>>0);
 do {
  if ($74) {
   $75 = ($72|0)>(-1);
   if ($75) {
    HEAP32[$71>>2] = $70;
    $76 = HEAP32[$outRemainingObjects>>2]|0;
    $77 = ($70*44)|0;
    $78 = (($outRemainingObjects) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    HEAP32[$0>>2] = $79;
    ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
    $80 = (__Z16realloc_internalPvji10MemLabelIdiPKci($76,$77,4,$$byval_copy13,0,568792,370)|0);
    HEAP32[$outRemainingObjects>>2] = $80;
    break;
   } else {
    $81 = ($70*44)|0;
    $82 = (($outRemainingObjects) + 4|0);
    $83 = HEAP32[$82>>2]|0;
    HEAP32[$0>>2] = $83;
    ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
    $84 = (__Z15malloc_internaljj10MemLabelIdiPKci($81,4,$$byval_copy13,0,568792,352)|0);
    $85 = HEAP32[$outRemainingObjects>>2]|0;
    $86 = (($outRemainingObjects) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87*44)|0;
    _memcpy(($84|0),($85|0),($88|0))|0;
    HEAP32[$71>>2] = $70;
    HEAP32[$outRemainingObjects>>2] = $84;
    break;
   }
  }
 } while(0);
 __ZN13BatchRendererC2ER15RenderLoopStats($batchRenderer,$stats);
 $89 = (($batchRenderer) + 68|0);
 HEAP8[$89>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1660,($reflectionProbeCache|0),($batchRenderer|0),($stats|0));
 $90 = __THREW__; __THREW__ = 0;
 $91 = $90&1;
 L18: do {
  if ($91) {
   label = 27;
  } else {
   $92 = ($69|0)==(0);
   L20: do {
    if (!($92)) {
     $93 = (($this) + 8|0);
     $94 = (($receiverBounds) + 4|0);
     $95 = (($receiverBounds) + 8|0);
     $96 = (($receiverBounds) + 12|0);
     $97 = (($receiverBounds) + 16|0);
     $98 = (($receiverBounds) + 20|0);
     $99 = (($outRemainingObjects) + 8|0);
     $100 = (($outRemainingObjects) + 4|0);
     $101 = (($9) + 5920|0);
     $102 = (($reflectionProbeCache) + 128|0);
     $260 = 0;$262 = 0;$264 = -1;$267 = Math_fround(-1.0);$283 = 16711935;$285 = -1;$channels$043 = 0;$i$040 = 0;$prevPassIndex$042 = -1;$prevStencilRef$041 = 0;
     L22: while(1) {
      $103 = HEAP32[$93>>2]|0;
      $104 = HEAP32[$66>>2]|0;
      $105 = (($103) + ($i$040<<2)|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = HEAP32[$104>>2]|0;
      $108 = (($107) + (($106*44)|0)|0);
      $109 = ((($107) + (($106*44)|0)|0) + 36|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ((($107) + (($106*44)|0)|0) + 32|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = ((($107) + (($106*44)|0)|0) + 28|0);
      $114 = Math_fround(HEAPF32[$113>>2]);
      $115 = $114 > $7;
      if ($115) {
       $116 = HEAP32[$this>>2]|0;
       $117 = (($116) + 20|0);
       $118 = Math_fround(HEAPF32[$117>>2]);
       $119 = $118 < Math_fround(0.0);
       if ($119) {
        $120 = Math_fround(-$118);
        $124 = $120;
       } else {
        $124 = $118;
       }
       $121 = (($112) + 76|0);
       $122 = Math_fround(HEAPF32[$121>>2]);
       $123 = Math_fround($124 * $122);
       $125 = (($116) + 36|0);
       $126 = Math_fround(HEAPF32[$125>>2]);
       $127 = $126 < Math_fround(0.0);
       if ($127) {
        $128 = Math_fround(-$126);
        $132 = $128;
       } else {
        $132 = $126;
       }
       $129 = (($112) + 80|0);
       $130 = Math_fround(HEAPF32[$129>>2]);
       $131 = Math_fround($132 * $130);
       $133 = Math_fround($123 + $131);
       $134 = (($116) + 52|0);
       $135 = Math_fround(HEAPF32[$134>>2]);
       $136 = $135 < Math_fround(0.0);
       if ($136) {
        $137 = Math_fround(-$135);
        $141 = $137;
       } else {
        $141 = $135;
       }
       $138 = (($112) + 84|0);
       $139 = Math_fround(HEAPF32[$138>>2]);
       $140 = Math_fround($141 * $139);
       $142 = Math_fround($133 + $140);
       $143 = Math_fround($114 - $142);
       $144 = $143 > $7;
       if ($144) {
        $withinShadowDistance$0$off0 = 0;
       } else {
        $withinShadowDistance$0$off0 = 1;
       }
      } else {
       $withinShadowDistance$0$off0 = 1;
      }
      $153 = (($112) + 120|0);
      $154 = Math_fround(HEAPF32[$153>>2]);
      $155 = HEAP32[$108>>2]|0;
      $156 = ((($107) + (($106*44)|0)|0) + 8|0);
      $157 = HEAP16[$156>>1]|0;
      $158 = $157 << 16 >> 16;
      $159 = (($112) + 116|0);
      $160 = HEAP32[$159>>2]|0;
      $161 = (($160) + 168|0);
      $162 = HEAP32[$161>>2]|0;
      $163 = ($162|0)==(0|0);
      if ($163) {
       $286 = 0;
      } else {
       $164 = (($162) + 32|0);
       $165 = HEAP32[$164>>2]|0;
       $286 = $165;
      }
      $166 = ((($107) + (($106*44)|0)|0) + 12|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = ($157<<16>>16)==(-1);
      if ($168) {
       $169 = (($110) + 52|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = (($170) + 24|0);
       $172 = HEAP32[$171>>2]|0;
       $173 = ($172|0)==(-1);
       if ($173) {
        if ($withinShadowDistance$0$off0) {
         $174 = (($160) + 42|0);
         $175 = HEAP8[$174>>0]|0;
         $176 = ($175<<24>>24)==(0);
         if (!($176)) {
          $177 = (($112) + 64|0);
          $178 = Math_fround(HEAPF32[$177>>2]);
          $179 = (($112) + 76|0);
          $180 = Math_fround(HEAPF32[$179>>2]);
          $181 = Math_fround($178 + $180);
          $182 = (($112) + 68|0);
          $183 = Math_fround(HEAPF32[$182>>2]);
          $184 = (($112) + 80|0);
          $185 = Math_fround(HEAPF32[$184>>2]);
          $186 = Math_fround($183 + $185);
          $187 = (($112) + 72|0);
          $188 = Math_fround(HEAPF32[$187>>2]);
          $189 = (($112) + 84|0);
          $190 = Math_fround(HEAPF32[$189>>2]);
          $191 = Math_fround($188 + $190);
          $192 = Math_fround(HEAPF32[$receiverBounds>>2]);
          $193 = $181 < $192;
          $194 = $193 ? $181 : $192;
          $195 = Math_fround(HEAPF32[$94>>2]);
          $196 = $186 < $195;
          $197 = $196 ? $186 : $195;
          $198 = Math_fround(HEAPF32[$95>>2]);
          $199 = $191 < $198;
          $200 = $199 ? $191 : $198;
          HEAPF32[$receiverBounds>>2] = $194;
          HEAPF32[$94>>2] = $197;
          HEAPF32[$95>>2] = $200;
          $201 = Math_fround(HEAPF32[$96>>2]);
          $202 = $201 < $181;
          $203 = $202 ? $181 : $201;
          $204 = Math_fround(HEAPF32[$97>>2]);
          $205 = $204 < $186;
          $206 = $205 ? $186 : $204;
          $207 = Math_fround(HEAPF32[$98>>2]);
          $208 = $207 < $191;
          $209 = $208 ? $191 : $207;
          HEAPF32[$96>>2] = $203;
          HEAPF32[$97>>2] = $206;
          HEAPF32[$98>>2] = $209;
          $210 = Math_fround(HEAPF32[$177>>2]);
          $211 = Math_fround(HEAPF32[$179>>2]);
          $212 = Math_fround($210 - $211);
          $213 = Math_fround(HEAPF32[$182>>2]);
          $214 = Math_fround(HEAPF32[$184>>2]);
          $215 = Math_fround($213 - $214);
          $216 = Math_fround(HEAPF32[$187>>2]);
          $217 = Math_fround(HEAPF32[$189>>2]);
          $218 = Math_fround($216 - $217);
          $219 = $212 < $194;
          $220 = $219 ? $212 : $194;
          $221 = $215 < $197;
          $222 = $221 ? $215 : $197;
          $223 = $218 < $200;
          $224 = $223 ? $218 : $200;
          HEAPF32[$receiverBounds>>2] = $220;
          HEAPF32[$94>>2] = $222;
          HEAPF32[$95>>2] = $224;
          $225 = $203 < $212;
          $226 = $225 ? $212 : $203;
          $227 = $206 < $215;
          $228 = $227 ? $215 : $206;
          $229 = $209 < $218;
          $230 = $229 ? $218 : $209;
          HEAPF32[$96>>2] = $226;
          HEAPF32[$97>>2] = $228;
          HEAPF32[$98>>2] = $230;
         }
        }
        $231 = HEAP32[$99>>2]|0;
        $232 = (($231) + 1)|0;
        HEAP32[$99>>2] = $232;
        $233 = HEAP32[$71>>2]|0;
        $234 = $233 & 2147483647;
        $235 = ($232>>>0)>($234>>>0);
        if ($235) {
         $236 = $233 << 1;
         $237 = ($236|0)==(0);
         $238 = $237 ? 1 : $236;
         $239 = ($234>>>0)<($238>>>0);
         do {
          if ($239) {
           $240 = ($233|0)>(-1);
           if ($240) {
            HEAP32[$71>>2] = $238;
            $241 = HEAP32[$outRemainingObjects>>2]|0;
            $242 = ($238*44)|0;
            $243 = HEAP32[$100>>2]|0;
            HEAP32[$0>>2] = $243;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
            $244 = (invoke_iiiiiiii(108,($241|0),($242|0),4,($$byval_copy13|0),0,(568792|0),370)|0);
            $245 = __THREW__; __THREW__ = 0;
            $246 = $245&1;
            if ($246) {
             label = 26;
             break L22;
            }
            HEAP32[$outRemainingObjects>>2] = $244;
            break;
           } else {
            $247 = ($238*44)|0;
            $248 = HEAP32[$100>>2]|0;
            HEAP32[$1>>2] = $248;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
            $249 = (invoke_iiiiiii(102,($247|0),4,($$byval_copy13|0),0,(568792|0),352)|0);
            $250 = __THREW__; __THREW__ = 0;
            $251 = $250&1;
            if ($251) {
             label = 26;
             break L22;
            }
            $252 = HEAP32[$outRemainingObjects>>2]|0;
            $253 = HEAP32[$99>>2]|0;
            $254 = ($253*44)|0;
            _memcpy(($249|0),($252|0),($254|0))|0;
            HEAP32[$71>>2] = $238;
            HEAP32[$outRemainingObjects>>2] = $249;
            break;
           }
          }
         } while(0);
         $$pre$i = HEAP32[$99>>2]|0;
         $256 = $$pre$i;
        } else {
         $256 = $232;
        }
        $255 = (($256) + -1)|0;
        $257 = HEAP32[$outRemainingObjects>>2]|0;
        $258 = (($257) + (($255*44)|0)|0);
        dest=$258+0|0; src=$108+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $524 = $264;$525 = $285;$526 = $283;$527 = $267;$528 = $262;$529 = $260;$channels$4 = $channels$043;$prevPassIndex$5 = $prevPassIndex$042;$prevStencilRef$5 = $prevStencilRef$041;
       } else {
        $265 = $172;
        label = 45;
       }
      } else {
       $265 = $158;
       label = 45;
      }
      if ((label|0) == 45) {
       label = 0;
       $259 = ($260|0)==($155|0);
       $261 = ($262|0)==($110|0);
       $or$cond16 = $259 & $261;
       $263 = ($264|0)==($265|0);
       $or$cond17 = $or$cond16 & $263;
       do {
        if ($or$cond17) {
         $266 = $267 > Math_fround(0.0);
         $268 = $266&1;
         $269 = $267 < Math_fround(0.0);
         $270 = $269&1;
         $271 = (($268) - ($270))|0;
         $272 = $154 > Math_fround(0.0);
         $273 = $272&1;
         $274 = $154 < Math_fround(0.0);
         $275 = $274&1;
         $276 = (($273) - ($275))|0;
         $277 = ($271|0)==($276|0);
         if ($277) {
          $278 = ($271|0)<(0);
          if ($278) {
           $279 = Math_fround($267 - $154);
           $280 = $279 < Math_fround(0.0);
           if ($280) {
            $281 = Math_fround(-$279);
            $282 = $281;
           } else {
            $282 = $279;
           }
           $notlhs23 = !($282 <= Math_fround(9.99999997475242707878E-7));
           $notrhs24 = ($283|0)!=($167|0);
           $or$cond19$not = $notrhs24 | $notlhs23;
           $284 = ($285|0)!=($286|0);
           $or$cond21 = $or$cond19$not | $284;
           if ($or$cond21) {
            label = 56;
            break;
           } else {
            $530 = $264;$531 = $285;$532 = $283;$533 = $267;$534 = $262;$535 = $260;$resetPass$0$off0 = 0;
            break;
           }
          }
          $287 = Math_fround($267 * Math_fround(16.0));
          $288 = !($287 >= Math_fround(0.0));
          if ($288) {
           $289 = Math_fround($287 + Math_fround(-0.999999940395355224609));
           $$sink$i1$i$i = $289;
          } else {
           $$sink$i1$i$i = $287;
          }
          $290 = (~~(($$sink$i1$i$i)));
          $291 = Math_fround($154 * Math_fround(16.0));
          $292 = !($291 >= Math_fround(0.0));
          if ($292) {
           $293 = Math_fround($291 + Math_fround(-0.999999940395355224609));
           $$sink$i$i$i = $293;
          } else {
           $$sink$i$i$i = $291;
          }
          $294 = (~~(($$sink$i$i$i)));
          $notlhs = ($290|0)!=($294|0);
          $notrhs = ($283|0)!=($167|0);
          $or$cond18$not = $notrhs | $notlhs;
          $$old20 = ($285|0)!=($286|0);
          $or$cond22 = $or$cond18$not | $$old20;
          if ($or$cond22) {
           label = 56;
          } else {
           $530 = $264;$531 = $285;$532 = $283;$533 = $267;$534 = $262;$535 = $260;$resetPass$0$off0 = 0;
          }
         } else {
          label = 56;
         }
        } else {
         label = 56;
        }
       } while(0);
       if ((label|0) == 56) {
        label = 0;
        __THREW__ = 0;
        invoke_vi(3398,($batchRenderer|0));
        $295 = __THREW__; __THREW__ = 0;
        $296 = $295&1;
        if ($296) {
         label = 26;
         break;
        }
        __THREW__ = 0;
        invoke_viif(41,($9|0),($8|0),(+$154));
        $297 = __THREW__; __THREW__ = 0;
        $298 = $297&1;
        if ($298) {
         label = 26;
         break;
        } else {
         $530 = $265;$531 = $286;$532 = $167;$533 = $154;$534 = $110;$535 = $155;$resetPass$0$off0 = 1;
        }
       }
       __THREW__ = 0;
       invoke_vi(3397,($reflection|0));
       $299 = __THREW__; __THREW__ = 0;
       $300 = $299&1;
       if ($300) {
        label = 26;
        break;
       }
       $301 = HEAP32[$159>>2]|0;
       $302 = (($112) + 64|0);
       __THREW__ = 0;
       invoke_viiii(333,($301|0),($302|0),($defaultReflection|0),($reflection|0));
       $303 = __THREW__; __THREW__ = 0;
       $304 = $303&1;
       if ($304) {
        label = 26;
        break;
       }
       $305 = (_memcmp($reflectionProbeCache,$reflection,124)|0);
       $306 = ($305|0)==(0);
       if (!($306)) {
        dest=$reflectionProbeCache+0|0; src=$reflection+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $307 = HEAP32[$102>>2]|0;
        __THREW__ = 0;
        invoke_vii(2614,($307|0),($reflection|0));
        $308 = __THREW__; __THREW__ = 0;
        $309 = $308&1;
        if ($309) {
         label = 26;
         break;
        }
       }
       $310 = HEAP32[$159>>2]|0;
       $311 = (($310) + 36|0);
       $312 = HEAP32[$311>>2]|0;
       $313 = $312&65535;
       $$off$i = (($313) + -254)<<16>>16;
       $314 = ($$off$i&65535)>(1);
       __THREW__ = 0;
       $315 = (invoke_iiii(1533,($310|0),($$off0$|0),($$off0|0))|0);
       $316 = __THREW__; __THREW__ = 0;
       $317 = $316&1;
       if ($317) {
        label = 26;
        break;
       }
       $318 = (($110) + 52|0);
       $319 = HEAP32[$318>>2]|0;
       $320 = HEAP32[$319>>2]|0;
       $321 = (($320) + ($265<<2)|0);
       $322 = HEAP32[$321>>2]|0;
       $323 = (($322) + 16|0);
       $324 = HEAP32[$323>>2]|0;
       $325 = ($324|0)>(0);
       if ($325) {
        $326 = (($112) + 76|0);
        $327 = (($112) + 68|0);
        $328 = (($112) + 80|0);
        $329 = (($112) + 72|0);
        $330 = (($112) + 84|0);
        $331 = ((($107) + (($106*44)|0)|0) + 6|0);
        $$8 = $315 ? 128 : 192;
        if ($314) {
         $channels$132$us = $channels$043;$p$033$us = 0;$prevPassIndex$131$us = $prevPassIndex$042;$prevStencilRef$130$us = $prevStencilRef$041;$resetPass$1$off029$us = $resetPass$0$off0;
         while(1) {
          $332 = HEAP32[$322>>2]|0;
          $333 = (($332) + ($p$033$us<<2)|0);
          $334 = HEAP32[$333>>2]|0;
          $335 = (($334) + 584|0);
          $336 = HEAP32[$335>>2]|0;
          $337 = ($336|0)==(6);
          do {
           if ($337) {
            $stencilRef$0$$us = $withinShadowDistance$0$off0 ? 128 : 160;
            $338 = HEAP32[$159>>2]|0;
            $339 = HEAP32[$338>>2]|0;
            $340 = (($339) + 32|0);
            $341 = HEAP32[$340>>2]|0;
            __THREW__ = 0;
            $342 = (invoke_ii($341|0,($338|0))|0);
            $343 = __THREW__; __THREW__ = 0;
            $344 = $343&1;
            if ($344) {
             label = 77;
             break L22;
            }
            $345 = ((($lightingLayers) + ($342<<2)|0) + 4|0);
            $346 = HEAP32[$345>>2]|0;
            $347 = ($346|0)==(-1);
            if ($347) {
             $stencilRef$2$us = $stencilRef$0$$us;
            } else {
             $348 = 1 << $346;
             $349 = $348 | $stencilRef$0$$us;
             $stencilRef$2$us = $349;
            }
            $350 = ($p$033$us|0)==($prevPassIndex$131$us|0);
            $351 = ($stencilRef$2$us|0)==($prevStencilRef$130$us|0);
            $or$cond$us = $350 & $351;
            if ($or$cond$us) {
             if ($resetPass$1$off029$us) {
              label = 72;
             } else {
              $channels$2$us = $channels$132$us;$prevStencilRef$3$us = $prevStencilRef$130$us;$resetPass$2$off014$us = 0;
             }
            } else {
             __THREW__ = 0;
             invoke_vi(3398,($batchRenderer|0));
             $352 = __THREW__; __THREW__ = 0;
             $353 = $352&1;
             if ($353) {
              label = 77;
              break L22;
             } else {
              label = 72;
             }
            }
            if ((label|0) == 72) {
             label = 0;
             $354 = HEAP32[$108>>2]|0;
             __THREW__ = 0;
             $355 = (invoke_iiiiii(193,($354|0),($p$033$us|0),($110|0),($8|0),($265|0))|0);
             $356 = __THREW__; __THREW__ = 0;
             $357 = $356&1;
             if ($357) {
              label = 77;
              break L22;
             }
             $358 = HEAP32[$9>>2]|0;
             $359 = (($358) + 64|0);
             $360 = HEAP32[$359>>2]|0;
             $361 = HEAP32[$101>>2]|0;
             $362 = $361 | $stencilRef$2$us;
             __THREW__ = 0;
             invoke_viii($360|0,($9|0),($26|0),($362|0));
             $363 = __THREW__; __THREW__ = 0;
             $364 = $363&1;
             if ($364) {
              label = 77;
              break L22;
             } else {
              $channels$2$us = $355;$prevStencilRef$3$us = $stencilRef$2$us;$resetPass$2$off014$us = 1;
             }
            }
            $365 = Math_fround(HEAPF32[$302>>2]);
            $366 = Math_fround(HEAPF32[$326>>2]);
            $367 = Math_fround($365 + $366);
            $368 = Math_fround(HEAPF32[$327>>2]);
            $369 = Math_fround(HEAPF32[$328>>2]);
            $370 = Math_fround($368 + $369);
            $371 = Math_fround(HEAPF32[$329>>2]);
            $372 = Math_fround(HEAPF32[$330>>2]);
            $373 = Math_fround($371 + $372);
            $374 = Math_fround(HEAPF32[$receiverBounds>>2]);
            $375 = $367 < $374;
            $376 = $375 ? $367 : $374;
            $377 = Math_fround(HEAPF32[$94>>2]);
            $378 = $370 < $377;
            $379 = $378 ? $370 : $377;
            $380 = Math_fround(HEAPF32[$95>>2]);
            $381 = $373 < $380;
            $382 = $381 ? $373 : $380;
            HEAPF32[$receiverBounds>>2] = $376;
            HEAPF32[$94>>2] = $379;
            HEAPF32[$95>>2] = $382;
            $383 = Math_fround(HEAPF32[$96>>2]);
            $384 = $383 < $367;
            $385 = $384 ? $367 : $383;
            $386 = Math_fround(HEAPF32[$97>>2]);
            $387 = $386 < $370;
            $388 = $387 ? $370 : $386;
            $389 = Math_fround(HEAPF32[$98>>2]);
            $390 = $389 < $373;
            $391 = $390 ? $373 : $389;
            HEAPF32[$96>>2] = $385;
            HEAPF32[$97>>2] = $388;
            HEAPF32[$98>>2] = $391;
            $392 = Math_fround(HEAPF32[$302>>2]);
            $393 = Math_fround(HEAPF32[$326>>2]);
            $394 = Math_fround($392 - $393);
            $395 = Math_fround(HEAPF32[$327>>2]);
            $396 = Math_fround(HEAPF32[$328>>2]);
            $397 = Math_fround($395 - $396);
            $398 = Math_fround(HEAPF32[$329>>2]);
            $399 = Math_fround(HEAPF32[$330>>2]);
            $400 = Math_fround($398 - $399);
            $401 = $394 < $376;
            $402 = $401 ? $394 : $376;
            $403 = $397 < $379;
            $404 = $403 ? $397 : $379;
            $405 = $400 < $382;
            $406 = $405 ? $400 : $382;
            HEAPF32[$receiverBounds>>2] = $402;
            HEAPF32[$94>>2] = $404;
            HEAPF32[$95>>2] = $406;
            $407 = $385 < $394;
            $408 = $407 ? $394 : $385;
            $409 = $388 < $397;
            $410 = $409 ? $397 : $388;
            $411 = $391 < $400;
            $412 = $411 ? $400 : $391;
            HEAPF32[$96>>2] = $408;
            HEAPF32[$97>>2] = $410;
            HEAPF32[$98>>2] = $412;
            $413 = ($channels$2$us|0)==(0|0);
            if ($413) {
             $channels$3$us = 0;$prevPassIndex$4$us = $p$033$us;$prevStencilRef$4$us = $prevStencilRef$3$us;$resetPass$3$off0$us = $resetPass$2$off014$us;
             break;
            }
            $414 = HEAP32[$159>>2]|0;
            $415 = HEAP16[$331>>1]|0;
            $416 = $415&65535;
            __THREW__ = 0;
            invoke_viiiii(90,($batchRenderer|0),($414|0),($112|0),($416|0),($channels$2$us|0));
            $417 = __THREW__; __THREW__ = 0;
            $418 = $417&1;
            if ($418) {
             label = 77;
             break L22;
            } else {
             $channels$3$us = $channels$2$us;$prevPassIndex$4$us = $p$033$us;$prevStencilRef$4$us = $prevStencilRef$3$us;$resetPass$3$off0$us = $resetPass$2$off014$us;
            }
           } else {
            $channels$3$us = $channels$132$us;$prevPassIndex$4$us = $prevPassIndex$131$us;$prevStencilRef$4$us = $prevStencilRef$130$us;$resetPass$3$off0$us = $resetPass$1$off029$us;
           }
          } while(0);
          $419 = (($p$033$us) + 1)|0;
          $420 = ($419|0)<($324|0);
          if ($420) {
           $channels$132$us = $channels$3$us;$p$033$us = $419;$prevPassIndex$131$us = $prevPassIndex$4$us;$prevStencilRef$130$us = $prevStencilRef$4$us;$resetPass$1$off029$us = $resetPass$3$off0$us;
          } else {
           $524 = $530;$525 = $531;$526 = $532;$527 = $533;$528 = $534;$529 = $535;$channels$4 = $channels$3$us;$prevPassIndex$5 = $prevPassIndex$4$us;$prevStencilRef$5 = $prevStencilRef$4$us;
           break;
          }
         }
        } else {
         $channels$132 = $channels$043;$p$033 = 0;$prevPassIndex$131 = $prevPassIndex$042;$prevStencilRef$130 = $prevStencilRef$041;$resetPass$1$off029 = $resetPass$0$off0;
         while(1) {
          $423 = HEAP32[$322>>2]|0;
          $424 = (($423) + ($p$033<<2)|0);
          $425 = HEAP32[$424>>2]|0;
          $426 = (($425) + 584|0);
          $427 = HEAP32[$426>>2]|0;
          $428 = ($427|0)==(6);
          do {
           if ($428) {
            $429 = $$8 | 32;
            $stencilRef$0$ = $withinShadowDistance$0$off0 ? $$8 : $429;
            $430 = HEAP32[$159>>2]|0;
            $431 = HEAP32[$430>>2]|0;
            $432 = (($431) + 32|0);
            $433 = HEAP32[$432>>2]|0;
            __THREW__ = 0;
            $434 = (invoke_ii($433|0,($430|0))|0);
            $435 = __THREW__; __THREW__ = 0;
            $436 = $435&1;
            if ($436) {
             label = 25;
             break L22;
            }
            $437 = ((($lightingLayers) + ($434<<2)|0) + 4|0);
            $438 = HEAP32[$437>>2]|0;
            $439 = ($438|0)==(-1);
            if ($439) {
             $stencilRef$2 = $stencilRef$0$;
            } else {
             $440 = 1 << $438;
             $441 = $440 | $stencilRef$0$;
             $stencilRef$2 = $441;
            }
            $442 = ($p$033|0)==($prevPassIndex$131|0);
            $443 = ($stencilRef$2|0)==($prevStencilRef$130|0);
            $or$cond = $442 & $443;
            if ($or$cond) {
             if ($resetPass$1$off029) {
              label = 85;
             } else {
              $channels$2 = $channels$132;$prevStencilRef$3 = $prevStencilRef$130;$resetPass$2$off014 = 0;
             }
            } else {
             __THREW__ = 0;
             invoke_vi(3398,($batchRenderer|0));
             $444 = __THREW__; __THREW__ = 0;
             $445 = $444&1;
             if ($445) {
              label = 25;
              break L22;
             } else {
              label = 85;
             }
            }
            if ((label|0) == 85) {
             label = 0;
             $446 = HEAP32[$108>>2]|0;
             __THREW__ = 0;
             $447 = (invoke_iiiiii(193,($446|0),($p$033|0),($110|0),($8|0),($265|0))|0);
             $448 = __THREW__; __THREW__ = 0;
             $449 = $448&1;
             if ($449) {
              label = 25;
              break L22;
             }
             $450 = HEAP32[$9>>2]|0;
             $451 = (($450) + 64|0);
             $452 = HEAP32[$451>>2]|0;
             $453 = HEAP32[$101>>2]|0;
             $454 = $453 | $stencilRef$2;
             __THREW__ = 0;
             invoke_viii($452|0,($9|0),($26|0),($454|0));
             $455 = __THREW__; __THREW__ = 0;
             $456 = $455&1;
             if ($456) {
              label = 25;
              break L22;
             } else {
              $channels$2 = $447;$prevStencilRef$3 = $stencilRef$2;$resetPass$2$off014 = 1;
             }
            }
            $457 = Math_fround(HEAPF32[$302>>2]);
            $458 = Math_fround(HEAPF32[$326>>2]);
            $459 = Math_fround($457 + $458);
            $460 = Math_fround(HEAPF32[$327>>2]);
            $461 = Math_fround(HEAPF32[$328>>2]);
            $462 = Math_fround($460 + $461);
            $463 = Math_fround(HEAPF32[$329>>2]);
            $464 = Math_fround(HEAPF32[$330>>2]);
            $465 = Math_fround($463 + $464);
            $466 = Math_fround(HEAPF32[$receiverBounds>>2]);
            $467 = $459 < $466;
            $468 = $467 ? $459 : $466;
            $469 = Math_fround(HEAPF32[$94>>2]);
            $470 = $462 < $469;
            $471 = $470 ? $462 : $469;
            $472 = Math_fround(HEAPF32[$95>>2]);
            $473 = $465 < $472;
            $474 = $473 ? $465 : $472;
            HEAPF32[$receiverBounds>>2] = $468;
            HEAPF32[$94>>2] = $471;
            HEAPF32[$95>>2] = $474;
            $475 = Math_fround(HEAPF32[$96>>2]);
            $476 = $475 < $459;
            $477 = $476 ? $459 : $475;
            $478 = Math_fround(HEAPF32[$97>>2]);
            $479 = $478 < $462;
            $480 = $479 ? $462 : $478;
            $481 = Math_fround(HEAPF32[$98>>2]);
            $482 = $481 < $465;
            $483 = $482 ? $465 : $481;
            HEAPF32[$96>>2] = $477;
            HEAPF32[$97>>2] = $480;
            HEAPF32[$98>>2] = $483;
            $484 = Math_fround(HEAPF32[$302>>2]);
            $485 = Math_fround(HEAPF32[$326>>2]);
            $486 = Math_fround($484 - $485);
            $487 = Math_fround(HEAPF32[$327>>2]);
            $488 = Math_fround(HEAPF32[$328>>2]);
            $489 = Math_fround($487 - $488);
            $490 = Math_fround(HEAPF32[$329>>2]);
            $491 = Math_fround(HEAPF32[$330>>2]);
            $492 = Math_fround($490 - $491);
            $493 = $486 < $468;
            $494 = $493 ? $486 : $468;
            $495 = $489 < $471;
            $496 = $495 ? $489 : $471;
            $497 = $492 < $474;
            $498 = $497 ? $492 : $474;
            HEAPF32[$receiverBounds>>2] = $494;
            HEAPF32[$94>>2] = $496;
            HEAPF32[$95>>2] = $498;
            $499 = $477 < $486;
            $500 = $499 ? $486 : $477;
            $501 = $480 < $489;
            $502 = $501 ? $489 : $480;
            $503 = $483 < $492;
            $504 = $503 ? $492 : $483;
            HEAPF32[$96>>2] = $500;
            HEAPF32[$97>>2] = $502;
            HEAPF32[$98>>2] = $504;
            $505 = ($channels$2|0)==(0|0);
            if ($505) {
             $channels$3 = 0;$prevPassIndex$4 = $p$033;$prevStencilRef$4 = $prevStencilRef$3;$resetPass$3$off0 = $resetPass$2$off014;
             break;
            }
            $506 = HEAP32[$159>>2]|0;
            $507 = HEAP16[$331>>1]|0;
            $508 = $507&65535;
            __THREW__ = 0;
            invoke_viiiii(90,($batchRenderer|0),($506|0),($112|0),($508|0),($channels$2|0));
            $509 = __THREW__; __THREW__ = 0;
            $510 = $509&1;
            if ($510) {
             label = 25;
             break L22;
            } else {
             $channels$3 = $channels$2;$prevPassIndex$4 = $p$033;$prevStencilRef$4 = $prevStencilRef$3;$resetPass$3$off0 = $resetPass$2$off014;
            }
           } else {
            $channels$3 = $channels$132;$prevPassIndex$4 = $prevPassIndex$131;$prevStencilRef$4 = $prevStencilRef$130;$resetPass$3$off0 = $resetPass$1$off029;
           }
          } while(0);
          $511 = (($p$033) + 1)|0;
          $512 = ($511|0)<($324|0);
          if ($512) {
           $channels$132 = $channels$3;$p$033 = $511;$prevPassIndex$131 = $prevPassIndex$4;$prevStencilRef$130 = $prevStencilRef$4;$resetPass$1$off029 = $resetPass$3$off0;
          } else {
           $524 = $530;$525 = $531;$526 = $532;$527 = $533;$528 = $534;$529 = $535;$channels$4 = $channels$3;$prevPassIndex$5 = $prevPassIndex$4;$prevStencilRef$5 = $prevStencilRef$4;
           break;
          }
         }
        }
       } else {
        $524 = $530;$525 = $531;$526 = $532;$527 = $533;$528 = $534;$529 = $535;$channels$4 = $channels$043;$prevPassIndex$5 = $prevPassIndex$042;$prevStencilRef$5 = $prevStencilRef$041;
       }
      }
      $513 = (($i$040) + 1)|0;
      $514 = ($513>>>0)<($69>>>0);
      if ($514) {
       $260 = $529;$262 = $528;$264 = $524;$267 = $527;$283 = $526;$285 = $525;$channels$043 = $channels$4;$i$040 = $513;$prevPassIndex$042 = $prevPassIndex$5;$prevStencilRef$041 = $prevStencilRef$5;
      } else {
       break L20;
      }
     }
     if ((label|0) == 25) {
      $145 = ___cxa_find_matching_catch()|0;
      $146 = tempRet0;
      $lpad$phi$index = $145;$lpad$phi$index4 = $146;
      break L18;
     }
     else if ((label|0) == 26) {
      $147 = ___cxa_find_matching_catch()|0;
      $148 = tempRet0;
      $lpad$phi$index = $147;$lpad$phi$index4 = $148;
      break L18;
     }
     else if ((label|0) == 77) {
      $421 = ___cxa_find_matching_catch()|0;
      $422 = tempRet0;
      $lpad$phi$index = $421;$lpad$phi$index4 = $422;
      break L18;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3398,($batchRenderer|0));
   $515 = __THREW__; __THREW__ = 0;
   $516 = $515&1;
   if ($516) {
    label = 27;
   } else {
    $517 = HEAP32[$this>>2]|0;
    $518 = HEAP32[$517>>2]|0;
    $519 = (($518) + 636|0);
    __THREW__ = 0;
    invoke_viii(1663,($519|0),5,($8|0));
    $520 = __THREW__; __THREW__ = 0;
    $521 = $520&1;
    if ($521) {
     label = 27;
    } else {
     __ZN13BatchRendererD1Ev($batchRenderer);
     STACKTOP = sp;return ($28|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $149 = ___cxa_find_matching_catch()|0;
  $150 = tempRet0;
  $lpad$phi$index = $149;$lpad$phi$index4 = $150;
 }
 __THREW__ = 0;
 invoke_vi(3399,($batchRenderer|0));
 $151 = __THREW__; __THREW__ = 0;
 $152 = $151&1;
 if ($152) {
  $522 = ___cxa_find_matching_catch(0|0)|0;
  $523 = tempRet0;
  ___clang_call_terminate($522);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN17PrePassRenderLoop15RenderFinalPassEP13RenderTextureS1_bb($this,$rtMain,$rtLight,$hdr,$linearLighting) {
 $this = $this|0;
 $rtMain = $rtMain|0;
 $rtLight = $rtLight|0;
 $hdr = $hdr|0;
 $linearLighting = $linearLighting|0;
 var $$old13 = 0, $$pre = 0, $$pre39 = 0, $$sink$i$i$i = Math_fround(0), $$sink$i1$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0;
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ambientAndLightProbeSH = 0, $batchRenderer = 0, $brmerge = 0, $channels$034 = 0, $channels$124 = 0, $channels$2 = 0;
 var $channels$3 = 0, $channels$4 = 0, $i$01$i$i$i = 0, $index$032 = 0, $lightmapSTCache = 0, $linearLighting$not = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $notlhs = 0, $notlhs16 = 0, $notrhs = 0, $notrhs17 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond11$not = 0, $or$cond12$not = 0, $or$cond14 = 0, $or$cond15 = 0, $p$025 = 0, $prevPassIndex$033 = 0;
 var $prevPassIndex$123 = 0, $prevPassIndex$3 = 0, $prevPassIndex$4 = 0, $resetPass$0$off0 = 0, $resetPass$1$off022 = 0, $resetPass$2$off06 = 0, $resetPass$3$off0 = 0, $shConstantCache = 0, $stats = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $stats = sp + 424|0;
 $batchRenderer = sp;
 $shConstantCache = sp + 80|0;
 $lightmapSTCache = sp + 304|0;
 $ambientAndLightProbeSH = sp + 316|0;
 $0 = HEAP32[652824>>2]|0;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,0);
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($rtMain,0,-1,0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $linearLighting$not = $linearLighting ^ 1;
 $brmerge = $hdr | $linearLighting$not;
 if ($brmerge) {
  $12 = 0;
 } else {
  $8 = ($rtMain|0)==(0|0);
  if ($8) {
   $12 = 1;
  } else {
   $9 = (($rtMain) + 130|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)!=(0);
   $12 = $11;
  }
 }
 FUNCTION_TABLE_vii[$7 & 4095]($1,$12);
 $13 = HEAP32[$this>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 __ZN6Camera13ClearNoSkyboxEb($14,1);
 $15 = ($rtLight|0)==(0|0);
 if ($15) {
  $16 = (($0) + 20|0);
  if ($hdr) {
   $17 = (__ZN10builtintex15GetBlackTextureEv()|0);
   $19 = $17;
  } else {
   $18 = (__ZN10builtintex15GetWhiteTextureEv()|0);
   $19 = $18;
  }
  $20 = (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($16,568576,$19)|0);
  __ZN9ShaderLab6TexEnv15SetTextureScaleEff($20,Math_fround(1.0),Math_fround(1.0));
  __ZN9ShaderLab6TexEnv16SetTextureOffsetEff($20,Math_fround(0.0),Math_fround(0.0));
 } else {
  (__ZN13RenderTexture17SetGlobalPropertyERKN9ShaderLab16FastPropertyNameE($rtLight,568576)|0);
 }
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($23,8,$0);
 $24 = (__Z13GetGISettingsv()|0);
 $25 = (($24) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (__Z12GetGfxDevicev()|0);
 $28 = (($27) + 692|0);
 HEAPF32[$28>>2] = $26;
 $29 = (($27) + 696|0);
 HEAPF32[$29>>2] = $26;
 $30 = (($27) + 700|0);
 HEAPF32[$30>>2] = $26;
 $31 = (($27) + 704|0);
 HEAPF32[$31>>2] = Math_fround(1.0);
 $32 = (__Z19GetLightmapSettingsv()|0);
 __Z14SetupLightmapsRK16LightmapSettings($32);
 $33 = (__Z19GetLightmapSettingsv()|0);
 $34 = (__ZNK16LightmapSettings19AreLightProbesBakedEv($33)|0);
 $35 = (__Z17GetRenderSettingsv()|0);
 $36 = (($35) + 296|0);
 __ZN13BatchRendererC2ER15RenderLoopStats($batchRenderer,$stats);
 __THREW__ = 0;
 invoke_viii(1659,($shConstantCache|0),($batchRenderer|0),($stats|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 L13: do {
  if ($38) {
   label = 20;
  } else {
   __THREW__ = 0;
   invoke_viii(1661,($lightmapSTCache|0),($batchRenderer|0),($stats|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    label = 20;
   } else {
    $41 = (($batchRenderer) + 68|0);
    HEAP8[$41>>0] = 0;
    $42 = (($this) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==(0);
    L16: do {
     if (!($46)) {
      $47 = (($this) + 8|0);
      $48 = (($shConstantCache) + 108|0);
      $49 = (($shConstantCache) + 216|0);
      $102 = Math_fround(-1.0);$113 = 16711935;$116 = -1;$54 = $43;$90 = 0;$92 = 0;$95 = -1;$channels$034 = 0;$index$032 = 0;$prevPassIndex$033 = -1;
      L18: while(1) {
       $50 = HEAP32[$47>>2]|0;
       $51 = (($50) + ($index$032<<2)|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = HEAP32[$54>>2]|0;
       $55 = ((($53) + (($52*44)|0)|0) + 32|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = ((($53) + (($52*44)|0)|0) + 36|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($56) + 120|0);
       $60 = Math_fround(HEAPF32[$59>>2]);
       $61 = (($53) + (($52*44)|0)|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = ((($53) + (($52*44)|0)|0) + 8|0);
       $64 = HEAP16[$63>>1]|0;
       $65 = $64 << 16 >> 16;
       $66 = (($56) + 116|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($67) + 168|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ($69|0)==(0|0);
       if ($70) {
        $115 = 0;
       } else {
        $71 = (($69) + 32|0);
        $72 = HEAP32[$71>>2]|0;
        $115 = $72;
       }
       $73 = ((($53) + (($52*44)|0)|0) + 12|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($64<<16>>16)==(-1);
       if ($75) {
        $76 = (($58) + 52|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = (($77) + 24|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = ($79|0)==(-1);
        if ($80) {
         $197 = $95;$198 = $116;$199 = $113;$200 = $102;$201 = $92;$202 = $90;$channels$4 = $channels$034;$prevPassIndex$4 = $prevPassIndex$033;
        } else {
         $94 = $79;
         label = 22;
        }
       } else {
        $94 = $65;
        label = 22;
       }
       if ((label|0) == 22) {
        label = 0;
        $89 = ($62|0)==($90|0);
        $91 = ($58|0)==($92|0);
        $or$cond = $89 & $91;
        $93 = ($94|0)==($95|0);
        $or$cond10 = $or$cond & $93;
        do {
         if ($or$cond10) {
          $96 = $60 > Math_fround(0.0);
          $97 = $96&1;
          $98 = $60 < Math_fround(0.0);
          $99 = $98&1;
          $100 = (($97) - ($99))|0;
          $101 = $102 > Math_fround(0.0);
          $103 = $101&1;
          $104 = $102 < Math_fround(0.0);
          $105 = $104&1;
          $106 = (($103) - ($105))|0;
          $107 = ($100|0)==($106|0);
          if ($107) {
           $108 = ($100|0)<(0);
           if ($108) {
            $109 = Math_fround($60 - $102);
            $110 = $109 < Math_fround(0.0);
            if ($110) {
             $111 = Math_fround(-$109);
             $112 = $111;
            } else {
             $112 = $109;
            }
            $notlhs16 = !($112 <= Math_fround(9.99999997475242707878E-7));
            $notrhs17 = ($74|0)!=($113|0);
            $or$cond12$not = $notrhs17 | $notlhs16;
            $114 = ($115|0)!=($116|0);
            $or$cond14 = $or$cond12$not | $114;
            if ($or$cond14) {
             label = 33;
             break;
            } else {
             $129 = $67;$203 = $95;$204 = $116;$205 = $113;$206 = $102;$207 = $92;$208 = $90;$resetPass$0$off0 = 0;
             break;
            }
           }
           $117 = Math_fround($60 * Math_fround(16.0));
           $118 = !($117 >= Math_fround(0.0));
           if ($118) {
            $119 = Math_fround($117 + Math_fround(-0.999999940395355224609));
            $$sink$i1$i$i = $119;
           } else {
            $$sink$i1$i$i = $117;
           }
           $120 = (~~(($$sink$i1$i$i)));
           $121 = Math_fround($102 * Math_fround(16.0));
           $122 = !($121 >= Math_fround(0.0));
           if ($122) {
            $123 = Math_fround($121 + Math_fround(-0.999999940395355224609));
            $$sink$i$i$i = $123;
           } else {
            $$sink$i$i$i = $121;
           }
           $124 = (~~(($$sink$i$i$i)));
           $notlhs = ($120|0)!=($124|0);
           $notrhs = ($74|0)!=($113|0);
           $or$cond11$not = $notrhs | $notlhs;
           $$old13 = ($115|0)!=($116|0);
           $or$cond15 = $or$cond11$not | $$old13;
           if ($or$cond15) {
            label = 33;
           } else {
            $129 = $67;$203 = $95;$204 = $116;$205 = $113;$206 = $102;$207 = $92;$208 = $90;$resetPass$0$off0 = 0;
           }
          } else {
           label = 33;
          }
         } else {
          label = 33;
         }
        } while(0);
        if ((label|0) == 33) {
         label = 0;
         __THREW__ = 0;
         invoke_vi(3398,($batchRenderer|0));
         $125 = __THREW__; __THREW__ = 0;
         $126 = $125&1;
         if ($126) {
          label = 19;
          break;
         }
         __THREW__ = 0;
         invoke_viif(41,($1|0),($0|0),(+$60));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          label = 19;
          break;
         }
         $$pre39 = HEAP32[$66>>2]|0;
         $129 = $$pre39;$203 = $94;$204 = $115;$205 = $74;$206 = $60;$207 = $58;$208 = $62;$resetPass$0$off0 = 1;
        }
        __THREW__ = 0;
        invoke_vii(2612,($lightmapSTCache|0),($129|0));
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if ($131) {
         label = 19;
         break;
        }
        dest=$ambientAndLightProbeSH+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
        __THREW__ = 0;
        invoke_viiii(338,($56|0),($36|0),($34|0),($ambientAndLightProbeSH|0));
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if ($133) {
         label = 19;
         break;
        } else {
         $i$01$i$i$i = 0;
        }
        while(1) {
         $136 = (($48) + ($i$01$i$i$i<<2)|0);
         $137 = HEAP32[$136>>2]|0;
         $138 = (($ambientAndLightProbeSH) + ($i$01$i$i$i<<2)|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = ($137|0)==($139|0);
         $135 = (($i$01$i$i$i) + 1)|0;
         if (!($140)) {
          label = 40;
          break;
         }
         $134 = ($135|0)<(27);
         if ($134) {
          $i$01$i$i$i = $135;
         } else {
          break;
         }
        }
        if ((label|0) == 40) {
         label = 0;
         dest=$48+0|0; src=$ambientAndLightProbeSH+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
         $141 = HEAP32[$49>>2]|0;
         __THREW__ = 0;
         invoke_vii(2613,($141|0),($ambientAndLightProbeSH|0));
         $142 = __THREW__; __THREW__ = 0;
         $143 = $142&1;
         if ($143) {
          label = 19;
          break;
         }
        }
        $144 = HEAP32[$57>>2]|0;
        $145 = (($144) + 52|0);
        $146 = HEAP32[$145>>2]|0;
        $147 = HEAP32[$146>>2]|0;
        $148 = (($147) + ($94<<2)|0);
        $149 = HEAP32[$148>>2]|0;
        $150 = (($149) + 16|0);
        $151 = HEAP32[$150>>2]|0;
        $152 = ($151|0)>(0);
        if ($152) {
         $153 = ((($53) + (($52*44)|0)|0) + 12|0);
         $154 = ((($53) + (($52*44)|0)|0) + 6|0);
         $channels$124 = $channels$034;$p$025 = 0;$prevPassIndex$123 = $prevPassIndex$033;$resetPass$1$off022 = $resetPass$0$off0;
         while(1) {
          $155 = HEAP32[$149>>2]|0;
          $156 = (($155) + ($p$025<<2)|0);
          $157 = HEAP32[$156>>2]|0;
          $158 = (($157) + 584|0);
          $159 = HEAP32[$158>>2]|0;
          $160 = ($159|0)==(7);
          if ($160) {
           $161 = ($p$025|0)==($prevPassIndex$123|0);
           if ($161) {
            if ($resetPass$1$off022) {
             label = 47;
            } else {
             $channels$2 = $channels$124;$resetPass$2$off06 = 0;
            }
           } else {
            __THREW__ = 0;
            invoke_vi(3398,($batchRenderer|0));
            $162 = __THREW__; __THREW__ = 0;
            $163 = $162&1;
            if ($163) {
             label = 18;
             break L18;
            } else {
             label = 47;
            }
           }
           if ((label|0) == 47) {
            label = 0;
            __THREW__ = 0;
            invoke_vii(2615,($32|0),($153|0));
            $164 = __THREW__; __THREW__ = 0;
            $165 = $164&1;
            if ($165) {
             label = 18;
             break L18;
            }
            $166 = HEAP32[$61>>2]|0;
            __THREW__ = 0;
            $167 = (invoke_iiiiii(193,($166|0),($p$025|0),($58|0),($0|0),($94|0))|0);
            $168 = __THREW__; __THREW__ = 0;
            $169 = $168&1;
            if ($169) {
             label = 18;
             break L18;
            } else {
             $channels$2 = $167;$resetPass$2$off06 = 1;
            }
           }
           $170 = ($channels$2|0)==(0|0);
           if ($170) {
            $channels$3 = 0;$prevPassIndex$3 = $p$025;$resetPass$3$off0 = $resetPass$2$off06;
           } else {
            $171 = HEAP32[$66>>2]|0;
            $172 = HEAP16[$154>>1]|0;
            $173 = $172&65535;
            __THREW__ = 0;
            invoke_viiiii(90,($batchRenderer|0),($171|0),($56|0),($173|0),($channels$2|0));
            $174 = __THREW__; __THREW__ = 0;
            $175 = $174&1;
            if ($175) {
             label = 18;
             break L18;
            } else {
             $channels$3 = $channels$2;$prevPassIndex$3 = $p$025;$resetPass$3$off0 = $resetPass$2$off06;
            }
           }
          } else {
           $channels$3 = $channels$124;$prevPassIndex$3 = $prevPassIndex$123;$resetPass$3$off0 = $resetPass$1$off022;
          }
          $176 = (($p$025) + 1)|0;
          $177 = ($176|0)<($151|0);
          if ($177) {
           $channels$124 = $channels$3;$p$025 = $176;$prevPassIndex$123 = $prevPassIndex$3;$resetPass$1$off022 = $resetPass$3$off0;
          } else {
           $197 = $203;$198 = $204;$199 = $205;$200 = $206;$201 = $207;$202 = $208;$channels$4 = $channels$3;$prevPassIndex$4 = $prevPassIndex$3;
           break;
          }
         }
        } else {
         $197 = $203;$198 = $204;$199 = $205;$200 = $206;$201 = $207;$202 = $208;$channels$4 = $channels$034;$prevPassIndex$4 = $prevPassIndex$033;
        }
       }
       $178 = (($index$032) + 1)|0;
       $179 = ($178>>>0)<($45>>>0);
       if (!($179)) {
        break L16;
       }
       $$pre = HEAP32[$42>>2]|0;
       $102 = $200;$113 = $199;$116 = $198;$54 = $$pre;$90 = $202;$92 = $201;$95 = $197;$channels$034 = $channels$4;$index$032 = $178;$prevPassIndex$033 = $prevPassIndex$4;
      }
      if ((label|0) == 18) {
       $81 = ___cxa_find_matching_catch()|0;
       $82 = tempRet0;
       $lpad$phi$index = $81;$lpad$phi$index3 = $82;
       break L13;
      }
      else if ((label|0) == 19) {
       $83 = ___cxa_find_matching_catch()|0;
       $84 = tempRet0;
       $lpad$phi$index = $83;$lpad$phi$index3 = $84;
       break L13;
      }
     }
    } while(0);
    __THREW__ = 0;
    invoke_vi(3398,($batchRenderer|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if ($181) {
     label = 20;
    } else {
     $182 = HEAP32[$this>>2]|0;
     $183 = HEAP32[$182>>2]|0;
     $184 = (($183) + 636|0);
     __THREW__ = 0;
     invoke_viii(1663,($184|0),9,($0|0));
     $185 = __THREW__; __THREW__ = 0;
     $186 = $185&1;
     if ($186) {
      label = 20;
     } else {
      __THREW__ = 0;
      $187 = (invoke_i(59)|0);
      $188 = __THREW__; __THREW__ = 0;
      $189 = $188&1;
      if ($189) {
       label = 20;
      } else {
       $190 = HEAP32[$187>>2]|0;
       $191 = (($190) + 72|0);
       $192 = HEAP32[$191>>2]|0;
       __THREW__ = 0;
       invoke_vii($192|0,($187|0),0);
       $193 = __THREW__; __THREW__ = 0;
       $194 = $193&1;
       if ($194) {
        label = 20;
       } else {
        __ZN13BatchRendererD1Ev($batchRenderer);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $85 = ___cxa_find_matching_catch()|0;
  $86 = tempRet0;
  $lpad$phi$index = $85;$lpad$phi$index3 = $86;
 }
 __THREW__ = 0;
 invoke_vi(3399,($batchRenderer|0));
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if ($88) {
  $195 = ___cxa_find_matching_catch(0|0)|0;
  $196 = tempRet0;
  ___clang_call_terminate($195);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19DoPrePassRenderLoopR17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EES4_RP13RenderTextureS7_S7_R12ActiveLightsbPb($ctx,$objects,$outRemainingObjects,$outDepthRT,$outDepthNormalsRT,$outMainShadowMap,$activeLights,$linearLighting,$outDepthWasCopied) {
 $ctx = $ctx|0;
 $objects = $objects|0;
 $outRemainingObjects = $outRemainingObjects|0;
 $outDepthRT = $outDepthRT|0;
 $outDepthNormalsRT = $outDepthNormalsRT|0;
 $outMainShadowMap = $outMainShadowMap|0;
 $activeLights = $activeLights|0;
 $linearLighting = $linearLighting|0;
 $outDepthWasCopied = $outDepthWasCopied|0;
 var $$0$i$i$i$i = Math_fround(0), $$0$i$i$i$i15 = Math_fround(0), $$0$i1$i$i$i17 = Math_fround(0), $$0$i3$i$i$i = Math_fround(0), $$0$i3$i$i$i16 = Math_fround(0), $$byval_copy13 = 0, $$byval_copy8 = 0, $$in = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i8 = 0, $$pre22 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0;
 var $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0);
 var $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $bit$01$i$i = 0, $bit$1$i$i = 0, $black = 0, $colorSurfaceHandle$sroa$0$0 = 0, $depthTextureHandle$sroa$0$0 = 0, $depthTextureID = 0;
 var $exitcond$i$i = 0, $fadeCenterAndType = 0, $i1$03$i$i = 0, $it$020 = 0, $lightFade = 0, $lightingLayers = 0, $loop = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $mask$02$i$i = 0, $phitmp = 0, $receiverBounds = 0, $roIndex$021 = 0, $rtLight = 0, $scevgep$i$i = 0, $shadowDistance = 0, $shadowSphereRange = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy13 = sp + 284|0;
 $$byval_copy8 = sp + 280|0;
 $0 = sp;
 $1 = sp + 276|0;
 $2 = sp + 272|0;
 $loop = sp + 248|0;
 $lightFade = sp + 232|0;
 $fadeCenterAndType = sp + 216|0;
 $shadowDistance = sp + 212|0;
 $shadowSphereRange = sp + 208|0;
 $lightingLayers = sp + 72|0;
 $receiverBounds = sp + 16|0;
 $depthTextureID = sp + 4|0;
 $3 = sp + 8|0;
 $4 = sp + 12|0;
 $rtLight = sp + 40|0;
 $5 = sp + 44|0;
 $black = sp + 48|0;
 $6 = sp + 64|0;
 $7 = sp + 68|0;
 HEAP32[$outDepthRT>>2] = 0;
 HEAP32[$outDepthNormalsRT>>2] = 0;
 HEAP8[$outDepthWasCopied>>0] = 0;
 $8 = HEAP32[652824>>2]|0;
 $9 = (($loop) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($loop) + 16|0);
 $11 = (($loop) + 20|0);
 HEAP32[$11>>2] = 0;
 $12 = (($loop) + 12|0);
 HEAP32[$12>>2] = 61;
 HEAP32[$loop>>2] = $ctx;
 $13 = (($loop) + 4|0);
 HEAP32[$13>>2] = $objects;
 $14 = (($loop) + 8|0);
 HEAP32[$10>>2] = 0;
 $15 = HEAP32[$objects>>2]|0;
 $16 = (($objects) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + (($17*44)|0)|0);
 $19 = ($17|0)==(0);
 do {
  if ($19) {
   $61 = $15;$62 = 0;
   label = 19;
  } else {
   $20 = 1;$22 = 0;$31 = 0;$it$020 = $15;$roIndex$021 = 0;
   L3: while(1) {
    HEAP32[$10>>2] = $20;
    $21 = $22 & 2147483647;
    $23 = ($20>>>0)>($21>>>0);
    if ($23) {
     $24 = $22 << 1;
     $25 = ($24|0)==(0);
     $26 = $25 ? 1 : $24;
     $27 = ($21>>>0)<($26>>>0);
     do {
      if ($27) {
       $28 = ($22|0)>(-1);
       if ($28) {
        HEAP32[$11>>2] = $26;
        $29 = $26 << 2;
        $30 = HEAP32[$12>>2]|0;
        HEAP32[$1>>2] = $30;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
        $32 = (invoke_iiiiiiii(108,($31|0),($29|0),4,($$byval_copy13|0),0,(568792|0),370)|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         label = 13;
         break L3;
        }
        HEAP32[$14>>2] = $32;
        $277 = $32;
        break;
       } else {
        $35 = $26 << 2;
        $36 = HEAP32[$12>>2]|0;
        HEAP32[$2>>2] = $36;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$2+0>>2]|0;
        $37 = (invoke_iiiiiii(102,($35|0),4,($$byval_copy13|0),0,(568792|0),352)|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         label = 13;
         break L3;
        }
        $40 = HEAP32[$14>>2]|0;
        $41 = HEAP32[$10>>2]|0;
        $42 = $41 << 2;
        _memcpy(($37|0),($40|0),($42|0))|0;
        HEAP32[$11>>2] = $26;
        HEAP32[$14>>2] = $37;
        $277 = $37;
        break;
       }
      } else {
       $277 = $31;
      }
     } while(0);
     $$pre$i$i = HEAP32[$10>>2]|0;
     $44 = $$pre$i$i;$46 = $277;
    } else {
     $44 = $20;$46 = $31;
    }
    $43 = (($44) + -1)|0;
    $45 = (($46) + ($43<<2)|0);
    HEAP32[$45>>2] = $roIndex$021;
    $47 = (($it$020) + 44|0);
    $48 = ($47|0)==($18|0);
    if ($48) {
     label = 18;
     break;
    }
    $49 = (($roIndex$021) + 1)|0;
    $$pre28 = HEAP32[$10>>2]|0;
    $$pre29 = HEAP32[$11>>2]|0;
    $phitmp = (($$pre28) + 1)|0;
    $20 = $phitmp;$22 = $$pre29;$31 = $46;$it$020 = $47;$roIndex$021 = $49;
   }
   if ((label|0) == 13) {
    $50 = ___cxa_find_matching_catch()|0;
    $51 = tempRet0;
    $lpad$phi$index = $50;$lpad$phi$index2 = $51;
    break;
   }
   else if ((label|0) == 18) {
    $$pre = HEAP32[$objects>>2]|0;
    $$pre22 = HEAP32[$16>>2]|0;
    $61 = $$pre;$62 = $$pre22;
    label = 19;
    break;
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $60 = (($61) + (($62*44)|0)|0);
  __ZNSt3__16__sortIR25RenderPrePassObjectSorterP16RenderObjectDataEEvT0_S5_T_($61,$60,$0);
  __THREW__ = 0;
  $63 = (invoke_i(59)|0);
  $64 = __THREW__; __THREW__ = 0;
  $65 = $64&1;
  L22: do {
   if (!($65)) {
    $66 = HEAP32[$ctx>>2]|0;
    __THREW__ = 0;
    invoke_viiii(339,($66|0),($fadeCenterAndType|0),($shadowDistance|0),($shadowSphereRange|0));
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if (!($68)) {
     $69 = HEAP32[$ctx>>2]|0;
     $70 = Math_fround(HEAPF32[$shadowDistance>>2]);
     $71 = Math_fround(HEAPF32[$shadowSphereRange>>2]);
     __THREW__ = 0;
     invoke_vifffi(2,($69|0),1.0,(+$70),(+$71),($lightFade|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if (!($73)) {
      $74 = (($63) + 676|0);
      ;HEAP32[$74+0>>2]=HEAP32[$lightFade+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$lightFade+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$lightFade+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$lightFade+12>>2]|0;
      $75 = (($63) + 932|0);
      ;HEAP32[$75+0>>2]=HEAP32[$fadeCenterAndType+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$fadeCenterAndType+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$fadeCenterAndType+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$fadeCenterAndType+12>>2]|0;
      __THREW__ = 0;
      $76 = (invoke_i(63)|0);
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if (!($78)) {
       __THREW__ = 0;
       $79 = (invoke_i(66)|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if (!($81)) {
        $82 = ($79|0)==(1);
        $83 = (($76) + 40|0);
        $84 = Math_fround(HEAPF32[$83>>2]);
        do {
         if ($82) {
          $85 = !($84 <= Math_fround(0.0404499992728233337402));
          do {
           if ($85) {
            $87 = $84 < Math_fround(1.0);
            if ($87) {
             $88 = Math_fround($84 + Math_fround(0.054999999701976776123));
             $89 = Math_fround($88 / Math_fround(1.05499994754791259766));
             $90 = (Math_fround(+(Math_pow((+$89),2.40000009536743164063))));
             $$0$i$i$i$i = $90;
             break;
            } else {
             $91 = (Math_fround(+(Math_pow((+$84),2.40000009536743164063))));
             $$0$i$i$i$i = $91;
             break;
            }
           } else {
            $86 = Math_fround($84 / Math_fround(12.9200000762939453125));
            $$0$i$i$i$i = $86;
           }
          } while(0);
          $92 = (($76) + 44|0);
          $93 = Math_fround(HEAPF32[$92>>2]);
          $94 = !($93 <= Math_fround(0.0404499992728233337402));
          do {
           if ($94) {
            $96 = $93 < Math_fround(1.0);
            if ($96) {
             $97 = Math_fround($93 + Math_fround(0.054999999701976776123));
             $98 = Math_fround($97 / Math_fround(1.05499994754791259766));
             $99 = (Math_fround(+(Math_pow((+$98),2.40000009536743164063))));
             $$0$i3$i$i$i = $99;
             break;
            } else {
             $100 = (Math_fround(+(Math_pow((+$93),2.40000009536743164063))));
             $$0$i3$i$i$i = $100;
             break;
            }
           } else {
            $95 = Math_fround($93 / Math_fround(12.9200000762939453125));
            $$0$i3$i$i$i = $95;
           }
          } while(0);
          $101 = (($76) + 48|0);
          $102 = Math_fround(HEAPF32[$101>>2]);
          $103 = !($102 <= Math_fround(0.0404499992728233337402));
          if (!($103)) {
           $104 = Math_fround($102 / Math_fround(12.9200000762939453125));
           $$0$i$i$i$i15 = $$0$i$i$i$i;$$0$i1$i$i$i17 = $104;$$0$i3$i$i$i16 = $$0$i3$i$i$i;
           break;
          }
          $105 = $102 < Math_fround(1.0);
          if ($105) {
           $106 = Math_fround($102 + Math_fround(0.054999999701976776123));
           $107 = Math_fround($106 / Math_fround(1.05499994754791259766));
           $108 = (Math_fround(+(Math_pow((+$107),2.40000009536743164063))));
           $$0$i$i$i$i15 = $$0$i$i$i$i;$$0$i1$i$i$i17 = $108;$$0$i3$i$i$i16 = $$0$i3$i$i$i;
           break;
          } else {
           $109 = (Math_fround(+(Math_pow((+$102),2.40000009536743164063))));
           $$0$i$i$i$i15 = $$0$i$i$i$i;$$0$i1$i$i$i17 = $109;$$0$i3$i$i$i16 = $$0$i3$i$i$i;
           break;
          }
         } else {
          $110 = (($76) + 44|0);
          $111 = Math_fround(HEAPF32[$110>>2]);
          $112 = (($76) + 48|0);
          $113 = Math_fround(HEAPF32[$112>>2]);
          $$0$i$i$i$i15 = $84;$$0$i1$i$i$i17 = $113;$$0$i3$i$i$i16 = $111;
         }
        } while(0);
        $$in = (($76) + 52|0);
        $114 = Math_fround(HEAPF32[$$in>>2]);
        $115 = (($63) + 660|0);
        HEAPF32[$115>>2] = $$0$i$i$i$i15;
        $116 = (($63) + 664|0);
        HEAPF32[$116>>2] = $$0$i3$i$i$i16;
        $117 = (($63) + 668|0);
        HEAPF32[$117>>2] = $$0$i1$i$i$i17;
        $118 = (($63) + 672|0);
        HEAPF32[$118>>2] = $114;
        __THREW__ = 0;
        $119 = (invoke_i(59)|0);
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if (!($121)) {
         $122 = HEAP32[$ctx>>2]|0;
         $123 = (($122) + 348|0);
         $124 = HEAP32[$123>>2]|0;
         $125 = (($124) + 140|0);
         $126 = HEAP32[$125>>2]|0;
         $127 = ($126|0)==(0|0);
         if ($127) {
          $128 = (($124) + 148|0);
          $129 = HEAP32[$128>>2]|0;
          $130 = ($129|0)==(0|0);
          if ($130) {
           __THREW__ = 0;
           (invoke_ii(3218,($124|0))|0);
           $131 = __THREW__; __THREW__ = 0;
           $132 = $131&1;
           if ($132) {
            break;
           }
          }
         }
         __THREW__ = 0;
         $133 = (invoke_i(67)|0);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if (!($135)) {
          HEAP32[$lightingLayers>>2] = $133;
          $scevgep$i$i = (($lightingLayers) + 4|0);
          dest=$scevgep$i$i+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          $136 = (($lightingLayers) + 132|0);
          HEAP32[$136>>2] = 0;
          $140 = 0;$bit$01$i$i = 3;$i1$03$i$i = 0;$mask$02$i$i = 1;
          while(1) {
           $137 = $mask$02$i$i & $133;
           $138 = ($137|0)==(0);
           if ($138) {
            $278 = $140;$bit$1$i$i = $bit$01$i$i;
           } else {
            $139 = ($140|0)<(4);
            if ($139) {
             $141 = ((($lightingLayers) + ($i1$03$i$i<<2)|0) + 4|0);
             HEAP32[$141>>2] = $bit$01$i$i;
             $$pre$i$i8 = HEAP32[$136>>2]|0;
             $144 = $$pre$i$i8;
            } else {
             $144 = $140;
            }
            $142 = (($bit$01$i$i) + -1)|0;
            $143 = (($144) + 1)|0;
            HEAP32[$136>>2] = $143;
            $278 = $143;$bit$1$i$i = $142;
           }
           $145 = (($i1$03$i$i) + 1)|0;
           $146 = $mask$02$i$i << 1;
           $exitcond$i$i = ($145|0)==(32);
           if ($exitcond$i$i) {
            break;
           } else {
            $140 = $278;$bit$01$i$i = $bit$1$i$i;$i1$03$i$i = $145;$mask$02$i$i = $146;
           }
          }
          HEAP8[678904>>0] = 0;
          $147 = (($receiverBounds) + 12|0);
          $148 = (($receiverBounds) + 16|0);
          $149 = (($receiverBounds) + 20|0);
          ;HEAP32[$receiverBounds+0>>2]=0|0;HEAP32[$receiverBounds+4>>2]=0|0;HEAP32[$receiverBounds+8>>2]=0|0;HEAP32[$receiverBounds+12>>2]=0|0;HEAP32[$receiverBounds+16>>2]=0|0;
          ;HEAP32[$receiverBounds+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$receiverBounds+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$receiverBounds+8>>2]=HEAP32[616664+8>>2]|0;
          $150 = Math_fround(HEAPF32[616664>>2]);
          $151 = Math_fround(-$150);
          $152 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
          $153 = Math_fround(-$152);
          $154 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
          $155 = Math_fround(-$154);
          HEAPF32[$147>>2] = $151;
          HEAPF32[$148>>2] = $153;
          HEAPF32[$149>>2] = $155;
          __THREW__ = 0;
          $156 = (invoke_iiiiii(194,($loop|0),($124|0),($lightingLayers|0),($outRemainingObjects|0),($receiverBounds|0))|0);
          $157 = __THREW__; __THREW__ = 0;
          $158 = $157&1;
          if (!($158)) {
           HEAP32[$outDepthRT>>2] = $156;
           $159 = (($156) + 140|0);
           $160 = HEAP32[$159>>2]|0;
           $161 = (($124) + 148|0);
           $162 = HEAP32[$161>>2]|0;
           $163 = (($124) + 136|0);
           $164 = HEAP32[$163>>2]|0;
           HEAP32[$depthTextureID>>2] = $164;
           $165 = (($124) + 120|0);
           $166 = HEAP32[$165>>2]|0;
           $167 = (($119) + 5928|0);
           $168 = HEAP32[$167>>2]|0;
           $169 = ($168|0)==(8);
           if ($169) {
            __THREW__ = 0;
            $170 = (invoke_iiiii(232,($ctx|0),($objects|0),($14|0),($8|0))|0);
            $171 = __THREW__; __THREW__ = 0;
            $172 = $171&1;
            if ($172) {
             break;
            }
            $173 = (($170) + 44|0);
            $174 = HEAP32[$173>>2]|0;
            HEAP32[$depthTextureID>>2] = $174;
            HEAP32[$outDepthRT>>2] = $170;
            $175 = (($170) + 140|0);
            $176 = HEAP32[$175>>2]|0;
            $177 = (($170) + 148|0);
            $178 = HEAP32[$177>>2]|0;
            HEAP8[$outDepthWasCopied>>0] = 1;
            $colorSurfaceHandle$sroa$0$0 = $176;$depthTextureHandle$sroa$0$0 = $178;
           } else {
            $colorSurfaceHandle$sroa$0$0 = $160;$depthTextureHandle$sroa$0$0 = $162;
           }
           $179 = HEAP8[((640792 + 248|0))>>0]|0;
           $180 = ($179<<24>>24)==(0);
           do {
            if (!($180)) {
             $181 = (($activeLights) + 16|0);
             $182 = HEAP8[$181>>0]|0;
             $183 = ($182<<24>>24)==(0);
             do {
              if ($183) {
               label = 61;
              } else {
               $184 = HEAP32[$activeLights>>2]|0;
               $185 = ($184|0)==(0|0);
               if ($185) {
                label = 61;
               } else {
                $186 = HEAP32[$184>>2]|0;
                $187 = ($186|0)==(0|0);
                if ($187) {
                 label = 61;
                } else {
                 $188 = (($186) + 216|0);
                 $189 = HEAP32[$188>>2]|0;
                 $190 = ($189|0)==(1);
                 if (!($190)) {
                  label = 61;
                  break;
                 }
                 $194 = (($186) + 116|0);
                 $195 = HEAP32[$194>>2]|0;
                 $196 = ($195|0)==(0);
                 $197 = HEAP32[$ctx>>2]|0;
                 $198 = (($197) + 604|0);
                 $199 = HEAP32[$198>>2]|0;
                 if ($196) {
                  $201 = $199;
                  label = 63;
                 } else {
                  $208 = $199;
                 }
                }
               }
              }
             } while(0);
             if ((label|0) == 61) {
              $191 = HEAP32[$ctx>>2]|0;
              $192 = (($191) + 604|0);
              $193 = HEAP32[$192>>2]|0;
              $201 = $193;
              label = 63;
             }
             if ((label|0) == 63) {
              $200 = $201 & 1;
              $202 = ($200|0)==(0);
              if ($202) {
               break;
              } else {
               $208 = $201;
              }
             }
             HEAP32[$3>>2] = $colorSurfaceHandle$sroa$0$0;
             HEAP32[$4>>2] = $depthTextureHandle$sroa$0$0;
             $203 = (($124) + 100|0);
             $204 = HEAP32[$203>>2]|0;
             $205 = (($124) + 104|0);
             $206 = HEAP32[$205>>2]|0;
             $207 = $208 & 1;
             $209 = ($207|0)!=(0);
             __THREW__ = 0;
             ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
             ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$4+0>>2]|0;
             invoke_viiiiiiii(24,($ctx|0),($124|0),($outRemainingObjects|0),($$byval_copy8|0),($$byval_copy13|0),($204|0),($206|0),($209|0));
             $210 = __THREW__; __THREW__ = 0;
             $211 = $210&1;
             if ($211) {
              break L22;
             }
            }
           } while(0);
           if (!($169)) {
            $212 = (($ctx) + 116|0);
            $213 = HEAP32[$212>>2]|0;
            __THREW__ = 0;
            invoke_viiiiii(102,($119|0),($213|0),($166|0),($outDepthRT|0),($depthTextureID|0),($outDepthWasCopied|0));
            $214 = __THREW__; __THREW__ = 0;
            $215 = $214&1;
            if ($215) {
             break;
            }
           }
           HEAP32[$rtLight>>2] = 0;
           $216 = HEAP32[$depthTextureID>>2]|0;
           HEAP32[$5>>2] = $216;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$5+0>>2]|0;
           invoke_viiiiiiiiii(6,($loop|0),($activeLights|0),($124|0),($$byval_copy13|0),($156|0),($rtLight|0),($lightFade|0),($lightingLayers|0),($receiverBounds|0),($outMainShadowMap|0));
           $217 = __THREW__; __THREW__ = 0;
           $218 = $217&1;
           if (!($218)) {
            HEAP8[678904>>0] = 1;
            $219 = HEAP32[$ctx>>2]|0;
            $220 = (($219) + 623|0);
            $221 = HEAP8[$220>>0]|0;
            $222 = ($221<<24>>24)==(0);
            if ($222) {
             $230 = $219;
            } else {
             ;HEAP32[$black+0>>2]=0|0;HEAP32[$black+4>>2]=0|0;HEAP32[$black+8>>2]=0|0;HEAP32[$black+12>>2]=0|0;
             $223 = HEAP32[$119>>2]|0;
             $224 = (($223) + 24|0);
             $225 = HEAP32[$224>>2]|0;
             __THREW__ = 0;
             invoke_viiifi($225|0,($119|0),4,($black|0),1.0,0);
             $226 = __THREW__; __THREW__ = 0;
             $227 = $226&1;
             if ($227) {
              break;
             }
             $$pre27 = HEAP32[$ctx>>2]|0;
             $230 = $$pre27;
            }
            $228 = HEAP32[$rtLight>>2]|0;
            $229 = (($230) + 620|0);
            $231 = HEAP8[$229>>0]|0;
            $232 = ($231<<24>>24)!=(0);
            __THREW__ = 0;
            invoke_viiiii(91,($loop|0),($124|0),($228|0),($232|0),($linearLighting|0));
            $233 = __THREW__; __THREW__ = 0;
            $234 = $233&1;
            if (!($234)) {
             $235 = ($228|0)==(0|0);
             if (!($235)) {
              $236 = HEAP32[$119>>2]|0;
              $237 = (($236) + 452|0);
              $238 = HEAP32[$237>>2]|0;
              $239 = (($228) + 140|0);
              $240 = HEAP32[$239>>2]|0;
              HEAP32[$6>>2] = $240;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$6+0>>2]|0;
              invoke_viiii($238|0,($119|0),($$byval_copy13|0),0,-4);
              $241 = __THREW__; __THREW__ = 0;
              $242 = $241&1;
              if ($242) {
               break;
              }
              $243 = HEAP32[$119>>2]|0;
              $244 = (($243) + 452|0);
              $245 = HEAP32[$244>>2]|0;
              $246 = (($228) + 148|0);
              $247 = HEAP32[$246>>2]|0;
              HEAP32[$7>>2] = $247;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$7+0>>2]|0;
              invoke_viiii($245|0,($119|0),($$byval_copy13|0),0,-4);
              $248 = __THREW__; __THREW__ = 0;
              $249 = $248&1;
              if ($249) {
               break;
              }
             }
             $250 = HEAP32[$ctx>>2]|0;
             $251 = (($250) + 604|0);
             $252 = HEAP32[$251>>2]|0;
             $253 = $252 & 2;
             $254 = ($253|0)==(0);
             if (!($254)) {
              __THREW__ = 0;
              $255 = (invoke_iii(2367,($ctx|0),($outRemainingObjects|0))|0);
              $256 = __THREW__; __THREW__ = 0;
              $257 = $256&1;
              if ($257) {
               break;
              }
              HEAP32[$outDepthNormalsRT>>2] = $255;
              __THREW__ = 0;
              invoke_viiii(337,($124|0),0,-1,0);
              $258 = __THREW__; __THREW__ = 0;
              $259 = $258&1;
              if ($259) {
               break;
              }
             }
             $260 = HEAP32[$119>>2]|0;
             $261 = (($260) + 100|0);
             $262 = HEAP32[$261>>2]|0;
             $263 = (($ctx) + 12|0);
             __THREW__ = 0;
             invoke_vii($262|0,($119|0),($263|0));
             $264 = __THREW__; __THREW__ = 0;
             $265 = $264&1;
             if ($265) {
              break;
             }
             $266 = HEAP32[$119>>2]|0;
             $267 = (($266) + 136|0);
             $268 = HEAP32[$267>>2]|0;
             __THREW__ = 0;
             invoke_vii($268|0,($119|0),0);
             $269 = __THREW__; __THREW__ = 0;
             $270 = $269&1;
             if ($270) {
              break;
             }
             $271 = HEAP32[$11>>2]|0;
             $272 = ($271|0)>(-1);
             if (!($272)) {
              STACKTOP = sp;return;
             }
             $273 = HEAP32[$9>>2]|0;
             $274 = HEAP32[$12>>2]|0;
             HEAP32[$$byval_copy8>>2] = $274;
             ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy8+0>>2]|0;
             __Z19free_alloc_internalPv10MemLabelId($273,$$byval_copy13);
             HEAP32[$9>>2] = 0;
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  } while(0);
  $52 = ___cxa_find_matching_catch()|0;
  $53 = tempRet0;
  $lpad$phi$index = $52;$lpad$phi$index2 = $53;
 }
 $54 = HEAP32[$11>>2]|0;
 $55 = ($54|0)>(-1);
 if (!($55)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $56 = HEAP32[$9>>2]|0;
 $57 = HEAP32[$12>>2]|0;
 HEAP32[$$byval_copy8>>2] = $57;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy8+0>>2]|0;
 invoke_vii(2591,($56|0),($$byval_copy13|0));
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if ($59) {
  $275 = ___cxa_find_matching_catch(0|0)|0;
  $276 = tempRet0;
  ___clang_call_terminate($275);
  // unreachable;
 }
 HEAP32[$9>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16__sortIR25RenderPrePassObjectSorterP16RenderObjectDataEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0);
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $__i$038 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0;
 var $__i$4 = 0, $__j$035 = 0, $__j$035$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i33 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i33 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -44|0);
  $2 = (($$01$ph) + -88|0);
  $3 = (($$01$ph) + -4|0);
  $4 = (($$01$ph) + -40|0);
  $5 = (($$01$ph) + -32|0);
  $6 = (($$01$ph) + -24|0);
  $7 = (($$01$ph) + -20|0);
  $8 = (($$01$ph) + -28|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $9 = $$0;
   $10 = (($0) - ($9))|0;
   $11 = (($10|0) / 44)&-1;
   switch ($11|0) {
   case 3:  {
    label = 19;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 4:  {
    label = 20;
    break L1;
    break;
   }
   case 5:  {
    label = 21;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 181;
    break L1;
    break;
   }
   default: {
   }
   }
   $56 = ($10|0)<(1364);
   if ($56) {
    label = 23;
    break L1;
   }
   $57 = ($10|0)>(43956);
   $58 = (($10|0) / 88)&-1;
   $59 = (($$0) + (($58*44)|0)|0);
   if ($57) {
    $60 = (($10|0) / 176)&-1;
    $61 = (($$0) + (($60*44)|0)|0);
    $$sum = (($60) + ($58))|0;
    $62 = (($$0) + (($$sum*44)|0)|0);
    $63 = (__ZNSt3__17__sort5IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_S5_T_($$0,$61,$59,$62,$1,0)|0);
    $__n_swaps$0 = $63;
   } else {
    $64 = (__ZNSt3__17__sort3IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($$0,$59,$1,0)|0);
    $__n_swaps$0 = $64;
   }
   $65 = (($$0) + 40|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ((($$0) + (($58*44)|0)|0) + 40|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($66|0)==($68|0);
   do {
    if ($69) {
     $71 = (($$0) + 4|0);
     $72 = HEAP16[$71>>1]|0;
     $73 = ((($$0) + (($58*44)|0)|0) + 4|0);
     $74 = HEAP16[$73>>1]|0;
     $75 = ($72<<16>>16)==($74<<16>>16);
     if (!($75)) {
      $76 = ($72<<16>>16)<($74<<16>>16);
      if ($76) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 41;
       break;
      }
     }
     $77 = (($$0) + 12|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ((($$0) + (($58*44)|0)|0) + 12|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($78|0)==($80|0);
     if (!($81)) {
      $82 = ($78>>>0)<($80>>>0);
      if ($82) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 41;
       break;
      }
     }
     $83 = (($$0) + 20|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ((($$0) + (($58*44)|0)|0) + 20|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($84|0)==($86|0);
     if (!($87)) {
      $88 = ($84|0)>($86|0);
      if ($88) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 41;
       break;
      }
     }
     $89 = HEAP32[$$0>>2]|0;
     $90 = HEAP32[$59>>2]|0;
     $91 = ($89|0)==($90|0);
     if (!($91)) {
      $92 = (($89) + 4|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = (($90) + 4|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = ($93|0)<($95|0);
      if ($96) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 41;
       break;
      }
     }
     $97 = (($$0) + 24|0);
     $98 = Math_fround(HEAPF32[$97>>2]);
     $99 = ((($$0) + (($58*44)|0)|0) + 24|0);
     $100 = Math_fround(HEAPF32[$99>>2]);
     $101 = $98 == $100;
     if ($101) {
      $102 = (($$0) + 16|0);
      $103 = HEAP16[$102>>1]|0;
      $104 = ((($$0) + (($58*44)|0)|0) + 16|0);
      $105 = HEAP16[$104>>1]|0;
      $106 = ($103<<16>>16)==($105<<16>>16);
      if (!($106)) {
       $107 = ($103&65535)>($105&65535);
       if ($107) {
        $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
        break;
       } else {
        label = 41;
        break;
       }
      }
     }
     $108 = $98 > $100;
     if ($108) {
      $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
     } else {
      label = 41;
     }
    } else {
     $70 = ($66>>>0)<($68>>>0);
     if ($70) {
      $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
     } else {
      label = 41;
     }
    }
   } while(0);
   L30: do {
    if ((label|0) == 41) {
     label = 0;
     $109 = ($$0|0)==($2|0);
     L32: do {
      if (!($109)) {
       $110 = ((($$0) + (($58*44)|0)|0) + 4|0);
       $111 = ((($$0) + (($58*44)|0)|0) + 12|0);
       $112 = ((($$0) + (($58*44)|0)|0) + 20|0);
       $113 = ((($$0) + (($58*44)|0)|0) + 24|0);
       $114 = ((($$0) + (($58*44)|0)|0) + 16|0);
       $303 = $2;$__j$035 = $1;
       L34: while(1) {
        $283 = (($__j$035) + -4|0);
        $284 = HEAP32[$283>>2]|0;
        $285 = ($284|0)==($68|0);
        do {
         if ($285) {
          $287 = (($__j$035) + -40|0);
          $288 = HEAP16[$287>>1]|0;
          $289 = HEAP16[$110>>1]|0;
          $290 = ($288<<16>>16)==($289<<16>>16);
          if (!($290)) {
           $291 = ($288<<16>>16)<($289<<16>>16);
           if ($291) {
            break L34;
           } else {
            break;
           }
          }
          $292 = (($__j$035) + -32|0);
          $293 = HEAP32[$292>>2]|0;
          $294 = HEAP32[$111>>2]|0;
          $295 = ($293|0)==($294|0);
          if (!($295)) {
           $296 = ($293>>>0)<($294>>>0);
           if ($296) {
            break L34;
           } else {
            break;
           }
          }
          $297 = (($__j$035) + -24|0);
          $298 = HEAP32[$297>>2]|0;
          $299 = HEAP32[$112>>2]|0;
          $300 = ($298|0)==($299|0);
          if (!($300)) {
           $301 = ($298|0)>($299|0);
           if ($301) {
            break L34;
           } else {
            break;
           }
          }
          $302 = HEAP32[$303>>2]|0;
          $304 = HEAP32[$59>>2]|0;
          $305 = ($302|0)==($304|0);
          if (!($305)) {
           $306 = (($302) + 4|0);
           $307 = HEAP32[$306>>2]|0;
           $308 = (($304) + 4|0);
           $309 = HEAP32[$308>>2]|0;
           $310 = ($307|0)<($309|0);
           if ($310) {
            break L34;
           } else {
            break;
           }
          }
          $311 = (($__j$035) + -20|0);
          $312 = Math_fround(HEAPF32[$311>>2]);
          $313 = Math_fround(HEAPF32[$113>>2]);
          $314 = $312 == $313;
          if ($314) {
           $315 = (($__j$035) + -28|0);
           $316 = HEAP16[$315>>1]|0;
           $317 = HEAP16[$114>>1]|0;
           $318 = ($316<<16>>16)==($317<<16>>16);
           if (!($318)) {
            $319 = ($316&65535)>($317&65535);
            if ($319) {
             break L34;
            } else {
             break;
            }
           }
          }
          $320 = $312 > $313;
          if ($320) {
           break L34;
          }
         } else {
          $286 = ($284>>>0)<($68>>>0);
          if ($286) {
           break L34;
          }
         }
        } while(0);
        $321 = (($303) + -44|0);
        $322 = ($$0|0)==($321|0);
        if ($322) {
         break L32;
        } else {
         $__j$035$phi = $303;$303 = $321;$__j$035 = $__j$035$phi;
        }
       }
       dest=$__t$i33+0|0; src=$$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       dest=$$0+0|0; src=$303+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       dest=$303+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $323 = (($__n_swaps$0) + 1)|0;
       $__j$3 = $303;$__n_swaps$3 = $323;
       break L30;
      }
     } while(0);
     $115 = (($$0) + 44|0);
     $116 = HEAP32[$3>>2]|0;
     $117 = ($66|0)==($116|0);
     do {
      if ($117) {
       $119 = (($$0) + 4|0);
       $120 = HEAP16[$119>>1]|0;
       $121 = HEAP16[$4>>1]|0;
       $122 = ($120<<16>>16)==($121<<16>>16);
       if (!($122)) {
        $123 = ($120<<16>>16)<($121<<16>>16);
        if ($123) {
         $__i$1 = $115;
         break;
        } else {
         label = 57;
         break;
        }
       }
       $124 = (($$0) + 12|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = HEAP32[$5>>2]|0;
       $127 = ($125|0)==($126|0);
       if (!($127)) {
        $128 = ($125>>>0)<($126>>>0);
        if ($128) {
         $__i$1 = $115;
         break;
        } else {
         label = 57;
         break;
        }
       }
       $129 = (($$0) + 20|0);
       $130 = HEAP32[$129>>2]|0;
       $131 = HEAP32[$6>>2]|0;
       $132 = ($130|0)==($131|0);
       if (!($132)) {
        $133 = ($130|0)>($131|0);
        if ($133) {
         $__i$1 = $115;
         break;
        } else {
         label = 57;
         break;
        }
       }
       $134 = HEAP32[$$0>>2]|0;
       $135 = HEAP32[$1>>2]|0;
       $136 = ($134|0)==($135|0);
       if (!($136)) {
        $137 = (($134) + 4|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = (($135) + 4|0);
        $140 = HEAP32[$139>>2]|0;
        $141 = ($138|0)<($140|0);
        if ($141) {
         $__i$1 = $115;
         break;
        } else {
         label = 57;
         break;
        }
       }
       $142 = (($$0) + 24|0);
       $143 = Math_fround(HEAPF32[$142>>2]);
       $144 = Math_fround(HEAPF32[$7>>2]);
       $145 = $143 == $144;
       if ($145) {
        $146 = (($$0) + 16|0);
        $147 = HEAP16[$146>>1]|0;
        $148 = HEAP16[$8>>1]|0;
        $149 = ($147<<16>>16)==($148<<16>>16);
        if (!($149)) {
         $150 = ($147&65535)>($148&65535);
         if ($150) {
          $__i$1 = $115;
          break;
         } else {
          label = 57;
          break;
         }
        }
       }
       $151 = $143 > $144;
       if ($151) {
        $__i$1 = $115;
       } else {
        label = 57;
       }
      } else {
       $118 = ($66>>>0)<($116>>>0);
       if ($118) {
        $__i$1 = $115;
       } else {
        label = 57;
       }
      }
     } while(0);
     if ((label|0) == 57) {
      label = 0;
      $152 = ($115|0)==($1|0);
      if ($152) {
       label = 181;
       break L1;
      }
      $153 = (($$0) + 4|0);
      $154 = (($$0) + 12|0);
      $155 = (($$0) + 20|0);
      $156 = (($$0) + 24|0);
      $157 = (($$0) + 16|0);
      $__i$038 = $115;
      L80: while(1) {
       $158 = (($__i$038) + 40|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = ($66|0)==($159|0);
       do {
        if ($160) {
         $162 = HEAP16[$153>>1]|0;
         $163 = (($__i$038) + 4|0);
         $164 = HEAP16[$163>>1]|0;
         $165 = ($162<<16>>16)==($164<<16>>16);
         if (!($165)) {
          $166 = ($162<<16>>16)<($164<<16>>16);
          if ($166) {
           break L80;
          } else {
           break;
          }
         }
         $167 = HEAP32[$154>>2]|0;
         $168 = (($__i$038) + 12|0);
         $169 = HEAP32[$168>>2]|0;
         $170 = ($167|0)==($169|0);
         if (!($170)) {
          $171 = ($167>>>0)<($169>>>0);
          if ($171) {
           break L80;
          } else {
           break;
          }
         }
         $172 = HEAP32[$155>>2]|0;
         $173 = (($__i$038) + 20|0);
         $174 = HEAP32[$173>>2]|0;
         $175 = ($172|0)==($174|0);
         if (!($175)) {
          $176 = ($172|0)>($174|0);
          if ($176) {
           break L80;
          } else {
           break;
          }
         }
         $177 = HEAP32[$$0>>2]|0;
         $178 = HEAP32[$__i$038>>2]|0;
         $179 = ($177|0)==($178|0);
         if (!($179)) {
          $180 = (($177) + 4|0);
          $181 = HEAP32[$180>>2]|0;
          $182 = (($178) + 4|0);
          $183 = HEAP32[$182>>2]|0;
          $184 = ($181|0)<($183|0);
          if ($184) {
           break L80;
          } else {
           break;
          }
         }
         $185 = Math_fround(HEAPF32[$156>>2]);
         $186 = (($__i$038) + 24|0);
         $187 = Math_fround(HEAPF32[$186>>2]);
         $188 = $185 == $187;
         if ($188) {
          $189 = HEAP16[$157>>1]|0;
          $190 = (($__i$038) + 16|0);
          $191 = HEAP16[$190>>1]|0;
          $192 = ($189<<16>>16)==($191<<16>>16);
          if (!($192)) {
           $193 = ($189&65535)>($191&65535);
           if ($193) {
            break L80;
           } else {
            break;
           }
          }
         }
         $194 = $185 > $187;
         if ($194) {
          break L80;
         }
        } else {
         $161 = ($66>>>0)<($159>>>0);
         if ($161) {
          break L80;
         }
        }
       } while(0);
       $196 = (($__i$038) + 44|0);
       $197 = ($196|0)==($1|0);
       if ($197) {
        label = 181;
        break L1;
       } else {
        $__i$038 = $196;
       }
      }
      dest=$__t$i33+0|0; src=$__i$038+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$__i$038+0|0; src=$1+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$1+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $195 = (($__i$038) + 44|0);
      $__i$1 = $195;
     }
     $198 = ($__i$1|0)==($1|0);
     if ($198) {
      label = 181;
      break L1;
     }
     $199 = (($$0) + 4|0);
     $200 = (($$0) + 12|0);
     $201 = (($$0) + 20|0);
     $202 = (($$0) + 24|0);
     $203 = (($$0) + 16|0);
     $__i$2$ph = $__i$1;$__j$1$ph = $1;
     while(1) {
      $204 = HEAP32[$65>>2]|0;
      $__i$2 = $__i$2$ph;
      L107: while(1) {
       $205 = (($__i$2) + 40|0);
       $206 = HEAP32[$205>>2]|0;
       $207 = ($204|0)==($206|0);
       do {
        if ($207) {
         $209 = HEAP16[$199>>1]|0;
         $210 = (($__i$2) + 4|0);
         $211 = HEAP16[$210>>1]|0;
         $212 = ($209<<16>>16)==($211<<16>>16);
         if (!($212)) {
          $213 = ($209<<16>>16)<($211<<16>>16);
          if ($213) {
           $__j$2 = $__j$1$ph;
           break L107;
          } else {
           break;
          }
         }
         $214 = HEAP32[$200>>2]|0;
         $215 = (($__i$2) + 12|0);
         $216 = HEAP32[$215>>2]|0;
         $217 = ($214|0)==($216|0);
         if (!($217)) {
          $218 = ($214>>>0)<($216>>>0);
          if ($218) {
           $__j$2 = $__j$1$ph;
           break L107;
          } else {
           break;
          }
         }
         $219 = HEAP32[$201>>2]|0;
         $220 = (($__i$2) + 20|0);
         $221 = HEAP32[$220>>2]|0;
         $222 = ($219|0)==($221|0);
         if (!($222)) {
          $223 = ($219|0)>($221|0);
          if ($223) {
           $__j$2 = $__j$1$ph;
           break L107;
          } else {
           break;
          }
         }
         $224 = HEAP32[$$0>>2]|0;
         $225 = HEAP32[$__i$2>>2]|0;
         $226 = ($224|0)==($225|0);
         if (!($226)) {
          $227 = (($224) + 4|0);
          $228 = HEAP32[$227>>2]|0;
          $229 = (($225) + 4|0);
          $230 = HEAP32[$229>>2]|0;
          $231 = ($228|0)<($230|0);
          if ($231) {
           $__j$2 = $__j$1$ph;
           break L107;
          } else {
           break;
          }
         }
         $232 = Math_fround(HEAPF32[$202>>2]);
         $233 = (($__i$2) + 24|0);
         $234 = Math_fround(HEAPF32[$233>>2]);
         $235 = $232 == $234;
         if ($235) {
          $236 = HEAP16[$203>>1]|0;
          $237 = (($__i$2) + 16|0);
          $238 = HEAP16[$237>>1]|0;
          $239 = ($236<<16>>16)==($238<<16>>16);
          if (!($239)) {
           $240 = ($236&65535)>($238&65535);
           if ($240) {
            $__j$2 = $__j$1$ph;
            break L107;
           } else {
            break;
           }
          }
         }
         $241 = $232 > $234;
         if ($241) {
          $__j$2 = $__j$1$ph;
          break L107;
         }
        } else {
         $208 = ($204>>>0)<($206>>>0);
         if ($208) {
          $__j$2 = $__j$1$ph;
          break L107;
         }
        }
       } while(0);
       $242 = (($__i$2) + 44|0);
       $__i$2 = $242;
      }
      while(1) {
       $243 = (($__j$2) + -44|0);
       $244 = (($__j$2) + -4|0);
       $245 = HEAP32[$244>>2]|0;
       $246 = ($204|0)==($245|0);
       if (!($246)) {
        $247 = ($204>>>0)<($245>>>0);
        if ($247) {
         $__j$2 = $243;
         continue;
        } else {
         break;
        }
       }
       $248 = HEAP16[$199>>1]|0;
       $249 = (($__j$2) + -40|0);
       $250 = HEAP16[$249>>1]|0;
       $251 = ($248<<16>>16)==($250<<16>>16);
       if (!($251)) {
        $252 = ($248<<16>>16)<($250<<16>>16);
        if ($252) {
         $__j$2 = $243;
         continue;
        } else {
         break;
        }
       }
       $253 = HEAP32[$200>>2]|0;
       $254 = (($__j$2) + -32|0);
       $255 = HEAP32[$254>>2]|0;
       $256 = ($253|0)==($255|0);
       if (!($256)) {
        $257 = ($253>>>0)<($255>>>0);
        if ($257) {
         $__j$2 = $243;
         continue;
        } else {
         break;
        }
       }
       $258 = HEAP32[$201>>2]|0;
       $259 = (($__j$2) + -24|0);
       $260 = HEAP32[$259>>2]|0;
       $261 = ($258|0)==($260|0);
       if (!($261)) {
        $262 = ($258|0)>($260|0);
        if ($262) {
         $__j$2 = $243;
         continue;
        } else {
         break;
        }
       }
       $263 = HEAP32[$$0>>2]|0;
       $264 = HEAP32[$243>>2]|0;
       $265 = ($263|0)==($264|0);
       if (!($265)) {
        $266 = (($263) + 4|0);
        $267 = HEAP32[$266>>2]|0;
        $268 = (($264) + 4|0);
        $269 = HEAP32[$268>>2]|0;
        $270 = ($267|0)<($269|0);
        if ($270) {
         $__j$2 = $243;
         continue;
        } else {
         break;
        }
       }
       $271 = Math_fround(HEAPF32[$202>>2]);
       $272 = (($__j$2) + -20|0);
       $273 = Math_fround(HEAPF32[$272>>2]);
       $274 = $271 == $273;
       if ($274) {
        $275 = HEAP16[$203>>1]|0;
        $276 = (($__j$2) + -28|0);
        $277 = HEAP16[$276>>1]|0;
        $278 = ($275<<16>>16)==($277<<16>>16);
        if (!($278)) {
         $279 = ($275&65535)>($277&65535);
         if ($279) {
          $__j$2 = $243;
          continue;
         } else {
          break;
         }
        }
       }
       $280 = $271 > $273;
       if ($280) {
        $__j$2 = $243;
       } else {
        break;
       }
      }
      $281 = ($__i$2>>>0)<($243>>>0);
      if (!($281)) {
       $$0 = $__i$2;
       continue L3;
      }
      dest=$__t$i33+0|0; src=$__i$2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$__i$2+0|0; src=$243+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$243+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $282 = (($__i$2) + 44|0);
      $__i$2$ph = $282;$__j$1$ph = $243;
     }
    }
   } while(0);
   $324 = (($$0) + 44|0);
   $325 = ($324>>>0)<($__j$3>>>0);
   L153: do {
    if ($325) {
     $__i$3$ph = $324;$__j$4$ph = $__j$3;$__m$0$ph = $59;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $326 = (($__m$0$ph) + 40|0);
      $327 = HEAP32[$326>>2]|0;
      $328 = (($__m$0$ph) + 4|0);
      $329 = (($__m$0$ph) + 12|0);
      $330 = (($__m$0$ph) + 20|0);
      $331 = (($__m$0$ph) + 24|0);
      $332 = (($__m$0$ph) + 16|0);
      $__i$3 = $__i$3$ph;
      L156: while(1) {
       $333 = (($__i$3) + 40|0);
       $334 = HEAP32[$333>>2]|0;
       $335 = ($334|0)==($327|0);
       do {
        if ($335) {
         $337 = (($__i$3) + 4|0);
         $338 = HEAP16[$337>>1]|0;
         $339 = HEAP16[$328>>1]|0;
         $340 = ($338<<16>>16)==($339<<16>>16);
         if (!($340)) {
          $341 = ($338<<16>>16)<($339<<16>>16);
          if ($341) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L156;
          }
         }
         $342 = (($__i$3) + 12|0);
         $343 = HEAP32[$342>>2]|0;
         $344 = HEAP32[$329>>2]|0;
         $345 = ($343|0)==($344|0);
         if (!($345)) {
          $346 = ($343>>>0)<($344>>>0);
          if ($346) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L156;
          }
         }
         $347 = (($__i$3) + 20|0);
         $348 = HEAP32[$347>>2]|0;
         $349 = HEAP32[$330>>2]|0;
         $350 = ($348|0)==($349|0);
         if (!($350)) {
          $351 = ($348|0)>($349|0);
          if ($351) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L156;
          }
         }
         $352 = HEAP32[$__i$3>>2]|0;
         $353 = HEAP32[$__m$0$ph>>2]|0;
         $354 = ($352|0)==($353|0);
         if (!($354)) {
          $355 = (($352) + 4|0);
          $356 = HEAP32[$355>>2]|0;
          $357 = (($353) + 4|0);
          $358 = HEAP32[$357>>2]|0;
          $359 = ($356|0)<($358|0);
          if ($359) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L156;
          }
         }
         $360 = (($__i$3) + 24|0);
         $361 = Math_fround(HEAPF32[$360>>2]);
         $362 = Math_fround(HEAPF32[$331>>2]);
         $363 = $361 == $362;
         if ($363) {
          $364 = (($__i$3) + 16|0);
          $365 = HEAP16[$364>>1]|0;
          $366 = HEAP16[$332>>1]|0;
          $367 = ($365<<16>>16)==($366<<16>>16);
          if (!($367)) {
           $368 = ($365&65535)>($366&65535);
           if ($368) {
            break;
           } else {
            $__j$5 = $__j$4$ph;
            break L156;
           }
          }
         }
         $369 = $361 > $362;
         if (!($369)) {
          $__j$5 = $__j$4$ph;
          break L156;
         }
        } else {
         $336 = ($334>>>0)<($327>>>0);
         if (!($336)) {
          $__j$5 = $__j$4$ph;
          break L156;
         }
        }
       } while(0);
       $370 = (($__i$3) + 44|0);
       $__i$3 = $370;
      }
      while(1) {
       $371 = (($__j$5) + -44|0);
       $372 = (($__j$5) + -4|0);
       $373 = HEAP32[$372>>2]|0;
       $374 = ($373|0)==($327|0);
       if (!($374)) {
        $375 = ($373>>>0)<($327>>>0);
        if ($375) {
         break;
        } else {
         $__j$5 = $371;
         continue;
        }
       }
       $376 = (($__j$5) + -40|0);
       $377 = HEAP16[$376>>1]|0;
       $378 = HEAP16[$328>>1]|0;
       $379 = ($377<<16>>16)==($378<<16>>16);
       if (!($379)) {
        $380 = ($377<<16>>16)<($378<<16>>16);
        if ($380) {
         break;
        } else {
         $__j$5 = $371;
         continue;
        }
       }
       $381 = (($__j$5) + -32|0);
       $382 = HEAP32[$381>>2]|0;
       $383 = HEAP32[$329>>2]|0;
       $384 = ($382|0)==($383|0);
       if (!($384)) {
        $385 = ($382>>>0)<($383>>>0);
        if ($385) {
         break;
        } else {
         $__j$5 = $371;
         continue;
        }
       }
       $386 = (($__j$5) + -24|0);
       $387 = HEAP32[$386>>2]|0;
       $388 = HEAP32[$330>>2]|0;
       $389 = ($387|0)==($388|0);
       if (!($389)) {
        $390 = ($387|0)>($388|0);
        if ($390) {
         break;
        } else {
         $__j$5 = $371;
         continue;
        }
       }
       $391 = HEAP32[$371>>2]|0;
       $392 = HEAP32[$__m$0$ph>>2]|0;
       $393 = ($391|0)==($392|0);
       if (!($393)) {
        $394 = (($391) + 4|0);
        $395 = HEAP32[$394>>2]|0;
        $396 = (($392) + 4|0);
        $397 = HEAP32[$396>>2]|0;
        $398 = ($395|0)<($397|0);
        if ($398) {
         break;
        } else {
         $__j$5 = $371;
         continue;
        }
       }
       $399 = (($__j$5) + -20|0);
       $400 = Math_fround(HEAPF32[$399>>2]);
       $401 = Math_fround(HEAPF32[$331>>2]);
       $402 = $400 == $401;
       if ($402) {
        $403 = (($__j$5) + -28|0);
        $404 = HEAP16[$403>>1]|0;
        $405 = HEAP16[$332>>1]|0;
        $406 = ($404<<16>>16)==($405<<16>>16);
        if (!($406)) {
         $407 = ($404&65535)>($405&65535);
         if ($407) {
          break;
         } else {
          $__j$5 = $371;
          continue;
         }
        }
       }
       $408 = $400 > $401;
       if ($408) {
        break;
       } else {
        $__j$5 = $371;
       }
      }
      $409 = ($__i$3>>>0)>($371>>>0);
      if ($409) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L153;
      }
      dest=$__t$i33+0|0; src=$__i$3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$__i$3+0|0; src=$371+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$371+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $410 = (($__n_swaps$4$ph) + 1)|0;
      $411 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $411 ? $371 : $__m$0$ph;
      $412 = (($__i$3) + 44|0);
      $__i$3$ph = $412;$__j$4$ph = $371;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $410;
     }
    } else {
     $__i$4 = $324;$__m$2 = $59;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $413 = ($__i$4|0)==($__m$2|0);
   L202: do {
    if ($413) {
     $__n_swaps$6 = $__n_swaps$5;
    } else {
     $414 = (($__m$2) + 40|0);
     $415 = HEAP32[$414>>2]|0;
     $416 = (($__i$4) + 40|0);
     $417 = HEAP32[$416>>2]|0;
     $418 = ($415|0)==($417|0);
     do {
      if ($418) {
       $420 = (($__m$2) + 4|0);
       $421 = HEAP16[$420>>1]|0;
       $422 = (($__i$4) + 4|0);
       $423 = HEAP16[$422>>1]|0;
       $424 = ($421<<16>>16)==($423<<16>>16);
       if (!($424)) {
        $425 = ($421<<16>>16)<($423<<16>>16);
        if ($425) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L202;
        }
       }
       $426 = (($__m$2) + 12|0);
       $427 = HEAP32[$426>>2]|0;
       $428 = (($__i$4) + 12|0);
       $429 = HEAP32[$428>>2]|0;
       $430 = ($427|0)==($429|0);
       if (!($430)) {
        $431 = ($427>>>0)<($429>>>0);
        if ($431) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L202;
        }
       }
       $432 = (($__m$2) + 20|0);
       $433 = HEAP32[$432>>2]|0;
       $434 = (($__i$4) + 20|0);
       $435 = HEAP32[$434>>2]|0;
       $436 = ($433|0)==($435|0);
       if (!($436)) {
        $437 = ($433|0)>($435|0);
        if ($437) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L202;
        }
       }
       $438 = HEAP32[$__m$2>>2]|0;
       $439 = HEAP32[$__i$4>>2]|0;
       $440 = ($438|0)==($439|0);
       if (!($440)) {
        $441 = (($438) + 4|0);
        $442 = HEAP32[$441>>2]|0;
        $443 = (($439) + 4|0);
        $444 = HEAP32[$443>>2]|0;
        $445 = ($442|0)<($444|0);
        if ($445) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L202;
        }
       }
       $446 = (($__m$2) + 24|0);
       $447 = Math_fround(HEAPF32[$446>>2]);
       $448 = (($__i$4) + 24|0);
       $449 = Math_fround(HEAPF32[$448>>2]);
       $450 = $447 == $449;
       if ($450) {
        $451 = (($__m$2) + 16|0);
        $452 = HEAP16[$451>>1]|0;
        $453 = (($__i$4) + 16|0);
        $454 = HEAP16[$453>>1]|0;
        $455 = ($452<<16>>16)==($454<<16>>16);
        if (!($455)) {
         $456 = ($452&65535)>($454&65535);
         if ($456) {
          break;
         } else {
          $__n_swaps$6 = $__n_swaps$5;
          break L202;
         }
        }
       }
       $457 = $447 > $449;
       if (!($457)) {
        $__n_swaps$6 = $__n_swaps$5;
        break L202;
       }
      } else {
       $419 = ($415>>>0)<($417>>>0);
       if (!($419)) {
        $__n_swaps$6 = $__n_swaps$5;
        break L202;
       }
      }
     } while(0);
     dest=$__t$i33+0|0; src=$__i$4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     dest=$__i$4+0|0; src=$__m$2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     dest=$__m$2+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $458 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $458;
    }
   } while(0);
   $459 = ($__n_swaps$6|0)==(0);
   if ($459) {
    $460 = (__ZNSt3__127__insertion_sort_incompleteIR25RenderPrePassObjectSorterP16RenderObjectDataEEbT0_S5_T_($$0,$__i$4,0)|0);
    $461 = (($__i$4) + 44|0);
    $462 = (__ZNSt3__127__insertion_sort_incompleteIR25RenderPrePassObjectSorterP16RenderObjectDataEEbT0_S5_T_($461,$$01$ph,0)|0);
    if ($462) {
     label = 176;
     break;
    }
    if ($460) {
     $$0 = $461;
     continue;
    }
   }
   $463 = $__i$4;
   $464 = (($463) - ($9))|0;
   $465 = (($0) - ($463))|0;
   $466 = ($464|0)<($465|0);
   if (!($466)) {
    label = 180;
    break;
   }
   __ZNSt3__16__sortIR25RenderPrePassObjectSorterP16RenderObjectDataEEvT0_S5_T_($$0,$__i$4,$__comp);
   $467 = (($__i$4) + 44|0);
   $$0 = $467;
  }
  if ((label|0) == 176) {
   label = 0;
   if ($460) {
    label = 181;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 180) {
   label = 0;
   $468 = (($__i$4) + 44|0);
   __ZNSt3__16__sortIR25RenderPrePassObjectSorterP16RenderObjectDataEEvT0_S5_T_($468,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $12 = HEAP32[$3>>2]|0;
  $13 = (($$0) + 40|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  do {
   if ($15) {
    $17 = HEAP16[$4>>1]|0;
    $18 = (($$0) + 4|0);
    $19 = HEAP16[$18>>1]|0;
    $20 = ($17<<16>>16)==($19<<16>>16);
    if (!($20)) {
     $21 = ($17<<16>>16)<($19<<16>>16);
     if ($21) {
      break;
     }
     STACKTOP = sp;return;
    }
    $22 = HEAP32[$5>>2]|0;
    $23 = (($$0) + 12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($22|0)==($24|0);
    if (!($25)) {
     $26 = ($22>>>0)<($24>>>0);
     if ($26) {
      break;
     }
     STACKTOP = sp;return;
    }
    $27 = HEAP32[$6>>2]|0;
    $28 = (($$0) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27|0)==($29|0);
    if (!($30)) {
     $31 = ($27|0)>($29|0);
     if ($31) {
      break;
     }
     STACKTOP = sp;return;
    }
    $32 = HEAP32[$1>>2]|0;
    $33 = HEAP32[$$0>>2]|0;
    $34 = ($32|0)==($33|0);
    if (!($34)) {
     $35 = (($32) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($33) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($36|0)<($38|0);
     if ($39) {
      break;
     }
     STACKTOP = sp;return;
    }
    $40 = Math_fround(HEAPF32[$7>>2]);
    $41 = (($$0) + 24|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = $40 == $42;
    if ($43) {
     $44 = HEAP16[$8>>1]|0;
     $45 = (($$0) + 16|0);
     $46 = HEAP16[$45>>1]|0;
     $47 = ($44<<16>>16)==($46<<16>>16);
     if (!($47)) {
      $48 = ($44&65535)>($46&65535);
      if ($48) {
       break;
      }
      STACKTOP = sp;return;
     }
    }
    $49 = $40 > $42;
    if (!($49)) {
     STACKTOP = sp;return;
    }
   } else {
    $16 = ($12>>>0)<($14>>>0);
    if (!($16)) {
     STACKTOP = sp;return;
    }
   }
  } while(0);
  dest=$__t$i33+0|0; src=$$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$$0+0|0; src=$1+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$1+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 else if ((label|0) == 19) {
  $50 = (($$0) + 44|0);
  (__ZNSt3__17__sort3IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($$0,$50,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 20) {
  $51 = (($$0) + 44|0);
  $52 = (($$0) + 88|0);
  (__ZNSt3__17__sort4IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_T_($$0,$51,$52,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $53 = (($$0) + 44|0);
  $54 = (($$0) + 88|0);
  $55 = (($$0) + 132|0);
  (__ZNSt3__17__sort5IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_S5_T_($$0,$53,$54,$55,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 23) {
  __ZNSt3__118__insertion_sort_3IR25RenderPrePassObjectSorterP16RenderObjectDataEEvT0_S5_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 181) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $$0$i = 0, $$0$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__t$i10 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i10 = sp;
 $0 = (($__y) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__x) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 do {
  if ($4) {
   $6 = (($__y) + 4|0);
   $7 = HEAP16[$6>>1]|0;
   $8 = (($__x) + 4|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = ($7<<16>>16)==($9<<16>>16);
   if (!($10)) {
    $11 = ($7<<16>>16)<($9<<16>>16);
    $$0$i = $11;
    break;
   }
   $12 = (($__y) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($__x) + 12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($13|0)==($15|0);
   if (!($16)) {
    $17 = ($13>>>0)<($15>>>0);
    $$0$i = $17;
    break;
   }
   $18 = (($__y) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__x) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if (!($22)) {
    $23 = ($19|0)>($21|0);
    $$0$i = $23;
    break;
   }
   $24 = HEAP32[$__y>>2]|0;
   $25 = HEAP32[$__x>>2]|0;
   $26 = ($24|0)==($25|0);
   if (!($26)) {
    $27 = (($24) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($25) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($28|0)<($30|0);
    $$0$i = $31;
    break;
   }
   $32 = (($__y) + 24|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = (($__x) + 24|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = $33 == $35;
   if ($36) {
    $37 = (($__y) + 16|0);
    $38 = HEAP16[$37>>1]|0;
    $39 = (($__x) + 16|0);
    $40 = HEAP16[$39>>1]|0;
    $41 = ($38<<16>>16)==($40<<16>>16);
    if (!($41)) {
     $42 = ($38&65535)>($40&65535);
     $$0$i = $42;
     break;
    }
   }
   $43 = $33 > $35;
   $$0$i = $43;
  } else {
   $5 = ($1>>>0)<($3>>>0);
   $$0$i = $5;
  }
 } while(0);
 $44 = (($__z) + 40|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==($1|0);
 do {
  if ($46) {
   $48 = (($__z) + 4|0);
   $49 = HEAP16[$48>>1]|0;
   $50 = (($__y) + 4|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = ($49<<16>>16)==($51<<16>>16);
   if (!($52)) {
    $53 = ($49<<16>>16)<($51<<16>>16);
    $$0$i12 = $53;
    break;
   }
   $54 = (($__z) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($__y) + 12|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($55|0)==($57|0);
   if (!($58)) {
    $59 = ($55>>>0)<($57>>>0);
    $$0$i12 = $59;
    break;
   }
   $60 = (($__z) + 20|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($__y) + 20|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($61|0)==($63|0);
   if (!($64)) {
    $65 = ($61|0)>($63|0);
    $$0$i12 = $65;
    break;
   }
   $66 = HEAP32[$__z>>2]|0;
   $67 = HEAP32[$__y>>2]|0;
   $68 = ($66|0)==($67|0);
   if (!($68)) {
    $69 = (($66) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($67) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($70|0)<($72|0);
    $$0$i12 = $73;
    break;
   }
   $74 = (($__z) + 24|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = (($__y) + 24|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = $75 == $77;
   if ($78) {
    $79 = (($__z) + 16|0);
    $80 = HEAP16[$79>>1]|0;
    $81 = (($__y) + 16|0);
    $82 = HEAP16[$81>>1]|0;
    $83 = ($80<<16>>16)==($82<<16>>16);
    if (!($83)) {
     $84 = ($80&65535)>($82&65535);
     $$0$i12 = $84;
     break;
    }
   }
   $85 = $75 > $77;
   $$0$i12 = $85;
  } else {
   $47 = ($45>>>0)<($1>>>0);
   $$0$i12 = $47;
  }
 } while(0);
 if (!($$0$i)) {
  if (!($$0$i12)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  dest=$__t$i10+0|0; src=$__y+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__y+0|0; src=$__z+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__z+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $86 = HEAP32[$0>>2]|0;
  $87 = HEAP32[$2>>2]|0;
  $88 = ($86|0)==($87|0);
  do {
   if ($88) {
    $90 = (($__y) + 4|0);
    $91 = HEAP16[$90>>1]|0;
    $92 = (($__x) + 4|0);
    $93 = HEAP16[$92>>1]|0;
    $94 = ($91<<16>>16)==($93<<16>>16);
    if (!($94)) {
     $95 = ($91<<16>>16)<($93<<16>>16);
     if ($95) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $96 = (($__y) + 12|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($__x) + 12|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = ($97|0)==($99|0);
    if (!($100)) {
     $101 = ($97>>>0)<($99>>>0);
     if ($101) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $102 = (($__y) + 20|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($__x) + 20|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($103|0)==($105|0);
    if (!($106)) {
     $107 = ($103|0)>($105|0);
     if ($107) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $108 = HEAP32[$__y>>2]|0;
    $109 = HEAP32[$__x>>2]|0;
    $110 = ($108|0)==($109|0);
    if (!($110)) {
     $111 = (($108) + 4|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = (($109) + 4|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($112|0)<($114|0);
     if ($115) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $116 = (($__y) + 24|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = (($__x) + 24|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = $117 == $119;
    if ($120) {
     $121 = (($__y) + 16|0);
     $122 = HEAP16[$121>>1]|0;
     $123 = (($__x) + 16|0);
     $124 = HEAP16[$123>>1]|0;
     $125 = ($122<<16>>16)==($124<<16>>16);
     if (!($125)) {
      $126 = ($122&65535)>($124&65535);
      if ($126) {
       break;
      } else {
       $$0 = 1;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $127 = $117 > $119;
    if (!($127)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $89 = ($86>>>0)<($87>>>0);
    if (!($89)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  dest=$__t$i10+0|0; src=$__x+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__x+0|0; src=$__y+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__y+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($$0$i12) {
  dest=$__t$i10+0|0; src=$__x+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__x+0|0; src=$__z+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__z+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 dest=$__t$i10+0|0; src=$__x+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x+0|0; src=$__y+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__y+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $128 = HEAP32[$44>>2]|0;
 $129 = HEAP32[$0>>2]|0;
 $130 = ($128|0)==($129|0);
 do {
  if ($130) {
   $132 = (($__z) + 4|0);
   $133 = HEAP16[$132>>1]|0;
   $134 = (($__y) + 4|0);
   $135 = HEAP16[$134>>1]|0;
   $136 = ($133<<16>>16)==($135<<16>>16);
   if (!($136)) {
    $137 = ($133<<16>>16)<($135<<16>>16);
    if ($137) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $138 = (($__z) + 12|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = (($__y) + 12|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = ($139|0)==($141|0);
   if (!($142)) {
    $143 = ($139>>>0)<($141>>>0);
    if ($143) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $144 = (($__z) + 20|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = (($__y) + 20|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ($145|0)==($147|0);
   if (!($148)) {
    $149 = ($145|0)>($147|0);
    if ($149) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $150 = HEAP32[$__z>>2]|0;
   $151 = HEAP32[$__y>>2]|0;
   $152 = ($150|0)==($151|0);
   if (!($152)) {
    $153 = (($150) + 4|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = (($151) + 4|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = ($154|0)<($156|0);
    if ($157) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $158 = (($__z) + 24|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = (($__y) + 24|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = $159 == $161;
   if ($162) {
    $163 = (($__z) + 16|0);
    $164 = HEAP16[$163>>1]|0;
    $165 = (($__y) + 16|0);
    $166 = HEAP16[$165>>1]|0;
    $167 = ($164<<16>>16)==($166<<16>>16);
    if (!($167)) {
     $168 = ($164&65535)>($166&65535);
     if ($168) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
   }
   $169 = $159 > $161;
   if (!($169)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $131 = ($128>>>0)<($129>>>0);
   if (!($131)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 dest=$__t$i10+0|0; src=$__y+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__y+0|0; src=$__z+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__z+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__t$i8 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i8 = sp;
 $0 = (__ZNSt3__17__sort3IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__x1,$__x2,$__x3,0)|0);
 $1 = (($__x4) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__x3) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   $7 = (($__x4) + 4|0);
   $8 = HEAP16[$7>>1]|0;
   $9 = (($__x3) + 4|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = ($8<<16>>16)==($10<<16>>16);
   if (!($11)) {
    $12 = ($8<<16>>16)<($10<<16>>16);
    if ($12) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $13 = (($__x4) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($__x3) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14|0)==($16|0);
   if (!($17)) {
    $18 = ($14>>>0)<($16>>>0);
    if ($18) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $19 = (($__x4) + 20|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($__x3) + 20|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($20|0)==($22|0);
   if (!($23)) {
    $24 = ($20|0)>($22|0);
    if ($24) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $25 = HEAP32[$__x4>>2]|0;
   $26 = HEAP32[$__x3>>2]|0;
   $27 = ($25|0)==($26|0);
   if (!($27)) {
    $28 = (($25) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($26) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($29|0)<($31|0);
    if ($32) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $33 = (($__x4) + 24|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = (($__x3) + 24|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = $34 == $36;
   if ($37) {
    $38 = (($__x4) + 16|0);
    $39 = HEAP16[$38>>1]|0;
    $40 = (($__x3) + 16|0);
    $41 = HEAP16[$40>>1]|0;
    $42 = ($39<<16>>16)==($41<<16>>16);
    if (!($42)) {
     $43 = ($39&65535)>($41&65535);
     if ($43) {
      break;
     } else {
      $__r$0 = $0;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $44 = $34 > $36;
   if (!($44)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $6 = ($2>>>0)<($4>>>0);
   if (!($6)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i8+0|0; src=$__x3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x3+0|0; src=$__x4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x4+0|0; src=$__t$i8+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $45 = (($0) + 1)|0;
 $46 = HEAP32[$3>>2]|0;
 $47 = (($__x2) + 40|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($46|0)==($48|0);
 do {
  if ($49) {
   $51 = (($__x3) + 4|0);
   $52 = HEAP16[$51>>1]|0;
   $53 = (($__x2) + 4|0);
   $54 = HEAP16[$53>>1]|0;
   $55 = ($52<<16>>16)==($54<<16>>16);
   if (!($55)) {
    $56 = ($52<<16>>16)<($54<<16>>16);
    if ($56) {
     break;
    } else {
     $__r$0 = $45;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $57 = (($__x3) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($__x2) + 12|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($58|0)==($60|0);
   if (!($61)) {
    $62 = ($58>>>0)<($60>>>0);
    if ($62) {
     break;
    } else {
     $__r$0 = $45;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $63 = (($__x3) + 20|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($__x2) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($64|0)==($66|0);
   if (!($67)) {
    $68 = ($64|0)>($66|0);
    if ($68) {
     break;
    } else {
     $__r$0 = $45;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $69 = HEAP32[$__x3>>2]|0;
   $70 = HEAP32[$__x2>>2]|0;
   $71 = ($69|0)==($70|0);
   if (!($71)) {
    $72 = (($69) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($70) + 4|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($73|0)<($75|0);
    if ($76) {
     break;
    } else {
     $__r$0 = $45;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $77 = (($__x3) + 24|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = (($__x2) + 24|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = $78 == $80;
   if ($81) {
    $82 = (($__x3) + 16|0);
    $83 = HEAP16[$82>>1]|0;
    $84 = (($__x2) + 16|0);
    $85 = HEAP16[$84>>1]|0;
    $86 = ($83<<16>>16)==($85<<16>>16);
    if (!($86)) {
     $87 = ($83&65535)>($85&65535);
     if ($87) {
      break;
     } else {
      $__r$0 = $45;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $88 = $78 > $80;
   if (!($88)) {
    $__r$0 = $45;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $50 = ($46>>>0)<($48>>>0);
   if (!($50)) {
    $__r$0 = $45;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i8+0|0; src=$__x2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x2+0|0; src=$__x3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x3+0|0; src=$__t$i8+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $89 = (($0) + 2)|0;
 $90 = HEAP32[$47>>2]|0;
 $91 = (($__x1) + 40|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($90|0)==($92|0);
 do {
  if ($93) {
   $95 = (($__x2) + 4|0);
   $96 = HEAP16[$95>>1]|0;
   $97 = (($__x1) + 4|0);
   $98 = HEAP16[$97>>1]|0;
   $99 = ($96<<16>>16)==($98<<16>>16);
   if (!($99)) {
    $100 = ($96<<16>>16)<($98<<16>>16);
    if ($100) {
     break;
    } else {
     $__r$0 = $89;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $101 = (($__x2) + 12|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($__x1) + 12|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($102|0)==($104|0);
   if (!($105)) {
    $106 = ($102>>>0)<($104>>>0);
    if ($106) {
     break;
    } else {
     $__r$0 = $89;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $107 = (($__x2) + 20|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($__x1) + 20|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ($108|0)==($110|0);
   if (!($111)) {
    $112 = ($108|0)>($110|0);
    if ($112) {
     break;
    } else {
     $__r$0 = $89;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $113 = HEAP32[$__x2>>2]|0;
   $114 = HEAP32[$__x1>>2]|0;
   $115 = ($113|0)==($114|0);
   if (!($115)) {
    $116 = (($113) + 4|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = (($114) + 4|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($117|0)<($119|0);
    if ($120) {
     break;
    } else {
     $__r$0 = $89;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $121 = (($__x2) + 24|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = (($__x1) + 24|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = $122 == $124;
   if ($125) {
    $126 = (($__x2) + 16|0);
    $127 = HEAP16[$126>>1]|0;
    $128 = (($__x1) + 16|0);
    $129 = HEAP16[$128>>1]|0;
    $130 = ($127<<16>>16)==($129<<16>>16);
    if (!($130)) {
     $131 = ($127&65535)>($129&65535);
     if ($131) {
      break;
     } else {
      $__r$0 = $89;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $132 = $122 > $124;
   if (!($132)) {
    $__r$0 = $89;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $94 = ($90>>>0)<($92>>>0);
   if (!($94)) {
    $__r$0 = $89;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i8+0|0; src=$__x1+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x1+0|0; src=$__x2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x2+0|0; src=$__t$i8+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $133 = (($0) + 3)|0;
 $__r$0 = $133;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__t$i12 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i12 = sp;
 $0 = (__ZNSt3__17__sort4IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = (($__x5) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__x4) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   $7 = (($__x5) + 4|0);
   $8 = HEAP16[$7>>1]|0;
   $9 = (($__x4) + 4|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = ($8<<16>>16)==($10<<16>>16);
   if (!($11)) {
    $12 = ($8<<16>>16)<($10<<16>>16);
    if ($12) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $13 = (($__x5) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($__x4) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14|0)==($16|0);
   if (!($17)) {
    $18 = ($14>>>0)<($16>>>0);
    if ($18) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $19 = (($__x5) + 20|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($__x4) + 20|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($20|0)==($22|0);
   if (!($23)) {
    $24 = ($20|0)>($22|0);
    if ($24) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $25 = HEAP32[$__x5>>2]|0;
   $26 = HEAP32[$__x4>>2]|0;
   $27 = ($25|0)==($26|0);
   if (!($27)) {
    $28 = (($25) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($26) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($29|0)<($31|0);
    if ($32) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $33 = (($__x5) + 24|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = (($__x4) + 24|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = $34 == $36;
   if ($37) {
    $38 = (($__x5) + 16|0);
    $39 = HEAP16[$38>>1]|0;
    $40 = (($__x4) + 16|0);
    $41 = HEAP16[$40>>1]|0;
    $42 = ($39<<16>>16)==($41<<16>>16);
    if (!($42)) {
     $43 = ($39&65535)>($41&65535);
     if ($43) {
      break;
     } else {
      $__r$0 = $0;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $44 = $34 > $36;
   if (!($44)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $6 = ($2>>>0)<($4>>>0);
   if (!($6)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i12+0|0; src=$__x4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x4+0|0; src=$__x5+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x5+0|0; src=$__t$i12+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $45 = (($0) + 1)|0;
 $46 = HEAP32[$3>>2]|0;
 $47 = (($__x3) + 40|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($46|0)==($48|0);
 do {
  if ($49) {
   $51 = (($__x4) + 4|0);
   $52 = HEAP16[$51>>1]|0;
   $53 = (($__x3) + 4|0);
   $54 = HEAP16[$53>>1]|0;
   $55 = ($52<<16>>16)==($54<<16>>16);
   if (!($55)) {
    $56 = ($52<<16>>16)<($54<<16>>16);
    if ($56) {
     break;
    } else {
     $__r$0 = $45;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $57 = (($__x4) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($__x3) + 12|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($58|0)==($60|0);
   if (!($61)) {
    $62 = ($58>>>0)<($60>>>0);
    if ($62) {
     break;
    } else {
     $__r$0 = $45;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $63 = (($__x4) + 20|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($__x3) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($64|0)==($66|0);
   if (!($67)) {
    $68 = ($64|0)>($66|0);
    if ($68) {
     break;
    } else {
     $__r$0 = $45;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $69 = HEAP32[$__x4>>2]|0;
   $70 = HEAP32[$__x3>>2]|0;
   $71 = ($69|0)==($70|0);
   if (!($71)) {
    $72 = (($69) + 4|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($70) + 4|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($73|0)<($75|0);
    if ($76) {
     break;
    } else {
     $__r$0 = $45;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $77 = (($__x4) + 24|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = (($__x3) + 24|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = $78 == $80;
   if ($81) {
    $82 = (($__x4) + 16|0);
    $83 = HEAP16[$82>>1]|0;
    $84 = (($__x3) + 16|0);
    $85 = HEAP16[$84>>1]|0;
    $86 = ($83<<16>>16)==($85<<16>>16);
    if (!($86)) {
     $87 = ($83&65535)>($85&65535);
     if ($87) {
      break;
     } else {
      $__r$0 = $45;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $88 = $78 > $80;
   if (!($88)) {
    $__r$0 = $45;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $50 = ($46>>>0)<($48>>>0);
   if (!($50)) {
    $__r$0 = $45;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i12+0|0; src=$__x3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x3+0|0; src=$__x4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x4+0|0; src=$__t$i12+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $89 = (($0) + 2)|0;
 $90 = HEAP32[$47>>2]|0;
 $91 = (($__x2) + 40|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($90|0)==($92|0);
 do {
  if ($93) {
   $95 = (($__x3) + 4|0);
   $96 = HEAP16[$95>>1]|0;
   $97 = (($__x2) + 4|0);
   $98 = HEAP16[$97>>1]|0;
   $99 = ($96<<16>>16)==($98<<16>>16);
   if (!($99)) {
    $100 = ($96<<16>>16)<($98<<16>>16);
    if ($100) {
     break;
    } else {
     $__r$0 = $89;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $101 = (($__x3) + 12|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($__x2) + 12|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($102|0)==($104|0);
   if (!($105)) {
    $106 = ($102>>>0)<($104>>>0);
    if ($106) {
     break;
    } else {
     $__r$0 = $89;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $107 = (($__x3) + 20|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($__x2) + 20|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ($108|0)==($110|0);
   if (!($111)) {
    $112 = ($108|0)>($110|0);
    if ($112) {
     break;
    } else {
     $__r$0 = $89;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $113 = HEAP32[$__x3>>2]|0;
   $114 = HEAP32[$__x2>>2]|0;
   $115 = ($113|0)==($114|0);
   if (!($115)) {
    $116 = (($113) + 4|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = (($114) + 4|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($117|0)<($119|0);
    if ($120) {
     break;
    } else {
     $__r$0 = $89;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $121 = (($__x3) + 24|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = (($__x2) + 24|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = $122 == $124;
   if ($125) {
    $126 = (($__x3) + 16|0);
    $127 = HEAP16[$126>>1]|0;
    $128 = (($__x2) + 16|0);
    $129 = HEAP16[$128>>1]|0;
    $130 = ($127<<16>>16)==($129<<16>>16);
    if (!($130)) {
     $131 = ($127&65535)>($129&65535);
     if ($131) {
      break;
     } else {
      $__r$0 = $89;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $132 = $122 > $124;
   if (!($132)) {
    $__r$0 = $89;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $94 = ($90>>>0)<($92>>>0);
   if (!($94)) {
    $__r$0 = $89;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i12+0|0; src=$__x2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x2+0|0; src=$__x3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x3+0|0; src=$__t$i12+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $133 = (($0) + 3)|0;
 $134 = HEAP32[$91>>2]|0;
 $135 = (($__x1) + 40|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = ($134|0)==($136|0);
 do {
  if ($137) {
   $139 = (($__x2) + 4|0);
   $140 = HEAP16[$139>>1]|0;
   $141 = (($__x1) + 4|0);
   $142 = HEAP16[$141>>1]|0;
   $143 = ($140<<16>>16)==($142<<16>>16);
   if (!($143)) {
    $144 = ($140<<16>>16)<($142<<16>>16);
    if ($144) {
     break;
    } else {
     $__r$0 = $133;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $145 = (($__x2) + 12|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = (($__x1) + 12|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = ($146|0)==($148|0);
   if (!($149)) {
    $150 = ($146>>>0)<($148>>>0);
    if ($150) {
     break;
    } else {
     $__r$0 = $133;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $151 = (($__x2) + 20|0);
   $152 = HEAP32[$151>>2]|0;
   $153 = (($__x1) + 20|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ($152|0)==($154|0);
   if (!($155)) {
    $156 = ($152|0)>($154|0);
    if ($156) {
     break;
    } else {
     $__r$0 = $133;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $157 = HEAP32[$__x2>>2]|0;
   $158 = HEAP32[$__x1>>2]|0;
   $159 = ($157|0)==($158|0);
   if (!($159)) {
    $160 = (($157) + 4|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = (($158) + 4|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = ($161|0)<($163|0);
    if ($164) {
     break;
    } else {
     $__r$0 = $133;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $165 = (($__x2) + 24|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   $167 = (($__x1) + 24|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = $166 == $168;
   if ($169) {
    $170 = (($__x2) + 16|0);
    $171 = HEAP16[$170>>1]|0;
    $172 = (($__x1) + 16|0);
    $173 = HEAP16[$172>>1]|0;
    $174 = ($171<<16>>16)==($173<<16>>16);
    if (!($174)) {
     $175 = ($171&65535)>($173&65535);
     if ($175) {
      break;
     } else {
      $__r$0 = $133;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $176 = $166 > $168;
   if (!($176)) {
    $__r$0 = $133;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $138 = ($134>>>0)<($136>>>0);
   if (!($138)) {
    $__r$0 = $133;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i12+0|0; src=$__x1+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x1+0|0; src=$__x2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x2+0|0; src=$__t$i12+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $177 = (($0) + 4)|0;
 $__r$0 = $177;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IR25RenderPrePassObjectSorterP16RenderObjectDataEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$lcssa = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$07 = 0, $__j$06 = 0, $__j$06$phi = 0, $__k$0$lcssa = 0, $__t$sroa$2 = 0, $__t$sroa$5 = 0;
 var $__t$sroa$8 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$sroa$2 = sp + 16|0;
 $__t$sroa$5 = sp + 22|0;
 $__t$sroa$8 = sp;
 $0 = (($__first) + 88|0);
 $1 = (($__first) + 44|0);
 (__ZNSt3__17__sort3IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 132|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $__i$07 = $2;$__j$06 = $0;
 while(1) {
  $4 = (($__i$07) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($__j$06) + 40|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $10 = (($__i$07) + 4|0);
    $11 = HEAP16[$10>>1]|0;
    $12 = (($__j$06) + 4|0);
    $13 = HEAP16[$12>>1]|0;
    $14 = ($11<<16>>16)==($13<<16>>16);
    if (!($14)) {
     $15 = ($11<<16>>16)<($13<<16>>16);
     if ($15) {
      $74 = $11;
      label = 18;
      break;
     } else {
      break;
     }
    }
    $16 = (($__i$07) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($__j$06) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($17|0)==($19|0);
    if (!($20)) {
     $21 = ($17>>>0)<($19>>>0);
     if ($21) {
      $74 = $11;
      label = 18;
      break;
     } else {
      break;
     }
    }
    $22 = (($__i$07) + 20|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($__j$06) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($23|0)==($25|0);
    if (!($26)) {
     $27 = ($23|0)>($25|0);
     if ($27) {
      $74 = $11;
      label = 18;
      break;
     } else {
      break;
     }
    }
    $28 = HEAP32[$__i$07>>2]|0;
    $29 = HEAP32[$__j$06>>2]|0;
    $30 = ($28|0)==($29|0);
    if (!($30)) {
     $31 = (($28) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($29) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($32|0)<($34|0);
     if ($35) {
      $74 = $11;
      label = 18;
      break;
     } else {
      break;
     }
    }
    $36 = (($__i$07) + 24|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = (($__j$06) + 24|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = $37 == $39;
    if ($40) {
     $41 = (($__i$07) + 16|0);
     $42 = HEAP16[$41>>1]|0;
     $43 = (($__j$06) + 16|0);
     $44 = HEAP16[$43>>1]|0;
     $45 = ($42<<16>>16)==($44<<16>>16);
     if (!($45)) {
      $46 = ($42&65535)>($44&65535);
      if ($46) {
       $74 = $11;
       label = 18;
       break;
      } else {
       break;
      }
     }
    }
    $47 = $37 > $39;
    if ($47) {
     $74 = $11;
     label = 18;
    }
   } else {
    $9 = ($5>>>0)<($7>>>0);
    if ($9) {
     $$phi$trans$insert = (($__i$07) + 4|0);
     $$pre = HEAP16[$$phi$trans$insert>>1]|0;
     $74 = $$pre;
     label = 18;
    }
   }
  } while(0);
  if ((label|0) == 18) {
   label = 0;
   $48 = HEAP32[$__i$07>>2]|0;
   $49 = (($__i$07) + 6|0);
   ;HEAP16[$__t$sroa$2+0>>1]=HEAP16[$49+0>>1]|0;HEAP16[$__t$sroa$2+2>>1]=HEAP16[$49+2>>1]|0;HEAP16[$__t$sroa$2+4>>1]=HEAP16[$49+4>>1]|0;
   $50 = (($__i$07) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($__i$07) + 16|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = $53&65535;
   $55 = $53 >>> 16;
   $56 = $55&65535;
   HEAP16[$__t$sroa$5>>1] = $56;
   $57 = (($__i$07) + 20|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($__i$07) + 24|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = (($__i$07) + 28|0);
   ;HEAP32[$__t$sroa$8+0>>2]=HEAP32[$61+0>>2]|0;HEAP32[$__t$sroa$8+4>>2]=HEAP32[$61+4>>2]|0;HEAP32[$__t$sroa$8+8>>2]=HEAP32[$61+8>>2]|0;
   $62 = HEAP32[$4>>2]|0;
   $63 = (($48) + 4|0);
   dest=$__i$07+0|0; src=$__j$06+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $64 = ($__j$06|0)==($__first|0);
   L28: do {
    if ($64) {
     $$lcssa = $__j$06;$__k$0$lcssa = $__first;
    } else {
     $66 = $__j$06;
     while(1) {
      $65 = (($66) + -44|0);
      $67 = (($66) + -4|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ($62|0)==($68|0);
      do {
       if ($69) {
        $71 = (($66) + -40|0);
        $72 = HEAP16[$71>>1]|0;
        $73 = ($74<<16>>16)==($72<<16>>16);
        if (!($73)) {
         $75 = ($74<<16>>16)<($72<<16>>16);
         if ($75) {
          break;
         } else {
          $$lcssa = $66;$__k$0$lcssa = $66;
          break L28;
         }
        }
        $76 = (($66) + -32|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = ($51|0)==($77|0);
        if (!($78)) {
         $79 = ($51>>>0)<($77>>>0);
         if ($79) {
          break;
         } else {
          $$lcssa = $66;$__k$0$lcssa = $66;
          break L28;
         }
        }
        $80 = (($66) + -24|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = ($58|0)==($81|0);
        if (!($82)) {
         $83 = ($58|0)>($81|0);
         if ($83) {
          break;
         } else {
          $$lcssa = $66;$__k$0$lcssa = $66;
          break L28;
         }
        }
        $84 = HEAP32[$65>>2]|0;
        $85 = ($48|0)==($84|0);
        if (!($85)) {
         $86 = HEAP32[$63>>2]|0;
         $87 = (($84) + 4|0);
         $88 = HEAP32[$87>>2]|0;
         $89 = ($86|0)<($88|0);
         if ($89) {
          break;
         } else {
          $$lcssa = $66;$__k$0$lcssa = $66;
          break L28;
         }
        }
        $90 = (($66) + -20|0);
        $91 = Math_fround(HEAPF32[$90>>2]);
        $92 = $60 == $91;
        if ($92) {
         $93 = (($66) + -28|0);
         $94 = HEAP16[$93>>1]|0;
         $95 = ($54<<16>>16)==($94<<16>>16);
         if (!($95)) {
          $96 = ($54&65535)>($94&65535);
          if ($96) {
           break;
          } else {
           $$lcssa = $66;$__k$0$lcssa = $66;
           break L28;
          }
         }
        }
        $97 = $60 > $91;
        if (!($97)) {
         $$lcssa = $66;$__k$0$lcssa = $66;
         break L28;
        }
       } else {
        $70 = ($62>>>0)<($68>>>0);
        if (!($70)) {
         $$lcssa = $66;$__k$0$lcssa = $66;
         break L28;
        }
       }
      } while(0);
      dest=$66+0|0; src=$65+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $98 = ($65|0)==($__first|0);
      if ($98) {
       $$lcssa = $65;$__k$0$lcssa = $__first;
       break;
      } else {
       $66 = $65;
      }
     }
    }
   } while(0);
   HEAP32[$__k$0$lcssa>>2] = $48;
   $99 = (($__k$0$lcssa) + 4|0);
   HEAP16[$99>>1] = $74;
   $100 = (($__k$0$lcssa) + 6|0);
   ;HEAP16[$100+0>>1]=HEAP16[$__t$sroa$2+0>>1]|0;HEAP16[$100+2>>1]=HEAP16[$__t$sroa$2+2>>1]|0;HEAP16[$100+4>>1]=HEAP16[$__t$sroa$2+4>>1]|0;
   $101 = (($__k$0$lcssa) + 12|0);
   HEAP32[$101>>2] = $51;
   $102 = (($__k$0$lcssa) + 16|0);
   HEAP16[$102>>1] = $54;
   $103 = (($$lcssa) + 18|0);
   $104 = HEAP16[$__t$sroa$5>>1]|0;
   HEAP16[$103>>1] = $104;
   $105 = (($__k$0$lcssa) + 20|0);
   HEAP32[$105>>2] = $58;
   $106 = (($__k$0$lcssa) + 24|0);
   HEAPF32[$106>>2] = $60;
   $107 = (($__k$0$lcssa) + 28|0);
   ;HEAP32[$107+0>>2]=HEAP32[$__t$sroa$8+0>>2]|0;HEAP32[$107+4>>2]=HEAP32[$__t$sroa$8+4>>2]|0;HEAP32[$107+8>>2]=HEAP32[$__t$sroa$8+8>>2]|0;
   $108 = (($__k$0$lcssa) + 40|0);
   HEAP32[$108>>2] = $62;
  }
  $109 = (($__i$07) + 44|0);
  $110 = ($109|0)==($__last|0);
  if ($110) {
   break;
  } else {
   $__j$06$phi = $__i$07;$__i$07 = $109;$__j$06 = $__j$06$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIR25RenderPrePassObjectSorterP16RenderObjectDataEEbT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$3 = 0, $$lcssa = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $__count$015 = 0, $__count$1 = 0, $__i$017 = 0;
 var $__j$014 = 0, $__j$014$phi = 0, $__k$0$lcssa = 0, $__t$i = 0, $__t$sroa$5 = 0, $__t$sroa$8 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i = sp + 16|0;
 $__t$sroa$5 = sp + 60|0;
 $__t$sroa$8 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 44)&-1;
 switch ($3|0) {
 case 2:  {
  $4 = (($__last) + -44|0);
  $5 = (($__last) + -4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($__first) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $11 = (($__last) + -40|0);
    $12 = HEAP16[$11>>1]|0;
    $13 = (($__first) + 4|0);
    $14 = HEAP16[$13>>1]|0;
    $15 = ($12<<16>>16)==($14<<16>>16);
    if (!($15)) {
     $16 = ($12<<16>>16)<($14<<16>>16);
     if ($16) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    }
    $17 = (($__last) + -32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__first) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if (!($21)) {
     $22 = ($18>>>0)<($20>>>0);
     if ($22) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    }
    $23 = (($__last) + -24|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($__first) + 20|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($24|0)==($26|0);
    if (!($27)) {
     $28 = ($24|0)>($26|0);
     if ($28) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    }
    $29 = HEAP32[$4>>2]|0;
    $30 = HEAP32[$__first>>2]|0;
    $31 = ($29|0)==($30|0);
    if (!($31)) {
     $32 = (($29) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($30) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($33|0)<($35|0);
     if ($36) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    }
    $37 = (($__last) + -20|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = (($__first) + 24|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = $38 == $40;
    if ($41) {
     $42 = (($__last) + -28|0);
     $43 = HEAP16[$42>>1]|0;
     $44 = (($__first) + 16|0);
     $45 = HEAP16[$44>>1]|0;
     $46 = ($43<<16>>16)==($45<<16>>16);
     if (!($46)) {
      $47 = ($43&65535)>($45&65535);
      if ($47) {
       break;
      } else {
       $$3 = 1;
      }
      STACKTOP = sp;return ($$3|0);
     }
    }
    $48 = $38 > $40;
    if (!($48)) {
     $$3 = 1;
     STACKTOP = sp;return ($$3|0);
    }
   } else {
    $10 = ($6>>>0)<($8>>>0);
    if (!($10)) {
     $$3 = 1;
     STACKTOP = sp;return ($$3|0);
    }
   }
  } while(0);
  dest=$__t$i+0|0; src=$__first+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__first+0|0; src=$4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$4+0|0; src=$__t$i+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 3:  {
  $49 = (($__first) + 44|0);
  $50 = (($__last) + -44|0);
  (__ZNSt3__17__sort3IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__first,$49,$50,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 5:  {
  $54 = (($__first) + 44|0);
  $55 = (($__first) + 88|0);
  $56 = (($__first) + 132|0);
  $57 = (($__last) + -44|0);
  (__ZNSt3__17__sort5IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_S5_T_($__first,$54,$55,$56,$57,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 4:  {
  $51 = (($__first) + 44|0);
  $52 = (($__first) + 88|0);
  $53 = (($__last) + -44|0);
  (__ZNSt3__17__sort4IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_T_($__first,$51,$52,$53,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 1: case 0:  {
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 default: {
  $58 = (($__first) + 88|0);
  $59 = (($__first) + 44|0);
  (__ZNSt3__17__sort3IR25RenderPrePassObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__first,$59,$58,0)|0);
  $60 = (($__first) + 132|0);
  $61 = ($60|0)==($__last|0);
  if ($61) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  $__count$015 = 0;$__i$017 = $60;$__j$014 = $58;
  while(1) {
   $62 = (($__i$017) + 40|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($__j$014) + 40|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($63|0)==($65|0);
   do {
    if ($66) {
     $68 = (($__i$017) + 4|0);
     $69 = HEAP16[$68>>1]|0;
     $70 = (($__j$014) + 4|0);
     $71 = HEAP16[$70>>1]|0;
     $72 = ($69<<16>>16)==($71<<16>>16);
     if (!($72)) {
      $73 = ($69<<16>>16)<($71<<16>>16);
      if ($73) {
       $132 = $69;
       label = 37;
       break;
      } else {
       $__count$1 = $__count$015;
       break;
      }
     }
     $74 = (($__i$017) + 12|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($__j$014) + 12|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ($75|0)==($77|0);
     if (!($78)) {
      $79 = ($75>>>0)<($77>>>0);
      if ($79) {
       $132 = $69;
       label = 37;
       break;
      } else {
       $__count$1 = $__count$015;
       break;
      }
     }
     $80 = (($__i$017) + 20|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($__j$014) + 20|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($81|0)==($83|0);
     if (!($84)) {
      $85 = ($81|0)>($83|0);
      if ($85) {
       $132 = $69;
       label = 37;
       break;
      } else {
       $__count$1 = $__count$015;
       break;
      }
     }
     $86 = HEAP32[$__i$017>>2]|0;
     $87 = HEAP32[$__j$014>>2]|0;
     $88 = ($86|0)==($87|0);
     if (!($88)) {
      $89 = (($86) + 4|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = (($87) + 4|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = ($90|0)<($92|0);
      if ($93) {
       $132 = $69;
       label = 37;
       break;
      } else {
       $__count$1 = $__count$015;
       break;
      }
     }
     $94 = (($__i$017) + 24|0);
     $95 = Math_fround(HEAPF32[$94>>2]);
     $96 = (($__j$014) + 24|0);
     $97 = Math_fround(HEAPF32[$96>>2]);
     $98 = $95 == $97;
     if ($98) {
      $99 = (($__i$017) + 16|0);
      $100 = HEAP16[$99>>1]|0;
      $101 = (($__j$014) + 16|0);
      $102 = HEAP16[$101>>1]|0;
      $103 = ($100<<16>>16)==($102<<16>>16);
      if (!($103)) {
       $104 = ($100&65535)>($102&65535);
       if ($104) {
        $132 = $69;
        label = 37;
        break;
       } else {
        $__count$1 = $__count$015;
        break;
       }
      }
     }
     $105 = $95 > $97;
     if ($105) {
      $132 = $69;
      label = 37;
     } else {
      $__count$1 = $__count$015;
     }
    } else {
     $67 = ($63>>>0)<($65>>>0);
     if ($67) {
      $$phi$trans$insert = (($__i$017) + 4|0);
      $$pre = HEAP16[$$phi$trans$insert>>1]|0;
      $132 = $$pre;
      label = 37;
     } else {
      $__count$1 = $__count$015;
     }
    }
   } while(0);
   if ((label|0) == 37) {
    label = 0;
    $106 = HEAP32[$__i$017>>2]|0;
    $107 = (($__i$017) + 6|0);
    ;HEAP16[$__t$i+0>>1]=HEAP16[$107+0>>1]|0;HEAP16[$__t$i+2>>1]=HEAP16[$107+2>>1]|0;HEAP16[$__t$i+4>>1]=HEAP16[$107+4>>1]|0;
    $108 = (($__i$017) + 12|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($__i$017) + 16|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = $111&65535;
    $113 = $111 >>> 16;
    $114 = $113&65535;
    HEAP16[$__t$sroa$5>>1] = $114;
    $115 = (($__i$017) + 20|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($__i$017) + 24|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = (($__i$017) + 28|0);
    ;HEAP32[$__t$sroa$8+0>>2]=HEAP32[$119+0>>2]|0;HEAP32[$__t$sroa$8+4>>2]=HEAP32[$119+4>>2]|0;HEAP32[$__t$sroa$8+8>>2]=HEAP32[$119+8>>2]|0;
    $120 = HEAP32[$62>>2]|0;
    $121 = (($106) + 4|0);
    dest=$__i$017+0|0; src=$__j$014+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $122 = ($__j$014|0)==($__first|0);
    L63: do {
     if ($122) {
      $$lcssa = $__j$014;$__k$0$lcssa = $__first;
     } else {
      $124 = $__j$014;
      while(1) {
       $123 = (($124) + -44|0);
       $125 = (($124) + -4|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = ($120|0)==($126|0);
       do {
        if ($127) {
         $129 = (($124) + -40|0);
         $130 = HEAP16[$129>>1]|0;
         $131 = ($132<<16>>16)==($130<<16>>16);
         if (!($131)) {
          $133 = ($132<<16>>16)<($130<<16>>16);
          if ($133) {
           break;
          } else {
           $$lcssa = $124;$__k$0$lcssa = $124;
           break L63;
          }
         }
         $134 = (($124) + -32|0);
         $135 = HEAP32[$134>>2]|0;
         $136 = ($109|0)==($135|0);
         if (!($136)) {
          $137 = ($109>>>0)<($135>>>0);
          if ($137) {
           break;
          } else {
           $$lcssa = $124;$__k$0$lcssa = $124;
           break L63;
          }
         }
         $138 = (($124) + -24|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = ($116|0)==($139|0);
         if (!($140)) {
          $141 = ($116|0)>($139|0);
          if ($141) {
           break;
          } else {
           $$lcssa = $124;$__k$0$lcssa = $124;
           break L63;
          }
         }
         $142 = HEAP32[$123>>2]|0;
         $143 = ($106|0)==($142|0);
         if (!($143)) {
          $144 = HEAP32[$121>>2]|0;
          $145 = (($142) + 4|0);
          $146 = HEAP32[$145>>2]|0;
          $147 = ($144|0)<($146|0);
          if ($147) {
           break;
          } else {
           $$lcssa = $124;$__k$0$lcssa = $124;
           break L63;
          }
         }
         $148 = (($124) + -20|0);
         $149 = Math_fround(HEAPF32[$148>>2]);
         $150 = $118 == $149;
         if ($150) {
          $151 = (($124) + -28|0);
          $152 = HEAP16[$151>>1]|0;
          $153 = ($112<<16>>16)==($152<<16>>16);
          if (!($153)) {
           $154 = ($112&65535)>($152&65535);
           if ($154) {
            break;
           } else {
            $$lcssa = $124;$__k$0$lcssa = $124;
            break L63;
           }
          }
         }
         $155 = $118 > $149;
         if (!($155)) {
          $$lcssa = $124;$__k$0$lcssa = $124;
          break L63;
         }
        } else {
         $128 = ($120>>>0)<($126>>>0);
         if (!($128)) {
          $$lcssa = $124;$__k$0$lcssa = $124;
          break L63;
         }
        }
       } while(0);
       dest=$124+0|0; src=$123+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $156 = ($123|0)==($__first|0);
       if ($156) {
        $$lcssa = $123;$__k$0$lcssa = $__first;
        break;
       } else {
        $124 = $123;
       }
      }
     }
    } while(0);
    HEAP32[$__k$0$lcssa>>2] = $106;
    $157 = (($__k$0$lcssa) + 4|0);
    HEAP16[$157>>1] = $132;
    $158 = (($__k$0$lcssa) + 6|0);
    ;HEAP16[$158+0>>1]=HEAP16[$__t$i+0>>1]|0;HEAP16[$158+2>>1]=HEAP16[$__t$i+2>>1]|0;HEAP16[$158+4>>1]=HEAP16[$__t$i+4>>1]|0;
    $159 = (($__k$0$lcssa) + 12|0);
    HEAP32[$159>>2] = $109;
    $160 = (($__k$0$lcssa) + 16|0);
    HEAP16[$160>>1] = $112;
    $161 = (($$lcssa) + 18|0);
    $162 = HEAP16[$__t$sroa$5>>1]|0;
    HEAP16[$161>>1] = $162;
    $163 = (($__k$0$lcssa) + 20|0);
    HEAP32[$163>>2] = $116;
    $164 = (($__k$0$lcssa) + 24|0);
    HEAPF32[$164>>2] = $118;
    $165 = (($__k$0$lcssa) + 28|0);
    ;HEAP32[$165+0>>2]=HEAP32[$__t$sroa$8+0>>2]|0;HEAP32[$165+4>>2]=HEAP32[$__t$sroa$8+4>>2]|0;HEAP32[$165+8>>2]=HEAP32[$__t$sroa$8+8>>2]|0;
    $166 = (($__k$0$lcssa) + 40|0);
    HEAP32[$166>>2] = $120;
    $167 = (($__count$015) + 1)|0;
    $168 = ($167|0)==(8);
    if ($168) {
     break;
    } else {
     $__count$1 = $167;
    }
   }
   $171 = (($__i$017) + 44|0);
   $172 = ($171|0)==($__last|0);
   if ($172) {
    $$3 = 1;
    label = 56;
    break;
   } else {
    $__j$014$phi = $__i$017;$__count$015 = $__count$1;$__i$017 = $171;$__j$014 = $__j$014$phi;
   }
  }
  if ((label|0) == 56) {
   STACKTOP = sp;return ($$3|0);
  }
  $169 = (($__i$017) + 44|0);
  $170 = ($169|0)==($__last|0);
  $$3 = $170;
  STACKTOP = sp;return ($$3|0);
 }
 }
 return 0|0;
}
function __GLOBAL__I_a1667() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568488);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[568480>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568512);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[568504>>2] = $2;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568536);
 $3 = HEAP32[$0>>2]|0;
 HEAP32[568528>>2] = $3;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568560);
 $4 = HEAP32[$0>>2]|0;
 HEAP32[568552>>2] = $4;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568584);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[568576>>2] = $5;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568608);
 $6 = HEAP32[$0>>2]|0;
 HEAP32[568600>>2] = $6;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568632);
 $7 = HEAP32[$0>>2]|0;
 HEAP32[568624>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN18DeferredRenderLoop14RenderLightingER12ActiveLightsP13RenderTexture9TextureIDPS3_iRK8Vector4fRK14LightingLayersR10MinMaxAABBS5_($this,$activeLights,$rtMain,$depthTextureID,$rtGBuffer,$rtGBufferCount,$lightFade,$lightingLayers,$receiverBounds,$outMainShadowMap) {
 $this = $this|0;
 $activeLights = $activeLights|0;
 $rtMain = $rtMain|0;
 $depthTextureID = $depthTextureID|0;
 $rtGBuffer = $rtGBuffer|0;
 $rtGBufferCount = $rtGBufferCount|0;
 $lightFade = $lightFade|0;
 $lightingLayers = $lightingLayers|0;
 $receiverBounds = $receiverBounds|0;
 $outMainShadowMap = $outMainShadowMap|0;
 var $$ = 0, $$$pre = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0;
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $camData = 0, $i$013 = 0, $it$012 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $name = 0, $or$cond = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 960|0;
 $$byval_copy = sp + 768|0;
 $camData = sp;
 $0 = sp + 724|0;
 $name = sp + 728|0;
 $1 = sp + 732|0;
 $2 = sp + 744|0;
 $3 = sp + 756|0;
 HEAP32[$outMainShadowMap>>2] = 0;
 $4 = (__Z18GetQualitySettingsv()|0);
 $5 = (($4) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8) + (($6*96)|0)|0) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__Z19GetLightmapSettingsv()|0);
 $12 = (__ZNK16LightmapSettings22GetLightmapsModeLegacyEv($11)|0);
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 _memcpy(($camData|0),($15|0),612)|0;
 $16 = HEAP32[652824>>2]|0;
 $17 = Math_fround(HEAPF32[$receiverBounds>>2]);
 $18 = Math_fround($17 + Math_fround(-0.00999999977648258209228));
 HEAPF32[$receiverBounds>>2] = $18;
 $19 = (($receiverBounds) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 + Math_fround(-0.00999999977648258209228));
 HEAPF32[$19>>2] = $21;
 $22 = (($receiverBounds) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 + Math_fround(-0.00999999977648258209228));
 HEAPF32[$22>>2] = $24;
 $25 = (($receiverBounds) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + Math_fround(0.00999999977648258209228));
 HEAPF32[$25>>2] = $27;
 $28 = (($receiverBounds) + 16|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 + Math_fround(0.00999999977648258209228));
 HEAPF32[$28>>2] = $30;
 $31 = (($receiverBounds) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 + Math_fround(0.00999999977648258209228));
 HEAPF32[$31>>2] = $33;
 __Z15InitLightMeshesv();
 $34 = HEAP8[569048>>0]|0;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  HEAP32[$$byval_copy>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy,569056);
  $36 = HEAP32[$$byval_copy>>2]|0;
  HEAP32[569040>>2] = $36;
  HEAP8[569048>>0] = 1;
 }
 $37 = HEAP8[569088>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  HEAP32[$$byval_copy>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy,569096);
  $39 = HEAP32[$$byval_copy>>2]|0;
  HEAP32[569080>>2] = $39;
  HEAP8[569088>>0] = 1;
 }
 $40 = HEAP32[$rtMain>>2]|0;
 $41 = (($40) + 116|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (FUNCTION_TABLE_ii[$42 & 4095]($rtMain)|0);
 $44 = HEAP32[$rtMain>>2]|0;
 $45 = (($44) + 120|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (FUNCTION_TABLE_ii[$46 & 4095]($rtMain)|0);
 $48 = HEAP8[((640792 + 248|0))>>0]|0;
 $49 = ($48<<24>>24)==(0);
 if (!($49)) {
  $50 = (($16) + 20|0);
  $51 = HEAP32[$depthTextureID>>2]|0;
  HEAP32[$0>>2] = $51;
  $52 = (($rtMain) + 72|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($rtMain) + 76|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($rtMain) + 64|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($rtMain) + 68|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN9ShaderLab13PropertySheet16SetRectTextureIDERKNS_16FastPropertyNameE9TextureIDiiffff($50,569040,$$byval_copy,$43,$47,$53,$55,$57,$59);
 }
 $60 = ($rtGBufferCount|0)>(0);
 L10: do {
  if ($60) {
   $61 = (($2) + 8|0);
   $62 = (($2) + 4|0);
   $63 = (($1) + 1|0);
   $64 = (($16) + 20|0);
   $65 = (($1) + 8|0);
   $i$013 = 0;
   while(1) {
    HEAP32[$name>>2] = -1;
    $66 = (__Znwj(32)|0);
    HEAP32[$61>>2] = $66;
    HEAP32[$2>>2] = 33;
    HEAP32[$62>>2] = 21;
    dest=$66+0|0; src=569120+0|0; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $67 = (($66) + 21|0);
    HEAP8[$67>>0] = 0;
    $68 = (($i$013) + 48)|0;
    $69 = $68&255;
    __THREW__ = 0;
    invoke_viii(1667,($1|0),($2|0),($69|0));
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     label = 16;
     break;
    }
    $72 = HEAP8[$1>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    $75 = HEAP32[$65>>2]|0;
    $$ = $74 ? $63 : $75;
    __THREW__ = 0;
    invoke_vii(2618,($name|0),($$|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     label = 17;
     break;
    }
    $78 = HEAP8[$1>>0]|0;
    $79 = $78 & 1;
    $80 = ($79<<24>>24)==(0);
    if (!($80)) {
     $81 = HEAP32[$65>>2]|0;
     __ZdlPv($81);
    }
    $82 = HEAP8[$2>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if (!($84)) {
     $85 = HEAP32[$61>>2]|0;
     __ZdlPv($85);
    }
    $86 = (($rtGBuffer) + ($i$013<<2)|0);
    $87 = HEAP32[$86>>2]|0;
    (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($64,$name,$87)|0);
    $88 = (($i$013) + 1)|0;
    $89 = ($88|0)<($rtGBufferCount|0);
    if ($89) {
     $i$013 = $88;
    } else {
     break L10;
    }
   }
   if ((label|0) == 16) {
    $90 = ___cxa_find_matching_catch()|0;
    $91 = tempRet0;
    $$0 = $90;$$01 = $91;
   }
   else if ((label|0) == 17) {
    $92 = ___cxa_find_matching_catch()|0;
    $93 = tempRet0;
    $94 = HEAP8[$1>>0]|0;
    $95 = $94 & 1;
    $96 = ($95<<24>>24)==(0);
    if ($96) {
     $$0 = $92;$$01 = $93;
    } else {
     $97 = HEAP32[$65>>2]|0;
     __ZdlPv($97);
     $$0 = $92;$$01 = $93;
    }
   }
   $98 = HEAP8[$2>>0]|0;
   $99 = $98 & 1;
   $100 = ($99<<24>>24)==(0);
   if ($100) {
    $$2 = $$0;$$23 = $$01;
    ___resumeException($$2|0);
    // unreachable;
   }
   $101 = HEAP32[$61>>2]|0;
   __ZdlPv($101);
   $$2 = $$0;$$23 = $$01;
   ___resumeException($$2|0);
   // unreachable;
  }
 } while(0);
 $102 = (($rtGBuffer) + 8|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ($103|0)==(0|0);
 if (!($104)) {
  $105 = (($16) + 20|0);
  (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($105,569080,$103)|0);
 }
 $106 = (__Z12GetGfxDevicev()|0);
 $107 = (__Z12GetGfxDevicev()|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($108) + 88|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = (FUNCTION_TABLE_ii[$110 & 4095]($107)|0);
 $112 = HEAP32[$107>>2]|0;
 $113 = (($112) + 84|0);
 $114 = HEAP32[$113>>2]|0;
 FUNCTION_TABLE_vii[$114 & 4095]($107,0);
 $115 = HEAP32[$106>>2]|0;
 $116 = (($115) + 136|0);
 $117 = HEAP32[$116>>2]|0;
 __THREW__ = 0;
 invoke_vii($117|0,($106|0),0);
 $118 = __THREW__; __THREW__ = 0;
 $119 = $118&1;
 L35: do {
  if ($119) {
   label = 31;
  } else {
   $120 = HEAP32[$106>>2]|0;
   $121 = (($120) + 40|0);
   $122 = HEAP32[$121>>2]|0;
   HEAP8[$3>>0] = 0;
   $123 = (($3) + 1|0);
   HEAP8[$123>>0] = -1;
   $124 = (($3) + 2|0);
   HEAP8[$124>>0] = -1;
   $125 = (($3) + 4|0);
   HEAP8[$125>>0] = 8;
   $126 = (($3) + 5|0);
   HEAP8[$126>>0] = 0;
   $127 = (($3) + 6|0);
   HEAP8[$127>>0] = 0;
   $128 = (($3) + 7|0);
   HEAP8[$128>>0] = 0;
   $129 = (($3) + 8|0);
   HEAP8[$129>>0] = 8;
   $130 = (($3) + 9|0);
   HEAP8[$130>>0] = 0;
   $131 = (($3) + 10|0);
   HEAP8[$131>>0] = 0;
   $132 = (($3) + 11|0);
   HEAP8[$132>>0] = 0;
   __THREW__ = 0;
   $133 = (invoke_iii($122|0,($106|0),($3|0))|0);
   $134 = __THREW__; __THREW__ = 0;
   $135 = $134&1;
   if ($135) {
    label = 31;
   } else {
    __THREW__ = 0;
    invoke_vi(3405,($$byval_copy|0));
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if ($137) {
     label = 31;
    } else {
     $138 = HEAP32[$106>>2]|0;
     $139 = (($138) + 96|0);
     $140 = HEAP32[$139>>2]|0;
     __THREW__ = 0;
     invoke_vii($140|0,($106|0),(616552|0));
     $141 = __THREW__; __THREW__ = 0;
     $142 = $141&1;
     L39: do {
      if ($142) {
       label = 33;
      } else {
       $143 = HEAP32[$this>>2]|0;
       $144 = HEAP32[$143>>2]|0;
       $145 = (($144) + 636|0);
       __THREW__ = 0;
       invoke_viii(1663,($145|0),6,($16|0));
       $146 = __THREW__; __THREW__ = 0;
       $147 = $146&1;
       if ($147) {
        label = 33;
       } else {
        $148 = (($activeLights) + 16|0);
        $149 = HEAP8[$148>>0]|0;
        $150 = ($149<<24>>24)==(0);
        $$pre = HEAP32[$activeLights>>2]|0;
        $$$pre = $150 ? 0 : $$pre;
        $151 = (($activeLights) + 8|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = (($$pre) + (($152*108)|0)|0);
        $154 = ($152|0)==(0);
        L42: do {
         if (!($154)) {
          $155 = (($rtGBuffer) + 12|0);
          $it$012 = $$pre;
          while(1) {
           $156 = (($it$012) + 9|0);
           $157 = HEAP8[$156>>0]|0;
           $158 = ($157<<24>>24)==(0);
           $159 = ($it$012|0)==($$$pre|0);
           $or$cond = $158 | $159;
           if (!($or$cond)) {
            $168 = HEAP32[$this>>2]|0;
            $169 = HEAP32[$155>>2]|0;
            __THREW__ = 0;
            (invoke_iiiiiiiiiiiiiii(2,($168|0),($camData|0),($10|0),($12|0),($169|0),($rtMain|0),($133|0),($receiverBounds|0),($$byval_copy|0),($lightFade|0),($lightingLayers|0),($it$012|0),0,($16|0))|0);
            $170 = __THREW__; __THREW__ = 0;
            $171 = $170&1;
            if ($171) {
             break;
            }
           }
           $172 = (($it$012) + 108|0);
           $173 = ($172|0)==($153|0);
           if ($173) {
            break L42;
           } else {
            $it$012 = $172;
           }
          }
          $162 = ___cxa_find_matching_catch()|0;
          $163 = tempRet0;
          $lpad$phi$index = $162;$lpad$phi$index2 = $163;
          break L39;
         }
        } while(0);
        $174 = ($$$pre|0)==(0|0);
        if (!($174)) {
         $175 = HEAP32[$this>>2]|0;
         $176 = (($rtGBuffer) + 12|0);
         $177 = HEAP32[$176>>2]|0;
         __THREW__ = 0;
         $178 = (invoke_iiiiiiiiiiiiiii(2,($175|0),($camData|0),($10|0),($12|0),($177|0),($rtMain|0),($133|0),($receiverBounds|0),($$byval_copy|0),($lightFade|0),($lightingLayers|0),($$$pre|0),1,($16|0))|0);
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if ($180) {
          label = 33;
          break;
         }
         $181 = ($178|0)==(0|0);
         if (!($181)) {
          $182 = HEAP32[$this>>2]|0;
          $183 = (($182) + 116|0);
          $184 = HEAP32[$183>>2]|0;
          __THREW__ = 0;
          invoke_viii(1666,($184|0),5,($178|0));
          $185 = __THREW__; __THREW__ = 0;
          $186 = $185&1;
          if ($186) {
           label = 33;
           break;
          }
          HEAP32[$outMainShadowMap>>2] = $178;
         }
        }
        __THREW__ = 0;
        invoke_vi(3400,($16|0));
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         label = 33;
        } else {
         $189 = HEAP32[$106>>2]|0;
         $190 = (($189) + 64|0);
         $191 = HEAP32[$190>>2]|0;
         __THREW__ = 0;
         invoke_viii($191|0,($106|0),($133|0),0);
         $192 = __THREW__; __THREW__ = 0;
         $193 = $192&1;
         if ($193) {
          label = 33;
         } else {
          $194 = HEAP32[$this>>2]|0;
          $195 = HEAP32[$194>>2]|0;
          $196 = (($195) + 636|0);
          __THREW__ = 0;
          invoke_viii(1663,($196|0),7,($16|0));
          $197 = __THREW__; __THREW__ = 0;
          $198 = $197&1;
          if ($198) {
           label = 33;
          } else {
           __THREW__ = 0;
           invoke_vi(3375,($$byval_copy|0));
           $199 = __THREW__; __THREW__ = 0;
           $200 = $199&1;
           if ($200) {
            label = 31;
            break L35;
           }
           $201 = (__Z12GetGfxDevicev()|0);
           $202 = HEAP32[$201>>2]|0;
           $203 = (($202) + 84|0);
           $204 = HEAP32[$203>>2]|0;
           FUNCTION_TABLE_vii[$204 & 4095]($201,$111);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 33) {
      $164 = ___cxa_find_matching_catch()|0;
      $165 = tempRet0;
      $lpad$phi$index = $164;$lpad$phi$index2 = $165;
     }
     __THREW__ = 0;
     invoke_vi(3375,($$byval_copy|0));
     $166 = __THREW__; __THREW__ = 0;
     $167 = $166&1;
     if ($167) {
      $213 = ___cxa_find_matching_catch(0|0)|0;
      $214 = tempRet0;
      ___clang_call_terminate($213);
      // unreachable;
     } else {
      $$1 = $lpad$phi$index;$$12 = $lpad$phi$index2;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 31) {
  $160 = ___cxa_find_matching_catch()|0;
  $161 = tempRet0;
  $$1 = $160;$$12 = $161;
 }
 __THREW__ = 0;
 $205 = (invoke_i(59)|0);
 $206 = __THREW__; __THREW__ = 0;
 $207 = $206&1;
 if ($207) {
  $213 = ___cxa_find_matching_catch(0|0)|0;
  $214 = tempRet0;
  ___clang_call_terminate($213);
  // unreachable;
 }
 $208 = HEAP32[$205>>2]|0;
 $209 = (($208) + 84|0);
 $210 = HEAP32[$209>>2]|0;
 __THREW__ = 0;
 invoke_vii($210|0,($205|0),($111|0));
 $211 = __THREW__; __THREW__ = 0;
 $212 = $211&1;
 if ($212) {
  $213 = ___cxa_find_matching_catch(0|0)|0;
  $214 = tempRet0;
  ___clang_call_terminate($213);
  // unreachable;
 } else {
  $$2 = $$1;$$23 = $$12;
  ___resumeException($$2|0);
  // unreachable;
 }
}
function __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_S6_($agg$result,$__lhs,$__rhs) {
 $agg$result = $agg$result|0;
 $__lhs = $__lhs|0;
 $__rhs = $__rhs|0;
 var $$pn$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__cap$0$i = 0, $__p$0$i = 0, $__p$0$i2 = 0, $__p$0$sum$pre$i = 0, $__p$0$sum$pre$phi$iZZZ2D = 0, $__sz$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $0 = HEAP8[$__lhs>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = $0&255;
  $8 = $7 >>> 1;
  $9 = (($__lhs) + 1|0);
  $11 = $8;$28 = $9;
 } else {
  $3 = (($__lhs) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($__lhs) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $11 = $4;$28 = $6;
 }
 $10 = (($11) + 1)|0;
 $12 = ($10>>>0)>(4294967279);
 do {
  if ($12) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    // unreachable;
   }
  } else {
   $15 = ($10>>>0)<(11);
   if ($15) {
    $16 = $11 << 1;
    $17 = $16&255;
    HEAP8[$agg$result>>0] = $17;
    $18 = (($agg$result) + 1|0);
    $31 = $17;$__p$0$i = $18;
   } else {
    $19 = (($11) + 17)|0;
    $20 = $19 & -16;
    __THREW__ = 0;
    $21 = (invoke_ii(2988,($20|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = (($agg$result) + 8|0);
    HEAP32[$24>>2] = $21;
    $25 = $20 | 1;
    HEAP32[$agg$result>>2] = $25;
    $26 = (($agg$result) + 4|0);
    HEAP32[$26>>2] = $11;
    $27 = $25&255;
    $31 = $27;$__p$0$i = $21;
   }
   _memcpy(($__p$0$i|0),($28|0),($11|0))|0;
   $29 = (($__p$0$i) + ($11)|0);
   HEAP8[$29>>0] = 0;
   $30 = $31 & 1;
   $32 = ($30<<24>>24)!=(0);
   if ($32) {
    $35 = HEAP32[$agg$result>>2]|0;
    $36 = $35 & -2;
    $37 = (($36) + -1)|0;
    $38 = (($agg$result) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $__cap$0$i = $37;$__sz$0$i = $39;
   } else {
    $33 = $31&255;
    $34 = $33 >>> 1;
    $__cap$0$i = 10;$__sz$0$i = $34;
   }
   $40 = ($__sz$0$i|0)==($__cap$0$i|0);
   if ($40) {
    __THREW__ = 0;
    invoke_viiiiiii(61,($agg$result|0),($__cap$0$i|0),1,($__cap$0$i|0),($__cap$0$i|0),0,0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $43 = HEAP8[$agg$result>>0]|0;
    $44 = $43 & 1;
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     label = 18;
    } else {
     label = 19;
    }
   } else {
    if ($32) {
     label = 19;
    } else {
     label = 18;
    }
   }
   if ((label|0) == 18) {
    $46 = (($agg$result) + 1|0);
    $47 = $__sz$0$i << 1;
    $48 = (($47) + 2)|0;
    $49 = $48&255;
    HEAP8[$agg$result>>0] = $49;
    $__p$0$sum$pre$i = (($__sz$0$i) + 1)|0;
    $$pn$i = $46;$__p$0$sum$pre$phi$iZZZ2D = $__p$0$sum$pre$i;
    $__p$0$i2 = (($$pn$i) + ($__sz$0$i)|0);
    HEAP8[$__p$0$i2>>0] = $__rhs;
    $61 = (($$pn$i) + ($__p$0$sum$pre$phi$iZZZ2D)|0);
    HEAP8[$61>>0] = 0;
    STACKTOP = sp;return;
   }
   else if ((label|0) == 19) {
    $50 = (($agg$result) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($__sz$0$i) + 1)|0;
    $53 = (($agg$result) + 4|0);
    HEAP32[$53>>2] = $52;
    $$pn$i = $51;$__p$0$sum$pre$phi$iZZZ2D = $52;
    $__p$0$i2 = (($$pn$i) + ($__sz$0$i)|0);
    HEAP8[$__p$0$i2>>0] = $__rhs;
    $61 = (($$pn$i) + ($__p$0$sum$pre$phi$iZZZ2D)|0);
    HEAP8[$61>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $54 = ___cxa_find_matching_catch()|0;
 $55 = tempRet0;
 $56 = HEAP8[$agg$result>>0]|0;
 $57 = $56 & 1;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  ___resumeException($54|0);
  // unreachable;
 }
 $59 = (($agg$result) + 8|0);
 $60 = HEAP32[$59>>2]|0;
 __ZdlPv($60);
 ___resumeException($54|0);
 // unreachable;
}
function __ZL19RenderLightDeferredRK17RenderLoopContextRK14ShadowCullDataN15QualitySettings13ShadowQualityEN16LightmapSettings19LightmapsModeLegacyEP13RenderTextureSA_iiPK18DeviceStencilStateRK10MinMaxAABBRK22DeviceMVPMatricesStateRK8Vector4fRK14LightingLayersRK11ActiveLightbRN9ShaderLab17ShaderPassContextE($ctx,$shadowCullData,$shadowQuality,$lightmapsMode,$rtLight,$rtMain,$devStDisabled,$receiverBounds,$mvpState,$lightFade,$lightingLayers,$light,$returnShadowMap,$passContext) {
 $ctx = $ctx|0;
 $shadowCullData = $shadowCullData|0;
 $shadowQuality = $shadowQuality|0;
 $lightmapsMode = $lightmapsMode|0;
 $rtLight = $rtLight|0;
 $rtMain = $rtMain|0;
 $devStDisabled = $devStDisabled|0;
 $receiverBounds = $receiverBounds|0;
 $mvpState = $mvpState|0;
 $lightFade = $lightFade|0;
 $lightingLayers = $lightingLayers|0;
 $light = $light|0;
 $returnShadowMap = $returnShadowMap|0;
 $passContext = $passContext|0;
 var $$ = 0, $$$i = 0, $$0$i = 0, $$0$i$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$19 = Math_fround(0), $$20 = Math_fround(0), $$21 = Math_fround(0), $$22 = Math_fround(0), $$6 = 0, $$6$ = 0, $$byval_copy4 = 0, $$in = 0, $$not3 = 0, $$not4 = 0, $$not7 = 0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0;
 var $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $blendstate = 0, $brmerge = 0, $brmerge5 = 0, $brmerge8 = 0, $brmerge9 = 0, $depthstate = 0, $depthstate4 = 0, $lightCol = 0, $lightMatrix = 0, $lightPassAddBits = 0, $lightPassCount$0 = 0;
 var $lightPos = 0, $lightShadows$0 = 0, $lightShadows1$0 = 0, $lightStencil = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $phitmp = 0, $pp$029 = 0, $rasterstate = 0, $rasterstate3 = 0, $rtSurfaceColor = 0, $shadowMap$0 = 0, $shadowMap$1 = 0, $shadowMap$2 = 0, $shadowMatrices = 0, $stencil = 0, $stencilRef$0 = 0, $storemerge24 = 0, $temp1 = 0;
 var $temp2 = 0, $temp3 = 0, $temp4 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1536|0;
 $$byval_copy4 = sp + 72|0;
 $lightMatrix = sp + 1464|0;
 $lightPos = sp + 1448|0;
 $lightCol = sp + 1432|0;
 $temp1 = sp + 1368|0;
 $temp2 = sp + 1304|0;
 $temp3 = sp + 1240|0;
 $0 = sp + 1224|0;
 $1 = sp + 1212|0;
 $temp4 = sp + 488|0;
 $2 = sp + 476|0;
 $3 = sp + 464|0;
 $4 = sp + 448|0;
 $5 = sp + 432|0;
 $6 = sp + 136|0;
 $shadowMatrices = sp + 176|0;
 $7 = sp + 64|0;
 $8 = sp + 56|0;
 $rtSurfaceColor = sp + 52|0;
 $9 = sp + 48|0;
 $lightPassAddBits = sp + 16|0;
 $blendstate = sp + 36|0;
 $rasterstate = sp + 24|0;
 $depthstate = sp + 1530|0;
 $lightStencil = sp + 140|0;
 $10 = sp + 152|0;
 $11 = sp + 156|0;
 $stencil = sp + 160|0;
 $rasterstate3 = sp;
 $depthstate4 = sp + 1528|0;
 $12 = HEAP32[$light>>2]|0;
 $13 = (($12) + 216|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(3);
 if ($15) {
  $$0$i = 2;
 } else {
  $16 = (($12) + 221|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $$0$i = 0;
  } else {
   $19 = (($12) + 212|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(1);
   $$$i = $21 ? 1 : 2;
   $$0$i = $$$i;
  }
 }
 $22 = (($12) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($23)|0);
 __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($lightMatrix,$24);
 $25 = (($lightMatrix) + 48|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($lightMatrix) + 52|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($lightMatrix) + 56|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$lightPos>>2] = $26;
 $31 = (($lightPos) + 4|0);
 HEAPF32[$31>>2] = $28;
 $32 = (($lightPos) + 8|0);
 HEAPF32[$32>>2] = $30;
 $33 = (($12) + 116|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = HEAP32[$13>>2]|0;
  $37 = ($36|0)==(1);
  if ($37) {
   $lightShadows$0 = $34;
  } else {
   $38 = (__Z16GetBuildSettingsv()|0);
   $39 = (($38) + 103|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   $$ = $41 ? 0 : $34;
   $lightShadows$0 = $$;
  }
  $42 = ($lightShadows$0|0)>(1);
  if ($42) {
   (__Z21GetSoftShadowsEnabledv()|0);
  }
 }
 $43 = (__Z12GetGfxDevicev()|0);
 __ZN5Light15SetLightKeywordEv($12);
 $44 = (($lightMatrix) + 32|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($lightMatrix) + 36|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($lightMatrix) + 40|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (__Z19GetActiveColorSpacev()|0);
 $51 = ($50|0)==(1);
 $52 = (($12) + 140|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 do {
  if ($51) {
   $54 = !($53 <= Math_fround(0.0404499992728233337402));
   do {
    if ($54) {
     $56 = $53 < Math_fround(1.0);
     if ($56) {
      $57 = Math_fround($53 + Math_fround(0.054999999701976776123));
      $58 = Math_fround($57 / Math_fround(1.05499994754791259766));
      $59 = (Math_fround(+(Math_pow((+$58),2.40000009536743164063))));
      $$0$i$i$i = $59;
      break;
     } else {
      $60 = (Math_fround(+(Math_pow((+$53),2.40000009536743164063))));
      $$0$i$i$i = $60;
      break;
     }
    } else {
     $55 = Math_fround($53 / Math_fround(12.9200000762939453125));
     $$0$i$i$i = $55;
    }
   } while(0);
   $61 = (($12) + 144|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = !($62 <= Math_fround(0.0404499992728233337402));
   do {
    if ($63) {
     $65 = $62 < Math_fround(1.0);
     if ($65) {
      $66 = Math_fround($62 + Math_fround(0.054999999701976776123));
      $67 = Math_fround($66 / Math_fround(1.05499994754791259766));
      $68 = (Math_fround(+(Math_pow((+$67),2.40000009536743164063))));
      $$0$i3$i$i = $68;
      break;
     } else {
      $69 = (Math_fround(+(Math_pow((+$62),2.40000009536743164063))));
      $$0$i3$i$i = $69;
      break;
     }
    } else {
     $64 = Math_fround($62 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i = $64;
    }
   } while(0);
   $70 = (($12) + 148|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = !($71 <= Math_fround(0.0404499992728233337402));
   if (!($72)) {
    $73 = Math_fround($71 / Math_fround(12.9200000762939453125));
    $87 = $$0$i$i$i;$89 = $$0$i3$i$i;$91 = $73;
    break;
   }
   $74 = $71 < Math_fround(1.0);
   if ($74) {
    $75 = Math_fround($71 + Math_fround(0.054999999701976776123));
    $76 = Math_fround($75 / Math_fround(1.05499994754791259766));
    $77 = (Math_fround(+(Math_pow((+$76),2.40000009536743164063))));
    $87 = $$0$i$i$i;$89 = $$0$i3$i$i;$91 = $77;
    break;
   } else {
    $78 = (Math_fround(+(Math_pow((+$71),2.40000009536743164063))));
    $87 = $$0$i$i$i;$89 = $$0$i3$i$i;$91 = $78;
    break;
   }
  } else {
   $79 = (($12) + 144|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = (($12) + 148|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $87 = $53;$89 = $80;$91 = $82;
  }
 } while(0);
 $$in = (($12) + 152|0);
 $83 = Math_fround(HEAPF32[$$in>>2]);
 $84 = (($12) + 184|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($87 * $85);
 $88 = Math_fround($89 * $85);
 $90 = Math_fround($91 * $85);
 $92 = Math_fround($83 * $85);
 $93 = Math_fround($86 * Math_fround(2.0));
 $94 = Math_fround($88 * Math_fround(2.0));
 $95 = Math_fround($90 * Math_fround(2.0));
 $96 = Math_fround($92 * Math_fround(2.0));
 HEAPF32[$lightCol>>2] = $93;
 $97 = (($lightCol) + 4|0);
 HEAPF32[$97>>2] = $94;
 $98 = (($lightCol) + 8|0);
 HEAPF32[$98>>2] = $95;
 $99 = (($lightCol) + 12|0);
 HEAPF32[$99>>2] = $96;
 $100 = HEAP32[$13>>2]|0;
 if ((($100|0) == 2)) {
  $111 = (($12) + 40|0);
  $112 = (($43) + 3556|0);
  dest=$112+0|0; src=$111+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 } else if ((($100|0) == 1)) {
  $113 = (($12) + 196|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = Math_fround(Math_fround(1.0) / $114);
  HEAPF32[$2>>2] = $115;
  $116 = (($2) + 4|0);
  HEAPF32[$116>>2] = $115;
  $117 = (($2) + 8|0);
  HEAPF32[$117>>2] = Math_fround(0.0);
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($temp1,$2)|0);
  HEAPF32[$3>>2] = Math_fround(0.5);
  $118 = (($3) + 4|0);
  HEAPF32[$118>>2] = Math_fround(0.5);
  $119 = (($3) + 8|0);
  HEAPF32[$119>>2] = Math_fround(0.0);
  (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($temp2,$3)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp2,$temp1,$temp3);
  $120 = (($12) + 40|0);
  $121 = (($43) + 3556|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp3,$120,$121);
 } else if ((($100|0) == 0)) {
  $101 = (($12) + 40|0);
  dest=$$byval_copy4+0|0; src=$101+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  HEAPF32[$0>>2] = Math_fround(-0.5);
  $102 = (($0) + 4|0);
  HEAPF32[$102>>2] = Math_fround(-0.5);
  $103 = (($0) + 8|0);
  HEAPF32[$103>>2] = Math_fround(1.0);
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($temp1,$0)|0);
  HEAPF32[$1>>2] = Math_fround(0.5);
  $104 = (($1) + 4|0);
  HEAPF32[$104>>2] = Math_fround(0.5);
  $105 = (($1) + 8|0);
  HEAPF32[$105>>2] = Math_fround(0.0);
  (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($temp2,$1)|0);
  $106 = (($12) + 200|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = (($12) + 188|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  (__ZN10Matrix4x4f19SetPerspectiveCotanEfff($temp3,$107,Math_fround(0.0),$109)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp2,$temp3,$temp4);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp4,$temp1,$temp2);
  $110 = (($43) + 3556|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp2,$$byval_copy4,$110);
 }
 $122 = HEAP32[569184>>2]|0;
 __Z22AssignCookieToMaterialRK5LightPN5Unity8MaterialE($12,$122);
 $123 = (($light) + 20|0);
 $124 = HEAP8[$123>>0]|0;
 $125 = ($124<<24>>24)==(0);
 if ($125) {
  label = 32;
 } else {
  $126 = (($light) + 21|0);
  $127 = HEAP8[$126>>0]|0;
  $128 = ($127<<24>>24)==(0);
  if ($128) {
   label = 32;
  } else {
   $133 = 1;
  }
 }
 if ((label|0) == 32) {
  $129 = HEAP32[$13>>2]|0;
  $130 = ($129|0)==(1);
  $133 = $130;
 }
 $131 = (($passContext) + 20|0);
 $132 = $133 ? Math_fround(1.0) : Math_fround(0.0);
 __ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf($131,568952,$132);
 $134 = Math_fround(HEAPF32[$lightPos>>2]);
 $135 = Math_fround(HEAPF32[$31>>2]);
 $136 = Math_fround(HEAPF32[$32>>2]);
 $137 = (($12) + 188|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($138 * $138);
 $140 = Math_fround(Math_fround(1.0) / $139);
 HEAPF32[$4>>2] = $134;
 $141 = (($4) + 4|0);
 HEAPF32[$141>>2] = $135;
 $142 = (($4) + 8|0);
 HEAPF32[$142>>2] = $136;
 $143 = (($4) + 12|0);
 HEAPF32[$143>>2] = $140;
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($131,568832,$4);
 HEAPF32[$5>>2] = $45;
 $144 = (($5) + 4|0);
 HEAPF32[$144>>2] = $47;
 $145 = (($5) + 8|0);
 HEAPF32[$145>>2] = $49;
 $146 = (($5) + 12|0);
 HEAPF32[$146>>2] = Math_fround(0.0);
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($131,568856,$5);
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($131,568880,$lightCol);
 $147 = HEAP32[569184>>2]|0;
 HEAP32[$$byval_copy4>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy4,569200);
 $148 = HEAP32[$$byval_copy4>>2]|0;
 HEAP32[$6>>2] = $148;
 $149 = (__ZN10builtintex21GetAttenuationTextureEv()|0);
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$6+0>>2]|0;
 __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($147,$$byval_copy4,$149);
 _memcpy(($temp4|0),($shadowCullData|0),612)|0;
 $150 = (($light) + 4|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = ($151|0)==(0|0);
 do {
  if ($152) {
   label = 48;
  } else {
   $153 = Math_fround(HEAPF32[$receiverBounds>>2]);
   $154 = Math_fround(HEAPF32[616664>>2]);
   $155 = $153 == $154;
   if ($155) {
    $156 = (($receiverBounds) + 4|0);
    $157 = Math_fround(HEAPF32[$156>>2]);
    $158 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
    $159 = $157 == $158;
    if ($159) {
     $160 = (($receiverBounds) + 8|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
     $163 = $161 == $162;
     if ($163) {
      label = 48;
      break;
     }
    }
   }
   $164 = Math_fround(-$154);
   $165 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
   $166 = Math_fround(-$165);
   $167 = (($receiverBounds) + 12|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = $168 == $164;
   if ($169) {
    $170 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
    $171 = Math_fround(-$170);
    $172 = (($receiverBounds) + 16|0);
    $173 = Math_fround(HEAPF32[$172>>2]);
    $174 = $173 == $171;
    if ($174) {
     $175 = (($receiverBounds) + 20|0);
     $176 = Math_fround(HEAPF32[$175>>2]);
     $phitmp = $176 == $166;
     $178 = $phitmp;
    } else {
     $178 = 0;
    }
   } else {
    $178 = 0;
   }
   $177 = ($shadowQuality|0)==(0);
   $or$cond = $178 | $177;
   if ($or$cond) {
    label = 48;
   } else {
    $179 = HEAP32[$33>>2]|0;
    $180 = ($shadowQuality|0)!=(1);
    $181 = ($179|0)==(0);
    $or$cond1 = $180 | $181;
    $lightShadows1$0 = $or$cond1 ? $179 : 1;
    $182 = HEAP32[$13>>2]|0;
    __Z18SetShadowsKeywordsRN9ShaderLab17ShaderPassContextE9LightType10ShadowTypebb($passContext,$182,$lightShadows1$0,0,1);
    $183 = HEAP32[$43>>2]|0;
    $184 = (($183) + 100|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = (($ctx) + 12|0);
    FUNCTION_TABLE_vii[$185 & 4095]($43,$186);
    $187 = HEAP32[$43>>2]|0;
    $188 = (($187) + 64|0);
    $189 = HEAP32[$188>>2]|0;
    FUNCTION_TABLE_viii[$189 & 4095]($43,$devStDisabled,0);
    $190 = HEAP32[$43>>2]|0;
    $191 = (($190) + 408|0);
    $192 = HEAP32[$191>>2]|0;
    FUNCTION_TABLE_vi[$192 & 4095]($43);
    $193 = (__Z16RenderShadowMapsR16ShadowCameraDataRK11ActiveLightRK10MinMaxAABBRN9ShaderLab17ShaderPassContextEP10Matrix4x4f($temp4,$light,$receiverBounds,$passContext,$shadowMatrices)|0);
    $194 = ($193|0)==(0|0);
    if ($194) {
     __Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE($passContext);
     $shadowMap$1 = 0;
    } else {
     $195 = (($12) + 124|0);
     $196 = Math_fround(HEAPF32[$195>>2]);
     $197 = Math_fround(Math_fround(1.0) - $196);
     $198 = (($43) + 772|0);
     HEAPF32[$198>>2] = $197;
     $199 = (($43) + 776|0);
     HEAPF32[$199>>2] = Math_fround(0.0);
     $200 = (($43) + 780|0);
     HEAPF32[$200>>2] = Math_fround(0.0);
     $201 = (($43) + 784|0);
     HEAPF32[$201>>2] = Math_fround(0.0);
     $202 = HEAP32[$13>>2]|0;
     if ((($202|0) == 1)) {
      $203 = (($43) + 3044|0);
      dest=$203+0|0; src=$shadowMatrices+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $204 = (($temp4) + 616|0);
      $205 = (($temp4) + 656|0);
      $206 = (($193) + 100|0);
      $207 = HEAP32[$206>>2]|0;
      $208 = (Math_fround(($207|0)));
      $209 = (($193) + 104|0);
      $210 = HEAP32[$209>>2]|0;
      $211 = (Math_fround(($210|0)));
      HEAPF32[$7>>2] = $208;
      $212 = (($7) + 4|0);
      HEAPF32[$212>>2] = $211;
      __Z29SetCascadedShadowShaderParamsPK10Matrix4x4fPKfPK8Vector4fRK8Vector2f($shadowMatrices,$204,$205,$7);
      $213 = HEAP32[$ctx>>2]|0;
      $214 = (($12) + 132|0);
      $215 = Math_fround(HEAPF32[$214>>2]);
      $216 = (($12) + 136|0);
      $217 = Math_fround(HEAPF32[$216>>2]);
      $218 = (__Z27ComputeScreenSpaceShadowMapRK6CameraP13RenderTextureff10ShadowTypeRN9ShaderLab17ShaderPassContextE($213,$193,$215,$217,$lightShadows1$0,$passContext)|0);
      $shadowMap$0 = $218;
     } else if ((($202|0) == 0)) {
      $219 = (($43) + 3044|0);
      dest=$219+0|0; src=$shadowMatrices+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $shadowMap$0 = $193;
     } else {
      $shadowMap$0 = $193;
     }
     $220 = HEAP32[$shadowMap$0>>2]|0;
     $221 = (($220) + 116|0);
     $222 = HEAP32[$221>>2]|0;
     $223 = (FUNCTION_TABLE_ii[$222 & 4095]($shadowMap$0)|0);
     $224 = (Math_fround(($223|0)));
     $225 = Math_fround(Math_fround(0.5) / $224);
     $226 = HEAP32[$shadowMap$0>>2]|0;
     $227 = (($226) + 120|0);
     $228 = HEAP32[$227>>2]|0;
     $229 = (FUNCTION_TABLE_ii[$228 & 4095]($shadowMap$0)|0);
     $230 = (Math_fround(($229|0)));
     $231 = Math_fround(Math_fround(0.5) / $230);
     $232 = Math_fround(-$225);
     $233 = Math_fround(-$231);
     $234 = (($43) + 708|0);
     HEAPF32[$234>>2] = $232;
     $235 = (($43) + 712|0);
     HEAPF32[$235>>2] = $233;
     $236 = (($43) + 716|0);
     HEAPF32[$236>>2] = Math_fround(0.0);
     $237 = (($43) + 720|0);
     HEAPF32[$237>>2] = Math_fround(0.0);
     $238 = (($43) + 724|0);
     HEAPF32[$238>>2] = $225;
     $239 = (($43) + 728|0);
     HEAPF32[$239>>2] = $233;
     $240 = (($43) + 732|0);
     HEAPF32[$240>>2] = Math_fround(0.0);
     $241 = (($43) + 736|0);
     HEAPF32[$241>>2] = Math_fround(0.0);
     $242 = (($43) + 740|0);
     HEAPF32[$242>>2] = $232;
     $243 = (($43) + 744|0);
     HEAPF32[$243>>2] = $231;
     $244 = (($43) + 748|0);
     HEAPF32[$244>>2] = Math_fround(0.0);
     $245 = (($43) + 752|0);
     HEAPF32[$245>>2] = Math_fround(0.0);
     $246 = (($43) + 756|0);
     HEAPF32[$246>>2] = $225;
     $247 = (($43) + 760|0);
     HEAPF32[$247>>2] = $231;
     $248 = (($43) + 764|0);
     HEAPF32[$248>>2] = Math_fround(0.0);
     $249 = (($43) + 768|0);
     HEAPF32[$249>>2] = Math_fround(0.0);
     $250 = HEAP32[569184>>2]|0;
     $251 = HEAP32[569008>>2]|0;
     HEAP32[$8>>2] = $251;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$8+0>>2]|0;
     __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($250,$$byval_copy4,$shadowMap$0);
     $shadowMap$1 = $shadowMap$0;
    }
    $252 = HEAP32[$43>>2]|0;
    $253 = (($252) + 104|0);
    $254 = HEAP32[$253>>2]|0;
    $255 = (($mvpState) + 128|0);
    FUNCTION_TABLE_vii[$254 & 4095]($43,$255);
    $256 = HEAP32[$43>>2]|0;
    $257 = (($256) + 100|0);
    $258 = HEAP32[$257>>2]|0;
    $259 = (($mvpState) + 64|0);
    FUNCTION_TABLE_vii[$258 & 4095]($43,$259);
    __Z27SetClippingPlaneShaderPropsv();
    $260 = HEAP32[$43>>2]|0;
    $261 = (($260) + 136|0);
    $262 = HEAP32[$261>>2]|0;
    FUNCTION_TABLE_vii[$262 & 4095]($43,0);
    $shadowMap$2 = $shadowMap$1;
   }
  }
 } while(0);
 if ((label|0) == 48) {
  __Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE($passContext);
  $shadowMap$2 = 0;
 }
 $263 = (__ZN13RenderTexture9GetActiveEv()|0);
 $264 = ($263|0)==($rtLight|0);
 if (!($264)) {
  $265 = (($rtLight) + 140|0);
  $266 = HEAP32[$265>>2]|0;
  HEAP32[$rtSurfaceColor>>2] = $266;
  $267 = (($rtMain) + 148|0);
  $268 = HEAP32[$267>>2]|0;
  HEAP32[$9>>2] = $268;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$9+0>>2]|0;
  (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rtSurfaceColor,$$byval_copy4,$rtLight,0,-1,0)|0);
 }
 $269 = $lightPassAddBits;
 $270 = $269;
 HEAP32[$270>>2] = 64;
 $271 = (($269) + 4)|0;
 $272 = $271;
 HEAP32[$272>>2] = 0;
 $273 = ($$0$i|0)==(0);
 if ($273) {
  HEAP32[$lightPassAddBits>>2] = 0;
  $lightPassCount$0 = 1;
 } else {
  $274 = ($$0$i|0)!=(1);
  $275 = ($lightmapsMode|0)==(1);
  $or$cond2 = $274 | $275;
  if ($or$cond2) {
   $lightPassCount$0 = 2;
  } else {
   HEAP32[$lightPassAddBits>>2] = 64;
   $lightPassCount$0 = 1;
  }
 }
 $276 = HEAP8[$123>>0]|0;
 $277 = ($276<<24>>24)==(0);
 $278 = (($light) + 21|0);
 do {
  if ($277) {
   $279 = HEAP8[$278>>0]|0;
   $$not3 = ($279<<24>>24)!=(0);
   $$not4 = $273 ^ 1;
   $brmerge = $$not3 | $$not4;
   if ($brmerge) {
    label = 59;
   } else {
    $280 = HEAP32[$13>>2]|0;
    $281 = ($280|0)==(0);
    if ($281) {
     $282 = (__Z9LightMaskRK5LightRK14LightingLayers($12,$lightingLayers)|0);
     $328 = $282;
    } else {
     $284 = ($280|0)==(2);
     $285 = (__Z9LightMaskRK5LightRK14LightingLayers($12,$lightingLayers)|0);
     if ($284) {
      $328 = $285;
     } else {
      $426 = $285;$467 = 0;
      break;
     }
    }
    $286 = (__ZN5Unity8Material10GetDefaultEv()|0);
    $287 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($286,0,$passContext,0,1)|0);
    $288 = (($blendstate) + 4|0);
    HEAP8[$288>>0] = 1;
    $289 = (($blendstate) + 5|0);
    HEAP8[$289>>0] = 0;
    $290 = (($blendstate) + 6|0);
    HEAP8[$290>>0] = 1;
    $291 = (($blendstate) + 7|0);
    ;HEAP8[$291+0>>0]=0|0;HEAP8[$291+1>>0]=0|0;HEAP8[$291+2>>0]=0|0;HEAP8[$291+3>>0]=0|0;HEAP8[$291+4>>0]=0|0;
    HEAP32[$blendstate>>2] = 0;
    $292 = HEAP32[$43>>2]|0;
    $293 = (($292) + 52|0);
    $294 = HEAP32[$293>>2]|0;
    $295 = (($292) + 32|0);
    $296 = HEAP32[$295>>2]|0;
    $297 = (FUNCTION_TABLE_iii[$296 & 4095]($43,$blendstate)|0);
    FUNCTION_TABLE_viif[$294 & 63]($43,$297,Math_fround(0.0));
    $298 = $rasterstate;
    $299 = $298;
    HEAP32[$299>>2] = 0;
    $300 = (($298) + 4)|0;
    $301 = $300;
    HEAP32[$301>>2] = 0;
    $302 = (($rasterstate) + 4|0);
    HEAP32[$302>>2] = 0;
    $303 = (($rasterstate) + 8|0);
    HEAPF32[$303>>2] = Math_fround(0.0);
    HEAP32[$rasterstate>>2] = 0;
    $304 = HEAP32[$43>>2]|0;
    $305 = (($304) + 56|0);
    $306 = HEAP32[$305>>2]|0;
    $307 = (($304) + 44|0);
    $308 = HEAP32[$307>>2]|0;
    $309 = (FUNCTION_TABLE_iii[$308 & 4095]($43,$rasterstate)|0);
    FUNCTION_TABLE_vii[$306 & 4095]($43,$309);
    $310 = (($depthstate) + 1|0);
    HEAP8[$depthstate>>0] = 0;
    HEAP8[$310>>0] = 4;
    $311 = HEAP32[$43>>2]|0;
    $312 = (($311) + 60|0);
    $313 = HEAP32[$312>>2]|0;
    $314 = (($311) + 36|0);
    $315 = HEAP32[$314>>2]|0;
    $316 = (FUNCTION_TABLE_iii[$315 & 4095]($43,$depthstate)|0);
    FUNCTION_TABLE_vii[$313 & 4095]($43,$316);
    $317 = (($lightStencil) + 1|0);
    $318 = (($lightStencil) + 2|0);
    $319 = (($lightStencil) + 4|0);
    $320 = (($lightStencil) + 5|0);
    $321 = (($lightStencil) + 6|0);
    HEAP8[$321>>0] = 0;
    $322 = (($lightStencil) + 7|0);
    $323 = (($lightStencil) + 8|0);
    $324 = (($lightStencil) + 9|0);
    $325 = (($lightStencil) + 10|0);
    HEAP8[$325>>0] = 0;
    $326 = (($lightStencil) + 11|0);
    HEAP8[$lightStencil>>0] = 1;
    HEAP8[$317>>0] = -1;
    HEAP8[$318>>0] = 16;
    HEAP8[$326>>0] = 5;
    HEAP8[$322>>0] = 5;
    HEAP8[$324>>0] = 0;
    HEAP8[$320>>0] = 0;
    $327 = ($328|0)!=(0);
    $329 = $327 ? 6 : 8;
    HEAP8[$323>>0] = $329;
    HEAP8[$319>>0] = $329;
    $330 = HEAP32[$43>>2]|0;
    $331 = (($330) + 64|0);
    $332 = HEAP32[$331>>2]|0;
    $333 = (($330) + 40|0);
    $334 = HEAP32[$333>>2]|0;
    $335 = (FUNCTION_TABLE_iii[$334 & 4095]($43,$lightStencil)|0);
    $336 = $328 | 192;
    FUNCTION_TABLE_viii[$332 & 4095]($43,$335,$336);
    __Z15RenderLightGeomRK17RenderLoopContextRK11ActiveLightRK8Vector3fRK10Matrix4x4fbPK14ChannelAssigns($ctx,$light,$lightPos,$lightMatrix,$133,$287);
    HEAP32[$blendstate>>2] = 15;
    $337 = HEAP32[$43>>2]|0;
    $338 = (($337) + 52|0);
    $339 = HEAP32[$338>>2]|0;
    $340 = (($337) + 32|0);
    $341 = HEAP32[$340>>2]|0;
    $342 = (FUNCTION_TABLE_iii[$341 & 4095]($43,$blendstate)|0);
    FUNCTION_TABLE_viif[$339 & 63]($43,$342,Math_fround(0.0));
    $426 = $328;$467 = 1;
   }
  } else {
   label = 59;
  }
 } while(0);
 if ((label|0) == 59) {
  $283 = (__Z9LightMaskRK5LightRK14LightingLayers($12,$lightingLayers)|0);
  $426 = $283;$467 = 0;
 }
 $343 = HEAP32[$ctx>>2]|0;
 $344 = (($343) + 620|0);
 $345 = HEAP8[$344>>0]|0;
 $346 = ($345<<24>>24)!=(0);
 $347 = (($lightFade) + 8|0);
 $348 = (($lightFade) + 12|0);
 $349 = (($lightFade) + 4|0);
 $350 = (($12) + 124|0);
 $351 = (($43) + 676|0);
 $352 = (($43) + 684|0);
 $353 = (($43) + 688|0);
 $354 = (($43) + 772|0);
 $355 = (($43) + 776|0);
 $356 = (($43) + 780|0);
 $357 = (($43) + 784|0);
 $358 = $346 ? Math_fround(1.0) : Math_fround(2.0);
 $359 = (Math_fround(($346&1)));
 $360 = (($stencil) + 1|0);
 $361 = (($stencil) + 2|0);
 $362 = (($stencil) + 4|0);
 $363 = (($stencil) + 5|0);
 $364 = (($stencil) + 6|0);
 $365 = (($stencil) + 7|0);
 $366 = (($stencil) + 8|0);
 $367 = (($stencil) + 9|0);
 $368 = (($stencil) + 10|0);
 $369 = (($stencil) + 11|0);
 $370 = ($$0$i|0)==(1);
 $$6 = $370 ? -64 : -128;
 $$not7 = $370 ^ 1;
 $371 = (($rasterstate3) + 4|0);
 $372 = (($rasterstate3) + 8|0);
 $373 = (($depthstate4) + 1|0);
 $374 = $$6&255;
 $375 = $374 | 32;
 $376 = $375&255;
 $pp$029 = 0;
 while(1) {
  $377 = $lightFade;
  $378 = $377;
  $379 = HEAP32[$378>>2]|0;
  $380 = (($377) + 4)|0;
  $381 = $380;
  $382 = HEAP32[$381>>2]|0;
  $383 = Math_fround(HEAPF32[$347>>2]);
  $384 = Math_fround(HEAPF32[$348>>2]);
  $385 = Math_fround(HEAPF32[$349>>2]);
  $386 = Math_fround(HEAPF32[$350>>2]);
  $387 = Math_fround(Math_fround(1.0) - $386);
  $388 = ($pp$029|0)==(0);
  $brmerge5 = $388 | $273;
  $$19 = $brmerge5 ? Math_fround(0.0) : $384;
  $$20 = $brmerge5 ? Math_fround(0.0) : $383;
  $$21 = $brmerge5 ? $384 : Math_fround(0.0);
  $$22 = $brmerge5 ? $383 : Math_fround(0.0);
  $389 = $351;
  $390 = $389;
  HEAP32[$390>>2] = $379;
  $391 = (($389) + 4)|0;
  $392 = $391;
  HEAP32[$392>>2] = $382;
  HEAPF32[$352>>2] = $$20;
  HEAPF32[$353>>2] = $$19;
  HEAPF32[$354>>2] = $387;
  HEAPF32[$355>>2] = $385;
  HEAPF32[$356>>2] = $$22;
  HEAPF32[$357>>2] = $$21;
  $393 = HEAP32[569184>>2]|0;
  $394 = (($393) + 32|0);
  $395 = HEAP32[$394>>2]|0;
  $396 = ($395|0)==(0|0);
  if ($396) {
   __ZN5Unity8Material15BuildPropertiesEv($393);
   $$pre$i = HEAP32[$394>>2]|0;
   $398 = $$pre$i;
  } else {
   $398 = $395;
  }
  $397 = (($398) + 48|0);
  $399 = HEAP32[$397>>2]|0;
  $400 = (($398) + 48|0);
  $401 = ($399|0)==(0|0);
  if (!($401)) {
   $402 = HEAP32[568904>>2]|0;
   $$0$ph7$i$i$i$i = $400;$$01$ph6$i$in$i$i$i = $399;
   L93: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $403 = (($$013$i$in$i$i$i) + 16|0);
     $404 = HEAP32[$403>>2]|0;
     $405 = ($404|0)<($402|0);
     if (!($405)) {
      break;
     }
     $408 = (($$013$i$in$i$i$i) + 4|0);
     $409 = HEAP32[$408>>2]|0;
     $410 = ($409|0)==(0|0);
     if ($410) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L93;
     } else {
      $$013$i$in$i$i$i = $409;
     }
    }
    $406 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $407 = ($406|0)==(0|0);
    if ($407) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $406;
    }
   }
   $411 = ($$0$ph5$i$i$i$i|0)==($400|0);
   if (!($411)) {
    $412 = (($$0$ph5$i$i$i$i) + 16|0);
    $413 = HEAP32[$412>>2]|0;
    $414 = ($402|0)<($413|0);
    if (!($414)) {
     $415 = (($$0$ph5$i$i$i$i) + 20|0);
     $416 = HEAP32[$415>>2]|0;
     $417 = ($416|0)==(0|0);
     if (!($417)) {
      __ZN9ShaderLab6TexEnv21TextureMipBiasChangedEf($416,Math_fround(-8.0));
     }
    }
   }
  }
  $418 = HEAP32[569184>>2]|0;
  HEAP32[$$byval_copy4>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy4,569216);
  $419 = HEAP32[$$byval_copy4>>2]|0;
  HEAP32[$10>>2] = $419;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$10+0>>2]|0;
  __ZN5Unity8Material8SetFloatEN9ShaderLab16FastPropertyNameEf($418,$$byval_copy4,$358);
  $420 = HEAP32[569184>>2]|0;
  HEAP32[$$byval_copy4>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy4,569232);
  $421 = HEAP32[$$byval_copy4>>2]|0;
  HEAP32[$11>>2] = $421;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$11+0>>2]|0;
  __ZN5Unity8Material8SetFloatEN9ShaderLab16FastPropertyNameEf($420,$$byval_copy4,$359);
  $422 = HEAP32[569184>>2]|0;
  $423 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($422,0,$passContext,0,1)|0);
  HEAP8[$360>>0] = -1;
  HEAP8[$361>>0] = -1;
  HEAP8[$363>>0] = 0;
  HEAP8[$364>>0] = 0;
  HEAP8[$365>>0] = 0;
  HEAP8[$367>>0] = 0;
  HEAP8[$368>>0] = 0;
  HEAP8[$369>>0] = 0;
  HEAP8[$stencil>>0] = 1;
  HEAP8[$366>>0] = 3;
  HEAP8[$362>>0] = 3;
  $brmerge8 = $388 | $$not7;
  $$6$ = $brmerge8 ? $$6 : $376;
  $424 = $$6$&255;
  $425 = $424 | $426;
  $427 = $425&255;
  HEAP8[$360>>0] = $427;
  $428 = (($lightPassAddBits) + ($pp$029<<2)|0);
  $429 = HEAP32[$428>>2]|0;
  $430 = (($429) + 128)|0;
  if ($467) {
   HEAP8[$361>>0] = 16;
   HEAP8[$369>>0] = 1;
   HEAP8[$365>>0] = 1;
   HEAP8[$367>>0] = 1;
   HEAP8[$363>>0] = 1;
   HEAP8[$368>>0] = 1;
   HEAP8[$364>>0] = 1;
   $431 = $425 | 16;
   $432 = $431&255;
   HEAP8[$360>>0] = $432;
   $433 = $430 | 16;
   $stencilRef$0 = $433;
  } else {
   $stencilRef$0 = $430;
  }
  $434 = HEAP32[$43>>2]|0;
  $435 = (($434) + 40|0);
  $436 = HEAP32[$435>>2]|0;
  $437 = (FUNCTION_TABLE_iii[$436 & 4095]($43,$stencil)|0);
  $438 = HEAP32[$43>>2]|0;
  $439 = (($438) + 64|0);
  $440 = HEAP32[$439>>2]|0;
  FUNCTION_TABLE_viii[$440 & 4095]($43,$437,$stencilRef$0);
  $441 = $rasterstate3;
  $442 = $441;
  HEAP32[$442>>2] = 0;
  $443 = (($441) + 4)|0;
  $444 = $443;
  HEAP32[$444>>2] = 0;
  HEAP32[$rasterstate3>>2] = 2;
  HEAP32[$371>>2] = 0;
  HEAPF32[$372>>2] = Math_fround(0.0);
  HEAP8[$373>>0] = 2;
  HEAP8[$depthstate4>>0] = 0;
  $445 = HEAP8[$123>>0]|0;
  $446 = ($445<<24>>24)==(0);
  if ($446) {
   $storemerge24 = 4;
  } else {
   $447 = HEAP8[$278>>0]|0;
   $448 = ($447<<24>>24)==(0);
   if ($448) {
    $449 = HEAP32[$13>>2]|0;
    if ((($449|0) == 2) | (($449|0) == 0)) {
     HEAP32[$rasterstate3>>2] = 1;
     $storemerge24 = 5;
    } else {
     $storemerge24 = 4;
    }
   } else {
    $storemerge24 = 4;
   }
  }
  HEAP8[$373>>0] = $storemerge24;
  $450 = HEAP32[$43>>2]|0;
  $451 = (($450) + 56|0);
  $452 = HEAP32[$451>>2]|0;
  $453 = (($450) + 44|0);
  $454 = HEAP32[$453>>2]|0;
  $455 = (FUNCTION_TABLE_iii[$454 & 4095]($43,$rasterstate3)|0);
  FUNCTION_TABLE_vii[$452 & 4095]($43,$455);
  $456 = HEAP32[$43>>2]|0;
  $457 = (($456) + 60|0);
  $458 = HEAP32[$457>>2]|0;
  $459 = (($456) + 36|0);
  $460 = HEAP32[$459>>2]|0;
  $461 = (FUNCTION_TABLE_iii[$460 & 4095]($43,$depthstate4)|0);
  FUNCTION_TABLE_vii[$458 & 4095]($43,$461);
  __Z15RenderLightGeomRK17RenderLoopContextRK11ActiveLightRK8Vector3fRK10Matrix4x4fbPK14ChannelAssigns($ctx,$light,$lightPos,$lightMatrix,$133,$423);
  $462 = (($pp$029) + 1)|0;
  $463 = ($462|0)<($lightPassCount$0|0);
  if ($463) {
   $pp$029 = $462;
  } else {
   break;
  }
 }
 $464 = ($shadowMap$2|0)==(0|0);
 $brmerge9 = $464 | $returnShadowMap;
 if ($brmerge9) {
  $466 = $returnShadowMap ? $shadowMap$2 : 0;
  STACKTOP = sp;return ($466|0);
 }
 $465 = (__Z22GetRenderBufferManagerv()|0);
 __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($465,$shadowMap$2);
 $466 = $returnShadowMap ? $shadowMap$2 : 0;
 STACKTOP = sp;return ($466|0);
}
function __ZN18DeferredRenderLoop13RenderGBufferEP13RenderTextureRK14LightingLayersR13dynamic_arrayI16RenderObjectDataLj4EER10MinMaxAABBPS1_bb($this,$rtMain,$lightingLayers,$outRemainingObjects,$receiverBounds,$outGBuffer,$rtMainAsEmission,$linearLighting) {
 $this = $this|0;
 $rtMain = $rtMain|0;
 $lightingLayers = $lightingLayers|0;
 $outRemainingObjects = $outRemainingObjects|0;
 $receiverBounds = $receiverBounds|0;
 $outGBuffer = $outGBuffer|0;
 $rtMainAsEmission = $rtMainAsEmission|0;
 $linearLighting = $linearLighting|0;
 var $$ = 0, $$8 = 0, $$9 = 0, $$byval_copy14 = 0, $$off$i = 0, $$off0 = 0, $$off0$ = 0, $$old24 = 0, $$pre = 0, $$pre$i = 0, $$sink$i$i$i = Math_fround(0), $$sink$i1$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0);
 var $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0;
 var $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0;
 var $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0);
 var $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = 0, $446 = Math_fround(0), $447 = Math_fround(0);
 var $448 = 0, $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0);
 var $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = 0, $475 = Math_fround(0), $476 = 0, $477 = Math_fround(0), $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0;
 var $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = 0, $535 = Math_fround(0), $536 = Math_fround(0), $537 = 0;
 var $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = Math_fround(0), $543 = 0, $544 = Math_fround(0), $545 = Math_fround(0), $546 = 0, $547 = Math_fround(0), $548 = Math_fround(0), $549 = 0, $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0);
 var $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = 0, $565 = Math_fround(0), $566 = 0, $567 = Math_fround(0), $568 = 0, $569 = Math_fround(0), $57 = 0, $570 = 0, $571 = Math_fround(0), $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0;
 var $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = Math_fround(0), $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = Math_fround(0), $605 = 0, $606 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ambientAndLightProbeSH = 0;
 var $batchRenderer = 0, $black = 0, $channels$047 = 0, $channels$135 = 0, $channels$135$us = 0, $channels$2 = 0, $channels$2$us = 0, $channels$3 = 0, $channels$3$us = 0, $channels$4 = 0, $defaultReflection = 0, $exitcond = 0, $formats = 0, $i$01$i$i$i = 0, $i$049 = 0, $index$044 = 0, $lightmapSTCache = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, $notlhs = 0;
 var $notlhs27 = 0, $notrhs = 0, $notrhs28 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond10$us = 0, $or$cond20 = 0, $or$cond21 = 0, $or$cond22$not = 0, $or$cond23$not = 0, $or$cond25 = 0, $or$cond26 = 0, $p$037 = 0, $p$037$us = 0, $phitmp2 = 0, $prevPassIndex$046 = 0, $prevPassIndex$134 = 0, $prevPassIndex$134$us = 0, $prevPassIndex$4 = 0, $prevPassIndex$4$us = 0;
 var $prevPassIndex$5 = 0, $prevStencilRef$045 = 0, $prevStencilRef$133 = 0, $prevStencilRef$133$us = 0, $prevStencilRef$3 = 0, $prevStencilRef$3$us = 0, $prevStencilRef$4 = 0, $prevStencilRef$4$us = 0, $prevStencilRef$5 = 0, $reflection = 0, $reflectionProbeCache = 0, $resetPass$0$off0 = 0, $resetPass$1$off036 = 0, $resetPass$1$off036$us = 0, $resetPass$2$off018 = 0, $resetPass$2$off018$us = 0, $resetPass$3$off0 = 0, $resetPass$3$off0$us = 0, $rsColors = 0, $rsColorsToClear = 0;
 var $rtCountToClear$051 = 0, $rtCountToClear$1 = 0, $rtFlags$1 = 0, $shConstantCache = 0, $ss$0 = 0, $stRender = 0, $stats = 0, $stencilRef$0$ = 0, $stencilRef$0$$us = 0, $stencilRef$2 = 0, $stencilRef$2$us = 0, $withinShadowDistance$0$off0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 912|0;
 $$byval_copy14 = sp + 900|0;
 $0 = sp + 896|0;
 $1 = sp + 892|0;
 $2 = sp + 888|0;
 $3 = sp + 884|0;
 $stRender = sp + 872|0;
 $formats = sp + 856|0;
 $rsColors = sp + 840|0;
 $rsColorsToClear = sp + 824|0;
 $4 = sp + 144|0;
 $black = sp;
 $5 = sp + 16|0;
 $defaultReflection = sp + 20|0;
 $stats = sp + 904|0;
 $batchRenderer = sp + 148|0;
 $shConstantCache = sp + 224|0;
 $reflectionProbeCache = sp + 448|0;
 $lightmapSTCache = sp + 580|0;
 $ambientAndLightProbeSH = sp + 592|0;
 $reflection = sp + 700|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 580|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = HEAP32[652824>>2]|0;
 $12 = (__Z12GetGfxDevicev()|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 136|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($12,0);
 $16 = (($stRender) + 1|0);
 HEAP8[$16>>0] = -1;
 $17 = (($stRender) + 2|0);
 $18 = (($stRender) + 4|0);
 HEAP8[$18>>0] = 8;
 $19 = (($stRender) + 5|0);
 $20 = (($stRender) + 6|0);
 HEAP8[$20>>0] = 0;
 $21 = (($stRender) + 7|0);
 HEAP8[$21>>0] = 0;
 $22 = (($stRender) + 8|0);
 HEAP8[$22>>0] = 8;
 $23 = (($stRender) + 9|0);
 $24 = (($stRender) + 10|0);
 HEAP8[$24>>0] = 0;
 $25 = (($stRender) + 11|0);
 HEAP8[$25>>0] = 0;
 HEAP8[$17>>0] = -17;
 HEAP8[$stRender>>0] = 1;
 HEAP8[$23>>0] = 2;
 HEAP8[$19>>0] = 2;
 $26 = HEAP32[$12>>2]|0;
 $27 = (($26) + 40|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_iii[$28 & 4095]($12,$stRender)|0);
 ;HEAP32[$formats+0>>2]=0|0;HEAP32[$formats+4>>2]=0|0;HEAP32[$formats+8>>2]=0|0;HEAP32[$formats+12>>2]=0|0;
 $30 = HEAP8[((640792 + 209|0))>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if (!($31)) {
  $32 = (($formats) + 8|0);
  HEAP32[$32>>2] = 8;
  $33 = (($formats) + 12|0);
  HEAP32[$33>>2] = 8;
 }
 $34 = (__Z22GetRenderBufferManagerv()|0);
 ;HEAP32[$rsColors+0>>2]=0|0;HEAP32[$rsColors+4>>2]=0|0;HEAP32[$rsColors+8>>2]=0|0;HEAP32[$rsColors+12>>2]=0|0;
 ;HEAP32[$rsColorsToClear+0>>2]=0|0;HEAP32[$rsColorsToClear+4>>2]=0|0;HEAP32[$rsColorsToClear+8>>2]=0|0;HEAP32[$rsColorsToClear+12>>2]=0|0;
 $35 = (($rtMain) + 140|0);
 $i$049 = 0;$rtCountToClear$051 = 0;
 while(1) {
  $36 = ($i$049|0)==(3);
  $or$cond = $36 & $rtMainAsEmission;
  if ($or$cond) {
   $37 = HEAP32[$35>>2]|0;
   $38 = (($rsColors) + 12|0);
   HEAP32[$38>>2] = $37;
   $39 = (($outGBuffer) + 12|0);
   HEAP32[$39>>2] = $rtMain;
   $rtCountToClear$1 = $rtCountToClear$051;
  } else {
   $40 = (($formats) + ($i$049<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (569144 + ($i$049<<2)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($34,-1,-1,0,$41,0,$43,1)|0);
   $45 = ($44|0)==(0|0);
   if (!($45)) {
    $46 = HEAP32[$44>>2]|0;
    $47 = (($46) + 36|0);
    $48 = HEAP32[$47>>2]|0;
    FUNCTION_TABLE_vii[$48 & 4095]($44,569160);
   }
   __ZN7Texture13SetFilterModeEi($44,0);
   $49 = (($44) + 140|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    $52 = (($44) + 148|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     (__ZN13RenderTexture6CreateEv($44)|0);
     $$pre = HEAP32[$49>>2]|0;
     $57 = $$pre;
    } else {
     $57 = 0;
    }
   } else {
    $57 = $50;
   }
   $55 = (($rtCountToClear$051) + 1)|0;
   $56 = (($rsColorsToClear) + ($rtCountToClear$051<<2)|0);
   HEAP32[$56>>2] = $57;
   $58 = (($rsColors) + ($i$049<<2)|0);
   HEAP32[$58>>2] = $57;
   $59 = (($outGBuffer) + ($i$049<<2)|0);
   HEAP32[$59>>2] = $44;
   $60 = HEAP32[$this>>2]|0;
   $61 = (($60) + 116|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($i$049) + 11)|0;
   __Z23AddRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureTypeP13RenderTexture($62,$63,$44);
   $rtCountToClear$1 = $55;
  }
  $64 = (($i$049) + 1)|0;
  $exitcond = ($64|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $i$049 = $64;$rtCountToClear$051 = $rtCountToClear$1;
  }
 }
 $65 = (($rtMain) + 148|0);
 $66 = HEAP32[$65>>2]|0;
 if ($rtMainAsEmission) {
  __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($rtMain,0,-1,1);
  $67 = HEAP32[$this>>2]|0;
  $68 = HEAP32[$67>>2]|0;
  __ZN6Camera13ClearNoSkyboxEb($68,1);
 }
 $69 = HEAP32[$this>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + 376|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(4);
 $$ = $73 ? 1 : 7;
 $$8 = $73 ? 4 : 12;
 $74 = $rtMainAsEmission&1;
 $rtFlags$1 = $$8 | $74;
 HEAP32[$4>>2] = $66;
 $75 = HEAP32[$outGBuffer>>2]|0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$4+0>>2]|0;
 (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej($rtCountToClear$1,$rsColorsToClear,$$byval_copy14,$75,0,-1,$rtFlags$1)|0);
 ;HEAP32[$black+0>>2]=0|0;HEAP32[$black+4>>2]=0|0;HEAP32[$black+8>>2]=0|0;HEAP32[$black+12>>2]=0|0;
 __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE($$,$black,Math_fround(1.0),0,$11);
 if ($rtMainAsEmission) {
  HEAP32[$5>>2] = $66;
  $76 = HEAP32[$outGBuffer>>2]|0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
  (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(4,$rsColors,$$byval_copy14,$76,0,-1,$rtFlags$1)|0);
 }
 $77 = HEAP32[$12>>2]|0;
 $78 = (($77) + 72|0);
 $79 = HEAP32[$78>>2]|0;
 FUNCTION_TABLE_vii[$79 & 4095]($12,$linearLighting);
 $80 = HEAP32[$12>>2]|0;
 $81 = (($80) + 100|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$this>>2]|0;
 $84 = (($83) + 12|0);
 FUNCTION_TABLE_vii[$82 & 4095]($12,$84);
 $85 = HEAP32[$this>>2]|0;
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($87,4,$11);
 $88 = (__Z19GetLightmapSettingsv()|0);
 $89 = (__ZNK16LightmapSettings19AreLightProbesBakedEv($88)|0);
 if ($89) {
  $90 = (__ZNK16LightmapSettings22GetLightmapsModeLegacyEv($88)|0);
  $91 = ($90|0)==(1);
  if ($91) {
   $92 = (($88) + 84|0);
   $93 = HEAP32[$92>>2]|0;
   $phitmp2 = ($93|0)!=(2);
   $$off0 = $phitmp2;
  } else {
   $$off0 = 1;
  }
 } else {
  $$off0 = 0;
 }
 $94 = (__ZNK16LightmapSettings23HasLightProbeTetrahedraEv($88)|0);
 $$off0$ = $94 & $$off0;
 $95 = (__Z17GetRenderSettingsv()|0);
 $96 = (($95) + 296|0);
 $97 = (__Z19GetReflectionProbesv()|0);
 __ZNK16ReflectionProbes16GetDefaultSampleEv($defaultReflection,$97);
 __Z14SetupLightmapsRK16LightmapSettings($88);
 __ZN13BatchRendererC2ER15RenderLoopStats($batchRenderer,$stats);
 __THREW__ = 0;
 invoke_viii(1659,($shConstantCache|0),($batchRenderer|0),($stats|0));
 $98 = __THREW__; __THREW__ = 0;
 $99 = $98&1;
 L28: do {
  if ($99) {
   label = 35;
  } else {
   __THREW__ = 0;
   invoke_viii(1660,($reflectionProbeCache|0),($batchRenderer|0),($stats|0));
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if ($101) {
    label = 35;
   } else {
    __THREW__ = 0;
    invoke_viii(1661,($lightmapSTCache|0),($batchRenderer|0),($stats|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 35;
    } else {
     $104 = (($this) + 4|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = (($105) + 8|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = $107 >>> 4;
     $109 = (($outRemainingObjects) + 12|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = $110 & 2147483647;
     $112 = ($111>>>0)<($108>>>0);
     do {
      if ($112) {
       $113 = ($110|0)>(-1);
       if ($113) {
        HEAP32[$109>>2] = $108;
        $114 = HEAP32[$outRemainingObjects>>2]|0;
        $115 = ($108*44)|0;
        $116 = (($outRemainingObjects) + 4|0);
        $117 = HEAP32[$116>>2]|0;
        HEAP32[$0>>2] = $117;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
        $118 = (invoke_iiiiiiii(108,($114|0),($115|0),4,($$byval_copy14|0),0,(569192|0),370)|0);
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         label = 35;
         break L28;
        }
        HEAP32[$outRemainingObjects>>2] = $118;
        break;
       } else {
        $121 = ($108*44)|0;
        $122 = (($outRemainingObjects) + 4|0);
        $123 = HEAP32[$122>>2]|0;
        HEAP32[$1>>2] = $123;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
        $124 = (invoke_iiiiiii(102,($121|0),4,($$byval_copy14|0),0,(569192|0),352)|0);
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         label = 35;
         break L28;
        }
        $127 = HEAP32[$outRemainingObjects>>2]|0;
        $128 = (($outRemainingObjects) + 8|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = ($129*44)|0;
        _memcpy(($124|0),($127|0),($130|0))|0;
        HEAP32[$109>>2] = $108;
        HEAP32[$outRemainingObjects>>2] = $124;
        break;
       }
      }
     } while(0);
     $131 = ($107|0)==(0);
     L40: do {
      if (!($131)) {
       $132 = (($this) + 8|0);
       $133 = (($receiverBounds) + 4|0);
       $134 = (($receiverBounds) + 8|0);
       $135 = (($receiverBounds) + 12|0);
       $136 = (($receiverBounds) + 16|0);
       $137 = (($receiverBounds) + 20|0);
       $138 = (($outRemainingObjects) + 8|0);
       $139 = (($outRemainingObjects) + 4|0);
       $140 = (($shConstantCache) + 108|0);
       $141 = (($12) + 5920|0);
       $142 = (($reflectionProbeCache) + 128|0);
       $143 = (($shConstantCache) + 216|0);
       $315 = 0;$317 = 0;$319 = -1;$321 = Math_fround(-1.0);$337 = 16711935;$339 = -1;$channels$047 = 0;$index$044 = 0;$prevPassIndex$046 = -1;$prevStencilRef$045 = 0;
       L42: while(1) {
        $144 = HEAP32[$132>>2]|0;
        $145 = HEAP32[$104>>2]|0;
        $146 = (($144) + ($index$044<<2)|0);
        $147 = HEAP32[$146>>2]|0;
        $148 = HEAP32[$145>>2]|0;
        $149 = (($148) + (($147*44)|0)|0);
        $150 = ((($148) + (($147*44)|0)|0) + 36|0);
        $151 = HEAP32[$150>>2]|0;
        $152 = ((($148) + (($147*44)|0)|0) + 8|0);
        $153 = HEAP16[$152>>1]|0;
        $154 = $153 << 16 >> 16;
        $155 = ($153<<16>>16)==(-1);
        if ($155) {
         $156 = (($151) + 52|0);
         $157 = HEAP32[$156>>2]|0;
         $158 = (($157) + 28|0);
         $159 = HEAP32[$158>>2]|0;
         $ss$0 = $159;
        } else {
         $ss$0 = $154;
        }
        $168 = ((($148) + (($147*44)|0)|0) + 32|0);
        $169 = HEAP32[$168>>2]|0;
        $170 = ((($148) + (($147*44)|0)|0) + 28|0);
        $171 = Math_fround(HEAPF32[$170>>2]);
        $172 = $171 > $10;
        if ($172) {
         $173 = HEAP32[$this>>2]|0;
         $174 = (($173) + 20|0);
         $175 = Math_fround(HEAPF32[$174>>2]);
         $176 = $175 < Math_fround(0.0);
         if ($176) {
          $177 = Math_fround(-$175);
          $181 = $177;
         } else {
          $181 = $175;
         }
         $178 = (($169) + 76|0);
         $179 = Math_fround(HEAPF32[$178>>2]);
         $180 = Math_fround($181 * $179);
         $182 = (($173) + 36|0);
         $183 = Math_fround(HEAPF32[$182>>2]);
         $184 = $183 < Math_fround(0.0);
         if ($184) {
          $185 = Math_fround(-$183);
          $189 = $185;
         } else {
          $189 = $183;
         }
         $186 = (($169) + 80|0);
         $187 = Math_fround(HEAPF32[$186>>2]);
         $188 = Math_fround($189 * $187);
         $190 = Math_fround($180 + $188);
         $191 = (($173) + 52|0);
         $192 = Math_fround(HEAPF32[$191>>2]);
         $193 = $192 < Math_fround(0.0);
         if ($193) {
          $194 = Math_fround(-$192);
          $198 = $194;
         } else {
          $198 = $192;
         }
         $195 = (($169) + 84|0);
         $196 = Math_fround(HEAPF32[$195>>2]);
         $197 = Math_fround($198 * $196);
         $199 = Math_fround($190 + $197);
         $200 = Math_fround($171 - $199);
         $201 = $200 > $10;
         if ($201) {
          $withinShadowDistance$0$off0 = 0;
         } else {
          $withinShadowDistance$0$off0 = 1;
         }
        } else {
         $withinShadowDistance$0$off0 = 1;
        }
        $202 = ($ss$0|0)==(-1);
        do {
         if ($202) {
          if ($withinShadowDistance$0$off0) {
           $203 = (($169) + 116|0);
           $204 = HEAP32[$203>>2]|0;
           $205 = (($204) + 42|0);
           $206 = HEAP8[$205>>0]|0;
           $207 = ($206<<24>>24)==(0);
           if (!($207)) {
            $208 = (($169) + 64|0);
            $209 = Math_fround(HEAPF32[$208>>2]);
            $210 = (($169) + 76|0);
            $211 = Math_fround(HEAPF32[$210>>2]);
            $212 = Math_fround($209 + $211);
            $213 = (($169) + 68|0);
            $214 = Math_fround(HEAPF32[$213>>2]);
            $215 = (($169) + 80|0);
            $216 = Math_fround(HEAPF32[$215>>2]);
            $217 = Math_fround($214 + $216);
            $218 = (($169) + 72|0);
            $219 = Math_fround(HEAPF32[$218>>2]);
            $220 = (($169) + 84|0);
            $221 = Math_fround(HEAPF32[$220>>2]);
            $222 = Math_fround($219 + $221);
            $223 = Math_fround(HEAPF32[$receiverBounds>>2]);
            $224 = $212 < $223;
            $225 = $224 ? $212 : $223;
            $226 = Math_fround(HEAPF32[$133>>2]);
            $227 = $217 < $226;
            $228 = $227 ? $217 : $226;
            $229 = Math_fround(HEAPF32[$134>>2]);
            $230 = $222 < $229;
            $231 = $230 ? $222 : $229;
            HEAPF32[$receiverBounds>>2] = $225;
            HEAPF32[$133>>2] = $228;
            HEAPF32[$134>>2] = $231;
            $232 = Math_fround(HEAPF32[$135>>2]);
            $233 = $232 < $212;
            $234 = $233 ? $212 : $232;
            $235 = Math_fround(HEAPF32[$136>>2]);
            $236 = $235 < $217;
            $237 = $236 ? $217 : $235;
            $238 = Math_fround(HEAPF32[$137>>2]);
            $239 = $238 < $222;
            $240 = $239 ? $222 : $238;
            HEAPF32[$135>>2] = $234;
            HEAPF32[$136>>2] = $237;
            HEAPF32[$137>>2] = $240;
            $241 = Math_fround(HEAPF32[$208>>2]);
            $242 = Math_fround(HEAPF32[$210>>2]);
            $243 = Math_fround($241 - $242);
            $244 = Math_fround(HEAPF32[$213>>2]);
            $245 = Math_fround(HEAPF32[$215>>2]);
            $246 = Math_fround($244 - $245);
            $247 = Math_fround(HEAPF32[$218>>2]);
            $248 = Math_fround(HEAPF32[$220>>2]);
            $249 = Math_fround($247 - $248);
            $250 = $243 < $225;
            $251 = $250 ? $243 : $225;
            $252 = $246 < $228;
            $253 = $252 ? $246 : $228;
            $254 = $249 < $231;
            $255 = $254 ? $249 : $231;
            HEAPF32[$receiverBounds>>2] = $251;
            HEAPF32[$133>>2] = $253;
            HEAPF32[$134>>2] = $255;
            $256 = $234 < $243;
            $257 = $256 ? $243 : $234;
            $258 = $237 < $246;
            $259 = $258 ? $246 : $237;
            $260 = $240 < $249;
            $261 = $260 ? $249 : $240;
            HEAPF32[$135>>2] = $257;
            HEAPF32[$136>>2] = $259;
            HEAPF32[$137>>2] = $261;
           }
          }
          $262 = HEAP32[$138>>2]|0;
          $263 = (($262) + 1)|0;
          HEAP32[$138>>2] = $263;
          $264 = HEAP32[$109>>2]|0;
          $265 = $264 & 2147483647;
          $266 = ($263>>>0)>($265>>>0);
          if ($266) {
           $267 = $264 << 1;
           $268 = ($267|0)==(0);
           $269 = $268 ? 1 : $267;
           $270 = ($265>>>0)<($269>>>0);
           do {
            if ($270) {
             $271 = ($264|0)>(-1);
             if ($271) {
              HEAP32[$109>>2] = $269;
              $272 = HEAP32[$outRemainingObjects>>2]|0;
              $273 = ($269*44)|0;
              $274 = HEAP32[$139>>2]|0;
              HEAP32[$2>>2] = $274;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
              $275 = (invoke_iiiiiiii(108,($272|0),($273|0),4,($$byval_copy14|0),0,(569192|0),370)|0);
              $276 = __THREW__; __THREW__ = 0;
              $277 = $276&1;
              if ($277) {
               label = 34;
               break L42;
              }
              HEAP32[$outRemainingObjects>>2] = $275;
              break;
             } else {
              $278 = ($269*44)|0;
              $279 = HEAP32[$139>>2]|0;
              HEAP32[$3>>2] = $279;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
              $280 = (invoke_iiiiiii(102,($278|0),4,($$byval_copy14|0),0,(569192|0),352)|0);
              $281 = __THREW__; __THREW__ = 0;
              $282 = $281&1;
              if ($282) {
               label = 34;
               break L42;
              }
              $283 = HEAP32[$outRemainingObjects>>2]|0;
              $284 = HEAP32[$138>>2]|0;
              $285 = ($284*44)|0;
              _memcpy(($280|0),($283|0),($285|0))|0;
              HEAP32[$109>>2] = $269;
              HEAP32[$outRemainingObjects>>2] = $280;
              break;
             }
            }
           } while(0);
           $$pre$i = HEAP32[$138>>2]|0;
           $287 = $$pre$i;
          } else {
           $287 = $263;
          }
          $286 = (($287) + -1)|0;
          $288 = HEAP32[$outRemainingObjects>>2]|0;
          $289 = (($288) + (($286*44)|0)|0);
          dest=$289+0|0; src=$149+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
          $595 = $319;$596 = $339;$597 = $337;$598 = $321;$599 = $317;$600 = $315;$channels$4 = $channels$047;$prevPassIndex$5 = $prevPassIndex$046;$prevStencilRef$5 = $prevStencilRef$045;
         } else {
          $290 = (($169) + 116|0);
          $291 = HEAP32[$290>>2]|0;
          $292 = ((($148) + (($147*44)|0)|0) + 12|0);
          $293 = HEAP16[$292>>1]|0;
          $$off$i = (($293) + -254)<<16>>16;
          $294 = ($$off$i&65535)>(1);
          __THREW__ = 0;
          $295 = (invoke_iiii(1533,($291|0),($$off0$|0),($$off0|0))|0);
          $296 = __THREW__; __THREW__ = 0;
          $297 = $296&1;
          if ($297) {
           label = 34;
           break L42;
          }
          $298 = HEAP32[$168>>2]|0;
          $299 = (($298) + 120|0);
          $300 = Math_fround(HEAPF32[$299>>2]);
          $301 = HEAP32[$149>>2]|0;
          $302 = HEAP32[$150>>2]|0;
          $303 = HEAP16[$152>>1]|0;
          $304 = $303 << 16 >> 16;
          $305 = (($298) + 116|0);
          $306 = HEAP32[$305>>2]|0;
          $307 = (($306) + 168|0);
          $308 = HEAP32[$307>>2]|0;
          $309 = ($308|0)==(0|0);
          if ($309) {
           $340 = 0;
          } else {
           $310 = (($308) + 32|0);
           $311 = HEAP32[$310>>2]|0;
           $340 = $311;
          }
          $312 = ((($148) + (($147*44)|0)|0) + 12|0);
          $313 = HEAP32[$312>>2]|0;
          $314 = ($315|0)==($301|0);
          $316 = ($317|0)==($302|0);
          $or$cond20 = $314 & $316;
          $318 = ($319|0)==($304|0);
          $or$cond21 = $or$cond20 & $318;
          do {
           if ($or$cond21) {
            $320 = $321 > Math_fround(0.0);
            $322 = $320&1;
            $323 = $321 < Math_fround(0.0);
            $324 = $323&1;
            $325 = (($322) - ($324))|0;
            $326 = $300 > Math_fround(0.0);
            $327 = $326&1;
            $328 = $300 < Math_fround(0.0);
            $329 = $328&1;
            $330 = (($327) - ($329))|0;
            $331 = ($325|0)==($330|0);
            if (!($331)) {
             label = 73;
             break;
            }
            $332 = ($325|0)<(0);
            if ($332) {
             $333 = Math_fround($321 - $300);
             $334 = $333 < Math_fround(0.0);
             if ($334) {
              $335 = Math_fround(-$333);
              $336 = $335;
             } else {
              $336 = $333;
             }
             $notlhs27 = !($336 <= Math_fround(9.99999997475242707878E-7));
             $notrhs28 = ($337|0)!=($313|0);
             $or$cond23$not = $notrhs28 | $notlhs27;
             $338 = ($339|0)!=($340|0);
             $or$cond25 = $or$cond23$not | $338;
             if ($or$cond25) {
              label = 73;
              break;
             }
            } else {
             $341 = Math_fround($321 * Math_fround(16.0));
             $342 = !($341 >= Math_fround(0.0));
             if ($342) {
              $343 = Math_fround($341 + Math_fround(-0.999999940395355224609));
              $$sink$i1$i$i = $343;
             } else {
              $$sink$i1$i$i = $341;
             }
             $344 = (~~(($$sink$i1$i$i)));
             $345 = Math_fround($300 * Math_fround(16.0));
             $346 = !($345 >= Math_fround(0.0));
             if ($346) {
              $347 = Math_fround($345 + Math_fround(-0.999999940395355224609));
              $$sink$i$i$i = $347;
             } else {
              $$sink$i$i$i = $345;
             }
             $348 = (~~(($$sink$i$i$i)));
             $notlhs = ($344|0)!=($348|0);
             $notrhs = ($337|0)!=($313|0);
             $or$cond22$not = $notrhs | $notlhs;
             $$old24 = ($339|0)!=($340|0);
             $or$cond26 = $or$cond22$not | $$old24;
             if ($or$cond26) {
              label = 73;
              break;
             }
            }
            __THREW__ = 0;
            $353 = (invoke_iif(27,($151|0),(+$300))|0);
            $354 = __THREW__; __THREW__ = 0;
            $355 = $354&1;
            if ($355) {
             label = 34;
             break L42;
            }
            if (!($353)) {
             $601 = $319;$602 = $339;$603 = $337;$604 = $321;$605 = $317;$606 = $315;$resetPass$0$off0 = 0;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3398,($batchRenderer|0));
            $356 = __THREW__; __THREW__ = 0;
            $357 = $356&1;
            if ($357) {
             label = 34;
             break L42;
            } else {
             $601 = $319;$602 = $339;$603 = $337;$604 = $321;$605 = $317;$606 = $315;$resetPass$0$off0 = 0;
            }
           } else {
            label = 73;
           }
          } while(0);
          if ((label|0) == 73) {
           label = 0;
           __THREW__ = 0;
           invoke_vi(3398,($batchRenderer|0));
           $349 = __THREW__; __THREW__ = 0;
           $350 = $349&1;
           if ($350) {
            label = 34;
            break L42;
           }
           __THREW__ = 0;
           invoke_viif(41,($12|0),($11|0),(+$300));
           $351 = __THREW__; __THREW__ = 0;
           $352 = $351&1;
           if ($352) {
            label = 34;
            break L42;
           } else {
            $601 = $304;$602 = $340;$603 = $313;$604 = $300;$605 = $302;$606 = $301;$resetPass$0$off0 = 1;
           }
          }
          $358 = HEAP32[$290>>2]|0;
          __THREW__ = 0;
          invoke_vii(2612,($lightmapSTCache|0),($358|0));
          $359 = __THREW__; __THREW__ = 0;
          $360 = $359&1;
          if ($360) {
           label = 34;
           break L42;
          }
          dest=$ambientAndLightProbeSH+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          __THREW__ = 0;
          invoke_viiii(338,($169|0),($96|0),($89|0),($ambientAndLightProbeSH|0));
          $361 = __THREW__; __THREW__ = 0;
          $362 = $361&1;
          if ($362) {
           label = 34;
           break L42;
          } else {
           $i$01$i$i$i = 0;
          }
          while(1) {
           $365 = (($140) + ($i$01$i$i$i<<2)|0);
           $366 = HEAP32[$365>>2]|0;
           $367 = (($ambientAndLightProbeSH) + ($i$01$i$i$i<<2)|0);
           $368 = HEAP32[$367>>2]|0;
           $369 = ($366|0)==($368|0);
           $364 = (($i$01$i$i$i) + 1)|0;
           if (!($369)) {
            label = 82;
            break;
           }
           $363 = ($364|0)<(27);
           if ($363) {
            $i$01$i$i$i = $364;
           } else {
            break;
           }
          }
          if ((label|0) == 82) {
           label = 0;
           dest=$140+0|0; src=$ambientAndLightProbeSH+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           $370 = HEAP32[$143>>2]|0;
           __THREW__ = 0;
           invoke_vii(2613,($370|0),($ambientAndLightProbeSH|0));
           $371 = __THREW__; __THREW__ = 0;
           $372 = $371&1;
           if ($372) {
            label = 34;
            break L42;
           }
          }
          __THREW__ = 0;
          invoke_vi(3397,($reflection|0));
          $373 = __THREW__; __THREW__ = 0;
          $374 = $373&1;
          if ($374) {
           label = 34;
           break L42;
          }
          $375 = HEAP32[$290>>2]|0;
          $376 = (($169) + 64|0);
          __THREW__ = 0;
          invoke_viiii(333,($375|0),($376|0),($defaultReflection|0),($reflection|0));
          $377 = __THREW__; __THREW__ = 0;
          $378 = $377&1;
          if ($378) {
           label = 34;
           break L42;
          }
          $379 = (_memcmp($reflectionProbeCache,$reflection,124)|0);
          $380 = ($379|0)==(0);
          if (!($380)) {
           dest=$reflectionProbeCache+0|0; src=$reflection+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           $381 = HEAP32[$142>>2]|0;
           __THREW__ = 0;
           invoke_vii(2614,($381|0),($reflection|0));
           $382 = __THREW__; __THREW__ = 0;
           $383 = $382&1;
           if ($383) {
            label = 34;
            break L42;
           }
          }
          $384 = (($151) + 52|0);
          $385 = HEAP32[$384>>2]|0;
          $386 = HEAP32[$385>>2]|0;
          $387 = (($386) + ($ss$0<<2)|0);
          $388 = HEAP32[$387>>2]|0;
          $389 = (($388) + 16|0);
          $390 = HEAP32[$389>>2]|0;
          $391 = ($390|0)>(0);
          if (!($391)) {
           $595 = $601;$596 = $602;$597 = $603;$598 = $604;$599 = $605;$600 = $606;$channels$4 = $channels$047;$prevPassIndex$5 = $prevPassIndex$046;$prevStencilRef$5 = $prevStencilRef$045;
           break;
          }
          $392 = (($169) + 76|0);
          $393 = (($169) + 68|0);
          $394 = (($169) + 80|0);
          $395 = (($169) + 72|0);
          $396 = (($169) + 84|0);
          $397 = ((($148) + (($147*44)|0)|0) + 6|0);
          $$9 = $295 ? 128 : 192;
          if ($294) {
           $channels$135$us = $channels$047;$p$037$us = 0;$prevPassIndex$134$us = $prevPassIndex$046;$prevStencilRef$133$us = $prevStencilRef$045;$resetPass$1$off036$us = $resetPass$0$off0;
           while(1) {
            $398 = HEAP32[$388>>2]|0;
            $399 = (($398) + ($p$037$us<<2)|0);
            $400 = HEAP32[$399>>2]|0;
            $401 = (($400) + 584|0);
            $402 = HEAP32[$401>>2]|0;
            $403 = ($402|0)==(10);
            do {
             if ($403) {
              $stencilRef$0$$us = $withinShadowDistance$0$off0 ? 128 : 160;
              $404 = HEAP32[$291>>2]|0;
              $405 = (($404) + 32|0);
              $406 = HEAP32[$405>>2]|0;
              __THREW__ = 0;
              $407 = (invoke_ii($406|0,($291|0))|0);
              $408 = __THREW__; __THREW__ = 0;
              $409 = $408&1;
              if ($409) {
               label = 102;
               break L42;
              }
              $410 = ((($lightingLayers) + ($407<<2)|0) + 4|0);
              $411 = HEAP32[$410>>2]|0;
              $412 = ($411|0)==(-1);
              if ($412) {
               $stencilRef$2$us = $stencilRef$0$$us;
              } else {
               $413 = 1 << $411;
               $414 = $413 | $stencilRef$0$$us;
               $stencilRef$2$us = $414;
              }
              $415 = ($p$037$us|0)==($prevPassIndex$134$us|0);
              $416 = ($stencilRef$2$us|0)==($prevStencilRef$133$us|0);
              $or$cond10$us = $415 & $416;
              if ($or$cond10$us) {
               if ($resetPass$1$off036$us) {
                label = 96;
               } else {
                $channels$2$us = $channels$135$us;$prevStencilRef$3$us = $prevStencilRef$133$us;$resetPass$2$off018$us = 0;
               }
              } else {
               __THREW__ = 0;
               invoke_vi(3398,($batchRenderer|0));
               $417 = __THREW__; __THREW__ = 0;
               $418 = $417&1;
               if ($418) {
                label = 102;
                break L42;
               } else {
                label = 96;
               }
              }
              if ((label|0) == 96) {
               label = 0;
               __THREW__ = 0;
               invoke_vii(2615,($88|0),($292|0));
               $419 = __THREW__; __THREW__ = 0;
               $420 = $419&1;
               if ($420) {
                label = 102;
                break L42;
               }
               $421 = HEAP32[$149>>2]|0;
               __THREW__ = 0;
               $422 = (invoke_iiiiii(193,($421|0),($p$037$us|0),($151|0),($11|0),($ss$0|0))|0);
               $423 = __THREW__; __THREW__ = 0;
               $424 = $423&1;
               if ($424) {
                label = 102;
                break L42;
               }
               $425 = HEAP32[$12>>2]|0;
               $426 = (($425) + 64|0);
               $427 = HEAP32[$426>>2]|0;
               $428 = HEAP32[$141>>2]|0;
               $429 = $428 | $stencilRef$2$us;
               __THREW__ = 0;
               invoke_viii($427|0,($12|0),($29|0),($429|0));
               $430 = __THREW__; __THREW__ = 0;
               $431 = $430&1;
               if ($431) {
                label = 102;
                break L42;
               } else {
                $channels$2$us = $422;$prevStencilRef$3$us = $stencilRef$2$us;$resetPass$2$off018$us = 1;
               }
              }
              $432 = Math_fround(HEAPF32[$376>>2]);
              $433 = Math_fround(HEAPF32[$392>>2]);
              $434 = Math_fround($432 + $433);
              $435 = Math_fround(HEAPF32[$393>>2]);
              $436 = Math_fround(HEAPF32[$394>>2]);
              $437 = Math_fround($435 + $436);
              $438 = Math_fround(HEAPF32[$395>>2]);
              $439 = Math_fround(HEAPF32[$396>>2]);
              $440 = Math_fround($438 + $439);
              $441 = Math_fround(HEAPF32[$receiverBounds>>2]);
              $442 = $434 < $441;
              $443 = $442 ? $434 : $441;
              $444 = Math_fround(HEAPF32[$133>>2]);
              $445 = $437 < $444;
              $446 = $445 ? $437 : $444;
              $447 = Math_fround(HEAPF32[$134>>2]);
              $448 = $440 < $447;
              $449 = $448 ? $440 : $447;
              HEAPF32[$receiverBounds>>2] = $443;
              HEAPF32[$133>>2] = $446;
              HEAPF32[$134>>2] = $449;
              $450 = Math_fround(HEAPF32[$135>>2]);
              $451 = $450 < $434;
              $452 = $451 ? $434 : $450;
              $453 = Math_fround(HEAPF32[$136>>2]);
              $454 = $453 < $437;
              $455 = $454 ? $437 : $453;
              $456 = Math_fround(HEAPF32[$137>>2]);
              $457 = $456 < $440;
              $458 = $457 ? $440 : $456;
              HEAPF32[$135>>2] = $452;
              HEAPF32[$136>>2] = $455;
              HEAPF32[$137>>2] = $458;
              $459 = Math_fround(HEAPF32[$376>>2]);
              $460 = Math_fround(HEAPF32[$392>>2]);
              $461 = Math_fround($459 - $460);
              $462 = Math_fround(HEAPF32[$393>>2]);
              $463 = Math_fround(HEAPF32[$394>>2]);
              $464 = Math_fround($462 - $463);
              $465 = Math_fround(HEAPF32[$395>>2]);
              $466 = Math_fround(HEAPF32[$396>>2]);
              $467 = Math_fround($465 - $466);
              $468 = $461 < $443;
              $469 = $468 ? $461 : $443;
              $470 = $464 < $446;
              $471 = $470 ? $464 : $446;
              $472 = $467 < $449;
              $473 = $472 ? $467 : $449;
              HEAPF32[$receiverBounds>>2] = $469;
              HEAPF32[$133>>2] = $471;
              HEAPF32[$134>>2] = $473;
              $474 = $452 < $461;
              $475 = $474 ? $461 : $452;
              $476 = $455 < $464;
              $477 = $476 ? $464 : $455;
              $478 = $458 < $467;
              $479 = $478 ? $467 : $458;
              HEAPF32[$135>>2] = $475;
              HEAPF32[$136>>2] = $477;
              HEAPF32[$137>>2] = $479;
              $480 = ($channels$2$us|0)==(0|0);
              if ($480) {
               $channels$3$us = 0;$prevPassIndex$4$us = $p$037$us;$prevStencilRef$4$us = $prevStencilRef$3$us;$resetPass$3$off0$us = $resetPass$2$off018$us;
               break;
              }
              $481 = HEAP16[$397>>1]|0;
              $482 = $481&65535;
              __THREW__ = 0;
              invoke_viiiii(90,($batchRenderer|0),($291|0),($169|0),($482|0),($channels$2$us|0));
              $483 = __THREW__; __THREW__ = 0;
              $484 = $483&1;
              if ($484) {
               label = 102;
               break L42;
              } else {
               $channels$3$us = $channels$2$us;$prevPassIndex$4$us = $p$037$us;$prevStencilRef$4$us = $prevStencilRef$3$us;$resetPass$3$off0$us = $resetPass$2$off018$us;
              }
             } else {
              $channels$3$us = $channels$135$us;$prevPassIndex$4$us = $prevPassIndex$134$us;$prevStencilRef$4$us = $prevStencilRef$133$us;$resetPass$3$off0$us = $resetPass$1$off036$us;
             }
            } while(0);
            $485 = (($p$037$us) + 1)|0;
            $486 = ($485|0)<($390|0);
            if ($486) {
             $channels$135$us = $channels$3$us;$p$037$us = $485;$prevPassIndex$134$us = $prevPassIndex$4$us;$prevStencilRef$133$us = $prevStencilRef$4$us;$resetPass$1$off036$us = $resetPass$3$off0$us;
            } else {
             $595 = $601;$596 = $602;$597 = $603;$598 = $604;$599 = $605;$600 = $606;$channels$4 = $channels$3$us;$prevPassIndex$5 = $prevPassIndex$4$us;$prevStencilRef$5 = $prevStencilRef$4$us;
             break;
            }
           }
          } else {
           $channels$135 = $channels$047;$p$037 = 0;$prevPassIndex$134 = $prevPassIndex$046;$prevStencilRef$133 = $prevStencilRef$045;$resetPass$1$off036 = $resetPass$0$off0;
           while(1) {
            $489 = HEAP32[$388>>2]|0;
            $490 = (($489) + ($p$037<<2)|0);
            $491 = HEAP32[$490>>2]|0;
            $492 = (($491) + 584|0);
            $493 = HEAP32[$492>>2]|0;
            $494 = ($493|0)==(10);
            do {
             if ($494) {
              $495 = $$9 | 32;
              $stencilRef$0$ = $withinShadowDistance$0$off0 ? $$9 : $495;
              $496 = HEAP32[$291>>2]|0;
              $497 = (($496) + 32|0);
              $498 = HEAP32[$497>>2]|0;
              __THREW__ = 0;
              $499 = (invoke_ii($498|0,($291|0))|0);
              $500 = __THREW__; __THREW__ = 0;
              $501 = $500&1;
              if ($501) {
               label = 33;
               break L42;
              }
              $502 = ((($lightingLayers) + ($499<<2)|0) + 4|0);
              $503 = HEAP32[$502>>2]|0;
              $504 = ($503|0)==(-1);
              if ($504) {
               $stencilRef$2 = $stencilRef$0$;
              } else {
               $505 = 1 << $503;
               $506 = $505 | $stencilRef$0$;
               $stencilRef$2 = $506;
              }
              $507 = ($p$037|0)==($prevPassIndex$134|0);
              $508 = ($stencilRef$2|0)==($prevStencilRef$133|0);
              $or$cond10 = $507 & $508;
              if ($or$cond10) {
               if ($resetPass$1$off036) {
                label = 110;
               } else {
                $channels$2 = $channels$135;$prevStencilRef$3 = $prevStencilRef$133;$resetPass$2$off018 = 0;
               }
              } else {
               __THREW__ = 0;
               invoke_vi(3398,($batchRenderer|0));
               $509 = __THREW__; __THREW__ = 0;
               $510 = $509&1;
               if ($510) {
                label = 33;
                break L42;
               } else {
                label = 110;
               }
              }
              if ((label|0) == 110) {
               label = 0;
               __THREW__ = 0;
               invoke_vii(2615,($88|0),($292|0));
               $511 = __THREW__; __THREW__ = 0;
               $512 = $511&1;
               if ($512) {
                label = 33;
                break L42;
               }
               $513 = HEAP32[$149>>2]|0;
               __THREW__ = 0;
               $514 = (invoke_iiiiii(193,($513|0),($p$037|0),($151|0),($11|0),($ss$0|0))|0);
               $515 = __THREW__; __THREW__ = 0;
               $516 = $515&1;
               if ($516) {
                label = 33;
                break L42;
               }
               $517 = HEAP32[$12>>2]|0;
               $518 = (($517) + 64|0);
               $519 = HEAP32[$518>>2]|0;
               $520 = HEAP32[$141>>2]|0;
               $521 = $520 | $stencilRef$2;
               __THREW__ = 0;
               invoke_viii($519|0,($12|0),($29|0),($521|0));
               $522 = __THREW__; __THREW__ = 0;
               $523 = $522&1;
               if ($523) {
                label = 33;
                break L42;
               } else {
                $channels$2 = $514;$prevStencilRef$3 = $stencilRef$2;$resetPass$2$off018 = 1;
               }
              }
              $524 = Math_fround(HEAPF32[$376>>2]);
              $525 = Math_fround(HEAPF32[$392>>2]);
              $526 = Math_fround($524 + $525);
              $527 = Math_fround(HEAPF32[$393>>2]);
              $528 = Math_fround(HEAPF32[$394>>2]);
              $529 = Math_fround($527 + $528);
              $530 = Math_fround(HEAPF32[$395>>2]);
              $531 = Math_fround(HEAPF32[$396>>2]);
              $532 = Math_fround($530 + $531);
              $533 = Math_fround(HEAPF32[$receiverBounds>>2]);
              $534 = $526 < $533;
              $535 = $534 ? $526 : $533;
              $536 = Math_fround(HEAPF32[$133>>2]);
              $537 = $529 < $536;
              $538 = $537 ? $529 : $536;
              $539 = Math_fround(HEAPF32[$134>>2]);
              $540 = $532 < $539;
              $541 = $540 ? $532 : $539;
              HEAPF32[$receiverBounds>>2] = $535;
              HEAPF32[$133>>2] = $538;
              HEAPF32[$134>>2] = $541;
              $542 = Math_fround(HEAPF32[$135>>2]);
              $543 = $542 < $526;
              $544 = $543 ? $526 : $542;
              $545 = Math_fround(HEAPF32[$136>>2]);
              $546 = $545 < $529;
              $547 = $546 ? $529 : $545;
              $548 = Math_fround(HEAPF32[$137>>2]);
              $549 = $548 < $532;
              $550 = $549 ? $532 : $548;
              HEAPF32[$135>>2] = $544;
              HEAPF32[$136>>2] = $547;
              HEAPF32[$137>>2] = $550;
              $551 = Math_fround(HEAPF32[$376>>2]);
              $552 = Math_fround(HEAPF32[$392>>2]);
              $553 = Math_fround($551 - $552);
              $554 = Math_fround(HEAPF32[$393>>2]);
              $555 = Math_fround(HEAPF32[$394>>2]);
              $556 = Math_fround($554 - $555);
              $557 = Math_fround(HEAPF32[$395>>2]);
              $558 = Math_fround(HEAPF32[$396>>2]);
              $559 = Math_fround($557 - $558);
              $560 = $553 < $535;
              $561 = $560 ? $553 : $535;
              $562 = $556 < $538;
              $563 = $562 ? $556 : $538;
              $564 = $559 < $541;
              $565 = $564 ? $559 : $541;
              HEAPF32[$receiverBounds>>2] = $561;
              HEAPF32[$133>>2] = $563;
              HEAPF32[$134>>2] = $565;
              $566 = $544 < $553;
              $567 = $566 ? $553 : $544;
              $568 = $547 < $556;
              $569 = $568 ? $556 : $547;
              $570 = $550 < $559;
              $571 = $570 ? $559 : $550;
              HEAPF32[$135>>2] = $567;
              HEAPF32[$136>>2] = $569;
              HEAPF32[$137>>2] = $571;
              $572 = ($channels$2|0)==(0|0);
              if ($572) {
               $channels$3 = 0;$prevPassIndex$4 = $p$037;$prevStencilRef$4 = $prevStencilRef$3;$resetPass$3$off0 = $resetPass$2$off018;
               break;
              }
              $573 = HEAP16[$397>>1]|0;
              $574 = $573&65535;
              __THREW__ = 0;
              invoke_viiiii(90,($batchRenderer|0),($291|0),($169|0),($574|0),($channels$2|0));
              $575 = __THREW__; __THREW__ = 0;
              $576 = $575&1;
              if ($576) {
               label = 33;
               break L42;
              } else {
               $channels$3 = $channels$2;$prevPassIndex$4 = $p$037;$prevStencilRef$4 = $prevStencilRef$3;$resetPass$3$off0 = $resetPass$2$off018;
              }
             } else {
              $channels$3 = $channels$135;$prevPassIndex$4 = $prevPassIndex$134;$prevStencilRef$4 = $prevStencilRef$133;$resetPass$3$off0 = $resetPass$1$off036;
             }
            } while(0);
            $577 = (($p$037) + 1)|0;
            $578 = ($577|0)<($390|0);
            if ($578) {
             $channels$135 = $channels$3;$p$037 = $577;$prevPassIndex$134 = $prevPassIndex$4;$prevStencilRef$133 = $prevStencilRef$4;$resetPass$1$off036 = $resetPass$3$off0;
            } else {
             $595 = $601;$596 = $602;$597 = $603;$598 = $604;$599 = $605;$600 = $606;$channels$4 = $channels$3;$prevPassIndex$5 = $prevPassIndex$4;$prevStencilRef$5 = $prevStencilRef$4;
             break;
            }
           }
          }
         }
        } while(0);
        $579 = (($index$044) + 1)|0;
        $580 = ($579>>>0)<($107>>>0);
        if ($580) {
         $315 = $600;$317 = $599;$319 = $595;$321 = $598;$337 = $597;$339 = $596;$channels$047 = $channels$4;$index$044 = $579;$prevPassIndex$046 = $prevPassIndex$5;$prevStencilRef$045 = $prevStencilRef$5;
        } else {
         break L40;
        }
       }
       if ((label|0) == 33) {
        $160 = ___cxa_find_matching_catch()|0;
        $161 = tempRet0;
        $lpad$phi$index = $160;$lpad$phi$index4 = $161;
        break L28;
       }
       else if ((label|0) == 34) {
        $162 = ___cxa_find_matching_catch()|0;
        $163 = tempRet0;
        $lpad$phi$index = $162;$lpad$phi$index4 = $163;
        break L28;
       }
       else if ((label|0) == 102) {
        $487 = ___cxa_find_matching_catch()|0;
        $488 = tempRet0;
        $lpad$phi$index = $487;$lpad$phi$index4 = $488;
        break L28;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3398,($batchRenderer|0));
     $581 = __THREW__; __THREW__ = 0;
     $582 = $581&1;
     if ($582) {
      label = 35;
     } else {
      $583 = HEAP32[$this>>2]|0;
      $584 = HEAP32[$583>>2]|0;
      $585 = (($584) + 636|0);
      __THREW__ = 0;
      invoke_viii(1663,($585|0),5,($11|0));
      $586 = __THREW__; __THREW__ = 0;
      $587 = $586&1;
      if ($587) {
       label = 35;
      } else {
       $588 = HEAP32[$12>>2]|0;
       $589 = (($588) + 72|0);
       $590 = HEAP32[$589>>2]|0;
       __THREW__ = 0;
       invoke_vii($590|0,($12|0),0);
       $591 = __THREW__; __THREW__ = 0;
       $592 = $591&1;
       if ($592) {
        label = 35;
       } else {
        __ZN13BatchRendererD1Ev($batchRenderer);
        STACKTOP = sp;return 4;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 35) {
  $164 = ___cxa_find_matching_catch()|0;
  $165 = tempRet0;
  $lpad$phi$index = $164;$lpad$phi$index4 = $165;
 }
 __THREW__ = 0;
 invoke_vi(3399,($batchRenderer|0));
 $166 = __THREW__; __THREW__ = 0;
 $167 = $166&1;
 if ($167) {
  $593 = ___cxa_find_matching_catch(0|0)|0;
  $594 = tempRet0;
  ___clang_call_terminate($593);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN18DeferredRenderLoop15RenderFinalPassEP13RenderTextureS1_b($this,$rtMain,$rtLight,$linearLighting) {
 $this = $this|0;
 $rtMain = $rtMain|0;
 $rtLight = $rtLight|0;
 $linearLighting = $linearLighting|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,0);
 $4 = HEAP32[652824>>2]|0;
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($rtMain,0,-1,0);
 $5 = (__Z12GetGfxDevicev()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 88|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $10 = HEAP32[$5>>2]|0;
 $11 = (($10) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vii[$12 & 4095]($5,0);
 $13 = (($4) + 20|0);
 __THREW__ = 0;
 invoke_viif(42,($13|0),(568976|0),128.0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 do {
  if (!($15)) {
   $16 = HEAP32[$0>>2]|0;
   $17 = (($16) + 72|0);
   $18 = HEAP32[$17>>2]|0;
   if ($linearLighting) {
    $19 = ($rtMain|0)==(0|0);
    if ($19) {
     $23 = 1;
    } else {
     $20 = (($rtMain) + 130|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)!=(0);
     $23 = $22;
    }
   } else {
    $23 = 0;
   }
   __THREW__ = 0;
   invoke_vii($18|0,($0|0),($23|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$this>>2]|0;
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    invoke_vii(2619,($27|0),1);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($rtLight|0)==(0|0);
     if ($30) {
      __THREW__ = 0;
      $43 = (invoke_i(68)|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break;
      }
      __THREW__ = 0;
      $46 = (invoke_iiii(1534,($13|0),(568928|0),($43|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      __THREW__ = 0;
      invoke_viff(17,($46|0),1.0,1.0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      __THREW__ = 0;
      invoke_viff(18,($46|0),0.0,0.0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
     } else {
      __THREW__ = 0;
      (invoke_iii(2368,($rtLight|0),(568928|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
     }
     $53 = HEAP32[$this>>2]|0;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($54) + 636|0);
     __THREW__ = 0;
     invoke_viii(1663,($55|0),8,($4|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if (!($57)) {
      $58 = HEAP32[569184>>2]|0;
      __THREW__ = 0;
      invoke_viiiiii(103,(0|0),($rtMain|0),($58|0),1,0,-1);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if (!($60)) {
       $61 = HEAP32[$this>>2]|0;
       $62 = HEAP32[$61>>2]|0;
       $63 = (($62) + 636|0);
       __THREW__ = 0;
       invoke_viii(1663,($63|0),9,($4|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if (!($65)) {
        __THREW__ = 0;
        $66 = (invoke_i(59)|0);
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if (!($68)) {
         $69 = HEAP32[$66>>2]|0;
         $70 = (($69) + 72|0);
         $71 = HEAP32[$70>>2]|0;
         __THREW__ = 0;
         invoke_vii($71|0,($66|0),0);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if (!($73)) {
          $74 = (__Z12GetGfxDevicev()|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = (($75) + 84|0);
          $77 = HEAP32[$76>>2]|0;
          FUNCTION_TABLE_vii[$77 & 4095]($74,$9);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 __THREW__ = 0;
 $35 = (invoke_i(59)|0);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $78 = ___cxa_find_matching_catch(0|0)|0;
  $79 = tempRet0;
  ___clang_call_terminate($78);
  // unreachable;
 }
 $38 = HEAP32[$35>>2]|0;
 $39 = (($38) + 84|0);
 $40 = HEAP32[$39>>2]|0;
 __THREW__ = 0;
 invoke_vii($40|0,($35|0),($9|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $78 = ___cxa_find_matching_catch(0|0)|0;
  $79 = tempRet0;
  ___clang_call_terminate($78);
  // unreachable;
 } else {
  ___resumeException($33|0);
  // unreachable;
 }
}
function __Z20DoDeferredRenderLoopR17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EES4_RP13RenderTextureS7_S7_R12ActiveLightsbPb($ctx,$objects,$outRemainingObjects,$outDepthRT,$outDepthNormalsRT,$outMainShadowMap,$activeLights,$linearLighting,$outDepthWasCopied) {
 $ctx = $ctx|0;
 $objects = $objects|0;
 $outRemainingObjects = $outRemainingObjects|0;
 $outDepthRT = $outDepthRT|0;
 $outDepthNormalsRT = $outDepthNormalsRT|0;
 $outMainShadowMap = $outMainShadowMap|0;
 $activeLights = $activeLights|0;
 $linearLighting = $linearLighting|0;
 $outDepthWasCopied = $outDepthWasCopied|0;
 var $$ = Math_fround(0), $$0$i$i$i$i = Math_fround(0), $$0$i$i$i$i14 = Math_fround(0), $$0$i1$i$i$i16 = Math_fround(0), $$0$i3$i$i$i = Math_fround(0), $$0$i3$i$i$i15 = Math_fround(0), $$19 = Math_fround(0), $$byval_copy11 = 0, $$byval_copy8 = 0, $$in = 0, $$pre = 0, $$pre$i$i22 = 0, $$pre$i$i7 = 0, $$pre26 = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0);
 var $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0);
 var $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $bit$01$i$i = 0, $bit$1$i$i = 0, $black = 0, $depthTextureID = 0;
 var $exitcond$i$i = 0, $fadeCenterAndType = 0, $i1$03$i$i = 0, $it$020 = 0, $lightFade = 0, $lightingLayers = 0, $loop = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $mask$02$i$i = 0, $receiverBounds = 0, $roIndex$021 = 0, $rtGBuffer = 0, $scevgep$i$i = 0, $shadowDistance = 0, $shadowSphereRange = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy11 = sp + 300|0;
 $$byval_copy8 = sp + 296|0;
 $0 = sp;
 $1 = sp + 292|0;
 $2 = sp + 288|0;
 $loop = sp + 264|0;
 $lightFade = sp + 8|0;
 $fadeCenterAndType = sp + 248|0;
 $shadowDistance = sp + 240|0;
 $shadowSphereRange = sp + 68|0;
 $lightingLayers = sp + 72|0;
 $receiverBounds = sp + 24|0;
 $rtGBuffer = sp + 48|0;
 $depthTextureID = sp + 64|0;
 $3 = sp + 208|0;
 $4 = sp + 212|0;
 $5 = sp + 216|0;
 $black = sp + 224|0;
 HEAP32[$outDepthRT>>2] = 0;
 HEAP32[$outDepthNormalsRT>>2] = 0;
 HEAP8[$outDepthWasCopied>>0] = 0;
 $6 = (__Z19GetGraphicsSettingsv()|0);
 $7 = (($6) + 24|0);
 __ZNK21BuiltinShaderSettings22CreateMaterialIfNeededEPPN5Unity8MaterialEi($7,569184,2);
 $8 = HEAP32[569184>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($loop) + 8|0);
 HEAP32[$10>>2] = 0;
 $11 = (($loop) + 16|0);
 $12 = (($loop) + 20|0);
 HEAP32[$12>>2] = 0;
 $13 = (($loop) + 12|0);
 HEAP32[$13>>2] = 61;
 HEAP32[$loop>>2] = $ctx;
 $14 = (($loop) + 4|0);
 HEAP32[$14>>2] = $objects;
 $15 = HEAP32[652824>>2]|0;
 HEAP32[$11>>2] = 0;
 $16 = HEAP32[$objects>>2]|0;
 $17 = (($objects) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + (($18*44)|0)|0);
 $20 = ($18|0)==(0);
 do {
  if ($20) {
   $57 = $16;$58 = 0;
   label = 18;
  } else {
   $21 = (($loop) + 8|0);
   $$pre$i$i22 = 0;$24 = 0;$32 = 0;$it$020 = $16;$roIndex$021 = 0;
   L6: while(1) {
    $22 = (($$pre$i$i22) + 1)|0;
    $23 = $24 & 2147483647;
    $25 = ($22>>>0)>($23>>>0);
    do {
     if ($25) {
      $26 = $24 << 1;
      $27 = ($26|0)==(0);
      $28 = $27 ? 1 : $26;
      $29 = ($23>>>0)<($28>>>0);
      if ($29) {
       $30 = ($24|0)>(-1);
       if ($30) {
        HEAP32[$12>>2] = $28;
        $31 = $28 << 2;
        HEAP32[$1>>2] = 61;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
        $33 = (invoke_iiiiiiii(108,($32|0),($31|0),4,($$byval_copy11|0),0,(569192|0),370)|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         $279 = $28;
         label = 12;
         break L6;
        }
        HEAP32[$21>>2] = $33;
        $278 = $28;$42 = $33;
        break;
       } else {
        $36 = $28 << 2;
        HEAP32[$2>>2] = 61;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
        $37 = (invoke_iiiiiii(102,($36|0),4,($$byval_copy11|0),0,(569192|0),352)|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         $279 = $24;
         label = 12;
         break L6;
        }
        $40 = $22 << 2;
        _memcpy(($37|0),($32|0),($40|0))|0;
        HEAP32[$12>>2] = $28;
        HEAP32[$21>>2] = $37;
        $278 = $28;$42 = $37;
        break;
       }
      } else {
       $278 = $24;$42 = $32;
      }
     } else {
      $278 = $24;$42 = $32;
     }
    } while(0);
    $41 = (($42) + ($$pre$i$i22<<2)|0);
    HEAP32[$41>>2] = $roIndex$021;
    $43 = (($it$020) + 44|0);
    $44 = (($roIndex$021) + 1)|0;
    $45 = ($43|0)==($19|0);
    if ($45) {
     label = 17;
     break;
    } else {
     $$pre$i$i22 = $22;$24 = $278;$32 = $42;$it$020 = $43;$roIndex$021 = $44;
    }
   }
   if ((label|0) == 12) {
    $46 = ___cxa_find_matching_catch()|0;
    $47 = tempRet0;
    HEAP32[$11>>2] = $22;
    $51 = $279;$lpad$phi$index = $46;$lpad$phi$index2 = $47;
    break;
   }
   else if ((label|0) == 17) {
    HEAP32[$11>>2] = $22;
    $$pre = HEAP32[$objects>>2]|0;
    $$pre26 = HEAP32[$17>>2]|0;
    $57 = $$pre;$58 = $$pre26;
    label = 18;
    break;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $56 = (($57) + (($58*44)|0)|0);
  __ZNSt3__16__sortIR26RenderDeferredObjectSorterP16RenderObjectDataEEvT0_S5_T_($57,$56,$0);
  __THREW__ = 0;
  $59 = (invoke_i(59)|0);
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  L22: do {
   if (!($61)) {
    $62 = HEAP32[$ctx>>2]|0;
    __THREW__ = 0;
    invoke_viiii(339,($62|0),($fadeCenterAndType|0),($shadowDistance|0),($shadowSphereRange|0));
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if (!($64)) {
     $65 = HEAP32[$ctx>>2]|0;
     $66 = Math_fround(HEAPF32[$shadowDistance>>2]);
     $67 = Math_fround(HEAPF32[$shadowSphereRange>>2]);
     __THREW__ = 0;
     invoke_vifffi(2,($65|0),1.0,(+$66),(+$67),($lightFade|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if (!($69)) {
      $70 = (($59) + 932|0);
      ;HEAP32[$70+0>>2]=HEAP32[$fadeCenterAndType+0>>2]|0;HEAP32[$70+4>>2]=HEAP32[$fadeCenterAndType+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$fadeCenterAndType+8>>2]|0;HEAP32[$70+12>>2]=HEAP32[$fadeCenterAndType+12>>2]|0;
      __THREW__ = 0;
      $71 = (invoke_i(63)|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if (!($73)) {
       __THREW__ = 0;
       $74 = (invoke_i(66)|0);
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if (!($76)) {
        $77 = ($74|0)==(1);
        $78 = (($71) + 40|0);
        $79 = Math_fround(HEAPF32[$78>>2]);
        do {
         if ($77) {
          $80 = !($79 <= Math_fround(0.0404499992728233337402));
          do {
           if ($80) {
            $82 = $79 < Math_fround(1.0);
            if ($82) {
             $83 = Math_fround($79 + Math_fround(0.054999999701976776123));
             $84 = Math_fround($83 / Math_fround(1.05499994754791259766));
             $85 = (Math_fround(+(Math_pow((+$84),2.40000009536743164063))));
             $$0$i$i$i$i = $85;
             break;
            } else {
             $86 = (Math_fround(+(Math_pow((+$79),2.40000009536743164063))));
             $$0$i$i$i$i = $86;
             break;
            }
           } else {
            $81 = Math_fround($79 / Math_fround(12.9200000762939453125));
            $$0$i$i$i$i = $81;
           }
          } while(0);
          $87 = (($71) + 44|0);
          $88 = Math_fround(HEAPF32[$87>>2]);
          $89 = !($88 <= Math_fround(0.0404499992728233337402));
          do {
           if ($89) {
            $91 = $88 < Math_fround(1.0);
            if ($91) {
             $92 = Math_fround($88 + Math_fround(0.054999999701976776123));
             $93 = Math_fround($92 / Math_fround(1.05499994754791259766));
             $94 = (Math_fround(+(Math_pow((+$93),2.40000009536743164063))));
             $$0$i3$i$i$i = $94;
             break;
            } else {
             $95 = (Math_fround(+(Math_pow((+$88),2.40000009536743164063))));
             $$0$i3$i$i$i = $95;
             break;
            }
           } else {
            $90 = Math_fround($88 / Math_fround(12.9200000762939453125));
            $$0$i3$i$i$i = $90;
           }
          } while(0);
          $96 = (($71) + 48|0);
          $97 = Math_fround(HEAPF32[$96>>2]);
          $98 = !($97 <= Math_fround(0.0404499992728233337402));
          if (!($98)) {
           $99 = Math_fround($97 / Math_fround(12.9200000762939453125));
           $$0$i$i$i$i14 = $$0$i$i$i$i;$$0$i1$i$i$i16 = $99;$$0$i3$i$i$i15 = $$0$i3$i$i$i;
           break;
          }
          $100 = $97 < Math_fround(1.0);
          if ($100) {
           $101 = Math_fround($97 + Math_fround(0.054999999701976776123));
           $102 = Math_fround($101 / Math_fround(1.05499994754791259766));
           $103 = (Math_fround(+(Math_pow((+$102),2.40000009536743164063))));
           $$0$i$i$i$i14 = $$0$i$i$i$i;$$0$i1$i$i$i16 = $103;$$0$i3$i$i$i15 = $$0$i3$i$i$i;
           break;
          } else {
           $104 = (Math_fround(+(Math_pow((+$97),2.40000009536743164063))));
           $$0$i$i$i$i14 = $$0$i$i$i$i;$$0$i1$i$i$i16 = $104;$$0$i3$i$i$i15 = $$0$i3$i$i$i;
           break;
          }
         } else {
          $105 = (($71) + 44|0);
          $106 = Math_fround(HEAPF32[$105>>2]);
          $107 = (($71) + 48|0);
          $108 = Math_fround(HEAPF32[$107>>2]);
          $$0$i$i$i$i14 = $79;$$0$i1$i$i$i16 = $108;$$0$i3$i$i$i15 = $106;
         }
        } while(0);
        $$in = (($71) + 52|0);
        $109 = Math_fround(HEAPF32[$$in>>2]);
        $110 = (($59) + 660|0);
        HEAPF32[$110>>2] = $$0$i$i$i$i14;
        $111 = (($59) + 664|0);
        HEAPF32[$111>>2] = $$0$i3$i$i$i15;
        $112 = (($59) + 668|0);
        HEAPF32[$112>>2] = $$0$i1$i$i$i16;
        $113 = (($59) + 672|0);
        HEAPF32[$113>>2] = $109;
        __THREW__ = 0;
        $114 = (invoke_i(59)|0);
        $115 = __THREW__; __THREW__ = 0;
        $116 = $115&1;
        if (!($116)) {
         $117 = HEAP32[$ctx>>2]|0;
         $118 = (($117) + 348|0);
         $119 = HEAP32[$118>>2]|0;
         $120 = (($119) + 140|0);
         $121 = HEAP32[$120>>2]|0;
         $122 = ($121|0)==(0|0);
         if ($122) {
          $123 = (($119) + 148|0);
          $124 = HEAP32[$123>>2]|0;
          $125 = ($124|0)==(0|0);
          if ($125) {
           __THREW__ = 0;
           (invoke_ii(3218,($119|0))|0);
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            break;
           }
          }
         }
         __THREW__ = 0;
         $128 = (invoke_i(67)|0);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if (!($130)) {
          HEAP32[$lightingLayers>>2] = $128;
          $scevgep$i$i = (($lightingLayers) + 4|0);
          dest=$scevgep$i$i+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          $131 = (($lightingLayers) + 132|0);
          HEAP32[$131>>2] = 0;
          $135 = 0;$bit$01$i$i = 3;$i1$03$i$i = 0;$mask$02$i$i = 1;
          while(1) {
           $132 = $mask$02$i$i & $128;
           $133 = ($132|0)==(0);
           if ($133) {
            $280 = $135;$bit$1$i$i = $bit$01$i$i;
           } else {
            $134 = ($135|0)<(4);
            if ($134) {
             $136 = ((($lightingLayers) + ($i1$03$i$i<<2)|0) + 4|0);
             HEAP32[$136>>2] = $bit$01$i$i;
             $$pre$i$i7 = HEAP32[$131>>2]|0;
             $139 = $$pre$i$i7;
            } else {
             $139 = $135;
            }
            $137 = (($bit$01$i$i) + -1)|0;
            $138 = (($139) + 1)|0;
            HEAP32[$131>>2] = $138;
            $280 = $138;$bit$1$i$i = $137;
           }
           $140 = (($i1$03$i$i) + 1)|0;
           $141 = $mask$02$i$i << 1;
           $exitcond$i$i = ($140|0)==(32);
           if ($exitcond$i$i) {
            break;
           } else {
            $135 = $280;$bit$01$i$i = $bit$1$i$i;$i1$03$i$i = $140;$mask$02$i$i = $141;
           }
          }
          HEAP8[678904>>0] = 0;
          $142 = HEAP32[$ctx>>2]|0;
          $143 = (($142) + 620|0);
          $144 = HEAP8[$143>>0]|0;
          $145 = ($144<<24>>24)!=(0);
          $146 = $lightFade;
          $147 = $146;
          $148 = HEAP32[$147>>2]|0;
          $149 = (($146) + 4)|0;
          $150 = $149;
          $151 = HEAP32[$150>>2]|0;
          $152 = (($lightFade) + 8|0);
          $153 = Math_fround(HEAPF32[$152>>2]);
          $154 = (($lightFade) + 12|0);
          $155 = Math_fround(HEAPF32[$154>>2]);
          __THREW__ = 0;
          $156 = (invoke_i(64)|0);
          $157 = __THREW__; __THREW__ = 0;
          $158 = $157&1;
          if (!($158)) {
           __THREW__ = 0;
           $159 = (invoke_ii(3217,($156|0))|0);
           $160 = __THREW__; __THREW__ = 0;
           $161 = $160&1;
           if (!($161)) {
            $162 = ($159|0)==(1);
            $$ = $162 ? $155 : Math_fround(1.0);
            $$19 = $162 ? $153 : Math_fround(1.0);
            $163 = (($59) + 676|0);
            $164 = $163;
            $165 = $164;
            HEAP32[$165>>2] = $148;
            $166 = (($164) + 4)|0;
            $167 = $166;
            HEAP32[$167>>2] = $151;
            $168 = (($59) + 684|0);
            HEAPF32[$168>>2] = $$19;
            $169 = (($59) + 688|0);
            HEAPF32[$169>>2] = $$;
            $170 = (($receiverBounds) + 12|0);
            $171 = (($receiverBounds) + 16|0);
            $172 = (($receiverBounds) + 20|0);
            ;HEAP32[$receiverBounds+0>>2]=0|0;HEAP32[$receiverBounds+4>>2]=0|0;HEAP32[$receiverBounds+8>>2]=0|0;HEAP32[$receiverBounds+12>>2]=0|0;HEAP32[$receiverBounds+16>>2]=0|0;
            ;HEAP32[$receiverBounds+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$receiverBounds+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$receiverBounds+8>>2]=HEAP32[616664+8>>2]|0;
            $173 = Math_fround(HEAPF32[616664>>2]);
            $174 = Math_fround(-$173);
            $175 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
            $176 = Math_fround(-$175);
            $177 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
            $178 = Math_fround(-$177);
            HEAPF32[$170>>2] = $174;
            HEAPF32[$171>>2] = $176;
            HEAPF32[$172>>2] = $178;
            __THREW__ = 0;
            (invoke_iiiiiiiii(38,($loop|0),($119|0),($lightingLayers|0),($outRemainingObjects|0),($receiverBounds|0),($rtGBuffer|0),($145|0),($linearLighting|0))|0);
            $179 = __THREW__; __THREW__ = 0;
            $180 = $179&1;
            if (!($180)) {
             $181 = HEAP32[$rtGBuffer>>2]|0;
             HEAP32[$outDepthRT>>2] = $181;
             $182 = (($119) + 136|0);
             $183 = HEAP32[$182>>2]|0;
             HEAP32[$depthTextureID>>2] = $183;
             $184 = (($119) + 120|0);
             $185 = HEAP32[$184>>2]|0;
             $186 = HEAP8[((640792 + 248|0))>>0]|0;
             $187 = ($186<<24>>24)==(0);
             do {
              if (!($187)) {
               $188 = (($activeLights) + 16|0);
               $189 = HEAP8[$188>>0]|0;
               $190 = ($189<<24>>24)==(0);
               do {
                if ($190) {
                 label = 59;
                } else {
                 $191 = HEAP32[$activeLights>>2]|0;
                 $192 = ($191|0)==(0|0);
                 if ($192) {
                  label = 59;
                  break;
                 }
                 $193 = HEAP32[$191>>2]|0;
                 $194 = ($193|0)==(0|0);
                 if ($194) {
                  label = 59;
                  break;
                 }
                 $195 = (($193) + 216|0);
                 $196 = HEAP32[$195>>2]|0;
                 $197 = ($196|0)==(1);
                 if (!($197)) {
                  label = 59;
                  break;
                 }
                 $201 = (($193) + 116|0);
                 $202 = HEAP32[$201>>2]|0;
                 $203 = ($202|0)==(0);
                 $204 = HEAP32[$ctx>>2]|0;
                 $205 = (($204) + 604|0);
                 $206 = HEAP32[$205>>2]|0;
                 if ($203) {
                  $208 = $206;
                  label = 61;
                 } else {
                  $219 = $206;
                 }
                }
               } while(0);
               if ((label|0) == 59) {
                $198 = HEAP32[$ctx>>2]|0;
                $199 = (($198) + 604|0);
                $200 = HEAP32[$199>>2]|0;
                $208 = $200;
                label = 61;
               }
               if ((label|0) == 61) {
                $207 = $208 & 1;
                $209 = ($207|0)==(0);
                if ($209) {
                 break;
                } else {
                 $219 = $208;
                }
               }
               $210 = (($181) + 140|0);
               $211 = HEAP32[$210>>2]|0;
               HEAP32[$3>>2] = $211;
               $212 = (($119) + 148|0);
               $213 = HEAP32[$212>>2]|0;
               HEAP32[$4>>2] = $213;
               $214 = (($119) + 100|0);
               $215 = HEAP32[$214>>2]|0;
               $216 = (($119) + 104|0);
               $217 = HEAP32[$216>>2]|0;
               $218 = $219 & 1;
               $220 = ($218|0)!=(0);
               __THREW__ = 0;
               ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
               ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$4+0>>2]|0;
               invoke_viiiiiiii(24,($ctx|0),($119|0),($outRemainingObjects|0),($$byval_copy8|0),($$byval_copy11|0),($215|0),($217|0),($220|0));
               $221 = __THREW__; __THREW__ = 0;
               $222 = $221&1;
               if ($222) {
                break L22;
               }
              }
             } while(0);
             $223 = (($ctx) + 116|0);
             $224 = HEAP32[$223>>2]|0;
             __THREW__ = 0;
             invoke_viiiiii(102,($114|0),($224|0),($185|0),($outDepthRT|0),($depthTextureID|0),($outDepthWasCopied|0));
             $225 = __THREW__; __THREW__ = 0;
             $226 = $225&1;
             if (!($226)) {
              ;HEAP32[$163+0>>2]=HEAP32[$lightFade+0>>2]|0;HEAP32[$163+4>>2]=HEAP32[$lightFade+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$lightFade+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$lightFade+12>>2]|0;
              $227 = HEAP32[$depthTextureID>>2]|0;
              HEAP32[$5>>2] = $227;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$5+0>>2]|0;
              invoke_viiiiiiiiii(7,($loop|0),($activeLights|0),($119|0),($$byval_copy11|0),($rtGBuffer|0),4,($lightFade|0),($lightingLayers|0),($receiverBounds|0),($outMainShadowMap|0));
              $228 = __THREW__; __THREW__ = 0;
              $229 = $228&1;
              if (!($229)) {
               HEAP8[678904>>0] = 1;
               $230 = HEAP32[$ctx>>2]|0;
               $231 = (($230) + 623|0);
               $232 = HEAP8[$231>>0]|0;
               $233 = ($232<<24>>24)==(0);
               if (!($233)) {
                ;HEAP32[$black+0>>2]=0|0;HEAP32[$black+4>>2]=0|0;HEAP32[$black+8>>2]=0|0;HEAP32[$black+12>>2]=0|0;
                $234 = HEAP32[$114>>2]|0;
                $235 = (($234) + 24|0);
                $236 = HEAP32[$235>>2]|0;
                __THREW__ = 0;
                invoke_viiifi($236|0,($114|0),4,($black|0),1.0,0);
                $237 = __THREW__; __THREW__ = 0;
                $238 = $237&1;
                if ($238) {
                 break;
                }
               }
               if ($145) {
                $243 = HEAP32[$ctx>>2]|0;
                $244 = (($243) + 636|0);
                __THREW__ = 0;
                invoke_viii(1663,($244|0),8,($15|0));
                $245 = __THREW__; __THREW__ = 0;
                $246 = $245&1;
                if ($246) {
                 break;
                }
                $247 = HEAP32[$ctx>>2]|0;
                $248 = (($247) + 636|0);
                __THREW__ = 0;
                invoke_viii(1663,($248|0),9,($15|0));
                $249 = __THREW__; __THREW__ = 0;
                $250 = $249&1;
                if ($250) {
                 break;
                }
               } else {
                $239 = (($rtGBuffer) + 12|0);
                $240 = HEAP32[$239>>2]|0;
                __THREW__ = 0;
                invoke_viiii(340,($loop|0),($119|0),($240|0),($linearLighting|0));
                $241 = __THREW__; __THREW__ = 0;
                $242 = $241&1;
                if ($242) {
                 break;
                }
               }
               $251 = HEAP32[$ctx>>2]|0;
               $252 = (($251) + 604|0);
               $253 = HEAP32[$252>>2]|0;
               $254 = $253 & 2;
               $255 = ($254|0)==(0);
               if (!($255)) {
                __THREW__ = 0;
                $256 = (invoke_iii(2367,($ctx|0),($outRemainingObjects|0))|0);
                $257 = __THREW__; __THREW__ = 0;
                $258 = $257&1;
                if ($258) {
                 break;
                }
                HEAP32[$outDepthNormalsRT>>2] = $256;
               }
               __THREW__ = 0;
               invoke_viiii(337,($119|0),0,-1,0);
               $259 = __THREW__; __THREW__ = 0;
               $260 = $259&1;
               if ($260) {
                break;
               }
               $261 = HEAP32[$114>>2]|0;
               $262 = (($261) + 100|0);
               $263 = HEAP32[$262>>2]|0;
               $264 = (($ctx) + 12|0);
               __THREW__ = 0;
               invoke_vii($263|0,($114|0),($264|0));
               $265 = __THREW__; __THREW__ = 0;
               $266 = $265&1;
               if ($266) {
                break;
               }
               $267 = HEAP32[$114>>2]|0;
               $268 = (($267) + 136|0);
               $269 = HEAP32[$268>>2]|0;
               __THREW__ = 0;
               invoke_vii($269|0,($114|0),0);
               $270 = __THREW__; __THREW__ = 0;
               $271 = $270&1;
               if ($271) {
                break;
               }
               $272 = HEAP32[$12>>2]|0;
               $273 = ($272|0)>(-1);
               if (!($273)) {
                STACKTOP = sp;return;
               }
               $274 = HEAP32[$10>>2]|0;
               $275 = HEAP32[$13>>2]|0;
               HEAP32[$$byval_copy8>>2] = $275;
               ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$$byval_copy8+0>>2]|0;
               __Z19free_alloc_internalPv10MemLabelId($274,$$byval_copy11);
               HEAP32[$10>>2] = 0;
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  } while(0);
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $$pre27 = HEAP32[$12>>2]|0;
  $51 = $$pre27;$lpad$phi$index = $48;$lpad$phi$index2 = $49;
 }
 $50 = ($51|0)>(-1);
 if (!($50)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $52 = HEAP32[$10>>2]|0;
 $53 = HEAP32[$13>>2]|0;
 HEAP32[$$byval_copy8>>2] = $53;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$$byval_copy8+0>>2]|0;
 invoke_vii(2591,($52|0),($$byval_copy11|0));
 $54 = __THREW__; __THREW__ = 0;
 $55 = $54&1;
 if ($55) {
  $276 = ___cxa_find_matching_catch(0|0)|0;
  $277 = tempRet0;
  ___clang_call_terminate($276);
  // unreachable;
 }
 HEAP32[$10>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16__sortIR26RenderDeferredObjectSorterP16RenderObjectDataEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0);
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = 0;
 var $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0;
 var $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$038 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$035 = 0, $__j$035$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0;
 var $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i33 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i33 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -44|0);
  $2 = (($$01$ph) + -88|0);
  $3 = (($$01$ph) + -4|0);
  $4 = (($$01$ph) + -40|0);
  $5 = (($$01$ph) + -32|0);
  $6 = (($$01$ph) + -24|0);
  $7 = (($$01$ph) + -20|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $8 = $$0;
   $9 = (($0) - ($8))|0;
   $10 = (($9|0) / 44)&-1;
   switch ($10|0) {
   case 5:  {
    label = 18;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 16;
    break L1;
    break;
   }
   case 4:  {
    label = 17;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 151;
    break L1;
    break;
   }
   default: {
   }
   }
   $49 = ($9|0)<(1364);
   if ($49) {
    label = 20;
    break L1;
   }
   $50 = ($9|0)>(43956);
   $51 = (($9|0) / 88)&-1;
   $52 = (($$0) + (($51*44)|0)|0);
   if ($50) {
    $53 = (($9|0) / 176)&-1;
    $54 = (($$0) + (($53*44)|0)|0);
    $$sum = (($53) + ($51))|0;
    $55 = (($$0) + (($$sum*44)|0)|0);
    $56 = (__ZNSt3__17__sort5IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_S5_T_($$0,$54,$52,$55,$1,0)|0);
    $__n_swaps$0 = $56;
   } else {
    $57 = (__ZNSt3__17__sort3IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($$0,$52,$1,0)|0);
    $__n_swaps$0 = $57;
   }
   $58 = (($$0) + 40|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ((($$0) + (($51*44)|0)|0) + 40|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($59|0)==($61|0);
   do {
    if ($62) {
     $64 = (($$0) + 4|0);
     $65 = HEAP16[$64>>1]|0;
     $66 = ((($$0) + (($51*44)|0)|0) + 4|0);
     $67 = HEAP16[$66>>1]|0;
     $68 = ($65<<16>>16)==($67<<16>>16);
     if (!($68)) {
      $69 = ($65<<16>>16)<($67<<16>>16);
      if ($69) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 35;
       break;
      }
     }
     $70 = (($$0) + 12|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ((($$0) + (($51*44)|0)|0) + 12|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ($71|0)==($73|0);
     if (!($74)) {
      $75 = ($71>>>0)<($73>>>0);
      if ($75) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 35;
       break;
      }
     }
     $76 = (($$0) + 20|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ((($$0) + (($51*44)|0)|0) + 20|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($77|0)==($79|0);
     if (!($80)) {
      $81 = ($77|0)>($79|0);
      if ($81) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 35;
       break;
      }
     }
     $82 = HEAP32[$$0>>2]|0;
     $83 = HEAP32[$52>>2]|0;
     $84 = ($82|0)==($83|0);
     if ($84) {
      $90 = (($$0) + 24|0);
      $91 = Math_fround(HEAPF32[$90>>2]);
      $92 = ((($$0) + (($51*44)|0)|0) + 24|0);
      $93 = Math_fround(HEAPF32[$92>>2]);
      $94 = $91 > $93;
      if ($94) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 35;
       break;
      }
     } else {
      $85 = (($82) + 4|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = (($83) + 4|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = ($86|0)<($88|0);
      if ($89) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 35;
       break;
      }
     }
    } else {
     $63 = ($59>>>0)<($61>>>0);
     if ($63) {
      $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
     } else {
      label = 35;
     }
    }
   } while(0);
   L26: do {
    if ((label|0) == 35) {
     label = 0;
     $95 = ($$0|0)==($2|0);
     L28: do {
      if (!($95)) {
       $96 = ((($$0) + (($51*44)|0)|0) + 4|0);
       $97 = ((($$0) + (($51*44)|0)|0) + 12|0);
       $98 = ((($$0) + (($51*44)|0)|0) + 20|0);
       $99 = ((($$0) + (($51*44)|0)|0) + 24|0);
       $262 = $2;$__j$035 = $1;
       L30: while(1) {
        $242 = (($__j$035) + -4|0);
        $243 = HEAP32[$242>>2]|0;
        $244 = ($243|0)==($61|0);
        do {
         if ($244) {
          $246 = (($__j$035) + -40|0);
          $247 = HEAP16[$246>>1]|0;
          $248 = HEAP16[$96>>1]|0;
          $249 = ($247<<16>>16)==($248<<16>>16);
          if (!($249)) {
           $250 = ($247<<16>>16)<($248<<16>>16);
           if ($250) {
            break L30;
           } else {
            break;
           }
          }
          $251 = (($__j$035) + -32|0);
          $252 = HEAP32[$251>>2]|0;
          $253 = HEAP32[$97>>2]|0;
          $254 = ($252|0)==($253|0);
          if (!($254)) {
           $255 = ($252>>>0)<($253>>>0);
           if ($255) {
            break L30;
           } else {
            break;
           }
          }
          $256 = (($__j$035) + -24|0);
          $257 = HEAP32[$256>>2]|0;
          $258 = HEAP32[$98>>2]|0;
          $259 = ($257|0)==($258|0);
          if (!($259)) {
           $260 = ($257|0)>($258|0);
           if ($260) {
            break L30;
           } else {
            break;
           }
          }
          $261 = HEAP32[$262>>2]|0;
          $263 = HEAP32[$52>>2]|0;
          $264 = ($261|0)==($263|0);
          if ($264) {
           $270 = (($__j$035) + -20|0);
           $271 = Math_fround(HEAPF32[$270>>2]);
           $272 = Math_fround(HEAPF32[$99>>2]);
           $273 = $271 > $272;
           if ($273) {
            break L30;
           } else {
            break;
           }
          } else {
           $265 = (($261) + 4|0);
           $266 = HEAP32[$265>>2]|0;
           $267 = (($263) + 4|0);
           $268 = HEAP32[$267>>2]|0;
           $269 = ($266|0)<($268|0);
           if ($269) {
            break L30;
           } else {
            break;
           }
          }
         } else {
          $245 = ($243>>>0)<($61>>>0);
          if ($245) {
           break L30;
          }
         }
        } while(0);
        $274 = (($262) + -44|0);
        $275 = ($$0|0)==($274|0);
        if ($275) {
         break L28;
        } else {
         $__j$035$phi = $262;$262 = $274;$__j$035 = $__j$035$phi;
        }
       }
       dest=$__t$i33+0|0; src=$$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       dest=$$0+0|0; src=$262+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       dest=$262+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $276 = (($__n_swaps$0) + 1)|0;
       $__j$3 = $262;$__n_swaps$3 = $276;
       break L26;
      }
     } while(0);
     $100 = (($$0) + 44|0);
     $101 = HEAP32[$3>>2]|0;
     $102 = ($59|0)==($101|0);
     do {
      if ($102) {
       $104 = (($$0) + 4|0);
       $105 = HEAP16[$104>>1]|0;
       $106 = HEAP16[$4>>1]|0;
       $107 = ($105<<16>>16)==($106<<16>>16);
       if (!($107)) {
        $108 = ($105<<16>>16)<($106<<16>>16);
        if ($108) {
         $__i$1 = $100;
         break;
        } else {
         label = 48;
         break;
        }
       }
       $109 = (($$0) + 12|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = HEAP32[$5>>2]|0;
       $112 = ($110|0)==($111|0);
       if (!($112)) {
        $113 = ($110>>>0)<($111>>>0);
        if ($113) {
         $__i$1 = $100;
         break;
        } else {
         label = 48;
         break;
        }
       }
       $114 = (($$0) + 20|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = HEAP32[$6>>2]|0;
       $117 = ($115|0)==($116|0);
       if (!($117)) {
        $118 = ($115|0)>($116|0);
        if ($118) {
         $__i$1 = $100;
         break;
        } else {
         label = 48;
         break;
        }
       }
       $119 = HEAP32[$$0>>2]|0;
       $120 = HEAP32[$1>>2]|0;
       $121 = ($119|0)==($120|0);
       if ($121) {
        $127 = (($$0) + 24|0);
        $128 = Math_fround(HEAPF32[$127>>2]);
        $129 = Math_fround(HEAPF32[$7>>2]);
        $130 = $128 > $129;
        if ($130) {
         $__i$1 = $100;
         break;
        } else {
         label = 48;
         break;
        }
       } else {
        $122 = (($119) + 4|0);
        $123 = HEAP32[$122>>2]|0;
        $124 = (($120) + 4|0);
        $125 = HEAP32[$124>>2]|0;
        $126 = ($123|0)<($125|0);
        if ($126) {
         $__i$1 = $100;
         break;
        } else {
         label = 48;
         break;
        }
       }
      } else {
       $103 = ($59>>>0)<($101>>>0);
       if ($103) {
        $__i$1 = $100;
       } else {
        label = 48;
       }
      }
     } while(0);
     if ((label|0) == 48) {
      label = 0;
      $131 = ($100|0)==($1|0);
      if ($131) {
       label = 151;
       break L1;
      }
      $132 = (($$0) + 4|0);
      $133 = (($$0) + 12|0);
      $134 = (($$0) + 20|0);
      $135 = (($$0) + 24|0);
      $__i$038 = $100;
      L68: while(1) {
       $136 = (($__i$038) + 40|0);
       $137 = HEAP32[$136>>2]|0;
       $138 = ($59|0)==($137|0);
       do {
        if ($138) {
         $140 = HEAP16[$132>>1]|0;
         $141 = (($__i$038) + 4|0);
         $142 = HEAP16[$141>>1]|0;
         $143 = ($140<<16>>16)==($142<<16>>16);
         if (!($143)) {
          $144 = ($140<<16>>16)<($142<<16>>16);
          if ($144) {
           break L68;
          } else {
           break;
          }
         }
         $145 = HEAP32[$133>>2]|0;
         $146 = (($__i$038) + 12|0);
         $147 = HEAP32[$146>>2]|0;
         $148 = ($145|0)==($147|0);
         if (!($148)) {
          $149 = ($145>>>0)<($147>>>0);
          if ($149) {
           break L68;
          } else {
           break;
          }
         }
         $150 = HEAP32[$134>>2]|0;
         $151 = (($__i$038) + 20|0);
         $152 = HEAP32[$151>>2]|0;
         $153 = ($150|0)==($152|0);
         if (!($153)) {
          $154 = ($150|0)>($152|0);
          if ($154) {
           break L68;
          } else {
           break;
          }
         }
         $155 = HEAP32[$$0>>2]|0;
         $156 = HEAP32[$__i$038>>2]|0;
         $157 = ($155|0)==($156|0);
         if ($157) {
          $163 = Math_fround(HEAPF32[$135>>2]);
          $164 = (($__i$038) + 24|0);
          $165 = Math_fround(HEAPF32[$164>>2]);
          $166 = $163 > $165;
          if ($166) {
           break L68;
          } else {
           break;
          }
         } else {
          $158 = (($155) + 4|0);
          $159 = HEAP32[$158>>2]|0;
          $160 = (($156) + 4|0);
          $161 = HEAP32[$160>>2]|0;
          $162 = ($159|0)<($161|0);
          if ($162) {
           break L68;
          } else {
           break;
          }
         }
        } else {
         $139 = ($59>>>0)<($137>>>0);
         if ($139) {
          break L68;
         }
        }
       } while(0);
       $168 = (($__i$038) + 44|0);
       $169 = ($168|0)==($1|0);
       if ($169) {
        label = 151;
        break L1;
       } else {
        $__i$038 = $168;
       }
      }
      dest=$__t$i33+0|0; src=$__i$038+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$__i$038+0|0; src=$1+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$1+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $167 = (($__i$038) + 44|0);
      $__i$1 = $167;
     }
     $170 = ($__i$1|0)==($1|0);
     if ($170) {
      label = 151;
      break L1;
     }
     $171 = (($$0) + 24|0);
     $172 = (($$0) + 4|0);
     $173 = (($$0) + 12|0);
     $174 = (($$0) + 20|0);
     $__i$2$ph = $__i$1;$__j$1$ph = $1;
     while(1) {
      $175 = HEAP32[$58>>2]|0;
      $__i$2 = $__i$2$ph;
      L91: while(1) {
       $176 = (($__i$2) + 40|0);
       $177 = HEAP32[$176>>2]|0;
       $178 = ($175|0)==($177|0);
       do {
        if ($178) {
         $180 = HEAP16[$172>>1]|0;
         $181 = (($__i$2) + 4|0);
         $182 = HEAP16[$181>>1]|0;
         $183 = ($180<<16>>16)==($182<<16>>16);
         if (!($183)) {
          $184 = ($180<<16>>16)<($182<<16>>16);
          if ($184) {
           $__j$2 = $__j$1$ph;
           break L91;
          } else {
           break;
          }
         }
         $185 = HEAP32[$173>>2]|0;
         $186 = (($__i$2) + 12|0);
         $187 = HEAP32[$186>>2]|0;
         $188 = ($185|0)==($187|0);
         if (!($188)) {
          $189 = ($185>>>0)<($187>>>0);
          if ($189) {
           $__j$2 = $__j$1$ph;
           break L91;
          } else {
           break;
          }
         }
         $190 = HEAP32[$174>>2]|0;
         $191 = (($__i$2) + 20|0);
         $192 = HEAP32[$191>>2]|0;
         $193 = ($190|0)==($192|0);
         if (!($193)) {
          $194 = ($190|0)>($192|0);
          if ($194) {
           $__j$2 = $__j$1$ph;
           break L91;
          } else {
           break;
          }
         }
         $195 = HEAP32[$$0>>2]|0;
         $196 = HEAP32[$__i$2>>2]|0;
         $197 = ($195|0)==($196|0);
         if ($197) {
          $203 = Math_fround(HEAPF32[$171>>2]);
          $204 = (($__i$2) + 24|0);
          $205 = Math_fround(HEAPF32[$204>>2]);
          $206 = $203 > $205;
          if ($206) {
           $__j$2 = $__j$1$ph;
           break L91;
          } else {
           break;
          }
         } else {
          $198 = (($195) + 4|0);
          $199 = HEAP32[$198>>2]|0;
          $200 = (($196) + 4|0);
          $201 = HEAP32[$200>>2]|0;
          $202 = ($199|0)<($201|0);
          if ($202) {
           $__j$2 = $__j$1$ph;
           break L91;
          } else {
           break;
          }
         }
        } else {
         $179 = ($175>>>0)<($177>>>0);
         if ($179) {
          $__j$2 = $__j$1$ph;
          break L91;
         }
        }
       } while(0);
       $207 = (($__i$2) + 44|0);
       $__i$2 = $207;
      }
      while(1) {
       $208 = (($__j$2) + -44|0);
       $209 = (($__j$2) + -4|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = ($175|0)==($210|0);
       if (!($211)) {
        $212 = ($175>>>0)<($210>>>0);
        if ($212) {
         $__j$2 = $208;
         continue;
        } else {
         break;
        }
       }
       $213 = HEAP16[$172>>1]|0;
       $214 = (($__j$2) + -40|0);
       $215 = HEAP16[$214>>1]|0;
       $216 = ($213<<16>>16)==($215<<16>>16);
       if (!($216)) {
        $217 = ($213<<16>>16)<($215<<16>>16);
        if ($217) {
         $__j$2 = $208;
         continue;
        } else {
         break;
        }
       }
       $218 = HEAP32[$173>>2]|0;
       $219 = (($__j$2) + -32|0);
       $220 = HEAP32[$219>>2]|0;
       $221 = ($218|0)==($220|0);
       if (!($221)) {
        $222 = ($218>>>0)<($220>>>0);
        if ($222) {
         $__j$2 = $208;
         continue;
        } else {
         break;
        }
       }
       $223 = HEAP32[$174>>2]|0;
       $224 = (($__j$2) + -24|0);
       $225 = HEAP32[$224>>2]|0;
       $226 = ($223|0)==($225|0);
       if (!($226)) {
        $227 = ($223|0)>($225|0);
        if ($227) {
         $__j$2 = $208;
         continue;
        } else {
         break;
        }
       }
       $228 = HEAP32[$$0>>2]|0;
       $229 = HEAP32[$208>>2]|0;
       $230 = ($228|0)==($229|0);
       if ($230) {
        $236 = Math_fround(HEAPF32[$171>>2]);
        $237 = (($__j$2) + -20|0);
        $238 = Math_fround(HEAPF32[$237>>2]);
        $239 = $236 > $238;
        if ($239) {
         $__j$2 = $208;
         continue;
        } else {
         break;
        }
       } else {
        $231 = (($228) + 4|0);
        $232 = HEAP32[$231>>2]|0;
        $233 = (($229) + 4|0);
        $234 = HEAP32[$233>>2]|0;
        $235 = ($232|0)<($234|0);
        if ($235) {
         $__j$2 = $208;
         continue;
        } else {
         break;
        }
       }
      }
      $240 = ($__i$2>>>0)<($208>>>0);
      if (!($240)) {
       $$0 = $__i$2;
       continue L3;
      }
      dest=$__t$i33+0|0; src=$__i$2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$__i$2+0|0; src=$208+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$208+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $241 = (($__i$2) + 44|0);
      $__i$2$ph = $241;$__j$1$ph = $208;
     }
    }
   } while(0);
   $277 = (($$0) + 44|0);
   $278 = ($277>>>0)<($__j$3>>>0);
   L129: do {
    if ($278) {
     $__i$3$ph = $277;$__j$4$ph = $__j$3;$__m$0$ph = $52;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $279 = (($__m$0$ph) + 40|0);
      $280 = HEAP32[$279>>2]|0;
      $281 = (($__m$0$ph) + 4|0);
      $282 = (($__m$0$ph) + 12|0);
      $283 = (($__m$0$ph) + 20|0);
      $284 = (($__m$0$ph) + 24|0);
      $__i$3 = $__i$3$ph;
      L132: while(1) {
       $285 = (($__i$3) + 40|0);
       $286 = HEAP32[$285>>2]|0;
       $287 = ($286|0)==($280|0);
       do {
        if ($287) {
         $289 = (($__i$3) + 4|0);
         $290 = HEAP16[$289>>1]|0;
         $291 = HEAP16[$281>>1]|0;
         $292 = ($290<<16>>16)==($291<<16>>16);
         if (!($292)) {
          $293 = ($290<<16>>16)<($291<<16>>16);
          if ($293) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L132;
          }
         }
         $294 = (($__i$3) + 12|0);
         $295 = HEAP32[$294>>2]|0;
         $296 = HEAP32[$282>>2]|0;
         $297 = ($295|0)==($296|0);
         if (!($297)) {
          $298 = ($295>>>0)<($296>>>0);
          if ($298) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L132;
          }
         }
         $299 = (($__i$3) + 20|0);
         $300 = HEAP32[$299>>2]|0;
         $301 = HEAP32[$283>>2]|0;
         $302 = ($300|0)==($301|0);
         if (!($302)) {
          $303 = ($300|0)>($301|0);
          if ($303) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L132;
          }
         }
         $304 = HEAP32[$__i$3>>2]|0;
         $305 = HEAP32[$__m$0$ph>>2]|0;
         $306 = ($304|0)==($305|0);
         if ($306) {
          $312 = (($__i$3) + 24|0);
          $313 = Math_fround(HEAPF32[$312>>2]);
          $314 = Math_fround(HEAPF32[$284>>2]);
          $315 = $313 > $314;
          if ($315) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L132;
          }
         } else {
          $307 = (($304) + 4|0);
          $308 = HEAP32[$307>>2]|0;
          $309 = (($305) + 4|0);
          $310 = HEAP32[$309>>2]|0;
          $311 = ($308|0)<($310|0);
          if ($311) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L132;
          }
         }
        } else {
         $288 = ($286>>>0)<($280>>>0);
         if (!($288)) {
          $__j$5 = $__j$4$ph;
          break L132;
         }
        }
       } while(0);
       $316 = (($__i$3) + 44|0);
       $__i$3 = $316;
      }
      while(1) {
       $317 = (($__j$5) + -44|0);
       $318 = (($__j$5) + -4|0);
       $319 = HEAP32[$318>>2]|0;
       $320 = ($319|0)==($280|0);
       if (!($320)) {
        $321 = ($319>>>0)<($280>>>0);
        if ($321) {
         break;
        } else {
         $__j$5 = $317;
         continue;
        }
       }
       $322 = (($__j$5) + -40|0);
       $323 = HEAP16[$322>>1]|0;
       $324 = HEAP16[$281>>1]|0;
       $325 = ($323<<16>>16)==($324<<16>>16);
       if (!($325)) {
        $326 = ($323<<16>>16)<($324<<16>>16);
        if ($326) {
         break;
        } else {
         $__j$5 = $317;
         continue;
        }
       }
       $327 = (($__j$5) + -32|0);
       $328 = HEAP32[$327>>2]|0;
       $329 = HEAP32[$282>>2]|0;
       $330 = ($328|0)==($329|0);
       if (!($330)) {
        $331 = ($328>>>0)<($329>>>0);
        if ($331) {
         break;
        } else {
         $__j$5 = $317;
         continue;
        }
       }
       $332 = (($__j$5) + -24|0);
       $333 = HEAP32[$332>>2]|0;
       $334 = HEAP32[$283>>2]|0;
       $335 = ($333|0)==($334|0);
       if (!($335)) {
        $336 = ($333|0)>($334|0);
        if ($336) {
         break;
        } else {
         $__j$5 = $317;
         continue;
        }
       }
       $337 = HEAP32[$317>>2]|0;
       $338 = HEAP32[$__m$0$ph>>2]|0;
       $339 = ($337|0)==($338|0);
       if ($339) {
        $345 = (($__j$5) + -20|0);
        $346 = Math_fround(HEAPF32[$345>>2]);
        $347 = Math_fround(HEAPF32[$284>>2]);
        $348 = $346 > $347;
        if ($348) {
         break;
        } else {
         $__j$5 = $317;
         continue;
        }
       } else {
        $340 = (($337) + 4|0);
        $341 = HEAP32[$340>>2]|0;
        $342 = (($338) + 4|0);
        $343 = HEAP32[$342>>2]|0;
        $344 = ($341|0)<($343|0);
        if ($344) {
         break;
        } else {
         $__j$5 = $317;
         continue;
        }
       }
      }
      $349 = ($__i$3>>>0)>($317>>>0);
      if ($349) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L129;
      }
      dest=$__t$i33+0|0; src=$__i$3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$__i$3+0|0; src=$317+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$317+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $350 = (($__n_swaps$4$ph) + 1)|0;
      $351 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $351 ? $317 : $__m$0$ph;
      $352 = (($__i$3) + 44|0);
      $__i$3$ph = $352;$__j$4$ph = $317;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $350;
     }
    } else {
     $__i$4 = $277;$__m$2 = $52;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $353 = ($__i$4|0)==($__m$2|0);
   L170: do {
    if ($353) {
     $__n_swaps$6 = $__n_swaps$5;
    } else {
     $354 = (($__m$2) + 40|0);
     $355 = HEAP32[$354>>2]|0;
     $356 = (($__i$4) + 40|0);
     $357 = HEAP32[$356>>2]|0;
     $358 = ($355|0)==($357|0);
     do {
      if ($358) {
       $360 = (($__m$2) + 4|0);
       $361 = HEAP16[$360>>1]|0;
       $362 = (($__i$4) + 4|0);
       $363 = HEAP16[$362>>1]|0;
       $364 = ($361<<16>>16)==($363<<16>>16);
       if (!($364)) {
        $365 = ($361<<16>>16)<($363<<16>>16);
        if ($365) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L170;
        }
       }
       $366 = (($__m$2) + 12|0);
       $367 = HEAP32[$366>>2]|0;
       $368 = (($__i$4) + 12|0);
       $369 = HEAP32[$368>>2]|0;
       $370 = ($367|0)==($369|0);
       if (!($370)) {
        $371 = ($367>>>0)<($369>>>0);
        if ($371) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L170;
        }
       }
       $372 = (($__m$2) + 20|0);
       $373 = HEAP32[$372>>2]|0;
       $374 = (($__i$4) + 20|0);
       $375 = HEAP32[$374>>2]|0;
       $376 = ($373|0)==($375|0);
       if (!($376)) {
        $377 = ($373|0)>($375|0);
        if ($377) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L170;
        }
       }
       $378 = HEAP32[$__m$2>>2]|0;
       $379 = HEAP32[$__i$4>>2]|0;
       $380 = ($378|0)==($379|0);
       if ($380) {
        $386 = (($__m$2) + 24|0);
        $387 = Math_fround(HEAPF32[$386>>2]);
        $388 = (($__i$4) + 24|0);
        $389 = Math_fround(HEAPF32[$388>>2]);
        $390 = $387 > $389;
        if ($390) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L170;
        }
       } else {
        $381 = (($378) + 4|0);
        $382 = HEAP32[$381>>2]|0;
        $383 = (($379) + 4|0);
        $384 = HEAP32[$383>>2]|0;
        $385 = ($382|0)<($384|0);
        if ($385) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L170;
        }
       }
      } else {
       $359 = ($355>>>0)<($357>>>0);
       if (!($359)) {
        $__n_swaps$6 = $__n_swaps$5;
        break L170;
       }
      }
     } while(0);
     dest=$__t$i33+0|0; src=$__i$4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     dest=$__i$4+0|0; src=$__m$2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     dest=$__m$2+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $391 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $391;
    }
   } while(0);
   $392 = ($__n_swaps$6|0)==(0);
   if ($392) {
    $393 = (__ZNSt3__127__insertion_sort_incompleteIR26RenderDeferredObjectSorterP16RenderObjectDataEEbT0_S5_T_($$0,$__i$4,0)|0);
    $394 = (($__i$4) + 44|0);
    $395 = (__ZNSt3__127__insertion_sort_incompleteIR26RenderDeferredObjectSorterP16RenderObjectDataEEbT0_S5_T_($394,$$01$ph,0)|0);
    if ($395) {
     label = 146;
     break;
    }
    if ($393) {
     $$0 = $394;
     continue;
    }
   }
   $396 = $__i$4;
   $397 = (($396) - ($8))|0;
   $398 = (($0) - ($396))|0;
   $399 = ($397|0)<($398|0);
   if (!($399)) {
    label = 150;
    break;
   }
   __ZNSt3__16__sortIR26RenderDeferredObjectSorterP16RenderObjectDataEEvT0_S5_T_($$0,$__i$4,$__comp);
   $400 = (($__i$4) + 44|0);
   $$0 = $400;
  }
  if ((label|0) == 146) {
   label = 0;
   if ($393) {
    label = 151;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 150) {
   label = 0;
   $401 = (($__i$4) + 44|0);
   __ZNSt3__16__sortIR26RenderDeferredObjectSorterP16RenderObjectDataEEvT0_S5_T_($401,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $11 = HEAP32[$3>>2]|0;
  $12 = (($$0) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  do {
   if ($14) {
    $16 = HEAP16[$4>>1]|0;
    $17 = (($$0) + 4|0);
    $18 = HEAP16[$17>>1]|0;
    $19 = ($16<<16>>16)==($18<<16>>16);
    if (!($19)) {
     $20 = ($16<<16>>16)<($18<<16>>16);
     if ($20) {
      break;
     }
     STACKTOP = sp;return;
    }
    $21 = HEAP32[$5>>2]|0;
    $22 = (($$0) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($21|0)==($23|0);
    if (!($24)) {
     $25 = ($21>>>0)<($23>>>0);
     if ($25) {
      break;
     }
     STACKTOP = sp;return;
    }
    $26 = HEAP32[$6>>2]|0;
    $27 = (($$0) + 20|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($26|0)==($28|0);
    if (!($29)) {
     $30 = ($26|0)>($28|0);
     if ($30) {
      break;
     }
     STACKTOP = sp;return;
    }
    $31 = HEAP32[$1>>2]|0;
    $32 = HEAP32[$$0>>2]|0;
    $33 = ($31|0)==($32|0);
    if ($33) {
     $39 = Math_fround(HEAPF32[$7>>2]);
     $40 = (($$0) + 24|0);
     $41 = Math_fround(HEAPF32[$40>>2]);
     $42 = $39 > $41;
     if ($42) {
      break;
     }
     STACKTOP = sp;return;
    } else {
     $34 = (($31) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($32) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($35|0)<($37|0);
     if ($38) {
      break;
     }
     STACKTOP = sp;return;
    }
   } else {
    $15 = ($11>>>0)<($13>>>0);
    if (!($15)) {
     STACKTOP = sp;return;
    }
   }
  } while(0);
  dest=$__t$i33+0|0; src=$$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$$0+0|0; src=$1+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$1+0|0; src=$__t$i33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 else if ((label|0) == 16) {
  $43 = (($$0) + 44|0);
  (__ZNSt3__17__sort3IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($$0,$43,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 17) {
  $44 = (($$0) + 44|0);
  $45 = (($$0) + 88|0);
  (__ZNSt3__17__sort4IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_T_($$0,$44,$45,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 18) {
  $46 = (($$0) + 44|0);
  $47 = (($$0) + 88|0);
  $48 = (($$0) + 132|0);
  (__ZNSt3__17__sort5IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_S5_T_($$0,$46,$47,$48,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 20) {
  __ZNSt3__118__insertion_sort_3IR26RenderDeferredObjectSorterP16RenderObjectDataEEvT0_S5_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 151) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $$0$i = 0, $$0$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__t$i10 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i10 = sp;
 $0 = (($__y) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__x) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 do {
  if ($4) {
   $6 = (($__y) + 4|0);
   $7 = HEAP16[$6>>1]|0;
   $8 = (($__x) + 4|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = ($7<<16>>16)==($9<<16>>16);
   if (!($10)) {
    $11 = ($7<<16>>16)<($9<<16>>16);
    $$0$i = $11;
    break;
   }
   $12 = (($__y) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($__x) + 12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($13|0)==($15|0);
   if (!($16)) {
    $17 = ($13>>>0)<($15>>>0);
    $$0$i = $17;
    break;
   }
   $18 = (($__y) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__x) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if (!($22)) {
    $23 = ($19|0)>($21|0);
    $$0$i = $23;
    break;
   }
   $24 = HEAP32[$__y>>2]|0;
   $25 = HEAP32[$__x>>2]|0;
   $26 = ($24|0)==($25|0);
   if ($26) {
    $32 = (($__y) + 24|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = (($__x) + 24|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = $33 > $35;
    $$0$i = $36;
    break;
   } else {
    $27 = (($24) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($25) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($28|0)<($30|0);
    $$0$i = $31;
    break;
   }
  } else {
   $5 = ($1>>>0)<($3>>>0);
   $$0$i = $5;
  }
 } while(0);
 $37 = (($__z) + 40|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==($1|0);
 do {
  if ($39) {
   $41 = (($__z) + 4|0);
   $42 = HEAP16[$41>>1]|0;
   $43 = (($__y) + 4|0);
   $44 = HEAP16[$43>>1]|0;
   $45 = ($42<<16>>16)==($44<<16>>16);
   if (!($45)) {
    $46 = ($42<<16>>16)<($44<<16>>16);
    $$0$i12 = $46;
    break;
   }
   $47 = (($__z) + 12|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($__y) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($48|0)==($50|0);
   if (!($51)) {
    $52 = ($48>>>0)<($50>>>0);
    $$0$i12 = $52;
    break;
   }
   $53 = (($__z) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($__y) + 20|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($54|0)==($56|0);
   if (!($57)) {
    $58 = ($54|0)>($56|0);
    $$0$i12 = $58;
    break;
   }
   $59 = HEAP32[$__z>>2]|0;
   $60 = HEAP32[$__y>>2]|0;
   $61 = ($59|0)==($60|0);
   if ($61) {
    $67 = (($__z) + 24|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = (($__y) + 24|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = $68 > $70;
    $$0$i12 = $71;
    break;
   } else {
    $62 = (($59) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($60) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($63|0)<($65|0);
    $$0$i12 = $66;
    break;
   }
  } else {
   $40 = ($38>>>0)<($1>>>0);
   $$0$i12 = $40;
  }
 } while(0);
 if (!($$0$i)) {
  if (!($$0$i12)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  dest=$__t$i10+0|0; src=$__y+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__y+0|0; src=$__z+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__z+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $72 = HEAP32[$0>>2]|0;
  $73 = HEAP32[$2>>2]|0;
  $74 = ($72|0)==($73|0);
  do {
   if ($74) {
    $76 = (($__y) + 4|0);
    $77 = HEAP16[$76>>1]|0;
    $78 = (($__x) + 4|0);
    $79 = HEAP16[$78>>1]|0;
    $80 = ($77<<16>>16)==($79<<16>>16);
    if (!($80)) {
     $81 = ($77<<16>>16)<($79<<16>>16);
     if ($81) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $82 = (($__y) + 12|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($__x) + 12|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if (!($86)) {
     $87 = ($83>>>0)<($85>>>0);
     if ($87) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $88 = (($__y) + 20|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($__x) + 20|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($89|0)==($91|0);
    if (!($92)) {
     $93 = ($89|0)>($91|0);
     if ($93) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $94 = HEAP32[$__y>>2]|0;
    $95 = HEAP32[$__x>>2]|0;
    $96 = ($94|0)==($95|0);
    if ($96) {
     $102 = (($__y) + 24|0);
     $103 = Math_fround(HEAPF32[$102>>2]);
     $104 = (($__x) + 24|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = $103 > $105;
     if ($106) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    } else {
     $97 = (($94) + 4|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($95) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = ($98|0)<($100|0);
     if ($101) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $75 = ($72>>>0)<($73>>>0);
    if (!($75)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  dest=$__t$i10+0|0; src=$__x+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__x+0|0; src=$__y+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__y+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($$0$i12) {
  dest=$__t$i10+0|0; src=$__x+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__x+0|0; src=$__z+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__z+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 dest=$__t$i10+0|0; src=$__x+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x+0|0; src=$__y+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__y+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $107 = HEAP32[$37>>2]|0;
 $108 = HEAP32[$0>>2]|0;
 $109 = ($107|0)==($108|0);
 do {
  if ($109) {
   $111 = (($__z) + 4|0);
   $112 = HEAP16[$111>>1]|0;
   $113 = (($__y) + 4|0);
   $114 = HEAP16[$113>>1]|0;
   $115 = ($112<<16>>16)==($114<<16>>16);
   if (!($115)) {
    $116 = ($112<<16>>16)<($114<<16>>16);
    if ($116) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $117 = (($__z) + 12|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($__y) + 12|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ($118|0)==($120|0);
   if (!($121)) {
    $122 = ($118>>>0)<($120>>>0);
    if ($122) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $123 = (($__z) + 20|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = (($__y) + 20|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($124|0)==($126|0);
   if (!($127)) {
    $128 = ($124|0)>($126|0);
    if ($128) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $129 = HEAP32[$__z>>2]|0;
   $130 = HEAP32[$__y>>2]|0;
   $131 = ($129|0)==($130|0);
   if ($131) {
    $137 = (($__z) + 24|0);
    $138 = Math_fround(HEAPF32[$137>>2]);
    $139 = (($__y) + 24|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = $138 > $140;
    if ($141) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   } else {
    $132 = (($129) + 4|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = (($130) + 4|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = ($133|0)<($135|0);
    if ($136) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $110 = ($107>>>0)<($108>>>0);
   if (!($110)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 dest=$__t$i10+0|0; src=$__y+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__y+0|0; src=$__z+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__z+0|0; src=$__t$i10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__t$i8 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i8 = sp;
 $0 = (__ZNSt3__17__sort3IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__x1,$__x2,$__x3,0)|0);
 $1 = (($__x4) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__x3) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   $7 = (($__x4) + 4|0);
   $8 = HEAP16[$7>>1]|0;
   $9 = (($__x3) + 4|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = ($8<<16>>16)==($10<<16>>16);
   if (!($11)) {
    $12 = ($8<<16>>16)<($10<<16>>16);
    if ($12) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $13 = (($__x4) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($__x3) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14|0)==($16|0);
   if (!($17)) {
    $18 = ($14>>>0)<($16>>>0);
    if ($18) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $19 = (($__x4) + 20|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($__x3) + 20|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($20|0)==($22|0);
   if (!($23)) {
    $24 = ($20|0)>($22|0);
    if ($24) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $25 = HEAP32[$__x4>>2]|0;
   $26 = HEAP32[$__x3>>2]|0;
   $27 = ($25|0)==($26|0);
   if ($27) {
    $33 = (($__x4) + 24|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($__x3) + 24|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = $34 > $36;
    if ($37) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $28 = (($25) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($26) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($29|0)<($31|0);
    if ($32) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $6 = ($2>>>0)<($4>>>0);
   if (!($6)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i8+0|0; src=$__x3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x3+0|0; src=$__x4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x4+0|0; src=$__t$i8+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $38 = (($0) + 1)|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = (($__x2) + 40|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)==($41|0);
 do {
  if ($42) {
   $44 = (($__x3) + 4|0);
   $45 = HEAP16[$44>>1]|0;
   $46 = (($__x2) + 4|0);
   $47 = HEAP16[$46>>1]|0;
   $48 = ($45<<16>>16)==($47<<16>>16);
   if (!($48)) {
    $49 = ($45<<16>>16)<($47<<16>>16);
    if ($49) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $50 = (($__x3) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($__x2) + 12|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($51|0)==($53|0);
   if (!($54)) {
    $55 = ($51>>>0)<($53>>>0);
    if ($55) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $56 = (($__x3) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($__x2) + 20|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($57|0)==($59|0);
   if (!($60)) {
    $61 = ($57|0)>($59|0);
    if ($61) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $62 = HEAP32[$__x3>>2]|0;
   $63 = HEAP32[$__x2>>2]|0;
   $64 = ($62|0)==($63|0);
   if ($64) {
    $70 = (($__x3) + 24|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = (($__x2) + 24|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = $71 > $73;
    if ($74) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $65 = (($62) + 4|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($63) + 4|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ($66|0)<($68|0);
    if ($69) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $43 = ($39>>>0)<($41>>>0);
   if (!($43)) {
    $__r$0 = $38;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i8+0|0; src=$__x2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x2+0|0; src=$__x3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x3+0|0; src=$__t$i8+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $75 = (($0) + 2)|0;
 $76 = HEAP32[$40>>2]|0;
 $77 = (($__x1) + 40|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($76|0)==($78|0);
 do {
  if ($79) {
   $81 = (($__x2) + 4|0);
   $82 = HEAP16[$81>>1]|0;
   $83 = (($__x1) + 4|0);
   $84 = HEAP16[$83>>1]|0;
   $85 = ($82<<16>>16)==($84<<16>>16);
   if (!($85)) {
    $86 = ($82<<16>>16)<($84<<16>>16);
    if ($86) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $87 = (($__x2) + 12|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($__x1) + 12|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($88|0)==($90|0);
   if (!($91)) {
    $92 = ($88>>>0)<($90>>>0);
    if ($92) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $93 = (($__x2) + 20|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($__x1) + 20|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($94|0)==($96|0);
   if (!($97)) {
    $98 = ($94|0)>($96|0);
    if ($98) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $99 = HEAP32[$__x2>>2]|0;
   $100 = HEAP32[$__x1>>2]|0;
   $101 = ($99|0)==($100|0);
   if ($101) {
    $107 = (($__x2) + 24|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $109 = (($__x1) + 24|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $111 = $108 > $110;
    if ($111) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $102 = (($99) + 4|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($100) + 4|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($103|0)<($105|0);
    if ($106) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $80 = ($76>>>0)<($78>>>0);
   if (!($80)) {
    $__r$0 = $75;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i8+0|0; src=$__x1+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x1+0|0; src=$__x2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x2+0|0; src=$__t$i8+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $112 = (($0) + 3)|0;
 $__r$0 = $112;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__t$i12 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i12 = sp;
 $0 = (__ZNSt3__17__sort4IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = (($__x5) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__x4) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   $7 = (($__x5) + 4|0);
   $8 = HEAP16[$7>>1]|0;
   $9 = (($__x4) + 4|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = ($8<<16>>16)==($10<<16>>16);
   if (!($11)) {
    $12 = ($8<<16>>16)<($10<<16>>16);
    if ($12) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $13 = (($__x5) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($__x4) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14|0)==($16|0);
   if (!($17)) {
    $18 = ($14>>>0)<($16>>>0);
    if ($18) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $19 = (($__x5) + 20|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($__x4) + 20|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($20|0)==($22|0);
   if (!($23)) {
    $24 = ($20|0)>($22|0);
    if ($24) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $25 = HEAP32[$__x5>>2]|0;
   $26 = HEAP32[$__x4>>2]|0;
   $27 = ($25|0)==($26|0);
   if ($27) {
    $33 = (($__x5) + 24|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($__x4) + 24|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = $34 > $36;
    if ($37) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $28 = (($25) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($26) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($29|0)<($31|0);
    if ($32) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $6 = ($2>>>0)<($4>>>0);
   if (!($6)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i12+0|0; src=$__x4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x4+0|0; src=$__x5+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x5+0|0; src=$__t$i12+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $38 = (($0) + 1)|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = (($__x3) + 40|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)==($41|0);
 do {
  if ($42) {
   $44 = (($__x4) + 4|0);
   $45 = HEAP16[$44>>1]|0;
   $46 = (($__x3) + 4|0);
   $47 = HEAP16[$46>>1]|0;
   $48 = ($45<<16>>16)==($47<<16>>16);
   if (!($48)) {
    $49 = ($45<<16>>16)<($47<<16>>16);
    if ($49) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $50 = (($__x4) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($__x3) + 12|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($51|0)==($53|0);
   if (!($54)) {
    $55 = ($51>>>0)<($53>>>0);
    if ($55) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $56 = (($__x4) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($__x3) + 20|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($57|0)==($59|0);
   if (!($60)) {
    $61 = ($57|0)>($59|0);
    if ($61) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $62 = HEAP32[$__x4>>2]|0;
   $63 = HEAP32[$__x3>>2]|0;
   $64 = ($62|0)==($63|0);
   if ($64) {
    $70 = (($__x4) + 24|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = (($__x3) + 24|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = $71 > $73;
    if ($74) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $65 = (($62) + 4|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($63) + 4|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ($66|0)<($68|0);
    if ($69) {
     break;
    } else {
     $__r$0 = $38;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $43 = ($39>>>0)<($41>>>0);
   if (!($43)) {
    $__r$0 = $38;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i12+0|0; src=$__x3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x3+0|0; src=$__x4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x4+0|0; src=$__t$i12+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $75 = (($0) + 2)|0;
 $76 = HEAP32[$40>>2]|0;
 $77 = (($__x2) + 40|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($76|0)==($78|0);
 do {
  if ($79) {
   $81 = (($__x3) + 4|0);
   $82 = HEAP16[$81>>1]|0;
   $83 = (($__x2) + 4|0);
   $84 = HEAP16[$83>>1]|0;
   $85 = ($82<<16>>16)==($84<<16>>16);
   if (!($85)) {
    $86 = ($82<<16>>16)<($84<<16>>16);
    if ($86) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $87 = (($__x3) + 12|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($__x2) + 12|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($88|0)==($90|0);
   if (!($91)) {
    $92 = ($88>>>0)<($90>>>0);
    if ($92) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $93 = (($__x3) + 20|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($__x2) + 20|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($94|0)==($96|0);
   if (!($97)) {
    $98 = ($94|0)>($96|0);
    if ($98) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $99 = HEAP32[$__x3>>2]|0;
   $100 = HEAP32[$__x2>>2]|0;
   $101 = ($99|0)==($100|0);
   if ($101) {
    $107 = (($__x3) + 24|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $109 = (($__x2) + 24|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $111 = $108 > $110;
    if ($111) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $102 = (($99) + 4|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($100) + 4|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($103|0)<($105|0);
    if ($106) {
     break;
    } else {
     $__r$0 = $75;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $80 = ($76>>>0)<($78>>>0);
   if (!($80)) {
    $__r$0 = $75;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i12+0|0; src=$__x2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x2+0|0; src=$__x3+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x3+0|0; src=$__t$i12+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $112 = (($0) + 3)|0;
 $113 = HEAP32[$77>>2]|0;
 $114 = (($__x1) + 40|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ($113|0)==($115|0);
 do {
  if ($116) {
   $118 = (($__x2) + 4|0);
   $119 = HEAP16[$118>>1]|0;
   $120 = (($__x1) + 4|0);
   $121 = HEAP16[$120>>1]|0;
   $122 = ($119<<16>>16)==($121<<16>>16);
   if (!($122)) {
    $123 = ($119<<16>>16)<($121<<16>>16);
    if ($123) {
     break;
    } else {
     $__r$0 = $112;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $124 = (($__x2) + 12|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = (($__x1) + 12|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($125|0)==($127|0);
   if (!($128)) {
    $129 = ($125>>>0)<($127>>>0);
    if ($129) {
     break;
    } else {
     $__r$0 = $112;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $130 = (($__x2) + 20|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = (($__x1) + 20|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($131|0)==($133|0);
   if (!($134)) {
    $135 = ($131|0)>($133|0);
    if ($135) {
     break;
    } else {
     $__r$0 = $112;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $136 = HEAP32[$__x2>>2]|0;
   $137 = HEAP32[$__x1>>2]|0;
   $138 = ($136|0)==($137|0);
   if ($138) {
    $144 = (($__x2) + 24|0);
    $145 = Math_fround(HEAPF32[$144>>2]);
    $146 = (($__x1) + 24|0);
    $147 = Math_fround(HEAPF32[$146>>2]);
    $148 = $145 > $147;
    if ($148) {
     break;
    } else {
     $__r$0 = $112;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $139 = (($136) + 4|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = (($137) + 4|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = ($140|0)<($142|0);
    if ($143) {
     break;
    } else {
     $__r$0 = $112;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $117 = ($113>>>0)<($115>>>0);
   if (!($117)) {
    $__r$0 = $112;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 dest=$__t$i12+0|0; src=$__x1+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x1+0|0; src=$__x2+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$__x2+0|0; src=$__t$i12+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $149 = (($0) + 4)|0;
 $__r$0 = $149;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IR26RenderDeferredObjectSorterP16RenderObjectDataEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $__i$06 = 0, $__j$05 = 0, $__j$05$phi = 0, $__k$0$lcssa = 0, $__k$04 = 0;
 var $__t$sroa$2 = 0, $__t$sroa$7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$sroa$2 = sp + 16|0;
 $__t$sroa$7 = sp;
 $0 = (($__first) + 88|0);
 $1 = (($__first) + 44|0);
 (__ZNSt3__17__sort3IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 132|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $__i$06 = $2;$__j$05 = $0;
 while(1) {
  $4 = (($__i$06) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($__j$05) + 40|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $10 = (($__i$06) + 4|0);
    $11 = HEAP16[$10>>1]|0;
    $12 = (($__j$05) + 4|0);
    $13 = HEAP16[$12>>1]|0;
    $14 = ($11<<16>>16)==($13<<16>>16);
    if (!($14)) {
     $15 = ($11<<16>>16)<($13<<16>>16);
     if ($15) {
      $63 = $11;
      label = 15;
      break;
     } else {
      break;
     }
    }
    $16 = (($__i$06) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($__j$05) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($17|0)==($19|0);
    if (!($20)) {
     $21 = ($17>>>0)<($19>>>0);
     if ($21) {
      $63 = $11;
      label = 15;
      break;
     } else {
      break;
     }
    }
    $22 = (($__i$06) + 20|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($__j$05) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($23|0)==($25|0);
    if (!($26)) {
     $27 = ($23|0)>($25|0);
     if ($27) {
      $63 = $11;
      label = 15;
      break;
     } else {
      break;
     }
    }
    $28 = HEAP32[$__i$06>>2]|0;
    $29 = HEAP32[$__j$05>>2]|0;
    $30 = ($28|0)==($29|0);
    if ($30) {
     $36 = (($__i$06) + 24|0);
     $37 = Math_fround(HEAPF32[$36>>2]);
     $38 = (($__j$05) + 24|0);
     $39 = Math_fround(HEAPF32[$38>>2]);
     $40 = $37 > $39;
     if ($40) {
      $63 = $11;
      label = 15;
      break;
     } else {
      break;
     }
    } else {
     $31 = (($28) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($29) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($32|0)<($34|0);
     if ($35) {
      $63 = $11;
      label = 15;
      break;
     } else {
      break;
     }
    }
   } else {
    $9 = ($5>>>0)<($7>>>0);
    if ($9) {
     $$phi$trans$insert = (($__i$06) + 4|0);
     $$pre = HEAP16[$$phi$trans$insert>>1]|0;
     $63 = $$pre;
     label = 15;
    }
   }
  } while(0);
  if ((label|0) == 15) {
   label = 0;
   $41 = HEAP32[$__i$06>>2]|0;
   $42 = (($__i$06) + 6|0);
   ;HEAP16[$__t$sroa$2+0>>1]=HEAP16[$42+0>>1]|0;HEAP16[$__t$sroa$2+2>>1]=HEAP16[$42+2>>1]|0;HEAP16[$__t$sroa$2+4>>1]=HEAP16[$42+4>>1]|0;
   $43 = (($__i$06) + 12|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($__i$06) + 16|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($__i$06) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($__i$06) + 24|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = (($__i$06) + 28|0);
   ;HEAP32[$__t$sroa$7+0>>2]=HEAP32[$51+0>>2]|0;HEAP32[$__t$sroa$7+4>>2]=HEAP32[$51+4>>2]|0;HEAP32[$__t$sroa$7+8>>2]=HEAP32[$51+8>>2]|0;
   $52 = HEAP32[$4>>2]|0;
   $53 = (($41) + 4|0);
   dest=$__i$06+0|0; src=$__j$05+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $54 = ($__j$05|0)==($__first|0);
   L24: do {
    if ($54) {
     $__k$0$lcssa = $__first;
    } else {
     $__k$04 = $__j$05;
     while(1) {
      $55 = (($__k$04) + -44|0);
      $56 = (($__k$04) + -4|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($52|0)==($57|0);
      do {
       if ($58) {
        $60 = (($__k$04) + -40|0);
        $61 = HEAP16[$60>>1]|0;
        $62 = ($63<<16>>16)==($61<<16>>16);
        if (!($62)) {
         $64 = ($63<<16>>16)<($61<<16>>16);
         if ($64) {
          break;
         } else {
          $__k$0$lcssa = $__k$04;
          break L24;
         }
        }
        $65 = (($__k$04) + -32|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = ($44|0)==($66|0);
        if (!($67)) {
         $68 = ($44>>>0)<($66>>>0);
         if ($68) {
          break;
         } else {
          $__k$0$lcssa = $__k$04;
          break L24;
         }
        }
        $69 = (($__k$04) + -24|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($48|0)==($70|0);
        if (!($71)) {
         $72 = ($48|0)>($70|0);
         if ($72) {
          break;
         } else {
          $__k$0$lcssa = $__k$04;
          break L24;
         }
        }
        $73 = HEAP32[$55>>2]|0;
        $74 = ($41|0)==($73|0);
        if ($74) {
         $79 = (($__k$04) + -20|0);
         $80 = Math_fround(HEAPF32[$79>>2]);
         $81 = $50 > $80;
         if ($81) {
          break;
         } else {
          $__k$0$lcssa = $__k$04;
          break L24;
         }
        } else {
         $75 = HEAP32[$53>>2]|0;
         $76 = (($73) + 4|0);
         $77 = HEAP32[$76>>2]|0;
         $78 = ($75|0)<($77|0);
         if ($78) {
          break;
         } else {
          $__k$0$lcssa = $__k$04;
          break L24;
         }
        }
       } else {
        $59 = ($52>>>0)<($57>>>0);
        if (!($59)) {
         $__k$0$lcssa = $__k$04;
         break L24;
        }
       }
      } while(0);
      dest=$__k$04+0|0; src=$55+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $82 = ($55|0)==($__first|0);
      if ($82) {
       $__k$0$lcssa = $__first;
       break;
      } else {
       $__k$04 = $55;
      }
     }
    }
   } while(0);
   HEAP32[$__k$0$lcssa>>2] = $41;
   $83 = (($__k$0$lcssa) + 4|0);
   HEAP16[$83>>1] = $63;
   $84 = (($__k$0$lcssa) + 6|0);
   ;HEAP16[$84+0>>1]=HEAP16[$__t$sroa$2+0>>1]|0;HEAP16[$84+2>>1]=HEAP16[$__t$sroa$2+2>>1]|0;HEAP16[$84+4>>1]=HEAP16[$__t$sroa$2+4>>1]|0;
   $85 = (($__k$0$lcssa) + 12|0);
   HEAP32[$85>>2] = $44;
   $86 = (($__k$0$lcssa) + 16|0);
   HEAP32[$86>>2] = $46;
   $87 = (($__k$0$lcssa) + 20|0);
   HEAP32[$87>>2] = $48;
   $88 = (($__k$0$lcssa) + 24|0);
   HEAPF32[$88>>2] = $50;
   $89 = (($__k$0$lcssa) + 28|0);
   ;HEAP32[$89+0>>2]=HEAP32[$__t$sroa$7+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$__t$sroa$7+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$__t$sroa$7+8>>2]|0;
   $90 = (($__k$0$lcssa) + 40|0);
   HEAP32[$90>>2] = $52;
  }
  $91 = (($__i$06) + 44|0);
  $92 = ($91|0)==($__last|0);
  if ($92) {
   break;
  } else {
   $__j$05$phi = $__i$06;$__i$06 = $91;$__j$05 = $__j$05$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIR26RenderDeferredObjectSorterP16RenderObjectDataEEbT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$3 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0;
 var $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$012 = 0, $__count$1 = 0, $__i$013 = 0, $__j$011 = 0, $__j$011$phi = 0, $__k$0$lcssa = 0, $__k$08 = 0, $__t$i = 0, $__t$sroa$7 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i = sp + 16|0;
 $__t$sroa$7 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 44)&-1;
 switch ($3|0) {
 case 1: case 0:  {
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 5:  {
  $47 = (($__first) + 44|0);
  $48 = (($__first) + 88|0);
  $49 = (($__first) + 132|0);
  $50 = (($__last) + -44|0);
  (__ZNSt3__17__sort5IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_S5_T_($__first,$47,$48,$49,$50,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 4:  {
  $44 = (($__first) + 44|0);
  $45 = (($__first) + 88|0);
  $46 = (($__last) + -44|0);
  (__ZNSt3__17__sort4IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_S5_T_($__first,$44,$45,$46,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 3:  {
  $42 = (($__first) + 44|0);
  $43 = (($__last) + -44|0);
  (__ZNSt3__17__sort3IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__first,$42,$43,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -44|0);
  $5 = (($__last) + -4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($__first) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $11 = (($__last) + -40|0);
    $12 = HEAP16[$11>>1]|0;
    $13 = (($__first) + 4|0);
    $14 = HEAP16[$13>>1]|0;
    $15 = ($12<<16>>16)==($14<<16>>16);
    if (!($15)) {
     $16 = ($12<<16>>16)<($14<<16>>16);
     if ($16) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    }
    $17 = (($__last) + -32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__first) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if (!($21)) {
     $22 = ($18>>>0)<($20>>>0);
     if ($22) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    }
    $23 = (($__last) + -24|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($__first) + 20|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($24|0)==($26|0);
    if (!($27)) {
     $28 = ($24|0)>($26|0);
     if ($28) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    }
    $29 = HEAP32[$4>>2]|0;
    $30 = HEAP32[$__first>>2]|0;
    $31 = ($29|0)==($30|0);
    if ($31) {
     $37 = (($__last) + -20|0);
     $38 = Math_fround(HEAPF32[$37>>2]);
     $39 = (($__first) + 24|0);
     $40 = Math_fround(HEAPF32[$39>>2]);
     $41 = $38 > $40;
     if ($41) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    } else {
     $32 = (($29) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($30) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($33|0)<($35|0);
     if ($36) {
      break;
     } else {
      $$3 = 1;
     }
     STACKTOP = sp;return ($$3|0);
    }
   } else {
    $10 = ($6>>>0)<($8>>>0);
    if (!($10)) {
     $$3 = 1;
     STACKTOP = sp;return ($$3|0);
    }
   }
  } while(0);
  dest=$__t$i+0|0; src=$__first+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__first+0|0; src=$4+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$4+0|0; src=$__t$i+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 default: {
  $51 = (($__first) + 88|0);
  $52 = (($__first) + 44|0);
  (__ZNSt3__17__sort3IR26RenderDeferredObjectSorterP16RenderObjectDataEEjT0_S5_S5_T_($__first,$52,$51,0)|0);
  $53 = (($__first) + 132|0);
  $54 = ($53|0)==($__last|0);
  if ($54) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  $__count$012 = 0;$__i$013 = $53;$__j$011 = $51;
  while(1) {
   $55 = (($__i$013) + 40|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($__j$011) + 40|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($56|0)==($58|0);
   do {
    if ($59) {
     $61 = (($__i$013) + 4|0);
     $62 = HEAP16[$61>>1]|0;
     $63 = (($__j$011) + 4|0);
     $64 = HEAP16[$63>>1]|0;
     $65 = ($62<<16>>16)==($64<<16>>16);
     if (!($65)) {
      $66 = ($62<<16>>16)<($64<<16>>16);
      if ($66) {
       $114 = $62;
       label = 31;
       break;
      } else {
       $__count$1 = $__count$012;
       break;
      }
     }
     $67 = (($__i$013) + 12|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($__j$011) + 12|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($68|0)==($70|0);
     if (!($71)) {
      $72 = ($68>>>0)<($70>>>0);
      if ($72) {
       $114 = $62;
       label = 31;
       break;
      } else {
       $__count$1 = $__count$012;
       break;
      }
     }
     $73 = (($__i$013) + 20|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($__j$011) + 20|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($74|0)==($76|0);
     if (!($77)) {
      $78 = ($74|0)>($76|0);
      if ($78) {
       $114 = $62;
       label = 31;
       break;
      } else {
       $__count$1 = $__count$012;
       break;
      }
     }
     $79 = HEAP32[$__i$013>>2]|0;
     $80 = HEAP32[$__j$011>>2]|0;
     $81 = ($79|0)==($80|0);
     if ($81) {
      $87 = (($__i$013) + 24|0);
      $88 = Math_fround(HEAPF32[$87>>2]);
      $89 = (($__j$011) + 24|0);
      $90 = Math_fround(HEAPF32[$89>>2]);
      $91 = $88 > $90;
      if ($91) {
       $114 = $62;
       label = 31;
       break;
      } else {
       $__count$1 = $__count$012;
       break;
      }
     } else {
      $82 = (($79) + 4|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = (($80) + 4|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ($83|0)<($85|0);
      if ($86) {
       $114 = $62;
       label = 31;
       break;
      } else {
       $__count$1 = $__count$012;
       break;
      }
     }
    } else {
     $60 = ($56>>>0)<($58>>>0);
     if ($60) {
      $$phi$trans$insert = (($__i$013) + 4|0);
      $$pre = HEAP16[$$phi$trans$insert>>1]|0;
      $114 = $$pre;
      label = 31;
     } else {
      $__count$1 = $__count$012;
     }
    }
   } while(0);
   if ((label|0) == 31) {
    label = 0;
    $92 = HEAP32[$__i$013>>2]|0;
    $93 = (($__i$013) + 6|0);
    ;HEAP16[$__t$i+0>>1]=HEAP16[$93+0>>1]|0;HEAP16[$__t$i+2>>1]=HEAP16[$93+2>>1]|0;HEAP16[$__t$i+4>>1]=HEAP16[$93+4>>1]|0;
    $94 = (($__i$013) + 12|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($__i$013) + 16|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($__i$013) + 20|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($__i$013) + 24|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = (($__i$013) + 28|0);
    ;HEAP32[$__t$sroa$7+0>>2]=HEAP32[$102+0>>2]|0;HEAP32[$__t$sroa$7+4>>2]=HEAP32[$102+4>>2]|0;HEAP32[$__t$sroa$7+8>>2]=HEAP32[$102+8>>2]|0;
    $103 = HEAP32[$55>>2]|0;
    $104 = (($92) + 4|0);
    dest=$__i$013+0|0; src=$__j$011+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $105 = ($__j$011|0)==($__first|0);
    L27: do {
     if ($105) {
      $__k$0$lcssa = $__first;
     } else {
      $__k$08 = $__j$011;
      while(1) {
       $106 = (($__k$08) + -44|0);
       $107 = (($__k$08) + -4|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ($103|0)==($108|0);
       do {
        if ($109) {
         $111 = (($__k$08) + -40|0);
         $112 = HEAP16[$111>>1]|0;
         $113 = ($114<<16>>16)==($112<<16>>16);
         if (!($113)) {
          $115 = ($114<<16>>16)<($112<<16>>16);
          if ($115) {
           break;
          } else {
           $__k$0$lcssa = $__k$08;
           break L27;
          }
         }
         $116 = (($__k$08) + -32|0);
         $117 = HEAP32[$116>>2]|0;
         $118 = ($95|0)==($117|0);
         if (!($118)) {
          $119 = ($95>>>0)<($117>>>0);
          if ($119) {
           break;
          } else {
           $__k$0$lcssa = $__k$08;
           break L27;
          }
         }
         $120 = (($__k$08) + -24|0);
         $121 = HEAP32[$120>>2]|0;
         $122 = ($99|0)==($121|0);
         if (!($122)) {
          $123 = ($99|0)>($121|0);
          if ($123) {
           break;
          } else {
           $__k$0$lcssa = $__k$08;
           break L27;
          }
         }
         $124 = HEAP32[$106>>2]|0;
         $125 = ($92|0)==($124|0);
         if ($125) {
          $130 = (($__k$08) + -20|0);
          $131 = Math_fround(HEAPF32[$130>>2]);
          $132 = $101 > $131;
          if ($132) {
           break;
          } else {
           $__k$0$lcssa = $__k$08;
           break L27;
          }
         } else {
          $126 = HEAP32[$104>>2]|0;
          $127 = (($124) + 4|0);
          $128 = HEAP32[$127>>2]|0;
          $129 = ($126|0)<($128|0);
          if ($129) {
           break;
          } else {
           $__k$0$lcssa = $__k$08;
           break L27;
          }
         }
        } else {
         $110 = ($103>>>0)<($108>>>0);
         if (!($110)) {
          $__k$0$lcssa = $__k$08;
          break L27;
         }
        }
       } while(0);
       dest=$__k$08+0|0; src=$106+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $133 = ($106|0)==($__first|0);
       if ($133) {
        $__k$0$lcssa = $__first;
        break;
       } else {
        $__k$08 = $106;
       }
      }
     }
    } while(0);
    HEAP32[$__k$0$lcssa>>2] = $92;
    $134 = (($__k$0$lcssa) + 4|0);
    HEAP16[$134>>1] = $114;
    $135 = (($__k$0$lcssa) + 6|0);
    ;HEAP16[$135+0>>1]=HEAP16[$__t$i+0>>1]|0;HEAP16[$135+2>>1]=HEAP16[$__t$i+2>>1]|0;HEAP16[$135+4>>1]=HEAP16[$__t$i+4>>1]|0;
    $136 = (($__k$0$lcssa) + 12|0);
    HEAP32[$136>>2] = $95;
    $137 = (($__k$0$lcssa) + 16|0);
    HEAP32[$137>>2] = $97;
    $138 = (($__k$0$lcssa) + 20|0);
    HEAP32[$138>>2] = $99;
    $139 = (($__k$0$lcssa) + 24|0);
    HEAPF32[$139>>2] = $101;
    $140 = (($__k$0$lcssa) + 28|0);
    ;HEAP32[$140+0>>2]=HEAP32[$__t$sroa$7+0>>2]|0;HEAP32[$140+4>>2]=HEAP32[$__t$sroa$7+4>>2]|0;HEAP32[$140+8>>2]=HEAP32[$__t$sroa$7+8>>2]|0;
    $141 = (($__k$0$lcssa) + 40|0);
    HEAP32[$141>>2] = $103;
    $142 = (($__count$012) + 1)|0;
    $143 = ($142|0)==(8);
    if ($143) {
     break;
    } else {
     $__count$1 = $142;
    }
   }
   $146 = (($__i$013) + 44|0);
   $147 = ($146|0)==($__last|0);
   if ($147) {
    $$3 = 1;
    label = 47;
    break;
   } else {
    $__j$011$phi = $__i$013;$__count$012 = $__count$1;$__i$013 = $146;$__j$011 = $__j$011$phi;
   }
  }
  if ((label|0) == 47) {
   STACKTOP = sp;return ($$3|0);
  }
  $144 = (($__i$013) + 44|0);
  $145 = ($144|0)==($__last|0);
  $$3 = $145;
  STACKTOP = sp;return ($$3|0);
 }
 }
 return 0|0;
}
function __GLOBAL__I_a1688() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568840);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[568832>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568864);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[568856>>2] = $2;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568888);
 $3 = HEAP32[$0>>2]|0;
 HEAP32[568880>>2] = $3;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568912);
 $4 = HEAP32[$0>>2]|0;
 HEAP32[568904>>2] = $4;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568936);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[568928>>2] = $5;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568960);
 $6 = HEAP32[$0>>2]|0;
 HEAP32[568952>>2] = $6;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,568984);
 $7 = HEAP32[$0>>2]|0;
 HEAP32[568976>>2] = $7;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,569016);
 $8 = HEAP32[$0>>2]|0;
 HEAP32[569008>>2] = $8;
 STACKTOP = sp;return;
}
function __Z16CreateRenderLoopR6Camera($camera) {
 $camera = $camera|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__Znwj(860)|0);
 $1 = (($0) + 76|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;
 $2 = (($0) + 316|0);
 $3 = (($0) + 484|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($0) + 488|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($0) + 492|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($0) + 500|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($0) + 504|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($0) + 508|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($0) + 516|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($0) + 520|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($0) + 524|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($0) + 532|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($0) + 536|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($0) + 540|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($0) + 548|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($0) + 552|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($0) + 556|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($0) + 564|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($0) + 568|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($0) + 572|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($0) + 580|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($0) + 584|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($0) + 588|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($0) + 596|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($0) + 600|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($0) + 604|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($0) + 612|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($0) + 616|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($0) + 620|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($0) + 628|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($0) + 632|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($0) + 636|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($0) + 644|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($0) + 648|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($0) + 652|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($0) + 660|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($0) + 664|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($0) + 668|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($0) + 676|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($0) + 680|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($0) + 684|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($0) + 724|0);
 HEAP32[$42>>2] = 0;
 $43 = (($0) + 728|0);
 HEAP32[$43>>2] = -1;
 $44 = (($0) + 732|0);
 HEAP32[$44>>2] = 0;
 $45 = (($0) + 740|0);
 HEAP32[$45>>2] = 0;
 $46 = (($0) + 744|0);
 HEAP32[$46>>2] = 0;
 $47 = (($0) + 736|0);
 HEAP32[$47>>2] = 61;
 $48 = (($0) + 748|0);
 HEAP32[$48>>2] = 0;
 $49 = (($0) + 756|0);
 HEAP32[$49>>2] = 0;
 $50 = (($0) + 760|0);
 HEAP32[$50>>2] = 0;
 $51 = (($0) + 752|0);
 HEAP32[$51>>2] = 61;
 $52 = (($0) + 764|0);
 dest=$52+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$0>>2] = $camera;
 $53 = (($0) + 116|0);
 HEAP32[$53>>2] = $0;
 $scevgep$i = (($0) + 800|0);
 dest=$scevgep$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return ($0|0);
}
function __Z16DeleteRenderLoopP10RenderLoop($loop) {
 $loop = $loop|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($loop|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3406,($loop|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($loop);
  ___resumeException($3|0);
  // unreachable;
 }
 __ZdlPv($loop);
 STACKTOP = sp;return;
}
function __Z25GetRenderLoopImageFiltersR10RenderLoop($loop) {
 $loop = $loop|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($loop) + 764|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN10RenderLoopD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 776|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($this) + 780|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $__new_last2$i$i$i$i$i$i$i = $3;
   $scevgep$i$i$i$i$i$i$i = (($6) + -12|0);
   $8 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($8)|0);
   $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
   $9 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
   $10 = $9 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($6) + (($10*12)|0)|0);
   HEAP32[$5>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  __ZdlPv($3);
 }
 $11 = (($this) + 764|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = (($this) + 768|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($12|0);
  if (!($16)) {
   $__new_last2$i$i$i$i$i1$i$i = $12;
   $scevgep$i$i$i$i$i2$i$i = (($15) + -12|0);
   $17 = (0 - ($__new_last2$i$i$i$i$i1$i$i))|0;
   $uglygep$i$i$i$i$i4$i$i = (($scevgep$i$i$i$i$i2$i$i) + ($17)|0);
   $uglygep3$i$i$i$i$i5$i$i = $uglygep$i$i$i$i$i4$i$i;
   $18 = (($uglygep3$i$i$i$i$i5$i$i>>>0) / 12)&-1;
   $19 = $18 ^ -1;
   $scevgep4$i$i$i$i$i6$i$i = (($15) + (($19*12)|0)|0);
   HEAP32[$14>>2] = $scevgep4$i$i$i$i$i6$i$i;
  }
  __ZdlPv($12);
 }
 $20 = (($this) + 732|0);
 $21 = (($this) + 764|0);
 $23 = $21;
 while(1) {
  $22 = (($23) + -16|0);
  $24 = (($23) + -4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)>(-1);
  if ($26) {
   $27 = HEAP32[$22>>2]|0;
   $28 = (($23) + -12|0);
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$1>>2] = $29;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($27|0),($$byval_copy1|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    break;
   }
   HEAP32[$22>>2] = 0;
  }
  $32 = ($22|0)==($20|0);
  if ($32) {
   label = 14;
   break;
  } else {
   $23 = $22;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 $35 = ($20|0)==($22|0);
 if ($35) {
  ___resumeException($33|0);
  // unreachable;
 }
 $37 = $22;
 while(1) {
  $36 = (($37) + -16|0);
  $38 = (($37) + -4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)>(-1);
  if ($40) {
   $41 = HEAP32[$36>>2]|0;
   $42 = (($37) + -12|0);
   $43 = HEAP32[$42>>2]|0;
   HEAP32[$0>>2] = $43;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($41|0),($$byval_copy1|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    label = 22;
    break;
   }
   HEAP32[$36>>2] = 0;
  }
  $46 = ($36|0)==($20|0);
  if ($46) {
   label = 21;
   break;
  } else {
   $37 = $36;
  }
 }
 if ((label|0) == 21) {
  ___resumeException($33|0);
  // unreachable;
 }
 else if ((label|0) == 22) {
  $47 = ___cxa_find_matching_catch(0|0)|0;
  $48 = tempRet0;
  ___clang_call_terminate($47);
  // unreachable;
 }
}
function __Z18RenderImageFiltersR10RenderLoopP13RenderTextureb($loop,$targetTexture,$afterOpaque) {
 $loop = $loop|0;
 $targetTexture = $targetTexture|0;
 $afterOpaque = $afterOpaque|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $afterOpaque$not = 0, $brmerge = 0, $phitmp$i = 0, $phitmp$i$i = 0, $r$i = 0, $rect$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $r$i = sp + 16|0;
 $rect$i = sp;
 $0 = HEAP32[$loop>>2]|0;
 $1 = $afterOpaque ? 12 : 18;
 $2 = HEAP32[652824>>2]|0;
 $3 = (($0) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($3,$1,$2);
 $4 = (__ZNK6Camera28CalculateNeedsToRenderIntoRTEv($0)|0);
 $5 = (($loop) + 764|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($loop) + 768|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  $10 = (($loop) + 776|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($loop) + 780|0);
  $13 = HEAP32[$12>>2]|0;
  $phitmp$i$i = ($11|0)==($13|0);
  if (!($phitmp$i$i)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $14 = HEAP32[$loop>>2]|0;
  $15 = (__ZNK6Camera27GetUsesScreenForCompositingEb($14,$4)|0);
  if ($15) {
   if ($afterOpaque) {
    $16 = (__ZN12ImageFilters21GetTargetBeforeOpaqueEv($5)|0);
    $19 = $16;
   } else {
    $17 = (__ZN12ImageFilters20GetTargetAfterOpaqueEbb($5,$4,1)|0);
    $19 = $17;
   }
   $18 = ($19|0)==(0|0);
   if (!($18)) {
    $20 = (__Z12GetGfxDevicev()|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 408|0);
    $23 = HEAP32[$22>>2]|0;
    FUNCTION_TABLE_vi[$23 & 4095]($20);
    $24 = HEAP32[$loop>>2]|0;
    __ZNK6Camera13GetCameraRectEb($r$i,$24,0);
    __Z14RectfToRectIntRK5RectTIfE($rect$i,$r$i);
    $25 = (($rect$i) + 8|0);
    $26 = HEAP32[$19>>2]|0;
    $27 = (($26) + 116|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (FUNCTION_TABLE_ii[$28 & 4095]($19)|0);
    $30 = HEAP32[$25>>2]|0;
    $31 = ($29|0)<($30|0);
    $32 = $31 ? $29 : $30;
    $33 = (($rect$i) + 12|0);
    $34 = HEAP32[$19>>2]|0;
    $35 = (($34) + 120|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (FUNCTION_TABLE_ii[$36 & 4095]($19)|0);
    $38 = HEAP32[$33>>2]|0;
    $39 = ($37|0)<($38|0);
    $40 = $39 ? $37 : $38;
    $41 = HEAP32[$rect$i>>2]|0;
    $42 = (($rect$i) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    __ZN13RenderTexture10GrabPixelsEiiii($19,$41,$43,$32,$40);
    __ZN13RenderTexture24CorrectVerticalTexelSizeEb($19,0);
   }
  }
 }
 $44 = HEAP32[$5>>2]|0;
 $45 = HEAP32[$7>>2]|0;
 $46 = ($44|0)==($45|0);
 if ($46) {
  $47 = (($loop) + 776|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($loop) + 780|0);
  $50 = HEAP32[$49>>2]|0;
  $phitmp$i = ($48|0)==($50|0);
  if ($phitmp$i) {
   $55 = 0;
  } else {
   label = 11;
  }
 } else {
  label = 11;
 }
 if ((label|0) == 11) {
  $51 = (__ZNK6Camera27GetUsesScreenForCompositingEb($0,$4)|0);
  $55 = $51;
 }
 $52 = (($0) + 620|0);
 $53 = HEAP8[$52>>0]|0;
 $54 = ($53<<24>>24)!=(0);
 __ZN12ImageFilters8DoRenderEP13RenderTexturebbbb($5,$targetTexture,$4,$afterOpaque,$55,$54);
 $afterOpaque$not = $afterOpaque ^ 1;
 $brmerge = $55 | $afterOpaque$not;
 if ($brmerge) {
  $58 = $afterOpaque ? 13 : 19;
  $59 = HEAP32[652824>>2]|0;
  __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($3,$58,$59);
  STACKTOP = sp;return;
 }
 $56 = (__ZN12ImageFilters20GetTargetAfterOpaqueEbb($5,$4,0)|0);
 $57 = (($0) + 348|0);
 HEAP32[$57>>2] = $56;
 $58 = $afterOpaque ? 13 : 19;
 $59 = HEAP32[652824>>2]|0;
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($3,$58,$59);
 STACKTOP = sp;return;
}
function __Z12DoRenderLoopR10RenderLoop13RenderingPathR11CullResultsb($loop,$renderPath,$contents,$dontRenderRenderables) {
 $loop = $loop|0;
 $renderPath = $renderPath|0;
 $contents = $contents|0;
 $dontRenderRenderables = $dontRenderRenderables|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$01 = 0, $$byval_copy12 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0);
 var $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0);
 var $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $it$033 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $mat$0 = 0, $mi$028 = 0, $not$ = 0, $prepassDepthWasCopied = 0, $queueIndex$0 = 0, $remainingObjects = 0, $remainingObjects2 = 0, $rtDepth = 0, $rtDepthNormals = 0, $rtShadowMap = 0, $rtShadowMap1 = 0, $scevgep$i = 0, $temp$0$i$i = 0;
 var $usedSubshaderIndex$0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy12 = sp + 108|0;
 $0 = sp + 104|0;
 $1 = sp + 100|0;
 $2 = sp + 96|0;
 $3 = sp + 92|0;
 $4 = sp + 88|0;
 $5 = sp + 84|0;
 $6 = sp + 80|0;
 $7 = sp + 24|0;
 $8 = sp;
 $9 = sp + 16|0;
 $rtDepth = sp + 20|0;
 $rtDepthNormals = sp + 28|0;
 $prepassDepthWasCopied = sp + 120|0;
 $rtShadowMap = sp + 32|0;
 $remainingObjects = sp + 40|0;
 $rtShadowMap1 = sp + 56|0;
 $remainingObjects2 = sp + 64|0;
 $10 = (($contents) + 1024|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($loop) + 8|0);
 HEAP32[$12>>2] = $11;
 $13 = (($loop) + 4|0);
 HEAP32[$13>>2] = $contents;
 $14 = (__Z12GetGfxDevicev()|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 88|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($14)|0);
 __THREW__ = 0;
 $19 = (invoke_i(69)|0);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L1: do {
  if ($21) {
   label = 36;
  } else {
   $22 = (($19) + 94|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)==(0);
   $25 = HEAP32[$loop>>2]|0;
   $26 = (($contents) + 1068|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($contents) + 1072|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)!=(0|0);
   __THREW__ = 0;
   $31 = (invoke_ii(3219,($25|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    label = 36;
   } else {
    $34 = (($loop) + 12|0);
    dest=$34+0|0; src=$31+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $35 = (($loop) + 92|0);
    $36 = (($25) + 24|0);
    $37 = HEAP32[$36>>2]|0;
    __THREW__ = 0;
    $38 = (invoke_ii(3220,($37|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 36;
    } else {
     __THREW__ = 0;
     invoke_vii(2620,($$byval_copy12|0),($38|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 36;
     } else {
      ;HEAP32[$35+0>>2]=HEAP32[$$byval_copy12+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$$byval_copy12+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$$byval_copy12+8>>2]|0;
      __THREW__ = 0;
      invoke_vii(2621,($8|0),($25|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 36;
      } else {
       $45 = (($loop) + 76|0);
       ;HEAP32[$45+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$8+12>>2]|0;
       $46 = (($25) + 600|0);
       $47 = HEAP32[$46>>2]|0;
       if ((($47|0) == 1)) {
        $48 = (($loop) + 104|0);
        HEAP8[$48>>0] = 0;
        $436 = 0;
       } else if ((($47|0) == 2)) {
        $49 = (($loop) + 104|0);
        HEAP8[$49>>0] = 1;
        $436 = 1;
       } else {
        $50 = (($25) + 616|0);
        $51 = HEAP8[$50>>0]|0;
        $52 = (($loop) + 104|0);
        HEAP8[$52>>0] = $51;
        $436 = $51;
       }
       $53 = (($loop) + 105|0);
       $54 = $dontRenderRenderables&1;
       HEAP8[$53>>0] = $54;
       $55 = (($loop) + 106|0);
       $56 = $30&1;
       HEAP8[$55>>0] = $56;
       $57 = (($loop) + 740|0);
       HEAP32[$57>>2] = 0;
       $58 = (($loop) + 756|0);
       HEAP32[$58>>2] = 0;
       $scevgep$i = (($loop) + 800|0);
       dest=$scevgep$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       $59 = (($contents) + 92|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = (($contents) + 100|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($60) + ($62<<7)|0);
       $64 = ($62|0)==(0);
       L12: do {
        if (!($64)) {
         $65 = (($loop) + 104|0);
         $66 = (($loop) + 20|0);
         $67 = (($loop) + 36|0);
         $68 = (($loop) + 52|0);
         $69 = (($loop) + 68|0);
         $70 = (($loop) + 92|0);
         $71 = (($loop) + 96|0);
         $72 = (($loop) + 100|0);
         $73 = (($27) + 52|0);
         $83 = $436;$it$033 = $60;
         L14: while(1) {
          $74 = (($it$033) + 116|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = (($it$033) + 64|0);
          $77 = Math_fround(HEAPF32[$76>>2]);
          $78 = (($it$033) + 68|0);
          $79 = Math_fround(HEAPF32[$78>>2]);
          $80 = (($it$033) + 72|0);
          $81 = Math_fround(HEAPF32[$80>>2]);
          $82 = ($83<<24>>24)==(0);
          $84 = Math_fround(HEAPF32[$66>>2]);
          $85 = Math_fround($77 * $84);
          $86 = Math_fround(HEAPF32[$67>>2]);
          $87 = Math_fround($79 * $86);
          $88 = Math_fround($85 + $87);
          $89 = Math_fround(HEAPF32[$68>>2]);
          $90 = Math_fround($81 * $89);
          $91 = Math_fround($88 + $90);
          $92 = Math_fround(HEAPF32[$69>>2]);
          $93 = Math_fround($92 + $91);
          if ($82) {
           $94 = Math_fround(HEAPF32[$70>>2]);
           $95 = Math_fround($77 - $94);
           $96 = Math_fround(HEAPF32[$71>>2]);
           $97 = Math_fround($79 - $96);
           $98 = Math_fround(HEAPF32[$72>>2]);
           $99 = Math_fround($81 - $98);
           $100 = Math_fround($95 * $95);
           $101 = Math_fround($97 * $97);
           $102 = Math_fround($100 + $101);
           $103 = Math_fround($99 * $99);
           $104 = Math_fround($102 + $103);
           $105 = Math_fround(-$104);
           $113 = $105;
          } else {
           $113 = $93;
          }
          $106 = HEAP32[$75>>2]|0;
          $107 = (($106) + 36|0);
          $108 = HEAP32[$107>>2]|0;
          __THREW__ = 0;
          $109 = (Math_fround(+(invoke_fi($108|0,($75|0)))));
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           label = 35;
           break;
          }
          $112 = Math_fround($113 - $109);
          $114 = Math_fround(-$93);
          $115 = HEAP32[$75>>2]|0;
          $116 = (($115) + 40|0);
          $117 = HEAP32[$116>>2]|0;
          __THREW__ = 0;
          $118 = (invoke_ii($117|0,($75|0))|0);
          $119 = __THREW__; __THREW__ = 0;
          $120 = $119&1;
          if ($120) {
           label = 35;
           break;
          }
          if ($24) {
           $250 = 0;
          } else {
           $121 = HEAP32[$75>>2]|0;
           $122 = (($121) + 52|0);
           $123 = HEAP32[$122>>2]|0;
           __THREW__ = 0;
           $124 = (invoke_ii($123|0,($75|0))|0);
           $125 = __THREW__; __THREW__ = 0;
           $126 = $125&1;
           if ($126) {
            label = 35;
            break;
           } else {
            $250 = $124;
           }
          }
          $127 = (($75) + 36|0);
          $128 = HEAP32[$127>>2]|0;
          $129 = ($118|0)>(0);
          if ($129) {
           $130 = (($75) + 172|0);
           $mi$028 = 0;
           while(1) {
            $131 = HEAP32[$75>>2]|0;
            $132 = (($131) + 44|0);
            $133 = HEAP32[$132>>2]|0;
            __THREW__ = 0;
            invoke_viii($133|0,($9|0),($75|0),($mi$028|0));
            $134 = __THREW__; __THREW__ = 0;
            $135 = $134&1;
            if ($135) {
             label = 34;
             break L14;
            }
            $136 = HEAP32[$9>>2]|0;
            $137 = ($136|0)==(0);
            L29: do {
             if ($137) {
              label = 33;
             } else {
              HEAP32[$7>>2] = $136;
              $138 = HEAP32[560624>>2]|0;
              $139 = ($138|0)==(0|0);
              do {
               if (!($139)) {
                $140 = (($138) + 36|0);
                $141 = HEAP32[$140>>2]|0;
                $142 = (($138) + 4|0);
                $143 = HEAP32[$142>>2]|0;
                $144 = ($141|0)==($143|0);
                do {
                 if ($144) {
                  $145 = (($138) + 28|0);
                  $146 = HEAP32[$145>>2]|0;
                  $147 = (($138) + 32|0);
                  $148 = HEAP32[$147>>2]|0;
                  $149 = (($146) + ($148<<3)|0);
                  $165 = $149;
                 } else {
                  __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy12,$138,$7);
                  $150 = HEAP32[$$byval_copy12>>2]|0;
                  $151 = ($150|0)==(-1);
                  $152 = (($138) + 28|0);
                  $153 = HEAP32[$152>>2]|0;
                  if ($151) {
                   $154 = (($138) + 32|0);
                   $155 = HEAP32[$154>>2]|0;
                   $156 = (($153) + ($155<<3)|0);
                   $165 = $156;
                   break;
                  } else {
                   $157 = (($153) + ($150<<3)|0);
                   $165 = $157;
                   break;
                  }
                 }
                } while(0);
                $158 = HEAP32[560624>>2]|0;
                $159 = (($158) + 28|0);
                $160 = HEAP32[$159>>2]|0;
                $161 = (($158) + 32|0);
                $162 = HEAP32[$161>>2]|0;
                $163 = (($160) + ($162<<3)|0);
                $164 = ($165|0)==($163|0);
                if ($164) {
                 break;
                }
                $166 = (($165) + 4|0);
                $167 = HEAP32[$166>>2]|0;
                $168 = ($167|0)==(0|0);
                if ($168) {
                 break;
                }
                $mat$0 = $167;
                break L29;
               }
              } while(0);
              $169 = HEAP32[$9>>2]|0;
              __THREW__ = 0;
              $170 = (invoke_ii(3215,($169|0))|0);
              $171 = __THREW__; __THREW__ = 0;
              $172 = $171&1;
              if ($172) {
               label = 34;
               break L14;
              }
              $173 = ($170|0)==(0|0);
              if ($173) {
               label = 33;
              } else {
               $mat$0 = $170;
              }
             }
            } while(0);
            if ((label|0) == 33) {
             label = 0;
             __THREW__ = 0;
             $174 = (invoke_i(70)|0);
             $175 = __THREW__; __THREW__ = 0;
             $176 = $175&1;
             if ($176) {
              label = 34;
              break L14;
             } else {
              $mat$0 = $174;
             }
            }
            __THREW__ = 0;
            $183 = (invoke_ii(3221,($mat$0|0))|0);
            $184 = __THREW__; __THREW__ = 0;
            $185 = $184&1;
            if ($185) {
             label = 34;
             break L14;
            }
            if ($30) {
             __THREW__ = 0;
             $186 = (invoke_iiii(1535,($183|0),($27|0),($29|0))|0);
             $187 = __THREW__; __THREW__ = 0;
             $188 = $187&1;
             if ($188) {
              label = 34;
              break L14;
             }
             $189 = ($186|0)<(0);
             if (!($189)) {
              $usedSubshaderIndex$0 = $186;
              label = 42;
             }
            } else {
             $usedSubshaderIndex$0 = -1;
             label = 42;
            }
            if ((label|0) == 42) {
             label = 0;
             $190 = HEAP32[$75>>2]|0;
             $191 = (($190) + 48|0);
             $192 = HEAP32[$191>>2]|0;
             __THREW__ = 0;
             $193 = (invoke_iii($192|0,($75|0),($mi$028|0))|0);
             $194 = __THREW__; __THREW__ = 0;
             $195 = $194&1;
             if ($195) {
              label = 34;
              break L14;
             }
             $196 = (($mat$0) + 64|0);
             $197 = HEAP32[$196>>2]|0;
             $198 = ($197|0)<(0);
             do {
              if ($198) {
               if ($30) {
                $203 = HEAP32[$73>>2]|0;
                __THREW__ = 0;
                $204 = (invoke_iii(2369,($203|0),($usedSubshaderIndex$0|0))|0);
                $205 = __THREW__; __THREW__ = 0;
                $206 = $205&1;
                if ($206) {
                 label = 34;
                 break L14;
                } else {
                 $queueIndex$0 = $204;
                 break;
                }
               } else {
                $199 = (($183) + 52|0);
                $200 = HEAP32[$199>>2]|0;
                $201 = (($200) + 36|0);
                $202 = HEAP32[$201>>2]|0;
                $queueIndex$0 = $202;
                break;
               }
              } else {
               $queueIndex$0 = $197;
              }
             } while(0);
             $not$ = ($queueIndex$0|0)>(2500);
             $$ = $not$&1;
             $207 = ((($loop) + ($$<<4)|0) + 732|0);
             $208 = ((($loop) + ($$<<4)|0) + 740|0);
             $209 = HEAP32[$208>>2]|0;
             $210 = (($209) + 1)|0;
             HEAP32[$208>>2] = $210;
             $211 = ((($loop) + ($$<<4)|0) + 744|0);
             $212 = HEAP32[$211>>2]|0;
             $213 = $212 & 2147483647;
             $214 = ($210>>>0)>($213>>>0);
             if ($214) {
              $215 = $212 << 1;
              $216 = ($215|0)==(0);
              $217 = $216 ? 1 : $215;
              $218 = ($213>>>0)<($217>>>0);
              do {
               if ($218) {
                $219 = ($212|0)>(-1);
                if ($219) {
                 HEAP32[$211>>2] = $217;
                 $220 = HEAP32[$207>>2]|0;
                 $221 = ($217*44)|0;
                 $222 = ((($loop) + ($$<<4)|0) + 736|0);
                 $223 = HEAP32[$222>>2]|0;
                 HEAP32[$5>>2] = $223;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$5+0>>2]|0;
                 $224 = (invoke_iiiiiiii(108,($220|0),($221|0),4,($$byval_copy12|0),0,(569248|0),370)|0);
                 $225 = __THREW__; __THREW__ = 0;
                 $226 = $225&1;
                 if ($226) {
                  label = 34;
                  break L14;
                 }
                 HEAP32[$207>>2] = $224;
                 break;
                } else {
                 $227 = ($217*44)|0;
                 $228 = ((($loop) + ($$<<4)|0) + 736|0);
                 $229 = HEAP32[$228>>2]|0;
                 HEAP32[$6>>2] = $229;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$6+0>>2]|0;
                 $230 = (invoke_iiiiiii(102,($227|0),4,($$byval_copy12|0),0,(569248|0),352)|0);
                 $231 = __THREW__; __THREW__ = 0;
                 $232 = $231&1;
                 if ($232) {
                  label = 34;
                  break L14;
                 }
                 $233 = HEAP32[$207>>2]|0;
                 $234 = HEAP32[$208>>2]|0;
                 $235 = ($234*44)|0;
                 _memcpy(($230|0),($233|0),($235|0))|0;
                 HEAP32[$211>>2] = $217;
                 HEAP32[$207>>2] = $230;
                 break;
                }
               }
              } while(0);
              $$pre$i = HEAP32[$208>>2]|0;
              $237 = $$pre$i;
             } else {
              $237 = $210;
             }
             $236 = (($237) + -1)|0;
             $238 = HEAP32[$207>>2]|0;
             $239 = (($238) + (($236*44)|0)|0);
             HEAP32[$239>>2] = $mat$0;
             $240 = $queueIndex$0&65535;
             $241 = ((($238) + (($236*44)|0)|0) + 4|0);
             HEAP16[$241>>1] = $240;
             $242 = $193&65535;
             $243 = ((($238) + (($236*44)|0)|0) + 6|0);
             HEAP16[$243>>1] = $242;
             $244 = $usedSubshaderIndex$0&65535;
             $245 = ((($238) + (($236*44)|0)|0) + 8|0);
             HEAP16[$245>>1] = $244;
             $246 = $mi$028&65535;
             $247 = ((($238) + (($236*44)|0)|0) + 10|0);
             HEAP16[$247>>1] = $246;
             $248 = ((($238) + (($236*44)|0)|0) + 12|0);
             HEAP32[$248>>2] = $128;
             $249 = ((($238) + (($236*44)|0)|0) + 20|0);
             HEAP32[$249>>2] = $250;
             $251 = ((($238) + (($236*44)|0)|0) + 24|0);
             HEAPF32[$251>>2] = $112;
             $252 = ((($238) + (($236*44)|0)|0) + 28|0);
             HEAPF32[$252>>2] = $114;
             $253 = ((($238) + (($236*44)|0)|0) + 32|0);
             HEAP32[$253>>2] = $it$033;
             $254 = $30 ? $27 : $183;
             $255 = ((($238) + (($236*44)|0)|0) + 36|0);
             HEAP32[$255>>2] = $254;
             $256 = HEAP32[$75>>2]|0;
             $257 = (($256) + 60|0);
             $258 = HEAP32[$257>>2]|0;
             __THREW__ = 0;
             $259 = (invoke_ii($258|0,($75|0))|0);
             $260 = __THREW__; __THREW__ = 0;
             $261 = $260&1;
             if ($261) {
              label = 34;
              break L14;
             }
             $262 = ((($238) + (($236*44)|0)|0) + 16|0);
             HEAP16[$262>>1] = $259;
             $263 = HEAP32[$130>>2]|0;
             $264 = ((($238) + (($236*44)|0)|0) + 40|0);
             HEAP32[$264>>2] = $263;
            }
            $265 = (($mi$028) + 1)|0;
            $266 = ($265|0)<($118|0);
            if ($266) {
             $mi$028 = $265;
            } else {
             break;
            }
           }
          }
          $267 = (($it$033) + 128|0);
          $268 = ($267|0)==($63|0);
          if ($268) {
           break L12;
          }
          $$pre = HEAP8[$65>>0]|0;
          $83 = $$pre;$it$033 = $267;
         }
         if ((label|0) == 34) {
          $177 = ___cxa_find_matching_catch()|0;
          $178 = tempRet0;
          $lpad$phi$index = $177;$lpad$phi$index3 = $178;
          label = 37;
          break L1;
         }
         else if ((label|0) == 35) {
          $179 = ___cxa_find_matching_catch()|0;
          $180 = tempRet0;
          $lpad$phi$index = $179;$lpad$phi$index3 = $180;
          label = 37;
          break L1;
         }
        }
       } while(0);
       __THREW__ = 0;
       $269 = (invoke_i(66)|0);
       $270 = __THREW__; __THREW__ = 0;
       $271 = $270&1;
       if ($271) {
        label = 36;
       } else {
        $272 = ($269|0)==(1);
        HEAP32[$rtDepth>>2] = 0;
        HEAP32[$rtDepthNormals>>2] = 0;
        HEAP8[$prepassDepthWasCopied>>0] = 0;
        $273 = (($loop) + 108|0);
        HEAP32[$273>>2] = 0;
        $274 = (($loop) + 112|0);
        HEAP32[$274>>2] = 2501;
        L80: do {
         if ((($renderPath|0) == 2)) {
          HEAP32[$rtShadowMap>>2] = 0;
          HEAP32[$remainingObjects>>2] = 0;
          $275 = (($remainingObjects) + 8|0);
          HEAP32[$275>>2] = 0;
          $276 = (($remainingObjects) + 12|0);
          HEAP32[$276>>2] = 0;
          $277 = (($remainingObjects) + 4|0);
          HEAP32[$277>>2] = 61;
          $278 = (($loop) + 732|0);
          $279 = (($contents) + 124|0);
          __THREW__ = 0;
          invoke_viiiiiiiii(9,($loop|0),($278|0),($remainingObjects|0),($rtDepth|0),($rtDepthNormals|0),($rtShadowMap|0),($279|0),($272|0),($prepassDepthWasCopied|0));
          $280 = __THREW__; __THREW__ = 0;
          $281 = $280&1;
          do {
           if (!($281)) {
            $282 = HEAP8[$prepassDepthWasCopied>>0]|0;
            $283 = ($282<<24>>24)!=(0);
            $284 = HEAP32[$rtDepth>>2]|0;
            $285 = HEAP32[$rtDepthNormals>>2]|0;
            $286 = HEAP32[$275>>2]|0;
            $287 = ($286|0)==(0);
            if (!($287)) {
             $288 = HEAP32[$rtShadowMap>>2]|0;
             __THREW__ = 0;
             invoke_viiiiiiii(25,($loop|0),($remainingObjects|0),1,1,($288|0),($279|0),($272|0),0);
             $289 = __THREW__; __THREW__ = 0;
             $290 = $289&1;
             if ($290) {
              break;
             }
             $291 = HEAP32[$loop>>2]|0;
             $292 = HEAP32[652824>>2]|0;
             __THREW__ = 0;
             invoke_viiiiiiiii(10,($291|0),($284|0),($285|0),($remainingObjects|0),($26|0),($283|0),1,1,($292|0));
             $293 = __THREW__; __THREW__ = 0;
             $294 = $293&1;
             if ($294) {
              break;
             }
            }
            $295 = HEAP32[$276>>2]|0;
            $296 = ($295|0)>(-1);
            if (!($296)) {
             break L80;
            }
            $297 = HEAP32[$remainingObjects>>2]|0;
            $298 = HEAP32[$277>>2]|0;
            HEAP32[$4>>2] = $298;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
            invoke_vii(2591,($297|0),($$byval_copy12|0));
            $299 = __THREW__; __THREW__ = 0;
            $300 = $299&1;
            if ($300) {
             label = 36;
             break L1;
            }
            HEAP32[$remainingObjects>>2] = 0;
            break L80;
           }
          } while(0);
          $301 = ___cxa_find_matching_catch()|0;
          $302 = tempRet0;
          $303 = HEAP32[$276>>2]|0;
          $304 = ($303|0)>(-1);
          if (!($304)) {
           $$0 = $301;$$01 = $302;
           break L1;
          }
          $305 = HEAP32[$remainingObjects>>2]|0;
          $306 = HEAP32[$277>>2]|0;
          HEAP32[$3>>2] = $306;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
          invoke_vii(2591,($305|0),($$byval_copy12|0));
          $307 = __THREW__; __THREW__ = 0;
          $308 = $307&1;
          if ($308) {
           $434 = ___cxa_find_matching_catch(0|0)|0;
           $435 = tempRet0;
           ___clang_call_terminate($434);
           // unreachable;
          } else {
           HEAP32[$remainingObjects>>2] = 0;
           $$0 = $301;$$01 = $302;
           break L1;
          }
         } else if ((($renderPath|0) == 3)) {
          HEAP32[$rtShadowMap1>>2] = 0;
          HEAP32[$remainingObjects2>>2] = 0;
          $309 = (($remainingObjects2) + 8|0);
          HEAP32[$309>>2] = 0;
          $310 = (($remainingObjects2) + 12|0);
          HEAP32[$310>>2] = 0;
          $311 = (($remainingObjects2) + 4|0);
          HEAP32[$311>>2] = 61;
          $312 = (($loop) + 732|0);
          $313 = (($contents) + 124|0);
          __THREW__ = 0;
          invoke_viiiiiiiii(11,($loop|0),($312|0),($remainingObjects2|0),($rtDepth|0),($rtDepthNormals|0),($rtShadowMap1|0),($313|0),($272|0),($prepassDepthWasCopied|0));
          $314 = __THREW__; __THREW__ = 0;
          $315 = $314&1;
          do {
           if (!($315)) {
            $316 = HEAP8[$prepassDepthWasCopied>>0]|0;
            $317 = ($316<<24>>24)!=(0);
            $318 = HEAP32[$rtDepth>>2]|0;
            $319 = HEAP32[$rtDepthNormals>>2]|0;
            $320 = HEAP32[$309>>2]|0;
            $321 = ($320|0)==(0);
            if (!($321)) {
             $322 = HEAP32[$rtShadowMap1>>2]|0;
             __THREW__ = 0;
             invoke_viiiiiiii(25,($loop|0),($remainingObjects2|0),1,1,($322|0),($313|0),($272|0),0);
             $323 = __THREW__; __THREW__ = 0;
             $324 = $323&1;
             if ($324) {
              break;
             }
             $325 = HEAP32[$loop>>2]|0;
             $326 = HEAP32[652824>>2]|0;
             __THREW__ = 0;
             invoke_viiiiiiiii(10,($325|0),($318|0),($319|0),($remainingObjects2|0),($26|0),($317|0),1,1,($326|0));
             $327 = __THREW__; __THREW__ = 0;
             $328 = $327&1;
             if ($328) {
              break;
             }
            }
            $329 = HEAP32[$310>>2]|0;
            $330 = ($329|0)>(-1);
            if (!($330)) {
             break L80;
            }
            $331 = HEAP32[$remainingObjects2>>2]|0;
            $332 = HEAP32[$311>>2]|0;
            HEAP32[$2>>2] = $332;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
            invoke_vii(2591,($331|0),($$byval_copy12|0));
            $333 = __THREW__; __THREW__ = 0;
            $334 = $333&1;
            if ($334) {
             label = 36;
             break L1;
            }
            HEAP32[$remainingObjects2>>2] = 0;
            break L80;
           }
          } while(0);
          $335 = ___cxa_find_matching_catch()|0;
          $336 = tempRet0;
          $337 = HEAP32[$310>>2]|0;
          $338 = ($337|0)>(-1);
          if (!($338)) {
           $$0 = $335;$$01 = $336;
           break L1;
          }
          $339 = HEAP32[$remainingObjects2>>2]|0;
          $340 = HEAP32[$311>>2]|0;
          HEAP32[$1>>2] = $340;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
          invoke_vii(2591,($339|0),($$byval_copy12|0));
          $341 = __THREW__; __THREW__ = 0;
          $342 = $341&1;
          if ($342) {
           $434 = ___cxa_find_matching_catch(0|0)|0;
           $435 = tempRet0;
           ___clang_call_terminate($434);
           // unreachable;
          } else {
           HEAP32[$remainingObjects2>>2] = 0;
           $$0 = $335;$$01 = $336;
           break L1;
          }
         } else {
          $343 = ($renderPath|0)==(1);
          $344 = (($loop) + 732|0);
          $345 = (($contents) + 124|0);
          if ($343) {
           __THREW__ = 0;
           invoke_viiiiiiii(25,($loop|0),($344|0),1,0,(0|0),($345|0),($272|0),1);
           $346 = __THREW__; __THREW__ = 0;
           $347 = $346&1;
           if ($347) {
            label = 36;
            break L1;
           } else {
            break;
           }
          } else {
           __THREW__ = 0;
           invoke_viiiiii(104,($loop|0),($344|0),1,($345|0),($272|0),1);
           $348 = __THREW__; __THREW__ = 0;
           $349 = $348&1;
           if ($349) {
            label = 36;
            break L1;
           } else {
            break;
           }
          }
         }
        } while(0);
        __THREW__ = 0;
        $350 = (invoke_i(59)|0);
        $351 = __THREW__; __THREW__ = 0;
        $352 = $351&1;
        if ($352) {
         label = 36;
        } else {
         $353 = HEAP32[$350>>2]|0;
         $354 = (($353) + 72|0);
         $355 = HEAP32[$354>>2]|0;
         __THREW__ = 0;
         invoke_vii($355|0,($350|0),($272|0));
         $356 = __THREW__; __THREW__ = 0;
         $357 = $356&1;
         if ($357) {
          label = 36;
         } else {
          __THREW__ = 0;
          invoke_vi(3407,($25|0));
          $358 = __THREW__; __THREW__ = 0;
          $359 = $358&1;
          if ($359) {
           label = 36;
          } else {
           __THREW__ = 0;
           $360 = (invoke_i(59)|0);
           $361 = __THREW__; __THREW__ = 0;
           $362 = $361&1;
           if ($362) {
            label = 36;
           } else {
            $363 = HEAP32[$360>>2]|0;
            $364 = (($363) + 72|0);
            $365 = HEAP32[$364>>2]|0;
            __THREW__ = 0;
            invoke_vii($365|0,($360|0),0);
            $366 = __THREW__; __THREW__ = 0;
            $367 = $366&1;
            if ($367) {
             label = 36;
            } else {
             $368 = (($25) + 292|0);
             $369 = HEAP32[$368>>2]|0;
             $370 = ($369|0)==(0);
             if ($370) {
              $$0$i$i = 0;
             } else {
              HEAP32[$0>>2] = $369;
              $371 = HEAP32[560624>>2]|0;
              $372 = ($371|0)==(0|0);
              if ($372) {
               label = 99;
              } else {
               $373 = (($371) + 36|0);
               $374 = HEAP32[$373>>2]|0;
               $375 = (($371) + 4|0);
               $376 = HEAP32[$375>>2]|0;
               $377 = ($374|0)==($376|0);
               do {
                if ($377) {
                 $378 = (($371) + 28|0);
                 $379 = HEAP32[$378>>2]|0;
                 $380 = (($371) + 32|0);
                 $381 = HEAP32[$380>>2]|0;
                 $382 = (($379) + ($381<<3)|0);
                 $398 = $382;
                } else {
                 __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy12,$371,$0);
                 $383 = HEAP32[$$byval_copy12>>2]|0;
                 $384 = ($383|0)==(-1);
                 $385 = (($371) + 28|0);
                 $386 = HEAP32[$385>>2]|0;
                 if ($384) {
                  $387 = (($371) + 32|0);
                  $388 = HEAP32[$387>>2]|0;
                  $389 = (($386) + ($388<<3)|0);
                  $398 = $389;
                  break;
                 } else {
                  $390 = (($386) + ($383<<3)|0);
                  $398 = $390;
                  break;
                 }
                }
               } while(0);
               $391 = HEAP32[560624>>2]|0;
               $392 = (($391) + 28|0);
               $393 = HEAP32[$392>>2]|0;
               $394 = (($391) + 32|0);
               $395 = HEAP32[$394>>2]|0;
               $396 = (($393) + ($395<<3)|0);
               $397 = ($398|0)==($396|0);
               if ($397) {
                label = 99;
               } else {
                $399 = (($398) + 4|0);
                $400 = HEAP32[$399>>2]|0;
                $401 = ($400|0)==(0|0);
                if ($401) {
                 label = 99;
                } else {
                 $temp$0$i$i = $400;
                }
               }
              }
              if ((label|0) == 99) {
               $402 = HEAP32[$368>>2]|0;
               __THREW__ = 0;
               $403 = (invoke_ii(3215,($402|0))|0);
               $404 = __THREW__; __THREW__ = 0;
               $405 = $404&1;
               if ($405) {
                label = 36;
                break;
               } else {
                $temp$0$i$i = $403;
               }
              }
              $$0$i$i = $temp$0$i$i;
             }
             __THREW__ = 0;
             invoke_viii(1668,($loop|0),($$0$i$i|0),1);
             $406 = __THREW__; __THREW__ = 0;
             $407 = $406&1;
             if ($407) {
              label = 36;
             } else {
              HEAP32[$273>>2] = 2501;
              HEAP32[$274>>2] = 5000;
              $408 = ($renderPath|0)==(0);
              $409 = (($loop) + 748|0);
              $410 = (($contents) + 124|0);
              if ($408) {
               __THREW__ = 0;
               invoke_viiiiii(104,($loop|0),($409|0),0,($410|0),($272|0),0);
               $413 = __THREW__; __THREW__ = 0;
               $414 = $413&1;
               if ($414) {
                label = 36;
                break;
               }
              } else {
               __THREW__ = 0;
               invoke_viiiiiiii(25,($loop|0),($409|0),0,0,(0|0),($410|0),($272|0),0);
               $411 = __THREW__; __THREW__ = 0;
               $412 = $411&1;
               if ($412) {
                label = 36;
                break;
               }
              }
              $415 = HEAP32[$rtDepth>>2]|0;
              $416 = HEAP32[$rtDepthNormals>>2]|0;
              $417 = HEAP8[$prepassDepthWasCopied>>0]|0;
              $418 = ($417<<24>>24)!=(0);
              $419 = HEAP32[652824>>2]|0;
              __THREW__ = 0;
              invoke_viiiiiiiii(10,($25|0),($415|0),($416|0),($409|0),($26|0),($418|0),0,0,($419|0));
              $420 = __THREW__; __THREW__ = 0;
              $421 = $420&1;
              if ($421) {
               label = 36;
              } else {
               HEAP32[$12>>2] = 0;
               HEAP32[$13>>2] = 0;
               $422 = (__Z12GetGfxDevicev()|0);
               $423 = HEAP32[$422>>2]|0;
               $424 = (($423) + 84|0);
               $425 = HEAP32[$424>>2]|0;
               FUNCTION_TABLE_vii[$425 & 4095]($422,$18);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 36) {
  $181 = ___cxa_find_matching_catch()|0;
  $182 = tempRet0;
  $lpad$phi$index = $181;$lpad$phi$index3 = $182;
  label = 37;
 }
 if ((label|0) == 37) {
  $$0 = $lpad$phi$index;$$01 = $lpad$phi$index3;
 }
 __THREW__ = 0;
 $426 = (invoke_i(59)|0);
 $427 = __THREW__; __THREW__ = 0;
 $428 = $427&1;
 if ($428) {
  $434 = ___cxa_find_matching_catch(0|0)|0;
  $435 = tempRet0;
  ___clang_call_terminate($434);
  // unreachable;
 }
 $429 = HEAP32[$426>>2]|0;
 $430 = (($429) + 84|0);
 $431 = HEAP32[$430>>2]|0;
 __THREW__ = 0;
 invoke_vii($431|0,($426|0),($18|0));
 $432 = __THREW__; __THREW__ = 0;
 $433 = $432&1;
 if ($433) {
  $434 = ___cxa_find_matching_catch(0|0)|0;
  $435 = tempRet0;
  ___clang_call_terminate($434);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZL25UpdateCameraDepthTexturesR6CameraP13RenderTextureS2_R13dynamic_arrayI16RenderObjectDataLj4EERK17ShaderReplaceDatabbbRN9ShaderLab17ShaderPassContextE($camera,$rtDepth,$rtDepthNormals,$objects,$shaderReplace,$depthWasCopied,$skipDepthTexture,$afterOpaque,$passContext) {
 $camera = $camera|0;
 $rtDepth = $rtDepth|0;
 $rtDepthNormals = $rtDepthNormals|0;
 $objects = $objects|0;
 $shaderReplace = $shaderReplace|0;
 $depthWasCopied = $depthWasCopied|0;
 $skipDepthTexture = $skipDepthTexture|0;
 $afterOpaque = $afterOpaque|0;
 $passContext = $passContext|0;
 var $$ = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $rtSurfaceColor = 0, $rtSurfaceColor1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 28|0;
 $rtSurfaceColor = sp;
 $0 = sp + 4|0;
 $rtSurfaceColor1 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = ($rtDepth|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($objects) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($camera) + 348|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 148|0);
 $10 = HEAP32[$9>>2]|0;
 $$ = $afterOpaque ? 2 : 18;
 $11 = HEAP8[((640792 + 248|0))>>0]|0;
 $12 = ($11<<24>>24)==(0);
 $or$cond = $12 | $skipDepthTexture;
 if (!($or$cond)) {
  $13 = (($camera) + 604|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & 1;
  $16 = ($15|0)==(0);
  if (!($16)) {
   if ($depthWasCopied) {
    __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($rtDepth,0,-1,0);
   } else {
    $17 = (($rtDepth) + 140|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$rtSurfaceColor>>2] = $18;
    HEAP32[$0>>2] = $10;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rtSurfaceColor,$$byval_copy1,$rtDepth,0,-1,0)|0);
   }
   __Z20RenderSceneDepthPassR13dynamic_arrayI16RenderObjectDataLj4EERK17ShaderReplaceDatabRN9ShaderLab17ShaderPassContextE($objects,$shaderReplace,0,$passContext);
   __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($camera,$passContext,$$);
  }
 }
 $19 = ($rtDepthNormals|0)==(0|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (($camera) + 604|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 & 2;
 $23 = ($22|0)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (__Z34GetCameraDepthNormalsTextureShaderv()|0);
 $25 = ($24|0)==(0|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($rtDepthNormals) + 140|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$rtSurfaceColor1>>2] = $27;
 HEAP32[$1>>2] = $10;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rtSurfaceColor1,$$byval_copy1,$rtDepthNormals,0,-1,0)|0);
 HEAP8[$2>>0] = 20;
 $28 = (($2) + 1|0);
 dest=$28+0|0; src=569256+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $29 = (($2) + 11|0);
 HEAP8[$29>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(341,($objects|0),($24|0),($2|0),($passContext|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  $39 = HEAP8[$2>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   ___resumeException($37|0);
   // unreachable;
  }
  $42 = (($2) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  __ZdlPv($43);
  ___resumeException($37|0);
  // unreachable;
 } else {
  $32 = HEAP8[$2>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if (!($34)) {
   $35 = (($2) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   __ZdlPv($36);
  }
  __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($camera,$passContext,$$);
  STACKTOP = sp;return;
 }
}
function __Z22CleanupAfterRenderLoopR10RenderLoop($loop) {
 $loop = $loop|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z22GetRenderBufferManagerv()|0);
 $i$01 = 0;
 while(1) {
  $1 = ((($loop) + ($i$01<<2)|0) + 800|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($0,$2);
   HEAP32[$1>>2] = 0;
  }
  $4 = (($i$01) + 1)|0;
  $exitcond = ($4|0)==(15);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $4;
  }
 }
 __ZN9ShaderLab23ClearGrabPassFrameStateEv();
 STACKTOP = sp;return;
}
function __Z23AddRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureTypeP13RenderTexture($loop,$type,$rt) {
 $loop = $loop|0;
 $type = $type|0;
 $rt = $rt|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($loop) + ($type<<2)|0) + 800|0);
 HEAP32[$0>>2] = $rt;
 STACKTOP = sp;return;
}
function __Z23GetRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureType($loop,$type) {
 $loop = $loop|0;
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($type|0)==(1);
 if ($0) {
  $1 = (__ZN13RenderTexture9GetActiveEv()|0);
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $2 = ((($loop) + ($type<<2)|0) + 800|0);
  $3 = HEAP32[$2>>2]|0;
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z28RenderSceneShaderReplacementRK13dynamic_arrayI11VisibleNodeLj4EEP6ShaderRKNSt3__112basic_stringIcNS6_11char_traitsIcEENS6_9allocatorIcEEEERN9ShaderLab17ShaderPassContextE($contents,$shader,$shaderReplaceTag,$passContext) {
 $contents = $contents|0;
 $shader = $shader|0;
 $shaderReplaceTag = $shaderReplaceTag|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $replaceData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $replaceData = sp;
 $0 = (($replaceData) + 4|0);
 HEAP32[$0>>2] = -1;
 HEAP32[$replaceData>>2] = $shader;
 $1 = HEAP8[$shaderReplaceTag>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $9 = $7;
 } else {
  $4 = (($shaderReplaceTag) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $9 = $5;
 }
 $8 = ($9|0)==(0);
 if ($8) {
  $11 = -1;
 } else {
  $10 = (__ZN9ShaderLab14GetShaderTagIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($shaderReplaceTag)|0);
  $11 = $10;
 }
 HEAP32[$0>>2] = $11;
 __Z28RenderSceneShaderReplacementRK13dynamic_arrayI11VisibleNodeLj4EERK17ShaderReplaceDataRN9ShaderLab17ShaderPassContextE($contents,$replaceData,$passContext);
 STACKTOP = sp;return;
}
function __Z28RenderSceneShaderReplacementRK13dynamic_arrayI11VisibleNodeLj4EERK17ShaderReplaceDataRN9ShaderLab17ShaderPassContextE($contents,$shaderReplace,$passContext) {
 $contents = $contents|0;
 $shaderReplace = $shaderReplace|0;
 $passContext = $passContext|0;
 var $$0$i = 0, $$byval_copy10 = 0, $$pr = 0, $$pre$i = 0, $$pre1$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i2 = 0, $curCameraMatrix = 0, $i$015 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $mi$011 = 0, $phitmp = 0, $renderObjects = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $temp$0$i = 0, $temp$0$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy10 = sp + 104|0;
 $0 = sp + 100|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 88|0;
 $4 = sp + 80|0;
 $curCameraMatrix = sp + 16|0;
 $renderObjects = sp;
 $5 = sp + 84|0;
 $6 = (($shaderReplace) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$shaderReplace>>2]|0;
 $9 = (__Z16GetRenderManagerv()|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$4>>2] = $10;
 $11 = HEAP32[560624>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  label = 9;
 } else {
  $13 = (($11) + 36|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($11) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14|0)==($16|0);
  do {
   if ($17) {
    $18 = (($11) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($11) + 32|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($19) + ($21<<3)|0);
    $38 = $22;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy10,$11,$4);
    $23 = HEAP32[$$byval_copy10>>2]|0;
    $24 = ($23|0)==(-1);
    $25 = (($11) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    if ($24) {
     $27 = (($11) + 32|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($26) + ($28<<3)|0);
     $38 = $29;
     break;
    } else {
     $30 = (($26) + ($23<<3)|0);
     $38 = $30;
     break;
    }
   }
  } while(0);
  $31 = HEAP32[560624>>2]|0;
  $32 = (($31) + 28|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + 32|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + ($35<<3)|0);
  $37 = ($38|0)==($36|0);
  if ($37) {
   label = 9;
  } else {
   $39 = (($38) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    label = 9;
   } else {
    $temp$0$i$i = $40;
   }
  }
 }
 if ((label|0) == 9) {
  $42 = HEAP32[$9>>2]|0;
  $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
  $temp$0$i$i = $43;
 }
 $44 = (__ZNK6Camera22GetWorldToCameraMatrixEv($temp$0$i$i)|0);
 dest=$curCameraMatrix+0|0; src=$44+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$renderObjects>>2] = 0;
 $45 = (($renderObjects) + 4|0);
 HEAP32[$45>>2] = 0;
 $46 = (($renderObjects) + 8|0);
 HEAP32[$46>>2] = 0;
 $47 = (($contents) + 8|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 >>> 2;
 $50 = ($49|0)==(0);
 if ($50) {
  $67 = $48;
  label = 16;
 } else {
  $51 = $49 << 5;
  HEAP32[$2>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
  $52 = (invoke_iiiiiii(102,($51|0),16,($$byval_copy10|0),0,(569272|0),79)|0);
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if ($54) {
   label = 39;
  } else {
   $$pre$i = HEAP32[$renderObjects>>2]|0;
   $$pre1$i = HEAP32[$45>>2]|0;
   $phitmp = $$pre1$i;
   $55 = (($52) + ($49<<5)|0);
   $56 = $$pre$i;
   $57 = (($phitmp) - ($56))|0;
   $58 = $57 >> 5;
   $$sum$i = (0 - ($58))|0;
   $59 = (($52) + ($$sum$i<<5)|0);
   _memcpy(($59|0),($$pre$i|0),($57|0))|0;
   $60 = HEAP32[$renderObjects>>2]|0;
   HEAP32[$renderObjects>>2] = $59;
   HEAP32[$45>>2] = $52;
   HEAP32[$46>>2] = $55;
   $61 = ($60|0)==(0|0);
   if (!($61)) {
    HEAP32[$3>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($60|0),($$byval_copy10|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $64 = ___cxa_find_matching_catch()|0;
     $65 = tempRet0;
     ___cxa_call_unexpected(($64|0));
     // unreachable;
    }
   }
   $$pr = HEAP32[$47>>2]|0;
   $67 = $$pr;
   label = 16;
  }
 }
 L21: do {
  if ((label|0) == 16) {
   $66 = ($67|0)==(0);
   L23: do {
    if (!($66)) {
     $68 = HEAP32[$contents>>2]|0;
     $69 = (($curCameraMatrix) + 8|0);
     $70 = (($curCameraMatrix) + 24|0);
     $71 = (($curCameraMatrix) + 40|0);
     $72 = (($curCameraMatrix) + 56|0);
     $i$015 = $68;
     L25: while(1) {
      $73 = (($i$015) + 64|0);
      $74 = Math_fround(HEAPF32[$73>>2]);
      $75 = (($i$015) + 68|0);
      $76 = Math_fround(HEAPF32[$75>>2]);
      $77 = (($i$015) + 72|0);
      $78 = Math_fround(HEAPF32[$77>>2]);
      $79 = Math_fround(HEAPF32[$69>>2]);
      $80 = Math_fround($74 * $79);
      $81 = Math_fround(HEAPF32[$70>>2]);
      $82 = Math_fround($76 * $81);
      $83 = Math_fround($80 + $82);
      $84 = Math_fround(HEAPF32[$71>>2]);
      $85 = Math_fround($78 * $84);
      $86 = Math_fround($83 + $85);
      $87 = Math_fround(HEAPF32[$72>>2]);
      $88 = Math_fround($87 + $86);
      $89 = (($i$015) + 116|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = HEAP32[$90>>2]|0;
      $92 = (($91) + 40|0);
      $93 = HEAP32[$92>>2]|0;
      __THREW__ = 0;
      $94 = (invoke_ii($93|0,($90|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 38;
       break;
      }
      $97 = ($94|0)>(0);
      if ($97) {
       $98 = (($90) + 172|0);
       $mi$011 = 0;
       while(1) {
        $99 = HEAP32[$90>>2]|0;
        $100 = (($99) + 44|0);
        $101 = HEAP32[$100>>2]|0;
        __THREW__ = 0;
        invoke_viii($101|0,($5|0),($90|0),($mi$011|0));
        $102 = __THREW__; __THREW__ = 0;
        $103 = $102&1;
        if ($103) {
         label = 37;
         break L25;
        }
        $104 = HEAP32[$5>>2]|0;
        $105 = ($104|0)==(0);
        if ($105) {
         $$0$i = 0;
        } else {
         HEAP32[$1>>2] = $104;
         $106 = HEAP32[560624>>2]|0;
         $107 = ($106|0)==(0|0);
         if ($107) {
          label = 31;
         } else {
          $108 = (($106) + 36|0);
          $109 = HEAP32[$108>>2]|0;
          $110 = (($106) + 4|0);
          $111 = HEAP32[$110>>2]|0;
          $112 = ($109|0)==($111|0);
          do {
           if ($112) {
            $113 = (($106) + 28|0);
            $114 = HEAP32[$113>>2]|0;
            $115 = (($106) + 32|0);
            $116 = HEAP32[$115>>2]|0;
            $117 = (($114) + ($116<<3)|0);
            $133 = $117;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy10,$106,$1);
            $118 = HEAP32[$$byval_copy10>>2]|0;
            $119 = ($118|0)==(-1);
            $120 = (($106) + 28|0);
            $121 = HEAP32[$120>>2]|0;
            if ($119) {
             $122 = (($106) + 32|0);
             $123 = HEAP32[$122>>2]|0;
             $124 = (($121) + ($123<<3)|0);
             $133 = $124;
             break;
            } else {
             $125 = (($121) + ($118<<3)|0);
             $133 = $125;
             break;
            }
           }
          } while(0);
          $126 = HEAP32[560624>>2]|0;
          $127 = (($126) + 28|0);
          $128 = HEAP32[$127>>2]|0;
          $129 = (($126) + 32|0);
          $130 = HEAP32[$129>>2]|0;
          $131 = (($128) + ($130<<3)|0);
          $132 = ($133|0)==($131|0);
          if ($132) {
           label = 31;
          } else {
           $134 = (($133) + 4|0);
           $135 = HEAP32[$134>>2]|0;
           $136 = ($135|0)==(0|0);
           if ($136) {
            label = 31;
           } else {
            $temp$0$i = $135;
           }
          }
         }
         if ((label|0) == 31) {
          label = 0;
          $137 = HEAP32[$5>>2]|0;
          __THREW__ = 0;
          $138 = (invoke_ii(3215,($137|0))|0);
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           label = 37;
           break L25;
          } else {
           $temp$0$i = $138;
          }
         }
         $$0$i = $temp$0$i;
        }
        $141 = HEAP32[$90>>2]|0;
        $142 = (($141) + 52|0);
        $143 = HEAP32[$142>>2]|0;
        __THREW__ = 0;
        $144 = (invoke_ii($143|0,($90|0))|0);
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 37;
         break L25;
        }
        $147 = HEAP32[$98>>2]|0;
        $148 = HEAP32[$90>>2]|0;
        $149 = (($148) + 60|0);
        $150 = HEAP32[$149>>2]|0;
        __THREW__ = 0;
        $151 = (invoke_ii($150|0,($90|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         label = 37;
         break L25;
        }
        __THREW__ = 0;
        invoke_viiiiifiiii(1,($renderObjects|0),($$0$i|0),($8|0),($7|0),($i$015|0),(+$88),($mi$011|0),($144|0),($147|0),($151|0));
        $154 = __THREW__; __THREW__ = 0;
        $155 = $154&1;
        if ($155) {
         label = 37;
         break L25;
        }
        $156 = (($mi$011) + 1)|0;
        $157 = ($156|0)<($94|0);
        if ($157) {
         $mi$011 = $156;
        } else {
         break;
        }
       }
      }
      $175 = (($i$015) + 128|0);
      $176 = HEAP32[$contents>>2]|0;
      $177 = HEAP32[$47>>2]|0;
      $178 = (($176) + ($177<<7)|0);
      $179 = ($175|0)==($178|0);
      if ($179) {
       break L23;
      } else {
       $i$015 = $175;
      }
     }
     if ((label|0) == 37) {
      $158 = ___cxa_find_matching_catch()|0;
      $159 = tempRet0;
      $lpad$phi$index = $158;$lpad$phi$index3 = $159;
      break L21;
     }
     else if ((label|0) == 38) {
      $160 = ___cxa_find_matching_catch()|0;
      $161 = tempRet0;
      $lpad$phi$index = $160;$lpad$phi$index3 = $161;
      break L21;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_viii(1669,($curCameraMatrix|0),($renderObjects|0),($passContext|0));
   $180 = __THREW__; __THREW__ = 0;
   $181 = $180&1;
   if ($181) {
    label = 39;
   } else {
    $182 = HEAP32[$renderObjects>>2]|0;
    $183 = ($182|0)==(0|0);
    if ($183) {
     STACKTOP = sp;return;
    }
    $184 = HEAP32[$45>>2]|0;
    $185 = ($184|0)==($182|0);
    if (!($185)) {
     $__new_last2$i$i$i$i$i = $182;
     $scevgep$i$i$i$i$i = (($184) + -32|0);
     $186 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($186)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $187 = $uglygep3$i$i$i$i$i >>> 5;
     $188 = $187 ^ -1;
     $scevgep4$i$i$i$i$i = (($184) + ($188<<5)|0);
     HEAP32[$45>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($182|0),($$byval_copy10|0));
    $189 = __THREW__; __THREW__ = 0;
    $190 = $189&1;
    if ($190) {
     $191 = ___cxa_find_matching_catch()|0;
     $192 = tempRet0;
     ___cxa_call_unexpected(($191|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 39) {
  $162 = ___cxa_find_matching_catch()|0;
  $163 = tempRet0;
  $lpad$phi$index = $162;$lpad$phi$index3 = $163;
 }
 $164 = HEAP32[$renderObjects>>2]|0;
 $165 = ($164|0)==(0|0);
 if ($165) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $166 = HEAP32[$45>>2]|0;
 $167 = ($166|0)==($164|0);
 if (!($167)) {
  $__new_last2$i$i$i$i$i2 = $164;
  $scevgep$i$i$i$i$i3 = (($166) + -32|0);
  $168 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($168)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $169 = $uglygep3$i$i$i$i$i6 >>> 5;
  $170 = $169 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($166) + ($170<<5)|0);
  HEAP32[$45>>2] = $scevgep4$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($164|0),($$byval_copy10|0));
 $171 = __THREW__; __THREW__ = 0;
 $172 = $171&1;
 if ($172) {
  $173 = ___cxa_find_matching_catch()|0;
  $174 = tempRet0;
  ___cxa_call_unexpected(($173|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZL20AddReplacementObjectRNSt3__16vectorI17RODataReplacement13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEEPN5Unity8MaterialEP6ShaderiPK11VisibleNodefii18GlobalLayeringDatat($renderObjects,$mat,$replacementShader,$replacementTagID,$visibleNode,$distanceForSort,$materialIndex,$staticBatchIndex,$globalLayeringData$0,$sameDistanceSortPriority) {
 $renderObjects = $renderObjects|0;
 $mat = $mat|0;
 $replacementShader = $replacementShader|0;
 $replacementTagID = $replacementTagID|0;
 $visibleNode = $visibleNode|0;
 $distanceForSort = Math_fround($distanceForSort);
 $materialIndex = $materialIndex|0;
 $staticBatchIndex = $staticBatchIndex|0;
 $globalLayeringData$0 = $globalLayeringData$0|0;
 $sameDistanceSortPriority = $sameDistanceSortPriority|0;
 var $$0 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = ($mat|0)==(0|0);
 if ($1) {
  $2 = (__ZN5Unity8Material10GetDefaultEv()|0);
  $$0 = $2;
 } else {
  $$0 = $mat;
 }
 $3 = (__ZN5Unity8Material9GetShaderEv($$0)|0);
 $4 = (__Z28CalculateSubShaderIndexToUseP6ShaderS0_i($3,$replacementShader,$replacementTagID)|0);
 $5 = ($4|0)<(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
 $6 = (($0) + 24|0);
 HEAP32[$6>>2] = -2147450880;
 $7 = (($renderObjects) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($renderObjects) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  __ZNSt3__16vectorI17RODataReplacement13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($renderObjects,$0);
  $$pre = HEAP32[$7>>2]|0;
  $16 = $$pre;
 } else {
  $12 = ($8|0)==(0|0);
  if ($12) {
   $14 = 0;
  } else {
   ;HEAP32[$8+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$0+24>>2]|0;HEAP32[$8+28>>2]=HEAP32[$0+28>>2]|0;
   $$pre$i = HEAP32[$7>>2]|0;
   $14 = $$pre$i;
  }
  $13 = (($14) + 32|0);
  HEAP32[$7>>2] = $13;
  $16 = $13;
 }
 $15 = (($16) + -20|0);
 HEAP32[$15>>2] = $visibleNode;
 $17 = (($$0) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (HEAPF32[tempDoublePtr>>2]=$distanceForSort,HEAP32[tempDoublePtr>>2]|0);
 $20 = $19 >>> 22;
 $21 = $4 << 27;
 $22 = $staticBatchIndex << 19;
 $23 = $22 & 133693440;
 $24 = $20 << 9;
 $25 = $18 << 3;
 $26 = $25 & 496;
 $27 = $23 | $24;
 $28 = $27 | $21;
 $29 = $28 | $26;
 $30 = (($16) + -32|0);
 HEAP32[$30>>2] = $29;
 $31 = (($16) + -24|0);
 HEAP32[$31>>2] = $$0;
 $32 = (($16) + -12|0);
 HEAP32[$32>>2] = $materialIndex;
 $33 = (($16) + -16|0);
 HEAP32[$33>>2] = $replacementShader;
 $34 = (($16) + -28|0);
 HEAP32[$34>>2] = $4;
 $35 = (($16) + -4|0);
 HEAP16[$35>>1] = $sameDistanceSortPriority;
 $36 = (($16) + -8|0);
 HEAP32[$36>>2] = $globalLayeringData$0;
 STACKTOP = sp;return;
}
function __ZL27PerformRenderingReplacementR6CameraRK10Matrix4x4fRNSt3__16vectorI17RODataReplacement13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEEERN9ShaderLab17ShaderPassContextE($curCameraMatrix,$renderData,$passContext) {
 $curCameraMatrix = $curCameraMatrix|0;
 $renderData = $renderData|0;
 $passContext = $passContext|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond15 = 0, $i$011 = 0, $p$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$renderData>>2]|0;
 $2 = (($renderData) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__sortIR19ROSorterReplacementP17RODataReplacementEEvT0_S5_T_($1,$3,$0);
 $4 = (__Z12GetGfxDevicev()|0);
 $5 = HEAP32[$2>>2]|0;
 $6 = HEAP32[$renderData>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 5;
 $11 = HEAP32[$4>>2]|0;
 $12 = (($11) + 100|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$13 & 4095]($4,$curCameraMatrix);
 $14 = ($10|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 } else {
  $i$011 = 0;
 }
 while(1) {
  $15 = HEAP32[$renderData>>2]|0;
  $16 = ((($15) + ($i$011<<5)|0) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 116|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($15) + ($i$011<<5)|0) + 16|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($17) + 120|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  __Z12SetupLODFadeR9GfxDeviceRN9ShaderLab17ShaderPassContextEf($4,$passContext,$23);
  $24 = HEAP32[$20>>2]|0;
  $25 = (($24) + 52|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($15) + ($i$011<<5)|0) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$26>>2]|0;
  $30 = (($29) + ($28<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)>(0);
  L5: do {
   if ($34) {
    $35 = ((($15) + ($i$011<<5)|0) + 8|0);
    $36 = (($17) + 112|0);
    $37 = ((($15) + ($i$011<<5)|0) + 20|0);
    $39 = $28;$p$010 = 0;
    while(1) {
     $38 = HEAP32[$35>>2]|0;
     $40 = (__ZN5Unity8Material17SetPassWithShaderEiP6ShaderRN9ShaderLab17ShaderPassContextEi($38,$p$010,$21,$passContext,$39)|0);
     $41 = ($40|0)==(0|0);
     if (!($41)) {
      $42 = HEAP32[$36>>2]|0;
      __Z17SetupObjectMatrixRK10Matrix4x4fi($17,$42);
      $43 = HEAP32[$19>>2]|0;
      $44 = (($43) + 8|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = (($43) + 48|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = HEAP32[$37>>2]|0;
      $49 = (FUNCTION_TABLE_iii[$47 & 4095]($19,$48)|0);
      FUNCTION_TABLE_viii[$45 & 4095]($19,$49,$40);
     }
     $50 = (($p$010) + 1)|0;
     $exitcond = ($50|0)==($33|0);
     if ($exitcond) {
      break L5;
     }
     $$pre = HEAP32[$27>>2]|0;
     $39 = $$pre;$p$010 = $50;
    }
   }
  } while(0);
  $51 = (($i$011) + 1)|0;
  $exitcond15 = ($51|0)==($10|0);
  if ($exitcond15) {
   break;
  } else {
   $i$011 = $51;
  }
 }
 STACKTOP = sp;return;
}
function __Z20RenderSceneDepthPassRK13dynamic_arrayI11VisibleNodeLj4EERK17ShaderReplaceDatabRN9ShaderLab17ShaderPassContextE($contents,$shaderReplace,$disableDynamicBatching,$passContext) {
 $contents = $contents|0;
 $shaderReplace = $shaderReplace|0;
 $disableDynamicBatching = $disableDynamicBatching|0;
 $passContext = $passContext|0;
 var $$0$i = 0, $$byval_copy10 = 0, $$pr = 0, $$pre$i = 0, $$pre1$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $curCameraMatrix = 0, $i$015 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $mi$011 = 0, $phitmp = 0, $renderObjects = 0, $scevgep$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $temp$0$i = 0, $temp$0$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy10 = sp + 104|0;
 $0 = sp + 100|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 88|0;
 $4 = sp + 80|0;
 $curCameraMatrix = sp + 16|0;
 $renderObjects = sp;
 $5 = sp + 84|0;
 $6 = (__Z16GetRenderManagerv()|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$4>>2] = $7;
 $8 = HEAP32[560624>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = (($8) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($8) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  do {
   if ($14) {
    $15 = (($8) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($8) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + ($18<<3)|0);
    $35 = $19;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy10,$8,$4);
    $20 = HEAP32[$$byval_copy10>>2]|0;
    $21 = ($20|0)==(-1);
    $22 = (($8) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    if ($21) {
     $24 = (($8) + 32|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($23) + ($25<<3)|0);
     $35 = $26;
     break;
    } else {
     $27 = (($23) + ($20<<3)|0);
     $35 = $27;
     break;
    }
   }
  } while(0);
  $28 = HEAP32[560624>>2]|0;
  $29 = (($28) + 28|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 32|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + ($32<<3)|0);
  $34 = ($35|0)==($33|0);
  if ($34) {
   label = 9;
  } else {
   $36 = (($35) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    label = 9;
   } else {
    $temp$0$i$i = $37;
   }
  }
 }
 if ((label|0) == 9) {
  $39 = HEAP32[$6>>2]|0;
  $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
  $temp$0$i$i = $40;
 }
 $41 = (__ZNK6Camera22GetWorldToCameraMatrixEv($temp$0$i$i)|0);
 dest=$curCameraMatrix+0|0; src=$41+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$renderObjects>>2] = 0;
 $42 = (($renderObjects) + 4|0);
 HEAP32[$42>>2] = 0;
 $43 = (($renderObjects) + 8|0);
 HEAP32[$43>>2] = 0;
 $44 = (($contents) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45 >>> 1;
 $47 = ($46|0)==(0);
 if ($47) {
  $64 = $45;
  label = 16;
 } else {
  $48 = $46 << 5;
  HEAP32[$2>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
  $49 = (invoke_iiiiiii(102,($48|0),16,($$byval_copy10|0),0,(569272|0),79)|0);
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   label = 38;
  } else {
   $$pre$i = HEAP32[$renderObjects>>2]|0;
   $$pre1$i = HEAP32[$42>>2]|0;
   $phitmp = $$pre1$i;
   $52 = (($49) + ($46<<5)|0);
   $53 = $$pre$i;
   $54 = (($phitmp) - ($53))|0;
   $55 = $54 >> 5;
   $$sum$i = (0 - ($55))|0;
   $56 = (($49) + ($$sum$i<<5)|0);
   _memcpy(($56|0),($$pre$i|0),($54|0))|0;
   $57 = HEAP32[$renderObjects>>2]|0;
   HEAP32[$renderObjects>>2] = $56;
   HEAP32[$42>>2] = $49;
   HEAP32[$43>>2] = $52;
   $58 = ($57|0)==(0|0);
   if (!($58)) {
    HEAP32[$3>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy10|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     $61 = ___cxa_find_matching_catch()|0;
     $62 = tempRet0;
     ___cxa_call_unexpected(($61|0));
     // unreachable;
    }
   }
   $$pr = HEAP32[$44>>2]|0;
   $64 = $$pr;
   label = 16;
  }
 }
 L21: do {
  if ((label|0) == 16) {
   $63 = ($64|0)==(0);
   L23: do {
    if (!($63)) {
     $65 = HEAP32[$contents>>2]|0;
     $66 = (($curCameraMatrix) + 8|0);
     $67 = (($curCameraMatrix) + 24|0);
     $68 = (($curCameraMatrix) + 40|0);
     $69 = (($curCameraMatrix) + 56|0);
     $i$015 = $65;
     L25: while(1) {
      $70 = (($i$015) + 64|0);
      $71 = Math_fround(HEAPF32[$70>>2]);
      $72 = (($i$015) + 68|0);
      $73 = Math_fround(HEAPF32[$72>>2]);
      $74 = (($i$015) + 72|0);
      $75 = Math_fround(HEAPF32[$74>>2]);
      $76 = Math_fround(HEAPF32[$66>>2]);
      $77 = Math_fround($71 * $76);
      $78 = Math_fround(HEAPF32[$67>>2]);
      $79 = Math_fround($73 * $78);
      $80 = Math_fround($77 + $79);
      $81 = Math_fround(HEAPF32[$68>>2]);
      $82 = Math_fround($75 * $81);
      $83 = Math_fround($80 + $82);
      $84 = Math_fround(HEAPF32[$69>>2]);
      $85 = Math_fround($84 + $83);
      $86 = (($i$015) + 116|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = HEAP32[$87>>2]|0;
      $89 = (($88) + 40|0);
      $90 = HEAP32[$89>>2]|0;
      __THREW__ = 0;
      $91 = (invoke_ii($90|0,($87|0))|0);
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       label = 37;
       break;
      }
      $94 = ($91|0)>(0);
      if ($94) {
       $95 = (($87) + 172|0);
       $mi$011 = 0;
       while(1) {
        $96 = HEAP32[$87>>2]|0;
        $97 = (($96) + 44|0);
        $98 = HEAP32[$97>>2]|0;
        __THREW__ = 0;
        invoke_viii($98|0,($5|0),($87|0),($mi$011|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 36;
         break L25;
        }
        $101 = HEAP32[$5>>2]|0;
        $102 = ($101|0)==(0);
        if ($102) {
         $$0$i = 0;
        } else {
         HEAP32[$1>>2] = $101;
         $103 = HEAP32[560624>>2]|0;
         $104 = ($103|0)==(0|0);
         if ($104) {
          label = 31;
         } else {
          $105 = (($103) + 36|0);
          $106 = HEAP32[$105>>2]|0;
          $107 = (($103) + 4|0);
          $108 = HEAP32[$107>>2]|0;
          $109 = ($106|0)==($108|0);
          do {
           if ($109) {
            $110 = (($103) + 28|0);
            $111 = HEAP32[$110>>2]|0;
            $112 = (($103) + 32|0);
            $113 = HEAP32[$112>>2]|0;
            $114 = (($111) + ($113<<3)|0);
            $130 = $114;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy10,$103,$1);
            $115 = HEAP32[$$byval_copy10>>2]|0;
            $116 = ($115|0)==(-1);
            $117 = (($103) + 28|0);
            $118 = HEAP32[$117>>2]|0;
            if ($116) {
             $119 = (($103) + 32|0);
             $120 = HEAP32[$119>>2]|0;
             $121 = (($118) + ($120<<3)|0);
             $130 = $121;
             break;
            } else {
             $122 = (($118) + ($115<<3)|0);
             $130 = $122;
             break;
            }
           }
          } while(0);
          $123 = HEAP32[560624>>2]|0;
          $124 = (($123) + 28|0);
          $125 = HEAP32[$124>>2]|0;
          $126 = (($123) + 32|0);
          $127 = HEAP32[$126>>2]|0;
          $128 = (($125) + ($127<<3)|0);
          $129 = ($130|0)==($128|0);
          if ($129) {
           label = 31;
          } else {
           $131 = (($130) + 4|0);
           $132 = HEAP32[$131>>2]|0;
           $133 = ($132|0)==(0|0);
           if ($133) {
            label = 31;
           } else {
            $temp$0$i = $132;
           }
          }
         }
         if ((label|0) == 31) {
          label = 0;
          $134 = HEAP32[$5>>2]|0;
          __THREW__ = 0;
          $135 = (invoke_ii(3215,($134|0))|0);
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           label = 36;
           break L25;
          } else {
           $temp$0$i = $135;
          }
         }
         $$0$i = $temp$0$i;
        }
        $138 = HEAP32[$87>>2]|0;
        $139 = (($138) + 52|0);
        $140 = HEAP32[$139>>2]|0;
        __THREW__ = 0;
        $141 = (invoke_ii($140|0,($87|0))|0);
        $142 = __THREW__; __THREW__ = 0;
        $143 = $142&1;
        if ($143) {
         label = 36;
         break L25;
        }
        $144 = HEAP32[$95>>2]|0;
        __THREW__ = 0;
        invoke_viiiifiii(1,($renderObjects|0),($$0$i|0),($shaderReplace|0),($i$015|0),(+$85),($mi$011|0),($141|0),($144|0));
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 36;
         break L25;
        }
        $147 = (($mi$011) + 1)|0;
        $148 = ($147|0)<($91|0);
        if ($148) {
         $mi$011 = $147;
        } else {
         break;
        }
       }
      }
      $166 = (($i$015) + 128|0);
      $167 = HEAP32[$contents>>2]|0;
      $168 = HEAP32[$44>>2]|0;
      $169 = (($167) + ($168<<7)|0);
      $170 = ($166|0)==($169|0);
      if ($170) {
       break L23;
      } else {
       $i$015 = $166;
      }
     }
     if ((label|0) == 36) {
      $149 = ___cxa_find_matching_catch()|0;
      $150 = tempRet0;
      $lpad$phi$index = $149;$lpad$phi$index3 = $150;
      break L21;
     }
     else if ((label|0) == 37) {
      $151 = ___cxa_find_matching_catch()|0;
      $152 = tempRet0;
      $lpad$phi$index = $151;$lpad$phi$index3 = $152;
      break L21;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_viiii(342,($curCameraMatrix|0),($renderObjects|0),($disableDynamicBatching|0),($passContext|0));
   $171 = __THREW__; __THREW__ = 0;
   $172 = $171&1;
   if ($172) {
    label = 38;
   } else {
    $173 = HEAP32[$renderObjects>>2]|0;
    $174 = ($173|0)==(0|0);
    if ($174) {
     STACKTOP = sp;return;
    }
    $175 = HEAP32[$42>>2]|0;
    $176 = ($175|0)==($173|0);
    if (!($176)) {
     $__new_last2$i$i$i$i$i = $173;
     $scevgep$i$i$i$i$i = (($175) + -32|0);
     $177 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($177)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $178 = $uglygep3$i$i$i$i$i >>> 5;
     $179 = $178 ^ -1;
     $scevgep4$i$i$i$i$i = (($175) + ($179<<5)|0);
     HEAP32[$42>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($173|0),($$byval_copy10|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if ($181) {
     $182 = ___cxa_find_matching_catch()|0;
     $183 = tempRet0;
     ___cxa_call_unexpected(($182|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 38) {
  $153 = ___cxa_find_matching_catch()|0;
  $154 = tempRet0;
  $lpad$phi$index = $153;$lpad$phi$index3 = $154;
 }
 $155 = HEAP32[$renderObjects>>2]|0;
 $156 = ($155|0)==(0|0);
 if ($156) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $157 = HEAP32[$42>>2]|0;
 $158 = ($157|0)==($155|0);
 if (!($158)) {
  $__new_last2$i$i$i$i$i2 = $155;
  $scevgep$i$i$i$i$i3 = (($157) + -32|0);
  $159 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($159)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $160 = $uglygep3$i$i$i$i$i6 >>> 5;
  $161 = $160 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($157) + ($161<<5)|0);
  HEAP32[$42>>2] = $scevgep4$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($155|0),($$byval_copy10|0));
 $162 = __THREW__; __THREW__ = 0;
 $163 = $162&1;
 if ($163) {
  $164 = ___cxa_find_matching_catch()|0;
  $165 = tempRet0;
  ___cxa_call_unexpected(($164|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZL18AddDepthPassObjectRNSt3__16vectorI17RODataReplacement13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEEPN5Unity8MaterialERK17ShaderReplaceDataPK11VisibleNodefii18GlobalLayeringData($renderObjects,$mat,$shaderReplace,$visibleNode,$distanceForSort,$materialIndex,$staticBatchIndex,$globalLayeringData$0) {
 $renderObjects = $renderObjects|0;
 $mat = $mat|0;
 $shaderReplace = $shaderReplace|0;
 $visibleNode = $visibleNode|0;
 $distanceForSort = Math_fround($distanceForSort);
 $materialIndex = $materialIndex|0;
 $staticBatchIndex = $staticBatchIndex|0;
 $globalLayeringData$0 = $globalLayeringData$0|0;
 var $$ = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $passIndex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $passIndex = sp + 32|0;
 $0 = sp;
 $1 = ($mat|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (__ZNK5Unity8Material20GetActualRenderQueueEv($mat)|0);
 $3 = ($2|0)>(2500);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__ZN5Unity8Material9GetShaderEv($mat)|0);
 $5 = HEAP32[$shaderReplace>>2]|0;
 $6 = (($shaderReplace) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z28CalculateSubShaderIndexToUseP6ShaderS0_i($4,$5,$7)|0);
 $9 = ($8|0)<(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$shaderReplace>>2]|0;
 $11 = ($10|0)==(0|0);
 $$ = $11 ? $4 : $10;
 $12 = (__ZN6Shader24GetShadowCasterPassToUseEiRi($$,$8,$passIndex)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
 $14 = (($0) + 24|0);
 HEAP32[$14>>2] = -2147450880;
 $15 = (($renderObjects) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($renderObjects) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16|0)==($18|0);
 if ($19) {
  __ZNSt3__16vectorI17RODataReplacement13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($renderObjects,$0);
  $$pre = HEAP32[$15>>2]|0;
  $24 = $$pre;
 } else {
  $20 = ($16|0)==(0|0);
  if ($20) {
   $22 = 0;
  } else {
   ;HEAP32[$16+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$16+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$16+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$16+24>>2]=HEAP32[$0+24>>2]|0;HEAP32[$16+28>>2]=HEAP32[$0+28>>2]|0;
   $$pre$i = HEAP32[$15>>2]|0;
   $22 = $$pre$i;
  }
  $21 = (($22) + 32|0);
  HEAP32[$15>>2] = $21;
  $24 = $21;
 }
 $23 = (($24) + -20|0);
 HEAP32[$23>>2] = $visibleNode;
 $25 = (($mat) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (HEAPF32[tempDoublePtr>>2]=$distanceForSort,HEAP32[tempDoublePtr>>2]|0);
 $28 = $27 >>> 22;
 $29 = $8 << 27;
 $30 = $staticBatchIndex << 19;
 $31 = $30 & 133693440;
 $32 = $28 << 9;
 $33 = $26 << 3;
 $34 = $33 & 496;
 $35 = $31 | $32;
 $36 = $35 | $29;
 $37 = $36 | $34;
 $38 = (($24) + -32|0);
 HEAP32[$38>>2] = $37;
 $39 = (($24) + -24|0);
 HEAP32[$39>>2] = $mat;
 $40 = (($24) + -12|0);
 HEAP32[$40>>2] = $materialIndex;
 $41 = (($24) + -16|0);
 HEAP32[$41>>2] = $$;
 $42 = (($24) + -28|0);
 HEAP32[$42>>2] = $8;
 $43 = (($24) + -8|0);
 HEAP32[$43>>2] = $globalLayeringData$0;
 STACKTOP = sp;return;
}
function __ZL25PerformRenderingDepthPassR6CameraRK10Matrix4x4fRNSt3__16vectorI17RODataReplacement13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEEEbRN9ShaderLab17ShaderPassContextE($curCameraMatrix,$renderData,$disableDynamicBatching,$passContext) {
 $curCameraMatrix = $curCameraMatrix|0;
 $renderData = $renderData|0;
 $disableDynamicBatching = $disableDynamicBatching|0;
 $passContext = $passContext|0;
 var $$pre = 0, $$sink$i$i$i$i = Math_fround(0), $$sink$i1$i$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0);
 var $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $batchRenderer = 0, $channels$016 = 0, $channels$1 = 0, $i$015 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond13 = 0, $or$cond14 = 0;
 var $phitmp$i = 0, $phitmp$i$old = 0, $stats = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp;
 $stats = sp + 80|0;
 $batchRenderer = sp + 4|0;
 $1 = HEAP32[$renderData>>2]|0;
 $2 = (($renderData) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__sortIR17ROSorterDepthPassP17RODataReplacementEEvT0_S5_T_($1,$3,$0);
 __ZN13BatchRendererC2ER15RenderLoopStats($batchRenderer,$stats);
 __THREW__ = 0;
 $4 = (invoke_i(59)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 24;
  } else {
   $7 = HEAP32[$4>>2]|0;
   $8 = (($7) + 100|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vii($9|0,($4|0),($curCameraMatrix|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 24;
   } else {
    $12 = (($4) + 788|0);
    ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
    __THREW__ = 0;
    invoke_viiiii(88,($passContext|0),1,1,0,1);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 24;
    } else {
     $15 = HEAP32[$2>>2]|0;
     $16 = HEAP32[$renderData>>2]|0;
     $17 = $15;
     $18 = $16;
     $19 = (($17) - ($18))|0;
     $20 = $19 >> 5;
     $21 = ($20|0)==(0);
     L5: do {
      if (!($21)) {
       $23 = $16;$48 = 0;$50 = 0;$52 = -1;$54 = -1;$61 = Math_fround(0.0);$74 = 0;$channels$016 = 0;$i$015 = 0;
       L6: while(1) {
        $22 = ((($23) + ($i$015<<5)|0) + 12|0);
        $24 = HEAP32[$22>>2]|0;
        $25 = (($24) + 116|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = (($24) + 120|0);
        $28 = Math_fround(HEAPF32[$27>>2]);
        $29 = ((($23) + ($i$015<<5)|0) + 8|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = ((($23) + ($i$015<<5)|0) + 16|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = ((($23) + ($i$015<<5)|0) + 4|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = (($26) + 168|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = ($36|0)==(0|0);
        if ($37) {
         $73 = 0;
        } else {
         $38 = (($36) + 32|0);
         $39 = HEAP32[$38>>2]|0;
         $73 = $39;
        }
        if ($disableDynamicBatching) {
         $40 = HEAP32[$26>>2]|0;
         $41 = (($40) + 52|0);
         $42 = HEAP32[$41>>2]|0;
         __THREW__ = 0;
         $43 = (invoke_ii($42|0,($26|0))|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break;
         }
         $46 = ($43|0)==(0);
         $120 = $46;
        } else {
         $120 = 0;
        }
        $47 = ($30|0)==($48|0);
        $49 = ($32|0)==($50|0);
        $or$cond = $47 & $49;
        $51 = ($34|0)==($52|0);
        $or$cond11 = $or$cond & $51;
        $53 = ($54|0)==(0);
        $or$cond12 = $or$cond11 & $53;
        do {
         if ($or$cond12) {
          $55 = $28 > Math_fround(0.0);
          $56 = $55&1;
          $57 = $28 < Math_fround(0.0);
          $58 = $57&1;
          $59 = (($56) - ($58))|0;
          $60 = $61 > Math_fround(0.0);
          $62 = $60&1;
          $63 = $61 < Math_fround(0.0);
          $64 = $63&1;
          $65 = (($62) - ($64))|0;
          $66 = ($59|0)==($65|0);
          if ($66) {
           $67 = ($59|0)<(0);
           if ($67) {
            $68 = Math_fround($28 - $61);
            $69 = $68 < Math_fround(0.0);
            if ($69) {
             $70 = Math_fround(-$68);
             $72 = $70;
            } else {
             $72 = $68;
            }
            $71 = !($72 <= Math_fround(9.99999997475242707878E-7));
            $phitmp$i = ($73|0)!=($74|0);
            $or$cond13 = $71 | $phitmp$i;
            if ($or$cond13) {
             label = 21;
             break;
            }
           } else {
            $75 = Math_fround($28 * Math_fround(16.0));
            $76 = !($75 >= Math_fround(0.0));
            if ($76) {
             $77 = Math_fround($75 + Math_fround(-0.999999940395355224609));
             $$sink$i1$i$i$i = $77;
            } else {
             $$sink$i1$i$i$i = $75;
            }
            $78 = (~~(($$sink$i1$i$i$i)));
            $79 = Math_fround($61 * Math_fround(16.0));
            $80 = !($79 >= Math_fround(0.0));
            if ($80) {
             $81 = Math_fround($79 + Math_fround(-0.999999940395355224609));
             $$sink$i$i$i$i = $81;
            } else {
             $$sink$i$i$i$i = $79;
            }
            $82 = (~~(($$sink$i$i$i$i)));
            $83 = ($78|0)!=($82|0);
            $phitmp$i$old = ($73|0)!=($74|0);
            $or$cond14 = $83 | $phitmp$i$old;
            if ($or$cond14) {
             label = 21;
             break;
            }
           }
           if ($120) {
            __THREW__ = 0;
            invoke_vi(3398,($batchRenderer|0));
            $95 = __THREW__; __THREW__ = 0;
            $96 = $95&1;
            if ($96) {
             break L6;
            } else {
             $121 = $74;$122 = $52;$123 = $50;$124 = $48;$125 = $61;$channels$1 = $channels$016;
            }
           } else {
            $121 = $74;$122 = $52;$123 = $50;$124 = $48;$125 = $61;$channels$1 = $channels$016;
           }
          } else {
           label = 21;
          }
         } else {
          label = 21;
         }
        } while(0);
        if ((label|0) == 21) {
         label = 0;
         __THREW__ = 0;
         invoke_vi(3398,($batchRenderer|0));
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          break;
         }
         $86 = Math_fround(HEAPF32[$27>>2]);
         __THREW__ = 0;
         invoke_viif(41,($4|0),($passContext|0),(+$86));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          break;
         }
         $97 = HEAP32[$29>>2]|0;
         $98 = HEAP32[$31>>2]|0;
         $99 = HEAP32[$33>>2]|0;
         __THREW__ = 0;
         $100 = (invoke_iiiii(233,($97|0),($98|0),($passContext|0),($99|0))|0);
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          break;
         } else {
          $121 = $73;$122 = $34;$123 = $32;$124 = $30;$125 = $28;$channels$1 = $100;
         }
        }
        $103 = ($channels$1|0)==(0|0);
        if (!($103)) {
         $104 = HEAP32[$26>>2]|0;
         $105 = (($104) + 48|0);
         $106 = HEAP32[$105>>2]|0;
         $107 = ((($23) + ($i$015<<5)|0) + 20|0);
         $108 = HEAP32[$107>>2]|0;
         __THREW__ = 0;
         $109 = (invoke_iii($106|0,($26|0),($108|0))|0);
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         if ($111) {
          break;
         }
         __THREW__ = 0;
         invoke_viiiii(90,($batchRenderer|0),($26|0),($24|0),($109|0),($channels$1|0));
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if ($113) {
          break;
         }
        }
        $114 = (($i$015) + 1)|0;
        $115 = ($114>>>0)<($20>>>0);
        if (!($115)) {
         break L5;
        }
        $$pre = HEAP32[$renderData>>2]|0;
        $23 = $$pre;$48 = $124;$50 = $123;$52 = $122;$54 = 0;$61 = $125;$74 = $121;$channels$016 = $channels$1;$i$015 = $114;
       }
       $89 = ___cxa_find_matching_catch()|0;
       $90 = tempRet0;
       $lpad$phi$index = $89;$lpad$phi$index2 = $90;
       break L1;
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3398,($batchRenderer|0));
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      label = 24;
     } else {
      __ZN13BatchRendererD1Ev($batchRenderer);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  $lpad$phi$index = $91;$lpad$phi$index2 = $92;
 }
 __THREW__ = 0;
 invoke_vi(3399,($batchRenderer|0));
 $93 = __THREW__; __THREW__ = 0;
 $94 = $93&1;
 if ($94) {
  $118 = ___cxa_find_matching_catch(0|0)|0;
  $119 = tempRet0;
  ___clang_call_terminate($118);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z20RenderSceneDepthPassR13dynamic_arrayI16RenderObjectDataLj4EERK17ShaderReplaceDatabRN9ShaderLab17ShaderPassContextE($contents,$shaderReplace,$disableDynamicBatching,$passContext) {
 $contents = $contents|0;
 $shaderReplace = $shaderReplace|0;
 $disableDynamicBatching = $disableDynamicBatching|0;
 $passContext = $passContext|0;
 var $$0$i = 0, $$byval_copy8 = 0, $$pr = 0, $$pre$i = 0, $$pre1$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $curCameraMatrix = 0, $i$011 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp = 0, $renderObjects = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $temp$0$i = 0, $temp$0$i$i = 0, $uglygep$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy8 = sp + 104|0;
 $0 = sp + 100|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 88|0;
 $4 = sp + 80|0;
 $curCameraMatrix = sp + 16|0;
 $renderObjects = sp;
 $5 = sp + 84|0;
 $6 = (__Z16GetRenderManagerv()|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$4>>2] = $7;
 $8 = HEAP32[560624>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = (($8) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($8) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  do {
   if ($14) {
    $15 = (($8) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($8) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + ($18<<3)|0);
    $35 = $19;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy8,$8,$4);
    $20 = HEAP32[$$byval_copy8>>2]|0;
    $21 = ($20|0)==(-1);
    $22 = (($8) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    if ($21) {
     $24 = (($8) + 32|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($23) + ($25<<3)|0);
     $35 = $26;
     break;
    } else {
     $27 = (($23) + ($20<<3)|0);
     $35 = $27;
     break;
    }
   }
  } while(0);
  $28 = HEAP32[560624>>2]|0;
  $29 = (($28) + 28|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 32|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + ($32<<3)|0);
  $34 = ($35|0)==($33|0);
  if ($34) {
   label = 9;
  } else {
   $36 = (($35) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    label = 9;
   } else {
    $temp$0$i$i = $37;
   }
  }
 }
 if ((label|0) == 9) {
  $39 = HEAP32[$6>>2]|0;
  $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
  $temp$0$i$i = $40;
 }
 $41 = (__ZNK6Camera22GetWorldToCameraMatrixEv($temp$0$i$i)|0);
 dest=$curCameraMatrix+0|0; src=$41+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$renderObjects>>2] = 0;
 $42 = (($renderObjects) + 4|0);
 HEAP32[$42>>2] = 0;
 $43 = (($renderObjects) + 8|0);
 HEAP32[$43>>2] = 0;
 $44 = (($contents) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45 >>> 1;
 $47 = ($46|0)==(0);
 if ($47) {
  $64 = $45;
  label = 16;
 } else {
  $48 = $46 << 5;
  HEAP32[$2>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
  $49 = (invoke_iiiiiii(102,($48|0),16,($$byval_copy8|0),0,(569272|0),79)|0);
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   label = 33;
  } else {
   $$pre$i = HEAP32[$renderObjects>>2]|0;
   $$pre1$i = HEAP32[$42>>2]|0;
   $phitmp = $$pre1$i;
   $52 = (($49) + ($46<<5)|0);
   $53 = $$pre$i;
   $54 = (($phitmp) - ($53))|0;
   $55 = $54 >> 5;
   $$sum$i = (0 - ($55))|0;
   $56 = (($49) + ($$sum$i<<5)|0);
   _memcpy(($56|0),($$pre$i|0),($54|0))|0;
   $57 = HEAP32[$renderObjects>>2]|0;
   HEAP32[$renderObjects>>2] = $56;
   HEAP32[$42>>2] = $49;
   HEAP32[$43>>2] = $52;
   $58 = ($57|0)==(0|0);
   if (!($58)) {
    HEAP32[$3>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy8|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     $61 = ___cxa_find_matching_catch()|0;
     $62 = tempRet0;
     ___cxa_call_unexpected(($61|0));
     // unreachable;
    }
   }
   $$pr = HEAP32[$44>>2]|0;
   $64 = $$pr;
   label = 16;
  }
 }
 L21: do {
  if ((label|0) == 16) {
   $63 = ($64|0)==(0);
   L23: do {
    if (!($63)) {
     $65 = HEAP32[$contents>>2]|0;
     $i$011 = $65;
     while(1) {
      $66 = (($i$011) + 32|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 116|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = HEAP32[$69>>2]|0;
      $71 = (($70) + 44|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($i$011) + 10|0);
      $74 = HEAP16[$73>>1]|0;
      $75 = $74&65535;
      __THREW__ = 0;
      invoke_viii($72|0,($5|0),($69|0),($75|0));
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      $78 = HEAP32[$5>>2]|0;
      $79 = ($78|0)==(0);
      if ($79) {
       $$0$i = 0;
      } else {
       HEAP32[$1>>2] = $78;
       $80 = HEAP32[560624>>2]|0;
       $81 = ($80|0)==(0|0);
       if ($81) {
        label = 28;
       } else {
        $82 = (($80) + 36|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = (($80) + 4|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = ($83|0)==($85|0);
        do {
         if ($86) {
          $87 = (($80) + 28|0);
          $88 = HEAP32[$87>>2]|0;
          $89 = (($80) + 32|0);
          $90 = HEAP32[$89>>2]|0;
          $91 = (($88) + ($90<<3)|0);
          $107 = $91;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy8,$80,$1);
          $92 = HEAP32[$$byval_copy8>>2]|0;
          $93 = ($92|0)==(-1);
          $94 = (($80) + 28|0);
          $95 = HEAP32[$94>>2]|0;
          if ($93) {
           $96 = (($80) + 32|0);
           $97 = HEAP32[$96>>2]|0;
           $98 = (($95) + ($97<<3)|0);
           $107 = $98;
           break;
          } else {
           $99 = (($95) + ($92<<3)|0);
           $107 = $99;
           break;
          }
         }
        } while(0);
        $100 = HEAP32[560624>>2]|0;
        $101 = (($100) + 28|0);
        $102 = HEAP32[$101>>2]|0;
        $103 = (($100) + 32|0);
        $104 = HEAP32[$103>>2]|0;
        $105 = (($102) + ($104<<3)|0);
        $106 = ($107|0)==($105|0);
        if ($106) {
         label = 28;
        } else {
         $108 = (($107) + 4|0);
         $109 = HEAP32[$108>>2]|0;
         $110 = ($109|0)==(0|0);
         if ($110) {
          label = 28;
         } else {
          $temp$0$i = $109;
         }
        }
       }
       if ((label|0) == 28) {
        label = 0;
        $111 = HEAP32[$5>>2]|0;
        __THREW__ = 0;
        $112 = (invoke_ii(3215,($111|0))|0);
        $113 = __THREW__; __THREW__ = 0;
        $114 = $113&1;
        if ($114) {
         break;
        } else {
         $temp$0$i = $112;
        }
       }
       $$0$i = $temp$0$i;
      }
      $115 = HEAP32[$66>>2]|0;
      $116 = (($i$011) + 24|0);
      $117 = Math_fround(HEAPF32[$116>>2]);
      $118 = HEAP16[$73>>1]|0;
      $119 = $118&65535;
      $120 = (($i$011) + 20|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = (($69) + 172|0);
      $123 = HEAP32[$122>>2]|0;
      __THREW__ = 0;
      invoke_viiiifiii(1,($renderObjects|0),($$0$i|0),($shaderReplace|0),($115|0),(+$117),($119|0),($121|0),($123|0));
      $124 = __THREW__; __THREW__ = 0;
      $125 = $124&1;
      if ($125) {
       break;
      }
      $126 = (($i$011) + 44|0);
      $127 = HEAP32[$contents>>2]|0;
      $128 = HEAP32[$44>>2]|0;
      $129 = (($127) + (($128*44)|0)|0);
      $130 = ($126|0)==($129|0);
      if ($130) {
       break L23;
      } else {
       $i$011 = $126;
      }
     }
     $131 = ___cxa_find_matching_catch()|0;
     $132 = tempRet0;
     $lpad$phi$index = $131;$lpad$phi$index2 = $132;
     break L21;
    }
   } while(0);
   __THREW__ = 0;
   invoke_viiii(342,($curCameraMatrix|0),($renderObjects|0),($disableDynamicBatching|0),($passContext|0));
   $146 = __THREW__; __THREW__ = 0;
   $147 = $146&1;
   if ($147) {
    label = 33;
   } else {
    $148 = HEAP32[$renderObjects>>2]|0;
    $149 = ($148|0)==(0|0);
    if ($149) {
     STACKTOP = sp;return;
    }
    $150 = HEAP32[$42>>2]|0;
    $151 = ($150|0)==($148|0);
    if (!($151)) {
     $__new_last2$i$i$i$i$i = $148;
     $scevgep$i$i$i$i$i = (($150) + -32|0);
     $152 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($152)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $153 = $uglygep3$i$i$i$i$i >>> 5;
     $154 = $153 ^ -1;
     $scevgep4$i$i$i$i$i = (($150) + ($154<<5)|0);
     HEAP32[$42>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($148|0),($$byval_copy8|0));
    $155 = __THREW__; __THREW__ = 0;
    $156 = $155&1;
    if ($156) {
     $157 = ___cxa_find_matching_catch()|0;
     $158 = tempRet0;
     ___cxa_call_unexpected(($157|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 33) {
  $133 = ___cxa_find_matching_catch()|0;
  $134 = tempRet0;
  $lpad$phi$index = $133;$lpad$phi$index2 = $134;
 }
 $135 = HEAP32[$renderObjects>>2]|0;
 $136 = ($135|0)==(0|0);
 if ($136) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $137 = HEAP32[$42>>2]|0;
 $138 = ($137|0)==($135|0);
 if (!($138)) {
  $__new_last2$i$i$i$i$i2 = $135;
  $scevgep$i$i$i$i$i3 = (($137) + -32|0);
  $139 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($139)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $140 = $uglygep3$i$i$i$i$i6 >>> 5;
  $141 = $140 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($137) + ($141<<5)|0);
  HEAP32[$42>>2] = $scevgep4$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($135|0),($$byval_copy8|0));
 $142 = __THREW__; __THREW__ = 0;
 $143 = $142&1;
 if ($143) {
  $144 = ___cxa_find_matching_catch()|0;
  $145 = tempRet0;
  ___cxa_call_unexpected(($144|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z28RenderSceneShaderReplacementRK13dynamic_arrayI16RenderObjectDataLj4EEP6ShaderRKNSt3__112basic_stringIcNS6_11char_traitsIcEENS6_9allocatorIcEEEERN9ShaderLab17ShaderPassContextE($contents,$replacementShader,$replacementTag,$passContext) {
 $contents = $contents|0;
 $replacementShader = $replacementShader|0;
 $replacementTag = $replacementTag|0;
 $passContext = $passContext|0;
 var $$0$i = 0, $$byval_copy8 = 0, $$pr = 0, $$pre$i = 0, $$pre1$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $curCameraMatrix = 0, $i$011 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp = 0, $renderObjects = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $temp$0$i = 0, $temp$0$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy8 = sp + 104|0;
 $0 = sp + 100|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 88|0;
 $4 = sp + 80|0;
 $curCameraMatrix = sp + 16|0;
 $renderObjects = sp;
 $5 = sp + 84|0;
 $6 = HEAP8[$replacementTag>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $11 = $6&255;
  $12 = $11 >>> 1;
  $14 = $12;
 } else {
  $9 = (($replacementTag) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $14 = $10;
 }
 $13 = ($14|0)==(0);
 if ($13) {
  $140 = -1;
 } else {
  $15 = (__ZN9ShaderLab14GetShaderTagIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($replacementTag)|0);
  $140 = $15;
 }
 $16 = (__Z16GetRenderManagerv()|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$4>>2] = $17;
 $18 = HEAP32[560624>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  label = 14;
 } else {
  $20 = (($18) + 36|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($18) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($21|0)==($23|0);
  do {
   if ($24) {
    $25 = (($18) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($18) + 32|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + ($28<<3)|0);
    $45 = $29;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy8,$18,$4);
    $30 = HEAP32[$$byval_copy8>>2]|0;
    $31 = ($30|0)==(-1);
    $32 = (($18) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    if ($31) {
     $34 = (($18) + 32|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($33) + ($35<<3)|0);
     $45 = $36;
     break;
    } else {
     $37 = (($33) + ($30<<3)|0);
     $45 = $37;
     break;
    }
   }
  } while(0);
  $38 = HEAP32[560624>>2]|0;
  $39 = (($38) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 32|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + ($42<<3)|0);
  $44 = ($45|0)==($43|0);
  if ($44) {
   label = 14;
  } else {
   $46 = (($45) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    label = 14;
   } else {
    $temp$0$i$i = $47;
   }
  }
 }
 if ((label|0) == 14) {
  $49 = HEAP32[$16>>2]|0;
  $50 = (__Z31ReadObjectFromPersistentManageri($49)|0);
  $temp$0$i$i = $50;
 }
 $51 = (__ZNK6Camera22GetWorldToCameraMatrixEv($temp$0$i$i)|0);
 dest=$curCameraMatrix+0|0; src=$51+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$renderObjects>>2] = 0;
 $52 = (($renderObjects) + 4|0);
 HEAP32[$52>>2] = 0;
 $53 = (($renderObjects) + 8|0);
 HEAP32[$53>>2] = 0;
 $54 = (($contents) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 >>> 2;
 $57 = ($56|0)==(0);
 if ($57) {
  $74 = $55;
  label = 21;
 } else {
  $58 = $56 << 5;
  HEAP32[$2>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
  $59 = (invoke_iiiiiii(102,($58|0),16,($$byval_copy8|0),0,(569272|0),79)|0);
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if ($61) {
   label = 39;
  } else {
   $$pre$i = HEAP32[$renderObjects>>2]|0;
   $$pre1$i = HEAP32[$52>>2]|0;
   $phitmp = $$pre1$i;
   $62 = (($59) + ($56<<5)|0);
   $63 = $$pre$i;
   $64 = (($phitmp) - ($63))|0;
   $65 = $64 >> 5;
   $$sum$i = (0 - ($65))|0;
   $66 = (($59) + ($$sum$i<<5)|0);
   _memcpy(($66|0),($$pre$i|0),($64|0))|0;
   $67 = HEAP32[$renderObjects>>2]|0;
   HEAP32[$renderObjects>>2] = $66;
   HEAP32[$52>>2] = $59;
   HEAP32[$53>>2] = $62;
   $68 = ($67|0)==(0|0);
   if (!($68)) {
    HEAP32[$3>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($67|0),($$byval_copy8|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     $71 = ___cxa_find_matching_catch()|0;
     $72 = tempRet0;
     ___cxa_call_unexpected(($71|0));
     // unreachable;
    }
   }
   $$pr = HEAP32[$54>>2]|0;
   $74 = $$pr;
   label = 21;
  }
 }
 L28: do {
  if ((label|0) == 21) {
   $73 = ($74|0)==(0);
   L30: do {
    if (!($73)) {
     $75 = HEAP32[$contents>>2]|0;
     $i$011 = $75;
     while(1) {
      $76 = (($i$011) + 32|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($77) + 116|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 44|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($i$011) + 10|0);
      $84 = HEAP16[$83>>1]|0;
      $85 = $84&65535;
      __THREW__ = 0;
      invoke_viii($82|0,($5|0),($79|0),($85|0));
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       break;
      }
      $88 = HEAP32[$5>>2]|0;
      $89 = ($88|0)==(0);
      if ($89) {
       $$0$i = 0;
      } else {
       HEAP32[$1>>2] = $88;
       $90 = HEAP32[560624>>2]|0;
       $91 = ($90|0)==(0|0);
       if ($91) {
        label = 33;
       } else {
        $92 = (($90) + 36|0);
        $93 = HEAP32[$92>>2]|0;
        $94 = (($90) + 4|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = ($93|0)==($95|0);
        do {
         if ($96) {
          $97 = (($90) + 28|0);
          $98 = HEAP32[$97>>2]|0;
          $99 = (($90) + 32|0);
          $100 = HEAP32[$99>>2]|0;
          $101 = (($98) + ($100<<3)|0);
          $117 = $101;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy8,$90,$1);
          $102 = HEAP32[$$byval_copy8>>2]|0;
          $103 = ($102|0)==(-1);
          $104 = (($90) + 28|0);
          $105 = HEAP32[$104>>2]|0;
          if ($103) {
           $106 = (($90) + 32|0);
           $107 = HEAP32[$106>>2]|0;
           $108 = (($105) + ($107<<3)|0);
           $117 = $108;
           break;
          } else {
           $109 = (($105) + ($102<<3)|0);
           $117 = $109;
           break;
          }
         }
        } while(0);
        $110 = HEAP32[560624>>2]|0;
        $111 = (($110) + 28|0);
        $112 = HEAP32[$111>>2]|0;
        $113 = (($110) + 32|0);
        $114 = HEAP32[$113>>2]|0;
        $115 = (($112) + ($114<<3)|0);
        $116 = ($117|0)==($115|0);
        if ($116) {
         label = 33;
        } else {
         $118 = (($117) + 4|0);
         $119 = HEAP32[$118>>2]|0;
         $120 = ($119|0)==(0|0);
         if ($120) {
          label = 33;
         } else {
          $temp$0$i = $119;
         }
        }
       }
       if ((label|0) == 33) {
        label = 0;
        $121 = HEAP32[$5>>2]|0;
        __THREW__ = 0;
        $122 = (invoke_ii(3215,($121|0))|0);
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if ($124) {
         break;
        } else {
         $temp$0$i = $122;
        }
       }
       $$0$i = $temp$0$i;
      }
      $125 = HEAP32[$76>>2]|0;
      $126 = (($i$011) + 24|0);
      $127 = Math_fround(HEAPF32[$126>>2]);
      $128 = HEAP16[$83>>1]|0;
      $129 = (($i$011) + 20|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = (($79) + 172|0);
      $132 = HEAP32[$131>>2]|0;
      $133 = HEAP32[$79>>2]|0;
      $134 = (($133) + 60|0);
      $135 = HEAP32[$134>>2]|0;
      __THREW__ = 0;
      $136 = (invoke_ii($135|0,($79|0))|0);
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break;
      }
      $139 = $128&65535;
      __THREW__ = 0;
      invoke_viiiiifiiii(1,($renderObjects|0),($$0$i|0),($replacementShader|0),($140|0),($125|0),(+$127),($139|0),($130|0),($132|0),($136|0));
      $141 = __THREW__; __THREW__ = 0;
      $142 = $141&1;
      if ($142) {
       break;
      }
      $143 = (($i$011) + 44|0);
      $144 = HEAP32[$contents>>2]|0;
      $145 = HEAP32[$54>>2]|0;
      $146 = (($144) + (($145*44)|0)|0);
      $147 = ($143|0)==($146|0);
      if ($147) {
       break L30;
      } else {
       $i$011 = $143;
      }
     }
     $148 = ___cxa_find_matching_catch()|0;
     $149 = tempRet0;
     $lpad$phi$index = $148;$lpad$phi$index2 = $149;
     break L28;
    }
   } while(0);
   __THREW__ = 0;
   invoke_viii(1669,($curCameraMatrix|0),($renderObjects|0),($passContext|0));
   $163 = __THREW__; __THREW__ = 0;
   $164 = $163&1;
   if ($164) {
    label = 39;
   } else {
    $165 = HEAP32[$renderObjects>>2]|0;
    $166 = ($165|0)==(0|0);
    if ($166) {
     STACKTOP = sp;return;
    }
    $167 = HEAP32[$52>>2]|0;
    $168 = ($167|0)==($165|0);
    if (!($168)) {
     $__new_last2$i$i$i$i$i = $165;
     $scevgep$i$i$i$i$i = (($167) + -32|0);
     $169 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($169)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $170 = $uglygep3$i$i$i$i$i >>> 5;
     $171 = $170 ^ -1;
     $scevgep4$i$i$i$i$i = (($167) + ($171<<5)|0);
     HEAP32[$52>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($165|0),($$byval_copy8|0));
    $172 = __THREW__; __THREW__ = 0;
    $173 = $172&1;
    if ($173) {
     $174 = ___cxa_find_matching_catch()|0;
     $175 = tempRet0;
     ___cxa_call_unexpected(($174|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 39) {
  $150 = ___cxa_find_matching_catch()|0;
  $151 = tempRet0;
  $lpad$phi$index = $150;$lpad$phi$index2 = $151;
 }
 $152 = HEAP32[$renderObjects>>2]|0;
 $153 = ($152|0)==(0|0);
 if ($153) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $154 = HEAP32[$52>>2]|0;
 $155 = ($154|0)==($152|0);
 if (!($155)) {
  $__new_last2$i$i$i$i$i2 = $152;
  $scevgep$i$i$i$i$i3 = (($154) + -32|0);
  $156 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($156)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $157 = $uglygep3$i$i$i$i$i6 >>> 5;
  $158 = $157 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($154) + ($158<<5)|0);
  HEAP32[$52>>2] = $scevgep4$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($152|0),($$byval_copy8|0));
 $159 = __THREW__; __THREW__ = 0;
 $160 = $159&1;
 if ($160) {
  $161 = ___cxa_find_matching_catch()|0;
  $162 = tempRet0;
  ___cxa_call_unexpected(($161|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZNSt3__16__sortIR17ROSorterDepthPassP17RODataReplacementEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$027 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0;
 var $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i23 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -32|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 5;
   switch ($4|0) {
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 71;
    break L1;
    break;
   }
   default: {
   }
   }
   $37 = ($3|0)<(992);
   if ($37) {
    label = 21;
    break L1;
   }
   $38 = ($3|0)>(31968);
   $39 = (($4|0) / 2)&-1;
   $40 = (($$0) + ($39<<5)|0);
   do {
    if ($38) {
     $41 = (($4|0) / 4)&-1;
     $42 = (($$0) + ($41<<5)|0);
     $$sum = (($41) + ($39))|0;
     $43 = (($$0) + ($$sum<<5)|0);
     $44 = (__ZNSt3__17__sort4IR17ROSorterDepthPassP17RODataReplacementEEjT0_S5_S5_S5_T_($$0,$42,$40,$43,0)|0);
     $45 = HEAP32[$1>>2]|0;
     $46 = HEAP32[$43>>2]|0;
     $47 = ($45>>>0)<($46>>>0);
     if (!($47)) {
      $$pre$phiZ2D = $40;$__n_swaps$0 = $44;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$43+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$43+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$43+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$43+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$43+28>>2]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$43+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$43+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$43+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$43+28>>1]=HEAP16[$1+28>>1]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
     $48 = HEAP32[$43>>2]|0;
     $49 = HEAP32[$40>>2]|0;
     $50 = ($48>>>0)<($49>>>0);
     if (!($50)) {
      $51 = (($44) + 1)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $51;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$40+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$40+28>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$43+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$43+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$43+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$43+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$43+28>>1]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$43+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$43+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$43+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$43+28>>1]=HEAP16[$__t$i23+28>>1]|0;
     $52 = HEAP32[$40>>2]|0;
     $53 = HEAP32[$42>>2]|0;
     $54 = ($52>>>0)<($53>>>0);
     if (!($54)) {
      $55 = (($44) + 2)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $55;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$42+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$42+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$42+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$42+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$42+28>>2]|0;
     ;HEAP32[$42+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$42+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$42+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$42+24>>2]=HEAP32[$40+24>>2]|0;HEAP16[$42+28>>1]=HEAP16[$40+28>>1]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$__t$i23+28>>1]|0;
     $56 = HEAP32[$42>>2]|0;
     $57 = HEAP32[$$0>>2]|0;
     $58 = ($56>>>0)<($57>>>0);
     if ($58) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$42+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$42+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$42+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$42+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$42+28>>1]|0;
      ;HEAP32[$42+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$42+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$42+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$42+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$42+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $60 = (($44) + 4)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $60;
      break;
     } else {
      $59 = (($44) + 3)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $59;
      break;
     }
    } else {
     $61 = HEAP32[$40>>2]|0;
     $62 = HEAP32[$$0>>2]|0;
     $63 = ($61>>>0)<($62>>>0);
     $64 = HEAP32[$1>>2]|0;
     $65 = ($64>>>0)<($61>>>0);
     if (!($63)) {
      if (!($65)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 0;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$40+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$40+28>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$1+28>>1]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $66 = HEAP32[$40>>2]|0;
      $67 = HEAP32[$$0>>2]|0;
      $68 = ($66>>>0)<($67>>>0);
      if (!($68)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$40+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$40+28>>1]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
      break;
     }
     if ($65) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$1+28>>1]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
     ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$40+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$40+28>>1]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$__t$i23+28>>1]|0;
     $69 = HEAP32[$1>>2]|0;
     $70 = HEAP32[$40>>2]|0;
     $71 = ($69>>>0)<($70>>>0);
     if ($71) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$40+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$40+28>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$1+28>>1]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $72 = HEAP32[$$0>>2]|0;
   $73 = HEAP32[$$pre$phiZ2D>>2]|0;
   $74 = ($72>>>0)<($73>>>0);
   do {
    if ($74) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $75 = (($__j$0) + -32|0);
      $76 = ($$0|0)==($75|0);
      if ($76) {
       break;
      }
      $94 = HEAP32[$75>>2]|0;
      $95 = ($94>>>0)<($73>>>0);
      if ($95) {
       label = 54;
       break;
      } else {
       $__j$0 = $75;
      }
     }
     if ((label|0) == 54) {
      label = 0;
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$75+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$75+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$75+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$75+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$75+28>>1]|0;
      ;HEAP32[$75+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$75+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$75+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$75+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$75+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $96 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $75;$__n_swaps$3 = $96;
      break;
     }
     $77 = (($$0) + 32|0);
     $78 = HEAP32[$1>>2]|0;
     $79 = ($72>>>0)<($78>>>0);
     if ($79) {
      $__i$1 = $77;
     } else {
      $80 = ($77|0)==($1|0);
      if ($80) {
       label = 71;
       break L1;
      } else {
       $__i$027 = $77;
      }
      while(1) {
       $83 = HEAP32[$__i$027>>2]|0;
       $84 = ($72>>>0)<($83>>>0);
       $82 = (($__i$027) + 32|0);
       if ($84) {
        break;
       }
       $81 = ($82|0)==($1|0);
       if ($81) {
        label = 71;
        break L1;
       } else {
        $__i$027 = $82;
       }
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$027+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$027+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$027+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$027+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$__i$027+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$__i$027+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$__i$027+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$__i$027+28>>2]|0;
      ;HEAP32[$__i$027+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$027+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$027+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$027+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__i$027+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__i$027+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$__i$027+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$__i$027+28>>1]=HEAP16[$1+28>>1]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $__i$1 = $82;
     }
     $85 = ($__i$1|0)==($1|0);
     if ($85) {
      label = 71;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $86 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $87 = HEAP32[$__i$2>>2]|0;
       $88 = ($86>>>0)<($87>>>0);
       $89 = (($__i$2) + 32|0);
       if ($88) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $89;
       }
      }
      while(1) {
       $90 = (($__j$2) + -32|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($86>>>0)<($91>>>0);
       if ($92) {
        $__j$2 = $90;
       } else {
        break;
       }
      }
      $93 = ($__i$2>>>0)<($90>>>0);
      if (!($93)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$2+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$__i$2+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$__i$2+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$__i$2+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$__i$2+28>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$90+12>>2]|0;HEAP32[$__i$2+16>>2]=HEAP32[$90+16>>2]|0;HEAP32[$__i$2+20>>2]=HEAP32[$90+20>>2]|0;HEAP32[$__i$2+24>>2]=HEAP32[$90+24>>2]|0;HEAP16[$__i$2+28>>1]=HEAP16[$90+28>>1]|0;
      ;HEAP32[$90+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$90+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$90+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$90+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$90+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $__i$2$ph = $89;$__j$1$ph = $90;
     }
    }
   } while(0);
   $97 = (($$0) + 32|0);
   $98 = ($97>>>0)<($__j$3>>>0);
   L55: do {
    if ($98) {
     $__i$3$ph = $97;$__j$4$ph = $__j$3;$__m$0$ph = $40;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $99 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $100 = HEAP32[$__i$3>>2]|0;
       $101 = ($100>>>0)<($99>>>0);
       $102 = (($__i$3) + 32|0);
       if ($101) {
        $__i$3 = $102;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $103 = (($__j$5) + -32|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ($104>>>0)<($99>>>0);
       if ($105) {
        break;
       } else {
        $__j$5 = $103;
       }
      }
      $106 = ($__i$3>>>0)>($103>>>0);
      if ($106) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L55;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$3+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$__i$3+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$__i$3+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$__i$3+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$__i$3+28>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$103+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$103+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$103+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$103+12>>2]|0;HEAP32[$__i$3+16>>2]=HEAP32[$103+16>>2]|0;HEAP32[$__i$3+20>>2]=HEAP32[$103+20>>2]|0;HEAP32[$__i$3+24>>2]=HEAP32[$103+24>>2]|0;HEAP16[$__i$3+28>>1]=HEAP16[$103+28>>1]|0;
      ;HEAP32[$103+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$103+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$103+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$103+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$103+28>>1]=HEAP16[$__t$i23+28>>1]|0;
      $107 = (($__n_swaps$4$ph) + 1)|0;
      $108 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $108 ? $103 : $__m$0$ph;
      $__i$3$ph = $102;$__j$4$ph = $103;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $107;
     }
    } else {
     $__i$4 = $97;$__m$2 = $40;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $109 = ($__i$4|0)==($__m$2|0);
   if ($109) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $110 = HEAP32[$__m$2>>2]|0;
    $111 = HEAP32[$__i$4>>2]|0;
    $112 = ($110>>>0)<($111>>>0);
    if ($112) {
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$4+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$__i$4+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$__i$4+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$__i$4+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$__i$4+28>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;HEAP32[$__i$4+16>>2]=HEAP32[$__m$2+16>>2]|0;HEAP32[$__i$4+20>>2]=HEAP32[$__m$2+20>>2]|0;HEAP32[$__i$4+24>>2]=HEAP32[$__m$2+24>>2]|0;HEAP16[$__i$4+28>>1]=HEAP16[$__m$2+28>>1]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$__m$2+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$__m$2+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$__m$2+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$__m$2+28>>1]=HEAP16[$__t$i23+28>>1]|0;
     $113 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $113;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $114 = ($__n_swaps$6|0)==(0);
   if ($114) {
    $115 = (__ZNSt3__127__insertion_sort_incompleteIR17ROSorterDepthPassP17RODataReplacementEEbT0_S5_T_($$0,$__i$4,0)|0);
    $116 = (($__i$4) + 32|0);
    $117 = (__ZNSt3__127__insertion_sort_incompleteIR17ROSorterDepthPassP17RODataReplacementEEbT0_S5_T_($116,$$01$ph,0)|0);
    if ($117) {
     label = 66;
     break;
    }
    if ($115) {
     $$0 = $116;
     continue;
    }
   }
   $118 = $__i$4;
   $119 = (($118) - ($2))|0;
   $120 = (($0) - ($118))|0;
   $121 = ($119|0)<($120|0);
   if (!($121)) {
    label = 70;
    break;
   }
   __ZNSt3__16__sortIR17ROSorterDepthPassP17RODataReplacementEEvT0_S5_T_($$0,$__i$4,$__comp);
   $122 = (($__i$4) + 32|0);
   $$0 = $122;
  }
  if ((label|0) == 66) {
   label = 0;
   if ($115) {
    label = 71;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 70) {
   label = 0;
   $123 = (($__i$4) + 32|0);
   __ZNSt3__16__sortIR17ROSorterDepthPassP17RODataReplacementEEvT0_S5_T_($123,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = ($5>>>0)<($6>>>0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$1+28>>1]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $8 = (($$0) + 32|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$$0>>2]|0;
  $11 = ($9>>>0)<($10>>>0);
  $12 = HEAP32[$1>>2]|0;
  $13 = ($12>>>0)<($9>>>0);
  if (!($11)) {
   if (!($13)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$8+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$8+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$8+28>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$8+28>>1]=HEAP16[$1+28>>1]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
   $14 = HEAP32[$8>>2]|0;
   $15 = HEAP32[$$0>>2]|0;
   $16 = ($14>>>0)<($15>>>0);
   if (!($16)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$8+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$8+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$8+28>>1]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$8+28>>1]=HEAP16[$__t$i23+28>>1]|0;
   STACKTOP = sp;return;
  }
  if ($13) {
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$1+28>>1]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$8+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$8+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$8+28>>1]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$8+28>>1]=HEAP16[$__t$i23+28>>1]|0;
  $17 = HEAP32[$1>>2]|0;
  $18 = HEAP32[$8>>2]|0;
  $19 = ($17>>>0)<($18>>>0);
  if (!($19)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$8+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$8+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$8+28>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$8+28>>1]=HEAP16[$1+28>>1]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $20 = (($$0) + 32|0);
  $21 = (($$0) + 64|0);
  (__ZNSt3__17__sort4IR17ROSorterDepthPassP17RODataReplacementEEjT0_S5_S5_S5_T_($$0,$20,$21,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $22 = (($$0) + 32|0);
  $23 = (($$0) + 64|0);
  $24 = (($$0) + 96|0);
  (__ZNSt3__17__sort4IR17ROSorterDepthPassP17RODataReplacementEEjT0_S5_S5_S5_T_($$0,$22,$23,$24,0)|0);
  $25 = HEAP32[$1>>2]|0;
  $26 = HEAP32[$24>>2]|0;
  $27 = ($25>>>0)<($26>>>0);
  if (!($27)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$24+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$24+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$24+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$24+28>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$24+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$24+28>>1]=HEAP16[$1+28>>1]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i23+28>>1]|0;
  $28 = HEAP32[$24>>2]|0;
  $29 = HEAP32[$23>>2]|0;
  $30 = ($28>>>0)<($29>>>0);
  if (!($30)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$23+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$23+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$23+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$23+28>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$24+16>>2]|0;HEAP32[$23+20>>2]=HEAP32[$24+20>>2]|0;HEAP32[$23+24>>2]=HEAP32[$24+24>>2]|0;HEAP16[$23+28>>1]=HEAP16[$24+28>>1]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$24+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$24+28>>1]=HEAP16[$__t$i23+28>>1]|0;
  $31 = HEAP32[$23>>2]|0;
  $32 = HEAP32[$22>>2]|0;
  $33 = ($31>>>0)<($32>>>0);
  if (!($33)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$22+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$22+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$22+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$22+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$22+28>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$23+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$23+20>>2]|0;HEAP32[$22+24>>2]=HEAP32[$23+24>>2]|0;HEAP16[$22+28>>1]=HEAP16[$23+28>>1]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$23+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$23+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$23+28>>1]=HEAP16[$__t$i23+28>>1]|0;
  $34 = HEAP32[$22>>2]|0;
  $35 = HEAP32[$$0>>2]|0;
  $36 = ($34>>>0)<($35>>>0);
  if (!($36)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i23+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i23+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i23+28>>2]=HEAP32[$$0+28>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$22+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$22+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$22+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$22+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$22+28>>1]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$__t$i23+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$__t$i23+20>>2]|0;HEAP32[$22+24>>2]=HEAP32[$__t$i23+24>>2]|0;HEAP16[$22+28>>1]=HEAP16[$__t$i23+28>>1]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IR17ROSorterDepthPassP17RODataReplacementEEvT0_S5_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 71) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IR17ROSorterDepthPassP17RODataReplacementEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i2 = sp;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0>>>0)<($1>>>0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3>>>0)<($0>>>0);
 do {
  if ($2) {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x1+24>>2]|0;HEAP32[$__t$i2+28>>2]=HEAP32[$__x1+28>>2]|0;
    ;HEAP32[$__x1+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP16[$__x1+28>>1]=HEAP16[$__x3+28>>1]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i2+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__t$i2+28>>1]|0;
    $$0$i = 1;
    break;
   }
   ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x1+24>>2]|0;HEAP32[$__t$i2+28>>2]=HEAP32[$__x1+28>>2]|0;
   ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP16[$__x1+28>>1]=HEAP16[$__x2+28>>1]|0;
   ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i2+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__t$i2+28>>1]|0;
   $8 = HEAP32[$__x3>>2]|0;
   $9 = HEAP32[$__x2>>2]|0;
   $10 = ($8>>>0)<($9>>>0);
   if ($10) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP32[$__t$i2+28>>2]=HEAP32[$__x2+28>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__x3+28>>1]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i2+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__t$i2+28>>1]|0;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP32[$__t$i2+28>>2]=HEAP32[$__x2+28>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__x3+28>>1]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i2+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__t$i2+28>>1]|0;
    $5 = HEAP32[$__x2>>2]|0;
    $6 = HEAP32[$__x1>>2]|0;
    $7 = ($5>>>0)<($6>>>0);
    if ($7) {
     ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x1+24>>2]|0;HEAP32[$__t$i2+28>>2]=HEAP32[$__x1+28>>2]|0;
     ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP16[$__x1+28>>1]=HEAP16[$__x2+28>>1]|0;
     ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i2+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__t$i2+28>>1]|0;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $11 = HEAP32[$__x4>>2]|0;
 $12 = HEAP32[$__x3>>2]|0;
 $13 = ($11>>>0)<($12>>>0);
 if (!($13)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP32[$__t$i2+28>>2]=HEAP32[$__x3+28>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__x4+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__x4+28>>1]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__t$i2+24>>2]|0;HEAP16[$__x4+28>>1]=HEAP16[$__t$i2+28>>1]|0;
 $14 = (($$0$i) + 1)|0;
 $15 = HEAP32[$__x3>>2]|0;
 $16 = HEAP32[$__x2>>2]|0;
 $17 = ($15>>>0)<($16>>>0);
 if (!($17)) {
  $__r$0 = $14;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP32[$__t$i2+28>>2]=HEAP32[$__x2+28>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__x3+28>>1]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i2+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__t$i2+28>>1]|0;
 $18 = (($$0$i) + 2)|0;
 $19 = HEAP32[$__x2>>2]|0;
 $20 = HEAP32[$__x1>>2]|0;
 $21 = ($19>>>0)<($20>>>0);
 if (!($21)) {
  $__r$0 = $18;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x1+24>>2]|0;HEAP32[$__t$i2+28>>2]=HEAP32[$__x1+28>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP16[$__x1+28>>1]=HEAP16[$__x2+28>>1]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i2+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__t$i2+28>>1]|0;
 $22 = (($$0$i) + 3)|0;
 $__r$0 = $22;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IR17ROSorterDepthPassP17RODataReplacementEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i = 0, $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i4$i = sp + 32|0;
 $__t$sroa$1 = sp;
 $0 = (($__first) + 64|0);
 $1 = (($__first) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = ($2>>>0)<($3>>>0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5>>>0)<($2>>>0);
 do {
  if ($4) {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i+28>>2]=HEAP32[$__first+28>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$0+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$0+28>>1]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$__t$i4$i+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$__t$i4$i+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$__t$i4$i+24>>2]|0;HEAP16[$0+28>>1]=HEAP16[$__t$i4$i+28>>1]|0;
    break;
   }
   ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i+28>>2]=HEAP32[$__first+28>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$1+28>>1]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i4$i+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i4$i+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i4$i+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i4$i+28>>1]|0;
   $9 = HEAP32[$1>>2]|0;
   $10 = ($5>>>0)<($9>>>0);
   if ($10) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__t$i4$i+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$__t$i4$i+24>>2]=HEAP32[$1+24>>2]|0;HEAP32[$__t$i4$i+28>>2]=HEAP32[$1+28>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$0+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$0+28>>1]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$__t$i4$i+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$__t$i4$i+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$__t$i4$i+24>>2]|0;HEAP16[$0+28>>1]=HEAP16[$__t$i4$i+28>>1]|0;
   }
  } else {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__t$i4$i+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$__t$i4$i+24>>2]=HEAP32[$1+24>>2]|0;HEAP32[$__t$i4$i+28>>2]=HEAP32[$1+28>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$0+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$0+28>>1]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$__t$i4$i+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$__t$i4$i+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$__t$i4$i+24>>2]|0;HEAP16[$0+28>>1]=HEAP16[$__t$i4$i+28>>1]|0;
    $7 = HEAP32[$1>>2]|0;
    $8 = ($7>>>0)<($3>>>0);
    if ($8) {
     ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i+28>>2]=HEAP32[$__first+28>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$1+28>>1]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i4$i+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i4$i+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i4$i+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i4$i+28>>1]|0;
    }
   }
  }
 } while(0);
 $11 = (($__first) + 96|0);
 $12 = ($11|0)==($__last|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $__i$02 = $11;$__j$01 = $0;
 while(1) {
  $13 = HEAP32[$__i$02>>2]|0;
  $14 = HEAP32[$__j$01>>2]|0;
  $15 = ($13>>>0)<($14>>>0);
  if ($15) {
   $16 = (($__i$02) + 4|0);
   ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$__t$sroa$1+12>>2]=HEAP32[$16+12>>2]|0;HEAP32[$__t$sroa$1+16>>2]=HEAP32[$16+16>>2]|0;HEAP32[$__t$sroa$1+20>>2]=HEAP32[$16+20>>2]|0;HEAP32[$__t$sroa$1+24>>2]=HEAP32[$16+24>>2]|0;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;HEAP32[$__j$1+16>>2]=HEAP32[$__k$0+16>>2]|0;HEAP32[$__j$1+20>>2]=HEAP32[$__k$0+20>>2]|0;HEAP32[$__j$1+24>>2]=HEAP32[$__k$0+24>>2]|0;HEAP16[$__j$1+28>>1]=HEAP16[$__k$0+28>>1]|0;
    $17 = ($__k$0|0)==($__first|0);
    if ($17) {
     $__k$0$lcssa = $__first;
     break;
    }
    $18 = (($__k$0) + -32|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($13>>>0)<($19>>>0);
    if ($20) {
     $__j$1$phi = $__k$0;$__k$0 = $18;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAP32[$__k$0$lcssa>>2] = $13;
   $21 = (($__k$0$lcssa) + 4|0);
   ;HEAP32[$21+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$__t$sroa$1+12>>2]|0;HEAP32[$21+16>>2]=HEAP32[$__t$sroa$1+16>>2]|0;HEAP32[$21+20>>2]=HEAP32[$__t$sroa$1+20>>2]|0;HEAP16[$21+24>>1]=HEAP16[$__t$sroa$1+24>>1]|0;
  }
  $22 = (($__i$02) + 32|0);
  $23 = ($22|0)==($__last|0);
  if ($23) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $22;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIR17ROSorterDepthPassP17RODataReplacementEEbT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$014 = 0, $__count$1 = 0, $__i$015 = 0, $__j$013 = 0, $__j$013$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i5 = 0, $__t$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i4$i5 = sp + 32|0;
 $__t$sroa$1 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 5;
 switch ($3|0) {
 case 4:  {
  $21 = (($__first) + 32|0);
  $22 = (($__first) + 64|0);
  $23 = (($__last) + -32|0);
  (__ZNSt3__17__sort4IR17ROSorterDepthPassP17RODataReplacementEEjT0_S5_S5_S5_T_($__first,$21,$22,$23,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $24 = (($__first) + 32|0);
  $25 = (($__first) + 64|0);
  $26 = (($__first) + 96|0);
  $27 = (($__last) + -32|0);
  (__ZNSt3__17__sort4IR17ROSorterDepthPassP17RODataReplacementEEjT0_S5_S5_S5_T_($__first,$24,$25,$26,0)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$26>>2]|0;
  $30 = ($28>>>0)<($29>>>0);
  if (!($30)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$26+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$26+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$26+28>>2]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$27+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$27+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$27+20>>2]|0;HEAP32[$26+24>>2]=HEAP32[$27+24>>2]|0;HEAP16[$26+28>>1]=HEAP16[$27+28>>1]|0;
  ;HEAP32[$27+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$27+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$27+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$27+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$27+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
  $31 = HEAP32[$26>>2]|0;
  $32 = HEAP32[$25>>2]|0;
  $33 = ($31>>>0)<($32>>>0);
  if (!($33)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$25+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$25+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$25+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$25+28>>2]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$25+20>>2]=HEAP32[$26+20>>2]|0;HEAP32[$25+24>>2]=HEAP32[$26+24>>2]|0;HEAP16[$25+28>>1]=HEAP16[$26+28>>1]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$26+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$26+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
  $34 = HEAP32[$25>>2]|0;
  $35 = HEAP32[$24>>2]|0;
  $36 = ($34>>>0)<($35>>>0);
  if (!($36)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$24+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$24+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$24+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$24+28>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$25+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$25+20>>2]|0;HEAP32[$24+24>>2]=HEAP32[$25+24>>2]|0;HEAP16[$24+28>>1]=HEAP16[$25+28>>1]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$25+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$25+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$25+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
  $37 = HEAP32[$24>>2]|0;
  $38 = HEAP32[$__first>>2]|0;
  $39 = ($37>>>0)<($38>>>0);
  if (!($39)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$__first+28>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$24+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$24+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$24+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$24+28>>1]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$24+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$24+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $8 = (($__first) + 32|0);
  $9 = (($__last) + -32|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$__first>>2]|0;
  $12 = ($10>>>0)<($11>>>0);
  $13 = HEAP32[$9>>2]|0;
  $14 = ($13>>>0)<($10>>>0);
  if (!($12)) {
   if (!($14)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$8+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$8+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$8+28>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$9+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$9+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$9+24>>2]|0;HEAP16[$8+28>>1]=HEAP16[$9+28>>1]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$9+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$9+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$9+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$9+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
   $15 = HEAP32[$8>>2]|0;
   $16 = HEAP32[$__first>>2]|0;
   $17 = ($15>>>0)<($16>>>0);
   if (!($17)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$__first+28>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$8+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$8+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$8+28>>1]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$8+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($14) {
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$__first+28>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$9+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$9+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$9+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$9+28>>1]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$9+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$9+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$9+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$9+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$__first+28>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$8+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$8+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$8+28>>1]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$8+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
  $18 = HEAP32[$9>>2]|0;
  $19 = HEAP32[$8>>2]|0;
  $20 = ($18>>>0)<($19>>>0);
  if (!($20)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$8+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$8+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$8+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$8+28>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$9+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$9+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$9+24>>2]|0;HEAP16[$8+28>>1]=HEAP16[$9+28>>1]|0;
  ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$9+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$9+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$9+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$9+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5>>>0)<($6>>>0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$__first+28>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$4+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$4+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$4+28>>1]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$4+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$4+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $40 = (($__first) + 64|0);
  $41 = (($__first) + 32|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$__first>>2]|0;
  $44 = ($42>>>0)<($43>>>0);
  $45 = HEAP32[$40>>2]|0;
  $46 = ($45>>>0)<($42>>>0);
  do {
   if ($44) {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$__first+28>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$40+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$40+28>>1]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
     break;
    }
    ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$__first+28>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$41+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$41+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$41+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$41+28>>1]|0;
    ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$41+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$41+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$41+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$41+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
    $49 = HEAP32[$41>>2]|0;
    $50 = ($45>>>0)<($49>>>0);
    if ($50) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$41+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$41+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$41+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$41+28>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$41+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$41+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$41+24>>2]=HEAP32[$40+24>>2]|0;HEAP16[$41+28>>1]=HEAP16[$40+28>>1]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
    }
   } else {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$41+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$41+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$41+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$41+28>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$41+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$41+20>>2]=HEAP32[$40+20>>2]|0;HEAP32[$41+24>>2]=HEAP32[$40+24>>2]|0;HEAP16[$41+28>>1]=HEAP16[$40+28>>1]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$40+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
     $47 = HEAP32[$41>>2]|0;
     $48 = ($47>>>0)<($43>>>0);
     if ($48) {
      ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i4$i5+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i4$i5+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i4$i5+28>>2]=HEAP32[$__first+28>>2]|0;
      ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$41+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$41+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$41+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$41+28>>1]|0;
      ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP32[$41+16>>2]=HEAP32[$__t$i4$i5+16>>2]|0;HEAP32[$41+20>>2]=HEAP32[$__t$i4$i5+20>>2]|0;HEAP32[$41+24>>2]=HEAP32[$__t$i4$i5+24>>2]|0;HEAP16[$41+28>>1]=HEAP16[$__t$i4$i5+28>>1]|0;
     }
    }
   }
  } while(0);
  $51 = (($__first) + 96|0);
  $52 = ($51|0)==($__last|0);
  if ($52) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$014 = 0;$__i$015 = $51;$__j$013 = $40;
  while(1) {
   $53 = HEAP32[$__i$015>>2]|0;
   $54 = HEAP32[$__j$013>>2]|0;
   $55 = ($53>>>0)<($54>>>0);
   if ($55) {
    $56 = (($__i$015) + 4|0);
    ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$__t$sroa$1+12>>2]=HEAP32[$56+12>>2]|0;HEAP32[$__t$sroa$1+16>>2]=HEAP32[$56+16>>2]|0;HEAP32[$__t$sroa$1+20>>2]=HEAP32[$56+20>>2]|0;HEAP32[$__t$sroa$1+24>>2]=HEAP32[$56+24>>2]|0;
    $__j$1 = $__i$015;$__k$0 = $__j$013;
    while(1) {
     ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;HEAP32[$__j$1+16>>2]=HEAP32[$__k$0+16>>2]|0;HEAP32[$__j$1+20>>2]=HEAP32[$__k$0+20>>2]|0;HEAP32[$__j$1+24>>2]=HEAP32[$__k$0+24>>2]|0;HEAP16[$__j$1+28>>1]=HEAP16[$__k$0+28>>1]|0;
     $57 = ($__k$0|0)==($__first|0);
     if ($57) {
      $__k$0$lcssa = $__first;
      break;
     }
     $58 = (($__k$0) + -32|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($53>>>0)<($59>>>0);
     if ($60) {
      $__j$1$phi = $__k$0;$__k$0 = $58;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $53;
    $61 = (($__k$0$lcssa) + 4|0);
    ;HEAP32[$61+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$__t$sroa$1+12>>2]|0;HEAP32[$61+16>>2]=HEAP32[$__t$sroa$1+16>>2]|0;HEAP32[$61+20>>2]=HEAP32[$__t$sroa$1+20>>2]|0;HEAP16[$61+24>>1]=HEAP16[$__t$sroa$1+24>>1]|0;
    $62 = (($__count$014) + 1)|0;
    $63 = ($62|0)==(8);
    if ($63) {
     break;
    } else {
     $__count$1 = $62;
    }
   } else {
    $__count$1 = $__count$014;
   }
   $66 = (($__i$015) + 32|0);
   $67 = ($66|0)==($__last|0);
   if ($67) {
    $$0 = 1;
    label = 35;
    break;
   } else {
    $__j$013$phi = $__i$015;$__count$014 = $__count$1;$__i$015 = $66;$__j$013 = $__j$013$phi;
   }
  }
  if ((label|0) == 35) {
   STACKTOP = sp;return ($$0|0);
  }
  $64 = (($__i$015) + 32|0);
  $65 = ($64|0)==($__last|0);
  $$0 = $65;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16vectorI17RODataReplacement13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 5;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 5;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 4;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 5;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,569272,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<5)|0);
 $24 = (($23) + ($$0$i3<<5)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  ;HEAP32[$22+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$22+24>>2]=HEAP32[$__x+24>>2]|0;HEAP32[$22+28>>2]=HEAP32[$__x+28>>2]|0;
 }
 $26 = (($23) + ($8<<5)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = $28;
 $30 = $27;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 5;
 $$sum1 = (($7) - ($32))|0;
 $33 = (($23) + ($$sum1<<5)|0);
 _memcpy(($33|0),($27|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$1>>2] = $26;
 HEAP32[$10>>2] = $24;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__sortIR19ROSorterReplacementP17RODataReplacementEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$038 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$035 = 0, $__j$035$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i33 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -32|0);
  $2 = (($$01$ph) + -64|0);
  $3 = (($$01$ph) + -8|0);
  $4 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $5 = $$0;
   $6 = (($0) - ($5))|0;
   $7 = $6 >> 5;
   switch ($7|0) {
   case 1: case 0:  {
    label = 101;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 11;
    break L1;
    break;
   }
   case 5:  {
    label = 13;
    break L1;
    break;
   }
   case 4:  {
    label = 12;
    break L1;
    break;
   }
   default: {
   }
   }
   $28 = ($6|0)<(992);
   if ($28) {
    label = 15;
    break L1;
   }
   $29 = ($6|0)>(31968);
   $30 = (($7|0) / 2)&-1;
   $31 = (($$0) + ($30<<5)|0);
   if ($29) {
    $32 = (($7|0) / 4)&-1;
    $33 = (($$0) + ($32<<5)|0);
    $$sum = (($32) + ($30))|0;
    $34 = (($$0) + ($$sum<<5)|0);
    $35 = (__ZNSt3__17__sort5IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_S5_S5_T_($$0,$33,$31,$34,$1,0)|0);
    $__n_swaps$0 = $35;
   } else {
    $36 = (__ZNSt3__17__sort3IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_T_($$0,$31,$1,0)|0);
    $__n_swaps$0 = $36;
   }
   $37 = (($$0) + 24|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($$0) + ($30<<5)|0) + 24|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($38|0)==($40|0);
   do {
    if ($41) {
     $43 = HEAP32[$$0>>2]|0;
     $44 = HEAP32[$31>>2]|0;
     $45 = ($43|0)==($44|0);
     if ($45) {
      $46 = (($$0) + 28|0);
      $47 = HEAP16[$46>>1]|0;
      $48 = ((($$0) + ($30<<5)|0) + 28|0);
      $49 = HEAP16[$48>>1]|0;
      $50 = ($47<<16>>16)==($49<<16>>16);
      if (!($50)) {
       $51 = ($47&65535)>($49&65535);
       if ($51) {
        $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
        break;
       } else {
        label = 25;
        break;
       }
      }
     }
     $52 = ($43>>>0)<($44>>>0);
     if ($52) {
      $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
     } else {
      label = 25;
     }
    } else {
     $42 = ($38>>>0)<($40>>>0);
     if ($42) {
      $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
     } else {
      label = 25;
     }
    }
   } while(0);
   L18: do {
    if ((label|0) == 25) {
     label = 0;
     $53 = ($$0|0)==($2|0);
     L20: do {
      if (!($53)) {
       $54 = ((($$0) + ($30<<5)|0) + 28|0);
       $124 = $2;$__j$035 = $1;
       L22: while(1) {
        $119 = (($__j$035) + -8|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = ($120|0)==($40|0);
        do {
         if ($121) {
          $123 = HEAP32[$124>>2]|0;
          $125 = HEAP32[$31>>2]|0;
          $126 = ($123|0)==($125|0);
          if ($126) {
           $127 = (($__j$035) + -4|0);
           $128 = HEAP16[$127>>1]|0;
           $129 = HEAP16[$54>>1]|0;
           $130 = ($128<<16>>16)==($129<<16>>16);
           if (!($130)) {
            $131 = ($128&65535)>($129&65535);
            if ($131) {
             break L22;
            } else {
             break;
            }
           }
          }
          $132 = ($123>>>0)<($125>>>0);
          if ($132) {
           break L22;
          }
         } else {
          $122 = ($120>>>0)<($40>>>0);
          if ($122) {
           break L22;
          }
         }
        } while(0);
        $133 = (($124) + -32|0);
        $134 = ($$0|0)==($133|0);
        if ($134) {
         break L20;
        } else {
         $__j$035$phi = $124;$124 = $133;$__j$035 = $__j$035$phi;
        }
       }
       ;HEAP32[$__t$i33+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i33+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i33+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i33+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i33+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i33+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i33+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i33+28>>2]=HEAP32[$$0+28>>2]|0;
       ;HEAP32[$$0+0>>2]=HEAP32[$124+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$124+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$124+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$124+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$124+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$124+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$124+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$124+28>>1]|0;
       ;HEAP32[$124+0>>2]=HEAP32[$__t$i33+0>>2]|0;HEAP32[$124+4>>2]=HEAP32[$__t$i33+4>>2]|0;HEAP32[$124+8>>2]=HEAP32[$__t$i33+8>>2]|0;HEAP32[$124+12>>2]=HEAP32[$__t$i33+12>>2]|0;HEAP32[$124+16>>2]=HEAP32[$__t$i33+16>>2]|0;HEAP32[$124+20>>2]=HEAP32[$__t$i33+20>>2]|0;HEAP32[$124+24>>2]=HEAP32[$__t$i33+24>>2]|0;HEAP16[$124+28>>1]=HEAP16[$__t$i33+28>>1]|0;
       $135 = (($__n_swaps$0) + 1)|0;
       $__j$3 = $124;$__n_swaps$3 = $135;
       break L18;
      }
     } while(0);
     $55 = (($$0) + 32|0);
     $56 = HEAP32[$3>>2]|0;
     $57 = ($38|0)==($56|0);
     do {
      if ($57) {
       $59 = HEAP32[$$0>>2]|0;
       $60 = HEAP32[$1>>2]|0;
       $61 = ($59|0)==($60|0);
       if ($61) {
        $62 = (($$0) + 28|0);
        $63 = HEAP16[$62>>1]|0;
        $64 = HEAP16[$4>>1]|0;
        $65 = ($63<<16>>16)==($64<<16>>16);
        if (!($65)) {
         $66 = ($63&65535)>($64&65535);
         if ($66) {
          $__i$1 = $55;
          break;
         } else {
          label = 33;
          break;
         }
        }
       }
       $67 = ($59>>>0)<($60>>>0);
       if ($67) {
        $__i$1 = $55;
       } else {
        label = 33;
       }
      } else {
       $58 = ($38>>>0)<($56>>>0);
       if ($58) {
        $__i$1 = $55;
       } else {
        label = 33;
       }
      }
     } while(0);
     if ((label|0) == 33) {
      label = 0;
      $68 = ($55|0)==($1|0);
      if ($68) {
       label = 101;
       break L1;
      }
      $69 = (($$0) + 28|0);
      $__i$038 = $55;
      L44: while(1) {
       $70 = (($__i$038) + 24|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = ($38|0)==($71|0);
       do {
        if ($72) {
         $74 = HEAP32[$$0>>2]|0;
         $75 = HEAP32[$__i$038>>2]|0;
         $76 = ($74|0)==($75|0);
         if ($76) {
          $77 = HEAP16[$69>>1]|0;
          $78 = (($__i$038) + 28|0);
          $79 = HEAP16[$78>>1]|0;
          $80 = ($77<<16>>16)==($79<<16>>16);
          if (!($80)) {
           $81 = ($77&65535)>($79&65535);
           if ($81) {
            break L44;
           } else {
            break;
           }
          }
         }
         $82 = ($74>>>0)<($75>>>0);
         if ($82) {
          break L44;
         }
        } else {
         $73 = ($38>>>0)<($71>>>0);
         if ($73) {
          break L44;
         }
        }
       } while(0);
       $84 = (($__i$038) + 32|0);
       $85 = ($84|0)==($1|0);
       if ($85) {
        label = 101;
        break L1;
       } else {
        $__i$038 = $84;
       }
      }
      ;HEAP32[$__t$i33+0>>2]=HEAP32[$__i$038+0>>2]|0;HEAP32[$__t$i33+4>>2]=HEAP32[$__i$038+4>>2]|0;HEAP32[$__t$i33+8>>2]=HEAP32[$__i$038+8>>2]|0;HEAP32[$__t$i33+12>>2]=HEAP32[$__i$038+12>>2]|0;HEAP32[$__t$i33+16>>2]=HEAP32[$__i$038+16>>2]|0;HEAP32[$__t$i33+20>>2]=HEAP32[$__i$038+20>>2]|0;HEAP32[$__t$i33+24>>2]=HEAP32[$__i$038+24>>2]|0;HEAP32[$__t$i33+28>>2]=HEAP32[$__i$038+28>>2]|0;
      ;HEAP32[$__i$038+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$038+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$038+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$038+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__i$038+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__i$038+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$__i$038+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$__i$038+28>>1]=HEAP16[$1+28>>1]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i33+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i33+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i33+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i33+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i33+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i33+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i33+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i33+28>>1]|0;
      $83 = (($__i$038) + 32|0);
      $__i$1 = $83;
     }
     $86 = ($__i$1|0)==($1|0);
     if ($86) {
      label = 101;
      break L1;
     }
     $87 = (($$0) + 28|0);
     $__i$2$ph = $__i$1;$__j$1$ph = $1;
     while(1) {
      $88 = HEAP32[$37>>2]|0;
      $__i$2 = $__i$2$ph;
      L59: while(1) {
       $89 = (($__i$2) + 24|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = ($88|0)==($90|0);
       do {
        if ($91) {
         $93 = HEAP32[$$0>>2]|0;
         $94 = HEAP32[$__i$2>>2]|0;
         $95 = ($93|0)==($94|0);
         if ($95) {
          $96 = HEAP16[$87>>1]|0;
          $97 = (($__i$2) + 28|0);
          $98 = HEAP16[$97>>1]|0;
          $99 = ($96<<16>>16)==($98<<16>>16);
          if (!($99)) {
           $100 = ($96&65535)>($98&65535);
           if ($100) {
            $__j$2 = $__j$1$ph;
            break L59;
           } else {
            break;
           }
          }
         }
         $101 = ($93>>>0)<($94>>>0);
         if ($101) {
          $__j$2 = $__j$1$ph;
          break L59;
         }
        } else {
         $92 = ($88>>>0)<($90>>>0);
         if ($92) {
          $__j$2 = $__j$1$ph;
          break L59;
         }
        }
       } while(0);
       $102 = (($__i$2) + 32|0);
       $__i$2 = $102;
      }
      while(1) {
       $103 = (($__j$2) + -32|0);
       $104 = (($__j$2) + -8|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = ($88|0)==($105|0);
       if (!($106)) {
        $107 = ($88>>>0)<($105>>>0);
        if ($107) {
         $__j$2 = $103;
         continue;
        } else {
         break;
        }
       }
       $108 = HEAP32[$$0>>2]|0;
       $109 = HEAP32[$103>>2]|0;
       $110 = ($108|0)==($109|0);
       if ($110) {
        $111 = HEAP16[$87>>1]|0;
        $112 = (($__j$2) + -4|0);
        $113 = HEAP16[$112>>1]|0;
        $114 = ($111<<16>>16)==($113<<16>>16);
        if (!($114)) {
         $115 = ($111&65535)>($113&65535);
         if ($115) {
          $__j$2 = $103;
          continue;
         } else {
          break;
         }
        }
       }
       $116 = ($108>>>0)<($109>>>0);
       if ($116) {
        $__j$2 = $103;
       } else {
        break;
       }
      }
      $117 = ($__i$2>>>0)<($103>>>0);
      if (!($117)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i33+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i33+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i33+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i33+12>>2]=HEAP32[$__i$2+12>>2]|0;HEAP32[$__t$i33+16>>2]=HEAP32[$__i$2+16>>2]|0;HEAP32[$__t$i33+20>>2]=HEAP32[$__i$2+20>>2]|0;HEAP32[$__t$i33+24>>2]=HEAP32[$__i$2+24>>2]|0;HEAP32[$__t$i33+28>>2]=HEAP32[$__i$2+28>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$103+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$103+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$103+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$103+12>>2]|0;HEAP32[$__i$2+16>>2]=HEAP32[$103+16>>2]|0;HEAP32[$__i$2+20>>2]=HEAP32[$103+20>>2]|0;HEAP32[$__i$2+24>>2]=HEAP32[$103+24>>2]|0;HEAP16[$__i$2+28>>1]=HEAP16[$103+28>>1]|0;
      ;HEAP32[$103+0>>2]=HEAP32[$__t$i33+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$__t$i33+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$__t$i33+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$__t$i33+12>>2]|0;HEAP32[$103+16>>2]=HEAP32[$__t$i33+16>>2]|0;HEAP32[$103+20>>2]=HEAP32[$__t$i33+20>>2]|0;HEAP32[$103+24>>2]=HEAP32[$__t$i33+24>>2]|0;HEAP16[$103+28>>1]=HEAP16[$__t$i33+28>>1]|0;
      $118 = (($__i$2) + 32|0);
      $__i$2$ph = $118;$__j$1$ph = $103;
     }
    }
   } while(0);
   $136 = (($$0) + 32|0);
   $137 = ($136>>>0)<($__j$3>>>0);
   L81: do {
    if ($137) {
     $__i$3$ph = $136;$__j$4$ph = $__j$3;$__m$0$ph = $31;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $138 = (($__m$0$ph) + 24|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = (($__m$0$ph) + 28|0);
      $__i$3 = $__i$3$ph;
      L84: while(1) {
       $141 = (($__i$3) + 24|0);
       $142 = HEAP32[$141>>2]|0;
       $143 = ($142|0)==($139|0);
       do {
        if ($143) {
         $145 = HEAP32[$__i$3>>2]|0;
         $146 = HEAP32[$__m$0$ph>>2]|0;
         $147 = ($145|0)==($146|0);
         if ($147) {
          $148 = (($__i$3) + 28|0);
          $149 = HEAP16[$148>>1]|0;
          $150 = HEAP16[$140>>1]|0;
          $151 = ($149<<16>>16)==($150<<16>>16);
          if (!($151)) {
           $152 = ($149&65535)>($150&65535);
           if ($152) {
            break;
           } else {
            $__j$5 = $__j$4$ph;
            break L84;
           }
          }
         }
         $153 = ($145>>>0)<($146>>>0);
         if (!($153)) {
          $__j$5 = $__j$4$ph;
          break L84;
         }
        } else {
         $144 = ($142>>>0)<($139>>>0);
         if (!($144)) {
          $__j$5 = $__j$4$ph;
          break L84;
         }
        }
       } while(0);
       $154 = (($__i$3) + 32|0);
       $__i$3 = $154;
      }
      while(1) {
       $155 = (($__j$5) + -32|0);
       $156 = (($__j$5) + -8|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = ($157|0)==($139|0);
       if (!($158)) {
        $159 = ($157>>>0)<($139>>>0);
        if ($159) {
         break;
        } else {
         $__j$5 = $155;
         continue;
        }
       }
       $160 = HEAP32[$155>>2]|0;
       $161 = HEAP32[$__m$0$ph>>2]|0;
       $162 = ($160|0)==($161|0);
       if ($162) {
        $163 = (($__j$5) + -4|0);
        $164 = HEAP16[$163>>1]|0;
        $165 = HEAP16[$140>>1]|0;
        $166 = ($164<<16>>16)==($165<<16>>16);
        if (!($166)) {
         $167 = ($164&65535)>($165&65535);
         if ($167) {
          break;
         } else {
          $__j$5 = $155;
          continue;
         }
        }
       }
       $168 = ($160>>>0)<($161>>>0);
       if ($168) {
        break;
       } else {
        $__j$5 = $155;
       }
      }
      $169 = ($__i$3>>>0)>($155>>>0);
      if ($169) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L81;
      }
      ;HEAP32[$__t$i33+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i33+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i33+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i33+12>>2]=HEAP32[$__i$3+12>>2]|0;HEAP32[$__t$i33+16>>2]=HEAP32[$__i$3+16>>2]|0;HEAP32[$__t$i33+20>>2]=HEAP32[$__i$3+20>>2]|0;HEAP32[$__t$i33+24>>2]=HEAP32[$__i$3+24>>2]|0;HEAP32[$__t$i33+28>>2]=HEAP32[$__i$3+28>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$155+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$155+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$155+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$155+12>>2]|0;HEAP32[$__i$3+16>>2]=HEAP32[$155+16>>2]|0;HEAP32[$__i$3+20>>2]=HEAP32[$155+20>>2]|0;HEAP32[$__i$3+24>>2]=HEAP32[$155+24>>2]|0;HEAP16[$__i$3+28>>1]=HEAP16[$155+28>>1]|0;
      ;HEAP32[$155+0>>2]=HEAP32[$__t$i33+0>>2]|0;HEAP32[$155+4>>2]=HEAP32[$__t$i33+4>>2]|0;HEAP32[$155+8>>2]=HEAP32[$__t$i33+8>>2]|0;HEAP32[$155+12>>2]=HEAP32[$__t$i33+12>>2]|0;HEAP32[$155+16>>2]=HEAP32[$__t$i33+16>>2]|0;HEAP32[$155+20>>2]=HEAP32[$__t$i33+20>>2]|0;HEAP32[$155+24>>2]=HEAP32[$__t$i33+24>>2]|0;HEAP16[$155+28>>1]=HEAP16[$__t$i33+28>>1]|0;
      $170 = (($__n_swaps$4$ph) + 1)|0;
      $171 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $171 ? $155 : $__m$0$ph;
      $172 = (($__i$3) + 32|0);
      $__i$3$ph = $172;$__j$4$ph = $155;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $170;
     }
    } else {
     $__i$4 = $136;$__m$2 = $31;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $173 = ($__i$4|0)==($__m$2|0);
   L106: do {
    if ($173) {
     $__n_swaps$6 = $__n_swaps$5;
    } else {
     $174 = (($__m$2) + 24|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = (($__i$4) + 24|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = ($175|0)==($177|0);
     do {
      if ($178) {
       $180 = HEAP32[$__m$2>>2]|0;
       $181 = HEAP32[$__i$4>>2]|0;
       $182 = ($180|0)==($181|0);
       if ($182) {
        $183 = (($__m$2) + 28|0);
        $184 = HEAP16[$183>>1]|0;
        $185 = (($__i$4) + 28|0);
        $186 = HEAP16[$185>>1]|0;
        $187 = ($184<<16>>16)==($186<<16>>16);
        if (!($187)) {
         $188 = ($184&65535)>($186&65535);
         if ($188) {
          break;
         } else {
          $__n_swaps$6 = $__n_swaps$5;
          break L106;
         }
        }
       }
       $189 = ($180>>>0)<($181>>>0);
       if (!($189)) {
        $__n_swaps$6 = $__n_swaps$5;
        break L106;
       }
      } else {
       $179 = ($175>>>0)<($177>>>0);
       if (!($179)) {
        $__n_swaps$6 = $__n_swaps$5;
        break L106;
       }
      }
     } while(0);
     ;HEAP32[$__t$i33+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i33+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i33+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i33+12>>2]=HEAP32[$__i$4+12>>2]|0;HEAP32[$__t$i33+16>>2]=HEAP32[$__i$4+16>>2]|0;HEAP32[$__t$i33+20>>2]=HEAP32[$__i$4+20>>2]|0;HEAP32[$__t$i33+24>>2]=HEAP32[$__i$4+24>>2]|0;HEAP32[$__t$i33+28>>2]=HEAP32[$__i$4+28>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;HEAP32[$__i$4+16>>2]=HEAP32[$__m$2+16>>2]|0;HEAP32[$__i$4+20>>2]=HEAP32[$__m$2+20>>2]|0;HEAP32[$__i$4+24>>2]=HEAP32[$__m$2+24>>2]|0;HEAP16[$__i$4+28>>1]=HEAP16[$__m$2+28>>1]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i33+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i33+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i33+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i33+12>>2]|0;HEAP32[$__m$2+16>>2]=HEAP32[$__t$i33+16>>2]|0;HEAP32[$__m$2+20>>2]=HEAP32[$__t$i33+20>>2]|0;HEAP32[$__m$2+24>>2]=HEAP32[$__t$i33+24>>2]|0;HEAP16[$__m$2+28>>1]=HEAP16[$__t$i33+28>>1]|0;
     $190 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $190;
    }
   } while(0);
   $191 = ($__n_swaps$6|0)==(0);
   if ($191) {
    $192 = (__ZNSt3__127__insertion_sort_incompleteIR19ROSorterReplacementP17RODataReplacementEEbT0_S5_T_($$0,$__i$4,0)|0);
    $193 = (($__i$4) + 32|0);
    $194 = (__ZNSt3__127__insertion_sort_incompleteIR19ROSorterReplacementP17RODataReplacementEEbT0_S5_T_($193,$$01$ph,0)|0);
    if ($194) {
     label = 96;
     break;
    }
    if ($192) {
     $$0 = $193;
     continue;
    }
   }
   $195 = $__i$4;
   $196 = (($195) - ($5))|0;
   $197 = (($0) - ($195))|0;
   $198 = ($196|0)<($197|0);
   if (!($198)) {
    label = 100;
    break;
   }
   __ZNSt3__16__sortIR19ROSorterReplacementP17RODataReplacementEEvT0_S5_T_($$0,$__i$4,$__comp);
   $199 = (($__i$4) + 32|0);
   $$0 = $199;
  }
  if ((label|0) == 96) {
   label = 0;
   if ($192) {
    label = 101;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 100) {
   label = 0;
   $200 = (($__i$4) + 32|0);
   __ZNSt3__16__sortIR19ROSorterReplacementP17RODataReplacementEEvT0_S5_T_($200,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $8 = HEAP32[$3>>2]|0;
  $9 = (($$0) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  do {
   if ($11) {
    $13 = HEAP32[$1>>2]|0;
    $14 = HEAP32[$$0>>2]|0;
    $15 = ($13|0)==($14|0);
    if ($15) {
     $16 = HEAP16[$4>>1]|0;
     $17 = (($$0) + 28|0);
     $18 = HEAP16[$17>>1]|0;
     $19 = ($16<<16>>16)==($18<<16>>16);
     if (!($19)) {
      $20 = ($16&65535)>($18&65535);
      if ($20) {
       break;
      }
      STACKTOP = sp;return;
     }
    }
    $21 = ($13>>>0)<($14>>>0);
    if (!($21)) {
     STACKTOP = sp;return;
    }
   } else {
    $12 = ($8>>>0)<($10>>>0);
    if (!($12)) {
     STACKTOP = sp;return;
    }
   }
  } while(0);
  ;HEAP32[$__t$i33+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i33+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i33+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i33+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i33+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i33+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i33+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i33+28>>2]=HEAP32[$$0+28>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$1+24>>2]|0;HEAP16[$$0+28>>1]=HEAP16[$1+28>>1]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i33+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i33+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i33+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i33+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i33+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i33+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i33+24>>2]|0;HEAP16[$1+28>>1]=HEAP16[$__t$i33+28>>1]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  $22 = (($$0) + 32|0);
  (__ZNSt3__17__sort3IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_T_($$0,$22,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  $23 = (($$0) + 32|0);
  $24 = (($$0) + 64|0);
  (__ZNSt3__17__sort4IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_S5_T_($$0,$23,$24,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 13) {
  $25 = (($$0) + 32|0);
  $26 = (($$0) + 64|0);
  $27 = (($$0) + 96|0);
  (__ZNSt3__17__sort5IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_S5_S5_T_($$0,$25,$26,$27,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  __ZNSt3__118__insertion_sort_3IR19ROSorterReplacementP17RODataReplacementEEvT0_S5_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 101) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $$0$i = 0, $$0$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__t$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i10 = sp;
 $0 = (($__y) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__x) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 do {
  if ($4) {
   $6 = HEAP32[$__y>>2]|0;
   $7 = HEAP32[$__x>>2]|0;
   $8 = ($6|0)==($7|0);
   if ($8) {
    $9 = (($__y) + 28|0);
    $10 = HEAP16[$9>>1]|0;
    $11 = (($__x) + 28|0);
    $12 = HEAP16[$11>>1]|0;
    $13 = ($10<<16>>16)==($12<<16>>16);
    if (!($13)) {
     $14 = ($10&65535)>($12&65535);
     $$0$i = $14;
     break;
    }
   }
   $15 = ($6>>>0)<($7>>>0);
   $$0$i = $15;
  } else {
   $5 = ($1>>>0)<($3>>>0);
   $$0$i = $5;
  }
 } while(0);
 $16 = (($__z) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==($1|0);
 do {
  if ($18) {
   $20 = HEAP32[$__z>>2]|0;
   $21 = HEAP32[$__y>>2]|0;
   $22 = ($20|0)==($21|0);
   if ($22) {
    $23 = (($__z) + 28|0);
    $24 = HEAP16[$23>>1]|0;
    $25 = (($__y) + 28|0);
    $26 = HEAP16[$25>>1]|0;
    $27 = ($24<<16>>16)==($26<<16>>16);
    if (!($27)) {
     $28 = ($24&65535)>($26&65535);
     $$0$i12 = $28;
     break;
    }
   }
   $29 = ($20>>>0)<($21>>>0);
   $$0$i12 = $29;
  } else {
   $19 = ($17>>>0)<($1>>>0);
   $$0$i12 = $19;
  }
 } while(0);
 if (!($$0$i)) {
  if (!($$0$i12)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i10+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__t$i10+24>>2]=HEAP32[$__y+24>>2]|0;HEAP32[$__t$i10+28>>2]=HEAP32[$__y+28>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__z+24>>2]|0;HEAP16[$__y+28>>1]=HEAP16[$__z+28>>1]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i10+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i10+24>>2]|0;HEAP16[$__z+28>>1]=HEAP16[$__t$i10+28>>1]|0;
  $30 = HEAP32[$0>>2]|0;
  $31 = HEAP32[$2>>2]|0;
  $32 = ($30|0)==($31|0);
  do {
   if ($32) {
    $34 = HEAP32[$__y>>2]|0;
    $35 = HEAP32[$__x>>2]|0;
    $36 = ($34|0)==($35|0);
    if ($36) {
     $37 = (($__y) + 28|0);
     $38 = HEAP16[$37>>1]|0;
     $39 = (($__x) + 28|0);
     $40 = HEAP16[$39>>1]|0;
     $41 = ($38<<16>>16)==($40<<16>>16);
     if (!($41)) {
      $42 = ($38&65535)>($40&65535);
      if ($42) {
       break;
      } else {
       $$0 = 1;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $43 = ($34>>>0)<($35>>>0);
    if (!($43)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $33 = ($30>>>0)<($31>>>0);
    if (!($33)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  ;HEAP32[$__t$i10+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i10+24>>2]=HEAP32[$__x+24>>2]|0;HEAP32[$__t$i10+28>>2]=HEAP32[$__x+28>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__y+24>>2]|0;HEAP16[$__x+28>>1]=HEAP16[$__y+28>>1]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__t$i10+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__t$i10+24>>2]|0;HEAP16[$__y+28>>1]=HEAP16[$__t$i10+28>>1]|0;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($$0$i12) {
  ;HEAP32[$__t$i10+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i10+24>>2]=HEAP32[$__x+24>>2]|0;HEAP32[$__t$i10+28>>2]=HEAP32[$__x+28>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__z+24>>2]|0;HEAP16[$__x+28>>1]=HEAP16[$__z+28>>1]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i10+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i10+24>>2]|0;HEAP16[$__z+28>>1]=HEAP16[$__t$i10+28>>1]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$__t$i10+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i10+24>>2]=HEAP32[$__x+24>>2]|0;HEAP32[$__t$i10+28>>2]=HEAP32[$__x+28>>2]|0;
 ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__y+24>>2]|0;HEAP16[$__x+28>>1]=HEAP16[$__y+28>>1]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__t$i10+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__t$i10+24>>2]|0;HEAP16[$__y+28>>1]=HEAP16[$__t$i10+28>>1]|0;
 $44 = HEAP32[$16>>2]|0;
 $45 = HEAP32[$0>>2]|0;
 $46 = ($44|0)==($45|0);
 do {
  if ($46) {
   $48 = HEAP32[$__z>>2]|0;
   $49 = HEAP32[$__y>>2]|0;
   $50 = ($48|0)==($49|0);
   if ($50) {
    $51 = (($__z) + 28|0);
    $52 = HEAP16[$51>>1]|0;
    $53 = (($__y) + 28|0);
    $54 = HEAP16[$53>>1]|0;
    $55 = ($52<<16>>16)==($54<<16>>16);
    if (!($55)) {
     $56 = ($52&65535)>($54&65535);
     if ($56) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
   }
   $57 = ($48>>>0)<($49>>>0);
   if (!($57)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $47 = ($44>>>0)<($45>>>0);
   if (!($47)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i10+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__t$i10+24>>2]=HEAP32[$__y+24>>2]|0;HEAP32[$__t$i10+28>>2]=HEAP32[$__y+28>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__z+24>>2]|0;HEAP16[$__y+28>>1]=HEAP16[$__z+28>>1]|0;
 ;HEAP32[$__z+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i10+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i10+24>>2]|0;HEAP16[$__z+28>>1]=HEAP16[$__t$i10+28>>1]|0;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i8 = sp;
 $0 = (__ZNSt3__17__sort3IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_T_($__x1,$__x2,$__x3,0)|0);
 $1 = (($__x4) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__x3) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   $7 = HEAP32[$__x4>>2]|0;
   $8 = HEAP32[$__x3>>2]|0;
   $9 = ($7|0)==($8|0);
   if ($9) {
    $10 = (($__x4) + 28|0);
    $11 = HEAP16[$10>>1]|0;
    $12 = (($__x3) + 28|0);
    $13 = HEAP16[$12>>1]|0;
    $14 = ($11<<16>>16)==($13<<16>>16);
    if (!($14)) {
     $15 = ($11&65535)>($13&65535);
     if ($15) {
      break;
     } else {
      $__r$0 = $0;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $16 = ($7>>>0)<($8>>>0);
   if (!($16)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $6 = ($2>>>0)<($4>>>0);
   if (!($6)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i8+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__t$i8+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP32[$__t$i8+28>>2]=HEAP32[$__x3+28>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__x4+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__x4+28>>1]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i8+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i8+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__t$i8+24>>2]|0;HEAP16[$__x4+28>>1]=HEAP16[$__t$i8+28>>1]|0;
 $17 = (($0) + 1)|0;
 $18 = HEAP32[$3>>2]|0;
 $19 = (($__x2) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18|0)==($20|0);
 do {
  if ($21) {
   $23 = HEAP32[$__x3>>2]|0;
   $24 = HEAP32[$__x2>>2]|0;
   $25 = ($23|0)==($24|0);
   if ($25) {
    $26 = (($__x3) + 28|0);
    $27 = HEAP16[$26>>1]|0;
    $28 = (($__x2) + 28|0);
    $29 = HEAP16[$28>>1]|0;
    $30 = ($27<<16>>16)==($29<<16>>16);
    if (!($30)) {
     $31 = ($27&65535)>($29&65535);
     if ($31) {
      break;
     } else {
      $__r$0 = $17;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $32 = ($23>>>0)<($24>>>0);
   if (!($32)) {
    $__r$0 = $17;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $22 = ($18>>>0)<($20>>>0);
   if (!($22)) {
    $__r$0 = $17;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i8+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i8+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP32[$__t$i8+28>>2]=HEAP32[$__x2+28>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__x3+28>>1]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i8+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i8+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i8+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__t$i8+28>>1]|0;
 $33 = (($0) + 2)|0;
 $34 = HEAP32[$19>>2]|0;
 $35 = (($__x1) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 do {
  if ($37) {
   $39 = HEAP32[$__x2>>2]|0;
   $40 = HEAP32[$__x1>>2]|0;
   $41 = ($39|0)==($40|0);
   if ($41) {
    $42 = (($__x2) + 28|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = (($__x1) + 28|0);
    $45 = HEAP16[$44>>1]|0;
    $46 = ($43<<16>>16)==($45<<16>>16);
    if (!($46)) {
     $47 = ($43&65535)>($45&65535);
     if ($47) {
      break;
     } else {
      $__r$0 = $33;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $48 = ($39>>>0)<($40>>>0);
   if (!($48)) {
    $__r$0 = $33;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $38 = ($34>>>0)<($36>>>0);
   if (!($38)) {
    $__r$0 = $33;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i8+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i8+24>>2]=HEAP32[$__x1+24>>2]|0;HEAP32[$__t$i8+28>>2]=HEAP32[$__x1+28>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP16[$__x1+28>>1]=HEAP16[$__x2+28>>1]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i8+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i8+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i8+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__t$i8+28>>1]|0;
 $49 = (($0) + 3)|0;
 $__r$0 = $49;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i12 = sp;
 $0 = (__ZNSt3__17__sort4IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = (($__x5) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__x4) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   $7 = HEAP32[$__x5>>2]|0;
   $8 = HEAP32[$__x4>>2]|0;
   $9 = ($7|0)==($8|0);
   if ($9) {
    $10 = (($__x5) + 28|0);
    $11 = HEAP16[$10>>1]|0;
    $12 = (($__x4) + 28|0);
    $13 = HEAP16[$12>>1]|0;
    $14 = ($11<<16>>16)==($13<<16>>16);
    if (!($14)) {
     $15 = ($11&65535)>($13&65535);
     if ($15) {
      break;
     } else {
      $__r$0 = $0;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $16 = ($7>>>0)<($8>>>0);
   if (!($16)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $6 = ($2>>>0)<($4>>>0);
   if (!($6)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i12+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__t$i12+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__t$i12+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__t$i12+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__t$i12+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__t$i12+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__t$i12+24>>2]=HEAP32[$__x4+24>>2]|0;HEAP32[$__t$i12+28>>2]=HEAP32[$__x4+28>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__x5+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__x5+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__x5+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__x5+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__x5+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__x5+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__x5+24>>2]|0;HEAP16[$__x4+28>>1]=HEAP16[$__x5+28>>1]|0;
 ;HEAP32[$__x5+0>>2]=HEAP32[$__t$i12+0>>2]|0;HEAP32[$__x5+4>>2]=HEAP32[$__t$i12+4>>2]|0;HEAP32[$__x5+8>>2]=HEAP32[$__t$i12+8>>2]|0;HEAP32[$__x5+12>>2]=HEAP32[$__t$i12+12>>2]|0;HEAP32[$__x5+16>>2]=HEAP32[$__t$i12+16>>2]|0;HEAP32[$__x5+20>>2]=HEAP32[$__t$i12+20>>2]|0;HEAP32[$__x5+24>>2]=HEAP32[$__t$i12+24>>2]|0;HEAP16[$__x5+28>>1]=HEAP16[$__t$i12+28>>1]|0;
 $17 = (($0) + 1)|0;
 $18 = HEAP32[$3>>2]|0;
 $19 = (($__x3) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18|0)==($20|0);
 do {
  if ($21) {
   $23 = HEAP32[$__x4>>2]|0;
   $24 = HEAP32[$__x3>>2]|0;
   $25 = ($23|0)==($24|0);
   if ($25) {
    $26 = (($__x4) + 28|0);
    $27 = HEAP16[$26>>1]|0;
    $28 = (($__x3) + 28|0);
    $29 = HEAP16[$28>>1]|0;
    $30 = ($27<<16>>16)==($29<<16>>16);
    if (!($30)) {
     $31 = ($27&65535)>($29&65535);
     if ($31) {
      break;
     } else {
      $__r$0 = $17;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $32 = ($23>>>0)<($24>>>0);
   if (!($32)) {
    $__r$0 = $17;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $22 = ($18>>>0)<($20>>>0);
   if (!($22)) {
    $__r$0 = $17;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i12+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i12+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i12+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i12+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i12+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i12+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__t$i12+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP32[$__t$i12+28>>2]=HEAP32[$__x3+28>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__x4+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__x4+28>>1]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i12+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i12+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i12+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i12+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i12+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i12+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__t$i12+24>>2]|0;HEAP16[$__x4+28>>1]=HEAP16[$__t$i12+28>>1]|0;
 $33 = (($0) + 2)|0;
 $34 = HEAP32[$19>>2]|0;
 $35 = (($__x2) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 do {
  if ($37) {
   $39 = HEAP32[$__x3>>2]|0;
   $40 = HEAP32[$__x2>>2]|0;
   $41 = ($39|0)==($40|0);
   if ($41) {
    $42 = (($__x3) + 28|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = (($__x2) + 28|0);
    $45 = HEAP16[$44>>1]|0;
    $46 = ($43<<16>>16)==($45<<16>>16);
    if (!($46)) {
     $47 = ($43&65535)>($45&65535);
     if ($47) {
      break;
     } else {
      $__r$0 = $33;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $48 = ($39>>>0)<($40>>>0);
   if (!($48)) {
    $__r$0 = $33;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $38 = ($34>>>0)<($36>>>0);
   if (!($38)) {
    $__r$0 = $33;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i12+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i12+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i12+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i12+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i12+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i12+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i12+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP32[$__t$i12+28>>2]=HEAP32[$__x2+28>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__x3+28>>1]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i12+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i12+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i12+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i12+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i12+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i12+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i12+24>>2]|0;HEAP16[$__x3+28>>1]=HEAP16[$__t$i12+28>>1]|0;
 $49 = (($0) + 3)|0;
 $50 = HEAP32[$35>>2]|0;
 $51 = (($__x1) + 24|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($50|0)==($52|0);
 do {
  if ($53) {
   $55 = HEAP32[$__x2>>2]|0;
   $56 = HEAP32[$__x1>>2]|0;
   $57 = ($55|0)==($56|0);
   if ($57) {
    $58 = (($__x2) + 28|0);
    $59 = HEAP16[$58>>1]|0;
    $60 = (($__x1) + 28|0);
    $61 = HEAP16[$60>>1]|0;
    $62 = ($59<<16>>16)==($61<<16>>16);
    if (!($62)) {
     $63 = ($59&65535)>($61&65535);
     if ($63) {
      break;
     } else {
      $__r$0 = $49;
     }
     STACKTOP = sp;return ($__r$0|0);
    }
   }
   $64 = ($55>>>0)<($56>>>0);
   if (!($64)) {
    $__r$0 = $49;
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $54 = ($50>>>0)<($52>>>0);
   if (!($54)) {
    $__r$0 = $49;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i12+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i12+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i12+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i12+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i12+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i12+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i12+24>>2]=HEAP32[$__x1+24>>2]|0;HEAP32[$__t$i12+28>>2]=HEAP32[$__x1+28>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP16[$__x1+28>>1]=HEAP16[$__x2+28>>1]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i12+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i12+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i12+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i12+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i12+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i12+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i12+24>>2]|0;HEAP16[$__x2+28>>1]=HEAP16[$__t$i12+28>>1]|0;
 $65 = (($0) + 4)|0;
 $__r$0 = $65;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IR19ROSorterReplacementP17RODataReplacementEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$06 = 0, $__j$05 = 0, $__j$05$phi = 0, $__k$0$lcssa = 0, $__k$04 = 0, $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$sroa$1 = sp;
 $0 = (($__first) + 64|0);
 $1 = (($__first) + 32|0);
 (__ZNSt3__17__sort3IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 96|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $__i$06 = $2;$__j$05 = $0;
 while(1) {
  $4 = (($__i$06) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($__j$05) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $10 = HEAP32[$__i$06>>2]|0;
    $11 = HEAP32[$__j$05>>2]|0;
    $12 = ($10|0)==($11|0);
    if ($12) {
     $13 = (($__i$06) + 28|0);
     $14 = HEAP16[$13>>1]|0;
     $15 = (($__j$05) + 28|0);
     $16 = HEAP16[$15>>1]|0;
     $17 = ($14<<16>>16)==($16<<16>>16);
     if (!($17)) {
      $18 = ($14&65535)>($16&65535);
      if ($18) {
       $32 = $10;
       label = 10;
       break;
      } else {
       break;
      }
     }
    }
    $19 = ($10>>>0)<($11>>>0);
    if ($19) {
     $32 = $10;
     label = 10;
    }
   } else {
    $9 = ($5>>>0)<($7>>>0);
    if ($9) {
     $$pre = HEAP32[$__i$06>>2]|0;
     $32 = $$pre;
     label = 10;
    }
   }
  } while(0);
  if ((label|0) == 10) {
   label = 0;
   $20 = (($__i$06) + 4|0);
   ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$__t$sroa$1+12>>2]=HEAP32[$20+12>>2]|0;HEAP32[$__t$sroa$1+16>>2]=HEAP32[$20+16>>2]|0;
   $21 = HEAP32[$4>>2]|0;
   $22 = (($__i$06) + 28|0);
   $23 = HEAP16[$22>>1]|0;
   ;HEAP32[$__i$06+0>>2]=HEAP32[$__j$05+0>>2]|0;HEAP32[$__i$06+4>>2]=HEAP32[$__j$05+4>>2]|0;HEAP32[$__i$06+8>>2]=HEAP32[$__j$05+8>>2]|0;HEAP32[$__i$06+12>>2]=HEAP32[$__j$05+12>>2]|0;HEAP32[$__i$06+16>>2]=HEAP32[$__j$05+16>>2]|0;HEAP32[$__i$06+20>>2]=HEAP32[$__j$05+20>>2]|0;HEAP32[$__i$06+24>>2]=HEAP32[$__j$05+24>>2]|0;HEAP16[$__i$06+28>>1]=HEAP16[$__j$05+28>>1]|0;
   $24 = ($__j$05|0)==($__first|0);
   L16: do {
    if ($24) {
     $__k$0$lcssa = $__first;
    } else {
     $__k$04 = $__j$05;
     while(1) {
      $25 = (($__k$04) + -32|0);
      $26 = (($__k$04) + -8|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($21|0)==($27|0);
      do {
       if ($28) {
        $30 = HEAP32[$25>>2]|0;
        $31 = ($32|0)==($30|0);
        if ($31) {
         $33 = (($__k$04) + -4|0);
         $34 = HEAP16[$33>>1]|0;
         $35 = ($23<<16>>16)==($34<<16>>16);
         if (!($35)) {
          $36 = ($23&65535)>($34&65535);
          if ($36) {
           break;
          } else {
           $__k$0$lcssa = $__k$04;
           break L16;
          }
         }
        }
        $37 = ($32>>>0)<($30>>>0);
        if (!($37)) {
         $__k$0$lcssa = $__k$04;
         break L16;
        }
       } else {
        $29 = ($21>>>0)<($27>>>0);
        if (!($29)) {
         $__k$0$lcssa = $__k$04;
         break L16;
        }
       }
      } while(0);
      ;HEAP32[$__k$04+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$__k$04+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$__k$04+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$__k$04+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$__k$04+16>>2]=HEAP32[$25+16>>2]|0;HEAP32[$__k$04+20>>2]=HEAP32[$25+20>>2]|0;HEAP32[$__k$04+24>>2]=HEAP32[$25+24>>2]|0;HEAP16[$__k$04+28>>1]=HEAP16[$25+28>>1]|0;
      $38 = ($25|0)==($__first|0);
      if ($38) {
       $__k$0$lcssa = $__first;
       break;
      } else {
       $__k$04 = $25;
      }
     }
    }
   } while(0);
   HEAP32[$__k$0$lcssa>>2] = $32;
   $39 = (($__k$0$lcssa) + 4|0);
   ;HEAP32[$39+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$__t$sroa$1+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$__t$sroa$1+16>>2]|0;
   $40 = (($__k$0$lcssa) + 24|0);
   HEAP32[$40>>2] = $21;
   $41 = (($__k$0$lcssa) + 28|0);
   HEAP16[$41>>1] = $23;
  }
  $42 = (($__i$06) + 32|0);
  $43 = ($42|0)==($__last|0);
  if ($43) {
   break;
  } else {
   $__j$05$phi = $__i$06;$__i$06 = $42;$__j$05 = $__j$05$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIR19ROSorterReplacementP17RODataReplacementEEbT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0;
 var $__count$010 = 0, $__count$1 = 0, $__i$012 = 0, $__j$09 = 0, $__j$09$phi = 0, $__k$0$lcssa = 0, $__k$07 = 0, $__t$i = 0, $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i = sp + 24|0;
 $__t$sroa$1 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 5;
 switch ($3|0) {
 case 2:  {
  $4 = (($__last) + -32|0);
  $5 = (($__last) + -8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($__first) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $11 = HEAP32[$4>>2]|0;
    $12 = HEAP32[$__first>>2]|0;
    $13 = ($11|0)==($12|0);
    if ($13) {
     $14 = (($__last) + -4|0);
     $15 = HEAP16[$14>>1]|0;
     $16 = (($__first) + 28|0);
     $17 = HEAP16[$16>>1]|0;
     $18 = ($15<<16>>16)==($17<<16>>16);
     if (!($18)) {
      $19 = ($15&65535)>($17&65535);
      if ($19) {
       break;
      } else {
       $$0 = 1;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $20 = ($11>>>0)<($12>>>0);
    if (!($20)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $10 = ($6>>>0)<($8>>>0);
    if (!($10)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  ;HEAP32[$__t$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i+28>>2]=HEAP32[$__first+28>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$4+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$4+24>>2]|0;HEAP16[$__first+28>>1]=HEAP16[$4+28>>1]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$__t$i+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$__t$i+20>>2]|0;HEAP32[$4+24>>2]=HEAP32[$__t$i+24>>2]|0;HEAP16[$4+28>>1]=HEAP16[$__t$i+28>>1]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $21 = (($__first) + 32|0);
  $22 = (($__last) + -32|0);
  (__ZNSt3__17__sort3IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_T_($__first,$21,$22,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $26 = (($__first) + 32|0);
  $27 = (($__first) + 64|0);
  $28 = (($__first) + 96|0);
  $29 = (($__last) + -32|0);
  (__ZNSt3__17__sort5IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_S5_S5_T_($__first,$26,$27,$28,$29,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $23 = (($__first) + 32|0);
  $24 = (($__first) + 64|0);
  $25 = (($__last) + -32|0);
  (__ZNSt3__17__sort4IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_S5_T_($__first,$23,$24,$25,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $30 = (($__first) + 64|0);
  $31 = (($__first) + 32|0);
  (__ZNSt3__17__sort3IR19ROSorterReplacementP17RODataReplacementEEjT0_S5_S5_T_($__first,$31,$30,0)|0);
  $32 = (($__first) + 96|0);
  $33 = ($32|0)==($__last|0);
  if ($33) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$010 = 0;$__i$012 = $32;$__j$09 = $30;
  while(1) {
   $34 = (($__i$012) + 24|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($__j$09) + 24|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($35|0)==($37|0);
   do {
    if ($38) {
     $40 = HEAP32[$__i$012>>2]|0;
     $41 = HEAP32[$__j$09>>2]|0;
     $42 = ($40|0)==($41|0);
     if ($42) {
      $43 = (($__i$012) + 28|0);
      $44 = HEAP16[$43>>1]|0;
      $45 = (($__j$09) + 28|0);
      $46 = HEAP16[$45>>1]|0;
      $47 = ($44<<16>>16)==($46<<16>>16);
      if (!($47)) {
       $48 = ($44&65535)>($46&65535);
       if ($48) {
        $62 = $40;
        label = 21;
        break;
       } else {
        $__count$1 = $__count$010;
        break;
       }
      }
     }
     $49 = ($40>>>0)<($41>>>0);
     if ($49) {
      $62 = $40;
      label = 21;
     } else {
      $__count$1 = $__count$010;
     }
    } else {
     $39 = ($35>>>0)<($37>>>0);
     if ($39) {
      $$pre = HEAP32[$__i$012>>2]|0;
      $62 = $$pre;
      label = 21;
     } else {
      $__count$1 = $__count$010;
     }
    }
   } while(0);
   if ((label|0) == 21) {
    label = 0;
    $50 = (($__i$012) + 4|0);
    ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$__t$sroa$1+12>>2]=HEAP32[$50+12>>2]|0;HEAP32[$__t$sroa$1+16>>2]=HEAP32[$50+16>>2]|0;
    $51 = HEAP32[$34>>2]|0;
    $52 = (($__i$012) + 28|0);
    $53 = HEAP16[$52>>1]|0;
    ;HEAP32[$__i$012+0>>2]=HEAP32[$__j$09+0>>2]|0;HEAP32[$__i$012+4>>2]=HEAP32[$__j$09+4>>2]|0;HEAP32[$__i$012+8>>2]=HEAP32[$__j$09+8>>2]|0;HEAP32[$__i$012+12>>2]=HEAP32[$__j$09+12>>2]|0;HEAP32[$__i$012+16>>2]=HEAP32[$__j$09+16>>2]|0;HEAP32[$__i$012+20>>2]=HEAP32[$__j$09+20>>2]|0;HEAP32[$__i$012+24>>2]=HEAP32[$__j$09+24>>2]|0;HEAP16[$__i$012+28>>1]=HEAP16[$__j$09+28>>1]|0;
    $54 = ($__j$09|0)==($__first|0);
    L33: do {
     if ($54) {
      $__k$0$lcssa = $__first;
     } else {
      $__k$07 = $__j$09;
      while(1) {
       $55 = (($__k$07) + -32|0);
       $56 = (($__k$07) + -8|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = ($51|0)==($57|0);
       do {
        if ($58) {
         $60 = HEAP32[$55>>2]|0;
         $61 = ($62|0)==($60|0);
         if ($61) {
          $63 = (($__k$07) + -4|0);
          $64 = HEAP16[$63>>1]|0;
          $65 = ($53<<16>>16)==($64<<16>>16);
          if (!($65)) {
           $66 = ($53&65535)>($64&65535);
           if ($66) {
            break;
           } else {
            $__k$0$lcssa = $__k$07;
            break L33;
           }
          }
         }
         $67 = ($62>>>0)<($60>>>0);
         if (!($67)) {
          $__k$0$lcssa = $__k$07;
          break L33;
         }
        } else {
         $59 = ($51>>>0)<($57>>>0);
         if (!($59)) {
          $__k$0$lcssa = $__k$07;
          break L33;
         }
        }
       } while(0);
       ;HEAP32[$__k$07+0>>2]=HEAP32[$55+0>>2]|0;HEAP32[$__k$07+4>>2]=HEAP32[$55+4>>2]|0;HEAP32[$__k$07+8>>2]=HEAP32[$55+8>>2]|0;HEAP32[$__k$07+12>>2]=HEAP32[$55+12>>2]|0;HEAP32[$__k$07+16>>2]=HEAP32[$55+16>>2]|0;HEAP32[$__k$07+20>>2]=HEAP32[$55+20>>2]|0;HEAP32[$__k$07+24>>2]=HEAP32[$55+24>>2]|0;HEAP16[$__k$07+28>>1]=HEAP16[$55+28>>1]|0;
       $68 = ($55|0)==($__first|0);
       if ($68) {
        $__k$0$lcssa = $__first;
        break;
       } else {
        $__k$07 = $55;
       }
      }
     }
    } while(0);
    HEAP32[$__k$0$lcssa>>2] = $62;
    $69 = (($__k$0$lcssa) + 4|0);
    ;HEAP32[$69+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$69+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$69+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;HEAP32[$69+12>>2]=HEAP32[$__t$sroa$1+12>>2]|0;HEAP32[$69+16>>2]=HEAP32[$__t$sroa$1+16>>2]|0;
    $70 = (($__k$0$lcssa) + 24|0);
    HEAP32[$70>>2] = $51;
    $71 = (($__k$0$lcssa) + 28|0);
    HEAP16[$71>>1] = $53;
    $72 = (($__count$010) + 1)|0;
    $73 = ($72|0)==(8);
    if ($73) {
     break;
    } else {
     $__count$1 = $72;
    }
   }
   $76 = (($__i$012) + 32|0);
   $77 = ($76|0)==($__last|0);
   if ($77) {
    $$0 = 1;
    label = 32;
    break;
   } else {
    $__j$09$phi = $__i$012;$__count$010 = $__count$1;$__i$012 = $76;$__j$09 = $__j$09$phi;
   }
  }
  if ((label|0) == 32) {
   STACKTOP = sp;return ($$0|0);
  }
  $74 = (($__i$012) + 32|0);
  $75 = ($74|0)==($__last|0);
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZL24KeywordsStaticInitializev() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN8keywords6CreateEPKc(569296)|0);
 HEAP32[569280>>2] = $0;
 $1 = (__ZN8keywords6CreateEPKc(569320)|0);
 HEAP32[569288>>2] = $1;
 STACKTOP = sp;return;
}
function __ZL21KeywordsStaticDestroyv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z12SetupLODFadeR9GfxDeviceRN9ShaderLab17ShaderPassContextEf($device,$passContext,$lodFade) {
 $device = $device|0;
 $passContext = $passContext|0;
 $lodFade = Math_fround($lodFade);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fabsf = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$device>>2]|0;
 $1 = (($0) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $fabsf = (Math_fround(Math_abs((Math_fround($lodFade)))));
 FUNCTION_TABLE_vif[$2 & 255]($device,$fabsf);
 $3 = $lodFade == Math_fround(0.0);
 if ($3) {
  $4 = HEAP32[569280>>2]|0;
  $5 = $4 & 31;
  $6 = 1 << $5;
  $7 = $6 ^ -1;
  $8 = $4 >>> 5;
  $9 = ((($passContext) + ($8<<2)|0) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & $7;
  HEAP32[$9>>2] = $11;
  $12 = HEAP32[569288>>2]|0;
  $13 = $12 & 31;
  $14 = 1 << $13;
  $15 = $14 ^ -1;
  $16 = $12 >>> 5;
  $17 = ((($passContext) + ($16<<2)|0) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & $15;
  HEAP32[$17>>2] = $19;
  STACKTOP = sp;return;
 }
 $20 = $lodFade > Math_fround(0.0);
 $21 = HEAP32[569280>>2]|0;
 $22 = $21 & 31;
 $23 = 1 << $22;
 if ($20) {
  $24 = $23 ^ -1;
  $25 = $21 >>> 5;
  $26 = ((($passContext) + ($25<<2)|0) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 & $24;
  HEAP32[$26>>2] = $28;
  $29 = HEAP32[569288>>2]|0;
  $30 = $29 & 31;
  $31 = 1 << $30;
  $32 = $29 >>> 5;
  $33 = ((($passContext) + ($32<<2)|0) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $31 | $34;
  HEAP32[$33>>2] = $35;
  STACKTOP = sp;return;
 } else {
  $36 = $21 >>> 5;
  $37 = ((($passContext) + ($36<<2)|0) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38 | $23;
  HEAP32[$37>>2] = $39;
  $40 = HEAP32[569288>>2]|0;
  $41 = $40 & 31;
  $42 = 1 << $41;
  $43 = $42 ^ -1;
  $44 = $40 >>> 5;
  $45 = ((($passContext) + ($44<<2)|0) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46 & $43;
  HEAP32[$45>>2] = $47;
  STACKTOP = sp;return;
 }
}
function __ZN15SHConstantCacheC2ER13BatchRendererR15RenderLoopStats($this,$batchRenderer,$stats) {
 $this = $this|0;
 $batchRenderer = $batchRenderer|0;
 $stats = $stats|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 216|0);
 HEAP32[$0>>2] = $batchRenderer;
 $1 = (($this) + 220|0);
 HEAP32[$1>>2] = $stats;
 $2 = (($batchRenderer) + 52|0);
 _memset(($this|0),0,216)|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  __ZN13BatchRenderer5FlushEv($batchRenderer);
 }
 __Z14SetSHConstantsR28ApplyBuiltinInstancePropertyRK19SphericalHarmonics3($batchRenderer,$this);
 STACKTOP = sp;return;
}
function __Z14SetSHConstantsR13BatchRendererRK19SphericalHarmonics3($batchRenderer,$sh) {
 $batchRenderer = $batchRenderer|0;
 $sh = $sh|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($batchRenderer) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __ZN13BatchRenderer5FlushEv($batchRenderer);
 }
 __Z14SetSHConstantsR28ApplyBuiltinInstancePropertyRK19SphericalHarmonics3($batchRenderer,$sh);
 STACKTOP = sp;return;
}
function __Z14SetSHConstantsR28ApplyBuiltinInstancePropertyRK19SphericalHarmonics3($params,$sh) {
 $params = $params|0;
 $sh = $sh|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $14 = 0;
 var $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0);
 var $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0;
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0;
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $vCoeff = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $vCoeff = sp;
 $1 = HEAP8[569352>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  HEAPF32[569344>>2] = Math_fround(1.77245390415191650391);
  HEAP8[569352>>0] = 1;
 }
 $3 = Math_fround(HEAPF32[569344>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = Math_fround(Math_fround(1.0) / $4);
 $6 = Math_fround($3 * Math_fround(3.0));
 $7 = Math_fround(Math_fround(1.73205077648162841797) / $6);
 $8 = Math_fround($3 * Math_fround(8.0));
 $9 = Math_fround($3 * Math_fround(16.0));
 $10 = Math_fround(Math_fround(2.23606801033020019531) / $9);
 $11 = Math_fround(-$7);
 $12 = (($sh) + 36|0);
 $13 = (($sh) + 12|0);
 $14 = (($sh) + 24|0);
 $15 = (($sh) + 72|0);
 $16 = Math_fround(HEAPF32[$12>>2]);
 $17 = Math_fround($16 * $11);
 HEAPF32[$vCoeff>>2] = $17;
 $18 = Math_fround(HEAPF32[$13>>2]);
 $19 = Math_fround($18 * $11);
 $20 = (($vCoeff) + 4|0);
 HEAPF32[$20>>2] = $19;
 $21 = Math_fround(HEAPF32[$14>>2]);
 $22 = Math_fround($7 * $21);
 $23 = (($vCoeff) + 8|0);
 HEAPF32[$23>>2] = $22;
 $24 = Math_fround(HEAPF32[$sh>>2]);
 $25 = Math_fround($5 * $24);
 $26 = Math_fround(HEAPF32[$15>>2]);
 $27 = Math_fround($10 * $26);
 $28 = Math_fround($25 - $27);
 $29 = (($vCoeff) + 12|0);
 HEAPF32[$29>>2] = $28;
 $30 = (($12) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $11);
 $33 = (($vCoeff) + 16|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($13) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * $11);
 $37 = (($vCoeff) + 20|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($14) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($7 * $39);
 $41 = (($vCoeff) + 24|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($sh) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($5 * $43);
 $45 = (($15) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($10 * $46);
 $48 = Math_fround($44 - $47);
 $49 = (($vCoeff) + 28|0);
 HEAPF32[$49>>2] = $48;
 $50 = (($12) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $11);
 $53 = (($vCoeff) + 32|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($13) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * $11);
 $57 = (($vCoeff) + 36|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($14) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($7 * $59);
 $61 = (($vCoeff) + 40|0);
 HEAPF32[$61>>2] = $60;
 $62 = (($sh) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($5 * $63);
 $65 = (($15) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($10 * $66);
 $68 = Math_fround($64 - $67);
 $69 = (($vCoeff) + 44|0);
 HEAPF32[$69>>2] = $68;
 $70 = Math_fround(Math_fround(3.87298345565795898438) / $8);
 $71 = Math_fround($70 * Math_fround(0.5));
 $72 = (($params) + 36|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($73) + 992|0);
 ;HEAP32[$74+0>>2]=HEAP32[$vCoeff+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$vCoeff+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$vCoeff+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$vCoeff+12>>2]|0;
 HEAP32[$0>>2] = 1073741886;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($params,$0,$vCoeff);
 $75 = (($vCoeff) + 16|0);
 $76 = HEAP32[$72>>2]|0;
 $77 = (($76) + 1008|0);
 ;HEAP32[$77+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$75+12>>2]|0;
 HEAP32[$0>>2] = 1073741887;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($params,$0,$75);
 $78 = (($vCoeff) + 32|0);
 $79 = HEAP32[$72>>2]|0;
 $80 = (($79) + 1024|0);
 ;HEAP32[$80+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$80+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$80+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$80+12>>2]=HEAP32[$78+12>>2]|0;
 HEAP32[$0>>2] = 1073741888;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($params,$0,$78);
 $81 = (($sh) + 48|0);
 $82 = Math_fround(-$70);
 $83 = (($sh) + 60|0);
 $84 = Math_fround($10 * Math_fround(3.0));
 $85 = (($sh) + 84|0);
 $86 = Math_fround(HEAPF32[$81>>2]);
 $87 = Math_fround($70 * $86);
 HEAPF32[$vCoeff>>2] = $87;
 $88 = Math_fround(HEAPF32[$83>>2]);
 $89 = Math_fround($88 * $82);
 HEAPF32[$20>>2] = $89;
 $90 = Math_fround(HEAPF32[$15>>2]);
 $91 = Math_fround($84 * $90);
 HEAPF32[$23>>2] = $91;
 $92 = Math_fround(HEAPF32[$85>>2]);
 $93 = Math_fround($92 * $82);
 HEAPF32[$29>>2] = $93;
 $94 = (($81) + 4|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($70 * $95);
 HEAPF32[$33>>2] = $96;
 $97 = (($83) + 4|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($98 * $82);
 HEAPF32[$37>>2] = $99;
 $100 = Math_fround(HEAPF32[$45>>2]);
 $101 = Math_fround($84 * $100);
 HEAPF32[$41>>2] = $101;
 $102 = (($85) + 4|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($103 * $82);
 HEAPF32[$49>>2] = $104;
 $105 = (($81) + 8|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($70 * $106);
 HEAPF32[$53>>2] = $107;
 $108 = (($83) + 8|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($109 * $82);
 HEAPF32[$57>>2] = $110;
 $111 = Math_fround(HEAPF32[$65>>2]);
 $112 = Math_fround($84 * $111);
 HEAPF32[$61>>2] = $112;
 $113 = (($85) + 8|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($114 * $82);
 HEAPF32[$69>>2] = $115;
 $116 = HEAP32[$72>>2]|0;
 $117 = (($116) + 1040|0);
 ;HEAP32[$117+0>>2]=HEAP32[$vCoeff+0>>2]|0;HEAP32[$117+4>>2]=HEAP32[$vCoeff+4>>2]|0;HEAP32[$117+8>>2]=HEAP32[$vCoeff+8>>2]|0;HEAP32[$117+12>>2]=HEAP32[$vCoeff+12>>2]|0;
 HEAP32[$0>>2] = 1073741889;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($params,$0,$vCoeff);
 $118 = HEAP32[$72>>2]|0;
 $119 = (($118) + 1056|0);
 ;HEAP32[$119+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$119+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$119+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$119+12>>2]=HEAP32[$75+12>>2]|0;
 HEAP32[$0>>2] = 1073741890;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($params,$0,$75);
 $120 = HEAP32[$72>>2]|0;
 $121 = (($120) + 1072|0);
 ;HEAP32[$121+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$121+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$121+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$121+12>>2]=HEAP32[$78+12>>2]|0;
 HEAP32[$0>>2] = 1073741891;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($params,$0,$78);
 $122 = (($sh) + 96|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($71 * $123);
 HEAPF32[$vCoeff>>2] = $124;
 $125 = (($122) + 4|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($71 * $126);
 HEAPF32[$20>>2] = $127;
 $128 = (($122) + 8|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($71 * $129);
 HEAPF32[$23>>2] = $130;
 HEAPF32[$29>>2] = Math_fround(1.0);
 $131 = HEAP32[$72>>2]|0;
 $132 = (($131) + 1088|0);
 ;HEAP32[$132+0>>2]=HEAP32[$vCoeff+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$vCoeff+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$vCoeff+8>>2]|0;HEAP32[$132+12>>2]=HEAP32[$vCoeff+12>>2]|0;
 HEAP32[$0>>2] = 1073741892;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($params,$0,$vCoeff);
 STACKTOP = sp;return;
}
function __ZN20ReflectionProbeCacheC2ER13BatchRendererR15RenderLoopStats($this,$batchRenderer,$stats) {
 $this = $this|0;
 $batchRenderer = $batchRenderer|0;
 $stats = $stats|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16ReflectionSampleC2Ev($this);
 $0 = (($this) + 124|0);
 HEAP32[$0>>2] = $stats;
 $1 = (($this) + 128|0);
 HEAP32[$1>>2] = $batchRenderer;
 __Z14SetReflectionsR13BatchRendererRK16ReflectionSample($batchRenderer,$this);
 STACKTOP = sp;return;
}
function __Z14SetReflectionsR13BatchRendererRK16ReflectionSample($batchRenderer,$reflSample) {
 $batchRenderer = $batchRenderer|0;
 $reflSample = $reflSample|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $lerp = 0, $max = 0, $max1 = 0, $min = 0, $min1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy3 = sp + 92|0;
 $0 = sp + 88|0;
 $1 = sp + 84|0;
 $2 = sp + 80|0;
 $min = sp + 64|0;
 $max = sp + 32|0;
 $min1 = sp + 16|0;
 $max1 = sp;
 $lerp = sp + 48|0;
 $3 = (($batchRenderer) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  __ZN13BatchRenderer5FlushEv($batchRenderer);
 }
 $6 = (($reflSample) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($batchRenderer) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4960|0);
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($10,$$byval_copy3,4,0,0);
 HEAP32[$1>>2] = -1073741805;
 HEAP32[$2>>2] = $7;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN21MaterialPropertyBlock18AddPropertyTextureERKN9ShaderLab16FastPropertyNameE16TextureDimension9TextureID($batchRenderer,$1,4,$$byval_copy3);
 $11 = Math_fround(HEAPF32[$reflSample>>2]);
 $12 = (($reflSample) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($reflSample) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($reflSample) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = (($reflSample) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($reflSample) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 HEAPF32[$min>>2] = $14;
 $25 = (($min) + 4|0);
 HEAPF32[$25>>2] = $19;
 $26 = (($min) + 8|0);
 HEAPF32[$26>>2] = $24;
 $27 = (($min) + 12|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = Math_fround($11 + $13);
 $29 = Math_fround($16 + $18);
 $30 = Math_fround($21 + $23);
 HEAPF32[$max>>2] = $28;
 $31 = (($max) + 4|0);
 HEAPF32[$31>>2] = $29;
 $32 = (($max) + 8|0);
 HEAPF32[$32>>2] = $30;
 $33 = (($max) + 12|0);
 HEAPF32[$33>>2] = Math_fround(1.0);
 $34 = (($reflSample) + 28|0);
 $35 = HEAP32[$8>>2]|0;
 $36 = (($35) + 2304|0);
 ;HEAP32[$36+0>>2]=HEAP32[$34+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$34+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$34+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741968;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$34);
 $37 = HEAP32[$8>>2]|0;
 $38 = (($37) + 2336|0);
 ;HEAP32[$38+0>>2]=HEAP32[$min+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$min+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$min+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$min+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741970;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$min);
 $39 = HEAP32[$8>>2]|0;
 $40 = (($39) + 2320|0);
 ;HEAP32[$40+0>>2]=HEAP32[$max+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$max+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$max+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$max+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741969;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$max);
 $41 = (($reflSample) + 44|0);
 $42 = HEAP32[$8>>2]|0;
 $43 = (($42) + 2352|0);
 ;HEAP32[$43+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$41+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741971;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$41);
 $44 = (($reflSample) + 84|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$8>>2]|0;
 $47 = (($46) + 5024|0);
 HEAP32[$0>>2] = $45;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($47,$$byval_copy3,4,0,0);
 HEAP32[$1>>2] = -1073741804;
 HEAP32[$2>>2] = $45;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN21MaterialPropertyBlock18AddPropertyTextureERKN9ShaderLab16FastPropertyNameE16TextureDimension9TextureID($batchRenderer,$1,4,$$byval_copy3);
 $48 = (($reflSample) + 60|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($reflSample) + 72|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($49 - $51);
 $53 = (($reflSample) + 64|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($reflSample) + 76|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($54 - $56);
 $58 = (($reflSample) + 68|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($reflSample) + 80|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($59 - $61);
 HEAPF32[$min1>>2] = $52;
 $63 = (($min1) + 4|0);
 HEAPF32[$63>>2] = $57;
 $64 = (($min1) + 8|0);
 HEAPF32[$64>>2] = $62;
 $65 = (($min1) + 12|0);
 HEAPF32[$65>>2] = Math_fround(1.0);
 $66 = Math_fround($49 + $51);
 $67 = Math_fround($54 + $56);
 $68 = Math_fround($59 + $61);
 HEAPF32[$max1>>2] = $66;
 $69 = (($max1) + 4|0);
 HEAPF32[$69>>2] = $67;
 $70 = (($max1) + 8|0);
 HEAPF32[$70>>2] = $68;
 $71 = (($max1) + 12|0);
 HEAPF32[$71>>2] = Math_fround(1.0);
 $72 = (($reflSample) + 88|0);
 $73 = HEAP32[$8>>2]|0;
 $74 = (($73) + 2368|0);
 ;HEAP32[$74+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$72+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741972;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$72);
 $75 = HEAP32[$8>>2]|0;
 $76 = (($75) + 2400|0);
 ;HEAP32[$76+0>>2]=HEAP32[$min1+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$min1+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$min1+8>>2]|0;HEAP32[$76+12>>2]=HEAP32[$min1+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741974;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$min1);
 $77 = HEAP32[$8>>2]|0;
 $78 = (($77) + 2384|0);
 ;HEAP32[$78+0>>2]=HEAP32[$max1+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$max1+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$max1+8>>2]|0;HEAP32[$78+12>>2]=HEAP32[$max1+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741973;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$max1);
 $79 = (($reflSample) + 104|0);
 $80 = HEAP32[$8>>2]|0;
 $81 = (($80) + 2416|0);
 ;HEAP32[$81+0>>2]=HEAP32[$79+0>>2]|0;HEAP32[$81+4>>2]=HEAP32[$79+4>>2]|0;HEAP32[$81+8>>2]=HEAP32[$79+8>>2]|0;HEAP32[$81+12>>2]=HEAP32[$79+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741975;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$79);
 $82 = (($reflSample) + 120|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 HEAPF32[$lerp>>2] = $83;
 $84 = (($lerp) + 4|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 $85 = (($lerp) + 8|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 $86 = (($lerp) + 12|0);
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = HEAP32[$8>>2]|0;
 $88 = (($87) + 2432|0);
 ;HEAP32[$88+0>>2]=HEAP32[$lerp+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$lerp+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$lerp+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$lerp+12>>2]|0;
 HEAP32[$$byval_copy3>>2] = 1073741976;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($batchRenderer,$$byval_copy3,$lerp);
 STACKTOP = sp;return;
}
function __ZN15LightmapSTCacheC2ER13BatchRendererR15RenderLoopStats($this,$apply,$stats) {
 $this = $this|0;
 $apply = $apply|0;
 $stats = $stats|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $identityLightmapST$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $identityLightmapST$i = sp;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $apply;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $stats;
 HEAPF32[$identityLightmapST$i>>2] = Math_fround(1.0);
 $3 = (($identityLightmapST$i) + 4|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($identityLightmapST$i) + 8|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($identityLightmapST$i) + 12|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($identityLightmapST$i) + 16|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($identityLightmapST$i) + 20|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($identityLightmapST$i) + 24|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($identityLightmapST$i) + 28|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($apply) + 52|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  __ZN13BatchRenderer5FlushEv($apply);
 }
 $13 = (($apply) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 960|0);
 ;HEAP32[$15+0>>2]=HEAP32[$identityLightmapST$i+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$identityLightmapST$i+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$identityLightmapST$i+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$identityLightmapST$i+12>>2]|0;
 HEAP32[$0>>2] = 1073741884;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($apply,$0,$identityLightmapST$i);
 $16 = HEAP32[$13>>2]|0;
 $17 = (($16) + 976|0);
 ;HEAP32[$17+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$6+12>>2]|0;
 HEAP32[$0>>2] = 1073741885;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($apply,$0,$6);
 HEAP8[$this>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN15LightmapSTCache5ApplyER12BaseRenderer($this,$renderer) {
 $this = $this|0;
 $renderer = $renderer|0;
 var $$off$i$i$i = 0, $$off$i1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $identityLightmapST$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $identityLightmapST$i = sp;
 $1 = (($renderer) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2&65535;
 $$off$i$i$i = (($3) + -254)<<16>>16;
 $4 = ($$off$i$i$i&65535)>(1);
 if ($4) {
  label = 3;
 } else {
  $5 = $2 >>> 16;
  $6 = $5&65535;
  $$off$i1$i$i = (($6) + -254)<<16>>16;
  $7 = ($$off$i1$i$i&65535)>(1);
  if ($7) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $8 = HEAP32[$renderer>>2]|0;
  $9 = (($8) + 52|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($renderer)|0);
  $12 = ($11|0)==(0);
  if ($12) {
   $13 = (($this) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0);
   if (!($17)) {
    __ZN13BatchRenderer5FlushEv($14);
   }
   $18 = (($renderer) + 4|0);
   $19 = (($14) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 960|0);
   ;HEAP32[$21+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$18+12>>2]|0;
   HEAP32[$0>>2] = 1073741884;
   __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($14,$0,$18);
   $22 = (($renderer) + 20|0);
   $23 = HEAP32[$19>>2]|0;
   $24 = (($23) + 976|0);
   ;HEAP32[$24+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$22+12>>2]|0;
   HEAP32[$0>>2] = 1073741885;
   __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($14,$0,$22);
   HEAP8[$this>>0] = 0;
   STACKTOP = sp;return;
  }
 }
 $25 = HEAP8[$this>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if (!($26)) {
  STACKTOP = sp;return;
 }
 HEAPF32[$identityLightmapST$i>>2] = Math_fround(1.0);
 $27 = (($identityLightmapST$i) + 4|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($identityLightmapST$i) + 8|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($identityLightmapST$i) + 12|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($identityLightmapST$i) + 16|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($identityLightmapST$i) + 20|0);
 HEAPF32[$31>>2] = Math_fround(1.0);
 $32 = (($identityLightmapST$i) + 24|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($identityLightmapST$i) + 28|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($this) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 52|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if (!($38)) {
  __ZN13BatchRenderer5FlushEv($35);
 }
 $39 = (($35) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 960|0);
 ;HEAP32[$41+0>>2]=HEAP32[$identityLightmapST$i+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$identityLightmapST$i+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$identityLightmapST$i+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$identityLightmapST$i+12>>2]|0;
 HEAP32[$0>>2] = 1073741884;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($35,$0,$identityLightmapST$i);
 $42 = HEAP32[$39>>2]|0;
 $43 = (($42) + 976|0);
 ;HEAP32[$43+0>>2]=HEAP32[$30+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$30+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$30+12>>2]|0;
 HEAP32[$0>>2] = 1073741885;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($35,$0,$30);
 HEAP8[$this>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN15LightmapSTCache18ApplyFixedFunctionER12BaseRendererR9GfxDevice($this,$renderer,$device) {
 $this = $this|0;
 $renderer = $renderer|0;
 $device = $device|0;
 var $$off$i$i$i = 0, $$off$i1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($renderer) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2&65535;
 $$off$i$i$i = (($3) + -254)<<16>>16;
 $4 = ($$off$i$i$i&65535)>(1);
 if ($4) {
  label = 4;
 } else {
  $5 = $2 >>> 16;
  $6 = $5&65535;
  $$off$i1$i$i = (($6) + -254)<<16>>16;
  $7 = ($$off$i1$i$i&65535)>(1);
  if ($7) {
   label = 4;
  } else {
   $8 = HEAP32[$device>>2]|0;
   $9 = (($8) + 132|0);
   $10 = HEAP32[$9>>2]|0;
   $23 = $10;
  }
 }
 if ((label|0) == 4) {
  $11 = HEAP32[$renderer>>2]|0;
  $12 = (($11) + 52|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_ii[$13 & 4095]($renderer)|0);
  $15 = ($14|0)==(0);
  $16 = HEAP32[$device>>2]|0;
  $17 = (($16) + 132|0);
  $18 = HEAP32[$17>>2]|0;
  if ($15) {
   $19 = (($renderer) + 4|0);
   FUNCTION_TABLE_vii[$18 & 4095]($device,$19);
   STACKTOP = sp;return;
  } else {
   $23 = $18;
  }
 }
 HEAPF32[$0>>2] = Math_fround(1.0);
 $20 = (($0) + 4|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($0) + 8|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($0) + 12|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 FUNCTION_TABLE_vii[$23 & 4095]($device,$0);
 STACKTOP = sp;return;
}
function __ZN12BaseRendererC2E12RendererType($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((569360 + 8|0));
 $0 = (($this) + 40|0);
 $1 = $type&255;
 HEAP8[$0>>0] = $1;
 $2 = (($this) + 41|0);
 HEAP8[$2>>0] = 1;
 $3 = (($this) + 42|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 43|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 44|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 48|0);
 HEAP8[$6>>0] = 1;
 $7 = (($this) + 49|0);
 HEAP8[$7>>0] = 1;
 $8 = (($this) + 116|0);
 dest=$8+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $9 = (($this) + 168|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 172|0);
 HEAP32[$10>>2] = -2147450880;
 $11 = (($this) + 176|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 180|0);
 HEAP32[$12>>2] = -1;
 $13 = (($this) + 184|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 36|0);
 $15 = (($14) + 2|0);
 HEAP16[$15>>1] = 255;
 HEAP16[$14>>1] = 255;
 $16 = (($this) + 4|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($this) + 8|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($this) + 12|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 16|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($this) + 20|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($this) + 24|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 28|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 32|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN12BaseRendererD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN12BaseRendererD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12BaseRenderer12GetWorldAABBER4AABB($this,$aabb) {
 $this = $this|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($this) + 49|0);
 if ($2) {
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if (!($5)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $6 = HEAP32[$this>>2]|0;
  $7 = (($6) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vi[$8 & 4095]($this);
  HEAP8[$0>>0] = 0;
  HEAP8[$3>>0] = 0;
 }
 $9 = (($this) + 116|0);
 ;HEAP32[$aabb+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$aabb+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$aabb+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$aabb+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$aabb+16>>2]=HEAP32[$9+16>>2]|0;HEAP32[$aabb+20>>2]=HEAP32[$9+20>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK12BaseRenderer19GetLightmapIndexIntE12LightmapType($this,$lightmapType) {
 $this = $this|0;
 $lightmapType = $lightmapType|0;
 var $$$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = (($0) + ($lightmapType<<1)|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(255);
 $4 = $2&65535;
 $$$i = $3 ? -1 : $4;
 STACKTOP = sp;return ($$$i|0);
}
function __ZN12BaseRenderer26SetLightmapIndexIntNoDirtyEi12LightmapType($this,$index,$lightmapType) {
 $this = $this|0;
 $index = $index|0;
 $lightmapType = $lightmapType|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 36|0);
 $2 = (($1) + ($lightmapType<<1)|0);
 $3 = ($index|0)==(-1);
 if ($3) {
  HEAP16[$2>>1] = 255;
  STACKTOP = sp;return;
 }
 $4 = ($index>>>0)>(255);
 if (!($4)) {
  $26 = $index&65535;
  HEAP16[$2>>1] = $26;
  STACKTOP = sp;return;
 }
 HEAP16[$2>>1] = 255;
 HEAP32[$vararg_buffer>>2] = 255;
 __Z6FormatPKcz($0,569432,$vararg_buffer);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (($0) + 1|0);
  $11 = $10;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($11|0),0,(569472|0),60,1,0,0,(0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP8[$0>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   ___resumeException($19|0);
   // unreachable;
  }
  $24 = (($0) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  __ZdlPv($25);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   STACKTOP = sp;return;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  STACKTOP = sp;return;
 }
}
function __ZNK12BaseRenderer14AllowsBatchingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN12BaseRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns($this,$renderData,$channels) {
 $this = $this|0;
 $renderData = $renderData|0;
 $channels = $channels|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12BaseRenderer21RendererBecameVisibleEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 43|0);
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN12BaseRenderer23RendererBecameInvisibleEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 43|0);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK12BaseRenderer15GetSortingFudgeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return Math_fround(0.0);
}
function __ZNK12BaseRenderer14GetSubsetIndexEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($i|0);
}
function __ZNK12BaseRenderer19GetStaticBatchIndexEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK12BaseRenderer14GetMeshIDSmallEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK12BaseRenderer23GetDistanceSortPriorityEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6Camera15InitializeClassEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(20,564104,1670,0);
 __Z27RegisterAllowNameConversionPKcS0_S0_(570920,569576,569600);
 $0 = (__ZN8keywords6CreateEPKc(569616)|0);
 HEAP32[569640>>2] = $0;
 $1 = (__ZN8keywords6CreateEPKc(569648)|0);
 HEAP32[569664>>2] = $1;
 STACKTOP = sp;return;
}
function __ZZN6Camera15InitializeClassEvEN36FunctorImpl_Camera_kTransformChanged4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($object) + 608|0);
 HEAP8[$2>>0] = 1;
 $3 = (($object) + 610|0);
 HEAP8[$3>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN6CameraC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$1 = 0, $$13 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $scevgep = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy1,$mode);
 $3 = (($this) + 28|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 29|0);
 HEAP8[$4>>0] = 0;
 HEAP32[$this>>2] = ((569672 + 8|0));
 $5 = (($this) + 32|0);
 $6 = (($this) + 160|0);
 $7 = (($this) + 292|0);
 $8 = (($this) + 296|0);
 $9 = (($this) + 96|0);
 $10 = (($this) + 224|0);
 $11 = (($this) + 332|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 340|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 344|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 352|0);
 $15 = (($this) + 360|0);
 $16 = (($this) + 396|0);
 ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
 $17 = (($this) + 424|0);
 $18 = (($this) + 436|0);
 $19 = (($this) + 604|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 608|0);
 dest=$7+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;HEAP32[$14+16>>2]=0|0;
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;HEAP32[$17+16>>2]=0|0;HEAP32[$17+20>>2]=0|0;
 $21 = (($this) + 623|0);
 HEAP8[$20>>0]=16843009&255;HEAP8[$20+1>>0]=(16843009>>8)&255;HEAP8[$20+2>>0]=(16843009>>16)&255;HEAP8[$20+3>>0]=16843009>>24;
 HEAP8[$21>>0] = 0;
 $22 = (($this) + 636|0);
 __THREW__ = 0;
 invoke_vi(3408,($22|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  $$1 = $42;$$13 = $43;
 } else {
  __THREW__ = 0;
  $25 = (invoke_ii(3222,($this|0))|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   $28 = (($this) + 288|0);
   HEAP32[$28>>2] = $25;
   $29 = (($this) + 412|0);
   HEAP32[$29>>2] = -1;
   $30 = (($this) + 416|0);
   HEAP32[$30>>2] = -1;
   $scevgep = (($this) + 468|0);
   dest=$scevgep+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $31 = (($this) + 618|0);
   HEAP8[$31>>0] = 0;
   $32 = (($this) + 600|0);
   HEAP32[$32>>2] = 0;
   $33 = (($this) + 612|0);
   $34 = (($this) + 619|0);
   HEAP8[$33>>0]=16843009&255;HEAP8[$33+1>>0]=(16843009>>8)&255;HEAP8[$33+2>>0]=(16843009>>16)&255;HEAP8[$33+3>>0]=16843009>>24;
   HEAP8[$34>>0]=0&255;HEAP8[$34+1>>0]=(0>>8)&255;HEAP8[$34+2>>0]=(0>>16)&255;HEAP8[$34+3>>0]=0>>24;
   ;HEAP32[$17+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[616680+8>>2]|0;
   ;HEAP32[$18+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[616680+8>>2]|0;
   dest=$10+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   _memmove(($9|0),(616552|0),64)|0;
   dest=$6+0|0; src=$9+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   dest=$5+0|0; src=$9+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $35 = (($this) + 348|0);
   HEAP32[$35>>2] = 0;
   $36 = (($this) + 617|0);
   HEAP8[$36>>0] = 1;
   $37 = (($this) + 336|0);
   HEAP32[$37>>2] = 0;
   $38 = (($this) + 328|0);
   HEAP32[$38>>2] = 1;
   ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;HEAP32[$8+28>>2]=0|0;
   __THREW__ = 0;
   $39 = (invoke_i(71)|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    $44 = HEAP32[$39>>2]|0;
    $45 = (($44) + 432|0);
    $46 = HEAP32[$45>>2]|0;
    __THREW__ = 0;
    $47 = (invoke_ii($46|0,($39|0))|0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if (!($49)) {
     $50 = (($this) + 296|0);
     HEAP32[$50>>2] = $47;
     __THREW__ = 0;
     $51 = (invoke_i(71)|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      $54 = HEAP32[$51>>2]|0;
      $55 = (($54) + 436|0);
      $56 = HEAP32[$55>>2]|0;
      __THREW__ = 0;
      $57 = (invoke_ii($56|0,($51|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       HEAP32[$11>>2] = $57;
       __THREW__ = 0;
       $60 = (invoke_ii(3223,($this|0))|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if (!($62)) {
        HEAP32[$1>>2] = $60;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
        $63 = (invoke_iiiiiii(103,32,($$byval_copy1|0),0,16,(569816|0),140)|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if (!($65)) {
         HEAP32[$63>>2] = 0;
         $66 = (($63) + 8|0);
         HEAP32[$66>>2] = 0;
         $67 = (($63) + 12|0);
         HEAP32[$67>>2] = 0;
         $68 = (($63) + 4|0);
         HEAP32[$68>>2] = 61;
         $69 = (($63) + 16|0);
         HEAP32[$69>>2] = 0;
         $70 = (($63) + 24|0);
         HEAP32[$70>>2] = 0;
         $71 = (($63) + 28|0);
         HEAP32[$71>>2] = 0;
         $72 = (($63) + 20|0);
         HEAP32[$72>>2] = 61;
         $73 = (($this) + 372|0);
         HEAP32[$73>>2] = $63;
         $74 = (($this) + 624|0);
         HEAPF32[$74>>2] = Math_fround(0.0219999998807907104492);
         $75 = (($this) + 628|0);
         HEAPF32[$75>>2] = Math_fround(10.0);
         $76 = (($this) + 632|0);
         HEAP32[$76>>2] = 0;
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
  $77 = ___cxa_find_matching_catch()|0;
  $78 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3409,($22|0));
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if ($80) {
   $88 = ___cxa_find_matching_catch(0|0)|0;
   $89 = tempRet0;
   ___clang_call_terminate($88);
   // unreachable;
  } else {
   $$1 = $77;$$13 = $78;
  }
 }
 $81 = HEAP8[$15>>0]|0;
 $82 = $81 & 1;
 $83 = ($82<<24>>24)==(0);
 if (!($83)) {
  $84 = (($this) + 368|0);
  $85 = HEAP32[$84>>2]|0;
  __ZdlPv($85);
 }
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $86 = __THREW__; __THREW__ = 0;
 $87 = $86&1;
 if ($87) {
  $88 = ___cxa_find_matching_catch(0|0)|0;
  $89 = tempRet0;
  ___clang_call_terminate($88);
  // unreachable;
 } else {
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZN6Camera5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 396|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 400|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 404|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 408|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 380|0);
 HEAPF32[$4>>2] = Math_fround(0.192156866192817687988);
 $5 = (($this) + 384|0);
 HEAPF32[$5>>2] = Math_fround(0.301960796117782592773);
 $6 = (($this) + 388|0);
 HEAPF32[$6>>2] = Math_fround(0.474509805440902709961);
 $7 = (($this) + 392|0);
 HEAPF32[$7>>2] = Math_fround(0.0196078438311815261841);
 $8 = (($this) + 420|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 456|0);
 HEAPF32[$9>>2] = Math_fround(0.300000011920928955078);
 $10 = (($this) + 460|0);
 HEAPF32[$10>>2] = Math_fround(1000.0);
 $11 = (($this) + 464|0);
 HEAP32[$11>>2] = -1;
 $12 = (($this) + 596|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($this) + 616|0);
 HEAP8[$13>>0] = 0;
 $14 = (($this) + 619|0);
 HEAP8[$14>>0] = 0;
 $15 = (($this) + 600|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 448|0);
 HEAPF32[$16>>2] = Math_fround(5.0);
 $17 = (($this) + 452|0);
 HEAPF32[$17>>2] = Math_fround(60.0);
 $18 = (($this) + 376|0);
 HEAP32[$18>>2] = 1;
 $19 = (($this) + 610|0);
 HEAP8[$19>>0] = 1;
 $20 = (($this) + 609|0);
 HEAP8[$20>>0] = 1;
 $21 = (($this) + 608|0);
 HEAP8[$21>>0] = 1;
 $22 = (($this) + 352|0);
 HEAP32[$22>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6Camera16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component16CheckConsistencyEv($this);
 $0 = (($this) + 464|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<(-1);
 if ($2) {
  $$0$i = -1;
 } else {
  $3 = ($1|0)>(3);
  $$$i = $3 ? 3 : $1;
  $$0$i = $$$i;
 }
 HEAP32[$0>>2] = $$0$i;
 $4 = (($this) + 616|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $7 = (($this) + 456|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $8 < Math_fround(0.00999999977648258209228);
 $or$cond = $6 & $9;
 if ($or$cond) {
  HEAPF32[$7>>2] = Math_fround(0.00999999977648258209228);
  $13 = Math_fround(0.00999999977648258209228);
 } else {
  $13 = $8;
 }
 $10 = (($this) + 460|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($13 + Math_fround(0.00999999977648258209228));
 $14 = $11 < $12;
 if (!($14)) {
  STACKTOP = sp;return;
 }
 HEAPF32[$10>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN6Camera15ThreadedCleanupEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 372|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK6Object14GetMemoryLabelEv($this)|0);
 $6 = ($4|0)==(0|0);
 if (!($6)) {
  $7 = (($4) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)>(-1);
  do {
   if ($9) {
    $10 = (($4) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($4) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$1>>2] = $13;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($11|0),($$byval_copy3|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     HEAP32[$10>>2] = 0;
     break;
    }
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $24 = (($4) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)>(-1);
    if (!($26)) {
     ___resumeException($22|0);
     // unreachable;
    }
    $27 = HEAP32[$4>>2]|0;
    $28 = (($4) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$0>>2] = $29;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy3|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     $32 = ___cxa_find_matching_catch(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    }
    HEAP32[$4>>2] = 0;
    ___resumeException($22|0);
    // unreachable;
   }
  } while(0);
  $16 = (($4) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)>(-1);
  if ($18) {
   $19 = HEAP32[$4>>2]|0;
   $20 = (($4) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$0>>2] = $21;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy3);
   HEAP32[$4>>2] = 0;
  }
 }
 HEAP32[$2>>2] = $5;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($4,$$byval_copy3);
 HEAP32[$3>>2] = 0;
 $34 = (($this) + 288|0);
 $35 = HEAP32[$34>>2]|0;
 __Z16DeleteRenderLoopP10RenderLoop($35);
 STACKTOP = sp;return;
}
function __ZN6Camera17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i1 = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 636|0);
 __ZN19RenderEventsContext23RemoveAllCommandBuffersEv($2);
 $3 = (($this) + 292|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  __ZN6Camera21CleanupAfterRenderingEv($this);
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $4;
 $6 = HEAP32[560624>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  label = 10;
 } else {
  $8 = (($6) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  do {
   if ($12) {
    $13 = (($6) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($6) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + ($16<<3)|0);
    $33 = $17;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$6,$1);
    $18 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $19 = ($18|0)==(-1);
    $20 = (($6) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    if ($19) {
     $22 = (($6) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($21) + ($23<<3)|0);
     $33 = $24;
     break;
    } else {
     $25 = (($21) + ($18<<3)|0);
     $33 = $25;
     break;
    }
   }
  } while(0);
  $26 = HEAP32[560624>>2]|0;
  $27 = (($26) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + ($30<<3)|0);
  $32 = ($33|0)==($31|0);
  if ($32) {
   label = 10;
  } else {
   $34 = (($33) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 10;
   }
  }
 }
 if ((label|0) == 10) {
  $37 = HEAP32[$3>>2]|0;
  $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   __ZN6Camera21CleanupAfterRenderingEv($this);
   STACKTOP = sp;return;
  }
 }
 $40 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $40;
 $41 = HEAP32[560624>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  label = 19;
 } else {
  $43 = (($41) + 36|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($41) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($44|0)==($46|0);
  do {
   if ($47) {
    $48 = (($41) + 28|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($41) + 32|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($49) + ($51<<3)|0);
    $68 = $52;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$41,$0);
    $53 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $54 = ($53|0)==(-1);
    $55 = (($41) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    if ($54) {
     $57 = (($41) + 32|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($56) + ($58<<3)|0);
     $68 = $59;
     break;
    } else {
     $60 = (($56) + ($53<<3)|0);
     $68 = $60;
     break;
    }
   }
  } while(0);
  $61 = HEAP32[560624>>2]|0;
  $62 = (($61) + 28|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($61) + 32|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($63) + ($65<<3)|0);
  $67 = ($68|0)==($66|0);
  if ($67) {
   label = 19;
  } else {
   $69 = (($68) + 4|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==(0|0);
   if ($71) {
    label = 19;
   } else {
    $temp$0$i5 = $70;
   }
  }
 }
 if ((label|0) == 19) {
  $72 = HEAP32[$3>>2]|0;
  $73 = (__Z31ReadObjectFromPersistentManageri($72)|0);
  $temp$0$i5 = $73;
 }
 __ZN13RenderTexture7ReleaseEv($temp$0$i5);
 __ZN6Camera21CleanupAfterRenderingEv($this);
 STACKTOP = sp;return;
}
function __ZN6Camera21CleanupAfterRenderingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 636|0);
 __ZN19RenderEventsContext14ReleaseTempRTsEv($0);
 $1 = (($this) + 372|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN21IntermediateRenderers5ClearEj($2,0);
 $3 = (($this) + 288|0);
 $4 = HEAP32[$3>>2]|0;
 __Z22CleanupAfterRenderLoopR10RenderLoop($4);
 $5 = (($this) + 340|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (__Z22GetRenderBufferManagerv()|0);
  $9 = HEAP32[$5>>2]|0;
  __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($8,$9);
  HEAP32[$5>>2] = 0;
 }
 $10 = (($this) + 344|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (__Z22GetRenderBufferManagerv()|0);
 $14 = HEAP32[$10>>2]|0;
 __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($13,$14);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6Camera13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 $0 = $awakeMode & 1;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($this) + 29|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   $5 = (__Z16GetRenderManagerv()|0);
   __ZN13RenderManager12RemoveCameraEP6Camera($5,$this);
   $6 = (__Z16GetRenderManagerv()|0);
   __ZN13RenderManager9AddCameraEP6Camera($6,$this);
  }
 }
 $7 = (($this) + 610|0);
 HEAP8[$7>>0] = 1;
 $8 = (($this) + 609|0);
 HEAP8[$8>>0] = 1;
 $9 = (($this) + 608|0);
 HEAP8[$9>>0] = 1;
 __ZN6Camera20WindowSizeHasChangedEv($this);
 $10 = (($this) + 619|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 __ZNK6Camera18DisplayHDRWarningsEv($this);
 STACKTOP = sp;return;
}
function __ZN6Camera20WindowSizeHasChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $screenRect$i$i$i = 0, $storemerge$i$i$i$i = Math_fround(0), $storemerge1$i$i$i$i = Math_fround(0), $x2$0$i$i$i$i = Math_fround(0), $y2$0$i$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $screenRect$i$i$i = sp;
 $0 = (($this) + 615|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZL19GetCameraTargetRectRK6Camerab($screenRect$i$i$i,$this,1);
 $3 = (($this) + 396|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 400|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 404|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 408|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($screenRect$i$i$i) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($screenRect$i$i$i) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($4 * $12);
 $16 = Math_fround($8 * $12);
 $17 = Math_fround($6 * $14);
 $18 = Math_fround($10 * $14);
 $19 = Math_fround(HEAPF32[$screenRect$i$i$i>>2]);
 $20 = (($screenRect$i$i$i) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($15 + $19);
 $23 = Math_fround($17 + $21);
 $24 = Math_fround($16 + $22);
 $25 = Math_fround($18 + $23);
 $26 = Math_fround($12 + $19);
 $27 = Math_fround($14 + $21);
 $28 = $22 < $19;
 $29 = $28 ? $19 : $22;
 $30 = $24 > $26;
 $x2$0$i$i$i$i = $30 ? $26 : $24;
 $31 = $23 < $21;
 $32 = $31 ? $21 : $23;
 $33 = $25 > $27;
 $y2$0$i$i$i$i = $33 ? $27 : $25;
 $34 = Math_fround($x2$0$i$i$i$i - $29);
 $35 = Math_fround($y2$0$i$i$i$i - $32);
 $36 = $35 < Math_fround(0.0);
 $storemerge$i$i$i$i = $36 ? Math_fround(0.0) : $35;
 $37 = $storemerge$i$i$i$i != Math_fround(0.0);
 if ($37) {
  $38 = $34 < Math_fround(0.0);
  $storemerge1$i$i$i$i = $38 ? Math_fround(0.0) : $34;
  $39 = Math_fround($storemerge1$i$i$i$i / $storemerge$i$i$i$i);
  $40 = (($this) + 596|0);
  HEAPF32[$40>>2] = $39;
 } else {
  $41 = (($this) + 596|0);
  HEAPF32[$41>>2] = Math_fround(1.0);
 }
 $42 = (($this) + 609|0);
 HEAP8[$42>>0] = 1;
 $43 = (($this) + 610|0);
 HEAP8[$43>>0] = 1;
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK6Camera18DisplayHDRWarningsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetQualitySettingsv()|0);
 $1 = (($0) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*96)|0)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(0);
 if ($7) {
  $8 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
  $9 = ($8|0)==(1);
  if ($9) {
   $10 = ($this|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    $11 = (($this) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = $12;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(570440,0,569816,2648,512,$13,0,0);
  }
 }
 $14 = (__Z12GetGfxDevicev()|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 676|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($14)|0);
 $19 = ((640792 + ($18)|0) + 201|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = (__Z16GetBuildSettingsv()|0);
  $23 = (($22) + 92|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if ($25) {
   label = 8;
  }
 }
 if ((label|0) == 8) {
  $26 = ($this|0)==(0|0);
  if ($26) {
   $29 = 0;
  } else {
   $27 = (($this) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $28;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(570632,0,569816,2650,512,$29,0,0);
 }
 $30 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
 $31 = ($30|0)==(3);
 $32 = HEAP8[((640792 + 124|0))>>0]|0;
 $33 = ($32<<24>>24)==(0);
 $or$cond = $31 & $33;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $34 = ($this|0)==(0|0);
 if ($34) {
  $37 = 0;
 } else {
  $35 = (($this) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = $36;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(570744,0,569816,2652,512,$37,0,0);
 STACKTOP = sp;return;
}
function __ZN6Camera12AddToManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Z16GetRenderManagerv()|0);
 __ZN13RenderManager9AddCameraEP6Camera($1,$this);
 __ZN6Camera20WindowSizeHasChangedEv($this);
 $2 = (($this) + 436|0);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($4)|0);
 __ZNK9Transform11GetPositionEv($0,$5);
 ;HEAP32[$2+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$0+8>>2]|0;
 $6 = (($this) + 424|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 428|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 432|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN6Camera17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetRenderManagerv()|0);
 __ZN13RenderManager12RemoveCameraEP6Camera($0,$this);
 STACKTOP = sp;return;
}
function __ZNK6Camera13GetCameraRectEb($agg$result,$this,$zeroOrigin) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $zeroOrigin = $zeroOrigin|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $screenRect = 0, $storemerge$i = Math_fround(0), $storemerge1$i = Math_fround(0), $x2$0$i = Math_fround(0), $y2$0$i = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $screenRect = sp;
 __ZL19GetCameraTargetRectRK6Camerab($screenRect,$this,$zeroOrigin);
 $0 = (($this) + 396|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (($screenRect) + 8|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($screenRect) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$agg$result>>2]);
 $6 = Math_fround($2 * $5);
 $7 = (($agg$result) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($2 * $8);
 HEAPF32[$7>>2] = $9;
 $10 = (($agg$result) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($4 * $11);
 $13 = (($agg$result) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($4 * $14);
 HEAPF32[$13>>2] = $15;
 $16 = Math_fround(HEAPF32[$screenRect>>2]);
 $17 = (($screenRect) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 + $6);
 HEAPF32[$agg$result>>2] = $19;
 $20 = Math_fround($18 + $12);
 HEAPF32[$10>>2] = $20;
 $21 = Math_fround($19 + $9);
 $22 = Math_fround($20 + $15);
 $23 = Math_fround($16 + $2);
 $24 = Math_fround($18 + $4);
 $25 = $19 < $16;
 if ($25) {
  HEAPF32[$agg$result>>2] = $16;
  $30 = $16;
 } else {
  $30 = $19;
 }
 $26 = $21 > $23;
 $x2$0$i = $26 ? $23 : $21;
 $27 = $20 < $18;
 if ($27) {
  HEAPF32[$10>>2] = $18;
  $33 = $18;
 } else {
  $33 = $20;
 }
 $28 = $22 > $24;
 $y2$0$i = $28 ? $24 : $22;
 $29 = Math_fround($x2$0$i - $30);
 $31 = $29 < Math_fround(0.0);
 $storemerge1$i = $31 ? Math_fround(0.0) : $29;
 HEAPF32[$7>>2] = $storemerge1$i;
 $32 = Math_fround($y2$0$i - $33);
 $34 = $32 < Math_fround(0.0);
 $storemerge$i = $34 ? Math_fround(0.0) : $32;
 HEAPF32[$13>>2] = $storemerge$i;
 STACKTOP = sp;return;
}
function __ZL19GetCameraTargetRectRK6Camerab($agg$result,$camera,$zeroOrigin) {
 $agg$result = $agg$result|0;
 $camera = $camera|0;
 $zeroOrigin = $zeroOrigin|0;
 var $$ = Math_fround(0), $$1 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $9 = 0, $pos$i$i$i$i$i = 0, $temp$0$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($camera) + 292|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if (!($3)) {
   HEAP32[$0>>2] = $2;
   $4 = HEAP32[560624>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    label = 10;
   } else {
    $6 = (($4) + 36|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($4) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($7|0)==($9|0);
    do {
     if ($10) {
      $11 = (($4) + 28|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = (($4) + 32|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($12) + ($14<<3)|0);
      $31 = $15;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$4,$0);
      $16 = HEAP32[$pos$i$i$i$i$i>>2]|0;
      $17 = ($16|0)==(-1);
      $18 = (($4) + 28|0);
      $19 = HEAP32[$18>>2]|0;
      if ($17) {
       $20 = (($4) + 32|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($19) + ($21<<3)|0);
       $31 = $22;
       break;
      } else {
       $23 = (($19) + ($16<<3)|0);
       $31 = $23;
       break;
      }
     }
    } while(0);
    $24 = HEAP32[560624>>2]|0;
    $25 = (($24) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + 32|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + ($28<<3)|0);
    $30 = ($31|0)==($29|0);
    if ($30) {
     label = 10;
    } else {
     $32 = (($31) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      label = 10;
     } else {
      $temp$0$i$i3 = $33;
     }
    }
   }
   if ((label|0) == 10) {
    $35 = HEAP32[$1>>2]|0;
    $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
    $37 = ($36|0)==(0|0);
    if ($37) {
     break;
    } else {
     $temp$0$i$i3 = $36;
    }
   }
   $38 = (($temp$0$i$i3) + 100|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (Math_fround(($39|0)));
   $41 = (($temp$0$i$i3) + 104|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (Math_fround(($42|0)));
   HEAPF32[$agg$result>>2] = Math_fround(0.0);
   $44 = (($agg$result) + 8|0);
   HEAPF32[$44>>2] = $40;
   $45 = (($agg$result) + 4|0);
   HEAPF32[$45>>2] = Math_fround(0.0);
   $46 = (($agg$result) + 12|0);
   HEAPF32[$46>>2] = $43;
   STACKTOP = sp;return;
  }
 } while(0);
 $47 = (($camera) + 296|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if (!($49)) {
  $50 = (($48) + 23|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = ($51<<24>>24)==(0);
  if ($52) {
   $53 = (($48) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (Math_fround(($54>>>0)));
   $56 = (($48) + 8|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (Math_fround(($57>>>0)));
   HEAPF32[$agg$result>>2] = Math_fround(0.0);
   $59 = (($agg$result) + 8|0);
   HEAPF32[$59>>2] = $55;
   $60 = (($agg$result) + 4|0);
   HEAPF32[$60>>2] = Math_fround(0.0);
   $61 = (($agg$result) + 12|0);
   HEAPF32[$61>>2] = $58;
   STACKTOP = sp;return;
  }
 }
 $62 = (__Z16GetRenderManagerv()|0);
 $63 = (($62) + 56|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($62) + 60|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($62) + 64|0);
 $68 = $67;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $$ = $zeroOrigin ? Math_fround(0.0) : $66;
 $$1 = $zeroOrigin ? Math_fround(0.0) : $64;
 HEAPF32[$agg$result>>2] = $$1;
 $74 = (($agg$result) + 4|0);
 HEAPF32[$74>>2] = $$;
 $75 = (($agg$result) + 8|0);
 $76 = $75;
 $77 = $76;
 HEAP32[$77>>2] = $70;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $73;
 STACKTOP = sp;return;
}
function __ZNK6Camera24GetScreenViewportRectIntEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $screenRect$i$i = 0, $storemerge$i$i$i = Math_fround(0), $storemerge1$i$i$i = Math_fround(0), $x2$0$i$i$i = Math_fround(0);
 var $y2$0$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $screenRect$i$i = sp + 16|0;
 $0 = sp;
 __ZL19GetCameraTargetRectRK6Camerab($screenRect$i$i,$this,1);
 $1 = (($this) + 396|0);
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($screenRect$i$i) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($screenRect$i$i) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$0>>2]);
 $7 = Math_fround($3 * $6);
 $8 = (($0) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($3 * $9);
 HEAPF32[$8>>2] = $10;
 $11 = (($0) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($5 * $12);
 $14 = (($0) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($5 * $15);
 HEAPF32[$14>>2] = $16;
 $17 = Math_fround(HEAPF32[$screenRect$i$i>>2]);
 $18 = (($screenRect$i$i) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($7 + $17);
 HEAPF32[$0>>2] = $20;
 $21 = Math_fround($13 + $19);
 HEAPF32[$11>>2] = $21;
 $22 = Math_fround($10 + $20);
 $23 = Math_fround($16 + $21);
 $24 = Math_fround($3 + $17);
 $25 = Math_fround($5 + $19);
 $26 = $20 < $17;
 if ($26) {
  HEAPF32[$0>>2] = $17;
  $31 = $17;
 } else {
  $31 = $20;
 }
 $27 = $22 > $24;
 $x2$0$i$i$i = $27 ? $24 : $22;
 $28 = $21 < $19;
 if ($28) {
  HEAPF32[$11>>2] = $19;
  $34 = $19;
 } else {
  $34 = $21;
 }
 $29 = $23 > $25;
 $y2$0$i$i$i = $29 ? $25 : $23;
 $30 = Math_fround($x2$0$i$i$i - $31);
 $32 = $30 < Math_fround(0.0);
 $storemerge1$i$i$i = $32 ? Math_fround(0.0) : $30;
 HEAPF32[$8>>2] = $storemerge1$i$i$i;
 $33 = Math_fround($y2$0$i$i$i - $34);
 $35 = $33 < Math_fround(0.0);
 $storemerge$i$i$i = $35 ? Math_fround(0.0) : $33;
 HEAPF32[$14>>2] = $storemerge$i$i$i;
 __Z14RectfToRectIntRK5RectTIfE($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZN6Camera25SetNormalizedViewportRectERK5RectTIfE($this,$normalizedRect) {
 $this = $this|0;
 $normalizedRect = $normalizedRect|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 396|0);
 ;HEAP32[$0+0>>2]=HEAP32[$normalizedRect+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$normalizedRect+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$normalizedRect+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$normalizedRect+12>>2]|0;
 __ZN6Camera20WindowSizeHasChangedEv($this);
 STACKTOP = sp;return;
}
function __ZNK6Camera27GetUsesScreenForCompositingEb($this,$forceIntoRT) {
 $this = $this|0;
 $forceIntoRT = $forceIntoRT|0;
 var $$0 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$switch = 0, $notlhs = 0, $notrhs = 0;
 var $or$cond$not = 0, $or$cond3 = 0, $phitmp$i = 0, $pos$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i$i = sp + 8|0;
 $0 = sp;
 if ($forceIntoRT) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 292|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$4,$0);
     $16 = HEAP32[$pos$i$i$i$i$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if (!($30)) {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $phitmp$i = ($36|0)==(0|0);
  if (!($phitmp$i)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $37 = (($this) + 296|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = (($38) + 23|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = (__Z18GetQualitySettingsv()|0);
 $44 = (($43) + 40|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 24|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($47) + (($45*96)|0)|0) + 68|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP8[((640792 + 129|0))>>0]|0;
 $notlhs = ($49|0)>(1);
 $notrhs = ($50<<24>>24)!=(0);
 $or$cond$not = $notrhs & $notlhs;
 $51 = HEAP8[((640792 + 131|0))>>0]|0;
 $52 = ($51<<24>>24)==(0);
 $or$cond3 = $or$cond$not & $52;
 if ($or$cond3) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $53 = (($this) + 376|0);
  $54 = HEAP32[$53>>2]|0;
  $$off = (($54) + -1)|0;
  $not$switch = ($$off>>>0)>(1);
  STACKTOP = sp;return ($not$switch|0);
 }
 return 0|0;
}
function __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($this,$passContext,$renderFlags) {
 $this = $this|0;
 $passContext = $passContext|0;
 $renderFlags = $renderFlags|0;
 var $$$i = 0, $$0$i = 0, $$0$i15 = 0, $$0$i8 = 0, $$1$i = 0, $$byval_copy = 0, $$off = 0, $$pr = 0, $$rtcolor5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0);
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0;
 var $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$i = 0, $depth$sroa$0$0$i = 0, $depth$sroa$0$04$i = 0, $depth$sroa$0$07$i = 0, $or$cond$i = 0, $or$cond$i1 = 0, $phitmp$i = 0, $storemerge$i$i$i = Math_fround(0);
 var $storemerge1$i$i$i = Math_fround(0), $switch = 0, $temp$0$i14 = 0, $temp$0$i7 = 0, $viewcoord = 0, $viewport = 0, $x2$0$i$i$i = Math_fround(0), $y2$0$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy = sp + 160|0;
 $0 = sp + 96|0;
 $1 = sp + 92|0;
 $2 = sp + 88|0;
 $3 = sp + 84|0;
 $4 = sp + 80|0;
 $viewport = sp + 48|0;
 $5 = sp + 32|0;
 $viewcoord = sp + 16|0;
 $6 = sp;
 $7 = sp + 64|0;
 $8 = (__Z12GetGfxDevicev()|0);
 $9 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
 $10 = (__Z16GetBuildSettingsv()|0);
 $11 = (($10) + 92|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $36 = 1;
 } else {
  $14 = (__Z12GetGfxDevicev()|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 676|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (FUNCTION_TABLE_ii[$17 & 4095]($14)|0);
  $19 = ((640792 + ($18)|0) + 201|0);
  $20 = HEAP8[$19>>0]|0;
  $phitmp$i = ($20<<24>>24)==(0);
  $36 = $phitmp$i;
 }
 $21 = (__Z18GetQualitySettingsv()|0);
 $22 = (($21) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($25) + (($23*96)|0)|0) + 68|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 $29 = ($9|0)==(2);
 $or$cond$i = $28 | $29;
 $30 = ($9|0)==(3);
 $$1$i = $or$cond$i | $30;
 if ($30) {
  $31 = HEAP8[((640792 + 124|0))>>0]|0;
  $32 = ($31<<24>>24)!=(0);
  $39 = $32;
 } else {
  $39 = 1;
 }
 $33 = (($this) + 619|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)==(0);
 $brmerge$i = $35 | $36;
 if ($brmerge$i) {
  $37 = (($this) + 620|0);
  HEAP8[$37>>0] = 0;
  $38 = HEAP32[569664>>2]|0;
  $322 = $37;$50 = $38;
  label = 9;
 } else {
  $$$i = $$1$i & $39;
  $40 = (($this) + 620|0);
  $41 = $$$i&1;
  HEAP8[$40>>0] = $41;
  $42 = HEAP32[569664>>2]|0;
  if ($$$i) {
   $43 = $42 & 31;
   $44 = 1 << $43;
   $45 = $42 >>> 5;
   $46 = ((($passContext) + ($45<<2)|0) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | $44;
   HEAP32[$46>>2] = $48;
   $86 = $40;
  } else {
   $322 = $40;$50 = $42;
   label = 9;
  }
 }
 if ((label|0) == 9) {
  $49 = $50 & 31;
  $51 = 1 << $49;
  $52 = $51 ^ -1;
  $53 = $50 >>> 5;
  $54 = ((($passContext) + ($53<<2)|0) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = $55 & $52;
  HEAP32[$54>>2] = $56;
  $86 = $322;
 }
 $57 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
 $58 = $57 & -2;
 $59 = ($58|0)==(2);
 do {
  if ($59) {
   $$0$i = 1;
  } else {
   $60 = HEAP8[((640792 + 129|0))>>0]|0;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    label = 13;
   } else {
    $62 = (__Z18GetQualitySettingsv()|0);
    $63 = (($62) + 40|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($62) + 24|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ((($66) + (($64*96)|0)|0) + 68|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ($68|0)>(1);
    $70 = HEAP8[((640792 + 131|0))>>0]|0;
    $71 = ($70<<24>>24)==(0);
    $or$cond$i1 = $69 & $71;
    if (!($or$cond$i1)) {
     label = 13;
    }
   }
   if ((label|0) == 13) {
    $72 = (($this) + 288|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (__Z25GetRenderLoopImageFiltersR10RenderLoop($73)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($74) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = ($75|0)==($77|0);
    if (!($78)) {
     $$0$i = 1;
     break;
    }
   }
   $$0$i = 0;
  }
 } while(0);
 $79 = (__ZNK6Camera26CalculateAntiAliasingForRTEv($this)|0);
 $80 = $renderFlags & 4;
 $81 = ($80|0)==(0);
 if (!($81)) {
  $82 = (($this) + 288|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (__Z25GetRenderLoopImageFiltersR10RenderLoop($83)|0);
  $85 = HEAP8[$86>>0]|0;
  $87 = ($85<<24>>24)!=(0);
  __ZN12ImageFilters7PrepareEbbi($84,$$0$i,$87,$79);
 }
 $88 = (($this) + 348|0);
 HEAP32[$88>>2] = 0;
 $89 = (__ZNK6Camera27GetUsesScreenForCompositingEb($this,$$0$i)|0);
 do {
  if (!($89)) {
   $90 = (($this) + 288|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (__Z25GetRenderLoopImageFiltersR10RenderLoop($91)|0);
   $93 = $renderFlags & 16;
   $94 = ($93|0)==(0);
   if ($94) {
    $96 = (__ZN12ImageFilters21GetTargetBeforeOpaqueEv($92)|0);
    HEAP32[$88>>2] = $96;
    $97 = ($96|0)==(0|0);
    if (!($97)) {
     $98 = (($this) + 292|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ($99|0)==(0);
     do {
      if (!($100)) {
       HEAP32[$4>>2] = $99;
       $101 = HEAP32[560624>>2]|0;
       $102 = ($101|0)==(0|0);
       if ($102) {
        label = 30;
       } else {
        $103 = (($101) + 36|0);
        $104 = HEAP32[$103>>2]|0;
        $105 = (($101) + 4|0);
        $106 = HEAP32[$105>>2]|0;
        $107 = ($104|0)==($106|0);
        do {
         if ($107) {
          $108 = (($101) + 28|0);
          $109 = HEAP32[$108>>2]|0;
          $110 = (($101) + 32|0);
          $111 = HEAP32[$110>>2]|0;
          $112 = (($109) + ($111<<3)|0);
          $128 = $112;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$101,$4);
          $113 = HEAP32[$$byval_copy>>2]|0;
          $114 = ($113|0)==(-1);
          $115 = (($101) + 28|0);
          $116 = HEAP32[$115>>2]|0;
          if ($114) {
           $117 = (($101) + 32|0);
           $118 = HEAP32[$117>>2]|0;
           $119 = (($116) + ($118<<3)|0);
           $128 = $119;
           break;
          } else {
           $120 = (($116) + ($113<<3)|0);
           $128 = $120;
           break;
          }
         }
        } while(0);
        $121 = HEAP32[560624>>2]|0;
        $122 = (($121) + 28|0);
        $123 = HEAP32[$122>>2]|0;
        $124 = (($121) + 32|0);
        $125 = HEAP32[$124>>2]|0;
        $126 = (($123) + ($125<<3)|0);
        $127 = ($128|0)==($126|0);
        if ($127) {
         label = 30;
        } else {
         $129 = (($128) + 4|0);
         $130 = HEAP32[$129>>2]|0;
         $131 = ($130|0)==(0|0);
         if ($131) {
          label = 30;
         }
        }
       }
       if ((label|0) == 30) {
        $132 = HEAP32[$98>>2]|0;
        $133 = (__Z31ReadObjectFromPersistentManageri($132)|0);
        $134 = ($133|0)==(0|0);
        if ($134) {
         break;
        }
       }
       $135 = (($this) + 376|0);
       $136 = HEAP32[$135>>2]|0;
       $$off = (($136) + -3)|0;
       $switch = ($$off>>>0)<(2);
       if ($switch) {
        $137 = HEAP32[$98>>2]|0;
        $138 = ($137|0)==(0);
        if ($138) {
         $$0$i8 = 0;
        } else {
         HEAP32[$3>>2] = $137;
         $139 = HEAP32[560624>>2]|0;
         $140 = ($139|0)==(0|0);
         if ($140) {
          label = 41;
         } else {
          $141 = (($139) + 36|0);
          $142 = HEAP32[$141>>2]|0;
          $143 = (($139) + 4|0);
          $144 = HEAP32[$143>>2]|0;
          $145 = ($142|0)==($144|0);
          do {
           if ($145) {
            $146 = (($139) + 28|0);
            $147 = HEAP32[$146>>2]|0;
            $148 = (($139) + 32|0);
            $149 = HEAP32[$148>>2]|0;
            $150 = (($147) + ($149<<3)|0);
            $166 = $150;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$139,$3);
            $151 = HEAP32[$$byval_copy>>2]|0;
            $152 = ($151|0)==(-1);
            $153 = (($139) + 28|0);
            $154 = HEAP32[$153>>2]|0;
            if ($152) {
             $155 = (($139) + 32|0);
             $156 = HEAP32[$155>>2]|0;
             $157 = (($154) + ($156<<3)|0);
             $166 = $157;
             break;
            } else {
             $158 = (($154) + ($151<<3)|0);
             $166 = $158;
             break;
            }
           }
          } while(0);
          $159 = HEAP32[560624>>2]|0;
          $160 = (($159) + 28|0);
          $161 = HEAP32[$160>>2]|0;
          $162 = (($159) + 32|0);
          $163 = HEAP32[$162>>2]|0;
          $164 = (($161) + ($163<<3)|0);
          $165 = ($166|0)==($164|0);
          if ($165) {
           label = 41;
          } else {
           $167 = (($166) + 4|0);
           $168 = HEAP32[$167>>2]|0;
           $169 = ($168|0)==(0|0);
           if ($169) {
            label = 41;
           } else {
            $temp$0$i7 = $168;
           }
          }
         }
         if ((label|0) == 41) {
          $170 = HEAP32[$98>>2]|0;
          $171 = (__Z31ReadObjectFromPersistentManageri($170)|0);
          $temp$0$i7 = $171;
         }
         $$0$i8 = $temp$0$i7;
        }
        $172 = HEAP32[$88>>2]|0;
        __ZN12ImageFilters4BlitEP7TextureP13RenderTexture($$0$i8,$172);
       }
      }
     } while(0);
     $$pr = HEAP32[$88>>2]|0;
     $174 = $$pr;
     label = 45;
    }
   } else {
    $95 = (__ZN12ImageFilters14GetTargetFinalEv($92)|0);
    HEAP32[$88>>2] = $95;
    $174 = $95;
    label = 45;
   }
   if ((label|0) == 45) {
    $173 = ($174|0)==(0|0);
    if (!($173)) {
     break;
    }
   }
   $175 = (($this) + 292|0);
   $176 = HEAP32[$175>>2]|0;
   $177 = ($176|0)==(0);
   if ($177) {
    $$0$i15 = 0;
   } else {
    HEAP32[$2>>2] = $176;
    $178 = HEAP32[560624>>2]|0;
    $179 = ($178|0)==(0|0);
    if ($179) {
     label = 55;
    } else {
     $180 = (($178) + 36|0);
     $181 = HEAP32[$180>>2]|0;
     $182 = (($178) + 4|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = ($181|0)==($183|0);
     do {
      if ($184) {
       $185 = (($178) + 28|0);
       $186 = HEAP32[$185>>2]|0;
       $187 = (($178) + 32|0);
       $188 = HEAP32[$187>>2]|0;
       $189 = (($186) + ($188<<3)|0);
       $205 = $189;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$178,$2);
       $190 = HEAP32[$$byval_copy>>2]|0;
       $191 = ($190|0)==(-1);
       $192 = (($178) + 28|0);
       $193 = HEAP32[$192>>2]|0;
       if ($191) {
        $194 = (($178) + 32|0);
        $195 = HEAP32[$194>>2]|0;
        $196 = (($193) + ($195<<3)|0);
        $205 = $196;
        break;
       } else {
        $197 = (($193) + ($190<<3)|0);
        $205 = $197;
        break;
       }
      }
     } while(0);
     $198 = HEAP32[560624>>2]|0;
     $199 = (($198) + 28|0);
     $200 = HEAP32[$199>>2]|0;
     $201 = (($198) + 32|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = (($200) + ($202<<3)|0);
     $204 = ($205|0)==($203|0);
     if ($204) {
      label = 55;
     } else {
      $206 = (($205) + 4|0);
      $207 = HEAP32[$206>>2]|0;
      $208 = ($207|0)==(0|0);
      if ($208) {
       label = 55;
      } else {
       $temp$0$i14 = $207;
      }
     }
    }
    if ((label|0) == 55) {
     $209 = HEAP32[$175>>2]|0;
     $210 = (__Z31ReadObjectFromPersistentManageri($209)|0);
     $temp$0$i14 = $210;
    }
    $$0$i15 = $temp$0$i14;
   }
   HEAP32[$88>>2] = $$0$i15;
  }
 } while(0);
 __ZL19GetCameraTargetRectRK6Camerab($$byval_copy,$this,0);
 $211 = (($this) + 396|0);
 ;HEAP32[$5+0>>2]=HEAP32[$211+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$211+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$211+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$211+12>>2]|0;
 $212 = (($$byval_copy) + 8|0);
 $213 = Math_fround(HEAPF32[$212>>2]);
 $214 = (($$byval_copy) + 12|0);
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = Math_fround(HEAPF32[$5>>2]);
 $217 = Math_fround($213 * $216);
 $218 = (($5) + 8|0);
 $219 = Math_fround(HEAPF32[$218>>2]);
 $220 = Math_fround($213 * $219);
 HEAPF32[$218>>2] = $220;
 $221 = (($5) + 4|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = Math_fround($215 * $222);
 $224 = (($5) + 12|0);
 $225 = Math_fround(HEAPF32[$224>>2]);
 $226 = Math_fround($215 * $225);
 HEAPF32[$224>>2] = $226;
 $227 = Math_fround(HEAPF32[$$byval_copy>>2]);
 $228 = (($$byval_copy) + 4|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = Math_fround($217 + $227);
 HEAPF32[$5>>2] = $230;
 $231 = Math_fround($223 + $229);
 HEAPF32[$221>>2] = $231;
 $232 = Math_fround($220 + $230);
 $233 = Math_fround($226 + $231);
 $234 = Math_fround($213 + $227);
 $235 = Math_fround($215 + $229);
 $236 = $230 < $227;
 if ($236) {
  HEAPF32[$5>>2] = $227;
  $241 = $227;
 } else {
  $241 = $230;
 }
 $237 = $232 > $234;
 $x2$0$i$i$i = $237 ? $234 : $232;
 $238 = $231 < $229;
 if ($238) {
  HEAPF32[$221>>2] = $229;
  $244 = $229;
 } else {
  $244 = $231;
 }
 $239 = $233 > $235;
 $y2$0$i$i$i = $239 ? $235 : $233;
 $240 = Math_fround($x2$0$i$i$i - $241);
 $242 = $240 < Math_fround(0.0);
 $storemerge1$i$i$i = $242 ? Math_fround(0.0) : $240;
 HEAPF32[$218>>2] = $storemerge1$i$i$i;
 $243 = Math_fround($y2$0$i$i$i - $244);
 $245 = $243 < Math_fround(0.0);
 $storemerge$i$i$i = $245 ? Math_fround(0.0) : $243;
 HEAPF32[$224>>2] = $storemerge$i$i$i;
 __Z14RectfToRectIntRK5RectTIfE($viewport,$5);
 $246 = (__Z16GetRenderManagerv()|0);
 $247 = (($246) + 72|0);
 ;HEAP32[$247+0>>2]=HEAP32[$viewport+0>>2]|0;HEAP32[$247+4>>2]=HEAP32[$viewport+4>>2]|0;HEAP32[$247+8>>2]=HEAP32[$viewport+8>>2]|0;HEAP32[$247+12>>2]=HEAP32[$viewport+12>>2]|0;
 $248 = $renderFlags & 2;
 $249 = ($248|0)==(0);
 if (!($249)) {
  $250 = HEAP32[$88>>2]|0;
  $251 = (__Z28EnsureRenderTextureIsCreatedP13RenderTexture($250)|0);
  HEAP32[$88>>2] = $251;
  $252 = ($251|0)==(0|0);
  if ($252) {
   HEAP32[$0>>2] = 0;
   $256 = (($this) + 296|0);
   $257 = (($this) + 332|0);
   $depth$sroa$0$04$i = HEAP32[$257>>2]|0;
   $258 = (($this) + 328|0);
   $259 = HEAP32[$258>>2]|0;
   $260 = (($this) + 336|0);
   $261 = HEAP32[$260>>2]|0;
   HEAP32[$88>>2] = $261;
   $$rtcolor5$i = $256;$262 = $259;$263 = $261;$depth$sroa$0$07$i = $depth$sroa$0$04$i;
  } else {
   $253 = (($251) + 140|0);
   $254 = HEAP32[$253>>2]|0;
   HEAP32[$0>>2] = $254;
   $255 = (($251) + 148|0);
   $depth$sroa$0$0$i = HEAP32[$255>>2]|0;
   $$rtcolor5$i = $0;$262 = 1;$263 = $251;$depth$sroa$0$07$i = $depth$sroa$0$0$i;
  }
  HEAP32[$1>>2] = $depth$sroa$0$07$i;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej($262,$$rtcolor5$i,$$byval_copy,$263,0,-1,1)|0);
  $264 = HEAP32[$$rtcolor5$i>>2]|0;
  $265 = ($264|0)==(0|0);
  if ($265) {
   ;HEAP32[$viewcoord+0>>2]=0|0;HEAP32[$viewcoord+4>>2]=0|0;HEAP32[$viewcoord+8>>2]=0|0;HEAP32[$viewcoord+12>>2]=0|0;
   $269 = $viewcoord;
   label = 70;
  } else {
   $266 = (($264) + 23|0);
   $267 = HEAP8[$266>>0]|0;
   $268 = ($267<<24>>24)==(0);
   ;HEAP32[$viewcoord+0>>2]=0|0;HEAP32[$viewcoord+4>>2]=0|0;HEAP32[$viewcoord+8>>2]=0|0;HEAP32[$viewcoord+12>>2]=0|0;
   if ($268) {
    $269 = $viewcoord;
    label = 70;
   } else {
    ;HEAP32[$viewcoord+0>>2]=HEAP32[$viewport+0>>2]|0;HEAP32[$viewcoord+4>>2]=HEAP32[$viewport+4>>2]|0;HEAP32[$viewcoord+8>>2]=HEAP32[$viewport+8>>2]|0;HEAP32[$viewcoord+12>>2]=HEAP32[$viewport+12>>2]|0;
   }
  }
  if ((label|0) == 70) {
   __ZNK6Camera18GetRenderRectangleEv($7,$this);
   __Z14RectfToRectIntRK5RectTIfE($6,$7);
   ;HEAP32[$269+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$269+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$269+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$269+12>>2]=HEAP32[$6+12>>2]|0;
  }
  __Z22FlipScreenRectIfNeededRK9GfxDeviceR5RectTIiE($8,$viewcoord);
  $270 = HEAP32[$8>>2]|0;
  $271 = (($270) + 172|0);
  $272 = HEAP32[$271>>2]|0;
  FUNCTION_TABLE_vii[$272 & 4095]($8,$viewcoord);
 }
 $273 = HEAP32[$8>>2]|0;
 $274 = (($273) + 104|0);
 $275 = HEAP32[$274>>2]|0;
 $276 = (($this) + 609|0);
 $277 = HEAP8[$276>>0]|0;
 $278 = ($277<<24>>24)==(0);
 if (!($278)) {
  $279 = (($this) + 613|0);
  $280 = HEAP8[$279>>0]|0;
  $281 = ($280<<24>>24)==(0);
  if (!($281)) {
   $282 = (($this) + 616|0);
   $283 = HEAP8[$282>>0]|0;
   $284 = ($283<<24>>24)==(0);
   $285 = (($this) + 96|0);
   if ($284) {
    $286 = (($this) + 452|0);
    $287 = Math_fround(HEAPF32[$286>>2]);
    $288 = (($this) + 596|0);
    $289 = Math_fround(HEAPF32[$288>>2]);
    $290 = (($this) + 456|0);
    $291 = Math_fround(HEAPF32[$290>>2]);
    $292 = (($this) + 460|0);
    $293 = Math_fround(HEAPF32[$292>>2]);
    (__ZN10Matrix4x4f14SetPerspectiveEffff($285,$287,$289,$291,$293)|0);
   } else {
    $294 = (($this) + 448|0);
    $295 = Math_fround(HEAPF32[$294>>2]);
    $296 = Math_fround(-$295);
    $297 = (($this) + 596|0);
    $298 = Math_fround(HEAPF32[$297>>2]);
    $299 = Math_fround($298 * $296);
    $300 = Math_fround($295 * $298);
    $301 = (($this) + 456|0);
    $302 = Math_fround(HEAPF32[$301>>2]);
    $303 = (($this) + 460|0);
    $304 = Math_fround(HEAPF32[$303>>2]);
    (__ZN10Matrix4x4f8SetOrthoEffffff($285,$299,$300,$296,$295,$302,$304)|0);
   }
   HEAP8[$276>>0] = 0;
  }
 }
 $305 = (($this) + 96|0);
 FUNCTION_TABLE_vii[$275 & 4095]($8,$305);
 $306 = HEAP32[$8>>2]|0;
 $307 = (($306) + 100|0);
 $308 = HEAP32[$307>>2]|0;
 $309 = (($this) + 608|0);
 $310 = HEAP8[$309>>0]|0;
 $311 = ($310<<24>>24)==(0);
 if ($311) {
  $321 = (($this) + 32|0);
  FUNCTION_TABLE_vii[$308 & 4095]($8,$321);
  __ZN6Camera20SetCameraShaderPropsERN9ShaderLab17ShaderPassContextE($this,$passContext);
  STACKTOP = sp;return;
 }
 $312 = (($this) + 612|0);
 $313 = HEAP8[$312>>0]|0;
 $314 = ($313<<24>>24)==(0);
 if ($314) {
  $321 = (($this) + 32|0);
  FUNCTION_TABLE_vii[$308 & 4095]($8,$321);
  __ZN6Camera20SetCameraShaderPropsERN9ShaderLab17ShaderPassContextE($this,$passContext);
  STACKTOP = sp;return;
 }
 $315 = (($this) + 32|0);
 HEAPF32[$$byval_copy>>2] = Math_fround(1.0);
 $316 = (($$byval_copy) + 4|0);
 HEAPF32[$316>>2] = Math_fround(1.0);
 $317 = (($$byval_copy) + 8|0);
 HEAPF32[$317>>2] = Math_fround(-1.0);
 (__ZN10Matrix4x4f8SetScaleERK8Vector3f($315,$$byval_copy)|0);
 $318 = (($this) + 24|0);
 $319 = HEAP32[$318>>2]|0;
 $320 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($319)|0);
 __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($0,$320);
 (__ZN10Matrix4x4fmLERKS_($315,$0)|0);
 HEAP8[$309>>0] = 0;
 $321 = (($this) + 32|0);
 FUNCTION_TABLE_vii[$308 & 4095]($8,$321);
 __ZN6Camera20SetCameraShaderPropsERN9ShaderLab17ShaderPassContextE($this,$passContext);
 STACKTOP = sp;return;
}
function __ZNK6Camera28CalculateNeedsToRenderIntoRTEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
 $1 = $0 & -2;
 $2 = ($1|0)==(2);
 if ($2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[((640792 + 129|0))>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  label = 4;
 } else {
  $5 = (__Z18GetQualitySettingsv()|0);
  $6 = (($5) + 40|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9) + (($7*96)|0)|0) + 68|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)>(1);
  $13 = HEAP8[((640792 + 131|0))>>0]|0;
  $14 = ($13<<24>>24)==(0);
  $or$cond = $12 & $14;
  if (!($or$cond)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $15 = (($this) + 288|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (__Z25GetRenderLoopImageFiltersR10RenderLoop($16)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($17) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($18|0)==($20|0);
  if (!($21)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK6Camera26CalculateAntiAliasingForRTEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $pos$i$i$i$i3 = 0, $temp$0$i = 0, $temp$0$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i3 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 292|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $3;
 $5 = HEAP32[560624>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 10;
 } else {
  $7 = (($5) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  do {
   if ($11) {
    $12 = (($5) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($5) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + ($15<<3)|0);
    $32 = $16;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i3,$5,$1);
    $17 = HEAP32[$pos$i$i$i$i3>>2]|0;
    $18 = ($17|0)==(-1);
    $19 = (($5) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    if ($18) {
     $21 = (($5) + 32|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + ($22<<3)|0);
     $32 = $23;
     break;
    } else {
     $24 = (($20) + ($17<<3)|0);
     $32 = $24;
     break;
    }
   }
  } while(0);
  $25 = HEAP32[560624>>2]|0;
  $26 = (($25) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 32|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + ($29<<3)|0);
  $31 = ($32|0)==($30|0);
  if ($31) {
   label = 10;
  } else {
   $33 = (($32) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    label = 10;
   } else {
    $temp$0$i = $34;
   }
  }
 }
 if ((label|0) == 10) {
  $36 = HEAP32[$2>>2]|0;
  $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
  $temp$0$i = $37;
 }
 $38 = ($temp$0$i|0)==(0|0);
 $39 = HEAP8[((640792 + 129|0))>>0]|0;
 $40 = ($39<<24>>24)==(0);
 $or$cond = $38 | $40;
 if ($or$cond) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
 $42 = $41 & -2;
 $43 = ($42|0)==(2);
 if ($43) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $44;
 $45 = HEAP32[560624>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  label = 21;
 } else {
  $47 = (($45) + 36|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($45) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($48|0)==($50|0);
  do {
   if ($51) {
    $52 = (($45) + 28|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($45) + 32|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($53) + ($55<<3)|0);
    $72 = $56;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i3,$45,$0);
    $57 = HEAP32[$pos$i$i$i$i3>>2]|0;
    $58 = ($57|0)==(-1);
    $59 = (($45) + 28|0);
    $60 = HEAP32[$59>>2]|0;
    if ($58) {
     $61 = (($45) + 32|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($60) + ($62<<3)|0);
     $72 = $63;
     break;
    } else {
     $64 = (($60) + ($57<<3)|0);
     $72 = $64;
     break;
    }
   }
  } while(0);
  $65 = HEAP32[560624>>2]|0;
  $66 = (($65) + 28|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($65) + 32|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($67) + ($69<<3)|0);
  $71 = ($72|0)==($70|0);
  if ($71) {
   label = 21;
  } else {
   $73 = (($72) + 4|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    label = 21;
   } else {
    $temp$0$i7 = $74;
   }
  }
 }
 if ((label|0) == 21) {
  $76 = HEAP32[$2>>2]|0;
  $77 = (__Z31ReadObjectFromPersistentManageri($76)|0);
  $temp$0$i7 = $77;
 }
 $78 = (($temp$0$i7) + 108|0);
 $79 = HEAP32[$78>>2]|0;
 $$0 = $79;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK6Camera18GetRenderRectangleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $9 = 0, $screenRect$i$i = 0, $storemerge$i$i$i = Math_fround(0), $storemerge1$i$i$i = Math_fround(0), $temp$0$i = 0, $x2$0$i$i$i = Math_fround(0), $y2$0$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $screenRect$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 348|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 292|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0);
  if ($6) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $5;
   $7 = HEAP32[560624>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 11;
   } else {
    $9 = (($7) + 36|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    do {
     if ($13) {
      $14 = (($7) + 28|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($7) + 32|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($15) + ($17<<3)|0);
      $34 = $18;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($screenRect$i$i,$7,$0);
      $19 = HEAP32[$screenRect$i$i>>2]|0;
      $20 = ($19|0)==(-1);
      $21 = (($7) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      if ($20) {
       $23 = (($7) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $34 = $25;
       break;
      } else {
       $26 = (($22) + ($19<<3)|0);
       $34 = $26;
       break;
      }
     }
    } while(0);
    $27 = HEAP32[560624>>2]|0;
    $28 = (($27) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + ($31<<3)|0);
    $33 = ($34|0)==($32|0);
    if ($33) {
     label = 11;
    } else {
     $35 = (($34) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      label = 11;
     } else {
      $temp$0$i = $36;
     }
    }
   }
   if ((label|0) == 11) {
    $38 = HEAP32[$4>>2]|0;
    $39 = (__Z31ReadObjectFromPersistentManageri($38)|0);
    $temp$0$i = $39;
   }
   $$0$i = $temp$0$i;
  }
  $40 = ($2|0)==($$0$i|0);
  if (!($40)) {
   $41 = HEAP32[$1>>2]|0;
   $42 = (($41) + 100|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (Math_fround(($43|0)));
   $45 = (($41) + 104|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (Math_fround(($46|0)));
   HEAPF32[$agg$result>>2] = Math_fround(0.0);
   $48 = (($agg$result) + 8|0);
   HEAPF32[$48>>2] = $44;
   $49 = (($agg$result) + 4|0);
   HEAPF32[$49>>2] = Math_fround(0.0);
   $50 = (($agg$result) + 12|0);
   HEAPF32[$50>>2] = $47;
   STACKTOP = sp;return;
  }
 }
 __ZL19GetCameraTargetRectRK6Camerab($screenRect$i$i,$this,0);
 $51 = (($this) + 396|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$51+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$51+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$51+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$51+12>>2]|0;
 $52 = (($screenRect$i$i) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($screenRect$i$i) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround(HEAPF32[$agg$result>>2]);
 $57 = Math_fround($53 * $56);
 $58 = (($agg$result) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($53 * $59);
 HEAPF32[$58>>2] = $60;
 $61 = (($agg$result) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($55 * $62);
 $64 = (($agg$result) + 12|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($55 * $65);
 HEAPF32[$64>>2] = $66;
 $67 = Math_fround(HEAPF32[$screenRect$i$i>>2]);
 $68 = (($screenRect$i$i) + 4|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($57 + $67);
 HEAPF32[$agg$result>>2] = $70;
 $71 = Math_fround($63 + $69);
 HEAPF32[$61>>2] = $71;
 $72 = Math_fround($60 + $70);
 $73 = Math_fround($66 + $71);
 $74 = Math_fround($53 + $67);
 $75 = Math_fround($55 + $69);
 $76 = $70 < $67;
 if ($76) {
  HEAPF32[$agg$result>>2] = $67;
  $81 = $67;
 } else {
  $81 = $70;
 }
 $77 = $72 > $74;
 $x2$0$i$i$i = $77 ? $74 : $72;
 $78 = $71 < $69;
 if ($78) {
  HEAPF32[$61>>2] = $69;
  $84 = $69;
 } else {
  $84 = $71;
 }
 $79 = $73 > $75;
 $y2$0$i$i$i = $79 ? $75 : $73;
 $80 = Math_fround($x2$0$i$i$i - $81);
 $82 = $80 < Math_fround(0.0);
 $storemerge1$i$i$i = $82 ? Math_fround(0.0) : $80;
 HEAPF32[$58>>2] = $storemerge1$i$i$i;
 $83 = Math_fround($y2$0$i$i$i - $84);
 $85 = $83 < Math_fround(0.0);
 $storemerge$i$i$i = $85 ? Math_fround(0.0) : $83;
 HEAPF32[$64>>2] = $storemerge$i$i$i;
 STACKTOP = sp;return;
}
function __ZNK6Camera19GetProjectionMatrixEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 609|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $29 = (($this) + 96|0);
  STACKTOP = sp;return ($29|0);
 }
 $3 = (($this) + 613|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $29 = (($this) + 96|0);
  STACKTOP = sp;return ($29|0);
 }
 $6 = (($this) + 616|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = (($this) + 96|0);
 if ($8) {
  $10 = (($this) + 452|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($this) + 596|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($this) + 456|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($this) + 460|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  (__ZN10Matrix4x4f14SetPerspectiveEffff($9,$11,$13,$15,$17)|0);
 } else {
  $18 = (($this) + 448|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround(-$19);
  $21 = (($this) + 596|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($22 * $20);
  $24 = Math_fround($19 * $22);
  $25 = (($this) + 456|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($this) + 460|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  (__ZN10Matrix4x4f8SetOrthoEffffff($9,$23,$24,$20,$19,$26,$28)|0);
 }
 HEAP8[$0>>0] = 0;
 $29 = (($this) + 96|0);
 STACKTOP = sp;return ($29|0);
}
function __ZNK6Camera22GetWorldToCameraMatrixEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = (($this) + 608|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $14 = (($this) + 32|0);
  STACKTOP = sp;return ($14|0);
 }
 $5 = (($this) + 612|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $14 = (($this) + 32|0);
  STACKTOP = sp;return ($14|0);
 }
 $8 = (($this) + 32|0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $9 = (($0) + 4|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($0) + 8|0);
 HEAPF32[$10>>2] = Math_fround(-1.0);
 (__ZN10Matrix4x4f8SetScaleERK8Vector3f($8,$0)|0);
 $11 = (($this) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($12)|0);
 __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$13);
 (__ZN10Matrix4x4fmLERKS_($8,$1)|0);
 HEAP8[$2>>0] = 0;
 $14 = (($this) + 32|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN6Camera20SetCameraShaderPropsERN9ShaderLab17ShaderPassContextE($this,$passContext) {
 $this = $this|0;
 $passContext = $passContext|0;
 var $$ = Math_fround(0), $$$i = Math_fround(0), $$$i10 = Math_fround(0), $$0$i11 = Math_fround(0), $$0$i3 = Math_fround(0), $$0$i8 = Math_fround(0), $$0$i854 = Math_fround(0), $$0$i855 = Math_fround(0), $$0$i9 = Math_fround(0), $$53 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0;
 var $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0;
 var $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0);
 var $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0);
 var $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0);
 var $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0);
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0.0, $24 = 0, $240 = 0.0, $241 = Math_fround(0), $242 = 0.0, $243 = 0.0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0);
 var $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = 0;
 var $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $i$03$i$i = 0, $i$03$i$i4 = 0, $invertY = 0, $j$01$i$i = 0, $j$01$i$i6 = 0, $phitmp = Math_fround(0), $pos = 0, $reflMat = 0, $storemerge$i$i$i = Math_fround(0), $storemerge1$i$i$i = Math_fround(0), $temp = 0, $x2$0$i$i$i = Math_fround(0), $y2$0$i$i$i = Math_fround(0), dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $0 = sp + 304|0;
 $1 = sp;
 $pos = sp + 64|0;
 $temp = sp + 80|0;
 $2 = sp + 144|0;
 $invertY = sp + 160|0;
 $3 = sp + 224|0;
 $reflMat = sp + 240|0;
 $4 = (__Z12GetGfxDevicev()|0);
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($6)|0);
 __ZNK9Transform11GetPositionEv($pos,$7);
 $8 = Math_fround(HEAPF32[$pos>>2]);
 $9 = (($pos) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($pos) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($4) + 564|0);
 HEAPF32[$13>>2] = $8;
 $14 = (($4) + 568|0);
 HEAPF32[$14>>2] = $10;
 $15 = (($4) + 572|0);
 HEAPF32[$15>>2] = $12;
 $16 = (($4) + 576|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $17 = (($2) + 4|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($2) + 8|0);
 HEAPF32[$18>>2] = Math_fround(-1.0);
 (__ZN10Matrix4x4f8SetScaleERK8Vector3f($temp,$2)|0);
 $19 = (($this) + 608|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  $22 = (($this) + 612|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  if (!($24)) {
   $25 = (($this) + 32|0);
   HEAPF32[$0>>2] = Math_fround(1.0);
   $26 = (($0) + 4|0);
   HEAPF32[$26>>2] = Math_fround(1.0);
   $27 = (($0) + 8|0);
   HEAPF32[$27>>2] = Math_fround(-1.0);
   (__ZN10Matrix4x4f8SetScaleERK8Vector3f($25,$0)|0);
   $28 = HEAP32[$5>>2]|0;
   $29 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($28)|0);
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$29);
   (__ZN10Matrix4x4fmLERKS_($25,$1)|0);
   HEAP8[$19>>0] = 0;
  }
 }
 $30 = (($this) + 32|0);
 (__ZN10Matrix4x4fmLERKS_($temp,$30)|0);
 $31 = (($4) + 2916|0);
 dest=$31+0|0; src=$temp+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 (__Z25InvertMatrix4x4_General3DPKfPf($temp,$1)|0);
 $32 = (($4) + 2980|0);
 dest=$32+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $33 = (($temp) + 56|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($temp) + 52|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($temp) + 48|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $36 = (($3) + 4|0);
 HEAPF32[$36>>2] = Math_fround(-1.0);
 $37 = (($3) + 8|0);
 HEAPF32[$37>>2] = Math_fround(1.0);
 (__ZN10Matrix4x4f8SetScaleERK8Vector3f($invertY,$3)|0);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp,$invertY,$reflMat);
 $38 = (($passContext) + 20|0);
 __ZN9ShaderLab13PropertySheet9SetMatrixERKNS_16FastPropertyNameERK10Matrix4x4f($38,569552,$reflMat);
 __Z27SetClippingPlaneShaderPropsv();
 $39 = (__Z14GetTimeManagerv()|0);
 $40 = (($39) + 88|0);
 $41 = +HEAPF64[$40>>3];
 $42 = (($39) + 160|0);
 $43 = +HEAPF64[$42>>3];
 $44 = $41 + $43;
 $45 = Math_fround($44);
 $46 = (($39) + 104|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = $47 < Math_fround(0.00499999988824129104614);
 if ($48) {
  $$0$i11 = Math_fround(0.00499999988824129104614);
 } else {
  $49 = $47 > Math_fround(0.20000000298023223877);
  $$$i10 = $49 ? Math_fround(0.20000000298023223877) : $47;
  $$0$i11 = $$$i10;
 }
 $50 = (($39) + 108|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = $51 < Math_fround(0.00499999988824129104614);
 if ($52) {
  $$0$i9 = Math_fround(0.00499999988824129104614);
 } else {
  $53 = $51 > Math_fround(0.20000000298023223877);
  $$$i = $53 ? Math_fround(0.20000000298023223877) : $51;
  $$0$i9 = $$$i;
 }
 $54 = Math_fround($45 * Math_fround(0.0500000007450580596924));
 $55 = Math_fround($45 * Math_fround(2.0));
 $56 = Math_fround($45 * Math_fround(3.0));
 $57 = (($4) + 1108|0);
 HEAPF32[$57>>2] = $54;
 $58 = (($4) + 1112|0);
 HEAPF32[$58>>2] = $45;
 $59 = (($4) + 1116|0);
 HEAPF32[$59>>2] = $55;
 $60 = (($4) + 1120|0);
 HEAPF32[$60>>2] = $56;
 $61 = Math_fround($45 * Math_fround(0.125));
 $62 = (Math_fround(+(Math_sin((+$61)))));
 $63 = Math_fround($45 * Math_fround(0.25));
 $64 = (Math_fround(+(Math_sin((+$63)))));
 $65 = Math_fround($45 * Math_fround(0.5));
 $66 = (Math_fround(+(Math_sin((+$65)))));
 $67 = (Math_fround(+(Math_sin((+$45)))));
 $68 = (($4) + 1124|0);
 HEAPF32[$68>>2] = $62;
 $69 = (($4) + 1128|0);
 HEAPF32[$69>>2] = $64;
 $70 = (($4) + 1132|0);
 HEAPF32[$70>>2] = $66;
 $71 = (($4) + 1136|0);
 HEAPF32[$71>>2] = $67;
 $72 = (Math_fround(+(Math_cos((+$61)))));
 $73 = (Math_fround(+(Math_cos((+$63)))));
 $74 = (Math_fround(+(Math_cos((+$65)))));
 $75 = (Math_fround(+(Math_cos((+$45)))));
 $76 = (($4) + 1140|0);
 HEAPF32[$76>>2] = $72;
 $77 = (($4) + 1144|0);
 HEAPF32[$77>>2] = $73;
 $78 = (($4) + 1148|0);
 HEAPF32[$78>>2] = $74;
 $79 = (($4) + 1152|0);
 HEAPF32[$79>>2] = $75;
 $80 = (Math_fround(+(_fmodf((+$45),3.14159274101257324219))));
 $81 = (Math_fround(+(_fmodf((+$55),3.14159274101257324219))));
 $82 = (Math_fround(+(_fmodf((+$56),3.14159274101257324219))));
 $83 = Math_fround($45 * Math_fround(4.0));
 $84 = (Math_fround(+(_fmodf((+$83),3.14159274101257324219))));
 $85 = (($4) + 1156|0);
 HEAPF32[$85>>2] = $80;
 $86 = (($4) + 1160|0);
 HEAPF32[$86>>2] = $81;
 $87 = (($4) + 1164|0);
 HEAPF32[$87>>2] = $82;
 $88 = (($4) + 1168|0);
 HEAPF32[$88>>2] = $84;
 $89 = Math_fround(Math_fround(1.0) / $$0$i11);
 $90 = Math_fround(Math_fround(1.0) / $$0$i9);
 $91 = (($4) + 1172|0);
 HEAPF32[$91>>2] = $$0$i11;
 $92 = (($4) + 1176|0);
 HEAPF32[$92>>2] = $89;
 $93 = (($4) + 1180|0);
 HEAPF32[$93>>2] = $$0$i9;
 $94 = (($4) + 1184|0);
 HEAPF32[$94>>2] = $90;
 $95 = (($this) + 613|0);
 $96 = HEAP8[$95>>0]|0;
 $97 = ($96<<24>>24)==(0);
 do {
  if ($97) {
   $i$03$i$i4 = 0;
   L12: while(1) {
    $j$01$i$i6 = 0;
    while(1) {
     $100 = ($i$03$i$i4|0)==($j$01$i$i6|0);
     if (!($100)) {
      $101 = $j$01$i$i6 << 2;
      $102 = (($101) + ($i$03$i$i4))|0;
      $103 = ((($this) + ($102<<2)|0) + 96|0);
      $104 = Math_fround(HEAPF32[$103>>2]);
      $105 = $104 != Math_fround(0.0);
      if ($105) {
       label = 15;
       break L12;
      }
     }
     $106 = (($j$01$i$i6) + 1)|0;
     $107 = ($106|0)<(3);
     if ($107) {
      $j$01$i$i6 = $106;
     } else {
      break;
     }
    }
    $108 = (($i$03$i$i4) + 1)|0;
    $109 = ($108|0)<(3);
    if ($109) {
     $i$03$i$i4 = $108;
    } else {
     label = 16;
     break;
    }
   }
   if ((label|0) == 15) {
    $110 = (($this) + 456|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $$0$i8 = $111;
   }
   else if ((label|0) == 16) {
    $112 = (($this) + 108|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = (($this) + 124|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = (($this) + 140|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = (($this) + 156|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = (($this) + 104|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    $122 = (($this) + 120|0);
    $123 = Math_fround(HEAPF32[$122>>2]);
    $124 = (($this) + 136|0);
    $125 = Math_fround(HEAPF32[$124>>2]);
    $126 = (($this) + 152|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = Math_fround($113 + $121);
    $129 = Math_fround($115 + $123);
    $130 = Math_fround($117 + $125);
    $131 = Math_fround($119 + $127);
    $132 = Math_fround(-$131);
    $133 = Math_fround($128 * $128);
    $134 = Math_fround($129 * $129);
    $135 = Math_fround($133 + $134);
    $136 = Math_fround($130 * $130);
    $137 = Math_fround($135 + $136);
    $138 = (Math_fround(Math_sqrt((Math_fround($137)))));
    $139 = Math_fround($132 / $138);
    $$0$i8 = $139;
   }
   if ($97) {
    $i$03$i$i = 0;
    L24: while(1) {
     $j$01$i$i = 0;
     while(1) {
      $142 = ($i$03$i$i|0)==($j$01$i$i|0);
      if (!($142)) {
       $143 = $j$01$i$i << 2;
       $144 = (($143) + ($i$03$i$i))|0;
       $145 = ((($this) + ($144<<2)|0) + 96|0);
       $146 = Math_fround(HEAPF32[$145>>2]);
       $147 = $146 != Math_fround(0.0);
       if ($147) {
        label = 24;
        break L24;
       }
      }
      $148 = (($j$01$i$i) + 1)|0;
      $149 = ($148|0)<(3);
      if ($149) {
       $j$01$i$i = $148;
      } else {
       break;
      }
     }
     $150 = (($i$03$i$i) + 1)|0;
     $151 = ($150|0)<(3);
     if ($151) {
      $i$03$i$i = $150;
     } else {
      label = 25;
      break;
     }
    }
    if ((label|0) == 24) {
     $152 = (($this) + 460|0);
     $153 = Math_fround(HEAPF32[$152>>2]);
     $$0$i3 = $153;$$0$i854 = $$0$i8;
     break;
    }
    else if ((label|0) == 25) {
     $154 = (($this) + 108|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = (($this) + 124|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = (($this) + 140|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = (($this) + 156|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = (($this) + 104|0);
     $163 = Math_fround(HEAPF32[$162>>2]);
     $164 = (($this) + 120|0);
     $165 = Math_fround(HEAPF32[$164>>2]);
     $166 = (($this) + 136|0);
     $167 = Math_fround(HEAPF32[$166>>2]);
     $168 = (($this) + 152|0);
     $169 = Math_fround(HEAPF32[$168>>2]);
     $170 = Math_fround($155 - $163);
     $171 = Math_fround($157 - $165);
     $172 = Math_fround($159 - $167);
     $173 = Math_fround($161 - $169);
     $174 = Math_fround($170 * $170);
     $175 = Math_fround($171 * $171);
     $176 = Math_fround($174 + $175);
     $177 = Math_fround($172 * $172);
     $178 = Math_fround($176 + $177);
     $179 = (Math_fround(Math_sqrt((Math_fround($178)))));
     $180 = Math_fround($173 / $179);
     $$0$i3 = $180;$$0$i854 = $$0$i8;
     break;
    }
   } else {
    $$0$i855 = $$0$i8;
    label = 18;
   }
  } else {
   $98 = (($this) + 456|0);
   $99 = Math_fround(HEAPF32[$98>>2]);
   $$0$i855 = $99;
   label = 18;
  }
 } while(0);
 if ((label|0) == 18) {
  $140 = (($this) + 460|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $$0$i3 = $141;$$0$i854 = $$0$i855;
 }
 $181 = $$0$i854 == Math_fround(0.0);
 if ($181) {
  $238 = Math_fround(1.0);
 } else {
  $182 = Math_fround(Math_fround(1.0) / $$0$i854);
  $238 = $182;
 }
 $183 = $$0$i3 == Math_fround(0.0);
 if ($183) {
  $193 = Math_fround(1.0);
 } else {
  $184 = Math_fround(Math_fround(1.0) / $$0$i3);
  $193 = $184;
 }
 $185 = (($4) + 5924|0);
 $186 = HEAP8[$185>>0]|0;
 $187 = ($186<<24>>24)!=(0);
 $188 = $187 ? Math_fround(-1.0) : Math_fround(1.0);
 $189 = (($4) + 580|0);
 HEAPF32[$189>>2] = $188;
 $190 = (($4) + 584|0);
 HEAPF32[$190>>2] = $$0$i854;
 $191 = (($4) + 588|0);
 HEAPF32[$191>>2] = $$0$i3;
 $192 = (($4) + 592|0);
 HEAPF32[$192>>2] = $193;
 __ZL19GetCameraTargetRectRK6Camerab($0,$this,1);
 $194 = (($this) + 396|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = (($this) + 400|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = (($this) + 404|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = (($this) + 408|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = (($0) + 8|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = (($0) + 12|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = Math_fround($195 * $203);
 $207 = Math_fround($199 * $203);
 $208 = Math_fround($197 * $205);
 $209 = Math_fround($201 * $205);
 $210 = Math_fround(HEAPF32[$0>>2]);
 $211 = (($0) + 4|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = Math_fround($206 + $210);
 $214 = Math_fround($208 + $212);
 $215 = Math_fround($207 + $213);
 $216 = Math_fround($209 + $214);
 $217 = Math_fround($203 + $210);
 $218 = Math_fround($205 + $212);
 $219 = $213 < $210;
 $220 = $219 ? $210 : $213;
 $221 = $215 > $217;
 $x2$0$i$i$i = $221 ? $217 : $215;
 $222 = $214 < $212;
 $223 = $222 ? $212 : $214;
 $224 = $216 > $218;
 $y2$0$i$i$i = $224 ? $218 : $216;
 $225 = Math_fround($x2$0$i$i$i - $220);
 $226 = $225 < Math_fround(0.0);
 $storemerge1$i$i$i = $226 ? Math_fround(0.0) : $225;
 $227 = Math_fround($y2$0$i$i$i - $223);
 $228 = $227 < Math_fround(0.0);
 $storemerge$i$i$i = $228 ? Math_fround(0.0) : $227;
 $229 = Math_fround(Math_fround(1.0) / $storemerge1$i$i$i);
 $230 = Math_fround($229 + Math_fround(1.0));
 $231 = Math_fround(Math_fround(1.0) / $storemerge$i$i$i);
 $232 = Math_fround($231 + Math_fround(1.0));
 $233 = (($4) + 596|0);
 HEAPF32[$233>>2] = $storemerge1$i$i$i;
 $234 = (($4) + 600|0);
 HEAPF32[$234>>2] = $storemerge$i$i$i;
 $235 = (($4) + 604|0);
 HEAPF32[$235>>2] = $230;
 $236 = (($4) + 608|0);
 HEAPF32[$236>>2] = $232;
 $237 = Math_fround($$0$i3 * $238);
 $239 = +$237;
 $240 = 1.0 - $239;
 $241 = Math_fround($240);
 $242 = +$193;
 $243 = $240 * $242;
 $244 = Math_fround($243);
 $245 = Math_fround($237 * $193);
 $246 = (($4) + 612|0);
 HEAPF32[$246>>2] = $241;
 $247 = (($4) + 616|0);
 HEAPF32[$247>>2] = $237;
 $248 = (($4) + 620|0);
 HEAPF32[$248>>2] = $244;
 $249 = (($4) + 624|0);
 HEAPF32[$249>>2] = $245;
 $250 = (($this) + 609|0);
 $251 = HEAP8[$250>>0]|0;
 $252 = ($251<<24>>24)==(0);
 if (!($252)) {
  $253 = HEAP8[$95>>0]|0;
  $254 = ($253<<24>>24)==(0);
  if (!($254)) {
   $255 = (($this) + 616|0);
   $256 = HEAP8[$255>>0]|0;
   $257 = ($256<<24>>24)==(0);
   $258 = (($this) + 96|0);
   if ($257) {
    $259 = (($this) + 452|0);
    $260 = Math_fround(HEAPF32[$259>>2]);
    $261 = (($this) + 596|0);
    $262 = Math_fround(HEAPF32[$261>>2]);
    $263 = (($this) + 456|0);
    $264 = Math_fround(HEAPF32[$263>>2]);
    $265 = (($this) + 460|0);
    $266 = Math_fround(HEAPF32[$265>>2]);
    (__ZN10Matrix4x4f14SetPerspectiveEffff($258,$260,$262,$264,$266)|0);
   } else {
    $267 = (($this) + 448|0);
    $268 = Math_fround(HEAPF32[$267>>2]);
    $269 = Math_fround(-$268);
    $270 = (($this) + 596|0);
    $271 = Math_fround(HEAPF32[$270>>2]);
    $272 = Math_fround($271 * $269);
    $273 = Math_fround($268 * $271);
    $274 = (($this) + 456|0);
    $275 = Math_fround(HEAPF32[$274>>2]);
    $276 = (($this) + 460|0);
    $277 = Math_fround(HEAPF32[$276>>2]);
    (__ZN10Matrix4x4f8SetOrthoEffffff($258,$272,$273,$269,$268,$275,$277)|0);
   }
   HEAP8[$250>>0] = 0;
  }
 }
 $278 = (($this) + 96|0);
 $279 = (($this) + 108|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = $280 != Math_fround(0.0);
 if ($281) {
  $300 = Math_fround(0.0);
 } else {
  $282 = (($this) + 124|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = $283 != Math_fround(0.0);
  if ($284) {
   $300 = Math_fround(0.0);
  } else {
   $285 = (($this) + 140|0);
   $286 = Math_fround(HEAPF32[$285>>2]);
   $287 = $286 != Math_fround(0.0);
   if ($287) {
    $300 = Math_fround(0.0);
   } else {
    $288 = (($this) + 156|0);
    $289 = Math_fround(HEAPF32[$288>>2]);
    $290 = $289 != Math_fround(1.0);
    $phitmp = $290 ? Math_fround(0.0) : Math_fround(1.0);
    $300 = $phitmp;
   }
  }
 }
 $291 = (($this) + 448|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = (($this) + 596|0);
 $294 = Math_fround(HEAPF32[$293>>2]);
 $295 = Math_fround($292 * $294);
 $296 = (($4) + 628|0);
 HEAPF32[$296>>2] = $295;
 $297 = (($4) + 632|0);
 HEAPF32[$297>>2] = $292;
 $298 = (($4) + 636|0);
 HEAPF32[$298>>2] = Math_fround(0.0);
 $299 = (($4) + 640|0);
 HEAPF32[$299>>2] = $300;
 $301 = (($4) + 3620|0);
 dest=$301+0|0; src=$278+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 (__Z20InvertMatrix4x4_FullPKfPf($278,$0)|0);
 $302 = (($4) + 3684|0);
 dest=$302+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $303 = (__Z19GetActiveColorSpacev()|0);
 $304 = ($303|0)==(1);
 $$53 = $304 ? Math_fround(0.214041143655776977539) : Math_fround(0.5);
 $305 = (($4) + 1332|0);
 HEAPF32[$305>>2] = $$53;
 $306 = (($4) + 1336|0);
 HEAPF32[$306>>2] = $$53;
 $307 = (($4) + 1340|0);
 HEAPF32[$307>>2] = $$53;
 $308 = (($4) + 1344|0);
 HEAPF32[$308>>2] = Math_fround(0.5);
 $309 = (__Z19GetActiveColorSpacev()|0);
 $310 = ($309|0)==(1);
 $$ = $310 ? Math_fround(5.27803182601928710938) : Math_fround(2.0);
 $311 = (($4) + 1348|0);
 HEAPF32[$311>>2] = $$;
 $312 = (($4) + 1352|0);
 HEAPF32[$312>>2] = $$;
 $313 = (($4) + 1356|0);
 HEAPF32[$313>>2] = $$;
 $314 = (($4) + 1360|0);
 HEAPF32[$314>>2] = Math_fround(2.0);
 $315 = (__Z24GetBillboardBatchManagerv()|0);
 __ZN21BillboardBatchManager12BeforeRenderERK6Camera($315,$this);
 STACKTOP = sp;return;
}
function __ZNK6Camera17GetProjectionNearEv($this) {
 $this = $this|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $i$03$i = 0, $j$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 613|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $i$03$i = 0;
 } else {
  $3 = (($this) + 456|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $$0 = $4;
  STACKTOP = sp;return (Math_fround($$0));
 }
 L4: while(1) {
  $j$01$i = 0;
  while(1) {
   $5 = ($i$03$i|0)==($j$01$i|0);
   if (!($5)) {
    $6 = $j$01$i << 2;
    $7 = (($6) + ($i$03$i))|0;
    $8 = ((($this) + ($7<<2)|0) + 96|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = $9 != Math_fround(0.0);
    if ($10) {
     label = 8;
     break L4;
    }
   }
   $11 = (($j$01$i) + 1)|0;
   $12 = ($11|0)<(3);
   if ($12) {
    $j$01$i = $11;
   } else {
    break;
   }
  }
  $13 = (($i$03$i) + 1)|0;
  $14 = ($13|0)<(3);
  if ($14) {
   $i$03$i = $13;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 8) {
  $15 = (($this) + 456|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $$0 = $16;
  STACKTOP = sp;return (Math_fround($$0));
 }
 else if ((label|0) == 9) {
  $17 = (($this) + 108|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($this) + 124|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($this) + 140|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($this) + 156|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($this) + 104|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($this) + 120|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($this) + 136|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($this) + 152|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($18 + $26);
  $34 = Math_fround($20 + $28);
  $35 = Math_fround($22 + $30);
  $36 = Math_fround($24 + $32);
  $37 = Math_fround(-$36);
  $38 = Math_fround($33 * $33);
  $39 = Math_fround($34 * $34);
  $40 = Math_fround($38 + $39);
  $41 = Math_fround($35 * $35);
  $42 = Math_fround($40 + $41);
  $43 = (Math_fround(Math_sqrt((Math_fround($42)))));
  $44 = Math_fround($37 / $43);
  $$0 = $44;
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZNK6Camera16GetProjectionFarEv($this) {
 $this = $this|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $i$03$i = 0, $j$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 613|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $i$03$i = 0;
 } else {
  $3 = (($this) + 460|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $$0 = $4;
  STACKTOP = sp;return (Math_fround($$0));
 }
 L4: while(1) {
  $j$01$i = 0;
  while(1) {
   $5 = ($i$03$i|0)==($j$01$i|0);
   if (!($5)) {
    $6 = $j$01$i << 2;
    $7 = (($6) + ($i$03$i))|0;
    $8 = ((($this) + ($7<<2)|0) + 96|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = $9 != Math_fround(0.0);
    if ($10) {
     label = 8;
     break L4;
    }
   }
   $11 = (($j$01$i) + 1)|0;
   $12 = ($11|0)<(3);
   if ($12) {
    $j$01$i = $11;
   } else {
    break;
   }
  }
  $13 = (($i$03$i) + 1)|0;
  $14 = ($13|0)<(3);
  if ($14) {
   $i$03$i = $13;
  } else {
   label = 9;
   break;
  }
 }
 if ((label|0) == 8) {
  $15 = (($this) + 460|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $$0 = $16;
  STACKTOP = sp;return (Math_fround($$0));
 }
 else if ((label|0) == 9) {
  $17 = (($this) + 108|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($this) + 124|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($this) + 140|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($this) + 156|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($this) + 104|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($this) + 120|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($this) + 136|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($this) + 152|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($18 - $26);
  $34 = Math_fround($20 - $28);
  $35 = Math_fround($22 - $30);
  $36 = Math_fround($24 - $32);
  $37 = Math_fround($33 * $33);
  $38 = Math_fround($34 * $34);
  $39 = Math_fround($37 + $38);
  $40 = Math_fround($35 * $35);
  $41 = Math_fround($39 + $40);
  $42 = (Math_fround(Math_sqrt((Math_fround($41)))));
  $43 = Math_fround($36 / $42);
  $$0 = $43;
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZNK6Camera17GetSkyboxMaterialEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($2,45)|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 28|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   $8 = (__ZNK6Skybox11GetMaterialEv($3)|0);
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = (__ZNK6Skybox11GetMaterialEv($3)|0);
    $$0 = $10;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = (__Z17GetRenderSettingsv()|0);
 $12 = (($11) + 464|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $13;
 $15 = HEAP32[560624>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  label = 14;
 } else {
  $17 = (($15) + 36|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($15) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($18|0)==($20|0);
  do {
   if ($21) {
    $22 = (($15) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($15) + 32|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + ($25<<3)|0);
    $42 = $26;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$15,$0);
    $27 = HEAP32[$pos$i$i$i$i>>2]|0;
    $28 = ($27|0)==(-1);
    $29 = (($15) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    if ($28) {
     $31 = (($15) + 32|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($30) + ($32<<3)|0);
     $42 = $33;
     break;
    } else {
     $34 = (($30) + ($27<<3)|0);
     $42 = $34;
     break;
    }
   }
  } while(0);
  $35 = HEAP32[560624>>2]|0;
  $36 = (($35) + 28|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + 32|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + ($39<<3)|0);
  $41 = ($42|0)==($40|0);
  if ($41) {
   label = 14;
  } else {
   $43 = (($42) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0|0);
   if ($45) {
    label = 14;
   } else {
    $temp$0$i$i = $44;
   }
  }
 }
 if ((label|0) == 14) {
  $46 = HEAP32[$12>>2]|0;
  $47 = (__Z31ReadObjectFromPersistentManageri($46)|0);
  $temp$0$i$i = $47;
 }
 $$0 = $temp$0$i$i;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6Camera12RenderSkyboxEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 376|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__ZNK6Camera17GetSkyboxMaterialEv($this)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[652824>>2]|0;
 $6 = (($this) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($6,14,$5);
 __ZN6Skybox12RenderSkyboxEPN5Unity8MaterialERK6Camera($3,$this);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($6,15,$5);
 STACKTOP = sp;return;
}
function __ZN6Camera13ClearNoSkyboxEb($this,$noDepth) {
 $this = $this|0;
 $noDepth = $noDepth|0;
 var $$0$i$i$i$i = Math_fround(0), $$0$i1$i$i$i = Math_fround(0), $$0$i3$i$i$i = Math_fround(0), $$byval_copy = 0, $$flags$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0;
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $flags$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = (($this) + 376|0);
 $3 = HEAP32[$2>>2]|0;
 if ((($3|0) == 4)) {
  $flags$0 = 0;
 } else if ((($3|0) == 3)) {
  $flags$0 = 6;
 } else {
  $flags$0 = 7;
 }
 $4 = $flags$0 & 1;
 $$flags$0 = $noDepth ? $4 : $flags$0;
 $5 = ($$flags$0|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 __ZNK6Camera18GetRenderRectangleEv($0,$this);
 $6 = (($this) + 380|0);
 $7 = (__Z19GetActiveColorSpacev()|0);
 $8 = ($7|0)==(1);
 if ($8) {
  $9 = Math_fround(HEAPF32[$6>>2]);
  $10 = !($9 <= Math_fround(0.0404499992728233337402));
  do {
   if ($10) {
    $12 = $9 < Math_fround(1.0);
    if ($12) {
     $13 = Math_fround($9 + Math_fround(0.054999999701976776123));
     $14 = Math_fround($13 / Math_fround(1.05499994754791259766));
     $15 = (Math_fround(+(Math_pow((+$14),2.40000009536743164063))));
     $$0$i$i$i$i = $15;
     break;
    } else {
     $16 = (Math_fround(+(Math_pow((+$9),2.40000009536743164063))));
     $$0$i$i$i$i = $16;
     break;
    }
   } else {
    $11 = Math_fround($9 / Math_fround(12.9200000762939453125));
    $$0$i$i$i$i = $11;
   }
  } while(0);
  $17 = (($this) + 384|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = !($18 <= Math_fround(0.0404499992728233337402));
  do {
   if ($19) {
    $21 = $18 < Math_fround(1.0);
    if ($21) {
     $22 = Math_fround($18 + Math_fround(0.054999999701976776123));
     $23 = Math_fround($22 / Math_fround(1.05499994754791259766));
     $24 = (Math_fround(+(Math_pow((+$23),2.40000009536743164063))));
     $$0$i3$i$i$i = $24;
     break;
    } else {
     $25 = (Math_fround(+(Math_pow((+$18),2.40000009536743164063))));
     $$0$i3$i$i$i = $25;
     break;
    }
   } else {
    $20 = Math_fround($18 / Math_fround(12.9200000762939453125));
    $$0$i3$i$i$i = $20;
   }
  } while(0);
  $26 = (($this) + 388|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = !($27 <= Math_fround(0.0404499992728233337402));
  do {
   if ($28) {
    $30 = $27 < Math_fround(1.0);
    if ($30) {
     $31 = Math_fround($27 + Math_fround(0.054999999701976776123));
     $32 = Math_fround($31 / Math_fround(1.05499994754791259766));
     $33 = (Math_fround(+(Math_pow((+$32),2.40000009536743164063))));
     $$0$i1$i$i$i = $33;
     break;
    } else {
     $34 = (Math_fround(+(Math_pow((+$27),2.40000009536743164063))));
     $$0$i1$i$i$i = $34;
     break;
    }
   } else {
    $29 = Math_fround($27 / Math_fround(12.9200000762939453125));
    $$0$i1$i$i$i = $29;
   }
  } while(0);
  $35 = (($this) + 392|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$1>>2] = $$0$i$i$i$i;
  $37 = (($1) + 4|0);
  HEAPF32[$37>>2] = $$0$i3$i$i$i;
  $38 = (($1) + 8|0);
  HEAPF32[$38>>2] = $$0$i1$i$i$i;
  $39 = (($1) + 12|0);
  HEAPF32[$39>>2] = $36;
 } else {
  ;HEAP32[$1+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$6+12>>2]|0;
 }
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 __ZL16ClearFramebuffer13GfxClearFlags5RectTIfERK10ColorRGBAf($$flags$0,$$byval_copy,$1);
 STACKTOP = sp;return;
}
function __ZL16ClearFramebuffer13GfxClearFlags5RectTIfERK10ColorRGBAf($gfxClearFlags,$rect,$color) {
 $gfxClearFlags = $gfxClearFlags|0;
 $rect = $rect|0;
 $color = $color|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $scissorRect = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scissorRect = sp;
 $0 = (__Z12GetGfxDevicev()|0);
 __Z14RectfToRectIntRK5RectTIfE($scissorRect,$rect);
 __Z22FlipScreenRectIfNeededRK9GfxDeviceR5RectTIiE($0,$scissorRect);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 180|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$scissorRect);
 $4 = (+_emscripten_get_now());
 $5 = HEAP32[652824>>2]|0;
 __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE($gfxClearFlags,$color,Math_fround(1.0),0,$5);
 $6 = (__Z12GetGfxDevicev()|0);
 $7 = (+_emscripten_get_now());
 $8 = (($6) + 5544|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $32 = HEAP32[$0>>2]|0;
  $33 = (($32) + 184|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_vi[$34 & 4095]($0);
  STACKTOP = sp;return;
 }
 $11 = $7 * 1.0E+6;
 $12 = $4 * 1.0E+6;
 $13 = (~~$11)>>>0;
 $14 = +Math_abs($11) >= 1.0 ? $11 > 0.0 ? (Math_min(+Math_floor($11 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($11 - +(~~$11 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $15 = (~~$12)>>>0;
 $16 = +Math_abs($12) >= 1.0 ? $12 > 0.0 ? (Math_min(+Math_floor($12 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($12 - +(~~$12 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $17 = (_i64Subtract(($13|0),($14|0),($15|0),($16|0))|0);
 $18 = tempRet0;
 $19 = (($6) + 5416|0);
 $20 = $19;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 4)|0;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (_i64Add(($17|0),($18|0),($22|0),($25|0))|0);
 $27 = tempRet0;
 $28 = $19;
 $29 = $28;
 HEAP32[$29>>2] = $26;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = $27;
 $32 = HEAP32[$0>>2]|0;
 $33 = (($32) + 184|0);
 $34 = HEAP32[$33>>2]|0;
 FUNCTION_TABLE_vi[$34 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZNK6Camera22CalculateFrustumPlanesEP5PlaneRK10Matrix4x4ffRfb($this,$frustum,$overrideWorldToClip,$overrideFarPlane,$outBaseFarDistance,$implicitNearFar) {
 $this = $this|0;
 $frustum = $frustum|0;
 $overrideWorldToClip = $overrideWorldToClip|0;
 $overrideFarPlane = Math_fround($overrideFarPlane);
 $outBaseFarDistance = $outBaseFarDistance|0;
 $implicitNearFar = $implicitNearFar|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $8 = 0, $9 = 0, $brmerge = 0, $cam2world = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 128|0;
 $1 = sp;
 $cam2world = sp + 64|0;
 __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($overrideWorldToClip,$frustum);
 $2 = (($this) + 612|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $brmerge = $4 | $implicitNearFar;
 if (!($brmerge)) {
  $73 = (($frustum) + 92|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($74 - $overrideFarPlane);
  HEAPF32[$outBaseFarDistance>>2] = $75;
  STACKTOP = sp;return;
 }
 $5 = (($this) + 608|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 $8 = ($3<<24>>24)==(0);
 $or$cond = $7 | $8;
 if (!($or$cond)) {
  $9 = (($this) + 32|0);
  HEAPF32[$0>>2] = Math_fround(1.0);
  $10 = (($0) + 4|0);
  HEAPF32[$10>>2] = Math_fround(1.0);
  $11 = (($0) + 8|0);
  HEAPF32[$11>>2] = Math_fround(-1.0);
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($9,$0)|0);
  $12 = (($this) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($13)|0);
  __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$14);
  (__ZN10Matrix4x4fmLERKS_($9,$1)|0);
  HEAP8[$5>>0] = 0;
 }
 $15 = (($this) + 32|0);
 (__Z20InvertMatrix4x4_FullPKfPf($15,$cam2world)|0);
 $16 = (($cam2world) + 48|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($cam2world) + 52|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($cam2world) + 56|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($cam2world) + 32|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($cam2world) + 36|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($cam2world) + 40|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($23 * $23);
 $29 = Math_fround($25 * $25);
 $30 = Math_fround($28 + $29);
 $31 = Math_fround($27 * $27);
 $32 = Math_fround($30 + $31);
 $33 = (Math_fround(Math_sqrt((Math_fround($32)))));
 $34 = Math_fround(HEAPF32[616648>>2]);
 $35 = $33 > $34;
 if ($35) {
  $36 = Math_fround($23 / $33);
  $37 = Math_fround($25 / $33);
  $38 = Math_fround($27 / $33);
  $43 = $36;$45 = $37;$47 = $38;
 } else {
  $39 = Math_fround(HEAPF32[616680>>2]);
  $40 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
  $41 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
  $43 = $39;$45 = $40;$47 = $41;
 }
 $42 = Math_fround(-$43);
 $44 = Math_fround(-$45);
 $46 = Math_fround(-$47);
 $48 = (($frustum) + 64|0);
 HEAPF32[$48>>2] = $42;
 $49 = (($frustum) + 68|0);
 HEAPF32[$49>>2] = $44;
 $50 = (($frustum) + 72|0);
 HEAPF32[$50>>2] = $46;
 $51 = Math_fround($17 * $42);
 $52 = Math_fround($19 * $44);
 $53 = Math_fround($52 + $51);
 $54 = Math_fround($21 * $46);
 $55 = Math_fround($54 + $53);
 $56 = Math_fround(-$55);
 $57 = (($frustum) + 76|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($this) + 456|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($56 - $59);
 HEAPF32[$57>>2] = $60;
 $61 = (($frustum) + 80|0);
 HEAPF32[$61>>2] = $43;
 $62 = (($frustum) + 84|0);
 HEAPF32[$62>>2] = $45;
 $63 = (($frustum) + 88|0);
 HEAPF32[$63>>2] = $47;
 $64 = Math_fround($17 * $43);
 $65 = Math_fround($19 * $45);
 $66 = Math_fround($65 + $64);
 $67 = Math_fround($21 * $47);
 $68 = Math_fround($67 + $66);
 $69 = Math_fround(-$68);
 $70 = (($frustum) + 92|0);
 HEAPF32[$70>>2] = $69;
 HEAPF32[$outBaseFarDistance>>2] = $69;
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 + $overrideFarPlane);
 HEAPF32[$70>>2] = $72;
 STACKTOP = sp;return;
}
function __ZNK6Camera22GetCameraToWorldMatrixEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = (($this) + 608|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = (($this) + 612|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   $8 = (($this) + 32|0);
   HEAPF32[$0>>2] = Math_fround(1.0);
   $9 = (($0) + 4|0);
   HEAPF32[$9>>2] = Math_fround(1.0);
   $10 = (($0) + 8|0);
   HEAPF32[$10>>2] = Math_fround(-1.0);
   (__ZN10Matrix4x4f8SetScaleERK8Vector3f($8,$0)|0);
   $11 = (($this) + 24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($12)|0);
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$13);
   (__ZN10Matrix4x4fmLERKS_($8,$1)|0);
   HEAP8[$2>>0] = 0;
  }
 }
 $14 = (($this) + 32|0);
 (__Z20InvertMatrix4x4_FullPKfPf($14,$agg$result)|0);
 STACKTOP = sp;return;
}
function __ZNK6Camera26CalculateCullingParametersER17CullingParameters($this,$cullingParameters) {
 $this = $this|0;
 $cullingParameters = $cullingParameters|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $baseFarDistance = 0, $exitcond$i = 0, $frustum = 0, $i$01$i = 0, $worldToClipMatrix = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $frustum = sp + 88|0;
 $baseFarDistance = sp;
 $worldToClipMatrix = sp + 8|0;
 $0 = sp + 72|0;
 HEAPF32[$frustum>>2] = Math_fround(0.0);
 $1 = (($frustum) + 4|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($frustum) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($frustum) + 16|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($frustum) + 20|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($frustum) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($frustum) + 32|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($frustum) + 36|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($frustum) + 40|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($frustum) + 48|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($frustum) + 52|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($frustum) + 56|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($frustum) + 64|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($frustum) + 68|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($frustum) + 72|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($frustum) + 80|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($frustum) + 84|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($frustum) + 88|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (__ZNK6Camera20GetWorldToClipMatrixEv($this)|0);
 dest=$worldToClipMatrix+0|0; src=$18+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $19 = (($cullingParameters) + 532|0);
 _memmove(($19|0),($18|0),64)|0;
 $20 = (($cullingParameters) + 596|0);
 $21 = (($this) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($22)|0);
 __ZNK9Transform11GetPositionEv($0,$23);
 ;HEAP32[$20+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$0+8>>2]|0;
 $24 = (($this) + 460|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 __ZNK6Camera22CalculateFrustumPlanesEP5PlaneRK10Matrix4x4ffRfb($this,$frustum,$worldToClipMatrix,$25,$baseFarDistance,0);
 __ZNK6Camera32CalculateCustomCullingParametersER17CullingParametersPK5Planei($this,$cullingParameters,$frustum,6);
 $26 = (($this) + 618|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)==(0);
 if (!($28)) {
  $29 = (($this) + 468|0);
  $30 = (($cullingParameters) + 196|0);
  _memmove(($30|0),($29|0),128)|0;
  $31 = (($cullingParameters) + 324|0);
  HEAP32[$31>>2] = 2;
  STACKTOP = sp;return;
 }
 $32 = Math_fround(HEAPF32[$baseFarDistance>>2]);
 $i$01$i = 0;
 while(1) {
  $33 = ((($this) + ($i$01$i<<2)|0) + 468|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = $34 != Math_fround(0.0);
  if ($35) {
   $36 = Math_fround($32 + $34);
   $37 = ((($cullingParameters) + ($i$01$i<<2)|0) + 196|0);
   HEAPF32[$37>>2] = $36;
  } else {
   $38 = Math_fround(HEAPF32[$24>>2]);
   $39 = Math_fround($32 + $38);
   $40 = ((($cullingParameters) + ($i$01$i<<2)|0) + 196|0);
   HEAPF32[$40>>2] = $39;
  }
  $41 = (($i$01$i) + 1)|0;
  $exitcond$i = ($41|0)==(32);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $41;
  }
 }
 $42 = (($cullingParameters) + 324|0);
 HEAP32[$42>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNK6Camera20GetWorldToClipMatrixEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = (($this) + 610|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$pre = (($this) + 160|0);
  $$pre$phiZ2D = $$pre;
  STACKTOP = sp;return ($$pre$phiZ2D|0);
 }
 $5 = (($this) + 609|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($this) + 613|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if (!($10)) {
   $11 = (($this) + 616|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = ($12<<24>>24)==(0);
   $14 = (($this) + 96|0);
   if ($13) {
    $15 = (($this) + 452|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = (($this) + 596|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = (($this) + 456|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = (($this) + 460|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    (__ZN10Matrix4x4f14SetPerspectiveEffff($14,$16,$18,$20,$22)|0);
   } else {
    $23 = (($this) + 448|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = Math_fround(-$24);
    $26 = (($this) + 596|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = Math_fround($27 * $25);
    $29 = Math_fround($24 * $27);
    $30 = (($this) + 456|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = (($this) + 460|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    (__ZN10Matrix4x4f8SetOrthoEffffff($14,$28,$29,$25,$24,$31,$33)|0);
   }
   HEAP8[$5>>0] = 0;
  }
 }
 $34 = (($this) + 96|0);
 $35 = (($this) + 608|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)==(0);
 if (!($37)) {
  $38 = (($this) + 612|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = ($39<<24>>24)==(0);
  if (!($40)) {
   $41 = (($this) + 32|0);
   HEAPF32[$0>>2] = Math_fround(1.0);
   $42 = (($0) + 4|0);
   HEAPF32[$42>>2] = Math_fround(1.0);
   $43 = (($0) + 8|0);
   HEAPF32[$43>>2] = Math_fround(-1.0);
   (__ZN10Matrix4x4f8SetScaleERK8Vector3f($41,$0)|0);
   $44 = (($this) + 24|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($45)|0);
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$46);
   (__ZN10Matrix4x4fmLERKS_($41,$1)|0);
   HEAP8[$35>>0] = 0;
  }
 }
 $47 = (($this) + 32|0);
 $48 = (($this) + 160|0);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($34,$47,$48);
 HEAP8[$2>>0] = 0;
 $$pre$phiZ2D = $48;
 STACKTOP = sp;return ($$pre$phiZ2D|0);
}
function __ZNK6Camera11GetPositionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($1)|0);
 __ZNK9Transform11GetPositionEv($agg$result,$2);
 STACKTOP = sp;return;
}
function __ZNK6Camera32CalculateCustomCullingParametersER17CullingParametersPK5Planei($this,$cullingParameters,$planes,$planeCount) {
 $this = $this|0;
 $cullingParameters = $cullingParameters|0;
 $planes = $planes|0;
 $planeCount = $planeCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $screenRect$i$i = 0, $y2$0$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $screenRect$i$i = sp + 24|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = (($this) + 616|0);
 $3 = HEAP8[$2>>0]|0;
 HEAP8[$cullingParameters>>0] = $3;
 $4 = (($cullingParameters) + 4|0);
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($6)|0);
 __ZNK9Transform11GetPositionEv($0,$7);
 ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;
 $8 = (($this) + 452|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($cullingParameters) + 16|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($this) + 448|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($cullingParameters) + 20|0);
 HEAPF32[$13>>2] = $12;
 __ZL19GetCameraTargetRectRK6Camerab($screenRect$i$i,$this,0);
 $14 = (($this) + 400|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 408|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($screenRect$i$i) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($15 * $19);
 $21 = Math_fround($17 * $19);
 $22 = (($screenRect$i$i) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($20 + $23);
 $25 = Math_fround($21 + $24);
 $26 = Math_fround($19 + $23);
 $27 = $24 < $23;
 $28 = $27 ? $23 : $24;
 $29 = $25 > $26;
 $y2$0$i$i$i = $29 ? $26 : $25;
 $30 = Math_fround($y2$0$i$i$i - $28);
 $31 = $30 < Math_fround(0.0);
 $32 = (~~(($30)));
 $33 = $31 ? 0 : $32;
 $34 = (($cullingParameters) + 24|0);
 HEAP32[$34>>2] = $33;
 __Z16SetCullingPlanesR17CullingParametersPK5Planei($cullingParameters,$planes,$planeCount);
 $35 = (($cullingParameters) + 188|0);
 HEAP32[$35>>2] = $planeCount;
 $36 = (($cullingParameters) + 324|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 412|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($cullingParameters) + 192|0);
 HEAP32[$39>>2] = $38;
 $40 = (__ZNK6Camera20GetWorldToClipMatrixEv($this)|0);
 $41 = (($cullingParameters) + 532|0);
 _memmove(($41|0),($40|0),64)|0;
 $42 = (($cullingParameters) + 596|0);
 $43 = HEAP32[$5>>2]|0;
 $44 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($43)|0);
 __ZNK9Transform11GetPositionEv($1,$44);
 ;HEAP32[$42+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$1+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN6Camera10CustomCullERK23CameraCullingParametersR11CullResults($this,$parameters,$results) {
 $this = $this|0;
 $parameters = $parameters|0;
 $results = $results|0;
 var $$$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$$i = 0, $or$cond = 0, $temp$0$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $$byval_copy = sp + 224|0;
 $0 = sp;
 $1 = sp + 200|0;
 $2 = sp + 208|0;
 $3 = sp + 212|0;
 $4 = (($this) + 622|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = (($this) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(569824,0,569816,1053,1,$8,0,0);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 404|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = !($10 <= Math_fround(9.99999974737875163555E-6));
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 408|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = !($13 <= Math_fround(9.99999974737875163555E-6));
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 396|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = !($16 >= Math_fround(1.0));
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = Math_fround($10 + $16);
 $19 = !($18 <= Math_fround(0.0));
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = (($this) + 400|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = !($21 >= Math_fround(1.0));
 if (!($22)) {
  STACKTOP = sp;return;
 }
 $23 = Math_fround($13 + $21);
 $24 = !($23 <= Math_fround(0.0));
 if (!($24)) {
  STACKTOP = sp;return;
 }
 $25 = (($this) + 460|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 456|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = !($26 <= $28);
 if (!($29)) {
  STACKTOP = sp;return;
 }
 $30 = (($this) + 616|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  $33 = !($28 <= Math_fround(0.0));
  if (!($33)) {
   STACKTOP = sp;return;
  }
  $34 = (($this) + 452|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = $35 < Math_fround(0.0);
  if ($36) {
   $37 = Math_fround(-$35);
   $39 = $37;
  } else {
   $39 = $35;
  }
  $38 = $39 < Math_fround(9.99999997475242707878E-7);
  if ($38) {
   STACKTOP = sp;return;
  }
 } else {
  $40 = (($this) + 448|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = $41 < Math_fround(0.0);
  if ($42) {
   $43 = Math_fround(-$41);
   $45 = $43;
  } else {
   $45 = $41;
  }
  $44 = $45 < Math_fround(9.99999997475242707878E-7);
  if ($44) {
   STACKTOP = sp;return;
  }
 }
 $46 = (($$byval_copy) + 8|0);
 HEAP32[$46>>2] = 0;
 $47 = (($$byval_copy) + 4|0);
 HEAP32[$47>>2] = 0;
 HEAP32[$$byval_copy>>2] = 0;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,564824,$$byval_copy);
 $48 = (__Z17GetMonoManagerPtrv()|0);
 $49 = ($48|0)==(0|0);
 if (!($49)) {
  $50 = (__Z19GetScriptingManagerv()|0);
  $51 = (($50) + 628|0);
  $52 = $51;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 4)|0;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = $1;
  $59 = $58;
  HEAP32[$59>>2] = $54;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = $57;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
  __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($0,$$byval_copy);
  $62 = (__ZN9Scripting19ScriptingWrapperForEP6Object($this)|0);
  $63 = (($0) + 32|0);
  __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($63,$62);
  (__ZN19ScriptingInvocation6InvokeEv($0)|0);
 }
 $64 = (($this) + 24|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  label = 23;
 } else {
  $67 = (__ZNK5Unity10GameObject8IsActiveEv($65)|0);
  if ($67) {
   $68 = (($this) + 28|0);
   $69 = HEAP8[$68>>0]|0;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    label = 23;
   }
  } else {
   label = 23;
  }
 }
 if ((label|0) == 23) {
  $71 = (($parameters) + 12|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = $72 & 1;
  $74 = ($73|0)==(0);
  if ($74) {
   STACKTOP = sp;return;
  }
 }
 HEAP8[$4>>0] = 1;
 $75 = (($this) + 412|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (__Z18GetITerrainManagerv()|0);
 $78 = ($76|0)==(0);
 $79 = ($77|0)==(0|0);
 $or$cond = $78 | $79;
 if (!($or$cond)) {
  $80 = HEAP32[$77>>2]|0;
  $81 = (($80) + 20|0);
  $82 = HEAP32[$81>>2]|0;
  FUNCTION_TABLE_vii[$82 & 4095]($77,$76);
 }
 $83 = (__ZN5Unity8GetSceneEv()|0);
 __ZN5Unity5Scene22RecalculateDirtyBoundsEv($83);
 $84 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
 __ZN6Camera29PrepareSceneCullingParametersERK23CameraCullingParameters13RenderingPathR11CullResults($parameters,$84,$results);
 $85 = (($parameters) + 4|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(0|0);
 do {
  if ($87) {
   $99 = (($this) + 356|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==(0);
   if (!($101)) {
    HEAP32[$0>>2] = $100;
    $102 = HEAP32[560624>>2]|0;
    $103 = ($102|0)==(0|0);
    if ($103) {
     label = 38;
    } else {
     $104 = (($102) + 36|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = (($102) + 4|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ($105|0)==($107|0);
     do {
      if ($108) {
       $109 = (($102) + 28|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = (($102) + 32|0);
       $112 = HEAP32[$111>>2]|0;
       $113 = (($110) + ($112<<3)|0);
       $129 = $113;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$102,$0);
       $114 = HEAP32[$$byval_copy>>2]|0;
       $115 = ($114|0)==(-1);
       $116 = (($102) + 28|0);
       $117 = HEAP32[$116>>2]|0;
       if ($115) {
        $118 = (($102) + 32|0);
        $119 = HEAP32[$118>>2]|0;
        $120 = (($117) + ($119<<3)|0);
        $129 = $120;
        break;
       } else {
        $121 = (($117) + ($114<<3)|0);
        $129 = $121;
        break;
       }
      }
     } while(0);
     $122 = HEAP32[560624>>2]|0;
     $123 = (($122) + 28|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = (($122) + 32|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = (($124) + ($126<<3)|0);
     $128 = ($129|0)==($127|0);
     if ($128) {
      label = 38;
     } else {
      $130 = (($129) + 4|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = ($131|0)==(0|0);
      if ($132) {
       label = 38;
      } else {
       $temp$0$i3 = $131;
      }
     }
    }
    if ((label|0) == 38) {
     $133 = HEAP32[$99>>2]|0;
     $134 = (__Z31ReadObjectFromPersistentManageri($133)|0);
     $135 = ($134|0)==(0|0);
     if ($135) {
      break;
     } else {
      $temp$0$i3 = $134;
     }
    }
    $136 = (($this) + 360|0);
    $137 = (($results) + 1068|0);
    HEAP32[$137>>2] = $temp$0$i3;
    $138 = HEAP8[$136>>0]|0;
    $139 = $138 & 1;
    $140 = ($139<<24>>24)==(0);
    if ($140) {
     $143 = $138&255;
     $144 = $143 >>> 1;
     $146 = $144;
    } else {
     $141 = (($this) + 364|0);
     $142 = HEAP32[$141>>2]|0;
     $146 = $142;
    }
    $145 = ($146|0)==(0);
    if ($145) {
     $149 = -1;
    } else {
     $147 = (__ZN9ShaderLab14GetShaderTagIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($136)|0);
     $149 = $147;
    }
    $148 = (($results) + 1072|0);
    HEAP32[$148>>2] = $149;
   }
  } else {
   $88 = (($results) + 1068|0);
   $89 = $85;
   $90 = $89;
   $91 = HEAP32[$90>>2]|0;
   $92 = (($89) + 4)|0;
   $93 = $92;
   $94 = HEAP32[$93>>2]|0;
   $95 = $88;
   $96 = $95;
   HEAP32[$96>>2] = $91;
   $97 = (($95) + 4)|0;
   $98 = $97;
   HEAP32[$98>>2] = $94;
  }
 } while(0);
 $150 = (($results) + 240|0);
 $151 = (($results) + 913|0);
 $152 = HEAP8[$151>>0]|0;
 $153 = ($152<<24>>24)==(0);
 if (!($153)) {
  $154 = HEAP32[628512>>2]|0;
  HEAP32[$2>>2] = $154;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
  $155 = (__Znwj10MemLabelIdbiPKci(612,$$byval_copy,0,16,569816,1107)|0);
  $156 = (($155) + 196|0);
  $157 = (($155) + 364|0);
  HEAPF32[$157>>2] = Math_fround(0.0);
  $158 = (($155) + 368|0);
  ;HEAP32[$156+0>>2]=0|0;HEAP32[$156+4>>2]=0|0;HEAP32[$156+8>>2]=0|0;HEAP32[$156+12>>2]=0|0;HEAP32[$156+16>>2]=0|0;HEAP32[$156+20>>2]=0|0;
  HEAPF32[$158>>2] = Math_fround(0.0);
  $159 = (($155) + 372|0);
  HEAPF32[$159>>2] = Math_fround(0.0);
  $160 = (($155) + 380|0);
  HEAPF32[$160>>2] = Math_fround(0.0);
  $161 = (($155) + 384|0);
  HEAPF32[$161>>2] = Math_fround(0.0);
  $162 = (($155) + 388|0);
  HEAPF32[$162>>2] = Math_fround(0.0);
  $163 = (($155) + 396|0);
  HEAPF32[$163>>2] = Math_fround(0.0);
  $164 = (($155) + 400|0);
  HEAPF32[$164>>2] = Math_fround(0.0);
  $165 = (($155) + 404|0);
  HEAPF32[$165>>2] = Math_fround(0.0);
  $166 = (($155) + 412|0);
  HEAPF32[$166>>2] = Math_fround(0.0);
  $167 = (($155) + 416|0);
  HEAPF32[$167>>2] = Math_fround(0.0);
  $168 = (($155) + 420|0);
  HEAPF32[$168>>2] = Math_fround(0.0);
  $169 = (($155) + 428|0);
  HEAPF32[$169>>2] = Math_fround(0.0);
  $170 = (($155) + 432|0);
  HEAPF32[$170>>2] = Math_fround(0.0);
  $171 = (($155) + 436|0);
  HEAPF32[$171>>2] = Math_fround(0.0);
  $172 = (($155) + 444|0);
  HEAPF32[$172>>2] = Math_fround(0.0);
  $173 = (($155) + 448|0);
  HEAPF32[$173>>2] = Math_fround(0.0);
  $174 = (($155) + 452|0);
  HEAPF32[$174>>2] = Math_fround(0.0);
  $175 = (($155) + 460|0);
  HEAPF32[$175>>2] = Math_fround(0.0);
  $176 = (($155) + 464|0);
  HEAPF32[$176>>2] = Math_fround(0.0);
  $177 = (($155) + 468|0);
  HEAPF32[$177>>2] = Math_fround(0.0);
  $178 = (($155) + 476|0);
  HEAPF32[$178>>2] = Math_fround(0.0);
  $179 = (($155) + 480|0);
  HEAPF32[$179>>2] = Math_fround(0.0);
  $180 = (($155) + 484|0);
  HEAPF32[$180>>2] = Math_fround(0.0);
  $181 = (($155) + 492|0);
  HEAPF32[$181>>2] = Math_fround(0.0);
  $182 = (($155) + 496|0);
  HEAPF32[$182>>2] = Math_fround(0.0);
  $183 = (($155) + 500|0);
  HEAPF32[$183>>2] = Math_fround(0.0);
  $184 = (($155) + 508|0);
  HEAPF32[$184>>2] = Math_fround(0.0);
  $185 = (($155) + 512|0);
  HEAPF32[$185>>2] = Math_fround(0.0);
  $186 = (($155) + 516|0);
  HEAPF32[$186>>2] = Math_fround(0.0);
  $187 = (($155) + 524|0);
  HEAPF32[$187>>2] = Math_fround(0.0);
  $188 = (($155) + 528|0);
  HEAPF32[$188>>2] = Math_fround(0.0);
  $189 = (($155) + 532|0);
  HEAPF32[$189>>2] = Math_fround(0.0);
  $190 = (($155) + 540|0);
  HEAPF32[$190>>2] = Math_fround(0.0);
  $191 = (($155) + 544|0);
  HEAPF32[$191>>2] = Math_fround(0.0);
  $192 = (($155) + 548|0);
  HEAPF32[$192>>2] = Math_fround(0.0);
  $193 = (($155) + 556|0);
  HEAPF32[$193>>2] = Math_fround(0.0);
  $194 = (($155) + 560|0);
  HEAPF32[$194>>2] = Math_fround(0.0);
  $195 = (($155) + 564|0);
  HEAPF32[$195>>2] = Math_fround(0.0);
  $196 = (($155) + 604|0);
  HEAP32[$196>>2] = 0;
  $197 = (($155) + 608|0);
  HEAP32[$197>>2] = -1;
  $198 = HEAP32[$parameters>>2]|0;
  $199 = (($198) + 24|0);
  $200 = HEAP32[$199>>2]|0;
  $201 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($200)|0);
  __ZNK9Transform11GetPositionEv($3,$201);
  $202 = (($results) + 1068|0);
  __Z19SetupShadowCullDataR6CameraRK8Vector3fRK17ShaderReplaceDataPK22SceneCullingParametersR14ShadowCullData($198,$3,$202,$150,$155);
  $203 = (($results) + 80|0);
  $204 = HEAP32[$203>>2]|0;
  $205 = (($results) + 928|0);
  $206 = HEAP32[$205>>2]|0;
  $207 = ($206|0)!=(0|0);
  $not$$i = ($204|0)!=(0|0);
  $$$i = $207 & $not$$i;
  if ($$$i) {
   $208 = (($results) + 16|0);
   $209 = (($155) + 596|0);
   HEAP32[$209>>2] = $208;
  }
  $210 = (($results) + 1024|0);
  HEAP32[$210>>2] = $155;
 }
 __Z9CullSceneR22SceneCullingParametersR11CullResults($150,$results);
 $211 = (($results) + 1076|0);
 HEAP8[$211>>0] = 1;
 HEAP8[$4>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN6Camera4CullER11CullResults($this,$results) {
 $this = $this|0;
 $results = $results|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $parameters = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $parameters = sp;
 $0 = (($parameters) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($parameters) + 8|0);
 HEAP32[$1>>2] = -1;
 HEAP32[$parameters>>2] = $this;
 $2 = (($parameters) + 12|0);
 HEAP32[$2>>2] = 4;
 $3 = (($parameters) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($parameters) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 617|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  HEAP32[$2>>2] = 6;
 }
 __ZN6Camera10CustomCullERK23CameraCullingParametersR11CullResults($this,$parameters,$results);
 STACKTOP = sp;return;
}
function __ZN6Camera29PrepareSceneCullingParametersERK23CameraCullingParameters13RenderingPathR11CullResults($parameters,$renderPath,$results) {
 $parameters = $parameters|0;
 $renderPath = $renderPath|0;
 $results = $results|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $phitmp = 0, $tomeData$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($parameters) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $tomeData$0 = 0;
 } else {
  $4 = (__ZN5Unity8GetSceneEv()|0);
  $5 = (($4) + 116|0);
  $6 = HEAP32[$5>>2]|0;
  $tomeData$0 = $6;
 }
 $7 = (__ZN5Unity8GetSceneEv()|0);
 $8 = (__ZNK5Unity5Scene22GetStaticBoundingBoxesEv($7)|0);
 $9 = (($results) + 848|0);
 HEAP32[$9>>2] = $8;
 $10 = (__ZN5Unity8GetSceneEv()|0);
 $11 = (__ZNK5Unity5Scene19GetStaticSceneNodesEv($10)|0);
 $12 = (($results) + 852|0);
 HEAP32[$12>>2] = $11;
 $13 = (__ZN5Unity8GetSceneEv()|0);
 $14 = (__ZNK5Unity5Scene20GetStaticObjectCountEv($13)|0);
 $15 = (($results) + 856|0);
 HEAP32[$15>>2] = $14;
 $16 = (__ZN5Unity8GetSceneEv()|0);
 $17 = (__ZNK5Unity5Scene23GetDynamicBoundingBoxesEv($16)|0);
 $18 = (($results) + 860|0);
 HEAP32[$18>>2] = $17;
 $19 = (__ZN5Unity8GetSceneEv()|0);
 $20 = (__ZNK5Unity5Scene20GetDynamicSceneNodesEv($19)|0);
 $21 = (($results) + 864|0);
 HEAP32[$21>>2] = $20;
 $22 = (__ZN5Unity8GetSceneEv()|0);
 $23 = (__ZNK5Unity5Scene21GetDynamicObjectCountEv($22)|0);
 $24 = (($results) + 868|0);
 HEAP32[$24>>2] = $23;
 $25 = (__ZN5Unity8GetSceneEv()|0);
 $26 = (__ZNK21IntermediateRenderers16GetBoundingBoxesEv($25)|0);
 $27 = (($results) + 872|0);
 HEAP32[$27>>2] = $26;
 $28 = (__ZNK21IntermediateRenderers13GetSceneNodesEv($25)|0);
 $29 = (($results) + 876|0);
 HEAP32[$29>>2] = $28;
 $30 = (($25) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($results) + 880|0);
 HEAP32[$32>>2] = $31;
 $33 = HEAP32[$parameters>>2]|0;
 $34 = (($33) + 372|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (__ZNK21IntermediateRenderers16GetBoundingBoxesEv($35)|0);
 $37 = (($results) + 884|0);
 HEAP32[$37>>2] = $36;
 $38 = (__ZNK21IntermediateRenderers13GetSceneNodesEv($35)|0);
 $39 = (($results) + 888|0);
 HEAP32[$39>>2] = $38;
 $40 = (($35) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($results) + 892|0);
 HEAP32[$42>>2] = $41;
 $43 = (__Z18GetITerrainManagerv()|0);
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = HEAP32[$43>>2]|0;
  $46 = (($45) + 68|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($results) + 992|0);
  $49 = (($results) + 1008|0);
  FUNCTION_TABLE_viii[$47 & 4095]($43,$48,$49);
 }
 $50 = (($results) + 1008|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($results) + 896|0);
 HEAP32[$52>>2] = $51;
 $53 = (($results) + 992|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($results) + 900|0);
 HEAP32[$55>>2] = $54;
 $56 = (($results) + 1016|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($results) + 904|0);
 HEAP32[$58>>2] = $57;
 $59 = (($results) + 848|0);
 __ZN11CullResults4InitEPKN5Umbra4TomeEPK16RendererCullData($results,$tomeData$0,$59);
 $60 = HEAP32[$parameters>>2]|0;
 $61 = (($results) + 240|0);
 __ZNK6Camera26CalculateCullingParametersER17CullingParameters($60,$61);
 $62 = (($results) + 16|0);
 $63 = (($results) + 924|0);
 HEAP32[$63>>2] = $62;
 $64 = (($parameters) + 16|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($results) + 936|0);
 HEAP32[$66>>2] = $65;
 $67 = (($parameters) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($results) + 940|0);
 HEAP32[$69>>2] = $68;
 $70 = (($results) + 928|0);
 HEAP32[$70>>2] = $tomeData$0;
 $71 = (__ZN5Unity8GetSceneEv()|0);
 $72 = (($71) + 112|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($results) + 932|0);
 HEAP32[$74>>2] = $73;
 $75 = HEAP32[$0>>2]|0;
 $76 = (($results) + 913|0);
 $77 = $75 >>> 2;
 $$lobit = $77 & 1;
 $78 = $$lobit&255;
 HEAP8[$76>>0] = $78;
 $79 = ($renderPath|0)==(1);
 if (!($79)) {
  $84 = 0;
  $83 = (($results) + 912|0);
  HEAP8[$83>>0] = $84;
  $85 = (($results) + 916|0);
  HEAP32[$85>>2] = $renderPath;
  $86 = ($tomeData$0|0)!=(0|0);
  $87 = (($results) + 76|0);
  $88 = $86&1;
  HEAP8[$87>>0] = $88;
  __ZN6Camera21PrepareLODCullingDataER11CullResultsb($results,0);
  STACKTOP = sp;return;
 }
 $80 = (__Z19GetLightmapSettingsv()|0);
 $81 = (__ZNK16LightmapSettings28GetUseDualLightmapsInForwardEv($80)|0);
 $82 = $81&1;
 $phitmp = $82 ^ 1;
 $84 = $phitmp;
 $83 = (($results) + 912|0);
 HEAP8[$83>>0] = $84;
 $85 = (($results) + 916|0);
 HEAP32[$85>>2] = $renderPath;
 $86 = ($tomeData$0|0)!=(0|0);
 $87 = (($results) + 76|0);
 $88 = $86&1;
 HEAP8[$87>>0] = $88;
 __ZN6Camera21PrepareLODCullingDataER11CullResultsb($results,0);
 STACKTOP = sp;return;
}
function __ZNK6Camera25GetRenderImmediateObjectsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN6Camera21PrepareLODCullingDataER11CullResultsb($results,$skipTerrainLODGroupManagers) {
 $results = $results|0;
 $skipTerrainLODGroupManagers = $skipTerrainLODGroupManagers|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$01$i$i = 0, $$byval_copy19 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i6 = 0, $$pre$phiZ2D = 0, $$pre29 = 0, $$pre30 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0;
 var $i$028 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp = 0, $phitmp32 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy19 = sp + 88|0;
 $0 = sp + 84|0;
 $1 = sp + 80|0;
 $2 = sp + 76|0;
 $3 = sp + 72|0;
 $4 = sp + 68|0;
 $5 = sp + 64|0;
 $6 = sp + 60|0;
 $7 = sp + 44|0;
 $8 = sp + 40|0;
 $9 = sp + 24|0;
 $10 = sp + 8|0;
 $11 = sp;
 $12 = sp + 48|0;
 $13 = (__ZN15LODGroupManager13GetIDPoolSizeEv()|0);
 $14 = (($results) + 952|0);
 $15 = HEAP32[628512>>2]|0;
 HEAP32[$9>>2] = 0;
 $16 = (($9) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = (($9) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = (($9) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = (($results) + 956|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$14>>2]|0;
 $22 = $20;
 $23 = $21;
 $24 = (($22) - ($23))|0;
 $25 = $24 >> 4;
 $26 = ($25>>>0)<($13>>>0);
 L1: do {
  if ($26) {
   $27 = (($13) - ($25))|0;
   __THREW__ = 0;
   invoke_viii(1671,($14|0),($27|0),($9|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    $$pre = HEAP32[$18>>2]|0;
    $phitmp = ($$pre|0)>(-1);
    if ($phitmp) {
     label = 12;
     break;
    } else {
     break;
    }
   }
   $89 = ___cxa_find_matching_catch()|0;
   $90 = tempRet0;
   $91 = HEAP32[$18>>2]|0;
   $92 = ($91|0)>(-1);
   if (!($92)) {
    $$0 = $89;$$01 = $90;
    ___resumeException($$0|0);
    // unreachable;
   }
   $93 = HEAP32[$9>>2]|0;
   $94 = HEAP32[$16>>2]|0;
   HEAP32[$8>>2] = $94;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$8+0>>2]|0;
   invoke_vii(2591,($93|0),($$byval_copy19|0));
   $95 = __THREW__; __THREW__ = 0;
   $96 = $95&1;
   if ($96) {
    $243 = ___cxa_find_matching_catch(0|0)|0;
    $244 = tempRet0;
    ___clang_call_terminate($243);
    // unreachable;
   }
   HEAP32[$9>>2] = 0;
   $$0 = $89;$$01 = $90;
   ___resumeException($$0|0);
   // unreachable;
  } else {
   $30 = ($25>>>0)>($13>>>0);
   if ($30) {
    $31 = (($21) + ($13<<4)|0);
    $32 = ($20|0)==($31|0);
    if ($32) {
     label = 12;
    } else {
     $34 = $20;
     while(1) {
      $33 = (($34) + -16|0);
      HEAP32[$19>>2] = $33;
      $35 = (($34) + -4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($36|0)>(-1);
      if ($37) {
       $40 = HEAP32[$33>>2]|0;
       $41 = (($34) + -12|0);
       $42 = HEAP32[$41>>2]|0;
       HEAP32[$0>>2] = $42;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($40|0),($$byval_copy19|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       HEAP32[$33>>2] = 0;
       $$pre$i$i$i = HEAP32[$19>>2]|0;
       $39 = $$pre$i$i$i;
      } else {
       $39 = $33;
      }
      $38 = ($39|0)==($31|0);
      if ($38) {
       label = 12;
       break L1;
      } else {
       $34 = $39;
      }
     }
     $45 = ___cxa_find_matching_catch()|0;
     $46 = tempRet0;
     ___cxa_call_unexpected(($45|0));
     // unreachable;
    }
   } else {
    label = 12;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $47 = HEAP32[$9>>2]|0;
  $48 = HEAP32[$16>>2]|0;
  HEAP32[$0>>2] = $48;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($47,$$byval_copy19);
  HEAP32[$9>>2] = 0;
 }
 $49 = (($results) + 964|0);
 $50 = HEAP32[628512>>2]|0;
 HEAP32[$10>>2] = 0;
 $51 = (($10) + 4|0);
 HEAP32[$51>>2] = $50;
 $52 = (($10) + 8|0);
 HEAP32[$52>>2] = 0;
 $53 = (($10) + 12|0);
 HEAP32[$53>>2] = 0;
 $54 = (($results) + 968|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$49>>2]|0;
 $57 = $55;
 $58 = $56;
 $59 = (($57) - ($58))|0;
 $60 = $59 >> 4;
 $61 = ($60>>>0)<($13>>>0);
 L26: do {
  if ($61) {
   $62 = (($13) - ($60))|0;
   __THREW__ = 0;
   invoke_viii(1672,($49|0),($62|0),($10|0));
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if (!($64)) {
    $$pre29 = HEAP32[$53>>2]|0;
    $phitmp32 = ($$pre29|0)>(-1);
    if ($phitmp32) {
     label = 24;
     break;
    } else {
     break;
    }
   }
   $97 = ___cxa_find_matching_catch()|0;
   $98 = tempRet0;
   $99 = HEAP32[$53>>2]|0;
   $100 = ($99|0)>(-1);
   if (!($100)) {
    $$0 = $97;$$01 = $98;
    ___resumeException($$0|0);
    // unreachable;
   }
   $101 = HEAP32[$10>>2]|0;
   $102 = HEAP32[$51>>2]|0;
   HEAP32[$7>>2] = $102;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$7+0>>2]|0;
   invoke_vii(2591,($101|0),($$byval_copy19|0));
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    $243 = ___cxa_find_matching_catch(0|0)|0;
    $244 = tempRet0;
    ___clang_call_terminate($243);
    // unreachable;
   }
   HEAP32[$10>>2] = 0;
   $$0 = $97;$$01 = $98;
   ___resumeException($$0|0);
   // unreachable;
  } else {
   $65 = ($60>>>0)>($13>>>0);
   if ($65) {
    $66 = (($56) + ($13<<4)|0);
    $67 = ($55|0)==($66|0);
    if ($67) {
     label = 24;
    } else {
     $69 = $55;
     while(1) {
      $68 = (($69) + -16|0);
      HEAP32[$54>>2] = $68;
      $70 = (($69) + -4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($71|0)>(-1);
      if ($72) {
       $75 = HEAP32[$68>>2]|0;
       $76 = (($69) + -12|0);
       $77 = HEAP32[$76>>2]|0;
       HEAP32[$0>>2] = $77;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($75|0),($$byval_copy19|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
       HEAP32[$68>>2] = 0;
       $$pre$i$i$i6 = HEAP32[$54>>2]|0;
       $74 = $$pre$i$i$i6;
      } else {
       $74 = $68;
      }
      $73 = ($74|0)==($66|0);
      if ($73) {
       label = 24;
       break L26;
      } else {
       $69 = $74;
      }
     }
     $80 = ___cxa_find_matching_catch()|0;
     $81 = tempRet0;
     ___cxa_call_unexpected(($80|0));
     // unreachable;
    }
   } else {
    label = 24;
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $82 = HEAP32[$10>>2]|0;
  $83 = HEAP32[$51>>2]|0;
  HEAP32[$0>>2] = $83;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($82,$$byval_copy19);
  HEAP32[$10>>2] = 0;
 }
 $84 = $13 << 2;
 $85 = (($84) + 15)|0;
 $86 = ($85>>>0)<(2000);
 $87 = ($13|0)!=(0);
 if ($86) {
  if ($87) {
   $88 = STACKTOP; STACKTOP = STACKTOP + ((((1*$85)|0)+15)&-16)|0;;
   $116 = 0;$allocPtr$0 = $88;
   label = 42;
  } else {
   $116 = 0;$allocPtr$0 = 0;
   label = 42;
  }
 } else {
  if ($87) {
   $105 = HEAP32[628512>>2]|0;
   HEAP32[$11>>2] = $105;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$11+0>>2]|0;
   $106 = (invoke_iiiiiii(102,($85|0),16,($$byval_copy19|0),0,(569816|0),995)|0);
   $107 = __THREW__; __THREW__ = 0;
   $108 = $107&1;
   if ($108) {
    $109 = ___cxa_find_matching_catch()|0;
    $110 = tempRet0;
    $245 = $6;$246 = $110;$247 = $109;
   } else {
    $116 = $106;$allocPtr$0 = $106;
    label = 42;
   }
  } else {
   $116 = 0;$allocPtr$0 = 0;
   label = 42;
  }
 }
 if ((label|0) == 42) {
  $120 = $allocPtr$0;
  $121 = (($120) + 15)|0;
  $122 = $121 & -16;
  $123 = $122;
  $124 = $122;
  _memset(($123|0),0,($84|0))|0;
  __THREW__ = 0;
  $125 = (invoke_i(72)|0);
  $126 = __THREW__; __THREW__ = 0;
  $127 = $126&1;
  L59: do {
   if ($127) {
    label = 38;
   } else {
    HEAP32[$124>>2] = $125;
    if (!($skipTerrainLODGroupManagers)) {
     __THREW__ = 0;
     $128 = (invoke_i(73)|0);
     $129 = __THREW__; __THREW__ = 0;
     $130 = $129&1;
     if ($130) {
      label = 38;
      break;
     }
     $131 = ($128|0)==(0|0);
     if (!($131)) {
      $132 = HEAP32[$128>>2]|0;
      $133 = (($132) + 72|0);
      $134 = HEAP32[$133>>2]|0;
      __THREW__ = 0;
      invoke_viii($134|0,($128|0),($124|0),($13|0));
      $135 = __THREW__; __THREW__ = 0;
      $136 = $135&1;
      if ($136) {
       label = 38;
       break;
      }
     }
    }
    $137 = (($results) + 976|0);
    ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
    $138 = (($results) + 988|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = $139 & 2147483647;
    $141 = ($140>>>0)<($13>>>0);
    do {
     if ($141) {
      $142 = ($139|0)>(-1);
      if ($142) {
       HEAP32[$138>>2] = $13;
       $143 = HEAP32[$137>>2]|0;
       $144 = ($13*12)|0;
       $145 = (($results) + 980|0);
       $146 = HEAP32[$145>>2]|0;
       HEAP32[$4>>2] = $146;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
       $147 = (invoke_iiiiiiii(108,($143|0),($144|0),4,($$byval_copy19|0),0,(569816|0),370)|0);
       $148 = __THREW__; __THREW__ = 0;
       $149 = $148&1;
       if ($149) {
        label = 38;
        break L59;
       }
       HEAP32[$137>>2] = $147;
       break;
      } else {
       $150 = ($13*12)|0;
       $151 = (($results) + 980|0);
       $152 = HEAP32[$151>>2]|0;
       HEAP32[$5>>2] = $152;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$5+0>>2]|0;
       $153 = (invoke_iiiiiii(102,($150|0),4,($$byval_copy19|0),0,(569816|0),352)|0);
       $154 = __THREW__; __THREW__ = 0;
       $155 = $154&1;
       if ($155) {
        label = 38;
        break L59;
       }
       $156 = HEAP32[$137>>2]|0;
       $157 = (($results) + 984|0);
       $158 = HEAP32[$157>>2]|0;
       $159 = ($158*12)|0;
       _memcpy(($153|0),($156|0),($159|0))|0;
       HEAP32[$138>>2] = $13;
       HEAP32[$137>>2] = $153;
       break;
      }
     }
    } while(0);
    $160 = (($results) + 984|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = ($161>>>0)<($13>>>0);
    if ($162) {
     $163 = HEAP32[$137>>2]|0;
     $164 = (($163) + (($13*12)|0)|0);
     $165 = ($161|0)==($13|0);
     if (!($165)) {
      $166 = (($163) + (($161*12)|0)|0);
      $$01$i$i = $166;
      while(1) {
       $167 = ($$01$i$i|0)==(0|0);
       if (!($167)) {
        ;HEAP32[$$01$i$i+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$12+8>>2]|0;
       }
       $168 = (($$01$i$i) + 12|0);
       $169 = ($168|0)==($164|0);
       if ($169) {
        break;
       } else {
        $$01$i$i = $168;
       }
      }
     }
    }
    HEAP32[$160>>2] = $13;
    $170 = ($13|0)>(0);
    L83: do {
     if ($170) {
      $171 = (($results) + 240|0);
      $i$028 = 0;
      L86: while(1) {
       $172 = (($124) + ($i$028<<2)|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ($173|0)==(0|0);
       if (!($174)) {
        $175 = HEAP32[$173>>2]|0;
        __THREW__ = 0;
        $176 = (invoke_i(72)|0);
        $177 = __THREW__; __THREW__ = 0;
        $178 = $177&1;
        if ($178) {
         break;
        }
        $179 = ($173|0)==($176|0);
        $$ = $179 ? 0 : $175;
        $180 = HEAP32[$14>>2]|0;
        $181 = (($180) + ($$<<4)|0);
        $182 = HEAP32[$49>>2]|0;
        $183 = (($182) + ($$<<4)|0);
        $184 = (($173) + 12|0);
        $185 = HEAP32[$184>>2]|0;
        $186 = ((($180) + ($$<<4)|0) + 8|0);
        HEAP32[$186>>2] = $185;
        $187 = ((($180) + ($$<<4)|0) + 12|0);
        $188 = HEAP32[$187>>2]|0;
        $189 = $188 & 2147483647;
        $190 = ($189>>>0)<($185>>>0);
        do {
         if ($190) {
          $191 = ($188|0)>(-1);
          if ($191) {
           HEAP32[$187>>2] = $185;
           $192 = HEAP32[$181>>2]|0;
           $193 = ((($180) + ($$<<4)|0) + 4|0);
           $194 = HEAP32[$193>>2]|0;
           HEAP32[$0>>2] = $194;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
           $195 = (invoke_iiiiiiii(108,($192|0),($185|0),1,($$byval_copy19|0),0,(569816|0),370)|0);
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            break L86;
           }
           HEAP32[$181>>2] = $195;
           break;
          } else {
           $198 = ((($180) + ($$<<4)|0) + 4|0);
           $199 = HEAP32[$198>>2]|0;
           HEAP32[$1>>2] = $199;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
           $200 = (invoke_iiiiiii(102,($185|0),1,($$byval_copy19|0),0,(569816|0),352)|0);
           $201 = __THREW__; __THREW__ = 0;
           $202 = $201&1;
           if ($202) {
            break L86;
           }
           $203 = HEAP32[$181>>2]|0;
           $204 = HEAP32[$186>>2]|0;
           _memcpy(($200|0),($203|0),($204|0))|0;
           HEAP32[$187>>2] = $185;
           HEAP32[$181>>2] = $200;
           break;
          }
         }
        } while(0);
        $205 = ((($182) + ($$<<4)|0) + 8|0);
        HEAP32[$205>>2] = $185;
        $206 = ((($182) + ($$<<4)|0) + 12|0);
        $207 = HEAP32[$206>>2]|0;
        $208 = $207 & 2147483647;
        $209 = ($208>>>0)<($185>>>0);
        do {
         if ($209) {
          $210 = ($207|0)>(-1);
          if ($210) {
           HEAP32[$206>>2] = $185;
           $211 = HEAP32[$183>>2]|0;
           $212 = $185 << 2;
           $213 = ((($182) + ($$<<4)|0) + 4|0);
           $214 = HEAP32[$213>>2]|0;
           HEAP32[$2>>2] = $214;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
           $215 = (invoke_iiiiiiii(108,($211|0),($212|0),4,($$byval_copy19|0),0,(569816|0),370)|0);
           $216 = __THREW__; __THREW__ = 0;
           $217 = $216&1;
           if ($217) {
            break L86;
           }
           HEAP32[$183>>2] = $215;
           $228 = $215;
           break;
          } else {
           $218 = $185 << 2;
           $219 = ((($182) + ($$<<4)|0) + 4|0);
           $220 = HEAP32[$219>>2]|0;
           HEAP32[$3>>2] = $220;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
           $221 = (invoke_iiiiiii(102,($218|0),4,($$byval_copy19|0),0,(569816|0),352)|0);
           $222 = __THREW__; __THREW__ = 0;
           $223 = $222&1;
           if ($223) {
            break L86;
           }
           $224 = HEAP32[$183>>2]|0;
           $225 = HEAP32[$205>>2]|0;
           $226 = $225 << 2;
           _memcpy(($221|0),($224|0),($226|0))|0;
           HEAP32[$206>>2] = $185;
           HEAP32[$183>>2] = $221;
           $228 = $221;
           break;
          }
         } else {
          $$pre30 = HEAP32[$183>>2]|0;
          $228 = $$pre30;
         }
        } while(0);
        $227 = HEAP32[$181>>2]|0;
        __THREW__ = 0;
        invoke_viiii(343,($173|0),($171|0),($227|0),($228|0));
        $229 = __THREW__; __THREW__ = 0;
        $230 = $229&1;
        if ($230) {
         break;
        }
        $231 = HEAP32[$137>>2]|0;
        $232 = HEAP32[$181>>2]|0;
        $233 = (($231) + (($$*12)|0)|0);
        HEAP32[$233>>2] = $232;
        $234 = HEAP32[$183>>2]|0;
        $235 = ((($231) + (($$*12)|0)|0) + 4|0);
        HEAP32[$235>>2] = $234;
        $236 = ((($231) + (($$*12)|0)|0) + 8|0);
        HEAP32[$236>>2] = $185;
       }
       $237 = (($i$028) + 1)|0;
       $238 = ($237|0)<($13|0);
       if ($238) {
        $i$028 = $237;
       } else {
        $$pre$phiZ2D = $137;
        break L83;
       }
      }
      $111 = ___cxa_find_matching_catch()|0;
      $112 = tempRet0;
      $lpad$phi$index = $111;$lpad$phi$index2 = $112;
      break L59;
     } else {
      $$pre$phiZ2D = $137;
     }
    } while(0);
    $239 = HEAP32[$$pre$phiZ2D>>2]|0;
    $240 = (($results) + 908|0);
    HEAP32[$240>>2] = $239;
    $241 = ($116|0)==(0|0);
    if ($241) {
     STACKTOP = sp;return;
    }
    $242 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $242;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($116,$$byval_copy19);
    STACKTOP = sp;return;
   }
  } while(0);
  if ((label|0) == 38) {
   $113 = ___cxa_find_matching_catch()|0;
   $114 = tempRet0;
   $lpad$phi$index = $113;$lpad$phi$index2 = $114;
  }
  $115 = ($116|0)==(0|0);
  if ($115) {
   $245 = $6;$246 = $lpad$phi$index2;$247 = $lpad$phi$index;
  } else {
   $117 = HEAP32[628512>>2]|0;
   HEAP32[$6>>2] = $117;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$6+0>>2]|0;
   invoke_vii(2591,($116|0),($$byval_copy19|0));
   $118 = __THREW__; __THREW__ = 0;
   $119 = $118&1;
   if ($119) {
    $243 = ___cxa_find_matching_catch(0|0)|0;
    $244 = tempRet0;
    ___clang_call_terminate($243);
    // unreachable;
   } else {
    $245 = $6;$246 = $lpad$phi$index2;$247 = $lpad$phi$index;
   }
  }
 }
 $$0 = $247;$$01 = $246;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNK6Camera22CalculateRenderingPathEv($this) {
 $this = $this|0;
 var $$ = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $not$ = 0, $phitmp3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 464|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $3 = (__Z17GetPlayerSettingsv()|0);
  $4 = (__ZN14PlayerSettings23GetRenderingPathRuntimeEv($3)|0);
  $6 = $4;
 } else {
  $6 = $1;
 }
 $5 = ($6|0)==(3);
 $7 = $6 & -2;
 $8 = ($7|0)==(2);
 if (!($8)) {
  $50 = $6;
  STACKTOP = sp;return ($50|0);
 }
 $9 = HEAP8[((640792 + 263|0))>>0]|0;
 $10 = ($9<<24>>24)==(0);
 $$not = ($6|0)!=(2);
 $brmerge = $10 | $$not;
 if ($brmerge) {
  $11 = HEAP8[((640792 + 264|0))>>0]|0;
  $not$ = ($11<<24>>24)!=(0);
  $$ = $5 & $not$;
  if (!($$)) {
   $50 = 1;
   STACKTOP = sp;return ($50|0);
  }
 }
 $12 = (($this) + 616|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  $50 = 1;
  STACKTOP = sp;return ($50|0);
 }
 $15 = (__ZN13RenderTexture9IsEnabledEv()|0);
 if (!($15)) {
  $50 = 1;
  STACKTOP = sp;return ($50|0);
 }
 $16 = (($this) + 609|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if (!($18)) {
  $19 = (($this) + 613|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if (!($21)) {
   $22 = HEAP8[$12>>0]|0;
   $23 = ($22<<24>>24)==(0);
   $24 = (($this) + 96|0);
   if ($23) {
    $25 = (($this) + 452|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = (($this) + 596|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = (($this) + 456|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = (($this) + 460|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    (__ZN10Matrix4x4f14SetPerspectiveEffff($24,$26,$28,$30,$32)|0);
   } else {
    $33 = (($this) + 448|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = Math_fround(-$34);
    $36 = (($this) + 596|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = Math_fround($37 * $35);
    $39 = Math_fround($34 * $37);
    $40 = (($this) + 456|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = (($this) + 460|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    (__ZN10Matrix4x4f8SetOrthoEffffff($24,$38,$39,$35,$34,$41,$43)|0);
   }
   HEAP8[$16>>0] = 0;
  }
 }
 $44 = (($this) + 104|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = $45 != Math_fround(0.0);
 if ($46) {
  $50 = 1;
  STACKTOP = sp;return ($50|0);
 }
 $47 = (($this) + 120|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = $48 != Math_fround(0.0);
 $phitmp3 = $49 ? 1 : $6;
 $50 = $phitmp3;
 STACKTOP = sp;return ($50|0);
}
function __ZNK6Camera16GetStereoEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 292|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$4,$0);
     $16 = HEAP32[$pos$i$i$i$i$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if (!($30)) {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     $44 = 0;
     STACKTOP = sp;return ($44|0);
    }
   }
  }
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $44 = 0;
   STACKTOP = sp;return ($44|0);
  }
 }
 $38 = (__Z12GetGfxDevicev()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 780|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (FUNCTION_TABLE_ii[$41 & 4095]($38)|0);
 $43 = ($42|0)!=(0);
 $44 = $43;
 STACKTOP = sp;return ($44|0);
}
function __ZN6Camera8DoRenderER11CullResultsPFvRS_R10RenderLoopS1_Ei($this,$cullResults,$customRender,$renderFlags) {
 $this = $this|0;
 $cullResults = $cullResults|0;
 $customRender = $customRender|0;
 $renderFlags = $renderFlags|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $invocation = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$byval_copy = sp + 208|0;
 $invocation = sp;
 $0 = sp + 200|0;
 $1 = (($this) + 404|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = !($2 <= Math_fround(9.99999974737875163555E-6));
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 408|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = !($5 <= Math_fround(9.99999974737875163555E-6));
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 396|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 >= Math_fround(1.0));
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = Math_fround($2 + $8);
 $11 = !($10 <= Math_fround(0.0));
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 400|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = !($13 >= Math_fround(1.0));
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = Math_fround($5 + $13);
 $16 = !($15 <= Math_fround(0.0));
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 460|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 456|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = !($18 <= $20);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 616|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $25 = !($20 <= Math_fround(0.0));
  if (!($25)) {
   STACKTOP = sp;return;
  }
  $26 = (($this) + 452|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = $27 < Math_fround(0.0);
  if ($28) {
   $29 = Math_fround(-$27);
   $31 = $29;
  } else {
   $31 = $27;
  }
  $30 = $31 < Math_fround(9.99999997475242707878E-7);
  if ($30) {
   STACKTOP = sp;return;
  }
 } else {
  $32 = (($this) + 448|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = $33 < Math_fround(0.0);
  if ($34) {
   $35 = Math_fround(-$33);
   $37 = $35;
  } else {
   $37 = $33;
  }
  $36 = $37 < Math_fround(9.99999997475242707878E-7);
  if ($36) {
   STACKTOP = sp;return;
  }
 }
 $38 = $renderFlags & 32;
 $39 = ($38|0)==(0);
 $40 = ($customRender|0)==(0|0);
 if ($40) {
  $43 = (($cullResults) + 916|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($this) + 288|0);
  $46 = HEAP32[$45>>2]|0;
  __Z12DoRenderLoopR10RenderLoop13RenderingPathR11CullResultsb($46,$44,$cullResults,0);
 } else {
  $41 = (($this) + 288|0);
  $42 = HEAP32[$41>>2]|0;
  FUNCTION_TABLE_viii[$customRender & 4095]($this,$42,$cullResults);
 }
 if ($39) {
  $47 = (($tmpcast$byval_copy) + 8|0);
  HEAP32[$47>>2] = 0;
  $48 = (($tmpcast$byval_copy) + 4|0);
  HEAP32[$48>>2] = 0;
  HEAP32[$tmpcast$byval_copy>>2] = 0;
  __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,564864,$tmpcast$byval_copy);
  $49 = (__Z17GetMonoManagerPtrv()|0);
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   $51 = (__Z19GetScriptingManagerv()|0);
   $52 = (($51) + 644|0);
   $53 = $52;
   $54 = $53;
   $55 = HEAP32[$54>>2]|0;
   $56 = (($53) + 4)|0;
   $57 = $56;
   $58 = HEAP32[$57>>2]|0;
   $59 = $0;
   $60 = $59;
   HEAP32[$60>>2] = $55;
   $61 = (($59) + 4)|0;
   $62 = $61;
   HEAP32[$62>>2] = $58;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
   $63 = (__ZN9Scripting19ScriptingWrapperForEP6Object($this)|0);
   $64 = (($invocation) + 32|0);
   __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($64,$63);
   (__ZN19ScriptingInvocation6InvokeEv($invocation)|0);
  }
 }
 $65 = (__Z12GetGfxDevicev()|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 136|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($65,0);
 __ZN6Shader23HandleShadersWithErrorsEv();
 STACKTOP = sp;return;
}
function __ZNK6Camera21CalculateCanDoShadowsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16ShouldUseShadowsb(1)|0);
 if (!($0)) {
  $35 = 0;
  STACKTOP = sp;return ($35|0);
 }
 $1 = (($this) + 609|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 613|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   $7 = (($this) + 616|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   $10 = (($this) + 96|0);
   if ($9) {
    $11 = (($this) + 452|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    $13 = (($this) + 596|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $15 = (($this) + 456|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = (($this) + 460|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    (__ZN10Matrix4x4f14SetPerspectiveEffff($10,$12,$14,$16,$18)|0);
   } else {
    $19 = (($this) + 448|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = Math_fround(-$20);
    $22 = (($this) + 596|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = Math_fround($23 * $21);
    $25 = Math_fround($20 * $23);
    $26 = (($this) + 456|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = (($this) + 460|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    (__ZN10Matrix4x4f8SetOrthoEffffff($10,$24,$25,$21,$20,$27,$29)|0);
   }
   HEAP8[$1>>0] = 0;
  }
 }
 $30 = (($this) + 104|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = $31 != Math_fround(0.0);
 if ($32) {
  $35 = 0;
  STACKTOP = sp;return ($35|0);
 }
 $33 = (($this) + 120|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $phitmp = $34 == Math_fround(0.0);
 $35 = $phitmp;
 STACKTOP = sp;return ($35|0);
}
function __ZNK6Camera23CalculateShadowDistanceEv($this) {
 $this = $this|0;
 var $0 = Math_fround(0), $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZN15QualitySettings29GetShadowDistanceForRenderingEv()));
 $1 = (($this) + 460|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 < $0;
 $4 = $3 ? $2 : $0;
 STACKTOP = sp;return (Math_fround($4));
}
function __Z16StoreRenderStateR20CameraRenderOldState($state) {
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i$i$i = 0, $temp$0$i$i$i2 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i$i$i = sp + 24|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = (($state) + 16|0);
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + 176|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($1,$2);
 ;HEAP32[$3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$1+12>>2]|0;
 $7 = (($state) + 36|0);
 $8 = (__ZN13RenderTexture9GetActiveEv()|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  HEAP32[$7>>2] = 0;
 } else {
  $10 = (($8) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$7>>2] = $11;
 }
 $12 = (($state) + 32|0);
 $13 = (__Z16GetRenderManagerv()|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 do {
  if ($15) {
   label = 14;
  } else {
   HEAP32[$0>>2] = $14;
   $16 = HEAP32[560624>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    label = 13;
   } else {
    $18 = (($16) + 36|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($16) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($19|0)==($21|0);
    do {
     if ($22) {
      $23 = (($16) + 28|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($16) + 32|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + ($26<<3)|0);
      $43 = $27;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i$i,$16,$0);
      $28 = HEAP32[$pos$i$i$i$i$i$i>>2]|0;
      $29 = ($28|0)==(-1);
      $30 = (($16) + 28|0);
      $31 = HEAP32[$30>>2]|0;
      if ($29) {
       $32 = (($16) + 32|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = (($31) + ($33<<3)|0);
       $43 = $34;
       break;
      } else {
       $35 = (($31) + ($28<<3)|0);
       $43 = $35;
       break;
      }
     }
    } while(0);
    $36 = HEAP32[560624>>2]|0;
    $37 = (($36) + 28|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 32|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($38) + ($40<<3)|0);
    $42 = ($43|0)==($41|0);
    if ($42) {
     label = 13;
    } else {
     $44 = (($43) + 4|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      label = 13;
     } else {
      $temp$0$i$i$i2 = $45;
     }
    }
   }
   if ((label|0) == 13) {
    $47 = HEAP32[$13>>2]|0;
    $48 = (__Z31ReadObjectFromPersistentManageri($47)|0);
    $49 = ($48|0)==(0|0);
    if ($49) {
     label = 14;
     break;
    } else {
     $temp$0$i$i$i2 = $48;
    }
   }
   $50 = (($temp$0$i$i$i2) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$12>>2] = $51;
  }
 } while(0);
 if ((label|0) == 14) {
  HEAP32[$12>>2] = 0;
 }
 $52 = (($state) + 104|0);
 $53 = HEAP32[$2>>2]|0;
 $54 = (($53) + 116|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (FUNCTION_TABLE_ii[$55 & 4095]($2)|0);
 dest=$52+0|0; src=$56+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $57 = (($state) + 40|0);
 $58 = HEAP32[$2>>2]|0;
 $59 = (($58) + 112|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (FUNCTION_TABLE_ii[$60 & 4095]($2)|0);
 dest=$57+0|0; src=$61+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $62 = (($state) + 168|0);
 $63 = HEAP32[$2>>2]|0;
 $64 = (($63) + 120|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (FUNCTION_TABLE_ii[$65 & 4095]($2)|0);
 dest=$62+0|0; src=$66+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z18RestoreRenderStateR20CameraRenderOldStateRN9ShaderLab17ShaderPassContextE($state,$passContext) {
 $state = $state|0;
 $passContext = $passContext|0;
 var $$0$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $pos$i$i$i$i1 = 0, $temp$0$i10 = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = (($state) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 do {
  if ($5) {
   $6 = (__Z16GetRenderManagerv()|0);
   $43 = $6;
   label = 13;
  } else {
   HEAP32[$1>>2] = $4;
   $7 = HEAP32[560624>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 12;
   } else {
    $9 = (($7) + 36|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    do {
     if ($13) {
      $14 = (($7) + 28|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($7) + 32|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($15) + ($17<<3)|0);
      $34 = $18;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$7,$1);
      $19 = HEAP32[$pos$i$i$i$i1>>2]|0;
      $20 = ($19|0)==(-1);
      $21 = (($7) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      if ($20) {
       $23 = (($7) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $34 = $25;
       break;
      } else {
       $26 = (($22) + ($19<<3)|0);
       $34 = $26;
       break;
      }
     }
    } while(0);
    $27 = HEAP32[560624>>2]|0;
    $28 = (($27) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + ($31<<3)|0);
    $33 = ($34|0)==($32|0);
    if ($33) {
     label = 12;
    } else {
     $35 = (($34) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      label = 12;
     } else {
      $38 = (__Z16GetRenderManagerv()|0);
      $46 = $38;$temp$0$i10 = $36;
     }
    }
   }
   if ((label|0) == 12) {
    $39 = HEAP32[$3>>2]|0;
    $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
    $41 = (__Z16GetRenderManagerv()|0);
    $42 = ($40|0)==(0|0);
    if ($42) {
     $43 = $41;
     label = 13;
     break;
    } else {
     $46 = $41;$temp$0$i10 = $40;
    }
   }
   $44 = (($temp$0$i10) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   HEAP32[$46>>2] = $45;
   __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($temp$0$i10,$passContext,0);
  }
 } while(0);
 if ((label|0) == 13) {
  HEAP32[$43>>2] = 0;
 }
 $47 = (($state) + 36|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0);
 if ($49) {
  $$0$i6 = 0;
 } else {
  HEAP32[$0>>2] = $48;
  $50 = HEAP32[560624>>2]|0;
  $51 = ($50|0)==(0|0);
  if ($51) {
   label = 24;
  } else {
   $52 = (($50) + 36|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($50) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($53|0)==($55|0);
   do {
    if ($56) {
     $57 = (($50) + 28|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($50) + 32|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (($58) + ($60<<3)|0);
     $77 = $61;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$50,$0);
     $62 = HEAP32[$pos$i$i$i$i1>>2]|0;
     $63 = ($62|0)==(-1);
     $64 = (($50) + 28|0);
     $65 = HEAP32[$64>>2]|0;
     if ($63) {
      $66 = (($50) + 32|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($65) + ($67<<3)|0);
      $77 = $68;
      break;
     } else {
      $69 = (($65) + ($62<<3)|0);
      $77 = $69;
      break;
     }
    }
   } while(0);
   $70 = HEAP32[560624>>2]|0;
   $71 = (($70) + 28|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($70) + 32|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($72) + ($74<<3)|0);
   $76 = ($77|0)==($75|0);
   if ($76) {
    label = 24;
   } else {
    $78 = (($77) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($79|0)==(0|0);
    if ($80) {
     label = 24;
    } else {
     $temp$0$i5 = $79;
    }
   }
  }
  if ((label|0) == 24) {
   $81 = HEAP32[$47>>2]|0;
   $82 = (__Z31ReadObjectFromPersistentManageri($81)|0);
   $temp$0$i5 = $82;
  }
  $$0$i6 = $temp$0$i5;
 }
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($$0$i6,0,-1,0);
 $83 = HEAP32[$2>>2]|0;
 $84 = (($83) + 172|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($state) + 16|0);
 FUNCTION_TABLE_vii[$85 & 4095]($2,$86);
 $87 = HEAP32[$2>>2]|0;
 $88 = (($87) + 104|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($state) + 168|0);
 FUNCTION_TABLE_vii[$89 & 4095]($2,$90);
 $91 = HEAP32[$2>>2]|0;
 $92 = (($91) + 100|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($state) + 104|0);
 FUNCTION_TABLE_vii[$93 & 4095]($2,$94);
 $95 = HEAP32[$2>>2]|0;
 $96 = (($95) + 96|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = (($state) + 40|0);
 FUNCTION_TABLE_vii[$97 & 4095]($2,$98);
 __Z27SetClippingPlaneShaderPropsv();
 STACKTOP = sp;return;
}
function __ZN6Camera16StandaloneRenderEjP6ShaderRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($this,$renderFlags,$replacementShader,$replacementTag) {
 $this = $this|0;
 $renderFlags = $renderFlags|0;
 $replacementShader = $replacementShader|0;
 $replacementTag = $replacementTag|0;
 var $$ = 0, $$$v = 0, $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $cullResults = 0, $parameters$i = 0, $state = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1344|0;
 $parameters$i = sp + 1312|0;
 $state = sp;
 $cullResults = sp + 232|0;
 $0 = HEAP32[652824>>2]|0;
 __ZN13RenderManager18UpdateAllRenderersEv();
 HEAP32[$state>>2] = 0;
 $1 = (($state) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($state) + 16|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 $3 = $renderFlags & 8;
 $4 = ($3|0)==(0);
 if ($4) {
  __Z16StoreRenderStateR20CameraRenderOldState($state);
 }
 $5 = (__Z16GetRenderManagerv()|0);
 $6 = ($this|0)==(0|0);
 if ($6) {
  HEAP32[$5>>2] = 0;
 } else {
  $7 = (($this) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$5>>2] = $8;
 }
 __ZN6Camera20WindowSizeHasChangedEv($this);
 __ZN11CullResultsC2Ev($cullResults);
 $9 = (($parameters$i) + 4|0);
 HEAP32[$9>>2] = 0;
 $10 = (($parameters$i) + 8|0);
 HEAP32[$10>>2] = -1;
 HEAP32[$parameters$i>>2] = $this;
 $11 = (($parameters$i) + 12|0);
 HEAP32[$11>>2] = 5;
 $12 = (($parameters$i) + 16|0);
 HEAP32[$12>>2] = 0;
 $13 = (($parameters$i) + 20|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 617|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if (!($16)) {
  HEAP32[$11>>2] = 7;
 }
 $17 = ($replacementShader|0)==(0|0);
 do {
  if ($17) {
   label = 15;
  } else {
   HEAP32[$9>>2] = $replacementShader;
   $18 = HEAP8[$replacementTag>>0]|0;
   $19 = $18 & 1;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $23 = $18&255;
    $24 = $23 >>> 1;
    $26 = $24;
   } else {
    $21 = (($replacementTag) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $26 = $22;
   }
   $25 = ($26|0)==(0);
   if ($25) {
    $30 = -1;
   } else {
    __THREW__ = 0;
    $27 = (invoke_ii(3224,($replacementTag|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 21;
     break;
    } else {
     $30 = $27;
    }
   }
   HEAP32[$10>>2] = $30;
   label = 15;
  }
 } while(0);
 L20: do {
  if ((label|0) == 15) {
   __THREW__ = 0;
   invoke_viii(1673,($this|0),($parameters$i|0),($cullResults|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 21;
   } else {
    __THREW__ = 0;
    $33 = (invoke_i(59)|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 21;
    } else {
     $36 = (($33) + 5784|0);
     $37 = HEAP8[$36>>0]|0;
     $38 = ($37<<24>>24)==(0);
     if ($38) {
      $39 = HEAP32[$33>>2]|0;
      $40 = (($39) + 504|0);
      $41 = HEAP32[$40>>2]|0;
      __THREW__ = 0;
      invoke_vi($41|0,($33|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       label = 21;
       break;
      }
      $44 = HEAP32[$33>>2]|0;
      $45 = (($44) + 516|0);
      $46 = HEAP32[$45>>2]|0;
      __THREW__ = 0;
      $47 = (invoke_ii($46|0,($33|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 21;
       break;
      }
      if ($47) {
       $55 = 1;
       label = 25;
      }
     } else {
      $55 = 0;
      label = 25;
     }
     L28: do {
      if ((label|0) == 25) {
       $$$v = $17 ? 1 : 33;
       $$ = $$$v | $renderFlags;
       __THREW__ = 0;
       invoke_viiii(344,($this|0),($cullResults|0),($0|0),($$|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       do {
        if (!($65)) {
         if ($4) {
          __THREW__ = 0;
          invoke_vii(2622,($state|0),($0|0));
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           break;
          }
         }
         $68 = ($55<<24>>24)==(0);
         if (!($68)) {
          break L28;
         }
         __ZN11CullResultsD2Ev($cullResults);
         STACKTOP = sp;return;
        }
       } while(0);
       $52 = ___cxa_find_matching_catch()|0;
       $53 = tempRet0;
       $54 = ($55<<24>>24)==(0);
       if ($54) {
        $$0 = $53;$$01 = $52;
        break L20;
       }
       __THREW__ = 0;
       $56 = (invoke_i(59)|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        $79 = ___cxa_find_matching_catch(0|0)|0;
        $80 = tempRet0;
        ___clang_call_terminate($79);
        // unreachable;
       }
       $59 = HEAP32[$56>>2]|0;
       $60 = (($59) + 508|0);
       $61 = HEAP32[$60>>2]|0;
       __THREW__ = 0;
       invoke_vi($61|0,($56|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if (!($63)) {
        $$0 = $53;$$01 = $52;
        break L20;
       }
       $79 = ___cxa_find_matching_catch(0|0)|0;
       $80 = tempRet0;
       ___clang_call_terminate($79);
       // unreachable;
      }
     } while(0);
     __THREW__ = 0;
     $69 = (invoke_i(59)|0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      label = 21;
     } else {
      $72 = HEAP32[$69>>2]|0;
      $73 = (($72) + 508|0);
      $74 = HEAP32[$73>>2]|0;
      __THREW__ = 0;
      invoke_vi($74|0,($69|0));
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 21;
      } else {
       __ZN11CullResultsD2Ev($cullResults);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  $$0 = $51;$$01 = $50;
 }
 __THREW__ = 0;
 invoke_vi(3411,($cullResults|0));
 $77 = __THREW__; __THREW__ = 0;
 $78 = $77&1;
 if ($78) {
  $79 = ___cxa_find_matching_catch(0|0)|0;
  $80 = tempRet0;
  ___clang_call_terminate($79);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN6Camera6RenderER11CullResultsRN9ShaderLab17ShaderPassContextEi($this,$cullResults,$passContext,$renderFlags) {
 $this = $this|0;
 $cullResults = $cullResults|0;
 $passContext = $passContext|0;
 $renderFlags = $renderFlags|0;
 var $$0$i1 = 0, $$0$i7 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0;
 var $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0);
 var $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $curPosition = 0, $temp$0$i = 0, $temp$0$i6 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $tmpcast$byval_copy = sp + 224|0;
 $0 = sp;
 $1 = sp + 220|0;
 $curPosition = sp + 208|0;
 $2 = sp + 200|0;
 $3 = (($this) + 404|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = !($4 <= Math_fround(9.99999974737875163555E-6));
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 408|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = !($7 <= Math_fround(9.99999974737875163555E-6));
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 396|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = !($10 >= Math_fround(1.0));
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = Math_fround($4 + $10);
 $13 = !($12 <= Math_fround(0.0));
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 400|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = !($15 >= Math_fround(1.0));
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = Math_fround($7 + $15);
 $18 = !($17 <= Math_fround(0.0));
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $19 = (($this) + 460|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 456|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = !($20 <= $22);
 if (!($23)) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 616|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $27 = !($22 <= Math_fround(0.0));
  if (!($27)) {
   STACKTOP = sp;return;
  }
  $28 = (($this) + 452|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = $29 < Math_fround(0.0);
  if ($30) {
   $31 = Math_fround(-$29);
   $33 = $31;
  } else {
   $33 = $29;
  }
  $32 = $33 < Math_fround(9.99999997475242707878E-7);
  if ($32) {
   STACKTOP = sp;return;
  }
 } else {
  $34 = (($this) + 448|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = $35 < Math_fround(0.0);
  if ($36) {
   $37 = Math_fround(-$35);
   $39 = $37;
  } else {
   $39 = $35;
  }
  $38 = $39 < Math_fround(9.99999997475242707878E-7);
  if ($38) {
   STACKTOP = sp;return;
  }
 }
 $40 = (($cullResults) + 1076|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = (($this) + 621|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  $46 = ($this|0)==(0|0);
  if ($46) {
   $49 = 0;
  } else {
   $47 = (($this) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = $48;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(570304,0,569816,1761,512,$49,0,0);
  STACKTOP = sp;return;
 }
 $50 = (__Z12GetGfxDevicev()|0);
 $51 = (($50) + 5784|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = ($52<<24>>24)==(0);
 if ($53) {
  $54 = (__Z12GetGfxDevicev()|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + 504|0);
  $57 = HEAP32[$56>>2]|0;
  FUNCTION_TABLE_vi[$57 & 4095]($54);
 }
 HEAP8[$43>>0] = 1;
 $58 = (($this) + 24|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($59)|0);
 __ZNK9Transform11GetPositionEv($curPosition,$60);
 $61 = (($this) + 436|0);
 $62 = Math_fround(HEAPF32[$curPosition>>2]);
 $63 = Math_fround(HEAPF32[$61>>2]);
 $64 = Math_fround($62 - $63);
 $65 = (($curPosition) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($this) + 440|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($66 - $68);
 $70 = (($curPosition) + 8|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($this) + 444|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($71 - $73);
 $75 = (__Z14GetTimeManagerv()|0);
 $76 = (($75) + 116|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($64 * $77);
 $79 = Math_fround($69 * $77);
 $80 = Math_fround($74 * $77);
 $81 = (($this) + 424|0);
 HEAPF32[$81>>2] = $78;
 $82 = (($this) + 428|0);
 HEAPF32[$82>>2] = $79;
 $83 = (($this) + 432|0);
 HEAPF32[$83>>2] = $80;
 ;HEAP32[$61+0>>2]=HEAP32[$curPosition+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$curPosition+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$curPosition+8>>2]|0;
 $84 = (__Z16GetRenderManagerv()|0);
 $85 = ($this|0)==(0|0);
 if ($85) {
  HEAP32[$84>>2] = 0;
 } else {
  $86 = (($this) + 4|0);
  $87 = HEAP32[$86>>2]|0;
  HEAP32[$84>>2] = $87;
 }
 $88 = $renderFlags & 32;
 $89 = ($88|0)!=(0);
 if (!($89)) {
  $90 = (($tmpcast$byval_copy) + 8|0);
  HEAP32[$90>>2] = 0;
  $91 = (($tmpcast$byval_copy) + 4|0);
  HEAP32[$91>>2] = 0;
  HEAP32[$tmpcast$byval_copy>>2] = 0;
  __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,564904,$tmpcast$byval_copy);
  $92 = (__Z17GetMonoManagerPtrv()|0);
  $93 = ($92|0)==(0|0);
  if (!($93)) {
   $94 = (__Z19GetScriptingManagerv()|0);
   $95 = (($94) + 636|0);
   $96 = $95;
   $97 = $96;
   $98 = HEAP32[$97>>2]|0;
   $99 = (($96) + 4)|0;
   $100 = $99;
   $101 = HEAP32[$100>>2]|0;
   $102 = $2;
   $103 = $102;
   HEAP32[$103>>2] = $98;
   $104 = (($102) + 4)|0;
   $105 = $104;
   HEAP32[$105>>2] = $101;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
   __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($0,$tmpcast$byval_copy);
   $106 = (__ZN9Scripting19ScriptingWrapperForEP6Object($this)|0);
   $107 = (($0) + 32|0);
   __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($107,$106);
   (__ZN19ScriptingInvocation6InvokeEv($0)|0);
  }
 }
 __ZN6Camera19UpdateDepthTexturesERK11CullResults($this,$cullResults);
 $108 = $renderFlags | 4;
 __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($this,$passContext,$108);
 __ZN6Camera8DoRenderER11CullResultsPFvRS_R10RenderLoopS1_Ei($this,$cullResults,0,$renderFlags);
 $109 = $renderFlags & 1;
 $110 = ($109|0)!=(0);
 if ($110) {
  label = 32;
 } else {
  $111 = (($this) + 28|0);
  $112 = HEAP8[$111>>0]|0;
  $113 = ($112<<24>>24)==(0);
  if ($113) {
   $$pre = (($this) + 292|0);
   $$pre$phiZ2D = $$pre;
  } else {
   label = 32;
  }
 }
 if ((label|0) == 32) {
  $114 = (($cullResults) + 1068|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = ($115|0)==(0|0);
  if ($116) {
   $117 = HEAP32[$58>>2]|0;
   $118 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($117,124)|0);
   $119 = ($118|0)==(0|0);
   if (!($119)) {
    $120 = (($118) + 28|0);
    $121 = HEAP8[$120>>0]|0;
    $122 = ($121<<24>>24)==(0);
    if (!($122)) {
     $123 = (__ZN12FlareManager3GetEv()|0);
     __ZN12FlareManager12RenderFlaresEv($123);
    }
   }
   $124 = (__Z16GetRenderManagerv()|0);
   __ZN13RenderManager29InvokeOnRenderObjectCallbacksEv($124);
  }
  $125 = (($this) + 288|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (($this) + 292|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($128|0)==(0);
  if ($129) {
   $$0$i7 = 0;
  } else {
   HEAP32[$0>>2] = $128;
   $130 = HEAP32[560624>>2]|0;
   $131 = ($130|0)==(0|0);
   do {
    if ($131) {
     label = 46;
    } else {
     $132 = (($130) + 36|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = (($130) + 4|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($133|0)==($135|0);
     do {
      if ($136) {
       $137 = (($130) + 28|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = (($130) + 32|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = (($138) + ($140<<3)|0);
       $157 = $141;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast$byval_copy,$130,$0);
       $142 = HEAP32[$tmpcast$byval_copy>>2]|0;
       $143 = ($142|0)==(-1);
       $144 = (($130) + 28|0);
       $145 = HEAP32[$144>>2]|0;
       if ($143) {
        $146 = (($130) + 32|0);
        $147 = HEAP32[$146>>2]|0;
        $148 = (($145) + ($147<<3)|0);
        $157 = $148;
        break;
       } else {
        $149 = (($145) + ($142<<3)|0);
        $157 = $149;
        break;
       }
      }
     } while(0);
     $150 = HEAP32[560624>>2]|0;
     $151 = (($150) + 28|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = (($150) + 32|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (($152) + ($154<<3)|0);
     $156 = ($157|0)==($155|0);
     if ($156) {
      label = 46;
      break;
     }
     $158 = (($157) + 4|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ($159|0)==(0|0);
     if ($160) {
      label = 46;
     } else {
      $temp$0$i6 = $159;
     }
    }
   } while(0);
   if ((label|0) == 46) {
    $161 = HEAP32[$127>>2]|0;
    $162 = (__Z31ReadObjectFromPersistentManageri($161)|0);
    $temp$0$i6 = $162;
   }
   $$0$i7 = $temp$0$i6;
  }
  __Z18RenderImageFiltersR10RenderLoopP13RenderTextureb($126,$$0$i7,0);
  $$pre$phiZ2D = $127;
 }
 $163 = HEAP32[$$pre$phiZ2D>>2]|0;
 $164 = ($163|0)==(0);
 if ($164) {
  $$0$i1 = 0;
 } else {
  HEAP32[$1>>2] = $163;
  $165 = HEAP32[560624>>2]|0;
  $166 = ($165|0)==(0|0);
  if ($166) {
   label = 58;
  } else {
   $167 = (($165) + 36|0);
   $168 = HEAP32[$167>>2]|0;
   $169 = (($165) + 4|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = ($168|0)==($170|0);
   do {
    if ($171) {
     $172 = (($165) + 28|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = (($165) + 32|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = (($173) + ($175<<3)|0);
     $192 = $176;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast$byval_copy,$165,$1);
     $177 = HEAP32[$tmpcast$byval_copy>>2]|0;
     $178 = ($177|0)==(-1);
     $179 = (($165) + 28|0);
     $180 = HEAP32[$179>>2]|0;
     if ($178) {
      $181 = (($165) + 32|0);
      $182 = HEAP32[$181>>2]|0;
      $183 = (($180) + ($182<<3)|0);
      $192 = $183;
      break;
     } else {
      $184 = (($180) + ($177<<3)|0);
      $192 = $184;
      break;
     }
    }
   } while(0);
   $185 = HEAP32[560624>>2]|0;
   $186 = (($185) + 28|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = (($185) + 32|0);
   $189 = HEAP32[$188>>2]|0;
   $190 = (($187) + ($189<<3)|0);
   $191 = ($192|0)==($190|0);
   if ($191) {
    label = 58;
   } else {
    $193 = (($192) + 4|0);
    $194 = HEAP32[$193>>2]|0;
    $195 = ($194|0)==(0|0);
    if ($195) {
     label = 58;
    } else {
     $temp$0$i = $194;
    }
   }
  }
  if ((label|0) == 58) {
   $196 = HEAP32[$$pre$phiZ2D>>2]|0;
   $197 = (__Z31ReadObjectFromPersistentManageri($196)|0);
   $temp$0$i = $197;
  }
  $$0$i1 = $temp$0$i;
 }
 $198 = (($this) + 348|0);
 HEAP32[$198>>2] = $$0$i1;
 HEAP8[$43>>0] = 0;
 if ($110) {
  label = 62;
 } else {
  $199 = (($this) + 28|0);
  $200 = HEAP8[$199>>0]|0;
  $201 = ($200<<24>>24)==(0);
  if (!($201)) {
   label = 62;
  }
 }
 if ((label|0) == 62) {
  do {
   if (!($89)) {
    $202 = HEAP32[$58>>2]|0;
    $203 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($202,92)|0);
    $204 = ($203|0)==(0|0);
    if (!($204)) {
     $205 = (($203) + 28|0);
     $206 = HEAP8[$205>>0]|0;
     $207 = ($206<<24>>24)==(0);
     if ($207) {
      break;
     }
     __ZN8GUILayer14RenderGUILayerEv($203);
    }
   }
  } while(0);
  $208 = (($this) + 636|0);
  __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($208,20,$passContext);
 }
 __Z20SyncFenceCullResultsR11CullResults($cullResults);
 __ZN6Camera21CleanupAfterRenderingEv($this);
 STACKTOP = sp;return;
}
function __ZN6Camera25StandaloneRenderToCubemapEP7TextureiPFvPK9SceneNodePK4AABBR9IndexListPvESA_($this,$texture,$faceMask,$postProcessCullResults,$postProcessCullResultsData) {
 $this = $this|0;
 $texture = $texture|0;
 $faceMask = $faceMask|0;
 $postProcessCullResults = $postProcessCullResults|0;
 $postProcessCullResultsData = $postProcessCullResultsData|0;
 var $$ = 0, $$0$i15 = 0, $$0$i16 = 0, $$0$i6 = 0, $$019 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $$sink$index7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $cullResults = 0, $i$021 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $parameters$i = 0, $state = 0, $tempRTColorFormat$0 = 0, $translateMat = 0, $viewMatrix = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1488|0;
 $parameters$i = sp + 1464|0;
 $state = sp;
 $viewMatrix = sp + 232|0;
 $translateMat = sp + 296|0;
 $0 = sp + 360|0;
 $1 = sp + 372|0;
 $cullResults = sp + 384|0;
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 672|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = ($texture|0)==(0|0);
 if ($7) {
  $$0$i16 = 0;
  label = 3;
 } else {
  $8 = (($texture) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 >>> 21;
  $11 = HEAP32[560640>>2]|0;
  $12 = Math_imul($11, $10)|0;
  $13 = (($12) + 89)|0;
  $14 = $13 >> 5;
  $15 = $14 << 5;
  $16 = (($13) - ($15))|0;
  $17 = HEAP32[560632>>2]|0;
  $18 = (($17) + ($14<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = 1 << $16;
  $21 = $20 & $19;
  $22 = ($21|0)==(0);
  $$ = $22 ? 0 : $texture;
  $23 = (($12) + 84)|0;
  $24 = $23 >> 5;
  $25 = $24 << 5;
  $26 = (($23) - ($25))|0;
  $27 = (($17) + ($24<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = 1 << $26;
  $30 = $29 & $28;
  $31 = ($30|0)==(0);
  if ($31) {
   $$0$i16 = $$;
   label = 3;
  } else {
   $$0$i15 = $$;$$0$i6 = $texture;
  }
 }
 if ((label|0) == 3) {
  $$0$i15 = $$0$i16;$$0$i6 = 0;
 }
 $32 = HEAP32[652824>>2]|0;
 $33 = ($$0$i15|0)!=(0|0);
 do {
  if ($33) {
   $34 = (($$0$i15) + 127|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)==(0);
   if ($36) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(569880,0,569816,1391,1,0,0,0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $37 = (($$0$i15) + 48|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $tempRTColorFormat$0 = $6;
   } else {
    $40 = (($38) + 32|0);
    $41 = HEAP32[$40>>2]|0;
    if ((($41|0) == 3) | (($41|0) == 5)) {
     $tempRTColorFormat$0 = $6;
    } else {
     $42 = ($this|0)==(0|0);
     if ($42) {
      $45 = 0;
     } else {
      $43 = (($this) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = $44;
     }
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(569944,0,569816,1397,1,$45,0,0);
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
   }
  } else {
   $46 = ($$0$i6|0)==(0|0);
   if ($46) {
    $58 = ($this|0)==(0|0);
    if ($58) {
     $61 = 0;
    } else {
     $59 = (($this) + 4|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = $60;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(570048,0,569816,1413,1,$61,0,0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $47 = HEAP32[$$0$i6>>2]|0;
   $48 = (($47) + 92|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (FUNCTION_TABLE_ii[$49 & 4095]($$0$i6)|0);
   $51 = ($50|0)==(4);
   if ($51) {
    $56 = (($$0$i6) + 116|0);
    $57 = HEAP32[$56>>2]|0;
    $tempRTColorFormat$0 = $57;
    break;
   }
   $52 = ($this|0)==(0|0);
   if ($52) {
    $55 = 0;
   } else {
    $53 = (($this) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = $54;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(570008,0,569816,1405,1,$55,0,0);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 $62 = HEAP8[((640792 + 241|0))>>0]|0;
 $63 = ($62<<24>>24)==(0);
 $64 = HEAP8[((640792 + 242|0))>>0]|0;
 $65 = ($64<<24>>24)==(0);
 $or$cond = $63 | $65;
 if ($or$cond) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 __ZN13RenderManager18UpdateAllRenderersEv();
 $66 = HEAP32[$texture>>2]|0;
 $67 = (($66) + 104|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (FUNCTION_TABLE_ii[$68 & 4095]($texture)|0);
 $70 = (__Z22GetRenderBufferManagerv()|0);
 $71 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($70,$69,$69,2,$tempRTColorFormat$0,0,0,1)|0);
 $72 = ($71|0)==(0|0);
 if ($72) {
  $73 = ($this|0)==(0|0);
  if ($73) {
   $76 = 0;
  } else {
   $74 = (($this) + 4|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = $75;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(570112,0,569816,1430,1,$76,0,0);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 HEAP32[$state>>2] = 0;
 $77 = (($state) + 4|0);
 HEAP32[$77>>2] = 0;
 $78 = (($state) + 16|0);
 ;HEAP32[$78+0>>2]=0|0;HEAP32[$78+4>>2]=0|0;HEAP32[$78+8>>2]=0|0;HEAP32[$78+12>>2]=0|0;HEAP32[$78+16>>2]=0|0;HEAP32[$78+20>>2]=0|0;
 __Z16StoreRenderStateR20CameraRenderOldState($state);
 $79 = (__Z16GetRenderManagerv()|0);
 $80 = ($this|0)==(0|0);
 if ($80) {
  HEAP32[$79>>2] = 0;
 } else {
  $81 = (($this) + 4|0);
  $82 = HEAP32[$81>>2]|0;
  HEAP32[$79>>2] = $82;
 }
 $83 = (($this) + 292|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($71) + 4|0);
 $86 = HEAP32[$85>>2]|0;
 HEAP32[$83>>2] = $86;
 $87 = (($this) + 464|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($this) + 452|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($this) + 596|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($this) + 615|0);
 $94 = HEAP8[$93>>0]|0;
 HEAPF32[$89>>2] = Math_fround(90.0);
 HEAPF32[$91>>2] = Math_fround(1.0);
 HEAP8[$93>>0] = 0;
 $95 = (($this) + 609|0);
 HEAP8[$95>>0] = 1;
 $96 = (($this) + 610|0);
 HEAP8[$96>>0] = 1;
 $97 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
 $98 = ($97|0)>(1);
 if ($98) {
  HEAP32[$87>>2] = 1;
 }
 $99 = (__Z12GetGfxDevicev()|0);
 $100 = (($99) + 5784|0);
 $101 = HEAP8[$100>>0]|0;
 $102 = ($101<<24>>24)==(0);
 if ($102) {
  $103 = HEAP32[$99>>2]|0;
  $104 = (($103) + 504|0);
  $105 = HEAP32[$104>>2]|0;
  FUNCTION_TABLE_vi[$105 & 4095]($99);
  $106 = HEAP32[$99>>2]|0;
  $107 = (($106) + 516|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (FUNCTION_TABLE_ii[$108 & 4095]($99)|0);
  if ($109) {
   $217 = 1;
   label = 36;
  } else {
   $$019 = 0;
  }
 } else {
  $217 = 0;
  label = 36;
 }
 L53: do {
  if ((label|0) == 36) {
   __THREW__ = 0;
   $114 = (invoke_i(59)|0);
   $115 = __THREW__; __THREW__ = 0;
   $116 = $115&1;
   do {
    if ($116) {
     label = 34;
    } else {
     $117 = (($this) + 24|0);
     $118 = HEAP32[$117>>2]|0;
     __THREW__ = 0;
     $119 = (invoke_ii(3220,($118|0))|0);
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if ($121) {
      label = 34;
     } else {
      __THREW__ = 0;
      invoke_vii(2620,($1|0),($119|0));
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       label = 34;
      } else {
       $124 = Math_fround(HEAPF32[$1>>2]);
       $125 = Math_fround(-$124);
       $126 = (($1) + 4|0);
       $127 = Math_fround(HEAPF32[$126>>2]);
       $128 = Math_fround(-$127);
       $129 = (($1) + 8|0);
       $130 = Math_fround(HEAPF32[$129>>2]);
       $131 = Math_fround(-$130);
       HEAPF32[$0>>2] = $125;
       $132 = (($0) + 4|0);
       HEAPF32[$132>>2] = $128;
       $133 = (($0) + 8|0);
       HEAPF32[$133>>2] = $131;
       __THREW__ = 0;
       (invoke_iii(2370,($translateMat|0),($0|0))|0);
       $134 = __THREW__; __THREW__ = 0;
       $135 = $134&1;
       if ($135) {
        label = 34;
       } else {
        $136 = HEAP32[$114>>2]|0;
        $137 = (($136) + 80|0);
        $138 = HEAP32[$137>>2]|0;
        __THREW__ = 0;
        invoke_vii($138|0,($114|0),1);
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         label = 34;
        } else {
         $141 = (($this) + 32|0);
         $142 = (($this) + 612|0);
         $143 = (($cullResults) + 944|0);
         $144 = (($cullResults) + 948|0);
         $145 = (($parameters$i) + 4|0);
         $146 = (($parameters$i) + 8|0);
         $147 = (($parameters$i) + 12|0);
         $148 = (($parameters$i) + 16|0);
         $149 = (($parameters$i) + 20|0);
         $150 = (($this) + 617|0);
         $151 = (($114) + 5924|0);
         $i$021 = 0;
         while(1) {
          $152 = 1 << $i$021;
          $153 = $152 & $faceMask;
          $154 = ($153|0)==(0);
          if (!($154)) {
           __THREW__ = 0;
           invoke_viiii(337,($71|0),0,-1,0);
           $155 = __THREW__; __THREW__ = 0;
           $156 = $155&1;
           if ($156) {
            label = 33;
            break;
           }
           $157 = ($i$021*3)|0;
           $158 = (576872 + (($157*12)|0)|0);
           $159 = (($157) + 1)|0;
           $160 = (576872 + (($159*12)|0)|0);
           $161 = (($157) + 2)|0;
           $162 = (576872 + (($161*12)|0)|0);
           __THREW__ = 0;
           (invoke_iiiii(234,($viewMatrix|0),($158|0),($160|0),($162|0))|0);
           $163 = __THREW__; __THREW__ = 0;
           $164 = $163&1;
           if ($164) {
            label = 33;
            break;
           }
           __THREW__ = 0;
           (invoke_iii(2371,($viewMatrix|0),($translateMat|0))|0);
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            label = 33;
            break;
           }
           dest=$141+0|0; src=$viewMatrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           HEAP8[$142>>0] = 0;
           HEAP8[$96>>0] = 1;
           __THREW__ = 0;
           invoke_vi(3412,($cullResults|0));
           $167 = __THREW__; __THREW__ = 0;
           $168 = $167&1;
           if ($168) {
            label = 33;
            break;
           }
           HEAP32[$143>>2] = $postProcessCullResults;
           HEAP32[$144>>2] = $postProcessCullResultsData;
           HEAP32[$145>>2] = 0;
           HEAP32[$146>>2] = -1;
           HEAP32[$parameters$i>>2] = $this;
           HEAP32[$147>>2] = 5;
           HEAP32[$148>>2] = 0;
           HEAP32[$149>>2] = 0;
           $169 = HEAP8[$150>>0]|0;
           $170 = ($169<<24>>24)==(0);
           if (!($170)) {
            HEAP32[$147>>2] = 7;
           }
           __THREW__ = 0;
           invoke_viii(1673,($this|0),($parameters$i|0),($cullResults|0));
           $171 = __THREW__; __THREW__ = 0;
           $172 = $171&1;
           if ($172) {
            label = 54;
            break;
           }
           __THREW__ = 0;
           invoke_viiii(344,($this|0),($cullResults|0),($32|0),3);
           $173 = __THREW__; __THREW__ = 0;
           $174 = $173&1;
           if ($174) {
            label = 53;
            break;
           }
           if ($33) {
            $175 = HEAP8[$151>>0]|0;
            $176 = ($175<<24>>24)!=(0);
            __THREW__ = 0;
            invoke_viiiiiiiiii(8,($$0$i15|0),($i$021|0),0,0,($69|0),($69|0),0,0,($176|0),0);
            $177 = __THREW__; __THREW__ = 0;
            $178 = $177&1;
            if ($178) {
             label = 53;
             break;
            }
           } else {
            __THREW__ = 0;
            invoke_viiii(337,($$0$i6|0),0,($i$021|0),0);
            $183 = __THREW__; __THREW__ = 0;
            $184 = $183&1;
            if ($184) {
             label = 53;
             break;
            }
            __THREW__ = 0;
            $185 = (invoke_i(74)|0);
            $186 = __THREW__; __THREW__ = 0;
            $187 = $186&1;
            if ($187) {
             label = 53;
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(103,($71|0),($$0$i6|0),($185|0),-1,0,($i$021|0));
            $188 = __THREW__; __THREW__ = 0;
            $189 = $188&1;
            if ($189) {
             label = 53;
             break;
            }
           }
           __THREW__ = 0;
           invoke_vi(3411,($cullResults|0));
           $190 = __THREW__; __THREW__ = 0;
           $191 = $190&1;
           if ($191) {
            label = 33;
            break;
           }
          }
          $192 = (($i$021) + 1)|0;
          $193 = ($192|0)<(6);
          if ($193) {
           $i$021 = $192;
          } else {
           label = 61;
           break;
          }
         }
         if ((label|0) == 33) {
          $110 = ___cxa_find_matching_catch()|0;
          $111 = tempRet0;
          $lpad$phi$index = $110;$lpad$phi$index2 = $111;
          label = 35;
          break;
         }
         else if ((label|0) == 53) {
          $179 = ___cxa_find_matching_catch()|0;
          $180 = tempRet0;
          $$03 = $179;$$sink$index7 = $180;
         }
         else if ((label|0) == 54) {
          $181 = ___cxa_find_matching_catch()|0;
          $182 = tempRet0;
          $$03 = $181;$$sink$index7 = $182;
         }
         else if ((label|0) == 61) {
          HEAP8[$142>>0] = 1;
          $196 = (($this) + 608|0);
          HEAP8[$196>>0] = 1;
          HEAP32[$87>>2] = $88;
          HEAPF32[$89>>2] = $90;
          HEAPF32[$91>>2] = $92;
          HEAP8[$93>>0] = $94;
          HEAP8[$95>>0] = 1;
          HEAP8[$96>>0] = 1;
          HEAP32[$83>>2] = $84;
          __THREW__ = 0;
          invoke_vii(2622,($state|0),($32|0));
          $197 = __THREW__; __THREW__ = 0;
          $198 = $197&1;
          if ($198) {
           label = 34;
           break;
          }
          $199 = HEAP32[$114>>2]|0;
          $200 = (($199) + 80|0);
          $201 = HEAP32[$200>>2]|0;
          __THREW__ = 0;
          invoke_vii($201|0,($114|0),0);
          $202 = __THREW__; __THREW__ = 0;
          $203 = $202&1;
          if ($203) {
           label = 34;
           break;
          }
          __THREW__ = 0;
          $204 = (invoke_i(61)|0);
          $205 = __THREW__; __THREW__ = 0;
          $206 = $205&1;
          if ($206) {
           label = 34;
           break;
          }
          __THREW__ = 0;
          invoke_vii(2617,($204|0),($71|0));
          $207 = __THREW__; __THREW__ = 0;
          $208 = $207&1;
          if ($208) {
           label = 34;
           break;
          }
          if ($33) {
           __THREW__ = 0;
           invoke_vii(2623,($$0$i15|0),1);
           $209 = __THREW__; __THREW__ = 0;
           $210 = $209&1;
           if ($210) {
            label = 34;
            break;
           }
           $211 = HEAP32[$$0$i15>>2]|0;
           $212 = (($211) + 152|0);
           $213 = HEAP32[$212>>2]|0;
           __THREW__ = 0;
           invoke_vi($213|0,($$0$i15|0));
           $214 = __THREW__; __THREW__ = 0;
           $215 = $214&1;
           if ($215) {
            label = 34;
            break;
           }
          }
          $216 = ($217<<24>>24)==(0);
          if ($216) {
           $$1 = 1;
          } else {
           $$019 = 1;
           break L53;
          }
          STACKTOP = sp;return ($$1|0);
         }
         __THREW__ = 0;
         invoke_vi(3411,($cullResults|0));
         $194 = __THREW__; __THREW__ = 0;
         $195 = $194&1;
         if ($195) {
          $231 = ___cxa_find_matching_catch(0|0)|0;
          $232 = tempRet0;
          ___clang_call_terminate($231);
          // unreachable;
         } else {
          $$12 = $$sink$index7;$$14 = $$03;
         }
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 34) {
    $112 = ___cxa_find_matching_catch()|0;
    $113 = tempRet0;
    $lpad$phi$index = $112;$lpad$phi$index2 = $113;
    label = 35;
   }
   if ((label|0) == 35) {
    $$12 = $lpad$phi$index2;$$14 = $lpad$phi$index;
   }
   $222 = ($217<<24>>24)==(0);
   if ($222) {
    ___resumeException($$14|0);
    // unreachable;
   }
   __THREW__ = 0;
   $223 = (invoke_i(59)|0);
   $224 = __THREW__; __THREW__ = 0;
   $225 = $224&1;
   if ($225) {
    $231 = ___cxa_find_matching_catch(0|0)|0;
    $232 = tempRet0;
    ___clang_call_terminate($231);
    // unreachable;
   }
   $226 = HEAP32[$223>>2]|0;
   $227 = (($226) + 508|0);
   $228 = HEAP32[$227>>2]|0;
   __THREW__ = 0;
   invoke_vi($228|0,($223|0));
   $229 = __THREW__; __THREW__ = 0;
   $230 = $229&1;
   if ($230) {
    $231 = ___cxa_find_matching_catch(0|0)|0;
    $232 = tempRet0;
    ___clang_call_terminate($231);
    // unreachable;
   } else {
    ___resumeException($$14|0);
    // unreachable;
   }
  }
 } while(0);
 $218 = (__Z12GetGfxDevicev()|0);
 $219 = HEAP32[$218>>2]|0;
 $220 = (($219) + 508|0);
 $221 = HEAP32[$220>>2]|0;
 FUNCTION_TABLE_vi[$221 & 4095]($218);
 $$1 = $$019;
 STACKTOP = sp;return ($$1|0);
}
function __Z34GetCameraDepthNormalsTextureShaderv() {
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Z15GetScriptMapperv()|0);
 $2 = (__Znwj(48)|0);
 $3 = (($0) + 8|0);
 HEAP32[$3>>2] = $2;
 HEAP32[$0>>2] = 49;
 $4 = (($0) + 4|0);
 HEAP32[$4>>2] = 32;
 dest=$2+0|0; src=570192+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $5 = (($2) + 32|0);
 HEAP8[$5>>0] = 0;
 __THREW__ = 0;
 $6 = (invoke_iii(2366,($1|0),($0|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP8[$0>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   ___resumeException($15|0);
   // unreachable;
  }
  $20 = HEAP32[$3>>2]|0;
  __ZdlPv($20);
  ___resumeException($15|0);
  // unreachable;
 }
 $9 = HEAP8[$0>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = HEAP32[$3>>2]|0;
  __ZdlPv($12);
 }
 $13 = ($6|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return (0|0);
 } else {
  $14 = (__ZNK6Shader11IsSupportedEv($6)|0);
  $$ = $14 ? $6 : 0;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function __ZN6Camera18RenderDepthTextureERK11CullResultsRN9ShaderLab17ShaderPassContextE($this,$cullResults,$passContext) {
 $this = $this|0;
 $cullResults = $cullResults|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 340|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (__Z22GetRenderBufferManagerv()|0);
  $5 = HEAP32[$1>>2]|0;
  __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($4,$5);
  HEAP32[$1>>2] = 0;
 }
 $6 = (__Z22GetRenderBufferManagerv()|0);
 $7 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($6,-1,-1,2,1,0,1,1)|0);
 HEAP32[$1>>2] = $7;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095]($7,570232);
 $12 = HEAP32[$1>>2]|0;
 __ZN7Texture13SetFilterModeEi($12,0);
 $13 = (__Z12GetGfxDevicev()|0);
 $14 = HEAP32[$1>>2]|0;
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($14,0,-1,0);
 $15 = HEAP32[$13>>2]|0;
 $16 = (($15) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $18 = (($0) + 4|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($0) + 8|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($0) + 12|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 FUNCTION_TABLE_viiifi[$17 & 7]($13,7,$0,Math_fround(1.0),0);
 __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($this,$passContext,0);
 $21 = (($this) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($21,0,$passContext);
 $22 = (($cullResults) + 92|0);
 $23 = (($cullResults) + 1068|0);
 __Z20RenderSceneDepthPassRK13dynamic_arrayI11VisibleNodeLj4EERK17ShaderReplaceDatabRN9ShaderLab17ShaderPassContextE($22,$23,0,$passContext);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($21,1,$passContext);
 $24 = HEAP32[$13>>2]|0;
 $25 = (($24) + 136|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vii[$26 & 4095]($13,0);
 $27 = (($passContext) + 20|0);
 $28 = HEAP32[$1>>2]|0;
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($27,569480,$28)|0);
 STACKTOP = sp;return;
}
function __ZN6Camera25RenderDepthNormalsTextureERK11CullResultsRN9ShaderLab17ShaderPassContextE($this,$cullResults,$passContext) {
 $this = $this|0;
 $cullResults = $cullResults|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (__Z34GetCameraDepthNormalsTextureShaderv()|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 344|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (__Z22GetRenderBufferManagerv()|0);
  $8 = HEAP32[$4>>2]|0;
  __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($7,$8);
  HEAP32[$4>>2] = 0;
 }
 $9 = (__Z22GetRenderBufferManagerv()|0);
 $10 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($9,-1,-1,1,0,0,1,1)|0);
 HEAP32[$4>>2] = $10;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($10,570256);
 $15 = HEAP32[$4>>2]|0;
 __ZN7Texture13SetFilterModeEi($15,0);
 $16 = (__Z12GetGfxDevicev()|0);
 $17 = HEAP32[$4>>2]|0;
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($17,0,-1,0);
 HEAPF32[$0>>2] = Math_fround(0.5);
 $18 = (($0) + 4|0);
 HEAPF32[$18>>2] = Math_fround(0.5);
 $19 = (($0) + 8|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($0) + 12|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE(7,$0,Math_fround(1.0),0,$passContext);
 __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($this,$passContext,0);
 $21 = (($this) + 636|0);
 __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($21,2,$passContext);
 $22 = (($cullResults) + 92|0);
 HEAP8[$1>>0] = 20;
 $23 = (($1) + 1|0);
 dest=$23+0|0; src=570288+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $24 = (($1) + 11|0);
 HEAP8[$24>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(345,($22|0),($2|0),($1|0),($passContext|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  $39 = HEAP8[$1>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   ___resumeException($37|0);
   // unreachable;
  }
  $42 = (($1) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  __ZdlPv($43);
  ___resumeException($37|0);
  // unreachable;
 } else {
  $27 = HEAP8[$1>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  if (!($29)) {
   $30 = (($1) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   __ZdlPv($31);
  }
  __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($21,3,$passContext);
  $32 = HEAP32[$16>>2]|0;
  $33 = (($32) + 136|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_vii[$34 & 4095]($16,0);
  $35 = (($passContext) + 20|0);
  $36 = HEAP32[$4>>2]|0;
  (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($35,569512,$36)|0);
  STACKTOP = sp;return;
 }
}
function __ZN6Camera23GetBuiltinRenderTextureE24BuiltinRenderTextureType($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($type|0)==(2);
 if ($0) {
  $1 = (($this) + 348|0);
  $2 = HEAP32[$1>>2]|0;
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (($this) + 288|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__Z23GetRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureType($4,$type)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6Camera19UpdateDepthTexturesERK11CullResults($this,$cullResults) {
 $this = $this|0;
 $cullResults = $cullResults|0;
 var $$$not = 0, $$2 = 0, $$depthTexMask$0 = 0, $$depthTexMask$2 = 0, $$not = 0, $$not9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0);
 var $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $brmerge = 0, $brmerge6 = 0;
 var $depthTexMask$0 = 0, $depthTexMask$1 = 0, $depthTexMask$2 = 0, $depthTexMask$3 = 0, $or$cond11 = 0, $or$cond4 = 0, $or$cond8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[652824>>2]|0;
 $1 = HEAP32[569640>>2]|0;
 $2 = $1 & 31;
 $3 = 1 << $2;
 $4 = $3 ^ -1;
 $5 = $1 >>> 5;
 $6 = ((($0) + ($5<<2)|0) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & $4;
 HEAP32[$6>>2] = $8;
 $9 = (($this) + 616|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $12 = (__Z18GetQualitySettingsv()|0);
  $13 = (($12) + 40|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16) + (($14*96)|0)|0) + 76|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)!=(0);
  $25 = $19;
 } else {
  $25 = 0;
 }
 $20 = (($this) + 604|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__ZNK6Camera22CalculateRenderingPathEv($this)|0);
 $23 = $22 & -2;
 $24 = ($23|0)==(2);
 $$not = $25 ^ 1;
 $$$not = $24 ^ 1;
 $brmerge = $$not | $$$not;
 if (!($brmerge)) {
  $26 = HEAP32[569640>>2]|0;
  $27 = $26 & 31;
  $28 = 1 << $27;
  $29 = $26 >>> 5;
  $30 = ((($0) + ($29<<2)|0) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $28 | $31;
  HEAP32[$30>>2] = $32;
 }
 $33 = HEAP32[((640792 + 248|0))>>2]|0;
 $34 = $33&255;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $36 = $24&1;
  $$2 = $36 | $21;
  $depthTexMask$0 = $$2;
 } else {
  $depthTexMask$0 = $21;
 }
 $37 = $33 & 16711680;
 $38 = ($37|0)==(0);
 $or$cond4 = $24 | $38;
 if ($or$cond4) {
  $depthTexMask$1 = $depthTexMask$0;
 } else {
  $39 = (($cullResults) + 164|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)==(0);
  $42 = (__ZNK6Camera21CalculateCanDoShadowsEv($this)|0);
  if ($41) {
   $depthTexMask$1 = $depthTexMask$0;
  } else {
   $43 = $42&1;
   $$depthTexMask$0 = $43 | $depthTexMask$0;
   $depthTexMask$1 = $$depthTexMask$0;
  }
 }
 $44 = $depthTexMask$1 & 1;
 $45 = ($44|0)==(0);
 $brmerge6 = $45 | $$$not;
 $46 = HEAP8[((640792 + 248|0))>>0]|0;
 $47 = ($46<<24>>24)==(0);
 $or$cond8 = $brmerge6 | $47;
 $48 = $depthTexMask$1 & -2;
 $depthTexMask$2 = $or$cond8 ? $depthTexMask$1 : $48;
 $49 = $depthTexMask$2 & 2;
 $50 = ($49|0)==(0);
 if ($50) {
  $depthTexMask$3 = $depthTexMask$2;
 } else {
  $51 = $depthTexMask$2 & -3;
  $$depthTexMask$2 = $24 ? $51 : $depthTexMask$2;
  $depthTexMask$3 = $$depthTexMask$2;
 }
 $52 = ($depthTexMask$3|0)==(0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = (__ZN13RenderTexture9IsEnabledEv()|0);
 $$not9 = $53 ^ 1;
 $54 = HEAP8[((640792 + 202|0))>>0]|0;
 $55 = ($54<<24>>24)==(0);
 $or$cond11 = $55 | $$not9;
 if ($or$cond11) {
  STACKTOP = sp;return;
 }
 if ($25) {
  $56 = $depthTexMask$3 & 1;
  $57 = ($56|0)==(0);
  if (!($57)) {
   $58 = HEAP32[569640>>2]|0;
   $59 = $58 & 31;
   $60 = 1 << $59;
   $61 = $58 >>> 5;
   $62 = ((($0) + ($61<<2)|0) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = $60 | $63;
   HEAP32[$62>>2] = $64;
  }
 }
 $65 = (($this) + 404|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = !($66 <= Math_fround(9.99999974737875163555E-6));
 if (!($67)) {
  STACKTOP = sp;return;
 }
 $68 = (($this) + 408|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = !($69 <= Math_fround(9.99999974737875163555E-6));
 if (!($70)) {
  STACKTOP = sp;return;
 }
 $71 = (($this) + 396|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = !($72 >= Math_fround(1.0));
 if (!($73)) {
  STACKTOP = sp;return;
 }
 $74 = Math_fround($66 + $72);
 $75 = !($74 <= Math_fround(0.0));
 if (!($75)) {
  STACKTOP = sp;return;
 }
 $76 = (($this) + 400|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = !($77 >= Math_fround(1.0));
 if (!($78)) {
  STACKTOP = sp;return;
 }
 $79 = Math_fround($69 + $77);
 $80 = !($79 <= Math_fround(0.0));
 if (!($80)) {
  STACKTOP = sp;return;
 }
 $81 = (($this) + 460|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($this) + 456|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = !($82 <= $84);
 if (!($85)) {
  STACKTOP = sp;return;
 }
 $86 = HEAP8[$9>>0]|0;
 $87 = ($86<<24>>24)==(0);
 if ($87) {
  $88 = !($84 <= Math_fround(0.0));
  if (!($88)) {
   STACKTOP = sp;return;
  }
  $89 = (($this) + 452|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = $90 < Math_fround(0.0);
  if ($91) {
   $92 = Math_fround(-$90);
   $94 = $92;
  } else {
   $94 = $90;
  }
  $93 = $94 < Math_fround(9.99999997475242707878E-7);
  if ($93) {
   STACKTOP = sp;return;
  }
 } else {
  $95 = (($this) + 448|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = $96 < Math_fround(0.0);
  if ($97) {
   $98 = Math_fround(-$96);
   $100 = $98;
  } else {
   $100 = $96;
  }
  $99 = $100 < Math_fround(9.99999997475242707878E-7);
  if ($99) {
   STACKTOP = sp;return;
  }
 }
 $101 = $depthTexMask$3 & 1;
 $102 = ($101|0)==(0);
 if (!($102)) {
  __ZN6Camera18RenderDepthTextureERK11CullResultsRN9ShaderLab17ShaderPassContextE($this,$cullResults,$0);
 }
 $103 = $depthTexMask$3 & 2;
 $104 = ($103|0)==(0);
 if (!($104)) {
  __ZN6Camera25RenderDepthNormalsTextureERK11CullResultsRN9ShaderLab17ShaderPassContextE($this,$cullResults,$0);
 }
 $105 = (__Z12GetGfxDevicev()|0);
 $106 = (($105) + 5928|0);
 $107 = HEAP32[$106>>2]|0;
 if (!((($107|0) == 8) | (($107|0) == 11))) {
  STACKTOP = sp;return;
 }
 $108 = $depthTexMask$3 & 3;
 $109 = ($108|0)==(0);
 if ($109) {
  STACKTOP = sp;return;
 }
 $110 = (($this) + 348|0);
 $111 = HEAP32[$110>>2]|0;
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($111,0,-1,0);
 STACKTOP = sp;return;
}
function __ZN6Camera15StandaloneSetupERN9ShaderLab17ShaderPassContextE($this,$passContext) {
 $this = $this|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetRenderManagerv()|0);
 $1 = ($this|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 0;
 } else {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $3;
 }
 __ZN6Camera11SetupRenderERN9ShaderLab17ShaderPassContextEi($this,$passContext,3);
 STACKTOP = sp;return;
}
function __ZN6Camera25GetStereoProjectionParamsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($3)|0);
 __ZNK9Transform11GetPositionEv($agg$result,$4);
 $5 = (($this) + 608|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($this) + 612|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if (!($10)) {
   $11 = (($this) + 32|0);
   HEAPF32[$0>>2] = Math_fround(1.0);
   $12 = (($0) + 4|0);
   HEAPF32[$12>>2] = Math_fround(1.0);
   $13 = (($0) + 8|0);
   HEAPF32[$13>>2] = Math_fround(-1.0);
   (__ZN10Matrix4x4f8SetScaleERK8Vector3f($11,$0)|0);
   $14 = HEAP32[$2>>2]|0;
   $15 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($14)|0);
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$15);
   (__ZN10Matrix4x4fmLERKS_($11,$1)|0);
   HEAP8[$5>>0] = 0;
  }
 }
 $16 = (($this) + 32|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 36|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 40|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($agg$result) + 12|0);
 HEAPF32[$22>>2] = $17;
 $23 = (($agg$result) + 16|0);
 HEAPF32[$23>>2] = $19;
 $24 = (($agg$result) + 20|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($this) + 624|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($agg$result) + 24|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($this) + 628|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($agg$result) + 28|0);
 HEAPF32[$30>>2] = $29;
 $31 = (($this) + 456|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($agg$result) + 32|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($this) + 460|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($agg$result) + 36|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($this) + 452|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($agg$result) + 40|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($this) + 596|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($agg$result) + 44|0);
 HEAPF32[$42>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN6Camera21RenderStereoToBuffersEii($this,$renderFlags,$mode) {
 $this = $this|0;
 $renderFlags = $renderFlags|0;
 $mode = $mode|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$01 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$pre = 0, $$rtcolor5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0;
 var $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0);
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0);
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0);
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0;
 var $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $color$i = 0, $color$i11 = 0, $cullResultsLeft = 0, $cullResultsRight = 0, $depth$sroa$0$0$i = 0, $depth$sroa$0$0$i12 = 0, $depth$sroa$0$0$i25 = 0, $depth$sroa$0$0$i3 = 0, $depth$sroa$0$04$i = 0, $depth$sroa$0$07$i = 0, $or$cond = 0, $originalProjMatrix$sroa$0$sroa$2 = 0;
 var $originalProjMatrix$sroa$0$sroa$6 = 0, $originalViewMatrix$sroa$0$sroa$0 = 0, $originalViewMatrix$sroa$0$sroa$2 = 0, $p = 0, $parameters$i = 0, $projMatrix$sroa$2 = 0, $projMatrix$sroa$6 = 0, $rtcolor$i = 0, $storemerge$i$i$i = Math_fround(0), $storemerge1$i$i$i = Math_fround(0), $temp$0$i = 0, $temp$0$i$i = 0, $viewMatrix$sroa$0 = 0, $viewMatrix$sroa$2 = 0, $x2$0$i$i$i = Math_fround(0), $y2$0$i$i$i = Math_fround(0), dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2576|0;
 $$byval_copy5 = sp + 2552|0;
 $$byval_copy4 = sp + 2488|0;
 $0 = sp + 2484|0;
 $color$i11 = sp + 2480|0;
 $1 = sp + 2476|0;
 $2 = sp + 2472|0;
 $parameters$i = sp + 2448|0;
 $color$i = sp + 2440|0;
 $3 = sp + 2436|0;
 $4 = sp + 2432|0;
 $rtcolor$i = sp + 2428|0;
 $5 = sp + 2424|0;
 $p = sp + 2376|0;
 $originalViewMatrix$sroa$0$sroa$0 = sp + 104|0;
 $originalViewMatrix$sroa$0$sroa$2 = sp;
 $originalProjMatrix$sroa$0$sroa$2 = sp + 12|0;
 $originalProjMatrix$sroa$0$sroa$6 = sp + 24|0;
 $viewMatrix$sroa$0 = sp + 56|0;
 $viewMatrix$sroa$2 = sp + 152|0;
 $projMatrix$sroa$2 = sp + 164|0;
 $projMatrix$sroa$6 = sp + 176|0;
 $cullResultsLeft = sp + 208|0;
 $cullResultsRight = sp + 1288|0;
 $6 = sp + 2368|0;
 $7 = sp + 2372|0;
 $8 = (__Z12GetGfxDevicev()|0);
 __ZN6Camera25GetStereoProjectionParamsEv($p,$this);
 $9 = HEAP32[652824>>2]|0;
 $10 = (($this) + 596|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = ($mode|0)==(8);
 if ($12) {
  __ZL19GetCameraTargetRectRK6Camerab($$byval_copy5,$this,1);
  $13 = (($this) + 396|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($this) + 400|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($this) + 404|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($this) + 408|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($$byval_copy5) + 8|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($$byval_copy5) + 12|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($14 * $22);
  $26 = Math_fround($18 * $22);
  $27 = Math_fround($16 * $24);
  $28 = Math_fround($20 * $24);
  $29 = Math_fround(HEAPF32[$$byval_copy5>>2]);
  $30 = (($$byval_copy5) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($25 + $29);
  $33 = Math_fround($27 + $31);
  $34 = Math_fround($26 + $32);
  $35 = Math_fround($28 + $33);
  $36 = Math_fround($22 + $29);
  $37 = Math_fround($24 + $31);
  $38 = $32 < $29;
  $39 = $38 ? $29 : $32;
  $40 = $34 > $36;
  $x2$0$i$i$i = $40 ? $36 : $34;
  $41 = $33 < $31;
  $42 = $41 ? $31 : $33;
  $43 = $35 > $37;
  $y2$0$i$i$i = $43 ? $37 : $35;
  $44 = Math_fround($x2$0$i$i$i - $39);
  $45 = Math_fround($y2$0$i$i$i - $42);
  $46 = $45 < Math_fround(0.0);
  $storemerge$i$i$i = $46 ? Math_fround(0.0) : $45;
  $47 = $storemerge$i$i$i != Math_fround(0.0);
  if ($47) {
   $48 = $44 < Math_fround(0.0);
   $storemerge1$i$i$i = $48 ? Math_fround(0.0) : $44;
   $49 = Math_fround($storemerge$i$i$i * Math_fround(0.5));
   $50 = Math_fround($storemerge1$i$i$i / $49);
   HEAPF32[$10>>2] = $50;
  }
 }
 $51 = (($this) + 608|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = ($52<<24>>24)==(0);
 if (!($53)) {
  $54 = (($this) + 612|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = ($55<<24>>24)==(0);
  if (!($56)) {
   $57 = (($this) + 32|0);
   HEAPF32[$$byval_copy5>>2] = Math_fround(1.0);
   $58 = (($$byval_copy5) + 4|0);
   HEAPF32[$58>>2] = Math_fround(1.0);
   $59 = (($$byval_copy5) + 8|0);
   HEAPF32[$59>>2] = Math_fround(-1.0);
   (__ZN10Matrix4x4f8SetScaleERK8Vector3f($57,$$byval_copy5)|0);
   $60 = (($this) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($61)|0);
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($$byval_copy4,$62);
   (__ZN10Matrix4x4fmLERKS_($57,$$byval_copy4)|0);
   HEAP8[$51>>0] = 0;
  }
 }
 $63 = (($this) + 32|0);
 dest=$originalViewMatrix$sroa$0$sroa$0+0|0; src=$63+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $64 = (($this) + 80|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($this) + 84|0);
 ;HEAP32[$originalViewMatrix$sroa$0$sroa$2+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$originalViewMatrix$sroa$0$sroa$2+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$originalViewMatrix$sroa$0$sroa$2+8>>2]=HEAP32[$66+8>>2]|0;
 $67 = (($this) + 609|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = ($68<<24>>24)==(0);
 $$pre = (($this) + 613|0);
 if (!($69)) {
  $70 = HEAP8[$$pre>>0]|0;
  $71 = ($70<<24>>24)==(0);
  if (!($71)) {
   $72 = (($this) + 616|0);
   $73 = HEAP8[$72>>0]|0;
   $74 = ($73<<24>>24)==(0);
   $75 = (($this) + 96|0);
   if ($74) {
    $76 = (($this) + 452|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = Math_fround(HEAPF32[$10>>2]);
    $79 = (($this) + 456|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = (($this) + 460|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    (__ZN10Matrix4x4f14SetPerspectiveEffff($75,$77,$78,$80,$82)|0);
   } else {
    $83 = (($this) + 448|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = Math_fround(-$84);
    $86 = Math_fround(HEAPF32[$10>>2]);
    $87 = Math_fround($86 * $85);
    $88 = Math_fround($84 * $86);
    $89 = (($this) + 456|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = (($this) + 460|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    (__ZN10Matrix4x4f8SetOrthoEffffff($75,$87,$88,$85,$84,$90,$92)|0);
   }
   HEAP8[$67>>0] = 0;
  }
 }
 $93 = (($this) + 96|0);
 $94 = $93;
 $95 = $94;
 $96 = HEAP32[$95>>2]|0;
 $97 = (($94) + 4)|0;
 $98 = $97;
 $99 = HEAP32[$98>>2]|0;
 $100 = (($this) + 104|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($this) + 108|0);
 ;HEAP32[$originalProjMatrix$sroa$0$sroa$2+0>>2]=HEAP32[$102+0>>2]|0;HEAP32[$originalProjMatrix$sroa$0$sroa$2+4>>2]=HEAP32[$102+4>>2]|0;HEAP32[$originalProjMatrix$sroa$0$sroa$2+8>>2]=HEAP32[$102+8>>2]|0;
 $103 = (($this) + 120|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($this) + 124|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($this) + 128|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($this) + 132|0);
 ;HEAP32[$originalProjMatrix$sroa$0$sroa$6+0>>2]=HEAP32[$109+0>>2]|0;HEAP32[$originalProjMatrix$sroa$0$sroa$6+4>>2]=HEAP32[$109+4>>2]|0;HEAP32[$originalProjMatrix$sroa$0$sroa$6+8>>2]=HEAP32[$109+8>>2]|0;HEAP32[$originalProjMatrix$sroa$0$sroa$6+12>>2]=HEAP32[$109+12>>2]|0;HEAP32[$originalProjMatrix$sroa$0$sroa$6+16>>2]=HEAP32[$109+16>>2]|0;HEAP32[$originalProjMatrix$sroa$0$sroa$6+20>>2]=HEAP32[$109+20>>2]|0;HEAP32[$originalProjMatrix$sroa$0$sroa$6+24>>2]=HEAP32[$109+24>>2]|0;
 $110 = HEAP8[$$pre>>0]|0;
 $111 = (($this) + 612|0);
 $112 = HEAP8[$111>>0]|0;
 dest=$viewMatrix$sroa$0+0|0; src=$originalViewMatrix$sroa$0$sroa$0+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$viewMatrix$sroa$2+0>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+0>>2]|0;HEAP32[$viewMatrix$sroa$2+4>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+4>>2]|0;HEAP32[$viewMatrix$sroa$2+8>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+8>>2]|0;
 ;HEAP32[$projMatrix$sroa$2+0>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+0>>2]|0;HEAP32[$projMatrix$sroa$2+4>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+4>>2]|0;HEAP32[$projMatrix$sroa$2+8>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+8>>2]|0;
 ;HEAP32[$projMatrix$sroa$6+0>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+0>>2]|0;HEAP32[$projMatrix$sroa$6+4>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+4>>2]|0;HEAP32[$projMatrix$sroa$6+8>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+8>>2]|0;HEAP32[$projMatrix$sroa$6+12>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+12>>2]|0;HEAP32[$projMatrix$sroa$6+16>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+16>>2]|0;HEAP32[$projMatrix$sroa$6+20>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+20>>2]|0;HEAP32[$projMatrix$sroa$6+24>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+24>>2]|0;
 $113 = (__Z19GetActiveColorSpacev()|0);
 $114 = ($113|0)==(1);
 $115 = ($mode|0)==(2);
 $116 = ($mode|0)==(4);
 $$ = $116 | $12;
 $117 = (($this) + 620|0);
 $118 = HEAP8[$117>>0]|0;
 $119 = ($118<<24>>24)!=(0);
 $120 = (__Z14GetTemporaryRTbbbibb(1,$119,$114,1,$115,$$)|0);
 $121 = (($120) + 134|0);
 HEAP8[$121>>0] = 0;
 $122 = HEAP8[$117>>0]|0;
 $123 = ($122<<24>>24)!=(0);
 $124 = (__Z14GetTemporaryRTbbbibb(1,$123,$114,1,$115,$$)|0);
 $125 = (($124) + 134|0);
 HEAP8[$125>>0] = 0;
 __ZN11CullResultsC2Ev($cullResultsLeft);
 __THREW__ = 0;
 invoke_vi(3412,($cullResultsRight|0));
 $126 = __THREW__; __THREW__ = 0;
 $127 = $126&1;
 L17: do {
  if ($127) {
   label = 20;
  } else {
   $128 = (($p) + 24|0);
   $129 = Math_fround(HEAPF32[$128>>2]);
   $130 = Math_fround($129 * Math_fround(-0.5));
   $131 = Math_fround($65 + $130);
   $132 = Math_fround($129 * Math_fround(0.5));
   $133 = (($p) + 32|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = Math_fround($132 * $134);
   $136 = (($p) + 28|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = Math_fround($135 / $137);
   $139 = (($p) + 40|0);
   $140 = Math_fround(HEAPF32[$139>>2]);
   $141 = Math_fround($140 * Math_fround(0.5));
   $142 = Math_fround($141 / Math_fround(360.0));
   $143 = Math_fround($142 * Math_fround(2.0));
   $144 = Math_fround($143 * Math_fround(3.14159274101257324219));
   $145 = (Math_fround(+(Math_tan((+$144)))));
   $146 = Math_fround($134 * $145);
   $147 = (($p) + 44|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = Math_fround($146 * $148);
   $150 = Math_fround(-$138);
   $151 = Math_fround($150 / $149);
   $152 = Math_fround($151 * Math_fround(-1.0));
   $153 = Math_fround($108 + $152);
   dest=$63+0|0; src=$viewMatrix$sroa$0+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   HEAPF32[$64>>2] = $131;
   ;HEAP32[$66+0>>2]=HEAP32[$viewMatrix$sroa$2+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$viewMatrix$sroa$2+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$viewMatrix$sroa$2+8>>2]|0;
   HEAP8[$111>>0] = 0;
   $154 = (($this) + 610|0);
   $155 = $93;
   $156 = $155;
   HEAP32[$156>>2] = $96;
   $157 = (($155) + 4)|0;
   $158 = $157;
   HEAP32[$158>>2] = $99;
   HEAPF32[$100>>2] = $101;
   ;HEAP32[$102+0>>2]=HEAP32[$projMatrix$sroa$2+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$projMatrix$sroa$2+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$projMatrix$sroa$2+8>>2]|0;
   HEAPF32[$103>>2] = $104;
   HEAPF32[$105>>2] = $106;
   HEAPF32[$107>>2] = $153;
   ;HEAP32[$109+0>>2]=HEAP32[$projMatrix$sroa$6+0>>2]|0;HEAP32[$109+4>>2]=HEAP32[$projMatrix$sroa$6+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$projMatrix$sroa$6+8>>2]|0;HEAP32[$109+12>>2]=HEAP32[$projMatrix$sroa$6+12>>2]|0;HEAP32[$109+16>>2]=HEAP32[$projMatrix$sroa$6+16>>2]|0;HEAP32[$109+20>>2]=HEAP32[$projMatrix$sroa$6+20>>2]|0;HEAP32[$109+24>>2]=HEAP32[$projMatrix$sroa$6+24>>2]|0;
   HEAP8[$$pre>>0] = 0;
   HEAP8[$154>>0] = 1;
   $159 = $101 != Math_fround(0.0);
   $160 = $104 != Math_fround(0.0);
   $or$cond = $159 | $160;
   if (!($or$cond)) {
    $161 = (($this) + 614|0);
    HEAP8[$161>>0] = 0;
    $162 = (($this) + 224|0);
    $163 = $162;
    $164 = $163;
    HEAP32[$164>>2] = $96;
    $165 = (($163) + 4)|0;
    $166 = $165;
    HEAP32[$166>>2] = $99;
    $167 = (($this) + 232|0);
    HEAPF32[$167>>2] = $101;
    $168 = (($this) + 236|0);
    ;HEAP32[$168+0>>2]=HEAP32[$projMatrix$sroa$2+0>>2]|0;HEAP32[$168+4>>2]=HEAP32[$projMatrix$sroa$2+4>>2]|0;HEAP32[$168+8>>2]=HEAP32[$projMatrix$sroa$2+8>>2]|0;
    $169 = (($this) + 248|0);
    HEAPF32[$169>>2] = $104;
    $170 = (($this) + 252|0);
    HEAPF32[$170>>2] = $106;
    $171 = (($this) + 256|0);
    HEAPF32[$171>>2] = $153;
    $172 = (($this) + 260|0);
    ;HEAP32[$172+0>>2]=HEAP32[$projMatrix$sroa$6+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$projMatrix$sroa$6+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$projMatrix$sroa$6+8>>2]|0;HEAP32[$172+12>>2]=HEAP32[$projMatrix$sroa$6+12>>2]|0;HEAP32[$172+16>>2]=HEAP32[$projMatrix$sroa$6+16>>2]|0;HEAP32[$172+20>>2]=HEAP32[$projMatrix$sroa$6+20>>2]|0;HEAP32[$172+24>>2]=HEAP32[$projMatrix$sroa$6+24>>2]|0;
   }
   $173 = (($parameters$i) + 4|0);
   HEAP32[$173>>2] = 0;
   $174 = (($parameters$i) + 8|0);
   HEAP32[$174>>2] = -1;
   HEAP32[$parameters$i>>2] = $this;
   $175 = (($parameters$i) + 12|0);
   HEAP32[$175>>2] = 4;
   $176 = (($parameters$i) + 16|0);
   HEAP32[$176>>2] = 0;
   $177 = (($parameters$i) + 20|0);
   HEAP32[$177>>2] = 0;
   $178 = (($this) + 617|0);
   $179 = HEAP8[$178>>0]|0;
   $180 = ($179<<24>>24)==(0);
   if (!($180)) {
    HEAP32[$175>>2] = 6;
   }
   __THREW__ = 0;
   invoke_viii(1673,($this|0),($parameters$i|0),($cullResultsLeft|0));
   $181 = __THREW__; __THREW__ = 0;
   $182 = $181&1;
   do {
    if (!($182)) {
     $183 = (($this) + 28|0);
     $184 = HEAP8[$183>>0]|0;
     $185 = ($184<<24>>24)==(0);
     if (!($185)) {
      $192 = (($this) + 292|0);
      $193 = HEAP32[$192>>2]|0;
      $194 = ($193|0)==(0);
      if ($194) {
       $$0$i$i = 0;
      } else {
       HEAP32[$2>>2] = $193;
       $195 = HEAP32[560624>>2]|0;
       $196 = ($195|0)==(0|0);
       if ($196) {
        label = 31;
       } else {
        $197 = (($195) + 36|0);
        $198 = HEAP32[$197>>2]|0;
        $199 = (($195) + 4|0);
        $200 = HEAP32[$199>>2]|0;
        $201 = ($198|0)==($200|0);
        do {
         if ($201) {
          $202 = (($195) + 28|0);
          $203 = HEAP32[$202>>2]|0;
          $204 = (($195) + 32|0);
          $205 = HEAP32[$204>>2]|0;
          $206 = (($203) + ($205<<3)|0);
          $222 = $206;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$195,$2);
          $207 = HEAP32[$$byval_copy5>>2]|0;
          $208 = ($207|0)==(-1);
          $209 = (($195) + 28|0);
          $210 = HEAP32[$209>>2]|0;
          if ($208) {
           $211 = (($195) + 32|0);
           $212 = HEAP32[$211>>2]|0;
           $213 = (($210) + ($212<<3)|0);
           $222 = $213;
           break;
          } else {
           $214 = (($210) + ($207<<3)|0);
           $222 = $214;
           break;
          }
         }
        } while(0);
        $215 = HEAP32[560624>>2]|0;
        $216 = (($215) + 28|0);
        $217 = HEAP32[$216>>2]|0;
        $218 = (($215) + 32|0);
        $219 = HEAP32[$218>>2]|0;
        $220 = (($217) + ($219<<3)|0);
        $221 = ($222|0)==($220|0);
        if ($221) {
         label = 31;
        } else {
         $223 = (($222) + 4|0);
         $224 = HEAP32[$223>>2]|0;
         $225 = ($224|0)==(0|0);
         if ($225) {
          label = 31;
         } else {
          $temp$0$i$i = $224;
         }
        }
       }
       if ((label|0) == 31) {
        $226 = HEAP32[$192>>2]|0;
        __THREW__ = 0;
        $227 = (invoke_ii(3215,($226|0))|0);
        $228 = __THREW__; __THREW__ = 0;
        $229 = $228&1;
        if ($229) {
         break;
        } else {
         $temp$0$i$i = $227;
        }
       }
       $$0$i$i = $temp$0$i$i;
      }
      $230 = ($124|0)==(0|0);
      if ($230) {
       __THREW__ = 0;
       $235 = (invoke_i(59)|0);
       $236 = __THREW__; __THREW__ = 0;
       $237 = $236&1;
       if ($237) {
        break;
       }
       $238 = HEAP32[$235>>2]|0;
       $239 = (($238) + 432|0);
       $240 = HEAP32[$239>>2]|0;
       __THREW__ = 0;
       $241 = (invoke_ii($240|0,($235|0))|0);
       $242 = __THREW__; __THREW__ = 0;
       $243 = $242&1;
       if ($243) {
        break;
       }
       HEAP32[$color$i11>>2] = $241;
       __THREW__ = 0;
       $244 = (invoke_i(59)|0);
       $245 = __THREW__; __THREW__ = 0;
       $246 = $245&1;
       if ($246) {
        break;
       }
       $247 = HEAP32[$244>>2]|0;
       $248 = (($247) + 436|0);
       $249 = HEAP32[$248>>2]|0;
       __THREW__ = 0;
       $250 = (invoke_ii($249|0,($244|0))|0);
       $251 = __THREW__; __THREW__ = 0;
       $252 = $251&1;
       if ($252) {
        break;
       } else {
        $depth$sroa$0$0$i12 = $250;
       }
      } else {
       $231 = (($124) + 140|0);
       $232 = HEAP32[$231>>2]|0;
       HEAP32[$color$i11>>2] = $232;
       $233 = (($124) + 148|0);
       $234 = HEAP32[$233>>2]|0;
       $depth$sroa$0$0$i12 = $234;
      }
      HEAP32[$1>>2] = $depth$sroa$0$0$i12;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_viiiiii(105,($this|0),($124|0),1,($color$i11|0),($$byval_copy5|0),(0|0));
      $253 = __THREW__; __THREW__ = 0;
      $254 = $253&1;
      if ($254) {
       break;
      }
      $255 = HEAP32[$8>>2]|0;
      $256 = (($255) + 72|0);
      $257 = HEAP32[$256>>2]|0;
      __THREW__ = 0;
      invoke_vii($257|0,($8|0),($114|0));
      $258 = __THREW__; __THREW__ = 0;
      $259 = $258&1;
      if ($259) {
       break;
      }
      $260 = $renderFlags | 64;
      __THREW__ = 0;
      invoke_viiii(344,($this|0),($cullResultsLeft|0),($9|0),($260|0));
      $261 = __THREW__; __THREW__ = 0;
      $262 = $261&1;
      if ($262) {
       break;
      }
      __THREW__ = 0;
      $263 = (invoke_i(75)|0);
      $264 = __THREW__; __THREW__ = 0;
      $265 = $264&1;
      if ($265) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3413,($263|0));
      $266 = __THREW__; __THREW__ = 0;
      $267 = $266&1;
      if ($267) {
       break;
      }
      dest=$viewMatrix$sroa$0+0|0; src=$originalViewMatrix$sroa$0$sroa$0+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      ;HEAP32[$viewMatrix$sroa$2+0>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+0>>2]|0;HEAP32[$viewMatrix$sroa$2+4>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+4>>2]|0;HEAP32[$viewMatrix$sroa$2+8>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+8>>2]|0;
      ;HEAP32[$projMatrix$sroa$2+0>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+0>>2]|0;HEAP32[$projMatrix$sroa$2+4>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+4>>2]|0;HEAP32[$projMatrix$sroa$2+8>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+8>>2]|0;
      ;HEAP32[$projMatrix$sroa$6+0>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+0>>2]|0;HEAP32[$projMatrix$sroa$6+4>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+4>>2]|0;HEAP32[$projMatrix$sroa$6+8>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+8>>2]|0;HEAP32[$projMatrix$sroa$6+12>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+12>>2]|0;HEAP32[$projMatrix$sroa$6+16>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+16>>2]|0;HEAP32[$projMatrix$sroa$6+20>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+20>>2]|0;HEAP32[$projMatrix$sroa$6+24>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+24>>2]|0;
      $268 = Math_fround($65 + $132);
      $269 = Math_fround($108 + $151);
      dest=$63+0|0; src=$originalViewMatrix$sroa$0$sroa$0+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      HEAPF32[$64>>2] = $268;
      ;HEAP32[$66+0>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+8>>2]|0;
      HEAP8[$111>>0] = 0;
      $270 = $93;
      $271 = $270;
      HEAP32[$271>>2] = $96;
      $272 = (($270) + 4)|0;
      $273 = $272;
      HEAP32[$273>>2] = $99;
      HEAPF32[$100>>2] = $101;
      ;HEAP32[$102+0>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+8>>2]|0;
      HEAPF32[$103>>2] = $104;
      HEAPF32[$105>>2] = $106;
      HEAPF32[$107>>2] = $269;
      ;HEAP32[$109+0>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+0>>2]|0;HEAP32[$109+4>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+8>>2]|0;HEAP32[$109+12>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+12>>2]|0;HEAP32[$109+16>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+16>>2]|0;HEAP32[$109+20>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+20>>2]|0;HEAP32[$109+24>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+24>>2]|0;
      HEAP8[$$pre>>0] = 0;
      HEAP8[$154>>0] = 1;
      if (!($or$cond)) {
       $274 = (($this) + 614|0);
       HEAP8[$274>>0] = 0;
       $275 = (($this) + 224|0);
       $276 = $275;
       $277 = $276;
       HEAP32[$277>>2] = $96;
       $278 = (($276) + 4)|0;
       $279 = $278;
       HEAP32[$279>>2] = $99;
       $280 = (($this) + 232|0);
       HEAPF32[$280>>2] = $101;
       $281 = (($this) + 236|0);
       ;HEAP32[$281+0>>2]=HEAP32[$projMatrix$sroa$2+0>>2]|0;HEAP32[$281+4>>2]=HEAP32[$projMatrix$sroa$2+4>>2]|0;HEAP32[$281+8>>2]=HEAP32[$projMatrix$sroa$2+8>>2]|0;
       $282 = (($this) + 248|0);
       HEAPF32[$282>>2] = $104;
       $283 = (($this) + 252|0);
       HEAPF32[$283>>2] = $106;
       $284 = (($this) + 256|0);
       HEAPF32[$284>>2] = $269;
       $285 = (($this) + 260|0);
       ;HEAP32[$285+0>>2]=HEAP32[$projMatrix$sroa$6+0>>2]|0;HEAP32[$285+4>>2]=HEAP32[$projMatrix$sroa$6+4>>2]|0;HEAP32[$285+8>>2]=HEAP32[$projMatrix$sroa$6+8>>2]|0;HEAP32[$285+12>>2]=HEAP32[$projMatrix$sroa$6+12>>2]|0;HEAP32[$285+16>>2]=HEAP32[$projMatrix$sroa$6+16>>2]|0;HEAP32[$285+20>>2]=HEAP32[$projMatrix$sroa$6+20>>2]|0;HEAP32[$285+24>>2]=HEAP32[$projMatrix$sroa$6+24>>2]|0;
      }
      $286 = (($$byval_copy5) + 4|0);
      HEAP32[$286>>2] = 0;
      $287 = (($$byval_copy5) + 8|0);
      HEAP32[$287>>2] = -1;
      HEAP32[$$byval_copy5>>2] = $this;
      $288 = (($$byval_copy5) + 12|0);
      HEAP32[$288>>2] = 4;
      $289 = (($$byval_copy5) + 16|0);
      HEAP32[$289>>2] = 0;
      $290 = (($$byval_copy5) + 20|0);
      HEAP32[$290>>2] = 0;
      $291 = HEAP8[$178>>0]|0;
      $292 = ($291<<24>>24)==(0);
      if (!($292)) {
       HEAP32[$288>>2] = 6;
      }
      __THREW__ = 0;
      invoke_viii(1673,($this|0),($$byval_copy5|0),($cullResultsRight|0));
      $293 = __THREW__; __THREW__ = 0;
      $294 = $293&1;
      if ($294) {
       break;
      }
      $295 = ($120|0)==(0|0);
      if ($295) {
       __THREW__ = 0;
       $300 = (invoke_i(59)|0);
       $301 = __THREW__; __THREW__ = 0;
       $302 = $301&1;
       if ($302) {
        break;
       }
       $303 = HEAP32[$300>>2]|0;
       $304 = (($303) + 432|0);
       $305 = HEAP32[$304>>2]|0;
       __THREW__ = 0;
       $306 = (invoke_ii($305|0,($300|0))|0);
       $307 = __THREW__; __THREW__ = 0;
       $308 = $307&1;
       if ($308) {
        break;
       }
       HEAP32[$$byval_copy4>>2] = $306;
       __THREW__ = 0;
       $309 = (invoke_i(59)|0);
       $310 = __THREW__; __THREW__ = 0;
       $311 = $310&1;
       if ($311) {
        break;
       }
       $312 = HEAP32[$309>>2]|0;
       $313 = (($312) + 436|0);
       $314 = HEAP32[$313>>2]|0;
       __THREW__ = 0;
       $315 = (invoke_ii($314|0,($309|0))|0);
       $316 = __THREW__; __THREW__ = 0;
       $317 = $316&1;
       if ($317) {
        break;
       } else {
        $depth$sroa$0$0$i25 = $315;
       }
      } else {
       $296 = (($120) + 140|0);
       $297 = HEAP32[$296>>2]|0;
       HEAP32[$$byval_copy4>>2] = $297;
       $298 = (($120) + 148|0);
       $299 = HEAP32[$298>>2]|0;
       $depth$sroa$0$0$i25 = $299;
      }
      HEAP32[$0>>2] = $depth$sroa$0$0$i25;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_viiiiii(105,($this|0),($120|0),1,($$byval_copy4|0),($$byval_copy5|0),(0|0));
      $318 = __THREW__; __THREW__ = 0;
      $319 = $318&1;
      if ($319) {
       break;
      }
      $320 = HEAP32[$8>>2]|0;
      $321 = (($320) + 72|0);
      $322 = HEAP32[$321>>2]|0;
      __THREW__ = 0;
      invoke_vii($322|0,($8|0),($114|0));
      $323 = __THREW__; __THREW__ = 0;
      $324 = $323&1;
      if ($324) {
       break;
      }
      $325 = $renderFlags | 128;
      __THREW__ = 0;
      invoke_viiii(344,($this|0),($cullResultsRight|0),($9|0),($325|0));
      $326 = __THREW__; __THREW__ = 0;
      $327 = $326&1;
      if ($327) {
       break;
      }
      __THREW__ = 0;
      $328 = (invoke_i(75)|0);
      $329 = __THREW__; __THREW__ = 0;
      $330 = $329&1;
      if ($330) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3413,($328|0));
      $331 = __THREW__; __THREW__ = 0;
      $332 = $331&1;
      if ($332) {
       break;
      }
      $333 = ($$0$i$i|0)==(0|0);
      if ($333) {
       __THREW__ = 0;
       $338 = (invoke_i(59)|0);
       $339 = __THREW__; __THREW__ = 0;
       $340 = $339&1;
       if ($340) {
        break;
       }
       $341 = HEAP32[$338>>2]|0;
       $342 = (($341) + 432|0);
       $343 = HEAP32[$342>>2]|0;
       __THREW__ = 0;
       $344 = (invoke_ii($343|0,($338|0))|0);
       $345 = __THREW__; __THREW__ = 0;
       $346 = $345&1;
       if ($346) {
        break;
       }
       HEAP32[$color$i>>2] = $344;
       __THREW__ = 0;
       $347 = (invoke_i(59)|0);
       $348 = __THREW__; __THREW__ = 0;
       $349 = $348&1;
       if ($349) {
        break;
       }
       $350 = HEAP32[$347>>2]|0;
       $351 = (($350) + 436|0);
       $352 = HEAP32[$351>>2]|0;
       __THREW__ = 0;
       $353 = (invoke_ii($352|0,($347|0))|0);
       $354 = __THREW__; __THREW__ = 0;
       $355 = $354&1;
       if ($355) {
        break;
       } else {
        $depth$sroa$0$0$i3 = $353;
       }
      } else {
       $334 = (($$0$i$i) + 140|0);
       $335 = HEAP32[$334>>2]|0;
       HEAP32[$color$i>>2] = $335;
       $336 = (($$0$i$i) + 148|0);
       $337 = HEAP32[$336>>2]|0;
       $depth$sroa$0$0$i3 = $337;
      }
      HEAP32[$3>>2] = $depth$sroa$0$0$i3;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_viiiiii(105,($this|0),($$0$i$i|0),1,($color$i|0),($$byval_copy5|0),(0|0));
      $356 = __THREW__; __THREW__ = 0;
      $357 = $356&1;
      if ($357) {
       break;
      }
      $358 = HEAP32[$192>>2]|0;
      $359 = ($358|0)==(0);
      if ($359) {
       $$0$i = 0;
      } else {
       HEAP32[$4>>2] = $358;
       $360 = HEAP32[560624>>2]|0;
       $361 = ($360|0)==(0|0);
       do {
        if ($361) {
         label = 76;
        } else {
         $362 = (($360) + 36|0);
         $363 = HEAP32[$362>>2]|0;
         $364 = (($360) + 4|0);
         $365 = HEAP32[$364>>2]|0;
         $366 = ($363|0)==($365|0);
         do {
          if ($366) {
           $367 = (($360) + 28|0);
           $368 = HEAP32[$367>>2]|0;
           $369 = (($360) + 32|0);
           $370 = HEAP32[$369>>2]|0;
           $371 = (($368) + ($370<<3)|0);
           $387 = $371;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$360,$4);
           $372 = HEAP32[$$byval_copy5>>2]|0;
           $373 = ($372|0)==(-1);
           $374 = (($360) + 28|0);
           $375 = HEAP32[$374>>2]|0;
           if ($373) {
            $376 = (($360) + 32|0);
            $377 = HEAP32[$376>>2]|0;
            $378 = (($375) + ($377<<3)|0);
            $387 = $378;
            break;
           } else {
            $379 = (($375) + ($372<<3)|0);
            $387 = $379;
            break;
           }
          }
         } while(0);
         $380 = HEAP32[560624>>2]|0;
         $381 = (($380) + 28|0);
         $382 = HEAP32[$381>>2]|0;
         $383 = (($380) + 32|0);
         $384 = HEAP32[$383>>2]|0;
         $385 = (($382) + ($384<<3)|0);
         $386 = ($387|0)==($385|0);
         if ($386) {
          label = 76;
          break;
         }
         $388 = (($387) + 4|0);
         $389 = HEAP32[$388>>2]|0;
         $390 = ($389|0)==(0|0);
         if ($390) {
          label = 76;
         } else {
          $temp$0$i = $389;
         }
        }
       } while(0);
       if ((label|0) == 76) {
        $391 = HEAP32[$192>>2]|0;
        __THREW__ = 0;
        $392 = (invoke_ii(3215,($391|0))|0);
        $393 = __THREW__; __THREW__ = 0;
        $394 = $393&1;
        if ($394) {
         break;
        } else {
         $temp$0$i = $392;
        }
       }
       $$0$i = $temp$0$i;
      }
      $395 = (($this) + 348|0);
      HEAP32[$395>>2] = $$0$i;
      $396 = ($$0$i|0)==(0|0);
      if ($396) {
       HEAP32[$rtcolor$i>>2] = 0;
       $400 = (($this) + 296|0);
       $401 = (($this) + 332|0);
       $depth$sroa$0$04$i = HEAP32[$401>>2]|0;
       $402 = (($this) + 328|0);
       $403 = HEAP32[$402>>2]|0;
       $404 = (($this) + 336|0);
       $405 = HEAP32[$404>>2]|0;
       HEAP32[$395>>2] = $405;
       $$rtcolor5$i = $400;$406 = $403;$407 = $405;$depth$sroa$0$07$i = $depth$sroa$0$04$i;
      } else {
       $397 = (($$0$i) + 140|0);
       $398 = HEAP32[$397>>2]|0;
       HEAP32[$rtcolor$i>>2] = $398;
       $399 = (($$0$i) + 148|0);
       $depth$sroa$0$0$i = HEAP32[$399>>2]|0;
       $$rtcolor5$i = $rtcolor$i;$406 = 1;$407 = $$0$i;$depth$sroa$0$07$i = $depth$sroa$0$0$i;
      }
      HEAP32[$5>>2] = $depth$sroa$0$07$i;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
      (invoke_iiiiiiii(109,($406|0),($$rtcolor5$i|0),($$byval_copy5|0),($407|0),0,-1,1)|0);
      $408 = __THREW__; __THREW__ = 0;
      $409 = $408&1;
      if ($409) {
       break;
      }
      HEAPF32[$10>>2] = $11;
      HEAP8[$$pre>>0] = $110;
      HEAP8[$111>>0] = $112;
      $410 = $93;
      $411 = $410;
      HEAP32[$411>>2] = $96;
      $412 = (($410) + 4)|0;
      $413 = $412;
      HEAP32[$413>>2] = $99;
      HEAPF32[$100>>2] = $101;
      ;HEAP32[$102+0>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$2+8>>2]|0;
      HEAPF32[$103>>2] = $104;
      HEAPF32[$105>>2] = $106;
      HEAPF32[$107>>2] = $108;
      ;HEAP32[$109+0>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+0>>2]|0;HEAP32[$109+4>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+8>>2]|0;HEAP32[$109+12>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+12>>2]|0;HEAP32[$109+16>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+16>>2]|0;HEAP32[$109+20>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+20>>2]|0;HEAP32[$109+24>>2]=HEAP32[$originalProjMatrix$sroa$0$sroa$6+24>>2]|0;
      dest=$63+0|0; src=$originalViewMatrix$sroa$0$sroa$0+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      HEAPF32[$64>>2] = $65;
      ;HEAP32[$66+0>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$originalViewMatrix$sroa$0$sroa$2+8>>2]|0;
      $414 = HEAP32[$8>>2]|0;
      $415 = (($414) + 776|0);
      $416 = HEAP32[$415>>2]|0;
      $417 = (($124) + 140|0);
      $418 = HEAP32[$417>>2]|0;
      HEAP32[$6>>2] = $418;
      $419 = (($120) + 140|0);
      $420 = HEAP32[$419>>2]|0;
      HEAP32[$7>>2] = $420;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$6+0>>2]|0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$7+0>>2]|0;
      invoke_viii($416|0,($8|0),($$byval_copy4|0),($$byval_copy5|0));
      $421 = __THREW__; __THREW__ = 0;
      $422 = $421&1;
      if ($422) {
       break;
      }
      HEAP8[$125>>0] = 1;
      __THREW__ = 0;
      $423 = (invoke_i(61)|0);
      $424 = __THREW__; __THREW__ = 0;
      $425 = $424&1;
      if ($425) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(2617,($423|0),($124|0));
      $426 = __THREW__; __THREW__ = 0;
      $427 = $426&1;
      if ($427) {
       break;
      }
      HEAP8[$121>>0] = 1;
      __THREW__ = 0;
      $428 = (invoke_i(61)|0);
      $429 = __THREW__; __THREW__ = 0;
      $430 = $429&1;
      if ($430) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(2617,($428|0),($120|0));
      $431 = __THREW__; __THREW__ = 0;
      $432 = $431&1;
      if ($432) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vi(3411,($cullResultsRight|0));
     $433 = __THREW__; __THREW__ = 0;
     $434 = $433&1;
     if ($434) {
      label = 20;
      break L17;
     }
     __ZN11CullResultsD2Ev($cullResultsLeft);
     STACKTOP = sp;return;
    }
   } while(0);
   $188 = ___cxa_find_matching_catch()|0;
   $189 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3411,($cullResultsRight|0));
   $190 = __THREW__; __THREW__ = 0;
   $191 = $190&1;
   if ($191) {
    $437 = ___cxa_find_matching_catch(0|0)|0;
    $438 = tempRet0;
    ___clang_call_terminate($437);
    // unreachable;
   } else {
    $$0 = $188;$$01 = $189;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $186 = ___cxa_find_matching_catch()|0;
  $187 = tempRet0;
  $$0 = $186;$$01 = $187;
 }
 __THREW__ = 0;
 invoke_vi(3411,($cullResultsLeft|0));
 $435 = __THREW__; __THREW__ = 0;
 $436 = $435&1;
 if ($436) {
  $437 = ___cxa_find_matching_catch(0|0)|0;
  $438 = tempRet0;
  ___clang_call_terminate($437);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN6Camera19SetProjectionMatrixERK10Matrix4x4f($this,$matrix) {
 $this = $this|0;
 $matrix = $matrix|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 dest=$0+0|0; src=$matrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (($this) + 613|0);
 HEAP8[$1>>0] = 0;
 $2 = (($this) + 610|0);
 HEAP8[$2>>0] = 1;
 $3 = (($matrix) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = $4 != Math_fround(0.0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($matrix) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $7 != Math_fround(0.0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 614|0);
 HEAP8[$9>>0] = 0;
 $10 = (($this) + 224|0);
 dest=$10+0|0; src=$matrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN6Camera16SetTargetTextureEP13RenderTexture($this,$tex) {
 $this = $this|0;
 $tex = $tex|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $color = 0, $depth$sroa$0$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $color = sp;
 $0 = sp + 4|0;
 $1 = ($tex|0)==(0|0);
 if ($1) {
  $6 = (__Z12GetGfxDevicev()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 432|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
  HEAP32[$color>>2] = $10;
  $11 = (__Z12GetGfxDevicev()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 436|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
  $depth$sroa$0$0 = $15;
 } else {
  $2 = (($tex) + 140|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$color>>2] = $3;
  $4 = (($tex) + 148|0);
  $5 = HEAP32[$4>>2]|0;
  $depth$sroa$0$0 = $5;
 }
 HEAP32[$0>>2] = $depth$sroa$0$0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN6Camera23SetTargetTextureBuffersEP13RenderTextureiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES6_S1_($this,$tex,1,$color,$$byval_copy,0);
 STACKTOP = sp;return;
}
function __ZN6Camera12RenderStereoEi($this,$renderFlags) {
 $this = $this|0;
 $renderFlags = $renderFlags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 780|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 __ZN6Camera21RenderStereoToBuffersEii($this,$renderFlags,$4);
 STACKTOP = sp;return;
}
function __ZN6Camera14AddImageFilterERK11ImageFilter($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 288|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__Z25GetRenderLoopImageFiltersR10RenderLoop($1)|0);
 __ZN12ImageFilters14AddImageFilterERK11ImageFilter($2,$filter);
 STACKTOP = sp;return;
}
function __ZN6Camera17RemoveImageFilterERK11ImageFilter($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 288|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__Z25GetRenderLoopImageFiltersR10RenderLoop($1)|0);
 __ZN12ImageFilters17RemoveImageFilterERK11ImageFilter($2,$filter);
 STACKTOP = sp;return;
}
function __ZNK6Camera16ScreenPointToRayERK8Vector2f($agg$result,$this,$viewPortPos) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $viewPortPos = $viewPortPos|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $clipToWorld = 0, $out = 0, $viewport = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $0 = sp + 272|0;
 $1 = sp + 208|0;
 $viewport = sp + 192|0;
 $out = sp + 176|0;
 $clipToWorld = sp + 112|0;
 $2 = sp + 48|0;
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = sp + 36|0;
 __ZNK6Camera24GetScreenViewportRectIntEv($viewport,$this);
 HEAPF32[$out>>2] = Math_fround(0.0);
 $7 = (($out) + 4|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($out) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (__ZNK6Camera20GetWorldToClipMatrixEv($this)|0);
 (__Z20InvertMatrix4x4_FullPKfPf($9,$clipToWorld)|0);
 $10 = (($this) + 608|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  $13 = (($this) + 612|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if (!($15)) {
   $16 = (($this) + 32|0);
   HEAPF32[$0>>2] = Math_fround(1.0);
   $17 = (($0) + 4|0);
   HEAPF32[$17>>2] = Math_fround(1.0);
   $18 = (($0) + 8|0);
   HEAPF32[$18>>2] = Math_fround(-1.0);
   (__ZN10Matrix4x4f8SetScaleERK8Vector3f($16,$0)|0);
   $19 = (($this) + 24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($20)|0);
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$21);
   (__ZN10Matrix4x4fmLERKS_($16,$1)|0);
   HEAP8[$10>>0] = 0;
  }
 }
 $22 = (($this) + 32|0);
 (__Z20InvertMatrix4x4_FullPKfPf($22,$2)|0);
 $23 = Math_fround(HEAPF32[$viewPortPos>>2]);
 $24 = (($viewPortPos) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 456|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$3>>2] = $23;
 $28 = (($3) + 4|0);
 HEAPF32[$28>>2] = $25;
 $29 = (($3) + 8|0);
 HEAPF32[$29>>2] = $27;
 $30 = (__Z15CameraUnProjectRK8Vector3fRK10Matrix4x4fS4_RK5RectTIiERS_($3,$2,$clipToWorld,$viewport,$out)|0);
 if (!($30)) {
  $31 = (($this) + 24|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($32)|0);
  __ZNK9Transform11GetPositionEv($4,$33);
  ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
  ;HEAP32[$agg$result+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$4+8>>2]|0;
  $34 = (($agg$result) + 12|0);
  HEAPF32[$34>>2] = Math_fround(0.0);
  $35 = (($agg$result) + 16|0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  $36 = (($agg$result) + 20|0);
  HEAPF32[$36>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
 $37 = Math_fround(HEAPF32[$out>>2]);
 $38 = Math_fround(HEAPF32[$7>>2]);
 $39 = Math_fround(HEAPF32[$8>>2]);
 $40 = (($this) + 616|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)==(0);
 do {
  if ($42) {
   $61 = Math_fround(HEAPF32[$viewPortPos>>2]);
   $62 = Math_fround(HEAPF32[$24>>2]);
   $63 = Math_fround(HEAPF32[$26>>2]);
   $64 = Math_fround($63 + Math_fround(1000.0));
   HEAPF32[$5>>2] = $61;
   $65 = (($5) + 4|0);
   HEAPF32[$65>>2] = $62;
   $66 = (($5) + 8|0);
   HEAPF32[$66>>2] = $64;
   $67 = (__Z15CameraUnProjectRK8Vector3fRK10Matrix4x4fS4_RK5RectTIiERS_($5,$2,$clipToWorld,$viewport,$out)|0);
   if ($67) {
    $74 = Math_fround(HEAPF32[$out>>2]);
    $75 = Math_fround($74 - $37);
    $76 = Math_fround(HEAPF32[$7>>2]);
    $77 = Math_fround($76 - $38);
    $78 = Math_fround(HEAPF32[$8>>2]);
    $79 = Math_fround($78 - $39);
    $80 = Math_fround($75 * $75);
    $81 = Math_fround($77 * $77);
    $82 = Math_fround($80 + $81);
    $83 = Math_fround($79 * $79);
    $84 = Math_fround($82 + $83);
    $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
    $86 = Math_fround($75 / $85);
    $87 = Math_fround($77 / $85);
    $88 = Math_fround($79 / $85);
    $92 = $86;$94 = $87;$96 = $88;
    break;
   }
   $68 = (($this) + 24|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($69)|0);
   __ZNK9Transform11GetPositionEv($6,$70);
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
   ;HEAP32[$agg$result+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$6+8>>2]|0;
   $71 = (($agg$result) + 12|0);
   HEAPF32[$71>>2] = Math_fround(0.0);
   $72 = (($agg$result) + 16|0);
   HEAPF32[$72>>2] = Math_fround(0.0);
   $73 = (($agg$result) + 20|0);
   HEAPF32[$73>>2] = Math_fround(1.0);
   STACKTOP = sp;return;
  } else {
   $43 = (($2) + 32|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($2) + 36|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($2) + 40|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = Math_fround(-$44);
   $50 = Math_fround(-$46);
   $51 = Math_fround(-$48);
   $52 = Math_fround($44 * $44);
   $53 = Math_fround($46 * $46);
   $54 = Math_fround($52 + $53);
   $55 = Math_fround($48 * $48);
   $56 = Math_fround($54 + $55);
   $57 = (Math_fround(Math_sqrt((Math_fround($56)))));
   $58 = Math_fround($49 / $57);
   $59 = Math_fround($50 / $57);
   $60 = Math_fround($51 / $57);
   $92 = $58;$94 = $59;$96 = $60;
  }
 } while(0);
 HEAPF32[$agg$result>>2] = $37;
 $89 = (($agg$result) + 4|0);
 HEAPF32[$89>>2] = $38;
 $90 = (($agg$result) + 8|0);
 HEAPF32[$90>>2] = $39;
 $91 = (($agg$result) + 12|0);
 HEAPF32[$91>>2] = $92;
 $93 = (($agg$result) + 16|0);
 HEAPF32[$93>>2] = $94;
 $95 = (($agg$result) + 20|0);
 HEAPF32[$95>>2] = $96;
 STACKTOP = sp;return;
}
function __ZNK6Camera18WorldToScreenPointERK8Vector3fPb($agg$result,$this,$v,$canProject) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $v = $v|0;
 $canProject = $canProject|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $viewport = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 144|0;
 $1 = sp;
 $viewport = sp + 64|0;
 $2 = sp + 80|0;
 __ZNK6Camera24GetScreenViewportRectIntEv($viewport,$this);
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $3 = (($agg$result) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($agg$result) + 8|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 608|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($this) + 612|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if (!($10)) {
   $11 = (($this) + 32|0);
   HEAPF32[$0>>2] = Math_fround(1.0);
   $12 = (($0) + 4|0);
   HEAPF32[$12>>2] = Math_fround(1.0);
   $13 = (($0) + 8|0);
   HEAPF32[$13>>2] = Math_fround(-1.0);
   (__ZN10Matrix4x4f8SetScaleERK8Vector3f($11,$0)|0);
   $14 = (($this) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($15)|0);
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$16);
   (__ZN10Matrix4x4fmLERKS_($11,$1)|0);
   HEAP8[$5>>0] = 0;
  }
 }
 $17 = (($this) + 32|0);
 (__Z20InvertMatrix4x4_FullPKfPf($17,$2)|0);
 $18 = (__ZNK6Camera20GetWorldToClipMatrixEv($this)|0);
 $19 = (__Z13CameraProjectRK8Vector3fRK10Matrix4x4fS4_RK5RectTIiERS_($v,$2,$18,$viewport,$agg$result)|0);
 $20 = ($canProject|0)==(0|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = $19&1;
 HEAP8[$canProject>>0] = $21;
 STACKTOP = sp;return;
}
function __ZNK6Camera18ScreenToWorldPointERK8Vector3f($agg$result,$this,$v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $clipToWorld = 0;
 var $viewport = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $0 = sp + 208|0;
 $1 = sp;
 $viewport = sp + 64|0;
 $clipToWorld = sp + 80|0;
 $2 = sp + 144|0;
 __ZNK6Camera24GetScreenViewportRectIntEv($viewport,$this);
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $3 = (($agg$result) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($agg$result) + 8|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (__ZNK6Camera20GetWorldToClipMatrixEv($this)|0);
 (__Z20InvertMatrix4x4_FullPKfPf($5,$clipToWorld)|0);
 $6 = (($this) + 608|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($this) + 612|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $12 = (($this) + 32|0);
   HEAPF32[$0>>2] = Math_fround(1.0);
   $13 = (($0) + 4|0);
   HEAPF32[$13>>2] = Math_fround(1.0);
   $14 = (($0) + 8|0);
   HEAPF32[$14>>2] = Math_fround(-1.0);
   (__ZN10Matrix4x4f8SetScaleERK8Vector3f($12,$0)|0);
   $15 = (($this) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($16)|0);
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$17);
   (__ZN10Matrix4x4fmLERKS_($12,$1)|0);
   HEAP8[$6>>0] = 0;
  }
 }
 $18 = (($this) + 32|0);
 (__Z20InvertMatrix4x4_FullPKfPf($18,$2)|0);
 (__Z15CameraUnProjectRK8Vector3fRK10Matrix4x4fS4_RK5RectTIiERS_($v,$2,$clipToWorld,$viewport,$agg$result)|0);
 STACKTOP = sp;return;
}
function __ZNK6Camera20WorldToViewportPointERK8Vector3f($agg$result,$this,$worldPoint) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $worldPoint = $worldPoint|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $screenPoint = 0, $screenRect$i$i$i = 0, $storemerge$i$i$i$i = Math_fround(0), $storemerge1$i$i$i$i = Math_fround(0), $tempBool = 0, $x2$0$i$i$i$i = Math_fround(0), $y2$0$i$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $screenRect$i$i$i = sp + 16|0;
 $tempBool = sp + 32|0;
 $screenPoint = sp;
 __ZNK6Camera18WorldToScreenPointERK8Vector3fPb($screenPoint,$this,$worldPoint,$tempBool);
 __ZL19GetCameraTargetRectRK6Camerab($screenRect$i$i$i,$this,1);
 $0 = (($this) + 396|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 400|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 404|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 408|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($screenRect$i$i$i) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($screenRect$i$i$i) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($1 * $9);
 $13 = Math_fround($5 * $9);
 $14 = Math_fround($3 * $11);
 $15 = Math_fround($7 * $11);
 $16 = Math_fround(HEAPF32[$screenRect$i$i$i>>2]);
 $17 = (($screenRect$i$i$i) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($12 + $16);
 $20 = Math_fround($14 + $18);
 $21 = Math_fround($13 + $19);
 $22 = Math_fround($15 + $20);
 $23 = Math_fround($9 + $16);
 $24 = Math_fround($11 + $18);
 $25 = $19 < $16;
 $26 = $25 ? $16 : $19;
 $27 = $21 > $23;
 $x2$0$i$i$i$i = $27 ? $23 : $21;
 $28 = $20 < $18;
 $29 = $28 ? $18 : $20;
 $30 = $22 > $24;
 $y2$0$i$i$i$i = $30 ? $24 : $22;
 $31 = Math_fround($x2$0$i$i$i$i - $26);
 $32 = $31 < Math_fround(0.0);
 $storemerge1$i$i$i$i = $32 ? Math_fround(0.0) : $31;
 $33 = Math_fround($y2$0$i$i$i$i - $29);
 $34 = $33 < Math_fround(0.0);
 $storemerge$i$i$i$i = $34 ? Math_fround(0.0) : $33;
 $35 = Math_fround(HEAPF32[$screenPoint>>2]);
 $36 = Math_fround($35 - $26);
 $37 = Math_fround($36 / $storemerge1$i$i$i$i);
 $38 = (($screenPoint) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 - $29);
 $41 = Math_fround($40 / $storemerge$i$i$i$i);
 $42 = (($screenPoint) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$agg$result>>2] = $37;
 $44 = (($agg$result) + 4|0);
 HEAPF32[$44>>2] = $41;
 $45 = (($agg$result) + 8|0);
 HEAPF32[$45>>2] = $43;
 STACKTOP = sp;return;
}
function __ZNK6Camera21ScreenToViewportPointERK8Vector3f($agg$result,$this,$screenPos) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $screenPos = $screenPos|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $screenRect$i$i = 0, $storemerge$i$i$i = Math_fround(0), $storemerge1$i$i$i = Math_fround(0), $x2$0$i$i$i = Math_fround(0), $y2$0$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $screenRect$i$i = sp;
 __ZL19GetCameraTargetRectRK6Camerab($screenRect$i$i,$this,1);
 $0 = (($this) + 396|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 400|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 404|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 408|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($screenRect$i$i) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($screenRect$i$i) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($1 * $9);
 $13 = Math_fround($5 * $9);
 $14 = Math_fround($3 * $11);
 $15 = Math_fround($7 * $11);
 $16 = Math_fround(HEAPF32[$screenRect$i$i>>2]);
 $17 = (($screenRect$i$i) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($12 + $16);
 $20 = Math_fround($14 + $18);
 $21 = Math_fround($13 + $19);
 $22 = Math_fround($15 + $20);
 $23 = Math_fround($9 + $16);
 $24 = Math_fround($11 + $18);
 $25 = $19 < $16;
 $26 = $25 ? $16 : $19;
 $27 = $21 > $23;
 $x2$0$i$i$i = $27 ? $23 : $21;
 $28 = $20 < $18;
 $29 = $28 ? $18 : $20;
 $30 = $22 > $24;
 $y2$0$i$i$i = $30 ? $24 : $22;
 $31 = Math_fround($x2$0$i$i$i - $26);
 $32 = $31 < Math_fround(0.0);
 $storemerge1$i$i$i = $32 ? Math_fround(0.0) : $31;
 $33 = Math_fround($y2$0$i$i$i - $29);
 $34 = $33 < Math_fround(0.0);
 $storemerge$i$i$i = $34 ? Math_fround(0.0) : $33;
 $35 = Math_fround(HEAPF32[$screenPos>>2]);
 $36 = Math_fround($35 - $26);
 $37 = Math_fround($36 / $storemerge1$i$i$i);
 $38 = (($screenPos) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 - $29);
 $41 = Math_fround($40 / $storemerge$i$i$i);
 $42 = (($screenPos) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$agg$result>>2] = $37;
 $44 = (($agg$result) + 4|0);
 HEAPF32[$44>>2] = $41;
 $45 = (($agg$result) + 8|0);
 HEAPF32[$45>>2] = $43;
 STACKTOP = sp;return;
}
function __ZNK6Camera20ViewportToWorldPointERK8Vector3f($agg$result,$this,$viewPortPoint) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $viewPortPoint = $viewPortPoint|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $screenPoint = 0, $screenRect$i$i$i = 0, $storemerge$i$i$i$i = Math_fround(0), $storemerge1$i$i$i$i = Math_fround(0), $x2$0$i$i$i$i = Math_fround(0), $y2$0$i$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $screenRect$i$i$i = sp + 16|0;
 $screenPoint = sp;
 __ZL19GetCameraTargetRectRK6Camerab($screenRect$i$i$i,$this,1);
 $0 = (($this) + 396|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 400|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 404|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 408|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($screenRect$i$i$i) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($screenRect$i$i$i) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($1 * $9);
 $13 = Math_fround($5 * $9);
 $14 = Math_fround($3 * $11);
 $15 = Math_fround($7 * $11);
 $16 = Math_fround(HEAPF32[$screenRect$i$i$i>>2]);
 $17 = (($screenRect$i$i$i) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($12 + $16);
 $20 = Math_fround($14 + $18);
 $21 = Math_fround($13 + $19);
 $22 = Math_fround($15 + $20);
 $23 = Math_fround($9 + $16);
 $24 = Math_fround($11 + $18);
 $25 = $19 < $16;
 $26 = $25 ? $16 : $19;
 $27 = $21 > $23;
 $x2$0$i$i$i$i = $27 ? $23 : $21;
 $28 = $20 < $18;
 $29 = $28 ? $18 : $20;
 $30 = $22 > $24;
 $y2$0$i$i$i$i = $30 ? $24 : $22;
 $31 = Math_fround($x2$0$i$i$i$i - $26);
 $32 = $31 < Math_fround(0.0);
 $storemerge1$i$i$i$i = $32 ? Math_fround(0.0) : $31;
 $33 = Math_fround($y2$0$i$i$i$i - $29);
 $34 = $33 < Math_fround(0.0);
 $storemerge$i$i$i$i = $34 ? Math_fround(0.0) : $33;
 $35 = Math_fround(HEAPF32[$viewPortPoint>>2]);
 $36 = Math_fround($35 * $storemerge1$i$i$i$i);
 $37 = Math_fround($26 + $36);
 $38 = (($viewPortPoint) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $storemerge$i$i$i$i);
 $41 = Math_fround($29 + $40);
 $42 = (($viewPortPoint) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$screenPoint>>2] = $37;
 $44 = (($screenPoint) + 4|0);
 HEAPF32[$44>>2] = $41;
 $45 = (($screenPoint) + 8|0);
 HEAPF32[$45>>2] = $43;
 __ZNK6Camera18ScreenToWorldPointERK8Vector3f($agg$result,$this,$screenPoint);
 STACKTOP = sp;return;
}
function __ZNK6Camera21ViewportToCameraPointERK8Vector3f($agg$result,$this,$viewPort) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $viewPort = $viewPort|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $invProjection = 0, $storemerge = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $invProjection = sp;
 $0 = (($this) + 609|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 613|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if (!($5)) {
   $6 = (($this) + 616|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   $9 = (($this) + 96|0);
   if ($8) {
    $10 = (($this) + 452|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    $12 = (($this) + 596|0);
    $13 = Math_fround(HEAPF32[$12>>2]);
    $14 = (($this) + 456|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = (($this) + 460|0);
    $17 = Math_fround(HEAPF32[$16>>2]);
    (__ZN10Matrix4x4f14SetPerspectiveEffff($9,$11,$13,$15,$17)|0);
   } else {
    $18 = (($this) + 448|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = Math_fround(-$19);
    $21 = (($this) + 596|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = Math_fround($22 * $20);
    $24 = Math_fround($19 * $22);
    $25 = (($this) + 456|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = (($this) + 460|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    (__ZN10Matrix4x4f8SetOrthoEffffff($9,$23,$24,$20,$19,$26,$28)|0);
   }
   HEAP8[$0>>0] = 0;
  }
 }
 $29 = (($this) + 96|0);
 (__Z20InvertMatrix4x4_FullPKfPf($29,$invProjection)|0);
 $30 = Math_fround(HEAPF32[$viewPort>>2]);
 $31 = Math_fround(Math_fround(1.0) - $30);
 $32 = Math_fround($31 * Math_fround(-1.0));
 $33 = Math_fround($30 + $32);
 $34 = (($viewPort) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround(Math_fround(1.0) - $35);
 $37 = Math_fround($36 * Math_fround(-1.0));
 $38 = Math_fround($35 + $37);
 $39 = (($viewPort) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 456|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 - $42);
 $44 = (($this) + 460|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 / $45);
 $47 = Math_fround(Math_fround(1.0) - $46);
 $48 = Math_fround($47 * Math_fround(-1.0));
 $49 = Math_fround($46 + $48);
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $50 = (($agg$result) + 4|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($agg$result) + 8|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = Math_fround(HEAPF32[$invProjection>>2]);
 $53 = Math_fround($33 * $52);
 $54 = (($invProjection) + 16|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($38 * $55);
 $57 = Math_fround($53 + $56);
 $58 = (($invProjection) + 32|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 * $49);
 $61 = Math_fround($57 + $60);
 $62 = (($invProjection) + 48|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 + $61);
 $65 = (($invProjection) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($33 * $66);
 $68 = (($invProjection) + 20|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($38 * $69);
 $71 = Math_fround($67 + $70);
 $72 = (($invProjection) + 36|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($49 * $73);
 $75 = Math_fround($71 + $74);
 $76 = (($invProjection) + 52|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 + $75);
 $79 = (($invProjection) + 12|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($33 * $80);
 $82 = (($invProjection) + 28|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($38 * $83);
 $85 = Math_fround($81 + $84);
 $86 = (($invProjection) + 44|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($49 * $87);
 $89 = Math_fround($85 + $88);
 $90 = (($invProjection) + 60|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 + $89);
 $93 = $92 < Math_fround(0.0);
 if ($93) {
  $94 = Math_fround(-$92);
  $96 = $94;
 } else {
  $96 = $92;
 }
 $95 = $96 > Math_fround(1.00000001168609742308E-7);
 if ($95) {
  $97 = Math_fround(Math_fround(1.0) / $92);
  $98 = Math_fround($64 * $97);
  HEAPF32[$agg$result>>2] = $98;
  $99 = Math_fround($78 * $97);
  $storemerge = $99;
  HEAPF32[$50>>2] = $storemerge;
  HEAPF32[$51>>2] = $40;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $storemerge = Math_fround(0.0);
  HEAPF32[$50>>2] = $storemerge;
  HEAPF32[$51>>2] = $40;
  STACKTOP = sp;return;
 }
}
function __ZNK6Camera18ViewportPointToRayERK8Vector2f($agg$result,$this,$viewPortPos) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $viewPortPos = $viewPortPos|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $5 = Math_fround(0);
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $screenRect$i$i$i = 0, $storemerge$i$i$i$i = Math_fround(0), $storemerge1$i$i$i$i = Math_fround(0), $x2$0$i$i$i$i = Math_fround(0), $y2$0$i$i$i$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $screenRect$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$viewPortPos>>2]);
 $2 = (($viewPortPos) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 __ZL19GetCameraTargetRectRK6Camerab($screenRect$i$i$i,$this,1);
 $4 = (($this) + 396|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 400|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 404|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 408|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($screenRect$i$i$i) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($screenRect$i$i$i) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($5 * $13);
 $17 = Math_fround($9 * $13);
 $18 = Math_fround($7 * $15);
 $19 = Math_fround($11 * $15);
 $20 = Math_fround(HEAPF32[$screenRect$i$i$i>>2]);
 $21 = (($screenRect$i$i$i) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($16 + $20);
 $24 = Math_fround($18 + $22);
 $25 = Math_fround($17 + $23);
 $26 = Math_fround($19 + $24);
 $27 = Math_fround($13 + $20);
 $28 = Math_fround($15 + $22);
 $29 = $23 < $20;
 $30 = $29 ? $20 : $23;
 $31 = $25 > $27;
 $x2$0$i$i$i$i = $31 ? $27 : $25;
 $32 = $24 < $22;
 $33 = $32 ? $22 : $24;
 $34 = $26 > $28;
 $y2$0$i$i$i$i = $34 ? $28 : $26;
 $35 = Math_fround($x2$0$i$i$i$i - $30);
 $36 = $35 < Math_fround(0.0);
 $storemerge1$i$i$i$i = $36 ? Math_fround(0.0) : $35;
 $37 = Math_fround($y2$0$i$i$i$i - $33);
 $38 = $37 < Math_fround(0.0);
 $storemerge$i$i$i$i = $38 ? Math_fround(0.0) : $37;
 $39 = Math_fround($1 * $storemerge1$i$i$i$i);
 $40 = Math_fround($30 + $39);
 $41 = Math_fround($3 * $storemerge$i$i$i$i);
 $42 = Math_fround($33 + $41);
 HEAPF32[$0>>2] = $40;
 $43 = (($0) + 4|0);
 HEAPF32[$43>>2] = $42;
 __ZNK6Camera16ScreenPointToRayERK8Vector2f($agg$result,$this,$0);
 STACKTOP = sp;return;
}
function __ZN6Camera9SetAspectEf($this,$aspect) {
 $this = $this|0;
 $aspect = Math_fround($aspect);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 596|0);
 HEAPF32[$0>>2] = $aspect;
 $1 = (($this) + 609|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 610|0);
 HEAP8[$2>>0] = 1;
 $3 = (($this) + 615|0);
 HEAP8[$3>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK6Camera25GetSkyboxProjectionMatrixEfR10Matrix4x4f($this,$nearClip,$outMatrix) {
 $this = $this|0;
 $nearClip = Math_fround($nearClip);
 $outMatrix = $outMatrix|0;
 var $$pr$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = Math_fround(0), $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 614|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if (!($2)) {
   $3 = (($this) + 611|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if (!($5)) {
    $6 = (($this) + 616|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = ($7<<24>>24)==(0);
    $9 = (($this) + 224|0);
    if ($8) {
     $10 = (($this) + 452|0);
     $11 = Math_fround(HEAPF32[$10>>2]);
     $12 = (($this) + 596|0);
     $13 = Math_fround(HEAPF32[$12>>2]);
     $14 = (($this) + 456|0);
     $15 = Math_fround(HEAPF32[$14>>2]);
     $16 = (($this) + 460|0);
     $17 = Math_fround(HEAPF32[$16>>2]);
     (__ZN10Matrix4x4f14SetPerspectiveEffff($9,$11,$13,$15,$17)|0);
    } else {
     $18 = (($this) + 448|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = Math_fround(-$19);
     $21 = (($this) + 596|0);
     $22 = Math_fround(HEAPF32[$21>>2]);
     $23 = Math_fround($22 * $20);
     $24 = Math_fround($19 * $22);
     $25 = (($this) + 456|0);
     $26 = Math_fround(HEAPF32[$25>>2]);
     $27 = (($this) + 460|0);
     $28 = Math_fround(HEAPF32[$27>>2]);
     (__ZN10Matrix4x4f8SetOrthoEffffff($9,$23,$24,$20,$19,$26,$28)|0);
    }
    HEAP8[$3>>0] = 0;
    $$pr$pre = HEAP8[$0>>0]|0;
    $29 = ($$pr$pre<<24>>24)==(0);
    if ($29) {
     break;
    }
   }
   $68 = (($this) + 616|0);
   $69 = HEAP8[$68>>0]|0;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    $71 = (($this) + 452|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = (($this) + 596|0);
    $74 = Math_fround(HEAPF32[$73>>2]);
    $75 = (($this) + 460|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    (__ZN10Matrix4x4f14SetPerspectiveEffff($outMatrix,$72,$74,$nearClip,$76)|0);
    STACKTOP = sp;return;
   } else {
    $77 = (($this) + 448|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = Math_fround(-$78);
    $80 = (($this) + 596|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = Math_fround($81 * $79);
    $83 = Math_fround($78 * $81);
    $84 = (($this) + 460|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    (__ZN10Matrix4x4f8SetOrthoEffffff($outMatrix,$82,$83,$79,$78,$nearClip,$85)|0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $30 = (($this) + 224|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 244|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 256|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($this) + 260|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($this) + 456|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * Math_fround(2.0));
 $41 = Math_fround($40 / $31);
 $42 = Math_fround($35 + Math_fround(1.0));
 $43 = Math_fround($42 * Math_fround(0.5));
 $44 = Math_fround($43 * $41);
 $45 = Math_fround($40 / $33);
 $46 = Math_fround($37 + Math_fround(1.0));
 $47 = Math_fround($46 * Math_fround(0.5));
 $48 = Math_fround($47 * $45);
 $49 = +$41;
 $50 = +$42;
 $51 = $50 * 0.5;
 $52 = $51 + -1.0;
 $53 = $49 * $52;
 $54 = Math_fround($53);
 $55 = +$45;
 $56 = +$46;
 $57 = $56 * 0.5;
 $58 = $57 + -1.0;
 $59 = $55 * $58;
 $60 = Math_fround($59);
 $61 = Math_fround($nearClip / $39);
 $62 = Math_fround($44 * $61);
 $63 = Math_fround($48 * $61);
 $64 = Math_fround($61 * $54);
 $65 = Math_fround($61 * $60);
 $66 = (($this) + 460|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 (__ZN10Matrix4x4f14SetPerspectiveEffffff($outMatrix,$64,$62,$63,$65,$nearClip,$67)|0);
 STACKTOP = sp;return;
}
function __ZNK6Camera27GetImplicitProjectionMatrixEffR10Matrix4x4f($this,$overrideNearPlane,$overrideFarPlane,$outMatrix) {
 $this = $this|0;
 $overrideNearPlane = Math_fround($overrideNearPlane);
 $overrideFarPlane = Math_fround($overrideFarPlane);
 $outMatrix = $outMatrix|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 616|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 452|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($this) + 596|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  (__ZN10Matrix4x4f14SetPerspectiveEffff($outMatrix,$4,$6,$overrideNearPlane,$overrideFarPlane)|0);
  STACKTOP = sp;return;
 } else {
  $7 = (($this) + 448|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround(-$8);
  $10 = (($this) + 596|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($11 * $9);
  $13 = Math_fround($8 * $11);
  (__ZN10Matrix4x4f8SetOrthoEffffff($outMatrix,$12,$13,$9,$8,$overrideNearPlane,$overrideFarPlane)|0);
  STACKTOP = sp;return;
 }
}
function __ZN6Camera23SetTargetTextureBuffersEP13RenderTextureiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES6_S1_($this,$tex,$colorCount,$color,$depth,$rbOrigin) {
 $this = $this|0;
 $tex = $tex|0;
 $colorCount = $colorCount|0;
 $color = $color|0;
 $depth = $depth|0;
 $rbOrigin = $rbOrigin|0;
 var $$0$i$i = 0, $$not = 0, $$not1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $brmerge = 0, $brmerge3 = 0, $or$cond = 0, $phitmp = 0, $pos$i$i$i$i$i = 0, $storemerge = 0, $temp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($tex|0)==(0|0);
 if ($2) {
  $8 = 0;
 } else {
  $3 = (($tex) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($8|0);
 if ($7) {
  $9 = (($this) + 328|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($colorCount|0);
  if ($11) {
   $12 = (($this) + 296|0);
   $13 = $colorCount << 2;
   $14 = (_memcmp($color,$12,$13)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = HEAP32[$depth>>2]|0;
    $17 = (($this) + 332|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($16|0)==($18|0);
    $20 = $19;
   } else {
    $20 = 0;
   }
  } else {
   $20 = 0;
  }
  $$not = $2 ^ 1;
  $brmerge = $20 | $$not;
  if ($brmerge) {
   STACKTOP = sp;return;
  }
 }
 $21 = (__Z16GetRenderManagerv()|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i$i = 0;
 } else {
  HEAP32[$0>>2] = $22;
  $24 = HEAP32[560624>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   label = 17;
  } else {
   $26 = (($24) + 36|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($24) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)==($29|0);
   do {
    if ($30) {
     $31 = (($24) + 28|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($24) + 32|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + ($34<<3)|0);
     $51 = $35;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$24,$0);
     $36 = HEAP32[$pos$i$i$i$i$i>>2]|0;
     $37 = ($36|0)==(-1);
     $38 = (($24) + 28|0);
     $39 = HEAP32[$38>>2]|0;
     if ($37) {
      $40 = (($24) + 32|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($39) + ($41<<3)|0);
      $51 = $42;
      break;
     } else {
      $43 = (($39) + ($36<<3)|0);
      $51 = $43;
      break;
     }
    }
   } while(0);
   $44 = HEAP32[560624>>2]|0;
   $45 = (($44) + 28|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 32|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($46) + ($48<<3)|0);
   $50 = ($51|0)==($49|0);
   if ($50) {
    label = 17;
   } else {
    $52 = (($51) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     label = 17;
    } else {
     $temp$0$i$i = $53;
    }
   }
  }
  if ((label|0) == 17) {
   $55 = HEAP32[$21>>2]|0;
   $56 = (__Z31ReadObjectFromPersistentManageri($55)|0);
   $temp$0$i$i = $56;
  }
  $$0$i$i = $temp$0$i$i;
 }
 $57 = HEAP32[$5>>2]|0;
 $58 = ($57|0)==(0);
 do {
  if ($58) {
   label = 29;
  } else {
   HEAP32[$1>>2] = $57;
   $59 = HEAP32[560624>>2]|0;
   $60 = ($59|0)==(0|0);
   if (!($60)) {
    $61 = (($59) + 36|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($59) + 4|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($62|0)==($64|0);
    do {
     if ($65) {
      $66 = (($59) + 28|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($59) + 32|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($67) + ($69<<3)|0);
      $86 = $70;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$59,$1);
      $71 = HEAP32[$pos$i$i$i$i$i>>2]|0;
      $72 = ($71|0)==(-1);
      $73 = (($59) + 28|0);
      $74 = HEAP32[$73>>2]|0;
      if ($72) {
       $75 = (($59) + 32|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = (($74) + ($76<<3)|0);
       $86 = $77;
       break;
      } else {
       $78 = (($74) + ($71<<3)|0);
       $86 = $78;
       break;
      }
     }
    } while(0);
    $79 = HEAP32[560624>>2]|0;
    $80 = (($79) + 28|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($79) + 32|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($81) + ($83<<3)|0);
    $85 = ($86|0)==($84|0);
    if (!($85)) {
     $87 = (($86) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ($88|0)==(0|0);
     if (!($89)) {
      $112 = 0;
      break;
     }
    }
   }
   $90 = HEAP32[$5>>2]|0;
   $91 = (__Z31ReadObjectFromPersistentManageri($90)|0);
   $92 = ($91|0)==(0|0);
   if ($92) {
    label = 29;
   } else {
    $112 = 0;
   }
  }
 } while(0);
 if ((label|0) == 29) {
  $93 = (($this) + 336|0);
  $94 = HEAP32[$93>>2]|0;
  $phitmp = ($94|0)==(0|0);
  $112 = $phitmp;
 }
 if ($2) {
  $storemerge = 0;
 } else {
  $95 = (($tex) + 4|0);
  $96 = HEAP32[$95>>2]|0;
  $storemerge = $96;
 }
 HEAP32[$5>>2] = $storemerge;
 $97 = (($this) + 296|0);
 $98 = $colorCount << 2;
 _memcpy(($97|0),($color|0),($98|0))|0;
 $99 = ($colorCount|0)<(8);
 if ($99) {
  $100 = ((($this) + ($colorCount<<2)|0) + 296|0);
  $101 = (8 - ($colorCount))|0;
  $102 = $101 << 2;
  _memset(($100|0),0,($102|0))|0;
 }
 $103 = (($this) + 328|0);
 HEAP32[$103>>2] = $colorCount;
 $104 = HEAP32[$depth>>2]|0;
 $105 = (($this) + 332|0);
 HEAP32[$105>>2] = $104;
 $106 = (($this) + 336|0);
 HEAP32[$106>>2] = $rbOrigin;
 $107 = (($this) + 29|0);
 $108 = HEAP8[$107>>0]|0;
 $109 = ($108<<24>>24)==(0);
 if ($109) {
  STACKTOP = sp;return;
 }
 $110 = (__Z16GetRenderManagerv()|0);
 __ZN13RenderManager12RemoveCameraEP6Camera($110,$this);
 $111 = (__Z16GetRenderManagerv()|0);
 __ZN13RenderManager9AddCameraEP6Camera($111,$this);
 $$not1 = ($$0$i$i|0)!=($this|0);
 $brmerge3 = $$not1 | $112;
 if ($brmerge3) {
  STACKTOP = sp;return;
 }
 $113 = ($rbOrigin|0)==(0|0);
 $or$cond = $2 & $113;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $114 = (__Z16GetRenderManagerv()|0);
 $115 = ($this|0)==(0|0);
 if ($115) {
  HEAP32[$114>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $116 = (($this) + 4|0);
  $117 = HEAP32[$116>>2]|0;
  HEAP32[$114>>2] = $117;
  STACKTOP = sp;return;
 }
}
function __ZN6Camera7SetNearEf($this,$n) {
 $this = $this|0;
 $n = Math_fround($n);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 456|0);
 HEAPF32[$0>>2] = $n;
 $1 = (($this) + 609|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 610|0);
 HEAP8[$2>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN6Camera6SetFarEf($this,$f) {
 $this = $this|0;
 $f = Math_fround($f);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 460|0);
 HEAPF32[$0>>2] = $f;
 $1 = (($this) + 609|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 610|0);
 HEAP8[$2>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN6Camera19SetOrthographicSizeEf($this,$f) {
 $this = $this|0;
 $f = Math_fround($f);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 448|0);
 HEAPF32[$0>>2] = $f;
 $1 = (($this) + 609|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 610|0);
 HEAP8[$2>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN6Camera15SetOrthographicEb($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 616|0);
 $1 = $v&1;
 HEAP8[$0>>0] = $1;
 $2 = (($this) + 609|0);
 HEAP8[$2>>0] = 1;
 $3 = (($this) + 610|0);
 HEAP8[$3>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN6Camera18SetBackgroundColorERK10ColorRGBAf($this,$color) {
 $this = $this|0;
 $color = $color|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$color>>2]);
 $1 = (($color) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($color) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($color) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 380|0);
 HEAPF32[$7>>2] = $0;
 $8 = (($this) + 384|0);
 HEAPF32[$8>>2] = $2;
 $9 = (($this) + 388|0);
 HEAPF32[$9>>2] = $4;
 $10 = (($this) + 392|0);
 HEAPF32[$10>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN6Camera13SetClearFlagsEi($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 376|0);
 HEAP32[$0>>2] = $flags;
 STACKTOP = sp;return;
}
function __ZN6Camera14SetCullingMaskEj($this,$cullingMask) {
 $this = $this|0;
 $cullingMask = $cullingMask|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 412|0);
 HEAP32[$0>>2] = $cullingMask;
 STACKTOP = sp;return;
}
function __Z20RegisterClass_Camerav() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(20,89,90,0,91);
 STACKTOP = sp;return;
}
function __ZN6Camera13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 HEAP8[$0>>0] = 12;
 $3 = (($0) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[570920+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[570920+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[570920+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[570920+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[570920+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[570920+5>>0]|0;
 $4 = (($0) + 7|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,20,8,($0|0),972,(2372|0),0,1);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN6Camera12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Camera7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(972,$$byval_copy2,1,16,569816,91)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1674,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(569816|0),91);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK6Camera25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 20;
}
function __ZN6Camera23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,570928,570920,$this,0);
 __ZN6Camera8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN6Camera23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,570928,570920,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN6Camera8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN6Camera23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6Camera8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN6Camera23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6Camera8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN6Camera23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6Camera8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN6Camera23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 292|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN6CameraD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6CameraD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN6CameraD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3414,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN6Camera8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0);
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 376|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
 }
 $8 = (($this) + 380|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 396|0);
 __ZN5RectTIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($9,$transfer);
 $10 = (($this) + 456|0);
 $11 = HEAP32[$1>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$4>>2]|0;
 $14 = ($12>>>0)<($13>>>0);
 if ($14) {
  $15 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$11>>2] = $15;
  HEAP32[$1>>2] = $12;
  $18 = $12;$20 = $13;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$10,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $18 = $$pre;$20 = $$pre10;
 }
 $16 = (($this) + 460|0);
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)<($20>>>0);
 if ($19) {
  $21 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$18>>2] = $21;
  HEAP32[$1>>2] = $17;
  $24 = $17;$26 = $20;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$16,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $24 = $$pre11;$26 = $$pre12;
 }
 $22 = (($this) + 452|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)<($26>>>0);
 if ($25) {
  $27 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$24>>2] = $27;
  HEAP32[$1>>2] = $23;
  $30 = $23;$32 = $26;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$22,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $30 = $$pre13;$32 = $$pre14;
 }
 $28 = (($this) + 616|0);
 $29 = (($30) + 1|0);
 $31 = ($29>>>0)<($32>>>0);
 if ($31) {
  $33 = HEAP8[$28>>0]|0;
  HEAP8[$30>>0] = $33;
  $34 = HEAP32[$1>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$1>>2] = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$28,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $36 = (($this) + 448|0);
 $37 = HEAP32[$1>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$4>>2]|0;
 $40 = ($38>>>0)<($39>>>0);
 if ($40) {
  $41 = Math_fround(HEAPF32[$36>>2]);
  HEAPF32[$37>>2] = $41;
  HEAP32[$1>>2] = $38;
  $44 = $38;$46 = $39;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$36,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $44 = $$pre15;$46 = $$pre16;
 }
 $42 = (($this) + 420|0);
 $43 = (($44) + 4|0);
 $45 = ($43>>>0)<($46>>>0);
 if ($45) {
  $47 = Math_fround(HEAPF32[$42>>2]);
  HEAPF32[$44>>2] = $47;
  HEAP32[$1>>2] = $43;
  $50 = $43;$52 = $46;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$42,4);
  $$pre17 = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $50 = $$pre17;$52 = $$pre18;
 }
 $48 = (($this) + 412|0);
 $49 = (($50) + 4|0);
 $51 = ($49>>>0)<($52>>>0);
 if ($51) {
  $53 = HEAP32[$48>>2]|0;
  HEAP32[$50>>2] = $53;
  HEAP32[$1>>2] = $49;
  $56 = $49;$58 = $52;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$48,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $56 = $$pre19;$58 = $$pre20;
 }
 $54 = (($this) + 464|0);
 $55 = (($56) + 4|0);
 $57 = ($55>>>0)<($58>>>0);
 if ($57) {
  $59 = HEAP32[$54>>2]|0;
  HEAP32[$56>>2] = $59;
  HEAP32[$1>>2] = $55;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$54,4);
 }
 $60 = (($this) + 292|0);
 __ZN4PPtrI13RenderTextureE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($60,$transfer);
 $61 = (($this) + 352|0);
 $62 = HEAP32[$1>>2]|0;
 $63 = (($62) + 4|0);
 $64 = HEAP32[$4>>2]|0;
 $65 = ($63>>>0)<($64>>>0);
 if ($65) {
  $66 = HEAP32[$61>>2]|0;
  HEAP32[$62>>2] = $66;
  HEAP32[$1>>2] = $63;
  $69 = $63;$71 = $64;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$61,4);
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $69 = $$pre21;$71 = $$pre22;
 }
 $67 = (($this) + 619|0);
 $68 = (($69) + 1|0);
 $70 = ($68>>>0)<($71>>>0);
 if ($70) {
  $72 = HEAP8[$67>>0]|0;
  HEAP8[$69>>0] = $72;
  $73 = HEAP32[$1>>2]|0;
  $74 = (($73) + 1|0);
  HEAP32[$1>>2] = $74;
  $77 = $74;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$67,1);
  $$pre23 = HEAP32[$1>>2]|0;
  $77 = $$pre23;
 }
 $75 = (($this) + 617|0);
 $76 = (($77) + 1|0);
 $78 = HEAP32[$4>>2]|0;
 $79 = ($76>>>0)<($78>>>0);
 if ($79) {
  $80 = HEAP8[$75>>0]|0;
  HEAP8[$77>>0] = $80;
  $81 = HEAP32[$1>>2]|0;
  $82 = (($81) + 1|0);
  HEAP32[$1>>2] = $82;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$75,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $83 = (($this) + 628|0);
 $84 = HEAP32[$1>>2]|0;
 $85 = (($84) + 4|0);
 $86 = HEAP32[$4>>2]|0;
 $87 = ($85>>>0)<($86>>>0);
 if ($87) {
  $88 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$84>>2] = $88;
  HEAP32[$1>>2] = $85;
  $91 = $85;$93 = $86;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$83,4);
  $$pre24 = HEAP32[$1>>2]|0;
  $$pre25 = HEAP32[$4>>2]|0;
  $91 = $$pre24;$93 = $$pre25;
 }
 $89 = (($this) + 624|0);
 $90 = (($91) + 4|0);
 $92 = ($90>>>0)<($93>>>0);
 if ($92) {
  $94 = Math_fround(HEAPF32[$89>>2]);
  HEAPF32[$91>>2] = $94;
  HEAP32[$1>>2] = $90;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$89,4);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI13RenderTextureE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN6Camera8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i24 = 0, $$pre$i$i$i27 = 0, $$pre$i$i$i28 = 0, $$pre$i$i$i34 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i9 = 0, $$pre$phi$i$i$i10Z2D = 0, $$pre$phi$i$i$i15Z2D = 0, $$pre$phi$i$i$i20Z2D = 0, $$pre$phi$i$i$i25Z2D = 0, $$pre$phi$i$i$i35Z2D = 0, $$pre$phi$i$i$i5Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre37 = 0;
 var $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 376|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $8 = $$pre$i$i$i1;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 380|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 $11 = (($this) + 396|0);
 __ZN5RectTIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($11,$transfer);
 $12 = (($this) + 456|0);
 $13 = HEAP32[$1>>2]|0;
 $14 = (($13) + 4|0);
 $15 = HEAP32[$4>>2]|0;
 $16 = ($14>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$12,4);
  $$pre$i$i$i4 = HEAP32[$12>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre37 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i5Z2D = $12;$19 = $$pre$i$i$i4;$23 = $$pre;$25 = $$pre37;
 } else {
  $17 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$12>>2] = $17;
  HEAP32[$1>>2] = $14;
  $18 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i5Z2D = $12;$19 = $18;$23 = $14;$25 = $15;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$$pre$phi$i$i$i5Z2D>>2] = $20;
 $21 = (($this) + 460|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$21,4);
  $$pre$i$i$i9 = HEAP32[$21>>2]|0;
  $$pre38 = HEAP32[$1>>2]|0;
  $$pre39 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i10Z2D = $21;$28 = $$pre$i$i$i9;$32 = $$pre38;$34 = $$pre39;
 } else {
  $26 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$21>>2] = $26;
  HEAP32[$1>>2] = $22;
  $27 = (HEAPF32[tempDoublePtr>>2]=$26,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i10Z2D = $21;$28 = $27;$32 = $22;$34 = $25;
 }
 $29 = (_llvm_bswap_i32(($28|0))|0);
 HEAP32[$$pre$phi$i$i$i10Z2D>>2] = $29;
 $30 = (($this) + 452|0);
 $31 = (($32) + 4|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$30,4);
  $$pre$i$i$i14 = HEAP32[$30>>2]|0;
  $$pre40 = HEAP32[$1>>2]|0;
  $$pre41 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i15Z2D = $30;$37 = $$pre$i$i$i14;$41 = $$pre40;$43 = $$pre41;
 } else {
  $35 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$30>>2] = $35;
  HEAP32[$1>>2] = $31;
  $36 = (HEAPF32[tempDoublePtr>>2]=$35,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i15Z2D = $30;$37 = $36;$41 = $31;$43 = $34;
 }
 $38 = (_llvm_bswap_i32(($37|0))|0);
 HEAP32[$$pre$phi$i$i$i15Z2D>>2] = $38;
 $39 = (($this) + 616|0);
 $40 = (($41) + 1|0);
 $42 = ($40>>>0)>($43>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$39,1);
 } else {
  $44 = HEAP8[$41>>0]|0;
  HEAP8[$39>>0] = $44;
  $45 = HEAP32[$1>>2]|0;
  $46 = (($45) + 1|0);
  HEAP32[$1>>2] = $46;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $47 = (($this) + 448|0);
 $48 = HEAP32[$1>>2]|0;
 $49 = (($48) + 4|0);
 $50 = HEAP32[$4>>2]|0;
 $51 = ($49>>>0)>($50>>>0);
 if ($51) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$47,4);
  $$pre$i$i$i19 = HEAP32[$47>>2]|0;
  $$pre42 = HEAP32[$1>>2]|0;
  $$pre43 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i20Z2D = $47;$54 = $$pre$i$i$i19;$58 = $$pre42;$60 = $$pre43;
 } else {
  $52 = Math_fround(HEAPF32[$48>>2]);
  HEAPF32[$47>>2] = $52;
  HEAP32[$1>>2] = $49;
  $53 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i20Z2D = $47;$54 = $53;$58 = $49;$60 = $50;
 }
 $55 = (_llvm_bswap_i32(($54|0))|0);
 HEAP32[$$pre$phi$i$i$i20Z2D>>2] = $55;
 $56 = (($this) + 420|0);
 $57 = (($58) + 4|0);
 $59 = ($57>>>0)>($60>>>0);
 if ($59) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$56,4);
  $$pre$i$i$i24 = HEAP32[$56>>2]|0;
  $$pre44 = HEAP32[$1>>2]|0;
  $$pre45 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i25Z2D = $56;$63 = $$pre$i$i$i24;$67 = $$pre44;$69 = $$pre45;
 } else {
  $61 = Math_fround(HEAPF32[$58>>2]);
  HEAPF32[$56>>2] = $61;
  HEAP32[$1>>2] = $57;
  $62 = (HEAPF32[tempDoublePtr>>2]=$61,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i25Z2D = $56;$63 = $62;$67 = $57;$69 = $60;
 }
 $64 = (_llvm_bswap_i32(($63|0))|0);
 HEAP32[$$pre$phi$i$i$i25Z2D>>2] = $64;
 $65 = (($this) + 412|0);
 $66 = (($67) + 4|0);
 $68 = ($66>>>0)>($69>>>0);
 if ($68) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$65,4);
  $$pre$i$i$i$i$i$i = HEAP32[$65>>2]|0;
  $$pre46 = HEAP32[$1>>2]|0;
  $$pre47 = HEAP32[$4>>2]|0;
  $71 = $$pre$i$i$i$i$i$i;$75 = $$pre46;$77 = $$pre47;
 } else {
  $70 = HEAP32[$67>>2]|0;
  HEAP32[$65>>2] = $70;
  HEAP32[$1>>2] = $66;
  $71 = $70;$75 = $66;$77 = $69;
 }
 $72 = (_llvm_bswap_i32(($71|0))|0);
 HEAP32[$65>>2] = $72;
 $73 = (($this) + 464|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)>($77>>>0);
 if ($76) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$73,4);
  $$pre$i$i$i27 = HEAP32[$73>>2]|0;
  $79 = $$pre$i$i$i27;
 } else {
  $78 = HEAP32[$75>>2]|0;
  HEAP32[$73>>2] = $78;
  HEAP32[$1>>2] = $74;
  $79 = $78;
 }
 $80 = (_llvm_bswap_i32(($79|0))|0);
 HEAP32[$73>>2] = $80;
 $81 = (($this) + 292|0);
 __ZN4PPtrI13RenderTextureE8TransferI18StreamedBinaryReadILb1EEEEvRT_($81,$transfer);
 $82 = (($this) + 352|0);
 $83 = HEAP32[$1>>2]|0;
 $84 = (($83) + 4|0);
 $85 = HEAP32[$4>>2]|0;
 $86 = ($84>>>0)>($85>>>0);
 if ($86) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$82,4);
  $$pre$i$i$i28 = HEAP32[$82>>2]|0;
  $$pre48 = HEAP32[$1>>2]|0;
  $$pre49 = HEAP32[$4>>2]|0;
  $88 = $$pre$i$i$i28;$92 = $$pre48;$94 = $$pre49;
 } else {
  $87 = HEAP32[$83>>2]|0;
  HEAP32[$82>>2] = $87;
  HEAP32[$1>>2] = $84;
  $88 = $87;$92 = $84;$94 = $85;
 }
 $89 = (_llvm_bswap_i32(($88|0))|0);
 HEAP32[$82>>2] = $89;
 $90 = (($this) + 619|0);
 $91 = (($92) + 1|0);
 $93 = ($91>>>0)>($94>>>0);
 if ($93) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$90,1);
  $$pre50 = HEAP32[$1>>2]|0;
  $100 = $$pre50;
 } else {
  $95 = HEAP8[$92>>0]|0;
  HEAP8[$90>>0] = $95;
  $96 = HEAP32[$1>>2]|0;
  $97 = (($96) + 1|0);
  HEAP32[$1>>2] = $97;
  $100 = $97;
 }
 $98 = (($this) + 617|0);
 $99 = (($100) + 1|0);
 $101 = HEAP32[$4>>2]|0;
 $102 = ($99>>>0)>($101>>>0);
 if ($102) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$98,1);
 } else {
  $103 = HEAP8[$100>>0]|0;
  HEAP8[$98>>0] = $103;
  $104 = HEAP32[$1>>2]|0;
  $105 = (($104) + 1|0);
  HEAP32[$1>>2] = $105;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $106 = (($this) + 628|0);
 $107 = HEAP32[$1>>2]|0;
 $108 = (($107) + 4|0);
 $109 = HEAP32[$4>>2]|0;
 $110 = ($108>>>0)>($109>>>0);
 if ($110) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$106,4);
  $$pre$i$i$i34 = HEAP32[$106>>2]|0;
  $$pre51 = HEAP32[$1>>2]|0;
  $$pre52 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i35Z2D = $106;$113 = $$pre$i$i$i34;$117 = $$pre51;$119 = $$pre52;
 } else {
  $111 = Math_fround(HEAPF32[$107>>2]);
  HEAPF32[$106>>2] = $111;
  HEAP32[$1>>2] = $108;
  $112 = (HEAPF32[tempDoublePtr>>2]=$111,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i35Z2D = $106;$113 = $112;$117 = $108;$119 = $109;
 }
 $114 = (_llvm_bswap_i32(($113|0))|0);
 HEAP32[$$pre$phi$i$i$i35Z2D>>2] = $114;
 $115 = (($this) + 624|0);
 $116 = (($117) + 4|0);
 $118 = ($116>>>0)>($119>>>0);
 if ($118) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$115,4);
  $$pre$i$i$i = HEAP32[$115>>2]|0;
  $$pre$phi$i$i$iZ2D = $115;$122 = $$pre$i$i$i;
  $123 = (_llvm_bswap_i32(($122|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $123;
  STACKTOP = sp;return;
 } else {
  $120 = Math_fround(HEAPF32[$117>>2]);
  HEAPF32[$115>>2] = $120;
  HEAP32[$1>>2] = $116;
  $121 = (HEAPF32[tempDoublePtr>>2]=$120,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $115;$122 = $121;
  $123 = (_llvm_bswap_i32(($122|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $123;
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI13RenderTextureE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN6Camera8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0);
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 376|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
 }
 $8 = (($this) + 380|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 396|0);
 __ZN5RectTIfE8TransferI18StreamedBinaryReadILb0EEEEvRT_($9,$transfer);
 $10 = (($this) + 456|0);
 $11 = HEAP32[$1>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$4>>2]|0;
 $14 = ($12>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $18 = $$pre;$20 = $$pre10;
 } else {
  $15 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$1>>2] = $12;
  $18 = $12;$20 = $13;
 }
 $16 = (($this) + 460|0);
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)>($20>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$16,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $24 = $$pre11;$26 = $$pre12;
 } else {
  $21 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$16>>2] = $21;
  HEAP32[$1>>2] = $17;
  $24 = $17;$26 = $20;
 }
 $22 = (($this) + 452|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)>($26>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$22,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $30 = $$pre13;$32 = $$pre14;
 } else {
  $27 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$22>>2] = $27;
  HEAP32[$1>>2] = $23;
  $30 = $23;$32 = $26;
 }
 $28 = (($this) + 616|0);
 $29 = (($30) + 1|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$28,1);
 } else {
  $33 = HEAP8[$30>>0]|0;
  HEAP8[$28>>0] = $33;
  $34 = HEAP32[$1>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$1>>2] = $35;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $36 = (($this) + 448|0);
 $37 = HEAP32[$1>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$4>>2]|0;
 $40 = ($38>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$36,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $44 = $$pre15;$46 = $$pre16;
 } else {
  $41 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$36>>2] = $41;
  HEAP32[$1>>2] = $38;
  $44 = $38;$46 = $39;
 }
 $42 = (($this) + 420|0);
 $43 = (($44) + 4|0);
 $45 = ($43>>>0)>($46>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$42,4);
  $$pre17 = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $50 = $$pre17;$52 = $$pre18;
 } else {
  $47 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$42>>2] = $47;
  HEAP32[$1>>2] = $43;
  $50 = $43;$52 = $46;
 }
 $48 = (($this) + 412|0);
 $49 = (($50) + 4|0);
 $51 = ($49>>>0)>($52>>>0);
 if ($51) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$48,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $56 = $$pre19;$58 = $$pre20;
 } else {
  $53 = HEAP32[$50>>2]|0;
  HEAP32[$48>>2] = $53;
  HEAP32[$1>>2] = $49;
  $56 = $49;$58 = $52;
 }
 $54 = (($this) + 464|0);
 $55 = (($56) + 4|0);
 $57 = ($55>>>0)>($58>>>0);
 if ($57) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$54,4);
 } else {
  $59 = HEAP32[$56>>2]|0;
  HEAP32[$54>>2] = $59;
  HEAP32[$1>>2] = $55;
 }
 $60 = (($this) + 292|0);
 __ZN4PPtrI13RenderTextureE8TransferI18StreamedBinaryReadILb0EEEEvRT_($60,$transfer);
 $61 = (($this) + 352|0);
 $62 = HEAP32[$1>>2]|0;
 $63 = (($62) + 4|0);
 $64 = HEAP32[$4>>2]|0;
 $65 = ($63>>>0)>($64>>>0);
 if ($65) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$61,4);
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $69 = $$pre21;$71 = $$pre22;
 } else {
  $66 = HEAP32[$62>>2]|0;
  HEAP32[$61>>2] = $66;
  HEAP32[$1>>2] = $63;
  $69 = $63;$71 = $64;
 }
 $67 = (($this) + 619|0);
 $68 = (($69) + 1|0);
 $70 = ($68>>>0)>($71>>>0);
 if ($70) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$67,1);
  $$pre23 = HEAP32[$1>>2]|0;
  $77 = $$pre23;
 } else {
  $72 = HEAP8[$69>>0]|0;
  HEAP8[$67>>0] = $72;
  $73 = HEAP32[$1>>2]|0;
  $74 = (($73) + 1|0);
  HEAP32[$1>>2] = $74;
  $77 = $74;
 }
 $75 = (($this) + 617|0);
 $76 = (($77) + 1|0);
 $78 = HEAP32[$4>>2]|0;
 $79 = ($76>>>0)>($78>>>0);
 if ($79) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$75,1);
 } else {
  $80 = HEAP8[$77>>0]|0;
  HEAP8[$75>>0] = $80;
  $81 = HEAP32[$1>>2]|0;
  $82 = (($81) + 1|0);
  HEAP32[$1>>2] = $82;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $83 = (($this) + 628|0);
 $84 = HEAP32[$1>>2]|0;
 $85 = (($84) + 4|0);
 $86 = HEAP32[$4>>2]|0;
 $87 = ($85>>>0)>($86>>>0);
 if ($87) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$83,4);
  $$pre24 = HEAP32[$1>>2]|0;
  $$pre25 = HEAP32[$4>>2]|0;
  $91 = $$pre24;$93 = $$pre25;
 } else {
  $88 = Math_fround(HEAPF32[$84>>2]);
  HEAPF32[$83>>2] = $88;
  HEAP32[$1>>2] = $85;
  $91 = $85;$93 = $86;
 }
 $89 = (($this) + 624|0);
 $90 = (($91) + 4|0);
 $92 = ($90>>>0)>($93>>>0);
 if ($92) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$89,4);
  STACKTOP = sp;return;
 } else {
  $94 = Math_fround(HEAPF32[$91>>2]);
  HEAPF32[$89>>2] = $94;
  HEAP32[$1>>2] = $90;
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI13RenderTextureE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN6Camera8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i11 = 0, $$sum$i$i$i$i$i6 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i12 = 0, $$sum1$i$i$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i10 = sp;
 __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 376|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$0,570936,0);
 $1 = (($this) + 380|0);
 $2 = HEAP32[580560>>2]|0;
 $3 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,570952,$2,$converter$i$i10,1)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ($3|0)>(0);
  if ($5) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,571304,0);
   $6 = (($this) + 384|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,571312,0);
   $7 = (($this) + 388|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$7,571320,0);
   $8 = (($this) + 392|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$8,571328,0);
  } else {
   $9 = HEAP32[$converter$i$i10>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 396|0);
 $12 = HEAP32[580648>>2]|0;
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,570976,$12,$converter$i$i10,1)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$11,571272,0);
   $16 = (($this) + 400|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,571280,0);
   $17 = (($this) + 404|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$17,571288,0);
   $18 = (($this) + 408|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$18,571296,0);
  } else {
   $19 = HEAP32[$converter$i$i10>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (($this) + 456|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$21,571008,0);
 $22 = (($this) + 460|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$22,571024,0);
 $23 = (($this) + 452|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$23,571040,0);
 $24 = (($this) + 616|0);
 $25 = HEAP32[580544>>2]|0;
 $26 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,569600,$25,$converter$i$i10,0)|0);
 $27 = ($26|0)==(0);
 if (!($27)) {
  $28 = ($26|0)>(0);
  do {
   if ($28) {
    $29 = (($transfer) + 12|0);
    $30 = (($transfer) + 80|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + 12|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($transfer) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($transfer) + 28|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($transfer) + 32|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = Math_imul($39, $37)|0;
    $$sum$i$i$i$i$i = (($33) - ($40))|0;
    $41 = (($35) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$29>>2] = $41;
    $42 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($42)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $43 = (($35) + ($$sum1$i$i$i$i$i)|0);
     $44 = (($transfer) + 20|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($43>>>0)>($45>>>0);
     if (!($46)) {
      $47 = HEAP8[$41>>0]|0;
      HEAP8[$24>>0] = $47;
      $48 = HEAP32[$29>>2]|0;
      $49 = (($48) + 1|0);
      HEAP32[$29>>2] = $49;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($29,$24,1);
   } else {
    $50 = HEAP32[$converter$i$i10>>2]|0;
    $51 = ($50|0)==(0|0);
    if (!($51)) {
     (FUNCTION_TABLE_iii[$50 & 4095]($24,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $52 = (($this) + 448|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$52,571056,0);
 $53 = (($this) + 420|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$53,571080,0);
 $54 = (($this) + 412|0);
 $55 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,571088,571360,$converter$i$i10,1)|0);
 $56 = ($55|0)==(0);
 if (!($56)) {
  $57 = ($55|0)>(0);
  if ($57) {
   __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
   __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$54,571264,0);
   $58 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,1)|0);
   if ($58) {
    $59 = HEAP32[$54>>2]|0;
    $60 = $59 & 32;
    $61 = ($60|0)==(0);
    if (!($61)) {
     $62 = $59 | -65536;
     HEAP32[$54>>2] = $62;
    }
   }
  } else {
   $63 = HEAP32[$converter$i$i10>>2]|0;
   $64 = ($63|0)==(0|0);
   if (!($64)) {
    (FUNCTION_TABLE_iii[$63 & 4095]($54,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $65 = (($this) + 464|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$65,571104,0);
 $66 = (($this) + 292|0);
 $67 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,571120,571336,$converter$i$i10,1)|0);
 $68 = ($67|0)==(0);
 if (!($68)) {
  $69 = ($67|0)>(0);
  if ($69) {
   __ZN4PPtrI13RenderTextureE8TransferI14SafeBinaryReadEEvRT_($66,$transfer);
  } else {
   $70 = HEAP32[$converter$i$i10>>2]|0;
   $71 = ($70|0)==(0|0);
   if (!($71)) {
    (FUNCTION_TABLE_iii[$70 & 4095]($66,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $72 = (($this) + 352|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$72,571136,0);
 $73 = (($this) + 619|0);
 $74 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,571152,$25,$converter$i$i10,0)|0);
 $75 = ($74|0)==(0);
 if (!($75)) {
  $76 = ($74|0)>(0);
  do {
   if ($76) {
    $77 = (($transfer) + 12|0);
    $78 = (($transfer) + 80|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($79) + 12|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($transfer) + 16|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($transfer) + 28|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($transfer) + 32|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = Math_imul($87, $85)|0;
    $$sum$i$i$i$i$i6 = (($81) - ($88))|0;
    $89 = (($83) + ($$sum$i$i$i$i$i6)|0);
    HEAP32[$77>>2] = $89;
    $90 = ($$sum$i$i$i$i$i6|0)<(0);
    if (!($90)) {
     $$sum1$i$i$i$i$i7 = (($$sum$i$i$i$i$i6) + 1)|0;
     $91 = (($83) + ($$sum1$i$i$i$i$i7)|0);
     $92 = (($transfer) + 20|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ($91>>>0)>($93>>>0);
     if (!($94)) {
      $95 = HEAP8[$89>>0]|0;
      HEAP8[$73>>0] = $95;
      $96 = HEAP32[$77>>2]|0;
      $97 = (($96) + 1|0);
      HEAP32[$77>>2] = $97;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($77,$73,1);
   } else {
    $98 = HEAP32[$converter$i$i10>>2]|0;
    $99 = ($98|0)==(0|0);
    if (!($99)) {
     (FUNCTION_TABLE_iii[$98 & 4095]($73,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $100 = (($this) + 617|0);
 $101 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,571160,$25,$converter$i$i10,0)|0);
 $102 = ($101|0)==(0);
 if ($102) {
  $127 = (($this) + 628|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$127,571184,0);
  $128 = (($this) + 624|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$128,571208,0);
  STACKTOP = sp;return;
 }
 $103 = ($101|0)>(0);
 do {
  if ($103) {
   $104 = (($transfer) + 12|0);
   $105 = (($transfer) + 80|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = (($106) + 12|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($transfer) + 16|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = (($transfer) + 28|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = (($transfer) + 32|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = Math_imul($114, $112)|0;
   $$sum$i$i$i$i$i11 = (($108) - ($115))|0;
   $116 = (($110) + ($$sum$i$i$i$i$i11)|0);
   HEAP32[$104>>2] = $116;
   $117 = ($$sum$i$i$i$i$i11|0)<(0);
   if (!($117)) {
    $$sum1$i$i$i$i$i12 = (($$sum$i$i$i$i$i11) + 1)|0;
    $118 = (($110) + ($$sum1$i$i$i$i$i12)|0);
    $119 = (($transfer) + 20|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = ($118>>>0)>($120>>>0);
    if (!($121)) {
     $122 = HEAP8[$116>>0]|0;
     HEAP8[$100>>0] = $122;
     $123 = HEAP32[$104>>2]|0;
     $124 = (($123) + 1|0);
     HEAP32[$104>>2] = $124;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($104,$100,1);
  } else {
   $125 = HEAP32[$converter$i$i10>>2]|0;
   $126 = ($125|0)==(0|0);
   if (!($126)) {
    (FUNCTION_TABLE_iii[$125 & 4095]($100,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $127 = (($this) + 628|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$127,571184,0);
 $128 = (($this) + 624|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$128,571208,0);
 STACKTOP = sp;return;
}
function __ZN4PPtrI13RenderTextureE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,571232,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,571248,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,571232,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,571248,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN6Camera8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $localIdentifier$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 376|0);
 $1 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,570936,$1,$0,2048);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 380|0);
 $9 = HEAP32[580560>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,570952,$9,$8,2048);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($8,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 396|0);
 $11 = HEAP32[580648>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,570976,$11,$10,0);
 __ZN5RectTIfE8TransferI13ProxyTransferEEvRT_($10,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 456|0);
 $13 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571008,$13,$12,0);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 460|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571024,$13,$18,0);
 $19 = HEAP32[$2>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 452|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571040,$13,$23,2048);
 $24 = HEAP32[$2>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 616|0);
 $29 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,569600,$29,$28,0);
 $30 = HEAP32[$2>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$5>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $34 = (($this) + 448|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571056,$13,$34,0);
 $35 = HEAP32[$2>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$5>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $39 = (($this) + 420|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571080,$13,$39,0);
 $40 = HEAP32[$2>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$5>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = (($this) + 412|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571088,571360,$44,0);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571264,$1,$44,4194305);
 $45 = HEAP32[$2>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$5>>2]|0;
 $48 = ((($46) + (($47*24)|0)|0) + 12|0);
 HEAP32[$48>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $49 = (($this) + 464|0);
 $50 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571104,$50,$49,0);
 $51 = HEAP32[$2>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$5>>2]|0;
 $54 = ((($52) + (($53*24)|0)|0) + 12|0);
 HEAP32[$54>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $55 = (($this) + 292|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571120,571336,$55,0);
 $56 = (($localIdentifier$i$i$i) + 8|0);
 $57 = $56;
 $58 = $57;
 HEAP32[$58>>2] = 0;
 $59 = (($57) + 4)|0;
 $60 = $59;
 HEAP32[$60>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571232,$50,$55,1);
 $61 = HEAP32[$2>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP32[$5>>2]|0;
 $64 = ((($62) + (($63*24)|0)|0) + 12|0);
 HEAP32[$64>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $65 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571248,$65,$56,1);
 $66 = HEAP32[$2>>2]|0;
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$5>>2]|0;
 $69 = ((($67) + (($68*24)|0)|0) + 12|0);
 HEAP32[$69>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $70 = (($this) + 352|0);
 $71 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571136,$71,$70,0);
 $72 = HEAP32[$2>>2]|0;
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$5>>2]|0;
 $75 = ((($73) + (($74*24)|0)|0) + 12|0);
 HEAP32[$75>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $76 = (($this) + 619|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571152,$29,$76,0);
 $77 = HEAP32[$2>>2]|0;
 $78 = HEAP32[$77>>2]|0;
 $79 = HEAP32[$5>>2]|0;
 $80 = ((($78) + (($79*24)|0)|0) + 12|0);
 HEAP32[$80>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $81 = (($this) + 617|0);
 $82 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571160,$82,$81,0);
 $83 = HEAP32[$2>>2]|0;
 $84 = HEAP32[$83>>2]|0;
 $85 = HEAP32[$5>>2]|0;
 $86 = ((($84) + (($85*24)|0)|0) + 12|0);
 HEAP32[$86>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $87 = (($this) + 628|0);
 $88 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571184,$88,$87,0);
 $89 = HEAP32[$2>>2]|0;
 $90 = HEAP32[$89>>2]|0;
 $91 = HEAP32[$5>>2]|0;
 $92 = ((($90) + (($91*24)|0)|0) + 12|0);
 HEAP32[$92>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $93 = (($this) + 624|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571208,$88,$93,0);
 $94 = HEAP32[$2>>2]|0;
 $95 = HEAP32[$94>>2]|0;
 $96 = HEAP32[$5>>2]|0;
 $97 = ((($95) + (($96*24)|0)|0) + 12|0);
 HEAP32[$97>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI13dynamic_arrayIfLj4EE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEjRKS2_($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i129 = 0, $$0$i130 = 0, $$0$i3 = 0, $$01$i$i = 0, $$byval_copy12 = 0, $$idx$i$i$i$i = 0, $$idx$i$i$i$i$i = 0, $$idx$i$i$i$i4 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i5 = 0, $$pre$i11 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i$i = 0, $phitmp$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy12 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = ($10>>>0)<($__n>>>0);
 if (!($11)) {
  $12 = (($__x) + 4|0);
  $13 = (($__x) + 8|0);
  $$0$i = $__n;$15 = $6;
  while(1) {
   $14 = ($15|0)==(0|0);
   if ($14) {
    $28 = 0;
   } else {
    $16 = HEAP32[$12>>2]|0;
    $17 = (($15) + 4|0);
    HEAP32[$17>>2] = $16;
    $18 = (($15) + 8|0);
    HEAP32[$18>>2] = 0;
    $19 = (($15) + 12|0);
    HEAP32[$19>>2] = 0;
    HEAP32[$15>>2] = 0;
    $20 = HEAP32[$__x>>2]|0;
    $21 = HEAP32[$13>>2]|0;
    $$idx$i$i$i$i = $21 << 2;
    $22 = $$idx$i$i$i$i >> 2;
    HEAP32[$18>>2] = $22;
    $23 = ($22|0)==(0);
    if ($23) {
     $25 = 0;$26 = 0;
    } else {
     HEAP32[$19>>2] = $22;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i$i$i,4,$$byval_copy12,0,569816,370)|0);
     HEAP32[$15>>2] = $24;
     $$pre$i$i$i = HEAP32[$18>>2]|0;
     $phitmp$i$i$i = $$pre$i$i$i << 2;
     $25 = $24;$26 = $phitmp$i$i$i;
    }
    _memcpy(($25|0),($20|0),($26|0))|0;
    $$pre1$i = HEAP32[$5>>2]|0;
    $28 = $$pre1$i;
   }
   $27 = (($28) + 16|0);
   HEAP32[$5>>2] = $27;
   $29 = (($$0$i) + -1)|0;
   $30 = ($29|0)==(0);
   if ($30) {
    break;
   } else {
    $$0$i = $29;$15 = $27;
   }
  }
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$this>>2]|0;
 $32 = $31;
 $33 = (($8) - ($32))|0;
 $34 = $33 >> 4;
 $35 = (($34) + ($__n))|0;
 $36 = ($35|0)<(0);
 if ($36) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $37 = (($7) - ($32))|0;
 $38 = $37 >> 4;
 $39 = ($38>>>0)<(1073741823);
 if ($39) {
  $40 = $37 >> 3;
  $41 = ($40>>>0)<($35>>>0);
  $42 = $41 ? $35 : $40;
  $43 = ($42|0)==(0);
  if ($43) {
   $$0$i130 = 0;$47 = 0;
  } else {
   $$0$i129 = $42;
   label = 12;
  }
 } else {
  $$0$i129 = 2147483647;
  label = 12;
 }
 if ((label|0) == 12) {
  $44 = $$0$i129 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
  $45 = (__Z15malloc_internaljj10MemLabelIdiPKci($44,16,$$byval_copy12,0,569816,79)|0);
  $$0$i130 = $$0$i129;$47 = $45;
 }
 $46 = (($47) + ($34<<4)|0);
 $48 = (($47) + ($$0$i130<<4)|0);
 $49 = (($__x) + 4|0);
 $50 = (($__x) + 8|0);
 $$0$i3 = $__n;$52 = $46;
 while(1) {
  $51 = ($52|0)==(0|0);
  if ($51) {
   $67 = 0;
  } else {
   $53 = HEAP32[$49>>2]|0;
   $54 = (($52) + 4|0);
   HEAP32[$54>>2] = $53;
   $55 = (($52) + 8|0);
   HEAP32[$55>>2] = 0;
   $56 = (($52) + 12|0);
   HEAP32[$56>>2] = 0;
   HEAP32[$52>>2] = 0;
   $57 = HEAP32[$__x>>2]|0;
   $58 = HEAP32[$50>>2]|0;
   $$idx$i$i$i$i4 = $58 << 2;
   $59 = $$idx$i$i$i$i4 >> 2;
   HEAP32[$55>>2] = $59;
   $60 = ($59|0)==(0);
   if ($60) {
    $64 = 0;$65 = 0;
   } else {
    HEAP32[$56>>2] = $59;
    HEAP32[$1>>2] = $53;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
    $61 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i4|0),4,($$byval_copy12|0),0,(569816|0),370)|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 38;
     break;
    }
    HEAP32[$52>>2] = $61;
    $$pre$i$i$i5 = HEAP32[$55>>2]|0;
    $phitmp$i$i$i6 = $$pre$i$i$i5 << 2;
    $64 = $61;$65 = $phitmp$i$i$i6;
   }
   _memcpy(($64|0),($57|0),($65|0))|0;
   $67 = $52;
  }
  $66 = (($67) + 16|0);
  $68 = (($$0$i3) + -1)|0;
  $69 = ($68|0)==(0);
  if ($69) {
   label = 20;
   break;
  } else {
   $$0$i3 = $68;$52 = $66;
  }
 }
 L30: do {
  if ((label|0) == 20) {
   $70 = HEAP32[$this>>2]|0;
   $71 = HEAP32[$5>>2]|0;
   $72 = ($71|0)==($70|0);
   L33: do {
    if ($72) {
     HEAP32[$this>>2] = $46;
     HEAP32[$5>>2] = $66;
     HEAP32[$3>>2] = $48;
     $108 = $70;
    } else {
     $$01$i$i = $71;$77 = $46;
     while(1) {
      $73 = (($$01$i$i) + -16|0);
      $74 = (($$01$i$i) + -12|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($77) + -12|0);
      HEAP32[$76>>2] = $75;
      $78 = (($77) + -8|0);
      HEAP32[$78>>2] = 0;
      $79 = (($77) + -4|0);
      HEAP32[$79>>2] = 0;
      $80 = (($77) + -16|0);
      HEAP32[$80>>2] = 0;
      $81 = HEAP32[$73>>2]|0;
      $82 = (($$01$i$i) + -8|0);
      $83 = HEAP32[$82>>2]|0;
      $$idx$i$i$i$i$i = $83 << 2;
      $84 = $$idx$i$i$i$i$i >> 2;
      HEAP32[$78>>2] = $84;
      $85 = ($84|0)==(0);
      if ($85) {
       $89 = 0;$90 = 0;
      } else {
       HEAP32[$79>>2] = $84;
       HEAP32[$0>>2] = $75;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
       $86 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i$i|0),4,($$byval_copy12|0),0,(569816|0),370)|0);
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        label = 37;
        break;
       }
       HEAP32[$80>>2] = $86;
       $$pre$i$i$i$i = HEAP32[$78>>2]|0;
       $phitmp$i$i$i$i = $$pre$i$i$i$i << 2;
       $89 = $86;$90 = $phitmp$i$i$i$i;
      }
      _memcpy(($89|0),($81|0),($90|0))|0;
      $91 = (($77) + -16|0);
      $92 = ($73|0)==($70|0);
      if ($92) {
       break;
      } else {
       $$01$i$i = $73;$77 = $91;
      }
     }
     if ((label|0) == 37) {
      $113 = ___cxa_find_matching_catch()|0;
      $114 = tempRet0;
      $118 = $66;$119 = $77;$lpad$phi$index = $113;$lpad$phi$index2 = $114;
      break L30;
     }
     $$pre$i11 = HEAP32[$this>>2]|0;
     $$pre = HEAP32[$5>>2]|0;
     HEAP32[$this>>2] = $91;
     HEAP32[$5>>2] = $66;
     HEAP32[$3>>2] = $48;
     $93 = ($$pre|0)==($$pre$i11|0);
     if ($93) {
      $108 = $$pre$i11;
     } else {
      $95 = $$pre;
      while(1) {
       $94 = (($95) + -16|0);
       $96 = (($95) + -4|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = ($97|0)>(-1);
       if ($98) {
        $100 = HEAP32[$94>>2]|0;
        $101 = (($95) + -12|0);
        $102 = HEAP32[$101>>2]|0;
        HEAP32[$0>>2] = $102;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($100|0),($$byval_copy12|0));
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         break;
        }
        HEAP32[$94>>2] = 0;
       }
       $99 = ($94|0)==($$pre$i11|0);
       if ($99) {
        $108 = $$pre$i11;
        break L33;
       } else {
        $95 = $94;
       }
      }
      $105 = ___cxa_find_matching_catch()|0;
      $106 = tempRet0;
      ___cxa_call_unexpected(($105|0));
      // unreachable;
     }
    }
   } while(0);
   $107 = ($108|0)==(0|0);
   if ($107) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($108|0),($$byval_copy12|0));
   $109 = __THREW__; __THREW__ = 0;
   $110 = $109&1;
   if ($110) {
    $111 = ___cxa_find_matching_catch()|0;
    $112 = tempRet0;
    ___cxa_call_unexpected(($111|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
  else if ((label|0) == 38) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   $118 = $52;$119 = $46;$lpad$phi$index = $115;$lpad$phi$index2 = $116;
  }
 } while(0);
 $117 = ($118|0)==($119|0);
 L61: do {
  if (!($117)) {
   $121 = $118;
   while(1) {
    $120 = (($121) + -16|0);
    $122 = (($121) + -4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = ($123|0)>(-1);
    if ($124) {
     $126 = HEAP32[$120>>2]|0;
     $127 = (($121) + -12|0);
     $128 = HEAP32[$127>>2]|0;
     HEAP32[$2>>2] = $128;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($126|0),($$byval_copy12|0));
     $129 = __THREW__; __THREW__ = 0;
     $130 = $129&1;
     if ($130) {
      break;
     }
     HEAP32[$120>>2] = 0;
    }
    $125 = ($120|0)==($119|0);
    if ($125) {
     break L61;
    } else {
     $121 = $120;
    }
   }
   $131 = ___cxa_find_matching_catch()|0;
   $132 = tempRet0;
   ___cxa_call_unexpected(($131|0));
   // unreachable;
  }
 } while(0);
 $133 = ($47|0)==(0|0);
 if ($133) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy12|0));
 $134 = __THREW__; __THREW__ = 0;
 $135 = $134&1;
 if ($135) {
  $136 = ___cxa_find_matching_catch()|0;
  $137 = tempRet0;
  ___cxa_call_unexpected(($136|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI13dynamic_arrayIhLj1EE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEjRKS2_($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i127 = 0, $$0$i128 = 0, $$0$i3 = 0, $$01$i$i = 0, $$byval_copy12 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i4 = 0, $$pre$i9 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy12 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = ($10>>>0)<($__n>>>0);
 if (!($11)) {
  $12 = (($__x) + 4|0);
  $13 = (($__x) + 8|0);
  $$0$i = $__n;$15 = $6;
  while(1) {
   $14 = ($15|0)==(0|0);
   if ($14) {
    $27 = 0;
   } else {
    $16 = HEAP32[$12>>2]|0;
    $17 = (($15) + 4|0);
    HEAP32[$17>>2] = $16;
    $18 = (($15) + 8|0);
    HEAP32[$18>>2] = 0;
    $19 = (($15) + 12|0);
    HEAP32[$19>>2] = 0;
    HEAP32[$15>>2] = 0;
    $20 = HEAP32[$__x>>2]|0;
    $21 = HEAP32[$13>>2]|0;
    HEAP32[$18>>2] = $21;
    $22 = ($21|0)==(0);
    if ($22) {
     $24 = 0;$25 = 0;
    } else {
     HEAP32[$19>>2] = $21;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
     $23 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$21,1,$$byval_copy12,0,569816,370)|0);
     HEAP32[$15>>2] = $23;
     $$pre$i$i$i = HEAP32[$18>>2]|0;
     $24 = $23;$25 = $$pre$i$i$i;
    }
    _memcpy(($24|0),($20|0),($25|0))|0;
    $$pre1$i = HEAP32[$5>>2]|0;
    $27 = $$pre1$i;
   }
   $26 = (($27) + 16|0);
   HEAP32[$5>>2] = $26;
   $28 = (($$0$i) + -1)|0;
   $29 = ($28|0)==(0);
   if ($29) {
    break;
   } else {
    $$0$i = $28;$15 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 $30 = HEAP32[$this>>2]|0;
 $31 = $30;
 $32 = (($8) - ($31))|0;
 $33 = $32 >> 4;
 $34 = (($33) + ($__n))|0;
 $35 = ($34|0)<(0);
 if ($35) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $36 = (($7) - ($31))|0;
 $37 = $36 >> 4;
 $38 = ($37>>>0)<(1073741823);
 if ($38) {
  $39 = $36 >> 3;
  $40 = ($39>>>0)<($34>>>0);
  $41 = $40 ? $34 : $39;
  $42 = ($41|0)==(0);
  if ($42) {
   $$0$i128 = 0;$46 = 0;
  } else {
   $$0$i127 = $41;
   label = 12;
  }
 } else {
  $$0$i127 = 2147483647;
  label = 12;
 }
 if ((label|0) == 12) {
  $43 = $$0$i127 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
  $44 = (__Z15malloc_internaljj10MemLabelIdiPKci($43,16,$$byval_copy12,0,569816,79)|0);
  $$0$i128 = $$0$i127;$46 = $44;
 }
 $45 = (($46) + ($33<<4)|0);
 $47 = (($46) + ($$0$i128<<4)|0);
 $48 = (($__x) + 4|0);
 $49 = (($__x) + 8|0);
 $$0$i3 = $__n;$51 = $45;
 while(1) {
  $50 = ($51|0)==(0|0);
  if ($50) {
   $65 = 0;
  } else {
   $52 = HEAP32[$48>>2]|0;
   $53 = (($51) + 4|0);
   HEAP32[$53>>2] = $52;
   $54 = (($51) + 8|0);
   HEAP32[$54>>2] = 0;
   $55 = (($51) + 12|0);
   HEAP32[$55>>2] = 0;
   HEAP32[$51>>2] = 0;
   $56 = HEAP32[$__x>>2]|0;
   $57 = HEAP32[$49>>2]|0;
   HEAP32[$54>>2] = $57;
   $58 = ($57|0)==(0);
   if ($58) {
    $62 = 0;$63 = 0;
   } else {
    HEAP32[$55>>2] = $57;
    HEAP32[$1>>2] = $52;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
    $59 = (invoke_iiiiiiii(108,(0|0),($57|0),1,($$byval_copy12|0),0,(569816|0),370)|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     label = 38;
     break;
    }
    HEAP32[$51>>2] = $59;
    $$pre$i$i$i4 = HEAP32[$54>>2]|0;
    $62 = $59;$63 = $$pre$i$i$i4;
   }
   _memcpy(($62|0),($56|0),($63|0))|0;
   $65 = $51;
  }
  $64 = (($65) + 16|0);
  $66 = (($$0$i3) + -1)|0;
  $67 = ($66|0)==(0);
  if ($67) {
   label = 20;
   break;
  } else {
   $$0$i3 = $66;$51 = $64;
  }
 }
 L30: do {
  if ((label|0) == 20) {
   $68 = HEAP32[$this>>2]|0;
   $69 = HEAP32[$5>>2]|0;
   $70 = ($69|0)==($68|0);
   L33: do {
    if ($70) {
     HEAP32[$this>>2] = $45;
     HEAP32[$5>>2] = $64;
     HEAP32[$3>>2] = $47;
     $105 = $68;
    } else {
     $$01$i$i = $69;$75 = $45;
     while(1) {
      $71 = (($$01$i$i) + -16|0);
      $72 = (($$01$i$i) + -12|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($75) + -12|0);
      HEAP32[$74>>2] = $73;
      $76 = (($75) + -8|0);
      HEAP32[$76>>2] = 0;
      $77 = (($75) + -4|0);
      HEAP32[$77>>2] = 0;
      $78 = (($75) + -16|0);
      HEAP32[$78>>2] = 0;
      $79 = HEAP32[$71>>2]|0;
      $80 = (($$01$i$i) + -8|0);
      $81 = HEAP32[$80>>2]|0;
      HEAP32[$76>>2] = $81;
      $82 = ($81|0)==(0);
      if ($82) {
       $86 = 0;$87 = 0;
      } else {
       HEAP32[$77>>2] = $81;
       HEAP32[$0>>2] = $73;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
       $83 = (invoke_iiiiiiii(108,(0|0),($81|0),1,($$byval_copy12|0),0,(569816|0),370)|0);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        label = 37;
        break;
       }
       HEAP32[$78>>2] = $83;
       $$pre$i$i$i$i = HEAP32[$76>>2]|0;
       $86 = $83;$87 = $$pre$i$i$i$i;
      }
      _memcpy(($86|0),($79|0),($87|0))|0;
      $88 = (($75) + -16|0);
      $89 = ($71|0)==($68|0);
      if ($89) {
       break;
      } else {
       $$01$i$i = $71;$75 = $88;
      }
     }
     if ((label|0) == 37) {
      $110 = ___cxa_find_matching_catch()|0;
      $111 = tempRet0;
      $115 = $64;$116 = $75;$lpad$phi$index = $110;$lpad$phi$index2 = $111;
      break L30;
     }
     $$pre$i9 = HEAP32[$this>>2]|0;
     $$pre = HEAP32[$5>>2]|0;
     HEAP32[$this>>2] = $88;
     HEAP32[$5>>2] = $64;
     HEAP32[$3>>2] = $47;
     $90 = ($$pre|0)==($$pre$i9|0);
     if ($90) {
      $105 = $$pre$i9;
     } else {
      $92 = $$pre;
      while(1) {
       $91 = (($92) + -16|0);
       $93 = (($92) + -4|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = ($94|0)>(-1);
       if ($95) {
        $97 = HEAP32[$91>>2]|0;
        $98 = (($92) + -12|0);
        $99 = HEAP32[$98>>2]|0;
        HEAP32[$0>>2] = $99;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($97|0),($$byval_copy12|0));
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         break;
        }
        HEAP32[$91>>2] = 0;
       }
       $96 = ($91|0)==($$pre$i9|0);
       if ($96) {
        $105 = $$pre$i9;
        break L33;
       } else {
        $92 = $91;
       }
      }
      $102 = ___cxa_find_matching_catch()|0;
      $103 = tempRet0;
      ___cxa_call_unexpected(($102|0));
      // unreachable;
     }
    }
   } while(0);
   $104 = ($105|0)==(0|0);
   if ($104) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($105|0),($$byval_copy12|0));
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    $108 = ___cxa_find_matching_catch()|0;
    $109 = tempRet0;
    ___cxa_call_unexpected(($108|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
  else if ((label|0) == 38) {
   $112 = ___cxa_find_matching_catch()|0;
   $113 = tempRet0;
   $115 = $51;$116 = $45;$lpad$phi$index = $112;$lpad$phi$index2 = $113;
  }
 } while(0);
 $114 = ($115|0)==($116|0);
 L61: do {
  if (!($114)) {
   $118 = $115;
   while(1) {
    $117 = (($118) + -16|0);
    $119 = (($118) + -4|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = ($120|0)>(-1);
    if ($121) {
     $123 = HEAP32[$117>>2]|0;
     $124 = (($118) + -12|0);
     $125 = HEAP32[$124>>2]|0;
     HEAP32[$2>>2] = $125;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($123|0),($$byval_copy12|0));
     $126 = __THREW__; __THREW__ = 0;
     $127 = $126&1;
     if ($127) {
      break;
     }
     HEAP32[$117>>2] = 0;
    }
    $122 = ($117|0)==($116|0);
    if ($122) {
     break L61;
    } else {
     $118 = $117;
    }
   }
   $128 = ___cxa_find_matching_catch()|0;
   $129 = tempRet0;
   ___cxa_call_unexpected(($128|0));
   // unreachable;
  }
 } while(0);
 $130 = ($46|0)==(0|0);
 if ($130) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($46|0),($$byval_copy12|0));
 $131 = __THREW__; __THREW__ = 0;
 $132 = $131&1;
 if ($132) {
  $133 = ___cxa_find_matching_catch()|0;
  $134 = tempRet0;
  ___cxa_call_unexpected(($133|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN6CameraD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((569672 + 8|0));
 __THREW__ = 0;
 invoke_vi(3415,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if ($1) {
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   $13 = (($this) + 636|0);
   __THREW__ = 0;
   invoke_vi(3409,($13|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $26 = ___cxa_find_matching_catch(0|0)|0;
    $27 = tempRet0;
    ___clang_call_terminate($26);
    // unreachable;
   } else {
    $$0 = $12;$$01 = $11;
   }
  } else {
   $2 = (($this) + 636|0);
   __THREW__ = 0;
   invoke_vi(3409,($2|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $16 = ___cxa_find_matching_catch()|0;
    $17 = tempRet0;
    $$0 = $17;$$01 = $16;
    break;
   }
   $5 = (($this) + 360|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = $6 & 1;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    __ZN9BehaviourD2Ev($this);
    STACKTOP = sp;return;
   }
   $9 = (($this) + 368|0);
   $10 = HEAP32[$9>>2]|0;
   __ZdlPv($10);
   __ZN9BehaviourD2Ev($this);
   STACKTOP = sp;return;
  }
 } while(0);
 $18 = (($this) + 360|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  $22 = (($this) + 368|0);
  $23 = HEAP32[$22>>2]|0;
  __ZdlPv($23);
 }
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch(0|0)|0;
  $27 = tempRet0;
  ___clang_call_terminate($26);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __GLOBAL__I_a1817() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,569488);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[569480>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,569520);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[569512>>2] = $2;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,569560);
 $3 = HEAP32[$0>>2]|0;
 HEAP32[569552>>2] = $3;
 STACKTOP = sp;return;
}
function __Z22FlipScreenRectIfNeededRK9GfxDeviceR5RectTIiE($device,$screenRect) {
 $device = $device|0;
 $screenRect = $screenRect|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($device) + 5932|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($device) + 5924|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   STACKTOP = sp;return;
  }
 }
 $6 = (($device) + 5788|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (__Z16GetScreenManagerv()|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $14 = (($screenRect) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) - ($15))|0;
 $17 = (($screenRect) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) - ($18))|0;
 $20 = ($19|0)<($16|0);
 $$ = $20 ? $19 : $16;
 $$1 = $20 ? $16 : $19;
 $21 = ($$|0)<(0);
 $22 = $21 ? 0 : $$;
 HEAP32[$14>>2] = $22;
 $23 = (($$1) - ($22))|0;
 $24 = ($23|0)<(0);
 $25 = $24 ? 0 : $23;
 HEAP32[$17>>2] = $25;
 STACKTOP = sp;return;
}
function __Z15CalcPixelMatrixRK5RectTIfER10Matrix4x4f($screenRect,$out) {
 $screenRect = $screenRect|0;
 $out = $out|0;
 var $0 = Math_fround(0), $1 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$screenRect>>2]);
 $1 = (($screenRect) + 8|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 $4 = (($screenRect) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($screenRect) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 (__ZN10Matrix4x4f8SetOrthoEffffff($out,$0,$3,$5,$8,Math_fround(-1.0),Math_fround(100.0))|0);
 STACKTOP = sp;return;
}
function __Z30ApplyTexelOffsetsToPixelMatrixbR10Matrix4x4f($invertYTexelOffset,$matrix) {
 $invertYTexelOffset = $invertYTexelOffset|0;
 $matrix = $matrix|0;
 var $$$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($0) + 5933|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $11 = Math_fround(0.0);$8 = Math_fround(0.0);
 } else {
  $4 = (($0) + 5788|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  $$$i = $6 ? Math_fround(-0.5) : Math_fround(0.5);
  $11 = Math_fround(0.5);$8 = $$$i;
 }
 if ($invertYTexelOffset) {
  $7 = Math_fround(-$8);
  $18 = $7;
 } else {
  $18 = $8;
 }
 $9 = Math_fround(HEAPF32[$matrix>>2]);
 $10 = Math_fround($11 * $9);
 $12 = (($matrix) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 - $10);
 HEAPF32[$12>>2] = $14;
 $15 = (($matrix) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($18 * $16);
 $19 = (($matrix) + 52|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 - $17);
 HEAPF32[$19>>2] = $21;
 STACKTOP = sp;return;
}
function __Z25LoadFullScreenOrthoMatrixffb($nearPlane,$farPlane,$forceNoHalfTexelOffset) {
 $nearPlane = Math_fround($nearPlane);
 $farPlane = Math_fround($farPlane);
 $forceNoHalfTexelOffset = $forceNoHalfTexelOffset|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $brmerge = 0, $matrix = 0, $offsetX$0 = Math_fround(0), $offsetY$0 = Math_fround(0), $viewport = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $viewport = sp + 64|0;
 $matrix = sp;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($0) + 5933|0);
 $2 = HEAP8[$1>>0]|0;
 $$not = ($2<<24>>24)==(0);
 $brmerge = $$not | $forceNoHalfTexelOffset;
 if ($brmerge) {
  $offsetX$0 = Math_fround(0.0);$offsetY$0 = Math_fround(0.0);
 } else {
  $3 = HEAP32[$0>>2]|0;
  $4 = (($3) + 176|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($viewport,$0);
  $6 = (($viewport) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $29 = Math_fround(0.0);
  } else {
   $9 = (Math_fround(($7|0)));
   $10 = Math_fround(Math_fround(0.5) / $9);
   $29 = $10;
  }
  $11 = (($viewport) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if ($13) {
   $20 = Math_fround(0.0);
  } else {
   $14 = (Math_fround(($12|0)));
   $15 = Math_fround(Math_fround(0.5) / $14);
   $20 = $15;
  }
  $16 = (($0) + 5788|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = Math_fround(-$20);
   $offsetX$0 = $29;$offsetY$0 = $19;
  } else {
   $offsetX$0 = $29;$offsetY$0 = $20;
  }
 }
 $21 = Math_fround($offsetX$0 + Math_fround(1.0));
 $22 = Math_fround($offsetY$0 + Math_fround(1.0));
 (__ZN10Matrix4x4f8SetOrthoEffffff($matrix,$offsetX$0,$21,$offsetY$0,$22,$nearPlane,$farPlane)|0);
 $23 = HEAP32[$0>>2]|0;
 $24 = (($23) + 104|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095]($0,$matrix);
 $26 = HEAP32[$0>>2]|0;
 $27 = (($26) + 100|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vii[$28 & 4095]($0,616552);
 STACKTOP = sp;return;
}
function __Z28SetupPixelCorrectCoordinatesv() {
 var $$$i = 0, $$$i$i$i = Math_fround(0), $$1$i = 0, $$sink$i$i$i = Math_fround(0), $$sink$i$i1$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0;
 var $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = Math_fround(0), $ortho$i = 0, $screenRect = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $ortho$i = sp + 16|0;
 $screenRect = sp;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (__Z16GetRenderManagerv()|0);
 $2 = (($1) + 56|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($1) + 60|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($1) + 64|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($1) + 68|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 ;HEAP32[$screenRect+0>>2]=0|0;HEAP32[$screenRect+4>>2]=0|0;HEAP32[$screenRect+8>>2]=0|0;HEAP32[$screenRect+12>>2]=0|0;
 $10 = Math_fround($3 + Math_fround(0.5));
 $11 = !($10 >= Math_fround(0.0));
 if ($11) {
  $12 = Math_fround($10 + Math_fround(-0.999999940395355224609));
  $$sink$i$i1$i = $12;
 } else {
  $$sink$i$i1$i = $10;
 }
 $13 = (~~(($$sink$i$i1$i)));
 HEAP32[$screenRect>>2] = $13;
 $14 = Math_fround($5 + Math_fround(0.5));
 $15 = !($14 >= Math_fround(0.0));
 if ($15) {
  $16 = Math_fround($14 + Math_fround(-0.999999940395355224609));
  $$sink$i$i$i = $16;
 } else {
  $$sink$i$i$i = $14;
 }
 $17 = (~~(($$sink$i$i$i)));
 $18 = (($screenRect) + 4|0);
 HEAP32[$18>>2] = $17;
 $19 = Math_fround($3 + $7);
 $20 = Math_fround($19 + Math_fround(0.5));
 $21 = (~~(($20))>>>0);
 $22 = (($21) - ($13))|0;
 $23 = (($screenRect) + 8|0);
 HEAP32[$23>>2] = $22;
 $24 = Math_fround($5 + $9);
 $25 = Math_fround($24 + Math_fround(0.5));
 $26 = (~~(($25))>>>0);
 $27 = (($26) - ($17))|0;
 $28 = (($screenRect) + 12|0);
 HEAP32[$28>>2] = $27;
 $29 = (($0) + 5932|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  label = 7;
 } else {
  $32 = (($0) + 5924|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)==(0);
  if (!($34)) {
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $35 = (($0) + 5788|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   $38 = (__Z16GetScreenManagerv()|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 84|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (FUNCTION_TABLE_ii[$41 & 4095]($38)|0);
   $43 = HEAP32[$18>>2]|0;
   $44 = (($42) - ($43))|0;
   $45 = HEAP32[$28>>2]|0;
   $46 = (($44) - ($45))|0;
   $47 = ($46|0)<($44|0);
   $$$i = $47 ? $46 : $44;
   $$1$i = $47 ? $44 : $46;
   $48 = ($$$i|0)<(0);
   $49 = $48 ? 0 : $$$i;
   HEAP32[$18>>2] = $49;
   $50 = (($$1$i) - ($49))|0;
   $51 = ($50|0)<(0);
   $52 = $51 ? 0 : $50;
   HEAP32[$28>>2] = $52;
  }
 }
 $53 = HEAP32[$0>>2]|0;
 $54 = (($53) + 172|0);
 $55 = HEAP32[$54>>2]|0;
 FUNCTION_TABLE_vii[$55 & 4095]($0,$screenRect);
 (__ZN10Matrix4x4f8SetOrthoEffffff($ortho$i,$3,$19,$5,$24,Math_fround(-1.0),Math_fround(100.0))|0);
 $56 = (__Z12GetGfxDevicev()|0);
 $57 = (($56) + 5933|0);
 $58 = HEAP8[$57>>0]|0;
 $59 = ($58<<24>>24)==(0);
 if ($59) {
  $65 = Math_fround(0.0);$72 = Math_fround(0.0);
 } else {
  $60 = (($56) + 5788|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($61|0)==(0|0);
  $$$i$i$i = $62 ? Math_fround(-0.5) : Math_fround(0.5);
  $65 = Math_fround(0.5);$72 = $$$i$i$i;
 }
 $63 = Math_fround(HEAPF32[$ortho$i>>2]);
 $64 = Math_fround($65 * $63);
 $66 = (($ortho$i) + 48|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 - $64);
 HEAPF32[$66>>2] = $68;
 $69 = (($ortho$i) + 20|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($72 * $70);
 $73 = (($ortho$i) + 52|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($74 - $71);
 HEAPF32[$73>>2] = $75;
 $76 = HEAP32[$0>>2]|0;
 $77 = (($76) + 104|0);
 $78 = HEAP32[$77>>2]|0;
 FUNCTION_TABLE_vii[$78 & 4095]($0,$ortho$i);
 $79 = HEAP32[$0>>2]|0;
 $80 = (($79) + 100|0);
 $81 = HEAP32[$80>>2]|0;
 FUNCTION_TABLE_vii[$81 & 4095]($0,616552);
 STACKTOP = sp;return;
}
function __Z14RectfToRectIntRK5RectTIfE($agg$result,$r) {
 $agg$result = $agg$result|0;
 $r = $r|0;
 var $$sink$i$i = Math_fround(0), $$sink$i$i1 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 $0 = Math_fround(HEAPF32[$r>>2]);
 $1 = Math_fround($0 + Math_fround(0.5));
 $2 = !($1 >= Math_fround(0.0));
 if ($2) {
  $3 = Math_fround($1 + Math_fround(-0.999999940395355224609));
  $$sink$i$i1 = $3;
 } else {
  $$sink$i$i1 = $1;
 }
 $4 = (~~(($$sink$i$i1)));
 HEAP32[$agg$result>>2] = $4;
 $5 = (($r) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 + Math_fround(0.5));
 $8 = !($7 >= Math_fround(0.0));
 if ($8) {
  $9 = Math_fround($7 + Math_fround(-0.999999940395355224609));
  $$sink$i$i = $9;
 } else {
  $$sink$i$i = $7;
 }
 $10 = (~~(($$sink$i$i)));
 $11 = (($agg$result) + 4|0);
 HEAP32[$11>>2] = $10;
 $12 = (($r) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($0 + $13);
 $15 = Math_fround($14 + Math_fround(0.5));
 $16 = (~~(($15))>>>0);
 $17 = (($16) - ($4))|0;
 $18 = (($agg$result) + 8|0);
 HEAP32[$18>>2] = $17;
 $19 = (($r) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($6 + $20);
 $22 = Math_fround($21 + Math_fround(0.5));
 $23 = (~~(($22))>>>0);
 $24 = (($23) - ($10))|0;
 $25 = (($agg$result) + 12|0);
 HEAP32[$25>>2] = $24;
 STACKTOP = sp;return;
}
function __Z13CameraProjectRK8Vector3fRK10Matrix4x4fS4_RK5RectTIiERS_($p,$cameraToWorld,$worldToClip,$viewport,$outP) {
 $p = $p|0;
 $cameraToWorld = $cameraToWorld|0;
 $worldToClip = $worldToClip|0;
 $viewport = $viewport|0;
 $outP = $outP|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$worldToClip>>2]);
 $1 = Math_fround(HEAPF32[$p>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($worldToClip) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($p) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($worldToClip) + 32|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($p) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($worldToClip) + 48|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + $14);
 $18 = (($worldToClip) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($1 * $19);
 $21 = (($worldToClip) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($6 * $22);
 $24 = Math_fround($20 + $23);
 $25 = (($worldToClip) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($12 * $26);
 $28 = Math_fround($24 + $27);
 $29 = (($worldToClip) + 52|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $28);
 $32 = (($worldToClip) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($1 * $33);
 $35 = (($worldToClip) + 28|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($6 * $36);
 $38 = Math_fround($34 + $37);
 $39 = (($worldToClip) + 44|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($12 * $40);
 $42 = Math_fround($38 + $41);
 $43 = (($worldToClip) + 60|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 + $42);
 $46 = $45 < Math_fround(0.0);
 if ($46) {
  $47 = Math_fround(-$45);
  $49 = $47;
 } else {
  $49 = $45;
 }
 $48 = $49 > Math_fround(1.00000001168609742308E-7);
 if ($48) {
  $50 = Math_fround(Math_fround(1.0) / $45);
  $51 = Math_fround($17 * $50);
  $52 = Math_fround($31 * $50);
  $53 = (($cameraToWorld) + 48|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($cameraToWorld) + 52|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($cameraToWorld) + 56|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($1 - $54);
  $60 = Math_fround($6 - $56);
  $61 = Math_fround($12 - $58);
  $62 = (($cameraToWorld) + 32|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($cameraToWorld) + 36|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = (($cameraToWorld) + 40|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($59 * $63);
  $69 = Math_fround($60 * $65);
  $70 = Math_fround(-$69);
  $71 = Math_fround($70 - $68);
  $72 = Math_fround($61 * $67);
  $73 = Math_fround($71 - $72);
  $74 = HEAP32[$viewport>>2]|0;
  $75 = (Math_fround(($74|0)));
  $76 = Math_fround($51 + Math_fround(1.0));
  $77 = (($viewport) + 8|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (Math_fround(($78|0)));
  $80 = Math_fround($76 * $79);
  $81 = Math_fround($80 * Math_fround(0.5));
  $82 = Math_fround($75 + $81);
  HEAPF32[$outP>>2] = $82;
  $83 = (($viewport) + 4|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (Math_fround(($84|0)));
  $86 = Math_fround($52 + Math_fround(1.0));
  $87 = (($viewport) + 12|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (Math_fround(($88|0)));
  $90 = Math_fround($86 * $89);
  $91 = Math_fround($90 * Math_fround(0.5));
  $92 = Math_fround($85 + $91);
  $93 = (($outP) + 4|0);
  HEAPF32[$93>>2] = $92;
  $94 = (($outP) + 8|0);
  HEAPF32[$94>>2] = $73;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAPF32[$outP>>2] = Math_fround(0.0);
  $95 = (($outP) + 4|0);
  HEAPF32[$95>>2] = Math_fround(0.0);
  $96 = (($outP) + 8|0);
  HEAPF32[$96>>2] = Math_fround(0.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z15CameraUnProjectRK8Vector3fRK10Matrix4x4fS4_RK5RectTIiERS_($p,$cameraToWorld,$clipToWorld,$viewport,$outP) {
 $p = $p|0;
 $cameraToWorld = $cameraToWorld|0;
 $clipToWorld = $clipToWorld|0;
 $viewport = $viewport|0;
 $outP = $outP|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0;
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0;
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0;
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0);
 var $98 = 0, $99 = Math_fround(0), $or$cond = 0, $or$cond10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$p>>2]);
 $1 = HEAP32[$viewport>>2]|0;
 $2 = (Math_fround(($1|0)));
 $3 = Math_fround($0 - $2);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = (($viewport) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (Math_fround(($6|0)));
 $8 = Math_fround($4 / $7);
 $9 = Math_fround($8 + Math_fround(-1.0));
 $10 = (($p) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($viewport) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (Math_fround(($13|0)));
 $15 = Math_fround($11 - $14);
 $16 = Math_fround($15 * Math_fround(2.0));
 $17 = (($viewport) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (Math_fround(($18|0)));
 $20 = Math_fround($16 / $19);
 $21 = Math_fround($20 + Math_fround(-1.0));
 $22 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $23 = Math_fround($9 * $22);
 $24 = (($clipToWorld) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($21 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($clipToWorld) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * Math_fround(0.949999988079071044921));
 $31 = Math_fround($27 + $30);
 $32 = (($clipToWorld) + 48|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 + $31);
 $35 = (($clipToWorld) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($9 * $36);
 $38 = (($clipToWorld) + 20|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($21 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($clipToWorld) + 36|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * Math_fround(0.949999988079071044921));
 $45 = Math_fround($41 + $44);
 $46 = (($clipToWorld) + 52|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 + $45);
 $49 = (($clipToWorld) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($9 * $50);
 $52 = (($clipToWorld) + 24|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($21 * $53);
 $55 = Math_fround($51 + $54);
 $56 = (($clipToWorld) + 40|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 * Math_fround(0.949999988079071044921));
 $59 = Math_fround($55 + $58);
 $60 = (($clipToWorld) + 56|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 + $59);
 $63 = (($clipToWorld) + 12|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($9 * $64);
 $66 = (($clipToWorld) + 28|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($21 * $67);
 $69 = Math_fround($65 + $68);
 $70 = (($clipToWorld) + 44|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * Math_fround(0.949999988079071044921));
 $73 = Math_fround($69 + $72);
 $74 = (($clipToWorld) + 60|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 + $73);
 $77 = $76 < Math_fround(0.0);
 if ($77) {
  $78 = Math_fround(-$76);
  $80 = $78;
 } else {
  $80 = $76;
 }
 $79 = $80 > Math_fround(1.00000001168609742308E-7);
 if ($79) {
  $81 = Math_fround(Math_fround(1.0) / $76);
  $82 = Math_fround($34 * $81);
  $83 = Math_fround($48 * $81);
  $84 = Math_fround($62 * $81);
  $85 = (($cameraToWorld) + 48|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = (($cameraToWorld) + 52|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (($cameraToWorld) + 56|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = Math_fround($82 - $86);
  $92 = Math_fround($83 - $88);
  $93 = Math_fround($84 - $90);
  $94 = (($cameraToWorld) + 32|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = (($cameraToWorld) + 36|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = (($cameraToWorld) + 40|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = Math_fround(-$95);
  $101 = Math_fround(-$97);
  $102 = Math_fround(-$99);
  $103 = Math_fround($91 * $100);
  $104 = Math_fround($92 * $101);
  $105 = Math_fround($103 + $104);
  $106 = Math_fround($93 * $102);
  $107 = Math_fround($105 + $106);
  $108 = $107 < Math_fround(0.0);
  if ($108) {
   $109 = Math_fround(-$107);
   $111 = $109;
  } else {
   $111 = $107;
  }
  $110 = !($111 >= Math_fround(9.99999997475242707878E-7));
  if (!($110)) {
   $112 = $64 != Math_fround(0.0);
   $113 = $67 != Math_fround(0.0);
   $or$cond = $112 | $113;
   $114 = $71 != Math_fround(0.0);
   $or$cond10 = $or$cond | $114;
   if ($or$cond10) {
    $115 = (($p) + 8|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $121 = $116;
   } else {
    $117 = $75 != Math_fround(1.0);
    $118 = (($p) + 8|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    if ($117) {
     $121 = $119;
    } else {
     $130 = Math_fround($107 - $119);
     $131 = Math_fround($130 * $100);
     $132 = Math_fround($130 * $101);
     $133 = Math_fround($130 * $102);
     $134 = Math_fround($82 - $131);
     $135 = Math_fround($83 - $132);
     $136 = Math_fround($84 - $133);
     HEAPF32[$outP>>2] = $134;
     $137 = (($outP) + 4|0);
     HEAPF32[$137>>2] = $135;
     $138 = (($outP) + 8|0);
     HEAPF32[$138>>2] = $136;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $120 = Math_fround($121 / $107);
   $122 = Math_fround($91 * $120);
   $123 = Math_fround($92 * $120);
   $124 = Math_fround($93 * $120);
   $125 = Math_fround($86 + $122);
   $126 = Math_fround($88 + $123);
   $127 = Math_fround($90 + $124);
   HEAPF32[$outP>>2] = $125;
   $128 = (($outP) + 4|0);
   HEAPF32[$128>>2] = $126;
   $129 = (($outP) + 8|0);
   HEAPF32[$129>>2] = $127;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAPF32[$outP>>2] = Math_fround(0.0);
 $139 = (($outP) + 4|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($outP) + 8|0);
 HEAPF32[$140>>2] = Math_fround(0.0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __Z13SetGLViewportRK5RectTIfE($pixelRect) {
 $pixelRect = $pixelRect|0;
 var $$$i = 0, $$1$i = 0, $$sink$i$i$i = Math_fround(0), $$sink$i$i1$i = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $viewport = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $viewport = sp;
 $0 = Math_fround(HEAPF32[$pixelRect>>2]);
 $1 = (($pixelRect) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($pixelRect) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($pixelRect) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (__Z12GetGfxDevicev()|0);
 ;HEAP32[$viewport+0>>2]=0|0;HEAP32[$viewport+4>>2]=0|0;HEAP32[$viewport+8>>2]=0|0;HEAP32[$viewport+12>>2]=0|0;
 $8 = Math_fround($0 + Math_fround(0.5));
 $9 = !($8 >= Math_fround(0.0));
 if ($9) {
  $10 = Math_fround($8 + Math_fround(-0.999999940395355224609));
  $$sink$i$i1$i = $10;
 } else {
  $$sink$i$i1$i = $8;
 }
 $11 = (~~(($$sink$i$i1$i)));
 HEAP32[$viewport>>2] = $11;
 $12 = Math_fround($2 + Math_fround(0.5));
 $13 = !($12 >= Math_fround(0.0));
 if ($13) {
  $14 = Math_fround($12 + Math_fround(-0.999999940395355224609));
  $$sink$i$i$i = $14;
 } else {
  $$sink$i$i$i = $12;
 }
 $15 = (~~(($$sink$i$i$i)));
 $16 = (($viewport) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = Math_fround($0 + $4);
 $18 = Math_fround($17 + Math_fround(0.5));
 $19 = (~~(($18))>>>0);
 $20 = (($19) - ($11))|0;
 $21 = (($viewport) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = Math_fround($2 + $6);
 $23 = Math_fround($22 + Math_fround(0.5));
 $24 = (~~(($23))>>>0);
 $25 = (($24) - ($15))|0;
 $26 = (($viewport) + 12|0);
 HEAP32[$26>>2] = $25;
 $27 = (($7) + 5932|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  $30 = (($7) + 5924|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   $51 = HEAP32[$7>>2]|0;
   $52 = (($51) + 172|0);
   $53 = HEAP32[$52>>2]|0;
   FUNCTION_TABLE_vii[$53 & 4095]($7,$viewport);
   STACKTOP = sp;return;
  }
 }
 $33 = (($7) + 5788|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $51 = HEAP32[$7>>2]|0;
  $52 = (($51) + 172|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vii[$53 & 4095]($7,$viewport);
  STACKTOP = sp;return;
 }
 $36 = (__Z16GetScreenManagerv()|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 84|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (FUNCTION_TABLE_ii[$39 & 4095]($36)|0);
 $41 = HEAP32[$16>>2]|0;
 $42 = (($40) - ($41))|0;
 $43 = HEAP32[$26>>2]|0;
 $44 = (($42) - ($43))|0;
 $45 = ($44|0)<($42|0);
 $$$i = $45 ? $44 : $42;
 $$1$i = $45 ? $42 : $44;
 $46 = ($$$i|0)<(0);
 $47 = $46 ? 0 : $$$i;
 HEAP32[$16>>2] = $47;
 $48 = (($$1$i) - ($47))|0;
 $49 = ($48|0)<(0);
 $50 = $49 ? 0 : $48;
 HEAP32[$26>>2] = $50;
 $51 = HEAP32[$7>>2]|0;
 $52 = (($51) + 172|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vii[$53 & 4095]($7,$viewport);
 STACKTOP = sp;return;
}
function __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($finalMatrix,$outPlanes) {
 $finalMatrix = $finalMatrix|0;
 $outPlanes = $outPlanes|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($finalMatrix) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($finalMatrix) + 28|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($finalMatrix) + 44|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($finalMatrix) + 60|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(HEAPF32[$finalMatrix>>2]);
 $9 = (($finalMatrix) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($finalMatrix) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($finalMatrix) + 48|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($1 + $8);
 $16 = Math_fround($3 + $10);
 $17 = Math_fround($5 + $12);
 $18 = Math_fround($7 + $14);
 $19 = (($outPlanes) + 4|0);
 $20 = (($outPlanes) + 8|0);
 $21 = (($outPlanes) + 12|0);
 $22 = Math_fround($15 * $15);
 $23 = Math_fround($16 * $16);
 $24 = Math_fround($22 + $23);
 $25 = Math_fround($17 * $17);
 $26 = Math_fround($24 + $25);
 $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
 $28 = Math_fround(Math_fround(1.0) / $27);
 $29 = Math_fround($15 * $28);
 HEAPF32[$outPlanes>>2] = $29;
 $30 = Math_fround($16 * $28);
 HEAPF32[$19>>2] = $30;
 $31 = Math_fround($17 * $28);
 HEAPF32[$20>>2] = $31;
 $32 = Math_fround($28 * $18);
 HEAPF32[$21>>2] = $32;
 $33 = Math_fround($1 - $8);
 $34 = Math_fround($3 - $10);
 $35 = Math_fround($5 - $12);
 $36 = Math_fround($7 - $14);
 $37 = (($outPlanes) + 16|0);
 $38 = (($outPlanes) + 20|0);
 $39 = (($outPlanes) + 24|0);
 $40 = (($outPlanes) + 28|0);
 $41 = Math_fround($33 * $33);
 $42 = Math_fround($34 * $34);
 $43 = Math_fround($41 + $42);
 $44 = Math_fround($35 * $35);
 $45 = Math_fround($43 + $44);
 $46 = (Math_fround(Math_sqrt((Math_fround($45)))));
 $47 = Math_fround(Math_fround(1.0) / $46);
 $48 = Math_fround($33 * $47);
 HEAPF32[$37>>2] = $48;
 $49 = Math_fround($34 * $47);
 HEAPF32[$38>>2] = $49;
 $50 = Math_fround($35 * $47);
 HEAPF32[$39>>2] = $50;
 $51 = Math_fround($47 * $36);
 HEAPF32[$40>>2] = $51;
 $52 = (($finalMatrix) + 4|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($finalMatrix) + 20|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($finalMatrix) + 36|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($finalMatrix) + 52|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($1 + $53);
 $61 = Math_fround($3 + $55);
 $62 = Math_fround($5 + $57);
 $63 = Math_fround($7 + $59);
 $64 = (($outPlanes) + 32|0);
 $65 = (($outPlanes) + 36|0);
 $66 = (($outPlanes) + 40|0);
 $67 = (($outPlanes) + 44|0);
 $68 = Math_fround($60 * $60);
 $69 = Math_fround($61 * $61);
 $70 = Math_fround($68 + $69);
 $71 = Math_fround($62 * $62);
 $72 = Math_fround($70 + $71);
 $73 = (Math_fround(Math_sqrt((Math_fround($72)))));
 $74 = Math_fround(Math_fround(1.0) / $73);
 $75 = Math_fround($60 * $74);
 HEAPF32[$64>>2] = $75;
 $76 = Math_fround($61 * $74);
 HEAPF32[$65>>2] = $76;
 $77 = Math_fround($62 * $74);
 HEAPF32[$66>>2] = $77;
 $78 = Math_fround($74 * $63);
 HEAPF32[$67>>2] = $78;
 $79 = Math_fround($1 - $53);
 $80 = Math_fround($3 - $55);
 $81 = Math_fround($5 - $57);
 $82 = Math_fround($7 - $59);
 $83 = (($outPlanes) + 48|0);
 $84 = (($outPlanes) + 52|0);
 $85 = (($outPlanes) + 56|0);
 $86 = (($outPlanes) + 60|0);
 $87 = Math_fround($79 * $79);
 $88 = Math_fround($80 * $80);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($81 * $81);
 $91 = Math_fround($89 + $90);
 $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
 $93 = Math_fround(Math_fround(1.0) / $92);
 $94 = Math_fround($79 * $93);
 HEAPF32[$83>>2] = $94;
 $95 = Math_fround($80 * $93);
 HEAPF32[$84>>2] = $95;
 $96 = Math_fround($81 * $93);
 HEAPF32[$85>>2] = $96;
 $97 = Math_fround($93 * $82);
 HEAPF32[$86>>2] = $97;
 $98 = (($finalMatrix) + 8|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($finalMatrix) + 24|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($finalMatrix) + 40|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($finalMatrix) + 56|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($1 + $99);
 $107 = Math_fround($3 + $101);
 $108 = Math_fround($5 + $103);
 $109 = Math_fround($7 + $105);
 $110 = (($outPlanes) + 64|0);
 $111 = (($outPlanes) + 68|0);
 $112 = (($outPlanes) + 72|0);
 $113 = (($outPlanes) + 76|0);
 $114 = Math_fround($106 * $106);
 $115 = Math_fround($107 * $107);
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($108 * $108);
 $118 = Math_fround($116 + $117);
 $119 = (Math_fround(Math_sqrt((Math_fround($118)))));
 $120 = Math_fround(Math_fround(1.0) / $119);
 $121 = Math_fround($106 * $120);
 HEAPF32[$110>>2] = $121;
 $122 = Math_fround($107 * $120);
 HEAPF32[$111>>2] = $122;
 $123 = Math_fround($108 * $120);
 HEAPF32[$112>>2] = $123;
 $124 = Math_fround($120 * $109);
 HEAPF32[$113>>2] = $124;
 $125 = Math_fround($1 - $99);
 $126 = Math_fround($3 - $101);
 $127 = Math_fround($5 - $103);
 $128 = Math_fround($7 - $105);
 $129 = (($outPlanes) + 80|0);
 $130 = (($outPlanes) + 84|0);
 $131 = (($outPlanes) + 88|0);
 $132 = (($outPlanes) + 92|0);
 $133 = Math_fround($125 * $125);
 $134 = Math_fround($126 * $126);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround($127 * $127);
 $137 = Math_fround($135 + $136);
 $138 = (Math_fround(Math_sqrt((Math_fround($137)))));
 $139 = Math_fround(Math_fround(1.0) / $138);
 $140 = Math_fround($125 * $139);
 HEAPF32[$129>>2] = $140;
 $141 = Math_fround($126 * $139);
 HEAPF32[$130>>2] = $141;
 $142 = Math_fround($127 * $139);
 HEAPF32[$131>>2] = $142;
 $143 = Math_fround($139 * $128);
 HEAPF32[$132>>2] = $143;
 STACKTOP = sp;return;
}
function __Z27SetClippingPlaneShaderPropsv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $planes = 0, $viewProj = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $viewProj = sp + 96|0;
 $planes = sp;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 124|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($0)|0);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($8,$4,$viewProj);
 HEAPF32[$planes>>2] = Math_fround(0.0);
 $9 = (($planes) + 4|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($planes) + 8|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($planes) + 16|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($planes) + 20|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($planes) + 24|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($planes) + 32|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($planes) + 36|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($planes) + 40|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($planes) + 48|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($planes) + 52|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($planes) + 56|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($planes) + 64|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($planes) + 68|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($planes) + 72|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($planes) + 80|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($planes) + 84|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($planes) + 88|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($viewProj,$planes);
 $26 = (($0) + 1380|0);
 ;HEAP32[$26+0>>2]=HEAP32[$planes+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$planes+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$planes+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$planes+12>>2]|0;
 $27 = (($planes) + 16|0);
 $28 = (($0) + 1396|0);
 ;HEAP32[$28+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$27+12>>2]|0;
 $29 = (($planes) + 32|0);
 $30 = (($0) + 1412|0);
 ;HEAP32[$30+0>>2]=HEAP32[$29+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$29+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$29+12>>2]|0;
 $31 = (($planes) + 48|0);
 $32 = (($0) + 1428|0);
 ;HEAP32[$32+0>>2]=HEAP32[$31+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$31+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$31+12>>2]|0;
 $33 = (($planes) + 64|0);
 $34 = (($0) + 1444|0);
 ;HEAP32[$34+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$33+12>>2]|0;
 $35 = (($planes) + 80|0);
 $36 = (($0) + 1460|0);
 ;HEAP32[$36+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$35+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN22DeviceMVPMatricesStateC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = (($this) + 128|0);
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 116|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 dest=$0+0|0; src=$6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $7 = HEAP32[$2>>2]|0;
 $8 = (($7) + 112|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($2)|0);
 dest=$this+0|0; src=$10+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $11 = HEAP32[$2>>2]|0;
 $12 = (($11) + 120|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 4095]($2)|0);
 dest=$1+0|0; src=$14+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN22DeviceMVPMatricesStateD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $planes$i = 0, $viewProj$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $viewProj$i = sp + 96|0;
 $planes$i = sp;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 128|0);
 FUNCTION_TABLE_vii[$3 & 4095]($0,$4);
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 100|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 64|0);
 FUNCTION_TABLE_vii[$7 & 4095]($0,$8);
 $9 = HEAP32[$0>>2]|0;
 $10 = (($9) + 96|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095]($0,$this);
 $12 = (__Z12GetGfxDevicev()|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 116|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
 $17 = HEAP32[$12>>2]|0;
 $18 = (($17) + 124|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_ii[$19 & 4095]($12)|0);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($20,$16,$viewProj$i);
 HEAPF32[$planes$i>>2] = Math_fround(0.0);
 $21 = (($planes$i) + 4|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($planes$i) + 8|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($planes$i) + 16|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($planes$i) + 20|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($planes$i) + 24|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($planes$i) + 32|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($planes$i) + 36|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($planes$i) + 40|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($planes$i) + 48|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($planes$i) + 52|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($planes$i) + 56|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($planes$i) + 64|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($planes$i) + 68|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($planes$i) + 72|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($planes$i) + 80|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($planes$i) + 84|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($planes$i) + 88|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($viewProj$i,$planes$i);
 $38 = (($12) + 1380|0);
 ;HEAP32[$38+0>>2]=HEAP32[$planes$i+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$planes$i+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$planes$i+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$planes$i+12>>2]|0;
 $39 = (($planes$i) + 16|0);
 $40 = (($12) + 1396|0);
 ;HEAP32[$40+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$39+12>>2]|0;
 $41 = (($planes$i) + 32|0);
 $42 = (($12) + 1412|0);
 ;HEAP32[$42+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$41+12>>2]|0;
 $43 = (($planes$i) + 48|0);
 $44 = (($12) + 1428|0);
 ;HEAP32[$44+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$43+12>>2]|0;
 $45 = (($planes$i) + 64|0);
 $46 = (($12) + 1444|0);
 ;HEAP32[$46+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$46+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[$45+8>>2]|0;HEAP32[$46+12>>2]=HEAP32[$45+12>>2]|0;
 $47 = (($planes$i) + 80|0);
 $48 = (($12) + 1460|0);
 ;HEAP32[$48+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$48+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$48+8>>2]=HEAP32[$47+8>>2]|0;HEAP32[$48+12>>2]=HEAP32[$47+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN27DeviceViewProjMatricesStateC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 dest=$this+0|0; src=$5+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = HEAP32[$1>>2]|0;
 $7 = (($6) + 120|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($1)|0);
 dest=$0+0|0; src=$9+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN27DeviceViewProjMatricesStateD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $planes$i = 0, $viewProj$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $viewProj$i = sp + 96|0;
 $planes$i = sp;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 64|0);
 FUNCTION_TABLE_vii[$3 & 4095]($0,$4);
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 100|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($0,$this);
 $8 = (__Z12GetGfxDevicev()|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 116|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
 $13 = HEAP32[$8>>2]|0;
 $14 = (($13) + 124|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($8)|0);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($16,$12,$viewProj$i);
 HEAPF32[$planes$i>>2] = Math_fround(0.0);
 $17 = (($planes$i) + 4|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($planes$i) + 8|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($planes$i) + 16|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($planes$i) + 20|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($planes$i) + 24|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($planes$i) + 32|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($planes$i) + 36|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($planes$i) + 40|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($planes$i) + 48|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($planes$i) + 52|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($planes$i) + 56|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($planes$i) + 64|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($planes$i) + 68|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($planes$i) + 72|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($planes$i) + 80|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($planes$i) + 84|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($planes$i) + 88|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($viewProj$i,$planes$i);
 $34 = (($8) + 1380|0);
 ;HEAP32[$34+0>>2]=HEAP32[$planes$i+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$planes$i+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$planes$i+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$planes$i+12>>2]|0;
 $35 = (($planes$i) + 16|0);
 $36 = (($8) + 1396|0);
 ;HEAP32[$36+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$35+12>>2]|0;
 $37 = (($planes$i) + 32|0);
 $38 = (($8) + 1412|0);
 ;HEAP32[$38+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$37+12>>2]|0;
 $39 = (($planes$i) + 48|0);
 $40 = (($8) + 1428|0);
 ;HEAP32[$40+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$39+12>>2]|0;
 $41 = (($planes$i) + 64|0);
 $42 = (($8) + 1444|0);
 ;HEAP32[$42+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$41+12>>2]|0;
 $43 = (($planes$i) + 80|0);
 $44 = (($8) + 1460|0);
 ;HEAP32[$44+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$43+12>>2]|0;
 STACKTOP = sp;return;
}
function __Z20PrepareSceneNodesJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($userData) + 16|0);
 $2 = (($userData) + 848|0);
 $3 = (($userData) + 976|0);
 $4 = (($userData) + 92|0);
 $5 = (($userData) + 108|0);
 $6 = (($userData) + 116|0);
 $7 = (($userData) + 120|0);
 $8 = (($userData) + 112|0);
 $i$01 = 0;
 while(1) {
  $9 = ((($2) + (($i$01*12)|0)|0) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$3>>2]|0;
  $12 = ((($1) + (($i$01*12)|0)|0) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)>(0);
  if ($14) {
   $15 = (($1) + (($i$01*12)|0)|0);
   $i$01$i = 0;
   while(1) {
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + ($i$01$i<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ((($10) + (($18*24)|0)|0) + 20|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = ($20<<24>>24)==(0);
    $$pre$i = (($10) + (($18*24)|0)|0);
    if (!($21)) {
     $22 = HEAP32[$$pre$i>>2]|0;
     $23 = HEAP32[$6>>2]|0;
     $24 = (($23) + 1)|0;
     HEAP32[$6>>2] = $24;
     $25 = HEAP32[$7>>2]|0;
     $26 = $25 & 2147483647;
     $27 = ($24>>>0)>($26>>>0);
     if ($27) {
      $28 = $25 << 1;
      $29 = ($28|0)==(0);
      $30 = $29 ? 1 : $28;
      $31 = ($26>>>0)<($30>>>0);
      do {
       if ($31) {
        $32 = ($25|0)>(-1);
        if ($32) {
         HEAP32[$7>>2] = $30;
         $33 = HEAP32[$5>>2]|0;
         $34 = $30 << 2;
         $35 = HEAP32[$8>>2]|0;
         HEAP32[$0>>2] = $35;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         $36 = (__Z16realloc_internalPvji10MemLabelIdiPKci($33,$34,4,$$byval_copy1,0,571376,370)|0);
         HEAP32[$5>>2] = $36;
         break;
        } else {
         $37 = $30 << 2;
         $38 = HEAP32[$8>>2]|0;
         HEAP32[$0>>2] = $38;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         $39 = (__Z15malloc_internaljj10MemLabelIdiPKci($37,4,$$byval_copy1,0,571376,352)|0);
         $40 = HEAP32[$5>>2]|0;
         $41 = HEAP32[$6>>2]|0;
         $42 = $41 << 2;
         _memcpy(($39|0),($40|0),($42|0))|0;
         HEAP32[$7>>2] = $30;
         HEAP32[$5>>2] = $39;
         break;
        }
       }
      } while(0);
      $$pre$i$i$i = HEAP32[$6>>2]|0;
      $44 = $$pre$i$i$i;
     } else {
      $44 = $24;
     }
     $43 = (($44) + -1)|0;
     $45 = HEAP32[$5>>2]|0;
     $46 = (($45) + ($43<<2)|0);
     HEAP32[$46>>2] = $22;
    }
    $47 = (__ZN13dynamic_arrayI11VisibleNodeLj4EE9push_backEv($4)|0);
    $48 = HEAP32[$$pre$i>>2]|0;
    $49 = (($47) + 116|0);
    HEAP32[$49>>2] = $48;
    $50 = ((($10) + (($18*24)|0)|0) + 12|0);
    $51 = HEAP16[$50>>1]|0;
    $52 = $51&65535;
    $53 = ((($10) + (($18*24)|0)|0) + 14|0);
    $54 = HEAP16[$53>>1]|0;
    $55 = $54&65535;
    $56 = ((($10) + (($18*24)|0)|0) + 16|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($11) + (($52*12)|0)|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ((($11) + (($52*12)|0)|0) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (Math_fround(__ZN15LODGroupManager16CalculateLODFadeEjjPKhPKf($55,$57,$59,$61)));
    $63 = (($47) + 120|0);
    HEAPF32[$63>>2] = $62;
    $64 = (($i$01$i) + 1)|0;
    $65 = HEAP32[$12>>2]|0;
    $66 = ($64|0)<($65|0);
    if ($66) {
     $i$01$i = $64;
    } else {
     break;
    }
   }
  }
  $67 = (($i$01) + 1)|0;
  $exitcond = ($67|0)==(5);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $67;
  }
 }
 STACKTOP = sp;return;
}
function __Z9CullSceneR22SceneCullingParametersR11CullResults($cullingParameters,$results) {
 $cullingParameters = $cullingParameters|0;
 $results = $results|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i$i$i = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $i$01$i2$i = 0, $i$01$i4$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i$i = sp;
 $0 = (($results) + 16|0);
 $1 = (($results) + 8|0);
 __Z9CullSceneR8JobFenceS0_RK22SceneCullingParametersR13CullingOutput($results,$1,$cullingParameters,$0);
 $2 = (($results) + 84|0);
 __Z18ScheduleJobDependsR8JobFencePFvPvES1_S0_11JobPriority($2,3416,$results,$1,0);
 $3 = (($cullingParameters) + 673|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  __ZL10CullLightsRK22SceneCullingParametersR11CullResults($cullingParameters,$results);
 }
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __Z21CompleteFenceInternalR8JobFence($1);
 }
 $8 = (__ZN15GlobalCallbacks3GetEv()|0);
 $9 = (($results) + 16|0);
 $10 = (($results) + 848|0);
 $i$01$i$i = 0;
 while(1) {
  $11 = ((($8) + ($i$01$i$i<<2)|0) + 896|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   FUNCTION_TABLE_vii[$12 & 4095]($9,$10);
  }
  $14 = (($i$01$i$i) + 1)|0;
  $exitcond$i$i = ($14|0)==(16);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$01$i$i = $14;
  }
 }
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  __Z21CompleteFenceInternalR8JobFence($2);
 }
 $17 = (__ZN5Unity8GetSceneEv()|0);
 __ZN5Unity5Scene27SetPreventAddRemoveRendererEb($17,1);
 $18 = (($results) + 116|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = (($results) + 108|0);
  $22 = (($data$i$i$i) + 8|0);
  $23 = (($data$i$i$i) + 4|0);
  $i$01$i2$i = 0;
  while(1) {
   $24 = HEAP32[$21>>2]|0;
   $25 = (($24) + ($i$01$i2$i<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if ($27) {
    $29 = 0;
   } else {
    $28 = (($26) + -28|0);
    $29 = $28;
   }
   HEAP32[$22>>2] = 0;
   HEAP32[$23>>2] = 0;
   HEAP32[$data$i$i$i>>2] = 0;
   __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($29,564776,$data$i$i$i);
   $30 = (($i$01$i2$i) + 1)|0;
   $31 = HEAP32[$18>>2]|0;
   $32 = ($30>>>0)<($31>>>0);
   if ($32) {
    $i$01$i2$i = $30;
   } else {
    break;
   }
  }
 }
 $33 = (__ZN5Unity8GetSceneEv()|0);
 __ZN5Unity5Scene27SetPreventAddRemoveRendererEb($33,0);
 $34 = (($results) + 100|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0);
 if (!($36)) {
  $37 = (($results) + 92|0);
  $i$01$i4$i = 0;
  while(1) {
   $38 = HEAP32[$37>>2]|0;
   $39 = (($38) + ($i$01$i4$i<<7)|0);
   $40 = ((($38) + ($i$01$i4$i<<7)|0) + 116|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 48|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = ($43<<24>>24)==(0);
   $45 = (($41) + 49|0);
   if ($44) {
    $46 = HEAP8[$45>>0]|0;
    $47 = ($46<<24>>24)==(0);
    if (!($47)) {
     label = 20;
    }
   } else {
    label = 20;
   }
   if ((label|0) == 20) {
    label = 0;
    $48 = HEAP32[$41>>2]|0;
    $49 = (($48) + 20|0);
    $50 = HEAP32[$49>>2]|0;
    FUNCTION_TABLE_vi[$50 & 4095]($41);
    HEAP8[$42>>0] = 0;
    HEAP8[$45>>0] = 0;
   }
   $51 = (($41) + 52|0);
   dest=$39+0|0; src=$51+0|0; stop=dest+116|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $52 = (($i$01$i4$i) + 1)|0;
   $53 = HEAP32[$34>>2]|0;
   $54 = ($52>>>0)<($53>>>0);
   if ($54) {
    $i$01$i4$i = $52;
   } else {
    break;
   }
  }
 }
 $55 = HEAP8[$3>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  STACKTOP = sp;return;
 }
 $57 = (($results) + 184|0);
 $58 = (($cullingParameters) + 676|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($results) + 92|0);
 $61 = (($results) + 124|0);
 $62 = (($results) + 192|0);
 $63 = (($results) + 208|0);
 __Z22CullAllPerObjectLightsR8JobFenceiRK13dynamic_arrayI11VisibleNodeLj4EERK12ActiveLightsRS1_I11CulledLightLj4EERS1_IjLj4EE($57,$59,$60,$61,$62,$63);
 STACKTOP = sp;return;
}
function __ZL10CullLightsRK22SceneCullingParametersR11CullResults($cullingParameters,$results) {
 $cullingParameters = $cullingParameters|0;
 $results = $results|0;
 var $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$byval_copy35 = 0, $$pre$i = 0, $$sink$index12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cullLocalLightsFence = 0, $directionalLights = 0, $exitcond$i$i = 0, $exitcond$i$i$i = 0, $index$01$i$i = 0, $index$01$i$i$i = 0, $isShadowCastingLocalLight = 0, $localLights = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0;
 var $lpad$phi51$index = 0, $lpad$phi51$index2 = 0, $node$0$i = 0, $node$01$i = 0, $node$03$i = 0, $offScreenLocalLightIndices = 0, $offScreenLocalLightvisibilityFades = 0, $size$02$i = 0, $visibleLocalLightIndices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy35 = sp + 172|0;
 $0 = sp + 168|0;
 $1 = sp + 164|0;
 $2 = sp + 160|0;
 $3 = sp + 156|0;
 $4 = sp + 152|0;
 $5 = sp + 148|0;
 $6 = sp + 144|0;
 $7 = sp + 140|0;
 $8 = sp + 136|0;
 $9 = sp + 132|0;
 $10 = sp + 128|0;
 $11 = sp + 124|0;
 $12 = sp + 120|0;
 $13 = sp + 16|0;
 $14 = sp;
 $15 = sp + 4|0;
 $16 = sp + 8|0;
 $17 = sp + 12|0;
 $localLights = sp + 24|0;
 $directionalLights = sp + 40|0;
 $offScreenLocalLightvisibilityFades = sp + 56|0;
 $isShadowCastingLocalLight = sp + 72|0;
 $visibleLocalLightIndices = sp + 88|0;
 $offScreenLocalLightIndices = sp + 100|0;
 $cullLocalLightsFence = sp + 112|0;
 $18 = (__Z15GetLightManagerv()|0);
 $19 = (($18) + 4|0);
 $node$01$i = HEAP32[$19>>2]|0;
 $20 = ($node$01$i|0)==($18|0);
 if (!($20)) {
  $node$03$i = $node$01$i;$size$02$i = 0;
  while(1) {
   $21 = (($node$03$i) + 4|0);
   $22 = (($size$02$i) + 1)|0;
   $node$0$i = HEAP32[$21>>2]|0;
   $23 = ($node$0$i|0)==($18|0);
   if ($23) {
    break;
   } else {
    $node$03$i = $node$0$i;$size$02$i = $22;
   }
  }
  $24 = ($22|0)==(0);
  $25 = (($results) + 124|0);
  if (!($24)) {
   $28 = (($results) + 168|0);
   $29 = (($results) + 180|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $30 & 2147483647;
   $32 = ($31>>>0)<($22>>>0);
   do {
    if ($32) {
     $33 = ($30|0)>(-1);
     if ($33) {
      HEAP32[$29>>2] = $22;
      $34 = HEAP32[$28>>2]|0;
      $35 = $22 << 4;
      $36 = (($results) + 172|0);
      $37 = HEAP32[$36>>2]|0;
      HEAP32[$0>>2] = $37;
      ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$0+0>>2]|0;
      $38 = (__Z16realloc_internalPvji10MemLabelIdiPKci($34,$35,4,$$byval_copy35,0,571376,370)|0);
      HEAP32[$28>>2] = $38;
      break;
     } else {
      $39 = $22 << 4;
      $40 = (($results) + 172|0);
      $41 = HEAP32[$40>>2]|0;
      HEAP32[$0>>2] = $41;
      ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$0+0>>2]|0;
      $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($39,4,$$byval_copy35,0,571376,352)|0);
      $43 = HEAP32[$28>>2]|0;
      $44 = (($results) + 176|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = $45 << 4;
      _memcpy(($42|0),($43|0),($46|0))|0;
      HEAP32[$29>>2] = $22;
      HEAP32[$28>>2] = $42;
      break;
     }
    }
   } while(0);
   $47 = HEAP32[628512>>2]|0;
   HEAP32[$localLights>>2] = 0;
   $48 = (($localLights) + 4|0);
   HEAP32[$48>>2] = $47;
   $49 = (($localLights) + 8|0);
   HEAP32[$49>>2] = 0;
   $50 = (($localLights) + 12|0);
   HEAP32[$50>>2] = 0;
   HEAP32[$directionalLights>>2] = 0;
   $51 = (($directionalLights) + 4|0);
   HEAP32[$51>>2] = $47;
   $52 = (($directionalLights) + 8|0);
   HEAP32[$52>>2] = 0;
   $53 = (($directionalLights) + 12|0);
   HEAP32[$53>>2] = 0;
   HEAP32[$offScreenLocalLightvisibilityFades>>2] = 0;
   $54 = (($offScreenLocalLightvisibilityFades) + 4|0);
   HEAP32[$54>>2] = $47;
   $55 = (($offScreenLocalLightvisibilityFades) + 8|0);
   HEAP32[$55>>2] = 0;
   $56 = (($offScreenLocalLightvisibilityFades) + 12|0);
   HEAP32[$56>>2] = 0;
   HEAP32[$isShadowCastingLocalLight>>2] = 0;
   $57 = (($isShadowCastingLocalLight) + 4|0);
   HEAP32[$57>>2] = $47;
   $58 = (($isShadowCastingLocalLight) + 8|0);
   HEAP32[$58>>2] = 0;
   $59 = (($isShadowCastingLocalLight) + 12|0);
   HEAP32[$59>>2] = 0;
   $60 = ($22|0)==(0);
   if ($60) {
    label = 12;
   } else {
    HEAP32[$50>>2] = $22;
    $61 = $22 << 2;
    HEAP32[$13>>2] = $47;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$13+0>>2]|0;
    $62 = (invoke_iiiiiiii(108,(0|0),($61|0),4,($$byval_copy35|0),0,(571376|0),370)|0);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     label = 80;
    } else {
     HEAP32[$localLights>>2] = $62;
     label = 12;
    }
   }
   L15: do {
    if ((label|0) == 12) {
     $65 = HEAP32[$53>>2]|0;
     $66 = $65 & 2147483647;
     $67 = ($66>>>0)<($22>>>0);
     do {
      if ($67) {
       $68 = ($65|0)>(-1);
       if ($68) {
        HEAP32[$53>>2] = $22;
        $69 = HEAP32[$directionalLights>>2]|0;
        $70 = $22 << 2;
        $71 = HEAP32[$51>>2]|0;
        HEAP32[$11>>2] = $71;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$11+0>>2]|0;
        $72 = (invoke_iiiiiiii(108,($69|0),($70|0),4,($$byval_copy35|0),0,(571376|0),370)|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 80;
         break L15;
        }
        HEAP32[$directionalLights>>2] = $72;
        break;
       } else {
        $75 = $22 << 2;
        $76 = HEAP32[$51>>2]|0;
        HEAP32[$12>>2] = $76;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$12+0>>2]|0;
        $77 = (invoke_iiiiiii(102,($75|0),4,($$byval_copy35|0),0,(571376|0),352)|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 80;
         break L15;
        }
        $80 = HEAP32[$directionalLights>>2]|0;
        $81 = HEAP32[$52>>2]|0;
        $82 = $81 << 2;
        _memcpy(($77|0),($80|0),($82|0))|0;
        HEAP32[$53>>2] = $22;
        HEAP32[$directionalLights>>2] = $77;
        break;
       }
      }
     } while(0);
     $83 = HEAP32[$56>>2]|0;
     $84 = $83 & 2147483647;
     $85 = ($84>>>0)<($22>>>0);
     do {
      if ($85) {
       $86 = ($83|0)>(-1);
       if ($86) {
        HEAP32[$56>>2] = $22;
        $87 = HEAP32[$offScreenLocalLightvisibilityFades>>2]|0;
        $88 = $22 << 2;
        $89 = HEAP32[$54>>2]|0;
        HEAP32[$9>>2] = $89;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$9+0>>2]|0;
        $90 = (invoke_iiiiiiii(108,($87|0),($88|0),4,($$byval_copy35|0),0,(571376|0),370)|0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         label = 80;
         break L15;
        }
        HEAP32[$offScreenLocalLightvisibilityFades>>2] = $90;
        break;
       } else {
        $93 = $22 << 2;
        $94 = HEAP32[$54>>2]|0;
        HEAP32[$10>>2] = $94;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$10+0>>2]|0;
        $95 = (invoke_iiiiiii(102,($93|0),4,($$byval_copy35|0),0,(571376|0),352)|0);
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         label = 80;
         break L15;
        }
        $98 = HEAP32[$offScreenLocalLightvisibilityFades>>2]|0;
        $99 = HEAP32[$55>>2]|0;
        $100 = $99 << 2;
        _memcpy(($95|0),($98|0),($100|0))|0;
        HEAP32[$56>>2] = $22;
        HEAP32[$offScreenLocalLightvisibilityFades>>2] = $95;
        break;
       }
      }
     } while(0);
     $101 = HEAP32[$59>>2]|0;
     $102 = $101 & 2147483647;
     $103 = ($102>>>0)<($22>>>0);
     do {
      if ($103) {
       $104 = ($101|0)>(-1);
       if ($104) {
        HEAP32[$59>>2] = $22;
        $105 = HEAP32[$isShadowCastingLocalLight>>2]|0;
        $106 = $22 << 2;
        $107 = HEAP32[$57>>2]|0;
        HEAP32[$7>>2] = $107;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$7+0>>2]|0;
        $108 = (invoke_iiiiiiii(108,($105|0),($106|0),4,($$byval_copy35|0),0,(571376|0),370)|0);
        $109 = __THREW__; __THREW__ = 0;
        $110 = $109&1;
        if ($110) {
         label = 80;
         break L15;
        }
        HEAP32[$isShadowCastingLocalLight>>2] = $108;
        break;
       } else {
        $111 = $22 << 2;
        $112 = HEAP32[$57>>2]|0;
        HEAP32[$8>>2] = $112;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$8+0>>2]|0;
        $113 = (invoke_iiiiiii(102,($111|0),4,($$byval_copy35|0),0,(571376|0),352)|0);
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if ($115) {
         label = 80;
         break L15;
        }
        $116 = HEAP32[$isShadowCastingLocalLight>>2]|0;
        $117 = HEAP32[$58>>2]|0;
        $118 = $117 << 2;
        _memcpy(($113|0),($116|0),($118|0))|0;
        HEAP32[$59>>2] = $22;
        HEAP32[$isShadowCastingLocalLight>>2] = $113;
        break;
       }
      }
     } while(0);
     $119 = (($results) + 1024|0);
     $120 = HEAP32[$119>>2]|0;
     __THREW__ = 0;
     invoke_viiiii(92,($directionalLights|0),($localLights|0),($28|0),($isShadowCastingLocalLight|0),($120|0));
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if ($122) {
      label = 80;
     } else {
      $123 = HEAP32[$52>>2]|0;
      $124 = HEAP32[$49>>2]|0;
      $125 = (($124) + ($123))|0;
      $126 = (($results) + 136|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = $127 & 2147483647;
      $129 = ($128>>>0)<($125>>>0);
      do {
       if ($129) {
        $130 = ($127|0)>(-1);
        if ($130) {
         HEAP32[$126>>2] = $125;
         $131 = HEAP32[$25>>2]|0;
         $132 = ($125*108)|0;
         $133 = (($results) + 128|0);
         $134 = HEAP32[$133>>2]|0;
         HEAP32[$5>>2] = $134;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$5+0>>2]|0;
         $135 = (invoke_iiiiiiii(108,($131|0),($132|0),4,($$byval_copy35|0),0,(571376|0),370)|0);
         $136 = __THREW__; __THREW__ = 0;
         $137 = $136&1;
         if ($137) {
          label = 80;
          break L15;
         }
         HEAP32[$25>>2] = $135;
         break;
        } else {
         $138 = ($125*108)|0;
         $139 = (($results) + 128|0);
         $140 = HEAP32[$139>>2]|0;
         HEAP32[$6>>2] = $140;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$6+0>>2]|0;
         $141 = (invoke_iiiiiii(102,($138|0),4,($$byval_copy35|0),0,(571376|0),352)|0);
         $142 = __THREW__; __THREW__ = 0;
         $143 = $142&1;
         if ($143) {
          label = 80;
          break L15;
         }
         $144 = HEAP32[$25>>2]|0;
         $145 = (($results) + 132|0);
         $146 = HEAP32[$145>>2]|0;
         $147 = ($146*108)|0;
         _memcpy(($141|0),($144|0),($147|0))|0;
         HEAP32[$126>>2] = $125;
         HEAP32[$25>>2] = $141;
         break;
        }
       }
      } while(0);
      $148 = HEAP32[$directionalLights>>2]|0;
      $149 = HEAP32[$52>>2]|0;
      __THREW__ = 0;
      invoke_viii(1675,($148|0),($149|0),($25|0));
      $150 = __THREW__; __THREW__ = 0;
      $151 = $150&1;
      if ($151) {
       label = 80;
      } else {
       $152 = (($results) + 224|0);
       $153 = HEAP32[$52>>2]|0;
       $154 = HEAP32[$49>>2]|0;
       $155 = (($154) + ($153))|0;
       $156 = (($results) + 236|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = $157 & 2147483647;
       $159 = ($158>>>0)<($155>>>0);
       do {
        if ($159) {
         $160 = ($157|0)>(-1);
         if ($160) {
          HEAP32[$156>>2] = $155;
          $161 = HEAP32[$152>>2]|0;
          $162 = ($155*796)|0;
          $163 = (($results) + 228|0);
          $164 = HEAP32[$163>>2]|0;
          HEAP32[$3>>2] = $164;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$3+0>>2]|0;
          $165 = (invoke_iiiiiiii(108,($161|0),($162|0),4,($$byval_copy35|0),0,(571376|0),370)|0);
          $166 = __THREW__; __THREW__ = 0;
          $167 = $166&1;
          if ($167) {
           label = 80;
           break L15;
          }
          HEAP32[$152>>2] = $165;
          break;
         } else {
          $168 = ($155*796)|0;
          $169 = (($results) + 228|0);
          $170 = HEAP32[$169>>2]|0;
          HEAP32[$4>>2] = $170;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$4+0>>2]|0;
          $171 = (invoke_iiiiiii(102,($168|0),4,($$byval_copy35|0),0,(571376|0),352)|0);
          $172 = __THREW__; __THREW__ = 0;
          $173 = $172&1;
          if ($173) {
           label = 80;
           break L15;
          }
          $174 = HEAP32[$152>>2]|0;
          $175 = (($results) + 232|0);
          $176 = HEAP32[$175>>2]|0;
          $177 = ($176*796)|0;
          _memcpy(($171|0),($174|0),($177|0))|0;
          HEAP32[$156>>2] = $155;
          HEAP32[$152>>2] = $171;
          break;
         }
        }
       } while(0);
       $178 = (($results) + 144|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ($179|0)==(0);
       L59: do {
        if (!($180)) {
         $index$01$i$i = 0;
         while(1) {
          $181 = HEAP32[$25>>2]|0;
          $182 = ((($181) + (($index$01$i$i*108)|0)|0) + 9|0);
          $183 = HEAP8[$182>>0]|0;
          $184 = ($183<<24>>24)==(0);
          if ($184) {
           label = 51;
          } else {
           $185 = ((($181) + (($index$01$i$i*108)|0)|0) + 8|0);
           $186 = HEAP8[$185>>0]|0;
           $187 = ($186<<24>>24)==(0);
           if ($187) {
            label = 51;
           } else {
            $188 = (($181) + (($index$01$i$i*108)|0)|0);
            $189 = HEAP32[$188>>2]|0;
            $190 = (($189) + 116|0);
            $191 = HEAP32[$190>>2]|0;
            $192 = ($191|0)==(0);
            if ($192) {
             label = 51;
            } else {
             __THREW__ = 0;
             $193 = (invoke_ii(3225,($152|0))|0);
             $194 = __THREW__; __THREW__ = 0;
             $195 = $194&1;
             if ($195) {
              break;
             }
             HEAP32[$193>>2] = $index$01$i$i;
             $196 = ((($181) + (($index$01$i$i*108)|0)|0) + 4|0);
             HEAP32[$196>>2] = $193;
            }
           }
          }
          if ((label|0) == 51) {
           label = 0;
           $197 = ((($181) + (($index$01$i$i*108)|0)|0) + 4|0);
           HEAP32[$197>>2] = 0;
          }
          $198 = (($index$01$i$i) + 1)|0;
          $exitcond$i$i = ($198|0)==($179|0);
          if ($exitcond$i$i) {
           break L59;
          } else {
           $index$01$i$i = $198;
          }
         }
         $284 = ___cxa_find_matching_catch()|0;
         $285 = tempRet0;
         $lpad$phi51$index = $284;$lpad$phi51$index2 = $285;
         label = 81;
         break L15;
        }
       } while(0);
       HEAP32[$visibleLocalLightIndices>>2] = 0;
       $199 = (($visibleLocalLightIndices) + 4|0);
       HEAP32[$199>>2] = 0;
       $200 = (($visibleLocalLightIndices) + 8|0);
       HEAP32[$200>>2] = 0;
       $201 = (($results) + 176|0);
       $202 = HEAP32[$201>>2]|0;
       __THREW__ = 0;
       invoke_vii(2624,($visibleLocalLightIndices|0),($202|0));
       $203 = __THREW__; __THREW__ = 0;
       $204 = $203&1;
       if ($204) {
        label = 80;
       } else {
        HEAP32[$offScreenLocalLightIndices>>2] = 0;
        $205 = (($offScreenLocalLightIndices) + 4|0);
        HEAP32[$205>>2] = 0;
        $206 = (($offScreenLocalLightIndices) + 8|0);
        HEAP32[$206>>2] = 0;
        $207 = HEAP32[$201>>2]|0;
        __THREW__ = 0;
        invoke_vii(2624,($offScreenLocalLightIndices|0),($207|0));
        $208 = __THREW__; __THREW__ = 0;
        $209 = $208&1;
        if ($209) {
         label = 80;
        } else {
         HEAP32[$cullLocalLightsFence>>2] = 0;
         $210 = (($cullLocalLightsFence) + 4|0);
         HEAP32[$210>>2] = 0;
         __THREW__ = 0;
         invoke_viiiiiiii(26,($cullLocalLightsFence|0),($results|0),($cullingParameters|0),($28|0),($isShadowCastingLocalLight|0),($visibleLocalLightIndices|0),($offScreenLocalLightIndices|0),($offScreenLocalLightvisibilityFades|0));
         $211 = __THREW__; __THREW__ = 0;
         $212 = $211&1;
         L75: do {
          if ($212) {
           label = 83;
          } else {
           $213 = (($results) + 232|0);
           $214 = HEAP32[$213>>2]|0;
           __THREW__ = 0;
           invoke_viii(1676,($214|0),($cullingParameters|0),($results|0));
           $215 = __THREW__; __THREW__ = 0;
           $216 = $215&1;
           if ($216) {
            label = 83;
           } else {
            $217 = HEAP32[$cullLocalLightsFence>>2]|0;
            $218 = ($217|0)==(0|0);
            if (!($218)) {
             __THREW__ = 0;
             invoke_vi(3402,($cullLocalLightsFence|0));
             $219 = __THREW__; __THREW__ = 0;
             $220 = $219&1;
             if ($220) {
              label = 83;
              break;
             }
            }
            $221 = HEAP32[$119>>2]|0;
            $222 = HEAP32[$localLights>>2]|0;
            $223 = HEAP32[$28>>2]|0;
            $224 = HEAP32[$offScreenLocalLightvisibilityFades>>2]|0;
            __THREW__ = 0;
            invoke_viiiiiii(65,($221|0),($222|0),($223|0),($visibleLocalLightIndices|0),($224|0),($offScreenLocalLightIndices|0),($25|0));
            $225 = __THREW__; __THREW__ = 0;
            $226 = $225&1;
            if ($226) {
             label = 83;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3417,($visibleLocalLightIndices|0));
            $227 = __THREW__; __THREW__ = 0;
            $228 = $227&1;
            if ($228) {
             label = 83;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3417,($offScreenLocalLightIndices|0));
            $229 = __THREW__; __THREW__ = 0;
            $230 = $229&1;
            if ($230) {
             label = 83;
             break;
            }
            __THREW__ = 0;
            $231 = (invoke_i(76)|0);
            $232 = __THREW__; __THREW__ = 0;
            $233 = $232&1;
            if ($233) {
             label = 83;
             break;
            }
            $234 = (($231) + 40|0);
            $235 = HEAP32[$234>>2]|0;
            $236 = (($231) + 24|0);
            $237 = HEAP32[$236>>2]|0;
            $238 = ((($237) + (($235*96)|0)|0) + 16|0);
            $239 = HEAP32[$238>>2]|0;
            $240 = ($239|0)==(0);
            do {
             if (!($240)) {
              $241 = (($cullingParameters) + 676|0);
              $242 = HEAP32[$241>>2]|0;
              $243 = ($242|0)==(0);
              if ($243) {
               break;
              }
              $244 = HEAP32[$213>>2]|0;
              $245 = HEAP32[$178>>2]|0;
              $246 = (($results) + 148|0);
              $247 = HEAP32[$246>>2]|0;
              $248 = (($247) + ($245))|0;
              $249 = (($results) + 152|0);
              $250 = HEAP32[$249>>2]|0;
              $251 = (($248) + ($250))|0;
              $252 = ($245>>>0)<($251>>>0);
              if (!($252)) {
               break;
              }
              $253 = (($results) + 124|0);
              $index$01$i$i$i = $245;
              L89: while(1) {
               $254 = HEAP32[$253>>2]|0;
               $255 = ((($254) + (($index$01$i$i$i*108)|0)|0) + 9|0);
               $256 = HEAP8[$255>>0]|0;
               $257 = ($256<<24>>24)==(0);
               do {
                if ($257) {
                 label = 72;
                } else {
                 $258 = ((($254) + (($index$01$i$i$i*108)|0)|0) + 8|0);
                 $259 = HEAP8[$258>>0]|0;
                 $260 = ($259<<24>>24)==(0);
                 if ($260) {
                  label = 72;
                  break;
                 }
                 $261 = (($254) + (($index$01$i$i$i*108)|0)|0);
                 $262 = HEAP32[$261>>2]|0;
                 $263 = (($262) + 116|0);
                 $264 = HEAP32[$263>>2]|0;
                 $265 = ($264|0)==(0);
                 if ($265) {
                  label = 72;
                  break;
                 }
                 __THREW__ = 0;
                 $266 = (invoke_ii(3225,($152|0))|0);
                 $267 = __THREW__; __THREW__ = 0;
                 $268 = $267&1;
                 if ($268) {
                  label = 82;
                  break L89;
                 }
                 HEAP32[$266>>2] = $index$01$i$i$i;
                 $269 = ((($254) + (($index$01$i$i$i*108)|0)|0) + 4|0);
                 HEAP32[$269>>2] = $266;
                }
               } while(0);
               if ((label|0) == 72) {
                label = 0;
                $270 = ((($254) + (($index$01$i$i$i*108)|0)|0) + 4|0);
                HEAP32[$270>>2] = 0;
               }
               $271 = (($index$01$i$i$i) + 1)|0;
               $exitcond$i$i$i = ($271|0)==($251|0);
               if ($exitcond$i$i$i) {
                break;
               } else {
                $index$01$i$i$i = $271;
               }
              }
              if ((label|0) == 82) {
               $288 = ___cxa_find_matching_catch()|0;
               $289 = tempRet0;
               $lpad$phi$index = $288;$lpad$phi$index7 = $289;
               break L75;
              }
              $$pre$i = HEAP32[$213>>2]|0;
              $272 = ($$pre$i|0)==($244|0);
              if ($272) {
               break;
              }
              $273 = (($cullingParameters) + 672|0);
              $274 = HEAP8[$273>>0]|0;
              $275 = ($274<<24>>24)!=(0);
              __THREW__ = 0;
              invoke_viiii(346,($244|0),($$pre$i|0),($275|0),($results|0));
              $276 = __THREW__; __THREW__ = 0;
              $277 = $276&1;
              if ($277) {
               label = 83;
               break L75;
              }
             }
            } while(0);
            $292 = HEAP32[$59>>2]|0;
            $293 = ($292|0)>(-1);
            do {
             if ($293) {
              $294 = HEAP32[$isShadowCastingLocalLight>>2]|0;
              $295 = HEAP32[$57>>2]|0;
              HEAP32[$0>>2] = $295;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$0+0>>2]|0;
              invoke_vii(2591,($294|0),($$byval_copy35|0));
              $296 = __THREW__; __THREW__ = 0;
              $297 = $296&1;
              if ($297) {
               $282 = ___cxa_find_matching_catch()|0;
               $283 = tempRet0;
               $$1 = $283;$$12 = $282;
               label = 100;
               break L15;
              } else {
               HEAP32[$isShadowCastingLocalLight>>2] = 0;
               break;
              }
             }
            } while(0);
            $298 = HEAP32[$56>>2]|0;
            $299 = ($298|0)>(-1);
            do {
             if ($299) {
              $300 = HEAP32[$offScreenLocalLightvisibilityFades>>2]|0;
              $301 = HEAP32[$54>>2]|0;
              HEAP32[$1>>2] = $301;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$1+0>>2]|0;
              invoke_vii(2591,($300|0),($$byval_copy35|0));
              $302 = __THREW__; __THREW__ = 0;
              $303 = $302&1;
              if ($303) {
               $280 = ___cxa_find_matching_catch()|0;
               $281 = tempRet0;
               $$2 = $281;$$23 = $280;
               label = 103;
               break L15;
              } else {
               HEAP32[$offScreenLocalLightvisibilityFades>>2] = 0;
               break;
              }
             }
            } while(0);
            $304 = HEAP32[$53>>2]|0;
            $305 = ($304|0)>(-1);
            do {
             if ($305) {
              $306 = HEAP32[$directionalLights>>2]|0;
              $307 = HEAP32[$51>>2]|0;
              HEAP32[$2>>2] = $307;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$2+0>>2]|0;
              invoke_vii(2591,($306|0),($$byval_copy35|0));
              $308 = __THREW__; __THREW__ = 0;
              $309 = $308&1;
              if ($309) {
               $278 = ___cxa_find_matching_catch()|0;
               $279 = tempRet0;
               $$3 = $279;$$34 = $278;
               break L15;
              } else {
               HEAP32[$directionalLights>>2] = 0;
               break;
              }
             }
            } while(0);
            $310 = HEAP32[$50>>2]|0;
            $311 = ($310|0)>(-1);
            if (!($311)) {
             STACKTOP = sp;return;
            }
            $312 = HEAP32[$localLights>>2]|0;
            $313 = HEAP32[$48>>2]|0;
            HEAP32[$0>>2] = $313;
            ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$0+0>>2]|0;
            __Z19free_alloc_internalPv10MemLabelId($312,$$byval_copy35);
            HEAP32[$localLights>>2] = 0;
            STACKTOP = sp;return;
           }
          }
         } while(0);
         if ((label|0) == 83) {
          $290 = ___cxa_find_matching_catch()|0;
          $291 = tempRet0;
          $lpad$phi$index = $290;$lpad$phi$index7 = $291;
         }
         $$01 = $lpad$phi$index;$$sink$index12 = $lpad$phi$index7;
         label = 97;
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 80) {
    $286 = ___cxa_find_matching_catch()|0;
    $287 = tempRet0;
    $lpad$phi51$index = $286;$lpad$phi51$index2 = $287;
    label = 81;
   }
   if ((label|0) == 81) {
    $$01 = $lpad$phi51$index;$$sink$index12 = $lpad$phi51$index2;
    label = 97;
   }
   do {
    if ((label|0) == 97) {
     $314 = HEAP32[$59>>2]|0;
     $315 = ($314|0)>(-1);
     if ($315) {
      $316 = HEAP32[$isShadowCastingLocalLight>>2]|0;
      $317 = HEAP32[$57>>2]|0;
      HEAP32[$14>>2] = $317;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$14+0>>2]|0;
      invoke_vii(2591,($316|0),($$byval_copy35|0));
      $318 = __THREW__; __THREW__ = 0;
      $319 = $318&1;
      if ($319) {
       $338 = ___cxa_find_matching_catch(0|0)|0;
       $339 = tempRet0;
       ___clang_call_terminate($338);
       // unreachable;
      } else {
       HEAP32[$isShadowCastingLocalLight>>2] = 0;
       $$1 = $$sink$index12;$$12 = $$01;
       label = 100;
       break;
      }
     } else {
      $$1 = $$sink$index12;$$12 = $$01;
      label = 100;
     }
    }
   } while(0);
   do {
    if ((label|0) == 100) {
     $320 = HEAP32[$56>>2]|0;
     $321 = ($320|0)>(-1);
     if ($321) {
      $322 = HEAP32[$offScreenLocalLightvisibilityFades>>2]|0;
      $323 = HEAP32[$54>>2]|0;
      HEAP32[$15>>2] = $323;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$15+0>>2]|0;
      invoke_vii(2591,($322|0),($$byval_copy35|0));
      $324 = __THREW__; __THREW__ = 0;
      $325 = $324&1;
      if ($325) {
       $338 = ___cxa_find_matching_catch(0|0)|0;
       $339 = tempRet0;
       ___clang_call_terminate($338);
       // unreachable;
      } else {
       HEAP32[$offScreenLocalLightvisibilityFades>>2] = 0;
       $$2 = $$1;$$23 = $$12;
       label = 103;
       break;
      }
     } else {
      $$2 = $$1;$$23 = $$12;
      label = 103;
     }
    }
   } while(0);
   do {
    if ((label|0) == 103) {
     $326 = HEAP32[$53>>2]|0;
     $327 = ($326|0)>(-1);
     if ($327) {
      $328 = HEAP32[$directionalLights>>2]|0;
      $329 = HEAP32[$51>>2]|0;
      HEAP32[$16>>2] = $329;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$16+0>>2]|0;
      invoke_vii(2591,($328|0),($$byval_copy35|0));
      $330 = __THREW__; __THREW__ = 0;
      $331 = $330&1;
      if ($331) {
       $338 = ___cxa_find_matching_catch(0|0)|0;
       $339 = tempRet0;
       ___clang_call_terminate($338);
       // unreachable;
      } else {
       HEAP32[$directionalLights>>2] = 0;
       $$3 = $$2;$$34 = $$23;
       break;
      }
     } else {
      $$3 = $$2;$$34 = $$23;
     }
    }
   } while(0);
   $332 = HEAP32[$50>>2]|0;
   $333 = ($332|0)>(-1);
   if (!($333)) {
    ___resumeException($$34|0);
    // unreachable;
   }
   $334 = HEAP32[$localLights>>2]|0;
   $335 = HEAP32[$48>>2]|0;
   HEAP32[$17>>2] = $335;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$17+0>>2]|0;
   invoke_vii(2591,($334|0),($$byval_copy35|0));
   $336 = __THREW__; __THREW__ = 0;
   $337 = $336&1;
   if ($337) {
    $338 = ___cxa_find_matching_catch(0|0)|0;
    $339 = tempRet0;
    ___clang_call_terminate($338);
    // unreachable;
   }
   HEAP32[$localLights>>2] = 0;
   ___resumeException($$34|0);
   // unreachable;
  }
 }
 $26 = (($results) + 140|0);
 HEAP8[$26>>0] = 0;
 $27 = (($results) + 164|0);
 HEAP8[$27>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI11VisibleNodeLj4EE9push_backEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 do {
  if ($7) {
   $8 = $5 << 1;
   $9 = ($8|0)==(0);
   $10 = $9 ? 1 : $8;
   $11 = ($6>>>0)<($10>>>0);
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = $10 << 7;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,571376,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = $10 << 7;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,571376,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = $23 << 7;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($25) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + ($26<<7)|0);
 STACKTOP = sp;return ($28|0);
}
function __ZN13dynamic_arrayI13ShadowedLightLj4EE19push_back_constructEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 do {
  if ($7) {
   $8 = $5 << 1;
   $9 = ($8|0)==(0);
   $10 = $9 ? 1 : $8;
   $11 = ($6>>>0)<($10>>>0);
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*796)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,571376,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*796)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,571376,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*796)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($25) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($26*796)|0)|0);
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return ($28|0);
 }
 $30 = ((($27) + (($26*796)|0)|0) + 4|0);
 $31 = ((($27) + (($26*796)|0)|0) + 68|0);
 HEAP32[$31>>2] = 0;
 dest=$30+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$30+60>>0]=0|0;
 $32 = ((($27) + (($26*796)|0)|0) + 72|0);
 HEAP32[$32>>2] = 0;
 $33 = ((($27) + (($26*796)|0)|0) + 76|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($27) + (($26*796)|0)|0) + 84|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = ((($27) + (($26*796)|0)|0) + 88|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = ((($27) + (($26*796)|0)|0) + 92|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = ((($27) + (($26*796)|0)|0) + 108|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = ((($27) + (($26*796)|0)|0) + 112|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = ((($27) + (($26*796)|0)|0) + 116|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = ((($27) + (($26*796)|0)|0) + 124|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = ((($27) + (($26*796)|0)|0) + 128|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = ((($27) + (($26*796)|0)|0) + 132|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = ((($27) + (($26*796)|0)|0) + 140|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = ((($27) + (($26*796)|0)|0) + 144|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = ((($27) + (($26*796)|0)|0) + 148|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = ((($27) + (($26*796)|0)|0) + 156|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = ((($27) + (($26*796)|0)|0) + 160|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = ((($27) + (($26*796)|0)|0) + 164|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = ((($27) + (($26*796)|0)|0) + 172|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = ((($27) + (($26*796)|0)|0) + 176|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = ((($27) + (($26*796)|0)|0) + 180|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = ((($27) + (($26*796)|0)|0) + 188|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = ((($27) + (($26*796)|0)|0) + 192|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = ((($27) + (($26*796)|0)|0) + 196|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = ((($27) + (($26*796)|0)|0) + 204|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = ((($27) + (($26*796)|0)|0) + 208|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = ((($27) + (($26*796)|0)|0) + 212|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = ((($27) + (($26*796)|0)|0) + 220|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = ((($27) + (($26*796)|0)|0) + 224|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = ((($27) + (($26*796)|0)|0) + 228|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = ((($27) + (($26*796)|0)|0) + 236|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = ((($27) + (($26*796)|0)|0) + 240|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = ((($27) + (($26*796)|0)|0) + 244|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = ((($27) + (($26*796)|0)|0) + 252|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = ((($27) + (($26*796)|0)|0) + 256|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 $66 = ((($27) + (($26*796)|0)|0) + 260|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = ((($27) + (($26*796)|0)|0) + 408|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = ((($27) + (($26*796)|0)|0) + 412|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = ((($27) + (($26*796)|0)|0) + 416|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 $70 = ((($27) + (($26*796)|0)|0) + 676|0);
 $71 = ((($27) + (($26*796)|0)|0) + 784|0);
 HEAP32[$71>>2] = 0;
 $72 = ((($27) + (($26*796)|0)|0) + 788|0);
 HEAP32[$72>>2] = 0;
 dest=$70+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $73 = ((($27) + (($26*796)|0)|0) + 792|0);
 HEAP32[$73>>2] = 0;
 STACKTOP = sp;return ($28|0);
}
function __ZN11CullResultsC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 84|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 88|0);
 HEAP32[$2>>2] = 0;
 dest=$this+0|0; stop=dest+76|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$this+76>>0]=0|0;
 $3 = HEAP32[628520>>2]|0;
 $4 = (($this) + 92|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 96|0);
 HEAP32[$5>>2] = $3;
 $6 = (($this) + 100|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 104|0);
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[628520>>2]|0;
 $9 = (($this) + 108|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 112|0);
 HEAP32[$10>>2] = $8;
 $11 = (($this) + 116|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 120|0);
 HEAP32[$12>>2] = 0;
 $13 = HEAP32[628512>>2]|0;
 $14 = (($this) + 124|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 128|0);
 HEAP32[$15>>2] = $13;
 $16 = (($this) + 132|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 136|0);
 HEAP32[$17>>2] = 0;
 $18 = HEAP32[628512>>2]|0;
 $19 = (($this) + 168|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 172|0);
 HEAP32[$20>>2] = $18;
 $21 = (($this) + 176|0);
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
 $22 = HEAP32[628520>>2]|0;
 $23 = (($this) + 192|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 196|0);
 HEAP32[$24>>2] = $22;
 $25 = (($this) + 200|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 204|0);
 HEAP32[$26>>2] = 0;
 $27 = HEAP32[628520>>2]|0;
 $28 = (($this) + 208|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 212|0);
 HEAP32[$29>>2] = $27;
 $30 = (($this) + 216|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 220|0);
 HEAP32[$31>>2] = 0;
 $32 = HEAP32[628512>>2]|0;
 $33 = (($this) + 224|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 228|0);
 HEAP32[$34>>2] = $32;
 $35 = (($this) + 232|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 236|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 244|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($this) + 248|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($this) + 252|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($this) + 268|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($this) + 272|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($this) + 276|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($this) + 284|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($this) + 288|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($this) + 292|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($this) + 300|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($this) + 304|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($this) + 308|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($this) + 316|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($this) + 320|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($this) + 324|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($this) + 332|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($this) + 336|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($this) + 340|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($this) + 348|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($this) + 352|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($this) + 356|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($this) + 364|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($this) + 368|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($this) + 372|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($this) + 380|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (($this) + 384|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($this) + 388|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($this) + 396|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = (($this) + 400|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 $66 = (($this) + 404|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($this) + 412|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($this) + 416|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($this) + 420|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 $70 = (($this) + 568|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($this) + 572|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($this) + 576|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($this) + 836|0);
 $74 = (($this) + 944|0);
 dest=$73+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$74+0>>2]=0|0;HEAP32[$74+4>>2]=0|0;HEAP32[$74+8>>2]=0|0;HEAP32[$74+12>>2]=0|0;HEAP32[$74+16>>2]=0|0;HEAP32[$74+20>>2]=0|0;HEAP32[$74+24>>2]=0|0;HEAP32[$74+28>>2]=0|0;
 $75 = HEAP32[628512>>2]|0;
 $76 = (($this) + 976|0);
 HEAP32[$76>>2] = 0;
 $77 = (($this) + 980|0);
 HEAP32[$77>>2] = $75;
 $78 = (($this) + 984|0);
 HEAP32[$78>>2] = 0;
 $79 = (($this) + 988|0);
 HEAP32[$79>>2] = 0;
 $80 = HEAP32[628512>>2]|0;
 $81 = (($this) + 992|0);
 HEAP32[$81>>2] = 0;
 $82 = (($this) + 996|0);
 HEAP32[$82>>2] = $80;
 $83 = (($this) + 1000|0);
 HEAP32[$83>>2] = 0;
 $84 = (($this) + 1004|0);
 HEAP32[$84>>2] = 0;
 $85 = HEAP32[628512>>2]|0;
 $86 = (($this) + 1008|0);
 HEAP32[$86>>2] = 0;
 $87 = (($this) + 1012|0);
 HEAP32[$87>>2] = $85;
 $88 = (($this) + 1016|0);
 ;HEAP32[$88+0>>2]=0|0;HEAP32[$88+4>>2]=0|0;HEAP32[$88+8>>2]=0|0;HEAP32[$88+12>>2]=0|0;HEAP32[$88+16>>2]=0|0;
 $89 = HEAP32[628520>>2]|0;
 $90 = (($this) + 1036|0);
 HEAP32[$90>>2] = 0;
 $91 = (($this) + 1040|0);
 HEAP32[$91>>2] = $89;
 $92 = (($this) + 1044|0);
 HEAP32[$92>>2] = 0;
 $93 = (($this) + 1048|0);
 HEAP32[$93>>2] = 0;
 $94 = HEAP32[628520>>2]|0;
 $95 = (($this) + 1052|0);
 HEAP32[$95>>2] = 0;
 $96 = (($this) + 1056|0);
 HEAP32[$96>>2] = $94;
 $97 = (($this) + 1060|0);
 HEAP32[$97>>2] = 0;
 $98 = (($this) + 1064|0);
 HEAP32[$98>>2] = 0;
 $99 = (($this) + 1068|0);
 HEAP32[$99>>2] = 0;
 $100 = (($this) + 1072|0);
 HEAP32[$100>>2] = -1;
 $101 = (($this) + 1076|0);
 HEAP8[$101>>0] = 0;
 STACKTOP = sp;return;
}
function __Z20SyncFenceCullResultsR11CullResults($results) {
 $results = $results|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$results>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  __Z21CompleteFenceInternalR8JobFence($results);
 }
 $2 = (($results) + 184|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __Z21CompleteFenceInternalR8JobFence($2);
 }
 $5 = (($results) + 1028|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __Z21CompleteFenceInternalR8JobFence($5);
 }
 $8 = (($results) + 232|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($results) + 224|0);
 $19 = $9;$i$04 = 0;
 while(1) {
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($12) + (($i$04*796)|0)|0) + 72|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $18 = $19;
  } else {
   __Z21CompleteFenceInternalR8JobFence($13);
   $$pre = HEAP32[$8>>2]|0;
   $18 = $$pre;
  }
  $16 = (($i$04) + 1)|0;
  $17 = ($16>>>0)<($18>>>0);
  if ($17) {
   $19 = $18;$i$04 = $16;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11CullResultsD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$10 = 0, $$1016 = 0, $$12 = 0, $$1218 = 0, $$13 = 0, $$1319 = 0, $$14 = 0, $$1420 = 0, $$17 = 0, $$3 = 0, $$39 = 0, $$4 = 0, $$410 = 0, $$5 = 0, $$511 = 0, $$8 = 0, $$814 = 0;
 var $$9 = 0, $$915 = 0, $$byval_copy66 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i47 = 0, $$pre$i$i$i$i$i66 = 0, $$pre$i$i$i$i$i74 = 0, $$pre$i$i$i49 = 0, $$pre$i$i$i68 = 0, $$pre$i$i$i76 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index10Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body92$indexZ2D = 0, $i$0100 = 0, $i$04$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy66 = sp + 124|0;
 $0 = sp + 120|0;
 $1 = sp + 116|0;
 $2 = sp + 112|0;
 $3 = sp + 108|0;
 $4 = sp + 104|0;
 $5 = sp + 100|0;
 $6 = sp + 96|0;
 $7 = sp + 92|0;
 $8 = sp + 88|0;
 $9 = sp + 84|0;
 $10 = sp + 80|0;
 $11 = sp + 76|0;
 $12 = sp + 72|0;
 $13 = sp + 68|0;
 $14 = sp + 64|0;
 $15 = sp + 60|0;
 $16 = sp + 24|0;
 $17 = sp;
 $18 = sp + 4|0;
 $19 = sp + 8|0;
 $20 = sp + 12|0;
 $21 = sp + 16|0;
 $22 = sp + 20|0;
 $23 = sp + 28|0;
 $24 = sp + 32|0;
 $25 = sp + 36|0;
 $26 = sp + 40|0;
 $27 = sp + 44|0;
 $28 = sp + 48|0;
 $29 = sp + 52|0;
 $30 = sp + 56|0;
 $31 = HEAP32[$this>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  label = 3;
 } else {
  __THREW__ = 0;
  invoke_vi(3402,($this|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   label = 21;
  } else {
   label = 3;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   $35 = (($this) + 184|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    __THREW__ = 0;
    invoke_vi(3402,($35|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 21;
     break;
    }
   }
   $40 = (($this) + 1028|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    __THREW__ = 0;
    invoke_vi(3402,($40|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     label = 21;
     break;
    }
   }
   $45 = (($this) + 232|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0);
   L11: do {
    if ($47) {
     $517 = 0;
    } else {
     $48 = (($this) + 224|0);
     $518 = $46;$i$04$i = 0;
     while(1) {
      $49 = HEAP32[$48>>2]|0;
      $50 = ((($49) + (($i$04$i*796)|0)|0) + 72|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==(0|0);
      if ($52) {
       $57 = $518;
      } else {
       __THREW__ = 0;
       invoke_vi(3402,($50|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       $$pre$i = HEAP32[$45>>2]|0;
       $57 = $$pre$i;
      }
      $55 = (($i$04$i) + 1)|0;
      $56 = ($55>>>0)<($57>>>0);
      if ($56) {
       $518 = $57;$i$04$i = $55;
      } else {
       $517 = $57;
       break L11;
      }
     }
     $76 = ___cxa_find_matching_catch()|0;
     $77 = tempRet0;
     $lpad$phi$index = $76;$lpad$phi$index3 = $77;
     label = 22;
     break L3;
    }
   } while(0);
   $58 = (($this) + 80|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0|0);
   if ($60) {
    $73 = $517;
   } else {
    __THREW__ = 0;
    $61 = (invoke_i(77)|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 21;
     break;
    }
    $64 = HEAP32[$61>>2]|0;
    $65 = (($64) + 36|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = HEAP32[$58>>2]|0;
    $68 = HEAP32[628512>>2]|0;
    HEAP32[$30>>2] = $68;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$30+0>>2]|0;
    invoke_viiii($66|0,($61|0),($67|0),0,($$byval_copy66|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     label = 21;
     break;
    }
    $$pre = HEAP32[$45>>2]|0;
    $73 = $$pre;
   }
   $71 = (($this) + 224|0);
   $72 = ($73|0)==(0);
   L26: do {
    if (!($72)) {
     $i$0100 = 0;
     while(1) {
      $89 = HEAP32[$71>>2]|0;
      $90 = ((($89) + (($i$0100*796)|0)|0) + 4|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = HEAP32[628512>>2]|0;
      HEAP32[$28>>2] = $92;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$28+0>>2]|0;
      invoke_vii(2591,($91|0),($$byval_copy66|0));
      $93 = __THREW__; __THREW__ = 0;
      $94 = $93&1;
      if ($94) {
       break;
      }
      HEAP32[$90>>2] = 0;
      $95 = ((($89) + (($i$0100*796)|0)|0) + 16|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = HEAP32[628512>>2]|0;
      HEAP32[$28>>2] = $97;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$28+0>>2]|0;
      invoke_vii(2591,($96|0),($$byval_copy66|0));
      $98 = __THREW__; __THREW__ = 0;
      $99 = $98&1;
      if ($99) {
       break;
      }
      HEAP32[$95>>2] = 0;
      $100 = ((($89) + (($i$0100*796)|0)|0) + 28|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = HEAP32[628512>>2]|0;
      HEAP32[$28>>2] = $102;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$28+0>>2]|0;
      invoke_vii(2591,($101|0),($$byval_copy66|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       break;
      }
      HEAP32[$100>>2] = 0;
      $105 = ((($89) + (($i$0100*796)|0)|0) + 40|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = HEAP32[628512>>2]|0;
      HEAP32[$28>>2] = $107;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$28+0>>2]|0;
      invoke_vii(2591,($106|0),($$byval_copy66|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       break;
      }
      HEAP32[$105>>2] = 0;
      $110 = ((($89) + (($i$0100*796)|0)|0) + 52|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = HEAP32[628512>>2]|0;
      HEAP32[$28>>2] = $112;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$28+0>>2]|0;
      invoke_vii(2591,($111|0),($$byval_copy66|0));
      $113 = __THREW__; __THREW__ = 0;
      $114 = $113&1;
      if ($114) {
       break;
      }
      HEAP32[$110>>2] = 0;
      $115 = HEAP32[$71>>2]|0;
      $116 = ((($115) + (($i$0100*796)|0)|0) + 792|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = ($117|0)==(0|0);
      if (!($118)) {
       __THREW__ = 0;
       $119 = (invoke_i(77)|0);
       $120 = __THREW__; __THREW__ = 0;
       $121 = $120&1;
       if ($121) {
        break;
       }
       $122 = HEAP32[$119>>2]|0;
       $123 = (($122) + 24|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = HEAP32[$71>>2]|0;
       $126 = ((($125) + (($i$0100*796)|0)|0) + 792|0);
       $127 = HEAP32[$126>>2]|0;
       __THREW__ = 0;
       invoke_vii($124|0,($119|0),($127|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        break;
       }
      }
      $130 = (($i$0100) + 1)|0;
      $131 = HEAP32[$45>>2]|0;
      $132 = ($130>>>0)<($131>>>0);
      if ($132) {
       $i$0100 = $130;
      } else {
       break L26;
      }
     }
     $74 = ___cxa_find_matching_catch()|0;
     $75 = tempRet0;
     $lpad$phi$index = $74;$lpad$phi$index3 = $75;
     label = 22;
     break L3;
    }
   } while(0);
   $133 = (($this) + 16|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = HEAP32[628512>>2]|0;
   HEAP32[$27>>2] = $135;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$27+0>>2]|0;
   invoke_vii(2591,($134|0),($$byval_copy66|0));
   $136 = __THREW__; __THREW__ = 0;
   $137 = $136&1;
   if ($137) {
    label = 21;
   } else {
    HEAP32[$133>>2] = 0;
    $138 = (($this) + 28|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = HEAP32[628512>>2]|0;
    HEAP32[$27>>2] = $140;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$27+0>>2]|0;
    invoke_vii(2591,($139|0),($$byval_copy66|0));
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if ($142) {
     label = 21;
    } else {
     HEAP32[$138>>2] = 0;
     $143 = (($this) + 40|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = HEAP32[628512>>2]|0;
     HEAP32[$27>>2] = $145;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$27+0>>2]|0;
     invoke_vii(2591,($144|0),($$byval_copy66|0));
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      label = 21;
     } else {
      HEAP32[$143>>2] = 0;
      $148 = (($this) + 52|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = HEAP32[628512>>2]|0;
      HEAP32[$27>>2] = $150;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$27+0>>2]|0;
      invoke_vii(2591,($149|0),($$byval_copy66|0));
      $151 = __THREW__; __THREW__ = 0;
      $152 = $151&1;
      if ($152) {
       label = 21;
      } else {
       HEAP32[$148>>2] = 0;
       $153 = (($this) + 64|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = HEAP32[628512>>2]|0;
       HEAP32[$27>>2] = $155;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$27+0>>2]|0;
       invoke_vii(2591,($154|0),($$byval_copy66|0));
       $156 = __THREW__; __THREW__ = 0;
       $157 = $156&1;
       if ($157) {
        label = 21;
       } else {
        HEAP32[$153>>2] = 0;
        $158 = (($this) + 1024|0);
        $159 = HEAP32[$158>>2]|0;
        $160 = HEAP32[628512>>2]|0;
        HEAP32[$26>>2] = $160;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$26+0>>2]|0;
        invoke_vii(2591,($159|0),($$byval_copy66|0));
        $161 = __THREW__; __THREW__ = 0;
        $162 = $161&1;
        if ($162) {
         label = 21;
        } else {
         HEAP32[$158>>2] = 0;
         $163 = (($this) + 1064|0);
         $164 = HEAP32[$163>>2]|0;
         $165 = ($164|0)>(-1);
         do {
          if ($165) {
           $166 = (($this) + 1052|0);
           $167 = HEAP32[$166>>2]|0;
           $168 = (($this) + 1056|0);
           $169 = HEAP32[$168>>2]|0;
           HEAP32[$25>>2] = $169;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$25+0>>2]|0;
           invoke_vii(2591,($167|0),($$byval_copy66|0));
           $170 = __THREW__; __THREW__ = 0;
           $171 = $170&1;
           if ($171) {
            $332 = ___cxa_find_matching_catch()|0;
            $333 = tempRet0;
            $$0 = $333;$$01 = $332;
            label = 105;
            break L3;
           } else {
            HEAP32[$166>>2] = 0;
            break;
           }
          }
         } while(0);
         $172 = (($this) + 1048|0);
         $173 = HEAP32[$172>>2]|0;
         $174 = ($173|0)>(-1);
         do {
          if ($174) {
           $175 = (($this) + 1036|0);
           $176 = HEAP32[$175>>2]|0;
           $177 = (($this) + 1040|0);
           $178 = HEAP32[$177>>2]|0;
           HEAP32[$24>>2] = $178;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$24+0>>2]|0;
           invoke_vii(2591,($176|0),($$byval_copy66|0));
           $179 = __THREW__; __THREW__ = 0;
           $180 = $179&1;
           if ($180) {
            $334 = ___cxa_find_matching_catch()|0;
            $335 = tempRet0;
            $$1 = $335;$$17 = $334;
            label = 109;
            break L3;
           } else {
            HEAP32[$175>>2] = 0;
            break;
           }
          }
         } while(0);
         $181 = (($this) + 1020|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = ($182|0)>(-1);
         do {
          if ($183) {
           $184 = (($this) + 1008|0);
           $185 = HEAP32[$184>>2]|0;
           $186 = (($this) + 1012|0);
           $187 = HEAP32[$186>>2]|0;
           HEAP32[$23>>2] = $187;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$23+0>>2]|0;
           invoke_vii(2591,($185|0),($$byval_copy66|0));
           $188 = __THREW__; __THREW__ = 0;
           $189 = $188&1;
           if ($189) {
            $345 = ___cxa_find_matching_catch()|0;
            $346 = tempRet0;
            $$3 = $346;$$39 = $345;
            label = 113;
            break L3;
           } else {
            HEAP32[$184>>2] = 0;
            break;
           }
          }
         } while(0);
         $190 = (($this) + 1004|0);
         $191 = HEAP32[$190>>2]|0;
         $192 = ($191|0)>(-1);
         do {
          if ($192) {
           $193 = (($this) + 992|0);
           $194 = HEAP32[$193>>2]|0;
           $195 = (($this) + 996|0);
           $196 = HEAP32[$195>>2]|0;
           HEAP32[$22>>2] = $196;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$22+0>>2]|0;
           invoke_vii(2591,($194|0),($$byval_copy66|0));
           $197 = __THREW__; __THREW__ = 0;
           $198 = $197&1;
           if ($198) {
            $356 = ___cxa_find_matching_catch()|0;
            $357 = tempRet0;
            $$4 = $357;$$410 = $356;
            label = 117;
            break L3;
           } else {
            HEAP32[$193>>2] = 0;
            break;
           }
          }
         } while(0);
         $199 = (($this) + 988|0);
         $200 = HEAP32[$199>>2]|0;
         $201 = ($200|0)>(-1);
         do {
          if ($201) {
           $202 = (($this) + 976|0);
           $203 = HEAP32[$202>>2]|0;
           $204 = (($this) + 980|0);
           $205 = HEAP32[$204>>2]|0;
           HEAP32[$21>>2] = $205;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$21+0>>2]|0;
           invoke_vii(2591,($203|0),($$byval_copy66|0));
           $206 = __THREW__; __THREW__ = 0;
           $207 = $206&1;
           if ($207) {
            $367 = ___cxa_find_matching_catch()|0;
            $368 = tempRet0;
            $$5 = $368;$$511 = $367;
            label = 120;
            break L3;
           } else {
            HEAP32[$202>>2] = 0;
            break;
           }
          }
         } while(0);
         $208 = (($this) + 964|0);
         $209 = HEAP32[$208>>2]|0;
         $210 = ($209|0)==(0|0);
         do {
          if (!($210)) {
           $211 = (($this) + 968|0);
           $212 = HEAP32[$211>>2]|0;
           $213 = ($212|0)==($209|0);
           do {
            if ($213) {
             $228 = $209;
            } else {
             $215 = $212;
             while(1) {
              $214 = (($215) + -16|0);
              HEAP32[$211>>2] = $214;
              $216 = (($215) + -4|0);
              $217 = HEAP32[$216>>2]|0;
              $218 = ($217|0)>(-1);
              if ($218) {
               $221 = HEAP32[$214>>2]|0;
               $222 = (($215) + -12|0);
               $223 = HEAP32[$222>>2]|0;
               HEAP32[$0>>2] = $223;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
               invoke_vii(2591,($221|0),($$byval_copy66|0));
               $224 = __THREW__; __THREW__ = 0;
               $225 = $224&1;
               if ($225) {
                label = 62;
                break;
               }
               HEAP32[$214>>2] = 0;
               $$pre$i$i$i$i$i = HEAP32[$211>>2]|0;
               $220 = $$pre$i$i$i$i$i;
              } else {
               $220 = $214;
              }
              $219 = ($220|0)==($209|0);
              if ($219) {
               label = 63;
               break;
              } else {
               $215 = $220;
              }
             }
             if ((label|0) == 62) {
              $226 = ___cxa_find_matching_catch()|0;
              $227 = tempRet0;
              ___cxa_call_unexpected(($226|0));
              // unreachable;
             }
             else if ((label|0) == 63) {
              $$pre$i$i$i = HEAP32[$208>>2]|0;
              $228 = $$pre$i$i$i;
              break;
             }
            }
           } while(0);
           HEAP32[$20>>2] = 90;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$20+0>>2]|0;
           invoke_vii(2591,($228|0),($$byval_copy66|0));
           $229 = __THREW__; __THREW__ = 0;
           $230 = $229&1;
           if (!($230)) {
            break;
           }
           $231 = ___cxa_find_matching_catch()|0;
           $232 = tempRet0;
           ___cxa_call_unexpected(($231|0));
           // unreachable;
          }
         } while(0);
         $233 = (($this) + 952|0);
         $234 = HEAP32[$233>>2]|0;
         $235 = ($234|0)==(0|0);
         do {
          if (!($235)) {
           $236 = (($this) + 956|0);
           $237 = HEAP32[$236>>2]|0;
           $238 = ($237|0)==($234|0);
           do {
            if ($238) {
             $253 = $234;
            } else {
             $240 = $237;
             while(1) {
              $239 = (($240) + -16|0);
              HEAP32[$236>>2] = $239;
              $241 = (($240) + -4|0);
              $242 = HEAP32[$241>>2]|0;
              $243 = ($242|0)>(-1);
              if ($243) {
               $246 = HEAP32[$239>>2]|0;
               $247 = (($240) + -12|0);
               $248 = HEAP32[$247>>2]|0;
               HEAP32[$0>>2] = $248;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
               invoke_vii(2591,($246|0),($$byval_copy66|0));
               $249 = __THREW__; __THREW__ = 0;
               $250 = $249&1;
               if ($250) {
                label = 73;
                break;
               }
               HEAP32[$239>>2] = 0;
               $$pre$i$i$i$i$i47 = HEAP32[$236>>2]|0;
               $245 = $$pre$i$i$i$i$i47;
              } else {
               $245 = $239;
              }
              $244 = ($245|0)==($234|0);
              if ($244) {
               label = 74;
               break;
              } else {
               $240 = $245;
              }
             }
             if ((label|0) == 73) {
              $251 = ___cxa_find_matching_catch()|0;
              $252 = tempRet0;
              ___cxa_call_unexpected(($251|0));
              // unreachable;
             }
             else if ((label|0) == 74) {
              $$pre$i$i$i49 = HEAP32[$233>>2]|0;
              $253 = $$pre$i$i$i49;
              break;
             }
            }
           } while(0);
           HEAP32[$19>>2] = 90;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$19+0>>2]|0;
           invoke_vii(2591,($253|0),($$byval_copy66|0));
           $254 = __THREW__; __THREW__ = 0;
           $255 = $254&1;
           if (!($255)) {
            break;
           }
           $256 = ___cxa_find_matching_catch()|0;
           $257 = tempRet0;
           ___cxa_call_unexpected(($256|0));
           // unreachable;
          }
         } while(0);
         $258 = (($this) + 236|0);
         $259 = HEAP32[$258>>2]|0;
         $260 = ($259|0)>(-1);
         do {
          if ($260) {
           $261 = HEAP32[$71>>2]|0;
           $262 = (($this) + 228|0);
           $263 = HEAP32[$262>>2]|0;
           HEAP32[$18>>2] = $263;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$18+0>>2]|0;
           invoke_vii(2591,($261|0),($$byval_copy66|0));
           $264 = __THREW__; __THREW__ = 0;
           $265 = $264&1;
           if ($265) {
            $428 = ___cxa_find_matching_catch()|0;
            $429 = tempRet0;
            $$8 = $429;$$814 = $428;
            label = 147;
            break L3;
           } else {
            HEAP32[$71>>2] = 0;
            break;
           }
          }
         } while(0);
         $266 = (($this) + 220|0);
         $267 = HEAP32[$266>>2]|0;
         $268 = ($267|0)>(-1);
         do {
          if ($268) {
           $269 = (($this) + 208|0);
           $270 = HEAP32[$269>>2]|0;
           $271 = (($this) + 212|0);
           $272 = HEAP32[$271>>2]|0;
           HEAP32[$17>>2] = $272;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$17+0>>2]|0;
           invoke_vii(2591,($270|0),($$byval_copy66|0));
           $273 = __THREW__; __THREW__ = 0;
           $274 = $273&1;
           if ($274) {
            $439 = ___cxa_find_matching_catch()|0;
            $440 = tempRet0;
            $$9 = $440;$$915 = $439;
            label = 151;
            break L3;
           } else {
            HEAP32[$269>>2] = 0;
            break;
           }
          }
         } while(0);
         $275 = (($this) + 204|0);
         $276 = HEAP32[$275>>2]|0;
         $277 = ($276|0)>(-1);
         do {
          if ($277) {
           $278 = (($this) + 192|0);
           $279 = HEAP32[$278>>2]|0;
           $280 = (($this) + 196|0);
           $281 = HEAP32[$280>>2]|0;
           HEAP32[$16>>2] = $281;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$16+0>>2]|0;
           invoke_vii(2591,($279|0),($$byval_copy66|0));
           $282 = __THREW__; __THREW__ = 0;
           $283 = $282&1;
           if ($283) {
            $450 = ___cxa_find_matching_catch()|0;
            $451 = tempRet0;
            $$10 = $451;$$1016 = $450;
            label = 156;
            break L3;
           } else {
            HEAP32[$278>>2] = 0;
            break;
           }
          }
         } while(0);
         $284 = (($this) + 124|0);
         $285 = (($this) + 180|0);
         $286 = HEAP32[$285>>2]|0;
         $287 = ($286|0)>(-1);
         do {
          if ($287) {
           $288 = (($this) + 168|0);
           $289 = HEAP32[$288>>2]|0;
           $290 = (($this) + 172|0);
           $291 = HEAP32[$290>>2]|0;
           HEAP32[$15>>2] = $291;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$15+0>>2]|0;
           invoke_vii(2591,($289|0),($$byval_copy66|0));
           $292 = __THREW__; __THREW__ = 0;
           $293 = $292&1;
           if (!($293)) {
            HEAP32[$288>>2] = 0;
            label = 89;
            break;
           }
           $302 = ___cxa_find_matching_catch()|0;
           $303 = tempRet0;
           $304 = (($this) + 136|0);
           $305 = HEAP32[$304>>2]|0;
           $306 = ($305|0)>(-1);
           if (!($306)) {
            $eh$lpad$body$index10Z2D = $303;$eh$lpad$body$indexZ2D = $302;
            break;
           }
           $307 = HEAP32[$284>>2]|0;
           $308 = (($this) + 128|0);
           $309 = HEAP32[$308>>2]|0;
           HEAP32[$0>>2] = $309;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($307|0),($$byval_copy66|0));
           $310 = __THREW__; __THREW__ = 0;
           $311 = $310&1;
           if ($311) {
            $312 = ___cxa_find_matching_catch(0|0)|0;
            $313 = tempRet0;
            ___clang_call_terminate($312);
            // unreachable;
           } else {
            HEAP32[$284>>2] = 0;
            $eh$lpad$body$index10Z2D = $303;$eh$lpad$body$indexZ2D = $302;
            break;
           }
          } else {
           label = 89;
          }
         } while(0);
         L136: do {
          if ((label|0) == 89) {
           $294 = (($this) + 136|0);
           $295 = HEAP32[$294>>2]|0;
           $296 = ($295|0)>(-1);
           do {
            if ($296) {
             $297 = HEAP32[$284>>2]|0;
             $298 = (($this) + 128|0);
             $299 = HEAP32[$298>>2]|0;
             HEAP32[$14>>2] = $299;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$14+0>>2]|0;
             invoke_vii(2591,($297|0),($$byval_copy66|0));
             $300 = __THREW__; __THREW__ = 0;
             $301 = $300&1;
             if ($301) {
              $461 = ___cxa_find_matching_catch()|0;
              $462 = tempRet0;
              $eh$lpad$body$index10Z2D = $462;$eh$lpad$body$indexZ2D = $461;
              break L136;
             } else {
              HEAP32[$284>>2] = 0;
              break;
             }
            }
           } while(0);
           $314 = (($this) + 120|0);
           $315 = HEAP32[$314>>2]|0;
           $316 = ($315|0)>(-1);
           do {
            if ($316) {
             $317 = (($this) + 108|0);
             $318 = HEAP32[$317>>2]|0;
             $319 = (($this) + 112|0);
             $320 = HEAP32[$319>>2]|0;
             HEAP32[$13>>2] = $320;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$13+0>>2]|0;
             invoke_vii(2591,($318|0),($$byval_copy66|0));
             $321 = __THREW__; __THREW__ = 0;
             $322 = $321&1;
             if ($322) {
              $493 = ___cxa_find_matching_catch()|0;
              $494 = tempRet0;
              $$13 = $494;$$1319 = $493;
              label = 171;
              break L3;
             } else {
              HEAP32[$317>>2] = 0;
              break;
             }
            }
           } while(0);
           $323 = (($this) + 104|0);
           $324 = HEAP32[$323>>2]|0;
           $325 = ($324|0)>(-1);
           if (!($325)) {
            STACKTOP = sp;return;
           }
           $326 = (($this) + 92|0);
           $327 = HEAP32[$326>>2]|0;
           $328 = (($this) + 96|0);
           $329 = HEAP32[$328>>2]|0;
           HEAP32[$0>>2] = $329;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($327|0),($$byval_copy66|0));
           $330 = __THREW__; __THREW__ = 0;
           $331 = $330&1;
           if ($331) {
            $504 = ___cxa_find_matching_catch()|0;
            $505 = tempRet0;
            $$14 = $505;$$1420 = $504;
            ___resumeException($$1420|0);
            // unreachable;
           } else {
            HEAP32[$326>>2] = 0;
            STACKTOP = sp;return;
           }
          }
         } while(0);
         $$12 = $eh$lpad$body$index10Z2D;$$1218 = $eh$lpad$body$indexZ2D;
         label = 167;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  $lpad$phi$index = $78;$lpad$phi$index3 = $79;
  label = 22;
 }
 if ((label|0) == 22) {
  $80 = (($this) + 1064|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)>(-1);
  if ($82) {
   $83 = (($this) + 1052|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($this) + 1056|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$29>>2] = $86;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$29+0>>2]|0;
   invoke_vii(2591,($84|0),($$byval_copy66|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if (!($88)) {
    HEAP32[$83>>2] = 0;
    $$0 = $lpad$phi$index3;$$01 = $lpad$phi$index;
    label = 105;
   }
  } else {
   $$0 = $lpad$phi$index3;$$01 = $lpad$phi$index;
   label = 105;
  }
 }
 if ((label|0) == 105) {
  $336 = (($this) + 1048|0);
  $337 = HEAP32[$336>>2]|0;
  $338 = ($337|0)>(-1);
  if ($338) {
   $339 = (($this) + 1036|0);
   $340 = HEAP32[$339>>2]|0;
   $341 = (($this) + 1040|0);
   $342 = HEAP32[$341>>2]|0;
   HEAP32[$12>>2] = $342;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$12+0>>2]|0;
   invoke_vii(2591,($340|0),($$byval_copy66|0));
   $343 = __THREW__; __THREW__ = 0;
   $344 = $343&1;
   if (!($344)) {
    HEAP32[$339>>2] = 0;
    $$1 = $$0;$$17 = $$01;
    label = 109;
   }
  } else {
   $$1 = $$0;$$17 = $$01;
   label = 109;
  }
 }
 if ((label|0) == 109) {
  $347 = (($this) + 1020|0);
  $348 = HEAP32[$347>>2]|0;
  $349 = ($348|0)>(-1);
  if ($349) {
   $350 = (($this) + 1008|0);
   $351 = HEAP32[$350>>2]|0;
   $352 = (($this) + 1012|0);
   $353 = HEAP32[$352>>2]|0;
   HEAP32[$11>>2] = $353;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$11+0>>2]|0;
   invoke_vii(2591,($351|0),($$byval_copy66|0));
   $354 = __THREW__; __THREW__ = 0;
   $355 = $354&1;
   if (!($355)) {
    HEAP32[$350>>2] = 0;
    $$3 = $$1;$$39 = $$17;
    label = 113;
   }
  } else {
   $$3 = $$1;$$39 = $$17;
   label = 113;
  }
 }
 if ((label|0) == 113) {
  $358 = (($this) + 1004|0);
  $359 = HEAP32[$358>>2]|0;
  $360 = ($359|0)>(-1);
  if ($360) {
   $361 = (($this) + 992|0);
   $362 = HEAP32[$361>>2]|0;
   $363 = (($this) + 996|0);
   $364 = HEAP32[$363>>2]|0;
   HEAP32[$10>>2] = $364;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$10+0>>2]|0;
   invoke_vii(2591,($362|0),($$byval_copy66|0));
   $365 = __THREW__; __THREW__ = 0;
   $366 = $365&1;
   if (!($366)) {
    HEAP32[$361>>2] = 0;
    $$4 = $$3;$$410 = $$39;
    label = 117;
   }
  } else {
   $$4 = $$3;$$410 = $$39;
   label = 117;
  }
 }
 if ((label|0) == 117) {
  $369 = (($this) + 988|0);
  $370 = HEAP32[$369>>2]|0;
  $371 = ($370|0)>(-1);
  if ($371) {
   $372 = (($this) + 976|0);
   $373 = HEAP32[$372>>2]|0;
   $374 = (($this) + 980|0);
   $375 = HEAP32[$374>>2]|0;
   HEAP32[$9>>2] = $375;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($373|0),($$byval_copy66|0));
   $376 = __THREW__; __THREW__ = 0;
   $377 = $376&1;
   if (!($377)) {
    HEAP32[$372>>2] = 0;
    $$5 = $$4;$$511 = $$410;
    label = 120;
   }
  } else {
   $$5 = $$4;$$511 = $$410;
   label = 120;
  }
 }
 if ((label|0) == 120) {
  $378 = (($this) + 964|0);
  $379 = HEAP32[$378>>2]|0;
  $380 = ($379|0)==(0|0);
  if (!($380)) {
   $381 = (($this) + 968|0);
   $382 = HEAP32[$381>>2]|0;
   $383 = ($382|0)==($379|0);
   do {
    if ($383) {
     $398 = $379;
    } else {
     $385 = $382;
     while(1) {
      $384 = (($385) + -16|0);
      HEAP32[$381>>2] = $384;
      $386 = (($385) + -4|0);
      $387 = HEAP32[$386>>2]|0;
      $388 = ($387|0)>(-1);
      if ($388) {
       $391 = HEAP32[$384>>2]|0;
       $392 = (($385) + -12|0);
       $393 = HEAP32[$392>>2]|0;
       HEAP32[$0>>2] = $393;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($391|0),($$byval_copy66|0));
       $394 = __THREW__; __THREW__ = 0;
       $395 = $394&1;
       if ($395) {
        label = 127;
        break;
       }
       HEAP32[$384>>2] = 0;
       $$pre$i$i$i$i$i66 = HEAP32[$381>>2]|0;
       $390 = $$pre$i$i$i$i$i66;
      } else {
       $390 = $384;
      }
      $389 = ($390|0)==($379|0);
      if ($389) {
       label = 128;
       break;
      } else {
       $385 = $390;
      }
     }
     if ((label|0) == 127) {
      $396 = ___cxa_find_matching_catch()|0;
      $397 = tempRet0;
      ___cxa_call_unexpected(($396|0));
      // unreachable;
     }
     else if ((label|0) == 128) {
      $$pre$i$i$i68 = HEAP32[$378>>2]|0;
      $398 = $$pre$i$i$i68;
      break;
     }
    }
   } while(0);
   HEAP32[$8>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$8+0>>2]|0;
   invoke_vii(2591,($398|0),($$byval_copy66|0));
   $399 = __THREW__; __THREW__ = 0;
   $400 = $399&1;
   if ($400) {
    $401 = ___cxa_find_matching_catch()|0;
    $402 = tempRet0;
    ___cxa_call_unexpected(($401|0));
    // unreachable;
   }
  }
  $403 = (($this) + 952|0);
  $404 = HEAP32[$403>>2]|0;
  $405 = ($404|0)==(0|0);
  if (!($405)) {
   $406 = (($this) + 956|0);
   $407 = HEAP32[$406>>2]|0;
   $408 = ($407|0)==($404|0);
   do {
    if ($408) {
     $423 = $404;
    } else {
     $410 = $407;
     while(1) {
      $409 = (($410) + -16|0);
      HEAP32[$406>>2] = $409;
      $411 = (($410) + -4|0);
      $412 = HEAP32[$411>>2]|0;
      $413 = ($412|0)>(-1);
      if ($413) {
       $416 = HEAP32[$409>>2]|0;
       $417 = (($410) + -12|0);
       $418 = HEAP32[$417>>2]|0;
       HEAP32[$0>>2] = $418;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($416|0),($$byval_copy66|0));
       $419 = __THREW__; __THREW__ = 0;
       $420 = $419&1;
       if ($420) {
        label = 138;
        break;
       }
       HEAP32[$409>>2] = 0;
       $$pre$i$i$i$i$i74 = HEAP32[$406>>2]|0;
       $415 = $$pre$i$i$i$i$i74;
      } else {
       $415 = $409;
      }
      $414 = ($415|0)==($404|0);
      if ($414) {
       label = 139;
       break;
      } else {
       $410 = $415;
      }
     }
     if ((label|0) == 138) {
      $421 = ___cxa_find_matching_catch()|0;
      $422 = tempRet0;
      ___cxa_call_unexpected(($421|0));
      // unreachable;
     }
     else if ((label|0) == 139) {
      $$pre$i$i$i76 = HEAP32[$403>>2]|0;
      $423 = $$pre$i$i$i76;
      break;
     }
    }
   } while(0);
   HEAP32[$7>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$7+0>>2]|0;
   invoke_vii(2591,($423|0),($$byval_copy66|0));
   $424 = __THREW__; __THREW__ = 0;
   $425 = $424&1;
   if ($425) {
    $426 = ___cxa_find_matching_catch()|0;
    $427 = tempRet0;
    ___cxa_call_unexpected(($426|0));
    // unreachable;
   }
  }
  $430 = (($this) + 236|0);
  $431 = HEAP32[$430>>2]|0;
  $432 = ($431|0)>(-1);
  if ($432) {
   $433 = (($this) + 224|0);
   $434 = HEAP32[$433>>2]|0;
   $435 = (($this) + 228|0);
   $436 = HEAP32[$435>>2]|0;
   HEAP32[$6>>2] = $436;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$6+0>>2]|0;
   invoke_vii(2591,($434|0),($$byval_copy66|0));
   $437 = __THREW__; __THREW__ = 0;
   $438 = $437&1;
   if (!($438)) {
    HEAP32[$433>>2] = 0;
    $$8 = $$5;$$814 = $$511;
    label = 147;
   }
  } else {
   $$8 = $$5;$$814 = $$511;
   label = 147;
  }
 }
 if ((label|0) == 147) {
  $441 = (($this) + 220|0);
  $442 = HEAP32[$441>>2]|0;
  $443 = ($442|0)>(-1);
  if ($443) {
   $444 = (($this) + 208|0);
   $445 = HEAP32[$444>>2]|0;
   $446 = (($this) + 212|0);
   $447 = HEAP32[$446>>2]|0;
   HEAP32[$5>>2] = $447;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($445|0),($$byval_copy66|0));
   $448 = __THREW__; __THREW__ = 0;
   $449 = $448&1;
   if (!($449)) {
    HEAP32[$444>>2] = 0;
    $$9 = $$8;$$915 = $$814;
    label = 151;
   }
  } else {
   $$9 = $$8;$$915 = $$814;
   label = 151;
  }
 }
 if ((label|0) == 151) {
  $452 = (($this) + 204|0);
  $453 = HEAP32[$452>>2]|0;
  $454 = ($453|0)>(-1);
  if ($454) {
   $455 = (($this) + 192|0);
   $456 = HEAP32[$455>>2]|0;
   $457 = (($this) + 196|0);
   $458 = HEAP32[$457>>2]|0;
   HEAP32[$4>>2] = $458;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($456|0),($$byval_copy66|0));
   $459 = __THREW__; __THREW__ = 0;
   $460 = $459&1;
   if (!($460)) {
    HEAP32[$455>>2] = 0;
    $$10 = $$9;$$1016 = $$915;
    label = 156;
   }
  } else {
   $$10 = $$9;$$1016 = $$915;
   label = 156;
  }
 }
 if ((label|0) == 156) {
  $463 = (($this) + 124|0);
  $464 = (($this) + 180|0);
  $465 = HEAP32[$464>>2]|0;
  $466 = ($465|0)>(-1);
  do {
   if ($466) {
    $467 = (($this) + 168|0);
    $468 = HEAP32[$467>>2]|0;
    $469 = (($this) + 172|0);
    $470 = HEAP32[$469>>2]|0;
    HEAP32[$3>>2] = $470;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($468|0),($$byval_copy66|0));
    $471 = __THREW__; __THREW__ = 0;
    $472 = $471&1;
    if (!($472)) {
     HEAP32[$467>>2] = 0;
     break;
    }
    $481 = ___cxa_find_matching_catch(0|0)|0;
    $482 = tempRet0;
    $483 = (($this) + 136|0);
    $484 = HEAP32[$483>>2]|0;
    $485 = ($484|0)>(-1);
    if (!($485)) {
     $eh$lpad$body92$indexZ2D = $481;
     ___clang_call_terminate($eh$lpad$body92$indexZ2D);
     // unreachable;
    }
    $486 = HEAP32[$463>>2]|0;
    $487 = (($this) + 128|0);
    $488 = HEAP32[$487>>2]|0;
    HEAP32[$0>>2] = $488;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($486|0),($$byval_copy66|0));
    $489 = __THREW__; __THREW__ = 0;
    $490 = $489&1;
    if ($490) {
     $491 = ___cxa_find_matching_catch(0|0)|0;
     $492 = tempRet0;
     ___clang_call_terminate($491);
     // unreachable;
    }
    HEAP32[$463>>2] = 0;
    $eh$lpad$body92$indexZ2D = $481;
    ___clang_call_terminate($eh$lpad$body92$indexZ2D);
    // unreachable;
   }
  } while(0);
  $473 = (($this) + 136|0);
  $474 = HEAP32[$473>>2]|0;
  $475 = ($474|0)>(-1);
  if ($475) {
   $476 = HEAP32[$463>>2]|0;
   $477 = (($this) + 128|0);
   $478 = HEAP32[$477>>2]|0;
   HEAP32[$2>>2] = $478;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($476|0),($$byval_copy66|0));
   $479 = __THREW__; __THREW__ = 0;
   $480 = $479&1;
   if (!($480)) {
    HEAP32[$463>>2] = 0;
    $$12 = $$10;$$1218 = $$1016;
    label = 167;
   }
  } else {
   $$12 = $$10;$$1218 = $$1016;
   label = 167;
  }
 }
 if ((label|0) == 167) {
  $495 = (($this) + 120|0);
  $496 = HEAP32[$495>>2]|0;
  $497 = ($496|0)>(-1);
  if ($497) {
   $498 = (($this) + 108|0);
   $499 = HEAP32[$498>>2]|0;
   $500 = (($this) + 112|0);
   $501 = HEAP32[$500>>2]|0;
   HEAP32[$1>>2] = $501;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($499|0),($$byval_copy66|0));
   $502 = __THREW__; __THREW__ = 0;
   $503 = $502&1;
   if (!($503)) {
    HEAP32[$498>>2] = 0;
    $$13 = $$12;$$1319 = $$1218;
    label = 171;
   }
  } else {
   $$13 = $$12;$$1319 = $$1218;
   label = 171;
  }
 }
 if ((label|0) == 171) {
  $506 = (($this) + 104|0);
  $507 = HEAP32[$506>>2]|0;
  $508 = ($507|0)>(-1);
  if (!($508)) {
   $$14 = $$13;$$1420 = $$1319;
   ___resumeException($$1420|0);
   // unreachable;
  }
  $509 = (($this) + 92|0);
  $510 = HEAP32[$509>>2]|0;
  $511 = (($this) + 96|0);
  $512 = HEAP32[$511>>2]|0;
  HEAP32[$0>>2] = $512;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy66+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($510|0),($$byval_copy66|0));
  $513 = __THREW__; __THREW__ = 0;
  $514 = $513&1;
  if (!($514)) {
   HEAP32[$509>>2] = 0;
   $$14 = $$13;$$1420 = $$1319;
   ___resumeException($$1420|0);
   // unreachable;
  }
 }
 $515 = ___cxa_find_matching_catch(0|0)|0;
 $516 = tempRet0;
 $eh$lpad$body92$indexZ2D = $515;
 ___clang_call_terminate($eh$lpad$body92$indexZ2D);
 // unreachable;
}
function __Z13InitIndexListR9IndexListj($list,$count) {
 $list = $list|0;
 $count = $count|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = $count << 2;
 $2 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Z15malloc_internaljj10MemLabelIdiPKci($1,16,$$byval_copy,0,571384,61)|0);
 HEAP32[$list>>2] = $3;
 $4 = (($list) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($list) + 8|0);
 HEAP32[$5>>2] = $count;
 STACKTOP = sp;return;
}
function __Z16DestroyIndexListR9IndexList($list) {
 $list = $list|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$list>>2]|0;
 $2 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[$list>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19CreateCullingOutputPK16RendererCullDataR13CullingOutput($rendererCullData,$cullingOutput) {
 $rendererCullData = $rendererCullData|0;
 $cullingOutput = $cullingOutput|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 4|0;
 $0 = sp;
 $1 = (($rendererCullData) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 2;
 $4 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__Z15malloc_internaljj10MemLabelIdiPKci($3,16,$$byval_copy4,0,571384,61)|0);
 HEAP32[$cullingOutput>>2] = $5;
 $6 = (($cullingOutput) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($cullingOutput) + 8|0);
 HEAP32[$7>>2] = $2;
 $8 = (($rendererCullData) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 << 2;
 $11 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $11;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 $12 = (__Z15malloc_internaljj10MemLabelIdiPKci($10,16,$$byval_copy4,0,571384,61)|0);
 $13 = (($cullingOutput) + 12|0);
 HEAP32[$13>>2] = $12;
 $14 = (($cullingOutput) + 16|0);
 HEAP32[$14>>2] = 0;
 $15 = (($cullingOutput) + 20|0);
 HEAP32[$15>>2] = $9;
 $16 = (($rendererCullData) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 << 2;
 $19 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $19;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,16,$$byval_copy4,0,571384,61)|0);
 $21 = (($cullingOutput) + 24|0);
 HEAP32[$21>>2] = $20;
 $22 = (($cullingOutput) + 28|0);
 HEAP32[$22>>2] = 0;
 $23 = (($cullingOutput) + 32|0);
 HEAP32[$23>>2] = $17;
 $24 = (($rendererCullData) + 44|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 << 2;
 $27 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $27;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($26,16,$$byval_copy4,0,571384,61)|0);
 $29 = (($cullingOutput) + 36|0);
 HEAP32[$29>>2] = $28;
 $30 = (($cullingOutput) + 40|0);
 HEAP32[$30>>2] = 0;
 $31 = (($cullingOutput) + 44|0);
 HEAP32[$31>>2] = $25;
 $32 = (($rendererCullData) + 56|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 << 2;
 $35 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $35;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 $36 = (__Z15malloc_internaljj10MemLabelIdiPKci($34,16,$$byval_copy4,0,571384,61)|0);
 $37 = (($cullingOutput) + 48|0);
 HEAP32[$37>>2] = $36;
 $38 = (($cullingOutput) + 52|0);
 HEAP32[$38>>2] = 0;
 $39 = (($cullingOutput) + 56|0);
 HEAP32[$39>>2] = $33;
 STACKTOP = sp;return;
}
function __ZN11CullResults4InitEPKN5Umbra4TomeEPK16RendererCullData($this,$tome,$rendererCullData) {
 $this = $this|0;
 $tome = $tome|0;
 $rendererCullData = $rendererCullData|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 __Z19CreateCullingOutputPK16RendererCullDataR13CullingOutput($rendererCullData,$1);
 $2 = ($tome|0)==(0|0);
 if ($2) {
  $11 = (($this) + 80|0);
  HEAP32[$11>>2] = 0;
 } else {
  $3 = (__Z9GetIUmbrav()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$1>>2]|0;
  $8 = HEAP32[628512>>2]|0;
  HEAP32[$0>>2] = $8;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $9 = (FUNCTION_TABLE_iiiii[$6 & 511]($3,$tome,$7,$$byval_copy)|0);
  $10 = (($this) + 80|0);
  HEAP32[$10>>2] = $9;
 }
 $12 = (($this) + 144|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;
 STACKTOP = sp;return;
}
function __Z16SetCullingPlanesR17CullingParametersPK5Planei($parameters,$planes,$planeCount) {
 $parameters = $parameters|0;
 $planes = $planes|0;
 $planeCount = $planeCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($parameters) + 188|0);
 HEAP32[$0>>2] = $planeCount;
 $1 = ($planeCount|0)>(0);
 if ($1) {
  $i$01 = 0;
  while(1) {
   $2 = ((($parameters) + ($i$01<<4)|0) + 28|0);
   $3 = (($planes) + ($i$01<<4)|0);
   ;HEAP32[$2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$3+12>>2]|0;
   $4 = (($i$01) + 1)|0;
   $exitcond = ($4|0)==($planeCount|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $4;
   }
  }
 }
 $5 = (($parameters) + 340|0);
 (__Z22PrepareOptimizedPlanesPK5PlaneiPKN4math7_float4E($planes,$planeCount,$5)|0);
 STACKTOP = sp;return;
}
function __ZN11NamedObjectD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((566840 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if ($1) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   $15 = (($this) + 24|0);
   __THREW__ = 0;
   invoke_vi(3382,($15|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $$0 = $14;$$01 = $13;
    label = 10;
   }
  } else {
   $2 = (($this) + 24|0);
   __THREW__ = 0;
   invoke_vi(3382,($2|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    $$0 = $19;$$01 = $18;
    label = 10;
    break;
   }
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    STACKTOP = sp;return;
   }
   $7 = ___cxa_find_matching_catch()|0;
   $8 = tempRet0;
   __THREW__ = 0;
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $11 = ___cxa_find_matching_catch(0|0)|0;
    $12 = tempRet0;
    ___clang_call_terminate($11);
    // unreachable;
   } else {
    ___resumeException($7|0);
    // unreachable;
   }
  }
 } while(0);
 do {
  if ((label|0) == 10) {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    ___resumeException($$01|0);
    // unreachable;
   }
   $24 = ___cxa_find_matching_catch(0|0)|0;
   $25 = tempRet0;
   __THREW__ = 0;
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $28 = ___cxa_find_matching_catch(0|0)|0;
    $29 = tempRet0;
    ___clang_call_terminate($28);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $24;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 $30 = ___cxa_find_matching_catch(0|0)|0;
 $31 = tempRet0;
 $eh$lpad$body$indexZ2D = $30;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN5Flare6RenderER8Vector3ffRK10ColorRGBAfRK14ChannelAssigns($this,$pos,$visibility,$tintColor,$channels) {
 $this = $this|0;
 $pos = $pos|0;
 $visibility = Math_fround($visibility);
 $tintColor = $tintColor|0;
 $channels = $channels|0;
 var $$ = Math_fround(0), $$0 = Math_fround(0), $$in = 0, $$in$in = Math_fround(0), $$in$in$in = Math_fround(0), $$in37 = 0, $$in37$in = Math_fround(0), $$in37$in$in = Math_fround(0), $$in38 = 0, $$in38$in = Math_fround(0), $$in38$in$in = Math_fround(0), $$off0 = 0, $$off32 = 0, $$op$i$i$i = Math_fround(0), $$op$i$i$i5 = Math_fround(0), $$op$i1$i$i = Math_fround(0), $$op$i1$i$i8 = Math_fround(0), $$op$i2$i$i = Math_fround(0), $$op$i2$i$i7 = Math_fround(0), $$op$i3$i$i = Math_fround(0);
 var $$op$i3$i$i6 = Math_fround(0), $$sink = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0;
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0;
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0;
 var $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0;
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $pos$i$i$i$i = 0, $temp$0$i40 = 0, $vbPtr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $vbPtr = sp + 12|0;
 $2 = (($this) + 52|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $3 == Math_fround(-1.0);
 L1: do {
  if ($4) {
   $5 = (($this) + 40|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0);
   do {
    if (!($7)) {
     HEAP32[$0>>2] = $6;
     $8 = HEAP32[560624>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 11;
     } else {
      $10 = (($8) + 36|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (($8) + 4|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = ($11|0)==($13|0);
      do {
       if ($14) {
        $15 = (($8) + 28|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = (($8) + 32|0);
        $18 = HEAP32[$17>>2]|0;
        $19 = (($16) + ($18<<3)|0);
        $35 = $19;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$8,$0);
        $20 = HEAP32[$pos$i$i$i$i>>2]|0;
        $21 = ($20|0)==(-1);
        $22 = (($8) + 28|0);
        $23 = HEAP32[$22>>2]|0;
        if ($21) {
         $24 = (($8) + 32|0);
         $25 = HEAP32[$24>>2]|0;
         $26 = (($23) + ($25<<3)|0);
         $35 = $26;
         break;
        } else {
         $27 = (($23) + ($20<<3)|0);
         $35 = $27;
         break;
        }
       }
      } while(0);
      $28 = HEAP32[560624>>2]|0;
      $29 = (($28) + 28|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($28) + 32|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($30) + ($32<<3)|0);
      $34 = ($35|0)==($33|0);
      if ($34) {
       label = 11;
      } else {
       $36 = (($35) + 4|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($37|0)==(0|0);
       if ($38) {
        label = 11;
       } else {
        $temp$0$i40 = $37;
       }
      }
     }
     if ((label|0) == 11) {
      $39 = HEAP32[$5>>2]|0;
      $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
      $41 = ($40|0)==(0|0);
      if ($41) {
       break;
      } else {
       $temp$0$i40 = $40;
      }
     }
     $42 = (($temp$0$i40) + 72|0);
     $43 = Math_fround(HEAPF32[$42>>2]);
     $44 = Math_fround($43 * Math_fround(0.5));
     HEAPF32[$2>>2] = $44;
     $45 = (($temp$0$i40) + 76|0);
     $46 = Math_fround(HEAPF32[$45>>2]);
     $47 = Math_fround($46 * Math_fround(0.5));
     $48 = (($this) + 56|0);
     HEAPF32[$48>>2] = $47;
     break L1;
    }
   } while(0);
   HEAPF32[$2>>2] = Math_fround(0.0);
   $49 = (($this) + 56|0);
   HEAPF32[$49>>2] = Math_fround(0.0);
  }
 } while(0);
 $50 = Math_fround(HEAPF32[$pos>>2]);
 $51 = (($pos) + 4|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($50 * $50);
 $54 = Math_fround($52 * $52);
 $55 = Math_fround($53 + $54);
 $56 = Math_fround(HEAPF32[616632>>2]);
 $57 = $55 > $56;
 if ($57) {
  $58 = (Math_fround(Math_sqrt((Math_fround($55)))));
  $59 = Math_fround($50 / $58);
  $60 = Math_fround($52 / $58);
  $61 = (HEAPF32[tempDoublePtr>>2]=$59,HEAP32[tempDoublePtr>>2]|0);
  $62 = (HEAPF32[tempDoublePtr>>2]=$60,HEAP32[tempDoublePtr>>2]|0);
  $$off0 = $61;$$off32 = $62;
 } else {
  HEAPF32[$1>>2] = Math_fround(1.0);
  $63 = (($1) + 4|0);
  HEAPF32[$63>>2] = Math_fround(0.0);
  $64 = $1;
  $65 = $64;
  $66 = HEAP32[$65>>2]|0;
  $67 = (($64) + 4)|0;
  $68 = $67;
  $69 = HEAP32[$68>>2]|0;
  $$off0 = $66;$$off32 = $69;
 }
 $70 = (HEAP32[tempDoublePtr>>2]=$$off0,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $71 = (HEAP32[tempDoublePtr>>2]=$$off32,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $72 = (($this) + 48|0);
 $73 = HEAP8[$72>>0]|0;
 $74 = ($73<<24>>24)==(0);
 if ($74) {
  $$0 = $visibility;
 } else {
  $75 = (__Z17GetRenderSettingsv()|0);
  $76 = (($pos) + 8|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = (Math_fround(__ZNK14RenderSettings13CalcFogFactorEf($75,$77)));
  $79 = Math_fround(Math_fround(1.0) - $78);
  $80 = Math_fround($79 * $visibility);
  $$0 = $80;
 }
 $81 = (($this) + 32|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($this) + 28|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = $82;
 $86 = $84;
 $87 = (($85) - ($86))|0;
 $88 = (__Z12GetGfxDevicev()|0);
 $89 = (__ZN9GfxDevice13GetDynamicVBOEv($88)|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = (($90) + 8|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = $87 >> 3;
 $94 = (FUNCTION_TABLE_iiiiiiii[$92 & 127]($89,24,$93,0,2,$vbPtr,0)|0);
 if (!($94)) {
  STACKTOP = sp;return;
 }
 $95 = HEAP32[$81>>2]|0;
 $96 = HEAP32[$83>>2]|0;
 $97 = ($96|0)==($95|0);
 if (!($97)) {
  $98 = (($this) + 44|0);
  $99 = (($this) + 56|0);
  $100 = (($pos) + 8|0);
  $101 = (($tintColor) + 4|0);
  $102 = (($tintColor) + 8|0);
  $103 = (($tintColor) + 12|0);
  $104 = Math_fround($$0 * Math_fround(0.00999999977648258209228));
  $107 = $96;
  while(1) {
   $105 = HEAP32[$98>>2]|0;
   $106 = HEAP32[$107>>2]|0;
   do {
    if ((($105|0) == 1)) {
     if ((($106|0) == 2)) {
      $146 = Math_fround(HEAPF32[$2>>2]);
      $147 = Math_fround(Math_fround(0.5) - $146);
      $148 = Math_fround(HEAPF32[$99>>2]);
      $149 = Math_fround(Math_fround(1.0) - $148);
      $197 = Math_fround(0.75);$199 = $149;$337 = $147;$346 = Math_fround(0.0);
      break;
     } else if ((($106|0) == 1)) {
      $142 = Math_fround(HEAPF32[$2>>2]);
      $143 = Math_fround(Math_fround(0.5) - $142);
      $144 = Math_fround(HEAPF32[$99>>2]);
      $145 = Math_fround(Math_fround(0.75) - $144);
      $197 = Math_fround(0.5);$199 = $145;$337 = $143;$346 = Math_fround(0.0);
      break;
     } else if ((($106|0) == 0)) {
      $138 = Math_fround(HEAPF32[$2>>2]);
      $139 = Math_fround(Math_fround(1.0) - $138);
      $140 = Math_fround(HEAPF32[$99>>2]);
      $141 = Math_fround(Math_fround(0.5) - $140);
      $197 = Math_fround(0.0);$199 = $141;$337 = $139;$346 = Math_fround(0.0);
      break;
     } else {
      $150 = (($106) + -3)|0;
      $151 = $150 & 1;
      $152 = $150 >> 1;
      $153 = (Math_fround(($151|0)));
      $154 = Math_fround($153 * Math_fround(0.25));
      $155 = Math_fround($154 + Math_fround(0.5));
      $156 = (Math_fround(($152|0)));
      $157 = Math_fround($156 * Math_fround(0.25));
      $158 = Math_fround($157 * Math_fround(0.5));
      $159 = Math_fround($158 + Math_fround(0.5));
      $160 = Math_fround(HEAPF32[$2>>2]);
      $161 = Math_fround($155 + $160);
      $162 = Math_fround(HEAPF32[$99>>2]);
      $163 = Math_fround($159 + $162);
      $164 = (($151) + 1)|0;
      $165 = (Math_fround(($164|0)));
      $166 = Math_fround($165 * Math_fround(0.25));
      $167 = Math_fround($166 + Math_fround(0.5));
      $168 = (($152) + 1)|0;
      $169 = (Math_fround(($168|0)));
      $170 = Math_fround($169 * Math_fround(0.25));
      $171 = Math_fround($170 * Math_fround(0.5));
      $172 = Math_fround($171 + Math_fround(0.5));
      $173 = Math_fround($167 - $160);
      $174 = Math_fround($172 - $162);
      $197 = $163;$199 = $174;$337 = $173;$346 = $161;
      break;
     }
    } else if ((($105|0) == 0)) {
     $108 = ($106|0)==(0);
     if ($108) {
      $132 = Math_fround(HEAPF32[$2>>2]);
      $133 = Math_fround($132 + Math_fround(0.0));
      $134 = Math_fround(HEAPF32[$99>>2]);
      $135 = Math_fround($134 + Math_fround(0.0));
      $136 = Math_fround(Math_fround(1.0) - $132);
      $137 = Math_fround(Math_fround(0.5) - $134);
      $197 = $135;$199 = $137;$337 = $136;$346 = $133;
      break;
     } else {
      $109 = (($106) + -1)|0;
      $110 = $109 & 1;
      $111 = $109 >> 1;
      $112 = (Math_fround(($110|0)));
      $113 = Math_fround($112 * Math_fround(0.5));
      $114 = (Math_fround(($111|0)));
      $115 = Math_fround($114 * Math_fround(0.5));
      $116 = Math_fround($115 * Math_fround(0.5));
      $117 = Math_fround($116 + Math_fround(0.5));
      $118 = Math_fround(HEAPF32[$2>>2]);
      $119 = Math_fround($113 + $118);
      $120 = Math_fround(HEAPF32[$99>>2]);
      $121 = Math_fround($117 + $120);
      $122 = (($110) + 1)|0;
      $123 = (Math_fround(($122|0)));
      $124 = Math_fround($123 * Math_fround(0.5));
      $125 = (($111) + 1)|0;
      $126 = (Math_fround(($125|0)));
      $127 = Math_fround($126 * Math_fround(0.5));
      $128 = Math_fround($127 * Math_fround(0.5));
      $129 = Math_fround($128 + Math_fround(0.5));
      $130 = Math_fround($124 - $118);
      $131 = Math_fround($129 - $120);
      $197 = $121;$199 = $131;$337 = $130;$346 = $119;
      break;
     }
    } else {
     $175 = (($105) + -1)|0;
     $176 = (($106|0) % ($175|0))&-1;
     $177 = (($106|0) / ($175|0))&-1;
     $178 = (Math_fround(($175|0)));
     $179 = Math_fround(Math_fround(1.0) / $178);
     $180 = (Math_fround(($176|0)));
     $181 = Math_fround($180 * $179);
     $182 = (Math_fround(($177|0)));
     $183 = Math_fround($182 * $179);
     $184 = Math_fround(HEAPF32[$2>>2]);
     $185 = Math_fround($181 + $184);
     $186 = Math_fround(HEAPF32[$99>>2]);
     $187 = Math_fround($183 + $186);
     $188 = (($176) + 1)|0;
     $189 = (Math_fround(($188|0)));
     $190 = Math_fround($189 * $179);
     $191 = (($177) + 1)|0;
     $192 = (Math_fround(($191|0)));
     $193 = Math_fround($179 * $192);
     $194 = Math_fround($190 - $184);
     $195 = Math_fround($193 - $186);
     $197 = $187;$199 = $195;$337 = $194;$346 = $185;
    }
   } while(0);
   $196 = Math_fround(Math_fround(1.0) - $197);
   $198 = Math_fround(Math_fround(1.0) - $199);
   $200 = (($107) + 8|0);
   $201 = Math_fround(HEAPF32[$200>>2]);
   $202 = Math_fround(HEAPF32[$100>>2]);
   $203 = Math_fround($201 * $202);
   $204 = (($107) + 30|0);
   $205 = HEAP8[$204>>0]|0;
   $206 = ($205<<24>>24)==(0);
   $$ = $206 ? Math_fround(0.00999999977648258209228) : $104;
   $207 = Math_fround($203 * $$);
   $208 = (($107) + 29|0);
   $209 = HEAP8[$208>>0]|0;
   $210 = ($209<<24>>24)==(0);
   if ($210) {
    $317 = $207;$319 = $207;
   } else {
    $211 = Math_fround($207 * Math_fround(1.39999997615814208984));
    $212 = Math_fround($70 * $211);
    $213 = Math_fround($71 * $211);
    $317 = $212;$319 = $213;
   }
   $214 = (($107) + 4|0);
   $215 = Math_fround(HEAPF32[$214>>2]);
   $216 = Math_fround($215 * Math_fround(0.0));
   $217 = Math_fround($202 * $215);
   $218 = Math_fround(Math_fround(1.0) - $215);
   $219 = Math_fround(HEAPF32[$pos>>2]);
   $220 = Math_fround($218 * $219);
   $221 = Math_fround(HEAPF32[$51>>2]);
   $222 = Math_fround($218 * $221);
   $223 = Math_fround($202 * $218);
   $224 = Math_fround($216 + $220);
   $225 = Math_fround($216 + $222);
   $226 = Math_fround($217 + $223);
   $227 = (($107) + 28|0);
   $228 = HEAP8[$227>>0]|0;
   $229 = ($228<<24>>24)==(0);
   $230 = (($107) + 12|0);
   $231 = Math_fround(HEAPF32[$230>>2]);
   if ($229) {
    $232 = Math_fround($$0 * $231);
    $233 = (($107) + 16|0);
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = Math_fround($$0 * $234);
    $236 = (($107) + 20|0);
    $237 = Math_fround(HEAPF32[$236>>2]);
    $238 = Math_fround($$0 * $237);
    $239 = (($107) + 24|0);
    $240 = Math_fround(HEAPF32[$239>>2]);
    $241 = Math_fround($$0 * $240);
    $242 = $232 < Math_fround(0.0);
    $243 = $242 ? Math_fround(0.0) : $232;
    $244 = $243 > Math_fround(1.0);
    $$op$i$i$i5 = Math_fround($243 * Math_fround(255.0));
    $245 = $244 ? Math_fround(255.0) : $$op$i$i$i5;
    $246 = $235 < Math_fround(0.0);
    $247 = $246 ? Math_fround(0.0) : $235;
    $248 = $247 > Math_fround(1.0);
    $$op$i3$i$i6 = Math_fround($247 * Math_fround(255.0));
    $249 = $248 ? Math_fround(255.0) : $$op$i3$i$i6;
    $250 = $238 < Math_fround(0.0);
    $251 = $250 ? Math_fround(0.0) : $238;
    $252 = $251 > Math_fround(1.0);
    $$op$i2$i$i7 = Math_fround($251 * Math_fround(255.0));
    $253 = $252 ? Math_fround(255.0) : $$op$i2$i$i7;
    $254 = $241 < Math_fround(0.0);
    $255 = $254 ? Math_fround(0.0) : $241;
    $256 = $255 > Math_fround(1.0);
    $$op$i1$i$i8 = Math_fround($255 * Math_fround(255.0));
    $257 = $256 ? Math_fround(255.0) : $$op$i1$i$i8;
    $$in$in$in = $253;$$in37$in$in = $249;$$in38$in$in = $245;$$sink = $257;
   } else {
    $258 = (($107) + 16|0);
    $259 = Math_fround(HEAPF32[$258>>2]);
    $260 = (($107) + 20|0);
    $261 = Math_fround(HEAPF32[$260>>2]);
    $262 = (($107) + 24|0);
    $263 = Math_fround(HEAPF32[$262>>2]);
    $264 = Math_fround(HEAPF32[$tintColor>>2]);
    $265 = Math_fround($231 * $264);
    $266 = Math_fround(HEAPF32[$101>>2]);
    $267 = Math_fround($259 * $266);
    $268 = Math_fround(HEAPF32[$102>>2]);
    $269 = Math_fround($261 * $268);
    $270 = Math_fround(HEAPF32[$103>>2]);
    $271 = Math_fround($263 * $270);
    $272 = (($107) + 31|0);
    $273 = HEAP8[$272>>0]|0;
    $274 = ($273<<24>>24)==(0);
    if ($274) {
     $280 = $265;$285 = $267;$290 = $269;$295 = $271;
    } else {
     $275 = Math_fround($$0 * $265);
     $276 = Math_fround($$0 * $267);
     $277 = Math_fround($$0 * $269);
     $278 = Math_fround($$0 * $271);
     $280 = $275;$285 = $276;$290 = $277;$295 = $278;
    }
    $279 = $280 < Math_fround(0.0);
    $281 = $279 ? Math_fround(0.0) : $280;
    $282 = $281 > Math_fround(1.0);
    $$op$i$i$i = Math_fround($281 * Math_fround(255.0));
    $283 = $282 ? Math_fround(255.0) : $$op$i$i$i;
    $284 = $285 < Math_fround(0.0);
    $286 = $284 ? Math_fround(0.0) : $285;
    $287 = $286 > Math_fround(1.0);
    $$op$i3$i$i = Math_fround($286 * Math_fround(255.0));
    $288 = $287 ? Math_fround(255.0) : $$op$i3$i$i;
    $289 = $290 < Math_fround(0.0);
    $291 = $289 ? Math_fround(0.0) : $290;
    $292 = $291 > Math_fround(1.0);
    $$op$i2$i$i = Math_fround($291 * Math_fround(255.0));
    $293 = $292 ? Math_fround(255.0) : $$op$i2$i$i;
    $294 = $295 < Math_fround(0.0);
    $296 = $294 ? Math_fround(0.0) : $295;
    $297 = $296 > Math_fround(1.0);
    $$op$i1$i$i = Math_fround($296 * Math_fround(255.0));
    $298 = $297 ? Math_fround(255.0) : $$op$i1$i$i;
    $$in$in$in = $293;$$in37$in$in = $288;$$in38$in$in = $283;$$sink = $298;
   }
   $$in38$in = Math_fround($$in38$in$in + Math_fround(0.5));
   $$in37$in = Math_fround($$in37$in$in + Math_fround(0.5));
   $$in$in = Math_fround($$in$in$in + Math_fround(0.5));
   $$in38 = (~~(($$in38$in))>>>0);
   $$in37 = (~~(($$in37$in))>>>0);
   $$in = (~~(($$in$in))>>>0);
   $299 = Math_fround($$sink + Math_fround(0.5));
   $300 = (~~(($299))>>>0);
   $301 = HEAP8[((640792 + 258|0))>>0]|0;
   $302 = ($301<<24>>24)==(0);
   if ($302) {
    $303 = $300 << 24;
    $304 = $$in << 16;
    $305 = $304 & 16711680;
    $306 = $305 | $303;
    $307 = $$in37 << 8;
    $308 = $307 & 65280;
    $309 = $306 | $308;
    $310 = $$in38 & 255;
    $311 = $309 | $310;
    $312 = $309 >>> 8;
    $313 = $306 >>> 16;
    $314 = $300 & 255;
    $324 = $314;$326 = $313;$330 = $312;$334 = $311;
   } else {
    $324 = $300;$326 = $$in38;$330 = $$in37;$334 = $$in;
   }
   $315 = HEAP32[$vbPtr>>2]|0;
   $316 = Math_fround($224 - $317);
   $318 = Math_fround($225 - $319);
   HEAPF32[$315>>2] = $316;
   $320 = (($315) + 4|0);
   HEAPF32[$320>>2] = $318;
   $321 = (($315) + 8|0);
   HEAPF32[$321>>2] = $226;
   $322 = (($315) + 12|0);
   $323 = $324 << 24;
   $325 = $326 << 16;
   $327 = $325 & 16711680;
   $328 = $327 | $323;
   $329 = $330 << 8;
   $331 = $329 & 65280;
   $332 = $328 | $331;
   $333 = $334 & 255;
   $335 = $332 | $333;
   HEAP32[$322>>2] = $335;
   $336 = (($315) + 16|0);
   HEAPF32[$336>>2] = $337;
   $338 = (($315) + 20|0);
   HEAPF32[$338>>2] = $196;
   $339 = Math_fround($319 + $224);
   $340 = Math_fround($225 - $317);
   $341 = (($315) + 24|0);
   HEAPF32[$341>>2] = $339;
   $342 = (($315) + 28|0);
   HEAPF32[$342>>2] = $340;
   $343 = (($315) + 32|0);
   HEAPF32[$343>>2] = $226;
   $344 = (($315) + 36|0);
   HEAP32[$344>>2] = $335;
   $345 = (($315) + 40|0);
   HEAPF32[$345>>2] = $346;
   $347 = (($315) + 44|0);
   HEAPF32[$347>>2] = $196;
   $348 = Math_fround($317 + $224);
   $349 = Math_fround($319 + $225);
   $350 = (($315) + 48|0);
   HEAPF32[$350>>2] = $348;
   $351 = (($315) + 52|0);
   HEAPF32[$351>>2] = $349;
   $352 = (($315) + 56|0);
   HEAPF32[$352>>2] = $226;
   $353 = (($315) + 60|0);
   HEAP32[$353>>2] = $335;
   $354 = (($315) + 64|0);
   HEAPF32[$354>>2] = $346;
   $355 = (($315) + 68|0);
   HEAPF32[$355>>2] = $198;
   $356 = Math_fround($224 - $319);
   $357 = Math_fround($317 + $225);
   $358 = (($315) + 72|0);
   HEAPF32[$358>>2] = $356;
   $359 = (($315) + 76|0);
   HEAPF32[$359>>2] = $357;
   $360 = (($315) + 80|0);
   HEAPF32[$360>>2] = $226;
   $361 = (($315) + 84|0);
   HEAP32[$361>>2] = $335;
   $362 = (($315) + 88|0);
   HEAPF32[$362>>2] = $337;
   $363 = (($315) + 92|0);
   HEAPF32[$363>>2] = $198;
   $364 = (($315) + 96|0);
   HEAP32[$vbPtr>>2] = $364;
   $365 = (($107) + 32|0);
   $366 = ($365|0)==($95|0);
   if ($366) {
    break;
   } else {
    $107 = $365;
   }
  }
 }
 $367 = HEAP32[$89>>2]|0;
 $368 = (($367) + 12|0);
 $369 = HEAP32[$368>>2]|0;
 FUNCTION_TABLE_viii[$369 & 4095]($89,$93,0);
 $370 = HEAP32[$89>>2]|0;
 $371 = (($370) + 16|0);
 $372 = HEAP32[$371>>2]|0;
 $373 = (($channels) + 4|0);
 $374 = HEAP32[$373>>2]|0;
 $375 = HEAP32[571424>>2]|0;
 $376 = ($375|0)==(0|0);
 if ($376) {
  $377 = (__Z26GetMeshVertexFormatManagerv()|0);
  $378 = HEAP32[571416>>2]|0;
  $379 = (__ZN23MeshVertexFormatManager10GetDefaultEj($377,$378)|0);
  HEAP32[571424>>2] = $379;
  $380 = $379;
 } else {
  $380 = $375;
 }
 $381 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($380,$374,0)|0);
 FUNCTION_TABLE_viii[$372 & 4095]($89,$channels,$381);
 STACKTOP = sp;return;
}
function __ZN12FlareManager3GetEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[571440>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $3 = (__Z15GetScriptMapperv()|0);
   $4 = (__Znwj(32)|0);
   $5 = (($0) + 8|0);
   HEAP32[$5>>2] = $4;
   HEAP32[$0>>2] = 33;
   $6 = (($0) + 4|0);
   HEAP32[$6>>2] = 21;
   dest=$4+0|0; src=571448+0|0; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $7 = (($4) + 21|0);
   HEAP8[$7>>0] = 0;
   __THREW__ = 0;
   $8 = (invoke_iii(2366,($3|0),($0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $17 = ___cxa_find_matching_catch()|0;
    $18 = tempRet0;
    $19 = HEAP8[$0>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     ___resumeException($17|0);
     // unreachable;
    }
    $22 = HEAP32[$5>>2]|0;
    __ZdlPv($22);
    ___resumeException($17|0);
    // unreachable;
   } else {
    $11 = HEAP8[$0>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = HEAP32[$5>>2]|0;
     __ZdlPv($14);
    }
    $15 = ($8|0)==(0|0);
    if ($15) {
     break;
    }
    $16 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($8,61,0)|0);
    HEAP32[571440>>2] = $16;
    break;
   }
  }
 } while(0);
 $23 = HEAP32[571432>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $30 = $23;
  STACKTOP = sp;return ($30|0);
 }
 $25 = (__Znwj(24)|0);
 $26 = (($25) + 4|0);
 ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;HEAP32[$25+16>>2]=0|0;
 HEAP32[$25>>2] = $26;
 $27 = (($25) + 12|0);
 HEAP32[$27>>2] = 0;
 $28 = (($25) + 16|0);
 HEAP32[$28>>2] = 0;
 $29 = (($25) + 20|0);
 HEAP32[$29>>2] = 0;
 HEAP32[571432>>2] = $25;
 $30 = $25;
 STACKTOP = sp;return ($30|0);
}
function __ZN12FlareManager8AddFlareEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i2 = 0, $$0$i$i$i6 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$01$i$i$i = 0, $$01$i$i$i4 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $index$017 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($4|0)==($3|0);
 L1: do {
  if (!($5)) {
   $7 = $4;$index$017 = 0;
   while(1) {
    $6 = (($7) + 49|0);
    $8 = HEAP8[$6>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     break;
    }
    $27 = (($7) + 52|0);
    $28 = (($index$017) + 1)|0;
    $29 = ($27|0)==($3|0);
    if ($29) {
     break L1;
    } else {
     $7 = $27;$index$017 = $28;
    }
   }
   HEAP8[$6>>0] = 1;
   $10 = HEAP32[$this>>2]|0;
   $11 = (($this) + 4|0);
   $12 = ($10|0)==($11|0);
   if ($12) {
    $$0 = $index$017;
    STACKTOP = sp;return ($$0|0);
   } else {
    $14 = $10;
   }
   while(1) {
    $13 = (($14) + 20|0);
    $15 = HEAP32[$13>>2]|0;
    $16 = (($15) + ($index$017<<2)|0);
    HEAPF32[$16>>2] = Math_fround(0.0);
    $17 = (($14) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $$01$i$i$i4 = $14;
     while(1) {
      $22 = (($$01$i$i$i4) + 8|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24|0)==($$01$i$i$i4|0);
      if ($25) {
       $$0$i$i$i6 = $23;
       break;
      } else {
       $$01$i$i$i4 = $23;
      }
     }
    } else {
     $$0$i$i$i$i2 = $18;
     while(1) {
      $20 = HEAP32[$$0$i$i$i$i2>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       $$0$i$i$i6 = $$0$i$i$i$i2;
       break;
      } else {
       $$0$i$i$i$i2 = $20;
      }
     }
    }
    $26 = ($$0$i$i$i6|0)==($11|0);
    if ($26) {
     $$0 = $index$017;
     break;
    } else {
     $14 = $$0$i$i$i6;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $30 = $3;
 $31 = $4;
 $32 = (($30) - ($31))|0;
 $33 = (($32|0) / 52)&-1;
 $34 = (($0) + 16|0);
 $35 = (($0) + 32|0);
 ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
 HEAP32[$35>>2] = -1;
 $36 = (($0) + 36|0);
 HEAP32[$36>>2] = -1;
 $37 = (($0) + 40|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($0) + 44|0);
 HEAPF32[$38>>2] = Math_fround(3.0);
 $39 = (($0) + 48|0);
 HEAP8[$39>>0] = 0;
 $40 = (($0) + 49|0);
 HEAP8[$40>>0] = 1;
 $41 = (($this) + 20|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($3|0)==($42|0);
 if ($43) {
  __ZNSt3__16vectorIN12FlareManager10FlareEntryENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1,$0);
 } else {
  $44 = ($3|0)==(0|0);
  if ($44) {
   $48 = 0;
  } else {
   ;HEAP32[$3+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$3+24>>2]=HEAP32[$0+24>>2]|0;
   $45 = (($3) + 28|0);
   HEAP32[$45>>2] = 0;
   $46 = (($3) + 32|0);
   ;HEAP32[$46+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$46+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$46+12>>2]=HEAP32[$35+12>>2]|0;HEAP16[$46+16>>1]=HEAP16[$35+16>>1]|0;
   $$pre$i = HEAP32[$2>>2]|0;
   $48 = $$pre$i;
  }
  $47 = (($48) + 52|0);
  HEAP32[$2>>2] = $47;
 }
 $49 = HEAP32[$this>>2]|0;
 $50 = (($this) + 4|0);
 $51 = ($49|0)==($50|0);
 if ($51) {
  $$0 = $33;
  STACKTOP = sp;return ($$0|0);
 } else {
  $53 = $49;
 }
 while(1) {
  $52 = (($53) + 24|0);
  $54 = HEAP32[$52>>2]|0;
  $55 = (($53) + 28|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($54|0)==($56|0);
  if ($57) {
   $60 = (($53) + 20|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $54;
   $63 = $61;
   $64 = (($62) - ($63))|0;
   $65 = $64 >> 2;
   $66 = (($65) + 1)|0;
   $67 = ($66>>>0)>(1073741823);
   if ($67) {
    label = 21;
    break;
   }
   $68 = ($65>>>0)<(536870911);
   if ($68) {
    $69 = $64 >> 1;
    $70 = ($69>>>0)<($66>>>0);
    $71 = $70 ? $66 : $69;
    $72 = ($71|0)==(0);
    if ($72) {
     $$0$i3$i$i = 0;$76 = 0;
    } else {
     $$0$i2$i$i = $71;
     label = 24;
    }
   } else {
    $$0$i2$i$i = 1073741823;
    label = 24;
   }
   if ((label|0) == 24) {
    label = 0;
    $73 = $$0$i2$i$i << 2;
    $74 = (__Znwj($73)|0);
    $$0$i3$i$i = $$0$i2$i$i;$76 = $74;
   }
   $75 = (($76) + ($65<<2)|0);
   $77 = (($76) + ($$0$i3$i$i<<2)|0);
   $78 = ($75|0)==(0|0);
   if (!($78)) {
    HEAPF32[$75>>2] = Math_fround(0.0);
   }
   $79 = (($76) + ($66<<2)|0);
   _memcpy(($76|0),($61|0),($64|0))|0;
   HEAP32[$60>>2] = $76;
   HEAP32[$52>>2] = $79;
   HEAP32[$55>>2] = $77;
   $80 = ($61|0)==(0|0);
   if (!($80)) {
    __ZdlPv($61);
   }
  } else {
   $58 = ($54|0)==(0|0);
   if (!($58)) {
    HEAPF32[$54>>2] = Math_fround(0.0);
   }
   $59 = (($54) + 4|0);
   HEAP32[$52>>2] = $59;
  }
  $81 = (($53) + 4|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(0|0);
  if ($83) {
   $$01$i$i$i = $53;
   while(1) {
    $86 = (($$01$i$i$i) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==($$01$i$i$i|0);
    if ($89) {
     $$0$i$i$i = $87;
     break;
    } else {
     $$01$i$i$i = $87;
    }
   }
  } else {
   $$0$i$i$i$i = $82;
   while(1) {
    $84 = HEAP32[$$0$i$i$i$i>>2]|0;
    $85 = ($84|0)==(0|0);
    if ($85) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $84;
    }
   }
  }
  $90 = ($$0$i$i$i|0)==($50|0);
  if ($90) {
   $$0 = $33;
   label = 34;
   break;
  } else {
   $53 = $$0$i$i$i;
  }
 }
 if ((label|0) == 21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 34) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN12FlareManager11UpdateFlareEiP5FlareRK8Vector3fbfRK10ColorRGBAffjj($this,$handle,$flare,$position,$infinite,$brightness,$color,$fadeSpeed,$layers,$ignoredLayers) {
 $this = $this|0;
 $handle = $handle|0;
 $flare = $flare|0;
 $position = $position|0;
 $infinite = $infinite|0;
 $brightness = Math_fround($brightness);
 $color = $color|0;
 $fadeSpeed = Math_fround($fadeSpeed);
 $layers = $layers|0;
 $ignoredLayers = $ignoredLayers|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + (($handle*52)|0)|0) + 16|0);
 ;HEAP32[$2+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$position+8>>2]|0;
 $3 = ((($1) + (($handle*52)|0)|0) + 28|0);
 $4 = ($flare|0)==(0|0);
 if ($4) {
  HEAP32[$3>>2] = 0;
 } else {
  $5 = (($flare) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$3>>2] = $6;
 }
 $7 = ((($1) + (($handle*52)|0)|0) + 48|0);
 $8 = $infinite&1;
 HEAP8[$7>>0] = $8;
 $9 = ((($1) + (($handle*52)|0)|0) + 40|0);
 HEAPF32[$9>>2] = $brightness;
 $10 = Math_fround(HEAPF32[$color>>2]);
 $11 = (($color) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($color) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($color) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($1) + (($handle*52)|0)|0);
 HEAPF32[$17>>2] = $10;
 $18 = ((($1) + (($handle*52)|0)|0) + 4|0);
 HEAPF32[$18>>2] = $12;
 $19 = ((($1) + (($handle*52)|0)|0) + 8|0);
 HEAPF32[$19>>2] = $14;
 $20 = ((($1) + (($handle*52)|0)|0) + 12|0);
 HEAPF32[$20>>2] = $16;
 $21 = ((($1) + (($handle*52)|0)|0) + 44|0);
 HEAPF32[$21>>2] = $fadeSpeed;
 $22 = ((($1) + (($handle*52)|0)|0) + 32|0);
 HEAP32[$22>>2] = $layers;
 $23 = ((($1) + (($handle*52)|0)|0) + 36|0);
 HEAP32[$23>>2] = $ignoredLayers;
 STACKTOP = sp;return;
}
function __ZN12FlareManager11DeleteFlareEi($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + (($handle*52)|0)|0) + 49|0);
 HEAP8[$2>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN12FlareManager9AddCameraER6Camera($this,$camera) {
 $this = $this|0;
 $camera = $camera|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 HEAP32[$0>>2] = $camera;
 $4 = (__ZNSt3__13mapIPK6CameraNS_6vectorIfNS_9allocatorIfEEEENS_4lessIS3_EENS5_INS_4pairIKS3_S7_EEEEEixERSB_($this,$0)|0);
 HEAP32[$1>>2] = 0;
 $5 = (($1) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($1) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = ($4|0)==($1|0);
 do {
  if (!($7)) {
   __THREW__ = 0;
   invoke_viii(1677,($4|0),(0|0),(0|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $$pre = HEAP32[$1>>2]|0;
    $10 = ($$pre|0)==(0|0);
    if ($10) {
     break;
    }
    $11 = HEAP32[$5>>2]|0;
    $12 = ($11|0)==($$pre|0);
    if (!($12)) {
     $__new_last2$i$i$i$i$i1 = $$pre;
     $scevgep$i$i$i$i$i2 = (($11) + -4|0);
     $13 = (0 - ($__new_last2$i$i$i$i$i1))|0;
     $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($13)|0);
     $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
     $14 = $uglygep3$i$i$i$i$i5 >>> 2;
     $15 = $14 ^ -1;
     $scevgep4$i$i$i$i$i6 = (($11) + ($15<<2)|0);
     HEAP32[$5>>2] = $scevgep4$i$i$i$i$i6;
    }
    __ZdlPv($$pre);
    break;
   }
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $42 = HEAP32[$1>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    ___resumeException($40|0);
    // unreachable;
   }
   $44 = HEAP32[$5>>2]|0;
   $45 = ($44|0)==($42|0);
   if (!($45)) {
    $__new_last2$i$i$i$i$i = $42;
    $scevgep$i$i$i$i$i = (($44) + -4|0);
    $46 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($46)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $47 = $uglygep3$i$i$i$i$i >>> 2;
    $48 = $47 ^ -1;
    $scevgep4$i$i$i$i$i = (($44) + ($48<<2)|0);
    HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($42);
   ___resumeException($40|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$2>>2] = $camera;
 $16 = (__ZNSt3__13mapIPK6CameraNS_6vectorIfNS_9allocatorIfEEEENS_4lessIS3_EENS5_INS_4pairIKS3_S7_EEEEEixERSB_($this,$2)|0);
 $17 = (($this) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $18;
 $22 = $20;
 $23 = (($21) - ($22))|0;
 $24 = (($23|0) / 52)&-1;
 HEAPF32[$3>>2] = Math_fround(0.0);
 $25 = (($16) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$16>>2]|0;
 $28 = $26;
 $29 = $27;
 $30 = (($28) - ($29))|0;
 $31 = $30 >> 2;
 $32 = ($31>>>0)<($24>>>0);
 if ($32) {
  $33 = (($24) - ($31))|0;
  __ZNSt3__16vectorIfNS_9allocatorIfEEE8__appendEjRKf($16,$33,$3);
  STACKTOP = sp;return;
 }
 $34 = ($31>>>0)>($24>>>0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 $35 = (($27) + ($24<<2)|0);
 $36 = ($26|0)==($35|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i = $35;
 $scevgep$i$i$i = (($26) + -4|0);
 $37 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($37)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $38 = $uglygep3$i$i$i >>> 2;
 $39 = $38 ^ -1;
 $scevgep4$i$i$i = (($26) + ($39<<2)|0);
 HEAP32[$25>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIPK6CameraNS_6vectorIfNS_9allocatorIfEEEENS_4lessIS3_EENS5_INS_4pairIKS3_S7_EEEEEixERSB_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$24 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3>>>0)<($5>>>0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5>>>0)<($3>>>0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$24 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$24 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$24 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $33 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($33|0);
 }
 $16 = (__Znwj(32)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 24|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 28|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$16>>2] = 0;
 $22 = (($16) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = (($16) + 8|0);
 HEAP32[$23>>2] = $24;
 HEAP32[$$0$i>>2] = $16;
 $25 = HEAP32[$this>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $29 = $16;
 } else {
  HEAP32[$this>>2] = $26;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $29 = $$pre$i;
 }
 $28 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$29);
 $30 = (($this) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 1)|0;
 HEAP32[$30>>2] = $32;
 $__r$0 = $16;
 $33 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($33|0);
}
function __ZN12FlareManager12RemoveCameraER6Camera($this,$camera) {
 $this = $this|0;
 $camera = $camera|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$i$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if ($3) {
  label = 8;
 } else {
  $$0$ph7$i$i$i = $2;$$01$ph6$i$in$i$i = $1;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $4 = (($$013$i$in$i$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5>>>0)<($camera>>>0);
    if (!($6)) {
     break;
    }
    $9 = (($$013$i$in$i$i) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $10;
    }
   }
   $7 = HEAP32[$$013$i$in$i$i>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $7;
   }
  }
  $12 = ($$0$ph5$i$i$i|0)==($2|0);
  if ($12) {
   label = 8;
  } else {
   $13 = (($$0$ph5$i$i$i) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14>>>0)>($camera>>>0);
   if ($15) {
    label = 8;
   } else {
    $17 = $$0$ph5$i$i$i;
   }
  }
 }
 if ((label|0) == 8) {
  $17 = $2;
 }
 $16 = (($17) + 4|0);
 $18 = HEAP32[$16>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $$01$i$i$i$i = $17;
  while(1) {
   $22 = (($$01$i$i$i$i) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==($$01$i$i$i$i|0);
   if ($25) {
    $$0$i$i$i$i = $23;
    break;
   } else {
    $$01$i$i$i$i = $23;
   }
  }
 } else {
  $$0$i$i$i$i$i = $18;
  while(1) {
   $20 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0$i$i$i$i = $$0$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i = $20;
   }
  }
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==($17|0);
 if ($27) {
  HEAP32[$this>>2] = $$0$i$i$i$i;
 }
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + -1)|0;
 HEAP32[$28>>2] = $30;
 $31 = (($17) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $40 = $1;
  __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($40,$17);
  __ZdlPv($17);
  STACKTOP = sp;return;
 }
 $34 = (($17) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==($32|0);
 if (!($36)) {
  $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i = $32;
  $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i = (($35) + -4|0);
  $37 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($37)|0);
  $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i;
  $38 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
  $39 = $38 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i = (($35) + ($39<<2)|0);
  HEAP32[$34>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i;
 }
 __ZdlPv($32);
 $$pre = HEAP32[$0>>2]|0;
 $40 = $$pre;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($40,$17);
 __ZdlPv($17);
 STACKTOP = sp;return;
}
function __ZN12FlareManager6UpdateEv($this) {
 $this = $this|0;
 var $$ = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$targetVisible$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0);
 var $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $brightness$025 = 0, $hit = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $or$cond3 = 0, $pos$i$i$i$i$i$i4 = 0;
 var $r = 0, $storemerge = Math_fround(0), $storemerge36 = Math_fround(0), $storemerge37 = Math_fround(0), $t$0 = Math_fround(0), $targetVisible$2 = Math_fround(0), $temp$0$i$i$i = 0, $temp$0$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $pos$i$i$i$i$i$i4 = sp + 168|0;
 $0 = sp + 160|0;
 $1 = sp + 156|0;
 $2 = sp + 144|0;
 $3 = sp + 132|0;
 $4 = sp + 120|0;
 $5 = sp + 108|0;
 $r = sp + 40|0;
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp;
 $hit = sp + 64|0;
 $9 = (__Z16GetRenderManagerv()|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$1>>2] = $10;
 $11 = HEAP32[560624>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  label = 9;
 } else {
  $13 = (($11) + 36|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($11) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14|0)==($16|0);
  do {
   if ($17) {
    $18 = (($11) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($11) + 32|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($19) + ($21<<3)|0);
    $38 = $22;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i$i4,$11,$1);
    $23 = HEAP32[$pos$i$i$i$i$i$i4>>2]|0;
    $24 = ($23|0)==(-1);
    $25 = (($11) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    if ($24) {
     $27 = (($11) + 32|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($26) + ($28<<3)|0);
     $38 = $29;
     break;
    } else {
     $30 = (($26) + ($23<<3)|0);
     $38 = $30;
     break;
    }
   }
  } while(0);
  $31 = HEAP32[560624>>2]|0;
  $32 = (($31) + 28|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + 32|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + ($35<<3)|0);
  $37 = ($38|0)==($36|0);
  if ($37) {
   label = 9;
  } else {
   $39 = (($38) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    label = 9;
   } else {
    $temp$0$i$i$i = $40;
   }
  }
 }
 if ((label|0) == 9) {
  $42 = HEAP32[$9>>2]|0;
  $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
  $temp$0$i$i$i = $43;
 }
 $44 = (($this) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($this) + 4|0);
 $47 = ($45|0)==(0|0);
 if ($47) {
  STACKTOP = sp;return;
 } else {
  $$0$ph7$i$i$i = $46;$$01$ph6$i$in$i$i = $45;
 }
 L16: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $48 = (($$013$i$in$i$i) + 16|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49>>>0)<($temp$0$i$i$i>>>0);
   if (!($50)) {
    break;
   }
   $53 = (($$013$i$in$i$i) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L16;
   } else {
    $$013$i$in$i$i = $54;
   }
  }
  $51 = HEAP32[$$013$i$in$i$i>>2]|0;
  $52 = ($51|0)==(0|0);
  if ($52) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $51;
  }
 }
 $56 = ($$0$ph5$i$i$i|0)==($46|0);
 if ($56) {
  STACKTOP = sp;return;
 }
 $57 = (($$0$ph5$i$i$i) + 16|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($temp$0$i$i$i>>>0)<($58>>>0);
 if ($59) {
  STACKTOP = sp;return;
 }
 $60 = (($$0$ph5$i$i$i) + 20|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($temp$0$i$i$i) + 460|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($this) + 12|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($this) + 16|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($65|0)==($67|0);
 if ($68) {
  STACKTOP = sp;return;
 }
 $69 = (($$0$ph5$i$i$i) + 24|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==($61|0);
 $$ = $71 ? 0 : $61;
 $72 = (($2) + 4|0);
 $73 = (($2) + 8|0);
 $74 = (($7) + 4|0);
 $75 = (($7) + 8|0);
 $76 = (($8) + 4|0);
 $77 = (($8) + 8|0);
 $78 = (($r) + 12|0);
 $79 = (($r) + 16|0);
 $80 = (($r) + 20|0);
 $81 = (($hit) + 32|0);
 $82 = (($hit) + 36|0);
 $83 = (($5) + 4|0);
 $84 = (($5) + 8|0);
 $85 = (($4) + 4|0);
 $86 = (($4) + 8|0);
 $87 = (($3) + 4|0);
 $89 = $65;$brightness$025 = $$;
 while(1) {
  $88 = (($89) + 49|0);
  $90 = HEAP8[$88>>0]|0;
  $91 = ($90<<24>>24)==(0);
  do {
   if (!($91)) {
    $92 = (($89) + 36|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = $93 ^ -1;
    $95 = (($89) + 44|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $97 = (__Z14IsWorldPlayingv()|0);
    if ($97) {
     $98 = (__Z14GetTimeManagerv()|0);
     $99 = (($98) + 104|0);
     $100 = Math_fround(HEAPF32[$99>>2]);
     $102 = $100;
    } else {
     $102 = Math_fround(1.0);
    }
    $101 = Math_fround($96 * $102);
    $103 = Math_fround($101 * Math_fround(0.5));
    $104 = (($89) + 48|0);
    $105 = HEAP8[$104>>0]|0;
    $106 = ($105<<24>>24)==(0);
    if ($106) {
     $107 = (($89) + 16|0);
     __ZNK6Camera20WorldToViewportPointERK8Vector3f($2,$temp$0$i$i$i,$107);
     $108 = Math_fround(HEAPF32[$2>>2]);
     $109 = Math_fround(HEAPF32[$72>>2]);
     $110 = Math_fround(HEAPF32[$73>>2]);
     $111 = $110 < $63;
     if ($111) {
      $112 = $108 > Math_fround(0.0);
      $113 = $108 < Math_fround(1.0);
      $or$cond = $112 & $113;
      if ($or$cond) {
       $114 = $109 > Math_fround(0.0);
       $115 = $109 < Math_fround(1.0);
       $or$cond1 = $114 & $115;
       if ($or$cond1) {
        label = 37;
       } else {
        $targetVisible$2 = Math_fround(0.0);
       }
      } else {
       $targetVisible$2 = Math_fround(0.0);
      }
     } else {
      $targetVisible$2 = Math_fround(0.0);
     }
    } else {
     $116 = (__Z16GetRenderManagerv()|0);
     $117 = HEAP32[$116>>2]|0;
     HEAP32[$0>>2] = $117;
     $118 = HEAP32[560624>>2]|0;
     $119 = ($118|0)==(0|0);
     if ($119) {
      label = 34;
     } else {
      $120 = (($118) + 36|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = (($118) + 4|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = ($121|0)==($123|0);
      do {
       if ($124) {
        $125 = (($118) + 28|0);
        $126 = HEAP32[$125>>2]|0;
        $127 = (($118) + 32|0);
        $128 = HEAP32[$127>>2]|0;
        $129 = (($126) + ($128<<3)|0);
        $145 = $129;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i$i4,$118,$0);
        $130 = HEAP32[$pos$i$i$i$i$i$i4>>2]|0;
        $131 = ($130|0)==(-1);
        $132 = (($118) + 28|0);
        $133 = HEAP32[$132>>2]|0;
        if ($131) {
         $134 = (($118) + 32|0);
         $135 = HEAP32[$134>>2]|0;
         $136 = (($133) + ($135<<3)|0);
         $145 = $136;
         break;
        } else {
         $137 = (($133) + ($130<<3)|0);
         $145 = $137;
         break;
        }
       }
      } while(0);
      $138 = HEAP32[560624>>2]|0;
      $139 = (($138) + 28|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = (($138) + 32|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = (($140) + ($142<<3)|0);
      $144 = ($145|0)==($143|0);
      if ($144) {
       label = 34;
      } else {
       $146 = (($145) + 4|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = ($147|0)==(0|0);
       if ($148) {
        label = 34;
       } else {
        $temp$0$i$i$i8 = $147;
       }
      }
     }
     if ((label|0) == 34) {
      label = 0;
      $149 = HEAP32[$116>>2]|0;
      $150 = (__Z31ReadObjectFromPersistentManageri($149)|0);
      $temp$0$i$i$i8 = $150;
     }
     __ZNK6Camera11GetPositionEv($5,$temp$0$i$i$i8);
     $151 = Math_fround(HEAPF32[$5>>2]);
     $152 = (($89) + 16|0);
     $153 = Math_fround(HEAPF32[$152>>2]);
     $154 = Math_fround($151 + $153);
     $155 = Math_fround(HEAPF32[$83>>2]);
     $156 = (($89) + 20|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = Math_fround($155 + $157);
     $159 = Math_fround(HEAPF32[$84>>2]);
     $160 = (($89) + 24|0);
     $161 = Math_fround(HEAPF32[$160>>2]);
     $162 = Math_fround($159 + $161);
     HEAPF32[$4>>2] = $154;
     HEAPF32[$85>>2] = $158;
     HEAPF32[$86>>2] = $162;
     __ZNK6Camera20WorldToViewportPointERK8Vector3f($3,$temp$0$i$i$i,$4);
     $163 = Math_fround(HEAPF32[$3>>2]);
     $164 = Math_fround(HEAPF32[$87>>2]);
     $165 = $163 > Math_fround(0.0);
     $166 = $163 < Math_fround(1.0);
     $or$cond2 = $165 & $166;
     if ($or$cond2) {
      $167 = $164 > Math_fround(0.0);
      $168 = $164 < Math_fround(1.0);
      $or$cond3 = $167 & $168;
      if ($or$cond3) {
       label = 37;
      } else {
       $targetVisible$2 = Math_fround(0.0);
      }
     } else {
      $targetVisible$2 = Math_fround(0.0);
     }
    }
    if ((label|0) == 37) {
     label = 0;
     ;HEAP32[$r+0>>2]=0|0;HEAP32[$r+4>>2]=0|0;HEAP32[$r+8>>2]=0|0;HEAP32[$r+12>>2]=0|0;HEAP32[$r+16>>2]=0|0;HEAP32[$r+20>>2]=0|0;
     __ZNK6Camera11GetPositionEv($6,$temp$0$i$i$i);
     ;HEAP32[$r+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$r+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$r+8>>2]=HEAP32[$6+8>>2]|0;
     $169 = HEAP8[$104>>0]|0;
     $170 = ($169<<24>>24)==(0);
     if ($170) {
      __ZNK6Camera11GetPositionEv($7,$temp$0$i$i$i);
      $171 = Math_fround(HEAPF32[$7>>2]);
      $172 = (($89) + 16|0);
      $173 = Math_fround(HEAPF32[$172>>2]);
      $174 = Math_fround($171 - $173);
      $175 = Math_fround(HEAPF32[$74>>2]);
      $176 = (($89) + 20|0);
      $177 = Math_fround(HEAPF32[$176>>2]);
      $178 = Math_fround($175 - $177);
      $179 = Math_fround(HEAPF32[$75>>2]);
      $180 = (($89) + 24|0);
      $181 = Math_fround(HEAPF32[$180>>2]);
      $182 = Math_fround($179 - $181);
      $183 = Math_fround($174 * $174);
      $184 = Math_fround($178 * $178);
      $185 = Math_fround($183 + $184);
      $186 = Math_fround($182 * $182);
      $187 = Math_fround($185 + $186);
      $188 = (Math_fround(Math_sqrt((Math_fround($187)))));
      __ZNK6Camera11GetPositionEv($8,$temp$0$i$i$i);
      $189 = Math_fround(HEAPF32[$172>>2]);
      $190 = Math_fround(HEAPF32[$8>>2]);
      $191 = Math_fround($189 - $190);
      $192 = Math_fround(HEAPF32[$176>>2]);
      $193 = Math_fround(HEAPF32[$76>>2]);
      $194 = Math_fround($192 - $193);
      $195 = Math_fround(HEAPF32[$180>>2]);
      $196 = Math_fround(HEAPF32[$77>>2]);
      $197 = Math_fround($195 - $196);
      $198 = Math_fround($191 / $188);
      $199 = Math_fround($194 / $188);
      $200 = Math_fround($197 / $188);
      $storemerge = $200;$storemerge36 = $199;$storemerge37 = $198;$t$0 = $188;
     } else {
      $201 = (($89) + 16|0);
      $202 = Math_fround(HEAPF32[$201>>2]);
      $203 = Math_fround(-$202);
      $204 = (($89) + 20|0);
      $205 = Math_fround(HEAPF32[$204>>2]);
      $206 = Math_fround(-$205);
      $207 = (($89) + 24|0);
      $208 = Math_fround(HEAPF32[$207>>2]);
      $209 = Math_fround(-$208);
      $storemerge = $209;$storemerge36 = $206;$storemerge37 = $203;$t$0 = Math_fround(1.0E+4);
     }
     HEAPF32[$78>>2] = $storemerge37;
     HEAPF32[$79>>2] = $storemerge36;
     HEAPF32[$80>>2] = $storemerge;
     $210 = (__Z19GetRaycastInterfacev()|0);
     HEAPF32[$81>>2] = Math_fround(0.0);
     HEAPF32[$82>>2] = Math_fround(0.0);
     ;HEAP32[$hit+0>>2]=0|0;HEAP32[$hit+4>>2]=0|0;HEAP32[$hit+8>>2]=0|0;HEAP32[$hit+12>>2]=0|0;HEAP32[$hit+16>>2]=0|0;HEAP32[$hit+20>>2]=0|0;
     $211 = ($210|0)==(0|0);
     if ($211) {
      $targetVisible$2 = Math_fround(1.0);
     } else {
      $212 = HEAP32[$210>>2]|0;
      $213 = (($212) + 12|0);
      $214 = HEAP32[$213>>2]|0;
      $215 = (FUNCTION_TABLE_iiifii[$214 & 1]($210,$r,$t$0,$94,$hit)|0);
      $$targetVisible$0 = $215 ? Math_fround(0.0) : Math_fround(1.0);
      $targetVisible$2 = $$targetVisible$0;
     }
    }
    $216 = Math_fround(HEAPF32[$brightness$025>>2]);
    $217 = $targetVisible$2 > $216;
    if ($217) {
     $218 = Math_fround($101 + $216);
     HEAPF32[$brightness$025>>2] = $218;
     $219 = $218 > Math_fround(1.0);
     if (!($219)) {
      break;
     }
     HEAPF32[$brightness$025>>2] = Math_fround(1.0);
     break;
    }
    $220 = $targetVisible$2 < $216;
    if ($220) {
     $221 = Math_fround($216 - $103);
     HEAPF32[$brightness$025>>2] = $221;
     $222 = $221 < Math_fround(0.0);
     if ($222) {
      HEAPF32[$brightness$025>>2] = Math_fround(0.0);
     }
    }
   }
  } while(0);
  $223 = (($89) + 52|0);
  $224 = (($brightness$025) + 4|0);
  $225 = HEAP32[$66>>2]|0;
  $226 = ($223|0)==($225|0);
  if ($226) {
   break;
  } else {
   $89 = $223;$brightness$025 = $224;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12FlareManager12RenderFlaresEv($this) {
 $this = $this|0;
 var $$ = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$in = 0, $$in38 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0);
 var $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0);
 var $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0);
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $brightness$026 = 0, $channels$024 = 0, $channels$1 = 0, $channels$2 = 0, $lastTex$025 = 0, $lastTex$1 = 0, $lastTex$2 = 0, $matView = 0, $matWorld = 0, $pos = 0, $pos$i$i$i$i = 0, $storemerge = Math_fround(0), $storemerge22 = Math_fround(0), $storemerge23 = Math_fround(0), $temp$0$i$i$i1 = 0, $temp$0$i$i$i6 = 0, $temp$0$i37 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $pos$i$i$i$i = sp + 160|0;
 $0 = sp + 156|0;
 $1 = sp + 152|0;
 $2 = sp + 148|0;
 $3 = sp + 144|0;
 $4 = sp + 128|0;
 $matView = sp + 64|0;
 $matWorld = sp;
 $pos = sp + 132|0;
 $5 = HEAP32[571440>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (__ZN5Unity8Material9GetShaderEv($5)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (__ZNK6Shader23GetActiveSubShaderIndexEv($7)|0);
 $10 = (__Z16GetRenderManagerv()|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$4>>2] = $11;
 $13 = HEAP32[560624>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  label = 12;
 } else {
  $15 = (($13) + 36|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($13) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($16|0)==($18|0);
  do {
   if ($19) {
    $20 = (($13) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($13) + 32|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + ($23<<3)|0);
    $40 = $24;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$13,$4);
    $25 = HEAP32[$pos$i$i$i$i>>2]|0;
    $26 = ($25|0)==(-1);
    $27 = (($13) + 28|0);
    $28 = HEAP32[$27>>2]|0;
    if ($26) {
     $29 = (($13) + 32|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + ($30<<3)|0);
     $40 = $31;
     break;
    } else {
     $32 = (($28) + ($25<<3)|0);
     $40 = $32;
     break;
    }
   }
  } while(0);
  $33 = HEAP32[560624>>2]|0;
  $34 = (($33) + 28|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + 32|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<3)|0);
  $39 = ($40|0)==($38|0);
  if ($39) {
   label = 12;
  } else {
   $41 = (($40) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    label = 12;
   }
  }
 }
 if ((label|0) == 12) {
  $44 = HEAP32[$10>>2]|0;
  $45 = (__Z31ReadObjectFromPersistentManageri($44)|0);
  $46 = ($45|0)==(0|0);
  if ($46) {
   STACKTOP = sp;return;
  }
 }
 $47 = (__Z16GetRenderManagerv()|0);
 $48 = HEAP32[$47>>2]|0;
 HEAP32[$3>>2] = $48;
 $49 = HEAP32[560624>>2]|0;
 $50 = ($49|0)==(0|0);
 if ($50) {
  label = 21;
 } else {
  $51 = (($49) + 36|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($49) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($52|0)==($54|0);
  do {
   if ($55) {
    $56 = (($49) + 28|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($49) + 32|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($57) + ($59<<3)|0);
    $76 = $60;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$49,$3);
    $61 = HEAP32[$pos$i$i$i$i>>2]|0;
    $62 = ($61|0)==(-1);
    $63 = (($49) + 28|0);
    $64 = HEAP32[$63>>2]|0;
    if ($62) {
     $65 = (($49) + 32|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = (($64) + ($66<<3)|0);
     $76 = $67;
     break;
    } else {
     $68 = (($64) + ($61<<3)|0);
     $76 = $68;
     break;
    }
   }
  } while(0);
  $69 = HEAP32[560624>>2]|0;
  $70 = (($69) + 28|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($69) + 32|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($71) + ($73<<3)|0);
  $75 = ($76|0)==($74|0);
  if ($75) {
   label = 21;
  } else {
   $77 = (($76) + 4|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==(0|0);
   if ($79) {
    label = 21;
   } else {
    $temp$0$i$i$i1 = $78;
   }
  }
 }
 if ((label|0) == 21) {
  $80 = HEAP32[$47>>2]|0;
  $81 = (__Z31ReadObjectFromPersistentManageri($80)|0);
  $temp$0$i$i$i1 = $81;
 }
 $82 = (($temp$0$i$i$i1) + 456|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($83 * Math_fround(2.0));
 __ZN12FlareManager6UpdateEv($this);
 $85 = (__Z12GetGfxDevicev()|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + 116|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (FUNCTION_TABLE_ii[$88 & 4095]($85)|0);
 dest=$matView+0|0; src=$89+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $90 = HEAP32[$85>>2]|0;
 $91 = (($90) + 112|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (FUNCTION_TABLE_ii[$92 & 4095]($85)|0);
 dest=$matWorld+0|0; src=$93+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $94 = HEAP32[$85>>2]|0;
 $95 = (($94) + 100|0);
 $96 = HEAP32[$95>>2]|0;
 FUNCTION_TABLE_vii[$96 & 4095]($85,616552);
 $97 = (($this) + 4|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (($this) + 4|0);
 $100 = ($98|0)==(0|0);
 if ($100) {
  label = 29;
 } else {
  $$0$ph7$i$i$i = $99;$$01$ph6$i$in$i$i = $98;
  L38: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $101 = (($$013$i$in$i$i) + 16|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ($102>>>0)<($temp$0$i$i$i1>>>0);
    if (!($103)) {
     break;
    }
    $106 = (($$013$i$in$i$i) + 4|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = ($107|0)==(0|0);
    if ($108) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L38;
    } else {
     $$013$i$in$i$i = $107;
    }
   }
   $104 = HEAP32[$$013$i$in$i$i>>2]|0;
   $105 = ($104|0)==(0|0);
   if ($105) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $104;
   }
  }
  $109 = ($$0$ph5$i$i$i|0)==($99|0);
  if ($109) {
   label = 29;
  } else {
   $110 = (($$0$ph5$i$i$i) + 16|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($temp$0$i$i$i1>>>0)<($111>>>0);
   if ($112) {
    label = 29;
   } else {
    $114 = $$0$ph5$i$i$i;
   }
  }
 }
 if ((label|0) == 29) {
  $114 = $99;
 }
 $113 = (($114) + 24|0);
 $115 = HEAP32[$113>>2]|0;
 $116 = (($114) + 20|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = ($115|0)==($117|0);
 $$ = $118 ? 0 : $117;
 $119 = (__Z16GetRenderManagerv()|0);
 $120 = HEAP32[$119>>2]|0;
 HEAP32[$2>>2] = $120;
 $121 = HEAP32[560624>>2]|0;
 $122 = ($121|0)==(0|0);
 if ($122) {
  label = 38;
 } else {
  $123 = (($121) + 36|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = (($121) + 4|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ($124|0)==($126|0);
  do {
   if ($127) {
    $128 = (($121) + 28|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = (($121) + 32|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($129) + ($131<<3)|0);
    $148 = $132;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$121,$2);
    $133 = HEAP32[$pos$i$i$i$i>>2]|0;
    $134 = ($133|0)==(-1);
    $135 = (($121) + 28|0);
    $136 = HEAP32[$135>>2]|0;
    if ($134) {
     $137 = (($121) + 32|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = (($136) + ($138<<3)|0);
     $148 = $139;
     break;
    } else {
     $140 = (($136) + ($133<<3)|0);
     $148 = $140;
     break;
    }
   }
  } while(0);
  $141 = HEAP32[560624>>2]|0;
  $142 = (($141) + 28|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = (($141) + 32|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = (($143) + ($145<<3)|0);
  $147 = ($148|0)==($146|0);
  if ($147) {
   label = 38;
  } else {
   $149 = (($148) + 4|0);
   $150 = HEAP32[$149>>2]|0;
   $151 = ($150|0)==(0|0);
   if ($151) {
    label = 38;
   } else {
    $temp$0$i$i$i6 = $150;
   }
  }
 }
 if ((label|0) == 38) {
  $152 = HEAP32[$119>>2]|0;
  $153 = (__Z31ReadObjectFromPersistentManageri($152)|0);
  $temp$0$i$i$i6 = $153;
 }
 $154 = (__ZNK6Camera22GetWorldToCameraMatrixEv($temp$0$i$i$i6)|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = (($154) + 4|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = (($154) + 8|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($154) + 16|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($154) + 20|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($154) + 24|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = (($154) + 32|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = (($154) + 36|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($154) + 40|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($154) + 48|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = (($154) + 52|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = (($154) + 56|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = HEAP32[652824>>2]|0;
 $179 = (($this) + 12|0);
 $180 = HEAP32[$179>>2]|0;
 $181 = (($this) + 16|0);
 $182 = HEAP32[$181>>2]|0;
 $183 = ($180|0)==($182|0);
 if (!($183)) {
  $184 = (($pos) + 4|0);
  $185 = (($pos) + 8|0);
  $186 = (($178) + 20|0);
  $188 = $180;$brightness$026 = $$;$channels$024 = 0;$lastTex$025 = 0;
  while(1) {
   $187 = (($188) + 49|0);
   $189 = HEAP8[$187>>0]|0;
   $190 = ($189<<24>>24)==(0);
   do {
    if ($190) {
     $channels$2 = $channels$024;$lastTex$2 = $lastTex$025;
    } else {
     $191 = Math_fround(HEAPF32[$brightness$026>>2]);
     $192 = !($191 <= Math_fround(0.0));
     if ($192) {
      $193 = (($188) + 28|0);
      $194 = HEAP32[$193>>2]|0;
      $195 = ($194|0)==(0);
      if ($195) {
       $channels$2 = $channels$024;$lastTex$2 = $lastTex$025;
      } else {
       HEAP32[$0>>2] = $194;
       $196 = HEAP32[560624>>2]|0;
       $197 = ($196|0)==(0|0);
       if ($197) {
        label = 53;
       } else {
        $198 = (($196) + 36|0);
        $199 = HEAP32[$198>>2]|0;
        $200 = (($196) + 4|0);
        $201 = HEAP32[$200>>2]|0;
        $202 = ($199|0)==($201|0);
        do {
         if ($202) {
          $203 = (($196) + 28|0);
          $204 = HEAP32[$203>>2]|0;
          $205 = (($196) + 32|0);
          $206 = HEAP32[$205>>2]|0;
          $207 = (($204) + ($206<<3)|0);
          $223 = $207;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$196,$0);
          $208 = HEAP32[$pos$i$i$i$i>>2]|0;
          $209 = ($208|0)==(-1);
          $210 = (($196) + 28|0);
          $211 = HEAP32[$210>>2]|0;
          if ($209) {
           $212 = (($196) + 32|0);
           $213 = HEAP32[$212>>2]|0;
           $214 = (($211) + ($213<<3)|0);
           $223 = $214;
           break;
          } else {
           $215 = (($211) + ($208<<3)|0);
           $223 = $215;
           break;
          }
         }
        } while(0);
        $216 = HEAP32[560624>>2]|0;
        $217 = (($216) + 28|0);
        $218 = HEAP32[$217>>2]|0;
        $219 = (($216) + 32|0);
        $220 = HEAP32[$219>>2]|0;
        $221 = (($218) + ($220<<3)|0);
        $222 = ($223|0)==($221|0);
        if ($222) {
         label = 53;
        } else {
         $224 = (($223) + 4|0);
         $225 = HEAP32[$224>>2]|0;
         $226 = ($225|0)==(0|0);
         if ($226) {
          label = 53;
         } else {
          $$in = $225;$temp$0$i37 = $225;
         }
        }
       }
       if ((label|0) == 53) {
        label = 0;
        $227 = HEAP32[$193>>2]|0;
        $228 = (__Z31ReadObjectFromPersistentManageri($227)|0);
        $229 = ($228|0)==(0|0);
        if ($229) {
         $channels$2 = $channels$024;$lastTex$2 = $lastTex$025;
         break;
        } else {
         $$in = $228;$temp$0$i37 = $228;
        }
       }
       HEAPF32[$pos>>2] = Math_fround(0.0);
       HEAPF32[$184>>2] = Math_fround(0.0);
       HEAPF32[$185>>2] = Math_fround(0.0);
       $230 = (($188) + 48|0);
       $231 = HEAP8[$230>>0]|0;
       $232 = ($231<<24>>24)==(0);
       $233 = (($188) + 16|0);
       $234 = Math_fround(HEAPF32[$233>>2]);
       if ($232) {
        $235 = Math_fround($155 * $234);
        $236 = (($188) + 20|0);
        $237 = Math_fround(HEAPF32[$236>>2]);
        $238 = Math_fround($161 * $237);
        $239 = Math_fround($235 + $238);
        $240 = (($188) + 24|0);
        $241 = Math_fround(HEAPF32[$240>>2]);
        $242 = Math_fround($167 * $241);
        $243 = Math_fround($239 + $242);
        $244 = Math_fround($173 + $243);
        $245 = Math_fround($157 * $234);
        $246 = Math_fround($163 * $237);
        $247 = Math_fround($245 + $246);
        $248 = Math_fround($169 * $241);
        $249 = Math_fround($247 + $248);
        $250 = Math_fround($175 + $249);
        $251 = Math_fround($159 * $234);
        $252 = Math_fround($165 * $237);
        $253 = Math_fround($251 + $252);
        $254 = Math_fround($171 * $241);
        $255 = Math_fround($253 + $254);
        $256 = Math_fround($177 + $255);
        $storemerge = $256;$storemerge22 = $250;$storemerge23 = $244;
       } else {
        $257 = (($188) + 20|0);
        $258 = Math_fround(HEAPF32[$257>>2]);
        $259 = (($188) + 24|0);
        $260 = Math_fround(HEAPF32[$259>>2]);
        $261 = Math_fround($84 * $234);
        $262 = Math_fround(-$261);
        $263 = Math_fround($84 * $258);
        $264 = Math_fround(-$263);
        $265 = Math_fround($84 * $260);
        $266 = Math_fround(-$265);
        $267 = Math_fround($155 * $262);
        $268 = Math_fround($161 * $264);
        $269 = Math_fround($267 + $268);
        $270 = Math_fround($167 * $266);
        $271 = Math_fround($269 + $270);
        $272 = Math_fround($157 * $262);
        $273 = Math_fround($163 * $264);
        $274 = Math_fround($272 + $273);
        $275 = Math_fround($169 * $266);
        $276 = Math_fround($274 + $275);
        $277 = Math_fround($159 * $262);
        $278 = Math_fround($165 * $264);
        $279 = Math_fround($277 + $278);
        $280 = Math_fround($171 * $266);
        $281 = Math_fround($279 + $280);
        $storemerge = $281;$storemerge22 = $276;$storemerge23 = $271;
       }
       HEAPF32[$pos>>2] = $storemerge23;
       HEAPF32[$184>>2] = $storemerge22;
       HEAPF32[$185>>2] = $storemerge;
       $282 = (($temp$0$i37) + 40|0);
       $283 = HEAP32[$282>>2]|0;
       $284 = ($283|0)==(0);
       if ($284) {
        $channels$2 = $channels$024;$lastTex$2 = $lastTex$025;
       } else {
        HEAP32[$1>>2] = $283;
        $285 = HEAP32[560624>>2]|0;
        $286 = ($285|0)==(0|0);
        do {
         if ($286) {
          label = 67;
         } else {
          $287 = (($285) + 36|0);
          $288 = HEAP32[$287>>2]|0;
          $289 = (($285) + 4|0);
          $290 = HEAP32[$289>>2]|0;
          $291 = ($288|0)==($290|0);
          do {
           if ($291) {
            $292 = (($285) + 28|0);
            $293 = HEAP32[$292>>2]|0;
            $294 = (($285) + 32|0);
            $295 = HEAP32[$294>>2]|0;
            $296 = (($293) + ($295<<3)|0);
            $312 = $296;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$285,$1);
            $297 = HEAP32[$pos$i$i$i$i>>2]|0;
            $298 = ($297|0)==(-1);
            $299 = (($285) + 28|0);
            $300 = HEAP32[$299>>2]|0;
            if ($298) {
             $301 = (($285) + 32|0);
             $302 = HEAP32[$301>>2]|0;
             $303 = (($300) + ($302<<3)|0);
             $312 = $303;
             break;
            } else {
             $304 = (($300) + ($297<<3)|0);
             $312 = $304;
             break;
            }
           }
          } while(0);
          $305 = HEAP32[560624>>2]|0;
          $306 = (($305) + 28|0);
          $307 = HEAP32[$306>>2]|0;
          $308 = (($305) + 32|0);
          $309 = HEAP32[$308>>2]|0;
          $310 = (($307) + ($309<<3)|0);
          $311 = ($312|0)==($310|0);
          if ($311) {
           label = 67;
           break;
          }
          $313 = (($312) + 4|0);
          $314 = HEAP32[$313>>2]|0;
          $315 = ($314|0)==(0|0);
          if ($315) {
           label = 67;
           break;
          }
          $$in38 = $314;
         }
        } while(0);
        if ((label|0) == 67) {
         label = 0;
         $316 = HEAP32[$282>>2]|0;
         $317 = (__Z31ReadObjectFromPersistentManageri($316)|0);
         $318 = ($317|0)==(0|0);
         if ($318) {
          $channels$2 = $channels$024;$lastTex$2 = $lastTex$025;
          break;
         } else {
          $$in38 = $317;
         }
        }
        $319 = ($lastTex$025|0)==($$in38|0);
        if ($319) {
         $channels$1 = $channels$024;$lastTex$1 = $lastTex$025;
        } else {
         (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($186,571392,$$in38)|0);
         $320 = HEAP32[571440>>2]|0;
         $321 = (__ZN5Unity8Material17SetPassWithShaderEiP6ShaderRN9ShaderLab17ShaderPassContextEi($320,0,$7,$178,$9)|0);
         $channels$1 = $321;$lastTex$1 = $$in38;
        }
        $322 = Math_fround(HEAPF32[$brightness$026>>2]);
        $323 = (($188) + 40|0);
        $324 = Math_fround(HEAPF32[$323>>2]);
        $325 = Math_fround($322 * $324);
        __ZN5Flare6RenderER8Vector3ffRK10ColorRGBAfRK14ChannelAssigns($$in,$pos,$325,$188,$channels$1);
        $channels$2 = $channels$1;$lastTex$2 = $lastTex$1;
       }
      }
     } else {
      $channels$2 = $channels$024;$lastTex$2 = $lastTex$025;
     }
    }
   } while(0);
   $326 = (($188) + 52|0);
   $327 = (($brightness$026) + 4|0);
   $328 = HEAP32[$181>>2]|0;
   $329 = ($326|0)==($328|0);
   if ($329) {
    break;
   } else {
    $188 = $326;$brightness$026 = $327;$channels$024 = $channels$2;$lastTex$025 = $lastTex$2;
   }
  }
 }
 $330 = HEAP32[$85>>2]|0;
 $331 = (($330) + 100|0);
 $332 = HEAP32[$331>>2]|0;
 FUNCTION_TABLE_vii[$332 & 4095]($85,$matView);
 $333 = HEAP32[$85>>2]|0;
 $334 = (($333) + 96|0);
 $335 = HEAP32[$334>>2]|0;
 FUNCTION_TABLE_vii[$335 & 4095]($85,$matWorld);
 STACKTOP = sp;return;
}
function __Z24RegisterClass_FlareLayerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(124,92,0,0,0);
 STACKTOP = sp;return;
}
function __ZN10FlareLayer13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 HEAP8[$0>>0] = 20;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=571472+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 11|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,124,8,($0|0),32,(2373|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN10FlareLayer7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(32,$$byval_copy2,1,16,571696,160)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = (($3) + 28|0);
  HEAP8[$6>>0] = 1;
  $7 = (($3) + 29|0);
  HEAP8[$7>>0] = 0;
  HEAP32[$3>>2] = ((571488 + 8|0));
  STACKTOP = sp;return ($3|0);
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(571696|0),160);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($8|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK10FlareLayer25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 124;
}
function __ZN10FlareLayer12AddToManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($1,20)|0);
 $3 = (__ZN12FlareManager3GetEv()|0);
 __ZN12FlareManager9AddCameraER6Camera($3,$2);
 STACKTOP = sp;return;
}
function __ZN10FlareLayer17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($1,20)|0);
 $3 = (__ZN12FlareManager3GetEv()|0);
 __ZN12FlareManager12RemoveCameraER6Camera($3,$2);
 STACKTOP = sp;return;
}
function __ZN10FlareLayerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((571488 + 8|0));
 __ZN9BehaviourD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN10FlareLayerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((571488 + 8|0));
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580560>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$data,571632,0);
  $5 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$5,571640,0);
  $6 = (($data) + 8|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$6,571648,0);
  $7 = (($data) + 12|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$7,571656,0);
 } else {
  $8 = HEAP32[$converter$i>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   (FUNCTION_TABLE_iii[$8 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI5FlareE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI5FlareE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI5FlareE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI5FlareE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,571664,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,571680,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,571664,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,571680,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIfNS_9allocatorIfEEE8__appendEjRKf($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    $11 = Math_fround(HEAPF32[$__x>>2]);
    HEAPF32[$10>>2] = $11;
   }
   $12 = (($10) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  $29 = (__Znwj($28)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   $34 = Math_fround(HEAPF32[$__x>>2]);
   HEAPF32[$33>>2] = $34;
  }
  $35 = (($33) + 4|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $35;
  }
 }
 $38 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 _memcpy(($31|0),($15|0),($17|0))|0;
 HEAP32[$this>>2] = $31;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $38;
 $39 = ($15|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIfNS_9allocatorIfEEE6assignIPfEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIfNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i13 = 0, $$01$i = 0, $$01$i8 = 0, $$promoted$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i3 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0;
 var $scevgep5$i = 0, $scevgep5$i10 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i5 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep4$i = 0, $uglygep4$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = $15 >> 2;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $30 = $__last;
   $31 = (($30) - ($1))|0;
   $32 = $31 >> 2;
   _memmove(($6|0),($__first|0),($31|0))|0;
   $33 = (($6) + ($32<<2)|0);
   $34 = HEAP32[$12>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -4|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = $uglygep3$i$i >>> 2;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + ($38<<2)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + ($16<<2)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $20 = $18;
  $$promoted$i2 = HEAP32[$12>>2]|0;
  $scevgep$i3 = (($__last) + -4|0);
  $21 = (0 - ($20))|0;
  $uglygep$i5 = (($scevgep$i3) + ($21)|0);
  $uglygep4$i6 = $uglygep$i5;
  $22 = $uglygep4$i6 >>> 2;
  $$01$i8 = $18;$24 = $$promoted$i2;
  while(1) {
   $23 = ($24|0)==(0|0);
   if (!($23)) {
    $25 = Math_fround(HEAPF32[$$01$i8>>2]);
    HEAPF32[$24>>2] = $25;
   }
   $26 = (($24) + 4|0);
   $27 = (($$01$i8) + 4|0);
   $28 = ($27|0)==($__last|0);
   if ($28) {
    break;
   } else {
    $$01$i8 = $27;$24 = $26;
   }
  }
  $29 = (($22) + 1)|0;
  $scevgep5$i10 = (($$promoted$i2) + ($29<<2)|0);
  HEAP32[$12>>2] = $scevgep5$i10;
  STACKTOP = sp;return;
 }
 $39 = ($6|0)==(0|0);
 if ($39) {
  $48 = $5;
 } else {
  $40 = (($this) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==($6|0);
  if (!($42)) {
   $scevgep$i$i$i$i = (($41) + -4|0);
   $43 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $44 = $uglygep3$i$i$i$i >>> 2;
   $45 = $44 ^ -1;
   $scevgep4$i$i$i$i = (($41) + ($45<<2)|0);
   HEAP32[$40>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$40>>2] = 0;
  HEAP32[$this>>2] = 0;
  $48 = 0;
 }
 $46 = ($3>>>0)>(1073741823);
 if ($46) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $47 = $48;
 $49 = $47 >> 2;
 $50 = ($49>>>0)<(536870911);
 if ($50) {
  $51 = $47 >> 1;
  $52 = ($51>>>0)<($3>>>0);
  $53 = $52 ? $3 : $51;
  $54 = ($53>>>0)>(1073741823);
  if ($54) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i13 = $53;
  }
 } else {
  $$0$i13 = 1073741823;
 }
 $55 = $$0$i13 << 2;
 $56 = (__Znwj($55)|0);
 $57 = (($this) + 4|0);
 HEAP32[$57>>2] = $56;
 HEAP32[$this>>2] = $56;
 $58 = (($56) + ($$0$i13<<2)|0);
 HEAP32[$4>>2] = $58;
 $59 = ($__first|0)==($__last|0);
 if ($59) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($__last) + -4|0);
 $60 = (0 - ($1))|0;
 $uglygep$i = (($scevgep$i) + ($60)|0);
 $uglygep4$i = $uglygep$i;
 $61 = $uglygep4$i >>> 2;
 $$01$i = $__first;$63 = $56;
 while(1) {
  $62 = ($63|0)==(0|0);
  if (!($62)) {
   $64 = Math_fround(HEAPF32[$$01$i>>2]);
   HEAPF32[$63>>2] = $64;
  }
  $65 = (($63) + 4|0);
  $66 = (($$01$i) + 4|0);
  $67 = ($66|0)==($__last|0);
  if ($67) {
   break;
  } else {
   $$01$i = $66;$63 = $65;
  }
 }
 $68 = (($61) + 1)|0;
 $scevgep5$i = (($56) + ($68<<2)|0);
 HEAP32[$57>>2] = $scevgep5$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN12FlareManager10FlareEntryENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i4 = 0, $$0$i5 = 0, $$01$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $scevgep3 = 0, $uglygep = 0, $uglygep2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 52)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(82595524);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 52)&-1;
 $14 = ($13>>>0)<(41297762);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i5 = 0;$22 = 0;
  } else {
   $$0$i4 = $17;
   label = 5;
  }
 } else {
  $$0$i4 = 82595524;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i4*52)|0;
  $20 = (__Znwj($19)|0);
  $$0$i5 = $$0$i4;$22 = $20;
 }
 $21 = (($22) + (($6*52)|0)|0);
 $23 = (($22) + (($$0$i5*52)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  ;HEAP32[$21+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$21+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$21+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$21+24>>2]=HEAP32[$__x+24>>2]|0;
  $25 = (($__x) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($22) + (($6*52)|0)|0) + 28|0);
  HEAP32[$27>>2] = $26;
  $28 = ((($22) + (($6*52)|0)|0) + 32|0);
  $29 = (($__x) + 32|0);
  ;HEAP32[$28+0>>2]=HEAP32[$29+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$29+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$29+12>>2]|0;HEAP16[$28+16>>1]=HEAP16[$29+16>>1]|0;
 }
 $30 = (($22) + (($7*52)|0)|0);
 $31 = ($1|0)==($2|0);
 if ($31) {
  $45 = $21;$47 = $1;
 } else {
  $32 = (($6) + -1)|0;
  $scevgep = (($1) + -52|0);
  $33 = (0 - ($4))|0;
  $uglygep = (($scevgep) + ($33)|0);
  $uglygep2 = $uglygep;
  $34 = (($uglygep2>>>0) / 52)&-1;
  $35 = (($32) - ($34))|0;
  $$01$i$i = $1;$37 = $21;
  while(1) {
   $36 = (($37) + -52|0);
   $38 = (($$01$i$i) + -52|0);
   ;HEAP32[$36+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$38+12>>2]|0;HEAP32[$36+16>>2]=HEAP32[$38+16>>2]|0;HEAP32[$36+20>>2]=HEAP32[$38+20>>2]|0;HEAP32[$36+24>>2]=HEAP32[$38+24>>2]|0;
   $39 = (($$01$i$i) + -24|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($37) + -24|0);
   HEAP32[$41>>2] = $40;
   $42 = (($37) + -20|0);
   $43 = (($$01$i$i) + -20|0);
   ;HEAP32[$42+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$43+12>>2]|0;HEAP16[$42+16>>1]=HEAP16[$43+16>>1]|0;
   $44 = ($38|0)==($2|0);
   if ($44) {
    break;
   } else {
    $$01$i$i = $38;$37 = $36;
   }
  }
  $scevgep3 = (($22) + (($35*52)|0)|0);
  $$pre$i = HEAP32[$this>>2]|0;
  $45 = $scevgep3;$47 = $$pre$i;
 }
 HEAP32[$this>>2] = $45;
 HEAP32[$0>>2] = $30;
 HEAP32[$9>>2] = $23;
 $46 = ($47|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZdlPv($47);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a1915() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,571400);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[571392>>2] = $1;
 HEAP32[571416>>2] = 13;
 HEAP32[571424>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK21BuiltinShaderSettings22CreateMaterialIfNeededEPPN5Unity8MaterialEi($this,$inoutMaterial,$minPassCount) {
 $this = $this|0;
 $inoutMaterial = $inoutMaterial|0;
 $minPassCount = $minPassCount|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $temp$0$i13 = 0, $temp$0$i15 = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 28|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $4;
 $6 = HEAP32[560624>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  label = 11;
 } else {
  $8 = (($6) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  do {
   if ($12) {
    $13 = (($6) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($6) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + ($16<<3)|0);
    $33 = $17;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$6,$2);
    $18 = HEAP32[$vararg_buffer>>2]|0;
    $19 = ($18|0)==(-1);
    $20 = (($6) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    if ($19) {
     $22 = (($6) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($21) + ($23<<3)|0);
     $33 = $24;
     break;
    } else {
     $25 = (($21) + ($18<<3)|0);
     $33 = $25;
     break;
    }
   }
  } while(0);
  $26 = HEAP32[560624>>2]|0;
  $27 = (($26) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + ($30<<3)|0);
  $32 = ($33|0)==($31|0);
  if ($32) {
   label = 11;
  } else {
   $34 = (($33) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 11;
   } else {
    $$in = $35;$temp$0$i15 = $35;
   }
  }
 }
 if ((label|0) == 11) {
  $37 = HEAP32[$this>>2]|0;
  $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $$in = $38;$temp$0$i15 = $38;
  }
 }
 $40 = (($temp$0$i15) + 52|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($41) + 4|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42|0)==($44|0);
 if (!($45)) {
  $46 = (($41) + 32|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($42) + ($47<<2)|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 16|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)<($minPassCount|0);
  if (!($52)) {
   $151 = HEAP32[$inoutMaterial>>2]|0;
   $152 = ($151|0)==(0|0);
   if ($152) {
    $153 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($$in,61,0)|0);
    HEAP32[$inoutMaterial>>2] = $153;
    STACKTOP = sp;return;
   }
   $154 = (__ZN5Unity8Material9GetShaderEv($151)|0);
   $155 = ($154|0)==($$in|0);
   if ($155) {
    STACKTOP = sp;return;
   }
   $156 = HEAP32[$inoutMaterial>>2]|0;
   __ZN5Unity8Material9SetShaderEP6Shader($156,$$in);
   STACKTOP = sp;return;
  }
 }
 HEAP32[$vararg_buffer>>2] = $minPassCount;
 __Z6FormatPKcz($3,571704,$vararg_buffer);
 $53 = HEAP32[$this>>2]|0;
 $54 = ($53|0)==(0);
 do {
  if ($54) {
   $136 = 0;
   label = 35;
  } else {
   HEAP32[$1>>2] = $53;
   $55 = HEAP32[560624>>2]|0;
   $56 = ($55|0)==(0|0);
   if ($56) {
    label = 23;
   } else {
    $57 = (($55) + 36|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($55) + 4|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($58|0)==($60|0);
    do {
     if ($61) {
      $62 = (($55) + 28|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($55) + 32|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($63) + ($65<<3)|0);
      $82 = $66;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$55,$1);
      $67 = HEAP32[$vararg_buffer>>2]|0;
      $68 = ($67|0)==(-1);
      $69 = (($55) + 28|0);
      $70 = HEAP32[$69>>2]|0;
      if ($68) {
       $71 = (($55) + 32|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = (($70) + ($72<<3)|0);
       $82 = $73;
       break;
      } else {
       $74 = (($70) + ($67<<3)|0);
       $82 = $74;
       break;
      }
     }
    } while(0);
    $75 = HEAP32[560624>>2]|0;
    $76 = (($75) + 28|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($75) + 32|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($77) + ($79<<3)|0);
    $81 = ($82|0)==($80|0);
    if ($81) {
     label = 23;
    } else {
     $83 = (($82) + 4|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ($84|0)==(0|0);
     if ($85) {
      label = 23;
     }
    }
   }
   if ((label|0) == 23) {
    $86 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    $87 = (invoke_ii(3215,($86|0))|0);
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     break;
    }
    $90 = ($87|0)==(0|0);
    if ($90) {
     $136 = 0;
     label = 35;
     break;
    }
   }
   $91 = HEAP32[$this>>2]|0;
   HEAP32[$0>>2] = $91;
   $92 = HEAP32[560624>>2]|0;
   $93 = ($92|0)==(0|0);
   if ($93) {
    label = 33;
   } else {
    $94 = (($92) + 36|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($92) + 4|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($95|0)==($97|0);
    do {
     if ($98) {
      $99 = (($92) + 28|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = (($92) + 32|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = (($100) + ($102<<3)|0);
      $119 = $103;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$92,$0);
      $104 = HEAP32[$vararg_buffer>>2]|0;
      $105 = ($104|0)==(-1);
      $106 = (($92) + 28|0);
      $107 = HEAP32[$106>>2]|0;
      if ($105) {
       $108 = (($92) + 32|0);
       $109 = HEAP32[$108>>2]|0;
       $110 = (($107) + ($109<<3)|0);
       $119 = $110;
       break;
      } else {
       $111 = (($107) + ($104<<3)|0);
       $119 = $111;
       break;
      }
     }
    } while(0);
    $112 = HEAP32[560624>>2]|0;
    $113 = (($112) + 28|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = (($112) + 32|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($114) + ($116<<3)|0);
    $118 = ($119|0)==($117|0);
    if ($118) {
     label = 33;
    } else {
     $120 = (($119) + 4|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = ($121|0)==(0|0);
     if ($122) {
      label = 33;
     } else {
      $temp$0$i13 = $121;
     }
    }
   }
   if ((label|0) == 33) {
    $123 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    $124 = (invoke_ii(3215,($123|0))|0);
    $125 = __THREW__; __THREW__ = 0;
    $126 = $125&1;
    if ($126) {
     break;
    } else {
     $temp$0$i13 = $124;
    }
   }
   $127 = (($temp$0$i13) + 4|0);
   $128 = HEAP32[$127>>2]|0;
   $136 = $128;
   label = 35;
  }
 } while(0);
 if ((label|0) == 35) {
  $129 = HEAP8[$3>>0]|0;
  $130 = $129 & 1;
  $131 = ($130<<24>>24)==(0);
  if ($131) {
   $134 = (($3) + 1|0);
   $135 = $134;
  } else {
   $132 = (($3) + 8|0);
   $133 = HEAP32[$132>>2]|0;
   $135 = $133;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($135|0),0,(571776|0),50,1,($136|0),0,(0|0));
  $137 = __THREW__; __THREW__ = 0;
  $138 = $137&1;
  if (!($138)) {
   $139 = HEAP8[$3>>0]|0;
   $140 = $139 & 1;
   $141 = ($140<<24>>24)==(0);
   if ($141) {
    STACKTOP = sp;return;
   }
   $142 = (($3) + 8|0);
   $143 = HEAP32[$142>>2]|0;
   __ZdlPv($143);
   STACKTOP = sp;return;
  }
 }
 $144 = ___cxa_find_matching_catch()|0;
 $145 = tempRet0;
 $146 = HEAP8[$3>>0]|0;
 $147 = $146 & 1;
 $148 = ($147<<24>>24)==(0);
 if ($148) {
  ___resumeException($144|0);
  // unreachable;
 }
 $149 = (($3) + 8|0);
 $150 = HEAP32[$149>>2]|0;
 __ZdlPv($150);
 ___resumeException($144|0);
 // unreachable;
}
function __ZN16GraphicsSettings15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13RenderManager15InitializeClassEv();
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13RenderManager12CleanupClassEv();
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings22WarmupPreloadedShadersEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $pos$i$i$i = 0, $temp$0$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $11 = $4;$i$02 = 0;
 while(1) {
  $10 = (($11) + ($i$02<<2)|0);
  $12 = HEAP32[$10>>2]|0;
  $13 = ($12|0)==(0);
  do {
   if (!($13)) {
    HEAP32[$0>>2] = $12;
    $14 = HEAP32[560624>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     label = 12;
    } else {
     $16 = (($14) + 36|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($14) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($17|0)==($19|0);
     do {
      if ($20) {
       $21 = (($14) + 28|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($14) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $41 = $25;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$14,$0);
       $26 = HEAP32[$pos$i$i$i>>2]|0;
       $27 = ($26|0)==(-1);
       $28 = (($14) + 28|0);
       $29 = HEAP32[$28>>2]|0;
       if ($27) {
        $30 = (($14) + 32|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = (($29) + ($31<<3)|0);
        $41 = $32;
        break;
       } else {
        $33 = (($29) + ($26<<3)|0);
        $41 = $33;
        break;
       }
      }
     } while(0);
     $34 = HEAP32[560624>>2]|0;
     $35 = (($34) + 28|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($34) + 32|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($36) + ($38<<3)|0);
     $40 = ($41|0)==($39|0);
     if ($40) {
      label = 12;
     } else {
      $42 = (($41) + 4|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = ($43|0)==(0|0);
      if ($44) {
       label = 12;
      } else {
       $temp$0$i4 = $43;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $45 = HEAP32[$10>>2]|0;
     $46 = (__Z31ReadObjectFromPersistentManageri($45)|0);
     $47 = ($46|0)==(0|0);
     if ($47) {
      break;
     } else {
      $temp$0$i4 = $46;
     }
    }
    __ZN23ShaderVariantCollection13WarmupShadersEv($temp$0$i4);
   }
  } while(0);
  $48 = (($i$02) + 1)|0;
  $49 = ($48|0)==($8|0);
  if ($49) {
   break;
  }
  $$pre = HEAP32[$3>>2]|0;
  $11 = $$pre;$i$02 = $48;
 }
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings10SmartResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 HEAP32[$0>>2] = 1;
 $1 = (($this) + 36|0);
 HEAP32[$1>>2] = 1;
 STACKTOP = sp;return;
}
function __Z30RegisterClass_GraphicsSettingsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(30,93,94,0,95);
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 16;
 dest=$3+0|0; src=571896+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 16|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,30,6,($0|0),64,(2374|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN16GraphicsSettings7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(64,$$byval_copy2,1,16,571776,50)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1678,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((571784 + 8|0));
  $6 = (($3) + 24|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 28|0);
  HEAP32[$7>>2] = 1;
  $8 = (($3) + 32|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 36|0);
  HEAP32[$9>>2] = 1;
  $10 = (($3) + 40|0);
  ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;
  STACKTOP = sp;return ($3|0);
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(571776|0),50);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK16GraphicsSettings25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 30;
}
function __ZN16GraphicsSettings23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571920,571896,$this,0);
 __ZN16GraphicsSettings8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,571920,571896,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN16GraphicsSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16GraphicsSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16GraphicsSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16GraphicsSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16GraphicsSettings8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z19GetGraphicsSettingsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(6)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z22GetGraphicsSettingsPtrv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24GetManagerPtrFromContexti(6)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN16GraphicsSettingsD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16GraphicsSettingsD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettingsD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3418,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN16GraphicsSettings8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 $12 = (($this) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 $18 = (FUNCTION_TABLE_iiii[$16 & 2047]($14,$13,$17)|0);
 $19 = HEAP8[$9>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  HEAP32[$12>>2] = $18;
 }
 $21 = (($this) + 40|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 44|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22|0)==($24|0);
 if (!($25)) {
  $27 = $22;
  while(1) {
   $26 = HEAP32[$27>>2]|0;
   $28 = HEAP32[$2>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$6>>2]|0;
   $32 = (FUNCTION_TABLE_iiii[$30 & 2047]($28,$26,$31)|0);
   $33 = HEAP8[$9>>0]|0;
   $34 = ($33<<24>>24)==(0);
   if (!($34)) {
    HEAP32[$27>>2] = $32;
   }
   $35 = (($27) + 4|0);
   $36 = ($35|0)==($24|0);
   if ($36) {
    break;
   } else {
    $27 = $35;
   }
  }
 }
 $37 = (($this) + 52|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($this) + 56|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($38|0)==($40|0);
 if ($41) {
  STACKTOP = sp;return;
 } else {
  $43 = $38;
 }
 while(1) {
  $42 = HEAP32[$43>>2]|0;
  $44 = HEAP32[$2>>2]|0;
  $45 = HEAP32[$44>>2]|0;
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$6>>2]|0;
  $48 = (FUNCTION_TABLE_iiii[$46 & 2047]($44,$42,$47)|0);
  $49 = HEAP8[$9>>0]|0;
  $50 = ($49<<24>>24)==(0);
  if (!($50)) {
   HEAP32[$43>>2] = $48;
  }
  $51 = (($43) + 4|0);
  $52 = ($51|0)==($40|0);
  if ($52) {
   break;
  } else {
   $43 = $51;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i2 = sp;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
 }
 $8 = (($this) + 24|0);
 __ZN4PPtrI6ShaderE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 36|0);
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($11>>>0)<($12>>>0);
 if ($13) {
  $14 = HEAP32[$9>>2]|0;
  HEAP32[$10>>2] = $14;
  HEAP32[$1>>2] = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$9,4);
 }
 $15 = (($this) + 32|0);
 __ZN4PPtrI6ShaderE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($15,$transfer);
 $16 = (($this) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 40|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $17;
 $21 = $19;
 $22 = (($20) - ($21))|0;
 $23 = $22 >> 2;
 HEAP32[$size$i$i$i2>>2] = $23;
 $24 = HEAP32[$1>>2]|0;
 $25 = (($24) + 4|0);
 $26 = HEAP32[$4>>2]|0;
 $27 = ($25>>>0)<($26>>>0);
 if ($27) {
  HEAP32[$24>>2] = $23;
  HEAP32[$1>>2] = $25;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i2,4);
 }
 $28 = HEAP32[$16>>2]|0;
 $29 = HEAP32[$18>>2]|0;
 $30 = ($29|0)==($28|0);
 if (!($30)) {
  $31 = $29;
  while(1) {
   __ZN4PPtrI6ShaderE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($31,$transfer);
   $32 = (($31) + 4|0);
   $33 = ($32|0)==($28|0);
   if ($33) {
    break;
   } else {
    $31 = $32;
   }
  }
 }
 $34 = (($this) + 56|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 52|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $35;
 $39 = $37;
 $40 = (($38) - ($39))|0;
 $41 = $40 >> 2;
 HEAP32[$size$i$i$i2>>2] = $41;
 $42 = HEAP32[$1>>2]|0;
 $43 = (($42) + 4|0);
 $44 = HEAP32[$4>>2]|0;
 $45 = ($43>>>0)<($44>>>0);
 if ($45) {
  HEAP32[$42>>2] = $41;
  HEAP32[$1>>2] = $43;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i2,4);
 }
 $46 = HEAP32[$34>>2]|0;
 $47 = HEAP32[$36>>2]|0;
 $48 = ($47|0)==($46|0);
 if ($48) {
  STACKTOP = sp;return;
 } else {
  $49 = $47;
 }
 while(1) {
  __ZN4PPtrI23ShaderVariantCollectionE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($49,$transfer);
  $50 = (($49) + 4|0);
  $51 = ($50|0)==($46|0);
  if ($51) {
   break;
  } else {
   $49 = $50;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4PPtrI23ShaderVariantCollectionE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI6ShaderE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN16GraphicsSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i$i$i$i = HEAP32[$0>>2]|0;
  $8 = $$pre$i$i$i$i$i$i;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 24|0);
 __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 $11 = (($this) + 36|0);
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$4>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i$i$i$i1 = HEAP32[$11>>2]|0;
  $17 = $$pre$i$i$i$i$i$i1;
 } else {
  $16 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$1>>2] = $13;
  $17 = $16;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$11>>2] = $18;
 $19 = (($this) + 32|0);
 __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb1EEEEvRT_($19,$transfer);
 $20 = (($this) + 40|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS6_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$20,0);
 $21 = (($this) + 52|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS6_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$21,0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS6_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS4_L18MemLabelIdentifier44ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI23ShaderVariantCollectionE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI23ShaderVariantCollectionE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS4_L18MemLabelIdentifier44ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy5 = 0, $$idx = 0, $$pre = 0, $$pre43 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i17 = 0, $__new_last2$i$i$i$i$i26 = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i18 = 0, $scevgep$i$i$i$i$i27 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i22 = 0;
 var $scevgep4$i$i$i$i$i31 = 0, $scevgep8$i$i = 0, $scevgep8$i$i41 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i20 = 0, $uglygep$i$i$i$i$i29 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i21 = 0, $uglygep3$i$i$i$i$i30 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $temp = sp + 8|0;
 $1 = sp + 20|0;
 $2 = sp + 24|0;
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$v>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)<($sz>>>0);
 if (!($10)) {
  $70 = ($9>>>0)>($sz>>>0);
  if (!($70)) {
   STACKTOP = sp;return;
  }
  $71 = (($5) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $72 = $$idx >> 2;
  $73 = ($72|0)==(0);
  do {
   if ($73) {
    $93 = 0;$95 = 0;$scevgep8$i$i41 = 0;
   } else {
    $74 = ($$idx|0)<(0);
    if ($74) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if (!($76)) {
      // unreachable;
     }
    } else {
     HEAP32[$0>>2] = 44;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $77 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy5|0),0,(571776|0),79)|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if (!($79)) {
      $80 = (($77) + ($72<<2)|0);
      $81 = ($sz|0)==(0);
      if ($81) {
       $93 = $77;$95 = $80;$scevgep8$i$i41 = $77;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($5) + ($$sum<<2)|0);
      $82 = (0 - ($7))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($82)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $84 = $77;$86 = $5;
      while(1) {
       $83 = ($84|0)==(0|0);
       if (!($83)) {
        $85 = HEAP32[$86>>2]|0;
        HEAP32[$84>>2] = $85;
       }
       $87 = (($84) + 4|0);
       $88 = (($86) + 4|0);
       $89 = ($88|0)==($71|0);
       if ($89) {
        break;
       } else {
        $84 = $87;$86 = $88;
       }
      }
      $90 = $uglygep6$i$i >>> 2;
      $91 = (($90) + 1)|0;
      $scevgep8$i$i = (($77) + ($91<<2)|0);
      $93 = $77;$95 = $80;$scevgep8$i$i41 = $scevgep8$i$i;
      break;
     }
    }
    $101 = ___cxa_find_matching_catch()|0;
    $102 = tempRet0;
    $$0 = $102;$$01 = $101;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $92 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $93;
  HEAP32[$3>>2] = $scevgep8$i$i41;
  $94 = (($v) + 8|0);
  HEAP32[$94>>2] = $95;
  $96 = ($92|0)==(0|0);
  if ($96) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 44;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($92|0),($$byval_copy5|0));
  $97 = __THREW__; __THREW__ = 0;
  $98 = $97&1;
  if ($98) {
   $99 = ___cxa_find_matching_catch()|0;
   $100 = tempRet0;
   ___cxa_call_unexpected(($99|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $11 = (($v) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($7))|0;
 $15 = $14 >> 2;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $69 = (($sz) - ($9))|0;
  __ZNSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE8__appendEj($v,$69);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2625,($temp|0),($sz|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if (!($20)) {
   $21 = HEAP32[$v>>2]|0;
   HEAP32[$1>>2] = $21;
   $22 = HEAP32[$3>>2]|0;
   HEAP32[$2>>2] = $22;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viii(1679,($temp|0),($$byval_copy|0),($$byval_copy5|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$17>>2]|0;
    $26 = HEAP32[$temp>>2]|0;
    $27 = $25;
    $28 = $26;
    $29 = (($27) - ($28))|0;
    $30 = $29 >> 2;
    $31 = ($30>>>0)<($sz>>>0);
    if ($31) {
     $32 = (($sz) - ($30))|0;
     __THREW__ = 0;
     invoke_vii(2626,($temp|0),($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre43 = HEAP32[$17>>2]|0;
     $42 = $$pre;$44 = $$pre43;
    } else {
     $35 = ($30>>>0)>($sz>>>0);
     if ($35) {
      $36 = (($26) + ($sz<<2)|0);
      $37 = ($25|0)==($36|0);
      if ($37) {
       $42 = $26;$44 = $25;
      } else {
       $__new_last2$i$i$i = $36;
       $scevgep$i$i$i = (($25) + -4|0);
       $38 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($38)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $39 = $uglygep3$i$i$i >>> 2;
       $40 = $39 ^ -1;
       $scevgep4$i$i$i = (($25) + ($40<<2)|0);
       HEAP32[$17>>2] = $scevgep4$i$i$i;
       $42 = $26;$44 = $scevgep4$i$i$i;
      }
     } else {
      $42 = $26;$44 = $25;
     }
    }
    $41 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $41;
    HEAP32[$v>>2] = $42;
    $43 = HEAP32[$3>>2]|0;
    HEAP32[$17>>2] = $43;
    HEAP32[$3>>2] = $44;
    $45 = HEAP32[$18>>2]|0;
    $46 = HEAP32[$11>>2]|0;
    HEAP32[$18>>2] = $46;
    HEAP32[$11>>2] = $45;
    $47 = ($41|0)==(0|0);
    if ($47) {
     STACKTOP = sp;return;
    }
    $48 = ($43|0)==($41|0);
    if (!($48)) {
     $__new_last2$i$i$i$i$i17 = $41;
     $scevgep$i$i$i$i$i18 = (($43) + -4|0);
     $49 = (0 - ($__new_last2$i$i$i$i$i17))|0;
     $uglygep$i$i$i$i$i20 = (($scevgep$i$i$i$i$i18) + ($49)|0);
     $uglygep3$i$i$i$i$i21 = $uglygep$i$i$i$i$i20;
     $50 = $uglygep3$i$i$i$i$i21 >>> 2;
     $51 = $50 ^ -1;
     $scevgep4$i$i$i$i$i22 = (($43) + ($51<<2)|0);
     HEAP32[$17>>2] = $scevgep4$i$i$i$i$i22;
    }
    HEAP32[$$byval_copy>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($41|0),($$byval_copy5|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     ___cxa_call_unexpected(($54|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 $58 = HEAP32[$temp>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
 $60 = HEAP32[$17>>2]|0;
 $61 = ($60|0)==($58|0);
 if (!($61)) {
  $__new_last2$i$i$i$i$i26 = $58;
  $scevgep$i$i$i$i$i27 = (($60) + -4|0);
  $62 = (0 - ($__new_last2$i$i$i$i$i26))|0;
  $uglygep$i$i$i$i$i29 = (($scevgep$i$i$i$i$i27) + ($62)|0);
  $uglygep3$i$i$i$i$i30 = $uglygep$i$i$i$i$i29;
  $63 = $uglygep3$i$i$i$i$i30 >>> 2;
  $64 = $63 ^ -1;
  $scevgep4$i$i$i$i$i31 = (($60) + ($64<<2)|0);
  HEAP32[$17>>2] = $scevgep4$i$i$i$i$i31;
 }
 HEAP32[$$byval_copy>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($58|0),($$byval_copy5|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  ___cxa_call_unexpected(($67|0));
  // unreachable;
 } else {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = $12 >> 2;
 $14 = ($__n|0)==(0);
 if ($14) {
  $$pre$i = $3;$18 = 0;$21 = $10;
 } else {
  $15 = $__n << 2;
  HEAP32[$0>>2] = 44;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy1,0,571776,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre1 = HEAP32[$9>>2]|0;
  $$pre$i = $$pre;$18 = $16;$21 = $$pre1;
 }
 $17 = (($18) + ($13<<2)|0);
 $19 = (($18) + ($__n<<2)|0);
 $20 = ($21|0)==($$pre$i|0);
 if ($20) {
  $31 = $17;$33 = $21;
 } else {
  $__begin13$i$i = $$pre$i;
  $scevgep$i$i = (($21) + -4|0);
  $22 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($22)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $21;$26 = $17;
  while(1) {
   $23 = (($$01$i$i) + -4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($26) + -4|0);
   HEAP32[$25>>2] = $24;
   $27 = (($26) + -4|0);
   $28 = ($23|0)==($$pre$i|0);
   if ($28) {
    break;
   } else {
    $$01$i$i = $23;$26 = $27;
   }
  }
  $29 = $uglygep4$i$i >>> 2;
  $30 = $29 ^ -1;
  $$sum = (($13) + ($30))|0;
  $scevgep5$i$i = (($18) + ($$sum<<2)|0);
  $31 = $scevgep5$i$i;$33 = $$pre$i;
 }
 HEAP32[$this>>2] = $31;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $32 = ($33|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$promoted15$i16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i8 = 0, $scevgep$i17 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i24 = 0, $uglygep$i = 0;
 var $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i9 = 0, $uglygep$i19 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $47 = ($9|0)==(0|0);
  do {
   if ($47) {
    $60 = $8;
   } else {
    $48 = (($this) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($9|0);
    if (!($50)) {
     $scevgep$i$i$i$i = (($49) + -4|0);
     $51 = (0 - ($11))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($51)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $52 = $uglygep3$i$i$i$i >>> 2;
     $53 = $52 ^ -1;
     $scevgep4$i$i$i$i = (($49) + ($53<<2)|0);
     HEAP32[$48>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$0>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy1|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     ___cxa_call_unexpected(($56|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$48>>2] = 0;
     HEAP32[$this>>2] = 0;
     $60 = 0;
     break;
    }
   }
  } while(0);
  $58 = ($5|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $59 = $60;
  $61 = $59 >> 2;
  $62 = ($61>>>0)<(1073741823);
  if ($62) {
   $63 = $59 >> 1;
   $64 = ($63>>>0)<($6>>>0);
   $65 = $64 ? $6 : $63;
   $66 = ($65|0)<(0);
   if ($66) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $65;
   }
  } else {
   $$0$i40 = 2147483647;
  }
  $67 = $$0$i40 << 2;
  HEAP32[$0>>2] = 44;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $68 = (__Z15malloc_internaljj10MemLabelIdiPKci($67,16,$$byval_copy1,0,571776,79)|0);
  $69 = (($this) + 4|0);
  HEAP32[$69>>2] = $68;
  HEAP32[$this>>2] = $68;
  $70 = (($68) + ($$0$i40<<2)|0);
  HEAP32[$7>>2] = $70;
  $71 = ($1|0)==($2|0);
  if ($71) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($2) + -4|0);
  $72 = (0 - ($4))|0;
  $uglygep$i = (($scevgep$i) + ($72)|0);
  $uglygep6$i = $uglygep$i;
  $73 = $uglygep6$i >>> 2;
  $75 = $68;$77 = $1;
  while(1) {
   $74 = ($75|0)==(0|0);
   if (!($74)) {
    $76 = HEAP32[$77>>2]|0;
    HEAP32[$75>>2] = $76;
   }
   $78 = (($75) + 4|0);
   $79 = (($77) + 4|0);
   $80 = ($79|0)==($2|0);
   if ($80) {
    break;
   } else {
    $75 = $78;$77 = $79;
   }
  }
  $81 = (($73) + 1)|0;
  $scevgep8$i = (($68) + ($81<<2)|0);
  HEAP32[$69>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 } else {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + ($19<<2)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i$i = (($23) + -4|0);
   $24 = (0 - ($4))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($24)|0);
   $uglygep5$i$i = $uglygep$i$i;
   $25 = $uglygep5$i$i >>> 2;
   $$01$i$i = $9;$27 = $1;
   while(1) {
    $26 = HEAP32[$27>>2]|0;
    HEAP32[$$01$i$i>>2] = $26;
    $28 = (($27) + 4|0);
    $29 = (($$01$i$i) + 4|0);
    $30 = ($28|0)==($23|0);
    if ($30) {
     break;
    } else {
     $$01$i$i = $29;$27 = $28;
    }
   }
   $31 = (($25) + 1)|0;
   $scevgep6$i$i = (($9) + ($31<<2)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  if (!($__growing$0$off0)) {
   $43 = ($16|0)==($$0$lcssa$i$i|0);
   if ($43) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $$0$lcssa$i$i;
   $scevgep$i$i8 = (($16) + -4|0);
   $44 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i9 = (($scevgep$i$i8) + ($44)|0);
   $uglygep3$i$i = $uglygep$i$i9;
   $45 = $uglygep3$i$i >>> 2;
   $46 = $45 ^ -1;
   $scevgep4$i$i = (($16) + ($46<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $32 = ($23|0)==($2|0);
  if ($32) {
   STACKTOP = sp;return;
  }
  $$promoted15$i16 = $23;
  $scevgep$i17 = (($2) + -4|0);
  $33 = (0 - ($$promoted15$i16))|0;
  $uglygep$i19 = (($scevgep$i17) + ($33)|0);
  $uglygep6$i20 = $uglygep$i19;
  $34 = $uglygep6$i20 >>> 2;
  $36 = $16;$38 = $23;
  while(1) {
   $35 = ($36|0)==(0|0);
   if (!($35)) {
    $37 = HEAP32[$38>>2]|0;
    HEAP32[$36>>2] = $37;
   }
   $39 = (($36) + 4|0);
   $40 = (($38) + 4|0);
   $41 = ($40|0)==($2|0);
   if ($41) {
    break;
   } else {
    $36 = $39;$38 = $40;
   }
  }
  $42 = (($34) + 1)|0;
  $scevgep8$i24 = (($16) + ($42<<2)|0);
  HEAP32[$15>>2] = $scevgep8$i24;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP32[$11>>2] = 0;
   }
   $12 = (($11) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<2)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  HEAP32[$0>>2] = 44;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy1,0,571776,79)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAP32[$33>>2] = 0;
  }
  $34 = (($33) + 4|0);
  $35 = (($$0$i2) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i2 = $35;$33 = $34;
  }
 }
 $37 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 $38 = HEAP32[$this>>2]|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = ($39|0)==($38|0);
 if ($40) {
  $50 = $30;
 } else {
  $__begin13$i$i = $38;
  $scevgep$i$i = (($39) + -4|0);
  $41 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($41)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $39;$45 = $30;
  while(1) {
   $42 = (($$01$i$i) + -4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($45) + -4|0);
   HEAP32[$44>>2] = $43;
   $46 = (($45) + -4|0);
   $47 = ($42|0)==($38|0);
   if ($47) {
    break;
   } else {
    $$01$i$i = $42;$45 = $46;
   }
  }
  $48 = $uglygep4$i$i >>> 2;
  $49 = $48 ^ -1;
  $$sum6 = (($18) + ($49))|0;
  $scevgep5$i$i = (($31) + ($$sum6<<2)|0);
  $50 = $scevgep5$i$i;
 }
 HEAP32[$this>>2] = $50;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $37;
 $51 = ($38|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($38|0),($$byval_copy1|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  ___cxa_call_unexpected(($54|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS6_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS4_L18MemLabelIdentifier44ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS4_L18MemLabelIdentifier44ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy5 = 0, $$idx = 0, $$pre = 0, $$pre43 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i17 = 0, $__new_last2$i$i$i$i$i26 = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i18 = 0, $scevgep$i$i$i$i$i27 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i22 = 0;
 var $scevgep4$i$i$i$i$i31 = 0, $scevgep8$i$i = 0, $scevgep8$i$i41 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i20 = 0, $uglygep$i$i$i$i$i29 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i21 = 0, $uglygep3$i$i$i$i$i30 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $temp = sp + 8|0;
 $1 = sp + 20|0;
 $2 = sp + 24|0;
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$v>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)<($sz>>>0);
 if (!($10)) {
  $70 = ($9>>>0)>($sz>>>0);
  if (!($70)) {
   STACKTOP = sp;return;
  }
  $71 = (($5) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $72 = $$idx >> 2;
  $73 = ($72|0)==(0);
  do {
   if ($73) {
    $93 = 0;$95 = 0;$scevgep8$i$i41 = 0;
   } else {
    $74 = ($$idx|0)<(0);
    if ($74) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if (!($76)) {
      // unreachable;
     }
    } else {
     HEAP32[$0>>2] = 44;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $77 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy5|0),0,(571776|0),79)|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if (!($79)) {
      $80 = (($77) + ($72<<2)|0);
      $81 = ($sz|0)==(0);
      if ($81) {
       $93 = $77;$95 = $80;$scevgep8$i$i41 = $77;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($5) + ($$sum<<2)|0);
      $82 = (0 - ($7))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($82)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $84 = $77;$86 = $5;
      while(1) {
       $83 = ($84|0)==(0|0);
       if (!($83)) {
        $85 = HEAP32[$86>>2]|0;
        HEAP32[$84>>2] = $85;
       }
       $87 = (($84) + 4|0);
       $88 = (($86) + 4|0);
       $89 = ($88|0)==($71|0);
       if ($89) {
        break;
       } else {
        $84 = $87;$86 = $88;
       }
      }
      $90 = $uglygep6$i$i >>> 2;
      $91 = (($90) + 1)|0;
      $scevgep8$i$i = (($77) + ($91<<2)|0);
      $93 = $77;$95 = $80;$scevgep8$i$i41 = $scevgep8$i$i;
      break;
     }
    }
    $101 = ___cxa_find_matching_catch()|0;
    $102 = tempRet0;
    $$0 = $102;$$01 = $101;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $92 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $93;
  HEAP32[$3>>2] = $scevgep8$i$i41;
  $94 = (($v) + 8|0);
  HEAP32[$94>>2] = $95;
  $96 = ($92|0)==(0|0);
  if ($96) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 44;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($92|0),($$byval_copy5|0));
  $97 = __THREW__; __THREW__ = 0;
  $98 = $97&1;
  if ($98) {
   $99 = ___cxa_find_matching_catch()|0;
   $100 = tempRet0;
   ___cxa_call_unexpected(($99|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $11 = (($v) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($7))|0;
 $15 = $14 >> 2;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $69 = (($sz) - ($9))|0;
  __ZNSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE8__appendEj($v,$69);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2627,($temp|0),($sz|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if (!($20)) {
   $21 = HEAP32[$v>>2]|0;
   HEAP32[$1>>2] = $21;
   $22 = HEAP32[$3>>2]|0;
   HEAP32[$2>>2] = $22;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viii(1680,($temp|0),($$byval_copy|0),($$byval_copy5|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$17>>2]|0;
    $26 = HEAP32[$temp>>2]|0;
    $27 = $25;
    $28 = $26;
    $29 = (($27) - ($28))|0;
    $30 = $29 >> 2;
    $31 = ($30>>>0)<($sz>>>0);
    if ($31) {
     $32 = (($sz) - ($30))|0;
     __THREW__ = 0;
     invoke_vii(2628,($temp|0),($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre43 = HEAP32[$17>>2]|0;
     $42 = $$pre;$44 = $$pre43;
    } else {
     $35 = ($30>>>0)>($sz>>>0);
     if ($35) {
      $36 = (($26) + ($sz<<2)|0);
      $37 = ($25|0)==($36|0);
      if ($37) {
       $42 = $26;$44 = $25;
      } else {
       $__new_last2$i$i$i = $36;
       $scevgep$i$i$i = (($25) + -4|0);
       $38 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($38)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $39 = $uglygep3$i$i$i >>> 2;
       $40 = $39 ^ -1;
       $scevgep4$i$i$i = (($25) + ($40<<2)|0);
       HEAP32[$17>>2] = $scevgep4$i$i$i;
       $42 = $26;$44 = $scevgep4$i$i$i;
      }
     } else {
      $42 = $26;$44 = $25;
     }
    }
    $41 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $41;
    HEAP32[$v>>2] = $42;
    $43 = HEAP32[$3>>2]|0;
    HEAP32[$17>>2] = $43;
    HEAP32[$3>>2] = $44;
    $45 = HEAP32[$18>>2]|0;
    $46 = HEAP32[$11>>2]|0;
    HEAP32[$18>>2] = $46;
    HEAP32[$11>>2] = $45;
    $47 = ($41|0)==(0|0);
    if ($47) {
     STACKTOP = sp;return;
    }
    $48 = ($43|0)==($41|0);
    if (!($48)) {
     $__new_last2$i$i$i$i$i17 = $41;
     $scevgep$i$i$i$i$i18 = (($43) + -4|0);
     $49 = (0 - ($__new_last2$i$i$i$i$i17))|0;
     $uglygep$i$i$i$i$i20 = (($scevgep$i$i$i$i$i18) + ($49)|0);
     $uglygep3$i$i$i$i$i21 = $uglygep$i$i$i$i$i20;
     $50 = $uglygep3$i$i$i$i$i21 >>> 2;
     $51 = $50 ^ -1;
     $scevgep4$i$i$i$i$i22 = (($43) + ($51<<2)|0);
     HEAP32[$17>>2] = $scevgep4$i$i$i$i$i22;
    }
    HEAP32[$$byval_copy>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($41|0),($$byval_copy5|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     ___cxa_call_unexpected(($54|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 $58 = HEAP32[$temp>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
 $60 = HEAP32[$17>>2]|0;
 $61 = ($60|0)==($58|0);
 if (!($61)) {
  $__new_last2$i$i$i$i$i26 = $58;
  $scevgep$i$i$i$i$i27 = (($60) + -4|0);
  $62 = (0 - ($__new_last2$i$i$i$i$i26))|0;
  $uglygep$i$i$i$i$i29 = (($scevgep$i$i$i$i$i27) + ($62)|0);
  $uglygep3$i$i$i$i$i30 = $uglygep$i$i$i$i$i29;
  $63 = $uglygep3$i$i$i$i$i30 >>> 2;
  $64 = $63 ^ -1;
  $scevgep4$i$i$i$i$i31 = (($60) + ($64<<2)|0);
  HEAP32[$17>>2] = $scevgep4$i$i$i$i$i31;
 }
 HEAP32[$$byval_copy>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($58|0),($$byval_copy5|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  ___cxa_call_unexpected(($67|0));
  // unreachable;
 } else {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = $12 >> 2;
 $14 = ($__n|0)==(0);
 if ($14) {
  $$pre$i = $3;$18 = 0;$21 = $10;
 } else {
  $15 = $__n << 2;
  HEAP32[$0>>2] = 44;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy1,0,571776,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre1 = HEAP32[$9>>2]|0;
  $$pre$i = $$pre;$18 = $16;$21 = $$pre1;
 }
 $17 = (($18) + ($13<<2)|0);
 $19 = (($18) + ($__n<<2)|0);
 $20 = ($21|0)==($$pre$i|0);
 if ($20) {
  $31 = $17;$33 = $21;
 } else {
  $__begin13$i$i = $$pre$i;
  $scevgep$i$i = (($21) + -4|0);
  $22 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($22)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $21;$26 = $17;
  while(1) {
   $23 = (($$01$i$i) + -4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($26) + -4|0);
   HEAP32[$25>>2] = $24;
   $27 = (($26) + -4|0);
   $28 = ($23|0)==($$pre$i|0);
   if ($28) {
    break;
   } else {
    $$01$i$i = $23;$26 = $27;
   }
  }
  $29 = $uglygep4$i$i >>> 2;
  $30 = $29 ^ -1;
  $$sum = (($13) + ($30))|0;
  $scevgep5$i$i = (($18) + ($$sum<<2)|0);
  $31 = $scevgep5$i$i;$33 = $$pre$i;
 }
 HEAP32[$this>>2] = $31;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $32 = ($33|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$promoted15$i16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i8 = 0, $scevgep$i17 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i24 = 0, $uglygep$i = 0;
 var $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i9 = 0, $uglygep$i19 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $47 = ($9|0)==(0|0);
  do {
   if ($47) {
    $60 = $8;
   } else {
    $48 = (($this) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($9|0);
    if (!($50)) {
     $scevgep$i$i$i$i = (($49) + -4|0);
     $51 = (0 - ($11))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($51)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $52 = $uglygep3$i$i$i$i >>> 2;
     $53 = $52 ^ -1;
     $scevgep4$i$i$i$i = (($49) + ($53<<2)|0);
     HEAP32[$48>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$0>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy1|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     ___cxa_call_unexpected(($56|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$48>>2] = 0;
     HEAP32[$this>>2] = 0;
     $60 = 0;
     break;
    }
   }
  } while(0);
  $58 = ($5|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $59 = $60;
  $61 = $59 >> 2;
  $62 = ($61>>>0)<(1073741823);
  if ($62) {
   $63 = $59 >> 1;
   $64 = ($63>>>0)<($6>>>0);
   $65 = $64 ? $6 : $63;
   $66 = ($65|0)<(0);
   if ($66) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $65;
   }
  } else {
   $$0$i40 = 2147483647;
  }
  $67 = $$0$i40 << 2;
  HEAP32[$0>>2] = 44;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $68 = (__Z15malloc_internaljj10MemLabelIdiPKci($67,16,$$byval_copy1,0,571776,79)|0);
  $69 = (($this) + 4|0);
  HEAP32[$69>>2] = $68;
  HEAP32[$this>>2] = $68;
  $70 = (($68) + ($$0$i40<<2)|0);
  HEAP32[$7>>2] = $70;
  $71 = ($1|0)==($2|0);
  if ($71) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($2) + -4|0);
  $72 = (0 - ($4))|0;
  $uglygep$i = (($scevgep$i) + ($72)|0);
  $uglygep6$i = $uglygep$i;
  $73 = $uglygep6$i >>> 2;
  $75 = $68;$77 = $1;
  while(1) {
   $74 = ($75|0)==(0|0);
   if (!($74)) {
    $76 = HEAP32[$77>>2]|0;
    HEAP32[$75>>2] = $76;
   }
   $78 = (($75) + 4|0);
   $79 = (($77) + 4|0);
   $80 = ($79|0)==($2|0);
   if ($80) {
    break;
   } else {
    $75 = $78;$77 = $79;
   }
  }
  $81 = (($73) + 1)|0;
  $scevgep8$i = (($68) + ($81<<2)|0);
  HEAP32[$69>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 } else {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + ($19<<2)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i$i = (($23) + -4|0);
   $24 = (0 - ($4))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($24)|0);
   $uglygep5$i$i = $uglygep$i$i;
   $25 = $uglygep5$i$i >>> 2;
   $$01$i$i = $9;$27 = $1;
   while(1) {
    $26 = HEAP32[$27>>2]|0;
    HEAP32[$$01$i$i>>2] = $26;
    $28 = (($27) + 4|0);
    $29 = (($$01$i$i) + 4|0);
    $30 = ($28|0)==($23|0);
    if ($30) {
     break;
    } else {
     $$01$i$i = $29;$27 = $28;
    }
   }
   $31 = (($25) + 1)|0;
   $scevgep6$i$i = (($9) + ($31<<2)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  if (!($__growing$0$off0)) {
   $43 = ($16|0)==($$0$lcssa$i$i|0);
   if ($43) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $$0$lcssa$i$i;
   $scevgep$i$i8 = (($16) + -4|0);
   $44 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i9 = (($scevgep$i$i8) + ($44)|0);
   $uglygep3$i$i = $uglygep$i$i9;
   $45 = $uglygep3$i$i >>> 2;
   $46 = $45 ^ -1;
   $scevgep4$i$i = (($16) + ($46<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $32 = ($23|0)==($2|0);
  if ($32) {
   STACKTOP = sp;return;
  }
  $$promoted15$i16 = $23;
  $scevgep$i17 = (($2) + -4|0);
  $33 = (0 - ($$promoted15$i16))|0;
  $uglygep$i19 = (($scevgep$i17) + ($33)|0);
  $uglygep6$i20 = $uglygep$i19;
  $34 = $uglygep6$i20 >>> 2;
  $36 = $16;$38 = $23;
  while(1) {
   $35 = ($36|0)==(0|0);
   if (!($35)) {
    $37 = HEAP32[$38>>2]|0;
    HEAP32[$36>>2] = $37;
   }
   $39 = (($36) + 4|0);
   $40 = (($38) + 4|0);
   $41 = ($40|0)==($2|0);
   if ($41) {
    break;
   } else {
    $36 = $39;$38 = $40;
   }
  }
  $42 = (($34) + 1)|0;
  $scevgep8$i24 = (($16) + ($42<<2)|0);
  HEAP32[$15>>2] = $scevgep8$i24;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP32[$11>>2] = 0;
   }
   $12 = (($11) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<2)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  HEAP32[$0>>2] = 44;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy1,0,571776,79)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAP32[$33>>2] = 0;
  }
  $34 = (($33) + 4|0);
  $35 = (($$0$i2) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i2 = $35;$33 = $34;
  }
 }
 $37 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 $38 = HEAP32[$this>>2]|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = ($39|0)==($38|0);
 if ($40) {
  $50 = $30;
 } else {
  $__begin13$i$i = $38;
  $scevgep$i$i = (($39) + -4|0);
  $41 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($41)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $39;$45 = $30;
  while(1) {
   $42 = (($$01$i$i) + -4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($45) + -4|0);
   HEAP32[$44>>2] = $43;
   $46 = (($45) + -4|0);
   $47 = ($42|0)==($38|0);
   if ($47) {
    break;
   } else {
    $$01$i$i = $42;$45 = $46;
   }
  }
  $48 = $uglygep4$i$i >>> 2;
  $49 = $48 ^ -1;
  $$sum6 = (($18) + ($49))|0;
  $scevgep5$i$i = (($31) + ($$sum6<<2)|0);
  $50 = $scevgep5$i$i;
 }
 HEAP32[$this>>2] = $50;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $37;
 $51 = ($38|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($38|0),($$byval_copy1|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  ___cxa_call_unexpected(($54|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN16GraphicsSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
 }
 $8 = (($this) + 24|0);
 __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 36|0);
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($11>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$9,4);
 } else {
  $14 = HEAP32[$10>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$1>>2] = $11;
 }
 $15 = (($this) + 32|0);
 __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb0EEEEvRT_($15,$transfer);
 $16 = (($this) + 40|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS6_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$16,0);
 $17 = (($this) + 52|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS6_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$17,0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS6_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS4_L18MemLabelIdentifier44ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI23ShaderVariantCollectionE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI23ShaderVariantCollectionE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS6_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS4_L18MemLabelIdentifier44ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN16GraphicsSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferI21BuiltinShaderSettingsEEvRT_PKc17TransferMetaFlags($transfer,$0,571928,0);
 $1 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferI21BuiltinShaderSettingsEEvRT_PKc17TransferMetaFlags($transfer,$1,571944,0);
 $2 = (($this) + 40|0);
 $3 = HEAP32[580760>>2]|0;
 $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,571968,$3,$converter$i$i1,1)|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = ($4|0)>(0);
  if ($6) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS5_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$2,0);
  } else {
   $7 = HEAP32[$converter$i$i1>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    (FUNCTION_TABLE_iii[$7 & 4095]($2,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $9 = (($this) + 52|0);
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,571992,$3,$converter$i$i1,1)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($10|0)>(0);
 if ($12) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS5_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$9,0);
 } else {
  $13 = HEAP32[$converter$i$i1>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   (FUNCTION_TABLE_iii[$13 & 4095]($9,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI21BuiltinShaderSettingsEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, $converter$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i$i = sp + 4|0;
 $converter$i = sp;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,572136,$converter$i,1)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ($1|0)>(0);
 if ($3) {
  $4 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$4,572056,0);
  $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,572064,572120,$converter$i$i$i$i,1)|0);
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = ($5|0)>(0);
   if ($7) {
    __ZN4PPtrI6ShaderE8TransferI14SafeBinaryReadEEvRT_($data,$this);
   } else {
    $8 = HEAP32[$converter$i$i$i$i>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     (FUNCTION_TABLE_iii[$8 & 4095]($data,$this)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } else {
  $10 = HEAP32[$converter$i>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   (FUNCTION_TABLE_iii[$10 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS5_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,572080,572080,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS4_L18MemLabelIdentifier44ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,572016,572088,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4PPtrI23ShaderVariantCollectionE8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 4|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,572016,572088,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4PPtrI23ShaderVariantCollectionE8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 4|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI23ShaderVariantCollectionE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,572024,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,572040,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,572024,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,572040,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS5_L18MemLabelIdentifier44ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,572080,572080,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS4_L18MemLabelIdentifier44ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,572016,572120,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4PPtrI6ShaderE8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 4|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,572016,572120,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4PPtrI6ShaderE8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 4|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI6ShaderE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,572024,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,572040,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,572024,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,572040,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN16GraphicsSettings8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i4 = 0, $p$i$i3 = 0, $size$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i$i4 = sp;
 $size$i$i$i2 = sp + 20|0;
 $p$i$i3 = sp + 16|0;
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571928,572136,$0,0);
 $1 = (($this) + 28|0);
 $2 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572056,$2,$1,0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572064,572120,$0,0);
 $9 = (($localIdentifier$i$i$i$i4) + 8|0);
 $10 = $9;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i4>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572024,$2,$0,1);
 $14 = HEAP32[$3>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$6>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572040,$18,$9,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$6>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571944,572136,$23,0);
 $24 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572056,$2,$24,0);
 $25 = HEAP32[$3>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$6>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572064,572120,$23,0);
 $29 = (($localIdentifier$i$i$i$i4) + 8|0);
 $30 = $29;
 $31 = $30;
 HEAP32[$31>>2] = 0;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i4>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572024,$2,$23,1);
 $34 = HEAP32[$3>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$6>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572040,$18,$29,1);
 $38 = HEAP32[$3>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$6>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $42 = (($this) + 40|0);
 $43 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571968,$43,$42,0);
 HEAP32[$p$i$i3>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,572080,572080,$size$i$i$i2,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572016,572120,$p$i$i3,0);
 $44 = (($localIdentifier$i$i$i$i4) + 8|0);
 $45 = $44;
 $46 = $45;
 HEAP32[$46>>2] = 0;
 $47 = (($45) + 4)|0;
 $48 = $47;
 HEAP32[$48>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i4>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572024,$2,$p$i$i3,1);
 $49 = HEAP32[$3>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$6>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572040,$18,$44,1);
 $53 = HEAP32[$3>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$6>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $57 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,571992,$43,$57,0);
 HEAP32[$p$i$i3>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,572080,572080,$size$i$i$i2,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572016,572088,$p$i$i3,0);
 $58 = (($localIdentifier$i$i$i$i4) + 8|0);
 $59 = $58;
 $60 = $59;
 HEAP32[$60>>2] = 0;
 $61 = (($59) + 4)|0;
 $62 = $61;
 HEAP32[$62>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i4>>2] = 0;
 $63 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572024,$63,$p$i$i3,1);
 $64 = HEAP32[$3>>2]|0;
 $65 = HEAP32[$64>>2]|0;
 $66 = HEAP32[$6>>2]|0;
 $67 = ((($65) + (($66*24)|0)|0) + 12|0);
 HEAP32[$67>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $68 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,572040,$68,$58,1);
 $69 = HEAP32[$3>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$6>>2]|0;
 $72 = ((($70) + (($71*24)|0)|0) + 12|0);
 HEAP32[$72>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN16GraphicsSettingsD2Ev($this) {
 $this = $this|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $eh$lpad$body$i$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy6 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((571784 + 8|0));
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($this) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($3|0);
  if (!($7)) {
   $__new_last2$i$i$i$i$i = $3;
   $scevgep$i$i$i$i$i = (($6) + -4|0);
   $8 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($8)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $9 = $uglygep3$i$i$i$i$i >>> 2;
   $10 = $9 ^ -1;
   $scevgep4$i$i$i$i$i = (($6) + ($10<<2)|0);
   HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
  }
  HEAP32[$1>>2] = 44;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($3|0),($$byval_copy6|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 $15 = (($this) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = (($this) + 44|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($16|0);
  if (!($20)) {
   $__new_last2$i$i$i$i$i2 = $16;
   $scevgep$i$i$i$i$i3 = (($19) + -4|0);
   $21 = (0 - ($__new_last2$i$i$i$i$i2))|0;
   $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($21)|0);
   $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
   $22 = $uglygep3$i$i$i$i$i6 >>> 2;
   $23 = $22 ^ -1;
   $scevgep4$i$i$i$i$i7 = (($19) + ($23<<2)|0);
   HEAP32[$18>>2] = $scevgep4$i$i$i$i$i7;
  }
  HEAP32[$0>>2] = 44;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($16|0),($$byval_copy6|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $26 = ___cxa_find_matching_catch()|0;
   $27 = tempRet0;
   ___cxa_call_unexpected(($26|0));
   // unreachable;
  }
 }
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if (!($31)) {
   STACKTOP = sp;return;
  }
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  __THREW__ = 0;
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $36 = ___cxa_find_matching_catch(0|0)|0;
   $37 = tempRet0;
   ___clang_call_terminate($36);
   // unreachable;
  } else {
   ___resumeException($32|0);
   // unreachable;
  }
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $44 = ___cxa_find_matching_catch(0|0)|0;
  $45 = tempRet0;
  __THREW__ = 0;
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if ($47) {
   $48 = ___cxa_find_matching_catch(0|0)|0;
   $49 = tempRet0;
   ___clang_call_terminate($48);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $44;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if (!($43)) {
  ___resumeException($38|0);
  // unreachable;
 }
 $50 = ___cxa_find_matching_catch(0|0)|0;
 $51 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $50;
 ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
 // unreachable;
}
function __Z14GetHaloManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(17)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN11HaloManager10UpdateHaloEi8Vector3f11ColorRGBA32fj($this,$h,$position,$color,$size,$layers) {
 $this = $this|0;
 $h = $h|0;
 $position = $position|0;
 $color = $color|0;
 $size = Math_fround($size);
 $layers = $layers|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $8 = $1;
 }
 while(1) {
  $7 = (($8) + 20|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = ($9|0)==($h|0);
  $6 = (($8) + 28|0);
  if ($10) {
   break;
  }
  $5 = ($6|0)==($3|0);
  if ($5) {
   label = 5;
   break;
  } else {
   $8 = $6;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$8+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$position+8>>2]|0;
 $11 = (($8) + 12|0);
 $12 = HEAP32[$color>>2]|0;
 HEAP32[$11>>2] = $12;
 $13 = (($8) + 16|0);
 HEAPF32[$13>>2] = $size;
 $14 = (($8) + 24|0);
 HEAP32[$14>>2] = $layers;
 STACKTOP = sp;return;
}
function __ZL16LoadHaloMaterialv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[572312>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__Z15GetScriptMapperv()|0);
 $4 = (__Znwj(32)|0);
 $5 = (($0) + 8|0);
 HEAP32[$5>>2] = $4;
 HEAP32[$0>>2] = 33;
 $6 = (($0) + 4|0);
 HEAP32[$6>>2] = 20;
 dest=$4+0|0; src=572328+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $7 = (($4) + 20|0);
 HEAP8[$7>>0] = 0;
 __THREW__ = 0;
 $8 = (invoke_iii(2366,($3|0),($0|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  $19 = HEAP8[$0>>0]|0;
  $20 = $19 & 1;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   ___resumeException($17|0);
   // unreachable;
  }
  $22 = HEAP32[$5>>2]|0;
  __ZdlPv($22);
  ___resumeException($17|0);
  // unreachable;
 }
 $11 = HEAP8[$0>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if (!($13)) {
  $14 = HEAP32[$5>>2]|0;
  __ZdlPv($14);
 }
 $15 = ($8|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($8,61,0)|0);
 HEAP32[572312>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN11HaloManager7AddHaloEv($this) {
 $this = $this|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $handle$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $handle$0 = 1;
 } else {
  $6 = (($4) + -8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 1)|0;
  $handle$0 = $8;
 }
 $9 = (($0) + 15|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP16[$0+12>>1]=0|0;HEAP8[$0+14>>0]=0|0;
 HEAP8[$9>>0] = -1;
 $10 = (($0) + 16|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($0) + 20|0);
 HEAP32[$11>>2] = $handle$0;
 $12 = (($0) + 24|0);
 HEAP32[$12>>2] = 1;
 $13 = (($this) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($4|0)==($14|0);
 if ($15) {
  __ZNSt3__16vectorIN11HaloManager4HaloENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($1,$0);
  STACKTOP = sp;return ($handle$0|0);
 }
 $16 = ($4|0)==(0|0);
 if ($16) {
  $18 = 0;
 } else {
  ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$4+24>>2]=HEAP32[$0+24>>2]|0;
  $$pre$i = HEAP32[$3>>2]|0;
  $18 = $$pre$i;
 }
 $17 = (($18) + 28|0);
 HEAP32[$3>>2] = $17;
 STACKTOP = sp;return ($handle$0|0);
}
function __ZN11HaloManager10DeleteHaloEi($this,$h) {
 $this = $this|0;
 $h = $h|0;
 var $$0$lcssa$i$i$i = 0, $$012$i$i$i = 0, $$03$i$i$i = 0, $$pre$i = 0, $$sum$i = 0, $$sum5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__first5$i$i$i = 0;
 var $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i1$i = 0, $scevgep4$i$i$i = 0, $scevgep7$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i3$i = 0, $uglygep3$i$i$i = 0, $uglygep6$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $8 = $1;
 }
 while(1) {
  $7 = (($8) + 20|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = ($9|0)==($h|0);
  $6 = (($8) + 28|0);
  if ($10) {
   break;
  }
  $5 = ($6|0)==($3|0);
  if ($5) {
   label = 10;
   break;
  } else {
   $8 = $6;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return;
 }
 $11 = $8;
 $12 = $1;
 $13 = (($11) - ($12))|0;
 $14 = (($13|0) / 28)&-1;
 $15 = (($1) + (($14*28)|0)|0);
 $$sum$i = (($14) + 1)|0;
 $16 = (($1) + (($$sum$i*28)|0)|0);
 $17 = ($16|0)==($3|0);
 if ($17) {
  $$0$lcssa$i$i$i = $15;$29 = $3;
 } else {
  $__first5$i$i$i = $16;
  $scevgep$i$i1$i = (($3) + -28|0);
  $18 = (0 - ($__first5$i$i$i))|0;
  $uglygep$i$i3$i = (($scevgep$i$i1$i) + ($18)|0);
  $$012$i$i$i = $16;$$03$i$i$i = $15;
  while(1) {
   ;HEAP32[$$03$i$i$i+0>>2]=HEAP32[$$012$i$i$i+0>>2]|0;HEAP32[$$03$i$i$i+4>>2]=HEAP32[$$012$i$i$i+4>>2]|0;HEAP32[$$03$i$i$i+8>>2]=HEAP32[$$012$i$i$i+8>>2]|0;
   $19 = (($$03$i$i$i) + 12|0);
   $20 = (($$012$i$i$i) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$19>>2] = $21;
   $22 = (($$03$i$i$i) + 16|0);
   $23 = (($$012$i$i$i) + 16|0);
   ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;
   $24 = (($$012$i$i$i) + 28|0);
   $25 = (($$03$i$i$i) + 28|0);
   $26 = ($24|0)==($3|0);
   if ($26) {
    break;
   } else {
    $$012$i$i$i = $24;$$03$i$i$i = $25;
   }
  }
  $uglygep6$i$i$i = $uglygep$i$i3$i;
  $27 = (($uglygep6$i$i$i>>>0) / 28)&-1;
  $$sum5$i = (($27) + ($$sum$i))|0;
  $scevgep7$i$i$i = (($1) + (($$sum5$i*28)|0)|0);
  $$pre$i = HEAP32[$2>>2]|0;
  $$0$lcssa$i$i$i = $scevgep7$i$i$i;$29 = $$pre$i;
 }
 $28 = ($29|0)==($$0$lcssa$i$i$i|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i = $$0$lcssa$i$i$i;
 $scevgep$i$i$i = (($29) + -28|0);
 $30 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($30)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $31 = (($uglygep3$i$i$i>>>0) / 28)&-1;
 $32 = $31 ^ -1;
 $scevgep4$i$i$i = (($29) + (($32*28)|0)|0);
 HEAP32[$2>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __ZN16LevelGameManagerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561080 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   STACKTOP = sp;return;
  }
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __THREW__ = 0;
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   ___resumeException($4|0);
   // unreachable;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$indexZ2D = $16;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  ___resumeException($10|0);
  // unreachable;
 }
 $22 = ___cxa_find_matching_catch(0|0)|0;
 $23 = tempRet0;
 $eh$lpad$body$indexZ2D = $22;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN11HaloManager13AwakeFromLoadE17AwakeFromLoadMode($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetRenderManagerv()|0);
 $1 = (($this) + 24|0);
 __ZN13RenderManager19AddCameraRenderableEP10Renderablei($0,$1,3000);
 STACKTOP = sp;return;
}
function __ZN11HaloManager17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetRenderManagerPtrv()|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($this) + 24|0);
  __ZN13RenderManager22RemoveCameraRenderableEP10Renderable($0,$2);
 }
 __ZN11GameManager17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __Z25RegisterClass_HaloManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(127,96,0,0,0);
 STACKTOP = sp;return;
}
function __ZN11HaloManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(3)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN16LevelGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 11;
 dest=$3+0|0; src=572296+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 11|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,127,3,($0|0),40,(2375|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN11HaloManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,1,16,572320,32)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1681,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = (($3) + 24|0);
  HEAP32[$3>>2] = ((572168 + 8|0));
  HEAP32[$6>>2] = ((572168 + 124|0));
  $7 = (($3) + 28|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 32|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 36|0);
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(572320|0),32);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK11HaloManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 127;
}
function __ZN11HaloManager16RenderRenderableERK11CullResultsRN9ShaderLab17ShaderPassContextE($this,$cullResults,$passContext) {
 $this = $this|0;
 $cullResults = $cullResults|0;
 $passContext = $passContext|0;
 var $$ = 0, $$sink = 0, $$sink$i$i = Math_fround(0), $$sink$i$i$us = Math_fround(0), $$sink$in = 0, $$sink$in$us = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0);
 var $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0;
 var $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = Math_fround(0);
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0;
 var $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0;
 var $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $exitcond35 = 0, $halosToRender$0$lcssa = 0, $halosToRender$033 = 0, $halosToRender$033$us = 0, $halosToRender$1 = 0, $halosToRender$1$us = 0, $i$030 = 0, $i$030$us = 0, $matWorld = 0, $pos$i$i$i$i$i$i = 0, $temp$0$i$i$i = 0, $vbPtr = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $pos$i$i$i$i$i$i = sp + 72|0;
 $0 = sp;
 $vbPtr = sp + 4|0;
 $matWorld = sp + 8|0;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($cullResults) + 1068|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 __ZL16LoadHaloMaterialv();
 $9 = HEAP32[572312>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (__ZN5Unity8Material9GetShaderEv($9)|0);
 $12 = (__ZNK6Shader23GetActiveSubShaderIndexEv($11)|0);
 $13 = (__Z12GetGfxDevicev()|0);
 $14 = HEAP32[$3>>2]|0;
 $15 = HEAP32[$1>>2]|0;
 $16 = $14;
 $17 = $15;
 $18 = (($16) - ($17))|0;
 $19 = (($18|0) / 28)&-1;
 $20 = ($19|0)>(3120);
 $$ = $20 ? 3120 : $19;
 $21 = (__ZN9GfxDevice13GetDynamicVBOEv($13)|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($$*21)|0;
 $26 = (FUNCTION_TABLE_iiiiiiii[$24 & 127]($21,24,$25,0,1,$vbPtr,0)|0);
 if (!($26)) {
  STACKTOP = sp;return;
 }
 $27 = (__Z16GetRenderManagerv()|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$0>>2] = $28;
 $29 = HEAP32[560624>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  label = 13;
 } else {
  $31 = (($29) + 36|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($29) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32|0)==($34|0);
  do {
   if ($35) {
    $36 = (($29) + 28|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($29) + 32|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($37) + ($39<<3)|0);
    $56 = $40;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i$i,$29,$0);
    $41 = HEAP32[$pos$i$i$i$i$i$i>>2]|0;
    $42 = ($41|0)==(-1);
    $43 = (($29) + 28|0);
    $44 = HEAP32[$43>>2]|0;
    if ($42) {
     $45 = (($29) + 32|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($44) + ($46<<3)|0);
     $56 = $47;
     break;
    } else {
     $48 = (($44) + ($41<<3)|0);
     $56 = $48;
     break;
    }
   }
  } while(0);
  $49 = HEAP32[560624>>2]|0;
  $50 = (($49) + 28|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 32|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + ($53<<3)|0);
  $55 = ($56|0)==($54|0);
  if ($55) {
   label = 13;
  } else {
   $57 = (($56) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==(0|0);
   if ($59) {
    label = 13;
   } else {
    $temp$0$i$i$i = $58;
   }
  }
 }
 if ((label|0) == 13) {
  $60 = HEAP32[$27>>2]|0;
  $61 = (__Z31ReadObjectFromPersistentManageri($60)|0);
  $temp$0$i$i$i = $61;
 }
 $62 = (($temp$0$i$i$i) + 412|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (__ZNK6Camera22GetWorldToCameraMatrixEv($temp$0$i$i$i)|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($64) + 4|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($64) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($64) + 16|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($64) + 20|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($64) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($64) + 32|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($64) + 36|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($64) + 40|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($64) + 48|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($64) + 52|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($64) + 56|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = ($$|0)>(0);
 if ($88) {
  $89 = HEAP32[$1>>2]|0;
  $90 = HEAP8[((640792 + 258|0))>>0]|0;
  $91 = ($90<<24>>24)==(0);
  $92 = ($18|0)<(87360);
  $93 = $92 ? $19 : 3120;
  if ($91) {
   $halosToRender$033$us = 0;$i$030$us = 0;
   while(1) {
    $94 = (($89) + (($i$030$us*28)|0)|0);
    $95 = Math_fround(HEAPF32[$94>>2]);
    $96 = Math_fround($65 * $95);
    $97 = ((($89) + (($i$030$us*28)|0)|0) + 4|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = Math_fround($71 * $98);
    $100 = Math_fround($96 + $99);
    $101 = ((($89) + (($i$030$us*28)|0)|0) + 8|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $103 = Math_fround($77 * $102);
    $104 = Math_fround($100 + $103);
    $105 = Math_fround($83 + $104);
    $106 = Math_fround($67 * $95);
    $107 = Math_fround($73 * $98);
    $108 = Math_fround($106 + $107);
    $109 = Math_fround($79 * $102);
    $110 = Math_fround($108 + $109);
    $111 = Math_fround($85 + $110);
    $112 = Math_fround($69 * $95);
    $113 = Math_fround($75 * $98);
    $114 = Math_fround($112 + $113);
    $115 = Math_fround($81 * $102);
    $116 = Math_fround($114 + $115);
    $117 = Math_fround($87 + $116);
    $118 = ((($89) + (($i$030$us*28)|0)|0) + 16|0);
    $119 = Math_fround(HEAPF32[$118>>2]);
    $120 = Math_fround(-$119);
    $121 = $117 > $120;
    if ($121) {
     $halosToRender$1$us = $halosToRender$033$us;
    } else {
     $122 = ((($89) + (($i$030$us*28)|0)|0) + 24|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = $123 & $63;
     $125 = ($124|0)==(0);
     if ($125) {
      $halosToRender$1$us = $halosToRender$033$us;
     } else {
      $126 = Math_fround($119 * Math_fround(-2.0));
      $127 = !($117 <= $126);
      if ($127) {
       $130 = Math_fround($117 * Math_fround(-255.0));
       $131 = Math_fround($130 / $119);
       $132 = Math_fround($131 + Math_fround(-255.0));
       $133 = Math_fround($132 + Math_fround(0.5));
       $134 = !($133 >= Math_fround(0.0));
       if ($134) {
        $135 = Math_fround($133 + Math_fround(-0.999999940395355224609));
        $$sink$i$i$us = $135;
       } else {
        $$sink$i$i$us = $133;
       }
       $136 = (~~(($$sink$i$i$us)));
       $137 = ((($89) + (($i$030$us*28)|0)|0) + 12|0);
       $138 = (($136) + 1)|0;
       $139 = HEAP32[$137>>2]|0;
       $140 = $139 & 16711935;
       $141 = Math_imul($140, $138)|0;
       $142 = $141 >>> 8;
       $143 = $142 & 16711935;
       $144 = $139 >>> 8;
       $145 = $144 & 16711935;
       $146 = Math_imul($145, $138)|0;
       $147 = $146 & -16711936;
       $148 = $143 | $147;
       $$sink$in$us = $148;
      } else {
       $128 = ((($89) + (($i$030$us*28)|0)|0) + 12|0);
       $129 = HEAP32[$128>>2]|0;
       $$sink$in$us = $129;
      }
      $149 = Math_fround($119 * Math_fround(0.333000004291534423828));
      $150 = Math_fround($149 + $117);
      $151 = HEAP32[$vbPtr>>2]|0;
      HEAPF32[$151>>2] = $105;
      $152 = (($151) + 4|0);
      HEAPF32[$152>>2] = $111;
      $153 = (($151) + 8|0);
      HEAPF32[$153>>2] = $150;
      $154 = (($151) + 12|0);
      HEAP32[$154>>2] = $$sink$in$us;
      $155 = (($151) + 16|0);
      HEAPF32[$155>>2] = Math_fround(0.5);
      $156 = (($151) + 20|0);
      HEAPF32[$156>>2] = Math_fround(0.5);
      $157 = (($151) + 24|0);
      HEAPF32[$157>>2] = $105;
      $158 = (($151) + 28|0);
      HEAPF32[$158>>2] = $111;
      $159 = (($151) + 32|0);
      HEAPF32[$159>>2] = $150;
      $160 = (($151) + 36|0);
      HEAP32[$160>>2] = $$sink$in$us;
      $161 = (($151) + 40|0);
      HEAPF32[$161>>2] = Math_fround(0.5);
      $162 = (($151) + 44|0);
      HEAPF32[$162>>2] = Math_fround(0.5);
      $163 = Math_fround($105 - $119);
      $164 = (($151) + 48|0);
      HEAPF32[$164>>2] = $163;
      $165 = (($151) + 52|0);
      HEAPF32[$165>>2] = $111;
      $166 = (($151) + 56|0);
      HEAPF32[$166>>2] = $117;
      $167 = (($151) + 60|0);
      HEAP32[$167>>2] = $$sink$in$us;
      $168 = (($151) + 64|0);
      HEAPF32[$168>>2] = Math_fround(0.0);
      $169 = (($151) + 68|0);
      HEAPF32[$169>>2] = Math_fround(0.5);
      $170 = (($151) + 72|0);
      HEAPF32[$170>>2] = $105;
      $171 = (($151) + 76|0);
      HEAPF32[$171>>2] = $111;
      $172 = (($151) + 80|0);
      HEAPF32[$172>>2] = $150;
      $173 = (($151) + 84|0);
      HEAP32[$173>>2] = $$sink$in$us;
      $174 = (($151) + 88|0);
      HEAPF32[$174>>2] = Math_fround(0.5);
      $175 = (($151) + 92|0);
      HEAPF32[$175>>2] = Math_fround(0.5);
      $176 = Math_fround($111 - $119);
      $177 = (($151) + 96|0);
      HEAPF32[$177>>2] = $163;
      $178 = (($151) + 100|0);
      HEAPF32[$178>>2] = $176;
      $179 = (($151) + 104|0);
      HEAPF32[$179>>2] = $117;
      $180 = (($151) + 108|0);
      HEAP32[$180>>2] = $$sink$in$us;
      $181 = (($151) + 112|0);
      HEAPF32[$181>>2] = Math_fround(0.0);
      $182 = (($151) + 116|0);
      HEAPF32[$182>>2] = Math_fround(0.0);
      $183 = (($151) + 120|0);
      HEAPF32[$183>>2] = $105;
      $184 = (($151) + 124|0);
      HEAPF32[$184>>2] = $111;
      $185 = (($151) + 128|0);
      HEAPF32[$185>>2] = $150;
      $186 = (($151) + 132|0);
      HEAP32[$186>>2] = $$sink$in$us;
      $187 = (($151) + 136|0);
      HEAPF32[$187>>2] = Math_fround(0.5);
      $188 = (($151) + 140|0);
      HEAPF32[$188>>2] = Math_fround(0.5);
      $189 = (($151) + 144|0);
      HEAPF32[$189>>2] = $105;
      $190 = (($151) + 148|0);
      HEAPF32[$190>>2] = $176;
      $191 = (($151) + 152|0);
      HEAPF32[$191>>2] = $117;
      $192 = (($151) + 156|0);
      HEAP32[$192>>2] = $$sink$in$us;
      $193 = (($151) + 160|0);
      HEAPF32[$193>>2] = Math_fround(0.5);
      $194 = (($151) + 164|0);
      HEAPF32[$194>>2] = Math_fround(0.0);
      $195 = (($151) + 168|0);
      HEAPF32[$195>>2] = $105;
      $196 = (($151) + 172|0);
      HEAPF32[$196>>2] = $111;
      $197 = (($151) + 176|0);
      HEAPF32[$197>>2] = $150;
      $198 = (($151) + 180|0);
      HEAP32[$198>>2] = $$sink$in$us;
      $199 = (($151) + 184|0);
      HEAPF32[$199>>2] = Math_fround(0.5);
      $200 = (($151) + 188|0);
      HEAPF32[$200>>2] = Math_fround(0.5);
      $201 = Math_fround($119 + $105);
      $202 = (($151) + 192|0);
      HEAPF32[$202>>2] = $201;
      $203 = (($151) + 196|0);
      HEAPF32[$203>>2] = $176;
      $204 = (($151) + 200|0);
      HEAPF32[$204>>2] = $117;
      $205 = (($151) + 204|0);
      HEAP32[$205>>2] = $$sink$in$us;
      $206 = (($151) + 208|0);
      HEAPF32[$206>>2] = Math_fround(1.0);
      $207 = (($151) + 212|0);
      HEAPF32[$207>>2] = Math_fround(0.0);
      $208 = (($151) + 216|0);
      HEAPF32[$208>>2] = $105;
      $209 = (($151) + 220|0);
      HEAPF32[$209>>2] = $111;
      $210 = (($151) + 224|0);
      HEAPF32[$210>>2] = $150;
      $211 = (($151) + 228|0);
      HEAP32[$211>>2] = $$sink$in$us;
      $212 = (($151) + 232|0);
      HEAPF32[$212>>2] = Math_fround(0.5);
      $213 = (($151) + 236|0);
      HEAPF32[$213>>2] = Math_fround(0.5);
      $214 = (($151) + 240|0);
      HEAPF32[$214>>2] = $201;
      $215 = (($151) + 244|0);
      HEAPF32[$215>>2] = $111;
      $216 = (($151) + 248|0);
      HEAPF32[$216>>2] = $117;
      $217 = (($151) + 252|0);
      HEAP32[$217>>2] = $$sink$in$us;
      $218 = (($151) + 256|0);
      HEAPF32[$218>>2] = Math_fround(1.0);
      $219 = (($151) + 260|0);
      HEAPF32[$219>>2] = Math_fround(0.5);
      $220 = (($151) + 264|0);
      HEAPF32[$220>>2] = $105;
      $221 = (($151) + 268|0);
      HEAPF32[$221>>2] = $111;
      $222 = (($151) + 272|0);
      HEAPF32[$222>>2] = $150;
      $223 = (($151) + 276|0);
      HEAP32[$223>>2] = $$sink$in$us;
      $224 = (($151) + 280|0);
      HEAPF32[$224>>2] = Math_fround(0.5);
      $225 = (($151) + 284|0);
      HEAPF32[$225>>2] = Math_fround(0.5);
      $226 = Math_fround($119 + $111);
      $227 = (($151) + 288|0);
      HEAPF32[$227>>2] = $201;
      $228 = (($151) + 292|0);
      HEAPF32[$228>>2] = $226;
      $229 = (($151) + 296|0);
      HEAPF32[$229>>2] = $117;
      $230 = (($151) + 300|0);
      HEAP32[$230>>2] = $$sink$in$us;
      $231 = (($151) + 304|0);
      HEAPF32[$231>>2] = Math_fround(1.0);
      $232 = (($151) + 308|0);
      HEAPF32[$232>>2] = Math_fround(1.0);
      $233 = (($151) + 312|0);
      HEAPF32[$233>>2] = $105;
      $234 = (($151) + 316|0);
      HEAPF32[$234>>2] = $111;
      $235 = (($151) + 320|0);
      HEAPF32[$235>>2] = $150;
      $236 = (($151) + 324|0);
      HEAP32[$236>>2] = $$sink$in$us;
      $237 = (($151) + 328|0);
      HEAPF32[$237>>2] = Math_fround(0.5);
      $238 = (($151) + 332|0);
      HEAPF32[$238>>2] = Math_fround(0.5);
      $239 = (($151) + 336|0);
      HEAPF32[$239>>2] = $105;
      $240 = (($151) + 340|0);
      HEAPF32[$240>>2] = $226;
      $241 = (($151) + 344|0);
      HEAPF32[$241>>2] = $117;
      $242 = (($151) + 348|0);
      HEAP32[$242>>2] = $$sink$in$us;
      $243 = (($151) + 352|0);
      HEAPF32[$243>>2] = Math_fround(0.5);
      $244 = (($151) + 356|0);
      HEAPF32[$244>>2] = Math_fround(1.0);
      $245 = (($151) + 360|0);
      HEAPF32[$245>>2] = $105;
      $246 = (($151) + 364|0);
      HEAPF32[$246>>2] = $111;
      $247 = (($151) + 368|0);
      HEAPF32[$247>>2] = $150;
      $248 = (($151) + 372|0);
      HEAP32[$248>>2] = $$sink$in$us;
      $249 = (($151) + 376|0);
      HEAPF32[$249>>2] = Math_fround(0.5);
      $250 = (($151) + 380|0);
      HEAPF32[$250>>2] = Math_fround(0.5);
      $251 = (($151) + 384|0);
      HEAPF32[$251>>2] = $163;
      $252 = (($151) + 388|0);
      HEAPF32[$252>>2] = $226;
      $253 = (($151) + 392|0);
      HEAPF32[$253>>2] = $117;
      $254 = (($151) + 396|0);
      HEAP32[$254>>2] = $$sink$in$us;
      $255 = (($151) + 400|0);
      HEAPF32[$255>>2] = Math_fround(0.0);
      $256 = (($151) + 404|0);
      HEAPF32[$256>>2] = Math_fround(1.0);
      $257 = (($151) + 408|0);
      HEAPF32[$257>>2] = $105;
      $258 = (($151) + 412|0);
      HEAPF32[$258>>2] = $111;
      $259 = (($151) + 416|0);
      HEAPF32[$259>>2] = $150;
      $260 = (($151) + 420|0);
      HEAP32[$260>>2] = $$sink$in$us;
      $261 = (($151) + 424|0);
      HEAPF32[$261>>2] = Math_fround(0.5);
      $262 = (($151) + 428|0);
      HEAPF32[$262>>2] = Math_fround(0.5);
      $263 = (($151) + 432|0);
      HEAPF32[$263>>2] = $163;
      $264 = (($151) + 436|0);
      HEAPF32[$264>>2] = $111;
      $265 = (($151) + 440|0);
      HEAPF32[$265>>2] = $117;
      $266 = (($151) + 444|0);
      HEAP32[$266>>2] = $$sink$in$us;
      $267 = (($151) + 448|0);
      HEAPF32[$267>>2] = Math_fround(0.0);
      $268 = (($151) + 452|0);
      HEAPF32[$268>>2] = Math_fround(0.5);
      $269 = (($151) + 456|0);
      HEAPF32[$269>>2] = $105;
      $270 = (($151) + 460|0);
      HEAPF32[$270>>2] = $111;
      $271 = (($151) + 464|0);
      HEAPF32[$271>>2] = $150;
      $272 = (($151) + 468|0);
      HEAP32[$272>>2] = $$sink$in$us;
      $273 = (($151) + 472|0);
      HEAPF32[$273>>2] = Math_fround(0.5);
      $274 = (($151) + 476|0);
      HEAPF32[$274>>2] = Math_fround(0.5);
      $275 = (($151) + 480|0);
      HEAPF32[$275>>2] = $105;
      $276 = (($151) + 484|0);
      HEAPF32[$276>>2] = $111;
      $277 = (($151) + 488|0);
      HEAPF32[$277>>2] = $150;
      $278 = (($151) + 492|0);
      HEAP32[$278>>2] = $$sink$in$us;
      $279 = (($151) + 496|0);
      HEAPF32[$279>>2] = Math_fround(0.5);
      $280 = (($151) + 500|0);
      HEAPF32[$280>>2] = Math_fround(0.5);
      $281 = (($151) + 504|0);
      HEAP32[$vbPtr>>2] = $281;
      $282 = (($halosToRender$033$us) + 1)|0;
      $halosToRender$1$us = $282;
     }
    }
    $283 = (($i$030$us) + 1)|0;
    $exitcond35 = ($283|0)==($93|0);
    if ($exitcond35) {
     $halosToRender$0$lcssa = $halosToRender$1$us;
     break;
    } else {
     $halosToRender$033$us = $halosToRender$1$us;$i$030$us = $283;
    }
   }
  } else {
   $halosToRender$033 = 0;$i$030 = 0;
   while(1) {
    $284 = (($89) + (($i$030*28)|0)|0);
    $285 = Math_fround(HEAPF32[$284>>2]);
    $286 = Math_fround($65 * $285);
    $287 = ((($89) + (($i$030*28)|0)|0) + 4|0);
    $288 = Math_fround(HEAPF32[$287>>2]);
    $289 = Math_fround($71 * $288);
    $290 = Math_fround($286 + $289);
    $291 = ((($89) + (($i$030*28)|0)|0) + 8|0);
    $292 = Math_fround(HEAPF32[$291>>2]);
    $293 = Math_fround($77 * $292);
    $294 = Math_fround($290 + $293);
    $295 = Math_fround($83 + $294);
    $296 = Math_fround($67 * $285);
    $297 = Math_fround($73 * $288);
    $298 = Math_fround($296 + $297);
    $299 = Math_fround($79 * $292);
    $300 = Math_fround($298 + $299);
    $301 = Math_fround($85 + $300);
    $302 = Math_fround($69 * $285);
    $303 = Math_fround($75 * $288);
    $304 = Math_fround($302 + $303);
    $305 = Math_fround($81 * $292);
    $306 = Math_fround($304 + $305);
    $307 = Math_fround($87 + $306);
    $308 = ((($89) + (($i$030*28)|0)|0) + 16|0);
    $309 = Math_fround(HEAPF32[$308>>2]);
    $310 = Math_fround(-$309);
    $311 = $307 > $310;
    if ($311) {
     $halosToRender$1 = $halosToRender$033;
    } else {
     $312 = ((($89) + (($i$030*28)|0)|0) + 24|0);
     $313 = HEAP32[$312>>2]|0;
     $314 = $313 & $63;
     $315 = ($314|0)==(0);
     if ($315) {
      $halosToRender$1 = $halosToRender$033;
     } else {
      $316 = Math_fround($309 * Math_fround(-2.0));
      $317 = !($307 <= $316);
      if ($317) {
       $320 = Math_fround($307 * Math_fround(-255.0));
       $321 = Math_fround($320 / $309);
       $322 = Math_fround($321 + Math_fround(-255.0));
       $323 = Math_fround($322 + Math_fround(0.5));
       $324 = !($323 >= Math_fround(0.0));
       if ($324) {
        $325 = Math_fround($323 + Math_fround(-0.999999940395355224609));
        $$sink$i$i = $325;
       } else {
        $$sink$i$i = $323;
       }
       $326 = (~~(($$sink$i$i)));
       $327 = ((($89) + (($i$030*28)|0)|0) + 12|0);
       $328 = (($326) + 1)|0;
       $329 = HEAP32[$327>>2]|0;
       $330 = $329 & 16711935;
       $331 = Math_imul($330, $328)|0;
       $332 = $331 >>> 8;
       $333 = $332 & 16711935;
       $334 = $329 >>> 8;
       $335 = $334 & 16711935;
       $336 = Math_imul($335, $328)|0;
       $337 = $336 & -16711936;
       $338 = $333 | $337;
       $$sink$in = $338;
      } else {
       $318 = ((($89) + (($i$030*28)|0)|0) + 12|0);
       $319 = HEAP32[$318>>2]|0;
       $$sink$in = $319;
      }
      $$sink = $$sink$in >>> 16;
      $339 = $$sink$in & -16777216;
      $340 = Math_fround($309 * Math_fround(0.333000004291534423828));
      $341 = Math_fround($340 + $307);
      $342 = HEAP32[$vbPtr>>2]|0;
      HEAPF32[$342>>2] = $295;
      $343 = (($342) + 4|0);
      HEAPF32[$343>>2] = $301;
      $344 = (($342) + 8|0);
      HEAPF32[$344>>2] = $341;
      $345 = (($342) + 12|0);
      $346 = $$sink$in << 16;
      $347 = $346 & 16711680;
      $348 = $347 | $339;
      $349 = $$sink$in & 65280;
      $350 = $348 | $349;
      $351 = $$sink & 255;
      $352 = $350 | $351;
      HEAP32[$345>>2] = $352;
      $353 = (($342) + 16|0);
      HEAPF32[$353>>2] = Math_fround(0.5);
      $354 = (($342) + 20|0);
      HEAPF32[$354>>2] = Math_fround(0.5);
      $355 = (($342) + 24|0);
      HEAPF32[$355>>2] = $295;
      $356 = (($342) + 28|0);
      HEAPF32[$356>>2] = $301;
      $357 = (($342) + 32|0);
      HEAPF32[$357>>2] = $341;
      $358 = (($342) + 36|0);
      HEAP32[$358>>2] = $352;
      $359 = (($342) + 40|0);
      HEAPF32[$359>>2] = Math_fround(0.5);
      $360 = (($342) + 44|0);
      HEAPF32[$360>>2] = Math_fround(0.5);
      $361 = Math_fround($295 - $309);
      $362 = (($342) + 48|0);
      HEAPF32[$362>>2] = $361;
      $363 = (($342) + 52|0);
      HEAPF32[$363>>2] = $301;
      $364 = (($342) + 56|0);
      HEAPF32[$364>>2] = $307;
      $365 = (($342) + 60|0);
      HEAP32[$365>>2] = $352;
      $366 = (($342) + 64|0);
      HEAPF32[$366>>2] = Math_fround(0.0);
      $367 = (($342) + 68|0);
      HEAPF32[$367>>2] = Math_fround(0.5);
      $368 = (($342) + 72|0);
      HEAPF32[$368>>2] = $295;
      $369 = (($342) + 76|0);
      HEAPF32[$369>>2] = $301;
      $370 = (($342) + 80|0);
      HEAPF32[$370>>2] = $341;
      $371 = (($342) + 84|0);
      HEAP32[$371>>2] = $352;
      $372 = (($342) + 88|0);
      HEAPF32[$372>>2] = Math_fround(0.5);
      $373 = (($342) + 92|0);
      HEAPF32[$373>>2] = Math_fround(0.5);
      $374 = Math_fround($301 - $309);
      $375 = (($342) + 96|0);
      HEAPF32[$375>>2] = $361;
      $376 = (($342) + 100|0);
      HEAPF32[$376>>2] = $374;
      $377 = (($342) + 104|0);
      HEAPF32[$377>>2] = $307;
      $378 = (($342) + 108|0);
      HEAP32[$378>>2] = $352;
      $379 = (($342) + 112|0);
      HEAPF32[$379>>2] = Math_fround(0.0);
      $380 = (($342) + 116|0);
      HEAPF32[$380>>2] = Math_fround(0.0);
      $381 = (($342) + 120|0);
      HEAPF32[$381>>2] = $295;
      $382 = (($342) + 124|0);
      HEAPF32[$382>>2] = $301;
      $383 = (($342) + 128|0);
      HEAPF32[$383>>2] = $341;
      $384 = (($342) + 132|0);
      HEAP32[$384>>2] = $352;
      $385 = (($342) + 136|0);
      HEAPF32[$385>>2] = Math_fround(0.5);
      $386 = (($342) + 140|0);
      HEAPF32[$386>>2] = Math_fround(0.5);
      $387 = (($342) + 144|0);
      HEAPF32[$387>>2] = $295;
      $388 = (($342) + 148|0);
      HEAPF32[$388>>2] = $374;
      $389 = (($342) + 152|0);
      HEAPF32[$389>>2] = $307;
      $390 = (($342) + 156|0);
      HEAP32[$390>>2] = $352;
      $391 = (($342) + 160|0);
      HEAPF32[$391>>2] = Math_fround(0.5);
      $392 = (($342) + 164|0);
      HEAPF32[$392>>2] = Math_fround(0.0);
      $393 = (($342) + 168|0);
      HEAPF32[$393>>2] = $295;
      $394 = (($342) + 172|0);
      HEAPF32[$394>>2] = $301;
      $395 = (($342) + 176|0);
      HEAPF32[$395>>2] = $341;
      $396 = (($342) + 180|0);
      HEAP32[$396>>2] = $352;
      $397 = (($342) + 184|0);
      HEAPF32[$397>>2] = Math_fround(0.5);
      $398 = (($342) + 188|0);
      HEAPF32[$398>>2] = Math_fround(0.5);
      $399 = Math_fround($309 + $295);
      $400 = (($342) + 192|0);
      HEAPF32[$400>>2] = $399;
      $401 = (($342) + 196|0);
      HEAPF32[$401>>2] = $374;
      $402 = (($342) + 200|0);
      HEAPF32[$402>>2] = $307;
      $403 = (($342) + 204|0);
      HEAP32[$403>>2] = $352;
      $404 = (($342) + 208|0);
      HEAPF32[$404>>2] = Math_fround(1.0);
      $405 = (($342) + 212|0);
      HEAPF32[$405>>2] = Math_fround(0.0);
      $406 = (($342) + 216|0);
      HEAPF32[$406>>2] = $295;
      $407 = (($342) + 220|0);
      HEAPF32[$407>>2] = $301;
      $408 = (($342) + 224|0);
      HEAPF32[$408>>2] = $341;
      $409 = (($342) + 228|0);
      HEAP32[$409>>2] = $352;
      $410 = (($342) + 232|0);
      HEAPF32[$410>>2] = Math_fround(0.5);
      $411 = (($342) + 236|0);
      HEAPF32[$411>>2] = Math_fround(0.5);
      $412 = (($342) + 240|0);
      HEAPF32[$412>>2] = $399;
      $413 = (($342) + 244|0);
      HEAPF32[$413>>2] = $301;
      $414 = (($342) + 248|0);
      HEAPF32[$414>>2] = $307;
      $415 = (($342) + 252|0);
      HEAP32[$415>>2] = $352;
      $416 = (($342) + 256|0);
      HEAPF32[$416>>2] = Math_fround(1.0);
      $417 = (($342) + 260|0);
      HEAPF32[$417>>2] = Math_fround(0.5);
      $418 = (($342) + 264|0);
      HEAPF32[$418>>2] = $295;
      $419 = (($342) + 268|0);
      HEAPF32[$419>>2] = $301;
      $420 = (($342) + 272|0);
      HEAPF32[$420>>2] = $341;
      $421 = (($342) + 276|0);
      HEAP32[$421>>2] = $352;
      $422 = (($342) + 280|0);
      HEAPF32[$422>>2] = Math_fround(0.5);
      $423 = (($342) + 284|0);
      HEAPF32[$423>>2] = Math_fround(0.5);
      $424 = Math_fround($309 + $301);
      $425 = (($342) + 288|0);
      HEAPF32[$425>>2] = $399;
      $426 = (($342) + 292|0);
      HEAPF32[$426>>2] = $424;
      $427 = (($342) + 296|0);
      HEAPF32[$427>>2] = $307;
      $428 = (($342) + 300|0);
      HEAP32[$428>>2] = $352;
      $429 = (($342) + 304|0);
      HEAPF32[$429>>2] = Math_fround(1.0);
      $430 = (($342) + 308|0);
      HEAPF32[$430>>2] = Math_fround(1.0);
      $431 = (($342) + 312|0);
      HEAPF32[$431>>2] = $295;
      $432 = (($342) + 316|0);
      HEAPF32[$432>>2] = $301;
      $433 = (($342) + 320|0);
      HEAPF32[$433>>2] = $341;
      $434 = (($342) + 324|0);
      HEAP32[$434>>2] = $352;
      $435 = (($342) + 328|0);
      HEAPF32[$435>>2] = Math_fround(0.5);
      $436 = (($342) + 332|0);
      HEAPF32[$436>>2] = Math_fround(0.5);
      $437 = (($342) + 336|0);
      HEAPF32[$437>>2] = $295;
      $438 = (($342) + 340|0);
      HEAPF32[$438>>2] = $424;
      $439 = (($342) + 344|0);
      HEAPF32[$439>>2] = $307;
      $440 = (($342) + 348|0);
      HEAP32[$440>>2] = $352;
      $441 = (($342) + 352|0);
      HEAPF32[$441>>2] = Math_fround(0.5);
      $442 = (($342) + 356|0);
      HEAPF32[$442>>2] = Math_fround(1.0);
      $443 = (($342) + 360|0);
      HEAPF32[$443>>2] = $295;
      $444 = (($342) + 364|0);
      HEAPF32[$444>>2] = $301;
      $445 = (($342) + 368|0);
      HEAPF32[$445>>2] = $341;
      $446 = (($342) + 372|0);
      HEAP32[$446>>2] = $352;
      $447 = (($342) + 376|0);
      HEAPF32[$447>>2] = Math_fround(0.5);
      $448 = (($342) + 380|0);
      HEAPF32[$448>>2] = Math_fround(0.5);
      $449 = (($342) + 384|0);
      HEAPF32[$449>>2] = $361;
      $450 = (($342) + 388|0);
      HEAPF32[$450>>2] = $424;
      $451 = (($342) + 392|0);
      HEAPF32[$451>>2] = $307;
      $452 = (($342) + 396|0);
      HEAP32[$452>>2] = $352;
      $453 = (($342) + 400|0);
      HEAPF32[$453>>2] = Math_fround(0.0);
      $454 = (($342) + 404|0);
      HEAPF32[$454>>2] = Math_fround(1.0);
      $455 = (($342) + 408|0);
      HEAPF32[$455>>2] = $295;
      $456 = (($342) + 412|0);
      HEAPF32[$456>>2] = $301;
      $457 = (($342) + 416|0);
      HEAPF32[$457>>2] = $341;
      $458 = (($342) + 420|0);
      HEAP32[$458>>2] = $352;
      $459 = (($342) + 424|0);
      HEAPF32[$459>>2] = Math_fround(0.5);
      $460 = (($342) + 428|0);
      HEAPF32[$460>>2] = Math_fround(0.5);
      $461 = (($342) + 432|0);
      HEAPF32[$461>>2] = $361;
      $462 = (($342) + 436|0);
      HEAPF32[$462>>2] = $301;
      $463 = (($342) + 440|0);
      HEAPF32[$463>>2] = $307;
      $464 = (($342) + 444|0);
      HEAP32[$464>>2] = $352;
      $465 = (($342) + 448|0);
      HEAPF32[$465>>2] = Math_fround(0.0);
      $466 = (($342) + 452|0);
      HEAPF32[$466>>2] = Math_fround(0.5);
      $467 = (($342) + 456|0);
      HEAPF32[$467>>2] = $295;
      $468 = (($342) + 460|0);
      HEAPF32[$468>>2] = $301;
      $469 = (($342) + 464|0);
      HEAPF32[$469>>2] = $341;
      $470 = (($342) + 468|0);
      HEAP32[$470>>2] = $352;
      $471 = (($342) + 472|0);
      HEAPF32[$471>>2] = Math_fround(0.5);
      $472 = (($342) + 476|0);
      HEAPF32[$472>>2] = Math_fround(0.5);
      $473 = (($342) + 480|0);
      HEAPF32[$473>>2] = $295;
      $474 = (($342) + 484|0);
      HEAPF32[$474>>2] = $301;
      $475 = (($342) + 488|0);
      HEAPF32[$475>>2] = $341;
      $476 = (($342) + 492|0);
      HEAP32[$476>>2] = $352;
      $477 = (($342) + 496|0);
      HEAPF32[$477>>2] = Math_fround(0.5);
      $478 = (($342) + 500|0);
      HEAPF32[$478>>2] = Math_fround(0.5);
      $479 = (($342) + 504|0);
      HEAP32[$vbPtr>>2] = $479;
      $480 = (($halosToRender$033) + 1)|0;
      $halosToRender$1 = $480;
     }
    }
    $481 = (($i$030) + 1)|0;
    $exitcond = ($481|0)==($93|0);
    if ($exitcond) {
     $halosToRender$0$lcssa = $halosToRender$1;
     break;
    } else {
     $halosToRender$033 = $halosToRender$1;$i$030 = $481;
    }
   }
  }
 } else {
  $halosToRender$0$lcssa = 0;
 }
 $482 = HEAP32[$21>>2]|0;
 $483 = (($482) + 12|0);
 $484 = HEAP32[$483>>2]|0;
 $485 = ($halosToRender$0$lcssa*21)|0;
 FUNCTION_TABLE_viii[$484 & 4095]($21,$485,0);
 $486 = HEAP32[$13>>2]|0;
 $487 = (($486) + 116|0);
 $488 = HEAP32[$487>>2]|0;
 $489 = (FUNCTION_TABLE_ii[$488 & 4095]($13)|0);
 dest=$pos$i$i$i$i$i$i+0|0; src=$489+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $490 = HEAP32[$13>>2]|0;
 $491 = (($490) + 112|0);
 $492 = HEAP32[$491>>2]|0;
 $493 = (FUNCTION_TABLE_ii[$492 & 4095]($13)|0);
 dest=$matWorld+0|0; src=$493+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $494 = HEAP32[$13>>2]|0;
 $495 = (($494) + 100|0);
 $496 = HEAP32[$495>>2]|0;
 FUNCTION_TABLE_vii[$496 & 4095]($13,616552);
 $497 = HEAP32[572312>>2]|0;
 $498 = (__ZN5Unity8Material17SetPassWithShaderEiP6ShaderRN9ShaderLab17ShaderPassContextEi($497,0,$11,$passContext,$12)|0);
 $499 = HEAP32[$21>>2]|0;
 $500 = (($499) + 16|0);
 $501 = HEAP32[$500>>2]|0;
 $502 = (($498) + 4|0);
 $503 = HEAP32[$502>>2]|0;
 $504 = HEAP32[572160>>2]|0;
 $505 = ($504|0)==(0|0);
 if ($505) {
  $506 = (__Z26GetMeshVertexFormatManagerv()|0);
  $507 = (__ZN23MeshVertexFormatManager10GetDefaultEj($506,13)|0);
  HEAP32[572160>>2] = $507;
  $508 = $507;
 } else {
  $508 = $504;
 }
 $509 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($508,$503,0)|0);
 FUNCTION_TABLE_viii[$501 & 4095]($21,$498,$509);
 $510 = HEAP32[$13>>2]|0;
 $511 = (($510) + 100|0);
 $512 = HEAP32[$511>>2]|0;
 FUNCTION_TABLE_vii[$512 & 4095]($13,$pos$i$i$i$i$i$i);
 $513 = HEAP32[$13>>2]|0;
 $514 = (($513) + 96|0);
 $515 = HEAP32[$514>>2]|0;
 FUNCTION_TABLE_vii[$515 & 4095]($13,$matWorld);
 STACKTOP = sp;return;
}
function __ZThn24_N11HaloManager16RenderRenderableERK11CullResultsRN9ShaderLab17ShaderPassContextE($this,$cullResults,$passContext) {
 $this = $this|0;
 $cullResults = $cullResults|0;
 $passContext = $passContext|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 __ZN11HaloManager16RenderRenderableERK11CullResultsRN9ShaderLab17ShaderPassContextE($0,$cullResults,$passContext);
 STACKTOP = sp;return;
}
function __ZN11HaloManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((572168 + 8|0));
 $0 = (($this) + 24|0);
 HEAP32[$0>>2] = ((572168 + 124|0));
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN16LevelGameManagerD2Ev($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 if (!($6)) {
  $__new_last2$i$i$i$i$i$i = $2;
  $scevgep$i$i$i$i$i$i = (($5) + -28|0);
  $7 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($7)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $8 = (($uglygep3$i$i$i$i$i$i>>>0) / 28)&-1;
  $9 = $8 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($5) + (($9*28)|0)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i;
 }
 __ZdlPv($2);
 __ZN16LevelGameManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN11HaloManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $eh$lpad$body$i$indexZ2D = 0;
 var $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((572168 + 8|0));
 $0 = (($this) + 24|0);
 HEAP32[$0>>2] = ((572168 + 124|0));
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $__new_last2$i$i$i$i$i$i$i = $2;
   $scevgep$i$i$i$i$i$i$i = (($5) + -28|0);
   $7 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($7)|0);
   $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
   $8 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 28)&-1;
   $9 = $8 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($5) + (($9*28)|0)|0);
   HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  __ZdlPv($2);
 }
 HEAP32[$this>>2] = ((561080 + 8|0));
 __THREW__ = 0;
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $28 = ___cxa_find_matching_catch(0|0)|0;
   $29 = tempRet0;
   __THREW__ = 0;
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch(0|0)|0;
    $33 = tempRet0;
    ___clang_call_terminate($32);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $28;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   $eh$lpad$body$index8Z2D = $23;$eh$lpad$body$indexZ2D = $22;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $34 = ___cxa_find_matching_catch(0|0)|0;
  $35 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $34;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __THREW__ = 0;
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $18 = ___cxa_find_matching_catch(0|0)|0;
    $19 = tempRet0;
    ___clang_call_terminate($18);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $15;$eh$lpad$body$indexZ2D = $14;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  $eh$lpad$body$index8Z2D = $37;$eh$lpad$body$indexZ2D = $36;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN11HaloManager4HaloENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 28)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(153391689);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 28)&-1;
 $14 = ($13>>>0)<(76695844);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 153391689;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*28)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*28)|0)|0);
 $23 = (($22) + (($$0$i3*28)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  ;HEAP32[$21+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$21+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$21+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$21+24>>2]=HEAP32[$__x+24>>2]|0;
 }
 $25 = (($22) + (($7*28)|0)|0);
 $26 = (($5|0) / -28)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*28)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN12ImageFilters14AddImageFilterERK11ImageFilter($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $$0$i = 0, $$0$i3 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$0$in = 0, $i$01$i = 0, $i$01$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($filter) + 9|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($this) + 12|0);
 $8 = $6 ? $this : $7;
 $9 = HEAP32[$filter>>2]|0;
 $10 = (($9) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 L1: do {
  if ($12) {
   $$0$i = -1;
  } else {
   $13 = (($11) + 32|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)>(0);
   if ($15) {
    $16 = (($11) + 24|0);
    $17 = HEAP32[$16>>2]|0;
    $i$01$i = 0;
    while(1) {
     $20 = ((($17) + ($i$01$i<<3)|0) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($9|0);
     $19 = (($i$01$i) + 1)|0;
     if ($22) {
      $$0$i = $i$01$i;
      break L1;
     }
     $18 = ($19|0)<($14|0);
     if ($18) {
      $i$01$i = $19;
     } else {
      $$0$i = -1;
      break;
     }
    }
   } else {
    $$0$i = -1;
   }
  }
 } while(0);
 $23 = (($8) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$8>>2]|0;
 $26 = $24;
 $27 = $25;
 $28 = (($26) - ($27))|0;
 $29 = (($28|0) / 12)&-1;
 $i$0$in = $29;
 while(1) {
  $i$0 = (($i$0$in) + -1)|0;
  $30 = ($i$0|0)>(-1);
  if (!($30)) {
   label = 15;
   break;
  }
  $31 = (($25) + (($i$0*12)|0)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  L11: do {
   if ($35) {
    $$0$i3 = -1;
   } else {
    $36 = (($34) + 32|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)>(0);
    if ($38) {
     $39 = (($34) + 24|0);
     $40 = HEAP32[$39>>2]|0;
     $i$01$i2 = 0;
     while(1) {
      $43 = ((($40) + ($i$01$i2<<3)|0) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==($32|0);
      $42 = (($i$01$i2) + 1)|0;
      if ($45) {
       $$0$i3 = $i$01$i2;
       break L11;
      }
      $41 = ($42|0)<($37|0);
      if ($41) {
       $i$01$i2 = $42;
      } else {
       $$0$i3 = -1;
       break;
      }
     }
    } else {
     $$0$i3 = -1;
    }
   }
  } while(0);
  $46 = ($$0$i|0)<($$0$i3|0);
  if ($46) {
   $i$0$in = $i$0;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  $47 = (($25) + (($i$0$in*12)|0)|0);
  HEAP32[$0>>2] = $47;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __ZNSt3__16vectorI11ImageFilterNS_9allocatorIS1_EEE6insertENS_11__wrap_iterIPKS1_EERS6_($1,$8,$$byval_copy1,$filter);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  HEAP32[$2>>2] = $25;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZNSt3__16vectorI11ImageFilterNS_9allocatorIS1_EEE6insertENS_11__wrap_iterIPKS1_EERS6_($3,$8,$$byval_copy1,$filter);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI11ImageFilterNS_9allocatorIS1_EEE6insertENS_11__wrap_iterIPKS1_EERS6_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i11 = 0, $$0$i12 = 0, $$pre = 0, $$pre$i10 = 0, $$sum = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$__position>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = (($4|0) / 12)&-1;
 $6 = (($0) + (($5*12)|0)|0);
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)<($10>>>0);
 if ($11) {
  $12 = ($6|0)==($8|0);
  if ($12) {
   $13 = ($6|0)==(0|0);
   if ($13) {
    $15 = 0;
   } else {
    ;HEAP32[$6+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$__x+8>>2]|0;
    $$pre = HEAP32[$7>>2]|0;
    $15 = $$pre;
   }
   $14 = (($15) + 12|0);
   HEAP32[$7>>2] = $14;
   $__p$0 = $6;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($5) + 1)|0;
  $16 = (($0) + (($$sum*12)|0)|0);
  $17 = $8;
  $18 = $16;
  $19 = (($17) - ($18))|0;
  $20 = (($19|0) / 12)&-1;
  $$sum15 = (($20) + ($5))|0;
  $21 = (($0) + (($$sum15*12)|0)|0);
  $22 = ($21>>>0)<($8>>>0);
  if ($22) {
   $24 = $8;$__i$01$i = $21;
   while(1) {
    $23 = ($24|0)==(0|0);
    if ($23) {
     $27 = 0;
    } else {
     ;HEAP32[$24+0>>2]=HEAP32[$__i$01$i+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__i$01$i+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__i$01$i+8>>2]|0;
     $$pre$i10 = HEAP32[$7>>2]|0;
     $27 = $$pre$i10;
    }
    $25 = (($__i$01$i) + 12|0);
    $26 = (($27) + 12|0);
    HEAP32[$7>>2] = $26;
    $28 = ($25>>>0)<($8>>>0);
    if ($28) {
     $24 = $26;$__i$01$i = $25;
    } else {
     break;
    }
   }
  }
  $29 = (($19|0) / -12)&-1;
  $30 = (($8) + (($29*12)|0)|0);
  _memmove(($30|0),($6|0),($19|0))|0;
  $31 = ($6>>>0)>($__x>>>0);
  if ($31) {
   $__xr$0 = $__x;
  } else {
   $32 = HEAP32[$7>>2]|0;
   $33 = ($32>>>0)>($__x>>>0);
   $34 = (($__x) + 12|0);
   $$ = $33 ? $34 : $__x;
   $__xr$0 = $$;
  }
  ;HEAP32[$6+0>>2]=HEAP32[$__xr$0+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$__xr$0+4>>2]|0;HEAP16[$6+8>>1]=HEAP16[$__xr$0+8>>1]|0;
  $__p$0 = $6;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $35 = $8;
 $36 = (($35) - ($3))|0;
 $37 = (($36|0) / 12)&-1;
 $38 = (($37) + 1)|0;
 $39 = ($38>>>0)>(357913941);
 if ($39) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $40 = $10;
 $41 = (($40) - ($3))|0;
 $42 = (($41|0) / 12)&-1;
 $43 = ($42>>>0)<(178956970);
 if ($43) {
  $46 = $42 << 1;
  $47 = ($46>>>0)<($38>>>0);
  $48 = $47 ? $38 : $46;
  $49 = $6;
  $50 = (($4|0) / 12)&-1;
  $51 = ($48|0)==(0);
  if ($51) {
   $$0$i12 = 0;$55 = 0;$56 = $50;$82 = $49;
  } else {
   $$0$i11 = $48;$96 = $50;$97 = $49;
   label = 18;
  }
 } else {
  $44 = $6;
  $45 = (($4|0) / 12)&-1;
  $$0$i11 = 357913941;$96 = $45;$97 = $44;
  label = 18;
 }
 if ((label|0) == 18) {
  $52 = ($$0$i11*12)|0;
  $53 = (__Znwj($52)|0);
  $$0$i12 = $$0$i11;$55 = $53;$56 = $96;$82 = $97;
 }
 $54 = (($55) + (($56*12)|0)|0);
 $57 = (($55) + (($$0$i12*12)|0)|0);
 $58 = ($56|0)==($$0$i12|0);
 do {
  if ($58) {
   $59 = ($56|0)>(0);
   $60 = (($4|0) / 12)&-1;
   if ($59) {
    $61 = (($60) + 1)|0;
    $62 = (($61|0) / -2)&-1;
    $$sum14 = (($62) + ($56))|0;
    $63 = (($55) + (($$sum14*12)|0)|0);
    $76 = $63;$91 = $57;
    break;
   }
   $64 = $60 << 1;
   $65 = ($64|0)==(0);
   $66 = $65 ? 1 : $64;
   $67 = ($66*12)|0;
   __THREW__ = 0;
   $68 = (invoke_ii(2988,($67|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    $71 = $66 >>> 2;
    $72 = (($68) + (($71*12)|0)|0);
    $73 = (($68) + (($66*12)|0)|0);
    $74 = ($55|0)==(0|0);
    if ($74) {
     $76 = $72;$91 = $73;
     break;
    }
    __ZdlPv($55);
    $76 = $72;$91 = $73;
    break;
   }
   $93 = ___cxa_find_matching_catch()|0;
   $94 = tempRet0;
   $95 = ($55|0)==(0|0);
   if ($95) {
    ___resumeException($93|0);
    // unreachable;
   }
   __ZdlPv($55);
   ___resumeException($93|0);
   // unreachable;
  } else {
   $76 = $54;$91 = $57;
  }
 } while(0);
 $75 = ($76|0)==(0|0);
 if ($75) {
  $78 = 0;
 } else {
  ;HEAP32[$76+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$__x+8>>2]|0;
  $78 = $76;
 }
 $77 = (($78) + 12|0);
 $79 = HEAP32[$this>>2]|0;
 $80 = $79;
 $81 = (($82) - ($80))|0;
 $83 = (($81|0) / -12)&-1;
 $84 = (($76) + (($83*12)|0)|0);
 _memcpy(($84|0),($79|0),($81|0))|0;
 $85 = HEAP32[$7>>2]|0;
 $86 = $85;
 $87 = (($86) - ($82))|0;
 $88 = (($87|0) / 12)&-1;
 _memcpy(($77|0),($6|0),($87|0))|0;
 $$sum13 = (($88) + 1)|0;
 $89 = (($78) + (($$sum13*12)|0)|0);
 $90 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $84;
 HEAP32[$7>>2] = $89;
 HEAP32[$9>>2] = $91;
 $92 = ($90|0)==(0|0);
 if ($92) {
  $__p$0 = $76;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 __ZdlPv($90);
 $__p$0 = $76;
 HEAP32[$agg$result>>2] = $__p$0;
 STACKTOP = sp;return;
}
function __ZN12ImageFilters17RemoveImageFilterERK11ImageFilter($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $$be = 0, $$be22 = 0, $$sum$i = 0, $$sum$i4 = 0, $$sum1$i = 0, $$sum1$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i6 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i7 = 0, $scevgep4$i$i$i = 0;
 var $scevgep4$i$i$i11 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i9 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if (!($3)) {
  $4 = (($filter) + 4|0);
  $21 = $2;$6 = $0;
  while(1) {
   $5 = HEAP32[$6>>2]|0;
   $7 = HEAP32[$filter>>2]|0;
   $8 = ($5|0)==($7|0);
   if ($8) {
    $9 = (($6) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = HEAP32[$4>>2]|0;
    $12 = ($10|0)==($11|0);
    if ($12) {
     $13 = HEAP32[$this>>2]|0;
     $14 = $6;
     $15 = $13;
     $16 = (($14) - ($15))|0;
     $17 = (($16|0) / 12)&-1;
     $18 = (($13) + (($17*12)|0)|0);
     $$sum$i4 = (($17) + 1)|0;
     $19 = (($13) + (($$sum$i4*12)|0)|0);
     $20 = $21;
     $22 = $19;
     $23 = (($20) - ($22))|0;
     $24 = (($23|0) / 12)&-1;
     _memmove(($18|0),($19|0),($23|0))|0;
     $$sum1$i5 = (($24) + ($17))|0;
     $25 = (($13) + (($$sum1$i5*12)|0)|0);
     $26 = HEAP32[$1>>2]|0;
     $27 = ($26|0)==($25|0);
     if ($27) {
      $$be22 = $18;$33 = $25;
     } else {
      $__new_last2$i$i$i6 = $25;
      $scevgep$i$i$i7 = (($26) + -12|0);
      $28 = (0 - ($__new_last2$i$i$i6))|0;
      $uglygep$i$i$i9 = (($scevgep$i$i$i7) + ($28)|0);
      $uglygep3$i$i$i10 = $uglygep$i$i$i9;
      $29 = (($uglygep3$i$i$i10>>>0) / 12)&-1;
      $30 = $29 ^ -1;
      $scevgep4$i$i$i11 = (($26) + (($30*12)|0)|0);
      HEAP32[$1>>2] = $scevgep4$i$i$i11;
      $$be22 = $18;$33 = $scevgep4$i$i$i11;
     }
    } else {
     label = 7;
    }
   } else {
    label = 7;
   }
   if ((label|0) == 7) {
    label = 0;
    $31 = (($6) + 12|0);
    $$be22 = $31;$33 = $21;
   }
   $32 = ($$be22|0)==($33|0);
   if ($32) {
    break;
   } else {
    $21 = $33;$6 = $$be22;
   }
  }
 }
 $34 = (($this) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($35|0)==($37|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($filter) + 4|0);
 $41 = $35;$56 = $37;
 while(1) {
  $40 = HEAP32[$41>>2]|0;
  $42 = HEAP32[$filter>>2]|0;
  $43 = ($40|0)==($42|0);
  if ($43) {
   $44 = (($41) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$39>>2]|0;
   $47 = ($45|0)==($46|0);
   if ($47) {
    $48 = HEAP32[$34>>2]|0;
    $49 = $41;
    $50 = $48;
    $51 = (($49) - ($50))|0;
    $52 = (($51|0) / 12)&-1;
    $53 = (($48) + (($52*12)|0)|0);
    $$sum$i = (($52) + 1)|0;
    $54 = (($48) + (($$sum$i*12)|0)|0);
    $55 = $56;
    $57 = $54;
    $58 = (($55) - ($57))|0;
    $59 = (($58|0) / 12)&-1;
    _memmove(($53|0),($54|0),($58|0))|0;
    $$sum1$i = (($59) + ($52))|0;
    $60 = (($48) + (($$sum1$i*12)|0)|0);
    $61 = HEAP32[$36>>2]|0;
    $62 = ($61|0)==($60|0);
    if ($62) {
     $$be = $53;$68 = $60;
    } else {
     $__new_last2$i$i$i = $60;
     $scevgep$i$i$i = (($61) + -12|0);
     $63 = (0 - ($__new_last2$i$i$i))|0;
     $uglygep$i$i$i = (($scevgep$i$i$i) + ($63)|0);
     $uglygep3$i$i$i = $uglygep$i$i$i;
     $64 = (($uglygep3$i$i$i>>>0) / 12)&-1;
     $65 = $64 ^ -1;
     $scevgep4$i$i$i = (($61) + (($65*12)|0)|0);
     HEAP32[$36>>2] = $scevgep4$i$i$i;
     $$be = $53;$68 = $scevgep4$i$i$i;
    }
   } else {
    label = 15;
   }
  } else {
   label = 15;
  }
  if ((label|0) == 15) {
   label = 0;
   $66 = (($41) + 12|0);
   $$be = $66;$68 = $56;
  }
  $67 = ($$be|0)==($68|0);
  if ($67) {
   break;
  } else {
   $41 = $$be;$56 = $68;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12ImageFilters21GetTargetBeforeOpaqueEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN12ImageFilters20GetTargetAfterOpaqueEbb($this,$forceIntoRT,$usingScreenToComposite) {
 $this = $this|0;
 $forceIntoRT = $forceIntoRT|0;
 $usingScreenToComposite = $usingScreenToComposite|0;
 var $$0 = 0, $$0$in = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $brmerge1 = 0, $usingScreenToComposite$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 24|0);
   $$0$in = $4;
  } else {
   $5 = (($this) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($this) + 16|0);
   $8 = HEAP32[$7>>2]|0;
   $$not = ($6|0)!=($8|0);
   $brmerge = $$not | $forceIntoRT;
   if (!($brmerge)) {
    $9 = (($this) + 24|0);
    $$0$in = $9;
    break;
   }
   $usingScreenToComposite$not = $usingScreenToComposite ^ 1;
   $brmerge1 = $usingScreenToComposite$not | $forceIntoRT;
   if ($brmerge1) {
    $11 = (($this) + 28|0);
    $$0$in = $11;
    break;
   } else {
    $10 = (($this) + 24|0);
    $$0$in = $10;
    break;
   }
  }
 } while(0);
 $$0 = HEAP32[$$0$in>>2]|0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12ImageFilters14GetTargetFinalEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z14GetTemporaryRTbbbibb($depthBuffer,$requestHDR,$requestLinear,$antiAliasing,$halfWidth,$halfHeight) {
 $depthBuffer = $depthBuffer|0;
 $requestHDR = $requestHDR|0;
 $requestLinear = $requestLinear|0;
 $antiAliasing = $antiAliasing|0;
 $halfWidth = $halfWidth|0;
 $halfHeight = $halfHeight|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z22GetRenderBufferManagerv()|0);
 $1 = $halfWidth ? -2 : -1;
 $2 = $halfHeight ? -2 : -1;
 $3 = $depthBuffer ? 2 : 0;
 $4 = (__Z12GetGfxDevicev()|0);
 $5 = HEAP32[$4>>2]|0;
 if ($requestHDR) {
  $6 = (($5) + 676|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
  $12 = $8;
 } else {
  $9 = (($5) + 672|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($4)|0);
  $12 = $11;
 }
 if ($requestLinear) {
  $phitmp = $requestHDR ? 1 : 2;
  $13 = $phitmp;
 } else {
  $13 = 1;
 }
 $14 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($0,$1,$2,$3,$12,0,$13,$antiAliasing)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return ($14|0);
 }
 __ZN13RenderTexture24CorrectVerticalTexelSizeEb($14,1);
 $16 = HEAP32[$14>>2]|0;
 $17 = (($16) + 36|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($14,572376);
 STACKTOP = sp;return ($14|0);
}
function __ZN12ImageFilters17SwitchTargetToLDREP13RenderTextureb($this,$oldRt,$requestLinear) {
 $this = $this|0;
 $oldRt = $oldRt|0;
 $requestLinear = $requestLinear|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($oldRt|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__Z22GetRenderBufferManagerv()|0);
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 672|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $$ = $requestLinear ? 2 : 1;
 $7 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($1,-1,-1,0,$6,0,$$,1)|0);
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  __ZN13RenderTexture24CorrectVerticalTexelSizeEb($7,1);
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($7,572376);
 }
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($oldRt|0);
 if ($14) {
  $15 = (__Z22GetRenderBufferManagerv()|0);
  __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($15,$oldRt);
  HEAP32[$12>>2] = $7;
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==($oldRt|0);
 $19 = (__Z22GetRenderBufferManagerv()|0);
 __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($19,$oldRt);
 if (!($18)) {
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$16>>2] = $7;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12ImageFilters7PrepareEbbi($this,$forceIntoRT,$hdr,$antiAliasing) {
 $this = $this|0;
 $forceIntoRT = $forceIntoRT|0;
 $hdr = $hdr|0;
 $antiAliasing = $antiAliasing|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $brmerge = 0, $hdrAfterOpaque$0$off0$ = 0, $hdrAfterOpaque$0$off0$lcssa = 0, $hdrAfterOpaque$0$off08 = 0, $i$09 = 0, $or$cond = 0, $phitmp$i = 0, $phitmp$i4 = 0, $phitmp$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if ($3) {
  $4 = (($this) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $phitmp$i = ($5|0)!=($7|0);
  $brmerge = $phitmp$i | $forceIntoRT;
  if (!($brmerge)) {
   STACKTOP = sp;return;
  }
 }
 $8 = (__ZN13RenderTexture9IsEnabledEv()|0);
 $$not = $8 ^ 1;
 $9 = HEAP32[((640792 + 232|0))>>2]|0;
 $10 = ($9|0)==(0);
 $or$cond = $10 | $$not;
 if ($or$cond) {
  $11 = HEAP8[572400>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if (!($12)) {
   STACKTOP = sp;return;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(572408,0,572496,183,1,0,0,0);
  HEAP8[572400>>0] = 1;
  STACKTOP = sp;return;
 }
 $13 = (__Z19GetActiveColorSpacev()|0);
 $14 = ($13|0)==(1);
 $15 = (__Z22GetRenderBufferManagerv()|0);
 $16 = (__Z12GetGfxDevicev()|0);
 $17 = HEAP32[$16>>2]|0;
 if ($hdr) {
  $18 = (($17) + 676|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
  $24 = $20;
 } else {
  $21 = (($17) + 672|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (FUNCTION_TABLE_ii[$22 & 4095]($16)|0);
  $24 = $23;
 }
 if ($14) {
  $phitmp$i5 = $hdr ? 1 : 2;
  $25 = $phitmp$i5;
 } else {
  $25 = 1;
 }
 $26 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($15,-1,-1,2,$24,0,$25,$antiAliasing)|0);
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  __ZN13RenderTexture24CorrectVerticalTexelSizeEb($26,1);
  $28 = HEAP32[$26>>2]|0;
  $29 = (($28) + 36|0);
  $30 = HEAP32[$29>>2]|0;
  FUNCTION_TABLE_vii[$30 & 4095]($26,572376);
 }
 $31 = (($this) + 24|0);
 HEAP32[$31>>2] = $26;
 $32 = HEAP32[$1>>2]|0;
 $33 = HEAP32[$this>>2]|0;
 $34 = $32;
 $35 = $33;
 $36 = (($34) - ($35))|0;
 $37 = (($36|0) / 12)&-1;
 $38 = ($32|0)==($33|0);
 if ($38) {
  $hdrAfterOpaque$0$off0$lcssa = $hdr;
 } else {
  $hdrAfterOpaque$0$off08 = $hdr;$i$09 = 0;
  while(1) {
   $39 = ((($33) + (($i$09*12)|0)|0) + 8|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   $hdrAfterOpaque$0$off0$ = $41 & $hdrAfterOpaque$0$off08;
   $42 = (($i$09) + 1)|0;
   $43 = ($42>>>0)<($37>>>0);
   if ($43) {
    $hdrAfterOpaque$0$off08 = $hdrAfterOpaque$0$off0$;$i$09 = $42;
   } else {
    $hdrAfterOpaque$0$off0$lcssa = $hdrAfterOpaque$0$off0$;
    break;
   }
  }
 }
 $44 = (__Z22GetRenderBufferManagerv()|0);
 $45 = (__Z12GetGfxDevicev()|0);
 $46 = HEAP32[$45>>2]|0;
 if ($hdrAfterOpaque$0$off0$lcssa) {
  $47 = (($46) + 676|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (FUNCTION_TABLE_ii[$48 & 4095]($45)|0);
  $53 = $49;
 } else {
  $50 = (($46) + 672|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (FUNCTION_TABLE_ii[$51 & 4095]($45)|0);
  $53 = $52;
 }
 if ($14) {
  $phitmp$i4 = $hdrAfterOpaque$0$off0$lcssa ? 1 : 2;
  $54 = $phitmp$i4;
 } else {
  $54 = 1;
 }
 $55 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($44,-1,-1,0,$53,0,$54,$antiAliasing)|0);
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  __ZN13RenderTexture24CorrectVerticalTexelSizeEb($55,1);
  $57 = HEAP32[$55>>2]|0;
  $58 = (($57) + 36|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vii[$59 & 4095]($55,572376);
 }
 $60 = (($this) + 28|0);
 HEAP32[$60>>2] = $55;
 STACKTOP = sp;return;
}
function __ZN12ImageFilters8DoRenderEP13RenderTexturebbbb($this,$finalRT,$forceIntoRT,$afterOpaque,$usingScreenToComposite,$hdr) {
 $this = $this|0;
 $finalRT = $finalRT|0;
 $forceIntoRT = $forceIntoRT|0;
 $afterOpaque = $afterOpaque|0;
 $usingScreenToComposite = $usingScreenToComposite|0;
 $hdr = $hdr|0;
 var $$0 = 0, $$0$i = 0, $$0$in$i = 0, $$byval_copy1 = 0, $$lcssa = 0, $$lcssa18 = 0, $$not = 0, $$not$i = 0, $$not14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge$i = 0, $brmerge$not = 0, $brmerge1$i = 0, $brmerge10 = 0, $brmerge11 = 0, $brmerge12 = 0;
 var $brmerge13 = 0, $brmerge15 = 0, $brmerge9 = 0, $buffersInHDR$0$off0$not = 0, $buffersInHDR$0$off020 = 0, $buffersInHDR$1$off0 = 0, $buffersInHDR$2$off0 = 0, $dst$0 = 0, $dstRsColor = 0, $dstRsDepth = 0, $forceIntoRT$not = 0, $hdr$not = 0, $i$019 = 0, $or$cond = 0, $or$cond3 = 0, $phitmp$i = 0, $rsColor = 0, $usingScreenToComposite$not$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $dstRsColor = sp;
 $dstRsDepth = sp + 4|0;
 $0 = sp + 8|0;
 $rsColor = sp + 12|0;
 $1 = sp + 16|0;
 $2 = (__ZN13RenderTexture9IsEnabledEv()|0);
 $$not = $2 ^ 1;
 $3 = HEAP32[((640792 + 232|0))>>2]|0;
 $4 = ($3|0)==(0);
 $or$cond = $4 | $$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $5 = (__Z19GetActiveColorSpacev()|0);
 $6 = ($5|0)==(1);
 $7 = (__Z22GetRenderBufferManagerv()|0);
 $8 = (__Z12GetGfxDevicev()|0);
 $9 = (($8) + 5788|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 32|0);
 HEAP32[$11>>2] = $10;
 if ($afterOpaque) {
  $12 = (($this) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($15|0)==($17|0);
  $brmerge = $18 | $usingScreenToComposite;
  $brmerge$not = $brmerge ^ 1;
  $brmerge9 = $brmerge$not | $forceIntoRT;
  if ($brmerge9) {
   $19 = (($this) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   $$0 = $20;$36 = $13;
  } else {
   $$0 = $finalRT;$36 = $13;
  }
 } else {
  $21 = HEAP32[$this>>2]|0;
  $22 = (($this) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($21|0)==($23|0);
  do {
   if ($24) {
    $25 = (($this) + 24|0);
    $$0$in$i = $25;
   } else {
    $26 = (($this) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($this) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $$not$i = ($27|0)!=($29|0);
    $brmerge$i = $$not$i | $forceIntoRT;
    if (!($brmerge$i)) {
     $30 = (($this) + 24|0);
     $$0$in$i = $30;
     break;
    }
    $usingScreenToComposite$not$i = $usingScreenToComposite ^ 1;
    $brmerge1$i = $usingScreenToComposite$not$i | $forceIntoRT;
    if ($brmerge1$i) {
     $32 = (($this) + 28|0);
     $$0$in$i = $32;
     break;
    } else {
     $31 = (($this) + 24|0);
     $$0$in$i = $31;
     break;
    }
   }
  } while(0);
  $$0$i = HEAP32[$$0$in$i>>2]|0;
  $$0 = $finalRT;$36 = $$0$i;
 }
 $33 = HEAP8[572504>>0]|0;
 $34 = HEAP32[572512>>2]|0;
 $35 = HEAP32[572520>>2]|0;
 HEAP8[572504>>0] = 0;
 HEAP32[572512>>2] = $36;
 HEAP32[572520>>2] = $$0;
 $37 = (__Z12GetGfxDevicev()|0);
 $38 = (($this) + 12|0);
 $39 = $afterOpaque ? $this : $38;
 $40 = (($39) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$39>>2]|0;
 $43 = $41;
 $44 = $42;
 $45 = (($43) - ($44))|0;
 $46 = (($45|0) / 12)&-1;
 $47 = ($41|0)==($42|0);
 if ($47) {
  $$lcssa = $36;$$lcssa18 = 0;
 } else {
  $48 = (($46) + -1)|0;
  $hdr$not = $hdr ^ 1;
  $49 = (($this) + 24|0);
  $50 = (($this) + 28|0);
  $102 = $36;$56 = 0;$buffersInHDR$0$off020 = $hdr;$i$019 = 0;
  while(1) {
   $51 = ($i$019|0)==($48|0);
   if ($51) {
    $182 = $56;$buffersInHDR$2$off0 = $buffersInHDR$0$off020;$dst$0 = $$0;
   } else {
    $52 = HEAP32[$39>>2]|0;
    $53 = ((($52) + (($i$019*12)|0)|0) + 8|0);
    $54 = HEAP8[$53>>0]|0;
    $55 = ($54<<24>>24)==(0);
    $buffersInHDR$0$off0$not = $buffersInHDR$0$off020 ^ 1;
    $brmerge10 = $55 | $buffersInHDR$0$off0$not;
    if ($brmerge10) {
     $59 = $56;$buffersInHDR$1$off0 = $buffersInHDR$0$off020;
    } else {
     $57 = (__ZN12ImageFilters17SwitchTargetToLDREP13RenderTextureb($this,$56,$6)|0);
     $59 = $57;$buffersInHDR$1$off0 = 0;
    }
    $58 = ($59|0)==(0|0);
    if ($58) {
     $60 = (__Z22GetRenderBufferManagerv()|0);
     $61 = (__Z12GetGfxDevicev()|0);
     $62 = HEAP32[$61>>2]|0;
     if ($buffersInHDR$1$off0) {
      $63 = (($62) + 676|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (FUNCTION_TABLE_ii[$64 & 4095]($61)|0);
      $69 = $65;
     } else {
      $66 = (($62) + 672|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (FUNCTION_TABLE_ii[$67 & 4095]($61)|0);
      $69 = $68;
     }
     if ($6) {
      $phitmp$i = $buffersInHDR$1$off0 ? 1 : 2;
      $70 = $phitmp$i;
     } else {
      $70 = 1;
     }
     $71 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($60,-1,-1,0,$69,0,$70,1)|0);
     $72 = ($71|0)==(0|0);
     if ($72) {
      $182 = 0;$buffersInHDR$2$off0 = $buffersInHDR$1$off0;$dst$0 = 0;
     } else {
      __ZN13RenderTexture24CorrectVerticalTexelSizeEb($71,1);
      $73 = HEAP32[$71>>2]|0;
      $74 = (($73) + 36|0);
      $75 = HEAP32[$74>>2]|0;
      FUNCTION_TABLE_vii[$75 & 4095]($71,572376);
      $182 = $71;$buffersInHDR$2$off0 = $buffersInHDR$1$off0;$dst$0 = $71;
     }
    } else {
     $182 = $59;$buffersInHDR$2$off0 = $buffersInHDR$1$off0;$dst$0 = $59;
    }
   }
   HEAP8[572504>>0] = 1;
   HEAP32[$dstRsColor>>2] = 0;
   HEAP32[$dstRsDepth>>2] = 0;
   __ZL27GetDestRenderTargetSurfacesP13RenderTextureR12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES6_($dst$0,$dstRsColor,$dstRsDepth);
   $76 = HEAP32[$dstRsColor>>2]|0;
   $77 = (($76) + 23|0);
   $78 = HEAP8[$77>>0]|0;
   $79 = ($78<<24>>24)==(0);
   if ($79) {
    $80 = HEAP32[$37>>2]|0;
    $81 = (($80) + 404|0);
    $82 = HEAP32[$81>>2]|0;
    FUNCTION_TABLE_vii[$82 & 4095]($37,$dstRsColor);
   }
   $83 = HEAP32[572512>>2]|0;
   $84 = (($83) + 148|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = HEAP32[$dstRsDepth>>2]|0;
   $87 = ($86|0)==($85|0);
   if ($87) {
    label = 31;
   } else {
    $88 = (($86) + 23|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = ($89<<24>>24)==(0);
    if ($90) {
     $91 = HEAP32[$37>>2]|0;
     $92 = (($91) + 404|0);
     $93 = HEAP32[$92>>2]|0;
     FUNCTION_TABLE_vii[$93 & 4095]($37,$dstRsDepth);
    } else {
     label = 31;
    }
   }
   if ((label|0) == 31) {
    label = 0;
    $94 = HEAP32[$37>>2]|0;
    $95 = (($94) + 412|0);
    $96 = HEAP32[$95>>2]|0;
    HEAP32[$0>>2] = $86;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    FUNCTION_TABLE_vii[$96 & 4095]($37,$$byval_copy1);
   }
   $97 = HEAP32[$39>>2]|0;
   $98 = ((($97) + (($i$019*12)|0)|0) + 4|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = (($97) + (($i$019*12)|0)|0);
   $101 = HEAP32[$100>>2]|0;
   FUNCTION_TABLE_viii[$99 & 4095]($101,$102,$dst$0);
   HEAP8[572504>>0] = 0;
   $103 = HEAP32[$39>>2]|0;
   $104 = ((($103) + (($i$019*12)|0)|0) + 8|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = ($105<<24>>24)==(0);
   $brmerge11 = $106 | $hdr$not;
   $brmerge12 = $brmerge11 | $buffersInHDR$2$off0;
   $107 = ($102|0)==(0|0);
   if ($brmerge12) {
    if ($107) {
     $183 = 0;
    } else {
     __ZN13RenderTexture24CorrectVerticalTexelSizeEb($102,1);
     $183 = $102;
    }
   } else {
    if ($107) {
     $183 = 0;
    } else {
     $108 = (__Z22GetRenderBufferManagerv()|0);
     __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($108,$102);
     $109 = HEAP32[$49>>2]|0;
     $110 = ($102|0)==($109|0);
     if ($110) {
      HEAP32[$49>>2] = 0;
     }
     $111 = HEAP32[$50>>2]|0;
     $112 = ($102|0)==($111|0);
     if ($112) {
      HEAP32[$50>>2] = 0;
      $183 = 0;
     } else {
      $183 = 0;
     }
    }
   }
   $113 = (($i$019) + 1)|0;
   $114 = ($113>>>0)<($46>>>0);
   if ($114) {
    $102 = $182;$56 = $183;$buffersInHDR$0$off020 = $buffersInHDR$2$off0;$i$019 = $113;
   } else {
    $$lcssa = $182;$$lcssa18 = $183;
    break;
   }
  }
 }
 $forceIntoRT$not = $forceIntoRT ^ 1;
 $brmerge13 = $afterOpaque | $forceIntoRT$not;
 if ($brmerge13) {
  $154 = 0;
 } else {
  $115 = HEAP32[$39>>2]|0;
  $116 = HEAP32[$40>>2]|0;
  $117 = ($115|0)==($116|0);
  if ($117) {
   __ZN12ImageFilters4BlitEP7TextureP13RenderTexture($$lcssa,$$0);
   $154 = 1;
  } else {
   $154 = 0;
  }
 }
 $118 = HEAP32[572512>>2]|0;
 $119 = ($118|0)!=(0|0);
 $120 = HEAP32[572520>>2]|0;
 $121 = ($120|0)!=(0|0);
 $or$cond3 = $119 & $121;
 if ($or$cond3) {
  $122 = (($118) + 148|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)==(0|0);
  if (!($124)) {
   $125 = HEAP32[$37>>2]|0;
   $126 = (($125) + 424|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (FUNCTION_TABLE_ii[$127 & 4095]($37)|0);
   $129 = ($128|0)==(0|0);
   if ($129) {
    $140 = 1;$144 = 0;$148 = 0;
   } else {
    $130 = (($128) + 12|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($128) + 4|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = (($128) + 8|0);
    $135 = HEAP32[$134>>2]|0;
    $140 = $131;$144 = $133;$148 = $135;
   }
   $136 = ($123|0)==($128|0);
   if (!($136)) {
    $137 = (($123) + 12|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($138|0)==($140|0);
    if ($139) {
     $141 = (($123) + 4|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ($142|0)==($144|0);
     if ($143) {
      $145 = (($123) + 8|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($146|0)==($148|0);
      if ($147) {
       $149 = HEAP32[$37>>2]|0;
       $150 = (($149) + 420|0);
       $151 = HEAP32[$150>>2]|0;
       $152 = (FUNCTION_TABLE_iii[$151 & 4095]($37,0)|0);
       HEAP32[$rsColor>>2] = $152;
       HEAP32[$1>>2] = $123;
       $153 = HEAP32[572520>>2]|0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rsColor,$$byval_copy1,$153,0,-1,0)|0);
      }
     }
    }
   }
  }
 }
 $$not14 = ($41|0)!=($42|0);
 $brmerge15 = $$not14 | $154;
 if ($brmerge15) {
  HEAP32[$11>>2] = $$0;
 }
 $155 = ($$lcssa18|0)==(0|0);
 if (!($155)) {
  $156 = (($this) + 24|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = ($$lcssa18|0)==($157|0);
  if (!($158)) {
   $159 = (($this) + 28|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = ($$lcssa18|0)==($160|0);
   if (!($161)) {
    __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($7,$$lcssa18);
   }
  }
 }
 $162 = ($$lcssa|0)==(0|0);
 if (!($162)) {
  $163 = (($this) + 24|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = ($$lcssa|0)==($164|0);
  if (!($165)) {
   $166 = (($this) + 28|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ($$lcssa|0)==($167|0);
   if (!($168)) {
    __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($7,$$lcssa);
   }
  }
 }
 if (!($afterOpaque)) {
  $169 = (($this) + 24|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = ($170|0)==(0|0);
  if (!($171)) {
   __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($7,$170);
   HEAP32[$169>>2] = 0;
  }
  $172 = (($this) + 28|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = ($173|0)==(0|0);
  if (!($174)) {
   __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($7,$173);
   $175 = HEAP32[$172>>2]|0;
   $176 = HEAP32[$11>>2]|0;
   $177 = ($175|0)==($176|0);
   if ($177) {
    HEAP32[$11>>2] = 0;
   }
   HEAP32[$172>>2] = 0;
  }
 }
 $178 = (__Z12GetGfxDevicev()|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = (($179) + 72|0);
 $181 = HEAP32[$180>>2]|0;
 FUNCTION_TABLE_vii[$181 & 4095]($178,0);
 HEAP8[572504>>0] = $33;
 HEAP32[572512>>2] = $34;
 HEAP32[572520>>2] = $35;
 STACKTOP = sp;return;
}
function __ZL27GetDestRenderTargetSurfacesP13RenderTextureR12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES6_($dest,$outColor,$outDepth) {
 $dest = $dest|0;
 $outColor = $outColor|0;
 $outDepth = $outDepth|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($dest|0)!=(0|0);
 if ($0) {
  $1 = (($dest) + 140|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if ($3) {
   $4 = (($dest) + 148|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    (__ZN13RenderTexture6CreateEv($dest)|0);
   }
  }
 }
 $7 = HEAP8[572504>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = HEAP32[572512>>2]|0;
  $10 = ($9|0)!=(0|0);
  $or$cond = $0 & $10;
  $11 = HEAP32[572520>>2]|0;
  $12 = ($11|0)==($dest|0);
  $or$cond8 = $or$cond & $12;
  if ($or$cond8) {
   $13 = (($dest) + 100|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($9) + 100|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14|0)==($16|0);
   if ($17) {
    $18 = (($dest) + 104|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($9) + 104|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($19|0)==($21|0);
    if ($22) {
     $23 = (($9) + 140|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      $26 = (($9) + 148|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==(0|0);
      if ($28) {
       (__ZN13RenderTexture6CreateEv($9)|0);
      }
     }
     $29 = (($dest) + 140|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$outColor>>2] = $30;
     $31 = HEAP32[572512>>2]|0;
     $32 = (($31) + 148|0);
     $33 = HEAP32[$32>>2]|0;
     HEAP32[$outDepth>>2] = $33;
     STACKTOP = sp;return;
    }
   }
  }
 }
 if ($0) {
  $34 = (($dest) + 140|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$outColor>>2] = $35;
  $36 = (($dest) + 148|0);
  $37 = HEAP32[$36>>2]|0;
  HEAP32[$outDepth>>2] = $37;
  STACKTOP = sp;return;
 } else {
  $38 = (__Z12GetGfxDevicev()|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 432|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (FUNCTION_TABLE_ii[$41 & 4095]($38)|0);
  HEAP32[$outColor>>2] = $42;
  $43 = (__Z12GetGfxDevicev()|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 436|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (FUNCTION_TABLE_ii[$46 & 4095]($43)|0);
  HEAP32[$outDepth>>2] = $47;
  STACKTOP = sp;return;
 }
}
function __ZN12ImageFilters4BlitEP7TextureP13RenderTexture($source,$dest) {
 $source = $source|0;
 $dest = $dest|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = Math_fround(0), $9 = 0, $or$cond = 0, $pos$i$i$i$i$i = 0, $r = 0, $rect = 0, $temp$0$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i$i$i = sp + 56|0;
 $0 = sp;
 $r = sp + 8|0;
 $1 = sp + 24|0;
 $rect = sp + 40|0;
 $2 = ($source|0)!=(0|0);
 $3 = ($dest|0)==(0|0);
 $or$cond = $2 | $3;
 if ($or$cond) {
  $61 = (__ZN12ImageFilters19GetBlitCopyMaterialEv()|0);
  $62 = ($61|0)==(0|0);
  if ($62) {
   STACKTOP = sp;return;
  }
  __ZN12ImageFilters4BlitEP7TextureP13RenderTexturePN5Unity8MaterialEib11CubemapFace($source,$dest,$61,-1,1,-1);
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$dest>>2]|0;
 $5 = (($4) + 116|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($dest)|0);
 $8 = (Math_fround(($7|0)));
 $9 = HEAP32[$dest>>2]|0;
 $10 = (($9) + 120|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($dest)|0);
 $13 = (Math_fround(($12|0)));
 HEAPF32[$r>>2] = Math_fround(0.0);
 $14 = (($r) + 8|0);
 HEAPF32[$14>>2] = $8;
 $15 = (($r) + 4|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($r) + 12|0);
 HEAPF32[$16>>2] = $13;
 $17 = (__Z16GetRenderManagerv()|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 do {
  if (!($19)) {
   HEAP32[$0>>2] = $18;
   $20 = HEAP32[560624>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    label = 11;
   } else {
    $22 = (($20) + 36|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($20) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($23|0)==($25|0);
    do {
     if ($26) {
      $27 = (($20) + 28|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($20) + 32|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($28) + ($30<<3)|0);
      $47 = $31;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$20,$0);
      $32 = HEAP32[$pos$i$i$i$i$i>>2]|0;
      $33 = ($32|0)==(-1);
      $34 = (($20) + 28|0);
      $35 = HEAP32[$34>>2]|0;
      if ($33) {
       $36 = (($20) + 32|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + ($37<<3)|0);
       $47 = $38;
       break;
      } else {
       $39 = (($35) + ($32<<3)|0);
       $47 = $39;
       break;
      }
     }
    } while(0);
    $40 = HEAP32[560624>>2]|0;
    $41 = (($40) + 28|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($40) + 32|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($42) + ($44<<3)|0);
    $46 = ($47|0)==($45|0);
    if ($46) {
     label = 11;
    } else {
     $48 = (($47) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0|0);
     if ($50) {
      label = 11;
     } else {
      $temp$0$i$i$i2 = $49;
     }
    }
   }
   if ((label|0) == 11) {
    $51 = HEAP32[$17>>2]|0;
    $52 = (__Z31ReadObjectFromPersistentManageri($51)|0);
    $53 = ($52|0)==(0|0);
    if ($53) {
     break;
    } else {
     $temp$0$i$i$i2 = $52;
    }
   }
   __ZNK6Camera18GetRenderRectangleEv($1,$temp$0$i$i$i2);
   ;HEAP32[$r+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$r+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$r+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$r+12>>2]=HEAP32[$1+12>>2]|0;
  }
 } while(0);
 __Z14RectfToRectIntRK5RectTIfE($rect,$r);
 $54 = HEAP32[$rect>>2]|0;
 $55 = (($rect) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($rect) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($rect) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 __ZN13RenderTexture10GrabPixelsEiiii($dest,$54,$56,$58,$60);
 STACKTOP = sp;return;
}
function __ZN12ImageFilters19GetBlitCopyMaterialEv() {
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 16|0;
 $1 = sp + 4|0;
 $2 = HEAP32[572528>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $$02 = $2;
  STACKTOP = sp;return ($$02|0);
 }
 $4 = (__Z15GetScriptMapperv()|0);
 $5 = (__Znwj(16)|0);
 $6 = (($0) + 8|0);
 HEAP32[$6>>2] = $5;
 HEAP32[$0>>2] = 17;
 $7 = (($0) + 4|0);
 HEAP32[$7>>2] = 15;
 dest=$5+0|0; src=572536+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $8 = (($5) + 15|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 $9 = (invoke_iii(2366,($4|0),($0|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $33 = HEAP8[$0>>0]|0;
  $34 = $33 & 1;
  $35 = ($34<<24>>24)==(0);
  if ($35) {
   $$0 = $32;$$01 = $31;
   ___resumeException($$01|0);
   // unreachable;
  }
  $36 = HEAP32[$6>>2]|0;
  __ZdlPv($36);
  $$0 = $32;$$01 = $31;
  ___resumeException($$01|0);
  // unreachable;
 }
 $12 = HEAP8[$0>>0]|0;
 $13 = $12 & 1;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  $15 = HEAP32[$6>>2]|0;
  __ZdlPv($15);
 }
 $16 = ($9|0)==(0|0);
 if (!($16)) {
  $44 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($9,61,0)|0);
  HEAP32[572528>>2] = $44;
  $$02 = $44;
  STACKTOP = sp;return ($$02|0);
 }
 __Z6FormatPKcz($1,572552,$vararg_buffer);
 $17 = HEAP8[$1>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $22 = (($1) + 1|0);
  $23 = $22;
 } else {
  $20 = (($1) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $23 = $21;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($23|0),0,(572496|0),465,1,0,0,(0|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  $39 = HEAP8[$1>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $$0 = $38;$$01 = $37;
   ___resumeException($$01|0);
   // unreachable;
  }
  $42 = (($1) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  __ZdlPv($43);
  $$0 = $38;$$01 = $37;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $26 = HEAP8[$1>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $$02 = 0;
   STACKTOP = sp;return ($$02|0);
  }
  $29 = (($1) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  __ZdlPv($30);
  $$02 = 0;
  STACKTOP = sp;return ($$02|0);
 }
 return 0|0;
}
function __ZN12ImageFilters4BlitEP7TextureP13RenderTexturePN5Unity8MaterialEib11CubemapFace($source,$dest,$mat,$pass,$setRT,$cubemapFace) {
 $source = $source|0;
 $dest = $dest|0;
 $mat = $mat|0;
 $pass = $pass|0;
 $setRT = $setRT|0;
 $cubemapFace = $cubemapFace|0;
 var $$ = 0, $$01 = 0, $$02 = 0, $$byval_copy10 = 0, $$off0 = 0, $$setRT = 0, $$uvY$i$i = Math_fround(0), $$uvY$i$i14 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$031 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $rsColor$i = 0, $rsDepth$i = 0, $uvY$$i$i = Math_fround(0), $uvY$$i$i13 = Math_fround(0), $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $$byval_copy10 = sp;
 $rsColor$i = sp + 48|0;
 $rsDepth$i = sp + 12|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $4 = sp + 40|0;
 $5 = (__Z12GetGfxDevicev()|0);
 $6 = (__ZN13RenderTexture9GetActiveEv()|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $11 = 0;
 } else {
  $8 = (($6) + 108|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)>(1);
  $11 = $10;
 }
 $$setRT = $11 | $setRT;
 if ($$setRT) {
  $$ = $11 ? 2 : 0;
  HEAP32[$rsColor$i>>2] = 0;
  HEAP32[$rsDepth$i>>2] = 0;
  __ZL27GetDestRenderTargetSurfacesP13RenderTextureR12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES6_($dest,$rsColor$i,$rsDepth$i);
  $12 = HEAP32[$rsDepth$i>>2]|0;
  HEAP32[$0>>2] = $12;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
  (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$rsColor$i,$$byval_copy10,$dest,0,$cubemapFace,$$)|0);
  __ZN13RenderTexture19FindAndSetSRGBWriteEPS_($dest);
 }
 $13 = ($source|0)==(0|0);
 if ($13) {
  $$off0 = 0;$189 = 0;
 } else {
  $14 = HEAP32[572352>>2]|0;
  HEAP32[$1>>2] = $14;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
  $15 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($mat,$$byval_copy10)|0);
  if ($15) {
   $16 = HEAP32[572352>>2]|0;
   HEAP32[$2>>2] = $16;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
   __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($mat,$$byval_copy10,$source);
   $190 = 1;
  } else {
   $190 = 0;
  }
  $17 = (($source) + 76|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = $18 < Math_fround(0.0);
  $$off0 = $19;$189 = $190;
 }
 __ZN22DeviceMVPMatricesStateC2Ev($rsColor$i);
 __THREW__ = 0;
 invoke_vffi(1,-1.0,100.0,0);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L13: do {
  if ($21) {
   label = 28;
  } else {
   __THREW__ = 0;
   $22 = (invoke_ii(3226,($mat|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 28;
   } else {
    $25 = ($pass|0)==(-1);
    L16: do {
     if ($25) {
      $26 = ($22|0)>(0);
      if ($26) {
       $uvY$$i$i = $$off0 ? Math_fround(1.0) : Math_fround(0.0);
       $$uvY$i$i = $$off0 ? Math_fround(0.0) : Math_fround(1.0);
       $i$031 = 0;
       while(1) {
        $27 = HEAP32[652824>>2]|0;
        __THREW__ = 0;
        $28 = (invoke_iiiiii(195,($mat|0),($i$031|0),($27|0),0,1)|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break;
        }
        $31 = HEAP32[$5>>2]|0;
        $32 = (($31) + 580|0);
        $33 = HEAP32[$32>>2]|0;
        __THREW__ = 0;
        invoke_viii($33|0,($5|0),2,($28|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
        $36 = HEAP32[$5>>2]|0;
        $37 = (($36) + 568|0);
        $38 = HEAP32[$37>>2]|0;
        __THREW__ = 0;
        invoke_viffff($38|0,($5|0),1.0,1.0,1.0,1.0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
        $41 = HEAP32[$5>>2]|0;
        $42 = (($41) + 572|0);
        $43 = HEAP32[$42>>2]|0;
        __THREW__ = 0;
        invoke_vifff($43|0,($5|0),0.0,(+$uvY$$i$i),0.0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
        $46 = HEAP32[$5>>2]|0;
        $47 = (($46) + 560|0);
        $48 = HEAP32[$47>>2]|0;
        __THREW__ = 0;
        invoke_vifff($48|0,($5|0),0.0,0.0,0.100000001490116119385);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        $51 = HEAP32[$5>>2]|0;
        $52 = (($51) + 572|0);
        $53 = HEAP32[$52>>2]|0;
        __THREW__ = 0;
        invoke_vifff($53|0,($5|0),0.0,(+$$uvY$i$i),0.0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         break;
        }
        $56 = HEAP32[$5>>2]|0;
        $57 = (($56) + 560|0);
        $58 = HEAP32[$57>>2]|0;
        __THREW__ = 0;
        invoke_vifff($58|0,($5|0),0.0,1.0,0.100000001490116119385);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        $61 = HEAP32[$5>>2]|0;
        $62 = (($61) + 572|0);
        $63 = HEAP32[$62>>2]|0;
        __THREW__ = 0;
        invoke_vifff($63|0,($5|0),1.0,(+$$uvY$i$i),0.0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         break;
        }
        $66 = HEAP32[$5>>2]|0;
        $67 = (($66) + 560|0);
        $68 = HEAP32[$67>>2]|0;
        __THREW__ = 0;
        invoke_vifff($68|0,($5|0),1.0,1.0,0.100000001490116119385);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
        $71 = HEAP32[$5>>2]|0;
        $72 = (($71) + 572|0);
        $73 = HEAP32[$72>>2]|0;
        __THREW__ = 0;
        invoke_vifff($73|0,($5|0),1.0,(+$uvY$$i$i),0.0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        $76 = HEAP32[$5>>2]|0;
        $77 = (($76) + 560|0);
        $78 = HEAP32[$77>>2]|0;
        __THREW__ = 0;
        invoke_vifff($78|0,($5|0),1.0,0.0,0.100000001490116119385);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         break;
        }
        $81 = HEAP32[$5>>2]|0;
        $82 = (($81) + 584|0);
        $83 = HEAP32[$82>>2]|0;
        __THREW__ = 0;
        invoke_vi($83|0,($5|0));
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         break;
        }
        $86 = (($i$031) + 1)|0;
        $87 = ($86|0)<($22|0);
        if ($87) {
         $i$031 = $86;
        } else {
         break L16;
        }
       }
       $88 = ___cxa_find_matching_catch()|0;
       $89 = tempRet0;
       $lpad$phi$index = $88;$lpad$phi$index2 = $89;
       label = 29;
       break L13;
      }
     } else {
      $92 = ($pass|0)>(-1);
      $93 = ($22|0)>($pass|0);
      $or$cond = $92 & $93;
      if (!($or$cond)) {
       $153 = HEAP32[$mat>>2]|0;
       $154 = (($153) + 32|0);
       $155 = HEAP32[$154>>2]|0;
       __THREW__ = 0;
       $156 = (invoke_ii($155|0,($mat|0))|0);
       $157 = __THREW__; __THREW__ = 0;
       $158 = $157&1;
       if ($158) {
        label = 28;
        break L13;
       }
       __THREW__ = 0;
       HEAP32[$$byval_copy10>>2] = $pass;
       $vararg_ptr6 = (($$byval_copy10) + 4|0);
       HEAP32[$vararg_ptr6>>2] = $156;
       $vararg_ptr7 = (($$byval_copy10) + 8|0);
       HEAP32[$vararg_ptr7>>2] = $22;
       invoke_viii(1617,($3|0),(572608|0),($$byval_copy10|0));
       $159 = __THREW__; __THREW__ = 0;
       $160 = $159&1;
       if ($160) {
        label = 28;
        break L13;
       }
       $161 = HEAP8[$3>>0]|0;
       $162 = $161 & 1;
       $163 = ($162<<24>>24)==(0);
       if ($163) {
        $166 = (($3) + 1|0);
        $167 = $166;
       } else {
        $164 = (($3) + 8|0);
        $165 = HEAP32[$164>>2]|0;
        $167 = $165;
       }
       __THREW__ = 0;
       invoke_viiiiiiii(21,($167|0),0,(572496|0),609,1,0,0,(0|0));
       $168 = __THREW__; __THREW__ = 0;
       $169 = $168&1;
       if ($169) {
        $175 = ___cxa_find_matching_catch()|0;
        $176 = tempRet0;
        $177 = HEAP8[$3>>0]|0;
        $178 = $177 & 1;
        $179 = ($178<<24>>24)==(0);
        if ($179) {
         $$01 = $176;$$02 = $175;
         break L13;
        }
        $180 = (($3) + 8|0);
        $181 = HEAP32[$180>>2]|0;
        __ZdlPv($181);
        $$01 = $176;$$02 = $175;
        break L13;
       } else {
        $170 = HEAP8[$3>>0]|0;
        $171 = $170 & 1;
        $172 = ($171<<24>>24)==(0);
        if ($172) {
         break;
        }
        $173 = (($3) + 8|0);
        $174 = HEAP32[$173>>2]|0;
        __ZdlPv($174);
        break;
       }
      }
      $94 = HEAP32[652824>>2]|0;
      __THREW__ = 0;
      $95 = (invoke_iiiiii(195,($mat|0),($pass|0),($94|0),0,1)|0);
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       label = 28;
       break L13;
      }
      $98 = HEAP32[$5>>2]|0;
      $99 = (($98) + 580|0);
      $100 = HEAP32[$99>>2]|0;
      __THREW__ = 0;
      invoke_viii($100|0,($5|0),2,($95|0));
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       label = 28;
       break L13;
      }
      $uvY$$i$i13 = $$off0 ? Math_fround(1.0) : Math_fround(0.0);
      $$uvY$i$i14 = $$off0 ? Math_fround(0.0) : Math_fround(1.0);
      $103 = HEAP32[$5>>2]|0;
      $104 = (($103) + 568|0);
      $105 = HEAP32[$104>>2]|0;
      __THREW__ = 0;
      invoke_viffff($105|0,($5|0),1.0,1.0,1.0,1.0);
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       label = 28;
       break L13;
      }
      $108 = HEAP32[$5>>2]|0;
      $109 = (($108) + 572|0);
      $110 = HEAP32[$109>>2]|0;
      __THREW__ = 0;
      invoke_vifff($110|0,($5|0),0.0,(+$uvY$$i$i13),0.0);
      $111 = __THREW__; __THREW__ = 0;
      $112 = $111&1;
      if ($112) {
       label = 28;
       break L13;
      }
      $113 = HEAP32[$5>>2]|0;
      $114 = (($113) + 560|0);
      $115 = HEAP32[$114>>2]|0;
      __THREW__ = 0;
      invoke_vifff($115|0,($5|0),0.0,0.0,0.100000001490116119385);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       label = 28;
       break L13;
      }
      $118 = HEAP32[$5>>2]|0;
      $119 = (($118) + 572|0);
      $120 = HEAP32[$119>>2]|0;
      __THREW__ = 0;
      invoke_vifff($120|0,($5|0),0.0,(+$$uvY$i$i14),0.0);
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 28;
       break L13;
      }
      $123 = HEAP32[$5>>2]|0;
      $124 = (($123) + 560|0);
      $125 = HEAP32[$124>>2]|0;
      __THREW__ = 0;
      invoke_vifff($125|0,($5|0),0.0,1.0,0.100000001490116119385);
      $126 = __THREW__; __THREW__ = 0;
      $127 = $126&1;
      if ($127) {
       label = 28;
       break L13;
      }
      $128 = HEAP32[$5>>2]|0;
      $129 = (($128) + 572|0);
      $130 = HEAP32[$129>>2]|0;
      __THREW__ = 0;
      invoke_vifff($130|0,($5|0),1.0,(+$$uvY$i$i14),0.0);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       label = 28;
       break L13;
      }
      $133 = HEAP32[$5>>2]|0;
      $134 = (($133) + 560|0);
      $135 = HEAP32[$134>>2]|0;
      __THREW__ = 0;
      invoke_vifff($135|0,($5|0),1.0,1.0,0.100000001490116119385);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       label = 28;
       break L13;
      }
      $138 = HEAP32[$5>>2]|0;
      $139 = (($138) + 572|0);
      $140 = HEAP32[$139>>2]|0;
      __THREW__ = 0;
      invoke_vifff($140|0,($5|0),1.0,(+$uvY$$i$i13),0.0);
      $141 = __THREW__; __THREW__ = 0;
      $142 = $141&1;
      if ($142) {
       label = 28;
       break L13;
      }
      $143 = HEAP32[$5>>2]|0;
      $144 = (($143) + 560|0);
      $145 = HEAP32[$144>>2]|0;
      __THREW__ = 0;
      invoke_vifff($145|0,($5|0),1.0,0.0,0.100000001490116119385);
      $146 = __THREW__; __THREW__ = 0;
      $147 = $146&1;
      if ($147) {
       label = 28;
       break L13;
      }
      $148 = HEAP32[$5>>2]|0;
      $149 = (($148) + 584|0);
      $150 = HEAP32[$149>>2]|0;
      __THREW__ = 0;
      invoke_vi($150|0,($5|0));
      $151 = __THREW__; __THREW__ = 0;
      $152 = $151&1;
      if ($152) {
       label = 28;
       break L13;
      }
     }
    } while(0);
    if (!($189)) {
     __ZN22DeviceMVPMatricesStateD2Ev($rsColor$i);
     STACKTOP = sp;return;
    }
    $182 = HEAP32[572352>>2]|0;
    HEAP32[$4>>2] = $182;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_viii(1682,($mat|0),($$byval_copy10|0),(0|0));
    $183 = __THREW__; __THREW__ = 0;
    $184 = $183&1;
    if ($184) {
     label = 28;
    } else {
     __ZN22DeviceMVPMatricesStateD2Ev($rsColor$i);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 28) {
  $90 = ___cxa_find_matching_catch()|0;
  $91 = tempRet0;
  $lpad$phi$index = $90;$lpad$phi$index2 = $91;
  label = 29;
 }
 if ((label|0) == 29) {
  $$01 = $lpad$phi$index2;$$02 = $lpad$phi$index;
 }
 __THREW__ = 0;
 invoke_vi(3375,($rsColor$i|0));
 $185 = __THREW__; __THREW__ = 0;
 $186 = $185&1;
 if ($186) {
  $187 = ___cxa_find_matching_catch(0|0)|0;
  $188 = tempRet0;
  ___clang_call_terminate($187);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
}
function __GLOBAL__I_a1998() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,572360);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[572352>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN17IntermediateUsers6NotifyE18IntermediateNotify($this,$notify) {
 $this = $this|0;
 $notify = $notify|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($notify|0) == 0)) {
  $0 = (($this) + 4|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==($this|0);
  if ($2) {
   STACKTOP = sp;return;
  } else {
   $4 = $1;
  }
  while(1) {
   $3 = (($4) + 8|0);
   $5 = HEAP32[$3>>2]|0;
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 72|0);
   $8 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vi[$8 & 4095]($5);
   $9 = (($4) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($this|0);
   if ($11) {
    break;
   } else {
    $4 = $10;
   }
  }
  STACKTOP = sp;return;
 } else if ((($notify|0) == 1)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($this|0);
  if ($14) {
   STACKTOP = sp;return;
  } else {
   $16 = $13;
  }
  while(1) {
   $15 = (($16) + 8|0);
   $17 = HEAP32[$15>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 76|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vi[$20 & 4095]($17);
   $21 = (($16) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==($this|0);
   if ($23) {
    break;
   } else {
    $16 = $22;
   }
  }
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN20IntermediateRendererC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12BaseRendererC2E12RendererType($this,10);
 HEAP32[$this>>2] = ((572680 + 8|0));
 $0 = (($this) + 188|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 192|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 196|0);
 HEAP32[$2>>2] = $this;
 $3 = (($this) + 200|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[628400>>2]|0;
 $5 = (($this) + 204|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 208|0);
 HEAP32[$6>>2] = $4;
 $7 = (($this) + 212|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 216|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 220|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 224|0);
 HEAP32[$10>>2] = $4;
 $11 = (($this) + 228|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 232|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 236|0);
 $14 = HEAP32[641904>>2]|0;
 HEAP32[$13>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN20IntermediateRenderer10InitializeERK10Matrix4x4fRK4AABB4PPtrIN5Unity8MaterialEEibb($this,$matrix,$localAABB,$material,$layer,$castShadows,$receiveShadows) {
 $this = $this|0;
 $matrix = $matrix|0;
 $localAABB = $localAABB|0;
 $material = $material|0;
 $layer = $layer|0;
 $castShadows = $castShadows|0;
 $receiveShadows = $receiveShadows|0;
 var $$layer = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0);
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$material>>2]|0;
 $1 = (($this) + 200|0);
 HEAP32[$1>>2] = $0;
 $2 = ($layer>>>0)>(31);
 $$layer = $2 ? 0 : $layer;
 $3 = (($this) + 240|0);
 HEAP32[$3>>2] = $$layer;
 $4 = (($this) + 41|0);
 $5 = $castShadows&1;
 HEAP8[$4>>0] = $5;
 $6 = (($this) + 42|0);
 $7 = $receiveShadows&1;
 HEAP8[$6>>0] = $7;
 $8 = (($this) + 52|0);
 dest=$8+0|0; src=$matrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $9 = Math_fround(HEAPF32[616648>>2]);
 $10 = (__Z20ComputeTransformTypeRK10Matrix4x4ff($matrix,$9)|0);
 $11 = (($this) + 164|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 140|0);
 ;HEAP32[$12+0>>2]=HEAP32[$localAABB+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$localAABB+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$localAABB+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$localAABB+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$localAABB+16>>2]|0;HEAP32[$12+20>>2]=HEAP32[$localAABB+20>>2]|0;
 $13 = (($this) + 116|0);
 __Z13TransformAABBRK4AABBRK10Matrix4x4fRS_($localAABB,$matrix,$13);
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vi[$16 & 4095]($this);
 $17 = (($this) + 48|0);
 HEAP8[$17>>0] = 0;
 $18 = (($this) + 49|0);
 HEAP8[$18>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN20IntermediateRendererD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(950,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN20IntermediateRendererD2Ev($this) {
 $this = $this|0;
 var $$byval_copy9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy9 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((572680 + 8|0));
 $2 = (($this) + 43|0);
 HEAP8[$2>>0] = 0;
 $3 = (($this) + 204|0);
 $4 = (($this) + 232|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(-1);
 do {
  if ($6) {
   $7 = (($this) + 220|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 224|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$1>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy9|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    HEAP32[$7>>2] = 0;
    label = 4;
    break;
   }
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $23 = (($this) + 216|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)>(-1);
   if ($25) {
    $26 = HEAP32[$3>>2]|0;
    $27 = (($this) + 208|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$0>>2] = $28;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($26|0),($$byval_copy9|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     HEAP32[$3>>2] = 0;
     $eh$lpad$body$index3Z2D = $22;$eh$lpad$body$indexZ2D = $21;
     break;
    }
   } else {
    $eh$lpad$body$index3Z2D = $22;$eh$lpad$body$indexZ2D = $21;
   }
  } else {
   label = 4;
  }
 } while(0);
 do {
  if ((label|0) == 4) {
   $13 = (($this) + 216|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)>(-1);
   if (!($15)) {
    STACKTOP = sp;return;
   }
   $16 = HEAP32[$3>>2]|0;
   $17 = (($this) + 208|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$0>>2] = $18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($16|0),($$byval_copy9|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $33 = ___cxa_find_matching_catch()|0;
    $34 = tempRet0;
    $eh$lpad$body$index3Z2D = $34;$eh$lpad$body$indexZ2D = $33;
    break;
   }
   HEAP32[$3>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 __THREW__ = 0;
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN20IntermediateRenderer20OnAssetBoundsChangedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN24MeshIntermediateRenderer16StaticInitializeEv() {
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628480>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,572784,71)|0);
 $4 = HEAP32[628480>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(98,($3|0),1,(572792|0),252,65536,($$byval_copy2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[572776>>2] = $3;
  STACKTOP = sp;return;
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),0,16,(572784|0),71);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN24MeshIntermediateRenderer13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[572776>>2]|0;
 $2 = HEAP32[628480>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN10MemoryPoolD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[572776>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN24MeshIntermediateRendererD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((572824 + 8|0));
 $0 = (($this) + 188|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 192|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 __THREW__ = 0;
 invoke_vi(950,($this|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $10 = HEAP32[572776>>2]|0;
  __ZN10MemoryPool10DeallocateEPv($10,$this);
  STACKTOP = sp;return;
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $13 = HEAP32[572776>>2]|0;
 __THREW__ = 0;
 invoke_vii(2609,($13|0),($this|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  ___clang_call_terminate($16);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZN24MeshIntermediateRendererD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((572824 + 8|0));
 $0 = (($this) + 188|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN20IntermediateRendererD2Ev($this);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 192|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $6;
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 __ZN20IntermediateRendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN24MeshIntermediateRenderer14OnAssetDeletedEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN24MeshIntermediateRenderer6RenderEiRK14ChannelAssigns($this,$subsetIndex,$channels) {
 $this = $this|0;
 $subsetIndex = $subsetIndex|0;
 $channels = $channels|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 248|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 244|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 168|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $13 = $3;
 } else {
  $8 = (__Z12GetGfxDevicev()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 216|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($8,$12);
  $$pre$i = HEAP32[$2>>2]|0;
  $13 = $$pre$i;
 }
 __ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_($channels,$13,$1,0,0);
 STACKTOP = sp;return;
}
function __ZN24MeshIntermediateRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns($this,$renderData,$channels) {
 $this = $this|0;
 $renderData = $renderData|0;
 $channels = $channels|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z20RenderMultipleMeshesRK22RenderMultipleMeshDataRK14ChannelAssigns($renderData,$channels);
 STACKTOP = sp;return;
}
function __ZN24MeshIntermediateRenderer10InitializeERK10Matrix4x4fP4MeshRK4AABB4PPtrIN5Unity8MaterialEEibbi($this,$matrix,$mesh,$localAABB,$material,$layer,$castShadows,$receiveShadows,$submeshIndex) {
 $this = $this|0;
 $matrix = $matrix|0;
 $mesh = $mesh|0;
 $localAABB = $localAABB|0;
 $material = $material|0;
 $layer = $layer|0;
 $castShadows = $castShadows|0;
 $receiveShadows = $receiveShadows|0;
 $submeshIndex = $submeshIndex|0;
 var $$0 = 0, $$layer$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 HEAP32[$0>>2] = $mesh;
 $1 = ($mesh|0)==(0|0);
 do {
  if ($1) {
   $$0 = $submeshIndex;
  } else {
   $2 = (($this) + 188|0);
   $3 = (($mesh) + 220|0);
   $4 = ($2|0)==($3|0);
   if (!($4)) {
    $5 = HEAP32[$2>>2]|0;
    $6 = ($5|0)==(0|0);
    $$pre$i$i$i$i = (($this) + 192|0);
    if (!($6)) {
     $7 = HEAP32[$$pre$i$i$i$i>>2]|0;
     $8 = (($5) + 4|0);
     HEAP32[$8>>2] = $7;
     $9 = HEAP32[$2>>2]|0;
     $10 = HEAP32[$$pre$i$i$i$i>>2]|0;
     HEAP32[$10>>2] = $9;
     HEAP32[$2>>2] = 0;
     HEAP32[$$pre$i$i$i$i>>2] = 0;
    }
    $11 = HEAP32[$3>>2]|0;
    HEAP32[$2>>2] = $11;
    HEAP32[$$pre$i$i$i$i>>2] = $3;
    $12 = (($11) + 4|0);
    HEAP32[$12>>2] = $2;
    $13 = HEAP32[$$pre$i$i$i$i>>2]|0;
    HEAP32[$13>>2] = $2;
   }
   $14 = ($submeshIndex|0)<(0);
   if (!($14)) {
    $15 = HEAP32[$0>>2]|0;
    $16 = (__ZNK4Mesh15GetSubMeshCountEv($15)|0);
    $17 = ($16|0)>($submeshIndex|0);
    if ($17) {
     $$0 = $submeshIndex;
     break;
    }
   }
   $$0 = 0;
  }
 } while(0);
 $18 = (($this) + 248|0);
 HEAP32[$18>>2] = $$0;
 $19 = HEAP32[$material>>2]|0;
 $20 = (($this) + 200|0);
 HEAP32[$20>>2] = $19;
 $21 = ($layer>>>0)>(31);
 $$layer$i = $21 ? 0 : $layer;
 $22 = (($this) + 240|0);
 HEAP32[$22>>2] = $$layer$i;
 $23 = (($this) + 41|0);
 $24 = $castShadows&1;
 HEAP8[$23>>0] = $24;
 $25 = (($this) + 42|0);
 $26 = $receiveShadows&1;
 HEAP8[$25>>0] = $26;
 $27 = (($this) + 52|0);
 dest=$27+0|0; src=$matrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $28 = Math_fround(HEAPF32[616648>>2]);
 $29 = (__Z20ComputeTransformTypeRK10Matrix4x4ff($matrix,$28)|0);
 $30 = (($this) + 164|0);
 HEAP32[$30>>2] = $29;
 $31 = (($this) + 140|0);
 ;HEAP32[$31+0>>2]=HEAP32[$localAABB+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$localAABB+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$localAABB+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$localAABB+12>>2]|0;HEAP32[$31+16>>2]=HEAP32[$localAABB+16>>2]|0;HEAP32[$31+20>>2]=HEAP32[$localAABB+20>>2]|0;
 $32 = (($this) + 116|0);
 __Z13TransformAABBRK4AABBRK10Matrix4x4fRS_($localAABB,$matrix,$32);
 $33 = HEAP32[$this>>2]|0;
 $34 = (($33) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vi[$35 & 4095]($this);
 $36 = (($this) + 48|0);
 HEAP8[$36>>0] = 0;
 $37 = (($this) + 49|0);
 HEAP8[$37>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN48MeshIntermediateRendererWithDistanceSortingOrder16StaticInitializeEv() {
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628480>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,572784,146)|0);
 $4 = HEAP32[628480>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(98,($3|0),1,(572928|0),256,65536,($$byval_copy2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[572920>>2] = $3;
  STACKTOP = sp;return;
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),0,16,(572784|0),146);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN48MeshIntermediateRendererWithDistanceSortingOrder13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[572920>>2]|0;
 $2 = HEAP32[628480>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN10MemoryPoolD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[572920>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN48MeshIntermediateRendererWithDistanceSortingOrderD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((572824 + 8|0));
 $0 = (($this) + 188|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 192|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 __THREW__ = 0;
 invoke_vi(950,($this|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $10 = HEAP32[572920>>2]|0;
  __ZN10MemoryPool10DeallocateEPv($10,$this);
  STACKTOP = sp;return;
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $13 = HEAP32[572920>>2]|0;
 __THREW__ = 0;
 invoke_vii(2609,($13|0),($this|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  ___clang_call_terminate($16);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZN26SpriteIntermediateRenderer16StaticInitializeEv() {
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628480>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,572784,179)|0);
 $4 = HEAP32[628480>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(98,($3|0),1,(573088|0),264,65536,($$byval_copy2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[573080>>2] = $3;
  STACKTOP = sp;return;
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),0,16,(572784|0),179);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN26SpriteIntermediateRenderer13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[573080>>2]|0;
 $2 = HEAP32[628480>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN10MemoryPoolD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[573080>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN21IntermediateRenderers5ClearEj($this,$startIndex) {
 $this = $this|0;
 $startIndex = $startIndex|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>($startIndex>>>0);
 if ($3) {
  $i$01 = $startIndex;
  while(1) {
   $4 = HEAP32[$this>>2]|0;
   $5 = (($4) + (($i$01*24)|0)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    $8 = HEAP32[$6>>2]|0;
    $9 = (($8) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    FUNCTION_TABLE_vi[$10 & 4095]($6);
   }
   $11 = (($i$01) + 1)|0;
   $exitcond = ($11|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $11;
   }
  }
 }
 HEAP32[$1>>2] = $startIndex;
 $12 = (($this) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14>>>0)<($startIndex>>>0);
 do {
  if ($15) {
   $16 = ($13|0)>(-1);
   if ($16) {
    HEAP32[$12>>2] = $startIndex;
    $17 = HEAP32[$this>>2]|0;
    $18 = ($startIndex*24)|0;
    $19 = (($this) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z16realloc_internalPvji10MemLabelIdiPKci($17,$18,4,$$byval_copy3,0,572784,370)|0);
    HEAP32[$this>>2] = $21;
    break;
   } else {
    $22 = ($startIndex*24)|0;
    $23 = (($this) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = $24;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,4,$$byval_copy3,0,572784,352)|0);
    $26 = HEAP32[$this>>2]|0;
    $27 = HEAP32[$1>>2]|0;
    $28 = ($27*24)|0;
    _memcpy(($25|0),($26|0),($28|0))|0;
    HEAP32[$12>>2] = $startIndex;
    HEAP32[$this>>2] = $25;
    break;
   }
  }
 } while(0);
 $29 = (($this) + 16|0);
 $30 = (($this) + 24|0);
 HEAP32[$30>>2] = $startIndex;
 $31 = (($this) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 & 2147483647;
 $34 = ($33>>>0)<($startIndex>>>0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 $35 = ($32|0)>(-1);
 if ($35) {
  HEAP32[$31>>2] = $startIndex;
  $36 = HEAP32[$29>>2]|0;
  $37 = ($startIndex*24)|0;
  $38 = (($this) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  HEAP32[$0>>2] = $39;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $40 = (__Z16realloc_internalPvji10MemLabelIdiPKci($36,$37,4,$$byval_copy3,0,572784,370)|0);
  HEAP32[$29>>2] = $40;
  STACKTOP = sp;return;
 } else {
  $41 = ($startIndex*24)|0;
  $42 = (($this) + 20|0);
  $43 = HEAP32[$42>>2]|0;
  HEAP32[$0>>2] = $43;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $44 = (__Z15malloc_internaljj10MemLabelIdiPKci($41,4,$$byval_copy3,0,572784,352)|0);
  $45 = HEAP32[$29>>2]|0;
  $46 = HEAP32[$30>>2]|0;
  $47 = ($46*24)|0;
  _memcpy(($44|0),($45|0),($47|0))|0;
  HEAP32[$31>>2] = $startIndex;
  HEAP32[$29>>2] = $44;
  STACKTOP = sp;return;
 }
}
function __ZNK21IntermediateRenderers16GetBoundingBoxesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK21IntermediateRenderers13GetSceneNodesEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN21IntermediateRenderers3AddEP20IntermediateRenderer($this,$renderer) {
 $this = $this|0;
 $renderer = $renderer|0;
 var $$byval_copy3 = 0, $$pre$i = 0, $$pre$i$i = 0, $$sroa$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $0 = sp;
 $$sroa$3 = sp + 4|0;
 ;HEAP32[$$sroa$3+0>>2]=0|0;HEAP32[$$sroa$3+4>>2]=0|0;HEAP16[$$sroa$3+8>>1]=0|0;HEAP8[$$sroa$3+10>>0]=0|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = $5 << 1;
  $9 = ($8|0)==(0);
  $10 = $9 ? 1 : $8;
  $11 = ($6>>>0)<($10>>>0);
  do {
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*24)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy3,0,572784,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*24)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy3,0,572784,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*24)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$1>>2]|0;
  $26 = $$pre$i$i;
 } else {
  $26 = $3;
 }
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($25*24)|0)|0);
 HEAP32[$28>>2] = 0;
 $29 = ((($27) + (($25*24)|0)|0) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($27) + (($25*24)|0)|0) + 8|0);
 HEAP32[$30>>2] = -1;
 $31 = ((($27) + (($25*24)|0)|0) + 12|0);
 ;HEAP32[$31+0>>2]=HEAP32[$$sroa$3+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$$sroa$3+4>>2]|0;HEAP16[$31+8>>1]=HEAP16[$$sroa$3+8>>1]|0;HEAP8[$31+10>>0]=HEAP8[$$sroa$3+10>>0]|0;
 $32 = HEAP32[$1>>2]|0;
 $33 = (($32) + -1)|0;
 $34 = HEAP32[$this>>2]|0;
 $35 = (($34) + (($33*24)|0)|0);
 HEAP32[$35>>2] = $renderer;
 $36 = HEAP32[$renderer>>2]|0;
 $37 = (($36) + 32|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 4095]($renderer)|0);
 $40 = ((($34) + (($33*24)|0)|0) + 4|0);
 HEAP32[$40>>2] = $39;
 $41 = (($this) + 16|0);
 $42 = (($this) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 1)|0;
 HEAP32[$42>>2] = $44;
 $45 = (($this) + 28|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 & 2147483647;
 $48 = ($44>>>0)>($47>>>0);
 if (!($48)) {
  $67 = $44;
  $66 = (($67) + -1)|0;
  $68 = HEAP32[$41>>2]|0;
  $69 = (($68) + (($66*24)|0)|0);
  __ZN12BaseRenderer12GetWorldAABBER4AABB($renderer,$69);
  STACKTOP = sp;return;
 }
 $49 = $46 << 1;
 $50 = ($49|0)==(0);
 $51 = $50 ? 1 : $49;
 $52 = ($47>>>0)<($51>>>0);
 do {
  if ($52) {
   $53 = ($46|0)>(-1);
   if ($53) {
    HEAP32[$45>>2] = $51;
    $54 = HEAP32[$41>>2]|0;
    $55 = ($51*24)|0;
    $56 = (($this) + 20|0);
    $57 = HEAP32[$56>>2]|0;
    HEAP32[$0>>2] = $57;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $58 = (__Z16realloc_internalPvji10MemLabelIdiPKci($54,$55,4,$$byval_copy3,0,572784,370)|0);
    HEAP32[$41>>2] = $58;
    break;
   } else {
    $59 = ($51*24)|0;
    $60 = (($this) + 20|0);
    $61 = HEAP32[$60>>2]|0;
    HEAP32[$0>>2] = $61;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $62 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,4,$$byval_copy3,0,572784,352)|0);
    $63 = HEAP32[$41>>2]|0;
    $64 = HEAP32[$42>>2]|0;
    $65 = ($64*24)|0;
    _memcpy(($62|0),($63|0),($65|0))|0;
    HEAP32[$45>>2] = $51;
    HEAP32[$41>>2] = $62;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$42>>2]|0;
 $67 = $$pre$i;
 $66 = (($67) + -1)|0;
 $68 = HEAP32[$41>>2]|0;
 $69 = (($68) + (($66*24)|0)|0);
 __ZN12BaseRenderer12GetWorldAABBER4AABB($renderer,$69);
 STACKTOP = sp;return;
}
function __Z27AddMeshIntermediateRendererRK10Matrix4x4fP4Mesh4PPtrIN5Unity8MaterialEEibbiP6Camera($matrix,$mesh,$material,$layer,$castShadows,$receiveShadows,$submeshIndex,$camera) {
 $matrix = $matrix|0;
 $mesh = $mesh|0;
 $material = $material|0;
 $layer = $layer|0;
 $castShadows = $castShadows|0;
 $receiveShadows = $receiveShadows|0;
 $submeshIndex = $submeshIndex|0;
 $camera = $camera|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $bounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bounds = sp + 8|0;
 $0 = sp;
 ;HEAP32[$bounds+0>>2]=0|0;HEAP32[$bounds+4>>2]=0|0;HEAP32[$bounds+8>>2]=0|0;HEAP32[$bounds+12>>2]=0|0;HEAP32[$bounds+16>>2]=0|0;HEAP32[$bounds+20>>2]=0|0;
 $1 = ($mesh|0)==(0|0);
 if ($1) {
  ;HEAP32[$bounds+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[616680+8>>2]|0;
  $3 = (($bounds) + 12|0);
  ;HEAP32[$3+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[616680+8>>2]|0;
 } else {
  $2 = (($mesh) + 168|0);
  ;HEAP32[$bounds+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$2+20>>2]|0;
 }
 $4 = HEAP32[$material>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = (__Z27AddMeshIntermediateRendererRK10Matrix4x4fP4MeshRK4AABB4PPtrIN5Unity8MaterialEEibbiP6Camera($matrix,$mesh,$bounds,$0,$layer,$castShadows,$receiveShadows,$submeshIndex,$camera)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z27AddMeshIntermediateRendererRK10Matrix4x4fP4MeshRK4AABB4PPtrIN5Unity8MaterialEEibbiP6Camera($matrix,$mesh,$localAABB,$material,$layer,$castShadows,$receiveShadows,$submeshIndex,$camera) {
 $matrix = $matrix|0;
 $mesh = $mesh|0;
 $localAABB = $localAABB|0;
 $material = $material|0;
 $layer = $layer|0;
 $castShadows = $castShadows|0;
 $receiveShadows = $receiveShadows|0;
 $submeshIndex = $submeshIndex|0;
 $camera = $camera|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[572776>>2]|0;
 $2 = (__ZN10MemoryPool8AllocateEj($1,252)|0);
 __THREW__ = 0;
 invoke_vii(2629,($2|0),10);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  $30 = HEAP32[572776>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($30|0),($2|0));
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if ($32) {
   $33 = ___cxa_find_matching_catch(0|0)|0;
   $34 = tempRet0;
   ___clang_call_terminate($33);
   // unreachable;
  } else {
   ___resumeException($28|0);
   // unreachable;
  }
 }
 $5 = (($2) + 188|0);
 HEAP32[$5>>2] = 0;
 $6 = (($2) + 192|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 196|0);
 HEAP32[$7>>2] = $2;
 $8 = (($2) + 200|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[628400>>2]|0;
 $10 = (($2) + 204|0);
 HEAP32[$10>>2] = 0;
 $11 = (($2) + 208|0);
 HEAP32[$11>>2] = $9;
 $12 = (($2) + 212|0);
 HEAP32[$12>>2] = 0;
 $13 = (($2) + 216|0);
 HEAP32[$13>>2] = 0;
 $14 = (($2) + 220|0);
 HEAP32[$14>>2] = 0;
 $15 = (($2) + 224|0);
 HEAP32[$15>>2] = $9;
 $16 = (($2) + 228|0);
 HEAP32[$16>>2] = 0;
 $17 = (($2) + 232|0);
 HEAP32[$17>>2] = 0;
 $18 = (($2) + 236|0);
 $19 = HEAP32[641904>>2]|0;
 HEAP32[$18>>2] = $19;
 HEAP32[$2>>2] = ((572824 + 8|0));
 $20 = (($2) + 244|0);
 HEAP32[$20>>2] = 0;
 $21 = (($2) + 248|0);
 HEAP32[$21>>2] = 0;
 $22 = HEAP32[$material>>2]|0;
 HEAP32[$0>>2] = $22;
 __ZN24MeshIntermediateRenderer10InitializeERK10Matrix4x4fP4MeshRK4AABB4PPtrIN5Unity8MaterialEEibbi($2,$matrix,$mesh,$localAABB,$0,$layer,$castShadows,$receiveShadows,$submeshIndex);
 $23 = ($camera|0)==(0|0);
 if ($23) {
  $26 = (__ZN5Unity8GetSceneEv()|0);
  $27 = $26;
  __ZN21IntermediateRenderers3AddEP20IntermediateRenderer($27,$2);
  STACKTOP = sp;return ($2|0);
 } else {
  $24 = (($camera) + 372|0);
  $25 = HEAP32[$24>>2]|0;
  $27 = $25;
  __ZN21IntermediateRenderers3AddEP20IntermediateRenderer($27,$2);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z23AddIntermediateRendererP20IntermediateRendererP6Camera($renderer,$camera) {
 $renderer = $renderer|0;
 $camera = $camera|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($camera|0)==(0|0);
 if ($0) {
  $3 = (__ZN5Unity8GetSceneEv()|0);
  $4 = $3;
 } else {
  $1 = (($camera) + 372|0);
  $2 = HEAP32[$1>>2]|0;
  $4 = $2;
 }
 __ZN21IntermediateRenderers3AddEP20IntermediateRenderer($4,$renderer);
 STACKTOP = sp;return;
}
function __Z48AddMeshIntermediateRendererWithDistanceSortOrderRK10Matrix4x4fP4MeshtRK4AABB4PPtrIN5Unity8MaterialEEibbiP6Camera($matrix,$mesh,$distanceSortingOrder,$localAABB,$material,$layer,$castShadows,$receiveShadows,$submeshIndex,$camera) {
 $matrix = $matrix|0;
 $mesh = $mesh|0;
 $distanceSortingOrder = $distanceSortingOrder|0;
 $localAABB = $localAABB|0;
 $material = $material|0;
 $layer = $layer|0;
 $castShadows = $castShadows|0;
 $receiveShadows = $receiveShadows|0;
 $submeshIndex = $submeshIndex|0;
 $camera = $camera|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $renderers$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[572920>>2]|0;
 $2 = (__ZN10MemoryPool8AllocateEj($1,256)|0);
 __THREW__ = 0;
 invoke_vii(2629,($2|0),10);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  $29 = HEAP32[572920>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($29|0),($2|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $33 = ___cxa_find_matching_catch(0|0)|0;
   $34 = tempRet0;
   ___clang_call_terminate($33);
   // unreachable;
  } else {
   ___resumeException($27|0);
   // unreachable;
  }
 }
 $5 = (($2) + 188|0);
 HEAP32[$5>>2] = 0;
 $6 = (($2) + 192|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 196|0);
 HEAP32[$7>>2] = $2;
 $8 = (($2) + 200|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[628400>>2]|0;
 $10 = (($2) + 204|0);
 HEAP32[$10>>2] = 0;
 $11 = (($2) + 208|0);
 HEAP32[$11>>2] = $9;
 $12 = (($2) + 212|0);
 HEAP32[$12>>2] = 0;
 $13 = (($2) + 216|0);
 HEAP32[$13>>2] = 0;
 $14 = (($2) + 220|0);
 HEAP32[$14>>2] = 0;
 $15 = (($2) + 224|0);
 HEAP32[$15>>2] = $9;
 $16 = (($2) + 228|0);
 HEAP32[$16>>2] = 0;
 $17 = (($2) + 232|0);
 HEAP32[$17>>2] = 0;
 $18 = (($2) + 236|0);
 $19 = HEAP32[641904>>2]|0;
 HEAP32[$18>>2] = $19;
 $20 = (($2) + 244|0);
 HEAP32[$20>>2] = 0;
 $21 = (($2) + 248|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$2>>2] = ((572984 + 8|0));
 $22 = (($2) + 252|0);
 $23 = HEAP32[$material>>2]|0;
 HEAP16[$22>>1] = $distanceSortingOrder;
 HEAP32[$0>>2] = $23;
 __ZN24MeshIntermediateRenderer10InitializeERK10Matrix4x4fP4MeshRK4AABB4PPtrIN5Unity8MaterialEEibbi($2,$matrix,$mesh,$localAABB,$0,$layer,$castShadows,$receiveShadows,$submeshIndex);
 $24 = ($camera|0)==(0|0);
 if ($24) {
  $32 = (__ZN5Unity8GetSceneEv()|0);
  $renderers$0 = $32;
  __ZN21IntermediateRenderers3AddEP20IntermediateRenderer($renderers$0,$2);
  STACKTOP = sp;return ($2|0);
 } else {
  $25 = (($camera) + 372|0);
  $26 = HEAP32[$25>>2]|0;
  $renderers$0 = $26;
  __ZN21IntermediateRenderers3AddEP20IntermediateRenderer($renderers$0,$2);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __ZN20IntermediateRenderer19UpdateTransformInfoEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK20IntermediateRenderer8GetLayerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 240|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK20IntermediateRenderer16GetMaterialCountEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK20IntermediateRenderer11GetMaterialEi($agg$result,$this,$i) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 STACKTOP = sp;return;
}
function __ZNK20IntermediateRenderer12GetLayerMaskEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 240|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = 1 << $1;
 STACKTOP = sp;return ($2|0);
}
function __ZN20IntermediateRenderer7GetMeshEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN20IntermediateRenderer10UpdateAABBEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK24MeshIntermediateRenderer14AllowsBatchingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK24MeshIntermediateRenderer14GetSubsetIndexEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 248|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN24MeshIntermediateRenderer7GetMeshEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK48MeshIntermediateRendererWithDistanceSortingOrder23GetDistanceSortPriorityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 252|0);
 $1 = HEAP16[$0>>1]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z21GetRenderModeSortBiasi($mode) {
 $mode = $mode|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (573144 + ($mode<<2)|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5Light11CalcQuadFacEf($range) {
 $range = Math_fround($range);
 var $0 = Math_fround(0), $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($range * $range);
 $1 = Math_fround(Math_fround(25.0) / $0);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN5Light19AttenuateNormalizedEf($distSqr) {
 $distSqr = Math_fround($distSqr);
 var $0 = Math_fround(0), $1 = Math_fround(0), $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $atten$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($distSqr * Math_fround(25.0));
 $1 = Math_fround($0 + Math_fround(1.0));
 $2 = Math_fround(Math_fround(1.0) / $1);
 $3 = !($distSqr >= Math_fround(0.640000045299530029296));
 if ($3) {
  $atten$0 = $2;
  STACKTOP = sp;return (Math_fround($atten$0));
 }
 $4 = $distSqr > Math_fround(1.0);
 if ($4) {
  $atten$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($atten$0));
 }
 $5 = Math_fround($distSqr + Math_fround(-0.640000045299530029296));
 $6 = Math_fround($5 / Math_fround(0.359999954700469970703));
 $7 = Math_fround(Math_fround(1.0) - $6);
 $8 = Math_fround($2 * $7);
 $atten$0 = $8;
 STACKTOP = sp;return (Math_fround($atten$0));
}
function __ZN5LightC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 $2 = (($this) + 28|0);
 HEAP8[$2>>0] = 1;
 $3 = (($this) + 29|0);
 HEAP8[$3>>0] = 0;
 $4 = (($this) + 32|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 36|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$this>>2] = ((573160 + 8|0));
 $6 = (($this) + 104|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 108|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 112|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 116|0);
 __THREW__ = 0;
 invoke_vi(3419,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = (($this) + 40|0);
  $13 = (($this) + 172|0);
  HEAP32[$13>>2] = 0;
  $14 = (($this) + 176|0);
  HEAP32[$14>>2] = 0;
  $15 = (($this) + 221|0);
  HEAP8[$15>>0] = 0;
  $16 = (($this) + 228|0);
  HEAP32[$16>>2] = 0;
  $17 = (($this) + 248|0);
  $18 = Math_fround(HEAPF32[616680>>2]);
  HEAPF32[$17>>2] = $18;
  $19 = (($this) + 252|0);
  $20 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
  HEAPF32[$19>>2] = $20;
  $21 = (($this) + 256|0);
  $22 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
  HEAPF32[$21>>2] = $22;
  $23 = (($this) + 260|0);
  HEAPF32[$23>>2] = Math_fround(1.0);
  $24 = (($this) + 264|0);
  $25 = Math_fround(HEAPF32[616744>>2]);
  HEAPF32[$24>>2] = $25;
  $26 = (($this) + 268|0);
  $27 = Math_fround(HEAPF32[((616744 + 4|0))>>2]);
  HEAPF32[$26>>2] = $27;
  $28 = (($this) + 272|0);
  $29 = Math_fround(HEAPF32[((616744 + 8|0))>>2]);
  HEAPF32[$28>>2] = $29;
  $30 = (($this) + 276|0);
  HEAPF32[$30>>2] = Math_fround(1.0);
  $31 = (($this) + 280|0);
  HEAPF32[$31>>2] = Math_fround(0.0);
  $32 = (($this) + 284|0);
  HEAPF32[$32>>2] = Math_fround(0.0);
  $33 = (($this) + 288|0);
  HEAPF32[$33>>2] = Math_fround(0.0);
  $34 = (($this) + 292|0);
  HEAPF32[$34>>2] = Math_fround(1.0);
  $35 = (($this) + 296|0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  $36 = (($this) + 300|0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $37 = (($this) + 304|0);
  HEAPF32[$37>>2] = Math_fround(0.0);
  $38 = (($this) + 308|0);
  HEAP32[$38>>2] = 1;
  $39 = (($this) + 312|0);
  HEAP8[$39>>0] = 0;
  $40 = (($this) + 236|0);
  HEAP32[$40>>2] = 1;
  $41 = (($this) + 240|0);
  HEAP32[$41>>2] = 0;
  $42 = (($this) + 244|0);
  HEAP32[$42>>2] = -1;
  dest=$12+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  ;HEAP32[$6+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[616680+8>>2]|0;
  STACKTOP = sp;return;
 }
 $43 = ___cxa_find_matching_catch()|0;
 $44 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $47 = ___cxa_find_matching_catch(0|0)|0;
  $48 = tempRet0;
  ___clang_call_terminate($47);
  // unreachable;
 } else {
  ___resumeException($43|0);
  // unreachable;
 }
}
function __ZN5Light15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(108,564104,1683,0);
 STACKTOP = sp;return;
}
function __ZZN5Light15InitializeClassEvEN35FunctorImpl_Light_kTransformChanged4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $2 = sp + 16|0;
 $3 = sp;
 $4 = (($object) + 29|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $12 = (($object) + 312|0);
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 }
 $7 = (($object) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($8)|0);
 $10 = (($object) + 40|0);
 __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($2,$9);
 dest=$10+0|0; src=$2+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $11 = (($object) + 104|0);
 __ZNK9Transform11GetPositionEv($3,$9);
 ;HEAP32[$11+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$3+8>>2]|0;
 __ZN5Light7PrecalcEv($object);
 $12 = (($object) + 312|0);
 HEAP8[$12>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5Light12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK5Light15AttenuateApproxEf($this,$sqrDist) {
 $this = $this|0;
 $sqrDist = Math_fround($sqrDist);
 var $0 = 0, $1 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 188|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * $1);
 $3 = Math_fround(Math_fround(25.0) / $2);
 $4 = Math_fround($3 * $sqrDist);
 $5 = Math_fround($4 + Math_fround(1.0));
 $6 = Math_fround(Math_fround(1.0) / $5);
 STACKTOP = sp;return (Math_fround($6));
}
function __ZN5Light7PrecalcEv($this) {
 $this = $this|0;
 var $$0$i$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$in = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $6 = 0, $7 = Math_fround(0);
 var $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetActiveColorSpacev()|0);
 $1 = ($0|0)==(1);
 $2 = (($this) + 140|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 do {
  if ($1) {
   $4 = !($3 <= Math_fround(0.0404499992728233337402));
   do {
    if ($4) {
     $6 = $3 < Math_fround(1.0);
     if ($6) {
      $7 = Math_fround($3 + Math_fround(0.054999999701976776123));
      $8 = Math_fround($7 / Math_fround(1.05499994754791259766));
      $9 = (Math_fround(+(Math_pow((+$8),2.40000009536743164063))));
      $$0$i$i$i = $9;
      break;
     } else {
      $10 = (Math_fround(+(Math_pow((+$3),2.40000009536743164063))));
      $$0$i$i$i = $10;
      break;
     }
    } else {
     $5 = Math_fround($3 / Math_fround(12.9200000762939453125));
     $$0$i$i$i = $5;
    }
   } while(0);
   $11 = (($this) + 144|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = !($12 <= Math_fround(0.0404499992728233337402));
   do {
    if ($13) {
     $15 = $12 < Math_fround(1.0);
     if ($15) {
      $16 = Math_fround($12 + Math_fround(0.054999999701976776123));
      $17 = Math_fround($16 / Math_fround(1.05499994754791259766));
      $18 = (Math_fround(+(Math_pow((+$17),2.40000009536743164063))));
      $$0$i3$i$i = $18;
      break;
     } else {
      $19 = (Math_fround(+(Math_pow((+$12),2.40000009536743164063))));
      $$0$i3$i$i = $19;
      break;
     }
    } else {
     $14 = Math_fround($12 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i = $14;
    }
   } while(0);
   $20 = (($this) + 148|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = !($21 <= Math_fround(0.0404499992728233337402));
   if (!($22)) {
    $23 = Math_fround($21 / Math_fround(12.9200000762939453125));
    $37 = $$0$i$i$i;$39 = $$0$i3$i$i;$41 = $23;
    break;
   }
   $24 = $21 < Math_fround(1.0);
   if ($24) {
    $25 = Math_fround($21 + Math_fround(0.054999999701976776123));
    $26 = Math_fround($25 / Math_fround(1.05499994754791259766));
    $27 = (Math_fround(+(Math_pow((+$26),2.40000009536743164063))));
    $37 = $$0$i$i$i;$39 = $$0$i3$i$i;$41 = $27;
    break;
   } else {
    $28 = (Math_fround(+(Math_pow((+$21),2.40000009536743164063))));
    $37 = $$0$i$i$i;$39 = $$0$i3$i$i;$41 = $28;
    break;
   }
  } else {
   $29 = (($this) + 144|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = (($this) + 148|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $37 = $3;$39 = $30;$41 = $32;
  }
 } while(0);
 $$in = (($this) + 152|0);
 $33 = Math_fround(HEAPF32[$$in>>2]);
 $34 = (($this) + 184|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($37 * $35);
 $38 = Math_fround($39 * $35);
 $40 = Math_fround($41 * $35);
 $42 = Math_fround($33 * $35);
 $43 = (($this) + 156|0);
 HEAPF32[$43>>2] = $36;
 $44 = (($this) + 160|0);
 HEAPF32[$44>>2] = $38;
 $45 = (($this) + 164|0);
 HEAPF32[$45>>2] = $40;
 $46 = (($this) + 168|0);
 HEAPF32[$46>>2] = $42;
 $47 = (($this) + 192|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($48 * Math_fround(0.5));
 $50 = Math_fround($49 / Math_fround(360.0));
 $51 = Math_fround($50 * Math_fround(2.0));
 $52 = Math_fround($51 * Math_fround(3.14159274101257324219));
 $53 = (Math_fround(+(Math_cos((+$52)))));
 $54 = (Math_fround(+(Math_sin((+$52)))));
 $55 = Math_fround($53 / $54);
 $56 = (($this) + 200|0);
 HEAPF32[$56>>2] = $55;
 $57 = Math_fround(Math_fround(1.0) / $53);
 $58 = (($this) + 204|0);
 HEAPF32[$58>>2] = $57;
 __ZN5Light16SetupAttenuationEv($this);
 __ZN5Light9SetupHaloEv($this);
 __ZN5Light10SetupFlareEv($this);
 STACKTOP = sp;return;
}
function __ZN5Light5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 __ZN14ShadowSettings5ResetEv($0);
 $1 = (($this) + 140|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 144|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 148|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 152|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 184|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 188|0);
 HEAPF32[$6>>2] = Math_fround(10.0);
 $7 = (($this) + 192|0);
 HEAPF32[$7>>2] = Math_fround(30.0);
 $8 = (($this) + 196|0);
 HEAPF32[$8>>2] = Math_fround(10.0);
 $9 = (($this) + 212|0);
 HEAP32[$9>>2] = 4;
 $10 = (($this) + 200|0);
 HEAPF32[$10>>2] = Math_fround(3.73205065727233886719);
 $11 = (($this) + 204|0);
 HEAPF32[$11>>2] = Math_fround(1.03527617454528808594);
 $12 = (($this) + 208|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 220|0);
 HEAP8[$13>>0] = 0;
 $14 = (($this) + 216|0);
 HEAP32[$14>>2] = 2;
 $15 = (($this) + 180|0);
 HEAP32[$15>>2] = -1;
 $16 = (($this) + 224|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN5Light16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$$i = Math_fround(0), $$$i10 = 0, $$$i4 = Math_fround(0), $$$i7 = Math_fround(0), $$0$i11 = 0, $$0$i3 = Math_fround(0), $$0$i5 = Math_fround(0), $$0$i8 = Math_fround(0), $$mask = 0, $$mask18 = 0, $$mask19 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0;
 var $106 = Math_fround(0), $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0;
 var $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 176|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = (($this) + 216|0);
   $64 = $4;
  } else {
   HEAP32[$0>>2] = $2;
   $5 = HEAP32[560624>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    label = 11;
   } else {
    $7 = (($5) + 36|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($5) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    do {
     if ($11) {
      $12 = (($5) + 28|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($5) + 32|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($13) + ($15<<3)|0);
      $32 = $16;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$0);
      $17 = HEAP32[$pos$i$i$i$i>>2]|0;
      $18 = ($17|0)==(-1);
      $19 = (($5) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      if ($18) {
       $21 = (($5) + 32|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + ($22<<3)|0);
       $32 = $23;
       break;
      } else {
       $24 = (($20) + ($17<<3)|0);
       $32 = $24;
       break;
      }
     }
    } while(0);
    $25 = HEAP32[560624>>2]|0;
    $26 = (($25) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + ($29<<3)|0);
    $31 = ($32|0)==($30|0);
    if ($31) {
     label = 11;
    } else {
     $33 = (($32) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      label = 11;
     } else {
      $temp$0$i = $34;
     }
    }
   }
   if ((label|0) == 11) {
    $36 = HEAP32[$1>>2]|0;
    $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
    $temp$0$i = $37;
   }
   $38 = (($this) + 216|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)!=(2);
   $41 = ($temp$0$i|0)==(0|0);
   $or$cond = $40 | $41;
   if (!($or$cond)) {
    $42 = (($temp$0$i) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $$mask = $43 & -2097152;
    $44 = ($$mask|0)==(186646528);
    if (!($44)) {
     HEAP32[$1>>2] = 0;
     $64 = $38;
     break;
    }
   }
   $45 = ($39|0)==(2);
   $or$cond1 = $45 | $41;
   if (!($or$cond1)) {
    $46 = (($temp$0$i) + 8|0);
    $47 = HEAP32[$46>>2]|0;
    $$mask19 = $47 & -2097152;
    $48 = ($$mask19|0)==(186646528);
    if ($48) {
     HEAP32[$1>>2] = 0;
     $64 = $38;
     break;
    }
   }
   $49 = ($39|0)!=(0);
   $or$cond2 = $49 | $41;
   if ($or$cond2) {
    $64 = $38;
   } else {
    $50 = HEAP32[$temp$0$i>>2]|0;
    $51 = (($50) + 108|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (FUNCTION_TABLE_ii[$52 & 4095]($temp$0$i)|0);
    $54 = HEAP32[$temp$0$i>>2]|0;
    $55 = (($54) + 104|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (FUNCTION_TABLE_ii[$56 & 4095]($temp$0$i)|0);
    $58 = ($53|0)==($57|0);
    if ($58) {
     $64 = $38;
    } else {
     $59 = ($this|0)==(0|0);
     if ($59) {
      $62 = 0;
     } else {
      $60 = (($this) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = $61;
     }
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(573304,0,573376,162,1,$62,0,0);
     HEAP32[$1>>2] = 0;
     $64 = $38;
    }
   }
  }
 } while(0);
 $63 = HEAP32[$64>>2]|0;
 $65 = ($63|0)<(0);
 if ($65) {
  $$0$i11 = 0;
 } else {
  $66 = ($63|0)>(3);
  $$$i10 = $66 ? 3 : $63;
  $$0$i11 = $$$i10;
 }
 HEAP32[$64>>2] = $$0$i11;
 $67 = (($this) + 212|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68 & 7;
 $70 = ($69|0)==(0);
 if ($70) {
  label = 27;
 } else {
  $71 = $68 >>> 1;
  $72 = $71 & 1431655765;
  $73 = (($68) - ($72))|0;
  $74 = $73 & 858993459;
  $75 = $73 >>> 2;
  $76 = $75 & 858993459;
  $77 = (($76) + ($74))|0;
  $78 = $77 >>> 4;
  $79 = (($78) + ($77))|0;
  $80 = $79 & 252645135;
  $81 = Math_imul($80, 16843009)|0;
  $$mask18 = $81 & -16777216;
  $82 = ($$mask18|0)==(16777216);
  if (!($82)) {
   label = 27;
  }
 }
 if ((label|0) == 27) {
  HEAP32[$67>>2] = 4;
 }
 $83 = (($this) + 188|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = $84 < Math_fround(0.0);
 $86 = $85 ? Math_fround(0.0) : $84;
 HEAPF32[$83>>2] = $86;
 $87 = (($this) + 192|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = $88 > Math_fround(179.0);
 $90 = $89 ? Math_fround(179.0) : $88;
 $91 = $90 < Math_fround(1.0);
 $92 = $91 ? Math_fround(1.0) : $90;
 HEAPF32[$87>>2] = $92;
 $93 = (($this) + 196|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = $94 < Math_fround(0.0);
 $96 = $95 ? Math_fround(0.0) : $94;
 HEAPF32[$93>>2] = $96;
 $97 = (($this) + 128|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = $98 < Math_fround(0.0);
 if ($99) {
  $$0$i8 = Math_fround(0.0);
 } else {
  $100 = $98 > Math_fround(10.0);
  $$$i7 = $100 ? Math_fround(10.0) : $98;
  $$0$i8 = $$$i7;
 }
 HEAPF32[$97>>2] = $$0$i8;
 $101 = (($this) + 132|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = $102 < Math_fround(1.0);
 if ($103) {
  $$0$i5 = Math_fround(1.0);
 } else {
  $104 = $102 > Math_fround(8.0);
  $$$i4 = $104 ? Math_fround(8.0) : $102;
  $$0$i5 = $$$i4;
 }
 HEAPF32[$101>>2] = $$0$i5;
 $105 = (($this) + 136|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = $106 < Math_fround(0.100000001490116119385);
 if ($107) {
  $$0$i3 = Math_fround(0.100000001490116119385);
  HEAPF32[$105>>2] = $$0$i3;
  STACKTOP = sp;return;
 }
 $108 = $106 > Math_fround(5.0);
 $$$i = $108 ? Math_fround(5.0) : $106;
 $$0$i3 = $$$i;
 HEAPF32[$105>>2] = $$0$i3;
 STACKTOP = sp;return;
}
function __ZN5Light12AddToManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($3)|0);
 $5 = (($this) + 40|0);
 __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($0,$4);
 dest=$5+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = (($this) + 104|0);
 __ZNK9Transform11GetPositionEv($1,$4);
 ;HEAP32[$6+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$1+8>>2]|0;
 $7 = (__Z15GetLightManagerv()|0);
 __ZN12LightManager8AddLightEP5Light($7,$this);
 __ZN5Light9SetupHaloEv($this);
 __ZN5Light10SetupFlareEv($this);
 STACKTOP = sp;return;
}
function __ZN5Light9SetupHaloEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$op$i$i$i$i = Math_fround(0), $$op$i1$i$i$i = Math_fround(0), $$op$i2$i$i$i = Math_fround(0), $$op$i3$i$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0);
 var $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 28|0;
 $$byval_copy = sp;
 $0 = sp + 12|0;
 $1 = sp + 24|0;
 $2 = (($this) + 220|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = (($this) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (__ZNK5Unity10GameObject8IsActiveEv($6)|0);
   if ($8) {
    $9 = (($this) + 28|0);
    $10 = HEAP8[$9>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if (!($11)) {
     $12 = (__Z17GetRenderSettingsv()|0);
     $13 = (($12) + 404|0);
     $14 = Math_fround(HEAPF32[$13>>2]);
     $15 = (($this) + 240|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0);
     if ($17) {
      $18 = (__Z14GetHaloManagerv()|0);
      $19 = (__ZN11HaloManager7AddHaloEv($18)|0);
      HEAP32[$15>>2] = $19;
      $20 = ($19|0)==(0);
      if ($20) {
       STACKTOP = sp;return;
      }
     }
     $21 = (__Z14GetHaloManagerv()|0);
     $22 = HEAP32[$15>>2]|0;
     $23 = HEAP32[$5>>2]|0;
     $24 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($23)|0);
     __ZNK9Transform11GetPositionEv($0,$24);
     $25 = (($this) + 184|0);
     $26 = Math_fround(HEAPF32[$25>>2]);
     $27 = Math_fround($14 * $26);
     $28 = (($this) + 152|0);
     $29 = Math_fround(HEAPF32[$28>>2]);
     $30 = Math_fround($27 * $29);
     $31 = (($this) + 140|0);
     $32 = Math_fround(HEAPF32[$31>>2]);
     $33 = Math_fround($32 * $30);
     $34 = (($this) + 144|0);
     $35 = Math_fround(HEAPF32[$34>>2]);
     $36 = Math_fround($30 * $35);
     $37 = (($this) + 148|0);
     $38 = Math_fround(HEAPF32[$37>>2]);
     $39 = Math_fround($30 * $38);
     $40 = Math_fround($30 * $29);
     $41 = $33 < Math_fround(0.0);
     $42 = $41 ? Math_fround(0.0) : $33;
     $43 = $42 > Math_fround(1.0);
     $$op$i$i$i$i = Math_fround($42 * Math_fround(255.0));
     $44 = $43 ? Math_fround(255.0) : $$op$i$i$i$i;
     $45 = Math_fround($44 + Math_fround(0.5));
     $46 = (~~(($45))>>>0);
     $47 = $46&255;
     HEAP8[$1>>0] = $47;
     $48 = $36 < Math_fround(0.0);
     $49 = $48 ? Math_fround(0.0) : $36;
     $50 = $49 > Math_fround(1.0);
     $$op$i3$i$i$i = Math_fround($49 * Math_fround(255.0));
     $51 = $50 ? Math_fround(255.0) : $$op$i3$i$i$i;
     $52 = Math_fround($51 + Math_fround(0.5));
     $53 = (~~(($52))>>>0);
     $54 = $53&255;
     $55 = (($1) + 1|0);
     HEAP8[$55>>0] = $54;
     $56 = $39 < Math_fround(0.0);
     $57 = $56 ? Math_fround(0.0) : $39;
     $58 = $57 > Math_fround(1.0);
     $$op$i2$i$i$i = Math_fround($57 * Math_fround(255.0));
     $59 = $58 ? Math_fround(255.0) : $$op$i2$i$i$i;
     $60 = Math_fround($59 + Math_fround(0.5));
     $61 = (~~(($60))>>>0);
     $62 = $61&255;
     $63 = (($1) + 2|0);
     HEAP8[$63>>0] = $62;
     $64 = $40 < Math_fround(0.0);
     $65 = $64 ? Math_fround(0.0) : $40;
     $66 = $65 > Math_fround(1.0);
     $$op$i1$i$i$i = Math_fround($65 * Math_fround(255.0));
     $67 = $66 ? Math_fround(255.0) : $$op$i1$i$i$i;
     $68 = Math_fround($67 + Math_fround(0.5));
     $69 = (~~(($68))>>>0);
     $70 = $69&255;
     $71 = (($1) + 3|0);
     HEAP8[$71>>0] = $70;
     $72 = (($this) + 188|0);
     $73 = Math_fround(HEAPF32[$72>>2]);
     $74 = Math_fround($14 * $73);
     $75 = HEAP32[$5>>2]|0;
     $76 = (($75) + 40|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = 1 << $77;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
     __ZN11HaloManager10UpdateHaloEi8Vector3f11ColorRGBA32fj($21,$22,$$byval_copy,$$byval_copy1,$74,$78);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $79 = (($this) + 240|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0);
 if ($81) {
  STACKTOP = sp;return;
 }
 $82 = (__Z14GetHaloManagerv()|0);
 $83 = HEAP32[$79>>2]|0;
 __ZN11HaloManager10DeleteHaloEi($82,$83);
 HEAP32[$79>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Light10SetupFlareEv($this) {
 $this = $this|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $inf$0$off0 = 0, $pos = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i = sp + 56|0;
 $0 = sp;
 $pos = sp + 4|0;
 $1 = sp + 16|0;
 $2 = sp + 28|0;
 $3 = sp + 40|0;
 $4 = (($this) + 172|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if (!($6)) {
   HEAP32[$0>>2] = $5;
   $7 = HEAP32[560624>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 11;
   } else {
    $9 = (($7) + 36|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    do {
     if ($13) {
      $14 = (($7) + 28|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($7) + 32|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($15) + ($17<<3)|0);
      $34 = $18;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$7,$0);
      $19 = HEAP32[$pos$i$i$i>>2]|0;
      $20 = ($19|0)==(-1);
      $21 = (($7) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      if ($20) {
       $23 = (($7) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $34 = $25;
       break;
      } else {
       $26 = (($22) + ($19<<3)|0);
       $34 = $26;
       break;
      }
     }
    } while(0);
    $27 = HEAP32[560624>>2]|0;
    $28 = (($27) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + ($31<<3)|0);
    $33 = ($34|0)==($32|0);
    if ($33) {
     label = 11;
    } else {
     $35 = (($34) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      label = 11;
     } else {
      $$in = $36;
     }
    }
   }
   if ((label|0) == 11) {
    $38 = HEAP32[$4>>2]|0;
    $39 = (__Z31ReadObjectFromPersistentManageri($38)|0);
    $40 = ($39|0)==(0|0);
    if ($40) {
     break;
    } else {
     $$in = $39;
    }
   }
   $41 = (($this) + 24|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = (__ZNK5Unity10GameObject8IsActiveEv($42)|0);
    if ($44) {
     $45 = (($this) + 28|0);
     $46 = HEAP8[$45>>0]|0;
     $47 = ($46<<24>>24)==(0);
     if (!($47)) {
      HEAPF32[$pos>>2] = Math_fround(0.0);
      $53 = (($pos) + 4|0);
      HEAPF32[$53>>2] = Math_fround(0.0);
      $54 = (($pos) + 8|0);
      HEAPF32[$54>>2] = Math_fround(0.0);
      $55 = (($this) + 216|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($56|0)==(1);
      $58 = HEAP32[$41>>2]|0;
      $59 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($58)|0);
      if ($57) {
       HEAPF32[$3>>2] = Math_fround(0.0);
       $60 = (($3) + 4|0);
       HEAPF32[$60>>2] = Math_fround(0.0);
       $61 = (($3) + 8|0);
       HEAPF32[$61>>2] = Math_fround(1.0);
       __ZNK9Transform18TransformDirectionERK8Vector3f($2,$59,$3);
       ;HEAP32[$pos+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$pos+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$pos+8>>2]=HEAP32[$2+8>>2]|0;
       $inf$0$off0 = 1;
      } else {
       __ZNK9Transform11GetPositionEv($1,$59);
       ;HEAP32[$pos+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$pos+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$pos+8>>2]=HEAP32[$1+8>>2]|0;
       $inf$0$off0 = 0;
      }
      $62 = (($this) + 244|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($63|0)==(-1);
      if ($64) {
       $65 = (__ZN12FlareManager3GetEv()|0);
       $66 = (__ZN12FlareManager8AddFlareEv($65)|0);
       HEAP32[$62>>2] = $66;
      }
      $67 = (__ZN12FlareManager3GetEv()|0);
      $68 = HEAP32[$62>>2]|0;
      $69 = (__Z17GetRenderSettingsv()|0);
      $70 = (($69) + 408|0);
      $71 = Math_fround(HEAPF32[$70>>2]);
      $72 = (($this) + 156|0);
      $73 = (__Z17GetRenderSettingsv()|0);
      $74 = (($73) + 412|0);
      $75 = Math_fround(HEAPF32[$74>>2]);
      $76 = HEAP32[$41>>2]|0;
      $77 = (($76) + 40|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = 1 << $78;
      __ZN12FlareManager11UpdateFlareEiP5FlareRK8Vector3fbfRK10ColorRGBAffjj($67,$68,$$in,$pos,$inf$0$off0,$71,$72,$75,$79,6);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $48 = (($this) + 244|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(-1);
 if ($50) {
  STACKTOP = sp;return;
 }
 $51 = (__ZN12FlareManager3GetEv()|0);
 $52 = HEAP32[$48>>2]|0;
 __ZN12FlareManager11DeleteFlareEi($51,$52);
 HEAP32[$48>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5Light17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__Z15GetLightManagerv()|0);
  __ZN12LightManager11RemoveLightEP5Light($3,$this);
 }
 $4 = (($this) + 240|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (__Z14GetHaloManagerv()|0);
  $8 = HEAP32[$4>>2]|0;
  __ZN11HaloManager10DeleteHaloEi($7,$8);
  HEAP32[$4>>2] = 0;
 }
 $9 = (($this) + 244|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(-1);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (__ZN12FlareManager3GetEv()|0);
 $13 = HEAP32[$9>>2]|0;
 __ZN12FlareManager11DeleteFlareEi($12,$13);
 HEAP32[$9>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN5Light16SetupAttenuationEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $cookie$05 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 176|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   label = 10;
  } else {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
     $16 = HEAP32[$pos$i$i$i$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if ($30) {
    label = 10;
   } else {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     label = 10;
    } else {
     $temp$0$i = $33;
    }
   }
  }
  if ((label|0) == 10) {
   $35 = HEAP32[$1>>2]|0;
   $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
   $temp$0$i = $36;
  }
  $$0$i = $temp$0$i;
 }
 $37 = (($this) + 216|0);
 $38 = HEAP32[$37>>2]|0;
 if ((($38|0) == 0)) {
  $39 = ($$0$i|0)==(0|0);
  L19: do {
   if ($39) {
    $41 = (($this) + 24|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    do {
     if ($43) {
      $44 = (($this) + 228|0);
      $54 = $44;
     } else {
      $45 = (__ZNK5Unity10GameObject8IsActiveEv($42)|0);
      if ($45) {
       $46 = (($this) + 28|0);
       $47 = HEAP8[$46>>0]|0;
       $48 = ($47<<24>>24)==(0);
       if (!($48)) {
        $50 = (__Z17GetRenderSettingsv()|0);
        $51 = (__ZNK14RenderSettings20GetDefaultSpotCookieEv($50)|0);
        $52 = (($this) + 228|0);
        $53 = ($51|0)==(0|0);
        if ($53) {
         $54 = $52;
         break;
        } else {
         $57 = $52;$cookie$05 = $51;
         label = 22;
         break L19;
        }
       }
      }
      $49 = (($this) + 228|0);
      $54 = $49;
     }
    } while(0);
    HEAP32[$54>>2] = 0;
   } else {
    $40 = (($this) + 228|0);
    $57 = $40;$cookie$05 = $$0$i;
    label = 22;
   }
  } while(0);
  if ((label|0) == 22) {
   $55 = (($cookie$05) + 4|0);
   $56 = HEAP32[$55>>2]|0;
   HEAP32[$57>>2] = $56;
  }
  $58 = (($this) + 232|0);
  HEAP32[$58>>2] = 0;
  $59 = (($this) + 236|0);
  HEAP32[$59>>2] = 0;
  STACKTOP = sp;return;
 } else if ((($38|0) == 1)) {
  $72 = ($$0$i|0)==(0|0);
  $73 = (($this) + 228|0);
  if ($72) {
   HEAP32[$73>>2] = 0;
   $78 = (($this) + 232|0);
   HEAP32[$78>>2] = 3;
   $79 = (($this) + 236|0);
   HEAP32[$79>>2] = 1;
   STACKTOP = sp;return;
  } else {
   $74 = (($$0$i) + 4|0);
   $75 = HEAP32[$74>>2]|0;
   HEAP32[$73>>2] = $75;
   $76 = (($this) + 232|0);
   HEAP32[$76>>2] = 2;
   $77 = (($this) + 236|0);
   HEAP32[$77>>2] = 2;
   STACKTOP = sp;return;
  }
 } else if ((($38|0) == 2)) {
  $60 = ($$0$i|0)==(0|0);
  $61 = (($this) + 228|0);
  if (!($60)) {
   $62 = (($$0$i) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   HEAP32[$61>>2] = $63;
   $64 = (($this) + 232|0);
   HEAP32[$64>>2] = 1;
   $65 = (($this) + 236|0);
   HEAP32[$65>>2] = 4;
   STACKTOP = sp;return;
  }
  $66 = (__ZN10builtintex21GetAttenuationTextureEv()|0);
  $67 = ($66|0)==(0|0);
  if ($67) {
   HEAP32[$61>>2] = 0;
  } else {
   $68 = (($66) + 4|0);
   $69 = HEAP32[$68>>2]|0;
   HEAP32[$61>>2] = $69;
  }
  $70 = (($this) + 232|0);
  HEAP32[$70>>2] = 1;
  $71 = (($this) + 236|0);
  HEAP32[$71>>2] = 3;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNK5Light19SetPropsToShaderLabEf($this,$blend) {
 $this = $this|0;
 $blend = Math_fround($blend);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $pos$i$i$i$i = 0, $temp$0$i2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = (($this) + 156|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $blend);
 $5 = (($this) + 160|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $blend);
 $8 = (($this) + 164|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $blend);
 $11 = (($this) + 168|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $blend);
 $14 = (($1) + 548|0);
 HEAPF32[$14>>2] = $4;
 $15 = (($1) + 552|0);
 HEAPF32[$15>>2] = $7;
 $16 = (($1) + 556|0);
 HEAPF32[$16>>2] = $10;
 $17 = (($1) + 560|0);
 HEAPF32[$17>>2] = $13;
 $18 = (($this) + 228|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $19;
 $21 = HEAP32[560624>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  label = 10;
 } else {
  $23 = (($21) + 36|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($21) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($24|0)==($26|0);
  do {
   if ($27) {
    $28 = (($21) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($21) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + ($31<<3)|0);
    $48 = $32;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$21,$0);
    $33 = HEAP32[$pos$i$i$i$i>>2]|0;
    $34 = ($33|0)==(-1);
    $35 = (($21) + 28|0);
    $36 = HEAP32[$35>>2]|0;
    if ($34) {
     $37 = (($21) + 32|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($36) + ($38<<3)|0);
     $48 = $39;
     break;
    } else {
     $40 = (($36) + ($33<<3)|0);
     $48 = $40;
     break;
    }
   }
  } while(0);
  $41 = HEAP32[560624>>2]|0;
  $42 = (($41) + 28|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 32|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($43) + ($45<<3)|0);
  $47 = ($48|0)==($46|0);
  if ($47) {
   label = 10;
  } else {
   $49 = (($48) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    label = 10;
   } else {
    $temp$0$i2 = $50;
   }
  }
 }
 if ((label|0) == 10) {
  $52 = HEAP32[$18>>2]|0;
  $53 = (__Z31ReadObjectFromPersistentManageri($52)|0);
  $54 = ($53|0)==(0|0);
  if ($54) {
   STACKTOP = sp;return;
  } else {
   $temp$0$i2 = $53;
  }
 }
 $55 = HEAP32[652824>>2]|0;
 $56 = (($55) + 20|0);
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($56,573120,$temp$0$i2)|0);
 STACKTOP = sp;return;
}
function __ZN5Light15SetLightKeywordEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[652824>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & -32;
 $4 = (($this) + 236|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_bitshift64Shl(1,0,($5|0))|0);
 $7 = tempRet0;
 $8 = $6 | $3;
 HEAP32[$1>>2] = $8;
 STACKTOP = sp;return;
}
function __ZNK5Light9GetMatrixEPK10Matrix4x4fPS0_($this,$object2light,$outMatrix) {
 $this = $this|0;
 $object2light = $object2light|0;
 $outMatrix = $outMatrix|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $temp1 = 0, $temp2 = 0, $temp3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $temp1 = sp + 176|0;
 $temp2 = sp;
 $temp3 = sp + 64|0;
 $0 = sp + 128|0;
 $1 = sp + 140|0;
 $2 = sp + 152|0;
 $3 = sp + 164|0;
 $4 = (($this) + 232|0);
 $5 = HEAP32[$4>>2]|0;
 if ((($5|0) == 1)) {
  $16 = (($this) + 188|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround(Math_fround(1.0) / $17);
  HEAPF32[$1>>2] = $18;
  $19 = (($1) + 4|0);
  HEAPF32[$19>>2] = $18;
  $20 = (($1) + 8|0);
  HEAPF32[$20>>2] = $18;
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($temp1,$1)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp1,$object2light,$outMatrix);
  STACKTOP = sp;return;
 } else if ((($5|0) == 0)) {
  (__ZN10Matrix4x4f11SetIdentityEv($temp3)|0);
  $6 = (($this) + 200|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround(Math_fround(2.0) / $7);
  $9 = (($temp3) + 44|0);
  HEAPF32[$9>>2] = $8;
  $10 = (($temp3) + 60|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($this) + 188|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround(Math_fround(1.0) / $12);
  HEAPF32[$0>>2] = $13;
  $14 = (($0) + 4|0);
  HEAPF32[$14>>2] = $13;
  $15 = (($0) + 8|0);
  HEAPF32[$15>>2] = $13;
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($temp1,$0)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp3,$temp1,$temp2);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp2,$object2light,$outMatrix);
  STACKTOP = sp;return;
 } else if ((($5|0) == 2)) {
  $21 = (($this) + 196|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround(Math_fround(1.0) / $22);
  HEAPF32[$2>>2] = $23;
  $24 = (($2) + 4|0);
  HEAPF32[$24>>2] = $23;
  $25 = (($2) + 8|0);
  HEAPF32[$25>>2] = Math_fround(0.0);
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($temp1,$2)|0);
  HEAPF32[$3>>2] = Math_fround(0.5);
  $26 = (($3) + 4|0);
  HEAPF32[$26>>2] = Math_fround(0.5);
  $27 = (($3) + 8|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($temp2,$3)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp2,$temp1,$temp3);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp3,$object2light,$outMatrix);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNK5Light15ComputeGfxLightER14GfxVertexLight($this,$gfxLight) {
 $this = $this|0;
 $gfxLight = $gfxLight|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $9 = Math_fround(0), $lightDir = 0, $lightDir2 = 0, $lightPos = 0, $lightPos1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $lightPos = sp + 60|0;
 $lightDir = sp;
 $0 = sp + 12|0;
 $lightPos1 = sp + 24|0;
 $lightDir2 = sp + 36|0;
 $1 = sp + 48|0;
 $2 = (($this) + 216|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($gfxLight) + 60|0);
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($6)|0);
 $8 = HEAP32[$2>>2]|0;
 if ((($8|0) == 1)) {
  HEAPF32[$0>>2] = Math_fround(0.0);
  $27 = (($0) + 4|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  $28 = (($0) + 8|0);
  HEAPF32[$28>>2] = Math_fround(1.0);
  __ZNK9Transform18TransformDirectionERK8Vector3f($lightDir,$7,$0);
  $29 = Math_fround(HEAPF32[$lightDir>>2]);
  $30 = (($lightDir) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($lightDir) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$gfxLight>>2] = $29;
  $34 = (($gfxLight) + 4|0);
  HEAPF32[$34>>2] = $31;
  $35 = (($gfxLight) + 8|0);
  HEAPF32[$35>>2] = $33;
  $36 = (($gfxLight) + 12|0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $37 = (($gfxLight) + 52|0);
  HEAPF32[$37>>2] = Math_fround(0.0);
  $38 = (($gfxLight) + 56|0);
  HEAPF32[$38>>2] = Math_fround(-1.0);
  $39 = (($gfxLight) + 16|0);
  HEAPF32[$39>>2] = Math_fround(1.0);
  $40 = (($gfxLight) + 20|0);
  HEAPF32[$40>>2] = Math_fround(0.0);
  $41 = (($gfxLight) + 24|0);
  HEAPF32[$41>>2] = Math_fround(0.0);
  $42 = (($gfxLight) + 28|0);
  HEAPF32[$42>>2] = Math_fround(0.0);
 } else if ((($8|0) == 0)) {
  __ZNK9Transform11GetPositionEv($lightPos1,$7);
  $43 = Math_fround(HEAPF32[$lightPos1>>2]);
  $44 = (($lightPos1) + 4|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($lightPos1) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  HEAPF32[$gfxLight>>2] = $43;
  $48 = (($gfxLight) + 4|0);
  HEAPF32[$48>>2] = $45;
  $49 = (($gfxLight) + 8|0);
  HEAPF32[$49>>2] = $47;
  $50 = (($gfxLight) + 12|0);
  HEAPF32[$50>>2] = Math_fround(1.0);
  HEAPF32[$1>>2] = Math_fround(0.0);
  $51 = (($1) + 4|0);
  HEAPF32[$51>>2] = Math_fround(0.0);
  $52 = (($1) + 8|0);
  HEAPF32[$52>>2] = Math_fround(1.0);
  __ZNK9Transform18TransformDirectionERK8Vector3f($lightDir2,$7,$1);
  $53 = Math_fround(HEAPF32[$lightDir2>>2]);
  $54 = (($lightDir2) + 4|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($lightDir2) + 8|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($gfxLight) + 16|0);
  HEAPF32[$58>>2] = $53;
  $59 = (($gfxLight) + 20|0);
  HEAPF32[$59>>2] = $55;
  $60 = (($gfxLight) + 24|0);
  HEAPF32[$60>>2] = $57;
  $61 = (($gfxLight) + 28|0);
  HEAPF32[$61>>2] = Math_fround(0.0);
  $62 = (($this) + 192|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($gfxLight) + 56|0);
  HEAPF32[$64>>2] = $63;
  $65 = (($this) + 188|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($66 * $66);
  $68 = Math_fround(Math_fround(25.0) / $67);
  $69 = (($gfxLight) + 52|0);
  HEAPF32[$69>>2] = $68;
 } else if ((($8|0) == 2)) {
  __ZNK9Transform11GetPositionEv($lightPos,$7);
  $9 = Math_fround(HEAPF32[$lightPos>>2]);
  $10 = (($lightPos) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($lightPos) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$gfxLight>>2] = $9;
  $14 = (($gfxLight) + 4|0);
  HEAPF32[$14>>2] = $11;
  $15 = (($gfxLight) + 8|0);
  HEAPF32[$15>>2] = $13;
  $16 = (($gfxLight) + 12|0);
  HEAPF32[$16>>2] = Math_fround(1.0);
  $17 = (($gfxLight) + 56|0);
  HEAPF32[$17>>2] = Math_fround(-1.0);
  $18 = (($this) + 188|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($19 * $19);
  $21 = Math_fround(Math_fround(25.0) / $20);
  $22 = (($gfxLight) + 52|0);
  HEAPF32[$22>>2] = $21;
  $23 = (($gfxLight) + 16|0);
  HEAPF32[$23>>2] = Math_fround(1.0);
  $24 = (($gfxLight) + 20|0);
  HEAPF32[$24>>2] = Math_fround(0.0);
  $25 = (($gfxLight) + 24|0);
  HEAPF32[$25>>2] = Math_fround(0.0);
  $26 = (($gfxLight) + 28|0);
  HEAPF32[$26>>2] = Math_fround(0.0);
 } else if (!((($8|0) == 3))) {
  $70 = (($this) + 4|0);
  $71 = HEAP32[$70>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(573384,0,573376,327,1,$71,0,0);
 }
 $72 = (($this) + 156|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($this) + 160|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($this) + 164|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($this) + 168|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($gfxLight) + 32|0);
 HEAPF32[$80>>2] = $73;
 $81 = (($gfxLight) + 36|0);
 HEAPF32[$81>>2] = $75;
 $82 = (($gfxLight) + 40|0);
 HEAPF32[$82>>2] = $77;
 $83 = (($gfxLight) + 44|0);
 HEAPF32[$83>>2] = $79;
 $84 = (($this) + 188|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($gfxLight) + 48|0);
 HEAPF32[$86>>2] = $85;
 STACKTOP = sp;return;
}
function __ZN5Light16SetupVertexLightEif($this,$lightNo,$visibilityFade) {
 $this = $this|0;
 $lightNo = $lightNo|0;
 $visibilityFade = Math_fround($visibilityFade);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0);
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 312|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($this) + 248|0);
 if ($2) {
  __ZNK5Light15ComputeGfxLightER14GfxVertexLight($this,$3);
  HEAP8[$0>>0] = 1;
 }
 $4 = (__Z12GetGfxDevicev()|0);
 $5 = (($this) + 156|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 160|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 164|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($6 * $visibilityFade);
 $12 = Math_fround($8 * $visibilityFade);
 $13 = Math_fround($10 * $visibilityFade);
 $14 = (($this) + 280|0);
 HEAPF32[$14>>2] = $11;
 $15 = (($this) + 284|0);
 HEAPF32[$15>>2] = $12;
 $16 = (($this) + 288|0);
 HEAPF32[$16>>2] = $13;
 $17 = (($this) + 292|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = HEAP32[$4>>2]|0;
 $19 = (($18) + 248|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_viii[$20 & 4095]($4,$lightNo,$3);
 STACKTOP = sp;return;
}
function __ZN5Light13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 16|0;
 $1 = sp;
 __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 $2 = $awakeMode & 1;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 28|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   $7 = (($this) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = (__ZNK5Unity10GameObject8IsActiveEv($8)|0);
    if ($10) {
     $11 = HEAP32[$7>>2]|0;
     $12 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($11)|0);
     $13 = (($this) + 40|0);
     __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($0,$12);
     dest=$13+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $14 = (($this) + 104|0);
     __ZNK9Transform11GetPositionEv($1,$12);
     ;HEAP32[$14+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$1+8>>2]|0;
    }
   }
  }
 }
 $15 = (($this) + 312|0);
 HEAP8[$15>>0] = 0;
 __ZN5Light7PrecalcEv($this);
 STACKTOP = sp;return;
}
function __ZNK5Light24GetFinalShadowResolutionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lightShadowResolution$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if (!($2)) {
  $lightShadowResolution$0 = $1;
  STACKTOP = sp;return ($lightShadowResolution$0|0);
 }
 $3 = (__Z18GetQualitySettingsv()|0);
 $4 = (($3) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7) + (($5*96)|0)|0) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $lightShadowResolution$0 = $9;
 STACKTOP = sp;return ($lightShadowResolution$0|0);
}
function __ZNK5Light15IsValidToRenderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 216|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 2)) {
  label = 5;
 } else if ((($1|0) == 0)) {
  $2 = (($this) + 188|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = $3 < Math_fround(0.00100000004749745130539);
  if ($4) {
   $11 = 0;
  } else {
   $5 = (($this) + 192|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = $6 < Math_fround(0.00100000004749745130539);
   if ($7) {
    $11 = 0;
   } else {
    $8 = ($1|0)==(2);
    if ($8) {
     label = 5;
    } else {
     $11 = 1;
    }
   }
  }
 } else {
  $11 = 1;
 }
 if ((label|0) == 5) {
  $9 = (($this) + 188|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $phitmp = !($10 < Math_fround(9.99999993922529029077E-9));
  $11 = $phitmp;
 }
 STACKTOP = sp;return ($11|0);
}
function __Z19RegisterClass_Lightv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(108,97,98,0,99);
 STACKTOP = sp;return;
}
function __ZN5Light13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 HEAP8[$0>>0] = 10;
 $3 = (($0) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[573408+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[573408+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[573408+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[573408+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[573408+4>>0]|0;
 $4 = (($0) + 6|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,108,8,($0|0),316,(2376|0),0,1);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN5Light7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(316,$$byval_copy2,1,16,573376,28)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1684,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(573376|0),28);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK5Light25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 108;
}
function __ZN5Light23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573416,573408,$this,0);
 __ZN5Light8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Light23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,573416,573408,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN5Light8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Light23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Light8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Light23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Light8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Light23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Light8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Light23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 176|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 $12 = (($this) + 172|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 $18 = (FUNCTION_TABLE_iiii[$16 & 2047]($14,$13,$17)|0);
 $19 = HEAP8[$9>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 HEAP32[$12>>2] = $18;
 STACKTOP = sp;return;
}
function __Z19SetLightScissorRectRK5RectTIfES2_bR9GfxDevice($lightRect,$viewPort,$intoRT,$device) {
 $lightRect = $lightRect|0;
 $viewPort = $viewPort|0;
 $intoRT = $intoRT|0;
 $device = $device|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0;
 var $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $rect = 0, $scissorRect = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $rect = sp + 16|0;
 $scissorRect = sp;
 ;HEAP32[$rect+0>>2]=HEAP32[$lightRect+0>>2]|0;HEAP32[$rect+4>>2]=HEAP32[$lightRect+4>>2]|0;HEAP32[$rect+8>>2]=HEAP32[$lightRect+8>>2]|0;HEAP32[$rect+12>>2]=HEAP32[$lightRect+12>>2]|0;
 $0 = (($viewPort) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($viewPort) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(HEAPF32[$rect>>2]);
 $5 = Math_fround($1 * $4);
 HEAPF32[$rect>>2] = $5;
 $6 = (($rect) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($1 * $7);
 HEAPF32[$6>>2] = $8;
 $9 = (($rect) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($3 * $10);
 HEAPF32[$9>>2] = $11;
 $12 = (($rect) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($3 * $13);
 HEAPF32[$12>>2] = $14;
 if (!($intoRT)) {
  $15 = Math_fround(HEAPF32[$viewPort>>2]);
  $16 = (($viewPort) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($15 + $5);
  HEAPF32[$rect>>2] = $18;
  $19 = Math_fround($17 + $11);
  HEAPF32[$9>>2] = $19;
 }
 __Z14RectfToRectIntRK5RectTIfE($scissorRect,$rect);
 __Z22FlipScreenRectIfNeededRK9GfxDeviceR5RectTIiE($device,$scissorRect);
 $20 = HEAP32[$device>>2]|0;
 $21 = (($20) + 180|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vii[$22 & 4095]($device,$scissorRect);
 STACKTOP = sp;return;
}
function __Z16ClearScissorRectbRK5RectTIiER9GfxDevice($oldScissor,$oldRect,$device) {
 $oldScissor = $oldScissor|0;
 $oldRect = $oldRect|0;
 $device = $device|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($oldScissor) {
  $0 = HEAP32[$device>>2]|0;
  $1 = (($0) + 180|0);
  $2 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_vii[$2 & 4095]($device,$oldRect);
  STACKTOP = sp;return;
 } else {
  $3 = HEAP32[$device>>2]|0;
  $4 = (($3) + 184|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($device);
  STACKTOP = sp;return;
 }
}
function __ZN5LightD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((573160 + 8|0));
 __ZN9BehaviourD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5LightD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((573160 + 8|0));
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5Light8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0);
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0);
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 216|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
 }
 $8 = (($this) + 140|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 184|0);
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($11>>>0)<($12>>>0);
 if ($13) {
  $14 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$10>>2] = $14;
  HEAP32[$1>>2] = $11;
  $17 = $11;$19 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$9,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $17 = $$pre;$19 = $$pre8;
 }
 $15 = (($this) + 188|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)<($19>>>0);
 if ($18) {
  $20 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$17>>2] = $20;
  HEAP32[$1>>2] = $16;
  $23 = $16;$25 = $19;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$15,4);
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $23 = $$pre9;$25 = $$pre10;
 }
 $21 = (($this) + 192|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)<($25>>>0);
 if ($24) {
  $26 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$23>>2] = $26;
  HEAP32[$1>>2] = $22;
  $29 = $22;$31 = $25;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$21,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $29 = $$pre11;$31 = $$pre12;
 }
 $27 = (($this) + 196|0);
 $28 = (($29) + 4|0);
 $30 = ($28>>>0)<($31>>>0);
 if ($30) {
  $32 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$29>>2] = $32;
  HEAP32[$1>>2] = $28;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$27,4);
 }
 $33 = (($this) + 116|0);
 __ZN14ShadowSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($33,$transfer);
 $34 = (($this) + 176|0);
 __ZN4PPtrI7TextureE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($34,$transfer);
 $35 = (($this) + 220|0);
 $36 = HEAP32[$1>>2]|0;
 $37 = (($36) + 1|0);
 $38 = HEAP32[$4>>2]|0;
 $39 = ($37>>>0)<($38>>>0);
 if ($39) {
  $40 = HEAP8[$35>>0]|0;
  HEAP8[$36>>0] = $40;
  $41 = HEAP32[$1>>2]|0;
  $42 = (($41) + 1|0);
  HEAP32[$1>>2] = $42;
  $45 = $42;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$35,1);
  $$pre13 = HEAP32[$1>>2]|0;
  $45 = $$pre13;
 }
 $43 = (($this) + 221|0);
 $44 = (($45) + 1|0);
 $46 = HEAP32[$4>>2]|0;
 $47 = ($44>>>0)<($46>>>0);
 if ($47) {
  $48 = HEAP8[$43>>0]|0;
  HEAP8[$45>>0] = $48;
  $49 = HEAP32[$1>>2]|0;
  $50 = (($49) + 1|0);
  HEAP32[$1>>2] = $50;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$43,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $51 = (($this) + 172|0);
 __ZN4PPtrI5FlareE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($51,$transfer);
 $52 = (($this) + 208|0);
 $53 = HEAP32[$1>>2]|0;
 $54 = (($53) + 4|0);
 $55 = HEAP32[$4>>2]|0;
 $56 = ($54>>>0)<($55>>>0);
 if ($56) {
  $57 = HEAP32[$52>>2]|0;
  HEAP32[$53>>2] = $57;
  HEAP32[$1>>2] = $54;
  $60 = $54;$62 = $55;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$52,4);
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $60 = $$pre14;$62 = $$pre15;
 }
 $58 = (($this) + 180|0);
 $59 = (($60) + 4|0);
 $61 = ($59>>>0)<($62>>>0);
 if ($61) {
  $63 = HEAP32[$58>>2]|0;
  HEAP32[$60>>2] = $63;
  HEAP32[$1>>2] = $59;
  $66 = $59;$68 = $62;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$58,4);
  $$pre16 = HEAP32[$1>>2]|0;
  $$pre17 = HEAP32[$4>>2]|0;
  $66 = $$pre16;$68 = $$pre17;
 }
 $64 = (($this) + 212|0);
 $65 = (($66) + 4|0);
 $67 = ($65>>>0)<($68>>>0);
 if ($67) {
  $69 = HEAP32[$64>>2]|0;
  HEAP32[$66>>2] = $69;
  HEAP32[$1>>2] = $65;
  $72 = $65;$74 = $68;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$64,4);
  $$pre18 = HEAP32[$1>>2]|0;
  $$pre19 = HEAP32[$4>>2]|0;
  $72 = $$pre18;$74 = $$pre19;
 }
 $70 = (($this) + 224|0);
 $71 = (($72) + 4|0);
 $73 = ($71>>>0)<($74>>>0);
 if ($73) {
  $75 = Math_fround(HEAPF32[$70>>2]);
  HEAPF32[$72>>2] = $75;
  HEAP32[$1>>2] = $71;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$70,4);
  STACKTOP = sp;return;
 }
}
function __ZN14ShadowSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $11 = $$pre5;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $15 = $$pre6;$17 = $$pre7;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $21 = $$pre8;$23 = $$pre9;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $27 = $$pre10;$29 = $$pre11;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $33 = $$pre12;$35 = $$pre13;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$33>>2] = $36;
  HEAP32[$0>>2] = $32;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,4);
  STACKTOP = sp;return;
 }
}
function __ZN5Light8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i17 = 0, $$pre$i$i$i21 = 0, $$pre$i$i$i25 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i9 = 0, $$pre$phi$i$i$i10Z2D = 0, $$pre$phi$i$i$i15Z2D = 0, $$pre$phi$i$i$i22Z2D = 0, $$pre$phi$i$i$i5Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0;
 var $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 216|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $8 = $$pre$i$i$i1;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 140|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 $11 = (($this) + 184|0);
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$4>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i4 = HEAP32[$11>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre27 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i5Z2D = $11;$18 = $$pre$i$i$i4;$22 = $$pre;$24 = $$pre27;
 } else {
  $16 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$1>>2] = $13;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i5Z2D = $11;$18 = $17;$22 = $13;$24 = $14;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$i5Z2D>>2] = $19;
 $20 = (($this) + 188|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre$i$i$i9 = HEAP32[$20>>2]|0;
  $$pre28 = HEAP32[$1>>2]|0;
  $$pre29 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i10Z2D = $20;$27 = $$pre$i$i$i9;$31 = $$pre28;$33 = $$pre29;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $26 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i10Z2D = $20;$27 = $26;$31 = $21;$33 = $24;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$$pre$phi$i$i$i10Z2D>>2] = $28;
 $29 = (($this) + 192|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$29,4);
  $$pre$i$i$i14 = HEAP32[$29>>2]|0;
  $$pre30 = HEAP32[$1>>2]|0;
  $$pre31 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i15Z2D = $29;$36 = $$pre$i$i$i14;$40 = $$pre30;$42 = $$pre31;
 } else {
  $34 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$29>>2] = $34;
  HEAP32[$1>>2] = $30;
  $35 = (HEAPF32[tempDoublePtr>>2]=$34,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i15Z2D = $29;$36 = $35;$40 = $30;$42 = $33;
 }
 $37 = (_llvm_bswap_i32(($36|0))|0);
 HEAP32[$$pre$phi$i$i$i15Z2D>>2] = $37;
 $38 = (($this) + 196|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)>($42>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
  $$pre$i$i$i21 = HEAP32[$38>>2]|0;
  $$pre$phi$i$i$i22Z2D = $38;$45 = $$pre$i$i$i21;
 } else {
  $43 = Math_fround(HEAPF32[$40>>2]);
  HEAPF32[$38>>2] = $43;
  HEAP32[$1>>2] = $39;
  $44 = (HEAPF32[tempDoublePtr>>2]=$43,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i22Z2D = $38;$45 = $44;
 }
 $46 = (_llvm_bswap_i32(($45|0))|0);
 HEAP32[$$pre$phi$i$i$i22Z2D>>2] = $46;
 $47 = (($this) + 116|0);
 __ZN14ShadowSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($47,$transfer);
 $48 = (($this) + 176|0);
 __ZN4PPtrI7TextureE8TransferI18StreamedBinaryReadILb1EEEEvRT_($48,$transfer);
 $49 = (($this) + 220|0);
 $50 = HEAP32[$1>>2]|0;
 $51 = (($50) + 1|0);
 $52 = HEAP32[$4>>2]|0;
 $53 = ($51>>>0)>($52>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$49,1);
  $$pre32 = HEAP32[$1>>2]|0;
  $59 = $$pre32;
 } else {
  $54 = HEAP8[$50>>0]|0;
  HEAP8[$49>>0] = $54;
  $55 = HEAP32[$1>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$1>>2] = $56;
  $59 = $56;
 }
 $57 = (($this) + 221|0);
 $58 = (($59) + 1|0);
 $60 = HEAP32[$4>>2]|0;
 $61 = ($58>>>0)>($60>>>0);
 if ($61) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$57,1);
 } else {
  $62 = HEAP8[$59>>0]|0;
  HEAP8[$57>>0] = $62;
  $63 = HEAP32[$1>>2]|0;
  $64 = (($63) + 1|0);
  HEAP32[$1>>2] = $64;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $65 = (($this) + 172|0);
 __ZN4PPtrI5FlareE8TransferI18StreamedBinaryReadILb1EEEEvRT_($65,$transfer);
 $66 = (($this) + 208|0);
 $67 = HEAP32[$1>>2]|0;
 $68 = (($67) + 4|0);
 $69 = HEAP32[$4>>2]|0;
 $70 = ($68>>>0)>($69>>>0);
 if ($70) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$66,4);
  $$pre$i$i$i25 = HEAP32[$66>>2]|0;
  $$pre33 = HEAP32[$1>>2]|0;
  $$pre34 = HEAP32[$4>>2]|0;
  $72 = $$pre$i$i$i25;$76 = $$pre33;$78 = $$pre34;
 } else {
  $71 = HEAP32[$67>>2]|0;
  HEAP32[$66>>2] = $71;
  HEAP32[$1>>2] = $68;
  $72 = $71;$76 = $68;$78 = $69;
 }
 $73 = (_llvm_bswap_i32(($72|0))|0);
 HEAP32[$66>>2] = $73;
 $74 = (($this) + 180|0);
 $75 = (($76) + 4|0);
 $77 = ($75>>>0)>($78>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$74,4);
  $$pre$i$i$i$i$i$i = HEAP32[$74>>2]|0;
  $$pre35 = HEAP32[$1>>2]|0;
  $$pre36 = HEAP32[$4>>2]|0;
  $80 = $$pre$i$i$i$i$i$i;$84 = $$pre35;$86 = $$pre36;
 } else {
  $79 = HEAP32[$76>>2]|0;
  HEAP32[$74>>2] = $79;
  HEAP32[$1>>2] = $75;
  $80 = $79;$84 = $75;$86 = $78;
 }
 $81 = (_llvm_bswap_i32(($80|0))|0);
 HEAP32[$74>>2] = $81;
 $82 = (($this) + 212|0);
 $83 = (($84) + 4|0);
 $85 = ($83>>>0)>($86>>>0);
 if ($85) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$82,4);
  $$pre$i$i$i17 = HEAP32[$82>>2]|0;
  $$pre37 = HEAP32[$1>>2]|0;
  $$pre38 = HEAP32[$4>>2]|0;
  $88 = $$pre$i$i$i17;$92 = $$pre37;$94 = $$pre38;
 } else {
  $87 = HEAP32[$84>>2]|0;
  HEAP32[$82>>2] = $87;
  HEAP32[$1>>2] = $83;
  $88 = $87;$92 = $83;$94 = $86;
 }
 $89 = (_llvm_bswap_i32(($88|0))|0);
 HEAP32[$82>>2] = $89;
 $90 = (($this) + 224|0);
 $91 = (($92) + 4|0);
 $93 = ($91>>>0)>($94>>>0);
 if ($93) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$90,4);
  $$pre$i$i$i = HEAP32[$90>>2]|0;
  $$pre$phi$i$i$iZ2D = $90;$97 = $$pre$i$i$i;
  $98 = (_llvm_bswap_i32(($97|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $98;
  STACKTOP = sp;return;
 } else {
  $95 = Math_fround(HEAPF32[$92>>2]);
  HEAPF32[$90>>2] = $95;
  HEAP32[$1>>2] = $91;
  $96 = (HEAPF32[tempDoublePtr>>2]=$95,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $90;$97 = $96;
  $98 = (_llvm_bswap_i32(($97|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $98;
  STACKTOP = sp;return;
 }
}
function __ZN14ShadowSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $$pre$phi$i$i$i12Z2D = 0, $$pre$phi$i$i$i17Z2D = 0, $$pre$phi$i$i$i7Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre19 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre19;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre20 = HEAP32[$0>>2]|0;
  $$pre21 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre20;$21 = $$pre21;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $$pre22 = HEAP32[$0>>2]|0;
  $$pre23 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $17;$24 = $$pre$i$i$i3;$28 = $$pre22;$30 = $$pre23;
 } else {
  $22 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = (HEAPF32[tempDoublePtr>>2]=$22,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $17;$24 = $23;$28 = $18;$30 = $21;
 }
 $25 = (_llvm_bswap_i32(($24|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $25;
 $26 = (($this) + 12|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$26,4);
  $$pre$i$i$i6 = HEAP32[$26>>2]|0;
  $$pre24 = HEAP32[$0>>2]|0;
  $$pre25 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i7Z2D = $26;$33 = $$pre$i$i$i6;$37 = $$pre24;$39 = $$pre25;
 } else {
  $31 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$26>>2] = $31;
  HEAP32[$0>>2] = $27;
  $32 = (HEAPF32[tempDoublePtr>>2]=$31,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i7Z2D = $26;$33 = $32;$37 = $27;$39 = $30;
 }
 $34 = (_llvm_bswap_i32(($33|0))|0);
 HEAP32[$$pre$phi$i$i$i7Z2D>>2] = $34;
 $35 = (($this) + 16|0);
 $36 = (($37) + 4|0);
 $38 = ($36>>>0)>($39>>>0);
 if ($38) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$35,4);
  $$pre$i$i$i11 = HEAP32[$35>>2]|0;
  $$pre26 = HEAP32[$0>>2]|0;
  $$pre27 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i12Z2D = $35;$42 = $$pre$i$i$i11;$46 = $$pre26;$48 = $$pre27;
 } else {
  $40 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$35>>2] = $40;
  HEAP32[$0>>2] = $36;
  $41 = (HEAPF32[tempDoublePtr>>2]=$40,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i12Z2D = $35;$42 = $41;$46 = $36;$48 = $39;
 }
 $43 = (_llvm_bswap_i32(($42|0))|0);
 HEAP32[$$pre$phi$i$i$i12Z2D>>2] = $43;
 $44 = (($this) + 20|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)>($48>>>0);
 if ($47) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$44,4);
  $$pre$i$i$i16 = HEAP32[$44>>2]|0;
  $$pre$phi$i$i$i17Z2D = $44;$51 = $$pre$i$i$i16;
  $52 = (_llvm_bswap_i32(($51|0))|0);
  HEAP32[$$pre$phi$i$i$i17Z2D>>2] = $52;
  STACKTOP = sp;return;
 } else {
  $49 = Math_fround(HEAPF32[$46>>2]);
  HEAPF32[$44>>2] = $49;
  HEAP32[$0>>2] = $45;
  $50 = (HEAPF32[tempDoublePtr>>2]=$49,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i17Z2D = $44;$51 = $50;
  $52 = (_llvm_bswap_i32(($51|0))|0);
  HEAP32[$$pre$phi$i$i$i17Z2D>>2] = $52;
  STACKTOP = sp;return;
 }
}
function __ZN5Light8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0);
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0);
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 216|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
 }
 $8 = (($this) + 140|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 184|0);
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($11>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$9,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $17 = $$pre;$19 = $$pre8;
 } else {
  $14 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$9>>2] = $14;
  HEAP32[$1>>2] = $11;
  $17 = $11;$19 = $12;
 }
 $15 = (($this) + 188|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$15,4);
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $23 = $$pre9;$25 = $$pre10;
 } else {
  $20 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$15>>2] = $20;
  HEAP32[$1>>2] = $16;
  $23 = $16;$25 = $19;
 }
 $21 = (($this) + 192|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$21,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $29 = $$pre11;$31 = $$pre12;
 } else {
  $26 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$21>>2] = $26;
  HEAP32[$1>>2] = $22;
  $29 = $22;$31 = $25;
 }
 $27 = (($this) + 196|0);
 $28 = (($29) + 4|0);
 $30 = ($28>>>0)>($31>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$27,4);
 } else {
  $32 = Math_fround(HEAPF32[$29>>2]);
  HEAPF32[$27>>2] = $32;
  HEAP32[$1>>2] = $28;
 }
 $33 = (($this) + 116|0);
 __ZN14ShadowSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($33,$transfer);
 $34 = (($this) + 176|0);
 __ZN4PPtrI7TextureE8TransferI18StreamedBinaryReadILb0EEEEvRT_($34,$transfer);
 $35 = (($this) + 220|0);
 $36 = HEAP32[$1>>2]|0;
 $37 = (($36) + 1|0);
 $38 = HEAP32[$4>>2]|0;
 $39 = ($37>>>0)>($38>>>0);
 if ($39) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$35,1);
  $$pre13 = HEAP32[$1>>2]|0;
  $45 = $$pre13;
 } else {
  $40 = HEAP8[$36>>0]|0;
  HEAP8[$35>>0] = $40;
  $41 = HEAP32[$1>>2]|0;
  $42 = (($41) + 1|0);
  HEAP32[$1>>2] = $42;
  $45 = $42;
 }
 $43 = (($this) + 221|0);
 $44 = (($45) + 1|0);
 $46 = HEAP32[$4>>2]|0;
 $47 = ($44>>>0)>($46>>>0);
 if ($47) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$43,1);
 } else {
  $48 = HEAP8[$45>>0]|0;
  HEAP8[$43>>0] = $48;
  $49 = HEAP32[$1>>2]|0;
  $50 = (($49) + 1|0);
  HEAP32[$1>>2] = $50;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $51 = (($this) + 172|0);
 __ZN4PPtrI5FlareE8TransferI18StreamedBinaryReadILb0EEEEvRT_($51,$transfer);
 $52 = (($this) + 208|0);
 $53 = HEAP32[$1>>2]|0;
 $54 = (($53) + 4|0);
 $55 = HEAP32[$4>>2]|0;
 $56 = ($54>>>0)>($55>>>0);
 if ($56) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$52,4);
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $60 = $$pre14;$62 = $$pre15;
 } else {
  $57 = HEAP32[$53>>2]|0;
  HEAP32[$52>>2] = $57;
  HEAP32[$1>>2] = $54;
  $60 = $54;$62 = $55;
 }
 $58 = (($this) + 180|0);
 $59 = (($60) + 4|0);
 $61 = ($59>>>0)>($62>>>0);
 if ($61) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$58,4);
  $$pre16 = HEAP32[$1>>2]|0;
  $$pre17 = HEAP32[$4>>2]|0;
  $66 = $$pre16;$68 = $$pre17;
 } else {
  $63 = HEAP32[$60>>2]|0;
  HEAP32[$58>>2] = $63;
  HEAP32[$1>>2] = $59;
  $66 = $59;$68 = $62;
 }
 $64 = (($this) + 212|0);
 $65 = (($66) + 4|0);
 $67 = ($65>>>0)>($68>>>0);
 if ($67) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$64,4);
  $$pre18 = HEAP32[$1>>2]|0;
  $$pre19 = HEAP32[$4>>2]|0;
  $72 = $$pre18;$74 = $$pre19;
 } else {
  $69 = HEAP32[$66>>2]|0;
  HEAP32[$64>>2] = $69;
  HEAP32[$1>>2] = $65;
  $72 = $65;$74 = $68;
 }
 $70 = (($this) + 224|0);
 $71 = (($72) + 4|0);
 $73 = ($71>>>0)>($74>>>0);
 if ($73) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$70,4);
  STACKTOP = sp;return;
 } else {
  $75 = Math_fround(HEAPF32[$72>>2]);
  HEAPF32[$70>>2] = $75;
  HEAP32[$1>>2] = $71;
  STACKTOP = sp;return;
 }
}
function __ZN14ShadowSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $11 = $$pre5;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $15 = $$pre6;$17 = $$pre7;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $21 = $$pre8;$23 = $$pre9;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $27 = $$pre10;$29 = $$pre11;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $33 = $$pre12;$35 = $$pre13;
 } else {
  $30 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$31,4);
  STACKTOP = sp;return;
 } else {
  $36 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$31>>2] = $36;
  HEAP32[$0>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN5Light8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i5 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i10 = sp;
 __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,5);
 $0 = (($this) + 216|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$0,573424,0);
 $1 = (($this) + 140|0);
 $2 = HEAP32[580560>>2]|0;
 $3 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,573432,$2,$converter$i$i10,1)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ($3|0)>(0);
  if ($5) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,573760,0);
   $6 = (($this) + 144|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,573768,0);
   $7 = (($this) + 148|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$7,573776,0);
   $8 = (($this) + 152|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$8,573784,0);
  } else {
   $9 = HEAP32[$converter$i$i10>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 184|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$11,573440,0);
 $12 = (($this) + 188|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,573456,0);
 $13 = (($this) + 192|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,573464,0);
 $14 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,2)|0);
 if ($14) {
  $15 = Math_fround(HEAPF32[$13>>2]);
  $16 = Math_fround($15 * Math_fround(2.0));
  $17 = (($this) + 196|0);
  HEAPF32[$17>>2] = $16;
 } else {
  $18 = (($this) + 196|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$18,573480,0);
 }
 $19 = (($this) + 116|0);
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,573496,573840,$converter$i$i10,1)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = ($20|0)>(0);
  if ($22) {
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$19,573424,0);
   $23 = (($this) + 120|0);
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$23,573688,0);
   $24 = (($this) + 124|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$24,573704,0);
   $25 = (($this) + 128|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$25,573720,0);
   $26 = (($this) + 132|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$26,573728,0);
   $27 = (($this) + 136|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$27,573744,0);
  } else {
   $28 = HEAP32[$converter$i$i10>>2]|0;
   $29 = ($28|0)==(0|0);
   if (!($29)) {
    (FUNCTION_TABLE_iii[$28 & 4095]($19,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $30 = (($this) + 176|0);
 $31 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,573512,573824,$converter$i$i10,1)|0);
 $32 = ($31|0)==(0);
 if (!($32)) {
  $33 = ($31|0)>(0);
  if ($33) {
   __ZN4PPtrI7TextureE8TransferI14SafeBinaryReadEEvRT_($30,$transfer);
  } else {
   $34 = HEAP32[$converter$i$i10>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    (FUNCTION_TABLE_iii[$34 & 4095]($30,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $36 = (($this) + 220|0);
 $37 = HEAP32[580544>>2]|0;
 $38 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,573528,$37,$converter$i$i10,0)|0);
 $39 = ($38|0)==(0);
 if (!($39)) {
  $40 = ($38|0)>(0);
  do {
   if ($40) {
    $41 = (($transfer) + 12|0);
    $42 = (($transfer) + 80|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 12|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($transfer) + 16|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($transfer) + 28|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($transfer) + 32|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = Math_imul($51, $49)|0;
    $$sum$i$i$i$i$i = (($45) - ($52))|0;
    $53 = (($47) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$41>>2] = $53;
    $54 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($54)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $55 = (($47) + ($$sum1$i$i$i$i$i)|0);
     $56 = (($transfer) + 20|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($55>>>0)>($57>>>0);
     if (!($58)) {
      $59 = HEAP8[$53>>0]|0;
      HEAP8[$36>>0] = $59;
      $60 = HEAP32[$41>>2]|0;
      $61 = (($60) + 1|0);
      HEAP32[$41>>2] = $61;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($41,$36,1);
   } else {
    $62 = HEAP32[$converter$i$i10>>2]|0;
    $63 = ($62|0)==(0|0);
    if (!($63)) {
     (FUNCTION_TABLE_iii[$62 & 4095]($36,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $64 = (($this) + 221|0);
 $65 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,573544,$37,$converter$i$i10,0)|0);
 $66 = ($65|0)==(0);
 if (!($66)) {
  $67 = ($65|0)>(0);
  do {
   if ($67) {
    $68 = (($transfer) + 12|0);
    $69 = (($transfer) + 80|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($70) + 12|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($transfer) + 16|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($transfer) + 28|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = (($transfer) + 32|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = Math_imul($78, $76)|0;
    $$sum$i$i$i$i$i5 = (($72) - ($79))|0;
    $80 = (($74) + ($$sum$i$i$i$i$i5)|0);
    HEAP32[$68>>2] = $80;
    $81 = ($$sum$i$i$i$i$i5|0)<(0);
    if (!($81)) {
     $$sum1$i$i$i$i$i6 = (($$sum$i$i$i$i$i5) + 1)|0;
     $82 = (($74) + ($$sum1$i$i$i$i$i6)|0);
     $83 = (($transfer) + 20|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ($82>>>0)>($84>>>0);
     if (!($85)) {
      $86 = HEAP8[$80>>0]|0;
      HEAP8[$64>>0] = $86;
      $87 = HEAP32[$68>>2]|0;
      $88 = (($87) + 1|0);
      HEAP32[$68>>2] = $88;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($68,$64,1);
   } else {
    $89 = HEAP32[$converter$i$i10>>2]|0;
    $90 = ($89|0)==(0|0);
    if (!($90)) {
     (FUNCTION_TABLE_iii[$89 & 4095]($64,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $91 = (($this) + 172|0);
 $92 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,573568,573808,$converter$i$i10,1)|0);
 $93 = ($92|0)==(0);
 if (!($93)) {
  $94 = ($92|0)>(0);
  if ($94) {
   __ZN4PPtrI5FlareE8TransferI14SafeBinaryReadEEvRT_($91,$transfer);
  } else {
   $95 = HEAP32[$converter$i$i10>>2]|0;
   $96 = ($95|0)==(0|0);
   if (!($96)) {
    (FUNCTION_TABLE_iii[$95 & 4095]($91,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $97 = (($this) + 208|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$97,573576,0);
 $98 = (($this) + 180|0);
 $99 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,573592,573792,$converter$i$i10,1)|0);
 $100 = ($99|0)==(0);
 if ($100) {
  $109 = (($this) + 212|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$109,573608,0);
  $110 = (($this) + 224|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$110,573624,0);
  STACKTOP = sp;return;
 }
 $101 = ($99|0)>(0);
 if ($101) {
  __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$98,573648,0);
  $102 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,1)|0);
  if ($102) {
   $103 = HEAP32[$98>>2]|0;
   $104 = $103 & 32;
   $105 = ($104|0)==(0);
   if (!($105)) {
    $106 = $103 | -65536;
    HEAP32[$98>>2] = $106;
   }
  }
 } else {
  $107 = HEAP32[$converter$i$i10>>2]|0;
  $108 = ($107|0)==(0|0);
  if (!($108)) {
   (FUNCTION_TABLE_iii[$107 & 4095]($98,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $109 = (($this) + 212|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$109,573608,0);
 $110 = (($this) + 224|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$110,573624,0);
 STACKTOP = sp;return;
}
function __ZN5Light8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $localIdentifier$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i1 = sp;
 __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,5);
 $0 = (($this) + 216|0);
 $1 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573424,$1,$0,2048);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 140|0);
 $9 = HEAP32[580560>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573432,$9,$8,2048);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($8,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 184|0);
 $11 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573440,$11,$10,0);
 $12 = HEAP32[$2>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$5>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 188|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573456,$11,$16,2048);
 $17 = HEAP32[$2>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$5>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $21 = (($this) + 192|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573464,$11,$21,2048);
 $22 = HEAP32[$2>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$5>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $26 = (($this) + 196|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573480,$11,$26,0);
 $27 = HEAP32[$2>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$5>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $31 = (($this) + 116|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573496,573840,$31,0);
 __ZN14ShadowSettings8TransferI13ProxyTransferEEvRT_($31,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = (($this) + 176|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573512,573824,$32,0);
 $33 = (($localIdentifier$i$i$i1) + 8|0);
 $34 = $33;
 $35 = $34;
 HEAP32[$35>>2] = 0;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573656,$1,$32,1);
 $38 = HEAP32[$2>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$5>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $42 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573672,$42,$33,1);
 $43 = HEAP32[$2>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$5>>2]|0;
 $46 = ((($44) + (($45*24)|0)|0) + 12|0);
 HEAP32[$46>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $47 = (($this) + 220|0);
 $48 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573528,$48,$47,2048);
 $49 = HEAP32[$2>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$5>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $53 = (($this) + 221|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573544,$48,$53,8388609);
 $54 = HEAP32[$2>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$5>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $58 = (($this) + 172|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573568,573808,$58,0);
 $59 = (($localIdentifier$i$i$i1) + 8|0);
 $60 = $59;
 $61 = $60;
 HEAP32[$61>>2] = 0;
 $62 = (($60) + 4)|0;
 $63 = $62;
 HEAP32[$63>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 $64 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573656,$64,$58,1);
 $65 = HEAP32[$2>>2]|0;
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$5>>2]|0;
 $68 = ((($66) + (($67*24)|0)|0) + 12|0);
 HEAP32[$68>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573672,$42,$59,1);
 $69 = HEAP32[$2>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$5>>2]|0;
 $72 = ((($70) + (($71*24)|0)|0) + 12|0);
 HEAP32[$72>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $73 = (($this) + 208|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573576,$64,$73,0);
 $74 = HEAP32[$2>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 $76 = HEAP32[$5>>2]|0;
 $77 = ((($75) + (($76*24)|0)|0) + 12|0);
 HEAP32[$77>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $78 = (($this) + 180|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573592,573792,$78,0);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $79 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573648,$79,$78,4194305);
 $80 = HEAP32[$2>>2]|0;
 $81 = HEAP32[$80>>2]|0;
 $82 = HEAP32[$5>>2]|0;
 $83 = ((($81) + (($82*24)|0)|0) + 12|0);
 HEAP32[$83>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $84 = (($this) + 212|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573608,$64,$84,0);
 $85 = HEAP32[$2>>2]|0;
 $86 = HEAP32[$85>>2]|0;
 $87 = HEAP32[$5>>2]|0;
 $88 = ((($86) + (($87*24)|0)|0) + 12|0);
 HEAP32[$88>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $89 = (($this) + 224|0);
 $90 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573624,$90,$89,0);
 $91 = HEAP32[$2>>2]|0;
 $92 = HEAP32[$91>>2]|0;
 $93 = HEAP32[$5>>2]|0;
 $94 = ((($92) + (($93*24)|0)|0) + 12|0);
 HEAP32[$94>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14ShadowSettings8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573424,$0,$this,2048);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573688,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 $13 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573704,$13,$12,0);
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$4>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573720,$13,$18,0);
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$4>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573728,$13,$23,0);
 $24 = HEAP32[$1>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$4>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,573744,$13,$28,0);
 $29 = HEAP32[$1>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$4>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a2062() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,573128);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[573120>>2] = $1;
 STACKTOP = sp;return;
}
function __Z15CullLocalLightsR8JobFenceS0_RK22SceneCullingParametersRK13dynamic_arrayI8Vector4fLj4EERKS4_IiLj4EER9IndexListSD_RS4_IfLj4EE($fence,$waitForOcclusionBuffer,$cullingParameters,$localLightBSpheres,$isShadowCastingLocalLight,$visibleLocalLightIndices,$offScreenLocalLightIndices,$offScreenLocalLightvisibilityFades) {
 $fence = $fence|0;
 $waitForOcclusionBuffer = $waitForOcclusionBuffer|0;
 $cullingParameters = $cullingParameters|0;
 $localLightBSpheres = $localLightBSpheres|0;
 $isShadowCastingLocalLight = $isShadowCastingLocalLight|0;
 $visibleLocalLightIndices = $visibleLocalLightIndices|0;
 $offScreenLocalLightIndices = $offScreenLocalLightIndices|0;
 $offScreenLocalLightvisibilityFades = $offScreenLocalLightvisibilityFades|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($localLightBSpheres) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[628520>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__Znwj10MemLabelIdbiPKci(284,$$byval_copy,0,16,573856,156)|0);
 HEAP32[$5>>2] = $cullingParameters;
 $6 = HEAP32[$localLightBSpheres>>2]|0;
 $7 = (($5) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$isShadowCastingLocalLight>>2]|0;
 $9 = (($5) + 8|0);
 HEAP32[$9>>2] = $8;
 $10 = (($5) + 12|0);
 HEAP32[$10>>2] = $visibleLocalLightIndices;
 $11 = (($5) + 16|0);
 HEAP32[$11>>2] = $offScreenLocalLightIndices;
 $12 = HEAP32[$offScreenLocalLightvisibilityFades>>2]|0;
 $13 = (($5) + 20|0);
 HEAP32[$13>>2] = $12;
 $14 = (($5) + 24|0);
 $15 = HEAP32[$1>>2]|0;
 $16 = (__Z40ConfigureBlockRangesWithMinIndicesPerJobP10BlockRangeii($14,$15,16)|0);
 $17 = (($5) + 280|0);
 HEAP32[$17>>2] = $16;
 __Z22ScheduleForEachDependsR8JobFencePFvPvjES1_iS0_PFvS1_E11JobPriority($fence,2630,$5,$16,$waitForOcclusionBuffer,3420,0);
 STACKTOP = sp;return;
}
function __ZL38FrustumAndOcculusionCullLocalLightsJobPvj($userData,$index) {
 $userData = $userData|0;
 $index = $index|0;
 var $$pre$i = 0, $$pre5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$03$i = 0, $offScreenLightCount$0$lcssa$i = 0, $offScreenLightCount$01$i = 0, $offScreenLightCount$1$i = 0, $visibleLightCount$0$lcssa$i = 0, $visibleLightCount$02$i = 0, $visibleLightCount$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($userData) + 24|0);
 $1 = (($0) + (($index*12)|0)|0);
 $2 = (($userData) + 216|0);
 $3 = (($2) + ($index<<2)|0);
 $4 = (($userData) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = ((($0) + (($index*12)|0)|0) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6))|0;
 $10 = ($6>>>0)<($9>>>0);
 if ($10) {
  $11 = (($userData) + 16|0);
  $12 = (($userData) + 12|0);
  $13 = HEAP32[$11>>2]|0;
  $14 = HEAP32[$12>>2]|0;
  $15 = (($userData) + 4|0);
  $$pre5$i = HEAP32[$15>>2]|0;
  $17 = $$pre5$i;$i$03$i = $6;$offScreenLightCount$01$i = $6;$visibleLightCount$02$i = $6;
  while(1) {
   $16 = (($17) + ($i$03$i<<4)|0);
   $18 = HEAP32[$userData>>2]|0;
   $19 = (($18) + 28|0);
   $20 = (($18) + 188|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (Math_fround(__Z22PointDistanceToFrustumRK8Vector4fPK5Planei($16,$19,$21)));
   $23 = HEAP32[$15>>2]|0;
   $24 = ((($23) + ($i$03$i<<4)|0) + 12|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = $22 < $25;
   if ($26) {
    $27 = (($visibleLightCount$02$i) + 1)|0;
    $28 = HEAP32[$14>>2]|0;
    $29 = (($28) + ($visibleLightCount$02$i<<2)|0);
    HEAP32[$29>>2] = $i$03$i;
    $offScreenLightCount$1$i = $offScreenLightCount$01$i;$visibleLightCount$1$i = $27;
   } else {
    $30 = Math_fround($25 + $25);
    $31 = $22 < $30;
    if ($31) {
     $32 = HEAP32[$13>>2]|0;
     $33 = (($32) + ($offScreenLightCount$01$i<<2)|0);
     HEAP32[$33>>2] = $i$03$i;
     $34 = Math_fround($22 - $25);
     $35 = Math_fround($34 / $25);
     $36 = Math_fround(Math_fround(1.0) - $35);
     $37 = (($offScreenLightCount$01$i) + 1)|0;
     $38 = (($5) + ($offScreenLightCount$01$i<<2)|0);
     HEAPF32[$38>>2] = $36;
     $offScreenLightCount$1$i = $37;$visibleLightCount$1$i = $visibleLightCount$02$i;
    } else {
     $offScreenLightCount$1$i = $offScreenLightCount$01$i;$visibleLightCount$1$i = $visibleLightCount$02$i;
    }
   }
   $39 = (($i$03$i) + 1)|0;
   $exitcond$i = ($39|0)==($9|0);
   if ($exitcond$i) {
    break;
   } else {
    $17 = $23;$i$03$i = $39;$offScreenLightCount$01$i = $offScreenLightCount$1$i;$visibleLightCount$02$i = $visibleLightCount$1$i;
   }
  }
  $$pre$i = HEAP32[$1>>2]|0;
  $41 = $$pre$i;$offScreenLightCount$0$lcssa$i = $offScreenLightCount$1$i;$visibleLightCount$0$lcssa$i = $visibleLightCount$1$i;
 } else {
  $41 = $6;$offScreenLightCount$0$lcssa$i = $6;$visibleLightCount$0$lcssa$i = $6;
 }
 $40 = (($visibleLightCount$0$lcssa$i) - ($41))|0;
 HEAP32[$7>>2] = $40;
 $42 = (($offScreenLightCount$0$lcssa$i) - ($41))|0;
 HEAP32[$3>>2] = $42;
 $43 = (__Z9GetIUmbrav()|0);
 $44 = ($43|0)==(0|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + 48|0);
 $47 = HEAP32[$46>>2]|0;
 FUNCTION_TABLE_viii[$47 & 4095]($43,$userData,$1);
 STACKTOP = sp;return;
}
function __ZL45FrustumAndOcculusionCullLocalLightsCombineJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond20 = 0, $i$012 = 0, $j$04 = 0, $j1$06 = 0, $offSceenLightCount$0$lcssa = 0, $offSceenLightCount$011 = 0, $offSceenLightCount$1$lcssa = 0, $offSceenLightCount$15 = 0, $visibleLightCount$0$lcssa = 0, $visibleLightCount$013 = 0, $visibleLightCount$1$lcssa = 0;
 var $visibleLightCount$13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($userData) + 12|0);
 $2 = (($userData) + 24|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = (($userData) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($userData) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($userData) + 280|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $offSceenLightCount$0$lcssa = 0;$visibleLightCount$0$lcssa = 0;
  $43 = (($3) + 4|0);
  HEAP32[$43>>2] = $visibleLightCount$0$lcssa;
  $44 = (($5) + 4|0);
  HEAP32[$44>>2] = $offSceenLightCount$0$lcssa;
  $45 = HEAP32[628520>>2]|0;
  HEAP32[$0>>2] = $45;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy);
  STACKTOP = sp;return;
 }
 $11 = (($userData) + 216|0);
 $i$012 = 0;$offSceenLightCount$011 = 0;$visibleLightCount$013 = 0;
 while(1) {
  $12 = (($2) + (($i$012*12)|0)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($2) + (($i$012*12)|0)|0) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + ($13))|0;
  $17 = ($13>>>0)<($16>>>0);
  if ($17) {
   $18 = HEAP32[$3>>2]|0;
   $j$04 = $13;$visibleLightCount$13 = $visibleLightCount$013;
   while(1) {
    $19 = (($18) + ($j$04<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($visibleLightCount$13) + 1)|0;
    $22 = (($18) + ($visibleLightCount$13<<2)|0);
    HEAP32[$22>>2] = $20;
    $23 = (($j$04) + 1)|0;
    $exitcond = ($23|0)==($16|0);
    if ($exitcond) {
     break;
    } else {
     $j$04 = $23;$visibleLightCount$13 = $21;
    }
   }
   $24 = (($visibleLightCount$013) + ($15))|0;
   $$pre = HEAP32[$12>>2]|0;
   $28 = $$pre;$visibleLightCount$1$lcssa = $24;
  } else {
   $28 = $13;$visibleLightCount$1$lcssa = $visibleLightCount$013;
  }
  $25 = (($11) + ($i$012<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + ($28))|0;
  $29 = ($28>>>0)<($27>>>0);
  if ($29) {
   $30 = HEAP32[$5>>2]|0;
   $j1$06 = $28;$offSceenLightCount$15 = $offSceenLightCount$011;
   while(1) {
    $31 = (($30) + ($j1$06<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + ($offSceenLightCount$15<<2)|0);
    HEAP32[$33>>2] = $32;
    $34 = (($7) + ($j1$06<<2)|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = (($offSceenLightCount$15) + 1)|0;
    $37 = (($7) + ($offSceenLightCount$15<<2)|0);
    HEAPF32[$37>>2] = $35;
    $38 = (($j1$06) + 1)|0;
    $exitcond20 = ($38|0)==($27|0);
    if ($exitcond20) {
     break;
    } else {
     $j1$06 = $38;$offSceenLightCount$15 = $36;
    }
   }
   $39 = (($offSceenLightCount$011) + ($26))|0;
   $offSceenLightCount$1$lcssa = $39;
  } else {
   $offSceenLightCount$1$lcssa = $offSceenLightCount$011;
  }
  $40 = (($i$012) + 1)|0;
  $41 = HEAP32[$8>>2]|0;
  $42 = ($40>>>0)<($41>>>0);
  if ($42) {
   $i$012 = $40;$offSceenLightCount$011 = $offSceenLightCount$1$lcssa;$visibleLightCount$013 = $visibleLightCount$1$lcssa;
  } else {
   $offSceenLightCount$0$lcssa = $offSceenLightCount$1$lcssa;$visibleLightCount$0$lcssa = $visibleLightCount$1$lcssa;
   break;
  }
 }
 $43 = (($3) + 4|0);
 HEAP32[$43>>2] = $visibleLightCount$0$lcssa;
 $44 = (($5) + 4|0);
 HEAP32[$44>>2] = $offSceenLightCount$0$lcssa;
 $45 = HEAP32[628520>>2]|0;
 HEAP32[$0>>2] = $45;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z20AddDirectionalLightsPPK5LightjR12ActiveLights($lights,$count,$outLights) {
 $lights = $lights|0;
 $count = $count|0;
 $outLights = $outLights|0;
 var $$$i$i = 0, $$$i$i3 = 0, $$0$i$i = Math_fround(0), $$0$i$i1 = 0, $$0$i$i11 = 0, $$0$i$i2 = 0, $$0$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0;
 var $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bestMainLightIntensity$02$i = Math_fround(0), $bestMainLightIntensity$1$i = Math_fround(0), $exitcond = 0, $exitcond$i = 0, $i$01$i = 0, $i$018 = 0;
 var $mainLightIndex$0$lcssa$i13$ph = 0, $mainLightIndex$03$i = 0, $mainLightIndex$1$i = 0, $phitmp = 0, $phitmp15 = 0, $phitmp16 = 0, $phitmp17 = 0, $pos$i$i$i$i6 = 0, $temp$0$i$i = 0, $temp$0$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i$i6 = sp + 56|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 32|0;
 $3 = (($outLights) + 40|0);
 HEAP8[$3>>0] = 0;
 $4 = ($count|0)==(0);
 if ($4) {
  label = 22;
 } else {
  $bestMainLightIntensity$02$i = Math_fround(0.0);$i$01$i = 0;$mainLightIndex$03$i = -1;
  while(1) {
   $5 = (($lights) + ($i$01$i<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 208|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(2);
   if ($9) {
    $$0$i$i = Math_fround(0.0);
   } else {
    $10 = (($6) + 140|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    $12 = Math_fround($11 * Math_fround(0.300000011920928955078));
    $13 = (($6) + 144|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $15 = Math_fround($14 * Math_fround(0.589999973773956298828));
    $16 = Math_fround($12 + $15);
    $17 = (($6) + 148|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = Math_fround($18 * Math_fround(0.109999999403953552246));
    $20 = Math_fround($16 + $19);
    $21 = (($6) + 184|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = Math_fround($22 * $20);
    $24 = (($6) + 116|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(0);
    if ($26) {
     $$0$i$i = $23;
    } else {
     $27 = Math_fround($23 * Math_fround(16.0));
     $$0$i$i = $27;
    }
   }
   $28 = $$0$i$i > $bestMainLightIntensity$02$i;
   $bestMainLightIntensity$1$i = $28 ? $$0$i$i : $bestMainLightIntensity$02$i;
   $mainLightIndex$1$i = $28 ? $i$01$i : $mainLightIndex$03$i;
   $29 = (($i$01$i) + 1)|0;
   $exitcond$i = ($29|0)==($count|0);
   if ($exitcond$i) {
    break;
   } else {
    $bestMainLightIntensity$02$i = $bestMainLightIntensity$1$i;$i$01$i = $29;$mainLightIndex$03$i = $mainLightIndex$1$i;
   }
  }
  $30 = ($mainLightIndex$1$i|0)==(-1);
  if ($30) {
   label = 22;
  } else {
   $31 = (($lights) + ($mainLightIndex$1$i<<2)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (__ZN13dynamic_arrayI11ActiveLightLj4EE9push_backEv($outLights)|0);
   HEAP32[$33>>2] = $32;
   $34 = (($33) + 8|0);
   HEAP8[$34>>0] = 1;
   $35 = (($33) + 24|0);
   $36 = (($1) + 12|0);
   ;HEAP32[$1+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[616680+8>>2]|0;
   ;HEAP32[$36+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[616664+8>>2]|0;
   ;HEAP32[$35+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$35+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$35+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$35+20>>2]=HEAP32[$1+20>>2]|0;
   $37 = (($32) + 216|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(3);
   if ($39) {
    $$0$i$i4 = 2;
   } else {
    $40 = (($32) + 221|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $$0$i$i4 = 0;
    } else {
     $43 = (($32) + 212|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==(1);
     $$$i$i3 = $45 ? 1 : 2;
     $$0$i$i4 = $$$i$i3;
    }
   }
   $46 = (($33) + 12|0);
   HEAP32[$46>>2] = $$0$i$i4;
   $47 = (($33) + 9|0);
   HEAP8[$47>>0] = 1;
   $48 = (($33) + 48|0);
   HEAPF32[$48>>2] = Math_fround(0.0);
   $49 = (($33) + 52|0);
   HEAPF32[$49>>2] = Math_fround(0.0);
   $50 = (($33) + 56|0);
   HEAPF32[$50>>2] = Math_fround(1.0);
   $51 = (($33) + 60|0);
   HEAPF32[$51>>2] = Math_fround(1.0);
   $52 = (($32) + 180|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($33) + 16|0);
   HEAP32[$54>>2] = $53;
   $55 = (($32) + 176|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==(0);
   if ($57) {
    $$0$i$i11 = 0;
   } else {
    HEAP32[$0>>2] = $56;
    $58 = HEAP32[560624>>2]|0;
    $59 = ($58|0)==(0|0);
    if ($59) {
     label = 19;
    } else {
     $60 = (($58) + 36|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($58) + 4|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($61|0)==($63|0);
     do {
      if ($64) {
       $65 = (($58) + 28|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = (($58) + 32|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = (($66) + ($68<<3)|0);
       $85 = $69;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i6,$58,$0);
       $70 = HEAP32[$pos$i$i$i$i6>>2]|0;
       $71 = ($70|0)==(-1);
       $72 = (($58) + 28|0);
       $73 = HEAP32[$72>>2]|0;
       if ($71) {
        $74 = (($58) + 32|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($73) + ($75<<3)|0);
        $85 = $76;
        break;
       } else {
        $77 = (($73) + ($70<<3)|0);
        $85 = $77;
        break;
       }
      }
     } while(0);
     $78 = HEAP32[560624>>2]|0;
     $79 = (($78) + 28|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (($78) + 32|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = (($80) + ($82<<3)|0);
     $84 = ($85|0)==($83|0);
     if ($84) {
      label = 19;
     } else {
      $86 = (($85) + 4|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = ($87|0)==(0|0);
      if ($88) {
       label = 19;
      } else {
       $temp$0$i$i10 = $87;
      }
     }
    }
    if ((label|0) == 19) {
     $89 = HEAP32[$55>>2]|0;
     $90 = (__Z31ReadObjectFromPersistentManageri($89)|0);
     $temp$0$i$i10 = $90;
    }
    $phitmp = ($temp$0$i$i10|0)!=(0|0);
    $phitmp15 = $phitmp&1;
    $$0$i$i11 = $phitmp15;
   }
   $91 = (($33) + 64|0);
   HEAP8[$91>>0] = $$0$i$i11;
   $92 = (($32) + 208|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($33) + 68|0);
   HEAP32[$94>>2] = $93;
   $95 = HEAP32[$37>>2]|0;
   $96 = (($33) + 72|0);
   HEAP32[$96>>2] = $95;
   $97 = (($33) + 100|0);
   HEAP8[$97>>0] = 0;
   $98 = (($33) + 104|0);
   HEAPF32[$98>>2] = Math_fround(1.0);
   $99 = (($32) + 140|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = Math_fround($100 * Math_fround(0.300000011920928955078));
   $102 = (($32) + 144|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = Math_fround($103 * Math_fround(0.589999973773956298828));
   $105 = Math_fround($101 + $104);
   $106 = (($32) + 148|0);
   $107 = Math_fround(HEAPF32[$106>>2]);
   $108 = Math_fround($107 * Math_fround(0.109999999403953552246));
   $109 = Math_fround($105 + $108);
   $110 = (($32) + 184|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = Math_fround($111 * $109);
   $113 = (($33) + 96|0);
   HEAPF32[$113>>2] = $112;
   $114 = (($outLights) + 16|0);
   HEAP8[$114>>0] = 1;
   $mainLightIndex$0$lcssa$i13$ph = $mainLightIndex$1$i;
  }
 }
 if ((label|0) == 22) {
  $115 = (($outLights) + 16|0);
  HEAP8[$115>>0] = 0;
  $mainLightIndex$0$lcssa$i13$ph = -1;
 }
 if ($4) {
  $204 = (($outLights) + 8|0);
  $205 = HEAP32[$204>>2]|0;
  $206 = (($outLights) + 20|0);
  HEAP32[$206>>2] = $205;
  STACKTOP = sp;return;
 }
 $116 = (($2) + 12|0);
 $i$018 = 0;
 while(1) {
  $117 = (($lights) + ($i$018<<2)|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($118) + 116|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ($120|0)==(0);
  if (!($121)) {
   HEAP8[$3>>0] = 1;
  }
  $122 = ($i$018|0)==($mainLightIndex$0$lcssa$i13$ph|0);
  if (!($122)) {
   $123 = (__ZN13dynamic_arrayI11ActiveLightLj4EE9push_backEv($outLights)|0);
   HEAP32[$123>>2] = $118;
   $124 = (($123) + 8|0);
   HEAP8[$124>>0] = 1;
   $125 = (($123) + 24|0);
   ;HEAP32[$2+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[616680+8>>2]|0;
   ;HEAP32[$116+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$116+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[616664+8>>2]|0;
   ;HEAP32[$125+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$125+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$125+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$125+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$125+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$125+20>>2]=HEAP32[$2+20>>2]|0;
   $126 = (($118) + 216|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)==(3);
   if ($128) {
    $$0$i$i1 = 2;
   } else {
    $129 = (($118) + 221|0);
    $130 = HEAP8[$129>>0]|0;
    $131 = ($130<<24>>24)==(0);
    if ($131) {
     $$0$i$i1 = 0;
    } else {
     $132 = (($118) + 212|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($133|0)==(1);
     $$$i$i = $134 ? 1 : 2;
     $$0$i$i1 = $$$i$i;
    }
   }
   $135 = (($123) + 12|0);
   HEAP32[$135>>2] = $$0$i$i1;
   $136 = (($123) + 9|0);
   HEAP8[$136>>0] = 1;
   $137 = (($123) + 48|0);
   HEAPF32[$137>>2] = Math_fround(0.0);
   $138 = (($123) + 52|0);
   HEAPF32[$138>>2] = Math_fround(0.0);
   $139 = (($123) + 56|0);
   HEAPF32[$139>>2] = Math_fround(1.0);
   $140 = (($123) + 60|0);
   HEAPF32[$140>>2] = Math_fround(1.0);
   $141 = (($118) + 180|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = (($123) + 16|0);
   HEAP32[$143>>2] = $142;
   $144 = (($118) + 176|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = ($145|0)==(0);
   if ($146) {
    $$0$i$i2 = 0;
   } else {
    HEAP32[$1>>2] = $145;
    $147 = HEAP32[560624>>2]|0;
    $148 = ($147|0)==(0|0);
    if ($148) {
     label = 40;
    } else {
     $149 = (($147) + 36|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = (($147) + 4|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = ($150|0)==($152|0);
     do {
      if ($153) {
       $154 = (($147) + 28|0);
       $155 = HEAP32[$154>>2]|0;
       $156 = (($147) + 32|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = (($155) + ($157<<3)|0);
       $174 = $158;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i6,$147,$1);
       $159 = HEAP32[$pos$i$i$i$i6>>2]|0;
       $160 = ($159|0)==(-1);
       $161 = (($147) + 28|0);
       $162 = HEAP32[$161>>2]|0;
       if ($160) {
        $163 = (($147) + 32|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = (($162) + ($164<<3)|0);
        $174 = $165;
        break;
       } else {
        $166 = (($162) + ($159<<3)|0);
        $174 = $166;
        break;
       }
      }
     } while(0);
     $167 = HEAP32[560624>>2]|0;
     $168 = (($167) + 28|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = (($167) + 32|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = (($169) + ($171<<3)|0);
     $173 = ($174|0)==($172|0);
     if ($173) {
      label = 40;
     } else {
      $175 = (($174) + 4|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = ($176|0)==(0|0);
      if ($177) {
       label = 40;
      } else {
       $temp$0$i$i = $176;
      }
     }
    }
    if ((label|0) == 40) {
     label = 0;
     $178 = HEAP32[$144>>2]|0;
     $179 = (__Z31ReadObjectFromPersistentManageri($178)|0);
     $temp$0$i$i = $179;
    }
    $phitmp16 = ($temp$0$i$i|0)!=(0|0);
    $phitmp17 = $phitmp16&1;
    $$0$i$i2 = $phitmp17;
   }
   $180 = (($123) + 64|0);
   HEAP8[$180>>0] = $$0$i$i2;
   $181 = (($118) + 208|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = (($123) + 68|0);
   HEAP32[$183>>2] = $182;
   $184 = HEAP32[$126>>2]|0;
   $185 = (($123) + 72|0);
   HEAP32[$185>>2] = $184;
   $186 = (($123) + 100|0);
   HEAP8[$186>>0] = 0;
   $187 = (($123) + 104|0);
   HEAPF32[$187>>2] = Math_fround(1.0);
   $188 = (($118) + 140|0);
   $189 = Math_fround(HEAPF32[$188>>2]);
   $190 = Math_fround($189 * Math_fround(0.300000011920928955078));
   $191 = (($118) + 144|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = Math_fround($192 * Math_fround(0.589999973773956298828));
   $194 = Math_fround($190 + $193);
   $195 = (($118) + 148|0);
   $196 = Math_fround(HEAPF32[$195>>2]);
   $197 = Math_fround($196 * Math_fround(0.109999999403953552246));
   $198 = Math_fround($194 + $197);
   $199 = (($118) + 184|0);
   $200 = Math_fround(HEAPF32[$199>>2]);
   $201 = Math_fround($200 * $198);
   $202 = (($123) + 96|0);
   HEAPF32[$202>>2] = $201;
  }
  $203 = (($i$018) + 1)|0;
  $exitcond = ($203|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$018 = $203;
  }
 }
 $204 = (($outLights) + 8|0);
 $205 = HEAP32[$204>>2]|0;
 $206 = (($outLights) + 20|0);
 HEAP32[$206>>2] = $205;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI11ActiveLightLj4EE9push_backEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 do {
  if ($7) {
   $8 = $5 << 1;
   $9 = ($8|0)==(0);
   $10 = $9 ? 1 : $8;
   $11 = ($6>>>0)<($10>>>0);
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*108)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,573856,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*108)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,573856,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*108)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($25) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($26*108)|0)|0);
 STACKTOP = sp;return ($28|0);
}
function __Z26CalculateLightScreenBoundsRK14ShadowCullDataRK5LightRK10Matrix4x4fR5RectTIfE($cullData,$light,$lightMatrix,$outRect) {
 $cullData = $cullData|0;
 $light = $light|0;
 $lightMatrix = $lightMatrix|0;
 $outRect = $outRect|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aabb = 0, $hullCounts = 0, $hullFaces$0 = 0;
 var $hullPoints = 0, $nearPlane = 0, $spotBounds = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $hullCounts = sp + 424|0;
 $hullPoints = sp;
 $spotBounds = sp + 288|0;
 $nearPlane = sp + 384|0;
 $aabb = sp + 400|0;
 $0 = (($lightMatrix) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($lightMatrix) + 52|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($lightMatrix) + 56|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($hullPoints) + 16|0);
 ;HEAP32[$hullPoints+0>>2]=0|0;HEAP32[$hullPoints+4>>2]=0|0;HEAP32[$hullPoints+8>>2]=0|0;HEAP32[$hullPoints+12>>2]=0|0;
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($hullPoints) + 20|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($hullPoints) + 24|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($hullPoints) + 28|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($hullPoints) + 32|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($hullPoints) + 36|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($hullPoints) + 40|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($hullPoints) + 44|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($hullPoints) + 48|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($hullPoints) + 52|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($hullPoints) + 56|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($hullPoints) + 60|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($hullPoints) + 64|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($hullPoints) + 68|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($hullPoints) + 72|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($hullPoints) + 76|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($hullPoints) + 80|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($hullPoints) + 84|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($hullPoints) + 88|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($hullPoints) + 92|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($hullPoints) + 96|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($hullPoints) + 100|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($hullPoints) + 104|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($hullPoints) + 108|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($hullPoints) + 112|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($hullPoints) + 116|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($hullPoints) + 120|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($hullPoints) + 124|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($hullPoints) + 128|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($hullPoints) + 132|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($hullPoints) + 136|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($hullPoints) + 140|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($hullPoints) + 144|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($hullPoints) + 148|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($hullPoints) + 152|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($hullPoints) + 156|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($hullPoints) + 160|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($hullPoints) + 164|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($hullPoints) + 168|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($hullPoints) + 172|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($hullPoints) + 176|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($hullPoints) + 180|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($hullPoints) + 184|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($hullPoints) + 188|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($hullPoints) + 192|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($hullPoints) + 196|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($hullPoints) + 200|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($hullPoints) + 204|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($hullPoints) + 208|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($hullPoints) + 212|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($hullPoints) + 216|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($hullPoints) + 220|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($hullPoints) + 224|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($hullPoints) + 228|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($hullPoints) + 232|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($hullPoints) + 236|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (($hullPoints) + 240|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($hullPoints) + 244|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($hullPoints) + 248|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = (($hullPoints) + 252|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 $66 = (($hullPoints) + 256|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($hullPoints) + 260|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($hullPoints) + 264|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($hullPoints) + 268|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 $70 = (($hullPoints) + 272|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($hullPoints) + 276|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($hullPoints) + 280|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($hullPoints) + 284|0);
 HEAPF32[$73>>2] = Math_fround(0.0);
 $74 = (($light) + 216|0);
 $75 = HEAP32[$74>>2]|0;
 if ((($75|0) == 2)) {
  $100 = (($light) + 188|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  ;HEAP32[$spotBounds+0>>2]=0|0;HEAP32[$spotBounds+4>>2]=0|0;HEAP32[$spotBounds+8>>2]=0|0;
  $102 = Math_fround($1 - $101);
  $103 = Math_fround($3 - $101);
  $104 = Math_fround($5 - $101);
  HEAPF32[$spotBounds>>2] = $102;
  $105 = (($spotBounds) + 4|0);
  HEAPF32[$105>>2] = $103;
  $106 = (($spotBounds) + 8|0);
  HEAPF32[$106>>2] = $104;
  $107 = (($spotBounds) + 12|0);
  $108 = Math_fround($1 + $101);
  HEAPF32[$107>>2] = $108;
  $109 = (($spotBounds) + 16|0);
  HEAPF32[$109>>2] = $103;
  $110 = (($spotBounds) + 20|0);
  HEAPF32[$110>>2] = $104;
  $111 = (($spotBounds) + 24|0);
  $112 = Math_fround($3 + $101);
  HEAPF32[$111>>2] = $108;
  $113 = (($spotBounds) + 28|0);
  HEAPF32[$113>>2] = $112;
  $114 = (($spotBounds) + 32|0);
  HEAPF32[$114>>2] = $104;
  $115 = (($spotBounds) + 36|0);
  HEAPF32[$115>>2] = $102;
  $116 = (($spotBounds) + 40|0);
  HEAPF32[$116>>2] = $112;
  $117 = (($spotBounds) + 44|0);
  HEAPF32[$117>>2] = $104;
  $118 = (($spotBounds) + 48|0);
  $119 = Math_fround($5 + $101);
  HEAPF32[$118>>2] = $102;
  $120 = (($spotBounds) + 52|0);
  HEAPF32[$120>>2] = $103;
  $121 = (($spotBounds) + 56|0);
  HEAPF32[$121>>2] = $119;
  $122 = (($spotBounds) + 60|0);
  HEAPF32[$122>>2] = $108;
  $123 = (($spotBounds) + 64|0);
  HEAPF32[$123>>2] = $103;
  $124 = (($spotBounds) + 68|0);
  HEAPF32[$124>>2] = $119;
  $125 = (($spotBounds) + 72|0);
  HEAPF32[$125>>2] = $108;
  $126 = (($spotBounds) + 76|0);
  HEAPF32[$126>>2] = $112;
  $127 = (($spotBounds) + 80|0);
  HEAPF32[$127>>2] = $119;
  $128 = (($spotBounds) + 84|0);
  HEAPF32[$128>>2] = $102;
  $129 = (($spotBounds) + 88|0);
  HEAPF32[$129>>2] = $112;
  $130 = (($spotBounds) + 92|0);
  HEAPF32[$130>>2] = $119;
  ;HEAP8[$hullCounts+0>>0]=4|0;HEAP8[$hullCounts+1>>0]=4|0;HEAP8[$hullCounts+2>>0]=4|0;HEAP8[$hullCounts+3>>0]=4|0;HEAP8[$hullCounts+4>>0]=4|0;HEAP8[$hullCounts+5>>0]=4|0;
  ;HEAP32[$hullPoints+0>>2]=HEAP32[$spotBounds+0>>2]|0;HEAP32[$hullPoints+4>>2]=HEAP32[$spotBounds+4>>2]|0;HEAP32[$hullPoints+8>>2]=HEAP32[$spotBounds+8>>2]|0;
  $131 = (($hullPoints) + 12|0);
  ;HEAP32[$131+0>>2]=HEAP32[$107+0>>2]|0;HEAP32[$131+4>>2]=HEAP32[$107+4>>2]|0;HEAP32[$131+8>>2]=HEAP32[$107+8>>2]|0;
  $132 = (($hullPoints) + 24|0);
  ;HEAP32[$132+0>>2]=HEAP32[$111+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$111+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$111+8>>2]|0;
  $133 = (($hullPoints) + 36|0);
  ;HEAP32[$133+0>>2]=HEAP32[$115+0>>2]|0;HEAP32[$133+4>>2]=HEAP32[$115+4>>2]|0;HEAP32[$133+8>>2]=HEAP32[$115+8>>2]|0;
  $134 = (($hullPoints) + 48|0);
  ;HEAP32[$134+0>>2]=HEAP32[$128+0>>2]|0;HEAP32[$134+4>>2]=HEAP32[$128+4>>2]|0;HEAP32[$134+8>>2]=HEAP32[$128+8>>2]|0;
  $135 = (($hullPoints) + 60|0);
  ;HEAP32[$135+0>>2]=HEAP32[$125+0>>2]|0;HEAP32[$135+4>>2]=HEAP32[$125+4>>2]|0;HEAP32[$135+8>>2]=HEAP32[$125+8>>2]|0;
  $136 = (($hullPoints) + 72|0);
  ;HEAP32[$136+0>>2]=HEAP32[$122+0>>2]|0;HEAP32[$136+4>>2]=HEAP32[$122+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$122+8>>2]|0;
  $137 = (($hullPoints) + 84|0);
  ;HEAP32[$137+0>>2]=HEAP32[$118+0>>2]|0;HEAP32[$137+4>>2]=HEAP32[$118+4>>2]|0;HEAP32[$137+8>>2]=HEAP32[$118+8>>2]|0;
  $138 = (($hullPoints) + 96|0);
  ;HEAP32[$138+0>>2]=HEAP32[$spotBounds+0>>2]|0;HEAP32[$138+4>>2]=HEAP32[$spotBounds+4>>2]|0;HEAP32[$138+8>>2]=HEAP32[$spotBounds+8>>2]|0;
  $139 = (($hullPoints) + 108|0);
  ;HEAP32[$139+0>>2]=HEAP32[$115+0>>2]|0;HEAP32[$139+4>>2]=HEAP32[$115+4>>2]|0;HEAP32[$139+8>>2]=HEAP32[$115+8>>2]|0;
  $140 = (($hullPoints) + 120|0);
  ;HEAP32[$140+0>>2]=HEAP32[$128+0>>2]|0;HEAP32[$140+4>>2]=HEAP32[$128+4>>2]|0;HEAP32[$140+8>>2]=HEAP32[$128+8>>2]|0;
  $141 = (($hullPoints) + 132|0);
  ;HEAP32[$141+0>>2]=HEAP32[$118+0>>2]|0;HEAP32[$141+4>>2]=HEAP32[$118+4>>2]|0;HEAP32[$141+8>>2]=HEAP32[$118+8>>2]|0;
  $142 = (($hullPoints) + 144|0);
  ;HEAP32[$142+0>>2]=HEAP32[$107+0>>2]|0;HEAP32[$142+4>>2]=HEAP32[$107+4>>2]|0;HEAP32[$142+8>>2]=HEAP32[$107+8>>2]|0;
  $143 = (($hullPoints) + 156|0);
  ;HEAP32[$143+0>>2]=HEAP32[$122+0>>2]|0;HEAP32[$143+4>>2]=HEAP32[$122+4>>2]|0;HEAP32[$143+8>>2]=HEAP32[$122+8>>2]|0;
  $144 = (($hullPoints) + 168|0);
  ;HEAP32[$144+0>>2]=HEAP32[$125+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$125+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$125+8>>2]|0;
  $145 = (($hullPoints) + 180|0);
  ;HEAP32[$145+0>>2]=HEAP32[$111+0>>2]|0;HEAP32[$145+4>>2]=HEAP32[$111+4>>2]|0;HEAP32[$145+8>>2]=HEAP32[$111+8>>2]|0;
  $146 = (($hullPoints) + 192|0);
  ;HEAP32[$146+0>>2]=HEAP32[$118+0>>2]|0;HEAP32[$146+4>>2]=HEAP32[$118+4>>2]|0;HEAP32[$146+8>>2]=HEAP32[$118+8>>2]|0;
  $147 = (($hullPoints) + 204|0);
  ;HEAP32[$147+0>>2]=HEAP32[$122+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$122+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$122+8>>2]|0;
  $148 = (($hullPoints) + 216|0);
  ;HEAP32[$148+0>>2]=HEAP32[$107+0>>2]|0;HEAP32[$148+4>>2]=HEAP32[$107+4>>2]|0;HEAP32[$148+8>>2]=HEAP32[$107+8>>2]|0;
  $149 = (($hullPoints) + 228|0);
  ;HEAP32[$149+0>>2]=HEAP32[$spotBounds+0>>2]|0;HEAP32[$149+4>>2]=HEAP32[$spotBounds+4>>2]|0;HEAP32[$149+8>>2]=HEAP32[$spotBounds+8>>2]|0;
  $150 = (($hullPoints) + 240|0);
  ;HEAP32[$150+0>>2]=HEAP32[$125+0>>2]|0;HEAP32[$150+4>>2]=HEAP32[$125+4>>2]|0;HEAP32[$150+8>>2]=HEAP32[$125+8>>2]|0;
  $151 = (($hullPoints) + 252|0);
  ;HEAP32[$151+0>>2]=HEAP32[$128+0>>2]|0;HEAP32[$151+4>>2]=HEAP32[$128+4>>2]|0;HEAP32[$151+8>>2]=HEAP32[$128+8>>2]|0;
  $152 = (($hullPoints) + 264|0);
  ;HEAP32[$152+0>>2]=HEAP32[$115+0>>2]|0;HEAP32[$152+4>>2]=HEAP32[$115+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$115+8>>2]|0;
  $153 = (($hullPoints) + 276|0);
  ;HEAP32[$153+0>>2]=HEAP32[$111+0>>2]|0;HEAP32[$153+4>>2]=HEAP32[$111+4>>2]|0;HEAP32[$153+8>>2]=HEAP32[$111+8>>2]|0;
  $$pre$phiZ2D = $hullCounts;$hullFaces$0 = 6;
 } else if ((($75|0) == 0)) {
  dest=$spotBounds+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $76 = (($light) + 188|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = (($light) + 200|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  __Z24CalculateSpotLightBoundsffRK10Matrix4x4fR15SpotLightBounds($77,$79,$lightMatrix,$spotBounds);
  HEAP8[$hullCounts>>0] = 4;
  $80 = (($hullCounts) + 1|0);
  $81 = (($spotBounds) + 48|0);
  HEAP8[$80>>0]=50529027&255;HEAP8[$80+1>>0]=(50529027>>8)&255;HEAP8[$80+2>>0]=(50529027>>16)&255;HEAP8[$80+3>>0]=50529027>>24;
  ;HEAP32[$hullPoints+0>>2]=HEAP32[$81+0>>2]|0;HEAP32[$hullPoints+4>>2]=HEAP32[$81+4>>2]|0;HEAP32[$hullPoints+8>>2]=HEAP32[$81+8>>2]|0;
  $82 = (($hullPoints) + 12|0);
  $83 = (($spotBounds) + 36|0);
  ;HEAP32[$82+0>>2]=HEAP32[$83+0>>2]|0;HEAP32[$82+4>>2]=HEAP32[$83+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$83+8>>2]|0;
  $84 = (($hullPoints) + 24|0);
  $85 = (($spotBounds) + 24|0);
  ;HEAP32[$84+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$85+8>>2]|0;
  $86 = (($hullPoints) + 36|0);
  $87 = (($spotBounds) + 12|0);
  ;HEAP32[$86+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$86+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$86+8>>2]=HEAP32[$87+8>>2]|0;
  $88 = (($hullPoints) + 48|0);
  ;HEAP32[$88+0>>2]=HEAP32[$spotBounds+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$spotBounds+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$spotBounds+8>>2]|0;
  $89 = (($hullPoints) + 60|0);
  ;HEAP32[$89+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$87+8>>2]|0;
  $90 = (($hullPoints) + 72|0);
  ;HEAP32[$90+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$85+8>>2]|0;
  $91 = (($hullPoints) + 84|0);
  ;HEAP32[$91+0>>2]=HEAP32[$spotBounds+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$spotBounds+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$spotBounds+8>>2]|0;
  $92 = (($hullPoints) + 96|0);
  ;HEAP32[$92+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$85+8>>2]|0;
  $93 = (($hullPoints) + 108|0);
  ;HEAP32[$93+0>>2]=HEAP32[$83+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$83+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$83+8>>2]|0;
  $94 = (($hullPoints) + 120|0);
  ;HEAP32[$94+0>>2]=HEAP32[$spotBounds+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$spotBounds+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$spotBounds+8>>2]|0;
  $95 = (($hullPoints) + 132|0);
  ;HEAP32[$95+0>>2]=HEAP32[$83+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$83+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$83+8>>2]|0;
  $96 = (($hullPoints) + 144|0);
  ;HEAP32[$96+0>>2]=HEAP32[$81+0>>2]|0;HEAP32[$96+4>>2]=HEAP32[$81+4>>2]|0;HEAP32[$96+8>>2]=HEAP32[$81+8>>2]|0;
  $97 = (($hullPoints) + 156|0);
  ;HEAP32[$97+0>>2]=HEAP32[$spotBounds+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$spotBounds+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$spotBounds+8>>2]|0;
  $98 = (($hullPoints) + 168|0);
  ;HEAP32[$98+0>>2]=HEAP32[$81+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$81+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$81+8>>2]|0;
  $99 = (($hullPoints) + 180|0);
  ;HEAP32[$99+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$87+8>>2]|0;
  $$pre$phiZ2D = $hullCounts;$hullFaces$0 = 5;
 } else {
  $$pre$phiZ2D = $hullCounts;$hullFaces$0 = 0;
 }
 HEAPF32[$nearPlane>>2] = Math_fround(0.0);
 $154 = (($nearPlane) + 4|0);
 HEAPF32[$154>>2] = Math_fround(0.0);
 $155 = (($nearPlane) + 8|0);
 HEAPF32[$155>>2] = Math_fround(0.0);
 $156 = (($cullData) + 208|0);
 $157 = (($cullData) + 584|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround(HEAPF32[$156>>2]);
 $160 = Math_fround($158 * $159);
 $161 = (($cullData) + 212|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = Math_fround($158 * $162);
 $164 = (($cullData) + 216|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = Math_fround($158 * $165);
 $167 = (($cullData) + 196|0);
 $168 = Math_fround(HEAPF32[$167>>2]);
 $169 = Math_fround($160 + $168);
 $170 = (($cullData) + 200|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = Math_fround($163 + $171);
 $173 = (($cullData) + 204|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = Math_fround($166 + $174);
 ;HEAP32[$nearPlane+0>>2]=HEAP32[$156+0>>2]|0;HEAP32[$nearPlane+4>>2]=HEAP32[$156+4>>2]|0;HEAP32[$nearPlane+8>>2]=HEAP32[$156+8>>2]|0;
 $176 = Math_fround($169 * $159);
 $177 = Math_fround($172 * $162);
 $178 = Math_fround($176 + $177);
 $179 = Math_fround($175 * $165);
 $180 = Math_fround($178 + $179);
 $181 = Math_fround(-$180);
 $182 = (($nearPlane) + 12|0);
 $183 = $180 > Math_fround(-0.0);
 $184 = $183 ? $180 : $181;
 $185 = Math_fround($184 * Math_fround(9.99999974737875163555E-5));
 $186 = Math_fround($181 - $185);
 HEAPF32[$182>>2] = $186;
 $187 = (($aabb) + 12|0);
 $188 = (($aabb) + 16|0);
 $189 = (($aabb) + 20|0);
 ;HEAP32[$aabb+0>>2]=0|0;HEAP32[$aabb+4>>2]=0|0;HEAP32[$aabb+8>>2]=0|0;HEAP32[$aabb+12>>2]=0|0;HEAP32[$aabb+16>>2]=0|0;
 ;HEAP32[$aabb+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$aabb+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$aabb+8>>2]=HEAP32[616664+8>>2]|0;
 $190 = Math_fround(HEAPF32[616664>>2]);
 $191 = Math_fround(-$190);
 $192 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $193 = Math_fround(-$192);
 $194 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $195 = Math_fround(-$194);
 HEAPF32[$187>>2] = $191;
 HEAPF32[$188>>2] = $193;
 HEAPF32[$189>>2] = $195;
 $196 = (($cullData) + 132|0);
 __Z14CalcHullBoundsPK8Vector3fPKhhRK5PlaneRK10Matrix4x4fR10MinMaxAABB($hullPoints,$$pre$phiZ2D,$hullFaces$0,$nearPlane,$196,$aabb);
 $197 = Math_fround(HEAPF32[$aabb>>2]);
 $198 = Math_fround($197 + Math_fround(1.0));
 $199 = Math_fround($198 * Math_fround(0.5));
 $200 = (($aabb) + 4|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = Math_fround($201 + Math_fround(1.0));
 $203 = Math_fround($202 * Math_fround(0.5));
 $204 = Math_fround(HEAPF32[$187>>2]);
 $205 = Math_fround($204 - $197);
 $206 = Math_fround($205 * Math_fround(0.5));
 $207 = Math_fround(HEAPF32[$188>>2]);
 $208 = Math_fround($207 - $201);
 $209 = Math_fround($208 * Math_fround(0.5));
 HEAPF32[$outRect>>2] = $199;
 $210 = (($outRect) + 8|0);
 HEAPF32[$210>>2] = $206;
 $211 = (($outRect) + 4|0);
 HEAPF32[$211>>2] = $203;
 $212 = (($outRect) + 12|0);
 HEAPF32[$212>>2] = $209;
 $213 = $204 > $197;
 if ($213) {
  $215 = 1;
  STACKTOP = sp;return ($215|0);
 }
 $214 = $207 > $201;
 $215 = $214;
 STACKTOP = sp;return ($215|0);
}
function __Z20AddActiveLocalLightsRK27LocalLightCullingParametersRK14ShadowCullDataPK8Vector4fPPK5LightRK9IndexListPfRSC_R12ActiveLights($params,$shadowCullData,$lightBSpheres,$lights,$visibleLocalLights,$visibilityFades,$offScreenLocalLights,$outLights) {
 $params = $params|0;
 $shadowCullData = $shadowCullData|0;
 $lightBSpheres = $lightBSpheres|0;
 $lights = $lights|0;
 $visibleLocalLights = $visibleLocalLights|0;
 $visibilityFades = $visibilityFades|0;
 $offScreenLocalLights = $offScreenLocalLights|0;
 $outLights = $outLights|0;
 var $$byval_copy5 = 0, $$byval_copy6 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$1 = 0, $i$05 = 0, $i$05$1 = 0, $i2$02$us = 0, $i2$02$us$1 = 0, $lightCount = 0, $lightMatrix = 0, $lightMatrix6 = 0, $lightScreenRect = 0, $offScreenLightCount$1$lcssa$1 = 0, $offScreenLightCount$1$lcssa13 = 0;
 var $offScreenLightCount$16 = 0, $offScreenLightCount$16$1 = 0, $offScreenLightCount$3 = 0, $offScreenLightCount$3$1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $$byval_copy6 = sp + 360|0;
 $$byval_copy5 = sp + 296|0;
 $lightCount = sp;
 $lightMatrix = sp + 232|0;
 $lightScreenRect = sp + 136|0;
 $0 = sp + 152|0;
 $lightMatrix6 = sp + 72|0;
 $1 = sp + 8|0;
 $2 = sp + 216|0;
 $3 = (($offScreenLocalLights) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $lightCount;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($visibleLocalLights) + 4|0);
 $10 = (($lightScreenRect) + 8|0);
 $11 = (($lightScreenRect) + 12|0);
 $12 = HEAP32[$9>>2]|0;
 $13 = ($12|0)>(0);
 if ($13) {
  $35 = 0;$i$05 = 0;$offScreenLightCount$16 = $4;
  while(1) {
   $14 = HEAP32[$visibleLocalLights>>2]|0;
   $15 = (($14) + ($i$05<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($lights) + ($16<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 216|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   do {
    if ($21) {
     $22 = (($18) + 24|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($23)|0);
     __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($lightMatrix,$24);
     ;HEAP32[$lightScreenRect+0>>2]=0|0;HEAP32[$lightScreenRect+4>>2]=0|0;HEAP32[$lightScreenRect+8>>2]=0|0;HEAP32[$lightScreenRect+12>>2]=0|0;
     $25 = HEAP32[$17>>2]|0;
     $26 = (__Z26CalculateLightScreenBoundsRK14ShadowCullDataRK5LightRK10Matrix4x4fR5RectTIfE($shadowCullData,$25,$lightMatrix,$lightScreenRect)|0);
     if (!($26)) {
      $36 = (($visibilityFades) + ($offScreenLightCount$16<<2)|0);
      HEAPF32[$36>>2] = Math_fround(1.0);
      $37 = (($offScreenLightCount$16) + 1)|0;
      $38 = HEAP32[$offScreenLocalLights>>2]|0;
      $39 = (($38) + ($offScreenLightCount$16<<2)|0);
      HEAP32[$39>>2] = $16;
      $120 = $35;$offScreenLightCount$3 = $37;
      break;
     }
     $27 = Math_fround(HEAPF32[$10>>2]);
     $28 = !($27 <= Math_fround(9.99999974737875163555E-6));
     if ($28) {
      $29 = Math_fround(HEAPF32[$11>>2]);
      $30 = !($29 <= Math_fround(9.99999974737875163555E-6));
      if ($30) {
       $31 = HEAP32[$17>>2]|0;
       dest=$0+0|0; src=$lightMatrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $32 = (($lightBSpheres) + ($16<<4)|0);
       $33 = (__ZN13dynamic_arrayI11ActiveLightLj4EE9push_backEv($outLights)|0);
       dest=$$byval_copy5+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$lightScreenRect+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$lightScreenRect+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$lightScreenRect+8>>2]|0;HEAP32[$$byval_copy6+12>>2]=HEAP32[$lightScreenRect+12>>2]|0;
       __ZL21SetupActiveLocalLightRK27LocalLightCullingParametersRK14ShadowCullDataRK5Light10Matrix4x4fRK8Vector4f5RectTIfEbfiR11ActiveLight($params,$shadowCullData,$31,$$byval_copy5,$32,$$byval_copy6,1,Math_fround(1.0),$16,$33);
       $34 = (($35) + 1)|0;
       HEAP32[$lightCount>>2] = $34;
       $120 = $34;$offScreenLightCount$3 = $offScreenLightCount$16;
      } else {
       $120 = $35;$offScreenLightCount$3 = $offScreenLightCount$16;
      }
     } else {
      $120 = $35;$offScreenLightCount$3 = $offScreenLightCount$16;
     }
    } else {
     $120 = $35;$offScreenLightCount$3 = $offScreenLightCount$16;
    }
   } while(0);
   $40 = (($i$05) + 1)|0;
   $41 = HEAP32[$9>>2]|0;
   $42 = ($40|0)<($41|0);
   if ($42) {
    $35 = $120;$i$05 = $40;$offScreenLightCount$16 = $offScreenLightCount$3;
   } else {
    break;
   }
  }
  $43 = ($41|0)>(0);
  if ($43) {
   $66 = (($lightCount) + 4|0);
   $92 = 0;$i$05$1 = 0;$offScreenLightCount$16$1 = $offScreenLightCount$3;
   while(1) {
    $67 = HEAP32[$visibleLocalLights>>2]|0;
    $68 = (($67) + ($i$05$1<<2)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($lights) + ($69<<2)|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($71) + 216|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73|0)==(2);
    do {
     if ($74) {
      $75 = (($71) + 24|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($76)|0);
      __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($lightMatrix,$77);
      ;HEAP32[$lightScreenRect+0>>2]=0|0;HEAP32[$lightScreenRect+4>>2]=0|0;HEAP32[$lightScreenRect+8>>2]=0|0;HEAP32[$lightScreenRect+12>>2]=0|0;
      $78 = HEAP32[$70>>2]|0;
      $79 = (__Z26CalculateLightScreenBoundsRK14ShadowCullDataRK5LightRK10Matrix4x4fR5RectTIfE($shadowCullData,$78,$lightMatrix,$lightScreenRect)|0);
      if (!($79)) {
       $80 = (($visibilityFades) + ($offScreenLightCount$16$1<<2)|0);
       HEAPF32[$80>>2] = Math_fround(1.0);
       $81 = (($offScreenLightCount$16$1) + 1)|0;
       $82 = HEAP32[$offScreenLocalLights>>2]|0;
       $83 = (($82) + ($offScreenLightCount$16$1<<2)|0);
       HEAP32[$83>>2] = $69;
       $122 = $92;$offScreenLightCount$3$1 = $81;
       break;
      }
      $84 = Math_fround(HEAPF32[$10>>2]);
      $85 = !($84 <= Math_fround(9.99999974737875163555E-6));
      if ($85) {
       $86 = Math_fround(HEAPF32[$11>>2]);
       $87 = !($86 <= Math_fround(9.99999974737875163555E-6));
       if ($87) {
        $88 = HEAP32[$70>>2]|0;
        dest=$0+0|0; src=$lightMatrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $89 = (($lightBSpheres) + ($69<<4)|0);
        $90 = (__ZN13dynamic_arrayI11ActiveLightLj4EE9push_backEv($outLights)|0);
        dest=$$byval_copy5+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$lightScreenRect+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$lightScreenRect+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$lightScreenRect+8>>2]|0;HEAP32[$$byval_copy6+12>>2]=HEAP32[$lightScreenRect+12>>2]|0;
        __ZL21SetupActiveLocalLightRK27LocalLightCullingParametersRK14ShadowCullDataRK5Light10Matrix4x4fRK8Vector4f5RectTIfEbfiR11ActiveLight($params,$shadowCullData,$88,$$byval_copy5,$89,$$byval_copy6,1,Math_fround(1.0),$69,$90);
        $91 = (($92) + 1)|0;
        HEAP32[$66>>2] = $91;
        $122 = $91;$offScreenLightCount$3$1 = $offScreenLightCount$16$1;
       } else {
        $122 = $92;$offScreenLightCount$3$1 = $offScreenLightCount$16$1;
       }
      } else {
       $122 = $92;$offScreenLightCount$3$1 = $offScreenLightCount$16$1;
      }
     } else {
      $122 = $92;$offScreenLightCount$3$1 = $offScreenLightCount$16$1;
     }
    } while(0);
    $93 = (($i$05$1) + 1)|0;
    $94 = HEAP32[$9>>2]|0;
    $95 = ($93|0)<($94|0);
    if ($95) {
     $92 = $122;$i$05$1 = $93;$offScreenLightCount$16$1 = $offScreenLightCount$3$1;
    } else {
     $$pre$phiZ2D = $66;$97 = $120;$99 = $122;$offScreenLightCount$1$lcssa$1 = $offScreenLightCount$3$1;
     break;
    }
   }
  } else {
   $119 = $120;$offScreenLightCount$1$lcssa13 = $offScreenLightCount$3;
   label = 11;
  }
 } else {
  $119 = 0;$offScreenLightCount$1$lcssa13 = $4;
  label = 11;
 }
 if ((label|0) == 11) {
  $$pre = (($lightCount) + 4|0);
  $$pre$phiZ2D = $$pre;$97 = $119;$99 = 0;$offScreenLightCount$1$lcssa$1 = $offScreenLightCount$1$lcssa13;
 }
 $96 = (($outLights) + 24|0);
 HEAP32[$96>>2] = $97;
 $98 = (($outLights) + 28|0);
 HEAP32[$98>>2] = $99;
 HEAP32[$$pre$phiZ2D>>2] = 0;
 HEAP32[$lightCount>>2] = 0;
 $100 = ($offScreenLightCount$1$lcssa$1|0)>(0);
 if (!($100)) {
  $63 = 0;$65 = 0;
  $62 = (($outLights) + 32|0);
  HEAP32[$62>>2] = $63;
  $64 = (($outLights) + 36|0);
  HEAP32[$64>>2] = $65;
  STACKTOP = sp;return;
 }
 $60 = 0;$i2$02$us = 0;
 while(1) {
  $44 = HEAP32[$offScreenLocalLights>>2]|0;
  $45 = (($44) + ($i2$02$us<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($lights) + ($46<<2)|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 216|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==(0);
  if ($51) {
   $52 = (($48) + 24|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($53)|0);
   __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($lightMatrix6,$54);
   dest=$1+0|0; src=$lightMatrix6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $55 = (($lightBSpheres) + ($46<<4)|0);
   $56 = (($visibilityFades) + ($i2$02$us<<2)|0);
   ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = (__ZN13dynamic_arrayI11ActiveLightLj4EE9push_backEv($outLights)|0);
   dest=$$byval_copy5+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy6+12>>2]=HEAP32[$2+12>>2]|0;
   __ZL21SetupActiveLocalLightRK27LocalLightCullingParametersRK14ShadowCullDataRK5Light10Matrix4x4fRK8Vector4f5RectTIfEbfiR11ActiveLight($params,$shadowCullData,$48,$$byval_copy5,$55,$$byval_copy6,0,$57,$46,$58);
   $59 = (($60) + 1)|0;
   HEAP32[$lightCount>>2] = $59;
   $121 = $59;
  } else {
   $121 = $60;
  }
  $61 = (($i2$02$us) + 1)|0;
  $exitcond = ($61|0)==($offScreenLightCount$1$lcssa$1|0);
  if ($exitcond) {
   $117 = 0;$i2$02$us$1 = 0;
   break;
  } else {
   $60 = $121;$i2$02$us = $61;
  }
 }
 while(1) {
  $101 = HEAP32[$offScreenLocalLights>>2]|0;
  $102 = (($101) + ($i2$02$us$1<<2)|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (($lights) + ($103<<2)|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($105) + 216|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = ($107|0)==(2);
  if ($108) {
   $109 = (($105) + 24|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($110)|0);
   __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($lightMatrix6,$111);
   dest=$1+0|0; src=$lightMatrix6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $112 = (($lightBSpheres) + ($103<<4)|0);
   $113 = (($visibilityFades) + ($i2$02$us$1<<2)|0);
   ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
   $114 = Math_fround(HEAPF32[$113>>2]);
   $115 = (__ZN13dynamic_arrayI11ActiveLightLj4EE9push_backEv($outLights)|0);
   dest=$$byval_copy5+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy6+12>>2]=HEAP32[$2+12>>2]|0;
   __ZL21SetupActiveLocalLightRK27LocalLightCullingParametersRK14ShadowCullDataRK5Light10Matrix4x4fRK8Vector4f5RectTIfEbfiR11ActiveLight($params,$shadowCullData,$105,$$byval_copy5,$112,$$byval_copy6,0,$114,$103,$115);
   $116 = (($117) + 1)|0;
   HEAP32[$$pre$phiZ2D>>2] = $116;
   $123 = $116;
  } else {
   $123 = $117;
  }
  $118 = (($i2$02$us$1) + 1)|0;
  $exitcond$1 = ($118|0)==($offScreenLightCount$1$lcssa$1|0);
  if ($exitcond$1) {
   $63 = $121;$65 = $123;
   break;
  } else {
   $117 = $123;$i2$02$us$1 = $118;
  }
 }
 $62 = (($outLights) + 32|0);
 HEAP32[$62>>2] = $63;
 $64 = (($outLights) + 36|0);
 HEAP32[$64>>2] = $65;
 STACKTOP = sp;return;
}
function __ZL21SetupActiveLocalLightRK27LocalLightCullingParametersRK14ShadowCullDataRK5Light10Matrix4x4fRK8Vector4f5RectTIfEbfiR11ActiveLight($params,$shadowCullData,$light,$lightMatrix,$lightBSpheres,$lightScreenRectangle,$isVisible,$visibilityFade,$lightIndex,$outLight) {
 $params = $params|0;
 $shadowCullData = $shadowCullData|0;
 $light = $light|0;
 $lightMatrix = $lightMatrix|0;
 $lightBSpheres = $lightBSpheres|0;
 $lightScreenRectangle = $lightScreenRectangle|0;
 $isVisible = $isVisible|0;
 $visibilityFade = Math_fround($visibilityFade);
 $lightIndex = $lightIndex|0;
 $outLight = $outLight|0;
 var $$$i = 0, $$0$i = 0, $$0$i$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0);
 var $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0;
 var $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0);
 var $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0;
 var $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0;
 var $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0), $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = 0;
 var $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $phitmp = 0, $phitmp31 = 0, $pos$i$i$i$i = 0, $temp$0$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i$i = sp + 4|0;
 $0 = sp;
 $1 = (($lightBSpheres) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(HEAPF32[$lightBSpheres>>2]);
 $4 = (($lightBSpheres) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($lightBSpheres) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = HEAP32[$shadowCullData>>2]|0;
 $9 = (($8) + 456|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * Math_fround(1.00100004673004150391));
 $12 = (($8) + 460|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * Math_fround(0.999000012874603271484));
 HEAP32[$outLight>>2] = $light;
 $15 = Math_fround(HEAPF32[$params>>2]);
 $16 = Math_fround($3 * $15);
 $17 = (($params) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($5 * $18);
 $20 = Math_fround($16 + $19);
 $21 = (($params) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($7 * $22);
 $24 = Math_fround($20 + $23);
 $25 = (($params) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 + $24);
 $28 = (($outLight) + 9|0);
 $29 = $isVisible&1;
 HEAP8[$28>>0] = $29;
 $30 = (($outLight) + 48|0);
 ;HEAP32[$30+0>>2]=HEAP32[$lightScreenRectangle+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$lightScreenRectangle+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$lightScreenRectangle+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$lightScreenRectangle+12>>2]|0;
 $31 = (($outLight) + 104|0);
 HEAPF32[$31>>2] = $visibilityFade;
 $32 = (($outLight) + 76|0);
 HEAP32[$32>>2] = $lightIndex;
 $33 = (($light) + 188|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($light) + 104|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($light) + 108|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($light) + 112|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($outLight) + 80|0);
 HEAPF32[$41>>2] = $36;
 $42 = (($outLight) + 84|0);
 HEAPF32[$42>>2] = $38;
 $43 = (($outLight) + 88|0);
 HEAPF32[$43>>2] = $40;
 $44 = (($outLight) + 92|0);
 HEAPF32[$44>>2] = $34;
 $45 = (($light) + 140|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 * Math_fround(0.300000011920928955078));
 $48 = (($light) + 144|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * Math_fround(0.589999973773956298828));
 $51 = Math_fround($47 + $50);
 $52 = (($light) + 148|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 * Math_fround(0.109999999403953552246));
 $55 = Math_fround($51 + $54);
 $56 = (($light) + 184|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 * $55);
 $59 = (($outLight) + 96|0);
 HEAPF32[$59>>2] = $58;
 $60 = (($outLight) + 100|0);
 $61 = $29 ^ 1;
 HEAP8[$60>>0] = $61;
 $62 = (($light) + 216|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(3);
 if ($64) {
  $$0$i = 2;
 } else {
  $65 = (($light) + 221|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = ($66<<24>>24)==(0);
  if ($67) {
   $$0$i = 0;
  } else {
   $68 = (($light) + 212|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(1);
   $$$i = $70 ? 1 : 2;
   $$0$i = $$$i;
  }
 }
 $71 = (($outLight) + 12|0);
 HEAP32[$71>>2] = $$0$i;
 $72 = (($light) + 180|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($outLight) + 16|0);
 HEAP32[$74>>2] = $73;
 $75 = (($light) + 176|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0);
 if ($77) {
  $$0$i$i = 0;
 } else {
  HEAP32[$0>>2] = $76;
  $78 = HEAP32[560624>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   label = 13;
  } else {
   $80 = (($78) + 36|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($78) + 4|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($81|0)==($83|0);
   do {
    if ($84) {
     $85 = (($78) + 28|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($78) + 32|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = (($86) + ($88<<3)|0);
     $105 = $89;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$78,$0);
     $90 = HEAP32[$pos$i$i$i$i>>2]|0;
     $91 = ($90|0)==(-1);
     $92 = (($78) + 28|0);
     $93 = HEAP32[$92>>2]|0;
     if ($91) {
      $94 = (($78) + 32|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = (($93) + ($95<<3)|0);
      $105 = $96;
      break;
     } else {
      $97 = (($93) + ($90<<3)|0);
      $105 = $97;
      break;
     }
    }
   } while(0);
   $98 = HEAP32[560624>>2]|0;
   $99 = (($98) + 28|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($98) + 32|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($100) + ($102<<3)|0);
   $104 = ($105|0)==($103|0);
   if ($104) {
    label = 13;
   } else {
    $106 = (($105) + 4|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = ($107|0)==(0|0);
    if ($108) {
     label = 13;
    } else {
     $temp$0$i$i = $107;
    }
   }
  }
  if ((label|0) == 13) {
   $109 = HEAP32[$75>>2]|0;
   $110 = (__Z31ReadObjectFromPersistentManageri($109)|0);
   $temp$0$i$i = $110;
  }
  $phitmp = ($temp$0$i$i|0)!=(0|0);
  $phitmp31 = $phitmp&1;
  $$0$i$i = $phitmp31;
 }
 $111 = (($outLight) + 64|0);
 HEAP8[$111>>0] = $$0$i$i;
 $112 = (($light) + 208|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($outLight) + 68|0);
 HEAP32[$114>>2] = $113;
 $115 = HEAP32[$62>>2]|0;
 $116 = (($outLight) + 72|0);
 HEAP32[$116>>2] = $115;
 $117 = ($115|0)==(0);
 if ($117) {
  dest=$pos$i$i$i$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $118 = Math_fround(HEAPF32[$33>>2]);
  $119 = (($light) + 200|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  __Z24CalculateSpotLightBoundsffRK10Matrix4x4fR15SpotLightBounds($118,$120,$lightMatrix,$pos$i$i$i$i);
  $121 = Math_fround(HEAPF32[$params>>2]);
  $122 = Math_fround(HEAPF32[$17>>2]);
  $123 = Math_fround(HEAPF32[$21>>2]);
  $124 = Math_fround(HEAPF32[$25>>2]);
  $125 = Math_fround(HEAPF32[$pos$i$i$i$i>>2]);
  $126 = Math_fround($121 * $125);
  $127 = (($pos$i$i$i$i) + 4|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = Math_fround($122 * $128);
  $130 = Math_fround($126 + $129);
  $131 = (($pos$i$i$i$i) + 8|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = Math_fround($123 * $132);
  $134 = Math_fround($130 + $133);
  $135 = Math_fround($124 + $134);
  $136 = $135 < Math_fround(inf);
  $137 = $136 ? $135 : Math_fround(inf);
  $138 = $135 > Math_fround(-inf);
  $139 = $138 ? $135 : Math_fround(-inf);
  $140 = (($pos$i$i$i$i) + 12|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = Math_fround($121 * $141);
  $143 = (($pos$i$i$i$i) + 16|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = Math_fround($122 * $144);
  $146 = Math_fround($142 + $145);
  $147 = (($pos$i$i$i$i) + 20|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = Math_fround($123 * $148);
  $150 = Math_fround($146 + $149);
  $151 = Math_fround($124 + $150);
  $152 = $151 < $137;
  $153 = $152 ? $151 : $137;
  $154 = $139 < $151;
  $155 = $154 ? $151 : $139;
  $156 = (($pos$i$i$i$i) + 24|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = Math_fround($121 * $157);
  $159 = (($pos$i$i$i$i) + 28|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = Math_fround($122 * $160);
  $162 = Math_fround($158 + $161);
  $163 = (($pos$i$i$i$i) + 32|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = Math_fround($123 * $164);
  $166 = Math_fround($162 + $165);
  $167 = Math_fround($124 + $166);
  $168 = $167 < $153;
  $169 = $168 ? $167 : $153;
  $170 = $155 < $167;
  $171 = $170 ? $167 : $155;
  $172 = (($pos$i$i$i$i) + 36|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($121 * $173);
  $175 = (($pos$i$i$i$i) + 40|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = Math_fround($122 * $176);
  $178 = Math_fround($174 + $177);
  $179 = (($pos$i$i$i$i) + 44|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = Math_fround($123 * $180);
  $182 = Math_fround($178 + $181);
  $183 = Math_fround($124 + $182);
  $184 = $183 < $169;
  $185 = $184 ? $183 : $169;
  $186 = $171 < $183;
  $187 = $186 ? $183 : $171;
  $188 = (($pos$i$i$i$i) + 48|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = Math_fround($121 * $189);
  $191 = (($pos$i$i$i$i) + 52|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = Math_fround($122 * $192);
  $194 = Math_fround($190 + $193);
  $195 = (($pos$i$i$i$i) + 56|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = Math_fround($123 * $196);
  $198 = Math_fround($194 + $197);
  $199 = Math_fround($124 + $198);
  $200 = $199 < $185;
  $201 = $200 ? $199 : $185;
  $202 = $187 < $199;
  $203 = $202 ? $199 : $187;
  $204 = $201 <= $11;
  $205 = (($outLight) + 20|0);
  $206 = $204&1;
  HEAP8[$205>>0] = $206;
  $207 = $203 >= $14;
  $208 = (($outLight) + 21|0);
  $209 = $207&1;
  HEAP8[$208>>0] = $209;
  $210 = Math_fround($27 - $2);
  $211 = $201 < $210;
  $212 = $211 ? $210 : $201;
  $213 = (($params) + 16|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = $212 > $214;
  if ($215) {
   HEAP8[$28>>0] = 0;
   $216 = (($outLight) + 48|0);
   ;HEAP32[$216+0>>2]=0|0;HEAP32[$216+4>>2]=0|0;HEAP32[$216+8>>2]=0|0;HEAP32[$216+12>>2]=0|0;
  }
  $217 = $141 < $125;
  $218 = $217 ? $141 : $125;
  $219 = $144 < $128;
  $220 = $219 ? $144 : $128;
  $221 = $148 < $132;
  $222 = $221 ? $148 : $132;
  $223 = $125 < $141;
  $224 = $223 ? $141 : $125;
  $225 = $128 < $144;
  $226 = $225 ? $144 : $128;
  $227 = $132 < $148;
  $228 = $227 ? $148 : $132;
  $229 = $157 < $218;
  $230 = $229 ? $157 : $218;
  $231 = $160 < $220;
  $232 = $231 ? $160 : $220;
  $233 = $164 < $222;
  $234 = $233 ? $164 : $222;
  $235 = $224 < $157;
  $236 = $235 ? $157 : $224;
  $237 = $226 < $160;
  $238 = $237 ? $160 : $226;
  $239 = $228 < $164;
  $240 = $239 ? $164 : $228;
  $241 = $173 < $230;
  $242 = $241 ? $173 : $230;
  $243 = $176 < $232;
  $244 = $243 ? $176 : $232;
  $245 = $180 < $234;
  $246 = $245 ? $180 : $234;
  $247 = $236 < $173;
  $248 = $247 ? $173 : $236;
  $249 = $238 < $176;
  $250 = $249 ? $176 : $238;
  $251 = $240 < $180;
  $252 = $251 ? $180 : $240;
  $253 = $189 < $242;
  $254 = $253 ? $189 : $242;
  $255 = $192 < $244;
  $256 = $255 ? $192 : $244;
  $257 = $196 < $246;
  $258 = $257 ? $196 : $246;
  $259 = $248 < $189;
  $260 = $259 ? $189 : $248;
  $261 = $250 < $192;
  $262 = $261 ? $192 : $250;
  $263 = $252 < $196;
  $264 = $263 ? $196 : $252;
  $265 = Math_fround($260 + $254);
  $266 = Math_fround($262 + $256);
  $267 = Math_fround($264 + $258);
  $268 = Math_fround($265 * Math_fround(0.5));
  $269 = Math_fround($266 * Math_fround(0.5));
  $270 = Math_fround($267 * Math_fround(0.5));
  $271 = Math_fround($260 - $254);
  $272 = Math_fround($262 - $256);
  $273 = Math_fround($264 - $258);
  $274 = Math_fround($271 * Math_fround(0.5));
  $275 = Math_fround($272 * Math_fround(0.5));
  $276 = Math_fround($273 * Math_fround(0.5));
  $277 = (($outLight) + 24|0);
  HEAPF32[$277>>2] = $268;
  $278 = (($outLight) + 28|0);
  HEAPF32[$278>>2] = $269;
  $279 = (($outLight) + 32|0);
  HEAPF32[$279>>2] = $270;
  $280 = (($outLight) + 36|0);
  HEAPF32[$280>>2] = $274;
  $281 = (($outLight) + 40|0);
  HEAPF32[$281>>2] = $275;
  $282 = (($outLight) + 44|0);
  HEAPF32[$282>>2] = $276;
  $302 = $212;
 } else {
  $283 = Math_fround($27 - $2);
  $284 = (($outLight) + 24|0);
  HEAPF32[$284>>2] = $3;
  $285 = (($outLight) + 28|0);
  HEAPF32[$285>>2] = $5;
  $286 = (($outLight) + 32|0);
  HEAPF32[$286>>2] = $7;
  $287 = (($outLight) + 36|0);
  HEAPF32[$287>>2] = $2;
  $288 = (($outLight) + 40|0);
  HEAPF32[$288>>2] = $2;
  $289 = (($outLight) + 44|0);
  HEAPF32[$289>>2] = $2;
  $290 = Math_fround($2 * Math_fround(1.26999998092651367188));
  $291 = Math_fround($27 - $290);
  $292 = $291 <= $11;
  $293 = (($outLight) + 20|0);
  $294 = $292&1;
  HEAP8[$293>>0] = $294;
  $295 = Math_fround($290 + $27);
  $296 = $295 >= $14;
  $297 = (($outLight) + 21|0);
  $298 = $296&1;
  HEAP8[$297>>0] = $298;
  $302 = $283;
 }
 $299 = (($shadowCullData) + 580|0);
 $300 = Math_fround(HEAPF32[$299>>2]);
 $301 = $302 < $300;
 do {
  if ($301) {
   $304 = (($params) + 20|0);
   $305 = HEAP8[$304>>0]|0;
   $306 = (($outLight) + 8|0);
   HEAP8[$306>>0] = $305;
   $307 = ($305<<24>>24)==(0);
   if ($307) {
    $334 = $306;
   } else {
    $308 = (($shadowCullData) + 576|0);
    $309 = HEAP8[$308>>0]|0;
    $310 = ($309<<24>>24)==(0);
    if ($310) {
     $334 = $306;
    } else {
     $311 = (($shadowCullData) + 568|0);
     $312 = Math_fround(HEAPF32[$311>>2]);
     $313 = Math_fround($2 + $312);
     $314 = (($shadowCullData) + 556|0);
     $315 = Math_fround(HEAPF32[$314>>2]);
     $316 = Math_fround($3 - $315);
     $317 = (($shadowCullData) + 560|0);
     $318 = Math_fround(HEAPF32[$317>>2]);
     $319 = Math_fround($5 - $318);
     $320 = (($shadowCullData) + 564|0);
     $321 = Math_fround(HEAPF32[$320>>2]);
     $322 = Math_fround($7 - $321);
     $323 = Math_fround($316 * $316);
     $324 = Math_fround($319 * $319);
     $325 = Math_fround($323 + $324);
     $326 = Math_fround($322 * $322);
     $327 = Math_fround($325 + $326);
     $328 = Math_fround($313 * $313);
     $329 = $327 > $328;
     if ($329) {
      HEAP8[$306>>0] = 0;
      $334 = $306;
      break;
     }
     $330 = (($outLight) + 24|0);
     $331 = (__Z25IsObjectWithinShadowRangeRK14ShadowCullDataRK4AABB($shadowCullData,$330)|0);
     if ($331) {
      $334 = $306;
     } else {
      HEAP8[$306>>0] = 0;
      $334 = $306;
     }
    }
   }
  } else {
   $303 = (($outLight) + 8|0);
   HEAP8[$303>>0] = 0;
   $334 = $303;
  }
 } while(0);
 $332 = ($$0$i|0)==(1);
 if (!($332)) {
  STACKTOP = sp;return;
 }
 $333 = HEAP8[$334>>0]|0;
 $335 = ($333<<24>>24)==(0);
 if (!($335)) {
  STACKTOP = sp;return;
 }
 HEAP8[$28>>0] = 0;
 $336 = (($outLight) + 48|0);
 ;HEAP32[$336+0>>2]=0|0;HEAP32[$336+4>>2]=0|0;HEAP32[$336+8>>2]=0|0;HEAP32[$336+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __Z16FindActiveLightsR13dynamic_arrayIPK5LightLj4EES4_RS_I8Vector4fLj4EERS_IiLj4EERK14ShadowCullData($directionalLights,$localLights,$localLightBSpheres,$isShadowCastingLocalLight,$cullData) {
 $directionalLights = $directionalLights|0;
 $localLights = $localLights|0;
 $localLightBSpheres = $localLightBSpheres|0;
 $isShadowCastingLocalLight = $isShadowCastingLocalLight|0;
 $cullData = $cullData|0;
 var $$byval_copy5 = 0, $$pre$i$i = 0, $$pre$i$i2 = 0, $$pre$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$$i = 0, $radius$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (__Z15GetLightManagerv()|0);
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($localLightBSpheres) + 8|0);
 $8 = (($localLightBSpheres) + 12|0);
 $9 = (($localLightBSpheres) + 4|0);
 $10 = (($isShadowCastingLocalLight) + 8|0);
 $11 = (($isShadowCastingLocalLight) + 12|0);
 $12 = (($isShadowCastingLocalLight) + 4|0);
 $14 = $5;
 while(1) {
  $13 = (($14) + -32|0);
  $15 = (($14) + 184|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$cullData>>2]|0;
  $18 = (($17) + 412|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($16|0)==(3);
  do {
   if (!($20)) {
    $21 = (($13) + 221|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if (!($23)) {
     $24 = (($14) + 180|0);
     $25 = HEAP32[$24>>2]|0;
     $not$$i = ($25|0)==(1);
     if (!($not$$i)) {
      break;
     }
    }
    $26 = (($14) + 148|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = $27 & $19;
    $29 = ($28|0)==(0);
    if (!($29)) {
     $30 = (($14) + 152|0);
     $31 = Math_fround(HEAPF32[$30>>2]);
     $32 = $31 < Math_fround(0.00999999977648258209228);
     if (!($32)) {
      $33 = (__ZNK5Light15IsValidToRenderEv($13)|0);
      if ($33) {
       $34 = ($16|0)==(1);
       if ($34) {
        HEAP32[$1>>2] = $13;
        __ZN13dynamic_arrayIPK5LightLj4EE9push_backERKS2_($directionalLights,$1);
        break;
       }
       $35 = $16 & -3;
       $36 = ($35|0)==(0);
       if (!($36)) {
        $122 = ($13|0)==(0|0);
        if ($122) {
         $125 = 0;
        } else {
         $123 = (($14) + -28|0);
         $124 = HEAP32[$123>>2]|0;
         $125 = $124;
        }
        __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(573864,0,573856,564,1,$125,0,0);
        break;
       }
       $37 = ($16|0)==(0);
       $38 = (($14) + 156|0);
       $39 = Math_fround(HEAPF32[$38>>2]);
       if ($37) {
        $40 = (($14) + 172|0);
        $41 = Math_fround(HEAPF32[$40>>2]);
        $42 = Math_fround($39 * $41);
        $radius$0 = $42;
       } else {
        $radius$0 = $39;
       }
       $43 = (($14) + 72|0);
       $44 = Math_fround(HEAPF32[$43>>2]);
       $45 = (($14) + 76|0);
       $46 = Math_fround(HEAPF32[$45>>2]);
       $47 = (($14) + 80|0);
       $48 = Math_fround(HEAPF32[$47>>2]);
       $49 = HEAP32[$7>>2]|0;
       $50 = (($49) + 1)|0;
       HEAP32[$7>>2] = $50;
       $51 = HEAP32[$8>>2]|0;
       $52 = $51 & 2147483647;
       $53 = ($50>>>0)>($52>>>0);
       if ($53) {
        $54 = $51 << 1;
        $55 = ($54|0)==(0);
        $56 = $55 ? 1 : $54;
        $57 = ($52>>>0)<($56>>>0);
        do {
         if ($57) {
          $58 = ($51|0)>(-1);
          if ($58) {
           HEAP32[$8>>2] = $56;
           $59 = HEAP32[$localLightBSpheres>>2]|0;
           $60 = $56 << 4;
           $61 = HEAP32[$9>>2]|0;
           HEAP32[$0>>2] = $61;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
           $62 = (__Z16realloc_internalPvji10MemLabelIdiPKci($59,$60,4,$$byval_copy5,0,573856,370)|0);
           HEAP32[$localLightBSpheres>>2] = $62;
           break;
          } else {
           $63 = $56 << 4;
           $64 = HEAP32[$9>>2]|0;
           HEAP32[$0>>2] = $64;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
           $65 = (__Z15malloc_internaljj10MemLabelIdiPKci($63,4,$$byval_copy5,0,573856,352)|0);
           $66 = HEAP32[$localLightBSpheres>>2]|0;
           $67 = HEAP32[$7>>2]|0;
           $68 = $67 << 4;
           _memcpy(($65|0),($66|0),($68|0))|0;
           HEAP32[$8>>2] = $56;
           HEAP32[$localLightBSpheres>>2] = $65;
           break;
          }
         }
        } while(0);
        $$pre$i$i5 = HEAP32[$7>>2]|0;
        $70 = $$pre$i$i5;
       } else {
        $70 = $50;
       }
       $69 = (($70) + -1)|0;
       $71 = HEAP32[$localLightBSpheres>>2]|0;
       $72 = (($71) + ($69<<4)|0);
       HEAPF32[$72>>2] = $44;
       $73 = ((($71) + ($69<<4)|0) + 4|0);
       HEAPF32[$73>>2] = $46;
       $74 = ((($71) + ($69<<4)|0) + 8|0);
       HEAPF32[$74>>2] = $48;
       $75 = ((($71) + ($69<<4)|0) + 12|0);
       HEAPF32[$75>>2] = $radius$0;
       HEAP32[$2>>2] = $13;
       __ZN13dynamic_arrayIPK5LightLj4EE9push_backERKS2_($localLights,$2);
       $76 = (($14) + 84|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($77|0)==(0);
       $79 = HEAP32[$10>>2]|0;
       $80 = (($79) + 1)|0;
       HEAP32[$10>>2] = $80;
       $81 = HEAP32[$11>>2]|0;
       $82 = $81 & 2147483647;
       $83 = ($80>>>0)>($82>>>0);
       if ($78) {
        if ($83) {
         $103 = $81 << 1;
         $104 = ($103|0)==(0);
         $105 = $104 ? 1 : $103;
         $106 = ($82>>>0)<($105>>>0);
         do {
          if ($106) {
           $107 = ($81|0)>(-1);
           if ($107) {
            HEAP32[$11>>2] = $105;
            $108 = HEAP32[$isShadowCastingLocalLight>>2]|0;
            $109 = $105 << 2;
            $110 = HEAP32[$12>>2]|0;
            HEAP32[$0>>2] = $110;
            ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
            $111 = (__Z16realloc_internalPvji10MemLabelIdiPKci($108,$109,4,$$byval_copy5,0,573856,370)|0);
            HEAP32[$isShadowCastingLocalLight>>2] = $111;
            break;
           } else {
            $112 = $105 << 2;
            $113 = HEAP32[$12>>2]|0;
            HEAP32[$0>>2] = $113;
            ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
            $114 = (__Z15malloc_internaljj10MemLabelIdiPKci($112,4,$$byval_copy5,0,573856,352)|0);
            $115 = HEAP32[$isShadowCastingLocalLight>>2]|0;
            $116 = HEAP32[$10>>2]|0;
            $117 = $116 << 2;
            _memcpy(($114|0),($115|0),($117|0))|0;
            HEAP32[$11>>2] = $105;
            HEAP32[$isShadowCastingLocalLight>>2] = $114;
            break;
           }
          }
         } while(0);
         $$pre$i$i = HEAP32[$10>>2]|0;
         $119 = $$pre$i$i;
        } else {
         $119 = $80;
        }
        $118 = (($119) + -1)|0;
        $120 = HEAP32[$isShadowCastingLocalLight>>2]|0;
        $121 = (($120) + ($118<<2)|0);
        HEAP32[$121>>2] = 0;
        break;
       } else {
        if ($83) {
         $84 = $81 << 1;
         $85 = ($84|0)==(0);
         $86 = $85 ? 1 : $84;
         $87 = ($82>>>0)<($86>>>0);
         do {
          if ($87) {
           $88 = ($81|0)>(-1);
           if ($88) {
            HEAP32[$11>>2] = $86;
            $89 = HEAP32[$isShadowCastingLocalLight>>2]|0;
            $90 = $86 << 2;
            $91 = HEAP32[$12>>2]|0;
            HEAP32[$0>>2] = $91;
            ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
            $92 = (__Z16realloc_internalPvji10MemLabelIdiPKci($89,$90,4,$$byval_copy5,0,573856,370)|0);
            HEAP32[$isShadowCastingLocalLight>>2] = $92;
            break;
           } else {
            $93 = $86 << 2;
            $94 = HEAP32[$12>>2]|0;
            HEAP32[$0>>2] = $94;
            ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
            $95 = (__Z15malloc_internaljj10MemLabelIdiPKci($93,4,$$byval_copy5,0,573856,352)|0);
            $96 = HEAP32[$isShadowCastingLocalLight>>2]|0;
            $97 = HEAP32[$10>>2]|0;
            $98 = $97 << 2;
            _memcpy(($95|0),($96|0),($98|0))|0;
            HEAP32[$11>>2] = $86;
            HEAP32[$isShadowCastingLocalLight>>2] = $95;
            break;
           }
          }
         } while(0);
         $$pre$i$i2 = HEAP32[$10>>2]|0;
         $100 = $$pre$i$i2;
        } else {
         $100 = $80;
        }
        $99 = (($100) + -1)|0;
        $101 = HEAP32[$isShadowCastingLocalLight>>2]|0;
        $102 = (($101) + ($99<<2)|0);
        HEAP32[$102>>2] = 1;
        break;
       }
      }
     }
    }
   }
  } while(0);
  $126 = (($14) + 4|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ($127|0)==($3|0);
  if ($128) {
   break;
  } else {
   $14 = $127;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIPK5LightLj4EE9push_backERKS2_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$t>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if (!($8)) {
  $27 = $4;
  $26 = (($27) + -1)|0;
  $28 = HEAP32[$this>>2]|0;
  $29 = (($28) + ($26<<2)|0);
  HEAP32[$29>>2] = $1;
  STACKTOP = sp;return;
 }
 $9 = $6 << 1;
 $10 = ($9|0)==(0);
 $11 = $10 ? 1 : $9;
 $12 = ($7>>>0)<($11>>>0);
 do {
  if ($12) {
   $13 = ($6|0)>(-1);
   if ($13) {
    HEAP32[$5>>2] = $11;
    $14 = HEAP32[$this>>2]|0;
    $15 = $11 << 2;
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy1,0,573856,370)|0);
    HEAP32[$this>>2] = $18;
    break;
   } else {
    $19 = $11 << 2;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,573856,352)|0);
    $23 = HEAP32[$this>>2]|0;
    $24 = HEAP32[$2>>2]|0;
    $25 = $24 << 2;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$5>>2] = $11;
    HEAP32[$this>>2] = $22;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$2>>2]|0;
 $27 = $$pre$i;
 $26 = (($27) + -1)|0;
 $28 = HEAP32[$this>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAP32[$29>>2] = $1;
 STACKTOP = sp;return;
}
function __Z20AddActiveLocalLightsRK14ShadowCullDataPPK5LightPK8Vector4fRK9IndexListPfRS9_R12ActiveLights($cullData,$localLights,$localLightBSpheres,$visibleLocalLightIndices,$offScreenLocalLightvisibilityFades,$offScreenLocalLightIndices,$outLights) {
 $cullData = $cullData|0;
 $localLights = $localLights|0;
 $localLightBSpheres = $localLightBSpheres|0;
 $visibleLocalLightIndices = $visibleLocalLightIndices|0;
 $offScreenLocalLightvisibilityFades = $offScreenLocalLightvisibilityFades|0;
 $offScreenLocalLightIndices = $offScreenLocalLightIndices|0;
 $outLights = $outLights|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $localLightCullParameters = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localLightCullParameters = sp;
 $0 = (($cullData) + 208|0);
 ;HEAP32[$localLightCullParameters+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$localLightCullParameters+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$localLightCullParameters+8>>2]=HEAP32[$0+8>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($cullData) + 196|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 * $3);
 $5 = (($cullData) + 212|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($cullData) + 200|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = Math_fround($4 + $9);
 $11 = (($cullData) + 216|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($cullData) + 204|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 * $14);
 $16 = Math_fround($10 + $15);
 $17 = Math_fround(-$16);
 $18 = (($localLightCullParameters) + 12|0);
 HEAPF32[$18>>2] = $17;
 $19 = HEAP32[$cullData>>2]|0;
 $20 = (($19) + 460|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($localLightCullParameters) + 16|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($cullData) + 580|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($19) + 456|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = $24 > $26;
 $28 = (($localLightCullParameters) + 20|0);
 $29 = $27&1;
 HEAP8[$28>>0] = $29;
 $30 = (($19) + 412|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($localLightCullParameters) + 24|0);
 HEAP32[$32>>2] = $31;
 __Z20AddActiveLocalLightsRK27LocalLightCullingParametersRK14ShadowCullDataPK8Vector4fPPK5LightRK9IndexListPfRSC_R12ActiveLights($localLightCullParameters,$cullData,$localLightBSpheres,$localLights,$visibleLocalLightIndices,$offScreenLocalLightvisibilityFades,$offScreenLocalLightIndices,$outLights);
 STACKTOP = sp;return;
}
function __Z13FindMainLightv() {
 var $$0 = 0, $$0$i$i = Math_fround(0), $$027 = 0, $$028 = 0, $$byval_copy17 = 0, $$index = 0, $$index10 = 0, $$index2 = 0, $$index6 = 0, $$lcssa152426 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bestMainLightIntensity$02$i = Math_fround(0), $bestMainLightIntensity$1$i = Math_fround(0), $exitcond$i = 0, $i$01$i = 0, $mainLightIndex$03$i = 0, $mainLightIndex$1$i = 0, $not$$i = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy17 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (__Z15GetLightManagerv()|0);
 $5 = HEAP32[628512>>2]|0;
 HEAP32[$3>>2] = $5;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$3+0>>2]|0;
 $6 = (invoke_iiiiiiii(108,(0|0),32,4,($$byval_copy17|0),0,(573856|0),370)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if ($8) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   $$index = $9;$$index2 = $10;$38 = 0;
  } else {
   $11 = (($4) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==($4|0);
   if ($13) {
    $$028 = 0;$$lcssa152426 = $6;
   } else {
    $15 = $12;$42 = 0;$44 = 8;$52 = $6;
    L6: while(1) {
     $14 = (($15) + -32|0);
     $16 = (($15) + 184|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(3);
     do {
      if ($18) {
       $67 = $42;$69 = $52;$98 = $44;
      } else {
       $19 = (($14) + 221|0);
       $20 = HEAP8[$19>>0]|0;
       $21 = ($20<<24>>24)==(0);
       if (!($21)) {
        $22 = (($15) + 180|0);
        $23 = HEAP32[$22>>2]|0;
        $not$$i = ($23|0)==(1);
        if (!($not$$i)) {
         $67 = $42;$69 = $52;$98 = $44;
         break;
        }
       }
       $24 = (($15) + 148|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = ($25|0)==(0);
       if ($26) {
        $67 = $42;$69 = $52;$98 = $44;
       } else {
        $27 = (($15) + 152|0);
        $28 = Math_fround(HEAPF32[$27>>2]);
        $29 = $28 < Math_fround(0.00999999977648258209228);
        if ($29) {
         $67 = $42;$69 = $52;$98 = $44;
        } else {
         __THREW__ = 0;
         $30 = (invoke_ii(3227,($14|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          $37 = $44;
          label = 12;
          break L6;
         }
         $33 = ($17|0)==(1);
         $or$cond = $30 & $33;
         if ($or$cond) {
          $41 = (($42) + 1)|0;
          $43 = $44 & 2147483647;
          $45 = ($41>>>0)>($43>>>0);
          do {
           if ($45) {
            $46 = $44 << 1;
            $47 = ($46|0)==(0);
            $48 = $47 ? 1 : $46;
            $49 = ($43>>>0)<($48>>>0);
            if ($49) {
             $50 = ($44|0)>(-1);
             if ($50) {
              $51 = $48 << 2;
              HEAP32[$1>>2] = $5;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$1+0>>2]|0;
              $53 = (invoke_iiiiiiii(108,($52|0),($51|0),4,($$byval_copy17|0),0,(573856|0),370)|0);
              $54 = __THREW__; __THREW__ = 0;
              $55 = $54&1;
              if ($55) {
               $37 = $48;
               label = 12;
               break L6;
              }
              $101 = $48;$62 = $53;
              break;
             } else {
              $56 = $48 << 2;
              HEAP32[$2>>2] = $5;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$2+0>>2]|0;
              $57 = (invoke_iiiiiii(102,($56|0),4,($$byval_copy17|0),0,(573856|0),352)|0);
              $58 = __THREW__; __THREW__ = 0;
              $59 = $58&1;
              if ($59) {
               $37 = $44;
               label = 12;
               break L6;
              }
              $60 = $41 << 2;
              _memcpy(($57|0),($52|0),($60|0))|0;
              $101 = $48;$62 = $57;
              break;
             }
            } else {
             $101 = $44;$62 = $52;
            }
           } else {
            $101 = $44;$62 = $52;
           }
          } while(0);
          $61 = (($62) + ($42<<2)|0);
          HEAP32[$61>>2] = $14;
          $67 = $41;$69 = $62;$98 = $101;
         } else {
          $67 = $42;$69 = $52;$98 = $44;
         }
        }
       }
      }
     } while(0);
     $63 = (($15) + 4|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)==($4|0);
     if ($65) {
      break;
     } else {
      $15 = $64;$42 = $67;$44 = $98;$52 = $69;
     }
    }
    if ((label|0) == 12) {
     $34 = ___cxa_find_matching_catch()|0;
     $35 = tempRet0;
     $36 = ($37|0)>(-1);
     if ($36) {
      $$index = $34;$$index2 = $35;$38 = $52;
      break;
     } else {
      $$index10 = $35;$$index6 = $34;
     }
     ___resumeException($$index6|0);
     // unreachable;
    }
    $66 = ($67|0)==(0);
    if ($66) {
     $$0 = 0;
    } else {
     $bestMainLightIntensity$02$i = Math_fround(0.0);$i$01$i = 0;$mainLightIndex$03$i = -1;
     while(1) {
      $68 = (($69) + ($i$01$i<<2)|0);
      $70 = HEAP32[$68>>2]|0;
      $71 = (($70) + 208|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = ($72|0)==(2);
      if ($73) {
       $$0$i$i = Math_fround(0.0);
      } else {
       $74 = (($70) + 140|0);
       $75 = Math_fround(HEAPF32[$74>>2]);
       $76 = Math_fround($75 * Math_fround(0.300000011920928955078));
       $77 = (($70) + 144|0);
       $78 = Math_fround(HEAPF32[$77>>2]);
       $79 = Math_fround($78 * Math_fround(0.589999973773956298828));
       $80 = Math_fround($76 + $79);
       $81 = (($70) + 148|0);
       $82 = Math_fround(HEAPF32[$81>>2]);
       $83 = Math_fround($82 * Math_fround(0.109999999403953552246));
       $84 = Math_fround($80 + $83);
       $85 = (($70) + 184|0);
       $86 = Math_fround(HEAPF32[$85>>2]);
       $87 = Math_fround($86 * $84);
       $88 = (($70) + 116|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = ($89|0)==(0);
       if ($90) {
        $$0$i$i = $87;
       } else {
        $91 = Math_fround($87 * Math_fround(16.0));
        $$0$i$i = $91;
       }
      }
      $92 = $$0$i$i > $bestMainLightIntensity$02$i;
      $bestMainLightIntensity$1$i = $92 ? $$0$i$i : $bestMainLightIntensity$02$i;
      $mainLightIndex$1$i = $92 ? $i$01$i : $mainLightIndex$03$i;
      $93 = (($i$01$i) + 1)|0;
      $exitcond$i = ($93|0)==($67|0);
      if ($exitcond$i) {
       break;
      } else {
       $bestMainLightIntensity$02$i = $bestMainLightIntensity$1$i;$i$01$i = $93;$mainLightIndex$03$i = $mainLightIndex$1$i;
      }
     }
     $94 = ($mainLightIndex$1$i|0)==(-1);
     if ($94) {
      $$0 = 0;
     } else {
      $95 = (($69) + ($mainLightIndex$1$i<<2)|0);
      $96 = HEAP32[$95>>2]|0;
      $$0 = $96;
     }
    }
    $97 = ($98|0)>(-1);
    if ($97) {
     $$028 = $$0;$$lcssa152426 = $69;
    } else {
     $$027 = $$0;
     STACKTOP = sp;return ($$027|0);
    }
   }
   HEAP32[$0>>2] = $5;
   ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($$lcssa152426,$$byval_copy17);
   $$027 = $$028;
   STACKTOP = sp;return ($$027|0);
  }
 } while(0);
 HEAP32[$0>>2] = $5;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($38|0),($$byval_copy17|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $99 = ___cxa_find_matching_catch(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 } else {
  $$index10 = $$index2;$$index6 = $$index;
  ___resumeException($$index6|0);
  // unreachable;
 }
 return 0|0;
}
function __Z15GetLightManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[573888>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN12LightManager15InitializeClassEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(8)|0);
 $1 = (($0) + 4|0);
 HEAP32[$0>>2] = $0;
 HEAP32[$1>>2] = $0;
 HEAP32[573888>>2] = $0;
 $2 = (__ZN8keywords6CreateEPKc(573896)|0);
 HEAP32[573912>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN12LightManager12CleanupClassEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[573888>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  __ZdlPv($0);
 }
 HEAP32[573888>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12LightManager17SetupVertexLightsEiPKPK11ActiveLight($lightCount,$lights) {
 $lightCount = $lightCount|0;
 $lights = $lights|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0;
 var $smax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = HEAP32[((640792 + 88|0))>>2]|0;
 $2 = ($1|0)<($lightCount|0);
 $3 = $2 ? $1 : $lightCount;
 $4 = ($3|0)>(0);
 if ($4) {
  $5 = $1 ^ -1;
  $6 = $lightCount ^ -1;
  $7 = ($5|0)>($6|0);
  $smax = $7 ? $5 : $6;
  $8 = $smax ^ -1;
  $i$01 = 0;
  while(1) {
   $9 = (($lights) + ($i$01<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = (($10) + 104|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   __ZN5Light16SetupVertexLightEif($11,$i$01,$13);
   $14 = (($i$01) + 1)|0;
   $exitcond = ($14|0)==($8|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $14;
   }
  }
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (($15) + 244|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($0,$3);
 STACKTOP = sp;return;
}
function __ZN12LightManager22SetupForwardBaseLightsERK18ForwardLightsBlock($lights) {
 $lights = $lights|0;
 var $$0$i$i$i = Math_fround(0), $$0$i$i$i9 = Math_fround(0), $$0$i1$i$i11 = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$i3$i$i10 = Math_fround(0), $$in = 0, $$lcssa1320 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$014 = 0, $i1$012 = 0, $intensity$0 = Math_fround(0), $lightColors = 0, $lightDir = 0, $packedAtten = 0, $packedPosX = 0, $packedPosY = 0, $packedPosZ = 0, $uglygep = 0;
 var $uglygep18 = 0, $uglygep19 = 0, $world2Light = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $packedPosX = sp + 200|0;
 $packedPosY = sp;
 $packedPosZ = sp + 16|0;
 $packedAtten = sp + 32|0;
 $lightColors = sp + 48|0;
 $lightDir = sp + 112|0;
 $0 = sp + 124|0;
 $world2Light = sp + 136|0;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = (($1) + 4|0);
 $3 = (($lights) + 128|0);
 $4 = (($lights) + 112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($lights) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if ($8) {
  $9 = (($lights) + 120|0);
  $10 = (($lights) + 124|0);
  $33 = $7;$i$014 = 0;
  while(1) {
   $$sum = (($i$014) + ($5))|0;
   $15 = (($3) + ($$sum<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 104|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = (($17) + 108|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = (($17) + 112|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = (($17) + 184|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = Math_fround($25 * Math_fround(2.0));
   $27 = ($i$014|0)==(0);
   if ($27) {
    $28 = Math_fround(HEAPF32[$9>>2]);
    $29 = $28 != Math_fround(1.0);
    if ($29) {
     $30 = Math_fround(Math_fround(1.0) - $28);
     $31 = Math_fround($26 * $30);
     $intensity$0 = $31;
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    label = 0;
    $32 = (($33) + -1)|0;
    $34 = ($i$014|0)==($32|0);
    if ($34) {
     $35 = Math_fround(HEAPF32[$10>>2]);
     $36 = Math_fround($26 * $35);
     $intensity$0 = $36;
    } else {
     $intensity$0 = $26;
    }
   }
   $37 = (__Z19GetActiveColorSpacev()|0);
   $38 = ($37|0)==(1);
   $39 = (($17) + 140|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   do {
    if ($38) {
     $41 = !($40 <= Math_fround(0.0404499992728233337402));
     do {
      if ($41) {
       $43 = $40 < Math_fround(1.0);
       if ($43) {
        $44 = Math_fround($40 + Math_fround(0.054999999701976776123));
        $45 = Math_fround($44 / Math_fround(1.05499994754791259766));
        $46 = (Math_fround(+(Math_pow((+$45),2.40000009536743164063))));
        $$0$i$i$i = $46;
        break;
       } else {
        $47 = (Math_fround(+(Math_pow((+$40),2.40000009536743164063))));
        $$0$i$i$i = $47;
        break;
       }
      } else {
       $42 = Math_fround($40 / Math_fround(12.9200000762939453125));
       $$0$i$i$i = $42;
      }
     } while(0);
     $48 = (($17) + 144|0);
     $49 = Math_fround(HEAPF32[$48>>2]);
     $50 = !($49 <= Math_fround(0.0404499992728233337402));
     do {
      if ($50) {
       $52 = $49 < Math_fround(1.0);
       if ($52) {
        $53 = Math_fround($49 + Math_fround(0.054999999701976776123));
        $54 = Math_fround($53 / Math_fround(1.05499994754791259766));
        $55 = (Math_fround(+(Math_pow((+$54),2.40000009536743164063))));
        $$0$i3$i$i = $55;
        break;
       } else {
        $56 = (Math_fround(+(Math_pow((+$49),2.40000009536743164063))));
        $$0$i3$i$i = $56;
        break;
       }
      } else {
       $51 = Math_fround($49 / Math_fround(12.9200000762939453125));
       $$0$i3$i$i = $51;
      }
     } while(0);
     $57 = (($17) + 148|0);
     $58 = Math_fround(HEAPF32[$57>>2]);
     $59 = !($58 <= Math_fround(0.0404499992728233337402));
     if (!($59)) {
      $60 = Math_fround($58 / Math_fround(12.9200000762939453125));
      $$0$i$i$i9 = $$0$i$i$i;$$0$i1$i$i11 = $60;$$0$i3$i$i10 = $$0$i3$i$i;
      break;
     }
     $61 = $58 < Math_fround(1.0);
     if ($61) {
      $62 = Math_fround($58 + Math_fround(0.054999999701976776123));
      $63 = Math_fround($62 / Math_fround(1.05499994754791259766));
      $64 = (Math_fround(+(Math_pow((+$63),2.40000009536743164063))));
      $$0$i$i$i9 = $$0$i$i$i;$$0$i1$i$i11 = $64;$$0$i3$i$i10 = $$0$i3$i$i;
      break;
     } else {
      $65 = (Math_fround(+(Math_pow((+$58),2.40000009536743164063))));
      $$0$i$i$i9 = $$0$i$i$i;$$0$i1$i$i11 = $65;$$0$i3$i$i10 = $$0$i3$i$i;
      break;
     }
    } else {
     $66 = (($17) + 144|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = (($17) + 148|0);
     $69 = Math_fround(HEAPF32[$68>>2]);
     $$0$i$i$i9 = $40;$$0$i1$i$i11 = $69;$$0$i3$i$i10 = $67;
    }
   } while(0);
   $$in = (($17) + 152|0);
   $70 = Math_fround(HEAPF32[$$in>>2]);
   $71 = Math_fround($intensity$0 * $$0$i$i$i9);
   $72 = Math_fround($intensity$0 * $$0$i3$i$i10);
   $73 = Math_fround($intensity$0 * $$0$i1$i$i11);
   $74 = Math_fround($intensity$0 * $70);
   $75 = (($17) + 188|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = (Math_fround(__ZN5Light11CalcQuadFacEf($76)));
   $78 = (($packedPosX) + ($i$014<<2)|0);
   HEAPF32[$78>>2] = $19;
   $79 = (($packedPosY) + ($i$014<<2)|0);
   HEAPF32[$79>>2] = $21;
   $80 = (($packedPosZ) + ($i$014<<2)|0);
   HEAPF32[$80>>2] = $23;
   $81 = (($packedAtten) + ($i$014<<2)|0);
   HEAPF32[$81>>2] = $77;
   $82 = (($lightColors) + ($i$014<<4)|0);
   HEAPF32[$82>>2] = $71;
   $83 = ((($lightColors) + ($i$014<<4)|0) + 4|0);
   HEAPF32[$83>>2] = $72;
   $84 = ((($lightColors) + ($i$014<<4)|0) + 8|0);
   HEAPF32[$84>>2] = $73;
   $85 = ((($lightColors) + ($i$014<<4)|0) + 12|0);
   HEAPF32[$85>>2] = $74;
   $86 = (($i$014) + 1)|0;
   $12 = HEAP32[$6>>2]|0;
   $87 = ($86|0)<($12|0);
   if ($87) {
    $33 = $12;$i$014 = $86;
   } else {
    break;
   }
  }
  $11 = ($12|0)<(4);
  if ($11) {
   $$lcssa1320 = $12;
   label = 4;
  } else {
   $92 = $12;
  }
 } else {
  $$lcssa1320 = $7;
  label = 4;
 }
 if ((label|0) == 4) {
  $13 = $$lcssa1320 << 2;
  $uglygep = (($packedPosX) + ($13)|0);
  $14 = (16 - ($13))|0;
  _memset(($uglygep|0),0,($14|0))|0;
  $uglygep18 = (($packedPosY) + ($13)|0);
  _memset(($uglygep18|0),0,($14|0))|0;
  $uglygep19 = (($packedPosZ) + ($13)|0);
  _memset(($uglygep19|0),0,($14|0))|0;
  $i1$012 = $$lcssa1320;
  while(1) {
   $88 = (($packedAtten) + ($i1$012<<2)|0);
   HEAPF32[$88>>2] = Math_fround(1.0);
   $89 = (($lightColors) + ($i1$012<<4)|0);
   $90 = (($i1$012) + 1)|0;
   $exitcond = ($90|0)==(4);
   ;HEAP32[$89+0>>2]=0|0;HEAP32[$89+4>>2]=0|0;HEAP32[$89+8>>2]=0|0;HEAP32[$89+12>>2]=0|0;
   if ($exitcond) {
    $92 = $$lcssa1320;
    break;
   } else {
    $i1$012 = $90;
   }
  }
 }
 $91 = ($92|0)==(0);
 if ($91) {
  $111 = HEAP32[652824>>2]|0;
  $112 = HEAP32[573912>>2]|0;
  $113 = $112 & 31;
  $114 = 1 << $113;
  $115 = $114 ^ -1;
  $116 = $112 >>> 5;
  $117 = ((($111) + ($116<<2)|0) + 4|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = $118 & $115;
  HEAP32[$117>>2] = $119;
 } else {
  $93 = (($1) + 1188|0);
  ;HEAP32[$93+0>>2]=HEAP32[$packedPosX+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$packedPosX+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$packedPosX+8>>2]|0;HEAP32[$93+12>>2]=HEAP32[$packedPosX+12>>2]|0;
  $94 = (($1) + 1204|0);
  ;HEAP32[$94+0>>2]=HEAP32[$packedPosY+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$packedPosY+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$packedPosY+8>>2]|0;HEAP32[$94+12>>2]=HEAP32[$packedPosY+12>>2]|0;
  $95 = (($1) + 1220|0);
  ;HEAP32[$95+0>>2]=HEAP32[$packedPosZ+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$packedPosZ+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$packedPosZ+8>>2]|0;HEAP32[$95+12>>2]=HEAP32[$packedPosZ+12>>2]|0;
  $96 = (($1) + 1236|0);
  ;HEAP32[$96+0>>2]=HEAP32[$packedAtten+0>>2]|0;HEAP32[$96+4>>2]=HEAP32[$packedAtten+4>>2]|0;HEAP32[$96+8>>2]=HEAP32[$packedAtten+8>>2]|0;HEAP32[$96+12>>2]=HEAP32[$packedAtten+12>>2]|0;
  ;HEAP32[$2+0>>2]=HEAP32[$lightColors+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$lightColors+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$lightColors+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$lightColors+12>>2]|0;
  $97 = (($lightColors) + 16|0);
  $98 = (($1) + 20|0);
  ;HEAP32[$98+0>>2]=HEAP32[$97+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$97+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$97+8>>2]|0;HEAP32[$98+12>>2]=HEAP32[$97+12>>2]|0;
  $99 = (($lightColors) + 32|0);
  $100 = (($1) + 36|0);
  ;HEAP32[$100+0>>2]=HEAP32[$99+0>>2]|0;HEAP32[$100+4>>2]=HEAP32[$99+4>>2]|0;HEAP32[$100+8>>2]=HEAP32[$99+8>>2]|0;HEAP32[$100+12>>2]=HEAP32[$99+12>>2]|0;
  $101 = (($lightColors) + 48|0);
  $102 = (($1) + 52|0);
  ;HEAP32[$102+0>>2]=HEAP32[$101+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$101+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$101+8>>2]|0;HEAP32[$102+12>>2]=HEAP32[$101+12>>2]|0;
  $103 = HEAP32[652824>>2]|0;
  $104 = HEAP32[573912>>2]|0;
  $105 = $104 & 31;
  $106 = 1 << $105;
  $107 = $104 >>> 5;
  $108 = ((($103) + ($107<<2)|0) + 4|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = $106 | $109;
  HEAP32[$108>>2] = $110;
 }
 $120 = (($lights) + 108|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($121|0)==(0|0);
 if ($122) {
  $123 = (($1) + 548|0);
  ;HEAP32[$123+0>>2]=0|0;HEAP32[$123+4>>2]=0|0;HEAP32[$123+8>>2]=0|0;HEAP32[$123+12>>2]=0|0;
  STACKTOP = sp;return;
 } else {
  $124 = HEAP32[$121>>2]|0;
  $125 = (($124) + 24|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($126)|0);
  HEAPF32[$0>>2] = Math_fround(0.0);
  $128 = (($0) + 4|0);
  HEAPF32[$128>>2] = Math_fround(0.0);
  $129 = (($0) + 8|0);
  HEAPF32[$129>>2] = Math_fround(-1.0);
  __ZNK9Transform18TransformDirectionERK8Vector3f($lightDir,$127,$0);
  $130 = Math_fround(HEAPF32[$lightDir>>2]);
  $131 = (($lightDir) + 4|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = (($lightDir) + 8|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($1) + 532|0);
  HEAPF32[$135>>2] = $130;
  $136 = (($1) + 536|0);
  HEAPF32[$136>>2] = $132;
  $137 = (($1) + 540|0);
  HEAPF32[$137>>2] = $134;
  $138 = (($1) + 544|0);
  HEAPF32[$138>>2] = Math_fround(0.0);
  $139 = (($124) + 40|0);
  dest=$world2Light+0|0; src=$139+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $140 = (($1) + 3556|0);
  __ZNK5Light9GetMatrixEPK10Matrix4x4fPS0_($124,$world2Light,$140);
  __ZN5Light15SetLightKeywordEv($124);
  __ZNK5Light19SetPropsToShaderLabEf($124,Math_fround(1.0));
  STACKTOP = sp;return;
 }
}
function __ZN12LightManager20SetupForwardAddLightEP5Lightf($light,$blend) {
 $light = $light|0;
 $blend = Math_fround($blend);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $world2Light = 0, $worldDir = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $worldDir = sp + 80|0;
 $0 = sp;
 $world2Light = sp + 16|0;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = (($light) + 216|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1);
 if ($4) {
  $11 = (($light) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($12)|0);
  HEAPF32[$0>>2] = Math_fround(0.0);
  $14 = (($0) + 4|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
  $15 = (($0) + 8|0);
  HEAPF32[$15>>2] = Math_fround(-1.0);
  __ZNK9Transform18TransformDirectionERK8Vector3f($worldDir,$13,$0);
  $16 = Math_fround(HEAPF32[$worldDir>>2]);
  $17 = (($worldDir) + 4|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($worldDir) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $22 = $16;$24 = $18;$26 = $20;$28 = Math_fround(0.0);
 } else {
  $5 = (($light) + 104|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($light) + 108|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($light) + 112|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $22 = $6;$24 = $8;$26 = $10;$28 = Math_fround(1.0);
 }
 $21 = (($1) + 532|0);
 HEAPF32[$21>>2] = $22;
 $23 = (($1) + 536|0);
 HEAPF32[$23>>2] = $24;
 $25 = (($1) + 540|0);
 HEAPF32[$25>>2] = $26;
 $27 = (($1) + 544|0);
 HEAPF32[$27>>2] = $28;
 $29 = (($light) + 40|0);
 dest=$world2Light+0|0; src=$29+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $30 = (($1) + 3556|0);
 __ZNK5Light9GetMatrixEPK10Matrix4x4fPS0_($light,$world2Light,$30);
 __ZN5Light15SetLightKeywordEv($light);
 __ZNK5Light19SetPropsToShaderLabEf($light,$blend);
 STACKTOP = sp;return;
}
function __ZN12LightManager8AddLightEP5Light($this,$source) {
 $this = $this|0;
 $source = $source|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($source) + 32|0);
 $1 = ($0|0)==($this|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 $$pre$i$i = (($source) + 36|0);
 if (!($3)) {
  $4 = HEAP32[$$pre$i$i>>2]|0;
  $5 = (($2) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$$pre$i$i>>2] = 0;
 }
 $8 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = $8;
 HEAP32[$$pre$i$i>>2] = $this;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $0;
 $10 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$10>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN12LightManager11RemoveLightEP5Light($this,$source) {
 $this = $this|0;
 $source = $source|0;
 var $$$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($source|0)==(0|0);
 $1 = (($source) + 32|0);
 $$$i$i = $0 ? 0 : $1;
 $2 = HEAP32[$$$i$i>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($$$i$i) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$$$i$i>>2]|0;
 $8 = HEAP32[$4>>2]|0;
 HEAP32[$8>>2] = $7;
 HEAP32[$$$i$i>>2] = 0;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12LightManager9GetLightsE9LightTypei($agg$result,$this,$type,$layer) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $type = $type|0;
 $layer = $layer|0;
 var $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $light = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $light = sp + 4|0;
 HEAP32[$agg$result>>2] = 0;
 $1 = (($agg$result) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($agg$result) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = 1 << $layer;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($this|0);
 if ($6) {
  STACKTOP = sp;return;
 } else {
  $8 = $5;
 }
 L3: while(1) {
  $7 = (($8) + -32|0);
  HEAP32[$light>>2] = $7;
  $9 = ($7|0)==(0|0);
  do {
   if (!($9)) {
    $23 = (($8) + 184|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==($type|0);
    if ($25) {
     $26 = (($8) + 148|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = $27 & $3;
     $29 = ($28|0)==(0);
     if (!($29)) {
      $30 = HEAP32[$1>>2]|0;
      $31 = HEAP32[$2>>2]|0;
      $32 = ($30|0)==($31|0);
      if ($32) {
       __THREW__ = 0;
       invoke_vii(2631,($agg$result|0),($light|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break L3;
       } else {
        break;
       }
      }
      $33 = ($30|0)==(0|0);
      if ($33) {
       $35 = 0;
      } else {
       HEAP32[$30>>2] = $7;
       $$pre$i = HEAP32[$1>>2]|0;
       $35 = $$pre$i;
      }
      $34 = (($35) + 4|0);
      HEAP32[$1>>2] = $34;
     }
    }
   }
  } while(0);
  $38 = (($8) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==($this|0);
  if ($40) {
   label = 16;
   break;
  } else {
   $8 = $39;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $12 = HEAP32[$agg$result>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  ___resumeException($10|0);
  // unreachable;
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = ($14|0)==($12|0);
 if (!($15)) {
  $__new_last2$i$i$i$i$i = $12;
  $scevgep$i$i$i$i$i = (($14) + -4|0);
  $16 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($16)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $17 = $uglygep3$i$i$i$i$i >>> 2;
  $18 = $17 ^ -1;
  $scevgep4$i$i$i$i$i = (($14) + ($18<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
 }
 HEAP32[$0>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($12|0),($$byval_copy|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  ___cxa_call_unexpected(($21|0));
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN12LightManager25FindVertexLightsForObjectER13dynamic_arrayIhLj1EEP11CulledLightjRK12ActiveLightsRK11VisibleNode($this,$dest,$culledLights,$lightCount,$activeLights,$node) {
 $this = $this|0;
 $dest = $dest|0;
 $culledLights = $culledLights|0;
 $lightCount = $lightCount|0;
 $activeLights = $activeLights|0;
 $node = $node|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $smax = 0, $smax$op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[((640792 + 88|0))>>2]|0;
 $2 = ($1|0)>(8);
 $3 = $2 ? 8 : $1;
 $4 = ($3|0)<($lightCount|0);
 $5 = $4 ? $3 : $lightCount;
 $6 = (($dest) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5 << 2;
 $9 = (($7) + 4)|0;
 $10 = (($9) + ($8))|0;
 HEAP32[$6>>2] = $10;
 $11 = (($dest) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2147483647;
 $14 = ($13>>>0)<($10>>>0);
 do {
  if ($14) {
   $15 = ($12|0)>(-1);
   if ($15) {
    HEAP32[$11>>2] = $10;
    $16 = HEAP32[$dest>>2]|0;
    $17 = (($dest) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$0>>2] = $18;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $19 = (__Z16realloc_internalPvji10MemLabelIdiPKci($16,$10,1,$$byval_copy1,0,573920,370)|0);
    HEAP32[$dest>>2] = $19;
    $26 = $19;
    break;
   } else {
    $20 = (($dest) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($10,1,$$byval_copy1,0,573920,352)|0);
    $23 = HEAP32[$dest>>2]|0;
    $24 = HEAP32[$6>>2]|0;
    _memcpy(($22|0),($23|0),($24|0))|0;
    HEAP32[$11>>2] = $10;
    HEAP32[$dest>>2] = $22;
    $26 = $22;
    break;
   }
  } else {
   $$pre = HEAP32[$dest>>2]|0;
   $26 = $$pre;
  }
 } while(0);
 $25 = (($26) + ($7)|0);
 $27 = (($26) + ($9)|0);
 HEAP32[$25>>2] = $5;
 $28 = ($5|0)>(0);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $29 = $1 ^ -1;
 $30 = $lightCount ^ -1;
 $31 = ($29|0)>($30|0);
 $smax = $31 ? $29 : $30;
 $32 = ($smax|0)>(-9);
 $smax$op = $smax ^ -1;
 $33 = $32 ? $smax$op : 8;
 $i$02 = 0;
 while(1) {
  $34 = (($culledLights) + ($i$02<<3)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$activeLights>>2]|0;
  $37 = (($36) + (($35*108)|0)|0);
  $38 = (($27) + ($i$02<<2)|0);
  HEAP32[$38>>2] = $37;
  $39 = (($i$02) + 1)|0;
  $exitcond = ($39|0)==($33|0);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $39;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12LightManager26FindForwardLightsForObjectER13dynamic_arrayIhLj1EEPK11CulledLightjRK12ActiveLightsRK11VisibleNodeRK23FindForwardLightsParams($dest,$culledLightsIn,$lightCount,$activeLights,$node,$params) {
 $dest = $dest|0;
 $culledLightsIn = $culledLightsIn|0;
 $lightCount = $lightCount|0;
 $activeLights = $activeLights|0;
 $node = $node|0;
 $params = $params|0;
 var $$$i$i$i = Math_fround(0), $$$i$i1$i = Math_fround(0), $$0 = 0, $$0$i$i7$i = Math_fround(0), $$byval_copy11 = 0, $$not = 0, $$off0 = 0, $$pre$i = 0, $$pre18$i = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$sum = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum20 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0);
 var $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0, $brmerge = 0, $brmerge2 = 0, $culledLights$0 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i5 = 0;
 var $exitcond38 = 0, $i$017$i = 0, $i$017$in$i = 0, $i$035 = 0, $i1$027 = 0, $j$01$i = 0, $lastAutoAddLightIndex$0$i1$0 = 0, $lastAutoAddLightIndex$0$lcssa = 0, $lastAutoAddLightIndex$030 = 0, $lastAutoAddLightIndex$1 = 0, $lastVertexLightIndex$0$i = 0, $lights$0$i = 0, $lights$0$lcssa = 0, $lights$032 = 0, $lights$1 = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond1 = 0, $or$cond3 = 0;
 var $remaining$0$lcssa$i = 0, $remaining$0$lcssa$i11 = 0, $remaining$01$i = 0, $remaining$1$i = 0, $smax = 0, $smax$op = 0, $visibleLightCount$02$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy11 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($node) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $9 = 1 << $8;
 $10 = (__Z19GetLightmapSettingsv()|0);
 $11 = HEAP32[$3>>2]|0;
 $12 = (__ZNK16LightmapSettings23HasLightProbeTetrahedraEv($10)|0);
 $13 = (__ZNK16LightmapSettings19AreLightProbesBakedEv($10)|0);
 $14 = (__Z30IsUsingLightProbesForRenderingPK12BaseRendererbb($11,$12,$13)|0);
 $15 = HEAP8[$params>>0]|0;
 if ($14) {
  $16 = $15 & 2;
  $17 = ($16<<24>>24)==(0);
  $332 = $17;
 } else {
  $332 = 0;
 }
 $18 = $15 & 4;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $20 = (($node) + 124|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = ($21<<24>>24)==(0);
  if ($22) {
   $$0 = $lightCount;$culledLights$0 = $culledLightsIn;
  } else {
   $23 = $lightCount << 3;
   $24 = (($23) + 15)|0;
   $25 = ($24>>>0)<(2000);
   $26 = ($lightCount|0)!=(0);
   if ($25) {
    if ($26) {
     $27 = STACKTOP; STACKTOP = STACKTOP + ((((1*$24)|0)+15)&-16)|0;;
     $55 = 0;$allocPtr$0 = $27;
     label = 11;
    } else {
     label = 10;
    }
   } else {
    if ($26) {
     $28 = HEAP32[628512>>2]|0;
     HEAP32[$2>>2] = $28;
     ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
     $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($24,16,$$byval_copy11,0,573920,412)|0);
     $55 = $29;$allocPtr$0 = $29;
     label = 11;
    } else {
     label = 10;
    }
   }
   if ((label|0) == 10) {
    $333 = $1;$334 = 0;$remaining$0$lcssa$i11 = 0;
   }
   else if ((label|0) == 11) {
    $30 = $allocPtr$0;
    $31 = (($30) + 15)|0;
    $32 = $31 & -16;
    $33 = $32;
    $34 = ($lightCount|0)==(0);
    if ($34) {
     $remaining$0$lcssa$i = 0;
    } else {
     $remaining$01$i = 0;$visibleLightCount$02$i = 0;
     while(1) {
      $35 = (($culledLightsIn) + ($visibleLightCount$02$i<<3)|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = HEAP32[$activeLights>>2]|0;
      $38 = ((($37) + (($36*108)|0)|0) + 100|0);
      $39 = HEAP8[$38>>0]|0;
      $40 = ($39<<24>>24)==(0);
      if ($40) {
       $41 = (($remaining$01$i) + 1)|0;
       $42 = (($33) + ($remaining$01$i<<3)|0);
       $43 = $35;
       $44 = $43;
       $45 = HEAP32[$44>>2]|0;
       $46 = (($43) + 4)|0;
       $47 = $46;
       $48 = HEAP32[$47>>2]|0;
       $49 = $42;
       $50 = $49;
       HEAP32[$50>>2] = $45;
       $51 = (($49) + 4)|0;
       $52 = $51;
       HEAP32[$52>>2] = $48;
       $remaining$1$i = $41;
      } else {
       $remaining$1$i = $remaining$01$i;
      }
      $53 = (($visibleLightCount$02$i) + 1)|0;
      $exitcond$i5 = ($53|0)==($lightCount|0);
      if ($exitcond$i5) {
       $remaining$0$lcssa$i = $remaining$1$i;
       break;
      } else {
       $remaining$01$i = $remaining$1$i;$visibleLightCount$02$i = $53;
      }
     }
    }
    $54 = ($55|0)==(0|0);
    if ($54) {
     $333 = $1;$334 = $33;$remaining$0$lcssa$i11 = $remaining$0$lcssa$i;
    } else {
     $56 = HEAP32[628512>>2]|0;
     HEAP32[$1>>2] = $56;
     ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($55,$$byval_copy11);
     $333 = $1;$334 = $33;$remaining$0$lcssa$i11 = $remaining$0$lcssa$i;
    }
   }
   $$0 = $remaining$0$lcssa$i11;$culledLights$0 = $334;
  }
 } else {
  $$0 = $lightCount;$culledLights$0 = $culledLightsIn;
 }
 $57 = (($dest) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + 128)|0;
 HEAP32[$57>>2] = $59;
 $60 = (($dest) + 12|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = $61 & 2147483647;
 $63 = ($62>>>0)<($59>>>0);
 do {
  if ($63) {
   $64 = ($61|0)>(-1);
   if ($64) {
    HEAP32[$60>>2] = $59;
    $65 = HEAP32[$dest>>2]|0;
    $66 = (($dest) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    HEAP32[$0>>2] = $67;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    $68 = (__Z16realloc_internalPvji10MemLabelIdiPKci($65,$59,1,$$byval_copy11,0,573920,370)|0);
    HEAP32[$dest>>2] = $68;
    $75 = $68;
    break;
   } else {
    $69 = (($dest) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    HEAP32[$0>>2] = $70;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    $71 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,1,$$byval_copy11,0,573920,352)|0);
    $72 = HEAP32[$dest>>2]|0;
    $73 = HEAP32[$57>>2]|0;
    _memcpy(($71|0),($72|0),($73|0))|0;
    HEAP32[$60>>2] = $59;
    HEAP32[$dest>>2] = $71;
    $75 = $71;
    break;
   }
  } else {
   $$pre42 = HEAP32[$dest>>2]|0;
   $75 = $$pre42;
  }
 } while(0);
 $74 = (($75) + ($58)|0);
 $$sum = (($58) + 112)|0;
 $76 = (($75) + ($$sum)|0);
 HEAP32[$76>>2] = 0;
 $$sum17 = (($58) + 116)|0;
 $77 = (($75) + ($$sum17)|0);
 HEAP32[$77>>2] = 0;
 $$sum18 = (($58) + 108)|0;
 $78 = (($75) + ($$sum18)|0);
 HEAP32[$78>>2] = 0;
 $$sum19 = (($58) + 120)|0;
 $79 = (($75) + ($$sum19)|0);
 HEAPF32[$79>>2] = Math_fround(1.0);
 $$sum20 = (($58) + 124)|0;
 $80 = (($75) + ($$sum20)|0);
 HEAPF32[$80>>2] = Math_fround(1.0);
 $81 = HEAP8[$params>>0]|0;
 $82 = $81 & 4;
 $83 = ($82<<24>>24)==(0);
 if (!($83)) {
  $84 = HEAP32[((640792 + 88|0))>>2]|0;
  $85 = ($84|0)>(8);
  $86 = $85 ? 8 : $84;
  $87 = ($86|0)<($$0|0);
  $88 = $87 ? $86 : $$0;
  dest=$74+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $89 = $88 << 2;
  $90 = (($89) + ($59))|0;
  HEAP32[$57>>2] = $90;
  $91 = HEAP32[$60>>2]|0;
  $92 = $91 & 2147483647;
  $93 = ($92>>>0)<($90>>>0);
  do {
   if ($93) {
    $94 = ($91|0)>(-1);
    if ($94) {
     HEAP32[$60>>2] = $90;
     $95 = HEAP32[$dest>>2]|0;
     $96 = (($dest) + 4|0);
     $97 = HEAP32[$96>>2]|0;
     HEAP32[$0>>2] = $97;
     ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
     $98 = (__Z16realloc_internalPvji10MemLabelIdiPKci($95,$90,1,$$byval_copy11,0,573920,370)|0);
     HEAP32[$dest>>2] = $98;
     $105 = $98;
     break;
    } else {
     $99 = (($dest) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     HEAP32[$0>>2] = $100;
     ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
     $101 = (__Z15malloc_internaljj10MemLabelIdiPKci($90,1,$$byval_copy11,0,573920,352)|0);
     $102 = HEAP32[$dest>>2]|0;
     $103 = HEAP32[$57>>2]|0;
     _memcpy(($101|0),($102|0),($103|0))|0;
     HEAP32[$60>>2] = $90;
     HEAP32[$dest>>2] = $101;
     $105 = $101;
     break;
    }
   } else {
    $$pre45 = HEAP32[$dest>>2]|0;
    $105 = $$pre45;
   }
  } while(0);
  $104 = (($105) + ($59)|0);
  $106 = (($105) + ($$sum17)|0);
  HEAP32[$106>>2] = $88;
  $107 = ($88|0)>(0);
  if (!($107)) {
   STACKTOP = sp;return;
  }
  $108 = $$0 ^ -1;
  $109 = $84 ^ -1;
  $110 = ($108|0)>($109|0);
  $smax = $110 ? $108 : $109;
  $111 = ($smax|0)>(-9);
  $smax$op = $smax ^ -1;
  $112 = $111 ? $smax$op : 8;
  $i$035 = 0;
  while(1) {
   $113 = (($culledLights$0) + ($i$035<<3)|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = HEAP32[$activeLights>>2]|0;
   $116 = (($115) + (($114*108)|0)|0);
   $117 = (($104) + ($i$035<<2)|0);
   HEAP32[$117>>2] = $116;
   $118 = (($i$035) + 1)|0;
   $exitcond38 = ($118|0)==($112|0);
   if ($exitcond38) {
    break;
   } else {
    $i$035 = $118;
   }
  }
  STACKTOP = sp;return;
 }
 $119 = (($activeLights) + 16|0);
 $120 = HEAP8[$119>>0]|0;
 $121 = ($120<<24>>24)==(0);
 do {
  if (!($121)) {
   $122 = HEAP32[$activeLights>>2]|0;
   $123 = ($122|0)==(0|0);
   if (!($123)) {
    $124 = (($122) + 16|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = $125 & $9;
    $127 = ($126|0)==(0);
    if (!($127)) {
     $128 = (($122) + 64|0);
     $129 = HEAP8[$128>>0]|0;
     $130 = ($129<<24>>24)==(0);
     if ($130) {
      if ($332) {
       $131 = (($122) + 12|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = ($132|0)==(1);
       if ($133) {
        break;
       }
      }
      HEAP32[$78>>2] = $122;
     }
    }
   }
  }
 } while(0);
 if ($14) {
  dest=$74+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 } else {
  $134 = (($params) + 8|0);
  dest=$74+0|0; src=$134+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $135 = ($$0|0)==(0);
 if ($135) {
  $lastAutoAddLightIndex$0$lcssa = -1;$lights$0$lcssa = $74;
 } else {
  $136 = (($params) + 4|0);
  $137 = (($dest) + 4|0);
  $i1$027 = 0;$lastAutoAddLightIndex$030 = -1;$lights$032 = $74;
  while(1) {
   $138 = (($culledLights$0) + ($i1$027<<3)|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = HEAP32[$activeLights>>2]|0;
   $141 = (($140) + (($139*108)|0)|0);
   $142 = ((($140) + (($139*108)|0)|0) + 68|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = HEAP8[$params>>0]|0;
   $145 = $144 & 1;
   $146 = ($145<<24>>24)==(0);
   if ($146) {
    $$off0 = 0;
   } else {
    $147 = ((($140) + (($139*108)|0)|0) + 12|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ($148|0)==(0);
    $$off0 = $149;
   }
   $150 = (($lights$032) + 108|0);
   $151 = HEAP32[$150>>2]|0;
   $notlhs = ($151|0)==(0|0);
   $notrhs = ($139|0)!=(0);
   $or$cond$not = $notrhs | $notlhs;
   $brmerge = $or$cond$not | $$off0;
   do {
    if ($brmerge) {
     if ($notlhs) {
      $152 = ((($140) + (($139*108)|0)|0) + 72|0);
      $153 = HEAP32[$152>>2]|0;
      $154 = ($153|0)!=(1);
      $155 = ($143|0)==(2);
      $or$cond1 = $154 | $155;
      if (!($or$cond1)) {
       $156 = ((($140) + (($139*108)|0)|0) + 64|0);
       $157 = HEAP8[$156>>0]|0;
       $$not = ($157<<24>>24)!=(0);
       $brmerge2 = $$not | $$off0;
       if (!($brmerge2)) {
        HEAP32[$150>>2] = $141;
        $lastAutoAddLightIndex$1 = $lastAutoAddLightIndex$030;$lights$1 = $lights$032;
        break;
       }
      }
     }
     if ((($143|0) == 1)) {
      label = 54;
     } else if (!((($143|0) == 2))) {
      $158 = (($lights$032) + 112|0);
      $159 = HEAP32[$158>>2]|0;
      $160 = HEAP32[$136>>2]|0;
      $161 = ($159|0)<($160|0);
      if ($161) {
       label = 54;
      }
     }
     if ((label|0) == 54) {
      label = 0;
      $162 = $144 & 8;
      $163 = ($162<<24>>24)==(0);
      if ($163) {
       $164 = HEAP32[$57>>2]|0;
       $165 = (($164) + 4)|0;
       HEAP32[$57>>2] = $165;
       $166 = HEAP32[$60>>2]|0;
       $167 = $166 & 2147483647;
       $168 = ($167>>>0)<($165>>>0);
       do {
        if ($168) {
         $169 = ($166|0)>(-1);
         if ($169) {
          HEAP32[$60>>2] = $165;
          $170 = HEAP32[$dest>>2]|0;
          $171 = HEAP32[$137>>2]|0;
          HEAP32[$0>>2] = $171;
          ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
          $172 = (__Z16realloc_internalPvji10MemLabelIdiPKci($170,$165,1,$$byval_copy11,0,573920,370)|0);
          HEAP32[$dest>>2] = $172;
          $178 = $172;
          break;
         } else {
          $173 = HEAP32[$137>>2]|0;
          HEAP32[$0>>2] = $173;
          ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
          $174 = (__Z15malloc_internaljj10MemLabelIdiPKci($165,1,$$byval_copy11,0,573920,352)|0);
          $175 = HEAP32[$dest>>2]|0;
          $176 = HEAP32[$57>>2]|0;
          _memcpy(($174|0),($175|0),($176|0))|0;
          HEAP32[$60>>2] = $165;
          HEAP32[$dest>>2] = $174;
          $178 = $174;
          break;
         }
        } else {
         $$pre43 = HEAP32[$dest>>2]|0;
         $178 = $$pre43;
        }
       } while(0);
       $177 = (($178) + ($164)|0);
       HEAP32[$177>>2] = $141;
       $179 = HEAP32[$dest>>2]|0;
       $180 = (($179) + ($58)|0);
       $181 = (($179) + ($$sum)|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = (($182) + 1)|0;
       HEAP32[$181>>2] = $183;
       $184 = HEAP32[$136>>2]|0;
       $185 = ($183|0)!=($184|0);
       $186 = ($143|0)==(1);
       $or$cond3 = $185 | $186;
       $lastAutoAddLightIndex$0$i1$0 = $or$cond3 ? $lastAutoAddLightIndex$030 : $i1$027;
       $lastAutoAddLightIndex$1 = $lastAutoAddLightIndex$0$i1$0;$lights$1 = $180;
       break;
      }
     }
     if ($146) {
      $187 = ((($140) + (($139*108)|0)|0) + 72|0);
      $188 = HEAP32[$187>>2]|0;
      $189 = ($188|0)==(1);
      if (!($189)) {
       $190 = (($lights$032) + 116|0);
       $191 = HEAP32[$190>>2]|0;
       $192 = ($191|0)<(4);
       if ($192) {
        $193 = HEAP32[$57>>2]|0;
        $194 = (($193) + 4)|0;
        HEAP32[$57>>2] = $194;
        $195 = HEAP32[$60>>2]|0;
        $196 = $195 & 2147483647;
        $197 = ($196>>>0)<($194>>>0);
        do {
         if ($197) {
          $198 = ($195|0)>(-1);
          if ($198) {
           HEAP32[$60>>2] = $194;
           $199 = HEAP32[$dest>>2]|0;
           $200 = HEAP32[$137>>2]|0;
           HEAP32[$0>>2] = $200;
           ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
           $201 = (__Z16realloc_internalPvji10MemLabelIdiPKci($199,$194,1,$$byval_copy11,0,573920,370)|0);
           HEAP32[$dest>>2] = $201;
           $207 = $201;
           break;
          } else {
           $202 = HEAP32[$137>>2]|0;
           HEAP32[$0>>2] = $202;
           ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
           $203 = (__Z15malloc_internaljj10MemLabelIdiPKci($194,1,$$byval_copy11,0,573920,352)|0);
           $204 = HEAP32[$dest>>2]|0;
           $205 = HEAP32[$57>>2]|0;
           _memcpy(($203|0),($204|0),($205|0))|0;
           HEAP32[$60>>2] = $194;
           HEAP32[$dest>>2] = $203;
           $207 = $203;
           break;
          }
         } else {
          $$pre44 = HEAP32[$dest>>2]|0;
          $207 = $$pre44;
         }
        } while(0);
        $206 = (($207) + ($193)|0);
        HEAP32[$206>>2] = $141;
        $208 = HEAP32[$dest>>2]|0;
        $209 = (($208) + ($58)|0);
        $210 = (($208) + ($$sum17)|0);
        $211 = HEAP32[$210>>2]|0;
        $212 = (($211) + 1)|0;
        HEAP32[$210>>2] = $212;
        $lastAutoAddLightIndex$1 = $lastAutoAddLightIndex$030;$lights$1 = $209;
        break;
       }
      }
      $213 = HEAP32[$141>>2]|0;
      __ZL12AddLightToSHRK11VisibleNodeRK5LightP18ForwardLightsBlockf($node,$213,$lights$032,Math_fround(1.0));
      $lastAutoAddLightIndex$1 = $lastAutoAddLightIndex$030;$lights$1 = $lights$032;
     } else {
      $lastAutoAddLightIndex$1 = $lastAutoAddLightIndex$030;$lights$1 = $lights$032;
     }
    } else {
     $lastAutoAddLightIndex$1 = $lastAutoAddLightIndex$030;$lights$1 = $lights$032;
    }
   } while(0);
   $214 = (($i1$027) + 1)|0;
   $exitcond = ($214|0)==($$0|0);
   if ($exitcond) {
    $lastAutoAddLightIndex$0$lcssa = $lastAutoAddLightIndex$1;$lights$0$lcssa = $lights$1;
    break;
   } else {
    $i1$027 = $214;$lastAutoAddLightIndex$030 = $lastAutoAddLightIndex$1;$lights$032 = $lights$1;
   }
  }
 }
 $215 = HEAP8[$params>>0]|0;
 $216 = $215 & 1;
 $217 = ($216<<24>>24)==(0);
 $218 = HEAP32[$dest>>2]|0;
 $219 = (($218) + ($58)|0);
 $220 = (($218) + ($$sum)|0);
 $221 = HEAP32[$220>>2]|0;
 $222 = (($218) + ($$sum17)|0);
 $223 = HEAP32[$222>>2]|0;
 $224 = (($223) + ($221))|0;
 $225 = (($224) + -1)|0;
 $226 = (($218) + ($$sum19)|0);
 HEAPF32[$226>>2] = Math_fround(1.0);
 $227 = ($lastAutoAddLightIndex$0$lcssa|0)<(1);
 do {
  if ($227) {
   $lastVertexLightIndex$0$i = $225;$lights$0$i = $219;
  } else {
   $228 = (($$0) + -1)|0;
   $229 = ($228|0)>($lastAutoAddLightIndex$0$lcssa|0);
   if ($229) {
    $230 = (($lastAutoAddLightIndex$0$lcssa) + -1)|0;
    $231 = ((($culledLights$0) + ($230<<3)|0) + 4|0);
    $232 = Math_fround(HEAPF32[$231>>2]);
    $233 = ((($culledLights$0) + ($lastAutoAddLightIndex$0$lcssa<<3)|0) + 4|0);
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = (($lastAutoAddLightIndex$0$lcssa) + 1)|0;
    $236 = ((($culledLights$0) + ($235<<3)|0) + 4|0);
    $237 = Math_fround(HEAPF32[$236>>2]);
    $238 = Math_fround($232 - $237);
    $239 = (Math_fround(__Z21GetRenderModeSortBiasi(1)));
    $240 = !($238 >= $239);
    if ($240) {
     $241 = Math_fround($234 - $237);
     $242 = Math_fround($238 + Math_fround(0.00100000004749745130539));
     $243 = Math_fround($241 / $242);
     $244 = $243 < Math_fround(0.0);
     if ($244) {
      $246 = Math_fround(0.0);
     } else {
      $245 = $243 > Math_fround(1.0);
      $$$i$i1$i = $245 ? Math_fround(1.0) : $243;
      $246 = $$$i$i1$i;
     }
     HEAPF32[$226>>2] = $246;
     if ($217) {
      $247 = (($culledLights$0) + ($lastAutoAddLightIndex$0$lcssa<<3)|0);
      $248 = HEAP32[$247>>2]|0;
      $249 = HEAP32[$activeLights>>2]|0;
      $250 = (($249) + (($248*108)|0)|0);
      $251 = HEAP32[$250>>2]|0;
      $252 = (($251) + 216|0);
      $253 = HEAP32[$252>>2]|0;
      $254 = ($253|0)==(1);
      if ($254) {
       $289 = Math_fround(Math_fround(1.0) - $246);
       __ZL12AddLightToSHRK11VisibleNodeRK5LightP18ForwardLightsBlockf($node,$251,$219,$289);
       $lastVertexLightIndex$0$i = $225;$lights$0$i = $219;
       break;
      }
      $255 = HEAP32[$57>>2]|0;
      $256 = (($255) + 4)|0;
      HEAP32[$57>>2] = $256;
      $257 = HEAP32[$60>>2]|0;
      $258 = $257 & 2147483647;
      $259 = ($258>>>0)<($256>>>0);
      do {
       if ($259) {
        $260 = ($257|0)>(-1);
        if ($260) {
         HEAP32[$60>>2] = $256;
         $261 = HEAP32[$dest>>2]|0;
         $262 = (($dest) + 4|0);
         $263 = HEAP32[$262>>2]|0;
         HEAP32[$0>>2] = $263;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
         $264 = (__Z16realloc_internalPvji10MemLabelIdiPKci($261,$256,1,$$byval_copy11,0,573920,370)|0);
         HEAP32[$dest>>2] = $264;
         $271 = $264;
         break;
        } else {
         $265 = (($dest) + 4|0);
         $266 = HEAP32[$265>>2]|0;
         HEAP32[$0>>2] = $266;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
         $267 = (__Z15malloc_internaljj10MemLabelIdiPKci($256,1,$$byval_copy11,0,573920,352)|0);
         $268 = HEAP32[$dest>>2]|0;
         $269 = HEAP32[$57>>2]|0;
         _memcpy(($267|0),($268|0),($269|0))|0;
         HEAP32[$60>>2] = $256;
         HEAP32[$dest>>2] = $267;
         $271 = $267;
         break;
        }
       } else {
        $$pre18$i = HEAP32[$dest>>2]|0;
        $271 = $$pre18$i;
       }
      } while(0);
      $270 = (($271) + ($58)|0);
      $272 = (($271) + ($59)|0);
      $273 = (($271) + ($$sum)|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = (($271) + ($$sum17)|0);
      $276 = HEAP32[$275>>2]|0;
      $277 = (($276) + ($274))|0;
      $278 = (($274) + -1)|0;
      $279 = ($277|0)>($278|0);
      if ($279) {
       $i$017$in$i = $277;
       while(1) {
        $i$017$i = (($i$017$in$i) + -1)|0;
        $280 = (($272) + ($i$017$i<<2)|0);
        $281 = HEAP32[$280>>2]|0;
        $282 = (($272) + ($i$017$in$i<<2)|0);
        HEAP32[$282>>2] = $281;
        $283 = HEAP32[$273>>2]|0;
        $284 = ($i$017$in$i|0)>($283|0);
        if ($284) {
         $i$017$in$i = $i$017$i;
        } else {
         break;
        }
       }
       $$pre$i = HEAP32[$275>>2]|0;
       $286 = $$pre$i;
      } else {
       $286 = $276;
      }
      $285 = (($286) + 1)|0;
      HEAP32[$275>>2] = $285;
      $287 = ($286|0)>(3);
      if ($287) {
       $288 = (($224) + -2)|0;
       HEAP32[$275>>2] = 4;
       $lastVertexLightIndex$0$i = $288;$lights$0$i = $270;
      } else {
       $lastVertexLightIndex$0$i = $225;$lights$0$i = $270;
      }
     } else {
      $lastVertexLightIndex$0$i = $225;$lights$0$i = $219;
     }
    } else {
     $lastVertexLightIndex$0$i = $225;$lights$0$i = $219;
    }
   } else {
    $lastVertexLightIndex$0$i = $225;$lights$0$i = $219;
   }
  }
 } while(0);
 $290 = (($lights$0$i) + 116|0);
 $291 = HEAP32[$290>>2]|0;
 $292 = ($291|0)>(0);
 if ($292) {
  $293 = (($lights$0$i) + 124|0);
  HEAPF32[$293>>2] = Math_fround(1.0);
  $294 = ($lastVertexLightIndex$0$i|0)<(1);
  if (!($294)) {
   $295 = (($$0) + -1)|0;
   $296 = ($295|0)>($lastVertexLightIndex$0$i|0);
   if ($296) {
    $297 = (($lastVertexLightIndex$0$i) + -1)|0;
    $298 = ((($culledLights$0) + ($297<<3)|0) + 4|0);
    $299 = Math_fround(HEAPF32[$298>>2]);
    $300 = ((($culledLights$0) + ($lastVertexLightIndex$0$i<<3)|0) + 4|0);
    $301 = Math_fround(HEAPF32[$300>>2]);
    $302 = (($lastVertexLightIndex$0$i) + 1)|0;
    $303 = ((($culledLights$0) + ($302<<3)|0) + 4|0);
    $304 = Math_fround(HEAPF32[$303>>2]);
    $305 = Math_fround($299 - $304);
    $306 = (Math_fround(__Z21GetRenderModeSortBiasi(1)));
    $307 = !($305 >= $306);
    if ($307) {
     $308 = Math_fround($301 - $304);
     $309 = Math_fround($305 + Math_fround(0.00100000004749745130539));
     $310 = Math_fround($308 / $309);
     $311 = $310 < Math_fround(0.0);
     if ($311) {
      $$0$i$i7$i = Math_fround(0.0);
     } else {
      $312 = $310 > Math_fround(1.0);
      $$$i$i$i = $312 ? Math_fround(1.0) : $310;
      $$0$i$i7$i = $$$i$i$i;
     }
     HEAPF32[$293>>2] = $$0$i$i7$i;
    }
   }
  }
 }
 if (!($14)) {
  STACKTOP = sp;return;
 }
 dest=$$byval_copy11+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $313 = HEAP32[$3>>2]|0;
 $314 = (($node) + 64|0);
 $315 = (__Z25GetLightProbeCoefficientsP12BaseRendererRK4AABBR19SphericalHarmonics3($313,$314,$$byval_copy11)|0);
 if ($315) {
  $j$01$i = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $316 = (($$byval_copy11) + (($j$01$i*12)|0)|0);
  $317 = Math_fround(HEAPF32[$316>>2]);
  $318 = (($lights$0$lcssa) + (($j$01$i*12)|0)|0);
  $319 = Math_fround(HEAPF32[$318>>2]);
  $320 = Math_fround($317 + $319);
  HEAPF32[$318>>2] = $320;
  $321 = ((($$byval_copy11) + (($j$01$i*12)|0)|0) + 4|0);
  $322 = Math_fround(HEAPF32[$321>>2]);
  $323 = ((($lights$0$lcssa) + (($j$01$i*12)|0)|0) + 4|0);
  $324 = Math_fround(HEAPF32[$323>>2]);
  $325 = Math_fround($322 + $324);
  HEAPF32[$323>>2] = $325;
  $326 = ((($$byval_copy11) + (($j$01$i*12)|0)|0) + 8|0);
  $327 = Math_fround(HEAPF32[$326>>2]);
  $328 = ((($lights$0$lcssa) + (($j$01$i*12)|0)|0) + 8|0);
  $329 = Math_fround(HEAPF32[$328>>2]);
  $330 = Math_fround($327 + $329);
  HEAPF32[$328>>2] = $330;
  $331 = (($j$01$i) + 1)|0;
  $exitcond$i = ($331|0)==(9);
  if ($exitcond$i) {
   break;
  } else {
   $j$01$i = $331;
  }
 }
 STACKTOP = sp;return;
}
function __ZL12AddLightToSHRK11VisibleNodeRK5LightP18ForwardLightsBlockf($node,$source,$lights,$blend) {
 $node = $node|0;
 $source = $source|0;
 $lights = $lights|0;
 $blend = Math_fround($blend);
 var $$0$i$i$i$i = Math_fround(0), $$0$i$i$i1$i = Math_fround(0), $$0$i$i$i121$i = Math_fround(0), $$0$i$i$i18$i = Math_fround(0), $$0$i1$i$i20$i = Math_fround(0), $$0$i1$i$i523$i = Math_fround(0), $$0$i3$i$i$i = Math_fround(0), $$0$i3$i$i19$i = Math_fround(0), $$0$i3$i$i3$i = Math_fround(0), $$0$i3$i$i322$i = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert10 = 0, $$phi$trans$insert12 = 0, $$pre = 0, $$pre11 = Math_fround(0), $$pre13 = Math_fround(0), $$pre9 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0);
 var $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0);
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0);
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0);
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0);
 var $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0);
 var $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0);
 var $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = 0;
 var $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0);
 var $exitcond = 0, $i$07 = 0, $lum$0$i = Math_fround(0), $shB = 0, $shG = 0, $shR = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 120|0;
 $1 = sp;
 $shR = sp + 12|0;
 $shG = sp + 48|0;
 $shB = sp + 84|0;
 $2 = (($source) + 216|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1);
 do {
  if ($4) {
   $36 = (($source) + 24|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($37)|0);
   HEAPF32[$1>>2] = Math_fround(0.0);
   $39 = (($1) + 4|0);
   HEAPF32[$39>>2] = Math_fround(0.0);
   $40 = (($1) + 8|0);
   HEAPF32[$40>>2] = Math_fround(-1.0);
   __ZNK9Transform18TransformDirectionERK8Vector3f($0,$38,$1);
   $41 = Math_fround(HEAPF32[$0>>2]);
   $42 = (($0) + 4|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = (($0) + 8|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $$pre = HEAP32[$2>>2]|0;
   $257 = $45;$258 = $43;$259 = $41;$49 = $$pre;
   label = 6;
  } else {
   $5 = (($source) + 104|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = (($node) + 64|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = Math_fround($6 - $8);
   $10 = (($source) + 108|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = (($node) + 68|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = Math_fround($11 - $13);
   $15 = (($source) + 112|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = (($node) + 72|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = Math_fround($16 - $18);
   $20 = Math_fround($9 * $9);
   $21 = Math_fround($14 * $14);
   $22 = Math_fround($20 + $21);
   $23 = Math_fround($19 * $19);
   $24 = Math_fround($22 + $23);
   $25 = (Math_fround(Math_sqrt((Math_fround($24)))));
   $26 = Math_fround(HEAPF32[616648>>2]);
   $27 = $25 > $26;
   if ($27) {
    $28 = Math_fround($9 / $25);
    $29 = Math_fround($14 / $25);
    $30 = Math_fround($19 / $25);
    $257 = $30;$258 = $29;$259 = $28;$49 = $3;
    label = 6;
    break;
   } else {
    $31 = Math_fround(HEAPF32[616680>>2]);
    $32 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
    $33 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
    $34 = (($source) + 184|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $103 = $35;$260 = $31;$261 = $32;$262 = $33;
    label = 25;
    break;
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $46 = (($source) + 184|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = ($49|0)==(1);
  if ($48) {
   $50 = (__Z19GetActiveColorSpacev()|0);
   $51 = ($50|0)==(1);
   $52 = (($source) + 140|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   do {
    if ($51) {
     $54 = !($53 <= Math_fround(0.0404499992728233337402));
     do {
      if ($54) {
       $56 = $53 < Math_fround(1.0);
       if ($56) {
        $57 = Math_fround($53 + Math_fround(0.054999999701976776123));
        $58 = Math_fround($57 / Math_fround(1.05499994754791259766));
        $59 = (Math_fround(+(Math_pow((+$58),2.40000009536743164063))));
        $$0$i$i$i1$i = $59;
        break;
       } else {
        $60 = (Math_fround(+(Math_pow((+$53),2.40000009536743164063))));
        $$0$i$i$i1$i = $60;
        break;
       }
      } else {
       $55 = Math_fround($53 / Math_fround(12.9200000762939453125));
       $$0$i$i$i1$i = $55;
      }
     } while(0);
     $61 = (($source) + 144|0);
     $62 = Math_fround(HEAPF32[$61>>2]);
     $63 = !($62 <= Math_fround(0.0404499992728233337402));
     do {
      if ($63) {
       $65 = $62 < Math_fround(1.0);
       if ($65) {
        $66 = Math_fround($62 + Math_fround(0.054999999701976776123));
        $67 = Math_fround($66 / Math_fround(1.05499994754791259766));
        $68 = (Math_fround(+(Math_pow((+$67),2.40000009536743164063))));
        $$0$i3$i$i3$i = $68;
        break;
       } else {
        $69 = (Math_fround(+(Math_pow((+$62),2.40000009536743164063))));
        $$0$i3$i$i3$i = $69;
        break;
       }
      } else {
       $64 = Math_fround($62 / Math_fround(12.9200000762939453125));
       $$0$i3$i$i3$i = $64;
      }
     } while(0);
     $70 = (($source) + 148|0);
     $71 = Math_fround(HEAPF32[$70>>2]);
     $72 = !($71 <= Math_fround(0.0404499992728233337402));
     if (!($72)) {
      $73 = Math_fround($71 / Math_fround(12.9200000762939453125));
      $$0$i$i$i121$i = $$0$i$i$i1$i;$$0$i1$i$i523$i = $73;$$0$i3$i$i322$i = $$0$i3$i$i3$i;
      break;
     }
     $74 = $71 < Math_fround(1.0);
     if ($74) {
      $75 = Math_fround($71 + Math_fround(0.054999999701976776123));
      $76 = Math_fround($75 / Math_fround(1.05499994754791259766));
      $77 = (Math_fround(+(Math_pow((+$76),2.40000009536743164063))));
      $$0$i$i$i121$i = $$0$i$i$i1$i;$$0$i1$i$i523$i = $77;$$0$i3$i$i322$i = $$0$i3$i$i3$i;
      break;
     } else {
      $78 = (Math_fround(+(Math_pow((+$71),2.40000009536743164063))));
      $$0$i$i$i121$i = $$0$i$i$i1$i;$$0$i1$i$i523$i = $78;$$0$i3$i$i322$i = $$0$i3$i$i3$i;
      break;
     }
    } else {
     $79 = (($source) + 144|0);
     $80 = Math_fround(HEAPF32[$79>>2]);
     $81 = (($source) + 148|0);
     $82 = Math_fround(HEAPF32[$81>>2]);
     $$0$i$i$i121$i = $53;$$0$i1$i$i523$i = $82;$$0$i3$i$i322$i = $80;
    }
   } while(0);
   $83 = Math_fround($47 * $$0$i$i$i121$i);
   $84 = Math_fround($47 * $$0$i3$i$i322$i);
   $85 = Math_fround($47 * $$0$i1$i$i523$i);
   $166 = $83;$168 = $84;$170 = $85;$172 = $258;$174 = $257;$176 = $259;
  } else {
   $103 = $47;$260 = $259;$261 = $258;$262 = $257;
   label = 25;
  }
 }
 if ((label|0) == 25) {
  $86 = (($node) + 100|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = (($node) + 104|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = (($node) + 108|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($87 * $87);
  $93 = Math_fround($89 * $89);
  $94 = Math_fround($92 + $93);
  $95 = Math_fround($91 * $91);
  $96 = Math_fround($94 + $95);
  $97 = (($source) + 188|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = Math_fround($98 * $98);
  $100 = $96 > $99;
  if ($100) {
   $101 = Math_fround($99 / $96);
   $102 = Math_fround($103 * $101);
   $lum$0$i = $102;
  } else {
   $lum$0$i = $103;
  }
  $104 = (($node) + 64|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = (($node) + 68|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = (($node) + 72|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($source) + 104|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround($105 - $111);
  $113 = (($source) + 108|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = Math_fround($107 - $114);
  $116 = (($source) + 112|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = Math_fround($109 - $117);
  $119 = Math_fround($112 * $112);
  $120 = Math_fround($115 * $115);
  $121 = Math_fround($119 + $120);
  $122 = Math_fround($118 * $118);
  $123 = Math_fround($121 + $122);
  $124 = $123 < $96;
  $125 = $124 ? $96 : $123;
  $126 = (Math_fround(__ZNK5Light15AttenuateApproxEf($source,$125)));
  $127 = Math_fround($lum$0$i * $126);
  $128 = (__Z19GetActiveColorSpacev()|0);
  $129 = ($128|0)==(1);
  $130 = (($source) + 140|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  do {
   if ($129) {
    $132 = !($131 <= Math_fround(0.0404499992728233337402));
    do {
     if ($132) {
      $134 = $131 < Math_fround(1.0);
      if ($134) {
       $135 = Math_fround($131 + Math_fround(0.054999999701976776123));
       $136 = Math_fround($135 / Math_fround(1.05499994754791259766));
       $137 = (Math_fround(+(Math_pow((+$136),2.40000009536743164063))));
       $$0$i$i$i$i = $137;
       break;
      } else {
       $138 = (Math_fround(+(Math_pow((+$131),2.40000009536743164063))));
       $$0$i$i$i$i = $138;
       break;
      }
     } else {
      $133 = Math_fround($131 / Math_fround(12.9200000762939453125));
      $$0$i$i$i$i = $133;
     }
    } while(0);
    $139 = (($source) + 144|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = !($140 <= Math_fround(0.0404499992728233337402));
    do {
     if ($141) {
      $143 = $140 < Math_fround(1.0);
      if ($143) {
       $144 = Math_fround($140 + Math_fround(0.054999999701976776123));
       $145 = Math_fround($144 / Math_fround(1.05499994754791259766));
       $146 = (Math_fround(+(Math_pow((+$145),2.40000009536743164063))));
       $$0$i3$i$i$i = $146;
       break;
      } else {
       $147 = (Math_fround(+(Math_pow((+$140),2.40000009536743164063))));
       $$0$i3$i$i$i = $147;
       break;
      }
     } else {
      $142 = Math_fround($140 / Math_fround(12.9200000762939453125));
      $$0$i3$i$i$i = $142;
     }
    } while(0);
    $148 = (($source) + 148|0);
    $149 = Math_fround(HEAPF32[$148>>2]);
    $150 = !($149 <= Math_fround(0.0404499992728233337402));
    if (!($150)) {
     $151 = Math_fround($149 / Math_fround(12.9200000762939453125));
     $$0$i$i$i18$i = $$0$i$i$i$i;$$0$i1$i$i20$i = $151;$$0$i3$i$i19$i = $$0$i3$i$i$i;
     break;
    }
    $152 = $149 < Math_fround(1.0);
    if ($152) {
     $153 = Math_fround($149 + Math_fround(0.054999999701976776123));
     $154 = Math_fround($153 / Math_fround(1.05499994754791259766));
     $155 = (Math_fround(+(Math_pow((+$154),2.40000009536743164063))));
     $$0$i$i$i18$i = $$0$i$i$i$i;$$0$i1$i$i20$i = $155;$$0$i3$i$i19$i = $$0$i3$i$i$i;
     break;
    } else {
     $156 = (Math_fround(+(Math_pow((+$149),2.40000009536743164063))));
     $$0$i$i$i18$i = $$0$i$i$i$i;$$0$i1$i$i20$i = $156;$$0$i3$i$i19$i = $$0$i3$i$i$i;
     break;
    }
   } else {
    $157 = (($source) + 144|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = (($source) + 148|0);
    $160 = Math_fround(HEAPF32[$159>>2]);
    $$0$i$i$i18$i = $131;$$0$i1$i$i20$i = $160;$$0$i3$i$i19$i = $158;
   }
  } while(0);
  $161 = Math_fround($127 * $$0$i$i$i18$i);
  $162 = Math_fround($127 * $$0$i3$i$i19$i);
  $163 = Math_fround($127 * $$0$i1$i$i20$i);
  $166 = $161;$168 = $162;$170 = $163;$172 = $261;$174 = $262;$176 = $260;
 }
 $164 = Math_fround($blend * Math_fround(2.0));
 $165 = Math_fround($164 * $166);
 $167 = Math_fround($164 * $168);
 $169 = Math_fround($164 * $170);
 $171 = Math_fround($172 * Math_fround(-0.488602519035339355469));
 $173 = Math_fround($174 * Math_fround(0.488602519035339355469));
 $175 = Math_fround($176 * Math_fround(-0.488602519035339355469));
 $177 = Math_fround($172 * $176);
 $178 = Math_fround($177 * Math_fround(1.09254848957061767578));
 $179 = Math_fround($174 * $172);
 $180 = Math_fround($179 * Math_fround(-1.09254848957061767578));
 $181 = Math_fround($174 * $174);
 $182 = Math_fround($181 + Math_fround(-0.333333343267440795898));
 $183 = Math_fround($182 * Math_fround(0.94617468118667602539));
 $184 = Math_fround($174 * $176);
 $185 = Math_fround($184 * Math_fround(-1.09254848957061767578));
 $186 = Math_fround($176 * $176);
 $187 = Math_fround($172 * $172);
 $188 = Math_fround($186 - $187);
 $189 = Math_fround($188 * Math_fround(0.546274244785308837891));
 $190 = Math_fround($165 * Math_fround(2.95679306983947753906));
 $191 = Math_fround($167 * Math_fround(2.95679306983947753906));
 $192 = Math_fround($169 * Math_fround(2.95679306983947753906));
 $193 = Math_fround($190 * Math_fround(0.282094806432723999023));
 HEAPF32[$shR>>2] = $193;
 $194 = Math_fround($191 * Math_fround(0.282094806432723999023));
 HEAPF32[$shG>>2] = $194;
 $195 = Math_fround($192 * Math_fround(0.282094806432723999023));
 HEAPF32[$shB>>2] = $195;
 $196 = Math_fround($171 * $190);
 $197 = (($shR) + 4|0);
 HEAPF32[$197>>2] = $196;
 $198 = Math_fround($171 * $191);
 $199 = (($shG) + 4|0);
 HEAPF32[$199>>2] = $198;
 $200 = Math_fround($171 * $192);
 $201 = (($shB) + 4|0);
 HEAPF32[$201>>2] = $200;
 $202 = Math_fround($173 * $190);
 $203 = (($shR) + 8|0);
 HEAPF32[$203>>2] = $202;
 $204 = Math_fround($173 * $191);
 $205 = (($shG) + 8|0);
 HEAPF32[$205>>2] = $204;
 $206 = Math_fround($173 * $192);
 $207 = (($shB) + 8|0);
 HEAPF32[$207>>2] = $206;
 $208 = Math_fround($175 * $190);
 $209 = (($shR) + 12|0);
 HEAPF32[$209>>2] = $208;
 $210 = Math_fround($175 * $191);
 $211 = (($shG) + 12|0);
 HEAPF32[$211>>2] = $210;
 $212 = Math_fround($175 * $192);
 $213 = (($shB) + 12|0);
 HEAPF32[$213>>2] = $212;
 $214 = Math_fround($178 * $190);
 $215 = (($shR) + 16|0);
 HEAPF32[$215>>2] = $214;
 $216 = Math_fround($178 * $191);
 $217 = (($shG) + 16|0);
 HEAPF32[$217>>2] = $216;
 $218 = Math_fround($178 * $192);
 $219 = (($shB) + 16|0);
 HEAPF32[$219>>2] = $218;
 $220 = Math_fround($180 * $190);
 $221 = (($shR) + 20|0);
 HEAPF32[$221>>2] = $220;
 $222 = Math_fround($180 * $191);
 $223 = (($shG) + 20|0);
 HEAPF32[$223>>2] = $222;
 $224 = Math_fround($180 * $192);
 $225 = (($shB) + 20|0);
 HEAPF32[$225>>2] = $224;
 $226 = Math_fround($183 * $190);
 $227 = (($shR) + 24|0);
 HEAPF32[$227>>2] = $226;
 $228 = Math_fround($183 * $191);
 $229 = (($shG) + 24|0);
 HEAPF32[$229>>2] = $228;
 $230 = Math_fround($183 * $192);
 $231 = (($shB) + 24|0);
 HEAPF32[$231>>2] = $230;
 $232 = Math_fround($185 * $190);
 $233 = (($shR) + 28|0);
 HEAPF32[$233>>2] = $232;
 $234 = Math_fround($185 * $191);
 $235 = (($shG) + 28|0);
 HEAPF32[$235>>2] = $234;
 $236 = Math_fround($185 * $192);
 $237 = (($shB) + 28|0);
 HEAPF32[$237>>2] = $236;
 $238 = Math_fround($189 * $190);
 $239 = (($shR) + 32|0);
 HEAPF32[$239>>2] = $238;
 $240 = Math_fround($189 * $191);
 $241 = (($shG) + 32|0);
 HEAPF32[$241>>2] = $240;
 $242 = Math_fround($189 * $192);
 $243 = (($shB) + 32|0);
 HEAPF32[$243>>2] = $242;
 $247 = $193;$251 = $194;$255 = $195;$i$07 = 0;
 while(1) {
  $244 = (($lights) + (($i$07*12)|0)|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = Math_fround($247 + $245);
  HEAPF32[$244>>2] = $246;
  $248 = (($244) + 4|0);
  $249 = Math_fround(HEAPF32[$248>>2]);
  $250 = Math_fround($251 + $249);
  HEAPF32[$248>>2] = $250;
  $252 = (($244) + 8|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = Math_fround($255 + $253);
  HEAPF32[$252>>2] = $254;
  $256 = (($i$07) + 1)|0;
  $exitcond = ($256|0)==(9);
  if ($exitcond) {
   break;
  }
  $$phi$trans$insert = (($shR) + ($256<<2)|0);
  $$pre9 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$phi$trans$insert10 = (($shG) + ($256<<2)|0);
  $$pre11 = Math_fround(HEAPF32[$$phi$trans$insert10>>2]);
  $$phi$trans$insert12 = (($shB) + ($256<<2)|0);
  $$pre13 = Math_fround(HEAPF32[$$phi$trans$insert12>>2]);
  $247 = $$pre9;$251 = $$pre11;$255 = $$pre13;$i$07 = $256;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIP5Light13stl_allocatorIS2_L18MemLabelIdentifier44ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 2;
  HEAP32[$0>>2] = 44;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,573920,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<2)|0);
 $24 = (($23) + ($$0$i3<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$__x>>2]|0;
  HEAP32[$22>>2] = $26;
 }
 $27 = (($23) + ($8<<2)|0);
 $28 = HEAP32[$this>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = $29;
 $31 = $28;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $$sum1 = (($7) - ($33))|0;
 $34 = (($23) + ($$sum1<<2)|0);
 _memcpy(($34|0),($28|0),($32|0))|0;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $34;
 HEAP32[$1>>2] = $27;
 HEAP32[$10>>2] = $24;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN11LightProbes13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z25RegisterClass_LightProbesv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(258,100,101,0,102);
 STACKTOP = sp;return;
}
function __ZN11LightProbes13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 11;
 dest=$3+0|0; src=574032+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 11|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,258,130,($0|0),156,(2377|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN11LightProbes15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11LightProbes12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11LightProbes7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(156,$$byval_copy2,1,16,574056,39)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1685,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((573928 + 8|0));
  $6 = (($3) + 28|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 36|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 40|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 32|0);
  HEAP32[$9>>2] = 61;
  $10 = (($3) + 44|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 52|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 56|0);
  HEAP32[$12>>2] = 0;
  $13 = (($3) + 48|0);
  HEAP32[$13>>2] = 61;
  $14 = HEAP32[628504>>2]|0;
  $15 = (($3) + 60|0);
  HEAP32[$15>>2] = 0;
  $16 = (($3) + 64|0);
  HEAP32[$16>>2] = $14;
  $17 = (($3) + 68|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 72|0);
  HEAP32[$18>>2] = 0;
  $19 = HEAP32[628504>>2]|0;
  $20 = (($3) + 76|0);
  HEAP32[$20>>2] = 0;
  $21 = (($3) + 80|0);
  HEAP32[$21>>2] = $19;
  $22 = (($3) + 84|0);
  HEAP32[$22>>2] = 0;
  $23 = (($3) + 88|0);
  HEAP32[$23>>2] = 0;
  $24 = (($3) + 96|0);
  HEAP32[$24>>2] = 0;
  $25 = (($3) + 100|0);
  HEAP32[$25>>2] = 0;
  $26 = (($3) + 104|0);
  HEAP32[$26>>2] = 0;
  $27 = (($3) + 112|0);
  $28 = (($3) + 132|0);
  HEAP32[$28>>2] = 0;
  $29 = (($3) + 136|0);
  HEAP32[$29>>2] = 0;
  $30 = (($3) + 128|0);
  ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;
  HEAP32[$30>>2] = 61;
  $31 = (($3) + 140|0);
  HEAP32[$31>>2] = 0;
  $32 = (($3) + 148|0);
  HEAP32[$32>>2] = 0;
  $33 = (($3) + 152|0);
  HEAP32[$33>>2] = 0;
  $34 = (($3) + 144|0);
  HEAP32[$34>>2] = 61;
  STACKTOP = sp;return ($3|0);
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(574056|0),39);
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch(0|0)|0;
  $40 = tempRet0;
  ___clang_call_terminate($39);
  // unreachable;
 } else {
  ___resumeException($35|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK11LightProbes25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 258;
}
function __ZN11LightProbes23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $p$i$i$i$i = 0, $size$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $size$i$i$i$i$i = sp + 48|0;
 $p$i$i$i$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574048,574032,$this,0);
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN13ProxyTransfer8TransferIN11LightProbes14LightProbeDataEEEvRT_PKc17TransferMetaFlags($transfer,$0,574064,0);
 $1 = (($this) + 140|0);
 $2 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574072,$2,$1,0);
 dest=$p$i$i$i$i+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,574872,574872,$size$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574096,574880,$p$i$i$i$i,0);
 __ZN11LightProbes19SHCoefficientsBaked8TransferI13ProxyTransferEEvRT_($p$i$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11LightProbes23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574048,574032,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN11LightProbes8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11LightProbes23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11TetrahedronLj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 60|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI13ProbeSetIndexLj8EEEEvRT_17TransferMetaFlags($transfer,$2,0);
 $3 = (($this) + 76|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($transfer,$3,0);
 $4 = (($this) + 92|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapI7Hash128iNSt3__14lessIS3_EE13stl_allocatorINS4_4pairIS3_iEEL18MemLabelIdentifier72ELi16EEEEEvRT_17TransferMetaFlags($transfer,$4,0);
 $5 = (($this) + 140|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EEEEvRT_17TransferMetaFlags($transfer,$5,0);
 STACKTOP = sp;return;
}
function __ZN11LightProbes23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11TetrahedronLj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 60|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI13ProbeSetIndexLj8EEEEvRT_17TransferMetaFlags($transfer,$2,0);
 $3 = (($this) + 76|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($transfer,$3,0);
 $4 = (($this) + 92|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapI7Hash128iNSt3__14lessIS3_EE13stl_allocatorINS4_4pairIS3_iEEL18MemLabelIdentifier72ELi16EEEEEvRT_17TransferMetaFlags($transfer,$4,0);
 $5 = (($this) + 140|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EEEEvRT_17TransferMetaFlags($transfer,$5,0);
 STACKTOP = sp;return;
}
function __ZN11LightProbes23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i = sp;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN11LightProbes14LightProbeData8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size$i$i$i$i$i$i>>2] = $2;
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size$i$i$i$i$i$i,4);
 }
 $9 = (($this) + 140|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$1>>2]|0;
 $12 = (($10) + (($11*48)|0)|0);
 $13 = ($11|0)==(0);
 if ($13) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i$i$i$i = $10;
 }
 while(1) {
  __ZN11LightProbes19SHCoefficientsBaked8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i$i$i$i,$transfer);
  $14 = (($i$01$i$i$i$i$i$i) + 48|0);
  $15 = ($14|0)==($12|0);
  if ($15) {
   break;
  } else {
   $i$01$i$i$i$i$i$i = $14;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11LightProbes23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZNK11LightProbes15GetCoefficientsEjfPf($this,$index,$indirectLightScale,$outCoeffs) {
 $this = $this|0;
 $index = $index|0;
 $indirectLightScale = Math_fround($indirectLightScale);
 $outCoeffs = $outCoeffs|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0;
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0;
 var $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($index>>>0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + (($index*48)|0)|0);
 $6 = (($this) + 140|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + (($index*48)|0)|0);
 $9 = Math_fround(HEAPF32[$5>>2]);
 $10 = Math_fround($9 * $indirectLightScale);
 $11 = Math_fround(HEAPF32[$8>>2]);
 $12 = Math_fround($10 + $11);
 $13 = Math_fround($12 * Math_fround(3.54490780830383300781));
 HEAPF32[$outCoeffs>>2] = $13;
 $14 = ((($4) + (($index*48)|0)|0) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $indirectLightScale);
 $17 = ((($7) + (($index*48)|0)|0) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 + $18);
 $20 = Math_fround($19 * Math_fround(3.54490780830383300781));
 $21 = (($outCoeffs) + 4|0);
 HEAPF32[$21>>2] = $20;
 $22 = ((($4) + (($index*48)|0)|0) + 32|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $indirectLightScale);
 $25 = ((($7) + (($index*48)|0)|0) + 32|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($24 + $26);
 $28 = Math_fround($27 * Math_fround(3.54490780830383300781));
 $29 = (($outCoeffs) + 8|0);
 HEAPF32[$29>>2] = $28;
 $30 = ((($4) + (($index*48)|0)|0) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $indirectLightScale);
 $33 = ((($7) + (($index*48)|0)|0) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($32 + $34);
 $36 = Math_fround($35 * Math_fround(-3.06998038291931152344));
 $37 = (($outCoeffs) + 12|0);
 HEAPF32[$37>>2] = $36;
 $38 = ((($4) + (($index*48)|0)|0) + 24|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $indirectLightScale);
 $41 = ((($7) + (($index*48)|0)|0) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 + $42);
 $44 = Math_fround($43 * Math_fround(-3.06998038291931152344));
 $45 = (($outCoeffs) + 16|0);
 HEAPF32[$45>>2] = $44;
 $46 = ((($4) + (($index*48)|0)|0) + 40|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 * $indirectLightScale);
 $49 = ((($7) + (($index*48)|0)|0) + 40|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($48 + $50);
 $52 = Math_fround($51 * Math_fround(-3.06998038291931152344));
 $53 = (($outCoeffs) + 20|0);
 HEAPF32[$53>>2] = $52;
 $54 = ((($4) + (($index*48)|0)|0) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * $indirectLightScale);
 $57 = ((($7) + (($index*48)|0)|0) + 12|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($56 + $58);
 $60 = Math_fround($59 * Math_fround(3.06998038291931152344));
 $61 = (($outCoeffs) + 24|0);
 HEAPF32[$61>>2] = $60;
 $62 = ((($4) + (($index*48)|0)|0) + 28|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $indirectLightScale);
 $65 = ((($7) + (($index*48)|0)|0) + 28|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($64 + $66);
 $68 = Math_fround($67 * Math_fround(3.06998038291931152344));
 $69 = (($outCoeffs) + 28|0);
 HEAPF32[$69>>2] = $68;
 $70 = ((($4) + (($index*48)|0)|0) + 44|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $indirectLightScale);
 $73 = ((($7) + (($index*48)|0)|0) + 44|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($72 + $74);
 $76 = Math_fround($75 * Math_fround(3.06998038291931152344));
 $77 = (($outCoeffs) + 32|0);
 HEAPF32[$77>>2] = $76;
 $78 = ((($4) + (($index*48)|0)|0) + 4|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($79 * $indirectLightScale);
 $81 = ((($7) + (($index*48)|0)|0) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($80 + $82);
 $84 = Math_fround($83 * Math_fround(-3.06998038291931152344));
 $85 = (($outCoeffs) + 36|0);
 HEAPF32[$85>>2] = $84;
 $86 = ((($4) + (($index*48)|0)|0) + 20|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($87 * $indirectLightScale);
 $89 = ((($7) + (($index*48)|0)|0) + 20|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($88 + $90);
 $92 = Math_fround($91 * Math_fround(-3.06998038291931152344));
 $93 = (($outCoeffs) + 40|0);
 HEAPF32[$93>>2] = $92;
 $94 = ((($4) + (($index*48)|0)|0) + 36|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($95 * $indirectLightScale);
 $97 = ((($7) + (($index*48)|0)|0) + 36|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($96 + $98);
 $100 = Math_fround($99 * Math_fround(-3.06998038291931152344));
 $101 = (($outCoeffs) + 44|0);
 HEAPF32[$101>>2] = $100;
 $102 = (($outCoeffs) + 48|0);
 dest=$102+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK11LightProbes25GetInterpolatedLightProbeERK8Vector3ffRiPfR8Vector4fRf($this,$position,$indirectLightingScale,$tetIndex,$coefficients,$weights,$t) {
 $this = $this|0;
 $position = $position|0;
 $indirectLightingScale = Math_fround($indirectLightingScale);
 $tetIndex = $tetIndex|0;
 $coefficients = $coefficients|0;
 $weights = $weights|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond3$i = 0, $i$02$i = 0, $j$01$i = 0, $or$cond = 0, $steps = 0, $tempCoefficients$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $tempCoefficients$i = sp + 4|0;
 $steps = sp;
 dest=$coefficients+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($this) + 28|0);
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($this) + 84|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   __ZNK11LightProbes14LightProbeData33GetLightProbeInterpolationWeightsERK8Vector3fRiR8Vector4fRfS4_($0,$position,$tetIndex,$weights,$t,$steps);
   $7 = HEAP32[$tetIndex>>2]|0;
   $8 = ($7|0)>(-1);
   $9 = ($7|0)<($2|0);
   $or$cond = $8 & $9;
   if (!($or$cond)) {
    STACKTOP = sp;return;
   }
   $10 = (($this) + 28|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($11) + (($7*80)|0)|0) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 >> 31;
   $15 = (($14) + 4)|0;
   $16 = ($15|0)>(0);
   if (!($16)) {
    STACKTOP = sp;return;
   }
   $i$02$i = 0;
   while(1) {
    $17 = ((($11) + (($7*80)|0)|0) + ($i$02$i<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($weights) + ($i$02$i<<2)|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    (__ZNK11LightProbes15GetCoefficientsEjfPf($this,$18,$indirectLightingScale,$tempCoefficients$i)|0);
    $j$01$i = 0;
    while(1) {
     $21 = (($tempCoefficients$i) + ($j$01$i<<2)|0);
     $22 = Math_fround(HEAPF32[$21>>2]);
     $23 = Math_fround($20 * $22);
     $24 = (($coefficients) + ($j$01$i<<2)|0);
     $25 = Math_fround(HEAPF32[$24>>2]);
     $26 = Math_fround($25 + $23);
     HEAPF32[$24>>2] = $26;
     $27 = (($j$01$i) + 1)|0;
     $exitcond$i = ($27|0)==(27);
     if ($exitcond$i) {
      break;
     } else {
      $j$01$i = $27;
     }
    }
    $28 = (($i$02$i) + 1)|0;
    $exitcond3$i = ($28|0)==($15|0);
    if ($exitcond3$i) {
     break;
    } else {
     $i$02$i = $28;
    }
   }
   STACKTOP = sp;return;
  }
 }
 HEAP32[$tetIndex>>2] = -1;
 ;HEAP32[$weights+0>>2]=0|0;HEAP32[$weights+4>>2]=0|0;HEAP32[$weights+8>>2]=0|0;HEAP32[$weights+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNK11LightProbes14LightProbeData33GetLightProbeInterpolationWeightsERK8Vector3fRiR8Vector4fRfS4_($this,$position,$tetIndex,$weights,$t,$steps) {
 $this = $this|0;
 $position = $position|0;
 $tetIndex = $tetIndex|0;
 $weights = $weights|0;
 $t = $t|0;
 $steps = $steps|0;
 var $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0;
 var $99 = Math_fround(0), $or$cond = 0, $or$cond17 = 0, $or$cond18 = 0, $positions = 0, $prev$08 = 0, $prevprev$07 = 0, $prevprev$07$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $positions = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$tetIndex>>2]|0;
 $3 = ($2|0)>(-1);
 $4 = ($2|0)<($1|0);
 $or$cond = $3 & $4;
 if (!($or$cond)) {
  HEAP32[$tetIndex>>2] = 0;
 }
 HEAP32[$steps>>2] = 0;
 $5 = (($this) + 16|0);
 $6 = (($weights) + 12|0);
 $7 = ($1|0)>(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 56|0);
 $9 = (($this) + 48|0);
 $10 = (($positions) + 4|0);
 $11 = (($positions) + 8|0);
 $12 = (($positions) + 12|0);
 $13 = (($position) + 4|0);
 $14 = (($position) + 8|0);
 $15 = (($weights) + 4|0);
 $16 = (($weights) + 8|0);
 $prev$08 = -1;$prevprev$07 = -1;
 while(1) {
  $17 = HEAP32[$tetIndex>>2]|0;
  $18 = HEAP32[$this>>2]|0;
  $19 = (($18) + (($17*80)|0)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$8>>2]|0;
  $22 = ($21>>>0)>($20>>>0);
  if ($22) {
   $23 = HEAP32[$9>>2]|0;
   $24 = (($23) + (($20*12)|0)|0);
   HEAP32[$positions>>2] = $24;
  }
  $25 = ((($18) + (($17*80)|0)|0) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($21>>>0)>($26>>>0);
  if ($27) {
   $28 = HEAP32[$9>>2]|0;
   $29 = (($28) + (($26*12)|0)|0);
   HEAP32[$10>>2] = $29;
  }
  $30 = ((($18) + (($17*80)|0)|0) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($21>>>0)>($31>>>0);
  if ($32) {
   $33 = HEAP32[$9>>2]|0;
   $34 = (($33) + (($31*12)|0)|0);
   HEAP32[$11>>2] = $34;
  }
  $35 = ((($18) + (($17*80)|0)|0) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($21>>>0)>($36>>>0);
  if ($37) {
   $38 = HEAP32[$9>>2]|0;
   $39 = (($38) + (($36*12)|0)|0);
   HEAP32[$12>>2] = $39;
  }
  $40 = ($36|0)>(-1);
  if ($40) {
   $41 = HEAP32[$12>>2]|0;
   $42 = Math_fround(HEAPF32[$position>>2]);
   $43 = Math_fround(HEAPF32[$41>>2]);
   $44 = Math_fround($42 - $43);
   $45 = Math_fround(HEAPF32[$13>>2]);
   $46 = (($41) + 4|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = Math_fround($45 - $47);
   $49 = Math_fround(HEAPF32[$14>>2]);
   $50 = (($41) + 8|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = Math_fround($49 - $51);
   $53 = ((($18) + (($17*80)|0)|0) + 32|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = Math_fround($44 * $54);
   $56 = ((($18) + (($17*80)|0)|0) + 44|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = Math_fround($48 * $57);
   $59 = Math_fround($55 + $58);
   $60 = ((($18) + (($17*80)|0)|0) + 56|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = Math_fround($52 * $61);
   $63 = Math_fround($59 + $62);
   $64 = ((($18) + (($17*80)|0)|0) + 36|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = Math_fround($44 * $65);
   $67 = ((($18) + (($17*80)|0)|0) + 48|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = Math_fround($48 * $68);
   $70 = Math_fround($66 + $69);
   $71 = ((($18) + (($17*80)|0)|0) + 60|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = Math_fround($52 * $72);
   $74 = Math_fround($70 + $73);
   $75 = ((($18) + (($17*80)|0)|0) + 40|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = Math_fround($44 * $76);
   $78 = ((($18) + (($17*80)|0)|0) + 52|0);
   $79 = Math_fround(HEAPF32[$78>>2]);
   $80 = Math_fround($48 * $79);
   $81 = Math_fround($77 + $80);
   $82 = ((($18) + (($17*80)|0)|0) + 64|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = Math_fround($52 * $83);
   $85 = Math_fround($81 + $84);
   HEAPF32[$weights>>2] = $63;
   HEAPF32[$15>>2] = $74;
   HEAPF32[$16>>2] = $85;
   $86 = Math_fround(Math_fround(1.0) - $63);
   $87 = Math_fround($86 - $74);
   $88 = Math_fround($87 - $85);
   HEAPF32[$6>>2] = $88;
   $90 = $63;
  } else {
   __Z37GetBarycentricCoordinatesForOuterCellPPK8Vector3fRK13dynamic_arrayIS_Lj4EERS0_RK11TetrahedronR8Vector4fRf($positions,$5,$position,$19,$weights,$t);
   $$pre = Math_fround(HEAPF32[$weights>>2]);
   $90 = $$pre;
  }
  $89 = !($90 >= Math_fround(0.0));
  if (!($89)) {
   $91 = Math_fround(HEAPF32[$15>>2]);
   $92 = !($91 >= Math_fround(0.0));
   if (!($92)) {
    $93 = Math_fround(HEAPF32[$16>>2]);
    $94 = !($93 >= Math_fround(0.0));
    if (!($94)) {
     $95 = Math_fround(HEAPF32[$6>>2]);
     $96 = !($95 >= Math_fround(0.0));
     if (!($96)) {
      label = 30;
      break;
     }
    }
   }
  }
  $97 = HEAP32[$tetIndex>>2]|0;
  $98 = ($97|0)==($prevprev$07|0);
  if ($98) {
   label = 30;
   break;
  }
  $99 = Math_fround(HEAPF32[$15>>2]);
  $100 = $90 < $99;
  $101 = Math_fround(HEAPF32[$16>>2]);
  $102 = $90 < $101;
  $or$cond17 = $100 & $102;
  if ($or$cond17) {
   $103 = Math_fround(HEAPF32[$6>>2]);
   $104 = $90 < $103;
   if ($104) {
    $105 = ((($18) + (($17*80)|0)|0) + 16|0);
    $106 = HEAP32[$105>>2]|0;
    HEAP32[$tetIndex>>2] = $106;
   } else {
    label = 24;
   }
  } else {
   label = 24;
  }
  do {
   if ((label|0) == 24) {
    label = 0;
    $107 = $99 < $101;
    $108 = Math_fround(HEAPF32[$6>>2]);
    $109 = $99 < $108;
    $or$cond18 = $107 & $109;
    if ($or$cond18) {
     $110 = ((($18) + (($17*80)|0)|0) + 20|0);
     $111 = HEAP32[$110>>2]|0;
     HEAP32[$tetIndex>>2] = $111;
     break;
    }
    $112 = $101 < $108;
    if ($112) {
     $113 = ((($18) + (($17*80)|0)|0) + 24|0);
     $114 = HEAP32[$113>>2]|0;
     HEAP32[$tetIndex>>2] = $114;
     break;
    } else {
     $115 = ((($18) + (($17*80)|0)|0) + 28|0);
     $116 = HEAP32[$115>>2]|0;
     HEAP32[$tetIndex>>2] = $116;
     break;
    }
   }
  } while(0);
  $117 = HEAP32[$steps>>2]|0;
  $118 = (($117) + 1)|0;
  HEAP32[$steps>>2] = $118;
  $119 = ($118|0)<($1|0);
  if ($119) {
   $prevprev$07$phi = $prev$08;$prev$08 = $97;$prevprev$07 = $prevprev$07$phi;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 30) {
  STACKTOP = sp;return;
 }
}
function __ZN13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EE18resize_initializedEjRKS1_b($this,$size,$t,$double_on_resize) {
 $this = $this|0;
 $size = $size|0;
 $t = $t|0;
 $double_on_resize = $double_on_resize|0;
 var $$01$i = 0, $$byval_copy1 = 0, $$size = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $requested_size$0 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)<($size>>>0);
 do {
  if ($4) {
   if ($double_on_resize) {
    $5 = $2 << 1;
    $6 = ($5>>>0)>($size>>>0);
    $$size = $6 ? $5 : $size;
    $requested_size$0 = $$size;
   } else {
    $requested_size$0 = $size;
   }
   $7 = ($3>>>0)<($requested_size$0>>>0);
   if ($7) {
    $8 = ($2|0)>(-1);
    if ($8) {
     HEAP32[$1>>2] = $requested_size$0;
     $9 = HEAP32[$this>>2]|0;
     $10 = ($requested_size$0*48)|0;
     $11 = (($this) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     HEAP32[$0>>2] = $12;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($9,$10,4,$$byval_copy1,0,574056,370)|0);
     HEAP32[$this>>2] = $13;
     break;
    } else {
     $14 = ($requested_size$0*48)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,574056,352)|0);
     $18 = HEAP32[$this>>2]|0;
     $19 = (($this) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20*48)|0;
     _memcpy(($17|0),($18|0),($21|0))|0;
     HEAP32[$1>>2] = $requested_size$0;
     HEAP32[$this>>2] = $17;
     break;
    }
   }
  }
 } while(0);
 $22 = (($this) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($size>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + (($size*48)|0)|0);
 $27 = ($23|0)==($size|0);
 if ($27) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $28 = (($25) + (($23*48)|0)|0);
 $$01$i = $28;
 while(1) {
  $29 = ($$01$i|0)==(0|0);
  if (!($29)) {
   dest=$$01$i+0|0; src=$t+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $30 = (($$01$i) + 48|0);
  $31 = ($30|0)==($26|0);
  if ($31) {
   break;
  } else {
   $$01$i = $30;
  }
 }
 HEAP32[$22>>2] = $size;
 STACKTOP = sp;return;
}
function __ZNK11LightProbes47GetNonTetrahedralizedProbeSetIndexOffsetAndSizeERK7Hash128($agg$result,$this,$identifier) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $identifier = $identifier|0;
 var $$neg2$i$i$i$i$i = 0, $$old = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  $55 = $1;
 } else {
  $5 = $1;
  $6 = $3;
  $7 = (($6) - ($5))|0;
  $8 = (($7|0) / 24)&-1;
  $9 = $identifier;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($9) + 4)|0;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($identifier) + 8|0);
  $18 = $1;$__len$03$i$i$i$i$i = $8;
  while(1) {
   $16 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $17 = (($18) + (($16*24)|0)|0);
   $19 = $17;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = ($21|0)==($11|0);
   $26 = ($24|0)==($14|0);
   $27 = $25 & $26;
   if ($27) {
    $33 = ((($18) + (($16*24)|0)|0) + 8|0);
    $34 = $33;
    $35 = $34;
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + 4)|0;
    $38 = $37;
    $39 = HEAP32[$38>>2]|0;
    $40 = $15;
    $41 = $40;
    $42 = HEAP32[$41>>2]|0;
    $43 = (($40) + 4)|0;
    $44 = $43;
    $45 = HEAP32[$44>>2]|0;
    $46 = ($39>>>0)<($45>>>0);
    $47 = ($39|0)==($45|0);
    $48 = ($36>>>0)<($42>>>0);
    $49 = $47 & $48;
    $50 = $46 | $49;
    if ($50) {
     label = 6;
    } else {
     $106 = $18;$__len$0$be$i$i$i$i$i = $16;
    }
   } else {
    $28 = ($24>>>0)<($14>>>0);
    $29 = ($24|0)==($14|0);
    $30 = ($21>>>0)<($11>>>0);
    $31 = $29 & $30;
    $32 = $28 | $31;
    if ($32) {
     label = 6;
    } else {
     $106 = $18;$__len$0$be$i$i$i$i$i = $16;
    }
   }
   if ((label|0) == 6) {
    label = 0;
    $$sum$i$i$i$i$i = (($16) + 1)|0;
    $51 = (($18) + (($$sum$i$i$i$i$i*24)|0)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $52 = (($$neg2$i$i$i$i$i) - ($16))|0;
    $106 = $51;$__len$0$be$i$i$i$i$i = $52;
   }
   $53 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($53) {
    $55 = $106;
    break;
   } else {
    $18 = $106;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $54 = ($55|0)==($3|0);
 do {
  if (!($54)) {
   $56 = $identifier;
   $57 = $56;
   $58 = HEAP32[$57>>2]|0;
   $59 = (($56) + 4)|0;
   $60 = $59;
   $61 = HEAP32[$60>>2]|0;
   $62 = $55;
   $63 = $62;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($62) + 4)|0;
   $66 = $65;
   $67 = HEAP32[$66>>2]|0;
   $68 = ($58|0)==($64|0);
   $69 = ($61|0)==($67|0);
   $70 = $68 & $69;
   if ($70) {
    $77 = (($identifier) + 8|0);
    $78 = $77;
    $79 = $78;
    $80 = HEAP32[$79>>2]|0;
    $81 = (($78) + 4)|0;
    $82 = $81;
    $83 = HEAP32[$82>>2]|0;
    $84 = (($55) + 8|0);
    $85 = $84;
    $86 = $85;
    $87 = HEAP32[$86>>2]|0;
    $88 = (($85) + 4)|0;
    $89 = $88;
    $90 = HEAP32[$89>>2]|0;
    $91 = ($83>>>0)<($90>>>0);
    $92 = ($83|0)==($90|0);
    $93 = ($80>>>0)<($87>>>0);
    $94 = $92 & $93;
    $95 = $91 | $94;
    $$old = ($55|0)==($3|0);
    $or$cond1 = $95 | $$old;
    if ($or$cond1) {
     break;
    }
   } else {
    $71 = ($61>>>0)<($67>>>0);
    $72 = ($61|0)==($67|0);
    $73 = ($58>>>0)<($64>>>0);
    $74 = $72 & $73;
    $75 = $71 | $74;
    $76 = ($55|0)==($3|0);
    $or$cond = $75 | $76;
    if ($or$cond) {
     break;
    }
   }
   $97 = (($55) + 16|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($this) + 60|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ((($100) + (($98*24)|0)|0) + 16|0);
   $102 = ((($100) + (($98*24)|0)|0) + 20|0);
   $103 = HEAP32[$101>>2]|0;
   HEAP32[$agg$result>>2] = $103;
   $104 = (($agg$result) + 4|0);
   $105 = HEAP32[$102>>2]|0;
   HEAP32[$104>>2] = $105;
   STACKTOP = sp;return;
  }
 } while(0);
 HEAP32[$agg$result>>2] = -1;
 $96 = (($agg$result) + 4|0);
 HEAP32[$96>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11LightProbesD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11LightProbesD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN11LightProbesD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3421,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN11LightProbes19SHCoefficientsBaked8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0;
 var $$pre31 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $11 = $$pre12;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $15 = $$pre13;$17 = $$pre14;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre15 = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $21 = $$pre15;$23 = $$pre16;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $27 = $$pre17;$29 = $$pre18;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $33 = $$pre19;$35 = $$pre20;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$33>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,4);
  $$pre21 = HEAP32[$0>>2]|0;
  $$pre22 = HEAP32[$3>>2]|0;
  $39 = $$pre21;$41 = $$pre22;
 }
 $37 = (($this) + 24|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$39>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$37,4);
  $$pre23 = HEAP32[$0>>2]|0;
  $$pre24 = HEAP32[$3>>2]|0;
  $45 = $$pre23;$47 = $$pre24;
 }
 $43 = (($this) + 28|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)<($47>>>0);
 if ($46) {
  $48 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$45>>2] = $48;
  HEAP32[$0>>2] = $44;
  $51 = $44;$53 = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$43,4);
  $$pre25 = HEAP32[$0>>2]|0;
  $$pre26 = HEAP32[$3>>2]|0;
  $51 = $$pre25;$53 = $$pre26;
 }
 $49 = (($this) + 32|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)<($53>>>0);
 if ($52) {
  $54 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$51>>2] = $54;
  HEAP32[$0>>2] = $50;
  $57 = $50;$59 = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$49,4);
  $$pre27 = HEAP32[$0>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $57 = $$pre27;$59 = $$pre28;
 }
 $55 = (($this) + 36|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)<($59>>>0);
 if ($58) {
  $60 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$57>>2] = $60;
  HEAP32[$0>>2] = $56;
  $63 = $56;$65 = $59;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$55,4);
  $$pre29 = HEAP32[$0>>2]|0;
  $$pre30 = HEAP32[$3>>2]|0;
  $63 = $$pre29;$65 = $$pre30;
 }
 $61 = (($this) + 40|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)<($65>>>0);
 if ($64) {
  $66 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$63>>2] = $66;
  HEAP32[$0>>2] = $62;
  $69 = $62;$71 = $65;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$61,4);
  $$pre31 = HEAP32[$0>>2]|0;
  $$pre32 = HEAP32[$3>>2]|0;
  $69 = $$pre31;$71 = $$pre32;
 }
 $67 = (($this) + 44|0);
 $68 = (($69) + 4|0);
 $70 = ($68>>>0)<($71>>>0);
 if ($70) {
  $72 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$69>>2] = $72;
  HEAP32[$0>>2] = $68;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$67,4);
  STACKTOP = sp;return;
 }
}
function __ZN11LightProbes14LightProbeData8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, $i$01$i$i$i$i$i$i = 0, $size$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i1 = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i1>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i1,4);
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) + (($9*80)|0)|0);
 $11 = ($9|0)==(0);
 if (!($11)) {
  $i$01$i$i$i$i$i$i = $8;
  while(1) {
   __ZN11Tetrahedron8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i$i$i$i,$transfer);
   $12 = (($i$01$i$i$i$i$i$i) + 80|0);
   $13 = ($12|0)==($10|0);
   if ($13) {
    break;
   } else {
    $i$01$i$i$i$i$i$i = $12;
   }
  }
 }
 $14 = (($this) + 16|0);
 __ZN19StreamedBinaryWriteILb0EE8TransferI13dynamic_arrayI8Vector3fLj4EEEEvRT_PKc17TransferMetaFlags($transfer,$14,0,0);
 $15 = (($this) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$size$i$i$i1>>2] = $16;
 $17 = HEAP32[$2>>2]|0;
 $18 = (($17) + 4|0);
 $19 = HEAP32[$5>>2]|0;
 $20 = ($18>>>0)<($19>>>0);
 if ($20) {
  HEAP32[$17>>2] = $16;
  HEAP32[$2>>2] = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i1,4);
 }
 $21 = (($this) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$15>>2]|0;
 $24 = (($22) + (($23*24)|0)|0);
 $25 = ($23|0)==(0);
 if (!($25)) {
  $i$01$i$i$i = $22;
  while(1) {
   __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $26 = (($i$01$i$i$i) + 16|0);
   $27 = HEAP32[$2>>2]|0;
   $28 = (($27) + 4|0);
   $29 = HEAP32[$5>>2]|0;
   $30 = ($28>>>0)<($29>>>0);
   if ($30) {
    $31 = HEAP32[$26>>2]|0;
    HEAP32[$27>>2] = $31;
    HEAP32[$2>>2] = $28;
    $34 = $28;$36 = $29;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$26,4);
    $$pre$i$i$i = HEAP32[$2>>2]|0;
    $$pre2$i$i$i = HEAP32[$5>>2]|0;
    $34 = $$pre$i$i$i;$36 = $$pre2$i$i$i;
   }
   $32 = (($i$01$i$i$i) + 20|0);
   $33 = (($34) + 4|0);
   $35 = ($33>>>0)<($36>>>0);
   if ($35) {
    $37 = HEAP32[$32>>2]|0;
    HEAP32[$34>>2] = $37;
    HEAP32[$2>>2] = $33;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$32,4);
   }
   $38 = (($i$01$i$i$i) + 24|0);
   $39 = ($38|0)==($24|0);
   if ($39) {
    break;
   } else {
    $i$01$i$i$i = $38;
   }
  }
 }
 $40 = (($this) + 48|0);
 __ZN19StreamedBinaryWriteILb0EE8TransferI13dynamic_arrayI8Vector3fLj4EEEEvRT_PKc17TransferMetaFlags($transfer,$40,0,0);
 $41 = (($this) + 72|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($this) + 68|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $42;
 $46 = $44;
 $47 = (($45) - ($46))|0;
 $48 = (($47|0) / 24)&-1;
 HEAP32[$size$i$i$i1>>2] = $48;
 $49 = HEAP32[$2>>2]|0;
 $50 = (($49) + 4|0);
 $51 = HEAP32[$5>>2]|0;
 $52 = ($50>>>0)<($51>>>0);
 if ($52) {
  HEAP32[$49>>2] = $48;
  HEAP32[$2>>2] = $50;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i1,4);
 }
 $53 = HEAP32[$41>>2]|0;
 $54 = HEAP32[$43>>2]|0;
 $55 = ($54|0)==($53|0);
 if ($55) {
  STACKTOP = sp;return;
 } else {
  $56 = $54;
 }
 while(1) {
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($56,$transfer);
  $57 = (($56) + 16|0);
  $58 = HEAP32[$2>>2]|0;
  $59 = (($58) + 4|0);
  $60 = HEAP32[$5>>2]|0;
  $61 = ($59>>>0)<($60>>>0);
  if ($61) {
   $62 = HEAP32[$57>>2]|0;
   HEAP32[$58>>2] = $62;
   HEAP32[$2>>2] = $59;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$57,4);
  }
  $63 = (($56) + 24|0);
  $64 = ($63|0)==($53|0);
  if ($64) {
   break;
  } else {
   $56 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE8TransferI13dynamic_arrayI8Vector3fLj4EEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i$i = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $size$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i = sp;
 $2 = (($data) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size$i$i>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = HEAP32[$2>>2]|0;
 $12 = (($10) + (($11*12)|0)|0);
 $13 = ($11|0)==(0);
 if ($13) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i = $10;
 }
 while(1) {
  $14 = HEAP32[$4>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$7>>2]|0;
  $17 = ($15>>>0)<($16>>>0);
  if ($17) {
   $18 = Math_fround(HEAPF32[$i$01$i$i>>2]);
   HEAPF32[$14>>2] = $18;
   HEAP32[$4>>2] = $15;
   $21 = $15;$23 = $16;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01$i$i,4);
   $$pre$i$i$i = HEAP32[$4>>2]|0;
   $$pre3$i$i$i = HEAP32[$7>>2]|0;
   $21 = $$pre$i$i$i;$23 = $$pre3$i$i$i;
  }
  $19 = (($i$01$i$i) + 4|0);
  $20 = (($21) + 4|0);
  $22 = ($20>>>0)<($23>>>0);
  if ($22) {
   $24 = Math_fround(HEAPF32[$19>>2]);
   HEAPF32[$21>>2] = $24;
   HEAP32[$4>>2] = $20;
   $27 = $20;$29 = $23;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$19,4);
   $$pre4$i$i$i = HEAP32[$4>>2]|0;
   $$pre5$i$i$i = HEAP32[$7>>2]|0;
   $27 = $$pre4$i$i$i;$29 = $$pre5$i$i$i;
  }
  $25 = (($i$01$i$i) + 8|0);
  $26 = (($27) + 4|0);
  $28 = ($26>>>0)<($29>>>0);
  if ($28) {
   $30 = Math_fround(HEAPF32[$25>>2]);
   HEAPF32[$27>>2] = $30;
   HEAP32[$4>>2] = $26;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$25,4);
  }
  $31 = (($i$01$i$i) + 12|0);
  $32 = ($31|0)==($12|0);
  if ($32) {
   break;
  } else {
   $i$01$i$i = $31;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP8[$this>>0]|0;
  HEAP8[$1>>0] = $6;
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 1|0);
  HEAP32[$0>>2] = $8;
  $11 = $8;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,1);
  $$pre = HEAP32[$0>>2]|0;
  $11 = $$pre;
 }
 $9 = (($this) + 1|0);
 $10 = (($11) + 1|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = HEAP8[$9>>0]|0;
  HEAP8[$11>>0] = $14;
  $15 = HEAP32[$0>>2]|0;
  $16 = (($15) + 1|0);
  HEAP32[$0>>2] = $16;
  $19 = $16;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$9,1);
  $$pre16 = HEAP32[$0>>2]|0;
  $19 = $$pre16;
 }
 $17 = (($this) + 2|0);
 $18 = (($19) + 1|0);
 $20 = HEAP32[$3>>2]|0;
 $21 = ($18>>>0)<($20>>>0);
 if ($21) {
  $22 = HEAP8[$17>>0]|0;
  HEAP8[$19>>0] = $22;
  $23 = HEAP32[$0>>2]|0;
  $24 = (($23) + 1|0);
  HEAP32[$0>>2] = $24;
  $27 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$17,1);
  $$pre17 = HEAP32[$0>>2]|0;
  $27 = $$pre17;
 }
 $25 = (($this) + 3|0);
 $26 = (($27) + 1|0);
 $28 = HEAP32[$3>>2]|0;
 $29 = ($26>>>0)<($28>>>0);
 if ($29) {
  $30 = HEAP8[$25>>0]|0;
  HEAP8[$27>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  $35 = $32;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,1);
  $$pre18 = HEAP32[$0>>2]|0;
  $35 = $$pre18;
 }
 $33 = (($this) + 4|0);
 $34 = (($35) + 1|0);
 $36 = HEAP32[$3>>2]|0;
 $37 = ($34>>>0)<($36>>>0);
 if ($37) {
  $38 = HEAP8[$33>>0]|0;
  HEAP8[$35>>0] = $38;
  $39 = HEAP32[$0>>2]|0;
  $40 = (($39) + 1|0);
  HEAP32[$0>>2] = $40;
  $43 = $40;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$33,1);
  $$pre19 = HEAP32[$0>>2]|0;
  $43 = $$pre19;
 }
 $41 = (($this) + 5|0);
 $42 = (($43) + 1|0);
 $44 = HEAP32[$3>>2]|0;
 $45 = ($42>>>0)<($44>>>0);
 if ($45) {
  $46 = HEAP8[$41>>0]|0;
  HEAP8[$43>>0] = $46;
  $47 = HEAP32[$0>>2]|0;
  $48 = (($47) + 1|0);
  HEAP32[$0>>2] = $48;
  $51 = $48;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$41,1);
  $$pre20 = HEAP32[$0>>2]|0;
  $51 = $$pre20;
 }
 $49 = (($this) + 6|0);
 $50 = (($51) + 1|0);
 $52 = HEAP32[$3>>2]|0;
 $53 = ($50>>>0)<($52>>>0);
 if ($53) {
  $54 = HEAP8[$49>>0]|0;
  HEAP8[$51>>0] = $54;
  $55 = HEAP32[$0>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$0>>2] = $56;
  $59 = $56;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$49,1);
  $$pre21 = HEAP32[$0>>2]|0;
  $59 = $$pre21;
 }
 $57 = (($this) + 7|0);
 $58 = (($59) + 1|0);
 $60 = HEAP32[$3>>2]|0;
 $61 = ($58>>>0)<($60>>>0);
 if ($61) {
  $62 = HEAP8[$57>>0]|0;
  HEAP8[$59>>0] = $62;
  $63 = HEAP32[$0>>2]|0;
  $64 = (($63) + 1|0);
  HEAP32[$0>>2] = $64;
  $67 = $64;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$57,1);
  $$pre22 = HEAP32[$0>>2]|0;
  $67 = $$pre22;
 }
 $65 = (($this) + 8|0);
 $66 = (($67) + 1|0);
 $68 = HEAP32[$3>>2]|0;
 $69 = ($66>>>0)<($68>>>0);
 if ($69) {
  $70 = HEAP8[$65>>0]|0;
  HEAP8[$67>>0] = $70;
  $71 = HEAP32[$0>>2]|0;
  $72 = (($71) + 1|0);
  HEAP32[$0>>2] = $72;
  $75 = $72;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$65,1);
  $$pre23 = HEAP32[$0>>2]|0;
  $75 = $$pre23;
 }
 $73 = (($this) + 9|0);
 $74 = (($75) + 1|0);
 $76 = HEAP32[$3>>2]|0;
 $77 = ($74>>>0)<($76>>>0);
 if ($77) {
  $78 = HEAP8[$73>>0]|0;
  HEAP8[$75>>0] = $78;
  $79 = HEAP32[$0>>2]|0;
  $80 = (($79) + 1|0);
  HEAP32[$0>>2] = $80;
  $83 = $80;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$73,1);
  $$pre24 = HEAP32[$0>>2]|0;
  $83 = $$pre24;
 }
 $81 = (($this) + 10|0);
 $82 = (($83) + 1|0);
 $84 = HEAP32[$3>>2]|0;
 $85 = ($82>>>0)<($84>>>0);
 if ($85) {
  $86 = HEAP8[$81>>0]|0;
  HEAP8[$83>>0] = $86;
  $87 = HEAP32[$0>>2]|0;
  $88 = (($87) + 1|0);
  HEAP32[$0>>2] = $88;
  $91 = $88;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$81,1);
  $$pre25 = HEAP32[$0>>2]|0;
  $91 = $$pre25;
 }
 $89 = (($this) + 11|0);
 $90 = (($91) + 1|0);
 $92 = HEAP32[$3>>2]|0;
 $93 = ($90>>>0)<($92>>>0);
 if ($93) {
  $94 = HEAP8[$89>>0]|0;
  HEAP8[$91>>0] = $94;
  $95 = HEAP32[$0>>2]|0;
  $96 = (($95) + 1|0);
  HEAP32[$0>>2] = $96;
  $99 = $96;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$89,1);
  $$pre26 = HEAP32[$0>>2]|0;
  $99 = $$pre26;
 }
 $97 = (($this) + 12|0);
 $98 = (($99) + 1|0);
 $100 = HEAP32[$3>>2]|0;
 $101 = ($98>>>0)<($100>>>0);
 if ($101) {
  $102 = HEAP8[$97>>0]|0;
  HEAP8[$99>>0] = $102;
  $103 = HEAP32[$0>>2]|0;
  $104 = (($103) + 1|0);
  HEAP32[$0>>2] = $104;
  $107 = $104;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$97,1);
  $$pre27 = HEAP32[$0>>2]|0;
  $107 = $$pre27;
 }
 $105 = (($this) + 13|0);
 $106 = (($107) + 1|0);
 $108 = HEAP32[$3>>2]|0;
 $109 = ($106>>>0)<($108>>>0);
 if ($109) {
  $110 = HEAP8[$105>>0]|0;
  HEAP8[$107>>0] = $110;
  $111 = HEAP32[$0>>2]|0;
  $112 = (($111) + 1|0);
  HEAP32[$0>>2] = $112;
  $115 = $112;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$105,1);
  $$pre28 = HEAP32[$0>>2]|0;
  $115 = $$pre28;
 }
 $113 = (($this) + 14|0);
 $114 = (($115) + 1|0);
 $116 = HEAP32[$3>>2]|0;
 $117 = ($114>>>0)<($116>>>0);
 if ($117) {
  $118 = HEAP8[$113>>0]|0;
  HEAP8[$115>>0] = $118;
  $119 = HEAP32[$0>>2]|0;
  $120 = (($119) + 1|0);
  HEAP32[$0>>2] = $120;
  $123 = $120;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$113,1);
  $$pre29 = HEAP32[$0>>2]|0;
  $123 = $$pre29;
 }
 $121 = (($this) + 15|0);
 $122 = (($123) + 1|0);
 $124 = HEAP32[$3>>2]|0;
 $125 = ($122>>>0)<($124>>>0);
 if ($125) {
  $126 = HEAP8[$121>>0]|0;
  HEAP8[$123>>0] = $126;
  $127 = HEAP32[$0>>2]|0;
  $128 = (($127) + 1|0);
  HEAP32[$0>>2] = $128;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$121,1);
  STACKTOP = sp;return;
 }
}
function __ZN11Tetrahedron8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $11 = $$pre8;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $15 = $$pre9;$17 = $$pre10;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$13>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre11 = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $21 = $$pre11;$23 = $$pre12;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $27 = $$pre13;$29 = $$pre14;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $$pre15 = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $33 = $$pre15;$35 = $$pre16;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = HEAP32[$31>>2]|0;
  HEAP32[$33>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $39 = $$pre17;$41 = $$pre18;
 }
 $37 = (($this) + 24|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = HEAP32[$37>>2]|0;
  HEAP32[$39>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$37,4);
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $45 = $$pre19;$47 = $$pre20;
 }
 $43 = (($this) + 28|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)<($47>>>0);
 if ($46) {
  $48 = HEAP32[$43>>2]|0;
  HEAP32[$45>>2] = $48;
  HEAP32[$0>>2] = $44;
  $49 = (($this) + 32|0);
  __ZN10Matrix3x4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($49,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$43,4);
  $49 = (($this) + 32|0);
  __ZN10Matrix3x4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($49,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN10Matrix3x4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0;
 var $$pre31 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $11 = $$pre12;$9 = $$pre;
 }
 $7 = (($this) + 12|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $15 = $$pre13;$17 = $$pre14;
 }
 $13 = (($this) + 24|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre15 = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $21 = $$pre15;$23 = $$pre16;
 }
 $19 = (($this) + 36|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $27 = $$pre17;$29 = $$pre18;
 }
 $25 = (($this) + 4|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $33 = $$pre19;$35 = $$pre20;
 }
 $31 = (($this) + 16|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$33>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,4);
  $$pre21 = HEAP32[$0>>2]|0;
  $$pre22 = HEAP32[$3>>2]|0;
  $39 = $$pre21;$41 = $$pre22;
 }
 $37 = (($this) + 28|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$39>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$37,4);
  $$pre23 = HEAP32[$0>>2]|0;
  $$pre24 = HEAP32[$3>>2]|0;
  $45 = $$pre23;$47 = $$pre24;
 }
 $43 = (($this) + 40|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)<($47>>>0);
 if ($46) {
  $48 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$45>>2] = $48;
  HEAP32[$0>>2] = $44;
  $51 = $44;$53 = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$43,4);
  $$pre25 = HEAP32[$0>>2]|0;
  $$pre26 = HEAP32[$3>>2]|0;
  $51 = $$pre25;$53 = $$pre26;
 }
 $49 = (($this) + 8|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)<($53>>>0);
 if ($52) {
  $54 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$51>>2] = $54;
  HEAP32[$0>>2] = $50;
  $57 = $50;$59 = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$49,4);
  $$pre27 = HEAP32[$0>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $57 = $$pre27;$59 = $$pre28;
 }
 $55 = (($this) + 20|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)<($59>>>0);
 if ($58) {
  $60 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$57>>2] = $60;
  HEAP32[$0>>2] = $56;
  $63 = $56;$65 = $59;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$55,4);
  $$pre29 = HEAP32[$0>>2]|0;
  $$pre30 = HEAP32[$3>>2]|0;
  $63 = $$pre29;$65 = $$pre30;
 }
 $61 = (($this) + 32|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)<($65>>>0);
 if ($64) {
  $66 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$63>>2] = $66;
  HEAP32[$0>>2] = $62;
  $69 = $62;$71 = $65;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$61,4);
  $$pre31 = HEAP32[$0>>2]|0;
  $$pre32 = HEAP32[$3>>2]|0;
  $69 = $$pre31;$71 = $$pre32;
 }
 $67 = (($this) + 44|0);
 $68 = (($69) + 4|0);
 $70 = ($68>>>0)<($71>>>0);
 if ($70) {
  $72 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$69>>2] = $72;
  HEAP32[$0>>2] = $68;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$67,4);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($5) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $34 = $$pre$i$i$i4;
  } else {
   $33 = HEAP32[$6>>2]|0;
   HEAP32[$size1>>2] = $33;
   HEAP32[$2>>2] = $7;
   $34 = $33;
  }
  $35 = (_llvm_bswap_i32(($34|0))|0);
  HEAP32[$size1>>2] = $35;
  $36 = (($this) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$data>>2]|0;
  $39 = ($38|0)==(0|0);
  if ($39) {
   $40 = (($data) + 4|0);
   HEAP32[$40>>2] = $37;
  }
  dest=$$byval_copy+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  __ZN13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EE18resize_initializedEjRKS1_b($data,$35,$$byval_copy,0);
  $41 = HEAP32[$data>>2]|0;
  $42 = (($data) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + (($43*48)|0)|0);
  $45 = ($43|0)==(0);
  if ($45) {
   STACKTOP = sp;return;
  } else {
   $i$06 = $41;
  }
  while(1) {
   __ZN11LightProbes19SHCoefficientsBaked8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$06,$this);
   $46 = (($i$06) + 48|0);
   $47 = ($46|0)==($44|0);
   if ($47) {
    break;
   } else {
    $i$06 = $46;
   }
  }
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre7 = HEAP32[$8>>2]|0;
  $12 = $$pre$i$i$i;$15 = $$pre;$17 = $$pre7;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$size>>2] = $11;
  HEAP32[$2>>2] = $7;
  $12 = $11;$15 = $7;$17 = $9;
 }
 $13 = (_llvm_bswap_i32(($12|0))|0);
 HEAP32[$size>>2] = $13;
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $19 = $$pre$i$i$i1;$22 = $$pre8;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$offset>>2] = $18;
  HEAP32[$2>>2] = $14;
  $19 = $18;$22 = $13;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$offset>>2] = $20;
 $21 = ($22*48)|0;
 $23 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$20,$21)|0);
 $24 = (($data) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if ($26) {
  $27 = HEAP32[$data>>2]|0;
  $28 = (($data) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$1>>2] = $29;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy);
  HEAP32[$data>>2] = 0;
 }
 $30 = (($21|0) / 48)&-1;
 $31 = (($data) + 8|0);
 HEAP32[$31>>2] = $30;
 $32 = $30 | -2147483648;
 HEAP32[$24>>2] = $32;
 HEAP32[$data>>2] = $23;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11LightProbes19SHCoefficientsBaked8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i28 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i33 = 0, $$pre$i$i$i38 = 0, $$pre$i$i$i43 = 0, $$pre$i$i$i48 = 0, $$pre$i$i$i53 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i19Z2D = 0, $$pre$phi$i$i$i24Z2D = 0, $$pre$phi$i$i$i29Z2D = 0, $$pre$phi$i$i$i34Z2D = 0, $$pre$phi$i$i$i39Z2D = 0, $$pre$phi$i$i$i44Z2D = 0;
 var $$pre$phi$i$i$i49Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i54Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre56 = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0;
 var $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $$pre75 = 0, $$pre76 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre56 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $this;$12 = $$pre;$14 = $$pre56;$8 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i3 = HEAP32[$10>>2]|0;
  $$pre57 = HEAP32[$0>>2]|0;
  $$pre58 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $10;$17 = $$pre$i$i$i3;$21 = $$pre57;$23 = $$pre58;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i8 = HEAP32[$19>>2]|0;
  $$pre59 = HEAP32[$0>>2]|0;
  $$pre60 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $19;$26 = $$pre$i$i$i8;$30 = $$pre59;$32 = $$pre60;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i13 = HEAP32[$28>>2]|0;
  $$pre61 = HEAP32[$0>>2]|0;
  $$pre62 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $28;$35 = $$pre$i$i$i13;$39 = $$pre61;$41 = $$pre62;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $28;$35 = $34;$39 = $29;$41 = $32;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $36;
 $37 = (($this) + 16|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre$i$i$i18 = HEAP32[$37>>2]|0;
  $$pre63 = HEAP32[$0>>2]|0;
  $$pre64 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i19Z2D = $37;$44 = $$pre$i$i$i18;$48 = $$pre63;$50 = $$pre64;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $43 = (HEAPF32[tempDoublePtr>>2]=$42,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i19Z2D = $37;$44 = $43;$48 = $38;$50 = $41;
 }
 $45 = (_llvm_bswap_i32(($44|0))|0);
 HEAP32[$$pre$phi$i$i$i19Z2D>>2] = $45;
 $46 = (($this) + 20|0);
 $47 = (($48) + 4|0);
 $49 = ($47>>>0)>($50>>>0);
 if ($49) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$46,4);
  $$pre$i$i$i23 = HEAP32[$46>>2]|0;
  $$pre65 = HEAP32[$0>>2]|0;
  $$pre66 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i24Z2D = $46;$53 = $$pre$i$i$i23;$57 = $$pre65;$59 = $$pre66;
 } else {
  $51 = Math_fround(HEAPF32[$48>>2]);
  HEAPF32[$46>>2] = $51;
  HEAP32[$0>>2] = $47;
  $52 = (HEAPF32[tempDoublePtr>>2]=$51,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i24Z2D = $46;$53 = $52;$57 = $47;$59 = $50;
 }
 $54 = (_llvm_bswap_i32(($53|0))|0);
 HEAP32[$$pre$phi$i$i$i24Z2D>>2] = $54;
 $55 = (($this) + 24|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)>($59>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$55,4);
  $$pre$i$i$i28 = HEAP32[$55>>2]|0;
  $$pre67 = HEAP32[$0>>2]|0;
  $$pre68 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i29Z2D = $55;$62 = $$pre$i$i$i28;$66 = $$pre67;$68 = $$pre68;
 } else {
  $60 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$55>>2] = $60;
  HEAP32[$0>>2] = $56;
  $61 = (HEAPF32[tempDoublePtr>>2]=$60,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i29Z2D = $55;$62 = $61;$66 = $56;$68 = $59;
 }
 $63 = (_llvm_bswap_i32(($62|0))|0);
 HEAP32[$$pre$phi$i$i$i29Z2D>>2] = $63;
 $64 = (($this) + 28|0);
 $65 = (($66) + 4|0);
 $67 = ($65>>>0)>($68>>>0);
 if ($67) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$64,4);
  $$pre$i$i$i33 = HEAP32[$64>>2]|0;
  $$pre69 = HEAP32[$0>>2]|0;
  $$pre70 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i34Z2D = $64;$71 = $$pre$i$i$i33;$75 = $$pre69;$77 = $$pre70;
 } else {
  $69 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$64>>2] = $69;
  HEAP32[$0>>2] = $65;
  $70 = (HEAPF32[tempDoublePtr>>2]=$69,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i34Z2D = $64;$71 = $70;$75 = $65;$77 = $68;
 }
 $72 = (_llvm_bswap_i32(($71|0))|0);
 HEAP32[$$pre$phi$i$i$i34Z2D>>2] = $72;
 $73 = (($this) + 32|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)>($77>>>0);
 if ($76) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$73,4);
  $$pre$i$i$i38 = HEAP32[$73>>2]|0;
  $$pre71 = HEAP32[$0>>2]|0;
  $$pre72 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i39Z2D = $73;$80 = $$pre$i$i$i38;$84 = $$pre71;$86 = $$pre72;
 } else {
  $78 = Math_fround(HEAPF32[$75>>2]);
  HEAPF32[$73>>2] = $78;
  HEAP32[$0>>2] = $74;
  $79 = (HEAPF32[tempDoublePtr>>2]=$78,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i39Z2D = $73;$80 = $79;$84 = $74;$86 = $77;
 }
 $81 = (_llvm_bswap_i32(($80|0))|0);
 HEAP32[$$pre$phi$i$i$i39Z2D>>2] = $81;
 $82 = (($this) + 36|0);
 $83 = (($84) + 4|0);
 $85 = ($83>>>0)>($86>>>0);
 if ($85) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$82,4);
  $$pre$i$i$i43 = HEAP32[$82>>2]|0;
  $$pre73 = HEAP32[$0>>2]|0;
  $$pre74 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i44Z2D = $82;$89 = $$pre$i$i$i43;$93 = $$pre73;$95 = $$pre74;
 } else {
  $87 = Math_fround(HEAPF32[$84>>2]);
  HEAPF32[$82>>2] = $87;
  HEAP32[$0>>2] = $83;
  $88 = (HEAPF32[tempDoublePtr>>2]=$87,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i44Z2D = $82;$89 = $88;$93 = $83;$95 = $86;
 }
 $90 = (_llvm_bswap_i32(($89|0))|0);
 HEAP32[$$pre$phi$i$i$i44Z2D>>2] = $90;
 $91 = (($this) + 40|0);
 $92 = (($93) + 4|0);
 $94 = ($92>>>0)>($95>>>0);
 if ($94) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$91,4);
  $$pre$i$i$i48 = HEAP32[$91>>2]|0;
  $$pre75 = HEAP32[$0>>2]|0;
  $$pre76 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i49Z2D = $91;$102 = $$pre75;$104 = $$pre76;$98 = $$pre$i$i$i48;
 } else {
  $96 = Math_fround(HEAPF32[$93>>2]);
  HEAPF32[$91>>2] = $96;
  HEAP32[$0>>2] = $92;
  $97 = (HEAPF32[tempDoublePtr>>2]=$96,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i49Z2D = $91;$102 = $92;$104 = $95;$98 = $97;
 }
 $99 = (_llvm_bswap_i32(($98|0))|0);
 HEAP32[$$pre$phi$i$i$i49Z2D>>2] = $99;
 $100 = (($this) + 44|0);
 $101 = (($102) + 4|0);
 $103 = ($101>>>0)>($104>>>0);
 if ($103) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$100,4);
  $$pre$i$i$i53 = HEAP32[$100>>2]|0;
  $$pre$phi$i$i$i54Z2D = $100;$107 = $$pre$i$i$i53;
  $108 = (_llvm_bswap_i32(($107|0))|0);
  HEAP32[$$pre$phi$i$i$i54Z2D>>2] = $108;
  STACKTOP = sp;return;
 } else {
  $105 = Math_fround(HEAPF32[$102>>2]);
  HEAPF32[$100>>2] = $105;
  HEAP32[$0>>2] = $101;
  $106 = (HEAPF32[tempDoublePtr>>2]=$105,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i54Z2D = $100;$107 = $106;
  $108 = (_llvm_bswap_i32(($107|0))|0);
  HEAP32[$$pre$phi$i$i$i54Z2D>>2] = $108;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapI7Hash128iNSt3__14lessIS3_EE13stl_allocatorINS4_4pairIS3_iEEL18MemLabelIdentifier72ELi16EEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre10 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre8 = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre8;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = ($21*24)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = (($data) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$25>>2]|0;
 $29 = $27;
 $30 = $28;
 $31 = (($29) - ($30))|0;
 $32 = (($31|0) / 24)&-1;
 $33 = ($32>>>0)<($24>>>0);
 if ($33) {
  $34 = (($24) - ($32))|0;
  __ZNSt3__16vectorINS_4pairI7Hash128iEE13stl_allocatorIS3_L18MemLabelIdentifier72ELi16EEE8__appendEj($25,$34);
  $$pre = HEAP32[$26>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre7 = HEAP32[$$phi$trans$insert>>2]|0;
  $42 = $$pre7;$43 = $$pre;
 } else {
  $35 = ($32>>>0)>($24>>>0);
  if ($35) {
   $36 = (($28) + (($24*24)|0)|0);
   $37 = ($27|0)==($36|0);
   if ($37) {
    $42 = $28;$43 = $27;
   } else {
    $__new_last2$i$i$i$i = $36;
    $scevgep$i$i$i$i = (($27) + -24|0);
    $38 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($38)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $39 = (($uglygep3$i$i$i$i>>>0) / 24)&-1;
    $40 = $39 ^ -1;
    $scevgep4$i$i$i$i = (($27) + (($40*24)|0)|0);
    HEAP32[$26>>2] = $scevgep4$i$i$i$i;
    $42 = $28;$43 = $scevgep4$i$i$i$i;
   }
  } else {
   $42 = $28;$43 = $27;
  }
 }
 $41 = ($42|0)==($43|0);
 if ($41) {
  STACKTOP = sp;return;
 } else {
  $44 = $42;
 }
 while(1) {
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($44,$this);
  $45 = (($44) + 16|0);
  $46 = HEAP32[$1>>2]|0;
  $47 = (($46) + 4|0);
  $48 = HEAP32[$7>>2]|0;
  $49 = ($47>>>0)>($48>>>0);
  if ($49) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$45,4);
   $$pre$i$i$i$i$i = HEAP32[$45>>2]|0;
   $51 = $$pre$i$i$i$i$i;
  } else {
   $50 = HEAP32[$46>>2]|0;
   HEAP32[$45>>2] = $50;
   HEAP32[$1>>2] = $47;
   $51 = $50;
  }
  $52 = (_llvm_bswap_i32(($51|0))|0);
  HEAP32[$45>>2] = $52;
  $53 = (($44) + 24|0);
  $54 = ($53|0)==($43|0);
  if ($54) {
   break;
  } else {
   $44 = $53;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,1);
  $$pre = HEAP32[$0>>2]|0;
  $11 = $$pre;
 } else {
  $6 = HEAP8[$1>>0]|0;
  HEAP8[$this>>0] = $6;
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 1|0);
  HEAP32[$0>>2] = $8;
  $11 = $8;
 }
 $9 = (($this) + 1|0);
 $10 = (($11) + 1|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,1);
  $$pre16 = HEAP32[$0>>2]|0;
  $19 = $$pre16;
 } else {
  $14 = HEAP8[$11>>0]|0;
  HEAP8[$9>>0] = $14;
  $15 = HEAP32[$0>>2]|0;
  $16 = (($15) + 1|0);
  HEAP32[$0>>2] = $16;
  $19 = $16;
 }
 $17 = (($this) + 2|0);
 $18 = (($19) + 1|0);
 $20 = HEAP32[$3>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,1);
  $$pre17 = HEAP32[$0>>2]|0;
  $27 = $$pre17;
 } else {
  $22 = HEAP8[$19>>0]|0;
  HEAP8[$17>>0] = $22;
  $23 = HEAP32[$0>>2]|0;
  $24 = (($23) + 1|0);
  HEAP32[$0>>2] = $24;
  $27 = $24;
 }
 $25 = (($this) + 3|0);
 $26 = (($27) + 1|0);
 $28 = HEAP32[$3>>2]|0;
 $29 = ($26>>>0)>($28>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,1);
  $$pre18 = HEAP32[$0>>2]|0;
  $35 = $$pre18;
 } else {
  $30 = HEAP8[$27>>0]|0;
  HEAP8[$25>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  $35 = $32;
 }
 $33 = (($this) + 4|0);
 $34 = (($35) + 1|0);
 $36 = HEAP32[$3>>2]|0;
 $37 = ($34>>>0)>($36>>>0);
 if ($37) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$33,1);
  $$pre19 = HEAP32[$0>>2]|0;
  $43 = $$pre19;
 } else {
  $38 = HEAP8[$35>>0]|0;
  HEAP8[$33>>0] = $38;
  $39 = HEAP32[$0>>2]|0;
  $40 = (($39) + 1|0);
  HEAP32[$0>>2] = $40;
  $43 = $40;
 }
 $41 = (($this) + 5|0);
 $42 = (($43) + 1|0);
 $44 = HEAP32[$3>>2]|0;
 $45 = ($42>>>0)>($44>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$41,1);
  $$pre20 = HEAP32[$0>>2]|0;
  $51 = $$pre20;
 } else {
  $46 = HEAP8[$43>>0]|0;
  HEAP8[$41>>0] = $46;
  $47 = HEAP32[$0>>2]|0;
  $48 = (($47) + 1|0);
  HEAP32[$0>>2] = $48;
  $51 = $48;
 }
 $49 = (($this) + 6|0);
 $50 = (($51) + 1|0);
 $52 = HEAP32[$3>>2]|0;
 $53 = ($50>>>0)>($52>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$49,1);
  $$pre21 = HEAP32[$0>>2]|0;
  $59 = $$pre21;
 } else {
  $54 = HEAP8[$51>>0]|0;
  HEAP8[$49>>0] = $54;
  $55 = HEAP32[$0>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$0>>2] = $56;
  $59 = $56;
 }
 $57 = (($this) + 7|0);
 $58 = (($59) + 1|0);
 $60 = HEAP32[$3>>2]|0;
 $61 = ($58>>>0)>($60>>>0);
 if ($61) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$57,1);
  $$pre22 = HEAP32[$0>>2]|0;
  $67 = $$pre22;
 } else {
  $62 = HEAP8[$59>>0]|0;
  HEAP8[$57>>0] = $62;
  $63 = HEAP32[$0>>2]|0;
  $64 = (($63) + 1|0);
  HEAP32[$0>>2] = $64;
  $67 = $64;
 }
 $65 = (($this) + 8|0);
 $66 = (($67) + 1|0);
 $68 = HEAP32[$3>>2]|0;
 $69 = ($66>>>0)>($68>>>0);
 if ($69) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$65,1);
  $$pre23 = HEAP32[$0>>2]|0;
  $75 = $$pre23;
 } else {
  $70 = HEAP8[$67>>0]|0;
  HEAP8[$65>>0] = $70;
  $71 = HEAP32[$0>>2]|0;
  $72 = (($71) + 1|0);
  HEAP32[$0>>2] = $72;
  $75 = $72;
 }
 $73 = (($this) + 9|0);
 $74 = (($75) + 1|0);
 $76 = HEAP32[$3>>2]|0;
 $77 = ($74>>>0)>($76>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$73,1);
  $$pre24 = HEAP32[$0>>2]|0;
  $83 = $$pre24;
 } else {
  $78 = HEAP8[$75>>0]|0;
  HEAP8[$73>>0] = $78;
  $79 = HEAP32[$0>>2]|0;
  $80 = (($79) + 1|0);
  HEAP32[$0>>2] = $80;
  $83 = $80;
 }
 $81 = (($this) + 10|0);
 $82 = (($83) + 1|0);
 $84 = HEAP32[$3>>2]|0;
 $85 = ($82>>>0)>($84>>>0);
 if ($85) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$81,1);
  $$pre25 = HEAP32[$0>>2]|0;
  $91 = $$pre25;
 } else {
  $86 = HEAP8[$83>>0]|0;
  HEAP8[$81>>0] = $86;
  $87 = HEAP32[$0>>2]|0;
  $88 = (($87) + 1|0);
  HEAP32[$0>>2] = $88;
  $91 = $88;
 }
 $89 = (($this) + 11|0);
 $90 = (($91) + 1|0);
 $92 = HEAP32[$3>>2]|0;
 $93 = ($90>>>0)>($92>>>0);
 if ($93) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$89,1);
  $$pre26 = HEAP32[$0>>2]|0;
  $99 = $$pre26;
 } else {
  $94 = HEAP8[$91>>0]|0;
  HEAP8[$89>>0] = $94;
  $95 = HEAP32[$0>>2]|0;
  $96 = (($95) + 1|0);
  HEAP32[$0>>2] = $96;
  $99 = $96;
 }
 $97 = (($this) + 12|0);
 $98 = (($99) + 1|0);
 $100 = HEAP32[$3>>2]|0;
 $101 = ($98>>>0)>($100>>>0);
 if ($101) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$97,1);
  $$pre27 = HEAP32[$0>>2]|0;
  $107 = $$pre27;
 } else {
  $102 = HEAP8[$99>>0]|0;
  HEAP8[$97>>0] = $102;
  $103 = HEAP32[$0>>2]|0;
  $104 = (($103) + 1|0);
  HEAP32[$0>>2] = $104;
  $107 = $104;
 }
 $105 = (($this) + 13|0);
 $106 = (($107) + 1|0);
 $108 = HEAP32[$3>>2]|0;
 $109 = ($106>>>0)>($108>>>0);
 if ($109) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$105,1);
  $$pre28 = HEAP32[$0>>2]|0;
  $115 = $$pre28;
 } else {
  $110 = HEAP8[$107>>0]|0;
  HEAP8[$105>>0] = $110;
  $111 = HEAP32[$0>>2]|0;
  $112 = (($111) + 1|0);
  HEAP32[$0>>2] = $112;
  $115 = $112;
 }
 $113 = (($this) + 14|0);
 $114 = (($115) + 1|0);
 $116 = HEAP32[$3>>2]|0;
 $117 = ($114>>>0)>($116>>>0);
 if ($117) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$113,1);
  $$pre29 = HEAP32[$0>>2]|0;
  $123 = $$pre29;
 } else {
  $118 = HEAP8[$115>>0]|0;
  HEAP8[$113>>0] = $118;
  $119 = HEAP32[$0>>2]|0;
  $120 = (($119) + 1|0);
  HEAP32[$0>>2] = $120;
  $123 = $120;
 }
 $121 = (($this) + 15|0);
 $122 = (($123) + 1|0);
 $124 = HEAP32[$3>>2]|0;
 $125 = ($122>>>0)>($124>>>0);
 if ($125) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$121,1);
  STACKTOP = sp;return;
 } else {
  $126 = HEAP8[$123>>0]|0;
  HEAP8[$121>>0] = $126;
  $127 = HEAP32[$0>>2]|0;
  $128 = (($127) + 1|0);
  HEAP32[$0>>2] = $128;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorINS_4pairI7Hash128iEE13stl_allocatorIS3_L18MemLabelIdentifier72ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 24)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 24|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = (($18|0) / 24)&-1;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = (($22|0) / 24)&-1;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $23 << 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = ($$0$i56*24)|0;
  HEAP32[$0>>2] = 72;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,574056,79)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + (($19*24)|0)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $36 = 0;
  } else {
   ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;
   $36 = $34;
  }
  $35 = (($36) + 24|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $35;
  }
 }
 $39 = (($32) + (($$0$i57*24)|0)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = (($44|0) / -24)&-1;
 $$sum = (($45) + ($19))|0;
 $46 = (($32) + (($$sum*24)|0)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $35;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 72;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI8Vector3fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*12)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$i$04,0,0);
   $44 = (($i$04) + 12|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = ($23*12)|0;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = (($22|0) / 12)&-1;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI8Vector3fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = ($rs*12)|0;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,574056,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = ($rs*12)|0;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,574056,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20*12)|0;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + (($rs*12)|0)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + (($23*12)|0)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   HEAPF32[$$01$i$i>>2] = Math_fround(0.0);
   $30 = (($$01$i$i) + 4|0);
   HEAPF32[$30>>2] = Math_fround(0.0);
   $31 = (($$01$i$i) + 8|0);
   HEAPF32[$31>>2] = Math_fround(0.0);
  }
  $32 = (($$01$i$i) + 12|0);
  $33 = ($32|0)==($25|0);
  if ($33) {
   break;
  } else {
   $$01$i$i = $32;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i3$i$i = 0, $$pre$i$i$i8$i$i = 0, $$pre$phi$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$i4$i$iZ2D = 0, $$pre$phi$i$i$i9$i$iZ2D = 0, $$pre11$i$i = 0, $$pre12$i$i = 0, $$pre13$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$data,4);
  $$pre$i$i$i3$i$i = HEAP32[$data>>2]|0;
  $$pre$i$i = HEAP32[$2>>2]|0;
  $$pre11$i$i = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$i4$i$iZ2D = $data;$10 = $$pre$i$i$i3$i$i;$14 = $$pre$i$i;$16 = $$pre11$i$i;
 } else {
  $8 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$data>>2] = $8;
  HEAP32[$2>>2] = $4;
  $9 = (HEAPF32[tempDoublePtr>>2]=$8,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4$i$iZ2D = $data;$10 = $9;$14 = $4;$16 = $6;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$$pre$phi$i$i$i4$i$iZ2D>>2] = $11;
 $12 = (($data) + 4|0);
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$12,4);
  $$pre$i$i$i8$i$i = HEAP32[$12>>2]|0;
  $$pre12$i$i = HEAP32[$2>>2]|0;
  $$pre13$i$i = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$i9$i$iZ2D = $12;$19 = $$pre$i$i$i8$i$i;$23 = $$pre12$i$i;$25 = $$pre13$i$i;
 } else {
  $17 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$12>>2] = $17;
  HEAP32[$2>>2] = $13;
  $18 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9$i$iZ2D = $12;$19 = $18;$23 = $13;$25 = $16;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$$pre$phi$i$i$i9$i$iZ2D>>2] = $20;
 $21 = (($data) + 8|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$21,4);
  $$pre$i$i$i$i$i = HEAP32[$21>>2]|0;
  $$pre$phi$i$i$i$i$iZ2D = $21;$28 = $$pre$i$i$i$i$i;
  $29 = (_llvm_bswap_i32(($28|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$iZ2D>>2] = $29;
  STACKTOP = sp;return;
 } else {
  $26 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$21>>2] = $26;
  HEAP32[$2>>2] = $22;
  $27 = (HEAPF32[tempDoublePtr>>2]=$26,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i$i$iZ2D = $21;$28 = $27;
  $29 = (_llvm_bswap_i32(($28|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$iZ2D>>2] = $29;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI13ProbeSetIndexLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i1$i$i$i = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i4 = 0, $$pre3$i$i$i = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if (!($6)) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre6 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i1;$16 = $$pre;$18 = $$pre6;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre7 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i2;$23 = $$pre7;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = ($23*24)|0;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = (($22|0) / 24)&-1;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $35 = $$pre$i$i$i4;
 } else {
  $34 = HEAP32[$7>>2]|0;
  HEAP32[$size1>>2] = $34;
  HEAP32[$3>>2] = $8;
  $35 = $34;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$size1>>2] = $36;
 $37 = (($this) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$2>>2] = $38;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI13ProbeSetIndexLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
 $39 = HEAP32[$data>>2]|0;
 $40 = (($data) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + (($41*24)|0)|0);
 $43 = ($41|0)==(0);
 if ($43) {
  STACKTOP = sp;return;
 } else {
  $i$05 = $39;
 }
 while(1) {
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($i$05,$this);
  $44 = (($i$05) + 16|0);
  $45 = HEAP32[$3>>2]|0;
  $46 = (($45) + 4|0);
  $47 = HEAP32[$9>>2]|0;
  $48 = ($46>>>0)>($47>>>0);
  if ($48) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$44,4);
   $$pre$i$i$i$i$i$i = HEAP32[$44>>2]|0;
   $$pre$i$i$i = HEAP32[$3>>2]|0;
   $$pre3$i$i$i = HEAP32[$9>>2]|0;
   $50 = $$pre$i$i$i$i$i$i;$54 = $$pre$i$i$i;$56 = $$pre3$i$i$i;
  } else {
   $49 = HEAP32[$45>>2]|0;
   HEAP32[$44>>2] = $49;
   HEAP32[$3>>2] = $46;
   $50 = $49;$54 = $46;$56 = $47;
  }
  $51 = (_llvm_bswap_i32(($50|0))|0);
  HEAP32[$44>>2] = $51;
  $52 = (($i$05) + 20|0);
  $53 = (($54) + 4|0);
  $55 = ($53>>>0)>($56>>>0);
  if ($55) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$52,4);
   $$pre$i$i$i1$i$i$i = HEAP32[$52>>2]|0;
   $58 = $$pre$i$i$i1$i$i$i;
  } else {
   $57 = HEAP32[$54>>2]|0;
   HEAP32[$52>>2] = $57;
   HEAP32[$3>>2] = $53;
   $58 = $57;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  HEAP32[$52>>2] = $59;
  $60 = (($i$05) + 24|0);
  $61 = ($60|0)==($42|0);
  if ($61) {
   break;
  } else {
   $i$05 = $60;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI13ProbeSetIndexLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 28|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 $6 = (($data) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = ($rs*24)|0;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,8,$$byval_copy1,0,574056,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = ($rs*24)|0;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,8,$$byval_copy1,0,574056,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21*24)|0;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + (($rs*24)|0)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + (($24*24)|0)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$01$i$i+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$01$i$i+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$01$i$i+20>>2]=HEAP32[$1+20>>2]|0;
  }
  $31 = (($$01$i$i) + 24|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11TetrahedronLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11TetrahedronLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*80)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN11Tetrahedron8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 80|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = ($23*80)|0;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = (($22|0) / 80)&-1;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI11TetrahedronLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 88|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 dest=$1+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $6 = (($data) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = ($rs*80)|0;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,4,$$byval_copy1,0,574056,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = ($rs*80)|0;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,4,$$byval_copy1,0,574056,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21*80)|0;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + (($rs*80)|0)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + (($24*80)|0)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   dest=$$01$i$i+0|0; src=$1+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $31 = (($$01$i$i) + 80|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN11Tetrahedron8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre$i$i$i7 = 0, $$pre$i$i$i9 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0;
 var $$pre26 = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre15 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre15;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre16 = HEAP32[$0>>2]|0;
  $$pre17 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre16;$21 = $$pre17;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $$pre18 = HEAP32[$0>>2]|0;
  $$pre19 = HEAP32[$3>>2]|0;
  $23 = $$pre$i$i$i3;$27 = $$pre18;$29 = $$pre19;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = $22;$27 = $18;$29 = $21;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$17>>2] = $24;
 $25 = (($this) + 12|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre$i$i$i5 = HEAP32[$25>>2]|0;
  $$pre20 = HEAP32[$0>>2]|0;
  $$pre21 = HEAP32[$3>>2]|0;
  $31 = $$pre$i$i$i5;$35 = $$pre20;$37 = $$pre21;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = $30;$35 = $26;$37 = $29;
 }
 $32 = (_llvm_bswap_i32(($31|0))|0);
 HEAP32[$25>>2] = $32;
 $33 = (($this) + 16|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$33,4);
  $$pre$i$i$i7 = HEAP32[$33>>2]|0;
  $$pre22 = HEAP32[$0>>2]|0;
  $$pre23 = HEAP32[$3>>2]|0;
  $39 = $$pre$i$i$i7;$43 = $$pre22;$45 = $$pre23;
 } else {
  $38 = HEAP32[$35>>2]|0;
  HEAP32[$33>>2] = $38;
  HEAP32[$0>>2] = $34;
  $39 = $38;$43 = $34;$45 = $37;
 }
 $40 = (_llvm_bswap_i32(($39|0))|0);
 HEAP32[$33>>2] = $40;
 $41 = (($this) + 20|0);
 $42 = (($43) + 4|0);
 $44 = ($42>>>0)>($45>>>0);
 if ($44) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$41,4);
  $$pre$i$i$i9 = HEAP32[$41>>2]|0;
  $$pre24 = HEAP32[$0>>2]|0;
  $$pre25 = HEAP32[$3>>2]|0;
  $47 = $$pre$i$i$i9;$51 = $$pre24;$53 = $$pre25;
 } else {
  $46 = HEAP32[$43>>2]|0;
  HEAP32[$41>>2] = $46;
  HEAP32[$0>>2] = $42;
  $47 = $46;$51 = $42;$53 = $45;
 }
 $48 = (_llvm_bswap_i32(($47|0))|0);
 HEAP32[$41>>2] = $48;
 $49 = (($this) + 24|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)>($53>>>0);
 if ($52) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$49,4);
  $$pre$i$i$i11 = HEAP32[$49>>2]|0;
  $$pre26 = HEAP32[$0>>2]|0;
  $$pre27 = HEAP32[$3>>2]|0;
  $55 = $$pre$i$i$i11;$59 = $$pre26;$61 = $$pre27;
 } else {
  $54 = HEAP32[$51>>2]|0;
  HEAP32[$49>>2] = $54;
  HEAP32[$0>>2] = $50;
  $55 = $54;$59 = $50;$61 = $53;
 }
 $56 = (_llvm_bswap_i32(($55|0))|0);
 HEAP32[$49>>2] = $56;
 $57 = (($this) + 28|0);
 $58 = (($59) + 4|0);
 $60 = ($58>>>0)>($61>>>0);
 if ($60) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$57,4);
  $$pre$i$i$i13 = HEAP32[$57>>2]|0;
  $63 = $$pre$i$i$i13;
  $64 = (_llvm_bswap_i32(($63|0))|0);
  HEAP32[$57>>2] = $64;
  $65 = (($this) + 32|0);
  __ZN10Matrix3x4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($65,$transfer);
  STACKTOP = sp;return;
 } else {
  $62 = HEAP32[$59>>2]|0;
  HEAP32[$57>>2] = $62;
  HEAP32[$0>>2] = $58;
  $63 = $62;
  $64 = (_llvm_bswap_i32(($63|0))|0);
  HEAP32[$57>>2] = $64;
  $65 = (($this) + 32|0);
  __ZN10Matrix3x4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($65,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN10Matrix3x4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i28 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i33 = 0, $$pre$i$i$i38 = 0, $$pre$i$i$i43 = 0, $$pre$i$i$i48 = 0, $$pre$i$i$i53 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i19Z2D = 0, $$pre$phi$i$i$i24Z2D = 0, $$pre$phi$i$i$i29Z2D = 0, $$pre$phi$i$i$i34Z2D = 0, $$pre$phi$i$i$i39Z2D = 0, $$pre$phi$i$i$i44Z2D = 0;
 var $$pre$phi$i$i$i49Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i54Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre56 = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0;
 var $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $$pre75 = 0, $$pre76 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre56 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $this;$12 = $$pre;$14 = $$pre56;$8 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $9;
 $10 = (($this) + 12|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i3 = HEAP32[$10>>2]|0;
  $$pre57 = HEAP32[$0>>2]|0;
  $$pre58 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $10;$17 = $$pre$i$i$i3;$21 = $$pre57;$23 = $$pre58;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $18;
 $19 = (($this) + 24|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i8 = HEAP32[$19>>2]|0;
  $$pre59 = HEAP32[$0>>2]|0;
  $$pre60 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $19;$26 = $$pre$i$i$i8;$30 = $$pre59;$32 = $$pre60;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $27;
 $28 = (($this) + 36|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i13 = HEAP32[$28>>2]|0;
  $$pre61 = HEAP32[$0>>2]|0;
  $$pre62 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $28;$35 = $$pre$i$i$i13;$39 = $$pre61;$41 = $$pre62;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $28;$35 = $34;$39 = $29;$41 = $32;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $36;
 $37 = (($this) + 4|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre$i$i$i18 = HEAP32[$37>>2]|0;
  $$pre63 = HEAP32[$0>>2]|0;
  $$pre64 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i19Z2D = $37;$44 = $$pre$i$i$i18;$48 = $$pre63;$50 = $$pre64;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $43 = (HEAPF32[tempDoublePtr>>2]=$42,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i19Z2D = $37;$44 = $43;$48 = $38;$50 = $41;
 }
 $45 = (_llvm_bswap_i32(($44|0))|0);
 HEAP32[$$pre$phi$i$i$i19Z2D>>2] = $45;
 $46 = (($this) + 16|0);
 $47 = (($48) + 4|0);
 $49 = ($47>>>0)>($50>>>0);
 if ($49) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$46,4);
  $$pre$i$i$i23 = HEAP32[$46>>2]|0;
  $$pre65 = HEAP32[$0>>2]|0;
  $$pre66 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i24Z2D = $46;$53 = $$pre$i$i$i23;$57 = $$pre65;$59 = $$pre66;
 } else {
  $51 = Math_fround(HEAPF32[$48>>2]);
  HEAPF32[$46>>2] = $51;
  HEAP32[$0>>2] = $47;
  $52 = (HEAPF32[tempDoublePtr>>2]=$51,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i24Z2D = $46;$53 = $52;$57 = $47;$59 = $50;
 }
 $54 = (_llvm_bswap_i32(($53|0))|0);
 HEAP32[$$pre$phi$i$i$i24Z2D>>2] = $54;
 $55 = (($this) + 28|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)>($59>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$55,4);
  $$pre$i$i$i28 = HEAP32[$55>>2]|0;
  $$pre67 = HEAP32[$0>>2]|0;
  $$pre68 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i29Z2D = $55;$62 = $$pre$i$i$i28;$66 = $$pre67;$68 = $$pre68;
 } else {
  $60 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$55>>2] = $60;
  HEAP32[$0>>2] = $56;
  $61 = (HEAPF32[tempDoublePtr>>2]=$60,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i29Z2D = $55;$62 = $61;$66 = $56;$68 = $59;
 }
 $63 = (_llvm_bswap_i32(($62|0))|0);
 HEAP32[$$pre$phi$i$i$i29Z2D>>2] = $63;
 $64 = (($this) + 40|0);
 $65 = (($66) + 4|0);
 $67 = ($65>>>0)>($68>>>0);
 if ($67) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$64,4);
  $$pre$i$i$i33 = HEAP32[$64>>2]|0;
  $$pre69 = HEAP32[$0>>2]|0;
  $$pre70 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i34Z2D = $64;$71 = $$pre$i$i$i33;$75 = $$pre69;$77 = $$pre70;
 } else {
  $69 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$64>>2] = $69;
  HEAP32[$0>>2] = $65;
  $70 = (HEAPF32[tempDoublePtr>>2]=$69,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i34Z2D = $64;$71 = $70;$75 = $65;$77 = $68;
 }
 $72 = (_llvm_bswap_i32(($71|0))|0);
 HEAP32[$$pre$phi$i$i$i34Z2D>>2] = $72;
 $73 = (($this) + 8|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)>($77>>>0);
 if ($76) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$73,4);
  $$pre$i$i$i38 = HEAP32[$73>>2]|0;
  $$pre71 = HEAP32[$0>>2]|0;
  $$pre72 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i39Z2D = $73;$80 = $$pre$i$i$i38;$84 = $$pre71;$86 = $$pre72;
 } else {
  $78 = Math_fround(HEAPF32[$75>>2]);
  HEAPF32[$73>>2] = $78;
  HEAP32[$0>>2] = $74;
  $79 = (HEAPF32[tempDoublePtr>>2]=$78,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i39Z2D = $73;$80 = $79;$84 = $74;$86 = $77;
 }
 $81 = (_llvm_bswap_i32(($80|0))|0);
 HEAP32[$$pre$phi$i$i$i39Z2D>>2] = $81;
 $82 = (($this) + 20|0);
 $83 = (($84) + 4|0);
 $85 = ($83>>>0)>($86>>>0);
 if ($85) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$82,4);
  $$pre$i$i$i43 = HEAP32[$82>>2]|0;
  $$pre73 = HEAP32[$0>>2]|0;
  $$pre74 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i44Z2D = $82;$89 = $$pre$i$i$i43;$93 = $$pre73;$95 = $$pre74;
 } else {
  $87 = Math_fround(HEAPF32[$84>>2]);
  HEAPF32[$82>>2] = $87;
  HEAP32[$0>>2] = $83;
  $88 = (HEAPF32[tempDoublePtr>>2]=$87,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i44Z2D = $82;$89 = $88;$93 = $83;$95 = $86;
 }
 $90 = (_llvm_bswap_i32(($89|0))|0);
 HEAP32[$$pre$phi$i$i$i44Z2D>>2] = $90;
 $91 = (($this) + 32|0);
 $92 = (($93) + 4|0);
 $94 = ($92>>>0)>($95>>>0);
 if ($94) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$91,4);
  $$pre$i$i$i48 = HEAP32[$91>>2]|0;
  $$pre75 = HEAP32[$0>>2]|0;
  $$pre76 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i49Z2D = $91;$102 = $$pre75;$104 = $$pre76;$98 = $$pre$i$i$i48;
 } else {
  $96 = Math_fround(HEAPF32[$93>>2]);
  HEAPF32[$91>>2] = $96;
  HEAP32[$0>>2] = $92;
  $97 = (HEAPF32[tempDoublePtr>>2]=$96,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i49Z2D = $91;$102 = $92;$104 = $95;$98 = $97;
 }
 $99 = (_llvm_bswap_i32(($98|0))|0);
 HEAP32[$$pre$phi$i$i$i49Z2D>>2] = $99;
 $100 = (($this) + 44|0);
 $101 = (($102) + 4|0);
 $103 = ($101>>>0)>($104>>>0);
 if ($103) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$100,4);
  $$pre$i$i$i53 = HEAP32[$100>>2]|0;
  $$pre$phi$i$i$i54Z2D = $100;$107 = $$pre$i$i$i53;
  $108 = (_llvm_bswap_i32(($107|0))|0);
  HEAP32[$$pre$phi$i$i$i54Z2D>>2] = $108;
  STACKTOP = sp;return;
 } else {
  $105 = Math_fround(HEAPF32[$102>>2]);
  HEAPF32[$100>>2] = $105;
  HEAP32[$0>>2] = $101;
  $106 = (HEAPF32[tempDoublePtr>>2]=$105,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i54Z2D = $100;$107 = $106;
  $108 = (_llvm_bswap_i32(($107|0))|0);
  HEAP32[$$pre$phi$i$i$i54Z2D>>2] = $108;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($5) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $36 = $$pre;
  } else {
   $30 = HEAP32[$6>>2]|0;
   HEAP32[$size1>>2] = $30;
   HEAP32[$2>>2] = $7;
   $36 = $30;
  }
  $31 = (($this) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$data>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $35 = (($data) + 4|0);
   HEAP32[$35>>2] = $32;
  }
  dest=$$byval_copy+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  __ZN13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EE18resize_initializedEjRKS1_b($data,$36,$$byval_copy,0);
  $37 = HEAP32[$data>>2]|0;
  $38 = (($data) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + (($39*48)|0)|0);
  $41 = ($39|0)==(0);
  if ($41) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $37;
  }
  while(1) {
   __ZN11LightProbes19SHCoefficientsBaked8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$04,$this);
   $42 = (($i$04) + 48|0);
   $43 = ($42|0)==($40|0);
   if ($43) {
    break;
   } else {
    $i$04 = $42;
   }
  }
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre5 = HEAP32[$2>>2]|0;
  $$pre6 = HEAP32[$8>>2]|0;
  $13 = $$pre5;$15 = $$pre6;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$size>>2] = $11;
  HEAP32[$2>>2] = $7;
  $13 = $7;$15 = $9;
 }
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $19 = $$pre7;
 } else {
  $16 = HEAP32[$13>>2]|0;
  HEAP32[$offset>>2] = $16;
  HEAP32[$2>>2] = $12;
  $19 = $16;
 }
 $17 = HEAP32[$size>>2]|0;
 $18 = ($17*48)|0;
 $20 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$19,$18)|0);
 $21 = (($data) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(-1);
 if ($23) {
  $24 = HEAP32[$data>>2]|0;
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  HEAP32[$1>>2] = $26;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($24,$$byval_copy);
  HEAP32[$data>>2] = 0;
 }
 $27 = (($18|0) / 48)&-1;
 $28 = (($data) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = $27 | -2147483648;
 HEAP32[$21>>2] = $29;
 HEAP32[$data>>2] = $20;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11LightProbes19SHCoefficientsBaked8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0;
 var $$pre31 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $11 = $$pre12;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $15 = $$pre13;$17 = $$pre14;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre15 = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $21 = $$pre15;$23 = $$pre16;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $27 = $$pre17;$29 = $$pre18;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $33 = $$pre19;$35 = $$pre20;
 } else {
  $30 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$31,4);
  $$pre21 = HEAP32[$0>>2]|0;
  $$pre22 = HEAP32[$3>>2]|0;
  $39 = $$pre21;$41 = $$pre22;
 } else {
  $36 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$31>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 }
 $37 = (($this) + 24|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre23 = HEAP32[$0>>2]|0;
  $$pre24 = HEAP32[$3>>2]|0;
  $45 = $$pre23;$47 = $$pre24;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 }
 $43 = (($this) + 28|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)>($47>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$43,4);
  $$pre25 = HEAP32[$0>>2]|0;
  $$pre26 = HEAP32[$3>>2]|0;
  $51 = $$pre25;$53 = $$pre26;
 } else {
  $48 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$43>>2] = $48;
  HEAP32[$0>>2] = $44;
  $51 = $44;$53 = $47;
 }
 $49 = (($this) + 32|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)>($53>>>0);
 if ($52) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$49,4);
  $$pre27 = HEAP32[$0>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $57 = $$pre27;$59 = $$pre28;
 } else {
  $54 = Math_fround(HEAPF32[$51>>2]);
  HEAPF32[$49>>2] = $54;
  HEAP32[$0>>2] = $50;
  $57 = $50;$59 = $53;
 }
 $55 = (($this) + 36|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)>($59>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$55,4);
  $$pre29 = HEAP32[$0>>2]|0;
  $$pre30 = HEAP32[$3>>2]|0;
  $63 = $$pre29;$65 = $$pre30;
 } else {
  $60 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$55>>2] = $60;
  HEAP32[$0>>2] = $56;
  $63 = $56;$65 = $59;
 }
 $61 = (($this) + 40|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)>($65>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$61,4);
  $$pre31 = HEAP32[$0>>2]|0;
  $$pre32 = HEAP32[$3>>2]|0;
  $69 = $$pre31;$71 = $$pre32;
 } else {
  $66 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$61>>2] = $66;
  HEAP32[$0>>2] = $62;
  $69 = $62;$71 = $65;
 }
 $67 = (($this) + 44|0);
 $68 = (($69) + 4|0);
 $70 = ($68>>>0)>($71>>>0);
 if ($70) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$67,4);
  STACKTOP = sp;return;
 } else {
  $72 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$67>>2] = $72;
  HEAP32[$0>>2] = $68;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapI7Hash128iNSt3__14lessIS3_EE13stl_allocatorINS4_4pairIS3_iEEL18MemLabelIdentifier72ELi16EEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0;
 var $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre7 = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $12 = $$pre7;$14 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre9 = HEAP32[$offset>>2]|0;
   $18 = $$pre9;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = ($16*24)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $29 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $29 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = (($data) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$20>>2]|0;
 $24 = $22;
 $25 = $23;
 $26 = (($24) - ($25))|0;
 $27 = (($26|0) / 24)&-1;
 $28 = ($27>>>0)<($29>>>0);
 if ($28) {
  $30 = (($29) - ($27))|0;
  __ZNSt3__16vectorINS_4pairI7Hash128iEE13stl_allocatorIS3_L18MemLabelIdentifier72ELi16EEE8__appendEj($20,$30);
  $$pre5 = HEAP32[$21>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre6 = HEAP32[$$phi$trans$insert>>2]|0;
  $38 = $$pre6;$39 = $$pre5;
 } else {
  $31 = ($27>>>0)>($29>>>0);
  if ($31) {
   $32 = (($23) + (($29*24)|0)|0);
   $33 = ($22|0)==($32|0);
   if ($33) {
    $38 = $23;$39 = $22;
   } else {
    $__new_last2$i$i$i$i = $32;
    $scevgep$i$i$i$i = (($22) + -24|0);
    $34 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($34)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $35 = (($uglygep3$i$i$i$i>>>0) / 24)&-1;
    $36 = $35 ^ -1;
    $scevgep4$i$i$i$i = (($22) + (($36*24)|0)|0);
    HEAP32[$21>>2] = $scevgep4$i$i$i$i;
    $38 = $23;$39 = $scevgep4$i$i$i$i;
   }
  } else {
   $38 = $23;$39 = $22;
  }
 }
 $37 = ($38|0)==($39|0);
 if ($37) {
  STACKTOP = sp;return;
 } else {
  $40 = $38;
 }
 while(1) {
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($40,$this);
  $41 = (($40) + 16|0);
  $42 = HEAP32[$1>>2]|0;
  $43 = (($42) + 4|0);
  $44 = HEAP32[$7>>2]|0;
  $45 = ($43>>>0)>($44>>>0);
  if ($45) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$41,4);
  } else {
   $46 = HEAP32[$42>>2]|0;
   HEAP32[$41>>2] = $46;
   HEAP32[$1>>2] = $43;
  }
  $47 = (($40) + 24|0);
  $48 = ($47|0)==($39|0);
  if ($48) {
   break;
  } else {
   $40 = $47;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,1);
  $$pre = HEAP32[$0>>2]|0;
  $11 = $$pre;
 } else {
  $6 = HEAP8[$1>>0]|0;
  HEAP8[$this>>0] = $6;
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 1|0);
  HEAP32[$0>>2] = $8;
  $11 = $8;
 }
 $9 = (($this) + 1|0);
 $10 = (($11) + 1|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,1);
  $$pre16 = HEAP32[$0>>2]|0;
  $19 = $$pre16;
 } else {
  $14 = HEAP8[$11>>0]|0;
  HEAP8[$9>>0] = $14;
  $15 = HEAP32[$0>>2]|0;
  $16 = (($15) + 1|0);
  HEAP32[$0>>2] = $16;
  $19 = $16;
 }
 $17 = (($this) + 2|0);
 $18 = (($19) + 1|0);
 $20 = HEAP32[$3>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,1);
  $$pre17 = HEAP32[$0>>2]|0;
  $27 = $$pre17;
 } else {
  $22 = HEAP8[$19>>0]|0;
  HEAP8[$17>>0] = $22;
  $23 = HEAP32[$0>>2]|0;
  $24 = (($23) + 1|0);
  HEAP32[$0>>2] = $24;
  $27 = $24;
 }
 $25 = (($this) + 3|0);
 $26 = (($27) + 1|0);
 $28 = HEAP32[$3>>2]|0;
 $29 = ($26>>>0)>($28>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,1);
  $$pre18 = HEAP32[$0>>2]|0;
  $35 = $$pre18;
 } else {
  $30 = HEAP8[$27>>0]|0;
  HEAP8[$25>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  $35 = $32;
 }
 $33 = (($this) + 4|0);
 $34 = (($35) + 1|0);
 $36 = HEAP32[$3>>2]|0;
 $37 = ($34>>>0)>($36>>>0);
 if ($37) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$33,1);
  $$pre19 = HEAP32[$0>>2]|0;
  $43 = $$pre19;
 } else {
  $38 = HEAP8[$35>>0]|0;
  HEAP8[$33>>0] = $38;
  $39 = HEAP32[$0>>2]|0;
  $40 = (($39) + 1|0);
  HEAP32[$0>>2] = $40;
  $43 = $40;
 }
 $41 = (($this) + 5|0);
 $42 = (($43) + 1|0);
 $44 = HEAP32[$3>>2]|0;
 $45 = ($42>>>0)>($44>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$41,1);
  $$pre20 = HEAP32[$0>>2]|0;
  $51 = $$pre20;
 } else {
  $46 = HEAP8[$43>>0]|0;
  HEAP8[$41>>0] = $46;
  $47 = HEAP32[$0>>2]|0;
  $48 = (($47) + 1|0);
  HEAP32[$0>>2] = $48;
  $51 = $48;
 }
 $49 = (($this) + 6|0);
 $50 = (($51) + 1|0);
 $52 = HEAP32[$3>>2]|0;
 $53 = ($50>>>0)>($52>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$49,1);
  $$pre21 = HEAP32[$0>>2]|0;
  $59 = $$pre21;
 } else {
  $54 = HEAP8[$51>>0]|0;
  HEAP8[$49>>0] = $54;
  $55 = HEAP32[$0>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$0>>2] = $56;
  $59 = $56;
 }
 $57 = (($this) + 7|0);
 $58 = (($59) + 1|0);
 $60 = HEAP32[$3>>2]|0;
 $61 = ($58>>>0)>($60>>>0);
 if ($61) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$57,1);
  $$pre22 = HEAP32[$0>>2]|0;
  $67 = $$pre22;
 } else {
  $62 = HEAP8[$59>>0]|0;
  HEAP8[$57>>0] = $62;
  $63 = HEAP32[$0>>2]|0;
  $64 = (($63) + 1|0);
  HEAP32[$0>>2] = $64;
  $67 = $64;
 }
 $65 = (($this) + 8|0);
 $66 = (($67) + 1|0);
 $68 = HEAP32[$3>>2]|0;
 $69 = ($66>>>0)>($68>>>0);
 if ($69) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$65,1);
  $$pre23 = HEAP32[$0>>2]|0;
  $75 = $$pre23;
 } else {
  $70 = HEAP8[$67>>0]|0;
  HEAP8[$65>>0] = $70;
  $71 = HEAP32[$0>>2]|0;
  $72 = (($71) + 1|0);
  HEAP32[$0>>2] = $72;
  $75 = $72;
 }
 $73 = (($this) + 9|0);
 $74 = (($75) + 1|0);
 $76 = HEAP32[$3>>2]|0;
 $77 = ($74>>>0)>($76>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$73,1);
  $$pre24 = HEAP32[$0>>2]|0;
  $83 = $$pre24;
 } else {
  $78 = HEAP8[$75>>0]|0;
  HEAP8[$73>>0] = $78;
  $79 = HEAP32[$0>>2]|0;
  $80 = (($79) + 1|0);
  HEAP32[$0>>2] = $80;
  $83 = $80;
 }
 $81 = (($this) + 10|0);
 $82 = (($83) + 1|0);
 $84 = HEAP32[$3>>2]|0;
 $85 = ($82>>>0)>($84>>>0);
 if ($85) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$81,1);
  $$pre25 = HEAP32[$0>>2]|0;
  $91 = $$pre25;
 } else {
  $86 = HEAP8[$83>>0]|0;
  HEAP8[$81>>0] = $86;
  $87 = HEAP32[$0>>2]|0;
  $88 = (($87) + 1|0);
  HEAP32[$0>>2] = $88;
  $91 = $88;
 }
 $89 = (($this) + 11|0);
 $90 = (($91) + 1|0);
 $92 = HEAP32[$3>>2]|0;
 $93 = ($90>>>0)>($92>>>0);
 if ($93) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$89,1);
  $$pre26 = HEAP32[$0>>2]|0;
  $99 = $$pre26;
 } else {
  $94 = HEAP8[$91>>0]|0;
  HEAP8[$89>>0] = $94;
  $95 = HEAP32[$0>>2]|0;
  $96 = (($95) + 1|0);
  HEAP32[$0>>2] = $96;
  $99 = $96;
 }
 $97 = (($this) + 12|0);
 $98 = (($99) + 1|0);
 $100 = HEAP32[$3>>2]|0;
 $101 = ($98>>>0)>($100>>>0);
 if ($101) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$97,1);
  $$pre27 = HEAP32[$0>>2]|0;
  $107 = $$pre27;
 } else {
  $102 = HEAP8[$99>>0]|0;
  HEAP8[$97>>0] = $102;
  $103 = HEAP32[$0>>2]|0;
  $104 = (($103) + 1|0);
  HEAP32[$0>>2] = $104;
  $107 = $104;
 }
 $105 = (($this) + 13|0);
 $106 = (($107) + 1|0);
 $108 = HEAP32[$3>>2]|0;
 $109 = ($106>>>0)>($108>>>0);
 if ($109) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$105,1);
  $$pre28 = HEAP32[$0>>2]|0;
  $115 = $$pre28;
 } else {
  $110 = HEAP8[$107>>0]|0;
  HEAP8[$105>>0] = $110;
  $111 = HEAP32[$0>>2]|0;
  $112 = (($111) + 1|0);
  HEAP32[$0>>2] = $112;
  $115 = $112;
 }
 $113 = (($this) + 14|0);
 $114 = (($115) + 1|0);
 $116 = HEAP32[$3>>2]|0;
 $117 = ($114>>>0)>($116>>>0);
 if ($117) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$113,1);
  $$pre29 = HEAP32[$0>>2]|0;
  $123 = $$pre29;
 } else {
  $118 = HEAP8[$115>>0]|0;
  HEAP8[$113>>0] = $118;
  $119 = HEAP32[$0>>2]|0;
  $120 = (($119) + 1|0);
  HEAP32[$0>>2] = $120;
  $123 = $120;
 }
 $121 = (($this) + 15|0);
 $122 = (($123) + 1|0);
 $124 = HEAP32[$3>>2]|0;
 $125 = ($122>>>0)>($124>>>0);
 if ($125) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$121,1);
  STACKTOP = sp;return;
 } else {
  $126 = HEAP8[$123>>0]|0;
  HEAP8[$121>>0] = $126;
  $127 = HEAP32[$0>>2]|0;
  $128 = (($127) + 1|0);
  HEAP32[$0>>2] = $128;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI8Vector3fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$size1>>2]|0;
  $36 = ($35|0)==(0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $37 = HEAP32[$data>>2]|0;
  $38 = ($35*12)|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$37,$38);
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre2 = HEAP32[$3>>2]|0;
  $$pre3 = HEAP32[$9>>2]|0;
  $14 = $$pre2;$16 = $$pre3;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre4 = HEAP32[$offset>>2]|0;
  $20 = $$pre4;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = ($18*12)|0;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = (($19|0) / 12)&-1;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI13ProbeSetIndexLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if (!($6)) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre3 = HEAP32[$3>>2]|0;
   $$pre4 = HEAP32[$9>>2]|0;
   $14 = $$pre3;$16 = $$pre4;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $14 = $8;$16 = $10;
  }
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre5 = HEAP32[$offset>>2]|0;
   $20 = $$pre5;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$3>>2] = $13;
   $20 = $17;
  }
  $18 = HEAP32[$size>>2]|0;
  $19 = ($18*24)|0;
  $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
  $22 = (($data) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>(-1);
  if ($24) {
   $25 = HEAP32[$data>>2]|0;
   $26 = (($data) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $28 = (($19|0) / 24)&-1;
  $29 = (($data) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $28 | -2147483648;
  HEAP32[$22>>2] = $30;
  HEAP32[$data>>2] = $21;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $34 = $$pre;
 } else {
  $31 = HEAP32[$7>>2]|0;
  HEAP32[$size1>>2] = $31;
  HEAP32[$3>>2] = $8;
  $34 = $31;
 }
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$2>>2] = $33;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI13ProbeSetIndexLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
 $35 = HEAP32[$data>>2]|0;
 $36 = (($data) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + (($37*24)|0)|0);
 $39 = ($37|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 } else {
  $i$02 = $35;
 }
 while(1) {
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
  $40 = (($i$02) + 16|0);
  $41 = HEAP32[$3>>2]|0;
  $42 = (($41) + 4|0);
  $43 = HEAP32[$9>>2]|0;
  $44 = ($42>>>0)>($43>>>0);
  if ($44) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$40,4);
   $$pre$i$i$i = HEAP32[$3>>2]|0;
   $$pre2$i$i$i = HEAP32[$9>>2]|0;
   $48 = $$pre$i$i$i;$50 = $$pre2$i$i$i;
  } else {
   $45 = HEAP32[$41>>2]|0;
   HEAP32[$40>>2] = $45;
   HEAP32[$3>>2] = $42;
   $48 = $42;$50 = $43;
  }
  $46 = (($i$02) + 20|0);
  $47 = (($48) + 4|0);
  $49 = ($47>>>0)>($50>>>0);
  if ($49) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$46,4);
  } else {
   $51 = HEAP32[$48>>2]|0;
   HEAP32[$46>>2] = $51;
   HEAP32[$3>>2] = $47;
  }
  $52 = (($i$02) + 24|0);
  $53 = ($52|0)==($38|0);
  if ($53) {
   break;
  } else {
   $i$02 = $52;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11TetrahedronLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11TetrahedronLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + (($37*80)|0)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN11Tetrahedron8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 80|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = ($18*80)|0;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = (($19|0) / 80)&-1;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11Tetrahedron8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $11 = $$pre8;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $15 = $$pre9;$17 = $$pre10;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre11 = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $21 = $$pre11;$23 = $$pre12;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $27 = $$pre13;$29 = $$pre14;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre15 = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $33 = $$pre15;$35 = $$pre16;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$31,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $39 = $$pre17;$41 = $$pre18;
 } else {
  $36 = HEAP32[$33>>2]|0;
  HEAP32[$31>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 }
 $37 = (($this) + 24|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $45 = $$pre19;$47 = $$pre20;
 } else {
  $42 = HEAP32[$39>>2]|0;
  HEAP32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 }
 $43 = (($this) + 28|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)>($47>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$43,4);
  $49 = (($this) + 32|0);
  __ZN10Matrix3x4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($49,$transfer);
  STACKTOP = sp;return;
 } else {
  $48 = HEAP32[$45>>2]|0;
  HEAP32[$43>>2] = $48;
  HEAP32[$0>>2] = $44;
  $49 = (($this) + 32|0);
  __ZN10Matrix3x4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($49,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN10Matrix3x4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0;
 var $$pre31 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0);
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $11 = $$pre12;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 12|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $15 = $$pre13;$17 = $$pre14;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 24|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre15 = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $21 = $$pre15;$23 = $$pre16;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 36|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $27 = $$pre17;$29 = $$pre18;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 4|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $33 = $$pre19;$35 = $$pre20;
 } else {
  $30 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 }
 $31 = (($this) + 16|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$31,4);
  $$pre21 = HEAP32[$0>>2]|0;
  $$pre22 = HEAP32[$3>>2]|0;
  $39 = $$pre21;$41 = $$pre22;
 } else {
  $36 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$31>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 }
 $37 = (($this) + 28|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre23 = HEAP32[$0>>2]|0;
  $$pre24 = HEAP32[$3>>2]|0;
  $45 = $$pre23;$47 = $$pre24;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 }
 $43 = (($this) + 40|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)>($47>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$43,4);
  $$pre25 = HEAP32[$0>>2]|0;
  $$pre26 = HEAP32[$3>>2]|0;
  $51 = $$pre25;$53 = $$pre26;
 } else {
  $48 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$43>>2] = $48;
  HEAP32[$0>>2] = $44;
  $51 = $44;$53 = $47;
 }
 $49 = (($this) + 8|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)>($53>>>0);
 if ($52) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$49,4);
  $$pre27 = HEAP32[$0>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $57 = $$pre27;$59 = $$pre28;
 } else {
  $54 = Math_fround(HEAPF32[$51>>2]);
  HEAPF32[$49>>2] = $54;
  HEAP32[$0>>2] = $50;
  $57 = $50;$59 = $53;
 }
 $55 = (($this) + 20|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)>($59>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$55,4);
  $$pre29 = HEAP32[$0>>2]|0;
  $$pre30 = HEAP32[$3>>2]|0;
  $63 = $$pre29;$65 = $$pre30;
 } else {
  $60 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$55>>2] = $60;
  HEAP32[$0>>2] = $56;
  $63 = $56;$65 = $59;
 }
 $61 = (($this) + 32|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)>($65>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$61,4);
  $$pre31 = HEAP32[$0>>2]|0;
  $$pre32 = HEAP32[$3>>2]|0;
  $69 = $$pre31;$71 = $$pre32;
 } else {
  $66 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$61>>2] = $66;
  HEAP32[$0>>2] = $62;
  $69 = $62;$71 = $65;
 }
 $67 = (($this) + 44|0);
 $68 = (($69) + 4|0);
 $70 = ($68>>>0)>($71>>>0);
 if ($70) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$67,4);
  STACKTOP = sp;return;
 } else {
  $72 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$67>>2] = $72;
  HEAP32[$0>>2] = $68;
  STACKTOP = sp;return;
 }
}
function __ZN11LightProbes8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574064,574904,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN11LightProbes14LightProbeData8TransferI14SafeBinaryReadEEvRT_($0,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 140|0);
 $7 = HEAP32[580760>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574072,$7,$converter$i$i1,1)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EEEEvRT_17TransferMetaFlags($transfer,$6,0);
 } else {
  $11 = HEAP32[$converter$i$i1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (FUNCTION_TABLE_iii[$11 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i$14 = 0, $size = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $1 = sp + 16|0;
 $size = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,574872,574872,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$data>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (($data) + 4|0);
  HEAP32[$11>>2] = $8;
 }
 dest=$1+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN13dynamic_arrayIN11LightProbes19SHCoefficientsBakedELj4EE18resize_initializedEjRKS1_b($data,$6,$1,0);
 $12 = HEAP32[$data>>2]|0;
 $13 = HEAP32[$3>>2]|0;
 $14 = (($12) + (($13*48)|0)|0);
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)==(0);
 do {
  if (!($16)) {
   $17 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,574880,0,1)|0);
   $18 = (($this) + 80|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (__ZNK16TypeTreeIterator7GetNodeEv($19)|0);
   $21 = (($20) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($this) + 84|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$24>>2] = 0;
   $25 = ($17|0)==(2);
   if ($25) {
    $26 = HEAP32[$18>>2]|0;
    $27 = (($26) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$data>>2]|0;
    $30 = ($29|0)==($14|0);
    L11: do {
     if (!($30)) {
      $32 = 0;$35 = $26;$i$03 = $29;
      while(1) {
       $31 = Math_imul($32, $22)|0;
       $33 = (($31) + ($28))|0;
       $34 = (($35) + 20|0);
       HEAP32[$34>>2] = $33;
       $36 = (($35) + 12|0);
       HEAP32[$36>>2] = $33;
       $37 = (($35) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$35);
       $38 = $2;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = (($38) + 4)|0;
       $42 = $41;
       $43 = HEAP32[$42>>2]|0;
       $44 = $37;
       $45 = $44;
       HEAP32[$45>>2] = $40;
       $46 = (($44) + 4)|0;
       $47 = $46;
       HEAP32[$47>>2] = $43;
       $48 = HEAP32[$23>>2]|0;
       $49 = HEAP32[$48>>2]|0;
       $50 = (($49) + 1)|0;
       HEAP32[$48>>2] = $50;
       __ZN11LightProbes19SHCoefficientsBaked8TransferI14SafeBinaryReadEEvRT_($i$03,$this);
       $51 = (($i$03) + 48|0);
       $52 = ($51|0)==($14|0);
       if ($52) {
        break L11;
       }
       $$pre = HEAP32[$23>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$18>>2]|0;
       $32 = $$pre8;$35 = $$pre9;$i$03 = $51;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $53 = HEAP32[$data>>2]|0;
   $54 = ($53|0)==($14|0);
   if (!($54)) {
    $i$14 = $53;
    while(1) {
     $55 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,574880,$1,1)|0);
     $56 = ($55|0)==(0);
     if (!($56)) {
      $57 = ($55|0)>(0);
      if ($57) {
       __ZN11LightProbes19SHCoefficientsBaked8TransferI14SafeBinaryReadEEvRT_($i$14,$this);
      } else {
       $58 = HEAP32[$1>>2]|0;
       $59 = ($58|0)==(0|0);
       if (!($59)) {
        (FUNCTION_TABLE_iii[$58 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $60 = (($i$14) + 48|0);
     $61 = ($60|0)==($14|0);
     if ($61) {
      break;
     } else {
      $i$14 = $60;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11LightProbes19SHCoefficientsBaked8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$this,574104,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,574112,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,574120,0);
 $2 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$2,574128,0);
 $3 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$3,574136,0);
 $4 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$4,574144,0);
 $5 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,574152,0);
 $6 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,574160,0);
 $7 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$7,574168,0);
 $8 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$8,574176,0);
 $9 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$9,574184,0);
 $10 = (($this) + 44|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$10,574192,0);
 STACKTOP = sp;return;
}
function __ZN11LightProbes14LightProbeData8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574200,574944,$converter$i$i3,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   __ZN26ProbeSetTetrahedralization8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  } else {
   $3 = HEAP32[$converter$i$i3>>2]|0;
   $4 = ($3|0)==(0|0);
   if (!($4)) {
    (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $5 = (($this) + 32|0);
 $6 = HEAP32[580760>>2]|0;
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574224,$6,$converter$i$i3,1)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  if ($9) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI13ProbeSetIndexLj8EEEEvRT_17TransferMetaFlags($transfer,$5,0);
  } else {
   $10 = HEAP32[$converter$i$i3>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    (FUNCTION_TABLE_iii[$10 & 4095]($5,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $12 = (($this) + 48|0);
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574240,$6,$converter$i$i3,1)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($transfer,$12,0);
  } else {
   $16 = HEAP32[$converter$i$i3>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    (FUNCTION_TABLE_iii[$16 & 4095]($12,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $18 = (($this) + 64|0);
 $19 = HEAP32[580600>>2]|0;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574256,$19,$converter$i$i3,1)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = ($20|0)>(0);
 if ($22) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapI7Hash128iNSt3__14lessIS2_EE13stl_allocatorINS3_4pairIS2_iEEL18MemLabelIdentifier72ELi16EEEEEvRT_17TransferMetaFlags($transfer,$18,0);
 } else {
  $23 = HEAP32[$converter$i$i3>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   (FUNCTION_TABLE_iii[$23 & 4095]($18,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapI7Hash128iNSt3__14lessIS2_EE13stl_allocatorINS3_4pairIS2_iEEL18MemLabelIdentifier72ELi16EEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $__new_last2$i$i$i$i = 0, $converter$i$i = 0;
 var $converter$i$i$i2 = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($data) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 24)&-1;
 HEAP32[$size>>2] = $9;
 $10 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,574872,574872,$size)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$size>>2]|0;
 $12 = (($data) + 4|0);
 $13 = HEAP32[$2>>2]|0;
 $14 = HEAP32[$12>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = (($17|0) / 24)&-1;
 $19 = ($18>>>0)<($11>>>0);
 if ($19) {
  $20 = (($11) - ($18))|0;
  __ZNSt3__16vectorINS_4pairI7Hash128iEE13stl_allocatorIS3_L18MemLabelIdentifier72ELi16EEE8__appendEj($12,$20);
  $$pre = HEAP32[$2>>2]|0;
  $$pre10 = HEAP32[$size>>2]|0;
  $28 = $$pre10;$44 = $$pre;
 } else {
  $21 = ($18>>>0)>($11>>>0);
  if ($21) {
   $22 = (($14) + (($11*24)|0)|0);
   $23 = ($13|0)==($22|0);
   if ($23) {
    $28 = $11;$44 = $13;
   } else {
    $__new_last2$i$i$i$i = $22;
    $scevgep$i$i$i$i = (($13) + -24|0);
    $24 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($24)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $25 = (($uglygep3$i$i$i$i>>>0) / 24)&-1;
    $26 = $25 ^ -1;
    $scevgep4$i$i$i$i = (($13) + (($26*24)|0)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i;
    $28 = $11;$44 = $scevgep4$i$i$i$i;
   }
  } else {
   $28 = $11;$44 = $13;
  }
 }
 $27 = ($28|0)==(0);
 do {
  if (!($27)) {
   $29 = HEAP32[580608>>2]|0;
   $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,$29,0,1)|0);
   $31 = (($this) + 80|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (__ZNK16TypeTreeIterator7GetNodeEv($32)|0);
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($this) + 84|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$37>>2] = 0;
   $38 = ($30|0)==(2);
   if ($38) {
    $39 = HEAP32[$31>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$4>>2]|0;
    $43 = ($42|0)==($44|0);
    L14: do {
     if (!($43)) {
      $45 = HEAP32[580576>>2]|0;
      $46 = HEAP32[580656>>2]|0;
      $48 = 0;$51 = $39;$70 = $42;
      while(1) {
       $47 = Math_imul($48, $35)|0;
       $49 = (($47) + ($41))|0;
       $50 = (($51) + 20|0);
       HEAP32[$50>>2] = $49;
       $52 = (($51) + 12|0);
       HEAP32[$52>>2] = $49;
       $53 = (($51) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$51);
       $54 = $1;
       $55 = $54;
       $56 = HEAP32[$55>>2]|0;
       $57 = (($54) + 4)|0;
       $58 = $57;
       $59 = HEAP32[$58>>2]|0;
       $60 = $53;
       $61 = $60;
       HEAP32[$61>>2] = $56;
       $62 = (($60) + 4)|0;
       $63 = $62;
       HEAP32[$63>>2] = $59;
       $64 = HEAP32[$36>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = (($65) + 1)|0;
       HEAP32[$64>>2] = $66;
       $67 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$45,574920,$converter$i$i$i2,1)|0);
       $68 = ($67|0)==(0);
       if (!($68)) {
        $69 = ($67|0)>(0);
        if ($69) {
         __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($70,$this);
        } else {
         $71 = HEAP32[$converter$i$i$i2>>2]|0;
         $72 = ($71|0)==(0|0);
         if (!($72)) {
          (FUNCTION_TABLE_iii[$71 & 4095]($70,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $73 = (($70) + 16|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$73,$46,0);
       $74 = (($70) + 24|0);
       $75 = ($74|0)==($44|0);
       if ($75) {
        break L14;
       }
       $$pre11 = HEAP32[$36>>2]|0;
       $$pre12 = HEAP32[$$pre11>>2]|0;
       $$pre13 = HEAP32[$31>>2]|0;
       $48 = $$pre12;$51 = $$pre13;$70 = $74;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $76 = HEAP32[$4>>2]|0;
   $77 = ($76|0)==($44|0);
   if (!($77)) {
    $78 = HEAP32[580576>>2]|0;
    $79 = HEAP32[580656>>2]|0;
    $86 = $76;
    while(1) {
     $80 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,$29,$converter$i$i,1)|0);
     $81 = ($80|0)==(0);
     if (!($81)) {
      $82 = ($80|0)>(0);
      if ($82) {
       $83 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$78,574920,$converter$i$i$i2,1)|0);
       $84 = ($83|0)==(0);
       if (!($84)) {
        $85 = ($83|0)>(0);
        if ($85) {
         __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($86,$this);
        } else {
         $87 = HEAP32[$converter$i$i$i2>>2]|0;
         $88 = ($87|0)==(0|0);
         if (!($88)) {
          (FUNCTION_TABLE_iii[$87 & 4095]($86,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $89 = (($86) + 16|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$89,$79,0);
      } else {
       $90 = HEAP32[$converter$i$i>>2]|0;
       $91 = ($90|0)==(0|0);
       if (!($91)) {
        (FUNCTION_TABLE_iii[$90 & 4095]($86,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $92 = (($86) + 24|0);
     $93 = ($92|0)==($44|0);
     if ($93) {
      break;
     } else {
      $86 = $92;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i12 = 0, $$sum$i$i$i$i$i17 = 0, $$sum$i$i$i$i$i2 = 0, $$sum$i$i$i$i$i22 = 0, $$sum$i$i$i$i$i27 = 0, $$sum$i$i$i$i$i32 = 0, $$sum$i$i$i$i$i37 = 0, $$sum$i$i$i$i$i42 = 0, $$sum$i$i$i$i$i47 = 0, $$sum$i$i$i$i$i52 = 0, $$sum$i$i$i$i$i57 = 0, $$sum$i$i$i$i$i62 = 0, $$sum$i$i$i$i$i67 = 0, $$sum$i$i$i$i$i7 = 0, $$sum$i$i$i$i$i72 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i13 = 0, $$sum1$i$i$i$i$i18 = 0, $$sum1$i$i$i$i$i23 = 0;
 var $$sum1$i$i$i$i$i28 = 0, $$sum1$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i33 = 0, $$sum1$i$i$i$i$i38 = 0, $$sum1$i$i$i$i$i43 = 0, $$sum1$i$i$i$i$i48 = 0, $$sum1$i$i$i$i$i53 = 0, $$sum1$i$i$i$i$i58 = 0, $$sum1$i$i$i$i$i63 = 0, $$sum1$i$i$i$i$i68 = 0, $$sum1$i$i$i$i$i73 = 0, $$sum1$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i71 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i71 = sp;
 $0 = HEAP32[580744>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574296,$0,$converter$i$i71,0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  do {
   if ($3) {
    $4 = (($transfer) + 12|0);
    $5 = (($transfer) + 80|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($6) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($transfer) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($transfer) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($transfer) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = Math_imul($14, $12)|0;
    $$sum$i$i$i$i$i = (($8) - ($15))|0;
    $16 = (($10) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$4>>2] = $16;
    $17 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($17)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $18 = (($10) + ($$sum1$i$i$i$i$i)|0);
     $19 = (($transfer) + 20|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($18>>>0)>($20>>>0);
     if (!($21)) {
      $22 = HEAP8[$16>>0]|0;
      HEAP8[$this>>0] = $22;
      $23 = HEAP32[$4>>2]|0;
      $24 = (($23) + 1|0);
      HEAP32[$4>>2] = $24;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($4,$this,1);
   } else {
    $25 = HEAP32[$converter$i$i71>>2]|0;
    $26 = ($25|0)==(0|0);
    if (!($26)) {
     (FUNCTION_TABLE_iii[$25 & 4095]($this,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $27 = (($this) + 1|0);
 $28 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574312,$0,$converter$i$i71,0)|0);
 $29 = ($28|0)==(0);
 if (!($29)) {
  $30 = ($28|0)>(0);
  do {
   if ($30) {
    $31 = (($transfer) + 12|0);
    $32 = (($transfer) + 80|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($transfer) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($transfer) + 28|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($transfer) + 32|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = Math_imul($41, $39)|0;
    $$sum$i$i$i$i$i2 = (($35) - ($42))|0;
    $43 = (($37) + ($$sum$i$i$i$i$i2)|0);
    HEAP32[$31>>2] = $43;
    $44 = ($$sum$i$i$i$i$i2|0)<(0);
    if (!($44)) {
     $$sum1$i$i$i$i$i3 = (($$sum$i$i$i$i$i2) + 1)|0;
     $45 = (($37) + ($$sum1$i$i$i$i$i3)|0);
     $46 = (($transfer) + 20|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($45>>>0)>($47>>>0);
     if (!($48)) {
      $49 = HEAP8[$43>>0]|0;
      HEAP8[$27>>0] = $49;
      $50 = HEAP32[$31>>2]|0;
      $51 = (($50) + 1|0);
      HEAP32[$31>>2] = $51;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($31,$27,1);
   } else {
    $52 = HEAP32[$converter$i$i71>>2]|0;
    $53 = ($52|0)==(0|0);
    if (!($53)) {
     (FUNCTION_TABLE_iii[$52 & 4095]($27,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $54 = (($this) + 2|0);
 $55 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574328,$0,$converter$i$i71,0)|0);
 $56 = ($55|0)==(0);
 if (!($56)) {
  $57 = ($55|0)>(0);
  do {
   if ($57) {
    $58 = (($transfer) + 12|0);
    $59 = (($transfer) + 80|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($60) + 12|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($transfer) + 16|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($transfer) + 28|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($transfer) + 32|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = Math_imul($68, $66)|0;
    $$sum$i$i$i$i$i7 = (($62) - ($69))|0;
    $70 = (($64) + ($$sum$i$i$i$i$i7)|0);
    HEAP32[$58>>2] = $70;
    $71 = ($$sum$i$i$i$i$i7|0)<(0);
    if (!($71)) {
     $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
     $72 = (($64) + ($$sum1$i$i$i$i$i8)|0);
     $73 = (($transfer) + 20|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($72>>>0)>($74>>>0);
     if (!($75)) {
      $76 = HEAP8[$70>>0]|0;
      HEAP8[$54>>0] = $76;
      $77 = HEAP32[$58>>2]|0;
      $78 = (($77) + 1|0);
      HEAP32[$58>>2] = $78;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($58,$54,1);
   } else {
    $79 = HEAP32[$converter$i$i71>>2]|0;
    $80 = ($79|0)==(0|0);
    if (!($80)) {
     (FUNCTION_TABLE_iii[$79 & 4095]($54,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $81 = (($this) + 3|0);
 $82 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574344,$0,$converter$i$i71,0)|0);
 $83 = ($82|0)==(0);
 if (!($83)) {
  $84 = ($82|0)>(0);
  do {
   if ($84) {
    $85 = (($transfer) + 12|0);
    $86 = (($transfer) + 80|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = (($87) + 12|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($transfer) + 16|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($transfer) + 28|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($transfer) + 32|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = Math_imul($95, $93)|0;
    $$sum$i$i$i$i$i12 = (($89) - ($96))|0;
    $97 = (($91) + ($$sum$i$i$i$i$i12)|0);
    HEAP32[$85>>2] = $97;
    $98 = ($$sum$i$i$i$i$i12|0)<(0);
    if (!($98)) {
     $$sum1$i$i$i$i$i13 = (($$sum$i$i$i$i$i12) + 1)|0;
     $99 = (($91) + ($$sum1$i$i$i$i$i13)|0);
     $100 = (($transfer) + 20|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($99>>>0)>($101>>>0);
     if (!($102)) {
      $103 = HEAP8[$97>>0]|0;
      HEAP8[$81>>0] = $103;
      $104 = HEAP32[$85>>2]|0;
      $105 = (($104) + 1|0);
      HEAP32[$85>>2] = $105;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($85,$81,1);
   } else {
    $106 = HEAP32[$converter$i$i71>>2]|0;
    $107 = ($106|0)==(0|0);
    if (!($107)) {
     (FUNCTION_TABLE_iii[$106 & 4095]($81,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $108 = (($this) + 4|0);
 $109 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574360,$0,$converter$i$i71,0)|0);
 $110 = ($109|0)==(0);
 if (!($110)) {
  $111 = ($109|0)>(0);
  do {
   if ($111) {
    $112 = (($transfer) + 12|0);
    $113 = (($transfer) + 80|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = (($114) + 12|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($transfer) + 16|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (($transfer) + 28|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = (($transfer) + 32|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = Math_imul($122, $120)|0;
    $$sum$i$i$i$i$i17 = (($116) - ($123))|0;
    $124 = (($118) + ($$sum$i$i$i$i$i17)|0);
    HEAP32[$112>>2] = $124;
    $125 = ($$sum$i$i$i$i$i17|0)<(0);
    if (!($125)) {
     $$sum1$i$i$i$i$i18 = (($$sum$i$i$i$i$i17) + 1)|0;
     $126 = (($118) + ($$sum1$i$i$i$i$i18)|0);
     $127 = (($transfer) + 20|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = ($126>>>0)>($128>>>0);
     if (!($129)) {
      $130 = HEAP8[$124>>0]|0;
      HEAP8[$108>>0] = $130;
      $131 = HEAP32[$112>>2]|0;
      $132 = (($131) + 1|0);
      HEAP32[$112>>2] = $132;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($112,$108,1);
   } else {
    $133 = HEAP32[$converter$i$i71>>2]|0;
    $134 = ($133|0)==(0|0);
    if (!($134)) {
     (FUNCTION_TABLE_iii[$133 & 4095]($108,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $135 = (($this) + 5|0);
 $136 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574376,$0,$converter$i$i71,0)|0);
 $137 = ($136|0)==(0);
 if (!($137)) {
  $138 = ($136|0)>(0);
  do {
   if ($138) {
    $139 = (($transfer) + 12|0);
    $140 = (($transfer) + 80|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (($141) + 12|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = (($transfer) + 16|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = (($transfer) + 28|0);
    $147 = HEAP32[$146>>2]|0;
    $148 = (($transfer) + 32|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = Math_imul($149, $147)|0;
    $$sum$i$i$i$i$i22 = (($143) - ($150))|0;
    $151 = (($145) + ($$sum$i$i$i$i$i22)|0);
    HEAP32[$139>>2] = $151;
    $152 = ($$sum$i$i$i$i$i22|0)<(0);
    if (!($152)) {
     $$sum1$i$i$i$i$i23 = (($$sum$i$i$i$i$i22) + 1)|0;
     $153 = (($145) + ($$sum1$i$i$i$i$i23)|0);
     $154 = (($transfer) + 20|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = ($153>>>0)>($155>>>0);
     if (!($156)) {
      $157 = HEAP8[$151>>0]|0;
      HEAP8[$135>>0] = $157;
      $158 = HEAP32[$139>>2]|0;
      $159 = (($158) + 1|0);
      HEAP32[$139>>2] = $159;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($139,$135,1);
   } else {
    $160 = HEAP32[$converter$i$i71>>2]|0;
    $161 = ($160|0)==(0|0);
    if (!($161)) {
     (FUNCTION_TABLE_iii[$160 & 4095]($135,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $162 = (($this) + 6|0);
 $163 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574392,$0,$converter$i$i71,0)|0);
 $164 = ($163|0)==(0);
 if (!($164)) {
  $165 = ($163|0)>(0);
  do {
   if ($165) {
    $166 = (($transfer) + 12|0);
    $167 = (($transfer) + 80|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = (($168) + 12|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = (($transfer) + 16|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = (($transfer) + 28|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = (($transfer) + 32|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = Math_imul($176, $174)|0;
    $$sum$i$i$i$i$i27 = (($170) - ($177))|0;
    $178 = (($172) + ($$sum$i$i$i$i$i27)|0);
    HEAP32[$166>>2] = $178;
    $179 = ($$sum$i$i$i$i$i27|0)<(0);
    if (!($179)) {
     $$sum1$i$i$i$i$i28 = (($$sum$i$i$i$i$i27) + 1)|0;
     $180 = (($172) + ($$sum1$i$i$i$i$i28)|0);
     $181 = (($transfer) + 20|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = ($180>>>0)>($182>>>0);
     if (!($183)) {
      $184 = HEAP8[$178>>0]|0;
      HEAP8[$162>>0] = $184;
      $185 = HEAP32[$166>>2]|0;
      $186 = (($185) + 1|0);
      HEAP32[$166>>2] = $186;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($166,$162,1);
   } else {
    $187 = HEAP32[$converter$i$i71>>2]|0;
    $188 = ($187|0)==(0|0);
    if (!($188)) {
     (FUNCTION_TABLE_iii[$187 & 4095]($162,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $189 = (($this) + 7|0);
 $190 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574408,$0,$converter$i$i71,0)|0);
 $191 = ($190|0)==(0);
 if (!($191)) {
  $192 = ($190|0)>(0);
  do {
   if ($192) {
    $193 = (($transfer) + 12|0);
    $194 = (($transfer) + 80|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = (($195) + 12|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = (($transfer) + 16|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = (($transfer) + 28|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = (($transfer) + 32|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = Math_imul($203, $201)|0;
    $$sum$i$i$i$i$i32 = (($197) - ($204))|0;
    $205 = (($199) + ($$sum$i$i$i$i$i32)|0);
    HEAP32[$193>>2] = $205;
    $206 = ($$sum$i$i$i$i$i32|0)<(0);
    if (!($206)) {
     $$sum1$i$i$i$i$i33 = (($$sum$i$i$i$i$i32) + 1)|0;
     $207 = (($199) + ($$sum1$i$i$i$i$i33)|0);
     $208 = (($transfer) + 20|0);
     $209 = HEAP32[$208>>2]|0;
     $210 = ($207>>>0)>($209>>>0);
     if (!($210)) {
      $211 = HEAP8[$205>>0]|0;
      HEAP8[$189>>0] = $211;
      $212 = HEAP32[$193>>2]|0;
      $213 = (($212) + 1|0);
      HEAP32[$193>>2] = $213;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($193,$189,1);
   } else {
    $214 = HEAP32[$converter$i$i71>>2]|0;
    $215 = ($214|0)==(0|0);
    if (!($215)) {
     (FUNCTION_TABLE_iii[$214 & 4095]($189,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $216 = (($this) + 8|0);
 $217 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574424,$0,$converter$i$i71,0)|0);
 $218 = ($217|0)==(0);
 if (!($218)) {
  $219 = ($217|0)>(0);
  do {
   if ($219) {
    $220 = (($transfer) + 12|0);
    $221 = (($transfer) + 80|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = (($222) + 12|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = (($transfer) + 16|0);
    $226 = HEAP32[$225>>2]|0;
    $227 = (($transfer) + 28|0);
    $228 = HEAP32[$227>>2]|0;
    $229 = (($transfer) + 32|0);
    $230 = HEAP32[$229>>2]|0;
    $231 = Math_imul($230, $228)|0;
    $$sum$i$i$i$i$i37 = (($224) - ($231))|0;
    $232 = (($226) + ($$sum$i$i$i$i$i37)|0);
    HEAP32[$220>>2] = $232;
    $233 = ($$sum$i$i$i$i$i37|0)<(0);
    if (!($233)) {
     $$sum1$i$i$i$i$i38 = (($$sum$i$i$i$i$i37) + 1)|0;
     $234 = (($226) + ($$sum1$i$i$i$i$i38)|0);
     $235 = (($transfer) + 20|0);
     $236 = HEAP32[$235>>2]|0;
     $237 = ($234>>>0)>($236>>>0);
     if (!($237)) {
      $238 = HEAP8[$232>>0]|0;
      HEAP8[$216>>0] = $238;
      $239 = HEAP32[$220>>2]|0;
      $240 = (($239) + 1|0);
      HEAP32[$220>>2] = $240;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($220,$216,1);
   } else {
    $241 = HEAP32[$converter$i$i71>>2]|0;
    $242 = ($241|0)==(0|0);
    if (!($242)) {
     (FUNCTION_TABLE_iii[$241 & 4095]($216,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $243 = (($this) + 9|0);
 $244 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574440,$0,$converter$i$i71,0)|0);
 $245 = ($244|0)==(0);
 if (!($245)) {
  $246 = ($244|0)>(0);
  do {
   if ($246) {
    $247 = (($transfer) + 12|0);
    $248 = (($transfer) + 80|0);
    $249 = HEAP32[$248>>2]|0;
    $250 = (($249) + 12|0);
    $251 = HEAP32[$250>>2]|0;
    $252 = (($transfer) + 16|0);
    $253 = HEAP32[$252>>2]|0;
    $254 = (($transfer) + 28|0);
    $255 = HEAP32[$254>>2]|0;
    $256 = (($transfer) + 32|0);
    $257 = HEAP32[$256>>2]|0;
    $258 = Math_imul($257, $255)|0;
    $$sum$i$i$i$i$i42 = (($251) - ($258))|0;
    $259 = (($253) + ($$sum$i$i$i$i$i42)|0);
    HEAP32[$247>>2] = $259;
    $260 = ($$sum$i$i$i$i$i42|0)<(0);
    if (!($260)) {
     $$sum1$i$i$i$i$i43 = (($$sum$i$i$i$i$i42) + 1)|0;
     $261 = (($253) + ($$sum1$i$i$i$i$i43)|0);
     $262 = (($transfer) + 20|0);
     $263 = HEAP32[$262>>2]|0;
     $264 = ($261>>>0)>($263>>>0);
     if (!($264)) {
      $265 = HEAP8[$259>>0]|0;
      HEAP8[$243>>0] = $265;
      $266 = HEAP32[$247>>2]|0;
      $267 = (($266) + 1|0);
      HEAP32[$247>>2] = $267;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($247,$243,1);
   } else {
    $268 = HEAP32[$converter$i$i71>>2]|0;
    $269 = ($268|0)==(0|0);
    if (!($269)) {
     (FUNCTION_TABLE_iii[$268 & 4095]($243,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $270 = (($this) + 10|0);
 $271 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574456,$0,$converter$i$i71,0)|0);
 $272 = ($271|0)==(0);
 if (!($272)) {
  $273 = ($271|0)>(0);
  do {
   if ($273) {
    $274 = (($transfer) + 12|0);
    $275 = (($transfer) + 80|0);
    $276 = HEAP32[$275>>2]|0;
    $277 = (($276) + 12|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = (($transfer) + 16|0);
    $280 = HEAP32[$279>>2]|0;
    $281 = (($transfer) + 28|0);
    $282 = HEAP32[$281>>2]|0;
    $283 = (($transfer) + 32|0);
    $284 = HEAP32[$283>>2]|0;
    $285 = Math_imul($284, $282)|0;
    $$sum$i$i$i$i$i47 = (($278) - ($285))|0;
    $286 = (($280) + ($$sum$i$i$i$i$i47)|0);
    HEAP32[$274>>2] = $286;
    $287 = ($$sum$i$i$i$i$i47|0)<(0);
    if (!($287)) {
     $$sum1$i$i$i$i$i48 = (($$sum$i$i$i$i$i47) + 1)|0;
     $288 = (($280) + ($$sum1$i$i$i$i$i48)|0);
     $289 = (($transfer) + 20|0);
     $290 = HEAP32[$289>>2]|0;
     $291 = ($288>>>0)>($290>>>0);
     if (!($291)) {
      $292 = HEAP8[$286>>0]|0;
      HEAP8[$270>>0] = $292;
      $293 = HEAP32[$274>>2]|0;
      $294 = (($293) + 1|0);
      HEAP32[$274>>2] = $294;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($274,$270,1);
   } else {
    $295 = HEAP32[$converter$i$i71>>2]|0;
    $296 = ($295|0)==(0|0);
    if (!($296)) {
     (FUNCTION_TABLE_iii[$295 & 4095]($270,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $297 = (($this) + 11|0);
 $298 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574472,$0,$converter$i$i71,0)|0);
 $299 = ($298|0)==(0);
 if (!($299)) {
  $300 = ($298|0)>(0);
  do {
   if ($300) {
    $301 = (($transfer) + 12|0);
    $302 = (($transfer) + 80|0);
    $303 = HEAP32[$302>>2]|0;
    $304 = (($303) + 12|0);
    $305 = HEAP32[$304>>2]|0;
    $306 = (($transfer) + 16|0);
    $307 = HEAP32[$306>>2]|0;
    $308 = (($transfer) + 28|0);
    $309 = HEAP32[$308>>2]|0;
    $310 = (($transfer) + 32|0);
    $311 = HEAP32[$310>>2]|0;
    $312 = Math_imul($311, $309)|0;
    $$sum$i$i$i$i$i52 = (($305) - ($312))|0;
    $313 = (($307) + ($$sum$i$i$i$i$i52)|0);
    HEAP32[$301>>2] = $313;
    $314 = ($$sum$i$i$i$i$i52|0)<(0);
    if (!($314)) {
     $$sum1$i$i$i$i$i53 = (($$sum$i$i$i$i$i52) + 1)|0;
     $315 = (($307) + ($$sum1$i$i$i$i$i53)|0);
     $316 = (($transfer) + 20|0);
     $317 = HEAP32[$316>>2]|0;
     $318 = ($315>>>0)>($317>>>0);
     if (!($318)) {
      $319 = HEAP8[$313>>0]|0;
      HEAP8[$297>>0] = $319;
      $320 = HEAP32[$301>>2]|0;
      $321 = (($320) + 1|0);
      HEAP32[$301>>2] = $321;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($301,$297,1);
   } else {
    $322 = HEAP32[$converter$i$i71>>2]|0;
    $323 = ($322|0)==(0|0);
    if (!($323)) {
     (FUNCTION_TABLE_iii[$322 & 4095]($297,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $324 = (($this) + 12|0);
 $325 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574488,$0,$converter$i$i71,0)|0);
 $326 = ($325|0)==(0);
 if (!($326)) {
  $327 = ($325|0)>(0);
  do {
   if ($327) {
    $328 = (($transfer) + 12|0);
    $329 = (($transfer) + 80|0);
    $330 = HEAP32[$329>>2]|0;
    $331 = (($330) + 12|0);
    $332 = HEAP32[$331>>2]|0;
    $333 = (($transfer) + 16|0);
    $334 = HEAP32[$333>>2]|0;
    $335 = (($transfer) + 28|0);
    $336 = HEAP32[$335>>2]|0;
    $337 = (($transfer) + 32|0);
    $338 = HEAP32[$337>>2]|0;
    $339 = Math_imul($338, $336)|0;
    $$sum$i$i$i$i$i57 = (($332) - ($339))|0;
    $340 = (($334) + ($$sum$i$i$i$i$i57)|0);
    HEAP32[$328>>2] = $340;
    $341 = ($$sum$i$i$i$i$i57|0)<(0);
    if (!($341)) {
     $$sum1$i$i$i$i$i58 = (($$sum$i$i$i$i$i57) + 1)|0;
     $342 = (($334) + ($$sum1$i$i$i$i$i58)|0);
     $343 = (($transfer) + 20|0);
     $344 = HEAP32[$343>>2]|0;
     $345 = ($342>>>0)>($344>>>0);
     if (!($345)) {
      $346 = HEAP8[$340>>0]|0;
      HEAP8[$324>>0] = $346;
      $347 = HEAP32[$328>>2]|0;
      $348 = (($347) + 1|0);
      HEAP32[$328>>2] = $348;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($328,$324,1);
   } else {
    $349 = HEAP32[$converter$i$i71>>2]|0;
    $350 = ($349|0)==(0|0);
    if (!($350)) {
     (FUNCTION_TABLE_iii[$349 & 4095]($324,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $351 = (($this) + 13|0);
 $352 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574504,$0,$converter$i$i71,0)|0);
 $353 = ($352|0)==(0);
 if (!($353)) {
  $354 = ($352|0)>(0);
  do {
   if ($354) {
    $355 = (($transfer) + 12|0);
    $356 = (($transfer) + 80|0);
    $357 = HEAP32[$356>>2]|0;
    $358 = (($357) + 12|0);
    $359 = HEAP32[$358>>2]|0;
    $360 = (($transfer) + 16|0);
    $361 = HEAP32[$360>>2]|0;
    $362 = (($transfer) + 28|0);
    $363 = HEAP32[$362>>2]|0;
    $364 = (($transfer) + 32|0);
    $365 = HEAP32[$364>>2]|0;
    $366 = Math_imul($365, $363)|0;
    $$sum$i$i$i$i$i62 = (($359) - ($366))|0;
    $367 = (($361) + ($$sum$i$i$i$i$i62)|0);
    HEAP32[$355>>2] = $367;
    $368 = ($$sum$i$i$i$i$i62|0)<(0);
    if (!($368)) {
     $$sum1$i$i$i$i$i63 = (($$sum$i$i$i$i$i62) + 1)|0;
     $369 = (($361) + ($$sum1$i$i$i$i$i63)|0);
     $370 = (($transfer) + 20|0);
     $371 = HEAP32[$370>>2]|0;
     $372 = ($369>>>0)>($371>>>0);
     if (!($372)) {
      $373 = HEAP8[$367>>0]|0;
      HEAP8[$351>>0] = $373;
      $374 = HEAP32[$355>>2]|0;
      $375 = (($374) + 1|0);
      HEAP32[$355>>2] = $375;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($355,$351,1);
   } else {
    $376 = HEAP32[$converter$i$i71>>2]|0;
    $377 = ($376|0)==(0|0);
    if (!($377)) {
     (FUNCTION_TABLE_iii[$376 & 4095]($351,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $378 = (($this) + 14|0);
 $379 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574520,$0,$converter$i$i71,0)|0);
 $380 = ($379|0)==(0);
 if (!($380)) {
  $381 = ($379|0)>(0);
  L171: do {
   if ($381) {
    $382 = (($transfer) + 12|0);
    $383 = (($transfer) + 80|0);
    $384 = HEAP32[$383>>2]|0;
    $385 = (($384) + 12|0);
    $386 = HEAP32[$385>>2]|0;
    $387 = (($transfer) + 16|0);
    $388 = HEAP32[$387>>2]|0;
    $389 = (($transfer) + 28|0);
    $390 = HEAP32[$389>>2]|0;
    $391 = (($transfer) + 32|0);
    $392 = HEAP32[$391>>2]|0;
    $393 = Math_imul($392, $390)|0;
    $$sum$i$i$i$i$i67 = (($386) - ($393))|0;
    $394 = (($388) + ($$sum$i$i$i$i$i67)|0);
    HEAP32[$382>>2] = $394;
    $395 = ($$sum$i$i$i$i$i67|0)<(0);
    do {
     if (!($395)) {
      $$sum1$i$i$i$i$i68 = (($$sum$i$i$i$i$i67) + 1)|0;
      $396 = (($388) + ($$sum1$i$i$i$i$i68)|0);
      $397 = (($transfer) + 20|0);
      $398 = HEAP32[$397>>2]|0;
      $399 = ($396>>>0)>($398>>>0);
      if ($399) {
       break;
      }
      $400 = HEAP8[$394>>0]|0;
      HEAP8[$378>>0] = $400;
      $401 = HEAP32[$382>>2]|0;
      $402 = (($401) + 1|0);
      HEAP32[$382>>2] = $402;
      break L171;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($382,$378,1);
   } else {
    $403 = HEAP32[$converter$i$i71>>2]|0;
    $404 = ($403|0)==(0|0);
    if (!($404)) {
     (FUNCTION_TABLE_iii[$403 & 4095]($378,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $405 = (($this) + 15|0);
 $406 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574536,$0,$converter$i$i71,0)|0);
 $407 = ($406|0)==(0);
 if ($407) {
  STACKTOP = sp;return;
 }
 $408 = ($406|0)>(0);
 L184: do {
  if ($408) {
   $409 = (($transfer) + 12|0);
   $410 = (($transfer) + 80|0);
   $411 = HEAP32[$410>>2]|0;
   $412 = (($411) + 12|0);
   $413 = HEAP32[$412>>2]|0;
   $414 = (($transfer) + 16|0);
   $415 = HEAP32[$414>>2]|0;
   $416 = (($transfer) + 28|0);
   $417 = HEAP32[$416>>2]|0;
   $418 = (($transfer) + 32|0);
   $419 = HEAP32[$418>>2]|0;
   $420 = Math_imul($419, $417)|0;
   $$sum$i$i$i$i$i72 = (($413) - ($420))|0;
   $421 = (($415) + ($$sum$i$i$i$i$i72)|0);
   HEAP32[$409>>2] = $421;
   $422 = ($$sum$i$i$i$i$i72|0)<(0);
   do {
    if (!($422)) {
     $$sum1$i$i$i$i$i73 = (($$sum$i$i$i$i$i72) + 1)|0;
     $423 = (($415) + ($$sum1$i$i$i$i$i73)|0);
     $424 = (($transfer) + 20|0);
     $425 = HEAP32[$424>>2]|0;
     $426 = ($423>>>0)>($425>>>0);
     if ($426) {
      break;
     }
     $427 = HEAP8[$421>>0]|0;
     HEAP8[$405>>0] = $427;
     $428 = HEAP32[$409>>2]|0;
     $429 = (($428) + 1|0);
     HEAP32[$409>>2] = $429;
     break L184;
    }
   } while(0);
   __ZN12CachedReader15UpdateReadCacheEPvj($409,$405,1);
  } else {
   $430 = HEAP32[$converter$i$i71>>2]|0;
   $431 = ($430|0)==(0|0);
   if (!($431)) {
    (FUNCTION_TABLE_iii[$430 & 4095]($405,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,574872,574872,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI8Vector3fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*12)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580776>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $53 = HEAP32[$data>>2]|0;
    $54 = ($53|0)==($11|0);
    if ($54) {
     break;
    } else {
     $i$12 = $53;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$i$12,574096,0);
     $55 = (($i$12) + 12|0);
     $56 = ($55|0)==($11|0);
     if ($56) {
      break L4;
     } else {
      $i$12 = $55;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $30 = 0;$33 = $24;$i$01 = $27;
     while(1) {
      $29 = Math_imul($30, $20)|0;
      $31 = (($29) + ($26))|0;
      $32 = (($33) + 20|0);
      HEAP32[$32>>2] = $31;
      $34 = (($33) + 12|0);
      HEAP32[$34>>2] = $31;
      $35 = (($33) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($2,$33);
      $36 = $2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      $42 = $35;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      $46 = HEAP32[$21>>2]|0;
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + 1)|0;
      HEAP32[$46>>2] = $48;
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$01,574552,0);
      $49 = (($i$01) + 4|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,574560,0);
      $50 = (($i$01) + 8|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,574568,0);
      $51 = (($i$01) + 12|0);
      $52 = ($51|0)==($11|0);
      if ($52) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre6 = HEAP32[$$pre>>2]|0;
      $$pre7 = HEAP32[$16>>2]|0;
      $30 = $$pre6;$33 = $$pre7;$i$01 = $51;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580776>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$data,574552,0);
  $5 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$5,574560,0);
  $6 = (($data) + 8|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$6,574568,0);
 } else {
  $7 = HEAP32[$converter$i>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   (FUNCTION_TABLE_iii[$7 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI13ProbeSetIndexLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,574872,574872,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI13ProbeSetIndexLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*24)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,574928,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN13ProbeSetIndex8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 24|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,574928,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN13ProbeSetIndex8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 24|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13ProbeSetIndex8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574576,574920,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  } else {
   $3 = HEAP32[$converter$i$i>>2]|0;
   $4 = ($3|0)==(0|0);
   if (!($4)) {
    (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $5 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$5,574584,0);
 $6 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$6,574600,0);
 STACKTOP = sp;return;
}
function __ZN26ProbeSetTetrahedralization8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580760>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574608,$0,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11TetrahedronLj4EEEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 16|0);
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574624,$0,$converter$i$i1,1)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = ($7|0)>(0);
 if ($9) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags($transfer,$6,0);
 } else {
  $10 = HEAP32[$converter$i$i1>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   (FUNCTION_TABLE_iii[$10 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11TetrahedronLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,574872,574872,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI11TetrahedronLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*80)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,574992,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN11Tetrahedron8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 80|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,574096,574992,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN11Tetrahedron8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 80|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11Tetrahedron8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,574640,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$0,574656,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$1,574672,0);
 $2 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$2,574688,0);
 $3 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$3,574704,0);
 $4 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$4,574720,0);
 $5 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$5,574736,0);
 $6 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$6,574752,0);
 $7 = (($this) + 32|0);
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,574768,574976,$converter$i$i,1)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  __ZN10Matrix3x4f8TransferI14SafeBinaryReadEEvRT_($7,$transfer);
 } else {
  $11 = HEAP32[$converter$i$i>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (FUNCTION_TABLE_iii[$11 & 4095]($7,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10Matrix3x4f8TransferI14SafeBinaryReadEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$this,574776,0);
 $0 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$0,574784,0);
 $1 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$1,574792,0);
 $2 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$2,574800,0);
 $3 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$3,574808,0);
 $4 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$4,574816,0);
 $5 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$5,574824,0);
 $6 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$6,574832,0);
 $7 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$7,574840,0);
 $8 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$8,574848,0);
 $9 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$9,574856,0);
 $10 = (($this) + 44|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$10,574864,0);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferIN11LightProbes14LightProbeDataEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $size$i$i$i$i$i$i$i = sp + 80|0;
 $p$i$i$i$i$i$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,574904,$data,$metaFlag);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574200,574944,$data,0);
 $0 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574608,$0,$data,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,574872,574872,$size$i$i$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574096,574992,$p$i$i$i$i$i$i,0);
 __ZN11Tetrahedron8TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i,$this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $1 = (($data) + 16|0);
 __ZN13ProxyTransfer8TransferI13dynamic_arrayI8Vector3fLj4EEEEvRT_PKc17TransferMetaFlags($this,$1,574624,0);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $2 = (($data) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574224,$0,$2,0);
 ;HEAP32[$p$i$i$i$i$i$i+0>>2]=0|0;HEAP32[$p$i$i$i$i$i$i+4>>2]=0|0;HEAP32[$p$i$i$i$i$i$i+8>>2]=0|0;HEAP32[$p$i$i$i$i$i$i+12>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,574872,574872,$size$i$i$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574096,574928,$p$i$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574576,574920,$p$i$i$i$i$i$i,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i,$this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $3 = (($p$i$i$i$i$i$i) + 16|0);
 $4 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574584,$4,$3,0);
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($7) + (($9*24)|0)|0) + 12|0);
 HEAP32[$10>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $11 = (($p$i$i$i$i$i$i) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574600,$4,$11,0);
 $12 = HEAP32[$5>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$8>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $16 = (($data) + 48|0);
 __ZN13ProxyTransfer8TransferI13dynamic_arrayI8Vector3fLj4EEEEvRT_PKc17TransferMetaFlags($this,$16,574240,0);
 $17 = (($data) + 64|0);
 $18 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574256,$18,$17,0);
 ;HEAP32[$p$i$i$i$i$i$i+0>>2]=0|0;HEAP32[$p$i$i$i$i$i$i+4>>2]=0|0;HEAP32[$p$i$i$i$i$i$i+8>>2]=0|0;HEAP32[$p$i$i$i$i$i$i+12>>2]=0|0;HEAP32[$p$i$i$i$i$i$i+16>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,574872,574872,$size$i$i$i$i$i$i$i,0);
 $19 = HEAP32[580608>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574096,$19,$p$i$i$i$i$i$i,0);
 $20 = HEAP32[580576>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$20,574920,$p$i$i$i$i$i$i,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i,$this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $21 = (($p$i$i$i$i$i$i) + 16|0);
 $22 = HEAP32[580656>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$22,$4,$21,0);
 $23 = HEAP32[$5>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$8>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11LightProbes19SHCoefficientsBaked8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574104,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574112,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574120,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574128,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574136,$0,$22,0);
 $23 = HEAP32[$1>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$4>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $27 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574144,$0,$27,0);
 $28 = HEAP32[$1>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$4>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574152,$0,$32,0);
 $33 = HEAP32[$1>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$4>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $37 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574160,$0,$37,0);
 $38 = HEAP32[$1>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$4>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $42 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574168,$0,$42,0);
 $43 = HEAP32[$1>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ((($44) + (($45*24)|0)|0) + 12|0);
 HEAP32[$46>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $47 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574176,$0,$47,0);
 $48 = HEAP32[$1>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$4>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $52 = (($this) + 40|0);
 $53 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574184,$53,$52,0);
 $54 = HEAP32[$1>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$4>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $58 = (($this) + 44|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574192,$53,$58,0);
 $59 = HEAP32[$1>>2]|0;
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$4>>2]|0;
 $62 = ((($60) + (($61*24)|0)|0) + 12|0);
 HEAP32[$62>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI13dynamic_arrayI8Vector3fLj4EEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp + 12|0;
 $p$i$i = sp;
 $0 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$0,$data,$metaFlag);
 HEAPF32[$p$i$i>>2] = Math_fround(0.0);
 $1 = (($p$i$i) + 4|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($p$i$i) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,574872,574872,$size$i$i$i,0);
 $3 = HEAP32[580776>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574096,$3,$p$i$i,0);
 $4 = (($this) + 16|0);
 $5 = (__ZNK16TypeTreeIterator7GetNodeEv($4)|0);
 $6 = (($5) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 | 2097152;
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($11) + (($13*24)|0)|0) + 20|0);
 HEAP32[$14>>2] = $8;
 $15 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574552,$15,$p$i$i,0);
 $16 = HEAP32[$9>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$12>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574560,$15,$1,0);
 $20 = HEAP32[$9>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$12>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,574568,$15,$2,0);
 $24 = HEAP32[$9>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$12>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7Hash1288TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574296,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 1|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574312,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 2|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574328,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 3|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574344,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574360,$0,$22,0);
 $23 = HEAP32[$1>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$4>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $27 = (($this) + 5|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574376,$0,$27,0);
 $28 = HEAP32[$1>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$4>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = (($this) + 6|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574392,$0,$32,0);
 $33 = HEAP32[$1>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$4>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $37 = (($this) + 7|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574408,$0,$37,0);
 $38 = HEAP32[$1>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$4>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $42 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574424,$0,$42,0);
 $43 = HEAP32[$1>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ((($44) + (($45*24)|0)|0) + 12|0);
 HEAP32[$46>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $47 = (($this) + 9|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574440,$0,$47,0);
 $48 = HEAP32[$1>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$4>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $52 = (($this) + 10|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574456,$0,$52,0);
 $53 = HEAP32[$1>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$4>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $57 = (($this) + 11|0);
 $58 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574472,$58,$57,0);
 $59 = HEAP32[$1>>2]|0;
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$4>>2]|0;
 $62 = ((($60) + (($61*24)|0)|0) + 12|0);
 HEAP32[$62>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $63 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574488,$58,$63,0);
 $64 = HEAP32[$1>>2]|0;
 $65 = HEAP32[$64>>2]|0;
 $66 = HEAP32[$4>>2]|0;
 $67 = ((($65) + (($66*24)|0)|0) + 12|0);
 HEAP32[$67>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $68 = (($this) + 13|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574504,$58,$68,0);
 $69 = HEAP32[$1>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$4>>2]|0;
 $72 = ((($70) + (($71*24)|0)|0) + 12|0);
 HEAP32[$72>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $73 = (($this) + 14|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574520,$58,$73,0);
 $74 = HEAP32[$1>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 $76 = HEAP32[$4>>2]|0;
 $77 = ((($75) + (($76*24)|0)|0) + 12|0);
 HEAP32[$77>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $78 = (($this) + 15|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574536,$58,$78,0);
 $79 = HEAP32[$1>>2]|0;
 $80 = HEAP32[$79>>2]|0;
 $81 = HEAP32[$4>>2]|0;
 $82 = ((($80) + (($81*24)|0)|0) + 12|0);
 HEAP32[$82>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11Tetrahedron8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574640,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574656,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574672,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574688,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574704,$0,$22,0);
 $23 = HEAP32[$1>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$4>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $27 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574720,$0,$27,0);
 $28 = HEAP32[$1>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$4>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574736,$0,$32,0);
 $33 = HEAP32[$1>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$4>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $37 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574752,$0,$37,0);
 $38 = HEAP32[$1>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$4>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $42 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,574768,574976,$42,0);
 __ZN10Matrix3x4f8TransferI13ProxyTransferEEvRT_($42,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10Matrix3x4f8TransferI13ProxyTransferEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574776,$0,$this,0);
 $1 = (($t) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($t) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $7 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574784,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $12 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574792,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $17 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574800,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $22 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574808,$0,$22,0);
 $23 = HEAP32[$1>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$4>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $27 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574816,$0,$27,0);
 $28 = HEAP32[$1>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$4>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $32 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574824,$0,$32,0);
 $33 = HEAP32[$1>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$4>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $37 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574832,$0,$37,0);
 $38 = HEAP32[$1>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$4>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $42 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574840,$0,$42,0);
 $43 = HEAP32[$1>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ((($44) + (($45*24)|0)|0) + 12|0);
 HEAP32[$46>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $47 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574848,$0,$47,0);
 $48 = HEAP32[$1>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$4>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $52 = (($this) + 32|0);
 $53 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574856,$53,$52,0);
 $54 = HEAP32[$1>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$4>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $58 = (($this) + 44|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,574864,$53,$58,0);
 $59 = HEAP32[$1>>2]|0;
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$4>>2]|0;
 $62 = ((($60) + (($61*24)|0)|0) + 12|0);
 HEAP32[$62>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 STACKTOP = sp;return;
}
function __ZN11LightProbesD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$2 = 0, $$23 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i8 = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i9 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i11 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i12 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((573928 + 8|0));
 $3 = (($this) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 do {
  if ($5) {
   $6 = (($this) + 140|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($this) + 144|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$2>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($7|0),($$byval_copy2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$6>>2] = 0;
    label = 4;
    break;
   }
   $33 = ___cxa_find_matching_catch()|0;
   $34 = tempRet0;
   $35 = (($this) + 136|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)>(-1);
   if ($37) {
    $38 = (($this) + 124|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($this) + 128|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$0>>2] = $41;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($39|0),($$byval_copy2|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     $62 = ___cxa_find_matching_catch(0|0)|0;
     $63 = tempRet0;
     ___clang_call_terminate($62);
     // unreachable;
    } else {
     HEAP32[$38>>2] = 0;
     $$0 = $34;$$01 = $33;
     label = 17;
     break;
    }
   } else {
    $$0 = $34;$$01 = $33;
    label = 17;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $12 = (($this) + 136|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)>(-1);
   do {
    if ($14) {
     $15 = (($this) + 124|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($this) + 128|0);
     $18 = HEAP32[$17>>2]|0;
     HEAP32[$1>>2] = $18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($16|0),($$byval_copy2|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      $44 = ___cxa_find_matching_catch()|0;
      $45 = tempRet0;
      $$0 = $45;$$01 = $44;
      label = 17;
      break L10;
     } else {
      HEAP32[$15>>2] = 0;
      break;
     }
    }
   } while(0);
   $21 = (($this) + 112|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    $24 = (($this) + 116|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==($22|0);
    if (!($26)) {
     $__new_last2$i$i$i$i$i$i$i$i$i = $22;
     $scevgep$i$i$i$i$i$i$i$i$i = (($25) + -40|0);
     $27 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($27)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
     $28 = (($uglygep3$i$i$i$i$i$i$i$i$i>>>0) / 40)&-1;
     $29 = $28 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i = (($25) + (($29*40)|0)|0);
     HEAP32[$24>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($22);
   }
   $30 = (($this) + 28|0);
   __THREW__ = 0;
   invoke_vi(3422,($30|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    $$2 = $56;$$23 = $55;
    break;
   } else {
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $46 = (($this) + 112|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  if (!($48)) {
   $49 = (($this) + 116|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==($47|0);
   if (!($51)) {
    $__new_last2$i$i$i$i$i$i$i$i$i8 = $47;
    $scevgep$i$i$i$i$i$i$i$i$i9 = (($50) + -40|0);
    $52 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i8))|0;
    $uglygep$i$i$i$i$i$i$i$i$i11 = (($scevgep$i$i$i$i$i$i$i$i$i9) + ($52)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i12 = $uglygep$i$i$i$i$i$i$i$i$i11;
    $53 = (($uglygep3$i$i$i$i$i$i$i$i$i12>>>0) / 40)&-1;
    $54 = $53 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i13 = (($50) + (($54*40)|0)|0);
    HEAP32[$49>>2] = $scevgep4$i$i$i$i$i$i$i$i$i13;
   }
   __ZdlPv($47);
  }
  $57 = (($this) + 28|0);
  __THREW__ = 0;
  invoke_vi(3422,($57|0));
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if ($59) {
   $62 = ___cxa_find_matching_catch(0|0)|0;
   $63 = tempRet0;
   ___clang_call_terminate($62);
   // unreachable;
  } else {
   $$2 = $$0;$$23 = $$01;
  }
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 if ($61) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 } else {
  ___resumeException($$23|0);
  // unreachable;
 }
}
function __Z37GetBarycentricCoordinatesForOuterCellPPK8Vector3fRK13dynamic_arrayIS_Lj4EERS0_RK11TetrahedronR8Vector4fRf($positions,$hullRays,$p,$tet,$coords,$t) {
 $positions = $positions|0;
 $hullRays = $hullRays|0;
 $p = $p|0;
 $tet = $tet|0;
 $coords = $coords|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = Math_fround(0), $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = Math_fround(0), $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0.0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0.0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0);
 var $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $tri = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tri = sp + 12|0;
 $0 = sp;
 $1 = HEAP32[$positions>>2]|0;
 $2 = (($positions) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(HEAPF32[$1>>2]);
 $6 = Math_fround($4 - $5);
 $7 = (($3) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($1) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 - $10);
 $12 = (($3) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = (($positions) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 - $5);
 $21 = (($18) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 - $10);
 $24 = (($18) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 - $15);
 $27 = Math_fround($16 * $23);
 $28 = Math_fround($11 * $26);
 $29 = Math_fround($27 - $28);
 $30 = Math_fround($6 * $26);
 $31 = Math_fround($16 * $20);
 $32 = Math_fround($30 - $31);
 $33 = Math_fround($11 * $20);
 $34 = Math_fround($6 * $23);
 $35 = Math_fround($33 - $34);
 $36 = Math_fround(HEAPF32[$p>>2]);
 $37 = Math_fround($36 - $5);
 $38 = (($p) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 - $10);
 $41 = (($p) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($42 - $15);
 $44 = Math_fround($37 * $29);
 $45 = Math_fround($40 * $32);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($35 * $43);
 $48 = Math_fround($46 + $47);
 HEAPF32[$t>>2] = $48;
 $49 = $48 < Math_fround(0.0);
 if ($49) {
  HEAPF32[$coords>>2] = Math_fround(0.0);
  $50 = (($coords) + 4|0);
  HEAPF32[$50>>2] = Math_fround(0.0);
  $51 = (($coords) + 8|0);
  HEAPF32[$51>>2] = Math_fround(0.0);
  $52 = (($coords) + 12|0);
  HEAPF32[$52>>2] = Math_fround(-1.0);
  STACKTOP = sp;return;
 }
 $53 = (($tet) + 32|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround(HEAPF32[$p>>2]);
 $56 = Math_fround($54 * $55);
 $57 = (($tet) + 44|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround(HEAPF32[$38>>2]);
 $60 = Math_fround($58 * $59);
 $61 = Math_fround($56 + $60);
 $62 = (($tet) + 56|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround(HEAPF32[$41>>2]);
 $65 = Math_fround($63 * $64);
 $66 = Math_fround($61 + $65);
 $67 = (($tet) + 68|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 + $66);
 $70 = (($tet) + 36|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($55 * $71);
 $73 = (($tet) + 48|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($59 * $74);
 $76 = Math_fround($72 + $75);
 $77 = (($tet) + 60|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($64 * $78);
 $80 = Math_fround($76 + $79);
 $81 = (($tet) + 72|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 + $80);
 $84 = (($tet) + 40|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($55 * $85);
 $87 = (($tet) + 52|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = Math_fround($59 * $88);
 $90 = Math_fround($86 + $89);
 $91 = (($tet) + 64|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($64 * $92);
 $94 = Math_fround($90 + $93);
 $95 = (($tet) + 76|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($96 + $94);
 $98 = (($tet) + 12|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($99|0)==(-1);
 do {
  if ($100) {
   $101 = +$69;
   $102 = +$83;
   $103 = +$97;
   $104 = $101 * 0.33333333333333331483;
   $105 = $104 * $104;
   $106 = $104 * $105;
   $107 = $104 * $102;
   $108 = $107 * 0.5;
   $109 = $106 - $108;
   $110 = $103 * 0.5;
   $111 = $109 + $110;
   $112 = $102 * 0.33333333333333331483;
   $113 = $112 - $105;
   $114 = $113 * $113;
   $115 = $113 * $114;
   $116 = $111 * $111;
   $117 = $115 + $116;
   $118 = !($117 >= 0.0);
   if ($118) {
    $131 = -$115;
    $132 = (+Math_sqrt((+$131)));
    $133 = -$111;
    $134 = $133 / $132;
    $135 = (+Math_acos((+$134)));
    $136 = (+Math_pow((+$132),0.33333333333333331483));
    $137 = $113 / $136;
    $138 = $136 - $137;
    $139 = $135 * 0.33333333333333331483;
    $140 = (+Math_cos((+$139)));
    $141 = $138 * $140;
    $142 = $141 - $104;
    $165 = $142;
    break;
   }
   $119 = (+Math_sqrt((+$117)));
   $120 = $119 - $111;
   $121 = $120 > 0.0;
   if ($121) {
    $122 = (+Math_pow((+$120),0.33333333333333331483));
    $128 = $122;
   } else {
    $123 = -$120;
    $124 = (+Math_pow((+$123),0.33333333333333331483));
    $125 = -$124;
    $128 = $125;
   }
   $126 = -$104;
   $127 = $113 / $128;
   $129 = $126 - $127;
   $130 = $128 + $129;
   $165 = $130;
  } else {
   $143 = $69 < Math_fround(0.0);
   if ($143) {
    $144 = Math_fround(-$69);
    $146 = $144;
   } else {
    $146 = $69;
   }
   $145 = $146 < Math_fround(9.99999974737875163555E-6);
   if ($145) {
    $147 = $83 < Math_fround(0.0);
    if ($147) {
     $148 = Math_fround(-$83);
     $150 = $148;
    } else {
     $150 = $83;
    }
    $149 = $150 > Math_fround(9.99999974737875163555E-6);
    if ($149) {
     $151 = Math_fround(-$97);
     $152 = Math_fround($151 / $83);
     $163 = $152;
    } else {
     $163 = Math_fround(0.0);
    }
   } else {
    $153 = Math_fround($83 * $83);
    $154 = Math_fround($69 * Math_fround(4.0));
    $155 = Math_fround($154 * $97);
    $156 = Math_fround($153 - $155);
    $157 = $156 < Math_fround(0.0);
    if ($157) {
     $163 = Math_fround(0.0);
    } else {
     $158 = Math_fround(Math_fround(0.5) / $69);
     $159 = (Math_fround(Math_sqrt((Math_fround($156)))));
     $160 = Math_fround($159 - $83);
     $161 = Math_fround($158 * $160);
     $163 = $161;
    }
   }
   $162 = +$163;
   $165 = $162;
  }
 } while(0);
 $164 = Math_fround($165);
 HEAPF32[$t>>2] = $164;
 $166 = (($tri) + 16|0);
 ;HEAP32[$tri+0>>2]=0|0;HEAP32[$tri+4>>2]=0|0;HEAP32[$tri+8>>2]=0|0;HEAP32[$tri+12>>2]=0|0;
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = (($tri) + 20|0);
 HEAPF32[$167>>2] = Math_fround(0.0);
 $168 = (($tri) + 24|0);
 HEAPF32[$168>>2] = Math_fround(0.0);
 $169 = (($tri) + 28|0);
 HEAPF32[$169>>2] = Math_fround(0.0);
 $170 = (($tri) + 32|0);
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = HEAP32[$tet>>2]|0;
 $172 = HEAP32[$hullRays>>2]|0;
 $173 = (($172) + (($171*12)|0)|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = Math_fround($164 * $174);
 $176 = ((($172) + (($171*12)|0)|0) + 4|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = Math_fround($164 * $177);
 $179 = ((($172) + (($171*12)|0)|0) + 8|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = Math_fround($164 * $180);
 $182 = Math_fround(HEAPF32[$1>>2]);
 $183 = Math_fround($175 + $182);
 $184 = Math_fround(HEAPF32[$9>>2]);
 $185 = Math_fround($178 + $184);
 $186 = Math_fround(HEAPF32[$14>>2]);
 $187 = Math_fround($181 + $186);
 HEAPF32[$tri>>2] = $183;
 $188 = (($tri) + 4|0);
 HEAPF32[$188>>2] = $185;
 $189 = (($tri) + 8|0);
 HEAPF32[$189>>2] = $187;
 $190 = (($tet) + 4|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = (($172) + (($191*12)|0)|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = Math_fround($164 * $193);
 $195 = ((($172) + (($191*12)|0)|0) + 4|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = Math_fround($164 * $196);
 $198 = ((($172) + (($191*12)|0)|0) + 8|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = Math_fround($164 * $199);
 $201 = Math_fround(HEAPF32[$3>>2]);
 $202 = Math_fround($194 + $201);
 $203 = Math_fround(HEAPF32[$7>>2]);
 $204 = Math_fround($197 + $203);
 $205 = Math_fround(HEAPF32[$12>>2]);
 $206 = Math_fround($200 + $205);
 $207 = (($tri) + 12|0);
 HEAPF32[$207>>2] = $202;
 $208 = (($tri) + 16|0);
 HEAPF32[$208>>2] = $204;
 $209 = (($tri) + 20|0);
 HEAPF32[$209>>2] = $206;
 $210 = (($tet) + 8|0);
 $211 = HEAP32[$210>>2]|0;
 $212 = (($172) + (($211*12)|0)|0);
 $213 = Math_fround(HEAPF32[$212>>2]);
 $214 = Math_fround($164 * $213);
 $215 = ((($172) + (($211*12)|0)|0) + 4|0);
 $216 = Math_fround(HEAPF32[$215>>2]);
 $217 = Math_fround($164 * $216);
 $218 = ((($172) + (($211*12)|0)|0) + 8|0);
 $219 = Math_fround(HEAPF32[$218>>2]);
 $220 = Math_fround($164 * $219);
 $221 = Math_fround(HEAPF32[$18>>2]);
 $222 = Math_fround($214 + $221);
 $223 = Math_fround(HEAPF32[$21>>2]);
 $224 = Math_fround($217 + $223);
 $225 = Math_fround(HEAPF32[$24>>2]);
 $226 = Math_fround($220 + $225);
 $227 = (($tri) + 24|0);
 HEAPF32[$227>>2] = $222;
 $228 = (($tri) + 28|0);
 HEAPF32[$228>>2] = $224;
 $229 = (($tri) + 32|0);
 HEAPF32[$229>>2] = $226;
 __ZN15LightProbeUtils32BarycentricCoordinates3DTriangleEPK8Vector3fRS1_($0,$tri,$p);
 $230 = Math_fround(HEAPF32[$0>>2]);
 $231 = (($0) + 4|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = (($0) + 8|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 HEAPF32[$coords>>2] = $230;
 $235 = (($coords) + 4|0);
 HEAPF32[$235>>2] = $232;
 $236 = (($coords) + 8|0);
 HEAPF32[$236>>2] = $234;
 $237 = (($coords) + 12|0);
 HEAPF32[$237>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN11LightProbes14LightProbeDataD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$byval_copy16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy16 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = (($this) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 72|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $7;
   $scevgep$i$i$i$i$i$i$i$i$i = (($10) + -24|0);
   $12 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($12)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $13 = (($uglygep3$i$i$i$i$i$i$i$i$i>>>0) / 24)&-1;
   $14 = $13 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($10) + (($14*24)|0)|0);
   HEAP32[$9>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
  HEAP32[$5>>2] = 72;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,($7|0),($$byval_copy16|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   $17 = ___cxa_find_matching_catch()|0;
   $18 = tempRet0;
   ___cxa_call_unexpected(($17|0));
   // unreachable;
  }
 }
 $19 = (($this) + 60|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>(-1);
 do {
  if ($21) {
   $22 = (($this) + 48|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($this) + 52|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$4>>2] = $25;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($23|0),($$byval_copy16|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    HEAP32[$22>>2] = 0;
    label = 9;
    break;
   }
   $66 = ___cxa_find_matching_catch()|0;
   $67 = tempRet0;
   $68 = (($this) + 44|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)>(-1);
   if ($70) {
    $71 = (($this) + 32|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($this) + 36|0);
    $74 = HEAP32[$73>>2]|0;
    HEAP32[$2>>2] = $74;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($72|0),($$byval_copy16|0));
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if (!($76)) {
     HEAP32[$71>>2] = 0;
     $$1 = $67;$$12 = $66;
     label = 27;
    }
   } else {
    $$1 = $67;$$12 = $66;
    label = 27;
   }
  } else {
   label = 9;
  }
 } while(0);
 L15: do {
  if ((label|0) == 9) {
   $28 = (($this) + 44|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>(-1);
   do {
    if ($30) {
     $31 = (($this) + 32|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($this) + 36|0);
     $34 = HEAP32[$33>>2]|0;
     HEAP32[$3>>2] = $34;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($32|0),($$byval_copy16|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $64 = ___cxa_find_matching_catch()|0;
      $65 = tempRet0;
      $$1 = $65;$$12 = $64;
      label = 27;
      break L15;
     } else {
      HEAP32[$31>>2] = 0;
      break;
     }
    }
   } while(0);
   $37 = (($this) + 28|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)>(-1);
   do {
    if ($39) {
     $40 = (($this) + 16|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($this) + 20|0);
     $43 = HEAP32[$42>>2]|0;
     HEAP32[$1>>2] = $43;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($41|0),($$byval_copy16|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      HEAP32[$40>>2] = 0;
      break;
     }
     $52 = ___cxa_find_matching_catch()|0;
     $53 = tempRet0;
     $54 = (($this) + 12|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)>(-1);
     if (!($56)) {
      ___resumeException($52|0);
      // unreachable;
     }
     $57 = HEAP32[$this>>2]|0;
     $58 = (($this) + 4|0);
     $59 = HEAP32[$58>>2]|0;
     HEAP32[$0>>2] = $59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($57|0),($$byval_copy16|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      $62 = ___cxa_find_matching_catch(0|0)|0;
      $63 = tempRet0;
      ___clang_call_terminate($62);
      // unreachable;
     }
     HEAP32[$this>>2] = 0;
     ___resumeException($52|0);
     // unreachable;
    }
   } while(0);
   $46 = (($this) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)>(-1);
   if (!($48)) {
    STACKTOP = sp;return;
   }
   $49 = HEAP32[$this>>2]|0;
   $50 = (($this) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$0>>2] = $51;
   ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($49,$$byval_copy16);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 27) {
  $77 = (($this) + 28|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)>(-1);
  do {
   if ($79) {
    $80 = (($this) + 16|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($this) + 20|0);
    $83 = HEAP32[$82>>2]|0;
    HEAP32[$1>>2] = $83;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($81|0),($$byval_copy16|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     HEAP32[$80>>2] = 0;
     break;
    }
    $94 = ___cxa_find_matching_catch(0|0)|0;
    $95 = tempRet0;
    $96 = (($this) + 12|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($97|0)>(-1);
    if (!($98)) {
     $eh$lpad$body$indexZ2D = $94;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
    $99 = HEAP32[$this>>2]|0;
    $100 = (($this) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    HEAP32[$0>>2] = $101;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($99|0),($$byval_copy16|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     $104 = ___cxa_find_matching_catch(0|0)|0;
     $105 = tempRet0;
     ___clang_call_terminate($104);
     // unreachable;
    }
    HEAP32[$this>>2] = 0;
    $eh$lpad$body$indexZ2D = $94;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  } while(0);
  $86 = (($this) + 12|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)>(-1);
  if (!($88)) {
   ___resumeException($$12|0);
   // unreachable;
  }
  $89 = HEAP32[$this>>2]|0;
  $90 = (($this) + 4|0);
  $91 = HEAP32[$90>>2]|0;
  HEAP32[$0>>2] = $91;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($89|0),($$byval_copy16|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if (!($93)) {
   HEAP32[$this>>2] = 0;
   ___resumeException($$12|0);
   // unreachable;
  }
 }
 $106 = ___cxa_find_matching_catch(0|0)|0;
 $107 = tempRet0;
 $eh$lpad$body$indexZ2D = $106;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __Z25GetBarycentricCoordinatesRK13dynamic_arrayI8Vector3fLj4EES3_RKS0_RK11TetrahedronR8Vector4fRf($bakedPositions,$hullRays,$p,$tet,$coords,$t) {
 $bakedPositions = $bakedPositions|0;
 $hullRays = $hullRays|0;
 $p = $p|0;
 $tet = $tet|0;
 $coords = $coords|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($tet) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(-1);
 if ($2) {
  $3 = HEAP32[$bakedPositions>>2]|0;
  $4 = Math_fround(HEAPF32[$p>>2]);
  $5 = (($3) + (($1*12)|0)|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 - $6);
  $8 = (($p) + 4|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = ((($3) + (($1*12)|0)|0) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($9 - $11);
  $13 = (($p) + 8|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = ((($3) + (($1*12)|0)|0) + 8|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($14 - $16);
  $18 = (($tet) + 32|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($7 * $19);
  $21 = (($tet) + 44|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($12 * $22);
  $24 = Math_fround($20 + $23);
  $25 = (($tet) + 56|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($17 * $26);
  $28 = Math_fround($24 + $27);
  $29 = (($tet) + 36|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($7 * $30);
  $32 = (($tet) + 48|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($12 * $33);
  $35 = Math_fround($31 + $34);
  $36 = (($tet) + 60|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($17 * $37);
  $39 = Math_fround($35 + $38);
  $40 = (($tet) + 40|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($7 * $41);
  $43 = (($tet) + 52|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($12 * $44);
  $46 = Math_fround($42 + $45);
  $47 = (($tet) + 64|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($17 * $48);
  $50 = Math_fround($46 + $49);
  HEAPF32[$coords>>2] = $28;
  $51 = (($coords) + 4|0);
  HEAPF32[$51>>2] = $39;
  $52 = (($coords) + 8|0);
  HEAPF32[$52>>2] = $50;
  $53 = Math_fround(Math_fround(1.0) - $28);
  $54 = Math_fround($53 - $39);
  $55 = Math_fround($54 - $50);
  $56 = (($coords) + 12|0);
  HEAPF32[$56>>2] = $55;
  STACKTOP = sp;return;
 } else {
  __Z37GetBarycentricCoordinatesForOuterCellRK13dynamic_arrayI8Vector3fLj4EES3_RKS0_RK11TetrahedronR8Vector4fRf($bakedPositions,$hullRays,$p,$tet,$coords,$t);
  STACKTOP = sp;return;
 }
}
function __Z37GetBarycentricCoordinatesForOuterCellRK13dynamic_arrayI8Vector3fLj4EES3_RKS0_RK11TetrahedronR8Vector4fRf($bakedPositions,$hullRays,$p,$tet,$coords,$t) {
 $bakedPositions = $bakedPositions|0;
 $hullRays = $hullRays|0;
 $p = $p|0;
 $tet = $tet|0;
 $coords = $coords|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = Math_fround(0), $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = Math_fround(0), $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = Math_fround(0), $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0.0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0.0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $tri = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tri = sp + 12|0;
 $0 = sp;
 $1 = HEAP32[$tet>>2]|0;
 $2 = HEAP32[$bakedPositions>>2]|0;
 $3 = (($tet) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + (($4*12)|0)|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($2) + (($1*12)|0)|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = ((($2) + (($4*12)|0)|0) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = ((($2) + (($1*12)|0)|0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = ((($2) + (($4*12)|0)|0) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = ((($2) + (($1*12)|0)|0) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = (($tet) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($2) + (($21*12)|0)|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 - $8);
 $25 = ((($2) + (($21*12)|0)|0) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 - $13);
 $28 = ((($2) + (($21*12)|0)|0) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 - $18);
 $31 = Math_fround($19 * $27);
 $32 = Math_fround($14 * $30);
 $33 = Math_fround($31 - $32);
 $34 = Math_fround($9 * $30);
 $35 = Math_fround($19 * $24);
 $36 = Math_fround($34 - $35);
 $37 = Math_fround($14 * $24);
 $38 = Math_fround($9 * $27);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround(HEAPF32[$p>>2]);
 $41 = Math_fround($40 - $8);
 $42 = (($p) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 - $13);
 $45 = (($p) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 - $18);
 $48 = Math_fround($41 * $33);
 $49 = Math_fround($44 * $36);
 $50 = Math_fround($48 + $49);
 $51 = Math_fround($39 * $47);
 $52 = Math_fround($50 + $51);
 HEAPF32[$t>>2] = $52;
 $53 = $52 < Math_fround(0.0);
 if ($53) {
  HEAPF32[$coords>>2] = Math_fround(0.0);
  $54 = (($coords) + 4|0);
  HEAPF32[$54>>2] = Math_fround(0.0);
  $55 = (($coords) + 8|0);
  HEAPF32[$55>>2] = Math_fround(0.0);
  $56 = (($coords) + 12|0);
  HEAPF32[$56>>2] = Math_fround(-1.0);
  STACKTOP = sp;return;
 }
 $57 = (($tet) + 32|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround(HEAPF32[$p>>2]);
 $60 = Math_fround($58 * $59);
 $61 = (($tet) + 44|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround(HEAPF32[$42>>2]);
 $64 = Math_fround($62 * $63);
 $65 = Math_fround($60 + $64);
 $66 = (($tet) + 56|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround(HEAPF32[$45>>2]);
 $69 = Math_fround($67 * $68);
 $70 = Math_fround($65 + $69);
 $71 = (($tet) + 68|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 + $70);
 $74 = (($tet) + 36|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($59 * $75);
 $77 = (($tet) + 48|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($63 * $78);
 $80 = Math_fround($76 + $79);
 $81 = (($tet) + 60|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($68 * $82);
 $84 = Math_fround($80 + $83);
 $85 = (($tet) + 72|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 + $84);
 $88 = (($tet) + 40|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($59 * $89);
 $91 = (($tet) + 52|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($63 * $92);
 $94 = Math_fround($90 + $93);
 $95 = (($tet) + 64|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($68 * $96);
 $98 = Math_fround($94 + $97);
 $99 = (($tet) + 76|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 + $98);
 $102 = (($tet) + 12|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ($103|0)==(-1);
 do {
  if ($104) {
   $105 = +$73;
   $106 = +$87;
   $107 = +$101;
   $108 = $105 * 0.33333333333333331483;
   $109 = $108 * $108;
   $110 = $108 * $109;
   $111 = $108 * $106;
   $112 = $111 * 0.5;
   $113 = $110 - $112;
   $114 = $107 * 0.5;
   $115 = $113 + $114;
   $116 = $106 * 0.33333333333333331483;
   $117 = $116 - $109;
   $118 = $117 * $117;
   $119 = $117 * $118;
   $120 = $115 * $115;
   $121 = $119 + $120;
   $122 = !($121 >= 0.0);
   if ($122) {
    $135 = -$119;
    $136 = (+Math_sqrt((+$135)));
    $137 = -$115;
    $138 = $137 / $136;
    $139 = (+Math_acos((+$138)));
    $140 = (+Math_pow((+$136),0.33333333333333331483));
    $141 = $117 / $140;
    $142 = $140 - $141;
    $143 = $139 * 0.33333333333333331483;
    $144 = (+Math_cos((+$143)));
    $145 = $142 * $144;
    $146 = $145 - $108;
    $169 = $146;
    break;
   }
   $123 = (+Math_sqrt((+$121)));
   $124 = $123 - $115;
   $125 = $124 > 0.0;
   if ($125) {
    $126 = (+Math_pow((+$124),0.33333333333333331483));
    $132 = $126;
   } else {
    $127 = -$124;
    $128 = (+Math_pow((+$127),0.33333333333333331483));
    $129 = -$128;
    $132 = $129;
   }
   $130 = -$108;
   $131 = $117 / $132;
   $133 = $130 - $131;
   $134 = $132 + $133;
   $169 = $134;
  } else {
   $147 = $73 < Math_fround(0.0);
   if ($147) {
    $148 = Math_fround(-$73);
    $150 = $148;
   } else {
    $150 = $73;
   }
   $149 = $150 < Math_fround(9.99999974737875163555E-6);
   if ($149) {
    $151 = $87 < Math_fround(0.0);
    if ($151) {
     $152 = Math_fround(-$87);
     $154 = $152;
    } else {
     $154 = $87;
    }
    $153 = $154 > Math_fround(9.99999974737875163555E-6);
    if ($153) {
     $155 = Math_fround(-$101);
     $156 = Math_fround($155 / $87);
     $167 = $156;
    } else {
     $167 = Math_fround(0.0);
    }
   } else {
    $157 = Math_fround($87 * $87);
    $158 = Math_fround($73 * Math_fround(4.0));
    $159 = Math_fround($158 * $101);
    $160 = Math_fround($157 - $159);
    $161 = $160 < Math_fround(0.0);
    if ($161) {
     $167 = Math_fround(0.0);
    } else {
     $162 = Math_fround(Math_fround(0.5) / $73);
     $163 = (Math_fround(Math_sqrt((Math_fround($160)))));
     $164 = Math_fround($163 - $87);
     $165 = Math_fround($162 * $164);
     $167 = $165;
    }
   }
   $166 = +$167;
   $169 = $166;
  }
 } while(0);
 $168 = Math_fround($169);
 HEAPF32[$t>>2] = $168;
 $170 = (($tri) + 16|0);
 ;HEAP32[$tri+0>>2]=0|0;HEAP32[$tri+4>>2]=0|0;HEAP32[$tri+8>>2]=0|0;HEAP32[$tri+12>>2]=0|0;
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = (($tri) + 20|0);
 HEAPF32[$171>>2] = Math_fround(0.0);
 $172 = (($tri) + 24|0);
 HEAPF32[$172>>2] = Math_fround(0.0);
 $173 = (($tri) + 28|0);
 HEAPF32[$173>>2] = Math_fround(0.0);
 $174 = (($tri) + 32|0);
 HEAPF32[$174>>2] = Math_fround(0.0);
 $175 = HEAP32[$hullRays>>2]|0;
 $176 = (($175) + (($1*12)|0)|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = Math_fround($168 * $177);
 $179 = ((($175) + (($1*12)|0)|0) + 4|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 $181 = Math_fround($168 * $180);
 $182 = ((($175) + (($1*12)|0)|0) + 8|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = Math_fround($168 * $183);
 $185 = Math_fround(HEAPF32[$7>>2]);
 $186 = Math_fround($178 + $185);
 $187 = Math_fround(HEAPF32[$12>>2]);
 $188 = Math_fround($181 + $187);
 $189 = Math_fround(HEAPF32[$17>>2]);
 $190 = Math_fround($184 + $189);
 HEAPF32[$tri>>2] = $186;
 $191 = (($tri) + 4|0);
 HEAPF32[$191>>2] = $188;
 $192 = (($tri) + 8|0);
 HEAPF32[$192>>2] = $190;
 $193 = (($175) + (($4*12)|0)|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround($168 * $194);
 $196 = ((($175) + (($4*12)|0)|0) + 4|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = Math_fround($168 * $197);
 $199 = ((($175) + (($4*12)|0)|0) + 8|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = Math_fround($168 * $200);
 $202 = Math_fround(HEAPF32[$5>>2]);
 $203 = Math_fround($195 + $202);
 $204 = Math_fround(HEAPF32[$10>>2]);
 $205 = Math_fround($198 + $204);
 $206 = Math_fround(HEAPF32[$15>>2]);
 $207 = Math_fround($201 + $206);
 $208 = (($tri) + 12|0);
 HEAPF32[$208>>2] = $203;
 $209 = (($tri) + 16|0);
 HEAPF32[$209>>2] = $205;
 $210 = (($tri) + 20|0);
 HEAPF32[$210>>2] = $207;
 $211 = (($175) + (($21*12)|0)|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = Math_fround($168 * $212);
 $214 = ((($175) + (($21*12)|0)|0) + 4|0);
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = Math_fround($168 * $215);
 $217 = ((($175) + (($21*12)|0)|0) + 8|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 $219 = Math_fround($168 * $218);
 $220 = Math_fround(HEAPF32[$22>>2]);
 $221 = Math_fround($213 + $220);
 $222 = Math_fround(HEAPF32[$25>>2]);
 $223 = Math_fround($216 + $222);
 $224 = Math_fround(HEAPF32[$28>>2]);
 $225 = Math_fround($219 + $224);
 $226 = (($tri) + 24|0);
 HEAPF32[$226>>2] = $221;
 $227 = (($tri) + 28|0);
 HEAPF32[$227>>2] = $223;
 $228 = (($tri) + 32|0);
 HEAPF32[$228>>2] = $225;
 __ZN15LightProbeUtils32BarycentricCoordinates3DTriangleEPK8Vector3fRS1_($0,$tri,$p);
 $229 = Math_fround(HEAPF32[$0>>2]);
 $230 = (($0) + 4|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = (($0) + 8|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 HEAPF32[$coords>>2] = $229;
 $234 = (($coords) + 4|0);
 HEAPF32[$234>>2] = $231;
 $235 = (($coords) + 8|0);
 HEAPF32[$235>>2] = $233;
 $236 = (($coords) + 12|0);
 HEAPF32[$236>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __Z33GetLightProbeInterpolationWeightsRK20LightProbeDataLegacyRK8Vector3fRiR8Vector4fRfS5_($data,$position,$tetIndex,$weights,$t,$steps) {
 $data = $data|0;
 $position = $position|0;
 $tetIndex = $tetIndex|0;
 $weights = $weights|0;
 $t = $t|0;
 $steps = $steps|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond6 = 0, $or$cond7 = 0, $prev$02 = 0, $prevprev$01 = 0, $prevprev$01$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$tetIndex>>2]|0;
 $3 = ($2|0)>(-1);
 $4 = ($2|0)<($1|0);
 $or$cond = $3 & $4;
 if (!($or$cond)) {
  HEAP32[$tetIndex>>2] = 0;
 }
 $5 = (($weights) + 12|0);
 HEAP32[$steps>>2] = 0;
 $6 = ($1|0)>(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($data) + 32|0);
 $8 = (($data) + 48|0);
 $9 = (($weights) + 4|0);
 $10 = (($weights) + 8|0);
 $prev$02 = -1;$prevprev$01 = -1;
 while(1) {
  $11 = HEAP32[$tetIndex>>2]|0;
  $12 = HEAP32[$7>>2]|0;
  $13 = (($12) + (($11*80)|0)|0);
  __Z25GetBarycentricCoordinatesRK13dynamic_arrayI8Vector3fLj4EES3_RKS0_RK11TetrahedronR8Vector4fRf($data,$8,$position,$13,$weights,$t);
  $14 = Math_fround(HEAPF32[$weights>>2]);
  $15 = !($14 >= Math_fround(0.0));
  if (!($15)) {
   $16 = Math_fround(HEAPF32[$9>>2]);
   $17 = !($16 >= Math_fround(0.0));
   if (!($17)) {
    $18 = Math_fround(HEAPF32[$10>>2]);
    $19 = !($18 >= Math_fround(0.0));
    if (!($19)) {
     $20 = Math_fround(HEAPF32[$5>>2]);
     $21 = !($20 >= Math_fround(0.0));
     if (!($21)) {
      label = 19;
      break;
     }
    }
   }
  }
  $22 = HEAP32[$tetIndex>>2]|0;
  $23 = ($22|0)==($prevprev$01|0);
  if ($23) {
   label = 19;
   break;
  }
  $24 = Math_fround(HEAPF32[$9>>2]);
  $25 = $14 < $24;
  $26 = Math_fround(HEAPF32[$10>>2]);
  $27 = $14 < $26;
  $or$cond6 = $25 & $27;
  if ($or$cond6) {
   $28 = Math_fround(HEAPF32[$5>>2]);
   $29 = $14 < $28;
   if ($29) {
    $30 = ((($12) + (($11*80)|0)|0) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    HEAP32[$tetIndex>>2] = $31;
   } else {
    label = 13;
   }
  } else {
   label = 13;
  }
  do {
   if ((label|0) == 13) {
    label = 0;
    $32 = $24 < $26;
    $33 = Math_fround(HEAPF32[$5>>2]);
    $34 = $24 < $33;
    $or$cond7 = $32 & $34;
    if ($or$cond7) {
     $35 = ((($12) + (($11*80)|0)|0) + 20|0);
     $36 = HEAP32[$35>>2]|0;
     HEAP32[$tetIndex>>2] = $36;
     break;
    }
    $37 = $26 < $33;
    if ($37) {
     $38 = ((($12) + (($11*80)|0)|0) + 24|0);
     $39 = HEAP32[$38>>2]|0;
     HEAP32[$tetIndex>>2] = $39;
     break;
    } else {
     $40 = ((($12) + (($11*80)|0)|0) + 28|0);
     $41 = HEAP32[$40>>2]|0;
     HEAP32[$tetIndex>>2] = $41;
     break;
    }
   }
  } while(0);
  $42 = HEAP32[$steps>>2]|0;
  $43 = (($42) + 1)|0;
  HEAP32[$steps>>2] = $43;
  $44 = ($43|0)<($1|0);
  if ($44) {
   $prevprev$01$phi = $prev$02;$prev$02 = $22;$prevprev$01 = $prevprev$01$phi;
  } else {
   label = 19;
   break;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return;
 }
}
function __ZNK17LightProbesLegacy25GetInterpolatedLightProbeERK8Vector3fPfRiR8Vector4fRf($this,$position,$coefficients,$tetIndex,$weights,$t) {
 $this = $this|0;
 $position = $position|0;
 $coefficients = $coefficients|0;
 $tetIndex = $tetIndex|0;
 $weights = $weights|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond3$i = 0, $i$02$i = 0, $j$01$i = 0, $or$cond = 0, $steps = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $steps = sp;
 dest=$coefficients+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$tetIndex>>2] = -1;
  ;HEAP32[$weights+0>>2]=0|0;HEAP32[$weights+4>>2]=0|0;HEAP32[$weights+8>>2]=0|0;HEAP32[$weights+12>>2]=0|0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 28|0);
 __Z33GetLightProbeInterpolationWeightsRK20LightProbeDataLegacyRK8Vector3fRiR8Vector4fRfS5_($3,$position,$tetIndex,$weights,$t,$steps);
 $4 = HEAP32[$tetIndex>>2]|0;
 $5 = ($4|0)>(-1);
 $6 = ($4|0)<($1|0);
 $or$cond = $5 & $6;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8) + (($4*80)|0)|0) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >> 31;
 $12 = (($11) + 4)|0;
 $13 = ($12|0)>(0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 $i$02$i = 0;
 while(1) {
  $16 = ((($8) + (($4*80)|0)|0) + ($i$02$i<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($weights) + ($i$02$i<<2)|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $j$01$i = 0;
  while(1) {
   $20 = ((($15) + (($17*108)|0)|0) + ($j$01$i<<2)|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = Math_fround($19 * $21);
   $23 = (($coefficients) + ($j$01$i<<2)|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($24 + $22);
   HEAPF32[$23>>2] = $25;
   $26 = (($j$01$i) + 1)|0;
   $exitcond$i = ($26|0)==(27);
   if ($exitcond$i) {
    break;
   } else {
    $j$01$i = $26;
   }
  }
  $27 = (($i$02$i) + 1)|0;
  $exitcond3$i = ($27|0)==($12|0);
  if ($exitcond3$i) {
   break;
  } else {
   $i$02$i = $27;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4PPtrIN5Unity8MaterialEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrIN5Unity8MaterialEE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,575008,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,575024,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,575008,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,575024,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN16ReflectionSampleC2Ev($this) {
 $this = $this|0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$this+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN15ReflectionProbe19ClearRenderTexturesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$byval_copy = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $it$02 = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 140|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$lcssa = $3;
 } else {
  $it$02 = $3;
  while(1) {
   $7 = HEAP32[$it$02>>2]|0;
   __Z19DestroySingleObjectP6Object($7);
   $8 = (($it$02) + 4|0);
   $9 = HEAP32[$2>>2]|0;
   $10 = HEAP32[$4>>2]|0;
   $11 = (($9) + ($10<<2)|0);
   $12 = ($8|0)==($11|0);
   if ($12) {
    $$lcssa = $9;
    break;
   } else {
    $it$02 = $8;
   }
  }
 }
 $13 = (($this) + 152|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(-1);
 if ($15) {
  $16 = (($this) + 144|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$0>>2] = $17;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($$lcssa,$$byval_copy);
  HEAP32[$2>>2] = 0;
 }
 HEAP32[$4>>2] = 0;
 HEAP32[$13>>2] = 0;
 $18 = (($this) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 136|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(-1);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = HEAP32[575112>>2]|0;
 __ZNK15ReflectionProbe10GetTextureEv($1,$this);
 $25 = HEAP32[$1>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $25;
  $27 = HEAP32[560624>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   label = 16;
  } else {
   $29 = (($27) + 36|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($27) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($30|0)==($32|0);
   do {
    if ($33) {
     $34 = (($27) + 28|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($27) + 32|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($35) + ($37<<3)|0);
     $54 = $38;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$27,$0);
     $39 = HEAP32[$$byval_copy>>2]|0;
     $40 = ($39|0)==(-1);
     $41 = (($27) + 28|0);
     $42 = HEAP32[$41>>2]|0;
     if ($40) {
      $43 = (($27) + 32|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = (($42) + ($44<<3)|0);
      $54 = $45;
      break;
     } else {
      $46 = (($42) + ($39<<3)|0);
      $54 = $46;
      break;
     }
    }
   } while(0);
   $47 = HEAP32[560624>>2]|0;
   $48 = (($47) + 28|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($47) + 32|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($49) + ($51<<3)|0);
   $53 = ($54|0)==($52|0);
   if ($53) {
    label = 16;
   } else {
    $55 = (($54) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($56|0)==(0|0);
    if ($57) {
     label = 16;
    } else {
     $temp$0$i = $56;
    }
   }
  }
  if ((label|0) == 16) {
   $58 = (__Z31ReadObjectFromPersistentManageri($25)|0);
   $temp$0$i = $58;
  }
  $$0$i = $temp$0$i;
 }
 __ZN16ReflectionProbes22ForceProbeToUseTextureER15ReflectionProbeP7Texture($24,$this,$$0$i);
 STACKTOP = sp;return;
}
function __Z19GetReflectionProbesv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[575112>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN16ReflectionProbes22ForceProbeToUseTextureER15ReflectionProbeP7Texture($this,$probe,$texture) {
 $this = $this|0;
 $probe = $probe|0;
 $texture = $texture|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = ($texture|0)==(0|0);
 if ($2) {
  $12 = 0;
 } else {
  $3 = (($texture) + 44|0);
  $4 = HEAP32[$3>>2]|0;
  $12 = $4;
 }
 $5 = (($probe) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 if ((($6|0) == 1)) {
  $25 = (($probe) + 136|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($this) + 96|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($28) + (($26*44)|0)|0) + 24|0);
  HEAP32[$29>>2] = $12;
  $30 = ((($28) + (($26*44)|0)|0) + 28|0);
  $31 = (($probe) + 128|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  if ($2) {
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($1,0,0,Math_fround(1.0));
  } else {
   $33 = (($texture) + 52|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (__Z19GetActiveColorSpacev()|0);
   $36 = ($35|0)==(1);
   if ($36) {
    $37 = (($texture) + 56|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = $38;
   } else {
    $39 = 0;
   }
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($1,$34,$39,$32);
  }
  ;HEAP32[$30+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$1+12>>2]|0;
  STACKTOP = sp;return;
 } else if ((($6|0) == 0)) {
  $7 = (($probe) + 136|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 64|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + (($8*36)|0)|0);
  HEAP32[$11>>2] = $12;
  $13 = HEAP32[$7>>2]|0;
  $14 = HEAP32[$9>>2]|0;
  $15 = ((($14) + (($13*36)|0)|0) + 4|0);
  $16 = (($probe) + 128|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  if ($2) {
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($0,0,0,Math_fround(1.0));
  } else {
   $18 = (($texture) + 52|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (__Z19GetActiveColorSpacev()|0);
   $21 = ($20|0)==(1);
   if ($21) {
    $22 = (($texture) + 56|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = $23;
   } else {
    $24 = 0;
   }
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($0,$19,$24,$17);
  }
  ;HEAP32[$15+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$0+12>>2]|0;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNK15ReflectionProbe10GetTextureEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 if ((($2|0) == 2)) {
  $5 = (($this) + 124|0);
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$agg$result>>2] = $6;
  STACKTOP = sp;return;
 } else if ((($2|0) == 0)) {
  $3 = (($this) + 120|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP32[$agg$result>>2] = $4;
  STACKTOP = sp;return;
 } else if ((($2|0) == 1)) {
  $7 = (($this) + 148|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = (__Z12GetGfxDevicev()|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 788|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
   $15 = HEAP32[$7>>2]|0;
   $16 = (($14>>>0) % ($15>>>0))&-1;
   $17 = (($this) + 140|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + ($16<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = (($20) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    HEAP32[$agg$result>>2] = $23;
    STACKTOP = sp;return;
   }
  }
  $24 = (($this) + 120|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$agg$result>>2] = $25;
  STACKTOP = sp;return;
 } else {
  HEAP32[$vararg_buffer>>2] = $2;
  __Z6FormatPKcz($0,575048,$vararg_buffer);
  $26 = HEAP8[$0>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $31 = (($0) + 1|0);
   $32 = $31;
  } else {
   $29 = (($0) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $32 = $30;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($32|0),0,(575040|0),279,1,0,0,(0|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $42 = HEAP8[$0>>0]|0;
   $43 = $42 & 1;
   $44 = ($43<<24>>24)==(0);
   if ($44) {
    ___resumeException($40|0);
    // unreachable;
   }
   $45 = (($0) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   __ZdlPv($46);
   ___resumeException($40|0);
   // unreachable;
  } else {
   $35 = HEAP8[$0>>0]|0;
   $36 = $35 & 1;
   $37 = ($36<<24>>24)==(0);
   if (!($37)) {
    $38 = (($0) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    __ZdlPv($39);
   }
   HEAP32[$agg$result>>2] = 0;
   STACKTOP = sp;return;
  }
 }
}
function __ZN16ReflectionProbes11UpdateProbeER15ReflectionProbej($this,$probe,$index) {
 $this = $this|0;
 $probe = $probe|0;
 $index = $index|0;
 var $$0$i21 = 0, $$sroa$0$0 = 0, $$sroa$01$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0;
 var $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0;
 var $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0);
 var $temp$0$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = sp + 8|0;
 $4 = sp + 24|0;
 $5 = sp + 36|0;
 $6 = sp + 48|0;
 $7 = ($index|0)==(-1);
 if ($7) {
  STACKTOP = sp;return;
 }
 __ZNK15ReflectionProbe10GetTextureEv($2,$probe);
 $8 = HEAP32[$2>>2]|0;
 $9 = ($8|0)==(0);
 do {
  if ($9) {
   $$0$i21 = 0;$196 = 1;$94 = 0;
  } else {
   HEAP32[$1>>2] = $8;
   $10 = HEAP32[560624>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    label = 11;
   } else {
    $12 = (($10) + 36|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($10) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13|0)==($15|0);
    do {
     if ($16) {
      $17 = (($10) + 28|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($10) + 32|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($18) + ($20<<3)|0);
      $37 = $21;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($0,$10,$1);
      $22 = HEAP32[$0>>2]|0;
      $23 = ($22|0)==(-1);
      $24 = (($10) + 28|0);
      $25 = HEAP32[$24>>2]|0;
      if ($23) {
       $26 = (($10) + 32|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = (($25) + ($27<<3)|0);
       $37 = $28;
       break;
      } else {
       $29 = (($25) + ($22<<3)|0);
       $37 = $29;
       break;
      }
     }
    } while(0);
    $30 = HEAP32[560624>>2]|0;
    $31 = (($30) + 28|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 32|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($32) + ($34<<3)|0);
    $36 = ($37|0)==($35|0);
    if ($36) {
     label = 11;
    } else {
     $38 = (($37) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      label = 11;
     } else {
      $temp$0$i23 = $39;
     }
    }
   }
   if ((label|0) == 11) {
    $41 = (__Z31ReadObjectFromPersistentManageri($8)|0);
    $42 = ($41|0)==(0|0);
    if ($42) {
     $$0$i21 = 0;$196 = 1;$94 = 0;
     break;
    } else {
     $temp$0$i23 = $41;
    }
   }
   $43 = (($temp$0$i23) + 44|0);
   $44 = HEAP32[$43>>2]|0;
   $$0$i21 = $temp$0$i23;$196 = 0;$94 = $44;
  }
 } while(0);
 $45 = (($probe) + 136|0);
 HEAP32[$45>>2] = $index;
 $46 = (($probe) + 40|0);
 $47 = HEAP32[$46>>2]|0;
 if ((($47|0) == 1)) {
  $122 = (($probe) + 24|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($123)|0);
  __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($0,$124);
  $125 = HEAP32[$122>>2]|0;
  $126 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($125)|0);
  __ZNK9Transform18GetWorldScaleLossyEv($5,$126);
  $127 = Math_fround(HEAPF32[$5>>2]);
  $128 = $127 < Math_fround(0.00999999977648258209228);
  $129 = $128 ? Math_fround(0.00999999977648258209228) : $127;
  $130 = (($5) + 4|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  $132 = $131 < Math_fround(0.00999999977648258209228);
  $133 = $132 ? Math_fround(0.00999999977648258209228) : $131;
  $134 = (($0) + 48|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = (($0) + 52|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = (($0) + 56|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround(HEAPF32[$0>>2]);
  $141 = (($0) + 4|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($0) + 8|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = (($0) + 16|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($0) + 20|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = (($0) + 24|0);
  $150 = Math_fround(HEAPF32[$149>>2]);
  $151 = (($0) + 32|0);
  $152 = Math_fround(HEAPF32[$151>>2]);
  $153 = (($0) + 36|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = (($0) + 40|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = (($this) + 80|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = (($158) + (($index*24)|0)|0);
  HEAPF32[$159>>2] = $135;
  $160 = ((($158) + (($index*24)|0)|0) + 4|0);
  HEAPF32[$160>>2] = $137;
  $161 = ((($158) + (($index*24)|0)|0) + 8|0);
  HEAPF32[$161>>2] = $139;
  $162 = HEAP32[$157>>2]|0;
  $163 = ((($162) + (($index*24)|0)|0) + 12|0);
  HEAPF32[$163>>2] = $152;
  $164 = ((($162) + (($index*24)|0)|0) + 16|0);
  HEAPF32[$164>>2] = $154;
  $165 = ((($162) + (($index*24)|0)|0) + 20|0);
  HEAPF32[$165>>2] = $156;
  $166 = (($this) + 96|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = ($94|0)==(0);
  if ($168) {
   $169 = (__ZN10builtintex17GetBlackTextureIDEv()|0);
   $$sroa$0$0 = $169;
  } else {
   $$sroa$0$0 = $94;
  }
  $170 = ((($167) + (($index*44)|0)|0) + 24|0);
  HEAP32[$170>>2] = $$sroa$0$0;
  $171 = HEAP32[$166>>2]|0;
  $172 = ((($171) + (($index*44)|0)|0) + 28|0);
  $173 = (($probe) + 128|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  if ($196) {
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($6,0,0,Math_fround(1.0));
  } else {
   $175 = (($$0$i21) + 52|0);
   $176 = HEAP32[$175>>2]|0;
   $177 = (__Z19GetActiveColorSpacev()|0);
   $178 = ($177|0)==(1);
   if ($178) {
    $179 = (($$0$i21) + 56|0);
    $180 = HEAP32[$179>>2]|0;
    $181 = $180;
   } else {
    $181 = 0;
   }
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($6,$176,$181,$174);
  }
  ;HEAP32[$172+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$172+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$172+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$172+12>>2]=HEAP32[$6+12>>2]|0;
  $182 = HEAP32[$166>>2]|0;
  $183 = Math_fround($140 / $129);
  $184 = Math_fround($142 / $129);
  $185 = Math_fround($144 / $129);
  $186 = (($182) + (($index*44)|0)|0);
  HEAPF32[$186>>2] = $183;
  $187 = ((($182) + (($index*44)|0)|0) + 4|0);
  HEAPF32[$187>>2] = $184;
  $188 = ((($182) + (($index*44)|0)|0) + 8|0);
  HEAPF32[$188>>2] = $185;
  $189 = HEAP32[$166>>2]|0;
  $190 = Math_fround($146 / $133);
  $191 = Math_fround($148 / $133);
  $192 = Math_fround($150 / $133);
  $193 = ((($189) + (($index*44)|0)|0) + 12|0);
  HEAPF32[$193>>2] = $190;
  $194 = ((($189) + (($index*44)|0)|0) + 16|0);
  HEAPF32[$194>>2] = $191;
  $195 = ((($189) + (($index*44)|0)|0) + 20|0);
  HEAPF32[$195>>2] = $192;
  STACKTOP = sp;return;
 } else if ((($47|0) == 0)) {
  $48 = (($this) + 48|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($probe) + 24|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($51)|0);
  __ZNK9Transform11GetPositionEv($0,$52);
  $53 = Math_fround(HEAPF32[$0>>2]);
  $54 = (($probe) + 72|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($53 + $55);
  $57 = (($0) + 4|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($probe) + 76|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($58 + $60);
  $62 = (($0) + 8|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($probe) + 80|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($63 + $65);
  $67 = (($probe) + 60|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($probe) + 64|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = (($probe) + 68|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($68 * Math_fround(0.5));
  $74 = Math_fround($70 * Math_fround(0.5));
  $75 = Math_fround($72 * Math_fround(0.5));
  $76 = $73 < Math_fround(0.0);
  if ($76) {
   $77 = Math_fround(-$73);
   $86 = $77;
  } else {
   $86 = $73;
  }
  $78 = $74 < Math_fround(0.0);
  if ($78) {
   $79 = Math_fround(-$74);
   $88 = $79;
  } else {
   $88 = $74;
  }
  $80 = $75 < Math_fround(0.0);
  if ($80) {
   $81 = Math_fround(-$75);
   $90 = $81;
  } else {
   $90 = $75;
  }
  $82 = (($49) + (($index*24)|0)|0);
  HEAPF32[$82>>2] = $56;
  $83 = ((($49) + (($index*24)|0)|0) + 4|0);
  HEAPF32[$83>>2] = $61;
  $84 = ((($49) + (($index*24)|0)|0) + 8|0);
  HEAPF32[$84>>2] = $66;
  $85 = ((($49) + (($index*24)|0)|0) + 12|0);
  HEAPF32[$85>>2] = $86;
  $87 = ((($49) + (($index*24)|0)|0) + 16|0);
  HEAPF32[$87>>2] = $88;
  $89 = ((($49) + (($index*24)|0)|0) + 20|0);
  HEAPF32[$89>>2] = $90;
  $91 = (($this) + 64|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($94|0)==(0);
  if ($93) {
   $95 = (__ZN10builtintex21GetBlackCubeTextureIDEv()|0);
   $$sroa$01$0 = $95;
  } else {
   $$sroa$01$0 = $94;
  }
  $96 = (($92) + (($index*36)|0)|0);
  HEAP32[$96>>2] = $$sroa$01$0;
  $97 = ((($92) + (($index*36)|0)|0) + 4|0);
  $98 = (($probe) + 128|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  if ($196) {
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($3,0,0,Math_fround(1.0));
  } else {
   $100 = (($$0$i21) + 52|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (__Z19GetActiveColorSpacev()|0);
   $103 = ($102|0)==(1);
   if ($103) {
    $104 = (($$0$i21) + 56|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = $105;
   } else {
    $106 = 0;
   }
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($3,$101,$106,$99);
  }
  ;HEAP32[$97+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$97+12>>2]=HEAP32[$3+12>>2]|0;
  $107 = HEAP32[$50>>2]|0;
  $108 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($107)|0);
  __ZNK9Transform11GetPositionEv($4,$108);
  $109 = (($probe) + 134|0);
  $110 = HEAP8[$109>>0]|0;
  $111 = ($110<<24>>24)!=(0);
  $112 = $111 ? Math_fround(1.0) : Math_fround(0.0);
  $113 = Math_fround(HEAPF32[$4>>2]);
  $114 = (($4) + 4|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($4) + 8|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = ((($92) + (($index*36)|0)|0) + 20|0);
  HEAPF32[$118>>2] = $113;
  $119 = ((($92) + (($index*36)|0)|0) + 24|0);
  HEAPF32[$119>>2] = $115;
  $120 = ((($92) + (($index*36)|0)|0) + 28|0);
  HEAPF32[$120>>2] = $117;
  $121 = ((($92) + (($index*36)|0)|0) + 32|0);
  HEAPF32[$121>>2] = $112;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN16ReflectionProbes17SetDefaultTextureE4PPtrI7TextureEf($this,$texture,$intensity) {
 $this = $this|0;
 $texture = $texture|0;
 $intensity = Math_fround($intensity);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$texture>>2]|0;
 HEAP32[$this>>2] = $0;
 $1 = (($this) + 4|0);
 HEAPF32[$1>>2] = $intensity;
 __ZN16ReflectionProbes16UpdateSampleDataEv($this);
 STACKTOP = sp;return;
}
function __ZN16ReflectionProbes16UpdateSampleDataEv($this) {
 $this = $this|0;
 var $$byval_copy15 = 0, $$pre$i$i$i = 0, $$pre$i14 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$0 = 0, $it = 0, $node$0$i = 0, $node$01$i = 0, $node$03$i = 0;
 var $size$0$lcssa$i = 0, $size$02$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy15 = sp + 144|0;
 $0 = sp;
 $1 = sp + 4|0;
 $it = sp + 128|0;
 $2 = (($this) + 28|0);
 $3 = (($this) + 32|0);
 $node$01$i = HEAP32[$3>>2]|0;
 $4 = ($node$01$i|0)==($2|0);
 if ($4) {
  $size$0$lcssa$i = 0;
 } else {
  $node$03$i = $node$01$i;$size$02$i = 0;
  while(1) {
   $5 = (($node$03$i) + 4|0);
   $6 = (($size$02$i) + 1)|0;
   $node$0$i = HEAP32[$5>>2]|0;
   $7 = ($node$0$i|0)==($2|0);
   if ($7) {
    $size$0$lcssa$i = $6;
    break;
   } else {
    $node$03$i = $node$0$i;$size$02$i = $6;
   }
  }
 }
 $8 = (($this) + 48|0);
 $9 = (($this) + 60|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11>>>0)<($size$0$lcssa$i>>>0);
 do {
  if ($12) {
   $13 = ($10|0)>(-1);
   if ($13) {
    HEAP32[$9>>2] = $size$0$lcssa$i;
    $14 = HEAP32[$8>>2]|0;
    $15 = ($size$0$lcssa$i*24)|0;
    $16 = (($this) + 52|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy15,0,575040,370)|0);
    HEAP32[$8>>2] = $18;
    break;
   } else {
    $19 = ($size$0$lcssa$i*24)|0;
    $20 = (($this) + 52|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy15,0,575040,352)|0);
    $23 = HEAP32[$8>>2]|0;
    $24 = (($this) + 56|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25*24)|0;
    _memcpy(($22|0),($23|0),($26|0))|0;
    HEAP32[$9>>2] = $size$0$lcssa$i;
    HEAP32[$8>>2] = $22;
    break;
   }
  }
 } while(0);
 $27 = (($this) + 56|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 64|0);
 $29 = (($this) + 76|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 2147483647;
 $32 = ($31>>>0)<($size$0$lcssa$i>>>0);
 do {
  if ($32) {
   $33 = ($30|0)>(-1);
   if ($33) {
    HEAP32[$29>>2] = $size$0$lcssa$i;
    $34 = HEAP32[$28>>2]|0;
    $35 = ($size$0$lcssa$i*36)|0;
    $36 = (($this) + 68|0);
    $37 = HEAP32[$36>>2]|0;
    HEAP32[$0>>2] = $37;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
    $38 = (__Z16realloc_internalPvji10MemLabelIdiPKci($34,$35,4,$$byval_copy15,0,575040,370)|0);
    HEAP32[$28>>2] = $38;
    break;
   } else {
    $39 = ($size$0$lcssa$i*36)|0;
    $40 = (($this) + 68|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$0>>2] = $41;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
    $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($39,4,$$byval_copy15,0,575040,352)|0);
    $43 = HEAP32[$28>>2]|0;
    $44 = (($this) + 72|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45*36)|0;
    _memcpy(($42|0),($43|0),($46|0))|0;
    HEAP32[$29>>2] = $size$0$lcssa$i;
    HEAP32[$28>>2] = $42;
    break;
   }
  }
 } while(0);
 $47 = (($this) + 72|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 80|0);
 $49 = (($this) + 92|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 2147483647;
 $52 = ($51>>>0)<($size$0$lcssa$i>>>0);
 do {
  if ($52) {
   $53 = ($50|0)>(-1);
   if ($53) {
    HEAP32[$49>>2] = $size$0$lcssa$i;
    $54 = HEAP32[$48>>2]|0;
    $55 = ($size$0$lcssa$i*24)|0;
    $56 = (($this) + 84|0);
    $57 = HEAP32[$56>>2]|0;
    HEAP32[$0>>2] = $57;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
    $58 = (__Z16realloc_internalPvji10MemLabelIdiPKci($54,$55,4,$$byval_copy15,0,575040,370)|0);
    HEAP32[$48>>2] = $58;
    break;
   } else {
    $59 = ($size$0$lcssa$i*24)|0;
    $60 = (($this) + 84|0);
    $61 = HEAP32[$60>>2]|0;
    HEAP32[$0>>2] = $61;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
    $62 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,4,$$byval_copy15,0,575040,352)|0);
    $63 = HEAP32[$48>>2]|0;
    $64 = (($this) + 88|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65*24)|0;
    _memcpy(($62|0),($63|0),($66|0))|0;
    HEAP32[$49>>2] = $size$0$lcssa$i;
    HEAP32[$48>>2] = $62;
    break;
   }
  }
 } while(0);
 $67 = (($this) + 88|0);
 HEAP32[$67>>2] = 0;
 $68 = (($this) + 96|0);
 $69 = (($this) + 108|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = $70 & 2147483647;
 $72 = ($71>>>0)<($size$0$lcssa$i>>>0);
 do {
  if ($72) {
   $73 = ($70|0)>(-1);
   if ($73) {
    HEAP32[$69>>2] = $size$0$lcssa$i;
    $74 = HEAP32[$68>>2]|0;
    $75 = ($size$0$lcssa$i*44)|0;
    $76 = (($this) + 100|0);
    $77 = HEAP32[$76>>2]|0;
    HEAP32[$0>>2] = $77;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
    $78 = (__Z16realloc_internalPvji10MemLabelIdiPKci($74,$75,4,$$byval_copy15,0,575040,370)|0);
    HEAP32[$68>>2] = $78;
    break;
   } else {
    $79 = ($size$0$lcssa$i*44)|0;
    $80 = (($this) + 100|0);
    $81 = HEAP32[$80>>2]|0;
    HEAP32[$0>>2] = $81;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
    $82 = (__Z15malloc_internaljj10MemLabelIdiPKci($79,4,$$byval_copy15,0,575040,352)|0);
    $83 = HEAP32[$68>>2]|0;
    $84 = (($this) + 104|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($85*44)|0;
    _memcpy(($82|0),($83|0),($86|0))|0;
    HEAP32[$69>>2] = $size$0$lcssa$i;
    HEAP32[$68>>2] = $82;
    break;
   }
  }
 } while(0);
 $87 = (($this) + 104|0);
 HEAP32[$87>>2] = 0;
 $88 = (($this) + 112|0);
 __ZNK16ReflectionProbes21GenerateDefaultSampleEv($1,$this);
 dest=$88+0|0; src=$1+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $89 = (($it) + 4|0);
 $90 = (($it) + 8|0);
 HEAP32[$90>>2] = $2;
 $91 = (($it) + 12|0);
 HEAP32[$91>>2] = 0;
 $92 = HEAP32[$2>>2]|0;
 HEAP32[$it>>2] = $92;
 $93 = HEAP32[$3>>2]|0;
 HEAP32[$3>>2] = $it;
 HEAP32[$89>>2] = $93;
 HEAP32[$2>>2] = $2;
 $94 = ($92|0)==($2|0);
 if ($94) {
  HEAP32[$it>>2] = $it;
 }
 HEAP32[$3>>2] = $2;
 $95 = ($93|0)==($2|0);
 if ($95) {
  HEAP32[$89>>2] = $it;
 }
 $96 = (($this) + 32|0);
 HEAP32[$96>>2] = $2;
 HEAP32[$2>>2] = $2;
 $97 = HEAP32[$it>>2]|0;
 $98 = (($97) + 4|0);
 HEAP32[$98>>2] = $it;
 $99 = HEAP32[$89>>2]|0;
 HEAP32[$99>>2] = $it;
 $100 = (($this) + 52|0);
 $101 = (($this) + 68|0);
 $102 = (($this) + 84|0);
 $103 = (($this) + 100|0);
 while(1) {
  $104 = HEAP32[$89>>2]|0;
  $105 = ($104|0)==($it|0);
  if ($105) {
   break;
  }
  $106 = (($104) + -32|0);
  HEAP32[$91>>2] = $106;
  $107 = HEAP32[$104>>2]|0;
  $108 = ($107|0)==(0|0);
  if ($108) {
   $116 = $106;
  } else {
   $109 = (($104) + 4|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = (($107) + 4|0);
   HEAP32[$111>>2] = $110;
   $112 = HEAP32[$104>>2]|0;
   $113 = HEAP32[$109>>2]|0;
   HEAP32[$113>>2] = $112;
   HEAP32[$104>>2] = 0;
   HEAP32[$109>>2] = 0;
   $$pre3$i = HEAP32[$91>>2]|0;
   $116 = $$pre3$i;
  }
  $114 = HEAP32[$90>>2]|0;
  $115 = (($116) + 32|0);
  $117 = ($115|0)==($114|0);
  if ($117) {
   $128 = $116;
  } else {
   $118 = HEAP32[$115>>2]|0;
   $119 = ($118|0)==(0|0);
   $$pre$i$i$i = (($116) + 36|0);
   if (!($119)) {
    $120 = HEAP32[$$pre$i$i$i>>2]|0;
    $121 = (($118) + 4|0);
    HEAP32[$121>>2] = $120;
    $122 = HEAP32[$115>>2]|0;
    $123 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$123>>2] = $122;
    HEAP32[$115>>2] = 0;
    HEAP32[$$pre$i$i$i>>2] = 0;
   }
   $124 = HEAP32[$114>>2]|0;
   HEAP32[$115>>2] = $124;
   HEAP32[$$pre$i$i$i>>2] = $114;
   $125 = (($124) + 4|0);
   HEAP32[$125>>2] = $115;
   $126 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$126>>2] = $115;
   $$pre$i14 = HEAP32[$91>>2]|0;
   $128 = $$pre$i14;
  }
  $127 = ($128|0)==(0|0);
  if ($127) {
   label = 55;
   break;
  }
  $129 = (($128) + 40|0);
  $130 = HEAP32[$129>>2]|0;
  do {
   if ((($130|0) == 1)) {
    $171 = HEAP32[$67>>2]|0;
    $172 = (($171) + 1)|0;
    HEAP32[$67>>2] = $172;
    $173 = HEAP32[$49>>2]|0;
    $174 = $173 & 2147483647;
    $175 = ($172>>>0)>($174>>>0);
    do {
     if ($175) {
      $176 = $173 << 1;
      $177 = ($176|0)==(0);
      $178 = $177 ? 1 : $176;
      $179 = ($174>>>0)<($178>>>0);
      if ($179) {
       $180 = ($173|0)>(-1);
       if ($180) {
        HEAP32[$49>>2] = $178;
        $181 = HEAP32[$48>>2]|0;
        $182 = ($178*24)|0;
        $183 = HEAP32[$102>>2]|0;
        HEAP32[$0>>2] = $183;
        ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
        $184 = (__Z16realloc_internalPvji10MemLabelIdiPKci($181,$182,4,$$byval_copy15,0,575040,370)|0);
        HEAP32[$48>>2] = $184;
        break;
       } else {
        $185 = ($178*24)|0;
        $186 = HEAP32[$102>>2]|0;
        HEAP32[$0>>2] = $186;
        ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
        $187 = (__Z15malloc_internaljj10MemLabelIdiPKci($185,4,$$byval_copy15,0,575040,352)|0);
        $188 = HEAP32[$48>>2]|0;
        $189 = HEAP32[$67>>2]|0;
        $190 = ($189*24)|0;
        _memcpy(($187|0),($188|0),($190|0))|0;
        HEAP32[$49>>2] = $178;
        HEAP32[$48>>2] = $187;
        break;
       }
      }
     }
    } while(0);
    $191 = HEAP32[$87>>2]|0;
    $192 = (($191) + 1)|0;
    HEAP32[$87>>2] = $192;
    $193 = HEAP32[$69>>2]|0;
    $194 = $193 & 2147483647;
    $195 = ($192>>>0)>($194>>>0);
    if ($195) {
     $196 = $193 << 1;
     $197 = ($196|0)==(0);
     $198 = $197 ? 1 : $196;
     $199 = ($194>>>0)<($198>>>0);
     if ($199) {
      $200 = ($193|0)>(-1);
      if ($200) {
       HEAP32[$69>>2] = $198;
       $201 = HEAP32[$68>>2]|0;
       $202 = ($198*44)|0;
       $203 = HEAP32[$103>>2]|0;
       HEAP32[$0>>2] = $203;
       ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
       $204 = (__Z16realloc_internalPvji10MemLabelIdiPKci($201,$202,4,$$byval_copy15,0,575040,370)|0);
       HEAP32[$68>>2] = $204;
       $index$0 = $171;
       break;
      } else {
       $205 = ($198*44)|0;
       $206 = HEAP32[$103>>2]|0;
       HEAP32[$0>>2] = $206;
       ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
       $207 = (__Z15malloc_internaljj10MemLabelIdiPKci($205,4,$$byval_copy15,0,575040,352)|0);
       $208 = HEAP32[$68>>2]|0;
       $209 = HEAP32[$87>>2]|0;
       $210 = ($209*44)|0;
       _memcpy(($207|0),($208|0),($210|0))|0;
       HEAP32[$69>>2] = $198;
       HEAP32[$68>>2] = $207;
       $index$0 = $171;
       break;
      }
     } else {
      $index$0 = $171;
     }
    } else {
     $index$0 = $171;
    }
   } else if ((($130|0) == 0)) {
    $131 = HEAP32[$27>>2]|0;
    $132 = (($131) + 1)|0;
    HEAP32[$27>>2] = $132;
    $133 = HEAP32[$9>>2]|0;
    $134 = $133 & 2147483647;
    $135 = ($132>>>0)>($134>>>0);
    do {
     if ($135) {
      $136 = $133 << 1;
      $137 = ($136|0)==(0);
      $138 = $137 ? 1 : $136;
      $139 = ($134>>>0)<($138>>>0);
      if ($139) {
       $140 = ($133|0)>(-1);
       if ($140) {
        HEAP32[$9>>2] = $138;
        $141 = HEAP32[$8>>2]|0;
        $142 = ($138*24)|0;
        $143 = HEAP32[$100>>2]|0;
        HEAP32[$0>>2] = $143;
        ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
        $144 = (__Z16realloc_internalPvji10MemLabelIdiPKci($141,$142,4,$$byval_copy15,0,575040,370)|0);
        HEAP32[$8>>2] = $144;
        break;
       } else {
        $145 = ($138*24)|0;
        $146 = HEAP32[$100>>2]|0;
        HEAP32[$0>>2] = $146;
        ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
        $147 = (__Z15malloc_internaljj10MemLabelIdiPKci($145,4,$$byval_copy15,0,575040,352)|0);
        $148 = HEAP32[$8>>2]|0;
        $149 = HEAP32[$27>>2]|0;
        $150 = ($149*24)|0;
        _memcpy(($147|0),($148|0),($150|0))|0;
        HEAP32[$9>>2] = $138;
        HEAP32[$8>>2] = $147;
        break;
       }
      }
     }
    } while(0);
    $151 = HEAP32[$47>>2]|0;
    $152 = (($151) + 1)|0;
    HEAP32[$47>>2] = $152;
    $153 = HEAP32[$29>>2]|0;
    $154 = $153 & 2147483647;
    $155 = ($152>>>0)>($154>>>0);
    if ($155) {
     $156 = $153 << 1;
     $157 = ($156|0)==(0);
     $158 = $157 ? 1 : $156;
     $159 = ($154>>>0)<($158>>>0);
     if ($159) {
      $160 = ($153|0)>(-1);
      if ($160) {
       HEAP32[$29>>2] = $158;
       $161 = HEAP32[$28>>2]|0;
       $162 = ($158*36)|0;
       $163 = HEAP32[$101>>2]|0;
       HEAP32[$0>>2] = $163;
       ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
       $164 = (__Z16realloc_internalPvji10MemLabelIdiPKci($161,$162,4,$$byval_copy15,0,575040,370)|0);
       HEAP32[$28>>2] = $164;
       $index$0 = $131;
       break;
      } else {
       $165 = ($158*36)|0;
       $166 = HEAP32[$101>>2]|0;
       HEAP32[$0>>2] = $166;
       ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
       $167 = (__Z15malloc_internaljj10MemLabelIdiPKci($165,4,$$byval_copy15,0,575040,352)|0);
       $168 = HEAP32[$28>>2]|0;
       $169 = HEAP32[$47>>2]|0;
       $170 = ($169*36)|0;
       _memcpy(($167|0),($168|0),($170|0))|0;
       HEAP32[$29>>2] = $158;
       HEAP32[$28>>2] = $167;
       $index$0 = $131;
       break;
      }
     } else {
      $index$0 = $131;
     }
    } else {
     $index$0 = $131;
    }
   } else {
    $index$0 = 0;
   }
  } while(0);
  __ZN16ReflectionProbes11UpdateProbeER15ReflectionProbej($this,$128,$index$0);
 }
 if ((label|0) == 55) {
  STACKTOP = sp;return;
 }
 HEAP32[$91>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16ReflectionProbes10RenderCubeEP15ReflectionProbeP13RenderTexture($this,$probe,$renderTexture) {
 $this = $this|0;
 $probe = $probe|0;
 $renderTexture = $renderTexture|0;
 var $$$faceMask$1$3$i = 0, $$$i = 0, $$0 = 0, $$01 = 0, $$faceMask$1$1$i = 0, $$faceMask$1$3$i = 0, $$op$i$i$i$i = Math_fround(0), $$op$i2$i$i$i = Math_fround(0), $$op$i3$i$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0;
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0);
 var $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $faceMask$1 = 0, $faceMask$1$1$i = 0, $faceMask$1$3$i = 0, $pos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $pos = sp;
 $1 = sp + 16|0;
 __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(1);
 $2 = ($probe|0)!=(0|0);
 if ($2) {
  $3 = (($probe) + 156|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   __THREW__ = 0;
   $6 = (invoke_ii(3228,($this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 6;
   } else {
    $9 = HEAP32[$6>>2]|0;
    $10 = (($probe) + 136|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($11) + ($9))|0;
    $13 = (($probe) + 44|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(1);
    if (!($15)) {
     __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(0);
     STACKTOP = sp;return;
    }
    $16 = (($probe) + 52|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0);
    if ($18) {
     __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(0);
     STACKTOP = sp;return;
    }
    $21 = (($12) + 1)|0;
    $22 = (($12>>>0) % ($17>>>0))&-1;
    $23 = ($22|0)==(0);
    $$$i = $23&1;
    $24 = (($12) + 2)|0;
    $25 = (($21>>>0) % ($17>>>0))&-1;
    $26 = ($25|0)==(0);
    $27 = $$$i | 2;
    $faceMask$1$1$i = $26 ? $27 : $$$i;
    $28 = (($12) + 3)|0;
    $29 = (($24>>>0) % ($17>>>0))&-1;
    $30 = ($29|0)==(0);
    $31 = $faceMask$1$1$i | 4;
    $$faceMask$1$1$i = $30 ? $31 : $faceMask$1$1$i;
    $32 = (($12) + 4)|0;
    $33 = (($28>>>0) % ($17>>>0))&-1;
    $34 = ($33|0)==(0);
    $35 = $$faceMask$1$1$i | 8;
    $faceMask$1$3$i = $34 ? $35 : $$faceMask$1$1$i;
    $36 = (($12) + 5)|0;
    $37 = (($32>>>0) % ($17>>>0))&-1;
    $38 = ($37|0)==(0);
    $39 = $faceMask$1$3$i | 16;
    $$faceMask$1$3$i = $38 ? $39 : $faceMask$1$3$i;
    $40 = (($36>>>0) % ($17>>>0))&-1;
    $41 = ($40|0)==(0);
    $42 = $$faceMask$1$3$i | 32;
    $$$faceMask$1$3$i = $41 ? $42 : $$faceMask$1$3$i;
    $43 = ($$$faceMask$1$3$i|0)==(0);
    if ($43) {
     __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(0);
     STACKTOP = sp;return;
    } else {
     $faceMask$1 = $$$faceMask$1$3$i;
     label = 8;
    }
   }
  } else {
   $faceMask$1 = 63;
   label = 8;
  }
 } else {
  $faceMask$1 = 63;
  label = 8;
 }
 do {
  if ((label|0) == 8) {
   __THREW__ = 0;
   $44 = (invoke_ii(3229,($this|0))|0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    label = 6;
   } else {
    $47 = (($44) + 24|0);
    $48 = HEAP32[$47>>2]|0;
    __THREW__ = 0;
    $49 = (invoke_ii(3220,($48|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 6;
    } else {
     HEAPF32[$0>>2] = Math_fround(0.0);
     $52 = (($0) + 4|0);
     HEAPF32[$52>>2] = Math_fround(0.0);
     $53 = (($0) + 8|0);
     HEAPF32[$53>>2] = Math_fround(0.0);
     $54 = (($0) + 12|0);
     HEAPF32[$54>>2] = Math_fround(1.0);
     __THREW__ = 0;
     invoke_vii(2632,($49|0),($0|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 6;
     } else {
      __THREW__ = 0;
      invoke_vii(2633,($44|0),0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 6;
      } else {
       $59 = HEAP32[577088>>2]|0;
       $60 = (($59) + 1)|0;
       HEAP32[577088>>2] = $60;
       do {
        if ($2) {
         $61 = (($probe) + 24|0);
         $62 = HEAP32[$61>>2]|0;
         __THREW__ = 0;
         $63 = (invoke_ii(3220,($62|0))|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          label = 30;
         } else {
          __THREW__ = 0;
          invoke_vii(2620,($pos|0),($63|0));
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           label = 30;
          } else {
           __THREW__ = 0;
           invoke_vii(2634,($49|0),($pos|0));
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            label = 30;
           } else {
            __THREW__ = 0;
            $70 = (invoke_i(76)|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 30;
            } else {
             $73 = (($70) + 40|0);
             $74 = HEAP32[$73>>2]|0;
             $75 = (($70) + 24|0);
             $76 = HEAP32[$75>>2]|0;
             $77 = ((($76) + (($74*96)|0)|0) + 36|0);
             $78 = Math_fround(HEAPF32[$77>>2]);
             __THREW__ = 0;
             $79 = (invoke_i(76)|0);
             $80 = __THREW__; __THREW__ = 0;
             $81 = $80&1;
             if ($81) {
              label = 30;
             } else {
              $82 = (($probe) + 92|0);
              $83 = Math_fround(HEAPF32[$82>>2]);
              __THREW__ = 0;
              invoke_vif(184,($79|0),(+$83));
              $84 = __THREW__; __THREW__ = 0;
              $85 = $84&1;
              if ($85) {
               label = 30;
              } else {
               $86 = (($probe) + 104|0);
               $87 = Math_fround(HEAPF32[$86>>2]);
               $88 = $87 < Math_fround(0.0);
               $89 = $88 ? Math_fround(0.0) : $87;
               $90 = $89 > Math_fround(1.0);
               $$op$i$i$i$i = Math_fround($89 * Math_fround(255.0));
               $91 = $90 ? Math_fround(255.0) : $$op$i$i$i$i;
               $92 = Math_fround($91 + Math_fround(0.5));
               $93 = (~~(($92))>>>0);
               $94 = (($probe) + 108|0);
               $95 = Math_fround(HEAPF32[$94>>2]);
               $96 = $95 < Math_fround(0.0);
               $97 = $96 ? Math_fround(0.0) : $95;
               $98 = $97 > Math_fround(1.0);
               $$op$i3$i$i$i = Math_fround($97 * Math_fround(255.0));
               $99 = $98 ? Math_fround(255.0) : $$op$i3$i$i$i;
               $100 = Math_fround($99 + Math_fround(0.5));
               $101 = (~~(($100))>>>0);
               $102 = (($probe) + 112|0);
               $103 = Math_fround(HEAPF32[$102>>2]);
               $104 = $103 < Math_fround(0.0);
               $105 = $104 ? Math_fround(0.0) : $103;
               $106 = $105 > Math_fround(1.0);
               $$op$i2$i$i$i = Math_fround($105 * Math_fround(255.0));
               $107 = $106 ? Math_fround(255.0) : $$op$i2$i$i$i;
               $108 = Math_fround($107 + Math_fround(0.5));
               $109 = (~~(($108))>>>0);
               $110 = (($probe) + 84|0);
               $111 = Math_fround(HEAPF32[$110>>2]);
               __THREW__ = 0;
               invoke_vif(185,($44|0),(+$111));
               $112 = __THREW__; __THREW__ = 0;
               $113 = $112&1;
               if ($113) {
                label = 30;
               } else {
                $114 = (($probe) + 88|0);
                $115 = Math_fround(HEAPF32[$114>>2]);
                __THREW__ = 0;
                invoke_vif(186,($44|0),(+$115));
                $116 = __THREW__; __THREW__ = 0;
                $117 = $116&1;
                if ($117) {
                 label = 30;
                } else {
                 $118 = (($probe) + 100|0);
                 $119 = HEAP32[$118>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(2635,($44|0),($119|0));
                 $120 = __THREW__; __THREW__ = 0;
                 $121 = $120&1;
                 if ($121) {
                  label = 30;
                 } else {
                  $122 = $93 & 255;
                  $123 = (Math_fround(($122|0)));
                  $124 = Math_fround($123 / Math_fround(255.0));
                  $125 = $101 & 255;
                  $126 = (Math_fround(($125|0)));
                  $127 = Math_fround($126 / Math_fround(255.0));
                  $128 = $109 & 255;
                  $129 = (Math_fround(($128|0)));
                  $130 = Math_fround($129 / Math_fround(255.0));
                  HEAPF32[$1>>2] = $124;
                  $131 = (($1) + 4|0);
                  HEAPF32[$131>>2] = $127;
                  $132 = (($1) + 8|0);
                  HEAPF32[$132>>2] = $130;
                  $133 = (($1) + 12|0);
                  HEAPF32[$133>>2] = Math_fround(1.0);
                  __THREW__ = 0;
                  invoke_vii(2636,($44|0),($1|0));
                  $134 = __THREW__; __THREW__ = 0;
                  $135 = $134&1;
                  if ($135) {
                   label = 30;
                  } else {
                   $136 = (($probe) + 96|0);
                   $137 = HEAP32[$136>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(2637,($44|0),($137|0));
                   $138 = __THREW__; __THREW__ = 0;
                   $139 = $138&1;
                   if ($139) {
                    label = 30;
                   } else {
                    __THREW__ = 0;
                    invoke_vif(187,($44|0),1.0);
                    $140 = __THREW__; __THREW__ = 0;
                    $141 = $140&1;
                    if ($141) {
                     label = 30;
                    } else {
                     __THREW__ = 0;
                     (invoke_iiiiii(196,($44|0),($renderTexture|0),($faceMask$1|0),(0|0),(0|0))|0);
                     $142 = __THREW__; __THREW__ = 0;
                     $143 = $142&1;
                     if ($143) {
                      label = 30;
                      break;
                     }
                     __THREW__ = 0;
                     $144 = (invoke_i(76)|0);
                     $145 = __THREW__; __THREW__ = 0;
                     $146 = $145&1;
                     if ($146) {
                      label = 30;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vif(184,($144|0),(+$78));
                     $147 = __THREW__; __THREW__ = 0;
                     $148 = $147&1;
                     if ($148) {
                      label = 30;
                      break;
                     }
                     __THREW__ = 0;
                     $149 = (invoke_i(59)|0);
                     $150 = __THREW__; __THREW__ = 0;
                     $151 = $150&1;
                     if ($151) {
                      label = 30;
                      break;
                     }
                     $152 = HEAP32[$149>>2]|0;
                     $153 = (($152) + 312|0);
                     $154 = HEAP32[$153>>2]|0;
                     __THREW__ = 0;
                     invoke_vi($154|0,($149|0));
                     $155 = __THREW__; __THREW__ = 0;
                     $156 = $155&1;
                     if ($156) {
                      label = 30;
                     }
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        } else {
         __THREW__ = 0;
         invoke_vii(2634,($49|0),(616680|0));
         $161 = __THREW__; __THREW__ = 0;
         $162 = $161&1;
         if ($162) {
          label = 30;
         } else {
          __THREW__ = 0;
          invoke_vii(2635,($44|0),1);
          $163 = __THREW__; __THREW__ = 0;
          $164 = $163&1;
          if ($164) {
           label = 30;
          } else {
           __THREW__ = 0;
           invoke_vif(187,($44|0),1.0);
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            label = 30;
           } else {
            __THREW__ = 0;
            (invoke_iiiiii(196,($44|0),($renderTexture|0),($faceMask$1|0),(347|0),(0|0))|0);
            $167 = __THREW__; __THREW__ = 0;
            $168 = $167&1;
            if ($168) {
             label = 30;
            }
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 30) {
        $157 = ___cxa_find_matching_catch()|0;
        $158 = tempRet0;
        $159 = HEAP32[577088>>2]|0;
        $160 = (($159) + -1)|0;
        HEAP32[577088>>2] = $160;
        $$0 = $157;$$01 = $158;
        break;
       }
       $169 = HEAP32[577088>>2]|0;
       $170 = (($169) + -1)|0;
       HEAP32[577088>>2] = $170;
       __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $$0 = $19;$$01 = $20;
 }
 __THREW__ = 0;
 invoke_vi(3396,0);
 $171 = __THREW__; __THREW__ = 0;
 $172 = $171&1;
 if ($172) {
  $173 = ___cxa_find_matching_catch(0|0)|0;
  $174 = tempRet0;
  ___clang_call_terminate($173);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN16ReflectionProbes10RenderQuadEP15ReflectionProbeP13RenderTexture($this,$probe,$renderTexture) {
 $this = $this|0;
 $probe = $probe|0;
 $renderTexture = $renderTexture|0;
 var $$op$i$i$i$i = Math_fround(0), $$op$i2$i$i$i = Math_fround(0), $$op$i3$i$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0);
 var $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $probeWorldMatrix = 0, $rot = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $probeWorldMatrix = sp + 112|0;
 $0 = sp + 100|0;
 $1 = sp + 88|0;
 $rot = sp + 72|0;
 $2 = sp + 56|0;
 $3 = sp + 32|0;
 $4 = sp + 16|0;
 $5 = sp;
 $6 = sp + 44|0;
 $7 = (__ZN16ReflectionProbes22GetCurrentFrameCounterEv($this)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($probe) + 136|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($probe) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(1);
 if ($13) {
  $14 = (($probe) + 52|0);
  $15 = HEAP32[$14>>2]|0;
  $21 = $15;
 } else {
  $21 = 0;
 }
 $16 = (($probe) + 156|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $19 = (($10) + ($8))|0;
  $20 = (($19>>>0) % ($21>>>0))&-1;
  $22 = ($20|0)==(0);
  if (!($22)) {
   STACKTOP = sp;return;
  }
 }
 $23 = (($probe) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($24)|0);
 __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($probeWorldMatrix,$25);
 $26 = HEAP32[$23>>2]|0;
 $27 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($26)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($0,$27);
 $28 = Math_fround(HEAPF32[$0>>2]);
 $29 = $28 < Math_fround(0.00999999977648258209228);
 $30 = $29 ? Math_fround(0.00999999977648258209228) : $28;
 $31 = (($0) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = $32 < Math_fround(0.00999999977648258209228);
 $34 = $33 ? Math_fround(0.00999999977648258209228) : $32;
 $35 = (__ZN16ReflectionProbes9GetCameraEv($this)|0);
 $36 = (($35) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($37)|0);
 $39 = (($probeWorldMatrix) + 48|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($probeWorldMatrix) + 52|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($probeWorldMatrix) + 56|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($probeWorldMatrix) + 32|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($probeWorldMatrix) + 36|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($probeWorldMatrix) + 40|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($probe) + 84|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($46 * $52);
 $54 = Math_fround($48 * $52);
 $55 = Math_fround($50 * $52);
 $56 = Math_fround($40 + $53);
 $57 = Math_fround($42 + $54);
 $58 = Math_fround($44 + $55);
 HEAPF32[$1>>2] = $56;
 $59 = (($1) + 4|0);
 HEAPF32[$59>>2] = $57;
 $60 = (($1) + 8|0);
 HEAPF32[$60>>2] = $58;
 __ZN9Transform11SetPositionERK8Vector3f($38,$1);
 $61 = Math_fround(HEAPF32[$45>>2]);
 $62 = Math_fround(HEAPF32[$47>>2]);
 $63 = Math_fround(HEAPF32[$49>>2]);
 $64 = Math_fround(-$61);
 $65 = Math_fround(-$62);
 $66 = Math_fround(-$63);
 HEAPF32[$2>>2] = $64;
 $67 = (($2) + 4|0);
 HEAPF32[$67>>2] = $65;
 $68 = (($2) + 8|0);
 HEAPF32[$68>>2] = $66;
 $69 = (($probeWorldMatrix) + 16|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($probeWorldMatrix) + 20|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($probeWorldMatrix) + 24|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround(-$70);
 $76 = Math_fround(-$72);
 $77 = Math_fround(-$74);
 HEAPF32[$3>>2] = $75;
 $78 = (($3) + 4|0);
 HEAPF32[$78>>2] = $76;
 $79 = (($3) + 8|0);
 HEAPF32[$79>>2] = $77;
 (__Z24LookRotationToQuaternionRK8Vector3fS1_P11Quaternionf($2,$3,$rot)|0);
 __ZN9Transform11SetRotationERK11Quaternionf($38,$rot);
 $80 = (__Z18GetQualitySettingsv()|0);
 $81 = (($80) + 40|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($80) + 24|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ((($84) + (($82*96)|0)|0) + 36|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (__Z18GetQualitySettingsv()|0);
 $88 = (($probe) + 92|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 __ZN15QualitySettings28SetShadowDistanceTemporarilyEf($87,$89);
 $90 = (($probe) + 104|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = $91 < Math_fround(0.0);
 $93 = $92 ? Math_fround(0.0) : $91;
 $94 = $93 > Math_fround(1.0);
 $$op$i$i$i$i = Math_fround($93 * Math_fround(255.0));
 $95 = $94 ? Math_fround(255.0) : $$op$i$i$i$i;
 $96 = Math_fround($95 + Math_fround(0.5));
 $97 = (~~(($96))>>>0);
 $98 = (($probe) + 108|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = $99 < Math_fround(0.0);
 $101 = $100 ? Math_fround(0.0) : $99;
 $102 = $101 > Math_fround(1.0);
 $$op$i3$i$i$i = Math_fround($101 * Math_fround(255.0));
 $103 = $102 ? Math_fround(255.0) : $$op$i3$i$i$i;
 $104 = Math_fround($103 + Math_fround(0.5));
 $105 = (~~(($104))>>>0);
 $106 = (($probe) + 112|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = $107 < Math_fround(0.0);
 $109 = $108 ? Math_fround(0.0) : $107;
 $110 = $109 > Math_fround(1.0);
 $$op$i2$i$i$i = Math_fround($109 * Math_fround(255.0));
 $111 = $110 ? Math_fround(255.0) : $$op$i2$i$i$i;
 $112 = Math_fround($111 + Math_fround(0.5));
 $113 = (~~(($112))>>>0);
 $114 = Math_fround(HEAPF32[$51>>2]);
 __ZN6Camera7SetNearEf($35,$114);
 $115 = (($probe) + 88|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 __ZN6Camera6SetFarEf($35,$116);
 $117 = (($probe) + 100|0);
 $118 = HEAP32[$117>>2]|0;
 __ZN6Camera13SetClearFlagsEi($35,$118);
 $119 = $97 & 255;
 $120 = (Math_fround(($119|0)));
 $121 = Math_fround($120 / Math_fround(255.0));
 $122 = $105 & 255;
 $123 = (Math_fround(($122|0)));
 $124 = Math_fround($123 / Math_fround(255.0));
 $125 = $113 & 255;
 $126 = (Math_fround(($125|0)));
 $127 = Math_fround($126 / Math_fround(255.0));
 HEAPF32[$4>>2] = $121;
 $128 = (($4) + 4|0);
 HEAPF32[$128>>2] = $124;
 $129 = (($4) + 8|0);
 HEAPF32[$129>>2] = $127;
 $130 = (($4) + 12|0);
 HEAPF32[$130>>2] = Math_fround(1.0);
 __ZN6Camera18SetBackgroundColorERK10ColorRGBAf($35,$4);
 $131 = (($probe) + 96|0);
 $132 = HEAP32[$131>>2]|0;
 __ZN6Camera14SetCullingMaskEj($35,$132);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $133 = (($5) + 8|0);
 HEAPF32[$133>>2] = Math_fround(1.0);
 $134 = (($5) + 4|0);
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = (($5) + 12|0);
 HEAPF32[$135>>2] = Math_fround(1.0);
 __ZN6Camera25SetNormalizedViewportRectERK5RectTIfE($35,$5);
 __ZN6Camera15SetOrthographicEb($35,1);
 __ZN6Camera19SetOrthographicSizeEf($35,$34);
 $136 = Math_fround($30 / $34);
 __ZN6Camera9SetAspectEf($35,$136);
 __ZN6Camera16SetTargetTextureEP13RenderTexture($35,$renderTexture);
 HEAP8[$6>>0] = 0;
 $137 = (($6) + 1|0);
 HEAP8[$137>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(348,($35|0),2,(0|0),($6|0));
 $138 = __THREW__; __THREW__ = 0;
 $139 = $138&1;
 if ($139) {
  $146 = ___cxa_find_matching_catch()|0;
  $147 = tempRet0;
  $148 = HEAP8[$6>>0]|0;
  $149 = $148 & 1;
  $150 = ($149<<24>>24)==(0);
  if ($150) {
   ___resumeException($146|0);
   // unreachable;
  }
  $151 = (($6) + 8|0);
  $152 = HEAP32[$151>>2]|0;
  __ZdlPv($152);
  ___resumeException($146|0);
  // unreachable;
 } else {
  $140 = HEAP8[$6>>0]|0;
  $141 = $140 & 1;
  $142 = ($141<<24>>24)==(0);
  if (!($142)) {
   $143 = (($6) + 8|0);
   $144 = HEAP32[$143>>2]|0;
   __ZdlPv($144);
  }
  $145 = (__Z18GetQualitySettingsv()|0);
  __ZN15QualitySettings28SetShadowDistanceTemporarilyEf($145,$86);
  STACKTOP = sp;return;
 }
}
function __ZN16ReflectionProbes11RenderProbeEP15ReflectionProbe($this,$probe) {
 $this = $this|0;
 $probe = $probe|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($probe) + 148|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__Z12GetGfxDevicev()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 788|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $10 = HEAP32[$2>>2]|0;
 $11 = (($9>>>0) % ($10>>>0))&-1;
 $12 = (($probe) + 140|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($11<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 __ZNK15ReflectionProbe10GetTextureEv($1,$probe);
 $17 = HEAP32[$1>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $$0$i1 = 0;
 } else {
  HEAP32[$0>>2] = $17;
  $19 = HEAP32[560624>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   label = 12;
  } else {
   $21 = (($19) + 36|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($19) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22|0)==($24|0);
   do {
    if ($25) {
     $26 = (($19) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($19) + 32|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + ($29<<3)|0);
     $46 = $30;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$19,$0);
     $31 = HEAP32[$pos$i$i$i$i>>2]|0;
     $32 = ($31|0)==(-1);
     $33 = (($19) + 28|0);
     $34 = HEAP32[$33>>2]|0;
     if ($32) {
      $35 = (($19) + 32|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($34) + ($36<<3)|0);
      $46 = $37;
      break;
     } else {
      $38 = (($34) + ($31<<3)|0);
      $46 = $38;
      break;
     }
    }
   } while(0);
   $39 = HEAP32[560624>>2]|0;
   $40 = (($39) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 32|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + ($43<<3)|0);
   $45 = ($46|0)==($44|0);
   if ($45) {
    label = 12;
   } else {
    $47 = (($46) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     label = 12;
    } else {
     $temp$0$i = $48;
    }
   }
  }
  if ((label|0) == 12) {
   $50 = (__Z31ReadObjectFromPersistentManageri($17)|0);
   $temp$0$i = $50;
  }
  $$0$i1 = $temp$0$i;
 }
 __ZN16ReflectionProbes22ForceProbeToUseTextureER15ReflectionProbeP7Texture($this,$probe,$$0$i1);
 $51 = (($probe) + 40|0);
 $52 = HEAP32[$51>>2]|0;
 if ((($52|0) == 0)) {
  __ZN16ReflectionProbes10RenderCubeEP15ReflectionProbeP13RenderTexture($this,$probe,$15);
 } else if ((($52|0) == 1)) {
  __ZN16ReflectionProbes10RenderQuadEP15ReflectionProbeP13RenderTexture($this,$probe,$15);
 }
 $53 = (($probe) + 136|0);
 $54 = HEAP32[$53>>2]|0;
 __ZN16ReflectionProbes11UpdateProbeER15ReflectionProbej($this,$probe,$54);
 $55 = (($probe) + 156|0);
 HEAP8[$55>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN16ReflectionProbes22GetCurrentFrameCounterEv($this) {
 $this = $this|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 784|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = (($this) + 12|0);
 $7 = (($this) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9>>>0)<($5>>>0);
 do {
  if ($10) {
   $11 = ($8|0)>(-1);
   if ($11) {
    HEAP32[$7>>2] = $5;
    $12 = HEAP32[$6>>2]|0;
    $13 = $5 << 2;
    $14 = (($this) + 16|0);
    $15 = HEAP32[$14>>2]|0;
    HEAP32[$0>>2] = $15;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $16 = (__Z16realloc_internalPvji10MemLabelIdiPKci($12,$13,4,$$byval_copy1,0,575040,370)|0);
    HEAP32[$6>>2] = $16;
    break;
   } else {
    $17 = $5 << 2;
    $18 = (($this) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    HEAP32[$0>>2] = $19;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($17,4,$$byval_copy1,0,575040,352)|0);
    $21 = HEAP32[$6>>2]|0;
    $22 = (($this) + 20|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = $23 << 2;
    _memcpy(($20|0),($21|0),($24|0))|0;
    HEAP32[$7>>2] = $5;
    HEAP32[$6>>2] = $20;
    break;
   }
  }
 } while(0);
 $25 = (($this) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26>>>0)<($5>>>0);
 if ($27) {
  $28 = HEAP32[$6>>2]|0;
  $29 = (($28) + ($5<<2)|0);
  $30 = ($26|0)==($5|0);
  if (!($30)) {
   $31 = (($28) + ($26<<2)|0);
   $$01$i$i = $31;
   while(1) {
    $32 = ($$01$i$i|0)==(0|0);
    if (!($32)) {
     HEAP32[$$01$i$i>>2] = 0;
    }
    $33 = (($$01$i$i) + 4|0);
    $34 = ($33|0)==($29|0);
    if ($34) {
     break;
    } else {
     $$01$i$i = $33;
    }
   }
  }
 }
 HEAP32[$25>>2] = $5;
 $35 = (__Z12GetGfxDevicev()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 788|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 4095]($35)|0);
 $40 = HEAP32[$6>>2]|0;
 $41 = (($40) + ($39<<2)|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN16ReflectionProbes9GetCameraEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $25 = $2;
  STACKTOP = sp;return ($25|0);
 }
 $4 = (__Znwj(32)|0);
 $5 = (($0) + 8|0);
 HEAP32[$5>>2] = $4;
 HEAP32[$0>>2] = 33;
 $6 = (($0) + 4|0);
 HEAP32[$6>>2] = 24;
 dest=$4+0|0; src=575072+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $7 = (($4) + 24|0);
 HEAP8[$7>>0] = 0;
 __THREW__ = 0;
 HEAP32[$vararg_buffer>>2] = 0;
 $8 = (invoke_iiiiii(197,($0|0),1,61,(575104|0),($vararg_buffer|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP8[$0>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   ___resumeException($19|0);
   // unreachable;
  }
  $24 = HEAP32[$5>>2]|0;
  __ZdlPv($24);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if (!($13)) {
   $14 = HEAP32[$5>>2]|0;
   __ZdlPv($14);
  }
  $15 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($8,20)|0);
  HEAP32[$1>>2] = $15;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 120|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vii[$18 & 4095]($15,0);
  $$pre = HEAP32[$1>>2]|0;
  $25 = $$pre;
  STACKTOP = sp;return ($25|0);
 }
 return 0|0;
}
function __ZL37PostProcessCullResultsForSkyboxProbesPK9SceneNodePK4AABBR9IndexListPv($nodes,$bounds,$list,$userData) {
 $nodes = $nodes|0;
 $bounds = $bounds|0;
 $list = $list|0;
 $userData = $userData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($list) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK16ReflectionProbes21GenerateDefaultSampleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$pre = 0, $$sroa$0$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$08 = 0, $phitmp$i = 0, $pos$i$i$i$i1 = 0, $temp$0$i = 0, $temp$0$i510 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i$i1 = sp + 56|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 16|0;
 $4 = sp + 40|0;
 dest=$agg$result+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $5 = (($3) + 12|0);
 $6 = (($this) + 4|0);
 $i$08 = 0;
 while(1) {
  $7 = (($agg$result) + (($i$08*60)|0)|0);
  ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
  ;HEAP32[$3+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[616680+8>>2]|0;
  ;HEAP32[$5+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[616664+8>>2]|0;
  ;HEAP32[$7+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$7+20>>2]=HEAP32[$3+20>>2]|0;
  $8 = HEAP32[$this>>2]|0;
  $9 = ($8|0)==(0);
  do {
   if ($9) {
    label = 23;
   } else {
    HEAP32[$2>>2] = $8;
    $10 = HEAP32[560624>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     label = 11;
    } else {
     $12 = (($10) + 36|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($10) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($13|0)==($15|0);
     do {
      if ($16) {
       $17 = (($10) + 28|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = (($10) + 32|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($18) + ($20<<3)|0);
       $37 = $21;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$10,$2);
       $22 = HEAP32[$pos$i$i$i$i1>>2]|0;
       $23 = ($22|0)==(-1);
       $24 = (($10) + 28|0);
       $25 = HEAP32[$24>>2]|0;
       if ($23) {
        $26 = (($10) + 32|0);
        $27 = HEAP32[$26>>2]|0;
        $28 = (($25) + ($27<<3)|0);
        $37 = $28;
        break;
       } else {
        $29 = (($25) + ($22<<3)|0);
        $37 = $29;
        break;
       }
      }
     } while(0);
     $30 = HEAP32[560624>>2]|0;
     $31 = (($30) + 28|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($30) + 32|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + ($34<<3)|0);
     $36 = ($37|0)==($35|0);
     if ($36) {
      label = 11;
     } else {
      $38 = (($37) + 4|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = ($39|0)==(0|0);
      if ($40) {
       label = 11;
      } else {
       $45 = $30;
      }
     }
    }
    if ((label|0) == 11) {
     label = 0;
     $41 = HEAP32[$this>>2]|0;
     $42 = (__Z31ReadObjectFromPersistentManageri($41)|0);
     $phitmp$i = ($42|0)==(0|0);
     if ($phitmp$i) {
      label = 23;
      break;
     }
     $$pre = HEAP32[560624>>2]|0;
     $45 = $$pre;
    }
    $43 = HEAP32[$this>>2]|0;
    HEAP32[$1>>2] = $43;
    $44 = ($45|0)==(0|0);
    if ($44) {
     label = 21;
    } else {
     $46 = (($45) + 36|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (($45) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($47|0)==($49|0);
     do {
      if ($50) {
       $51 = (($45) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($45) + 32|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = (($52) + ($54<<3)|0);
       $71 = $55;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$45,$1);
       $56 = HEAP32[$pos$i$i$i$i1>>2]|0;
       $57 = ($56|0)==(-1);
       $58 = (($45) + 28|0);
       $59 = HEAP32[$58>>2]|0;
       if ($57) {
        $60 = (($45) + 32|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = (($59) + ($61<<3)|0);
        $71 = $62;
        break;
       } else {
        $63 = (($59) + ($56<<3)|0);
        $71 = $63;
        break;
       }
      }
     } while(0);
     $64 = HEAP32[560624>>2]|0;
     $65 = (($64) + 28|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = (($64) + 32|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($66) + ($68<<3)|0);
     $70 = ($71|0)==($69|0);
     if ($70) {
      label = 21;
     } else {
      $72 = (($71) + 4|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = ($73|0)==(0|0);
      if ($74) {
       label = 21;
      } else {
       $temp$0$i = $73;
      }
     }
    }
    if ((label|0) == 21) {
     label = 0;
     $75 = HEAP32[$this>>2]|0;
     $76 = (__Z31ReadObjectFromPersistentManageri($75)|0);
     $temp$0$i = $76;
    }
    $77 = (($temp$0$i) + 44|0);
    $78 = HEAP32[$77>>2]|0;
    $$sroa$0$0 = $78;
   }
  } while(0);
  if ((label|0) == 23) {
   label = 0;
   $79 = (__ZN10builtintex21GetBlackCubeTextureIDEv()|0);
   $$sroa$0$0 = $79;
  }
  $80 = ((($agg$result) + (($i$08*60)|0)|0) + 24|0);
  HEAP32[$80>>2] = $$sroa$0$0;
  $81 = ((($agg$result) + (($i$08*60)|0)|0) + 28|0);
  $82 = HEAP32[$this>>2]|0;
  $83 = ($82|0)==(0);
  do {
   if ($83) {
    label = 35;
   } else {
    HEAP32[$0>>2] = $82;
    $84 = HEAP32[560624>>2]|0;
    $85 = ($84|0)==(0|0);
    if ($85) {
     label = 34;
    } else {
     $86 = (($84) + 36|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = (($84) + 4|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = ($87|0)==($89|0);
     do {
      if ($90) {
       $91 = (($84) + 28|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = (($84) + 32|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = (($92) + ($94<<3)|0);
       $111 = $95;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$84,$0);
       $96 = HEAP32[$pos$i$i$i$i1>>2]|0;
       $97 = ($96|0)==(-1);
       $98 = (($84) + 28|0);
       $99 = HEAP32[$98>>2]|0;
       if ($97) {
        $100 = (($84) + 32|0);
        $101 = HEAP32[$100>>2]|0;
        $102 = (($99) + ($101<<3)|0);
        $111 = $102;
        break;
       } else {
        $103 = (($99) + ($96<<3)|0);
        $111 = $103;
        break;
       }
      }
     } while(0);
     $104 = HEAP32[560624>>2]|0;
     $105 = (($104) + 28|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = (($104) + 32|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = (($106) + ($108<<3)|0);
     $110 = ($111|0)==($109|0);
     if ($110) {
      label = 34;
     } else {
      $112 = (($111) + 4|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = ($113|0)==(0|0);
      if ($114) {
       label = 34;
      } else {
       $temp$0$i510 = $113;
      }
     }
    }
    if ((label|0) == 34) {
     label = 0;
     $115 = HEAP32[$this>>2]|0;
     $116 = (__Z31ReadObjectFromPersistentManageri($115)|0);
     $117 = ($116|0)==(0|0);
     if ($117) {
      label = 35;
      break;
     } else {
      $temp$0$i510 = $116;
     }
    }
    $118 = Math_fround(HEAPF32[$6>>2]);
    $119 = (($temp$0$i510) + 52|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = (__Z19GetActiveColorSpacev()|0);
    $122 = ($121|0)==(1);
    if ($122) {
     $123 = (($temp$0$i510) + 56|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = $124;
    } else {
     $125 = 0;
    }
    __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($4,$120,$125,$118);
   }
  } while(0);
  if ((label|0) == 35) {
   label = 0;
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($4,0,0,Math_fround(1.0));
  }
  ;HEAP32[$81+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$81+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$81+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$81+12>>2]=HEAP32[$4+12>>2]|0;
  $126 = ((($agg$result) + (($i$08*60)|0)|0) + 44|0);
  $127 = (($i$08) + 1)|0;
  $exitcond = ($127|0)==(2);
  ;HEAP32[$126+0>>2]=0|0;HEAP32[$126+4>>2]=0|0;HEAP32[$126+8>>2]=0|0;HEAP32[$126+12>>2]=0|0;
  if ($exitcond) {
   break;
  } else {
   $i$08 = $127;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16ReflectionProbes40UpdateRealtimeReflectionProbesTimeslicedEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i5 = 0, $$pre$i16 = 0, $$pre$i25 = 0, $$pre$i7 = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre$phi38Z2D = 0, $$pre3$i = 0, $$pre3$i12 = 0, $$pre3$i21 = 0, $$pre3$i3 = 0;
 var $$pre37 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $it = 0, $it1 = 0, $it2 = 0, $it3 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $pos$i$i$i$i = sp + 80|0;
 $0 = sp;
 $it = sp + 8|0;
 $it1 = sp + 24|0;
 $1 = sp + 40|0;
 $it2 = sp + 48|0;
 $it3 = sp + 64|0;
 $2 = (__Z19GetActiveColorSpacev()|0);
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if (!($5)) {
   $6 = (($this) + 28|0);
   $7 = (($it) + 4|0);
   $8 = (($it) + 8|0);
   HEAP32[$8>>2] = $6;
   $9 = (($it) + 12|0);
   HEAP32[$9>>2] = 0;
   $10 = HEAP32[$6>>2]|0;
   HEAP32[$it>>2] = $10;
   $11 = (($this) + 32|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$11>>2] = $it;
   HEAP32[$7>>2] = $12;
   HEAP32[$6>>2] = $6;
   $13 = ($10|0)==($6|0);
   if ($13) {
    HEAP32[$it>>2] = $it;
   }
   HEAP32[$11>>2] = $6;
   $14 = ($12|0)==($6|0);
   if ($14) {
    HEAP32[$7>>2] = $it;
   }
   $15 = (($this) + 32|0);
   HEAP32[$15>>2] = $6;
   HEAP32[$6>>2] = $6;
   $16 = HEAP32[$it>>2]|0;
   $17 = (($16) + 4|0);
   HEAP32[$17>>2] = $it;
   $18 = HEAP32[$7>>2]|0;
   HEAP32[$18>>2] = $it;
   $19 = HEAP32[$7>>2]|0;
   $20 = ($19|0)==($it|0);
   L9: do {
    if ($20) {
     label = 13;
    } else {
     $22 = $19;
     while(1) {
      $21 = (($22) + -32|0);
      HEAP32[$9>>2] = $21;
      $23 = HEAP32[$22>>2]|0;
      $24 = ($23|0)==(0|0);
      if ($24) {
       $32 = $21;
      } else {
       $25 = (($22) + 4|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = (($23) + 4|0);
       HEAP32[$27>>2] = $26;
       $28 = HEAP32[$22>>2]|0;
       $29 = HEAP32[$25>>2]|0;
       HEAP32[$29>>2] = $28;
       HEAP32[$22>>2] = 0;
       HEAP32[$25>>2] = 0;
       $$pre3$i = HEAP32[$9>>2]|0;
       $32 = $$pre3$i;
      }
      $30 = HEAP32[$8>>2]|0;
      $31 = (($32) + 32|0);
      $33 = ($31|0)==($30|0);
      if ($33) {
       $44 = $32;
      } else {
       $34 = HEAP32[$31>>2]|0;
       $35 = ($34|0)==(0|0);
       $$pre$i$i$i = (($32) + 36|0);
       if (!($35)) {
        $36 = HEAP32[$$pre$i$i$i>>2]|0;
        $37 = (($34) + 4|0);
        HEAP32[$37>>2] = $36;
        $38 = HEAP32[$31>>2]|0;
        $39 = HEAP32[$$pre$i$i$i>>2]|0;
        HEAP32[$39>>2] = $38;
        HEAP32[$31>>2] = 0;
        HEAP32[$$pre$i$i$i>>2] = 0;
       }
       $40 = HEAP32[$30>>2]|0;
       HEAP32[$31>>2] = $40;
       HEAP32[$$pre$i$i$i>>2] = $30;
       $41 = (($40) + 4|0);
       HEAP32[$41>>2] = $31;
       $42 = HEAP32[$$pre$i$i$i>>2]|0;
       HEAP32[$42>>2] = $31;
       $$pre$i = HEAP32[$9>>2]|0;
       $44 = $$pre$i;
      }
      $43 = ($44|0)==(0|0);
      if ($43) {
       break L9;
      }
      $45 = (($44) + 156|0);
      HEAP8[$45>>0] = 1;
      $46 = HEAP32[$7>>2]|0;
      $47 = ($46|0)==($it|0);
      if ($47) {
       label = 13;
       break;
      } else {
       $22 = $46;
      }
     }
    }
   } while(0);
   if ((label|0) == 13) {
    HEAP32[$9>>2] = 0;
   }
   __THREW__ = 0;
   $50 = (invoke_i(66)|0);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if (!($52)) {
    HEAP32[$3>>2] = $50;
    HEAP32[$7>>2] = 0;
    HEAP32[$it>>2] = 0;
    break;
   }
   $48 = ___cxa_find_matching_catch()|0;
   $49 = tempRet0;
   HEAP32[$7>>2] = 0;
   HEAP32[$it>>2] = 0;
   $$1 = $48;$$12 = $49;
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $53 = (($this) + 40|0);
 $54 = HEAP32[$53>>2]|0;
 if ((($54|0) == -1)) {
  HEAP32[$53>>2] = 0;
 } else if (!((($54|0) == 0))) {
  HEAP32[$53>>2] = 0;
  __ZN16ReflectionProbes27InvalidateAllRenderTexturesEv($this);
 }
 $55 = (($this) + 44|0);
 $56 = HEAP8[$55>>0]|0;
 $57 = ($56<<24>>24)==(0);
 $58 = (($this) + 28|0);
 if ($57) {
  $59 = (($it1) + 4|0);
  $60 = (($it1) + 8|0);
  HEAP32[$60>>2] = $58;
  $61 = (($it1) + 12|0);
  HEAP32[$61>>2] = 0;
  $62 = HEAP32[$58>>2]|0;
  HEAP32[$it1>>2] = $62;
  $63 = (($this) + 32|0);
  $64 = HEAP32[$63>>2]|0;
  HEAP32[$63>>2] = $it1;
  HEAP32[$59>>2] = $64;
  HEAP32[$58>>2] = $58;
  $65 = ($62|0)==($58|0);
  if ($65) {
   HEAP32[$it1>>2] = $it1;
  }
  HEAP32[$63>>2] = $58;
  $66 = ($64|0)==($58|0);
  if ($66) {
   HEAP32[$59>>2] = $it1;
  }
  $67 = (($this) + 32|0);
  HEAP32[$67>>2] = $58;
  HEAP32[$58>>2] = $58;
  $68 = HEAP32[$it1>>2]|0;
  $69 = (($68) + 4|0);
  HEAP32[$69>>2] = $it1;
  $70 = HEAP32[$59>>2]|0;
  HEAP32[$70>>2] = $it1;
  while(1) {
   $71 = HEAP32[$59>>2]|0;
   $72 = ($71|0)==($it1|0);
   if ($72) {
    label = 36;
    break;
   }
   $73 = (($71) + -32|0);
   HEAP32[$61>>2] = $73;
   $74 = HEAP32[$71>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    $83 = $73;
   } else {
    $76 = (($71) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($74) + 4|0);
    HEAP32[$78>>2] = $77;
    $79 = HEAP32[$71>>2]|0;
    $80 = HEAP32[$76>>2]|0;
    HEAP32[$80>>2] = $79;
    HEAP32[$71>>2] = 0;
    HEAP32[$76>>2] = 0;
    $$pre3$i21 = HEAP32[$61>>2]|0;
    $83 = $$pre3$i21;
   }
   $81 = HEAP32[$60>>2]|0;
   $82 = (($83) + 32|0);
   $84 = ($82|0)==($81|0);
   if ($84) {
    $95 = $83;
   } else {
    $85 = HEAP32[$82>>2]|0;
    $86 = ($85|0)==(0|0);
    $$pre$i$i$i23 = (($83) + 36|0);
    if (!($86)) {
     $87 = HEAP32[$$pre$i$i$i23>>2]|0;
     $88 = (($85) + 4|0);
     HEAP32[$88>>2] = $87;
     $89 = HEAP32[$82>>2]|0;
     $90 = HEAP32[$$pre$i$i$i23>>2]|0;
     HEAP32[$90>>2] = $89;
     HEAP32[$82>>2] = 0;
     HEAP32[$$pre$i$i$i23>>2] = 0;
    }
    $91 = HEAP32[$81>>2]|0;
    HEAP32[$82>>2] = $91;
    HEAP32[$$pre$i$i$i23>>2] = $81;
    $92 = (($91) + 4|0);
    HEAP32[$92>>2] = $82;
    $93 = HEAP32[$$pre$i$i$i23>>2]|0;
    HEAP32[$93>>2] = $82;
    $$pre$i25 = HEAP32[$61>>2]|0;
    $95 = $$pre$i25;
   }
   $94 = ($95|0)==(0|0);
   if ($94) {
    break;
   }
   __THREW__ = 0;
   invoke_vii(2638,($1|0),($95|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    label = 51;
    break;
   }
   $98 = HEAP32[$1>>2]|0;
   $99 = ($98|0)==(0);
   if ($99) {
    $$0$i = 0;
   } else {
    HEAP32[$0>>2] = $98;
    $100 = HEAP32[560624>>2]|0;
    $101 = ($100|0)==(0|0);
    if ($101) {
     label = 48;
    } else {
     $102 = (($100) + 36|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = (($100) + 4|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = ($103|0)==($105|0);
     do {
      if ($106) {
       $107 = (($100) + 28|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = (($100) + 32|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = (($108) + ($110<<3)|0);
       $127 = $111;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$100,$0);
       $112 = HEAP32[$pos$i$i$i$i>>2]|0;
       $113 = ($112|0)==(-1);
       $114 = (($100) + 28|0);
       $115 = HEAP32[$114>>2]|0;
       if ($113) {
        $116 = (($100) + 32|0);
        $117 = HEAP32[$116>>2]|0;
        $118 = (($115) + ($117<<3)|0);
        $127 = $118;
        break;
       } else {
        $119 = (($115) + ($112<<3)|0);
        $127 = $119;
        break;
       }
      }
     } while(0);
     $120 = HEAP32[560624>>2]|0;
     $121 = (($120) + 28|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = (($120) + 32|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = (($122) + ($124<<3)|0);
     $126 = ($127|0)==($125|0);
     if ($126) {
      label = 48;
     } else {
      $128 = (($127) + 4|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ($129|0)==(0|0);
      if ($130) {
       label = 48;
      } else {
       $temp$0$i = $129;
      }
     }
    }
    if ((label|0) == 48) {
     label = 0;
     __THREW__ = 0;
     $131 = (invoke_ii(3215,($98|0))|0);
     $132 = __THREW__; __THREW__ = 0;
     $133 = $132&1;
     if ($133) {
      label = 51;
      break;
     } else {
      $temp$0$i = $131;
     }
    }
    $$0$i = $temp$0$i;
   }
   __THREW__ = 0;
   invoke_viii(1686,($this|0),($95|0),($$0$i|0));
   $134 = __THREW__; __THREW__ = 0;
   $135 = $134&1;
   if ($135) {
    label = 51;
    break;
   }
  }
  if ((label|0) == 36) {
   HEAP32[$61>>2] = 0;
  }
  else if ((label|0) == 51) {
   $136 = ___cxa_find_matching_catch()|0;
   $137 = tempRet0;
   HEAP32[$59>>2] = 0;
   HEAP32[$it1>>2] = 0;
   $$1 = $136;$$12 = $137;
   ___resumeException($$1|0);
   // unreachable;
  }
  HEAP32[$59>>2] = 0;
  HEAP32[$it1>>2] = 0;
  $$pre$phi34Z2D = $58;$$pre$phi36Z2D = $58;$$pre$phi38Z2D = $63;
 } else {
  $$pre37 = (($this) + 32|0);
  $$pre$phi34Z2D = $58;$$pre$phi36Z2D = $58;$$pre$phi38Z2D = $$pre37;
 }
 $138 = (($it2) + 4|0);
 $139 = (($it2) + 8|0);
 HEAP32[$139>>2] = $58;
 $140 = (($it2) + 12|0);
 HEAP32[$140>>2] = 0;
 $141 = HEAP32[$$pre$phi36Z2D>>2]|0;
 HEAP32[$it2>>2] = $141;
 $142 = HEAP32[$$pre$phi38Z2D>>2]|0;
 HEAP32[$$pre$phi38Z2D>>2] = $it2;
 HEAP32[$138>>2] = $142;
 HEAP32[$$pre$phi36Z2D>>2] = $$pre$phi34Z2D;
 $143 = ($141|0)==($$pre$phi34Z2D|0);
 if ($143) {
  HEAP32[$it2>>2] = $it2;
 }
 HEAP32[$$pre$phi38Z2D>>2] = $$pre$phi34Z2D;
 $144 = ($142|0)==($$pre$phi34Z2D|0);
 if ($144) {
  HEAP32[$138>>2] = $it2;
 }
 $145 = (($$pre$phi34Z2D) + 4|0);
 HEAP32[$145>>2] = $$pre$phi34Z2D;
 $146 = HEAP32[$$pre$phi38Z2D>>2]|0;
 HEAP32[$146>>2] = $$pre$phi34Z2D;
 $147 = HEAP32[$it2>>2]|0;
 $148 = (($147) + 4|0);
 HEAP32[$148>>2] = $it2;
 $149 = HEAP32[$138>>2]|0;
 HEAP32[$149>>2] = $it2;
 while(1) {
  $150 = HEAP32[$138>>2]|0;
  $151 = ($150|0)==($it2|0);
  if ($151) {
   label = 65;
   break;
  }
  $152 = (($150) + -32|0);
  HEAP32[$140>>2] = $152;
  $153 = HEAP32[$150>>2]|0;
  $154 = ($153|0)==(0|0);
  if ($154) {
   $162 = $152;
  } else {
   $155 = (($150) + 4|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = (($153) + 4|0);
   HEAP32[$157>>2] = $156;
   $158 = HEAP32[$150>>2]|0;
   $159 = HEAP32[$155>>2]|0;
   HEAP32[$159>>2] = $158;
   HEAP32[$150>>2] = 0;
   HEAP32[$155>>2] = 0;
   $$pre3$i12 = HEAP32[$140>>2]|0;
   $162 = $$pre3$i12;
  }
  $160 = HEAP32[$139>>2]|0;
  $161 = (($162) + 32|0);
  $163 = ($161|0)==($160|0);
  if ($163) {
   $174 = $162;
  } else {
   $164 = HEAP32[$161>>2]|0;
   $165 = ($164|0)==(0|0);
   $$pre$i$i$i14 = (($162) + 36|0);
   if (!($165)) {
    $166 = HEAP32[$$pre$i$i$i14>>2]|0;
    $167 = (($164) + 4|0);
    HEAP32[$167>>2] = $166;
    $168 = HEAP32[$161>>2]|0;
    $169 = HEAP32[$$pre$i$i$i14>>2]|0;
    HEAP32[$169>>2] = $168;
    HEAP32[$161>>2] = 0;
    HEAP32[$$pre$i$i$i14>>2] = 0;
   }
   $170 = HEAP32[$160>>2]|0;
   HEAP32[$161>>2] = $170;
   HEAP32[$$pre$i$i$i14>>2] = $160;
   $171 = (($170) + 4|0);
   HEAP32[$171>>2] = $161;
   $172 = HEAP32[$$pre$i$i$i14>>2]|0;
   HEAP32[$172>>2] = $161;
   $$pre$i16 = HEAP32[$140>>2]|0;
   $174 = $$pre$i16;
  }
  $173 = ($174|0)==(0|0);
  if ($173) {
   label = 69;
   break;
  }
  __THREW__ = 0;
  invoke_vii(2639,($this|0),($174|0));
  $175 = __THREW__; __THREW__ = 0;
  $176 = $175&1;
  if ($176) {
   label = 68;
   break;
  }
 }
 if ((label|0) == 65) {
  HEAP32[$140>>2] = 0;
  label = 69;
 }
 else if ((label|0) == 68) {
  $177 = ___cxa_find_matching_catch()|0;
  $178 = tempRet0;
  $$0 = $177;$$01 = $178;
 }
 do {
  if ((label|0) == 69) {
   $179 = HEAP8[$55>>0]|0;
   $180 = ($179<<24>>24)==(0);
   if (!($180)) {
    HEAP32[$138>>2] = 0;
    HEAP32[$it2>>2] = 0;
    $224 = (__ZN16ReflectionProbes22GetCurrentFrameCounterEv($this)|0);
    $225 = HEAP32[$224>>2]|0;
    $226 = (($225) + 1)|0;
    HEAP32[$224>>2] = $226;
    STACKTOP = sp;return;
   }
   $181 = (($it3) + 4|0);
   $182 = (($it3) + 8|0);
   HEAP32[$182>>2] = $58;
   $183 = (($it3) + 12|0);
   HEAP32[$183>>2] = 0;
   $184 = HEAP32[$$pre$phi36Z2D>>2]|0;
   HEAP32[$it3>>2] = $184;
   $185 = HEAP32[$$pre$phi38Z2D>>2]|0;
   HEAP32[$$pre$phi38Z2D>>2] = $it3;
   HEAP32[$181>>2] = $185;
   HEAP32[$$pre$phi36Z2D>>2] = $$pre$phi34Z2D;
   $186 = ($184|0)==($$pre$phi34Z2D|0);
   if ($186) {
    HEAP32[$it3>>2] = $it3;
   }
   HEAP32[$$pre$phi38Z2D>>2] = $$pre$phi34Z2D;
   $187 = ($185|0)==($$pre$phi34Z2D|0);
   if ($187) {
    HEAP32[$181>>2] = $it3;
   }
   $188 = (($$pre$phi34Z2D) + 4|0);
   HEAP32[$188>>2] = $$pre$phi34Z2D;
   $189 = HEAP32[$$pre$phi38Z2D>>2]|0;
   HEAP32[$189>>2] = $$pre$phi34Z2D;
   $190 = HEAP32[$it3>>2]|0;
   $191 = (($190) + 4|0);
   HEAP32[$191>>2] = $it3;
   $192 = HEAP32[$181>>2]|0;
   HEAP32[$192>>2] = $it3;
   while(1) {
    $193 = HEAP32[$181>>2]|0;
    $194 = ($193|0)==($it3|0);
    if ($194) {
     label = 82;
     break;
    }
    $195 = (($193) + -32|0);
    HEAP32[$183>>2] = $195;
    $196 = HEAP32[$193>>2]|0;
    $197 = ($196|0)==(0|0);
    if ($197) {
     $205 = $195;
    } else {
     $198 = (($193) + 4|0);
     $199 = HEAP32[$198>>2]|0;
     $200 = (($196) + 4|0);
     HEAP32[$200>>2] = $199;
     $201 = HEAP32[$193>>2]|0;
     $202 = HEAP32[$198>>2]|0;
     HEAP32[$202>>2] = $201;
     HEAP32[$193>>2] = 0;
     HEAP32[$198>>2] = 0;
     $$pre3$i3 = HEAP32[$183>>2]|0;
     $205 = $$pre3$i3;
    }
    $203 = HEAP32[$182>>2]|0;
    $204 = (($205) + 32|0);
    $206 = ($204|0)==($203|0);
    if ($206) {
     $217 = $205;
    } else {
     $207 = HEAP32[$204>>2]|0;
     $208 = ($207|0)==(0|0);
     $$pre$i$i$i5 = (($205) + 36|0);
     if (!($208)) {
      $209 = HEAP32[$$pre$i$i$i5>>2]|0;
      $210 = (($207) + 4|0);
      HEAP32[$210>>2] = $209;
      $211 = HEAP32[$204>>2]|0;
      $212 = HEAP32[$$pre$i$i$i5>>2]|0;
      HEAP32[$212>>2] = $211;
      HEAP32[$204>>2] = 0;
      HEAP32[$$pre$i$i$i5>>2] = 0;
     }
     $213 = HEAP32[$203>>2]|0;
     HEAP32[$204>>2] = $213;
     HEAP32[$$pre$i$i$i5>>2] = $203;
     $214 = (($213) + 4|0);
     HEAP32[$214>>2] = $204;
     $215 = HEAP32[$$pre$i$i$i5>>2]|0;
     HEAP32[$215>>2] = $204;
     $$pre$i7 = HEAP32[$183>>2]|0;
     $217 = $$pre$i7;
    }
    $216 = ($217|0)==(0|0);
    if ($216) {
     break;
    }
    $218 = (($217) + 136|0);
    $219 = HEAP32[$218>>2]|0;
    __THREW__ = 0;
    invoke_viii(1687,($this|0),($217|0),($219|0));
    $220 = __THREW__; __THREW__ = 0;
    $221 = $220&1;
    if ($221) {
     label = 85;
     break;
    }
   }
   if ((label|0) == 82) {
    HEAP32[$183>>2] = 0;
   }
   else if ((label|0) == 85) {
    $222 = ___cxa_find_matching_catch()|0;
    $223 = tempRet0;
    HEAP32[$181>>2] = 0;
    HEAP32[$it3>>2] = 0;
    $$0 = $222;$$01 = $223;
    break;
   }
   HEAP32[$181>>2] = 0;
   HEAP32[$it3>>2] = 0;
   HEAP32[$138>>2] = 0;
   HEAP32[$it2>>2] = 0;
   $224 = (__ZN16ReflectionProbes22GetCurrentFrameCounterEv($this)|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = (($225) + 1)|0;
   HEAP32[$224>>2] = $226;
   STACKTOP = sp;return;
  }
 } while(0);
 HEAP32[$138>>2] = 0;
 HEAP32[$it2>>2] = 0;
 $$1 = $$0;$$12 = $$01;
 ___resumeException($$1|0);
 // unreachable;
}
function __ZN16ReflectionProbes27InvalidateAllRenderTexturesEv($this) {
 $this = $this|0;
 var $$pre$i = 0, $$pre$i$i$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $it = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $it = sp;
 $0 = (($this) + 28|0);
 $1 = (($it) + 4|0);
 $2 = (($it) + 8|0);
 HEAP32[$2>>2] = $0;
 $3 = (($it) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$0>>2]|0;
 HEAP32[$it>>2] = $4;
 $5 = (($this) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$5>>2] = $it;
 HEAP32[$1>>2] = $6;
 HEAP32[$0>>2] = $0;
 $7 = ($4|0)==($0|0);
 if ($7) {
  HEAP32[$it>>2] = $it;
 }
 HEAP32[$5>>2] = $0;
 $8 = ($6|0)==($0|0);
 if ($8) {
  HEAP32[$1>>2] = $it;
 }
 $9 = (($this) + 32|0);
 HEAP32[$9>>2] = $0;
 HEAP32[$0>>2] = $0;
 $10 = HEAP32[$it>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $it;
 $12 = HEAP32[$1>>2]|0;
 HEAP32[$12>>2] = $it;
 while(1) {
  $13 = HEAP32[$1>>2]|0;
  $14 = ($13|0)==($it|0);
  if ($14) {
   break;
  }
  $15 = (($13) + -32|0);
  HEAP32[$3>>2] = $15;
  $16 = HEAP32[$13>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $25 = $15;
  } else {
   $18 = (($13) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($16) + 4|0);
   HEAP32[$20>>2] = $19;
   $21 = HEAP32[$13>>2]|0;
   $22 = HEAP32[$18>>2]|0;
   HEAP32[$22>>2] = $21;
   HEAP32[$13>>2] = 0;
   HEAP32[$18>>2] = 0;
   $$pre3$i = HEAP32[$3>>2]|0;
   $25 = $$pre3$i;
  }
  $23 = HEAP32[$2>>2]|0;
  $24 = (($25) + 32|0);
  $26 = ($24|0)==($23|0);
  if ($26) {
   $37 = $25;
  } else {
   $27 = HEAP32[$24>>2]|0;
   $28 = ($27|0)==(0|0);
   $$pre$i$i$i = (($25) + 36|0);
   if (!($28)) {
    $29 = HEAP32[$$pre$i$i$i>>2]|0;
    $30 = (($27) + 4|0);
    HEAP32[$30>>2] = $29;
    $31 = HEAP32[$24>>2]|0;
    $32 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$32>>2] = $31;
    HEAP32[$24>>2] = 0;
    HEAP32[$$pre$i$i$i>>2] = 0;
   }
   $33 = HEAP32[$23>>2]|0;
   HEAP32[$24>>2] = $33;
   HEAP32[$$pre$i$i$i>>2] = $23;
   $34 = (($33) + 4|0);
   HEAP32[$34>>2] = $24;
   $35 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$35>>2] = $24;
   $$pre$i = HEAP32[$3>>2]|0;
   $37 = $$pre$i;
  }
  $36 = ($37|0)==(0|0);
  if ($36) {
   label = 16;
   break;
  }
  __ZN15ReflectionProbe19ClearRenderTexturesEv($37);
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16ReflectionProbes6UpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16ReflectionProbes16UpdateSampleDataEv($this);
 __ZN16ReflectionProbes40UpdateRealtimeReflectionProbesTimeslicedEv($this);
 STACKTOP = sp;return;
}
function __ZNK16ReflectionProbes16GetDefaultSampleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 dest=$agg$result+0|0; src=$0+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN16ReflectionProbes9GetSampleERK4AABBP9Transform20ReflectionProbeUsageR16ReflectionSample($this,$worldAABB,$anchor,$usage,$reflSample) {
 $this = $this|0;
 $worldAABB = $worldAABB|0;
 $anchor = $anchor|0;
 $usage = $usage|0;
 $reflSample = $reflSample|0;
 var $$0$i1 = Math_fround(0), $$0$i1$maxInfluence$sroa$1$011 = Math_fround(0), $$017 = 0, $$018 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0);
 var $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0);
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $i2$05 = 0, $intersect$i = 0, $maxInfluence$sroa$0$016 = Math_fround(0), $maxInfluence$sroa$0$110 = Math_fround(0), $maxInfluence$sroa$0$2 = Math_fround(0), $maxInfluence$sroa$0$3 = Math_fround(0), $maxInfluence$sroa$1$011 = Math_fround(0), $maxInfluence$sroa$1$1 = Math_fround(0), $maxInfluence$sroa$1$2 = Math_fround(0);
 var $or$cond = 0, $q$09 = 0, $q$09$ = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 144|0;
 $intersect$i = sp;
 $1 = sp + 24|0;
 $2 = sp + 48|0;
 $3 = sp + 72|0;
 $4 = sp + 96|0;
 $5 = sp + 120|0;
 $6 = (($this) + 48|0);
 $7 = (($this) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$worldAABB>>2]);
 $10 = (($worldAABB) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($worldAABB) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($worldAABB) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($worldAABB) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($worldAABB) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ($anchor|0)==(0|0);
 do {
  if ($20) {
   $$018 = $usage;$49 = $9;$51 = $11;$53 = $13;$maxInfluence$sroa$0$016 = Math_fround(0.0);
   label = 7;
  } else {
   $21 = (($anchor) + 24|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($22,215)|0);
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = (($23) + 40|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0);
    if ($27) {
     $28 = (($23) + 136|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($29|0)==(-1);
     if (!($30)) {
      $36 = HEAP32[$28>>2]|0;
      $37 = ($36|0)==($8|0);
      if ($37) {
       $$018 = 3;$49 = $9;$51 = $11;$53 = $13;$maxInfluence$sroa$0$016 = Math_fround(1.0);
       label = 7;
       break;
      } else {
       $$017 = 3;$115 = $36;$129 = $8;$154 = $9;$156 = $11;$158 = $13;$maxInfluence$sroa$0$3 = Math_fround(1.0);$maxInfluence$sroa$1$2 = Math_fround(0.0);
       label = 14;
       break;
      }
     }
    }
   }
   __ZNK9Transform11GetPositionEv($0,$anchor);
   $31 = Math_fround(HEAPF32[$0>>2]);
   $32 = (($0) + 4|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = (($0) + 8|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $$018 = $usage;$49 = $31;$51 = $33;$53 = $35;$maxInfluence$sroa$0$016 = Math_fround(0.0);
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $38 = HEAP32[$7>>2]|0;
  $39 = ($38|0)==(0);
  if (!($39)) {
   $40 = (($intersect$i) + 12|0);
   $41 = (($intersect$i) + 16|0);
   $42 = (($intersect$i) + 20|0);
   $43 = (($1) + 4|0);
   $44 = (($1) + 8|0);
   $45 = (($1) + 12|0);
   $46 = (($1) + 16|0);
   $47 = (($1) + 20|0);
   $48 = Math_fround($49 - $15);
   $50 = Math_fround($51 - $17);
   $52 = Math_fround($53 - $19);
   $54 = Math_fround($15 + $49);
   $55 = Math_fround($17 + $51);
   $56 = Math_fround($19 + $53);
   $57 = (($2) + 4|0);
   $58 = (($2) + 8|0);
   $59 = (($2) + 12|0);
   $60 = (($2) + 16|0);
   $61 = (($2) + 20|0);
   $62 = (($intersect$i) + 4|0);
   $63 = (($intersect$i) + 8|0);
   $64 = ($$018|0)!=(3);
   $110 = $8;$223 = $8;$maxInfluence$sroa$0$110 = $maxInfluence$sroa$0$016;$maxInfluence$sroa$1$011 = Math_fround(0.0);$q$09 = 0;
   while(1) {
    $65 = HEAP32[$6>>2]|0;
    ;HEAP32[$intersect$i+0>>2]=0|0;HEAP32[$intersect$i+4>>2]=0|0;HEAP32[$intersect$i+8>>2]=0|0;HEAP32[$intersect$i+12>>2]=0|0;HEAP32[$intersect$i+16>>2]=0|0;
    ;HEAP32[$intersect$i+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$intersect$i+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$intersect$i+8>>2]=HEAP32[616664+8>>2]|0;
    $66 = Math_fround(HEAPF32[616664>>2]);
    $67 = Math_fround(-$66);
    $68 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
    $69 = Math_fround(-$68);
    $70 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
    $71 = Math_fround(-$70);
    HEAPF32[$40>>2] = $67;
    HEAPF32[$41>>2] = $69;
    HEAPF32[$42>>2] = $71;
    ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;
    HEAPF32[$1>>2] = $48;
    HEAPF32[$43>>2] = $50;
    HEAPF32[$44>>2] = $52;
    HEAPF32[$45>>2] = $54;
    HEAPF32[$46>>2] = $55;
    HEAPF32[$47>>2] = $56;
    $72 = (($65) + (($q$09*24)|0)|0);
    ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = ((($65) + (($q$09*24)|0)|0) + 12|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = Math_fround($73 - $75);
    $77 = ((($65) + (($q$09*24)|0)|0) + 4|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = ((($65) + (($q$09*24)|0)|0) + 16|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = Math_fround($78 - $80);
    $82 = ((($65) + (($q$09*24)|0)|0) + 8|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = ((($65) + (($q$09*24)|0)|0) + 20|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = Math_fround($83 - $85);
    HEAPF32[$2>>2] = $76;
    HEAPF32[$57>>2] = $81;
    HEAPF32[$58>>2] = $86;
    $87 = Math_fround(HEAPF32[$72>>2]);
    $88 = Math_fround(HEAPF32[$74>>2]);
    $89 = Math_fround($87 + $88);
    $90 = Math_fround(HEAPF32[$77>>2]);
    $91 = Math_fround(HEAPF32[$79>>2]);
    $92 = Math_fround($90 + $91);
    $93 = Math_fround(HEAPF32[$82>>2]);
    $94 = Math_fround(HEAPF32[$84>>2]);
    $95 = Math_fround($93 + $94);
    HEAPF32[$59>>2] = $89;
    HEAPF32[$60>>2] = $92;
    HEAPF32[$61>>2] = $95;
    $96 = (__Z17IntersectAABBAABBRK10MinMaxAABBS1_PS_($1,$2,$intersect$i)|0);
    if ($96) {
     $97 = Math_fround(HEAPF32[$40>>2]);
     $98 = Math_fround(HEAPF32[$intersect$i>>2]);
     $99 = Math_fround($97 - $98);
     $100 = Math_fround(HEAPF32[$41>>2]);
     $101 = Math_fround(HEAPF32[$62>>2]);
     $102 = Math_fround($100 - $101);
     $103 = Math_fround(HEAPF32[$42>>2]);
     $104 = Math_fround(HEAPF32[$63>>2]);
     $105 = Math_fround($103 - $104);
     $106 = Math_fround($99 * $102);
     $107 = Math_fround($106 * $105);
     $$0$i1 = $107;
    } else {
     $$0$i1 = Math_fround(0.0);
    }
    $108 = $$0$i1 > $maxInfluence$sroa$0$110;
    if ($108) {
     $224 = $223;$225 = $q$09;$maxInfluence$sroa$0$2 = $$0$i1;$maxInfluence$sroa$1$1 = $maxInfluence$sroa$0$110;
    } else {
     $109 = $$0$i1 > $maxInfluence$sroa$1$011;
     $or$cond = $64 & $109;
     $q$09$ = $or$cond ? $q$09 : $110;
     $$0$i1$maxInfluence$sroa$1$011 = $or$cond ? $$0$i1 : $maxInfluence$sroa$1$011;
     $224 = $q$09$;$225 = $223;$maxInfluence$sroa$0$2 = $maxInfluence$sroa$0$110;$maxInfluence$sroa$1$1 = $$0$i1$maxInfluence$sroa$1$011;
    }
    $111 = (($q$09) + 1)|0;
    $112 = HEAP32[$7>>2]|0;
    $113 = ($111>>>0)<($112>>>0);
    if ($113) {
     $110 = $224;$223 = $225;$maxInfluence$sroa$0$110 = $maxInfluence$sroa$0$2;$maxInfluence$sroa$1$011 = $maxInfluence$sroa$1$1;$q$09 = $111;
    } else {
     $$017 = $$018;$115 = $225;$129 = $224;$154 = $49;$156 = $51;$158 = $53;$maxInfluence$sroa$0$3 = $maxInfluence$sroa$0$2;$maxInfluence$sroa$1$2 = $maxInfluence$sroa$1$1;
     label = 14;
     break;
    }
   }
  }
 }
 if ((label|0) == 14) {
  $114 = ($115|0)==($8|0);
  if (!($114)) {
   $116 = (($this) + 64|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = (($reflSample) + 44|0);
   $119 = ((($117) + (($115*36)|0)|0) + 20|0);
   ;HEAP32[$118+0>>2]=HEAP32[$119+0>>2]|0;HEAP32[$118+4>>2]=HEAP32[$119+4>>2]|0;HEAP32[$118+8>>2]=HEAP32[$119+8>>2]|0;HEAP32[$118+12>>2]=HEAP32[$119+12>>2]|0;
   $120 = HEAP32[$6>>2]|0;
   $121 = (($120) + (($115*24)|0)|0);
   ;HEAP32[$reflSample+0>>2]=HEAP32[$121+0>>2]|0;HEAP32[$reflSample+4>>2]=HEAP32[$121+4>>2]|0;HEAP32[$reflSample+8>>2]=HEAP32[$121+8>>2]|0;HEAP32[$reflSample+12>>2]=HEAP32[$121+12>>2]|0;HEAP32[$reflSample+16>>2]=HEAP32[$121+16>>2]|0;HEAP32[$reflSample+20>>2]=HEAP32[$121+20>>2]|0;
   $122 = (($117) + (($115*36)|0)|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($reflSample) + 24|0);
   HEAP32[$124>>2] = $123;
   $125 = (($reflSample) + 28|0);
   $126 = ((($117) + (($115*36)|0)|0) + 4|0);
   ;HEAP32[$125+0>>2]=HEAP32[$126+0>>2]|0;HEAP32[$125+4>>2]=HEAP32[$126+4>>2]|0;HEAP32[$125+8>>2]=HEAP32[$126+8>>2]|0;HEAP32[$125+12>>2]=HEAP32[$126+12>>2]|0;
   $127 = (($reflSample) + 60|0);
   $128 = ($129|0)==($8|0);
   if ($128) {
    $221 = (($this) + 172|0);
    dest=$127+0|0; src=$221+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   } else {
    $211 = HEAP32[$116>>2]|0;
    $212 = (($reflSample) + 104|0);
    $213 = ((($211) + (($129*36)|0)|0) + 20|0);
    ;HEAP32[$212+0>>2]=HEAP32[$213+0>>2]|0;HEAP32[$212+4>>2]=HEAP32[$213+4>>2]|0;HEAP32[$212+8>>2]=HEAP32[$213+8>>2]|0;HEAP32[$212+12>>2]=HEAP32[$213+12>>2]|0;
    $214 = HEAP32[$6>>2]|0;
    $215 = (($214) + (($129*24)|0)|0);
    ;HEAP32[$127+0>>2]=HEAP32[$215+0>>2]|0;HEAP32[$127+4>>2]=HEAP32[$215+4>>2]|0;HEAP32[$127+8>>2]=HEAP32[$215+8>>2]|0;HEAP32[$127+12>>2]=HEAP32[$215+12>>2]|0;HEAP32[$127+16>>2]=HEAP32[$215+16>>2]|0;HEAP32[$127+20>>2]=HEAP32[$215+20>>2]|0;
    $216 = (($211) + (($129*36)|0)|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = (($reflSample) + 84|0);
    HEAP32[$218>>2] = $217;
    $219 = (($reflSample) + 88|0);
    $220 = ((($211) + (($129*36)|0)|0) + 4|0);
    ;HEAP32[$219+0>>2]=HEAP32[$220+0>>2]|0;HEAP32[$219+4>>2]=HEAP32[$220+4>>2]|0;HEAP32[$219+8>>2]=HEAP32[$220+8>>2]|0;HEAP32[$219+12>>2]=HEAP32[$220+12>>2]|0;
   }
   $222 = ($$017|0)==(3);
   do {
    if ($222) {
     $142 = Math_fround(1.0);
    } else {
     $130 = $maxInfluence$sroa$1$2 > Math_fround(0.0);
     if ($130) {
      $131 = Math_fround($maxInfluence$sroa$0$3 + $maxInfluence$sroa$1$2);
      $132 = Math_fround($maxInfluence$sroa$0$3 / $131);
      $142 = $132;
      break;
     }
     $133 = Math_fround($15 * Math_fround(2.0));
     $134 = Math_fround($17 * Math_fround(2.0));
     $135 = Math_fround($19 * Math_fround(2.0));
     $136 = Math_fround($133 * $134);
     $137 = Math_fround($136 * $135);
     $138 = $137 > Math_fround(0.0);
     if ($138) {
      $139 = ($$017|0)==(2);
      if ($139) {
       $140 = Math_fround($maxInfluence$sroa$0$3 / $137);
       $142 = $140;
      } else {
       $142 = Math_fround(1.0);
      }
     } else {
      $142 = Math_fround(0.0);
     }
    }
   } while(0);
   $141 = (($reflSample) + 120|0);
   HEAPF32[$141>>2] = $142;
   $143 = (($4) + 4|0);
   $144 = (($4) + 8|0);
   $145 = (($4) + 12|0);
   $146 = (($4) + 16|0);
   $147 = (($4) + 20|0);
   $148 = (($5) + 4|0);
   $149 = (($5) + 8|0);
   $150 = (($5) + 12|0);
   $151 = (($5) + 16|0);
   $152 = (($5) + 20|0);
   $153 = Math_fround($154 - $15);
   $155 = Math_fround($156 - $17);
   $157 = Math_fround($158 - $19);
   $159 = Math_fround($15 + $154);
   $160 = Math_fround($17 + $156);
   $161 = Math_fround($19 + $158);
   $162 = (($3) + 12|0);
   $163 = (($3) + 16|0);
   $164 = (($3) + 4|0);
   $165 = (($3) + 20|0);
   $166 = (($3) + 8|0);
   $i2$05 = 0;
   while(1) {
    $167 = ((($reflSample) + (($i2$05*60)|0)|0) + 56|0);
    $168 = Math_fround(HEAPF32[$167>>2]);
    $169 = $168 > Math_fround(0.0);
    if ($169) {
     $170 = (($reflSample) + (($i2$05*60)|0)|0);
     ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;
     $171 = Math_fround(HEAPF32[$170>>2]);
     $172 = ((($reflSample) + (($i2$05*60)|0)|0) + 12|0);
     $173 = Math_fround(HEAPF32[$172>>2]);
     $174 = Math_fround($171 - $173);
     $175 = ((($reflSample) + (($i2$05*60)|0)|0) + 4|0);
     $176 = Math_fround(HEAPF32[$175>>2]);
     $177 = ((($reflSample) + (($i2$05*60)|0)|0) + 16|0);
     $178 = Math_fround(HEAPF32[$177>>2]);
     $179 = Math_fround($176 - $178);
     $180 = ((($reflSample) + (($i2$05*60)|0)|0) + 8|0);
     $181 = Math_fround(HEAPF32[$180>>2]);
     $182 = ((($reflSample) + (($i2$05*60)|0)|0) + 20|0);
     $183 = Math_fround(HEAPF32[$182>>2]);
     $184 = Math_fround($181 - $183);
     HEAPF32[$4>>2] = $174;
     HEAPF32[$143>>2] = $179;
     HEAPF32[$144>>2] = $184;
     $185 = Math_fround($171 + $173);
     $186 = Math_fround($176 + $178);
     $187 = Math_fround($181 + $183);
     HEAPF32[$145>>2] = $185;
     HEAPF32[$146>>2] = $186;
     HEAPF32[$147>>2] = $187;
     ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;
     HEAPF32[$5>>2] = $153;
     HEAPF32[$148>>2] = $155;
     HEAPF32[$149>>2] = $157;
     HEAPF32[$150>>2] = $159;
     HEAPF32[$151>>2] = $160;
     HEAPF32[$152>>2] = $161;
     __Z7AddAABBRK10MinMaxAABBS1_($3,$4,$5);
     $188 = Math_fround(HEAPF32[$162>>2]);
     $189 = Math_fround(HEAPF32[$3>>2]);
     $190 = Math_fround($188 + $189);
     $191 = Math_fround(HEAPF32[$163>>2]);
     $192 = Math_fround(HEAPF32[$164>>2]);
     $193 = Math_fround($191 + $192);
     $194 = Math_fround(HEAPF32[$165>>2]);
     $195 = Math_fround(HEAPF32[$166>>2]);
     $196 = Math_fround($194 + $195);
     $197 = Math_fround($190 * Math_fround(0.5));
     $198 = Math_fround($193 * Math_fround(0.5));
     $199 = Math_fround($196 * Math_fround(0.5));
     HEAPF32[$170>>2] = $197;
     HEAPF32[$175>>2] = $198;
     HEAPF32[$180>>2] = $199;
     $200 = Math_fround($188 - $189);
     $201 = Math_fround($191 - $192);
     $202 = Math_fround($194 - $195);
     $203 = Math_fround($200 * Math_fround(0.5));
     $204 = Math_fround($201 * Math_fround(0.5));
     $205 = Math_fround($202 * Math_fround(0.5));
     HEAPF32[$172>>2] = $203;
     HEAPF32[$177>>2] = $204;
     HEAPF32[$182>>2] = $205;
    }
    $206 = (($i2$05) + 1)|0;
    $exitcond = ($206|0)==(2);
    if ($exitcond) {
     break;
    } else {
     $i2$05 = $206;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $207 = (($this) + 112|0);
 dest=$reflSample+0|0; src=$207+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $208 = (($reflSample) + 60|0);
 $209 = (($this) + 172|0);
 dest=$208+0|0; src=$209+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $210 = (($reflSample) + 120|0);
 HEAPF32[$210>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN16ReflectionProbes15InitializeClassEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Znwj(236)|0);
 HEAP32[$1>>2] = 0;
 $2 = (($1) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($1) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($1) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($1) + 16|0);
 HEAP32[$6>>2] = 61;
 $7 = (($1) + 28|0);
 $8 = (($1) + 32|0);
 HEAP32[$7>>2] = $7;
 HEAP32[$8>>2] = $7;
 $9 = (($1) + 40|0);
 HEAP32[$9>>2] = -1;
 $10 = (($1) + 44|0);
 HEAP8[$10>>0] = 0;
 $11 = (($1) + 48|0);
 HEAP32[$11>>2] = 0;
 $12 = (($1) + 56|0);
 HEAP32[$12>>2] = 0;
 $13 = (($1) + 60|0);
 HEAP32[$13>>2] = 0;
 $14 = (($1) + 52|0);
 HEAP32[$14>>2] = 61;
 $15 = (($1) + 64|0);
 HEAP32[$15>>2] = 0;
 $16 = (($1) + 72|0);
 HEAP32[$16>>2] = 0;
 $17 = (($1) + 76|0);
 HEAP32[$17>>2] = 0;
 $18 = (($1) + 68|0);
 HEAP32[$18>>2] = 61;
 $19 = (($1) + 80|0);
 HEAP32[$19>>2] = 0;
 $20 = (($1) + 88|0);
 HEAP32[$20>>2] = 0;
 $21 = (($1) + 92|0);
 HEAP32[$21>>2] = 0;
 $22 = (($1) + 84|0);
 HEAP32[$22>>2] = 61;
 $23 = (($1) + 96|0);
 HEAP32[$23>>2] = 0;
 $24 = (($1) + 104|0);
 HEAP32[$24>>2] = 0;
 $25 = (($1) + 108|0);
 HEAP32[$25>>2] = 0;
 $26 = (($1) + 100|0);
 HEAP32[$26>>2] = 61;
 $27 = (($1) + 112|0);
 dest=$27+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $28 = (($1) + 4|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 __THREW__ = 0;
 $29 = (invoke_i(66)|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if (!($31)) {
  $44 = (($1) + 36|0);
  HEAP32[$44>>2] = $29;
  HEAP32[575112>>2] = $1;
  STACKTOP = sp;return;
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3424,($11|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 }
 HEAP32[$8>>2] = 0;
 HEAP32[$7>>2] = 0;
 $36 = HEAP32[$5>>2]|0;
 $37 = ($36|0)>(-1);
 if (!($37)) {
  __ZdlPv($1);
  ___resumeException($32|0);
  // unreachable;
 }
 $38 = HEAP32[$3>>2]|0;
 $39 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $39;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($38|0),($$byval_copy|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  __ZdlPv($1);
  ___resumeException($32|0);
  // unreachable;
 }
}
function __ZN16ReflectionProbes12CleanupClassEv() {
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, $node$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[575112>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[575112>>2] = 0;
  STACKTOP = sp;return;
 }
 $4 = (($2) + 28|0);
 $5 = (($2) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 if (!($7)) {
  $node$01$i$i = $6;
  while(1) {
   $8 = (($node$01$i$i) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$node$01$i$i>>2] = 0;
   HEAP32[$8>>2] = 0;
   $10 = ($9|0)==($4|0);
   if ($10) {
    break;
   } else {
    $node$01$i$i = $9;
   }
  }
 }
 HEAP32[$5>>2] = $4;
 HEAP32[$4>>2] = $4;
 $11 = (($2) + 48|0);
 __THREW__ = 0;
 invoke_vi(3424,($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  HEAP32[$5>>2] = 0;
  HEAP32[$4>>2] = 0;
  $25 = (($2) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if (!($27)) {
   $eh$lpad$body$index3Z2D = $24;$eh$lpad$body$indexZ2D = $23;
   __ZdlPv($2);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $28 = (($2) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($2) + 16|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$1>>2] = $31;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($29|0),($$byval_copy8|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $34 = ___cxa_find_matching_catch(0|0)|0;
   $35 = tempRet0;
   ___clang_call_terminate($34);
   // unreachable;
  } else {
   $eh$lpad$body$index3Z2D = $24;$eh$lpad$body$indexZ2D = $23;
   __ZdlPv($2);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 HEAP32[$5>>2] = 0;
 HEAP32[$4>>2] = 0;
 $14 = (($2) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(-1);
 if ($16) {
  $17 = (($2) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($2) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$0>>2] = $20;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($18|0),($$byval_copy8|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $36 = ___cxa_find_matching_catch()|0;
   $37 = tempRet0;
   $eh$lpad$body$index3Z2D = $37;$eh$lpad$body$indexZ2D = $36;
   __ZdlPv($2);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __ZdlPv($2);
 HEAP32[575112>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16ReflectionProbes17RuntimeLookupDataD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 do {
  if ($8) {
   $9 = (($this) + 48|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 52|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$5>>2] = $12;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($10|0),($$byval_copy6|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$9>>2] = 0;
    label = 4;
    break;
   }
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   $41 = (($this) + 44|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)>(-1);
   if ($43) {
    $44 = (($this) + 32|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($this) + 36|0);
    $47 = HEAP32[$46>>2]|0;
    HEAP32[$2>>2] = $47;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($45|0),($$byval_copy6|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $71 = ___cxa_find_matching_catch(0|0)|0;
     $72 = tempRet0;
     ___clang_call_terminate($71);
     // unreachable;
    } else {
     HEAP32[$44>>2] = 0;
     $$0 = $40;$$01 = $39;
     label = 18;
     break;
    }
   } else {
    $$0 = $40;$$01 = $39;
    label = 18;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $15 = (($this) + 44|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(-1);
   do {
    if ($17) {
     $18 = (($this) + 32|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($this) + 36|0);
     $21 = HEAP32[$20>>2]|0;
     HEAP32[$4>>2] = $21;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($19|0),($$byval_copy6|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $50 = ___cxa_find_matching_catch()|0;
      $51 = tempRet0;
      $$0 = $51;$$01 = $50;
      label = 18;
      break L10;
     } else {
      HEAP32[$18>>2] = 0;
      break;
     }
    }
   } while(0);
   $24 = (($this) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(-1);
   do {
    if ($26) {
     $27 = (($this) + 16|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($this) + 20|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$3>>2] = $30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($28|0),($$byval_copy6|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $52 = ___cxa_find_matching_catch()|0;
      $53 = tempRet0;
      $$1 = $53;$$12 = $52;
      break L10;
     } else {
      HEAP32[$27>>2] = 0;
      break;
     }
    }
   } while(0);
   $33 = (($this) + 12|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)>(-1);
   if (!($35)) {
    STACKTOP = sp;return;
   }
   $36 = HEAP32[$this>>2]|0;
   $37 = (($this) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   HEAP32[$0>>2] = $38;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($36,$$byval_copy6);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 18) {
   $54 = (($this) + 28|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)>(-1);
   if ($56) {
    $57 = (($this) + 16|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($this) + 20|0);
    $60 = HEAP32[$59>>2]|0;
    HEAP32[$1>>2] = $60;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($58|0),($$byval_copy6|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $71 = ___cxa_find_matching_catch(0|0)|0;
     $72 = tempRet0;
     ___clang_call_terminate($71);
     // unreachable;
    } else {
     HEAP32[$57>>2] = 0;
     $$1 = $$0;$$12 = $$01;
     break;
    }
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 $63 = (($this) + 12|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)>(-1);
 if (!($65)) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($this) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$0>>2] = $68;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($66|0),($$byval_copy6|0));
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $71 = ___cxa_find_matching_catch(0|0)|0;
  $72 = tempRet0;
  ___clang_call_terminate($71);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$12|0);
 // unreachable;
}
function __Z30IsUsingLightProbesForRenderingPK12BaseRendererbb($renderer,$hasTetrahedra,$hasBakedLightProbes) {
 $renderer = $renderer|0;
 $hasTetrahedra = $hasTetrahedra|0;
 $hasBakedLightProbes = $hasBakedLightProbes|0;
 var $$not = 0, $$not1 = 0, $$off$i$i = 0, $$off$i1$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $brmerge = 0, $brmerge2 = 0, $hasBakedLightProbes$not = 0, $hasTetrahedra$not = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($renderer) + 176|0);
 $1 = HEAP32[$0>>2]|0;
 $$not = ($1|0)!=(1);
 $hasTetrahedra$not = $hasTetrahedra ^ 1;
 $brmerge = $$not | $hasTetrahedra$not;
 if ($brmerge) {
  $$not1 = ($1|0)!=(2);
  $hasBakedLightProbes$not = $hasBakedLightProbes ^ 1;
  $brmerge2 = $$not1 | $hasBakedLightProbes$not;
  if ($brmerge2) {
   $8 = 0;
   STACKTOP = sp;return ($8|0);
  }
 }
 $2 = (($renderer) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3&65535;
 $$off$i$i = (($4) + -254)<<16>>16;
 $5 = ($$off$i$i&65535)>(1);
 if ($5) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $6 = $3 >>> 16;
 $7 = $6&65535;
 $$off$i1$i = (($7) + -254)<<16>>16;
 $phitmp = ($$off$i1$i&65535)<(2);
 $8 = $phitmp;
 STACKTOP = sp;return ($8|0);
}
function __Z25GetLightProbeCoefficientsP12BaseRendererRK4AABBR19SphericalHarmonics3($renderer,$worldAABB,$coeffs) {
 $renderer = $renderer|0;
 $worldAABB = $worldAABB|0;
 $coeffs = $coeffs|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $position = 0, $temp$0$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp;
 $position = sp + 4|0;
 $1 = (($renderer) + 176|0);
 $2 = HEAP32[$1>>2]|0;
 if ((($2|0) == 1)) {
  $3 = (($renderer) + 184|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  do {
   if ($5) {
    label = 13;
   } else {
    HEAP32[$0>>2] = $4;
    $6 = HEAP32[560624>>2]|0;
    $7 = ($6|0)==(0|0);
    if ($7) {
     label = 11;
    } else {
     $8 = (($6) + 36|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($6) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($9|0)==($11|0);
     do {
      if ($12) {
       $13 = (($6) + 28|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = (($6) + 32|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = (($14) + ($16<<3)|0);
       $33 = $17;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$6,$0);
       $18 = HEAP32[$pos$i$i$i$i>>2]|0;
       $19 = ($18|0)==(-1);
       $20 = (($6) + 28|0);
       $21 = HEAP32[$20>>2]|0;
       if ($19) {
        $22 = (($6) + 32|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = (($21) + ($23<<3)|0);
        $33 = $24;
        break;
       } else {
        $25 = (($21) + ($18<<3)|0);
        $33 = $25;
        break;
       }
      }
     } while(0);
     $26 = HEAP32[560624>>2]|0;
     $27 = (($26) + 28|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($26) + 32|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + ($30<<3)|0);
     $32 = ($33|0)==($31|0);
     if ($32) {
      label = 11;
     } else {
      $34 = (($33) + 4|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==(0|0);
      if ($36) {
       label = 11;
      } else {
       $temp$0$i2 = $35;
      }
     }
    }
    if ((label|0) == 11) {
     $37 = HEAP32[$3>>2]|0;
     $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
     $39 = ($38|0)==(0|0);
     if ($39) {
      label = 13;
      break;
     } else {
      $temp$0$i2 = $38;
     }
    }
    __ZNK9Transform11GetPositionEv($position,$temp$0$i2);
   }
  } while(0);
  if ((label|0) == 13) {
   ;HEAP32[$position+0>>2]=HEAP32[$worldAABB+0>>2]|0;HEAP32[$position+4>>2]=HEAP32[$worldAABB+4>>2]|0;HEAP32[$position+8>>2]=HEAP32[$worldAABB+8>>2]|0;
  }
  $40 = (__Z19GetLightmapSettingsv()|0);
  $41 = (($renderer) + 180|0);
  __ZNK16LightmapSettings25GetInterpolatedLightProbeERK8Vector3fRiPf($40,$position,$41,$coeffs);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($2|0) == 2)) {
  $42 = (__Z19GetLightmapSettingsv()|0);
  $43 = (($renderer) + 180|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (__ZNK16LightmapSettings28GetNonInterpolatedLightProbeEiPf($42,$44,$coeffs)|0);
  $$0 = $45;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z34GetAmbientAndLightProbeSHConstantsRK11VisibleNodeRK19SphericalHarmonics3bRS2_($node,$ambientProbe,$areLightProbesBaked,$outProbe) {
 $node = $node|0;
 $ambientProbe = $ambientProbe|0;
 $areLightProbesBaked = $areLightProbesBaked|0;
 $outProbe = $outProbe|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 if ($areLightProbesBaked) {
  $0 = (($node) + 116|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($node) + 64|0);
  $3 = (__Z25GetLightProbeCoefficientsP12BaseRendererRK4AABBR19SphericalHarmonics3($1,$2,$outProbe)|0);
  if ($3) {
   STACKTOP = sp;return;
  }
 }
 dest=$outProbe+0|0; src=$ambientProbe+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z19GetReflectionSamplePK12BaseRendererRK4AABBRK16ReflectionSamplePS5_($renderer,$worldAABB,$defaultReflection,$outReflection) {
 $renderer = $renderer|0;
 $worldAABB = $worldAABB|0;
 $defaultReflection = $defaultReflection|0;
 $outReflection = $outReflection|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($renderer) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  dest=$outReflection+0|0; src=$defaultReflection+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $4 = (__Z19GetReflectionProbesv()|0);
 $5 = (($renderer) + 184|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $6;
  $8 = HEAP32[560624>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   label = 11;
  } else {
   $10 = (($8) + 36|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($8) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11|0)==($13|0);
   do {
    if ($14) {
     $15 = (($8) + 28|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($8) + 32|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($16) + ($18<<3)|0);
     $35 = $19;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$8,$0);
     $20 = HEAP32[$pos$i$i$i$i>>2]|0;
     $21 = ($20|0)==(-1);
     $22 = (($8) + 28|0);
     $23 = HEAP32[$22>>2]|0;
     if ($21) {
      $24 = (($8) + 32|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($23) + ($25<<3)|0);
      $35 = $26;
      break;
     } else {
      $27 = (($23) + ($20<<3)|0);
      $35 = $27;
      break;
     }
    }
   } while(0);
   $28 = HEAP32[560624>>2]|0;
   $29 = (($28) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($28) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + ($32<<3)|0);
   $34 = ($35|0)==($33|0);
   if ($34) {
    label = 11;
   } else {
    $36 = (($35) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     label = 11;
    } else {
     $temp$0$i = $37;
    }
   }
  }
  if ((label|0) == 11) {
   $39 = HEAP32[$5>>2]|0;
   $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
   $temp$0$i = $40;
  }
  $$0$i = $temp$0$i;
 }
 $41 = HEAP32[$1>>2]|0;
 __ZN16ReflectionProbes9GetSampleERK4AABBP9Transform20ReflectionProbeUsageR16ReflectionSample($4,$worldAABB,$$0$i,$41,$outReflection);
 STACKTOP = sp;return;
}
function __ZN13RenderManagerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $__f$01$i$i$i$i12 = 0, $__f$01$i$i$i$i15 = 0;
 var $__f$01$i$i$i$i18 = 0, $__f$01$i$i$i$i9 = 0, $node$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = (($this) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if (!($3)) {
  $node$01$i = $2;
  while(1) {
   $4 = (($node$01$i) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   HEAP32[$node$01$i>>2] = 0;
   HEAP32[$4>>2] = 0;
   $6 = ($5|0)==($0|0);
   if ($6) {
    break;
   } else {
    $node$01$i = $5;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 HEAP32[$0>>2] = 0;
 $7 = (($this) + 88|0);
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiP10RenderableEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($7,$9);
 $10 = (($this) + 40|0);
 $11 = (($this) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = (($this) + 44|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$10>>2]|0;
  $17 = (($16) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$15>>2]|0;
  $20 = (($19) + 4|0);
  HEAP32[$20>>2] = $18;
  $21 = HEAP32[$15>>2]|0;
  $22 = HEAP32[$17>>2]|0;
  HEAP32[$22>>2] = $21;
  HEAP32[$11>>2] = 0;
  $23 = ($15|0)==($10|0);
  if (!($23)) {
   $__f$01$i$i$i$i9 = $15;
   while(1) {
    $24 = (($__f$01$i$i$i$i9) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    __ZdlPv($__f$01$i$i$i$i9);
    $26 = ($25|0)==($10|0);
    if ($26) {
     break;
    } else {
     $__f$01$i$i$i$i9 = $25;
    }
   }
  }
 }
 $27 = (($this) + 28|0);
 $28 = (($this) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = (($this) + 32|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$27>>2]|0;
  $34 = (($33) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$32>>2]|0;
  $37 = (($36) + 4|0);
  HEAP32[$37>>2] = $35;
  $38 = HEAP32[$32>>2]|0;
  $39 = HEAP32[$34>>2]|0;
  HEAP32[$39>>2] = $38;
  HEAP32[$28>>2] = 0;
  $40 = ($32|0)==($27|0);
  if (!($40)) {
   $__f$01$i$i$i$i12 = $32;
   while(1) {
    $41 = (($__f$01$i$i$i$i12) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    __ZdlPv($__f$01$i$i$i$i12);
    $43 = ($42|0)==($27|0);
    if ($43) {
     break;
    } else {
     $__f$01$i$i$i$i12 = $42;
    }
   }
  }
 }
 $44 = (($this) + 16|0);
 $45 = (($this) + 24|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0);
 if (!($47)) {
  $48 = (($this) + 20|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = HEAP32[$44>>2]|0;
  $51 = (($50) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = HEAP32[$49>>2]|0;
  $54 = (($53) + 4|0);
  HEAP32[$54>>2] = $52;
  $55 = HEAP32[$49>>2]|0;
  $56 = HEAP32[$51>>2]|0;
  HEAP32[$56>>2] = $55;
  HEAP32[$45>>2] = 0;
  $57 = ($49|0)==($44|0);
  if (!($57)) {
   $__f$01$i$i$i$i15 = $49;
   while(1) {
    $58 = (($__f$01$i$i$i$i15) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    __ZdlPv($__f$01$i$i$i$i15);
    $60 = ($59|0)==($44|0);
    if ($60) {
     break;
    } else {
     $__f$01$i$i$i$i15 = $59;
    }
   }
  }
 }
 $61 = (($this) + 4|0);
 $62 = (($this) + 12|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(0);
 if ($64) {
  STACKTOP = sp;return;
 }
 $65 = (($this) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$61>>2]|0;
 $68 = (($67) + 4|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = HEAP32[$66>>2]|0;
 $71 = (($70) + 4|0);
 HEAP32[$71>>2] = $69;
 $72 = HEAP32[$66>>2]|0;
 $73 = HEAP32[$68>>2]|0;
 HEAP32[$73>>2] = $72;
 HEAP32[$62>>2] = 0;
 $74 = ($66|0)==($61|0);
 if ($74) {
  STACKTOP = sp;return;
 } else {
  $__f$01$i$i$i$i18 = $66;
 }
 while(1) {
  $75 = (($__f$01$i$i$i$i18) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  __ZdlPv($__f$01$i$i$i$i18);
  $77 = ($76|0)==($61|0);
  if ($77) {
   break;
  } else {
   $__f$01$i$i$i$i18 = $76;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13RenderManager22RenderOffscreenCamerasEv($this) {
 $this = $this|0;
 var $$0$i1 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $savedViewport = 0, $storemerge = 0, $temp$0$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1104|0;
 $pos$i$i$i$i = sp + 24|0;
 $0 = sp;
 $savedViewport = sp + 8|0;
 $1 = (($this) + 52|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 72|0);
 ;HEAP32[$savedViewport+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$savedViewport+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$savedViewport+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$savedViewport+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($this) + 16|0);
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 if ($6) {
  $64 = (__Z19GetReflectionProbesv()|0);
  __ZN16ReflectionProbes6UpdateEv($64);
  ;HEAP32[$2+0>>2]=HEAP32[$savedViewport+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$savedViewport+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$savedViewport+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$savedViewport+12>>2]|0;
  HEAP8[$1>>0] = 0;
  __ZN13RenderManager23AddRemoveCamerasDelayedEv($this);
  STACKTOP = sp;return;
 }
 $8 = $5;
 while(1) {
  $7 = (($8) + 8|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = ($9|0)==(0);
  do {
   if ($10) {
    $$0$i1 = 0;$storemerge = 0;
   } else {
    HEAP32[$0>>2] = $9;
    $11 = HEAP32[560624>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 12;
    } else {
     $13 = (($11) + 36|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($11) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     do {
      if ($17) {
       $18 = (($11) + 28|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($11) + 32|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($19) + ($21<<3)|0);
       $38 = $22;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$11,$0);
       $23 = HEAP32[$pos$i$i$i$i>>2]|0;
       $24 = ($23|0)==(-1);
       $25 = (($11) + 28|0);
       $26 = HEAP32[$25>>2]|0;
       if ($24) {
        $27 = (($11) + 32|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = (($26) + ($28<<3)|0);
        $38 = $29;
        break;
       } else {
        $30 = (($26) + ($23<<3)|0);
        $38 = $30;
        break;
       }
      }
     } while(0);
     $31 = HEAP32[560624>>2]|0;
     $32 = (($31) + 28|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + 32|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($33) + ($35<<3)|0);
     $37 = ($38|0)==($36|0);
     if ($37) {
      label = 12;
     } else {
      $39 = (($38) + 4|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       label = 12;
      } else {
       $temp$0$i4 = $40;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $42 = HEAP32[$7>>2]|0;
     $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
     $44 = ($43|0)==(0|0);
     if ($44) {
      $$0$i1 = 0;$storemerge = 0;
      break;
     } else {
      $temp$0$i4 = $43;
     }
    }
    $45 = (($temp$0$i4) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $$0$i1 = $temp$0$i4;$storemerge = $46;
   }
  } while(0);
  HEAP32[$this>>2] = $storemerge;
  __ZN11CullResultsC2Ev($pos$i$i$i$i);
  $47 = ($$0$i1|0)==(0|0);
  if (!($47)) {
   $48 = (($$0$i1) + 28|0);
   $49 = HEAP8[$48>>0]|0;
   $50 = ($49<<24>>24)==(0);
   if (!($50)) {
    __THREW__ = 0;
    invoke_vii(2640,($$0$i1|0),($pos$i$i$i$i|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    $$pr = HEAP8[$48>>0]|0;
    $57 = ($$pr<<24>>24)==(0);
    if (!($57)) {
     $58 = HEAP32[652824>>2]|0;
     __THREW__ = 0;
     invoke_viiii(344,($$0$i1|0),($pos$i$i$i$i|0),($58|0),2);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
    }
   }
  }
  __ZN11CullResultsD2Ev($pos$i$i$i$i);
  $61 = (($8) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==($3|0);
  if ($63) {
   label = 21;
   break;
  } else {
   $8 = $62;
  }
 }
 if ((label|0) == 21) {
  $64 = (__Z19GetReflectionProbesv()|0);
  __ZN16ReflectionProbes6UpdateEv($64);
  ;HEAP32[$2+0>>2]=HEAP32[$savedViewport+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$savedViewport+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$savedViewport+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$savedViewport+12>>2]|0;
  HEAP8[$1>>0] = 0;
  __ZN13RenderManager23AddRemoveCamerasDelayedEv($this);
  STACKTOP = sp;return;
 }
 $53 = ___cxa_find_matching_catch()|0;
 $54 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3411,($pos$i$i$i$i|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $65 = ___cxa_find_matching_catch(0|0)|0;
  $66 = tempRet0;
  ___clang_call_terminate($65);
  // unreachable;
 } else {
  ___resumeException($53|0);
  // unreachable;
 }
}
function __ZN13RenderManager23AddRemoveCamerasDelayedEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$0$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__f$01$i$i = 0, $__f$01$i$i8 = 0, $pos$i$i$i$i1 = 0, $temp$0$i = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 40|0);
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $7 = $4;
  while(1) {
   $6 = (($7) + 8|0);
   $8 = HEAP32[$6>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $$0$i6 = 0;
   } else {
    HEAP32[$0>>2] = $8;
    $10 = HEAP32[560624>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     label = 12;
    } else {
     $12 = (($10) + 36|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($10) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($13|0)==($15|0);
     do {
      if ($16) {
       $17 = (($10) + 28|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = (($10) + 32|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($18) + ($20<<3)|0);
       $37 = $21;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$10,$0);
       $22 = HEAP32[$pos$i$i$i$i1>>2]|0;
       $23 = ($22|0)==(-1);
       $24 = (($10) + 28|0);
       $25 = HEAP32[$24>>2]|0;
       if ($23) {
        $26 = (($10) + 32|0);
        $27 = HEAP32[$26>>2]|0;
        $28 = (($25) + ($27<<3)|0);
        $37 = $28;
        break;
       } else {
        $29 = (($25) + ($22<<3)|0);
        $37 = $29;
        break;
       }
      }
     } while(0);
     $30 = HEAP32[560624>>2]|0;
     $31 = (($30) + 28|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($30) + 32|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + ($34<<3)|0);
     $36 = ($37|0)==($35|0);
     if ($36) {
      label = 12;
     } else {
      $38 = (($37) + 4|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = ($39|0)==(0|0);
      if ($40) {
       label = 12;
      } else {
       $temp$0$i5 = $39;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $41 = HEAP32[$6>>2]|0;
     $42 = (__Z31ReadObjectFromPersistentManageri($41)|0);
     $temp$0$i5 = $42;
    }
    $$0$i6 = $temp$0$i5;
   }
   $43 = (($7) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   __ZN13RenderManager12RemoveCameraEP6Camera($this,$$0$i6);
   $45 = ($44|0)==($2|0);
   if ($45) {
    break;
   } else {
    $7 = $44;
   }
  }
 }
 $46 = (($this) + 48|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0);
 if (!($48)) {
  $49 = HEAP32[$3>>2]|0;
  $50 = HEAP32[$2>>2]|0;
  $51 = (($50) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = HEAP32[$49>>2]|0;
  $54 = (($53) + 4|0);
  HEAP32[$54>>2] = $52;
  $55 = HEAP32[$49>>2]|0;
  $56 = HEAP32[$51>>2]|0;
  HEAP32[$56>>2] = $55;
  HEAP32[$46>>2] = 0;
  $57 = ($49|0)==($2|0);
  if (!($57)) {
   $__f$01$i$i8 = $49;
   while(1) {
    $58 = (($__f$01$i$i8) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    __ZdlPv($__f$01$i$i8);
    $60 = ($59|0)==($2|0);
    if ($60) {
     break;
    } else {
     $__f$01$i$i8 = $59;
    }
   }
  }
 }
 $61 = (($this) + 28|0);
 $62 = (($this) + 32|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==($61|0);
 if (!($64)) {
  $66 = $63;
  while(1) {
   $65 = (($66) + 8|0);
   $67 = HEAP32[$65>>2]|0;
   $68 = ($67|0)==(0);
   if ($68) {
    $$0$i = 0;
   } else {
    HEAP32[$1>>2] = $67;
    $69 = HEAP32[560624>>2]|0;
    $70 = ($69|0)==(0|0);
    if ($70) {
     label = 29;
    } else {
     $71 = (($69) + 36|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = (($69) + 4|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($72|0)==($74|0);
     do {
      if ($75) {
       $76 = (($69) + 28|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = (($69) + 32|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = (($77) + ($79<<3)|0);
       $96 = $80;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$69,$1);
       $81 = HEAP32[$pos$i$i$i$i1>>2]|0;
       $82 = ($81|0)==(-1);
       $83 = (($69) + 28|0);
       $84 = HEAP32[$83>>2]|0;
       if ($82) {
        $85 = (($69) + 32|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = (($84) + ($86<<3)|0);
        $96 = $87;
        break;
       } else {
        $88 = (($84) + ($81<<3)|0);
        $96 = $88;
        break;
       }
      }
     } while(0);
     $89 = HEAP32[560624>>2]|0;
     $90 = (($89) + 28|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = (($89) + 32|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = (($91) + ($93<<3)|0);
     $95 = ($96|0)==($94|0);
     if ($95) {
      label = 29;
     } else {
      $97 = (($96) + 4|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = ($98|0)==(0|0);
      if ($99) {
       label = 29;
      } else {
       $temp$0$i = $98;
      }
     }
    }
    if ((label|0) == 29) {
     label = 0;
     $100 = HEAP32[$65>>2]|0;
     $101 = (__Z31ReadObjectFromPersistentManageri($100)|0);
     $temp$0$i = $101;
    }
    $$0$i = $temp$0$i;
   }
   $102 = (($66) + 4|0);
   $103 = HEAP32[$102>>2]|0;
   __ZN13RenderManager9AddCameraEP6Camera($this,$$0$i);
   $104 = ($103|0)==($61|0);
   if ($104) {
    break;
   } else {
    $66 = $103;
   }
  }
 }
 $105 = (($this) + 36|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($106|0)==(0);
 if ($107) {
  STACKTOP = sp;return;
 }
 $108 = HEAP32[$62>>2]|0;
 $109 = HEAP32[$61>>2]|0;
 $110 = (($109) + 4|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = HEAP32[$108>>2]|0;
 $113 = (($112) + 4|0);
 HEAP32[$113>>2] = $111;
 $114 = HEAP32[$108>>2]|0;
 $115 = HEAP32[$110>>2]|0;
 HEAP32[$115>>2] = $114;
 HEAP32[$105>>2] = 0;
 $116 = ($108|0)==($61|0);
 if ($116) {
  STACKTOP = sp;return;
 } else {
  $__f$01$i$i = $108;
 }
 while(1) {
  $117 = (($__f$01$i$i) + 4|0);
  $118 = HEAP32[$117>>2]|0;
  __ZdlPv($__f$01$i$i);
  $119 = ($118|0)==($61|0);
  if ($119) {
   break;
  } else {
   $__f$01$i$i = $118;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13RenderManager13RenderCamerasEi($this,$displayId) {
 $this = $this|0;
 $displayId = $displayId|0;
 var $$0$i = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $pos$i$i$i$i1 = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1088|0;
 $pos$i$i$i$i1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 52|0);
 HEAP8[$2>>0] = 1;
 $3 = (__ZN5Unity8GetSceneEv()|0);
 $4 = (($this) + 4|0);
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 if ($7) {
  HEAP8[$2>>0] = 0;
  __ZN13RenderManager23AddRemoveCamerasDelayedEv($this);
  STACKTOP = sp;return;
 }
 $9 = $6;
 L4: while(1) {
  $8 = (($9) + 8|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $10;
   $12 = HEAP32[560624>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    label = 12;
   } else {
    $14 = (($12) + 36|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($12) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($15|0)==($17|0);
    do {
     if ($18) {
      $19 = (($12) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($12) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $39 = $23;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$12,$0);
      $24 = HEAP32[$pos$i$i$i$i1>>2]|0;
      $25 = ($24|0)==(-1);
      $26 = (($12) + 28|0);
      $27 = HEAP32[$26>>2]|0;
      if ($25) {
       $28 = (($12) + 32|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($27) + ($29<<3)|0);
       $39 = $30;
       break;
      } else {
       $31 = (($27) + ($24<<3)|0);
       $39 = $31;
       break;
      }
     }
    } while(0);
    $32 = HEAP32[560624>>2]|0;
    $33 = (($32) + 28|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($32) + 32|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + ($36<<3)|0);
    $38 = ($39|0)==($37|0);
    if ($38) {
     label = 12;
    } else {
     $40 = (($39) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 12;
     } else {
      $temp$0$i = $41;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    $43 = HEAP32[$8>>2]|0;
    $44 = (__Z31ReadObjectFromPersistentManageri($43)|0);
    $temp$0$i = $44;
   }
   $$0$i = $temp$0$i;
  }
  $45 = (($$0$i) + 352|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0);
  if ($47) {
   __ZN5Unity5Scene17BeginCameraRenderEv($3);
   $48 = ($$0$i|0)==(0|0);
   L24: do {
    if ($48) {
     HEAP32[$this>>2] = 0;
     __ZN11CullResultsC2Ev($pos$i$i$i$i1);
     label = 35;
    } else {
     $49 = (($$0$i) + 4|0);
     $50 = HEAP32[$49>>2]|0;
     HEAP32[$this>>2] = $50;
     $51 = (($$0$i) + 28|0);
     $52 = HEAP8[$51>>0]|0;
     $53 = ($52<<24>>24)==(0);
     do {
      if (!($53)) {
       $54 = (__ZNK6Camera16GetStereoEnabledEv($$0$i)|0);
       if ($54) {
        $55 = (($$0$i) + 292|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = ($56|0)==(0);
        if (!($57)) {
         HEAP32[$1>>2] = $56;
         $58 = HEAP32[560624>>2]|0;
         $59 = ($58|0)==(0|0);
         if (!($59)) {
          $60 = (($58) + 36|0);
          $61 = HEAP32[$60>>2]|0;
          $62 = (($58) + 4|0);
          $63 = HEAP32[$62>>2]|0;
          $64 = ($61|0)==($63|0);
          do {
           if ($64) {
            $65 = (($58) + 28|0);
            $66 = HEAP32[$65>>2]|0;
            $67 = (($58) + 32|0);
            $68 = HEAP32[$67>>2]|0;
            $69 = (($66) + ($68<<3)|0);
            $85 = $69;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$58,$1);
            $70 = HEAP32[$pos$i$i$i$i1>>2]|0;
            $71 = ($70|0)==(-1);
            $72 = (($58) + 28|0);
            $73 = HEAP32[$72>>2]|0;
            if ($71) {
             $74 = (($58) + 32|0);
             $75 = HEAP32[$74>>2]|0;
             $76 = (($73) + ($75<<3)|0);
             $85 = $76;
             break;
            } else {
             $77 = (($73) + ($70<<3)|0);
             $85 = $77;
             break;
            }
           }
          } while(0);
          $78 = HEAP32[560624>>2]|0;
          $79 = (($78) + 28|0);
          $80 = HEAP32[$79>>2]|0;
          $81 = (($78) + 32|0);
          $82 = HEAP32[$81>>2]|0;
          $83 = (($80) + ($82<<3)|0);
          $84 = ($85|0)==($83|0);
          if (!($84)) {
           $86 = (($85) + 4|0);
           $87 = HEAP32[$86>>2]|0;
           $88 = ($87|0)==(0|0);
           if (!($88)) {
            break;
           }
          }
         }
         $89 = HEAP32[$55>>2]|0;
         $90 = (__Z31ReadObjectFromPersistentManageri($89)|0);
         $91 = ($90|0)==(0|0);
         if (!($91)) {
          break;
         }
        }
        __ZN6Camera12RenderStereoEi($$0$i,2);
        break L24;
       }
      }
     } while(0);
     __ZN11CullResultsC2Ev($pos$i$i$i$i1);
     $92 = HEAP8[$51>>0]|0;
     $93 = ($92<<24>>24)==(0);
     if ($93) {
      label = 35;
     } else {
      __THREW__ = 0;
      invoke_vii(2640,($$0$i|0),($pos$i$i$i$i1|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       break L4;
      }
      $$pr = HEAP8[$51>>0]|0;
      $100 = ($$pr<<24>>24)==(0);
      if ($100) {
       label = 35;
      } else {
       $101 = HEAP32[652824>>2]|0;
       __THREW__ = 0;
       invoke_viiii(344,($$0$i|0),($pos$i$i$i$i1|0),($101|0),2);
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if ($103) {
        break L4;
       } else {
        label = 35;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 35) {
    label = 0;
    __ZN11CullResultsD2Ev($pos$i$i$i$i1);
   }
   __ZN5Unity5Scene15EndCameraRenderEv($3);
  }
  $104 = (($9) + 4|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ($105|0)==($4|0);
  if ($106) {
   label = 38;
   break;
  } else {
   $9 = $105;
  }
 }
 if ((label|0) == 38) {
  HEAP8[$2>>0] = 0;
  __ZN13RenderManager23AddRemoveCamerasDelayedEv($this);
  STACKTOP = sp;return;
 }
 $96 = ___cxa_find_matching_catch()|0;
 $97 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3411,($pos$i$i$i$i1|0));
 $98 = __THREW__; __THREW__ = 0;
 $99 = $98&1;
 if ($99) {
  $107 = ___cxa_find_matching_catch(0|0)|0;
  $108 = tempRet0;
  ___clang_call_terminate($107);
  // unreachable;
 } else {
  ___resumeException($96|0);
  // unreachable;
 }
}
function __ZN13RenderManager19AddCameraRenderableEP10Renderablei($this,$r,$depth) {
 $this = $this|0;
 $r = $r|0;
 $depth = $depth|0;
 var $$0$i$i$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $r;
 $1 = (($this) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $12 = (($this) + 92|0);
  $$0$i$i$i = $12;$21 = $12;
 } else {
  $__nd$0$in$i$i$i = $2;
  while(1) {
   $4 = (($__nd$0$in$i$i$i) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)>($depth|0);
   if ($6) {
    $7 = HEAP32[$__nd$0$in$i$i$i>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $$0$i$i$i = $__nd$0$in$i$i$i;$21 = $__nd$0$in$i$i$i;
     break;
    } else {
     $__nd$0$in$i$i$i = $7;
     continue;
    }
   } else {
    $9 = (($__nd$0$in$i$i$i) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$i$i$i = $9;$21 = $__nd$0$in$i$i$i;
     break;
    } else {
     $__nd$0$in$i$i$i = $10;
     continue;
    }
   }
  }
 }
 $13 = (__Znwj(24)|0);
 $14 = (($13) + 16|0);
 $15 = $14;
 $16 = $15;
 HEAP32[$16>>2] = $depth;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $0;
 HEAP32[$13>>2] = 0;
 $19 = (($13) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($13) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i$i$i>>2] = $13;
 $22 = (($this) + 88|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $13;
 } else {
  HEAP32[$22>>2] = $24;
  $$pre$i$i$i = HEAP32[$$0$i$i$i>>2]|0;
  $27 = $$pre$i$i$i;
 }
 $26 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 96|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN13RenderManager22RemoveCameraRenderableEP10Renderable($this,$r) {
 $this = $this|0;
 $r = $r|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i5 = 0, $$0$i$i$i$i9 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 92|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 96|0);
 $5 = (($this) + 92|0);
 $7 = $1;
 while(1) {
  $6 = (($7) + 4|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $$01$i$i$i$i7 = $7;
   while(1) {
    $12 = (($$01$i$i$i$i7) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($$01$i$i$i$i7|0);
    if ($15) {
     $$0$i$i$i$i9 = $13;
     break;
    } else {
     $$01$i$i$i$i7 = $13;
    }
   }
  } else {
   $$0$i$i$i$i$i5 = $8;
   while(1) {
    $10 = HEAP32[$$0$i$i$i$i$i5>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$i$i$i$i9 = $$0$i$i$i$i$i5;
     break;
    } else {
     $$0$i$i$i$i$i5 = $10;
    }
   }
  }
  $16 = (($7) + 20|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($r|0);
  if ($18) {
   if ($9) {
    $$01$i$i$i$i = $7;
    while(1) {
     $22 = (($$01$i$i$i$i) + 8|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==($$01$i$i$i$i|0);
     if ($25) {
      $$0$i$i$i$i = $23;
      break;
     } else {
      $$01$i$i$i$i = $23;
     }
    }
   } else {
    $$0$i$i$i$i$i = $8;
    while(1) {
     $20 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $20;
     }
    }
   }
   $26 = HEAP32[$0>>2]|0;
   $27 = ($26|0)==($7|0);
   if ($27) {
    HEAP32[$0>>2] = $$0$i$i$i$i;
   }
   $28 = HEAP32[$4>>2]|0;
   $29 = (($28) + -1)|0;
   HEAP32[$4>>2] = $29;
   $30 = HEAP32[$5>>2]|0;
   __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($30,$7);
   __ZdlPv($7);
  }
  $19 = ($$0$i$i$i$i9|0)==($2|0);
  if ($19) {
   break;
  } else {
   $7 = $$0$i$i$i$i9;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13RenderManager29InvokeOnRenderObjectCallbacksEv($this) {
 $this = $this|0;
 var $$pre$i = 0, $$pre$i$i$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $it = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $it = sp;
 $0 = (($this) + 100|0);
 $1 = (($this) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($it) + 4|0);
 $5 = (($it) + 8|0);
 HEAP32[$5>>2] = $0;
 $6 = (($it) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[$0>>2]|0;
 HEAP32[$it>>2] = $7;
 HEAP32[$1>>2] = $it;
 HEAP32[$4>>2] = $2;
 HEAP32[$0>>2] = $0;
 $8 = ($7|0)==($0|0);
 if ($8) {
  HEAP32[$it>>2] = $it;
 }
 $9 = (($this) + 104|0);
 HEAP32[$9>>2] = $0;
 HEAP32[$0>>2] = $0;
 $10 = HEAP32[$it>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $it;
 $12 = HEAP32[$4>>2]|0;
 HEAP32[$12>>2] = $it;
 while(1) {
  $13 = HEAP32[$4>>2]|0;
  $14 = ($13|0)==($it|0);
  if ($14) {
   label = 12;
   break;
  }
  HEAP32[$6>>2] = $13;
  $15 = HEAP32[$13>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $24 = $13;
  } else {
   $17 = (($13) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($15) + 4|0);
   HEAP32[$19>>2] = $18;
   $20 = HEAP32[$13>>2]|0;
   $21 = HEAP32[$17>>2]|0;
   HEAP32[$21>>2] = $20;
   HEAP32[$13>>2] = 0;
   HEAP32[$17>>2] = 0;
   $$pre3$i = HEAP32[$6>>2]|0;
   $24 = $$pre3$i;
  }
  $22 = HEAP32[$5>>2]|0;
  $23 = ($24|0)==($22|0);
  if ($23) {
   $35 = $24;
  } else {
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   $$pre$i$i$i = (($24) + 4|0);
   if (!($26)) {
    $27 = HEAP32[$$pre$i$i$i>>2]|0;
    $28 = (($25) + 4|0);
    HEAP32[$28>>2] = $27;
    $29 = HEAP32[$24>>2]|0;
    $30 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$30>>2] = $29;
    HEAP32[$24>>2] = 0;
    HEAP32[$$pre$i$i$i>>2] = 0;
   }
   $31 = HEAP32[$22>>2]|0;
   HEAP32[$24>>2] = $31;
   HEAP32[$$pre$i$i$i>>2] = $22;
   $32 = (($31) + 4|0);
   HEAP32[$32>>2] = $24;
   $33 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$33>>2] = $24;
   $$pre$i = HEAP32[$6>>2]|0;
   $35 = $$pre$i;
  }
  $34 = ($35|0)==(0|0);
  if ($34) {
   break;
  }
  $36 = (($35) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  __ZN13MonoBehaviour20InvokeOnRenderObjectEv($37);
 }
 if ((label|0) == 12) {
  HEAP32[$6>>2] = 0;
 }
 HEAP32[$4>>2] = 0;
 HEAP32[$it>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13RenderManager9AddCameraEP6Camera($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$0$i$i = 0, $$lcssa12$i = 0, $$lcssa12$i11 = 0, $$lcssa12$i26 = 0, $$lcssa12$i39 = 0, $$lcssa12$i52 = 0, $$ph$be$i = 0, $$ph$be$i14 = 0, $$ph$be$i29 = 0, $$ph$be$i42 = 0, $$ph$be$i55 = 0, $$pn$i = 0, $$pn$i20 = 0, $$pn$i33 = 0, $$pn$i46 = 0, $$pn$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, $phitmp70 = 0, $pos$i$i$i$i58 = 0, $temp$0$i$i = 0, $temp$0$i90 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i58 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($c|0)==(0|0);
 if ($2) {
  $16 = 0;
 } else {
  $3 = (($c) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $16 = $4;
 }
 $5 = (($this) + 52|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($this) + 40|0);
  $9 = (($this) + 44|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($8|0);
  if (!($11)) {
   $12 = (($this) + 48|0);
   $$pn$i = $10;
   while(1) {
    $13 = (($$pn$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($16|0);
    $17 = (($$pn$i) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==($8|0);
    while(1) {
     if (!($15)) {
      $$ph$be$i = $18;
      break;
     }
     L13: do {
      if ($19) {
       $$lcssa12$i = $8;
      } else {
       $21 = $18;
       while(1) {
        $20 = (($21) + 8|0);
        $22 = HEAP32[$20>>2]|0;
        $23 = ($22|0)==($16|0);
        if (!($23)) {
         $$lcssa12$i = $21;
         break L13;
        }
        $24 = (($21) + 4|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = ($25|0)==($8|0);
        if ($26) {
         $$lcssa12$i = $8;
         break;
        } else {
         $21 = $25;
        }
       }
      }
     } while(0);
     $27 = ($$pn$i|0)==($$lcssa12$i|0);
     if (!($27)) {
      label = 12;
      break;
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $28 = HEAP32[$$lcssa12$i>>2]|0;
     $29 = (($28) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = HEAP32[$$pn$i>>2]|0;
     $32 = (($31) + 4|0);
     HEAP32[$32>>2] = $30;
     $33 = HEAP32[$$pn$i>>2]|0;
     $34 = HEAP32[$29>>2]|0;
     HEAP32[$34>>2] = $33;
     $36 = $$pn$i;
     while(1) {
      $35 = (($36) + 4|0);
      $37 = HEAP32[$35>>2]|0;
      $38 = HEAP32[$12>>2]|0;
      $39 = (($38) + -1)|0;
      HEAP32[$12>>2] = $39;
      __ZdlPv($36);
      $40 = ($37|0)==($$lcssa12$i|0);
      if ($40) {
       $$ph$be$i = $$lcssa12$i;
       break;
      } else {
       $36 = $37;
      }
     }
    }
    $41 = ($$ph$be$i|0)==($8|0);
    if ($41) {
     break;
    } else {
     $$pn$i = $$ph$be$i;
    }
   }
  }
  $42 = (($this) + 28|0);
  $43 = (__Znwj(12)|0);
  $44 = (($43) + 8|0);
  HEAP32[$44>>2] = $16;
  $45 = HEAP32[$42>>2]|0;
  $46 = (($45) + 4|0);
  HEAP32[$46>>2] = $43;
  $47 = HEAP32[$42>>2]|0;
  HEAP32[$43>>2] = $47;
  HEAP32[$42>>2] = $43;
  $48 = (($43) + 4|0);
  HEAP32[$48>>2] = $42;
  $49 = (($this) + 36|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + 1)|0;
  HEAP32[$49>>2] = $51;
  STACKTOP = sp;return;
 }
 $52 = (($this) + 28|0);
 if ($2) {
  $62 = 0;
 } else {
  $53 = (($c) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  $62 = $54;
 }
 $55 = (($this) + 32|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==($52|0);
 if (!($57)) {
  $58 = (($this) + 36|0);
  $$pn$i5 = $56;
  while(1) {
   $59 = (($$pn$i5) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==($62|0);
   $63 = (($$pn$i5) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==($52|0);
   while(1) {
    if (!($61)) {
     $$ph$be$i14 = $64;
     break;
    }
    L36: do {
     if ($65) {
      $$lcssa12$i11 = $52;
     } else {
      $67 = $64;
      while(1) {
       $66 = (($67) + 8|0);
       $68 = HEAP32[$66>>2]|0;
       $69 = ($68|0)==($62|0);
       if (!($69)) {
        $$lcssa12$i11 = $67;
        break L36;
       }
       $70 = (($67) + 4|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = ($71|0)==($52|0);
       if ($72) {
        $$lcssa12$i11 = $52;
        break;
       } else {
        $67 = $71;
       }
      }
     }
    } while(0);
    $73 = ($$pn$i5|0)==($$lcssa12$i11|0);
    if (!($73)) {
     label = 26;
     break;
    }
   }
   if ((label|0) == 26) {
    label = 0;
    $74 = HEAP32[$$lcssa12$i11>>2]|0;
    $75 = (($74) + 4|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = HEAP32[$$pn$i5>>2]|0;
    $78 = (($77) + 4|0);
    HEAP32[$78>>2] = $76;
    $79 = HEAP32[$$pn$i5>>2]|0;
    $80 = HEAP32[$75>>2]|0;
    HEAP32[$80>>2] = $79;
    $82 = $$pn$i5;
    while(1) {
     $81 = (($82) + 4|0);
     $83 = HEAP32[$81>>2]|0;
     $84 = HEAP32[$58>>2]|0;
     $85 = (($84) + -1)|0;
     HEAP32[$58>>2] = $85;
     __ZdlPv($82);
     $86 = ($83|0)==($$lcssa12$i11|0);
     if ($86) {
      $$ph$be$i14 = $$lcssa12$i11;
      break;
     } else {
      $82 = $83;
     }
    }
   }
   $87 = ($$ph$be$i14|0)==($52|0);
   if ($87) {
    break;
   } else {
    $$pn$i5 = $$ph$be$i14;
   }
  }
 }
 $88 = (($this) + 40|0);
 if ($2) {
  $98 = 0;
 } else {
  $89 = (($c) + 4|0);
  $90 = HEAP32[$89>>2]|0;
  $98 = $90;
 }
 $91 = (($this) + 44|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==($88|0);
 if (!($93)) {
  $94 = (($this) + 48|0);
  $$pn$i20 = $92;
  while(1) {
   $95 = (($$pn$i20) + 8|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==($98|0);
   $99 = (($$pn$i20) + 4|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==($88|0);
   while(1) {
    if (!($97)) {
     $$ph$be$i29 = $100;
     break;
    }
    L57: do {
     if ($101) {
      $$lcssa12$i26 = $88;
     } else {
      $103 = $100;
      while(1) {
       $102 = (($103) + 8|0);
       $104 = HEAP32[$102>>2]|0;
       $105 = ($104|0)==($98|0);
       if (!($105)) {
        $$lcssa12$i26 = $103;
        break L57;
       }
       $106 = (($103) + 4|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = ($107|0)==($88|0);
       if ($108) {
        $$lcssa12$i26 = $88;
        break;
       } else {
        $103 = $107;
       }
      }
     }
    } while(0);
    $109 = ($$pn$i20|0)==($$lcssa12$i26|0);
    if (!($109)) {
     label = 39;
     break;
    }
   }
   if ((label|0) == 39) {
    label = 0;
    $110 = HEAP32[$$lcssa12$i26>>2]|0;
    $111 = (($110) + 4|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = HEAP32[$$pn$i20>>2]|0;
    $114 = (($113) + 4|0);
    HEAP32[$114>>2] = $112;
    $115 = HEAP32[$$pn$i20>>2]|0;
    $116 = HEAP32[$111>>2]|0;
    HEAP32[$116>>2] = $115;
    $118 = $$pn$i20;
    while(1) {
     $117 = (($118) + 4|0);
     $119 = HEAP32[$117>>2]|0;
     $120 = HEAP32[$94>>2]|0;
     $121 = (($120) + -1)|0;
     HEAP32[$94>>2] = $121;
     __ZdlPv($118);
     $122 = ($119|0)==($$lcssa12$i26|0);
     if ($122) {
      $$ph$be$i29 = $$lcssa12$i26;
      break;
     } else {
      $118 = $119;
     }
    }
   }
   $123 = ($$ph$be$i29|0)==($88|0);
   if ($123) {
    break;
   } else {
    $$pn$i20 = $$ph$be$i29;
   }
  }
 }
 $124 = (($this) + 4|0);
 $125 = (($this) + 8|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($126|0)==($124|0);
 if (!($127)) {
  $128 = (($this) + 12|0);
  $$pn$i33 = $126;
  while(1) {
   $129 = (($$pn$i33) + 8|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ($130|0)==($16|0);
   $132 = (($$pn$i33) + 4|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($133|0)==($124|0);
   while(1) {
    if (!($131)) {
     $$ph$be$i42 = $133;
     break;
    }
    L75: do {
     if ($134) {
      $$lcssa12$i39 = $124;
     } else {
      $136 = $133;
      while(1) {
       $135 = (($136) + 8|0);
       $137 = HEAP32[$135>>2]|0;
       $138 = ($137|0)==($16|0);
       if (!($138)) {
        $$lcssa12$i39 = $136;
        break L75;
       }
       $139 = (($136) + 4|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = ($140|0)==($124|0);
       if ($141) {
        $$lcssa12$i39 = $124;
        break;
       } else {
        $136 = $140;
       }
      }
     }
    } while(0);
    $142 = ($$pn$i33|0)==($$lcssa12$i39|0);
    if (!($142)) {
     label = 50;
     break;
    }
   }
   if ((label|0) == 50) {
    label = 0;
    $143 = HEAP32[$$lcssa12$i39>>2]|0;
    $144 = (($143) + 4|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = HEAP32[$$pn$i33>>2]|0;
    $147 = (($146) + 4|0);
    HEAP32[$147>>2] = $145;
    $148 = HEAP32[$$pn$i33>>2]|0;
    $149 = HEAP32[$144>>2]|0;
    HEAP32[$149>>2] = $148;
    $151 = $$pn$i33;
    while(1) {
     $150 = (($151) + 4|0);
     $152 = HEAP32[$150>>2]|0;
     $153 = HEAP32[$128>>2]|0;
     $154 = (($153) + -1)|0;
     HEAP32[$128>>2] = $154;
     __ZdlPv($151);
     $155 = ($152|0)==($$lcssa12$i39|0);
     if ($155) {
      $$ph$be$i42 = $$lcssa12$i39;
      break;
     } else {
      $151 = $152;
     }
    }
   }
   $156 = ($$ph$be$i42|0)==($124|0);
   if ($156) {
    break;
   } else {
    $$pn$i33 = $$ph$be$i42;
   }
  }
 }
 $157 = (($this) + 16|0);
 $158 = (($this) + 20|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = ($159|0)==($157|0);
 if (!($160)) {
  $161 = (($this) + 24|0);
  $$pn$i46 = $159;
  while(1) {
   $162 = (($$pn$i46) + 8|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ($163|0)==($16|0);
   $165 = (($$pn$i46) + 4|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ($166|0)==($157|0);
   while(1) {
    if (!($164)) {
     $$ph$be$i55 = $166;
     break;
    }
    L93: do {
     if ($167) {
      $$lcssa12$i52 = $157;
     } else {
      $169 = $166;
      while(1) {
       $168 = (($169) + 8|0);
       $170 = HEAP32[$168>>2]|0;
       $171 = ($170|0)==($16|0);
       if (!($171)) {
        $$lcssa12$i52 = $169;
        break L93;
       }
       $172 = (($169) + 4|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ($173|0)==($157|0);
       if ($174) {
        $$lcssa12$i52 = $157;
        break;
       } else {
        $169 = $173;
       }
      }
     }
    } while(0);
    $175 = ($$pn$i46|0)==($$lcssa12$i52|0);
    if (!($175)) {
     label = 61;
     break;
    }
   }
   if ((label|0) == 61) {
    label = 0;
    $176 = HEAP32[$$lcssa12$i52>>2]|0;
    $177 = (($176) + 4|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = HEAP32[$$pn$i46>>2]|0;
    $180 = (($179) + 4|0);
    HEAP32[$180>>2] = $178;
    $181 = HEAP32[$$pn$i46>>2]|0;
    $182 = HEAP32[$177>>2]|0;
    HEAP32[$182>>2] = $181;
    $184 = $$pn$i46;
    while(1) {
     $183 = (($184) + 4|0);
     $185 = HEAP32[$183>>2]|0;
     $186 = HEAP32[$161>>2]|0;
     $187 = (($186) + -1)|0;
     HEAP32[$161>>2] = $187;
     __ZdlPv($184);
     $188 = ($185|0)==($$lcssa12$i52|0);
     if ($188) {
      $$ph$be$i55 = $$lcssa12$i52;
      break;
     } else {
      $184 = $185;
     }
    }
   }
   $189 = ($$ph$be$i55|0)==($157|0);
   if ($189) {
    break;
   } else {
    $$pn$i46 = $$ph$be$i55;
   }
  }
 }
 $190 = (($c) + 292|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = ($191|0)==(0);
 if ($192) {
  $$0$i$i = $124;
 } else {
  HEAP32[$0>>2] = $191;
  $193 = HEAP32[560624>>2]|0;
  $194 = ($193|0)==(0|0);
  if ($194) {
   label = 73;
  } else {
   $195 = (($193) + 36|0);
   $196 = HEAP32[$195>>2]|0;
   $197 = (($193) + 4|0);
   $198 = HEAP32[$197>>2]|0;
   $199 = ($196|0)==($198|0);
   do {
    if ($199) {
     $200 = (($193) + 28|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = (($193) + 32|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = (($201) + ($203<<3)|0);
     $220 = $204;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i58,$193,$0);
     $205 = HEAP32[$pos$i$i$i$i58>>2]|0;
     $206 = ($205|0)==(-1);
     $207 = (($193) + 28|0);
     $208 = HEAP32[$207>>2]|0;
     if ($206) {
      $209 = (($193) + 32|0);
      $210 = HEAP32[$209>>2]|0;
      $211 = (($208) + ($210<<3)|0);
      $220 = $211;
      break;
     } else {
      $212 = (($208) + ($205<<3)|0);
      $220 = $212;
      break;
     }
    }
   } while(0);
   $213 = HEAP32[560624>>2]|0;
   $214 = (($213) + 28|0);
   $215 = HEAP32[$214>>2]|0;
   $216 = (($213) + 32|0);
   $217 = HEAP32[$216>>2]|0;
   $218 = (($215) + ($217<<3)|0);
   $219 = ($220|0)==($218|0);
   if ($219) {
    label = 73;
   } else {
    $221 = (($220) + 4|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = ($222|0)==(0|0);
    if ($223) {
     label = 73;
    } else {
     $temp$0$i$i = $222;
    }
   }
  }
  if ((label|0) == 73) {
   $224 = HEAP32[$190>>2]|0;
   $225 = (__Z31ReadObjectFromPersistentManageri($224)|0);
   $temp$0$i$i = $225;
  }
  $phitmp = ($temp$0$i$i|0)==(0|0);
  $phitmp70 = $phitmp ? $124 : $157;
  $$0$i$i = $phitmp70;
 }
 $226 = (($$0$i$i) + 4|0);
 $227 = HEAP32[$226>>2]|0;
 $228 = ($227|0)==($$0$i$i|0);
 L120: do {
  if (!($228)) {
   $229 = (($c) + 420|0);
   $231 = $227;
   L122: while(1) {
    $230 = (($231) + 8|0);
    $232 = HEAP32[$230>>2]|0;
    $233 = ($232|0)==(0);
    do {
     if (!($233)) {
      HEAP32[$1>>2] = $232;
      $234 = HEAP32[560624>>2]|0;
      $235 = ($234|0)==(0|0);
      if ($235) {
       label = 86;
      } else {
       $236 = (($234) + 36|0);
       $237 = HEAP32[$236>>2]|0;
       $238 = (($234) + 4|0);
       $239 = HEAP32[$238>>2]|0;
       $240 = ($237|0)==($239|0);
       do {
        if ($240) {
         $241 = (($234) + 28|0);
         $242 = HEAP32[$241>>2]|0;
         $243 = (($234) + 32|0);
         $244 = HEAP32[$243>>2]|0;
         $245 = (($242) + ($244<<3)|0);
         $261 = $245;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i58,$234,$1);
         $246 = HEAP32[$pos$i$i$i$i58>>2]|0;
         $247 = ($246|0)==(-1);
         $248 = (($234) + 28|0);
         $249 = HEAP32[$248>>2]|0;
         if ($247) {
          $250 = (($234) + 32|0);
          $251 = HEAP32[$250>>2]|0;
          $252 = (($249) + ($251<<3)|0);
          $261 = $252;
          break;
         } else {
          $253 = (($249) + ($246<<3)|0);
          $261 = $253;
          break;
         }
        }
       } while(0);
       $254 = HEAP32[560624>>2]|0;
       $255 = (($254) + 28|0);
       $256 = HEAP32[$255>>2]|0;
       $257 = (($254) + 32|0);
       $258 = HEAP32[$257>>2]|0;
       $259 = (($256) + ($258<<3)|0);
       $260 = ($261|0)==($259|0);
       if ($260) {
        label = 86;
       } else {
        $262 = (($261) + 4|0);
        $263 = HEAP32[$262>>2]|0;
        $264 = ($263|0)==(0|0);
        if ($264) {
         label = 86;
        } else {
         $temp$0$i90 = $263;
        }
       }
      }
      if ((label|0) == 86) {
       label = 0;
       $265 = HEAP32[$230>>2]|0;
       $266 = (__Z31ReadObjectFromPersistentManageri($265)|0);
       $267 = ($266|0)==(0|0);
       if ($267) {
        break;
       } else {
        $temp$0$i90 = $266;
       }
      }
      $268 = (($temp$0$i90) + 420|0);
      $269 = Math_fround(HEAPF32[$268>>2]);
      $270 = Math_fround(HEAPF32[$229>>2]);
      $271 = $269 > $270;
      if ($271) {
       break L122;
      }
     }
    } while(0);
    $284 = (($231) + 4|0);
    $285 = HEAP32[$284>>2]|0;
    $286 = ($285|0)==($$0$i$i|0);
    if ($286) {
     break L120;
    } else {
     $231 = $285;
    }
   }
   if ($2) {
    $276 = 0;
   } else {
    $272 = (($c) + 4|0);
    $273 = HEAP32[$272>>2]|0;
    $276 = $273;
   }
   $274 = (__Znwj(12)|0);
   HEAP32[$274>>2] = 0;
   $275 = (($274) + 8|0);
   HEAP32[$275>>2] = $276;
   $277 = HEAP32[$231>>2]|0;
   $278 = (($277) + 4|0);
   HEAP32[$278>>2] = $274;
   $279 = HEAP32[$231>>2]|0;
   HEAP32[$274>>2] = $279;
   HEAP32[$231>>2] = $274;
   $280 = (($274) + 4|0);
   HEAP32[$280>>2] = $231;
   $281 = (($$0$i$i) + 8|0);
   $282 = HEAP32[$281>>2]|0;
   $283 = (($282) + 1)|0;
   HEAP32[$281>>2] = $283;
   STACKTOP = sp;return;
  }
 } while(0);
 if ($2) {
  $291 = 0;
 } else {
  $287 = (($c) + 4|0);
  $288 = HEAP32[$287>>2]|0;
  $291 = $288;
 }
 $289 = (__Znwj(12)|0);
 $290 = (($289) + 8|0);
 HEAP32[$290>>2] = $291;
 $292 = HEAP32[$$0$i$i>>2]|0;
 $293 = (($292) + 4|0);
 HEAP32[$293>>2] = $289;
 $294 = HEAP32[$$0$i$i>>2]|0;
 HEAP32[$289>>2] = $294;
 HEAP32[$$0$i$i>>2] = $289;
 $295 = (($289) + 4|0);
 HEAP32[$295>>2] = $$0$i$i;
 $296 = (($$0$i$i) + 8|0);
 $297 = HEAP32[$296>>2]|0;
 $298 = (($297) + 1)|0;
 HEAP32[$296>>2] = $298;
 STACKTOP = sp;return;
}
function __ZN13RenderManager12RemoveCameraEP6Camera($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$0$i = 0, $$lcssa12$i = 0, $$lcssa12$i10$lcssa = 0, $$lcssa12$i10$ph$us = 0, $$lcssa12$i23 = 0, $$lcssa12$i36$lcssa = 0, $$lcssa12$i36$ph$us = 0, $$ph$be$i = 0, $$ph$be$i13 = 0, $$ph$be$i26 = 0, $$ph$be$i39 = 0, $$pn$i = 0, $$pn$i17 = 0, $$pn$i30 = 0, $$pn$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = ($c|0)==(0|0);
 if ($1) {
  $12 = 0;
 } else {
  $2 = (($c) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $12 = $3;
 }
 $4 = (($this) + 28|0);
 $5 = (($this) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 if (!($7)) {
  $8 = (($this) + 36|0);
  $$pn$i = $6;
  while(1) {
   $9 = (($$pn$i) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($12|0);
   $13 = (($$pn$i) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($4|0);
   while(1) {
    if (!($11)) {
     $$ph$be$i = $14;
     break;
    }
    L11: do {
     if ($15) {
      $$lcssa12$i = $4;
     } else {
      $17 = $14;
      while(1) {
       $16 = (($17) + 8|0);
       $18 = HEAP32[$16>>2]|0;
       $19 = ($18|0)==($12|0);
       if (!($19)) {
        $$lcssa12$i = $17;
        break L11;
       }
       $20 = (($17) + 4|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($21|0)==($4|0);
       if ($22) {
        $$lcssa12$i = $4;
        break;
       } else {
        $17 = $21;
       }
      }
     }
    } while(0);
    $23 = ($$pn$i|0)==($$lcssa12$i|0);
    if (!($23)) {
     label = 11;
     break;
    }
   }
   if ((label|0) == 11) {
    label = 0;
    $24 = HEAP32[$$lcssa12$i>>2]|0;
    $25 = (($24) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$$pn$i>>2]|0;
    $28 = (($27) + 4|0);
    HEAP32[$28>>2] = $26;
    $29 = HEAP32[$$pn$i>>2]|0;
    $30 = HEAP32[$25>>2]|0;
    HEAP32[$30>>2] = $29;
    $32 = $$pn$i;
    while(1) {
     $31 = (($32) + 4|0);
     $33 = HEAP32[$31>>2]|0;
     $34 = HEAP32[$8>>2]|0;
     $35 = (($34) + -1)|0;
     HEAP32[$8>>2] = $35;
     __ZdlPv($32);
     $36 = ($33|0)==($$lcssa12$i|0);
     if ($36) {
      $$ph$be$i = $$lcssa12$i;
      break;
     } else {
      $32 = $33;
     }
    }
   }
   $37 = ($$ph$be$i|0)==($4|0);
   if ($37) {
    break;
   } else {
    $$pn$i = $$ph$be$i;
   }
  }
 }
 $38 = (($this) + 40|0);
 if ($1) {
  $48 = 0;
 } else {
  $39 = (($c) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  $48 = $40;
 }
 $41 = (($this) + 44|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==($38|0);
 if (!($43)) {
  $44 = (($this) + 48|0);
  $$pn$i17 = $42;
  while(1) {
   $45 = (($$pn$i17) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($48|0);
   $49 = (($$pn$i17) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==($38|0);
   while(1) {
    if (!($47)) {
     $$ph$be$i26 = $50;
     break;
    }
    L32: do {
     if ($51) {
      $$lcssa12$i23 = $38;
     } else {
      $53 = $50;
      while(1) {
       $52 = (($53) + 8|0);
       $54 = HEAP32[$52>>2]|0;
       $55 = ($54|0)==($48|0);
       if (!($55)) {
        $$lcssa12$i23 = $53;
        break L32;
       }
       $56 = (($53) + 4|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = ($57|0)==($38|0);
       if ($58) {
        $$lcssa12$i23 = $38;
        break;
       } else {
        $53 = $57;
       }
      }
     }
    } while(0);
    $59 = ($$pn$i17|0)==($$lcssa12$i23|0);
    if (!($59)) {
     label = 24;
     break;
    }
   }
   if ((label|0) == 24) {
    label = 0;
    $60 = HEAP32[$$lcssa12$i23>>2]|0;
    $61 = (($60) + 4|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = HEAP32[$$pn$i17>>2]|0;
    $64 = (($63) + 4|0);
    HEAP32[$64>>2] = $62;
    $65 = HEAP32[$$pn$i17>>2]|0;
    $66 = HEAP32[$61>>2]|0;
    HEAP32[$66>>2] = $65;
    $68 = $$pn$i17;
    while(1) {
     $67 = (($68) + 4|0);
     $69 = HEAP32[$67>>2]|0;
     $70 = HEAP32[$44>>2]|0;
     $71 = (($70) + -1)|0;
     HEAP32[$44>>2] = $71;
     __ZdlPv($68);
     $72 = ($69|0)==($$lcssa12$i23|0);
     if ($72) {
      $$ph$be$i26 = $$lcssa12$i23;
      break;
     } else {
      $68 = $69;
     }
    }
   }
   $73 = ($$ph$be$i26|0)==($38|0);
   if ($73) {
    break;
   } else {
    $$pn$i17 = $$ph$be$i26;
   }
  }
 }
 $74 = (($this) + 52|0);
 $75 = HEAP8[$74>>0]|0;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  $86 = (($this) + 4|0);
  $87 = (($this) + 8|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = ($88|0)==($86|0);
  if (!($89)) {
   $90 = (($this) + 12|0);
   $$pn$i30 = $88;
   while(1) {
    $91 = (($$pn$i30) + 8|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==($12|0);
    $94 = (($$pn$i30) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    if ($93) {
     $96 = ($95|0)==($86|0);
     if ($96) {
      while(1) {
       $97 = ($$pn$i30|0)==($86|0);
       if (!($97)) {
        $$lcssa12$i36$lcssa = $86;
        break;
       }
      }
     } else {
      $99 = $95;
      while(1) {
       $98 = (($99) + 8|0);
       $100 = HEAP32[$98>>2]|0;
       $101 = ($100|0)==($12|0);
       if ($101) {
        $102 = (($99) + 4|0);
        $103 = HEAP32[$102>>2]|0;
        $104 = ($103|0)==($86|0);
        if ($104) {
         $$lcssa12$i36$ph$us = $86;
        } else {
         $99 = $103;
         continue;
        }
       } else {
        $$lcssa12$i36$ph$us = $99;
       }
       $105 = ($$pn$i30|0)==($$lcssa12$i36$ph$us|0);
       if ($105) {
        $99 = $95;
       } else {
        $$lcssa12$i36$lcssa = $$lcssa12$i36$ph$us;
        break;
       }
      }
     }
     $106 = HEAP32[$$lcssa12$i36$lcssa>>2]|0;
     $107 = (($106) + 4|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = HEAP32[$$pn$i30>>2]|0;
     $110 = (($109) + 4|0);
     HEAP32[$110>>2] = $108;
     $111 = HEAP32[$$pn$i30>>2]|0;
     $112 = HEAP32[$107>>2]|0;
     HEAP32[$112>>2] = $111;
     $114 = $$pn$i30;
     while(1) {
      $113 = (($114) + 4|0);
      $115 = HEAP32[$113>>2]|0;
      $116 = HEAP32[$90>>2]|0;
      $117 = (($116) + -1)|0;
      HEAP32[$90>>2] = $117;
      __ZdlPv($114);
      $118 = ($115|0)==($$lcssa12$i36$lcssa|0);
      if ($118) {
       $$ph$be$i39 = $$lcssa12$i36$lcssa;
       break;
      } else {
       $114 = $115;
      }
     }
    } else {
     $$ph$be$i39 = $95;
    }
    $119 = ($$ph$be$i39|0)==($86|0);
    if ($119) {
     break;
    } else {
     $$pn$i30 = $$ph$be$i39;
    }
   }
  }
  $120 = (($this) + 16|0);
  $121 = (($this) + 20|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = ($122|0)==($120|0);
  if (!($123)) {
   $124 = (($this) + 24|0);
   $$pn$i4 = $122;
   while(1) {
    $125 = (($$pn$i4) + 8|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ($126|0)==($12|0);
    $128 = (($$pn$i4) + 4|0);
    $129 = HEAP32[$128>>2]|0;
    if ($127) {
     $130 = ($129|0)==($120|0);
     if ($130) {
      while(1) {
       $131 = ($$pn$i4|0)==($120|0);
       if (!($131)) {
        $$lcssa12$i10$lcssa = $120;
        break;
       }
      }
     } else {
      $133 = $129;
      while(1) {
       $132 = (($133) + 8|0);
       $134 = HEAP32[$132>>2]|0;
       $135 = ($134|0)==($12|0);
       if ($135) {
        $136 = (($133) + 4|0);
        $137 = HEAP32[$136>>2]|0;
        $138 = ($137|0)==($120|0);
        if ($138) {
         $$lcssa12$i10$ph$us = $120;
        } else {
         $133 = $137;
         continue;
        }
       } else {
        $$lcssa12$i10$ph$us = $133;
       }
       $139 = ($$pn$i4|0)==($$lcssa12$i10$ph$us|0);
       if ($139) {
        $133 = $129;
       } else {
        $$lcssa12$i10$lcssa = $$lcssa12$i10$ph$us;
        break;
       }
      }
     }
     $140 = HEAP32[$$lcssa12$i10$lcssa>>2]|0;
     $141 = (($140) + 4|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = HEAP32[$$pn$i4>>2]|0;
     $144 = (($143) + 4|0);
     HEAP32[$144>>2] = $142;
     $145 = HEAP32[$$pn$i4>>2]|0;
     $146 = HEAP32[$141>>2]|0;
     HEAP32[$146>>2] = $145;
     $148 = $$pn$i4;
     while(1) {
      $147 = (($148) + 4|0);
      $149 = HEAP32[$147>>2]|0;
      $150 = HEAP32[$124>>2]|0;
      $151 = (($150) + -1)|0;
      HEAP32[$124>>2] = $151;
      __ZdlPv($148);
      $152 = ($149|0)==($$lcssa12$i10$lcssa|0);
      if ($152) {
       $$ph$be$i13 = $$lcssa12$i10$lcssa;
       break;
      } else {
       $148 = $149;
      }
     }
    } else {
     $$ph$be$i13 = $129;
    }
    $153 = ($$ph$be$i13|0)==($120|0);
    if ($153) {
     break;
    } else {
     $$pn$i4 = $$ph$be$i13;
    }
   }
  }
 } else {
  $77 = (__Znwj(12)|0);
  $78 = (($77) + 8|0);
  HEAP32[$78>>2] = $12;
  $79 = HEAP32[$38>>2]|0;
  $80 = (($79) + 4|0);
  HEAP32[$80>>2] = $77;
  $81 = HEAP32[$38>>2]|0;
  HEAP32[$77>>2] = $81;
  HEAP32[$38>>2] = $77;
  $82 = (($77) + 4|0);
  HEAP32[$82>>2] = $38;
  $83 = (($this) + 48|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + 1)|0;
  HEAP32[$83>>2] = $85;
 }
 $154 = HEAP32[$this>>2]|0;
 $155 = ($154|0)==(0);
 if ($155) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $154;
  $156 = HEAP32[560624>>2]|0;
  $157 = ($156|0)==(0|0);
  if ($157) {
   label = 60;
  } else {
   $158 = (($156) + 36|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($156) + 4|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = ($159|0)==($161|0);
   do {
    if ($162) {
     $163 = (($156) + 28|0);
     $164 = HEAP32[$163>>2]|0;
     $165 = (($156) + 32|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = (($164) + ($166<<3)|0);
     $183 = $167;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$156,$0);
     $168 = HEAP32[$pos$i$i$i$i>>2]|0;
     $169 = ($168|0)==(-1);
     $170 = (($156) + 28|0);
     $171 = HEAP32[$170>>2]|0;
     if ($169) {
      $172 = (($156) + 32|0);
      $173 = HEAP32[$172>>2]|0;
      $174 = (($171) + ($173<<3)|0);
      $183 = $174;
      break;
     } else {
      $175 = (($171) + ($168<<3)|0);
      $183 = $175;
      break;
     }
    }
   } while(0);
   $176 = HEAP32[560624>>2]|0;
   $177 = (($176) + 28|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = (($176) + 32|0);
   $180 = HEAP32[$179>>2]|0;
   $181 = (($178) + ($180<<3)|0);
   $182 = ($183|0)==($181|0);
   if ($182) {
    label = 60;
   } else {
    $184 = (($183) + 4|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ($185|0)==(0|0);
    if ($186) {
     label = 60;
    } else {
     $temp$0$i = $185;
    }
   }
  }
  if ((label|0) == 60) {
   $187 = HEAP32[$this>>2]|0;
   $188 = (__Z31ReadObjectFromPersistentManageri($187)|0);
   $temp$0$i = $188;
  }
  $$0$i = $temp$0$i;
 }
 $189 = ($$0$i|0)==($c|0);
 if (!($189)) {
  STACKTOP = sp;return;
 }
 $190 = (($this) + 12|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = ($191|0)==(0);
 if ($192) {
  HEAP32[$this>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $193 = (($this) + 8|0);
  $194 = HEAP32[$193>>2]|0;
  $195 = (($194) + 8|0);
  $196 = HEAP32[$195>>2]|0;
  HEAP32[$this>>2] = $196;
  STACKTOP = sp;return;
 }
}
function __ZN13RenderManager13SetWindowRectERK5RectTIfE($this,$r) {
 $this = $this|0;
 $r = $r|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 56|0);
 ;HEAP32[$1+0>>2]=HEAP32[$r+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$r+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$r+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$r+12>>2]|0;
 $2 = (($this) + 4|0);
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $7 = $4;
 while(1) {
  $6 = (($7) + 8|0);
  $8 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $8;
  $9 = HEAP32[560624>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   label = 11;
  } else {
   $11 = (($9) + 36|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($9) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12|0)==($14|0);
   do {
    if ($15) {
     $16 = (($9) + 28|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($9) + 32|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($17) + ($19<<3)|0);
     $36 = $20;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$9,$0);
     $21 = HEAP32[$pos$i$i$i$i>>2]|0;
     $22 = ($21|0)==(-1);
     $23 = (($9) + 28|0);
     $24 = HEAP32[$23>>2]|0;
     if ($22) {
      $25 = (($9) + 32|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + ($26<<3)|0);
      $36 = $27;
      break;
     } else {
      $28 = (($24) + ($21<<3)|0);
      $36 = $28;
      break;
     }
    }
   } while(0);
   $29 = HEAP32[560624>>2]|0;
   $30 = (($29) + 28|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 32|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + ($33<<3)|0);
   $35 = ($36|0)==($34|0);
   if ($35) {
    label = 11;
   } else {
    $37 = (($36) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)==(0|0);
    if ($39) {
     label = 11;
    } else {
     $temp$0$i = $38;
    }
   }
  }
  if ((label|0) == 11) {
   label = 0;
   $40 = HEAP32[$6>>2]|0;
   $41 = (__Z31ReadObjectFromPersistentManageri($40)|0);
   $temp$0$i = $41;
  }
  __ZN6Camera20WindowSizeHasChangedEv($temp$0$i);
  $42 = (($7) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==($2|0);
  if ($44) {
   break;
  } else {
   $7 = $43;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13RenderManager18UpdateAllRenderersEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetIParticleSystemv()|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (__Z18GetIParticleSystemv()|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095]($2);
 }
 __ZN8Renderer26UpdateAllRenderersInternalEv();
 STACKTOP = sp;return;
}
function __Z16GetRenderManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[575120>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z19GetRenderManagerPtrv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[575120>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN13RenderManager15InitializeClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(108)|0);
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = $1;
 $2 = (($0) + 8|0);
 HEAP32[$2>>2] = $1;
 $3 = (($0) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($0) + 16|0);
 HEAP32[$4>>2] = $4;
 $5 = (($0) + 20|0);
 HEAP32[$5>>2] = $4;
 $6 = (($0) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($0) + 28|0);
 HEAP32[$7>>2] = $7;
 $8 = (($0) + 32|0);
 HEAP32[$8>>2] = $7;
 $9 = (($0) + 36|0);
 HEAP32[$9>>2] = 0;
 $10 = (($0) + 40|0);
 HEAP32[$10>>2] = $10;
 $11 = (($0) + 44|0);
 HEAP32[$11>>2] = $10;
 $12 = (($0) + 48|0);
 HEAP32[$12>>2] = 0;
 $13 = (($0) + 52|0);
 HEAP8[$13>>0] = 0;
 $14 = (($0) + 56|0);
 $15 = (($0) + 92|0);
 HEAP32[$15>>2] = 0;
 $16 = (($0) + 96|0);
 HEAP32[$16>>2] = 0;
 $17 = (($0) + 88|0);
 ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;HEAP32[$14+16>>2]=0|0;HEAP32[$14+20>>2]=0|0;
 HEAP32[$17>>2] = $15;
 $18 = (($0) + 100|0);
 $19 = (($0) + 104|0);
 HEAP32[$18>>2] = $18;
 HEAP32[$19>>2] = $18;
 HEAPF32[$14>>2] = Math_fround(0.0);
 $20 = (($0) + 60|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($0) + 64|0);
 HEAPF32[$21>>2] = Math_fround(128.0);
 $22 = (($0) + 68|0);
 HEAPF32[$22>>2] = Math_fround(128.0);
 $23 = (($0) + 72|0);
 HEAP32[$23>>2] = 0;
 $24 = (($0) + 76|0);
 HEAP32[$24>>2] = 0;
 $25 = (($0) + 80|0);
 HEAP32[$25>>2] = 128;
 $26 = (($0) + 84|0);
 HEAP32[$26>>2] = 128;
 HEAP32[$0>>2] = 0;
 HEAP32[575120>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN13RenderManager12CleanupClassEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[575120>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[575120>>2] = 0;
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3425,($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 }
 __ZdlPv($0);
 HEAP32[575120>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIiP10RenderableEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiP10RenderableEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiP10RenderableEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __Z17SetupObjectMatrixRK10Matrix4x4fi($m,$transformType) {
 $m = $m|0;
 $transformType = $transformType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($0,$m,$transformType);
 STACKTOP = sp;return;
}
function __Z23GetCurrentRenderOptionsv() {
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetQualitySettingsv()|0);
 $1 = (($0) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*96)|0)|0) + 77|0);
 $6 = HEAP8[$5>>0]|0;
 $$ = $6&255;
 STACKTOP = sp;return ($$|0);
}
function __Z21CheckShouldRenderPassiRN5Unity8MaterialE($pass,$material) {
 $pass = $pass|0;
 $material = $material|0;
 var $$$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetQualitySettingsv()|0);
 $1 = (($0) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*96)|0)|0) + 77|0);
 $6 = HEAP8[$5>>0]|0;
 $$$i = $6&255;
 $7 = (__ZN5Unity8Material9GetShaderEv($material)|0);
 $8 = (($7) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$9>>2]|0;
 $13 = (($12) + ($11<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($pass<<2)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 660|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & $$$i;
 $21 = ($20|0)==($19|0);
 STACKTOP = sp;return ($21|0);
}
function __Z28CalculateSubShaderIndexToUseP6ShaderS0_i($shader,$replacementShader,$replacementTagID) {
 $shader = $shader|0;
 $replacementShader = $replacementShader|0;
 $replacementTagID = $replacementTagID|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $usedSubshaderIndex$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($replacementShader|0)==(0|0);
 if ($0) {
  $8 = (__ZNK6Shader23GetActiveSubShaderIndexEv($shader)|0);
  $usedSubshaderIndex$0 = $8;
 } else {
  $1 = ($replacementTagID|0)>(-1);
  if ($1) {
   $2 = (($shader) + 52|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (__ZNK9ShaderLab9IntShader6GetTagEib($3,$replacementTagID,1)|0);
   $5 = ($4|0)<(0);
   if ($5) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $6 = (__ZNK6Shader24GetSubShaderWithTagValueEii($replacementShader,$replacementTagID,$4)|0);
   $7 = ($6|0)==(-1);
   if ($7) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $usedSubshaderIndex$0 = $6;
   }
  } else {
   $usedSubshaderIndex$0 = 0;
  }
 }
 $$0 = $usedSubshaderIndex$0;
 STACKTOP = sp;return ($$0|0);
}
function __Z20SetupObjectLightmapsRK16LightmapSettingsRK15LightmapIndices($lightmapper,$lightmapIndex) {
 $lightmapper = $lightmapper|0;
 $lightmapIndex = $lightmapIndex|0;
 var $$0$i$i = 0, $$byval_copy1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP16[$lightmapIndex>>1]|0;
 $3 = ($2<<16>>16)!=(255);
 if ($3) {
  label = 3;
 } else {
  $4 = (($lightmapIndex) + 2|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = ($5<<16>>16)==(255);
  if ($6) {
   $29 = HEAP32[652824>>2]|0;
   $30 = (($29) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31 & -229377;
   $33 = $32 | 32768;
   HEAP32[$30>>2] = $33;
   $55 = $29;$57 = $33;
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $7 = (($lightmapper) + 84|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(2);
  do {
   if ($9) {
    $10 = (__ZNK16LightmapSettings22GetLightmapsModeLegacyEv($lightmapper)|0);
    $11 = ($10|0)==(2);
    if ($11) {
     label = 6;
    } else {
     label = 8;
    }
   } else {
    $12 = (($lightmapper) + 92|0);
    $13 = HEAP32[$12>>2]|0;
    if ((($13|0) == 1)) {
     label = 6;
     break;
    } else if (!((($13|0) == 2))) {
     label = 8;
     break;
    }
    $19 = HEAP32[652824>>2]|0;
    $20 = (($19) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 & -229377;
    $23 = $22 | 131072;
    HEAP32[$20>>2] = $23;
    $44 = $19;$46 = $23;
   }
  } while(0);
  if ((label|0) == 6) {
   $14 = HEAP32[652824>>2]|0;
   $15 = (($14) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16 & -229377;
   $18 = $17 | 65536;
   HEAP32[$15>>2] = $18;
   $44 = $14;$46 = $18;
  }
  else if ((label|0) == 8) {
   $24 = HEAP32[652824>>2]|0;
   $25 = (($24) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = $26 & -229377;
   $28 = $27 | 32768;
   HEAP32[$25>>2] = $28;
   $44 = $24;$46 = $28;
  }
  if ($3) {
   $34 = HEAP16[$lightmapIndex>>1]|0;
   $35 = $34&65535;
   $36 = (($lightmapper) + 28|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)>($35|0);
   if ($38) {
    $39 = (($lightmapper) + 24|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($40) + ($35<<3)|0);
    $$0$i$i = $41;
   } else {
    $42 = (($lightmapper) + 40|0);
    $$0$i$i = $42;
   }
   $43 = (($44) + 4|0);
   $45 = $46 & -24577;
   $47 = $45 | 16384;
   HEAP32[$43>>2] = $47;
   $48 = (__Z12GetGfxDevicev()|0);
   $49 = (($48) + 4388|0);
   $50 = HEAP32[$$0$i$i>>2]|0;
   HEAP32[$0>>2] = $50;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($49,$$byval_copy1,2,0,0);
   $51 = (($48) + 4452|0);
   $52 = (($$0$i$i) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   HEAP32[$1>>2] = $53;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($51,$$byval_copy1,2,0,0);
   $$pre = HEAP32[652824>>2]|0;
   $$phi$trans$insert = (($$pre) + 4|0);
   $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
   $60 = $$pre;$62 = $$pre1;
   $59 = (($60) + 4|0);
   $61 = $62 & -786433;
   $63 = $61 | 262144;
   HEAP32[$59>>2] = $63;
   STACKTOP = sp;return;
  } else {
   $55 = $44;$57 = $46;
  }
 }
 $54 = (($55) + 4|0);
 $56 = $57 & -24577;
 $58 = $56 | 8192;
 HEAP32[$54>>2] = $58;
 $60 = $55;$62 = $58;
 $59 = (($60) + 4|0);
 $61 = $62 & -786433;
 $63 = $61 | 262144;
 HEAP32[$59>>2] = $63;
 STACKTOP = sp;return;
}
function __Z14SetupLightmapsRK16LightmapSettings($lightmapper) {
 $lightmapper = $lightmapper|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $hdrDecode = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $hdrDecode = sp;
 __ZNK16LightmapSettings23GetLightmapDecodeValuesEv($hdrDecode,$lightmapper);
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($0) + 2148|0);
 ;HEAP32[$1+0>>2]=HEAP32[$hdrDecode+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$hdrDecode+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$hdrDecode+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$hdrDecode+12>>2]|0;
 $2 = (($0) + 2164|0);
 ;HEAP32[$2+0>>2]=HEAP32[$hdrDecode+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$hdrDecode+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$hdrDecode+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$hdrDecode+12>>2]|0;
 $3 = (($0) + 2180|0);
 ;HEAP32[$3+0>>2]=HEAP32[$hdrDecode+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$hdrDecode+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$hdrDecode+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$hdrDecode+12>>2]|0;
 $4 = (($0) + 2196|0);
 ;HEAP32[$4+0>>2]=HEAP32[$hdrDecode+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$hdrDecode+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$hdrDecode+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$hdrDecode+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN14RenderSettings5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 424|0);
 HEAPF32[$0>>2] = Math_fround(0.5);
 $1 = (($this) + 428|0);
 HEAPF32[$1>>2] = Math_fround(0.5);
 $2 = (($this) + 432|0);
 HEAPF32[$2>>2] = Math_fround(0.5);
 $3 = (($this) + 436|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 440|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 444|0);
 HEAPF32[$5>>2] = Math_fround(300.0);
 $6 = (($this) + 448|0);
 HEAPF32[$6>>2] = Math_fround(0.00999999977648258209228);
 $7 = (($this) + 416|0);
 HEAP8[$7>>0] = 0;
 $8 = (($this) + 420|0);
 HEAP32[$8>>2] = 3;
 $9 = (($this) + 464|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 24|0);
 HEAPF32[$10>>2] = Math_fround(0.211999997496604919434);
 $11 = (($this) + 28|0);
 HEAPF32[$11>>2] = Math_fround(0.226999998092651367188);
 $12 = (($this) + 32|0);
 HEAPF32[$12>>2] = Math_fround(0.259000003337860107422);
 $13 = (($this) + 36|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($this) + 40|0);
 HEAPF32[$14>>2] = Math_fround(0.114000000059604644775);
 $15 = (($this) + 44|0);
 HEAPF32[$15>>2] = Math_fround(0.125);
 $16 = (($this) + 48|0);
 HEAPF32[$16>>2] = Math_fround(0.133000001311302185059);
 $17 = (($this) + 52|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($this) + 56|0);
 HEAPF32[$18>>2] = Math_fround(0.0469999983906745910645);
 $19 = (($this) + 60|0);
 HEAPF32[$19>>2] = Math_fround(0.0430000014603137969971);
 $20 = (($this) + 64|0);
 HEAPF32[$20>>2] = Math_fround(0.0350000001490116119385);
 $21 = (($this) + 68|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 288|0);
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($this) + 72|0);
 $24 = (($this) + 292|0);
 _memset(($23|0),0,216)|0;
 HEAP32[$24>>2] = 1;
 __ZN14RenderSettings23UpdateFinalAmbientProbeEv($this);
 $25 = (($this) + 408|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($this) + 412|0);
 HEAPF32[$26>>2] = Math_fround(3.0);
 $27 = (($this) + 404|0);
 HEAPF32[$27>>2] = Math_fround(0.5);
 $28 = (($this) + 472|0);
 HEAP32[$28>>2] = 1;
 $29 = (($this) + 468|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings23UpdateFinalAmbientProbeEv($this) {
 $this = $this|0;
 var $$ = Math_fround(0), $$0$i$i$i = Math_fround(0), $$0$i$i$i1 = Math_fround(0), $$0$i$i$i123 = Math_fround(0), $$0$i$i$i8 = Math_fround(0), $$0$i1$i$i525 = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$i3$i$i10 = Math_fround(0), $$0$i3$i$i3 = Math_fround(0), $$0$i3$i$i324 = Math_fround(0), $$26 = Math_fround(0), $$27 = Math_fround(0), $$28 = Math_fround(0), $$29 = Math_fround(0), $$30 = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert32 = 0, $$phi$trans$insert34 = 0, $$pre = Math_fround(0), $$pre33 = Math_fround(0);
 var $$pre35 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = 0;
 var $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0);
 var $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $downB = 0, $downG = 0, $downR = 0, $exitcond = 0, $i$031 = 0, $upB = 0;
 var $upG = 0, $upR = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $upR = sp + 180|0;
 $upG = sp;
 $upB = sp + 36|0;
 $downR = sp + 72|0;
 $downG = sp + 108|0;
 $downB = sp + 144|0;
 $0 = (($this) + 292|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($this) + 296|0);
  $4 = (__Z19GetActiveColorSpacev()|0);
  $5 = ($4|0)==(1);
  $6 = (($this) + 72|0);
  $7 = (($this) + 180|0);
  $8 = $5 ? $6 : $7;
  dest=$3+0|0; src=$8+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $9 = (__Z19GetActiveColorSpacev()|0);
 $10 = ($9|0)==(1);
 $11 = (($this) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 do {
  if ($10) {
   $13 = !($12 <= Math_fround(0.0404499992728233337402));
   do {
    if ($13) {
     $15 = $12 < Math_fround(1.0);
     if ($15) {
      $16 = Math_fround($12 + Math_fround(0.054999999701976776123));
      $17 = Math_fround($16 / Math_fround(1.05499994754791259766));
      $18 = (Math_fround(+(Math_pow((+$17),2.40000009536743164063))));
      $$0$i$i$i = $18;
      break;
     } else {
      $19 = (Math_fround(+(Math_pow((+$12),2.40000009536743164063))));
      $$0$i$i$i = $19;
      break;
     }
    } else {
     $14 = Math_fround($12 / Math_fround(12.9200000762939453125));
     $$0$i$i$i = $14;
    }
   } while(0);
   $20 = (($this) + 28|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = !($21 <= Math_fround(0.0404499992728233337402));
   do {
    if ($22) {
     $24 = $21 < Math_fround(1.0);
     if ($24) {
      $25 = Math_fround($21 + Math_fround(0.054999999701976776123));
      $26 = Math_fround($25 / Math_fround(1.05499994754791259766));
      $27 = (Math_fround(+(Math_pow((+$26),2.40000009536743164063))));
      $$0$i3$i$i = $27;
      break;
     } else {
      $28 = (Math_fround(+(Math_pow((+$21),2.40000009536743164063))));
      $$0$i3$i$i = $28;
      break;
     }
    } else {
     $23 = Math_fround($21 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i = $23;
    }
   } while(0);
   $29 = (($this) + 32|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = !($30 <= Math_fround(0.0404499992728233337402));
   if (!($31)) {
    $32 = Math_fround($30 / Math_fround(12.9200000762939453125));
    $45 = $$0$i$i$i;$47 = $$0$i3$i$i;$49 = $32;
    break;
   }
   $33 = $30 < Math_fround(1.0);
   if ($33) {
    $34 = Math_fround($30 + Math_fround(0.054999999701976776123));
    $35 = Math_fround($34 / Math_fround(1.05499994754791259766));
    $36 = (Math_fround(+(Math_pow((+$35),2.40000009536743164063))));
    $45 = $$0$i$i$i;$47 = $$0$i3$i$i;$49 = $36;
    break;
   } else {
    $37 = (Math_fround(+(Math_pow((+$30),2.40000009536743164063))));
    $45 = $$0$i$i$i;$47 = $$0$i3$i$i;$49 = $37;
    break;
   }
  } else {
   $38 = (($this) + 28|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = (($this) + 32|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $45 = $12;$47 = $39;$49 = $41;
  }
 } while(0);
 $42 = (($this) + 288|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($45 * $43);
 $46 = Math_fround($47 * $43);
 $48 = Math_fround($49 * $43);
 $50 = (__Z19GetActiveColorSpacev()|0);
 $51 = ($50|0)==(1);
 $52 = (($this) + 40|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 do {
  if ($51) {
   $54 = !($53 <= Math_fround(0.0404499992728233337402));
   do {
    if ($54) {
     $56 = $53 < Math_fround(1.0);
     if ($56) {
      $57 = Math_fround($53 + Math_fround(0.054999999701976776123));
      $58 = Math_fround($57 / Math_fround(1.05499994754791259766));
      $59 = (Math_fround(+(Math_pow((+$58),2.40000009536743164063))));
      $$0$i$i$i8 = $59;
      break;
     } else {
      $60 = (Math_fround(+(Math_pow((+$53),2.40000009536743164063))));
      $$0$i$i$i8 = $60;
      break;
     }
    } else {
     $55 = Math_fround($53 / Math_fround(12.9200000762939453125));
     $$0$i$i$i8 = $55;
    }
   } while(0);
   $61 = (($this) + 44|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = !($62 <= Math_fround(0.0404499992728233337402));
   do {
    if ($63) {
     $65 = $62 < Math_fround(1.0);
     if ($65) {
      $66 = Math_fround($62 + Math_fround(0.054999999701976776123));
      $67 = Math_fround($66 / Math_fround(1.05499994754791259766));
      $68 = (Math_fround(+(Math_pow((+$67),2.40000009536743164063))));
      $$0$i3$i$i10 = $68;
      break;
     } else {
      $69 = (Math_fround(+(Math_pow((+$62),2.40000009536743164063))));
      $$0$i3$i$i10 = $69;
      break;
     }
    } else {
     $64 = Math_fround($62 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i10 = $64;
    }
   } while(0);
   $70 = (($this) + 48|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = !($71 <= Math_fround(0.0404499992728233337402));
   if (!($72)) {
    $73 = Math_fround($71 / Math_fround(12.9200000762939453125));
    $85 = $$0$i$i$i8;$87 = $$0$i3$i$i10;$89 = $73;
    break;
   }
   $74 = $71 < Math_fround(1.0);
   if ($74) {
    $75 = Math_fround($71 + Math_fround(0.054999999701976776123));
    $76 = Math_fround($75 / Math_fround(1.05499994754791259766));
    $77 = (Math_fround(+(Math_pow((+$76),2.40000009536743164063))));
    $85 = $$0$i$i$i8;$87 = $$0$i3$i$i10;$89 = $77;
    break;
   } else {
    $78 = (Math_fround(+(Math_pow((+$71),2.40000009536743164063))));
    $85 = $$0$i$i$i8;$87 = $$0$i3$i$i10;$89 = $78;
    break;
   }
  } else {
   $79 = (($this) + 44|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = (($this) + 48|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $85 = $53;$87 = $80;$89 = $82;
  }
 } while(0);
 $83 = Math_fround(HEAPF32[$42>>2]);
 $84 = Math_fround($85 * $83);
 $86 = Math_fround($87 * $83);
 $88 = Math_fround($89 * $83);
 $90 = (__Z19GetActiveColorSpacev()|0);
 $91 = ($90|0)==(1);
 $92 = (($this) + 56|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 do {
  if ($91) {
   $94 = !($93 <= Math_fround(0.0404499992728233337402));
   do {
    if ($94) {
     $96 = $93 < Math_fround(1.0);
     if ($96) {
      $97 = Math_fround($93 + Math_fround(0.054999999701976776123));
      $98 = Math_fround($97 / Math_fround(1.05499994754791259766));
      $99 = (Math_fround(+(Math_pow((+$98),2.40000009536743164063))));
      $$0$i$i$i1 = $99;
      break;
     } else {
      $100 = (Math_fround(+(Math_pow((+$93),2.40000009536743164063))));
      $$0$i$i$i1 = $100;
      break;
     }
    } else {
     $95 = Math_fround($93 / Math_fround(12.9200000762939453125));
     $$0$i$i$i1 = $95;
    }
   } while(0);
   $101 = (($this) + 60|0);
   $102 = Math_fround(HEAPF32[$101>>2]);
   $103 = !($102 <= Math_fround(0.0404499992728233337402));
   do {
    if ($103) {
     $105 = $102 < Math_fround(1.0);
     if ($105) {
      $106 = Math_fround($102 + Math_fround(0.054999999701976776123));
      $107 = Math_fround($106 / Math_fround(1.05499994754791259766));
      $108 = (Math_fround(+(Math_pow((+$107),2.40000009536743164063))));
      $$0$i3$i$i3 = $108;
      break;
     } else {
      $109 = (Math_fround(+(Math_pow((+$102),2.40000009536743164063))));
      $$0$i3$i$i3 = $109;
      break;
     }
    } else {
     $104 = Math_fround($102 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i3 = $104;
    }
   } while(0);
   $110 = (($this) + 64|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = !($111 <= Math_fround(0.0404499992728233337402));
   if (!($112)) {
    $113 = Math_fround($111 / Math_fround(12.9200000762939453125));
    $$0$i$i$i123 = $$0$i$i$i1;$$0$i1$i$i525 = $113;$$0$i3$i$i324 = $$0$i3$i$i3;
    break;
   }
   $114 = $111 < Math_fround(1.0);
   if ($114) {
    $115 = Math_fround($111 + Math_fround(0.054999999701976776123));
    $116 = Math_fround($115 / Math_fround(1.05499994754791259766));
    $117 = (Math_fround(+(Math_pow((+$116),2.40000009536743164063))));
    $$0$i$i$i123 = $$0$i$i$i1;$$0$i1$i$i525 = $117;$$0$i3$i$i324 = $$0$i3$i$i3;
    break;
   } else {
    $118 = (Math_fround(+(Math_pow((+$111),2.40000009536743164063))));
    $$0$i$i$i123 = $$0$i$i$i1;$$0$i1$i$i525 = $118;$$0$i3$i$i324 = $$0$i3$i$i3;
    break;
   }
  } else {
   $119 = (($this) + 60|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = (($this) + 64|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $$0$i$i$i123 = $93;$$0$i1$i$i525 = $122;$$0$i3$i$i324 = $120;
  }
 } while(0);
 $123 = Math_fround(HEAPF32[$42>>2]);
 $124 = Math_fround($$0$i$i$i123 * $123);
 $125 = Math_fround($$0$i3$i$i324 * $123);
 $126 = Math_fround($$0$i1$i$i525 * $123);
 $127 = HEAP32[$0>>2]|0;
 $128 = ($127|0)==(3);
 $$ = $128 ? $48 : $88;
 $$26 = $128 ? $46 : $86;
 $$27 = $128 ? $44 : $84;
 $$28 = $128 ? $48 : $126;
 $$29 = $128 ? $46 : $125;
 $$30 = $128 ? $44 : $124;
 $129 = (($this) + 296|0);
 dest=$129+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $130 = Math_fround($$27 * Math_fround(3.54490780830383300781));
 HEAPF32[$129>>2] = $130;
 $131 = Math_fround($$26 * Math_fround(3.54490780830383300781));
 $132 = (($129) + 4|0);
 HEAPF32[$132>>2] = $131;
 $133 = Math_fround($$ * Math_fround(3.54490780830383300781));
 $134 = (($129) + 8|0);
 HEAPF32[$134>>2] = $133;
 $135 = Math_fround($44 - $$27);
 $136 = Math_fround($46 - $$26);
 $137 = Math_fround($48 - $$);
 $138 = Math_fround($135 * Math_fround(2.95679306983947753906));
 $139 = Math_fround($136 * Math_fround(2.95679306983947753906));
 $140 = Math_fround($137 * Math_fround(2.95679306983947753906));
 $141 = Math_fround($138 * Math_fround(0.282094806432723999023));
 HEAPF32[$upR>>2] = $141;
 $142 = Math_fround($139 * Math_fround(0.282094806432723999023));
 HEAPF32[$upG>>2] = $142;
 $143 = Math_fround($140 * Math_fround(0.282094806432723999023));
 HEAPF32[$upB>>2] = $143;
 $144 = Math_fround($138 * Math_fround(-0.488602519035339355469));
 $145 = (($upR) + 4|0);
 HEAPF32[$145>>2] = $144;
 $146 = Math_fround($139 * Math_fround(-0.488602519035339355469));
 $147 = (($upG) + 4|0);
 HEAPF32[$147>>2] = $146;
 $148 = Math_fround($140 * Math_fround(-0.488602519035339355469));
 $149 = (($upB) + 4|0);
 HEAPF32[$149>>2] = $148;
 $150 = Math_fround($138 * Math_fround(0.0));
 $151 = (($upR) + 8|0);
 HEAPF32[$151>>2] = $150;
 $152 = Math_fround($139 * Math_fround(0.0));
 $153 = (($upG) + 8|0);
 HEAPF32[$153>>2] = $152;
 $154 = Math_fround($140 * Math_fround(0.0));
 $155 = (($upB) + 8|0);
 HEAPF32[$155>>2] = $154;
 $156 = Math_fround($138 * Math_fround(-0.0));
 $157 = (($upR) + 12|0);
 HEAPF32[$157>>2] = $156;
 $158 = Math_fround($139 * Math_fround(-0.0));
 $159 = (($upG) + 12|0);
 HEAPF32[$159>>2] = $158;
 $160 = Math_fround($140 * Math_fround(-0.0));
 $161 = (($upB) + 12|0);
 HEAPF32[$161>>2] = $160;
 $162 = (($upR) + 16|0);
 HEAPF32[$162>>2] = $150;
 $163 = (($upG) + 16|0);
 HEAPF32[$163>>2] = $152;
 $164 = (($upB) + 16|0);
 HEAPF32[$164>>2] = $154;
 $165 = (($upR) + 20|0);
 HEAPF32[$165>>2] = $156;
 $166 = (($upG) + 20|0);
 HEAPF32[$166>>2] = $158;
 $167 = (($upB) + 20|0);
 HEAPF32[$167>>2] = $160;
 $168 = Math_fround($138 * Math_fround(-0.315391570329666137695));
 $169 = (($upR) + 24|0);
 HEAPF32[$169>>2] = $168;
 $170 = Math_fround($139 * Math_fround(-0.315391570329666137695));
 $171 = (($upG) + 24|0);
 HEAPF32[$171>>2] = $170;
 $172 = Math_fround($140 * Math_fround(-0.315391570329666137695));
 $173 = (($upB) + 24|0);
 HEAPF32[$173>>2] = $172;
 $174 = (($upR) + 28|0);
 HEAPF32[$174>>2] = $156;
 $175 = (($upG) + 28|0);
 HEAPF32[$175>>2] = $158;
 $176 = (($upB) + 28|0);
 HEAPF32[$176>>2] = $160;
 $177 = Math_fround($138 * Math_fround(-0.546274244785308837891));
 $178 = (($upR) + 32|0);
 HEAPF32[$178>>2] = $177;
 $179 = Math_fround($139 * Math_fround(-0.546274244785308837891));
 $180 = (($upG) + 32|0);
 HEAPF32[$180>>2] = $179;
 $181 = Math_fround($140 * Math_fround(-0.546274244785308837891));
 $182 = (($upB) + 32|0);
 HEAPF32[$182>>2] = $181;
 $183 = Math_fround($$30 - $$27);
 $184 = Math_fround($$29 - $$26);
 $185 = Math_fround($$28 - $$);
 $186 = Math_fround($183 * Math_fround(2.95679306983947753906));
 $187 = Math_fround($184 * Math_fround(2.95679306983947753906));
 $188 = Math_fround($185 * Math_fround(2.95679306983947753906));
 $189 = Math_fround($186 * Math_fround(0.282094806432723999023));
 HEAPF32[$downR>>2] = $189;
 $190 = Math_fround($187 * Math_fround(0.282094806432723999023));
 HEAPF32[$downG>>2] = $190;
 $191 = Math_fround($188 * Math_fround(0.282094806432723999023));
 HEAPF32[$downB>>2] = $191;
 $192 = Math_fround($186 * Math_fround(0.488602519035339355469));
 $193 = (($downR) + 4|0);
 HEAPF32[$193>>2] = $192;
 $194 = Math_fround($187 * Math_fround(0.488602519035339355469));
 $195 = (($downG) + 4|0);
 HEAPF32[$195>>2] = $194;
 $196 = Math_fround($188 * Math_fround(0.488602519035339355469));
 $197 = (($downB) + 4|0);
 HEAPF32[$197>>2] = $196;
 $198 = Math_fround($186 * Math_fround(0.0));
 $199 = (($downR) + 8|0);
 HEAPF32[$199>>2] = $198;
 $200 = Math_fround($187 * Math_fround(0.0));
 $201 = (($downG) + 8|0);
 HEAPF32[$201>>2] = $200;
 $202 = Math_fround($188 * Math_fround(0.0));
 $203 = (($downB) + 8|0);
 HEAPF32[$203>>2] = $202;
 $204 = Math_fround($186 * Math_fround(-0.0));
 $205 = (($downR) + 12|0);
 HEAPF32[$205>>2] = $204;
 $206 = Math_fround($187 * Math_fround(-0.0));
 $207 = (($downG) + 12|0);
 HEAPF32[$207>>2] = $206;
 $208 = Math_fround($188 * Math_fround(-0.0));
 $209 = (($downB) + 12|0);
 HEAPF32[$209>>2] = $208;
 $210 = (($downR) + 16|0);
 HEAPF32[$210>>2] = $204;
 $211 = (($downG) + 16|0);
 HEAPF32[$211>>2] = $206;
 $212 = (($downB) + 16|0);
 HEAPF32[$212>>2] = $208;
 $213 = (($downR) + 20|0);
 HEAPF32[$213>>2] = $198;
 $214 = (($downG) + 20|0);
 HEAPF32[$214>>2] = $200;
 $215 = (($downB) + 20|0);
 HEAPF32[$215>>2] = $202;
 $216 = Math_fround($186 * Math_fround(-0.315391570329666137695));
 $217 = (($downR) + 24|0);
 HEAPF32[$217>>2] = $216;
 $218 = Math_fround($187 * Math_fround(-0.315391570329666137695));
 $219 = (($downG) + 24|0);
 HEAPF32[$219>>2] = $218;
 $220 = Math_fround($188 * Math_fround(-0.315391570329666137695));
 $221 = (($downB) + 24|0);
 HEAPF32[$221>>2] = $220;
 $222 = (($downR) + 28|0);
 HEAPF32[$222>>2] = $204;
 $223 = (($downG) + 28|0);
 HEAPF32[$223>>2] = $206;
 $224 = (($downB) + 28|0);
 HEAPF32[$224>>2] = $208;
 $225 = Math_fround($186 * Math_fround(-0.546274244785308837891));
 $226 = (($downR) + 32|0);
 HEAPF32[$226>>2] = $225;
 $227 = Math_fround($187 * Math_fround(-0.546274244785308837891));
 $228 = (($downG) + 32|0);
 HEAPF32[$228>>2] = $227;
 $229 = Math_fround($188 * Math_fround(-0.546274244785308837891));
 $230 = (($downB) + 32|0);
 HEAPF32[$230>>2] = $229;
 $234 = $189;$241 = $190;$248 = $191;$i$031 = 0;
 while(1) {
  $231 = (($upR) + ($i$031<<2)|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = Math_fround($232 + $234);
  $235 = ((($this) + (($i$031*12)|0)|0) + 296|0);
  $236 = Math_fround(HEAPF32[$235>>2]);
  $237 = Math_fround($236 + $233);
  HEAPF32[$235>>2] = $237;
  $238 = (($upG) + ($i$031<<2)|0);
  $239 = Math_fround(HEAPF32[$238>>2]);
  $240 = Math_fround($239 + $241);
  $242 = ((($this) + (($i$031*12)|0)|0) + 300|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = Math_fround($243 + $240);
  HEAPF32[$242>>2] = $244;
  $245 = (($upB) + ($i$031<<2)|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround($246 + $248);
  $249 = ((($this) + (($i$031*12)|0)|0) + 304|0);
  $250 = Math_fround(HEAPF32[$249>>2]);
  $251 = Math_fround($250 + $247);
  HEAPF32[$249>>2] = $251;
  $252 = (($i$031) + 1)|0;
  $exitcond = ($252|0)==(9);
  if ($exitcond) {
   break;
  }
  $$phi$trans$insert = (($downR) + ($252<<2)|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$phi$trans$insert32 = (($downG) + ($252<<2)|0);
  $$pre33 = Math_fround(HEAPF32[$$phi$trans$insert32>>2]);
  $$phi$trans$insert34 = (($downB) + ($252<<2)|0);
  $$pre35 = Math_fround(HEAPF32[$$phi$trans$insert34>>2]);
  $234 = $$pre;$241 = $$pre33;$248 = $$pre35;$i$031 = $252;
 }
 STACKTOP = sp;return;
}
function __ZNK14RenderSettings13CalcFogFactorEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 416|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $3 = (($this) + 448|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $4);
 $6 = Math_fround($5 * $distance);
 $7 = Math_fround($6 * $distance);
 $8 = Math_fround(-$7);
 $9 = (Math_fround(+(Math_exp((+$8)))));
 $10 = Math_fround(Math_fround(1.0) - $9);
 $$0 = $10;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZNK14RenderSettings20GetDefaultSpotCookieEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 452|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK14RenderSettings12SetupAmbientEv($this) {
 $this = $this|0;
 var $$0$i$i$i = Math_fround(0), $$0$i$i$i1 = Math_fround(0), $$0$i$i$i8 = Math_fround(0), $$0$i$i$i831 = Math_fround(0), $$0$i1$i$i1233 = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$i3$i$i10 = Math_fround(0), $$0$i3$i$i1032 = Math_fround(0), $$0$i3$i$i3 = Math_fround(0), $$in = 0, $$in34 = 0, $$in35 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0);
 var $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0);
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0);
 var $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0);
 var $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $amb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $amb = sp;
 $0 = (__Z19GetActiveColorSpacev()|0);
 $1 = ($0|0)==(1);
 $2 = (($this) + 40|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 do {
  if ($1) {
   $4 = !($3 <= Math_fround(0.0404499992728233337402));
   do {
    if ($4) {
     $6 = $3 < Math_fround(1.0);
     if ($6) {
      $7 = Math_fround($3 + Math_fround(0.054999999701976776123));
      $8 = Math_fround($7 / Math_fround(1.05499994754791259766));
      $9 = (Math_fround(+(Math_pow((+$8),2.40000009536743164063))));
      $$0$i$i$i = $9;
      break;
     } else {
      $10 = (Math_fround(+(Math_pow((+$3),2.40000009536743164063))));
      $$0$i$i$i = $10;
      break;
     }
    } else {
     $5 = Math_fround($3 / Math_fround(12.9200000762939453125));
     $$0$i$i$i = $5;
    }
   } while(0);
   $11 = (($this) + 44|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = !($12 <= Math_fround(0.0404499992728233337402));
   do {
    if ($13) {
     $15 = $12 < Math_fround(1.0);
     if ($15) {
      $16 = Math_fround($12 + Math_fround(0.054999999701976776123));
      $17 = Math_fround($16 / Math_fround(1.05499994754791259766));
      $18 = (Math_fround(+(Math_pow((+$17),2.40000009536743164063))));
      $$0$i3$i$i = $18;
      break;
     } else {
      $19 = (Math_fround(+(Math_pow((+$12),2.40000009536743164063))));
      $$0$i3$i$i = $19;
      break;
     }
    } else {
     $14 = Math_fround($12 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i = $14;
    }
   } while(0);
   $20 = (($this) + 48|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = !($21 <= Math_fround(0.0404499992728233337402));
   if (!($22)) {
    $23 = Math_fround($21 / Math_fround(12.9200000762939453125));
    $35 = $$0$i$i$i;$37 = $$0$i3$i$i;$39 = $23;
    break;
   }
   $24 = $21 < Math_fround(1.0);
   if ($24) {
    $25 = Math_fround($21 + Math_fround(0.054999999701976776123));
    $26 = Math_fround($25 / Math_fround(1.05499994754791259766));
    $27 = (Math_fround(+(Math_pow((+$26),2.40000009536743164063))));
    $35 = $$0$i$i$i;$37 = $$0$i3$i$i;$39 = $27;
    break;
   } else {
    $28 = (Math_fround(+(Math_pow((+$21),2.40000009536743164063))));
    $35 = $$0$i$i$i;$37 = $$0$i3$i$i;$39 = $28;
    break;
   }
  } else {
   $29 = (($this) + 44|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = (($this) + 48|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $35 = $3;$37 = $30;$39 = $32;
  }
 } while(0);
 $$in = (($this) + 52|0);
 $33 = Math_fround(HEAPF32[$$in>>2]);
 $34 = Math_fround($35 * Math_fround(0.5));
 $36 = Math_fround($37 * Math_fround(0.5));
 $38 = Math_fround($39 * Math_fround(0.5));
 $40 = Math_fround($33 * Math_fround(0.5));
 HEAPF32[$amb>>2] = $34;
 $41 = (($amb) + 4|0);
 HEAPF32[$41>>2] = $36;
 $42 = (($amb) + 8|0);
 HEAPF32[$42>>2] = $38;
 $43 = (($amb) + 12|0);
 HEAPF32[$43>>2] = $40;
 $44 = (__Z19GetActiveColorSpacev()|0);
 $45 = ($44|0)==(1);
 $46 = (($this) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 do {
  if ($45) {
   $48 = !($47 <= Math_fround(0.0404499992728233337402));
   do {
    if ($48) {
     $50 = $47 < Math_fround(1.0);
     if ($50) {
      $51 = Math_fround($47 + Math_fround(0.054999999701976776123));
      $52 = Math_fround($51 / Math_fround(1.05499994754791259766));
      $53 = (Math_fround(+(Math_pow((+$52),2.40000009536743164063))));
      $$0$i$i$i1 = $53;
      break;
     } else {
      $54 = (Math_fround(+(Math_pow((+$47),2.40000009536743164063))));
      $$0$i$i$i1 = $54;
      break;
     }
    } else {
     $49 = Math_fround($47 / Math_fround(12.9200000762939453125));
     $$0$i$i$i1 = $49;
    }
   } while(0);
   $55 = (($this) + 28|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = !($56 <= Math_fround(0.0404499992728233337402));
   do {
    if ($57) {
     $59 = $56 < Math_fround(1.0);
     if ($59) {
      $60 = Math_fround($56 + Math_fround(0.054999999701976776123));
      $61 = Math_fround($60 / Math_fround(1.05499994754791259766));
      $62 = (Math_fround(+(Math_pow((+$61),2.40000009536743164063))));
      $$0$i3$i$i3 = $62;
      break;
     } else {
      $63 = (Math_fround(+(Math_pow((+$56),2.40000009536743164063))));
      $$0$i3$i$i3 = $63;
      break;
     }
    } else {
     $58 = Math_fround($56 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i3 = $58;
    }
   } while(0);
   $64 = (($this) + 32|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = !($65 <= Math_fround(0.0404499992728233337402));
   if (!($66)) {
    $67 = Math_fround($65 / Math_fround(12.9200000762939453125));
    $79 = $$0$i$i$i1;$81 = $$0$i3$i$i3;$83 = $67;
    break;
   }
   $68 = $65 < Math_fround(1.0);
   if ($68) {
    $69 = Math_fround($65 + Math_fround(0.054999999701976776123));
    $70 = Math_fround($69 / Math_fround(1.05499994754791259766));
    $71 = (Math_fround(+(Math_pow((+$70),2.40000009536743164063))));
    $79 = $$0$i$i$i1;$81 = $$0$i3$i$i3;$83 = $71;
    break;
   } else {
    $72 = (Math_fround(+(Math_pow((+$65),2.40000009536743164063))));
    $79 = $$0$i$i$i1;$81 = $$0$i3$i$i3;$83 = $72;
    break;
   }
  } else {
   $73 = (($this) + 28|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = (($this) + 32|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $79 = $47;$81 = $74;$83 = $76;
  }
 } while(0);
 $$in34 = (($this) + 36|0);
 $77 = Math_fround(HEAPF32[$$in34>>2]);
 $78 = Math_fround($79 * Math_fround(0.5));
 $80 = Math_fround($81 * Math_fround(0.5));
 $82 = Math_fround($83 * Math_fround(0.5));
 $84 = Math_fround($77 * Math_fround(0.5));
 $85 = (__Z19GetActiveColorSpacev()|0);
 $86 = ($85|0)==(1);
 $87 = (($this) + 56|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 do {
  if ($86) {
   $89 = !($88 <= Math_fround(0.0404499992728233337402));
   do {
    if ($89) {
     $91 = $88 < Math_fround(1.0);
     if ($91) {
      $92 = Math_fround($88 + Math_fround(0.054999999701976776123));
      $93 = Math_fround($92 / Math_fround(1.05499994754791259766));
      $94 = (Math_fround(+(Math_pow((+$93),2.40000009536743164063))));
      $$0$i$i$i8 = $94;
      break;
     } else {
      $95 = (Math_fround(+(Math_pow((+$88),2.40000009536743164063))));
      $$0$i$i$i8 = $95;
      break;
     }
    } else {
     $90 = Math_fround($88 / Math_fround(12.9200000762939453125));
     $$0$i$i$i8 = $90;
    }
   } while(0);
   $96 = (($this) + 60|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = !($97 <= Math_fround(0.0404499992728233337402));
   do {
    if ($98) {
     $100 = $97 < Math_fround(1.0);
     if ($100) {
      $101 = Math_fround($97 + Math_fround(0.054999999701976776123));
      $102 = Math_fround($101 / Math_fround(1.05499994754791259766));
      $103 = (Math_fround(+(Math_pow((+$102),2.40000009536743164063))));
      $$0$i3$i$i10 = $103;
      break;
     } else {
      $104 = (Math_fround(+(Math_pow((+$97),2.40000009536743164063))));
      $$0$i3$i$i10 = $104;
      break;
     }
    } else {
     $99 = Math_fround($97 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i10 = $99;
    }
   } while(0);
   $105 = (($this) + 64|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = !($106 <= Math_fround(0.0404499992728233337402));
   if (!($107)) {
    $108 = Math_fround($106 / Math_fround(12.9200000762939453125));
    $$0$i$i$i831 = $$0$i$i$i8;$$0$i1$i$i1233 = $108;$$0$i3$i$i1032 = $$0$i3$i$i10;
    break;
   }
   $109 = $106 < Math_fround(1.0);
   if ($109) {
    $110 = Math_fround($106 + Math_fround(0.054999999701976776123));
    $111 = Math_fround($110 / Math_fround(1.05499994754791259766));
    $112 = (Math_fround(+(Math_pow((+$111),2.40000009536743164063))));
    $$0$i$i$i831 = $$0$i$i$i8;$$0$i1$i$i1233 = $112;$$0$i3$i$i1032 = $$0$i3$i$i10;
    break;
   } else {
    $113 = (Math_fround(+(Math_pow((+$106),2.40000009536743164063))));
    $$0$i$i$i831 = $$0$i$i$i8;$$0$i1$i$i1233 = $113;$$0$i3$i$i1032 = $$0$i3$i$i10;
    break;
   }
  } else {
   $114 = (($this) + 60|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = (($this) + 64|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $$0$i$i$i831 = $88;$$0$i1$i$i1233 = $117;$$0$i3$i$i1032 = $115;
  }
 } while(0);
 $$in35 = (($this) + 68|0);
 $118 = Math_fround(HEAPF32[$$in35>>2]);
 $119 = Math_fround($$0$i$i$i831 * Math_fround(0.5));
 $120 = Math_fround($$0$i3$i$i1032 * Math_fround(0.5));
 $121 = Math_fround($$0$i1$i$i1233 * Math_fround(0.5));
 $122 = Math_fround($118 * Math_fround(0.5));
 $123 = (__Z12GetGfxDevicev()|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($124) + 252|0);
 $126 = HEAP32[$125>>2]|0;
 FUNCTION_TABLE_vii[$126 & 4095]($123,$amb);
 $127 = (($123) + 1476|0);
 HEAPF32[$127>>2] = $78;
 $128 = (($123) + 1480|0);
 HEAPF32[$128>>2] = $80;
 $129 = (($123) + 1484|0);
 HEAPF32[$129>>2] = $82;
 $130 = (($123) + 1488|0);
 HEAPF32[$130>>2] = $84;
 $131 = (($123) + 1492|0);
 HEAPF32[$131>>2] = $119;
 $132 = (($123) + 1496|0);
 HEAPF32[$132>>2] = $120;
 $133 = (($123) + 1500|0);
 HEAPF32[$133>>2] = $121;
 $134 = (($123) + 1504|0);
 HEAPF32[$134>>2] = $122;
 STACKTOP = sp;return;
}
function __ZN14RenderSettings13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $pos$i$i$i$i$i = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i$i = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[652824>>2]|0;
 $3 = (($2) + 20|0);
 $4 = (__ZN10builtintex21GetAttenuationTextureEv()|0);
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($3,575128,$4)|0);
 $5 = (($this) + 452|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   label = 11;
  } else {
   HEAP32[$0>>2] = $6;
   $8 = HEAP32[560624>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = (($8) + 36|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($8) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    do {
     if ($14) {
      $15 = (($8) + 28|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($8) + 32|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($16) + ($18<<3)|0);
      $35 = $19;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$8,$0);
      $20 = HEAP32[$pos$i$i$i$i$i>>2]|0;
      $21 = ($20|0)==(-1);
      $22 = (($8) + 28|0);
      $23 = HEAP32[$22>>2]|0;
      if ($21) {
       $24 = (($8) + 32|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (($23) + ($25<<3)|0);
       $35 = $26;
       break;
      } else {
       $27 = (($23) + ($20<<3)|0);
       $35 = $27;
       break;
      }
     }
    } while(0);
    $28 = HEAP32[560624>>2]|0;
    $29 = (($28) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 32|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + ($32<<3)|0);
    $34 = ($35|0)==($33|0);
    if (!($34)) {
     $36 = (($35) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==(0|0);
     if (!($38)) {
      break;
     }
    }
   }
   $39 = HEAP32[$5>>2]|0;
   $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
   $phitmp$i = ($40|0)==(0|0);
   if ($phitmp$i) {
    label = 11;
   }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   HEAP8[$1>>0] = 16;
   $41 = (($1) + 1|0);
   $42 = $41;
   $43 = $42;
   HEAP8[$43>>0]=1952870227&255;HEAP8[$43+1>>0]=(1952870227>>8)&255;HEAP8[$43+2>>0]=(1952870227>>16)&255;HEAP8[$43+3>>0]=1952870227>>24;
   $44 = (($42) + 4)|0;
   $45 = $44;
   HEAP8[$45>>0]=1685286958&255;HEAP8[$45+1>>0]=(1685286958>>8)&255;HEAP8[$45+2>>0]=(1685286958>>16)&255;HEAP8[$45+3>>0]=1685286958>>24;
   $46 = (($1) + 9|0);
   HEAP8[$46>>0] = 0;
   __THREW__ = 0;
   $47 = (invoke_i(58)|0);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    __THREW__ = 0;
    $50 = (invoke_iiii(1532,($47|0),28,($1|0))|0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if (!($52)) {
     $53 = ($50|0)==(0|0);
     if ($53) {
      $storemerge = 0;
     } else {
      $54 = (($50) + 4|0);
      $55 = HEAP32[$54>>2]|0;
      $storemerge = $55;
     }
     HEAP32[$5>>2] = $storemerge;
     $56 = HEAP8[$1>>0]|0;
     $57 = $56 & 1;
     $58 = ($57<<24>>24)==(0);
     if ($58) {
      break;
     }
     $59 = (($1) + 8|0);
     $60 = HEAP32[$59>>2]|0;
     __ZdlPv($60);
     break;
    }
   }
   $61 = ___cxa_find_matching_catch()|0;
   $62 = tempRet0;
   $63 = HEAP8[$1>>0]|0;
   $64 = $63 & 1;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    ___resumeException($61|0);
    // unreachable;
   }
   $66 = (($1) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   __ZdlPv($67);
   ___resumeException($61|0);
   // unreachable;
  }
 } while(0);
 __ZN14RenderSettings23UpdateFinalAmbientProbeEv($this);
 __ZN14RenderSettings14ApplyFogParamsEv($this);
 __ZN14RenderSettings16ApplyHaloTextureEv($this);
 $68 = (__Z12GetGfxDevicev()|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + 244|0);
 $71 = HEAP32[$70>>2]|0;
 FUNCTION_TABLE_vii[$71 & 4095]($68,0);
 $72 = $awakeMode & 1;
 $73 = ($72|0)==(0);
 if (!($73)) {
  __ZN14RenderSettings23UpdateDefaultReflectionEv($this);
  STACKTOP = sp;return;
 }
 __ZN14RenderSettings17ApplyLightChangesENS_16LightsUpdateTypeE(0,0);
 __ZN14RenderSettings23UpdateDefaultReflectionEv($this);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings14ApplyFogParamsEv($this) {
 $this = $this|0;
 var $$0$i$i$i = Math_fround(0), $$0$i$i$i17 = Math_fround(0), $$0$i1$i$i19 = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$i3$i$i18 = Math_fround(0), $$in = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0);
 var $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0;
 var $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $fogDensity$0 = Math_fround(0), $fogEnd$0 = Math_fround(0);
 var $fogStart$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($this) + 416|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = 0;
 } else {
  $4 = (($this) + 420|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5;
 }
 HEAP32[678896>>2] = $6;
 $7 = (($this) + 448|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 440|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 444|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 if ((($6|0) == 0)) {
  $39 = Math_fround(0.0);$41 = Math_fround(0.0);$43 = Math_fround(0.0);$45 = Math_fround(0.0);$fogDensity$0 = Math_fround(0.0);$fogEnd$0 = Math_fround(2.0E+4);$fogStart$0 = Math_fround(1.0E+4);
 } else if ((($6|0) == 1)) {
  $15 = Math_fround($12 - $10);
  $16 = $15 < Math_fround(0.0);
  if ($16) {
   $17 = Math_fround(-$15);
   $19 = $17;
  } else {
   $19 = $15;
  }
  $18 = $19 > Math_fround(9.99999974737875163555E-5);
  if ($18) {
   $20 = Math_fround(Math_fround(1.0) / $15);
   $24 = $20;
  } else {
   $24 = Math_fround(0.0);
  }
  $21 = Math_fround($8 * Math_fround(1.20112240314483642578));
  $22 = Math_fround($8 * Math_fround(1.44269502162933349609));
  $23 = Math_fround(-$24);
  $25 = Math_fround($12 * $24);
  $39 = $21;$41 = $22;$43 = $23;$45 = $25;$fogDensity$0 = $8;$fogEnd$0 = $12;$fogStart$0 = $10;
 } else {
  $13 = Math_fround($8 * Math_fround(1.20112240314483642578));
  $14 = Math_fround($8 * Math_fround(1.44269502162933349609));
  $39 = $13;$41 = $14;$43 = Math_fround(0.0);$45 = Math_fround(0.0);$fogDensity$0 = $8;$fogEnd$0 = $12;$fogStart$0 = $10;
 }
 $26 = (($0) + 1252|0);
 HEAPF32[$26>>2] = $fogStart$0;
 $27 = (($0) + 1256|0);
 HEAPF32[$27>>2] = $fogStart$0;
 $28 = (($0) + 1260|0);
 HEAPF32[$28>>2] = $fogStart$0;
 $29 = (($0) + 1264|0);
 HEAPF32[$29>>2] = $fogStart$0;
 $30 = (($0) + 1268|0);
 HEAPF32[$30>>2] = $fogEnd$0;
 $31 = (($0) + 1272|0);
 HEAPF32[$31>>2] = $fogEnd$0;
 $32 = (($0) + 1276|0);
 HEAPF32[$32>>2] = $fogEnd$0;
 $33 = (($0) + 1280|0);
 HEAPF32[$33>>2] = $fogEnd$0;
 $34 = (($0) + 1284|0);
 HEAPF32[$34>>2] = $fogDensity$0;
 $35 = (($0) + 1288|0);
 HEAPF32[$35>>2] = $fogDensity$0;
 $36 = (($0) + 1292|0);
 HEAPF32[$36>>2] = $fogDensity$0;
 $37 = (($0) + 1296|0);
 HEAPF32[$37>>2] = $fogDensity$0;
 $38 = (($0) + 1316|0);
 HEAPF32[$38>>2] = $39;
 $40 = (($0) + 1320|0);
 HEAPF32[$40>>2] = $41;
 $42 = (($0) + 1324|0);
 HEAPF32[$42>>2] = $43;
 $44 = (($0) + 1328|0);
 HEAPF32[$44>>2] = $45;
 $46 = (__Z19GetActiveColorSpacev()|0);
 $47 = ($46|0)==(1);
 $48 = (($this) + 424|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 do {
  if ($47) {
   $50 = !($49 <= Math_fround(0.0404499992728233337402));
   do {
    if ($50) {
     $52 = $49 < Math_fround(1.0);
     if ($52) {
      $53 = Math_fround($49 + Math_fround(0.054999999701976776123));
      $54 = Math_fround($53 / Math_fround(1.05499994754791259766));
      $55 = (Math_fround(+(Math_pow((+$54),2.40000009536743164063))));
      $$0$i$i$i = $55;
      break;
     } else {
      $56 = (Math_fround(+(Math_pow((+$49),2.40000009536743164063))));
      $$0$i$i$i = $56;
      break;
     }
    } else {
     $51 = Math_fround($49 / Math_fround(12.9200000762939453125));
     $$0$i$i$i = $51;
    }
   } while(0);
   $57 = (($this) + 428|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = !($58 <= Math_fround(0.0404499992728233337402));
   do {
    if ($59) {
     $61 = $58 < Math_fround(1.0);
     if ($61) {
      $62 = Math_fround($58 + Math_fround(0.054999999701976776123));
      $63 = Math_fround($62 / Math_fround(1.05499994754791259766));
      $64 = (Math_fround(+(Math_pow((+$63),2.40000009536743164063))));
      $$0$i3$i$i = $64;
      break;
     } else {
      $65 = (Math_fround(+(Math_pow((+$58),2.40000009536743164063))));
      $$0$i3$i$i = $65;
      break;
     }
    } else {
     $60 = Math_fround($58 / Math_fround(12.9200000762939453125));
     $$0$i3$i$i = $60;
    }
   } while(0);
   $66 = (($this) + 432|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = !($67 <= Math_fround(0.0404499992728233337402));
   if (!($68)) {
    $69 = Math_fround($67 / Math_fround(12.9200000762939453125));
    $$0$i$i$i17 = $$0$i$i$i;$$0$i1$i$i19 = $69;$$0$i3$i$i18 = $$0$i3$i$i;
    break;
   }
   $70 = $67 < Math_fround(1.0);
   if ($70) {
    $71 = Math_fround($67 + Math_fround(0.054999999701976776123));
    $72 = Math_fround($71 / Math_fround(1.05499994754791259766));
    $73 = (Math_fround(+(Math_pow((+$72),2.40000009536743164063))));
    $$0$i$i$i17 = $$0$i$i$i;$$0$i1$i$i19 = $73;$$0$i3$i$i18 = $$0$i3$i$i;
    break;
   } else {
    $74 = (Math_fround(+(Math_pow((+$67),2.40000009536743164063))));
    $$0$i$i$i17 = $$0$i$i$i;$$0$i1$i$i19 = $74;$$0$i3$i$i18 = $$0$i3$i$i;
    break;
   }
  } else {
   $75 = (($this) + 428|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = (($this) + 432|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $$0$i$i$i17 = $49;$$0$i1$i$i19 = $78;$$0$i3$i$i18 = $76;
  }
 } while(0);
 $$in = (($this) + 436|0);
 $79 = Math_fround(HEAPF32[$$in>>2]);
 $80 = (($0) + 1300|0);
 HEAPF32[$80>>2] = $$0$i$i$i17;
 $81 = (($0) + 1304|0);
 HEAPF32[$81>>2] = $$0$i3$i$i18;
 $82 = (($0) + 1308|0);
 HEAPF32[$82>>2] = $$0$i1$i$i19;
 $83 = (($0) + 1312|0);
 HEAPF32[$83>>2] = $79;
 $84 = HEAP32[652824>>2]|0;
 $85 = (($84) + 4|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = $86 & -7340033;
 HEAP32[$85>>2] = $87;
 $88 = HEAP32[678896>>2]|0;
 if ((($88|0) == 3)) {
  $91 = $87 | 4194304;
  HEAP32[$85>>2] = $91;
  STACKTOP = sp;return;
 } else if ((($88|0) == 2)) {
  $90 = $87 | 2097152;
  HEAP32[$85>>2] = $90;
  STACKTOP = sp;return;
 } else if ((($88|0) == 1)) {
  $89 = $87 | 1048576;
  HEAP32[$85>>2] = $89;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN14RenderSettings16ApplyHaloTextureEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 456|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = HEAP32[652824>>2]|0;
   $5 = (($4) + 20|0);
   $47 = $5;
  } else {
   HEAP32[$0>>2] = $2;
   $6 = HEAP32[560624>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    label = 12;
   } else {
    $8 = (($6) + 36|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($6) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($9|0)==($11|0);
    do {
     if ($12) {
      $13 = (($6) + 28|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($6) + 32|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($14) + ($16<<3)|0);
      $33 = $17;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$6,$0);
      $18 = HEAP32[$pos$i$i$i$i>>2]|0;
      $19 = ($18|0)==(-1);
      $20 = (($6) + 28|0);
      $21 = HEAP32[$20>>2]|0;
      if ($19) {
       $22 = (($6) + 32|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = (($21) + ($23<<3)|0);
       $33 = $24;
       break;
      } else {
       $25 = (($21) + ($18<<3)|0);
       $33 = $25;
       break;
      }
     }
    } while(0);
    $26 = HEAP32[560624>>2]|0;
    $27 = (($26) + 28|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + 32|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + ($30<<3)|0);
    $32 = ($33|0)==($31|0);
    if ($32) {
     label = 12;
    } else {
     $34 = (($33) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)==(0|0);
     if ($36) {
      label = 12;
     } else {
      $37 = HEAP32[652824>>2]|0;
      $38 = (($37) + 20|0);
      $48 = $38;$temp$0$i2 = $35;
     }
    }
   }
   if ((label|0) == 12) {
    $39 = HEAP32[$1>>2]|0;
    $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
    $41 = HEAP32[652824>>2]|0;
    $42 = (($41) + 20|0);
    $43 = ($40|0)==(0|0);
    if ($43) {
     $47 = $42;
     break;
    } else {
     $48 = $42;$temp$0$i2 = $40;
    }
   }
   $45 = $48;$46 = $temp$0$i2;
   (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($45,575152,$46)|0);
   STACKTOP = sp;return;
  }
 } while(0);
 $44 = (__ZN10builtintex14GetHaloTextureEv()|0);
 $45 = $47;$46 = $44;
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($45,575152,$46)|0);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings17ApplyLightChangesENS_16LightsUpdateTypeE($this,$updateType) {
 $this = $this|0;
 $updateType = $updateType|0;
 var $$0$i = 0, $$0$i$us = 0, $$lcssa = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $obj = 0, $pos$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $split = 0, $temp$0$i = 0, $temp$0$i$us = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp;
 $obj = sp + 4|0;
 HEAP32[$obj>>2] = 0;
 $1 = (($obj) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($obj) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1536,108,($obj|0),0)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $96 = ___cxa_find_matching_catch()|0;
   $97 = tempRet0;
   $lpad$phi$index = $96;$lpad$phi$index3 = $97;
  } else {
   $5 = HEAP32[$obj>>2]|0;
   $6 = HEAP32[$1>>2]|0;
   $7 = ($5|0)==($6|0);
   if ($7) {
    $$lcssa = $5;$113 = $5;
   } else {
    $8 = ($updateType|0)==(0);
    L5: do {
     if ($8) {
      $10 = $5;
      while(1) {
       $9 = HEAP32[$10>>2]|0;
       $11 = ($9|0)==(0);
       if ($11) {
        $$0$i$us = 0;
       } else {
        HEAP32[$0>>2] = $9;
        $12 = HEAP32[560624>>2]|0;
        $13 = ($12|0)==(0|0);
        if ($13) {
         label = 13;
        } else {
         $14 = (($12) + 36|0);
         $15 = HEAP32[$14>>2]|0;
         $16 = (($12) + 4|0);
         $17 = HEAP32[$16>>2]|0;
         $18 = ($15|0)==($17|0);
         do {
          if ($18) {
           $27 = (($12) + 28|0);
           $28 = HEAP32[$27>>2]|0;
           $29 = (($12) + 32|0);
           $30 = HEAP32[$29>>2]|0;
           $31 = (($28) + ($30<<3)|0);
           $39 = $31;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$12,$0);
           $19 = HEAP32[$pos$i$i$i$i>>2]|0;
           $20 = ($19|0)==(-1);
           $21 = (($12) + 28|0);
           $22 = HEAP32[$21>>2]|0;
           if ($20) {
            $24 = (($12) + 32|0);
            $25 = HEAP32[$24>>2]|0;
            $26 = (($22) + ($25<<3)|0);
            $39 = $26;
            break;
           } else {
            $23 = (($22) + ($19<<3)|0);
            $39 = $23;
            break;
           }
          }
         } while(0);
         $32 = HEAP32[560624>>2]|0;
         $33 = (($32) + 28|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = (($32) + 32|0);
         $36 = HEAP32[$35>>2]|0;
         $37 = (($34) + ($36<<3)|0);
         $38 = ($39|0)==($37|0);
         if ($38) {
          label = 13;
         } else {
          $40 = (($39) + 4|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = ($41|0)==(0|0);
          if ($42) {
           label = 13;
          } else {
           $temp$0$i$us = $41;
          }
         }
        }
        if ((label|0) == 13) {
         label = 0;
         __THREW__ = 0;
         $43 = (invoke_ii(3215,($9|0))|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break;
         } else {
          $temp$0$i$us = $43;
         }
        }
        $$0$i$us = $temp$0$i$us;
       }
       __THREW__ = 0;
       invoke_vi(3426,($$0$i$us|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3427,($$0$i$us|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3428,($$0$i$us|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       $52 = (($10) + 4|0);
       $53 = HEAP32[$1>>2]|0;
       $54 = ($52|0)==($53|0);
       if ($54) {
        $split = $52;
        break L5;
       } else {
        $10 = $52;
       }
      }
      $55 = ___cxa_find_matching_catch()|0;
      $56 = tempRet0;
      $lpad$phi$index = $55;$lpad$phi$index3 = $56;
      break L1;
     } else {
      $58 = $5;
      while(1) {
       $57 = HEAP32[$58>>2]|0;
       $59 = ($57|0)==(0);
       if ($59) {
        $$0$i = 0;
       } else {
        HEAP32[$0>>2] = $57;
        $60 = HEAP32[560624>>2]|0;
        $61 = ($60|0)==(0|0);
        if ($61) {
         label = 29;
        } else {
         $62 = (($60) + 36|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = (($60) + 4|0);
         $65 = HEAP32[$64>>2]|0;
         $66 = ($63|0)==($65|0);
         do {
          if ($66) {
           $67 = (($60) + 28|0);
           $68 = HEAP32[$67>>2]|0;
           $69 = (($60) + 32|0);
           $70 = HEAP32[$69>>2]|0;
           $71 = (($68) + ($70<<3)|0);
           $87 = $71;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$60,$0);
           $72 = HEAP32[$pos$i$i$i$i>>2]|0;
           $73 = ($72|0)==(-1);
           $74 = (($60) + 28|0);
           $75 = HEAP32[$74>>2]|0;
           if ($73) {
            $76 = (($60) + 32|0);
            $77 = HEAP32[$76>>2]|0;
            $78 = (($75) + ($77<<3)|0);
            $87 = $78;
            break;
           } else {
            $79 = (($75) + ($72<<3)|0);
            $87 = $79;
            break;
           }
          }
         } while(0);
         $80 = HEAP32[560624>>2]|0;
         $81 = (($80) + 28|0);
         $82 = HEAP32[$81>>2]|0;
         $83 = (($80) + 32|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = (($82) + ($84<<3)|0);
         $86 = ($87|0)==($85|0);
         if ($86) {
          label = 29;
         } else {
          $88 = (($87) + 4|0);
          $89 = HEAP32[$88>>2]|0;
          $90 = ($89|0)==(0|0);
          if ($90) {
           label = 29;
          } else {
           $temp$0$i = $89;
          }
         }
        }
        if ((label|0) == 29) {
         label = 0;
         __THREW__ = 0;
         $91 = (invoke_ii(3215,($57|0))|0);
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          break;
         } else {
          $temp$0$i = $91;
         }
        }
        $$0$i = $temp$0$i;
       }
       if ((($updateType|0) == 2)) {
        __THREW__ = 0;
        invoke_vi(3428,($$0$i|0));
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         break;
        }
       } else if ((($updateType|0) == 1)) {
        __THREW__ = 0;
        invoke_vi(3427,($$0$i|0));
        $105 = __THREW__; __THREW__ = 0;
        $106 = $105&1;
        if ($106) {
         break;
        }
       }
       $109 = (($58) + 4|0);
       $110 = HEAP32[$1>>2]|0;
       $111 = ($109|0)==($110|0);
       if ($111) {
        $split = $109;
        break L5;
       } else {
        $58 = $109;
       }
      }
      $94 = ___cxa_find_matching_catch()|0;
      $95 = tempRet0;
      $lpad$phi$index = $94;$lpad$phi$index3 = $95;
      break L1;
     }
    } while(0);
    $$pre = HEAP32[$obj>>2]|0;
    $$lcssa = $split;$113 = $$pre;
   }
   $112 = ($113|0)==(0|0);
   if ($112) {
    STACKTOP = sp;return;
   }
   $114 = ($$lcssa|0)==($113|0);
   if (!($114)) {
    $__new_last2$i$i$i$i$i = $113;
    $scevgep$i$i$i$i$i = (($$lcssa) + -4|0);
    $115 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($115)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $116 = $uglygep3$i$i$i$i$i >>> 2;
    $117 = $116 ^ -1;
    $scevgep4$i$i$i$i$i = (($$lcssa) + ($117<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($113);
   STACKTOP = sp;return;
  }
 } while(0);
 $98 = HEAP32[$obj>>2]|0;
 $99 = ($98|0)==(0|0);
 if ($99) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $100 = HEAP32[$1>>2]|0;
 $101 = ($100|0)==($98|0);
 if (!($101)) {
  $__new_last2$i$i$i$i$i1 = $98;
  $scevgep$i$i$i$i$i2 = (($100) + -4|0);
  $102 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($102)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $103 = $uglygep3$i$i$i$i$i5 >>> 2;
  $104 = $103 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($100) + ($104<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($98);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN14RenderSettings23UpdateDefaultReflectionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $9 = 0, $cond = 0, $pos$i$i$i$i1 = 0, $temp$0$i = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 472|0);
 $4 = HEAP32[$3>>2]|0;
 $cond = ($4|0)==(0);
 if ($cond) {
  $44 = (($this) + 480|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0);
  if ($46) {
   $84 = 0;
  } else {
   HEAP32[$1>>2] = $45;
   $47 = HEAP32[560624>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    label = 23;
   } else {
    $49 = (($47) + 36|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($47) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($50|0)==($52|0);
    do {
     if ($53) {
      $54 = (($47) + 28|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = (($47) + 32|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($55) + ($57<<3)|0);
      $74 = $58;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$47,$1);
      $59 = HEAP32[$pos$i$i$i$i1>>2]|0;
      $60 = ($59|0)==(-1);
      $61 = (($47) + 28|0);
      $62 = HEAP32[$61>>2]|0;
      if ($60) {
       $63 = (($47) + 32|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = (($62) + ($64<<3)|0);
       $74 = $65;
       break;
      } else {
       $66 = (($62) + ($59<<3)|0);
       $74 = $66;
       break;
      }
     }
    } while(0);
    $67 = HEAP32[560624>>2]|0;
    $68 = (($67) + 28|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($67) + 32|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($69) + ($71<<3)|0);
    $73 = ($74|0)==($72|0);
    if ($73) {
     label = 23;
    } else {
     $75 = (($74) + 4|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==(0|0);
     if ($77) {
      label = 23;
     } else {
      $temp$0$i = $76;
     }
    }
   }
   if ((label|0) == 23) {
    $78 = HEAP32[$44>>2]|0;
    $79 = (__Z31ReadObjectFromPersistentManageri($78)|0);
    $temp$0$i = $79;
   }
   $80 = ($temp$0$i|0)==(0|0);
   if ($80) {
    $84 = 0;
   } else {
    $81 = (($temp$0$i) + 4|0);
    $82 = HEAP32[$81>>2]|0;
    $84 = $82;
   }
  }
 } else {
  $5 = (($this) + 476|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $84 = 0;
  } else {
   HEAP32[$0>>2] = $6;
   $8 = HEAP32[560624>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    label = 11;
   } else {
    $10 = (($8) + 36|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($8) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    do {
     if ($14) {
      $15 = (($8) + 28|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($8) + 32|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($16) + ($18<<3)|0);
      $35 = $19;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$8,$0);
      $20 = HEAP32[$pos$i$i$i$i1>>2]|0;
      $21 = ($20|0)==(-1);
      $22 = (($8) + 28|0);
      $23 = HEAP32[$22>>2]|0;
      if ($21) {
       $24 = (($8) + 32|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (($23) + ($25<<3)|0);
       $35 = $26;
       break;
      } else {
       $27 = (($23) + ($20<<3)|0);
       $35 = $27;
       break;
      }
     }
    } while(0);
    $28 = HEAP32[560624>>2]|0;
    $29 = (($28) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 32|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + ($32<<3)|0);
    $34 = ($35|0)==($33|0);
    if ($34) {
     label = 11;
    } else {
     $36 = (($35) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 11;
     } else {
      $temp$0$i5 = $37;
     }
    }
   }
   if ((label|0) == 11) {
    $39 = HEAP32[$5>>2]|0;
    $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
    $temp$0$i5 = $40;
   }
   $41 = ($temp$0$i5|0)==(0|0);
   if ($41) {
    $84 = 0;
   } else {
    $42 = (($temp$0$i5) + 4|0);
    $43 = HEAP32[$42>>2]|0;
    $84 = $43;
   }
  }
 }
 $83 = (__Z19GetReflectionProbesv()|0);
 HEAP32[$2>>2] = $84;
 $85 = (($this) + 468|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 __ZN16ReflectionProbes17SetDefaultTextureE4PPtrI7TextureEf($83,$2,$86);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings16CheckConsistencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 448|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 < Math_fround(0.0);
 $3 = $2 ? Math_fround(0.0) : $1;
 $4 = $3 > Math_fround(1.0);
 $5 = $4 ? Math_fround(1.0) : $3;
 HEAPF32[$0>>2] = $5;
 $6 = (($this) + 404|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $7 < Math_fround(0.0);
 $9 = $8 ? Math_fround(0.0) : $7;
 $10 = $9 > Math_fround(1.0);
 $11 = $10 ? Math_fround(1.0) : $9;
 HEAPF32[$6>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN14RenderSettings15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z27RegisterAllowNameConversionPKcS0_S0_(575320,575288,575304);
 __ZN12LightManager15InitializeClassEv();
 __ZN16ReflectionProbes15InitializeClassEv();
 STACKTOP = sp;return;
}
function __ZN14RenderSettings19PostInitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10builtintex23GenerateBuiltinTexturesEv();
 STACKTOP = sp;return;
}
function __ZN14RenderSettings12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12LightManager12CleanupClassEv();
 __ZN16ReflectionProbes12CleanupClassEv();
 STACKTOP = sp;return;
}
function __Z28RegisterClass_RenderSettingsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(104,103,104,105,106);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(3)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN16LevelGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 14;
 dest=$3+0|0; src=575320+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 14|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,104,3,($0|0),484,(2378|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN14RenderSettings7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(484,$$byval_copy2,1,16,576008,37)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1681,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((575176 + 8|0));
  $6 = (($3) + 72|0);
  $7 = (($3) + 296|0);
  dest=$7+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $8 = (($3) + 452|0);
  $9 = (($3) + 476|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 480|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 440|0);
  HEAPF32[$11>>2] = Math_fround(0.0);
  $12 = (($3) + 444|0);
  _memset(($6|0),0,216)|0;
  ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
  HEAPF32[$12>>2] = Math_fround(300.0);
  $13 = (($3) + 448|0);
  HEAPF32[$13>>2] = Math_fround(0.00999999977648258209228);
  $14 = (($3) + 416|0);
  HEAP8[$14>>0] = 0;
  $15 = (($3) + 420|0);
  HEAP32[$15>>2] = 3;
  $16 = (($3) + 412|0);
  HEAPF32[$16>>2] = Math_fround(3.0);
  $17 = (($3) + 292|0);
  HEAP32[$17>>2] = 1;
  $18 = (($3) + 472|0);
  HEAP32[$18>>2] = 1;
  STACKTOP = sp;return ($3|0);
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(576008|0),37);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK14RenderSettings25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 104;
}
function __ZN14RenderSettings23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575336,575320,$this,0);
 __ZN14RenderSettings8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575336,575320,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN14RenderSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14RenderSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14RenderSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14RenderSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14RenderSettings8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z17GetRenderSettingsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(16)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14RenderSettingsD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561080 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   STACKTOP = sp;return;
  }
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __THREW__ = 0;
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   ___resumeException($4|0);
   // unreachable;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$i$i$indexZ2D = $16;
   ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  ___resumeException($10|0);
  // unreachable;
 }
 $22 = ___cxa_find_matching_catch(0|0)|0;
 $23 = tempRet0;
 $eh$lpad$body$i$i$indexZ2D = $22;
 ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
 // unreachable;
}
function __ZN14RenderSettingsD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561080 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $16 = ___cxa_find_matching_catch(0|0)|0;
   $17 = tempRet0;
   __THREW__ = 0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $20 = ___cxa_find_matching_catch(0|0)|0;
    $21 = tempRet0;
    ___clang_call_terminate($20);
    // unreachable;
   } else {
    $eh$lpad$body$i$i$i$indexZ2D = $16;
    ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $eh$lpad$body$index8Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  $eh$lpad$body$i$i$i$indexZ2D = $22;
  ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   $4 = ___cxa_find_matching_catch()|0;
   $5 = tempRet0;
   __THREW__ = 0;
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $8 = ___cxa_find_matching_catch(0|0)|0;
    $9 = tempRet0;
    ___clang_call_terminate($8);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $5;$eh$lpad$body$indexZ2D = $4;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $eh$lpad$body$index8Z2D = $27;$eh$lpad$body$indexZ2D = $26;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN14RenderSettings8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LevelGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $0 = (($this) + 464|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 $12 = (($this) + 456|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 $18 = (FUNCTION_TABLE_iiii[$16 & 2047]($14,$13,$17)|0);
 $19 = HEAP8[$9>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  HEAP32[$12>>2] = $18;
 }
 $21 = (($this) + 452|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$2>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$6>>2]|0;
 $27 = (FUNCTION_TABLE_iiii[$25 & 2047]($23,$22,$26)|0);
 $28 = HEAP8[$9>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  HEAP32[$21>>2] = $27;
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $30 = (($this) + 476|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$2>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$6>>2]|0;
 $36 = (FUNCTION_TABLE_iiii[$34 & 2047]($32,$31,$35)|0);
 $37 = HEAP8[$9>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if (!($38)) {
  HEAP32[$30>>2] = $36;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $39 = (($this) + 480|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$2>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$6>>2]|0;
 $45 = (FUNCTION_TABLE_iiii[$43 & 2047]($41,$40,$44)|0);
 $46 = HEAP8[$9>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if ($47) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  STACKTOP = sp;return;
 }
 HEAP32[$39>>2] = $45;
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN16LevelGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 416|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP8[$0>>0]|0;
  HEAP8[$2>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $10 = (($this) + 424|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 420|0);
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$4>>2]|0;
 $15 = ($13>>>0)<($14>>>0);
 if ($15) {
  $16 = HEAP32[$11>>2]|0;
  HEAP32[$12>>2] = $16;
  HEAP32[$1>>2] = $13;
  $19 = $13;$21 = $14;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$11,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $19 = $$pre;$21 = $$pre10;
 }
 $17 = (($this) + 448|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)<($21>>>0);
 if ($20) {
  $22 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$19>>2] = $22;
  HEAP32[$1>>2] = $18;
  $25 = $18;$27 = $21;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$17,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $25 = $$pre11;$27 = $$pre12;
 }
 $23 = (($this) + 440|0);
 $24 = (($25) + 4|0);
 $26 = ($24>>>0)<($27>>>0);
 if ($26) {
  $28 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$25>>2] = $28;
  HEAP32[$1>>2] = $24;
  $31 = $24;$33 = $27;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$23,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $31 = $$pre13;$33 = $$pre14;
 }
 $29 = (($this) + 444|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)<($33>>>0);
 if ($32) {
  $34 = Math_fround(HEAPF32[$29>>2]);
  HEAPF32[$31>>2] = $34;
  HEAP32[$1>>2] = $30;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$29,4);
 }
 $35 = (($this) + 24|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($35,$transfer);
 $36 = (($this) + 40|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($36,$transfer);
 $37 = (($this) + 56|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($37,$transfer);
 $38 = (($this) + 288|0);
 $39 = HEAP32[$1>>2]|0;
 $40 = (($39) + 4|0);
 $41 = HEAP32[$4>>2]|0;
 $42 = ($40>>>0)<($41>>>0);
 if ($42) {
  $43 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[$39>>2] = $43;
  HEAP32[$1>>2] = $40;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$38,4);
 }
 $44 = (($this) + 72|0);
 __ZN19SphericalHarmonics38TransferI19StreamedBinaryWriteILb0EEEEvRT_($44,$transfer);
 $45 = (($this) + 180|0);
 __ZN19SphericalHarmonics38TransferI19StreamedBinaryWriteILb0EEEEvRT_($45,$transfer);
 $46 = (($this) + 292|0);
 $47 = HEAP32[$1>>2]|0;
 $48 = (($47) + 4|0);
 $49 = HEAP32[$4>>2]|0;
 $50 = ($48>>>0)<($49>>>0);
 if ($50) {
  $51 = HEAP32[$46>>2]|0;
  HEAP32[$47>>2] = $51;
  HEAP32[$1>>2] = $48;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$46,4);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $52 = (($this) + 464|0);
 __ZN4PPtrIN5Unity8MaterialEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($52,$transfer);
 $53 = (($this) + 404|0);
 $54 = HEAP32[$1>>2]|0;
 $55 = (($54) + 4|0);
 $56 = HEAP32[$4>>2]|0;
 $57 = ($55>>>0)<($56>>>0);
 if ($57) {
  $58 = Math_fround(HEAPF32[$53>>2]);
  HEAPF32[$54>>2] = $58;
  HEAP32[$1>>2] = $55;
  $61 = $55;$63 = $56;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$53,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $61 = $$pre15;$63 = $$pre16;
 }
 $59 = (($this) + 408|0);
 $60 = (($61) + 4|0);
 $62 = ($60>>>0)<($63>>>0);
 if ($62) {
  $64 = Math_fround(HEAPF32[$59>>2]);
  HEAPF32[$61>>2] = $64;
  HEAP32[$1>>2] = $60;
  $67 = $60;$69 = $63;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$59,4);
  $$pre17 = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $67 = $$pre17;$69 = $$pre18;
 }
 $65 = (($this) + 412|0);
 $66 = (($67) + 4|0);
 $68 = ($66>>>0)<($69>>>0);
 if ($68) {
  $70 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$67>>2] = $70;
  HEAP32[$1>>2] = $66;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$65,4);
 }
 $71 = (($this) + 456|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($71,$transfer);
 $72 = (($this) + 452|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($72,$transfer);
 $73 = (($this) + 472|0);
 $74 = HEAP32[$1>>2]|0;
 $75 = (($74) + 4|0);
 $76 = HEAP32[$4>>2]|0;
 $77 = ($75>>>0)<($76>>>0);
 if ($77) {
  $78 = HEAP32[$73>>2]|0;
  HEAP32[$74>>2] = $78;
  HEAP32[$1>>2] = $75;
  $81 = $75;$83 = $76;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$73,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $81 = $$pre19;$83 = $$pre20;
 }
 $79 = (($this) + 468|0);
 $80 = (($81) + 4|0);
 $82 = ($80>>>0)<($83>>>0);
 if ($82) {
  $84 = Math_fround(HEAPF32[$79>>2]);
  HEAPF32[$81>>2] = $84;
  HEAP32[$1>>2] = $80;
  $85 = (($this) + 476|0);
  __ZN4PPtrI7CubemapE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($85,$transfer);
  $86 = (($this) + 480|0);
  __ZN4PPtrI7CubemapE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($86,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$79,4);
  $85 = (($this) + 476|0);
  __ZN4PPtrI7CubemapE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($85,$transfer);
  $86 = (($this) + 480|0);
  __ZN4PPtrI7CubemapE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($86,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI7CubemapE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN19SphericalHarmonics38TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i22 = 0, $$pre$i$i$i29 = 0, $$pre$i$i$i36 = 0, $$pre$i$i$i43 = 0, $$pre$i$i$i50 = 0, $$pre$i$i$i8 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i16 = 0, $$pre3$i$i$i2 = 0, $$pre3$i$i$i23 = 0, $$pre3$i$i$i30 = 0, $$pre3$i$i$i37 = 0, $$pre3$i$i$i44 = 0, $$pre3$i$i$i51 = 0, $$pre3$i$i$i9 = 0, $$pre4$i$i$i = 0;
 var $$pre4$i$i$i11 = 0, $$pre4$i$i$i18 = 0, $$pre4$i$i$i25 = 0, $$pre4$i$i$i32 = 0, $$pre4$i$i$i39 = 0, $$pre4$i$i$i4 = 0, $$pre4$i$i$i46 = 0, $$pre4$i$i$i53 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i12 = 0, $$pre5$i$i$i19 = 0, $$pre5$i$i$i26 = 0, $$pre5$i$i$i33 = 0, $$pre5$i$i$i40 = 0, $$pre5$i$i$i47 = 0, $$pre5$i$i$i5 = 0, $$pre5$i$i$i54 = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0;
 var $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $$pre71 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0);
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre3$i$i$i = HEAP32[$3>>2]|0;
  $11 = $$pre3$i$i$i;$9 = $$pre$i$i$i;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre4$i$i$i = HEAP32[$0>>2]|0;
  $$pre5$i$i$i = HEAP32[$3>>2]|0;
  $15 = $$pre4$i$i$i;$17 = $$pre5$i$i$i;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre57 = HEAP32[$3>>2]|0;
  $21 = $$pre;$23 = $$pre57;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i2 = HEAP32[$3>>2]|0;
  $27 = $$pre$i$i$i1;$29 = $$pre3$i$i$i2;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $$pre4$i$i$i4 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i5 = HEAP32[$3>>2]|0;
  $33 = $$pre4$i$i$i4;$35 = $$pre5$i$i$i5;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$33>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,4);
  $$pre58 = HEAP32[$0>>2]|0;
  $$pre59 = HEAP32[$3>>2]|0;
  $39 = $$pre58;$41 = $$pre59;
 }
 $37 = (($this) + 24|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$39>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$37,4);
  $$pre$i$i$i8 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i9 = HEAP32[$3>>2]|0;
  $45 = $$pre$i$i$i8;$47 = $$pre3$i$i$i9;
 }
 $43 = (($this) + 28|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)<($47>>>0);
 if ($46) {
  $48 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$45>>2] = $48;
  HEAP32[$0>>2] = $44;
  $51 = $44;$53 = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$43,4);
  $$pre4$i$i$i11 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i12 = HEAP32[$3>>2]|0;
  $51 = $$pre4$i$i$i11;$53 = $$pre5$i$i$i12;
 }
 $49 = (($this) + 32|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)<($53>>>0);
 if ($52) {
  $54 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$51>>2] = $54;
  HEAP32[$0>>2] = $50;
  $57 = $50;$59 = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$49,4);
  $$pre60 = HEAP32[$0>>2]|0;
  $$pre61 = HEAP32[$3>>2]|0;
  $57 = $$pre60;$59 = $$pre61;
 }
 $55 = (($this) + 36|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)<($59>>>0);
 if ($58) {
  $60 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$57>>2] = $60;
  HEAP32[$0>>2] = $56;
  $63 = $56;$65 = $59;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$55,4);
  $$pre$i$i$i15 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i16 = HEAP32[$3>>2]|0;
  $63 = $$pre$i$i$i15;$65 = $$pre3$i$i$i16;
 }
 $61 = (($this) + 40|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)<($65>>>0);
 if ($64) {
  $66 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$63>>2] = $66;
  HEAP32[$0>>2] = $62;
  $69 = $62;$71 = $65;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$61,4);
  $$pre4$i$i$i18 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i19 = HEAP32[$3>>2]|0;
  $69 = $$pre4$i$i$i18;$71 = $$pre5$i$i$i19;
 }
 $67 = (($this) + 44|0);
 $68 = (($69) + 4|0);
 $70 = ($68>>>0)<($71>>>0);
 if ($70) {
  $72 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$69>>2] = $72;
  HEAP32[$0>>2] = $68;
  $75 = $68;$77 = $71;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$67,4);
  $$pre62 = HEAP32[$0>>2]|0;
  $$pre63 = HEAP32[$3>>2]|0;
  $75 = $$pre62;$77 = $$pre63;
 }
 $73 = (($this) + 48|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)<($77>>>0);
 if ($76) {
  $78 = Math_fround(HEAPF32[$73>>2]);
  HEAPF32[$75>>2] = $78;
  HEAP32[$0>>2] = $74;
  $81 = $74;$83 = $77;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$73,4);
  $$pre$i$i$i22 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i23 = HEAP32[$3>>2]|0;
  $81 = $$pre$i$i$i22;$83 = $$pre3$i$i$i23;
 }
 $79 = (($this) + 52|0);
 $80 = (($81) + 4|0);
 $82 = ($80>>>0)<($83>>>0);
 if ($82) {
  $84 = Math_fround(HEAPF32[$79>>2]);
  HEAPF32[$81>>2] = $84;
  HEAP32[$0>>2] = $80;
  $87 = $80;$89 = $83;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$79,4);
  $$pre4$i$i$i25 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i26 = HEAP32[$3>>2]|0;
  $87 = $$pre4$i$i$i25;$89 = $$pre5$i$i$i26;
 }
 $85 = (($this) + 56|0);
 $86 = (($87) + 4|0);
 $88 = ($86>>>0)<($89>>>0);
 if ($88) {
  $90 = Math_fround(HEAPF32[$85>>2]);
  HEAPF32[$87>>2] = $90;
  HEAP32[$0>>2] = $86;
  $93 = $86;$95 = $89;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$85,4);
  $$pre64 = HEAP32[$0>>2]|0;
  $$pre65 = HEAP32[$3>>2]|0;
  $93 = $$pre64;$95 = $$pre65;
 }
 $91 = (($this) + 60|0);
 $92 = (($93) + 4|0);
 $94 = ($92>>>0)<($95>>>0);
 if ($94) {
  $96 = Math_fround(HEAPF32[$91>>2]);
  HEAPF32[$93>>2] = $96;
  HEAP32[$0>>2] = $92;
  $101 = $95;$99 = $92;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$91,4);
  $$pre$i$i$i29 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i30 = HEAP32[$3>>2]|0;
  $101 = $$pre3$i$i$i30;$99 = $$pre$i$i$i29;
 }
 $97 = (($this) + 64|0);
 $98 = (($99) + 4|0);
 $100 = ($98>>>0)<($101>>>0);
 if ($100) {
  $102 = Math_fround(HEAPF32[$97>>2]);
  HEAPF32[$99>>2] = $102;
  HEAP32[$0>>2] = $98;
  $105 = $98;$107 = $101;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$97,4);
  $$pre4$i$i$i32 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i33 = HEAP32[$3>>2]|0;
  $105 = $$pre4$i$i$i32;$107 = $$pre5$i$i$i33;
 }
 $103 = (($this) + 68|0);
 $104 = (($105) + 4|0);
 $106 = ($104>>>0)<($107>>>0);
 if ($106) {
  $108 = Math_fround(HEAPF32[$103>>2]);
  HEAPF32[$105>>2] = $108;
  HEAP32[$0>>2] = $104;
  $111 = $104;$113 = $107;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$103,4);
  $$pre66 = HEAP32[$0>>2]|0;
  $$pre67 = HEAP32[$3>>2]|0;
  $111 = $$pre66;$113 = $$pre67;
 }
 $109 = (($this) + 72|0);
 $110 = (($111) + 4|0);
 $112 = ($110>>>0)<($113>>>0);
 if ($112) {
  $114 = Math_fround(HEAPF32[$109>>2]);
  HEAPF32[$111>>2] = $114;
  HEAP32[$0>>2] = $110;
  $117 = $110;$119 = $113;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$109,4);
  $$pre$i$i$i36 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i37 = HEAP32[$3>>2]|0;
  $117 = $$pre$i$i$i36;$119 = $$pre3$i$i$i37;
 }
 $115 = (($this) + 76|0);
 $116 = (($117) + 4|0);
 $118 = ($116>>>0)<($119>>>0);
 if ($118) {
  $120 = Math_fround(HEAPF32[$115>>2]);
  HEAPF32[$117>>2] = $120;
  HEAP32[$0>>2] = $116;
  $123 = $116;$125 = $119;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$115,4);
  $$pre4$i$i$i39 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i40 = HEAP32[$3>>2]|0;
  $123 = $$pre4$i$i$i39;$125 = $$pre5$i$i$i40;
 }
 $121 = (($this) + 80|0);
 $122 = (($123) + 4|0);
 $124 = ($122>>>0)<($125>>>0);
 if ($124) {
  $126 = Math_fround(HEAPF32[$121>>2]);
  HEAPF32[$123>>2] = $126;
  HEAP32[$0>>2] = $122;
  $129 = $122;$131 = $125;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$121,4);
  $$pre68 = HEAP32[$0>>2]|0;
  $$pre69 = HEAP32[$3>>2]|0;
  $129 = $$pre68;$131 = $$pre69;
 }
 $127 = (($this) + 84|0);
 $128 = (($129) + 4|0);
 $130 = ($128>>>0)<($131>>>0);
 if ($130) {
  $132 = Math_fround(HEAPF32[$127>>2]);
  HEAPF32[$129>>2] = $132;
  HEAP32[$0>>2] = $128;
  $135 = $128;$137 = $131;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$127,4);
  $$pre$i$i$i43 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i44 = HEAP32[$3>>2]|0;
  $135 = $$pre$i$i$i43;$137 = $$pre3$i$i$i44;
 }
 $133 = (($this) + 88|0);
 $134 = (($135) + 4|0);
 $136 = ($134>>>0)<($137>>>0);
 if ($136) {
  $138 = Math_fround(HEAPF32[$133>>2]);
  HEAPF32[$135>>2] = $138;
  HEAP32[$0>>2] = $134;
  $141 = $134;$143 = $137;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$133,4);
  $$pre4$i$i$i46 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i47 = HEAP32[$3>>2]|0;
  $141 = $$pre4$i$i$i46;$143 = $$pre5$i$i$i47;
 }
 $139 = (($this) + 92|0);
 $140 = (($141) + 4|0);
 $142 = ($140>>>0)<($143>>>0);
 if ($142) {
  $144 = Math_fround(HEAPF32[$139>>2]);
  HEAPF32[$141>>2] = $144;
  HEAP32[$0>>2] = $140;
  $147 = $140;$149 = $143;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$139,4);
  $$pre70 = HEAP32[$0>>2]|0;
  $$pre71 = HEAP32[$3>>2]|0;
  $147 = $$pre70;$149 = $$pre71;
 }
 $145 = (($this) + 96|0);
 $146 = (($147) + 4|0);
 $148 = ($146>>>0)<($149>>>0);
 if ($148) {
  $150 = Math_fround(HEAPF32[$145>>2]);
  HEAPF32[$147>>2] = $150;
  HEAP32[$0>>2] = $146;
  $153 = $146;$155 = $149;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$145,4);
  $$pre$i$i$i50 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i51 = HEAP32[$3>>2]|0;
  $153 = $$pre$i$i$i50;$155 = $$pre3$i$i$i51;
 }
 $151 = (($this) + 100|0);
 $152 = (($153) + 4|0);
 $154 = ($152>>>0)<($155>>>0);
 if ($154) {
  $156 = Math_fround(HEAPF32[$151>>2]);
  HEAPF32[$153>>2] = $156;
  HEAP32[$0>>2] = $152;
  $159 = $152;$161 = $155;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$151,4);
  $$pre4$i$i$i53 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i54 = HEAP32[$3>>2]|0;
  $159 = $$pre4$i$i$i53;$161 = $$pre5$i$i$i54;
 }
 $157 = (($this) + 104|0);
 $158 = (($159) + 4|0);
 $160 = ($158>>>0)<($161>>>0);
 if ($160) {
  $162 = Math_fround(HEAPF32[$157>>2]);
  HEAPF32[$159>>2] = $162;
  HEAP32[$0>>2] = $158;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$157,4);
  STACKTOP = sp;return;
 }
}
function __ZN14RenderSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i17 = 0, $$pre$i$i$i21 = 0, $$pre$i$i$i26 = 0, $$pre$i$i$i31 = 0, $$pre$i$i$i34 = 0, $$pre$i$i$i38 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i9 = 0, $$pre$phi$i$i$i10Z2D = 0, $$pre$phi$i$i$i15Z2D = 0, $$pre$phi$i$i$i22Z2D = 0, $$pre$phi$i$i$i27Z2D = 0, $$pre$phi$i$i$i32Z2D = 0, $$pre$phi$i$i$i39Z2D = 0, $$pre$phi$i$i$i5Z2D = 0, $$pre$phi$i$i$iZ2D = 0;
 var $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LevelGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 416|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $10 = (($this) + 424|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 $11 = (($this) + 420|0);
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$4>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre41 = HEAP32[$4>>2]|0;
  $17 = $$pre$i$i$i;$21 = $$pre;$23 = $$pre41;
 } else {
  $16 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$1>>2] = $13;
  $17 = $16;$21 = $13;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$11>>2] = $18;
 $19 = (($this) + 448|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$19,4);
  $$pre$i$i$i1 = HEAP32[$19>>2]|0;
  $$pre42 = HEAP32[$1>>2]|0;
  $$pre43 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $19;$26 = $$pre$i$i$i1;$30 = $$pre42;$32 = $$pre43;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$1>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $27;
 $28 = (($this) + 440|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$28,4);
  $$pre$i$i$i4 = HEAP32[$28>>2]|0;
  $$pre44 = HEAP32[$1>>2]|0;
  $$pre45 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i5Z2D = $28;$35 = $$pre$i$i$i4;$39 = $$pre44;$41 = $$pre45;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$1>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i5Z2D = $28;$35 = $34;$39 = $29;$41 = $32;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$$pre$phi$i$i$i5Z2D>>2] = $36;
 $37 = (($this) + 444|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$37,4);
  $$pre$i$i$i9 = HEAP32[$37>>2]|0;
  $$pre$phi$i$i$i10Z2D = $37;$44 = $$pre$i$i$i9;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$1>>2] = $38;
  $43 = (HEAPF32[tempDoublePtr>>2]=$42,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i10Z2D = $37;$44 = $43;
 }
 $45 = (_llvm_bswap_i32(($44|0))|0);
 HEAP32[$$pre$phi$i$i$i10Z2D>>2] = $45;
 $46 = (($this) + 24|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($46,$transfer);
 $47 = (($this) + 40|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($47,$transfer);
 $48 = (($this) + 56|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($48,$transfer);
 $49 = (($this) + 288|0);
 $50 = HEAP32[$1>>2]|0;
 $51 = (($50) + 4|0);
 $52 = HEAP32[$4>>2]|0;
 $53 = ($51>>>0)>($52>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$49,4);
  $$pre$i$i$i14 = HEAP32[$49>>2]|0;
  $$pre$phi$i$i$i15Z2D = $49;$56 = $$pre$i$i$i14;
 } else {
  $54 = Math_fround(HEAPF32[$50>>2]);
  HEAPF32[$49>>2] = $54;
  HEAP32[$1>>2] = $51;
  $55 = (HEAPF32[tempDoublePtr>>2]=$54,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i15Z2D = $49;$56 = $55;
 }
 $57 = (_llvm_bswap_i32(($56|0))|0);
 HEAP32[$$pre$phi$i$i$i15Z2D>>2] = $57;
 $58 = (($this) + 72|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$58,0,0);
 $59 = (($this) + 84|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$59,0,0);
 $60 = (($this) + 96|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$60,0,0);
 $61 = (($this) + 108|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$61,0,0);
 $62 = (($this) + 120|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$62,0,0);
 $63 = (($this) + 132|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$63,0,0);
 $64 = (($this) + 144|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$64,0,0);
 $65 = (($this) + 156|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$65,0,0);
 $66 = (($this) + 168|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$66,0,0);
 $67 = (($this) + 180|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$67,0,0);
 $68 = (($this) + 192|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$68,0,0);
 $69 = (($this) + 204|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$69,0,0);
 $70 = (($this) + 216|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$70,0,0);
 $71 = (($this) + 228|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$71,0,0);
 $72 = (($this) + 240|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$72,0,0);
 $73 = (($this) + 252|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$73,0,0);
 $74 = (($this) + 264|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$74,0,0);
 $75 = (($this) + 276|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$75,0,0);
 $76 = (($this) + 292|0);
 $77 = HEAP32[$1>>2]|0;
 $78 = (($77) + 4|0);
 $79 = HEAP32[$4>>2]|0;
 $80 = ($78>>>0)>($79>>>0);
 if ($80) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$76,4);
  $$pre$i$i$i17 = HEAP32[$76>>2]|0;
  $82 = $$pre$i$i$i17;
 } else {
  $81 = HEAP32[$77>>2]|0;
  HEAP32[$76>>2] = $81;
  HEAP32[$1>>2] = $78;
  $82 = $81;
 }
 $83 = (_llvm_bswap_i32(($82|0))|0);
 HEAP32[$76>>2] = $83;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $84 = (($this) + 464|0);
 __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($84,$transfer);
 $85 = (($this) + 404|0);
 $86 = HEAP32[$1>>2]|0;
 $87 = (($86) + 4|0);
 $88 = HEAP32[$4>>2]|0;
 $89 = ($87>>>0)>($88>>>0);
 if ($89) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$85,4);
  $$pre$i$i$i21 = HEAP32[$85>>2]|0;
  $$pre46 = HEAP32[$1>>2]|0;
  $$pre47 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i22Z2D = $85;$92 = $$pre$i$i$i21;$96 = $$pre46;$98 = $$pre47;
 } else {
  $90 = Math_fround(HEAPF32[$86>>2]);
  HEAPF32[$85>>2] = $90;
  HEAP32[$1>>2] = $87;
  $91 = (HEAPF32[tempDoublePtr>>2]=$90,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i22Z2D = $85;$92 = $91;$96 = $87;$98 = $88;
 }
 $93 = (_llvm_bswap_i32(($92|0))|0);
 HEAP32[$$pre$phi$i$i$i22Z2D>>2] = $93;
 $94 = (($this) + 408|0);
 $95 = (($96) + 4|0);
 $97 = ($95>>>0)>($98>>>0);
 if ($97) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$94,4);
  $$pre$i$i$i26 = HEAP32[$94>>2]|0;
  $$pre48 = HEAP32[$1>>2]|0;
  $$pre49 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i27Z2D = $94;$101 = $$pre$i$i$i26;$105 = $$pre48;$107 = $$pre49;
 } else {
  $99 = Math_fround(HEAPF32[$96>>2]);
  HEAPF32[$94>>2] = $99;
  HEAP32[$1>>2] = $95;
  $100 = (HEAPF32[tempDoublePtr>>2]=$99,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i27Z2D = $94;$101 = $100;$105 = $95;$107 = $98;
 }
 $102 = (_llvm_bswap_i32(($101|0))|0);
 HEAP32[$$pre$phi$i$i$i27Z2D>>2] = $102;
 $103 = (($this) + 412|0);
 $104 = (($105) + 4|0);
 $106 = ($104>>>0)>($107>>>0);
 if ($106) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$103,4);
  $$pre$i$i$i31 = HEAP32[$103>>2]|0;
  $$pre$phi$i$i$i32Z2D = $103;$110 = $$pre$i$i$i31;
 } else {
  $108 = Math_fround(HEAPF32[$105>>2]);
  HEAPF32[$103>>2] = $108;
  HEAP32[$1>>2] = $104;
  $109 = (HEAPF32[tempDoublePtr>>2]=$108,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i32Z2D = $103;$110 = $109;
 }
 $111 = (_llvm_bswap_i32(($110|0))|0);
 HEAP32[$$pre$phi$i$i$i32Z2D>>2] = $111;
 $112 = (($this) + 456|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($112,$transfer);
 $113 = (($this) + 452|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($113,$transfer);
 $114 = (($this) + 472|0);
 $115 = HEAP32[$1>>2]|0;
 $116 = (($115) + 4|0);
 $117 = HEAP32[$4>>2]|0;
 $118 = ($116>>>0)>($117>>>0);
 if ($118) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$114,4);
  $$pre$i$i$i34 = HEAP32[$114>>2]|0;
  $$pre50 = HEAP32[$1>>2]|0;
  $$pre51 = HEAP32[$4>>2]|0;
  $120 = $$pre$i$i$i34;$124 = $$pre50;$126 = $$pre51;
 } else {
  $119 = HEAP32[$115>>2]|0;
  HEAP32[$114>>2] = $119;
  HEAP32[$1>>2] = $116;
  $120 = $119;$124 = $116;$126 = $117;
 }
 $121 = (_llvm_bswap_i32(($120|0))|0);
 HEAP32[$114>>2] = $121;
 $122 = (($this) + 468|0);
 $123 = (($124) + 4|0);
 $125 = ($123>>>0)>($126>>>0);
 if ($125) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$122,4);
  $$pre$i$i$i38 = HEAP32[$122>>2]|0;
  $$pre$phi$i$i$i39Z2D = $122;$129 = $$pre$i$i$i38;
  $130 = (_llvm_bswap_i32(($129|0))|0);
  HEAP32[$$pre$phi$i$i$i39Z2D>>2] = $130;
  $131 = (($this) + 476|0);
  __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb1EEEEvRT_($131,$transfer);
  $132 = (($this) + 480|0);
  __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb1EEEEvRT_($132,$transfer);
  STACKTOP = sp;return;
 } else {
  $127 = Math_fround(HEAPF32[$124>>2]);
  HEAPF32[$122>>2] = $127;
  HEAP32[$1>>2] = $123;
  $128 = (HEAPF32[tempDoublePtr>>2]=$127,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i39Z2D = $122;$129 = $128;
  $130 = (_llvm_bswap_i32(($129|0))|0);
  HEAP32[$$pre$phi$i$i$i39Z2D>>2] = $130;
  $131 = (($this) + 476|0);
  __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb1EEEEvRT_($131,$transfer);
  $132 = (($this) + 480|0);
  __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb1EEEEvRT_($132,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN14RenderSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN16LevelGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 416|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $10 = (($this) + 424|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 420|0);
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$4>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $19 = $$pre;$21 = $$pre10;
 } else {
  $16 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$1>>2] = $13;
  $19 = $13;$21 = $14;
 }
 $17 = (($this) + 448|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$17,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $25 = $$pre11;$27 = $$pre12;
 } else {
  $22 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$17>>2] = $22;
  HEAP32[$1>>2] = $18;
  $25 = $18;$27 = $21;
 }
 $23 = (($this) + 440|0);
 $24 = (($25) + 4|0);
 $26 = ($24>>>0)>($27>>>0);
 if ($26) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$23,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $31 = $$pre13;$33 = $$pre14;
 } else {
  $28 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$23>>2] = $28;
  HEAP32[$1>>2] = $24;
  $31 = $24;$33 = $27;
 }
 $29 = (($this) + 444|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$29,4);
 } else {
  $34 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$29>>2] = $34;
  HEAP32[$1>>2] = $30;
 }
 $35 = (($this) + 24|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($35,$transfer);
 $36 = (($this) + 40|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($36,$transfer);
 $37 = (($this) + 56|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($37,$transfer);
 $38 = (($this) + 288|0);
 $39 = HEAP32[$1>>2]|0;
 $40 = (($39) + 4|0);
 $41 = HEAP32[$4>>2]|0;
 $42 = ($40>>>0)>($41>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
 } else {
  $43 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$38>>2] = $43;
  HEAP32[$1>>2] = $40;
 }
 $44 = (($this) + 72|0);
 __ZN19SphericalHarmonics38TransferI18StreamedBinaryReadILb0EEEEvRT_($44,$transfer);
 $45 = (($this) + 180|0);
 __ZN19SphericalHarmonics38TransferI18StreamedBinaryReadILb0EEEEvRT_($45,$transfer);
 $46 = (($this) + 292|0);
 $47 = HEAP32[$1>>2]|0;
 $48 = (($47) + 4|0);
 $49 = HEAP32[$4>>2]|0;
 $50 = ($48>>>0)>($49>>>0);
 if ($50) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$46,4);
 } else {
  $51 = HEAP32[$47>>2]|0;
  HEAP32[$46>>2] = $51;
  HEAP32[$1>>2] = $48;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $52 = (($this) + 464|0);
 __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($52,$transfer);
 $53 = (($this) + 404|0);
 $54 = HEAP32[$1>>2]|0;
 $55 = (($54) + 4|0);
 $56 = HEAP32[$4>>2]|0;
 $57 = ($55>>>0)>($56>>>0);
 if ($57) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$53,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $61 = $$pre15;$63 = $$pre16;
 } else {
  $58 = Math_fround(HEAPF32[$54>>2]);
  HEAPF32[$53>>2] = $58;
  HEAP32[$1>>2] = $55;
  $61 = $55;$63 = $56;
 }
 $59 = (($this) + 408|0);
 $60 = (($61) + 4|0);
 $62 = ($60>>>0)>($63>>>0);
 if ($62) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$59,4);
  $$pre17 = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $67 = $$pre17;$69 = $$pre18;
 } else {
  $64 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$59>>2] = $64;
  HEAP32[$1>>2] = $60;
  $67 = $60;$69 = $63;
 }
 $65 = (($this) + 412|0);
 $66 = (($67) + 4|0);
 $68 = ($66>>>0)>($69>>>0);
 if ($68) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$65,4);
 } else {
  $70 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$65>>2] = $70;
  HEAP32[$1>>2] = $66;
 }
 $71 = (($this) + 456|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($71,$transfer);
 $72 = (($this) + 452|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($72,$transfer);
 $73 = (($this) + 472|0);
 $74 = HEAP32[$1>>2]|0;
 $75 = (($74) + 4|0);
 $76 = HEAP32[$4>>2]|0;
 $77 = ($75>>>0)>($76>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$73,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $81 = $$pre19;$83 = $$pre20;
 } else {
  $78 = HEAP32[$74>>2]|0;
  HEAP32[$73>>2] = $78;
  HEAP32[$1>>2] = $75;
  $81 = $75;$83 = $76;
 }
 $79 = (($this) + 468|0);
 $80 = (($81) + 4|0);
 $82 = ($80>>>0)>($83>>>0);
 if ($82) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$79,4);
  $85 = (($this) + 476|0);
  __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb0EEEEvRT_($85,$transfer);
  $86 = (($this) + 480|0);
  __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb0EEEEvRT_($86,$transfer);
  STACKTOP = sp;return;
 } else {
  $84 = Math_fround(HEAPF32[$81>>2]);
  HEAPF32[$79>>2] = $84;
  HEAP32[$1>>2] = $80;
  $85 = (($this) + 476|0);
  __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb0EEEEvRT_($85,$transfer);
  $86 = (($this) + 480|0);
  __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb0EEEEvRT_($86,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI7CubemapE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN19SphericalHarmonics38TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i22 = 0, $$pre$i$i$i29 = 0, $$pre$i$i$i36 = 0, $$pre$i$i$i43 = 0, $$pre$i$i$i50 = 0, $$pre$i$i$i8 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i16 = 0, $$pre3$i$i$i2 = 0, $$pre3$i$i$i23 = 0, $$pre3$i$i$i30 = 0, $$pre3$i$i$i37 = 0, $$pre3$i$i$i44 = 0, $$pre3$i$i$i51 = 0, $$pre3$i$i$i9 = 0, $$pre4$i$i$i = 0;
 var $$pre4$i$i$i11 = 0, $$pre4$i$i$i18 = 0, $$pre4$i$i$i25 = 0, $$pre4$i$i$i32 = 0, $$pre4$i$i$i39 = 0, $$pre4$i$i$i4 = 0, $$pre4$i$i$i46 = 0, $$pre4$i$i$i53 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i12 = 0, $$pre5$i$i$i19 = 0, $$pre5$i$i$i26 = 0, $$pre5$i$i$i33 = 0, $$pre5$i$i$i40 = 0, $$pre5$i$i$i47 = 0, $$pre5$i$i$i5 = 0, $$pre5$i$i$i54 = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0;
 var $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $$pre71 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0);
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre3$i$i$i = HEAP32[$3>>2]|0;
  $11 = $$pre3$i$i$i;$9 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre4$i$i$i = HEAP32[$0>>2]|0;
  $$pre5$i$i$i = HEAP32[$3>>2]|0;
  $15 = $$pre4$i$i$i;$17 = $$pre5$i$i$i;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre57 = HEAP32[$3>>2]|0;
  $21 = $$pre;$23 = $$pre57;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i2 = HEAP32[$3>>2]|0;
  $27 = $$pre$i$i$i1;$29 = $$pre3$i$i$i2;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre4$i$i$i4 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i5 = HEAP32[$3>>2]|0;
  $33 = $$pre4$i$i$i4;$35 = $$pre5$i$i$i5;
 } else {
  $30 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$31,4);
  $$pre58 = HEAP32[$0>>2]|0;
  $$pre59 = HEAP32[$3>>2]|0;
  $39 = $$pre58;$41 = $$pre59;
 } else {
  $36 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$31>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 }
 $37 = (($this) + 24|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre$i$i$i8 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i9 = HEAP32[$3>>2]|0;
  $45 = $$pre$i$i$i8;$47 = $$pre3$i$i$i9;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 }
 $43 = (($this) + 28|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)>($47>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$43,4);
  $$pre4$i$i$i11 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i12 = HEAP32[$3>>2]|0;
  $51 = $$pre4$i$i$i11;$53 = $$pre5$i$i$i12;
 } else {
  $48 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$43>>2] = $48;
  HEAP32[$0>>2] = $44;
  $51 = $44;$53 = $47;
 }
 $49 = (($this) + 32|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)>($53>>>0);
 if ($52) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$49,4);
  $$pre60 = HEAP32[$0>>2]|0;
  $$pre61 = HEAP32[$3>>2]|0;
  $57 = $$pre60;$59 = $$pre61;
 } else {
  $54 = Math_fround(HEAPF32[$51>>2]);
  HEAPF32[$49>>2] = $54;
  HEAP32[$0>>2] = $50;
  $57 = $50;$59 = $53;
 }
 $55 = (($this) + 36|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)>($59>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$55,4);
  $$pre$i$i$i15 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i16 = HEAP32[$3>>2]|0;
  $63 = $$pre$i$i$i15;$65 = $$pre3$i$i$i16;
 } else {
  $60 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$55>>2] = $60;
  HEAP32[$0>>2] = $56;
  $63 = $56;$65 = $59;
 }
 $61 = (($this) + 40|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)>($65>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$61,4);
  $$pre4$i$i$i18 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i19 = HEAP32[$3>>2]|0;
  $69 = $$pre4$i$i$i18;$71 = $$pre5$i$i$i19;
 } else {
  $66 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$61>>2] = $66;
  HEAP32[$0>>2] = $62;
  $69 = $62;$71 = $65;
 }
 $67 = (($this) + 44|0);
 $68 = (($69) + 4|0);
 $70 = ($68>>>0)>($71>>>0);
 if ($70) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$67,4);
  $$pre62 = HEAP32[$0>>2]|0;
  $$pre63 = HEAP32[$3>>2]|0;
  $75 = $$pre62;$77 = $$pre63;
 } else {
  $72 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$67>>2] = $72;
  HEAP32[$0>>2] = $68;
  $75 = $68;$77 = $71;
 }
 $73 = (($this) + 48|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)>($77>>>0);
 if ($76) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$73,4);
  $$pre$i$i$i22 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i23 = HEAP32[$3>>2]|0;
  $81 = $$pre$i$i$i22;$83 = $$pre3$i$i$i23;
 } else {
  $78 = Math_fround(HEAPF32[$75>>2]);
  HEAPF32[$73>>2] = $78;
  HEAP32[$0>>2] = $74;
  $81 = $74;$83 = $77;
 }
 $79 = (($this) + 52|0);
 $80 = (($81) + 4|0);
 $82 = ($80>>>0)>($83>>>0);
 if ($82) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$79,4);
  $$pre4$i$i$i25 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i26 = HEAP32[$3>>2]|0;
  $87 = $$pre4$i$i$i25;$89 = $$pre5$i$i$i26;
 } else {
  $84 = Math_fround(HEAPF32[$81>>2]);
  HEAPF32[$79>>2] = $84;
  HEAP32[$0>>2] = $80;
  $87 = $80;$89 = $83;
 }
 $85 = (($this) + 56|0);
 $86 = (($87) + 4|0);
 $88 = ($86>>>0)>($89>>>0);
 if ($88) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$85,4);
  $$pre64 = HEAP32[$0>>2]|0;
  $$pre65 = HEAP32[$3>>2]|0;
  $93 = $$pre64;$95 = $$pre65;
 } else {
  $90 = Math_fround(HEAPF32[$87>>2]);
  HEAPF32[$85>>2] = $90;
  HEAP32[$0>>2] = $86;
  $93 = $86;$95 = $89;
 }
 $91 = (($this) + 60|0);
 $92 = (($93) + 4|0);
 $94 = ($92>>>0)>($95>>>0);
 if ($94) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$91,4);
  $$pre$i$i$i29 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i30 = HEAP32[$3>>2]|0;
  $101 = $$pre3$i$i$i30;$99 = $$pre$i$i$i29;
 } else {
  $96 = Math_fround(HEAPF32[$93>>2]);
  HEAPF32[$91>>2] = $96;
  HEAP32[$0>>2] = $92;
  $101 = $95;$99 = $92;
 }
 $97 = (($this) + 64|0);
 $98 = (($99) + 4|0);
 $100 = ($98>>>0)>($101>>>0);
 if ($100) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$97,4);
  $$pre4$i$i$i32 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i33 = HEAP32[$3>>2]|0;
  $105 = $$pre4$i$i$i32;$107 = $$pre5$i$i$i33;
 } else {
  $102 = Math_fround(HEAPF32[$99>>2]);
  HEAPF32[$97>>2] = $102;
  HEAP32[$0>>2] = $98;
  $105 = $98;$107 = $101;
 }
 $103 = (($this) + 68|0);
 $104 = (($105) + 4|0);
 $106 = ($104>>>0)>($107>>>0);
 if ($106) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$103,4);
  $$pre66 = HEAP32[$0>>2]|0;
  $$pre67 = HEAP32[$3>>2]|0;
  $111 = $$pre66;$113 = $$pre67;
 } else {
  $108 = Math_fround(HEAPF32[$105>>2]);
  HEAPF32[$103>>2] = $108;
  HEAP32[$0>>2] = $104;
  $111 = $104;$113 = $107;
 }
 $109 = (($this) + 72|0);
 $110 = (($111) + 4|0);
 $112 = ($110>>>0)>($113>>>0);
 if ($112) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$109,4);
  $$pre$i$i$i36 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i37 = HEAP32[$3>>2]|0;
  $117 = $$pre$i$i$i36;$119 = $$pre3$i$i$i37;
 } else {
  $114 = Math_fround(HEAPF32[$111>>2]);
  HEAPF32[$109>>2] = $114;
  HEAP32[$0>>2] = $110;
  $117 = $110;$119 = $113;
 }
 $115 = (($this) + 76|0);
 $116 = (($117) + 4|0);
 $118 = ($116>>>0)>($119>>>0);
 if ($118) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$115,4);
  $$pre4$i$i$i39 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i40 = HEAP32[$3>>2]|0;
  $123 = $$pre4$i$i$i39;$125 = $$pre5$i$i$i40;
 } else {
  $120 = Math_fround(HEAPF32[$117>>2]);
  HEAPF32[$115>>2] = $120;
  HEAP32[$0>>2] = $116;
  $123 = $116;$125 = $119;
 }
 $121 = (($this) + 80|0);
 $122 = (($123) + 4|0);
 $124 = ($122>>>0)>($125>>>0);
 if ($124) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$121,4);
  $$pre68 = HEAP32[$0>>2]|0;
  $$pre69 = HEAP32[$3>>2]|0;
  $129 = $$pre68;$131 = $$pre69;
 } else {
  $126 = Math_fround(HEAPF32[$123>>2]);
  HEAPF32[$121>>2] = $126;
  HEAP32[$0>>2] = $122;
  $129 = $122;$131 = $125;
 }
 $127 = (($this) + 84|0);
 $128 = (($129) + 4|0);
 $130 = ($128>>>0)>($131>>>0);
 if ($130) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$127,4);
  $$pre$i$i$i43 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i44 = HEAP32[$3>>2]|0;
  $135 = $$pre$i$i$i43;$137 = $$pre3$i$i$i44;
 } else {
  $132 = Math_fround(HEAPF32[$129>>2]);
  HEAPF32[$127>>2] = $132;
  HEAP32[$0>>2] = $128;
  $135 = $128;$137 = $131;
 }
 $133 = (($this) + 88|0);
 $134 = (($135) + 4|0);
 $136 = ($134>>>0)>($137>>>0);
 if ($136) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$133,4);
  $$pre4$i$i$i46 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i47 = HEAP32[$3>>2]|0;
  $141 = $$pre4$i$i$i46;$143 = $$pre5$i$i$i47;
 } else {
  $138 = Math_fround(HEAPF32[$135>>2]);
  HEAPF32[$133>>2] = $138;
  HEAP32[$0>>2] = $134;
  $141 = $134;$143 = $137;
 }
 $139 = (($this) + 92|0);
 $140 = (($141) + 4|0);
 $142 = ($140>>>0)>($143>>>0);
 if ($142) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$139,4);
  $$pre70 = HEAP32[$0>>2]|0;
  $$pre71 = HEAP32[$3>>2]|0;
  $147 = $$pre70;$149 = $$pre71;
 } else {
  $144 = Math_fround(HEAPF32[$141>>2]);
  HEAPF32[$139>>2] = $144;
  HEAP32[$0>>2] = $140;
  $147 = $140;$149 = $143;
 }
 $145 = (($this) + 96|0);
 $146 = (($147) + 4|0);
 $148 = ($146>>>0)>($149>>>0);
 if ($148) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$145,4);
  $$pre$i$i$i50 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i51 = HEAP32[$3>>2]|0;
  $153 = $$pre$i$i$i50;$155 = $$pre3$i$i$i51;
 } else {
  $150 = Math_fround(HEAPF32[$147>>2]);
  HEAPF32[$145>>2] = $150;
  HEAP32[$0>>2] = $146;
  $153 = $146;$155 = $149;
 }
 $151 = (($this) + 100|0);
 $152 = (($153) + 4|0);
 $154 = ($152>>>0)>($155>>>0);
 if ($154) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$151,4);
  $$pre4$i$i$i53 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i54 = HEAP32[$3>>2]|0;
  $159 = $$pre4$i$i$i53;$161 = $$pre5$i$i$i54;
 } else {
  $156 = Math_fround(HEAPF32[$153>>2]);
  HEAPF32[$151>>2] = $156;
  HEAP32[$0>>2] = $152;
  $159 = $152;$161 = $155;
 }
 $157 = (($this) + 104|0);
 $158 = (($159) + 4|0);
 $160 = ($158>>>0)>($161>>>0);
 if ($160) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$157,4);
  STACKTOP = sp;return;
 } else {
  $162 = Math_fround(HEAPF32[$159>>2]);
  HEAPF32[$157>>2] = $162;
  HEAP32[$0>>2] = $158;
  STACKTOP = sp;return;
 }
}
function __ZN14RenderSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $converter$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i9 = sp;
 __ZN16LevelGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,4);
 $0 = (($this) + 416|0);
 $1 = HEAP32[580544>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575344,$1,$converter$i$i9,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  do {
   if ($4) {
    $5 = (($transfer) + 12|0);
    $6 = (($transfer) + 80|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($transfer) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($transfer) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($transfer) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = Math_imul($15, $13)|0;
    $$sum$i$i$i$i$i = (($9) - ($16))|0;
    $17 = (($11) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$5>>2] = $17;
    $18 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($18)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $19 = (($11) + ($$sum1$i$i$i$i$i)|0);
     $20 = (($transfer) + 20|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($19>>>0)>($21>>>0);
     if (!($22)) {
      $23 = HEAP8[$17>>0]|0;
      HEAP8[$0>>0] = $23;
      $24 = HEAP32[$5>>2]|0;
      $25 = (($24) + 1|0);
      HEAP32[$5>>2] = $25;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($5,$0,1);
   } else {
    $26 = HEAP32[$converter$i$i9>>2]|0;
    $27 = ($26|0)==(0|0);
    if (!($27)) {
     (FUNCTION_TABLE_iii[$26 & 4095]($0,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $28 = (($this) + 424|0);
 __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($transfer,$28,575352,0);
 $29 = (($this) + 420|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$29,575368,0);
 $30 = (($this) + 448|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$30,575384,0);
 $31 = (($this) + 440|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$31,575400,0);
 $32 = (($this) + 444|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$32,575424,0);
 $33 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($transfer,$33,575440,0);
 $34 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($transfer,$34,575464,0);
 $35 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($transfer,$35,575488,0);
 $36 = (($this) + 288|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$36,575512,0);
 $37 = (($this) + 72|0);
 $38 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575536,575984,$converter$i$i9,1)|0);
 $39 = ($38|0)==(0);
 if (!($39)) {
  $40 = ($38|0)>(0);
  if ($40) {
   __ZN19SphericalHarmonics38TransferI14SafeBinaryReadEEvRT_($37,$transfer);
  } else {
   $41 = HEAP32[$converter$i$i9>>2]|0;
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    (FUNCTION_TABLE_iii[$41 & 4095]($37,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $43 = (($this) + 180|0);
 $44 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575552,575984,$converter$i$i9,1)|0);
 $45 = ($44|0)==(0);
 if (!($45)) {
  $46 = ($44|0)>(0);
  if ($46) {
   __ZN19SphericalHarmonics38TransferI14SafeBinaryReadEEvRT_($43,$transfer);
  } else {
   $47 = HEAP32[$converter$i$i9>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    (FUNCTION_TABLE_iii[$47 & 4095]($43,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $49 = (($this) + 292|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$49,575576,0);
 $50 = (($this) + 464|0);
 $51 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575592,575968,$converter$i$i9,1)|0);
 $52 = ($51|0)==(0);
 if (!($52)) {
  $53 = ($51|0)>(0);
  if ($53) {
   __ZN4PPtrIN5Unity8MaterialEE8TransferI14SafeBinaryReadEEvRT_($50,$transfer);
  } else {
   $54 = HEAP32[$converter$i$i9>>2]|0;
   $55 = ($54|0)==(0|0);
   if (!($55)) {
    (FUNCTION_TABLE_iii[$54 & 4095]($50,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $56 = (($this) + 404|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$56,575616,0);
 $57 = (($this) + 408|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$57,575632,0);
 $58 = (($this) + 412|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$58,575648,0);
 $59 = (($this) + 456|0);
 $60 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575672,575952,$converter$i$i9,1)|0);
 $61 = ($60|0)==(0);
 if (!($61)) {
  $62 = ($60|0)>(0);
  if ($62) {
   __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($59,$transfer);
  } else {
   $63 = HEAP32[$converter$i$i9>>2]|0;
   $64 = ($63|0)==(0|0);
   if (!($64)) {
    (FUNCTION_TABLE_iii[$63 & 4095]($59,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $65 = (($this) + 452|0);
 $66 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575688,575952,$converter$i$i9,1)|0);
 $67 = ($66|0)==(0);
 if (!($67)) {
  $68 = ($66|0)>(0);
  if ($68) {
   __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($65,$transfer);
  } else {
   $69 = HEAP32[$converter$i$i9>>2]|0;
   $70 = ($69|0)==(0|0);
   if (!($70)) {
    (FUNCTION_TABLE_iii[$69 & 4095]($65,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $71 = (($this) + 472|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$71,575704,0);
 $72 = (($this) + 468|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$72,575728,0);
 $73 = (($this) + 476|0);
 $74 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575752,575936,$converter$i$i9,1)|0);
 $75 = ($74|0)==(0);
 if (!($75)) {
  $76 = ($74|0)>(0);
  if ($76) {
   __ZN4PPtrI7CubemapE8TransferI14SafeBinaryReadEEvRT_($73,$transfer);
  } else {
   $77 = HEAP32[$converter$i$i9>>2]|0;
   $78 = ($77|0)==(0|0);
   if (!($78)) {
    (FUNCTION_TABLE_iii[$77 & 4095]($73,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $79 = (($this) + 480|0);
 $80 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575776,575936,$converter$i$i9,1)|0);
 $81 = ($80|0)==(0);
 if ($81) {
  __ZN14RenderSettings18TransferDeprecatedI14SafeBinaryReadEEvRT_($this,$transfer);
  STACKTOP = sp;return;
 }
 $82 = ($80|0)>(0);
 if ($82) {
  __ZN4PPtrI7CubemapE8TransferI14SafeBinaryReadEEvRT_($79,$transfer);
 } else {
  $83 = HEAP32[$converter$i$i9>>2]|0;
  $84 = ($83|0)==(0|0);
  if (!($84)) {
   (FUNCTION_TABLE_iii[$83 & 4095]($79,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 __ZN14RenderSettings18TransferDeprecatedI14SafeBinaryReadEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings18TransferDeprecatedI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 if ($0) {
  $1 = (($this) + 24|0);
  __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($transfer,$1,575304,0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $3 = (($this) + 28|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($this) + 32|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($this) + 36|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($this) + 40|0);
  HEAPF32[$9>>2] = $2;
  $10 = (($this) + 44|0);
  HEAPF32[$10>>2] = $4;
  $11 = (($this) + 48|0);
  HEAPF32[$11>>2] = $6;
  $12 = (($this) + 52|0);
  HEAPF32[$12>>2] = $8;
  $13 = (($this) + 56|0);
  HEAPF32[$13>>2] = $2;
  $14 = (($this) + 60|0);
  HEAPF32[$14>>2] = $4;
  $15 = (($this) + 64|0);
  HEAPF32[$15>>2] = $6;
  $16 = (($this) + 68|0);
  HEAPF32[$16>>2] = $8;
  $17 = (($this) + 292|0);
  HEAP32[$17>>2] = 3;
 }
 $18 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,3)|0);
 if ($18) {
  $19 = (($this) + 292|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(3);
  if ($21) {
   $22 = (($this) + 40|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = (($this) + 44|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = (($this) + 48|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = (($this) + 52|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = (($this) + 24|0);
   HEAPF32[$30>>2] = $23;
   $31 = (($this) + 28|0);
   HEAPF32[$31>>2] = $25;
   $32 = (($this) + 32|0);
   HEAPF32[$32>>2] = $27;
   $33 = (($this) + 36|0);
   HEAPF32[$33>>2] = $29;
  }
 }
 $34 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,2)|0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 $35 = (($this) + 180|0);
 $36 = (($this) + 72|0);
 dest=$35+0|0; src=$36+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN4PPtrI7CubemapE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,575808,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,575824,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,575808,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,575824,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,575808,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,575824,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,575808,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,575824,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN19SphericalHarmonics38TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $converter$i$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i15 = sp;
 $0 = HEAP32[580776>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575840,$0,$converter$i$i15,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$this,575912,0);
   $4 = (($this) + 4|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$4,575920,0);
   $5 = (($this) + 8|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,575928,0);
  } else {
   $6 = HEAP32[$converter$i$i15>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    (FUNCTION_TABLE_iii[$6 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $8 = (($this) + 12|0);
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575848,$0,$converter$i$i15,1)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = ($9|0)>(0);
  if ($11) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$8,575912,0);
   $12 = (($this) + 16|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,575920,0);
   $13 = (($this) + 20|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,575928,0);
  } else {
   $14 = HEAP32[$converter$i$i15>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    (FUNCTION_TABLE_iii[$14 & 4095]($8,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $16 = (($this) + 24|0);
 $17 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575856,$0,$converter$i$i15,1)|0);
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = ($17|0)>(0);
  if ($19) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,575912,0);
   $20 = (($this) + 28|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$20,575920,0);
   $21 = (($this) + 32|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$21,575928,0);
  } else {
   $22 = HEAP32[$converter$i$i15>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    (FUNCTION_TABLE_iii[$22 & 4095]($16,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $24 = (($this) + 36|0);
 $25 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575864,$0,$converter$i$i15,1)|0);
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = ($25|0)>(0);
  if ($27) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$24,575912,0);
   $28 = (($this) + 40|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$28,575920,0);
   $29 = (($this) + 44|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$29,575928,0);
  } else {
   $30 = HEAP32[$converter$i$i15>>2]|0;
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    (FUNCTION_TABLE_iii[$30 & 4095]($24,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $32 = (($this) + 48|0);
 $33 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575872,$0,$converter$i$i15,1)|0);
 $34 = ($33|0)==(0);
 if (!($34)) {
  $35 = ($33|0)>(0);
  if ($35) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$32,575912,0);
   $36 = (($this) + 52|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$36,575920,0);
   $37 = (($this) + 56|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$37,575928,0);
  } else {
   $38 = HEAP32[$converter$i$i15>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    (FUNCTION_TABLE_iii[$38 & 4095]($32,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $40 = (($this) + 60|0);
 $41 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575880,$0,$converter$i$i15,1)|0);
 $42 = ($41|0)==(0);
 if (!($42)) {
  $43 = ($41|0)>(0);
  if ($43) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$40,575912,0);
   $44 = (($this) + 64|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$44,575920,0);
   $45 = (($this) + 68|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$45,575928,0);
  } else {
   $46 = HEAP32[$converter$i$i15>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    (FUNCTION_TABLE_iii[$46 & 4095]($40,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $48 = (($this) + 72|0);
 $49 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575888,$0,$converter$i$i15,1)|0);
 $50 = ($49|0)==(0);
 if (!($50)) {
  $51 = ($49|0)>(0);
  if ($51) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$48,575912,0);
   $52 = (($this) + 76|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$52,575920,0);
   $53 = (($this) + 80|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$53,575928,0);
  } else {
   $54 = HEAP32[$converter$i$i15>>2]|0;
   $55 = ($54|0)==(0|0);
   if (!($55)) {
    (FUNCTION_TABLE_iii[$54 & 4095]($48,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $56 = (($this) + 84|0);
 $57 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575896,$0,$converter$i$i15,1)|0);
 $58 = ($57|0)==(0);
 if (!($58)) {
  $59 = ($57|0)>(0);
  if ($59) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$56,575912,0);
   $60 = (($this) + 88|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$60,575920,0);
   $61 = (($this) + 92|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$61,575928,0);
  } else {
   $62 = HEAP32[$converter$i$i15>>2]|0;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    (FUNCTION_TABLE_iii[$62 & 4095]($56,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $64 = (($this) + 96|0);
 $65 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,575904,$0,$converter$i$i15,1)|0);
 $66 = ($65|0)==(0);
 if ($66) {
  STACKTOP = sp;return;
 }
 $67 = ($65|0)>(0);
 if ($67) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$64,575912,0);
  $68 = (($this) + 100|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$68,575920,0);
  $69 = (($this) + 104|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$69,575928,0);
 } else {
  $70 = HEAP32[$converter$i$i15>>2]|0;
  $71 = ($70|0)==(0|0);
  if (!($71)) {
   (FUNCTION_TABLE_iii[$70 & 4095]($64,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14RenderSettings8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $localIdentifier$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i4 = sp;
 __ZN16LevelGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,4);
 $0 = (($this) + 416|0);
 $1 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575344,$1,$0,2048);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $8 = (($this) + 424|0);
 $9 = HEAP32[580560>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575352,$9,$8,2048);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($8,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 420|0);
 $11 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575368,$11,$10,2048);
 $12 = HEAP32[$2>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$5>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 448|0);
 $17 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575384,$17,$16,2048);
 $18 = HEAP32[$2>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$5>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 440|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575400,$17,$22,2048);
 $23 = HEAP32[$2>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$5>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $27 = (($this) + 444|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575424,$17,$27,2048);
 $28 = HEAP32[$2>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$5>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575440,$9,$32,0);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($32,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575464,$9,$33,0);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($33,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $34 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575488,$9,$34,0);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($34,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $35 = (($this) + 288|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575512,$17,$35,0);
 $36 = HEAP32[$2>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$5>>2]|0;
 $39 = ((($37) + (($38*24)|0)|0) + 12|0);
 HEAP32[$39>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $40 = (($this) + 72|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575536,575984,$40,0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$40,575840,0);
 $41 = (($this) + 84|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$41,575848,0);
 $42 = (($this) + 96|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$42,575856,0);
 $43 = (($this) + 108|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$43,575864,0);
 $44 = (($this) + 120|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$44,575872,0);
 $45 = (($this) + 132|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$45,575880,0);
 $46 = (($this) + 144|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$46,575888,0);
 $47 = (($this) + 156|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$47,575896,0);
 $48 = (($this) + 168|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$48,575904,0);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $49 = (($this) + 180|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575552,575984,$49,0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$49,575840,0);
 $50 = (($this) + 192|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$50,575848,0);
 $51 = (($this) + 204|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$51,575856,0);
 $52 = (($this) + 216|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$52,575864,0);
 $53 = (($this) + 228|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$53,575872,0);
 $54 = (($this) + 240|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$54,575880,0);
 $55 = (($this) + 252|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$55,575888,0);
 $56 = (($this) + 264|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$56,575896,0);
 $57 = (($this) + 276|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$57,575904,0);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $58 = (($this) + 292|0);
 $59 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575576,$59,$58,0);
 $60 = HEAP32[$2>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$5>>2]|0;
 $63 = ((($61) + (($62*24)|0)|0) + 12|0);
 HEAP32[$63>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $64 = (($this) + 464|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575592,575968,$64,2048);
 $65 = (($localIdentifier$i$i$i4) + 8|0);
 $66 = $65;
 $67 = $66;
 HEAP32[$67>>2] = 0;
 $68 = (($66) + 4)|0;
 $69 = $68;
 HEAP32[$69>>2] = 0;
 HEAP32[$localIdentifier$i$i$i4>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575808,$59,$64,1);
 $70 = HEAP32[$2>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$5>>2]|0;
 $73 = ((($71) + (($72*24)|0)|0) + 12|0);
 HEAP32[$73>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $74 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575824,$74,$65,1);
 $75 = HEAP32[$2>>2]|0;
 $76 = HEAP32[$75>>2]|0;
 $77 = HEAP32[$5>>2]|0;
 $78 = ((($76) + (($77*24)|0)|0) + 12|0);
 HEAP32[$78>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $79 = (($this) + 404|0);
 $80 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575616,$80,$79,0);
 $81 = HEAP32[$2>>2]|0;
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$5>>2]|0;
 $84 = ((($82) + (($83*24)|0)|0) + 12|0);
 HEAP32[$84>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $85 = (($this) + 408|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575632,$80,$85,0);
 $86 = HEAP32[$2>>2]|0;
 $87 = HEAP32[$86>>2]|0;
 $88 = HEAP32[$5>>2]|0;
 $89 = ((($87) + (($88*24)|0)|0) + 12|0);
 HEAP32[$89>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $90 = (($this) + 412|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575648,$80,$90,0);
 $91 = HEAP32[$2>>2]|0;
 $92 = HEAP32[$91>>2]|0;
 $93 = HEAP32[$5>>2]|0;
 $94 = ((($92) + (($93*24)|0)|0) + 12|0);
 HEAP32[$94>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $95 = (($this) + 456|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575672,575952,$95,0);
 $96 = (($localIdentifier$i$i$i4) + 8|0);
 $97 = $96;
 $98 = $97;
 HEAP32[$98>>2] = 0;
 $99 = (($97) + 4)|0;
 $100 = $99;
 HEAP32[$100>>2] = 0;
 HEAP32[$localIdentifier$i$i$i4>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575808,$59,$95,1);
 $101 = HEAP32[$2>>2]|0;
 $102 = HEAP32[$101>>2]|0;
 $103 = HEAP32[$5>>2]|0;
 $104 = ((($102) + (($103*24)|0)|0) + 12|0);
 HEAP32[$104>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575824,$74,$96,1);
 $105 = HEAP32[$2>>2]|0;
 $106 = HEAP32[$105>>2]|0;
 $107 = HEAP32[$5>>2]|0;
 $108 = ((($106) + (($107*24)|0)|0) + 12|0);
 HEAP32[$108>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $109 = (($this) + 452|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575688,575952,$109,0);
 $110 = (($localIdentifier$i$i$i4) + 8|0);
 $111 = $110;
 $112 = $111;
 HEAP32[$112>>2] = 0;
 $113 = (($111) + 4)|0;
 $114 = $113;
 HEAP32[$114>>2] = 0;
 HEAP32[$localIdentifier$i$i$i4>>2] = 0;
 $115 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575808,$115,$109,1);
 $116 = HEAP32[$2>>2]|0;
 $117 = HEAP32[$116>>2]|0;
 $118 = HEAP32[$5>>2]|0;
 $119 = ((($117) + (($118*24)|0)|0) + 12|0);
 HEAP32[$119>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575824,$74,$110,1);
 $120 = HEAP32[$2>>2]|0;
 $121 = HEAP32[$120>>2]|0;
 $122 = HEAP32[$5>>2]|0;
 $123 = ((($121) + (($122*24)|0)|0) + 12|0);
 HEAP32[$123>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $124 = (($this) + 472|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575704,$115,$124,0);
 $125 = HEAP32[$2>>2]|0;
 $126 = HEAP32[$125>>2]|0;
 $127 = HEAP32[$5>>2]|0;
 $128 = ((($126) + (($127*24)|0)|0) + 12|0);
 HEAP32[$128>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $129 = (($this) + 468|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575728,$80,$129,0);
 $130 = HEAP32[$2>>2]|0;
 $131 = HEAP32[$130>>2]|0;
 $132 = HEAP32[$5>>2]|0;
 $133 = ((($131) + (($132*24)|0)|0) + 12|0);
 HEAP32[$133>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $134 = (($this) + 476|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575752,575936,$134,2048);
 $135 = (($localIdentifier$i$i$i4) + 8|0);
 $136 = $135;
 $137 = $136;
 HEAP32[$137>>2] = 0;
 $138 = (($136) + 4)|0;
 $139 = $138;
 HEAP32[$139>>2] = 0;
 HEAP32[$localIdentifier$i$i$i4>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575808,$115,$134,1);
 $140 = HEAP32[$2>>2]|0;
 $141 = HEAP32[$140>>2]|0;
 $142 = HEAP32[$5>>2]|0;
 $143 = ((($141) + (($142*24)|0)|0) + 12|0);
 HEAP32[$143>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $144 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575824,$144,$135,1);
 $145 = HEAP32[$2>>2]|0;
 $146 = HEAP32[$145>>2]|0;
 $147 = HEAP32[$5>>2]|0;
 $148 = ((($146) + (($147*24)|0)|0) + 12|0);
 HEAP32[$148>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $149 = (($this) + 480|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575776,575936,$149,2048);
 $150 = (($localIdentifier$i$i$i4) + 8|0);
 $151 = $150;
 $152 = $151;
 HEAP32[$152>>2] = 0;
 $153 = (($151) + 4)|0;
 $154 = $153;
 HEAP32[$154>>2] = 0;
 HEAP32[$localIdentifier$i$i$i4>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575808,$115,$149,1);
 $155 = HEAP32[$2>>2]|0;
 $156 = HEAP32[$155>>2]|0;
 $157 = HEAP32[$5>>2]|0;
 $158 = ((($156) + (($157*24)|0)|0) + 12|0);
 HEAP32[$158>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,575824,$144,$150,1);
 $159 = HEAP32[$2>>2]|0;
 $160 = HEAP32[$159>>2]|0;
 $161 = HEAP32[$5>>2]|0;
 $162 = ((($160) + (($161*24)|0)|0) + 12|0);
 HEAP32[$162>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580776>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$0,$data,$metaFlag);
 $1 = (($this) + 16|0);
 $2 = (__ZNK16TypeTreeIterator7GetNodeEv($1)|0);
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 | 2097152;
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($8) + (($10*24)|0)|0) + 20|0);
 HEAP32[$11>>2] = $5;
 $12 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,575912,$12,$data,0);
 $13 = HEAP32[$6>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$9>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $17 = (($data) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,575920,$12,$17,0);
 $18 = HEAP32[$6>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$9>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $22 = (($data) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,575928,$12,$22,0);
 $23 = HEAP32[$6>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$9>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a2431() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,575136);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[575128>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,575160);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[575152>>2] = $2;
 STACKTOP = sp;return;
}
function __Z25CalculateShadowCasterCullbPK5PlaneRK10Matrix4x4fRK8Vector3fff9LightTypeS7_R16ShadowCasterCullPKb($orthographic,$frustumCullPlanes,$clipToWorld,$apexWorld,$nearPlaneScale,$farPlaneScale,$lightType,$lightVec,$result,$alreadyTested) {
 $orthographic = $orthographic|0;
 $frustumCullPlanes = $frustumCullPlanes|0;
 $clipToWorld = $clipToWorld|0;
 $apexWorld = $apexWorld|0;
 $nearPlaneScale = Math_fround($nearPlaneScale);
 $farPlaneScale = Math_fround($farPlaneScale);
 $lightType = $lightType|0;
 $lightVec = $lightVec|0;
 $result = $result|0;
 $alreadyTested = $alreadyTested|0;
 var $$ph = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $edge$08 = 0, $edge3$02 = 0, $enablePlane = 0;
 var $facingLight = 0, $i$010 = 0, $i$010$us = 0, $nearFar$05 = 0, $tmp = 0, $tmp11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $facingLight = sp + 6|0;
 $enablePlane = sp;
 $0 = (($result) + 160|0);
 HEAP32[$0>>2] = 0;
 $1 = ($lightType|0)==(1);
 $2 = (($lightVec) + 4|0);
 $3 = (($lightVec) + 8|0);
 L1: do {
  if ($1) {
   $31 = 0;$i$010$us = 0;
   while(1) {
    $4 = (($frustumCullPlanes) + ($i$010$us<<4)|0);
    $5 = Math_fround(HEAPF32[$4>>2]);
    $6 = ((($frustumCullPlanes) + ($i$010$us<<4)|0) + 4|0);
    $7 = Math_fround(HEAPF32[$6>>2]);
    $8 = ((($frustumCullPlanes) + ($i$010$us<<4)|0) + 8|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = ((($frustumCullPlanes) + ($i$010$us<<4)|0) + 12|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    $12 = Math_fround(HEAPF32[$2>>2]);
    $13 = Math_fround(HEAPF32[$lightVec>>2]);
    $14 = Math_fround(HEAPF32[$3>>2]);
    $15 = Math_fround($7 * $12);
    $16 = Math_fround($5 * $13);
    $17 = Math_fround($9 * $14);
    $18 = Math_fround($16 + $15);
    $19 = Math_fround($18 + $17);
    $20 = $19 < Math_fround(0.0);
    $21 = (($facingLight) + ($i$010$us)|0);
    $22 = $20&1;
    HEAP8[$21>>0] = $22;
    $23 = (($enablePlane) + ($i$010$us)|0);
    HEAP8[$23>>0] = 1;
    $24 = (($facingLight) + ($i$010$us)|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = ($25<<24>>24)==(0);
    if ($26) {
     $134 = $31;
    } else {
     $27 = (($alreadyTested) + ($i$010$us)|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = ($28<<24>>24)==(0);
     if ($29) {
      $30 = (($31) + 1)|0;
      HEAP32[$0>>2] = $30;
      $32 = (($result) + ($31<<4)|0);
      HEAPF32[$32>>2] = $5;
      $33 = ((($result) + ($31<<4)|0) + 4|0);
      HEAPF32[$33>>2] = $7;
      $34 = ((($result) + ($31<<4)|0) + 8|0);
      HEAPF32[$34>>2] = $9;
      $35 = ((($result) + ($31<<4)|0) + 12|0);
      HEAPF32[$35>>2] = $11;
      $36 = HEAP32[$0>>2]|0;
      $37 = ($36|0)==(10);
      if ($37) {
       break;
      } else {
       $134 = $36;
      }
     } else {
      $134 = $31;
     }
    }
    $38 = (($i$010$us) + 1)|0;
    $39 = ($38|0)<(6);
    if ($39) {
     $31 = $134;$i$010$us = $38;
    } else {
     $edge$08 = 0;
     break L1;
    }
   }
   STACKTOP = sp;return;
  } else {
   $67 = 0;$i$010 = 0;
   while(1) {
    $40 = (($frustumCullPlanes) + ($i$010<<4)|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = ((($frustumCullPlanes) + ($i$010<<4)|0) + 4|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = ((($frustumCullPlanes) + ($i$010<<4)|0) + 8|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = ((($frustumCullPlanes) + ($i$010<<4)|0) + 12|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = Math_fround(HEAPF32[$2>>2]);
    $49 = Math_fround(HEAPF32[$lightVec>>2]);
    $50 = Math_fround(HEAPF32[$3>>2]);
    $51 = Math_fround($43 * $48);
    $52 = Math_fround($41 * $49);
    $53 = Math_fround($45 * $50);
    $54 = Math_fround($52 + $51);
    $55 = Math_fround($54 + $53);
    $56 = Math_fround($47 + $55);
    $57 = (($facingLight) + ($i$010)|0);
    HEAP8[$57>>0] = 0;
    $58 = (($enablePlane) + ($i$010)|0);
    HEAP8[$58>>0] = 1;
    $59 = $56 > Math_fround(-0.00999999977648258209228);
    if ($59) {
     HEAP8[$57>>0] = 1;
     $60 = $56 < Math_fround(0.00999999977648258209228);
     if ($60) {
      HEAP8[$58>>0] = 0;
     }
     $61 = $56 < Math_fround(0.0);
     if ($61) {
      $62 = Math_fround($47 - $56);
      $$ph = $62;
     } else {
      $$ph = $47;
     }
     $63 = (($alreadyTested) + ($i$010)|0);
     $64 = HEAP8[$63>>0]|0;
     $65 = ($64<<24>>24)==(0);
     if ($65) {
      $66 = (($67) + 1)|0;
      HEAP32[$0>>2] = $66;
      $68 = (($result) + ($67<<4)|0);
      HEAPF32[$68>>2] = $41;
      $69 = ((($result) + ($67<<4)|0) + 4|0);
      HEAPF32[$69>>2] = $43;
      $70 = ((($result) + ($67<<4)|0) + 8|0);
      HEAPF32[$70>>2] = $45;
      $71 = ((($result) + ($67<<4)|0) + 12|0);
      HEAPF32[$71>>2] = $$ph;
      $72 = HEAP32[$0>>2]|0;
      $73 = ($72|0)==(10);
      if ($73) {
       break;
      } else {
       $135 = $72;
      }
     } else {
      $135 = $67;
     }
    } else {
     $135 = $67;
    }
    $74 = (($i$010) + 1)|0;
    $75 = ($74|0)<(6);
    if ($75) {
     $67 = $135;$i$010 = $74;
    } else {
     $edge$08 = 0;
     break L1;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 while(1) {
  $76 = (576016 + ($edge$08<<2)|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($alreadyTested) + ($77)|0);
  $79 = HEAP8[$78>>0]|0;
  $80 = ($79<<24>>24)==(0);
  $81 = (($edge$08) + 1)|0;
  if ($80) {
   $82 = ($81|0)==(4);
   $tmp11 = $82 ? 0 : $81;
   $83 = (576016 + ($tmp11<<2)|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($facingLight) + ($77)|0);
   $86 = HEAP8[$85>>0]|0;
   $87 = (($facingLight) + ($84)|0);
   $88 = HEAP8[$87>>0]|0;
   $89 = ($86<<24>>24)==($88<<24>>24);
   if (!($89)) {
    $90 = (($enablePlane) + ($77)|0);
    $91 = HEAP8[$90>>0]|0;
    $92 = ($91<<24>>24)==(0);
    if (!($92)) {
     $93 = (($enablePlane) + ($84)|0);
     $94 = HEAP8[$93>>0]|0;
     $95 = ($94<<24>>24)==(0);
     if (!($95)) {
      $96 = HEAP32[$0>>2]|0;
      $97 = (($result) + ($96<<4)|0);
      $98 = (__ZL24AddShadowCasterCullPlanebPK5PlaneRK10Matrix4x4fRK8Vector3fffiii9LightTypeS7_RS_($orthographic,$frustumCullPlanes,$clipToWorld,$apexWorld,$nearPlaneScale,$farPlaneScale,$77,$84,5,$lightType,$lightVec,$97)|0);
      if ($98) {
       $99 = HEAP32[$0>>2]|0;
       $100 = (($99) + 1)|0;
       HEAP32[$0>>2] = $100;
       $101 = ($100|0)==(10);
       if ($101) {
        label = 30;
        break;
       }
      }
     }
    }
   }
  }
  $102 = ($81|0)<(4);
  if ($102) {
   $edge$08 = $81;
  } else {
   $nearFar$05 = 0;
   break;
  }
 }
 if ((label|0) == 30) {
  STACKTOP = sp;return;
 }
 L33: while(1) {
  $103 = (576032 + ($nearFar$05<<2)|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($alreadyTested) + ($104)|0);
  $106 = HEAP8[$105>>0]|0;
  $107 = ($106<<24>>24)==(0);
  if ($107) {
   $108 = (($facingLight) + ($104)|0);
   $109 = HEAP8[$108>>0]|0;
   $110 = (($enablePlane) + ($104)|0);
   $edge3$02 = 0;
   while(1) {
    $111 = (576016 + ($edge3$02<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($edge3$02) + 1)|0;
    $114 = ($113|0)==(4);
    $tmp = $114 ? 0 : $113;
    $115 = (576016 + ($tmp<<2)|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($facingLight) + ($112)|0);
    $118 = HEAP8[$117>>0]|0;
    $119 = ($109<<24>>24)==($118<<24>>24);
    if (!($119)) {
     $120 = HEAP8[$110>>0]|0;
     $121 = ($120<<24>>24)==(0);
     if (!($121)) {
      $122 = (($enablePlane) + ($112)|0);
      $123 = HEAP8[$122>>0]|0;
      $124 = ($123<<24>>24)==(0);
      if (!($124)) {
       $126 = HEAP32[$0>>2]|0;
       $127 = (($result) + ($126<<4)|0);
       $128 = (__ZL24AddShadowCasterCullPlanebPK5PlaneRK10Matrix4x4fRK8Vector3fffiii9LightTypeS7_RS_($orthographic,$frustumCullPlanes,$clipToWorld,$apexWorld,$nearPlaneScale,$farPlaneScale,$104,$112,$116,$lightType,$lightVec,$127)|0);
       if ($128) {
        $129 = HEAP32[$0>>2]|0;
        $130 = (($129) + 1)|0;
        HEAP32[$0>>2] = $130;
        $131 = ($130|0)==(10);
        if ($131) {
         label = 30;
         break L33;
        }
       }
      }
     }
    }
    $125 = ($113|0)<(4);
    if ($125) {
     $edge3$02 = $113;
    } else {
     break;
    }
   }
  }
  $132 = (($nearFar$05) + 1)|0;
  $133 = ($132|0)<(2);
  if ($133) {
   $nearFar$05 = $132;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 30) {
  STACKTOP = sp;return;
 }
}
function __ZL24AddShadowCasterCullPlanebPK5PlaneRK10Matrix4x4fRK8Vector3fffiii9LightTypeS7_RS_($orthographic,$frustumCullPlanes,$clipToWorld,$apexWorld,$nearPlaneScale,$farPlaneScale,$sideA,$sideB,$sideNeighbor,$lightType,$lightVec,$outPlane) {
 $orthographic = $orthographic|0;
 $frustumCullPlanes = $frustumCullPlanes|0;
 $clipToWorld = $clipToWorld|0;
 $apexWorld = $apexWorld|0;
 $nearPlaneScale = Math_fround($nearPlaneScale);
 $farPlaneScale = Math_fround($farPlaneScale);
 $sideA = $sideA|0;
 $sideB = $sideB|0;
 $sideNeighbor = $sideNeighbor|0;
 $lightType = $lightType|0;
 $lightVec = $lightVec|0;
 $outPlane = $outPlane|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $34 = 0;
 var $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0;
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[576128>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  HEAPF32[576056>>2] = Math_fround(-1.0);
  HEAPF32[((576056 + 4|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 8|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 12|0))>>2] = Math_fround(1.0);
  HEAPF32[((576056 + 16|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 20|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 24|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 28|0))>>2] = Math_fround(-1.0);
  HEAPF32[((576056 + 32|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 36|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 40|0))>>2] = Math_fround(1.0);
  HEAPF32[((576056 + 44|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 48|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 52|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 56|0))>>2] = Math_fround(-1.0);
  HEAPF32[((576056 + 60|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 64|0))>>2] = Math_fround(0.0);
  HEAPF32[((576056 + 68|0))>>2] = Math_fround(1.0);
  HEAP8[576128>>0] = 1;
 }
 $2 = (($frustumCullPlanes) + ($sideA<<4)|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($frustumCullPlanes) + ($sideB<<4)|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($3 + $5);
 $7 = ((($frustumCullPlanes) + ($sideA<<4)|0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = ((($frustumCullPlanes) + ($sideB<<4)|0) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 + $10);
 $12 = ((($frustumCullPlanes) + ($sideA<<4)|0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = ((($frustumCullPlanes) + ($sideB<<4)|0) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 + $15);
 $17 = (576056 + (($sideA*12)|0)|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (576056 + (($sideB*12)|0)|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 + $20);
 $22 = ((576056 + (($sideA*12)|0)|0) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = ((576056 + (($sideB*12)|0)|0) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 + $25);
 $27 = ((576056 + (($sideA*12)|0)|0) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = ((576056 + (($sideB*12)|0)|0) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 + $30);
 $32 = (576056 + (($sideNeighbor*12)|0)|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = ((576056 + (($sideNeighbor*12)|0)|0) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = ((576056 + (($sideNeighbor*12)|0)|0) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($21 - $33);
 $39 = Math_fround($26 - $35);
 $40 = Math_fround($31 - $37);
 $41 = Math_fround($21 + $33);
 $42 = Math_fround($26 + $35);
 $43 = Math_fround($31 + $37);
 $44 = $40 < Math_fround(0.0);
 $45 = $44 ? $nearPlaneScale : $farPlaneScale;
 $46 = $43 < Math_fround(0.0);
 $47 = $46 ? $nearPlaneScale : $farPlaneScale;
 $48 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $49 = Math_fround($38 * $48);
 $50 = (($clipToWorld) + 16|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($39 * $51);
 $53 = Math_fround($49 + $52);
 $54 = (($clipToWorld) + 32|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($40 * $55);
 $57 = Math_fround($53 + $56);
 $58 = (($clipToWorld) + 48|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 + $57);
 $61 = (($clipToWorld) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround($38 * $62);
 $64 = (($clipToWorld) + 20|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($39 * $65);
 $67 = Math_fround($63 + $66);
 $68 = (($clipToWorld) + 36|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($40 * $69);
 $71 = Math_fround($67 + $70);
 $72 = (($clipToWorld) + 52|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 + $71);
 $75 = (($clipToWorld) + 8|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($38 * $76);
 $78 = (($clipToWorld) + 24|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($39 * $79);
 $81 = Math_fround($77 + $80);
 $82 = (($clipToWorld) + 40|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($40 * $83);
 $85 = Math_fround($81 + $84);
 $86 = (($clipToWorld) + 56|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($87 + $85);
 $89 = (($clipToWorld) + 12|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($38 * $90);
 $92 = (($clipToWorld) + 28|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($39 * $93);
 $95 = Math_fround($91 + $94);
 $96 = (($clipToWorld) + 44|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($40 * $97);
 $99 = Math_fround($95 + $98);
 $100 = (($clipToWorld) + 60|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($101 + $99);
 $103 = $102 < Math_fround(0.0);
 if ($orthographic) {
  if ($103) {
   $104 = Math_fround(-$102);
   $106 = $104;
  } else {
   $106 = $102;
  }
  $105 = $106 > Math_fround(1.00000001168609742308E-7);
  if ($105) {
   $107 = Math_fround(Math_fround(1.0) / $102);
   $108 = Math_fround($60 * $107);
   $109 = Math_fround($74 * $107);
   $110 = Math_fround($88 * $107);
   $327 = $110;$328 = $109;$329 = $108;
  } else {
   $327 = Math_fround(0.0);$328 = Math_fround(0.0);$329 = Math_fround(0.0);
  }
  $111 = Math_fround($41 * $48);
  $112 = Math_fround($42 * $51);
  $113 = Math_fround($111 + $112);
  $114 = Math_fround($43 * $55);
  $115 = Math_fround($113 + $114);
  $116 = Math_fround($59 + $115);
  $117 = Math_fround($41 * $62);
  $118 = Math_fround($42 * $65);
  $119 = Math_fround($117 + $118);
  $120 = Math_fround($43 * $69);
  $121 = Math_fround($119 + $120);
  $122 = Math_fround($73 + $121);
  $123 = Math_fround($41 * $76);
  $124 = Math_fround($42 * $79);
  $125 = Math_fround($123 + $124);
  $126 = Math_fround($43 * $83);
  $127 = Math_fround($125 + $126);
  $128 = Math_fround($87 + $127);
  $129 = Math_fround($41 * $90);
  $130 = Math_fround($42 * $93);
  $131 = Math_fround($129 + $130);
  $132 = Math_fround($43 * $97);
  $133 = Math_fround($131 + $132);
  $134 = Math_fround($101 + $133);
  $135 = $134 < Math_fround(0.0);
  if ($135) {
   $136 = Math_fround(-$134);
   $138 = $136;
  } else {
   $138 = $134;
  }
  $137 = $138 > Math_fround(1.00000001168609742308E-7);
  if ($137) {
   $139 = Math_fround(Math_fround(1.0) / $134);
   $140 = Math_fround($116 * $139);
   $141 = Math_fround($122 * $139);
   $142 = Math_fround($128 * $139);
   $213 = $329;$214 = $140;$216 = $328;$217 = $141;$219 = $327;$220 = $142;
  } else {
   $213 = $329;$214 = Math_fround(0.0);$216 = $328;$217 = Math_fround(0.0);$219 = $327;$220 = Math_fround(0.0);
  }
 } else {
  if ($103) {
   $143 = Math_fround(-$102);
   $145 = $143;
  } else {
   $145 = $102;
  }
  $144 = $145 > Math_fround(1.00000001168609742308E-7);
  if ($144) {
   $146 = Math_fround(Math_fround(1.0) / $102);
   $147 = Math_fround($60 * $146);
   $148 = Math_fround($74 * $146);
   $149 = Math_fround($88 * $146);
   $184 = $147;$188 = $148;$192 = $149;
  } else {
   $184 = Math_fround(0.0);$188 = Math_fround(0.0);$192 = Math_fround(0.0);
  }
  $150 = Math_fround($41 * $48);
  $151 = Math_fround($42 * $51);
  $152 = Math_fround($150 + $151);
  $153 = Math_fround($43 * $55);
  $154 = Math_fround($152 + $153);
  $155 = Math_fround($59 + $154);
  $156 = Math_fround($41 * $62);
  $157 = Math_fround($42 * $65);
  $158 = Math_fround($156 + $157);
  $159 = Math_fround($43 * $69);
  $160 = Math_fround($158 + $159);
  $161 = Math_fround($73 + $160);
  $162 = Math_fround($41 * $76);
  $163 = Math_fround($42 * $79);
  $164 = Math_fround($162 + $163);
  $165 = Math_fround($43 * $83);
  $166 = Math_fround($164 + $165);
  $167 = Math_fround($87 + $166);
  $168 = Math_fround($41 * $90);
  $169 = Math_fround($42 * $93);
  $170 = Math_fround($168 + $169);
  $171 = Math_fround($43 * $97);
  $172 = Math_fround($170 + $171);
  $173 = Math_fround($101 + $172);
  $174 = $173 < Math_fround(0.0);
  if ($174) {
   $175 = Math_fround(-$173);
   $177 = $175;
  } else {
   $177 = $173;
  }
  $176 = $177 > Math_fround(1.00000001168609742308E-7);
  if ($176) {
   $178 = Math_fround(Math_fround(1.0) / $173);
   $179 = Math_fround($155 * $178);
   $180 = Math_fround($161 * $178);
   $181 = Math_fround($167 * $178);
   $200 = $179;$202 = $180;$204 = $181;
  } else {
   $200 = Math_fround(0.0);$202 = Math_fround(0.0);$204 = Math_fround(0.0);
  }
  $182 = Math_fround(HEAPF32[$apexWorld>>2]);
  $183 = Math_fround($184 - $182);
  $185 = (($apexWorld) + 4|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = Math_fround($188 - $186);
  $189 = (($apexWorld) + 8|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = Math_fround($192 - $190);
  $193 = Math_fround($45 * $183);
  $194 = Math_fround($45 * $187);
  $195 = Math_fround($45 * $191);
  $196 = Math_fround($182 + $193);
  $197 = Math_fround($186 + $194);
  $198 = Math_fround($190 + $195);
  $199 = Math_fround($200 - $182);
  $201 = Math_fround($202 - $186);
  $203 = Math_fround($204 - $190);
  $205 = Math_fround($47 * $199);
  $206 = Math_fround($47 * $201);
  $207 = Math_fround($47 * $203);
  $208 = Math_fround($182 + $205);
  $209 = Math_fround($186 + $206);
  $210 = Math_fround($190 + $207);
  $213 = $196;$214 = $208;$216 = $197;$217 = $209;$219 = $198;$220 = $210;
 }
 $211 = ($lightType|0)==(1);
 $212 = Math_fround($214 - $213);
 $215 = Math_fround($217 - $216);
 $218 = Math_fround($220 - $219);
 if (!($211)) {
  $283 = Math_fround(HEAPF32[$lightVec>>2]);
  $284 = Math_fround($283 - $213);
  $285 = (($lightVec) + 4|0);
  $286 = Math_fround(HEAPF32[$285>>2]);
  $287 = Math_fround($286 - $216);
  $288 = (($lightVec) + 8|0);
  $289 = Math_fround(HEAPF32[$288>>2]);
  $290 = Math_fround($289 - $219);
  $291 = Math_fround($215 * $290);
  $292 = Math_fround($218 * $287);
  $293 = Math_fround($291 - $292);
  $294 = Math_fround($218 * $284);
  $295 = Math_fround($212 * $290);
  $296 = Math_fround($294 - $295);
  $297 = Math_fround($212 * $287);
  $298 = Math_fround($215 * $284);
  $299 = Math_fround($297 - $298);
  $300 = (($outPlane) + 4|0);
  $301 = (($outPlane) + 8|0);
  $302 = Math_fround($293 * $293);
  $303 = Math_fround($296 * $296);
  $304 = Math_fround($302 + $303);
  $305 = Math_fround($299 * $299);
  $306 = Math_fround($305 + $304);
  $307 = (Math_fround(Math_sqrt((Math_fround($306)))));
  $308 = Math_fround($293 / $307);
  $309 = Math_fround($296 / $307);
  $310 = Math_fround($299 / $307);
  HEAPF32[$outPlane>>2] = $308;
  HEAPF32[$300>>2] = $309;
  HEAPF32[$301>>2] = $310;
  $311 = Math_fround($213 * $308);
  $312 = Math_fround($216 * $309);
  $313 = Math_fround($311 + $312);
  $314 = Math_fround($219 * $310);
  $315 = Math_fround($313 + $314);
  $316 = Math_fround(-$315);
  $317 = (($outPlane) + 12|0);
  HEAPF32[$317>>2] = $316;
  $318 = Math_fround($6 * $308);
  $319 = Math_fround($11 * $309);
  $320 = Math_fround($318 + $319);
  $321 = Math_fround($16 * $310);
  $322 = Math_fround($320 + $321);
  $323 = $322 < Math_fround(0.0);
  if (!($323)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $324 = Math_fround($308 * Math_fround(-1.0));
  HEAPF32[$outPlane>>2] = $324;
  $325 = Math_fround($309 * Math_fround(-1.0));
  HEAPF32[$300>>2] = $325;
  $326 = Math_fround($310 * Math_fround(-1.0));
  HEAPF32[$301>>2] = $326;
  HEAPF32[$317>>2] = $315;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $221 = Math_fround($212 * $212);
 $222 = Math_fround($215 * $215);
 $223 = Math_fround($222 + $221);
 $224 = Math_fround($218 * $218);
 $225 = Math_fround($224 + $223);
 $226 = (Math_fround(Math_sqrt((Math_fround($225)))));
 $227 = Math_fround(HEAPF32[616648>>2]);
 $228 = $226 > $227;
 if ($228) {
  $229 = Math_fround($212 / $226);
  $230 = Math_fround($215 / $226);
  $231 = Math_fround($218 / $226);
  $238 = $230;$242 = $231;$247 = $229;
 } else {
  $232 = Math_fround(HEAPF32[616680>>2]);
  $233 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
  $234 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
  $238 = $233;$242 = $234;$247 = $232;
 }
 $235 = (($lightVec) + 8|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = Math_fround($238 * $236);
 $239 = (($lightVec) + 4|0);
 $240 = Math_fround(HEAPF32[$239>>2]);
 $241 = Math_fround($242 * $240);
 $243 = Math_fround($237 - $241);
 $244 = Math_fround(HEAPF32[$lightVec>>2]);
 $245 = Math_fround($242 * $244);
 $246 = Math_fround($247 * $236);
 $248 = Math_fround($245 - $246);
 $249 = Math_fround($247 * $240);
 $250 = Math_fround($238 * $244);
 $251 = Math_fround($249 - $250);
 $252 = Math_fround($243 * $243);
 $253 = Math_fround($248 * $248);
 $254 = Math_fround($252 + $253);
 $255 = Math_fround($251 * $251);
 $256 = Math_fround($255 + $254);
 $257 = (Math_fround(Math_sqrt((Math_fround($256)))));
 $258 = $257 < Math_fround(0.00100000004749745130539);
 if ($258) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $259 = Math_fround($243 / $257);
 $260 = Math_fround($248 / $257);
 $261 = Math_fround($251 / $257);
 $262 = Math_fround($6 * $259);
 $263 = Math_fround($11 * $260);
 $264 = Math_fround($262 + $263);
 $265 = Math_fround($16 * $261);
 $266 = Math_fround($264 + $265);
 $267 = $266 < Math_fround(0.0);
 if ($267) {
  $268 = Math_fround($259 * Math_fround(-1.0));
  $269 = Math_fround($260 * Math_fround(-1.0));
  $270 = Math_fround($261 * Math_fround(-1.0));
  $271 = $268;$273 = $269;$275 = $270;
 } else {
  $271 = $259;$273 = $260;$275 = $261;
 }
 HEAPF32[$outPlane>>2] = $271;
 $272 = (($outPlane) + 4|0);
 HEAPF32[$272>>2] = $273;
 $274 = (($outPlane) + 8|0);
 HEAPF32[$274>>2] = $275;
 $276 = Math_fround($213 * $271);
 $277 = Math_fround($216 * $273);
 $278 = Math_fround($277 + $276);
 $279 = Math_fround($219 * $275);
 $280 = Math_fround($279 + $278);
 $281 = Math_fround(-$280);
 $282 = (($outPlane) + 12|0);
 HEAPF32[$282>>2] = $281;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z19SetupShadowCullDataR6CameraRK8Vector3fRK17ShaderReplaceDataPK22SceneCullingParametersR14ShadowCullData($camera,$cameraPos,$shaderReplaceData,$sceneCullParams,$cullData) {
 $camera = $camera|0;
 $cameraPos = $cameraPos|0;
 $shaderReplaceData = $shaderReplaceData|0;
 $sceneCullParams = $sceneCullParams|0;
 $cullData = $cullData|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = Math_fround(0);
 var $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0;
 var $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $cameraFrustum$i = 0, $cullRadius = 0, $i$010$i = 0, $screenRect = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $cameraFrustum$i = sp + 88|0;
 $screenRect = sp;
 $0 = sp + 16|0;
 $cullRadius = sp + 80|0;
 __ZNK6Camera13GetCameraRectEb($screenRect,$camera,1);
 $1 = (Math_fround(__ZNK6Camera23CalculateShadowDistanceEv($camera)));
 __ZNK6Camera22GetCameraToWorldMatrixEv($0,$camera);
 $2 = (($0) + 32|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($0) + 36|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($0) + 40|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($3 * $3);
 $9 = Math_fround($5 * $5);
 $10 = Math_fround($8 + $9);
 $11 = Math_fround($7 * $7);
 $12 = Math_fround($10 + $11);
 $13 = (Math_fround(Math_sqrt((Math_fround($12)))));
 $14 = Math_fround(HEAPF32[616648>>2]);
 $15 = $13 > $14;
 if ($15) {
  $16 = Math_fround($3 / $13);
  $17 = Math_fround($5 / $13);
  $18 = Math_fround($7 / $13);
  $23 = $16;$25 = $17;$27 = $18;
 } else {
  $19 = Math_fround(HEAPF32[616680>>2]);
  $20 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
  $21 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
  $23 = $19;$25 = $20;$27 = $21;
 }
 $22 = Math_fround(-$23);
 $24 = Math_fround(-$25);
 $26 = Math_fround(-$27);
 HEAP32[$cullData>>2] = $camera;
 $28 = (($cullData) + 196|0);
 ;HEAP32[$28+0>>2]=HEAP32[$cameraPos+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$cameraPos+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$cameraPos+8>>2]|0;
 $29 = (($cullData) + 208|0);
 HEAPF32[$29>>2] = $22;
 $30 = (($cullData) + 212|0);
 HEAPF32[$30>>2] = $24;
 $31 = (($cullData) + 216|0);
 HEAPF32[$31>>2] = $26;
 $32 = (($cullData) + 580|0);
 HEAPF32[$32>>2] = $1;
 $33 = (Math_fround(__ZNK6Camera17GetProjectionNearEv($camera)));
 $34 = (($cullData) + 584|0);
 HEAPF32[$34>>2] = $33;
 $35 = (Math_fround(__ZNK6Camera16GetProjectionFarEv($camera)));
 $36 = (($cullData) + 588|0);
 HEAPF32[$36>>2] = $35;
 $37 = Math_fround($1 / $35);
 $38 = (($cullData) + 592|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($screenRect) + 8|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($cullData) + 220|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($screenRect) + 12|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($cullData) + 224|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($cullData) + 132|0);
 $46 = (__ZNK6Camera20GetWorldToClipMatrixEv($camera)|0);
 dest=$45+0|0; src=$46+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $47 = (($cullData) + 596|0);
 HEAP32[$47>>2] = 0;
 $48 = (($cullData) + 4|0);
 (__Z20InvertMatrix4x4_FullPKfPf($45,$48)|0);
 $49 = Math_fround(HEAPF32[$36>>2]);
 $50 = Math_fround(HEAPF32[$34>>2]);
 $51 = Math_fround($49 / $50);
 dest=$cameraFrustum$i+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __Z16GetFrustumPointsRK10Matrix4x4fP8Vector3f($48,$cameraFrustum$i);
 $52 = Math_fround(HEAPF32[$cameraPos>>2]);
 $53 = (($cameraPos) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($cameraPos) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $i$010$i = 0;
 while(1) {
  $59 = (($i$010$i) + 4)|0;
  $60 = (($cameraFrustum$i) + (($i$010$i*12)|0)|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($61 - $52);
  $63 = ((($cameraFrustum$i) + (($i$010$i*12)|0)|0) + 4|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($64 - $54);
  $66 = ((($cameraFrustum$i) + (($i$010$i*12)|0)|0) + 8|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($67 - $56);
  $69 = Math_fround($51 * $62);
  $70 = Math_fround($51 * $65);
  $71 = Math_fround($51 * $68);
  $72 = Math_fround($52 + $69);
  $73 = Math_fround($54 + $70);
  $74 = Math_fround($56 + $71);
  $75 = (($cameraFrustum$i) + (($59*12)|0)|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($72 - $76);
  $78 = ((($cameraFrustum$i) + (($59*12)|0)|0) + 4|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($73 - $79);
  $81 = ((($cameraFrustum$i) + (($59*12)|0)|0) + 8|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($74 - $82);
  $84 = Math_fround($77 * $77);
  $85 = Math_fround($80 * $80);
  $86 = Math_fround($84 + $85);
  $87 = Math_fround($83 * $83);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround($76 - $61);
  $90 = Math_fround($79 - $64);
  $91 = Math_fround($82 - $67);
  $92 = Math_fround($89 * $89);
  $93 = Math_fround($90 * $90);
  $94 = Math_fround($92 + $93);
  $95 = Math_fround($91 * $91);
  $96 = Math_fround($94 + $95);
  $97 = Math_fround($96 * Math_fround(0.00999999977648258209228));
  $98 = !($88 <= $97);
  $58 = (($i$010$i) + 1)|0;
  if ($98) {
   label = 7;
   break;
  }
  $57 = ($58|0)<(4);
  if ($57) {
   $i$010$i = $58;
  } else {
   label = 8;
   break;
  }
 }
 if ((label|0) == 7) {
  $99 = (($camera) + 456|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($camera) + 460|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  __ZNK6Camera27GetImplicitProjectionMatrixEffR10Matrix4x4f($camera,$100,$102,$cameraFrustum$i);
  $103 = (__ZNK6Camera22GetWorldToCameraMatrixEv($camera)|0);
  $104 = (($cullData) + 68|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($cameraFrustum$i,$103,$104);
  (__Z20InvertMatrix4x4_FullPKfPf($104,$48)|0);
  $$pre$phiZ2D = $101;
 }
 else if ((label|0) == 8) {
  $105 = (($cullData) + 68|0);
  dest=$105+0|0; src=$45+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$pre = (($camera) + 460|0);
  $$pre$phiZ2D = $$pre;
 }
 $106 = (($cullData) + 460|0);
 $107 = (($cullData) + 68|0);
 $108 = (($cullData) + 360|0);
 __ZNK6Camera22CalculateFrustumPlanesEP5PlaneRK10Matrix4x4ffRfb($camera,$106,$107,$1,$108,1);
 $109 = (($cullData) + 364|0);
 ;HEAP32[$109+0>>2]=HEAP32[$106+0>>2]|0;HEAP32[$109+4>>2]=HEAP32[$106+4>>2]|0;HEAP32[$109+8>>2]=HEAP32[$106+8>>2]|0;HEAP32[$109+12>>2]=HEAP32[$106+12>>2]|0;
 $110 = (($cullData) + 380|0);
 $111 = (($cullData) + 476|0);
 ;HEAP32[$110+0>>2]=HEAP32[$111+0>>2]|0;HEAP32[$110+4>>2]=HEAP32[$111+4>>2]|0;HEAP32[$110+8>>2]=HEAP32[$111+8>>2]|0;HEAP32[$110+12>>2]=HEAP32[$111+12>>2]|0;
 $112 = (($cullData) + 396|0);
 $113 = (($cullData) + 492|0);
 ;HEAP32[$112+0>>2]=HEAP32[$113+0>>2]|0;HEAP32[$112+4>>2]=HEAP32[$113+4>>2]|0;HEAP32[$112+8>>2]=HEAP32[$113+8>>2]|0;HEAP32[$112+12>>2]=HEAP32[$113+12>>2]|0;
 $114 = (($cullData) + 412|0);
 $115 = (($cullData) + 508|0);
 ;HEAP32[$114+0>>2]=HEAP32[$115+0>>2]|0;HEAP32[$114+4>>2]=HEAP32[$115+4>>2]|0;HEAP32[$114+8>>2]=HEAP32[$115+8>>2]|0;HEAP32[$114+12>>2]=HEAP32[$115+12>>2]|0;
 $116 = (($cullData) + 428|0);
 $117 = (($cullData) + 524|0);
 ;HEAP32[$116+0>>2]=HEAP32[$117+0>>2]|0;HEAP32[$116+4>>2]=HEAP32[$117+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[$117+8>>2]|0;HEAP32[$116+12>>2]=HEAP32[$117+12>>2]|0;
 $118 = (($cullData) + 444|0);
 $119 = (($cullData) + 540|0);
 ;HEAP32[$118+0>>2]=HEAP32[$119+0>>2]|0;HEAP32[$118+4>>2]=HEAP32[$119+4>>2]|0;HEAP32[$118+8>>2]=HEAP32[$119+8>>2]|0;HEAP32[$118+12>>2]=HEAP32[$119+12>>2]|0;
 $120 = Math_fround(HEAPF32[$108>>2]);
 $121 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $122 = Math_fround($120 + $121);
 $123 = (($cullData) + 456|0);
 HEAPF32[$123>>2] = $122;
 $124 = (($cullData) + 556|0);
 ;HEAP32[$124+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$124+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$124+8>>2]=HEAP32[616680+8>>2]|0;
 HEAPF32[$cullRadius>>2] = Math_fround(999999986991104.0);
 $125 = (__ZL29CalculateSphericalShadowRangeRK6CameraR8Vector3fRf($camera,$124,$cullRadius)|0);
 $126 = (($cullData) + 576|0);
 $127 = $125&1;
 HEAP8[$126>>0] = $127;
 $128 = Math_fround(HEAPF32[$cullRadius>>2]);
 $129 = (($cullData) + 568|0);
 HEAPF32[$129>>2] = $128;
 $130 = Math_fround($128 * $128);
 $131 = (($cullData) + 572|0);
 HEAPF32[$131>>2] = $130;
 $132 = (($camera) + 468|0);
 $133 = (($cullData) + 228|0);
 _memmove(($133|0),($132|0),128)|0;
 $134 = (($camera) + 618|0);
 $135 = HEAP8[$134>>0]|0;
 $136 = (($cullData) + 356|0);
 HEAP8[$136>>0] = $135;
 $137 = (($cullData) + 604|0);
 $138 = $shaderReplaceData;
 $139 = $138;
 $140 = HEAP32[$139>>2]|0;
 $141 = (($138) + 4)|0;
 $142 = $141;
 $143 = HEAP32[$142>>2]|0;
 $144 = $137;
 $145 = $144;
 HEAP32[$145>>2] = $140;
 $146 = (($144) + 4)|0;
 $147 = $146;
 HEAP32[$147>>2] = $143;
 $148 = (($cullData) + 600|0);
 HEAP32[$148>>2] = $sceneCullParams;
 STACKTOP = sp;return;
}
function __ZL29CalculateSphericalShadowRangeRK6CameraR8Vector3fRf($camera,$outCenter,$outRadius) {
 $camera = $camera|0;
 $outCenter = $outCenter|0;
 $outRadius = $outRadius|0;
 var $$0 = 0, $$0$i = Math_fround(0), $$op$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $phitmp$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 64|0;
 $1 = sp;
 $2 = (__Z18GetQualitySettingsv()|0);
 $3 = (($2) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6) + (($4*96)|0)|0) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZNK6Camera11GetPositionEv($0,$camera);
 ;HEAP32[$outCenter+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$outCenter+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$outCenter+8>>2]=HEAP32[$0+8>>2]|0;
 $10 = (Math_fround(__ZNK6Camera23CalculateShadowDistanceEv($camera)));
 HEAPF32[$outRadius>>2] = $10;
 $11 = (($camera) + 616|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $14 = (($camera) + 452|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($15 / Math_fround(180.0));
  $17 = Math_fround(Math_fround(1.0) - $16);
  $18 = $17 < Math_fround(0.0);
  if ($18) {
   $$0$i = Math_fround(0.0);
  } else {
   $19 = $17 > Math_fround(1.0);
   $$op$i = Math_fround($17 * Math_fround(0.400000005960464477539));
   $phitmp$i = $19 ? Math_fround(0.400000005960464477539) : $$op$i;
   $$0$i = $phitmp$i;
  }
 } else {
  $$0$i = Math_fround(0.400000005960464477539);
 }
 $20 = Math_fround($$0$i * $10);
 $21 = Math_fround(-$20);
 __ZNK6Camera22GetCameraToWorldMatrixEv($1,$camera);
 $22 = Math_fround(HEAPF32[$1>>2]);
 $23 = Math_fround($22 * Math_fround(0.0));
 $24 = (($1) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * Math_fround(0.0));
 $27 = Math_fround($23 + $26);
 $28 = (($1) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $21);
 $31 = Math_fround($27 + $30);
 $32 = (($1) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 * Math_fround(0.0));
 $35 = (($1) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * Math_fround(0.0));
 $38 = Math_fround($34 + $37);
 $39 = (($1) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($40 * $21);
 $42 = Math_fround($38 + $41);
 $43 = (($1) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 * Math_fround(0.0));
 $46 = (($1) + 24|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 * Math_fround(0.0));
 $49 = Math_fround($45 + $48);
 $50 = (($1) + 40|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $21);
 $53 = Math_fround($49 + $52);
 $54 = Math_fround(HEAPF32[$outCenter>>2]);
 $55 = Math_fround($31 + $54);
 HEAPF32[$outCenter>>2] = $55;
 $56 = (($outCenter) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($42 + $57);
 HEAPF32[$56>>2] = $58;
 $59 = (($outCenter) + 8|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($53 + $60);
 HEAPF32[$59>>2] = $61;
 $62 = Math_fround(Math_fround(1.0) - $$0$i);
 $63 = Math_fround(HEAPF32[$outRadius>>2]);
 $64 = Math_fround($62 * $63);
 HEAPF32[$outRadius>>2] = $64;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z27CalculateShadowSphereOffsetRK6Camera($camera) {
 $camera = $camera|0;
 var $$0 = Math_fround(0), $$op = Math_fround(0), $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $phitmp = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($camera) + 616|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $$0 = Math_fround(0.400000005960464477539);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $3 = (($camera) + 452|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 / Math_fround(180.0));
 $6 = Math_fround(Math_fround(1.0) - $5);
 $7 = $6 < Math_fround(0.0);
 if ($7) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $8 = $6 > Math_fround(1.0);
 $$op = Math_fround($6 * Math_fround(0.400000005960464477539));
 $phitmp = $8 ? Math_fround(0.400000005960464477539) : $$op;
 $$0 = $phitmp;
 STACKTOP = sp;return (Math_fround($$0));
}
function __Z24CalculateLightShadowFadeRK6CamerafffR8Vector4f($camera,$shadowStrength,$shadowDistance,$shadowSphereRange,$outParams) {
 $camera = $camera|0;
 $shadowStrength = Math_fround($shadowStrength);
 $shadowDistance = Math_fround($shadowDistance);
 $shadowSphereRange = Math_fround($shadowSphereRange);
 $outParams = $outParams|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(Math_fround(1.0) - $shadowStrength);
 HEAPF32[$outParams>>2] = $0;
 $1 = $shadowSphereRange > Math_fround(0.0);
 if ($1) {
  $2 = (($camera) + 460|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = Math_fround($3 / $shadowDistance);
  $5 = (($outParams) + 4|0);
  HEAPF32[$5>>2] = $4;
  $6 = Math_fround($shadowDistance * Math_fround(0.20000000298023223877));
  $7 = Math_fround($shadowSphereRange - $6);
  $8 = Math_fround($shadowSphereRange - $7);
  $9 = Math_fround(Math_fround(1.0) / $8);
  $10 = (($outParams) + 8|0);
  HEAPF32[$10>>2] = $9;
  $11 = Math_fround($7 * $9);
  $12 = Math_fround(-$11);
  $13 = (($outParams) + 12|0);
  HEAPF32[$13>>2] = $12;
  STACKTOP = sp;return;
 } else {
  $14 = (($outParams) + 4|0);
  HEAPF32[$14>>2] = Math_fround(inf);
  $15 = (($outParams) + 8|0);
  HEAPF32[$15>>2] = Math_fround(0.0);
  $16 = (($outParams) + 12|0);
  HEAPF32[$16>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
}
function __Z33CalculateLightShadowCenterAndTypeRK6CameraR8Vector4fRfS4_($camera,$outCenterAndType,$outShadowDistance,$outShadowSphereRange) {
 $camera = $camera|0;
 $outCenterAndType = $outCenterAndType|0;
 $outShadowDistance = $outShadowDistance|0;
 $outShadowSphereRange = $outShadowSphereRange|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $center = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $center = sp;
 $0 = (Math_fround(__ZNK6Camera23CalculateShadowDistanceEv($camera)));
 HEAPF32[$outShadowDistance>>2] = $0;
 HEAPF32[$outShadowSphereRange>>2] = $0;
 __ZNK6Camera11GetPositionEv($center,$camera);
 $1 = (__ZL29CalculateSphericalShadowRangeRK6CameraR8Vector3fRf($camera,$center,$outShadowSphereRange)|0);
 $2 = Math_fround(HEAPF32[$center>>2]);
 $3 = (($center) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($center) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (Math_fround(($1&1)));
 HEAPF32[$outCenterAndType>>2] = $2;
 $8 = (($outCenterAndType) + 4|0);
 HEAPF32[$8>>2] = $4;
 $9 = (($outCenterAndType) + 8|0);
 HEAPF32[$9>>2] = $6;
 $10 = (($outCenterAndType) + 12|0);
 HEAPF32[$10>>2] = $7;
 STACKTOP = sp;return;
}
function __Z27CullLocalLightShadowCastersiibR11CullResults($startIndex,$endIndex,$excludeLightmapped,$results) {
 $startIndex = $startIndex|0;
 $endIndex = $endIndex|0;
 $excludeLightmapped = $excludeLightmapped|0;
 $results = $results|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond3 = 0, $i$02 = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($startIndex|0)<($endIndex|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (($results) + 224|0);
 $3 = (($results) + 124|0);
 $4 = (($results) + 1024|0);
 $5 = (($results) + 168|0);
 $6 = (($results) + 8|0);
 $i$02 = $startIndex;
 while(1) {
  $7 = HEAP32[$2>>2]|0;
  $8 = (($7) + (($i$02*796)|0)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$3>>2]|0;
  $11 = (($10) + (($9*108)|0)|0);
  $12 = ((($7) + (($i$02*796)|0)|0) + 80|0);
  $13 = HEAP32[$4>>2]|0;
  $14 = (($13) + 600|0);
  $15 = HEAP32[$14>>2]|0;
  _memcpy(($12|0),($15|0),712)|0;
  $16 = HEAP32[$4>>2]|0;
  $17 = HEAP32[$2>>2]|0;
  $18 = (($17) + (($i$02*796)|0)|0);
  __Z34PrepareParametersCullShadowCastersRK11ActiveLightRK14ShadowCullDataR22SceneCullingParametersR13ShadowedLight($11,$16,$12,$18);
  $19 = ((($10) + (($9*108)|0)|0) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 72|0);
  $22 = ((($10) + (($9*108)|0)|0) + 76|0);
  $j$01 = 0;
  while(1) {
   $23 = (((($7) + (($i$02*796)|0)|0) + (($j$01*12)|0)|0) + 696|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0);
   if (!($25)) {
    $26 = HEAP32[628520>>2]|0;
    HEAP32[$0>>2] = $26;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $27 = (__Znwj10MemLabelIdbiPKci(220,$$byval_copy,0,16,576048,509)|0);
    HEAP32[$27>>2] = $12;
    $28 = HEAP32[$4>>2]|0;
    $29 = (($27) + 4|0);
    HEAP32[$29>>2] = $28;
    $30 = (($27) + 16|0);
    HEAP32[$30>>2] = $j$01;
    $31 = HEAP32[$11>>2]|0;
    $32 = (($27) + 8|0);
    HEAP32[$32>>2] = $31;
    $33 = HEAP32[$22>>2]|0;
    $34 = HEAP32[$5>>2]|0;
    $35 = (($34) + ($33<<4)|0);
    $36 = (($27) + 12|0);
    HEAP32[$36>>2] = $35;
    $37 = HEAP32[$2>>2]|0;
    $38 = (((($37) + (($i$02*796)|0)|0) + (($j$01*12)|0)|0) + 4|0);
    $39 = (($27) + 20|0);
    HEAP32[$39>>2] = $38;
    $40 = (($27) + 24|0);
    $41 = HEAP32[$23>>2]|0;
    $42 = (__Z40ConfigureBlockRangesWithMinIndicesPerJobP10BlockRangeii($40,$41,256)|0);
    $43 = (($27) + 216|0);
    HEAP32[$43>>2] = $42;
    __Z21ScheduleForEachJobSetR8JobFencePFvPvjES1_iPFvS1_ES0_11JobPriority($21,2641,$27,$42,3429,$6,0);
   }
   $44 = (($j$01) + 1)|0;
   $exitcond = ($44|0)==(5);
   if ($exitcond) {
    break;
   } else {
    $j$01 = $44;
   }
  }
  $45 = (($i$02) + 1)|0;
  $exitcond3 = ($45|0)==($endIndex|0);
  if ($exitcond3) {
   break;
  } else {
   $i$02 = $45;
  }
 }
 STACKTOP = sp;return;
}
function __Z34PrepareParametersCullShadowCastersRK11ActiveLightRK14ShadowCullDataR22SceneCullingParametersR13ShadowedLight($activeLight,$cullData,$cullParams,$shadowedLight) {
 $activeLight = $activeLight|0;
 $cullData = $cullData|0;
 $cullParams = $cullParams|0;
 $shadowedLight = $shadowedLight|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $casterCull = 0, $lightDir = 0, $lightVec$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $lightVec$i = sp + 200|0;
 $0 = sp;
 $casterCull = sp + 12|0;
 $lightDir = sp + 176|0;
 $1 = sp + 188|0;
 $2 = (($cullParams) + 608|0);
 $3 = (($shadowedLight) + 4|0);
 __Z19CreateCullingOutputPK16RendererCullDataR13CullingOutput($2,$3);
 $4 = HEAP32[$activeLight>>2]|0;
 $5 = (($4) + 216|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($8)|0);
 HEAPF32[$casterCull>>2] = Math_fround(0.0);
 $10 = (($casterCull) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($casterCull) + 8|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($casterCull) + 16|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($casterCull) + 20|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($casterCull) + 24|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($casterCull) + 32|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($casterCull) + 36|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($casterCull) + 40|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($casterCull) + 48|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($casterCull) + 52|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($casterCull) + 56|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($casterCull) + 64|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($casterCull) + 68|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($casterCull) + 72|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($casterCull) + 80|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($casterCull) + 84|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($casterCull) + 88|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($casterCull) + 96|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($casterCull) + 100|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($casterCull) + 104|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($casterCull) + 112|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($casterCull) + 116|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($casterCull) + 120|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($casterCull) + 128|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($casterCull) + 132|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($casterCull) + 136|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($casterCull) + 144|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($casterCull) + 148|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($casterCull) + 152|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = HEAP32[$cullData>>2]|0;
 $40 = (($39) + 616|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)!=(0);
 $43 = (($cullData) + 460|0);
 $44 = (($cullData) + 4|0);
 $45 = (($cullData) + 196|0);
 $46 = (($cullData) + 592|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$lightVec$i>>2] = Math_fround(0.0);
 $48 = (($lightVec$i) + 4|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($lightVec$i) + 8|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = ($6|0)==(1);
 if ($50) {
  __ZNK9Transform18TransformDirectionERK8Vector3f($lightVec$i,$9,616744);
 } else {
  __ZNK9Transform11GetPositionEv($0,$9);
  ;HEAP32[$lightVec$i+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$lightVec$i+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$lightVec$i+8>>2]=HEAP32[$0+8>>2]|0;
 }
 __Z25CalculateShadowCasterCullbPK5PlaneRK10Matrix4x4fRK8Vector3fff9LightTypeS7_R16ShadowCasterCullPKb($42,$43,$44,$45,Math_fround(1.0),$47,$6,$lightVec$i,$casterCull,576040);
 $51 = HEAP32[$cullData>>2]|0;
 $52 = (($casterCull) + 160|0);
 $53 = HEAP32[$52>>2]|0;
 __ZNK6Camera32CalculateCustomCullingParametersER17CullingParametersPK5Planei($51,$cullParams,$casterCull,$53);
 if (!($50)) {
  STACKTOP = sp;return;
 }
 HEAPF32[$1>>2] = Math_fround(0.0);
 $54 = (($1) + 4|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($1) + 8|0);
 HEAPF32[$55>>2] = Math_fround(-1.0);
 __ZNK9Transform18TransformDirectionERK8Vector3f($lightDir,$9,$1);
 $56 = (($cullParams) + 328|0);
 ;HEAP32[$56+0>>2]=HEAP32[$lightDir+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$lightDir+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$lightDir+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZL25CullLocalShadowCastersJobPvj($userData,$index) {
 $userData = $userData|0;
 $index = $index|0;
 var $$$i$i = 0, $$$i2$i = 0, $$0$i$i$i = 0, $$0$i$i1$i = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $context$i = 0, $context1$i = 0, $proj$i = 0, $temp$i = 0, $visible$i = 0, $visible2$i = 0, $zscale$i = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $context$i = sp + 528|0;
 $visible$i = sp + 516|0;
 $context1$i = sp + 280|0;
 $zscale$i = sp + 216|0;
 $proj$i = sp + 152|0;
 $0 = sp + 128|0;
 $1 = sp + 64|0;
 $temp$i = sp;
 $visible2$i = sp + 140|0;
 $2 = (($userData) + 24|0);
 $3 = (($userData) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$userData>>2]|0;
 $6 = ((($5) + (($4*12)|0)|0) + 608|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($4*12)|0)|0) + 612|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($userData) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $$idx$val = HEAP32[$11>>2]|0;
 $12 = (($2) + (($index*12)|0)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($$idx$val) + ($13<<2)|0);
 $15 = ((($2) + (($index*12)|0)|0) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$context$i>>2] = $14;
 $17 = (($context$i) + 4|0);
 HEAP32[$17>>2] = $16;
 $18 = (($context$i) + 8|0);
 HEAP32[$18>>2] = $16;
 $19 = (($16) + ($13))|0;
 __Z29CullShadowCastersWithoutUmbraR9IndexListRK22SceneCullingParametersPK4AABBjj($context$i,$5,$7,$13,$19);
 __Z34ProcessIndexListIsNodeVisibleInOutRK22SceneCullingParametersPK9SceneNodePK4AABBR9IndexList($5,$9,$7,$context$i);
 $20 = HEAP32[$17>>2]|0;
 HEAP32[$15>>2] = $20;
 $21 = (($userData) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$3>>2]|0;
 $24 = (($22) + 600|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($25) + (($23*12)|0)|0) + 608|0);
 $27 = (($25) + 672|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = (($userData) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($userData) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 180|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$22>>2]|0;
 $36 = (($35) + 412|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & $34;
 $39 = (($30) + 216|0);
 $40 = HEAP32[$39>>2]|0;
 if ((($40|0) == 0)) {
  $74 = (($context1$i) + 140|0);
  HEAPF32[$74>>2] = Math_fround(0.0);
  $75 = (($context1$i) + 144|0);
  HEAPF32[$75>>2] = Math_fround(0.0);
  $76 = (($context1$i) + 148|0);
  HEAPF32[$76>>2] = Math_fround(0.0);
  $77 = (($context1$i) + 156|0);
  HEAPF32[$77>>2] = Math_fround(0.0);
  $78 = (($context1$i) + 160|0);
  HEAPF32[$78>>2] = Math_fround(0.0);
  $79 = (($context1$i) + 164|0);
  HEAPF32[$79>>2] = Math_fround(0.0);
  $80 = (($context1$i) + 172|0);
  HEAPF32[$80>>2] = Math_fround(0.0);
  $81 = (($context1$i) + 176|0);
  HEAPF32[$81>>2] = Math_fround(0.0);
  $82 = (($context1$i) + 180|0);
  HEAPF32[$82>>2] = Math_fround(0.0);
  $83 = (($context1$i) + 188|0);
  HEAPF32[$83>>2] = Math_fround(0.0);
  $84 = (($context1$i) + 192|0);
  HEAPF32[$84>>2] = Math_fround(0.0);
  $85 = (($context1$i) + 196|0);
  HEAPF32[$85>>2] = Math_fround(0.0);
  $86 = (($context1$i) + 204|0);
  HEAPF32[$86>>2] = Math_fround(0.0);
  $87 = (($context1$i) + 208|0);
  HEAPF32[$87>>2] = Math_fround(0.0);
  $88 = (($context1$i) + 212|0);
  HEAPF32[$88>>2] = Math_fround(0.0);
  $89 = (($context1$i) + 220|0);
  HEAPF32[$89>>2] = Math_fround(0.0);
  $90 = (($context1$i) + 224|0);
  HEAPF32[$90>>2] = Math_fround(0.0);
  $91 = (($context1$i) + 228|0);
  HEAPF32[$91>>2] = Math_fround(0.0);
  HEAPF32[$0>>2] = Math_fround(1.0);
  $92 = (($0) + 4|0);
  HEAPF32[$92>>2] = Math_fround(1.0);
  $93 = (($0) + 8|0);
  HEAPF32[$93>>2] = Math_fround(-1.0);
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($zscale$i,$0)|0);
  $94 = (($30) + 200|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = (($30) + 188|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  (__ZN10Matrix4x4f19SetPerspectiveCotanEfff($proj$i,$95,Math_fround(9.99999974737875163555E-5),$97)|0);
  $98 = (($context1$i) + 76|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($proj$i,$zscale$i,$98);
  $99 = (($30) + 24|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($100)|0);
  $102 = (($context1$i) + 12|0);
  __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$101);
  dest=$102+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($98,$102,$temp$i);
  $103 = (($context1$i) + 140|0);
  __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($temp$i,$103);
  HEAP32[$context1$i>>2] = $22;
  $104 = (($context1$i) + 8|0);
  HEAP32[$104>>2] = $38;
  $105 = ($28<<24>>24)!=(0);
  $106 = HEAP32[$39>>2]|0;
  $107 = ($106|0)==(3);
  if ($107) {
   $$0$i$i$i = 0;
  } else {
   $108 = (($30) + 221|0);
   $109 = HEAP8[$108>>0]|0;
   $110 = ($109<<24>>24)==(0);
   if ($110) {
    $$0$i$i$i = 0;
   } else {
    $111 = (($30) + 212|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($112|0)==(1);
    $$0$i$i$i = $113;
   }
  }
  $$$i$i = $$0$i$i$i & $105;
  $114 = (($context1$i) + 4|0);
  $115 = $$$i$i&1;
  HEAP8[$114>>0] = $115;
  $116 = HEAP32[$10>>2]|0;
  $117 = HEAP32[$116>>2]|0;
  $118 = HEAP32[$12>>2]|0;
  $119 = (($117) + ($118<<2)|0);
  $120 = HEAP32[$15>>2]|0;
  HEAP32[$visible2$i>>2] = $119;
  $121 = (($visible2$i) + 4|0);
  HEAP32[$121>>2] = $120;
  $122 = (($visible2$i) + 8|0);
  HEAP32[$122>>2] = $120;
  $123 = ((($25) + (($23*12)|0)|0) + 612|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = HEAP32[$26>>2]|0;
  __Z15CullSpotShadowsR9IndexListPK9SceneNodePK4AABBR15SpotCullContext($visible2$i,$124,$125,$context1$i);
  $126 = HEAP32[$121>>2]|0;
  HEAP32[$15>>2] = $126;
  STACKTOP = sp;return;
 } else if ((($40|0) == 2)) {
  $41 = (($context$i) + 12|0);
  HEAPF32[$41>>2] = Math_fround(0.0);
  $42 = (($context$i) + 16|0);
  HEAPF32[$42>>2] = Math_fround(0.0);
  $43 = (($context$i) + 20|0);
  HEAPF32[$43>>2] = Math_fround(0.0);
  $44 = Math_fround(HEAPF32[$32>>2]);
  $45 = (($32) + 4|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($32) + 8|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($32) + 12|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$41>>2] = $44;
  HEAPF32[$42>>2] = $46;
  HEAPF32[$43>>2] = $48;
  $51 = (($context$i) + 24|0);
  HEAPF32[$51>>2] = $50;
  HEAP32[$context$i>>2] = $22;
  $52 = (($context$i) + 8|0);
  HEAP32[$52>>2] = $38;
  $53 = ($28<<24>>24)!=(0);
  $54 = HEAP32[$39>>2]|0;
  $55 = ($54|0)==(3);
  if ($55) {
   $$0$i$i1$i = 0;
  } else {
   $56 = (($30) + 221|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ($57<<24>>24)==(0);
   if ($58) {
    $$0$i$i1$i = 0;
   } else {
    $59 = (($30) + 212|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==(1);
    $$0$i$i1$i = $61;
   }
  }
  $$$i2$i = $$0$i$i1$i & $53;
  $62 = (($context$i) + 4|0);
  $63 = $$$i2$i&1;
  HEAP8[$62>>0] = $63;
  $64 = HEAP32[$10>>2]|0;
  $65 = HEAP32[$64>>2]|0;
  $66 = HEAP32[$12>>2]|0;
  $67 = (($65) + ($66<<2)|0);
  HEAP32[$visible$i>>2] = $67;
  $68 = (($visible$i) + 4|0);
  HEAP32[$68>>2] = $20;
  $69 = (($visible$i) + 8|0);
  HEAP32[$69>>2] = $20;
  $70 = ((($25) + (($23*12)|0)|0) + 612|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = HEAP32[$26>>2]|0;
  __Z16CullPointShadowsR9IndexListPK9SceneNodePK4AABBR16PointCullContext($visible$i,$71,$72,$context$i);
  $73 = HEAP32[$68>>2]|0;
  HEAP32[$15>>2] = $73;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZL54CombineLocalShadowCasterCullignIndexListsAndDestroyJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond10$i = 0, $i$03$i = 0, $j$02$i = 0, $visibleCountNodes$0$lcssa$i = 0, $visibleCountNodes$04$i = 0, $visibleCountNodes$1$lcssa$i = 0, $visibleCountNodes$11$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($userData) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($userData) + 24|0);
 $4 = (($userData) + 216|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($userData) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)>(1);
 if ($8) {
  $i$03$i = 1;$visibleCountNodes$04$i = $7;
  while(1) {
   $9 = (($3) + (($i$03$i*12)|0)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($3) + (($i$03$i*12)|0)|0) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($10))|0;
   $14 = ($10>>>0)<($13>>>0);
   if ($14) {
    $15 = HEAP32[$2>>2]|0;
    $j$02$i = $10;$visibleCountNodes$11$i = $visibleCountNodes$04$i;
    while(1) {
     $16 = (($15) + ($j$02$i<<2)|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($visibleCountNodes$11$i) + 1)|0;
     $19 = (($15) + ($visibleCountNodes$11$i<<2)|0);
     HEAP32[$19>>2] = $17;
     $20 = (($j$02$i) + 1)|0;
     $exitcond$i = ($20|0)==($13|0);
     if ($exitcond$i) {
      break;
     } else {
      $j$02$i = $20;$visibleCountNodes$11$i = $18;
     }
    }
    $21 = (($12) + ($visibleCountNodes$04$i))|0;
    $visibleCountNodes$1$lcssa$i = $21;
   } else {
    $visibleCountNodes$1$lcssa$i = $visibleCountNodes$04$i;
   }
   $22 = (($i$03$i) + 1)|0;
   $exitcond10$i = ($22|0)==($5|0);
   if ($exitcond10$i) {
    $visibleCountNodes$0$lcssa$i = $visibleCountNodes$1$lcssa$i;
    break;
   } else {
    $i$03$i = $22;$visibleCountNodes$04$i = $visibleCountNodes$1$lcssa$i;
   }
  }
 } else {
  $visibleCountNodes$0$lcssa$i = $7;
 }
 $23 = (($2) + 4|0);
 HEAP32[$23>>2] = $visibleCountNodes$0$lcssa$i;
 $24 = HEAP32[628520>>2]|0;
 HEAP32[$0>>2] = $24;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z31CullDirectionalShadowCastersJobPvj($userData,$index) {
 $userData = $userData|0;
 $index = $index|0;
 var $$$i$i = 0, $$0$i$i$i = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $context$i = 0, $visible$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $context$i = sp + 12|0;
 $visible$i = sp;
 $0 = (($userData) + 28|0);
 $1 = (($0) + (($index*12)|0)|0);
 $2 = HEAP32[$userData>>2]|0;
 $3 = (($2) + 684|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 60|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $29 = (($userData) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ((($2) + (($30*12)|0)|0) + 608|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($2) + (($30*12)|0)|0) + 612|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($userData) + 24|0);
  $36 = HEAP32[$35>>2]|0;
  $$idx$val = HEAP32[$36>>2]|0;
  $37 = HEAP32[$1>>2]|0;
  $38 = (($$idx$val) + ($37<<2)|0);
  $39 = ((($0) + (($index*12)|0)|0) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$context$i>>2] = $38;
  $41 = (($context$i) + 4|0);
  HEAP32[$41>>2] = $40;
  $42 = (($context$i) + 8|0);
  HEAP32[$42>>2] = $40;
  $43 = (($40) + ($37))|0;
  __Z29CullShadowCastersWithoutUmbraR9IndexListRK22SceneCullingParametersPK4AABBjj($context$i,$2,$32,$37,$43);
  __Z34ProcessIndexListIsNodeVisibleInOutRK22SceneCullingParametersPK9SceneNodePK4AABBR9IndexList($2,$34,$32,$context$i);
  $44 = HEAP32[$41>>2]|0;
  HEAP32[$39>>2] = $44;
  $77 = $44;
 } else {
  $8 = (__Z9GetIUmbrav()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 52|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iiiii[$11 & 511]($8,$userData,$1,$index)|0);
  $13 = (($userData) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$1>>2]|0;
  $17 = (($15) + ($16<<2)|0);
  HEAP32[$context$i>>2] = $17;
  $18 = (($context$i) + 4|0);
  HEAP32[$18>>2] = $12;
  $19 = (($context$i) + 8|0);
  HEAP32[$19>>2] = $12;
  $20 = (($userData) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$userData>>2]|0;
  $23 = ((($22) + (($21*12)|0)|0) + 612|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($22) + (($21*12)|0)|0) + 608|0);
  $26 = HEAP32[$25>>2]|0;
  __Z34ProcessIndexListIsNodeVisibleInOutRK22SceneCullingParametersPK9SceneNodePK4AABBR9IndexList($22,$24,$26,$context$i);
  $27 = HEAP32[$18>>2]|0;
  $28 = ((($0) + (($index*12)|0)|0) + 4|0);
  HEAP32[$28>>2] = $27;
  $77 = $27;
 }
 $45 = (($userData) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($userData) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($userData) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($48) + 600|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 672|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)!=(0);
 HEAP32[$context$i>>2] = $48;
 $56 = (($userData) + 16|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($context$i) + 8|0);
 HEAP32[$58>>2] = $57;
 $59 = (($46) + 216|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(3);
 if ($61) {
  $$0$i$i$i = 0;
 } else {
  $62 = (($46) + 221|0);
  $63 = HEAP8[$62>>0]|0;
  $64 = ($63<<24>>24)==(0);
  if ($64) {
   $$0$i$i$i = 0;
  } else {
   $65 = (($46) + 212|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(1);
   $$0$i$i$i = $67;
  }
 }
 $$$i$i = $$0$i$i$i & $55;
 $68 = (($context$i) + 4|0);
 $69 = $$$i$i&1;
 HEAP8[$68>>0] = $69;
 $70 = (($userData) + 24|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$71>>2]|0;
 $73 = HEAP32[$1>>2]|0;
 $74 = (($72) + ($73<<2)|0);
 $75 = ((($0) + (($index*12)|0)|0) + 4|0);
 HEAP32[$visible$i>>2] = $74;
 $76 = (($visible$i) + 4|0);
 HEAP32[$76>>2] = $77;
 $78 = (($visible$i) + 8|0);
 HEAP32[$78>>2] = $77;
 $79 = ((($52) + (($50*12)|0)|0) + 612|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($52) + (($50*12)|0)|0) + 608|0);
 $82 = HEAP32[$81>>2]|0;
 __Z22CullDirectionalShadowsR9IndexListPK9SceneNodePK4AABBR22DirectionalCullContext($visible$i,$80,$82,$context$i);
 $83 = HEAP32[$76>>2]|0;
 HEAP32[$75>>2] = $83;
 STACKTOP = sp;return;
}
function __Z37GenerateCombinedDynamicVisibleListJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0);
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond$i = 0, $i$09$1$i = 0, $i$09$2$i = 0, $i$09$3$i = 0, $i$09$i = 0, $i3$05$i = 0, $index$1$lcssa$1$i = 0, $index$1$lcssa$2$i = 0, $index$1$lcssa$i = 0, $index$18$1$i = 0;
 var $index$18$2$i = 0, $index$18$3$i = 0, $index$26$i = 0, $index$3$lcssa$i = 0, $index$34$i = 0, $t2$07$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($userData) + 76|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($userData) + 1024|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 600|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 684|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($userData) + 1036|0);
 $11 = (($userData) + 1052|0);
 $12 = (($9) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($9) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($9) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($13))|0;
 $19 = (($9) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($15))|0;
 $22 = (($9) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($18) + ($23))|0;
 $25 = (($9) + 44|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($21) + ($26))|0;
 $28 = (($9) + 52|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($24) + ($29))|0;
 $31 = (($9) + 56|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($27) + ($32))|0;
 $34 = (($userData) + 1044|0);
 HEAP32[$34>>2] = $30;
 $35 = (($userData) + 1048|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37>>>0)<($30>>>0);
 do {
  if ($38) {
   $39 = ($36|0)>(-1);
   if ($39) {
    HEAP32[$35>>2] = $30;
    $40 = HEAP32[$10>>2]|0;
    $41 = $30 << 2;
    $42 = (($userData) + 1040|0);
    $43 = HEAP32[$42>>2]|0;
    HEAP32[$0>>2] = $43;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $44 = (__Z16realloc_internalPvji10MemLabelIdiPKci($40,$41,4,$$byval_copy3,0,576048,370)|0);
    HEAP32[$10>>2] = $44;
    break;
   } else {
    $45 = $30 << 2;
    $46 = (($userData) + 1040|0);
    $47 = HEAP32[$46>>2]|0;
    HEAP32[$0>>2] = $47;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $48 = (__Z15malloc_internaljj10MemLabelIdiPKci($45,4,$$byval_copy3,0,576048,352)|0);
    $49 = HEAP32[$10>>2]|0;
    $50 = HEAP32[$34>>2]|0;
    $51 = $50 << 2;
    _memcpy(($48|0),($49|0),($51|0))|0;
    HEAP32[$35>>2] = $30;
    HEAP32[$10>>2] = $48;
    break;
   }
  }
 } while(0);
 $52 = $33 << 1;
 $53 = (($userData) + 1060|0);
 HEAP32[$53>>2] = $52;
 $54 = (($userData) + 1064|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 & 2147483647;
 $57 = ($56>>>0)<($52>>>0);
 do {
  if ($57) {
   $58 = ($55|0)>(-1);
   if ($58) {
    HEAP32[$54>>2] = $52;
    $59 = HEAP32[$11>>2]|0;
    $60 = ($33*24)|0;
    $61 = (($userData) + 1056|0);
    $62 = HEAP32[$61>>2]|0;
    HEAP32[$0>>2] = $62;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $63 = (__Z16realloc_internalPvji10MemLabelIdiPKci($59,$60,4,$$byval_copy3,0,576048,370)|0);
    HEAP32[$11>>2] = $63;
    break;
   } else {
    $64 = ($33*24)|0;
    $65 = (($userData) + 1056|0);
    $66 = HEAP32[$65>>2]|0;
    HEAP32[$0>>2] = $66;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $67 = (__Z15malloc_internaljj10MemLabelIdiPKci($64,4,$$byval_copy3,0,576048,352)|0);
    $68 = HEAP32[$11>>2]|0;
    $69 = HEAP32[$53>>2]|0;
    $70 = ($69*12)|0;
    _memcpy(($67|0),($68|0),($70|0))|0;
    HEAP32[$54>>2] = $52;
    HEAP32[$11>>2] = $67;
    break;
   }
  }
 } while(0);
 $71 = (($9) + 12|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = HEAP32[$12>>2]|0;
 $74 = ($73|0)>(0);
 if ($74) {
  $75 = HEAP32[$10>>2]|0;
  $i$09$i = 0;
  while(1) {
   $76 = (($72) + ($i$09$i<<2)|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = (($i$09$i) + 1)|0;
   $79 = (($75) + ($i$09$i<<2)|0);
   HEAP32[$79>>2] = $77;
   $80 = HEAP32[$12>>2]|0;
   $81 = ($78|0)<($80|0);
   if ($81) {
    $i$09$i = $78;
   } else {
    $index$1$lcssa$i = $78;
    break;
   }
  }
 } else {
  $index$1$lcssa$i = 0;
 }
 $82 = HEAP32[$14>>2]|0;
 $83 = (($9) + 24|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = HEAP32[$16>>2]|0;
 $86 = ($85|0)>(0);
 if ($86) {
  $130 = HEAP32[$10>>2]|0;
  $i$09$1$i = 0;$index$18$1$i = $index$1$lcssa$i;
  while(1) {
   $131 = (($84) + ($i$09$1$i<<2)|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = (($132) + ($82))|0;
   $134 = (($index$18$1$i) + 1)|0;
   $135 = (($130) + ($index$18$1$i<<2)|0);
   HEAP32[$135>>2] = $133;
   $136 = (($i$09$1$i) + 1)|0;
   $137 = HEAP32[$16>>2]|0;
   $138 = ($136|0)<($137|0);
   if ($138) {
    $i$09$1$i = $136;$index$18$1$i = $134;
   } else {
    $index$1$lcssa$1$i = $134;
    break;
   }
  }
 } else {
  $index$1$lcssa$1$i = $index$1$lcssa$i;
 }
 $139 = HEAP32[$19>>2]|0;
 $140 = (($139) + ($82))|0;
 $141 = (($9) + 36|0);
 $142 = HEAP32[$141>>2]|0;
 $143 = HEAP32[$22>>2]|0;
 $144 = ($143|0)>(0);
 if ($144) {
  $145 = HEAP32[$10>>2]|0;
  $i$09$2$i = 0;$index$18$2$i = $index$1$lcssa$1$i;
  while(1) {
   $146 = (($142) + ($i$09$2$i<<2)|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = (($147) + ($140))|0;
   $149 = (($index$18$2$i) + 1)|0;
   $150 = (($145) + ($index$18$2$i<<2)|0);
   HEAP32[$150>>2] = $148;
   $151 = (($i$09$2$i) + 1)|0;
   $152 = HEAP32[$22>>2]|0;
   $153 = ($151|0)<($152|0);
   if ($153) {
    $i$09$2$i = $151;$index$18$2$i = $149;
   } else {
    $index$1$lcssa$2$i = $149;
    break;
   }
  }
 } else {
  $index$1$lcssa$2$i = $index$1$lcssa$1$i;
 }
 $154 = HEAP32[$25>>2]|0;
 $155 = (($154) + ($140))|0;
 $156 = (($9) + 48|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = HEAP32[$28>>2]|0;
 $159 = ($158|0)>(0);
 if ($159) {
  $160 = HEAP32[$10>>2]|0;
  $i$09$3$i = 0;$index$18$3$i = $index$1$lcssa$2$i;
  while(1) {
   $161 = (($157) + ($i$09$3$i<<2)|0);
   $162 = HEAP32[$161>>2]|0;
   $163 = (($155) + ($162))|0;
   $164 = (($index$18$3$i) + 1)|0;
   $165 = (($160) + ($index$18$3$i<<2)|0);
   HEAP32[$165>>2] = $163;
   $166 = (($i$09$3$i) + 1)|0;
   $167 = HEAP32[$28>>2]|0;
   $168 = ($166|0)<($167|0);
   if ($168) {
    $i$09$3$i = $166;$index$18$3$i = $164;
   } else {
    break;
   }
  }
 }
 $index$26$i = 0;$t2$07$i = 1;
 while(1) {
  $87 = ((($7) + (($t2$07$i*12)|0)|0) + 608|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = ((($7) + (($t2$07$i*12)|0)|0) + 616|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($90|0)==(0);
  if ($91) {
   $index$3$lcssa$i = $index$26$i;
  } else {
   $i3$05$i = 0;$index$34$i = $index$26$i;
   while(1) {
    $92 = (($index$34$i) + 1)|0;
    $93 = HEAP32[$11>>2]|0;
    $94 = (($88) + (($i3$05$i*24)|0)|0);
    $95 = Math_fround(HEAPF32[$94>>2]);
    $96 = ((($88) + (($i3$05$i*24)|0)|0) + 12|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = Math_fround($95 - $97);
    $99 = ((($88) + (($i3$05$i*24)|0)|0) + 4|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $101 = ((($88) + (($i3$05$i*24)|0)|0) + 16|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $103 = Math_fround($100 - $102);
    $104 = ((($88) + (($i3$05$i*24)|0)|0) + 8|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = ((($88) + (($i3$05$i*24)|0)|0) + 20|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = Math_fround($105 - $107);
    $109 = (($93) + (($index$34$i*12)|0)|0);
    HEAPF32[$109>>2] = $98;
    $110 = ((($93) + (($index$34$i*12)|0)|0) + 4|0);
    HEAPF32[$110>>2] = $103;
    $111 = ((($93) + (($index$34$i*12)|0)|0) + 8|0);
    HEAPF32[$111>>2] = $108;
    $112 = (($index$34$i) + 2)|0;
    $113 = HEAP32[$11>>2]|0;
    $114 = Math_fround(HEAPF32[$94>>2]);
    $115 = Math_fround(HEAPF32[$96>>2]);
    $116 = Math_fround($114 + $115);
    $117 = Math_fround(HEAPF32[$99>>2]);
    $118 = Math_fround(HEAPF32[$101>>2]);
    $119 = Math_fround($117 + $118);
    $120 = Math_fround(HEAPF32[$104>>2]);
    $121 = Math_fround(HEAPF32[$106>>2]);
    $122 = Math_fround($120 + $121);
    $123 = (($113) + (($92*12)|0)|0);
    HEAPF32[$123>>2] = $116;
    $124 = ((($113) + (($92*12)|0)|0) + 4|0);
    HEAPF32[$124>>2] = $119;
    $125 = ((($113) + (($92*12)|0)|0) + 8|0);
    HEAPF32[$125>>2] = $122;
    $126 = (($i3$05$i) + 1)|0;
    $127 = HEAP32[$89>>2]|0;
    $128 = ($126>>>0)<($127>>>0);
    if ($128) {
     $i3$05$i = $126;$index$34$i = $112;
    } else {
     $index$3$lcssa$i = $112;
     break;
    }
   }
  }
  $129 = (($t2$07$i) + 1)|0;
  $exitcond$i = ($129|0)==(5);
  if ($exitcond$i) {
   break;
  } else {
   $index$26$i = $index$3$lcssa$i;$t2$07$i = $129;
  }
 }
 STACKTOP = sp;return;
}
function __Z21CreateShadowCullerJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy11 = 0, $$lcssa = 0, $$lcssa19 = 0, $$lcssa21 = 0, $$ph = 0, $$ph17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $correctedLightDir = 0, $i$023 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy11 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $correctedLightDir = sp + 20|0;
 $5 = HEAP32[$userData>>2]|0;
 $6 = (($userData) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($userData) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + 76|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $107 = HEAP32[628520>>2]|0;
  HEAP32[$0>>2] = $107;
  ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy11);
  STACKTOP = sp;return;
 }
 $13 = HEAP32[628512>>2]|0;
 $14 = (($5) + 1044|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 do {
  if ($16) {
   $$lcssa = 0;$$lcssa19 = 0;$$lcssa21 = 0;
   label = 24;
  } else {
   $17 = (($5) + 1036|0);
   $18 = (($5) + 1052|0);
   $26 = 0;$28 = 0;$36 = 0;$i$023 = 0;
   L6: while(1) {
    $19 = HEAP32[$17>>2]|0;
    $20 = (($19) + ($i$023<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 << 1;
    $23 = HEAP32[$18>>2]|0;
    $24 = (($23) + (($22*12)|0)|0);
    $25 = $26 | 1;
    $27 = $28 & 2147483647;
    $29 = ($25>>>0)>($27>>>0);
    do {
     if ($29) {
      $30 = $28 << 1;
      $31 = ($30|0)==(0);
      $32 = $31 ? 1 : $30;
      $33 = ($27>>>0)<($32>>>0);
      if ($33) {
       $34 = ($28|0)>(-1);
       if ($34) {
        $35 = ($32*12)|0;
        HEAP32[$3>>2] = $13;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
        $37 = (invoke_iiiiiiii(108,($36|0),($35|0),4,($$byval_copy11|0),0,(576048|0),370)|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         $$ph = $32;$$ph17 = $36;
         label = 19;
         break L6;
        }
        $46 = $37;$52 = $32;
        break;
       } else {
        $40 = ($32*12)|0;
        HEAP32[$4>>2] = $13;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$4+0>>2]|0;
        $41 = (invoke_iiiiiii(102,($40|0),4,($$byval_copy11|0),0,(576048|0),352)|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         $$ph = $28;$$ph17 = $36;
         label = 19;
         break L6;
        }
        $44 = ($25*12)|0;
        _memcpy(($41|0),($36|0),($44|0))|0;
        $46 = $41;$52 = $32;
        break;
       }
      } else {
       $46 = $36;$52 = $28;
      }
     } else {
      $46 = $36;$52 = $28;
     }
    } while(0);
    $45 = (($46) + (($26*12)|0)|0);
    ;HEAP32[$45+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$24+8>>2]|0;
    $47 = $22 | 1;
    $48 = HEAP32[$18>>2]|0;
    $49 = (($48) + (($47*12)|0)|0);
    $50 = (($26) + 2)|0;
    $51 = $52 & 2147483647;
    $53 = ($50>>>0)>($51>>>0);
    do {
     if ($53) {
      $54 = $52 << 1;
      $55 = ($54|0)==(0);
      $56 = $55 ? 1 : $54;
      $57 = ($51>>>0)<($56>>>0);
      if ($57) {
       $58 = ($52|0)>(-1);
       if ($58) {
        $59 = ($56*12)|0;
        HEAP32[$1>>2] = $13;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
        $60 = (invoke_iiiiiiii(108,($46|0),($59|0),4,($$byval_copy11|0),0,(576048|0),370)|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         $$ph = $56;$$ph17 = $46;
         label = 19;
         break L6;
        }
        $110 = $56;$69 = $60;
        break;
       } else {
        $63 = ($56*12)|0;
        HEAP32[$2>>2] = $13;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
        $64 = (invoke_iiiiiii(102,($63|0),4,($$byval_copy11|0),0,(576048|0),352)|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         $$ph = $52;$$ph17 = $46;
         label = 19;
         break L6;
        }
        $67 = ($50*12)|0;
        _memcpy(($64|0),($46|0),($67|0))|0;
        $110 = $56;$69 = $64;
        break;
       }
      } else {
       $110 = $52;$69 = $46;
      }
     } else {
      $110 = $52;$69 = $46;
     }
    } while(0);
    $68 = (($69) + (($25*12)|0)|0);
    ;HEAP32[$68+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$68+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$68+8>>2]=HEAP32[$49+8>>2]|0;
    $70 = (($i$023) + 1)|0;
    $71 = HEAP32[$14>>2]|0;
    $72 = ($70>>>0)<($71>>>0);
    if ($72) {
     $26 = $50;$28 = $110;$36 = $69;$i$023 = $70;
    } else {
     label = 23;
     break;
    }
   }
   if ((label|0) == 19) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    $78 = $$ph;$79 = $$ph17;$lpad$phi$index = $73;$lpad$phi$index2 = $74;
    break;
   }
   else if ((label|0) == 23) {
    $phitmp = $50 >>> 1;
    $$lcssa = $110;$$lcssa19 = $phitmp;$$lcssa21 = $69;
    label = 24;
    break;
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $82 = (($7) + 328|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround(-$83);
  $85 = (($7) + 332|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround(-$86);
  $88 = (($7) + 336|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = Math_fround(-$89);
  HEAPF32[$correctedLightDir>>2] = $84;
  $91 = (($correctedLightDir) + 4|0);
  HEAPF32[$91>>2] = $87;
  $92 = (($correctedLightDir) + 8|0);
  HEAPF32[$92>>2] = $90;
  __THREW__ = 0;
  $93 = (invoke_i(77)|0);
  $94 = __THREW__; __THREW__ = 0;
  $95 = $94&1;
  if (!($95)) {
   $96 = HEAP32[$93>>2]|0;
   $97 = (($96) + 64|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($7) + 684|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($100) + 64|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   (invoke_iiiiiiii($98|0,($93|0),($9|0),($102|0),($103|0),($correctedLightDir|0),($$lcssa21|0),($$lcssa19|0))|0);
   $104 = __THREW__; __THREW__ = 0;
   $105 = $104&1;
   if (!($105)) {
    $106 = ($$lcssa|0)>(-1);
    if (!($106)) {
     $107 = HEAP32[628520>>2]|0;
     HEAP32[$0>>2] = $107;
     ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy11);
     STACKTOP = sp;return;
    }
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($$lcssa21,$$byval_copy11);
    $107 = HEAP32[628520>>2]|0;
    HEAP32[$0>>2] = $107;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy11);
    STACKTOP = sp;return;
   }
  }
  $75 = ___cxa_find_matching_catch()|0;
  $76 = tempRet0;
  $78 = $$lcssa;$79 = $$lcssa21;$lpad$phi$index = $75;$lpad$phi$index2 = $76;
 }
 $77 = ($78|0)>(-1);
 if (!($77)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $13;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($79|0),($$byval_copy11|0));
 $80 = __THREW__; __THREW__ = 0;
 $81 = $80&1;
 if ($81) {
  $108 = ___cxa_find_matching_catch(0|0)|0;
  $109 = tempRet0;
  ___clang_call_terminate($108);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z28CullDirectionalShadowCastersiRK22SceneCullingParametersR11CullResults($dirShadowLightCount,$cullingParameters,$results) {
 $dirShadowLightCount = $dirShadowLightCount|0;
 $cullingParameters = $cullingParameters|0;
 $results = $results|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $createShadowCullerFence = 0, $exitcond = 0, $exitcond4 = 0, $i$02 = 0, $j$01 = 0;
 var $shadowCuller$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $createShadowCullerFence = sp;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = ($dirShadowLightCount|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($cullingParameters) + 676|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($results) + 1028|0);
 $7 = (($results) + 76|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = (($results) + 8|0);
  __Z18ScheduleJobDependsR8JobFencePFvPvES1_S0_11JobPriority($6,3430,$results,$10,1);
 }
 $11 = ($dirShadowLightCount|0)>(0);
 if ($11) {
  $12 = (($results) + 224|0);
  $13 = (($results) + 124|0);
  $14 = (($results) + 1024|0);
  $15 = (($createShadowCullerFence) + 4|0);
  $16 = (($cullingParameters) + 192|0);
  $i$02 = 0;
  while(1) {
   $17 = HEAP32[$12>>2]|0;
   $18 = (($17) + (($i$02*796)|0)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$13>>2]|0;
   $21 = (($20) + (($19*108)|0)|0);
   $22 = ((($17) + (($i$02*796)|0)|0) + 80|0);
   $23 = HEAP32[$14>>2]|0;
   $24 = (($23) + 600|0);
   $25 = HEAP32[$24>>2]|0;
   _memcpy(($22|0),($25|0),712)|0;
   $26 = HEAP32[$14>>2]|0;
   $27 = HEAP32[$12>>2]|0;
   $28 = (($27) + (($i$02*796)|0)|0);
   __Z34PrepareParametersCullShadowCastersRK11ActiveLightRK14ShadowCullDataR22SceneCullingParametersR13ShadowedLight($21,$26,$22,$28);
   $29 = ((($17) + (($i$02*796)|0)|0) + 688|0);
   $30 = (__Z32CountListsWithValidRendererCountPK16RendererCullData($29)|0);
   $31 = ($30|0)==(0);
   if (!($31)) {
    HEAP32[$createShadowCullerFence>>2] = 0;
    HEAP32[$15>>2] = 0;
    $32 = HEAP8[$7>>0]|0;
    $33 = ($32<<24>>24)==(0);
    if ($33) {
     $shadowCuller$0 = 0;
    } else {
     $34 = (__Z9GetIUmbrav()|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($35) + 20|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (FUNCTION_TABLE_ii[$37 & 4095]($34)|0);
     $39 = HEAP32[$12>>2]|0;
     $40 = ((($39) + (($i$02*796)|0)|0) + 792|0);
     HEAP32[$40>>2] = $38;
     $41 = HEAP32[628520>>2]|0;
     HEAP32[$0>>2] = $41;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $42 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy1,0,16,576048,735)|0);
     HEAP32[$42>>2] = $results;
     $43 = (($42) + 4|0);
     HEAP32[$43>>2] = $22;
     $44 = (($42) + 8|0);
     HEAP32[$44>>2] = $38;
     __Z18ScheduleJobDependsR8JobFencePFvPvES1_S0_11JobPriority($createShadowCullerFence,3431,$42,$6,1);
     $shadowCuller$0 = $38;
    }
    $45 = ((($20) + (($19*108)|0)|0) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + 72|0);
    $j$01 = 0;
    while(1) {
     $48 = (((($17) + (($i$02*796)|0)|0) + (($j$01*12)|0)|0) + 696|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0);
     if (!($50)) {
      $51 = HEAP32[628520>>2]|0;
      HEAP32[$1>>2] = $51;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
      $52 = (__Znwj10MemLabelIdbiPKci(224,$$byval_copy1,0,16,576048,753)|0);
      HEAP32[$52>>2] = $22;
      $53 = (($52) + 8|0);
      HEAP32[$53>>2] = $shadowCuller$0;
      $54 = HEAP32[$14>>2]|0;
      $55 = (($52) + 4|0);
      HEAP32[$55>>2] = $54;
      $56 = HEAP32[$21>>2]|0;
      $57 = (($52) + 12|0);
      HEAP32[$57>>2] = $56;
      $58 = HEAP32[$21>>2]|0;
      $59 = (($58) + 180|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = HEAP32[$16>>2]|0;
      $62 = $61 & $60;
      $63 = (($52) + 16|0);
      HEAP32[$63>>2] = $62;
      $64 = (($52) + 20|0);
      HEAP32[$64>>2] = $j$01;
      $65 = HEAP32[$12>>2]|0;
      $66 = (((($65) + (($i$02*796)|0)|0) + (($j$01*12)|0)|0) + 4|0);
      $67 = (($52) + 24|0);
      HEAP32[$67>>2] = $66;
      $68 = (($52) + 28|0);
      $69 = HEAP32[$48>>2]|0;
      $70 = (__Z40ConfigureBlockRangesWithMinIndicesPerJobP10BlockRangeii($68,$69,256)|0);
      $71 = (($52) + 220|0);
      HEAP32[$71>>2] = $70;
      __Z21ScheduleForEachJobSetR8JobFencePFvPvjES1_iPFvS1_ES0_11JobPriority($47,2642,$52,$70,3432,$createShadowCullerFence,0);
     }
     $72 = (($j$01) + 1)|0;
     $exitcond = ($72|0)==(5);
     if ($exitcond) {
      break;
     } else {
      $j$01 = $72;
     }
    }
    __Z21ClearFenceWithoutSyncR8JobFence($createShadowCullerFence);
   }
   $73 = (($i$02) + 1)|0;
   $exitcond4 = ($73|0)==($dirShadowLightCount|0);
   if ($exitcond4) {
    break;
   } else {
    $i$02 = $73;
   }
  }
 }
 __Z21ClearFenceWithoutSyncR8JobFence($6);
 STACKTOP = sp;return;
}
function __ZL60CombineDirectionalShadowCasterCullignIndexListsAndDestroyJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond10$i = 0, $i$03$i = 0, $j$02$i = 0, $visibleCountNodes$0$lcssa$i = 0, $visibleCountNodes$04$i = 0, $visibleCountNodes$1$lcssa$i = 0, $visibleCountNodes$11$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($userData) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($userData) + 28|0);
 $4 = (($userData) + 220|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($userData) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)>(1);
 if ($8) {
  $i$03$i = 1;$visibleCountNodes$04$i = $7;
  while(1) {
   $9 = (($3) + (($i$03$i*12)|0)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($3) + (($i$03$i*12)|0)|0) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($10))|0;
   $14 = ($10>>>0)<($13>>>0);
   if ($14) {
    $15 = HEAP32[$2>>2]|0;
    $j$02$i = $10;$visibleCountNodes$11$i = $visibleCountNodes$04$i;
    while(1) {
     $16 = (($15) + ($j$02$i<<2)|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($visibleCountNodes$11$i) + 1)|0;
     $19 = (($15) + ($visibleCountNodes$11$i<<2)|0);
     HEAP32[$19>>2] = $17;
     $20 = (($j$02$i) + 1)|0;
     $exitcond$i = ($20|0)==($13|0);
     if ($exitcond$i) {
      break;
     } else {
      $j$02$i = $20;$visibleCountNodes$11$i = $18;
     }
    }
    $21 = (($12) + ($visibleCountNodes$04$i))|0;
    $visibleCountNodes$1$lcssa$i = $21;
   } else {
    $visibleCountNodes$1$lcssa$i = $visibleCountNodes$04$i;
   }
   $22 = (($i$03$i) + 1)|0;
   $exitcond10$i = ($22|0)==($5|0);
   if ($exitcond10$i) {
    $visibleCountNodes$0$lcssa$i = $visibleCountNodes$1$lcssa$i;
    break;
   } else {
    $i$03$i = $22;$visibleCountNodes$04$i = $visibleCountNodes$1$lcssa$i;
   }
  }
 } else {
  $visibleCountNodes$0$lcssa$i = $7;
 }
 $23 = (($2) + 4|0);
 HEAP32[$23>>2] = $visibleCountNodes$0$lcssa$i;
 $24 = HEAP32[628520>>2]|0;
 HEAP32[$0>>2] = $24;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z23CullDirectionalCascadesRNSt3__16vectorI16ShadowCasterData13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEEPK17ShadowCascadeInfoiRK11QuaternionfRK8Vector3fRK14ShadowCullData($casters,$cascades,$cascadeCount,$lightRot,$lightDir,$cullData) {
 $casters = $casters|0;
 $cascades = $cascades|0;
 $cascadeCount = $cascadeCount|0;
 $lightRot = $lightRot|0;
 $lightDir = $lightDir|0;
 $cullData = $cullData|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allVisible$0$lcssa = 0, $allVisible$021 = 0, $alreadyTested = 0, $casc$025 = 0, $casc1$020 = 0, $casc2$011 = 0, $casc3$014 = 0, $cullCylinders = 0, $cullPlanes = 0, $currentCascadeMask$010 = 0, $currentCascadeMask$113 = 0;
 var $exitcond = 0, $exitcond29 = 0, $exitcond30 = 0, $exitcond33 = 0, $i$017 = 0, $lightMat = 0, $or$cond = 0, $splitPlanes = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 880|0;
 $cullPlanes = sp + 216|0;
 $cullCylinders = sp;
 $lightMat = sp + 48|0;
 $alreadyTested = sp + 112|0;
 $splitPlanes = sp + 120|0;
 $0 = (__Z18GetQualitySettingsv()|0);
 $1 = (($0) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*96)|0)|0) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 $8 = ($cascadeCount|0)==(1);
 $or$cond = $7 & $8;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$cullData>>2]|0;
 HEAPF32[$cullPlanes>>2] = Math_fround(0.0);
 $10 = (($cullPlanes) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($cullPlanes) + 8|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($cullPlanes) + 16|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($cullPlanes) + 20|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($cullPlanes) + 24|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($cullPlanes) + 32|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($cullPlanes) + 36|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($cullPlanes) + 40|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($cullPlanes) + 48|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($cullPlanes) + 52|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($cullPlanes) + 56|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($cullPlanes) + 64|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($cullPlanes) + 68|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($cullPlanes) + 72|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($cullPlanes) + 80|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($cullPlanes) + 84|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($cullPlanes) + 88|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($cullPlanes) + 96|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($cullPlanes) + 100|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($cullPlanes) + 104|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($cullPlanes) + 112|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($cullPlanes) + 116|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($cullPlanes) + 120|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($cullPlanes) + 128|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($cullPlanes) + 132|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($cullPlanes) + 136|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($cullPlanes) + 144|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($cullPlanes) + 148|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($cullPlanes) + 152|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($cullPlanes) + 164|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($cullPlanes) + 168|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($cullPlanes) + 172|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($cullPlanes) + 180|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($cullPlanes) + 184|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($cullPlanes) + 188|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($cullPlanes) + 196|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($cullPlanes) + 200|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($cullPlanes) + 204|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($cullPlanes) + 212|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($cullPlanes) + 216|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($cullPlanes) + 220|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($cullPlanes) + 228|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($cullPlanes) + 232|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($cullPlanes) + 236|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($cullPlanes) + 244|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($cullPlanes) + 248|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($cullPlanes) + 252|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($cullPlanes) + 260|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($cullPlanes) + 264|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($cullPlanes) + 268|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($cullPlanes) + 276|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($cullPlanes) + 280|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (($cullPlanes) + 284|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($cullPlanes) + 292|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($cullPlanes) + 296|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = (($cullPlanes) + 300|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 $66 = (($cullPlanes) + 308|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($cullPlanes) + 312|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($cullPlanes) + 316|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($cullPlanes) + 328|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 $70 = (($cullPlanes) + 332|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($cullPlanes) + 336|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($cullPlanes) + 344|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($cullPlanes) + 348|0);
 HEAPF32[$73>>2] = Math_fround(0.0);
 $74 = (($cullPlanes) + 352|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($cullPlanes) + 360|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($cullPlanes) + 364|0);
 HEAPF32[$76>>2] = Math_fround(0.0);
 $77 = (($cullPlanes) + 368|0);
 HEAPF32[$77>>2] = Math_fround(0.0);
 $78 = (($cullPlanes) + 376|0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = (($cullPlanes) + 380|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($cullPlanes) + 384|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 $81 = (($cullPlanes) + 392|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 $82 = (($cullPlanes) + 396|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = (($cullPlanes) + 400|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($cullPlanes) + 408|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 $85 = (($cullPlanes) + 412|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 $86 = (($cullPlanes) + 416|0);
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = (($cullPlanes) + 424|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($cullPlanes) + 428|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($cullPlanes) + 432|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 $90 = (($cullPlanes) + 440|0);
 HEAPF32[$90>>2] = Math_fround(0.0);
 $91 = (($cullPlanes) + 444|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($cullPlanes) + 448|0);
 HEAPF32[$92>>2] = Math_fround(0.0);
 $93 = (($cullPlanes) + 456|0);
 HEAPF32[$93>>2] = Math_fround(0.0);
 $94 = (($cullPlanes) + 460|0);
 HEAPF32[$94>>2] = Math_fround(0.0);
 $95 = (($cullPlanes) + 464|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($cullPlanes) + 472|0);
 HEAPF32[$96>>2] = Math_fround(0.0);
 $97 = (($cullPlanes) + 476|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 $98 = (($cullPlanes) + 480|0);
 HEAPF32[$98>>2] = Math_fround(0.0);
 $99 = (($cullPlanes) + 492|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = (($cullPlanes) + 496|0);
 HEAPF32[$100>>2] = Math_fround(0.0);
 $101 = (($cullPlanes) + 500|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = (($cullPlanes) + 508|0);
 HEAPF32[$102>>2] = Math_fround(0.0);
 $103 = (($cullPlanes) + 512|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($cullPlanes) + 516|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($cullPlanes) + 524|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = (($cullPlanes) + 528|0);
 HEAPF32[$106>>2] = Math_fround(0.0);
 $107 = (($cullPlanes) + 532|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($cullPlanes) + 540|0);
 HEAPF32[$108>>2] = Math_fround(0.0);
 $109 = (($cullPlanes) + 544|0);
 HEAPF32[$109>>2] = Math_fround(0.0);
 $110 = (($cullPlanes) + 548|0);
 HEAPF32[$110>>2] = Math_fround(0.0);
 $111 = (($cullPlanes) + 556|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = (($cullPlanes) + 560|0);
 HEAPF32[$112>>2] = Math_fround(0.0);
 $113 = (($cullPlanes) + 564|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = (($cullPlanes) + 572|0);
 HEAPF32[$114>>2] = Math_fround(0.0);
 $115 = (($cullPlanes) + 576|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = (($cullPlanes) + 580|0);
 HEAPF32[$116>>2] = Math_fround(0.0);
 $117 = (($cullPlanes) + 588|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 $118 = (($cullPlanes) + 592|0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 $119 = (($cullPlanes) + 596|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($cullPlanes) + 604|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($cullPlanes) + 608|0);
 HEAPF32[$121>>2] = Math_fround(0.0);
 $122 = (($cullPlanes) + 612|0);
 HEAPF32[$122>>2] = Math_fround(0.0);
 $123 = (($cullPlanes) + 620|0);
 HEAPF32[$123>>2] = Math_fround(0.0);
 $124 = (($cullPlanes) + 624|0);
 HEAPF32[$124>>2] = Math_fround(0.0);
 $125 = (($cullPlanes) + 628|0);
 HEAPF32[$125>>2] = Math_fround(0.0);
 $126 = (($cullPlanes) + 636|0);
 HEAPF32[$126>>2] = Math_fround(0.0);
 $127 = (($cullPlanes) + 640|0);
 HEAPF32[$127>>2] = Math_fround(0.0);
 $128 = (($cullPlanes) + 644|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 HEAPF32[$cullCylinders>>2] = Math_fround(0.0);
 $129 = (($cullCylinders) + 4|0);
 HEAPF32[$129>>2] = Math_fround(0.0);
 $130 = (($cullCylinders) + 12|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = (($cullCylinders) + 16|0);
 HEAPF32[$131>>2] = Math_fround(0.0);
 $132 = (($cullCylinders) + 24|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = (($cullCylinders) + 28|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = (($cullCylinders) + 36|0);
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = (($cullCylinders) + 40|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 __Z18QuaternionToMatrixRK11QuaternionfR10Matrix4x4f($lightRot,$lightMat);
 $136 = ($cascadeCount|0)>(0);
 if ($136) {
  $137 = (($lightMat) + 4|0);
  $138 = (($lightMat) + 8|0);
  $139 = (($lightMat) + 16|0);
  $140 = (($lightMat) + 20|0);
  $141 = (($lightMat) + 24|0);
  $142 = (($alreadyTested) + 4|0);
  $143 = (($alreadyTested) + 5|0);
  $144 = (($cullData) + 460|0);
  $145 = (($9) + 456|0);
  $146 = (($splitPlanes) + 76|0);
  $147 = (($cullData) + 580|0);
  $148 = (($splitPlanes) + 92|0);
  $149 = (($cullData) + 584|0);
  $150 = (($cullData) + 588|0);
  $151 = (($9) + 616|0);
  $152 = (($cullData) + 4|0);
  $153 = (($cullData) + 196|0);
  $casc$025 = 0;
  while(1) {
   $154 = (($cascades) + (($casc$025*356)|0)|0);
   $155 = HEAP8[$154>>0]|0;
   $156 = ($155<<24>>24)==(0);
   do {
    if (!($156)) {
     $157 = HEAP32[$5>>2]|0;
     $158 = ($157|0)==(1);
     if ($158) {
      $159 = Math_fround(HEAPF32[$lightMat>>2]);
      $160 = Math_fround(HEAPF32[$137>>2]);
      $161 = Math_fround(HEAPF32[$138>>2]);
      $162 = ((($cascades) + (($casc$025*356)|0)|0) + 324|0);
      $163 = Math_fround(HEAPF32[$162>>2]);
      $164 = Math_fround($159 * $163);
      $165 = ((($cascades) + (($casc$025*356)|0)|0) + 328|0);
      $166 = Math_fround(HEAPF32[$165>>2]);
      $167 = Math_fround($160 * $166);
      $168 = Math_fround($164 + $167);
      $169 = ((($cascades) + (($casc$025*356)|0)|0) + 332|0);
      $170 = Math_fround(HEAPF32[$169>>2]);
      $171 = Math_fround($161 * $170);
      $172 = Math_fround($168 + $171);
      $173 = (($cullCylinders) + (($casc$025*12)|0)|0);
      HEAPF32[$173>>2] = $172;
      $174 = Math_fround(HEAPF32[$139>>2]);
      $175 = Math_fround(HEAPF32[$140>>2]);
      $176 = Math_fround(HEAPF32[$141>>2]);
      $177 = Math_fround($174 * $163);
      $178 = Math_fround($175 * $166);
      $179 = Math_fround($177 + $178);
      $180 = Math_fround($176 * $170);
      $181 = Math_fround($179 + $180);
      $182 = ((($cullCylinders) + (($casc$025*12)|0)|0) + 4|0);
      HEAPF32[$182>>2] = $181;
      $183 = ((($cascades) + (($casc$025*356)|0)|0) + 336|0);
      $184 = Math_fround(HEAPF32[$183>>2]);
      $185 = ((($cullCylinders) + (($casc$025*12)|0)|0) + 8|0);
      HEAPF32[$185>>2] = $184;
     }
     if ($8) {
      $210 = ((($cullPlanes) + (($casc$025*164)|0)|0) + 160|0);
      HEAP32[$210>>2] = 0;
      break;
     } else {
      HEAP32[$alreadyTested>>2] = 16843009;
      $186 = ($casc$025|0)==(0);
      $187 = $186&1;
      HEAP8[$142>>0] = $187;
      $188 = (($casc$025) + 1)|0;
      $189 = ($188|0)==($cascadeCount|0);
      $190 = $189&1;
      HEAP8[$143>>0] = $190;
      dest=$splitPlanes+0|0; src=$144+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $191 = ((($cascades) + (($casc$025*356)|0)|0) + 340|0);
      $192 = Math_fround(HEAPF32[$191>>2]);
      $193 = Math_fround(HEAPF32[$145>>2]);
      $194 = Math_fround($192 - $193);
      $195 = Math_fround(HEAPF32[$146>>2]);
      $196 = Math_fround($195 + $194);
      HEAPF32[$146>>2] = $196;
      $197 = ((($cascades) + (($casc$025*356)|0)|0) + 344|0);
      $198 = Math_fround(HEAPF32[$197>>2]);
      $199 = Math_fround(HEAPF32[$147>>2]);
      $200 = Math_fround($198 - $199);
      $201 = Math_fround(HEAPF32[$148>>2]);
      $202 = Math_fround($201 + $200);
      HEAPF32[$148>>2] = $202;
      $203 = Math_fround(HEAPF32[$149>>2]);
      $204 = Math_fround($192 / $203);
      $205 = Math_fround(HEAPF32[$150>>2]);
      $206 = Math_fround($198 / $205);
      $207 = HEAP8[$151>>0]|0;
      $208 = ($207<<24>>24)!=(0);
      $209 = (($cullPlanes) + (($casc$025*164)|0)|0);
      __Z25CalculateShadowCasterCullbPK5PlaneRK10Matrix4x4fRK8Vector3fff9LightTypeS7_R16ShadowCasterCullPKb($208,$splitPlanes,$152,$153,$204,$206,1,$lightDir,$209,$alreadyTested);
      break;
     }
    }
   } while(0);
   $211 = (($casc$025) + 1)|0;
   $exitcond33 = ($211|0)==($cascadeCount|0);
   if ($exitcond33) {
    break;
   } else {
    $casc$025 = $211;
   }
  }
  if ($136) {
   $allVisible$021 = 0;$casc1$020 = 0;
   while(1) {
    $212 = $allVisible$021 << 1;
    $213 = $212 | 1;
    $214 = (($casc1$020) + 1)|0;
    $exitcond30 = ($214|0)==($cascadeCount|0);
    if ($exitcond30) {
     $allVisible$0$lcssa = $213;
     break;
    } else {
     $allVisible$021 = $213;$casc1$020 = $214;
    }
   }
  } else {
   $allVisible$0$lcssa = 0;
  }
 } else {
  $allVisible$0$lcssa = 0;
 }
 $215 = (($casters) + 4|0);
 $216 = HEAP32[$215>>2]|0;
 $217 = HEAP32[$casters>>2]|0;
 $218 = $216;
 $219 = $217;
 $220 = (($218) - ($219))|0;
 $221 = (($220|0) / 24)&-1;
 $222 = ($220|0)>(0);
 if (!($222)) {
  STACKTOP = sp;return;
 }
 $223 = (($lightMat) + 4|0);
 $224 = (($lightMat) + 8|0);
 $225 = (($lightMat) + 16|0);
 $226 = (($lightMat) + 20|0);
 $227 = (($lightMat) + 24|0);
 $228 = ($cascadeCount|0)>(1);
 $230 = $217;$i$017 = 0;
 while(1) {
  $229 = ((($230) + (($i$017*24)|0)|0) + 4|0);
  $231 = HEAP32[$229>>2]|0;
  $232 = ((($230) + (($i$017*24)|0)|0) + 16|0);
  HEAP32[$232>>2] = $allVisible$0$lcssa;
  $233 = HEAP32[$5>>2]|0;
  $234 = ($233|0)==(1);
  if ($234) {
   $235 = (($231) + 12|0);
   $236 = Math_fround(HEAPF32[$235>>2]);
   $237 = Math_fround($236 * $236);
   $238 = (($231) + 16|0);
   $239 = Math_fround(HEAPF32[$238>>2]);
   $240 = Math_fround($239 * $239);
   $241 = Math_fround($237 + $240);
   $242 = (($231) + 20|0);
   $243 = Math_fround(HEAPF32[$242>>2]);
   $244 = Math_fround($243 * $243);
   $245 = Math_fround($241 + $244);
   $246 = (Math_fround(Math_sqrt((Math_fround($245)))));
   $247 = Math_fround(HEAPF32[$lightMat>>2]);
   $248 = Math_fround(HEAPF32[$223>>2]);
   $249 = Math_fround(HEAPF32[$224>>2]);
   $250 = Math_fround(HEAPF32[$231>>2]);
   $251 = Math_fround($247 * $250);
   $252 = (($231) + 4|0);
   $253 = Math_fround(HEAPF32[$252>>2]);
   $254 = Math_fround($248 * $253);
   $255 = Math_fround($251 + $254);
   $256 = (($231) + 8|0);
   $257 = Math_fround(HEAPF32[$256>>2]);
   $258 = Math_fround($249 * $257);
   $259 = Math_fround($255 + $258);
   $260 = Math_fround(HEAPF32[$225>>2]);
   $261 = Math_fround(HEAPF32[$226>>2]);
   $262 = Math_fround(HEAPF32[$227>>2]);
   $263 = Math_fround($250 * $260);
   $264 = Math_fround($253 * $261);
   $265 = Math_fround($263 + $264);
   $266 = Math_fround($257 * $262);
   $267 = Math_fround($265 + $266);
   if ($136) {
    $287 = $allVisible$0$lcssa;$casc2$011 = 0;$currentCascadeMask$010 = 1;
    while(1) {
     $268 = (($cascades) + (($casc2$011*356)|0)|0);
     $269 = HEAP8[$268>>0]|0;
     $270 = ($269<<24>>24)==(0);
     if ($270) {
      $307 = $287;
     } else {
      $271 = (($cullCylinders) + (($casc2$011*12)|0)|0);
      $272 = Math_fround(HEAPF32[$271>>2]);
      $273 = Math_fround($259 - $272);
      $274 = ((($cullCylinders) + (($casc2$011*12)|0)|0) + 4|0);
      $275 = Math_fround(HEAPF32[$274>>2]);
      $276 = Math_fround($267 - $275);
      $277 = Math_fround($273 * $273);
      $278 = Math_fround($276 * $276);
      $279 = Math_fround($277 + $278);
      $280 = ((($cullCylinders) + (($casc2$011*12)|0)|0) + 8|0);
      $281 = Math_fround(HEAPF32[$280>>2]);
      $282 = Math_fround($246 + $281);
      $283 = Math_fround($282 * $282);
      $284 = $279 > $283;
      if ($284) {
       $285 = $currentCascadeMask$010 ^ -1;
       $286 = $287 & $285;
       HEAP32[$232>>2] = $286;
       $307 = $286;
      } else {
       $307 = $287;
      }
     }
     $288 = (($casc2$011) + 1)|0;
     $289 = $currentCascadeMask$010 << 1;
     $exitcond = ($288|0)==($cascadeCount|0);
     if ($exitcond) {
      break;
     } else {
      $287 = $307;$casc2$011 = $288;$currentCascadeMask$010 = $289;
     }
    }
   }
  }
  if ($228) {
   $casc3$014 = 0;$currentCascadeMask$113 = 1;
   while(1) {
    $290 = (($cascades) + (($casc3$014*356)|0)|0);
    $291 = HEAP8[$290>>0]|0;
    $292 = ($291<<24>>24)==(0);
    if (!($292)) {
     $293 = HEAP32[$232>>2]|0;
     $294 = $293 & $currentCascadeMask$113;
     $295 = ($294|0)==(0);
     if (!($295)) {
      $296 = (($cullPlanes) + (($casc3$014*164)|0)|0);
      $297 = ((($cullPlanes) + (($casc3$014*164)|0)|0) + 160|0);
      $298 = HEAP32[$297>>2]|0;
      $299 = (__Z24IntersectAABBPlaneBoundsRK4AABBPK5Planei($231,$296,$298)|0);
      if (!($299)) {
       $300 = $currentCascadeMask$113 ^ -1;
       $301 = HEAP32[$232>>2]|0;
       $302 = $301 & $300;
       HEAP32[$232>>2] = $302;
      }
     }
    }
    $303 = (($casc3$014) + 1)|0;
    $304 = $currentCascadeMask$113 << 1;
    $exitcond29 = ($303|0)==($cascadeCount|0);
    if ($exitcond29) {
     break;
    } else {
     $casc3$014 = $303;$currentCascadeMask$113 = $304;
    }
   }
  }
  $305 = (($i$017) + 1)|0;
  $306 = ($305|0)<($221|0);
  if (!($306)) {
   break;
  }
  $$pre = HEAP32[$casters>>2]|0;
  $230 = $$pre;$i$017 = $305;
 }
 STACKTOP = sp;return;
}
function __Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE($passContext) {
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($passContext) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -8161;
 $3 = $2 | 32;
 HEAP32[$0>>2] = $3;
 STACKTOP = sp;return;
}
function __Z21GetSoftShadowsEnabledv() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetBuildSettingsv()|0);
 $1 = (($0) + 101|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($0) + 102|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = HEAP8[((640792 + 272|0))>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $or$cond = $6 & $8;
 if (!($or$cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__Z18GetQualitySettingsv()|0);
 $10 = (($9) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13) + (($11*96)|0)|0) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)<(2);
 if ($16) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = (Math_fround(__ZN15QualitySettings29GetShadowDistanceForRenderingEv()));
 $18 = $17 > Math_fround(0.0);
 $$0 = $18;
 STACKTOP = sp;return ($$0|0);
}
function __Z18SetShadowsKeywordsRN9ShaderLab17ShaderPassContextE9LightType10ShadowTypebb($passContext,$lightType,$shadowType,$screen,$enableSoftShadows) {
 $passContext = $passContext|0;
 $lightType = $lightType|0;
 $shadowType = $shadowType|0;
 $screen = $screen|0;
 $enableSoftShadows = $enableSoftShadows|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $brmerge = 0, $enableSoftShadows$not = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond1 = 0, $or$cond3 = 0, $storemerge = 0, $storemerge4 = 0, $storemerge5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetQualitySettingsv()|0);
 $1 = (($0) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*96)|0)|0) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($passContext) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & -2593;
 $$not = ($shadowType|0)!=(2);
 $enableSoftShadows$not = $enableSoftShadows ^ 1;
 $brmerge = $$not | $enableSoftShadows$not;
 $10 = $9 | 512;
 $11 = $8 & -2593;
 $storemerge = $brmerge ? $11 : $10;
 $notlhs = ($lightType|0)==(1);
 $notrhs = ($shadowType|0)!=(0);
 $or$cond$not = $notrhs & $notlhs;
 $12 = ($6|0)==(1);
 $or$cond1 = $or$cond$not & $12;
 $13 = $storemerge & -3105;
 $14 = $storemerge | 1024;
 $storemerge4 = $or$cond1 ? $14 : $13;
 HEAP32[$7>>2] = $storemerge4;
 do {
  if ($screen) {
   $15 = $storemerge4 & -2529;
   $16 = $15 | 128;
   HEAP32[$7>>2] = $16;
   $17 = HEAP8[((640792 + 249|0))>>0]|0;
   $18 = ($17<<24>>24)!=(0);
   $19 = HEAP8[((640792 + 250|0))>>0]|0;
   $20 = ($19<<24>>24)==(0);
   $or$cond3 = $18 & $20;
   if ($or$cond3) {
    $21 = $15 | 2176;
    HEAP32[$7>>2] = $21;
   }
  } else {
   $22 = ($lightType|0)==(2);
   $23 = $storemerge4 & -2529;
   if ($22) {
    $24 = $23 | 256;
    HEAP32[$7>>2] = $24;
    break;
   }
   $25 = $23 | 64;
   HEAP32[$7>>2] = $25;
   $26 = HEAP8[((640792 + 249|0))>>0]|0;
   $27 = ($26<<24>>24)==(0);
   if (!($27)) {
    $28 = $23 | 2112;
    HEAP32[$7>>2] = $28;
   }
  }
 } while(0);
 $29 = (__Z18GetQualitySettingsv()|0);
 $30 = (($29) + 40|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($33) + (($31*96)|0)|0) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)>(1);
 $37 = HEAP32[$7>>2]|0;
 $38 = $37 | 4096;
 $39 = $37 & -4097;
 $storemerge5 = $36 ? $39 : $38;
 HEAP32[$7>>2] = $storemerge5;
 STACKTOP = sp;return;
}
function __Z16RenderShadowMapsR16ShadowCameraDataRK11ActiveLightRK10MinMaxAABBRN9ShaderLab17ShaderPassContextEP10Matrix4x4f($cameraData,$activeLight,$receiverBounds,$passContext,$outShadowMatrices) {
 $cameraData = $cameraData|0;
 $activeLight = $activeLight|0;
 $receiverBounds = $receiverBounds|0;
 $passContext = $passContext|0;
 $outShadowMatrices = $outShadowMatrices|0;
 var $$ = 0, $$$i$i = 0, $$$i1$i = 0, $$$i4$i = 0, $$0 = 0, $$0$i = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$1$i = 0, $$10 = 0, $$11 = 0, $$7 = 0, $$9 = 0, $$byval_copy31 = 0, $$idx$val = 0, $$in$i$i = 0, $$lcssa$i = Math_fround(0), $$lcssa55$i = Math_fround(0), $$lcssa56$i = Math_fround(0);
 var $$lcssa57$i = Math_fround(0), $$lcssa58$i = Math_fround(0), $$lcssa59$i = Math_fround(0), $$phi$trans$insert$i = 0, $$phi$trans$insert101$phi$trans$insert$i = 0, $$phi$trans$insert103$phi$trans$insert$i = 0, $$phi$trans$insert93$phi$trans$insert$i = 0, $$phi$trans$insert96$phi$trans$insert$i = 0, $$phi$trans$insert98$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = Math_fround(0), $$pre$i28 = 0, $$pre$i29 = 0, $$pre$phi$iZ2D = 0, $$pre$phiZ2D = 0, $$pre$pre$i = Math_fround(0), $$pre1$i = 0, $$pre1$i30 = 0, $$pre100$i = Math_fround(0), $$pre102$i = Math_fround(0);
 var $$pre102$pre$i = Math_fround(0), $$pre104$i = Math_fround(0), $$pre104$pre$i = Math_fround(0), $$pre105$i = Math_fround(0), $$pre200 = 0, $$pre202 = 0, $$pre9$pre$i = 0, $$pre94$i = Math_fround(0), $$pre94$pre$i = Math_fround(0), $$pre95$i = Math_fround(0), $$pre97$i = Math_fround(0), $$pre97$pre$i = Math_fround(0), $$pre99$i = Math_fround(0), $$pre99$pre$i = Math_fround(0), $$sum$i31 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = Math_fround(0);
 var $1001 = 0, $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = Math_fround(0), $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = 0, $1019 = 0;
 var $102 = 0, $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = 0, $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = 0;
 var $1038 = 0, $1039 = 0, $104 = Math_fround(0), $1040 = 0, $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = 0, $1044 = 0, $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = 0, $105 = 0, $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0;
 var $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = Math_fround(0), $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = Math_fround(0), $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0;
 var $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = Math_fround(0), $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = 0, $1090 = Math_fround(0), $1091 = Math_fround(0);
 var $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0);
 var $111 = 0, $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = Math_fround(0), $1127 = 0;
 var $1128 = Math_fround(0), $1129 = 0, $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = 0, $1132 = Math_fround(0), $1133 = 0, $1134 = Math_fround(0), $1135 = 0, $1136 = Math_fround(0), $1137 = 0, $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = Math_fround(0), $1140 = 0, $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = 0, $1144 = Math_fround(0), $1145 = Math_fround(0);
 var $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = 0, $1150 = Math_fround(0), $1151 = 0, $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = 0, $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = 0, $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = Math_fround(0), $1163 = Math_fround(0);
 var $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = 0, $1169 = 0, $117 = Math_fround(0), $1170 = 0, $1171 = 0, $1172 = Math_fround(0), $1173 = 0, $1174 = Math_fround(0), $1175 = 0, $1176 = Math_fround(0), $1177 = 0, $1178 = Math_fround(0), $1179 = 0, $118 = Math_fround(0), $1180 = Math_fround(0), $1181 = 0;
 var $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = Math_fround(0), $1187 = Math_fround(0), $1188 = 0, $1189 = Math_fround(0), $119 = 0, $1190 = Math_fround(0), $1191 = 0, $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = Math_fround(0), $1197 = Math_fround(0), $1198 = Math_fround(0), $1199 = Math_fround(0), $12 = 0;
 var $120 = 0, $1200 = Math_fround(0), $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = 0, $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = 0, $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = 0, $1210 = 0, $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = 0, $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = 0, $1217 = Math_fround(0);
 var $1218 = Math_fround(0), $1219 = 0, $122 = 0, $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = 0, $1223 = 0, $1224 = Math_fround(0), $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = 0, $1228 = Math_fround(0), $1229 = 0, $123 = 0, $1230 = Math_fround(0), $1231 = 0, $1232 = Math_fround(0), $1233 = 0, $1234 = Math_fround(0), $1235 = 0;
 var $1236 = Math_fround(0), $1237 = 0, $1238 = 0, $1239 = Math_fround(0), $124 = 0, $1240 = 0, $1241 = Math_fround(0), $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = Math_fround(0), $1245 = 0, $1246 = Math_fround(0), $1247 = 0, $1248 = 0, $1249 = Math_fround(0), $125 = Math_fround(0), $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0), $1253 = Math_fround(0);
 var $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = 0, $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0), $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0), $1271 = Math_fround(0);
 var $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = Math_fround(0), $1276 = Math_fround(0), $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = Math_fround(0), $1280 = Math_fround(0), $1281 = Math_fround(0), $1282 = Math_fround(0), $1283 = Math_fround(0), $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = Math_fround(0), $1287 = Math_fround(0), $1288 = Math_fround(0), $1289 = Math_fround(0), $129 = 0;
 var $1290 = Math_fround(0), $1291 = 0, $1292 = Math_fround(0), $1293 = Math_fround(0), $1294 = Math_fround(0), $1295 = 0, $1296 = Math_fround(0), $1297 = Math_fround(0), $1298 = Math_fround(0), $1299 = 0, $13 = 0, $130 = 0, $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = 0, $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = 0, $1307 = Math_fround(0);
 var $1308 = Math_fround(0), $1309 = Math_fround(0), $131 = 0, $1310 = 0, $1311 = Math_fround(0), $1312 = 0, $1313 = Math_fround(0), $1314 = 0, $1315 = Math_fround(0), $1316 = 0, $1317 = Math_fround(0), $1318 = 0, $1319 = Math_fround(0), $132 = 0, $1320 = 0, $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = Math_fround(0), $1325 = Math_fround(0);
 var $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = 0, $133 = 0, $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = 0, $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = 0, $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = 0, $1340 = Math_fround(0), $1341 = Math_fround(0), $1342 = Math_fround(0), $1343 = Math_fround(0);
 var $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = 0, $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = 0, $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = 0, $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = 0, $1358 = Math_fround(0), $1359 = Math_fround(0), $136 = 0, $1360 = 0, $1361 = Math_fround(0);
 var $1362 = Math_fround(0), $1363 = 0, $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = 0, $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = 0, $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = Math_fround(0), $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = Math_fround(0), $1379 = Math_fround(0), $138 = 0;
 var $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = 0, $1390 = Math_fround(0), $1391 = Math_fround(0), $1392 = Math_fround(0), $1393 = Math_fround(0), $1394 = Math_fround(0), $1395 = Math_fround(0), $1396 = Math_fround(0), $1397 = Math_fround(0), $1398 = Math_fround(0);
 var $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = Math_fround(0), $1401 = Math_fround(0), $1402 = Math_fround(0), $1403 = Math_fround(0), $1404 = Math_fround(0), $1405 = Math_fround(0), $1406 = Math_fround(0), $1407 = Math_fround(0), $1408 = Math_fround(0), $1409 = Math_fround(0), $141 = 0, $1410 = Math_fround(0), $1411 = Math_fround(0), $1412 = Math_fround(0), $1413 = Math_fround(0), $1414 = Math_fround(0), $1415 = Math_fround(0);
 var $1416 = 0.0, $1417 = Math_fround(0), $1418 = 0.0, $1419 = 0.0, $142 = 0, $1420 = 0.0, $1421 = Math_fround(0), $1422 = 0.0, $1423 = 0.0, $1424 = 0.0, $1425 = 0.0, $1426 = Math_fround(0), $1427 = 0.0, $1428 = 0.0, $1429 = 0.0, $143 = 0, $1430 = 0.0, $1431 = Math_fround(0), $1432 = Math_fround(0), $1433 = Math_fround(0);
 var $1434 = 0.0, $1435 = 0, $1436 = 0, $1437 = Math_fround(0), $1438 = 0.0, $1439 = 0.0, $144 = 0, $1440 = 0.0, $1441 = 0.0, $1442 = 0.0, $1443 = 0.0, $1444 = 0.0, $1445 = 0.0, $1446 = 0.0, $1447 = 0.0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = Math_fround(0), $1451 = Math_fround(0);
 var $1452 = Math_fround(0), $1453 = Math_fround(0), $1454 = Math_fround(0), $1455 = Math_fround(0), $1456 = Math_fround(0), $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = 0, $1460 = Math_fround(0), $1461 = Math_fround(0), $1462 = Math_fround(0), $1463 = Math_fround(0), $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = Math_fround(0), $1467 = Math_fround(0), $1468 = Math_fround(0), $1469 = Math_fround(0), $147 = 0;
 var $1470 = Math_fround(0), $1471 = Math_fround(0), $1472 = Math_fround(0), $1473 = Math_fround(0), $1474 = Math_fround(0), $1475 = Math_fround(0), $1476 = Math_fround(0), $1477 = Math_fround(0), $1478 = Math_fround(0), $1479 = Math_fround(0), $148 = 0, $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0), $1486 = 0, $1487 = Math_fround(0), $1488 = 0;
 var $1489 = 0, $149 = 0, $1490 = Math_fround(0), $1491 = Math_fround(0), $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = Math_fround(0), $1497 = 0, $1498 = Math_fround(0), $1499 = 0, $15 = 0, $150 = 0, $1500 = Math_fround(0), $1501 = Math_fround(0), $1502 = Math_fround(0), $1503 = Math_fround(0), $1504 = 0, $1505 = 0;
 var $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = Math_fround(0), $1522 = Math_fround(0), $1523 = Math_fround(0);
 var $1524 = 0, $1525 = Math_fround(0), $1526 = 0, $1527 = Math_fround(0), $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0;
 var $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = Math_fround(0), $1548 = Math_fround(0), $1549 = Math_fround(0), $155 = Math_fround(0), $1550 = Math_fround(0), $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0;
 var $1560 = 0, $1561 = 0, $1562 = 0, $1563 = Math_fround(0), $1564 = Math_fround(0), $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0;
 var $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = Math_fround(0), $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = Math_fround(0), $1593 = Math_fround(0), $1594 = Math_fround(0), $1595 = 0, $1596 = Math_fround(0);
 var $1597 = 0, $1598 = Math_fround(0), $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = Math_fround(0), $1602 = Math_fround(0), $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0;
 var $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0;
 var $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = Math_fround(0), $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0;
 var $1650 = 0, $1651 = Math_fround(0), $1652 = Math_fround(0), $1653 = 0, $1654 = Math_fround(0), $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = Math_fround(0), $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0;
 var $1669 = 0, $167 = Math_fround(0), $1670 = Math_fround(0), $1671 = 0, $1672 = 0, $1673 = 0, $1674 = Math_fround(0), $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0;
 var $1687 = 0, $1688 = 0, $1689 = 0, $169 = Math_fround(0), $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0;
 var $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = Math_fround(0), $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = Math_fround(0), $1720 = 0, $1721 = 0;
 var $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = Math_fround(0);
 var $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0;
 var $341 = 0, $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = Math_fround(0);
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = Math_fround(0), $569 = 0, $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = Math_fround(0), $574 = 0, $575 = Math_fround(0);
 var $576 = Math_fround(0), $577 = 0, $578 = Math_fround(0), $579 = 0, $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = 0, $584 = Math_fround(0), $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = Math_fround(0), $589 = 0, $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = 0, $593 = Math_fround(0);
 var $594 = Math_fround(0), $595 = 0, $596 = Math_fround(0), $597 = Math_fround(0), $598 = 0, $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = 0, $61 = 0, $610 = Math_fround(0);
 var $611 = 0, $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = 0, $616 = Math_fround(0), $617 = 0, $618 = Math_fround(0), $619 = 0, $62 = 0, $620 = Math_fround(0), $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0;
 var $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = Math_fround(0), $656 = Math_fround(0), $657 = 0, $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = 0, $661 = Math_fround(0), $662 = Math_fround(0), $663 = 0, $664 = Math_fround(0), $665 = Math_fround(0);
 var $666 = Math_fround(0), $667 = Math_fround(0), $668 = 0, $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = 0, $673 = Math_fround(0), $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0;
 var $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0;
 var $701 = Math_fround(0), $702 = Math_fround(0), $703 = 0, $704 = Math_fround(0), $705 = Math_fround(0), $706 = 0, $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = 0, $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0);
 var $72 = Math_fround(0), $720 = 0, $721 = 0, $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0);
 var $738 = Math_fround(0), $739 = Math_fround(0), $74 = Math_fround(0), $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0;
 var $756 = 0, $757 = Math_fround(0), $758 = 0, $759 = Math_fround(0), $76 = 0, $760 = 0, $761 = Math_fround(0), $762 = 0, $763 = Math_fround(0), $764 = Math_fround(0), $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0;
 var $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = Math_fround(0), $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0;
 var $792 = 0, $793 = 0, $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = Math_fround(0), $805 = 0, $806 = Math_fround(0), $807 = Math_fround(0), $808 = 0, $809 = 0;
 var $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0;
 var $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0;
 var $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0;
 var $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = Math_fround(0), $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0;
 var $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0;
 var $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = Math_fround(0), $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0;
 var $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = Math_fround(0), $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = Math_fround(0), $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0;
 var $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = Math_fround(0), $950 = 0, $951 = 0, $952 = 0, $953 = Math_fround(0);
 var $954 = Math_fround(0), $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = Math_fround(0), $966 = Math_fround(0), $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = Math_fround(0);
 var $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = Math_fround(0), $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0;
 var $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1$i = 0, $__new_last2$i$i$i$i$i102 = 0, $__new_last2$i$i$i$i$i12 = 0, $__new_last2$i$i$i$i$i19 = 0, $axisX$i = 0, $axisY$i = 0, $axisZ$i = 0, $bias$0$i = Math_fround(0);
 var $c$0124 = 0, $cameraFrustum$i = 0, $cameraProjection$i = 0, $cascades = 0, $casterBounds = 0, $casterParts = 0, $casterTouchesView$0$off0$i = 0, $casters = 0, $data$i$i = 0, $eh$lpad$body$index16Z2D = 0, $eh$lpad$body$indexZ2D = 0, $enablePCFFilter$0$off0 = 0, $enablePCFFilter$0$off0$ = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i$i39 = 0, $exitcond$i34 = 0, $exitcond$i40 = 0, $exitcond$i77 = 0, $exitcond92$i = 0;
 var $f$0129 = 0, $farPlaneScale$0$i = Math_fround(0), $focusPoints$i = 0, $frustumSplit$i = 0, $frustumTransform$0$i = 0, $i$0$i = 0, $i$0$in4$i = 0, $i$0$in4$i$phi = 0, $i$01$i = 0, $i$01$i$i = 0, $i$01$i37 = 0, $i$02$i$i = 0, $i$03$i = 0, $i$05$i = 0, $i$077$i = 0, $i2$060$i = 0, $i5$073$i = 0, $lightDir = 0, $lightDir$i = 0, $lightPos = 0;
 var $lightRot = 0, $localFrustumTransform$i = 0, $lpad$phi176$index = 0, $lpad$phi176$index4 = 0, $not$ = 0, $or$cond = 0, $or$cond8 = 0, $part$i$i = 0, $passIndex$i$i = 0, $phitmp2$i = 0, $phitmp2$i57 = 0, $planes = 0, $pos$i = 0, $projMatrix$i = 0, $projMatrix$i85 = 0, $radius$i = 0, $s$i = 0, $scevgep$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i103 = 0, $scevgep$i$i$i$i$i13 = 0, $scevgep$i$i$i$i$i2$i = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i107 = 0, $scevgep4$i$i$i$i$i17 = 0, $scevgep4$i$i$i$i$i24 = 0, $scevgep4$i$i$i$i$i6$i = 0, $shadowCubeMap$0$off0 = 0, $shadowFormat$0 = 0, $shadowFormat$1 = 0, $shadowHeight$0 = 0, $shadowHeight$1 = 0, $shadowHeight$2 = 0, $shadowHeight$3 = 0, $shadowWidth$0 = 0, $shadowWidth$1 = 0, $shadowWorldToClip = 0;
 var $sphereCenter$i = 0, $splitIndex$0171 = 0, $splitIndex$1$lcssa = 0, $splitIndex$1163 = 0, $splitIndex$2140 = 0, $splitIndex$3$lcssa = 0, $splitIndex$3133 = 0, $t$02$i = 0, $temp$i = 0, $texMatrix = 0, $texMatrix$i = 0, $texMatrix$i86 = 0, $tilesX$0 = 0, $tilesY$0 = 0, $tr$i = 0, $tx$0164 = 0, $tx2$0135 = 0, $ty$0172 = 0, $ty1$0141 = 0, $uglygep$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i105 = 0, $uglygep$i$i$i$i$i15 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep$i$i$i$i$i4$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i106 = 0, $uglygep3$i$i$i$i$i16 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep3$i$i$i$i$i5$i = 0, $unionBounds$i = 0, $unionPoints$i = 0, $viewMatrix$i = 0, $worldToLocalMatrixNoScale$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3280|0;
 $$byval_copy31 = sp + 3264|0;
 $0 = sp + 3200|0;
 $projMatrix$i85 = sp + 3136|0;
 $s$i = sp + 3072|0;
 $1 = sp + 3056|0;
 $worldToLocalMatrixNoScale$i = sp + 2992|0;
 $texMatrix$i86 = sp + 2928|0;
 $temp$i = sp + 2864|0;
 $2 = sp + 2848|0;
 $localFrustumTransform$i = sp + 2784|0;
 $cameraProjection$i = sp + 2720|0;
 $cameraFrustum$i = sp + 2624|0;
 $frustumSplit$i = sp + 2528|0;
 $focusPoints$i = sp + 2516|0;
 $lightDir$i = sp + 2504|0;
 $3 = sp + 2492|0;
 $axisX$i = sp + 2480|0;
 $4 = sp + 2468|0;
 $axisY$i = sp + 2456|0;
 $5 = sp + 2444|0;
 $axisZ$i = sp + 2432|0;
 $6 = sp + 2420|0;
 $pos$i = sp + 2408|0;
 $unionBounds$i = sp + 2384|0;
 $unionPoints$i = sp + 2288|0;
 $sphereCenter$i = sp + 2276|0;
 $radius$i = sp + 2272|0;
 $7 = sp + 2208|0;
 $texMatrix$i = sp + 2144|0;
 $viewMatrix$i = sp + 2080|0;
 $projMatrix$i = sp + 2016|0;
 $tr$i = sp + 112|0;
 $8 = sp + 96|0;
 $9 = sp + 80|0;
 $10 = sp + 72|0;
 $11 = sp + 68|0;
 $passIndex$i$i = sp + 64|0;
 $part$i$i = sp + 48|0;
 $data$i$i = sp + 24|0;
 $12 = sp + 16|0;
 $13 = sp + 12|0;
 $14 = sp + 8|0;
 $15 = sp + 4|0;
 $16 = sp;
 $17 = sp + 20|0;
 $casterBounds = sp + 176|0;
 $casters = sp + 200|0;
 $casterParts = sp + 212|0;
 $lightPos = sp + 224|0;
 $lightRot = sp + 240|0;
 $lightDir = sp + 256|0;
 $18 = sp + 272|0;
 $shadowWorldToClip = sp + 288|0;
 $planes = sp + 352|0;
 $19 = sp + 448|0;
 $cascades = sp + 464|0;
 $20 = sp + 1888|0;
 $texMatrix = sp + 1904|0;
 $21 = sp + 1968|0;
 $22 = sp + 1984|0;
 $23 = sp + 2000|0;
 $24 = HEAP32[$activeLight>>2]|0;
 $25 = Math_fround(HEAPF32[$receiverBounds>>2]);
 $26 = Math_fround(HEAPF32[616664>>2]);
 $27 = $25 == $26;
 if ($27) {
  $28 = (($receiverBounds) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
  $31 = $29 == $30;
  if ($31) {
   $32 = (($receiverBounds) + 8|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
   $35 = $33 == $34;
   if ($35) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $36 = Math_fround(-$26);
 $37 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $38 = Math_fround(-$37);
 $39 = (($receiverBounds) + 12|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = $40 == $36;
 if ($41) {
  $42 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
  $43 = Math_fround(-$42);
  $44 = (($receiverBounds) + 16|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = $45 == $43;
  if ($46) {
   $47 = (($receiverBounds) + 20|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $phitmp2$i = $48 != $38;
   if (!($phitmp2$i)) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $49 = (($24) + 216|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(1);
 if ($51) {
  $52 = HEAP32[$cameraData>>2]|0;
  $53 = (($52) + 616|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = ($54<<24>>24)==(0);
  $56 = (__ZNK5Light24GetFinalShadowResolutionEv($24)|0);
  $57 = (3 - ($56))|0;
  $58 = (($cameraData) + 720|0);
  HEAP32[$58>>2] = $57;
  if ($55) {
   $59 = HEAP8[((640792 + 250|0))>>0]|0;
   $60 = ($59<<24>>24)==(0);
   if ($60) {
    $61 = (($cameraData) + 612|0);
    HEAP32[$61>>2] = 1;
    $79 = 1;
   } else {
    $62 = (__Z18GetQualitySettingsv()|0);
    $63 = (($62) + 40|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($62) + 24|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ((($66) + (($64*96)|0)|0) + 28|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($cameraData) + 612|0);
    HEAP32[$69>>2] = $68;
    $79 = $68;
   }
   $70 = HEAP32[$cameraData>>2]|0;
   $71 = (($70) + 456|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = (($cameraData) + 580|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = (($cameraData) + 612|0);
   $76 = (($cameraData) + 616|0);
   $77 = (($cameraData) + 636|0);
   HEAPF32[$76>>2] = $72;
   $78 = ((($cameraData) + ($79<<2)|0) + 616|0);
   HEAPF32[$78>>2] = $74;
   HEAPF32[$77>>2] = Math_fround(0.0);
   $80 = ((($cameraData) + ($79<<2)|0) + 636|0);
   HEAPF32[$80>>2] = Math_fround(1.0);
   if ((($79|0) == 4)) {
    $89 = (__Z18GetQualitySettingsv()|0);
    $90 = (($89) + 40|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($89) + 24|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ((($93) + (($91*96)|0)|0) + 44|0);
    $95 = Math_fround(HEAPF32[$94>>2]);
    $96 = (($cameraData) + 640|0);
    HEAPF32[$96>>2] = $95;
    $97 = (($94) + 4|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = (($cameraData) + 644|0);
    HEAPF32[$99>>2] = $98;
    $100 = (($94) + 8|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = (($cameraData) + 648|0);
    HEAPF32[$102>>2] = $101;
    label = 16;
   } else if ((($79|0) == 2)) {
    $81 = (__Z18GetQualitySettingsv()|0);
    $82 = (($81) + 40|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($81) + 24|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ((($85) + (($83*96)|0)|0) + 40|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = (($cameraData) + 640|0);
    HEAPF32[$88>>2] = $87;
    label = 16;
   } else {
    $103 = ($79|0)>(1);
    if ($103) {
     label = 16;
    }
   }
   if ((label|0) == 16) {
    $104 = Math_fround($74 - $72);
    $i$01$i$i = 1;
    while(1) {
     $105 = ((($cameraData) + ($i$01$i$i<<2)|0) + 636|0);
     $106 = Math_fround(HEAPF32[$105>>2]);
     $107 = Math_fround($104 * $106);
     $108 = Math_fround($72 + $107);
     $109 = ((($cameraData) + ($i$01$i$i<<2)|0) + 616|0);
     HEAPF32[$109>>2] = $108;
     $110 = (($i$01$i$i) + 1)|0;
     $exitcond$i$i = ($110|0)==($79|0);
     if ($exitcond$i$i) {
      break;
     } else {
      $i$01$i$i = $110;
     }
    }
   }
   $111 = HEAP32[$75>>2]|0;
   $i$03$i = (($111) + 1)|0;
   $112 = ($i$03$i|0)<(5);
   if ($112) {
    $$phi$trans$insert$i = ((($cameraData) + ($111<<2)|0) + 616|0);
    $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
    $114 = $$pre$i;$i$0$in4$i = $111;$i$05$i = $i$03$i;
    while(1) {
     $113 = Math_fround($114 * Math_fround(1.10000002384185791016));
     $115 = ((($cameraData) + ($i$05$i<<2)|0) + 616|0);
     HEAPF32[$115>>2] = $113;
     $116 = ((($cameraData) + ($i$0$in4$i<<2)|0) + 636|0);
     $117 = Math_fround(HEAPF32[$116>>2]);
     $118 = Math_fround($117 * Math_fround(1.10000002384185791016));
     $119 = ((($cameraData) + ($i$05$i<<2)|0) + 636|0);
     HEAPF32[$119>>2] = $118;
     $i$0$i = (($i$05$i) + 1)|0;
     $exitcond$i = ($i$0$i|0)==(5);
     if ($exitcond$i) {
      break;
     } else {
      $i$0$in4$i$phi = $i$05$i;$114 = $113;$i$05$i = $i$0$i;$i$0$in4$i = $i$0$in4$i$phi;
     }
    }
    $$pre9$pre$i = HEAP32[$75>>2]|0;
    $150 = $$pre9$pre$i;
   } else {
    $150 = $111;
   }
  } else {
   $$pre$phi$iZ2D = $cameraData;
   label = 22;
  }
 } else {
  $120 = (__ZNK5Light24GetFinalShadowResolutionEv($24)|0);
  $121 = (3 - ($120))|0;
  $122 = (($cameraData) + 720|0);
  HEAP32[$122>>2] = $121;
  $$pre$phi$iZ2D = $cameraData;
  label = 22;
 }
 if ((label|0) == 22) {
  $123 = HEAP32[$$pre$phi$iZ2D>>2]|0;
  $124 = (($123) + 456|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = (($cameraData) + 616|0);
  HEAPF32[$126>>2] = $125;
  $127 = (($cameraData) + 580|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = (($cameraData) + 620|0);
  HEAPF32[$129>>2] = $128;
  $130 = (($cameraData) + 636|0);
  HEAPF32[$130>>2] = Math_fround(0.0);
  $131 = (($cameraData) + 640|0);
  HEAPF32[$131>>2] = Math_fround(1.0);
  $132 = (($cameraData) + 612|0);
  HEAP32[$132>>2] = 1;
  $150 = 1;
 }
 $133 = (($cameraData) + 656|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = (($cameraData) + 660|0);
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = (($cameraData) + 664|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 $136 = (($cameraData) + 668|0);
 HEAPF32[$136>>2] = Math_fround(-inf);
 $137 = (($cameraData) + 672|0);
 HEAPF32[$137>>2] = Math_fround(0.0);
 $138 = (($cameraData) + 676|0);
 HEAPF32[$138>>2] = Math_fround(0.0);
 $139 = (($cameraData) + 680|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($cameraData) + 684|0);
 HEAPF32[$140>>2] = Math_fround(-inf);
 $141 = (($cameraData) + 688|0);
 HEAPF32[$141>>2] = Math_fround(0.0);
 $142 = (($cameraData) + 692|0);
 HEAPF32[$142>>2] = Math_fround(0.0);
 $143 = (($cameraData) + 696|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = (($cameraData) + 700|0);
 HEAPF32[$144>>2] = Math_fround(-inf);
 $145 = (($cameraData) + 704|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = (($cameraData) + 708|0);
 HEAPF32[$146>>2] = Math_fround(0.0);
 $147 = (($cameraData) + 712|0);
 HEAPF32[$147>>2] = Math_fround(0.0);
 $148 = (($cameraData) + 716|0);
 HEAPF32[$148>>2] = Math_fround(-inf);
 $149 = ($150|0)<(4);
 if ($149) {
  $scevgep$i = (($outShadowMatrices) + ($150<<6)|0);
  $151 = $150 << 6;
  $152 = (256 - ($151))|0;
  _memset(($scevgep$i|0),0,($152|0))|0;
 }
 $153 = (__Z12GetGfxDevicev()|0);
 $154 = HEAP32[$activeLight>>2]|0;
 $155 = Math_fround(HEAPF32[((640792 + 80|0))>>2]);
 $156 = $155 >= Math_fround(480.0);
 $157 = (($154) + 216|0);
 $158 = HEAP32[$157>>2]|0;
 if ((($158|0) == 1)) {
  $228 = $156 ? 4096 : 2048;
  $229 = HEAP32[((640792 + 116|0))>>2]|0;
  $230 = ($228|0)<($229|0);
  $231 = $230 ? $228 : $229;
  $232 = (($cameraData) + 220|0);
  $233 = (($cameraData) + 224|0);
  $234 = Math_fround(HEAPF32[$232>>2]);
  $235 = Math_fround(HEAPF32[$233>>2]);
  $236 = $234 < $235;
  $237 = $236 ? $235 : $234;
  $238 = (~~(($237)));
  $239 = (Math_fround(($238|0)));
  $240 = Math_fround($239 * Math_fround(3.79999995231628417969));
  $241 = (~~(($240)));
  $242 = (($241) + -1)|0;
  $243 = $242 >>> 16;
  $244 = $243 | $242;
  $245 = $244 >>> 8;
  $246 = $245 | $244;
  $247 = $246 >>> 4;
  $248 = $247 | $246;
  $249 = $248 >>> 2;
  $250 = $249 | $248;
  $251 = $250 >>> 1;
  $252 = $251 | $250;
  $253 = (($252) + 1)|0;
  $254 = (($cameraData) + 720|0);
  $255 = HEAP32[$254>>2]|0;
  $256 = $253 >> $255;
  $257 = ($256|0)<(32);
  if ($257) {
   $278 = 32;
  } else {
   $258 = ($256|0)>($231|0);
   $$$i$i = $258 ? $231 : $256;
   $278 = $$$i$i;
  }
 } else if ((($158|0) == 0)) {
  $193 = $156 ? 2048 : 1024;
  $194 = HEAP32[((640792 + 116|0))>>2]|0;
  $195 = ($193|0)<($194|0);
  $196 = $195 ? $193 : $194;
  $197 = (($activeLight) + 56|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = (($cameraData) + 220|0);
  $200 = Math_fround(HEAPF32[$199>>2]);
  $201 = Math_fround($198 * $200);
  $202 = (($activeLight) + 60|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = (($cameraData) + 224|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = Math_fround($203 * $205);
  $207 = $201 < $206;
  $208 = $207 ? $206 : $201;
  $209 = Math_fround($208 * Math_fround(2.0));
  $210 = (~~(($209)));
  $211 = (($210) + -1)|0;
  $212 = $211 >>> 16;
  $213 = $212 | $211;
  $214 = $213 >>> 8;
  $215 = $214 | $213;
  $216 = $215 >>> 4;
  $217 = $216 | $215;
  $218 = $217 >>> 2;
  $219 = $218 | $217;
  $220 = $219 >>> 1;
  $221 = $220 | $219;
  $222 = (($221) + 1)|0;
  $223 = (($cameraData) + 720|0);
  $224 = HEAP32[$223>>2]|0;
  $225 = $222 >> $224;
  $226 = ($225|0)<(16);
  if ($226) {
   $278 = 16;
  } else {
   $227 = ($225|0)>($196|0);
   $$$i1$i = $227 ? $196 : $225;
   $278 = $$$i1$i;
  }
 } else if ((($158|0) == 2)) {
  $159 = $156 ? 1024 : 512;
  $160 = HEAP32[((640792 + 112|0))>>2]|0;
  $161 = ($159|0)<($160|0);
  $162 = $161 ? $159 : $160;
  $163 = (($activeLight) + 56|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = (($cameraData) + 220|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = Math_fround($164 * $166);
  $168 = (($activeLight) + 60|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = (($cameraData) + 224|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = Math_fround($169 * $171);
  $173 = $167 < $172;
  $174 = $173 ? $172 : $167;
  $175 = (~~(($174)));
  $176 = (($175) + -1)|0;
  $177 = $176 >>> 16;
  $178 = $177 | $176;
  $179 = $178 >>> 8;
  $180 = $179 | $178;
  $181 = $180 >>> 4;
  $182 = $181 | $180;
  $183 = $182 >>> 2;
  $184 = $183 | $182;
  $185 = $184 >>> 1;
  $186 = $185 | $184;
  $187 = (($186) + 1)|0;
  $188 = (($cameraData) + 720|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = $187 >> $189;
  $191 = ($190|0)<(16);
  if ($191) {
   $278 = 16;
  } else {
   $192 = ($190|0)>($162|0);
   $$$i4$i = $192 ? $162 : $190;
   $278 = $$$i4$i;
  }
 } else {
  $278 = 128;
 }
 $259 = HEAP32[$49>>2]|0;
 $260 = ($259|0)==(2);
 do {
  if ($260) {
   $261 = HEAP8[((640792 + 242|0))>>0]|0;
   $262 = ($261<<24>>24)==(0);
   if ($262) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $263 = HEAP8[((640792 + 223|0))>>0]|0;
   $264 = ($263<<24>>24)==(0);
   if ($264) {
    $267 = HEAP8[((640792 + 215|0))>>0]|0;
    $268 = ($267<<24>>24)==(0);
    if (!($268)) {
     $shadowCubeMap$0$off0 = 1;$shadowFormat$1 = 14;$shadowHeight$1 = $278;
     break;
    }
    $269 = HEAP8[((640792 + 213|0))>>0]|0;
    $270 = ($269<<24>>24)==(0);
    if (!($270)) {
     $shadowCubeMap$0$off0 = 1;$shadowFormat$1 = 12;$shadowHeight$1 = $278;
     break;
    }
    $271 = HEAP8[((640792 + 216|0))>>0]|0;
    $272 = ($271<<24>>24)==(0);
    $$7 = $272 ? 22 : 15;
    $shadowFormat$0 = $$7;
   } else {
    $265 = HEAP8[((640792 + 201|0))>>0]|0;
    $266 = ($265<<24>>24)==(0);
    $$ = $266 ? 22 : 0;
    $shadowFormat$0 = $$;
   }
   $273 = ($shadowFormat$0|0)==(22);
   if ($273) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   } else {
    $shadowCubeMap$0$off0 = 1;$shadowFormat$1 = $shadowFormat$0;$shadowHeight$1 = $278;
   }
  } else {
   $274 = (($cameraData) + 612|0);
   $275 = HEAP32[$274>>2]|0;
   $276 = ($275|0)==(2);
   if ($276) {
    $277 = (($278|0) / 2)&-1;
    $shadowHeight$0 = $277;
   } else {
    $shadowHeight$0 = $278;
   }
   $279 = HEAP8[((640792 + 249|0))>>0]|0;
   $280 = ($279<<24>>24)!=(0);
   $281 = $280 ? 3 : 1;
   $shadowCubeMap$0$off0 = 0;$shadowFormat$1 = $281;$shadowHeight$1 = $shadowHeight$0;
  }
 } while(0);
 $282 = Math_fround($155 * Math_fround(1024.0));
 $283 = (~~(($282)));
 $284 = (($153) + 5448|0);
 $285 = HEAP32[$284>>2]|0;
 $286 = ($285|0)<(0);
 $287 = $286 << 31 >> 31;
 $288 = (($153) + 5456|0);
 $289 = $288;
 $290 = $289;
 $291 = HEAP32[$290>>2]|0;
 $292 = (($289) + 4)|0;
 $293 = $292;
 $294 = HEAP32[$293>>2]|0;
 $295 = (_i64Add(($285|0),($287|0),($291|0),($294|0))|0);
 $296 = tempRet0;
 $297 = (___divdi3(($295|0),($296|0),1024,0)|0);
 $298 = tempRet0;
 $299 = (($283) - ($297))|0;
 $300 = (Math_fround(($299|0)));
 $301 = Math_fround($300 * Math_fround(0.300000011920928955078));
 $302 = (~~(($301)));
 $303 = $shadowCubeMap$0$off0 ? 4 : 2;
 $shadowHeight$2 = $shadowHeight$1;$shadowWidth$0 = $278;
 while(1) {
  $304 = (__Z25EstimateRenderTextureSizeiii19RenderTextureFormat17DepthBufferFormat16TextureDimensionb($shadowWidth$0,$shadowHeight$2,1,$shadowFormat$1,1,$303,0)|0);
  $305 = (($304|0) / 1024)&-1;
  $306 = ($305|0)<($302|0);
  if ($306) {
   $shadowHeight$3 = $shadowHeight$2;$shadowWidth$1 = $shadowWidth$0;
   break;
  }
  $307 = (($shadowWidth$0|0) / 2)&-1;
  $308 = (($shadowHeight$2|0) / 2)&-1;
  $309 = ($shadowWidth$0|0)>(9);
  $310 = ($shadowHeight$2|0)>(9);
  $or$cond = $309 & $310;
  if ($or$cond) {
   $shadowHeight$2 = $308;$shadowWidth$0 = $307;
  } else {
   $shadowHeight$3 = $308;$shadowWidth$1 = $307;
   break;
  }
 }
 $311 = ($shadowWidth$1|0)<(5);
 $312 = ($shadowHeight$3|0)<(5);
 $or$cond8 = $311 | $312;
 if ($or$cond8) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $$9 = $shadowCubeMap$0$off0&1;
 $313 = (__Z22GetRenderBufferManagerv()|0);
 $314 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($313,$shadowWidth$1,$shadowHeight$3,1,$shadowFormat$1,$$9,1,1)|0);
 $315 = ($314|0)==(0|0);
 if (!($315)) {
  $316 = HEAP32[$314>>2]|0;
  $317 = (($316) + 36|0);
  $318 = HEAP32[$317>>2]|0;
  FUNCTION_TABLE_vii[$318 & 4095]($314,576200);
 }
 $319 = ($shadowFormat$1|0)==(3);
 $320 = HEAP8[((640792 + 250|0))>>0]|0;
 $321 = ($320<<24>>24)==(0);
 if ($321) {
  $322 = (($24) + 116|0);
  $323 = HEAP32[$322>>2]|0;
  $not$ = ($323|0)>(1);
  $$10 = $319 & $not$;
  $enablePCFFilter$0$off0 = $$10;
 } else {
  $enablePCFFilter$0$off0 = $319;
 }
 $324 = HEAP8[((640792 + 277|0))>>0]|0;
 $325 = ($324<<24>>24)==(0);
 $enablePCFFilter$0$off0$ = $325 & $enablePCFFilter$0$off0;
 $326 = $enablePCFFilter$0$off0$&1;
 $327 = (($314) + 28|0);
 HEAP32[$327>>2] = $326;
 $328 = HEAP32[$314>>2]|0;
 $329 = (($328) + 132|0);
 $330 = HEAP32[$329>>2]|0;
 FUNCTION_TABLE_vi[$330 & 4095]($314);
 $331 = (($314) + 140|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = ($332|0)==(0|0);
 if ($333) {
  $334 = (($314) + 148|0);
  $335 = HEAP32[$334>>2]|0;
  $336 = ($335|0)==(0|0);
  if ($336) {
   $337 = (__ZN13RenderTexture6CreateEv($314)|0);
   if (!($337)) {
    $338 = (__Z22GetRenderBufferManagerv()|0);
    __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($338,$314);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $339 = (($casterBounds) + 12|0);
 $340 = (($casterBounds) + 16|0);
 $341 = (($casterBounds) + 20|0);
 ;HEAP32[$casterBounds+0>>2]=0|0;HEAP32[$casterBounds+4>>2]=0|0;HEAP32[$casterBounds+8>>2]=0|0;HEAP32[$casterBounds+12>>2]=0|0;HEAP32[$casterBounds+16>>2]=0|0;
 ;HEAP32[$casterBounds+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$casterBounds+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$casterBounds+8>>2]=HEAP32[616664+8>>2]|0;
 $342 = Math_fround(HEAPF32[616664>>2]);
 $343 = Math_fround(-$342);
 $344 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $345 = Math_fround(-$344);
 $346 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $347 = Math_fround(-$346);
 HEAPF32[$339>>2] = $343;
 HEAPF32[$340>>2] = $345;
 HEAPF32[$341>>2] = $347;
 HEAP32[$casters>>2] = 0;
 $348 = (($casters) + 4|0);
 HEAP32[$348>>2] = 0;
 $349 = (($casters) + 8|0);
 HEAP32[$349>>2] = 0;
 HEAP32[$casterParts>>2] = 0;
 $350 = (($casterParts) + 4|0);
 HEAP32[$350>>2] = 0;
 $351 = (($casterParts) + 8|0);
 HEAP32[$351>>2] = 0;
 HEAP32[$14>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$14+0>>2]|0;
 $352 = (invoke_iiiiiii(102,1536,16,($$byval_copy31|0),0,(576840|0),79)|0);
 $353 = __THREW__; __THREW__ = 0;
 $354 = $353&1;
 L82: do {
  if ($354) {
   label = 122;
  } else {
   $$pre$i28 = HEAP32[$casters>>2]|0;
   $$pre1$i = HEAP32[$348>>2]|0;
   $355 = (($352) + 1536|0);
   $356 = $$pre1$i;
   $357 = $$pre$i28;
   $358 = (($356) - ($357))|0;
   $359 = (($358|0) / -24)&-1;
   $360 = (($352) + (($359*24)|0)|0);
   _memcpy(($360|0),($$pre$i28|0),($358|0))|0;
   $361 = HEAP32[$casters>>2]|0;
   HEAP32[$casters>>2] = $360;
   HEAP32[$348>>2] = $352;
   HEAP32[$349>>2] = $355;
   $362 = ($361|0)==(0|0);
   if (!($362)) {
    HEAP32[$15>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$15+0>>2]|0;
    invoke_vii(2591,($361|0),($$byval_copy31|0));
    $363 = __THREW__; __THREW__ = 0;
    $364 = $363&1;
    if ($364) {
     $365 = ___cxa_find_matching_catch()|0;
     $366 = tempRet0;
     ___cxa_call_unexpected(($365|0));
     // unreachable;
    }
   }
   $367 = HEAP32[$351>>2]|0;
   $368 = HEAP32[$casterParts>>2]|0;
   $369 = $367;
   $370 = $368;
   $371 = (($369) - ($370))|0;
   $372 = $371 >> 4;
   $373 = ($372>>>0)<(64);
   if ($373) {
    $374 = HEAP32[$350>>2]|0;
    $375 = $374;
    $376 = (($375) - ($370))|0;
    $377 = $376 >> 4;
    HEAP32[$12>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$12+0>>2]|0;
    $378 = (invoke_iiiiiii(102,1024,16,($$byval_copy31|0),0,(576840|0),79)|0);
    $379 = __THREW__; __THREW__ = 0;
    $380 = $379&1;
    if ($380) {
     label = 122;
     break;
    }
    $$pre$i29 = HEAP32[$casterParts>>2]|0;
    $$pre1$i30 = HEAP32[$350>>2]|0;
    $381 = (($378) + ($377<<4)|0);
    $382 = (($378) + 1024|0);
    $383 = $$pre1$i30;
    $384 = $$pre$i29;
    $385 = (($383) - ($384))|0;
    $386 = $385 >> 4;
    $$sum$i31 = (($377) - ($386))|0;
    $387 = (($378) + ($$sum$i31<<4)|0);
    _memcpy(($387|0),($$pre$i29|0),($385|0))|0;
    $388 = HEAP32[$casterParts>>2]|0;
    HEAP32[$casterParts>>2] = $387;
    HEAP32[$350>>2] = $381;
    HEAP32[$351>>2] = $382;
    $389 = ($388|0)==(0|0);
    if (!($389)) {
     HEAP32[$13>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$13+0>>2]|0;
     invoke_vii(2591,($388|0),($$byval_copy31|0));
     $390 = __THREW__; __THREW__ = 0;
     $391 = $390&1;
     if ($391) {
      $392 = ___cxa_find_matching_catch()|0;
      $393 = tempRet0;
      ___cxa_call_unexpected(($392|0));
      // unreachable;
     }
    }
   }
   $394 = (($activeLight) + 4|0);
   $395 = HEAP32[$394>>2]|0;
   $396 = (($395) + 72|0);
   $397 = HEAP32[$396>>2]|0;
   $398 = ($397|0)==(0|0);
   if ($398) {
    $405 = $395;
   } else {
    __THREW__ = 0;
    invoke_vi(3402,($396|0));
    $399 = __THREW__; __THREW__ = 0;
    $400 = $399&1;
    if ($400) {
     label = 122;
     break;
    }
    $$pre = HEAP32[$394>>2]|0;
    $405 = $$pre;
   }
   __THREW__ = 0;
   $401 = (invoke_i(78)|0);
   $402 = __THREW__; __THREW__ = 0;
   $403 = $402&1;
   if ($403) {
    label = 122;
   } else {
    $404 = (($405) + 4|0);
    $406 = (($cameraData) + 600|0);
    $407 = HEAP32[$406>>2]|0;
    $408 = (($407) + 608|0);
    $i$01$i = 0;
    while(1) {
     $409 = ((($401) + ($i$01$i<<2)|0) + 896|0);
     $410 = HEAP32[$409>>2]|0;
     $411 = ($410|0)==(0|0);
     if (!($411)) {
      __THREW__ = 0;
      invoke_vii($410|0,($404|0),($408|0));
      $412 = __THREW__; __THREW__ = 0;
      $413 = $412&1;
      if ($413) {
       label = 121;
       break;
      }
     }
     $414 = (($i$01$i) + 1)|0;
     $exitcond$i34 = ($414|0)==(16);
     if ($exitcond$i34) {
      break;
     } else {
      $i$01$i = $414;
     }
    }
    if ((label|0) == 121) {
     $637 = ___cxa_find_matching_catch()|0;
     $638 = tempRet0;
     $lpad$phi176$index = $637;$lpad$phi176$index4 = $638;
     label = 123;
     break;
    }
    $$idx$val = HEAP32[$49>>2]|0;
    $415 = ($$idx$val|0)==(1);
    $416 = HEAP32[$406>>2]|0;
    $417 = (($cameraData) + 364|0);
    $418 = (($cameraData) + 604|0);
    $419 = (($cameraData) + 608|0);
    $420 = (($part$i$i) + 8|0);
    $421 = (($part$i$i) + 4|0);
    $422 = (($part$i$i) + 12|0);
    $423 = (($data$i$i) + 4|0);
    $424 = (($data$i$i) + 16|0);
    $425 = (($data$i$i) + 8|0);
    $426 = (($data$i$i) + 12|0);
    $427 = (($data$i$i) + 20|0);
    $428 = (($casterBounds) + 4|0);
    $429 = (($casterBounds) + 8|0);
    $t$02$i = 0;
    L107: while(1) {
     $430 = ((($405) + (($t$02$i*12)|0)|0) + 8|0);
     $431 = HEAP32[$430>>2]|0;
     $432 = ($431|0)>(0);
     if ($432) {
      $433 = ((($405) + (($t$02$i*12)|0)|0) + 4|0);
      $434 = ((($416) + (($t$02$i*12)|0)|0) + 608|0);
      $435 = ((($416) + (($t$02$i*12)|0)|0) + 612|0);
      $i$01$i37 = 0;
      while(1) {
       $436 = HEAP32[$433>>2]|0;
       $437 = (($436) + ($i$01$i37<<2)|0);
       $438 = HEAP32[$437>>2]|0;
       if ($415) {
        $439 = HEAP32[$434>>2]|0;
        $440 = (($439) + (($438*24)|0)|0);
        __THREW__ = 0;
        $441 = (invoke_iii(2379,($440|0),($417|0))|0);
        $442 = __THREW__; __THREW__ = 0;
        $443 = $442&1;
        if ($443) {
         label = 120;
         break L107;
        } else {
         $casterTouchesView$0$off0$i = $441;
        }
       } else {
        $casterTouchesView$0$off0$i = 0;
       }
       $444 = HEAP32[$435>>2]|0;
       $445 = (($444) + (($438*24)|0)|0);
       $446 = HEAP32[$434>>2]|0;
       $447 = (($446) + (($438*24)|0)|0);
       $448 = HEAP32[$445>>2]|0;
       $449 = HEAP32[$350>>2]|0;
       $450 = HEAP32[$casterParts>>2]|0;
       $451 = $449;
       $452 = $450;
       $453 = (($451) - ($452))|0;
       $454 = $453 >> 4;
       $455 = HEAP32[$448>>2]|0;
       $456 = (($455) + 40|0);
       $457 = HEAP32[$456>>2]|0;
       __THREW__ = 0;
       $458 = (invoke_ii($457|0,($448|0))|0);
       $459 = __THREW__; __THREW__ = 0;
       $460 = $459&1;
       if ($460) {
        label = 120;
        break L107;
       }
       $461 = HEAP32[$418>>2]|0;
       $462 = HEAP32[$419>>2]|0;
       $463 = ($458|0)>(0);
       if ($463) {
        $464 = ($461|0)!=(0|0);
        $i$02$i$i = 0;
        while(1) {
         $465 = HEAP32[$448>>2]|0;
         $466 = (($465) + 44|0);
         $467 = HEAP32[$466>>2]|0;
         __THREW__ = 0;
         invoke_viii($467|0,($11|0),($448|0),($i$02$i$i|0));
         $468 = __THREW__; __THREW__ = 0;
         $469 = $468&1;
         if ($469) {
          label = 119;
          break L107;
         }
         $470 = HEAP32[$11>>2]|0;
         $471 = ($470|0)==(0);
         do {
          if (!($471)) {
           HEAP32[$10>>2] = $470;
           $472 = HEAP32[560624>>2]|0;
           $473 = ($472|0)==(0|0);
           do {
            if ($473) {
             label = 91;
            } else {
             $474 = (($472) + 36|0);
             $475 = HEAP32[$474>>2]|0;
             $476 = (($472) + 4|0);
             $477 = HEAP32[$476>>2]|0;
             $478 = ($475|0)==($477|0);
             do {
              if ($478) {
               $479 = (($472) + 28|0);
               $480 = HEAP32[$479>>2]|0;
               $481 = (($472) + 32|0);
               $482 = HEAP32[$481>>2]|0;
               $483 = (($480) + ($482<<3)|0);
               $499 = $483;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy31,$472,$10);
               $484 = HEAP32[$$byval_copy31>>2]|0;
               $485 = ($484|0)==(-1);
               $486 = (($472) + 28|0);
               $487 = HEAP32[$486>>2]|0;
               if ($485) {
                $488 = (($472) + 32|0);
                $489 = HEAP32[$488>>2]|0;
                $490 = (($487) + ($489<<3)|0);
                $499 = $490;
                break;
               } else {
                $491 = (($487) + ($484<<3)|0);
                $499 = $491;
                break;
               }
              }
             } while(0);
             $492 = HEAP32[560624>>2]|0;
             $493 = (($492) + 28|0);
             $494 = HEAP32[$493>>2]|0;
             $495 = (($492) + 32|0);
             $496 = HEAP32[$495>>2]|0;
             $497 = (($494) + ($496<<3)|0);
             $498 = ($499|0)==($497|0);
             if ($498) {
              label = 91;
              break;
             }
             $500 = (($499) + 4|0);
             $501 = HEAP32[$500>>2]|0;
             $502 = ($501|0)==(0|0);
             if ($502) {
              label = 91;
             } else {
              $$in$i$i = $501;
             }
            }
           } while(0);
           if ((label|0) == 91) {
            label = 0;
            $503 = HEAP32[$11>>2]|0;
            __THREW__ = 0;
            $504 = (invoke_ii(3215,($503|0))|0);
            $505 = __THREW__; __THREW__ = 0;
            $506 = $505&1;
            if ($506) {
             label = 119;
             break L107;
            }
            $507 = ($504|0)==(0|0);
            if ($507) {
             break;
            } else {
             $$in$i$i = $504;
            }
           }
           __THREW__ = 0;
           $508 = (invoke_ii(3221,($$in$i$i|0))|0);
           $509 = __THREW__; __THREW__ = 0;
           $510 = $509&1;
           if ($510) {
            label = 119;
            break L107;
           }
           $511 = $464 ? $461 : $508;
           __THREW__ = 0;
           $512 = (invoke_iiii(1535,($508|0),($461|0),($462|0))|0);
           $513 = __THREW__; __THREW__ = 0;
           $514 = $513&1;
           if ($514) {
            label = 119;
            break L107;
           }
           $515 = ($512|0)<(0);
           if ($515) {
            break;
           }
           __THREW__ = 0;
           $516 = (invoke_iiii(1537,($511|0),($512|0),($passIndex$i$i|0))|0);
           $517 = __THREW__; __THREW__ = 0;
           $518 = $517&1;
           if ($518) {
            label = 119;
            break L107;
           }
           $519 = ($516|0)==(0|0);
           if ($519) {
            break;
           }
           $520 = HEAP32[$448>>2]|0;
           $521 = (($520) + 48|0);
           $522 = HEAP32[$521>>2]|0;
           __THREW__ = 0;
           $523 = (invoke_iii($522|0,($448|0),($i$02$i$i|0))|0);
           $524 = __THREW__; __THREW__ = 0;
           $525 = $524&1;
           if ($525) {
            label = 119;
            break L107;
           }
           HEAP32[$part$i$i>>2] = $523;
           HEAP32[$420>>2] = $511;
           HEAP32[$421>>2] = $512;
           HEAP32[$422>>2] = $$in$i$i;
           $526 = HEAP32[$350>>2]|0;
           $527 = HEAP32[$351>>2]|0;
           $528 = ($526|0)==($527|0);
           if ($528) {
            __THREW__ = 0;
            invoke_vii(2643,($casterParts|0),($part$i$i|0));
            $532 = __THREW__; __THREW__ = 0;
            $533 = $532&1;
            if ($533) {
             label = 119;
             break L107;
            } else {
             break;
            }
           }
           $529 = ($526|0)==(0|0);
           if ($529) {
            $531 = 0;
           } else {
            ;HEAP32[$526+0>>2]=HEAP32[$part$i$i+0>>2]|0;HEAP32[$526+4>>2]=HEAP32[$part$i$i+4>>2]|0;HEAP32[$526+8>>2]=HEAP32[$part$i$i+8>>2]|0;HEAP32[$526+12>>2]=HEAP32[$part$i$i+12>>2]|0;
            $531 = $526;
           }
           $530 = (($531) + 16|0);
           HEAP32[$350>>2] = $530;
          }
         } while(0);
         $534 = (($i$02$i$i) + 1)|0;
         $exitcond$i$i39 = ($534|0)==($458|0);
         if ($exitcond$i$i39) {
          break;
         } else {
          $i$02$i$i = $534;
         }
        }
       }
       $535 = HEAP32[$350>>2]|0;
       $536 = HEAP32[$casterParts>>2]|0;
       $537 = $535;
       $538 = $536;
       $539 = (($537) - ($538))|0;
       $540 = $539 >> 4;
       $541 = ($540|0)==($454|0);
       do {
        if (!($541)) {
         HEAP32[$data$i$i>>2] = $445;
         HEAP32[$423>>2] = $447;
         HEAP32[$424>>2] = 1;
         HEAP32[$425>>2] = $454;
         HEAP32[$426>>2] = $540;
         $542 = ((($444) + (($438*24)|0)|0) + 12|0);
         $543 = HEAP16[$542>>1]|0;
         $544 = $543&65535;
         $545 = HEAP32[$406>>2]|0;
         $546 = (($545) + 668|0);
         $547 = HEAP32[$546>>2]|0;
         $548 = ((($444) + (($438*24)|0)|0) + 14|0);
         $549 = HEAP16[$548>>1]|0;
         $550 = $549&65535;
         $551 = ((($444) + (($438*24)|0)|0) + 16|0);
         $552 = HEAP32[$551>>2]|0;
         $553 = (($547) + (($544*12)|0)|0);
         $554 = HEAP32[$553>>2]|0;
         $555 = ((($547) + (($544*12)|0)|0) + 4|0);
         $556 = HEAP32[$555>>2]|0;
         __THREW__ = 0;
         $557 = (Math_fround(+(invoke_fiiii(1,($550|0),($552|0),($554|0),($556|0)))));
         $558 = __THREW__; __THREW__ = 0;
         $559 = $558&1;
         if ($559) {
          label = 120;
          break L107;
         }
         HEAPF32[$427>>2] = $557;
         $560 = HEAP32[$348>>2]|0;
         $561 = HEAP32[$349>>2]|0;
         $562 = ($560|0)==($561|0);
         if ($562) {
          __THREW__ = 0;
          invoke_vii(2644,($casters|0),($data$i$i|0));
          $566 = __THREW__; __THREW__ = 0;
          $567 = $566&1;
          if ($567) {
           label = 120;
           break L107;
          }
         } else {
          $563 = ($560|0)==(0|0);
          if ($563) {
           $565 = 0;
          } else {
           ;HEAP32[$560+0>>2]=HEAP32[$data$i$i+0>>2]|0;HEAP32[$560+4>>2]=HEAP32[$data$i$i+4>>2]|0;HEAP32[$560+8>>2]=HEAP32[$data$i$i+8>>2]|0;HEAP32[$560+12>>2]=HEAP32[$data$i$i+12>>2]|0;HEAP32[$560+16>>2]=HEAP32[$data$i$i+16>>2]|0;HEAP32[$560+20>>2]=HEAP32[$data$i$i+20>>2]|0;
           $565 = $560;
          }
          $564 = (($565) + 24|0);
          HEAP32[$348>>2] = $564;
         }
         if (!($casterTouchesView$0$off0$i)) {
          break;
         }
         $568 = Math_fround(HEAPF32[$447>>2]);
         $569 = ((($446) + (($438*24)|0)|0) + 12|0);
         $570 = Math_fround(HEAPF32[$569>>2]);
         $571 = Math_fround($568 + $570);
         $572 = ((($446) + (($438*24)|0)|0) + 4|0);
         $573 = Math_fround(HEAPF32[$572>>2]);
         $574 = ((($446) + (($438*24)|0)|0) + 16|0);
         $575 = Math_fround(HEAPF32[$574>>2]);
         $576 = Math_fround($573 + $575);
         $577 = ((($446) + (($438*24)|0)|0) + 8|0);
         $578 = Math_fround(HEAPF32[$577>>2]);
         $579 = ((($446) + (($438*24)|0)|0) + 20|0);
         $580 = Math_fround(HEAPF32[$579>>2]);
         $581 = Math_fround($578 + $580);
         $582 = Math_fround(HEAPF32[$casterBounds>>2]);
         $583 = $571 < $582;
         $584 = $583 ? $571 : $582;
         $585 = Math_fround(HEAPF32[$428>>2]);
         $586 = $576 < $585;
         $587 = $586 ? $576 : $585;
         $588 = Math_fround(HEAPF32[$429>>2]);
         $589 = $581 < $588;
         $590 = $589 ? $581 : $588;
         HEAPF32[$casterBounds>>2] = $584;
         HEAPF32[$428>>2] = $587;
         HEAPF32[$429>>2] = $590;
         $591 = Math_fround(HEAPF32[$339>>2]);
         $592 = $591 < $571;
         $593 = $592 ? $571 : $591;
         $594 = Math_fround(HEAPF32[$340>>2]);
         $595 = $594 < $576;
         $596 = $595 ? $576 : $594;
         $597 = Math_fround(HEAPF32[$341>>2]);
         $598 = $597 < $581;
         $599 = $598 ? $581 : $597;
         HEAPF32[$339>>2] = $593;
         HEAPF32[$340>>2] = $596;
         HEAPF32[$341>>2] = $599;
         $600 = Math_fround(HEAPF32[$447>>2]);
         $601 = Math_fround(HEAPF32[$569>>2]);
         $602 = Math_fround($600 - $601);
         $603 = Math_fround(HEAPF32[$572>>2]);
         $604 = Math_fround(HEAPF32[$574>>2]);
         $605 = Math_fround($603 - $604);
         $606 = Math_fround(HEAPF32[$577>>2]);
         $607 = Math_fround(HEAPF32[$579>>2]);
         $608 = Math_fround($606 - $607);
         $609 = $602 < $584;
         $610 = $609 ? $602 : $584;
         $611 = $605 < $587;
         $612 = $611 ? $605 : $587;
         $613 = $608 < $590;
         $614 = $613 ? $608 : $590;
         HEAPF32[$casterBounds>>2] = $610;
         HEAPF32[$428>>2] = $612;
         HEAPF32[$429>>2] = $614;
         $615 = $593 < $602;
         $616 = $615 ? $602 : $593;
         $617 = $596 < $605;
         $618 = $617 ? $605 : $596;
         $619 = $599 < $608;
         $620 = $619 ? $608 : $599;
         HEAPF32[$339>>2] = $616;
         HEAPF32[$340>>2] = $618;
         HEAPF32[$341>>2] = $620;
        }
       } while(0);
       $621 = (($i$01$i37) + 1)|0;
       $622 = HEAP32[$430>>2]|0;
       $623 = ($621|0)<($622|0);
       if ($623) {
        $i$01$i37 = $621;
       } else {
        break;
       }
      }
     }
     $624 = (($t$02$i) + 1)|0;
     $exitcond$i40 = ($624|0)==(5);
     if ($exitcond$i40) {
      label = 116;
      break;
     } else {
      $t$02$i = $624;
     }
    }
    if ((label|0) == 116) {
     $625 = HEAP32[$348>>2]|0;
     $626 = HEAP32[$casters>>2]|0;
     $627 = ($625|0)==($626|0);
     L167: do {
      if ($627) {
       __THREW__ = 0;
       $628 = (invoke_i(61)|0);
       $629 = __THREW__; __THREW__ = 0;
       $630 = $629&1;
       if ($630) {
        label = 122;
        break L82;
       }
       __THREW__ = 0;
       invoke_vii(2617,($628|0),($314|0));
       $631 = __THREW__; __THREW__ = 0;
       $632 = $631&1;
       if ($632) {
        label = 122;
        break L82;
       } else {
        $$0 = 0;
       }
      } else {
       __THREW__ = 0;
       $641 = (invoke_i(59)|0);
       $642 = __THREW__; __THREW__ = 0;
       $643 = $642&1;
       if ($643) {
        label = 122;
        break L82;
       }
       $644 = HEAP32[$641>>2]|0;
       $645 = (($644) + 88|0);
       $646 = HEAP32[$645>>2]|0;
       __THREW__ = 0;
       $647 = (invoke_ii($646|0,($641|0))|0);
       $648 = __THREW__; __THREW__ = 0;
       $649 = $648&1;
       if ($649) {
        label = 122;
        break L82;
       }
       $650 = HEAP32[$641>>2]|0;
       $651 = (($650) + 84|0);
       $652 = HEAP32[$651>>2]|0;
       __THREW__ = 0;
       invoke_vii($652|0,($641|0),0);
       $653 = __THREW__; __THREW__ = 0;
       $654 = $653&1;
       if ($654) {
        label = 122;
        break L82;
       }
       $655 = Math_fround(HEAPF32[$casterBounds>>2]);
       $656 = Math_fround(HEAPF32[616664>>2]);
       $657 = $655 == $656;
       do {
        if ($657) {
         $658 = Math_fround(HEAPF32[$428>>2]);
         $659 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
         $660 = $658 == $659;
         if (!($660)) {
          label = 130;
          break;
         }
         $661 = Math_fround(HEAPF32[$429>>2]);
         $662 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
         $663 = $661 == $662;
         if ($663) {
          label = 133;
         } else {
          label = 130;
         }
        } else {
         label = 130;
        }
       } while(0);
       do {
        if ((label|0) == 130) {
         $664 = Math_fround(-$656);
         $665 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
         $666 = Math_fround(-$665);
         $667 = Math_fround(HEAPF32[$339>>2]);
         $668 = $667 == $664;
         if (!($668)) {
          break;
         }
         $669 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
         $670 = Math_fround(-$669);
         $671 = Math_fround(HEAPF32[$340>>2]);
         $672 = $671 == $670;
         if (!($672)) {
          break;
         }
         $673 = Math_fround(HEAPF32[$341>>2]);
         $phitmp2$i57 = $673 != $666;
         if (!($phitmp2$i57)) {
          label = 133;
         }
        }
       } while(0);
       if ((label|0) == 133) {
        ;HEAP32[$casterBounds+0>>2]=HEAP32[$receiverBounds+0>>2]|0;HEAP32[$casterBounds+4>>2]=HEAP32[$receiverBounds+4>>2]|0;HEAP32[$casterBounds+8>>2]=HEAP32[$receiverBounds+8>>2]|0;HEAP32[$casterBounds+12>>2]=HEAP32[$receiverBounds+12>>2]|0;HEAP32[$casterBounds+16>>2]=HEAP32[$receiverBounds+16>>2]|0;HEAP32[$casterBounds+20>>2]=HEAP32[$receiverBounds+20>>2]|0;
       }
       $692 = (($24) + 24|0);
       $693 = HEAP32[$692>>2]|0;
       __THREW__ = 0;
       $694 = (invoke_ii(3220,($693|0))|0);
       $695 = __THREW__; __THREW__ = 0;
       $696 = $695&1;
       L184: do {
        if ($696) {
         label = 138;
        } else {
         __THREW__ = 0;
         invoke_vii(2620,($lightPos|0),($694|0));
         $697 = __THREW__; __THREW__ = 0;
         $698 = $697&1;
         if ($698) {
          label = 138;
          break;
         }
         __THREW__ = 0;
         invoke_vii(2645,($lightRot|0),($694|0));
         $699 = __THREW__; __THREW__ = 0;
         $700 = $699&1;
         if ($700) {
          label = 138;
          break;
         }
         $701 = Math_fround(HEAPF32[$lightRot>>2]);
         $702 = Math_fround($701 * Math_fround(2.0));
         $703 = (($lightRot) + 4|0);
         $704 = Math_fround(HEAPF32[$703>>2]);
         $705 = Math_fround($704 * Math_fround(2.0));
         $706 = (($lightRot) + 8|0);
         $707 = Math_fround(HEAPF32[$706>>2]);
         $708 = Math_fround($707 * Math_fround(2.0));
         $709 = Math_fround($701 * $702);
         $710 = Math_fround($704 * $705);
         $711 = Math_fround($707 * $708);
         $712 = Math_fround($701 * $705);
         $713 = Math_fround($701 * $708);
         $714 = Math_fround($704 * $708);
         $715 = (($lightRot) + 12|0);
         $716 = Math_fround(HEAPF32[$715>>2]);
         $717 = Math_fround($702 * $716);
         $718 = Math_fround($705 * $716);
         $719 = Math_fround($716 * $708);
         $720 = (($lightDir) + 4|0);
         $721 = (($lightDir) + 8|0);
         $722 = Math_fround($710 + $711);
         $723 = Math_fround(Math_fround(1.0) - $722);
         $724 = Math_fround($723 * Math_fround(0.0));
         $725 = Math_fround($712 - $719);
         $726 = Math_fround($725 * Math_fround(0.0));
         $727 = Math_fround($726 + $724);
         $728 = Math_fround($713 + $718);
         $729 = Math_fround($728 + $727);
         HEAPF32[$lightDir>>2] = $729;
         $730 = Math_fround($712 + $719);
         $731 = Math_fround($730 * Math_fround(0.0));
         $732 = Math_fround($709 + $711);
         $733 = Math_fround(Math_fround(1.0) - $732);
         $734 = Math_fround($733 * Math_fround(0.0));
         $735 = Math_fround($731 + $734);
         $736 = Math_fround($714 - $717);
         $737 = Math_fround($736 + $735);
         HEAPF32[$720>>2] = $737;
         $738 = Math_fround($713 - $718);
         $739 = Math_fround($738 * Math_fround(0.0));
         $740 = Math_fround($714 + $717);
         $741 = Math_fround($740 * Math_fround(0.0));
         $742 = Math_fround($739 + $741);
         $743 = Math_fround($709 + $710);
         $744 = Math_fround(Math_fround(1.0) - $743);
         $745 = Math_fround($744 + $742);
         HEAPF32[$721>>2] = $745;
         $746 = (($153) + 5925|0);
         $747 = HEAP8[$746>>0]|0;
         $748 = ($747<<24>>24)!=(0);
         $749 = HEAP32[$153>>2]|0;
         $750 = (($749) + 80|0);
         $751 = HEAP32[$750>>2]|0;
         $752 = HEAP32[$49>>2]|0;
         $753 = ($752|0)==(2);
         __THREW__ = 0;
         invoke_vii($751|0,($153|0),($753|0));
         $754 = __THREW__; __THREW__ = 0;
         $755 = $754&1;
         if ($755) {
          label = 138;
          break;
         }
         $756 = HEAP32[$49>>2]|0;
         L189: do {
          if ((($756|0) == 2)) {
           $757 = Math_fround(HEAPF32[$lightPos>>2]);
           $758 = (($lightPos) + 4|0);
           $759 = Math_fround(HEAPF32[$758>>2]);
           $760 = (($lightPos) + 8|0);
           $761 = Math_fround(HEAPF32[$760>>2]);
           $762 = (($24) + 188|0);
           $763 = Math_fround(HEAPF32[$762>>2]);
           $764 = Math_fround(Math_fround(1.0) / $763);
           $765 = (($153) + 644|0);
           HEAPF32[$765>>2] = $757;
           $766 = (($153) + 648|0);
           HEAPF32[$766>>2] = $759;
           $767 = (($153) + 652|0);
           HEAPF32[$767>>2] = $761;
           $768 = (($153) + 656|0);
           HEAPF32[$768>>2] = $764;
           $769 = (($18) + 4|0);
           $770 = (($18) + 8|0);
           $771 = (($18) + 12|0);
           $772 = (($8) + 4|0);
           $773 = (($8) + 8|0);
           $774 = (($passContext) + 20|0);
           $775 = (($9) + 4|0);
           $776 = (($9) + 8|0);
           $777 = (($9) + 12|0);
           $f$0129 = 0;
           L191: while(1) {
            __THREW__ = 0;
            invoke_viiii(337,($314|0),0,($f$0129|0),12);
            $778 = __THREW__; __THREW__ = 0;
            $779 = $778&1;
            if ($779) {
             label = 135;
             break;
            }
            HEAPF32[$18>>2] = Math_fround(1.0);
            HEAPF32[$769>>2] = Math_fround(1.0);
            HEAPF32[$770>>2] = Math_fround(1.0);
            HEAPF32[$771>>2] = Math_fround(1.0);
            __THREW__ = 0;
            invoke_viifii(3,7,($18|0),1.0,0,($passContext|0));
            $780 = __THREW__; __THREW__ = 0;
            $781 = $780&1;
            if ($781) {
             label = 135;
             break;
            }
            $782 = Math_fround(HEAPF32[$762>>2]);
            __THREW__ = 0;
            $783 = (invoke_i(59)|0);
            $784 = __THREW__; __THREW__ = 0;
            $785 = $784&1;
            if ($785) {
             label = 135;
             break;
            }
            $786 = ($f$0129*3)|0;
            $787 = (576872 + (($786*12)|0)|0);
            $788 = (($786) + 1)|0;
            $789 = (576872 + (($788*12)|0)|0);
            $790 = (($786) + 2)|0;
            $791 = (576872 + (($790*12)|0)|0);
            __THREW__ = 0;
            (invoke_iiiii(234,($viewMatrix$i|0),($787|0),($789|0),($791|0))|0);
            $792 = __THREW__; __THREW__ = 0;
            $793 = $792&1;
            if ($793) {
             label = 135;
             break;
            }
            $794 = Math_fround(HEAPF32[$lightPos>>2]);
            $795 = Math_fround(-$794);
            $796 = Math_fround(HEAPF32[$758>>2]);
            $797 = Math_fround(-$796);
            $798 = Math_fround(HEAPF32[$760>>2]);
            $799 = Math_fround(-$798);
            HEAPF32[$8>>2] = $795;
            HEAPF32[$772>>2] = $797;
            HEAPF32[$773>>2] = $799;
            __THREW__ = 0;
            (invoke_iii(2370,($tr$i|0),($8|0))|0);
            $800 = __THREW__; __THREW__ = 0;
            $801 = $800&1;
            if ($801) {
             label = 135;
             break;
            }
            __THREW__ = 0;
            (invoke_iii(2371,($viewMatrix$i|0),($tr$i|0))|0);
            $802 = __THREW__; __THREW__ = 0;
            $803 = $802&1;
            if ($803) {
             label = 135;
             break;
            }
            $804 = Math_fround($782 * Math_fround(0.00999999977648258209228));
            $805 = $804 > Math_fround(0.00999999977648258209228);
            $806 = $805 ? Math_fround(0.00999999977648258209228) : $804;
            $807 = Math_fround($782 * Math_fround(1.00999999046325683594));
            __THREW__ = 0;
            (invoke_iiffff(1,($projMatrix$i|0),90.0,1.0,(+$806),(+$807))|0);
            $808 = __THREW__; __THREW__ = 0;
            $809 = $808&1;
            if ($809) {
             label = 135;
             break;
            }
            $810 = HEAP32[$783>>2]|0;
            $811 = (($810) + 104|0);
            $812 = HEAP32[$811>>2]|0;
            __THREW__ = 0;
            invoke_vii($812|0,($783|0),($projMatrix$i|0));
            $813 = __THREW__; __THREW__ = 0;
            $814 = $813&1;
            if ($814) {
             label = 135;
             break;
            }
            $815 = HEAP32[$783>>2]|0;
            $816 = (($815) + 100|0);
            $817 = HEAP32[$816>>2]|0;
            __THREW__ = 0;
            invoke_vii($817|0,($783|0),($viewMatrix$i|0));
            $818 = __THREW__; __THREW__ = 0;
            $819 = $818&1;
            if ($819) {
             label = 135;
             break;
            }
            __THREW__ = 0;
            invoke_v(107);
            $820 = __THREW__; __THREW__ = 0;
            $821 = $820&1;
            if ($821) {
             label = 135;
             break;
            }
            __THREW__ = 0;
            invoke_viii(1688,($projMatrix$i|0),($viewMatrix$i|0),($shadowWorldToClip|0));
            $822 = __THREW__; __THREW__ = 0;
            $823 = $822&1;
            if ($823) {
             label = 135;
             break;
            }
            HEAPF32[$9>>2] = Math_fround(0.0);
            HEAPF32[$775>>2] = $806;
            HEAPF32[$776>>2] = $807;
            HEAPF32[$777>>2] = Math_fround(0.0);
            __THREW__ = 0;
            invoke_viii(1689,($774|0),(576168|0),($9|0));
            $824 = __THREW__; __THREW__ = 0;
            $825 = $824&1;
            if ($825) {
             label = 135;
             break;
            }
            HEAPF32[$planes>>2] = Math_fround(0.0);
            $826 = (($planes) + 4|0);
            HEAPF32[$826>>2] = Math_fround(0.0);
            $827 = (($planes) + 8|0);
            HEAPF32[$827>>2] = Math_fround(0.0);
            $828 = (($planes) + 16|0);
            HEAPF32[$828>>2] = Math_fround(0.0);
            $829 = (($planes) + 20|0);
            HEAPF32[$829>>2] = Math_fround(0.0);
            $830 = (($planes) + 24|0);
            HEAPF32[$830>>2] = Math_fround(0.0);
            $831 = (($planes) + 32|0);
            HEAPF32[$831>>2] = Math_fround(0.0);
            $832 = (($planes) + 36|0);
            HEAPF32[$832>>2] = Math_fround(0.0);
            $833 = (($planes) + 40|0);
            HEAPF32[$833>>2] = Math_fround(0.0);
            $834 = (($planes) + 48|0);
            HEAPF32[$834>>2] = Math_fround(0.0);
            $835 = (($planes) + 52|0);
            HEAPF32[$835>>2] = Math_fround(0.0);
            $836 = (($planes) + 56|0);
            HEAPF32[$836>>2] = Math_fround(0.0);
            $837 = (($planes) + 64|0);
            HEAPF32[$837>>2] = Math_fround(0.0);
            $838 = (($planes) + 68|0);
            HEAPF32[$838>>2] = Math_fround(0.0);
            $839 = (($planes) + 72|0);
            HEAPF32[$839>>2] = Math_fround(0.0);
            $840 = (($planes) + 80|0);
            HEAPF32[$840>>2] = Math_fround(0.0);
            $841 = (($planes) + 84|0);
            HEAPF32[$841>>2] = Math_fround(0.0);
            $842 = (($planes) + 88|0);
            HEAPF32[$842>>2] = Math_fround(0.0);
            __THREW__ = 0;
            invoke_vii(2646,($shadowWorldToClip|0),($planes|0));
            $843 = __THREW__; __THREW__ = 0;
            $844 = $843&1;
            if ($844) {
             label = 135;
             break;
            }
            $845 = HEAP32[$348>>2]|0;
            $846 = HEAP32[$casters>>2]|0;
            $847 = $845;
            $848 = $846;
            $849 = (($847) - ($848))|0;
            $850 = (($849|0) / 24)&-1;
            $851 = ($849|0)>(0);
            L206: do {
             if ($851) {
              $853 = $846;$c$0124 = 0;
              while(1) {
               $852 = ((($853) + (($c$0124*24)|0)|0) + 4|0);
               $854 = HEAP32[$852>>2]|0;
               __THREW__ = 0;
               $855 = (invoke_iiii(1538,($854|0),($planes|0),15)|0);
               $856 = __THREW__; __THREW__ = 0;
               $857 = $856&1;
               if ($857) {
                label = 134;
                break L191;
               }
               $858 = ((($853) + (($c$0124*24)|0)|0) + 16|0);
               $$11 = $855&1;
               HEAP32[$858>>2] = $$11;
               $859 = (($c$0124) + 1)|0;
               $860 = ($859|0)<($850|0);
               if (!($860)) {
                break L206;
               }
               $$pre200 = HEAP32[$casters>>2]|0;
               $853 = $$pre200;$c$0124 = $859;
              }
             }
            } while(0);
            __THREW__ = 0;
            invoke_viiiii(93,0,($casters|0),($casterParts|0),($cameraData|0),($passContext|0));
            $861 = __THREW__; __THREW__ = 0;
            $862 = $861&1;
            if ($862) {
             label = 135;
             break;
            }
            $863 = (($f$0129) + 1)|0;
            $864 = ($863|0)<(6);
            if ($864) {
             $f$0129 = $863;
            } else {
             break L189;
            }
           }
           if ((label|0) == 134) {
            $674 = ___cxa_find_matching_catch()|0;
            $675 = tempRet0;
            $eh$lpad$body$index16Z2D = $675;$eh$lpad$body$indexZ2D = $674;
            break L184;
           }
           else if ((label|0) == 135) {
            $676 = ___cxa_find_matching_catch()|0;
            $677 = tempRet0;
            $eh$lpad$body$index16Z2D = $677;$eh$lpad$body$indexZ2D = $676;
            break L184;
           }
          } else if ((($756|0) == 1)) {
           __THREW__ = 0;
           invoke_viiii(337,($314|0),0,-1,12);
           $865 = __THREW__; __THREW__ = 0;
           $866 = $865&1;
           if ($866) {
            label = 138;
            break L184;
           }
           HEAPF32[$19>>2] = Math_fround(1.0);
           $867 = (($19) + 4|0);
           HEAPF32[$867>>2] = Math_fround(1.0);
           $868 = (($19) + 8|0);
           HEAPF32[$868>>2] = Math_fround(1.0);
           $869 = (($19) + 12|0);
           HEAPF32[$869>>2] = Math_fround(1.0);
           __THREW__ = 0;
           invoke_viifii(3,7,($19|0),1.0,0,($passContext|0));
           $870 = __THREW__; __THREW__ = 0;
           $871 = $870&1;
           if ($871) {
            label = 138;
            break L184;
           }
           $872 = (($cameraData) + 612|0);
           $873 = HEAP32[$872>>2]|0;
           if ((($873|0) == 2) | (($873|0) == 1)) {
            $tilesX$0 = $873;$tilesY$0 = 1;
           } else if ((($873|0) == 4)) {
            $tilesX$0 = 2;$tilesY$0 = 2;
           } else {
            $tilesX$0 = 1;$tilesY$0 = 1;
           }
           $874 = (($shadowWidth$1|0) / ($tilesX$0|0))&-1;
           $875 = (($cascades) + 324|0);
           HEAPF32[$875>>2] = Math_fround(0.0);
           $876 = (($cascades) + 328|0);
           HEAPF32[$876>>2] = Math_fround(0.0);
           $877 = (($cascades) + 332|0);
           HEAPF32[$877>>2] = Math_fround(0.0);
           $878 = (($cascades) + 680|0);
           HEAPF32[$878>>2] = Math_fround(0.0);
           $879 = (($cascades) + 684|0);
           HEAPF32[$879>>2] = Math_fround(0.0);
           $880 = (($cascades) + 688|0);
           HEAPF32[$880>>2] = Math_fround(0.0);
           $881 = (($cascades) + 1036|0);
           HEAPF32[$881>>2] = Math_fround(0.0);
           $882 = (($cascades) + 1040|0);
           HEAPF32[$882>>2] = Math_fround(0.0);
           $883 = (($cascades) + 1044|0);
           HEAPF32[$883>>2] = Math_fround(0.0);
           $884 = (($cascades) + 1392|0);
           HEAPF32[$884>>2] = Math_fround(0.0);
           $885 = (($cascades) + 1396|0);
           HEAPF32[$885>>2] = Math_fround(0.0);
           $886 = (($cascades) + 1400|0);
           HEAPF32[$886>>2] = Math_fround(0.0);
           $887 = (($shadowHeight$3|0) / ($tilesY$0|0))&-1;
           $888 = ($tilesX$0|0)>(0);
           $889 = (($cameraData) + 588|0);
           $890 = (($cameraData) + 580|0);
           $891 = (($cameraData) + 584|0);
           $892 = (($localFrustumTransform$i) + 16|0);
           $893 = (($localFrustumTransform$i) + 32|0);
           $894 = (($localFrustumTransform$i) + 48|0);
           $895 = (($localFrustumTransform$i) + 4|0);
           $896 = (($localFrustumTransform$i) + 20|0);
           $897 = (($localFrustumTransform$i) + 36|0);
           $898 = (($localFrustumTransform$i) + 52|0);
           $899 = (($localFrustumTransform$i) + 8|0);
           $900 = (($localFrustumTransform$i) + 24|0);
           $901 = (($localFrustumTransform$i) + 40|0);
           $902 = (($localFrustumTransform$i) + 56|0);
           $903 = (($localFrustumTransform$i) + 12|0);
           $904 = (($localFrustumTransform$i) + 28|0);
           $905 = (($localFrustumTransform$i) + 44|0);
           $906 = (($localFrustumTransform$i) + 60|0);
           $907 = Math_fround(HEAPF32[616648>>2]);
           $908 = (($focusPoints$i) + 4|0);
           $909 = (($focusPoints$i) + 8|0);
           $910 = (($3) + 4|0);
           $911 = (($3) + 8|0);
           $912 = (($4) + 4|0);
           $913 = (($4) + 8|0);
           $914 = (($5) + 4|0);
           $915 = (($5) + 8|0);
           $916 = (($6) + 4|0);
           $917 = (($6) + 8|0);
           $918 = (($axisZ$i) + 4|0);
           $919 = (($axisZ$i) + 8|0);
           $920 = (($pos$i) + 4|0);
           $921 = (($pos$i) + 8|0);
           $922 = (Math_fround(($874|0)));
           $923 = (($axisX$i) + 4|0);
           $924 = (($axisX$i) + 8|0);
           $925 = (($axisY$i) + 4|0);
           $926 = (($axisY$i) + 8|0);
           $927 = (Math_fround(($887|0)));
           $928 = (($texMatrix$i) + 20|0);
           $929 = (($texMatrix$i) + 40|0);
           $930 = (($texMatrix$i) + 48|0);
           $931 = (($texMatrix$i) + 52|0);
           $932 = (($texMatrix$i) + 56|0);
           $933 = (($sphereCenter$i) + 4|0);
           $934 = (($sphereCenter$i) + 8|0);
           $935 = (($7) + 16|0);
           $936 = (($7) + 32|0);
           $937 = (($7) + 48|0);
           $938 = (($7) + 4|0);
           $939 = (($7) + 20|0);
           $940 = (($7) + 36|0);
           $941 = (($7) + 52|0);
           $942 = (($7) + 8|0);
           $943 = (($7) + 24|0);
           $944 = (($7) + 40|0);
           $945 = (($7) + 56|0);
           $946 = (($cameraData) + 4|0);
           $splitIndex$0171 = 0;$ty$0172 = 0;
           L223: while(1) {
            if ($888) {
             $splitIndex$1163 = $splitIndex$0171;$tx$0164 = 0;
             while(1) {
              $947 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 260|0);
              __THREW__ = 0;
              (invoke_ii(3230,($947|0))|0);
              $948 = __THREW__; __THREW__ = 0;
              $949 = $948&1;
              if ($949) {
               label = 137;
               break L223;
              }
              $950 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 324|0);
              ;HEAP32[$950+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$950+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$950+8>>2]=HEAP32[616680+8>>2]|0;
              $951 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 336|0);
              HEAPF32[$951>>2] = Math_fround(-1.0E+9);
              $952 = HEAP32[$cameraData>>2]|0;
              $953 = Math_fround(HEAPF32[$889>>2]);
              $954 = Math_fround(HEAPF32[$890>>2]);
              __THREW__ = 0;
              $955 = (invoke_i(76)|0);
              $956 = __THREW__; __THREW__ = 0;
              $957 = $956&1;
              if ($957) {
               label = 137;
               break L223;
              }
              $958 = (($955) + 40|0);
              $959 = HEAP32[$958>>2]|0;
              $960 = (($955) + 24|0);
              $961 = HEAP32[$960>>2]|0;
              $962 = ((($961) + (($959*96)|0)|0) + 24|0);
              $963 = HEAP32[$962>>2]|0;
              $964 = ($963|0)==(1);
              if ($964) {
               $965 = Math_fround(HEAPF32[$891>>2]);
               $966 = Math_fround(HEAPF32[$889>>2]);
               __THREW__ = 0;
               invoke_viffi(1,($952|0),(+$965),(+$966),($cameraProjection$i|0));
               $967 = __THREW__; __THREW__ = 0;
               $968 = $967&1;
               if ($968) {
                label = 137;
                break L223;
               }
               __THREW__ = 0;
               (invoke_iii(2380,($cameraProjection$i|0),($localFrustumTransform$i|0))|0);
               $969 = __THREW__; __THREW__ = 0;
               $970 = $969&1;
               if ($970) {
                label = 137;
                break L223;
               }
               $971 = Math_fround(HEAPF32[$localFrustumTransform$i>>2]);
               $972 = Math_fround(HEAPF32[$892>>2]);
               $973 = Math_fround($971 + $972);
               $974 = Math_fround(HEAPF32[$893>>2]);
               $975 = Math_fround($973 + $974);
               $976 = Math_fround(HEAPF32[$894>>2]);
               $977 = Math_fround($976 + $975);
               $978 = Math_fround(HEAPF32[$895>>2]);
               $979 = Math_fround(HEAPF32[$896>>2]);
               $980 = Math_fround($978 + $979);
               $981 = Math_fround(HEAPF32[$897>>2]);
               $982 = Math_fround($980 + $981);
               $983 = Math_fround(HEAPF32[$898>>2]);
               $984 = Math_fround($983 + $982);
               $985 = Math_fround(HEAPF32[$899>>2]);
               $986 = Math_fround(HEAPF32[$900>>2]);
               $987 = Math_fround($985 + $986);
               $988 = Math_fround(HEAPF32[$901>>2]);
               $989 = Math_fround($987 + $988);
               $990 = Math_fround(HEAPF32[$902>>2]);
               $991 = Math_fround($990 + $989);
               $992 = Math_fround(HEAPF32[$903>>2]);
               $993 = Math_fround(HEAPF32[$904>>2]);
               $994 = Math_fround($992 + $993);
               $995 = Math_fround(HEAPF32[$905>>2]);
               $996 = Math_fround($994 + $995);
               $997 = Math_fround(HEAPF32[$906>>2]);
               $998 = Math_fround($997 + $996);
               $999 = $998 < Math_fround(0.0);
               if ($999) {
                $1000 = Math_fround(-$998);
                $1002 = $1000;
               } else {
                $1002 = $998;
               }
               $1001 = $1002 > Math_fround(1.00000001168609742308E-7);
               if ($1001) {
                $1003 = Math_fround(Math_fround(1.0) / $998);
                $1004 = Math_fround($977 * $1003);
                $1005 = Math_fround($984 * $1003);
                $1006 = Math_fround($991 * $1003);
                $1008 = $1004;$1010 = $1005;$1013 = $1006;
               } else {
                $1008 = Math_fround(0.0);$1010 = Math_fround(0.0);$1013 = Math_fround(0.0);
               }
               $1007 = Math_fround($1008 * $1008);
               $1009 = Math_fround($1010 * $1010);
               $1011 = Math_fround($1009 + $1007);
               $1012 = Math_fround($1013 * $1013);
               $1014 = Math_fround($1012 + $1011);
               $1015 = (Math_fround(Math_sqrt((Math_fround($1014)))));
               $1016 = Math_fround($1015 / $953);
               __THREW__ = 0;
               $1017 = (Math_fround(+(invoke_fi(226,($952|0)))));
               $1018 = __THREW__; __THREW__ = 0;
               $1019 = $1018&1;
               if ($1019) {
                label = 137;
                break L223;
               }
               $1020 = Math_fround(Math_fround(1.0) - $1017);
               $1021 = Math_fround($1016 * $1016);
               $1022 = Math_fround($1021 * $1017);
               $1023 = Math_fround($1017 * $1022);
               $1024 = Math_fround($1021 * $1020);
               $1025 = Math_fround($1020 * $1024);
               $1026 = Math_fround($1025 - $1023);
               $1027 = Math_fround($1017 * $1017);
               $1028 = Math_fround($1027 + $1026);
               $1029 = (Math_fround(Math_sqrt((Math_fround($1028)))));
               $1030 = Math_fround($1017 + $1029);
               $1031 = Math_fround($1030 / $1021);
               $farPlaneScale$0$i = $1031;$frustumTransform$0$i = $localFrustumTransform$i;
              } else {
               $farPlaneScale$0$i = Math_fround(1.0);$frustumTransform$0$i = $946;
              }
              $1032 = Math_fround(HEAPF32[$891>>2]);
              $1033 = Math_fround($954 * $farPlaneScale$0$i);
              $1034 = Math_fround($1033 - $1032);
              $1035 = Math_fround($953 - $1032);
              $1036 = Math_fround($1034 / $1035);
              $1037 = !($1036 <= $907);
              do {
               if ($1037) {
                dest=$cameraFrustum$i+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
                __THREW__ = 0;
                invoke_vii(2647,($frustumTransform$0$i|0),($cameraFrustum$i|0));
                $1038 = __THREW__; __THREW__ = 0;
                $1039 = $1038&1;
                if ($1039) {
                 label = 137;
                 break L223;
                }
                $1040 = ((($cameraData) + ($splitIndex$1163<<2)|0) + 636|0);
                dest=$frustumSplit$i+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
                $1041 = Math_fround(HEAPF32[$1040>>2]);
                $1042 = Math_fround($1036 * $1041);
                $1043 = (($splitIndex$1163) + 1)|0;
                $1044 = ((($cameraData) + ($1043<<2)|0) + 636|0);
                $1045 = Math_fround(HEAPF32[$1044>>2]);
                $1046 = Math_fround($1036 * $1045);
                $1047 = Math_fround($1035 * $1042);
                $1048 = Math_fround($1032 + $1047);
                $1049 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 340|0);
                HEAPF32[$1049>>2] = $1048;
                $1050 = Math_fround($1035 * $1046);
                $1051 = Math_fround($1032 + $1050);
                $1052 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 344|0);
                HEAPF32[$1052>>2] = $1051;
                __THREW__ = 0;
                invoke_viffi(2,($cameraFrustum$i|0),(+$1042),(+$1046),($frustumSplit$i|0));
                $1053 = __THREW__; __THREW__ = 0;
                $1054 = $1053&1;
                if ($1054) {
                 label = 137;
                 break L223;
                }
                HEAP32[$focusPoints$i>>2] = 0;
                HEAP32[$908>>2] = 0;
                HEAP32[$909>>2] = 0;
                $1055 = ($963|0)==(0);
                do {
                 if ($1055) {
                  HEAPF32[$3>>2] = Math_fround(0.0);
                  HEAPF32[$910>>2] = Math_fround(0.0);
                  HEAPF32[$911>>2] = Math_fround(1.0);
                  __THREW__ = 0;
                  invoke_viii(1690,($lightDir$i|0),($694|0),($3|0));
                  $1056 = __THREW__; __THREW__ = 0;
                  $1057 = $1056&1;
                  if ($1057) {
                   label = 194;
                   break L223;
                  }
                  __THREW__ = 0;
                  invoke_viiii(349,($frustumSplit$i|0),($lightDir$i|0),($receiverBounds|0),($focusPoints$i|0));
                  $1058 = __THREW__; __THREW__ = 0;
                  $1059 = $1058&1;
                  if ($1059) {
                   label = 194;
                   break L223;
                  }
                  $1060 = HEAP32[$focusPoints$i>>2]|0;
                  $1061 = HEAP32[$908>>2]|0;
                  $1062 = ($1060|0)==($1061|0);
                  if (!($1062)) {
                   label = 198;
                   break;
                  }
                  $1063 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 4|0);
                  __THREW__ = 0;
                  (invoke_ii(3230,($1063|0))|0);
                  $1064 = __THREW__; __THREW__ = 0;
                  $1065 = $1064&1;
                  if ($1065) {
                   label = 194;
                   break L223;
                  }
                  $1066 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 132|0);
                  __THREW__ = 0;
                  (invoke_iiffffff(1,($1066|0),-1.0,1.0,-1.0,1.0,0.100000001490116119385,10.0)|0);
                  $1067 = __THREW__; __THREW__ = 0;
                  $1068 = $1067&1;
                  if ($1068) {
                   label = 194;
                   break L223;
                  } else {
                   $$0$i = 0;
                  }
                 } else {
                  label = 198;
                 }
                } while(0);
                if ((label|0) == 198) {
                 label = 0;
                 $1078 = Math_fround(HEAPF32[$339>>2]);
                 $1079 = Math_fround(HEAPF32[$casterBounds>>2]);
                 $1080 = Math_fround($1078 + $1079);
                 $1081 = Math_fround(HEAPF32[$340>>2]);
                 $1082 = Math_fround(HEAPF32[$428>>2]);
                 $1083 = Math_fround($1081 + $1082);
                 $1084 = Math_fround(HEAPF32[$341>>2]);
                 $1085 = Math_fround(HEAPF32[$429>>2]);
                 $1086 = Math_fround($1084 + $1085);
                 $1087 = Math_fround($1080 * Math_fround(0.5));
                 $1088 = Math_fround($1083 * Math_fround(0.5));
                 $1089 = Math_fround($1086 * Math_fround(0.5));
                 $1090 = Math_fround($1078 - $1079);
                 $1091 = Math_fround($1081 - $1082);
                 $1092 = Math_fround($1084 - $1085);
                 $1093 = Math_fround($1090 * $1090);
                 $1094 = Math_fround($1091 * $1091);
                 $1095 = Math_fround($1093 + $1094);
                 $1096 = Math_fround($1092 * $1092);
                 $1097 = Math_fround($1095 + $1096);
                 $1098 = (Math_fround(Math_sqrt((Math_fround($1097)))));
                 $1099 = Math_fround($1098 * Math_fround(0.5));
                 HEAPF32[$4>>2] = Math_fround(1.0);
                 HEAPF32[$912>>2] = Math_fround(0.0);
                 HEAPF32[$913>>2] = Math_fround(0.0);
                 __THREW__ = 0;
                 invoke_viii(1690,($axisX$i|0),($694|0),($4|0));
                 $1100 = __THREW__; __THREW__ = 0;
                 $1101 = $1100&1;
                 if ($1101) {
                  label = 194;
                  break L223;
                 }
                 HEAPF32[$5>>2] = Math_fround(0.0);
                 HEAPF32[$914>>2] = Math_fround(1.0);
                 HEAPF32[$915>>2] = Math_fround(0.0);
                 __THREW__ = 0;
                 invoke_viii(1690,($axisY$i|0),($694|0),($5|0));
                 $1102 = __THREW__; __THREW__ = 0;
                 $1103 = $1102&1;
                 if ($1103) {
                  label = 194;
                  break L223;
                 }
                 HEAPF32[$6>>2] = Math_fround(0.0);
                 HEAPF32[$916>>2] = Math_fround(0.0);
                 HEAPF32[$917>>2] = Math_fround(1.0);
                 __THREW__ = 0;
                 invoke_viii(1690,($axisZ$i|0),($694|0),($6|0));
                 $1104 = __THREW__; __THREW__ = 0;
                 $1105 = $1104&1;
                 if ($1105) {
                  label = 194;
                  break L223;
                 }
                 $1106 = Math_fround(HEAPF32[$axisZ$i>>2]);
                 $1107 = Math_fround($1099 * $1106);
                 $1108 = Math_fround(HEAPF32[$918>>2]);
                 $1109 = Math_fround($1099 * $1108);
                 $1110 = Math_fround(HEAPF32[$919>>2]);
                 $1111 = Math_fround($1099 * $1110);
                 $1112 = Math_fround($1107 * Math_fround(1.20000004768371582031));
                 $1113 = Math_fround($1109 * Math_fround(1.20000004768371582031));
                 $1114 = Math_fround($1111 * Math_fround(1.20000004768371582031));
                 $1115 = Math_fround($1087 - $1112);
                 $1116 = Math_fround($1088 - $1113);
                 $1117 = Math_fround($1089 - $1114);
                 HEAPF32[$pos$i>>2] = $1115;
                 HEAPF32[$920>>2] = $1116;
                 HEAPF32[$921>>2] = $1117;
                 $1118 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 4|0);
                 __THREW__ = 0;
                 (invoke_iiiiii(198,($1118|0),($pos$i|0),($axisX$i|0),($axisY$i|0),($axisZ$i|0))|0);
                 $1119 = __THREW__; __THREW__ = 0;
                 $1120 = $1119&1;
                 if ($1120) {
                  label = 194;
                  break L223;
                 }
                 __THREW__ = 0;
                 invoke_viii(1691,($unionBounds$i|0),($casterBounds|0),($receiverBounds|0));
                 $1121 = __THREW__; __THREW__ = 0;
                 $1122 = $1121&1;
                 if ($1122) {
                  label = 194;
                  break L223;
                 }
                 dest=$unionPoints$i+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
                 __THREW__ = 0;
                 invoke_vii(2648,($unionBounds$i|0),($unionPoints$i|0));
                 $1123 = __THREW__; __THREW__ = 0;
                 $1124 = $1123&1;
                 if ($1124) {
                  label = 194;
                  break L223;
                 }
                 $1125 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 52|0);
                 $1126 = Math_fround(HEAPF32[$1125>>2]);
                 $1127 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 56|0);
                 $1128 = Math_fround(HEAPF32[$1127>>2]);
                 $1129 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 60|0);
                 $1130 = Math_fround(HEAPF32[$1129>>2]);
                 $1131 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 36|0);
                 $1132 = Math_fround(HEAPF32[$1131>>2]);
                 $1133 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 40|0);
                 $1134 = Math_fround(HEAPF32[$1133>>2]);
                 $1135 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 44|0);
                 $1136 = Math_fround(HEAPF32[$1135>>2]);
                 $1152 = Math_fround(inf);$1155 = Math_fround(-inf);$i$077$i = 0;
                 while(1) {
                  $1137 = (($unionPoints$i) + (($i$077$i*12)|0)|0);
                  $1138 = Math_fround(HEAPF32[$1137>>2]);
                  $1139 = Math_fround($1138 - $1126);
                  $1140 = ((($unionPoints$i) + (($i$077$i*12)|0)|0) + 4|0);
                  $1141 = Math_fround(HEAPF32[$1140>>2]);
                  $1142 = Math_fround($1141 - $1128);
                  $1143 = ((($unionPoints$i) + (($i$077$i*12)|0)|0) + 8|0);
                  $1144 = Math_fround(HEAPF32[$1143>>2]);
                  $1145 = Math_fround($1144 - $1130);
                  $1146 = Math_fround($1132 * $1139);
                  $1147 = Math_fround($1134 * $1142);
                  $1148 = Math_fround($1146 + $1147);
                  $1149 = Math_fround($1136 * $1145);
                  $1150 = Math_fround($1148 + $1149);
                  $1151 = $1152 < $1150;
                  $1153 = $1151 ? $1152 : $1150;
                  $1154 = $1150 < $1155;
                  $1156 = $1154 ? $1155 : $1150;
                  $1157 = (($i$077$i) + 1)|0;
                  $exitcond92$i = ($1157|0)==(8);
                  if ($exitcond92$i) {
                   break;
                  } else {
                   $1152 = $1153;$1155 = $1156;$i$077$i = $1157;
                  }
                 }
                 $1158 = Math_fround($1153 + $1156);
                 $1159 = Math_fround($1158 * Math_fround(0.5));
                 $1160 = Math_fround($1156 - $1153);
                 $1161 = Math_fround($1160 * Math_fround(0.5));
                 $1162 = Math_fround(HEAPF32[616664>>2]);
                 $1163 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
                 $1164 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
                 $1165 = Math_fround(-$1162);
                 $1166 = Math_fround(-$1163);
                 $1167 = Math_fround(-$1164);
                 do {
                  if ($1055) {
                   $1168 = HEAP32[$908>>2]|0;
                   $1169 = HEAP32[$focusPoints$i>>2]|0;
                   $1170 = ($1168|0)==($1169|0);
                   $$pre$pre$i = Math_fround(HEAPF32[$1118>>2]);
                   if ($1170) {
                    $$phi$trans$insert93$phi$trans$insert$i = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 20|0);
                    $$pre94$pre$i = Math_fround(HEAPF32[$$phi$trans$insert93$phi$trans$insert$i>>2]);
                    $$phi$trans$insert96$phi$trans$insert$i = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 8|0);
                    $$pre97$pre$i = Math_fround(HEAPF32[$$phi$trans$insert96$phi$trans$insert$i>>2]);
                    $$phi$trans$insert98$phi$trans$insert$i = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 24|0);
                    $$pre99$pre$i = Math_fround(HEAPF32[$$phi$trans$insert98$phi$trans$insert$i>>2]);
                    $$phi$trans$insert101$phi$trans$insert$i = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 12|0);
                    $$pre102$pre$i = Math_fround(HEAPF32[$$phi$trans$insert101$phi$trans$insert$i>>2]);
                    $$phi$trans$insert103$phi$trans$insert$i = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 28|0);
                    $$pre104$pre$i = Math_fround(HEAPF32[$$phi$trans$insert103$phi$trans$insert$i>>2]);
                    $$lcssa$i = $1167;$$lcssa55$i = $1166;$$lcssa56$i = $1165;$$lcssa57$i = $1164;$$lcssa58$i = $1163;$$lcssa59$i = $1162;$$pre102$i = $$pre102$pre$i;$$pre104$i = $$pre104$pre$i;$$pre94$i = $$pre94$pre$i;$$pre97$i = $$pre97$pre$i;$$pre99$i = $$pre99$pre$i;
                   } else {
                    $1171 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 8|0);
                    $1172 = Math_fround(HEAPF32[$1171>>2]);
                    $1173 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 12|0);
                    $1174 = Math_fround(HEAPF32[$1173>>2]);
                    $1175 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 20|0);
                    $1176 = Math_fround(HEAPF32[$1175>>2]);
                    $1177 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 24|0);
                    $1178 = Math_fround(HEAPF32[$1177>>2]);
                    $1179 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 28|0);
                    $1180 = Math_fround(HEAPF32[$1179>>2]);
                    $1181 = $1168;
                    $1182 = $1169;
                    $1183 = (($1181) - ($1182))|0;
                    $1184 = (($1183|0) / 12)&-1;
                    $1205 = $1162;$1208 = $1163;$1211 = $1164;$1214 = $1165;$1217 = $1166;$1220 = $1167;$i2$060$i = 0;
                    while(1) {
                     $1185 = (($1169) + (($i2$060$i*12)|0)|0);
                     $1186 = Math_fround(HEAPF32[$1185>>2]);
                     $1187 = Math_fround($1186 - $1126);
                     $1188 = ((($1169) + (($i2$060$i*12)|0)|0) + 4|0);
                     $1189 = Math_fround(HEAPF32[$1188>>2]);
                     $1190 = Math_fround($1189 - $1128);
                     $1191 = ((($1169) + (($i2$060$i*12)|0)|0) + 8|0);
                     $1192 = Math_fround(HEAPF32[$1191>>2]);
                     $1193 = Math_fround($1192 - $1130);
                     $1194 = Math_fround($$pre$pre$i * $1187);
                     $1195 = Math_fround($1172 * $1190);
                     $1196 = Math_fround($1194 + $1195);
                     $1197 = Math_fround($1174 * $1193);
                     $1198 = Math_fround($1196 + $1197);
                     $1199 = Math_fround($1176 * $1187);
                     $1200 = Math_fround($1178 * $1190);
                     $1201 = Math_fround($1199 + $1200);
                     $1202 = Math_fround($1180 * $1193);
                     $1203 = Math_fround($1201 + $1202);
                     $1204 = $1198 < $1205;
                     $1206 = $1204 ? $1198 : $1205;
                     $1207 = $1203 < $1208;
                     $1209 = $1207 ? $1203 : $1208;
                     $1210 = $1159 < $1211;
                     $1212 = $1210 ? $1159 : $1211;
                     $1213 = $1214 < $1198;
                     $1215 = $1213 ? $1198 : $1214;
                     $1216 = $1217 < $1203;
                     $1218 = $1216 ? $1203 : $1217;
                     $1219 = $1220 < $1159;
                     $1221 = $1219 ? $1159 : $1220;
                     $1222 = (($i2$060$i) + 1)|0;
                     $1223 = ($1222>>>0)<($1184>>>0);
                     if ($1223) {
                      $1205 = $1206;$1208 = $1209;$1211 = $1212;$1214 = $1215;$1217 = $1218;$1220 = $1221;$i2$060$i = $1222;
                     } else {
                      $$lcssa$i = $1221;$$lcssa55$i = $1218;$$lcssa56$i = $1215;$$lcssa57$i = $1212;$$lcssa58$i = $1209;$$lcssa59$i = $1206;$$pre102$i = $1174;$$pre104$i = $1180;$$pre94$i = $1176;$$pre97$i = $1172;$$pre99$i = $1178;
                      break;
                     }
                    }
                   }
                   $1224 = Math_fround($$lcssa56$i - $$lcssa59$i);
                   $1225 = Math_fround($$lcssa55$i - $$lcssa58$i);
                   $1370 = $$lcssa59$i;$1371 = $$lcssa56$i;$1373 = $$lcssa58$i;$1374 = $$lcssa55$i;$1376 = $$lcssa57$i;$1377 = $$lcssa$i;$1382 = $1224;$1384 = $1225;$1386 = $$pre$pre$i;$1388 = $$pre94$i;$1391 = $1132;$1394 = $1126;$1396 = $$pre97$i;$1398 = $$pre99$i;$1401 = $1134;$1404 = $1128;$1406 = $$pre102$i;$1408 = $$pre104$i;$1411 = $1136;$1414 = $1130;
                  } else {
                   if (!($964)) {
                    $1226 = Math_fround(HEAPF32[$1118>>2]);
                    $1227 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 8|0);
                    $1228 = Math_fround(HEAPF32[$1227>>2]);
                    $1229 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 12|0);
                    $1230 = Math_fround(HEAPF32[$1229>>2]);
                    $1231 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 20|0);
                    $1232 = Math_fround(HEAPF32[$1231>>2]);
                    $1233 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 24|0);
                    $1234 = Math_fround(HEAPF32[$1233>>2]);
                    $1235 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 28|0);
                    $1236 = Math_fround(HEAPF32[$1235>>2]);
                    $1349 = $1162;$1352 = $1163;$1355 = $1164;$1358 = $1165;$1361 = $1166;$1364 = $1167;$i5$073$i = 0;
                    while(1) {
                     $1329 = (($frustumSplit$i) + (($i5$073$i*12)|0)|0);
                     $1330 = Math_fround(HEAPF32[$1329>>2]);
                     $1331 = Math_fround($1330 - $1126);
                     $1332 = ((($frustumSplit$i) + (($i5$073$i*12)|0)|0) + 4|0);
                     $1333 = Math_fround(HEAPF32[$1332>>2]);
                     $1334 = Math_fround($1333 - $1128);
                     $1335 = ((($frustumSplit$i) + (($i5$073$i*12)|0)|0) + 8|0);
                     $1336 = Math_fround(HEAPF32[$1335>>2]);
                     $1337 = Math_fround($1336 - $1130);
                     $1338 = Math_fround($1226 * $1331);
                     $1339 = Math_fround($1228 * $1334);
                     $1340 = Math_fround($1338 + $1339);
                     $1341 = Math_fround($1230 * $1337);
                     $1342 = Math_fround($1340 + $1341);
                     $1343 = Math_fround($1232 * $1331);
                     $1344 = Math_fround($1234 * $1334);
                     $1345 = Math_fround($1343 + $1344);
                     $1346 = Math_fround($1236 * $1337);
                     $1347 = Math_fround($1345 + $1346);
                     $1348 = $1342 < $1349;
                     $1350 = $1348 ? $1342 : $1349;
                     $1351 = $1347 < $1352;
                     $1353 = $1351 ? $1347 : $1352;
                     $1354 = $1159 < $1355;
                     $1356 = $1354 ? $1159 : $1355;
                     $1357 = $1358 < $1342;
                     $1359 = $1357 ? $1342 : $1358;
                     $1360 = $1361 < $1347;
                     $1362 = $1360 ? $1347 : $1361;
                     $1363 = $1364 < $1159;
                     $1365 = $1363 ? $1159 : $1364;
                     $1366 = (($i5$073$i) + 1)|0;
                     $exitcond$i77 = ($1366|0)==(8);
                     if ($exitcond$i77) {
                      break;
                     } else {
                      $1349 = $1350;$1352 = $1353;$1355 = $1356;$1358 = $1359;$1361 = $1362;$1364 = $1365;$i5$073$i = $1366;
                     }
                    }
                    $1367 = Math_fround($1359 - $1350);
                    $1368 = Math_fround($1362 - $1353);
                    $1370 = $1350;$1371 = $1359;$1373 = $1353;$1374 = $1362;$1376 = $1356;$1377 = $1365;$1382 = $1367;$1384 = $1368;$1386 = $1226;$1388 = $1232;$1391 = $1132;$1394 = $1126;$1396 = $1228;$1398 = $1234;$1401 = $1134;$1404 = $1128;$1406 = $1230;$1408 = $1236;$1411 = $1136;$1414 = $1130;
                    break;
                   }
                   HEAPF32[$sphereCenter$i>>2] = Math_fround(0.0);
                   HEAPF32[$933>>2] = Math_fround(0.0);
                   HEAPF32[$934>>2] = Math_fround(0.0);
                   __THREW__ = 0;
                   invoke_viii(1692,($frustumSplit$i|0),($sphereCenter$i|0),($radius$i|0));
                   $1237 = __THREW__; __THREW__ = 0;
                   $1238 = $1237&1;
                   if ($1238) {
                    label = 194;
                    break L223;
                   }
                   $1239 = Math_fround(HEAPF32[$934>>2]);
                   $1240 = $1239 < Math_fround(0.0);
                   if ($1240) {
                    $1241 = Math_fround(-$1239);
                    $1244 = $1241;
                   } else {
                    $1244 = $1239;
                   }
                   $1242 = Math_fround(HEAPF32[$radius$i>>2]);
                   $1243 = Math_fround($1244 + $1242);
                   $1245 = $954 < $1243;
                   $1246 = $1245 ? $954 : $1243;
                   HEAPF32[$1052>>2] = $1246;
                   __THREW__ = 0;
                   invoke_vii(2649,($7|0),($952|0));
                   $1247 = __THREW__; __THREW__ = 0;
                   $1248 = $1247&1;
                   if ($1248) {
                    label = 194;
                    break L223;
                   }
                   $1249 = Math_fround(HEAPF32[$7>>2]);
                   $1250 = Math_fround(HEAPF32[$sphereCenter$i>>2]);
                   $1251 = Math_fround($1249 * $1250);
                   $1252 = Math_fround(HEAPF32[$935>>2]);
                   $1253 = Math_fround(HEAPF32[$933>>2]);
                   $1254 = Math_fround($1252 * $1253);
                   $1255 = Math_fround($1251 + $1254);
                   $1256 = Math_fround(HEAPF32[$936>>2]);
                   $1257 = Math_fround(HEAPF32[$934>>2]);
                   $1258 = Math_fround($1256 * $1257);
                   $1259 = Math_fround($1255 + $1258);
                   $1260 = Math_fround(HEAPF32[$937>>2]);
                   $1261 = Math_fround($1260 + $1259);
                   $1262 = Math_fround(HEAPF32[$938>>2]);
                   $1263 = Math_fround($1250 * $1262);
                   $1264 = Math_fround(HEAPF32[$939>>2]);
                   $1265 = Math_fround($1253 * $1264);
                   $1266 = Math_fround($1263 + $1265);
                   $1267 = Math_fround(HEAPF32[$940>>2]);
                   $1268 = Math_fround($1257 * $1267);
                   $1269 = Math_fround($1266 + $1268);
                   $1270 = Math_fround(HEAPF32[$941>>2]);
                   $1271 = Math_fround($1270 + $1269);
                   $1272 = Math_fround(HEAPF32[$942>>2]);
                   $1273 = Math_fround($1250 * $1272);
                   $1274 = Math_fround(HEAPF32[$943>>2]);
                   $1275 = Math_fround($1253 * $1274);
                   $1276 = Math_fround($1273 + $1275);
                   $1277 = Math_fround(HEAPF32[$944>>2]);
                   $1278 = Math_fround($1257 * $1277);
                   $1279 = Math_fround($1276 + $1278);
                   $1280 = Math_fround(HEAPF32[$945>>2]);
                   $1281 = Math_fround($1280 + $1279);
                   HEAPF32[$sphereCenter$i>>2] = $1261;
                   HEAPF32[$933>>2] = $1271;
                   HEAPF32[$934>>2] = $1281;
                   $1282 = Math_fround(HEAPF32[$radius$i>>2]);
                   ;HEAP32[$950+0>>2]=HEAP32[$sphereCenter$i+0>>2]|0;HEAP32[$950+4>>2]=HEAP32[$sphereCenter$i+4>>2]|0;HEAP32[$950+8>>2]=HEAP32[$sphereCenter$i+8>>2]|0;
                   HEAPF32[$951>>2] = $1282;
                   $1283 = Math_fround(HEAPF32[$1125>>2]);
                   $1284 = Math_fround($1261 - $1283);
                   $1285 = Math_fround(HEAPF32[$1127>>2]);
                   $1286 = Math_fround($1271 - $1285);
                   $1287 = Math_fround(HEAPF32[$1129>>2]);
                   $1288 = Math_fround($1281 - $1287);
                   $1289 = Math_fround(HEAPF32[$1118>>2]);
                   $1290 = Math_fround($1284 * $1289);
                   $1291 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 8|0);
                   $1292 = Math_fround(HEAPF32[$1291>>2]);
                   $1293 = Math_fround($1286 * $1292);
                   $1294 = Math_fround($1290 + $1293);
                   $1295 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 12|0);
                   $1296 = Math_fround(HEAPF32[$1295>>2]);
                   $1297 = Math_fround($1288 * $1296);
                   $1298 = Math_fround($1294 + $1297);
                   $1299 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 20|0);
                   $1300 = Math_fround(HEAPF32[$1299>>2]);
                   $1301 = Math_fround($1284 * $1300);
                   $1302 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 24|0);
                   $1303 = Math_fround(HEAPF32[$1302>>2]);
                   $1304 = Math_fround($1286 * $1303);
                   $1305 = Math_fround($1301 + $1304);
                   $1306 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 28|0);
                   $1307 = Math_fround(HEAPF32[$1306>>2]);
                   $1308 = Math_fround($1288 * $1307);
                   $1309 = Math_fround($1305 + $1308);
                   $1310 = $1298 < $1162;
                   $1311 = $1310 ? $1298 : $1162;
                   $1312 = $1309 < $1163;
                   $1313 = $1312 ? $1309 : $1163;
                   $1314 = $1159 < $1164;
                   $1315 = $1314 ? $1159 : $1164;
                   $1316 = $1298 > $1165;
                   $1317 = $1316 ? $1298 : $1165;
                   $1318 = $1309 > $1166;
                   $1319 = $1318 ? $1309 : $1166;
                   $1320 = $1159 > $1167;
                   $1321 = $1320 ? $1159 : $1167;
                   $1322 = Math_fround($1311 - $1282);
                   $1323 = Math_fround($1313 - $1282);
                   $1324 = Math_fround($1315 - $1282);
                   $1325 = Math_fround($1282 + $1317);
                   $1326 = Math_fround($1282 + $1319);
                   $1327 = Math_fround($1321 + $1282);
                   $1328 = Math_fround($1282 * Math_fround(2.0));
                   $$pre95$i = Math_fround(HEAPF32[$1131>>2]);
                   $$pre100$i = Math_fround(HEAPF32[$1133>>2]);
                   $$pre105$i = Math_fround(HEAPF32[$1135>>2]);
                   $1370 = $1322;$1371 = $1325;$1373 = $1323;$1374 = $1326;$1376 = $1324;$1377 = $1327;$1382 = $1328;$1384 = $1328;$1386 = $1289;$1388 = $1300;$1391 = $$pre95$i;$1394 = $1283;$1396 = $1292;$1398 = $1303;$1401 = $$pre100$i;$1404 = $1285;$1406 = $1296;$1408 = $1307;$1411 = $$pre105$i;$1414 = $1287;
                  }
                 } while(0);
                 $1369 = Math_fround($1371 + $1370);
                 $1372 = Math_fround($1374 + $1373);
                 $1375 = Math_fround($1377 + $1376);
                 $1378 = Math_fround($1369 * Math_fround(0.5));
                 $1379 = Math_fround($1372 * Math_fround(0.5));
                 $1380 = Math_fround($1375 * Math_fround(0.5));
                 $1381 = Math_fround($1382 * Math_fround(0.5));
                 $1383 = Math_fround($1384 * Math_fround(0.5));
                 $1385 = Math_fround($1386 * $1378);
                 $1387 = Math_fround($1388 * $1379);
                 $1389 = Math_fround($1387 + $1385);
                 $1390 = Math_fround($1391 * $1380);
                 $1392 = Math_fround($1390 + $1389);
                 $1393 = Math_fround($1394 + $1392);
                 $1395 = Math_fround($1396 * $1378);
                 $1397 = Math_fround($1398 * $1379);
                 $1399 = Math_fround($1397 + $1395);
                 $1400 = Math_fround($1401 * $1380);
                 $1402 = Math_fround($1400 + $1399);
                 $1403 = Math_fround($1404 + $1402);
                 $1405 = Math_fround($1406 * $1378);
                 $1407 = Math_fround($1408 * $1379);
                 $1409 = Math_fround($1407 + $1405);
                 $1410 = Math_fround($1411 * $1380);
                 $1412 = Math_fround($1410 + $1409);
                 $1413 = Math_fround($1414 + $1412);
                 $1415 = Math_fround($1382 / $922);
                 $1416 = +$1415;
                 HEAPF32[$pos$i>>2] = $1393;
                 HEAPF32[$920>>2] = $1403;
                 HEAPF32[$921>>2] = $1413;
                 $1417 = Math_fround(HEAPF32[$axisX$i>>2]);
                 $1418 = +$1417;
                 $1419 = +$1393;
                 $1420 = $1418 * $1419;
                 $1421 = Math_fround(HEAPF32[$923>>2]);
                 $1422 = +$1421;
                 $1423 = +$1403;
                 $1424 = $1422 * $1423;
                 $1425 = $1420 + $1424;
                 $1426 = Math_fround(HEAPF32[$924>>2]);
                 $1427 = +$1426;
                 $1428 = +$1413;
                 $1429 = $1427 * $1428;
                 $1430 = $1429 + $1425;
                 $1431 = Math_fround(HEAPF32[$axisY$i>>2]);
                 $1432 = Math_fround(HEAPF32[$925>>2]);
                 $1433 = Math_fround(HEAPF32[$926>>2]);
                 __THREW__ = 0;
                 $1434 = (+invoke_ddd(3,(+$1430),(+$1416)));
                 $1435 = __THREW__; __THREW__ = 0;
                 $1436 = $1435&1;
                 if ($1436) {
                  label = 194;
                  break L223;
                 }
                 $1437 = Math_fround($1384 / $927);
                 $1438 = +$1437;
                 $1439 = +$1432;
                 $1440 = +$1431;
                 $1441 = +$1433;
                 $1442 = $1423 * $1439;
                 $1443 = $1440 * $1419;
                 $1444 = $1428 * $1441;
                 $1445 = $1443 + $1442;
                 $1446 = $1445 + $1444;
                 __THREW__ = 0;
                 $1447 = (+invoke_ddd(3,(+$1446),(+$1438)));
                 $1448 = __THREW__; __THREW__ = 0;
                 $1449 = $1448&1;
                 if ($1449) {
                  label = 194;
                  break L223;
                 }
                 $1450 = Math_fround($1434);
                 $1451 = Math_fround(HEAPF32[$axisX$i>>2]);
                 $1452 = Math_fround($1450 * $1451);
                 $1453 = Math_fround(HEAPF32[$923>>2]);
                 $1454 = Math_fround($1450 * $1453);
                 $1455 = Math_fround(HEAPF32[$924>>2]);
                 $1456 = Math_fround($1450 * $1455);
                 $1457 = Math_fround($1447);
                 $1458 = Math_fround(HEAPF32[$pos$i>>2]);
                 $1459 = Math_fround($1458 - $1452);
                 $1460 = Math_fround(HEAPF32[$920>>2]);
                 $1461 = Math_fround($1460 - $1454);
                 $1462 = Math_fround(HEAPF32[$921>>2]);
                 $1463 = Math_fround($1462 - $1456);
                 $1464 = Math_fround(HEAPF32[$axisY$i>>2]);
                 $1465 = Math_fround($1457 * $1464);
                 $1466 = Math_fround(HEAPF32[$925>>2]);
                 $1467 = Math_fround($1457 * $1466);
                 $1468 = Math_fround(HEAPF32[$926>>2]);
                 $1469 = Math_fround($1457 * $1468);
                 $1470 = Math_fround($1459 - $1465);
                 $1471 = Math_fround($1461 - $1467);
                 $1472 = Math_fround($1463 - $1469);
                 $1473 = Math_fround(HEAPF32[$axisZ$i>>2]);
                 $1474 = Math_fround($1161 * $1473);
                 $1475 = Math_fround(HEAPF32[$918>>2]);
                 $1476 = Math_fround($1161 * $1475);
                 $1477 = Math_fround(HEAPF32[$919>>2]);
                 $1478 = Math_fround($1161 * $1477);
                 $1479 = Math_fround($1474 * Math_fround(1.10000002384185791016));
                 $1480 = Math_fround($1476 * Math_fround(1.10000002384185791016));
                 $1481 = Math_fround($1478 * Math_fround(1.10000002384185791016));
                 $1482 = Math_fround($1470 - $1479);
                 HEAPF32[$pos$i>>2] = $1482;
                 $1483 = Math_fround($1471 - $1480);
                 HEAPF32[$920>>2] = $1483;
                 $1484 = Math_fround($1472 - $1481);
                 HEAPF32[$921>>2] = $1484;
                 HEAPF32[$1125>>2] = $1482;
                 HEAPF32[$1127>>2] = $1483;
                 HEAPF32[$1129>>2] = $1484;
                 $1485 = Math_fround($1161 * Math_fround(0.100000001490116119385));
                 $1486 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 348|0);
                 HEAPF32[$1486>>2] = $1485;
                 $1487 = Math_fround($1161 * Math_fround(2.20000004768371582031));
                 $1488 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 352|0);
                 HEAPF32[$1488>>2] = $1487;
                 $1489 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 132|0);
                 $1490 = Math_fround(-$1381);
                 $1491 = Math_fround(-$1383);
                 __THREW__ = 0;
                 (invoke_iiffffff(1,($1489|0),(+$1490),(+$1381),(+$1491),(+$1383),(+$1485),(+$1487))|0);
                 $1492 = __THREW__; __THREW__ = 0;
                 $1493 = $1492&1;
                 if ($1493) {
                  label = 194;
                  break L223;
                 }
                 $1494 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 68|0);
                 dest=$1494+0|0; src=$1118+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
                 $1495 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 100|0);
                 $1496 = Math_fround(HEAPF32[$1495>>2]);
                 $1497 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 104|0);
                 $1498 = Math_fround(HEAPF32[$1497>>2]);
                 $1499 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 108|0);
                 $1500 = Math_fround(HEAPF32[$1499>>2]);
                 $1501 = Math_fround(-$1496);
                 $1502 = Math_fround(-$1498);
                 $1503 = Math_fround(-$1500);
                 HEAPF32[$1495>>2] = $1501;
                 HEAPF32[$1497>>2] = $1502;
                 HEAPF32[$1499>>2] = $1503;
                 __THREW__ = 0;
                 (invoke_iii(2380,($1494|0),($1494|0))|0);
                 $1504 = __THREW__; __THREW__ = 0;
                 $1505 = $1504&1;
                 if ($1505) {
                  label = 194;
                  break L223;
                 }
                 dest=$texMatrix$i+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
                 HEAPF32[$texMatrix$i>>2] = Math_fround(0.5);
                 HEAPF32[$928>>2] = Math_fround(0.5);
                 HEAPF32[$929>>2] = Math_fround(0.5);
                 HEAPF32[$930>>2] = Math_fround(0.5);
                 HEAPF32[$931>>2] = Math_fround(0.5);
                 HEAPF32[$932>>2] = Math_fround(0.5);
                 $1506 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 196|0);
                 __THREW__ = 0;
                 invoke_viii(1688,($1489|0),($1494|0),($1506|0));
                 $1507 = __THREW__; __THREW__ = 0;
                 $1508 = $1507&1;
                 if ($1508) {
                  label = 194;
                  break L223;
                 }
                 __THREW__ = 0;
                 invoke_viii(1688,($texMatrix$i|0),($1506|0),($947|0));
                 $1509 = __THREW__; __THREW__ = 0;
                 $1510 = $1509&1;
                 if ($1510) {
                  label = 194;
                  break L223;
                 } else {
                  $$0$i = 1;
                 }
                }
                $1511 = HEAP32[$focusPoints$i>>2]|0;
                $1512 = ($1511|0)==(0|0);
                if ($1512) {
                 $$1$i = $$0$i;$$pre$phiZ2D = $1043;
                 break;
                }
                $1513 = HEAP32[$908>>2]|0;
                $1514 = ($1513|0)==($1511|0);
                if (!($1514)) {
                 $__new_last2$i$i$i$i$i$i = $1511;
                 $scevgep$i$i$i$i$i$i = (($1513) + -12|0);
                 $1515 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
                 $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($1515)|0);
                 $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
                 $1516 = (($uglygep3$i$i$i$i$i$i>>>0) / 12)&-1;
                 $1517 = $1516 ^ -1;
                 $scevgep4$i$i$i$i$i$i = (($1513) + (($1517*12)|0)|0);
                 HEAP32[$908>>2] = $scevgep4$i$i$i$i$i$i;
                }
                __ZdlPv($1511);
                $$1$i = $$0$i;$$pre$phiZ2D = $1043;
               } else {
                $$pre202 = (($splitIndex$1163) + 1)|0;
                $$1$i = 0;$$pre$phiZ2D = $$pre202;
               }
              } while(0);
              $1518 = (($cascades) + (($splitIndex$1163*356)|0)|0);
              $1519 = $$1$i&1;
              HEAP8[$1518>>0] = $1519;
              $1520 = (($outShadowMatrices) + ($splitIndex$1163<<6)|0);
              dest=$1520+0|0; src=$947+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
              $1521 = Math_fround(HEAPF32[$951>>2]);
              $1522 = Math_fround($1521 * $1521);
              $1523 = Math_fround(HEAPF32[$950>>2]);
              $1524 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 328|0);
              $1525 = Math_fround(HEAPF32[$1524>>2]);
              $1526 = ((($cascades) + (($splitIndex$1163*356)|0)|0) + 332|0);
              $1527 = Math_fround(HEAPF32[$1526>>2]);
              $1528 = ((($cameraData) + ($splitIndex$1163<<4)|0) + 656|0);
              HEAPF32[$1528>>2] = $1523;
              $1529 = ((($cameraData) + ($splitIndex$1163<<4)|0) + 660|0);
              HEAPF32[$1529>>2] = $1525;
              $1530 = ((($cameraData) + ($splitIndex$1163<<4)|0) + 664|0);
              HEAPF32[$1530>>2] = $1527;
              $1531 = ((($cameraData) + ($splitIndex$1163<<4)|0) + 668|0);
              HEAPF32[$1531>>2] = $1522;
              $1532 = (($tx$0164) + 1)|0;
              $1533 = ($1532|0)<($tilesX$0|0);
              if ($1533) {
               $splitIndex$1163 = $$pre$phiZ2D;$tx$0164 = $1532;
              } else {
               $splitIndex$1$lcssa = $$pre$phiZ2D;
               break;
              }
             }
            } else {
             $splitIndex$1$lcssa = $splitIndex$0171;
            }
            $1534 = (($ty$0172) + 1)|0;
            $1535 = ($1534|0)<($tilesY$0|0);
            if ($1535) {
             $splitIndex$0171 = $splitIndex$1$lcssa;$ty$0172 = $1534;
            } else {
             label = 233;
             break;
            }
           }
           if ((label|0) == 137) {
            $680 = ___cxa_find_matching_catch()|0;
            $681 = tempRet0;
            $eh$lpad$body$index16Z2D = $681;$eh$lpad$body$indexZ2D = $680;
            break L184;
           }
           else if ((label|0) == 194) {
            $1069 = ___cxa_find_matching_catch()|0;
            $1070 = tempRet0;
            $1071 = HEAP32[$focusPoints$i>>2]|0;
            $1072 = ($1071|0)==(0|0);
            if ($1072) {
             $eh$lpad$body$index16Z2D = $1070;$eh$lpad$body$indexZ2D = $1069;
             break L184;
            }
            $1073 = HEAP32[$908>>2]|0;
            $1074 = ($1073|0)==($1071|0);
            if (!($1074)) {
             $__new_last2$i$i$i$i$i1$i = $1071;
             $scevgep$i$i$i$i$i2$i = (($1073) + -12|0);
             $1075 = (0 - ($__new_last2$i$i$i$i$i1$i))|0;
             $uglygep$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i2$i) + ($1075)|0);
             $uglygep3$i$i$i$i$i5$i = $uglygep$i$i$i$i$i4$i;
             $1076 = (($uglygep3$i$i$i$i$i5$i>>>0) / 12)&-1;
             $1077 = $1076 ^ -1;
             $scevgep4$i$i$i$i$i6$i = (($1073) + (($1077*12)|0)|0);
             HEAP32[$908>>2] = $scevgep4$i$i$i$i$i6$i;
            }
            __ZdlPv($1071);
            $eh$lpad$body$index16Z2D = $1070;$eh$lpad$body$indexZ2D = $1069;
            break L184;
           }
           else if ((label|0) == 233) {
            __THREW__ = 0;
            invoke_viiiiii(106,($casters|0),($cascades|0),($splitIndex$1$lcssa|0),($lightRot|0),($lightDir|0),($cameraData|0));
            $1536 = __THREW__; __THREW__ = 0;
            $1537 = $1536&1;
            if ($1537) {
             label = 138;
             break L184;
            }
            $1538 = (($24) + 128|0);
            $1539 = (($153) + 788|0);
            $1540 = (($153) + 792|0);
            $1541 = (($153) + 796|0);
            $1542 = (($153) + 800|0);
            $1543 = (($20) + 4|0);
            $1544 = (($20) + 8|0);
            $1545 = (($20) + 12|0);
            $1546 = (($passContext) + 20|0);
            $1547 = (Math_fround(($tilesX$0|0)));
            $1548 = Math_fround(Math_fround(1.0) / $1547);
            $1549 = (Math_fround(($tilesY$0|0)));
            $1550 = Math_fround(Math_fround(1.0) / $1549);
            $1551 = (($texMatrix) + 20|0);
            $1552 = (($texMatrix) + 40|0);
            $1553 = (($texMatrix) + 48|0);
            $1554 = (($texMatrix) + 52|0);
            $1555 = (($874) + -2)|0;
            $1556 = (($887) + -2)|0;
            $1557 = (($21) + 8|0);
            $1558 = (($21) + 4|0);
            $1559 = (($21) + 12|0);
            $1560 = (($22) + 8|0);
            $1561 = (($22) + 4|0);
            $1562 = (($22) + 12|0);
            $splitIndex$2140 = 0;$ty1$0141 = 0;
            L306: while(1) {
             if ($888) {
              $1563 = (Math_fround(($ty1$0141|0)));
              $1564 = Math_fround($1563 / $1549);
              $1565 = Math_imul($ty1$0141, $887)|0;
              $1566 = (($1565) + 1)|0;
              $splitIndex$3133 = $splitIndex$2140;$tx2$0135 = 0;
              while(1) {
               $1567 = (($cascades) + (($splitIndex$3133*356)|0)|0);
               $1568 = HEAP8[$1567>>0]|0;
               $1569 = ($1568<<24>>24)==(0);
               if ($1569) {
                $1620 = (($outShadowMatrices) + ($splitIndex$3133<<6)|0);
                __THREW__ = 0;
                (invoke_ii(3230,($1620|0))|0);
                $1621 = __THREW__; __THREW__ = 0;
                $1622 = $1621&1;
                if ($1622) {
                 break L306;
                }
               } else {
                $1570 = HEAP32[$153>>2]|0;
                $1571 = (($1570) + 104|0);
                $1572 = HEAP32[$1571>>2]|0;
                $1573 = ((($cascades) + (($splitIndex$3133*356)|0)|0) + 132|0);
                __THREW__ = 0;
                invoke_vii($1572|0,($153|0),($1573|0));
                $1574 = __THREW__; __THREW__ = 0;
                $1575 = $1574&1;
                if ($1575) {
                 break L306;
                }
                $1576 = HEAP32[$153>>2]|0;
                $1577 = (($1576) + 100|0);
                $1578 = HEAP32[$1577>>2]|0;
                $1579 = ((($cascades) + (($splitIndex$3133*356)|0)|0) + 68|0);
                __THREW__ = 0;
                invoke_vii($1578|0,($153|0),($1579|0));
                $1580 = __THREW__; __THREW__ = 0;
                $1581 = $1580&1;
                if ($1581) {
                 break L306;
                }
                __THREW__ = 0;
                invoke_v(107);
                $1582 = __THREW__; __THREW__ = 0;
                $1583 = $1582&1;
                if ($1583) {
                 break L306;
                }
                $1584 = Math_fround(HEAPF32[$1538>>2]);
                $1585 = HEAP32[$153>>2]|0;
                $1586 = (($1585) + 124|0);
                $1587 = HEAP32[$1586>>2]|0;
                __THREW__ = 0;
                $1588 = (invoke_ii($1587|0,($153|0))|0);
                $1589 = __THREW__; __THREW__ = 0;
                $1590 = $1589&1;
                if ($1590) {
                 break L306;
                }
                $1591 = (($1588) + 40|0);
                $1592 = Math_fround(HEAPF32[$1591>>2]);
                $1593 = Math_fround($1592 * Math_fround(-1.0));
                $1594 = Math_fround($1584 * $1593);
                HEAPF32[$1539>>2] = $1594;
                HEAPF32[$1540>>2] = Math_fround(1.0);
                HEAPF32[$1541>>2] = Math_fround(0.0);
                HEAPF32[$1542>>2] = Math_fround(0.0);
                $1595 = ((($cascades) + (($splitIndex$3133*356)|0)|0) + 348|0);
                $1596 = Math_fround(HEAPF32[$1595>>2]);
                $1597 = ((($cascades) + (($splitIndex$3133*356)|0)|0) + 352|0);
                $1598 = Math_fround(HEAPF32[$1597>>2]);
                HEAPF32[$20>>2] = Math_fround(0.0);
                HEAPF32[$1543>>2] = $1596;
                HEAPF32[$1544>>2] = $1598;
                HEAPF32[$1545>>2] = Math_fround(0.0);
                __THREW__ = 0;
                invoke_viii(1689,($1546|0),(576168|0),($20|0));
                $1599 = __THREW__; __THREW__ = 0;
                $1600 = $1599&1;
                if ($1600) {
                 break L306;
                }
                dest=$texMatrix+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
                HEAPF32[$texMatrix>>2] = $1548;
                HEAPF32[$1551>>2] = $1550;
                HEAPF32[$1552>>2] = Math_fround(1.0);
                $1601 = (Math_fround(($tx2$0135|0)));
                $1602 = Math_fround($1601 / $1547);
                HEAPF32[$1553>>2] = $1602;
                HEAPF32[$1554>>2] = $1564;
                $1603 = ((($cascades) + (($splitIndex$3133*356)|0)|0) + 260|0);
                $1604 = (($outShadowMatrices) + ($splitIndex$3133<<6)|0);
                __THREW__ = 0;
                invoke_viii(1688,($texMatrix|0),($1603|0),($1604|0));
                $1605 = __THREW__; __THREW__ = 0;
                $1606 = $1605&1;
                if ($1606) {
                 break L306;
                }
                $1607 = HEAP32[$872>>2]|0;
                $1608 = ($1607|0)==(1);
                $1609 = HEAP32[$153>>2]|0;
                $1610 = (($1609) + 172|0);
                $1611 = HEAP32[$1610>>2]|0;
                $1612 = Math_imul($tx2$0135, $874)|0;
                if ($1608) {
                 $1613 = (($1612) + 1)|0;
                 HEAP32[$21>>2] = $1613;
                 HEAP32[$1557>>2] = $1555;
                 HEAP32[$1558>>2] = $1566;
                 HEAP32[$1559>>2] = $1556;
                 __THREW__ = 0;
                 invoke_vii($1611|0,($153|0),($21|0));
                 $1614 = __THREW__; __THREW__ = 0;
                 $1615 = $1614&1;
                 if ($1615) {
                  break L306;
                 }
                } else {
                 HEAP32[$22>>2] = $1612;
                 HEAP32[$1560>>2] = $874;
                 HEAP32[$1561>>2] = $1565;
                 HEAP32[$1562>>2] = $887;
                 __THREW__ = 0;
                 invoke_vii($1611|0,($153|0),($22|0));
                 $1616 = __THREW__; __THREW__ = 0;
                 $1617 = $1616&1;
                 if ($1617) {
                  break L306;
                 }
                }
                __THREW__ = 0;
                invoke_viiiii(93,($splitIndex$3133|0),($casters|0),($casterParts|0),($cameraData|0),($passContext|0));
                $1618 = __THREW__; __THREW__ = 0;
                $1619 = $1618&1;
                if ($1619) {
                 break L306;
                }
               }
               $1623 = (($splitIndex$3133) + 1)|0;
               $1624 = (($tx2$0135) + 1)|0;
               $1625 = ($1624|0)<($tilesX$0|0);
               if ($1625) {
                $splitIndex$3133 = $1623;$tx2$0135 = $1624;
               } else {
                $splitIndex$3$lcssa = $1623;
                break;
               }
              }
             } else {
              $splitIndex$3$lcssa = $splitIndex$2140;
             }
             $1626 = (($ty1$0141) + 1)|0;
             $1627 = ($1626|0)<($tilesY$0|0);
             if ($1627) {
              $splitIndex$2140 = $splitIndex$3$lcssa;$ty1$0141 = $1626;
             } else {
              break L189;
             }
            }
            $678 = ___cxa_find_matching_catch()|0;
            $679 = tempRet0;
            $eh$lpad$body$index16Z2D = $679;$eh$lpad$body$indexZ2D = $678;
            break L184;
           }
          } else {
           __THREW__ = 0;
           invoke_viiii(337,($314|0),0,-1,12);
           $1628 = __THREW__; __THREW__ = 0;
           $1629 = $1628&1;
           if ($1629) {
            label = 138;
            break L184;
           }
           HEAPF32[$23>>2] = Math_fround(1.0);
           $1630 = (($23) + 4|0);
           HEAPF32[$1630>>2] = Math_fround(1.0);
           $1631 = (($23) + 8|0);
           HEAPF32[$1631>>2] = Math_fround(1.0);
           $1632 = (($23) + 12|0);
           HEAPF32[$1632>>2] = Math_fround(1.0);
           __THREW__ = 0;
           invoke_viifii(3,7,($23|0),1.0,0,($passContext|0));
           $1633 = __THREW__; __THREW__ = 0;
           $1634 = $1633&1;
           if ($1634) {
            label = 138;
            break L184;
           }
           __THREW__ = 0;
           $1635 = (invoke_i(59)|0);
           $1636 = __THREW__; __THREW__ = 0;
           $1637 = $1636&1;
           if ($1637) {
            label = 138;
            break L184;
           }
           $1638 = HEAP32[$692>>2]|0;
           __THREW__ = 0;
           $1639 = (invoke_ii(3220,($1638|0))|0);
           $1640 = __THREW__; __THREW__ = 0;
           $1641 = $1640&1;
           if ($1641) {
            label = 138;
            break L184;
           }
           HEAPF32[$1>>2] = Math_fround(1.0);
           $1642 = (($1) + 4|0);
           HEAPF32[$1642>>2] = Math_fround(1.0);
           $1643 = (($1) + 8|0);
           HEAPF32[$1643>>2] = Math_fround(-1.0);
           __THREW__ = 0;
           (invoke_iii(2381,($s$i|0),($1|0))|0);
           $1644 = __THREW__; __THREW__ = 0;
           $1645 = $1644&1;
           if ($1645) {
            label = 138;
            break L184;
           }
           __THREW__ = 0;
           invoke_vii(2650,($worldToLocalMatrixNoScale$i|0),($1639|0));
           $1646 = __THREW__; __THREW__ = 0;
           $1647 = $1646&1;
           if ($1647) {
            label = 138;
            break L184;
           }
           __THREW__ = 0;
           invoke_viii(1688,($s$i|0),($worldToLocalMatrixNoScale$i|0),($0|0));
           $1648 = __THREW__; __THREW__ = 0;
           $1649 = $1648&1;
           if ($1649) {
            label = 138;
            break L184;
           }
           $1650 = (($24) + 188|0);
           $1651 = Math_fround(HEAPF32[$1650>>2]);
           $1652 = Math_fround($1651 * Math_fround(0.0399999991059303283691));
           $1653 = (($24) + 200|0);
           $1654 = Math_fround(HEAPF32[$1653>>2]);
           __THREW__ = 0;
           (invoke_iifff(2,($projMatrix$i85|0),(+$1654),(+$1652),(+$1651))|0);
           $1655 = __THREW__; __THREW__ = 0;
           $1656 = $1655&1;
           if ($1656) {
            label = 138;
            break L184;
           }
           $1657 = HEAP32[$1635>>2]|0;
           $1658 = (($1657) + 104|0);
           $1659 = HEAP32[$1658>>2]|0;
           __THREW__ = 0;
           invoke_vii($1659|0,($1635|0),($projMatrix$i85|0));
           $1660 = __THREW__; __THREW__ = 0;
           $1661 = $1660&1;
           if ($1661) {
            label = 138;
            break L184;
           }
           $1662 = HEAP32[$1635>>2]|0;
           $1663 = (($1662) + 100|0);
           $1664 = HEAP32[$1663>>2]|0;
           __THREW__ = 0;
           invoke_vii($1664|0,($1635|0),($0|0));
           $1665 = __THREW__; __THREW__ = 0;
           $1666 = $1665&1;
           if ($1666) {
            label = 138;
            break L184;
           }
           __THREW__ = 0;
           invoke_v(107);
           $1667 = __THREW__; __THREW__ = 0;
           $1668 = $1667&1;
           if ($1668) {
            label = 138;
            break L184;
           }
           $1669 = (($24) + 128|0);
           $1670 = Math_fround(HEAPF32[$1669>>2]);
           $1671 = (($1635) + 5932|0);
           $1672 = HEAP8[$1671>>0]|0;
           $1673 = ($1672<<24>>24)==(0);
           if ($1673) {
            $bias$0$i = $1670;
           } else {
            $1674 = Math_fround($1670 * Math_fround(2.0));
            $bias$0$i = $1674;
           }
           $1675 = (($1635) + 788|0);
           HEAPF32[$1675>>2] = $bias$0$i;
           $1676 = (($1635) + 792|0);
           HEAPF32[$1676>>2] = Math_fround(0.0);
           $1677 = (($1635) + 796|0);
           HEAPF32[$1677>>2] = Math_fround(0.0);
           $1678 = (($1635) + 800|0);
           HEAPF32[$1678>>2] = Math_fround(0.0);
           dest=$texMatrix$i86+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           HEAPF32[$texMatrix$i86>>2] = Math_fround(0.5);
           $1679 = (($texMatrix$i86) + 20|0);
           HEAPF32[$1679>>2] = Math_fround(0.5);
           $1680 = (($texMatrix$i86) + 40|0);
           HEAPF32[$1680>>2] = Math_fround(0.5);
           $1681 = (($texMatrix$i86) + 48|0);
           HEAPF32[$1681>>2] = Math_fround(0.5);
           $1682 = (($texMatrix$i86) + 52|0);
           HEAPF32[$1682>>2] = Math_fround(0.5);
           $1683 = (($texMatrix$i86) + 56|0);
           HEAPF32[$1683>>2] = Math_fround(0.5);
           __THREW__ = 0;
           invoke_viii(1688,($texMatrix$i86|0),($projMatrix$i85|0),($temp$i|0));
           $1684 = __THREW__; __THREW__ = 0;
           $1685 = $1684&1;
           if ($1685) {
            label = 138;
            break L184;
           }
           __THREW__ = 0;
           invoke_viii(1688,($temp$i|0),($0|0),($outShadowMatrices|0));
           $1686 = __THREW__; __THREW__ = 0;
           $1687 = $1686&1;
           if ($1687) {
            label = 138;
            break L184;
           }
           $1688 = (($passContext) + 20|0);
           HEAPF32[$2>>2] = Math_fround(0.0);
           $1689 = (($2) + 4|0);
           HEAPF32[$1689>>2] = $1652;
           $1690 = (($2) + 8|0);
           HEAPF32[$1690>>2] = $1651;
           $1691 = (($2) + 12|0);
           HEAPF32[$1691>>2] = Math_fround(0.0);
           __THREW__ = 0;
           invoke_viii(1689,($1688|0),(576168|0),($2|0));
           $1692 = __THREW__; __THREW__ = 0;
           $1693 = $1692&1;
           if ($1693) {
            label = 138;
            break L184;
           }
           __THREW__ = 0;
           invoke_viiiii(93,0,($casters|0),($casterParts|0),($cameraData|0),($passContext|0));
           $1694 = __THREW__; __THREW__ = 0;
           $1695 = $1694&1;
           if ($1695) {
            label = 138;
            break L184;
           }
          }
         } while(0);
         $1696 = HEAP32[$153>>2]|0;
         $1697 = (($1696) + 80|0);
         $1698 = HEAP32[$1697>>2]|0;
         __THREW__ = 0;
         invoke_vii($1698|0,($153|0),($748|0));
         $1699 = __THREW__; __THREW__ = 0;
         $1700 = $1699&1;
         if ($1700) {
          label = 138;
          break;
         }
         __THREW__ = 0;
         $1701 = (invoke_i(59)|0);
         $1702 = __THREW__; __THREW__ = 0;
         $1703 = $1702&1;
         if ($1703) {
          label = 122;
          break L82;
         }
         $1704 = HEAP32[$1701>>2]|0;
         $1705 = (($1704) + 84|0);
         $1706 = HEAP32[$1705>>2]|0;
         __THREW__ = 0;
         invoke_vii($1706|0,($1701|0),($647|0));
         $1707 = __THREW__; __THREW__ = 0;
         $1708 = $1707&1;
         if ($1708) {
          label = 122;
          break L82;
         } else {
          $$0 = $314;
          break L167;
         }
        }
       } while(0);
       if ((label|0) == 138) {
        $682 = ___cxa_find_matching_catch()|0;
        $683 = tempRet0;
        $eh$lpad$body$index16Z2D = $683;$eh$lpad$body$indexZ2D = $682;
       }
       __THREW__ = 0;
       $684 = (invoke_i(59)|0);
       $685 = __THREW__; __THREW__ = 0;
       $686 = $685&1;
       if ($686) {
        $1753 = ___cxa_find_matching_catch(0|0)|0;
        $1754 = tempRet0;
        ___clang_call_terminate($1753);
        // unreachable;
       }
       $687 = HEAP32[$684>>2]|0;
       $688 = (($687) + 84|0);
       $689 = HEAP32[$688>>2]|0;
       __THREW__ = 0;
       invoke_vii($689|0,($684|0),($647|0));
       $690 = __THREW__; __THREW__ = 0;
       $691 = $690&1;
       if (!($691)) {
        $$01 = $eh$lpad$body$indexZ2D;$$03 = $eh$lpad$body$index16Z2D;
        break L82;
       }
       $1753 = ___cxa_find_matching_catch(0|0)|0;
       $1754 = tempRet0;
       ___clang_call_terminate($1753);
       // unreachable;
      }
     } while(0);
     $1709 = HEAP32[$casterParts>>2]|0;
     $1710 = ($1709|0)==(0|0);
     do {
      if (!($1710)) {
       $1711 = HEAP32[$350>>2]|0;
       $1712 = ($1711|0)==($1709|0);
       if (!($1712)) {
        $__new_last2$i$i$i$i$i102 = $1709;
        $scevgep$i$i$i$i$i103 = (($1711) + -16|0);
        $1713 = (0 - ($__new_last2$i$i$i$i$i102))|0;
        $uglygep$i$i$i$i$i105 = (($scevgep$i$i$i$i$i103) + ($1713)|0);
        $uglygep3$i$i$i$i$i106 = $uglygep$i$i$i$i$i105;
        $1714 = $uglygep3$i$i$i$i$i106 >>> 4;
        $1715 = $1714 ^ -1;
        $scevgep4$i$i$i$i$i107 = (($1711) + ($1715<<4)|0);
        HEAP32[$350>>2] = $scevgep4$i$i$i$i$i107;
       }
       HEAP32[$0>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($1709|0),($$byval_copy31|0));
       $1716 = __THREW__; __THREW__ = 0;
       $1717 = $1716&1;
       if (!($1717)) {
        break;
       }
       $1718 = ___cxa_find_matching_catch()|0;
       $1719 = tempRet0;
       ___cxa_call_unexpected(($1718|0));
       // unreachable;
      }
     } while(0);
     $1720 = HEAP32[$casters>>2]|0;
     $1721 = ($1720|0)==(0|0);
     if ($1721) {
      $$1 = $$0;
      STACKTOP = sp;return ($$1|0);
     }
     $1722 = HEAP32[$348>>2]|0;
     $1723 = ($1722|0)==($1720|0);
     if (!($1723)) {
      $__new_last2$i$i$i$i$i19 = $1720;
      $scevgep$i$i$i$i$i20 = (($1722) + -24|0);
      $1724 = (0 - ($__new_last2$i$i$i$i$i19))|0;
      $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($1724)|0);
      $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
      $1725 = (($uglygep3$i$i$i$i$i23>>>0) / 24)&-1;
      $1726 = $1725 ^ -1;
      $scevgep4$i$i$i$i$i24 = (($1722) + (($1726*24)|0)|0);
      HEAP32[$348>>2] = $scevgep4$i$i$i$i$i24;
     }
     HEAP32[$projMatrix$i85>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$projMatrix$i85+0>>2]|0;
     invoke_vii(2591,($1720|0),($$byval_copy31|0));
     $1727 = __THREW__; __THREW__ = 0;
     $1728 = $1727&1;
     if ($1728) {
      $1729 = ___cxa_find_matching_catch()|0;
      $1730 = tempRet0;
      ___cxa_call_unexpected(($1729|0));
      // unreachable;
     } else {
      $$1 = $$0;
      STACKTOP = sp;return ($$1|0);
     }
    }
    else if ((label|0) == 119) {
     $633 = ___cxa_find_matching_catch()|0;
     $634 = tempRet0;
     $lpad$phi176$index = $633;$lpad$phi176$index4 = $634;
     label = 123;
     break;
    }
    else if ((label|0) == 120) {
     $635 = ___cxa_find_matching_catch()|0;
     $636 = tempRet0;
     $lpad$phi176$index = $635;$lpad$phi176$index4 = $636;
     label = 123;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 122) {
  $639 = ___cxa_find_matching_catch()|0;
  $640 = tempRet0;
  $lpad$phi176$index = $639;$lpad$phi176$index4 = $640;
  label = 123;
 }
 if ((label|0) == 123) {
  $$01 = $lpad$phi176$index;$$03 = $lpad$phi176$index4;
 }
 $1731 = HEAP32[$casterParts>>2]|0;
 $1732 = ($1731|0)==(0|0);
 if (!($1732)) {
  $1733 = HEAP32[$350>>2]|0;
  $1734 = ($1733|0)==($1731|0);
  if (!($1734)) {
   $__new_last2$i$i$i$i$i12 = $1731;
   $scevgep$i$i$i$i$i13 = (($1733) + -16|0);
   $1735 = (0 - ($__new_last2$i$i$i$i$i12))|0;
   $uglygep$i$i$i$i$i15 = (($scevgep$i$i$i$i$i13) + ($1735)|0);
   $uglygep3$i$i$i$i$i16 = $uglygep$i$i$i$i$i15;
   $1736 = $uglygep3$i$i$i$i$i16 >>> 4;
   $1737 = $1736 ^ -1;
   $scevgep4$i$i$i$i$i17 = (($1733) + ($1737<<4)|0);
   HEAP32[$350>>2] = $scevgep4$i$i$i$i$i17;
  }
  HEAP32[$16>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$16+0>>2]|0;
  invoke_vii(2591,($1731|0),($$byval_copy31|0));
  $1738 = __THREW__; __THREW__ = 0;
  $1739 = $1738&1;
  if ($1739) {
   $1740 = ___cxa_find_matching_catch()|0;
   $1741 = tempRet0;
   ___cxa_call_unexpected(($1740|0));
   // unreachable;
  }
 }
 $1742 = HEAP32[$casters>>2]|0;
 $1743 = ($1742|0)==(0|0);
 if ($1743) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $1744 = HEAP32[$348>>2]|0;
 $1745 = ($1744|0)==($1742|0);
 if (!($1745)) {
  $__new_last2$i$i$i$i$i = $1742;
  $scevgep$i$i$i$i$i = (($1744) + -24|0);
  $1746 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($1746)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $1747 = (($uglygep3$i$i$i$i$i>>>0) / 24)&-1;
  $1748 = $1747 ^ -1;
  $scevgep4$i$i$i$i$i = (($1744) + (($1748*24)|0)|0);
  HEAP32[$348>>2] = $scevgep4$i$i$i$i$i;
 }
 HEAP32[$17>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$17+0>>2]|0;
 invoke_vii(2591,($1742|0),($$byval_copy31|0));
 $1749 = __THREW__; __THREW__ = 0;
 $1750 = $1749&1;
 if ($1750) {
  $1751 = ___cxa_find_matching_catch()|0;
  $1752 = tempRet0;
  ___cxa_call_unexpected(($1751|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
 return 0|0;
}
function __ZL13RenderCastersiRK5LightRK8Vector3fS4_RNSt3__16vectorI16ShadowCasterData13stl_allocatorIS7_L18MemLabelIdentifier90ELi16EEEERNS6_I20ShadowCasterPartDataS8_ISD_LS9_90ELi16EEEERK16ShadowCameraDataRN9ShaderLab17ShaderPassContextE($splitIndex,$data,$dataParts,$cameraData,$passContext) {
 $splitIndex = $splitIndex|0;
 $data = $data|0;
 $dataParts = $dataParts|0;
 $cameraData = $cameraData|0;
 $passContext = $passContext|0;
 var $$0 = 0, $$01 = 0, $$byval_copy12 = 0, $$op$i = Math_fround(0), $$op3$i = 0, $$ph = 0, $$pre$pre$i = 0, $$pre12$pre$i = 0, $$sink$i$i = Math_fround(0), $$sink$i1$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0;
 var $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $activeCasters$0$lcssa$i = 0;
 var $activeCasters$09$i = 0, $activeCasters$15$i = 0, $activeCasters$2$i = 0, $allocPtr$0 = 0, $casterBatchRenderer = 0, $channels$07 = 0, $channels$1 = 0, $i$06$i = 0, $i$08 = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0, $lpad$phi15$index = 0, $lpad$phi15$index2 = 0, $m$04$i = 0, $matView = 0, $matWorld = 0, $or$cond = 0, $prevCustomPropsHash$09 = 0, $prevCustomPropsHash$1 = 0, $previousLodFade$05 = Math_fround(0);
 var $previousLodFade$1 = Math_fround(0), $stats = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $$byval_copy12 = sp + 216|0;
 $0 = sp;
 $1 = sp + 4|0;
 $matView = sp + 8|0;
 $matWorld = sp + 72|0;
 $2 = sp + 136|0;
 $stats = sp + 220|0;
 $casterBatchRenderer = sp + 140|0;
 $3 = (__Z12GetGfxDevicev()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 116|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 dest=$matView+0|0; src=$7+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 112|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($3)|0);
 dest=$matWorld+0|0; src=$11+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $12 = (($dataParts) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$dataParts>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = $17 | 15;
 $19 = ($18>>>0)<(2000);
 $20 = ($13|0)!=($14|0);
 if ($19) {
  if ($20) {
   $21 = STACKTOP; STACKTOP = STACKTOP + ((((1*$18)|0)+15)&-16)|0;;
   $276 = 0;$allocPtr$0 = $21;
   label = 9;
  } else {
   $276 = 0;$allocPtr$0 = 0;
   label = 9;
  }
 } else {
  if ($20) {
   $22 = HEAP32[628512>>2]|0;
   HEAP32[$2>>2] = $22;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
   $23 = (invoke_iiiiiii(102,($18|0),16,($$byval_copy12|0),0,(576840|0),409)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $$ph = 0;
    label = 7;
   } else {
    $276 = $23;$allocPtr$0 = $23;
    label = 9;
   }
  } else {
   $276 = 0;$allocPtr$0 = 0;
   label = 9;
  }
 }
 L6: do {
  if ((label|0) == 9) {
   $30 = $allocPtr$0;
   $31 = (($30) + 15)|0;
   $32 = $31 & -16;
   $33 = $32;
   $34 = 1 << $splitIndex;
   $35 = (($data) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = HEAP32[$data>>2]|0;
   $38 = ($36|0)==($37|0);
   L8: do {
    if ($38) {
     $activeCasters$0$lcssa$i = 0;
    } else {
     $39 = (($cameraData) + 76|0);
     $40 = (($cameraData) + 80|0);
     $41 = (($cameraData) + 92|0);
     $42 = (($cameraData) + 96|0);
     $43 = (($cameraData) + 108|0);
     $44 = (($cameraData) + 112|0);
     $45 = (($cameraData) + 124|0);
     $46 = (($cameraData) + 128|0);
     $286 = $36;$48 = $37;$activeCasters$09$i = 0;$i$06$i = 0;
     L10: while(1) {
      $47 = ((($48) + (($i$06$i*24)|0)|0) + 16|0);
      $49 = HEAP32[$47>>2]|0;
      $50 = $49 & $34;
      $51 = ($50|0)==(0);
      if ($51) {
       $124 = $286;$126 = $48;$activeCasters$2$i = $activeCasters$09$i;
      } else {
       $52 = ((($48) + (($i$06$i*24)|0)|0) + 8|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ((($48) + (($i$06$i*24)|0)|0) + 12|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = ($53>>>0)<($55>>>0);
       if ($56) {
        $57 = ((($48) + (($i$06$i*24)|0)|0) + 4|0);
        $58 = (($48) + (($i$06$i*24)|0)|0);
        $activeCasters$15$i = $activeCasters$09$i;$m$04$i = $53;
        while(1) {
         $59 = Math_fround(HEAPF32[$39>>2]);
         $60 = Math_fround(HEAPF32[$40>>2]);
         $61 = Math_fround(HEAPF32[$41>>2]);
         $62 = Math_fround(HEAPF32[$42>>2]);
         $63 = Math_fround(HEAPF32[$43>>2]);
         $64 = Math_fround(HEAPF32[$44>>2]);
         $65 = Math_fround(HEAPF32[$45>>2]);
         $66 = Math_fround(HEAPF32[$46>>2]);
         $67 = HEAP32[$57>>2]|0;
         $68 = Math_fround(HEAPF32[$67>>2]);
         $69 = Math_fround($59 * $68);
         $70 = (($67) + 4|0);
         $71 = Math_fround(HEAPF32[$70>>2]);
         $72 = Math_fround($61 * $71);
         $73 = Math_fround($69 + $72);
         $74 = (($67) + 8|0);
         $75 = Math_fround(HEAPF32[$74>>2]);
         $76 = Math_fround($63 * $75);
         $77 = Math_fround($73 + $76);
         $78 = Math_fround($65 + $77);
         $79 = Math_fround($60 * $68);
         $80 = Math_fround($62 * $71);
         $81 = Math_fround($79 + $80);
         $82 = Math_fround($64 * $75);
         $83 = Math_fround($81 + $82);
         $84 = Math_fround($66 + $83);
         $85 = Math_fround($78 / $84);
         $86 = $85 < Math_fround(0.0);
         $87 = $86 ? Math_fround(0.0) : $85;
         $88 = $87 > Math_fround(1.0);
         $89 = (($activeCasters$15$i) + 1)|0;
         $90 = HEAP32[$58>>2]|0;
         $91 = HEAP32[$90>>2]|0;
         $92 = HEAP32[$91>>2]|0;
         $93 = (($92) + 56|0);
         $94 = HEAP32[$93>>2]|0;
         __THREW__ = 0;
         $95 = (invoke_ii($94|0,($91|0))|0);
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          break L10;
         }
         $98 = HEAP32[$dataParts>>2]|0;
         $99 = ((($98) + ($m$04$i<<4)|0) + 12|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = (($100) + 32|0);
         $102 = HEAP32[$101>>2]|0;
         $103 = ($102|0)==(0|0);
         if ($103) {
          __THREW__ = 0;
          invoke_vi(3433,($100|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           break L10;
          }
         }
         $106 = (($100) + 136|0);
         $107 = HEAP32[$106>>2]|0;
         $$op$i = Math_fround($87 * Math_fround(16383.0));
         $108 = (~~(($$op$i))>>>0);
         $109 = $95 << 16;
         $$op3$i = $108 & 16383;
         $110 = $88 ? 16383 : $$op3$i;
         $111 = $110 | $109;
         $112 = (($33) + ($activeCasters$15$i<<4)|0);
         $113 = $112;
         $114 = $113;
         HEAP32[$114>>2] = $111;
         $115 = (($113) + 4)|0;
         $116 = $115;
         HEAP32[$116>>2] = $107;
         $117 = ((($33) + ($activeCasters$15$i<<4)|0) + 8|0);
         HEAP32[$117>>2] = $i$06$i;
         $118 = ((($33) + ($activeCasters$15$i<<4)|0) + 12|0);
         HEAP32[$118>>2] = $m$04$i;
         $119 = (($m$04$i) + 1)|0;
         $120 = HEAP32[$54>>2]|0;
         $121 = ($119>>>0)<($120>>>0);
         if ($121) {
          $activeCasters$15$i = $89;$m$04$i = $119;
         } else {
          break;
         }
        }
        $$pre$pre$i = HEAP32[$35>>2]|0;
        $$pre12$pre$i = HEAP32[$data>>2]|0;
        $124 = $$pre$pre$i;$126 = $$pre12$pre$i;$activeCasters$2$i = $89;
       } else {
        $124 = $286;$126 = $48;$activeCasters$2$i = $activeCasters$09$i;
       }
      }
      $122 = (($i$06$i) + 1)|0;
      $123 = $124;
      $125 = $126;
      $127 = (($123) - ($125))|0;
      $128 = (($127|0) / 24)&-1;
      $129 = ($122>>>0)<($128>>>0);
      if ($129) {
       $286 = $124;$48 = $126;$activeCasters$09$i = $activeCasters$2$i;$i$06$i = $122;
      } else {
       $activeCasters$0$lcssa$i = $activeCasters$2$i;
       break L8;
      }
     }
     $26 = ___cxa_find_matching_catch()|0;
     $27 = tempRet0;
     $285 = $276;$lpad$phi15$index = $26;$lpad$phi15$index2 = $27;
     label = 8;
     break L6;
    }
   } while(0);
   $130 = (($33) + ($activeCasters$0$lcssa$i<<4)|0);
   __ZNSt3__16__sortIR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEvT0_S5_T_($33,$130,$0);
   $131 = (($3) + 5544|0);
   $132 = HEAP8[$131>>0]|0;
   $133 = ($132<<24>>24)==(0);
   if (!($133)) {
    $134 = (($3) + 5400|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($135) + ($activeCasters$0$lcssa$i))|0;
    HEAP32[$134>>2] = $136;
   }
   $137 = ($activeCasters$0$lcssa$i|0)==(0);
   do {
    if (!($137)) {
     $138 = HEAP32[$3>>2]|0;
     $139 = (($138) + 644|0);
     $140 = HEAP32[$139>>2]|0;
     __THREW__ = 0;
     invoke_viff($140|0,($3|0),1.0,1.0);
     $141 = __THREW__; __THREW__ = 0;
     $142 = $141&1;
     if ($142) {
      $$ph = $276;
      label = 7;
      break L6;
     }
     __THREW__ = 0;
     invoke_viif(41,($3|0),($passContext|0),0.0);
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if ($144) {
      $$ph = $276;
      label = 7;
      break L6;
     }
     __THREW__ = 0;
     invoke_vii(2651,($casterBatchRenderer|0),($stats|0));
     $145 = __THREW__; __THREW__ = 0;
     $146 = $145&1;
     if ($146) {
      $$ph = $276;
      label = 7;
      break L6;
     }
     $147 = ($activeCasters$0$lcssa$i|0)>(0);
     L33: do {
      if ($147) {
       $186 = 1;$188 = 0;$channels$07 = 0;$i$08 = 0;$prevCustomPropsHash$09 = 0;$previousLodFade$05 = Math_fround(0.0);
       L34: while(1) {
        $148 = ((($33) + ($i$08<<4)|0) + 8|0);
        $149 = HEAP32[$148>>2]|0;
        $150 = HEAP32[$data>>2]|0;
        $151 = (($150) + (($149*24)|0)|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = HEAP32[$152>>2]|0;
        $154 = (($153) + 48|0);
        $155 = HEAP8[$154>>0]|0;
        $156 = ($155<<24>>24)==(0);
        $157 = (($153) + 49|0);
        if ($156) {
         $158 = HEAP8[$157>>0]|0;
         $159 = ($158<<24>>24)==(0);
         if (!($159)) {
          label = 29;
         }
        } else {
         label = 29;
        }
        if ((label|0) == 29) {
         label = 0;
         $160 = HEAP32[$153>>2]|0;
         $161 = (($160) + 20|0);
         $162 = HEAP32[$161>>2]|0;
         __THREW__ = 0;
         invoke_vi($162|0,($153|0));
         $163 = __THREW__; __THREW__ = 0;
         $164 = $163&1;
         if ($164) {
          break;
         }
         HEAP8[$154>>0] = 0;
         HEAP8[$157>>0] = 0;
        }
        $165 = (($153) + 52|0);
        $166 = ((($33) + ($i$08<<4)|0) + 12|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = HEAP32[$dataParts>>2]|0;
        $169 = (($33) + ($i$08<<4)|0);
        $170 = $169;
        $171 = $170;
        $172 = HEAP32[$171>>2]|0;
        $173 = (($170) + 4)|0;
        $174 = $173;
        $175 = HEAP32[$174>>2]|0;
        $176 = (($153) + 168|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = ($177|0)==(0|0);
        if ($178) {
         $191 = 0;
        } else {
         $179 = (($177) + 32|0);
         $180 = HEAP32[$179>>2]|0;
         $191 = $180;
        }
        $181 = HEAP32[$148>>2]|0;
        $182 = HEAP32[$data>>2]|0;
        $183 = ((($182) + (($181*24)|0)|0) + 20|0);
        $184 = Math_fround(HEAPF32[$183>>2]);
        $185 = ($186|0)==(0);
        $187 = ($188|0)==($175|0);
        $189 = $185 & $187;
        $190 = ($prevCustomPropsHash$09|0)==($191|0);
        $or$cond = $189 & $190;
        do {
         if ($or$cond) {
          $192 = $184 > Math_fround(0.0);
          $193 = $192&1;
          $194 = $184 < Math_fround(0.0);
          $195 = $194&1;
          $196 = (($193) - ($195))|0;
          $197 = $previousLodFade$05 > Math_fround(0.0);
          $198 = $197&1;
          $199 = $previousLodFade$05 < Math_fround(0.0);
          $200 = $199&1;
          $201 = (($198) - ($200))|0;
          $202 = ($196|0)==($201|0);
          if ($202) {
           $203 = ($196|0)<(0);
           if ($203) {
            $204 = Math_fround($184 - $previousLodFade$05);
            $205 = $204 < Math_fround(0.0);
            if ($205) {
             $206 = Math_fround(-$204);
             $208 = $206;
            } else {
             $208 = $204;
            }
            $207 = !($208 <= Math_fround(9.99999997475242707878E-7));
            if ($207) {
             label = 44;
             break;
            }
           } else {
            $209 = Math_fround($184 * Math_fround(16.0));
            $210 = !($209 >= Math_fround(0.0));
            if ($210) {
             $211 = Math_fround($209 + Math_fround(-0.999999940395355224609));
             $$sink$i1$i = $211;
            } else {
             $$sink$i1$i = $209;
            }
            $212 = (~~(($$sink$i1$i)));
            $213 = Math_fround($previousLodFade$05 * Math_fround(16.0));
            $214 = !($213 >= Math_fround(0.0));
            if ($214) {
             $215 = Math_fround($213 + Math_fround(-0.999999940395355224609));
             $$sink$i$i = $215;
            } else {
             $$sink$i$i = $213;
            }
            $216 = (~~(($$sink$i$i)));
            $217 = ($212|0)==($216|0);
            if (!($217)) {
             label = 44;
             break;
            }
           }
           $237 = ((($168) + ($167<<4)|0) + 8|0);
           $238 = HEAP32[$237>>2]|0;
           __THREW__ = 0;
           $239 = (invoke_iif(27,($238|0),(+$184))|0);
           $240 = __THREW__; __THREW__ = 0;
           $241 = $240&1;
           if ($241) {
            break L34;
           }
           if ($239) {
            __THREW__ = 0;
            invoke_vi(3398,($casterBatchRenderer|0));
            $242 = __THREW__; __THREW__ = 0;
            $243 = $242&1;
            if ($243) {
             break L34;
            } else {
             $287 = $186;$288 = $188;$channels$1 = $channels$07;$prevCustomPropsHash$1 = $prevCustomPropsHash$09;$previousLodFade$1 = $previousLodFade$05;
            }
           } else {
            $287 = $186;$288 = $188;$channels$1 = $channels$07;$prevCustomPropsHash$1 = $prevCustomPropsHash$09;$previousLodFade$1 = $previousLodFade$05;
           }
          } else {
           label = 44;
          }
         } else {
          label = 44;
         }
        } while(0);
        if ((label|0) == 44) {
         label = 0;
         __THREW__ = 0;
         invoke_vi(3398,($casterBatchRenderer|0));
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if ($219) {
          break;
         }
         __THREW__ = 0;
         invoke_viif(41,($3|0),($passContext|0),(+$184));
         $220 = __THREW__; __THREW__ = 0;
         $221 = $220&1;
         if ($221) {
          break;
         }
         $222 = ((($168) + ($167<<4)|0) + 12|0);
         $223 = HEAP32[$222>>2]|0;
         $224 = ((($168) + ($167<<4)|0) + 8|0);
         $225 = HEAP32[$224>>2]|0;
         $226 = ((($168) + ($167<<4)|0) + 4|0);
         $227 = HEAP32[$226>>2]|0;
         __THREW__ = 0;
         $228 = (invoke_iiiii(233,($223|0),($225|0),($passContext|0),($227|0))|0);
         $229 = __THREW__; __THREW__ = 0;
         $230 = $229&1;
         if ($230) {
          break;
         } else {
          $287 = 0;$288 = $175;$channels$1 = $228;$prevCustomPropsHash$1 = $191;$previousLodFade$1 = $184;
         }
        }
        $244 = ($channels$1|0)==(0|0);
        if (!($244)) {
         $245 = (($168) + ($167<<4)|0);
         $246 = HEAP32[$245>>2]|0;
         __THREW__ = 0;
         invoke_viiiii(90,($casterBatchRenderer|0),($153|0),($165|0),($246|0),($channels$1|0));
         $247 = __THREW__; __THREW__ = 0;
         $248 = $247&1;
         if ($248) {
          break;
         }
        }
        $249 = (($i$08) + 1)|0;
        $250 = ($249|0)<($activeCasters$0$lcssa$i|0);
        if ($250) {
         $186 = $287;$188 = $288;$channels$07 = $channels$1;$i$08 = $249;$prevCustomPropsHash$09 = $prevCustomPropsHash$1;$previousLodFade$05 = $previousLodFade$1;
        } else {
         label = 56;
         break L33;
        }
       }
       $231 = ___cxa_find_matching_catch()|0;
       $232 = tempRet0;
       $lpad$phi$index = $231;$lpad$phi$index7 = $232;
      } else {
       label = 56;
      }
     } while(0);
     if ((label|0) == 56) {
      __THREW__ = 0;
      invoke_vi(3398,($casterBatchRenderer|0));
      $251 = __THREW__; __THREW__ = 0;
      $252 = $251&1;
      if (!($252)) {
       $253 = HEAP32[$3>>2]|0;
       $254 = (($253) + 644|0);
       $255 = HEAP32[$254>>2]|0;
       __THREW__ = 0;
       invoke_viff($255|0,($3|0),1.0,1.0);
       $256 = __THREW__; __THREW__ = 0;
       $257 = $256&1;
       if (!($257)) {
        $258 = HEAP32[$3>>2]|0;
        $259 = (($258) + 100|0);
        $260 = HEAP32[$259>>2]|0;
        __THREW__ = 0;
        invoke_vii($260|0,($3|0),($matView|0));
        $261 = __THREW__; __THREW__ = 0;
        $262 = $261&1;
        if (!($262)) {
         $263 = HEAP32[$3>>2]|0;
         $264 = (($263) + 96|0);
         $265 = HEAP32[$264>>2]|0;
         __THREW__ = 0;
         invoke_vii($265|0,($3|0),($matWorld|0));
         $266 = __THREW__; __THREW__ = 0;
         $267 = $266&1;
         if (!($267)) {
          $268 = HEAP32[$3>>2]|0;
          $269 = (($268) + 644|0);
          $270 = HEAP32[$269>>2]|0;
          __THREW__ = 0;
          invoke_viff($270|0,($3|0),0.0,0.0);
          $271 = __THREW__; __THREW__ = 0;
          $272 = $271&1;
          if (!($272)) {
           __THREW__ = 0;
           invoke_vi(3399,($casterBatchRenderer|0));
           $273 = __THREW__; __THREW__ = 0;
           $274 = $273&1;
           if ($274) {
            $$ph = $276;
            label = 7;
            break L6;
           } else {
            break;
           }
          }
         }
        }
       }
      }
      $233 = ___cxa_find_matching_catch()|0;
      $234 = tempRet0;
      $lpad$phi$index = $233;$lpad$phi$index7 = $234;
     }
     __THREW__ = 0;
     invoke_vi(3399,($casterBatchRenderer|0));
     $235 = __THREW__; __THREW__ = 0;
     $236 = $235&1;
     if (!($236)) {
      $$0 = $lpad$phi$index;$$01 = $lpad$phi$index7;$279 = $276;
      break L6;
     }
     $283 = ___cxa_find_matching_catch(0|0)|0;
     $284 = tempRet0;
     ___clang_call_terminate($283);
     // unreachable;
    }
   } while(0);
   $275 = ($276|0)==(0|0);
   if ($275) {
    STACKTOP = sp;return;
   }
   $277 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $277;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($276,$$byval_copy12);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 7) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  $285 = $$ph;$lpad$phi15$index = $28;$lpad$phi15$index2 = $29;
  label = 8;
 }
 if ((label|0) == 8) {
  $$0 = $lpad$phi15$index;$$01 = $lpad$phi15$index2;$279 = $285;
 }
 $278 = ($279|0)==(0|0);
 if ($278) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $280 = HEAP32[628512>>2]|0;
 HEAP32[$1>>2] = $280;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($279|0),($$byval_copy12|0));
 $281 = __THREW__; __THREW__ = 0;
 $282 = $281&1;
 if ($282) {
  $283 = ___cxa_find_matching_catch(0|0)|0;
  $284 = tempRet0;
  ___clang_call_terminate($283);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __Z27ComputeScreenSpaceShadowMapRK6CameraP13RenderTextureff10ShadowTypeRN9ShaderLab17ShaderPassContextE($camera,$shadowMap,$blurWidth,$blurFade,$shadowType,$passContext) {
 $camera = $camera|0;
 $shadowMap = $shadowMap|0;
 $blurWidth = Math_fround($blurWidth);
 $blurFade = Math_fround($blurFade);
 $shadowType = $shadowType|0;
 $passContext = $passContext|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy = 0, $$not$i17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0);
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0);
 var $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0;
 var $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0;
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0);
 var $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0);
 var $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0);
 var $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = Math_fround(0), $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $clearColor = 0, $cond = 0, $notrhs$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i14 = 0, $or$cond1$i = 0, $or$cond1$i19 = 0, $or$cond3$i = 0, $params$i = 0, $storemerge$i = 0, $storemerge4$i = 0;
 var $storemerge4$i20 = 0, $storemerge5$i = 0, $storemerge5$i21 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy = sp + 184|0;
 $params$i = sp + 168|0;
 $0 = sp + 164|0;
 $1 = sp + 152|0;
 $clearColor = sp + 136|0;
 $2 = sp + 132|0;
 $3 = sp + 120|0;
 $4 = sp + 108|0;
 $5 = sp + 96|0;
 $6 = sp + 72|0;
 $7 = sp + 60|0;
 $8 = sp + 48|0;
 $9 = sp + 36|0;
 $10 = sp + 24|0;
 $11 = sp + 12|0;
 $12 = sp;
 $13 = sp + 84|0;
 $14 = (__Z12GetGfxDevicev()|0);
 $15 = HEAP32[576216>>2]|0;
 $16 = ($15|0)==(0|0);
 do {
  if ($16) {
   $17 = (__Z15GetScriptMapperv()|0);
   $18 = (__Znwj(48)|0);
   $19 = (($1) + 8|0);
   HEAP32[$19>>2] = $18;
   HEAP32[$1>>2] = 49;
   $20 = (($1) + 4|0);
   HEAP32[$20>>2] = 37;
   dest=$18+0|0; src=576224+0|0; stop=dest+37|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $21 = (($18) + 37|0);
   HEAP8[$21>>0] = 0;
   __THREW__ = 0;
   $22 = (invoke_iii(2366,($17|0),($1|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP8[$1>>0]|0;
    $26 = $25 & 1;
    $27 = ($26<<24>>24)==(0);
    if (!($27)) {
     $28 = HEAP32[$19>>2]|0;
     __ZdlPv($28);
    }
    $29 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($22,61,0)|0);
    HEAP32[576216>>2] = $29;
    break;
   }
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   $32 = HEAP8[$1>>0]|0;
   $33 = $32 & 1;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    $$01 = $30;$$02 = $31;
    ___resumeException($$01|0);
    // unreachable;
   }
   $35 = HEAP32[$19>>2]|0;
   __ZdlPv($35);
   $$01 = $30;$$02 = $31;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $36 = (Math_fround(__ZNK6Camera16GetProjectionFarEv($camera)));
 $37 = (Math_fround(__ZNK6Camera23CalculateShadowDistanceEv($camera)));
 $38 = Math_fround(Math_fround(0.20000000298023223877) / $37);
 $39 = Math_fround(Math_fround(4.0) / $37);
 $40 = Math_fround($39 * $blurFade);
 $41 = Math_fround($36 / $37);
 HEAPF32[$params$i>>2] = $38;
 $42 = (($params$i) + 4|0);
 HEAPF32[$42>>2] = $40;
 $43 = (($params$i) + 8|0);
 HEAPF32[$43>>2] = $41;
 $44 = (($params$i) + 12|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($passContext) + 20|0);
 HEAP32[$$byval_copy>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy,576848);
 $46 = HEAP32[$$byval_copy>>2]|0;
 HEAP32[$0>>2] = $46;
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($45,$0,$params$i);
 $47 = (__Z18GetQualitySettingsv()|0);
 $48 = (($47) + 40|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($47) + 24|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ((($51) + (($49*96)|0)|0) + 24|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($passContext) + 4|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 & -4065;
 $notrhs$i = ($shadowType|0)!=(0);
 $57 = ($53|0)==(1);
 $or$cond1$i = $notrhs$i & $57;
 $58 = $56 | 1024;
 $storemerge4$i = $or$cond1$i ? $58 : $56;
 $59 = $storemerge4$i | 64;
 HEAP32[$54>>2] = $59;
 $60 = HEAP8[((640792 + 249|0))>>0]|0;
 $61 = ($60<<24>>24)==(0);
 if (!($61)) {
  $62 = $storemerge4$i | 2112;
  HEAP32[$54>>2] = $62;
 }
 $63 = (__Z18GetQualitySettingsv()|0);
 $64 = (($63) + 40|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 24|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ((($67) + (($65*96)|0)|0) + 28|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)>(1);
 $71 = HEAP32[$54>>2]|0;
 $72 = $71 | 4096;
 $73 = $71 & -4097;
 $storemerge5$i = $70 ? $73 : $72;
 HEAP32[$54>>2] = $storemerge5$i;
 $74 = (__Z22GetRenderBufferManagerv()|0);
 $75 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($74,-1,-1,0,0,0,1,1)|0);
 $76 = ($75|0)==(0|0);
 if (!($76)) {
  $77 = HEAP32[$75>>2]|0;
  $78 = (($77) + 36|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_vii[$79 & 4095]($75,576264);
 }
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($75,0,-1,0);
 HEAPF32[$clearColor>>2] = Math_fround(1.0);
 $80 = (($clearColor) + 4|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 $81 = (($clearColor) + 8|0);
 HEAPF32[$81>>2] = Math_fround(1.0);
 $82 = (($clearColor) + 12|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = HEAP32[$14>>2]|0;
 $84 = (($83) + 24|0);
 $85 = HEAP32[$84>>2]|0;
 FUNCTION_TABLE_viiifi[$85 & 7]($14,1,$clearColor,Math_fround(1.0),0);
 __Z25LoadFullScreenOrthoMatrixffb(Math_fround(-1.0),Math_fround(100.0),0);
 $86 = HEAP32[576216>>2]|0;
 $87 = HEAP32[576136>>2]|0;
 HEAP32[$2>>2] = $87;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($86,$$byval_copy,$shadowMap);
 $88 = ($shadowType|0)==(2);
 if ($88) {
  $89 = (__Z16GetBuildSettingsv()|0);
  $90 = (($89) + 101|0);
  $91 = HEAP8[$90>>0]|0;
  $92 = ($91<<24>>24)==(0);
  if ($92) {
   $157 = 0;
  } else {
   $93 = (($89) + 102|0);
   $94 = HEAP8[$93>>0]|0;
   $95 = ($94<<24>>24)!=(0);
   $96 = HEAP8[((640792 + 272|0))>>0]|0;
   $97 = ($96<<24>>24)==(0);
   $or$cond$i = $95 & $97;
   if ($or$cond$i) {
    $98 = (__Z18GetQualitySettingsv()|0);
    $99 = (($98) + 40|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($98) + 24|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ((($102) + (($100*96)|0)|0) + 16|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($104|0)<(2);
    if ($105) {
     $157 = 0;
    } else {
     $106 = (Math_fround(__ZN15QualitySettings29GetShadowDistanceForRenderingEv()));
     $107 = !($106 > Math_fround(0.0));
     $108 = HEAP32[((640792 + 68|0))>>2]|0;
     $109 = ($108|0)<(30);
     $or$cond = $107 | $109;
     if ($or$cond) {
      $157 = 0;
     } else {
      $110 = (__Z18GetQualitySettingsv()|0);
      $111 = (($110) + 40|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = (($110) + 24|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = ((($114) + (($112*96)|0)|0) + 32|0);
      $116 = HEAP32[$115>>2]|0;
      $cond = ($116|0)==(2);
      if ($cond) {
       $117 = (__Znwj(16)|0);
       $118 = (($3) + 8|0);
       HEAP32[$118>>2] = $117;
       HEAP32[$3>>2] = 17;
       $119 = (($3) + 4|0);
       HEAP32[$119>>2] = 15;
       dest=$117+0|0; src=576288+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $120 = (($117) + 15|0);
       HEAP8[$120>>0] = 0;
       __THREW__ = 0;
       $121 = (invoke_ii(3224,($3|0))|0);
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if ($123) {
        $144 = ___cxa_find_matching_catch()|0;
        $145 = tempRet0;
        $146 = HEAP8[$3>>0]|0;
        $147 = $146 & 1;
        $148 = ($147<<24>>24)==(0);
        if ($148) {
         $$01 = $144;$$02 = $145;
         ___resumeException($$01|0);
         // unreachable;
        }
        $149 = HEAP32[$118>>2]|0;
        __ZdlPv($149);
        $$01 = $144;$$02 = $145;
        ___resumeException($$01|0);
        // unreachable;
       }
       $124 = HEAP8[$3>>0]|0;
       $125 = $124 & 1;
       $126 = ($125<<24>>24)==(0);
       if (!($126)) {
        $127 = HEAP32[$118>>2]|0;
        __ZdlPv($127);
       }
       HEAP8[$4>>0] = 14;
       $128 = (($4) + 1|0);
       ;HEAP8[$128+0>>0]=HEAP8[576304+0>>0]|0;HEAP8[$128+1>>0]=HEAP8[576304+1>>0]|0;HEAP8[$128+2>>0]=HEAP8[576304+2>>0]|0;HEAP8[$128+3>>0]=HEAP8[576304+3>>0]|0;HEAP8[$128+4>>0]=HEAP8[576304+4>>0]|0;HEAP8[$128+5>>0]=HEAP8[576304+5>>0]|0;HEAP8[$128+6>>0]=HEAP8[576304+6>>0]|0;
       $129 = (($4) + 8|0);
       HEAP8[$129>>0] = 0;
       __THREW__ = 0;
       $130 = (invoke_ii(3224,($4|0))|0);
       $131 = __THREW__; __THREW__ = 0;
       $132 = $131&1;
       if ($132) {
        $150 = ___cxa_find_matching_catch()|0;
        $151 = tempRet0;
        $152 = HEAP8[$4>>0]|0;
        $153 = $152 & 1;
        $154 = ($153<<24>>24)==(0);
        if ($154) {
         $$01 = $150;$$02 = $151;
         ___resumeException($$01|0);
         // unreachable;
        }
        $155 = HEAP32[$129>>2]|0;
        __ZdlPv($155);
        $$01 = $150;$$02 = $151;
        ___resumeException($$01|0);
        // unreachable;
       }
       $133 = HEAP8[$4>>0]|0;
       $134 = $133 & 1;
       $135 = ($134<<24>>24)==(0);
       if (!($135)) {
        $136 = HEAP32[$129>>2]|0;
        __ZdlPv($136);
       }
       $137 = HEAP32[576216>>2]|0;
       $138 = (__ZN5Unity8Material9GetShaderEv($137)|0);
       $139 = ($138|0)==(0|0);
       if ($139) {
        $142 = 0;
       } else {
        $140 = (__ZNK6Shader24GetSubShaderWithTagValueEii($138,$121,$130)|0);
        $142 = $140;
       }
       $141 = ($142|0)>(0);
       $143 = $141 ? $142 : 0;
       $157 = $143;
      } else {
       $157 = 0;
      }
     }
    }
   } else {
    $157 = 0;
   }
  }
 } else {
  $157 = 0;
 }
 $156 = HEAP32[576216>>2]|0;
 $158 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($156,0,$passContext,$157,1)|0);
 $159 = HEAP32[$14>>2]|0;
 $160 = (($159) + 580|0);
 $161 = HEAP32[$160>>2]|0;
 FUNCTION_TABLE_viii[$161 & 4095]($14,2,$158);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $162 = (($5) + 4|0);
 HEAPF32[$162>>2] = Math_fround(1.0);
 $163 = (($5) + 8|0);
 HEAPF32[$163>>2] = Math_fround(-1.0);
 (__ZN10Matrix4x4f8SetScaleERK8Vector3f($$byval_copy,$5)|0);
 $164 = (__ZNK6Camera22GetWorldToCameraMatrixEv($camera)|0);
 (__ZN10Matrix4x4fmLERKS_($$byval_copy,$164)|0);
 $165 = (Math_fround(__ZNK6Camera16GetProjectionFarEv($camera)));
 $166 = HEAP32[$14>>2]|0;
 $167 = (($166) + 576|0);
 $168 = HEAP32[$167>>2]|0;
 FUNCTION_TABLE_viifff[$168 & 3]($14,0,Math_fround(0.0),Math_fround(0.0),Math_fround(0.0));
 HEAPF32[$7>>2] = Math_fround(0.0);
 $169 = (($7) + 4|0);
 HEAPF32[$169>>2] = Math_fround(0.0);
 $170 = (($7) + 8|0);
 HEAPF32[$170>>2] = $165;
 __ZNK6Camera20ViewportToWorldPointERK8Vector3f($6,$camera,$7);
 $171 = Math_fround(HEAPF32[$$byval_copy>>2]);
 $172 = Math_fround(HEAPF32[$6>>2]);
 $173 = Math_fround($171 * $172);
 $174 = (($$byval_copy) + 16|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = (($6) + 4|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = Math_fround($175 * $177);
 $179 = Math_fround($173 + $178);
 $180 = (($$byval_copy) + 32|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = (($6) + 8|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = Math_fround($181 * $183);
 $185 = Math_fround($179 + $184);
 $186 = (($$byval_copy) + 48|0);
 $187 = Math_fround(HEAPF32[$186>>2]);
 $188 = Math_fround($187 + $185);
 $189 = (($$byval_copy) + 4|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = Math_fround($172 * $190);
 $192 = (($$byval_copy) + 20|0);
 $193 = Math_fround(HEAPF32[$192>>2]);
 $194 = Math_fround($177 * $193);
 $195 = Math_fround($191 + $194);
 $196 = (($$byval_copy) + 36|0);
 $197 = Math_fround(HEAPF32[$196>>2]);
 $198 = Math_fround($183 * $197);
 $199 = Math_fround($195 + $198);
 $200 = (($$byval_copy) + 52|0);
 $201 = Math_fround(HEAPF32[$200>>2]);
 $202 = Math_fround($201 + $199);
 $203 = (($$byval_copy) + 8|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = Math_fround($172 * $204);
 $206 = (($$byval_copy) + 24|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = Math_fround($177 * $207);
 $209 = Math_fround($205 + $208);
 $210 = (($$byval_copy) + 40|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = Math_fround($183 * $211);
 $213 = Math_fround($209 + $212);
 $214 = (($$byval_copy) + 56|0);
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = Math_fround($215 + $213);
 $217 = HEAP32[$14>>2]|0;
 $218 = (($217) + 564|0);
 $219 = HEAP32[$218>>2]|0;
 FUNCTION_TABLE_vifff[$219 & 15]($14,$188,$202,$216);
 $220 = HEAP32[$14>>2]|0;
 $221 = (($220) + 560|0);
 $222 = HEAP32[$221>>2]|0;
 FUNCTION_TABLE_vifff[$222 & 15]($14,Math_fround(0.0),Math_fround(0.0),Math_fround(0.100000001490116119385));
 $223 = HEAP32[$14>>2]|0;
 $224 = (($223) + 576|0);
 $225 = HEAP32[$224>>2]|0;
 FUNCTION_TABLE_viifff[$225 & 3]($14,0,Math_fround(1.0),Math_fround(0.0),Math_fround(0.0));
 HEAPF32[$9>>2] = Math_fround(1.0);
 $226 = (($9) + 4|0);
 HEAPF32[$226>>2] = Math_fround(0.0);
 $227 = (($9) + 8|0);
 HEAPF32[$227>>2] = $165;
 __ZNK6Camera20ViewportToWorldPointERK8Vector3f($8,$camera,$9);
 $228 = Math_fround(HEAPF32[$$byval_copy>>2]);
 $229 = Math_fround(HEAPF32[$8>>2]);
 $230 = Math_fround($228 * $229);
 $231 = Math_fround(HEAPF32[$174>>2]);
 $232 = (($8) + 4|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = Math_fround($231 * $233);
 $235 = Math_fround($230 + $234);
 $236 = Math_fround(HEAPF32[$180>>2]);
 $237 = (($8) + 8|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = Math_fround($236 * $238);
 $240 = Math_fround($235 + $239);
 $241 = Math_fround(HEAPF32[$186>>2]);
 $242 = Math_fround($241 + $240);
 $243 = Math_fround(HEAPF32[$189>>2]);
 $244 = Math_fround($229 * $243);
 $245 = Math_fround(HEAPF32[$192>>2]);
 $246 = Math_fround($233 * $245);
 $247 = Math_fround($244 + $246);
 $248 = Math_fround(HEAPF32[$196>>2]);
 $249 = Math_fround($238 * $248);
 $250 = Math_fround($247 + $249);
 $251 = Math_fround(HEAPF32[$200>>2]);
 $252 = Math_fround($251 + $250);
 $253 = Math_fround(HEAPF32[$203>>2]);
 $254 = Math_fround($229 * $253);
 $255 = Math_fround(HEAPF32[$206>>2]);
 $256 = Math_fround($233 * $255);
 $257 = Math_fround($254 + $256);
 $258 = Math_fround(HEAPF32[$210>>2]);
 $259 = Math_fround($238 * $258);
 $260 = Math_fround($257 + $259);
 $261 = Math_fround(HEAPF32[$214>>2]);
 $262 = Math_fround($261 + $260);
 $263 = HEAP32[$14>>2]|0;
 $264 = (($263) + 564|0);
 $265 = HEAP32[$264>>2]|0;
 FUNCTION_TABLE_vifff[$265 & 15]($14,$242,$252,$262);
 $266 = HEAP32[$14>>2]|0;
 $267 = (($266) + 560|0);
 $268 = HEAP32[$267>>2]|0;
 FUNCTION_TABLE_vifff[$268 & 15]($14,Math_fround(1.0),Math_fround(0.0),Math_fround(0.100000001490116119385));
 $269 = HEAP32[$14>>2]|0;
 $270 = (($269) + 576|0);
 $271 = HEAP32[$270>>2]|0;
 FUNCTION_TABLE_viifff[$271 & 3]($14,0,Math_fround(1.0),Math_fround(1.0),Math_fround(0.0));
 HEAPF32[$11>>2] = Math_fround(1.0);
 $272 = (($11) + 4|0);
 HEAPF32[$272>>2] = Math_fround(1.0);
 $273 = (($11) + 8|0);
 HEAPF32[$273>>2] = $165;
 __ZNK6Camera20ViewportToWorldPointERK8Vector3f($10,$camera,$11);
 $274 = Math_fround(HEAPF32[$$byval_copy>>2]);
 $275 = Math_fround(HEAPF32[$10>>2]);
 $276 = Math_fround($274 * $275);
 $277 = Math_fround(HEAPF32[$174>>2]);
 $278 = (($10) + 4|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = Math_fround($277 * $279);
 $281 = Math_fround($276 + $280);
 $282 = Math_fround(HEAPF32[$180>>2]);
 $283 = (($10) + 8|0);
 $284 = Math_fround(HEAPF32[$283>>2]);
 $285 = Math_fround($282 * $284);
 $286 = Math_fround($281 + $285);
 $287 = Math_fround(HEAPF32[$186>>2]);
 $288 = Math_fround($287 + $286);
 $289 = Math_fround(HEAPF32[$189>>2]);
 $290 = Math_fround($275 * $289);
 $291 = Math_fround(HEAPF32[$192>>2]);
 $292 = Math_fround($279 * $291);
 $293 = Math_fround($290 + $292);
 $294 = Math_fround(HEAPF32[$196>>2]);
 $295 = Math_fround($284 * $294);
 $296 = Math_fround($293 + $295);
 $297 = Math_fround(HEAPF32[$200>>2]);
 $298 = Math_fround($297 + $296);
 $299 = Math_fround(HEAPF32[$203>>2]);
 $300 = Math_fround($275 * $299);
 $301 = Math_fround(HEAPF32[$206>>2]);
 $302 = Math_fround($279 * $301);
 $303 = Math_fround($300 + $302);
 $304 = Math_fround(HEAPF32[$210>>2]);
 $305 = Math_fround($284 * $304);
 $306 = Math_fround($303 + $305);
 $307 = Math_fround(HEAPF32[$214>>2]);
 $308 = Math_fround($307 + $306);
 $309 = HEAP32[$14>>2]|0;
 $310 = (($309) + 564|0);
 $311 = HEAP32[$310>>2]|0;
 FUNCTION_TABLE_vifff[$311 & 15]($14,$288,$298,$308);
 $312 = HEAP32[$14>>2]|0;
 $313 = (($312) + 560|0);
 $314 = HEAP32[$313>>2]|0;
 FUNCTION_TABLE_vifff[$314 & 15]($14,Math_fround(1.0),Math_fround(1.0),Math_fround(0.100000001490116119385));
 $315 = HEAP32[$14>>2]|0;
 $316 = (($315) + 576|0);
 $317 = HEAP32[$316>>2]|0;
 FUNCTION_TABLE_viifff[$317 & 3]($14,0,Math_fround(0.0),Math_fround(1.0),Math_fround(0.0));
 HEAPF32[$13>>2] = Math_fround(0.0);
 $318 = (($13) + 4|0);
 HEAPF32[$318>>2] = Math_fround(1.0);
 $319 = (($13) + 8|0);
 HEAPF32[$319>>2] = $165;
 __ZNK6Camera20ViewportToWorldPointERK8Vector3f($12,$camera,$13);
 $320 = Math_fround(HEAPF32[$$byval_copy>>2]);
 $321 = Math_fround(HEAPF32[$12>>2]);
 $322 = Math_fround($320 * $321);
 $323 = Math_fround(HEAPF32[$174>>2]);
 $324 = (($12) + 4|0);
 $325 = Math_fround(HEAPF32[$324>>2]);
 $326 = Math_fround($323 * $325);
 $327 = Math_fround($322 + $326);
 $328 = Math_fround(HEAPF32[$180>>2]);
 $329 = (($12) + 8|0);
 $330 = Math_fround(HEAPF32[$329>>2]);
 $331 = Math_fround($328 * $330);
 $332 = Math_fround($327 + $331);
 $333 = Math_fround(HEAPF32[$186>>2]);
 $334 = Math_fround($333 + $332);
 $335 = Math_fround(HEAPF32[$189>>2]);
 $336 = Math_fround($321 * $335);
 $337 = Math_fround(HEAPF32[$192>>2]);
 $338 = Math_fround($325 * $337);
 $339 = Math_fround($336 + $338);
 $340 = Math_fround(HEAPF32[$196>>2]);
 $341 = Math_fround($330 * $340);
 $342 = Math_fround($339 + $341);
 $343 = Math_fround(HEAPF32[$200>>2]);
 $344 = Math_fround($343 + $342);
 $345 = Math_fround(HEAPF32[$203>>2]);
 $346 = Math_fround($321 * $345);
 $347 = Math_fround(HEAPF32[$206>>2]);
 $348 = Math_fround($325 * $347);
 $349 = Math_fround($346 + $348);
 $350 = Math_fround(HEAPF32[$210>>2]);
 $351 = Math_fround($330 * $350);
 $352 = Math_fround($349 + $351);
 $353 = Math_fround(HEAPF32[$214>>2]);
 $354 = Math_fround($353 + $352);
 $355 = HEAP32[$14>>2]|0;
 $356 = (($355) + 564|0);
 $357 = HEAP32[$356>>2]|0;
 FUNCTION_TABLE_vifff[$357 & 15]($14,$334,$344,$354);
 $358 = HEAP32[$14>>2]|0;
 $359 = (($358) + 560|0);
 $360 = HEAP32[$359>>2]|0;
 FUNCTION_TABLE_vifff[$360 & 15]($14,Math_fround(0.0),Math_fround(1.0),Math_fround(0.100000001490116119385));
 $361 = HEAP32[$14>>2]|0;
 $362 = (($361) + 584|0);
 $363 = HEAP32[$362>>2]|0;
 FUNCTION_TABLE_vi[$363 & 4095]($14);
 __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($74,$shadowMap);
 $364 = (__Z18GetQualitySettingsv()|0);
 $365 = (($364) + 40|0);
 $366 = HEAP32[$365>>2]|0;
 $367 = (($364) + 24|0);
 $368 = HEAP32[$367>>2]|0;
 $369 = ((($368) + (($366*96)|0)|0) + 24|0);
 $370 = HEAP32[$369>>2]|0;
 $371 = HEAP32[$54>>2]|0;
 $372 = $371 & -2593;
 $$not$i17 = ($shadowType|0)!=(2);
 $373 = $372 | 512;
 $storemerge$i = $$not$i17 ? $372 : $373;
 $374 = ($370|0)==(1);
 $or$cond1$i19 = $notrhs$i & $374;
 $375 = $storemerge$i & -3553;
 $376 = $storemerge$i | 1024;
 $storemerge4$i20 = $or$cond1$i19 ? $376 : $375;
 $377 = $storemerge4$i20 & -2529;
 $378 = $377 | 128;
 HEAP32[$54>>2] = $378;
 $379 = HEAP8[((640792 + 249|0))>>0]|0;
 $380 = ($379<<24>>24)!=(0);
 $381 = HEAP8[((640792 + 250|0))>>0]|0;
 $382 = ($381<<24>>24)==(0);
 $or$cond3$i = $380 & $382;
 if ($or$cond3$i) {
  $383 = $377 | 2176;
  HEAP32[$54>>2] = $383;
 }
 $384 = (__Z18GetQualitySettingsv()|0);
 $385 = (($384) + 40|0);
 $386 = HEAP32[$385>>2]|0;
 $387 = (($384) + 24|0);
 $388 = HEAP32[$387>>2]|0;
 $389 = ((($388) + (($386*96)|0)|0) + 28|0);
 $390 = HEAP32[$389>>2]|0;
 $391 = ($390|0)>(1);
 $392 = HEAP32[$54>>2]|0;
 $393 = $392 | 4096;
 $394 = $392 & -4097;
 $storemerge5$i21 = $391 ? $394 : $393;
 HEAP32[$54>>2] = $storemerge5$i21;
 if (!($88)) {
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 $395 = (__Z16GetBuildSettingsv()|0);
 $396 = (($395) + 101|0);
 $397 = HEAP8[$396>>0]|0;
 $398 = ($397<<24>>24)==(0);
 if ($398) {
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 $399 = (($395) + 102|0);
 $400 = HEAP8[$399>>0]|0;
 $401 = ($400<<24>>24)!=(0);
 $402 = HEAP8[((640792 + 272|0))>>0]|0;
 $403 = ($402<<24>>24)==(0);
 $or$cond$i14 = $401 & $403;
 if (!($or$cond$i14)) {
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 $404 = (__Z18GetQualitySettingsv()|0);
 $405 = (($404) + 40|0);
 $406 = HEAP32[$405>>2]|0;
 $407 = (($404) + 24|0);
 $408 = HEAP32[$407>>2]|0;
 $409 = ((($408) + (($406*96)|0)|0) + 16|0);
 $410 = HEAP32[$409>>2]|0;
 $411 = ($410|0)<(2);
 if ($411) {
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 $412 = (Math_fround(__ZN15QualitySettings29GetShadowDistanceForRenderingEv()));
 $413 = $412 > Math_fround(0.0);
 if (!($413)) {
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 $414 = (__Z18GetQualitySettingsv()|0);
 $415 = (($414) + 40|0);
 $416 = HEAP32[$415>>2]|0;
 $417 = (($414) + 24|0);
 $418 = HEAP32[$417>>2]|0;
 $419 = ((($418) + (($416*96)|0)|0) + 32|0);
 $420 = HEAP32[$419>>2]|0;
 $421 = ($420|0)==(1);
 if (!($421)) {
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 $422 = (__Z19BlurScreenShadowMapP13RenderTexture10ShadowTypefRN9ShaderLab17ShaderPassContextE($75,0,$blurWidth,$passContext)|0);
 $$0 = $422;
 STACKTOP = sp;return ($$0|0);
}
function __Z19BlurScreenShadowMapP13RenderTexture10ShadowTypefRN9ShaderLab17ShaderPassContextE($screenShadowMap,$shadowType,$blurWidth,$passContext) {
 $screenShadowMap = $screenShadowMap|0;
 $shadowType = $shadowType|0;
 $blurWidth = Math_fround($blurWidth);
 $passContext = $passContext|0;
 var $$$i = Math_fround(0), $$0 = Math_fround(0), $$0$i = Math_fround(0), $$02 = 0, $$03 = 0, $$byval_copy8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0);
 var $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0);
 var $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $clearColor = 0, $material$0 = 0;
 var $material$0$in = 0, $or$cond = 0, $preserveMVP = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0;
 $$byval_copy8 = sp + 456|0;
 $0 = sp + 452|0;
 $1 = sp + 448|0;
 $2 = sp + 444|0;
 $3 = sp + 440|0;
 $4 = sp + 436|0;
 $5 = sp + 432|0;
 $6 = sp + 428|0;
 $7 = sp + 424|0;
 $8 = sp + 412|0;
 $9 = sp + 400|0;
 $preserveMVP = sp + 208|0;
 $clearColor = sp + 192|0;
 $10 = sp + 184|0;
 $11 = sp + 168|0;
 $12 = sp + 164|0;
 $13 = sp + 56|0;
 $14 = sp;
 $15 = sp + 8|0;
 $16 = sp + 24|0;
 $17 = sp + 32|0;
 $18 = sp + 48|0;
 $19 = sp + 72|0;
 $20 = sp + 88|0;
 $21 = sp + 96|0;
 $22 = sp + 112|0;
 $23 = sp + 120|0;
 $24 = sp + 136|0;
 $25 = sp + 144|0;
 $26 = sp + 160|0;
 $27 = (($screenShadowMap) + 28|0);
 HEAP32[$27>>2] = 0;
 $28 = (__Z22GetRenderBufferManagerv()|0);
 $29 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($28,-1,-1,0,0,0,1,1)|0);
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = HEAP32[$29>>2]|0;
  $32 = (($31) + 36|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_vii[$33 & 4095]($29,576312);
 }
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($29,0,-1,12);
 $34 = (__Z12GetGfxDevicev()|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 88|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (FUNCTION_TABLE_ii[$37 & 4095]($34)|0);
 $39 = HEAP32[$34>>2]|0;
 $40 = (($39) + 84|0);
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vii[$41 & 4095]($34,0);
 __THREW__ = 0;
 $42 = (invoke_i(79)|0);
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 L4: do {
  if ($44) {
   label = 13;
  } else {
   $45 = (($42) + 80|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (Math_fround(($46|0)));
   $48 = (($42) + 84|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (Math_fround(($49|0)));
   $51 = HEAP32[576336>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    __THREW__ = 0;
    $53 = (invoke_i(80)|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 13;
     break;
    }
    __THREW__ = 0;
    $56 = (invoke_ii(2988,32)|0);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     label = 13;
     break;
    }
    $59 = (($8) + 8|0);
    HEAP32[$59>>2] = $56;
    HEAP32[$8>>2] = 33;
    $60 = (($8) + 4|0);
    HEAP32[$60>>2] = 24;
    dest=$56+0|0; src=576352+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $61 = (($56) + 24|0);
    HEAP8[$61>>0] = 0;
    __THREW__ = 0;
    $62 = (invoke_iii(2366,($53|0),($8|0))|0);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     $75 = ___cxa_find_matching_catch()|0;
     $76 = tempRet0;
     $77 = HEAP8[$8>>0]|0;
     $78 = $77 & 1;
     $79 = ($78<<24>>24)==(0);
     if ($79) {
      $$02 = $75;$$03 = $76;
      break;
     }
     $80 = HEAP32[$59>>2]|0;
     __ZdlPv($80);
     $$02 = $75;$$03 = $76;
     break;
    }
    $65 = HEAP8[$8>>0]|0;
    $66 = $65 & 1;
    $67 = ($66<<24>>24)==(0);
    if (!($67)) {
     $68 = HEAP32[$59>>2]|0;
     __ZdlPv($68);
    }
    $69 = ($62|0)==(0|0);
    if (!($69)) {
     __THREW__ = 0;
     $70 = (invoke_iiii(1539,($62|0),61,0)|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      label = 13;
      break;
     }
     HEAP32[576336>>2] = $70;
    }
   }
   $81 = HEAP32[576344>>2]|0;
   $82 = ($81|0)==(0|0);
   do {
    if ($82) {
     __THREW__ = 0;
     $83 = (invoke_i(80)|0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if ($85) {
      label = 13;
      break L4;
     }
     __THREW__ = 0;
     $86 = (invoke_ii(2988,32)|0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 13;
      break L4;
     }
     $89 = (($9) + 8|0);
     HEAP32[$89>>2] = $86;
     HEAP32[$9>>2] = 33;
     $90 = (($9) + 4|0);
     HEAP32[$90>>2] = 31;
     dest=$86+0|0; src=576384+0|0; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $91 = (($86) + 31|0);
     HEAP8[$91>>0] = 0;
     __THREW__ = 0;
     $92 = (invoke_iii(2366,($83|0),($9|0))|0);
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      $103 = ___cxa_find_matching_catch()|0;
      $104 = tempRet0;
      $105 = HEAP8[$9>>0]|0;
      $106 = $105 & 1;
      $107 = ($106<<24>>24)==(0);
      if ($107) {
       $$02 = $103;$$03 = $104;
       break L4;
      }
      $108 = HEAP32[$89>>2]|0;
      __ZdlPv($108);
      $$02 = $103;$$03 = $104;
      break L4;
     }
     $95 = HEAP8[$9>>0]|0;
     $96 = $95 & 1;
     $97 = ($96<<24>>24)==(0);
     if (!($97)) {
      $98 = HEAP32[$89>>2]|0;
      __ZdlPv($98);
     }
     $99 = ($92|0)==(0|0);
     if ($99) {
      $$pre = HEAP32[576344>>2]|0;
      $112 = $$pre;
      break;
     }
     __THREW__ = 0;
     $100 = (invoke_iiii(1539,($92|0),61,0)|0);
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      label = 13;
      break L4;
     }
     HEAP32[576344>>2] = $100;
     $112 = $100;
    } else {
     $112 = $81;
    }
   } while(0);
   $109 = HEAP32[((640792 + 68|0))>>2]|0;
   $110 = ($109|0)>(29);
   $111 = ($112|0)!=(0|0);
   $or$cond = $110 & $111;
   if ($or$cond) {
    __THREW__ = 0;
    $113 = (invoke_ii(3221,($112|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     label = 13;
     break;
    }
    __THREW__ = 0;
    $116 = (invoke_ii(3231,($113|0))|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     label = 13;
     break;
    }
    if ($116) {
     $119 = Math_fround($blurWidth * Math_fround(0.800000011920928955078));
     $$0 = $119;$material$0$in = 576344;
    } else {
     $$0 = $blurWidth;$material$0$in = 576336;
    }
   } else {
    $$0 = $blurWidth;$material$0$in = 576336;
   }
   $material$0 = HEAP32[$material$0$in>>2]|0;
   $120 = HEAP8[576424>>0]|0;
   $121 = ($120<<24>>24)==(0);
   if ($121) {
    HEAP32[$7>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($7|0),(576432|0));
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if ($123) {
     label = 13;
     break;
    }
    $124 = HEAP32[$7>>2]|0;
    HEAP32[576416>>2] = $124;
    HEAP8[576424>>0] = 1;
   }
   $125 = HEAP8[576456>>0]|0;
   $126 = ($125<<24>>24)==(0);
   if ($126) {
    HEAP32[$6>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($6|0),(576464|0));
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     label = 13;
     break;
    }
    $129 = HEAP32[$6>>2]|0;
    HEAP32[576448>>2] = $129;
    HEAP8[576456>>0] = 1;
   }
   $130 = HEAP8[576488>>0]|0;
   $131 = ($130<<24>>24)==(0);
   if ($131) {
    HEAP32[$5>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($5|0),(576496|0));
    $132 = __THREW__; __THREW__ = 0;
    $133 = $132&1;
    if ($133) {
     label = 13;
     break;
    }
    $134 = HEAP32[$5>>2]|0;
    HEAP32[576480>>2] = $134;
    HEAP8[576488>>0] = 1;
   }
   $135 = HEAP8[576520>>0]|0;
   $136 = ($135<<24>>24)==(0);
   if ($136) {
    HEAP32[$4>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($4|0),(576528|0));
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if ($138) {
     label = 13;
     break;
    }
    $139 = HEAP32[$4>>2]|0;
    HEAP32[576512>>2] = $139;
    HEAP8[576520>>0] = 1;
   }
   $140 = HEAP8[576552>>0]|0;
   $141 = ($140<<24>>24)==(0);
   if ($141) {
    HEAP32[$3>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($3|0),(576560|0));
    $142 = __THREW__; __THREW__ = 0;
    $143 = $142&1;
    if ($143) {
     label = 13;
     break;
    }
    $144 = HEAP32[$3>>2]|0;
    HEAP32[576544>>2] = $144;
    HEAP8[576552>>0] = 1;
   }
   $145 = HEAP8[576584>>0]|0;
   $146 = ($145<<24>>24)==(0);
   if ($146) {
    HEAP32[$2>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($2|0),(576592|0));
    $147 = __THREW__; __THREW__ = 0;
    $148 = $147&1;
    if ($148) {
     label = 13;
     break;
    }
    $149 = HEAP32[$2>>2]|0;
    HEAP32[576576>>2] = $149;
    HEAP8[576584>>0] = 1;
   }
   $150 = HEAP8[576616>>0]|0;
   $151 = ($150<<24>>24)==(0);
   if ($151) {
    HEAP32[$1>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($1|0),(576624|0));
    $152 = __THREW__; __THREW__ = 0;
    $153 = $152&1;
    if ($153) {
     label = 13;
     break;
    }
    $154 = HEAP32[$1>>2]|0;
    HEAP32[576608>>2] = $154;
    HEAP8[576616>>0] = 1;
   }
   $155 = HEAP8[576648>>0]|0;
   $156 = ($155<<24>>24)==(0);
   if ($156) {
    HEAP32[$0>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($0|0),(576656|0));
    $157 = __THREW__; __THREW__ = 0;
    $158 = $157&1;
    if ($158) {
     label = 13;
     break;
    }
    $159 = HEAP32[$0>>2]|0;
    HEAP32[576640>>2] = $159;
    HEAP8[576648>>0] = 1;
   }
   $160 = HEAP8[576680>>0]|0;
   $161 = ($160<<24>>24)==(0);
   if ($161) {
    HEAP32[$$byval_copy8>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($$byval_copy8|0),(576688|0));
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if ($163) {
     label = 13;
     break;
    }
    $164 = HEAP32[$$byval_copy8>>2]|0;
    HEAP32[576672>>2] = $164;
    HEAP8[576680>>0] = 1;
   }
   $165 = HEAP8[576832>>0]|0;
   $166 = ($165<<24>>24)==(0);
   if ($166) {
    HEAPF32[576704>>2] = Math_fround(-0.957152009010314941406);
    HEAPF32[576712>>2] = Math_fround(-0.387798011302947998047);
    HEAPF32[576720>>2] = Math_fround(-0.799005985260009765625);
    HEAPF32[576728>>2] = Math_fround(0.953368008136749267578);
    HEAPF32[576736>>2] = Math_fround(0.94085597991943359375);
    HEAPF32[576744>>2] = Math_fround(0.726248025894165039063);
    HEAPF32[576752>>2] = Math_fround(0.599229991436004638672);
    HEAPF32[576760>>2] = Math_fround(-0.881099820137023925781);
    HEAPF32[576768>>2] = Math_fround(-0.288248002529144287109);
    HEAPF32[576776>>2] = Math_fround(-0.855525374412536621093);
    HEAPF32[576784>>2] = Math_fround(0.0387279987335205078125);
    HEAPF32[576792>>2] = Math_fround(0.890071988105773925781);
    HEAPF32[576800>>2] = Math_fround(0.954100012779235839843);
    HEAPF32[576808>>2] = Math_fround(-0.130283996462821960449);
    HEAPF32[576816>>2] = Math_fround(-0.455428004264831542969);
    HEAPF32[576824>>2] = Math_fround(0.317178010940551757813);
    HEAP8[576832>>0] = 1;
   }
   $167 = Math_fround($47 * Math_fround(0.00156250002328306436539));
   $168 = Math_fround($167 * $50);
   $169 = Math_fround($168 * Math_fround(0.00208333344198763370514));
   $170 = $169 < Math_fround(1.0);
   if ($170) {
    $$0$i = Math_fround(1.0);
   } else {
    $171 = $169 > Math_fround(2.0);
    $$$i = $171 ? Math_fround(2.0) : $169;
    $$0$i = $$$i;
   }
   $172 = Math_fround($$0 * $$0$i);
   $173 = (($screenShadowMap) + 72|0);
   $174 = Math_fround(HEAPF32[$173>>2]);
   $175 = Math_fround($172 * $174);
   $176 = (($screenShadowMap) + 76|0);
   $177 = Math_fround(HEAPF32[$176>>2]);
   $178 = Math_fround($172 * $177);
   __THREW__ = 0;
   invoke_vi(3405,($preserveMVP|0));
   $179 = __THREW__; __THREW__ = 0;
   $180 = $179&1;
   if ($180) {
    label = 13;
   } else {
    __THREW__ = 0;
    $181 = (invoke_i(59)|0);
    $182 = __THREW__; __THREW__ = 0;
    $183 = $182&1;
    do {
     if (!($183)) {
      HEAPF32[$clearColor>>2] = Math_fround(1.0);
      $184 = (($clearColor) + 4|0);
      HEAPF32[$184>>2] = Math_fround(0.0);
      $185 = (($clearColor) + 8|0);
      HEAPF32[$185>>2] = Math_fround(1.0);
      $186 = (($clearColor) + 12|0);
      HEAPF32[$186>>2] = Math_fround(0.0);
      $187 = HEAP32[$181>>2]|0;
      $188 = (($187) + 24|0);
      $189 = HEAP32[$188>>2]|0;
      __THREW__ = 0;
      invoke_viiifi($189|0,($181|0),1,($clearColor|0),1.0,0);
      $190 = __THREW__; __THREW__ = 0;
      $191 = $190&1;
      if ($191) {
       break;
      }
      __THREW__ = 0;
      invoke_vffi(1,-1.0,100.0,0);
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if ($193) {
       break;
      }
      $194 = HEAP32[576448>>2]|0;
      HEAP32[$10>>2] = $194;
      $195 = Math_fround(HEAPF32[576704>>2]);
      $196 = Math_fround($175 * $195);
      $197 = Math_fround(HEAPF32[576712>>2]);
      $198 = Math_fround($178 * $197);
      $199 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      $200 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      HEAPF32[$11>>2] = $196;
      $201 = (($11) + 4|0);
      HEAPF32[$201>>2] = $198;
      $202 = (($11) + 8|0);
      HEAPF32[$202>>2] = $199;
      $203 = (($11) + 12|0);
      HEAPF32[$203>>2] = $200;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$10+0>>2]|0;
      invoke_viii(1693,($material$0|0),($$byval_copy8|0),($11|0));
      $204 = __THREW__; __THREW__ = 0;
      $205 = $204&1;
      if ($205) {
       break;
      }
      $206 = HEAP32[576480>>2]|0;
      HEAP32[$12>>2] = $206;
      $207 = Math_fround(HEAPF32[576720>>2]);
      $208 = Math_fround($175 * $207);
      $209 = Math_fround(HEAPF32[576728>>2]);
      $210 = Math_fround($178 * $209);
      $211 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      $212 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      HEAPF32[$13>>2] = $208;
      $213 = (($13) + 4|0);
      HEAPF32[$213>>2] = $210;
      $214 = (($13) + 8|0);
      HEAPF32[$214>>2] = $211;
      $215 = (($13) + 12|0);
      HEAPF32[$215>>2] = $212;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$12+0>>2]|0;
      invoke_viii(1693,($material$0|0),($$byval_copy8|0),($13|0));
      $216 = __THREW__; __THREW__ = 0;
      $217 = $216&1;
      if ($217) {
       break;
      }
      $218 = HEAP32[576512>>2]|0;
      HEAP32[$14>>2] = $218;
      $219 = Math_fround(HEAPF32[576736>>2]);
      $220 = Math_fround($175 * $219);
      $221 = Math_fround(HEAPF32[576744>>2]);
      $222 = Math_fround($178 * $221);
      $223 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      $224 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      HEAPF32[$15>>2] = $220;
      $225 = (($15) + 4|0);
      HEAPF32[$225>>2] = $222;
      $226 = (($15) + 8|0);
      HEAPF32[$226>>2] = $223;
      $227 = (($15) + 12|0);
      HEAPF32[$227>>2] = $224;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$14+0>>2]|0;
      invoke_viii(1693,($material$0|0),($$byval_copy8|0),($15|0));
      $228 = __THREW__; __THREW__ = 0;
      $229 = $228&1;
      if ($229) {
       break;
      }
      $230 = HEAP32[576544>>2]|0;
      HEAP32[$16>>2] = $230;
      $231 = Math_fround(HEAPF32[576752>>2]);
      $232 = Math_fround($175 * $231);
      $233 = Math_fround(HEAPF32[576760>>2]);
      $234 = Math_fround($178 * $233);
      $235 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      $236 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      HEAPF32[$17>>2] = $232;
      $237 = (($17) + 4|0);
      HEAPF32[$237>>2] = $234;
      $238 = (($17) + 8|0);
      HEAPF32[$238>>2] = $235;
      $239 = (($17) + 12|0);
      HEAPF32[$239>>2] = $236;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$16+0>>2]|0;
      invoke_viii(1693,($material$0|0),($$byval_copy8|0),($17|0));
      $240 = __THREW__; __THREW__ = 0;
      $241 = $240&1;
      if ($241) {
       break;
      }
      $242 = HEAP32[576576>>2]|0;
      HEAP32[$18>>2] = $242;
      $243 = Math_fround(HEAPF32[576768>>2]);
      $244 = Math_fround($175 * $243);
      $245 = Math_fround(HEAPF32[576776>>2]);
      $246 = Math_fround($178 * $245);
      $247 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      $248 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      HEAPF32[$19>>2] = $244;
      $249 = (($19) + 4|0);
      HEAPF32[$249>>2] = $246;
      $250 = (($19) + 8|0);
      HEAPF32[$250>>2] = $247;
      $251 = (($19) + 12|0);
      HEAPF32[$251>>2] = $248;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$18+0>>2]|0;
      invoke_viii(1693,($material$0|0),($$byval_copy8|0),($19|0));
      $252 = __THREW__; __THREW__ = 0;
      $253 = $252&1;
      if ($253) {
       break;
      }
      $254 = HEAP32[576608>>2]|0;
      HEAP32[$20>>2] = $254;
      $255 = Math_fround(HEAPF32[576784>>2]);
      $256 = Math_fround($175 * $255);
      $257 = Math_fround(HEAPF32[576792>>2]);
      $258 = Math_fround($178 * $257);
      $259 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      $260 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      HEAPF32[$21>>2] = $256;
      $261 = (($21) + 4|0);
      HEAPF32[$261>>2] = $258;
      $262 = (($21) + 8|0);
      HEAPF32[$262>>2] = $259;
      $263 = (($21) + 12|0);
      HEAPF32[$263>>2] = $260;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$20+0>>2]|0;
      invoke_viii(1693,($material$0|0),($$byval_copy8|0),($21|0));
      $264 = __THREW__; __THREW__ = 0;
      $265 = $264&1;
      if ($265) {
       break;
      }
      $266 = HEAP32[576640>>2]|0;
      HEAP32[$22>>2] = $266;
      $267 = Math_fround(HEAPF32[576800>>2]);
      $268 = Math_fround($175 * $267);
      $269 = Math_fround(HEAPF32[576808>>2]);
      $270 = Math_fround($178 * $269);
      $271 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      $272 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      HEAPF32[$23>>2] = $268;
      $273 = (($23) + 4|0);
      HEAPF32[$273>>2] = $270;
      $274 = (($23) + 8|0);
      HEAPF32[$274>>2] = $271;
      $275 = (($23) + 12|0);
      HEAPF32[$275>>2] = $272;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$22+0>>2]|0;
      invoke_viii(1693,($material$0|0),($$byval_copy8|0),($23|0));
      $276 = __THREW__; __THREW__ = 0;
      $277 = $276&1;
      if ($277) {
       break;
      }
      $278 = HEAP32[576672>>2]|0;
      HEAP32[$24>>2] = $278;
      $279 = Math_fround(HEAPF32[576816>>2]);
      $280 = Math_fround($175 * $279);
      $281 = Math_fround(HEAPF32[576824>>2]);
      $282 = Math_fround($178 * $281);
      $283 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      $284 = Math_fround(Math_fround(0.0) * Math_fround(0.0));
      HEAPF32[$25>>2] = $280;
      $285 = (($25) + 4|0);
      HEAPF32[$285>>2] = $282;
      $286 = (($25) + 8|0);
      HEAPF32[$286>>2] = $283;
      $287 = (($25) + 12|0);
      HEAPF32[$287>>2] = $284;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$24+0>>2]|0;
      invoke_viii(1693,($material$0|0),($$byval_copy8|0),($25|0));
      $288 = __THREW__; __THREW__ = 0;
      $289 = $288&1;
      if ($289) {
       break;
      }
      $290 = HEAP32[576416>>2]|0;
      HEAP32[$26>>2] = $290;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$26+0>>2]|0;
      invoke_viii(1682,($material$0|0),($$byval_copy8|0),($screenShadowMap|0));
      $291 = __THREW__; __THREW__ = 0;
      $292 = $291&1;
      if ($292) {
       break;
      }
      __THREW__ = 0;
      $293 = (invoke_iiiiii(195,($material$0|0),0,($passContext|0),0,1)|0);
      $294 = __THREW__; __THREW__ = 0;
      $295 = $294&1;
      if ($295) {
       break;
      }
      $296 = HEAP32[$181>>2]|0;
      $297 = (($296) + 580|0);
      $298 = HEAP32[$297>>2]|0;
      __THREW__ = 0;
      invoke_viii($298|0,($181|0),2,($293|0));
      $299 = __THREW__; __THREW__ = 0;
      $300 = $299&1;
      if ($300) {
       break;
      }
      $301 = HEAP32[$181>>2]|0;
      $302 = (($301) + 576|0);
      $303 = HEAP32[$302>>2]|0;
      __THREW__ = 0;
      invoke_viifff($303|0,($181|0),0,0.0,0.0,0.0);
      $304 = __THREW__; __THREW__ = 0;
      $305 = $304&1;
      if ($305) {
       break;
      }
      $306 = HEAP32[$181>>2]|0;
      $307 = (($306) + 560|0);
      $308 = HEAP32[$307>>2]|0;
      __THREW__ = 0;
      invoke_vifff($308|0,($181|0),0.0,0.0,0.0);
      $309 = __THREW__; __THREW__ = 0;
      $310 = $309&1;
      if ($310) {
       break;
      }
      $311 = HEAP32[$181>>2]|0;
      $312 = (($311) + 576|0);
      $313 = HEAP32[$312>>2]|0;
      __THREW__ = 0;
      invoke_viifff($313|0,($181|0),0,1.0,0.0,0.0);
      $314 = __THREW__; __THREW__ = 0;
      $315 = $314&1;
      if ($315) {
       break;
      }
      $316 = HEAP32[$181>>2]|0;
      $317 = (($316) + 560|0);
      $318 = HEAP32[$317>>2]|0;
      __THREW__ = 0;
      invoke_vifff($318|0,($181|0),1.0,0.0,0.0);
      $319 = __THREW__; __THREW__ = 0;
      $320 = $319&1;
      if ($320) {
       break;
      }
      $321 = HEAP32[$181>>2]|0;
      $322 = (($321) + 576|0);
      $323 = HEAP32[$322>>2]|0;
      __THREW__ = 0;
      invoke_viifff($323|0,($181|0),0,1.0,1.0,0.0);
      $324 = __THREW__; __THREW__ = 0;
      $325 = $324&1;
      if ($325) {
       break;
      }
      $326 = HEAP32[$181>>2]|0;
      $327 = (($326) + 560|0);
      $328 = HEAP32[$327>>2]|0;
      __THREW__ = 0;
      invoke_vifff($328|0,($181|0),1.0,1.0,0.0);
      $329 = __THREW__; __THREW__ = 0;
      $330 = $329&1;
      if ($330) {
       break;
      }
      $331 = HEAP32[$181>>2]|0;
      $332 = (($331) + 576|0);
      $333 = HEAP32[$332>>2]|0;
      __THREW__ = 0;
      invoke_viifff($333|0,($181|0),0,0.0,1.0,0.0);
      $334 = __THREW__; __THREW__ = 0;
      $335 = $334&1;
      if ($335) {
       break;
      }
      $336 = HEAP32[$181>>2]|0;
      $337 = (($336) + 560|0);
      $338 = HEAP32[$337>>2]|0;
      __THREW__ = 0;
      invoke_vifff($338|0,($181|0),0.0,1.0,0.0);
      $339 = __THREW__; __THREW__ = 0;
      $340 = $339&1;
      if ($340) {
       break;
      }
      $341 = HEAP32[$181>>2]|0;
      $342 = (($341) + 584|0);
      $343 = HEAP32[$342>>2]|0;
      __THREW__ = 0;
      invoke_vi($343|0,($181|0));
      $344 = __THREW__; __THREW__ = 0;
      $345 = $344&1;
      if ($345) {
       break;
      }
      __THREW__ = 0;
      $346 = (invoke_i(61)|0);
      $347 = __THREW__; __THREW__ = 0;
      $348 = $347&1;
      if ($348) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(2617,($346|0),($screenShadowMap|0));
      $349 = __THREW__; __THREW__ = 0;
      $350 = $349&1;
      if ($350) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3375,($preserveMVP|0));
      $351 = __THREW__; __THREW__ = 0;
      $352 = $351&1;
      if ($352) {
       label = 13;
       break L4;
      }
      $357 = (__Z12GetGfxDevicev()|0);
      $358 = HEAP32[$357>>2]|0;
      $359 = (($358) + 84|0);
      $360 = HEAP32[$359>>2]|0;
      FUNCTION_TABLE_vii[$360 & 4095]($357,$38);
      STACKTOP = sp;return ($29|0);
     }
    } while(0);
    $353 = ___cxa_find_matching_catch()|0;
    $354 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3375,($preserveMVP|0));
    $355 = __THREW__; __THREW__ = 0;
    $356 = $355&1;
    if ($356) {
     $369 = ___cxa_find_matching_catch(0|0)|0;
     $370 = tempRet0;
     ___clang_call_terminate($369);
     // unreachable;
    } else {
     $$02 = $353;$$03 = $354;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $73 = ___cxa_find_matching_catch()|0;
  $74 = tempRet0;
  $$02 = $73;$$03 = $74;
 }
 __THREW__ = 0;
 $361 = (invoke_i(59)|0);
 $362 = __THREW__; __THREW__ = 0;
 $363 = $362&1;
 if ($363) {
  $369 = ___cxa_find_matching_catch(0|0)|0;
  $370 = tempRet0;
  ___clang_call_terminate($369);
  // unreachable;
 }
 $364 = HEAP32[$361>>2]|0;
 $365 = (($364) + 84|0);
 $366 = HEAP32[$365>>2]|0;
 __THREW__ = 0;
 invoke_vii($366|0,($361|0),($38|0));
 $367 = __THREW__; __THREW__ = 0;
 $368 = $367&1;
 if ($368) {
  $369 = ___cxa_find_matching_catch(0|0)|0;
  $370 = tempRet0;
  ___clang_call_terminate($369);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
 return 0|0;
}
function __Z29SetCascadedShadowShaderParamsPK10Matrix4x4fPKfPK8Vector4fRK8Vector2f($shadowMatrices,$splitDistances,$splitSphereCentersAndSquaredRadii,$shadowmapSize) {
 $shadowMatrices = $shadowMatrices|0;
 $splitDistances = $splitDistances|0;
 $splitSphereCentersAndSquaredRadii = $splitSphereCentersAndSquaredRadii|0;
 $shadowmapSize = $shadowmapSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($shadowMatrices) + 64|0);
 $2 = (($0) + 3108|0);
 dest=$2+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $3 = (($shadowMatrices) + 128|0);
 $4 = (($0) + 3172|0);
 dest=$4+0|0; src=$3+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = (($shadowMatrices) + 192|0);
 $6 = (($0) + 3236|0);
 dest=$6+0|0; src=$5+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $7 = Math_fround(HEAPF32[$splitDistances>>2]);
 $8 = (($splitDistances) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($splitDistances) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($splitDistances) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($0) + 804|0);
 HEAPF32[$14>>2] = $7;
 $15 = (($0) + 808|0);
 HEAPF32[$15>>2] = $9;
 $16 = (($0) + 812|0);
 HEAPF32[$16>>2] = $11;
 $17 = (($0) + 816|0);
 HEAPF32[$17>>2] = $13;
 $18 = Math_fround(HEAPF32[$8>>2]);
 $19 = Math_fround(HEAPF32[$10>>2]);
 $20 = Math_fround(HEAPF32[$12>>2]);
 $21 = (($splitDistances) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($0) + 820|0);
 HEAPF32[$23>>2] = $18;
 $24 = (($0) + 824|0);
 HEAPF32[$24>>2] = $19;
 $25 = (($0) + 828|0);
 HEAPF32[$25>>2] = $20;
 $26 = (($0) + 832|0);
 HEAPF32[$26>>2] = $22;
 $27 = (($0) + 836|0);
 ;HEAP32[$27+0>>2]=HEAP32[$splitSphereCentersAndSquaredRadii+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$splitSphereCentersAndSquaredRadii+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$splitSphereCentersAndSquaredRadii+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$splitSphereCentersAndSquaredRadii+12>>2]|0;
 $28 = (($splitSphereCentersAndSquaredRadii) + 16|0);
 $29 = (($0) + 852|0);
 ;HEAP32[$29+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$28+8>>2]|0;HEAP32[$29+12>>2]=HEAP32[$28+12>>2]|0;
 $30 = (($splitSphereCentersAndSquaredRadii) + 32|0);
 $31 = (($0) + 868|0);
 ;HEAP32[$31+0>>2]=HEAP32[$30+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$30+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$30+12>>2]|0;
 $32 = (($splitSphereCentersAndSquaredRadii) + 48|0);
 $33 = (($0) + 884|0);
 ;HEAP32[$33+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$32+12>>2]|0;
 $34 = (($splitSphereCentersAndSquaredRadii) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($splitSphereCentersAndSquaredRadii) + 28|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($splitSphereCentersAndSquaredRadii) + 44|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($splitSphereCentersAndSquaredRadii) + 60|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($0) + 900|0);
 HEAPF32[$42>>2] = $35;
 $43 = (($0) + 904|0);
 HEAPF32[$43>>2] = $37;
 $44 = (($0) + 908|0);
 HEAPF32[$44>>2] = $39;
 $45 = (($0) + 912|0);
 HEAPF32[$45>>2] = $41;
 $46 = Math_fround(HEAPF32[$shadowmapSize>>2]);
 $47 = (($shadowmapSize) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround(Math_fround(1.0) / $46);
 $50 = Math_fround(Math_fround(1.0) / $48);
 $51 = (($0) + 916|0);
 HEAPF32[$51>>2] = $46;
 $52 = (($0) + 920|0);
 HEAPF32[$52>>2] = $48;
 $53 = (($0) + 924|0);
 HEAPF32[$53>>2] = $49;
 $54 = (($0) + 928|0);
 HEAPF32[$54>>2] = $50;
 STACKTOP = sp;return;
}
function __Z16ShouldUseShadowsb($checkShadowDistance) {
 $checkShadowDistance = $checkShadowDistance|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $checkShadowDistance$not = 0, $not$ = 0, $or$cond = 0, $or$cond$i = 0, $or$cond3$i = 0, $or$cond3$i$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZN15QualitySettings29GetShadowDistanceForRenderingEv()));
 $1 = (__Z16GetBuildSettingsv()|0);
 $2 = (($1) + 101|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $22 = 0;
  STACKTOP = sp;return ($22|0);
 }
 $5 = HEAP8[((640792 + 241|0))>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $7 = HEAP8[((640792 + 245|0))>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $or$cond$i = $6 | $8;
 $9 = HEAP8[((640792 + 242|0))>>0]|0;
 $10 = ($9<<24>>24)==(0);
 $or$cond3$i = $or$cond$i | $10;
 $or$cond3$i$not = $or$cond3$i ^ 1;
 $11 = HEAP32[((640792 + 232|0))>>2]|0;
 $12 = ($11|0)!=(0);
 $or$cond = $12 & $or$cond3$i$not;
 if (!($or$cond)) {
  $22 = 0;
  STACKTOP = sp;return ($22|0);
 }
 $13 = (__Z18GetQualitySettingsv()|0);
 $14 = (($13) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($17) + (($15*96)|0)|0) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 $checkShadowDistance$not = $checkShadowDistance ^ 1;
 $brmerge = $20 | $checkShadowDistance$not;
 $not$ = $20 ^ 1;
 if ($brmerge) {
  $22 = $not$;
  STACKTOP = sp;return ($22|0);
 }
 $21 = $0 > Math_fround(0.0);
 $22 = $21;
 STACKTOP = sp;return ($22|0);
}
function __ZNSt3__16__sortIR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$027 = 0;
 var $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i23 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i23 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -16|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 4;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 71;
    break L1;
    break;
   }
   default: {
   }
   }
   $158 = ($3|0)<(496);
   if ($158) {
    label = 21;
    break L1;
   }
   $159 = ($3|0)>(15984);
   $160 = (($4|0) / 2)&-1;
   $161 = (($$0) + ($160<<4)|0);
   do {
    if ($159) {
     $162 = (($4|0) / 4)&-1;
     $163 = (($$0) + ($162<<4)|0);
     $$sum = (($162) + ($160))|0;
     $164 = (($$0) + ($$sum<<4)|0);
     $165 = (__ZNSt3__17__sort4IR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEjT0_S5_S5_S5_T_($$0,$163,$161,$164,0)|0);
     $166 = $1;
     $167 = $166;
     $168 = HEAP32[$167>>2]|0;
     $169 = (($166) + 4)|0;
     $170 = $169;
     $171 = HEAP32[$170>>2]|0;
     $172 = $164;
     $173 = $172;
     $174 = HEAP32[$173>>2]|0;
     $175 = (($172) + 4)|0;
     $176 = $175;
     $177 = HEAP32[$176>>2]|0;
     $178 = ($171>>>0)<($177>>>0);
     $179 = ($171|0)==($177|0);
     $180 = ($168>>>0)<($174>>>0);
     $181 = $179 & $180;
     $182 = $178 | $181;
     if (!($182)) {
      $$pre$phiZ2D = $161;$__n_swaps$0 = $165;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$164+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$164+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$164+12>>2]|0;
     ;HEAP32[$164+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$164+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$164+12>>2]=HEAP32[$1+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $183 = $164;
     $184 = $183;
     $185 = HEAP32[$184>>2]|0;
     $186 = (($183) + 4)|0;
     $187 = $186;
     $188 = HEAP32[$187>>2]|0;
     $189 = $161;
     $190 = $189;
     $191 = HEAP32[$190>>2]|0;
     $192 = (($189) + 4)|0;
     $193 = $192;
     $194 = HEAP32[$193>>2]|0;
     $195 = ($188>>>0)<($194>>>0);
     $196 = ($188|0)==($194|0);
     $197 = ($185>>>0)<($191>>>0);
     $198 = $196 & $197;
     $199 = $195 | $198;
     if (!($199)) {
      $200 = (($165) + 1)|0;
      $$pre$phiZ2D = $161;$__n_swaps$0 = $200;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$161+12>>2]|0;
     ;HEAP32[$161+0>>2]=HEAP32[$164+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$164+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$164+12>>2]|0;
     ;HEAP32[$164+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$164+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$164+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $201 = $161;
     $202 = $201;
     $203 = HEAP32[$202>>2]|0;
     $204 = (($201) + 4)|0;
     $205 = $204;
     $206 = HEAP32[$205>>2]|0;
     $207 = $163;
     $208 = $207;
     $209 = HEAP32[$208>>2]|0;
     $210 = (($207) + 4)|0;
     $211 = $210;
     $212 = HEAP32[$211>>2]|0;
     $213 = ($206>>>0)<($212>>>0);
     $214 = ($206|0)==($212|0);
     $215 = ($203>>>0)<($209>>>0);
     $216 = $214 & $215;
     $217 = $213 | $216;
     if (!($217)) {
      $218 = (($165) + 2)|0;
      $$pre$phiZ2D = $161;$__n_swaps$0 = $218;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$163+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$163+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$163+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$163+12>>2]|0;
     ;HEAP32[$163+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$163+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$161+12>>2]|0;
     ;HEAP32[$161+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $219 = $163;
     $220 = $219;
     $221 = HEAP32[$220>>2]|0;
     $222 = (($219) + 4)|0;
     $223 = $222;
     $224 = HEAP32[$223>>2]|0;
     $225 = $$0;
     $226 = $225;
     $227 = HEAP32[$226>>2]|0;
     $228 = (($225) + 4)|0;
     $229 = $228;
     $230 = HEAP32[$229>>2]|0;
     $231 = ($224>>>0)<($230>>>0);
     $232 = ($224|0)==($230|0);
     $233 = ($221>>>0)<($227>>>0);
     $234 = $232 & $233;
     $235 = $231 | $234;
     if ($235) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$163+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$163+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$163+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$163+12>>2]|0;
      ;HEAP32[$163+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$163+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $237 = (($165) + 4)|0;
      $$pre$phiZ2D = $161;$__n_swaps$0 = $237;
      break;
     } else {
      $236 = (($165) + 3)|0;
      $$pre$phiZ2D = $161;$__n_swaps$0 = $236;
      break;
     }
    } else {
     $238 = $161;
     $239 = $238;
     $240 = HEAP32[$239>>2]|0;
     $241 = (($238) + 4)|0;
     $242 = $241;
     $243 = HEAP32[$242>>2]|0;
     $244 = $$0;
     $245 = $244;
     $246 = HEAP32[$245>>2]|0;
     $247 = (($244) + 4)|0;
     $248 = $247;
     $249 = HEAP32[$248>>2]|0;
     $250 = ($243>>>0)<($249>>>0);
     $251 = ($243|0)==($249|0);
     $252 = ($240>>>0)<($246>>>0);
     $253 = $251 & $252;
     $254 = $250 | $253;
     $255 = $1;
     $256 = $255;
     $257 = HEAP32[$256>>2]|0;
     $258 = (($255) + 4)|0;
     $259 = $258;
     $260 = HEAP32[$259>>2]|0;
     $261 = ($260>>>0)<($243>>>0);
     $262 = ($260|0)==($243|0);
     $263 = ($257>>>0)<($240>>>0);
     $264 = $262 & $263;
     $265 = $261 | $264;
     if (!($254)) {
      if (!($265)) {
       $$pre$phiZ2D = $161;$__n_swaps$0 = 0;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$161+12>>2]|0;
      ;HEAP32[$161+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $266 = $161;
      $267 = $266;
      $268 = HEAP32[$267>>2]|0;
      $269 = (($266) + 4)|0;
      $270 = $269;
      $271 = HEAP32[$270>>2]|0;
      $272 = $$0;
      $273 = $272;
      $274 = HEAP32[$273>>2]|0;
      $275 = (($272) + 4)|0;
      $276 = $275;
      $277 = HEAP32[$276>>2]|0;
      $278 = ($271>>>0)<($277>>>0);
      $279 = ($271|0)==($277|0);
      $280 = ($268>>>0)<($274>>>0);
      $281 = $279 & $280;
      $282 = $278 | $281;
      if (!($282)) {
       $$pre$phiZ2D = $161;$__n_swaps$0 = 1;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$161+12>>2]|0;
      ;HEAP32[$161+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $161;$__n_swaps$0 = 2;
      break;
     }
     if ($265) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $161;$__n_swaps$0 = 1;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
     ;HEAP32[$$0+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$161+12>>2]|0;
     ;HEAP32[$161+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $283 = $1;
     $284 = $283;
     $285 = HEAP32[$284>>2]|0;
     $286 = (($283) + 4)|0;
     $287 = $286;
     $288 = HEAP32[$287>>2]|0;
     $289 = $161;
     $290 = $289;
     $291 = HEAP32[$290>>2]|0;
     $292 = (($289) + 4)|0;
     $293 = $292;
     $294 = HEAP32[$293>>2]|0;
     $295 = ($288>>>0)<($294>>>0);
     $296 = ($288|0)==($294|0);
     $297 = ($285>>>0)<($291>>>0);
     $298 = $296 & $297;
     $299 = $295 | $298;
     if ($299) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$161+12>>2]|0;
      ;HEAP32[$161+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $161;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $161;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $300 = $$0;
   $301 = $300;
   $302 = HEAP32[$301>>2]|0;
   $303 = (($300) + 4)|0;
   $304 = $303;
   $305 = HEAP32[$304>>2]|0;
   $306 = $$pre$phiZ2D;
   $307 = $306;
   $308 = HEAP32[$307>>2]|0;
   $309 = (($306) + 4)|0;
   $310 = $309;
   $311 = HEAP32[$310>>2]|0;
   $312 = ($305>>>0)<($311>>>0);
   $313 = ($305|0)==($311|0);
   $314 = ($302>>>0)<($308>>>0);
   $315 = $313 & $314;
   $316 = $312 | $315;
   do {
    if ($316) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $317 = (($__j$0) + -16|0);
      $318 = ($$0|0)==($317|0);
      if ($318) {
       break;
      }
      $377 = $317;
      $378 = $377;
      $379 = HEAP32[$378>>2]|0;
      $380 = (($377) + 4)|0;
      $381 = $380;
      $382 = HEAP32[$381>>2]|0;
      $383 = ($382>>>0)<($311>>>0);
      $384 = ($382|0)==($311|0);
      $385 = ($379>>>0)<($308>>>0);
      $386 = $384 & $385;
      $387 = $383 | $386;
      if ($387) {
       label = 54;
       break;
      } else {
       $__j$0 = $317;
      }
     }
     if ((label|0) == 54) {
      label = 0;
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$317+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$317+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$317+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$317+12>>2]|0;
      ;HEAP32[$317+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$317+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$317+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$317+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $388 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $317;$__n_swaps$3 = $388;
      break;
     }
     $319 = (($$0) + 16|0);
     $320 = $1;
     $321 = $320;
     $322 = HEAP32[$321>>2]|0;
     $323 = (($320) + 4)|0;
     $324 = $323;
     $325 = HEAP32[$324>>2]|0;
     $326 = ($305>>>0)<($325>>>0);
     $327 = ($305|0)==($325|0);
     $328 = ($302>>>0)<($322>>>0);
     $329 = $327 & $328;
     $330 = $326 | $329;
     if ($330) {
      $__i$1 = $319;
     } else {
      $331 = ($319|0)==($1|0);
      if ($331) {
       label = 71;
       break L1;
      } else {
       $__i$027 = $319;
      }
      while(1) {
       $334 = $__i$027;
       $335 = $334;
       $336 = HEAP32[$335>>2]|0;
       $337 = (($334) + 4)|0;
       $338 = $337;
       $339 = HEAP32[$338>>2]|0;
       $340 = ($305>>>0)<($339>>>0);
       $341 = ($305|0)==($339|0);
       $342 = ($302>>>0)<($336>>>0);
       $343 = $341 & $342;
       $344 = $340 | $343;
       $333 = (($__i$027) + 16|0);
       if ($344) {
        break;
       }
       $332 = ($333|0)==($1|0);
       if ($332) {
        label = 71;
        break L1;
       } else {
        $__i$027 = $333;
       }
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$027+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$027+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$027+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$027+12>>2]|0;
      ;HEAP32[$__i$027+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$027+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$027+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$027+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $__i$1 = $333;
     }
     $345 = ($__i$1|0)==($1|0);
     if ($345) {
      label = 71;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $346 = $$0;
      $347 = $346;
      $348 = HEAP32[$347>>2]|0;
      $349 = (($346) + 4)|0;
      $350 = $349;
      $351 = HEAP32[$350>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $352 = $__i$2;
       $353 = $352;
       $354 = HEAP32[$353>>2]|0;
       $355 = (($352) + 4)|0;
       $356 = $355;
       $357 = HEAP32[$356>>2]|0;
       $358 = ($351>>>0)<($357>>>0);
       $359 = ($351|0)==($357|0);
       $360 = ($348>>>0)<($354>>>0);
       $361 = $359 & $360;
       $362 = $358 | $361;
       $363 = (($__i$2) + 16|0);
       if ($362) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $363;
       }
      }
      while(1) {
       $364 = (($__j$2) + -16|0);
       $365 = $364;
       $366 = $365;
       $367 = HEAP32[$366>>2]|0;
       $368 = (($365) + 4)|0;
       $369 = $368;
       $370 = HEAP32[$369>>2]|0;
       $371 = ($351>>>0)<($370>>>0);
       $372 = ($351|0)==($370|0);
       $373 = ($348>>>0)<($367>>>0);
       $374 = $372 & $373;
       $375 = $371 | $374;
       if ($375) {
        $__j$2 = $364;
       } else {
        break;
       }
      }
      $376 = ($__i$2>>>0)<($364>>>0);
      if (!($376)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$2+12>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$364+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$364+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$364+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$364+12>>2]|0;
      ;HEAP32[$364+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$364+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$364+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$364+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $__i$2$ph = $363;$__j$1$ph = $364;
     }
    }
   } while(0);
   $389 = (($$0) + 16|0);
   $390 = ($389>>>0)<($__j$3>>>0);
   L55: do {
    if ($390) {
     $__i$3$ph = $389;$__j$4$ph = $__j$3;$__m$0$ph = $161;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $391 = $__m$0$ph;
      $392 = $391;
      $393 = HEAP32[$392>>2]|0;
      $394 = (($391) + 4)|0;
      $395 = $394;
      $396 = HEAP32[$395>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $397 = $__i$3;
       $398 = $397;
       $399 = HEAP32[$398>>2]|0;
       $400 = (($397) + 4)|0;
       $401 = $400;
       $402 = HEAP32[$401>>2]|0;
       $403 = ($402>>>0)<($396>>>0);
       $404 = ($402|0)==($396|0);
       $405 = ($399>>>0)<($393>>>0);
       $406 = $404 & $405;
       $407 = $403 | $406;
       $408 = (($__i$3) + 16|0);
       if ($407) {
        $__i$3 = $408;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $409 = (($__j$5) + -16|0);
       $410 = $409;
       $411 = $410;
       $412 = HEAP32[$411>>2]|0;
       $413 = (($410) + 4)|0;
       $414 = $413;
       $415 = HEAP32[$414>>2]|0;
       $416 = ($415>>>0)<($396>>>0);
       $417 = ($415|0)==($396|0);
       $418 = ($412>>>0)<($393>>>0);
       $419 = $417 & $418;
       $420 = $416 | $419;
       if ($420) {
        break;
       } else {
        $__j$5 = $409;
       }
      }
      $421 = ($__i$3>>>0)>($409>>>0);
      if ($421) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L55;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$3+12>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$409+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$409+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$409+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$409+12>>2]|0;
      ;HEAP32[$409+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$409+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$409+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$409+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $422 = (($__n_swaps$4$ph) + 1)|0;
      $423 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $423 ? $409 : $__m$0$ph;
      $__i$3$ph = $408;$__j$4$ph = $409;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $422;
     }
    } else {
     $__i$4 = $389;$__m$2 = $161;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $424 = ($__i$4|0)==($__m$2|0);
   if ($424) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $425 = $__m$2;
    $426 = $425;
    $427 = HEAP32[$426>>2]|0;
    $428 = (($425) + 4)|0;
    $429 = $428;
    $430 = HEAP32[$429>>2]|0;
    $431 = $__i$4;
    $432 = $431;
    $433 = HEAP32[$432>>2]|0;
    $434 = (($431) + 4)|0;
    $435 = $434;
    $436 = HEAP32[$435>>2]|0;
    $437 = ($430>>>0)<($436>>>0);
    $438 = ($430|0)==($436|0);
    $439 = ($427>>>0)<($433>>>0);
    $440 = $438 & $439;
    $441 = $437 | $440;
    if ($441) {
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$4+12>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $442 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $442;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $443 = ($__n_swaps$6|0)==(0);
   if ($443) {
    $444 = (__ZNSt3__127__insertion_sort_incompleteIR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEbT0_S5_T_($$0,$__i$4,0)|0);
    $445 = (($__i$4) + 16|0);
    $446 = (__ZNSt3__127__insertion_sort_incompleteIR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEbT0_S5_T_($445,$$01$ph,0)|0);
    if ($446) {
     label = 66;
     break;
    }
    if ($444) {
     $$0 = $445;
     continue;
    }
   }
   $447 = $__i$4;
   $448 = (($447) - ($2))|0;
   $449 = (($0) - ($447))|0;
   $450 = ($448|0)<($449|0);
   if (!($450)) {
    label = 70;
    break;
   }
   __ZNSt3__16__sortIR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEvT0_S5_T_($$0,$__i$4,$__comp);
   $451 = (($__i$4) + 16|0);
   $$0 = $451;
  }
  if ((label|0) == 66) {
   label = 0;
   if ($444) {
    label = 71;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 70) {
   label = 0;
   $452 = (($__i$4) + 16|0);
   __ZNSt3__16__sortIR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEvT0_S5_T_($452,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = $1;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) + 4)|0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = $$0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = ($10>>>0)<($16>>>0);
  $18 = ($10|0)==($16|0);
  $19 = ($7>>>0)<($13>>>0);
  $20 = $18 & $19;
  $21 = $17 | $20;
  if (!($21)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $22 = (($$0) + 16|0);
  $23 = $22;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $$0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 4)|0;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = ($28>>>0)<($34>>>0);
  $36 = ($28|0)==($34|0);
  $37 = ($25>>>0)<($31>>>0);
  $38 = $36 & $37;
  $39 = $35 | $38;
  $40 = $1;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45>>>0)<($28>>>0);
  $47 = ($45|0)==($28|0);
  $48 = ($42>>>0)<($25>>>0);
  $49 = $47 & $48;
  $50 = $46 | $49;
  if (!($39)) {
   if (!($50)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$22+12>>2]|0;
   ;HEAP32[$22+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   $51 = $22;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($51) + 4)|0;
   $55 = $54;
   $56 = HEAP32[$55>>2]|0;
   $57 = $$0;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + 4)|0;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = ($56>>>0)<($62>>>0);
   $64 = ($56|0)==($62|0);
   $65 = ($53>>>0)<($59>>>0);
   $66 = $64 & $65;
   $67 = $63 | $66;
   if (!($67)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$22+12>>2]|0;
   ;HEAP32[$22+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   STACKTOP = sp;return;
  }
  if ($50) {
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $68 = $1;
  $69 = $68;
  $70 = HEAP32[$69>>2]|0;
  $71 = (($68) + 4)|0;
  $72 = $71;
  $73 = HEAP32[$72>>2]|0;
  $74 = $22;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + 4)|0;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = ($73>>>0)<($79>>>0);
  $81 = ($73|0)==($79|0);
  $82 = ($70>>>0)<($76>>>0);
  $83 = $81 & $82;
  $84 = $80 | $83;
  if (!($84)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $85 = (($$0) + 16|0);
  $86 = (($$0) + 32|0);
  (__ZNSt3__17__sort4IR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEjT0_S5_S5_S5_T_($$0,$85,$86,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $87 = (($$0) + 16|0);
  $88 = (($$0) + 32|0);
  $89 = (($$0) + 48|0);
  (__ZNSt3__17__sort4IR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEjT0_S5_S5_S5_T_($$0,$87,$88,$89,0)|0);
  $90 = $1;
  $91 = $90;
  $92 = HEAP32[$91>>2]|0;
  $93 = (($90) + 4)|0;
  $94 = $93;
  $95 = HEAP32[$94>>2]|0;
  $96 = $89;
  $97 = $96;
  $98 = HEAP32[$97>>2]|0;
  $99 = (($96) + 4)|0;
  $100 = $99;
  $101 = HEAP32[$100>>2]|0;
  $102 = ($95>>>0)<($101>>>0);
  $103 = ($95|0)==($101|0);
  $104 = ($92>>>0)<($98>>>0);
  $105 = $103 & $104;
  $106 = $102 | $105;
  if (!($106)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$89+12>>2]|0;
  ;HEAP32[$89+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $107 = $89;
  $108 = $107;
  $109 = HEAP32[$108>>2]|0;
  $110 = (($107) + 4)|0;
  $111 = $110;
  $112 = HEAP32[$111>>2]|0;
  $113 = $88;
  $114 = $113;
  $115 = HEAP32[$114>>2]|0;
  $116 = (($113) + 4)|0;
  $117 = $116;
  $118 = HEAP32[$117>>2]|0;
  $119 = ($112>>>0)<($118>>>0);
  $120 = ($112|0)==($118|0);
  $121 = ($109>>>0)<($115>>>0);
  $122 = $120 & $121;
  $123 = $119 | $122;
  if (!($123)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$88+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$88+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$88+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$88+12>>2]|0;
  ;HEAP32[$88+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$89+12>>2]|0;
  ;HEAP32[$89+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $124 = $88;
  $125 = $124;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($124) + 4)|0;
  $128 = $127;
  $129 = HEAP32[$128>>2]|0;
  $130 = $87;
  $131 = $130;
  $132 = HEAP32[$131>>2]|0;
  $133 = (($130) + 4)|0;
  $134 = $133;
  $135 = HEAP32[$134>>2]|0;
  $136 = ($129>>>0)<($135>>>0);
  $137 = ($129|0)==($135|0);
  $138 = ($126>>>0)<($132>>>0);
  $139 = $137 & $138;
  $140 = $136 | $139;
  if (!($140)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$87+12>>2]|0;
  ;HEAP32[$87+0>>2]=HEAP32[$88+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$88+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$88+8>>2]|0;HEAP32[$87+12>>2]=HEAP32[$88+12>>2]|0;
  ;HEAP32[$88+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $141 = $87;
  $142 = $141;
  $143 = HEAP32[$142>>2]|0;
  $144 = (($141) + 4)|0;
  $145 = $144;
  $146 = HEAP32[$145>>2]|0;
  $147 = $$0;
  $148 = $147;
  $149 = HEAP32[$148>>2]|0;
  $150 = (($147) + 4)|0;
  $151 = $150;
  $152 = HEAP32[$151>>2]|0;
  $153 = ($146>>>0)<($152>>>0);
  $154 = ($146|0)==($152|0);
  $155 = ($143>>>0)<($149>>>0);
  $156 = $154 & $155;
  $157 = $153 | $156;
  if (!($157)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$87+12>>2]|0;
  ;HEAP32[$87+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$87+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$87+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$87+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEvT0_S5_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 71) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__t$i2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i2 = sp;
 $0 = $__x2;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $__x1;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5>>>0)<($11>>>0);
 $13 = ($5|0)==($11|0);
 $14 = ($2>>>0)<($8>>>0);
 $15 = $13 & $14;
 $16 = $12 | $15;
 $17 = $__x3;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22>>>0)<($5>>>0);
 $24 = ($22|0)==($5|0);
 $25 = ($19>>>0)<($2>>>0);
 $26 = $24 & $25;
 $27 = $23 | $26;
 do {
  if ($16) {
   if ($27) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
    ;HEAP32[$__x1+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $$0$i = 1;
    break;
   }
   ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
   ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
   ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
   $45 = $__x3;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = (($45) + 4)|0;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = $__x2;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($51) + 4)|0;
   $55 = $54;
   $56 = HEAP32[$55>>2]|0;
   $57 = ($50>>>0)<($56>>>0);
   $58 = ($50|0)==($56|0);
   $59 = ($47>>>0)<($53>>>0);
   $60 = $58 & $59;
   $61 = $57 | $60;
   if ($61) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($27) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $28 = $__x2;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 4)|0;
    $32 = $31;
    $33 = HEAP32[$32>>2]|0;
    $34 = $__x1;
    $35 = $34;
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + 4)|0;
    $38 = $37;
    $39 = HEAP32[$38>>2]|0;
    $40 = ($33>>>0)<($39>>>0);
    $41 = ($33|0)==($39|0);
    $42 = ($30>>>0)<($36>>>0);
    $43 = $41 & $42;
    $44 = $40 | $43;
    if ($44) {
     ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
     ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
     ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $62 = $__x4;
 $63 = $62;
 $64 = HEAP32[$63>>2]|0;
 $65 = (($62) + 4)|0;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = $__x3;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = ($67>>>0)<($73>>>0);
 $75 = ($67|0)==($73|0);
 $76 = ($64>>>0)<($70>>>0);
 $77 = $75 & $76;
 $78 = $74 | $77;
 if (!($78)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x3+12>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $79 = (($$0$i) + 1)|0;
 $80 = $__x3;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = (($80) + 4)|0;
 $84 = $83;
 $85 = HEAP32[$84>>2]|0;
 $86 = $__x2;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = (($86) + 4)|0;
 $90 = $89;
 $91 = HEAP32[$90>>2]|0;
 $92 = ($85>>>0)<($91>>>0);
 $93 = ($85|0)==($91|0);
 $94 = ($82>>>0)<($88>>>0);
 $95 = $93 & $94;
 $96 = $92 | $95;
 if (!($96)) {
  $__r$0 = $79;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $97 = (($$0$i) + 2)|0;
 $98 = $__x2;
 $99 = $98;
 $100 = HEAP32[$99>>2]|0;
 $101 = (($98) + 4)|0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = $__x1;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = (($104) + 4)|0;
 $108 = $107;
 $109 = HEAP32[$108>>2]|0;
 $110 = ($103>>>0)<($109>>>0);
 $111 = ($103|0)==($109|0);
 $112 = ($100>>>0)<($106>>>0);
 $113 = $111 & $112;
 $114 = $110 | $113;
 if (!($114)) {
  $__r$0 = $97;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $115 = (($$0$i) + 3)|0;
 $__r$0 = $115;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i = 0;
 var $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4$i = sp + 8|0;
 $__t$sroa$1 = sp;
 $0 = (($__first) + 32|0);
 $1 = (($__first) + 16|0);
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $__first;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = ($7>>>0)<($13>>>0);
 $15 = ($7|0)==($13|0);
 $16 = ($4>>>0)<($10>>>0);
 $17 = $15 & $16;
 $18 = $14 | $17;
 $19 = $0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($7>>>0);
 $26 = ($24|0)==($7|0);
 $27 = ($21>>>0)<($4>>>0);
 $28 = $26 & $27;
 $29 = $25 | $28;
 do {
  if ($18) {
   if ($29) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    break;
   }
   ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
   $41 = $1;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = ($24>>>0)<($46>>>0);
   $48 = ($24|0)==($46|0);
   $49 = ($21>>>0)<($43>>>0);
   $50 = $48 & $49;
   $51 = $47 | $50;
   if ($51) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
   }
  } else {
   if ($29) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    $30 = $1;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35>>>0)<($13>>>0);
    $37 = ($35|0)==($13|0);
    $38 = ($32>>>0)<($10>>>0);
    $39 = $37 & $38;
    $40 = $36 | $39;
    if ($40) {
     ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    }
   }
  }
 } while(0);
 $52 = (($__first) + 48|0);
 $53 = ($52|0)==($__last|0);
 if ($53) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $52;$__j$01 = $0;
 }
 while(1) {
  $54 = $__i$02;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = (($54) + 4)|0;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = $__j$01;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = (($60) + 4)|0;
  $64 = $63;
  $65 = HEAP32[$64>>2]|0;
  $66 = ($59>>>0)<($65>>>0);
  $67 = ($59|0)==($65|0);
  $68 = ($56>>>0)<($62>>>0);
  $69 = $67 & $68;
  $70 = $66 | $69;
  if ($70) {
   $71 = (($__i$02) + 8|0);
   $72 = $71;
   $73 = $72;
   $74 = HEAP32[$73>>2]|0;
   $75 = (($72) + 4)|0;
   $76 = $75;
   $77 = HEAP32[$76>>2]|0;
   $78 = $__t$sroa$1;
   $79 = $78;
   HEAP32[$79>>2] = $74;
   $80 = (($78) + 4)|0;
   $81 = $80;
   HEAP32[$81>>2] = $77;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;
    $82 = ($__k$0|0)==($__first|0);
    if ($82) {
     $__k$0$lcssa = $__first;
     break;
    }
    $83 = (($__k$0) + -16|0);
    $84 = $83;
    $85 = $84;
    $86 = HEAP32[$85>>2]|0;
    $87 = (($84) + 4)|0;
    $88 = $87;
    $89 = HEAP32[$88>>2]|0;
    $90 = ($59>>>0)<($89>>>0);
    $91 = ($59|0)==($89|0);
    $92 = ($56>>>0)<($86>>>0);
    $93 = $91 & $92;
    $94 = $90 | $93;
    if ($94) {
     $__j$1$phi = $__k$0;$__k$0 = $83;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   $95 = $__k$0$lcssa;
   $96 = $95;
   HEAP32[$96>>2] = $56;
   $97 = (($95) + 4)|0;
   $98 = $97;
   HEAP32[$98>>2] = $59;
   $99 = (($__k$0$lcssa) + 8|0);
   $100 = $__t$sroa$1;
   $101 = $100;
   $102 = HEAP32[$101>>2]|0;
   $103 = (($100) + 4)|0;
   $104 = $103;
   $105 = HEAP32[$104>>2]|0;
   $106 = $99;
   $107 = $106;
   HEAP32[$107>>2] = $102;
   $108 = (($106) + 4)|0;
   $109 = $108;
   HEAP32[$109>>2] = $105;
  }
  $110 = (($__i$02) + 16|0);
  $111 = ($110|0)==($__last|0);
  if ($111) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $110;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEbT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$014 = 0, $__count$1 = 0;
 var $__i$015 = 0, $__j$013 = 0, $__j$013$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i5 = 0, $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4$i5 = sp + 8|0;
 $__t$sroa$1 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 4;
 switch ($3|0) {
 case 5:  {
  $89 = (($__first) + 16|0);
  $90 = (($__first) + 32|0);
  $91 = (($__first) + 48|0);
  $92 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEjT0_S5_S5_S5_T_($__first,$89,$90,$91,0)|0);
  $93 = $92;
  $94 = $93;
  $95 = HEAP32[$94>>2]|0;
  $96 = (($93) + 4)|0;
  $97 = $96;
  $98 = HEAP32[$97>>2]|0;
  $99 = $91;
  $100 = $99;
  $101 = HEAP32[$100>>2]|0;
  $102 = (($99) + 4)|0;
  $103 = $102;
  $104 = HEAP32[$103>>2]|0;
  $105 = ($98>>>0)<($104>>>0);
  $106 = ($98|0)==($104|0);
  $107 = ($95>>>0)<($101>>>0);
  $108 = $106 & $107;
  $109 = $105 | $108;
  if (!($109)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$91+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$91+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$91+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$91+12>>2]|0;
  ;HEAP32[$91+0>>2]=HEAP32[$92+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$92+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$92+8>>2]|0;HEAP32[$91+12>>2]=HEAP32[$92+12>>2]|0;
  ;HEAP32[$92+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$92+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $110 = $91;
  $111 = $110;
  $112 = HEAP32[$111>>2]|0;
  $113 = (($110) + 4)|0;
  $114 = $113;
  $115 = HEAP32[$114>>2]|0;
  $116 = $90;
  $117 = $116;
  $118 = HEAP32[$117>>2]|0;
  $119 = (($116) + 4)|0;
  $120 = $119;
  $121 = HEAP32[$120>>2]|0;
  $122 = ($115>>>0)<($121>>>0);
  $123 = ($115|0)==($121|0);
  $124 = ($112>>>0)<($118>>>0);
  $125 = $123 & $124;
  $126 = $122 | $125;
  if (!($126)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$90+12>>2]|0;
  ;HEAP32[$90+0>>2]=HEAP32[$91+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$91+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$91+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$91+12>>2]|0;
  ;HEAP32[$91+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$91+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $127 = $90;
  $128 = $127;
  $129 = HEAP32[$128>>2]|0;
  $130 = (($127) + 4)|0;
  $131 = $130;
  $132 = HEAP32[$131>>2]|0;
  $133 = $89;
  $134 = $133;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($133) + 4)|0;
  $137 = $136;
  $138 = HEAP32[$137>>2]|0;
  $139 = ($132>>>0)<($138>>>0);
  $140 = ($132|0)==($138|0);
  $141 = ($129>>>0)<($135>>>0);
  $142 = $140 & $141;
  $143 = $139 | $142;
  if (!($143)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$89+12>>2]|0;
  ;HEAP32[$89+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$90+12>>2]|0;
  ;HEAP32[$90+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $144 = $89;
  $145 = $144;
  $146 = HEAP32[$145>>2]|0;
  $147 = (($144) + 4)|0;
  $148 = $147;
  $149 = HEAP32[$148>>2]|0;
  $150 = $__first;
  $151 = $150;
  $152 = HEAP32[$151>>2]|0;
  $153 = (($150) + 4)|0;
  $154 = $153;
  $155 = HEAP32[$154>>2]|0;
  $156 = ($149>>>0)<($155>>>0);
  $157 = ($149|0)==($155|0);
  $158 = ($146>>>0)<($152>>>0);
  $159 = $157 & $158;
  $160 = $156 | $159;
  if (!($160)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$89+12>>2]|0;
  ;HEAP32[$89+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -16|0);
  $5 = $4;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) + 4)|0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = $__first;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = ($10>>>0)<($16>>>0);
  $18 = ($10|0)==($16|0);
  $19 = ($7>>>0)<($13>>>0);
  $20 = $18 & $19;
  $21 = $17 | $20;
  if (!($21)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $86 = (($__first) + 16|0);
  $87 = (($__first) + 32|0);
  $88 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IR28CompactShadowCasterKeySorterP21CompactCasterSortDataEEjT0_S5_S5_S5_T_($__first,$86,$87,$88,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $22 = (($__first) + 16|0);
  $23 = (($__last) + -16|0);
  $24 = $22;
  $25 = $24;
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 4)|0;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = $__first;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 4)|0;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = ($29>>>0)<($35>>>0);
  $37 = ($29|0)==($35|0);
  $38 = ($26>>>0)<($32>>>0);
  $39 = $37 & $38;
  $40 = $36 | $39;
  $41 = $23;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46>>>0)<($29>>>0);
  $48 = ($46|0)==($29|0);
  $49 = ($43>>>0)<($26>>>0);
  $50 = $48 & $49;
  $51 = $47 | $50;
  if (!($40)) {
   if (!($51)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$22+12>>2]|0;
   ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;
   ;HEAP32[$23+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $52 = $22;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = $__first;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = (($58) + 4)|0;
   $62 = $61;
   $63 = HEAP32[$62>>2]|0;
   $64 = ($57>>>0)<($63>>>0);
   $65 = ($57|0)==($63|0);
   $66 = ($54>>>0)<($60>>>0);
   $67 = $65 & $66;
   $68 = $64 | $67;
   if (!($68)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$22+12>>2]|0;
   ;HEAP32[$22+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($51) {
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$23+12>>2]|0;
   ;HEAP32[$23+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $69 = $23;
  $70 = $69;
  $71 = HEAP32[$70>>2]|0;
  $72 = (($69) + 4)|0;
  $73 = $72;
  $74 = HEAP32[$73>>2]|0;
  $75 = $22;
  $76 = $75;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($75) + 4)|0;
  $79 = $78;
  $80 = HEAP32[$79>>2]|0;
  $81 = ($74>>>0)<($80>>>0);
  $82 = ($74|0)==($80|0);
  $83 = ($71>>>0)<($77>>>0);
  $84 = $82 & $83;
  $85 = $81 | $84;
  if (!($85)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $161 = (($__first) + 32|0);
  $162 = (($__first) + 16|0);
  $163 = $162;
  $164 = $163;
  $165 = HEAP32[$164>>2]|0;
  $166 = (($163) + 4)|0;
  $167 = $166;
  $168 = HEAP32[$167>>2]|0;
  $169 = $__first;
  $170 = $169;
  $171 = HEAP32[$170>>2]|0;
  $172 = (($169) + 4)|0;
  $173 = $172;
  $174 = HEAP32[$173>>2]|0;
  $175 = ($168>>>0)<($174>>>0);
  $176 = ($168|0)==($174|0);
  $177 = ($165>>>0)<($171>>>0);
  $178 = $176 & $177;
  $179 = $175 | $178;
  $180 = $161;
  $181 = $180;
  $182 = HEAP32[$181>>2]|0;
  $183 = (($180) + 4)|0;
  $184 = $183;
  $185 = HEAP32[$184>>2]|0;
  $186 = ($185>>>0)<($168>>>0);
  $187 = ($185|0)==($168|0);
  $188 = ($182>>>0)<($165>>>0);
  $189 = $187 & $188;
  $190 = $186 | $189;
  do {
   if ($179) {
    if ($190) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$161+12>>2]|0;
     ;HEAP32[$161+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     break;
    }
    ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$162+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$162+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$162+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$162+12>>2]|0;
    ;HEAP32[$162+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
    $202 = $162;
    $203 = $202;
    $204 = HEAP32[$203>>2]|0;
    $205 = (($202) + 4)|0;
    $206 = $205;
    $207 = HEAP32[$206>>2]|0;
    $208 = ($185>>>0)<($207>>>0);
    $209 = ($185|0)==($207|0);
    $210 = ($182>>>0)<($204>>>0);
    $211 = $209 & $210;
    $212 = $208 | $211;
    if ($212) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$162+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$162+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$162+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$162+12>>2]|0;
     ;HEAP32[$162+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$161+12>>2]|0;
     ;HEAP32[$161+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
    }
   } else {
    if ($190) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$162+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$162+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$162+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$162+12>>2]|0;
     ;HEAP32[$162+0>>2]=HEAP32[$161+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$161+12>>2]|0;
     ;HEAP32[$161+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$161+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$161+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$161+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     $191 = $162;
     $192 = $191;
     $193 = HEAP32[$192>>2]|0;
     $194 = (($191) + 4)|0;
     $195 = $194;
     $196 = HEAP32[$195>>2]|0;
     $197 = ($196>>>0)<($174>>>0);
     $198 = ($196|0)==($174|0);
     $199 = ($193>>>0)<($171>>>0);
     $200 = $198 & $199;
     $201 = $197 | $200;
     if ($201) {
      ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
      ;HEAP32[$__first+0>>2]=HEAP32[$162+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$162+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$162+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$162+12>>2]|0;
      ;HEAP32[$162+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     }
    }
   }
  } while(0);
  $213 = (($__first) + 48|0);
  $214 = ($213|0)==($__last|0);
  if ($214) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$014 = 0;$__i$015 = $213;$__j$013 = $161;
  }
  while(1) {
   $215 = $__i$015;
   $216 = $215;
   $217 = HEAP32[$216>>2]|0;
   $218 = (($215) + 4)|0;
   $219 = $218;
   $220 = HEAP32[$219>>2]|0;
   $221 = $__j$013;
   $222 = $221;
   $223 = HEAP32[$222>>2]|0;
   $224 = (($221) + 4)|0;
   $225 = $224;
   $226 = HEAP32[$225>>2]|0;
   $227 = ($220>>>0)<($226>>>0);
   $228 = ($220|0)==($226|0);
   $229 = ($217>>>0)<($223>>>0);
   $230 = $228 & $229;
   $231 = $227 | $230;
   if ($231) {
    $232 = (($__i$015) + 8|0);
    $233 = $232;
    $234 = $233;
    $235 = HEAP32[$234>>2]|0;
    $236 = (($233) + 4)|0;
    $237 = $236;
    $238 = HEAP32[$237>>2]|0;
    $239 = $__t$sroa$1;
    $240 = $239;
    HEAP32[$240>>2] = $235;
    $241 = (($239) + 4)|0;
    $242 = $241;
    HEAP32[$242>>2] = $238;
    $__j$1 = $__i$015;$__k$0 = $__j$013;
    while(1) {
     ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;
     $243 = ($__k$0|0)==($__first|0);
     if ($243) {
      $__k$0$lcssa = $__first;
      break;
     }
     $244 = (($__k$0) + -16|0);
     $245 = $244;
     $246 = $245;
     $247 = HEAP32[$246>>2]|0;
     $248 = (($245) + 4)|0;
     $249 = $248;
     $250 = HEAP32[$249>>2]|0;
     $251 = ($220>>>0)<($250>>>0);
     $252 = ($220|0)==($250|0);
     $253 = ($217>>>0)<($247>>>0);
     $254 = $252 & $253;
     $255 = $251 | $254;
     if ($255) {
      $__j$1$phi = $__k$0;$__k$0 = $244;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    $256 = $__k$0$lcssa;
    $257 = $256;
    HEAP32[$257>>2] = $217;
    $258 = (($256) + 4)|0;
    $259 = $258;
    HEAP32[$259>>2] = $220;
    $260 = (($__k$0$lcssa) + 8|0);
    $261 = $__t$sroa$1;
    $262 = $261;
    $263 = HEAP32[$262>>2]|0;
    $264 = (($261) + 4)|0;
    $265 = $264;
    $266 = HEAP32[$265>>2]|0;
    $267 = $260;
    $268 = $267;
    HEAP32[$268>>2] = $263;
    $269 = (($267) + 4)|0;
    $270 = $269;
    HEAP32[$270>>2] = $266;
    $271 = (($__count$014) + 1)|0;
    $272 = ($271|0)==(8);
    if ($272) {
     break;
    } else {
     $__count$1 = $271;
    }
   } else {
    $__count$1 = $__count$014;
   }
   $275 = (($__i$015) + 16|0);
   $276 = ($275|0)==($__last|0);
   if ($276) {
    $$0 = 1;
    label = 34;
    break;
   } else {
    $__j$013$phi = $__i$015;$__count$014 = $__count$1;$__i$015 = $275;$__j$013 = $__j$013$phi;
   }
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  $273 = (($__i$015) + 16|0);
  $274 = ($273|0)==($__last|0);
  $$0 = $274;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16vectorI16ShadowCasterData13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 24)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 24)&-1;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $14 << 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = ($$0$i2*24)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,576840,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + (($7*24)|0)|0);
 $24 = (($23) + (($$0$i3*24)|0)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  ;HEAP32[$22+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$__x+20>>2]|0;
 }
 $26 = (($23) + (($8*24)|0)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = $28;
 $30 = $27;
 $31 = (($29) - ($30))|0;
 $32 = (($31|0) / -24)&-1;
 $$sum1 = (($32) + ($7))|0;
 $33 = (($23) + (($$sum1*24)|0)|0);
 _memcpy(($33|0),($27|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$1>>2] = $26;
 HEAP32[$10>>2] = $24;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI20ShadowCasterPartData13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 4;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 3;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,576840,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<4)|0);
 $24 = (($23) + ($$0$i3<<4)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  ;HEAP32[$22+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__x+12>>2]|0;
 }
 $26 = (($23) + ($8<<4)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = $28;
 $30 = $27;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 4;
 $$sum1 = (($7) - ($32))|0;
 $33 = (($23) + ($$sum1<<4)|0);
 _memcpy(($33|0),($27|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$1>>2] = $26;
 HEAP32[$10>>2] = $24;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __GLOBAL__I_a2482() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,576144);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[576136>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,576176);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[576168>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN14ShadowSettings5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = -1;
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.0500000007450580596924);
 $3 = (($this) + 16|0);
 HEAPF32[$3>>2] = Math_fround(4.0);
 $4 = (($this) + 20|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN6Skybox14RenderAllFacesEPN5Unity8MaterialE($mat) {
 $mat = $mat|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $pass$04 = 0, $range = 0, $source = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $range = sp + 8|0;
 $source = sp;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (__ZN15SkyboxGenerator19GetCubemapSkyboxVBOEv()|0);
 $2 = (__ZN5Unity8Material9GetShaderEv($mat)|0);
 $3 = (__ZNK6Shader23GetActiveSubShaderIndexEv($2)|0);
 $4 = (__ZN5Unity8Material12GetPassCountEv($mat)|0);
 ;HEAP32[$range+0>>2]=0|0;HEAP32[$range+4>>2]=0|0;HEAP32[$range+8>>2]=0|0;HEAP32[$range+12>>2]=0|0;HEAP32[$range+16>>2]=0|0;HEAP32[$range+20>>2]=0|0;
 HEAP32[$range>>2] = 0;
 $5 = (__ZN15SkyboxGenerator27GetCubemapSkyboxVertexCountEv()|0);
 $6 = (($range) + 20|0);
 HEAP32[$6>>2] = $5;
 HEAP32[$source>>2] = $1;
 $7 = (($source) + 4|0);
 HEAP32[$7>>2] = 28;
 $8 = ($4|0)>(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($2) + 52|0);
 $pass$04 = 0;
 while(1) {
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + ($3<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($pass$04<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 584|0);
  $18 = HEAP32[$17>>2]|0;
  if ((($18|0) == 0) | (($18|0) == 1) | (($18|0) == 4)) {
   $19 = HEAP32[652824>>2]|0;
   $20 = (__ZN5Unity8Material17SetPassWithShaderEiP6ShaderRN9ShaderLab17ShaderPassContextEi($mat,$pass$04,$2,$19,$3)|0);
   $21 = (($20) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (__ZN15SkyboxGenerator33GetCubemapSkyboxVertexDeclarationEj($22)|0);
   $24 = HEAP32[$0>>2]|0;
   $25 = (($24) + 300|0);
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_viiiiiiii[$26 & 63]($0,0,$source,1,$range,1,$23,$20);
  }
  $27 = (($pass$04) + 1)|0;
  $exitcond = ($27|0)==($4|0);
  if ($exitcond) {
   break;
  } else {
   $pass$04 = $27;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6Skybox8SetupSunER9GfxDevice($device) {
 $device = $device|0;
 var $$byval_copy22 = 0, $$pre = Math_fround(0), $$pre14 = Math_fround(0), $$pre15 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blackSH = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body9$indexZ2D = 0, $properties = 0;
 var $sunDir = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy22 = sp + 184|0;
 $0 = sp;
 $1 = sp + 4|0;
 $sunDir = sp + 8|0;
 $2 = sp + 20|0;
 $properties = sp + 32|0;
 $blackSH = sp + 76|0;
 $3 = (__Z13FindMainLightv()|0);
 HEAPF32[$sunDir>>2] = Math_fround(0.0);
 $4 = (($sunDir) + 4|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($sunDir) + 8|0);
 HEAPF32[$5>>2] = Math_fround(-1.0);
 $6 = ($3|0)==(0|0);
 if ($6) {
  $21 = Math_fround(0.0);$23 = Math_fround(0.0);$25 = Math_fround(0.0);$27 = Math_fround(0.0);$29 = Math_fround(0.0);$31 = Math_fround(0.0);$33 = Math_fround(-1.0);
 } else {
  $7 = HEAP32[577088>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = (($3) + 156|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = (($3) + 160|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = (($3) + 164|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = (($3) + 168|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $128 = $16;$129 = $14;$130 = $12;$131 = $10;
  } else {
   $128 = Math_fround(0.0);$129 = Math_fround(0.0);$130 = Math_fround(0.0);$131 = Math_fround(0.0);
  }
  $17 = (($3) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($18)|0);
  __ZNK9Transform18TransformDirectionERK8Vector3f($2,$19,$sunDir);
  ;HEAP32[$sunDir+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$sunDir+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$sunDir+8>>2]=HEAP32[$2+8>>2]|0;
  $$pre = Math_fround(HEAPF32[$sunDir>>2]);
  $$pre14 = Math_fround(HEAPF32[$4>>2]);
  $$pre15 = Math_fround(HEAPF32[$5>>2]);
  $21 = $131;$23 = $130;$25 = $129;$27 = $128;$29 = $$pre;$31 = $$pre14;$33 = $$pre15;
 }
 $20 = (($device) + 548|0);
 HEAPF32[$20>>2] = $21;
 $22 = (($device) + 552|0);
 HEAPF32[$22>>2] = $23;
 $24 = (($device) + 556|0);
 HEAPF32[$24>>2] = $25;
 $26 = (($device) + 560|0);
 HEAPF32[$26>>2] = $27;
 $28 = (($device) + 532|0);
 HEAPF32[$28>>2] = $29;
 $30 = (($device) + 536|0);
 HEAPF32[$30>>2] = $31;
 $32 = (($device) + 540|0);
 HEAPF32[$32>>2] = $33;
 $34 = (($device) + 544|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = HEAP32[$device>>2]|0;
 $36 = (($35) + 244|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($device,0);
 $38 = HEAP32[628512>>2]|0;
 HEAP32[$properties>>2] = 0;
 $39 = (($properties) + 4|0);
 HEAP32[$39>>2] = $38;
 $40 = (($properties) + 8|0);
 HEAP32[$40>>2] = 0;
 $41 = (($properties) + 12|0);
 HEAP32[$41>>2] = 0;
 $42 = (($properties) + 16|0);
 HEAP32[$42>>2] = 0;
 $43 = (($properties) + 20|0);
 HEAP32[$43>>2] = $38;
 $44 = (($properties) + 24|0);
 HEAP32[$44>>2] = 0;
 $45 = (($properties) + 28|0);
 HEAP32[$45>>2] = 0;
 $46 = (($properties) + 32|0);
 $47 = HEAP32[641904>>2]|0;
 HEAP32[$46>>2] = $47;
 __THREW__ = 0;
 invoke_vii(2610,($properties|0),($device|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  $52 = HEAP32[$45>>2]|0;
  $53 = ($52|0)>(-1);
  do {
   if ($53) {
    $54 = HEAP32[$42>>2]|0;
    $55 = HEAP32[$43>>2]|0;
    HEAP32[$1>>2] = $55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($54|0),($$byval_copy22|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if (!($57)) {
     HEAP32[$42>>2] = 0;
     break;
    }
    $64 = ___cxa_find_matching_catch(0|0)|0;
    $65 = tempRet0;
    $66 = HEAP32[$41>>2]|0;
    $67 = ($66|0)>(-1);
    if (!($67)) {
     $eh$lpad$body9$indexZ2D = $64;
     ___clang_call_terminate($eh$lpad$body9$indexZ2D);
     // unreachable;
    }
    $68 = HEAP32[$properties>>2]|0;
    $69 = HEAP32[$39>>2]|0;
    HEAP32[$0>>2] = $69;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($68|0),($$byval_copy22|0));
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $72 = ___cxa_find_matching_catch(0|0)|0;
     $73 = tempRet0;
     ___clang_call_terminate($72);
     // unreachable;
    }
    HEAP32[$properties>>2] = 0;
    $eh$lpad$body9$indexZ2D = $64;
    ___clang_call_terminate($eh$lpad$body9$indexZ2D);
    // unreachable;
   }
  } while(0);
  $58 = HEAP32[$41>>2]|0;
  $59 = ($58|0)>(-1);
  if (!($59)) {
   ___resumeException($50|0);
   // unreachable;
  }
  $60 = HEAP32[$properties>>2]|0;
  $61 = HEAP32[$39>>2]|0;
  HEAP32[$0>>2] = $61;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($60|0),($$byval_copy22|0));
  $62 = __THREW__; __THREW__ = 0;
  $63 = $62&1;
  if ($63) {
   $74 = ___cxa_find_matching_catch(0|0)|0;
   $75 = tempRet0;
   $eh$lpad$body9$indexZ2D = $74;
   ___clang_call_terminate($eh$lpad$body9$indexZ2D);
   // unreachable;
  } else {
   HEAP32[$properties>>2] = 0;
   ___resumeException($50|0);
   // unreachable;
  }
 }
 dest=$blackSH+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vii(2652,($properties|0),($blackSH|0));
 $76 = __THREW__; __THREW__ = 0;
 $77 = $76&1;
 do {
  if (!($77)) {
   $78 = HEAP32[$40>>2]|0;
   $79 = ($78|0)==(0);
   if (!($79)) {
    __THREW__ = 0;
    invoke_vi(3434,($properties|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     break;
    }
   }
   $82 = HEAP32[$45>>2]|0;
   $83 = ($82|0)>(-1);
   do {
    if ($83) {
     $84 = HEAP32[$42>>2]|0;
     $85 = HEAP32[$43>>2]|0;
     HEAP32[$1>>2] = $85;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($84|0),($$byval_copy22|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if (!($87)) {
      HEAP32[$42>>2] = 0;
      break;
     }
     $92 = ___cxa_find_matching_catch()|0;
     $93 = tempRet0;
     $94 = HEAP32[$41>>2]|0;
     $95 = ($94|0)>(-1);
     if (!($95)) {
      ___resumeException($92|0);
      // unreachable;
     }
     $96 = HEAP32[$properties>>2]|0;
     $97 = HEAP32[$39>>2]|0;
     HEAP32[$0>>2] = $97;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($96|0),($$byval_copy22|0));
     $98 = __THREW__; __THREW__ = 0;
     $99 = $98&1;
     if ($99) {
      $100 = ___cxa_find_matching_catch(0|0)|0;
      $101 = tempRet0;
      ___clang_call_terminate($100);
      // unreachable;
     }
     HEAP32[$properties>>2] = 0;
     ___resumeException($92|0);
     // unreachable;
    }
   } while(0);
   $88 = HEAP32[$41>>2]|0;
   $89 = ($88|0)>(-1);
   if (!($89)) {
    STACKTOP = sp;return;
   }
   $90 = HEAP32[$properties>>2]|0;
   $91 = HEAP32[$39>>2]|0;
   HEAP32[$0>>2] = $91;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($90,$$byval_copy22);
   HEAP32[$properties>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $102 = ___cxa_find_matching_catch()|0;
 $103 = tempRet0;
 $104 = HEAP32[$45>>2]|0;
 $105 = ($104|0)>(-1);
 do {
  if ($105) {
   $106 = HEAP32[$42>>2]|0;
   $107 = HEAP32[$43>>2]|0;
   HEAP32[$1>>2] = $107;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($106|0),($$byval_copy22|0));
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if (!($109)) {
    HEAP32[$42>>2] = 0;
    break;
   }
   $116 = ___cxa_find_matching_catch(0|0)|0;
   $117 = tempRet0;
   $118 = HEAP32[$41>>2]|0;
   $119 = ($118|0)>(-1);
   if (!($119)) {
    $eh$lpad$body$indexZ2D = $116;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $120 = HEAP32[$properties>>2]|0;
   $121 = HEAP32[$39>>2]|0;
   HEAP32[$0>>2] = $121;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($120|0),($$byval_copy22|0));
   $122 = __THREW__; __THREW__ = 0;
   $123 = $122&1;
   if ($123) {
    $124 = ___cxa_find_matching_catch(0|0)|0;
    $125 = tempRet0;
    ___clang_call_terminate($124);
    // unreachable;
   }
   HEAP32[$properties>>2] = 0;
   $eh$lpad$body$indexZ2D = $116;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 $110 = HEAP32[$41>>2]|0;
 $111 = ($110|0)>(-1);
 if (!($111)) {
  ___resumeException($102|0);
  // unreachable;
 }
 $112 = HEAP32[$properties>>2]|0;
 $113 = HEAP32[$39>>2]|0;
 HEAP32[$0>>2] = $113;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($112|0),($$byval_copy22|0));
 $114 = __THREW__; __THREW__ = 0;
 $115 = $114&1;
 if ($115) {
  $126 = ___cxa_find_matching_catch(0|0)|0;
  $127 = tempRet0;
  $eh$lpad$body$indexZ2D = $126;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$properties>>2] = 0;
  ___resumeException($102|0);
  // unreachable;
 }
}
function __ZN6Skybox12RenderSkyboxEPN5Unity8MaterialERK6Camera($mat,$camera) {
 $mat = $mat|0;
 $camera = $camera|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0;
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $j$021 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $matrix$i = 0, $matrix$i3 = 0, $matrix5$i = 0, $preserveMVP = 0;
 var $projection$i = 0, $projection4$i = 0, $range$i = 0, $source$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 624|0;
 $range$i = sp + 592|0;
 $source$i = sp + 584|0;
 $projection$i = sp + 520|0;
 $matrix$i3 = sp + 456|0;
 $0 = sp + 444|0;
 $1 = sp + 432|0;
 $projection4$i = sp + 368|0;
 $matrix5$i = sp + 304|0;
 $2 = sp + 100|0;
 $3 = sp + 88|0;
 $matrix$i = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $preserveMVP = sp + 112|0;
 $6 = ($mat|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (__Z12GetGfxDevicev()|0);
 __ZN22DeviceMVPMatricesStateC2Ev($preserveMVP);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 780|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_ii($10|0,($7|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L4: do {
  if ($13) {
   label = 8;
  } else {
   $14 = ($11|0)==(0);
   do {
    if ($14) {
     $44 = (($camera) + 616|0);
     $45 = HEAP8[$44>>0]|0;
     $46 = ($45<<24>>24)==(0);
     $47 = (($camera) + 456|0);
     $48 = Math_fround(HEAPF32[$47>>2]);
     $49 = Math_fround($48 * Math_fround(0.00999999977648258209228));
     $50 = (($camera) + 460|0);
     $51 = Math_fround(HEAPF32[$50>>2]);
     $52 = Math_fround($51 * Math_fround(10.0));
     if (!($46)) {
      dest=$projection$i+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $53 = (($projection$i) + 40|0);
      HEAPF32[$53>>2] = Math_fround(-0.999998986721038818359);
      $54 = Math_fround($49 * Math_fround(-1.99999904632568359375));
      $55 = (($projection$i) + 56|0);
      HEAPF32[$55>>2] = $54;
      $56 = (($projection$i) + 44|0);
      HEAPF32[$56>>2] = Math_fround(-1.0);
      dest=$matrix$i3+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      HEAPF32[$0>>2] = $52;
      $57 = (($0) + 4|0);
      HEAPF32[$57>>2] = $52;
      $58 = (($0) + 8|0);
      HEAPF32[$58>>2] = $52;
      __THREW__ = 0;
      (invoke_iii(2381,($matrix$i3|0),($0|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 8;
       break L4;
      }
      __THREW__ = 0;
      invoke_vii(2653,($1|0),($camera|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 8;
       break L4;
      }
      $63 = Math_fround(HEAPF32[$1>>2]);
      $64 = (($matrix$i3) + 48|0);
      HEAPF32[$64>>2] = $63;
      $65 = (($1) + 4|0);
      $66 = Math_fround(HEAPF32[$65>>2]);
      $67 = (($matrix$i3) + 52|0);
      HEAPF32[$67>>2] = $66;
      $68 = (($1) + 8|0);
      $69 = Math_fround(HEAPF32[$68>>2]);
      $70 = (($matrix$i3) + 56|0);
      HEAPF32[$70>>2] = $69;
      $71 = HEAP32[$7>>2]|0;
      $72 = (($71) + 96|0);
      $73 = HEAP32[$72>>2]|0;
      __THREW__ = 0;
      invoke_vii($73|0,($7|0),($matrix$i3|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 8;
       break L4;
      }
      $76 = HEAP32[$7>>2]|0;
      $77 = (($76) + 104|0);
      $78 = HEAP32[$77>>2]|0;
      __THREW__ = 0;
      invoke_vii($78|0,($7|0),($projection$i|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       label = 8;
       break L4;
      } else {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vifi(2,($camera|0),(+$49),($projection4$i|0));
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if ($82) {
      label = 8;
      break L4;
     }
     $83 = (($projection4$i) + 40|0);
     HEAPF32[$83>>2] = Math_fround(-0.999998986721038818359);
     $84 = Math_fround($49 * Math_fround(-1.99999904632568359375));
     $85 = (($projection4$i) + 56|0);
     HEAPF32[$85>>2] = $84;
     $86 = (($projection4$i) + 44|0);
     HEAPF32[$86>>2] = Math_fround(-1.0);
     dest=$matrix5$i+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     HEAPF32[$2>>2] = $52;
     $87 = (($2) + 4|0);
     HEAPF32[$87>>2] = $52;
     $88 = (($2) + 8|0);
     HEAPF32[$88>>2] = $52;
     __THREW__ = 0;
     (invoke_iii(2381,($matrix5$i|0),($2|0))|0);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 8;
      break L4;
     }
     __THREW__ = 0;
     invoke_vii(2653,($3|0),($camera|0));
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 8;
      break L4;
     }
     $93 = Math_fround(HEAPF32[$3>>2]);
     $94 = (($matrix5$i) + 48|0);
     HEAPF32[$94>>2] = $93;
     $95 = (($3) + 4|0);
     $96 = Math_fround(HEAPF32[$95>>2]);
     $97 = (($matrix5$i) + 52|0);
     HEAPF32[$97>>2] = $96;
     $98 = (($3) + 8|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     $100 = (($matrix5$i) + 56|0);
     HEAPF32[$100>>2] = $99;
     $101 = HEAP32[$7>>2]|0;
     $102 = (($101) + 96|0);
     $103 = HEAP32[$102>>2]|0;
     __THREW__ = 0;
     invoke_vii($103|0,($7|0),($matrix5$i|0));
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      label = 8;
      break L4;
     }
     $106 = HEAP32[$7>>2]|0;
     $107 = (($106) + 104|0);
     $108 = HEAP32[$107>>2]|0;
     __THREW__ = 0;
     invoke_vii($108|0,($7|0),($projection4$i|0));
     $109 = __THREW__; __THREW__ = 0;
     $110 = $109&1;
     if ($110) {
      label = 8;
      break L4;
     }
    } else {
     $15 = (($camera) + 460|0);
     $16 = Math_fround(HEAPF32[$15>>2]);
     $17 = Math_fround($16 * Math_fround(0.990000009536743164062));
     $18 = Math_fround($17 * Math_fround(0.577350258827209472656));
     dest=$matrix$i+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     HEAPF32[$4>>2] = $18;
     $19 = (($4) + 4|0);
     HEAPF32[$19>>2] = $18;
     $20 = (($4) + 8|0);
     HEAPF32[$20>>2] = $18;
     __THREW__ = 0;
     (invoke_iii(2381,($matrix$i|0),($4|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 8;
      break L4;
     }
     __THREW__ = 0;
     invoke_vii(2653,($5|0),($camera|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 8;
      break L4;
     }
     $25 = Math_fround(HEAPF32[$5>>2]);
     $26 = (($matrix$i) + 48|0);
     HEAPF32[$26>>2] = $25;
     $27 = (($5) + 4|0);
     $28 = Math_fround(HEAPF32[$27>>2]);
     $29 = (($matrix$i) + 52|0);
     HEAPF32[$29>>2] = $28;
     $30 = (($5) + 8|0);
     $31 = Math_fround(HEAPF32[$30>>2]);
     $32 = (($matrix$i) + 56|0);
     HEAPF32[$32>>2] = $31;
     $33 = HEAP32[$7>>2]|0;
     $34 = (($33) + 96|0);
     $35 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     invoke_vii($35|0,($7|0),($matrix$i|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 8;
      break L4;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3435,($7|0));
   $111 = __THREW__; __THREW__ = 0;
   $112 = $111&1;
   if ($112) {
    label = 8;
   } else {
    __THREW__ = 0;
    $113 = (invoke_ii(3226,($mat|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     label = 8;
    } else {
     $116 = ($113|0)==(6);
     L24: do {
      if ($116) {
       $117 = (($range$i) + 16|0);
       $118 = (($range$i) + 20|0);
       $119 = (($source$i) + 4|0);
       $j$021 = 0;
       while(1) {
        __THREW__ = 0;
        $120 = (invoke_i(59)|0);
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if ($122) {
         break;
        }
        __THREW__ = 0;
        $123 = (invoke_i(81)|0);
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break;
        }
        __THREW__ = 0;
        $126 = (invoke_ii(3221,($mat|0))|0);
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if ($128) {
         break;
        }
        __THREW__ = 0;
        $129 = (invoke_ii(3232,($126|0))|0);
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if ($131) {
         break;
        }
        $132 = HEAP32[652824>>2]|0;
        __THREW__ = 0;
        $133 = (invoke_iiiiii(193,($mat|0),($j$021|0),($126|0),($132|0),($129|0))|0);
        $134 = __THREW__; __THREW__ = 0;
        $135 = $134&1;
        if ($135) {
         break;
        }
        $136 = ($j$021*6)|0;
        ;HEAP32[$range$i+0>>2]=0|0;HEAP32[$range$i+4>>2]=0|0;HEAP32[$range$i+8>>2]=0|0;HEAP32[$range$i+12>>2]=0|0;
        HEAP32[$117>>2] = $136;
        HEAP32[$range$i>>2] = 0;
        HEAP32[$118>>2] = 6;
        HEAP32[$source$i>>2] = $123;
        HEAP32[$119>>2] = 24;
        $137 = HEAP32[$120>>2]|0;
        $138 = (($137) + 300|0);
        $139 = HEAP32[$138>>2]|0;
        $140 = (($133) + 4|0);
        $141 = HEAP32[$140>>2]|0;
        __THREW__ = 0;
        $142 = (invoke_ii(3233,($141|0))|0);
        $143 = __THREW__; __THREW__ = 0;
        $144 = $143&1;
        if ($144) {
         break;
        }
        __THREW__ = 0;
        invoke_viiiiiiii($139|0,($120|0),(0|0),($source$i|0),1,($range$i|0),1,($142|0),($133|0));
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         break;
        }
        $147 = (($j$021) + 1)|0;
        $148 = ($147|0)<(6);
        if ($148) {
         $j$021 = $147;
        } else {
         break L24;
        }
       }
       $38 = ___cxa_find_matching_catch()|0;
       $39 = tempRet0;
       $lpad$phi$index = $38;$lpad$phi$index2 = $39;
       break L4;
      } else {
       __THREW__ = 0;
       invoke_vi(3436,($mat|0));
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if ($150) {
        label = 8;
        break L4;
       }
      }
     } while(0);
     __ZN22DeviceMVPMatricesStateD2Ev($preserveMVP);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  $lpad$phi$index = $40;$lpad$phi$index2 = $41;
 }
 __THREW__ = 0;
 invoke_vi(3375,($preserveMVP|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $151 = ___cxa_find_matching_catch(0|0)|0;
  $152 = tempRet0;
  ___clang_call_terminate($151);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZNK6Skybox11GetMaterialEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, $temp$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN15SkyboxGenerator27GetCubemapSkyboxVertexCountEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[577112>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN15SkyboxGenerator19GetSixFaceSkyboxVBOEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[577984>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if (!($1)) {
   $2 = HEAP32[$0>>2]|0;
   $3 = (($2) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (FUNCTION_TABLE_ii[$4 & 4095]($0)|0);
   $6 = HEAP32[577984>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($5)) {
    if ($7) {
     break;
    } else {
     $$0 = $6;
    }
    STACKTOP = sp;return ($$0|0);
   }
   if (!($7)) {
    $8 = HEAP32[$6>>2]|0;
    $9 = (($8) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    FUNCTION_TABLE_vi[$10 & 4095]($6);
   }
   HEAP32[577984>>2] = 0;
  }
 } while(0);
 $11 = (__Z12GetGfxDevicev()|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 276|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
 HEAP32[577984>>2] = $15;
 $16 = HEAP32[$11>>2]|0;
 $17 = (($16) + 280|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_viiiiiii[$18 & 127]($11,$15,0,0,864,577120,0);
 $19 = HEAP32[577984>>2]|0;
 $$0 = $19;
 STACKTOP = sp;return ($$0|0);
}
function __ZN15SkyboxGenerator33GetSixFaceSkyboxVertexDeclarationEj($sourceMap) {
 $sourceMap = $sourceMap|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[577104>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__Z26GetMeshVertexFormatManagerv()|0);
  $3 = HEAP32[577096>>2]|0;
  $4 = (__ZN23MeshVertexFormatManager10GetDefaultEj($2,$3)|0);
  HEAP32[577104>>2] = $4;
  $5 = $4;
 } else {
  $5 = $0;
 }
 $6 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($5,$sourceMap,0)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN15SkyboxGenerator19GetCubemapSkyboxVBOEv() {
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy27 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert4$i = 0, $$phi$trans$insert6$i = 0, $$pre = 0, $$pre$i = Math_fround(0), $$pre5$i = Math_fround(0), $$pre7$i = Math_fround(0), $$sum = 0, $$sum56 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0);
 var $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0;
 var $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0);
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0);
 var $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = 0;
 var $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0);
 var $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0;
 var $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0);
 var $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0);
 var $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0;
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$0100 = 0, $i$199 = 0, $i$278 = 0, $k$084 = 0, $k3$058 = 0, $lpad$phi$index = 0, $lpad$phi$index14 = 0, $lpad$phi68$index = 0, $lpad$phi68$index3 = 0, $lpad$phi83$index = 0, $lpad$phi83$index9 = 0;
 var $or$cond$i = 0, $or$cond1$i = 0, $phitmp = 0, $top$0$i = 0, $v1$v2$i = 0, $v12$i = 0, $v12$i26 = 0, $v13$i = 0, $v13$i27 = 0, $v2$v3$i = 0, $v23$i = 0, $v3$v1$i = 0, $va$0$i = 0, $vb$0$i = 0, $vertData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy27 = sp + 200|0;
 $0 = sp + 196|0;
 $1 = sp + 192|0;
 $2 = sp + 188|0;
 $3 = sp + 184|0;
 $4 = sp + 180|0;
 $v12$i26 = sp + 152|0;
 $v23$i = sp + 124|0;
 $v13$i27 = sp + 96|0;
 $5 = sp + 72|0;
 $6 = sp + 68|0;
 $v12$i = sp + 40|0;
 $v13$i = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $vertData = sp + 80|0;
 $10 = HEAP32[577992>>2]|0;
 $11 = ($10|0)==(0|0);
 do {
  if (!($11)) {
   $12 = HEAP32[$10>>2]|0;
   $13 = (($12) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (FUNCTION_TABLE_ii[$14 & 4095]($10)|0);
   $16 = HEAP32[577992>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($15)) {
    if ($17) {
     break;
    } else {
     $$0 = $16;
    }
    STACKTOP = sp;return ($$0|0);
   }
   if (!($17)) {
    $18 = HEAP32[$16>>2]|0;
    $19 = (($18) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    FUNCTION_TABLE_vi[$20 & 4095]($16);
   }
   HEAP32[577992>>2] = 0;
  }
 } while(0);
 $21 = (__Z12GetGfxDevicev()|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 276|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_ii[$24 & 4095]($21)|0);
 HEAP32[577992>>2] = $25;
 HEAP32[$vertData>>2] = 0;
 $26 = (($vertData) + 8|0);
 $27 = (($vertData) + 12|0);
 $28 = (($vertData) + 4|0);
 HEAP32[$28>>2] = 61;
 HEAP32[$26>>2] = 24;
 HEAP32[$27>>2] = 24;
 HEAP32[$9>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$9+0>>2]|0;
 $29 = (invoke_iiiiiiii(108,(0|0),672,4,($$byval_copy27|0),0,(578296|0),370)|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 do {
  if ($31) {
   label = 13;
  } else {
   HEAP32[$vertData>>2] = $29;
   $i$0100 = 0;
   while(1) {
    $50 = ($i$0100*3)|0;
    $51 = (578000 + ($50<<2)|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $$sum = (($50) + 1)|0;
    $53 = (578000 + ($$sum<<2)|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $$sum56 = (($50) + 2)|0;
    $55 = (578000 + ($$sum56<<2)|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = Math_fround($52 * $52);
    $58 = Math_fround($54 * $54);
    $59 = Math_fround($57 + $58);
    $60 = Math_fround($56 * $56);
    $61 = Math_fround($59 + $60);
    $62 = (Math_fround(Math_sqrt((Math_fround($61)))));
    $63 = Math_fround($52 / $62);
    $64 = Math_fround($54 / $62);
    $65 = Math_fround($56 / $62);
    $66 = ((($29) + (($i$0100*28)|0)|0) + 16|0);
    HEAPF32[$66>>2] = $63;
    $67 = (($29) + (($i$0100*28)|0)|0);
    HEAPF32[$67>>2] = $63;
    $68 = ((($29) + (($i$0100*28)|0)|0) + 20|0);
    HEAPF32[$68>>2] = $64;
    $69 = ((($29) + (($i$0100*28)|0)|0) + 4|0);
    HEAPF32[$69>>2] = $64;
    $70 = ((($29) + (($i$0100*28)|0)|0) + 24|0);
    HEAPF32[$70>>2] = $65;
    $71 = ((($29) + (($i$0100*28)|0)|0) + 8|0);
    HEAPF32[$71>>2] = $65;
    $72 = ((($29) + (($i$0100*28)|0)|0) + 12|0);
    HEAP32[$72>>2] = -1;
    $73 = (($i$0100) + 1)|0;
    $exitcond = ($73|0)==(24);
    if ($exitcond) {
     break;
    } else {
     $i$0100 = $73;
    }
   }
   $32 = (($v12$i26) + 16|0);
   $33 = (($v12$i26) + 20|0);
   $34 = (($v12$i26) + 4|0);
   $35 = (($v12$i26) + 24|0);
   $36 = (($v12$i26) + 8|0);
   $37 = (($v12$i26) + 12|0);
   $38 = (($v23$i) + 16|0);
   $39 = (($v23$i) + 20|0);
   $40 = (($v23$i) + 4|0);
   $41 = (($v23$i) + 24|0);
   $42 = (($v23$i) + 8|0);
   $43 = (($v23$i) + 12|0);
   $44 = (($v13$i27) + 16|0);
   $45 = (($v13$i27) + 20|0);
   $46 = (($v13$i27) + 4|0);
   $47 = (($v13$i27) + 24|0);
   $48 = (($v13$i27) + 8|0);
   $49 = (($v13$i27) + 12|0);
   $106 = $29;$i$199 = 1;
   L16: while(1) {
    HEAP32[$vertData>>2] = 0;
    $92 = HEAP32[$26>>2]|0;
    HEAP32[$26>>2] = 0;
    $93 = HEAP32[$27>>2]|0;
    HEAP32[$27>>2] = 0;
    $94 = HEAP32[$28>>2]|0;
    HEAP32[$28>>2] = 61;
    HEAP32[$6>>2] = 61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_vii(2591,(0|0),($$byval_copy27|0));
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if ($96) {
     label = 34;
     break;
    }
    HEAP32[$vertData>>2] = 0;
    HEAP32[$26>>2] = 0;
    HEAP32[$27>>2] = 0;
    $97 = ($92|0)==(0);
    if (!($97)) {
     $98 = $92 << 2;
     HEAP32[$27>>2] = $98;
     $99 = ($92*112)|0;
     $100 = HEAP32[$28>>2]|0;
     HEAP32[$5>>2] = $100;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$5+0>>2]|0;
     $101 = (invoke_iiiiiiii(108,(0|0),($99|0),4,($$byval_copy27|0),0,(578296|0),370)|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     }
     HEAP32[$vertData>>2] = $101;
     $104 = ($92|0)>(0);
     if ($104) {
      $k$084 = 0;
      while(1) {
       $105 = (($106) + (($k$084*28)|0)|0);
       $107 = (($k$084) + 1)|0;
       $108 = (($106) + (($107*28)|0)|0);
       $109 = (($k$084) + 2)|0;
       $110 = (($106) + (($109*28)|0)|0);
       $111 = Math_fround(HEAPF32[$105>>2]);
       $112 = ((($106) + (($k$084*28)|0)|0) + 4|0);
       $113 = Math_fround(HEAPF32[$112>>2]);
       $114 = ((($106) + (($k$084*28)|0)|0) + 8|0);
       $115 = Math_fround(HEAPF32[$114>>2]);
       $116 = Math_fround(HEAPF32[$108>>2]);
       $117 = ((($106) + (($107*28)|0)|0) + 4|0);
       $118 = Math_fround(HEAPF32[$117>>2]);
       $119 = ((($106) + (($107*28)|0)|0) + 8|0);
       $120 = Math_fround(HEAPF32[$119>>2]);
       $121 = Math_fround($116 * Math_fround(0.5));
       $122 = Math_fround($118 * Math_fround(0.5));
       $123 = Math_fround($120 * Math_fround(0.5));
       $124 = Math_fround($111 * Math_fround(0.5));
       $125 = Math_fround($113 * Math_fround(0.5));
       $126 = Math_fround($115 * Math_fround(0.5));
       $127 = Math_fround($124 + $121);
       $128 = Math_fround($125 + $122);
       $129 = Math_fround($126 + $123);
       $130 = Math_fround($127 * $127);
       $131 = Math_fround($128 * $128);
       $132 = Math_fround($130 + $131);
       $133 = Math_fround($129 * $129);
       $134 = Math_fround($132 + $133);
       $135 = (Math_fround(Math_sqrt((Math_fround($134)))));
       $136 = Math_fround($127 / $135);
       $137 = Math_fround($128 / $135);
       $138 = Math_fround($129 / $135);
       HEAPF32[$32>>2] = $136;
       HEAPF32[$v12$i26>>2] = $136;
       HEAPF32[$33>>2] = $137;
       HEAPF32[$34>>2] = $137;
       HEAPF32[$35>>2] = $138;
       HEAPF32[$36>>2] = $138;
       HEAP32[$37>>2] = -1;
       $139 = Math_fround(HEAPF32[$110>>2]);
       $140 = ((($106) + (($109*28)|0)|0) + 4|0);
       $141 = Math_fround(HEAPF32[$140>>2]);
       $142 = ((($106) + (($109*28)|0)|0) + 8|0);
       $143 = Math_fround(HEAPF32[$142>>2]);
       $144 = Math_fround($139 * Math_fround(0.5));
       $145 = Math_fround($141 * Math_fround(0.5));
       $146 = Math_fround($143 * Math_fround(0.5));
       $147 = Math_fround($121 + $144);
       $148 = Math_fround($122 + $145);
       $149 = Math_fround($123 + $146);
       $150 = Math_fround($147 * $147);
       $151 = Math_fround($148 * $148);
       $152 = Math_fround($150 + $151);
       $153 = Math_fround($149 * $149);
       $154 = Math_fround($152 + $153);
       $155 = (Math_fround(Math_sqrt((Math_fround($154)))));
       $156 = Math_fround($147 / $155);
       $157 = Math_fround($148 / $155);
       $158 = Math_fround($149 / $155);
       HEAPF32[$38>>2] = $156;
       HEAPF32[$v23$i>>2] = $156;
       HEAPF32[$39>>2] = $157;
       HEAPF32[$40>>2] = $157;
       HEAPF32[$41>>2] = $158;
       HEAPF32[$42>>2] = $158;
       HEAP32[$43>>2] = -1;
       $159 = Math_fround($124 + $144);
       $160 = Math_fround($125 + $145);
       $161 = Math_fround($126 + $146);
       $162 = Math_fround($159 * $159);
       $163 = Math_fround($160 * $160);
       $164 = Math_fround($162 + $163);
       $165 = Math_fround($161 * $161);
       $166 = Math_fround($164 + $165);
       $167 = (Math_fround(Math_sqrt((Math_fround($166)))));
       $168 = Math_fround($159 / $167);
       $169 = Math_fround($160 / $167);
       $170 = Math_fround($161 / $167);
       HEAPF32[$44>>2] = $168;
       HEAPF32[$v13$i27>>2] = $168;
       HEAPF32[$45>>2] = $169;
       HEAPF32[$46>>2] = $169;
       HEAPF32[$47>>2] = $170;
       HEAPF32[$48>>2] = $170;
       HEAP32[$49>>2] = -1;
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($105|0));
       $171 = __THREW__; __THREW__ = 0;
       $172 = $171&1;
       if ($172) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v12$i26|0));
       $173 = __THREW__; __THREW__ = 0;
       $174 = $173&1;
       if ($174) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v13$i27|0));
       $175 = __THREW__; __THREW__ = 0;
       $176 = $175&1;
       if ($176) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v12$i26|0));
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($108|0));
       $179 = __THREW__; __THREW__ = 0;
       $180 = $179&1;
       if ($180) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v23$i|0));
       $181 = __THREW__; __THREW__ = 0;
       $182 = $181&1;
       if ($182) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v23$i|0));
       $183 = __THREW__; __THREW__ = 0;
       $184 = $183&1;
       if ($184) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v13$i27|0));
       $185 = __THREW__; __THREW__ = 0;
       $186 = $185&1;
       if ($186) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v12$i26|0));
       $187 = __THREW__; __THREW__ = 0;
       $188 = $187&1;
       if ($188) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($110|0));
       $189 = __THREW__; __THREW__ = 0;
       $190 = $189&1;
       if ($190) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v13$i27|0));
       $191 = __THREW__; __THREW__ = 0;
       $192 = $191&1;
       if ($192) {
        label = 33;
        break L16;
       }
       __THREW__ = 0;
       invoke_vii(2654,($vertData|0),($v23$i|0));
       $193 = __THREW__; __THREW__ = 0;
       $194 = $193&1;
       if ($194) {
        label = 33;
        break L16;
       }
       $195 = (($k$084) + 3)|0;
       $196 = ($195|0)<($92|0);
       if ($196) {
        $k$084 = $195;
       } else {
        break;
       }
      }
     }
    }
    $204 = ($93|0)>(-1);
    if ($204) {
     HEAP32[$3>>2] = $94;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($106|0),($$byval_copy27|0));
     $205 = __THREW__; __THREW__ = 0;
     $206 = $205&1;
     if ($206) {
      label = 12;
      break;
     }
    }
    $207 = ($i$199|0)<(3);
    if (!($207)) {
     label = 15;
     break;
    }
    $$pre = HEAP32[$vertData>>2]|0;
    $phitmp = (($i$199) + 1)|0;
    $106 = $$pre;$i$199 = $phitmp;
   }
   if ((label|0) == 12) {
    $76 = ___cxa_find_matching_catch()|0;
    $77 = tempRet0;
    $lpad$phi68$index = $76;$lpad$phi68$index3 = $77;
    label = 14;
    break;
   }
   else if ((label|0) == 15) {
    $80 = (($v12$i) + 16|0);
    $81 = (($v12$i) + 20|0);
    $82 = (($v12$i) + 4|0);
    $83 = (($v12$i) + 24|0);
    $84 = (($v12$i) + 8|0);
    $85 = (($v12$i) + 12|0);
    $86 = (($v13$i) + 16|0);
    $87 = (($v13$i) + 20|0);
    $88 = (($v13$i) + 4|0);
    $89 = (($v13$i) + 24|0);
    $90 = (($v13$i) + 8|0);
    $91 = (($v13$i) + 12|0);
    $i$278 = 0;
    L46: while(1) {
     $208 = HEAP32[$vertData>>2]|0;
     HEAP32[$vertData>>2] = 0;
     $209 = HEAP32[$26>>2]|0;
     HEAP32[$26>>2] = 0;
     $210 = HEAP32[$27>>2]|0;
     HEAP32[$27>>2] = 0;
     $211 = HEAP32[$28>>2]|0;
     HEAP32[$28>>2] = 61;
     $212 = (Math_fround(($i$278|0)));
     $213 = Math_fround($212 + Math_fround(1.0));
     $214 = (Math_fround(+(Math_pow(0.5,(+$213)))));
     HEAP32[$2>>2] = 61;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,(0|0),($$byval_copy27|0));
     $215 = __THREW__; __THREW__ = 0;
     $216 = $215&1;
     if ($216) {
      label = 56;
      break;
     }
     HEAP32[$vertData>>2] = 0;
     HEAP32[$26>>2] = 0;
     HEAP32[$27>>2] = 0;
     $217 = ($209|0)==(0);
     if (!($217)) {
      $218 = $209 << 2;
      HEAP32[$27>>2] = $218;
      $219 = ($209*112)|0;
      $220 = HEAP32[$28>>2]|0;
      HEAP32[$1>>2] = $220;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$1+0>>2]|0;
      $221 = (invoke_iiiiiiii(108,(0|0),($219|0),4,($$byval_copy27|0),0,(578296|0),370)|0);
      $222 = __THREW__; __THREW__ = 0;
      $223 = $222&1;
      if ($223) {
       label = 56;
       break;
      }
      HEAP32[$vertData>>2] = $221;
      $224 = ($209|0)>(0);
      if ($224) {
       $k3$058 = 0;
       while(1) {
        $225 = (($208) + (($k3$058*28)|0)|0);
        $226 = ((($208) + (($k3$058*28)|0)|0) + 4|0);
        $227 = Math_fround(HEAPF32[$226>>2]);
        $228 = $227 < Math_fround(0.0);
        if ($228) {
         $229 = Math_fround(-$227);
         $237 = $229;
        } else {
         $237 = $227;
        }
        $230 = (($k3$058) + 1)|0;
        $231 = (($208) + (($230*28)|0)|0);
        $232 = ((($208) + (($230*28)|0)|0) + 4|0);
        $233 = Math_fround(HEAPF32[$232>>2]);
        $234 = $233 < Math_fround(0.0);
        if ($234) {
         $235 = Math_fround(-$233);
         $238 = $235;
        } else {
         $238 = $233;
        }
        $236 = $237 < $238;
        $239 = (($k3$058) + 2)|0;
        $240 = (($208) + (($239*28)|0)|0);
        $241 = ((($208) + (($239*28)|0)|0) + 4|0);
        $242 = Math_fround(HEAPF32[$241>>2]);
        $243 = $242 < Math_fround(0.0);
        if ($243) {
         $244 = Math_fround(-$242);
         $247 = $244;
        } else {
         $247 = $242;
        }
        $245 = $236 ? $238 : $237;
        $246 = $245 < $247;
        $248 = $246 ? $247 : $245;
        $249 = $248 > $214;
        do {
         if ($249) {
          __THREW__ = 0;
          invoke_vii(2654,($vertData|0),($225|0));
          $250 = __THREW__; __THREW__ = 0;
          $251 = $250&1;
          if ($251) {
           label = 55;
           break L46;
          }
          __THREW__ = 0;
          invoke_vii(2654,($vertData|0),($231|0));
          $252 = __THREW__; __THREW__ = 0;
          $253 = $252&1;
          if ($253) {
           label = 55;
           break L46;
          }
          __THREW__ = 0;
          invoke_vii(2654,($vertData|0),($240|0));
          $254 = __THREW__; __THREW__ = 0;
          $255 = $254&1;
          if ($255) {
           label = 55;
           break L46;
          }
         } else {
          $263 = Math_fround($233 - $227);
          $264 = $263 < Math_fround(0.0);
          if ($264) {
           $265 = Math_fround(-$263);
           $273 = $265;
          } else {
           $273 = $263;
          }
          $266 = Math_fround($233 - $242);
          $267 = $266 < Math_fround(0.0);
          if ($267) {
           $268 = Math_fround(-$266);
           $274 = $268;
          } else {
           $274 = $266;
          }
          $269 = Math_fround($242 - $227);
          $270 = $269 < Math_fround(0.0);
          if ($270) {
           $271 = Math_fround(-$269);
           $276 = $271;
          } else {
           $276 = $269;
          }
          $272 = $273 < $274;
          $275 = $273 < $276;
          $or$cond$i = $272 & $275;
          if ($or$cond$i) {
           $288 = $227;$292 = $242;$312 = $233;$top$0$i = $240;$va$0$i = $225;$vb$0$i = $231;
          } else {
           $277 = $274 < $273;
           $278 = $274 < $276;
           $or$cond1$i = $277 & $278;
           $v1$v2$i = $or$cond1$i ? $225 : $231;
           $v2$v3$i = $or$cond1$i ? $231 : $240;
           $v3$v1$i = $or$cond1$i ? $240 : $225;
           $$phi$trans$insert$i = (($v1$v2$i) + 4|0);
           $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
           $$phi$trans$insert4$i = (($v2$v3$i) + 4|0);
           $$pre5$i = Math_fround(HEAPF32[$$phi$trans$insert4$i>>2]);
           $$phi$trans$insert6$i = (($v3$v1$i) + 4|0);
           $$pre7$i = Math_fround(HEAPF32[$$phi$trans$insert6$i>>2]);
           $288 = $$pre5$i;$292 = $$pre$i;$312 = $$pre7$i;$top$0$i = $v1$v2$i;$va$0$i = $v2$v3$i;$vb$0$i = $v3$v1$i;
          }
          $279 = Math_fround(HEAPF32[$top$0$i>>2]);
          $280 = (($top$0$i) + 8|0);
          $281 = Math_fround(HEAPF32[$280>>2]);
          $282 = Math_fround(HEAPF32[$va$0$i>>2]);
          $283 = (($va$0$i) + 4|0);
          $284 = (($va$0$i) + 8|0);
          $285 = Math_fround(HEAPF32[$284>>2]);
          $286 = Math_fround($282 * Math_fround(0.5));
          $287 = Math_fround($288 * Math_fround(0.5));
          $289 = Math_fround($285 * Math_fround(0.5));
          $290 = Math_fround($279 * Math_fround(0.5));
          $291 = Math_fround($292 * Math_fround(0.5));
          $293 = Math_fround($281 * Math_fround(0.5));
          $294 = Math_fround($290 + $286);
          $295 = Math_fround($287 + $291);
          $296 = Math_fround($293 + $289);
          $297 = Math_fround($294 * $294);
          $298 = Math_fround($295 * $295);
          $299 = Math_fround($298 + $297);
          $300 = Math_fround($296 * $296);
          $301 = Math_fround($299 + $300);
          $302 = (Math_fround(Math_sqrt((Math_fround($301)))));
          $303 = Math_fround($294 / $302);
          $304 = Math_fround($295 / $302);
          $305 = Math_fround($296 / $302);
          HEAPF32[$80>>2] = $303;
          HEAPF32[$v12$i>>2] = $303;
          HEAPF32[$81>>2] = $304;
          HEAPF32[$82>>2] = $304;
          HEAPF32[$83>>2] = $305;
          HEAPF32[$84>>2] = $305;
          HEAP32[$85>>2] = -1;
          $306 = Math_fround(HEAPF32[$vb$0$i>>2]);
          $307 = (($vb$0$i) + 4|0);
          $308 = (($vb$0$i) + 8|0);
          $309 = Math_fround(HEAPF32[$308>>2]);
          $310 = Math_fround($306 * Math_fround(0.5));
          $311 = Math_fround($312 * Math_fround(0.5));
          $313 = Math_fround($309 * Math_fround(0.5));
          $314 = Math_fround($290 + $310);
          $315 = Math_fround($311 + $291);
          $316 = Math_fround($293 + $313);
          $317 = Math_fround($314 * $314);
          $318 = Math_fround($315 * $315);
          $319 = Math_fround($318 + $317);
          $320 = Math_fround($316 * $316);
          $321 = Math_fround($319 + $320);
          $322 = (Math_fround(Math_sqrt((Math_fround($321)))));
          $323 = Math_fround($314 / $322);
          $324 = Math_fround($315 / $322);
          $325 = Math_fround($316 / $322);
          HEAPF32[$86>>2] = $323;
          HEAPF32[$v13$i>>2] = $323;
          HEAPF32[$87>>2] = $324;
          HEAPF32[$88>>2] = $324;
          HEAPF32[$89>>2] = $325;
          HEAPF32[$90>>2] = $325;
          HEAP32[$91>>2] = -1;
          __THREW__ = 0;
          invoke_vii(2654,($vertData|0),($top$0$i|0));
          $326 = __THREW__; __THREW__ = 0;
          $327 = $326&1;
          if ($327) {
           label = 55;
           break L46;
          }
          __THREW__ = 0;
          invoke_vii(2654,($vertData|0),($v12$i|0));
          $328 = __THREW__; __THREW__ = 0;
          $329 = $328&1;
          if ($329) {
           label = 55;
           break L46;
          }
          __THREW__ = 0;
          invoke_vii(2654,($vertData|0),($v13$i|0));
          $330 = __THREW__; __THREW__ = 0;
          $331 = $330&1;
          if ($331) {
           label = 55;
           break L46;
          }
          $332 = Math_fround(HEAPF32[$v13$i>>2]);
          $333 = Math_fround(HEAPF32[$va$0$i>>2]);
          $334 = Math_fround($332 - $333);
          $335 = Math_fround(HEAPF32[$88>>2]);
          $336 = Math_fround(HEAPF32[$283>>2]);
          $337 = Math_fround($335 - $336);
          $338 = Math_fround(HEAPF32[$90>>2]);
          $339 = Math_fround(HEAPF32[$284>>2]);
          $340 = Math_fround($338 - $339);
          $341 = Math_fround(HEAPF32[$v12$i>>2]);
          $342 = Math_fround(HEAPF32[$vb$0$i>>2]);
          $343 = Math_fround($341 - $342);
          $344 = Math_fround(HEAPF32[$82>>2]);
          $345 = Math_fround(HEAPF32[$307>>2]);
          $346 = Math_fround($344 - $345);
          $347 = Math_fround(HEAPF32[$84>>2]);
          $348 = Math_fround(HEAPF32[$308>>2]);
          $349 = Math_fround($347 - $348);
          $350 = Math_fround($334 * $334);
          $351 = Math_fround($337 * $337);
          $352 = Math_fround($350 + $351);
          $353 = Math_fround($340 * $340);
          $354 = Math_fround($352 + $353);
          $355 = Math_fround($343 * $343);
          $356 = Math_fround($346 * $346);
          $357 = Math_fround($355 + $356);
          $358 = Math_fround($349 * $349);
          $359 = Math_fround($357 + $358);
          $360 = $354 > $359;
          if ($360) {
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($v12$i|0));
           $361 = __THREW__; __THREW__ = 0;
           $362 = $361&1;
           if ($362) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($va$0$i|0));
           $363 = __THREW__; __THREW__ = 0;
           $364 = $363&1;
           if ($364) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($vb$0$i|0));
           $365 = __THREW__; __THREW__ = 0;
           $366 = $365&1;
           if ($366) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($v13$i|0));
           $367 = __THREW__; __THREW__ = 0;
           $368 = $367&1;
           if ($368) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($v12$i|0));
           $369 = __THREW__; __THREW__ = 0;
           $370 = $369&1;
           if ($370) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($vb$0$i|0));
           $371 = __THREW__; __THREW__ = 0;
           $372 = $371&1;
           if ($372) {
            label = 55;
            break L46;
           } else {
            break;
           }
          } else {
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($v13$i|0));
           $373 = __THREW__; __THREW__ = 0;
           $374 = $373&1;
           if ($374) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($v12$i|0));
           $375 = __THREW__; __THREW__ = 0;
           $376 = $375&1;
           if ($376) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($va$0$i|0));
           $377 = __THREW__; __THREW__ = 0;
           $378 = $377&1;
           if ($378) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($v13$i|0));
           $379 = __THREW__; __THREW__ = 0;
           $380 = $379&1;
           if ($380) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($va$0$i|0));
           $381 = __THREW__; __THREW__ = 0;
           $382 = $381&1;
           if ($382) {
            label = 55;
            break L46;
           }
           __THREW__ = 0;
           invoke_vii(2654,($vertData|0),($vb$0$i|0));
           $383 = __THREW__; __THREW__ = 0;
           $384 = $383&1;
           if ($384) {
            label = 55;
            break L46;
           } else {
            break;
           }
          }
         }
        } while(0);
        $385 = (($k3$058) + 3)|0;
        $386 = ($385|0)<($209|0);
        if ($386) {
         $k3$058 = $385;
        } else {
         break;
        }
       }
      }
     }
     $387 = ($210|0)>(-1);
     if ($387) {
      HEAP32[$7>>2] = $211;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$7+0>>2]|0;
      invoke_vii(2591,($208|0),($$byval_copy27|0));
      $388 = __THREW__; __THREW__ = 0;
      $389 = $388&1;
      if ($389) {
       label = 11;
       break;
      }
     }
     $390 = (($i$278) + 1)|0;
     $391 = ($390|0)<(2);
     if ($391) {
      $i$278 = $390;
     } else {
      label = 87;
      break;
     }
    }
    if ((label|0) == 11) {
     $74 = ___cxa_find_matching_catch()|0;
     $75 = tempRet0;
     $lpad$phi68$index = $74;$lpad$phi68$index3 = $75;
     label = 14;
     break;
    }
    else if ((label|0) == 55) {
     $256 = ___cxa_find_matching_catch()|0;
     $257 = tempRet0;
     $lpad$phi$index = $256;$lpad$phi$index14 = $257;
    }
    else if ((label|0) == 56) {
     $258 = ___cxa_find_matching_catch()|0;
     $259 = tempRet0;
     $lpad$phi$index = $258;$lpad$phi$index14 = $259;
    }
    else if ((label|0) == 87) {
     $392 = HEAP32[$21>>2]|0;
     $393 = (($392) + 280|0);
     $394 = HEAP32[$393>>2]|0;
     $395 = HEAP32[577992>>2]|0;
     $396 = HEAP32[$26>>2]|0;
     $397 = ($396*28)|0;
     $398 = HEAP32[$vertData>>2]|0;
     __THREW__ = 0;
     invoke_viiiiiii($394|0,($21|0),($395|0),0,0,($397|0),($398|0),0);
     $399 = __THREW__; __THREW__ = 0;
     $400 = $399&1;
     if ($400) {
      label = 13;
      break;
     }
     $401 = HEAP32[$26>>2]|0;
     HEAP32[577112>>2] = $401;
     $402 = HEAP32[577992>>2]|0;
     $403 = HEAP32[$27>>2]|0;
     $404 = ($403|0)>(-1);
     if (!($404)) {
      $$0 = $402;
      STACKTOP = sp;return ($$0|0);
     }
     $405 = HEAP32[$vertData>>2]|0;
     $406 = HEAP32[$28>>2]|0;
     HEAP32[$0>>2] = $406;
     ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($405,$$byval_copy27);
     HEAP32[$vertData>>2] = 0;
     $$0 = $402;
     STACKTOP = sp;return ($$0|0);
    }
    $260 = ($210|0)>(-1);
    if (!($260)) {
     $$01 = $lpad$phi$index;$$02 = $lpad$phi$index14;
     break;
    }
    HEAP32[$0>>2] = $211;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($208|0),($$byval_copy27|0));
    $261 = __THREW__; __THREW__ = 0;
    $262 = $261&1;
    if (!($262)) {
     $$01 = $lpad$phi$index;$$02 = $lpad$phi$index14;
     break;
    }
    $413 = ___cxa_find_matching_catch(0|0)|0;
    $414 = tempRet0;
    ___clang_call_terminate($413);
    // unreachable;
   }
   else if ((label|0) == 33) {
    $197 = ___cxa_find_matching_catch()|0;
    $198 = tempRet0;
    $lpad$phi83$index = $197;$lpad$phi83$index9 = $198;
   }
   else if ((label|0) == 34) {
    $199 = ___cxa_find_matching_catch()|0;
    $200 = tempRet0;
    $lpad$phi83$index = $199;$lpad$phi83$index9 = $200;
   }
   $201 = ($93|0)>(-1);
   if ($201) {
    HEAP32[$4>>2] = $94;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($106|0),($$byval_copy27|0));
    $202 = __THREW__; __THREW__ = 0;
    $203 = $202&1;
    if ($203) {
     $413 = ___cxa_find_matching_catch(0|0)|0;
     $414 = tempRet0;
     ___clang_call_terminate($413);
     // unreachable;
    } else {
     $$01 = $lpad$phi83$index;$$02 = $lpad$phi83$index9;
    }
   } else {
    $$01 = $lpad$phi83$index;$$02 = $lpad$phi83$index9;
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  $lpad$phi68$index = $78;$lpad$phi68$index3 = $79;
  label = 14;
 }
 if ((label|0) == 14) {
  $$01 = $lpad$phi68$index;$$02 = $lpad$phi68$index3;
 }
 $407 = HEAP32[$27>>2]|0;
 $408 = ($407|0)>(-1);
 if (!($408)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $409 = HEAP32[$vertData>>2]|0;
 $410 = HEAP32[$28>>2]|0;
 HEAP32[$8>>2] = $410;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$8+0>>2]|0;
 invoke_vii(2591,($409|0),($$byval_copy27|0));
 $411 = __THREW__; __THREW__ = 0;
 $412 = $411&1;
 if ($412) {
  $413 = ___cxa_find_matching_catch(0|0)|0;
  $414 = tempRet0;
  ___clang_call_terminate($413);
  // unreachable;
 }
 HEAP32[$vertData>>2] = 0;
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __ZN13dynamic_arrayIN15SkyboxGenerator19CubemapSkyboxVertexELj4EE9push_backERKS1_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = $5 << 1;
  $9 = ($8|0)==(0);
  $10 = $9 ? 1 : $8;
  $11 = ($6>>>0)<($10>>>0);
  do {
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*28)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,578296,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*28)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,578296,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*28)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$1>>2]|0;
  $26 = $$pre$i;
 } else {
  $26 = $3;
 }
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($25*28)|0)|0);
 ;HEAP32[$28+0>>2]=HEAP32[$t+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$t+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$t+8>>2]|0;
 $29 = ((($27) + (($25*28)|0)|0) + 12|0);
 $30 = (($t) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 HEAP32[$29>>2] = $31;
 $32 = ((($27) + (($25*28)|0)|0) + 16|0);
 $33 = (($t) + 16|0);
 ;HEAP32[$32+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$33+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN15SkyboxGenerator33GetCubemapSkyboxVertexDeclarationEj($shaderChannels) {
 $shaderChannels = $shaderChannels|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $channels = 0, $layout = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $layout = sp + 32|0;
 $channels = sp;
 $0 = HEAP32[578288>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $5 = $0;
  $6 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($5,$shaderChannels,0)|0);
  STACKTOP = sp;return ($6|0);
 }
 dest=$layout+0|0; src=588176+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $2 = (($layout) + 7|0);
 HEAP8[$2>>0] = 3;
 ;HEAP32[$channels+0>>2]=0|0;HEAP32[$channels+4>>2]=0|0;HEAP32[$channels+8>>2]=0|0;HEAP32[$channels+12>>2]=0|0;HEAP32[$channels+16>>2]=0|0;HEAP32[$channels+20>>2]=0|0;HEAP32[$channels+24>>2]=0|0;HEAP32[$channels+28>>2]=0|0;
 (__Z28BuildSingleStreamChannelInfojRK20VertexChannelsLayoutP11ChannelInfo(13,$layout,$channels)|0);
 $3 = (__Z26GetMeshVertexFormatManagerv()|0);
 $4 = (__ZN23MeshVertexFormatManager19GetMeshVertexFormatERK18VertexChannelsInfo($3,$channels)|0);
 HEAP32[578288>>2] = $4;
 $5 = $4;
 $6 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($5,$shaderChannels,0)|0);
 STACKTOP = sp;return ($6|0);
}
function __GLOBAL__I_a2517() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[577096>>2] = 13;
 HEAP32[577104>>2] = 0;
 HEAPF32[577120>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 4|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 8|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 12|0))>>2] = -1;
 HEAPF32[((577120 + 16|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 20|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 24|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 28|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 32|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 36|0))>>2] = -1;
 HEAPF32[((577120 + 40|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 44|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 48|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 52|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 56|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 60|0))>>2] = -1;
 HEAPF32[((577120 + 64|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 68|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 72|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 76|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 80|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 84|0))>>2] = -1;
 HEAPF32[((577120 + 88|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 92|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 96|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 100|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 104|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 108|0))>>2] = -1;
 HEAPF32[((577120 + 112|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 116|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 120|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 124|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 128|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 132|0))>>2] = -1;
 HEAPF32[((577120 + 136|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 140|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 144|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 148|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 152|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 156|0))>>2] = -1;
 HEAPF32[((577120 + 160|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 164|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 168|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 172|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 176|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 180|0))>>2] = -1;
 HEAPF32[((577120 + 184|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 188|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 192|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 196|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 200|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 204|0))>>2] = -1;
 HEAPF32[((577120 + 208|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 212|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 216|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 220|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 224|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 228|0))>>2] = -1;
 HEAPF32[((577120 + 232|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 236|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 240|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 244|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 248|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 252|0))>>2] = -1;
 HEAPF32[((577120 + 256|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 260|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 264|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 268|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 272|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 276|0))>>2] = -1;
 HEAPF32[((577120 + 280|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 284|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 288|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 292|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 296|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 300|0))>>2] = -1;
 HEAPF32[((577120 + 304|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 308|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 312|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 316|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 320|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 324|0))>>2] = -1;
 HEAPF32[((577120 + 328|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 332|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 336|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 340|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 344|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 348|0))>>2] = -1;
 HEAPF32[((577120 + 352|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 356|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 360|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 364|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 368|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 372|0))>>2] = -1;
 HEAPF32[((577120 + 376|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 380|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 384|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 388|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 392|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 396|0))>>2] = -1;
 HEAPF32[((577120 + 400|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 404|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 408|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 412|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 416|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 420|0))>>2] = -1;
 HEAPF32[((577120 + 424|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 428|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 432|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 436|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 440|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 444|0))>>2] = -1;
 HEAPF32[((577120 + 448|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 452|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 456|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 460|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 464|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 468|0))>>2] = -1;
 HEAPF32[((577120 + 472|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 476|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 480|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 484|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 488|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 492|0))>>2] = -1;
 HEAPF32[((577120 + 496|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 500|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 504|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 508|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 512|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 516|0))>>2] = -1;
 HEAPF32[((577120 + 520|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 524|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 528|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 532|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 536|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 540|0))>>2] = -1;
 HEAPF32[((577120 + 544|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 548|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 552|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 556|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 560|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 564|0))>>2] = -1;
 HEAPF32[((577120 + 568|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 572|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 576|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 580|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 584|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 588|0))>>2] = -1;
 HEAPF32[((577120 + 592|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 596|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 600|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 604|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 608|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 612|0))>>2] = -1;
 HEAPF32[((577120 + 616|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 620|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 624|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 628|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 632|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 636|0))>>2] = -1;
 HEAPF32[((577120 + 640|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 644|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 648|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 652|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 656|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 660|0))>>2] = -1;
 HEAPF32[((577120 + 664|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 668|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 672|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 676|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 680|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 684|0))>>2] = -1;
 HEAPF32[((577120 + 688|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 692|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 696|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 700|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 704|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 708|0))>>2] = -1;
 HEAPF32[((577120 + 712|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 716|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 720|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 724|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 728|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 732|0))>>2] = -1;
 HEAPF32[((577120 + 736|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 740|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 744|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 748|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 752|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 756|0))>>2] = -1;
 HEAPF32[((577120 + 760|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 764|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 768|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 772|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 776|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 780|0))>>2] = -1;
 HEAPF32[((577120 + 784|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 788|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 792|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 796|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 800|0))>>2] = Math_fround(1.0);
 HEAP32[((577120 + 804|0))>>2] = -1;
 HEAPF32[((577120 + 808|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 812|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 816|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 820|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 824|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 828|0))>>2] = -1;
 HEAPF32[((577120 + 832|0))>>2] = Math_fround(1.0);
 HEAPF32[((577120 + 836|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 840|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 844|0))>>2] = Math_fround(-1.0);
 HEAPF32[((577120 + 848|0))>>2] = Math_fround(-1.0);
 HEAP32[((577120 + 852|0))>>2] = -1;
 HEAPF32[((577120 + 856|0))>>2] = Math_fround(0.0);
 HEAPF32[((577120 + 860|0))>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __Z9CullSceneR8JobFenceS0_RK22SceneCullingParametersR13CullingOutput($staticOcclusionCulling,$dynamicOcclusionCulling,$cullingParams,$output) {
 $staticOcclusionCulling = $staticOcclusionCulling|0;
 $dynamicOcclusionCulling = $dynamicOcclusionCulling|0;
 $cullingParams = $cullingParams|0;
 $output = $output|0;
 var $$$i = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $i$01$i1 = 0, $occlusionBuffer$0$i = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($output) + 60|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $59 = $0;$occlusionBuffer$0$i = 0;
 } else {
  $5 = HEAP32[628520>>2]|0;
  HEAP32[$0>>2] = $5;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $6 = (__Znwj10MemLabelIdbiPKci(44,$$byval_copy2,0,16,578304,198)|0);
  $7 = (__Z22GetJobQueueThreadCountv()|0);
  $8 = ($7|0)>(2);
  $$$i = $8 ? 6 : 1;
  $9 = (($6) + 4|0);
  HEAP32[$9>>2] = $$$i;
  HEAP32[$6>>2] = $cullingParams;
  $10 = (($6) + 40|0);
  HEAP32[$10>>2] = $output;
  $11 = (($output) + 64|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($6) + 8|0);
  HEAP32[$13>>2] = $12;
  if ($8) {
   $14 = (($cullingParams) + 688|0);
   $i$01$i = 1;
   while(1) {
    $15 = (__Z9GetIUmbrav()|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$14>>2]|0;
    $20 = HEAP32[628520>>2]|0;
    HEAP32[$1>>2] = $20;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    $21 = (FUNCTION_TABLE_iiiii[$18 & 511]($15,$19,0,$$byval_copy2)|0);
    $22 = (($13) + ($i$01$i<<2)|0);
    HEAP32[$22>>2] = $21;
    $23 = (($i$01$i) + 1)|0;
    $24 = ($23|0)<($$$i|0);
    if ($24) {
     $i$01$i = $23;
    } else {
     break;
    }
   }
  }
  __Z15ScheduleForEachR8JobFencePFvPvjES1_iPFvS1_E11JobPriority($staticOcclusionCulling,2655,$6,$$$i,3437,0);
  $$pre = HEAP8[$2>>0]|0;
  $phitmp = ($$pre<<24>>24)==(0);
  if ($phitmp) {
   $59 = $0;$occlusionBuffer$0$i = 0;
  } else {
   $25 = (__Z9GetIUmbrav()|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + 28|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($output) + 64|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (FUNCTION_TABLE_iii[$28 & 4095]($25,$30)|0);
   $59 = $0;$occlusionBuffer$0$i = $31;
  }
 }
 $i$01$i1 = 0;
 while(1) {
  $32 = ((($cullingParams) + (($i$01$i1*12)|0)|0) + 616|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0);
  if (!($34)) {
   $35 = ((($cullingParams) + (($i$01$i1*12)|0)|0) + 608|0);
   $36 = HEAP32[628520>>2]|0;
   HEAP32[$0>>2] = $36;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $37 = (__Znwj10MemLabelIdbiPKci(220,$$byval_copy2,0,16,578304,119)|0);
   HEAP32[$37>>2] = $cullingParams;
   $38 = (($37) + 8|0);
   HEAP32[$38>>2] = $35;
   $39 = (($output) + (($i$01$i1*12)|0)|0);
   $40 = (($37) + 20|0);
   HEAP32[$40>>2] = $39;
   $41 = (($37) + 12|0);
   HEAP32[$41>>2] = $2;
   $42 = (($37) + 4|0);
   HEAP32[$42>>2] = $occlusionBuffer$0$i;
   $43 = (($37) + 16|0);
   HEAP32[$43>>2] = $i$01$i1;
   $44 = ($i$01$i1|0)==(0);
   if ($44) {
    $47 = HEAP8[$2>>0]|0;
    $48 = ($47<<24>>24)==(0);
    $49 = (($37) + 24|0);
    $50 = HEAP32[$32>>2]|0;
    if ($48) {
     $53 = $49;$54 = $50;
     label = 14;
    } else {
     $51 = (__Z20ConfigureBlockRangesP10BlockRangeii($49,$50,1)|0);
     $52 = (($37) + 216|0);
     HEAP32[$52>>2] = $51;
     $57 = $51;
    }
   } else {
    $45 = (($37) + 24|0);
    $46 = HEAP32[$32>>2]|0;
    $53 = $45;$54 = $46;
    label = 14;
   }
   if ((label|0) == 14) {
    label = 0;
    $55 = (__Z40ConfigureBlockRangesWithMinIndicesPerJobP10BlockRangeii($53,$54,256)|0);
    $56 = (($37) + 216|0);
    HEAP32[$56>>2] = $55;
    $57 = $55;
   }
   __Z21ScheduleForEachJobSetR8JobFencePFvPvjES1_iPFvS1_ES0_11JobPriority($dynamicOcclusionCulling,2656,$37,$57,3438,$staticOcclusionCulling,0);
  }
  $58 = (($i$01$i1) + 1)|0;
  $exitcond$i = ($58|0)==(5);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i1 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __Z32CountListsWithValidRendererCountPK16RendererCullData($cullData) {
 $cullData = $cullData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0$$1 = 0, $count$0$$2 = 0, $count$0$$3 = 0, $count$0$$4 = 0, $not$ = 0;
 var $not$$1 = 0, $not$$2 = 0, $not$$3 = 0, $not$$4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cullData) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $not$ = ($1|0)!=(0);
 $2 = $not$&1;
 $3 = (($cullData) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $not$$1 = ($4|0)!=(0);
 $5 = $not$$1&1;
 $count$0$$1 = (($5) + ($2))|0;
 $6 = (($cullData) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $not$$2 = ($7|0)!=(0);
 $8 = $not$$2&1;
 $count$0$$2 = (($8) + ($count$0$$1))|0;
 $9 = (($cullData) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $not$$3 = ($10|0)!=(0);
 $11 = $not$$3&1;
 $count$0$$3 = (($11) + ($count$0$$2))|0;
 $12 = (($cullData) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $not$$4 = ($13|0)!=(0);
 $14 = $not$$4&1;
 $count$0$$4 = (($14) + ($count$0$$3))|0;
 STACKTOP = sp;return ($count$0$$4|0);
}
function __ZL24QueryPortalVisibilityJobPvj($userData,$index) {
 $userData = $userData|0;
 $index = $index|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($userData) + 8|0);
 $1 = (($0) + ($index<<2)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z9GetIUmbrav()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$userData>>2]|0;
 $8 = (($7) + 700|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($userData) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiii[$6 & 255]($3,$2,$7,$9,$index,$11)|0);
 $$sum = (($index) + 32)|0;
 $13 = (($userData) + ($$sum)|0);
 $14 = $12&1;
 HEAP8[$13>>0] = $14;
 STACKTOP = sp;return;
}
function __ZL31QueryPortalVisibilityCombineJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy1 = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $i1$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($userData) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($userData) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 $7 = (($3) + 60|0);
 if ($6) {
  $i$04 = 0;
  while(1) {
   $$sum = (($i$04) + 32)|0;
   $8 = (($userData) + ($$sum)|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)==(0);
   if (!($10)) {
    HEAP8[$7>>0] = 0;
   }
   $11 = (($i$04) + 1)|0;
   $12 = ($11|0)<($5|0);
   if ($12) {
    $i$04 = $11;
   } else {
    break;
   }
  }
 }
 $13 = HEAP8[$7>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $30 = $5;
 } else {
  $15 = (__Z9GetIUmbrav()|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 56|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$userData>>2]|0;
  $20 = (($19) + 688|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($userData) + 8|0);
  $23 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_viiiii[$18 & 255]($15,$3,$21,$22,$23);
  $24 = HEAP32[$userData>>2]|0;
  $25 = (($24) + 612|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 608|0);
  $28 = HEAP32[$27>>2]|0;
  __Z34ProcessIndexListIsNodeVisibleInOutRK22SceneCullingParametersPK9SceneNodePK4AABBR9IndexList($24,$26,$28,$3);
  $$pre = HEAP32[$4>>2]|0;
  $30 = $$pre;
 }
 $29 = ($30|0)>(1);
 if (!($29)) {
  $42 = HEAP32[628520>>2]|0;
  HEAP32[$0>>2] = $42;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy1);
  STACKTOP = sp;return;
 }
 $31 = (($userData) + 8|0);
 $i1$03 = 1;
 while(1) {
  $32 = (__Z9GetIUmbrav()|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 36|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($31) + ($i1$03<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[628520>>2]|0;
  HEAP32[$1>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  FUNCTION_TABLE_viiii[$35 & 511]($32,$37,1,$$byval_copy1);
  $39 = (($i1$03) + 1)|0;
  $40 = HEAP32[$4>>2]|0;
  $41 = ($39|0)<($40|0);
  if ($41) {
   $i1$03 = $39;
  } else {
   break;
  }
 }
 $42 = HEAP32[628520>>2]|0;
 HEAP32[$0>>2] = $42;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy1);
 STACKTOP = sp;return;
}
function __ZL21CullDynamicObjectsJobPvj($userData,$index) {
 $userData = $userData|0;
 $index = $index|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $output = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $output = sp;
 $0 = (($userData) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($userData) + 12|0);
 if ($2) {
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   STACKTOP = sp;return;
  }
 }
 $7 = (($userData) + 24|0);
 $8 = (($userData) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($7) + (($index*12)|0)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12<<2)|0);
 $14 = ((($7) + (($index*12)|0)|0) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$output>>2] = $13;
 $16 = (($output) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = (($output) + 8|0);
 HEAP32[$17>>2] = $15;
 $18 = (($userData) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$userData>>2]|0;
 $21 = (($19) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($15) + ($12))|0;
 __Z34ProcessIndexListIsNodeVisibleStep1RK22SceneCullingParametersPK9SceneNodejjR9IndexList($20,$22,$12,$23,$output);
 $24 = HEAP32[$3>>2]|0;
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $31 = HEAP32[$userData>>2]|0;
  $32 = HEAP32[$19>>2]|0;
  __Z23CullObjectsWithoutUmbraRK22SceneCullingParametersPK4AABBR9IndexList($31,$32,$output);
  $$pre$phiZ2D = $19;
 } else {
  $27 = HEAP32[$18>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($userData) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  __Z23CullDynamicObjectsUmbraPK4AABBPKN5Umbra15OcclusionBufferER9IndexList($28,$30,$output);
  $$pre$phiZ2D = $19;
 }
 $33 = HEAP32[$userData>>2]|0;
 $34 = HEAP32[$21>>2]|0;
 $35 = HEAP32[$$pre$phiZ2D>>2]|0;
 __Z34ProcessIndexListIsNodeVisibleStep2RK22SceneCullingParametersPK9SceneNodePK4AABBR9IndexList($33,$34,$35,$output);
 $36 = HEAP32[$userData>>2]|0;
 $37 = (($36) + 704|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = HEAP32[$21>>2]|0;
  $41 = HEAP32[$$pre$phiZ2D>>2]|0;
  $42 = (($36) + 708|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_viiii[$38 & 511]($40,$41,$output,$43);
 }
 $44 = HEAP32[$16>>2]|0;
 HEAP32[$14>>2] = $44;
 STACKTOP = sp;return;
}
function __ZL26CullDynamicSceneCombineJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond10$i = 0, $i$03$i = 0, $j$02$i = 0, $visibleCountNodes$0$lcssa$i = 0, $visibleCountNodes$04$i = 0, $visibleCountNodes$1$lcssa$i = 0;
 var $visibleCountNodes$11$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($userData) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($userData) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   $31 = HEAP32[628520>>2]|0;
   HEAP32[$0>>2] = $31;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy);
   STACKTOP = sp;return;
  }
 }
 $8 = (($userData) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($userData) + 24|0);
 $11 = (($userData) + 216|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($userData) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12|0)>(1);
 if ($15) {
  $i$03$i = 1;$visibleCountNodes$04$i = $14;
  while(1) {
   $16 = (($10) + (($i$03$i*12)|0)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($10) + (($i$03$i*12)|0)|0) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + ($17))|0;
   $21 = ($17>>>0)<($20>>>0);
   if ($21) {
    $22 = HEAP32[$9>>2]|0;
    $j$02$i = $17;$visibleCountNodes$11$i = $visibleCountNodes$04$i;
    while(1) {
     $23 = (($22) + ($j$02$i<<2)|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($visibleCountNodes$11$i) + 1)|0;
     $26 = (($22) + ($visibleCountNodes$11$i<<2)|0);
     HEAP32[$26>>2] = $24;
     $27 = (($j$02$i) + 1)|0;
     $exitcond$i = ($27|0)==($20|0);
     if ($exitcond$i) {
      break;
     } else {
      $j$02$i = $27;$visibleCountNodes$11$i = $25;
     }
    }
    $28 = (($19) + ($visibleCountNodes$04$i))|0;
    $visibleCountNodes$1$lcssa$i = $28;
   } else {
    $visibleCountNodes$1$lcssa$i = $visibleCountNodes$04$i;
   }
   $29 = (($i$03$i) + 1)|0;
   $exitcond10$i = ($29|0)==($12|0);
   if ($exitcond10$i) {
    $visibleCountNodes$0$lcssa$i = $visibleCountNodes$1$lcssa$i;
    break;
   } else {
    $i$03$i = $29;$visibleCountNodes$04$i = $visibleCountNodes$1$lcssa$i;
   }
  }
 } else {
  $visibleCountNodes$0$lcssa$i = $14;
 }
 $30 = (($9) + 4|0);
 HEAP32[$30>>2] = $visibleCountNodes$0$lcssa$i;
 $31 = HEAP32[628520>>2]|0;
 HEAP32[$0>>2] = $31;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z16GetSceneSettingsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(15)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z19GetSceneSettingsPtrv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24GetManagerPtrFromContexti(15)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIhLj1EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy2 = 0, $$ph = 0, $$pr = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, $storemerge = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if (!($5)) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$2>>2]|0;
   $$pre7 = HEAP32[$8>>2]|0;
   $12 = $$pre$i$i$i;$15 = $$pre;$17 = $$pre7;
  } else {
   $11 = HEAP32[$6>>2]|0;
   HEAP32[$size>>2] = $11;
   HEAP32[$2>>2] = $7;
   $12 = $11;$15 = $7;$17 = $9;
  }
  $13 = (_llvm_bswap_i32(($12|0))|0);
  HEAP32[$size>>2] = $13;
  $14 = (($15) + 4|0);
  $16 = ($14>>>0)>($17>>>0);
  if ($16) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $19 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $18 = HEAP32[$15>>2]|0;
   HEAP32[$offset>>2] = $18;
   HEAP32[$2>>2] = $14;
   $19 = $18;$21 = $13;
  }
  $20 = (_llvm_bswap_i32(($19|0))|0);
  HEAP32[$offset>>2] = $20;
  $22 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$20,$21)|0);
  $23 = (($data) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)>(-1);
  if ($25) {
   $26 = HEAP32[$data>>2]|0;
   $27 = (($data) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$1>>2] = $28;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($26,$$byval_copy2);
   HEAP32[$data>>2] = 0;
  }
  $29 = (($data) + 8|0);
  HEAP32[$29>>2] = $21;
  $30 = $21 | -2147483648;
  HEAP32[$23>>2] = $30;
  HEAP32[$data>>2] = $22;
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $32 = $$pre$i$i$i4;
 } else {
  $31 = HEAP32[$6>>2]|0;
  HEAP32[$size1>>2] = $31;
  HEAP32[$2>>2] = $7;
  $32 = $31;
 }
 $33 = (_llvm_bswap_i32(($32|0))|0);
 HEAP32[$size1>>2] = $33;
 $34 = HEAP32[$data>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $36 = (($this) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($data) + 4|0);
  HEAP32[$38>>2] = $37;
 }
 $39 = (($data) + 8|0);
 HEAP32[$39>>2] = $33;
 $40 = (($data) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 2147483647;
 $43 = ($42>>>0)<($33>>>0);
 if ($43) {
  $44 = ($41|0)>(-1);
  if ($44) {
   HEAP32[$40>>2] = $33;
   $45 = (($data) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   HEAP32[$1>>2] = $46;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   $47 = (__Z16realloc_internalPvji10MemLabelIdiPKci($34,$33,1,$$byval_copy2,0,578320,370)|0);
   $$ph = $47;$storemerge = $47;
  } else {
   $48 = (($data) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   HEAP32[$1>>2] = $49;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   $50 = (__Z15malloc_internaljj10MemLabelIdiPKci($33,1,$$byval_copy2,0,578320,352)|0);
   $51 = HEAP32[$data>>2]|0;
   $52 = HEAP32[$39>>2]|0;
   _memcpy(($50|0),($51|0),($52|0))|0;
   HEAP32[$40>>2] = $33;
   $$ph = $50;$storemerge = $50;
  }
  HEAP32[$data>>2] = $storemerge;
  $$pr = HEAP32[$39>>2]|0;
  $54 = $$ph;$55 = $$pr;
 } else {
  $54 = $34;$55 = $33;
 }
 $53 = (($54) + ($55)|0);
 $56 = ($55|0)==(0);
 if ($56) {
  STACKTOP = sp;return;
 } else {
  $i$06 = $54;
 }
 while(1) {
  $57 = HEAP32[$2>>2]|0;
  $58 = (($57) + 1|0);
  $59 = HEAP32[$8>>2]|0;
  $60 = ($58>>>0)>($59>>>0);
  if ($60) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$i$06,1);
  } else {
   $61 = HEAP8[$57>>0]|0;
   HEAP8[$i$06>>0] = $61;
   $62 = HEAP32[$2>>2]|0;
   $63 = (($62) + 1|0);
   HEAP32[$2>>2] = $63;
  }
  $64 = (($i$06) + 1|0);
  $65 = ($64|0)==($53|0);
  if ($65) {
   break;
  } else {
   $i$06 = $64;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIhLj1EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if (!($5)) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
   $$pre4 = HEAP32[$2>>2]|0;
   $$pre5 = HEAP32[$8>>2]|0;
   $13 = $$pre4;$15 = $$pre5;
  } else {
   $11 = HEAP32[$6>>2]|0;
   HEAP32[$size>>2] = $11;
   HEAP32[$2>>2] = $7;
   $13 = $7;$15 = $9;
  }
  $12 = (($13) + 4|0);
  $14 = ($12>>>0)>($15>>>0);
  if ($14) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
   $$pre6 = HEAP32[$offset>>2]|0;
   $18 = $$pre6;
  } else {
   $16 = HEAP32[$13>>2]|0;
   HEAP32[$offset>>2] = $16;
   HEAP32[$2>>2] = $12;
   $18 = $16;
  }
  $17 = HEAP32[$size>>2]|0;
  $19 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$18,$17)|0);
  $20 = (($data) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)>(-1);
  if ($22) {
   $23 = HEAP32[$data>>2]|0;
   $24 = (($data) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$1>>2] = $25;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($23,$$byval_copy2);
   HEAP32[$data>>2] = 0;
  }
  $26 = (($data) + 8|0);
  HEAP32[$26>>2] = $17;
  $27 = $17 | -2147483648;
  HEAP32[$20>>2] = $27;
  HEAP32[$data>>2] = $19;
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $35 = $$pre;
 } else {
  $28 = HEAP32[$6>>2]|0;
  HEAP32[$size1>>2] = $28;
  HEAP32[$2>>2] = $7;
  $35 = $28;
 }
 $29 = HEAP32[$data>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  $31 = (($this) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($data) + 4|0);
  HEAP32[$33>>2] = $32;
 }
 $34 = (($data) + 8|0);
 HEAP32[$34>>2] = $35;
 $36 = (($data) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38>>>0)<($35>>>0);
 do {
  if ($39) {
   $40 = ($37|0)>(-1);
   if ($40) {
    HEAP32[$36>>2] = $35;
    $41 = (($data) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    HEAP32[$1>>2] = $42;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    $43 = (__Z16realloc_internalPvji10MemLabelIdiPKci($29,$35,1,$$byval_copy2,0,578320,370)|0);
    HEAP32[$data>>2] = $43;
    $51 = $43;
    break;
   } else {
    $44 = (($data) + 4|0);
    $45 = HEAP32[$44>>2]|0;
    HEAP32[$1>>2] = $45;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    $46 = (__Z15malloc_internaljj10MemLabelIdiPKci($35,1,$$byval_copy2,0,578320,352)|0);
    $47 = HEAP32[$data>>2]|0;
    $48 = HEAP32[$34>>2]|0;
    _memcpy(($46|0),($47|0),($48|0))|0;
    HEAP32[$36>>2] = $35;
    HEAP32[$data>>2] = $46;
    $51 = $46;
    break;
   }
  } else {
   $51 = $29;
  }
 } while(0);
 $49 = HEAP32[$size1>>2]|0;
 $50 = ($49|0)==(0);
 if ($50) {
  STACKTOP = sp;return;
 }
 __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$51,$49);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIhLj1EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $i$03 = 0, $i$15 = 0, $size = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $1 = sp + 12|0;
 $size = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,578328,578328,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$data>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($data) + 4|0);
  HEAP32[$11>>2] = $10;
 }
 HEAP32[$3>>2] = $6;
 $12 = (($data) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14>>>0)<($6>>>0);
 do {
  if ($15) {
   $16 = ($13|0)>(-1);
   if ($16) {
    HEAP32[$12>>2] = $6;
    $17 = (($data) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$1>>2] = $18;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $19 = (__Z16realloc_internalPvji10MemLabelIdiPKci($7,$6,1,$$byval_copy1,0,578320,370)|0);
    HEAP32[$data>>2] = $19;
    $27 = $19;
    break;
   } else {
    $20 = (($data) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$1>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($6,1,$$byval_copy1,0,578320,352)|0);
    $23 = HEAP32[$data>>2]|0;
    $24 = HEAP32[$3>>2]|0;
    _memcpy(($22|0),($23|0),($24|0))|0;
    HEAP32[$12>>2] = $6;
    HEAP32[$data>>2] = $22;
    $27 = $22;
    break;
   }
  } else {
   $27 = $7;
  }
 } while(0);
 $25 = HEAP32[$3>>2]|0;
 $26 = (($27) + ($25)|0);
 $28 = HEAP32[$size>>2]|0;
 $29 = ($28|0)==(0);
 L13: do {
  if (!($29)) {
   $30 = HEAP32[580744>>2]|0;
   $31 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,578312,$30,0,0)|0);
   $32 = (($this) + 80|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (__ZNK16TypeTreeIterator7GetNodeEv($33)|0);
   $35 = (($34) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($this) + 84|0);
   $38 = HEAP32[$37>>2]|0;
   HEAP32[$38>>2] = 0;
   $39 = ($31|0)==(2);
   if (!($39)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $87 = HEAP32[$data>>2]|0;
    $88 = ($87|0)==($26|0);
    if ($88) {
     break;
    } else {
     $i$15 = $87;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIhEEvRT_PKc17TransferMetaFlags($this,$i$15,578312,0);
     $89 = (($i$15) + 1|0);
     $90 = ($89|0)==($26|0);
     if ($90) {
      break L13;
     } else {
      $i$15 = $89;
     }
    }
   }
   $40 = HEAP32[$32>>2]|0;
   $41 = (($40) + 12|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$data>>2]|0;
   $44 = ($43|0)==($26|0);
   L20: do {
    if (!($44)) {
     $45 = (($this) + 12|0);
     $46 = (($this) + 16|0);
     $47 = (($this) + 28|0);
     $48 = (($this) + 32|0);
     $49 = (($this) + 20|0);
     $51 = 0;$54 = $40;$i$03 = $43;
     while(1) {
      $50 = Math_imul($51, $36)|0;
      $52 = (($50) + ($42))|0;
      $53 = (($54) + 20|0);
      HEAP32[$53>>2] = $52;
      $55 = (($54) + 12|0);
      HEAP32[$55>>2] = $52;
      $56 = (($54) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($2,$54);
      $57 = $2;
      $58 = $57;
      $59 = HEAP32[$58>>2]|0;
      $60 = (($57) + 4)|0;
      $61 = $60;
      $62 = HEAP32[$61>>2]|0;
      $63 = $56;
      $64 = $63;
      HEAP32[$64>>2] = $59;
      $65 = (($63) + 4)|0;
      $66 = $65;
      HEAP32[$66>>2] = $62;
      $67 = HEAP32[$37>>2]|0;
      $68 = HEAP32[$67>>2]|0;
      $69 = (($68) + 1)|0;
      HEAP32[$67>>2] = $69;
      $70 = HEAP32[$32>>2]|0;
      $71 = (($70) + 12|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = HEAP32[$46>>2]|0;
      $74 = HEAP32[$47>>2]|0;
      $75 = HEAP32[$48>>2]|0;
      $76 = Math_imul($75, $74)|0;
      $$sum$i$i$i = (($72) - ($76))|0;
      $77 = (($73) + ($$sum$i$i$i)|0);
      HEAP32[$45>>2] = $77;
      $78 = ($$sum$i$i$i|0)<(0);
      if ($78) {
       label = 15;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
       $79 = (($73) + ($$sum1$i$i$i)|0);
       $80 = HEAP32[$49>>2]|0;
       $81 = ($79>>>0)>($80>>>0);
       if ($81) {
        label = 15;
       } else {
        $82 = HEAP8[$77>>0]|0;
        HEAP8[$i$03>>0] = $82;
        $83 = HEAP32[$45>>2]|0;
        $84 = (($83) + 1|0);
        HEAP32[$45>>2] = $84;
       }
      }
      if ((label|0) == 15) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($45,$i$03,1);
      }
      $85 = (($i$03) + 1|0);
      $86 = ($85|0)==($26|0);
      if ($86) {
       break L20;
      }
      $$pre = HEAP32[$37>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$32>>2]|0;
      $51 = $$pre8;$54 = $$pre9;$i$03 = $85;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferIhEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i$i = 0, $$sum1$i$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580744>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 do {
  if ($4) {
   $5 = (($this) + 12|0);
   $6 = (($this) + 80|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($this) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($this) + 32|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = Math_imul($15, $13)|0;
   $$sum$i$i$i$i = (($9) - ($16))|0;
   $17 = (($11) + ($$sum$i$i$i$i)|0);
   HEAP32[$5>>2] = $17;
   $18 = ($$sum$i$i$i$i|0)<(0);
   if (!($18)) {
    $$sum1$i$i$i$i = (($$sum$i$i$i$i) + 1)|0;
    $19 = (($11) + ($$sum1$i$i$i$i)|0);
    $20 = (($this) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($19>>>0)>($21>>>0);
    if (!($22)) {
     $23 = HEAP8[$17>>0]|0;
     HEAP8[$data>>0] = $23;
     $24 = HEAP32[$5>>2]|0;
     $25 = (($24) + 1|0);
     HEAP32[$5>>2] = $25;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,1);
  } else {
   $26 = HEAP32[$converter$i>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    (FUNCTION_TABLE_iii[$26 & 4095]($data,$this)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN5Unity5SceneC2Ev($this) {
 $this = $this|0;
 var $$byval_copy14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $eh$lpad$body$indexZ2D = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy14 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = sp + 24|0;
 HEAP32[$this>>2] = 0;
 $7 = (($this) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 4|0);
 HEAP32[$9>>2] = 61;
 $10 = (($this) + 16|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 24|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 20|0);
 HEAP32[$13>>2] = 61;
 $14 = (($this) + 32|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 40|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 44|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 36|0);
 HEAP32[$17>>2] = 61;
 $18 = (($this) + 48|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 56|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 60|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 52|0);
 HEAP32[$21>>2] = 61;
 $22 = (($this) + 64|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 72|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 76|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 68|0);
 HEAP32[$25>>2] = 61;
 $26 = (($this) + 80|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 88|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 92|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 84|0);
 HEAP32[$29>>2] = 61;
 $30 = (($this) + 96|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 104|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 108|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 100|0);
 HEAP32[$33>>2] = 61;
 __THREW__ = 0;
 $34 = (invoke_i(78)|0);
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if (!($36)) {
  $i$01$i = 0;
  while(1) {
   $39 = ((($34) + ($i$01$i<<2)|0) + 896|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   $38 = (($i$01$i) + 1)|0;
   if ($41) {
    break;
   }
   $37 = ($38|0)<(16);
   if ($37) {
    $i$01$i = $38;
   } else {
    label = 5;
    break;
   }
  }
  if ((label|0) == 5) {
   $42 = (($this) + 112|0);
   ;HEAP32[$42+0>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;HEAP8[$42+12>>0]=0|0;
   STACKTOP = sp;return;
  }
  HEAP32[$39>>2] = 2657;
  $42 = (($this) + 112|0);
  ;HEAP32[$42+0>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;HEAP8[$42+12>>0]=0|0;
  STACKTOP = sp;return;
 }
 $43 = ___cxa_find_matching_catch()|0;
 $44 = tempRet0;
 $45 = HEAP32[$32>>2]|0;
 $46 = ($45|0)>(-1);
 if ($46) {
  $47 = HEAP32[$30>>2]|0;
  $48 = HEAP32[$33>>2]|0;
  HEAP32[$2>>2] = $48;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($47|0),($$byval_copy14|0));
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if (!($50)) {
   HEAP32[$30>>2] = 0;
   label = 9;
  }
 } else {
  label = 9;
 }
 do {
  if ((label|0) == 9) {
   $51 = HEAP32[$28>>2]|0;
   $52 = ($51|0)>(-1);
   if ($52) {
    $53 = HEAP32[$26>>2]|0;
    $54 = HEAP32[$29>>2]|0;
    HEAP32[$1>>2] = $54;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($53|0),($$byval_copy14|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     break;
    }
    HEAP32[$26>>2] = 0;
   }
   $57 = HEAP32[$24>>2]|0;
   $58 = ($57|0)>(-1);
   if ($58) {
    $59 = HEAP32[$22>>2]|0;
    $60 = HEAP32[$25>>2]|0;
    HEAP32[$0>>2] = $60;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($59|0),($$byval_copy14|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     break;
    }
    HEAP32[$22>>2] = 0;
   }
   $63 = HEAP32[$20>>2]|0;
   $64 = ($63|0)>(-1);
   if ($64) {
    $65 = HEAP32[$18>>2]|0;
    $66 = HEAP32[$21>>2]|0;
    HEAP32[$3>>2] = $66;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($65|0),($$byval_copy14|0));
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     break;
    }
    HEAP32[$18>>2] = 0;
   }
   $69 = HEAP32[$16>>2]|0;
   $70 = ($69|0)>(-1);
   if ($70) {
    $71 = HEAP32[$14>>2]|0;
    $72 = HEAP32[$17>>2]|0;
    HEAP32[$4>>2] = $72;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($71|0),($$byval_copy14|0));
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if ($74) {
     break;
    }
    HEAP32[$14>>2] = 0;
   }
   $75 = HEAP32[$12>>2]|0;
   $76 = ($75|0)>(-1);
   do {
    if ($76) {
     $77 = HEAP32[$10>>2]|0;
     $78 = HEAP32[$13>>2]|0;
     HEAP32[$6>>2] = $78;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($77|0),($$byval_copy14|0));
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      HEAP32[$10>>2] = 0;
      break;
     }
     $87 = ___cxa_find_matching_catch(0|0)|0;
     $88 = tempRet0;
     $89 = HEAP32[$8>>2]|0;
     $90 = ($89|0)>(-1);
     if (!($90)) {
      $eh$lpad$body$indexZ2D = $87;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
     $91 = HEAP32[$this>>2]|0;
     $92 = HEAP32[$9>>2]|0;
     HEAP32[$0>>2] = $92;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($91|0),($$byval_copy14|0));
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      $95 = ___cxa_find_matching_catch(0|0)|0;
      $96 = tempRet0;
      ___clang_call_terminate($95);
      // unreachable;
     }
     HEAP32[$this>>2] = 0;
     $eh$lpad$body$indexZ2D = $87;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   } while(0);
   $81 = HEAP32[$8>>2]|0;
   $82 = ($81|0)>(-1);
   if (!($82)) {
    ___resumeException($43|0);
    // unreachable;
   }
   $83 = HEAP32[$this>>2]|0;
   $84 = HEAP32[$9>>2]|0;
   HEAP32[$5>>2] = $84;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($83|0),($$byval_copy14|0));
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if (!($86)) {
    HEAP32[$this>>2] = 0;
    ___resumeException($43|0);
    // unreachable;
   }
  }
 } while(0);
 $97 = ___cxa_find_matching_catch(0|0)|0;
 $98 = tempRet0;
 $eh$lpad$body$indexZ2D = $97;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN5Unity5Scene28SceneAfterCullingOutputReadyEPK9IndexListPK16RendererCullData($visible,$0) {
 $visible = $visible|0;
 $0 = $0|0;
 var $$0$i = 0, $$pre = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$05 = 0, $i1$02 = 0, $i3$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[578368>>2]|0;
 $2 = (($visible) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $5 = (($1) + 80|0);
  $i$05 = 0;
  while(1) {
   $6 = HEAP32[$visible>>2]|0;
   $7 = (($6) + ($i$05<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$5>>2]|0;
   $10 = (($9) + ($8)|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = $11&255;
   $13 = $12 | 1;
   $14 = $13&255;
   HEAP8[$10>>0] = $14;
   $15 = (($i$05) + 1)|0;
   $16 = HEAP32[$2>>2]|0;
   $17 = ($15|0)<($16|0);
   if ($17) {
    $i$05 = $15;
   } else {
    break;
   }
  }
 }
 $18 = (($1) + 116|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $$0$i = 0;
 } else {
  $21 = (__Z9GetIUmbrav()|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$18>>2]|0;
  $26 = (FUNCTION_TABLE_iii[$24 & 4095]($21,$25)|0);
  $$0$i = $26;
 }
 $27 = (($visible) + 16|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)>(0);
 if ($29) {
  $30 = (($visible) + 12|0);
  $31 = (($1) + 80|0);
  $i1$02 = 0;
  while(1) {
   $32 = HEAP32[$30>>2]|0;
   $33 = (($32) + ($i1$02<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + ($$0$i))|0;
   $36 = HEAP32[$31>>2]|0;
   $37 = (($36) + ($35)|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = $38&255;
   $40 = $39 | 1;
   $41 = $40&255;
   HEAP8[$37>>0] = $41;
   $42 = (($i1$02) + 1)|0;
   $43 = HEAP32[$27>>2]|0;
   $44 = ($42|0)<($43|0);
   if ($44) {
    $i1$02 = $42;
   } else {
    break;
   }
  }
 }
 $45 = (($1) + 120|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46) + 1)|0;
 HEAP32[$45>>2] = $47;
 $48 = (($1) + 56|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)>(0);
 if (!($50)) {
  $69 = $47;
  $68 = (($69) + -1)|0;
  HEAP32[$45>>2] = $68;
  STACKTOP = sp;return;
 }
 $51 = (($1) + 80|0);
 $52 = (($1) + 48|0);
 $i3$01 = 0;
 while(1) {
  $53 = HEAP32[$51>>2]|0;
  $54 = (($53) + ($i3$01)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = ($55<<24>>24)==(1);
  if ($56) {
   $57 = HEAP32[$52>>2]|0;
   $58 = (($57) + (($i3$01*24)|0)|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = HEAP32[$59>>2]|0;
   $61 = (($60) + 24|0);
   $62 = HEAP32[$61>>2]|0;
   FUNCTION_TABLE_vi[$62 & 4095]($59);
   $63 = HEAP8[$54>>0]|0;
   $64 = $63&255;
   $65 = $64 | 4;
   $66 = $65&255;
   HEAP8[$54>>0] = $66;
  }
  $67 = (($i3$01) + 1)|0;
  $exitcond = ($67|0)==($49|0);
  if ($exitcond) {
   break;
  } else {
   $i3$01 = $67;
  }
 }
 $$pre = HEAP32[$45>>2]|0;
 $69 = $$pre;
 $68 = (($69) + -1)|0;
 HEAP32[$45>>2] = $68;
 STACKTOP = sp;return;
}
function __ZN5Unity5SceneD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$byval_copy28 = 0, $$pre$i = 0, $$pre5$i = 0, $$pre7$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$indexZ2D = 0, $i$01$i = 0, $i$1$i = 0, $it$02$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy28 = sp + 52|0;
 $0 = sp + 48|0;
 $1 = sp + 44|0;
 $2 = sp + 40|0;
 $3 = sp + 36|0;
 $4 = sp + 32|0;
 $5 = sp + 28|0;
 $6 = sp + 24|0;
 $7 = sp + 16|0;
 $8 = sp + 12|0;
 $9 = sp + 8|0;
 $10 = sp + 4|0;
 $11 = sp;
 $12 = sp + 20|0;
 __THREW__ = 0;
 invoke_vii(2658,($this|0),0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 L1: do {
  if ($14) {
   label = 39;
  } else {
   $15 = (($this) + 116|0);
   HEAP32[$15>>2] = 0;
   $16 = (($this) + 112|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[628424>>2]|0;
   HEAP32[$12>>2] = $18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$12+0>>2]|0;
   invoke_vii(2591,($17|0),($$byval_copy28|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 39;
   } else {
    HEAP32[$16>>2] = 0;
    $21 = (($this) + 48|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($this) + 56|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($22) + (($24*24)|0)|0);
    $26 = ($24|0)==(0);
    L4: do {
     if (!($26)) {
      $it$02$i = $22;
      while(1) {
       $28 = (($it$02$i) + 8|0);
       HEAP32[$28>>2] = -1;
       $29 = (($it$02$i) + 24|0);
       $30 = ($29|0)==($25|0);
       if ($30) {
        break;
       } else {
        $it$02$i = $29;
       }
      }
      $$pre$i = HEAP32[$23>>2]|0;
      $27 = ($$pre$i|0)==(0);
      if (!($27)) {
       $206 = $$pre$i;$32 = $22;$i$01$i = 0;
       while(1) {
        $31 = (($32) + (($i$01$i*24)|0)|0);
        $33 = HEAP32[$31>>2]|0;
        $34 = ($33|0)==(0|0);
        if ($34) {
         __THREW__ = 0;
         (invoke_iii(2382,($this|0),($i$01$i|0))|0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          break;
         }
         $37 = (($i$01$i) + -1)|0;
         $$pre5$i = HEAP32[$23>>2]|0;
         $40 = $$pre5$i;$i$1$i = $37;
        } else {
         $40 = $206;$i$1$i = $i$01$i;
        }
        $38 = (($i$1$i) + 1)|0;
        $39 = ($38>>>0)<($40>>>0);
        if (!($39)) {
         break L4;
        }
        $$pre7$i = HEAP32[$21>>2]|0;
        $206 = $40;$32 = $$pre7$i;$i$01$i = $38;
       }
       $116 = ___cxa_find_matching_catch()|0;
       $117 = tempRet0;
       $lpad$phi$index = $116;$lpad$phi$index2 = $117;
       label = 40;
       break L1;
      }
     }
    } while(0);
    __THREW__ = 0;
    $41 = (invoke_i(78)|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 39;
    } else {
     $44 = (($41) + 896|0);
     __ZN17CallbackArrayBaseIPFvPK9IndexListPK16RendererCullDataEE10UnregisterES7_($44,2657);
     $45 = (($this) + 108|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)>(-1);
     do {
      if ($47) {
       $48 = (($this) + 96|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = (($this) + 100|0);
       $51 = HEAP32[$50>>2]|0;
       HEAP32[$11>>2] = $51;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$11+0>>2]|0;
       invoke_vii(2591,($49|0),($$byval_copy28|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        $129 = ___cxa_find_matching_catch()|0;
        $130 = tempRet0;
        $$0 = $130;$$01 = $129;
        label = 45;
        break L1;
       } else {
        HEAP32[$48>>2] = 0;
        break;
       }
      }
     } while(0);
     $54 = (($this) + 92|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)>(-1);
     do {
      if ($56) {
       $57 = (($this) + 80|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($this) + 84|0);
       $60 = HEAP32[$59>>2]|0;
       HEAP32[$10>>2] = $60;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$10+0>>2]|0;
       invoke_vii(2591,($58|0),($$byval_copy28|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        $131 = ___cxa_find_matching_catch()|0;
        $132 = tempRet0;
        $$1 = $132;$$12 = $131;
        label = 49;
        break L1;
       } else {
        HEAP32[$57>>2] = 0;
        break;
       }
      }
     } while(0);
     $63 = (($this) + 76|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)>(-1);
     do {
      if ($65) {
       $66 = (($this) + 64|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($this) + 68|0);
       $69 = HEAP32[$68>>2]|0;
       HEAP32[$9>>2] = $69;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$9+0>>2]|0;
       invoke_vii(2591,($67|0),($$byval_copy28|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        $142 = ___cxa_find_matching_catch()|0;
        $143 = tempRet0;
        $$2 = $143;$$23 = $142;
        label = 53;
        break L1;
       } else {
        HEAP32[$66>>2] = 0;
        break;
       }
      }
     } while(0);
     $72 = (($this) + 60|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ($73|0)>(-1);
     do {
      if ($74) {
       $75 = HEAP32[$21>>2]|0;
       $76 = (($this) + 52|0);
       $77 = HEAP32[$76>>2]|0;
       HEAP32[$8>>2] = $77;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$8+0>>2]|0;
       invoke_vii(2591,($75|0),($$byval_copy28|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        $153 = ___cxa_find_matching_catch()|0;
        $154 = tempRet0;
        $$3 = $154;$$34 = $153;
        label = 57;
        break L1;
       } else {
        HEAP32[$21>>2] = 0;
        break;
       }
      }
     } while(0);
     $80 = (($this) + 44|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = ($81|0)>(-1);
     do {
      if ($82) {
       $83 = (($this) + 32|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = (($this) + 36|0);
       $86 = HEAP32[$85>>2]|0;
       HEAP32[$7>>2] = $86;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$7+0>>2]|0;
       invoke_vii(2591,($84|0),($$byval_copy28|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        $164 = ___cxa_find_matching_catch()|0;
        $165 = tempRet0;
        $$4 = $165;$$45 = $164;
        label = 60;
        break L1;
       } else {
        HEAP32[$83>>2] = 0;
        break;
       }
      }
     } while(0);
     $89 = (($this) + 28|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = ($90|0)>(-1);
     do {
      if ($91) {
       $92 = (($this) + 16|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = (($this) + 20|0);
       $95 = HEAP32[$94>>2]|0;
       HEAP32[$1>>2] = $95;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($93|0),($$byval_copy28|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        HEAP32[$92>>2] = 0;
        break;
       }
       $104 = ___cxa_find_matching_catch()|0;
       $105 = tempRet0;
       $106 = (($this) + 12|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = ($107|0)>(-1);
       if (!($108)) {
        ___resumeException($104|0);
        // unreachable;
       }
       $109 = HEAP32[$this>>2]|0;
       $110 = (($this) + 4|0);
       $111 = HEAP32[$110>>2]|0;
       HEAP32[$0>>2] = $111;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($109|0),($$byval_copy28|0));
       $112 = __THREW__; __THREW__ = 0;
       $113 = $112&1;
       if ($113) {
        $114 = ___cxa_find_matching_catch(0|0)|0;
        $115 = tempRet0;
        ___clang_call_terminate($114);
        // unreachable;
       }
       HEAP32[$this>>2] = 0;
       ___resumeException($104|0);
       // unreachable;
      }
     } while(0);
     $98 = (($this) + 12|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ($99|0)>(-1);
     if (!($100)) {
      STACKTOP = sp;return;
     }
     $101 = HEAP32[$this>>2]|0;
     $102 = (($this) + 4|0);
     $103 = HEAP32[$102>>2]|0;
     HEAP32[$0>>2] = $103;
     ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($101,$$byval_copy28);
     HEAP32[$this>>2] = 0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 39) {
  $118 = ___cxa_find_matching_catch()|0;
  $119 = tempRet0;
  $lpad$phi$index = $118;$lpad$phi$index2 = $119;
  label = 40;
 }
 if ((label|0) == 40) {
  $120 = (($this) + 108|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ($121|0)>(-1);
  if ($122) {
   $123 = (($this) + 96|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = (($this) + 100|0);
   $126 = HEAP32[$125>>2]|0;
   HEAP32[$6>>2] = $126;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$6+0>>2]|0;
   invoke_vii(2591,($124|0),($$byval_copy28|0));
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if (!($128)) {
    HEAP32[$123>>2] = 0;
    $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
    label = 45;
   }
  } else {
   $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
   label = 45;
  }
 }
 if ((label|0) == 45) {
  $133 = (($this) + 92|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = ($134|0)>(-1);
  if ($135) {
   $136 = (($this) + 80|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = (($this) + 84|0);
   $139 = HEAP32[$138>>2]|0;
   HEAP32[$5>>2] = $139;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($137|0),($$byval_copy28|0));
   $140 = __THREW__; __THREW__ = 0;
   $141 = $140&1;
   if (!($141)) {
    HEAP32[$136>>2] = 0;
    $$1 = $$0;$$12 = $$01;
    label = 49;
   }
  } else {
   $$1 = $$0;$$12 = $$01;
   label = 49;
  }
 }
 if ((label|0) == 49) {
  $144 = (($this) + 76|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = ($145|0)>(-1);
  if ($146) {
   $147 = (($this) + 64|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = (($this) + 68|0);
   $150 = HEAP32[$149>>2]|0;
   HEAP32[$4>>2] = $150;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($148|0),($$byval_copy28|0));
   $151 = __THREW__; __THREW__ = 0;
   $152 = $151&1;
   if (!($152)) {
    HEAP32[$147>>2] = 0;
    $$2 = $$1;$$23 = $$12;
    label = 53;
   }
  } else {
   $$2 = $$1;$$23 = $$12;
   label = 53;
  }
 }
 if ((label|0) == 53) {
  $155 = (($this) + 60|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = ($156|0)>(-1);
  if ($157) {
   $158 = (($this) + 48|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($this) + 52|0);
   $161 = HEAP32[$160>>2]|0;
   HEAP32[$3>>2] = $161;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($159|0),($$byval_copy28|0));
   $162 = __THREW__; __THREW__ = 0;
   $163 = $162&1;
   if (!($163)) {
    HEAP32[$158>>2] = 0;
    $$3 = $$2;$$34 = $$23;
    label = 57;
   }
  } else {
   $$3 = $$2;$$34 = $$23;
   label = 57;
  }
 }
 if ((label|0) == 57) {
  $166 = (($this) + 44|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = ($167|0)>(-1);
  if ($168) {
   $169 = (($this) + 32|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = (($this) + 36|0);
   $172 = HEAP32[$171>>2]|0;
   HEAP32[$2>>2] = $172;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($170|0),($$byval_copy28|0));
   $173 = __THREW__; __THREW__ = 0;
   $174 = $173&1;
   if (!($174)) {
    HEAP32[$169>>2] = 0;
    $$4 = $$3;$$45 = $$34;
    label = 60;
   }
  } else {
   $$4 = $$3;$$45 = $$34;
   label = 60;
  }
 }
 if ((label|0) == 60) {
  $175 = (($this) + 28|0);
  $176 = HEAP32[$175>>2]|0;
  $177 = ($176|0)>(-1);
  do {
   if ($177) {
    $178 = (($this) + 16|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = (($this) + 20|0);
    $181 = HEAP32[$180>>2]|0;
    HEAP32[$1>>2] = $181;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($179|0),($$byval_copy28|0));
    $182 = __THREW__; __THREW__ = 0;
    $183 = $182&1;
    if (!($183)) {
     HEAP32[$178>>2] = 0;
     break;
    }
    $192 = ___cxa_find_matching_catch(0|0)|0;
    $193 = tempRet0;
    $194 = (($this) + 12|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = ($195|0)>(-1);
    if (!($196)) {
     $eh$lpad$body$indexZ2D = $192;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
    $197 = HEAP32[$this>>2]|0;
    $198 = (($this) + 4|0);
    $199 = HEAP32[$198>>2]|0;
    HEAP32[$0>>2] = $199;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($197|0),($$byval_copy28|0));
    $200 = __THREW__; __THREW__ = 0;
    $201 = $200&1;
    if ($201) {
     $202 = ___cxa_find_matching_catch(0|0)|0;
     $203 = tempRet0;
     ___clang_call_terminate($202);
     // unreachable;
    }
    HEAP32[$this>>2] = 0;
    $eh$lpad$body$indexZ2D = $192;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  } while(0);
  $184 = (($this) + 12|0);
  $185 = HEAP32[$184>>2]|0;
  $186 = ($185|0)>(-1);
  if (!($186)) {
   ___resumeException($$45|0);
   // unreachable;
  }
  $187 = HEAP32[$this>>2]|0;
  $188 = (($this) + 4|0);
  $189 = HEAP32[$188>>2]|0;
  HEAP32[$0>>2] = $189;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($187|0),($$byval_copy28|0));
  $190 = __THREW__; __THREW__ = 0;
  $191 = $190&1;
  if (!($191)) {
   HEAP32[$this>>2] = 0;
   ___resumeException($$45|0);
   // unreachable;
  }
 }
 $204 = ___cxa_find_matching_catch(0|0)|0;
 $205 = tempRet0;
 $eh$lpad$body$indexZ2D = $204;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN5Unity5Scene26ClearIntermediateRenderersEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN21IntermediateRenderers5ClearEj($this,0);
 STACKTOP = sp;return;
}
function __ZN17CallbackArrayBaseIPFvPK9IndexListPK16RendererCullDataEE10UnregisterES7_($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==($callback|0);
 if ($1) {
  HEAP32[$this>>2] = 0;
 }
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($callback|0);
 if ($4) {
  HEAP32[$2>>2] = 0;
 }
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($callback|0);
 if ($7) {
  HEAP32[$5>>2] = 0;
 }
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($callback|0);
 if ($10) {
  HEAP32[$8>>2] = 0;
 }
 $11 = (($this) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($callback|0);
 if ($13) {
  HEAP32[$11>>2] = 0;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($callback|0);
 if ($16) {
  HEAP32[$14>>2] = 0;
 }
 $17 = (($this) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==($callback|0);
 if ($19) {
  HEAP32[$17>>2] = 0;
 }
 $20 = (($this) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($callback|0);
 if ($22) {
  HEAP32[$20>>2] = 0;
 }
 $23 = (($this) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($callback|0);
 if ($25) {
  HEAP32[$23>>2] = 0;
 }
 $26 = (($this) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==($callback|0);
 if ($28) {
  HEAP32[$26>>2] = 0;
 }
 $29 = (($this) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==($callback|0);
 if ($31) {
  HEAP32[$29>>2] = 0;
 }
 $32 = (($this) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==($callback|0);
 if ($34) {
  HEAP32[$32>>2] = 0;
 }
 $35 = (($this) + 48|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==($callback|0);
 if ($37) {
  HEAP32[$35>>2] = 0;
 }
 $38 = (($this) + 52|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==($callback|0);
 if ($40) {
  HEAP32[$38>>2] = 0;
 }
 $41 = (($this) + 56|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==($callback|0);
 if ($43) {
  HEAP32[$41>>2] = 0;
 }
 $44 = (($this) + 60|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==($callback|0);
 if (!($46)) {
  STACKTOP = sp;return;
 }
 HEAP32[$44>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity5Scene14RemoveRendererEi($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$0 = 0, $$0$i = 0, $$byval_copy3 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = ($handle|0)<(0);
 if (!($1)) {
  $2 = (($this) + 56|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)>($handle|0);
  if ($4) {
   $5 = (($this) + 48|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + (($handle*24)|0)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 120|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $12 = (($this) + 32|0);
    $13 = (($this) + 40|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($14) + 1)|0;
    HEAP32[$13>>2] = $15;
    $16 = (($this) + 44|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = $17 & 2147483647;
    $19 = ($15>>>0)>($18>>>0);
    if ($19) {
     $20 = $17 << 1;
     $21 = ($20|0)==(0);
     $22 = $21 ? 1 : $20;
     $23 = ($18>>>0)<($22>>>0);
     do {
      if ($23) {
       $24 = ($17|0)>(-1);
       if ($24) {
        HEAP32[$16>>2] = $22;
        $25 = HEAP32[$12>>2]|0;
        $26 = $22 << 2;
        $27 = (($this) + 36|0);
        $28 = HEAP32[$27>>2]|0;
        HEAP32[$0>>2] = $28;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
        $29 = (__Z16realloc_internalPvji10MemLabelIdiPKci($25,$26,4,$$byval_copy3,0,578360,370)|0);
        HEAP32[$12>>2] = $29;
        break;
       } else {
        $30 = $22 << 2;
        $31 = (($this) + 36|0);
        $32 = HEAP32[$31>>2]|0;
        HEAP32[$0>>2] = $32;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
        $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($30,4,$$byval_copy3,0,578360,352)|0);
        $34 = HEAP32[$12>>2]|0;
        $35 = HEAP32[$13>>2]|0;
        $36 = $35 << 2;
        _memcpy(($33|0),($34|0),($36|0))|0;
        HEAP32[$16>>2] = $22;
        HEAP32[$12>>2] = $33;
        break;
       }
      }
     } while(0);
     $$pre$i$i1 = HEAP32[$13>>2]|0;
     $38 = $$pre$i$i1;
    } else {
     $38 = $15;
    }
    $37 = (($38) + -1)|0;
    $39 = HEAP32[$12>>2]|0;
    $40 = (($39) + ($37<<2)|0);
    HEAP32[$40>>2] = $handle;
    $41 = ((($6) + (($handle*24)|0)|0) + 22|0);
    HEAP8[$41>>0] = 1;
    $$0 = $8;
    STACKTOP = sp;return ($$0|0);
   }
   $42 = (($this) + 116|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    $$0$i = 0;
   } else {
    $45 = (__Z9GetIUmbrav()|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + 12|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = HEAP32[$42>>2]|0;
    $50 = (FUNCTION_TABLE_iii[$48 & 4095]($45,$49)|0);
    $$0$i = $50;
   }
   $51 = ($$0$i|0)>($handle|0);
   if ($51) {
    $52 = (($this) + 80|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + ($handle)|0);
    HEAP8[$54>>0] = 0;
    HEAP32[$7>>2] = 0;
    $55 = ((($6) + (($handle*24)|0)|0) + 21|0);
    HEAP8[$55>>0] = 0;
    $$0 = $8;
    STACKTOP = sp;return ($$0|0);
   }
   $56 = HEAP32[$2>>2]|0;
   $57 = (($56) + -1)|0;
   $58 = HEAP32[$5>>2]|0;
   $59 = (($58) + (($57*24)|0)|0);
   $60 = ($57|0)==($handle|0);
   if ($60) {
    $114 = $56;
   } else {
    $61 = HEAP32[$59>>2]|0;
    $62 = ($61|0)==(0|0);
    if ($62) {
     $114 = $56;
    } else {
     $63 = (($this) + 64|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($64) + (($57*24)|0)|0);
     $66 = (($this) + 80|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($67) + ($57)|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = ($69<<24>>24)!=(0);
     $71 = (($58) + (($handle*24)|0)|0);
     ;HEAP32[$71+0>>2]=HEAP32[$59+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$59+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$59+8>>2]|0;HEAP32[$71+12>>2]=HEAP32[$59+12>>2]|0;HEAP32[$71+16>>2]=HEAP32[$59+16>>2]|0;HEAP16[$71+20>>1]=HEAP16[$59+20>>1]|0;HEAP8[$71+22>>0]=HEAP8[$59+22>>0]|0;
     $72 = HEAP32[$63>>2]|0;
     $73 = (($72) + (($handle*24)|0)|0);
     ;HEAP32[$73+0>>2]=HEAP32[$65+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$65+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$65+8>>2]|0;HEAP32[$73+12>>2]=HEAP32[$65+12>>2]|0;HEAP32[$73+16>>2]=HEAP32[$65+16>>2]|0;HEAP32[$73+20>>2]=HEAP32[$65+20>>2]|0;
     $74 = $70&1;
     $75 = HEAP32[$66>>2]|0;
     $76 = (($75) + ($handle)|0);
     HEAP8[$76>>0] = $74;
     $77 = ((($58) + (($57*24)|0)|0) + 21|0);
     $78 = HEAP8[$77>>0]|0;
     $79 = ($78<<24>>24)==(0);
     if (!($79)) {
      $80 = (($this) + 96|0);
      $81 = (($this) + 104|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($82) + 1)|0;
      HEAP32[$81>>2] = $83;
      $84 = (($this) + 108|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = $85 & 2147483647;
      $87 = ($83>>>0)>($86>>>0);
      if ($87) {
       $88 = $85 << 1;
       $89 = ($88|0)==(0);
       $90 = $89 ? 1 : $88;
       $91 = ($86>>>0)<($90>>>0);
       do {
        if ($91) {
         $92 = ($85|0)>(-1);
         if ($92) {
          HEAP32[$84>>2] = $90;
          $93 = HEAP32[$80>>2]|0;
          $94 = $90 << 2;
          $95 = (($this) + 100|0);
          $96 = HEAP32[$95>>2]|0;
          HEAP32[$0>>2] = $96;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
          $97 = (__Z16realloc_internalPvji10MemLabelIdiPKci($93,$94,4,$$byval_copy3,0,578360,370)|0);
          HEAP32[$80>>2] = $97;
          break;
         } else {
          $98 = $90 << 2;
          $99 = (($this) + 100|0);
          $100 = HEAP32[$99>>2]|0;
          HEAP32[$0>>2] = $100;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
          $101 = (__Z15malloc_internaljj10MemLabelIdiPKci($98,4,$$byval_copy3,0,578360,352)|0);
          $102 = HEAP32[$80>>2]|0;
          $103 = HEAP32[$81>>2]|0;
          $104 = $103 << 2;
          _memcpy(($101|0),($102|0),($104|0))|0;
          HEAP32[$84>>2] = $90;
          HEAP32[$80>>2] = $101;
          break;
         }
        }
       } while(0);
       $$pre$i$i = HEAP32[$81>>2]|0;
       $106 = $$pre$i$i;
      } else {
       $106 = $83;
      }
      $105 = (($106) + -1)|0;
      $107 = HEAP32[$80>>2]|0;
      $108 = (($107) + ($105<<2)|0);
      HEAP32[$108>>2] = $handle;
     }
     $109 = HEAP32[$59>>2]|0;
     $110 = ($109|0)==(0|0);
     if ($110) {
      $112 = 0;
     } else {
      $111 = (($109) + -28|0);
      $112 = $111;
     }
     __ZN8Renderer23NotifySceneHandleChangeEi($112,$handle);
     $$pre = HEAP32[$2>>2]|0;
     $114 = $$pre;
    }
   }
   $113 = (($114) + -1)|0;
   HEAP32[$2>>2] = $113;
   $115 = (($this) + 72|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (($116) + -1)|0;
   HEAP32[$115>>2] = $117;
   $118 = (($this) + 88|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = (($119) + -1)|0;
   HEAP32[$118>>2] = $120;
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(578336,0,578360,252,1,0,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity5Scene15InitializeUmbraEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre$phi20Z2D = 0, $$pre$phiZ2D = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre5$i = 0, $$pre7$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $handle$1 = 0, $i$01$i = 0, $i$01$i1 = 0, $i$012 = 0, $i$1$i = 0, $i1$010 = 0, $it$02$i = 0, $or$cond7 = 0, $or$cond78 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 32|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $5 = (($this) + 96|0);
  $6 = (($this) + 56|0);
  $7 = (($this) + 48|0);
  $8 = (($this) + 64|0);
  $i$01$i = 0;
  while(1) {
   $9 = HEAP32[$5>>2]|0;
   $10 = (($9) + ($i$01$i<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$6>>2]|0;
   $13 = ($11|0)<($12|0);
   if ($13) {
    $14 = HEAP32[$7>>2]|0;
    $15 = ((($14) + (($11*24)|0)|0) + 21|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if (!($17)) {
     $18 = (($14) + (($11*24)|0)|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = HEAP32[$8>>2]|0;
     $21 = (($20) + (($11*24)|0)|0);
     __ZN12BaseRenderer12GetWorldAABBER4AABB($19,$21);
     HEAP8[$15>>0] = 0;
    }
   }
   $22 = (($i$01$i) + 1)|0;
   $exitcond$i = ($22|0)==($3|0);
   if ($exitcond$i) {
    $$pre$phi20Z2D = $6;$$pre$phiZ2D = $7;
    break;
   } else {
    $i$01$i = $22;
   }
  }
 } else {
  $$pre18 = (($this) + 48|0);
  $$pre19 = (($this) + 56|0);
  $$pre$phi20Z2D = $$pre19;$$pre$phiZ2D = $$pre18;
 }
 HEAP32[$2>>2] = 0;
 $23 = (($this) + 116|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 112|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[628424>>2]|0;
 HEAP32[$0>>2] = $26;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy);
 HEAP32[$24>>2] = 0;
 $27 = HEAP32[$$pre$phiZ2D>>2]|0;
 $28 = HEAP32[$$pre$phi20Z2D>>2]|0;
 $29 = (($27) + (($28*24)|0)|0);
 $30 = ($28|0)==(0);
 L11: do {
  if (!($30)) {
   $it$02$i = $27;
   while(1) {
    $32 = (($it$02$i) + 8|0);
    HEAP32[$32>>2] = -1;
    $33 = (($it$02$i) + 24|0);
    $34 = ($33|0)==($29|0);
    if ($34) {
     break;
    } else {
     $it$02$i = $33;
    }
   }
   $$pre$i = HEAP32[$$pre$phi20Z2D>>2]|0;
   $31 = ($$pre$i|0)==(0);
   if (!($31)) {
    $171 = $$pre$i;$36 = $27;$i$01$i1 = 0;
    while(1) {
     $35 = (($36) + (($i$01$i1*24)|0)|0);
     $37 = HEAP32[$35>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      (__ZN5Unity5Scene14RemoveRendererEi($this,$i$01$i1)|0);
      $39 = (($i$01$i1) + -1)|0;
      $$pre5$i = HEAP32[$$pre$phi20Z2D>>2]|0;
      $42 = $$pre5$i;$i$1$i = $39;
     } else {
      $42 = $171;$i$1$i = $i$01$i1;
     }
     $40 = (($i$1$i) + 1)|0;
     $41 = ($40>>>0)<($42>>>0);
     if (!($41)) {
      break L11;
     }
     $$pre7$i = HEAP32[$$pre$phiZ2D>>2]|0;
     $171 = $42;$36 = $$pre7$i;$i$01$i1 = $40;
    }
   }
  }
 } while(0);
 $43 = (__Z19GetSceneSettingsPtrv()|0);
 $44 = ($43|0)==(0|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = (__Z16GetSceneSettingsv()|0);
 $46 = (($45) + 24|0);
 $47 = HEAP32[$46>>2]|0;
 HEAP32[$23>>2] = $47;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 $49 = (__Z16GetSceneSettingsv()|0);
 $50 = (__Z9GetIUmbrav()|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = HEAP32[$23>>2]|0;
 $55 = (FUNCTION_TABLE_iii[$53 & 4095]($50,$54)|0);
 $56 = ($55|0)>(0);
 if ($56) {
  $57 = (($49) + 36|0);
  $58 = (($49) + 28|0);
  $i$012 = 0;
  while(1) {
   $63 = (__Z9GetIUmbrav()|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 16|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = HEAP32[$23>>2]|0;
   $68 = (FUNCTION_TABLE_iiii[$66 & 2047]($63,$67,$i$012)|0);
   $69 = HEAP32[$57>>2]|0;
   $70 = ($68>>>0)<($69>>>0);
   if ($70) {
    $71 = HEAP32[$58>>2]|0;
    $72 = (($71) + ($68<<2)|0);
    $73 = HEAP32[$72>>2]|0;
    HEAP32[$0>>2] = $73;
    $74 = HEAP32[560624>>2]|0;
    $75 = ($74|0)==(0|0);
    if ($75) {
     label = 33;
    } else {
     $76 = (($74) + 36|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($74) + 4|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($77|0)==($79|0);
     do {
      if ($80) {
       $81 = (($74) + 28|0);
       $82 = HEAP32[$81>>2]|0;
       $83 = (($74) + 32|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = (($82) + ($84<<3)|0);
       $101 = $85;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$74,$0);
       $86 = HEAP32[$$byval_copy>>2]|0;
       $87 = ($86|0)==(-1);
       $88 = (($74) + 28|0);
       $89 = HEAP32[$88>>2]|0;
       if ($87) {
        $90 = (($74) + 32|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = (($89) + ($91<<3)|0);
        $101 = $92;
        break;
       } else {
        $93 = (($89) + ($86<<3)|0);
        $101 = $93;
        break;
       }
      }
     } while(0);
     $94 = HEAP32[560624>>2]|0;
     $95 = (($94) + 28|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($94) + 32|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($96) + ($98<<3)|0);
     $100 = ($101|0)==($99|0);
     if ($100) {
      label = 33;
     } else {
      $102 = (($101) + 4|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = ($103|0)==(0|0);
      if ($104) {
       label = 33;
      } else {
       $105 = (($103) + 8|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = $106 >>> 21;
       $108 = HEAP32[560640>>2]|0;
       $109 = Math_imul($108, $107)|0;
       $110 = (($109) + 25)|0;
       $111 = $110 >> 5;
       $112 = $111 << 5;
       $113 = (($110) - ($112))|0;
       $114 = HEAP32[560632>>2]|0;
       $115 = (($114) + ($111<<2)|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = 1 << $113;
       $118 = $117 & $116;
       $119 = ($118|0)==(0);
       if ($119) {
        label = 33;
       } else {
        $120 = (($103) + 216|0);
        $121 = HEAP32[$120>>2]|0;
        $122 = ($121|0)<(0);
        if ($122) {
         label = 33;
        } else {
         $123 = HEAP32[$$pre$phi20Z2D>>2]|0;
         $124 = ($121|0)<($123|0);
         if ($124) {
          $handle$1 = $121;
         } else {
          label = 33;
         }
        }
       }
      }
     }
    }
    if ((label|0) == 33) {
     label = 0;
     ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
     $125 = (__ZN5Unity5Scene19AddRendererInternalEP8RendereriRK4AABB($this,0,0,$1)|0);
     $handle$1 = $125;
    }
    $126 = HEAP32[$$pre$phiZ2D>>2]|0;
    $127 = ((($126) + (($handle$1*24)|0)|0) + 8|0);
    HEAP32[$127>>2] = $i$012;
   }
   $128 = (($i$012) + 1)|0;
   $exitcond = ($128|0)==($55|0);
   if ($exitcond) {
    break;
   } else {
    $i$012 = $128;
   }
  }
 }
 $59 = HEAP32[$$pre$phi20Z2D>>2]|0;
 $60 = ($59|0)==(0);
 if (!($60)) {
  $61 = (($this) + 64|0);
  $62 = (($this) + 80|0);
  $$pre = HEAP32[$$pre$phiZ2D>>2]|0;
  $130 = $$pre;$172 = $59;$i1$010 = 0;
  while(1) {
   $129 = ((($130) + (($i1$010*24)|0)|0) + 8|0);
   $131 = HEAP32[$129>>2]|0;
   $132 = ($131|0)==(-1);
   $133 = ($131|0)==($i1$010|0);
   $or$cond78 = $132 | $133;
   if ($or$cond78) {
    $170 = $172;$173 = $130;
   } else {
    $140 = $130;$142 = $131;
    while(1) {
     $139 = (($140) + (($i1$010*24)|0)|0);
     $141 = (($140) + (($142*24)|0)|0);
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$139+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$139+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$139+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$139+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$139+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$139+20>>2]|0;
     ;HEAP32[$139+0>>2]=HEAP32[$141+0>>2]|0;HEAP32[$139+4>>2]=HEAP32[$141+4>>2]|0;HEAP32[$139+8>>2]=HEAP32[$141+8>>2]|0;HEAP32[$139+12>>2]=HEAP32[$141+12>>2]|0;HEAP32[$139+16>>2]=HEAP32[$141+16>>2]|0;HEAP16[$139+20>>1]=HEAP16[$141+20>>1]|0;HEAP8[$139+22>>0]=HEAP8[$141+22>>0]|0;
     ;HEAP32[$141+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$141+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$141+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$141+12>>2]=HEAP32[$$byval_copy+12>>2]|0;HEAP32[$141+16>>2]=HEAP32[$$byval_copy+16>>2]|0;HEAP16[$141+20>>1]=HEAP16[$$byval_copy+20>>1]|0;HEAP8[$141+22>>0]=HEAP8[$$byval_copy+22>>0]|0;
     $143 = HEAP32[$61>>2]|0;
     $144 = (($143) + (($i1$010*24)|0)|0);
     $145 = (($143) + (($142*24)|0)|0);
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$144+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$144+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$144+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$144+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$144+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$144+20>>2]|0;
     ;HEAP32[$144+0>>2]=HEAP32[$145+0>>2]|0;HEAP32[$144+4>>2]=HEAP32[$145+4>>2]|0;HEAP32[$144+8>>2]=HEAP32[$145+8>>2]|0;HEAP32[$144+12>>2]=HEAP32[$145+12>>2]|0;HEAP32[$144+16>>2]=HEAP32[$145+16>>2]|0;HEAP32[$144+20>>2]=HEAP32[$145+20>>2]|0;
     ;HEAP32[$145+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$145+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$145+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$145+12>>2]=HEAP32[$$byval_copy+12>>2]|0;HEAP32[$145+16>>2]=HEAP32[$$byval_copy+16>>2]|0;HEAP32[$145+20>>2]=HEAP32[$$byval_copy+20>>2]|0;
     $146 = HEAP32[$62>>2]|0;
     $147 = (($146) + ($i1$010)|0);
     $148 = (($146) + ($142)|0);
     $149 = HEAP8[$147>>0]|0;
     $150 = HEAP8[$148>>0]|0;
     HEAP8[$147>>0] = $150;
     HEAP8[$148>>0] = $149;
     $151 = HEAP32[$$pre$phiZ2D>>2]|0;
     $152 = (($151) + (($i1$010*24)|0)|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = ($153|0)==(0|0);
     if ($154) {
      $158 = $151;
     } else {
      $155 = (($153) + -28|0);
      $156 = ($155|0)==(0|0);
      if ($156) {
       $158 = $151;
      } else {
       __ZN8Renderer23NotifySceneHandleChangeEi($155,$i1$010);
       $$pre16 = HEAP32[$$pre$phiZ2D>>2]|0;
       $158 = $$pre16;
      }
     }
     $157 = (($158) + (($142*24)|0)|0);
     $159 = HEAP32[$157>>2]|0;
     $160 = ($159|0)==(0|0);
     if ($160) {
      $164 = $158;
     } else {
      $161 = (($159) + -28|0);
      $162 = ($161|0)==(0|0);
      if ($162) {
       $164 = $158;
      } else {
       __ZN8Renderer23NotifySceneHandleChangeEi($161,$142);
       $$pre17 = HEAP32[$$pre$phiZ2D>>2]|0;
       $164 = $$pre17;
      }
     }
     $163 = ((($164) + (($i1$010*24)|0)|0) + 8|0);
     $165 = HEAP32[$163>>2]|0;
     $166 = ($165|0)==(-1);
     $167 = ($165|0)==($i1$010|0);
     $or$cond7 = $166 | $167;
     if ($or$cond7) {
      break;
     } else {
      $140 = $164;$142 = $165;
     }
    }
    $$pre15 = HEAP32[$$pre$phi20Z2D>>2]|0;
    $170 = $$pre15;$173 = $164;
   }
   $168 = (($i1$010) + 1)|0;
   $169 = ($168>>>0)<($170>>>0);
   if ($169) {
    $130 = $173;$172 = $170;$i1$010 = $168;
   } else {
    break;
   }
  }
 }
 $134 = (__Z9GetIUmbrav()|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($135) + 44|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = (FUNCTION_TABLE_ii[$137 & 4095]($134)|0);
 HEAP32[$24>>2] = $138;
 STACKTOP = sp;return;
}
function __ZN5Unity5Scene22RecalculateDirtyBoundsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 96|0);
 $4 = (($this) + 56|0);
 $5 = (($this) + 48|0);
 $6 = (($this) + 64|0);
 $i$01 = 0;
 while(1) {
  $7 = HEAP32[$3>>2]|0;
  $8 = (($7) + ($i$01<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$4>>2]|0;
  $11 = ($9|0)<($10|0);
  if ($11) {
   $12 = HEAP32[$5>>2]|0;
   $13 = ((($12) + (($9*24)|0)|0) + 21|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if (!($15)) {
    $16 = (($12) + (($9*24)|0)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[$6>>2]|0;
    $19 = (($18) + (($9*24)|0)|0);
    __ZN12BaseRenderer12GetWorldAABBER4AABB($17,$19);
    HEAP8[$13>>0] = 0;
   }
  }
  $20 = (($i$01) + 1)|0;
  $exitcond = ($20|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $20;
  }
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity5Scene19AddRendererInternalEP8RendereriRK4AABB($this,$renderer,$layer,$aabb) {
 $this = $this|0;
 $renderer = $renderer|0;
 $layer = $layer|0;
 $aabb = $aabb|0;
 var $$ = 0, $$byval_copy5 = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $$pre$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $node$sroa$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 16|0;
 $0 = sp;
 $node$sroa$3 = sp + 4|0;
 $1 = (($this) + 48|0);
 $2 = (($this) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$node$sroa$3+0>>2]=0|0;HEAP32[$node$sroa$3+4>>2]=0|0;HEAP16[$node$sroa$3+8>>1]=0|0;HEAP8[$node$sroa$3+10>>0]=0|0;
 $4 = ($renderer|0)==(0|0);
 $5 = (($renderer) + 28|0);
 $$ = $4 ? 0 : $5;
 $6 = (($3) + 1)|0;
 HEAP32[$2>>2] = $6;
 $7 = (($this) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($6>>>0)>($9>>>0);
 if ($10) {
  $11 = $8 << 1;
  $12 = ($11|0)==(0);
  $13 = $12 ? 1 : $11;
  $14 = ($9>>>0)<($13>>>0);
  do {
   if ($14) {
    $15 = ($8|0)>(-1);
    if ($15) {
     HEAP32[$7>>2] = $13;
     $16 = HEAP32[$1>>2]|0;
     $17 = ($13*24)|0;
     $18 = (($this) + 52|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$0>>2] = $19;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($16,$17,4,$$byval_copy5,0,578360,370)|0);
     HEAP32[$1>>2] = $20;
     break;
    } else {
     $21 = ($13*24)|0;
     $22 = (($this) + 52|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,4,$$byval_copy5,0,578360,352)|0);
     $25 = HEAP32[$1>>2]|0;
     $26 = HEAP32[$2>>2]|0;
     $27 = ($26*24)|0;
     _memcpy(($24|0),($25|0),($27|0))|0;
     HEAP32[$7>>2] = $13;
     HEAP32[$1>>2] = $24;
     break;
    }
   }
  } while(0);
  $$pre$i$i1 = HEAP32[$2>>2]|0;
  $29 = $$pre$i$i1;
 } else {
  $29 = $6;
 }
 $28 = (($29) + -1)|0;
 $30 = HEAP32[$1>>2]|0;
 $31 = (($30) + (($28*24)|0)|0);
 HEAP32[$31>>2] = $$;
 $32 = ((($30) + (($28*24)|0)|0) + 4|0);
 HEAP32[$32>>2] = $layer;
 $33 = ((($30) + (($28*24)|0)|0) + 8|0);
 HEAP32[$33>>2] = -1;
 $34 = ((($30) + (($28*24)|0)|0) + 12|0);
 ;HEAP32[$34+0>>2]=HEAP32[$node$sroa$3+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$node$sroa$3+4>>2]|0;HEAP16[$34+8>>1]=HEAP16[$node$sroa$3+8>>1]|0;HEAP8[$34+10>>0]=HEAP8[$node$sroa$3+10>>0]|0;
 $35 = (($this) + 64|0);
 $36 = (($this) + 72|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $39 = (($this) + 76|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = $40 & 2147483647;
 $42 = ($38>>>0)>($41>>>0);
 if ($42) {
  $43 = $40 << 1;
  $44 = ($43|0)==(0);
  $45 = $44 ? 1 : $43;
  $46 = ($41>>>0)<($45>>>0);
  do {
   if ($46) {
    $47 = ($40|0)>(-1);
    if ($47) {
     HEAP32[$39>>2] = $45;
     $48 = HEAP32[$35>>2]|0;
     $49 = ($45*24)|0;
     $50 = (($this) + 68|0);
     $51 = HEAP32[$50>>2]|0;
     HEAP32[$0>>2] = $51;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $52 = (__Z16realloc_internalPvji10MemLabelIdiPKci($48,$49,4,$$byval_copy5,0,578360,370)|0);
     HEAP32[$35>>2] = $52;
     break;
    } else {
     $53 = ($45*24)|0;
     $54 = (($this) + 68|0);
     $55 = HEAP32[$54>>2]|0;
     HEAP32[$0>>2] = $55;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $56 = (__Z15malloc_internaljj10MemLabelIdiPKci($53,4,$$byval_copy5,0,578360,352)|0);
     $57 = HEAP32[$35>>2]|0;
     $58 = HEAP32[$36>>2]|0;
     $59 = ($58*24)|0;
     _memcpy(($56|0),($57|0),($59|0))|0;
     HEAP32[$39>>2] = $45;
     HEAP32[$35>>2] = $56;
     break;
    }
   }
  } while(0);
  $$pre$i$i2 = HEAP32[$36>>2]|0;
  $61 = $$pre$i$i2;
 } else {
  $61 = $38;
 }
 $60 = (($61) + -1)|0;
 $62 = HEAP32[$35>>2]|0;
 $63 = (($62) + (($60*24)|0)|0);
 ;HEAP32[$63+0>>2]=HEAP32[$aabb+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$aabb+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$aabb+8>>2]|0;HEAP32[$63+12>>2]=HEAP32[$aabb+12>>2]|0;HEAP32[$63+16>>2]=HEAP32[$aabb+16>>2]|0;HEAP32[$63+20>>2]=HEAP32[$aabb+20>>2]|0;
 $64 = (($this) + 80|0);
 $65 = (($this) + 88|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$65>>2] = $67;
 $68 = (($this) + 92|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = $69 & 2147483647;
 $71 = ($67>>>0)>($70>>>0);
 if (!($71)) {
  $87 = $67;
  $86 = (($87) + -1)|0;
  $88 = HEAP32[$64>>2]|0;
  $89 = (($88) + ($86)|0);
  HEAP8[$89>>0] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $72 = $69 << 1;
 $73 = ($72|0)==(0);
 $74 = $73 ? 1 : $72;
 $75 = ($70>>>0)<($74>>>0);
 do {
  if ($75) {
   $76 = ($69|0)>(-1);
   if ($76) {
    HEAP32[$68>>2] = $74;
    $77 = HEAP32[$64>>2]|0;
    $78 = (($this) + 84|0);
    $79 = HEAP32[$78>>2]|0;
    HEAP32[$0>>2] = $79;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $80 = (__Z16realloc_internalPvji10MemLabelIdiPKci($77,$74,1,$$byval_copy5,0,578360,370)|0);
    HEAP32[$64>>2] = $80;
    break;
   } else {
    $81 = (($this) + 84|0);
    $82 = HEAP32[$81>>2]|0;
    HEAP32[$0>>2] = $82;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $83 = (__Z15malloc_internaljj10MemLabelIdiPKci($74,1,$$byval_copy5,0,578360,352)|0);
    $84 = HEAP32[$64>>2]|0;
    $85 = HEAP32[$65>>2]|0;
    _memcpy(($83|0),($84|0),($85|0))|0;
    HEAP32[$68>>2] = $74;
    HEAP32[$64>>2] = $83;
    break;
   }
  }
 } while(0);
 $$pre$i$i = HEAP32[$65>>2]|0;
 $87 = $$pre$i$i;
 $86 = (($87) + -1)|0;
 $88 = HEAP32[$64>>2]|0;
 $89 = (($88) + ($86)|0);
 HEAP8[$89>>0] = 0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK5Unity5Scene20GetStaticObjectCountEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__Z9GetIUmbrav()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$6 & 4095]($3,$7)|0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5Unity5Scene21GetDynamicObjectCountEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 0;
  $11 = (($1) - ($$0$i))|0;
  STACKTOP = sp;return ($11|0);
 }
 $5 = (__Z9GetIUmbrav()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$2>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$8 & 4095]($5,$9)|0);
 $$0$i = $10;
 $11 = (($1) - ($$0$i))|0;
 STACKTOP = sp;return ($11|0);
}
function __ZNK5Unity5Scene19GetStaticSceneNodesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5Unity5Scene20GetDynamicSceneNodesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 0;
  $11 = (($1) + (($$0$i*24)|0)|0);
  STACKTOP = sp;return ($11|0);
 }
 $5 = (__Z9GetIUmbrav()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$2>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$8 & 4095]($5,$9)|0);
 $$0$i = $10;
 $11 = (($1) + (($$0$i*24)|0)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZNK5Unity5Scene22GetStaticBoundingBoxesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK5Unity5Scene23GetDynamicBoundingBoxesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 0;
  $11 = (($1) + (($$0$i*24)|0)|0);
  STACKTOP = sp;return ($11|0);
 }
 $5 = (__Z9GetIUmbrav()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$2>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$8 & 4095]($5,$9)|0);
 $$0$i = $10;
 $11 = (($1) + (($$0$i*24)|0)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN5Unity5Scene11AddRendererEP8Renderer($this,$renderer) {
 $this = $this|0;
 $renderer = $renderer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $aabb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $aabb = sp;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$aabb+0>>2]=0|0;HEAP32[$aabb+4>>2]=0|0;HEAP32[$aabb+8>>2]=0|0;HEAP32[$aabb+12>>2]=0|0;HEAP32[$aabb+16>>2]=0|0;HEAP32[$aabb+20>>2]=0|0;
 $3 = (($renderer) + 28|0);
 __ZN12BaseRenderer12GetWorldAABBER4AABB($3,$aabb);
 $4 = HEAP32[$renderer>>2]|0;
 $5 = (($4) + 116|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($renderer)|0);
 $8 = (__ZN5Unity5Scene19AddRendererInternalEP8RendereriRK4AABB($this,$renderer,$7,$aabb)|0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity5Scene27SetPreventAddRemoveRendererEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $enable ? 1 : -1;
 $1 = (($this) + 120|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0))|0;
 HEAP32[$1>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN5Unity8GetSceneEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[578368>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN5Unity5Scene15NotifyInvisibleEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 80|0);
 $4 = (($this) + 48|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + ($i$01)|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(2);
  if ($8) {
   $9 = HEAP32[$4>>2]|0;
   $10 = (($9) + (($i$01*24)|0)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 28|0);
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vi[$14 & 4095]($11);
   $$pre = HEAP8[$6>>0]|0;
   $16 = $$pre;
  } else {
   $16 = $7;
  }
  $15 = ($16 << 1)&255;
  $17 = $15 & 2;
  HEAP8[$6>>0] = $17;
  $18 = (($i$01) + 1)|0;
  $exitcond = ($18|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $18;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity5Scene17BeginCameraRenderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 0;
 __ZN5Unity5Scene15InitializeUmbraEv($this);
 STACKTOP = sp;return;
}
function __ZN5Unity5Scene15EndCameraRenderEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$0 = 0, $i$01 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 __ZNSt3__16__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_($5,$6,$$byval_copy);
 $7 = HEAP32[$1>>2]|0;
 $i$01 = (($7) + -1)|0;
 $8 = ($i$01|0)>(-1);
 if ($8) {
  $i$02 = $i$01;
  while(1) {
   $9 = HEAP32[$4>>2]|0;
   $10 = (($9) + ($i$02<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   (__ZN5Unity5Scene14RemoveRendererEi($this,$11)|0);
   $i$0 = (($i$02) + -1)|0;
   $12 = ($i$0|0)>(-1);
   if ($12) {
    $i$02 = $i$0;
   } else {
    break;
   }
  }
 }
 $13 = (($this) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(-1);
 if ($15) {
  $16 = HEAP32[$4>>2]|0;
  $17 = (($this) + 36|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$0>>2] = $18;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($16,$$byval_copy);
  HEAP32[$4>>2] = 0;
 }
 HEAP32[$1>>2] = 0;
 HEAP32[$13>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity5Scene15InitializeClassEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(128)|0);
 __THREW__ = 0;
 invoke_vi(3439,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[578368>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __ZN5Unity5Scene12CleanupClassEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[578368>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[578368>>2] = 0;
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3440,($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 }
 __ZdlPv($0);
 HEAP32[578368>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__17__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $$0$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__r$0 = 0, $__r$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3|0)<($0|0);
 do {
  if ($2) {
   if ($4) {
    HEAP32[$__x1>>2] = $3;
    HEAP32[$__x3>>2] = $1;
    $$0$i$i = 1;$12 = $1;
    break;
   }
   HEAP32[$__x1>>2] = $0;
   HEAP32[$__x2>>2] = $1;
   $8 = HEAP32[$__x3>>2]|0;
   $9 = ($8|0)<($1|0);
   if ($9) {
    HEAP32[$__x2>>2] = $8;
    HEAP32[$__x3>>2] = $1;
    $$0$i$i = 2;$12 = $1;
   } else {
    $$0$i$i = 1;$12 = $8;
   }
  } else {
   if ($4) {
    HEAP32[$__x2>>2] = $3;
    HEAP32[$__x3>>2] = $0;
    $5 = HEAP32[$__x2>>2]|0;
    $6 = HEAP32[$__x1>>2]|0;
    $7 = ($5|0)<($6|0);
    if ($7) {
     HEAP32[$__x1>>2] = $5;
     HEAP32[$__x2>>2] = $6;
     $$pre$i = HEAP32[$__x3>>2]|0;
     $$0$i$i = 2;$12 = $$pre$i;
    } else {
     $$0$i$i = 1;$12 = $0;
    }
   } else {
    $$0$i$i = 0;$12 = $3;
   }
  }
 } while(0);
 $10 = HEAP32[$__x4>>2]|0;
 $11 = ($10|0)<($12|0);
 do {
  if ($11) {
   HEAP32[$__x3>>2] = $10;
   HEAP32[$__x4>>2] = $12;
   $13 = (($$0$i$i) + 1)|0;
   $14 = HEAP32[$__x3>>2]|0;
   $15 = HEAP32[$__x2>>2]|0;
   $16 = ($14|0)<($15|0);
   if ($16) {
    HEAP32[$__x2>>2] = $14;
    HEAP32[$__x3>>2] = $15;
    $17 = HEAP32[$__x2>>2]|0;
    $18 = HEAP32[$__x1>>2]|0;
    $19 = ($17|0)<($18|0);
    if ($19) {
     HEAP32[$__x1>>2] = $17;
     HEAP32[$__x2>>2] = $18;
     $21 = (($$0$i$i) + 3)|0;
     $__r$0$i = $21;
     break;
    } else {
     $20 = (($$0$i$i) + 2)|0;
     $__r$0$i = $20;
     break;
    }
   } else {
    $__r$0$i = $13;
   }
  } else {
   $__r$0$i = $$0$i$i;
  }
 } while(0);
 $22 = HEAP32[$__x5>>2]|0;
 $23 = HEAP32[$__x4>>2]|0;
 $24 = ($22|0)<($23|0);
 if (!($24)) {
  $__r$0 = $__r$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x4>>2] = $22;
 HEAP32[$__x5>>2] = $23;
 $25 = (($__r$0$i) + 1)|0;
 $26 = HEAP32[$__x4>>2]|0;
 $27 = HEAP32[$__x3>>2]|0;
 $28 = ($26|0)<($27|0);
 if (!($28)) {
  $__r$0 = $25;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $26;
 HEAP32[$__x4>>2] = $27;
 $29 = (($__r$0$i) + 2)|0;
 $30 = HEAP32[$__x3>>2]|0;
 $31 = HEAP32[$__x2>>2]|0;
 $32 = ($30|0)<($31|0);
 if (!($32)) {
  $__r$0 = $29;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $30;
 HEAP32[$__x3>>2] = $31;
 $33 = (($__r$0$i) + 3)|0;
 $34 = HEAP32[$__x2>>2]|0;
 $35 = HEAP32[$__x1>>2]|0;
 $36 = ($34|0)<($35|0);
 if (!($36)) {
  $__r$0 = $33;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $34;
 HEAP32[$__x2>>2] = $35;
 $37 = (($__r$0$i) + 4)|0;
 $__r$0 = $37;
 STACKTOP = sp;return ($__r$0|0);
}
function __Z22CullAllPerObjectLightsR8JobFenceiRK13dynamic_arrayI11VisibleNodeLj4EERK12ActiveLightsRS1_I11CulledLightLj4EERS1_IjLj4EE($fence,$renderPath,$visibleNodes,$lights,$forwardCulledLights,$forwardLightOffsets) {
 $fence = $fence|0;
 $renderPath = $renderPath|0;
 $visibleNodes = $visibleNodes|0;
 $lights = $lights|0;
 $forwardCulledLights = $forwardCulledLights|0;
 $forwardLightOffsets = $forwardLightOffsets|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$02$i = 0, $i$04 = 0, $mat$0$i$i = 0, $mi$01$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = (($visibleNodes) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($lights) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[628520>>2]|0;
 HEAP32[$2>>2] = $11;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 $12 = (__Znwj10MemLabelIdbiPKci(360,$$byval_copy3,0,16,578376,351)|0);
 HEAP32[$12>>2] = 0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($12) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($12) + 4|0);
 HEAP32[$15>>2] = 0;
 $16 = HEAP32[628520>>2]|0;
 HEAP32[$12>>2] = $16;
 $17 = (($12) + 16|0);
 HEAP32[$17>>2] = $visibleNodes;
 $18 = (($12) + 20|0);
 HEAP32[$18>>2] = $lights;
 $19 = (($12) + 32|0);
 HEAP32[$19>>2] = $forwardCulledLights;
 $20 = (($12) + 36|0);
 HEAP32[$20>>2] = $forwardLightOffsets;
 $21 = (__Z19GetLightmapSettingsv()|0);
 $22 = (__ZNK16LightmapSettings22GetLightmapsModeLegacyEv($21)|0);
 $23 = ($22|0)==(1);
 $24 = (($12) + 28|0);
 $25 = $23&1;
 HEAP8[$24>>0] = $25;
 $26 = (__Z19GetLightmapSettingsv()|0);
 $27 = (__ZNK16LightmapSettings23HasLightProbeTetrahedraEv($26)|0);
 $28 = (($12) + 29|0);
 $29 = $27&1;
 HEAP8[$28>>0] = $29;
 $30 = (__Z19GetLightmapSettingsv()|0);
 $31 = (__ZNK16LightmapSettings19AreLightProbesBakedEv($30)|0);
 $32 = (($12) + 30|0);
 $33 = $31&1;
 HEAP8[$32>>0] = $33;
 $34 = (($12) + 24|0);
 HEAP32[$34>>2] = $renderPath;
 $35 = HEAP32[$5>>2]|0;
 $36 = HEAP32[$8>>2]|0;
 $37 = Math_imul($36, $35)|0;
 $38 = (($37|0) / 2000)&-1;
 $39 = (($38) + 1)|0;
 $40 = ($39|0)<(1);
 $41 = $40 ? 1 : $39;
 $42 = (($35>>>0) / ($41>>>0))&-1;
 $43 = (($12) + 168|0);
 $44 = (__Z40ConfigureBlockRangesWithMinIndicesPerJobP10BlockRangeii($43,$35,$42)|0);
 $45 = HEAP32[$5>>2]|0;
 $46 = $45 << 2;
 $47 = HEAP32[628520>>2]|0;
 HEAP32[$3>>2] = $47;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
 $48 = (__Z15malloc_internaljj10MemLabelIdiPKci($46,16,$$byval_copy3,0,578376,376)|0);
 $49 = ($44|0)>(0);
 if ($49) {
  $50 = (($12) + 40|0);
  $51 = (($12) + 104|0);
  $i$04 = 0;
  while(1) {
   $52 = HEAP32[628520>>2]|0;
   HEAP32[$4>>2] = $52;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;
   $53 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy3,0,16,578376,379)|0);
   HEAP32[$53>>2] = 0;
   $54 = (($53) + 8|0);
   HEAP32[$54>>2] = 0;
   $55 = (($53) + 12|0);
   HEAP32[$55>>2] = 0;
   $56 = (($53) + 4|0);
   HEAP32[$56>>2] = 61;
   $57 = (($50) + ($i$04<<2)|0);
   HEAP32[$57>>2] = $53;
   $58 = ((($43) + (($i$04*12)|0)|0) + 4|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59*5)|0;
   $61 = ($60|0)==(0);
   if (!($61)) {
    HEAP32[$55>>2] = $60;
    $62 = HEAP32[$53>>2]|0;
    $63 = ($59*40)|0;
    HEAP32[$0>>2] = 61;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $64 = (__Z16realloc_internalPvji10MemLabelIdiPKci($62,$63,4,$$byval_copy3,0,578376,370)|0);
    HEAP32[$53>>2] = $64;
   }
   $65 = (($43) + (($i$04*12)|0)|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($48) + ($66<<2)|0);
   $68 = (($51) + ($i$04<<2)|0);
   HEAP32[$68>>2] = $67;
   $69 = (($i$04) + 1)|0;
   $exitcond = ($69|0)==($44|0);
   if ($exitcond) {
    break;
   } else {
    $i$04 = $69;
   }
  }
 }
 $70 = ($renderPath|0)>(1);
 if ($70) {
  $71 = ($renderPath|0)==(2);
  $72 = $71 ? 3 : 4;
  $73 = HEAP32[$5>>2]|0;
  __ZN14dynamic_bitset6resizeEjb($12,$73,0);
  $74 = HEAP32[$5>>2]|0;
  $75 = ($74|0)==(0);
  if (!($75)) {
   $i$02$i = 0;
   while(1) {
    $76 = HEAP32[$visibleNodes>>2]|0;
    $77 = ((($76) + ($i$02$i<<7)|0) + 116|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = HEAP32[$78>>2]|0;
    $80 = (($79) + 40|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (FUNCTION_TABLE_ii[$81 & 4095]($78)|0);
    $83 = ($82|0)>(0);
    L21: do {
     if ($83) {
      $mi$01$i$i = 0;
      while(1) {
       $86 = HEAP32[$78>>2]|0;
       $87 = (($86) + 44|0);
       $88 = HEAP32[$87>>2]|0;
       FUNCTION_TABLE_viii[$88 & 4095]($1,$78,$mi$01$i$i);
       $89 = HEAP32[$1>>2]|0;
       $90 = ($89|0)==(0);
       do {
        if ($90) {
         label = 25;
        } else {
         HEAP32[$0>>2] = $89;
         $91 = HEAP32[560624>>2]|0;
         $92 = ($91|0)==(0|0);
         if (!($92)) {
          $93 = (($91) + 36|0);
          $94 = HEAP32[$93>>2]|0;
          $95 = (($91) + 4|0);
          $96 = HEAP32[$95>>2]|0;
          $97 = ($94|0)==($96|0);
          do {
           if ($97) {
            $98 = (($91) + 28|0);
            $99 = HEAP32[$98>>2]|0;
            $100 = (($91) + 32|0);
            $101 = HEAP32[$100>>2]|0;
            $102 = (($99) + ($101<<3)|0);
            $118 = $102;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$91,$0);
            $103 = HEAP32[$$byval_copy3>>2]|0;
            $104 = ($103|0)==(-1);
            $105 = (($91) + 28|0);
            $106 = HEAP32[$105>>2]|0;
            if ($104) {
             $107 = (($91) + 32|0);
             $108 = HEAP32[$107>>2]|0;
             $109 = (($106) + ($108<<3)|0);
             $118 = $109;
             break;
            } else {
             $110 = (($106) + ($103<<3)|0);
             $118 = $110;
             break;
            }
           }
          } while(0);
          $111 = HEAP32[560624>>2]|0;
          $112 = (($111) + 28|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = (($111) + 32|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = (($113) + ($115<<3)|0);
          $117 = ($118|0)==($116|0);
          if (!($117)) {
           $119 = (($118) + 4|0);
           $120 = HEAP32[$119>>2]|0;
           $121 = ($120|0)==(0|0);
           if (!($121)) {
            $mat$0$i$i = $120;
            break;
           }
          }
         }
         $122 = HEAP32[$1>>2]|0;
         $123 = (__Z31ReadObjectFromPersistentManageri($122)|0);
         $124 = ($123|0)==(0|0);
         if ($124) {
          label = 25;
         } else {
          $mat$0$i$i = $123;
         }
        }
       } while(0);
       if ((label|0) == 25) {
        label = 0;
        $125 = (__ZN5Unity8Material10GetDefaultEv()|0);
        $mat$0$i$i = $125;
       }
       $126 = (__ZNK5Unity8Material20GetActualRenderQueueEv($mat$0$i$i)|0);
       $127 = ($126|0)>(2500);
       if ($127) {
        break;
       }
       $128 = (__ZN5Unity8Material9GetShaderEv($mat$0$i$i)|0);
       $129 = (($128) + 52|0);
       $130 = HEAP32[$129>>2]|0;
       $131 = ((($130) + ($72<<2)|0) + 12|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = ($132|0)==(-1);
       $85 = (($mi$01$i$i) + 1)|0;
       if ($133) {
        break;
       }
       $84 = ($85|0)<($82|0);
       if ($84) {
        $mi$01$i$i = $85;
       } else {
        label = 29;
        break L21;
       }
      }
      $134 = $i$02$i & 31;
      $135 = 1 << $134;
      $136 = $i$02$i >>> 5;
      $137 = HEAP32[$15>>2]|0;
      $138 = (($137) + ($136<<2)|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = $139 | $135;
      HEAP32[$138>>2] = $140;
     } else {
      label = 29;
     }
    } while(0);
    if ((label|0) == 29) {
     label = 0;
     $141 = $i$02$i & 31;
     $142 = 1 << $141;
     $143 = $142 ^ -1;
     $144 = $i$02$i >>> 5;
     $145 = HEAP32[$15>>2]|0;
     $146 = (($145) + ($144<<2)|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = $147 & $143;
     HEAP32[$146>>2] = $148;
    }
    $149 = (($i$02$i) + 1)|0;
    $150 = HEAP32[$5>>2]|0;
    $151 = ($149>>>0)<($150>>>0);
    if ($151) {
     $i$02$i = $149;
    } else {
     break;
    }
   }
  }
 } else {
  $152 = HEAP32[$5>>2]|0;
  __ZN14dynamic_bitset6resizeEjb($12,$152,1);
 }
 __Z15ScheduleForEachR8JobFencePFvPvjES1_iPFvS1_E11JobPriority($fence,2659,$12,$44,3441,0);
 STACKTOP = sp;return;
}
function __ZL25CullAllPerObjectLightsJobPvj($userData,$index) {
 $userData = $userData|0;
 $index = $index|0;
 var $$ = 0, $$$ = 0, $$1 = 0, $$not$i$i$us$i = 0, $$not$i$i15$i = 0, $$not$i$i18$i = 0, $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$i$i$us$i = 0, $brmerge$i$i16$i = 0;
 var $brmerge$i$i19$i = 0, $count$03 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond47$i = 0, $exitcond48$i = 0, $exitcond49$i = 0, $exitcond50$i = 0, $exitcond51$i = 0, $i$04 = 0, $index$0$lcssa$i = 0, $index$041$i = 0, $index$1$lcssa$i = 0, $index$136$i = 0, $index$2$lcssa$i = 0, $index$230$i = 0, $index$3$lcssa$i = 0, $index$326$i = 0, $index$424$i = 0, $index$424$us$i = 0;
 var $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($userData) + 168|0);
 $2 = (($1) + (($index*12)|0)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1) + (($index*12)|0)|0) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($3))|0;
 $7 = (($userData) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($userData) + 28|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = (($userData) + 29|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 $14 = (($userData) + 30|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)!=(0);
 $17 = (($userData) + 40|0);
 $18 = (($17) + ($index<<2)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($userData) + 104|0);
 $21 = (($20) + ($index<<2)|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($3|0)<($6|0);
 if (!($23)) {
  STACKTOP = sp;return;
 }
 $24 = (($userData) + 24|0);
 $25 = (($userData) + 16|0);
 $26 = HEAP32[$24>>2]|0;
 $27 = HEAP32[$25>>2]|0;
 $28 = (($19) + 8|0);
 $29 = (($userData) + 4|0);
 $30 = ($10<<24>>24)!=(0);
 $31 = (($8) + 20|0);
 $32 = (($8) + 24|0);
 $33 = (($8) + 28|0);
 $34 = (($8) + 32|0);
 $35 = (($8) + 36|0);
 $36 = ($10<<24>>24)==(0);
 $count$03 = 0;$i$04 = $3;
 while(1) {
  $37 = HEAP32[$28>>2]|0;
  $38 = (($count$03) + 1)|0;
  $39 = (($22) + ($count$03<<2)|0);
  HEAP32[$39>>2] = $37;
  $40 = HEAP32[$27>>2]|0;
  $41 = (($40) + ($i$04<<7)|0);
  $42 = $i$04 >>> 5;
  $43 = HEAP32[$29>>2]|0;
  $44 = (($43) + ($42<<2)|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $i$04 & 31;
  $47 = 1 << $46;
  $48 = $45 & $47;
  $49 = ($48|0)==(0);
  if ($49) {
   $50 = ((($40) + ($i$04<<7)|0) + 124|0);
   HEAP8[$50>>0] = 0;
  } else {
   $51 = ((($40) + ($i$04<<7)|0) + 116|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 32|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (FUNCTION_TABLE_ii[$55 & 4095]($52)|0);
   $57 = 1 << $56;
   $58 = (($52) + 36|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59&65535;
   $$off$i = (($60) + -254)<<16>>16;
   $61 = ($$off$i&65535)>(1);
   $62 = (__Z30IsUsingLightProbesForRenderingPK12BaseRendererbb($52,$13,$16)|0);
   $$ = $62 & $36;
   $not$ = ($26|0)!=(0);
   $$$ = $$ & $not$;
   $$1 = $61 | $$$;
   $63 = HEAP32[$28>>2]|0;
   $64 = ((($40) + ($i$04<<7)|0) + 64|0);
   $65 = ((($40) + ($i$04<<7)|0) + 64|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = ((($40) + ($i$04<<7)|0) + 68|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = ((($40) + ($i$04<<7)|0) + 72|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = HEAP32[$31>>2]|0;
   $72 = ($71|0)==(0);
   if ($72) {
    $index$0$lcssa$i = 0;
   } else {
    $index$041$i = 0;
    while(1) {
     $73 = HEAP32[$8>>2]|0;
     if ($$1) {
      $74 = ((($73) + (($index$041$i*108)|0)|0) + 12|0);
      $75 = HEAP32[$74>>2]|0;
      $$not$i$i15$i = ($75|0)!=(1);
      $brmerge$i$i16$i = $$not$i$i15$i | $30;
      if ($brmerge$i$i16$i) {
       label = 8;
      }
     } else {
      label = 8;
     }
     if ((label|0) == 8) {
      label = 0;
      $76 = ((($73) + (($index$041$i*108)|0)|0) + 16|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = $77 & $57;
      $79 = ($78|0)==(0);
      if (!($79)) {
       __ZL8AddLightRK12ActiveLightsRK8Vector3fiR13dynamic_arrayI11CulledLightLj4EE($8,$66,$68,$70,$index$041$i,$19);
      }
     }
     $80 = (($index$041$i) + 1)|0;
     $exitcond50$i = ($80|0)==($71|0);
     if ($exitcond50$i) {
      $index$0$lcssa$i = $71;
      break;
     } else {
      $index$041$i = $80;
     }
    }
   }
   $81 = HEAP32[$32>>2]|0;
   $82 = (($81) + ($71))|0;
   $83 = ($index$0$lcssa$i>>>0)<($82>>>0);
   if ($83) {
    $84 = ((($40) + ($i$04<<7)|0) + 88|0);
    $index$136$i = $index$0$lcssa$i;
    while(1) {
     $85 = HEAP32[$8>>2]|0;
     $86 = (($85) + (($index$136$i*108)|0)|0);
     $87 = (__ZL17IsSpotLightCulledRK11ActiveLightibbRK4AABBS4_RK10Matrix4x4f($86,$57,$$1,$30,$64,$84,$41)|0);
     if (!($87)) {
      __ZL8AddLightRK12ActiveLightsRK8Vector3fiR13dynamic_arrayI11CulledLightLj4EE($8,$66,$68,$70,$index$136$i,$19);
     }
     $88 = (($index$136$i) + 1)|0;
     $exitcond49$i = ($88|0)==($82|0);
     if ($exitcond49$i) {
      $index$1$lcssa$i = $82;
      break;
     } else {
      $index$136$i = $88;
     }
    }
   } else {
    $index$1$lcssa$i = $index$0$lcssa$i;
   }
   $89 = HEAP32[$33>>2]|0;
   $90 = (($89) + ($82))|0;
   $91 = ($index$1$lcssa$i>>>0)<($90>>>0);
   if ($91) {
    $92 = ((($40) + ($i$04<<7)|0) + 88|0);
    $93 = ((($40) + ($i$04<<7)|0) + 112|0);
    $index$230$i = $index$1$lcssa$i;
    while(1) {
     $94 = HEAP32[$8>>2]|0;
     if ($$1) {
      $95 = ((($94) + (($index$230$i*108)|0)|0) + 12|0);
      $96 = HEAP32[$95>>2]|0;
      $$not$i$i18$i = ($96|0)!=(1);
      $brmerge$i$i19$i = $$not$i$i18$i | $30;
      if ($brmerge$i$i19$i) {
       label = 20;
      }
     } else {
      label = 20;
     }
     if ((label|0) == 20) {
      label = 0;
      $97 = ((($94) + (($index$230$i*108)|0)|0) + 16|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = $98 & $57;
      $100 = ($99|0)==(0);
      if (!($100)) {
       $101 = ((($94) + (($index$230$i*108)|0)|0) + 80|0);
       $102 = (__Z19IntersectAABBSphereRK4AABBRK6Sphere($64,$101)|0);
       if ($102) {
        $103 = HEAP32[$93>>2]|0;
        $104 = (__Z30IntersectTransformedAABBSphereRK4AABBRK10Matrix4x4f13TransformTypeRK6Sphere($92,$41,$103,$101)|0);
        if ($104) {
         __ZL8AddLightRK12ActiveLightsRK8Vector3fiR13dynamic_arrayI11CulledLightLj4EE($8,$66,$68,$70,$index$230$i,$19);
        }
       }
      }
     }
     $105 = (($index$230$i) + 1)|0;
     $exitcond48$i = ($105|0)==($90|0);
     if ($exitcond48$i) {
      $index$2$lcssa$i = $90;
      break;
     } else {
      $index$230$i = $105;
     }
    }
   } else {
    $index$2$lcssa$i = $index$1$lcssa$i;
   }
   $106 = HEAP32[$28>>2]|0;
   $107 = HEAP32[$34>>2]|0;
   $108 = (($107) + ($90))|0;
   $109 = ($index$2$lcssa$i>>>0)<($108>>>0);
   if ($109) {
    $110 = ((($40) + ($i$04<<7)|0) + 88|0);
    $index$326$i = $index$2$lcssa$i;
    while(1) {
     $111 = HEAP32[$8>>2]|0;
     $112 = (($111) + (($index$326$i*108)|0)|0);
     $113 = (__ZL17IsSpotLightCulledRK11ActiveLightibbRK4AABBS4_RK10Matrix4x4f($112,$57,$$1,$30,$64,$110,$41)|0);
     if (!($113)) {
      __ZL8AddLightRK12ActiveLightsRK8Vector3fiR13dynamic_arrayI11CulledLightLj4EE($8,$66,$68,$70,$index$326$i,$19);
     }
     $114 = (($index$326$i) + 1)|0;
     $exitcond47$i = ($114|0)==($108|0);
     if ($exitcond47$i) {
      $index$3$lcssa$i = $108;
      break;
     } else {
      $index$326$i = $114;
     }
    }
   } else {
    $index$3$lcssa$i = $index$2$lcssa$i;
   }
   $115 = HEAP32[$35>>2]|0;
   $116 = (($115) + ($108))|0;
   $117 = ($index$3$lcssa$i>>>0)<($116>>>0);
   L47: do {
    if ($117) {
     $118 = ((($40) + ($i$04<<7)|0) + 88|0);
     $119 = ((($40) + ($i$04<<7)|0) + 112|0);
     if ($$1) {
      $index$424$us$i = $index$3$lcssa$i;
     } else {
      $index$424$i = $index$3$lcssa$i;
      while(1) {
       $132 = HEAP32[$8>>2]|0;
       $133 = ((($132) + (($index$424$i*108)|0)|0) + 16|0);
       $134 = HEAP32[$133>>2]|0;
       $135 = $134 & $57;
       $136 = ($135|0)==(0);
       if (!($136)) {
        $137 = ((($132) + (($index$424$i*108)|0)|0) + 80|0);
        $138 = (__Z19IntersectAABBSphereRK4AABBRK6Sphere($64,$137)|0);
        if ($138) {
         $139 = HEAP32[$119>>2]|0;
         $140 = (__Z30IntersectTransformedAABBSphereRK4AABBRK10Matrix4x4f13TransformTypeRK6Sphere($118,$41,$139,$137)|0);
         if ($140) {
          __ZL8AddLightRK12ActiveLightsRK8Vector3fiR13dynamic_arrayI11CulledLightLj4EE($8,$66,$68,$70,$index$424$i,$19);
         }
        }
       }
       $141 = (($index$424$i) + 1)|0;
       $exitcond$i = ($141|0)==($116|0);
       if ($exitcond$i) {
        break L47;
       } else {
        $index$424$i = $141;
       }
      }
     }
     while(1) {
      $120 = HEAP32[$8>>2]|0;
      $121 = ((($120) + (($index$424$us$i*108)|0)|0) + 12|0);
      $122 = HEAP32[$121>>2]|0;
      $$not$i$i$us$i = ($122|0)!=(1);
      $brmerge$i$i$us$i = $$not$i$i$us$i | $30;
      if ($brmerge$i$i$us$i) {
       $123 = ((($120) + (($index$424$us$i*108)|0)|0) + 16|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = $124 & $57;
       $126 = ($125|0)==(0);
       if (!($126)) {
        $127 = ((($120) + (($index$424$us$i*108)|0)|0) + 80|0);
        $128 = (__Z19IntersectAABBSphereRK4AABBRK6Sphere($64,$127)|0);
        if ($128) {
         $129 = HEAP32[$119>>2]|0;
         $130 = (__Z30IntersectTransformedAABBSphereRK4AABBRK10Matrix4x4f13TransformTypeRK6Sphere($118,$41,$129,$127)|0);
         if ($130) {
          __ZL8AddLightRK12ActiveLightsRK8Vector3fiR13dynamic_arrayI11CulledLightLj4EE($8,$66,$68,$70,$index$424$us$i,$19);
         }
        }
       }
      }
      $131 = (($index$424$us$i) + 1)|0;
      $exitcond51$i = ($131|0)==($116|0);
      if ($exitcond51$i) {
       break;
      } else {
       $index$424$us$i = $131;
      }
     }
    }
   } while(0);
   $142 = HEAP32[$28>>2]|0;
   $143 = ($142|0)==($63|0);
   if (!($143)) {
    $144 = HEAP32[$19>>2]|0;
    $145 = (($144) + ($63<<3)|0);
    $146 = (($144) + ($142<<3)|0);
    __ZNSt3__16__sortIRNS_6__lessI11CulledLightS2_EEPS2_EEvT0_S6_T_($145,$146,$0);
   }
   $147 = ($142|0)!=($106|0);
   $148 = ((($40) + ($i$04<<7)|0) + 124|0);
   $149 = $147&1;
   HEAP8[$148>>0] = $149;
  }
  $exitcond = ($38|0)==($5|0);
  if ($exitcond) {
   break;
  }
  $150 = (($i$04) + 1)|0;
  $count$03 = $38;$i$04 = $150;
 }
 STACKTOP = sp;return;
}
function __ZL32CullAllPerObjectLightsCombineJobPv($userData) {
 $userData = $userData|0;
 var $$byval_copy4 = 0, $$pre = 0, $$pre$phi15Z2D = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $exitcond = 0, $exitcond11 = 0, $exitcond13 = 0, $i$07 = 0, $i1$04 = 0, $j$03 = 0;
 var $offsetCount$0$lcssa = 0, $offsetCount$05 = 0, $or$cond = 0, $totalLights$0$lcssa = 0, $totalLights$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 4|0;
 $0 = sp;
 $1 = (($userData) + 168|0);
 $2 = (($userData) + 176|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($userData) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($userData) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($userData) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($3|0)>(0);
 if ($10) {
  $11 = (($userData) + 40|0);
  $i$07 = 0;$totalLights$08 = 0;
  while(1) {
   $12 = (($11) + ($i$07<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + ($totalLights$08))|0;
   $17 = (($i$07) + 1)|0;
   $exitcond13 = ($17|0)==($3|0);
   if ($exitcond13) {
    $totalLights$0$lcssa = $16;
    break;
   } else {
    $i$07 = $17;$totalLights$08 = $16;
   }
  }
 } else {
  $totalLights$0$lcssa = 0;
 }
 $18 = (($7) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & 2147483647;
 $21 = ($20>>>0)<($totalLights$0$lcssa>>>0);
 do {
  if ($21) {
   $22 = ($19|0)>(-1);
   if ($22) {
    HEAP32[$18>>2] = $totalLights$0$lcssa;
    $23 = HEAP32[$7>>2]|0;
    $24 = $totalLights$0$lcssa << 3;
    $25 = (($7) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP32[$0>>2] = $26;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $27 = (__Z16realloc_internalPvji10MemLabelIdiPKci($23,$24,4,$$byval_copy4,0,578376,370)|0);
    HEAP32[$7>>2] = $27;
    break;
   } else {
    $28 = $totalLights$0$lcssa << 3;
    $29 = (($7) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    HEAP32[$0>>2] = $30;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $31 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,4,$$byval_copy4,0,578376,352)|0);
    $32 = HEAP32[$7>>2]|0;
    $33 = (($7) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = $34 << 3;
    _memcpy(($31|0),($32|0),($35|0))|0;
    HEAP32[$18>>2] = $totalLights$0$lcssa;
    HEAP32[$7>>2] = $31;
    break;
   }
  }
 } while(0);
 $36 = (($5) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 $39 = (($9) + 8|0);
 HEAP32[$39>>2] = $38;
 $40 = (($9) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 2147483647;
 $43 = ($42>>>0)<($38>>>0);
 do {
  if ($43) {
   $44 = ($41|0)>(-1);
   if ($44) {
    HEAP32[$40>>2] = $38;
    $45 = HEAP32[$9>>2]|0;
    $46 = $38 << 2;
    $47 = (($9) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    HEAP32[$0>>2] = $48;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $49 = (__Z16realloc_internalPvji10MemLabelIdiPKci($45,$46,4,$$byval_copy4,0,578376,370)|0);
    HEAP32[$9>>2] = $49;
    break;
   } else {
    $50 = $38 << 2;
    $51 = (($9) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    HEAP32[$0>>2] = $52;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $53 = (__Z15malloc_internaljj10MemLabelIdiPKci($50,4,$$byval_copy4,0,578376,352)|0);
    $54 = HEAP32[$9>>2]|0;
    $55 = HEAP32[$39>>2]|0;
    $56 = $55 << 2;
    _memcpy(($53|0),($54|0),($56|0))|0;
    HEAP32[$40>>2] = $38;
    HEAP32[$9>>2] = $53;
    break;
   }
  }
 } while(0);
 if ($10) {
  $57 = (($userData) + 40|0);
  $58 = (($userData) + 104|0);
  $59 = (($7) + 8|0);
  $i1$04 = 0;$offsetCount$05 = 0;
  while(1) {
   $60 = (($57) + ($i1$04<<2)|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($58) + ($i1$04<<2)|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ((($1) + (($i1$04*12)|0)|0) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[$59>>2]|0;
   $67 = ($66|0)==(0);
   $68 = ($65|0)==(0);
   $or$cond = $67 | $68;
   if (!($or$cond)) {
    $j$03 = 0;
    while(1) {
     $69 = (($63) + ($j$03<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($70) + ($66))|0;
     HEAP32[$69>>2] = $71;
     $72 = (($j$03) + 1)|0;
     $exitcond = ($72|0)==($65|0);
     if ($exitcond) {
      break;
     } else {
      $j$03 = $72;
     }
    }
   }
   $73 = HEAP32[$9>>2]|0;
   $74 = (($73) + ($offsetCount$05<<2)|0);
   $75 = $65 << 2;
   _memcpy(($74|0),($63|0),($75|0))|0;
   $76 = (($65) + ($offsetCount$05))|0;
   $77 = HEAP32[$7>>2]|0;
   $78 = HEAP32[$59>>2]|0;
   $79 = (($77) + ($78<<3)|0);
   $80 = HEAP32[$61>>2]|0;
   $81 = (($61) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($80) + ($82<<3)|0);
   (__ZN13dynamic_arrayI11CulledLightLj4EE6insertEPS0_PKS0_S4_($7,$79,$80,$83)|0);
   $84 = (($i1$04) + 1)|0;
   $exitcond11 = ($84|0)==($3|0);
   if ($exitcond11) {
    $$pre$phi15Z2D = $9;$$pre$phiZ2D = $59;$offsetCount$0$lcssa = $76;
    break;
   } else {
    $i1$04 = $84;$offsetCount$05 = $76;
   }
  }
 } else {
  $$pre = (($7) + 8|0);
  $$pre$phi15Z2D = $9;$$pre$phiZ2D = $$pre;$offsetCount$0$lcssa = 0;
 }
 $85 = HEAP32[$$pre$phiZ2D>>2]|0;
 $86 = HEAP32[$$pre$phi15Z2D>>2]|0;
 $87 = (($86) + ($offsetCount$0$lcssa<<2)|0);
 HEAP32[$87>>2] = $85;
 $88 = HEAP32[628520>>2]|0;
 $89 = ($userData|0)==(0|0);
 if ($89) {
  HEAP32[$0>>2] = $88;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy4);
  STACKTOP = sp;return;
 }
 __ZN29CullAllPerObjectLightsJobDataD2Ev($userData);
 HEAP32[$0>>2] = $88;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy4);
 STACKTOP = sp;return;
}
function __Z25IsObjectWithinShadowRangeRK14ShadowCullDataRK4AABB($shadowCullData,$bounds) {
 $shadowCullData = $shadowCullData|0;
 $bounds = $bounds|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $sphere = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $sphere = sp;
 $0 = (($shadowCullData) + 576|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $29 = (($shadowCullData) + 540|0);
  $30 = (__Z24IntersectAABBPlaneBoundsRK4AABBPK5Planei($bounds,$29,1)|0);
  $$0 = $30;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($shadowCullData) + 556|0);
 $4 = Math_fround(HEAPF32[$bounds>>2]);
 $5 = Math_fround(HEAPF32[$3>>2]);
 $6 = Math_fround($4 - $5);
 $7 = (($bounds) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($shadowCullData) + 560|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 - $10);
 $12 = (($bounds) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($shadowCullData) + 564|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = Math_fround($6 * $6);
 $18 = Math_fround($11 * $11);
 $19 = Math_fround($17 + $18);
 $20 = Math_fround($16 * $16);
 $21 = Math_fround($19 + $20);
 $22 = (($shadowCullData) + 572|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = $21 < $23;
 if ($24) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $25 = (($shadowCullData) + 568|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 ;HEAP32[$sphere+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$sphere+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$sphere+8>>2]=HEAP32[$3+8>>2]|0;
 $27 = (($sphere) + 12|0);
 HEAPF32[$27>>2] = $26;
 $28 = (__Z19IntersectAABBSphereRK4AABBRK6Sphere($bounds,$sphere)|0);
 $$0 = $28;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13dynamic_arrayI11CulledLightLj4EE6insertEPS0_PKS0_S4_($this,$insert_before,$input_begin,$input_end) {
 $this = $this|0;
 $insert_before = $insert_before|0;
 $input_begin = $input_begin|0;
 $input_end = $input_end|0;
 var $$byval_copy1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = $insert_before;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 3;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) - ($5))|0;
 $9 = $input_end;
 $10 = $input_begin;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 3;
 $13 = (($7) + ($12))|0;
 HEAP32[$6>>2] = $13;
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($13>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $13;
    $19 = $13 << 3;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$19,4,$$byval_copy1,0,578376,370)|0);
    HEAP32[$this>>2] = $22;
    $31 = $22;
    break;
   } else {
    $23 = $13 << 3;
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$0>>2] = $25;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,4,$$byval_copy1,0,578376,352)|0);
    $27 = HEAP32[$this>>2]|0;
    $28 = HEAP32[$6>>2]|0;
    $29 = $28 << 3;
    _memcpy(($26|0),($27|0),($29|0))|0;
    HEAP32[$14>>2] = $13;
    HEAP32[$this>>2] = $26;
    $31 = $26;
    break;
   }
  } else {
   $31 = $1;
  }
 } while(0);
 $30 = (($31) + ($5<<3)|0);
 $$sum = (($5) + ($12))|0;
 $32 = (($31) + ($$sum<<3)|0);
 $33 = $8 << 3;
 _memmove(($32|0),($30|0),($33|0))|0;
 _memcpy(($30|0),($input_begin|0),($11|0))|0;
 STACKTOP = sp;return ($30|0);
}
function __ZN29CullAllPerObjectLightsJobDataD2Ev($this) {
 $this = $this|0;
 var $$byval_copy9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$09 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy9 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 104|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[628520>>2]|0;
 HEAP32[$3>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($5|0),($$byval_copy9|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if ($8) {
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   $lpad$phi$index = $30;$lpad$phi$index2 = $31;
  } else {
   HEAP32[$4>>2] = 0;
   $9 = (($this) + 176|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)>(0);
   if (!($11)) {
    $37 = (($this) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = HEAP32[$this>>2]|0;
    HEAP32[$0>>2] = $39;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($38,$$byval_copy9);
    STACKTOP = sp;return;
   }
   $i$09 = 0;
   while(1) {
    $12 = ((($this) + ($i$09<<2)|0) + 40|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[628520>>2]|0;
    $15 = ($13|0)==(0|0);
    if (!($15)) {
     $16 = (($13) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)>(-1);
     if ($18) {
      $19 = HEAP32[$13>>2]|0;
      $20 = (($13) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      HEAP32[$1>>2] = $21;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($19|0),($$byval_copy9|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 10;
       break;
      }
      HEAP32[$13>>2] = 0;
     }
    }
    HEAP32[$2>>2] = $14;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($13|0),($$byval_copy9|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     label = 10;
     break;
    }
    HEAP32[$12>>2] = 0;
    $26 = (($i$09) + 1)|0;
    $27 = ($26|0)<($10|0);
    if ($27) {
     $i$09 = $26;
    } else {
     label = 13;
     break;
    }
   }
   if ((label|0) == 10) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    $lpad$phi$index = $28;$lpad$phi$index2 = $29;
    break;
   }
   else if ((label|0) == 13) {
    $37 = (($this) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = HEAP32[$this>>2]|0;
    HEAP32[$0>>2] = $39;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($38,$$byval_copy9);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $32 = (($this) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$0>>2] = $34;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy9|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $40 = ___cxa_find_matching_catch(0|0)|0;
  $41 = tempRet0;
  ___clang_call_terminate($40);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZL8AddLightRK12ActiveLightsRK8Vector3fiR13dynamic_arrayI11CulledLightLj4EE($activeLights,$objectCenter$0$0$val,$objectCenter$0$1$val,$objectCenter$0$2$val,$index,$outLights) {
 $activeLights = $activeLights|0;
 $objectCenter$0$0$val = Math_fround($objectCenter$0$0$val);
 $objectCenter$0$1$val = Math_fround($objectCenter$0$1$val);
 $objectCenter$0$2$val = Math_fround($objectCenter$0$2$val);
 $index = $index|0;
 $outLights = $outLights|0;
 var $$0$i = Math_fround(0), $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$activeLights>>2]|0;
 $2 = (($1) + (($index*108)|0)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1) + (($index*108)|0)|0) + 96|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($3) + 216|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(1);
 if ($8) {
  $9 = (($3) + 116|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   $$0$i = $5;
  } else {
   $12 = Math_fround($5 * Math_fround(16.0));
   $$0$i = $12;
  }
 } else {
  $13 = (($3) + 104|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($objectCenter$0$0$val - $14);
  $16 = (($3) + 108|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($objectCenter$0$1$val - $17);
  $19 = (($3) + 112|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($objectCenter$0$2$val - $20);
  $22 = Math_fround($15 * $15);
  $23 = Math_fround($18 * $18);
  $24 = Math_fround($22 + $23);
  $25 = Math_fround($21 * $21);
  $26 = Math_fround($24 + $25);
  $27 = (Math_fround(__ZNK5Light15AttenuateApproxEf($3,$26)));
  $28 = Math_fround($5 * $27);
  $$0$i = $28;
 }
 $29 = (($3) + 208|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (Math_fround(__Z21GetRenderModeSortBiasi($30)));
 $32 = Math_fround($$0$i + $31);
 $33 = (($outLights) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 1)|0;
 HEAP32[$33>>2] = $35;
 $36 = (($outLights) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($35>>>0)>($38>>>0);
 if (!($39)) {
  $58 = $35;
  $57 = (($58) + -1)|0;
  $59 = HEAP32[$outLights>>2]|0;
  $60 = (($59) + ($57<<3)|0);
  $61 = (HEAPF32[tempDoublePtr>>2]=$32,HEAP32[tempDoublePtr>>2]|0);
  $62 = $60;
  $63 = $62;
  HEAP32[$63>>2] = $index;
  $64 = (($62) + 4)|0;
  $65 = $64;
  HEAP32[$65>>2] = $61;
  STACKTOP = sp;return;
 }
 $40 = $37 << 1;
 $41 = ($40|0)==(0);
 $42 = $41 ? 1 : $40;
 $43 = ($38>>>0)<($42>>>0);
 do {
  if ($43) {
   $44 = ($37|0)>(-1);
   if ($44) {
    HEAP32[$36>>2] = $42;
    $45 = HEAP32[$outLights>>2]|0;
    $46 = $42 << 3;
    $47 = (($outLights) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    HEAP32[$0>>2] = $48;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $49 = (__Z16realloc_internalPvji10MemLabelIdiPKci($45,$46,4,$$byval_copy1,0,578376,370)|0);
    HEAP32[$outLights>>2] = $49;
    break;
   } else {
    $50 = $42 << 3;
    $51 = (($outLights) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    HEAP32[$0>>2] = $52;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $53 = (__Z15malloc_internaljj10MemLabelIdiPKci($50,4,$$byval_copy1,0,578376,352)|0);
    $54 = HEAP32[$outLights>>2]|0;
    $55 = HEAP32[$33>>2]|0;
    $56 = $55 << 3;
    _memcpy(($53|0),($54|0),($56|0))|0;
    HEAP32[$36>>2] = $42;
    HEAP32[$outLights>>2] = $53;
    break;
   }
  }
 } while(0);
 $$pre$i$i = HEAP32[$33>>2]|0;
 $58 = $$pre$i$i;
 $57 = (($58) + -1)|0;
 $59 = HEAP32[$outLights>>2]|0;
 $60 = (($59) + ($57<<3)|0);
 $61 = (HEAPF32[tempDoublePtr>>2]=$32,HEAP32[tempDoublePtr>>2]|0);
 $62 = $60;
 $63 = $62;
 HEAP32[$63>>2] = $index;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = $61;
 STACKTOP = sp;return;
}
function __ZL17IsSpotLightCulledRK11ActiveLightibbRK4AABBS4_RK10Matrix4x4f($light,$layerMask,$lightmappedObject,$dualLightmapsMode,$globalObjectAABB,$localObjectAABB,$objectTransform) {
 $light = $light|0;
 $layerMask = $layerMask|0;
 $lightmappedObject = $lightmappedObject|0;
 $dualLightmapsMode = $dualLightmapsMode|0;
 $globalObjectAABB = $globalObjectAABB|0;
 $localObjectAABB = $localObjectAABB|0;
 $objectTransform = $objectTransform|0;
 var $$1 = 0, $$not$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $brmerge$i = 0, $finalProjMatrix = 0, $not$ = 0, $objectToLightMatrix = 0, $planes = 0, $projectionMatrix = 0, $temp = 0, $zscale = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $planes = sp + 336|0;
 $zscale = sp;
 $objectToLightMatrix = sp + 64|0;
 $projectionMatrix = sp + 128|0;
 $0 = sp + 192|0;
 $temp = sp + 208|0;
 $finalProjMatrix = sp + 272|0;
 if ($lightmappedObject) {
  $1 = (($light) + 12|0);
  $2 = HEAP32[$1>>2]|0;
  $$not$i = ($2|0)!=(1);
  $brmerge$i = $$not$i | $dualLightmapsMode;
  if (!($brmerge$i)) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $3 = (($light) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & $layerMask;
 $6 = ($5|0)==(0);
 if ($6) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $7 = (($light) + 24|0);
 $8 = (__Z17IntersectAABBAABBRK4AABBS1_($globalObjectAABB,$7)|0);
 if (!($8)) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $9 = HEAP32[$light>>2]|0;
 HEAPF32[$planes>>2] = Math_fround(0.0);
 $10 = (($planes) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($planes) + 8|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($planes) + 16|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($planes) + 20|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($planes) + 24|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($planes) + 32|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($planes) + 36|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($planes) + 40|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($planes) + 48|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($planes) + 52|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($planes) + 56|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($planes) + 64|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($planes) + 68|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($planes) + 72|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($planes) + 80|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($planes) + 84|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($planes) + 88|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $27 = (($0) + 4|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($0) + 8|0);
 HEAPF32[$28>>2] = Math_fround(-1.0);
 (__ZN10Matrix4x4f8SetScaleERK8Vector3f($zscale,$0)|0);
 $29 = (($9) + 188|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * Math_fround(9.99999974737875163555E-6));
 $32 = $31 > Math_fround(9.99999974737875163555E-5);
 $33 = $32 ? $31 : Math_fround(9.99999974737875163555E-5);
 $34 = (($9) + 200|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 (__ZN10Matrix4x4f19SetPerspectiveCotanEfff($projectionMatrix,$35,$33,$30)|0);
 $36 = (($9) + 40|0);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($zscale,$36,$temp);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($temp,$objectTransform,$objectToLightMatrix);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($projectionMatrix,$objectToLightMatrix,$finalProjMatrix);
 __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($finalProjMatrix,$planes);
 $37 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($localObjectAABB,$planes)|0);
 $not$ = $37 ^ 1;
 $$1 = $not$;
 STACKTOP = sp;return ($$1|0);
}
function __ZNSt3__16__sortIRNS_6__lessI11CulledLightS2_EEPS2_EEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0);
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0);
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = Math_fround(0);
 var $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = Math_fround(0), $487 = Math_fround(0), $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = Math_fround(0), $544 = Math_fround(0), $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = Math_fround(0), $562 = Math_fround(0), $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = Math_fround(0), $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = Math_fround(0), $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = Math_fround(0);
 var $597 = 0, $598 = Math_fround(0), $599 = 0, $6 = Math_fround(0), $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = Math_fround(0), $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = Math_fround(0), $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = Math_fround(0), $654 = 0, $655 = Math_fround(0), $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = Math_fround(0), $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $687 = Math_fround(0), $688 = 0, $689 = Math_fround(0), $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0;
 var $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$011 = 0, $__i$02$i = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0;
 var $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__k$0$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $2 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $3 = $$0;
   $4 = (($0) - ($3))|0;
   $5 = $4 >> 3;
   switch ($5|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 85;
    break L1;
    break;
   }
   default: {
   }
   }
   $220 = ($4|0)<(248);
   if ($220) {
    label = 21;
    break L1;
   }
   $352 = ($4|0)>(7992);
   $353 = (($5|0) / 2)&-1;
   $354 = (($$0) + ($353<<3)|0);
   do {
    if ($352) {
     $355 = (($5|0) / 4)&-1;
     $356 = (($$0) + ($355<<3)|0);
     $$sum = (($355) + ($353))|0;
     $357 = (($$0) + ($$sum<<3)|0);
     $358 = (__ZNSt3__17__sort4IRNS_6__lessI11CulledLightS2_EEPS2_EEjT0_S6_S6_S6_T_($$0,$356,$354,$357,0)|0);
     $359 = Math_fround(HEAPF32[$2>>2]);
     $360 = ((($$0) + ($$sum<<3)|0) + 4|0);
     $361 = Math_fround(HEAPF32[$360>>2]);
     $362 = $359 > $361;
     if (!($362)) {
      $$pre = ((($$0) + ($353<<3)|0) + 4|0);
      $$pre$phiZ2D = $$pre;$__n_swaps$0 = $358;
      break;
     }
     $363 = $357;
     $364 = $363;
     $365 = HEAP32[$364>>2]|0;
     $366 = (($363) + 4)|0;
     $367 = $366;
     $368 = HEAP32[$367>>2]|0;
     $369 = $1;
     $370 = $369;
     $371 = HEAP32[$370>>2]|0;
     $372 = (($369) + 4)|0;
     $373 = $372;
     $374 = HEAP32[$373>>2]|0;
     $375 = $357;
     $376 = $375;
     HEAP32[$376>>2] = $371;
     $377 = (($375) + 4)|0;
     $378 = $377;
     HEAP32[$378>>2] = $374;
     $379 = $1;
     $380 = $379;
     HEAP32[$380>>2] = $365;
     $381 = (($379) + 4)|0;
     $382 = $381;
     HEAP32[$382>>2] = $368;
     $383 = Math_fround(HEAPF32[$360>>2]);
     $384 = ((($$0) + ($353<<3)|0) + 4|0);
     $385 = Math_fround(HEAPF32[$384>>2]);
     $386 = $383 > $385;
     if (!($386)) {
      $387 = (($358) + 1)|0;
      $$pre$phiZ2D = $384;$__n_swaps$0 = $387;
      break;
     }
     $388 = $354;
     $389 = $388;
     $390 = HEAP32[$389>>2]|0;
     $391 = (($388) + 4)|0;
     $392 = $391;
     $393 = HEAP32[$392>>2]|0;
     $394 = $357;
     $395 = $394;
     $396 = HEAP32[$395>>2]|0;
     $397 = (($394) + 4)|0;
     $398 = $397;
     $399 = HEAP32[$398>>2]|0;
     $400 = $354;
     $401 = $400;
     HEAP32[$401>>2] = $396;
     $402 = (($400) + 4)|0;
     $403 = $402;
     HEAP32[$403>>2] = $399;
     $404 = $357;
     $405 = $404;
     HEAP32[$405>>2] = $390;
     $406 = (($404) + 4)|0;
     $407 = $406;
     HEAP32[$407>>2] = $393;
     $408 = Math_fround(HEAPF32[$384>>2]);
     $409 = ((($$0) + ($355<<3)|0) + 4|0);
     $410 = Math_fround(HEAPF32[$409>>2]);
     $411 = $408 > $410;
     if (!($411)) {
      $412 = (($358) + 2)|0;
      $$pre$phiZ2D = $384;$__n_swaps$0 = $412;
      break;
     }
     $413 = $356;
     $414 = $413;
     $415 = HEAP32[$414>>2]|0;
     $416 = (($413) + 4)|0;
     $417 = $416;
     $418 = HEAP32[$417>>2]|0;
     $419 = $354;
     $420 = $419;
     $421 = HEAP32[$420>>2]|0;
     $422 = (($419) + 4)|0;
     $423 = $422;
     $424 = HEAP32[$423>>2]|0;
     $425 = $356;
     $426 = $425;
     HEAP32[$426>>2] = $421;
     $427 = (($425) + 4)|0;
     $428 = $427;
     HEAP32[$428>>2] = $424;
     $429 = $354;
     $430 = $429;
     HEAP32[$430>>2] = $415;
     $431 = (($429) + 4)|0;
     $432 = $431;
     HEAP32[$432>>2] = $418;
     $433 = Math_fround(HEAPF32[$409>>2]);
     $434 = (($$0) + 4|0);
     $435 = Math_fround(HEAPF32[$434>>2]);
     $436 = $433 > $435;
     if ($436) {
      $438 = $$0;
      $439 = $438;
      $440 = HEAP32[$439>>2]|0;
      $441 = (($438) + 4)|0;
      $442 = $441;
      $443 = HEAP32[$442>>2]|0;
      $444 = $356;
      $445 = $444;
      $446 = HEAP32[$445>>2]|0;
      $447 = (($444) + 4)|0;
      $448 = $447;
      $449 = HEAP32[$448>>2]|0;
      $450 = $$0;
      $451 = $450;
      HEAP32[$451>>2] = $446;
      $452 = (($450) + 4)|0;
      $453 = $452;
      HEAP32[$453>>2] = $449;
      $454 = $356;
      $455 = $454;
      HEAP32[$455>>2] = $440;
      $456 = (($454) + 4)|0;
      $457 = $456;
      HEAP32[$457>>2] = $443;
      $458 = (($358) + 4)|0;
      $$pre$phiZ2D = $384;$__n_swaps$0 = $458;
      break;
     } else {
      $437 = (($358) + 3)|0;
      $$pre$phiZ2D = $384;$__n_swaps$0 = $437;
      break;
     }
    } else {
     $459 = ((($$0) + ($353<<3)|0) + 4|0);
     $460 = Math_fround(HEAPF32[$459>>2]);
     $461 = (($$0) + 4|0);
     $462 = Math_fround(HEAPF32[$461>>2]);
     $463 = $460 > $462;
     $464 = Math_fround(HEAPF32[$2>>2]);
     $465 = $464 > $460;
     if (!($463)) {
      if (!($465)) {
       $$pre$phiZ2D = $459;$__n_swaps$0 = 0;
       break;
      }
      $466 = $354;
      $467 = $466;
      $468 = HEAP32[$467>>2]|0;
      $469 = (($466) + 4)|0;
      $470 = $469;
      $471 = HEAP32[$470>>2]|0;
      $472 = $1;
      $473 = $472;
      $474 = HEAP32[$473>>2]|0;
      $475 = (($472) + 4)|0;
      $476 = $475;
      $477 = HEAP32[$476>>2]|0;
      $478 = $354;
      $479 = $478;
      HEAP32[$479>>2] = $474;
      $480 = (($478) + 4)|0;
      $481 = $480;
      HEAP32[$481>>2] = $477;
      $482 = $1;
      $483 = $482;
      HEAP32[$483>>2] = $468;
      $484 = (($482) + 4)|0;
      $485 = $484;
      HEAP32[$485>>2] = $471;
      $486 = Math_fround(HEAPF32[$459>>2]);
      $487 = Math_fround(HEAPF32[$461>>2]);
      $488 = $486 > $487;
      if (!($488)) {
       $$pre$phiZ2D = $459;$__n_swaps$0 = 1;
       break;
      }
      $489 = $$0;
      $490 = $489;
      $491 = HEAP32[$490>>2]|0;
      $492 = (($489) + 4)|0;
      $493 = $492;
      $494 = HEAP32[$493>>2]|0;
      $495 = $354;
      $496 = $495;
      $497 = HEAP32[$496>>2]|0;
      $498 = (($495) + 4)|0;
      $499 = $498;
      $500 = HEAP32[$499>>2]|0;
      $501 = $$0;
      $502 = $501;
      HEAP32[$502>>2] = $497;
      $503 = (($501) + 4)|0;
      $504 = $503;
      HEAP32[$504>>2] = $500;
      $505 = $354;
      $506 = $505;
      HEAP32[$506>>2] = $491;
      $507 = (($505) + 4)|0;
      $508 = $507;
      HEAP32[$508>>2] = $494;
      $$pre$phiZ2D = $459;$__n_swaps$0 = 2;
      break;
     }
     $509 = $$0;
     $510 = $509;
     $511 = HEAP32[$510>>2]|0;
     $512 = (($509) + 4)|0;
     $513 = $512;
     $514 = HEAP32[$513>>2]|0;
     if ($465) {
      $515 = $1;
      $516 = $515;
      $517 = HEAP32[$516>>2]|0;
      $518 = (($515) + 4)|0;
      $519 = $518;
      $520 = HEAP32[$519>>2]|0;
      $521 = $$0;
      $522 = $521;
      HEAP32[$522>>2] = $517;
      $523 = (($521) + 4)|0;
      $524 = $523;
      HEAP32[$524>>2] = $520;
      $525 = $1;
      $526 = $525;
      HEAP32[$526>>2] = $511;
      $527 = (($525) + 4)|0;
      $528 = $527;
      HEAP32[$528>>2] = $514;
      $$pre$phiZ2D = $459;$__n_swaps$0 = 1;
      break;
     }
     $529 = $354;
     $530 = $529;
     $531 = HEAP32[$530>>2]|0;
     $532 = (($529) + 4)|0;
     $533 = $532;
     $534 = HEAP32[$533>>2]|0;
     $535 = $$0;
     $536 = $535;
     HEAP32[$536>>2] = $531;
     $537 = (($535) + 4)|0;
     $538 = $537;
     HEAP32[$538>>2] = $534;
     $539 = $354;
     $540 = $539;
     HEAP32[$540>>2] = $511;
     $541 = (($539) + 4)|0;
     $542 = $541;
     HEAP32[$542>>2] = $514;
     $543 = Math_fround(HEAPF32[$2>>2]);
     $544 = (HEAP32[tempDoublePtr>>2]=$514,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $545 = $543 > $544;
     if ($545) {
      $546 = $1;
      $547 = $546;
      $548 = HEAP32[$547>>2]|0;
      $549 = (($546) + 4)|0;
      $550 = $549;
      $551 = HEAP32[$550>>2]|0;
      $552 = $354;
      $553 = $552;
      HEAP32[$553>>2] = $548;
      $554 = (($552) + 4)|0;
      $555 = $554;
      HEAP32[$555>>2] = $551;
      $556 = $1;
      $557 = $556;
      HEAP32[$557>>2] = $511;
      $558 = (($556) + 4)|0;
      $559 = $558;
      HEAP32[$559>>2] = $514;
      $$pre$phiZ2D = $459;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $459;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $560 = (($$0) + 4|0);
   $561 = Math_fround(HEAPF32[$560>>2]);
   $562 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
   $563 = $561 > $562;
   do {
    if ($563) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $564 = (($__j$0) + -8|0);
      $565 = ($$0|0)==($564|0);
      if ($565) {
       break;
      }
      $626 = (($__j$0) + -4|0);
      $627 = Math_fround(HEAPF32[$626>>2]);
      $628 = $627 > $562;
      if ($628) {
       label = 68;
       break;
      } else {
       $__j$0 = $564;
      }
     }
     if ((label|0) == 68) {
      label = 0;
      $629 = $$0;
      $630 = $629;
      $631 = HEAP32[$630>>2]|0;
      $632 = (($629) + 4)|0;
      $633 = $632;
      $634 = HEAP32[$633>>2]|0;
      $635 = $564;
      $636 = $635;
      $637 = HEAP32[$636>>2]|0;
      $638 = (($635) + 4)|0;
      $639 = $638;
      $640 = HEAP32[$639>>2]|0;
      $641 = $$0;
      $642 = $641;
      HEAP32[$642>>2] = $637;
      $643 = (($641) + 4)|0;
      $644 = $643;
      HEAP32[$644>>2] = $640;
      $645 = $564;
      $646 = $645;
      HEAP32[$646>>2] = $631;
      $647 = (($645) + 4)|0;
      $648 = $647;
      HEAP32[$648>>2] = $634;
      $649 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $564;$__n_swaps$3 = $649;
      break;
     }
     $566 = (($$0) + 8|0);
     $567 = Math_fround(HEAPF32[$2>>2]);
     $568 = $561 > $567;
     if ($568) {
      $__i$1 = $566;
     } else {
      $569 = ($566|0)==($1|0);
      if ($569) {
       label = 85;
       break L1;
      } else {
       $__i$011 = $566;
      }
      while(1) {
       $572 = (($__i$011) + 4|0);
       $573 = Math_fround(HEAPF32[$572>>2]);
       $574 = $561 > $573;
       $571 = (($__i$011) + 8|0);
       if ($574) {
        break;
       }
       $570 = ($571|0)==($1|0);
       if ($570) {
        label = 85;
        break L1;
       } else {
        $__i$011 = $571;
       }
      }
      $575 = $__i$011;
      $576 = $575;
      $577 = HEAP32[$576>>2]|0;
      $578 = (($575) + 4)|0;
      $579 = $578;
      $580 = HEAP32[$579>>2]|0;
      $581 = $1;
      $582 = $581;
      $583 = HEAP32[$582>>2]|0;
      $584 = (($581) + 4)|0;
      $585 = $584;
      $586 = HEAP32[$585>>2]|0;
      $587 = $__i$011;
      $588 = $587;
      HEAP32[$588>>2] = $583;
      $589 = (($587) + 4)|0;
      $590 = $589;
      HEAP32[$590>>2] = $586;
      $591 = $1;
      $592 = $591;
      HEAP32[$592>>2] = $577;
      $593 = (($591) + 4)|0;
      $594 = $593;
      HEAP32[$594>>2] = $580;
      $__i$1 = $571;
     }
     $595 = ($__i$1|0)==($1|0);
     if ($595) {
      label = 85;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $596 = Math_fround(HEAPF32[$560>>2]);
      $__i$2 = $__i$2$ph;
      while(1) {
       $597 = (($__i$2) + 4|0);
       $598 = Math_fround(HEAPF32[$597>>2]);
       $599 = $596 > $598;
       $600 = (($__i$2) + 8|0);
       if ($599) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $600;
       }
      }
      while(1) {
       $601 = (($__j$2) + -8|0);
       $602 = (($__j$2) + -4|0);
       $603 = Math_fround(HEAPF32[$602>>2]);
       $604 = $596 > $603;
       if ($604) {
        $__j$2 = $601;
       } else {
        break;
       }
      }
      $605 = ($__i$2>>>0)<($601>>>0);
      if (!($605)) {
       $$0 = $__i$2;
       continue L3;
      }
      $606 = $__i$2;
      $607 = $606;
      $608 = HEAP32[$607>>2]|0;
      $609 = (($606) + 4)|0;
      $610 = $609;
      $611 = HEAP32[$610>>2]|0;
      $612 = $601;
      $613 = $612;
      $614 = HEAP32[$613>>2]|0;
      $615 = (($612) + 4)|0;
      $616 = $615;
      $617 = HEAP32[$616>>2]|0;
      $618 = $__i$2;
      $619 = $618;
      HEAP32[$619>>2] = $614;
      $620 = (($618) + 4)|0;
      $621 = $620;
      HEAP32[$621>>2] = $617;
      $622 = $601;
      $623 = $622;
      HEAP32[$623>>2] = $608;
      $624 = (($622) + 4)|0;
      $625 = $624;
      HEAP32[$625>>2] = $611;
      $__i$2$ph = $600;$__j$1$ph = $601;
     }
    }
   } while(0);
   $650 = (($$0) + 8|0);
   $651 = ($650>>>0)<($__j$3>>>0);
   L55: do {
    if ($651) {
     $__i$3$ph = $650;$__j$4$ph = $__j$3;$__m$0$ph = $354;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $652 = (($__m$0$ph) + 4|0);
      $653 = Math_fround(HEAPF32[$652>>2]);
      $__i$3 = $__i$3$ph;
      while(1) {
       $654 = (($__i$3) + 4|0);
       $655 = Math_fround(HEAPF32[$654>>2]);
       $656 = $655 > $653;
       $657 = (($__i$3) + 8|0);
       if ($656) {
        $__i$3 = $657;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $658 = (($__j$5) + -8|0);
       $659 = (($__j$5) + -4|0);
       $660 = Math_fround(HEAPF32[$659>>2]);
       $661 = $660 > $653;
       if ($661) {
        break;
       } else {
        $__j$5 = $658;
       }
      }
      $662 = ($__i$3>>>0)>($658>>>0);
      if ($662) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L55;
      }
      $663 = $__i$3;
      $664 = $663;
      $665 = HEAP32[$664>>2]|0;
      $666 = (($663) + 4)|0;
      $667 = $666;
      $668 = HEAP32[$667>>2]|0;
      $669 = $658;
      $670 = $669;
      $671 = HEAP32[$670>>2]|0;
      $672 = (($669) + 4)|0;
      $673 = $672;
      $674 = HEAP32[$673>>2]|0;
      $675 = $__i$3;
      $676 = $675;
      HEAP32[$676>>2] = $671;
      $677 = (($675) + 4)|0;
      $678 = $677;
      HEAP32[$678>>2] = $674;
      $679 = $658;
      $680 = $679;
      HEAP32[$680>>2] = $665;
      $681 = (($679) + 4)|0;
      $682 = $681;
      HEAP32[$682>>2] = $668;
      $683 = (($__n_swaps$4$ph) + 1)|0;
      $684 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $684 ? $658 : $__m$0$ph;
      $__i$3$ph = $657;$__j$4$ph = $658;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $683;
     }
    } else {
     $__i$4 = $650;$__m$2 = $354;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $685 = ($__i$4|0)==($__m$2|0);
   if ($685) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $686 = (($__m$2) + 4|0);
    $687 = Math_fround(HEAPF32[$686>>2]);
    $688 = (($__i$4) + 4|0);
    $689 = Math_fround(HEAPF32[$688>>2]);
    $690 = $687 > $689;
    if ($690) {
     $691 = $__i$4;
     $692 = $691;
     $693 = HEAP32[$692>>2]|0;
     $694 = (($691) + 4)|0;
     $695 = $694;
     $696 = HEAP32[$695>>2]|0;
     $697 = $__m$2;
     $698 = $697;
     $699 = HEAP32[$698>>2]|0;
     $700 = (($697) + 4)|0;
     $701 = $700;
     $702 = HEAP32[$701>>2]|0;
     $703 = $__i$4;
     $704 = $703;
     HEAP32[$704>>2] = $699;
     $705 = (($703) + 4)|0;
     $706 = $705;
     HEAP32[$706>>2] = $702;
     $707 = $__m$2;
     $708 = $707;
     HEAP32[$708>>2] = $693;
     $709 = (($707) + 4)|0;
     $710 = $709;
     HEAP32[$710>>2] = $696;
     $711 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $711;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $712 = ($__n_swaps$6|0)==(0);
   if ($712) {
    $713 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI11CulledLightS2_EEPS2_EEbT0_S6_T_($$0,$__i$4,0)|0);
    $714 = (($__i$4) + 8|0);
    $715 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI11CulledLightS2_EEPS2_EEbT0_S6_T_($714,$$01$ph,0)|0);
    if ($715) {
     label = 80;
     break;
    }
    if ($713) {
     $$0 = $714;
     continue;
    }
   }
   $716 = $__i$4;
   $717 = (($716) - ($3))|0;
   $718 = (($0) - ($716))|0;
   $719 = ($717|0)<($718|0);
   if (!($719)) {
    label = 84;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessI11CulledLightS2_EEPS2_EEvT0_S6_T_($$0,$__i$4,$__comp);
   $720 = (($__i$4) + 8|0);
   $$0 = $720;
  }
  if ((label|0) == 80) {
   label = 0;
   if ($713) {
    label = 85;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 84) {
   label = 0;
   $721 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRNS_6__lessI11CulledLightS2_EEPS2_EEvT0_S6_T_($721,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $6 = Math_fround(HEAPF32[$2>>2]);
  $7 = (($$0) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = $6 > $8;
  if (!($9)) {
   STACKTOP = sp;return;
  }
  $10 = $$0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + 4)|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = $1;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) + 4)|0;
  $20 = $19;
  $21 = HEAP32[$20>>2]|0;
  $22 = $$0;
  $23 = $22;
  HEAP32[$23>>2] = $18;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $21;
  $26 = $1;
  $27 = $26;
  HEAP32[$27>>2] = $12;
  $28 = (($26) + 4)|0;
  $29 = $28;
  HEAP32[$29>>2] = $15;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $30 = (($$0) + 8|0);
  $31 = (($$0) + 12|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($$0) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = $32 > $34;
  $36 = Math_fround(HEAPF32[$2>>2]);
  $37 = $36 > $32;
  if (!($35)) {
   if (!($37)) {
    STACKTOP = sp;return;
   }
   $38 = $30;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = (($38) + 4)|0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = $1;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 4)|0;
   $48 = $47;
   $49 = HEAP32[$48>>2]|0;
   $50 = $30;
   $51 = $50;
   HEAP32[$51>>2] = $46;
   $52 = (($50) + 4)|0;
   $53 = $52;
   HEAP32[$53>>2] = $49;
   $54 = $1;
   $55 = $54;
   HEAP32[$55>>2] = $40;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $43;
   $58 = Math_fround(HEAPF32[$31>>2]);
   $59 = Math_fround(HEAPF32[$33>>2]);
   $60 = $58 > $59;
   if (!($60)) {
    STACKTOP = sp;return;
   }
   $61 = $$0;
   $62 = $61;
   $63 = HEAP32[$62>>2]|0;
   $64 = (($61) + 4)|0;
   $65 = $64;
   $66 = HEAP32[$65>>2]|0;
   $67 = $30;
   $68 = $67;
   $69 = HEAP32[$68>>2]|0;
   $70 = (($67) + 4)|0;
   $71 = $70;
   $72 = HEAP32[$71>>2]|0;
   $73 = $$0;
   $74 = $73;
   HEAP32[$74>>2] = $69;
   $75 = (($73) + 4)|0;
   $76 = $75;
   HEAP32[$76>>2] = $72;
   $77 = $30;
   $78 = $77;
   HEAP32[$78>>2] = $63;
   $79 = (($77) + 4)|0;
   $80 = $79;
   HEAP32[$80>>2] = $66;
   STACKTOP = sp;return;
  }
  $81 = $$0;
  $82 = $81;
  $83 = HEAP32[$82>>2]|0;
  $84 = (($81) + 4)|0;
  $85 = $84;
  $86 = HEAP32[$85>>2]|0;
  if ($37) {
   $87 = $1;
   $88 = $87;
   $89 = HEAP32[$88>>2]|0;
   $90 = (($87) + 4)|0;
   $91 = $90;
   $92 = HEAP32[$91>>2]|0;
   $93 = $$0;
   $94 = $93;
   HEAP32[$94>>2] = $89;
   $95 = (($93) + 4)|0;
   $96 = $95;
   HEAP32[$96>>2] = $92;
   $97 = $1;
   $98 = $97;
   HEAP32[$98>>2] = $83;
   $99 = (($97) + 4)|0;
   $100 = $99;
   HEAP32[$100>>2] = $86;
   STACKTOP = sp;return;
  }
  $101 = $30;
  $102 = $101;
  $103 = HEAP32[$102>>2]|0;
  $104 = (($101) + 4)|0;
  $105 = $104;
  $106 = HEAP32[$105>>2]|0;
  $107 = $$0;
  $108 = $107;
  HEAP32[$108>>2] = $103;
  $109 = (($107) + 4)|0;
  $110 = $109;
  HEAP32[$110>>2] = $106;
  $111 = $30;
  $112 = $111;
  HEAP32[$112>>2] = $83;
  $113 = (($111) + 4)|0;
  $114 = $113;
  HEAP32[$114>>2] = $86;
  $115 = Math_fround(HEAPF32[$2>>2]);
  $116 = (HEAP32[tempDoublePtr>>2]=$86,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $117 = $115 > $116;
  if (!($117)) {
   STACKTOP = sp;return;
  }
  $118 = $1;
  $119 = $118;
  $120 = HEAP32[$119>>2]|0;
  $121 = (($118) + 4)|0;
  $122 = $121;
  $123 = HEAP32[$122>>2]|0;
  $124 = $30;
  $125 = $124;
  HEAP32[$125>>2] = $120;
  $126 = (($124) + 4)|0;
  $127 = $126;
  HEAP32[$127>>2] = $123;
  $128 = $1;
  $129 = $128;
  HEAP32[$129>>2] = $83;
  $130 = (($128) + 4)|0;
  $131 = $130;
  HEAP32[$131>>2] = $86;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $132 = (($$0) + 8|0);
  $133 = (($$0) + 16|0);
  (__ZNSt3__17__sort4IRNS_6__lessI11CulledLightS2_EEPS2_EEjT0_S6_S6_S6_T_($$0,$132,$133,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $134 = (($$0) + 8|0);
  $135 = (($$0) + 16|0);
  $136 = (($$0) + 24|0);
  (__ZNSt3__17__sort4IRNS_6__lessI11CulledLightS2_EEPS2_EEjT0_S6_S6_S6_T_($$0,$134,$135,$136,0)|0);
  $137 = Math_fround(HEAPF32[$2>>2]);
  $138 = (($$0) + 28|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = $137 > $139;
  if (!($140)) {
   STACKTOP = sp;return;
  }
  $141 = $136;
  $142 = $141;
  $143 = HEAP32[$142>>2]|0;
  $144 = (($141) + 4)|0;
  $145 = $144;
  $146 = HEAP32[$145>>2]|0;
  $147 = $1;
  $148 = $147;
  $149 = HEAP32[$148>>2]|0;
  $150 = (($147) + 4)|0;
  $151 = $150;
  $152 = HEAP32[$151>>2]|0;
  $153 = $136;
  $154 = $153;
  HEAP32[$154>>2] = $149;
  $155 = (($153) + 4)|0;
  $156 = $155;
  HEAP32[$156>>2] = $152;
  $157 = $1;
  $158 = $157;
  HEAP32[$158>>2] = $143;
  $159 = (($157) + 4)|0;
  $160 = $159;
  HEAP32[$160>>2] = $146;
  $161 = Math_fround(HEAPF32[$138>>2]);
  $162 = (($$0) + 20|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = $161 > $163;
  if (!($164)) {
   STACKTOP = sp;return;
  }
  $165 = $135;
  $166 = $165;
  $167 = HEAP32[$166>>2]|0;
  $168 = (($165) + 4)|0;
  $169 = $168;
  $170 = HEAP32[$169>>2]|0;
  $171 = $136;
  $172 = $171;
  $173 = HEAP32[$172>>2]|0;
  $174 = (($171) + 4)|0;
  $175 = $174;
  $176 = HEAP32[$175>>2]|0;
  $177 = $135;
  $178 = $177;
  HEAP32[$178>>2] = $173;
  $179 = (($177) + 4)|0;
  $180 = $179;
  HEAP32[$180>>2] = $176;
  $181 = $136;
  $182 = $181;
  HEAP32[$182>>2] = $167;
  $183 = (($181) + 4)|0;
  $184 = $183;
  HEAP32[$184>>2] = $170;
  $185 = (HEAP32[tempDoublePtr>>2]=$176,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $186 = (($$0) + 12|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = $185 > $187;
  if (!($188)) {
   STACKTOP = sp;return;
  }
  $189 = $134;
  $190 = $189;
  $191 = HEAP32[$190>>2]|0;
  $192 = (($189) + 4)|0;
  $193 = $192;
  $194 = HEAP32[$193>>2]|0;
  $195 = $134;
  $196 = $195;
  HEAP32[$196>>2] = $173;
  $197 = (($195) + 4)|0;
  $198 = $197;
  HEAP32[$198>>2] = $176;
  $199 = $135;
  $200 = $199;
  HEAP32[$200>>2] = $191;
  $201 = (($199) + 4)|0;
  $202 = $201;
  HEAP32[$202>>2] = $194;
  $203 = (($$0) + 4|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = $185 > $204;
  if (!($205)) {
   STACKTOP = sp;return;
  }
  $206 = $$0;
  $207 = $206;
  $208 = HEAP32[$207>>2]|0;
  $209 = (($206) + 4)|0;
  $210 = $209;
  $211 = HEAP32[$210>>2]|0;
  $212 = $$0;
  $213 = $212;
  HEAP32[$213>>2] = $173;
  $214 = (($212) + 4)|0;
  $215 = $214;
  HEAP32[$215>>2] = $176;
  $216 = $134;
  $217 = $216;
  HEAP32[$217>>2] = $208;
  $218 = (($216) + 4)|0;
  $219 = $218;
  HEAP32[$219>>2] = $211;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $221 = (($$0) + 16|0);
  $222 = (($$0) + 8|0);
  $223 = (($$0) + 12|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = (($$0) + 4|0);
  $226 = Math_fround(HEAPF32[$225>>2]);
  $227 = $224 > $226;
  $228 = (($$0) + 20|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = $229 > $224;
  do {
   if ($227) {
    $267 = $$0;
    $268 = $267;
    $269 = HEAP32[$268>>2]|0;
    $270 = (($267) + 4)|0;
    $271 = $270;
    $272 = HEAP32[$271>>2]|0;
    if ($230) {
     $273 = $221;
     $274 = $273;
     $275 = HEAP32[$274>>2]|0;
     $276 = (($273) + 4)|0;
     $277 = $276;
     $278 = HEAP32[$277>>2]|0;
     $279 = $$0;
     $280 = $279;
     HEAP32[$280>>2] = $275;
     $281 = (($279) + 4)|0;
     $282 = $281;
     HEAP32[$282>>2] = $278;
     $283 = $221;
     $284 = $283;
     HEAP32[$284>>2] = $269;
     $285 = (($283) + 4)|0;
     $286 = $285;
     HEAP32[$286>>2] = $272;
     break;
    }
    $287 = $222;
    $288 = $287;
    $289 = HEAP32[$288>>2]|0;
    $290 = (($287) + 4)|0;
    $291 = $290;
    $292 = HEAP32[$291>>2]|0;
    $293 = $$0;
    $294 = $293;
    HEAP32[$294>>2] = $289;
    $295 = (($293) + 4)|0;
    $296 = $295;
    HEAP32[$296>>2] = $292;
    $297 = $222;
    $298 = $297;
    HEAP32[$298>>2] = $269;
    $299 = (($297) + 4)|0;
    $300 = $299;
    HEAP32[$300>>2] = $272;
    $301 = (HEAP32[tempDoublePtr>>2]=$272,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $302 = $229 > $301;
    if ($302) {
     $303 = $221;
     $304 = $303;
     $305 = HEAP32[$304>>2]|0;
     $306 = (($303) + 4)|0;
     $307 = $306;
     $308 = HEAP32[$307>>2]|0;
     $309 = $222;
     $310 = $309;
     HEAP32[$310>>2] = $305;
     $311 = (($309) + 4)|0;
     $312 = $311;
     HEAP32[$312>>2] = $308;
     $313 = $221;
     $314 = $313;
     HEAP32[$314>>2] = $269;
     $315 = (($313) + 4)|0;
     $316 = $315;
     HEAP32[$316>>2] = $272;
    }
   } else {
    if ($230) {
     $231 = $222;
     $232 = $231;
     $233 = HEAP32[$232>>2]|0;
     $234 = (($231) + 4)|0;
     $235 = $234;
     $236 = HEAP32[$235>>2]|0;
     $237 = $221;
     $238 = $237;
     $239 = HEAP32[$238>>2]|0;
     $240 = (($237) + 4)|0;
     $241 = $240;
     $242 = HEAP32[$241>>2]|0;
     $243 = $222;
     $244 = $243;
     HEAP32[$244>>2] = $239;
     $245 = (($243) + 4)|0;
     $246 = $245;
     HEAP32[$246>>2] = $242;
     $247 = $221;
     $248 = $247;
     HEAP32[$248>>2] = $233;
     $249 = (($247) + 4)|0;
     $250 = $249;
     HEAP32[$250>>2] = $236;
     $251 = (HEAP32[tempDoublePtr>>2]=$242,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $252 = $251 > $226;
     if ($252) {
      $253 = $$0;
      $254 = $253;
      $255 = HEAP32[$254>>2]|0;
      $256 = (($253) + 4)|0;
      $257 = $256;
      $258 = HEAP32[$257>>2]|0;
      $259 = $$0;
      $260 = $259;
      HEAP32[$260>>2] = $239;
      $261 = (($259) + 4)|0;
      $262 = $261;
      HEAP32[$262>>2] = $242;
      $263 = $222;
      $264 = $263;
      HEAP32[$264>>2] = $255;
      $265 = (($263) + 4)|0;
      $266 = $265;
      HEAP32[$266>>2] = $258;
     }
    }
   }
  } while(0);
  $317 = (($$0) + 24|0);
  $318 = ($317|0)==($$01$ph|0);
  if ($318) {
   STACKTOP = sp;return;
  } else {
   $__i$02$i = $317;$__j$01$i = $221;
  }
  while(1) {
   $319 = (($__i$02$i) + 4|0);
   $320 = Math_fround(HEAPF32[$319>>2]);
   $321 = (($__j$01$i) + 4|0);
   $322 = Math_fround(HEAPF32[$321>>2]);
   $323 = $320 > $322;
   if ($323) {
    $324 = $__i$02$i;
    $325 = $324;
    $326 = HEAP32[$325>>2]|0;
    $327 = (($324) + 4)|0;
    $328 = $327;
    $329 = HEAP32[$328>>2]|0;
    $330 = (HEAP32[tempDoublePtr>>2]=$329,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     $331 = $__k$0$i;
     $332 = $331;
     $333 = HEAP32[$332>>2]|0;
     $334 = (($331) + 4)|0;
     $335 = $334;
     $336 = HEAP32[$335>>2]|0;
     $337 = $__j$1$i;
     $338 = $337;
     HEAP32[$338>>2] = $333;
     $339 = (($337) + 4)|0;
     $340 = $339;
     HEAP32[$340>>2] = $336;
     $341 = ($__k$0$i|0)==($$0|0);
     if ($341) {
      break;
     }
     $342 = (($__k$0$i) + -8|0);
     $343 = (($__k$0$i) + -4|0);
     $344 = Math_fround(HEAPF32[$343>>2]);
     $345 = $330 > $344;
     if ($345) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $342;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $346 = $__k$0$i;
    $347 = $346;
    HEAP32[$347>>2] = $326;
    $348 = (($346) + 4)|0;
    $349 = $348;
    HEAP32[$349>>2] = $329;
   }
   $350 = (($__i$02$i) + 8|0);
   $351 = ($350|0)==($$01$ph|0);
   if ($351) {
    break;
   } else {
    $__j$01$i$phi = $__i$02$i;$__i$02$i = $350;$__j$01$i = $__j$01$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 85) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRNS_6__lessI11CulledLightS2_EEPS2_EEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $$pre = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__x2) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($__x1) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $1 > $3;
 $5 = (($__x3) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $6 > $1;
 do {
  if ($4) {
   $52 = $__x1;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   if ($7) {
    $58 = $__x3;
    $59 = $58;
    $60 = HEAP32[$59>>2]|0;
    $61 = (($58) + 4)|0;
    $62 = $61;
    $63 = HEAP32[$62>>2]|0;
    $64 = $__x1;
    $65 = $64;
    HEAP32[$65>>2] = $60;
    $66 = (($64) + 4)|0;
    $67 = $66;
    HEAP32[$67>>2] = $63;
    $68 = $__x3;
    $69 = $68;
    HEAP32[$69>>2] = $54;
    $70 = (($68) + 4)|0;
    $71 = $70;
    HEAP32[$71>>2] = $57;
    $72 = (HEAP32[tempDoublePtr>>2]=$57,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $$0$i = 1;$107 = $72;
    break;
   }
   $73 = $__x2;
   $74 = $73;
   $75 = HEAP32[$74>>2]|0;
   $76 = (($73) + 4)|0;
   $77 = $76;
   $78 = HEAP32[$77>>2]|0;
   $79 = $__x1;
   $80 = $79;
   HEAP32[$80>>2] = $75;
   $81 = (($79) + 4)|0;
   $82 = $81;
   HEAP32[$82>>2] = $78;
   $83 = $__x2;
   $84 = $83;
   HEAP32[$84>>2] = $54;
   $85 = (($83) + 4)|0;
   $86 = $85;
   HEAP32[$86>>2] = $57;
   $87 = Math_fround(HEAPF32[$5>>2]);
   $88 = (HEAP32[tempDoublePtr>>2]=$57,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $89 = $87 > $88;
   if ($89) {
    $90 = $__x3;
    $91 = $90;
    $92 = HEAP32[$91>>2]|0;
    $93 = (($90) + 4)|0;
    $94 = $93;
    $95 = HEAP32[$94>>2]|0;
    $96 = $__x2;
    $97 = $96;
    HEAP32[$97>>2] = $92;
    $98 = (($96) + 4)|0;
    $99 = $98;
    HEAP32[$99>>2] = $95;
    $100 = $__x3;
    $101 = $100;
    HEAP32[$101>>2] = $54;
    $102 = (($100) + 4)|0;
    $103 = $102;
    HEAP32[$103>>2] = $57;
    $$0$i = 2;$107 = $88;
   } else {
    $$0$i = 1;$107 = $87;
   }
  } else {
   if ($7) {
    $8 = $__x2;
    $9 = $8;
    $10 = HEAP32[$9>>2]|0;
    $11 = (($8) + 4)|0;
    $12 = $11;
    $13 = HEAP32[$12>>2]|0;
    $14 = $__x3;
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + 4)|0;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = $__x2;
    $21 = $20;
    HEAP32[$21>>2] = $16;
    $22 = (($20) + 4)|0;
    $23 = $22;
    HEAP32[$23>>2] = $19;
    $24 = $__x3;
    $25 = $24;
    HEAP32[$25>>2] = $10;
    $26 = (($24) + 4)|0;
    $27 = $26;
    HEAP32[$27>>2] = $13;
    $28 = Math_fround(HEAPF32[$0>>2]);
    $29 = Math_fround(HEAPF32[$2>>2]);
    $30 = $28 > $29;
    $31 = (HEAP32[tempDoublePtr>>2]=$13,Math_fround(HEAPF32[tempDoublePtr>>2]));
    if ($30) {
     $32 = $__x1;
     $33 = $32;
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + 4)|0;
     $36 = $35;
     $37 = HEAP32[$36>>2]|0;
     $38 = $__x2;
     $39 = $38;
     $40 = HEAP32[$39>>2]|0;
     $41 = (($38) + 4)|0;
     $42 = $41;
     $43 = HEAP32[$42>>2]|0;
     $44 = $__x1;
     $45 = $44;
     HEAP32[$45>>2] = $40;
     $46 = (($44) + 4)|0;
     $47 = $46;
     HEAP32[$47>>2] = $43;
     $48 = $__x2;
     $49 = $48;
     HEAP32[$49>>2] = $34;
     $50 = (($48) + 4)|0;
     $51 = $50;
     HEAP32[$51>>2] = $37;
     $$pre = Math_fround(HEAPF32[$5>>2]);
     $$0$i = 2;$107 = $$pre;
    } else {
     $$0$i = 1;$107 = $31;
    }
   } else {
    $$0$i = 0;$107 = $6;
   }
  }
 } while(0);
 $104 = (($__x4) + 4|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = $105 > $107;
 if (!($106)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $108 = $__x3;
 $109 = $108;
 $110 = HEAP32[$109>>2]|0;
 $111 = (($108) + 4)|0;
 $112 = $111;
 $113 = HEAP32[$112>>2]|0;
 $114 = $__x4;
 $115 = $114;
 $116 = HEAP32[$115>>2]|0;
 $117 = (($114) + 4)|0;
 $118 = $117;
 $119 = HEAP32[$118>>2]|0;
 $120 = $__x3;
 $121 = $120;
 HEAP32[$121>>2] = $116;
 $122 = (($120) + 4)|0;
 $123 = $122;
 HEAP32[$123>>2] = $119;
 $124 = $__x4;
 $125 = $124;
 HEAP32[$125>>2] = $110;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $113;
 $128 = (($$0$i) + 1)|0;
 $129 = Math_fround(HEAPF32[$5>>2]);
 $130 = Math_fround(HEAPF32[$0>>2]);
 $131 = $129 > $130;
 if (!($131)) {
  $__r$0 = $128;
  STACKTOP = sp;return ($__r$0|0);
 }
 $132 = $__x2;
 $133 = $132;
 $134 = HEAP32[$133>>2]|0;
 $135 = (($132) + 4)|0;
 $136 = $135;
 $137 = HEAP32[$136>>2]|0;
 $138 = $__x3;
 $139 = $138;
 $140 = HEAP32[$139>>2]|0;
 $141 = (($138) + 4)|0;
 $142 = $141;
 $143 = HEAP32[$142>>2]|0;
 $144 = $__x2;
 $145 = $144;
 HEAP32[$145>>2] = $140;
 $146 = (($144) + 4)|0;
 $147 = $146;
 HEAP32[$147>>2] = $143;
 $148 = $__x3;
 $149 = $148;
 HEAP32[$149>>2] = $134;
 $150 = (($148) + 4)|0;
 $151 = $150;
 HEAP32[$151>>2] = $137;
 $152 = (($$0$i) + 2)|0;
 $153 = Math_fround(HEAPF32[$0>>2]);
 $154 = Math_fround(HEAPF32[$2>>2]);
 $155 = $153 > $154;
 if (!($155)) {
  $__r$0 = $152;
  STACKTOP = sp;return ($__r$0|0);
 }
 $156 = $__x1;
 $157 = $156;
 $158 = HEAP32[$157>>2]|0;
 $159 = (($156) + 4)|0;
 $160 = $159;
 $161 = HEAP32[$160>>2]|0;
 $162 = $__x2;
 $163 = $162;
 $164 = HEAP32[$163>>2]|0;
 $165 = (($162) + 4)|0;
 $166 = $165;
 $167 = HEAP32[$166>>2]|0;
 $168 = $__x1;
 $169 = $168;
 HEAP32[$169>>2] = $164;
 $170 = (($168) + 4)|0;
 $171 = $170;
 HEAP32[$171>>2] = $167;
 $172 = $__x2;
 $173 = $172;
 HEAP32[$173>>2] = $158;
 $174 = (($172) + 4)|0;
 $175 = $174;
 HEAP32[$175>>2] = $161;
 $176 = (($$0$i) + 3)|0;
 $__r$0 = $176;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI11CulledLightS2_EEPS2_EEbT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = 0;
 var $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__count$05 = 0, $__count$1 = 0, $__i$06 = 0, $__j$04 = 0, $__j$04$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -4|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($__first) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = $5 > $7;
  if (!($8)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $9 = (($__last) + -8|0);
  $10 = $__first;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + 4)|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = $9;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) + 4)|0;
  $20 = $19;
  $21 = HEAP32[$20>>2]|0;
  $22 = $__first;
  $23 = $22;
  HEAP32[$23>>2] = $18;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $21;
  $26 = $9;
  $27 = $26;
  HEAP32[$27>>2] = $12;
  $28 = (($26) + 4)|0;
  $29 = $28;
  HEAP32[$29>>2] = $15;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $137 = (($__first) + 8|0);
  $138 = (($__first) + 16|0);
  $139 = (($__first) + 24|0);
  (__ZNSt3__17__sort4IRNS_6__lessI11CulledLightS2_EEPS2_EEjT0_S6_S6_S6_T_($__first,$137,$138,$139,0)|0);
  $140 = (($__last) + -4|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = (($__first) + 28|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = $141 > $143;
  if (!($144)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $145 = (($__last) + -8|0);
  $146 = $139;
  $147 = $146;
  $148 = HEAP32[$147>>2]|0;
  $149 = (($146) + 4)|0;
  $150 = $149;
  $151 = HEAP32[$150>>2]|0;
  $152 = $145;
  $153 = $152;
  $154 = HEAP32[$153>>2]|0;
  $155 = (($152) + 4)|0;
  $156 = $155;
  $157 = HEAP32[$156>>2]|0;
  $158 = $139;
  $159 = $158;
  HEAP32[$159>>2] = $154;
  $160 = (($158) + 4)|0;
  $161 = $160;
  HEAP32[$161>>2] = $157;
  $162 = $145;
  $163 = $162;
  HEAP32[$163>>2] = $148;
  $164 = (($162) + 4)|0;
  $165 = $164;
  HEAP32[$165>>2] = $151;
  $166 = Math_fround(HEAPF32[$142>>2]);
  $167 = (($__first) + 20|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = $166 > $168;
  if (!($169)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $170 = $138;
  $171 = $170;
  $172 = HEAP32[$171>>2]|0;
  $173 = (($170) + 4)|0;
  $174 = $173;
  $175 = HEAP32[$174>>2]|0;
  $176 = $139;
  $177 = $176;
  $178 = HEAP32[$177>>2]|0;
  $179 = (($176) + 4)|0;
  $180 = $179;
  $181 = HEAP32[$180>>2]|0;
  $182 = $138;
  $183 = $182;
  HEAP32[$183>>2] = $178;
  $184 = (($182) + 4)|0;
  $185 = $184;
  HEAP32[$185>>2] = $181;
  $186 = $139;
  $187 = $186;
  HEAP32[$187>>2] = $172;
  $188 = (($186) + 4)|0;
  $189 = $188;
  HEAP32[$189>>2] = $175;
  $190 = (HEAP32[tempDoublePtr>>2]=$181,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $191 = (($__first) + 12|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = $190 > $192;
  if (!($193)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $194 = $137;
  $195 = $194;
  $196 = HEAP32[$195>>2]|0;
  $197 = (($194) + 4)|0;
  $198 = $197;
  $199 = HEAP32[$198>>2]|0;
  $200 = $137;
  $201 = $200;
  HEAP32[$201>>2] = $178;
  $202 = (($200) + 4)|0;
  $203 = $202;
  HEAP32[$203>>2] = $181;
  $204 = $138;
  $205 = $204;
  HEAP32[$205>>2] = $196;
  $206 = (($204) + 4)|0;
  $207 = $206;
  HEAP32[$207>>2] = $199;
  $208 = (($__first) + 4|0);
  $209 = Math_fround(HEAPF32[$208>>2]);
  $210 = $190 > $209;
  if (!($210)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $211 = $__first;
  $212 = $211;
  $213 = HEAP32[$212>>2]|0;
  $214 = (($211) + 4)|0;
  $215 = $214;
  $216 = HEAP32[$215>>2]|0;
  $217 = $__first;
  $218 = $217;
  HEAP32[$218>>2] = $178;
  $219 = (($217) + 4)|0;
  $220 = $219;
  HEAP32[$220>>2] = $181;
  $221 = $137;
  $222 = $221;
  HEAP32[$222>>2] = $213;
  $223 = (($221) + 4)|0;
  $224 = $223;
  HEAP32[$224>>2] = $216;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $30 = (($__first) + 8|0);
  $31 = (($__last) + -8|0);
  $32 = (($__first) + 12|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($__first) + 4|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = $33 > $35;
  $37 = (($__last) + -4|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = $38 > $33;
  if (!($36)) {
   if (!($39)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $40 = $30;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $31;
   $47 = $46;
   $48 = HEAP32[$47>>2]|0;
   $49 = (($46) + 4)|0;
   $50 = $49;
   $51 = HEAP32[$50>>2]|0;
   $52 = $30;
   $53 = $52;
   HEAP32[$53>>2] = $48;
   $54 = (($52) + 4)|0;
   $55 = $54;
   HEAP32[$55>>2] = $51;
   $56 = $31;
   $57 = $56;
   HEAP32[$57>>2] = $42;
   $58 = (($56) + 4)|0;
   $59 = $58;
   HEAP32[$59>>2] = $45;
   $60 = Math_fround(HEAPF32[$32>>2]);
   $61 = Math_fround(HEAPF32[$34>>2]);
   $62 = $60 > $61;
   if (!($62)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $63 = $__first;
   $64 = $63;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($63) + 4)|0;
   $67 = $66;
   $68 = HEAP32[$67>>2]|0;
   $69 = $30;
   $70 = $69;
   $71 = HEAP32[$70>>2]|0;
   $72 = (($69) + 4)|0;
   $73 = $72;
   $74 = HEAP32[$73>>2]|0;
   $75 = $__first;
   $76 = $75;
   HEAP32[$76>>2] = $71;
   $77 = (($75) + 4)|0;
   $78 = $77;
   HEAP32[$78>>2] = $74;
   $79 = $30;
   $80 = $79;
   HEAP32[$80>>2] = $65;
   $81 = (($79) + 4)|0;
   $82 = $81;
   HEAP32[$82>>2] = $68;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $83 = $__first;
  $84 = $83;
  $85 = HEAP32[$84>>2]|0;
  $86 = (($83) + 4)|0;
  $87 = $86;
  $88 = HEAP32[$87>>2]|0;
  if ($39) {
   $89 = $31;
   $90 = $89;
   $91 = HEAP32[$90>>2]|0;
   $92 = (($89) + 4)|0;
   $93 = $92;
   $94 = HEAP32[$93>>2]|0;
   $95 = $__first;
   $96 = $95;
   HEAP32[$96>>2] = $91;
   $97 = (($95) + 4)|0;
   $98 = $97;
   HEAP32[$98>>2] = $94;
   $99 = $31;
   $100 = $99;
   HEAP32[$100>>2] = $85;
   $101 = (($99) + 4)|0;
   $102 = $101;
   HEAP32[$102>>2] = $88;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $103 = $30;
  $104 = $103;
  $105 = HEAP32[$104>>2]|0;
  $106 = (($103) + 4)|0;
  $107 = $106;
  $108 = HEAP32[$107>>2]|0;
  $109 = $__first;
  $110 = $109;
  HEAP32[$110>>2] = $105;
  $111 = (($109) + 4)|0;
  $112 = $111;
  HEAP32[$112>>2] = $108;
  $113 = $30;
  $114 = $113;
  HEAP32[$114>>2] = $85;
  $115 = (($113) + 4)|0;
  $116 = $115;
  HEAP32[$116>>2] = $88;
  $117 = Math_fround(HEAPF32[$37>>2]);
  $118 = (HEAP32[tempDoublePtr>>2]=$88,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $119 = $117 > $118;
  if (!($119)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $120 = $31;
  $121 = $120;
  $122 = HEAP32[$121>>2]|0;
  $123 = (($120) + 4)|0;
  $124 = $123;
  $125 = HEAP32[$124>>2]|0;
  $126 = $30;
  $127 = $126;
  HEAP32[$127>>2] = $122;
  $128 = (($126) + 4)|0;
  $129 = $128;
  HEAP32[$129>>2] = $125;
  $130 = $31;
  $131 = $130;
  HEAP32[$131>>2] = $85;
  $132 = (($130) + 4)|0;
  $133 = $132;
  HEAP32[$133>>2] = $88;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $134 = (($__first) + 8|0);
  $135 = (($__first) + 16|0);
  $136 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRNS_6__lessI11CulledLightS2_EEPS2_EEjT0_S6_S6_S6_T_($__first,$134,$135,$136,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $225 = (($__first) + 16|0);
  $226 = (($__first) + 8|0);
  $227 = (($__first) + 12|0);
  $228 = Math_fround(HEAPF32[$227>>2]);
  $229 = (($__first) + 4|0);
  $230 = Math_fround(HEAPF32[$229>>2]);
  $231 = $228 > $230;
  $232 = (($__first) + 20|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = $233 > $228;
  do {
   if ($231) {
    $271 = $__first;
    $272 = $271;
    $273 = HEAP32[$272>>2]|0;
    $274 = (($271) + 4)|0;
    $275 = $274;
    $276 = HEAP32[$275>>2]|0;
    if ($234) {
     $277 = $225;
     $278 = $277;
     $279 = HEAP32[$278>>2]|0;
     $280 = (($277) + 4)|0;
     $281 = $280;
     $282 = HEAP32[$281>>2]|0;
     $283 = $__first;
     $284 = $283;
     HEAP32[$284>>2] = $279;
     $285 = (($283) + 4)|0;
     $286 = $285;
     HEAP32[$286>>2] = $282;
     $287 = $225;
     $288 = $287;
     HEAP32[$288>>2] = $273;
     $289 = (($287) + 4)|0;
     $290 = $289;
     HEAP32[$290>>2] = $276;
     break;
    }
    $291 = $226;
    $292 = $291;
    $293 = HEAP32[$292>>2]|0;
    $294 = (($291) + 4)|0;
    $295 = $294;
    $296 = HEAP32[$295>>2]|0;
    $297 = $__first;
    $298 = $297;
    HEAP32[$298>>2] = $293;
    $299 = (($297) + 4)|0;
    $300 = $299;
    HEAP32[$300>>2] = $296;
    $301 = $226;
    $302 = $301;
    HEAP32[$302>>2] = $273;
    $303 = (($301) + 4)|0;
    $304 = $303;
    HEAP32[$304>>2] = $276;
    $305 = (HEAP32[tempDoublePtr>>2]=$276,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $306 = $233 > $305;
    if ($306) {
     $307 = $225;
     $308 = $307;
     $309 = HEAP32[$308>>2]|0;
     $310 = (($307) + 4)|0;
     $311 = $310;
     $312 = HEAP32[$311>>2]|0;
     $313 = $226;
     $314 = $313;
     HEAP32[$314>>2] = $309;
     $315 = (($313) + 4)|0;
     $316 = $315;
     HEAP32[$316>>2] = $312;
     $317 = $225;
     $318 = $317;
     HEAP32[$318>>2] = $273;
     $319 = (($317) + 4)|0;
     $320 = $319;
     HEAP32[$320>>2] = $276;
    }
   } else {
    if ($234) {
     $235 = $226;
     $236 = $235;
     $237 = HEAP32[$236>>2]|0;
     $238 = (($235) + 4)|0;
     $239 = $238;
     $240 = HEAP32[$239>>2]|0;
     $241 = $225;
     $242 = $241;
     $243 = HEAP32[$242>>2]|0;
     $244 = (($241) + 4)|0;
     $245 = $244;
     $246 = HEAP32[$245>>2]|0;
     $247 = $226;
     $248 = $247;
     HEAP32[$248>>2] = $243;
     $249 = (($247) + 4)|0;
     $250 = $249;
     HEAP32[$250>>2] = $246;
     $251 = $225;
     $252 = $251;
     HEAP32[$252>>2] = $237;
     $253 = (($251) + 4)|0;
     $254 = $253;
     HEAP32[$254>>2] = $240;
     $255 = (HEAP32[tempDoublePtr>>2]=$246,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $256 = $255 > $230;
     if ($256) {
      $257 = $__first;
      $258 = $257;
      $259 = HEAP32[$258>>2]|0;
      $260 = (($257) + 4)|0;
      $261 = $260;
      $262 = HEAP32[$261>>2]|0;
      $263 = $__first;
      $264 = $263;
      HEAP32[$264>>2] = $243;
      $265 = (($263) + 4)|0;
      $266 = $265;
      HEAP32[$266>>2] = $246;
      $267 = $226;
      $268 = $267;
      HEAP32[$268>>2] = $259;
      $269 = (($267) + 4)|0;
      $270 = $269;
      HEAP32[$270>>2] = $262;
     }
    }
   }
  } while(0);
  $321 = (($__first) + 24|0);
  $322 = ($321|0)==($__last|0);
  if ($322) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$05 = 0;$__i$06 = $321;$__j$04 = $225;
  }
  while(1) {
   $323 = (($__i$06) + 4|0);
   $324 = Math_fround(HEAPF32[$323>>2]);
   $325 = (($__j$04) + 4|0);
   $326 = Math_fround(HEAPF32[$325>>2]);
   $327 = $324 > $326;
   if ($327) {
    $328 = $__i$06;
    $329 = $328;
    $330 = HEAP32[$329>>2]|0;
    $331 = (($328) + 4)|0;
    $332 = $331;
    $333 = HEAP32[$332>>2]|0;
    $334 = (HEAP32[tempDoublePtr>>2]=$333,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $__j$1 = $__i$06;$__k$0 = $__j$04;
    while(1) {
     $335 = $__k$0;
     $336 = $335;
     $337 = HEAP32[$336>>2]|0;
     $338 = (($335) + 4)|0;
     $339 = $338;
     $340 = HEAP32[$339>>2]|0;
     $341 = $__j$1;
     $342 = $341;
     HEAP32[$342>>2] = $337;
     $343 = (($341) + 4)|0;
     $344 = $343;
     HEAP32[$344>>2] = $340;
     $345 = ($__k$0|0)==($__first|0);
     if ($345) {
      break;
     }
     $346 = (($__k$0) + -8|0);
     $347 = (($__k$0) + -4|0);
     $348 = Math_fround(HEAPF32[$347>>2]);
     $349 = $334 > $348;
     if ($349) {
      $__j$1$phi = $__k$0;$__k$0 = $346;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $350 = $__k$0;
    $351 = $350;
    HEAP32[$351>>2] = $330;
    $352 = (($350) + 4)|0;
    $353 = $352;
    HEAP32[$353>>2] = $333;
    $354 = (($__count$05) + 1)|0;
    $355 = ($354|0)==(8);
    if ($355) {
     break;
    } else {
     $__count$1 = $354;
    }
   } else {
    $__count$1 = $__count$05;
   }
   $358 = (($__i$06) + 8|0);
   $359 = ($358|0)==($__last|0);
   if ($359) {
    $$0 = 1;
    label = 34;
    break;
   } else {
    $__j$04$phi = $__i$06;$__count$05 = $__count$1;$__i$06 = $358;$__j$04 = $__j$04$phi;
   }
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  $356 = (($__i$06) + 8|0);
  $357 = ($356|0)==($__last|0);
  $$0 = $357;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __Z29CullShadowCastersWithoutUmbraR9IndexListRK22SceneCullingParametersPK4AABBjj($visibleObjects,$cullingParams,$aabbs,$beginIndex,$endIndex) {
 $visibleObjects = $visibleObjects|0;
 $cullingParams = $cullingParams|0;
 $aabbs = $aabbs|0;
 $beginIndex = $beginIndex|0;
 $endIndex = $endIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bounds = 0, $exitcond = 0, $i$02 = 0, $visibleIndex$0$lcssa = 0, $visibleIndex$01 = 0, $visibleIndex$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $bounds = sp;
 $0 = ($beginIndex>>>0)<($endIndex>>>0);
 if (!($0)) {
  $visibleIndex$0$lcssa = 0;
  $10 = (($visibleObjects) + 4|0);
  HEAP32[$10>>2] = $visibleIndex$0$lcssa;
  STACKTOP = sp;return;
 }
 $1 = (($cullingParams) + 340|0);
 $2 = (($cullingParams) + 188|0);
 $i$02 = $beginIndex;$visibleIndex$01 = 0;
 while(1) {
  $3 = (($aabbs) + (($i$02*24)|0)|0);
  ;HEAP32[$bounds+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$3+20>>2]|0;
  $4 = HEAP32[$2>>2]|0;
  $5 = (__Z33IntersectAABBPlaneBoundsOptimizedRK4AABBPKN4math7_float4Ei($bounds,$1,$4)|0);
  if ($5) {
   $6 = (($visibleIndex$01) + 1)|0;
   $7 = HEAP32[$visibleObjects>>2]|0;
   $8 = (($7) + ($visibleIndex$01<<2)|0);
   HEAP32[$8>>2] = $i$02;
   $visibleIndex$1 = $6;
  } else {
   $visibleIndex$1 = $visibleIndex$01;
  }
  $9 = (($i$02) + 1)|0;
  $exitcond = ($9|0)==($endIndex|0);
  if ($exitcond) {
   $visibleIndex$0$lcssa = $visibleIndex$1;
   break;
  } else {
   $i$02 = $9;$visibleIndex$01 = $visibleIndex$1;
  }
 }
 $10 = (($visibleObjects) + 4|0);
 HEAP32[$10>>2] = $visibleIndex$0$lcssa;
 STACKTOP = sp;return;
}
function __Z22CullDirectionalShadowsR9IndexListPK9SceneNodePK4AABBR22DirectionalCullContext($visible,$nodes,$boundingBoxes,$context) {
 $visible = $visible|0;
 $nodes = $nodes|0;
 $boundingBoxes = $boundingBoxes|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $visibleCount$0$lcssa = 0, $visibleCount$02 = 0;
 var $visibleCount$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($visible) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $visibleCount$0$lcssa = 0;
  HEAP32[$0>>2] = $visibleCount$0$lcssa;
  STACKTOP = sp;return;
 }
 $i$01 = 0;$visibleCount$02 = 0;
 while(1) {
  $3 = HEAP32[$visible>>2]|0;
  $4 = (($3) + ($i$01<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($nodes) + (($5*24)|0)|0);
  $7 = (($boundingBoxes) + (($5*24)|0)|0);
  $8 = (__ZL17CullCastersCommonRK17ShadowCullContextRK9SceneNodeRK4AABB($context,$6,$7)|0);
  if ($8) {
   $9 = HEAP32[$visible>>2]|0;
   $10 = (($9) + ($i$01<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($visibleCount$02) + 1)|0;
   $13 = (($9) + ($visibleCount$02<<2)|0);
   HEAP32[$13>>2] = $11;
   $visibleCount$1 = $12;
  } else {
   $visibleCount$1 = $visibleCount$02;
  }
  $14 = (($i$01) + 1)|0;
  $15 = HEAP32[$0>>2]|0;
  $16 = ($14|0)<($15|0);
  if ($16) {
   $i$01 = $14;$visibleCount$02 = $visibleCount$1;
  } else {
   $visibleCount$0$lcssa = $visibleCount$1;
   break;
  }
 }
 HEAP32[$0>>2] = $visibleCount$0$lcssa;
 STACKTOP = sp;return;
}
function __Z16CullPointShadowsR9IndexListPK9SceneNodePK4AABBR16PointCullContext($visible,$nodes,$boundingBoxes,$context) {
 $visible = $visible|0;
 $nodes = $nodes|0;
 $boundingBoxes = $boundingBoxes|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var $visibleCount$0$lcssa = 0, $visibleCount$02 = 0, $visibleCount$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($visible) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $visibleCount$0$lcssa = 0;
  HEAP32[$0>>2] = $visibleCount$0$lcssa;
  STACKTOP = sp;return;
 }
 $3 = (($context) + 12|0);
 $i$01 = 0;$visibleCount$02 = 0;
 while(1) {
  $4 = HEAP32[$visible>>2]|0;
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($nodes) + (($6*24)|0)|0);
  $8 = (($boundingBoxes) + (($6*24)|0)|0);
  $9 = (__ZL17CullCastersCommonRK17ShadowCullContextRK9SceneNodeRK4AABB($context,$7,$8)|0);
  if ($9) {
   $10 = (__Z19IntersectAABBSphereRK4AABBRK6Sphere($8,$3)|0);
   if ($10) {
    $11 = HEAP32[$visible>>2]|0;
    $12 = (($11) + ($i$01<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($visibleCount$02) + 1)|0;
    $15 = (($11) + ($visibleCount$02<<2)|0);
    HEAP32[$15>>2] = $13;
    $visibleCount$1 = $14;
   } else {
    $visibleCount$1 = $visibleCount$02;
   }
  } else {
   $visibleCount$1 = $visibleCount$02;
  }
  $16 = (($i$01) + 1)|0;
  $17 = HEAP32[$0>>2]|0;
  $18 = ($16|0)<($17|0);
  if ($18) {
   $i$01 = $16;$visibleCount$02 = $visibleCount$1;
  } else {
   $visibleCount$0$lcssa = $visibleCount$1;
   break;
  }
 }
 HEAP32[$0>>2] = $visibleCount$0$lcssa;
 STACKTOP = sp;return;
}
function __Z15CullSpotShadowsR9IndexListPK9SceneNodePK4AABBR15SpotCullContext($visible,$nodes,$boundingBoxes,$context) {
 $visible = $visible|0;
 $nodes = $nodes|0;
 $boundingBoxes = $boundingBoxes|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $planes$i = 0, $proj$i = 0, $temp$i = 0, $visibleCount$0$lcssa = 0, $visibleCount$02 = 0, $visibleCount$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $planes$i = sp + 128|0;
 $temp$i = sp;
 $proj$i = sp + 64|0;
 $0 = (($visible) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $visibleCount$0$lcssa = 0;
  HEAP32[$0>>2] = $visibleCount$0$lcssa;
  STACKTOP = sp;return;
 }
 $3 = (($context) + 140|0);
 $4 = (($planes$i) + 4|0);
 $5 = (($planes$i) + 8|0);
 $6 = (($planes$i) + 16|0);
 $7 = (($planes$i) + 20|0);
 $8 = (($planes$i) + 24|0);
 $9 = (($planes$i) + 32|0);
 $10 = (($planes$i) + 36|0);
 $11 = (($planes$i) + 40|0);
 $12 = (($planes$i) + 48|0);
 $13 = (($planes$i) + 52|0);
 $14 = (($planes$i) + 56|0);
 $15 = (($planes$i) + 64|0);
 $16 = (($planes$i) + 68|0);
 $17 = (($planes$i) + 72|0);
 $18 = (($planes$i) + 80|0);
 $19 = (($planes$i) + 84|0);
 $20 = (($planes$i) + 88|0);
 $21 = (($context) + 12|0);
 $22 = (($context) + 76|0);
 $i$01 = 0;$visibleCount$02 = 0;
 while(1) {
  $23 = HEAP32[$visible>>2]|0;
  $24 = (($23) + ($i$01<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($nodes) + (($25*24)|0)|0);
  $27 = (($boundingBoxes) + (($25*24)|0)|0);
  $28 = (__ZL17CullCastersCommonRK17ShadowCullContextRK9SceneNodeRK4AABB($context,$26,$27)|0);
  if ($28) {
   $29 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($27,$3)|0);
   if ($29) {
    $30 = HEAP32[$26>>2]|0;
    $31 = (($30) + 48|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = ($32<<24>>24)==(0);
    $34 = (($30) + 49|0);
    if ($33) {
     $35 = HEAP8[$34>>0]|0;
     $36 = ($35<<24>>24)==(0);
     if (!($36)) {
      label = 7;
     }
    } else {
     label = 7;
    }
    if ((label|0) == 7) {
     label = 0;
     $37 = HEAP32[$30>>2]|0;
     $38 = (($37) + 20|0);
     $39 = HEAP32[$38>>2]|0;
     FUNCTION_TABLE_vi[$39 & 4095]($30);
     HEAP8[$31>>0] = 0;
     HEAP8[$34>>0] = 0;
    }
    HEAPF32[$planes$i>>2] = Math_fround(0.0);
    HEAPF32[$4>>2] = Math_fround(0.0);
    HEAPF32[$5>>2] = Math_fround(0.0);
    HEAPF32[$6>>2] = Math_fround(0.0);
    HEAPF32[$7>>2] = Math_fround(0.0);
    HEAPF32[$8>>2] = Math_fround(0.0);
    HEAPF32[$9>>2] = Math_fround(0.0);
    HEAPF32[$10>>2] = Math_fround(0.0);
    HEAPF32[$11>>2] = Math_fround(0.0);
    HEAPF32[$12>>2] = Math_fround(0.0);
    HEAPF32[$13>>2] = Math_fround(0.0);
    HEAPF32[$14>>2] = Math_fround(0.0);
    HEAPF32[$15>>2] = Math_fround(0.0);
    HEAPF32[$16>>2] = Math_fround(0.0);
    HEAPF32[$17>>2] = Math_fround(0.0);
    HEAPF32[$18>>2] = Math_fround(0.0);
    HEAPF32[$19>>2] = Math_fround(0.0);
    HEAPF32[$20>>2] = Math_fround(0.0);
    $40 = (($30) + 52|0);
    __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($21,$40,$temp$i);
    __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($22,$temp$i,$proj$i);
    __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($proj$i,$planes$i);
    $41 = (($30) + 140|0);
    $42 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($41,$planes$i)|0);
    if ($42) {
     $43 = HEAP32[$visible>>2]|0;
     $44 = (($43) + ($i$01<<2)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($visibleCount$02) + 1)|0;
     $47 = (($43) + ($visibleCount$02<<2)|0);
     HEAP32[$47>>2] = $45;
     $visibleCount$1 = $46;
    } else {
     $visibleCount$1 = $visibleCount$02;
    }
   } else {
    $visibleCount$1 = $visibleCount$02;
   }
  } else {
   $visibleCount$1 = $visibleCount$02;
  }
  $48 = (($i$01) + 1)|0;
  $49 = HEAP32[$0>>2]|0;
  $50 = ($48|0)<($49|0);
  if ($50) {
   $i$01 = $48;$visibleCount$02 = $visibleCount$1;
  } else {
   $visibleCount$0$lcssa = $visibleCount$1;
   break;
  }
 }
 HEAP32[$0>>2] = $visibleCount$0$lcssa;
 STACKTOP = sp;return;
}
function __Z23CullObjectsWithoutUmbraRK22SceneCullingParametersPK4AABBR9IndexList($cullingParams,$aabbs,$list) {
 $cullingParams = $cullingParams|0;
 $aabbs = $aabbs|0;
 $list = $list|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $visibleIndex$0$lcssa = 0, $visibleIndex$02 = 0, $visibleIndex$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($list) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $visibleIndex$0$lcssa = 0;
  HEAP32[$0>>2] = $visibleIndex$0$lcssa;
  STACKTOP = sp;return;
 }
 $3 = (($cullingParams) + 340|0);
 $4 = (($cullingParams) + 188|0);
 $i$01 = 0;$visibleIndex$02 = 0;
 while(1) {
  $5 = HEAP32[$list>>2]|0;
  $6 = (($5) + ($i$01<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($aabbs) + (($7*24)|0)|0);
  $9 = HEAP32[$4>>2]|0;
  $10 = (__Z33IntersectAABBPlaneBoundsOptimizedRK4AABBPKN4math7_float4Ei($8,$3,$9)|0);
  if ($10) {
   $11 = (($visibleIndex$02) + 1)|0;
   $12 = HEAP32[$list>>2]|0;
   $13 = (($12) + ($visibleIndex$02<<2)|0);
   HEAP32[$13>>2] = $7;
   $visibleIndex$1 = $11;
  } else {
   $visibleIndex$1 = $visibleIndex$02;
  }
  $14 = (($i$01) + 1)|0;
  $exitcond = ($14|0)==($1|0);
  if ($exitcond) {
   $visibleIndex$0$lcssa = $visibleIndex$1;
   break;
  } else {
   $i$01 = $14;$visibleIndex$02 = $visibleIndex$1;
  }
 }
 HEAP32[$0>>2] = $visibleIndex$0$lcssa;
 STACKTOP = sp;return;
}
function __Z23CullDynamicObjectsUmbraPK4AABBPKN5Umbra15OcclusionBufferER9IndexList($aabbs,$occlusionBuffer,$list) {
 $aabbs = $aabbs|0;
 $occlusionBuffer = $occlusionBuffer|0;
 $list = $list|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z9GetIUmbrav()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($0,$aabbs,$occlusionBuffer,$list);
 STACKTOP = sp;return;
}
function __Z34ProcessIndexListIsNodeVisibleStep1RK22SceneCullingParametersPK9SceneNodejjR9IndexList($params,$nodes,$beginIndex,$endIndex,$list) {
 $params = $params|0;
 $nodes = $nodes|0;
 $beginIndex = $beginIndex|0;
 $endIndex = $endIndex|0;
 $list = $list|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $visibleCountNodes$0$lcssa = 0;
 var $visibleCountNodes$02 = 0, $visibleCountNodes$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($beginIndex>>>0)<($endIndex>>>0);
 if (!($0)) {
  $visibleCountNodes$0$lcssa = 0;
  $36 = (($list) + 4|0);
  HEAP32[$36>>2] = $visibleCountNodes$0$lcssa;
  STACKTOP = sp;return;
 }
 $1 = (($params) + 192|0);
 $2 = (($params) + 668|0);
 $i$01 = $beginIndex;$visibleCountNodes$02 = 0;
 while(1) {
  $3 = ((($nodes) + (($i$01*24)|0)|0) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = 1 << $4;
  $6 = HEAP32[$1>>2]|0;
  $7 = $5 & $6;
  $8 = ($7|0)==(0);
  do {
   if ($8) {
    $visibleCountNodes$1 = $visibleCountNodes$02;
   } else {
    $9 = (($nodes) + (($i$01*24)|0)|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $visibleCountNodes$1 = $visibleCountNodes$02;
    } else {
     $12 = ((($nodes) + (($i$01*24)|0)|0) + 22|0);
     $13 = HEAP8[$12>>0]|0;
     $14 = ($13<<24>>24)==(0);
     if ($14) {
      $15 = ((($nodes) + (($i$01*24)|0)|0) + 16|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(0);
      if (!($17)) {
       $18 = ((($nodes) + (($i$01*24)|0)|0) + 12|0);
       $19 = HEAP16[$18>>1]|0;
       $20 = $19&65535;
       $21 = ((($nodes) + (($i$01*24)|0)|0) + 14|0);
       $22 = HEAP16[$21>>1]|0;
       $23 = $22&65535;
       $24 = HEAP32[$2>>2]|0;
       $25 = (($24) + (($20*12)|0)|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = (($26) + ($23)|0);
       $28 = HEAP8[$27>>0]|0;
       $29 = $28&255;
       $30 = $29 & $16;
       $31 = ($30|0)==(0);
       if ($31) {
        $visibleCountNodes$1 = $visibleCountNodes$02;
        break;
       }
      }
      $32 = (($visibleCountNodes$02) + 1)|0;
      $33 = HEAP32[$list>>2]|0;
      $34 = (($33) + ($visibleCountNodes$02<<2)|0);
      HEAP32[$34>>2] = $i$01;
      $visibleCountNodes$1 = $32;
     } else {
      $visibleCountNodes$1 = $visibleCountNodes$02;
     }
    }
   }
  } while(0);
  $35 = (($i$01) + 1)|0;
  $exitcond = ($35|0)==($endIndex|0);
  if ($exitcond) {
   $visibleCountNodes$0$lcssa = $visibleCountNodes$1;
   break;
  } else {
   $i$01 = $35;$visibleCountNodes$02 = $visibleCountNodes$1;
  }
 }
 $36 = (($list) + 4|0);
 HEAP32[$36>>2] = $visibleCountNodes$0$lcssa;
 STACKTOP = sp;return;
}
function __Z34ProcessIndexListIsNodeVisibleStep2RK22SceneCullingParametersPK9SceneNodePK4AABBR9IndexList($params,$nodes,$bounds,$list) {
 $params = $params|0;
 $nodes = $nodes|0;
 $bounds = $bounds|0;
 $list = $list|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $farPlane$i$i = 0, $i$01 = 0, $visibleCountNodes$0$lcssa = 0, $visibleCountNodes$02 = 0, $visibleCountNodes$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $farPlane$i$i = sp;
 $0 = (($list) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $visibleCountNodes$0$lcssa = 0;
  HEAP32[$0>>2] = $visibleCountNodes$0$lcssa;
  STACKTOP = sp;return;
 }
 $3 = (($params) + 324|0);
 $4 = (($params) + 108|0);
 $5 = (($farPlane$i$i) + 12|0);
 $6 = (($params) + 596|0);
 $7 = (($params) + 600|0);
 $8 = (($params) + 604|0);
 $i$01 = 0;$visibleCountNodes$02 = 0;
 while(1) {
  $9 = HEAP32[$list>>2]|0;
  $10 = (($9) + ($i$01<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($bounds) + (($11*24)|0)|0);
  $13 = ((($nodes) + (($11*24)|0)|0) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$3>>2]|0;
  if ((($15|0) == 1)) {
   ;HEAP32[$farPlane$i$i+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$farPlane$i$i+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$farPlane$i$i+8>>2]=HEAP32[$4+8>>2]|0;
   $37 = ((($params) + ($14<<2)|0) + 196|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   HEAPF32[$5>>2] = $38;
   $39 = (__Z24IntersectAABBPlaneBoundsRK4AABBPK5Planei($12,$farPlane$i$i,1)|0);
   if ($39) {
    label = 7;
   } else {
    $visibleCountNodes$1 = $visibleCountNodes$02;
   }
  } else if ((($15|0) == 2)) {
   $16 = ((($params) + ($14<<2)|0) + 196|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = $17 == Math_fround(0.0);
   if ($18) {
    $42 = $9;
    label = 8;
   } else {
    $19 = Math_fround(HEAPF32[$12>>2]);
    $20 = Math_fround(HEAPF32[$6>>2]);
    $21 = Math_fround($19 - $20);
    $22 = ((($bounds) + (($11*24)|0)|0) + 4|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = Math_fround(HEAPF32[$7>>2]);
    $25 = Math_fround($23 - $24);
    $26 = ((($bounds) + (($11*24)|0)|0) + 8|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = Math_fround(HEAPF32[$8>>2]);
    $29 = Math_fround($27 - $28);
    $30 = Math_fround($21 * $21);
    $31 = Math_fround($25 * $25);
    $32 = Math_fround($30 + $31);
    $33 = Math_fround($29 * $29);
    $34 = Math_fround($32 + $33);
    $35 = Math_fround($17 * $17);
    $36 = $34 > $35;
    if ($36) {
     $visibleCountNodes$1 = $visibleCountNodes$02;
    } else {
     label = 7;
    }
   }
  } else {
   $42 = $9;
   label = 8;
  }
  if ((label|0) == 7) {
   label = 0;
   $$pre = HEAP32[$list>>2]|0;
   $42 = $$pre;
   label = 8;
  }
  if ((label|0) == 8) {
   label = 0;
   $40 = (($visibleCountNodes$02) + 1)|0;
   $41 = (($42) + ($visibleCountNodes$02<<2)|0);
   HEAP32[$41>>2] = $11;
   $visibleCountNodes$1 = $40;
  }
  $43 = (($i$01) + 1)|0;
  $exitcond = ($43|0)==($1|0);
  if ($exitcond) {
   $visibleCountNodes$0$lcssa = $visibleCountNodes$1;
   break;
  } else {
   $i$01 = $43;$visibleCountNodes$02 = $visibleCountNodes$1;
  }
 }
 HEAP32[$0>>2] = $visibleCountNodes$0$lcssa;
 STACKTOP = sp;return;
}
function __Z34ProcessIndexListIsNodeVisibleInOutRK22SceneCullingParametersPK9SceneNodePK4AABBR9IndexList($params,$nodes,$bounds,$list) {
 $params = $params|0;
 $nodes = $nodes|0;
 $bounds = $bounds|0;
 $list = $list|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $visibleCountNodes$0$lcssa = 0, $visibleCountNodes$02 = 0, $visibleCountNodes$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($list) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $visibleCountNodes$0$lcssa = 0;
  HEAP32[$0>>2] = $visibleCountNodes$0$lcssa;
  STACKTOP = sp;return;
 }
 $i$01 = 0;$visibleCountNodes$02 = 0;
 while(1) {
  $3 = HEAP32[$list>>2]|0;
  $4 = (($3) + ($i$01<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($nodes) + (($5*24)|0)|0);
  $7 = (($bounds) + (($5*24)|0)|0);
  $8 = (__Z13IsNodeVisibleRK9SceneNodeRK4AABBRK22SceneCullingParameters($6,$7,$params)|0);
  if ($8) {
   $9 = (($visibleCountNodes$02) + 1)|0;
   $10 = HEAP32[$list>>2]|0;
   $11 = (($10) + ($visibleCountNodes$02<<2)|0);
   HEAP32[$11>>2] = $5;
   $visibleCountNodes$1 = $9;
  } else {
   $visibleCountNodes$1 = $visibleCountNodes$02;
  }
  $12 = (($i$01) + 1)|0;
  $exitcond = ($12|0)==($1|0);
  if ($exitcond) {
   $visibleCountNodes$0$lcssa = $visibleCountNodes$1;
   break;
  } else {
   $i$01 = $12;$visibleCountNodes$02 = $visibleCountNodes$1;
  }
 }
 HEAP32[$0>>2] = $visibleCountNodes$0$lcssa;
 STACKTOP = sp;return;
}
function __Z13IsNodeVisibleRK9SceneNodeRK4AABBRK22SceneCullingParameters($node,$aabb,$params) {
 $node = $node|0;
 $aabb = $aabb|0;
 $params = $params|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $farPlane$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $farPlane$i$i = sp;
 $0 = (($node) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = 1 << $1;
 $3 = (($params) + 192|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2 & $4;
 $6 = ($5|0)==(0);
 if ($6) {
  $63 = 0;
  STACKTOP = sp;return ($63|0);
 }
 $7 = HEAP32[$node>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $63 = 0;
  STACKTOP = sp;return ($63|0);
 }
 $9 = (($node) + 22|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $63 = 0;
  STACKTOP = sp;return ($63|0);
 }
 $12 = (($node) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = (($node) + 12|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = $16&65535;
  $18 = (($node) + 14|0);
  $19 = HEAP16[$18>>1]|0;
  $20 = $19&65535;
  $21 = (($params) + 668|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + (($17*12)|0)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($20)|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = $26&255;
  $28 = $27 & $13;
  $29 = ($28|0)==(0);
  if ($29) {
   $63 = 0;
   STACKTOP = sp;return ($63|0);
  }
 }
 $30 = (($params) + 324|0);
 $31 = HEAP32[$30>>2]|0;
 if ((($31|0) == 1)) {
  $32 = (($params) + 108|0);
  ;HEAP32[$farPlane$i$i+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$farPlane$i$i+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$farPlane$i$i+8>>2]=HEAP32[$32+8>>2]|0;
  $33 = ((($params) + ($1<<2)|0) + 196|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($farPlane$i$i) + 12|0);
  HEAPF32[$35>>2] = $34;
  $36 = (__Z24IntersectAABBPlaneBoundsRK4AABBPK5Planei($aabb,$farPlane$i$i,1)|0);
  $37 = $36 ^ 1;
  $$0$i$i = $37;
 } else if ((($31|0) == 2)) {
  $38 = ((($params) + ($1<<2)|0) + 196|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = $39 == Math_fround(0.0);
  if ($40) {
   $$0$i$i = 0;
  } else {
   $41 = Math_fround(HEAPF32[$aabb>>2]);
   $42 = (($params) + 596|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = Math_fround($41 - $43);
   $45 = (($aabb) + 4|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($params) + 600|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = Math_fround($46 - $48);
   $50 = (($aabb) + 8|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = (($params) + 604|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = Math_fround($51 - $53);
   $55 = Math_fround($44 * $44);
   $56 = Math_fround($49 * $49);
   $57 = Math_fround($55 + $56);
   $58 = Math_fround($54 * $54);
   $59 = Math_fround($57 + $58);
   $60 = Math_fround($39 * $39);
   $61 = $59 > $60;
   $$0$i$i = $61;
  }
 } else {
  $$0$i$i = 0;
 }
 $62 = $$0$i$i ^ 1;
 $63 = $62;
 STACKTOP = sp;return ($63|0);
}
function __ZL17CullCastersCommonRK17ShadowCullContextRK9SceneNodeRK4AABB($context,$node,$aabb) {
 $context = $context|0;
 $node = $node|0;
 $aabb = $aabb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $farPlane = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $farPlane = sp;
 $0 = HEAP32[$node>>2]|0;
 $1 = (($0) + 41|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($context) + 4|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = (($0) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8&65535;
  $10 = ($9<<16>>16)==(255);
  if (!($10)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $11 = (($node) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = 1 << $12;
 $14 = (($context) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $13 & $15;
 $17 = ($16|0)==(0);
 if ($17) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = HEAP32[$context>>2]|0;
 $19 = ((($18) + ($12<<2)|0) + 228|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = $20 != Math_fround(0.0);
 do {
  if ($21) {
   $22 = (($18) + 356|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    $46 = (($18) + 540|0);
    ;HEAP32[$farPlane+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$farPlane+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$farPlane+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$farPlane+12>>2]=HEAP32[$46+12>>2]|0;
    $47 = (($18) + 360|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = Math_fround($20 + $48);
    $50 = (($farPlane) + 12|0);
    HEAPF32[$50>>2] = $49;
    $51 = (__Z24IntersectAABBPlaneBoundsRK4AABBPK5Planei($aabb,$farPlane,1)|0);
    if ($51) {
     break;
    } else {
     $$0 = 0;
    }
    STACKTOP = sp;return ($$0|0);
   } else {
    $25 = Math_fround(HEAPF32[$aabb>>2]);
    $26 = (($18) + 196|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = Math_fround($25 - $27);
    $29 = (($aabb) + 4|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = (($18) + 200|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = Math_fround($30 - $32);
    $34 = (($aabb) + 8|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = (($18) + 204|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = Math_fround($35 - $37);
    $39 = Math_fround($28 * $28);
    $40 = Math_fround($33 * $33);
    $41 = Math_fround($39 + $40);
    $42 = Math_fround($38 * $38);
    $43 = Math_fround($41 + $42);
    $44 = Math_fround($20 * $20);
    $45 = $43 > $44;
    if ($45) {
     $$0 = 0;
    } else {
     break;
    }
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN15GlobalCallbacks3GetEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (578384|0);
}
function __ZN17CommonStringTableC2Ev($this) {
 $this = $this|0;
 var $$02$i$i = 0, $$byval_copy8 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $h$0$lcssa$i$i = 0, $h$01$i$i = 0, $i1$010 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $str$011 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 304|0);
 HEAP32[$this>>2] = 0;
 $5 = (($this) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 61;
 $8 = (($this) + 16|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 24|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 28|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 20|0);
 HEAP32[$11>>2] = 61;
 $12 = (($this) + 32|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 40|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 44|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 36|0);
 HEAP32[$15>>2] = 61;
 $16 = (($this) + 48|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 56|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 60|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 52|0);
 HEAP32[$19>>2] = 61;
 $20 = (($this) + 64|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 72|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 76|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 68|0);
 HEAP32[$23>>2] = 61;
 $24 = (($this) + 80|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 88|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 92|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 84|0);
 HEAP32[$27>>2] = 61;
 $28 = (($this) + 96|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 104|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 108|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 100|0);
 HEAP32[$31>>2] = 61;
 $32 = (($this) + 112|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 120|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 124|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 116|0);
 HEAP32[$35>>2] = 61;
 $36 = (($this) + 128|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 136|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 140|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 132|0);
 HEAP32[$39>>2] = 61;
 $40 = (($this) + 144|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 152|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 156|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 148|0);
 HEAP32[$43>>2] = 61;
 $44 = (($this) + 160|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 168|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 172|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 164|0);
 HEAP32[$47>>2] = 61;
 $48 = (($this) + 176|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 184|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 188|0);
 HEAP32[$50>>2] = 0;
 $51 = (($this) + 180|0);
 HEAP32[$51>>2] = 61;
 $52 = (($this) + 192|0);
 HEAP32[$52>>2] = 0;
 $53 = (($this) + 200|0);
 HEAP32[$53>>2] = 0;
 $54 = (($this) + 204|0);
 HEAP32[$54>>2] = 0;
 $55 = (($this) + 196|0);
 HEAP32[$55>>2] = 61;
 $56 = (($this) + 208|0);
 HEAP32[$56>>2] = 0;
 $57 = (($this) + 216|0);
 HEAP32[$57>>2] = 0;
 $58 = (($this) + 220|0);
 HEAP32[$58>>2] = 0;
 $59 = (($this) + 212|0);
 HEAP32[$59>>2] = 61;
 $60 = (($this) + 224|0);
 HEAP32[$60>>2] = 0;
 $61 = (($this) + 232|0);
 HEAP32[$61>>2] = 0;
 $62 = (($this) + 236|0);
 HEAP32[$62>>2] = 0;
 $63 = (($this) + 228|0);
 HEAP32[$63>>2] = 61;
 $64 = (($this) + 240|0);
 HEAP32[$64>>2] = 0;
 $65 = (($this) + 248|0);
 HEAP32[$65>>2] = 0;
 $66 = (($this) + 252|0);
 HEAP32[$66>>2] = 0;
 $67 = (($this) + 244|0);
 HEAP32[$67>>2] = 61;
 $68 = (($this) + 256|0);
 HEAP32[$68>>2] = 0;
 $69 = (($this) + 264|0);
 HEAP32[$69>>2] = 0;
 $70 = (($this) + 268|0);
 HEAP32[$70>>2] = 0;
 $71 = (($this) + 260|0);
 HEAP32[$71>>2] = 61;
 $72 = (($this) + 272|0);
 HEAP32[$72>>2] = 0;
 $73 = (($this) + 280|0);
 HEAP32[$73>>2] = 0;
 $74 = (($this) + 284|0);
 HEAP32[$74>>2] = 0;
 $75 = (($this) + 276|0);
 HEAP32[$75>>2] = 61;
 $76 = (($this) + 288|0);
 HEAP32[$76>>2] = 0;
 $77 = (($this) + 296|0);
 HEAP32[$77>>2] = 0;
 $78 = (($this) + 300|0);
 HEAP32[$78>>2] = 0;
 $79 = (($this) + 292|0);
 HEAP32[$79>>2] = 61;
 $80 = HEAP32[628448>>2]|0;
 $81 = (($this) + 4|0);
 HEAP32[$81>>2] = $80;
 $82 = HEAP32[628448>>2]|0;
 $83 = (($this) + 20|0);
 HEAP32[$83>>2] = $82;
 $84 = HEAP32[628448>>2]|0;
 $85 = (($this) + 36|0);
 HEAP32[$85>>2] = $84;
 $86 = HEAP32[628448>>2]|0;
 $87 = (($this) + 52|0);
 HEAP32[$87>>2] = $86;
 $88 = HEAP32[628448>>2]|0;
 $89 = (($this) + 68|0);
 HEAP32[$89>>2] = $88;
 $90 = HEAP32[628448>>2]|0;
 $91 = (($this) + 84|0);
 HEAP32[$91>>2] = $90;
 $92 = HEAP32[628448>>2]|0;
 $93 = (($this) + 100|0);
 HEAP32[$93>>2] = $92;
 $94 = HEAP32[628448>>2]|0;
 $95 = (($this) + 116|0);
 HEAP32[$95>>2] = $94;
 $96 = HEAP32[628448>>2]|0;
 $97 = (($this) + 132|0);
 HEAP32[$97>>2] = $96;
 $98 = HEAP32[628448>>2]|0;
 $99 = (($this) + 148|0);
 HEAP32[$99>>2] = $98;
 $100 = HEAP32[628448>>2]|0;
 $101 = (($this) + 164|0);
 HEAP32[$101>>2] = $100;
 $102 = HEAP32[628448>>2]|0;
 $103 = (($this) + 180|0);
 HEAP32[$103>>2] = $102;
 $104 = HEAP32[628448>>2]|0;
 $105 = (($this) + 196|0);
 HEAP32[$105>>2] = $104;
 $106 = HEAP32[628448>>2]|0;
 $107 = (($this) + 212|0);
 HEAP32[$107>>2] = $106;
 $108 = HEAP32[628448>>2]|0;
 $109 = (($this) + 228|0);
 HEAP32[$109>>2] = $108;
 $110 = HEAP32[628448>>2]|0;
 $111 = (($this) + 244|0);
 HEAP32[$111>>2] = $110;
 $112 = HEAP32[628448>>2]|0;
 $113 = (($this) + 260|0);
 HEAP32[$113>>2] = $112;
 $114 = HEAP32[628448>>2]|0;
 $115 = (($this) + 276|0);
 HEAP32[$115>>2] = $114;
 $116 = HEAP32[628448>>2]|0;
 $117 = (($this) + 292|0);
 HEAP32[$117>>2] = $116;
 $118 = HEAP32[580528>>2]|0;
 $119 = HEAP32[580536>>2]|0;
 $120 = ($118>>>0)<($119>>>0);
 L1: do {
  if ($120) {
   $str$011 = $118;
   L3: while(1) {
    $125 = (_strlen(($str$011|0))|0);
    $126 = HEAP8[$str$011>>0]|0;
    $127 = ($126<<24>>24)==(0);
    if ($127) {
     $h$0$lcssa$i$i = 0;
    } else {
     $$02$i$i = $str$011;$129 = $126;$h$01$i$i = 0;
     while(1) {
      $128 = $129 << 24 >> 24;
      $130 = $h$01$i$i << 4;
      $131 = (($130) + ($128))|0;
      $132 = $131 & -268435456;
      $133 = $132 >>> 24;
      $134 = $133 | $132;
      $135 = $134 ^ $131;
      $136 = (($$02$i$i) + 1|0);
      $137 = HEAP8[$136>>0]|0;
      $138 = ($137<<24>>24)==(0);
      if ($138) {
       $h$0$lcssa$i$i = $135;
       break;
      } else {
       $$02$i$i = $136;$129 = $137;$h$01$i$i = $135;
      }
     }
    }
    $139 = (($h$0$lcssa$i$i>>>0) % 19)&-1;
    $140 = (($this) + ($139<<4)|0);
    $141 = ((($this) + ($139<<4)|0) + 8|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = (($142) + 1)|0;
    HEAP32[$141>>2] = $143;
    $144 = ((($this) + ($139<<4)|0) + 12|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = $145 & 2147483647;
    $147 = ($143>>>0)>($146>>>0);
    if ($147) {
     $148 = $145 << 1;
     $149 = ($148|0)==(0);
     $150 = $149 ? 1 : $148;
     $151 = ($146>>>0)<($150>>>0);
     do {
      if ($151) {
       $152 = ($145|0)>(-1);
       if ($152) {
        HEAP32[$144>>2] = $150;
        $153 = HEAP32[$140>>2]|0;
        $154 = $150 << 3;
        $155 = ((($this) + ($139<<4)|0) + 4|0);
        $156 = HEAP32[$155>>2]|0;
        HEAP32[$0>>2] = $156;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
        $157 = (invoke_iiiiiiii(108,($153|0),($154|0),4,($$byval_copy8|0),0,(580800|0),370)|0);
        $158 = __THREW__; __THREW__ = 0;
        $159 = $158&1;
        if ($159) {
         break L3;
        }
        HEAP32[$140>>2] = $157;
        break;
       } else {
        $160 = $150 << 3;
        $161 = ((($this) + ($139<<4)|0) + 4|0);
        $162 = HEAP32[$161>>2]|0;
        HEAP32[$1>>2] = $162;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
        $163 = (invoke_iiiiiii(102,($160|0),4,($$byval_copy8|0),0,(580800|0),352)|0);
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if ($165) {
         break L3;
        }
        $166 = HEAP32[$140>>2]|0;
        $167 = HEAP32[$141>>2]|0;
        $168 = $167 << 3;
        _memcpy(($163|0),($166|0),($168|0))|0;
        HEAP32[$144>>2] = $150;
        HEAP32[$140>>2] = $163;
        break;
       }
      }
     } while(0);
     $$pre$i$i = HEAP32[$141>>2]|0;
     $170 = $$pre$i$i;
    } else {
     $170 = $143;
    }
    $169 = (($170) + -1)|0;
    $171 = HEAP32[$140>>2]|0;
    $172 = (($171) + ($169<<3)|0);
    $173 = $str$011;
    $174 = $172;
    $175 = $174;
    HEAP32[$175>>2] = $h$0$lcssa$i$i;
    $176 = (($174) + 4)|0;
    $177 = $176;
    HEAP32[$177>>2] = $173;
    $178 = (($125) + 1)|0;
    $179 = (($str$011) + ($178)|0);
    $180 = ($179>>>0)<($119>>>0);
    if ($180) {
     $str$011 = $179;
    } else {
     label = 6;
     break L1;
    }
   }
   $123 = ___cxa_find_matching_catch()|0;
   $124 = tempRet0;
   $lpad$phi$index = $123;$lpad$phi$index2 = $124;
  } else {
   label = 6;
  }
 } while(0);
 do {
  if ((label|0) == 6) {
   $i1$010 = 0;
   while(1) {
    $181 = ((($this) + ($i1$010<<4)|0) + 12|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = ($182|0)>(-1);
    if ($183) {
     $184 = ((($this) + ($i1$010<<4)|0) + 8|0);
     $185 = HEAP32[$184>>2]|0;
     HEAP32[$181>>2] = $185;
     $186 = (($this) + ($i1$010<<4)|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = $185 << 3;
     $189 = ((($this) + ($i1$010<<4)|0) + 4|0);
     $190 = HEAP32[$189>>2]|0;
     HEAP32[$2>>2] = $190;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
     $191 = (invoke_iiiiiiii(108,($187|0),($188|0),4,($$byval_copy8|0),0,(580800|0),370)|0);
     $192 = __THREW__; __THREW__ = 0;
     $193 = $192&1;
     if ($193) {
      label = 2;
      break;
     }
     HEAP32[$186>>2] = $191;
    }
    $194 = (($i1$010) + 1)|0;
    $195 = ($194|0)<(19);
    if ($195) {
     $i1$010 = $194;
    } else {
     label = 22;
     break;
    }
   }
   if ((label|0) == 2) {
    $121 = ___cxa_find_matching_catch()|0;
    $122 = tempRet0;
    $lpad$phi$index = $121;$lpad$phi$index2 = $122;
    break;
   }
   else if ((label|0) == 22) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $197 = $4;
 while(1) {
  $196 = (($197) + -16|0);
  $198 = (($197) + -4|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ($199|0)>(-1);
  if ($200) {
   $201 = HEAP32[$196>>2]|0;
   $202 = (($197) + -12|0);
   $203 = HEAP32[$202>>2]|0;
   HEAP32[$3>>2] = $203;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($201|0),($$byval_copy8|0));
   $204 = __THREW__; __THREW__ = 0;
   $205 = $204&1;
   if ($205) {
    label = 28;
    break;
   }
   HEAP32[$196>>2] = 0;
  }
  $206 = ($196|0)==($this|0);
  if ($206) {
   label = 27;
   break;
  } else {
   $197 = $196;
  }
 }
 if ((label|0) == 27) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  $207 = ___cxa_find_matching_catch(0|0)|0;
  $208 = tempRet0;
  ___clang_call_terminate($207);
  // unreachable;
 }
}
function __ZNK17CommonStringTable16FindCommonStringEPKc($this,$str) {
 $this = $this|0;
 $str = $str|0;
 var $$0 = 0, $$02$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0$lcssa$i$i = 0, $h$01$i$i = 0, $i$03 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($str|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[580528>>2]|0;
 $2 = ($1>>>0)<=($str>>>0);
 $3 = HEAP32[580536>>2]|0;
 $4 = ($3>>>0)>($str>>>0);
 $or$cond = $2 & $4;
 if ($or$cond) {
  $$0 = $str;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP8[$str>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $h$0$lcssa$i$i = 0;
 } else {
  $$02$i$i = $str;$8 = $5;$h$01$i$i = 0;
  while(1) {
   $7 = $8 << 24 >> 24;
   $9 = $h$01$i$i << 4;
   $10 = (($9) + ($7))|0;
   $11 = $10 & -268435456;
   $12 = $11 >>> 24;
   $13 = $12 | $11;
   $14 = $13 ^ $10;
   $15 = (($$02$i$i) + 1|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    $h$0$lcssa$i$i = $14;
    break;
   } else {
    $$02$i$i = $15;$8 = $16;$h$01$i$i = $14;
   }
  }
 }
 $18 = (($h$0$lcssa$i$i>>>0) % 19)&-1;
 $19 = ((($this) + ($18<<4)|0) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = (($this) + ($18<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $i$03 = 0;
 while(1) {
  $24 = (($23) + ($i$03<<3)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==($h$0$lcssa$i$i|0);
  if ($26) {
   $27 = ((($23) + ($i$03<<3)|0) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (_strcmp($28,$str)|0);
   $30 = ($29|0)==(0);
   if ($30) {
    $$0 = $28;
    label = 10;
    break;
   }
  }
  $31 = (($i$03) + 1)|0;
  $32 = ($31>>>0)<($20>>>0);
  if ($32) {
   $i$03 = $31;
  } else {
   $$0 = 0;
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN17CommonStringTable16StaticInitializeEv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628448>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(304,$$byval_copy1,1,16,580800,59)|0);
 __THREW__ = 0;
 invoke_vi(3442,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  HEAP32[580808>>2] = $2;
  STACKTOP = sp;return;
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($2|0),($$byval_copy1|0),1,16,(580800|0),59);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN17CommonStringTable13StaticCleanupEv() {
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[580808>>2]|0;
 $4 = HEAP32[628448>>2]|0;
 $5 = ($3|0)==(0|0);
 if ($5) {
  HEAP32[$2>>2] = $4;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy2);
  HEAP32[580808>>2] = 0;
  STACKTOP = sp;return;
 }
 $6 = (($3) + 304|0);
 $8 = $6;
 while(1) {
  $7 = (($8) + -16|0);
  $9 = (($8) + -4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)>(-1);
  if ($11) {
   $12 = HEAP32[$7>>2]|0;
   $13 = (($8) + -12|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$1>>2] = $14;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($12|0),($$byval_copy2|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    break;
   }
   HEAP32[$7>>2] = 0;
  }
  $17 = ($7|0)==($3|0);
  if ($17) {
   label = 15;
   break;
  } else {
   $8 = $7;
  }
 }
 if ((label|0) == 15) {
  HEAP32[$2>>2] = $4;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy2);
  HEAP32[580808>>2] = 0;
  STACKTOP = sp;return;
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $20 = ($3|0)==($7|0);
 if ($20) {
  ___resumeException($18|0);
  // unreachable;
 }
 $22 = $7;
 while(1) {
  $21 = (($22) + -16|0);
  $23 = (($22) + -4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)>(-1);
  if ($25) {
   $26 = HEAP32[$21>>2]|0;
   $27 = (($22) + -12|0);
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$0>>2] = $28;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($26|0),($$byval_copy2|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 14;
    break;
   }
   HEAP32[$21>>2] = 0;
  }
  $31 = ($21|0)==($3|0);
  if ($31) {
   label = 13;
   break;
  } else {
   $22 = $21;
  }
 }
 if ((label|0) == 13) {
  ___resumeException($18|0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  $32 = ___cxa_find_matching_catch(0|0)|0;
  $33 = tempRet0;
  ___clang_call_terminate($32);
  // unreachable;
 }
}
function __Z20GetCommonStringTablev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580808>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN14ConstantString12create_emptyEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[580528>>2]|0;
  $4 = ($3>>>0)>($1>>>0);
  $5 = HEAP32[580536>>2]|0;
  $phitmp$i$i = ($5>>>0)<=($1>>>0);
  $or$cond$i = $4 | $phitmp$i$i;
  if ($or$cond$i) {
   $6 = (($1) + -4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = HEAP32[$6>>2]|0;
   $10 = $9 & 65535;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = HEAP32[$6>>2]|0;
    $13 = $12 << 16;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy);
   }
  }
 }
 $14 = HEAP32[580792>>2]|0;
 HEAP32[$this>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN14ConstantStringaSERKS_($this,$input) {
 $this = $this|0;
 $input = $input|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond$i$i = 0, $phitmp$i$i = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[580528>>2]|0;
  $4 = ($3>>>0)>($1>>>0);
  $5 = HEAP32[580536>>2]|0;
  $phitmp$i$i$i = ($5>>>0)<=($1>>>0);
  $or$cond$i$i = $4 | $phitmp$i$i$i;
  if ($or$cond$i$i) {
   $6 = (($1) + -4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = HEAP32[$6>>2]|0;
   $10 = $9 & 65535;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = HEAP32[$6>>2]|0;
    $13 = $12 << 16;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy);
   }
  }
 }
 HEAP32[$this>>2] = 0;
 $14 = HEAP32[$input>>2]|0;
 HEAP32[$this>>2] = $14;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = HEAP32[580528>>2]|0;
 $17 = ($16>>>0)>($14>>>0);
 $18 = HEAP32[580536>>2]|0;
 $phitmp$i$i = ($18>>>0)<=($14>>>0);
 $or$cond$i = $17 | $phitmp$i$i;
 if (!($or$cond$i)) {
  STACKTOP = sp;return;
 }
 $19 = (($14) + -4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 1)|0;
 HEAP32[$19>>2] = $21;
 $22 = HEAP32[$19>>2]|0;
 STACKTOP = sp;return;
}
function __ZN14ConstantString6assignERKS_($this,$input) {
 $this = $this|0;
 $input = $input|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond$i = 0, $phitmp$i = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[580528>>2]|0;
  $4 = ($3>>>0)>($1>>>0);
  $5 = HEAP32[580536>>2]|0;
  $phitmp$i$i = ($5>>>0)<=($1>>>0);
  $or$cond$i = $4 | $phitmp$i$i;
  if ($or$cond$i) {
   $6 = (($1) + -4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = HEAP32[$6>>2]|0;
   $10 = $9 & 65535;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = HEAP32[$6>>2]|0;
    $13 = $12 << 16;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy);
   }
  }
 }
 HEAP32[$this>>2] = 0;
 $14 = HEAP32[$input>>2]|0;
 HEAP32[$this>>2] = $14;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = HEAP32[580528>>2]|0;
 $17 = ($16>>>0)>($14>>>0);
 $18 = HEAP32[580536>>2]|0;
 $phitmp$i = ($18>>>0)<=($14>>>0);
 $or$cond = $17 | $phitmp$i;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $19 = (($14) + -4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 1)|0;
 HEAP32[$19>>2] = $21;
 $22 = HEAP32[$19>>2]|0;
 STACKTOP = sp;return;
}
function __ZN14ConstantString6assignEPKc10MemLabelId($this,$str,$label) {
 $this = $this|0;
 $str = $str|0;
 $label = $label|0;
 var $$byval_copy1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[580528>>2]|0;
  $5 = ($4>>>0)>($2>>>0);
  $6 = HEAP32[580536>>2]|0;
  $phitmp$i$i = ($6>>>0)<=($2>>>0);
  $or$cond$i = $5 | $phitmp$i$i;
  if ($or$cond$i) {
   $7 = (($2) + -4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + -1)|0;
   HEAP32[$7>>2] = $9;
   $10 = HEAP32[$7>>2]|0;
   $11 = $10 & 65535;
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = HEAP32[$7>>2]|0;
    $14 = $13 << 16;
    HEAP32[$0>>2] = $14;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy1);
   }
  }
 }
 HEAP32[$this>>2] = 0;
 $15 = (__Z20GetCommonStringTablev()|0);
 $16 = (__ZNK17CommonStringTable16FindCommonStringEPKc($15,$str)|0);
 HEAP32[$this>>2] = $16;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (_strlen(($str|0))|0);
 $19 = (($18) + 5)|0;
 $20 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $20;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,16,$$byval_copy1,0,580816,86)|0);
 $22 = (($21) + 4|0);
 HEAP32[$21>>2] = 1;
 $23 = HEAP32[$label>>2]|0;
 $24 = $23 << 16;
 $25 = HEAP32[$21>>2]|0;
 $26 = $25 & 65535;
 HEAP32[$21>>2] = $26;
 $27 = HEAP32[$21>>2]|0;
 $28 = $27 | $24;
 HEAP32[$21>>2] = $28;
 _memcpy(($22|0),($str|0),($18|0))|0;
 $$sum = (($18) + 4)|0;
 $29 = (($21) + ($$sum)|0);
 HEAP8[$29>>0] = 0;
 HEAP32[$this>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN14ConstantStringD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[580528>>2]|0;
  $4 = ($3>>>0)>($1>>>0);
  $5 = HEAP32[580536>>2]|0;
  $phitmp$i$i = ($5>>>0)<=($1>>>0);
  $or$cond$i = $4 | $phitmp$i$i;
  if ($or$cond$i) {
   $6 = (($1) + -4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = HEAP32[$6>>2]|0;
   $10 = $9 & 65535;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = HEAP32[$6>>2]|0;
    $13 = $12 << 16;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy);
   }
  }
 }
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14GrowableBufferD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[628472>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN13ModuleManager4LoadEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 256|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __Z31RegisterStaticallyLinkedModulesv();
 __ZN35RegisterRuntimeInitializeAndCleanup22ExecuteInitializationsEv();
 $i$01$i = 0;
 while(1) {
  $3 = ((($this) + ($i$01$i<<2)|0) + 192|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   FUNCTION_TABLE_vi[$4 & 4095]($this);
  }
  $6 = (($i$01$i) + 1)|0;
  $exitcond$i = ($6|0)==(16);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $6;
  }
 }
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN13ModuleManager3GetEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580824>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $3 = $0;
  STACKTOP = sp;return ($3|0);
 }
 $2 = (__Znwj(260)|0);
 _memset(($2|0),0,257)|0;
 HEAP32[580824>>2] = $2;
 $3 = $2;
 STACKTOP = sp;return ($3|0);
}
function __Z31RegisterStaticallyLinkedModulesv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17RegisterModule_UIv();
 __Z39RegisterStaticallyLinkedModulesGranularv();
 STACKTOP = sp;return;
}
function __ZL16StaticInitializev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628240>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,580832,32)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[580840>>2] = $2;
 STACKTOP = sp;return;
}
function __ZL13StaticDestroyv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[580840>>2]|0;
 $2 = HEAP32[628240>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($1,$5);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[580840>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($__nd) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZN11PerlinNoise5NoiseEff($x,$y) {
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0);
 var $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x < Math_fround(0.0);
 if ($0) {
  $1 = Math_fround(-$x);
  $5 = $1;
 } else {
  $5 = $x;
 }
 $2 = $y < Math_fround(0.0);
 if ($2) {
  $3 = Math_fround(-$y);
  $7 = $3;
 } else {
  $7 = $y;
 }
 $4 = (~~(($5)));
 $6 = (~~(($7)));
 $8 = $4 & 255;
 $9 = $6 & 255;
 $10 = (Math_fround(($4|0)));
 $11 = Math_fround($5 - $10);
 $12 = (Math_fround(($6|0)));
 $13 = Math_fround($7 - $12);
 $14 = $11 > Math_fround(1.0);
 $15 = $14 ? Math_fround(1.0) : $11;
 $16 = Math_fround($15 * $15);
 $17 = Math_fround($15 * $16);
 $18 = Math_fround($15 * Math_fround(6.0));
 $19 = Math_fround($18 + Math_fround(-15.0));
 $20 = Math_fround($15 * $19);
 $21 = Math_fround($20 + Math_fround(10.0));
 $22 = Math_fround($17 * $21);
 $23 = $13 > Math_fround(1.0);
 $24 = $23 ? Math_fround(1.0) : $13;
 $25 = Math_fround($24 * $24);
 $26 = Math_fround($24 * $25);
 $27 = Math_fround($24 * Math_fround(6.0));
 $28 = Math_fround($27 + Math_fround(-15.0));
 $29 = Math_fround($24 * $28);
 $30 = Math_fround($29 + Math_fround(10.0));
 $31 = Math_fround($26 * $30);
 $32 = (580848 + ($8<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($9) + ($33))|0;
 $35 = (580848 + ($34<<2)|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 1)|0;
 $38 = (580848 + ($37<<2)|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($8) + 1)|0;
 $41 = (580848 + ($40<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + ($9))|0;
 $44 = (580848 + ($43<<2)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 1)|0;
 $47 = (580848 + ($46<<2)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (580848 + ($36<<2)|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 15;
 $52 = ($51>>>0)<(8);
 $53 = $52 ? $11 : $13;
 $54 = ($51>>>0)<(4);
 if ($54) {
  $64 = $13;
 } else {
  $55 = $50 & 13;
  $56 = ($55|0)==(12);
  $57 = $56 ? $11 : Math_fround(0.0);
  $64 = $57;
 }
 $58 = $50 & 1;
 $59 = ($58|0)==(0);
 if ($59) {
  $67 = $53;
 } else {
  $60 = Math_fround(-$53);
  $67 = $60;
 }
 $61 = $50 & 2;
 $62 = ($61|0)==(0);
 if ($62) {
  $66 = $64;
 } else {
  $63 = Math_fround(-$64);
  $66 = $63;
 }
 $65 = Math_fround($67 + $66);
 $68 = (580848 + ($45<<2)|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = Math_fround($11 + Math_fround(-1.0));
 $71 = $69 & 15;
 $72 = ($71>>>0)<(8);
 $73 = $72 ? $70 : $13;
 $74 = ($71>>>0)<(4);
 if ($74) {
  $84 = $13;
 } else {
  $75 = $69 & 13;
  $76 = ($75|0)==(12);
  $77 = $76 ? $70 : Math_fround(0.0);
  $84 = $77;
 }
 $78 = $69 & 1;
 $79 = ($78|0)==(0);
 if ($79) {
  $87 = $73;
 } else {
  $80 = Math_fround(-$73);
  $87 = $80;
 }
 $81 = $69 & 2;
 $82 = ($81|0)==(0);
 if ($82) {
  $86 = $84;
 } else {
  $83 = Math_fround(-$84);
  $86 = $83;
 }
 $85 = Math_fround($87 + $86);
 $88 = Math_fround($85 - $65);
 $89 = Math_fround($22 * $88);
 $90 = Math_fround($65 + $89);
 $91 = (580848 + ($39<<2)|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = Math_fround($13 + Math_fround(-1.0));
 $94 = $92 & 15;
 $95 = ($94>>>0)<(8);
 $96 = $95 ? $11 : $93;
 $97 = ($94>>>0)<(4);
 if ($97) {
  $107 = $93;
 } else {
  $98 = $92 & 13;
  $99 = ($98|0)==(12);
  $100 = $99 ? $11 : Math_fround(0.0);
  $107 = $100;
 }
 $101 = $92 & 1;
 $102 = ($101|0)==(0);
 if ($102) {
  $110 = $96;
 } else {
  $103 = Math_fround(-$96);
  $110 = $103;
 }
 $104 = $92 & 2;
 $105 = ($104|0)==(0);
 if ($105) {
  $109 = $107;
 } else {
  $106 = Math_fround(-$107);
  $109 = $106;
 }
 $108 = Math_fround($110 + $109);
 $111 = (580848 + ($48<<2)|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = $112 & 15;
 $114 = ($113>>>0)<(8);
 $115 = $114 ? $70 : $93;
 $116 = ($113>>>0)<(4);
 if ($116) {
  $126 = $93;
 } else {
  $117 = $112 & 13;
  $118 = ($117|0)==(12);
  $119 = $118 ? $70 : Math_fround(0.0);
  $126 = $119;
 }
 $120 = $112 & 1;
 $121 = ($120|0)==(0);
 if ($121) {
  $129 = $115;
 } else {
  $122 = Math_fround(-$115);
  $129 = $122;
 }
 $123 = $112 & 2;
 $124 = ($123|0)==(0);
 if ($124) {
  $128 = $126;
  $127 = Math_fround($129 + $128);
  $130 = Math_fround($127 - $108);
  $131 = Math_fround($22 * $130);
  $132 = Math_fround($108 + $131);
  $133 = Math_fround($132 - $90);
  $134 = Math_fround($31 * $133);
  $135 = Math_fround($90 + $134);
  STACKTOP = sp;return (Math_fround($135));
 }
 $125 = Math_fround(-$126);
 $128 = $125;
 $127 = Math_fround($129 + $128);
 $130 = Math_fround($127 - $108);
 $131 = Math_fround($22 * $130);
 $132 = Math_fround($108 + $131);
 $133 = Math_fround($132 - $90);
 $134 = Math_fround($31 * $133);
 $135 = Math_fround($90 + $134);
 STACKTOP = sp;return (Math_fround($135));
}
function __ZN13SpeedTreeWindC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $scevgep = 0, $scevgep9$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = Math_fround(5.0);
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = Math_fround(2.5);
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 12|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 416|0);
 HEAPF32[$3>>2] = Math_fround(50.0);
 $4 = (($this) + 420|0);
 HEAPF32[$4>>2] = Math_fround(2.0);
 $5 = (($this) + 504|0);
 $6 = (($this) + 624|0);
 HEAPF32[$6>>2] = Math_fround(0.300000011920928955078);
 $7 = (($this) + 628|0);
 HEAPF32[$7>>2] = Math_fround(0.75);
 $8 = (($this) + 632|0);
 HEAPF32[$8>>2] = Math_fround(0.300000011920928955078);
 dest=$5+0|0; stop=dest+120|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $9 = (($this) + 636|0);
 $10 = (($this) + 756|0);
 HEAPF32[$10>>2] = Math_fround(0.300000011920928955078);
 $11 = (($this) + 760|0);
 HEAPF32[$11>>2] = Math_fround(0.75);
 $12 = (($this) + 764|0);
 HEAPF32[$12>>2] = Math_fround(0.300000011920928955078);
 dest=$9+0|0; stop=dest+120|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $13 = (($this) + 768|0);
 $14 = (($this) + 968|0);
 HEAPF32[$14>>2] = Math_fround(20.0);
 $15 = (($this) + 972|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($this) + 976|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($this) + 980|0);
 HEAPF32[$17>>2] = Math_fround(0.300000011920928955078);
 $18 = (($this) + 984|0);
 HEAPF32[$18>>2] = Math_fround(0.00499999988824129104614);
 $19 = (($this) + 988|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 _memset(($13|0),0,200)|0;
 $20 = (($this) + 992|0);
 $21 = (($this) + 1192|0);
 HEAPF32[$21>>2] = Math_fround(20.0);
 $22 = (($this) + 1196|0);
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($this) + 1200|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($this) + 1204|0);
 HEAPF32[$24>>2] = Math_fround(0.300000011920928955078);
 $25 = (($this) + 1208|0);
 HEAPF32[$25>>2] = Math_fround(0.00499999988824129104614);
 $26 = (($this) + 1212|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 _memset(($20|0),0,200)|0;
 $27 = (($this) + 1256|0);
 HEAPF32[$27>>2] = Math_fround(10.0);
 $28 = (($this) + 1260|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($this) + 1264|0);
 HEAPF32[$29>>2] = Math_fround(0.00499999988824129104614);
 $30 = (($this) + 1268|0);
 HEAPF32[$30>>2] = Math_fround(9.0);
 $31 = (($this) + 1272|0);
 HEAPF32[$31>>2] = Math_fround(32.0);
 $32 = (($this) + 1276|0);
 HEAPF32[$32>>2] = Math_fround(0.400000005960464477539);
 $33 = (($this) + 1280|0);
 HEAPF32[$33>>2] = Math_fround(0.0500000007450580596924);
 $34 = (($this) + 1284|0);
 HEAPF32[$34>>2] = Math_fround(0.5);
 $35 = (($this) + 1288|0);
 HEAPF32[$35>>2] = Math_fround(0.5);
 $36 = (($this) + 1292|0);
 HEAPF32[$36>>2] = Math_fround(-0.5);
 $37 = (($this) + 1296|0);
 HEAPF32[$37>>2] = Math_fround(0.5);
 $38 = (($this) + 1300|0);
 HEAPF32[$38>>2] = Math_fround(0.5);
 $39 = (($this) + 1304|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($this) + 1308|0);
 HEAPF32[$40>>2] = Math_fround(0.5);
 $41 = (($this) + 1312|0);
 HEAPF32[$41>>2] = Math_fround(1.0);
 $42 = (($this) + 1316|0);
 HEAPF32[$42>>2] = Math_fround(1.0);
 $43 = (($this) + 1320|0);
 HEAPF32[$43>>2] = Math_fround(4.0);
 $44 = (($this) + 1324|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 $45 = (($this) + 1328|0);
 HEAPF32[$45>>2] = Math_fround(1.0);
 $scevgep9$i = (($this) + 16|0);
 _memset(($scevgep9$i|0),0,400)|0;
 $46 = (($this) + 424|0);
 $47 = (($this) + 1216|0);
 dest=$46+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$47+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $48 = (($this) + 1344|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($this) + 1376|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($this) + 1392|0);
 HEAPF64[$50>>3] = -1.0;
 $51 = (($this) + 1400|0);
 HEAPF64[$51>>3] = 0.0;
 $52 = (($this) + 1408|0);
 HEAP8[$52>>0] = 0;
 $53 = (($this) + 1412|0);
 $54 = (($this) + 1448|0);
 dest=$53+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF64[$54>>3] = 1.0;
 $55 = (($this) + 1456|0);
 HEAPF64[$55>>3] = 0.0;
 $56 = (($this) + 1464|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($this) + 1472|0);
 $58 = (($this) + 1520|0);
 $59 = (($this) + 1556|0);
 $scevgep = (($this) + 1348|0);
 dest=$scevgep+0|0; stop=dest+28|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $60 = (($this) + 1380|0);
 ;HEAP32[$57+0>>2]=0|0;HEAP32[$57+4>>2]=0|0;HEAP32[$57+8>>2]=0|0;HEAP32[$57+12>>2]=0|0;HEAP32[$57+16>>2]=0|0;
 ;HEAP32[$58+0>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;HEAP32[$58+12>>2]=0|0;
 dest=$59+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$60>>2] = Math_fround(1.0);
 $61 = (($this) + 1504|0);
 HEAPF32[$61>>2] = Math_fround(1.0);
 $62 = (($this) + 1536|0);
 HEAPF32[$62>>2] = Math_fround(1.0);
 $63 = (($this) + 1492|0);
 HEAPF32[$63>>2] = Math_fround(1.0);
 $64 = (($this) + 1384|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = (($this) + 1508|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 $66 = (($this) + 1540|0);
 $67 = (($this) + 1496|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($this) + 1388|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($this) + 1512|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 $70 = (($this) + 1500|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($this) + 1340|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($this) + 1336|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($this) + 1332|0);
 HEAPF32[$73>>2] = Math_fround(0.0);
 ;HEAP32[$66+0>>2]=0|0;HEAP32[$66+4>>2]=0|0;HEAP32[$66+8>>2]=0|0;HEAP32[$66+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNK13SpeedTreeWind12InTransitionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0);
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1380|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 1492|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $1 != $3;
 if ($4) {
  $20 = 1;
  STACKTOP = sp;return ($20|0);
 }
 $5 = (($this) + 1384|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 1496|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $6 != $8;
 if ($9) {
  $20 = 1;
  STACKTOP = sp;return ($20|0);
 }
 $10 = (($this) + 1388|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 1500|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = $11 != $13;
 if ($14) {
  $20 = 1;
  STACKTOP = sp;return ($20|0);
 }
 $15 = (($this) + 1376|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 1464|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = $16 != $18;
 $20 = $19;
 STACKTOP = sp;return ($20|0);
}
function __ZN13SpeedTreeWind7AdvanceEbd($this,$bEnabled,$fTime) {
 $this = $this|0;
 $bEnabled = $bEnabled|0;
 $fTime = +$fTime;
 var $$pre = 0.0, $0 = 0, $1 = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0.0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0.0, $140 = 0.0, $141 = 0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = Math_fround(0), $146 = 0.0, $147 = 0.0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0.0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = 0.0, $153 = 0.0, $154 = 0, $155 = Math_fround(0), $156 = 0.0, $157 = 0.0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0.0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0.0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0);
 var $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = 0;
 var $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0;
 var $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0);
 var $331 = 0, $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0, $348 = 0, $349 = Math_fround(0);
 var $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0.0, $40 = 0, $400 = 0, $401 = Math_fround(0), $402 = 0;
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = 0, $432 = 0, $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0;
 var $44 = Math_fround(0), $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = 0;
 var $458 = 0, $459 = Math_fround(0), $46 = Math_fround(0), $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = 0, $474 = Math_fround(0), $475 = 0;
 var $476 = 0, $477 = Math_fround(0), $478 = 0, $479 = 0, $48 = 0, $480 = Math_fround(0), $481 = 0, $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = 0, $493 = 0;
 var $494 = Math_fround(0), $495 = 0, $496 = 0, $497 = Math_fround(0), $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = Math_fround(0), $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = Math_fround(0), $520 = 0, $521 = 0, $522 = 0, $523 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0;
 var $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0);
 var $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond = 0, $fDirectionFactor$0 = Math_fround(0), $fInterpolate$0 = Math_fround(0), $fStrengthFactor$0 = Math_fround(0), $i$04 = 0, $nAfter$0 = 0, $nBefore$0 = 0, $storemerge$i = Math_fround(0), $storemerge$i$i = Math_fround(0), dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 1392|0);
 $1 = +HEAPF64[$0>>3];
 $2 = $1 == -1.0;
 if ($2) {
  $3 = (($this) + 1400|0);
  HEAPF64[$3>>3] = 0.0;
 } else {
  $4 = $fTime - $1;
  $5 = (($this) + 1400|0);
  HEAPF64[$5>>3] = $4;
 }
 HEAPF64[$0>>3] = $fTime;
 if (!($bEnabled)) {
  $499 = (($this) + 1640|0);
  HEAPF32[$499>>2] = Math_fround(1.0);
  $500 = (($this) + 1644|0);
  $501 = (($this) + 1664|0);
  ;HEAP32[$500+0>>2]=0|0;HEAP32[$500+4>>2]=0|0;HEAP32[$500+8>>2]=0|0;HEAP32[$500+12>>2]=0|0;HEAP32[$500+16>>2]=0|0;
  HEAPF32[$501>>2] = Math_fround(1.0);
  $502 = (($this) + 1668|0);
  HEAPF32[$502>>2] = Math_fround(1.0);
  $503 = (($this) + 1736|0);
  HEAPF32[$503>>2] = Math_fround(0.0);
  $504 = (($this) + 1672|0);
  $505 = (($this) + 1720|0);
  HEAPF32[$505>>2] = Math_fround(0.0);
  $506 = (($this) + 1724|0);
  HEAPF32[$506>>2] = Math_fround(0.0);
  $507 = (($this) + 1728|0);
  HEAPF32[$507>>2] = Math_fround(0.0);
  $508 = (($this) + 1752|0);
  HEAPF32[$508>>2] = Math_fround(0.0);
  $509 = (($this) + 1756|0);
  HEAPF32[$509>>2] = Math_fround(0.0);
  $510 = (($this) + 1740|0);
  HEAPF32[$510>>2] = Math_fround(0.0);
  $511 = (($this) + 1744|0);
  HEAPF32[$511>>2] = Math_fround(0.0);
  $512 = (($this) + 1768|0);
  HEAPF32[$512>>2] = Math_fround(0.0);
  $513 = (($this) + 1772|0);
  HEAPF32[$513>>2] = Math_fround(0.0);
  $514 = (($this) + 1816|0);
  HEAPF32[$514>>2] = Math_fround(0.0);
  $515 = (($this) + 1820|0);
  HEAPF32[$515>>2] = Math_fround(0.0);
  $516 = (($this) + 1784|0);
  $517 = (($this) + 1832|0);
  $518 = (($this) + 1776|0);
  dest=$504+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  ;HEAP32[$516+0>>2]=0|0;HEAP32[$516+4>>2]=0|0;HEAP32[$516+8>>2]=0|0;HEAP32[$516+12>>2]=0|0;HEAP32[$516+16>>2]=0|0;HEAP32[$516+20>>2]=0|0;HEAP32[$516+24>>2]=0|0;
  ;HEAP32[$517+0>>2]=0|0;HEAP32[$517+4>>2]=0|0;HEAP32[$517+8>>2]=0|0;HEAP32[$517+12>>2]=0|0;HEAP32[$517+16>>2]=0|0;HEAP32[$517+20>>2]=0|0;HEAP32[$517+24>>2]=0|0;
  HEAPF32[$518>>2] = Math_fround(1.0);
  $519 = (($this) + 1824|0);
  HEAPF32[$519>>2] = Math_fround(1.0);
  $520 = (($this) + 1864|0);
  HEAPF32[$520>>2] = Math_fround(0.0);
  $521 = (($this) + 1868|0);
  HEAPF32[$521>>2] = Math_fround(0.0);
  $522 = (($this) + 1872|0);
  HEAPF32[$522>>2] = Math_fround(0.0);
  $523 = (($this) + 1876|0);
  HEAPF32[$523>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
 $6 = (($this) + 1408|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  __ZN13SpeedTreeWind4GustEd($this,$fTime);
 }
 $9 = (($this) + 1528|0);
 $10 = +HEAPF64[$9>>3];
 $11 = (($this) + 1520|0);
 $12 = +HEAPF64[$11>>3];
 $13 = $10 != $12;
 if ($13) {
  $14 = $fTime - $12;
  $15 = $10 - $12;
  $16 = $14 / $15;
  $17 = $16 > 0.0;
  $18 = $17 ? $16 : 0.0;
  $19 = $18 < 1.0;
  $20 = Math_fround($18);
  $21 = $19 ? $20 : Math_fround(1.0);
  $fDirectionFactor$0 = $21;
 } else {
  $fDirectionFactor$0 = Math_fround(1.0);
 }
 $22 = Math_fround($fDirectionFactor$0 * $fDirectionFactor$0);
 $23 = Math_fround($fDirectionFactor$0 * Math_fround(2.0));
 $24 = Math_fround(Math_fround(3.0) - $23);
 $25 = Math_fround($22 * $24);
 $26 = Math_fround($25 * Math_fround(0.5));
 $27 = Math_fround($fDirectionFactor$0 * Math_fround(0.5));
 $28 = Math_fround($27 + $26);
 $29 = $28 < Math_fround(0.5);
 if ($29) {
  $30 = Math_fround($28 * Math_fround(2.0));
  $31 = (($this) + 1536|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($this) + 1504|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround(Math_fround(1.0) - $30);
  $36 = Math_fround($35 * $32);
  $37 = Math_fround($30 * $34);
  $38 = Math_fround($36 + $37);
  $39 = (($this) + 1380|0);
  HEAPF32[$39>>2] = $38;
  $40 = (($this) + 1540|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($this) + 1508|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($35 * $41);
  $45 = Math_fround($30 * $43);
  $46 = Math_fround($44 + $45);
  $47 = (($this) + 1384|0);
  HEAPF32[$47>>2] = $46;
  $48 = (($this) + 1544|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($this) + 1512|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($35 * $49);
  $53 = Math_fround($30 * $51);
  $54 = Math_fround($52 + $53);
  $55 = (($this) + 1388|0);
  HEAPF32[$55>>2] = $54;
  $85 = $38;$88 = $46;$92 = $54;
 } else {
  $56 = Math_fround($28 + Math_fround(-0.5));
  $57 = Math_fround($56 * Math_fround(2.0));
  $58 = (($this) + 1504|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($this) + 1492|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround(Math_fround(1.0) - $57);
  $63 = Math_fround($62 * $59);
  $64 = Math_fround($57 * $61);
  $65 = Math_fround($63 + $64);
  $66 = (($this) + 1380|0);
  HEAPF32[$66>>2] = $65;
  $67 = (($this) + 1508|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($this) + 1496|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($62 * $68);
  $72 = Math_fround($57 * $70);
  $73 = Math_fround($71 + $72);
  $74 = (($this) + 1384|0);
  HEAPF32[$74>>2] = $73;
  $75 = (($this) + 1512|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($this) + 1500|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($62 * $76);
  $80 = Math_fround($57 * $78);
  $81 = Math_fround($79 + $80);
  $82 = (($this) + 1388|0);
  HEAPF32[$82>>2] = $81;
  $85 = $65;$88 = $73;$92 = $81;
 }
 $83 = (($this) + 1380|0);
 $84 = Math_fround($85 * $85);
 $86 = (($this) + 1384|0);
 $87 = Math_fround($88 * $88);
 $89 = Math_fround($84 + $87);
 $90 = (($this) + 1388|0);
 $91 = Math_fround($92 * $92);
 $93 = Math_fround($89 + $91);
 $94 = (Math_fround(Math_sqrt((Math_fround($93)))));
 $95 = $94 != Math_fround(0.0);
 if ($95) {
  $96 = Math_fround($85 / $94);
  HEAPF32[$83>>2] = $96;
  $97 = Math_fround($88 / $94);
  HEAPF32[$86>>2] = $97;
  $98 = Math_fround($92 / $94);
  $136 = $96;$150 = $97;$storemerge$i = $98;
 } else {
  HEAPF32[$83>>2] = Math_fround(0.0);
  HEAPF32[$86>>2] = Math_fround(0.0);
  $136 = Math_fround(0.0);$150 = Math_fround(0.0);$storemerge$i = Math_fround(0.0);
 }
 HEAPF32[$90>>2] = $storemerge$i;
 $99 = (($this) + 1480|0);
 $100 = +HEAPF64[$99>>3];
 $101 = (($this) + 1472|0);
 $102 = +HEAPF64[$101>>3];
 $103 = $100 != $102;
 if ($103) {
  $104 = $fTime - $102;
  $105 = $100 - $102;
  $106 = $104 / $105;
  $107 = $106 > 0.0;
  $108 = $107 ? $106 : 0.0;
  $109 = $108 < 1.0;
  $110 = Math_fround($108);
  $111 = $109 ? $110 : Math_fround(1.0);
  $fStrengthFactor$0 = $111;
 } else {
  $fStrengthFactor$0 = Math_fround(0.0);
 }
 $112 = (($this) + 1488|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($this) + 1464|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($fStrengthFactor$0 * $fStrengthFactor$0);
 $117 = Math_fround($fStrengthFactor$0 * Math_fround(2.0));
 $118 = Math_fround(Math_fround(3.0) - $117);
 $119 = Math_fround($116 * $118);
 $120 = Math_fround($fStrengthFactor$0 * Math_fround(0.0));
 $121 = Math_fround($120 + $119);
 $122 = Math_fround(Math_fround(1.0) - $121);
 $123 = Math_fround($113 * $122);
 $124 = Math_fround($115 * $121);
 $125 = Math_fround($124 + $123);
 $126 = (($this) + 1376|0);
 HEAPF32[$126>>2] = $125;
 $127 = (($this) + 1412|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($128 + $125);
 $130 = $129 < Math_fround(1.0);
 $131 = $130 ? $129 : Math_fround(1.0);
 $132 = $131 > Math_fround(0.0);
 $133 = $132 ? $131 : Math_fround(0.0);
 $134 = (($this) + 1556|0);
 HEAPF32[$134>>2] = $133;
 $135 = Math_fround($136 * $133);
 $137 = (($this) + 1280|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($138 * $135);
 $140 = +$139;
 $141 = (($this) + 1400|0);
 $142 = +HEAPF64[$141>>3];
 $143 = $142 * $140;
 $144 = (($this) + 1548|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = +$145;
 $147 = $146 + $143;
 $148 = Math_fround($147);
 HEAPF32[$144>>2] = $148;
 $149 = Math_fround($150 * $133);
 $151 = Math_fround($149 * $138);
 $152 = +$151;
 $153 = $142 * $152;
 $154 = (($this) + 1552|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = +$155;
 $157 = $156 + $153;
 $158 = Math_fround($157);
 HEAPF32[$154>>2] = $158;
 $159 = Math_fround($133 * Math_fround(9.0));
 $160 = (~~(($159)));
 $161 = (($160) + 1)|0;
 $162 = ($160|0)>(8);
 if ($162) {
  $fInterpolate$0 = Math_fround(0.0);$nAfter$0 = 9;$nBefore$0 = 9;
 } else {
  $163 = ($160|0)<(0);
  if ($163) {
   $fInterpolate$0 = Math_fround(0.0);$nAfter$0 = 0;$nBefore$0 = 0;
  } else {
   $164 = (Math_fround(($160|0)));
   $165 = Math_fround($159 - $164);
   $fInterpolate$0 = $165;$nAfter$0 = $161;$nBefore$0 = $160;
  }
 }
 $166 = Math_fround(Math_fround(1.0) - $fInterpolate$0);
 $176 = $142;$i$04 = 0;
 while(1) {
  $167 = (((($this) + (($i$04*40)|0)|0) + ($nBefore$0<<2)|0) + 16|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (((($this) + (($i$04*40)|0)|0) + ($nAfter$0<<2)|0) + 16|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround($166 * $168);
  $172 = Math_fround($fInterpolate$0 * $170);
  $173 = Math_fround($171 + $172);
  $174 = +$173;
  $175 = $176 * $174;
  $177 = Math_fround($175);
  $178 = ((($this) + ($i$04<<2)|0) + 1560|0);
  HEAPF32[$178>>2] = $177;
  $179 = ((($this) + ($i$04<<2)|0) + 1600|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = Math_fround($180 + $177);
  HEAPF32[$179>>2] = $181;
  $182 = (($i$04) + 1)|0;
  $exitcond = ($182|0)==(10);
  if ($exitcond) {
   break;
  }
  $$pre = +HEAPF64[$141>>3];
  $176 = $$pre;$i$04 = $182;
 }
 $183 = Math_fround(HEAPF32[$83>>2]);
 $184 = (($this) + 1640|0);
 HEAPF32[$184>>2] = $183;
 $185 = Math_fround(HEAPF32[$86>>2]);
 $186 = (($this) + 1644|0);
 HEAPF32[$186>>2] = $185;
 $187 = Math_fround(HEAPF32[$90>>2]);
 $188 = (($this) + 1648|0);
 HEAPF32[$188>>2] = $187;
 $189 = Math_fround(HEAPF32[$134>>2]);
 $190 = (($this) + 1652|0);
 HEAPF32[$190>>2] = $189;
 $191 = ((($this) + ($nBefore$0<<2)|0) + 424|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = ((($this) + ($nAfter$0<<2)|0) + 424|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = Math_fround($166 * $192);
 $196 = Math_fround($fInterpolate$0 * $194);
 $197 = Math_fround($195 + $196);
 $198 = (($this) + 1660|0);
 HEAPF32[$198>>2] = $197;
 $199 = (($this) + 1600|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = (($this) + 1656|0);
 HEAPF32[$201>>2] = $200;
 $202 = (($this) + 416|0);
 $203 = Math_fround(HEAPF32[$202>>2]);
 $204 = $203 != Math_fround(0.0);
 if ($204) {
  $205 = Math_fround(Math_fround(1.0) / $203);
  $207 = $205;
 } else {
  $207 = Math_fround(1.0);
 }
 $206 = (($this) + 1664|0);
 HEAPF32[$206>>2] = $207;
 $208 = (($this) + 420|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = (($this) + 1668|0);
 HEAPF32[$210>>2] = $209;
 $211 = ((($this) + ($nBefore$0<<2)|0) + 464|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = ((($this) + ($nAfter$0<<2)|0) + 464|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = Math_fround($166 * $212);
 $216 = Math_fround($fInterpolate$0 * $214);
 $217 = Math_fround($215 + $216);
 $218 = (($this) + 1736|0);
 HEAPF32[$218>>2] = $217;
 $219 = ((($this) + ($nBefore$0<<2)|0) + 504|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = ((($this) + ($nAfter$0<<2)|0) + 504|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = Math_fround($166 * $220);
 $224 = Math_fround($fInterpolate$0 * $222);
 $225 = Math_fround($223 + $224);
 $226 = (($this) + 1676|0);
 HEAPF32[$226>>2] = $225;
 $227 = (($this) + 1604|0);
 $228 = Math_fround(HEAPF32[$227>>2]);
 $229 = (($this) + 1672|0);
 HEAPF32[$229>>2] = $228;
 $230 = ((($this) + ($nBefore$0<<2)|0) + 636|0);
 $231 = Math_fround(HEAPF32[$230>>2]);
 $232 = ((($this) + ($nAfter$0<<2)|0) + 636|0);
 $233 = Math_fround(HEAPF32[$232>>2]);
 $234 = Math_fround($166 * $231);
 $235 = Math_fround($fInterpolate$0 * $233);
 $236 = Math_fround($234 + $235);
 $237 = (($this) + 1684|0);
 HEAPF32[$237>>2] = $236;
 $238 = (($this) + 1608|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($this) + 1680|0);
 HEAPF32[$240>>2] = $239;
 $241 = (($this) + 8|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 $243 = Math_fround($185 + $242);
 $244 = Math_fround($183 * $183);
 $245 = Math_fround($243 * $243);
 $246 = Math_fround($244 + $245);
 $247 = Math_fround($187 * $187);
 $248 = Math_fround($247 + $246);
 $249 = (Math_fround(Math_sqrt((Math_fround($248)))));
 $250 = $249 != Math_fround(0.0);
 if ($250) {
  $251 = Math_fround($183 / $249);
  $252 = Math_fround($243 / $249);
  $253 = Math_fround($187 / $249);
  $259 = $251;$267 = $252;$storemerge$i$i = $253;
 } else {
  $259 = Math_fround(0.0);$267 = Math_fround(0.0);$storemerge$i$i = Math_fround(0.0);
 }
 $254 = (($this) + 1332|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = (($this) + 1344|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = Math_fround($259 * $257);
 $260 = (($this) + 12|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = Math_fround($258 * $261);
 $263 = Math_fround($255 + $262);
 $264 = (($this) + 1336|0);
 $265 = Math_fround(HEAPF32[$264>>2]);
 $266 = Math_fround($267 * $257);
 $268 = Math_fround($266 * $261);
 $269 = Math_fround($265 + $268);
 $270 = (($this) + 1340|0);
 $271 = Math_fround(HEAPF32[$270>>2]);
 $272 = Math_fround($storemerge$i$i * $257);
 $273 = Math_fround($272 * $261);
 $274 = Math_fround($273 + $271);
 $275 = Math_fround($263 * $263);
 $276 = Math_fround($269 * $269);
 $277 = Math_fround($275 + $276);
 $278 = Math_fround($274 * $274);
 $279 = Math_fround($277 + $278);
 $280 = (Math_fround(Math_sqrt((Math_fround($279)))));
 $281 = $280 == Math_fround(0.0);
 if ($281) {
  $282 = (($this) + 1720|0);
  ;HEAP32[$282+0>>2]=0|0;HEAP32[$282+4>>2]=0|0;HEAP32[$282+8>>2]=0|0;HEAP32[$282+12>>2]=0|0;
 } else {
  $283 = Math_fround($263 / $280);
  $284 = (($this) + 1720|0);
  HEAPF32[$284>>2] = $283;
  $285 = Math_fround($269 / $280);
  $286 = (($this) + 1724|0);
  HEAPF32[$286>>2] = $285;
  $287 = Math_fround($274 / $280);
  $288 = (($this) + 1728|0);
  HEAPF32[$288>>2] = $287;
  $289 = (($this) + 1732|0);
  HEAPF32[$289>>2] = $280;
 }
 $290 = ((($this) + ($nBefore$0<<2)|0) + 544|0);
 $291 = Math_fround(HEAPF32[$290>>2]);
 $292 = ((($this) + ($nAfter$0<<2)|0) + 544|0);
 $293 = Math_fround(HEAPF32[$292>>2]);
 $294 = Math_fround($166 * $291);
 $295 = Math_fround($fInterpolate$0 * $293);
 $296 = Math_fround($294 + $295);
 $297 = (($this) + 1740|0);
 HEAPF32[$297>>2] = $296;
 $298 = (($this) + 1351|0);
 $299 = HEAP8[$298>>0]|0;
 $300 = ($299<<24>>24)==(0);
 if (!($300)) {
  $301 = Math_fround($296 * $257);
  HEAPF32[$297>>2] = $301;
 }
 $302 = (($this) + 624|0);
 $303 = Math_fround(HEAPF32[$302>>2]);
 $304 = (($this) + 1752|0);
 HEAPF32[$304>>2] = $303;
 $305 = ((($this) + ($nBefore$0<<2)|0) + 676|0);
 $306 = Math_fround(HEAPF32[$305>>2]);
 $307 = ((($this) + ($nAfter$0<<2)|0) + 676|0);
 $308 = Math_fround(HEAPF32[$307>>2]);
 $309 = Math_fround($166 * $306);
 $310 = Math_fround($fInterpolate$0 * $308);
 $311 = Math_fround($309 + $310);
 $312 = (($this) + 1744|0);
 HEAPF32[$312>>2] = $311;
 $313 = (($this) + 1357|0);
 $314 = HEAP8[$313>>0]|0;
 $315 = ($314<<24>>24)==(0);
 if (!($315)) {
  $316 = Math_fround($311 * $257);
  HEAPF32[$312>>2] = $316;
 }
 $317 = (($this) + 756|0);
 $318 = Math_fround(HEAPF32[$317>>2]);
 $319 = (($this) + 1756|0);
 HEAPF32[$319>>2] = $318;
 $320 = (($this) + 628|0);
 $321 = Math_fround(HEAPF32[$320>>2]);
 $322 = (($this) + 1688|0);
 HEAPF32[$322>>2] = $321;
 $323 = (($this) + 632|0);
 $324 = Math_fround(HEAPF32[$323>>2]);
 $325 = (($this) + 1692|0);
 HEAPF32[$325>>2] = $324;
 $326 = (($this) + 760|0);
 $327 = Math_fround(HEAPF32[$326>>2]);
 $328 = (($this) + 1696|0);
 HEAPF32[$328>>2] = $327;
 $329 = (($this) + 764|0);
 $330 = Math_fround(HEAPF32[$329>>2]);
 $331 = (($this) + 1700|0);
 HEAPF32[$331>>2] = $330;
 $332 = ((($this) + ($nBefore$0<<2)|0) + 584|0);
 $333 = Math_fround(HEAPF32[$332>>2]);
 $334 = ((($this) + ($nAfter$0<<2)|0) + 584|0);
 $335 = Math_fround(HEAPF32[$334>>2]);
 $336 = Math_fround($166 * $333);
 $337 = Math_fround($fInterpolate$0 * $335);
 $338 = Math_fround($336 + $337);
 $339 = (($this) + 1704|0);
 HEAPF32[$339>>2] = $338;
 $340 = ((($this) + ($nBefore$0<<2)|0) + 716|0);
 $341 = Math_fround(HEAPF32[$340>>2]);
 $342 = ((($this) + ($nAfter$0<<2)|0) + 716|0);
 $343 = Math_fround(HEAPF32[$342>>2]);
 $344 = Math_fround($166 * $341);
 $345 = Math_fround($fInterpolate$0 * $343);
 $346 = Math_fround($344 + $345);
 $347 = (($this) + 1708|0);
 HEAPF32[$347>>2] = $346;
 $348 = (($this) + 1612|0);
 $349 = Math_fround(HEAPF32[$348>>2]);
 $350 = (($this) + 1768|0);
 HEAPF32[$350>>2] = $349;
 $351 = ((($this) + ($nBefore$0<<2)|0) + 768|0);
 $352 = Math_fround(HEAPF32[$351>>2]);
 $353 = ((($this) + ($nAfter$0<<2)|0) + 768|0);
 $354 = Math_fround(HEAPF32[$353>>2]);
 $355 = Math_fround($166 * $352);
 $356 = Math_fround($fInterpolate$0 * $354);
 $357 = Math_fround($355 + $356);
 $358 = (($this) + 1772|0);
 HEAPF32[$358>>2] = $357;
 $359 = (($this) + 1624|0);
 $360 = Math_fround(HEAPF32[$359>>2]);
 $361 = (($this) + 1816|0);
 HEAPF32[$361>>2] = $360;
 $362 = ((($this) + ($nBefore$0<<2)|0) + 992|0);
 $363 = Math_fround(HEAPF32[$362>>2]);
 $364 = ((($this) + ($nAfter$0<<2)|0) + 992|0);
 $365 = Math_fround(HEAPF32[$364>>2]);
 $366 = Math_fround($166 * $363);
 $367 = Math_fround($fInterpolate$0 * $365);
 $368 = Math_fround($366 + $367);
 $369 = (($this) + 1820|0);
 HEAPF32[$369>>2] = $368;
 $370 = (($this) + 1616|0);
 $371 = Math_fround(HEAPF32[$370>>2]);
 $372 = (($this) + 1784|0);
 HEAPF32[$372>>2] = $371;
 $373 = ((($this) + ($nBefore$0<<2)|0) + 808|0);
 $374 = Math_fround(HEAPF32[$373>>2]);
 $375 = ((($this) + ($nAfter$0<<2)|0) + 808|0);
 $376 = Math_fround(HEAPF32[$375>>2]);
 $377 = Math_fround($166 * $374);
 $378 = Math_fround($fInterpolate$0 * $376);
 $379 = Math_fround($377 + $378);
 $380 = (($this) + 1788|0);
 HEAPF32[$380>>2] = $379;
 $381 = ((($this) + ($nBefore$0<<2)|0) + 848|0);
 $382 = Math_fround(HEAPF32[$381>>2]);
 $383 = ((($this) + ($nAfter$0<<2)|0) + 848|0);
 $384 = Math_fround(HEAPF32[$383>>2]);
 $385 = Math_fround($166 * $382);
 $386 = Math_fround($fInterpolate$0 * $384);
 $387 = Math_fround($385 + $386);
 $388 = (($this) + 1792|0);
 HEAPF32[$388>>2] = $387;
 $389 = ((($this) + ($nBefore$0<<2)|0) + 888|0);
 $390 = Math_fround(HEAPF32[$389>>2]);
 $391 = ((($this) + ($nAfter$0<<2)|0) + 888|0);
 $392 = Math_fround(HEAPF32[$391>>2]);
 $393 = Math_fround($166 * $390);
 $394 = Math_fround($fInterpolate$0 * $392);
 $395 = Math_fround($393 + $394);
 $396 = (($this) + 1796|0);
 HEAPF32[$396>>2] = $395;
 $397 = (($this) + 1628|0);
 $398 = Math_fround(HEAPF32[$397>>2]);
 $399 = (($this) + 1832|0);
 HEAPF32[$399>>2] = $398;
 $400 = ((($this) + ($nBefore$0<<2)|0) + 1032|0);
 $401 = Math_fround(HEAPF32[$400>>2]);
 $402 = ((($this) + ($nAfter$0<<2)|0) + 1032|0);
 $403 = Math_fround(HEAPF32[$402>>2]);
 $404 = Math_fround($166 * $401);
 $405 = Math_fround($fInterpolate$0 * $403);
 $406 = Math_fround($404 + $405);
 $407 = (($this) + 1836|0);
 HEAPF32[$407>>2] = $406;
 $408 = ((($this) + ($nBefore$0<<2)|0) + 1072|0);
 $409 = Math_fround(HEAPF32[$408>>2]);
 $410 = ((($this) + ($nAfter$0<<2)|0) + 1072|0);
 $411 = Math_fround(HEAPF32[$410>>2]);
 $412 = Math_fround($166 * $409);
 $413 = Math_fround($fInterpolate$0 * $411);
 $414 = Math_fround($412 + $413);
 $415 = (($this) + 1840|0);
 HEAPF32[$415>>2] = $414;
 $416 = ((($this) + ($nBefore$0<<2)|0) + 1112|0);
 $417 = Math_fround(HEAPF32[$416>>2]);
 $418 = ((($this) + ($nAfter$0<<2)|0) + 1112|0);
 $419 = Math_fround(HEAPF32[$418>>2]);
 $420 = Math_fround($166 * $417);
 $421 = Math_fround($fInterpolate$0 * $419);
 $422 = Math_fround($420 + $421);
 $423 = (($this) + 1844|0);
 HEAPF32[$423>>2] = $422;
 $424 = ((($this) + ($nBefore$0<<2)|0) + 928|0);
 $425 = Math_fround(HEAPF32[$424>>2]);
 $426 = ((($this) + ($nAfter$0<<2)|0) + 928|0);
 $427 = Math_fround(HEAPF32[$426>>2]);
 $428 = Math_fround($166 * $425);
 $429 = Math_fround($fInterpolate$0 * $427);
 $430 = Math_fround($428 + $429);
 $431 = (($this) + 1800|0);
 HEAPF32[$431>>2] = $430;
 $432 = ((($this) + ($nBefore$0<<2)|0) + 216|0);
 $433 = Math_fround(HEAPF32[$432>>2]);
 $434 = ((($this) + ($nAfter$0<<2)|0) + 216|0);
 $435 = Math_fround(HEAPF32[$434>>2]);
 $436 = Math_fround($166 * $433);
 $437 = Math_fround($fInterpolate$0 * $435);
 $438 = Math_fround($436 + $437);
 $439 = $438 < Math_fround(1.1920928955078125E-7);
 if ($439) {
  $440 = (($this) + 1804|0);
  HEAPF32[$440>>2] = Math_fround(0.0);
 } else {
  $441 = Math_fround(Math_fround(1.0) / $438);
  $442 = (($this) + 968|0);
  $443 = Math_fround(HEAPF32[$442>>2]);
  $444 = Math_fround($441 * $443);
  $445 = Math_fround($444 * Math_fround(10.0));
  $446 = (($this) + 1804|0);
  HEAPF32[$446>>2] = $445;
 }
 $447 = (($this) + 1620|0);
 $448 = Math_fround(HEAPF32[$447>>2]);
 $449 = (($this) + 1808|0);
 HEAPF32[$449>>2] = $448;
 $450 = ((($this) + ($nBefore$0<<2)|0) + 1152|0);
 $451 = Math_fround(HEAPF32[$450>>2]);
 $452 = ((($this) + ($nAfter$0<<2)|0) + 1152|0);
 $453 = Math_fround(HEAPF32[$452>>2]);
 $454 = Math_fround($166 * $451);
 $455 = Math_fround($fInterpolate$0 * $453);
 $456 = Math_fround($454 + $455);
 $457 = (($this) + 1848|0);
 HEAPF32[$457>>2] = $456;
 $458 = ((($this) + ($nBefore$0<<2)|0) + 336|0);
 $459 = Math_fround(HEAPF32[$458>>2]);
 $460 = ((($this) + ($nAfter$0<<2)|0) + 336|0);
 $461 = Math_fround(HEAPF32[$460>>2]);
 $462 = Math_fround($166 * $459);
 $463 = Math_fround($fInterpolate$0 * $461);
 $464 = Math_fround($462 + $463);
 $465 = $464 < Math_fround(1.1920928955078125E-7);
 if ($465) {
  $466 = (($this) + 1852|0);
  HEAPF32[$466>>2] = Math_fround(0.0);
 } else {
  $467 = Math_fround(Math_fround(1.0) / $464);
  $468 = (($this) + 1192|0);
  $469 = Math_fround(HEAPF32[$468>>2]);
  $470 = Math_fround($467 * $469);
  $471 = Math_fround($470 * Math_fround(10.0));
  $472 = (($this) + 1852|0);
  HEAPF32[$472>>2] = $471;
 }
 $473 = (($this) + 1632|0);
 $474 = Math_fround(HEAPF32[$473>>2]);
 $475 = (($this) + 1856|0);
 HEAPF32[$475>>2] = $474;
 $476 = (($this) + 988|0);
 $477 = Math_fround(HEAPF32[$476>>2]);
 $478 = (($this) + 1776|0);
 HEAPF32[$478>>2] = $477;
 $479 = (($this) + 1212|0);
 $480 = Math_fround(HEAPF32[$479>>2]);
 $481 = (($this) + 1824|0);
 HEAPF32[$481>>2] = $480;
 $482 = (($this) + 1636|0);
 $483 = Math_fround(HEAPF32[$482>>2]);
 $484 = (($this) + 1864|0);
 HEAPF32[$484>>2] = $483;
 $485 = ((($this) + ($nBefore$0<<2)|0) + 1216|0);
 $486 = Math_fround(HEAPF32[$485>>2]);
 $487 = ((($this) + ($nAfter$0<<2)|0) + 1216|0);
 $488 = Math_fround(HEAPF32[$487>>2]);
 $489 = Math_fround($166 * $486);
 $490 = Math_fround($fInterpolate$0 * $488);
 $491 = Math_fround($489 + $490);
 $492 = (($this) + 1868|0);
 HEAPF32[$492>>2] = $491;
 $493 = (($this) + 1256|0);
 $494 = Math_fround(HEAPF32[$493>>2]);
 $495 = (($this) + 1872|0);
 HEAPF32[$495>>2] = $494;
 $496 = (($this) + 1260|0);
 $497 = Math_fround(HEAPF32[$496>>2]);
 $498 = (($this) + 1876|0);
 HEAPF32[$498>>2] = $497;
 STACKTOP = sp;return;
}
function __ZN13SpeedTreeWind4GustEd($this,$fTime) {
 $this = $this|0;
 $fTime = +$fTime;
 var $$pre = 0.0, $$pre$i = 0, $$pre$i1 = 0, $$pre$i13 = 0, $$pre$i19 = 0, $$pre$i7 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $$pre1$i2 = 0, $$pre1$i20 = 0, $$pre1$i8 = 0, $$pre2$i = 0, $$pre2$i15 = 0, $$pre2$i21 = 0, $$pre2$i3 = 0, $$pre2$i9 = 0, $$pre3$i = 0, $$pre3$i16 = 0, $0 = 0, $1 = 0.0;
 var $10 = 0.0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0);
 var $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = 0.0, $152 = 0.0, $153 = 0;
 var $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0);
 var $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0.0, $213 = 0.0, $214 = 0, $215 = 0.0, $216 = 0, $217 = 0, $218 = 0.0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0.0, $222 = Math_fround(0), $223 = 0, $224 = 0.0, $225 = 0.0;
 var $226 = 0.0, $227 = 0.0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0;
 var $244 = 0, $245 = 0.0, $246 = 0, $247 = 0.0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0.0, $252 = Math_fround(0), $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0.0, $34 = 0, $35 = Math_fround(0), $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0.0, $45 = 0, $46 = 0, $47 = Math_fround(0);
 var $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0.0, $70 = Math_fround(0), $71 = 0.0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0.0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0;
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1432|0);
 $1 = +HEAPF64[$0>>3];
 $2 = $1 < $fTime;
 if ($2) {
  label = 4;
 } else {
  $3 = (($this) + 1456|0);
  $4 = +HEAPF64[$3>>3];
  $5 = $4 > $fTime;
  if ($5) {
   $6 = (($this) + 1424|0);
   $7 = +HEAPF64[$6>>3];
   $8 = $7 < $fTime;
   if ($8) {
    label = 4;
   }
  }
 }
 if ((label|0) == 4) {
  $9 = (($this) + 1400|0);
  $10 = +HEAPF64[$9>>3];
  $11 = Math_fround($10);
  $12 = HEAP8[582928>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   HEAP32[582896>>2] = 0;
   HEAP32[582904>>2] = 1;
   HEAP32[582912>>2] = 1812433254;
   HEAP32[582920>>2] = 1900727103;
   $14 = 582928;
   $15 = $14;
   HEAP32[$15>>2] = 1;
   $16 = (($14) + 4)|0;
   $17 = $16;
   HEAP32[$17>>2] = 0;
   $$pre = +HEAPF64[$9>>3];
   $$pre$i1 = 1;$$pre1$i2 = 1812433254;$$pre2$i3 = 1900727103;$19 = 0;$38 = $$pre;
  } else {
   $$pre$i = HEAP32[582896>>2]|0;
   $$pre1$i = HEAP32[582904>>2]|0;
   $$pre2$i = HEAP32[582912>>2]|0;
   $$pre3$i = HEAP32[582920>>2]|0;
   $$pre$i1 = $$pre1$i;$$pre1$i2 = $$pre2$i;$$pre2$i3 = $$pre3$i;$19 = $$pre$i;$38 = $10;
  }
  $18 = $19 << 11;
  $20 = $18 ^ $19;
  HEAP32[582896>>2] = $$pre$i1;
  HEAP32[582904>>2] = $$pre1$i2;
  HEAP32[582912>>2] = $$pre2$i3;
  $21 = $$pre2$i3 >>> 19;
  $22 = $20 >>> 8;
  $23 = $21 ^ $$pre2$i3;
  $24 = $23 ^ $20;
  $25 = $24 ^ $22;
  HEAP32[582920>>2] = $25;
  $26 = $25 & 8388607;
  $27 = (Math_fround(($26>>>0)));
  $28 = Math_fround($27 * Math_fround(1.19209303761635965202E-7));
  $29 = Math_fround($28 * Math_fround(0.0));
  $30 = Math_fround(Math_fround(1.0) - $28);
  $31 = Math_fround($11 * $30);
  $32 = Math_fround($29 + $31);
  $33 = +$32;
  $34 = (($this) + 1304|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = +$35;
  $37 = $38 * $36;
  $39 = $37 * 0.00999999977648258209228;
  $40 = $33 < $39;
  if ($40) {
   $41 = (($this) + 1440|0);
   HEAPF64[$41>>3] = $fTime;
   $42 = (($this) + 1412|0);
   $43 = Math_fround(HEAPF32[$42>>2]);
   $44 = +$43;
   $45 = (($this) + 1448|0);
   HEAPF64[$45>>3] = $44;
   $46 = (($this) + 1308|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = (($this) + 1312|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = HEAP8[582928>>0]|0;
   $51 = ($50<<24>>24)==(0);
   if ($51) {
    HEAP32[582896>>2] = 0;
    HEAP32[582904>>2] = 1;
    HEAP32[582912>>2] = 1812433254;
    HEAP32[582920>>2] = 1900727103;
    $52 = 582928;
    $53 = $52;
    HEAP32[$53>>2] = 1;
    $54 = (($52) + 4)|0;
    $55 = $54;
    HEAP32[$55>>2] = 0;
    $$pre$i19 = 1;$$pre1$i20 = 1812433254;$$pre2$i21 = 1900727103;$57 = 0;
   } else {
    $$pre$i19 = $$pre1$i2;$$pre1$i20 = $$pre2$i3;$$pre2$i21 = $25;$57 = $$pre$i1;
   }
   $56 = $57 << 11;
   $58 = $56 ^ $57;
   HEAP32[582896>>2] = $$pre$i19;
   HEAP32[582904>>2] = $$pre1$i20;
   HEAP32[582912>>2] = $$pre2$i21;
   $59 = $$pre2$i21 >>> 19;
   $60 = $58 >>> 8;
   $61 = $59 ^ $$pre2$i21;
   $62 = $61 ^ $58;
   $63 = $62 ^ $60;
   HEAP32[582920>>2] = $63;
   $64 = $63 & 8388607;
   $65 = (Math_fround(($64>>>0)));
   $66 = Math_fround($65 * Math_fround(1.19209303761635965202E-7));
   $67 = Math_fround($47 * $66);
   $68 = Math_fround(Math_fround(1.0) - $66);
   $69 = Math_fround($49 * $68);
   $70 = Math_fround($67 + $69);
   $71 = +$70;
   $72 = (($this) + 1416|0);
   HEAPF64[$72>>3] = $71;
   $73 = (($this) + 1376|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = Math_fround(Math_fround(1.0) - $74);
   $76 = $70 > $75;
   if ($76) {
    $77 = +$75;
    HEAPF64[$72>>3] = $77;
    $82 = $77;
   } else {
    $82 = $71;
   }
   $78 = Math_fround(HEAPF32[$this>>2]);
   $79 = Math_fround($78 * Math_fround(0.5));
   $80 = +$74;
   $81 = $82 - $80;
   $83 = (+Math_abs((+$81)));
   $84 = Math_fround($83);
   $85 = Math_fround(Math_fround(1.0) - $84);
   $86 = Math_fround($79 * $85);
   $87 = Math_fround($78 * $84);
   $88 = Math_fround($87 + $86);
   $89 = Math_fround(HEAPF32[$42>>2]);
   $90 = +$89;
   $91 = $82 > $90;
   if ($91) {
    $92 = (($this) + 1324|0);
    $93 = Math_fround(HEAPF32[$92>>2]);
    $94 = Math_fround($88 * Math_fround(2.0));
    $95 = HEAP8[582928>>0]|0;
    $96 = ($95<<24>>24)==(0);
    if ($96) {
     HEAP32[582896>>2] = 0;
     HEAP32[582904>>2] = 1;
     HEAP32[582912>>2] = 1812433254;
     HEAP32[582920>>2] = 1900727103;
     $97 = 582928;
     $98 = $97;
     HEAP32[$98>>2] = 1;
     $99 = (($97) + 4)|0;
     $100 = $99;
     HEAP32[$100>>2] = 0;
     $102 = 0;$104 = 1;$105 = 1812433254;$106 = 1900727103;
    } else {
     $102 = $$pre$i19;$104 = $$pre1$i20;$105 = $$pre2$i21;$106 = $63;
    }
    $101 = $102 << 11;
    $103 = $101 ^ $102;
    HEAP32[582896>>2] = $104;
    HEAP32[582904>>2] = $105;
    HEAP32[582912>>2] = $106;
    $107 = $106 >>> 19;
    $108 = $103 >>> 8;
    $109 = $107 ^ $106;
    $110 = $109 ^ $103;
    $111 = $110 ^ $108;
    HEAP32[582920>>2] = $111;
    $112 = $111 & 8388607;
    $113 = (Math_fround(($112>>>0)));
    $114 = Math_fround($113 * Math_fround(1.19209303761635965202E-7));
    $115 = Math_fround($88 * $114);
    $116 = Math_fround(Math_fround(1.0) - $114);
    $117 = Math_fround($94 * $116);
    $118 = Math_fround($115 + $117);
    $119 = Math_fround($93 * $118);
    $120 = +$119;
    $121 = $120 + $fTime;
    $122 = (($this) + 1424|0);
    HEAPF64[$122>>3] = $121;
    $$pre$i13 = $104;$$pre1$i14 = $105;$$pre2$i15 = $106;$$pre3$i16 = $111;$181 = $121;
   } else {
    $123 = (($this) + 1328|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = Math_fround($88 * Math_fround(2.0));
    $126 = HEAP8[582928>>0]|0;
    $127 = ($126<<24>>24)==(0);
    if ($127) {
     HEAP32[582896>>2] = 0;
     HEAP32[582904>>2] = 1;
     HEAP32[582912>>2] = 1812433254;
     HEAP32[582920>>2] = 1900727103;
     $128 = 582928;
     $129 = $128;
     HEAP32[$129>>2] = 1;
     $130 = (($128) + 4)|0;
     $131 = $130;
     HEAP32[$131>>2] = 0;
     $133 = 0;$135 = 1;$136 = 1812433254;$137 = 1900727103;
    } else {
     $133 = $$pre$i19;$135 = $$pre1$i20;$136 = $$pre2$i21;$137 = $63;
    }
    $132 = $133 << 11;
    $134 = $132 ^ $133;
    HEAP32[582896>>2] = $135;
    HEAP32[582904>>2] = $136;
    HEAP32[582912>>2] = $137;
    $138 = $137 >>> 19;
    $139 = $134 >>> 8;
    $140 = $138 ^ $137;
    $141 = $140 ^ $134;
    $142 = $141 ^ $139;
    HEAP32[582920>>2] = $142;
    $143 = $142 & 8388607;
    $144 = (Math_fround(($143>>>0)));
    $145 = Math_fround($144 * Math_fround(1.19209303761635965202E-7));
    $146 = Math_fround($88 * $145);
    $147 = Math_fround(Math_fround(1.0) - $145);
    $148 = Math_fround($125 * $147);
    $149 = Math_fround($146 + $148);
    $150 = Math_fround($124 * $149);
    $151 = +$150;
    $152 = $151 + $fTime;
    $153 = (($this) + 1424|0);
    HEAPF64[$153>>3] = $152;
    $$pre$i13 = $135;$$pre1$i14 = $136;$$pre2$i15 = $137;$$pre3$i16 = $142;$181 = $152;
   }
   $154 = (($this) + 1316|0);
   $155 = Math_fround(HEAPF32[$154>>2]);
   $156 = (($this) + 1320|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $158 = HEAP8[582928>>0]|0;
   $159 = ($158<<24>>24)==(0);
   if ($159) {
    HEAP32[582896>>2] = 0;
    HEAP32[582904>>2] = 1;
    HEAP32[582912>>2] = 1812433254;
    HEAP32[582920>>2] = 1900727103;
    $160 = 582928;
    $161 = $160;
    HEAP32[$161>>2] = 1;
    $162 = (($160) + 4)|0;
    $163 = $162;
    HEAP32[$163>>2] = 0;
    $$pre$i7 = 1;$$pre1$i8 = 1812433254;$$pre2$i9 = 1900727103;$165 = 0;
   } else {
    $$pre$i7 = $$pre1$i14;$$pre1$i8 = $$pre2$i15;$$pre2$i9 = $$pre3$i16;$165 = $$pre$i13;
   }
   $164 = $165 << 11;
   $166 = $164 ^ $165;
   HEAP32[582896>>2] = $$pre$i7;
   HEAP32[582904>>2] = $$pre1$i8;
   HEAP32[582912>>2] = $$pre2$i9;
   $167 = $$pre2$i9 >>> 19;
   $168 = $166 >>> 8;
   $169 = $167 ^ $$pre2$i9;
   $170 = $169 ^ $166;
   $171 = $170 ^ $168;
   HEAP32[582920>>2] = $171;
   $172 = $171 & 8388607;
   $173 = (Math_fround(($172>>>0)));
   $174 = Math_fround($173 * Math_fround(1.19209303761635965202E-7));
   $175 = Math_fround($155 * $174);
   $176 = Math_fround(Math_fround(1.0) - $174);
   $177 = Math_fround($157 * $176);
   $178 = Math_fround($175 + $177);
   $179 = +$178;
   $180 = $181 + $179;
   $182 = (($this) + 1456|0);
   HEAPF64[$182>>3] = $180;
   $183 = (($this) + 1328|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = Math_fround($88 * Math_fround(2.0));
   $186 = Math_fround($88 * Math_fround(3.0));
   $187 = HEAP8[582928>>0]|0;
   $188 = ($187<<24>>24)==(0);
   if ($188) {
    HEAP32[582896>>2] = 0;
    HEAP32[582904>>2] = 1;
    HEAP32[582912>>2] = 1812433254;
    HEAP32[582920>>2] = 1900727103;
    $189 = 582928;
    $190 = $189;
    HEAP32[$190>>2] = 1;
    $191 = (($189) + 4)|0;
    $192 = $191;
    HEAP32[$192>>2] = 0;
    $194 = 0;$196 = 1;$197 = 1812433254;$198 = 1900727103;
   } else {
    $194 = $$pre$i7;$196 = $$pre1$i8;$197 = $$pre2$i9;$198 = $171;
   }
   $193 = $194 << 11;
   $195 = $193 ^ $194;
   HEAP32[582896>>2] = $196;
   HEAP32[582904>>2] = $197;
   HEAP32[582912>>2] = $198;
   $199 = $198 >>> 19;
   $200 = $195 >>> 8;
   $201 = $199 ^ $198;
   $202 = $201 ^ $195;
   $203 = $202 ^ $200;
   HEAP32[582920>>2] = $203;
   $204 = $203 & 8388607;
   $205 = (Math_fround(($204>>>0)));
   $206 = Math_fround($205 * Math_fround(1.19209303761635965202E-7));
   $207 = Math_fround($185 * $206);
   $208 = Math_fround(Math_fround(1.0) - $206);
   $209 = Math_fround($186 * $208);
   $210 = Math_fround($207 + $209);
   $211 = Math_fround($184 * $210);
   $212 = +$211;
   $213 = $180 + $212;
   HEAPF64[$0>>3] = $213;
  }
 }
 $214 = (($this) + 1424|0);
 $215 = +HEAPF64[$214>>3];
 $216 = $215 > $fTime;
 if ($216) {
  $217 = (($this) + 1448|0);
  $218 = +HEAPF64[$217>>3];
  $219 = Math_fround($218);
  $220 = (($this) + 1416|0);
  $221 = +HEAPF64[$220>>3];
  $222 = Math_fround($221);
  $223 = (($this) + 1440|0);
  $224 = +HEAPF64[$223>>3];
  $225 = $fTime - $224;
  $226 = $215 - $224;
  $227 = $225 / $226;
  $228 = Math_fround($227);
  $229 = Math_fround(Math_fround(1.0) - $228);
  $230 = Math_fround($229 * Math_fround(-6.0));
  $231 = Math_fround($228 * Math_fround(6.0));
  $232 = Math_fround($231 + $230);
  $233 = Math_fround(-$232);
  $234 = (Math_fround(+(Math_exp((+$233)))));
  $235 = Math_fround($234 + Math_fround(1.0));
  $236 = Math_fround(Math_fround(1.0) / $235);
  $237 = Math_fround($228 * Math_fround(0.0));
  $238 = Math_fround($237 + $236);
  $239 = Math_fround(Math_fround(1.0) - $238);
  $240 = Math_fround($219 * $239);
  $241 = Math_fround($222 * $238);
  $242 = Math_fround($241 + $240);
  $243 = (($this) + 1412|0);
  HEAPF32[$243>>2] = $242;
  $273 = (($this) + 1412|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = $274 < Math_fround(1.0);
  $276 = $275 ? $274 : Math_fround(1.0);
  $277 = $276 > Math_fround(0.0);
  $278 = $277 ? $276 : Math_fround(0.0);
  HEAPF32[$273>>2] = $278;
  STACKTOP = sp;return;
 }
 $244 = (($this) + 1456|0);
 $245 = +HEAPF64[$244>>3];
 $246 = $245 < $fTime;
 if (!($246)) {
  $273 = (($this) + 1412|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = $274 < Math_fround(1.0);
  $276 = $275 ? $274 : Math_fround(1.0);
  $277 = $276 > Math_fround(0.0);
  $278 = $277 ? $276 : Math_fround(0.0);
  HEAPF32[$273>>2] = $278;
  STACKTOP = sp;return;
 }
 $247 = +HEAPF64[$0>>3];
 $248 = $247 > 0.0;
 $249 = $247 > $245;
 $or$cond = $248 & $249;
 if (!($or$cond)) {
  $273 = (($this) + 1412|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = $274 < Math_fround(1.0);
  $276 = $275 ? $274 : Math_fround(1.0);
  $277 = $276 > Math_fround(0.0);
  $278 = $277 ? $276 : Math_fround(0.0);
  HEAPF32[$273>>2] = $278;
  STACKTOP = sp;return;
 }
 $250 = (($this) + 1416|0);
 $251 = +HEAPF64[$250>>3];
 $252 = Math_fround($251);
 $253 = $fTime - $245;
 $254 = $247 - $245;
 $255 = $253 / $254;
 $256 = Math_fround($255);
 $257 = Math_fround(Math_fround(1.0) - $256);
 $258 = Math_fround($257 * Math_fround(-6.0));
 $259 = Math_fround($256 * Math_fround(6.0));
 $260 = Math_fround($259 + $258);
 $261 = Math_fround(-$260);
 $262 = (Math_fround(+(Math_exp((+$261)))));
 $263 = Math_fround($262 + Math_fround(1.0));
 $264 = Math_fround(Math_fround(1.0) / $263);
 $265 = Math_fround($264 * Math_fround(0.5));
 $266 = Math_fround($256 * Math_fround(0.5));
 $267 = Math_fround($266 + $265);
 $268 = Math_fround(Math_fround(1.0) - $267);
 $269 = Math_fround($252 * $268);
 $270 = Math_fround($267 * Math_fround(0.0));
 $271 = Math_fround($270 + $269);
 $272 = (($this) + 1412|0);
 HEAPF32[$272>>2] = $271;
 $273 = (($this) + 1412|0);
 $274 = Math_fround(HEAPF32[$273>>2]);
 $275 = $274 < Math_fround(1.0);
 $276 = $275 ? $274 : Math_fround(1.0);
 $277 = $276 > Math_fround(0.0);
 $278 = $277 ? $276 : Math_fround(0.0);
 HEAPF32[$273>>2] = $278;
 STACKTOP = sp;return;
}
function __ZN13SpeedTreeWind23SetDirectionAndStrengthERK8Vector4f($this,$vDirAndStr) {
 $this = $this|0;
 $vDirAndStr = $vDirAndStr|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre1 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $fabsf = Math_fround(0), $storemerge$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$vDirAndStr>>2]);
 $1 = (($this) + 1492|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $0 != $2;
 $$pre = (($vDirAndStr) + 4|0);
 if ($3) {
  $$pre1 = (($this) + 1496|0);
  $$pre$phi2Z2D = $$pre1;
  label = 5;
 } else {
  $4 = Math_fround(HEAPF32[$$pre>>2]);
  $5 = (($this) + 1496|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = $4 != $6;
  if ($7) {
   $$pre$phi2Z2D = $5;
   label = 5;
  } else {
   $8 = (($vDirAndStr) + 8|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = (($this) + 1500|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = $9 != $11;
   if ($12) {
    $$pre$phi2Z2D = $5;
    label = 5;
   }
  }
 }
 if ((label|0) == 5) {
  HEAPF32[$1>>2] = $0;
  $13 = Math_fround(HEAPF32[$$pre>>2]);
  HEAPF32[$$pre$phi2Z2D>>2] = $13;
  $14 = (($vDirAndStr) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($this) + 1500|0);
  HEAPF32[$16>>2] = $15;
  $17 = (($this) + 1380|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround(HEAPF32[$vDirAndStr>>2]);
  $20 = Math_fround($18 * $19);
  $21 = (($this) + 1384|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround(HEAPF32[$$pre>>2]);
  $24 = Math_fround($22 * $23);
  $25 = Math_fround($20 + $24);
  $26 = (($this) + 1388|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround(HEAPF32[$14>>2]);
  $29 = Math_fround($27 * $28);
  $30 = Math_fround($25 + $29);
  $31 = Math_fround($30 + Math_fround(1.0));
  $32 = Math_fround($31 * Math_fround(0.5));
  $33 = Math_fround(Math_fround(1.0) - $32);
  $34 = (($this) + 1392|0);
  $35 = +HEAPF64[$34>>3];
  $36 = (($this) + 1520|0);
  HEAPF64[$36>>3] = $35;
  $37 = (($this) + 4|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround($38 * Math_fround(0.5));
  $40 = Math_fround(Math_fround(1.0) - $33);
  $41 = Math_fround($39 * $40);
  $42 = Math_fround($38 * $33);
  $43 = Math_fround($42 + $41);
  $44 = +$43;
  $45 = $35 + $44;
  $46 = (($this) + 1528|0);
  HEAPF64[$46>>3] = $45;
  $47 = (($this) + 1536|0);
  HEAPF32[$47>>2] = $18;
  $48 = (($this) + 1540|0);
  HEAPF32[$48>>2] = $22;
  $49 = (($this) + 1544|0);
  HEAPF32[$49>>2] = $27;
  $50 = Math_fround($18 + $0);
  $51 = Math_fround($50 * Math_fround(0.5));
  $52 = (($this) + 1504|0);
  HEAPF32[$52>>2] = $51;
  $53 = Math_fround($22 + $13);
  $54 = Math_fround($53 * Math_fround(0.5));
  $55 = (($this) + 1508|0);
  HEAPF32[$55>>2] = $54;
  $56 = Math_fround($27 + $15);
  $57 = Math_fround($56 * Math_fround(0.5));
  $58 = (($this) + 1512|0);
  HEAPF32[$58>>2] = $57;
  $59 = Math_fround($51 * $51);
  $60 = Math_fround($54 * $54);
  $61 = Math_fround($59 + $60);
  $62 = Math_fround($57 * $57);
  $63 = Math_fround($61 + $62);
  $64 = (Math_fround(Math_sqrt((Math_fround($63)))));
  $65 = $64 != Math_fround(0.0);
  if ($65) {
   $66 = Math_fround($51 / $64);
   HEAPF32[$52>>2] = $66;
   $67 = Math_fround($54 / $64);
   HEAPF32[$55>>2] = $67;
   $68 = Math_fround($57 / $64);
   $storemerge$i = $68;
  } else {
   HEAPF32[$52>>2] = Math_fround(0.0);
   HEAPF32[$55>>2] = Math_fround(0.0);
   $storemerge$i = Math_fround(0.0);
  }
  HEAPF32[$58>>2] = $storemerge$i;
 }
 $69 = (($vDirAndStr) + 12|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($this) + 1464|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = $70 != $72;
 if (!($73)) {
  STACKTOP = sp;return;
 }
 $74 = (($this) + 1392|0);
 $75 = +HEAPF64[$74>>3];
 $76 = (($this) + 1472|0);
 HEAPF64[$76>>3] = $75;
 $77 = Math_fround(HEAPF32[$this>>2]);
 $78 = Math_fround($77 * Math_fround(0.5));
 $79 = (($this) + 1376|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($70 - $80);
 $fabsf = (Math_fround(Math_abs((Math_fround($81)))));
 $82 = Math_fround(Math_fround(1.0) - $fabsf);
 $83 = Math_fround($78 * $82);
 $84 = Math_fround($77 * $fabsf);
 $85 = Math_fround($84 + $83);
 $86 = +$85;
 $87 = $75 + $86;
 $88 = (($this) + 1480|0);
 HEAPF64[$88>>3] = $87;
 $89 = (($this) + 1488|0);
 HEAPF32[$89>>2] = $80;
 $90 = Math_fround(HEAPF32[$69>>2]);
 HEAPF32[$71>>2] = $90;
 STACKTOP = sp;return;
}
function __ZNK13SpeedTreeWind14GetShaderTableEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1640|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13SpeedTreeWind16CopySettingsFromEPKS_($this,$pOther) {
 $this = $this|0;
 $pOther = $pOther|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _memcpy(($this|0),($pOther|0),1376)|0;
 STACKTOP = sp;return;
}
function __ZNK13SpeedTreeWind23ComputeOscillationTimesEPf($this,$oscillations) {
 $this = $this|0;
 $oscillations = $oscillations|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1560|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$oscillations>>2]);
 $3 = Math_fround($1 + $2);
 HEAPF32[$oscillations>>2] = $3;
 $4 = (($this) + 1564|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($oscillations) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 HEAPF32[$6>>2] = $8;
 $9 = (($this) + 1568|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($oscillations) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 HEAPF32[$11>>2] = $13;
 $14 = (($this) + 1572|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($oscillations) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 + $17);
 HEAPF32[$16>>2] = $18;
 $19 = (($this) + 1576|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($oscillations) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 + $22);
 HEAPF32[$21>>2] = $23;
 $24 = (($this) + 1580|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($oscillations) + 20|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 + $27);
 HEAPF32[$26>>2] = $28;
 $29 = (($this) + 1584|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($oscillations) + 24|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($30 + $32);
 HEAPF32[$31>>2] = $33;
 $34 = (($this) + 1588|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($oscillations) + 28|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 + $37);
 HEAPF32[$36>>2] = $38;
 $39 = (($this) + 1592|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($oscillations) + 32|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 + $42);
 HEAPF32[$41>>2] = $43;
 $44 = (($this) + 1596|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($oscillations) + 36|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 + $47);
 HEAPF32[$46>>2] = $48;
 STACKTOP = sp;return;
}
function __ZN25LightweightSTWindInstanceC2Ev($this) {
 $this = $this|0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$this+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZNK18SpeedTreeWindAsset11ComputeHashEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1920|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$pre = (($this) + 1912|0);
  $$pre$phiZ2D = $$pre;
  $30 = HEAP32[$$pre$phiZ2D>>2]|0;
  STACKTOP = sp;return ($30|0);
 } else {
  $3 = (($this) + 32|0);
  $4 = (__Z8CRCBeginv()|0);
  $5 = (__Z7CRCFeedjPKhj($4,$3,1332)|0);
  $6 = (($this) + 1364|0);
  $7 = (__Z7CRCFeedjPKhj($5,$6,12)|0);
  $8 = (($this) + 1376|0);
  $9 = (__Z7CRCFeedjPKhj($7,$8,4)|0);
  $10 = (($this) + 1380|0);
  $11 = (__Z7CRCFeedjPKhj($9,$10,28)|0);
  $12 = (__Z7CRCDonej($11)|0);
  $13 = (($this) + 1912|0);
  HEAP32[$13>>2] = $12;
  $14 = (__Z8CRCBeginv()|0);
  $15 = (($this) + 448|0);
  $16 = (__Z7CRCFeedjPKhj($14,$15,4)|0);
  $17 = (($this) + 452|0);
  $18 = (__Z7CRCFeedjPKhj($16,$17,4)|0);
  $19 = (($this) + 456|0);
  $20 = (__Z7CRCFeedjPKhj($18,$19,40)|0);
  $21 = (($this) + 496|0);
  $22 = (__Z7CRCFeedjPKhj($20,$21,40)|0);
  $23 = (($this) + 48|0);
  $24 = (__Z7CRCFeedjPKhj($22,$23,40)|0);
  $25 = (__Z7CRCFeedjPKhj($24,$10,1)|0);
  $26 = (($this) + 1381|0);
  $27 = (__Z7CRCFeedjPKhj($25,$26,1)|0);
  $28 = (__Z7CRCDonej($27)|0);
  $29 = (($this) + 1916|0);
  HEAP32[$29>>2] = $28;
  HEAP8[$0>>0] = 0;
  $$pre$phiZ2D = $13;
  $30 = HEAP32[$$pre$phiZ2D>>2]|0;
  STACKTOP = sp;return ($30|0);
 }
 return 0|0;
}
function __ZL30InitializeSpeedTreeWindManagerv() {
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[628480>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $4 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy3,0,16,583472,55)|0);
 $5 = HEAP32[628440>>2]|0;
 HEAP32[$1>>2] = $5;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(98,($4|0),1,(583480|0),1912,38240,($$byval_copy3|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  HEAP32[583448>>2] = $4;
  $8 = HEAP32[628440>>2]|0;
  HEAP32[$2>>2] = $8;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
  $9 = (__Znwj10MemLabelIdbiPKci(52,$$byval_copy3,0,16,583472,58)|0);
  $10 = (($9) + 4|0);
  HEAP32[$10>>2] = 0;
  $11 = (($9) + 8|0);
  HEAP32[$11>>2] = 0;
  $12 = (($9) + 12|0);
  HEAP32[$12>>2] = 0;
  $13 = (($9) + 20|0);
  $14 = (($9) + 48|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
  ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;HEAP32[$13+16>>2]=0|0;HEAP32[$13+20>>2]=0|0;
  HEAP32[579472>>2] = 108;
  HEAP32[583464>>2] = $9;
  STACKTOP = sp;return;
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($4|0),($$byval_copy3|0),0,16,(583472|0),55);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZL27DestroySpeedTreeWindManagerv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[583464>>2]|0;
 $2 = HEAP32[628440>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN20SpeedTreeWindManagerD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy1);
 HEAP32[583464>>2] = 0;
 $4 = HEAP32[583448>>2]|0;
 $5 = HEAP32[628480>>2]|0;
 $6 = ($4|0)==(0|0);
 if (!($6)) {
  __ZN10MemoryPoolD2Ev($4);
 }
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($4,$$byval_copy1);
 HEAP32[583448>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20SpeedTreeWindManager11GetInstanceEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[583464>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZZN20SpeedTreeWindManagerC1EvEN10WindUpdate7ForwardEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[583464>>2]|0;
 $1 = (__Z14GetTimeManagerv()|0);
 $2 = (($1) + 88|0);
 $3 = +HEAPF64[$2>>3];
 $4 = Math_fround($3);
 __ZN20SpeedTreeWindManager6UpdateEf($0,$4);
 STACKTOP = sp;return;
}
function __ZN20SpeedTreeWindManagerD2Ev($this) {
 $this = $this|0;
 var $$byval_copy8 = 0, $$pr58 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre53 = 0, $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i$i$i11 = 0, $__new_last2$i$i$i$i$i$i$i$i$i2 = 0, $__new_last2$i$i$i$i$i$i$i$i$i20 = 0, $__new_last2$i$i$i$i$i29 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i12 = 0, $scevgep$i$i$i$i$i$i$i$i$i21 = 0, $scevgep$i$i$i$i$i$i$i$i$i3 = 0, $scevgep$i$i$i$i$i30 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i16 = 0, $scevgep4$i$i$i$i$i$i$i$i$i25 = 0, $scevgep4$i$i$i$i$i$i$i$i$i7 = 0, $scevgep4$i$i$i$i$i34 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i$i$i14 = 0, $uglygep$i$i$i$i$i$i$i$i$i23 = 0, $uglygep$i$i$i$i$i$i$i$i$i5 = 0, $uglygep$i$i$i$i$i32 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i15 = 0, $uglygep3$i$i$i$i$i$i$i$i$i24 = 0, $uglygep3$i$i$i$i$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 do {
  if ($6) {
   label = 15;
  } else {
   $8 = $3;$88 = $5;
   while(1) {
    $7 = (($8) + 4|0);
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $16 = $88;
    } else {
     $11 = HEAP32[583448>>2]|0;
     __THREW__ = 0;
     invoke_vii(2609,($11|0),($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      label = 7;
      break;
     }
     $$pre55 = HEAP32[$4>>2]|0;
     $16 = $$pre55;
    }
    $14 = (($8) + 8|0);
    $15 = ($14|0)==($16|0);
    if ($15) {
     break;
    } else {
     $8 = $14;$88 = $16;
    }
   }
   if ((label|0) == 7) {
    $19 = ___cxa_find_matching_catch()|0;
    $20 = tempRet0;
    $$pre56 = (($this) + 20|0);
    $$pre$phiZ2D = $$pre56;$lpad$phi$index = $19;$lpad$phi$index2 = $20;
    break;
   }
   $$pre = HEAP32[$2>>2]|0;
   $33 = ($16|0)==($$pre|0);
   if ($33) {
    label = 15;
   } else {
    $__new_last2$i$i$i$i$i = $$pre;
    $scevgep$i$i$i$i$i = (($16) + -8|0);
    $34 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($34)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $35 = $uglygep3$i$i$i$i$i >>> 3;
    $36 = $35 ^ -1;
    $scevgep4$i$i$i$i$i = (($16) + ($36<<3)|0);
    HEAP32[$4>>2] = $scevgep4$i$i$i$i$i;
    label = 15;
   }
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   $37 = (($this) + 20|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($this) + 24|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($38|0)==($40|0);
   if ($41) {
    $$pr58 = $38;$58 = $38;
   } else {
    $43 = $38;$89 = $40;
    while(1) {
     $42 = (($43) + 4|0);
     $44 = HEAP32[$42>>2]|0;
     $45 = ($44|0)==(0|0);
     if ($45) {
      $51 = $89;
     } else {
      $46 = HEAP32[583448>>2]|0;
      __THREW__ = 0;
      invoke_vii(2609,($46|0),($44|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 6;
       break;
      }
      $$pre54 = HEAP32[$39>>2]|0;
      $51 = $$pre54;
     }
     $49 = (($43) + 8|0);
     $50 = ($49|0)==($51|0);
     if ($50) {
      break;
     } else {
      $43 = $49;$89 = $51;
     }
    }
    if ((label|0) == 6) {
     $17 = ___cxa_find_matching_catch()|0;
     $18 = tempRet0;
     $$pre$phiZ2D = $37;$lpad$phi$index = $17;$lpad$phi$index2 = $18;
     break;
    }
    $$pre53 = HEAP32[$37>>2]|0;
    $52 = ($51|0)==($$pre53|0);
    if ($52) {
     $$pr58 = $$pre53;$58 = $51;
    } else {
     $__new_last2$i$i$i$i$i29 = $$pre53;
     $scevgep$i$i$i$i$i30 = (($51) + -8|0);
     $53 = (0 - ($__new_last2$i$i$i$i$i29))|0;
     $uglygep$i$i$i$i$i32 = (($scevgep$i$i$i$i$i30) + ($53)|0);
     $uglygep3$i$i$i$i$i33 = $uglygep$i$i$i$i$i32;
     $54 = $uglygep3$i$i$i$i$i33 >>> 3;
     $55 = $54 ^ -1;
     $scevgep4$i$i$i$i$i34 = (($51) + ($55<<3)|0);
     HEAP32[$39>>2] = $scevgep4$i$i$i$i$i34;
     $$pr58 = $$pre53;$58 = $scevgep4$i$i$i$i$i34;
    }
   }
   $56 = ($$pr58|0)==(0|0);
   if (!($56)) {
    $57 = ($58|0)==($$pr58|0);
    if (!($57)) {
     $__new_last2$i$i$i$i$i$i$i$i$i11 = $$pr58;
     $scevgep$i$i$i$i$i$i$i$i$i12 = (($58) + -8|0);
     $59 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i11))|0;
     $uglygep$i$i$i$i$i$i$i$i$i14 = (($scevgep$i$i$i$i$i$i$i$i$i12) + ($59)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i15 = $uglygep$i$i$i$i$i$i$i$i$i14;
     $60 = $uglygep3$i$i$i$i$i$i$i$i$i15 >>> 3;
     $61 = $60 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i16 = (($58) + ($61<<3)|0);
     HEAP32[$39>>2] = $scevgep4$i$i$i$i$i$i$i$i$i16;
    }
    HEAP32[$0>>2] = 55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($$pr58|0),($$byval_copy8|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $64 = ___cxa_find_matching_catch()|0;
     $65 = tempRet0;
     ___cxa_call_unexpected(($64|0));
     // unreachable;
    }
   }
   $66 = HEAP32[$2>>2]|0;
   $67 = ($66|0)==(0|0);
   if ($67) {
    STACKTOP = sp;return;
   }
   $68 = HEAP32[$4>>2]|0;
   $69 = ($68|0)==($66|0);
   if (!($69)) {
    $__new_last2$i$i$i$i$i$i$i$i$i2 = $66;
    $scevgep$i$i$i$i$i$i$i$i$i3 = (($68) + -8|0);
    $70 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i$i$i3) + ($70)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i$i$i5;
    $71 = $uglygep3$i$i$i$i$i$i$i$i$i6 >>> 3;
    $72 = $71 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i7 = (($68) + ($72<<3)|0);
    HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i$i$i$i7;
   }
   HEAP32[$1>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy8|0));
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    ___cxa_call_unexpected(($75|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $21 = HEAP32[$$pre$phiZ2D>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $23 = (($this) + 24|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==($21|0);
  if (!($25)) {
   $__new_last2$i$i$i$i$i$i$i$i$i20 = $21;
   $scevgep$i$i$i$i$i$i$i$i$i21 = (($24) + -8|0);
   $26 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i20))|0;
   $uglygep$i$i$i$i$i$i$i$i$i23 = (($scevgep$i$i$i$i$i$i$i$i$i21) + ($26)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i24 = $uglygep$i$i$i$i$i$i$i$i$i23;
   $27 = $uglygep3$i$i$i$i$i$i$i$i$i24 >>> 3;
   $28 = $27 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i25 = (($24) + ($28<<3)|0);
   HEAP32[$23>>2] = $scevgep4$i$i$i$i$i$i$i$i$i25;
  }
  HEAP32[$0>>2] = 55;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($21|0),($$byval_copy8|0));
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   ___cxa_call_unexpected(($31|0));
   // unreachable;
  }
 }
 $77 = HEAP32[$2>>2]|0;
 $78 = ($77|0)==(0|0);
 if ($78) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $79 = HEAP32[$4>>2]|0;
 $80 = ($79|0)==($77|0);
 if (!($80)) {
  $__new_last2$i$i$i$i$i$i$i$i$i = $77;
  $scevgep$i$i$i$i$i$i$i$i$i = (($79) + -8|0);
  $81 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($81)|0);
  $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
  $82 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
  $83 = $82 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i$i = (($79) + ($83<<3)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
 }
 HEAP32[$1>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($77|0),($$byval_copy8|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch()|0;
  $87 = tempRet0;
  ___cxa_call_unexpected(($86|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN20SpeedTreeWindManager8TickWindER25LightweightSTWindInstanceRK4AABBRK18SpeedTreeWindAsset($this,$instance,$aabb,$windAsset) {
 $this = $this|0;
 $instance = $instance|0;
 $aabb = $aabb|0;
 $windAsset = $windAsset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp;
 $1 = (__ZN20SpeedTreeWindManager11GetWindDataERK4AABBRK18SpeedTreeWindAsset($this,$aabb,$windAsset)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN25LightweightSTWindInstanceC2Ev($0);
  dest=$instance+0|0; src=$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return ($1|0);
 }
 $3 = Math_fround(HEAPF32[$instance>>2]);
 $4 = (($this) + 48|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $3 != $5;
 if (!($6)) {
  STACKTOP = sp;return ($1|0);
 }
 HEAPF32[$instance>>2] = $5;
 $7 = (($1) + 24|0);
 $8 = (($instance) + 4|0);
 __ZNK13SpeedTreeWind23ComputeOscillationTimesEPf($7,$8);
 STACKTOP = sp;return ($1|0);
}
function __ZN20SpeedTreeWindManager11GetWindDataERK4AABBRK18SpeedTreeWindAsset($this,$aabb,$windAsset) {
 $this = $this|0;
 $aabb = $aabb|0;
 $windAsset = $windAsset|0;
 var $$byval_copy1 = 0, $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx2 = 0, $$idx2$val = 0, $$idx3 = 0, $$idx3$val = 0, $$neg2$i$i$i$i$i = 0, $$neg2$i$i$i$i$i$i = 0, $$neg2$i$i$i$i$i$i8 = 0, $$neg2$i$i$i$i$i16 = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i$i = 0, $$sum$i$i$i$i$i$i7 = 0, $$sum$i$i$i$i$i15 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0;
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0);
 var $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0);
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0;
 var $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i$i9 = 0, $__len$0$be$i$i$i$i$i17 = 0, $__len$03$i$i$i$i$i = 0;
 var $__len$03$i$i$i$i$i$i = 0, $__len$03$i$i$i$i$i$i5 = 0, $__len$03$i$i$i$i$i14 = 0, $globalWind = 0, $or$cond = 0, $or$cond29 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 64|0;
 $0 = sp + 60|0;
 $1 = sp + 56|0;
 $2 = sp + 52|0;
 $3 = sp + 48|0;
 $globalWind = sp + 24|0;
 $4 = sp + 16|0;
 $5 = sp;
 $6 = sp + 40|0;
 __ZN20SpeedTreeWindManager25GetCachedGlobalWindVectorEv($globalWind,$this);
 $7 = (__ZNK18SpeedTreeWindAsset11ComputeHashEv($windAsset)|0);
 $$idx2 = (($this) + 4|0);
 $$idx2$val = HEAP32[$$idx2>>2]|0;
 $$idx3 = (($this) + 8|0);
 $$idx3$val = HEAP32[$$idx3>>2]|0;
 $8 = $$idx3$val;
 $9 = $$idx2$val;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($11|0)==(0);
 if ($12) {
  $22 = $$idx2$val;
 } else {
  $15 = $$idx2$val;$__len$03$i$i$i$i$i$i = $11;
  while(1) {
   $13 = (($__len$03$i$i$i$i$i$i|0) / 2)&-1;
   $14 = (($15) + ($13<<3)|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = ($16>>>0)<($7>>>0);
   if ($17) {
    $$sum$i$i$i$i$i$i = (($13) + 1)|0;
    $18 = (($15) + ($$sum$i$i$i$i$i$i<<3)|0);
    $$neg2$i$i$i$i$i$i = (($__len$03$i$i$i$i$i$i) + -1)|0;
    $19 = (($$neg2$i$i$i$i$i$i) - ($13))|0;
    $211 = $18;$__len$0$be$i$i$i$i$i$i = $19;
   } else {
    $211 = $15;$__len$0$be$i$i$i$i$i$i = $13;
   }
   $20 = ($__len$0$be$i$i$i$i$i$i|0)==(0);
   if ($20) {
    $22 = $211;
    break;
   } else {
    $15 = $211;$__len$03$i$i$i$i$i$i = $__len$0$be$i$i$i$i$i$i;
   }
  }
 }
 $21 = ($22|0)==($$idx3$val|0);
 if ($21) {
  label = 8;
 } else {
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23>>>0)>($7>>>0);
  if ($24) {
   label = 8;
  } else {
   $25 = (($22) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if ($27) {
    label = 8;
   } else {
    $65 = $26;
    label = 19;
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $28 = Math_fround(HEAPF32[$globalWind>>2]);
   $29 = Math_fround(HEAPF32[616680>>2]);
   $30 = $28 != $29;
   if (!($30)) {
    $31 = (($globalWind) + 4|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
    $34 = $32 != $33;
    if (!($34)) {
     $35 = (($globalWind) + 8|0);
     $36 = Math_fround(HEAPF32[$35>>2]);
     $37 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
     $38 = $36 != $37;
     if (!($38)) {
      $147 = 0;
      break;
     }
    }
   }
   $39 = (($windAsset) + 32|0);
   $40 = (__ZNK20SpeedTreeWindManager14CreateWindDataERK4AABBPKNS_8WindDataEPK13SpeedTreeWindRK8Vector3f($this,590472,0,$39,$globalWind)|0);
   $41 = (__ZNK18SpeedTreeWindAsset11ComputeHashEv($windAsset)|0);
   HEAP32[$4>>2] = $41;
   $42 = (($4) + 4|0);
   HEAP32[$42>>2] = $40;
   $43 = HEAP32[$$idx2>>2]|0;
   $44 = HEAP32[$$idx3>>2]|0;
   $45 = $44;
   $46 = $43;
   $47 = (($45) - ($46))|0;
   $48 = $47 >> 3;
   $49 = ($48|0)==(0);
   if ($49) {
    $59 = $43;
   } else {
    $52 = $43;$__len$03$i$i$i$i$i14 = $48;
    while(1) {
     $50 = (($__len$03$i$i$i$i$i14|0) / 2)&-1;
     $51 = (($52) + ($50<<3)|0);
     $53 = HEAP32[$51>>2]|0;
     $54 = ($53>>>0)<($41>>>0);
     if ($54) {
      $$sum$i$i$i$i$i15 = (($50) + 1)|0;
      $55 = (($52) + ($$sum$i$i$i$i$i15<<3)|0);
      $$neg2$i$i$i$i$i16 = (($__len$03$i$i$i$i$i14) + -1)|0;
      $56 = (($$neg2$i$i$i$i$i16) - ($50))|0;
      $212 = $55;$__len$0$be$i$i$i$i$i17 = $56;
     } else {
      $212 = $52;$__len$0$be$i$i$i$i$i17 = $50;
     }
     $57 = ($__len$0$be$i$i$i$i$i17|0)==(0);
     if ($57) {
      $59 = $212;
      break;
     } else {
      $52 = $212;$__len$03$i$i$i$i$i14 = $__len$0$be$i$i$i$i$i17;
     }
    }
   }
   $58 = ($59|0)==($44|0);
   if ($58) {
    label = 17;
   } else {
    $60 = HEAP32[$59>>2]|0;
    $61 = ($41>>>0)<($60>>>0);
    if ($61) {
     label = 17;
    }
   }
   if ((label|0) == 17) {
    $62 = (($this) + 4|0);
    HEAP32[$1>>2] = $59;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    __ZNSt3__16vectorINS_4pairIjPN20SpeedTreeWindManager8WindDataEEE13stl_allocatorIS5_L18MemLabelIdentifier55ELi16EEE6insertENS_11__wrap_iterIPKS5_EERSB_($0,$62,$$byval_copy1,$4);
   }
   $63 = ($40|0)==(0|0);
   if ($63) {
    $147 = 0;
   } else {
    $65 = $40;
    label = 19;
   }
  }
 } while(0);
 do {
  if ((label|0) == 19) {
   $64 = (($65) + 1400|0);
   $66 = Math_fround(HEAPF32[$64>>2]);
   $67 = $66 > Math_fround(0.0);
   if (!($67)) {
    $68 = (($65) + 24|0);
    $69 = (__ZNK13SpeedTreeWind12InTransitionEv($68)|0);
    if (!($69)) {
     $147 = 0;
     break;
    }
   }
   $70 = (($65) + 1904|0);
   HEAP8[$70>>0] = 1;
   $147 = $65;
  }
 } while(0);
 $71 = (__ZN11WindManager11GetInstanceEv()|0);
 $72 = (__ZN11WindManager7GetListEv($71)|0);
 $73 = (($72) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==($72|0);
 if ($75) {
  $129 = Math_fround(0.0);$132 = Math_fround(0.0);$135 = Math_fround(0.0);
 } else {
  $76 = (($$byval_copy1) + 4|0);
  $77 = (($$byval_copy1) + 8|0);
  $78 = (($$byval_copy1) + 12|0);
  $80 = $74;$94 = Math_fround(0.0);$96 = Math_fround(0.0);$98 = Math_fround(0.0);
  while(1) {
   $79 = (($80) + 8|0);
   $81 = HEAP32[$79>>2]|0;
   $82 = (($81) + 32|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==(1);
   if ($84) {
    $85 = (__ZNK8WindZone17ComputeWindVectorERK4AABBR8Vector4f($81,$aabb,$$byval_copy1)|0);
    if ($85) {
     $86 = Math_fround(HEAPF32[$$byval_copy1>>2]);
     $87 = Math_fround(HEAPF32[$76>>2]);
     $88 = Math_fround(HEAPF32[$77>>2]);
     $89 = Math_fround(HEAPF32[$78>>2]);
     $90 = Math_fround($86 * $89);
     $91 = Math_fround($87 * $89);
     $92 = Math_fround($88 * $89);
     $93 = Math_fround($94 + $90);
     $95 = Math_fround($96 + $91);
     $97 = Math_fround($98 + $92);
     $213 = $97;$214 = $95;$215 = $93;
    } else {
     $213 = $98;$214 = $96;$215 = $94;
    }
   } else {
    $213 = $98;$214 = $96;$215 = $94;
   }
   $99 = (($80) + 4|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==($72|0);
   if ($101) {
    $129 = $215;$132 = $214;$135 = $213;
    break;
   } else {
    $80 = $100;$94 = $215;$96 = $214;$98 = $213;
   }
  }
 }
 $102 = (__ZNK18SpeedTreeWindAsset11ComputeHashEv($windAsset)|0);
 HEAP32[$$byval_copy1>>2] = $102;
 $103 = (__Z8CRCBeginv()|0);
 $104 = (__Z7CRCFeedjPKhj($103,$aabb,24)|0);
 $105 = (__Z7CRCFeedjPKhj($104,$$byval_copy1,4)|0);
 $106 = (__Z7CRCDonej($105)|0);
 $$idx = (($this) + 20|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $$idx1 = (($this) + 24|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $107 = $$idx1$val;
 $108 = $$idx$val;
 $109 = (($107) - ($108))|0;
 $110 = $109 >> 3;
 $111 = ($110|0)==(0);
 if ($111) {
  $121 = $$idx$val;
 } else {
  $114 = $$idx$val;$__len$03$i$i$i$i$i$i5 = $110;
  while(1) {
   $112 = (($__len$03$i$i$i$i$i$i5|0) / 2)&-1;
   $113 = (($114) + ($112<<3)|0);
   $115 = HEAP32[$113>>2]|0;
   $116 = ($115>>>0)<($106>>>0);
   if ($116) {
    $$sum$i$i$i$i$i$i7 = (($112) + 1)|0;
    $117 = (($114) + ($$sum$i$i$i$i$i$i7<<3)|0);
    $$neg2$i$i$i$i$i$i8 = (($__len$03$i$i$i$i$i$i5) + -1)|0;
    $118 = (($$neg2$i$i$i$i$i$i8) - ($112))|0;
    $216 = $117;$__len$0$be$i$i$i$i$i$i9 = $118;
   } else {
    $216 = $114;$__len$0$be$i$i$i$i$i$i9 = $112;
   }
   $119 = ($__len$0$be$i$i$i$i$i$i9|0)==(0);
   if ($119) {
    $121 = $216;
    break;
   } else {
    $114 = $216;$__len$03$i$i$i$i$i$i5 = $__len$0$be$i$i$i$i$i$i9;
   }
  }
 }
 $120 = ($121|0)==($$idx1$val|0);
 if ($120) {
  label = 35;
 } else {
  $122 = HEAP32[$121>>2]|0;
  $123 = ($122>>>0)>($106>>>0);
  if ($123) {
   label = 35;
  } else {
   $124 = (($121) + 4|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = ($125|0)==(0|0);
   if ($126) {
    label = 35;
   } else {
    $172 = $125;
   }
  }
 }
 if ((label|0) == 35) {
  $127 = Math_fround(HEAPF32[616680>>2]);
  $128 = $129 != $127;
  $130 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
  $131 = $132 != $130;
  $or$cond = $128 | $131;
  $133 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
  $134 = $135 != $133;
  $or$cond29 = $or$cond | $134;
  if (!($or$cond29)) {
   $210 = $147;
   STACKTOP = sp;return ($210|0);
  }
  $136 = (($windAsset) + 32|0);
  $137 = Math_fround(HEAPF32[$globalWind>>2]);
  $138 = Math_fround($129 + $137);
  $139 = (($globalWind) + 4|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = Math_fround($132 + $140);
  $142 = (($globalWind) + 8|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = Math_fround($135 + $143);
  HEAPF32[$5>>2] = $138;
  $145 = (($5) + 4|0);
  HEAPF32[$145>>2] = $141;
  $146 = (($5) + 8|0);
  HEAPF32[$146>>2] = $144;
  $148 = (__ZNK20SpeedTreeWindManager14CreateWindDataERK4AABBPKNS_8WindDataEPK13SpeedTreeWindRK8Vector3f($this,$aabb,$147,$136,$5)|0);
  HEAP32[$6>>2] = $106;
  $149 = (($6) + 4|0);
  HEAP32[$149>>2] = $148;
  $150 = HEAP32[$$idx>>2]|0;
  $151 = HEAP32[$$idx1>>2]|0;
  $152 = $151;
  $153 = $150;
  $154 = (($152) - ($153))|0;
  $155 = $154 >> 3;
  $156 = ($155|0)==(0);
  if ($156) {
   $166 = $150;
  } else {
   $159 = $150;$__len$03$i$i$i$i$i = $155;
   while(1) {
    $157 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
    $158 = (($159) + ($157<<3)|0);
    $160 = HEAP32[$158>>2]|0;
    $161 = ($160>>>0)<($106>>>0);
    if ($161) {
     $$sum$i$i$i$i$i = (($157) + 1)|0;
     $162 = (($159) + ($$sum$i$i$i$i$i<<3)|0);
     $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
     $163 = (($$neg2$i$i$i$i$i) - ($157))|0;
     $217 = $162;$__len$0$be$i$i$i$i$i = $163;
    } else {
     $217 = $159;$__len$0$be$i$i$i$i$i = $157;
    }
    $164 = ($__len$0$be$i$i$i$i$i|0)==(0);
    if ($164) {
     $166 = $217;
     break;
    } else {
     $159 = $217;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
    }
   }
  }
  $165 = ($166|0)==($151|0);
  if ($165) {
   label = 42;
  } else {
   $167 = HEAP32[$166>>2]|0;
   $168 = ($106>>>0)<($167>>>0);
   if ($168) {
    label = 42;
   }
  }
  if ((label|0) == 42) {
   $169 = (($this) + 20|0);
   HEAP32[$3>>2] = $166;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$3+0>>2]|0;
   __ZNSt3__16vectorINS_4pairIjPN20SpeedTreeWindManager8WindDataEEE13stl_allocatorIS5_L18MemLabelIdentifier55ELi16EEE6insertENS_11__wrap_iterIPKS5_EERSB_($2,$169,$$byval_copy1,$6);
  }
  $170 = ($148|0)==(0|0);
  if ($170) {
   $210 = $147;
   STACKTOP = sp;return ($210|0);
  } else {
   $172 = $148;
  }
 }
 $171 = (($172) + 24|0);
 $173 = (__ZNK13SpeedTreeWind12InTransitionEv($171)|0);
 if (!($173)) {
  $174 = (($172) + 1516|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (($172) + 1520|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = (($172) + 1524|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = Math_fround(HEAPF32[616648>>2]);
  $181 = Math_fround(HEAPF32[$globalWind>>2]);
  $182 = Math_fround($181 - $175);
  $183 = (($globalWind) + 4|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = Math_fround($184 - $177);
  $186 = (($globalWind) + 8|0);
  $187 = Math_fround(HEAPF32[$186>>2]);
  $188 = Math_fround($187 - $179);
  $189 = Math_fround($182 * $182);
  $190 = Math_fround($185 * $185);
  $191 = Math_fround($189 + $190);
  $192 = Math_fround($188 * $188);
  $193 = Math_fround($191 + $192);
  $194 = Math_fround($180 * $180);
  $195 = !($193 <= $194);
  if (!($195)) {
   $196 = (($172) + 1400|0);
   $197 = Math_fround(HEAPF32[$196>>2]);
   $198 = Math_fround($181 * $181);
   $199 = Math_fround($184 * $184);
   $200 = Math_fround($198 + $199);
   $201 = Math_fround($187 * $187);
   $202 = Math_fround($200 + $201);
   $203 = (Math_fround(Math_sqrt((Math_fround($202)))));
   $204 = Math_fround($197 - $203);
   $205 = $204 < Math_fround(0.0);
   if ($205) {
    $206 = Math_fround(-$204);
    $208 = $206;
   } else {
    $208 = $204;
   }
   $207 = !($208 <= Math_fround(9.99999997475242707878E-7));
   if (!($207)) {
    $210 = $147;
    STACKTOP = sp;return ($210|0);
   }
  }
 }
 $209 = (($172) + 1904|0);
 HEAP8[$209>>0] = 1;
 $210 = $172;
 STACKTOP = sp;return ($210|0);
}
function __ZN20SpeedTreeWindManager21PrepareWindPropertiesER21MaterialPropertyBlockb($block,$globalWindOnly) {
 $block = $block|0;
 $globalWindOnly = $globalWindOnly|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $0 = sp + 272|0;
 $1 = sp + 256|0;
 $2 = sp + 240|0;
 $3 = sp + 224|0;
 $4 = sp + 208|0;
 $5 = sp + 192|0;
 $6 = sp + 176|0;
 $7 = sp + 160|0;
 $8 = sp + 144|0;
 $9 = sp + 128|0;
 $10 = sp + 96|0;
 $11 = sp + 80|0;
 $12 = sp + 64|0;
 $13 = sp + 48|0;
 $14 = sp + 32|0;
 $15 = sp + 16|0;
 $16 = sp;
 $17 = sp + 112|0;
 $18 = (($block) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = (($block) + 24|0);
 HEAP32[$19>>2] = 0;
 $20 = HEAP32[641904>>2]|0;
 $21 = (($block) + 32|0);
 HEAP32[$21>>2] = $20;
 __ZN21MaterialPropertyBlock16AddPropertyFloatERKN9ShaderLab16FastPropertyNameEf($block,583424,Math_fround(0.0));
 if ($globalWindOnly) {
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,582936,$15);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,582960,$16);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583104,$17);
  STACKTOP = sp;return;
 } else {
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,582936,$0);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,582960,$1);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,582984,$2);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583008,$3);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583040,$4);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583072,$5);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583104,$6);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583144,$7);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583176,$8);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583208,$9);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583240,$10);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583272,$11);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583304,$12);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583336,$13);
  __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($block,583368,$14);
  STACKTOP = sp;return;
 }
}
function __ZN20SpeedTreeWindManager18FillWindPropertiesER21MaterialPropertyBlockbbPKNS_8WindDataERK25LightweightSTWindInstance($block,$forTreeRenderer,$globalWindOnly,$windData,$instance) {
 $block = $block|0;
 $forTreeRenderer = $forTreeRenderer|0;
 $globalWindOnly = $globalWindOnly|0;
 $windData = $windData|0;
 $instance = $instance|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 if (!($forTreeRenderer)) {
  __ZN20SpeedTreeWindManager21PrepareWindPropertiesER21MaterialPropertyBlockb($block,$globalWindOnly);
 }
 $0 = (($block) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($windData|0)==(0|0);
 if ($2) {
  $3 = $globalWindOnly ? 52 : 244;
  _memset(($1|0),0,($3|0))|0;
  __ZN21MaterialPropertyBlock11ComputeHashEv($block);
  STACKTOP = sp;return;
 }
 $4 = (($1) + 4|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $5 = (($windData) + 24|0);
 $6 = (__ZNK13SpeedTreeWind14GetShaderTableEv($5)|0);
 if ($globalWindOnly) {
  ;HEAP32[$4+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$4+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$4+28>>2]=HEAP32[$6+28>>2]|0;
  $37 = (($1) + 36|0);
  $38 = (($6) + 96|0);
  ;HEAP32[$37+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$38+12>>2]|0;
  $39 = (($1) + 20|0);
  HEAPF32[$39>>2] = Math_fround(0.0);
  __ZN21MaterialPropertyBlock11ComputeHashEv($block);
  STACKTOP = sp;return;
 } else {
  _memcpy(($4|0),($6|0),240)|0;
  $7 = (($instance) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($1) + 20|0);
  HEAPF32[$9>>2] = $8;
  $10 = (($instance) + 8|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($1) + 36|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($instance) + 12|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($1) + 44|0);
  HEAPF32[$15>>2] = $14;
  $16 = (($instance) + 16|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($1) + 132|0);
  HEAPF32[$18>>2] = $17;
  $19 = (($instance) + 20|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($1) + 148|0);
  HEAPF32[$21>>2] = $20;
  $22 = (($instance) + 24|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($1) + 172|0);
  HEAPF32[$24>>2] = $23;
  $25 = (($instance) + 28|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($1) + 180|0);
  HEAPF32[$27>>2] = $26;
  $28 = (($instance) + 32|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($1) + 196|0);
  HEAPF32[$30>>2] = $29;
  $31 = (($instance) + 36|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($1) + 220|0);
  HEAPF32[$33>>2] = $32;
  $34 = (($instance) + 40|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = (($1) + 228|0);
  HEAPF32[$36>>2] = $35;
  __ZN21MaterialPropertyBlock11ComputeHashEv($block);
  STACKTOP = sp;return;
 }
}
function __ZN20SpeedTreeWindManager6UpdateEf($this,$currentTime) {
 $this = $this|0;
 $currentTime = Math_fround($currentTime);
 var $$0$lcssa$i$i$i$i$i = 0, $$0$lcssa$i$i$i$i$i19 = 0, $$012$i$i$i$i$i = 0, $$012$i$i$i$i$i11 = 0, $$03$i$i$i$i$i = 0, $$03$i$i$i$i$i10 = 0, $$be = 0, $$be39 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i17 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$sum$i$i$i = 0, $$sum$i$i$i6 = 0, $$sum5$i$i$i = 0, $$sum5$i$i$i15 = 0, $0 = 0, $1 = 0;
 var $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0);
 var $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0;
 var $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0);
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__first5$i$i$i$i$i = 0, $__first5$i$i$i$i$i7 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i21 = 0, $globalWindVec = 0, $scevgep$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i22 = 0, $scevgep$i$i1$i$i$i = 0, $scevgep$i$i1$i$i$i8 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i26 = 0, $scevgep7$i$i$i$i$i = 0, $scevgep7$i$i$i$i$i16 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i24 = 0, $uglygep$i$i3$i$i$i = 0, $uglygep$i$i3$i$i$i13 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i25 = 0, $uglygep6$i$i$i$i$i = 0, $uglygep6$i$i$i$i$i14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $globalWindVec = sp + 16|0;
 __ZN20SpeedTreeWindManager25GetCachedGlobalWindVectorEv($globalWindVec,$this);
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = Math_fround(HEAPF32[$globalWindVec>>2]);
  $8 = Math_fround($7 * $7);
  $9 = (($globalWindVec) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround($10 * $10);
  $12 = Math_fround($8 + $11);
  $13 = (($globalWindVec) + 8|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($14 * $14);
  $16 = Math_fround($12 + $15);
  $17 = (($0) + 4|0);
  $18 = (($0) + 8|0);
  $19 = (($0) + 12|0);
  $20 = +$currentTime;
  $21 = (($1) + 4|0);
  $22 = (($1) + 8|0);
  $23 = (($1) + 12|0);
  $191 = $5;$25 = $3;
  while(1) {
   $24 = (($25) + 4|0);
   $26 = HEAP32[$24>>2]|0;
   $27 = (($26) + 1904|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = ($28<<24>>24)==(0);
   if ($29) {
    $30 = ($26|0)==(0|0);
    if ($30) {
     $40 = $191;
    } else {
     $31 = HEAP32[583448>>2]|0;
     __ZN10MemoryPool10DeallocateEPv($31,$26);
     $$pre44 = HEAP32[$4>>2]|0;
     $40 = $$pre44;
    }
    $32 = HEAP32[$2>>2]|0;
    $33 = $25;
    $34 = $32;
    $35 = (($33) - ($34))|0;
    $36 = $35 >> 3;
    $37 = (($32) + ($36<<3)|0);
    $$sum$i$i$i = (($36) + 1)|0;
    $38 = (($32) + ($$sum$i$i$i<<3)|0);
    $39 = ($38|0)==($40|0);
    if ($39) {
     $$0$lcssa$i$i$i$i$i = $37;$51 = $40;
    } else {
     $scevgep$i$i1$i$i$i = (($40) + -8|0);
     $$012$i$i$i$i$i = $38;$$03$i$i$i$i$i = $37;
     while(1) {
      $41 = HEAP32[$$012$i$i$i$i$i>>2]|0;
      HEAP32[$$03$i$i$i$i$i>>2] = $41;
      $42 = (($$012$i$i$i$i$i) + 4|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = (($$03$i$i$i$i$i) + 4|0);
      HEAP32[$44>>2] = $43;
      $45 = (($$012$i$i$i$i$i) + 8|0);
      $46 = (($$03$i$i$i$i$i) + 8|0);
      $47 = ($45|0)==($40|0);
      if ($47) {
       break;
      } else {
       $$012$i$i$i$i$i = $45;$$03$i$i$i$i$i = $46;
      }
     }
     $__first5$i$i$i$i$i = $38;
     $48 = (0 - ($__first5$i$i$i$i$i))|0;
     $uglygep$i$i3$i$i$i = (($scevgep$i$i1$i$i$i) + ($48)|0);
     $uglygep6$i$i$i$i$i = $uglygep$i$i3$i$i$i;
     $49 = $uglygep6$i$i$i$i$i >>> 3;
     $$sum5$i$i$i = (($49) + ($$sum$i$i$i))|0;
     $scevgep7$i$i$i$i$i = (($32) + ($$sum5$i$i$i<<3)|0);
     $$pre$i$i$i = HEAP32[$4>>2]|0;
     $$0$lcssa$i$i$i$i$i = $scevgep7$i$i$i$i$i;$51 = $$pre$i$i$i;
    }
    $50 = ($51|0)==($$0$lcssa$i$i$i$i$i|0);
    if ($50) {
     $$be39 = $37;$76 = $51;
    } else {
     $__new_last2$i$i$i$i$i = $$0$lcssa$i$i$i$i$i;
     $scevgep$i$i$i$i$i = (($51) + -8|0);
     $52 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($52)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $53 = $uglygep3$i$i$i$i$i >>> 3;
     $54 = $53 ^ -1;
     $scevgep4$i$i$i$i$i = (($51) + ($54<<3)|0);
     HEAP32[$4>>2] = $scevgep4$i$i$i$i$i;
     $$be39 = $37;$76 = $scevgep4$i$i$i$i$i;
    }
   } else {
    $55 = (($26) + 24|0);
    $56 = (Math_fround(Math_sqrt((Math_fround($16)))));
    $57 = $56 < Math_fround(0.0);
    if ($57) {
     $58 = Math_fround(-$56);
     $60 = $58;
    } else {
     $60 = $56;
    }
    $59 = !($60 <= Math_fround(9.99999997475242707878E-7));
    if ($59) {
     $61 = Math_fround($7 / $56);
     $62 = Math_fround($10 / $56);
     $63 = Math_fround($14 / $56);
     HEAPF32[$0>>2] = $61;
     HEAPF32[$17>>2] = $62;
     HEAPF32[$18>>2] = $63;
     HEAPF32[$19>>2] = $56;
     __ZN13SpeedTreeWind23SetDirectionAndStrengthERK8Vector4f($55,$0);
    } else {
     $64 = (($26) + 1516|0);
     $65 = Math_fround(HEAPF32[$64>>2]);
     $66 = (($26) + 1520|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = (($26) + 1524|0);
     $69 = Math_fround(HEAPF32[$68>>2]);
     HEAPF32[$1>>2] = $65;
     HEAPF32[$21>>2] = $67;
     HEAPF32[$22>>2] = $69;
     HEAPF32[$23>>2] = Math_fround(0.0);
     __ZN13SpeedTreeWind23SetDirectionAndStrengthERK8Vector4f($55,$1);
    }
    $70 = HEAP32[$24>>2]|0;
    $71 = (($70) + 24|0);
    __ZN13SpeedTreeWind7AdvanceEbd($71,1,$20);
    $72 = HEAP32[$24>>2]|0;
    $73 = (($72) + 1904|0);
    HEAP8[$73>>0] = 0;
    $74 = (($25) + 8|0);
    $$pre45 = HEAP32[$4>>2]|0;
    $$be39 = $74;$76 = $$pre45;
   }
   $75 = ($$be39|0)==($76|0);
   if ($75) {
    break;
   } else {
    $191 = $76;$25 = $$be39;
   }
  }
 }
 $77 = (($this) + 20|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($this) + 24|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($78|0)==($80|0);
 if ($81) {
  $190 = (($this) + 48|0);
  HEAPF32[$190>>2] = $currentTime;
  STACKTOP = sp;return;
 }
 $82 = Math_fround(HEAPF32[$globalWindVec>>2]);
 $83 = (($globalWindVec) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($globalWindVec) + 8|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($0) + 4|0);
 $88 = (($0) + 8|0);
 $89 = (($0) + 12|0);
 $90 = +$currentTime;
 $91 = (($1) + 4|0);
 $92 = (($1) + 8|0);
 $93 = (($1) + 12|0);
 $94 = (($0) + 4|0);
 $95 = (($0) + 8|0);
 $96 = (($0) + 12|0);
 $192 = $80;$98 = $78;
 while(1) {
  $97 = (($98) + 4|0);
  $99 = HEAP32[$97>>2]|0;
  $100 = (($99) + 1904|0);
  $101 = HEAP8[$100>>0]|0;
  $102 = ($101<<24>>24)==(0);
  if ($102) {
   $103 = ($99|0)==(0|0);
   if ($103) {
    $113 = $192;
   } else {
    $104 = HEAP32[583448>>2]|0;
    __ZN10MemoryPool10DeallocateEPv($104,$99);
    $$pre = HEAP32[$79>>2]|0;
    $113 = $$pre;
   }
   $105 = HEAP32[$77>>2]|0;
   $106 = $98;
   $107 = $105;
   $108 = (($106) - ($107))|0;
   $109 = $108 >> 3;
   $110 = (($105) + ($109<<3)|0);
   $$sum$i$i$i6 = (($109) + 1)|0;
   $111 = (($105) + ($$sum$i$i$i6<<3)|0);
   $112 = ($111|0)==($113|0);
   if ($112) {
    $$0$lcssa$i$i$i$i$i19 = $110;$124 = $113;
   } else {
    $scevgep$i$i1$i$i$i8 = (($113) + -8|0);
    $$012$i$i$i$i$i11 = $111;$$03$i$i$i$i$i10 = $110;
    while(1) {
     $114 = HEAP32[$$012$i$i$i$i$i11>>2]|0;
     HEAP32[$$03$i$i$i$i$i10>>2] = $114;
     $115 = (($$012$i$i$i$i$i11) + 4|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = (($$03$i$i$i$i$i10) + 4|0);
     HEAP32[$117>>2] = $116;
     $118 = (($$012$i$i$i$i$i11) + 8|0);
     $119 = (($$03$i$i$i$i$i10) + 8|0);
     $120 = ($118|0)==($113|0);
     if ($120) {
      break;
     } else {
      $$012$i$i$i$i$i11 = $118;$$03$i$i$i$i$i10 = $119;
     }
    }
    $__first5$i$i$i$i$i7 = $111;
    $121 = (0 - ($__first5$i$i$i$i$i7))|0;
    $uglygep$i$i3$i$i$i13 = (($scevgep$i$i1$i$i$i8) + ($121)|0);
    $uglygep6$i$i$i$i$i14 = $uglygep$i$i3$i$i$i13;
    $122 = $uglygep6$i$i$i$i$i14 >>> 3;
    $$sum5$i$i$i15 = (($122) + ($$sum$i$i$i6))|0;
    $scevgep7$i$i$i$i$i16 = (($105) + ($$sum5$i$i$i15<<3)|0);
    $$pre$i$i$i17 = HEAP32[$79>>2]|0;
    $$0$lcssa$i$i$i$i$i19 = $scevgep7$i$i$i$i$i16;$124 = $$pre$i$i$i17;
   }
   $123 = ($124|0)==($$0$lcssa$i$i$i$i$i19|0);
   if ($123) {
    $$be = $110;$189 = $124;
   } else {
    $__new_last2$i$i$i$i$i21 = $$0$lcssa$i$i$i$i$i19;
    $scevgep$i$i$i$i$i22 = (($124) + -8|0);
    $125 = (0 - ($__new_last2$i$i$i$i$i21))|0;
    $uglygep$i$i$i$i$i24 = (($scevgep$i$i$i$i$i22) + ($125)|0);
    $uglygep3$i$i$i$i$i25 = $uglygep$i$i$i$i$i24;
    $126 = $uglygep3$i$i$i$i$i25 >>> 3;
    $127 = $126 ^ -1;
    $scevgep4$i$i$i$i$i26 = (($124) + ($127<<3)|0);
    HEAP32[$79>>2] = $scevgep4$i$i$i$i$i26;
    $$be = $110;$189 = $scevgep4$i$i$i$i$i26;
   }
  } else {
   $128 = (__ZN11WindManager11GetInstanceEv()|0);
   $129 = (__ZN11WindManager7GetListEv($128)|0);
   $130 = (($129) + 4|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = ($131|0)==($129|0);
   if ($132) {
    $159 = Math_fround(0.0);$161 = Math_fround(0.0);$163 = Math_fround(0.0);
   } else {
    $134 = $131;$148 = Math_fround(0.0);$150 = Math_fround(0.0);$152 = Math_fround(0.0);
    while(1) {
     $133 = (($134) + 8|0);
     $135 = HEAP32[$133>>2]|0;
     $136 = (($135) + 32|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = ($137|0)==(1);
     if ($138) {
      $139 = (__ZNK8WindZone17ComputeWindVectorERK4AABBR8Vector4f($135,$99,$0)|0);
      if ($139) {
       $140 = Math_fround(HEAPF32[$0>>2]);
       $141 = Math_fround(HEAPF32[$94>>2]);
       $142 = Math_fround(HEAPF32[$95>>2]);
       $143 = Math_fround(HEAPF32[$96>>2]);
       $144 = Math_fround($140 * $143);
       $145 = Math_fround($141 * $143);
       $146 = Math_fround($142 * $143);
       $147 = Math_fround($148 + $144);
       $149 = Math_fround($150 + $145);
       $151 = Math_fround($152 + $146);
       $193 = $151;$194 = $149;$195 = $147;
      } else {
       $193 = $152;$194 = $150;$195 = $148;
      }
     } else {
      $193 = $152;$194 = $150;$195 = $148;
     }
     $153 = (($134) + 4|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = ($154|0)==($129|0);
     if ($155) {
      $159 = $195;$161 = $194;$163 = $193;
      break;
     } else {
      $134 = $154;$148 = $195;$150 = $194;$152 = $193;
     }
    }
   }
   $156 = HEAP32[$97>>2]|0;
   $157 = (($156) + 24|0);
   $158 = Math_fround($159 + $82);
   $160 = Math_fround($161 + $84);
   $162 = Math_fround($163 + $86);
   $164 = Math_fround($158 * $158);
   $165 = Math_fround($160 * $160);
   $166 = Math_fround($164 + $165);
   $167 = Math_fround($162 * $162);
   $168 = Math_fround($166 + $167);
   $169 = (Math_fround(Math_sqrt((Math_fround($168)))));
   $170 = $169 < Math_fround(0.0);
   if ($170) {
    $171 = Math_fround(-$169);
    $173 = $171;
   } else {
    $173 = $169;
   }
   $172 = !($173 <= Math_fround(9.99999997475242707878E-7));
   if ($172) {
    $174 = Math_fround($158 / $169);
    $175 = Math_fround($160 / $169);
    $176 = Math_fround($162 / $169);
    HEAPF32[$0>>2] = $174;
    HEAPF32[$87>>2] = $175;
    HEAPF32[$88>>2] = $176;
    HEAPF32[$89>>2] = $169;
    __ZN13SpeedTreeWind23SetDirectionAndStrengthERK8Vector4f($157,$0);
   } else {
    $177 = (($156) + 1516|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = (($156) + 1520|0);
    $180 = Math_fround(HEAPF32[$179>>2]);
    $181 = (($156) + 1524|0);
    $182 = Math_fround(HEAPF32[$181>>2]);
    HEAPF32[$1>>2] = $178;
    HEAPF32[$91>>2] = $180;
    HEAPF32[$92>>2] = $182;
    HEAPF32[$93>>2] = Math_fround(0.0);
    __ZN13SpeedTreeWind23SetDirectionAndStrengthERK8Vector4f($157,$1);
   }
   $183 = HEAP32[$97>>2]|0;
   $184 = (($183) + 24|0);
   __ZN13SpeedTreeWind7AdvanceEbd($184,1,$90);
   $185 = HEAP32[$97>>2]|0;
   $186 = (($185) + 1904|0);
   HEAP8[$186>>0] = 0;
   $187 = (($98) + 8|0);
   $$pre43 = HEAP32[$79>>2]|0;
   $$be = $187;$189 = $$pre43;
  }
  $188 = ($$be|0)==($189|0);
  if ($188) {
   break;
  } else {
   $192 = $189;$98 = $$be;
  }
 }
 $190 = (($this) + 48|0);
 HEAPF32[$190>>2] = $currentTime;
 STACKTOP = sp;return;
}
function __ZN20SpeedTreeWindManager25GetCachedGlobalWindVectorEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vec$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vec$i = sp;
 $0 = (($this) + 44|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 48|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $1 != $3;
 if (!($4)) {
  $43 = (($this) + 32|0);
  ;HEAP32[$agg$result+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$43+8>>2]|0;
  STACKTOP = sp;return;
 }
 $5 = (__ZN11WindManager11GetInstanceEv()|0);
 $6 = (__ZN11WindManager7GetListEv($5)|0);
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($6|0);
 if ($9) {
  $37 = Math_fround(0.0);$39 = Math_fround(0.0);$41 = Math_fround(0.0);
 } else {
  $10 = (($vec$i) + 4|0);
  $11 = (($vec$i) + 8|0);
  $12 = (($vec$i) + 12|0);
  $14 = $8;$28 = Math_fround(0.0);$30 = Math_fround(0.0);$32 = Math_fround(0.0);
  while(1) {
   $13 = (($14) + 8|0);
   $15 = HEAP32[$13>>2]|0;
   $16 = (($15) + 32|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0);
   if ($18) {
    $19 = (__ZNK8WindZone17ComputeWindVectorERK4AABBR8Vector4f($15,590472,$vec$i)|0);
    if ($19) {
     $20 = Math_fround(HEAPF32[$vec$i>>2]);
     $21 = Math_fround(HEAPF32[$10>>2]);
     $22 = Math_fround(HEAPF32[$11>>2]);
     $23 = Math_fround(HEAPF32[$12>>2]);
     $24 = Math_fround($20 * $23);
     $25 = Math_fround($21 * $23);
     $26 = Math_fround($22 * $23);
     $27 = Math_fround($28 + $24);
     $29 = Math_fround($30 + $25);
     $31 = Math_fround($32 + $26);
     $44 = $31;$45 = $29;$46 = $27;
    } else {
     $44 = $32;$45 = $30;$46 = $28;
    }
   } else {
    $44 = $32;$45 = $30;$46 = $28;
   }
   $33 = (($14) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==($6|0);
   if ($35) {
    $37 = $46;$39 = $45;$41 = $44;
    break;
   } else {
    $14 = $34;$28 = $46;$30 = $45;$32 = $44;
   }
  }
 }
 $36 = (($this) + 32|0);
 HEAPF32[$36>>2] = $37;
 $38 = (($this) + 36|0);
 HEAPF32[$38>>2] = $39;
 $40 = (($this) + 40|0);
 HEAPF32[$40>>2] = $41;
 $42 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$0>>2] = $42;
 $43 = (($this) + 32|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$43+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK20SpeedTreeWindManager14CreateWindDataERK4AABBPKNS_8WindDataEPK13SpeedTreeWindRK8Vector3f($this,$aabb,$prototype1,$prototype2,$windVector) {
 $this = $this|0;
 $aabb = $aabb|0;
 $prototype1 = $prototype1|0;
 $prototype2 = $prototype2|0;
 $windVector = $windVector|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0.0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = HEAP32[583448>>2]|0;
 $3 = (__ZN10MemoryPool8AllocateEj($2,1912)|0);
 _memset(($3|0),0,1912)|0;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;
 $4 = (($3) + 24|0);
 __THREW__ = 0;
 invoke_vi(3443,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP32[583448>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($11|0),($3|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $48 = ___cxa_find_matching_catch(0|0)|0;
   $49 = tempRet0;
   ___clang_call_terminate($48);
   // unreachable;
  } else {
   ___resumeException($9|0);
   // unreachable;
  }
 }
 ;HEAP32[$3+0>>2]=HEAP32[$aabb+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$aabb+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$aabb+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$aabb+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$aabb+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$aabb+20>>2]|0;
 $7 = ($prototype1|0)==(0|0);
 if ($7) {
  __ZN13SpeedTreeWind16CopySettingsFromEPKS_($4,$prototype2);
  $14 = (($this) + 48|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = +$15;
  __ZN13SpeedTreeWind7AdvanceEbd($4,1,$16);
 } else {
  $8 = (($prototype1) + 24|0);
  _memcpy(($4|0),($8|0),1880)|0;
 }
 $17 = Math_fround(HEAPF32[$windVector>>2]);
 $18 = Math_fround($17 * $17);
 $19 = (($windVector) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (($windVector) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 * $24);
 $26 = Math_fround($22 + $25);
 $27 = (Math_fround(Math_sqrt((Math_fround($26)))));
 $28 = $27 < Math_fround(0.0);
 if ($28) {
  $29 = Math_fround(-$27);
  $31 = $29;
 } else {
  $31 = $27;
 }
 $30 = !($31 <= Math_fround(9.99999997475242707878E-7));
 if ($30) {
  $32 = Math_fround($17 / $27);
  $33 = Math_fround($20 / $27);
  $34 = Math_fround($24 / $27);
  HEAPF32[$0>>2] = $32;
  $35 = (($0) + 4|0);
  HEAPF32[$35>>2] = $33;
  $36 = (($0) + 8|0);
  HEAPF32[$36>>2] = $34;
  $37 = (($0) + 12|0);
  HEAPF32[$37>>2] = $27;
  __ZN13SpeedTreeWind23SetDirectionAndStrengthERK8Vector4f($4,$0);
  $47 = (($3) + 1904|0);
  HEAP8[$47>>0] = 1;
  STACKTOP = sp;return ($3|0);
 } else {
  $38 = (($3) + 1516|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($3) + 1520|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($3) + 1524|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  HEAPF32[$1>>2] = $39;
  $44 = (($1) + 4|0);
  HEAPF32[$44>>2] = $41;
  $45 = (($1) + 8|0);
  HEAPF32[$45>>2] = $43;
  $46 = (($1) + 12|0);
  HEAPF32[$46>>2] = Math_fround(0.0);
  __ZN13SpeedTreeWind23SetDirectionAndStrengthERK8Vector4f($4,$1);
  $47 = (($3) + 1904|0);
  HEAP8[$47>>0] = 1;
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZNSt3__16vectorINS_4pairIjPN20SpeedTreeWindManager8WindDataEEE13stl_allocatorIS5_L18MemLabelIdentifier55ELi16EEE6insertENS_11__wrap_iterIPKS5_EERSB_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i14 = 0, $$0$i15 = 0, $$012$i$i$i12 = 0, $$03$i$i$i11 = 0, $$byval_copy4 = 0, $$pre = 0, $$pre$i10 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = HEAP32[$__position>>2]|0;
 $4 = $3;
 $5 = $2;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = (($2) + ($7<<3)|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = ($8|0)==($10|0);
  if ($14) {
   $15 = ($8|0)==(0|0);
   if ($15) {
    $27 = 0;
   } else {
    $16 = $__x;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 4)|0;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    $22 = $8;
    $23 = $22;
    HEAP32[$23>>2] = $18;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP32[$25>>2] = $21;
    $$pre = HEAP32[$9>>2]|0;
    $27 = $$pre;
   }
   $26 = (($27) + 8|0);
   HEAP32[$9>>2] = $26;
   $__p$0 = $8;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($7) + 1)|0;
  $28 = (($2) + ($$sum<<3)|0);
  $29 = $10;
  $30 = $28;
  $31 = (($29) - ($30))|0;
  $32 = $31 >> 3;
  $$sum18 = (($32) + ($7))|0;
  $33 = (($2) + ($$sum18<<3)|0);
  $34 = ($33>>>0)<($10>>>0);
  if ($34) {
   $36 = $10;$__i$01$i = $33;
   while(1) {
    $35 = ($36|0)==(0|0);
    if ($35) {
     $49 = 0;
    } else {
     $37 = $__i$01$i;
     $38 = $37;
     $39 = HEAP32[$38>>2]|0;
     $40 = (($37) + 4)|0;
     $41 = $40;
     $42 = HEAP32[$41>>2]|0;
     $43 = $36;
     $44 = $43;
     HEAP32[$44>>2] = $39;
     $45 = (($43) + 4)|0;
     $46 = $45;
     HEAP32[$46>>2] = $42;
     $$pre$i10 = HEAP32[$9>>2]|0;
     $49 = $$pre$i10;
    }
    $47 = (($__i$01$i) + 8|0);
    $48 = (($49) + 8|0);
    HEAP32[$9>>2] = $48;
    $50 = ($47>>>0)<($10>>>0);
    if ($50) {
     $36 = $48;$__i$01$i = $47;
    } else {
     break;
    }
   }
  }
  $51 = ($32|0)==(0);
  if (!($51)) {
   $$012$i$i$i12 = $33;$$03$i$i$i11 = $10;
   while(1) {
    $52 = (($$03$i$i$i11) + -8|0);
    $53 = (($$012$i$i$i12) + -8|0);
    $54 = HEAP32[$53>>2]|0;
    HEAP32[$52>>2] = $54;
    $55 = (($$012$i$i$i12) + -4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($$03$i$i$i11) + -4|0);
    HEAP32[$57>>2] = $56;
    $58 = ($53|0)==($8|0);
    if ($58) {
     break;
    } else {
     $$012$i$i$i12 = $53;$$03$i$i$i11 = $52;
    }
   }
  }
  $59 = ($8>>>0)>($__x>>>0);
  if ($59) {
   $__xr$0 = $__x;
  } else {
   $60 = HEAP32[$9>>2]|0;
   $61 = ($60>>>0)>($__x>>>0);
   $62 = (($__x) + 8|0);
   $$ = $61 ? $62 : $__x;
   $__xr$0 = $$;
  }
  $63 = HEAP32[$__xr$0>>2]|0;
  HEAP32[$8>>2] = $63;
  $64 = (($__xr$0) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($2) + ($7<<3)|0) + 4|0);
  HEAP32[$66>>2] = $65;
  $__p$0 = $8;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $67 = $10;
 $68 = (($67) - ($5))|0;
 $69 = $68 >> 3;
 $70 = (($69) + 1)|0;
 $71 = ($70|0)<(0);
 if ($71) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $72 = $12;
 $73 = (($72) - ($5))|0;
 $74 = $73 >> 3;
 $75 = ($74>>>0)<(1073741823);
 if ($75) {
  $78 = $73 >> 2;
  $79 = ($78>>>0)<($70>>>0);
  $80 = $79 ? $70 : $78;
  $81 = $8;
  $82 = $6 >> 3;
  $83 = ($80|0)==(0);
  if ($83) {
   $$0$i15 = 0;$127 = $81;$87 = 0;$88 = $82;
  } else {
   $$0$i14 = $80;$150 = $82;$151 = $81;
   label = 20;
  }
 } else {
  $76 = $8;
  $77 = $6 >> 3;
  $$0$i14 = 2147483647;$150 = $77;$151 = $76;
  label = 20;
 }
 if ((label|0) == 20) {
  $84 = $$0$i14 << 3;
  HEAP32[$0>>2] = 55;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $85 = (__Z15malloc_internaljj10MemLabelIdiPKci($84,16,$$byval_copy4,0,583472,79)|0);
  $$0$i15 = $$0$i14;$127 = $151;$87 = $85;$88 = $150;
 }
 $86 = (($87) + ($88<<3)|0);
 $89 = (($87) + ($$0$i15<<3)|0);
 $90 = ($88|0)==($$0$i15|0);
 do {
  if ($90) {
   $91 = ($88|0)>(0);
   if ($91) {
    $92 = (($88) + 1)|0;
    $93 = (($92|0) / -2)&-1;
    $$sum17 = (($93) + ($88))|0;
    $94 = (($87) + ($$sum17<<3)|0);
    $111 = $94;$137 = $89;
    break;
   }
   $95 = $88 << 1;
   $96 = ($88|0)==(0);
   $97 = $96 ? 1 : $95;
   $98 = $97 << 3;
   HEAP32[$0>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   $99 = (invoke_iiiiiii(102,($98|0),16,($$byval_copy4|0),0,(583472|0),79)|0);
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if (!($101)) {
    $102 = $97 >>> 2;
    $103 = (($99) + ($102<<3)|0);
    $104 = (($99) + ($97<<3)|0);
    $105 = ($87|0)==(0|0);
    if ($105) {
     $111 = $103;$137 = $104;
     break;
    }
    HEAP32[$0>>2] = 55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($87|0),($$byval_copy4|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if (!($107)) {
     $111 = $103;$137 = $104;
     break;
    }
    $108 = ___cxa_find_matching_catch()|0;
    $109 = tempRet0;
    ___cxa_call_unexpected(($108|0));
    // unreachable;
   }
   $143 = ___cxa_find_matching_catch()|0;
   $144 = tempRet0;
   $145 = ($87|0)==(0|0);
   if ($145) {
    ___resumeException($143|0);
    // unreachable;
   }
   HEAP32[$1>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($87|0),($$byval_copy4|0));
   $146 = __THREW__; __THREW__ = 0;
   $147 = $146&1;
   if ($147) {
    $148 = ___cxa_find_matching_catch()|0;
    $149 = tempRet0;
    ___cxa_call_unexpected(($148|0));
    // unreachable;
   } else {
    ___resumeException($143|0);
    // unreachable;
   }
  } else {
   $111 = $86;$137 = $89;
  }
 } while(0);
 $110 = ($111|0)==(0|0);
 if ($110) {
  $123 = 0;
 } else {
  $112 = $__x;
  $113 = $112;
  $114 = HEAP32[$113>>2]|0;
  $115 = (($112) + 4)|0;
  $116 = $115;
  $117 = HEAP32[$116>>2]|0;
  $118 = $111;
  $119 = $118;
  HEAP32[$119>>2] = $114;
  $120 = (($118) + 4)|0;
  $121 = $120;
  HEAP32[$121>>2] = $117;
  $123 = $111;
 }
 $122 = (($123) + 8|0);
 $124 = HEAP32[$this>>2]|0;
 $125 = $124;
 $126 = (($127) - ($125))|0;
 $128 = $126 >> 3;
 $129 = (0 - ($128))|0;
 $130 = (($111) + ($129<<3)|0);
 _memcpy(($130|0),($124|0),($126|0))|0;
 $131 = HEAP32[$9>>2]|0;
 $132 = $131;
 $133 = (($132) - ($127))|0;
 $134 = $133 >> 3;
 _memcpy(($122|0),($8|0),($133|0))|0;
 $$sum16 = (($134) + 1)|0;
 $135 = (($123) + ($$sum16<<3)|0);
 $136 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $130;
 HEAP32[$9>>2] = $135;
 HEAP32[$11>>2] = $137;
 $138 = ($136|0)==(0|0);
 if ($138) {
  $__p$0 = $111;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($136|0),($$byval_copy4|0));
 $139 = __THREW__; __THREW__ = 0;
 $140 = $139&1;
 if ($140) {
  $141 = ___cxa_find_matching_catch()|0;
  $142 = tempRet0;
  ___cxa_call_unexpected(($141|0));
  // unreachable;
 } else {
  $__p$0 = $111;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
}
function __GLOBAL__I_a2967() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,582944);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[582936>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,582968);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[582960>>2] = $2;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,582992);
 $3 = HEAP32[$0>>2]|0;
 HEAP32[582984>>2] = $3;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583016);
 $4 = HEAP32[$0>>2]|0;
 HEAP32[583008>>2] = $4;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583048);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[583040>>2] = $5;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583080);
 $6 = HEAP32[$0>>2]|0;
 HEAP32[583072>>2] = $6;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583112);
 $7 = HEAP32[$0>>2]|0;
 HEAP32[583104>>2] = $7;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583152);
 $8 = HEAP32[$0>>2]|0;
 HEAP32[583144>>2] = $8;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583184);
 $9 = HEAP32[$0>>2]|0;
 HEAP32[583176>>2] = $9;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583216);
 $10 = HEAP32[$0>>2]|0;
 HEAP32[583208>>2] = $10;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583248);
 $11 = HEAP32[$0>>2]|0;
 HEAP32[583240>>2] = $11;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583280);
 $12 = HEAP32[$0>>2]|0;
 HEAP32[583272>>2] = $12;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583312);
 $13 = HEAP32[$0>>2]|0;
 HEAP32[583304>>2] = $13;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583344);
 $14 = HEAP32[$0>>2]|0;
 HEAP32[583336>>2] = $14;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583376);
 $15 = HEAP32[$0>>2]|0;
 HEAP32[583368>>2] = $15;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583400);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,583432);
 $16 = HEAP32[$0>>2]|0;
 HEAP32[583424>>2] = $16;
 __ZN35RegisterRuntimeInitializeAndCleanupC2EPFvvES1_i(583456,109,110,0);
 STACKTOP = sp;return;
}
function __ZNK8WindZone17ComputeWindVectorERK4AABBR8Vector4f($this,$bounds,$outVec) {
 $this = $this|0;
 $bounds = $bounds|0;
 $outVec = $outVec|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $delta = 0, $position = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $position = sp + 12|0;
 $delta = sp;
 $0 = Math_fround(HEAPF32[$bounds>>2]);
 $1 = (($bounds) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($bounds) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($bounds) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($2 + $6);
 $8 = Math_fround($2 - $6);
 $9 = Math_fround($7 - $8);
 $10 = Math_fround($9 * Math_fround(0.25));
 $11 = Math_fround($2 + $10);
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($13)|0);
 __ZNK9Transform11GetPositionEv($position,$14);
 $15 = (($this) + 32|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  __ZNK9Transform18TransformDirectionERK8Vector3f($delta,$14,616744);
  $18 = Math_fround(HEAPF32[$delta>>2]);
  $19 = Math_fround($18 * $18);
  $20 = (($delta) + 4|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($21 * $21);
  $23 = Math_fround($19 + $22);
  $24 = (($delta) + 8|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($25 * $25);
  $27 = Math_fround($23 + $26);
  $28 = (Math_fround(Math_sqrt((Math_fround($27)))));
  $29 = Math_fround($18 / $28);
  $30 = Math_fround($21 / $28);
  $31 = Math_fround($25 / $28);
  HEAPF32[$delta>>2] = $29;
  HEAPF32[$20>>2] = $30;
  HEAPF32[$24>>2] = $31;
  $32 = (($this) + 40|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$outVec>>2] = $29;
  $34 = (($outVec) + 4|0);
  HEAPF32[$34>>2] = $30;
  $35 = (($outVec) + 8|0);
  HEAPF32[$35>>2] = $31;
  $36 = (($outVec) + 12|0);
  HEAPF32[$36>>2] = $33;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($position,$bounds)));
 $38 = (($this) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $39);
 $41 = Math_fround($37 / $40);
 $42 = Math_fround(Math_fround(1.0) - $41);
 $43 = $42 > Math_fround(0.0);
 if (!($43)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = Math_fround(HEAPF32[$position>>2]);
 $45 = Math_fround($0 - $44);
 $46 = (($position) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($11 - $47);
 $49 = (($position) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($4 - $50);
 $52 = Math_fround($45 * $45);
 $53 = Math_fround($48 * $48);
 $54 = Math_fround($52 + $53);
 $55 = Math_fround($51 * $51);
 $56 = Math_fround($54 + $55);
 $57 = (Math_fround(Math_sqrt((Math_fround($56)))));
 $58 = Math_fround($45 / $57);
 $59 = Math_fround($48 / $57);
 $60 = Math_fround($51 / $57);
 $61 = (($this) + 40|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 HEAPF32[$outVec>>2] = $58;
 $63 = (($outVec) + 4|0);
 HEAPF32[$63>>2] = $59;
 $64 = (($outVec) + 8|0);
 HEAPF32[$64>>2] = $60;
 $65 = (($outVec) + 12|0);
 HEAPF32[$65>>2] = $62;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK8WindZone16ComputeWindForceERK4AABBf($agg$result,$this,$bounds,$time) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $bounds = $bounds|0;
 $time = Math_fround($time);
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0);
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $delta = 0, $position = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $position = sp + 12|0;
 $delta = sp;
 $0 = Math_fround(HEAPF32[$bounds>>2]);
 $1 = (($bounds) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($bounds) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($bounds) + 16|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($2 + $6);
 $8 = Math_fround($2 - $6);
 $9 = Math_fround($7 - $8);
 $10 = Math_fround($9 * Math_fround(0.25));
 $11 = Math_fround($2 + $10);
 $12 = Math_fround($time * Math_fround(3.14159274101257324219));
 $13 = (($this) + 52|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 * $14);
 $16 = Math_fround($0 * Math_fround(0.100000001490116119385));
 $17 = Math_fround($16 + $15);
 $18 = Math_fround($4 * Math_fround(0.100000001490116119385));
 $19 = Math_fround($18 + $17);
 $20 = (Math_fround(+(Math_cos((+$19)))));
 $21 = Math_fround($19 * Math_fround(0.375));
 $22 = (Math_fround(+(Math_cos((+$21)))));
 $23 = Math_fround($20 + $22);
 $24 = Math_fround($19 * Math_fround(0.0500000007450580596924));
 $25 = (Math_fround(+(Math_cos((+$24)))));
 $26 = Math_fround($23 + $25);
 $27 = Math_fround($26 * Math_fround(0.333000004291534423828));
 $28 = (($this) + 48|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $27);
 $31 = Math_fround($30 + Math_fround(1.0));
 $32 = (($this) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($33)|0);
 __ZNK9Transform11GetPositionEv($position,$34);
 $35 = (($this) + 32|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  __ZNK9Transform18TransformDirectionERK8Vector3f($delta,$34,616744);
  $38 = Math_fround(HEAPF32[$delta>>2]);
  $39 = Math_fround($38 * $38);
  $40 = (($delta) + 4|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($41 * $41);
  $43 = Math_fround($39 + $42);
  $44 = (($delta) + 8|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($45 * $45);
  $47 = Math_fround($43 + $46);
  $48 = (Math_fround(Math_sqrt((Math_fround($47)))));
  $49 = Math_fround($38 / $48);
  $50 = Math_fround($41 / $48);
  $51 = Math_fround($45 / $48);
  HEAPF32[$delta>>2] = $49;
  HEAPF32[$40>>2] = $50;
  HEAPF32[$44>>2] = $51;
  $52 = (($this) + 40|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($49 * $53);
  $55 = Math_fround($31 * $54);
  $56 = Math_fround($53 * $50);
  $57 = Math_fround($31 * $56);
  $58 = Math_fround($51 * $53);
  $59 = Math_fround($31 * $58);
  $60 = (($this) + 44|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($31 * $61);
  HEAPF32[$agg$result>>2] = $55;
  $63 = (($agg$result) + 4|0);
  HEAPF32[$63>>2] = $57;
  $64 = (($agg$result) + 8|0);
  HEAPF32[$64>>2] = $59;
  $65 = (($agg$result) + 12|0);
  HEAPF32[$65>>2] = $62;
  STACKTOP = sp;return;
 }
 $66 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($position,$bounds)));
 $67 = (($this) + 36|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 * $68);
 $70 = Math_fround($66 / $69);
 $71 = Math_fround(Math_fround(1.0) - $70);
 $72 = $71 > Math_fround(0.0);
 if ($72) {
  $73 = Math_fround($31 * $71);
  $74 = Math_fround(HEAPF32[$position>>2]);
  $75 = Math_fround($0 - $74);
  $76 = (($position) + 4|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = Math_fround($11 - $77);
  $79 = (($position) + 8|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = Math_fround($4 - $80);
  $82 = Math_fround($75 * $75);
  $83 = Math_fround($78 * $78);
  $84 = Math_fround($82 + $83);
  $85 = Math_fround($81 * $81);
  $86 = Math_fround($84 + $85);
  $87 = (Math_fround(Math_sqrt((Math_fround($86)))));
  $88 = Math_fround($75 / $87);
  $89 = Math_fround($78 / $87);
  $90 = Math_fround($81 / $87);
  $91 = (($this) + 40|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = Math_fround($88 * $92);
  $94 = Math_fround($73 * $93);
  $95 = Math_fround($89 * $92);
  $96 = Math_fround($73 * $95);
  $97 = Math_fround($90 * $92);
  $98 = Math_fround($73 * $97);
  $99 = (($this) + 44|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($73 * $100);
  HEAPF32[$agg$result>>2] = $94;
  $102 = (($agg$result) + 4|0);
  HEAPF32[$102>>2] = $96;
  $103 = (($agg$result) + 8|0);
  HEAPF32[$103>>2] = $98;
  $104 = (($agg$result) + 12|0);
  HEAPF32[$104>>2] = $101;
  STACKTOP = sp;return;
 } else {
  ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
  STACKTOP = sp;return;
 }
}
function __ZN11WindManager11GetInstanceEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[583512>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN11WindManager16StaticInitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(8,$$byval_copy,0,16,583520,183)|0);
 $3 = (($2) + 4|0);
 HEAP32[$2>>2] = $2;
 HEAP32[$3>>2] = $2;
 HEAP32[583512>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN11WindManager13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $node$01$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[583512>>2]|0;
 $2 = HEAP32[628352>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($1|0);
  if (!($6)) {
   $node$01$i$i$i = $5;
   while(1) {
    $7 = (($node$01$i$i$i) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    HEAP32[$node$01$i$i$i>>2] = 0;
    HEAP32[$7>>2] = 0;
    $9 = ($8|0)==($1|0);
    if ($9) {
     break;
    } else {
     $node$01$i$i$i = $8;
    }
   }
  }
  HEAP32[$4>>2] = 0;
  HEAP32[$1>>2] = 0;
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[583512>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11WindManager7GetListEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZN11WindManager16ComputeWindForceERK4AABB($agg$result,$this,$bounds) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $bounds = $bounds|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0.0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Z14GetTimeManagerv()|0);
 $2 = (($1) + 88|0);
 $3 = +HEAPF64[$2>>3];
 $4 = (($1) + 160|0);
 $5 = +HEAPF64[$4>>3];
 $6 = $3 + $5;
 $7 = Math_fround($6);
 $8 = (($agg$result) + 4|0);
 $9 = (($agg$result) + 8|0);
 $10 = (($agg$result) + 12|0);
 $11 = (($this) + 4|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($this|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($0) + 4|0);
 $15 = (($0) + 8|0);
 $16 = (($0) + 12|0);
 $18 = $12;$22 = Math_fround(0.0);$25 = Math_fround(0.0);$28 = Math_fround(0.0);$31 = Math_fround(0.0);
 while(1) {
  $17 = (($18) + 8|0);
  $19 = HEAP32[$17>>2]|0;
  __ZNK8WindZone16ComputeWindForceERK4AABBf($0,$19,$bounds,$7);
  $20 = Math_fround(HEAPF32[$0>>2]);
  $21 = Math_fround($22 + $20);
  $23 = Math_fround(HEAPF32[$14>>2]);
  $24 = Math_fround($25 + $23);
  $26 = Math_fround(HEAPF32[$15>>2]);
  $27 = Math_fround($28 + $26);
  $29 = Math_fround(HEAPF32[$16>>2]);
  $30 = Math_fround($31 + $29);
  HEAPF32[$agg$result>>2] = $21;
  HEAPF32[$8>>2] = $24;
  HEAPF32[$9>>2] = $27;
  HEAPF32[$10>>2] = $30;
  $32 = (($18) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==($this|0);
  if ($34) {
   break;
  } else {
   $18 = $33;$22 = $21;$25 = $24;$28 = $27;$31 = $30;
  }
 }
 STACKTOP = sp;return;
}
function __ZN17CollisionMeshDataC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP8[$this+16>>0]=0|0;
 STACKTOP = sp;return;
}
function __ZN17CollisionMeshDataD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__Z11GetIPhysicsv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 52|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$0>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($3,$7);
  HEAP32[$0>>2] = 0;
 }
 $8 = (($this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (__Z11GetIPhysicsv()|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($11,$15);
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17CollisionMeshData7CleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__Z11GetIPhysicsv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 52|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$0>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($3,$7);
  HEAP32[$0>>2] = 0;
 }
 $8 = (($this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (__Z11GetIPhysicsv()|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 56|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($11,$15);
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17CollisionMeshData20VertexDataHasChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   STACKTOP = sp;return;
  }
 }
 $6 = (($this) + 16|0);
 HEAP8[$6>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN17CollisionMeshData15GetSharedNxMeshER4Mesh($this,$meshData) {
 $this = $this|0;
 $meshData = $meshData|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $identity = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $identity = sp;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (__ZN10Matrix4x4f11SetIdentityEv($identity)|0);
  $3 = (__Z11GetIPhysicsv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$meshData,0,$identity,0)|0);
  HEAP32[$0>>2] = $7;
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN17CollisionMeshData21GetSharedNxConvexMeshER4Mesh($this,$meshData) {
 $this = $this|0;
 $meshData = $meshData|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $identity = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $identity = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (__ZN10Matrix4x4f11SetIdentityEv($identity)|0);
  $3 = (__Z11GetIPhysicsv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiiiii[$6 & 255]($3,$meshData,1,$identity,0)|0);
  HEAP32[$0>>2] = $7;
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN17CollisionMeshData21AwakeFromLoadThreadedER4Mesh($this,$meshData) {
 $this = $this|0;
 $meshData = $meshData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $identity = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $identity = sp;
 $0 = (($meshData) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__Z11GetIPhysicsv()|0);
 (__ZN10Matrix4x4f11SetIdentityEv($identity)|0);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = $1 & 4;
  $7 = ($6|0)==(0);
  if (!($7)) {
   $8 = HEAP32[$2>>2]|0;
   $9 = (($8) + 32|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_iiiiii[$10 & 255]($2,$meshData,0,$identity,0)|0);
   HEAP32[$3>>2] = $11;
  }
 }
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = $1 & 2;
 $16 = ($15|0)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$2>>2]|0;
 $18 = (($17) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_iiiiii[$19 & 255]($2,$meshData,1,$identity,0)|0);
 HEAP32[$12>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN17CollisionMeshData13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z24RegisterAllInternalCallsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z32RegisterAllStrippedInternalCallsv();
 STACKTOP = sp;return;
}
function __ZNK3WWW6IsDoneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 92|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
  $8 = $7;
  STACKTOP = sp;return ($8|0);
 } else {
  $3 = (__ZNK14UnityWebStream10IsFinishedEv($1)|0);
  $8 = $3;
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __ZN3WWW6RetainEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return;
}
function __ZN3WWW7ReleaseEv($this) {
 $this = $this|0;
 var $$not = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$0>>2]|0;
 $$not = ($3|0)!=(0);
 $4 = ($this|0)==(0|0);
 $or$cond = $4 | $$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vi[$7 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN12WWWDelayCall7CleanupEPv($userData) {
 $userData = $userData|0;
 var $$not$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($userData|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$userData>>2]|0;
 $2 = (($1) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = HEAP32[$2>>2]|0;
 $$not$i$i = ($5|0)!=(0);
 $6 = ($1|0)==(0|0);
 $or$cond$i$i = $6 | $$not$i$i;
 if (!($or$cond$i$i)) {
  $7 = HEAP32[$1>>2]|0;
  $8 = (($7) + 88|0);
  $9 = HEAP32[$8>>2]|0;
  __THREW__ = 0;
  invoke_vi($9|0,($1|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $19 = ___cxa_find_matching_catch()|0;
   $20 = tempRet0;
   __ZdlPv($userData);
   ___resumeException($19|0);
   // unreachable;
  }
 }
 $12 = (($userData) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($userData) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  invoke_vi($13|0,($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $19 = ___cxa_find_matching_catch()|0;
   $20 = tempRet0;
   __ZdlPv($userData);
   ___resumeException($19|0);
   // unreachable;
  }
 }
 __ZdlPv($userData);
 STACKTOP = sp;return;
}
function __ZN12WWWDelayCall8CallbackEP6ObjectPv($o,$userData) {
 $o = $o|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$userData>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if (!($2)) {
   $3 = (($1) + 4|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    $7 = HEAP32[$1>>2]|0;
    $8 = (($7) + 92|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (FUNCTION_TABLE_ii[$9 & 4095]($1)|0);
    if ($10) {
     break;
    }
    STACKTOP = sp;return;
   } else {
    $6 = (__ZNK14UnityWebStream10IsFinishedEv($4)|0);
    if ($6) {
     break;
    }
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $11 = (($userData) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($userData) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$12 & 4095]($o,$14);
 $15 = (__Z21GetDelayedCallManagerv()|0);
 $16 = ($o|0)==(0|0);
 if ($16) {
  HEAP32[$0>>2] = 0;
 } else {
  $17 = (($o) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$0>>2] = $18;
 }
 __ZN18DelayedCallManager17CancelCallDelayedE4PPtrI6ObjectEPFvPS1_PvEPFbS4_S4_ES4_($15,$0,2660,2383,$userData);
 STACKTOP = sp;return;
}
function __ZN12WWWDelayCall14MatchForCancelEPvS0_($callBackUserData,$cancelUserData) {
 $callBackUserData = $callBackUserData|0;
 $cancelUserData = $cancelUserData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($callBackUserData|0)==($cancelUserData|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN3WWW12CallWhenDoneEPFvP6ObjectPvES1_S2_PFvS2_E($this,$func,$o,$userData,$cleanup) {
 $this = $this|0;
 $func = $func|0;
 $o = $o|0;
 $userData = $userData|0;
 $cleanup = $cleanup|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Znwj(20)|0);
 HEAP32[$1>>2] = $this;
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($1) + 4|0);
 HEAP32[$6>>2] = $func;
 $7 = (($1) + 8|0);
 HEAP32[$7>>2] = $o;
 $8 = (($1) + 12|0);
 HEAP32[$8>>2] = $userData;
 $9 = (($1) + 16|0);
 HEAP32[$9>>2] = $cleanup;
 $10 = ($o|0)==(0|0);
 if ($10) {
  HEAP32[$0>>2] = 0;
 } else {
  $11 = (($o) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  HEAP32[$0>>2] = $12;
 }
 __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(2660,$0,Math_fround(0.0),$1,Math_fround(-1.0),3444,10);
 STACKTOP = sp;return;
}
function __ZN22RenderingCommandBufferD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 36|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($this) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($7|0),($$byval_copy1|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   ___cxa_call_unexpected(($10|0));
   // unreachable;
  }
 }
 $12 = (($this) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)>(-1);
 if (!($14)) {
  $21 = (($this) + 4|0);
  __ZN14GrowableBufferD2Ev($21);
  STACKTOP = sp;return;
 }
 $15 = (($this) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 HEAP32[$0>>2] = $18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($16|0),($$byval_copy1|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if (!($20)) {
  HEAP32[$15>>2] = 0;
  $21 = (($this) + 4|0);
  __ZN14GrowableBufferD2Ev($21);
  STACKTOP = sp;return;
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $24 = (($this) + 4|0);
 __THREW__ = 0;
 invoke_vi(3445,($24|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($22|0);
  // unreachable;
 }
}
function __ZN22RenderingCommandBuffer14ReleaseTempRTsEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__Z22GetRenderBufferManagerv()|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $i$01 = 0;
  while(1) {
   $8 = HEAP32[$1>>2]|0;
   $9 = ((($8) + ($i$01<<3)|0) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($5,$10);
   $11 = (($i$01) + 1)|0;
   $12 = ($11|0)==($6|0);
   if ($12) {
    break;
   } else {
    $i$01 = $11;
   }
  }
 }
 $13 = (($this) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(-1);
 if ($15) {
  $16 = HEAP32[$1>>2]|0;
  $17 = (($this) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$0>>2] = $18;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($16,$$byval_copy);
  HEAP32[$1>>2] = 0;
 }
 HEAP32[$2>>2] = 0;
 HEAP32[$13>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN22RenderingCommandBuffer13GetAndCheckRTE24BuiltinRenderTextureTypeRKN9ShaderLab16FastPropertyNameEPKcPP13RenderTexture($this,$rtBuiltin,$rtName,$desc,$inoutRT) {
 $this = $this|0;
 $rtBuiltin = $rtBuiltin|0;
 $rtName = $rtName|0;
 $desc = $desc|0;
 $inoutRT = $inoutRT|0;
 var $$0 = 0, $$0$i = 0, $$04 = 0, $$05 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $i$02$i = 0, $or$cond = 0, $rtBuiltin$off = 0, $temp$0$i$i$i2$i = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer3 = sp;
 $0 = sp + 36|0;
 $1 = sp + 12|0;
 $2 = sp + 24|0;
 $rtBuiltin$off = (($rtBuiltin) + -1)|0;
 $3 = ($rtBuiltin$off>>>0)<(14);
 if (!($3)) {
  $73 = HEAP32[$rtName>>2]|0;
  $74 = ($73|0)==(-1);
  if ($74) {
   $$05 = 1;
   STACKTOP = sp;return ($$05|0);
  }
  $75 = (($this) + 28|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0);
  L6: do {
   if ($77) {
    label = 30;
   } else {
    $78 = (($this) + 20|0);
    $79 = HEAP32[$78>>2]|0;
    $i$02$i = 0;
    while(1) {
     $82 = (($79) + ($i$02$i<<3)|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==($73|0);
     $81 = (($i$02$i) + 1)|0;
     if ($84) {
      break;
     }
     $80 = ($81|0)==($76|0);
     if ($80) {
      label = 30;
      break L6;
     } else {
      $i$02$i = $81;
     }
    }
    $85 = ((($79) + ($i$02$i<<3)|0) + 4|0);
    $86 = HEAP32[$85>>2]|0;
    HEAP32[$inoutRT>>2] = $86;
    $87 = ($86|0)==(0|0);
    if (!($87)) {
     $$05 = 1;
     STACKTOP = sp;return ($$05|0);
    }
   }
  } while(0);
  if ((label|0) == 30) {
   HEAP32[$inoutRT>>2] = 0;
  }
  $88 = (__ZNK9ShaderLab16FastPropertyName7GetNameEv($rtName)|0);
  $89 = (($this) + 36|0);
  $90 = HEAP8[$89>>0]|0;
  $91 = $90 & 1;
  $92 = ($91<<24>>24)==(0);
  if ($92) {
   $95 = (($89) + 1|0);
   $96 = $95;
  } else {
   $93 = (($this) + 44|0);
   $94 = HEAP32[$93>>2]|0;
   $96 = $94;
  }
  HEAP32[$vararg_buffer3>>2] = $88;
  $vararg_ptr6 = (($vararg_buffer3) + 4|0);
  HEAP32[$vararg_ptr6>>2] = $96;
  $vararg_ptr7 = (($vararg_buffer3) + 8|0);
  HEAP32[$vararg_ptr7>>2] = $desc;
  __Z6FormatPKcz($2,583624,$vararg_buffer3);
  $97 = HEAP8[$2>>0]|0;
  $98 = $97 & 1;
  $99 = ($98<<24>>24)==(0);
  if ($99) {
   $102 = (($2) + 1|0);
   $103 = $102;
  } else {
   $100 = (($2) + 8|0);
   $101 = HEAP32[$100>>2]|0;
   $103 = $101;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($103|0),0,(583616|0),328,512,0,0,(0|0));
  $104 = __THREW__; __THREW__ = 0;
  $105 = $104&1;
  if ($105) {
   $111 = ___cxa_find_matching_catch()|0;
   $112 = tempRet0;
   $113 = HEAP8[$2>>0]|0;
   $114 = $113 & 1;
   $115 = ($114<<24>>24)==(0);
   if ($115) {
    $$0 = $112;$$04 = $111;
    ___resumeException($$04|0);
    // unreachable;
   }
   $116 = (($2) + 8|0);
   $117 = HEAP32[$116>>2]|0;
   __ZdlPv($117);
   $$0 = $112;$$04 = $111;
   ___resumeException($$04|0);
   // unreachable;
  } else {
   $106 = HEAP8[$2>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $$05 = 0;
    STACKTOP = sp;return ($$05|0);
   }
   $109 = (($2) + 8|0);
   $110 = HEAP32[$109>>2]|0;
   __ZdlPv($110);
   $$05 = 0;
   STACKTOP = sp;return ($$05|0);
  }
 }
 $4 = (__Z16GetRenderManagerv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $5;
   $7 = HEAP32[560624>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 11;
   } else {
    $9 = (($7) + 36|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    do {
     if ($13) {
      $14 = (($7) + 28|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($7) + 32|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($15) + ($17<<3)|0);
      $34 = $18;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer3,$7,$0);
      $19 = HEAP32[$vararg_buffer3>>2]|0;
      $20 = ($19|0)==(-1);
      $21 = (($7) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      if ($20) {
       $23 = (($7) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $34 = $25;
       break;
      } else {
       $26 = (($22) + ($19<<3)|0);
       $34 = $26;
       break;
      }
     }
    } while(0);
    $27 = HEAP32[560624>>2]|0;
    $28 = (($27) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + ($31<<3)|0);
    $33 = ($34|0)==($32|0);
    if ($33) {
     label = 11;
    } else {
     $35 = (($34) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      label = 11;
     } else {
      $temp$0$i$i$i2$i = $36;
     }
    }
   }
   if ((label|0) == 11) {
    $38 = HEAP32[$4>>2]|0;
    $39 = (__Z31ReadObjectFromPersistentManageri($38)|0);
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$0$i = 0;
     break;
    } else {
     $temp$0$i$i$i2$i = $39;
    }
   }
   $41 = (__ZN6Camera23GetBuiltinRenderTextureE24BuiltinRenderTextureType($temp$0$i$i$i2$i,$rtBuiltin)|0);
   $$0$i = $41;
  }
 } while(0);
 HEAP32[$inoutRT>>2] = $$0$i;
 $42 = ($$0$i|0)==(0|0);
 $43 = ($rtBuiltin$off>>>0)>(1);
 $or$cond = $42 & $43;
 if (!($or$cond)) {
  $$05 = 1;
  STACKTOP = sp;return ($$05|0);
 }
 $44 = (($this) + 36|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = $45 & 1;
 $47 = ($46<<24>>24)==(0);
 if ($47) {
  $50 = (($44) + 1|0);
  $51 = $50;
 } else {
  $48 = (($this) + 44|0);
  $49 = HEAP32[$48>>2]|0;
  $51 = $49;
 }
 HEAP32[$vararg_buffer3>>2] = $rtBuiltin;
 $vararg_ptr1 = (($vararg_buffer3) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $51;
 $vararg_ptr2 = (($vararg_buffer3) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $desc;
 __Z6FormatPKcz($1,583528,$vararg_buffer3);
 $52 = HEAP8[$1>>0]|0;
 $53 = $52 & 1;
 $54 = ($53<<24>>24)==(0);
 if ($54) {
  $57 = (($1) + 1|0);
  $58 = $57;
 } else {
  $55 = (($1) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  $58 = $56;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($58|0),0,(583616|0),319,512,0,0,(0|0));
 $59 = __THREW__; __THREW__ = 0;
 $60 = $59&1;
 if ($60) {
  $66 = ___cxa_find_matching_catch()|0;
  $67 = tempRet0;
  $68 = HEAP8[$1>>0]|0;
  $69 = $68 & 1;
  $70 = ($69<<24>>24)==(0);
  if ($70) {
   $$0 = $67;$$04 = $66;
   ___resumeException($$04|0);
   // unreachable;
  }
  $71 = (($1) + 8|0);
  $72 = HEAP32[$71>>2]|0;
  __ZdlPv($72);
  $$0 = $67;$$04 = $66;
  ___resumeException($$04|0);
  // unreachable;
 } else {
  $61 = HEAP8[$1>>0]|0;
  $62 = $61 & 1;
  $63 = ($62<<24>>24)==(0);
  if ($63) {
   $$05 = 0;
   STACKTOP = sp;return ($$05|0);
  }
  $64 = (($1) + 8|0);
  $65 = HEAP32[$64>>2]|0;
  __ZdlPv($65);
  $$05 = 0;
  STACKTOP = sp;return ($$05|0);
 }
 return 0|0;
}
function __ZN22RenderingCommandBuffer20ExecuteCommandBufferERN9ShaderLab17ShaderPassContextE($this,$passContext) {
 $this = $this|0;
 $passContext = $passContext|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$0$i23 = 0, $$0$i62 = 0, $$0$i70 = 0, $$0$i78 = 0, $$0$i82 = 0, $$0$i90 = 0, $$01$i = 0, $$03 = 0, $$193 = 0, $$194 = 0, $$195 = 0, $$be = 0, $$byval_copy50 = 0, $$in$i = 0, $$in$i33 = 0, $$in13$i = 0, $$in7$i = 0;
 var $$pre$i$i = 0, $$rtColorZero$0 = 0, $$sroa$0$0 = 0, $$sroa$01$0 = 0, $$sum = 0, $$sum105 = 0, $$sum106 = 0, $$sum107 = 0, $$sum108 = 0, $$sum109 = 0, $$sum110 = 0, $$sum111 = 0, $$sum112 = 0, $$sum113 = 0, $$sum114 = 0, $$sum115 = 0, $$sum116 = 0, $$sum117 = 0, $$sum118 = 0, $$sum119 = 0;
 var $$sum120 = 0, $$sum121 = 0, $$sum122 = 0, $$sum123 = 0, $$sum124 = 0, $$sum125 = 0, $$sum126 = 0, $$sum127 = 0, $$sum128 = 0, $$sum129 = 0, $$sum130 = 0, $$sum131 = 0, $$sum132 = 0, $$sum133 = 0, $$sum134 = 0, $$sum135 = 0, $$sum136 = 0, $$sum137 = 0, $$sum138 = 0, $$sum139 = 0;
 var $$sum140 = 0, $$sum141 = 0, $$sum142 = 0, $$sum143 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0;
 var $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = Math_fround(0), $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = Math_fround(0), $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $block$i = 0, $blockProps$0 = 0, $blockValues$0 = 0, $dest = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index10Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond$i = 0, $hadRTChanges$0$off0$be = 0, $hadRTChanges$0$off0177 = 0, $i$01$i = 0, $i$0184 = 0, $i5$0149 = 0, $lastCmdType$0$be = 0, $lastCmdType$0176 = 0;
 var $lpad$phi$i$index = 0, $lpad$phi$i$index23 = 0, $ok4$0$off0$lcssa = 0, $ok4$0$off0151 = 0, $or$cond$i = 0, $or$cond$i38 = 0, $p$011$i = 0, $p$05$i = 0, $preserveMVPState = 0, $prevRTColor = 0, $rsColor = 0, $rt = 0, $rt16 = 0, $rtColor = 0, $rtColorZero$0$lcssa = 0, $rtColorZero$0150 = 0, $rtDepth = 0, $srcRT = 0, $temp$0$i = 0, $temp$0$i61 = 0;
 var $temp$0$i69 = 0, $temp$0$i77 = 0, $temp$0$i81 = 0, $temp$0$i89 = 0, $temp$0$i97191 = 0, $vararg_ptr40 = 0, $vararg_ptr41 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $$byval_copy50 = sp;
 $0 = sp + 428|0;
 $1 = sp + 424|0;
 $2 = sp + 420|0;
 $3 = sp + 416|0;
 $4 = sp + 412|0;
 $5 = sp + 408|0;
 $6 = sp + 404|0;
 $7 = sp + 400|0;
 $8 = sp + 396|0;
 $9 = sp + 392|0;
 $10 = sp + 380|0;
 $11 = sp + 376|0;
 $12 = sp + 372|0;
 $13 = sp + 368|0;
 $14 = sp + 432|0;
 $block$i = sp + 292|0;
 $15 = sp + 280|0;
 $16 = sp + 12|0;
 $preserveMVPState = sp + 16|0;
 $prevRTColor = sp + 208|0;
 $rt = sp + 240|0;
 $rsColor = sp + 248|0;
 $rtColor = sp + 360|0;
 $rtDepth = sp + 328|0;
 $17 = sp + 332|0;
 $srcRT = sp + 336|0;
 $dest = sp + 340|0;
 $rt16 = sp + 344|0;
 $18 = sp + 348|0;
 $19 = sp + 364|0;
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (__Z12GetGfxDevicev()|0);
 __ZN22DeviceMVPMatricesStateC2Ev($preserveMVPState);
 __THREW__ = 0;
 $24 = (invoke_i(82)|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 L4: do {
  if ($26) {
   label = 12;
  } else {
   $27 = HEAP32[$23>>2]|0;
   $28 = (($27) + 428|0);
   $29 = HEAP32[$28>>2]|0;
   __THREW__ = 0;
   $30 = (invoke_ii($29|0,($23|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 12;
   } else {
    ;HEAP32[$prevRTColor+0>>2]=0|0;HEAP32[$prevRTColor+4>>2]=0|0;HEAP32[$prevRTColor+8>>2]=0|0;HEAP32[$prevRTColor+12>>2]=0|0;HEAP32[$prevRTColor+16>>2]=0|0;HEAP32[$prevRTColor+20>>2]=0|0;HEAP32[$prevRTColor+24>>2]=0|0;HEAP32[$prevRTColor+28>>2]=0|0;
    $33 = ($30|0)>(0);
    L7: do {
     if ($33) {
      $i$0184 = 0;
      while(1) {
       $34 = HEAP32[$23>>2]|0;
       $35 = (($34) + 420|0);
       $36 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       $37 = (invoke_iii($36|0,($23|0),($i$0184|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
       $40 = (($prevRTColor) + ($i$0184<<2)|0);
       HEAP32[$40>>2] = $37;
       $41 = (($i$0184) + 1)|0;
       $42 = ($41|0)<($30|0);
       if ($42) {
        $i$0184 = $41;
       } else {
        break L7;
       }
      }
      $49 = ___cxa_find_matching_catch()|0;
      $50 = tempRet0;
      $eh$lpad$body$index10Z2D = $50;$eh$lpad$body$indexZ2D = $49;
      label = 13;
      break L4;
     }
    } while(0);
    $53 = HEAP32[$23>>2]|0;
    $54 = (($53) + 424|0);
    $55 = HEAP32[$54>>2]|0;
    __THREW__ = 0;
    $56 = (invoke_ii($55|0,($23|0))|0);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     label = 12;
    } else {
     $59 = (($23) + 5792|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = HEAP8[678904>>0]|0;
     HEAP8[678904>>0] = 1;
     $62 = (($this) + 4|0);
     $63 = (($this) + 36|0);
     $64 = (($63) + 1|0);
     $65 = (($18) + 1|0);
     $66 = (($18) + 8|0);
     $67 = (($this) + 44|0);
     $68 = (($block$i) + 28|0);
     $69 = (($block$i) + 16|0);
     $70 = (($block$i) + 20|0);
     $71 = (($block$i) + 12|0);
     $72 = (($block$i) + 4|0);
     $73 = (($15) + 1|0);
     $74 = (($15) + 8|0);
     $75 = (($10) + 1|0);
     $76 = (($10) + 8|0);
     $77 = (($passContext) + 20|0);
     $78 = (($this) + 28|0);
     $79 = (($this) + 32|0);
     $80 = (($this) + 20|0);
     $81 = (($this) + 24|0);
     $82 = (($this) + 20|0);
     $84 = 0;$hadRTChanges$0$off0177 = 0;$lastCmdType$0176 = 12;
     L15: while(1) {
      $83 = (($84) + 3)|0;
      $85 = $83 & -4;
      $86 = HEAP32[$62>>2]|0;
      $87 = (($86) + ($85)|0);
      $88 = HEAP32[$87>>2]|0;
      L17: do {
       switch ($88|0) {
       case 1:  {
        $89 = (($85) + 7)|0;
        $90 = $89 & -4;
        $91 = (($90) + 84)|0;
        $92 = (($86) + ($90)|0);
        $$sum136 = (($90) + 76)|0;
        $93 = (($86) + ($$sum136)|0);
        $94 = HEAP32[$93>>2]|0;
        $95 = ($94|0)==(0);
        if ($95) {
         $1020 = $91;$blockProps$0 = 0;$blockValues$0 = 0;
        } else {
         $$sum137 = (($90) + 80)|0;
         $96 = (($86) + ($$sum137)|0);
         $97 = HEAP32[$96>>2]|0;
         $98 = ($97|0)==(0);
         if ($98) {
          $1020 = $91;$blockProps$0 = 0;$blockValues$0 = 0;
         } else {
          $99 = $94 << 4;
          $100 = (($90) + 87)|0;
          $101 = $100 & -4;
          $102 = (($99) + ($101))|0;
          $103 = (($86) + ($101)|0);
          $104 = $97 << 2;
          $105 = (($104) + ($102))|0;
          $106 = (($86) + ($102)|0);
          $1020 = $105;$blockProps$0 = $103;$blockValues$0 = $106;
         }
        }
        $$sum138 = (($90) + 68)|0;
        $107 = (($86) + ($$sum138)|0);
        $108 = HEAP32[$107>>2]|0;
        $109 = ($108|0)==(0);
        if ($109) {
         $$be = $1020;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 1;
        } else {
         HEAP32[$14>>2] = $108;
         $110 = HEAP32[560624>>2]|0;
         $111 = ($110|0)==(0|0);
         if ($111) {
          label = 29;
         } else {
          $112 = (($110) + 36|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = (($110) + 4|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = ($113|0)==($115|0);
          do {
           if ($116) {
            $117 = (($110) + 28|0);
            $118 = HEAP32[$117>>2]|0;
            $119 = (($110) + 32|0);
            $120 = HEAP32[$119>>2]|0;
            $121 = (($118) + ($120<<3)|0);
            $137 = $121;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$110,$14);
            $122 = HEAP32[$$byval_copy50>>2]|0;
            $123 = ($122|0)==(-1);
            $124 = (($110) + 28|0);
            $125 = HEAP32[$124>>2]|0;
            if ($123) {
             $126 = (($110) + 32|0);
             $127 = HEAP32[$126>>2]|0;
             $128 = (($125) + ($127<<3)|0);
             $137 = $128;
             break;
            } else {
             $129 = (($125) + ($122<<3)|0);
             $137 = $129;
             break;
            }
           }
          } while(0);
          $130 = HEAP32[560624>>2]|0;
          $131 = (($130) + 28|0);
          $132 = HEAP32[$131>>2]|0;
          $133 = (($130) + 32|0);
          $134 = HEAP32[$133>>2]|0;
          $135 = (($132) + ($134<<3)|0);
          $136 = ($137|0)==($135|0);
          if ($136) {
           label = 29;
          } else {
           $138 = (($137) + 4|0);
           $139 = HEAP32[$138>>2]|0;
           $140 = ($139|0)==(0|0);
           if ($140) {
            label = 29;
           } else {
            $$in$i = $139;
           }
          }
         }
         if ((label|0) == 29) {
          label = 0;
          $141 = HEAP32[$107>>2]|0;
          __THREW__ = 0;
          $142 = (invoke_ii(3215,($141|0))|0);
          $143 = __THREW__; __THREW__ = 0;
          $144 = $143&1;
          if ($144) {
           label = 10;
           break L15;
          }
          $145 = ($142|0)==(0|0);
          if ($145) {
           $$be = $1020;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 1;
           break L17;
          } else {
           $$in$i = $142;
          }
         }
         $$sum139 = (($90) + 64)|0;
         $146 = (($86) + ($$sum139)|0);
         $147 = HEAP32[$146>>2]|0;
         $148 = ($147|0)==(0);
         if ($148) {
          $$be = $1020;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 1;
         } else {
          HEAP32[$13>>2] = $147;
          $149 = HEAP32[560624>>2]|0;
          $150 = ($149|0)==(0|0);
          if ($150) {
           label = 40;
          } else {
           $151 = (($149) + 36|0);
           $152 = HEAP32[$151>>2]|0;
           $153 = (($149) + 4|0);
           $154 = HEAP32[$153>>2]|0;
           $155 = ($152|0)==($154|0);
           do {
            if ($155) {
             $156 = (($149) + 28|0);
             $157 = HEAP32[$156>>2]|0;
             $158 = (($149) + 32|0);
             $159 = HEAP32[$158>>2]|0;
             $160 = (($157) + ($159<<3)|0);
             $176 = $160;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$149,$13);
             $161 = HEAP32[$$byval_copy50>>2]|0;
             $162 = ($161|0)==(-1);
             $163 = (($149) + 28|0);
             $164 = HEAP32[$163>>2]|0;
             if ($162) {
              $165 = (($149) + 32|0);
              $166 = HEAP32[$165>>2]|0;
              $167 = (($164) + ($166<<3)|0);
              $176 = $167;
              break;
             } else {
              $168 = (($164) + ($161<<3)|0);
              $176 = $168;
              break;
             }
            }
           } while(0);
           $169 = HEAP32[560624>>2]|0;
           $170 = (($169) + 28|0);
           $171 = HEAP32[$170>>2]|0;
           $172 = (($169) + 32|0);
           $173 = HEAP32[$172>>2]|0;
           $174 = (($171) + ($173<<3)|0);
           $175 = ($176|0)==($174|0);
           if ($175) {
            label = 40;
           } else {
            $177 = (($176) + 4|0);
            $178 = HEAP32[$177>>2]|0;
            $179 = ($178|0)==(0|0);
            if ($179) {
             label = 40;
            } else {
             $$in13$i = $178;
            }
           }
          }
          if ((label|0) == 40) {
           label = 0;
           $180 = HEAP32[$146>>2]|0;
           __THREW__ = 0;
           $181 = (invoke_ii(3215,($180|0))|0);
           $182 = __THREW__; __THREW__ = 0;
           $183 = $182&1;
           if ($183) {
            label = 10;
            break L15;
           }
           $184 = ($181|0)==(0|0);
           if ($184) {
            $$be = $1020;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 1;
            break L17;
           } else {
            $$in13$i = $181;
           }
          }
          $185 = HEAP32[$93>>2]|0;
          $$sum140 = (($90) + 80)|0;
          $186 = (($86) + ($$sum140)|0);
          $187 = HEAP32[$186>>2]|0;
          __THREW__ = 0;
          invoke_viiiii(94,($block$i|0),($blockProps$0|0),($185|0),($blockValues$0|0),($187|0));
          $188 = __THREW__; __THREW__ = 0;
          $189 = $188&1;
          if ($189) {
           label = 10;
           break L15;
          }
          __THREW__ = 0;
          $190 = (invoke_i(59)|0);
          $191 = __THREW__; __THREW__ = 0;
          $192 = $191&1;
          if ($192) {
           label = 54;
           break L15;
          }
          __THREW__ = 0;
          $193 = (invoke_ii(3226,($$in$i|0))|0);
          $194 = __THREW__; __THREW__ = 0;
          $195 = $194&1;
          if ($195) {
           label = 54;
           break L15;
          }
          __THREW__ = 0;
          invoke_vii(2661,($92|0),1);
          $196 = __THREW__; __THREW__ = 0;
          $197 = $196&1;
          if ($197) {
           label = 54;
           break L15;
          }
          $$sum141 = (($90) + 74)|0;
          $198 = (($86) + ($$sum141)|0);
          $199 = HEAP16[$198>>1]|0;
          $200 = $199 << 16 >> 16;
          $201 = ($199<<16>>16)==(-1);
          do {
           if ($201) {
            $202 = ($193|0)>(0);
            if ($202) {
             $$sum143 = (($90) + 72)|0;
             $203 = (($86) + ($$sum143)|0);
             $p$011$i = 0;
             while(1) {
              __THREW__ = 0;
              $204 = (invoke_iiiiii(195,($$in$i|0),($p$011$i|0),($passContext|0),0,1)|0);
              $205 = __THREW__; __THREW__ = 0;
              $206 = $205&1;
              if ($206) {
               label = 53;
               break L15;
              }
              $207 = ($204|0)==(0|0);
              if (!($207)) {
               $208 = HEAP32[$190>>2]|0;
               $209 = (($208) + 216|0);
               $210 = HEAP32[$209>>2]|0;
               __THREW__ = 0;
               invoke_vii($210|0,($190|0),($block$i|0));
               $211 = __THREW__; __THREW__ = 0;
               $212 = $211&1;
               if ($212) {
                label = 53;
                break L15;
               }
               $213 = HEAP16[$203>>1]|0;
               $214 = $213 << 16 >> 16;
               __THREW__ = 0;
               invoke_viiiii(95,($204|0),($$in13$i|0),($214|0),0,(0|0));
               $215 = __THREW__; __THREW__ = 0;
               $216 = $215&1;
               if ($216) {
                label = 53;
                break L15;
               }
              }
              $221 = (($p$011$i) + 1)|0;
              $222 = ($221|0)<($193|0);
              if ($222) {
               $p$011$i = $221;
              } else {
               break;
              }
             }
            }
           } else {
            $223 = ($199<<16>>16)>(-1);
            $224 = ($200|0)<($193|0);
            $or$cond$i = $223 & $224;
            if ($or$cond$i) {
             __THREW__ = 0;
             $225 = (invoke_iiiiii(195,($$in$i|0),($200|0),($passContext|0),0,1)|0);
             $226 = __THREW__; __THREW__ = 0;
             $227 = $226&1;
             if ($227) {
              label = 54;
              break L15;
             }
             $228 = ($225|0)==(0|0);
             if ($228) {
              break;
             }
             $229 = HEAP32[$190>>2]|0;
             $230 = (($229) + 216|0);
             $231 = HEAP32[$230>>2]|0;
             __THREW__ = 0;
             invoke_vii($231|0,($190|0),($block$i|0));
             $232 = __THREW__; __THREW__ = 0;
             $233 = $232&1;
             if ($233) {
              label = 54;
              break L15;
             }
             $$sum142 = (($90) + 72)|0;
             $234 = (($86) + ($$sum142)|0);
             $235 = HEAP16[$234>>1]|0;
             $236 = $235 << 16 >> 16;
             __THREW__ = 0;
             invoke_viiiii(95,($225|0),($$in13$i|0),($236|0),0,(0|0));
             $237 = __THREW__; __THREW__ = 0;
             $238 = $237&1;
             if ($238) {
              label = 54;
              break L15;
             } else {
              break;
             }
            } else {
             __THREW__ = 0;
             HEAP32[$$byval_copy50>>2] = $200;
             invoke_viii(1617,($15|0),(583984|0),($$byval_copy50|0));
             $239 = __THREW__; __THREW__ = 0;
             $240 = $239&1;
             if ($240) {
              label = 54;
              break L15;
             }
             $241 = HEAP8[$15>>0]|0;
             $242 = $241 & 1;
             $243 = ($242<<24>>24)==(0);
             $244 = HEAP32[$74>>2]|0;
             $$193 = $243 ? $73 : $244;
             __THREW__ = 0;
             invoke_viiiiiiii(21,($$193|0),0,(583616|0),253,1,0,0,(0|0));
             $245 = __THREW__; __THREW__ = 0;
             $246 = $245&1;
             if ($246) {
              label = 66;
              break L15;
             }
             $247 = HEAP8[$15>>0]|0;
             $248 = $247 & 1;
             $249 = ($248<<24>>24)==(0);
             if ($249) {
              break;
             }
             $250 = HEAP32[$74>>2]|0;
             __ZdlPv($250);
             break;
            }
           }
          } while(0);
          $257 = HEAP32[$68>>2]|0;
          $258 = ($257|0)>(-1);
          if ($258) {
           $259 = HEAP32[$69>>2]|0;
           $260 = HEAP32[$70>>2]|0;
           HEAP32[$12>>2] = $260;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$12+0>>2]|0;
           invoke_vii(2591,($259|0),($$byval_copy50|0));
           $261 = __THREW__; __THREW__ = 0;
           $262 = $261&1;
           if ($262) {
            label = 74;
            break L15;
           }
           HEAP32[$69>>2] = 0;
          }
          $263 = HEAP32[$71>>2]|0;
          $264 = ($263|0)>(-1);
          if ($264) {
           $265 = HEAP32[$block$i>>2]|0;
           $266 = HEAP32[$72>>2]|0;
           HEAP32[$11>>2] = $266;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$11+0>>2]|0;
           invoke_vii(2591,($265|0),($$byval_copy50|0));
           $267 = __THREW__; __THREW__ = 0;
           $268 = $267&1;
           if ($268) {
            label = 10;
            break L15;
           }
           HEAP32[$block$i>>2] = 0;
           $$be = $1020;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 1;
          } else {
           $$be = $1020;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 1;
          }
         }
        }
        break;
       }
       case 0:  {
        $303 = (($85) + 7)|0;
        $304 = $303 & -4;
        $305 = (($304) + 12)|0;
        $306 = (($86) + ($304)|0);
        $$sum132 = (($304) + 4)|0;
        $307 = (($86) + ($$sum132)|0);
        $308 = HEAP32[$307>>2]|0;
        $309 = ($308|0)==(0);
        if ($309) {
         $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
        } else {
         HEAP32[$9>>2] = $308;
         $310 = HEAP32[560624>>2]|0;
         $311 = ($310|0)==(0|0);
         if ($311) {
          label = 100;
         } else {
          $312 = (($310) + 36|0);
          $313 = HEAP32[$312>>2]|0;
          $314 = (($310) + 4|0);
          $315 = HEAP32[$314>>2]|0;
          $316 = ($313|0)==($315|0);
          do {
           if ($316) {
            $317 = (($310) + 28|0);
            $318 = HEAP32[$317>>2]|0;
            $319 = (($310) + 32|0);
            $320 = HEAP32[$319>>2]|0;
            $321 = (($318) + ($320<<3)|0);
            $337 = $321;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$310,$9);
            $322 = HEAP32[$$byval_copy50>>2]|0;
            $323 = ($322|0)==(-1);
            $324 = (($310) + 28|0);
            $325 = HEAP32[$324>>2]|0;
            if ($323) {
             $326 = (($310) + 32|0);
             $327 = HEAP32[$326>>2]|0;
             $328 = (($325) + ($327<<3)|0);
             $337 = $328;
             break;
            } else {
             $329 = (($325) + ($322<<3)|0);
             $337 = $329;
             break;
            }
           }
          } while(0);
          $330 = HEAP32[560624>>2]|0;
          $331 = (($330) + 28|0);
          $332 = HEAP32[$331>>2]|0;
          $333 = (($330) + 32|0);
          $334 = HEAP32[$333>>2]|0;
          $335 = (($332) + ($334<<3)|0);
          $336 = ($337|0)==($335|0);
          if ($336) {
           label = 100;
          } else {
           $338 = (($337) + 4|0);
           $339 = HEAP32[$338>>2]|0;
           $340 = ($339|0)==(0|0);
           if ($340) {
            label = 100;
           } else {
            $$in$i33 = $339;
           }
          }
         }
         if ((label|0) == 100) {
          label = 0;
          $341 = HEAP32[$307>>2]|0;
          __THREW__ = 0;
          $342 = (invoke_ii(3215,($341|0))|0);
          $343 = __THREW__; __THREW__ = 0;
          $344 = $343&1;
          if ($344) {
           label = 10;
           break L15;
          }
          $345 = ($342|0)==(0|0);
          if ($345) {
           $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
           break L17;
          } else {
           $$in$i33 = $342;
          }
         }
         $346 = HEAP32[$306>>2]|0;
         $347 = ($346|0)==(0);
         if ($347) {
          $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
         } else {
          HEAP32[$8>>2] = $346;
          $348 = HEAP32[560624>>2]|0;
          $349 = ($348|0)==(0|0);
          if ($349) {
           label = 111;
          } else {
           $350 = (($348) + 36|0);
           $351 = HEAP32[$350>>2]|0;
           $352 = (($348) + 4|0);
           $353 = HEAP32[$352>>2]|0;
           $354 = ($351|0)==($353|0);
           do {
            if ($354) {
             $355 = (($348) + 28|0);
             $356 = HEAP32[$355>>2]|0;
             $357 = (($348) + 32|0);
             $358 = HEAP32[$357>>2]|0;
             $359 = (($356) + ($358<<3)|0);
             $375 = $359;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$348,$8);
             $360 = HEAP32[$$byval_copy50>>2]|0;
             $361 = ($360|0)==(-1);
             $362 = (($348) + 28|0);
             $363 = HEAP32[$362>>2]|0;
             if ($361) {
              $364 = (($348) + 32|0);
              $365 = HEAP32[$364>>2]|0;
              $366 = (($363) + ($365<<3)|0);
              $375 = $366;
              break;
             } else {
              $367 = (($363) + ($360<<3)|0);
              $375 = $367;
              break;
             }
            }
           } while(0);
           $368 = HEAP32[560624>>2]|0;
           $369 = (($368) + 28|0);
           $370 = HEAP32[$369>>2]|0;
           $371 = (($368) + 32|0);
           $372 = HEAP32[$371>>2]|0;
           $373 = (($370) + ($372<<3)|0);
           $374 = ($375|0)==($373|0);
           if ($374) {
            label = 111;
           } else {
            $376 = (($375) + 4|0);
            $377 = HEAP32[$376>>2]|0;
            $378 = ($377|0)==(0|0);
            if ($378) {
             label = 111;
            } else {
             $$in7$i = $377;
            }
           }
          }
          if ((label|0) == 111) {
           label = 0;
           $379 = HEAP32[$306>>2]|0;
           __THREW__ = 0;
           $380 = (invoke_ii(3215,($379|0))|0);
           $381 = __THREW__; __THREW__ = 0;
           $382 = $381&1;
           if ($382) {
            label = 10;
            break L15;
           }
           $383 = ($380|0)==(0|0);
           if ($383) {
            $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
            break L17;
           } else {
            $$in7$i = $380;
           }
          }
          __THREW__ = 0;
          $384 = (invoke_ii(3221,($$in$i33|0))|0);
          $385 = __THREW__; __THREW__ = 0;
          $386 = $385&1;
          if ($386) {
           label = 10;
           break L15;
          }
          $387 = ($384|0)==(0|0);
          if ($387) {
           $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
          } else {
           __THREW__ = 0;
           $388 = (invoke_ii(3226,($$in$i33|0))|0);
           $389 = __THREW__; __THREW__ = 0;
           $390 = $389&1;
           if ($390) {
            label = 10;
            break L15;
           }
           $391 = (($$in7$i) + 28|0);
           $392 = (($391) + 48|0);
           $393 = HEAP8[$392>>0]|0;
           $394 = ($393<<24>>24)==(0);
           $395 = (($391) + 49|0);
           if ($394) {
            $396 = HEAP8[$395>>0]|0;
            $397 = ($396<<24>>24)==(0);
            if (!($397)) {
             label = 118;
            }
           } else {
            label = 118;
           }
           if ((label|0) == 118) {
            label = 0;
            $398 = HEAP32[$391>>2]|0;
            $399 = (($398) + 20|0);
            $400 = HEAP32[$399>>2]|0;
            __THREW__ = 0;
            invoke_vi($400|0,($391|0));
            $401 = __THREW__; __THREW__ = 0;
            $402 = $401&1;
            if ($402) {
             label = 10;
             break L15;
            }
            HEAP8[$392>>0] = 0;
            HEAP8[$395>>0] = 0;
           }
           $403 = (($391) + 52|0);
           $404 = (($391) + 164|0);
           $405 = HEAP32[$404>>2]|0;
           __THREW__ = 0;
           invoke_vii(2661,($403|0),($405|0));
           $406 = __THREW__; __THREW__ = 0;
           $407 = $406&1;
           if ($407) {
            label = 10;
            break L15;
           }
           $$sum133 = (($304) + 10)|0;
           $408 = (($86) + ($$sum133)|0);
           $409 = HEAP16[$408>>1]|0;
           $410 = $409 << 16 >> 16;
           $411 = ($409<<16>>16)==(-1);
           if ($411) {
            $412 = ($388|0)>(0);
            if (!($412)) {
             $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
             break L17;
            }
            $$sum135 = (($304) + 8)|0;
            $413 = (($86) + ($$sum135)|0);
            $p$05$i = 0;
            while(1) {
             __THREW__ = 0;
             $414 = (invoke_iiiiii(195,($$in$i33|0),($p$05$i|0),($passContext|0),0,1)|0);
             $415 = __THREW__; __THREW__ = 0;
             $416 = $415&1;
             if ($416) {
              label = 9;
              break L15;
             }
             $417 = ($414|0)==(0|0);
             if (!($417)) {
              $418 = HEAP32[$391>>2]|0;
              $419 = (($418) + 8|0);
              $420 = HEAP32[$419>>2]|0;
              $421 = HEAP32[$$in7$i>>2]|0;
              $422 = (($421) + 136|0);
              $423 = HEAP32[$422>>2]|0;
              $424 = HEAP16[$413>>1]|0;
              $425 = $424 << 16 >> 16;
              __THREW__ = 0;
              $426 = (invoke_iii($423|0,($$in7$i|0),($425|0))|0);
              $427 = __THREW__; __THREW__ = 0;
              $428 = $427&1;
              if ($428) {
               label = 9;
               break L15;
              }
              __THREW__ = 0;
              invoke_viii($420|0,($391|0),($426|0),($414|0));
              $429 = __THREW__; __THREW__ = 0;
              $430 = $429&1;
              if ($430) {
               label = 9;
               break L15;
              }
             }
             $431 = (($p$05$i) + 1)|0;
             $exitcond$i = ($431|0)==($388|0);
             if ($exitcond$i) {
              $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
              break L17;
             } else {
              $p$05$i = $431;
             }
            }
           }
           $432 = ($409<<16>>16)>(-1);
           $433 = ($410|0)<($388|0);
           $or$cond$i38 = $432 & $433;
           if ($or$cond$i38) {
            __THREW__ = 0;
            $434 = (invoke_iiiiii(195,($$in$i33|0),($410|0),($passContext|0),0,1)|0);
            $435 = __THREW__; __THREW__ = 0;
            $436 = $435&1;
            if ($436) {
             label = 10;
             break L15;
            }
            $437 = ($434|0)==(0|0);
            if ($437) {
             $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
             break L17;
            }
            $438 = HEAP32[$391>>2]|0;
            $439 = (($438) + 8|0);
            $440 = HEAP32[$439>>2]|0;
            $441 = HEAP32[$$in7$i>>2]|0;
            $442 = (($441) + 136|0);
            $443 = HEAP32[$442>>2]|0;
            $$sum134 = (($304) + 8)|0;
            $444 = (($86) + ($$sum134)|0);
            $445 = HEAP16[$444>>1]|0;
            $446 = $445 << 16 >> 16;
            __THREW__ = 0;
            $447 = (invoke_iii($443|0,($$in7$i|0),($446|0))|0);
            $448 = __THREW__; __THREW__ = 0;
            $449 = $448&1;
            if ($449) {
             label = 10;
             break L15;
            }
            __THREW__ = 0;
            invoke_viii($440|0,($391|0),($447|0),($434|0));
            $450 = __THREW__; __THREW__ = 0;
            $451 = $450&1;
            if ($451) {
             label = 10;
             break L15;
            } else {
             $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
             break L17;
            }
           } else {
            __THREW__ = 0;
            HEAP32[$$byval_copy50>>2] = $410;
            invoke_viii(1617,($10|0),(583920|0),($$byval_copy50|0));
            $452 = __THREW__; __THREW__ = 0;
            $453 = $452&1;
            if ($453) {
             label = 10;
             break L15;
            }
            $454 = HEAP8[$10>>0]|0;
            $455 = $454 & 1;
            $456 = ($455<<24>>24)==(0);
            $457 = HEAP32[$76>>2]|0;
            $$194 = $456 ? $75 : $457;
            __THREW__ = 0;
            invoke_viiiiiiii(21,($$194|0),0,(583616|0),299,1,0,0,(0|0));
            $458 = __THREW__; __THREW__ = 0;
            $459 = $458&1;
            if ($459) {
             label = 138;
             break L15;
            }
            $460 = HEAP8[$10>>0]|0;
            $461 = $460 & 1;
            $462 = ($461<<24>>24)==(0);
            if ($462) {
             $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
             break L17;
            }
            $463 = HEAP32[$76>>2]|0;
            __ZdlPv($463);
            $$be = $305;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 0;
            break L17;
           }
          }
         }
        }
        break;
       }
       case 3:  {
        $520 = (($85) + 7)|0;
        $521 = $520 & -4;
        $522 = (($86) + ($521)|0);
        ;HEAP32[$rsColor+0>>2]=0|0;HEAP32[$rsColor+4>>2]=0|0;HEAP32[$rsColor+8>>2]=0|0;HEAP32[$rsColor+12>>2]=0|0;HEAP32[$rsColor+16>>2]=0|0;HEAP32[$rsColor+20>>2]=0|0;HEAP32[$rsColor+24>>2]=0|0;HEAP32[$rsColor+28>>2]=0|0;
        $523 = (($521) + 112)|0;
        $524 = HEAP32[$522>>2]|0;
        $525 = ($524|0)>(0);
        if ($525) {
         $i5$0149 = 0;$ok4$0$off0151 = 1;$rtColorZero$0150 = 0;
         while(1) {
          $526 = ((($522) + ($i5$0149<<2)|0) + 4|0);
          $527 = HEAP32[$526>>2]|0;
          $528 = ($527|0)==(0);
          if ($528) {
           $$0$i70 = 0;
          } else {
           HEAP32[$6>>2] = $527;
           $529 = HEAP32[560624>>2]|0;
           $530 = ($529|0)==(0|0);
           if ($530) {
            label = 164;
           } else {
            $531 = (($529) + 36|0);
            $532 = HEAP32[$531>>2]|0;
            $533 = (($529) + 4|0);
            $534 = HEAP32[$533>>2]|0;
            $535 = ($532|0)==($534|0);
            do {
             if ($535) {
              $536 = (($529) + 28|0);
              $537 = HEAP32[$536>>2]|0;
              $538 = (($529) + 32|0);
              $539 = HEAP32[$538>>2]|0;
              $540 = (($537) + ($539<<3)|0);
              $556 = $540;
             } else {
              __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$529,$6);
              $541 = HEAP32[$$byval_copy50>>2]|0;
              $542 = ($541|0)==(-1);
              $543 = (($529) + 28|0);
              $544 = HEAP32[$543>>2]|0;
              if ($542) {
               $545 = (($529) + 32|0);
               $546 = HEAP32[$545>>2]|0;
               $547 = (($544) + ($546<<3)|0);
               $556 = $547;
               break;
              } else {
               $548 = (($544) + ($541<<3)|0);
               $556 = $548;
               break;
              }
             }
            } while(0);
            $549 = HEAP32[560624>>2]|0;
            $550 = (($549) + 28|0);
            $551 = HEAP32[$550>>2]|0;
            $552 = (($549) + 32|0);
            $553 = HEAP32[$552>>2]|0;
            $554 = (($551) + ($553<<3)|0);
            $555 = ($556|0)==($554|0);
            if ($555) {
             label = 164;
            } else {
             $557 = (($556) + 4|0);
             $558 = HEAP32[$557>>2]|0;
             $559 = ($558|0)==(0|0);
             if ($559) {
              label = 164;
             } else {
              $temp$0$i69 = $558;
             }
            }
           }
           if ((label|0) == 164) {
            label = 0;
            $560 = HEAP32[$526>>2]|0;
            __THREW__ = 0;
            $561 = (invoke_ii(3215,($560|0))|0);
            $562 = __THREW__; __THREW__ = 0;
            $563 = $562&1;
            if ($563) {
             label = 8;
             break L15;
            } else {
             $temp$0$i69 = $561;
            }
           }
           $$0$i70 = $temp$0$i69;
          }
          HEAP32[$rtColor>>2] = $$0$i70;
          $564 = ((($522) + ($i5$0149<<2)|0) + 36|0);
          $565 = HEAP32[$564>>2]|0;
          $566 = ((($522) + ($i5$0149<<2)|0) + 68|0);
          __THREW__ = 0;
          $567 = (invoke_iiiiii(199,($this|0),($565|0),($566|0),(583720|0),($rtColor|0))|0);
          $568 = __THREW__; __THREW__ = 0;
          $569 = $568&1;
          if ($569) {
           label = 8;
           break L15;
          }
          $570 = $ok4$0$off0151 & $567;
          $571 = HEAP32[$rtColor>>2]|0;
          __THREW__ = 0;
          $572 = (invoke_ii(3234,($571|0))|0);
          $573 = __THREW__; __THREW__ = 0;
          $574 = $573&1;
          if ($574) {
           label = 8;
           break L15;
          }
          HEAP32[$rtColor>>2] = $572;
          $575 = ($i5$0149|0)==(0);
          $$rtColorZero$0 = $575 ? $572 : $rtColorZero$0150;
          $576 = ($572|0)==(0|0);
          if ($576) {
           __THREW__ = 0;
           $579 = (invoke_i(59)|0);
           $580 = __THREW__; __THREW__ = 0;
           $581 = $580&1;
           if ($581) {
            label = 8;
            break L15;
           }
           $582 = HEAP32[$579>>2]|0;
           $583 = (($582) + 432|0);
           $584 = HEAP32[$583>>2]|0;
           __THREW__ = 0;
           $585 = (invoke_ii($584|0,($579|0))|0);
           $586 = __THREW__; __THREW__ = 0;
           $587 = $586&1;
           if ($587) {
            label = 8;
            break L15;
           } else {
            $$sroa$01$0 = $585;
           }
          } else {
           $577 = (($572) + 140|0);
           $578 = HEAP32[$577>>2]|0;
           $$sroa$01$0 = $578;
          }
          $588 = (($rsColor) + ($i5$0149<<2)|0);
          HEAP32[$588>>2] = $$sroa$01$0;
          $589 = (($i5$0149) + 1)|0;
          $590 = HEAP32[$522>>2]|0;
          $591 = ($589|0)<($590|0);
          if ($591) {
           $i5$0149 = $589;$ok4$0$off0151 = $570;$rtColorZero$0150 = $$rtColorZero$0;
          } else {
           $ok4$0$off0$lcssa = $570;$rtColorZero$0$lcssa = $$rtColorZero$0;
           break;
          }
         }
        } else {
         $ok4$0$off0$lcssa = 1;$rtColorZero$0$lcssa = 0;
        }
        $$sum127 = (($521) + 100)|0;
        $592 = (($86) + ($$sum127)|0);
        $593 = HEAP32[$592>>2]|0;
        $594 = ($593|0)==(0);
        if ($594) {
         $$0$i78 = 0;
        } else {
         HEAP32[$5>>2] = $593;
         $595 = HEAP32[560624>>2]|0;
         $596 = ($595|0)==(0|0);
         if ($596) {
          label = 182;
         } else {
          $597 = (($595) + 36|0);
          $598 = HEAP32[$597>>2]|0;
          $599 = (($595) + 4|0);
          $600 = HEAP32[$599>>2]|0;
          $601 = ($598|0)==($600|0);
          do {
           if ($601) {
            $602 = (($595) + 28|0);
            $603 = HEAP32[$602>>2]|0;
            $604 = (($595) + 32|0);
            $605 = HEAP32[$604>>2]|0;
            $606 = (($603) + ($605<<3)|0);
            $622 = $606;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$595,$5);
            $607 = HEAP32[$$byval_copy50>>2]|0;
            $608 = ($607|0)==(-1);
            $609 = (($595) + 28|0);
            $610 = HEAP32[$609>>2]|0;
            if ($608) {
             $611 = (($595) + 32|0);
             $612 = HEAP32[$611>>2]|0;
             $613 = (($610) + ($612<<3)|0);
             $622 = $613;
             break;
            } else {
             $614 = (($610) + ($607<<3)|0);
             $622 = $614;
             break;
            }
           }
          } while(0);
          $615 = HEAP32[560624>>2]|0;
          $616 = (($615) + 28|0);
          $617 = HEAP32[$616>>2]|0;
          $618 = (($615) + 32|0);
          $619 = HEAP32[$618>>2]|0;
          $620 = (($617) + ($619<<3)|0);
          $621 = ($622|0)==($620|0);
          if ($621) {
           label = 182;
          } else {
           $623 = (($622) + 4|0);
           $624 = HEAP32[$623>>2]|0;
           $625 = ($624|0)==(0|0);
           if ($625) {
            label = 182;
           } else {
            $temp$0$i77 = $624;
           }
          }
         }
         if ((label|0) == 182) {
          label = 0;
          $626 = HEAP32[$592>>2]|0;
          __THREW__ = 0;
          $627 = (invoke_ii(3215,($626|0))|0);
          $628 = __THREW__; __THREW__ = 0;
          $629 = $628&1;
          if ($629) {
           label = 10;
           break L15;
          } else {
           $temp$0$i77 = $627;
          }
         }
         $$0$i78 = $temp$0$i77;
        }
        HEAP32[$rtDepth>>2] = $$0$i78;
        $$sum128 = (($521) + 104)|0;
        $630 = (($86) + ($$sum128)|0);
        $631 = HEAP32[$630>>2]|0;
        $$sum129 = (($521) + 108)|0;
        $632 = (($86) + ($$sum129)|0);
        __THREW__ = 0;
        $633 = (invoke_iiiiii(199,($this|0),($631|0),($632|0),(583752|0),($rtDepth|0))|0);
        $634 = __THREW__; __THREW__ = 0;
        $635 = $634&1;
        if ($635) {
         label = 10;
         break L15;
        }
        $636 = $ok4$0$off0$lcssa & $633;
        $637 = HEAP32[$rtDepth>>2]|0;
        __THREW__ = 0;
        $638 = (invoke_ii(3234,($637|0))|0);
        $639 = __THREW__; __THREW__ = 0;
        $640 = $639&1;
        if ($640) {
         label = 10;
         break L15;
        }
        HEAP32[$rtDepth>>2] = $638;
        $641 = ($638|0)==(0|0);
        if ($641) {
         __THREW__ = 0;
         $644 = (invoke_i(59)|0);
         $645 = __THREW__; __THREW__ = 0;
         $646 = $645&1;
         if ($646) {
          label = 10;
          break L15;
         }
         $647 = HEAP32[$644>>2]|0;
         $648 = (($647) + 436|0);
         $649 = HEAP32[$648>>2]|0;
         __THREW__ = 0;
         $650 = (invoke_ii($649|0,($644|0))|0);
         $651 = __THREW__; __THREW__ = 0;
         $652 = $651&1;
         if ($652) {
          label = 10;
          break L15;
         } else {
          $$sroa$0$0 = $650;
         }
        } else {
         $642 = (($638) + 148|0);
         $643 = HEAP32[$642>>2]|0;
         $$sroa$0$0 = $643;
        }
        if ($636) {
         $653 = HEAP32[$522>>2]|0;
         HEAP32[$17>>2] = $$sroa$0$0;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$17+0>>2]|0;
         (invoke_iiiiiiii(109,($653|0),($rsColor|0),($$byval_copy50|0),($rtColorZero$0$lcssa|0),0,-1,0)|0);
         $654 = __THREW__; __THREW__ = 0;
         $655 = $654&1;
         if ($655) {
          label = 10;
          break L15;
         } else {
          $$be = $523;$hadRTChanges$0$off0$be = 1;$lastCmdType$0$be = 3;
         }
        } else {
         $$be = $523;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 3;
        }
        break;
       }
       case 2:  {
        $470 = (($85) + 7)|0;
        $471 = $470 & -4;
        $472 = (($471) + 12)|0;
        $473 = (($86) + ($471)|0);
        $474 = HEAP32[$473>>2]|0;
        $475 = ($474|0)==(0);
        if ($475) {
         $$0$i62 = 0;
        } else {
         HEAP32[$7>>2] = $474;
         $476 = HEAP32[560624>>2]|0;
         $477 = ($476|0)==(0|0);
         if ($477) {
          label = 149;
         } else {
          $478 = (($476) + 36|0);
          $479 = HEAP32[$478>>2]|0;
          $480 = (($476) + 4|0);
          $481 = HEAP32[$480>>2]|0;
          $482 = ($479|0)==($481|0);
          do {
           if ($482) {
            $483 = (($476) + 28|0);
            $484 = HEAP32[$483>>2]|0;
            $485 = (($476) + 32|0);
            $486 = HEAP32[$485>>2]|0;
            $487 = (($484) + ($486<<3)|0);
            $503 = $487;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$476,$7);
            $488 = HEAP32[$$byval_copy50>>2]|0;
            $489 = ($488|0)==(-1);
            $490 = (($476) + 28|0);
            $491 = HEAP32[$490>>2]|0;
            if ($489) {
             $492 = (($476) + 32|0);
             $493 = HEAP32[$492>>2]|0;
             $494 = (($491) + ($493<<3)|0);
             $503 = $494;
             break;
            } else {
             $495 = (($491) + ($488<<3)|0);
             $503 = $495;
             break;
            }
           }
          } while(0);
          $496 = HEAP32[560624>>2]|0;
          $497 = (($496) + 28|0);
          $498 = HEAP32[$497>>2]|0;
          $499 = (($496) + 32|0);
          $500 = HEAP32[$499>>2]|0;
          $501 = (($498) + ($500<<3)|0);
          $502 = ($503|0)==($501|0);
          if ($502) {
           label = 149;
          } else {
           $504 = (($503) + 4|0);
           $505 = HEAP32[$504>>2]|0;
           $506 = ($505|0)==(0|0);
           if ($506) {
            label = 149;
           } else {
            $temp$0$i61 = $505;
           }
          }
         }
         if ((label|0) == 149) {
          label = 0;
          $507 = HEAP32[$473>>2]|0;
          __THREW__ = 0;
          $508 = (invoke_ii(3215,($507|0))|0);
          $509 = __THREW__; __THREW__ = 0;
          $510 = $509&1;
          if ($510) {
           label = 10;
           break L15;
          } else {
           $temp$0$i61 = $508;
          }
         }
         $$0$i62 = $temp$0$i61;
        }
        HEAP32[$rt>>2] = $$0$i62;
        $$sum130 = (($471) + 4)|0;
        $511 = (($86) + ($$sum130)|0);
        $512 = HEAP32[$511>>2]|0;
        $$sum131 = (($471) + 8)|0;
        $513 = (($86) + ($$sum131)|0);
        __THREW__ = 0;
        $514 = (invoke_iiiiii(199,($this|0),($512|0),($513|0),(583704|0),($rt|0))|0);
        $515 = __THREW__; __THREW__ = 0;
        $516 = $515&1;
        if ($516) {
         label = 10;
         break L15;
        }
        if ($514) {
         $517 = HEAP32[$rt>>2]|0;
         __THREW__ = 0;
         invoke_viiii(337,($517|0),0,-1,0);
         $518 = __THREW__; __THREW__ = 0;
         $519 = $518&1;
         if ($519) {
          label = 10;
          break L15;
         } else {
          $$be = $472;$hadRTChanges$0$off0$be = 1;$lastCmdType$0$be = 2;
         }
        } else {
         $$be = $472;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 2;
        }
        break;
       }
       case 4:  {
        $656 = (($85) + 7)|0;
        $657 = $656 & -4;
        $658 = (($657) + 32)|0;
        $659 = (($86) + ($657)|0);
        $660 = HEAP32[$659>>2]|0;
        $661 = ($660|0)==(0);
        if ($661) {
         $$0$i82 = 0;
        } else {
         HEAP32[$4>>2] = $660;
         $662 = HEAP32[560624>>2]|0;
         $663 = ($662|0)==(0|0);
         if ($663) {
          label = 201;
         } else {
          $664 = (($662) + 36|0);
          $665 = HEAP32[$664>>2]|0;
          $666 = (($662) + 4|0);
          $667 = HEAP32[$666>>2]|0;
          $668 = ($665|0)==($667|0);
          do {
           if ($668) {
            $669 = (($662) + 28|0);
            $670 = HEAP32[$669>>2]|0;
            $671 = (($662) + 32|0);
            $672 = HEAP32[$671>>2]|0;
            $673 = (($670) + ($672<<3)|0);
            $689 = $673;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$662,$4);
            $674 = HEAP32[$$byval_copy50>>2]|0;
            $675 = ($674|0)==(-1);
            $676 = (($662) + 28|0);
            $677 = HEAP32[$676>>2]|0;
            if ($675) {
             $678 = (($662) + 32|0);
             $679 = HEAP32[$678>>2]|0;
             $680 = (($677) + ($679<<3)|0);
             $689 = $680;
             break;
            } else {
             $681 = (($677) + ($674<<3)|0);
             $689 = $681;
             break;
            }
           }
          } while(0);
          $682 = HEAP32[560624>>2]|0;
          $683 = (($682) + 28|0);
          $684 = HEAP32[$683>>2]|0;
          $685 = (($682) + 32|0);
          $686 = HEAP32[$685>>2]|0;
          $687 = (($684) + ($686<<3)|0);
          $688 = ($689|0)==($687|0);
          if ($688) {
           label = 201;
          } else {
           $690 = (($689) + 4|0);
           $691 = HEAP32[$690>>2]|0;
           $692 = ($691|0)==(0|0);
           if ($692) {
            label = 201;
           } else {
            $temp$0$i81 = $691;
           }
          }
         }
         if ((label|0) == 201) {
          label = 0;
          $693 = HEAP32[$659>>2]|0;
          __THREW__ = 0;
          $694 = (invoke_ii(3215,($693|0))|0);
          $695 = __THREW__; __THREW__ = 0;
          $696 = $695&1;
          if ($696) {
           label = 10;
           break L15;
          } else {
           $temp$0$i81 = $694;
          }
         }
         $$0$i82 = $temp$0$i81;
        }
        HEAP32[$srcRT>>2] = 0;
        $$sum120 = (($657) + 4)|0;
        $697 = (($86) + ($$sum120)|0);
        $698 = HEAP32[$697>>2]|0;
        $$sum121 = (($657) + 8)|0;
        $699 = (($86) + ($$sum121)|0);
        __THREW__ = 0;
        $700 = (invoke_iiiiii(199,($this|0),($698|0),($699|0),(583784|0),($srcRT|0))|0);
        $701 = __THREW__; __THREW__ = 0;
        $702 = $701&1;
        if ($702) {
         label = 10;
         break L15;
        }
        $703 = HEAP32[$srcRT>>2]|0;
        $704 = ($703|0)==(0|0);
        $$ = $704 ? $$0$i82 : $703;
        $$sum122 = (($657) + 12)|0;
        $705 = (($86) + ($$sum122)|0);
        $706 = HEAP32[$705>>2]|0;
        $707 = ($706|0)==(0);
        if ($707) {
         $$0$i90 = 0;
        } else {
         HEAP32[$3>>2] = $706;
         $708 = HEAP32[560624>>2]|0;
         $709 = ($708|0)==(0|0);
         if ($709) {
          label = 213;
         } else {
          $710 = (($708) + 36|0);
          $711 = HEAP32[$710>>2]|0;
          $712 = (($708) + 4|0);
          $713 = HEAP32[$712>>2]|0;
          $714 = ($711|0)==($713|0);
          do {
           if ($714) {
            $715 = (($708) + 28|0);
            $716 = HEAP32[$715>>2]|0;
            $717 = (($708) + 32|0);
            $718 = HEAP32[$717>>2]|0;
            $719 = (($716) + ($718<<3)|0);
            $735 = $719;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$708,$3);
            $720 = HEAP32[$$byval_copy50>>2]|0;
            $721 = ($720|0)==(-1);
            $722 = (($708) + 28|0);
            $723 = HEAP32[$722>>2]|0;
            if ($721) {
             $724 = (($708) + 32|0);
             $725 = HEAP32[$724>>2]|0;
             $726 = (($723) + ($725<<3)|0);
             $735 = $726;
             break;
            } else {
             $727 = (($723) + ($720<<3)|0);
             $735 = $727;
             break;
            }
           }
          } while(0);
          $728 = HEAP32[560624>>2]|0;
          $729 = (($728) + 28|0);
          $730 = HEAP32[$729>>2]|0;
          $731 = (($728) + 32|0);
          $732 = HEAP32[$731>>2]|0;
          $733 = (($730) + ($732<<3)|0);
          $734 = ($735|0)==($733|0);
          if ($734) {
           label = 213;
          } else {
           $736 = (($735) + 4|0);
           $737 = HEAP32[$736>>2]|0;
           $738 = ($737|0)==(0|0);
           if ($738) {
            label = 213;
           } else {
            $temp$0$i89 = $737;
           }
          }
         }
         if ((label|0) == 213) {
          label = 0;
          $739 = HEAP32[$705>>2]|0;
          __THREW__ = 0;
          $740 = (invoke_ii(3215,($739|0))|0);
          $741 = __THREW__; __THREW__ = 0;
          $742 = $741&1;
          if ($742) {
           label = 10;
           break L15;
          } else {
           $temp$0$i89 = $740;
          }
         }
         $$0$i90 = $temp$0$i89;
        }
        HEAP32[$dest>>2] = $$0$i90;
        $$sum123 = (($657) + 16)|0;
        $743 = (($86) + ($$sum123)|0);
        $744 = HEAP32[$743>>2]|0;
        $$sum124 = (($657) + 20)|0;
        $745 = (($86) + ($$sum124)|0);
        __THREW__ = 0;
        $746 = (invoke_iiiiii(199,($this|0),($744|0),($745|0),(583800|0),($dest|0))|0);
        $747 = __THREW__; __THREW__ = 0;
        $748 = $747&1;
        if ($748) {
         label = 10;
         break L15;
        }
        $749 = $700 & $746;
        if ($749) {
         $$sum125 = (($657) + 24)|0;
         $750 = (($86) + ($$sum125)|0);
         $751 = HEAP32[$750>>2]|0;
         $752 = ($751|0)==(0);
         do {
          if ($752) {
           $753 = HEAP32[$dest>>2]|0;
           $792 = $753;
          } else {
           HEAP32[$2>>2] = $751;
           $754 = HEAP32[560624>>2]|0;
           $755 = ($754|0)==(0|0);
           if ($755) {
            label = 228;
           } else {
            $756 = (($754) + 36|0);
            $757 = HEAP32[$756>>2]|0;
            $758 = (($754) + 4|0);
            $759 = HEAP32[$758>>2]|0;
            $760 = ($757|0)==($759|0);
            do {
             if ($760) {
              $761 = (($754) + 28|0);
              $762 = HEAP32[$761>>2]|0;
              $763 = (($754) + 32|0);
              $764 = HEAP32[$763>>2]|0;
              $765 = (($762) + ($764<<3)|0);
              $781 = $765;
             } else {
              __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$754,$2);
              $766 = HEAP32[$$byval_copy50>>2]|0;
              $767 = ($766|0)==(-1);
              $768 = (($754) + 28|0);
              $769 = HEAP32[$768>>2]|0;
              if ($767) {
               $770 = (($754) + 32|0);
               $771 = HEAP32[$770>>2]|0;
               $772 = (($769) + ($771<<3)|0);
               $781 = $772;
               break;
              } else {
               $773 = (($769) + ($766<<3)|0);
               $781 = $773;
               break;
              }
             }
            } while(0);
            $774 = HEAP32[560624>>2]|0;
            $775 = (($774) + 28|0);
            $776 = HEAP32[$775>>2]|0;
            $777 = (($774) + 32|0);
            $778 = HEAP32[$777>>2]|0;
            $779 = (($776) + ($778<<3)|0);
            $780 = ($781|0)==($779|0);
            if ($780) {
             label = 228;
            } else {
             $782 = (($781) + 4|0);
             $783 = HEAP32[$782>>2]|0;
             $784 = ($783|0)==(0|0);
             if ($784) {
              label = 228;
             } else {
              $785 = HEAP32[$dest>>2]|0;
              $799 = $785;$temp$0$i97191 = $783;
             }
            }
           }
           if ((label|0) == 228) {
            label = 0;
            $786 = HEAP32[$750>>2]|0;
            __THREW__ = 0;
            $787 = (invoke_ii(3215,($786|0))|0);
            $788 = __THREW__; __THREW__ = 0;
            $789 = $788&1;
            if ($789) {
             label = 10;
             break L15;
            }
            $790 = ($787|0)==(0|0);
            $791 = HEAP32[$dest>>2]|0;
            if ($790) {
             $792 = $791;
             break;
            } else {
             $799 = $791;$temp$0$i97191 = $787;
            }
           }
           $$sum126 = (($657) + 28)|0;
           $796 = (($86) + ($$sum126)|0);
           $797 = HEAP16[$796>>1]|0;
           $798 = $797 << 16 >> 16;
           __THREW__ = 0;
           invoke_viiiiii(103,($$|0),($799|0),($temp$0$i97191|0),($798|0),1,-1);
           $800 = __THREW__; __THREW__ = 0;
           $801 = $800&1;
           if ($801) {
            label = 10;
            break L15;
           } else {
            $$be = $658;$hadRTChanges$0$off0$be = 1;$lastCmdType$0$be = 4;
            break L17;
           }
          }
         } while(0);
         __THREW__ = 0;
         invoke_vii(2662,($$|0),($792|0));
         $793 = __THREW__; __THREW__ = 0;
         $794 = $793&1;
         if ($794) {
          label = 10;
          break L15;
         } else {
          $$be = $658;$hadRTChanges$0$off0$be = 1;$lastCmdType$0$be = 4;
         }
        } else {
         $$be = $658;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 4;
        }
        break;
       }
       case 5:  {
        $802 = (($85) + 7)|0;
        $803 = $802 & -4;
        $804 = (($803) + 28)|0;
        $805 = (($86) + ($803)|0);
        $806 = HEAP32[$23>>2]|0;
        $807 = (($806) + 24|0);
        $808 = HEAP32[$807>>2]|0;
        $$sum117 = (($803) + 16)|0;
        $809 = (($86) + ($$sum117)|0);
        $810 = HEAP32[$809>>2]|0;
        $$sum118 = (($803) + 20)|0;
        $811 = (($86) + ($$sum118)|0);
        $812 = Math_fround(HEAPF32[$811>>2]);
        $$sum119 = (($803) + 24)|0;
        $813 = (($86) + ($$sum119)|0);
        $814 = HEAP32[$813>>2]|0;
        __THREW__ = 0;
        invoke_viiifi($808|0,($23|0),($810|0),($805|0),(+$812),($814|0));
        $815 = __THREW__; __THREW__ = 0;
        $816 = $815&1;
        if ($816) {
         label = 10;
         break L15;
        } else {
         $$be = $804;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 5;
        }
        break;
       }
       case 9:  {
        $926 = (($85) + 7)|0;
        $927 = $926 & -4;
        $928 = (($927) + 20)|0;
        $929 = (($86) + ($927)|0);
        $$sum108 = (($927) + 4)|0;
        $930 = (($86) + ($$sum108)|0);
        __THREW__ = 0;
        invoke_viii(1689,($77|0),($929|0),($930|0));
        $931 = __THREW__; __THREW__ = 0;
        $932 = $931&1;
        if ($932) {
         label = 10;
         break L15;
        } else {
         $$be = $928;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 9;
        }
        break;
       }
       case 10:  {
        $933 = (($85) + 7)|0;
        $934 = $933 & -4;
        $935 = (($934) + 68)|0;
        $936 = (($86) + ($934)|0);
        $$sum107 = (($934) + 4)|0;
        $937 = (($86) + ($$sum107)|0);
        __THREW__ = 0;
        invoke_viii(1694,($77|0),($936|0),($937|0));
        $938 = __THREW__; __THREW__ = 0;
        $939 = $938&1;
        if ($939) {
         label = 10;
         break L15;
        } else {
         $$be = $935;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 10;
        }
        break;
       }
       case 6:  {
        $817 = (($85) + 7)|0;
        $818 = $817 & -4;
        $819 = (($818) + 32)|0;
        $820 = (($86) + ($818)|0);
        __THREW__ = 0;
        $821 = (invoke_i(61)|0);
        $822 = __THREW__; __THREW__ = 0;
        $823 = $822&1;
        if ($823) {
         label = 10;
         break L15;
        }
        $$sum110 = (($818) + 4)|0;
        $824 = (($86) + ($$sum110)|0);
        $825 = HEAP32[$824>>2]|0;
        $$sum111 = (($818) + 8)|0;
        $826 = (($86) + ($$sum111)|0);
        $827 = HEAP32[$826>>2]|0;
        $$sum112 = (($818) + 16)|0;
        $828 = (($86) + ($$sum112)|0);
        $829 = HEAP32[$828>>2]|0;
        $$sum113 = (($818) + 12)|0;
        $830 = (($86) + ($$sum113)|0);
        $831 = HEAP32[$830>>2]|0;
        $$sum114 = (($818) + 24)|0;
        $832 = (($86) + ($$sum114)|0);
        $833 = HEAP32[$832>>2]|0;
        $$sum115 = (($818) + 28)|0;
        $834 = (($86) + ($$sum115)|0);
        $835 = HEAP32[$834>>2]|0;
        __THREW__ = 0;
        $836 = (invoke_iiiiiiiii(37,($821|0),($825|0),($827|0),($829|0),($831|0),0,($833|0),($835|0))|0);
        $837 = __THREW__; __THREW__ = 0;
        $838 = $837&1;
        if ($838) {
         label = 10;
         break L15;
        }
        $$sum116 = (($818) + 20)|0;
        $839 = (($86) + ($$sum116)|0);
        $840 = HEAP32[$839>>2]|0;
        __THREW__ = 0;
        invoke_vii(2663,($836|0),($840|0));
        $841 = __THREW__; __THREW__ = 0;
        $842 = $841&1;
        if ($842) {
         label = 10;
         break L15;
        }
        __THREW__ = 0;
        (invoke_iiii(1534,($77|0),($820|0),($836|0))|0);
        $843 = __THREW__; __THREW__ = 0;
        $844 = $843&1;
        if ($844) {
         label = 10;
         break L15;
        }
        $845 = HEAP32[$820>>2]|0;
        $846 = HEAP32[$78>>2]|0;
        $847 = (($846) + 1)|0;
        HEAP32[$78>>2] = $847;
        $848 = HEAP32[$79>>2]|0;
        $849 = $848 & 2147483647;
        $850 = ($847>>>0)>($849>>>0);
        if ($850) {
         $851 = $848 << 1;
         $852 = ($851|0)==(0);
         $853 = $852 ? 1 : $851;
         $854 = ($849>>>0)<($853>>>0);
         do {
          if ($854) {
           $855 = ($848|0)>(-1);
           if ($855) {
            HEAP32[$79>>2] = $853;
            $856 = HEAP32[$80>>2]|0;
            $857 = $853 << 3;
            $858 = HEAP32[$81>>2]|0;
            HEAP32[$0>>2] = $858;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$0+0>>2]|0;
            $859 = (invoke_iiiiiiii(108,($856|0),($857|0),4,($$byval_copy50|0),0,(583616|0),370)|0);
            $860 = __THREW__; __THREW__ = 0;
            $861 = $860&1;
            if ($861) {
             label = 10;
             break L15;
            }
            HEAP32[$80>>2] = $859;
            break;
           } else {
            $862 = $853 << 3;
            $863 = HEAP32[$81>>2]|0;
            HEAP32[$1>>2] = $863;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$1+0>>2]|0;
            $864 = (invoke_iiiiiii(102,($862|0),4,($$byval_copy50|0),0,(583616|0),352)|0);
            $865 = __THREW__; __THREW__ = 0;
            $866 = $865&1;
            if ($866) {
             label = 10;
             break L15;
            }
            $867 = HEAP32[$80>>2]|0;
            $868 = HEAP32[$78>>2]|0;
            $869 = $868 << 3;
            _memcpy(($864|0),($867|0),($869|0))|0;
            HEAP32[$79>>2] = $853;
            HEAP32[$80>>2] = $864;
            break;
           }
          }
         } while(0);
         $$pre$i$i = HEAP32[$78>>2]|0;
         $871 = $$pre$i$i;
        } else {
         $871 = $847;
        }
        $870 = (($871) + -1)|0;
        $872 = HEAP32[$80>>2]|0;
        $873 = (($872) + ($870<<3)|0);
        $874 = $836;
        $875 = $873;
        $876 = $875;
        HEAP32[$876>>2] = $845;
        $877 = (($875) + 4)|0;
        $878 = $877;
        HEAP32[$878>>2] = $874;
        $$be = $819;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 6;
        break;
       }
       case 8:  {
        $918 = (($85) + 7)|0;
        $919 = $918 & -4;
        $920 = (($919) + 8)|0;
        $921 = (($86) + ($919)|0);
        $$sum109 = (($919) + 4)|0;
        $922 = (($86) + ($$sum109)|0);
        $923 = Math_fround(HEAPF32[$922>>2]);
        __THREW__ = 0;
        invoke_viif(42,($77|0),($921|0),(+$923));
        $924 = __THREW__; __THREW__ = 0;
        $925 = $924&1;
        if ($925) {
         label = 10;
         break L15;
        } else {
         $$be = $920;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 8;
        }
        break;
       }
       case 7:  {
        $879 = (($85) + 7)|0;
        $880 = $879 & -4;
        $881 = (($880) + 4)|0;
        $882 = HEAP32[$78>>2]|0;
        $883 = ($882|0)==(0);
        if ($883) {
         $$be = $881;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 7;
        } else {
         $884 = (($86) + ($880)|0);
         $885 = HEAP32[$82>>2]|0;
         $886 = HEAP32[$884>>2]|0;
         $i$01$i = 0;
         while(1) {
          $889 = (($885) + ($i$01$i<<3)|0);
          $890 = HEAP32[$889>>2]|0;
          $891 = ($890|0)==($886|0);
          $888 = (($i$01$i) + 1)|0;
          if ($891) {
           break;
          }
          $887 = ($888|0)==($882|0);
          if ($887) {
           $$be = $881;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 7;
           break L17;
          } else {
           $i$01$i = $888;
          }
         }
         $892 = ($i$01$i|0)==(-1);
         if ($892) {
          $$be = $881;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 7;
         } else {
          __THREW__ = 0;
          $893 = (invoke_i(61)|0);
          $894 = __THREW__; __THREW__ = 0;
          $895 = $894&1;
          if ($895) {
           label = 10;
           break L15;
          }
          $896 = HEAP32[$82>>2]|0;
          $897 = ((($896) + ($i$01$i<<3)|0) + 4|0);
          $898 = HEAP32[$897>>2]|0;
          __THREW__ = 0;
          invoke_vii(2617,($893|0),($898|0));
          $899 = __THREW__; __THREW__ = 0;
          $900 = $899&1;
          if ($900) {
           label = 10;
           break L15;
          }
          $901 = HEAP32[$82>>2]|0;
          $902 = (($901) + ($i$01$i<<3)|0);
          $903 = HEAP32[$78>>2]|0;
          $904 = (($903) + -1)|0;
          $905 = (($901) + ($904<<3)|0);
          $906 = $905;
          $907 = $906;
          $908 = HEAP32[$907>>2]|0;
          $909 = (($906) + 4)|0;
          $910 = $909;
          $911 = HEAP32[$910>>2]|0;
          $912 = $902;
          $913 = $912;
          HEAP32[$913>>2] = $908;
          $914 = (($912) + 4)|0;
          $915 = $914;
          HEAP32[$915>>2] = $911;
          $916 = HEAP32[$78>>2]|0;
          $917 = (($916) + -1)|0;
          HEAP32[$78>>2] = $917;
          $$be = $881;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 7;
         }
        }
        break;
       }
       case 11:  {
        $940 = (($85) + 7)|0;
        $941 = $940 & -4;
        $942 = (($941) + 16)|0;
        $943 = (($86) + ($941)|0);
        $$sum = (($941) + 4)|0;
        $944 = (($86) + ($$sum)|0);
        $945 = HEAP32[$944>>2]|0;
        $946 = ($945|0)==(0);
        if ($946) {
         $$0$i = 0;
        } else {
         HEAP32[$16>>2] = $945;
         $947 = HEAP32[560624>>2]|0;
         $948 = ($947|0)==(0|0);
         if ($948) {
          label = 268;
         } else {
          $949 = (($947) + 36|0);
          $950 = HEAP32[$949>>2]|0;
          $951 = (($947) + 4|0);
          $952 = HEAP32[$951>>2]|0;
          $953 = ($950|0)==($952|0);
          do {
           if ($953) {
            $954 = (($947) + 28|0);
            $955 = HEAP32[$954>>2]|0;
            $956 = (($947) + 32|0);
            $957 = HEAP32[$956>>2]|0;
            $958 = (($955) + ($957<<3)|0);
            $974 = $958;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy50,$947,$16);
            $959 = HEAP32[$$byval_copy50>>2]|0;
            $960 = ($959|0)==(-1);
            $961 = (($947) + 28|0);
            $962 = HEAP32[$961>>2]|0;
            if ($960) {
             $963 = (($947) + 32|0);
             $964 = HEAP32[$963>>2]|0;
             $965 = (($962) + ($964<<3)|0);
             $974 = $965;
             break;
            } else {
             $966 = (($962) + ($959<<3)|0);
             $974 = $966;
             break;
            }
           }
          } while(0);
          $967 = HEAP32[560624>>2]|0;
          $968 = (($967) + 28|0);
          $969 = HEAP32[$968>>2]|0;
          $970 = (($967) + 32|0);
          $971 = HEAP32[$970>>2]|0;
          $972 = (($969) + ($971<<3)|0);
          $973 = ($974|0)==($972|0);
          if ($973) {
           label = 268;
          } else {
           $975 = (($974) + 4|0);
           $976 = HEAP32[$975>>2]|0;
           $977 = ($976|0)==(0|0);
           if ($977) {
            label = 268;
           } else {
            $temp$0$i = $976;
           }
          }
         }
         if ((label|0) == 268) {
          label = 0;
          $978 = HEAP32[$944>>2]|0;
          __THREW__ = 0;
          $979 = (invoke_ii(3215,($978|0))|0);
          $980 = __THREW__; __THREW__ = 0;
          $981 = $980&1;
          if ($981) {
           label = 10;
           break L15;
          } else {
           $temp$0$i = $979;
          }
         }
         $$0$i = $temp$0$i;
        }
        HEAP32[$rt16>>2] = $$0$i;
        $$sum105 = (($941) + 8)|0;
        $982 = (($86) + ($$sum105)|0);
        $983 = HEAP32[$982>>2]|0;
        $$sum106 = (($941) + 12)|0;
        $984 = (($86) + ($$sum106)|0);
        __THREW__ = 0;
        $985 = (invoke_iiiiii(199,($this|0),($983|0),($984|0),(583824|0),($rt16|0))|0);
        $986 = __THREW__; __THREW__ = 0;
        $987 = $986&1;
        if ($987) {
         label = 10;
         break L15;
        }
        if ($985) {
         $988 = HEAP32[$rt16>>2]|0;
         __THREW__ = 0;
         (invoke_iiii(1534,($77|0),($943|0),($988|0))|0);
         $989 = __THREW__; __THREW__ = 0;
         $990 = $989&1;
         if ($990) {
          label = 10;
          break L15;
         } else {
          $$be = $942;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 11;
         }
        } else {
         $$be = $942;$hadRTChanges$0$off0$be = $hadRTChanges$0$off0177;$lastCmdType$0$be = 11;
        }
        break;
       }
       default: {
        label = 273;
        break L15;
       }
       }
      } while(0);
      $795 = ($$be>>>0)<($21>>>0);
      if ($795) {
       $84 = $$be;$hadRTChanges$0$off0177 = $hadRTChanges$0$off0$be;$lastCmdType$0176 = $lastCmdType$0$be;
      } else {
       label = 281;
       break;
      }
     }
     if ((label|0) == 8) {
      $43 = ___cxa_find_matching_catch()|0;
      $44 = tempRet0;
      $eh$lpad$body$index10Z2D = $44;$eh$lpad$body$indexZ2D = $43;
      label = 13;
      break;
     }
     else if ((label|0) == 9) {
      $45 = ___cxa_find_matching_catch()|0;
      $46 = tempRet0;
      $eh$lpad$body$index10Z2D = $46;$eh$lpad$body$indexZ2D = $45;
      label = 13;
      break;
     }
     else if ((label|0) == 53) {
      $217 = ___cxa_find_matching_catch()|0;
      $218 = tempRet0;
      $lpad$phi$i$index = $217;$lpad$phi$i$index23 = $218;
      label = 55;
     }
     else if ((label|0) == 54) {
      $219 = ___cxa_find_matching_catch()|0;
      $220 = tempRet0;
      $lpad$phi$i$index = $219;$lpad$phi$i$index23 = $220;
      label = 55;
     }
     else if ((label|0) == 66) {
      $251 = ___cxa_find_matching_catch()|0;
      $252 = tempRet0;
      $253 = HEAP8[$15>>0]|0;
      $254 = $253 & 1;
      $255 = ($254<<24>>24)==(0);
      if ($255) {
       $$0$i23 = $251;$$01$i = $252;
      } else {
       $256 = HEAP32[$74>>2]|0;
       __ZdlPv($256);
       $$0$i23 = $251;$$01$i = $252;
      }
     }
     else if ((label|0) == 74) {
      $269 = ___cxa_find_matching_catch()|0;
      $270 = tempRet0;
      $271 = HEAP32[$71>>2]|0;
      $272 = ($271|0)>(-1);
      if (!($272)) {
       $eh$lpad$body$index10Z2D = $270;$eh$lpad$body$indexZ2D = $269;
       label = 13;
       break;
      }
      $273 = HEAP32[$block$i>>2]|0;
      $274 = HEAP32[$72>>2]|0;
      HEAP32[$0>>2] = $274;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($273|0),($$byval_copy50|0));
      $275 = __THREW__; __THREW__ = 0;
      $276 = $275&1;
      if ($276) {
       $277 = ___cxa_find_matching_catch(0|0)|0;
       $278 = tempRet0;
       ___clang_call_terminate($277);
       // unreachable;
      } else {
       HEAP32[$block$i>>2] = 0;
       $eh$lpad$body$index10Z2D = $270;$eh$lpad$body$indexZ2D = $269;
       label = 13;
       break;
      }
     }
     else if ((label|0) == 138) {
      $464 = ___cxa_find_matching_catch()|0;
      $465 = tempRet0;
      $466 = HEAP8[$10>>0]|0;
      $467 = $466 & 1;
      $468 = ($467<<24>>24)==(0);
      if ($468) {
       $eh$lpad$body$index10Z2D = $465;$eh$lpad$body$indexZ2D = $464;
       label = 13;
       break;
      }
      $469 = HEAP32[$76>>2]|0;
      __ZdlPv($469);
      $eh$lpad$body$index10Z2D = $465;$eh$lpad$body$indexZ2D = $464;
      label = 13;
      break;
     }
     else if ((label|0) == 273) {
      $991 = HEAP8[$63>>0]|0;
      $992 = $991 & 1;
      $993 = ($992<<24>>24)==(0);
      if ($993) {
       $995 = $64;
      } else {
       $994 = HEAP32[$67>>2]|0;
       $995 = $994;
      }
      __THREW__ = 0;
      HEAP32[$$byval_copy50>>2] = $88;
      $vararg_ptr40 = (($$byval_copy50) + 4|0);
      HEAP32[$vararg_ptr40>>2] = $lastCmdType$0176;
      $vararg_ptr41 = (($$byval_copy50) + 8|0);
      HEAP32[$vararg_ptr41>>2] = $995;
      invoke_viii(1617,($18|0),(583848|0),($$byval_copy50|0));
      $996 = __THREW__; __THREW__ = 0;
      $997 = $996&1;
      if ($997) {
       label = 10;
      } else {
       $998 = HEAP8[$18>>0]|0;
       $999 = $998 & 1;
       $1000 = ($999<<24>>24)==(0);
       $1001 = HEAP32[$66>>2]|0;
       $$195 = $1000 ? $65 : $1001;
       __THREW__ = 0;
       invoke_viiiiiiii(21,($$195|0),0,(583616|0),519,1,0,0,(0|0));
       $1002 = __THREW__; __THREW__ = 0;
       $1003 = $1002&1;
       if ($1003) {
        $1008 = ___cxa_find_matching_catch()|0;
        $1009 = tempRet0;
        $1010 = HEAP8[$18>>0]|0;
        $1011 = $1010 & 1;
        $1012 = ($1011<<24>>24)==(0);
        if ($1012) {
         $$0 = $1008;$$03 = $1009;
         break;
        }
        $1013 = HEAP32[$66>>2]|0;
        __ZdlPv($1013);
        $$0 = $1008;$$03 = $1009;
        break;
       }
       $1004 = HEAP8[$18>>0]|0;
       $1005 = $1004 & 1;
       $1006 = ($1005<<24>>24)==(0);
       if (!($1006)) {
        $1007 = HEAP32[$66>>2]|0;
        __ZdlPv($1007);
       }
       if ($hadRTChanges$0$off0177) {
        label = 282;
       } else {
        label = 283;
       }
      }
     }
     else if ((label|0) == 281) {
      if ($hadRTChanges$0$off0$be) {
       label = 282;
      } else {
       label = 283;
      }
     }
     if ((label|0) == 10) {
      $47 = ___cxa_find_matching_catch()|0;
      $48 = tempRet0;
      $eh$lpad$body$index10Z2D = $48;$eh$lpad$body$indexZ2D = $47;
      label = 13;
      break;
     }
     else if ((label|0) == 55) {
      $$0$i23 = $lpad$phi$i$index;$$01$i = $lpad$phi$i$index23;
     }
     else if ((label|0) == 282) {
      HEAP32[$19>>2] = $56;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$19+0>>2]|0;
      (invoke_iiiiiiii(109,($30|0),($prevRTColor|0),($$byval_copy50|0),($24|0),0,($60|0),0)|0);
      $1014 = __THREW__; __THREW__ = 0;
      $1015 = $1014&1;
      if ($1015) {
       label = 12;
       break;
      } else {
       label = 283;
      }
     }
     if ((label|0) == 283) {
      HEAP8[678904>>0] = $61;
      __ZN22DeviceMVPMatricesStateD2Ev($preserveMVPState);
      STACKTOP = sp;return;
     }
     $279 = HEAP32[$68>>2]|0;
     $280 = ($279|0)>(-1);
     do {
      if ($280) {
       $281 = HEAP32[$69>>2]|0;
       $282 = HEAP32[$70>>2]|0;
       HEAP32[$1>>2] = $282;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($281|0),($$byval_copy50|0));
       $283 = __THREW__; __THREW__ = 0;
       $284 = $283&1;
       if (!($284)) {
        HEAP32[$69>>2] = 0;
        break;
       }
       $291 = ___cxa_find_matching_catch(0|0)|0;
       $292 = tempRet0;
       $293 = HEAP32[$71>>2]|0;
       $294 = ($293|0)>(-1);
       if (!($294)) {
        $eh$lpad$body$i$indexZ2D = $291;
        ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
        // unreachable;
       }
       $295 = HEAP32[$block$i>>2]|0;
       $296 = HEAP32[$72>>2]|0;
       HEAP32[$0>>2] = $296;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($295|0),($$byval_copy50|0));
       $297 = __THREW__; __THREW__ = 0;
       $298 = $297&1;
       if ($298) {
        $299 = ___cxa_find_matching_catch(0|0)|0;
        $300 = tempRet0;
        ___clang_call_terminate($299);
        // unreachable;
       }
       HEAP32[$block$i>>2] = 0;
       $eh$lpad$body$i$indexZ2D = $291;
       ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
       // unreachable;
      }
     } while(0);
     $285 = HEAP32[$71>>2]|0;
     $286 = ($285|0)>(-1);
     do {
      if ($286) {
       $287 = HEAP32[$block$i>>2]|0;
       $288 = HEAP32[$72>>2]|0;
       HEAP32[$0>>2] = $288;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($287|0),($$byval_copy50|0));
       $289 = __THREW__; __THREW__ = 0;
       $290 = $289&1;
       if (!($290)) {
        HEAP32[$block$i>>2] = 0;
        break;
       }
       $301 = ___cxa_find_matching_catch(0|0)|0;
       $302 = tempRet0;
       $eh$lpad$body$i$indexZ2D = $301;
       ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
       // unreachable;
      }
     } while(0);
     $eh$lpad$body$index10Z2D = $$01$i;$eh$lpad$body$indexZ2D = $$0$i23;
     label = 13;
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $eh$lpad$body$index10Z2D = $52;$eh$lpad$body$indexZ2D = $51;
  label = 13;
 }
 if ((label|0) == 13) {
  $$0 = $eh$lpad$body$indexZ2D;$$03 = $eh$lpad$body$index10Z2D;
 }
 __THREW__ = 0;
 invoke_vi(3375,($preserveMVPState|0));
 $1016 = __THREW__; __THREW__ = 0;
 $1017 = $1016&1;
 if ($1017) {
  $1018 = ___cxa_find_matching_catch(0|0)|0;
  $1019 = tempRet0;
  ___clang_call_terminate($1018);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN19RenderEventsContextC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 61;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 24|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 28|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = 61;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 44|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 36|0);
 HEAP32[$10>>2] = 61;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 56|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 60|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 52|0);
 HEAP32[$14>>2] = 61;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 72|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 76|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 68|0);
 HEAP32[$18>>2] = 61;
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 88|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 92|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 84|0);
 HEAP32[$22>>2] = 61;
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 104|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 108|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 100|0);
 HEAP32[$26>>2] = 61;
 $27 = (($this) + 112|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 120|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 124|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 116|0);
 HEAP32[$30>>2] = 61;
 $31 = (($this) + 128|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 136|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 140|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 132|0);
 HEAP32[$34>>2] = 61;
 $35 = (($this) + 144|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 152|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 156|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 148|0);
 HEAP32[$38>>2] = 61;
 $39 = (($this) + 160|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 168|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 172|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 164|0);
 HEAP32[$42>>2] = 61;
 $43 = (($this) + 176|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 184|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 188|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 180|0);
 HEAP32[$46>>2] = 61;
 $47 = (($this) + 192|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 200|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 204|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 196|0);
 HEAP32[$50>>2] = 61;
 $51 = (($this) + 208|0);
 HEAP32[$51>>2] = 0;
 $52 = (($this) + 216|0);
 HEAP32[$52>>2] = 0;
 $53 = (($this) + 220|0);
 HEAP32[$53>>2] = 0;
 $54 = (($this) + 212|0);
 HEAP32[$54>>2] = 61;
 $55 = (($this) + 224|0);
 HEAP32[$55>>2] = 0;
 $56 = (($this) + 232|0);
 HEAP32[$56>>2] = 0;
 $57 = (($this) + 236|0);
 HEAP32[$57>>2] = 0;
 $58 = (($this) + 228|0);
 HEAP32[$58>>2] = 61;
 $59 = (($this) + 240|0);
 HEAP32[$59>>2] = 0;
 $60 = (($this) + 248|0);
 HEAP32[$60>>2] = 0;
 $61 = (($this) + 252|0);
 HEAP32[$61>>2] = 0;
 $62 = (($this) + 244|0);
 HEAP32[$62>>2] = 61;
 $63 = (($this) + 256|0);
 HEAP32[$63>>2] = 0;
 $64 = (($this) + 264|0);
 HEAP32[$64>>2] = 0;
 $65 = (($this) + 268|0);
 HEAP32[$65>>2] = 0;
 $66 = (($this) + 260|0);
 HEAP32[$66>>2] = 61;
 $67 = (($this) + 272|0);
 HEAP32[$67>>2] = 0;
 $68 = (($this) + 280|0);
 HEAP32[$68>>2] = 0;
 $69 = (($this) + 284|0);
 HEAP32[$69>>2] = 0;
 $70 = (($this) + 276|0);
 HEAP32[$70>>2] = 61;
 $71 = (($this) + 288|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 296|0);
 HEAP32[$72>>2] = 0;
 $73 = (($this) + 300|0);
 HEAP32[$73>>2] = 0;
 $74 = (($this) + 292|0);
 HEAP32[$74>>2] = 61;
 $75 = (($this) + 304|0);
 HEAP32[$75>>2] = 0;
 $76 = (($this) + 312|0);
 HEAP32[$76>>2] = 0;
 $77 = (($this) + 316|0);
 HEAP32[$77>>2] = 0;
 $78 = (($this) + 308|0);
 HEAP32[$78>>2] = 61;
 $79 = (($this) + 320|0);
 HEAP32[$79>>2] = 0;
 $80 = (($this) + 328|0);
 HEAP32[$80>>2] = 0;
 $81 = (($this) + 332|0);
 HEAP32[$81>>2] = 0;
 $82 = (($this) + 324|0);
 HEAP32[$82>>2] = 61;
 STACKTOP = sp;return;
}
function __ZN19RenderEventsContextD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 336|0);
 $4 = $2;
 while(1) {
  $3 = (($4) + -16|0);
  $5 = (($4) + -4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>(-1);
  if ($7) {
   $8 = HEAP32[$3>>2]|0;
   $9 = (($4) + -12|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$1>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy1|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    break;
   }
   HEAP32[$3>>2] = 0;
  }
  $13 = ($3|0)==($this|0);
  if ($13) {
   label = 6;
   break;
  } else {
   $4 = $3;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $16 = ($this|0)==($3|0);
 if ($16) {
  ___resumeException($14|0);
  // unreachable;
 }
 $18 = $3;
 while(1) {
  $17 = (($18) + -16|0);
  $19 = (($18) + -4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)>(-1);
  if ($21) {
   $22 = HEAP32[$17>>2]|0;
   $23 = (($18) + -12|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$0>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($22|0),($$byval_copy1|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 14;
    break;
   }
   HEAP32[$17>>2] = 0;
  }
  $27 = ($17|0)==($this|0);
  if ($27) {
   label = 13;
   break;
  } else {
   $18 = $17;
  }
 }
 if ((label|0) == 13) {
  ___resumeException($14|0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 }
}
function __ZN19RenderEventsContext23RemoveAllCommandBuffersEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,0);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,1);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,2);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,3);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,4);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,5);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,6);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,7);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,8);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,9);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,10);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,11);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,12);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,13);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,14);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,15);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,16);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,17);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,18);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,19);
 __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,20);
 STACKTOP = sp;return;
}
function __ZN19RenderEventsContext20RemoveCommandBuffersE15RenderEventType($this,$event) {
 $this = $this|0;
 $event = $event|0;
 var $$byval_copy = 0, $$lcssa = 0, $$not$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $it$05 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + ($event<<4)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($this) + ($event<<4)|0) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 L1: do {
  if ($5) {
   $$lcssa = $2;
  } else {
   $it$05 = $2;
   while(1) {
    $6 = HEAP32[$it$05>>2]|0;
    $7 = (($6) + 48|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + -1)|0;
    HEAP32[$7>>2] = $9;
    $10 = HEAP32[$7>>2]|0;
    $$not$i = ($10|0)!=(0);
    $11 = ($6|0)==(0|0);
    $or$cond$i = $11 | $$not$i;
    if (!($or$cond$i)) {
     __THREW__ = 0;
     invoke_vi(3446,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __ZdlPv($6);
    }
    $16 = (($it$05) + 4|0);
    $17 = HEAP32[$1>>2]|0;
    $18 = HEAP32[$3>>2]|0;
    $19 = (($17) + ($18<<2)|0);
    $20 = ($16|0)==($19|0);
    if ($20) {
     $$lcssa = $17;
     break L1;
    } else {
     $it$05 = $16;
    }
   }
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __ZdlPv($6);
   ___resumeException($14|0);
   // unreachable;
  }
 } while(0);
 $21 = ((($this) + ($event<<4)|0) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(-1);
 if (!($23)) {
  HEAP32[$3>>2] = 0;
  HEAP32[$21>>2] = 0;
  STACKTOP = sp;return;
 }
 $24 = ((($this) + ($event<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$0>>2] = $25;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($$lcssa,$$byval_copy);
 HEAP32[$1>>2] = 0;
 HEAP32[$3>>2] = 0;
 HEAP32[$21>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE($this,$event,$passContext) {
 $this = $this|0;
 $event = $event|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $it$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($this) + ($event<<4)|0) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + ($event<<4)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<2)|0);
 $it$01 = $4;
 while(1) {
  $6 = HEAP32[$it$01>>2]|0;
  __ZN22RenderingCommandBuffer20ExecuteCommandBufferERN9ShaderLab17ShaderPassContextE($6,$passContext);
  $7 = (($it$01) + 4|0);
  $8 = ($7|0)==($5|0);
  if ($8) {
   break;
  } else {
   $it$01 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19RenderEventsContext14ReleaseTempRTsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $it$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$02 = 0;
 while(1) {
  $0 = (($this) + ($i$02<<4)|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ((($this) + ($i$02<<4)|0) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($1) + ($3<<2)|0);
  $5 = ($3|0)==(0);
  if (!($5)) {
   $it$01 = $1;
   while(1) {
    $6 = HEAP32[$it$01>>2]|0;
    __ZN22RenderingCommandBuffer14ReleaseTempRTsEv($6);
    $7 = (($it$01) + 4|0);
    $8 = ($7|0)==($4|0);
    if ($8) {
     break;
    } else {
     $it$01 = $7;
    }
   }
  }
  $9 = (($i$02) + 1)|0;
  $exitcond = ($9|0)==(21);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZN8RendererD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$byval_copy20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i11$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy20 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 HEAP32[$this>>2] = ((605192 + 8|0));
 $4 = (($this) + 28|0);
 HEAP32[$4>>2] = ((605192 + 172|0));
 __THREW__ = 0;
 invoke_vi(3447,($this|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   $53 = ___cxa_find_matching_catch()|0;
   $54 = tempRet0;
   $55 = (($this) + 248|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)>(-1);
   if ($57) {
    $58 = (($this) + 236|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($this) + 240|0);
    $61 = HEAP32[$60>>2]|0;
    HEAP32[$1>>2] = $61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($59|0),($$byval_copy20|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if (!($63)) {
     HEAP32[$58>>2] = 0;
     $$1 = $54;$$12 = $53;
     label = 27;
    }
   } else {
    $$1 = $54;$$12 = $53;
    label = 27;
   }
  } else {
   $7 = (($this) + 248|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)>(-1);
   do {
    if ($9) {
     $10 = (($this) + 236|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($this) + 240|0);
     $13 = HEAP32[$12>>2]|0;
     HEAP32[$3>>2] = $13;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($11|0),($$byval_copy20|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      $51 = ___cxa_find_matching_catch()|0;
      $52 = tempRet0;
      $$1 = $52;$$12 = $51;
      label = 27;
      break L1;
     } else {
      HEAP32[$10>>2] = 0;
      break;
     }
    }
   } while(0);
   $16 = (($this) + 232|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>(-1);
   do {
    if ($18) {
     $19 = (($this) + 220|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($this) + 224|0);
     $22 = HEAP32[$21>>2]|0;
     HEAP32[$2>>2] = $22;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($20|0),($$byval_copy20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      $64 = ___cxa_find_matching_catch()|0;
      $65 = tempRet0;
      $$2 = $65;$$23 = $64;
      label = 31;
      break L1;
     } else {
      HEAP32[$19>>2] = 0;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    $$3 = $76;$$34 = $75;
    label = 32;
    break;
   }
   HEAP32[$this>>2] = ((562072 + 8|0));
   __THREW__ = 0;
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    HEAP32[$this>>2] = ((560936 + 8|0));
    __THREW__ = 0;
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     STACKTOP = sp;return;
    }
    $31 = ___cxa_find_matching_catch()|0;
    $32 = tempRet0;
    __THREW__ = 0;
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch(0|0)|0;
     $36 = tempRet0;
     ___clang_call_terminate($35);
     // unreachable;
    } else {
     ___resumeException($31|0);
     // unreachable;
    }
   }
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $43 = ___cxa_find_matching_catch(0|0)|0;
    $44 = tempRet0;
    __THREW__ = 0;
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     $47 = ___cxa_find_matching_catch(0|0)|0;
     $48 = tempRet0;
     ___clang_call_terminate($47);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $43;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if (!($42)) {
    ___resumeException($37|0);
    // unreachable;
   }
   $49 = ___cxa_find_matching_catch(0|0)|0;
   $50 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $49;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 27) {
  $66 = (($this) + 232|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)>(-1);
  if ($68) {
   $69 = (($this) + 220|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($this) + 224|0);
   $72 = HEAP32[$71>>2]|0;
   HEAP32[$0>>2] = $72;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($70|0),($$byval_copy20|0));
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if (!($74)) {
    HEAP32[$69>>2] = 0;
    $$2 = $$1;$$23 = $$12;
    label = 31;
   }
  } else {
   $$2 = $$1;$$23 = $$12;
   label = 31;
  }
 }
 if ((label|0) == 31) {
  __THREW__ = 0;
  $77 = __THREW__; __THREW__ = 0;
  $78 = $77&1;
  if (!($78)) {
   $$3 = $$2;$$34 = $$23;
   label = 32;
  }
 }
 do {
  if ((label|0) == 32) {
   HEAP32[$this>>2] = ((562072 + 8|0));
   __THREW__ = 0;
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if (!($80)) {
    HEAP32[$this>>2] = ((560936 + 8|0));
    __THREW__ = 0;
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if (!($82)) {
     __THREW__ = 0;
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      break;
     }
     ___resumeException($$34|0);
     // unreachable;
    }
    $83 = ___cxa_find_matching_catch(0|0)|0;
    $84 = tempRet0;
    __THREW__ = 0;
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     $87 = ___cxa_find_matching_catch(0|0)|0;
     $88 = tempRet0;
     ___clang_call_terminate($87);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $83;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $91 = ___cxa_find_matching_catch(0|0)|0;
   $92 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $97 = ___cxa_find_matching_catch(0|0)|0;
    $98 = tempRet0;
    __THREW__ = 0;
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     $101 = ___cxa_find_matching_catch(0|0)|0;
     $102 = tempRet0;
     ___clang_call_terminate($101);
     // unreachable;
    } else {
     $eh$lpad$body$i11$indexZ2D = $97;
     ___clang_call_terminate($eh$lpad$body$i11$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $95 = __THREW__; __THREW__ = 0;
   $96 = $95&1;
   if (!($96)) {
    $eh$lpad$body$indexZ2D = $91;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $103 = ___cxa_find_matching_catch(0|0)|0;
   $104 = tempRet0;
   $eh$lpad$body$i11$indexZ2D = $103;
   ___clang_call_terminate($eh$lpad$body$i11$indexZ2D);
   // unreachable;
  }
 } while(0);
 $105 = ___cxa_find_matching_catch(0|0)|0;
 $106 = tempRet0;
 $eh$lpad$body$indexZ2D = $105;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN19SkinnedMeshRenderer7GetMeshEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 296|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN19SkinnedMeshRenderer22CalculateAnimatedPosesEP10Matrix4x4fj($this,$poses,$size) {
 $this = $this|0;
 $poses = $poses|0;
 $size = $size|0;
 var $$0 = 0, $$byval_copy = 0, $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $exitcond = 0, $hasAnyBones$0$off04 = 0, $hasAnyBones$1$off0 = 0, $i$05 = 0, $or$cond = 0, $or$cond$i = 0, $phitmp$i = 0, $temp$0$i7 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy = sp + 72|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 312|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = (($this) + 300|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (($7) + 28|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 128|0);
   $12 = HEAP32[$11>>2]|0;
   $phitmp$i = ($12|0)>(0);
   if ($phitmp$i) {
    $13 = (($this) + 332|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0);
    if ($15) {
     __ZN19SkinnedMeshRenderer27CreateCachedAnimatorBindingEv($this);
     $$pre$i = HEAP32[$13>>2]|0;
     $17 = $$pre$i;
    } else {
     $17 = $14;
    }
    $16 = ($17|0)==(0);
    $18 = HEAP32[616152>>2]|0;
    $19 = ($18|0)==(0|0);
    $or$cond$i = $16 | $19;
    if ($or$cond$i) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $20 = HEAP32[628432>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Znwj10MemLabelIdbiPKci(24,$$byval_copy,0,16,585080,332)|0);
    $22 = (($this) + 344|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     __ZN19SkinnedMeshRenderer27CreateCachedAnimatorBindingEv($this);
     $$pre$i$i = HEAP32[$22>>2]|0;
     $25 = $$pre$i$i;
    } else {
     $25 = $23;
    }
    HEAP32[$21>>2] = $25;
    $26 = (($this) + 324|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($21) + 4|0);
    HEAP32[$28>>2] = $27;
    $29 = (($this) + 340|0);
    $30 = HEAP16[$29>>1]|0;
    $31 = $30&65535;
    $32 = (($21) + 8|0);
    HEAP32[$32>>2] = $31;
    $33 = (($21) + 12|0);
    HEAP32[$33>>2] = $size;
    $34 = (($21) + 16|0);
    HEAP32[$34>>2] = 0;
    $35 = (($21) + 20|0);
    HEAP32[$35>>2] = $poses;
    $36 = ($21|0)==(0|0);
    if ($36) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    __Z31DoCalculateAnimatorSkinMatricesPv($21);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $37 = ($4>>>0)<($size>>>0);
 $38 = ($size|0)==(0);
 $or$cond = $37 | $38;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = (($this) + 304|0);
 $hasAnyBones$0$off04 = 0;$i$05 = 0;
 while(1) {
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + ($i$05<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0);
  do {
   if ($43) {
    $44 = (($poses) + ($i$05<<6)|0);
    $82 = $44;
    label = 26;
   } else {
    HEAP32[$1>>2] = $42;
    $45 = HEAP32[560624>>2]|0;
    $46 = ($45|0)==(0|0);
    if ($46) {
     label = 24;
    } else {
     $47 = (($45) + 36|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($45) + 4|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($48|0)==($50|0);
     do {
      if ($51) {
       $52 = (($45) + 28|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (($45) + 32|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = (($53) + ($55<<3)|0);
       $72 = $56;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$45,$1);
       $57 = HEAP32[$$byval_copy>>2]|0;
       $58 = ($57|0)==(-1);
       $59 = (($45) + 28|0);
       $60 = HEAP32[$59>>2]|0;
       if ($58) {
        $61 = (($45) + 32|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = (($60) + ($62<<3)|0);
        $72 = $63;
        break;
       } else {
        $64 = (($60) + ($57<<3)|0);
        $72 = $64;
        break;
       }
      }
     } while(0);
     $65 = HEAP32[560624>>2]|0;
     $66 = (($65) + 28|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($65) + 32|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (($67) + ($69<<3)|0);
     $71 = ($72|0)==($70|0);
     if ($71) {
      label = 24;
     } else {
      $73 = (($72) + 4|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($74|0)==(0|0);
      if ($75) {
       label = 24;
      } else {
       $76 = (($poses) + ($i$05<<6)|0);
       $81 = $76;$temp$0$i7 = $74;
      }
     }
    }
    if ((label|0) == 24) {
     label = 0;
     $77 = HEAP32[$41>>2]|0;
     $78 = (__Z31ReadObjectFromPersistentManageri($77)|0);
     $79 = ($78|0)==(0|0);
     $80 = (($poses) + ($i$05<<6)|0);
     if ($79) {
      $82 = $80;
      label = 26;
      break;
     } else {
      $81 = $80;$temp$0$i7 = $78;
     }
    }
    __ZNK9Transform21GetLocalToWorldMatrixEv($2,$temp$0$i7);
    dest=$81+0|0; src=$2+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $hasAnyBones$1$off0 = 1;
   }
  } while(0);
  if ((label|0) == 26) {
   label = 0;
   (__ZN10Matrix4x4f11SetIdentityEv($82)|0);
   $hasAnyBones$1$off0 = $hasAnyBones$0$off04;
  }
  $83 = (($i$05) + 1)|0;
  $exitcond = ($83|0)==($size|0);
  if ($exitcond) {
   $$0 = $hasAnyBones$1$off0;
   break;
  } else {
   $hasAnyBones$0$off04 = $hasAnyBones$1$off0;$i$05 = $83;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN19SkinnedMeshRenderer22CreateSkinMatricesTaskEP10Matrix4x4fjb($this,$outputPoses,$bindposeCount,$useBindpose) {
 $this = $this|0;
 $outputPoses = $outputPoses|0;
 $bindposeCount = $bindposeCount|0;
 $useBindpose = $useBindpose|0;
 var $$0 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 332|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __ZN19SkinnedMeshRenderer27CreateCachedAnimatorBindingEv($this);
  $$pre = HEAP32[$1>>2]|0;
  $5 = $$pre;
 } else {
  $5 = $2;
 }
 $4 = ($5|0)==(0);
 $6 = HEAP32[616152>>2]|0;
 $7 = ($6|0)==(0|0);
 $or$cond = $4 | $7;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP32[628432>>2]|0;
 HEAP32[$0>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $9 = (__Znwj10MemLabelIdbiPKci(24,$$byval_copy,0,16,585080,332)|0);
 $10 = (($this) + 344|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  __ZN19SkinnedMeshRenderer27CreateCachedAnimatorBindingEv($this);
  $$pre$i = HEAP32[$10>>2]|0;
  $13 = $$pre$i;
 } else {
  $13 = $11;
 }
 HEAP32[$9>>2] = $13;
 $14 = (($this) + 324|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($9) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 340|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18&65535;
 $20 = (($9) + 8|0);
 HEAP32[$20>>2] = $19;
 $21 = (($9) + 12|0);
 HEAP32[$21>>2] = $bindposeCount;
 if ($useBindpose) {
  $22 = (($this) + 300|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (__ZN4Mesh21AcquireSharedMeshDataEv($23)|0);
  $26 = $24;
 } else {
  $26 = 0;
 }
 $25 = (($9) + 16|0);
 HEAP32[$25>>2] = $26;
 $27 = (($9) + 20|0);
 HEAP32[$27>>2] = $outputPoses;
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function __ZN19SkinnedMeshRenderer27CreateCachedAnimatorBindingEv($this) {
 $this = $this|0;
 var $$02$i$i$i$i = 0, $$byval_copy5 = 0, $$masked$i$i$i = 0, $$pr = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i$i = 0, $i$03$i$i$i$i = 0, $p$01$i$i$i = 0, $reflection$01$i$i$i$i = 0, $reflection$1$i$i$i$i = 0;
 var $rootBoneHash = 0, $rootBonePath = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp + 36|0;
 $0 = sp;
 $1 = sp + 4|0;
 $rootBoneHash = sp + 8|0;
 $rootBonePath = sp + 12|0;
 $2 = sp + 24|0;
 $3 = (($this) + 344|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  __ZN6Object11RemoveEventEPFvPvS0_iES0_($4,1695,$this);
  $6 = (($this) + 284|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   __Z21CompleteFenceInternalR8JobFence($6);
  }
  $9 = (($this) + 336|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)>(-1);
  if ($11) {
   $12 = (($this) + 324|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($this) + 328|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$0>>2] = $15;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($13,$$byval_copy5);
   HEAP32[$12>>2] = 0;
  }
  $16 = (($this) + 332|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$9>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $17 = (($this) + 300|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (($18) + 124|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($18) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 128|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($21|0)==($25|0);
 if (!($26)) {
  $27 = (($18) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(585176,0,585080,1469,1,$28,0,0);
  STACKTOP = sp;return;
 }
 $29 = (($this) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (__Z34FindAncestorComponentExactTypeImplRN5Unity10GameObjectEi($30,95)|0);
 HEAP32[$3>>2] = $31;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (__Z13GetIAnimationv()|0);
 $34 = ($33|0)==(0|0);
 if ($34) {
  STACKTOP = sp;return;
 }
 $35 = (($this) + 284|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  __Z21CompleteFenceInternalR8JobFence($35);
 }
 $38 = (($this) + 324|0);
 $39 = HEAP32[$29>>2]|0;
 $40 = HEAP32[$3>>2]|0;
 $41 = (($40) + 24|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($39|0)==($42|0);
 if ($43) {
  $44 = (($this) + 340|0);
  HEAP16[$44>>1] = 0;
 } else {
  $45 = HEAP32[$17>>2]|0;
  $46 = (($45) + 132|0);
  $47 = HEAP32[$46>>2]|0;
  HEAP32[$rootBoneHash>>2] = $47;
  $48 = ($47|0)==(0);
  L28: do {
   if ($48) {
    $49 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($42)|0);
    $50 = HEAP32[$29>>2]|0;
    $51 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($50)|0);
    __Z22CalculateTransformPathRK9TransformPS0_($2,$51,$49);
    $52 = HEAP8[$2>>0]|0;
    $53 = $52 & 1;
    $54 = ($53<<24>>24)==(0);
    if ($54) {
     $59 = (($2) + 1|0);
     $60 = $52&255;
     $61 = $60 >>> 1;
     $63 = $61;$78 = $59;
    } else {
     $55 = (($2) + 8|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($2) + 4|0);
     $58 = HEAP32[$57>>2]|0;
     $63 = $58;$78 = $56;
    }
    $62 = ($63>>>0)>(2147483631);
    do {
     if ($62) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if (!($65)) {
       // unreachable;
      }
     } else {
      $66 = ($63>>>0)<(11);
      if ($66) {
       $67 = $63 << 1;
       $68 = $67&255;
       HEAP8[$rootBonePath>>0] = $68;
       $69 = (($rootBonePath) + 1|0);
       $__p$0$i$i$i$i = $69;
      } else {
       $70 = (($63) + 16)|0;
       $71 = $70 & -16;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $72 = (invoke_iiiiiii(102,($71|0),16,($$byval_copy5|0),0,(585080|0),79)|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($rootBonePath) + 8|0);
       HEAP32[$75>>2] = $72;
       $76 = $71 | 1;
       HEAP32[$rootBonePath>>2] = $76;
       $77 = (($rootBonePath) + 4|0);
       HEAP32[$77>>2] = $63;
       $__p$0$i$i$i$i = $72;
      }
      _memcpy(($__p$0$i$i$i$i|0),($78|0),($63|0))|0;
      $79 = (($__p$0$i$i$i$i) + ($63)|0);
      HEAP8[$79>>0] = 0;
      $80 = HEAP8[$2>>0]|0;
      $81 = $80 & 1;
      $82 = ($81<<24>>24)==(0);
      if (!($82)) {
       $83 = (($2) + 8|0);
       $84 = HEAP32[$83>>2]|0;
       __ZdlPv($84);
      }
      $85 = HEAP8[$rootBonePath>>0]|0;
      $86 = $85 & 1;
      $87 = ($86<<24>>24)==(0);
      if ($87) {
       $90 = (($rootBonePath) + 1|0);
       $98 = $90;
      } else {
       $88 = (($rootBonePath) + 8|0);
       $89 = HEAP32[$88>>2]|0;
       $98 = $89;
      }
      $$02$i$i$i$i = -1;$i$03$i$i$i$i = 0;$reflection$01$i$i$i$i = 0;
      while(1) {
       $91 = $$02$i$i$i$i & 1;
       $92 = ($91|0)==(0);
       if ($92) {
        $reflection$1$i$i$i$i = $reflection$01$i$i$i$i;
       } else {
        $93 = (31 - ($i$03$i$i$i$i))|0;
        $94 = 1 << $93;
        $95 = $94 | $reflection$01$i$i$i$i;
        $reflection$1$i$i$i$i = $95;
       }
       $96 = (($i$03$i$i$i$i) + 1)|0;
       $97 = $$02$i$i$i$i >>> 1;
       $exitcond$i$i$i$i = ($96|0)==(32);
       if ($exitcond$i$i$i$i) {
        break;
       } else {
        $$02$i$i$i$i = $97;$i$03$i$i$i$i = $96;$reflection$01$i$i$i$i = $reflection$1$i$i$i$i;
       }
      }
      $99 = (_strlen(($98|0))|0);
      $100 = (($98) + ($99)|0);
      $101 = ($99|0)>(0);
      if ($101) {
       $105 = $reflection$1$i$i$i$i;$p$01$i$i$i = $98;
       while(1) {
        $102 = HEAP8[$p$01$i$i$i>>0]|0;
        $103 = $102&255;
        $104 = $105 >>> 8;
        $$masked$i$i$i = $105 & 255;
        $106 = $103 ^ $$masked$i$i$i;
        $107 = (584048 + ($106<<2)|0);
        $108 = HEAP32[$107>>2]|0;
        $109 = $108 ^ $104;
        $110 = (($p$01$i$i$i) + 1|0);
        $exitcond$i$i$i = ($110|0)==($100|0);
        if ($exitcond$i$i$i) {
         $112 = $109;
         break;
        } else {
         $105 = $109;$p$01$i$i$i = $110;
        }
       }
      } else {
       $112 = $reflection$1$i$i$i$i;
      }
      $111 = $112 ^ -1;
      HEAP32[$rootBoneHash>>2] = $111;
      do {
       if ($87) {
        $127 = $111;
       } else {
        $113 = (($rootBonePath) + 8|0);
        $114 = HEAP32[$113>>2]|0;
        HEAP32[$0>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($114|0),($$byval_copy5|0));
        $115 = __THREW__; __THREW__ = 0;
        $116 = $115&1;
        if ($116) {
         $117 = ___cxa_find_matching_catch()|0;
         $118 = tempRet0;
         ___cxa_call_unexpected(($117|0));
         // unreachable;
        } else {
         $$pr = HEAP32[$rootBoneHash>>2]|0;
         $127 = $$pr;
         break;
        }
       }
      } while(0);
      $126 = ($127|0)==(0);
      if (!($126)) {
       break L28;
      }
      STACKTOP = sp;return;
     }
    } while(0);
    $119 = ___cxa_find_matching_catch()|0;
    $120 = tempRet0;
    $121 = HEAP8[$2>>0]|0;
    $122 = $121 & 1;
    $123 = ($122<<24>>24)==(0);
    if ($123) {
     ___resumeException($119|0);
     // unreachable;
    }
    $124 = (($2) + 8|0);
    $125 = HEAP32[$124>>2]|0;
    __ZdlPv($125);
    ___resumeException($119|0);
    // unreachable;
   }
  } while(0);
  $128 = (__Z13GetIAnimationv()|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = HEAP32[$129>>2]|0;
  $131 = HEAP32[$3>>2]|0;
  $132 = (($this) + 340|0);
  $133 = (FUNCTION_TABLE_iiiiii[$130 & 255]($128,$131,$rootBoneHash,1,$132)|0);
  if (!($133)) {
   STACKTOP = sp;return;
  }
 }
 $134 = HEAP32[$20>>2]|0;
 $135 = (($this) + 332|0);
 HEAP32[$135>>2] = $134;
 $136 = (($this) + 336|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = $137 & 2147483647;
 $139 = ($138>>>0)<($134>>>0);
 do {
  if ($139) {
   $140 = ($137|0)>(-1);
   if ($140) {
    HEAP32[$136>>2] = $134;
    $141 = HEAP32[$38>>2]|0;
    $142 = $134 << 1;
    $143 = (($this) + 328|0);
    $144 = HEAP32[$143>>2]|0;
    HEAP32[$1>>2] = $144;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    $145 = (__Z16realloc_internalPvji10MemLabelIdiPKci($141,$142,2,$$byval_copy5,0,585080,370)|0);
    HEAP32[$38>>2] = $145;
    $$pre$phiZ2D = $38;
    break;
   } else {
    $146 = $134 << 1;
    $147 = (($this) + 328|0);
    $148 = HEAP32[$147>>2]|0;
    HEAP32[$1>>2] = $148;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    $149 = (__Z15malloc_internaljj10MemLabelIdiPKci($146,2,$$byval_copy5,0,585080,352)|0);
    $150 = HEAP32[$38>>2]|0;
    $151 = HEAP32[$135>>2]|0;
    $152 = $151 << 1;
    _memcpy(($149|0),($150|0),($152|0))|0;
    HEAP32[$136>>2] = $134;
    HEAP32[$38>>2] = $149;
    $$pre$phiZ2D = $38;
    break;
   }
  } else {
   $$pre$phiZ2D = $38;
  }
 } while(0);
 $153 = (__Z13GetIAnimationv()|0);
 $154 = HEAP32[$153>>2]|0;
 $155 = HEAP32[$154>>2]|0;
 $156 = HEAP32[$3>>2]|0;
 $157 = (($18) + 116|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = HEAP32[$20>>2]|0;
 $160 = HEAP32[$$pre$phiZ2D>>2]|0;
 $161 = (FUNCTION_TABLE_iiiiii[$155 & 255]($153,$156,$158,$159,$160)|0);
 if (!($161)) {
  $162 = HEAP32[$136>>2]|0;
  $163 = ($162|0)>(-1);
  if ($163) {
   $164 = HEAP32[$$pre$phiZ2D>>2]|0;
   $165 = (($this) + 328|0);
   $166 = HEAP32[$165>>2]|0;
   HEAP32[$1>>2] = $166;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($164,$$byval_copy5);
   HEAP32[$$pre$phiZ2D>>2] = 0;
  }
  HEAP32[$135>>2] = 0;
  HEAP32[$136>>2] = 0;
 }
 $167 = HEAP32[$3>>2]|0;
 __ZN6Object8AddEventEPFvPvS0_iES0_($167,1695,$this);
 STACKTOP = sp;return;
}
function __ZN19SkinnedMeshRenderer17PrepareSkinCommonEiR12SkinMeshInfo($this,$flags,$skin) {
 $this = $this|0;
 $flags = $flags|0;
 $skin = $skin|0;
 var $$ = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i6 = 0, $$0$i5 = 0, $$1 = 0, $$byval_copy1 = 0, $$pre = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $hasBlendshape$0$in14 = 0, $i$0$i = 0, $i$0$in$i = 0, $or$cond = 0, $phitmp$i = 0, $phitmp$i8 = 0, $phitmp2 = 0, $rootPose = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy1 = sp + 172|0;
 $0 = sp;
 $rootPose = sp + 8|0;
 $1 = sp + 72|0;
 $2 = sp + 136|0;
 $3 = (($this) + 424|0);
 HEAP8[$3>>0] = 0;
 $4 = (($this) + 300|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $7 = (__ZNK4Mesh15GetSubMeshCountEv($5)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $9 = HEAP32[$4>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $28 = 0;
 } else {
  $11 = (($9) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 128|0);
  $14 = HEAP32[$13>>2]|0;
  $28 = $14;
 }
 $15 = (($this) + 348|0);
 $16 = (($this) + 360|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = ($17>>>0)<($18>>>0);
 $20 = $19 ? $17 : $18;
 $21 = (($this) + 352|0);
 $i$0$in$i = $20;
 while(1) {
  $i$0$i = (($i$0$in$i) + -1)|0;
  $22 = ($i$0$i|0)>(-1);
  if (!($22)) {
   $$0$i = 0;
   break;
  }
  $23 = HEAP32[$21>>2]|0;
  $24 = (($23) + ($i$0$i<<2)|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = $25 > Math_fround(9.99999974737875163555E-5);
  if ($26) {
   $$0$i = $i$0$in$i;
   break;
  } else {
   $i$0$in$i = $i$0$i;
  }
 }
 $27 = ($28|0)>(0);
 do {
  if ($27) {
   $29 = (__ZN4Mesh17VerifyBoneIndicesEj($9,$28)|0);
   if (!($29)) {
    $30 = ($this|0)==(0|0);
    if ($30) {
     $33 = 0;
    } else {
     $31 = (($this) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = $32;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(585088,0,585080,357,1,$33,0,0);
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $34 = HEAP32[$4>>2]|0;
   $35 = (($34) + 28|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 144|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0);
   if ($39) {
    label = 18;
   } else {
    $40 = (($this) + 312|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)!=(0);
    $43 = ($34|0)==(0|0);
    $or$cond = $42 | $43;
    if (!($or$cond)) {
     $44 = (($36) + 128|0);
     $45 = HEAP32[$44>>2]|0;
     $phitmp$i = ($45|0)>(0);
     if ($phitmp$i) {
      $46 = (($this) + 332|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($47|0)==(0);
      if ($48) {
       __ZN19SkinnedMeshRenderer27CreateCachedAnimatorBindingEv($this);
       $$pre = HEAP32[$46>>2]|0;
       $phitmp2 = ($$pre|0)==(0);
       if ($phitmp2) {
        label = 18;
        break;
       }
      }
     }
    }
    $51 = ($$0$i|0)>(0);
    if ($51) {
     $72 = 1;$79 = 0;$hasBlendshape$0$in14 = 1;
    } else {
     $52 = $flags & 8;
     $53 = ($52|0)==(0);
     if ($53) {
      $72 = 1;$79 = 0;$hasBlendshape$0$in14 = 0;
     } else {
      $54 = (($this) + 428|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ($55|0)==(0|0);
      if ($56) {
       $57 = (($this) + 432|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = ($58|0)==(0|0);
       if ($59) {
        $72 = 1;$79 = 0;$hasBlendshape$0$in14 = 0;
       } else {
        $60 = (__Z17GetPlayerSettingsv()|0);
        $61 = (($60) + 182|0);
        $62 = HEAP8[$61>>0]|0;
        $63 = ($62<<24>>24)==(0);
        $64 = HEAP8[((640792 + 255|0))>>0]|0;
        $$ = $63 ? 0 : $64;
        $72 = 1;$79 = $$;$hasBlendshape$0$in14 = 0;
       }
      } else {
       $72 = 1;$79 = 0;$hasBlendshape$0$in14 = 0;
      }
     }
    }
   }
  } else {
   label = 18;
  }
 } while(0);
 if ((label|0) == 18) {
  $49 = HEAP32[$15>>2]|0;
  $50 = ($49|0)!=(0);
  $72 = 0;$79 = 0;$hasBlendshape$0$in14 = $50;
 }
 $65 = HEAP32[$4>>2]|0;
 $66 = (($65) + 28|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 96|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($this) + 420|0);
 HEAP32[$70>>2] = $69;
 $71 = $72 ? $28 : 0;
 $73 = (($skin) + 8|0);
 HEAP32[$73>>2] = $71;
 $74 = (($skin) + 56|0);
 HEAP32[$74>>2] = $$0$i;
 $75 = (($67) + 100|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($skin) + 40|0);
 HEAP32[$77>>2] = $76;
 $78 = (($skin) + 80|0);
 HEAP8[$78>>0] = $79;
 __ZN12SkinMeshInfo8AllocateEv($skin);
 do {
  if ($72) {
   $80 = (($this) + 392|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($81|0)==(0);
   if ($82) {
    $83 = (__Z18GetQualitySettingsv()|0);
    $84 = (($83) + 40|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($83) + 24|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ((($87) + (($85*96)|0)|0) + 56|0);
    $89 = HEAP32[$88>>2]|0;
    $$0$i5 = $89;
   } else {
    $$0$i5 = $81;
   }
   HEAP32[$skin>>2] = $$0$i5;
   $90 = HEAP32[$4>>2]|0;
   $91 = (__ZN4Mesh16GetSkinInfluenceEi($90,$$0$i5)|0);
   $92 = (($skin) + 4|0);
   HEAP32[$92>>2] = $91;
   $93 = (($this) + 320|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (__ZN6Object24IDToPointerNoThreadCheckEi($94)|0);
   $96 = ($95|0)==(0|0);
   if ($96) {
    $97 = (__ZN8Renderer12GetTransformEv($this)|0);
    $$0$i$i6 = $97;
   } else {
    $$0$i$i6 = $95;
   }
   __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($1,$$0$i$i6);
   dest=$rootPose+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $98 = (($this) + 312|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)==(0);
   if ($100) {
    $101 = HEAP32[$4>>2]|0;
    $102 = ($101|0)==(0|0);
    if ($102) {
     label = 32;
    } else {
     $105 = (($101) + 28|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = (($106) + 128|0);
     $108 = HEAP32[$107>>2]|0;
     $phitmp$i8 = ($108|0)>(0);
     $109 = (($skin) + 48|0);
     $110 = HEAP32[$109>>2]|0;
     if ($phitmp$i8) {
      $111 = (__ZN19SkinnedMeshRenderer22CreateSkinMatricesTaskEP10Matrix4x4fjb($this,$110,$28,1)|0);
      $112 = ($111|0)==(0|0);
      if ($112) {
       $$1 = 0;
       STACKTOP = sp;return ($$1|0);
      } else {
       $113 = (($this) + 284|0);
       $114 = HEAP32[616152>>2]|0;
       __Z11ScheduleJobR8JobFencePFvPvES1_11JobPriority($113,$114,$111,0);
       $115 = (__Z13GetIAnimationv()|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = (($116) + 8|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = (($this) + 344|0);
       $120 = HEAP32[$119>>2]|0;
       FUNCTION_TABLE_viii[$118 & 4095]($115,$120,$113);
       $121 = (($skin) + 64|0);
       $122 = $113;
       $123 = $122;
       $124 = HEAP32[$123>>2]|0;
       $125 = (($122) + 4)|0;
       $126 = $125;
       $127 = HEAP32[$126>>2]|0;
       $128 = $121;
       $129 = $128;
       HEAP32[$129>>2] = $124;
       $130 = (($128) + 4)|0;
       $131 = $130;
       HEAP32[$131>>2] = $127;
       break;
      }
     } else {
      $132 = $110;
     }
    }
   } else {
    label = 32;
   }
   if ((label|0) == 32) {
    $103 = (($skin) + 48|0);
    $104 = HEAP32[$103>>2]|0;
    $132 = $104;
   }
   $133 = (__ZN19SkinnedMeshRenderer22CalculateAnimatedPosesEP10Matrix4x4fj($this,$132,$28)|0);
   if (!($133)) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $134 = HEAP32[$4>>2]|0;
   $135 = (($134) + 28|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = (($136) + 128|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ($138|0)==(0);
   if ($139) {
    $142 = 0;
   } else {
    $140 = (($136) + 120|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = $141;
   }
   __Z33MultiplyMatrixArrayWithBase4x4REFPK10Matrix4x4fS1_S1_PS_j($rootPose,$132,$142,$132,$28);
  } else {
   $143 = (($this) + 428|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ($144|0)==(0|0);
   $146 = (($skin) + 48|0);
   if ($145) {
    HEAP32[$146>>2] = 0;
   } else {
    $147 = HEAP32[$146>>2]|0;
    $148 = (($this) + 320|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = (__ZN6Object24IDToPointerNoThreadCheckEi($149)|0);
    $151 = ($150|0)==(0|0);
    if ($151) {
     $152 = (__ZN8Renderer12GetTransformEv($this)|0);
     $$0$i$i = $152;
    } else {
     $$0$i$i = $150;
    }
    __ZNK9Transform13GetWorldScaleEv($2,$$0$i$i);
    (__ZN10Matrix4x4faSERK10Matrix3x3f($147,$2)|0);
   }
   $153 = (($skin) + 4|0);
   HEAP32[$153>>2] = 0;
  }
 } while(0);
 if ($hasBlendshape$0$in14) {
  $154 = (($skin) + 52|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = HEAP32[$21>>2]|0;
  $157 = HEAP32[$74>>2]|0;
  $158 = $157 << 2;
  _memcpy(($155|0),($156|0),($158|0))|0;
  $159 = HEAP32[$4>>2]|0;
  $160 = (($159) + 56|0);
  $161 = (($skin) + 60|0);
  HEAP32[$161>>2] = $160;
 }
 $162 = HEAP32[$4>>2]|0;
 $163 = (($162) + 28|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = (($164) + 44|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = (($164) + 50|0);
 $168 = HEAP8[$167>>0]|0;
 $169 = (($164) + 92|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = (($170) + ($166)|0);
 $172 = (($skin) + 12|0);
 HEAP32[$172>>2] = $171;
 $173 = $168&255;
 $174 = (($skin) + 20|0);
 HEAP32[$174>>2] = $173;
 $175 = (($skin) + 24|0);
 HEAP32[$175>>2] = $173;
 $176 = $flags & 1;
 $177 = ($176|0)==(0);
 do {
  if ($177) {
   $178 = (__Z12GetGfxDevicev()|0);
   $179 = (($this) + 400|0);
   $180 = HEAP32[$179>>2]|0;
   $181 = ($180|0)==(0|0);
   if ($181) {
    $182 = HEAP32[$178>>2]|0;
    $183 = (($182) + 276|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = (FUNCTION_TABLE_ii[$184 & 4095]($178)|0);
    HEAP32[$179>>2] = $185;
    $193 = $185;
   } else {
    $193 = $180;
   }
   $186 = HEAP8[$78>>0]|0;
   $187 = ($186<<24>>24)!=(0);
   $188 = $187 ? 3 : 1;
   $189 = (($164) + 100|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = Math_imul($190, $173)|0;
   $192 = (($193) + 12|0);
   $194 = HEAP32[$192>>2]|0;
   $195 = ($194|0)==($188|0);
   if ($195) {
    $196 = HEAP32[$193>>2]|0;
    $197 = (($196) + 8|0);
    $198 = HEAP32[$197>>2]|0;
    $199 = (FUNCTION_TABLE_ii[$198 & 4095]($193)|0);
    $$pre19 = HEAP32[$179>>2]|0;
    if ($199) {
     $206 = $$pre19;
    } else {
     $200 = (($$pre19) + 20|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = ($201|0)==($191|0);
     if ($202) {
      break;
     } else {
      $206 = $$pre19;
     }
    }
   } else {
    $206 = $193;
   }
   $203 = HEAP32[$178>>2]|0;
   $204 = (($203) + 280|0);
   $205 = HEAP32[$204>>2]|0;
   FUNCTION_TABLE_viiiiiii[$205 & 127]($178,$206,$188,0,$191,0,0);
  }
 } while(0);
 $207 = HEAP8[$78>>0]|0;
 $208 = ($207<<24>>24)==(0);
 if (!($208)) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $209 = (($164) + 15|0);
 $210 = HEAP8[$209>>0]|0;
 $211 = ($210<<24>>24)!=(0);
 $212 = (($skin) + 36|0);
 $213 = $211&1;
 HEAP8[$212>>0] = $213;
 $214 = (($164) + 13|0);
 $215 = HEAP8[$214>>0]|0;
 $216 = $215&255;
 $217 = (($skin) + 28|0);
 HEAP32[$217>>2] = $216;
 $218 = (($164) + 39|0);
 $219 = HEAP8[$218>>0]|0;
 $220 = ($219<<24>>24)!=(0);
 $221 = (($skin) + 37|0);
 $222 = $220&1;
 HEAP8[$221>>0] = $222;
 $223 = (($164) + 37|0);
 $224 = HEAP8[$223>>0]|0;
 $225 = $224&255;
 $226 = (($skin) + 32|0);
 HEAP32[$226>>2] = $225;
 $227 = $flags & 2;
 $228 = ($227|0)==(0);
 if ($228) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $229 = (($this) + 404|0);
 $230 = HEAP32[$175>>2]|0;
 $231 = HEAP32[$77>>2]|0;
 $232 = Math_imul($231, $230)|0;
 $233 = (($this) + 412|0);
 HEAP32[$233>>2] = $232;
 $234 = (($this) + 416|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = $235 & 2147483647;
 $237 = ($236>>>0)<($232>>>0);
 do {
  if ($237) {
   $238 = ($235|0)>(-1);
   if ($238) {
    HEAP32[$234>>2] = $232;
    $239 = HEAP32[$229>>2]|0;
    $240 = (($this) + 408|0);
    $241 = HEAP32[$240>>2]|0;
    HEAP32[$0>>2] = $241;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $242 = (__Z16realloc_internalPvji10MemLabelIdiPKci($239,$232,1,$$byval_copy1,0,585080,370)|0);
    HEAP32[$229>>2] = $242;
    $249 = $242;
    break;
   } else {
    $243 = (($this) + 408|0);
    $244 = HEAP32[$243>>2]|0;
    HEAP32[$0>>2] = $244;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $245 = (__Z15malloc_internaljj10MemLabelIdiPKci($232,1,$$byval_copy1,0,585080,352)|0);
    $246 = HEAP32[$229>>2]|0;
    $247 = HEAP32[$233>>2]|0;
    _memcpy(($245|0),($246|0),($247|0))|0;
    HEAP32[$234>>2] = $232;
    HEAP32[$229>>2] = $245;
    $249 = $245;
    break;
   }
  } else {
   $$pre20 = HEAP32[$229>>2]|0;
   $249 = $$pre20;
  }
 } while(0);
 $248 = (($skin) + 16|0);
 HEAP32[$248>>2] = $249;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZN19SkinnedMeshRenderer17GetActualRootBoneEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN6Object24IDToPointerNoThreadCheckEi($1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = (__ZN8Renderer12GetTransformEv($this)|0);
  $$0$i = $4;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $$0$i = $2;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN19SkinnedMeshRenderer8SkinMeshER12SkinMeshInfob($this,$skin,$lastGpuSkinningThisFrame) {
 $this = $this|0;
 $skin = $skin|0;
 $lastGpuSkinningThisFrame = $lastGpuSkinningThisFrame|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $mesh = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $mesh = sp;
 $0 = (($this) + 292|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if (!($2)) {
  $3 = (__Z12GetGfxDevicev()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 320|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$0>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($3,$7);
  HEAP32[$0>>2] = -1;
 }
 $8 = (__Z12GetGfxDevicev()|0);
 $9 = (($skin) + 80|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $59 = (__Z12GetGfxDevicev()|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 316|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($this) + 400|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (FUNCTION_TABLE_iiii[$62 & 2047]($59,$skin,$64)|0);
  HEAP32[$0>>2] = $65;
  $66 = ($65|0)!=(-1);
  $$0 = $66;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($skin) + 64|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  __Z21CompleteFenceInternalR8JobFence($12);
 }
 $15 = (__Z12GetGfxDevicev()|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 376|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 432|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($skin) + 48|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($skin) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_viiii[$18 & 511]($15,$20,$22,$24);
 __ZN12SkinMeshInfo7ReleaseEv($skin);
 $25 = (($this) + 300|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 __ZN4Mesh14GetMeshBuffersEjPS_($mesh,$26,$30,0);
 $31 = HEAP32[$8>>2]|0;
 $32 = (($31) + 380|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($mesh) + 8|0);
 $35 = (($skin) + 84|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$19>>2]|0;
 $38 = (($this) + 400|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($skin) + 40|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$skin>>2]|0;
 FUNCTION_TABLE_viiiiiiiii[$33 & 31]($8,$34,$36,$37,$39,$41,$42,$30,$lastGpuSkinningThisFrame);
 $43 = HEAP32[$40>>2]|0;
 $44 = (($8) + 5544|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = ($45<<24>>24)==(0);
 if ($46) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $47 = (($8) + 5344|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + 1)|0;
 HEAP32[$47>>2] = $49;
 $50 = (($8) + 5348|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + ($43))|0;
 HEAP32[$50>>2] = $52;
 $53 = (($8) + 5356|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + ($43))|0;
 HEAP32[$53>>2] = $55;
 $56 = (($8) + 5352|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($43))|0;
 HEAP32[$56>>2] = $58;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN19SkinnedMeshRenderer22UpdateAllSkinnedMeshesENS_10UpdateTypeEP13dynamic_arrayIPS_Lj4EE($updateType,$outMeshes) {
 $updateType = $updateType|0;
 $outMeshes = $outMeshes|0;
 var $$ = 0, $$$i = 0, $$0 = 0, $$01 = 0, $$1$i = 0, $$byval_copy22 = 0, $$idx = 0, $$ph$ph$ph$ph = 0, $$ph40$ph$ph$ph = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i1$046 = 0, $i2$041 = 0, $i4$052 = 0, $lastGpuSkinning$062 = 0, $lastGpuSkinning$1 = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $node$0$i = 0, $node$01$i = 0, $node$03$i = 0, $not$ = 0, $phitmp = 0, $phitmp65 = 0, $size$0$lcssa$i = 0, $size$02$i = 0, $skinCount$025 = 0;
 var $skinCount$025$ph$ph$ph$ph = 0, $skinCount$02836 = 0, $skinCount$029 = 0, $skinCount$030 = 0, $skinCount$031 = 0, $skinCount$032 = 0, $skinCount$032$ph$ph$ph$ph = 0, $skinCount$03234 = 0, $skinCount$061 = 0, $skinCount$1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy22 = sp + 40|0;
 $0 = sp + 36|0;
 $1 = sp + 32|0;
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = sp + 20|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 $9 = sp + 16|0;
 $10 = ($updateType|0)==(0);
 $$ = $10 ? 2 : 8;
 $node$01$i = HEAP32[((585072 + 4|0))>>2]|0;
 $11 = ($node$01$i|0)==(585072|0);
 if ($11) {
  $size$0$lcssa$i = 0;
 } else {
  $node$03$i = $node$01$i;$size$02$i = 0;
  while(1) {
   $12 = (($node$03$i) + 4|0);
   $13 = (($size$02$i) + 1)|0;
   $node$0$i = HEAP32[$12>>2]|0;
   $14 = ($node$0$i|0)==(585072|0);
   if ($14) {
    $size$0$lcssa$i = $13;
    break;
   } else {
    $node$03$i = $node$0$i;$size$02$i = $13;
   }
  }
 }
 $15 = HEAP32[628512>>2]|0;
 $16 = $size$0$lcssa$i << 2;
 HEAP32[$0>>2] = $15;
 ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
 $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($16,4,$$byval_copy22,0,585080,352)|0);
 $18 = HEAP32[628512>>2]|0;
 $19 = ($size$0$lcssa$i*92)|0;
 HEAP32[$9>>2] = $18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$9+0>>2]|0;
 $20 = (invoke_iiiiiii(102,($19|0),4,($$byval_copy22|0),0,(585080|0),352)|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 L5: do {
  if ($22) {
   $186 = $17;$skinCount$031 = $size$0$lcssa$i;
   label = 6;
  } else {
   $23 = HEAP32[((585072 + 4|0))>>2]|0;
   $24 = ($23|0)==(585072|0);
   L7: do {
    if ($24) {
     $175 = $20;$179 = $17;$skinCount$029 = $size$0$lcssa$i;
    } else {
     $26 = $23;$lastGpuSkinning$062 = 0;$skinCount$061 = 0;
     while(1) {
      $25 = (($26) + 8|0);
      $27 = HEAP32[$25>>2]|0;
      $28 = (($27) + 428|0);
      $29 = HEAP32[$28>>2]|0;
      $not$ = ($29|0)==(0|0);
      $30 = $not$&1;
      $31 = ($30|0)==($updateType|0);
      if ($31) {
       $48 = (($20) + (($skinCount$061*92)|0)|0);
       dest=$48+0|0; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       __THREW__ = 0;
       $49 = (invoke_iiii(1540,($27|0),($$|0),($48|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        label = 10;
        break;
       }
       if ($49) {
        $52 = ((($20) + (($skinCount$061*92)|0)|0) + 80|0);
        $53 = HEAP8[$52>>0]|0;
        $54 = ($53<<24>>24)==(0);
        if ($54) {
         $192 = $lastGpuSkinning$062;
        } else {
         $55 = (($27) + 300|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = HEAP32[$48>>2]|0;
         __THREW__ = 0;
         $58 = (invoke_iii(2384,($56|0),($57|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 10;
          break;
         }
         $61 = ((($20) + (($skinCount$061*92)|0)|0) + 84|0);
         HEAP32[$61>>2] = $58;
         $$pre = HEAP8[$52>>0]|0;
         $phitmp = ($$pre<<24>>24)==(0);
         $phitmp65 = $phitmp ? $lastGpuSkinning$062 : $48;
         $192 = $phitmp65;
        }
        $62 = (($17) + ($skinCount$061<<2)|0);
        HEAP32[$62>>2] = $27;
        $63 = (($skinCount$061) + 1)|0;
        $lastGpuSkinning$1 = $192;$skinCount$1 = $63;
       } else {
        $lastGpuSkinning$1 = $lastGpuSkinning$062;$skinCount$1 = $skinCount$061;
       }
      } else {
       $lastGpuSkinning$1 = $lastGpuSkinning$062;$skinCount$1 = $skinCount$061;
      }
      $64 = (($26) + 4|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = ($65|0)==(585072|0);
      if ($66) {
       label = 21;
       break;
      } else {
       $26 = $65;$lastGpuSkinning$062 = $lastGpuSkinning$1;$skinCount$061 = $skinCount$1;
      }
     }
     L19: do {
      if ((label|0) == 10) {
       $40 = ___cxa_find_matching_catch()|0;
       $41 = tempRet0;
       $187 = $17;$188 = $20;$lpad$phi$index = $40;$lpad$phi$index5 = $41;$skinCount$025 = $size$0$lcssa$i;$skinCount$032 = $size$0$lcssa$i;
       label = 12;
      }
      else if ((label|0) == 21) {
       $67 = ($skinCount$1|0)==(0);
       if ($67) {
        $175 = $20;$179 = $17;$skinCount$029 = $size$0$lcssa$i;
        break L7;
       }
       $68 = $size$0$lcssa$i & 2147483647;
       $69 = ($68>>>0)<($skinCount$1>>>0);
       do {
        if ($69) {
         $70 = ($size$0$lcssa$i|0)>(-1);
         if (!($70)) {
          $77 = $skinCount$1 << 2;
          HEAP32[$3>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$3+0>>2]|0;
          $78 = (invoke_iiiiiii(102,($77|0),4,($$byval_copy22|0),0,(585080|0),352)|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           $$ph$ph$ph$ph = $17;$$ph40$ph$ph$ph = $20;$skinCount$025$ph$ph$ph$ph = $size$0$lcssa$i;$skinCount$032$ph$ph$ph$ph = $size$0$lcssa$i;
           break;
          }
          _memcpy(($78|0),($17|0),($77|0))|0;
          $85 = ($skinCount$1*92)|0;
          HEAP32[$1>>2] = $18;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
          $86 = (invoke_iiiiiii(102,($85|0),4,($$byval_copy22|0),0,(585080|0),352)|0);
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           $$ph$ph$ph$ph = $78;$$ph40$ph$ph$ph = $20;$skinCount$025$ph$ph$ph$ph = $size$0$lcssa$i;$skinCount$032$ph$ph$ph$ph = $skinCount$1;
           break;
          }
          _memcpy(($86|0),($20|0),($85|0))|0;
          $100 = $78;$93 = $86;$skinCount$02836 = $skinCount$1;
          label = 31;
          break;
         }
         $71 = $skinCount$1 << 2;
         HEAP32[$2>>2] = $15;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$2+0>>2]|0;
         $72 = (invoke_iiiiiiii(108,($17|0),($71|0),4,($$byval_copy22|0),0,(585080|0),370)|0);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          $75 = ___cxa_find_matching_catch()|0;
          $76 = tempRet0;
          $189 = $76;$190 = $75;$191 = $17;$45 = $20;$skinCount$03234 = $skinCount$1;
          break L19;
         }
         $81 = ($skinCount$1*92)|0;
         HEAP32[$0>>2] = $18;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
         $82 = (invoke_iiiiiiii(108,($20|0),($81|0),4,($$byval_copy22|0),0,(585080|0),370)|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          $$ph$ph$ph$ph = $72;$$ph40$ph$ph$ph = $20;$skinCount$025$ph$ph$ph$ph = $skinCount$1;$skinCount$032$ph$ph$ph$ph = $skinCount$1;
         } else {
          $100 = $72;$93 = $82;$skinCount$02836 = $skinCount$1;
          label = 31;
         }
        } else {
         $100 = $17;$93 = $20;$skinCount$02836 = $size$0$lcssa$i;
         label = 31;
        }
       } while(0);
       L33: do {
        if ((label|0) == 31) {
         __THREW__ = 0;
         $89 = (invoke_i(59)|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          $$ph$ph$ph$ph = $100;$$ph40$ph$ph$ph = $93;$skinCount$025$ph$ph$ph$ph = $skinCount$02836;$skinCount$032$ph$ph$ph$ph = $skinCount$02836;
         } else {
          L36: do {
           if ($10) {
            $i1$046 = 0;
            while(1) {
             $92 = (($93) + (($i1$046*92)|0)|0);
             $94 = ((($93) + (($i1$046*92)|0)|0) + 72|0);
             __THREW__ = 0;
             invoke_viiii(350,($94|0),(3448|0),($92|0),0);
             $95 = __THREW__; __THREW__ = 0;
             $96 = $95&1;
             if ($96) {
              label = 8;
              break;
             }
             $97 = (($i1$046) + 1)|0;
             $98 = ($97>>>0)<($skinCount$1>>>0);
             if ($98) {
              $i1$046 = $97;
             } else {
              $i2$041 = 0;
              break;
             }
            }
            if ((label|0) == 8) {
             $36 = ___cxa_find_matching_catch()|0;
             $37 = tempRet0;
             $187 = $100;$188 = $93;$lpad$phi$index = $36;$lpad$phi$index5 = $37;$skinCount$025 = $skinCount$02836;$skinCount$032 = $skinCount$02836;
             label = 12;
             break L19;
            }
            while(1) {
             $99 = (($100) + ($i2$041<<2)|0);
             $101 = HEAP32[$99>>2]|0;
             $102 = ((($93) + (($i2$041*92)|0)|0) + 72|0);
             $103 = HEAP32[$102>>2]|0;
             $104 = ($103|0)==(0|0);
             if (!($104)) {
              __THREW__ = 0;
              invoke_vi(3402,($102|0));
              $105 = __THREW__; __THREW__ = 0;
              $106 = $105&1;
              if ($106) {
               break;
              }
             }
             $107 = ((($93) + (($i2$041*92)|0)|0) + 16|0);
             $108 = HEAP32[$107>>2]|0;
             $109 = ((($93) + (($i2$041*92)|0)|0) + 28|0);
             $110 = HEAP32[$109>>2]|0;
             $111 = ((($93) + (($i2$041*92)|0)|0) + 36|0);
             $112 = HEAP8[$111>>0]|0;
             $113 = ((($93) + (($i2$041*92)|0)|0) + 32|0);
             $114 = HEAP32[$113>>2]|0;
             $115 = ((($93) + (($i2$041*92)|0)|0) + 37|0);
             $116 = HEAP8[$115>>0]|0;
             __THREW__ = 0;
             $117 = (invoke_i(83)|0);
             $118 = __THREW__; __THREW__ = 0;
             $119 = $118&1;
             if ($119) {
              break;
             }
             $120 = ($116<<24>>24)!=(0);
             $121 = (($108) + ($114)|0);
             $122 = ($112<<24>>24)!=(0);
             $123 = (($108) + ($110)|0);
             $$1$i = $120 ? $121 : 0;
             $$$i = $122 ? $123 : 0;
             $124 = HEAP32[$117>>2]|0;
             $125 = (($124) + 40|0);
             $126 = HEAP32[$125>>2]|0;
             $127 = (($101) + 428|0);
             $128 = HEAP32[$127>>2]|0;
             $129 = HEAP32[$107>>2]|0;
             $130 = ((($93) + (($i2$041*92)|0)|0) + 24|0);
             $131 = HEAP32[$130>>2]|0;
             __THREW__ = 0;
             invoke_viiiiiii($126|0,($117|0),($128|0),($129|0),($$$i|0),($$1$i|0),($131|0),0);
             $132 = __THREW__; __THREW__ = 0;
             $133 = $132&1;
             if ($133) {
              break;
             }
             $134 = (($i2$041) + 1)|0;
             $135 = ($134>>>0)<($skinCount$1>>>0);
             if ($135) {
              $i2$041 = $134;
             } else {
              break L36;
             }
            }
            $34 = ___cxa_find_matching_catch()|0;
            $35 = tempRet0;
            $187 = $100;$188 = $93;$lpad$phi$index = $34;$lpad$phi$index5 = $35;$skinCount$025 = $skinCount$02836;$skinCount$032 = $skinCount$02836;
            label = 12;
            break L19;
           } else {
            $136 = HEAP32[$89>>2]|0;
            $137 = (($136) + 308|0);
            $138 = HEAP32[$137>>2]|0;
            __THREW__ = 0;
            invoke_vii($138|0,($89|0),($skinCount$1|0));
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             $$ph$ph$ph$ph = $100;$$ph40$ph$ph$ph = $93;$skinCount$025$ph$ph$ph$ph = $skinCount$02836;$skinCount$032$ph$ph$ph$ph = $skinCount$02836;
             break L33;
            } else {
             $i4$052 = 0;
            }
            while(1) {
             $141 = (($93) + (($i4$052*92)|0)|0);
             $142 = (($100) + ($i4$052<<2)|0);
             $143 = HEAP32[$142>>2]|0;
             $144 = ($141|0)==($lastGpuSkinning$1|0);
             __THREW__ = 0;
             (invoke_iiii(1541,($143|0),($141|0),($144|0))|0);
             $145 = __THREW__; __THREW__ = 0;
             $146 = $145&1;
             if ($146) {
              break;
             }
             $147 = (($i4$052) + 1)|0;
             $148 = ($147>>>0)<($skinCount$1>>>0);
             if ($148) {
              $i4$052 = $147;
             } else {
              break L36;
             }
            }
            $38 = ___cxa_find_matching_catch()|0;
            $39 = tempRet0;
            $187 = $100;$188 = $93;$lpad$phi$index = $38;$lpad$phi$index5 = $39;$skinCount$025 = $skinCount$02836;$skinCount$032 = $skinCount$02836;
            label = 12;
            break L19;
           }
          } while(0);
          $149 = ($outMeshes|0)==(0|0);
          if ($149) {
           $175 = $93;$179 = $100;$skinCount$029 = $skinCount$02836;
           break L7;
          }
          $$idx = $skinCount$1 << 2;
          $150 = $$idx >> 2;
          $151 = (($outMeshes) + 8|0);
          HEAP32[$151>>2] = $150;
          $152 = (($outMeshes) + 12|0);
          $153 = HEAP32[$152>>2]|0;
          $154 = $153 & 2147483647;
          $155 = ($154>>>0)<($150>>>0);
          do {
           if ($155) {
            $156 = ($153|0)>(-1);
            if ($156) {
             HEAP32[$152>>2] = $150;
             $157 = HEAP32[$outMeshes>>2]|0;
             $158 = (($outMeshes) + 4|0);
             $159 = HEAP32[$158>>2]|0;
             HEAP32[$5>>2] = $159;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$5+0>>2]|0;
             $160 = (invoke_iiiiiiii(108,($157|0),($$idx|0),4,($$byval_copy22|0),0,(585080|0),370)|0);
             $161 = __THREW__; __THREW__ = 0;
             $162 = $161&1;
             if ($162) {
              $$ph$ph$ph$ph = $100;$$ph40$ph$ph$ph = $93;$skinCount$025$ph$ph$ph$ph = $skinCount$02836;$skinCount$032$ph$ph$ph$ph = $skinCount$02836;
              break L33;
             }
             HEAP32[$outMeshes>>2] = $160;
             $173 = $160;
             break;
            } else {
             $163 = (($outMeshes) + 4|0);
             $164 = HEAP32[$163>>2]|0;
             HEAP32[$6>>2] = $164;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$6+0>>2]|0;
             $165 = (invoke_iiiiiii(102,($$idx|0),4,($$byval_copy22|0),0,(585080|0),352)|0);
             $166 = __THREW__; __THREW__ = 0;
             $167 = $166&1;
             if ($167) {
              $$ph$ph$ph$ph = $100;$$ph40$ph$ph$ph = $93;$skinCount$025$ph$ph$ph$ph = $skinCount$02836;$skinCount$032$ph$ph$ph$ph = $skinCount$02836;
              break L33;
             }
             $168 = HEAP32[$outMeshes>>2]|0;
             $169 = HEAP32[$151>>2]|0;
             $170 = $169 << 2;
             _memcpy(($165|0),($168|0),($170|0))|0;
             HEAP32[$152>>2] = $150;
             HEAP32[$outMeshes>>2] = $165;
             $173 = $165;
             break;
            }
           } else {
            $$pre$i = HEAP32[$outMeshes>>2]|0;
            $173 = $$pre$i;
           }
          } while(0);
          $171 = HEAP32[$151>>2]|0;
          $172 = $171 << 2;
          _memcpy(($173|0),($100|0),($172|0))|0;
          $175 = $93;$179 = $100;$skinCount$029 = $skinCount$02836;
          break L7;
         }
        }
       } while(0);
       $42 = ___cxa_find_matching_catch()|0;
       $43 = tempRet0;
       $187 = $$ph$ph$ph$ph;$188 = $$ph40$ph$ph$ph;$lpad$phi$index = $42;$lpad$phi$index5 = $43;$skinCount$025 = $skinCount$025$ph$ph$ph$ph;$skinCount$032 = $skinCount$032$ph$ph$ph$ph;
       label = 12;
      }
     } while(0);
     if ((label|0) == 12) {
      $44 = ($skinCount$025|0)>(-1);
      if ($44) {
       $189 = $lpad$phi$index5;$190 = $lpad$phi$index;$191 = $187;$45 = $188;$skinCount$03234 = $skinCount$032;
      } else {
       $$0 = $lpad$phi$index;$$01 = $lpad$phi$index5;$181 = $187;$skinCount$030 = $skinCount$032;
       break L5;
      }
     }
     HEAP32[$4>>2] = $18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($45|0),($$byval_copy22|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if (!($47)) {
      $$0 = $190;$$01 = $189;$181 = $191;$skinCount$030 = $skinCount$03234;
      break L5;
     }
     $184 = ___cxa_find_matching_catch(0|0)|0;
     $185 = tempRet0;
     ___clang_call_terminate($184);
     // unreachable;
    }
   } while(0);
   $174 = ($skinCount$029|0)>(-1);
   if ($174) {
    HEAP32[$7>>2] = $18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$7+0>>2]|0;
    invoke_vii(2591,($175|0),($$byval_copy22|0));
    $176 = __THREW__; __THREW__ = 0;
    $177 = $176&1;
    if ($177) {
     $186 = $179;$skinCount$031 = $skinCount$029;
     label = 6;
     break;
    }
   }
   $178 = ($skinCount$029|0)>(-1);
   if (!($178)) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = $15;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($179,$$byval_copy22);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 6) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  $$0 = $32;$$01 = $33;$181 = $186;$skinCount$030 = $skinCount$031;
 }
 $180 = ($skinCount$030|0)>(-1);
 if (!($180)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 HEAP32[$8>>2] = $15;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$8+0>>2]|0;
 invoke_vii(2591,($181|0),($$byval_copy22|0));
 $182 = __THREW__; __THREW__ = 0;
 $183 = $182&1;
 if ($183) {
  $184 = ___cxa_find_matching_catch(0|0)|0;
  $185 = tempRet0;
  ___clang_call_terminate($184);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN19SkinnedMeshRenderer12UploadClothsERK13dynamic_arrayIPS_Lj4EE($skinnedMeshes) {
 $skinnedMeshes = $skinnedMeshes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($skinnedMeshes) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $i$01 = 0;
 while(1) {
  $3 = HEAP32[$skinnedMeshes>>2]|0;
  $4 = (($3) + ($i$01<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 412|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = (__Z12GetGfxDevicev()|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 284|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($5) + 400|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (FUNCTION_TABLE_iiiii[$12 & 511]($9,$14,0,0)|0);
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = (($5) + 404|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$6>>2]|0;
    _memcpy(($15|0),($18|0),($19|0))|0;
    $20 = HEAP32[$9>>2]|0;
    $21 = (($20) + 288|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$13>>2]|0;
    $24 = HEAP32[$6>>2]|0;
    FUNCTION_TABLE_viii[$22 & 4095]($9,$23,$24);
   }
  }
  $25 = (($i$01) + 1)|0;
  $exitcond = ($25|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19SkinnedMeshRenderer19SetBlendShapeWeightEjf($this,$index,$weight) {
 $this = $this|0;
 $index = $index|0;
 $weight = Math_fround($weight);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 12|0;
 $1 = sp + 8|0;
 $2 = (($this) + 348|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)>($index>>>0);
 $5 = (($this) + 352|0);
 $6 = (($this) + 360|0);
 $7 = HEAP32[$6>>2]|0;
 if ($4) {
  $29 = ($7>>>0)>($index>>>0);
  if (!($29)) {
   HEAPF32[$1>>2] = Math_fround(0.0);
   __ZN13dynamic_arrayIfLj4EE18resize_initializedEjRKfb($5,$3,$1,0);
  }
  $30 = HEAP32[$5>>2]|0;
  $31 = (($30) + ($index<<2)|0);
  HEAPF32[$31>>2] = $weight;
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer>>2] = $index;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $7;
 __Z6FormatPKcz($0,585128,$vararg_buffer);
 $8 = HEAP8[$0>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $13 = (($0) + 1|0);
  $14 = $13;
 } else {
  $11 = (($0) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $14 = $12;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($14|0),0,(585080|0),1400,1,0,0,(0|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $24 = HEAP8[$0>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   ___resumeException($22|0);
   // unreachable;
  }
  $27 = (($0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __ZdlPv($28);
  ___resumeException($22|0);
  // unreachable;
 } else {
  $17 = HEAP8[$0>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $20 = (($0) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  __ZdlPv($21);
  STACKTOP = sp;return;
 }
}
function __ZN13dynamic_arrayIfLj4EE18resize_initializedEjRKfb($this,$size,$t,$double_on_resize) {
 $this = $this|0;
 $size = $size|0;
 $t = $t|0;
 $double_on_resize = $double_on_resize|0;
 var $$01$i = 0, $$byval_copy1 = 0, $$size = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $requested_size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)<($size>>>0);
 do {
  if ($4) {
   if ($double_on_resize) {
    $5 = $2 << 1;
    $6 = ($5>>>0)>($size>>>0);
    $$size = $6 ? $5 : $size;
    $requested_size$0 = $$size;
   } else {
    $requested_size$0 = $size;
   }
   $7 = ($3>>>0)<($requested_size$0>>>0);
   if ($7) {
    $8 = ($2|0)>(-1);
    if ($8) {
     HEAP32[$1>>2] = $requested_size$0;
     $9 = HEAP32[$this>>2]|0;
     $10 = $requested_size$0 << 2;
     $11 = (($this) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     HEAP32[$0>>2] = $12;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($9,$10,4,$$byval_copy1,0,585080,370)|0);
     HEAP32[$this>>2] = $13;
     break;
    } else {
     $14 = $requested_size$0 << 2;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,585080,352)|0);
     $18 = HEAP32[$this>>2]|0;
     $19 = (($this) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = $20 << 2;
     _memcpy(($17|0),($18|0),($21|0))|0;
     HEAP32[$1>>2] = $requested_size$0;
     HEAP32[$this>>2] = $17;
     break;
    }
   }
  }
 } while(0);
 $22 = (($this) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($size>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + ($size<<2)|0);
 $27 = ($23|0)==($size|0);
 if ($27) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $28 = (($25) + ($23<<2)|0);
 $$01$i = $28;
 while(1) {
  $29 = ($$01$i|0)==(0|0);
  if (!($29)) {
   $30 = Math_fround(HEAPF32[$t>>2]);
   HEAPF32[$$01$i>>2] = $30;
  }
  $31 = (($$01$i) + 4|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i = $31;
  }
 }
 HEAP32[$22>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN19SkinnedMeshRenderer24AnimatorModifiedCallbackEPvS0_i($userData,$sender,$eventID) {
 $userData = $userData|0;
 $sender = $sender|0;
 $eventID = $eventID|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($eventID|0)==(3);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (($userData) + 344|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 __ZN6Object11RemoveEventEPFvPvS0_iES0_($3,1695,$userData);
 $5 = (($userData) + 284|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __Z21CompleteFenceInternalR8JobFence($5);
 }
 $8 = (($userData) + 336|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(-1);
 if ($10) {
  $11 = (($userData) + 324|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($userData) + 328|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$0>>2] = $14;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($12,$$byval_copy);
  HEAP32[$11>>2] = 0;
 }
 $15 = (($userData) + 332|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$8>>2] = 0;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN8Renderer15UpdateLocalAABBEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK8Renderer16GetMaterialCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 228|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK8Renderer11GetMaterialEi($agg$result,$this,$i) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 220|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($i<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$agg$result>>2] = $3;
 STACKTOP = sp;return;
}
function __ZNK8Renderer14GetSubsetIndexEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $7 = $i;
  STACKTOP = sp;return ($7|0);
 }
 $3 = (($this) + 236|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($i<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZThn28_NK8Renderer16GetMaterialCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 $1 = (($0) + 228|0);
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZThn28_NK8Renderer11GetMaterialEi($agg$result,$this,$i) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 $1 = (($0) + 220|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($i<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$agg$result>>2] = $4;
 STACKTOP = sp;return;
}
function __ZThn28_NK8Renderer14GetSubsetIndexEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 $1 = (($0) + 244|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $8 = $i;
  STACKTOP = sp;return ($8|0);
 }
 $4 = (($0) + 236|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($i<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$byval_copy1 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0;
 var $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = $__last;
 $2 = $__first;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / 56)&-1;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$this>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 56)&-1;
 $12 = ($4>>>0)>($11>>>0);
 if (!($12)) {
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14;
  $16 = (($15) - ($9))|0;
  $17 = (($16|0) / 56)&-1;
  $18 = ($4>>>0)>($17>>>0);
  if (!($18)) {
   $27 = $__last;
   $28 = (($27) - ($2))|0;
   $29 = (($28|0) / 56)&-1;
   _memmove(($7|0),($__first|0),($28|0))|0;
   $30 = (($7) + (($29*56)|0)|0);
   $31 = HEAP32[$13>>2]|0;
   $32 = ($31|0)==($30|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $30;
   $scevgep$i$i = (($31) + -56|0);
   $33 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($33)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $34 = (($uglygep3$i$i>>>0) / 56)&-1;
   $35 = $34 ^ -1;
   $scevgep4$i$i = (($31) + (($35*56)|0)|0);
   HEAP32[$13>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $19 = (($__first) + (($17*56)|0)|0);
  _memmove(($7|0),($__first|0),($16|0))|0;
  $20 = ($19|0)==($__last|0);
  if ($20) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$13>>2]|0;
  $$01$i3 = $19;$22 = $$pre$i1;
  while(1) {
   $21 = ($22|0)==(0|0);
   if ($21) {
    $24 = 0;
   } else {
    dest=$22+0|0; src=$$01$i3+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre2$i4 = HEAP32[$13>>2]|0;
    $24 = $$pre2$i4;
   }
   $23 = (($24) + 56|0);
   HEAP32[$13>>2] = $23;
   $25 = (($$01$i3) + 56|0);
   $26 = ($25|0)==($__last|0);
   if ($26) {
    break;
   } else {
    $$01$i3 = $25;$22 = $23;
   }
  }
  STACKTOP = sp;return;
 }
 $36 = ($7|0)==(0|0);
 do {
  if ($36) {
   $49 = $6;
  } else {
   $37 = (($this) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==($7|0);
   if (!($39)) {
    $scevgep$i$i$i$i = (($38) + -56|0);
    $40 = (0 - ($9))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($40)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $41 = (($uglygep3$i$i$i$i>>>0) / 56)&-1;
    $42 = $41 ^ -1;
    $scevgep4$i$i$i$i = (($38) + (($42*56)|0)|0);
    HEAP32[$37>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($7|0),($$byval_copy1|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $45 = ___cxa_find_matching_catch()|0;
    $46 = tempRet0;
    ___cxa_call_unexpected(($45|0));
    // unreachable;
   } else {
    HEAP32[$5>>2] = 0;
    HEAP32[$37>>2] = 0;
    HEAP32[$this>>2] = 0;
    $49 = 0;
    break;
   }
  }
 } while(0);
 $47 = ($3|0)<(0);
 if ($47) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $48 = $49;
 $50 = (($48|0) / 56)&-1;
 $51 = ($50>>>0)<(1073741823);
 if ($51) {
  $52 = $50 << 1;
  $53 = ($52>>>0)<($4>>>0);
  $54 = $53 ? $4 : $52;
  $55 = ($54|0)<(0);
  if ($55) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $54;
  }
 } else {
  $$0$i7 = 2147483647;
 }
 $56 = ($$0$i7*56)|0;
 HEAP32[$0>>2] = 10;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $57 = (__Z15malloc_internaljj10MemLabelIdiPKci($56,16,$$byval_copy1,0,585080,79)|0);
 $58 = (($this) + 4|0);
 HEAP32[$58>>2] = $57;
 HEAP32[$this>>2] = $57;
 $59 = (($57) + (($$0$i7*56)|0)|0);
 HEAP32[$5>>2] = $59;
 $60 = ($__first|0)==($__last|0);
 if ($60) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$62 = $57;
 }
 while(1) {
  $61 = ($62|0)==(0|0);
  if ($61) {
   $64 = 0;
  } else {
   dest=$62+0|0; src=$$01$i+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre2$i = HEAP32[$58>>2]|0;
   $64 = $$pre2$i;
  }
  $63 = (($64) + 56|0);
  HEAP32[$58>>2] = $63;
  $65 = (($$01$i) + 56|0);
  $66 = ($65|0)==($__last|0);
  if ($66) {
   break;
  } else {
   $$01$i = $65;$62 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE6assignIPhEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$byval_copy1 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = $__last;
 $2 = $__first;
 $3 = (($1) - ($2))|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = ($3>>>0)>($9>>>0);
 if (!($10)) {
  $11 = (($this) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12;
  $14 = (($13) - ($8))|0;
  $15 = ($3>>>0)>($14>>>0);
  if (!($15)) {
   _memmove(($6|0),($__first|0),($3|0))|0;
   $25 = (($6) + ($3)|0);
   $26 = HEAP32[$11>>2]|0;
   $27 = ($26|0)==($25|0);
   if ($27) {
    STACKTOP = sp;return;
   }
   HEAP32[$11>>2] = $25;
   STACKTOP = sp;return;
  }
  $16 = (($__first) + ($14)|0);
  _memmove(($6|0),($__first|0),($14|0))|0;
  $17 = ($16|0)==($__last|0);
  if ($17) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$11>>2]|0;
  $$01$i3 = $16;$19 = $$pre$i1;
  while(1) {
   $18 = ($19|0)==(0|0);
   if ($18) {
    $22 = 0;
   } else {
    $20 = HEAP8[$$01$i3>>0]|0;
    HEAP8[$19>>0] = $20;
    $$pre2$i4 = HEAP32[$11>>2]|0;
    $22 = $$pre2$i4;
   }
   $21 = (($22) + 1|0);
   HEAP32[$11>>2] = $21;
   $23 = (($$01$i3) + 1|0);
   $24 = ($23|0)==($__last|0);
   if ($24) {
    break;
   } else {
    $$01$i3 = $23;$19 = $21;
   }
  }
  STACKTOP = sp;return;
 }
 $28 = ($6|0)==(0|0);
 do {
  if ($28) {
   $38 = $5;
  } else {
   $29 = (($this) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==($6|0);
   if (!($31)) {
    HEAP32[$29>>2] = $6;
   }
   HEAP32[$0>>2] = 8;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($6|0),($$byval_copy1|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $34 = ___cxa_find_matching_catch()|0;
    $35 = tempRet0;
    ___cxa_call_unexpected(($34|0));
    // unreachable;
   } else {
    HEAP32[$4>>2] = 0;
    HEAP32[$29>>2] = 0;
    HEAP32[$this>>2] = 0;
    $38 = 0;
    break;
   }
  }
 } while(0);
 $36 = ($3|0)<(0);
 if ($36) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $37 = ($38>>>0)<((1073741823)>>>0);
 if ($37) {
  $39 = $38;
  $40 = $39 << 1;
  $41 = ($40>>>0)<($3>>>0);
  $42 = $41 ? $3 : $40;
  $43 = ($42|0)<(0);
  if ($43) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $42;
  }
 } else {
  $$0$i7 = 2147483647;
 }
 HEAP32[$0>>2] = 8;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $44 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i7,16,$$byval_copy1,0,585080,79)|0);
 $45 = (($this) + 4|0);
 HEAP32[$45>>2] = $44;
 HEAP32[$this>>2] = $44;
 $46 = (($44) + ($$0$i7)|0);
 HEAP32[$4>>2] = $46;
 $47 = ($__first|0)==($__last|0);
 if ($47) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$49 = $44;
 }
 while(1) {
  $48 = ($49|0)==(0|0);
  if ($48) {
   $52 = 0;
  } else {
   $50 = HEAP8[$$01$i>>0]|0;
   HEAP8[$49>>0] = $50;
   $$pre2$i = HEAP32[$45>>2]|0;
   $52 = $$pre2$i;
  }
  $51 = (($52) + 1|0);
  HEAP32[$45>>2] = $51;
  $53 = (($$01$i) + 1|0);
  $54 = ($53|0)==($__last|0);
  if ($54) {
   break;
  } else {
   $$01$i = $53;$49 = $51;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4AABB8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i2 = 0, $$pre4$i$i$i = 0, $$pre4$i$i$i4 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i5 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre3$i$i$i = HEAP32[$3>>2]|0;
  $11 = $$pre3$i$i$i;$9 = $$pre$i$i$i;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre4$i$i$i = HEAP32[$0>>2]|0;
  $$pre5$i$i$i = HEAP32[$3>>2]|0;
  $15 = $$pre4$i$i$i;$17 = $$pre5$i$i$i;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i2 = HEAP32[$3>>2]|0;
  $27 = $$pre$i$i$i1;$29 = $$pre3$i$i$i2;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $$pre4$i$i$i4 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i5 = HEAP32[$3>>2]|0;
  $33 = $$pre4$i$i$i4;$35 = $$pre5$i$i$i5;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$33>>2] = $36;
  HEAP32[$0>>2] = $32;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,4);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI9TransformE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI4MeshE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI9TransformE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIfLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$07 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if (!($5)) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$2>>2]|0;
   $$pre8 = HEAP32[$8>>2]|0;
   $12 = $$pre$i$i$i1;$15 = $$pre;$17 = $$pre8;
  } else {
   $11 = HEAP32[$6>>2]|0;
   HEAP32[$size>>2] = $11;
   HEAP32[$2>>2] = $7;
   $12 = $11;$15 = $7;$17 = $9;
  }
  $13 = (_llvm_bswap_i32(($12|0))|0);
  HEAP32[$size>>2] = $13;
  $14 = (($15) + 4|0);
  $16 = ($14>>>0)>($17>>>0);
  if ($16) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $19 = $$pre$i$i$i2;$22 = $$pre9;
  } else {
   $18 = HEAP32[$15>>2]|0;
   HEAP32[$offset>>2] = $18;
   HEAP32[$2>>2] = $14;
   $19 = $18;$22 = $13;
  }
  $20 = (_llvm_bswap_i32(($19|0))|0);
  HEAP32[$offset>>2] = $20;
  $21 = $22 << 2;
  $23 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$20,$21)|0);
  $24 = (($data) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)>(-1);
  if ($26) {
   $27 = HEAP32[$data>>2]|0;
   $28 = (($data) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$1>>2] = $29;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy);
   HEAP32[$data>>2] = 0;
  }
  $30 = $21 >> 2;
  $31 = (($data) + 8|0);
  HEAP32[$31>>2] = $30;
  $32 = $30 | -2147483648;
  HEAP32[$24>>2] = $32;
  HEAP32[$data>>2] = $23;
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $34 = $$pre$i$i$i5;
 } else {
  $33 = HEAP32[$6>>2]|0;
  HEAP32[$size1>>2] = $33;
  HEAP32[$2>>2] = $7;
  $34 = $33;
 }
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$size1>>2] = $35;
 $36 = (($this) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$data>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $40 = (($data) + 4|0);
  HEAP32[$40>>2] = $37;
 }
 HEAPF32[$$byval_copy>>2] = Math_fround(0.0);
 __ZN13dynamic_arrayIfLj4EE18resize_initializedEjRKfb($data,$35,$$byval_copy,0);
 $41 = HEAP32[$data>>2]|0;
 $42 = (($data) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($41) + ($43<<2)|0);
 $45 = ($43|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 } else {
  $i$07 = $41;
 }
 while(1) {
  $46 = HEAP32[$2>>2]|0;
  $47 = (($46) + 4|0);
  $48 = HEAP32[$8>>2]|0;
  $49 = ($47>>>0)>($48>>>0);
  if ($49) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$i$07,4);
   $$pre$i$i$i = HEAP32[$i$07>>2]|0;
   $$pre$phi$i$i$iZ2D = $i$07;$52 = $$pre$i$i$i;
  } else {
   $50 = Math_fround(HEAPF32[$46>>2]);
   HEAPF32[$i$07>>2] = $50;
   HEAP32[$2>>2] = $47;
   $51 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$iZ2D = $i$07;$52 = $51;
  }
  $53 = (_llvm_bswap_i32(($52|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $53;
  $54 = (($i$07) + 4|0);
  $55 = ($54|0)==($44|0);
  if ($55) {
   break;
  } else {
   $i$07 = $54;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4PPtrI4MeshE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4AABB8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i2 = 0, $$pre4$i$i$i = 0, $$pre4$i$i$i4 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i5 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre3$i$i$i = HEAP32[$3>>2]|0;
  $11 = $$pre3$i$i$i;$9 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre4$i$i$i = HEAP32[$0>>2]|0;
  $$pre5$i$i$i = HEAP32[$3>>2]|0;
  $15 = $$pre4$i$i$i;$17 = $$pre5$i$i$i;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre;$23 = $$pre8;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i2 = HEAP32[$3>>2]|0;
  $27 = $$pre$i$i$i1;$29 = $$pre3$i$i$i2;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre4$i$i$i4 = HEAP32[$0>>2]|0;
  $$pre5$i$i$i5 = HEAP32[$3>>2]|0;
  $33 = $$pre4$i$i$i4;$35 = $$pre5$i$i$i5;
 } else {
  $30 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$31,4);
  STACKTOP = sp;return;
 } else {
  $36 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$31>>2] = $36;
  HEAP32[$0>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI9TransformE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIfLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($5) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $36 = $$pre;
  } else {
   $30 = HEAP32[$6>>2]|0;
   HEAP32[$size1>>2] = $30;
   HEAP32[$2>>2] = $7;
   $36 = $30;
  }
  $31 = (($this) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$data>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $35 = (($data) + 4|0);
   HEAP32[$35>>2] = $32;
  }
  HEAPF32[$$byval_copy>>2] = Math_fround(0.0);
  __ZN13dynamic_arrayIfLj4EE18resize_initializedEjRKfb($data,$36,$$byval_copy,0);
  $37 = HEAP32[$size1>>2]|0;
  $38 = ($37|0)==(0);
  if ($38) {
   STACKTOP = sp;return;
  }
  $39 = HEAP32[$data>>2]|0;
  $40 = $37 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$39,$40);
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre4 = HEAP32[$2>>2]|0;
  $$pre5 = HEAP32[$8>>2]|0;
  $13 = $$pre4;$15 = $$pre5;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$size>>2] = $11;
  HEAP32[$2>>2] = $7;
  $13 = $7;$15 = $9;
 }
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
  $$pre6 = HEAP32[$offset>>2]|0;
  $19 = $$pre6;
 } else {
  $16 = HEAP32[$13>>2]|0;
  HEAP32[$offset>>2] = $16;
  HEAP32[$2>>2] = $12;
  $19 = $16;
 }
 $17 = HEAP32[$size>>2]|0;
 $18 = $17 << 2;
 $20 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$19,$18)|0);
 $21 = (($data) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(-1);
 if ($23) {
  $24 = HEAP32[$data>>2]|0;
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  HEAP32[$1>>2] = $26;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($24,$$byval_copy);
  HEAP32[$data>>2] = 0;
 }
 $27 = $18 >> 2;
 $28 = (($data) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = $27 | -2147483648;
 HEAP32[$21>>2] = $29;
 HEAP32[$data>>2] = $20;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI4MeshE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4AABB8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580776>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,585208,$0,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$this,585240,0);
   $4 = (($this) + 4|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$4,585248,0);
   $5 = (($this) + 8|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,585256,0);
  } else {
   $6 = HEAP32[$converter$i$i1>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    (FUNCTION_TABLE_iii[$6 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $8 = (($this) + 12|0);
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,585224,$0,$converter$i$i1,1)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 if ($11) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$8,585240,0);
  $12 = (($this) + 16|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,585248,0);
  $13 = (($this) + 20|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,585256,0);
 } else {
  $14 = HEAP32[$converter$i$i1>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   (FUNCTION_TABLE_iii[$14 & 4095]($8,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN4PPtrI9TransformE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,585264,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,585280,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,585264,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,585280,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIfLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $i$03 = 0, $i$15 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $1 = sp + 12|0;
 $size = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,585304,585304,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$data>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (($data) + 4|0);
  HEAP32[$11>>2] = $8;
 }
 HEAPF32[$1>>2] = Math_fround(0.0);
 __ZN13dynamic_arrayIfLj4EE18resize_initializedEjRKfb($data,$6,$1,0);
 $12 = HEAP32[$data>>2]|0;
 $13 = HEAP32[$3>>2]|0;
 $14 = (($12) + ($13<<2)|0);
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)==(0);
 L7: do {
  if (!($16)) {
   $17 = HEAP32[580584>>2]|0;
   $18 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,585296,$17,0,0)|0);
   $19 = (($this) + 80|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (__ZNK16TypeTreeIterator7GetNodeEv($20)|0);
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($this) + 84|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$25>>2] = 0;
   $26 = ($18|0)==(2);
   if (!($26)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $77 = HEAP32[$data>>2]|0;
    $78 = ($77|0)==($14|0);
    if ($78) {
     break;
    } else {
     $i$15 = $77;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$15,585296,0);
     $79 = (($i$15) + 4|0);
     $80 = ($79|0)==($14|0);
     if ($80) {
      break L7;
     } else {
      $i$15 = $79;
     }
    }
   }
   $27 = HEAP32[$19>>2]|0;
   $28 = (($27) + 12|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$data>>2]|0;
   $31 = ($30|0)==($14|0);
   L14: do {
    if (!($31)) {
     $32 = (($this) + 12|0);
     $33 = (($this) + 16|0);
     $34 = (($this) + 28|0);
     $35 = (($this) + 32|0);
     $36 = (($this) + 20|0);
     $38 = 0;$41 = $27;$i$03 = $30;
     while(1) {
      $37 = Math_imul($38, $23)|0;
      $39 = (($37) + ($29))|0;
      $40 = (($41) + 20|0);
      HEAP32[$40>>2] = $39;
      $42 = (($41) + 12|0);
      HEAP32[$42>>2] = $39;
      $43 = (($41) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($2,$41);
      $44 = $2;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = (($44) + 4)|0;
      $48 = $47;
      $49 = HEAP32[$48>>2]|0;
      $50 = $43;
      $51 = $50;
      HEAP32[$51>>2] = $46;
      $52 = (($50) + 4)|0;
      $53 = $52;
      HEAP32[$53>>2] = $49;
      $54 = HEAP32[$24>>2]|0;
      $55 = HEAP32[$54>>2]|0;
      $56 = (($55) + 1)|0;
      HEAP32[$54>>2] = $56;
      $57 = HEAP32[$19>>2]|0;
      $58 = (($57) + 12|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = HEAP32[$33>>2]|0;
      $61 = HEAP32[$34>>2]|0;
      $62 = HEAP32[$35>>2]|0;
      $63 = Math_imul($62, $61)|0;
      $$sum$i$i$i = (($59) - ($63))|0;
      $64 = (($60) + ($$sum$i$i$i)|0);
      HEAP32[$32>>2] = $64;
      $65 = ($$sum$i$i$i|0)<(0);
      if ($65) {
       label = 11;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $66 = (($60) + ($$sum1$i$i$i)|0);
       $67 = HEAP32[$36>>2]|0;
       $68 = ($66>>>0)>($67>>>0);
       if ($68) {
        label = 11;
       } else {
        $69 = Math_fround(HEAPF32[$64>>2]);
        HEAPF32[$i$03>>2] = $69;
        HEAP32[$32>>2] = $66;
       }
      }
      if ((label|0) == 11) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($32,$i$03,4);
      }
      $70 = HEAP32[$this>>2]|0;
      $71 = $70 & 512;
      $72 = ($71|0)==(0);
      if (!($72)) {
       $73 = HEAP32[$i$03>>2]|0;
       $74 = (_llvm_bswap_i32(($73|0))|0);
       HEAP32[$i$03>>2] = $74;
      }
      $75 = (($i$03) + 4|0);
      $76 = ($75|0)==($14|0);
      if ($76) {
       break L14;
      }
      $$pre = HEAP32[$24>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$19>>2]|0;
      $38 = $$pre8;$41 = $$pre9;$i$03 = $75;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI4MeshE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,585264,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,585280,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,585264,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,585280,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN8RendererD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8RendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN8RendererD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3449,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZThn28_N8RendererD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 __ZN8RendererD2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn28_N8RendererD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 __THREW__ = 0;
 invoke_vi(3449,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
}
function __ZN17PackedFloatVector10PackFloatsEPKfiiiib($this,$data,$itemCountInChunk,$chunkStride,$numChunks,$bitSize,$adjustBitSize) {
 $this = $this|0;
 $data = $data|0;
 $itemCountInChunk = $itemCountInChunk|0;
 $chunkStride = $chunkStride|0;
 $numChunks = $numChunks|0;
 $bitSize = $bitSize|0;
 $adjustBitSize = $adjustBitSize|0;
 var $$$0 = 0, $$$us = 0, $$0 = 0, $$2 = 0, $$indexPos$2$us = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $bitPos$013$us = 0, $bitPos$16$us = 0, $bitPos$2$lcssa$us = 0, $bitPos$22$us = 0, $bits$03$us = 0;
 var $exitcond = 0, $exitcond29 = 0, $i$016$us = 0, $i2$07$us = 0, $indexPos$012$us = 0, $indexPos$15$us = 0, $indexPos$2$lcssa$us = 0, $indexPos$21$us = 0, $it$023 = 0, $it$023$us = 0, $it1$014 = 0, $it1$014$us = 0, $maxf$0$lcssa = Math_fround(0), $maxf$025$us = Math_fround(0), $maxf$118$us = Math_fround(0), $maxf$2$us = Math_fround(0), $minf$0$lcssa = Math_fround(0), $minf$024$us = Math_fround(0), $minf$117$us = Math_fround(0), $minf$2$us = Math_fround(0);
 var $or$cond = 0, $scaled$0$us = Math_fround(0), $scaled$1$us = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = Math_imul($numChunks, $chunkStride)|0;
 $2 = (($data) + ($1)|0);
 $3 = ($2|0)==($data|0);
 L1: do {
  if ($3) {
   $maxf$0$lcssa = Math_fround(-inf);$minf$0$lcssa = Math_fround(inf);
  } else {
   $4 = ($itemCountInChunk|0)>(0);
   if ($4) {
    $it$023$us = $data;$maxf$025$us = Math_fround(-inf);$minf$024$us = Math_fround(inf);
   } else {
    $it$023 = $data;
    while(1) {
     $12 = (($it$023) + ($chunkStride)|0);
     $13 = ($12|0)==($2|0);
     if ($13) {
      $maxf$0$lcssa = Math_fround(-inf);$minf$0$lcssa = Math_fround(inf);
      break L1;
     } else {
      $it$023 = $12;
     }
    }
   }
   while(1) {
    $i$016$us = 0;$maxf$118$us = $maxf$025$us;$minf$117$us = $minf$024$us;
    while(1) {
     $7 = (($it$023$us) + ($i$016$us<<2)|0);
     $8 = Math_fround(HEAPF32[$7>>2]);
     $9 = $maxf$118$us < $8;
     $maxf$2$us = $9 ? $8 : $maxf$118$us;
     $10 = $minf$117$us > $8;
     $minf$2$us = $10 ? $8 : $minf$117$us;
     $11 = (($i$016$us) + 1)|0;
     $exitcond29 = ($11|0)==($itemCountInChunk|0);
     if ($exitcond29) {
      break;
     } else {
      $i$016$us = $11;$maxf$118$us = $maxf$2$us;$minf$117$us = $minf$2$us;
     }
    }
    $5 = (($it$023$us) + ($chunkStride)|0);
    $6 = ($5|0)==($2|0);
    if ($6) {
     $maxf$0$lcssa = $maxf$2$us;$minf$0$lcssa = $minf$2$us;
     break;
    } else {
     $it$023$us = $5;$maxf$025$us = $maxf$2$us;$minf$024$us = $minf$2$us;
    }
   }
  }
 } while(0);
 $14 = Math_fround($maxf$0$lcssa - $minf$0$lcssa);
 $15 = (($this) + 4|0);
 HEAPF32[$15>>2] = $14;
 $16 = $14 > Math_fround(0.0);
 $or$cond = $16 & $adjustBitSize;
 if ($or$cond) {
  $17 = (Math_fround(+(_log2f((+$14)))));
  $18 = (Math_fround(Math_ceil((Math_fround($17)))));
  $19 = (~~(($18)));
  $20 = (($19) + ($bitSize))|0;
  $$0 = $20;
 } else {
  $$0 = $bitSize;
 }
 $21 = ($$0|0)>(32);
 $$$0 = $21 ? 32 : $$0;
 $22 = $minf$0$lcssa == $maxf$0$lcssa;
 $$2 = $22 ? 0 : $$$0;
 $23 = (($this) + 8|0);
 HEAPF32[$23>>2] = $minf$0$lcssa;
 $24 = Math_imul($numChunks, $itemCountInChunk)|0;
 HEAP32[$this>>2] = $24;
 $25 = $$2&255;
 $26 = (($this) + 12|0);
 HEAP8[$26>>0] = $25;
 $27 = (($this) + 16|0);
 $28 = Math_imul($$2, $24)|0;
 $29 = (($28) + 7)|0;
 $30 = $29 >>> 3;
 HEAP8[$0>>0] = 0;
 $31 = (($this) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$27>>2]|0;
 $34 = $32;
 $35 = $33;
 $36 = (($34) - ($35))|0;
 $37 = ($36>>>0)<($30>>>0);
 if ($37) {
  $38 = (($30) - ($36))|0;
  __ZNSt3__16vectorIhNS_9allocatorIhEEE8__appendEjRKh($27,$38,$0);
 } else {
  $39 = ($36>>>0)>($30>>>0);
  if ($39) {
   $40 = (($33) + ($30)|0);
   $41 = ($32|0)==($40|0);
   if (!($41)) {
    HEAP32[$31>>2] = $40;
   }
  }
 }
 $42 = ($$2|0)==(0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = Math_fround(HEAPF32[$15>>2]);
 $44 = $43 > Math_fround(0.0);
 if ($44) {
  $45 = Math_fround(Math_fround(1.0) / $43);
  $54 = $45;
 } else {
  $54 = Math_fround(0.0);
 }
 if ($3) {
  STACKTOP = sp;return;
 }
 $46 = ($itemCountInChunk|0)>(0);
 if ($46) {
  $bitPos$013$us = 0;$indexPos$012$us = 0;$it1$014$us = $data;
 } else {
  $it1$014 = $data;
  while(1) {
   $86 = (($it1$014) + ($chunkStride)|0);
   $87 = ($86|0)==($2|0);
   if ($87) {
    break;
   } else {
    $it1$014 = $86;
   }
  }
  STACKTOP = sp;return;
 }
 while(1) {
  $$pre = HEAP8[$26>>0]|0;
  $58 = $$pre;$bitPos$16$us = $bitPos$013$us;$i2$07$us = 0;$indexPos$15$us = $indexPos$012$us;
  while(1) {
   $49 = (($it1$014$us) + ($i2$07$us<<2)|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = Math_fround(HEAPF32[$23>>2]);
   $52 = Math_fround($50 - $51);
   $53 = Math_fround($54 * $52);
   $55 = $53 < Math_fround(0.0);
   $scaled$0$us = $55 ? Math_fround(0.0) : $53;
   $56 = $scaled$0$us > Math_fround(1.0);
   $scaled$1$us = $56 ? Math_fround(1.0) : $scaled$0$us;
   $57 = $58&255;
   $59 = 1 << $57;
   $60 = (($59) + -1)|0;
   $61 = (Math_fround(($60|0)));
   $62 = Math_fround($61 * $scaled$1$us);
   $63 = Math_fround($62 + Math_fround(0.5));
   $64 = (~~(($63))>>>0);
   $65 = ($58<<24>>24)==(0);
   if ($65) {
    $88 = 0;$bitPos$2$lcssa$us = $bitPos$16$us;$indexPos$2$lcssa$us = $indexPos$15$us;
   } else {
    $bitPos$22$us = $bitPos$16$us;$bits$03$us = 0;$indexPos$21$us = $indexPos$15$us;
    while(1) {
     $67 = $64 >>> $bits$03$us;
     $68 = $67 << $bitPos$22$us;
     $69 = HEAP32[$27>>2]|0;
     $70 = (($69) + ($indexPos$21$us)|0);
     $71 = HEAP8[$70>>0]|0;
     $72 = $71&255;
     $73 = $72 | $68;
     $74 = $73&255;
     HEAP8[$70>>0] = $74;
     $75 = HEAP8[$26>>0]|0;
     $76 = $75&255;
     $77 = (($76) - ($bits$03$us))|0;
     $78 = (8 - ($bitPos$22$us))|0;
     $79 = ($78|0)<($77|0);
     $80 = $79 ? $78 : $77;
     $81 = (($80) + ($bitPos$22$us))|0;
     $82 = (($80) + ($bits$03$us))|0;
     $83 = ($81|0)==(8);
     $84 = $83&1;
     $$indexPos$2$us = (($84) + ($indexPos$21$us))|0;
     $$$us = $83 ? 0 : $81;
     $85 = ($82|0)<($76|0);
     if ($85) {
      $bitPos$22$us = $$$us;$bits$03$us = $82;$indexPos$21$us = $$indexPos$2$us;
     } else {
      $88 = $75;$bitPos$2$lcssa$us = $$$us;$indexPos$2$lcssa$us = $$indexPos$2$us;
      break;
     }
    }
   }
   $66 = (($i2$07$us) + 1)|0;
   $exitcond = ($66|0)==($itemCountInChunk|0);
   if ($exitcond) {
    break;
   } else {
    $58 = $88;$bitPos$16$us = $bitPos$2$lcssa$us;$i2$07$us = $66;$indexPos$15$us = $indexPos$2$lcssa$us;
   }
  }
  $47 = (($it1$014$us) + ($chunkStride)|0);
  $48 = ($47|0)==($2|0);
  if ($48) {
   break;
  } else {
   $bitPos$013$us = $bitPos$2$lcssa$us;$indexPos$012$us = $indexPos$2$lcssa$us;$it1$014$us = $47;
  }
 }
 STACKTOP = sp;return;
}
function __ZN17PackedFloatVector12UnpackFloatsEPfiiii($this,$data,$itemCountInChunk,$chunkStride,$start,$numChunks) {
 $this = $this|0;
 $data = $data|0;
 $itemCountInChunk = $itemCountInChunk|0;
 $chunkStride = $chunkStride|0;
 $start = $start|0;
 $numChunks = $numChunks|0;
 var $$ = 0, $$01 = 0, $$018 = 0, $$indexPos$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0.0, $46 = 0.0, $47 = Math_fround(0), $48 = 0.0, $49 = 0.0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0.0, $9 = 0, $bitPos$016 = 0;
 var $bitPos$1$lcssa = 0, $bitPos$110 = 0, $bitPos$2$lcssa = 0, $bitPos$22 = 0, $bits$05 = 0, $exitcond = 0, $i$012 = 0, $indexPos$017 = 0, $indexPos$1$lcssa = 0, $indexPos$111 = 0, $indexPos$2$lcssa = 0, $indexPos$23 = 0, $scale$0 = 0.0, $x$0$lcssa = 0, $x$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = Math_imul($2, $start)|0;
 $4 = (($3|0) / 8)&-1;
 $5 = (($3|0) % 8)&-1;
 $6 = (($this) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = +$7;
 $9 = ($1<<24>>24)==(0);
 if ($9) {
  $scale$0 = $8;
 } else {
  $10 = 1 << $2;
  $11 = (($10) + -1)|0;
  $12 = (+($11|0));
  $13 = $8 / $12;
  $scale$0 = $13;
 }
 $14 = ($numChunks|0)==(-1);
 if ($14) {
  $15 = HEAP32[$this>>2]|0;
  $16 = (($15>>>0) / ($itemCountInChunk>>>0))&-1;
  $$01 = $16;
 } else {
  $$01 = $numChunks;
 }
 $17 = Math_imul($$01, $chunkStride)|0;
 $18 = (($data) + ($17)|0);
 $19 = ($18|0)==($data|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = ($itemCountInChunk|0)>(0);
 $21 = (($this) + 8|0);
 $22 = (($this) + 16|0);
 $$018 = $data;$bitPos$016 = $5;$indexPos$017 = $4;
 while(1) {
  if ($20) {
   $bitPos$110 = $bitPos$016;$i$012 = 0;$indexPos$111 = $indexPos$017;
   while(1) {
    $23 = HEAP8[$0>>0]|0;
    $24 = $23&255;
    $25 = ($23<<24>>24)==(0);
    if ($25) {
     $bitPos$2$lcssa = $bitPos$110;$indexPos$2$lcssa = $indexPos$111;$x$0$lcssa = 0;
    } else {
     $26 = HEAP32[$22>>2]|0;
     $bitPos$22 = $bitPos$110;$bits$05 = 0;$indexPos$23 = $indexPos$111;$x$04 = 0;
     while(1) {
      $27 = (($26) + ($indexPos$23)|0);
      $28 = HEAP8[$27>>0]|0;
      $29 = $28&255;
      $30 = $29 >>> $bitPos$22;
      $31 = $30 << $bits$05;
      $32 = $31 | $x$04;
      $33 = (($24) - ($bits$05))|0;
      $34 = (8 - ($bitPos$22))|0;
      $35 = ($34|0)<($33|0);
      $36 = $35 ? $34 : $33;
      $37 = (($36) + ($bitPos$22))|0;
      $38 = (($36) + ($bits$05))|0;
      $39 = ($37|0)==(8);
      $$ = $39 ? 0 : $37;
      $40 = $39&1;
      $$indexPos$2 = (($40) + ($indexPos$23))|0;
      $41 = ($38|0)<($24|0);
      if ($41) {
       $bitPos$22 = $$;$bits$05 = $38;$indexPos$23 = $$indexPos$2;$x$04 = $32;
      } else {
       $bitPos$2$lcssa = $$;$indexPos$2$lcssa = $$indexPos$2;$x$0$lcssa = $32;
       break;
      }
     }
    }
    $42 = 1 << $24;
    $43 = (($42) + -1)|0;
    $44 = $43 & $x$0$lcssa;
    $45 = (+($44>>>0));
    $46 = $scale$0 * $45;
    $47 = Math_fround(HEAPF32[$21>>2]);
    $48 = +$47;
    $49 = $46 + $48;
    $50 = Math_fround($49);
    $51 = (($$018) + ($i$012<<2)|0);
    HEAPF32[$51>>2] = $50;
    $52 = (($i$012) + 1)|0;
    $exitcond = ($52|0)==($itemCountInChunk|0);
    if ($exitcond) {
     $bitPos$1$lcssa = $bitPos$2$lcssa;$indexPos$1$lcssa = $indexPos$2$lcssa;
     break;
    } else {
     $bitPos$110 = $bitPos$2$lcssa;$i$012 = $52;$indexPos$111 = $indexPos$2$lcssa;
    }
   }
  } else {
   $bitPos$1$lcssa = $bitPos$016;$indexPos$1$lcssa = $indexPos$017;
  }
  $53 = (($$018) + ($chunkStride)|0);
  $54 = ($53|0)==($18|0);
  if ($54) {
   break;
  } else {
   $$018 = $53;$bitPos$016 = $bitPos$1$lcssa;$indexPos$017 = $indexPos$1$lcssa;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16PackedQuatVector9PackQuatsEP11Quaternionfi($this,$data,$numItems) {
 $this = $this|0;
 $data = $data|0;
 $numItems = $numItems|0;
 var $$ = 0, $$1 = 0, $$indexPos$1 = 0, $$indexPos$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $bitPos$013 = 0, $bitPos$13 = 0, $bitPos$210 = 0, $bitPos$37 = 0, $bitPos$4 = 0, $bits$02 = 0, $bits$16 = 0;
 var $exitcond = 0, $exitcond15 = 0, $flags$0 = 0, $flags$1 = 0, $flags$2 = 0, $i$012 = 0, $indexPos$014 = 0, $indexPos$14 = 0, $indexPos$211 = 0, $indexPos$38 = 0, $indexPos$4 = 0, $j$09 = 0, $max$0 = Math_fround(0), $max$1 = Math_fround(0), $scaled$0 = Math_fround(0), $scaled$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = $numItems;
 $1 = (($this) + 4|0);
 $2 = $numItems << 2;
 HEAP8[$0>>0] = 0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$1>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = ($8>>>0)<($2>>>0);
 if ($9) {
  $10 = (($2) - ($8))|0;
  __ZNSt3__16vectorIhNS_9allocatorIhEEE8__appendEjRKh($1,$10,$0);
 } else {
  $11 = ($8>>>0)>($2>>>0);
  if ($11) {
   $12 = (($5) + ($2)|0);
   $13 = ($4|0)==($12|0);
   if (!($13)) {
    HEAP32[$3>>2] = $12;
   }
  }
 }
 $14 = ($numItems|0)>(0);
 if ($14) {
  $bitPos$013 = 0;$i$012 = 0;$indexPos$014 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $15 = (($data) + ($i$012<<4)|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = $16 < Math_fround(0.0);
  $18 = $17 ? 4 : 0;
  $19 = (Math_fround(Math_abs((Math_fround($16)))));
  $20 = ((($data) + ($i$012<<4)|0) + 4|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (Math_fround(Math_abs((Math_fround($21)))));
  $23 = $22 > $19;
  if ($23) {
   $24 = $21 < Math_fround(0.0);
   if ($24) {
    $flags$0 = 5;$max$0 = $22;
   } else {
    $flags$0 = 1;$max$0 = $22;
   }
  } else {
   $flags$0 = $18;$max$0 = $19;
  }
  $25 = ((($data) + ($i$012<<4)|0) + 8|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (Math_fround(Math_abs((Math_fround($26)))));
  $28 = $27 > $max$0;
  if ($28) {
   $29 = $26 < Math_fround(0.0);
   if ($29) {
    $flags$1 = 6;$max$1 = $27;
   } else {
    $flags$1 = 2;$max$1 = $27;
   }
  } else {
   $flags$1 = $flags$0;$max$1 = $max$0;
  }
  $30 = ((($data) + ($i$012<<4)|0) + 12|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (Math_fround(Math_abs((Math_fround($31)))));
  $33 = $32 > $max$1;
  if ($33) {
   $34 = $31 < Math_fround(0.0);
   if ($34) {
    $flags$2 = 7;
   } else {
    $flags$2 = 3;
   }
  } else {
   $flags$2 = $flags$1;
  }
  $35 = $flags$2 & 255;
  $bitPos$13 = $bitPos$013;$bits$02 = 0;$indexPos$14 = $indexPos$014;
  while(1) {
   $36 = $35 >>> $bits$02;
   $37 = $36 << $bitPos$13;
   $38 = HEAP32[$1>>2]|0;
   $39 = (($38) + ($indexPos$14)|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40&255;
   $42 = $41 | $37;
   $43 = $42&255;
   HEAP8[$39>>0] = $43;
   $44 = (3 - ($bits$02))|0;
   $45 = (8 - ($bitPos$13))|0;
   $46 = ($45|0)<($44|0);
   $47 = $46 ? $45 : $44;
   $48 = (($47) + ($bitPos$13))|0;
   $49 = (($47) + ($bits$02))|0;
   $50 = ($48|0)==(8);
   $$ = $50 ? 0 : $48;
   $51 = $50&1;
   $$indexPos$1 = (($51) + ($indexPos$14))|0;
   $52 = ($49|0)<(3);
   if ($52) {
    $bitPos$13 = $$;$bits$02 = $49;$indexPos$14 = $$indexPos$1;
   } else {
    break;
   }
  }
  $53 = $flags$2 & 3;
  $54 = (($flags$2) + 1)|0;
  $55 = $54 & 3;
  $bitPos$210 = $$;$indexPos$211 = $$indexPos$1;$j$09 = 0;
  while(1) {
   $56 = ($53|0)==($j$09|0);
   if ($56) {
    $bitPos$4 = $bitPos$210;$indexPos$4 = $indexPos$211;
   } else {
    $57 = ($55|0)==($j$09|0);
    $58 = $57 ? 9 : 10;
    $59 = (($15) + ($j$09<<2)|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = Math_fround($60 + Math_fround(1.0));
    $62 = Math_fround($61 * Math_fround(0.5));
    $63 = $62 < Math_fround(0.0);
    $scaled$0 = $63 ? Math_fround(0.0) : $62;
    $64 = $scaled$0 > Math_fround(1.0);
    $scaled$1 = $64 ? Math_fround(1.0) : $scaled$0;
    $65 = 1 << $58;
    $66 = (($65) + -1)|0;
    $67 = (Math_fround(($66|0)));
    $68 = Math_fround($67 * $scaled$1);
    $69 = (~~(($68))>>>0);
    $bitPos$37 = $bitPos$210;$bits$16 = 0;$indexPos$38 = $indexPos$211;
    while(1) {
     $70 = $69 >>> $bits$16;
     $71 = $70 << $bitPos$37;
     $72 = HEAP32[$1>>2]|0;
     $73 = (($72) + ($indexPos$38)|0);
     $74 = HEAP8[$73>>0]|0;
     $75 = $74&255;
     $76 = $75 | $71;
     $77 = $76&255;
     HEAP8[$73>>0] = $77;
     $78 = (($58) - ($bits$16))|0;
     $79 = (8 - ($bitPos$37))|0;
     $80 = ($79|0)<($78|0);
     $81 = $80 ? $79 : $78;
     $82 = (($81) + ($bitPos$37))|0;
     $83 = (($81) + ($bits$16))|0;
     $84 = ($82|0)==(8);
     $$1 = $84 ? 0 : $82;
     $85 = $84&1;
     $$indexPos$3 = (($85) + ($indexPos$38))|0;
     $86 = ($83|0)<($58|0);
     if ($86) {
      $bitPos$37 = $$1;$bits$16 = $83;$indexPos$38 = $$indexPos$3;
     } else {
      $bitPos$4 = $$1;$indexPos$4 = $$indexPos$3;
      break;
     }
    }
   }
   $87 = (($j$09) + 1)|0;
   $exitcond = ($87|0)==(4);
   if ($exitcond) {
    break;
   } else {
    $bitPos$210 = $bitPos$4;$indexPos$211 = $indexPos$4;$j$09 = $87;
   }
  }
  $88 = (($i$012) + 1)|0;
  $exitcond15 = ($88|0)==($numItems|0);
  if ($exitcond15) {
   break;
  } else {
   $bitPos$013 = $bitPos$4;$i$012 = $88;$indexPos$014 = $indexPos$4;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16PackedQuatVector11UnpackQuatsEP11Quaternionf($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$ = 0, $$1 = 0, $$indexPos$1 = 0, $$indexPos$3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0);
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $bitPos$016 = 0, $bitPos$14 = 0, $bitPos$213 = 0, $bitPos$38 = 0, $bitPos$4 = 0, $bits$02 = 0, $bits$16 = 0, $exitcond = 0, $flags$03 = 0, $i$015 = 0, $indexPos$017 = 0, $indexPos$15 = 0, $indexPos$214 = 0, $indexPos$39 = 0;
 var $indexPos$4 = 0, $j$011 = 0, $storemerge = Math_fround(0), $sum$010 = Math_fround(0), $sum$1 = Math_fround(0), $x$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)>(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 $$pre = HEAP32[$2>>2]|0;
 $bitPos$016 = 0;$i$015 = 0;$indexPos$017 = 0;
 while(1) {
  $bitPos$14 = $bitPos$016;$bits$02 = 0;$flags$03 = 0;$indexPos$15 = $indexPos$017;
  while(1) {
   $3 = (($$pre) + ($indexPos$15)|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = $4&255;
   $6 = $5 >>> $bitPos$14;
   $7 = $6 << $bits$02;
   $8 = $7 | $flags$03;
   $9 = (3 - ($bits$02))|0;
   $10 = (8 - ($bitPos$14))|0;
   $11 = ($10|0)<($9|0);
   $12 = $11 ? $10 : $9;
   $13 = (($12) + ($bitPos$14))|0;
   $14 = (($12) + ($bits$02))|0;
   $15 = ($13|0)==(8);
   $$ = $15 ? 0 : $13;
   $16 = $15&1;
   $$indexPos$1 = (($16) + ($indexPos$15))|0;
   $17 = ($14|0)<(3);
   if ($17) {
    $bitPos$14 = $$;$bits$02 = $14;$flags$03 = $8;$indexPos$15 = $$indexPos$1;
   } else {
    break;
   }
  }
  $18 = $8 & 3;
  $19 = (($8) + 1)|0;
  $20 = $19 & 3;
  $21 = (($data) + ($i$015<<4)|0);
  $bitPos$213 = $$;$indexPos$214 = $$indexPos$1;$j$011 = 0;$sum$010 = Math_fround(0.0);
  while(1) {
   $22 = ($18|0)==($j$011|0);
   if ($22) {
    $bitPos$4 = $bitPos$213;$indexPos$4 = $indexPos$214;$sum$1 = $sum$010;
   } else {
    $23 = ($20|0)==($j$011|0);
    $24 = $23 ? 9 : 10;
    $bitPos$38 = $bitPos$213;$bits$16 = 0;$indexPos$39 = $indexPos$214;$x$07 = 0;
    while(1) {
     $25 = (($$pre) + ($indexPos$39)|0);
     $26 = HEAP8[$25>>0]|0;
     $27 = $26&255;
     $28 = $27 >>> $bitPos$38;
     $29 = $28 << $bits$16;
     $30 = $29 | $x$07;
     $31 = (($24) - ($bits$16))|0;
     $32 = (8 - ($bitPos$38))|0;
     $33 = ($32|0)<($31|0);
     $34 = $33 ? $32 : $31;
     $35 = (($34) + ($bitPos$38))|0;
     $36 = (($34) + ($bits$16))|0;
     $37 = ($35|0)==(8);
     $$1 = $37 ? 0 : $35;
     $38 = $37&1;
     $$indexPos$3 = (($38) + ($indexPos$39))|0;
     $39 = ($36|0)<($24|0);
     if ($39) {
      $bitPos$38 = $$1;$bits$16 = $36;$indexPos$39 = $$indexPos$3;$x$07 = $30;
     } else {
      break;
     }
    }
    $40 = 1 << $24;
    $41 = (($40) + -1)|0;
    $42 = $30 & $41;
    $43 = (+($42>>>0));
    $44 = (+($41|0));
    $45 = $44 * 0.5;
    $46 = $43 / $45;
    $47 = $46 + -1.0;
    $48 = Math_fround($47);
    $49 = (($21) + ($j$011<<2)|0);
    HEAPF32[$49>>2] = $48;
    $50 = Math_fround($48 * $48);
    $51 = Math_fround($sum$010 + $50);
    $bitPos$4 = $$1;$indexPos$4 = $$indexPos$3;$sum$1 = $51;
   }
   $52 = (($j$011) + 1)|0;
   $exitcond = ($52|0)==(4);
   if ($exitcond) {
    break;
   } else {
    $bitPos$213 = $bitPos$4;$indexPos$214 = $indexPos$4;$j$011 = $52;$sum$010 = $sum$1;
   }
  }
  $53 = Math_fround(Math_fround(1.0) - $sum$1);
  $54 = (Math_fround(Math_sqrt((Math_fround($53)))));
  $55 = (($21) + ($18<<2)|0);
  $56 = $8 & 4;
  $57 = ($56|0)==(0);
  if ($57) {
   $storemerge = $54;
  } else {
   $58 = Math_fround(-$54);
   $storemerge = $58;
  }
  HEAPF32[$55>>2] = $storemerge;
  $59 = (($i$015) + 1)|0;
  $60 = ($59|0)<($0|0);
  if ($60) {
   $bitPos$016 = $bitPos$4;$i$015 = $59;$indexPos$017 = $indexPos$4;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14CompressedMeshC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP8[$this+12>>0]=0|0;
 $1 = (($this) + 44|0);
 $2 = (($this) + 72|0);
 $3 = (($this) + 92|0);
 $4 = (($this) + 120|0);
 $5 = (($this) + 140|0);
 $6 = (($this) + 168|0);
 $7 = (($this) + 188|0);
 $8 = (($this) + 208|0);
 $9 = (($this) + 228|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP8[$0+24>>0]=0|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP8[$1+24>>0]=0|0;
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP8[$2+16>>0]=0|0;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;HEAP8[$3+24>>0]=0|0;
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP8[$4+16>>0]=0|0;
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;HEAP8[$5+24>>0]=0|0;
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP8[$6+16>>0]=0|0;
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP8[$7+16>>0]=0|0;
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP8[$8+16>>0]=0|0;
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN14CompressedMesh8CompressERK4MeshRK21CompressedMeshQuality($this,$src,$quality) {
 $this = $this|0;
 $src = $src|0;
 $quality = $quality|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$3 = 0, $$36 = 0, $$byval_copy28 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $boneIndexPos$0$lcssa = 0, $boneIndexPos$092 = 0, $boneIndexPos$1$lcssa122126 = 0, $boneIndexPos$184 = 0, $boneIndexPos$2 = 0, $exitcond = 0, $exitcond112 = 0, $exitcond113 = 0, $i$0100 = 0, $i4$097 = 0, $i5$093 = 0, $j$085 = 0, $lastNonZero$0$lcssa = 0, $lastNonZero$079 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $notlhs = 0, $notrhs = 0, $notrhs80 = 0, $or$cond$not = 0, $or$cond7 = 0, $sum$0$lcssa121127 = 0, $sum$086 = 0, $uvDimensionTotal$1 = 0, $uvDimensionTotal$1$1 = 0, $uvDimensionTotal$1$2 = 0, $uvDimensionTotal$1$3 = 0, $uvIndex1$0103 = 0, $uvOffset$0104 = 0, $uvOffset$1 = 0, $weightPos$0$lcssa = 0, $weightPos$091 = 0, $weightPos$1$lcssa123125 = 0, $weightPos$1$lcssa124 = 0, $weightPos$183 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy28 = sp + 88|0;
 $0 = sp + 84|0;
 $1 = sp + 80|0;
 $2 = sp + 76|0;
 $3 = sp + 72|0;
 $4 = sp + 68|0;
 $5 = sp + 64|0;
 $6 = sp + 60|0;
 $7 = sp + 56|0;
 $8 = sp + 52|0;
 $9 = sp + 48|0;
 $10 = sp + 44|0;
 $11 = sp + 16|0;
 $12 = sp;
 $13 = sp + 4|0;
 $14 = sp + 8|0;
 $15 = sp + 12|0;
 $16 = sp + 20|0;
 $17 = sp + 24|0;
 $18 = sp + 28|0;
 $19 = sp + 32|0;
 $20 = sp + 36|0;
 $21 = sp + 40|0;
 $22 = (($src) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 100|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 92|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($23) + 8|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = ((($23) + (($30*12)|0)|0) + 44|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($23) + 9|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34&255;
 $36 = (($35) + ($32))|0;
 $37 = (($27) + ($36)|0);
 $38 = ((($23) + (($30*12)|0)|0) + 50|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39&255;
 $41 = HEAP32[$quality>>2]|0;
 __ZN17PackedFloatVector10PackFloatsEPKfiiiib($this,$37,3,$40,$25,$41,0);
 $42 = HEAP32[$22>>2]|0;
 $43 = (($42) + 112|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + 108|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $44;
 $48 = $46;
 $49 = (($47) - ($48))|0;
 $50 = (($49|0) / 2)&-1;
 $51 = (($this) + 220|0);
 __ZN15PackedIntVector8PackIntsItEEvPT_i($51,$46,$50);
 $52 = (($this) + 240|0);
 HEAP32[$52>>2] = 0;
 $53 = HEAP32[$22>>2]|0;
 $54 = (($53) + 23|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  $350 = 0;$uvDimensionTotal$1 = 0;
 } else {
  $57 = $55&255;
  $58 = (($57) + -1)|0;
  $59 = $58 | 4;
  HEAP32[$52>>2] = $59;
  $350 = $59;$uvDimensionTotal$1 = $57;
 }
 $60 = (($53) + 27|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $360 = $350;$uvDimensionTotal$1$1 = $uvDimensionTotal$1;
 } else {
  $345 = $61&255;
  $346 = $345 << 4;
  $347 = (($346) + -16)|0;
  $348 = $347 | 64;
  $349 = $350 | $348;
  HEAP32[$52>>2] = $349;
  $351 = (($345) + ($uvDimensionTotal$1))|0;
  $360 = $349;$uvDimensionTotal$1$1 = $351;
 }
 $352 = (($53) + 31|0);
 $353 = HEAP8[$352>>0]|0;
 $354 = ($353<<24>>24)==(0);
 if ($354) {
  $370 = $360;$uvDimensionTotal$1$2 = $uvDimensionTotal$1$1;
 } else {
  $355 = $353&255;
  $356 = $355 << 8;
  $357 = (($356) + -256)|0;
  $358 = $357 | 1024;
  $359 = $360 | $358;
  HEAP32[$52>>2] = $359;
  $361 = (($355) + ($uvDimensionTotal$1$1))|0;
  $370 = $359;$uvDimensionTotal$1$2 = $361;
 }
 $362 = (($53) + 35|0);
 $363 = HEAP8[$362>>0]|0;
 $364 = ($363<<24>>24)==(0);
 if ($364) {
  $uvDimensionTotal$1$3 = $uvDimensionTotal$1$2;
 } else {
  $365 = $363&255;
  $366 = $365 << 12;
  $367 = (($366) + -4096)|0;
  $368 = $367 | 16384;
  $369 = $370 | $368;
  HEAP32[$52>>2] = $369;
  $371 = (($365) + ($uvDimensionTotal$1$2))|0;
  $uvDimensionTotal$1$3 = $371;
 }
 $82 = Math_imul($uvDimensionTotal$1$3, $25)|0;
 $339 = HEAP32[628512>>2]|0;
 $372 = $82 << 2;
 HEAP32[$0>>2] = $339;
 ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$0+0>>2]|0;
 $70 = (__Z15malloc_internaljj10MemLabelIdiPKci($372,4,$$byval_copy28,0,585336,352)|0);
 $uvIndex1$0103 = 0;$uvOffset$0104 = 0;
 while(1) {
  $63 = (($uvIndex1$0103) + 3)|0;
  $64 = HEAP32[$22>>2]|0;
  $65 = ((($64) + ($63<<2)|0) + 11|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = ($66<<24>>24)==(0);
  if ($67) {
   $uvOffset$1 = $uvOffset$0104;
  } else {
   $68 = $66&255;
   $69 = (($70) + ($uvOffset$0104<<2)|0);
   __THREW__ = 0;
   invoke_viiii(351,($src|0),($uvIndex1$0103|0),($69|0),($68|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    label = 7;
    break;
   }
   $73 = Math_imul($68, $25)|0;
   $74 = (($73) + ($uvOffset$0104))|0;
   $uvOffset$1 = $74;
  }
  $79 = (($uvIndex1$0103) + 1)|0;
  $80 = ($79|0)<(4);
  if ($80) {
   $uvIndex1$0103 = $79;$uvOffset$0104 = $uvOffset$1;
  } else {
   label = 11;
   break;
  }
 }
 L19: do {
  if ((label|0) == 7) {
   $75 = ___cxa_find_matching_catch()|0;
   $76 = tempRet0;
   $lpad$phi$index = $75;$lpad$phi$index2 = $76;
   label = 9;
  }
  else if ((label|0) == 11) {
   $81 = ($82|0)==(0);
   if ($81) {
    label = 13;
   } else {
    $83 = (($this) + 28|0);
    $84 = (($quality) + 8|0);
    $85 = HEAP32[$84>>2]|0;
    __THREW__ = 0;
    invoke_viiiiiii(66,($83|0),($70|0),($82|0),1,1,($85|0),1);
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if (!($87)) {
     label = 13;
    }
   }
   L24: do {
    if ((label|0) == 13) {
     $88 = HEAP32[$22>>2]|0;
     $89 = (($88) + 15|0);
     $90 = HEAP8[$89>>0]|0;
     $91 = ($90<<24>>24)==(0);
     L26: do {
      if (!($91)) {
       $92 = HEAP32[628512>>2]|0;
       $93 = $25 << 3;
       HEAP32[$8>>2] = $92;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$8+0>>2]|0;
       $94 = (invoke_iiiiiii(102,($93|0),4,($$byval_copy28|0),0,(585336|0),352)|0);
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        break L24;
       }
       $97 = HEAP32[628512>>2]|0;
       $98 = $25 << 2;
       HEAP32[$7>>2] = $97;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$7+0>>2]|0;
       $99 = (invoke_iiiiiii(102,($98|0),4,($$byval_copy28|0),0,(585336|0),352)|0);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       do {
        if ($101) {
         label = 22;
        } else {
         $102 = HEAP32[$22>>2]|0;
         $103 = (($102) + 14|0);
         $104 = HEAP8[$103>>0]|0;
         $105 = ($104<<24>>24)==(0);
         if ($105) {
          $106 = (($102) + 15|0);
          $107 = HEAP8[$106>>0]|0;
          $108 = ($107&255)<(3);
          if ($108) {
           $139 = 0;$373 = 0;
          } else {
           $109 = (($102) + 92|0);
           $110 = HEAP32[$109>>2]|0;
           $111 = ($110|0)==(0|0);
           if ($111) {
            $139 = 1;$373 = 0;
           } else {
            $112 = (($102) + 12|0);
            $113 = HEAP8[$112>>0]|0;
            $114 = $113&255;
            $115 = ((($102) + (($114*12)|0)|0) + 50|0);
            $116 = HEAP8[$115>>0]|0;
            $117 = $116&255;
            $118 = ((($102) + (($114*12)|0)|0) + 44|0);
            $119 = HEAP32[$118>>2]|0;
            $120 = (($102) + 13|0);
            $121 = HEAP8[$120>>0]|0;
            $122 = $121&255;
            $123 = (($122) + ($119))|0;
            $124 = (($110) + ($123)|0);
            $139 = $117;$373 = $124;
           }
          }
         } else {
          $139 = 0;$373 = 0;
         }
         $125 = ($25|0)>(0);
         if ($125) {
          $127 = $373;$i$0100 = 0;
          while(1) {
           $126 = Math_fround(HEAPF32[$127>>2]);
           $128 = (($94) + ($i$0100<<3)|0);
           HEAPF32[$128>>2] = $126;
           $129 = (($127) + 4|0);
           $130 = Math_fround(HEAPF32[$129>>2]);
           $131 = ((($94) + ($i$0100<<3)|0) + 4|0);
           HEAPF32[$131>>2] = $130;
           $132 = (($127) + 8|0);
           $133 = Math_fround(HEAPF32[$132>>2]);
           $134 = $133 > Math_fround(0.0);
           $135 = $134&1;
           $136 = (($99) + ($i$0100<<2)|0);
           HEAP32[$136>>2] = $135;
           $137 = (($i$0100) + 1)|0;
           $138 = (($127) + ($139)|0);
           $exitcond113 = ($137|0)==($25|0);
           if ($exitcond113) {
            break;
           } else {
            $127 = $138;$i$0100 = $137;
           }
          }
         }
         $147 = (($this) + 56|0);
         $148 = (($quality) + 4|0);
         $149 = HEAP32[$148>>2]|0;
         __THREW__ = 0;
         invoke_viiiiiii(66,($147|0),($94|0),2,8,($25|0),($149|0),0);
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if (!($151)) {
          $152 = (($this) + 84|0);
          __THREW__ = 0;
          invoke_viii(1696,($152|0),($99|0),($25|0));
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if (!($154)) {
           $155 = ($25|0)>(-1);
           if (!($155)) {
            break L26;
           }
           HEAP32[$1>>2] = $97;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$1+0>>2]|0;
           invoke_vii(2591,($99|0),($$byval_copy28|0));
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            label = 22;
            break;
           }
           HEAP32[$2>>2] = $92;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$2+0>>2]|0;
           invoke_vii(2591,($94|0),($$byval_copy28|0));
           $158 = __THREW__; __THREW__ = 0;
           $159 = $158&1;
           if ($159) {
            break L24;
           } else {
            break L26;
           }
          }
         }
         $142 = ___cxa_find_matching_catch()|0;
         $143 = tempRet0;
         $144 = ($25|0)>(-1);
         if (!($144)) {
          $$3 = $143;$$36 = $142;
          break L19;
         }
         HEAP32[$0>>2] = $97;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($99|0),($$byval_copy28|0));
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         if ($146) {
          $343 = ___cxa_find_matching_catch(0|0)|0;
          $344 = tempRet0;
          ___clang_call_terminate($343);
          // unreachable;
         } else {
          $$0 = $143;$$03 = $142;
         }
        }
       } while(0);
       if ((label|0) == 22) {
        $140 = ___cxa_find_matching_catch()|0;
        $141 = tempRet0;
        $$0 = $141;$$03 = $140;
       }
       $160 = ($25|0)>(-1);
       if (!($160)) {
        $$3 = $$0;$$36 = $$03;
        break L19;
       }
       HEAP32[$3>>2] = $92;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$3+0>>2]|0;
       invoke_vii(2591,($94|0),($$byval_copy28|0));
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       if (!($162)) {
        $$3 = $$0;$$36 = $$03;
        break L19;
       }
       $343 = ___cxa_find_matching_catch(0|0)|0;
       $344 = tempRet0;
       ___clang_call_terminate($343);
       // unreachable;
      }
     } while(0);
     $163 = HEAP32[$22>>2]|0;
     $164 = (($163) + 39|0);
     $165 = HEAP8[$164>>0]|0;
     $166 = ($165<<24>>24)==(0);
     L54: do {
      if (!($166)) {
       $167 = HEAP32[628512>>2]|0;
       $168 = $25 << 3;
       HEAP32[$4>>2] = $167;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$4+0>>2]|0;
       $169 = (invoke_iiiiiii(102,($168|0),4,($$byval_copy28|0),0,(585336|0),352)|0);
       $170 = __THREW__; __THREW__ = 0;
       $171 = $170&1;
       if ($171) {
        break L24;
       }
       $172 = $25 << 1;
       $173 = HEAP32[628512>>2]|0;
       HEAP32[$5>>2] = $173;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$5+0>>2]|0;
       $174 = (invoke_iiiiiii(102,($168|0),4,($$byval_copy28|0),0,(585336|0),352)|0);
       $175 = __THREW__; __THREW__ = 0;
       $176 = $175&1;
       do {
        if ($176) {
         label = 41;
        } else {
         $177 = HEAP32[$22>>2]|0;
         $178 = (($177) + 38|0);
         $179 = HEAP8[$178>>0]|0;
         $180 = ($179<<24>>24)==(0);
         if ($180) {
          $181 = (($177) + 39|0);
          $182 = HEAP8[$181>>0]|0;
          $183 = ($182&255)<(4);
          if ($183) {
           $221 = 0;$374 = 0;
          } else {
           $184 = (($177) + 92|0);
           $185 = HEAP32[$184>>2]|0;
           $186 = ($185|0)==(0|0);
           if ($186) {
            $221 = 1;$374 = 0;
           } else {
            $187 = (($177) + 36|0);
            $188 = HEAP8[$187>>0]|0;
            $189 = $188&255;
            $190 = ((($177) + (($189*12)|0)|0) + 50|0);
            $191 = HEAP8[$190>>0]|0;
            $192 = $191&255;
            $193 = ((($177) + (($189*12)|0)|0) + 44|0);
            $194 = HEAP32[$193>>2]|0;
            $195 = (($177) + 37|0);
            $196 = HEAP8[$195>>0]|0;
            $197 = $196&255;
            $198 = (($197) + ($194))|0;
            $199 = (($185) + ($198)|0);
            $221 = $192;$374 = $199;
           }
          }
         } else {
          $221 = 0;$374 = 0;
         }
         $200 = ($25|0)>(0);
         if ($200) {
          $202 = $374;$i4$097 = 0;
          while(1) {
           $201 = Math_fround(HEAPF32[$202>>2]);
           $203 = (($169) + ($i4$097<<3)|0);
           HEAPF32[$203>>2] = $201;
           $204 = (($202) + 4|0);
           $205 = Math_fround(HEAPF32[$204>>2]);
           $206 = ((($169) + ($i4$097<<3)|0) + 4|0);
           HEAPF32[$206>>2] = $205;
           $207 = (($202) + 8|0);
           $208 = Math_fround(HEAPF32[$207>>2]);
           $209 = $208 > Math_fround(0.0);
           $210 = $209&1;
           $211 = $i4$097 << 1;
           $212 = (($174) + ($211<<2)|0);
           HEAP32[$212>>2] = $210;
           $213 = (($202) + 12|0);
           $214 = Math_fround(HEAPF32[$213>>2]);
           $215 = $214 > Math_fround(0.0);
           $216 = $215&1;
           $217 = $211 | 1;
           $218 = (($174) + ($217<<2)|0);
           HEAP32[$218>>2] = $216;
           $219 = (($i4$097) + 1)|0;
           $220 = (($202) + ($221)|0);
           $exitcond112 = ($219|0)==($25|0);
           if ($exitcond112) {
            break;
           } else {
            $202 = $220;$i4$097 = $219;
           }
          }
         }
         $229 = (($this) + 104|0);
         $230 = (($quality) + 4|0);
         $231 = HEAP32[$230>>2]|0;
         __THREW__ = 0;
         invoke_viiiiiii(66,($229|0),($169|0),2,8,($25|0),($231|0),0);
         $232 = __THREW__; __THREW__ = 0;
         $233 = $232&1;
         if (!($233)) {
          $234 = (($this) + 132|0);
          __THREW__ = 0;
          invoke_viii(1696,($234|0),($174|0),($172|0));
          $235 = __THREW__; __THREW__ = 0;
          $236 = $235&1;
          if (!($236)) {
           $237 = ($25|0)>(-1);
           if (!($237)) {
            break L54;
           }
           HEAP32[$9>>2] = $173;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$9+0>>2]|0;
           invoke_vii(2591,($174|0),($$byval_copy28|0));
           $238 = __THREW__; __THREW__ = 0;
           $239 = $238&1;
           if ($239) {
            label = 41;
            break;
           }
           HEAP32[$10>>2] = $167;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$10+0>>2]|0;
           invoke_vii(2591,($169|0),($$byval_copy28|0));
           $240 = __THREW__; __THREW__ = 0;
           $241 = $240&1;
           if ($241) {
            break L24;
           } else {
            break L54;
           }
          }
         }
         $224 = ___cxa_find_matching_catch()|0;
         $225 = tempRet0;
         $226 = ($25|0)>(-1);
         if (!($226)) {
          $$3 = $225;$$36 = $224;
          break L19;
         }
         HEAP32[$6>>2] = $173;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$6+0>>2]|0;
         invoke_vii(2591,($174|0),($$byval_copy28|0));
         $227 = __THREW__; __THREW__ = 0;
         $228 = $227&1;
         if ($228) {
          $343 = ___cxa_find_matching_catch(0|0)|0;
          $344 = tempRet0;
          ___clang_call_terminate($343);
          // unreachable;
         } else {
          $$1 = $225;$$14 = $224;
         }
        }
       } while(0);
       if ((label|0) == 41) {
        $222 = ___cxa_find_matching_catch()|0;
        $223 = tempRet0;
        $$1 = $223;$$14 = $222;
       }
       $242 = ($25|0)>(-1);
       if (!($242)) {
        $$3 = $$1;$$36 = $$14;
        break L19;
       }
       HEAP32[$11>>2] = $167;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$11+0>>2]|0;
       invoke_vii(2591,($169|0),($$byval_copy28|0));
       $243 = __THREW__; __THREW__ = 0;
       $244 = $243&1;
       if (!($244)) {
        $$3 = $$1;$$36 = $$14;
        break L19;
       }
       $343 = ___cxa_find_matching_catch(0|0)|0;
       $344 = tempRet0;
       ___clang_call_terminate($343);
       // unreachable;
      }
     } while(0);
     $245 = HEAP32[$22>>2]|0;
     $246 = (($245) + 19|0);
     $247 = HEAP8[$246>>0]|0;
     $248 = ($247<<24>>24)==(0);
     do {
      if (!($248)) {
       $249 = HEAP32[628512>>2]|0;
       $250 = $25 << 4;
       HEAP32[$12>>2] = $249;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$12+0>>2]|0;
       $251 = (invoke_iiiiiii(102,($250|0),4,($$byval_copy28|0),0,(585336|0),352)|0);
       $252 = __THREW__; __THREW__ = 0;
       $253 = $252&1;
       if ($253) {
        break L24;
       }
       __THREW__ = 0;
       invoke_vii(2664,($src|0),($251|0));
       $254 = __THREW__; __THREW__ = 0;
       $255 = $254&1;
       if (!($255)) {
        $256 = (($this) + 152|0);
        $257 = (($quality) + 12|0);
        $258 = HEAP32[$257>>2]|0;
        __THREW__ = 0;
        invoke_viiiiiii(66,($256|0),($251|0),4,16,($25|0),($258|0),0);
        $259 = __THREW__; __THREW__ = 0;
        $260 = $259&1;
        if (!($260)) {
         $261 = ($25|0)>(-1);
         if (!($261)) {
          break;
         }
         HEAP32[$13>>2] = $249;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$13+0>>2]|0;
         invoke_vii(2591,($251|0),($$byval_copy28|0));
         $262 = __THREW__; __THREW__ = 0;
         $263 = $262&1;
         if ($263) {
          break L24;
         } else {
          break;
         }
        }
       }
       $264 = ___cxa_find_matching_catch()|0;
       $265 = tempRet0;
       $266 = ($25|0)>(-1);
       if (!($266)) {
        $$3 = $265;$$36 = $264;
        break L19;
       }
       HEAP32[$14>>2] = $249;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$14+0>>2]|0;
       invoke_vii(2591,($251|0),($$byval_copy28|0));
       $267 = __THREW__; __THREW__ = 0;
       $268 = $267&1;
       if (!($268)) {
        $$3 = $265;$$36 = $264;
        break L19;
       }
       $343 = ___cxa_find_matching_catch(0|0)|0;
       $344 = tempRet0;
       ___clang_call_terminate($343);
       // unreachable;
      }
     } while(0);
     $269 = HEAP32[$22>>2]|0;
     $270 = (($269) + 144|0);
     $271 = HEAP32[$270>>2]|0;
     $272 = ($271|0)==(0);
     L93: do {
      if (!($272)) {
       $273 = (($269) + 136|0);
       $274 = HEAP32[$273>>2]|0;
       $275 = ($274|0)==(0|0);
       if (!($275)) {
        $276 = HEAP32[628512>>2]|0;
        $277 = ($25*12)|0;
        HEAP32[$15>>2] = $276;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$15+0>>2]|0;
        $278 = (invoke_iiiiiii(102,($277|0),4,($$byval_copy28|0),0,(585336|0),352)|0);
        $279 = __THREW__; __THREW__ = 0;
        $280 = $279&1;
        if ($280) {
         break L24;
        }
        $281 = HEAP32[628512>>2]|0;
        $282 = $25 << 4;
        HEAP32[$16>>2] = $281;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$16+0>>2]|0;
        $283 = (invoke_iiiiiii(102,($282|0),4,($$byval_copy28|0),0,(585336|0),352)|0);
        $284 = __THREW__; __THREW__ = 0;
        $285 = $284&1;
        do {
         if ($285) {
          label = 67;
         } else {
          $286 = ($25|0)>(0);
          if ($286) {
           $boneIndexPos$092 = 0;$i5$093 = 0;$weightPos$091 = 0;
           while(1) {
            $lastNonZero$079 = 3;
            while(1) {
             $289 = ((($274) + ($i5$093<<5)|0) + ($lastNonZero$079<<2)|0);
             $290 = Math_fround(HEAPF32[$289>>2]);
             $291 = $290 == Math_fround(0.0);
             $288 = (($lastNonZero$079) + -1)|0;
             if (!($291)) {
              $lastNonZero$0$lcssa = $lastNonZero$079;
              break;
             }
             $287 = ($288|0)>(0);
             if ($287) {
              $lastNonZero$079 = $288;
             } else {
              $lastNonZero$0$lcssa = $288;
              break;
             }
            }
            $notrhs80 = ($lastNonZero$0$lcssa|0)>(-1);
            do {
             if ($notrhs80) {
              $boneIndexPos$184 = $boneIndexPos$092;$j$085 = 0;$sum$086 = 0;$weightPos$183 = $weightPos$091;
              while(1) {
               $294 = ((($274) + ($i5$093<<5)|0) + ($j$085<<2)|0);
               $295 = Math_fround(HEAPF32[$294>>2]);
               $296 = Math_fround($295 * Math_fround(31.0));
               $297 = (~~(($296))>>>0);
               $298 = (($278) + ($weightPos$183<<2)|0);
               HEAP32[$298>>2] = $297;
               $299 = (((($274) + ($i5$093<<5)|0) + ($j$085<<2)|0) + 16|0);
               $300 = HEAP32[$299>>2]|0;
               $301 = (($boneIndexPos$184) + 1)|0;
               $302 = (($283) + ($boneIndexPos$184<<2)|0);
               HEAP32[$302>>2] = $300;
               $303 = (($weightPos$183) + 1)|0;
               $304 = HEAP32[$298>>2]|0;
               $305 = (($304) + ($sum$086))|0;
               $306 = (($j$085) + 1)|0;
               $notlhs = ($306|0)<(3);
               $notrhs = ($j$085|0)<($lastNonZero$0$lcssa|0);
               $or$cond$not = $notrhs & $notlhs;
               $307 = ($305|0)<(31);
               $or$cond7 = $or$cond$not & $307;
               if ($or$cond7) {
                $boneIndexPos$184 = $301;$j$085 = $306;$sum$086 = $305;$weightPos$183 = $303;
               } else {
                break;
               }
              }
              $313 = ($lastNonZero$0$lcssa|0)<(3);
              if ($313) {
               if ($307) {
                $boneIndexPos$1$lcssa122126 = $301;$sum$0$lcssa121127 = $305;$weightPos$1$lcssa123125 = $303;
                label = 74;
                break;
               } else {
                $boneIndexPos$2 = $301;$weightPos$1$lcssa124 = $303;
                break;
               }
              }
              if (!($307)) {
               $boneIndexPos$2 = $301;$weightPos$1$lcssa124 = $303;
               break;
              }
              $319 = (((($274) + ($i5$093<<5)|0) + ($306<<2)|0) + 16|0);
              $320 = HEAP32[$319>>2]|0;
              $321 = (($boneIndexPos$184) + 2)|0;
              $322 = (($283) + ($301<<2)|0);
              HEAP32[$322>>2] = $320;
              $boneIndexPos$2 = $321;$weightPos$1$lcssa124 = $303;
             } else {
              $boneIndexPos$1$lcssa122126 = $boneIndexPos$092;$sum$0$lcssa121127 = 0;$weightPos$1$lcssa123125 = $weightPos$091;
              label = 74;
             }
            } while(0);
            if ((label|0) == 74) {
             label = 0;
             $314 = (31 - ($sum$0$lcssa121127))|0;
             $315 = (($weightPos$1$lcssa123125) + -1)|0;
             $316 = (($278) + ($315<<2)|0);
             $317 = HEAP32[$316>>2]|0;
             $318 = (($314) + ($317))|0;
             HEAP32[$316>>2] = $318;
             $boneIndexPos$2 = $boneIndexPos$1$lcssa122126;$weightPos$1$lcssa124 = $weightPos$1$lcssa123125;
            }
            $323 = (($i5$093) + 1)|0;
            $exitcond = ($323|0)==($25|0);
            if ($exitcond) {
             $boneIndexPos$0$lcssa = $boneIndexPos$2;$weightPos$0$lcssa = $weightPos$1$lcssa124;
             break;
            } else {
             $boneIndexPos$092 = $boneIndexPos$2;$i5$093 = $323;$weightPos$091 = $weightPos$1$lcssa124;
            }
           }
          } else {
           $boneIndexPos$0$lcssa = 0;$weightPos$0$lcssa = 0;
          }
          $324 = (($this) + 180|0);
          __THREW__ = 0;
          invoke_viii(1696,($324|0),($278|0),($weightPos$0$lcssa|0));
          $325 = __THREW__; __THREW__ = 0;
          $326 = $325&1;
          if (!($326)) {
           $327 = (($this) + 200|0);
           __THREW__ = 0;
           invoke_viii(1696,($327|0),($283|0),($boneIndexPos$0$lcssa|0));
           $328 = __THREW__; __THREW__ = 0;
           $329 = $328&1;
           if (!($329)) {
            $330 = ($25|0)>(-1);
            if (!($330)) {
             break L93;
            }
            HEAP32[$18>>2] = $281;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$18+0>>2]|0;
            invoke_vii(2591,($283|0),($$byval_copy28|0));
            $331 = __THREW__; __THREW__ = 0;
            $332 = $331&1;
            if ($332) {
             label = 67;
             break;
            }
            HEAP32[$19>>2] = $276;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$19+0>>2]|0;
            invoke_vii(2591,($278|0),($$byval_copy28|0));
            $333 = __THREW__; __THREW__ = 0;
            $334 = $333&1;
            if ($334) {
             break L24;
            } else {
             break L93;
            }
           }
          }
          $308 = ___cxa_find_matching_catch()|0;
          $309 = tempRet0;
          $310 = ($25|0)>(-1);
          if (!($310)) {
           $$3 = $309;$$36 = $308;
           break L19;
          }
          HEAP32[$17>>2] = $281;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$17+0>>2]|0;
          invoke_vii(2591,($283|0),($$byval_copy28|0));
          $311 = __THREW__; __THREW__ = 0;
          $312 = $311&1;
          if ($312) {
           $343 = ___cxa_find_matching_catch(0|0)|0;
           $344 = tempRet0;
           ___clang_call_terminate($343);
           // unreachable;
          } else {
           $$2 = $309;$$25 = $308;
          }
         }
        } while(0);
        if ((label|0) == 67) {
         $292 = ___cxa_find_matching_catch()|0;
         $293 = tempRet0;
         $$2 = $293;$$25 = $292;
        }
        $335 = ($25|0)>(-1);
        if (!($335)) {
         $$3 = $$2;$$36 = $$25;
         break L19;
        }
        HEAP32[$20>>2] = $276;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$20+0>>2]|0;
        invoke_vii(2591,($278|0),($$byval_copy28|0));
        $336 = __THREW__; __THREW__ = 0;
        $337 = $336&1;
        if (!($337)) {
         $$3 = $$2;$$36 = $$25;
         break L19;
        }
        $343 = ___cxa_find_matching_catch(0|0)|0;
        $344 = tempRet0;
        ___clang_call_terminate($343);
        // unreachable;
       }
      }
     } while(0);
     $338 = ($82|0)>(-1);
     if (!($338)) {
      STACKTOP = sp;return;
     }
     HEAP32[$0>>2] = $339;
     ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($70,$$byval_copy28);
     STACKTOP = sp;return;
    }
   } while(0);
   $77 = ___cxa_find_matching_catch()|0;
   $78 = tempRet0;
   $lpad$phi$index = $77;$lpad$phi$index2 = $78;
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  $$3 = $lpad$phi$index2;$$36 = $lpad$phi$index;
 }
 $340 = ($82|0)>(-1);
 if (!($340)) {
  ___resumeException($$36|0);
  // unreachable;
 }
 HEAP32[$21>>2] = $339;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy28+0>>2]=HEAP32[$21+0>>2]|0;
 invoke_vii(2591,($70|0),($$byval_copy28|0));
 $341 = __THREW__; __THREW__ = 0;
 $342 = $341&1;
 if ($342) {
  $343 = ___cxa_find_matching_catch(0|0)|0;
  $344 = tempRet0;
  ___clang_call_terminate($343);
  // unreachable;
 } else {
  ___resumeException($$36|0);
  // unreachable;
 }
}
function __ZN15PackedIntVector8PackIntsItEEvPT_i($this,$data,$numItems) {
 $this = $this|0;
 $data = $data|0;
 $numItems = $numItems|0;
 var $$ = 0, $$$i = 0, $$1$i = 0, $$2$i = 0, $$indexPos$1 = 0, $$mask$i = 0, $$maxi$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $base$1$i = 0, $base$2$i = 0, $bitPos$06 = 0, $bitPos$1$lcssa = 0, $bitPos$12 = 0;
 var $bits$03 = 0, $exitcond = 0, $exitcond14 = 0, $i$08 = 0, $i1$07 = 0, $indexPos$05 = 0, $indexPos$1$lcssa = 0, $indexPos$11 = 0, $maxi$09 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($numItems|0)>(0);
 if ($1) {
  $i$08 = 0;$maxi$09 = 0;
  while(1) {
   $2 = (($data) + ($i$08<<1)|0);
   $3 = HEAP16[$2>>1]|0;
   $4 = $3&65535;
   $5 = ($maxi$09>>>0)<($4>>>0);
   $$maxi$0 = $5 ? $4 : $maxi$09;
   $6 = (($i$08) + 1)|0;
   $exitcond14 = ($6|0)==($numItems|0);
   if ($exitcond14) {
    break;
   } else {
    $i$08 = $6;$maxi$09 = $$maxi$0;
   }
  }
  HEAP32[$this>>2] = $numItems;
  $7 = ($$maxi$0|0)==(0);
  if ($7) {
   $24 = 0;
  } else {
   $8 = ($$maxi$0>>>0)>(65535);
   $9 = $$maxi$0 >>> 16;
   $$mask$i = $8 ? $9 : $$maxi$0;
   $$$i = $8 ? 16 : 0;
   $10 = $$mask$i & 65280;
   $11 = ($10|0)==(0);
   if ($11) {
    $$1$i = $$mask$i;$base$1$i = $$$i;
   } else {
    $12 = $$$i | 8;
    $13 = $$mask$i >>> 8;
    $$1$i = $13;$base$1$i = $12;
   }
   $14 = $$1$i & 240;
   $15 = ($14|0)==(0);
   if ($15) {
    $$2$i = $$1$i;$base$2$i = $base$1$i;
   } else {
    $16 = (($base$1$i) + 4)|0;
    $17 = $$1$i >>> 4;
    $$2$i = $17;$base$2$i = $16;
   }
   $18 = (585408 + ($$2$i)|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = $19&255;
   $21 = (($base$2$i) + 1)|0;
   $22 = (($21) + ($20))|0;
   $phitmp = $22&255;
   $24 = $phitmp;
  }
 } else {
  HEAP32[$this>>2] = $numItems;
  $24 = 0;
 }
 $23 = (($this) + 4|0);
 HEAP8[$23>>0] = $24;
 $25 = (($this) + 8|0);
 $26 = $24&255;
 $27 = Math_imul($26, $numItems)|0;
 $28 = (($27) + 7)|0;
 $29 = (($28|0) / 8)&-1;
 HEAP8[$0>>0] = 0;
 $30 = (($this) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$25>>2]|0;
 $33 = $31;
 $34 = $32;
 $35 = (($33) - ($34))|0;
 $36 = ($35>>>0)<($29>>>0);
 if ($36) {
  $37 = (($29) - ($35))|0;
  __ZNSt3__16vectorIhNS_9allocatorIhEEE8__appendEjRKh($25,$37,$0);
 } else {
  $38 = ($35>>>0)>($29>>>0);
  if ($38) {
   $39 = (($32) + ($29)|0);
   $40 = ($31|0)==($39|0);
   if (!($40)) {
    HEAP32[$30>>2] = $39;
   }
  }
 }
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $$pre = HEAP8[$23>>0]|0;
 $42 = $$pre;$bitPos$06 = 0;$i1$07 = 0;$indexPos$05 = 0;
 while(1) {
  $41 = ($42<<24>>24)==(0);
  if ($41) {
   $66 = 0;$bitPos$1$lcssa = $bitPos$06;$indexPos$1$lcssa = $indexPos$05;
  } else {
   $43 = (($data) + ($i1$07<<1)|0);
   $bitPos$12 = $bitPos$06;$bits$03 = 0;$indexPos$11 = $indexPos$05;
   while(1) {
    $44 = HEAP16[$43>>1]|0;
    $45 = $44&65535;
    $46 = $45 >>> $bits$03;
    $47 = $46 << $bitPos$12;
    $48 = HEAP32[$25>>2]|0;
    $49 = (($48) + ($indexPos$11)|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = $50&255;
    $52 = $51 | $47;
    $53 = $52&255;
    HEAP8[$49>>0] = $53;
    $54 = HEAP8[$23>>0]|0;
    $55 = $54&255;
    $56 = (($55) - ($bits$03))|0;
    $57 = (8 - ($bitPos$12))|0;
    $58 = ($57|0)<($56|0);
    $59 = $58 ? $57 : $56;
    $60 = (($59) + ($bitPos$12))|0;
    $61 = (($59) + ($bits$03))|0;
    $62 = ($60|0)==(8);
    $63 = $62&1;
    $$indexPos$1 = (($63) + ($indexPos$11))|0;
    $$ = $62 ? 0 : $60;
    $64 = ($61|0)<($55|0);
    if ($64) {
     $bitPos$12 = $$;$bits$03 = $61;$indexPos$11 = $$indexPos$1;
    } else {
     $66 = $54;$bitPos$1$lcssa = $$;$indexPos$1$lcssa = $$indexPos$1;
     break;
    }
   }
  }
  $65 = (($i1$07) + 1)|0;
  $exitcond = ($65|0)==($numItems|0);
  if ($exitcond) {
   break;
  } else {
   $42 = $66;$bitPos$06 = $bitPos$1$lcssa;$i1$07 = $65;$indexPos$05 = $indexPos$1$lcssa;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15PackedIntVector8PackIntsIjEEvPT_i($this,$data,$numItems) {
 $this = $this|0;
 $data = $data|0;
 $numItems = $numItems|0;
 var $$ = 0, $$$i = 0, $$1$i = 0, $$2$i = 0, $$indexPos$1 = 0, $$mask$i = 0, $$maxi$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $base$1$i = 0, $base$2$i = 0, $bitPos$06 = 0, $bitPos$1$lcssa = 0, $bitPos$12 = 0, $bits$03 = 0, $exitcond = 0;
 var $exitcond14 = 0, $i$08 = 0, $i1$07 = 0, $indexPos$05 = 0, $indexPos$1$lcssa = 0, $indexPos$11 = 0, $maxi$09 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($numItems|0)>(0);
 if ($1) {
  $i$08 = 0;$maxi$09 = 0;
  while(1) {
   $2 = (($data) + ($i$08<<2)|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($maxi$09>>>0)<($3>>>0);
   $$maxi$0 = $4 ? $3 : $maxi$09;
   $5 = (($i$08) + 1)|0;
   $exitcond14 = ($5|0)==($numItems|0);
   if ($exitcond14) {
    break;
   } else {
    $i$08 = $5;$maxi$09 = $$maxi$0;
   }
  }
  HEAP32[$this>>2] = $numItems;
  $6 = ($$maxi$0|0)==(0);
  if ($6) {
   $23 = 0;
  } else {
   $7 = ($$maxi$0>>>0)>(65535);
   $8 = $$maxi$0 >>> 16;
   $$mask$i = $7 ? $8 : $$maxi$0;
   $$$i = $7 ? 16 : 0;
   $9 = $$mask$i & 65280;
   $10 = ($9|0)==(0);
   if ($10) {
    $$1$i = $$mask$i;$base$1$i = $$$i;
   } else {
    $11 = $$$i | 8;
    $12 = $$mask$i >>> 8;
    $$1$i = $12;$base$1$i = $11;
   }
   $13 = $$1$i & 240;
   $14 = ($13|0)==(0);
   if ($14) {
    $$2$i = $$1$i;$base$2$i = $base$1$i;
   } else {
    $15 = (($base$1$i) + 4)|0;
    $16 = $$1$i >>> 4;
    $$2$i = $16;$base$2$i = $15;
   }
   $17 = (585408 + ($$2$i)|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = $18&255;
   $20 = (($base$2$i) + 1)|0;
   $21 = (($20) + ($19))|0;
   $phitmp = $21&255;
   $23 = $phitmp;
  }
 } else {
  HEAP32[$this>>2] = $numItems;
  $23 = 0;
 }
 $22 = (($this) + 4|0);
 HEAP8[$22>>0] = $23;
 $24 = (($this) + 8|0);
 $25 = $23&255;
 $26 = Math_imul($25, $numItems)|0;
 $27 = (($26) + 7)|0;
 $28 = (($27|0) / 8)&-1;
 HEAP8[$0>>0] = 0;
 $29 = (($this) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$24>>2]|0;
 $32 = $30;
 $33 = $31;
 $34 = (($32) - ($33))|0;
 $35 = ($34>>>0)<($28>>>0);
 if ($35) {
  $36 = (($28) - ($34))|0;
  __ZNSt3__16vectorIhNS_9allocatorIhEEE8__appendEjRKh($24,$36,$0);
 } else {
  $37 = ($34>>>0)>($28>>>0);
  if ($37) {
   $38 = (($31) + ($28)|0);
   $39 = ($30|0)==($38|0);
   if (!($39)) {
    HEAP32[$29>>2] = $38;
   }
  }
 }
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $$pre = HEAP8[$22>>0]|0;
 $41 = $$pre;$bitPos$06 = 0;$i1$07 = 0;$indexPos$05 = 0;
 while(1) {
  $40 = ($41<<24>>24)==(0);
  if ($40) {
   $64 = 0;$bitPos$1$lcssa = $bitPos$06;$indexPos$1$lcssa = $indexPos$05;
  } else {
   $42 = (($data) + ($i1$07<<2)|0);
   $bitPos$12 = $bitPos$06;$bits$03 = 0;$indexPos$11 = $indexPos$05;
   while(1) {
    $43 = HEAP32[$42>>2]|0;
    $44 = $43 >>> $bits$03;
    $45 = $44 << $bitPos$12;
    $46 = HEAP32[$24>>2]|0;
    $47 = (($46) + ($indexPos$11)|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = $48&255;
    $50 = $49 | $45;
    $51 = $50&255;
    HEAP8[$47>>0] = $51;
    $52 = HEAP8[$22>>0]|0;
    $53 = $52&255;
    $54 = (($53) - ($bits$03))|0;
    $55 = (8 - ($bitPos$12))|0;
    $56 = ($55|0)<($54|0);
    $57 = $56 ? $55 : $54;
    $58 = (($57) + ($bitPos$12))|0;
    $59 = (($57) + ($bits$03))|0;
    $60 = ($58|0)==(8);
    $61 = $60&1;
    $$indexPos$1 = (($61) + ($indexPos$11))|0;
    $$ = $60 ? 0 : $58;
    $62 = ($59|0)<($53|0);
    if ($62) {
     $bitPos$12 = $$;$bits$03 = $59;$indexPos$11 = $$indexPos$1;
    } else {
     $64 = $52;$bitPos$1$lcssa = $$;$indexPos$1$lcssa = $$indexPos$1;
     break;
    }
   }
  }
  $63 = (($i1$07) + 1)|0;
  $exitcond = ($63|0)==($numItems|0);
  if ($exitcond) {
   break;
  } else {
   $41 = $64;$bitPos$06 = $bitPos$1$lcssa;$i1$07 = $63;$indexPos$05 = $indexPos$1$lcssa;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14CompressedMesh10DecompressER4Mesh($this,$dest) {
 $this = $this|0;
 $dest = $dest|0;
 var $$ = 0, $$$i = 0, $$$i128 = 0, $$$i149 = 0, $$$i149$1 = 0, $$$i22 = 0, $$$i38 = 0, $$$i51 = 0, $$$i70 = 0, $$$i91 = 0, $$$i91$1 = 0, $$01$i$i = 0, $$01$i$i48 = 0, $$018$i$in = 0, $$018$i136$in = 0, $$018$i78$in = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0;
 var $$byval_copy20 = 0, $$decompressedFormat$1$ = 0, $$indexPos$1$i = 0, $$indexPos$1$i129 = 0, $$indexPos$1$i23 = 0, $$indexPos$1$i39 = 0, $$indexPos$1$i71 = 0, $$indexPos$2$i = 0, $$indexPos$2$i150 = 0, $$indexPos$2$i150$1 = 0, $$indexPos$2$i92 = 0, $$indexPos$2$i92$1 = 0, $$op$i$i$i$i$i = Math_fround(0), $$op$i1$i$i$i$i = Math_fround(0), $$op$i2$i$i$i$i = Math_fround(0), $$op$i3$i$i$i$i = Math_fround(0), $$pre = 0, $$pre$i = 0, $$pre$i123 = 0, $$pre$i17 = 0;
 var $$pre$i33 = 0, $$pre$i65 = 0, $$pre226 = 0, $$pre227 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0;
 var $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0.0, $226 = 0.0, $227 = Math_fround(0), $228 = 0.0, $229 = 0.0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = 0;
 var $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = 0.0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0.0, $359 = 0.0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0.0, $39 = 0, $390 = 0.0, $391 = Math_fround(0), $392 = 0.0, $393 = 0.0, $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = 0, $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = 0;
 var $473 = 0, $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = Math_fround(0), $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = Math_fround(0), $517 = 0.0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0.0, $523 = 0.0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0.0, $554 = 0.0, $555 = Math_fround(0), $556 = 0.0, $557 = 0.0, $558 = Math_fround(0), $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0;
 var $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0;
 var $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = Math_fround(0), $591 = 0, $592 = Math_fround(0), $593 = 0, $594 = Math_fround(0), $595 = Math_fround(0), $596 = 0, $597 = 0, $598 = 0, $599 = 0;
 var $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = 0, $602 = Math_fround(0), $603 = 0, $604 = Math_fround(0), $605 = Math_fround(0), $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = Math_fround(0), $611 = 0, $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $615 = Math_fround(0), $616 = 0;
 var $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = Math_fround(0), $621 = 0, $622 = Math_fround(0), $623 = 0, $624 = Math_fround(0), $625 = Math_fround(0), $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0;
 var $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0;
 var $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0), $664 = 0, $665 = Math_fround(0), $666 = 0, $667 = Math_fround(0), $668 = 0, $669 = 0, $67 = 0, $670 = 0;
 var $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0;
 var $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0;
 var $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0;
 var $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0;
 var $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0;
 var $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0;
 var $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0.0, $792 = 0.0, $793 = Math_fround(0), $794 = 0, $795 = 0, $796 = 0, $797 = 0;
 var $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0;
 var $815 = 0, $816 = 0, $817 = 0.0, $818 = 0.0, $819 = Math_fround(0), $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0;
 var $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0;
 var $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0.0, $858 = 0.0, $859 = Math_fround(0), $86 = 0, $860 = 0.0, $861 = 0.0, $862 = Math_fround(0), $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0;
 var $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0.0, $886 = 0.0, $887 = Math_fround(0);
 var $888 = 0.0, $889 = 0.0, $89 = 0, $890 = Math_fround(0), $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0;
 var $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0;
 var $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0;
 var $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0;
 var $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0;
 var $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $99 = 0, $bitPos$016$i = 0, $bitPos$016$i138 = 0, $bitPos$016$i80 = 0, $bitPos$05$i = 0, $bitPos$05$i122 = 0, $bitPos$05$i16 = 0, $bitPos$05$i32 = 0, $bitPos$05$i64 = 0, $bitPos$1$lcssa$i = 0, $bitPos$1$lcssa$i131 = 0;
 var $bitPos$1$lcssa$i25 = 0, $bitPos$1$lcssa$i41 = 0, $bitPos$1$lcssa$i73 = 0, $bitPos$11$i = 0, $bitPos$11$i127 = 0, $bitPos$11$i21 = 0, $bitPos$11$i37 = 0, $bitPos$11$i69 = 0, $bitPos$110$i = 0, $bitPos$2$lcssa$i = 0, $bitPos$2$lcssa$i153 = 0, $bitPos$2$lcssa$i153$1 = 0, $bitPos$2$lcssa$i95 = 0, $bitPos$2$lcssa$i95$1 = 0, $bitPos$22$i = 0, $bitPos$22$i148 = 0, $bitPos$22$i148$1 = 0, $bitPos$22$i90 = 0, $bitPos$22$i90$1 = 0, $bits$02$i = 0;
 var $bits$02$i126 = 0, $bits$02$i20 = 0, $bits$02$i36 = 0, $bits$02$i68 = 0, $bits$05$i = 0, $bits$05$i145 = 0, $bits$05$i145$1 = 0, $bits$05$i87 = 0, $bits$05$i87$1 = 0, $boneIndexPos$0188 = 0, $boneIndexPos$1 = 0, $bonePos$0186 = 0, $bonePos$1 = 0, $channelsLayout = 0, $decompressedFormat$1 = 0, $decompressedFormat$1$ = 0, $decompressedFormat$3 = 0, $decompressedFormat$3$1 = 0, $decompressedFormat$3$2 = 0, $decompressedFormat$5 = 0;
 var $decompressedFormat$5$ = 0, $decompressedFormat$7 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond225 = 0, $i$012$i = 0, $i$0200 = 0, $i$06$i = 0, $i$06$i121 = 0, $i$06$i15 = 0, $i$06$i31 = 0, $i$06$i63 = 0, $i4$0195 = 0, $i6$0191 = 0, $indexPos$017$i = 0, $indexPos$017$i137 = 0, $indexPos$017$i79 = 0, $indexPos$07$i = 0, $indexPos$07$i120 = 0, $indexPos$07$i14 = 0;
 var $indexPos$07$i30 = 0, $indexPos$07$i62 = 0, $indexPos$1$lcssa$i = 0, $indexPos$1$lcssa$i130 = 0, $indexPos$1$lcssa$i24 = 0, $indexPos$1$lcssa$i40 = 0, $indexPos$1$lcssa$i72 = 0, $indexPos$111$i = 0, $indexPos$13$i = 0, $indexPos$13$i125 = 0, $indexPos$13$i19 = 0, $indexPos$13$i35 = 0, $indexPos$13$i67 = 0, $indexPos$2$lcssa$i = 0, $indexPos$2$lcssa$i152 = 0, $indexPos$2$lcssa$i152$1 = 0, $indexPos$2$lcssa$i94 = 0, $indexPos$2$lcssa$i94$1 = 0, $indexPos$23$i = 0, $indexPos$23$i147 = 0;
 var $indexPos$23$i147$1 = 0, $indexPos$23$i89 = 0, $indexPos$23$i89$1 = 0, $j$0189 = 0, $j$1185 = 0, $j$2 = 0, $not$ = 0, $phitmp$i = 0, $scale$0$i = 0.0, $scale$0$i134 = 0.0, $scale$0$i76 = 0.0, $sum$0190 = 0, $sum$1 = 0, $uvSrcOffset$1 = 0, $uvSrcOffset$1$1 = 0, $uvSrcOffset$1$2 = 0, $x$0$lcssa$i = 0, $x$0$lcssa$i151 = 0, $x$0$lcssa$i151$1 = 0, $x$0$lcssa$i93 = 0;
 var $x$0$lcssa$i93$1 = 0, $x$04$i = 0, $x$04$i146 = 0, $x$04$i146$1 = 0, $x$04$i88 = 0, $x$04$i88$1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy20 = sp + 28|0;
 $0 = sp + 52|0;
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = sp + 36|0;
 $5 = sp + 32|0;
 $6 = sp + 24|0;
 $7 = sp + 20|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 4|0;
 $12 = sp;
 $channelsLayout = sp + 56|0;
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13|0) / 3)&-1;
 $15 = ($14*3)|0;
 $16 = ($13|0)==($15|0);
 do {
  if ($16) {
   $17 = (($this) + 56|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0);
   if (!($19)) {
    $20 = $14 << 1;
    $21 = ($18|0)==($20|0);
    if (!($21)) {
     break;
    }
    $22 = (($this) + 84|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==($14|0);
    if (!($24)) {
     break;
    }
   }
   $25 = (($this) + 104|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0);
   if (!($27)) {
    $28 = $14 << 1;
    $29 = ($26|0)==($28|0);
    if (!($29)) {
     break;
    }
    $30 = (($this) + 132|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==($26|0);
    if (!($32)) {
     break;
    }
   }
   $33 = (($this) + 152|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0);
   if (!($35)) {
    $36 = $14 << 2;
    $37 = ($34|0)==($36|0);
    if (!($37)) {
     break;
    }
   }
   $38 = (($this) + 220|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($dest) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 108|0);
   $43 = $39 << 1;
   $44 = (($41) + 112|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$42>>2]|0;
   $47 = $45;
   $48 = $46;
   $49 = (($47) - ($48))|0;
   $50 = ($49>>>0)<($43>>>0);
   if ($50) {
    $51 = (($43) - ($49))|0;
    __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE8__appendEj($42,$51);
    $$pre = HEAP32[$38>>2]|0;
    $66 = $$pre;
   } else {
    $52 = ($49>>>0)>($43>>>0);
    if ($52) {
     $53 = (($46) + ($43)|0);
     $54 = ($45|0)==($53|0);
     if ($54) {
      $66 = $39;
     } else {
      HEAP32[$44>>2] = $53;
      $66 = $39;
     }
    } else {
     $66 = $39;
    }
   }
   $55 = HEAP32[$40>>2]|0;
   $56 = (($55) + 108|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($this) + 224|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = $59&255;
   $61 = (_bitshift64Shl(1,0,($60|0))|0);
   $62 = tempRet0;
   $63 = (_i64Add(($61|0),($62|0),65535,0)|0);
   $64 = tempRet0;
   $65 = ($66|0)==(0);
   if (!($65)) {
    $67 = (($this) + 228|0);
    $bitPos$05$i = 0;$i$06$i = 0;$indexPos$07$i = 0;
    while(1) {
     $68 = (($57) + ($i$06$i<<1)|0);
     HEAP16[$68>>1] = 0;
     $69 = HEAP8[$58>>0]|0;
     $70 = ($69<<24>>24)==(0);
     if ($70) {
      $92 = 0;$bitPos$1$lcssa$i = $bitPos$05$i;$indexPos$1$lcssa$i = $indexPos$07$i;
     } else {
      $$pre$i = HEAP32[$67>>2]|0;
      $77 = 0;$bitPos$11$i = $bitPos$05$i;$bits$02$i = 0;$indexPos$13$i = $indexPos$07$i;
      while(1) {
       $71 = (($$pre$i) + ($indexPos$13$i)|0);
       $72 = HEAP8[$71>>0]|0;
       $73 = $72&255;
       $74 = $73 >>> $bitPos$11$i;
       $75 = $74 << $bits$02$i;
       $76 = $77 & 65535;
       $78 = $75 | $76;
       $79 = $78&65535;
       HEAP16[$68>>1] = $79;
       $80 = HEAP8[$58>>0]|0;
       $81 = $80&255;
       $82 = (($81) - ($bits$02$i))|0;
       $83 = (8 - ($bitPos$11$i))|0;
       $84 = ($83|0)<($82|0);
       $85 = $84 ? $83 : $82;
       $86 = (($85) + ($bitPos$11$i))|0;
       $87 = (($85) + ($bits$02$i))|0;
       $88 = ($86|0)==(8);
       $$$i = $88 ? 0 : $86;
       $89 = $88&1;
       $$indexPos$1$i = (($89) + ($indexPos$13$i))|0;
       $90 = ($87|0)<($81|0);
       if ($90) {
        $77 = $78;$bitPos$11$i = $$$i;$bits$02$i = $87;$indexPos$13$i = $$indexPos$1$i;
       } else {
        break;
       }
      }
      $phitmp$i = $78 & 65535;
      $92 = $phitmp$i;$bitPos$1$lcssa$i = $$$i;$indexPos$1$lcssa$i = $$indexPos$1$i;
     }
     $91 = $92 & $63;
     $93 = $91&65535;
     HEAP16[$68>>1] = $93;
     $94 = (($i$06$i) + 1)|0;
     $exitcond225 = ($94|0)==($66|0);
     if ($exitcond225) {
      break;
     } else {
      $bitPos$05$i = $bitPos$1$lcssa$i;$i$06$i = $94;$indexPos$07$i = $indexPos$1$lcssa$i;
     }
    }
   }
   $95 = HEAP32[$this>>2]|0;
   $96 = (($95|0) / 3)&-1;
   dest=$channelsLayout+0|0; src=588176+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $not$ = ($95|0)!=(0);
   $$ = $not$&1;
   $97 = HEAP32[$17>>2]|0;
   $98 = ($97|0)==(0);
   $99 = $$ | 2;
   $decompressedFormat$1 = $98 ? $$ : $99;
   $100 = (($this) + 240|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($101|0)==(0);
   if ($102) {
    $113 = (($this) + 28|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = ($114|0)==(0);
    $116 = $decompressedFormat$1 | 8;
    $decompressedFormat$1$ = $115 ? $decompressedFormat$1 : $116;
    $117 = $96 << 2;
    $118 = ($114|0)==($117|0);
    $119 = $decompressedFormat$1$ | 16;
    $$decompressedFormat$1$ = $118 ? $119 : $decompressedFormat$1$;
    $decompressedFormat$5 = $$decompressedFormat$1$;
   } else {
    $103 = $101 & 4;
    $104 = ($103|0)==(0);
    if ($104) {
     $decompressedFormat$3 = $decompressedFormat$1;
    } else {
     $105 = $decompressedFormat$1 | 8;
     $106 = $101 & 3;
     $107 = (($106) + 1)|0;
     $108 = $107&255;
     $109 = (($channelsLayout) + 7|0);
     HEAP8[$109>>0] = $108;
     $decompressedFormat$3 = $105;
    }
    $110 = $101 >>> 4;
    $111 = $110 & 4;
    $112 = ($111|0)==(0);
    if ($112) {
     $decompressedFormat$3$1 = $decompressedFormat$3;
    } else {
     $961 = $decompressedFormat$3 | 16;
     $962 = $110 & 3;
     $963 = (($962) + 1)|0;
     $964 = $963&255;
     $965 = (($channelsLayout) + 9|0);
     HEAP8[$965>>0] = $964;
     $decompressedFormat$3$1 = $961;
    }
    $966 = $101 >>> 8;
    $967 = $966 & 4;
    $968 = ($967|0)==(0);
    if ($968) {
     $decompressedFormat$3$2 = $decompressedFormat$3$1;
    } else {
     $969 = $decompressedFormat$3$1 | 32;
     $970 = $966 & 3;
     $971 = (($970) + 1)|0;
     $972 = $971&255;
     $973 = (($channelsLayout) + 11|0);
     HEAP8[$973>>0] = $972;
     $decompressedFormat$3$2 = $969;
    }
    $974 = $101 >>> 12;
    $975 = $974 & 4;
    $976 = ($975|0)==(0);
    if ($976) {
     $decompressedFormat$5 = $decompressedFormat$3$2;
    } else {
     $977 = $decompressedFormat$3$2 | 64;
     $978 = $974 & 3;
     $979 = (($978) + 1)|0;
     $980 = $979&255;
     $981 = (($channelsLayout) + 13|0);
     HEAP8[$981>>0] = $980;
     $decompressedFormat$5 = $977;
    }
   }
   $120 = HEAP32[$25>>2]|0;
   $121 = ($120|0)==(0);
   $122 = $decompressedFormat$5 | 128;
   $decompressedFormat$5$ = $121 ? $decompressedFormat$5 : $122;
   $123 = (($channelsLayout) + 4|0);
   $124 = HEAP32[$33>>2]|0;
   $125 = ($124|0)==(0);
   do {
    if ($125) {
     $decompressedFormat$7 = $decompressedFormat$5$;
    } else {
     $126 = $decompressedFormat$5$ | 4;
     $127 = (($this) + 160|0);
     $128 = Math_fround(HEAPF32[$127>>2]);
     $129 = $128 < Math_fround(0.0);
     if (!($129)) {
      $130 = (($this) + 156|0);
      $131 = Math_fround(HEAPF32[$130>>2]);
      $132 = Math_fround($128 + $131);
      $133 = $132 > Math_fround(1.0);
      if (!($133)) {
       $decompressedFormat$7 = $126;
       break;
      }
     }
     HEAP8[$123>>0] = 0;
     $decompressedFormat$7 = $126;
    }
   } while(0);
   __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayout($dest,$96,$decompressedFormat$7,$decompressedFormat$7,$channelsLayout);
   __ZN4Mesh21UnswizzleVertexColorsEb($dest,0);
   $134 = HEAP32[$40>>2]|0;
   $135 = (($134) + 92|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = (($134) + 8|0);
   $138 = HEAP8[$137>>0]|0;
   $139 = $138&255;
   $140 = ((($134) + (($139*12)|0)|0) + 44|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = (($134) + 9|0);
   $143 = HEAP8[$142>>0]|0;
   $144 = $143&255;
   $145 = (($144) + ($141))|0;
   $146 = (($136) + ($145)|0);
   $147 = ((($134) + (($139*12)|0)|0) + 50|0);
   $148 = HEAP8[$147>>0]|0;
   $149 = $148&255;
   __ZN17PackedFloatVector12UnpackFloatsEPfiiii($this,$146,3,$149,0,-1);
   $150 = (($this) + 28|0);
   $151 = $decompressedFormat$7 & 8;
   $152 = ($151|0)==(0);
   if ($152) {
    $uvSrcOffset$1 = 0;
   } else {
    $153 = (($channelsLayout) + 7|0);
    $154 = HEAP8[$153>>0]|0;
    $155 = $154&255;
    $156 = HEAP32[$40>>2]|0;
    $157 = (($156) + 92|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($156) + 20|0);
    $160 = HEAP8[$159>>0]|0;
    $161 = $160&255;
    $162 = ((($156) + (($161*12)|0)|0) + 44|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = (($156) + 21|0);
    $165 = HEAP8[$164>>0]|0;
    $166 = $165&255;
    $167 = (($166) + ($163))|0;
    $168 = (($158) + ($167)|0);
    $169 = ((($156) + (($161*12)|0)|0) + 50|0);
    $170 = HEAP8[$169>>0]|0;
    $171 = $170&255;
    __ZN17PackedFloatVector12UnpackFloatsEPfiiii($150,$168,$155,$171,0,$96);
    $172 = Math_imul($155, $96)|0;
    $uvSrcOffset$1 = $172;
   }
   $173 = $decompressedFormat$7 & 16;
   $174 = ($173|0)==(0);
   if ($174) {
    $uvSrcOffset$1$1 = $uvSrcOffset$1;
   } else {
    $894 = (($channelsLayout) + 9|0);
    $895 = HEAP8[$894>>0]|0;
    $896 = $895&255;
    $897 = HEAP32[$40>>2]|0;
    $898 = (($897) + 92|0);
    $899 = HEAP32[$898>>2]|0;
    $900 = (($897) + 24|0);
    $901 = HEAP8[$900>>0]|0;
    $902 = $901&255;
    $903 = ((($897) + (($902*12)|0)|0) + 44|0);
    $904 = HEAP32[$903>>2]|0;
    $905 = (($897) + 25|0);
    $906 = HEAP8[$905>>0]|0;
    $907 = $906&255;
    $908 = (($907) + ($904))|0;
    $909 = (($899) + ($908)|0);
    $910 = ((($897) + (($902*12)|0)|0) + 50|0);
    $911 = HEAP8[$910>>0]|0;
    $912 = $911&255;
    __ZN17PackedFloatVector12UnpackFloatsEPfiiii($150,$909,$896,$912,$uvSrcOffset$1,$96);
    $913 = Math_imul($896, $96)|0;
    $914 = (($913) + ($uvSrcOffset$1))|0;
    $uvSrcOffset$1$1 = $914;
   }
   $915 = $decompressedFormat$7 & 32;
   $916 = ($915|0)==(0);
   if ($916) {
    $uvSrcOffset$1$2 = $uvSrcOffset$1$1;
   } else {
    $917 = (($channelsLayout) + 11|0);
    $918 = HEAP8[$917>>0]|0;
    $919 = $918&255;
    $920 = HEAP32[$40>>2]|0;
    $921 = (($920) + 92|0);
    $922 = HEAP32[$921>>2]|0;
    $923 = (($920) + 28|0);
    $924 = HEAP8[$923>>0]|0;
    $925 = $924&255;
    $926 = ((($920) + (($925*12)|0)|0) + 44|0);
    $927 = HEAP32[$926>>2]|0;
    $928 = (($920) + 29|0);
    $929 = HEAP8[$928>>0]|0;
    $930 = $929&255;
    $931 = (($930) + ($927))|0;
    $932 = (($922) + ($931)|0);
    $933 = ((($920) + (($925*12)|0)|0) + 50|0);
    $934 = HEAP8[$933>>0]|0;
    $935 = $934&255;
    __ZN17PackedFloatVector12UnpackFloatsEPfiiii($150,$932,$919,$935,$uvSrcOffset$1$1,$96);
    $936 = Math_imul($919, $96)|0;
    $937 = (($936) + ($uvSrcOffset$1$1))|0;
    $uvSrcOffset$1$2 = $937;
   }
   $938 = $decompressedFormat$7 & 64;
   $939 = ($938|0)==(0);
   if (!($939)) {
    $940 = (($channelsLayout) + 13|0);
    $941 = HEAP8[$940>>0]|0;
    $942 = $941&255;
    $943 = HEAP32[$40>>2]|0;
    $944 = (($943) + 92|0);
    $945 = HEAP32[$944>>2]|0;
    $946 = (($943) + 32|0);
    $947 = HEAP8[$946>>0]|0;
    $948 = $947&255;
    $949 = ((($943) + (($948*12)|0)|0) + 44|0);
    $950 = HEAP32[$949>>2]|0;
    $951 = (($943) + 33|0);
    $952 = HEAP8[$951>>0]|0;
    $953 = $952&255;
    $954 = (($953) + ($950))|0;
    $955 = (($945) + ($954)|0);
    $956 = ((($943) + (($948*12)|0)|0) + 50|0);
    $957 = HEAP8[$956>>0]|0;
    $958 = $957&255;
    __ZN17PackedFloatVector12UnpackFloatsEPfiiii($150,$955,$942,$958,$uvSrcOffset$1$2,$96);
   }
   $959 = HEAP32[$17>>2]|0;
   $960 = ($959|0)==(0);
   L63: do {
    if (!($960)) {
     $175 = HEAP32[628512>>2]|0;
     $176 = $96 << 3;
     HEAP32[$0>>2] = $175;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
     $177 = (__Z15malloc_internaljj10MemLabelIdiPKci($176,4,$$byval_copy20,0,585336,352)|0);
     $178 = (($this) + 84|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = HEAP32[628512>>2]|0;
     $181 = $179 << 2;
     HEAP32[$0>>2] = $180;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
     $182 = (invoke_iiiiiii(102,($181|0),4,($$byval_copy20|0),0,(585336|0),352)|0);
     $183 = __THREW__; __THREW__ = 0;
     $184 = $183&1;
     do {
      if (!($184)) {
       $185 = (($this) + 68|0);
       $186 = HEAP8[$185>>0]|0;
       $187 = (($this) + 60|0);
       $188 = Math_fround(HEAPF32[$187>>2]);
       $189 = +$188;
       $190 = ($186<<24>>24)==(0);
       if ($190) {
        $scale$0$i134 = $189;
       } else {
        $191 = $186&255;
        $192 = 1 << $191;
        $193 = (($192) + -1)|0;
        $194 = (+($193|0));
        $195 = $189 / $194;
        $scale$0$i134 = $195;
       }
       $196 = HEAP32[$17>>2]|0;
       $197 = $196 >>> 1;
       $198 = $197 << 3;
       $199 = (($177) + ($198)|0);
       $200 = ($197|0)==(0);
       L70: do {
        if (!($200)) {
         $201 = (($this) + 64|0);
         $202 = (($this) + 72|0);
         $$018$i136$in = $177;$204 = $186;$bitPos$016$i138 = 0;$indexPos$017$i137 = 0;
         while(1) {
          $203 = $204&255;
          $205 = ($204<<24>>24)==(0);
          if ($205) {
           $bitPos$2$lcssa$i153 = $bitPos$016$i138;$indexPos$2$lcssa$i152 = $indexPos$017$i137;$x$0$lcssa$i151 = 0;
          } else {
           $206 = HEAP32[$202>>2]|0;
           $bitPos$22$i148 = $bitPos$016$i138;$bits$05$i145 = 0;$indexPos$23$i147 = $indexPos$017$i137;$x$04$i146 = 0;
           while(1) {
            $207 = (($206) + ($indexPos$23$i147)|0);
            $208 = HEAP8[$207>>0]|0;
            $209 = $208&255;
            $210 = $209 >>> $bitPos$22$i148;
            $211 = $210 << $bits$05$i145;
            $212 = $211 | $x$04$i146;
            $213 = (($203) - ($bits$05$i145))|0;
            $214 = (8 - ($bitPos$22$i148))|0;
            $215 = ($214|0)<($213|0);
            $216 = $215 ? $214 : $213;
            $217 = (($216) + ($bitPos$22$i148))|0;
            $218 = (($216) + ($bits$05$i145))|0;
            $219 = ($217|0)==(8);
            $$$i149 = $219 ? 0 : $217;
            $220 = $219&1;
            $$indexPos$2$i150 = (($220) + ($indexPos$23$i147))|0;
            $221 = ($218|0)<($203|0);
            if ($221) {
             $bitPos$22$i148 = $$$i149;$bits$05$i145 = $218;$indexPos$23$i147 = $$indexPos$2$i150;$x$04$i146 = $212;
            } else {
             $bitPos$2$lcssa$i153 = $$$i149;$indexPos$2$lcssa$i152 = $$indexPos$2$i150;$x$0$lcssa$i151 = $212;
             break;
            }
           }
          }
          $222 = 1 << $203;
          $223 = (($222) + -1)|0;
          $224 = $x$0$lcssa$i151 & $223;
          $225 = (+($224>>>0));
          $226 = $scale$0$i134 * $225;
          $227 = Math_fround(HEAPF32[$201>>2]);
          $228 = +$227;
          $229 = $226 + $228;
          $230 = Math_fround($229);
          HEAPF32[$$018$i136$in>>2] = $230;
          $231 = HEAP8[$185>>0]|0;
          $232 = $231&255;
          $233 = ($231<<24>>24)==(0);
          if ($233) {
           $bitPos$2$lcssa$i153$1 = $bitPos$2$lcssa$i153;$indexPos$2$lcssa$i152$1 = $indexPos$2$lcssa$i152;$x$0$lcssa$i151$1 = 0;
          } else {
           $866 = HEAP32[$202>>2]|0;
           $bitPos$22$i148$1 = $bitPos$2$lcssa$i153;$bits$05$i145$1 = 0;$indexPos$23$i147$1 = $indexPos$2$lcssa$i152;$x$04$i146$1 = 0;
           while(1) {
            $867 = (($866) + ($indexPos$23$i147$1)|0);
            $868 = HEAP8[$867>>0]|0;
            $869 = $868&255;
            $870 = $869 >>> $bitPos$22$i148$1;
            $871 = $870 << $bits$05$i145$1;
            $872 = $871 | $x$04$i146$1;
            $873 = (($232) - ($bits$05$i145$1))|0;
            $874 = (8 - ($bitPos$22$i148$1))|0;
            $875 = ($874|0)<($873|0);
            $876 = $875 ? $874 : $873;
            $877 = (($876) + ($bitPos$22$i148$1))|0;
            $878 = (($876) + ($bits$05$i145$1))|0;
            $879 = ($877|0)==(8);
            $$$i149$1 = $879 ? 0 : $877;
            $880 = $879&1;
            $$indexPos$2$i150$1 = (($880) + ($indexPos$23$i147$1))|0;
            $881 = ($878|0)<($232|0);
            if ($881) {
             $bitPos$22$i148$1 = $$$i149$1;$bits$05$i145$1 = $878;$indexPos$23$i147$1 = $$indexPos$2$i150$1;$x$04$i146$1 = $872;
            } else {
             $bitPos$2$lcssa$i153$1 = $$$i149$1;$indexPos$2$lcssa$i152$1 = $$indexPos$2$i150$1;$x$0$lcssa$i151$1 = $872;
             break;
            }
           }
          }
          $882 = 1 << $232;
          $883 = (($882) + -1)|0;
          $884 = $x$0$lcssa$i151$1 & $883;
          $885 = (+($884>>>0));
          $886 = $scale$0$i134 * $885;
          $887 = Math_fround(HEAPF32[$201>>2]);
          $888 = +$887;
          $889 = $886 + $888;
          $890 = Math_fround($889);
          $891 = (($$018$i136$in) + 4|0);
          HEAPF32[$891>>2] = $890;
          $892 = (($$018$i136$in) + 8|0);
          $893 = ($892|0)==($199|0);
          if ($893) {
           break L70;
          }
          $$pre227 = HEAP8[$185>>0]|0;
          $$018$i136$in = $892;$204 = $$pre227;$bitPos$016$i138 = $bitPos$2$lcssa$i153$1;$indexPos$017$i137 = $indexPos$2$lcssa$i152$1;
         }
        }
       } while(0);
       $234 = (($this) + 88|0);
       $235 = HEAP8[$234>>0]|0;
       $236 = $235&255;
       $237 = (_bitshift64Shl(1,0,($236|0))|0);
       $238 = tempRet0;
       $239 = (_i64Add(($237|0),($238|0),-1,0)|0);
       $240 = tempRet0;
       $241 = HEAP32[$178>>2]|0;
       $242 = ($241|0)==(0);
       if (!($242)) {
        $243 = (($this) + 92|0);
        $bitPos$05$i122 = 0;$i$06$i121 = 0;$indexPos$07$i120 = 0;
        while(1) {
         $244 = (($182) + ($i$06$i121<<2)|0);
         HEAP32[$244>>2] = 0;
         $245 = HEAP8[$234>>0]|0;
         $246 = ($245<<24>>24)==(0);
         if ($246) {
          $266 = 0;$bitPos$1$lcssa$i131 = $bitPos$05$i122;$indexPos$1$lcssa$i130 = $indexPos$07$i120;
         } else {
          $$pre$i123 = HEAP32[$243>>2]|0;
          $253 = 0;$bitPos$11$i127 = $bitPos$05$i122;$bits$02$i126 = 0;$indexPos$13$i125 = $indexPos$07$i120;
          while(1) {
           $247 = (($$pre$i123) + ($indexPos$13$i125)|0);
           $248 = HEAP8[$247>>0]|0;
           $249 = $248&255;
           $250 = $249 >>> $bitPos$11$i127;
           $251 = $250 << $bits$02$i126;
           $252 = $251 | $253;
           HEAP32[$244>>2] = $252;
           $254 = HEAP8[$234>>0]|0;
           $255 = $254&255;
           $256 = (($255) - ($bits$02$i126))|0;
           $257 = (8 - ($bitPos$11$i127))|0;
           $258 = ($257|0)<($256|0);
           $259 = $258 ? $257 : $256;
           $260 = (($259) + ($bitPos$11$i127))|0;
           $261 = (($259) + ($bits$02$i126))|0;
           $262 = ($260|0)==(8);
           $$$i128 = $262 ? 0 : $260;
           $263 = $262&1;
           $$indexPos$1$i129 = (($263) + ($indexPos$13$i125))|0;
           $264 = ($261|0)<($255|0);
           if ($264) {
            $253 = $252;$bitPos$11$i127 = $$$i128;$bits$02$i126 = $261;$indexPos$13$i125 = $$indexPos$1$i129;
           } else {
            $266 = $252;$bitPos$1$lcssa$i131 = $$$i128;$indexPos$1$lcssa$i130 = $$indexPos$1$i129;
            break;
           }
          }
         }
         $265 = $266 & $239;
         HEAP32[$244>>2] = $265;
         $267 = (($i$06$i121) + 1)|0;
         $268 = HEAP32[$178>>2]|0;
         $269 = ($267>>>0)<($268>>>0);
         if ($269) {
          $bitPos$05$i122 = $bitPos$1$lcssa$i131;$i$06$i121 = $267;$indexPos$07$i120 = $indexPos$1$lcssa$i130;
         } else {
          break;
         }
        }
       }
       $270 = HEAP32[$40>>2]|0;
       $271 = (($270) + 14|0);
       $272 = HEAP8[$271>>0]|0;
       $273 = ($272<<24>>24)==(0);
       do {
        if ($273) {
         $274 = (($270) + 15|0);
         $275 = HEAP8[$274>>0]|0;
         $276 = ($275&255)<(3);
         if ($276) {
          $326 = 0;$982 = 0;
          break;
         }
         $277 = (($270) + 92|0);
         $278 = HEAP32[$277>>2]|0;
         $279 = ($278|0)==(0|0);
         if ($279) {
          $326 = 1;$982 = 0;
          break;
         }
         $280 = (($270) + 12|0);
         $281 = HEAP8[$280>>0]|0;
         $282 = $281&255;
         $283 = ((($270) + (($282*12)|0)|0) + 50|0);
         $284 = HEAP8[$283>>0]|0;
         $285 = $284&255;
         $286 = ((($270) + (($282*12)|0)|0) + 44|0);
         $287 = HEAP32[$286>>2]|0;
         $288 = (($270) + 13|0);
         $289 = HEAP8[$288>>0]|0;
         $290 = $289&255;
         $291 = (($290) + ($287))|0;
         $292 = (($278) + ($291)|0);
         $326 = $285;$982 = $292;
        } else {
         $326 = 0;$982 = 0;
        }
       } while(0);
       $293 = ($95|0)>(2);
       if ($293) {
        $296 = $982;$i$0200 = 0;
        while(1) {
         $294 = (($177) + ($i$0200<<3)|0);
         $295 = Math_fround(HEAPF32[$294>>2]);
         HEAPF32[$296>>2] = $295;
         $297 = ((($177) + ($i$0200<<3)|0) + 4|0);
         $298 = Math_fround(HEAPF32[$297>>2]);
         $299 = (($296) + 4|0);
         HEAPF32[$299>>2] = $298;
         $300 = Math_fround(HEAPF32[$294>>2]);
         $301 = Math_fround($300 * $300);
         $302 = Math_fround(Math_fround(1.0) - $301);
         $303 = Math_fround(HEAPF32[$297>>2]);
         $304 = Math_fround($303 * $303);
         $305 = Math_fround($302 - $304);
         $306 = !($305 >= Math_fround(0.0));
         if ($306) {
          $309 = (($296) + 8|0);
          $310 = Math_fround($295 * $295);
          $311 = Math_fround($298 * $298);
          $312 = Math_fround($310 + $311);
          $313 = Math_fround($312 + Math_fround(0.0));
          $314 = (Math_fround(Math_sqrt((Math_fround($313)))));
          $315 = Math_fround($295 / $314);
          $316 = Math_fround($298 / $314);
          $317 = Math_fround(Math_fround(0.0) / $314);
          HEAPF32[$296>>2] = $315;
          HEAPF32[$299>>2] = $316;
          HEAPF32[$309>>2] = $317;
          $323 = $317;
         } else {
          $307 = (Math_fround(Math_sqrt((Math_fround($305)))));
          $308 = (($296) + 8|0);
          HEAPF32[$308>>2] = $307;
          $323 = $307;
         }
         $318 = (($182) + ($i$0200<<2)|0);
         $319 = HEAP32[$318>>2]|0;
         $320 = ($319|0)==(0);
         if ($320) {
          $321 = (($296) + 8|0);
          $322 = Math_fround(-$323);
          HEAPF32[$321>>2] = $322;
         }
         $324 = (($i$0200) + 1)|0;
         $325 = (($296) + ($326)|0);
         $327 = ($324|0)<($96|0);
         if ($327) {
          $296 = $325;$i$0200 = $324;
         } else {
          break;
         }
        }
       }
       $328 = ($179|0)>(-1);
       if ($328) {
        HEAP32[$1>>2] = $180;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($182|0),($$byval_copy20|0));
        $329 = __THREW__; __THREW__ = 0;
        $330 = $329&1;
        if ($330) {
         break;
        }
       }
       $331 = ($95|0)>(-3);
       if (!($331)) {
        break L63;
       }
       HEAP32[$0>>2] = $175;
       ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId($177,$$byval_copy20);
       break L63;
      }
     } while(0);
     $332 = ___cxa_find_matching_catch()|0;
     $333 = tempRet0;
     $334 = ($95|0)>(-3);
     if (!($334)) {
      $$3 = $333;$$34 = $332;
      ___resumeException($$34|0);
      // unreachable;
     }
     HEAP32[$2>>2] = $175;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($177|0),($$byval_copy20|0));
     $335 = __THREW__; __THREW__ = 0;
     $336 = $335&1;
     if ($336) {
      $836 = ___cxa_find_matching_catch(0|0)|0;
      $837 = tempRet0;
      ___clang_call_terminate($836);
      // unreachable;
     } else {
      $$3 = $333;$$34 = $332;
      ___resumeException($$34|0);
      // unreachable;
     }
    }
   } while(0);
   $337 = HEAP32[$25>>2]|0;
   $338 = ($337|0)==(0);
   L124: do {
    if (!($338)) {
     $339 = HEAP32[628512>>2]|0;
     $340 = $96 << 3;
     HEAP32[$0>>2] = $339;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
     $341 = (__Z15malloc_internaljj10MemLabelIdiPKci($340,4,$$byval_copy20,0,585336,352)|0);
     $342 = (($this) + 132|0);
     $343 = HEAP32[$342>>2]|0;
     $344 = HEAP32[628512>>2]|0;
     $345 = $343 << 2;
     HEAP32[$3>>2] = $344;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$3+0>>2]|0;
     $346 = (invoke_iiiiiii(102,($345|0),4,($$byval_copy20|0),0,(585336|0),352)|0);
     $347 = __THREW__; __THREW__ = 0;
     $348 = $347&1;
     do {
      if (!($348)) {
       $349 = (($this) + 116|0);
       $350 = HEAP8[$349>>0]|0;
       $351 = (($this) + 108|0);
       $352 = Math_fround(HEAPF32[$351>>2]);
       $353 = +$352;
       $354 = ($350<<24>>24)==(0);
       if ($354) {
        $scale$0$i76 = $353;
       } else {
        $355 = $350&255;
        $356 = 1 << $355;
        $357 = (($356) + -1)|0;
        $358 = (+($357|0));
        $359 = $353 / $358;
        $scale$0$i76 = $359;
       }
       $360 = HEAP32[$25>>2]|0;
       $361 = $360 >>> 1;
       $362 = $361 << 3;
       $363 = (($341) + ($362)|0);
       $364 = ($361|0)==(0);
       L131: do {
        if (!($364)) {
         $365 = (($this) + 112|0);
         $366 = (($this) + 120|0);
         $$018$i78$in = $341;$368 = $350;$bitPos$016$i80 = 0;$indexPos$017$i79 = 0;
         while(1) {
          $367 = $368&255;
          $369 = ($368<<24>>24)==(0);
          if ($369) {
           $bitPos$2$lcssa$i95 = $bitPos$016$i80;$indexPos$2$lcssa$i94 = $indexPos$017$i79;$x$0$lcssa$i93 = 0;
          } else {
           $370 = HEAP32[$366>>2]|0;
           $bitPos$22$i90 = $bitPos$016$i80;$bits$05$i87 = 0;$indexPos$23$i89 = $indexPos$017$i79;$x$04$i88 = 0;
           while(1) {
            $371 = (($370) + ($indexPos$23$i89)|0);
            $372 = HEAP8[$371>>0]|0;
            $373 = $372&255;
            $374 = $373 >>> $bitPos$22$i90;
            $375 = $374 << $bits$05$i87;
            $376 = $375 | $x$04$i88;
            $377 = (($367) - ($bits$05$i87))|0;
            $378 = (8 - ($bitPos$22$i90))|0;
            $379 = ($378|0)<($377|0);
            $380 = $379 ? $378 : $377;
            $381 = (($380) + ($bitPos$22$i90))|0;
            $382 = (($380) + ($bits$05$i87))|0;
            $383 = ($381|0)==(8);
            $$$i91 = $383 ? 0 : $381;
            $384 = $383&1;
            $$indexPos$2$i92 = (($384) + ($indexPos$23$i89))|0;
            $385 = ($382|0)<($367|0);
            if ($385) {
             $bitPos$22$i90 = $$$i91;$bits$05$i87 = $382;$indexPos$23$i89 = $$indexPos$2$i92;$x$04$i88 = $376;
            } else {
             $bitPos$2$lcssa$i95 = $$$i91;$indexPos$2$lcssa$i94 = $$indexPos$2$i92;$x$0$lcssa$i93 = $376;
             break;
            }
           }
          }
          $386 = 1 << $367;
          $387 = (($386) + -1)|0;
          $388 = $x$0$lcssa$i93 & $387;
          $389 = (+($388>>>0));
          $390 = $scale$0$i76 * $389;
          $391 = Math_fround(HEAPF32[$365>>2]);
          $392 = +$391;
          $393 = $390 + $392;
          $394 = Math_fround($393);
          HEAPF32[$$018$i78$in>>2] = $394;
          $395 = HEAP8[$349>>0]|0;
          $396 = $395&255;
          $397 = ($395<<24>>24)==(0);
          if ($397) {
           $bitPos$2$lcssa$i95$1 = $bitPos$2$lcssa$i95;$indexPos$2$lcssa$i94$1 = $indexPos$2$lcssa$i94;$x$0$lcssa$i93$1 = 0;
          } else {
           $838 = HEAP32[$366>>2]|0;
           $bitPos$22$i90$1 = $bitPos$2$lcssa$i95;$bits$05$i87$1 = 0;$indexPos$23$i89$1 = $indexPos$2$lcssa$i94;$x$04$i88$1 = 0;
           while(1) {
            $839 = (($838) + ($indexPos$23$i89$1)|0);
            $840 = HEAP8[$839>>0]|0;
            $841 = $840&255;
            $842 = $841 >>> $bitPos$22$i90$1;
            $843 = $842 << $bits$05$i87$1;
            $844 = $843 | $x$04$i88$1;
            $845 = (($396) - ($bits$05$i87$1))|0;
            $846 = (8 - ($bitPos$22$i90$1))|0;
            $847 = ($846|0)<($845|0);
            $848 = $847 ? $846 : $845;
            $849 = (($848) + ($bitPos$22$i90$1))|0;
            $850 = (($848) + ($bits$05$i87$1))|0;
            $851 = ($849|0)==(8);
            $$$i91$1 = $851 ? 0 : $849;
            $852 = $851&1;
            $$indexPos$2$i92$1 = (($852) + ($indexPos$23$i89$1))|0;
            $853 = ($850|0)<($396|0);
            if ($853) {
             $bitPos$22$i90$1 = $$$i91$1;$bits$05$i87$1 = $850;$indexPos$23$i89$1 = $$indexPos$2$i92$1;$x$04$i88$1 = $844;
            } else {
             $bitPos$2$lcssa$i95$1 = $$$i91$1;$indexPos$2$lcssa$i94$1 = $$indexPos$2$i92$1;$x$0$lcssa$i93$1 = $844;
             break;
            }
           }
          }
          $854 = 1 << $396;
          $855 = (($854) + -1)|0;
          $856 = $x$0$lcssa$i93$1 & $855;
          $857 = (+($856>>>0));
          $858 = $scale$0$i76 * $857;
          $859 = Math_fround(HEAPF32[$365>>2]);
          $860 = +$859;
          $861 = $858 + $860;
          $862 = Math_fround($861);
          $863 = (($$018$i78$in) + 4|0);
          HEAPF32[$863>>2] = $862;
          $864 = (($$018$i78$in) + 8|0);
          $865 = ($864|0)==($363|0);
          if ($865) {
           break L131;
          }
          $$pre226 = HEAP8[$349>>0]|0;
          $$018$i78$in = $864;$368 = $$pre226;$bitPos$016$i80 = $bitPos$2$lcssa$i95$1;$indexPos$017$i79 = $indexPos$2$lcssa$i94$1;
         }
        }
       } while(0);
       $398 = (($this) + 136|0);
       $399 = HEAP8[$398>>0]|0;
       $400 = $399&255;
       $401 = (_bitshift64Shl(1,0,($400|0))|0);
       $402 = tempRet0;
       $403 = (_i64Add(($401|0),($402|0),-1,0)|0);
       $404 = tempRet0;
       $405 = HEAP32[$342>>2]|0;
       $406 = ($405|0)==(0);
       if (!($406)) {
        $407 = (($this) + 140|0);
        $bitPos$05$i64 = 0;$i$06$i63 = 0;$indexPos$07$i62 = 0;
        while(1) {
         $408 = (($346) + ($i$06$i63<<2)|0);
         HEAP32[$408>>2] = 0;
         $409 = HEAP8[$398>>0]|0;
         $410 = ($409<<24>>24)==(0);
         if ($410) {
          $430 = 0;$bitPos$1$lcssa$i73 = $bitPos$05$i64;$indexPos$1$lcssa$i72 = $indexPos$07$i62;
         } else {
          $$pre$i65 = HEAP32[$407>>2]|0;
          $417 = 0;$bitPos$11$i69 = $bitPos$05$i64;$bits$02$i68 = 0;$indexPos$13$i67 = $indexPos$07$i62;
          while(1) {
           $411 = (($$pre$i65) + ($indexPos$13$i67)|0);
           $412 = HEAP8[$411>>0]|0;
           $413 = $412&255;
           $414 = $413 >>> $bitPos$11$i69;
           $415 = $414 << $bits$02$i68;
           $416 = $415 | $417;
           HEAP32[$408>>2] = $416;
           $418 = HEAP8[$398>>0]|0;
           $419 = $418&255;
           $420 = (($419) - ($bits$02$i68))|0;
           $421 = (8 - ($bitPos$11$i69))|0;
           $422 = ($421|0)<($420|0);
           $423 = $422 ? $421 : $420;
           $424 = (($423) + ($bitPos$11$i69))|0;
           $425 = (($423) + ($bits$02$i68))|0;
           $426 = ($424|0)==(8);
           $$$i70 = $426 ? 0 : $424;
           $427 = $426&1;
           $$indexPos$1$i71 = (($427) + ($indexPos$13$i67))|0;
           $428 = ($425|0)<($419|0);
           if ($428) {
            $417 = $416;$bitPos$11$i69 = $$$i70;$bits$02$i68 = $425;$indexPos$13$i67 = $$indexPos$1$i71;
           } else {
            $430 = $416;$bitPos$1$lcssa$i73 = $$$i70;$indexPos$1$lcssa$i72 = $$indexPos$1$i71;
            break;
           }
          }
         }
         $429 = $430 & $403;
         HEAP32[$408>>2] = $429;
         $431 = (($i$06$i63) + 1)|0;
         $432 = HEAP32[$342>>2]|0;
         $433 = ($431>>>0)<($432>>>0);
         if ($433) {
          $bitPos$05$i64 = $bitPos$1$lcssa$i73;$i$06$i63 = $431;$indexPos$07$i62 = $indexPos$1$lcssa$i72;
         } else {
          break;
         }
        }
       }
       $434 = HEAP32[$40>>2]|0;
       $435 = (($434) + 38|0);
       $436 = HEAP8[$435>>0]|0;
       $437 = ($436<<24>>24)==(0);
       do {
        if ($437) {
         $438 = (($434) + 39|0);
         $439 = HEAP8[$438>>0]|0;
         $440 = ($439&255)<(4);
         if ($440) {
          $497 = 0;$983 = 0;
          break;
         }
         $441 = (($434) + 92|0);
         $442 = HEAP32[$441>>2]|0;
         $443 = ($442|0)==(0|0);
         if ($443) {
          $497 = 1;$983 = 0;
          break;
         }
         $444 = (($434) + 36|0);
         $445 = HEAP8[$444>>0]|0;
         $446 = $445&255;
         $447 = ((($434) + (($446*12)|0)|0) + 50|0);
         $448 = HEAP8[$447>>0]|0;
         $449 = $448&255;
         $450 = ((($434) + (($446*12)|0)|0) + 44|0);
         $451 = HEAP32[$450>>2]|0;
         $452 = (($434) + 37|0);
         $453 = HEAP8[$452>>0]|0;
         $454 = $453&255;
         $455 = (($454) + ($451))|0;
         $456 = (($442) + ($455)|0);
         $497 = $449;$983 = $456;
        } else {
         $497 = 0;$983 = 0;
        }
       } while(0);
       $457 = ($95|0)>(2);
       if ($457) {
        $460 = $983;$i4$0195 = 0;
        while(1) {
         $458 = (($341) + ($i4$0195<<3)|0);
         $459 = Math_fround(HEAPF32[$458>>2]);
         HEAPF32[$460>>2] = $459;
         $461 = ((($341) + ($i4$0195<<3)|0) + 4|0);
         $462 = Math_fround(HEAPF32[$461>>2]);
         $463 = (($460) + 4|0);
         HEAPF32[$463>>2] = $462;
         $464 = Math_fround(HEAPF32[$458>>2]);
         $465 = Math_fround($464 * $464);
         $466 = Math_fround(Math_fround(1.0) - $465);
         $467 = Math_fround(HEAPF32[$461>>2]);
         $468 = Math_fround($467 * $467);
         $469 = Math_fround($466 - $468);
         $470 = !($469 >= Math_fround(0.0));
         if ($470) {
          $473 = (($460) + 8|0);
          $474 = Math_fround($459 * $459);
          $475 = Math_fround($462 * $462);
          $476 = Math_fround($474 + $475);
          $477 = Math_fround($476 + Math_fround(0.0));
          $478 = (Math_fround(Math_sqrt((Math_fround($477)))));
          $479 = Math_fround($459 / $478);
          $480 = Math_fround($462 / $478);
          $481 = Math_fround(Math_fround(0.0) / $478);
          HEAPF32[$460>>2] = $479;
          HEAPF32[$463>>2] = $480;
          HEAPF32[$473>>2] = $481;
          $488 = $481;
         } else {
          $471 = (Math_fround(Math_sqrt((Math_fround($469)))));
          $472 = (($460) + 8|0);
          HEAPF32[$472>>2] = $471;
          $488 = $471;
         }
         $482 = $i4$0195 << 1;
         $483 = (($346) + ($482<<2)|0);
         $484 = HEAP32[$483>>2]|0;
         $485 = ($484|0)==(0);
         if ($485) {
          $486 = (($460) + 8|0);
          $487 = Math_fround(-$488);
          HEAPF32[$486>>2] = $487;
         }
         $489 = $482 | 1;
         $490 = (($346) + ($489<<2)|0);
         $491 = HEAP32[$490>>2]|0;
         $492 = ($491|0)!=(0);
         $493 = $492 ? Math_fround(1.0) : Math_fround(-1.0);
         $494 = (($460) + 12|0);
         HEAPF32[$494>>2] = $493;
         $495 = (($i4$0195) + 1)|0;
         $496 = (($460) + ($497)|0);
         $498 = ($495|0)<($96|0);
         if ($498) {
          $460 = $496;$i4$0195 = $495;
         } else {
          break;
         }
        }
       }
       $499 = ($343|0)>(-1);
       if ($499) {
        HEAP32[$4>>2] = $344;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$4+0>>2]|0;
        invoke_vii(2591,($346|0),($$byval_copy20|0));
        $500 = __THREW__; __THREW__ = 0;
        $501 = $500&1;
        if ($501) {
         break;
        }
       }
       $502 = ($95|0)>(-3);
       if (!($502)) {
        break L124;
       }
       HEAP32[$0>>2] = $339;
       ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId($341,$$byval_copy20);
       break L124;
      }
     } while(0);
     $503 = ___cxa_find_matching_catch()|0;
     $504 = tempRet0;
     $505 = ($95|0)>(-3);
     if (!($505)) {
      $$3 = $504;$$34 = $503;
      ___resumeException($$34|0);
      // unreachable;
     }
     HEAP32[$5>>2] = $339;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($341|0),($$byval_copy20|0));
     $506 = __THREW__; __THREW__ = 0;
     $507 = $506&1;
     if ($507) {
      $836 = ___cxa_find_matching_catch(0|0)|0;
      $837 = tempRet0;
      ___clang_call_terminate($836);
      // unreachable;
     } else {
      $$3 = $504;$$34 = $503;
      ___resumeException($$34|0);
      // unreachable;
     }
    }
   } while(0);
   $508 = HEAP32[$33>>2]|0;
   $509 = ($508|0)==(0);
   do {
    if (!($509)) {
     $510 = HEAP32[628512>>2]|0;
     $511 = $96 << 4;
     HEAP32[$0>>2] = $510;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
     $512 = (__Z15malloc_internaljj10MemLabelIdiPKci($511,4,$$byval_copy20,0,585336,352)|0);
     $513 = (($this) + 164|0);
     $514 = HEAP8[$513>>0]|0;
     $515 = (($this) + 156|0);
     $516 = Math_fround(HEAPF32[$515>>2]);
     $517 = +$516;
     $518 = ($514<<24>>24)==(0);
     if ($518) {
      $scale$0$i = $517;
     } else {
      $519 = $514&255;
      $520 = 1 << $519;
      $521 = (($520) + -1)|0;
      $522 = (+($521|0));
      $523 = $517 / $522;
      $scale$0$i = $523;
     }
     $524 = HEAP32[$33>>2]|0;
     $525 = $524 >>> 2;
     $526 = $525 << 4;
     $527 = (($512) + ($526)|0);
     $528 = ($525|0)==(0);
     if (!($528)) {
      $529 = (($this) + 160|0);
      $530 = (($this) + 168|0);
      $$018$i$in = $512;$bitPos$016$i = 0;$indexPos$017$i = 0;
      while(1) {
       $bitPos$110$i = $bitPos$016$i;$i$012$i = 0;$indexPos$111$i = $indexPos$017$i;
       while(1) {
        $531 = HEAP8[$513>>0]|0;
        $532 = $531&255;
        $533 = ($531<<24>>24)==(0);
        if ($533) {
         $bitPos$2$lcssa$i = $bitPos$110$i;$indexPos$2$lcssa$i = $indexPos$111$i;$x$0$lcssa$i = 0;
        } else {
         $534 = HEAP32[$530>>2]|0;
         $bitPos$22$i = $bitPos$110$i;$bits$05$i = 0;$indexPos$23$i = $indexPos$111$i;$x$04$i = 0;
         while(1) {
          $535 = (($534) + ($indexPos$23$i)|0);
          $536 = HEAP8[$535>>0]|0;
          $537 = $536&255;
          $538 = $537 >>> $bitPos$22$i;
          $539 = $538 << $bits$05$i;
          $540 = $539 | $x$04$i;
          $541 = (($532) - ($bits$05$i))|0;
          $542 = (8 - ($bitPos$22$i))|0;
          $543 = ($542|0)<($541|0);
          $544 = $543 ? $542 : $541;
          $545 = (($544) + ($bitPos$22$i))|0;
          $546 = (($544) + ($bits$05$i))|0;
          $547 = ($545|0)==(8);
          $$$i51 = $547 ? 0 : $545;
          $548 = $547&1;
          $$indexPos$2$i = (($548) + ($indexPos$23$i))|0;
          $549 = ($546|0)<($532|0);
          if ($549) {
           $bitPos$22$i = $$$i51;$bits$05$i = $546;$indexPos$23$i = $$indexPos$2$i;$x$04$i = $540;
          } else {
           $bitPos$2$lcssa$i = $$$i51;$indexPos$2$lcssa$i = $$indexPos$2$i;$x$0$lcssa$i = $540;
           break;
          }
         }
        }
        $550 = 1 << $532;
        $551 = (($550) + -1)|0;
        $552 = $x$0$lcssa$i & $551;
        $553 = (+($552>>>0));
        $554 = $scale$0$i * $553;
        $555 = Math_fround(HEAPF32[$529>>2]);
        $556 = +$555;
        $557 = $554 + $556;
        $558 = Math_fround($557);
        $559 = (($$018$i$in) + ($i$012$i<<2)|0);
        HEAPF32[$559>>2] = $558;
        $560 = (($i$012$i) + 1)|0;
        $exitcond$i = ($560|0)==(4);
        if ($exitcond$i) {
         break;
        } else {
         $bitPos$110$i = $bitPos$2$lcssa$i;$i$012$i = $560;$indexPos$111$i = $indexPos$2$lcssa$i;
        }
       }
       $561 = (($$018$i$in) + 16|0);
       $562 = ($561|0)==($527|0);
       if ($562) {
        break;
       } else {
        $$018$i$in = $561;$bitPos$016$i = $bitPos$2$lcssa$i;$indexPos$017$i = $indexPos$2$lcssa$i;
       }
      }
     }
     $563 = HEAP8[$123>>0]|0;
     $564 = ($563<<24>>24)==(2);
     $565 = (($512) + ($96<<4)|0);
     $566 = HEAP32[$40>>2]|0;
     $567 = (($566) + 18|0);
     $568 = HEAP8[$567>>0]|0;
     do {
      if ($564) {
       $569 = ($568<<24>>24)==(2);
       do {
        if ($569) {
         $570 = (($566) + 19|0);
         $571 = HEAP8[$570>>0]|0;
         $572 = ($571&255)<(4);
         if ($572) {
          $631 = 0;$984 = 0;
          break;
         }
         $573 = (($566) + 92|0);
         $574 = HEAP32[$573>>2]|0;
         $575 = ($574|0)==(0|0);
         if ($575) {
          $631 = 1;$984 = 0;
          break;
         }
         $576 = (($566) + 16|0);
         $577 = HEAP8[$576>>0]|0;
         $578 = $577&255;
         $579 = ((($566) + (($578*12)|0)|0) + 50|0);
         $580 = HEAP8[$579>>0]|0;
         $581 = $580&255;
         $582 = ((($566) + (($578*12)|0)|0) + 44|0);
         $583 = HEAP32[$582>>2]|0;
         $584 = (($566) + 17|0);
         $585 = HEAP8[$584>>0]|0;
         $586 = $585&255;
         $587 = (($586) + ($583))|0;
         $588 = (($574) + ($587)|0);
         $631 = $581;$984 = $588;
        } else {
         $631 = 0;$984 = 0;
        }
       } while(0);
       $589 = ($512|0)==($565|0);
       if (!($589)) {
        $$01$i$i48 = $512;$598 = $984;
        while(1) {
         $590 = Math_fround(HEAPF32[$$01$i$i48>>2]);
         $591 = $590 < Math_fround(0.0);
         $592 = $591 ? Math_fround(0.0) : $590;
         $593 = $592 > Math_fround(1.0);
         $$op$i$i$i$i$i = Math_fround($592 * Math_fround(255.0));
         $594 = $593 ? Math_fround(255.0) : $$op$i$i$i$i$i;
         $595 = Math_fround($594 + Math_fround(0.5));
         $596 = (~~(($595))>>>0);
         $597 = $596&255;
         HEAP8[$598>>0] = $597;
         $599 = (($$01$i$i48) + 4|0);
         $600 = Math_fround(HEAPF32[$599>>2]);
         $601 = $600 < Math_fround(0.0);
         $602 = $601 ? Math_fround(0.0) : $600;
         $603 = $602 > Math_fround(1.0);
         $$op$i3$i$i$i$i = Math_fround($602 * Math_fround(255.0));
         $604 = $603 ? Math_fround(255.0) : $$op$i3$i$i$i$i;
         $605 = Math_fround($604 + Math_fround(0.5));
         $606 = (~~(($605))>>>0);
         $607 = $606&255;
         $608 = (($598) + 1|0);
         HEAP8[$608>>0] = $607;
         $609 = (($$01$i$i48) + 8|0);
         $610 = Math_fround(HEAPF32[$609>>2]);
         $611 = $610 < Math_fround(0.0);
         $612 = $611 ? Math_fround(0.0) : $610;
         $613 = $612 > Math_fround(1.0);
         $$op$i2$i$i$i$i = Math_fround($612 * Math_fround(255.0));
         $614 = $613 ? Math_fround(255.0) : $$op$i2$i$i$i$i;
         $615 = Math_fround($614 + Math_fround(0.5));
         $616 = (~~(($615))>>>0);
         $617 = $616&255;
         $618 = (($598) + 2|0);
         HEAP8[$618>>0] = $617;
         $619 = (($$01$i$i48) + 12|0);
         $620 = Math_fround(HEAPF32[$619>>2]);
         $621 = $620 < Math_fround(0.0);
         $622 = $621 ? Math_fround(0.0) : $620;
         $623 = $622 > Math_fround(1.0);
         $$op$i1$i$i$i$i = Math_fround($622 * Math_fround(255.0));
         $624 = $623 ? Math_fround(255.0) : $$op$i1$i$i$i$i;
         $625 = Math_fround($624 + Math_fround(0.5));
         $626 = (~~(($625))>>>0);
         $627 = $626&255;
         $628 = (($598) + 3|0);
         HEAP8[$628>>0] = $627;
         $629 = (($$01$i$i48) + 16|0);
         $630 = (($598) + ($631)|0);
         $632 = ($629|0)==($565|0);
         if ($632) {
          break;
         } else {
          $$01$i$i48 = $629;$598 = $630;
         }
        }
       }
       __THREW__ = 0;
       invoke_vii(2665,($dest|0),1);
       $633 = __THREW__; __THREW__ = 0;
       $634 = $633&1;
       if (!($634)) {
        break;
       }
       $635 = ___cxa_find_matching_catch()|0;
       $636 = tempRet0;
       $637 = ($95|0)>(-3);
       if (!($637)) {
        $$3 = $636;$$34 = $635;
        ___resumeException($$34|0);
        // unreachable;
       }
       HEAP32[$6>>2] = $510;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$6+0>>2]|0;
       invoke_vii(2591,($512|0),($$byval_copy20|0));
       $638 = __THREW__; __THREW__ = 0;
       $639 = $638&1;
       if ($639) {
        $836 = ___cxa_find_matching_catch(0|0)|0;
        $837 = tempRet0;
        ___clang_call_terminate($836);
        // unreachable;
       } else {
        $$3 = $636;$$34 = $635;
        ___resumeException($$34|0);
        // unreachable;
       }
      } else {
       $640 = ($568<<24>>24)==(0);
       do {
        if ($640) {
         $641 = (($566) + 19|0);
         $642 = HEAP8[$641>>0]|0;
         $643 = ($642&255)<(4);
         if ($643) {
          $674 = 0;$985 = 0;
          break;
         }
         $644 = (($566) + 92|0);
         $645 = HEAP32[$644>>2]|0;
         $646 = ($645|0)==(0|0);
         if ($646) {
          $674 = 1;$985 = 0;
          break;
         }
         $647 = (($566) + 16|0);
         $648 = HEAP8[$647>>0]|0;
         $649 = $648&255;
         $650 = ((($566) + (($649*12)|0)|0) + 50|0);
         $651 = HEAP8[$650>>0]|0;
         $652 = $651&255;
         $653 = ((($566) + (($649*12)|0)|0) + 44|0);
         $654 = HEAP32[$653>>2]|0;
         $655 = (($566) + 17|0);
         $656 = HEAP8[$655>>0]|0;
         $657 = $656&255;
         $658 = (($657) + ($654))|0;
         $659 = (($645) + ($658)|0);
         $674 = $652;$985 = $659;
        } else {
         $674 = 0;$985 = 0;
        }
       } while(0);
       $660 = ($512|0)==($565|0);
       if ($660) {
        break;
       } else {
        $$01$i$i = $512;$668 = $985;
       }
       while(1) {
        $661 = Math_fround(HEAPF32[$$01$i$i>>2]);
        $662 = (($$01$i$i) + 4|0);
        $663 = Math_fround(HEAPF32[$662>>2]);
        $664 = (($$01$i$i) + 8|0);
        $665 = Math_fround(HEAPF32[$664>>2]);
        $666 = (($$01$i$i) + 12|0);
        $667 = Math_fround(HEAPF32[$666>>2]);
        HEAPF32[$668>>2] = $661;
        $669 = (($668) + 4|0);
        HEAPF32[$669>>2] = $663;
        $670 = (($668) + 8|0);
        HEAPF32[$670>>2] = $665;
        $671 = (($668) + 12|0);
        HEAPF32[$671>>2] = $667;
        $672 = (($$01$i$i) + 16|0);
        $673 = (($668) + ($674)|0);
        $675 = ($672|0)==($565|0);
        if ($675) {
         break;
        } else {
         $$01$i$i = $672;$668 = $673;
        }
       }
      }
     } while(0);
     $676 = ($95|0)>(-3);
     if (!($676)) {
      break;
     }
     HEAP32[$0>>2] = $510;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($512,$$byval_copy20);
    }
   } while(0);
   $677 = (($this) + 180|0);
   $678 = HEAP32[$677>>2]|0;
   $679 = ($678|0)==(0);
   if ($679) {
    STACKTOP = sp;return;
   }
   $680 = HEAP32[628512>>2]|0;
   $681 = $678 << 2;
   HEAP32[$0>>2] = $680;
   ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
   $682 = (__Z15malloc_internaljj10MemLabelIdiPKci($681,4,$$byval_copy20,0,585336,352)|0);
   $683 = (($this) + 184|0);
   $684 = HEAP8[$683>>0]|0;
   $685 = $684&255;
   $686 = (_bitshift64Shl(1,0,($685|0))|0);
   $687 = tempRet0;
   $688 = (_i64Add(($686|0),($687|0),-1,0)|0);
   $689 = tempRet0;
   $690 = HEAP32[$677>>2]|0;
   $691 = ($690|0)==(0);
   if (!($691)) {
    $692 = (($this) + 188|0);
    $bitPos$05$i32 = 0;$i$06$i31 = 0;$indexPos$07$i30 = 0;
    while(1) {
     $693 = (($682) + ($i$06$i31<<2)|0);
     HEAP32[$693>>2] = 0;
     $694 = HEAP8[$683>>0]|0;
     $695 = ($694<<24>>24)==(0);
     if ($695) {
      $715 = 0;$bitPos$1$lcssa$i41 = $bitPos$05$i32;$indexPos$1$lcssa$i40 = $indexPos$07$i30;
     } else {
      $$pre$i33 = HEAP32[$692>>2]|0;
      $702 = 0;$bitPos$11$i37 = $bitPos$05$i32;$bits$02$i36 = 0;$indexPos$13$i35 = $indexPos$07$i30;
      while(1) {
       $696 = (($$pre$i33) + ($indexPos$13$i35)|0);
       $697 = HEAP8[$696>>0]|0;
       $698 = $697&255;
       $699 = $698 >>> $bitPos$11$i37;
       $700 = $699 << $bits$02$i36;
       $701 = $700 | $702;
       HEAP32[$693>>2] = $701;
       $703 = HEAP8[$683>>0]|0;
       $704 = $703&255;
       $705 = (($704) - ($bits$02$i36))|0;
       $706 = (8 - ($bitPos$11$i37))|0;
       $707 = ($706|0)<($705|0);
       $708 = $707 ? $706 : $705;
       $709 = (($708) + ($bitPos$11$i37))|0;
       $710 = (($708) + ($bits$02$i36))|0;
       $711 = ($709|0)==(8);
       $$$i38 = $711 ? 0 : $709;
       $712 = $711&1;
       $$indexPos$1$i39 = (($712) + ($indexPos$13$i35))|0;
       $713 = ($710|0)<($704|0);
       if ($713) {
        $702 = $701;$bitPos$11$i37 = $$$i38;$bits$02$i36 = $710;$indexPos$13$i35 = $$indexPos$1$i39;
       } else {
        $715 = $701;$bitPos$1$lcssa$i41 = $$$i38;$indexPos$1$lcssa$i40 = $$indexPos$1$i39;
        break;
       }
      }
     }
     $714 = $715 & $688;
     HEAP32[$693>>2] = $714;
     $716 = (($i$06$i31) + 1)|0;
     $717 = HEAP32[$677>>2]|0;
     $718 = ($716>>>0)<($717>>>0);
     if ($718) {
      $bitPos$05$i32 = $bitPos$1$lcssa$i41;$i$06$i31 = $716;$indexPos$07$i30 = $indexPos$1$lcssa$i40;
     } else {
      break;
     }
    }
   }
   $719 = (($this) + 200|0);
   $720 = HEAP32[$719>>2]|0;
   $721 = HEAP32[628512>>2]|0;
   $722 = $720 << 2;
   HEAP32[$7>>2] = $721;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$7+0>>2]|0;
   $723 = (invoke_iiiiiii(102,($722|0),4,($$byval_copy20|0),0,(585336|0),352)|0);
   $724 = __THREW__; __THREW__ = 0;
   $725 = $724&1;
   L245: do {
    if ($725) {
     label = 154;
    } else {
     $726 = (($this) + 204|0);
     $727 = HEAP8[$726>>0]|0;
     $728 = $727&255;
     $729 = (_bitshift64Shl(1,0,($728|0))|0);
     $730 = tempRet0;
     $731 = (_i64Add(($729|0),($730|0),-1,0)|0);
     $732 = tempRet0;
     $733 = HEAP32[$719>>2]|0;
     $734 = ($733|0)==(0);
     if (!($734)) {
      $735 = (($this) + 208|0);
      $bitPos$05$i16 = 0;$i$06$i15 = 0;$indexPos$07$i14 = 0;
      while(1) {
       $736 = (($723) + ($i$06$i15<<2)|0);
       HEAP32[$736>>2] = 0;
       $737 = HEAP8[$726>>0]|0;
       $738 = ($737<<24>>24)==(0);
       if ($738) {
        $758 = 0;$bitPos$1$lcssa$i25 = $bitPos$05$i16;$indexPos$1$lcssa$i24 = $indexPos$07$i14;
       } else {
        $$pre$i17 = HEAP32[$735>>2]|0;
        $745 = 0;$bitPos$11$i21 = $bitPos$05$i16;$bits$02$i20 = 0;$indexPos$13$i19 = $indexPos$07$i14;
        while(1) {
         $739 = (($$pre$i17) + ($indexPos$13$i19)|0);
         $740 = HEAP8[$739>>0]|0;
         $741 = $740&255;
         $742 = $741 >>> $bitPos$11$i21;
         $743 = $742 << $bits$02$i20;
         $744 = $743 | $745;
         HEAP32[$736>>2] = $744;
         $746 = HEAP8[$726>>0]|0;
         $747 = $746&255;
         $748 = (($747) - ($bits$02$i20))|0;
         $749 = (8 - ($bitPos$11$i21))|0;
         $750 = ($749|0)<($748|0);
         $751 = $750 ? $749 : $748;
         $752 = (($751) + ($bitPos$11$i21))|0;
         $753 = (($751) + ($bits$02$i20))|0;
         $754 = ($752|0)==(8);
         $$$i22 = $754 ? 0 : $752;
         $755 = $754&1;
         $$indexPos$1$i23 = (($755) + ($indexPos$13$i19))|0;
         $756 = ($753|0)<($747|0);
         if ($756) {
          $745 = $744;$bitPos$11$i21 = $$$i22;$bits$02$i20 = $753;$indexPos$13$i19 = $$indexPos$1$i23;
         } else {
          $758 = $744;$bitPos$1$lcssa$i25 = $$$i22;$indexPos$1$lcssa$i24 = $$indexPos$1$i23;
          break;
         }
        }
       }
       $757 = $758 & $731;
       HEAP32[$736>>2] = $757;
       $759 = (($i$06$i15) + 1)|0;
       $760 = HEAP32[$719>>2]|0;
       $761 = ($759>>>0)<($760>>>0);
       if ($761) {
        $bitPos$05$i16 = $bitPos$1$lcssa$i25;$i$06$i15 = $759;$indexPos$07$i14 = $indexPos$1$lcssa$i24;
       } else {
        break;
       }
      }
     }
     $762 = HEAP32[$40>>2]|0;
     $763 = (($762) + 136|0);
     $764 = (($762) + 144|0);
     HEAP32[$764>>2] = $96;
     $765 = (($762) + 148|0);
     $766 = HEAP32[$765>>2]|0;
     $767 = $766 & 2147483647;
     $768 = ($767>>>0)<($96>>>0);
     L257: do {
      if ($768) {
       $769 = ($766|0)>(-1);
       do {
        if ($769) {
         HEAP32[$765>>2] = $96;
         $770 = HEAP32[$763>>2]|0;
         $771 = $96 << 5;
         $772 = (($762) + 140|0);
         $773 = HEAP32[$772>>2]|0;
         HEAP32[$8>>2] = $773;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$8+0>>2]|0;
         $774 = (invoke_iiiiiiii(108,($770|0),($771|0),16,($$byval_copy20|0),0,(585336|0),370)|0);
         $775 = __THREW__; __THREW__ = 0;
         $776 = $775&1;
         if ($776) {
          break;
         }
         HEAP32[$763>>2] = $774;
         break L257;
        } else {
         $777 = $96 << 5;
         $778 = (($762) + 140|0);
         $779 = HEAP32[$778>>2]|0;
         HEAP32[$9>>2] = $779;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$9+0>>2]|0;
         $780 = (invoke_iiiiiii(102,($777|0),16,($$byval_copy20|0),0,(585336|0),352)|0);
         $781 = __THREW__; __THREW__ = 0;
         $782 = $781&1;
         if ($782) {
          break;
         }
         $783 = HEAP32[$763>>2]|0;
         $784 = HEAP32[$764>>2]|0;
         $785 = $784 << 5;
         _memcpy(($780|0),($783|0),($785|0))|0;
         HEAP32[$765>>2] = $96;
         HEAP32[$763>>2] = $780;
         break L257;
        }
       } while(0);
       $809 = ___cxa_find_matching_catch()|0;
       $810 = tempRet0;
       $811 = ($720|0)>(-1);
       if (!($811)) {
        $$2 = $810;$$23 = $809;
        break L245;
       }
       HEAP32[$10>>2] = $721;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$10+0>>2]|0;
       invoke_vii(2591,($723|0),($$byval_copy20|0));
       $812 = __THREW__; __THREW__ = 0;
       $813 = $812&1;
       if (!($813)) {
        $$2 = $810;$$23 = $809;
        break L245;
       }
       $836 = ___cxa_find_matching_catch(0|0)|0;
       $837 = tempRet0;
       ___clang_call_terminate($836);
       // unreachable;
      }
     } while(0);
     $786 = HEAP32[$677>>2]|0;
     $787 = ($786|0)>(0);
     if ($787) {
      $788 = HEAP32[$763>>2]|0;
      $boneIndexPos$0188 = 0;$bonePos$0186 = 0;$i6$0191 = 0;$j$0189 = 0;$sum$0190 = 0;
      while(1) {
       $789 = (($682) + ($i6$0191<<2)|0);
       $790 = HEAP32[$789>>2]|0;
       $791 = (+($790>>>0));
       $792 = $791 / 31.0;
       $793 = Math_fround($792);
       $794 = ((($788) + ($bonePos$0186<<5)|0) + ($j$0189<<2)|0);
       HEAPF32[$794>>2] = $793;
       $795 = (($boneIndexPos$0188) + 1)|0;
       $796 = (($723) + ($boneIndexPos$0188<<2)|0);
       $797 = HEAP32[$796>>2]|0;
       $798 = (((($788) + ($bonePos$0186<<5)|0) + ($j$0189<<2)|0) + 16|0);
       HEAP32[$798>>2] = $797;
       $799 = (($j$0189) + 1)|0;
       $800 = HEAP32[$789>>2]|0;
       $801 = (($800) + ($sum$0190))|0;
       $802 = ($801|0)>(30);
       do {
        if ($802) {
         $803 = ($799|0)<(4);
         if ($803) {
          $j$1185 = $799;
          while(1) {
           $804 = ((($788) + ($bonePos$0186<<5)|0) + ($j$1185<<2)|0);
           HEAPF32[$804>>2] = Math_fround(0.0);
           $805 = (((($788) + ($bonePos$0186<<5)|0) + ($j$1185<<2)|0) + 16|0);
           HEAP32[$805>>2] = 0;
           $806 = (($j$1185) + 1)|0;
           $exitcond = ($806|0)==(4);
           if ($exitcond) {
            break;
           } else {
            $j$1185 = $806;
           }
          }
         }
         $814 = (($bonePos$0186) + 1)|0;
         $boneIndexPos$1 = $795;$bonePos$1 = $814;$j$2 = 0;$sum$1 = 0;
        } else {
         $815 = ($799|0)==(3);
         if (!($815)) {
          $boneIndexPos$1 = $795;$bonePos$1 = $bonePos$0186;$j$2 = $799;$sum$1 = $801;
          break;
         }
         $816 = (31 - ($801))|0;
         $817 = (+($816|0));
         $818 = $817 / 31.0;
         $819 = Math_fround($818);
         $820 = ((($788) + ($bonePos$0186<<5)|0) + 12|0);
         HEAPF32[$820>>2] = $819;
         $821 = (($boneIndexPos$0188) + 2)|0;
         $822 = (($723) + ($795<<2)|0);
         $823 = HEAP32[$822>>2]|0;
         $824 = ((($788) + ($bonePos$0186<<5)|0) + 28|0);
         HEAP32[$824>>2] = $823;
         $825 = (($bonePos$0186) + 1)|0;
         $boneIndexPos$1 = $821;$bonePos$1 = $825;$j$2 = 0;$sum$1 = 0;
        }
       } while(0);
       $826 = (($i6$0191) + 1)|0;
       $827 = HEAP32[$677>>2]|0;
       $828 = ($826|0)<($827|0);
       if ($828) {
        $boneIndexPos$0188 = $boneIndexPos$1;$bonePos$0186 = $bonePos$1;$i6$0191 = $826;$j$0189 = $j$2;$sum$0190 = $sum$1;
       } else {
        break;
       }
      }
     }
     $829 = ($720|0)>(-1);
     if ($829) {
      HEAP32[$11>>2] = $721;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$11+0>>2]|0;
      invoke_vii(2591,($723|0),($$byval_copy20|0));
      $830 = __THREW__; __THREW__ = 0;
      $831 = $830&1;
      if ($831) {
       label = 154;
       break;
      }
     }
     $832 = ($678|0)>(-1);
     if (!($832)) {
      STACKTOP = sp;return;
     }
     HEAP32[$0>>2] = $680;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($682,$$byval_copy20);
     STACKTOP = sp;return;
    }
   } while(0);
   if ((label|0) == 154) {
    $807 = ___cxa_find_matching_catch()|0;
    $808 = tempRet0;
    $$2 = $808;$$23 = $807;
   }
   $833 = ($678|0)>(-1);
   if (!($833)) {
    $$3 = $$2;$$34 = $$23;
    ___resumeException($$34|0);
    // unreachable;
   }
   HEAP32[$12>>2] = $680;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$12+0>>2]|0;
   invoke_vii(2591,($682|0),($$byval_copy20|0));
   $834 = __THREW__; __THREW__ = 0;
   $835 = $834&1;
   if ($835) {
    $836 = ___cxa_find_matching_catch(0|0)|0;
    $837 = tempRet0;
    ___clang_call_terminate($836);
    // unreachable;
   } else {
    $$3 = $$2;$$34 = $$23;
    ___resumeException($$34|0);
    // unreachable;
   }
  }
 } while(0);
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(585312,0,585336,456,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN14CompressedMesh10GetQualityE15MeshCompression($compression) {
 $compression = $compression|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (585344 + ($compression<<4)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN24CompressedAnimationCurve17CompressQuatCurveERN13AnimationClip15QuaternionCurveE($this,$src) {
 $this = $this|0;
 $src = $src|0;
 var $$0 = 0, $$01 = 0, $$0131 = 0, $$032 = 0, $$byval_copy5 = 0, $$not = 0, $$not22 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $exitcond = 0, $exitcond30 = 0, $i$026 = 0, $i1$024 = 0, $i2$021 = 0, $not$ = 0, $not$18 = 0, $not$19 = 0, $not$20 = 0, $same$0$off0$lcssa = 0;
 var $same$0$off0$not = 0, $same$0$off023 = 0, $same$1$off0 = 0, $same$2$off0 = 0, $same$3$off0 = 0, $same$4$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($src) + 12|0);
 __ZN24CompressedAnimationCurve16CompressTimeKeysI11QuaternionfEEvR17AnimationCurveTplIT_E($this,$4);
 $5 = (($src) + 172|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[628512>>2]|0;
 $8 = $6 << 4;
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 $9 = (__Z15malloc_internaljj10MemLabelIdiPKci($8,4,$$byval_copy5,0,585336,352)|0);
 $10 = ($6|0)>(0);
 if ($10) {
  $11 = (($src) + 164|0);
  $i$026 = 0;
  while(1) {
   $12 = (($9) + ($i$026<<4)|0);
   $13 = HEAP32[$11>>2]|0;
   $14 = ((($13) + (($i$026*52)|0)|0) + 4|0);
   ;HEAP32[$12+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$14+12>>2]|0;
   $15 = (($i$026) + 1)|0;
   $exitcond30 = ($15|0)==($6|0);
   if ($exitcond30) {
    break;
   } else {
    $i$026 = $15;
   }
  }
 }
 $18 = (($this) + 20|0);
 __THREW__ = 0;
 invoke_viii(1697,($18|0),($9|0),($6|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if ($20) {
   label = 4;
  } else {
   $$not22 = ($6|0)<(1);
   if ($$not22) {
    $same$0$off0$lcssa = 1;
   } else {
    $21 = (($src) + 164|0);
    $22 = HEAP32[$21>>2]|0;
    $i1$024 = 0;$same$0$off023 = 1;
    while(1) {
     $23 = ((($22) + (($i1$024*52)|0)|0) + 20|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $not$ = ($24 == $24) & (Math_fround(0.0) == Math_fround(0.0));
     $same$1$off0 = $same$0$off023 & $not$;
     $25 = ((($22) + (($i1$024*52)|0)|0) + 24|0);
     $26 = Math_fround(HEAPF32[$25>>2]);
     $not$18 = ($26 == $26) & (Math_fround(0.0) == Math_fround(0.0));
     $same$2$off0 = $same$1$off0 & $not$18;
     $27 = ((($22) + (($i1$024*52)|0)|0) + 28|0);
     $28 = Math_fround(HEAPF32[$27>>2]);
     $not$19 = ($28 == $28) & (Math_fround(0.0) == Math_fround(0.0));
     $same$3$off0 = $same$2$off0 & $not$19;
     $29 = ((($22) + (($i1$024*52)|0)|0) + 32|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     $not$20 = ($30 == $30) & (Math_fround(0.0) == Math_fround(0.0));
     $same$4$off0 = $same$3$off0 & $not$20;
     $31 = (($i1$024) + 1)|0;
     $$not = ($31|0)>=($6|0);
     $same$0$off0$not = $same$4$off0 ^ 1;
     $brmerge = $$not | $same$0$off0$not;
     if ($brmerge) {
      $same$0$off0$lcssa = $same$4$off0;
      break;
     } else {
      $i1$024 = $31;$same$0$off023 = $same$4$off0;
     }
    }
   }
   $32 = $6 << 3;
   $33 = HEAP32[628512>>2]|0;
   $34 = $6 << 5;
   HEAP32[$1>>2] = $33;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   $35 = (invoke_iiiiiii(102,($34|0),4,($$byval_copy5|0),0,(585336|0),352)|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    label = 4;
   } else {
    if ($10) {
     $38 = (($src) + 164|0);
     $$pre = HEAP32[$38>>2]|0;
     $i2$021 = 0;
     while(1) {
      $39 = ((($$pre) + (($i2$021*52)|0)|0) + 20|0);
      $40 = Math_fround(HEAPF32[$39>>2]);
      $41 = ((($$pre) + (($i2$021*52)|0)|0) + 24|0);
      $42 = Math_fround(HEAPF32[$41>>2]);
      $43 = ((($$pre) + (($i2$021*52)|0)|0) + 28|0);
      $44 = Math_fround(HEAPF32[$43>>2]);
      $45 = ((($$pre) + (($i2$021*52)|0)|0) + 32|0);
      $46 = Math_fround(HEAPF32[$45>>2]);
      $47 = $i2$021 << 2;
      $48 = (($35) + ($47<<2)|0);
      HEAPF32[$48>>2] = $40;
      $49 = $47 | 1;
      $50 = (($35) + ($49<<2)|0);
      HEAPF32[$50>>2] = $42;
      $51 = $47 | 2;
      $52 = (($35) + ($51<<2)|0);
      HEAPF32[$52>>2] = $44;
      $53 = $47 | 3;
      $54 = (($35) + ($53<<2)|0);
      HEAPF32[$54>>2] = $46;
      $55 = ((($$pre) + (($i2$021*52)|0)|0) + 36|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      $57 = ((($$pre) + (($i2$021*52)|0)|0) + 40|0);
      $58 = Math_fround(HEAPF32[$57>>2]);
      $59 = ((($$pre) + (($i2$021*52)|0)|0) + 44|0);
      $60 = Math_fround(HEAPF32[$59>>2]);
      $61 = ((($$pre) + (($i2$021*52)|0)|0) + 48|0);
      $62 = Math_fround(HEAPF32[$61>>2]);
      $63 = (($i2$021) + ($6))|0;
      $64 = $63 << 2;
      $65 = (($35) + ($64<<2)|0);
      HEAPF32[$65>>2] = $56;
      $66 = $64 | 1;
      $67 = (($35) + ($66<<2)|0);
      HEAPF32[$67>>2] = $58;
      $68 = $64 | 2;
      $69 = (($35) + ($68<<2)|0);
      HEAPF32[$69>>2] = $60;
      $70 = $64 | 3;
      $71 = (($35) + ($70<<2)|0);
      HEAPF32[$71>>2] = $62;
      $72 = (($i2$021) + 1)|0;
      $exitcond = ($72|0)==($6|0);
      if ($exitcond) {
       break;
      } else {
       $i2$021 = $72;
      }
     }
    }
    $78 = (($this) + 36|0);
    if ($same$0$off0$lcssa) {
     $79 = $6 << 2;
     __THREW__ = 0;
     invoke_viiiiiii(66,($78|0),($35|0),1,4,($79|0),6,0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if (!($81)) {
      label = 18;
     }
    } else {
     __THREW__ = 0;
     invoke_viiiiiii(66,($78|0),($35|0),1,4,($32|0),6,0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if (!($83)) {
      label = 18;
     }
    }
    if ((label|0) == 18) {
     $84 = (($src) + 180|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = (($this) + 64|0);
     HEAP32[$86>>2] = $85;
     $87 = (($src) + 184|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = (($this) + 68|0);
     HEAP32[$89>>2] = $88;
     $90 = (($this) + 72|0);
     __THREW__ = 0;
     (invoke_iii(2359,($90|0),($src|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      $93 = ($6|0)>(-1);
      if (!($93)) {
       STACKTOP = sp;return;
      }
      HEAP32[$2>>2] = $33;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($35|0),($$byval_copy5|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       label = 4;
       break;
      }
      HEAP32[$0>>2] = $7;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy5);
      STACKTOP = sp;return;
     }
    }
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    $75 = ($6|0)>(-1);
    if (!($75)) {
     $$0131 = $74;$$032 = $73;
     ___resumeException($$032|0);
     // unreachable;
    }
    HEAP32[$0>>2] = $33;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($35|0),($$byval_copy5|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     $99 = ___cxa_find_matching_catch(0|0)|0;
     $100 = tempRet0;
     ___clang_call_terminate($99);
     // unreachable;
    } else {
     $$0 = $73;$$01 = $74;
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $$0 = $16;$$01 = $17;
 }
 $96 = ($6|0)>(-1);
 if (!($96)) {
  $$0131 = $$01;$$032 = $$0;
  ___resumeException($$032|0);
  // unreachable;
 }
 HEAP32[$3>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($9|0),($$byval_copy5|0));
 $97 = __THREW__; __THREW__ = 0;
 $98 = $97&1;
 if ($98) {
  $99 = ___cxa_find_matching_catch(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 } else {
  $$0131 = $$01;$$032 = $$0;
  ___resumeException($$032|0);
  // unreachable;
 }
}
function __ZN24CompressedAnimationCurve16CompressTimeKeysI11QuaternionfEEvR17AnimationCurveTplIT_E($this,$src) {
 $this = $this|0;
 $src = $src|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $exitcond = 0, $exitcond11 = 0, $i$06 = 0, $i2$05 = 0, $minTime$0$lcssa = Math_fround(0), $minTime$07 = Math_fround(0);
 var $minTime$1 = Math_fround(0), $t1$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($src) + 160|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $4 = (($src) + 152|0);
  $5 = HEAP32[$4>>2]|0;
  $i$06 = 0;$minTime$07 = Math_fround(0.0);
  while(1) {
   $6 = (($5) + (($i$06*52)|0)|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 < $minTime$07;
   $minTime$1 = $8 ? $7 : $minTime$07;
   $9 = (($i$06) + 1)|0;
   $exitcond11 = ($9|0)==($2|0);
   if ($exitcond11) {
    $minTime$0$lcssa = $minTime$1;
    break;
   } else {
    $i$06 = $9;$minTime$07 = $minTime$1;
   }
  }
 } else {
  $minTime$0$lcssa = Math_fround(0.0);
 }
 $10 = HEAP32[628512>>2]|0;
 $11 = $2 << 2;
 HEAP32[$0>>2] = $10;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $12 = (__Z15malloc_internaljj10MemLabelIdiPKci($11,4,$$byval_copy2,0,585336,352)|0);
 if ($3) {
  $13 = (($src) + 152|0);
  $14 = HEAP32[$13>>2]|0;
  $i2$05 = 0;$t1$04 = 0;
  while(1) {
   $15 = (($14) + (($i2$05*52)|0)|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($16 - $minTime$0$lcssa);
   $18 = Math_fround($17 * Math_fround(100.0));
   $19 = (~~(($18))>>>0);
   $20 = (($12) + ($i2$05<<2)|0);
   $21 = (($19) - ($t1$04))|0;
   HEAP32[$20>>2] = $21;
   $22 = (($i2$05) + 1)|0;
   $exitcond = ($22|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $i2$05 = $22;$t1$04 = $19;
   }
  }
 }
 __THREW__ = 0;
 invoke_viii(1696,($this|0),($12|0),($2|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  $30 = ($2|0)>(-1);
  if (!($30)) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($12,$$byval_copy2);
  STACKTOP = sp;return;
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = ($2|0)>(-1);
 if (!($25)) {
  ___resumeException($23|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($12|0),($$byval_copy2|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $31 = ___cxa_find_matching_catch(0|0)|0;
  $32 = tempRet0;
  ___clang_call_terminate($31);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZN24CompressedAnimationCurve19DecompressQuatCurveERN13AnimationClip15QuaternionCurveE($this,$src) {
 $this = $this|0;
 $src = $src|0;
 var $$ = 0, $$$i = 0, $$0 = 0, $$01 = 0, $$0122 = 0, $$018$i = 0, $$023 = 0, $$byval_copy5 = 0, $$indexPos$2$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0;
 var $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = Math_fround(0), $67 = 0.0, $68 = 0.0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0);
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $bitPos$016$i = 0, $bitPos$2$lcssa$i = 0, $bitPos$22$i = 0, $bits$05$i = 0, $exitcond = 0, $exitcond21 = 0, $i$017 = 0, $i1$016 = 0, $indexPos$017$i = 0, $indexPos$2$lcssa$i = 0, $indexPos$23$i = 0, $scale$0$i = 0.0, $x$0$lcssa$i = 0, $x$04$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($src) + 12|0);
 __ZN24CompressedAnimationCurve18DecompressTimeKeysI11QuaternionfEEvR17AnimationCurveTplIT_E($this,$4);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[628512>>2]|0;
 $8 = $6 << 4;
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 $9 = (__Z15malloc_internaljj10MemLabelIdiPKci($8,4,$$byval_copy5,0,585336,352)|0);
 __ZN16PackedQuatVector11UnpackQuatsEP11Quaternionf($5,$9);
 $10 = ($6|0)>(0);
 if ($10) {
  $11 = (($src) + 164|0);
  $i$017 = 0;
  while(1) {
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($12) + (($i$017*52)|0)|0) + 4|0);
   $14 = (($9) + ($i$017<<4)|0);
   ;HEAP32[$13+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$14+12>>2]|0;
   $15 = (($i$017) + 1)|0;
   $exitcond21 = ($15|0)==($6|0);
   if ($exitcond21) {
    break;
   } else {
    $i$017 = $15;
   }
  }
 }
 $18 = $6 << 3;
 $19 = HEAP32[628512>>2]|0;
 $20 = $6 << 5;
 HEAP32[$1>>2] = $19;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 $21 = (invoke_iiiiiii(102,($20|0),4,($$byval_copy5|0),0,(585336|0),352)|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 do {
  if ($23) {
   label = 4;
  } else {
   $24 = (($this) + 48|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = (($this) + 40|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = +$27;
   $29 = ($25<<24>>24)==(0);
   if ($29) {
    $scale$0$i = $28;
   } else {
    $30 = $25&255;
    $31 = 1 << $30;
    $32 = (($31) + -1)|0;
    $33 = (+($32|0));
    $34 = $28 / $33;
    $scale$0$i = $34;
   }
   $35 = (($this) + 36|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = $36 << 2;
   $38 = (($21) + ($37)|0);
   $39 = ($36|0)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($this) + 44|0);
     $41 = (($this) + 52|0);
     $$018$i = $21;$43 = $25;$bitPos$016$i = 0;$indexPos$017$i = 0;
     while(1) {
      $42 = $43&255;
      $44 = ($43<<24>>24)==(0);
      if ($44) {
       $bitPos$2$lcssa$i = $bitPos$016$i;$indexPos$2$lcssa$i = $indexPos$017$i;$x$0$lcssa$i = 0;
      } else {
       $45 = HEAP32[$41>>2]|0;
       $bitPos$22$i = $bitPos$016$i;$bits$05$i = 0;$indexPos$23$i = $indexPos$017$i;$x$04$i = 0;
       while(1) {
        $46 = (($45) + ($indexPos$23$i)|0);
        $47 = HEAP8[$46>>0]|0;
        $48 = $47&255;
        $49 = $48 >>> $bitPos$22$i;
        $50 = $49 << $bits$05$i;
        $51 = $50 | $x$04$i;
        $52 = (($42) - ($bits$05$i))|0;
        $53 = (8 - ($bitPos$22$i))|0;
        $54 = ($53|0)<($52|0);
        $55 = $54 ? $53 : $52;
        $56 = (($55) + ($bitPos$22$i))|0;
        $57 = (($55) + ($bits$05$i))|0;
        $58 = ($56|0)==(8);
        $$$i = $58 ? 0 : $56;
        $59 = $58&1;
        $$indexPos$2$i = (($59) + ($indexPos$23$i))|0;
        $60 = ($57|0)<($42|0);
        if ($60) {
         $bitPos$22$i = $$$i;$bits$05$i = $57;$indexPos$23$i = $$indexPos$2$i;$x$04$i = $51;
        } else {
         $bitPos$2$lcssa$i = $$$i;$indexPos$2$lcssa$i = $$indexPos$2$i;$x$0$lcssa$i = $51;
         break;
        }
       }
      }
      $61 = 1 << $42;
      $62 = (($61) + -1)|0;
      $63 = $x$0$lcssa$i & $62;
      $64 = (+($63>>>0));
      $65 = $scale$0$i * $64;
      $66 = Math_fround(HEAPF32[$40>>2]);
      $67 = +$66;
      $68 = $65 + $67;
      $69 = Math_fround($68);
      HEAPF32[$$018$i>>2] = $69;
      $70 = (($$018$i) + 4|0);
      $71 = ($70|0)==($38|0);
      if ($71) {
       break L11;
      }
      $$pre = HEAP8[$24>>0]|0;
      $$018$i = $70;$43 = $$pre;$bitPos$016$i = $bitPos$2$lcssa$i;$indexPos$017$i = $indexPos$2$lcssa$i;
     }
    }
   } while(0);
   $72 = ($36|0)==($18|0);
   $$ = $72 ? $6 : 0;
   if ($10) {
    $73 = (($src) + 164|0);
    $74 = HEAP32[$73>>2]|0;
    $i1$016 = 0;
    while(1) {
     $80 = $i1$016 << 2;
     $81 = (($21) + ($80<<2)|0);
     $82 = Math_fround(HEAPF32[$81>>2]);
     $83 = ((($74) + (($i1$016*52)|0)|0) + 20|0);
     HEAPF32[$83>>2] = $82;
     $84 = $80 | 1;
     $85 = (($21) + ($84<<2)|0);
     $86 = Math_fround(HEAPF32[$85>>2]);
     $87 = ((($74) + (($i1$016*52)|0)|0) + 24|0);
     HEAPF32[$87>>2] = $86;
     $88 = $80 | 2;
     $89 = (($21) + ($88<<2)|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     $91 = ((($74) + (($i1$016*52)|0)|0) + 28|0);
     HEAPF32[$91>>2] = $90;
     $92 = $80 | 3;
     $93 = (($21) + ($92<<2)|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = ((($74) + (($i1$016*52)|0)|0) + 32|0);
     HEAPF32[$95>>2] = $94;
     $96 = (($i1$016) + ($$))|0;
     $97 = $96 << 2;
     $98 = (($21) + ($97<<2)|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     $100 = ((($74) + (($i1$016*52)|0)|0) + 36|0);
     HEAPF32[$100>>2] = $99;
     $101 = $97 | 1;
     $102 = (($21) + ($101<<2)|0);
     $103 = Math_fround(HEAPF32[$102>>2]);
     $104 = ((($74) + (($i1$016*52)|0)|0) + 40|0);
     HEAPF32[$104>>2] = $103;
     $105 = $97 | 2;
     $106 = (($21) + ($105<<2)|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = ((($74) + (($i1$016*52)|0)|0) + 44|0);
     HEAPF32[$108>>2] = $107;
     $109 = $97 | 3;
     $110 = (($21) + ($109<<2)|0);
     $111 = Math_fround(HEAPF32[$110>>2]);
     $112 = ((($74) + (($i1$016*52)|0)|0) + 48|0);
     HEAPF32[$112>>2] = $111;
     $113 = (($i1$016) + 1)|0;
     $exitcond = ($113|0)==($6|0);
     if ($exitcond) {
      break;
     } else {
      $i1$016 = $113;
     }
    }
   }
   $114 = (($this) + 64|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = (($src) + 180|0);
   HEAP32[$116>>2] = $115;
   __THREW__ = 0;
   invoke_vi(3450,($4|0));
   $117 = __THREW__; __THREW__ = 0;
   $118 = $117&1;
   if (!($118)) {
    $119 = (($this) + 68|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = (($src) + 184|0);
    HEAP32[$121>>2] = $120;
    __THREW__ = 0;
    invoke_vi(3450,($4|0));
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if (!($123)) {
     $124 = (($this) + 72|0);
     __THREW__ = 0;
     (invoke_iii(2359,($src|0),($124|0))|0);
     $125 = __THREW__; __THREW__ = 0;
     $126 = $125&1;
     if (!($126)) {
      $127 = ($6|0)>(-1);
      if (!($127)) {
       STACKTOP = sp;return;
      }
      HEAP32[$2>>2] = $19;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($21|0),($$byval_copy5|0));
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if ($129) {
       label = 4;
       break;
      }
      HEAP32[$0>>2] = $7;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy5);
      STACKTOP = sp;return;
     }
    }
   }
   $75 = ___cxa_find_matching_catch()|0;
   $76 = tempRet0;
   $77 = ($6|0)>(-1);
   if (!($77)) {
    $$0122 = $75;$$023 = $76;
    ___resumeException($$0122|0);
    // unreachable;
   }
   HEAP32[$0>>2] = $19;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($21|0),($$byval_copy5|0));
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $133 = ___cxa_find_matching_catch(0|0)|0;
    $134 = tempRet0;
    ___clang_call_terminate($133);
    // unreachable;
   } else {
    $$0 = $76;$$01 = $75;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $$0 = $17;$$01 = $16;
 }
 $130 = ($6|0)>(-1);
 if (!($130)) {
  $$0122 = $$01;$$023 = $$0;
  ___resumeException($$0122|0);
  // unreachable;
 }
 HEAP32[$3>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($9|0),($$byval_copy5|0));
 $131 = __THREW__; __THREW__ = 0;
 $132 = $131&1;
 if ($132) {
  $133 = ___cxa_find_matching_catch(0|0)|0;
  $134 = tempRet0;
  ___clang_call_terminate($133);
  // unreachable;
 } else {
  $$0122 = $$01;$$023 = $$0;
  ___resumeException($$0122|0);
  // unreachable;
 }
}
function __ZN24CompressedAnimationCurve18DecompressTimeKeysI11QuaternionfEEvR17AnimationCurveTplIT_E($this,$src) {
 $this = $this|0;
 $src = $src|0;
 var $$$i = 0, $$byval_copy4 = 0, $$indexPos$1$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $bitPos$05$i = 0, $bitPos$1$lcssa$i = 0, $bitPos$11$i = 0, $bits$02$i = 0, $exitcond = 0, $i$06$i = 0, $i$07 = 0, $indexPos$07$i = 0, $indexPos$1$lcssa$i = 0, $indexPos$13$i = 0, $t$06 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[628512>>2]|0;
 $5 = $3 << 2;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Z15malloc_internaljj10MemLabelIdiPKci($5,4,$$byval_copy4,0,585336,352)|0);
 $7 = (($this) + 4|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = (_bitshift64Shl(1,0,($9|0))|0);
 $11 = tempRet0;
 $12 = (_i64Add(($10|0),($11|0),-1,0)|0);
 $13 = tempRet0;
 $14 = HEAP32[$this>>2]|0;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = (($this) + 8|0);
  $bitPos$05$i = 0;$i$06$i = 0;$indexPos$07$i = 0;
  while(1) {
   $17 = (($6) + ($i$06$i<<2)|0);
   HEAP32[$17>>2] = 0;
   $18 = HEAP8[$7>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    $39 = 0;$bitPos$1$lcssa$i = $bitPos$05$i;$indexPos$1$lcssa$i = $indexPos$07$i;
   } else {
    $$pre$i = HEAP32[$16>>2]|0;
    $26 = 0;$bitPos$11$i = $bitPos$05$i;$bits$02$i = 0;$indexPos$13$i = $indexPos$07$i;
    while(1) {
     $20 = (($$pre$i) + ($indexPos$13$i)|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = $21&255;
     $23 = $22 >>> $bitPos$11$i;
     $24 = $23 << $bits$02$i;
     $25 = $24 | $26;
     HEAP32[$17>>2] = $25;
     $27 = HEAP8[$7>>0]|0;
     $28 = $27&255;
     $29 = (($28) - ($bits$02$i))|0;
     $30 = (8 - ($bitPos$11$i))|0;
     $31 = ($30|0)<($29|0);
     $32 = $31 ? $30 : $29;
     $33 = (($32) + ($bitPos$11$i))|0;
     $34 = (($32) + ($bits$02$i))|0;
     $35 = ($33|0)==(8);
     $$$i = $35 ? 0 : $33;
     $36 = $35&1;
     $$indexPos$1$i = (($36) + ($indexPos$13$i))|0;
     $37 = ($34|0)<($28|0);
     if ($37) {
      $26 = $25;$bitPos$11$i = $$$i;$bits$02$i = $34;$indexPos$13$i = $$indexPos$1$i;
     } else {
      $39 = $25;$bitPos$1$lcssa$i = $$$i;$indexPos$1$lcssa$i = $$indexPos$1$i;
      break;
     }
    }
   }
   $38 = $39 & $12;
   HEAP32[$17>>2] = $38;
   $40 = (($i$06$i) + 1)|0;
   $41 = HEAP32[$this>>2]|0;
   $42 = ($40>>>0)<($41>>>0);
   if ($42) {
    $bitPos$05$i = $bitPos$1$lcssa$i;$i$06$i = $40;$indexPos$07$i = $indexPos$1$lcssa$i;
   } else {
    break;
   }
  }
 }
 $43 = (($src) + 152|0);
 $44 = (($src) + 160|0);
 HEAP32[$44>>2] = $3;
 $45 = (($src) + 164|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 & 2147483647;
 $48 = ($47>>>0)<($3>>>0);
 do {
  if ($48) {
   $49 = ($46|0)>(-1);
   if ($49) {
    HEAP32[$45>>2] = $3;
    $50 = HEAP32[$43>>2]|0;
    $51 = ($3*52)|0;
    $52 = (($src) + 156|0);
    $53 = HEAP32[$52>>2]|0;
    HEAP32[$0>>2] = $53;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $54 = (invoke_iiiiiiii(108,($50|0),($51|0),4,($$byval_copy4|0),0,(585336|0),370)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     HEAP32[$43>>2] = $54;
     break;
    }
   } else {
    $57 = ($3*52)|0;
    $58 = (($src) + 156|0);
    $59 = HEAP32[$58>>2]|0;
    HEAP32[$1>>2] = $59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    $60 = (invoke_iiiiiii(102,($57|0),4,($$byval_copy4|0),0,(585336|0),352)|0);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if (!($62)) {
     $63 = HEAP32[$43>>2]|0;
     $64 = HEAP32[$44>>2]|0;
     $65 = ($64*52)|0;
     _memcpy(($60|0),($63|0),($65|0))|0;
     HEAP32[$45>>2] = $3;
     HEAP32[$43>>2] = $60;
     break;
    }
   }
   $77 = ___cxa_find_matching_catch()|0;
   $78 = tempRet0;
   $79 = ($3|0)>(-1);
   if (!($79)) {
    ___resumeException($77|0);
    // unreachable;
   }
   HEAP32[$2>>2] = $4;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($6|0),($$byval_copy4|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $83 = ___cxa_find_matching_catch(0|0)|0;
    $84 = tempRet0;
    ___clang_call_terminate($83);
    // unreachable;
   } else {
    ___resumeException($77|0);
    // unreachable;
   }
  }
 } while(0);
 $66 = ($3|0)>(0);
 if ($66) {
  $67 = (($src) + 152|0);
  $68 = HEAP32[$67>>2]|0;
  $i$07 = 0;$t$06 = 0;
  while(1) {
   $69 = (($6) + ($i$07<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + ($t$06))|0;
   $72 = (+($71>>>0));
   $73 = $72 * 0.0100000000000000002082;
   $74 = Math_fround($73);
   $75 = (($68) + (($i$07*52)|0)|0);
   HEAPF32[$75>>2] = $74;
   $76 = (($i$07) + 1)|0;
   $exitcond = ($76|0)==($3|0);
   if ($exitcond) {
    break;
   } else {
    $i$07 = $76;$t$06 = $71;
   }
  }
 }
 $82 = ($3|0)>(-1);
 if (!($82)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy4);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $4;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    HEAP8[$10>>0] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 1|0);
   HEAP32[$3>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = (($17) + ($__n))|0;
 $19 = ($18|0)<(0);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($5) - ($16))|0;
 $21 = ($20>>>0)<(1073741823);
 if ($21) {
  $22 = $20 << 1;
  $23 = ($22>>>0)<($18>>>0);
  $24 = $23 ? $18 : $22;
  $25 = ($24|0)==(0);
  if ($25) {
   $$0$i57 = 0;$28 = 0;
  } else {
   $$0$i56 = $24;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  HEAP32[$0>>2] = 8;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i56,16,$$byval_copy1,0,585336,79)|0);
  $$0$i57 = $$0$i56;$28 = $26;
 }
 $27 = (($28) + ($17)|0);
 $$0$i2 = $__n;$30 = $27;
 while(1) {
  $29 = ($30|0)==(0|0);
  if ($29) {
   $32 = 0;
  } else {
   HEAP8[$30>>0] = 0;
   $32 = $30;
  }
  $31 = (($32) + 1|0);
  $33 = (($$0$i2) + -1)|0;
  $34 = ($33|0)==(0);
  if ($34) {
   break;
  } else {
   $$0$i2 = $33;$30 = $31;
  }
 }
 $35 = (($28) + ($$0$i57)|0);
 $36 = HEAP32[$this>>2]|0;
 $37 = HEAP32[$3>>2]|0;
 $38 = $37;
 $39 = $36;
 $40 = (($38) - ($39))|0;
 $$sum = (($17) - ($40))|0;
 $41 = (($28) + ($$sum)|0);
 _memcpy(($41|0),($36|0),($40|0))|0;
 $42 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $41;
 HEAP32[$3>>2] = $31;
 HEAP32[$1>>2] = $35;
 $43 = ($42|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($42|0),($$byval_copy1|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIhNS_9allocatorIhEEE8__appendEjRKh($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  $$0$i = $__n;$9 = $3;
  while(1) {
   $8 = ($9|0)==(0|0);
   if ($8) {
    $12 = 0;
   } else {
    $10 = HEAP8[$__x>>0]|0;
    HEAP8[$9>>0] = $10;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 1|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$9 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = (($17) + ($__n))|0;
 $19 = ($18|0)<(0);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($16))|0;
 $21 = ($20>>>0)<(1073741823);
 if ($21) {
  $22 = $20 << 1;
  $23 = ($22>>>0)<($18>>>0);
  $24 = $23 ? $18 : $22;
  $25 = ($24|0)==(0);
  if ($25) {
   $$0$i57 = 0;$28 = 0;
  } else {
   $$0$i56 = $24;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $26 = (__Znwj($$0$i56)|0);
  $$0$i57 = $$0$i56;$28 = $26;
 }
 $27 = (($28) + ($17)|0);
 $$0$i2 = $__n;$30 = $27;
 while(1) {
  $29 = ($30|0)==(0|0);
  if ($29) {
   $33 = 0;
  } else {
   $31 = HEAP8[$__x>>0]|0;
   HEAP8[$30>>0] = $31;
   $33 = $30;
  }
  $32 = (($33) + 1|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$30 = $32;
  }
 }
 $36 = (($28) + ($$0$i57)|0);
 $37 = HEAP32[$this>>2]|0;
 $38 = HEAP32[$2>>2]|0;
 $39 = $38;
 $40 = $37;
 $41 = (($39) - ($40))|0;
 $$sum = (($17) - ($41))|0;
 $42 = (($28) + ($$sum)|0);
 _memcpy(($42|0),($37|0),($41|0))|0;
 HEAP32[$this>>2] = $42;
 HEAP32[$2>>2] = $32;
 HEAP32[$0>>2] = $36;
 $43 = ($37|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 __ZdlPv($37);
 STACKTOP = sp;return;
}
function __ZN17GenericDynamicVBOC2ER9GfxDevice13GfxBufferModejj($this,$device,$bufferMode,$initialVBSize,$initialIBSize) {
 $this = $this|0;
 $device = $device|0;
 $bufferMode = $bufferMode|0;
 $initialVBSize = $initialVBSize|0;
 $initialIBSize = $initialIBSize|0;
 var $$0$i$i = 0, $$0$i$i4 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((585424 + 8|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $device;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $bufferMode;
 $3 = (($this) + 12|0);
 dest=$3+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP16[$3+40>>1]=0|0;
 $4 = HEAP32[628512>>2]|0;
 $5 = (($this) + 56|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 60|0);
 HEAP32[$6>>2] = $4;
 $7 = (($this) + 64|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 68|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$device>>2]|0;
 $10 = (($9) + 256|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 $12 = (invoke_ii($11|0,($device|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 do {
  if (!($14)) {
   $15 = (($this) + 16|0);
   HEAP32[$15>>2] = $12;
   $16 = HEAP32[$2>>2]|0;
   $17 = ($16|0)==(1);
   if ($17) {
    $$0$i$i4 = $initialIBSize;
    label = 5;
   } else {
    $18 = (($12) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19>>>0)<($initialIBSize>>>0);
    if ($20) {
     $21 = (($initialIBSize) + -1)|0;
     $22 = $21 >>> 16;
     $23 = $22 | $21;
     $24 = $23 >>> 8;
     $25 = $24 | $23;
     $26 = $25 >>> 4;
     $27 = $26 | $25;
     $28 = $27 >>> 2;
     $29 = $28 | $27;
     $30 = $29 >>> 1;
     $31 = $30 | $29;
     $32 = (($31) + 1)|0;
     $$0$i$i4 = $32;
     label = 5;
    }
   }
   if ((label|0) == 5) {
    $33 = ($$0$i$i4|0)==(0);
    if (!($33)) {
     $34 = HEAP32[$1>>2]|0;
     $35 = HEAP32[$34>>2]|0;
     $36 = (($35) + 260|0);
     $37 = HEAP32[$36>>2]|0;
     __THREW__ = 0;
     invoke_viiiiiii($37|0,($34|0),($12|0),($16|0),1,($$0$i$i4|0),(0|0),0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
    }
   }
   $40 = HEAP32[$device>>2]|0;
   $41 = (($40) + 276|0);
   $42 = HEAP32[$41>>2]|0;
   __THREW__ = 0;
   $43 = (invoke_ii($42|0,($device|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    HEAP32[$3>>2] = $43;
    $46 = HEAP32[$2>>2]|0;
    $47 = ($46|0)==(1);
    do {
     if ($47) {
      $$0$i$i = $initialVBSize;
     } else {
      $48 = (($43) + 20|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49>>>0)<($initialVBSize>>>0);
      if ($50) {
       $51 = (($initialVBSize) + -1)|0;
       $52 = $51 >>> 16;
       $53 = $52 | $51;
       $54 = $53 >>> 8;
       $55 = $54 | $53;
       $56 = $55 >>> 4;
       $57 = $56 | $55;
       $58 = $57 >>> 2;
       $59 = $58 | $57;
       $60 = $59 >>> 1;
       $61 = $60 | $59;
       $62 = (($61) + 1)|0;
       $$0$i$i = $62;
       break;
      } else {
       STACKTOP = sp;return;
      }
     }
    } while(0);
    $63 = ($$0$i$i|0)==(0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = HEAP32[$1>>2]|0;
    $65 = HEAP32[$64>>2]|0;
    $66 = (($65) + 280|0);
    $67 = HEAP32[$66>>2]|0;
    __THREW__ = 0;
    invoke_viiiiiii($67|0,($64|0),($43|0),($46|0),1,($$0$i$i|0),(0|0),0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if (!($69)) {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $70 = ___cxa_find_matching_catch()|0;
 $71 = tempRet0;
 $72 = HEAP32[$8>>2]|0;
 $73 = ($72|0)>(-1);
 if (!($73)) {
  ___resumeException($70|0);
  // unreachable;
 }
 $74 = HEAP32[$5>>2]|0;
 $75 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $75;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy|0));
 $76 = __THREW__; __THREW__ = 0;
 $77 = $76&1;
 if ($77) {
  $78 = ___cxa_find_matching_catch(0|0)|0;
  $79 = tempRet0;
  ___clang_call_terminate($78);
  // unreachable;
 }
 HEAP32[$5>>2] = 0;
 ___resumeException($70|0);
 // unreachable;
}
function __ZN17GenericDynamicVBOD0Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$01$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((585424 + 8|0));
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 272|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_vii($6|0,($3|0),($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[$2>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 292|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($this) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  invoke_vii($14|0,($11|0),($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   $19 = (($this) + 68|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)>(-1);
   if (!($21)) {
    __ZdlPv($this);
    STACKTOP = sp;return;
   }
   $22 = (($this) + 56|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($this) + 60|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$1>>2] = $25;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($23|0),($$byval_copy1|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __ZdlPv($this);
    STACKTOP = sp;return;
   }
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   $$0$i = $40;$$01$i = $39;
   __ZdlPv($this);
   ___resumeException($$01$i|0);
   // unreachable;
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 $30 = (($this) + 68|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)>(-1);
 if (!($32)) {
  $$0$i = $29;$$01$i = $28;
  __ZdlPv($this);
  ___resumeException($$01$i|0);
  // unreachable;
 }
 $33 = (($this) + 56|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 60|0);
 $36 = HEAP32[$35>>2]|0;
 HEAP32[$0>>2] = $36;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 } else {
  $$0$i = $29;$$01$i = $28;
  __ZdlPv($this);
  ___resumeException($$01$i|0);
  // unreachable;
 }
}
function __ZN17GenericDynamicVBOD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((585424 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 272|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_vii($5|0,($2|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $10 = HEAP32[$1>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 292|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  invoke_vii($13|0,($10|0),($15|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $18 = (($this) + 68|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)>(-1);
   if (!($20)) {
    STACKTOP = sp;return;
   }
   $21 = (($this) + 56|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($this) + 60|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$0>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($22|0),($$byval_copy1|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $38 = ___cxa_find_matching_catch()|0;
    $39 = tempRet0;
    $$0 = $39;$$01 = $38;
    ___resumeException($$01|0);
    // unreachable;
   } else {
    HEAP32[$21>>2] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $29 = (($this) + 68|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(-1);
 if (!($31)) {
  $$0 = $28;$$01 = $27;
  ___resumeException($$01|0);
  // unreachable;
 }
 $32 = (($this) + 56|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 60|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$0>>2] = $35;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $40 = ___cxa_find_matching_catch(0|0)|0;
  $41 = tempRet0;
  ___clang_call_terminate($40);
  // unreachable;
 }
 HEAP32[$32>>2] = 0;
 $$0 = $28;$$01 = $27;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN17GenericDynamicVBO8GetChunkEjjj16GfxPrimitiveTypePPvS2_($this,$stride,$maxVertices,$maxIndices,$primType,$outVB,$outIB) {
 $this = $this|0;
 $stride = $stride|0;
 $maxVertices = $maxVertices|0;
 $maxIndices = $maxIndices|0;
 $primType = $primType|0;
 $outVB = $outVB|0;
 $outIB = $outIB|0;
 var $$0 = 0, $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $or$cond2 = 0, $requiredIBSize$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = ($maxVertices|0)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($this) + 36|0);
 HEAP32[$2>>2] = $stride;
 $3 = (($this) + 48|0);
 HEAP32[$3>>2] = $primType;
 $4 = ($maxIndices|0)!=(0);
 $5 = (($this) + 52|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = Math_imul($maxVertices, $stride)|0;
 $8 = $maxIndices << 1;
 $9 = ($primType|0)==(2);
 $or$cond = $4 & $9;
 $10 = HEAP8[((640792 + 224|0))>>0]|0;
 $11 = ($10<<24>>24)==(0);
 $or$cond2 = $or$cond & $11;
 if ($or$cond2) {
  $12 = (($this) + 56|0);
  $13 = (($this) + 64|0);
  HEAP32[$13>>2] = $maxIndices;
  $14 = (($this) + 68|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 & 2147483647;
  $17 = ($16>>>0)<($maxIndices>>>0);
  do {
   if ($17) {
    $18 = ($15|0)>(-1);
    if ($18) {
     HEAP32[$14>>2] = $maxIndices;
     $19 = HEAP32[$12>>2]|0;
     $20 = (($this) + 60|0);
     $21 = HEAP32[$20>>2]|0;
     HEAP32[$0>>2] = $21;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($19,$8,2,$$byval_copy1,0,585456,370)|0);
     HEAP32[$12>>2] = $22;
     $29 = $22;
     break;
    } else {
     $23 = (($this) + 60|0);
     $24 = HEAP32[$23>>2]|0;
     HEAP32[$0>>2] = $24;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($8,2,$$byval_copy1,0,585456,352)|0);
     $26 = HEAP32[$12>>2]|0;
     $27 = HEAP32[$13>>2]|0;
     $28 = $27 << 1;
     _memcpy(($25|0),($26|0),($28|0))|0;
     HEAP32[$14>>2] = $maxIndices;
     HEAP32[$12>>2] = $25;
     $29 = $25;
     break;
    }
   } else {
    $$pre = HEAP32[$12>>2]|0;
    $29 = $$pre;
   }
  } while(0);
  HEAP32[$outIB>>2] = $29;
  $requiredIBSize$0 = 0;
 } else {
  $requiredIBSize$0 = $8;
 }
 $30 = (__ZN17GenericDynamicVBO19AllocateBufferSpaceEjjj($this,$7,$stride,$requiredIBSize$0)|0);
 if (!($30)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (($this) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 284|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + 20|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (FUNCTION_TABLE_iiiii[$35 & 511]($32,$37,$39,$7)|0);
 HEAP32[$outVB>>2] = $40;
 $41 = ($40|0)==(0|0);
 if ($41) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = ($requiredIBSize$0|0)==(0);
 if (!($42)) {
  $43 = HEAP32[$31>>2]|0;
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 264|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($this) + 16|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($this) + 28|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (FUNCTION_TABLE_iiiii[$46 & 511]($43,$48,$50,$requiredIBSize$0)|0);
  HEAP32[$outIB>>2] = $51;
  $52 = ($51|0)==(0|0);
  if ($52) {
   $53 = HEAP32[$31>>2]|0;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 288|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = HEAP32[$36>>2]|0;
   FUNCTION_TABLE_viii[$56 & 4095]($53,$57,0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $58 = (($this) + 53|0);
 HEAP8[$58>>0] = 1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17GenericDynamicVBO19AllocateBufferSpaceEjjj($this,$vbSize,$vbStride,$ibSize) {
 $this = $this|0;
 $vbSize = $vbSize|0;
 $vbStride = $vbStride|0;
 $ibSize = $ibSize|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i1 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(1);
 if ($3) {
  $$0$i$i = $vbSize;
  label = 4;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = (($4) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6>>>0)<($vbSize>>>0);
  if ($7) {
   $8 = (($vbSize) + -1)|0;
   $9 = $8 >>> 16;
   $10 = $9 | $8;
   $11 = $10 >>> 8;
   $12 = $11 | $10;
   $13 = $12 >>> 4;
   $14 = $13 | $12;
   $15 = $14 >>> 2;
   $16 = $15 | $14;
   $17 = $16 >>> 1;
   $18 = $17 | $16;
   $19 = (($18) + 1)|0;
   $$0$i$i = $19;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $20 = ($$0$i$i|0)==(0);
  if (!($20)) {
   $21 = (($this) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 280|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[$0>>2]|0;
   FUNCTION_TABLE_viiiiiii[$25 & 127]($22,$26,$2,1,$$0$i$i,0,0);
  }
 }
 $27 = HEAP32[$0>>2]|0;
 $28 = (($27) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29>>>0)<($vbSize>>>0);
 if ($30) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (($this) + 16|0);
 $32 = HEAP32[$1>>2]|0;
 $33 = ($32|0)==(1);
 if ($33) {
  $$0$i$i1 = $ibSize;
  label = 10;
 } else {
  $34 = HEAP32[$31>>2]|0;
  $35 = (($34) + 20|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36>>>0)<($ibSize>>>0);
  if ($37) {
   $38 = (($ibSize) + -1)|0;
   $39 = $38 >>> 16;
   $40 = $39 | $38;
   $41 = $40 >>> 8;
   $42 = $41 | $40;
   $43 = $42 >>> 4;
   $44 = $43 | $42;
   $45 = $44 >>> 2;
   $46 = $45 | $44;
   $47 = $46 >>> 1;
   $48 = $47 | $46;
   $49 = (($48) + 1)|0;
   $$0$i$i1 = $49;
   label = 10;
  }
 }
 if ((label|0) == 10) {
  $50 = ($$0$i$i1|0)==(0);
  if (!($50)) {
   $51 = (($this) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 260|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = HEAP32[$31>>2]|0;
   FUNCTION_TABLE_viiiiiii[$55 & 127]($52,$56,$32,1,$$0$i$i1,0,0);
  }
 }
 $57 = HEAP32[$31>>2]|0;
 $58 = (($57) + 20|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59>>>0)<($ibSize>>>0);
 if ($60) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $61 = HEAP32[$1>>2]|0;
 $62 = ($61|0)==(2);
 if (!($62)) {
  $80 = (($this) + 20|0);
  HEAP32[$80>>2] = 0;
  $81 = (($this) + 28|0);
  HEAP32[$81>>2] = 0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = ($vbStride|0)==(0);
 $$phi$trans$insert = (($this) + 20|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if ($63) {
  $69 = $$pre;
 } else {
  $64 = (($vbStride) + -1)|0;
  $65 = (($64) + ($$pre))|0;
  $66 = (($65>>>0) % ($vbStride>>>0))&-1;
  $67 = (($65) - ($66))|0;
  HEAP32[$$phi$trans$insert>>2] = $67;
  $69 = $67;
 }
 $68 = (($69) + ($vbSize))|0;
 $70 = HEAP32[$0>>2]|0;
 $71 = (($70) + 20|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($68>>>0)<($72>>>0);
 if (!($73)) {
  $74 = (($this) + 20|0);
  HEAP32[$74>>2] = 0;
 }
 $75 = (($this) + 28|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + ($ibSize))|0;
 $78 = HEAP32[$58>>2]|0;
 $79 = ($77>>>0)<($78>>>0);
 if ($79) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$75>>2] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17GenericDynamicVBO12ReleaseChunkEjj($this,$actualVertices,$actualIndices) {
 $this = $this|0;
 $actualVertices = $actualVertices|0;
 $actualIndices = $actualIndices|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 53|0);
 HEAP8[$1>>0] = 0;
 $2 = (($this) + 40|0);
 HEAP32[$2>>2] = $actualVertices;
 $3 = (($this) + 44|0);
 HEAP32[$3>>2] = $actualIndices;
 $4 = (($this) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_imul($5, $actualVertices)|0;
 $7 = $actualIndices << 1;
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 288|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_viii[$12 & 4095]($9,$14,$6);
 $15 = (($this) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 24|0);
 HEAP32[$17>>2] = $16;
 $18 = (($16) + ($6))|0;
 HEAP32[$15>>2] = $18;
 $19 = (($this) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(2);
 $22 = HEAP8[((640792 + 224|0))>>0]|0;
 $23 = ($22<<24>>24)==(0);
 $or$cond = $21 & $23;
 if ($or$cond) {
  __ZN17GenericDynamicVBO19FillQuadIndexBufferEv($this);
  $24 = (($this) + 68|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)>(-1);
  if ($26) {
   $27 = (($this) + 56|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($this) + 60|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$0>>2] = $30;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy);
   HEAP32[$27>>2] = 0;
  }
  $31 = (($this) + 64|0);
  HEAP32[$31>>2] = 0;
  HEAP32[$24>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $32 = (($this) + 52|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   STACKTOP = sp;return;
  }
  $35 = HEAP32[$8>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 268|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($this) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_viii[$38 & 4095]($35,$40,$7);
  $41 = (($this) + 28|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($this) + 32|0);
  HEAP32[$43>>2] = $42;
  $44 = (($42) + ($7))|0;
  HEAP32[$41>>2] = $44;
  STACKTOP = sp;return;
 }
}
function __ZN17GenericDynamicVBO19FillQuadIndexBufferEv($this) {
 $this = $this|0;
 var $$016$i = 0, $$07$i = 0, $$12$i = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $i$08$i = 0, $i1$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($this) + 44|0);
 $4 = (($this) + 40|0);
 $$in = $2 ? $4 : $3;
 $5 = HEAP32[$$in>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = $5 >>> 2;
 $8 = ($7*6)|0;
 $9 = ($7*12)|0;
 $10 = (__ZN17GenericDynamicVBO19AllocateBufferSpaceEjjj($this,0,0,$9)|0);
 if ($10) {
  $11 = (($this) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 264|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($this) + 28|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_iiiii[$15 & 511]($12,$17,$19,$9)|0);
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = HEAP8[$0>>0]|0;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $$12$i = $20;$i1$03$i = 0;
    label = 8;
   } else {
    $24 = (($this) + 56|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     $$12$i = $20;$i1$03$i = 0;
     label = 8;
    } else {
     $$016$i = $25;$$07$i = $20;$i$08$i = 0;
     while(1) {
      $27 = HEAP16[$$016$i>>1]|0;
      $28 = (($$07$i) + 2|0);
      HEAP16[$$07$i>>1] = $27;
      $29 = (($$016$i) + 2|0);
      $30 = HEAP16[$29>>1]|0;
      $31 = (($$07$i) + 4|0);
      HEAP16[$28>>1] = $30;
      $32 = (($$016$i) + 4|0);
      $33 = HEAP16[$32>>1]|0;
      $34 = (($$07$i) + 6|0);
      HEAP16[$31>>1] = $33;
      $35 = HEAP16[$$016$i>>1]|0;
      $36 = (($$07$i) + 8|0);
      HEAP16[$34>>1] = $35;
      $37 = HEAP16[$32>>1]|0;
      $38 = (($$07$i) + 10|0);
      HEAP16[$36>>1] = $37;
      $39 = (($$016$i) + 6|0);
      $40 = HEAP16[$39>>1]|0;
      $41 = (($$07$i) + 12|0);
      HEAP16[$38>>1] = $40;
      $42 = (($$016$i) + 8|0);
      $43 = (($i$08$i) + 4)|0;
      $44 = ($43>>>0)<($5>>>0);
      if ($44) {
       $$016$i = $42;$$07$i = $41;$i$08$i = $43;
      } else {
       break;
      }
     }
    }
   }
   if ((label|0) == 8) {
    while(1) {
     label = 0;
     $45 = $i1$03$i&65535;
     $46 = (($$12$i) + 2|0);
     HEAP16[$$12$i>>1] = $45;
     $47 = $i1$03$i | 1;
     $48 = $47&65535;
     $49 = (($$12$i) + 4|0);
     HEAP16[$46>>1] = $48;
     $50 = $i1$03$i | 2;
     $51 = $50&65535;
     $52 = (($$12$i) + 6|0);
     HEAP16[$49>>1] = $51;
     $53 = (($$12$i) + 8|0);
     HEAP16[$52>>1] = $45;
     $54 = (($$12$i) + 10|0);
     HEAP16[$53>>1] = $51;
     $55 = $i1$03$i | 3;
     $56 = $55&65535;
     $57 = (($$12$i) + 12|0);
     HEAP16[$54>>1] = $56;
     $58 = (($i1$03$i) + 4)|0;
     $59 = ($58>>>0)<($5>>>0);
     if ($59) {
      $$12$i = $57;$i1$03$i = $58;
      label = 8;
     } else {
      break;
     }
    }
   }
   $60 = (($this) + 48|0);
   HEAP32[$60>>2] = 0;
   HEAP8[$0>>0] = 1;
   HEAP32[$3>>2] = $8;
   $61 = HEAP32[$11>>2]|0;
   $62 = HEAP32[$61>>2]|0;
   $63 = (($62) + 268|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_viii[$64 & 4095]($61,$65,$9);
   $66 = HEAP32[$18>>2]|0;
   $67 = (($this) + 32|0);
   HEAP32[$67>>2] = $66;
   $68 = (($66) + ($9))|0;
   HEAP32[$18>>2] = $68;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$3>>2] = 0;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17GenericDynamicVBO9DrawChunkERK14ChannelAssignsP17VertexDeclaration($this,$channels,$vertexDecl) {
 $this = $this|0;
 $channels = $channels|0;
 $vertexDecl = $vertexDecl|0;
 var $$in = 0, $$pn = 0, $$pn$in$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $drawRange = 0, $vertexStream = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vertexStream = sp + 24|0;
 $drawRange = sp;
 $0 = (($this) + 52|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 44|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   STACKTOP = sp;return;
  }
 }
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$vertexStream>>2] = $10;
 $11 = (($this) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($vertexStream) + 4|0);
 HEAP32[$13>>2] = $12;
 ;HEAP32[$drawRange+0>>2]=0|0;HEAP32[$drawRange+4>>2]=0|0;HEAP32[$drawRange+8>>2]=0|0;HEAP32[$drawRange+12>>2]=0|0;HEAP32[$drawRange+16>>2]=0|0;
 $14 = (($this) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$drawRange>>2] = $15;
 $16 = (($drawRange) + 20|0);
 HEAP32[$16>>2] = $7;
 if ($2) {
  $17 = (($this) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18>>>0) / ($12>>>0))&-1;
  $20 = (($drawRange) + 16|0);
  HEAP32[$20>>2] = $19;
  $21 = (($this) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $$pn$in$in = $22;$38 = $22;$39 = 0;
 } else {
  $23 = (($this) + 44|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($drawRange) + 8|0);
  HEAP32[$25>>2] = $24;
  $26 = (($this) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($drawRange) + 4|0);
  HEAP32[$28>>2] = $27;
  $29 = (($this) + 24|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30>>>0) / ($12>>>0))&-1;
  $32 = (($drawRange) + 12|0);
  HEAP32[$32>>2] = $31;
  $33 = (($this) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($this) + 16|0);
  $36 = HEAP32[$35>>2]|0;
  $$pn$in$in = $34;$38 = $34;$39 = $36;
 }
 $$pn = HEAP32[$$pn$in$in>>2]|0;
 $$in = (($$pn) + 300|0);
 $37 = HEAP32[$$in>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$37 & 63]($38,$39,$vertexStream,1,$drawRange,1,$vertexDecl,$channels);
 STACKTOP = sp;return;
}
function __Z27ConvertSubMeshesToTrianglesRNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEEER13dynamic_arrayItLj2EE($submeshes,$indexBuffer) {
 $submeshes = $submeshes|0;
 $indexBuffer = $indexBuffer|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $destOffset$08 = 0, $destOffset2$0$lcssa = 0, $destOffset2$04 = 0, $destOffset2$1 = 0, $i$05 = 0, $or$cond = 0, $or$cond1 = 0, $q$07 = 0, $s$011 = 0, $srcOffset$09 = 0, $srcOffset$16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 4|0;
 $0 = sp;
 $1 = (($submeshes) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$submeshes>>2]|0;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($indexBuffer) + 8|0);
 $6 = (($indexBuffer) + 12|0);
 $7 = (($indexBuffer) + 4|0);
 $9 = $3;$s$011 = 0;
 while(1) {
  $8 = ((($9) + (($s$011*56)|0)|0) + 4|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = $10 >>> 1;
  $12 = (($9) + (($s$011*56)|0)|0);
  $13 = HEAP32[$12>>2]|0;
  if ((($13|0) == 1)) {
   $68 = ((($9) + (($s$011*56)|0)|0) + 8|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69>>>0)<(3);
   if (!($70)) {
    $71 = HEAP32[$5>>2]|0;
    $72 = ($69*3)|0;
    $73 = (($72) + -6)|0;
    $74 = (($73) + ($71))|0;
    HEAP32[$5>>2] = $74;
    $75 = HEAP32[$6>>2]|0;
    $76 = $75 & 2147483647;
    $77 = ($76>>>0)<($74>>>0);
    do {
     if ($77) {
      $78 = ($75|0)>(-1);
      if ($78) {
       HEAP32[$6>>2] = $74;
       $79 = HEAP32[$indexBuffer>>2]|0;
       $80 = $74 << 1;
       $81 = HEAP32[$7>>2]|0;
       HEAP32[$0>>2] = $81;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $82 = (__Z16realloc_internalPvji10MemLabelIdiPKci($79,$80,2,$$byval_copy5,0,585592,370)|0);
       HEAP32[$indexBuffer>>2] = $82;
       break;
      } else {
       $83 = $74 << 1;
       $84 = HEAP32[$7>>2]|0;
       HEAP32[$0>>2] = $84;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $85 = (__Z15malloc_internaljj10MemLabelIdiPKci($83,2,$$byval_copy5,0,585592,352)|0);
       $86 = HEAP32[$indexBuffer>>2]|0;
       $87 = HEAP32[$5>>2]|0;
       $88 = $87 << 1;
       _memcpy(($85|0),($86|0),($88|0))|0;
       HEAP32[$6>>2] = $74;
       HEAP32[$indexBuffer>>2] = $85;
       break;
      }
     }
    } while(0);
    $89 = HEAP32[$68>>2]|0;
    $90 = ($89|0)==(2);
    if ($90) {
     $destOffset2$0$lcssa = $71;
    } else {
     $91 = HEAP32[$indexBuffer>>2]|0;
     $92 = (($89) + -2)|0;
     $destOffset2$04 = $71;$i$05 = 0;$srcOffset$16 = $11;
     while(1) {
      $93 = (($91) + ($srcOffset$16<<1)|0);
      $94 = HEAP16[$93>>1]|0;
      $95 = (($srcOffset$16) + 1)|0;
      $96 = (($91) + ($95<<1)|0);
      $97 = HEAP16[$96>>1]|0;
      $98 = (($srcOffset$16) + 2)|0;
      $99 = (($91) + ($98<<1)|0);
      $100 = HEAP16[$99>>1]|0;
      $101 = ($94<<16>>16)==($97<<16>>16);
      $102 = ($94<<16>>16)==($100<<16>>16);
      $or$cond = $101 | $102;
      $103 = ($97<<16>>16)==($100<<16>>16);
      $or$cond1 = $or$cond | $103;
      if ($or$cond1) {
       $destOffset2$1 = $destOffset2$04;
      } else {
       $104 = $i$05 & 1;
       $105 = ($104|0)!=(0);
       $106 = $105 ? $97 : $94;
       $107 = (($91) + ($destOffset2$04<<1)|0);
       HEAP16[$107>>1] = $106;
       $108 = $105 ? $94 : $97;
       $109 = (($destOffset2$04) + 1)|0;
       $110 = (($91) + ($109<<1)|0);
       HEAP16[$110>>1] = $108;
       $111 = (($destOffset2$04) + 2)|0;
       $112 = (($91) + ($111<<1)|0);
       HEAP16[$112>>1] = $100;
       $113 = (($destOffset2$04) + 3)|0;
       $destOffset2$1 = $113;
      }
      $114 = (($i$05) + 1)|0;
      $115 = ($114>>>0)<($92>>>0);
      if ($115) {
       $destOffset2$04 = $destOffset2$1;$i$05 = $114;$srcOffset$16 = $95;
      } else {
       $destOffset2$0$lcssa = $destOffset2$1;
       break;
      }
     }
    }
    HEAP32[$5>>2] = $destOffset2$0$lcssa;
    $116 = HEAP32[$6>>2]|0;
    $117 = $116 & 2147483647;
    $118 = ($117>>>0)<($destOffset2$0$lcssa>>>0);
    do {
     if ($118) {
      $119 = ($116|0)>(-1);
      if ($119) {
       HEAP32[$6>>2] = $destOffset2$0$lcssa;
       $120 = HEAP32[$indexBuffer>>2]|0;
       $121 = $destOffset2$0$lcssa << 1;
       $122 = HEAP32[$7>>2]|0;
       HEAP32[$0>>2] = $122;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $123 = (__Z16realloc_internalPvji10MemLabelIdiPKci($120,$121,2,$$byval_copy5,0,585592,370)|0);
       HEAP32[$indexBuffer>>2] = $123;
       break;
      } else {
       $124 = $destOffset2$0$lcssa << 1;
       $125 = HEAP32[$7>>2]|0;
       HEAP32[$0>>2] = $125;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $126 = (__Z15malloc_internaljj10MemLabelIdiPKci($124,2,$$byval_copy5,0,585592,352)|0);
       $127 = HEAP32[$indexBuffer>>2]|0;
       $128 = HEAP32[$5>>2]|0;
       $129 = $128 << 1;
       _memcpy(($126|0),($127|0),($129|0))|0;
       HEAP32[$6>>2] = $destOffset2$0$lcssa;
       HEAP32[$indexBuffer>>2] = $126;
       break;
      }
     }
    } while(0);
    $130 = $71 << 1;
    $131 = ((($9) + (($s$011*56)|0)|0) + 24|0);
    HEAP32[$131>>2] = $130;
    $132 = (($destOffset2$0$lcssa) - ($71))|0;
    $133 = ((($9) + (($s$011*56)|0)|0) + 28|0);
    HEAP32[$133>>2] = $132;
   }
  } else if ((($13|0) == 2)) {
   $14 = ((($9) + (($s$011*56)|0)|0) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15>>>0)<(4);
   if (!($16)) {
    $17 = $15 >>> 2;
    $18 = HEAP32[$5>>2]|0;
    $19 = ($17*6)|0;
    $20 = (($18) + ($19))|0;
    HEAP32[$5>>2] = $20;
    $21 = HEAP32[$6>>2]|0;
    $22 = $21 & 2147483647;
    $23 = ($22>>>0)<($20>>>0);
    do {
     if ($23) {
      $24 = ($21|0)>(-1);
      if ($24) {
       HEAP32[$6>>2] = $20;
       $25 = HEAP32[$indexBuffer>>2]|0;
       $26 = $20 << 1;
       $27 = HEAP32[$7>>2]|0;
       HEAP32[$0>>2] = $27;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $28 = (__Z16realloc_internalPvji10MemLabelIdiPKci($25,$26,2,$$byval_copy5,0,585592,370)|0);
       HEAP32[$indexBuffer>>2] = $28;
       break;
      } else {
       $29 = $20 << 1;
       $30 = HEAP32[$7>>2]|0;
       HEAP32[$0>>2] = $30;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $31 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,2,$$byval_copy5,0,585592,352)|0);
       $32 = HEAP32[$indexBuffer>>2]|0;
       $33 = HEAP32[$5>>2]|0;
       $34 = $33 << 1;
       _memcpy(($31|0),($32|0),($34|0))|0;
       HEAP32[$6>>2] = $20;
       HEAP32[$indexBuffer>>2] = $31;
       break;
      }
     }
    } while(0);
    $35 = ($17|0)==(0);
    if (!($35)) {
     $36 = HEAP32[$indexBuffer>>2]|0;
     $destOffset$08 = $18;$q$07 = 0;$srcOffset$09 = $11;
     while(1) {
      $37 = (($36) + ($srcOffset$09<<1)|0);
      $38 = HEAP16[$37>>1]|0;
      $39 = (($36) + ($destOffset$08<<1)|0);
      HEAP16[$39>>1] = $38;
      $40 = (($srcOffset$09) + 1)|0;
      $41 = (($36) + ($40<<1)|0);
      $42 = HEAP16[$41>>1]|0;
      $43 = (($destOffset$08) + 1)|0;
      $44 = (($36) + ($43<<1)|0);
      HEAP16[$44>>1] = $42;
      $45 = (($srcOffset$09) + 2)|0;
      $46 = (($36) + ($45<<1)|0);
      $47 = HEAP16[$46>>1]|0;
      $48 = (($destOffset$08) + 2)|0;
      $49 = (($36) + ($48<<1)|0);
      HEAP16[$49>>1] = $47;
      $50 = HEAP16[$37>>1]|0;
      $51 = (($destOffset$08) + 3)|0;
      $52 = (($36) + ($51<<1)|0);
      HEAP16[$52>>1] = $50;
      $53 = HEAP16[$46>>1]|0;
      $54 = (($destOffset$08) + 4)|0;
      $55 = (($36) + ($54<<1)|0);
      HEAP16[$55>>1] = $53;
      $56 = (($srcOffset$09) + 3)|0;
      $57 = (($36) + ($56<<1)|0);
      $58 = HEAP16[$57>>1]|0;
      $59 = (($destOffset$08) + 5)|0;
      $60 = (($36) + ($59<<1)|0);
      HEAP16[$60>>1] = $58;
      $61 = (($destOffset$08) + 6)|0;
      $62 = (($srcOffset$09) + 4)|0;
      $63 = (($q$07) + 1)|0;
      $64 = ($63>>>0)<($17>>>0);
      if ($64) {
       $destOffset$08 = $61;$q$07 = $63;$srcOffset$09 = $62;
      } else {
       break;
      }
     }
    }
    $65 = $18 << 1;
    $66 = ((($9) + (($s$011*56)|0)|0) + 24|0);
    HEAP32[$66>>2] = $65;
    $67 = ((($9) + (($s$011*56)|0)|0) + 28|0);
    HEAP32[$67>>2] = $19;
   }
  }
  $134 = (($s$011) + 1)|0;
  $135 = HEAP32[$1>>2]|0;
  $136 = HEAP32[$submeshes>>2]|0;
  $137 = $135;
  $138 = $136;
  $139 = (($137) - ($138))|0;
  $140 = (($139|0) / 56)&-1;
  $141 = ($134>>>0)<($140>>>0);
  if ($141) {
   $9 = $136;$s$011 = $134;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4MeshC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$0 = 0, $$01 = 0, $$4 = 0, $$45 = 0, $$byval_copy5 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sub = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy5 = sp + 80|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $sub = sp + 24|0;
 $5 = HEAP32[$label>>2]|0;
 HEAP32[$3>>2] = $5;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy5,$mode);
 HEAP32[$this>>2] = ((585488 + 8|0));
 $6 = (($this) + 36|0);
 $7 = (($this) + 44|0);
 $8 = (($this) + 48|0);
 $9 = (($this) + 52|0);
 $10 = (($this) + 56|0);
 $11 = (($this) + 64|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 68|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 60|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 HEAP32[$13>>2] = 61;
 $14 = (($this) + 72|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 80|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 84|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 76|0);
 HEAP32[$17>>2] = 61;
 $18 = (($this) + 88|0);
 $19 = (($this) + 108|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 112|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 104|0);
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;
 HEAP32[$21>>2] = 61;
 $22 = (($this) + 116|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 120|0);
 HEAP32[$23>>2] = $5;
 $24 = (($this) + 124|0);
 $25 = (($this) + 128|0);
 $26 = (($this) + 136|0);
 $27 = (($this) + 140|0);
 ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;
 HEAP32[$27>>2] = $5;
 $28 = (($this) + 144|0);
 $29 = (($this) + 148|0);
 $30 = (($this) + 168|0);
 $31 = (($this) + 180|0);
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP32[$30+16>>2]=0|0;HEAP32[$30+20>>2]=0|0;
 ;HEAP32[$28+0>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;HEAP32[$28+12>>2]=0|0;HEAP32[$28+16>>2]=0|0;
 ;HEAP32[$30+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[616680+8>>2]|0;
 ;HEAP32[$31+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[616680+8>>2]|0;
 $32 = (($this) + 192|0);
 __THREW__ = 0;
 invoke_vi(3451,($32|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $86 = ___cxa_find_matching_catch()|0;
  $87 = tempRet0;
  $$4 = $87;$$45 = $86;
 } else {
  $35 = (($this) + 212|0);
  $36 = (($this) + 216|0);
  HEAP32[$35>>2] = $35;
  HEAP32[$36>>2] = $35;
  $37 = (($this) + 220|0);
  $38 = (($this) + 224|0);
  HEAP32[$37>>2] = $37;
  HEAP32[$38>>2] = $37;
  $39 = (($this) + 228|0);
  $40 = (($this) + 232|0);
  $41 = (($this) + 272|0);
  dest=$39+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP8[$41>>0] = 1;
  $42 = (($this) + 273|0);
  HEAP8[$42>>0] = 1;
  $43 = (($this) + 274|0);
  HEAP8[$43>>0] = 0;
  $44 = (($this) + 275|0);
  HEAP8[$44>>0] = 0;
  $45 = (($this) + 276|0);
  HEAP8[$45>>0] = 0;
  $46 = HEAP32[628248>>2]|0;
  HEAP32[$4>>2] = $46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
  $47 = (invoke_iiiiiii(103,184,($$byval_copy5|0),0,16,(585592|0),82)|0);
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  do {
   if ($49) {
    label = 11;
   } else {
    HEAP32[$47>>2] = ((587472 + 8|0));
    $50 = (($47) + 4|0);
    HEAP32[$50>>2] = 1;
    HEAP32[$47>>2] = ((587456 + 8|0));
    $51 = (($47) + 8|0);
    __THREW__ = 0;
    invoke_vi(3452,($51|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $90 = ___cxa_find_matching_catch()|0;
     $91 = tempRet0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_viiiiii(97,($47|0),($$byval_copy5|0),0,16,(585592|0),82);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if (!($93)) {
      $$0 = $91;$$01 = $90;
      break;
     }
     $125 = ___cxa_find_matching_catch(0|0)|0;
     $126 = tempRet0;
     ___clang_call_terminate($125);
     // unreachable;
    }
    $54 = (($47) + 108|0);
    $55 = (($47) + 124|0);
    ;HEAP32[$54+0>>2]=0|0;HEAP32[$54+4>>2]=0|0;HEAP32[$54+8>>2]=0|0;HEAP32[$54+12>>2]=0|0;
    HEAP32[$55>>2] = $5;
    $56 = (($47) + 128|0);
    HEAP32[$56>>2] = 0;
    $57 = (($47) + 132|0);
    HEAP32[$57>>2] = 0;
    $58 = (($47) + 136|0);
    HEAP32[$58>>2] = 0;
    $59 = (($47) + 140|0);
    HEAP32[$59>>2] = $5;
    $60 = (($47) + 144|0);
    HEAP32[$60>>2] = 0;
    $61 = (($47) + 148|0);
    HEAP32[$61>>2] = 0;
    $62 = (($47) + 152|0);
    HEAP32[$62>>2] = 0;
    $63 = (($47) + 156|0);
    HEAP32[$63>>2] = $5;
    $64 = (($47) + 160|0);
    HEAP32[$64>>2] = 0;
    $65 = (($47) + 164|0);
    HEAP32[$65>>2] = 0;
    $66 = (($47) + 168|0);
    HEAP32[$66>>2] = 0;
    $67 = (($47) + 172|0);
    HEAP32[$67>>2] = $5;
    $68 = (($47) + 176|0);
    HEAP32[$68>>2] = 0;
    $69 = (($47) + 180|0);
    HEAP32[$69>>2] = 0;
    $70 = (($this) + 28|0);
    HEAP32[$70>>2] = $47;
    $71 = (($this) + 164|0);
    HEAP32[$71>>2] = -1;
    $72 = (($sub) + 32|0);
    $73 = (($$byval_copy5) + 12|0);
    ;HEAP32[$sub+0>>2]=0|0;HEAP32[$sub+4>>2]=0|0;HEAP32[$sub+8>>2]=0|0;HEAP32[$sub+12>>2]=0|0;HEAP32[$sub+16>>2]=0|0;HEAP32[$sub+20>>2]=0|0;HEAP32[$sub+24>>2]=0|0;HEAP32[$sub+28>>2]=0|0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[616680+8>>2]|0;
    ;HEAP32[$73+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[616680+8>>2]|0;
    ;HEAP32[$72+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$$byval_copy5+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$$byval_copy5+8>>2]|0;HEAP32[$72+12>>2]=HEAP32[$$byval_copy5+12>>2]|0;HEAP32[$72+16>>2]=HEAP32[$$byval_copy5+16>>2]|0;HEAP32[$72+20>>2]=HEAP32[$$byval_copy5+20>>2]|0;
    $74 = HEAP32[$8>>2]|0;
    $75 = HEAP32[$9>>2]|0;
    $76 = ($74|0)==($75|0);
    if ($76) {
     __THREW__ = 0;
     invoke_vii(2666,($7|0),($sub|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      label = 11;
      break;
     }
     $82 = (($this) + 32|0);
     HEAP8[$82>>0] = 0;
     $83 = (($this) + 33|0);
     HEAP8[$83>>0] = 1;
     $84 = (($this) + 34|0);
     HEAP8[$84>>0] = 0;
     $85 = (($this) + 35|0);
     HEAP8[$85>>0] = 0;
     HEAP32[$6>>2] = 0;
     STACKTOP = sp;return;
    }
    $77 = ($74|0)==(0|0);
    if ($77) {
     $79 = 0;
    } else {
     dest=$74+0|0; src=$sub+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $$pre$i = HEAP32[$8>>2]|0;
     $79 = $$pre$i;
    }
    $78 = (($79) + 56|0);
    HEAP32[$8>>2] = $78;
    $82 = (($this) + 32|0);
    HEAP8[$82>>0] = 0;
    $83 = (($this) + 33|0);
    HEAP8[$83>>0] = 1;
    $84 = (($this) + 34|0);
    HEAP8[$84>>0] = 0;
    $85 = (($this) + 35|0);
    HEAP8[$85>>0] = 0;
    HEAP32[$6>>2] = 0;
    STACKTOP = sp;return;
   }
  } while(0);
  if ((label|0) == 11) {
   $88 = ___cxa_find_matching_catch()|0;
   $89 = tempRet0;
   $$0 = $89;$$01 = $88;
  }
  __THREW__ = 0;
  invoke_vi(3453,($40|0));
  $94 = __THREW__; __THREW__ = 0;
  $95 = $94&1;
  if ($95) {
   $125 = ___cxa_find_matching_catch(0|0)|0;
   $126 = tempRet0;
   ___clang_call_terminate($125);
   // unreachable;
  }
  ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;
  __THREW__ = 0;
  invoke_vi(3454,($32|0));
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   $125 = ___cxa_find_matching_catch(0|0)|0;
   $126 = tempRet0;
   ___clang_call_terminate($125);
   // unreachable;
  } else {
   $$4 = $$0;$$45 = $$01;
  }
 }
 $98 = HEAP32[$29>>2]|0;
 $99 = ($98|0)>(-1);
 do {
  if ($99) {
   $100 = HEAP32[$26>>2]|0;
   $101 = HEAP32[$27>>2]|0;
   HEAP32[$0>>2] = $101;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($100|0),($$byval_copy5|0));
   $102 = __THREW__; __THREW__ = 0;
   $103 = $102&1;
   if ($103) {
    $125 = ___cxa_find_matching_catch(0|0)|0;
    $126 = tempRet0;
    ___clang_call_terminate($125);
    // unreachable;
   } else {
    HEAP32[$26>>2] = 0;
    break;
   }
  }
 } while(0);
 $104 = HEAP32[$25>>2]|0;
 $105 = ($104|0)>(-1);
 do {
  if ($105) {
   $106 = HEAP32[$22>>2]|0;
   $107 = HEAP32[$23>>2]|0;
   HEAP32[$1>>2] = $107;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($106|0),($$byval_copy5|0));
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if ($109) {
    $125 = ___cxa_find_matching_catch(0|0)|0;
    $126 = tempRet0;
    ___clang_call_terminate($125);
    // unreachable;
   } else {
    HEAP32[$22>>2] = 0;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3455,($10|0));
 $110 = __THREW__; __THREW__ = 0;
 $111 = $110&1;
 if ($111) {
  $125 = ___cxa_find_matching_catch(0|0)|0;
  $126 = tempRet0;
  ___clang_call_terminate($125);
  // unreachable;
 }
 $112 = HEAP32[$7>>2]|0;
 $113 = ($112|0)==(0|0);
 if (!($113)) {
  $114 = HEAP32[$8>>2]|0;
  $115 = ($114|0)==($112|0);
  if (!($115)) {
   $__new_last2$i$i$i$i$i = $112;
   $scevgep$i$i$i$i$i = (($114) + -56|0);
   $116 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($116)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $117 = (($uglygep3$i$i$i$i$i>>>0) / 56)&-1;
   $118 = $117 ^ -1;
   $scevgep4$i$i$i$i$i = (($114) + (($118*56)|0)|0);
   HEAP32[$8>>2] = $scevgep4$i$i$i$i$i;
  }
  HEAP32[$2>>2] = 10;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($112|0),($$byval_copy5|0));
  $119 = __THREW__; __THREW__ = 0;
  $120 = $119&1;
  if ($120) {
   $121 = ___cxa_find_matching_catch()|0;
   $122 = tempRet0;
   ___cxa_call_unexpected(($121|0));
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $123 = __THREW__; __THREW__ = 0;
 $124 = $123&1;
 if ($124) {
  $125 = ___cxa_find_matching_catch(0|0)|0;
  $126 = tempRet0;
  ___clang_call_terminate($125);
  // unreachable;
 } else {
  ___resumeException($$45|0);
  // unreachable;
 }
}
function __ZN4Mesh17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $inData$c$i$i = 0, $node$01$i = 0, $node$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($$byval_copy) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($$byval_copy) + 4|0);
 $inData$c$i$i = $this;
 HEAP32[$2>>2] = $inData$c$i$i;
 HEAP32[$$byval_copy>>2] = 43;
 $3 = (($this) + 216|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 212|0);
 $6 = ($4|0)==($5|0);
 if ($6) {
  $15 = $4;
 } else {
  $8 = $4;
  while(1) {
   $7 = (($8) + 4|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = (($8) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   __ZN5Unity17SendMessageDirectER6ObjectRK17MessageIdentifierR11MessageData($11,564416,$$byval_copy);
   $12 = ($9|0)==($5|0);
   if ($12) {
    break;
   } else {
    $8 = $9;
   }
  }
  $$pre = HEAP32[$3>>2]|0;
  $15 = $$pre;
 }
 $13 = (($this) + 212|0);
 $14 = ($15|0)==($13|0);
 if (!($14)) {
  $node$01$i = $15;
  while(1) {
   $16 = (($node$01$i) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   HEAP32[$node$01$i>>2] = 0;
   HEAP32[$16>>2] = 0;
   $18 = ($17|0)==($13|0);
   if ($18) {
    break;
   } else {
    $node$01$i = $17;
   }
  }
 }
 HEAP32[$3>>2] = $13;
 HEAP32[$13>>2] = $13;
 $19 = (($this) + 220|0);
 __ZN17IntermediateUsers6NotifyE18IntermediateNotify($19,0);
 $20 = (($this) + 224|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($19|0);
 if (!($22)) {
  $node$01$i$i = $21;
  while(1) {
   $23 = (($node$01$i$i) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$node$01$i$i>>2] = 0;
   HEAP32[$23>>2] = 0;
   $25 = ($24|0)==($19|0);
   if ($25) {
    break;
   } else {
    $node$01$i$i = $24;
   }
  }
 }
 HEAP32[$20>>2] = $19;
 HEAP32[$19>>2] = $19;
 $26 = (($this) + 192|0);
 __ZN17CollisionMeshData7CleanupEv($26);
 __ZN4Mesh19UnloadFromGfxDeviceEv($this);
 $27 = (($this) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[628248>>2]|0;
 $30 = (($28) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + -1)|0;
 HEAP32[$30>>2] = $32;
 $33 = HEAP32[$30>>2]|0;
 $34 = ($33|0)==(0);
 if ($34) {
  $35 = HEAP32[$28>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_vi[$36 & 4095]($28);
  HEAP32[$0>>2] = $29;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy);
 }
 HEAP32[$27>>2] = 0;
 $37 = (($this) + 36|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 __ZN17UniqueIDGenerator8RemoveIDEj(585464,$38);
 HEAP32[$37>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4Mesh19UnloadFromGfxDeviceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 232|0);
 __ZN4Mesh12UploadedData6UnloadEv($0);
 $1 = (($this) + 268|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (__Z12GetGfxDevicev()|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 292|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$2>>2]|0;
  FUNCTION_TABLE_vii[$8 & 4095]($5,$9);
  HEAP32[$2>>2] = 0;
 }
 $10 = (($this) + 156|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = (__Z12GetGfxDevicev()|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 292|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$16 & 4095]($13,$17);
  HEAP32[$10>>2] = 0;
 }
 $18 = (($this) + 160|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $26 = (($this) + 273|0);
  HEAP8[$26>>0] = 1;
  $27 = (($this) + 272|0);
  HEAP8[$27>>0] = 1;
  STACKTOP = sp;return;
 }
 $21 = (__Z12GetGfxDevicev()|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 292|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vii[$24 & 4095]($21,$25);
 HEAP32[$18>>2] = 0;
 $26 = (($this) + 273|0);
 HEAP8[$26>>0] = 1;
 $27 = (($this) + 272|0);
 HEAP8[$27>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN4Mesh27SwizzleVertexColorsIfNeededEb($this,$transformData) {
 $this = $this|0;
 $transformData = $transformData|0;
 var $$ph = 0, $$ph37 = 0, $$ph40$ph = 0, $$ph42 = 0, $$ph43 = 0, $$ph47$ph = 0, $$pr = 0, $$pr41$pr = 0, $$pr44 = 0, $$pr48$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 18|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = (($1) + 19|0);
 $5 = ($3<<24>>24)==(2);
 if (!($5)) {
  $6 = (($this) + 276|0);
  HEAP8[$6>>0] = 0;
  STACKTOP = sp;return;
 }
 $7 = HEAP8[((640792 + 258|0))>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = (($this) + 276|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($7<<24>>24)==($10<<24>>24);
 if ($11) {
  STACKTOP = sp;return;
 }
 do {
  if ($transformData) {
   $12 = HEAP8[$4>>0]|0;
   $13 = ($12&255)<(4);
   if ($8) {
    if ($13) {
     break;
    }
    $93 = (($1) + 92|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(0|0);
    if ($95) {
     $$ph42 = 1;$$ph43 = 0;
    } else {
     $96 = (($1) + 16|0);
     $97 = HEAP8[$96>>0]|0;
     $98 = $97&255;
     $99 = ((($1) + (($98*12)|0)|0) + 50|0);
     $100 = HEAP8[$99>>0]|0;
     $101 = $100&255;
     $102 = ((($1) + (($98*12)|0)|0) + 44|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = (($1) + 17|0);
     $105 = HEAP8[$104>>0]|0;
     $106 = $105&255;
     $107 = (($106) + ($103))|0;
     $108 = (($94) + ($107)|0);
     $$ph42 = $101;$$ph43 = $108;
    }
    $$pr44 = HEAP8[$4>>0]|0;
    $109 = ($$pr44&255)<(4);
    if ($109) {
     $148 = 0;$170 = 0;$173 = 0;
    } else {
     $110 = (($1) + 92|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ($111|0)==(0|0);
     if ($112) {
      $$ph47$ph = 0;
     } else {
      $113 = (($1) + 100|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = (($1) + 16|0);
      $116 = HEAP8[$115>>0]|0;
      $117 = $116&255;
      $118 = ((($1) + (($117*12)|0)|0) + 50|0);
      $119 = HEAP8[$118>>0]|0;
      $120 = $119&255;
      $121 = ((($1) + (($117*12)|0)|0) + 44|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = (($1) + 17|0);
      $124 = HEAP8[$123>>0]|0;
      $125 = $124&255;
      $126 = Math_imul($120, $114)|0;
      $127 = (($126) + ($122))|0;
      $128 = (($127) + ($125))|0;
      $129 = (($111) + ($128)|0);
      $$ph47$ph = $129;
     }
     $$pr48$pr = HEAP8[$4>>0]|0;
     $130 = ($$pr48$pr&255)<(4);
     if ($130) {
      $148 = $$ph47$ph;$170 = 0;$173 = 0;
     } else {
      $131 = (($1) + 92|0);
      $132 = HEAP32[$131>>2]|0;
      $133 = ($132|0)==(0|0);
      if ($133) {
       $148 = $$ph47$ph;$170 = 1;$173 = 0;
      } else {
       $134 = (($1) + 16|0);
       $135 = HEAP8[$134>>0]|0;
       $136 = $135&255;
       $137 = ((($1) + (($136*12)|0)|0) + 50|0);
       $138 = HEAP8[$137>>0]|0;
       $139 = $138&255;
       $140 = ((($1) + (($136*12)|0)|0) + 44|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = (($1) + 17|0);
       $143 = HEAP8[$142>>0]|0;
       $144 = $143&255;
       $145 = (($144) + ($141))|0;
       $146 = (($132) + ($145)|0);
       $148 = $$ph47$ph;$170 = $139;$173 = $146;
      }
     }
    }
    $147 = ($$ph43|0)==($148|0);
    if ($147) {
     break;
    } else {
     $150 = $$ph43;$167 = $173;
    }
    while(1) {
     $149 = (($150) + 2|0);
     $151 = HEAP8[$149>>0]|0;
     $152 = (($150) + 1|0);
     $153 = HEAP8[$152>>0]|0;
     $154 = HEAP8[$150>>0]|0;
     $155 = (($150) + 3|0);
     $156 = HEAP8[$155>>0]|0;
     $157 = $156&255;
     $158 = $157 << 24;
     $159 = $154&255;
     $160 = $159 << 16;
     $161 = $153&255;
     $162 = $161 << 8;
     $163 = $151&255;
     $164 = $162 | $163;
     $165 = $164 | $160;
     $166 = $165 | $158;
     HEAP32[$167>>2] = $166;
     $168 = (($150) + ($$ph42)|0);
     $169 = (($167) + ($170)|0);
     $171 = ($168|0)==($148|0);
     if ($171) {
      break;
     } else {
      $150 = $168;$167 = $169;
     }
    }
   } else {
    if ($13) {
     break;
    }
    $14 = (($1) + 92|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     $$ph = 1;$$ph37 = 0;
    } else {
     $17 = (($1) + 16|0);
     $18 = HEAP8[$17>>0]|0;
     $19 = $18&255;
     $20 = ((($1) + (($19*12)|0)|0) + 50|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = $21&255;
     $23 = ((($1) + (($19*12)|0)|0) + 44|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($1) + 17|0);
     $26 = HEAP8[$25>>0]|0;
     $27 = $26&255;
     $28 = (($27) + ($24))|0;
     $29 = (($15) + ($28)|0);
     $$ph = $22;$$ph37 = $29;
    }
    $$pr = HEAP8[$4>>0]|0;
    $30 = ($$pr&255)<(4);
    if ($30) {
     $172 = 0;$69 = 0;$91 = 0;
    } else {
     $31 = (($1) + 92|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      $$ph40$ph = 0;
     } else {
      $34 = (($1) + 100|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = (($1) + 16|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = $37&255;
      $39 = ((($1) + (($38*12)|0)|0) + 50|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = $40&255;
      $42 = ((($1) + (($38*12)|0)|0) + 44|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = (($1) + 17|0);
      $45 = HEAP8[$44>>0]|0;
      $46 = $45&255;
      $47 = Math_imul($41, $35)|0;
      $48 = (($47) + ($43))|0;
      $49 = (($48) + ($46))|0;
      $50 = (($32) + ($49)|0);
      $$ph40$ph = $50;
     }
     $$pr41$pr = HEAP8[$4>>0]|0;
     $51 = ($$pr41$pr&255)<(4);
     if ($51) {
      $172 = 0;$69 = $$ph40$ph;$91 = 0;
     } else {
      $52 = (($1) + 92|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==(0|0);
      if ($54) {
       $172 = 0;$69 = $$ph40$ph;$91 = 1;
      } else {
       $55 = (($1) + 16|0);
       $56 = HEAP8[$55>>0]|0;
       $57 = $56&255;
       $58 = ((($1) + (($57*12)|0)|0) + 50|0);
       $59 = HEAP8[$58>>0]|0;
       $60 = $59&255;
       $61 = ((($1) + (($57*12)|0)|0) + 44|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($1) + 17|0);
       $64 = HEAP8[$63>>0]|0;
       $65 = $64&255;
       $66 = (($65) + ($62))|0;
       $67 = (($53) + ($66)|0);
       $172 = $67;$69 = $$ph40$ph;$91 = $60;
      }
     }
    }
    $68 = ($$ph37|0)==($69|0);
    if ($68) {
     break;
    } else {
     $71 = $$ph37;$88 = $172;
    }
    while(1) {
     $70 = (($71) + 2|0);
     $72 = HEAP8[$70>>0]|0;
     $73 = (($71) + 1|0);
     $74 = HEAP8[$73>>0]|0;
     $75 = HEAP8[$71>>0]|0;
     $76 = (($71) + 3|0);
     $77 = HEAP8[$76>>0]|0;
     $78 = $77&255;
     $79 = $78 << 24;
     $80 = $75&255;
     $81 = $80 << 16;
     $82 = $74&255;
     $83 = $82 << 8;
     $84 = $72&255;
     $85 = $83 | $84;
     $86 = $85 | $81;
     $87 = $86 | $79;
     HEAP32[$88>>2] = $87;
     $89 = (($71) + ($$ph)|0);
     $90 = (($88) + ($91)|0);
     $92 = ($89|0)==($69|0);
     if ($92) {
      break;
     } else {
      $71 = $89;$88 = $90;
     }
    }
   }
  }
 } while(0);
 HEAP8[$9>>0] = $7;
 STACKTOP = sp;return;
}
function __ZN4Mesh21UnswizzleVertexColorsEb($this,$transformData) {
 $this = $this|0;
 $transformData = $transformData|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 276|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 if ($transformData) {
  $3 = (($this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 18|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(2);
  if ($7) {
   $8 = (($4) + 19|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9&255)<(4);
   if ($10) {
    $96 = 0;$97 = 0;
    label = 8;
   } else {
    $11 = (($4) + 92|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $98 = 1;$99 = 0;
    } else {
     $14 = (($4) + 16|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = $15&255;
     $17 = ((($4) + (($16*12)|0)|0) + 50|0);
     $18 = HEAP8[$17>>0]|0;
     $19 = $18&255;
     $20 = ((($4) + (($16*12)|0)|0) + 44|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($4) + 17|0);
     $23 = HEAP8[$22>>0]|0;
     $24 = $23&255;
     $25 = (($24) + ($21))|0;
     $26 = (($12) + ($25)|0);
     $98 = $19;$99 = $26;
    }
    if ($7) {
     $96 = $99;$97 = $98;
     label = 8;
    } else {
     $100 = 0;$70 = $99;$71 = 0;$92 = $98;$94 = 0;
    }
   }
   if ((label|0) == 8) {
    $27 = (($4) + 19|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ($28&255)<(4);
    if ($29) {
     $101 = 0;
    } else {
     $30 = (($4) + 92|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==(0|0);
     if ($32) {
      $101 = 0;
     } else {
      $33 = (($4) + 100|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($4) + 16|0);
      $36 = HEAP8[$35>>0]|0;
      $37 = $36&255;
      $38 = ((($4) + (($37*12)|0)|0) + 50|0);
      $39 = HEAP8[$38>>0]|0;
      $40 = $39&255;
      $41 = ((($4) + (($37*12)|0)|0) + 44|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (($4) + 17|0);
      $44 = HEAP8[$43>>0]|0;
      $45 = $44&255;
      $46 = Math_imul($40, $34)|0;
      $47 = (($46) + ($42))|0;
      $48 = (($47) + ($45))|0;
      $49 = (($31) + ($48)|0);
      $101 = $49;
     }
    }
    if ($7) {
     $50 = (($4) + 19|0);
     $51 = HEAP8[$50>>0]|0;
     $52 = ($51&255)<(4);
     if ($52) {
      $100 = 0;$70 = $96;$71 = $101;$92 = $97;$94 = 0;
     } else {
      $53 = (($4) + 92|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($54|0)==(0|0);
      if ($55) {
       $100 = 0;$70 = $96;$71 = $101;$92 = $97;$94 = 1;
      } else {
       $56 = (($4) + 16|0);
       $57 = HEAP8[$56>>0]|0;
       $58 = $57&255;
       $59 = ((($4) + (($58*12)|0)|0) + 50|0);
       $60 = HEAP8[$59>>0]|0;
       $61 = $60&255;
       $62 = ((($4) + (($58*12)|0)|0) + 44|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = (($4) + 17|0);
       $65 = HEAP8[$64>>0]|0;
       $66 = $65&255;
       $67 = (($66) + ($63))|0;
       $68 = (($54) + ($67)|0);
       $100 = $68;$70 = $96;$71 = $101;$92 = $97;$94 = $61;
      }
     }
    } else {
     $100 = 0;$70 = $96;$71 = $101;$92 = $97;$94 = 0;
    }
   }
   $69 = ($70|0)==($71|0);
   if (!($69)) {
    $73 = $70;$90 = $100;
    while(1) {
     $72 = (($73) + 2|0);
     $74 = HEAP8[$72>>0]|0;
     $75 = (($73) + 1|0);
     $76 = HEAP8[$75>>0]|0;
     $77 = HEAP8[$73>>0]|0;
     $78 = (($73) + 3|0);
     $79 = HEAP8[$78>>0]|0;
     $80 = $79&255;
     $81 = $80 << 24;
     $82 = $77&255;
     $83 = $82 << 16;
     $84 = $76&255;
     $85 = $84 << 8;
     $86 = $74&255;
     $87 = $85 | $86;
     $88 = $87 | $83;
     $89 = $88 | $81;
     HEAP32[$90>>2] = $89;
     $91 = (($73) + ($92)|0);
     $93 = (($90) + ($94)|0);
     $95 = ($91|0)==($71|0);
     if ($95) {
      break;
     } else {
      $73 = $91;$90 = $93;
     }
    }
   }
  }
 }
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK4Mesh18ExtractVertexArrayEP8Vector3f($this,$destination) {
 $this = $this|0;
 $destination = $destination|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $destInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $destInfo = sp;
 $0 = sp + 100|0;
 __ZN14VertexDataInfoC2Ev($destInfo);
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP8[$0>>0] = 0;
 $5 = (($0) + 1|0);
 HEAP8[$5>>0] = 3;
 __ZN14VertexDataInfo18SetAsSingleChannelEPvj13ShaderChannelRK22ChannelFormatDimension($destInfo,$destination,$4,0,$0);
 $6 = HEAP32[$1>>2]|0;
 $7 = (($6) + 100|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($destInfo) + 88|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($6) + 8|0);
 __Z22CopyVertexDataChannelsjjRK14VertexDataInfoRS_($8,$10,$11,$destInfo);
 STACKTOP = sp;return;
}
function __ZNK4Mesh17ExtractColorArrayEP11ColorRGBA32($this,$destination) {
 $this = $this|0;
 $destination = $destination|0;
 var $$01$i = 0, $$01$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $destInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $destInfo = sp;
 $0 = sp + 100|0;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 18|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(2);
 if (!($5)) {
  __ZN14VertexDataInfoC2Ev($destInfo);
  $124 = HEAP32[$1>>2]|0;
  $125 = (($124) + 100|0);
  $126 = HEAP32[$125>>2]|0;
  HEAP8[$0>>0] = 2;
  $127 = (($0) + 1|0);
  HEAP8[$127>>0] = 4;
  __ZN14VertexDataInfo18SetAsSingleChannelEPvj13ShaderChannelRK22ChannelFormatDimension($destInfo,$destination,$126,2,$0);
  $128 = HEAP32[$1>>2]|0;
  $129 = (($128) + 100|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($destInfo) + 88|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = (($128) + 8|0);
  __Z22CopyVertexDataChannelsjjRK14VertexDataInfoRS_($130,$132,$133,$destInfo);
  STACKTOP = sp;return;
 }
 $6 = (($this) + 276|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = (($2) + 19|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10&255)<(4);
 if ($8) {
  if ($11) {
   $116 = 0;$121 = 0;
  } else {
   $76 = (($2) + 92|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if ($78) {
    $116 = 0;$121 = 1;
   } else {
    $79 = (($2) + 16|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = $80&255;
    $82 = ((($2) + (($81*12)|0)|0) + 50|0);
    $83 = HEAP8[$82>>0]|0;
    $84 = $83&255;
    $85 = ((($2) + (($81*12)|0)|0) + 44|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($2) + 17|0);
    $88 = HEAP8[$87>>0]|0;
    $89 = $88&255;
    $90 = (($89) + ($86))|0;
    $91 = (($77) + ($90)|0);
    $116 = $91;$121 = $84;
   }
  }
  $92 = (($2) + 19|0);
  $93 = HEAP8[$92>>0]|0;
  $94 = ($93&255)<(4);
  if ($94) {
   $117 = 0;
  } else {
   $95 = (($2) + 92|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0|0);
   if ($97) {
    $117 = 0;
   } else {
    $98 = (($2) + 100|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($2) + 16|0);
    $101 = HEAP8[$100>>0]|0;
    $102 = $101&255;
    $103 = ((($2) + (($102*12)|0)|0) + 50|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = $104&255;
    $106 = ((($2) + (($102*12)|0)|0) + 44|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($2) + 17|0);
    $109 = HEAP8[$108>>0]|0;
    $110 = $109&255;
    $111 = Math_imul($105, $99)|0;
    $112 = (($111) + ($107))|0;
    $113 = (($112) + ($110))|0;
    $114 = (($96) + ($113)|0);
    $117 = $114;
   }
  }
  $115 = ($116|0)==($117|0);
  if ($115) {
   STACKTOP = sp;return;
  } else {
   $$01$i$i = $destination;$119 = $116;
  }
  while(1) {
   $118 = HEAP32[$119>>2]|0;
   HEAP32[$$01$i$i>>2] = $118;
   $120 = (($119) + ($121)|0);
   $122 = (($$01$i$i) + 4|0);
   $123 = ($120|0)==($117|0);
   if ($123) {
    break;
   } else {
    $$01$i$i = $122;$119 = $120;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   $52 = 0;$73 = 0;
  } else {
   $12 = (($2) + 92|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $52 = 0;$73 = 1;
   } else {
    $15 = (($2) + 16|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = $16&255;
    $18 = ((($2) + (($17*12)|0)|0) + 50|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = $19&255;
    $21 = ((($2) + (($17*12)|0)|0) + 44|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($2) + 17|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24&255;
    $26 = (($25) + ($22))|0;
    $27 = (($13) + ($26)|0);
    $52 = $27;$73 = $20;
   }
  }
  $28 = (($2) + 19|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = ($29&255)<(4);
  if ($30) {
   $53 = 0;
  } else {
   $31 = (($2) + 92|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    $53 = 0;
   } else {
    $34 = (($2) + 100|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($2) + 16|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = $37&255;
    $39 = ((($2) + (($38*12)|0)|0) + 50|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = $40&255;
    $42 = ((($2) + (($38*12)|0)|0) + 44|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($2) + 17|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = $45&255;
    $47 = Math_imul($41, $35)|0;
    $48 = (($47) + ($43))|0;
    $49 = (($48) + ($46))|0;
    $50 = (($32) + ($49)|0);
    $53 = $50;
   }
  }
  $51 = ($52|0)==($53|0);
  if ($51) {
   STACKTOP = sp;return;
  } else {
   $$01$i = $destination;$55 = $52;
  }
  while(1) {
   $54 = (($55) + 2|0);
   $56 = HEAP8[$54>>0]|0;
   $57 = (($55) + 1|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = HEAP8[$55>>0]|0;
   $60 = (($55) + 3|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61&255;
   $63 = $62 << 24;
   $64 = $59&255;
   $65 = $64 << 16;
   $66 = $58&255;
   $67 = $66 << 8;
   $68 = $56&255;
   $69 = $67 | $68;
   $70 = $69 | $65;
   $71 = $70 | $63;
   HEAP32[$$01$i>>2] = $71;
   $72 = (($55) + ($73)|0);
   $74 = (($$01$i) + 4|0);
   $75 = ($72|0)==($53|0);
   if ($75) {
    break;
   } else {
    $$01$i = $74;$55 = $72;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNK4Mesh17ExtractColorArrayEP10ColorRGBAf($this,$destination) {
 $this = $this|0;
 $destination = $destination|0;
 var $$01$i = 0, $$01$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $destInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $destInfo = sp;
 $0 = sp + 100|0;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 18|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(2);
 if (!($5)) {
  __ZN14VertexDataInfoC2Ev($destInfo);
  $150 = HEAP32[$1>>2]|0;
  $151 = (($150) + 100|0);
  $152 = HEAP32[$151>>2]|0;
  HEAP8[$0>>0] = 0;
  $153 = (($0) + 1|0);
  HEAP8[$153>>0] = 4;
  __ZN14VertexDataInfo18SetAsSingleChannelEPvj13ShaderChannelRK22ChannelFormatDimension($destInfo,$destination,$152,2,$0);
  $154 = HEAP32[$1>>2]|0;
  $155 = (($154) + 100|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = (($destInfo) + 88|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = (($154) + 8|0);
  __Z22CopyVertexDataChannelsjjRK14VertexDataInfoRS_($156,$158,$159,$destInfo);
  STACKTOP = sp;return;
 }
 $6 = (($this) + 276|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = (($2) + 19|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10&255)<(4);
 if ($8) {
  if ($11) {
   $121 = 0;$147 = 0;
  } else {
   $81 = (($2) + 92|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==(0|0);
   if ($83) {
    $121 = 0;$147 = 1;
   } else {
    $84 = (($2) + 16|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = ((($2) + (($86*12)|0)|0) + 50|0);
    $88 = HEAP8[$87>>0]|0;
    $89 = $88&255;
    $90 = ((($2) + (($86*12)|0)|0) + 44|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($2) + 17|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = $93&255;
    $95 = (($94) + ($91))|0;
    $96 = (($82) + ($95)|0);
    $121 = $96;$147 = $89;
   }
  }
  $97 = (($2) + 19|0);
  $98 = HEAP8[$97>>0]|0;
  $99 = ($98&255)<(4);
  if ($99) {
   $122 = 0;
  } else {
   $100 = (($2) + 92|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($101|0)==(0|0);
   if ($102) {
    $122 = 0;
   } else {
    $103 = (($2) + 100|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($2) + 16|0);
    $106 = HEAP8[$105>>0]|0;
    $107 = $106&255;
    $108 = ((($2) + (($107*12)|0)|0) + 50|0);
    $109 = HEAP8[$108>>0]|0;
    $110 = $109&255;
    $111 = ((($2) + (($107*12)|0)|0) + 44|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($2) + 17|0);
    $114 = HEAP8[$113>>0]|0;
    $115 = $114&255;
    $116 = Math_imul($110, $104)|0;
    $117 = (($116) + ($112))|0;
    $118 = (($117) + ($115))|0;
    $119 = (($101) + ($118)|0);
    $122 = $119;
   }
  }
  $120 = ($121|0)==($122|0);
  if ($120) {
   STACKTOP = sp;return;
  } else {
   $$01$i$i = $destination;$124 = $121;
  }
  while(1) {
   $123 = HEAP8[$124>>0]|0;
   $125 = $123&255;
   $126 = (Math_fround(($125|0)));
   $127 = Math_fround($126 / Math_fround(255.0));
   $128 = (($124) + 1|0);
   $129 = HEAP8[$128>>0]|0;
   $130 = $129&255;
   $131 = (Math_fround(($130|0)));
   $132 = Math_fround($131 / Math_fround(255.0));
   $133 = (($124) + 2|0);
   $134 = HEAP8[$133>>0]|0;
   $135 = $134&255;
   $136 = (Math_fround(($135|0)));
   $137 = Math_fround($136 / Math_fround(255.0));
   $138 = (($124) + 3|0);
   $139 = HEAP8[$138>>0]|0;
   $140 = $139&255;
   $141 = (Math_fround(($140|0)));
   $142 = Math_fround($141 / Math_fround(255.0));
   HEAPF32[$$01$i$i>>2] = $127;
   $143 = (($$01$i$i) + 4|0);
   HEAPF32[$143>>2] = $132;
   $144 = (($$01$i$i) + 8|0);
   HEAPF32[$144>>2] = $137;
   $145 = (($$01$i$i) + 12|0);
   HEAPF32[$145>>2] = $142;
   $146 = (($124) + ($147)|0);
   $148 = (($$01$i$i) + 16|0);
   $149 = ($146|0)==($122|0);
   if ($149) {
    break;
   } else {
    $$01$i$i = $148;$124 = $146;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   $52 = 0;$78 = 0;
  } else {
   $12 = (($2) + 92|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $52 = 0;$78 = 1;
   } else {
    $15 = (($2) + 16|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = $16&255;
    $18 = ((($2) + (($17*12)|0)|0) + 50|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = $19&255;
    $21 = ((($2) + (($17*12)|0)|0) + 44|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($2) + 17|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24&255;
    $26 = (($25) + ($22))|0;
    $27 = (($13) + ($26)|0);
    $52 = $27;$78 = $20;
   }
  }
  $28 = (($2) + 19|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = ($29&255)<(4);
  if ($30) {
   $53 = 0;
  } else {
   $31 = (($2) + 92|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    $53 = 0;
   } else {
    $34 = (($2) + 100|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($2) + 16|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = $37&255;
    $39 = ((($2) + (($38*12)|0)|0) + 50|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = $40&255;
    $42 = ((($2) + (($38*12)|0)|0) + 44|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($2) + 17|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = $45&255;
    $47 = Math_imul($41, $35)|0;
    $48 = (($47) + ($43))|0;
    $49 = (($48) + ($46))|0;
    $50 = (($32) + ($49)|0);
    $53 = $50;
   }
  }
  $51 = ($52|0)==($53|0);
  if ($51) {
   STACKTOP = sp;return;
  } else {
   $$01$i = $destination;$55 = $52;
  }
  while(1) {
   $54 = (($55) + 2|0);
   $56 = HEAP8[$54>>0]|0;
   $57 = (($55) + 1|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = HEAP8[$55>>0]|0;
   $60 = (($55) + 3|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61&255;
   $63 = $59&255;
   $64 = $58&255;
   $65 = $56&255;
   $66 = (Math_fround(($65|0)));
   $67 = Math_fround($66 / Math_fround(255.0));
   $68 = (Math_fround(($64|0)));
   $69 = Math_fround($68 / Math_fround(255.0));
   $70 = (Math_fround(($63|0)));
   $71 = Math_fround($70 / Math_fround(255.0));
   $72 = (Math_fround(($62|0)));
   $73 = Math_fround($72 / Math_fround(255.0));
   HEAPF32[$$01$i>>2] = $67;
   $74 = (($$01$i) + 4|0);
   HEAPF32[$74>>2] = $69;
   $75 = (($$01$i) + 8|0);
   HEAPF32[$75>>2] = $71;
   $76 = (($$01$i) + 12|0);
   HEAPF32[$76>>2] = $73;
   $77 = (($55) + ($78)|0);
   $79 = (($$01$i) + 16|0);
   $80 = ($77|0)==($53|0);
   if ($80) {
    break;
   } else {
    $$01$i = $79;$55 = $77;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNK4Mesh14ExtractUvArrayEiPfi($this,$uvIndex,$destination,$dimension) {
 $this = $this|0;
 $uvIndex = $uvIndex|0;
 $destination = $destination|0;
 $dimension = $dimension|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $destInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $destInfo = sp;
 $0 = sp + 100|0;
 __ZN14VertexDataInfoC2Ev($destInfo);
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($uvIndex) + 3)|0;
 HEAP8[$0>>0] = 0;
 $6 = (($0) + 1|0);
 $7 = $dimension&255;
 HEAP8[$6>>0] = $7;
 __ZN14VertexDataInfo18SetAsSingleChannelEPvj13ShaderChannelRK22ChannelFormatDimension($destInfo,$destination,$4,$5,$0);
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($destInfo) + 88|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + 8|0);
 __Z22CopyVertexDataChannelsjjRK14VertexDataInfoRS_($10,$12,$13,$destInfo);
 STACKTOP = sp;return;
}
function __ZN4Mesh14ResizeVerticesEjj($this,$count,$shaderChannels) {
 $this = $this|0;
 $count = $count|0;
 $shaderChannels = $shaderChannels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $layout$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $layout$i$i = sp + 16|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 144|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = (($this) + 92|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($this) + 88|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  if ($10) {
   $11 = (($2) + 8|0);
   __ZNK14VertexDataInfo16GetStreamsLayoutEv($layout$i$i,$11);
   $12 = (($layout$i$i) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 & 255;
   $15 = $14 ^ 255;
   $16 = (($layout$i$i) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $17 ^ -1;
   $19 = $15 & $18;
   $20 = (($layout$i$i) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $21 ^ -1;
   $23 = $19 & $22;
   HEAP32[$layout$i$i>>2] = $23;
   ;HEAP32[$0+0>>2]=HEAP32[$layout$i$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$layout$i$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$layout$i$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$layout$i$i+12>>2]|0;
   __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayoutRK19VertexStreamsLayout($this,$count,$shaderChannels,0,588176,$0);
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$0+0>>2]=HEAP32[588160+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[588160+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[588160+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[588160+12>>2]|0;
 __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayoutRK19VertexStreamsLayout($this,$count,$shaderChannels,0,588176,$0);
 STACKTOP = sp;return;
}
function __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayout($this,$count,$shaderChannels,$reformatChannels,$channelsLayout) {
 $this = $this|0;
 $count = $count|0;
 $shaderChannels = $shaderChannels|0;
 $reformatChannels = $reformatChannels|0;
 $channelsLayout = $channelsLayout|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $layout$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $layout$i = sp + 16|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 144|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = (($this) + 92|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($this) + 88|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  if ($10) {
   $11 = (($2) + 8|0);
   __ZNK14VertexDataInfo16GetStreamsLayoutEv($layout$i,$11);
   $12 = (($layout$i) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 & 255;
   $15 = $14 ^ 255;
   $16 = (($layout$i) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = $17 ^ -1;
   $19 = $15 & $18;
   $20 = (($layout$i) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $21 ^ -1;
   $23 = $19 & $22;
   HEAP32[$layout$i>>2] = $23;
   ;HEAP32[$0+0>>2]=HEAP32[$layout$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$layout$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$layout$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$layout$i+12>>2]|0;
   __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayoutRK19VertexStreamsLayout($this,$count,$shaderChannels,$reformatChannels,$channelsLayout,$0);
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$0+0>>2]=HEAP32[588160+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[588160+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[588160+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[588160+12>>2]|0;
 __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayoutRK19VertexStreamsLayout($this,$count,$shaderChannels,$reformatChannels,$channelsLayout,$0);
 STACKTOP = sp;return;
}
function __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayoutRK19VertexStreamsLayout($this,$count,$shaderChannels,$reformatChannels,$channelsLayout,$streamsLayout) {
 $this = $this|0;
 $count = $count|0;
 $shaderChannels = $shaderChannels|0;
 $reformatChannels = $reformatChannels|0;
 $channelsLayout = $channelsLayout|0;
 $streamsLayout = $streamsLayout|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = (($2) + 96|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 ^ -1;
 $7 = $6 & $shaderChannels;
 $8 = $7 | $reformatChannels;
 $9 = $shaderChannels ^ -1;
 $10 = $5 & $9;
 $11 = (($2) + 100|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($count|0);
 $14 = ($8|0)==(0);
 $or$cond = $13 & $14;
 $15 = ($10|0)==(0);
 $or$cond1 = $or$cond & $15;
 if ($or$cond1) {
  STACKTOP = sp;return;
 }
 $16 = $5 & 4;
 $17 = $16 & $8;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = (($channelsLayout) + 4|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(2);
  if (!($21)) {
   __ZN4Mesh21UnswizzleVertexColorsEb($this,1);
  }
 }
 __ZN10VertexData6ResizeEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($3,$count,$8,$10,$streamsLayout,$channelsLayout);
 $22 = HEAP32[$1>>2]|0;
 $23 = (($22) + 144|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = (($22) + 136|0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
  __ZN13dynamic_arrayI13BoneInfluenceLj16EE18resize_initializedEjRKS0_b($26,$count,$0,0);
 }
 $27 = (($this) + 272|0);
 HEAP8[$27>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI13BoneInfluenceLj16EE18resize_initializedEjRKS0_b($this,$size,$t,$double_on_resize) {
 $this = $this|0;
 $size = $size|0;
 $t = $t|0;
 $double_on_resize = $double_on_resize|0;
 var $$01$i = 0, $$byval_copy1 = 0, $$size = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $requested_size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)<($size>>>0);
 do {
  if ($4) {
   if ($double_on_resize) {
    $5 = $2 << 1;
    $6 = ($5>>>0)>($size>>>0);
    $$size = $6 ? $5 : $size;
    $requested_size$0 = $$size;
   } else {
    $requested_size$0 = $size;
   }
   $7 = ($3>>>0)<($requested_size$0>>>0);
   if ($7) {
    $8 = ($2|0)>(-1);
    if ($8) {
     HEAP32[$1>>2] = $requested_size$0;
     $9 = HEAP32[$this>>2]|0;
     $10 = $requested_size$0 << 5;
     $11 = (($this) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     HEAP32[$0>>2] = $12;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($9,$10,16,$$byval_copy1,0,585592,370)|0);
     HEAP32[$this>>2] = $13;
     break;
    } else {
     $14 = $requested_size$0 << 5;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,16,$$byval_copy1,0,585592,352)|0);
     $18 = HEAP32[$this>>2]|0;
     $19 = (($this) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = $20 << 5;
     _memcpy(($17|0),($18|0),($21|0))|0;
     HEAP32[$1>>2] = $requested_size$0;
     HEAP32[$this>>2] = $17;
     break;
    }
   }
  }
 } while(0);
 $22 = (($this) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($size>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + ($size<<5)|0);
 $27 = ($23|0)==($size|0);
 if ($27) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $28 = (($25) + ($23<<5)|0);
 $$01$i = $28;
 while(1) {
  $29 = ($$01$i|0)==(0|0);
  if (!($29)) {
   ;HEAP32[$$01$i+0>>2]=HEAP32[$t+0>>2]|0;HEAP32[$$01$i+4>>2]=HEAP32[$t+4>>2]|0;HEAP32[$$01$i+8>>2]=HEAP32[$t+8>>2]|0;HEAP32[$$01$i+12>>2]=HEAP32[$t+12>>2]|0;HEAP32[$$01$i+16>>2]=HEAP32[$t+16>>2]|0;HEAP32[$$01$i+20>>2]=HEAP32[$t+20>>2]|0;HEAP32[$$01$i+24>>2]=HEAP32[$t+24>>2]|0;HEAP32[$$01$i+28>>2]=HEAP32[$t+28>>2]|0;
  }
  $30 = (($$01$i) + 32|0);
  $31 = ($30|0)==($26|0);
  if ($31) {
   break;
  } else {
   $$01$i = $30;
  }
 }
 HEAP32[$22>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN4Mesh25RecalculateBoundsInternalEv($this) {
 $this = $this|0;
 var $$lcssa16 = Math_fround(0), $$lcssa17 = Math_fround(0), $$lcssa18 = Math_fround(0), $$lcssa19 = Math_fround(0), $$lcssa20 = Math_fround(0), $$lcssa21 = Math_fround(0), $$sum = 0, $$sum2 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0);
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0);
 var $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0);
 var $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$09 = 0, $submesh$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[616664>>2]);
 $1 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $2 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $3 = Math_fround(-$0);
 $4 = Math_fround(-$1);
 $5 = Math_fround(-$2);
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 10|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $11 = (($7) + 11|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12&255)<(3);
  if ($13) {
   $196 = 0;$197 = 0;
   label = 6;
  } else {
   $14 = (($7) + 92|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $198 = 1;$199 = 0;
   } else {
    $17 = (($7) + 8|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18&255;
    $20 = ((($7) + (($19*12)|0)|0) + 50|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21&255;
    $23 = ((($7) + (($19*12)|0)|0) + 44|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($7) + 9|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26&255;
    $28 = (($27) + ($24))|0;
    $29 = (($15) + ($28)|0);
    $198 = $22;$199 = $29;
   }
   if ($10) {
    $196 = $199;$197 = $198;
    label = 6;
   } else {
    $54 = $199;$55 = 0;$81 = $198;
   }
  }
  if ((label|0) == 6) {
   $30 = (($7) + 11|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31&255)<(3);
   if ($32) {
    $54 = $196;$55 = 0;$81 = $197;
   } else {
    $33 = (($7) + 92|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     $54 = $196;$55 = 0;$81 = $197;
    } else {
     $36 = (($7) + 100|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($7) + 8|0);
     $39 = HEAP8[$38>>0]|0;
     $40 = $39&255;
     $41 = ((($7) + (($40*12)|0)|0) + 50|0);
     $42 = HEAP8[$41>>0]|0;
     $43 = $42&255;
     $44 = ((($7) + (($40*12)|0)|0) + 44|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($7) + 9|0);
     $47 = HEAP8[$46>>0]|0;
     $48 = $47&255;
     $49 = Math_imul($43, $37)|0;
     $50 = (($49) + ($45))|0;
     $51 = (($50) + ($48))|0;
     $52 = (($34) + ($51)|0);
     $54 = $196;$55 = $52;$81 = $197;
    }
   }
  }
  $53 = ($54|0)==($55|0);
  if ($53) {
   $$lcssa16 = $5;$$lcssa17 = $4;$$lcssa18 = $3;$$lcssa19 = $2;$$lcssa20 = $1;$$lcssa21 = $0;
  } else {
   $57 = $54;$59 = $0;$64 = $1;$69 = $2;$72 = $3;$75 = $4;$78 = $5;
   while(1) {
    $56 = Math_fround(HEAPF32[$57>>2]);
    $58 = $56 < $59;
    $60 = $58 ? $56 : $59;
    $61 = (($57) + 4|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = $62 < $64;
    $65 = $63 ? $62 : $64;
    $66 = (($57) + 8|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = $67 < $69;
    $70 = $68 ? $67 : $69;
    $71 = $72 < $56;
    $73 = $71 ? $56 : $72;
    $74 = $75 < $62;
    $76 = $74 ? $62 : $75;
    $77 = $78 < $67;
    $79 = $77 ? $67 : $78;
    $80 = (($57) + ($81)|0);
    $82 = ($80|0)==($55|0);
    if ($82) {
     $$lcssa16 = $79;$$lcssa17 = $76;$$lcssa18 = $73;$$lcssa19 = $70;$$lcssa20 = $65;$$lcssa21 = $60;
     break;
    } else {
     $57 = $80;$59 = $60;$64 = $65;$69 = $70;$72 = $73;$75 = $76;$78 = $79;
    }
   }
  }
 } else {
  $$lcssa16 = $5;$$lcssa17 = $4;$$lcssa18 = $3;$$lcssa19 = $2;$$lcssa20 = $1;$$lcssa21 = $0;
 }
 $83 = (($this) + 64|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(0);
 if ($85) {
  $151 = $$lcssa21;$152 = $$lcssa18;$154 = $$lcssa20;$155 = $$lcssa17;$157 = $$lcssa19;$158 = $$lcssa16;
 } else {
  if ($10) {
   $86 = (($7) + 11|0);
   $87 = HEAP8[$86>>0]|0;
   $88 = ($87&255)<(3);
   if ($88) {
    $110 = 0;$112 = 0;
   } else {
    $89 = (($7) + 92|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = ($90|0)==(0|0);
    if ($91) {
     $110 = 1;$112 = 0;
    } else {
     $92 = (($7) + 8|0);
     $93 = HEAP8[$92>>0]|0;
     $94 = $93&255;
     $95 = ((($7) + (($94*12)|0)|0) + 50|0);
     $96 = HEAP8[$95>>0]|0;
     $97 = $96&255;
     $98 = ((($7) + (($94*12)|0)|0) + 44|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = (($7) + 9|0);
     $101 = HEAP8[$100>>0]|0;
     $102 = $101&255;
     $103 = (($102) + ($99))|0;
     $104 = (($90) + ($103)|0);
     $110 = $97;$112 = $104;
    }
   }
  } else {
   $110 = 0;$112 = 0;
  }
  $105 = (($this) + 56|0);
  $106 = HEAP32[$105>>2]|0;
  $128 = $$lcssa21;$131 = $$lcssa20;$134 = $$lcssa19;$137 = $$lcssa18;$140 = $$lcssa17;$143 = $$lcssa16;$i$09 = 0;
  while(1) {
   $107 = ((($106) + (($i$09*40)|0)|0) + 36|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = Math_imul($108, $110)|0;
   $111 = (($112) + ($109)|0);
   $113 = Math_fround(HEAPF32[$111>>2]);
   $114 = (($106) + (($i$09*40)|0)|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = Math_fround($113 + $115);
   $$sum = (($109) + 4)|0;
   $117 = (($112) + ($$sum)|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = ((($106) + (($i$09*40)|0)|0) + 4|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = Math_fround($118 + $120);
   $$sum2 = (($109) + 8)|0;
   $122 = (($112) + ($$sum2)|0);
   $123 = Math_fround(HEAPF32[$122>>2]);
   $124 = ((($106) + (($i$09*40)|0)|0) + 8|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = Math_fround($123 + $125);
   $127 = $116 < $128;
   $129 = $127 ? $116 : $128;
   $130 = $121 < $131;
   $132 = $130 ? $121 : $131;
   $133 = $126 < $134;
   $135 = $133 ? $126 : $134;
   $136 = $137 < $116;
   $138 = $136 ? $116 : $137;
   $139 = $140 < $121;
   $141 = $139 ? $121 : $140;
   $142 = $143 < $126;
   $144 = $142 ? $126 : $143;
   $145 = (($i$09) + 1)|0;
   $146 = ($145>>>0)<($84>>>0);
   if ($146) {
    $128 = $129;$131 = $132;$134 = $135;$137 = $138;$140 = $141;$143 = $144;$i$09 = $145;
   } else {
    $151 = $129;$152 = $138;$154 = $132;$155 = $141;$157 = $135;$158 = $144;
    break;
   }
  }
 }
 $147 = (($7) + 100|0);
 $148 = HEAP32[$147>>2]|0;
 $149 = ($148|0)==(0);
 if ($149) {
  $168 = Math_fround(HEAPF32[616680>>2]);
  $169 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
  $170 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
  $172 = $168;$174 = $169;$176 = $170;$178 = $168;$180 = $169;$182 = $170;
 } else {
  $150 = Math_fround($152 + $151);
  $153 = Math_fround($155 + $154);
  $156 = Math_fround($158 + $157);
  $159 = Math_fround($150 * Math_fround(0.5));
  $160 = Math_fround($153 * Math_fround(0.5));
  $161 = Math_fround($156 * Math_fround(0.5));
  $162 = Math_fround($152 - $151);
  $163 = Math_fround($155 - $154);
  $164 = Math_fround($158 - $157);
  $165 = Math_fround($162 * Math_fround(0.5));
  $166 = Math_fround($163 * Math_fround(0.5));
  $167 = Math_fround($164 * Math_fround(0.5));
  $172 = $159;$174 = $160;$176 = $161;$178 = $165;$180 = $166;$182 = $167;
 }
 $171 = (($this) + 168|0);
 HEAPF32[$171>>2] = $172;
 $173 = (($this) + 172|0);
 HEAPF32[$173>>2] = $174;
 $175 = (($this) + 176|0);
 HEAPF32[$175>>2] = $176;
 $177 = (($this) + 180|0);
 HEAPF32[$177>>2] = $178;
 $179 = (($this) + 184|0);
 HEAPF32[$179>>2] = $180;
 $181 = (($this) + 188|0);
 HEAPF32[$181>>2] = $182;
 $183 = (($this) + 48|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = (($this) + 44|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = ($184|0)==($186|0);
 if ($187) {
  STACKTOP = sp;return;
 } else {
  $submesh$03 = 0;
 }
 while(1) {
  __ZN4Mesh32RecalculateSubmeshBoundsInternalEj($this,$submesh$03);
  $188 = (($submesh$03) + 1)|0;
  $189 = HEAP32[$183>>2]|0;
  $190 = HEAP32[$185>>2]|0;
  $191 = $189;
  $192 = $190;
  $193 = (($191) - ($192))|0;
  $194 = (($193|0) / 56)&-1;
  $195 = ($188>>>0)<($194>>>0);
  if ($195) {
   $submesh$03 = $188;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4Mesh32RecalculateSubmeshBoundsInternalEj($this,$submesh) {
 $this = $this|0;
 $submesh = $submesh|0;
 var $$sum = 0, $$sum1 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $i$09 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[616664>>2]);
 $1 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $2 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $3 = Math_fround(-$0);
 $4 = Math_fround(-$1);
 $5 = Math_fround(-$2);
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 112|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 if ($12) {
  $50 = 0;
 } else {
  $13 = (($this) + 44|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $9;
  $16 = $11;
  $17 = (($15) - ($16))|0;
  $18 = ((($14) + (($submesh*56)|0)|0) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19>>>0)<($17>>>0);
  if ($20) {
   $21 = (($11) + ($19)|0);
   $50 = $21;
  } else {
   $50 = 0;
  }
 }
 $22 = (($7) + 10|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $25 = (($7) + 11|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26&255)<(3);
  if ($27) {
   $54 = 0;$56 = 0;
  } else {
   $28 = (($7) + 92|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $54 = 1;$56 = 0;
   } else {
    $31 = (($7) + 8|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = $32&255;
    $34 = ((($7) + (($33*12)|0)|0) + 50|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = $35&255;
    $37 = ((($7) + (($33*12)|0)|0) + 44|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($7) + 9|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = $40&255;
    $42 = (($41) + ($38))|0;
    $43 = (($29) + ($42)|0);
    $54 = $36;$56 = $43;
   }
  }
 } else {
  $54 = 0;$56 = 0;
 }
 $44 = (($this) + 44|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($45) + (($submesh*56)|0)|0) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0);
 if (!($48)) {
  $59 = $0;$64 = $1;$69 = $2;$72 = $3;$75 = $4;$78 = $5;$i$09 = 0;
  while(1) {
   $49 = (($50) + ($i$09<<1)|0);
   $51 = HEAP16[$49>>1]|0;
   $52 = $51&65535;
   $53 = Math_imul($52, $54)|0;
   $55 = (($56) + ($53)|0);
   $57 = Math_fround(HEAPF32[$55>>2]);
   $58 = $57 < $59;
   $60 = $58 ? $57 : $59;
   $$sum = (($53) + 4)|0;
   $61 = (($56) + ($$sum)|0);
   $62 = Math_fround(HEAPF32[$61>>2]);
   $63 = $62 < $64;
   $65 = $63 ? $62 : $64;
   $$sum1 = (($53) + 8)|0;
   $66 = (($56) + ($$sum1)|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = $67 < $69;
   $70 = $68 ? $67 : $69;
   $71 = $72 < $57;
   $73 = $71 ? $57 : $72;
   $74 = $75 < $62;
   $76 = $74 ? $62 : $75;
   $77 = $78 < $67;
   $79 = $77 ? $67 : $78;
   $80 = (($i$09) + 1)|0;
   $81 = ($80>>>0)<($47>>>0);
   if ($81) {
    $59 = $60;$64 = $65;$69 = $70;$72 = $73;$75 = $76;$78 = $79;$i$09 = $80;
   } else {
    break;
   }
  }
  $phitmp = ($47|0)==(0);
  if (!($phitmp)) {
   $82 = Math_fround($73 + $60);
   $83 = Math_fround($76 + $65);
   $84 = Math_fround($79 + $70);
   $85 = Math_fround($82 * Math_fround(0.5));
   $86 = Math_fround($83 * Math_fround(0.5));
   $87 = Math_fround($84 * Math_fround(0.5));
   $88 = Math_fround($73 - $60);
   $89 = Math_fround($76 - $65);
   $90 = Math_fround($79 - $70);
   $91 = Math_fround($88 * Math_fround(0.5));
   $92 = Math_fround($89 * Math_fround(0.5));
   $93 = Math_fround($90 * Math_fround(0.5));
   $100 = $86;$102 = $87;$104 = $91;$106 = $92;$108 = $93;$98 = $85;
   $97 = ((($45) + (($submesh*56)|0)|0) + 32|0);
   HEAPF32[$97>>2] = $98;
   $99 = ((($45) + (($submesh*56)|0)|0) + 36|0);
   HEAPF32[$99>>2] = $100;
   $101 = ((($45) + (($submesh*56)|0)|0) + 40|0);
   HEAPF32[$101>>2] = $102;
   $103 = ((($45) + (($submesh*56)|0)|0) + 44|0);
   HEAPF32[$103>>2] = $104;
   $105 = ((($45) + (($submesh*56)|0)|0) + 48|0);
   HEAPF32[$105>>2] = $106;
   $107 = ((($45) + (($submesh*56)|0)|0) + 52|0);
   HEAPF32[$107>>2] = $108;
   STACKTOP = sp;return;
  }
 }
 $94 = Math_fround(HEAPF32[616680>>2]);
 $95 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
 $96 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
 $100 = $95;$102 = $96;$104 = $94;$106 = $95;$108 = $96;$98 = $94;
 $97 = ((($45) + (($submesh*56)|0)|0) + 32|0);
 HEAPF32[$97>>2] = $98;
 $99 = ((($45) + (($submesh*56)|0)|0) + 36|0);
 HEAPF32[$99>>2] = $100;
 $101 = ((($45) + (($submesh*56)|0)|0) + 40|0);
 HEAPF32[$101>>2] = $102;
 $103 = ((($45) + (($submesh*56)|0)|0) + 44|0);
 HEAPF32[$103>>2] = $104;
 $105 = ((($45) + (($submesh*56)|0)|0) + 48|0);
 HEAPF32[$105>>2] = $106;
 $107 = ((($45) + (($submesh*56)|0)|0) + 52|0);
 HEAPF32[$107>>2] = $108;
 STACKTOP = sp;return;
}
function __ZN4Mesh18GetSubMeshBuffer16Ei($this,$submesh) {
 $this = $this|0;
 $submesh = $submesh|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  $16 = 0;
  STACKTOP = sp;return ($16|0);
 }
 $7 = (($this) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $3;
 $10 = $5;
 $11 = (($9) - ($10))|0;
 $12 = ((($8) + (($submesh*56)|0)|0) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13>>>0)<($11>>>0);
 if (!($14)) {
  $16 = 0;
  STACKTOP = sp;return ($16|0);
 }
 $15 = (($5) + ($13)|0);
 $16 = $15;
 STACKTOP = sp;return ($16|0);
}
function __ZN4Mesh17RecalculateBoundsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i = 0, $inData$c$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i = sp;
 __ZN4Mesh25RecalculateBoundsInternalEv($this);
 $0 = (($data$i) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($data$i) + 4|0);
 $inData$c$i$i = $this;
 HEAP32[$1>>2] = $inData$c$i$i;
 HEAP32[$data$i>>2] = 43;
 $2 = (($this) + 216|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 212|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  $12 = (($this) + 220|0);
  __ZN17IntermediateUsers6NotifyE18IntermediateNotify($12,1);
  STACKTOP = sp;return;
 } else {
  $7 = $3;
 }
 while(1) {
  $6 = (($7) + 4|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = (($7) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN5Unity17SendMessageDirectER6ObjectRK17MessageIdentifierR11MessageData($10,564464,$data$i);
  $11 = ($8|0)==($4|0);
  if ($11) {
   break;
  } else {
   $7 = $8;
  }
 }
 $12 = (($this) + 220|0);
 __ZN17IntermediateUsers6NotifyE18IntermediateNotify($12,1);
 STACKTOP = sp;return;
}
function __ZN4Mesh5ClearEb($this,$keepVertexLayout) {
 $this = $this|0;
 $keepVertexLayout = $keepVertexLayout|0;
 var $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0;
 var $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $sub = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy = sp + 72|0;
 $0 = sp;
 $sub = sp + 16|0;
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if ($5) {
  $14 = $2;
 } else {
  $__new_last2$i$i$i = $2;
  $scevgep$i$i$i = (($4) + -56|0);
  $6 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($6)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $7 = (($uglygep3$i$i$i>>>0) / 56)&-1;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i = (($4) + (($8*56)|0)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i;
  $14 = $scevgep4$i$i$i;
 }
 $9 = (($sub) + 32|0);
 $10 = (($$byval_copy) + 12|0);
 ;HEAP32[$sub+0>>2]=0|0;HEAP32[$sub+4>>2]=0|0;HEAP32[$sub+8>>2]=0|0;HEAP32[$sub+12>>2]=0|0;HEAP32[$sub+16>>2]=0|0;HEAP32[$sub+20>>2]=0|0;HEAP32[$sub+24>>2]=0|0;HEAP32[$sub+28>>2]=0|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[616680+8>>2]|0;
 ;HEAP32[$10+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[616680+8>>2]|0;
 ;HEAP32[$9+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$$byval_copy+12>>2]|0;HEAP32[$9+16>>2]=HEAP32[$$byval_copy+16>>2]|0;HEAP32[$9+20>>2]=HEAP32[$$byval_copy+20>>2]|0;
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($14|0)==($12|0);
 if ($13) {
  __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($1,$sub);
 } else {
  $15 = ($14|0)==(0|0);
  if ($15) {
   $17 = 0;
  } else {
   dest=$14+0|0; src=$sub+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre$i = HEAP32[$3>>2]|0;
   $17 = $$pre$i;
  }
  $16 = (($17) + 56|0);
  HEAP32[$3>>2] = $16;
 }
 $18 = (($this) + 56|0);
 __Z16ClearBlendShapesR14BlendShapeData($18);
 $19 = (($this) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 108|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 112|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($22|0);
 if ($25) {
  $27 = $20;
 } else {
  HEAP32[$23>>2] = $22;
  $$pre = HEAP32[$19>>2]|0;
  $27 = $$pre;
 }
 $26 = (($27) + 96|0);
 $28 = HEAP32[$26>>2]|0;
 $29 = (($27) + 100|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 do {
  if (!($31)) {
   if ($keepVertexLayout) {
    $32 = (($27) + 144|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0);
    if ($34) {
     $35 = (($this) + 92|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($this) + 88|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($36|0)==($38|0);
     if ($39) {
      $40 = (($27) + 8|0);
      __ZNK14VertexDataInfo16GetStreamsLayoutEv($$byval_copy,$40);
      $41 = (($$byval_copy) + 4|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = $42 & 255;
      $44 = $43 ^ 255;
      $45 = (($$byval_copy) + 8|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = $46 ^ -1;
      $48 = $44 & $47;
      $49 = (($$byval_copy) + 12|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = $50 ^ -1;
      $52 = $48 & $51;
      HEAP32[$$byval_copy>>2] = $52;
      ;HEAP32[$0+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$$byval_copy+12>>2]|0;
     } else {
      label = 14;
     }
    } else {
     label = 14;
    }
    if ((label|0) == 14) {
     ;HEAP32[$0+0>>2]=HEAP32[588160+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[588160+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[588160+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[588160+12>>2]|0;
    }
    __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayoutRK19VertexStreamsLayout($this,0,$28,0,588176,$0);
    break;
   } else {
    __ZN14VertexDataInfoC2Ev($$byval_copy);
    $53 = HEAP32[$19>>2]|0;
    $54 = (($53) + 8|0);
    __THREW__ = 0;
    invoke_vii(2667,($$byval_copy|0),($54|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     $57 = (($this) + 272|0);
     HEAP8[$57>>0] = 1;
     __ZN10VertexDataD2Ev($$byval_copy);
     break;
    }
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3456,($$byval_copy|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     $74 = ___cxa_find_matching_catch(0|0)|0;
     $75 = tempRet0;
     ___clang_call_terminate($74);
     // unreachable;
    } else {
     ___resumeException($58|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $62 = HEAP32[$19>>2]|0;
 $63 = (($62) + 144|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0);
 if ($65) {
  $73 = (($this) + 276|0);
  HEAP8[$73>>0] = 0;
  __ZN4Mesh14ClearSkinCacheEv($this);
  __ZN4Mesh16SetChannelsDirtyEjb($this,$28,1);
  STACKTOP = sp;return;
 }
 $66 = (($62) + 148|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)>(-1);
 if ($68) {
  $69 = (($62) + 136|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($62) + 140|0);
  $72 = HEAP32[$71>>2]|0;
  HEAP32[$0>>2] = $72;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($70,$$byval_copy);
  HEAP32[$69>>2] = 0;
 }
 HEAP32[$63>>2] = 0;
 HEAP32[$66>>2] = 0;
 $73 = (($this) + 276|0);
 HEAP8[$73>>0] = 0;
 __ZN4Mesh14ClearSkinCacheEv($this);
 __ZN4Mesh16SetChannelsDirtyEjb($this,$28,1);
 STACKTOP = sp;return;
}
function __ZN4Mesh14ClearSkinCacheEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (($this) + 136|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 140|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy2);
  HEAP32[$4>>2] = 0;
 }
 $8 = (($this) + 144|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$1>>2] = 0;
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 164|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)>(-1);
 if ($13) {
  $14 = (($10) + 152|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($10) + 156|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$0>>2] = $17;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($15,$$byval_copy2);
  HEAP32[$14>>2] = 0;
 }
 $18 = (($10) + 160|0);
 HEAP32[$18>>2] = 0;
 HEAP32[$11>>2] = 0;
 $19 = (($10) + 180|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>(-1);
 if ($21) {
  $22 = (($10) + 168|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($10) + 172|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$0>>2] = $25;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($23,$$byval_copy2);
  HEAP32[$22>>2] = 0;
 }
 $26 = (($10) + 176|0);
 HEAP32[$26>>2] = 0;
 HEAP32[$19>>2] = 0;
 $27 = (($this) + 164|0);
 HEAP32[$27>>2] = -1;
 $28 = (($this) + 152|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (__Z12GetGfxDevicev()|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 292|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vii[$34 & 4095]($31,$35);
  HEAP32[$28>>2] = 0;
 }
 $36 = (($this) + 156|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  $39 = (__Z12GetGfxDevicev()|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 292|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$36>>2]|0;
  FUNCTION_TABLE_vii[$42 & 4095]($39,$43);
  HEAP32[$36>>2] = 0;
 }
 $44 = (($this) + 160|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = (__Z12GetGfxDevicev()|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + 292|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$50 & 4095]($47,$51);
 HEAP32[$44>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4Mesh16SetChannelsDirtyEjb($this,$vertexChannelsChanged,$indices) {
 $this = $this|0;
 $vertexChannelsChanged = $vertexChannelsChanged|0;
 $indices = $indices|0;
 var $$byval_copy = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $inData$c$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($vertexChannelsChanged|0)!=(0);
 $2 = $1&1;
 $3 = (($this) + 272|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = $5 | $2;
 $7 = $6&255;
 HEAP8[$3>>0] = $7;
 $8 = $indices&1;
 $9 = (($this) + 273|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = $11 | $8;
 $13 = $12&255;
 HEAP8[$9>>0] = $13;
 $14 = $vertexChannelsChanged & 1;
 $$not = ($14|0)!=(0);
 $brmerge = $$not | $indices;
 if ($brmerge) {
  $15 = (($this) + 192|0);
  __ZN17CollisionMeshData20VertexDataHasChangedEv($15);
  $16 = (($this) + 148|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)>(-1);
  if ($18) {
   $19 = (($this) + 136|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 140|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$0>>2] = $22;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($20,$$byval_copy);
   HEAP32[$19>>2] = 0;
  }
  $23 = (($this) + 144|0);
  HEAP32[$23>>2] = 0;
  HEAP32[$16>>2] = 0;
 }
 $24 = (($$byval_copy) + 8|0);
 HEAP32[$24>>2] = 0;
 $25 = (($$byval_copy) + 4|0);
 $inData$c$i$i = $this;
 HEAP32[$25>>2] = $inData$c$i$i;
 HEAP32[$$byval_copy>>2] = 43;
 $26 = (($this) + 216|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($this) + 212|0);
 $29 = ($27|0)==($28|0);
 if ($29) {
  STACKTOP = sp;return;
 } else {
  $31 = $27;
 }
 while(1) {
  $30 = (($31) + 4|0);
  $32 = HEAP32[$30>>2]|0;
  $33 = (($31) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  __ZN5Unity17SendMessageDirectER6ObjectRK17MessageIdentifierR11MessageData($34,564512,$$byval_copy);
  $35 = ($32|0)==($28|0);
  if ($35) {
   break;
  } else {
   $31 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __Z18RegisterClass_Meshv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(43,111,0,0,0);
 STACKTOP = sp;return;
}
function __ZN4Mesh13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 HEAP8[$0>>0] = 8;
 $3 = (($0) + 1|0);
 HEAP8[$3>>0]=1752393037&255;HEAP8[$3+1>>0]=(1752393037>>8)&255;HEAP8[$3+2>>0]=(1752393037>>16)&255;HEAP8[$3+3>>0]=1752393037>>24;
 $4 = (($0) + 5|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,43,130,($0|0),280,(2385|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN4Mesh7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(280,$$byval_copy2,1,16,585592,84)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1698,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(585592|0),84);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK4Mesh25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 43;
}
function __ZN4Mesh23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,585608,585600,$this,0);
 __ZN4Mesh8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN4Mesh23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,585608,585600,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN4Mesh8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN4Mesh23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4Mesh8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN4Mesh23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4Mesh8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN4Mesh23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4Mesh8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN4Mesh23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4Mesh8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN4Mesh24UpdateSubMeshVertexRangeEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$lcssa$i = 0, $$lcssa1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $index$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + (($index*56)|0)|0) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $37 = ((($1) + (($index*56)|0)|0) + 16|0);
  HEAP32[$37>>2] = 0;
  $38 = ((($1) + (($index*56)|0)|0) + 20|0);
  HEAP32[$38>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = (($this) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 112|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  $21 = 0;
 } else {
  $12 = $8;
  $13 = $10;
  $14 = (($12) - ($13))|0;
  $15 = ((($1) + (($index*56)|0)|0) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16>>>0)<($14>>>0);
  if ($17) {
   $18 = (($10) + ($16)|0);
   $21 = $18;
  } else {
   $21 = 0;
  }
 }
 $19 = ((($1) + (($index*56)|0)|0) + 16|0);
 $20 = (($21) + ($3<<1)|0);
 $22 = ($3|0)>(0);
 if ($22) {
  $25 = -1;$28 = 0;$index$02$i = $21;
  while(1) {
   $23 = HEAP16[$index$02$i>>1]|0;
   $24 = ($23&65535)<($25&65535);
   $26 = $24 ? $23 : $25;
   $27 = ($28&65535)<($23&65535);
   $29 = $27 ? $23 : $28;
   $30 = (($index$02$i) + 2|0);
   $31 = ($30>>>0)<($20>>>0);
   if ($31) {
    $25 = $26;$28 = $29;$index$02$i = $30;
   } else {
    $$lcssa$i = $26;$$lcssa1$i = $29;
    break;
   }
  }
 } else {
  $$lcssa$i = -1;$$lcssa1$i = 0;
 }
 $32 = $$lcssa$i&65535;
 HEAP32[$19>>2] = $32;
 $33 = $$lcssa1$i&65535;
 $34 = (($33) + 1)|0;
 $35 = (($34) - ($32))|0;
 $36 = ((($1) + (($index*56)|0)|0) + 20|0);
 HEAP32[$36>>2] = $35;
 STACKTOP = sp;return;
}
function __ZNK4Mesh26GetSubMeshDrawBuffersRangeEib($agg$result,$this,$submesh,$tessellation) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $submesh = $submesh|0;
 $tessellation = $tessellation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($submesh*56)|0)|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$2+20>>2]|0;
 $3 = HEAP32[$agg$result>>2]|0;
 if ($tessellation) {
  $4 = ($3|0)==(1);
  if (!($4)) {
   STACKTOP = sp;return;
  }
 } else {
  $5 = ($3|0)==(2);
  if (!($5)) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$agg$result>>2] = 0;
 $6 = ((($1) + (($submesh*56)|0)|0) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($agg$result) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($1) + (($submesh*56)|0)|0) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($agg$result) + 8|0);
 HEAP32[$11>>2] = $10;
 STACKTOP = sp;return;
}
function __ZNK4Mesh12GetTrianglesERNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEE($this,$triangles) {
 $this = $this|0;
 $triangles = $triangles|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $m$01 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$triangles>>2]|0;
 $1 = (($triangles) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if (!($3)) {
  $__new_last2$i$i$i = $0;
  $scevgep$i$i$i = (($2) + -4|0);
  $4 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($4)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $5 = $uglygep3$i$i$i >>> 2;
  $6 = $5 ^ -1;
  $scevgep4$i$i$i = (($2) + ($6<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i;
 }
 $7 = (($this) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 44|0);
 $13 = (($this) + 28|0);
 $14 = (($this) + 4|0);
 $m$01 = 0;
 while(1) {
  $15 = HEAP32[$13>>2]|0;
  $16 = (__ZN4Mesh15AppendTrianglesERNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEjRKNS1_I7SubMeshS2_IS7_LS3_10ELi16EEEEP14SharedMeshData($triangles,$m$01,$12,$15)|0);
  if ((($16|0) == 4)) {
   $18 = HEAP32[$14>>2]|0;
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(585680,0,585592,1096,1,$18,0,0);
  } else if ((($16|0) == 1)) {
   $17 = HEAP32[$14>>2]|0;
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(585616,0,585592,1093,1,$17,0,0);
  }
  $19 = (($m$01) + 1)|0;
  $20 = HEAP32[$7>>2]|0;
  $21 = HEAP32[$9>>2]|0;
  $22 = $20;
  $23 = $21;
  $24 = (($22) - ($23))|0;
  $25 = (($24|0) / 56)&-1;
  $26 = ($19>>>0)<($25>>>0);
  if ($26) {
   $m$01 = $19;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK4Mesh15GetSubMeshCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 56)&-1;
 STACKTOP = sp;return ($7|0);
}
function __Z16QuadsToTrianglesPKtiRNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEE($quads,$indexCount,$triangles) {
 $quads = $quads|0;
 $indexCount = $indexCount|0;
 $triangles = $triangles|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $q$01 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $t$02 = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($indexCount|0) / 4)&-1;
 $1 = $0 << 2;
 $2 = (($1|0) / 2)&-1;
 $3 = ($2*3)|0;
 $4 = (($triangles) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$triangles>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10>>>0)<($3>>>0);
 if ($11) {
  $12 = (($3) - ($10))|0;
  __ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE8__appendEj($triangles,$12);
 } else {
  $13 = ($10>>>0)>($3>>>0);
  if ($13) {
   $14 = (($6) + ($3<<2)|0);
   $15 = ($5|0)==($14|0);
   if (!($15)) {
    $__new_last2$i$i$i = $14;
    $scevgep$i$i$i = (($5) + -4|0);
    $16 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($16)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $17 = $uglygep3$i$i$i >>> 2;
    $18 = $17 ^ -1;
    $scevgep4$i$i$i = (($5) + ($18<<2)|0);
    HEAP32[$4>>2] = $scevgep4$i$i$i;
   }
  }
 }
 $19 = ($indexCount|0)>(3);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$triangles>>2]|0;
 $q$01 = 0;$t$02 = 0;
 while(1) {
  $21 = (($quads) + ($q$01<<1)|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22&65535;
  $24 = (($20) + ($t$02<<2)|0);
  HEAP32[$24>>2] = $23;
  $25 = $q$01 | 1;
  $26 = (($quads) + ($25<<1)|0);
  $27 = HEAP16[$26>>1]|0;
  $28 = $27&65535;
  $29 = $t$02 | 1;
  $30 = (($20) + ($29<<2)|0);
  HEAP32[$30>>2] = $28;
  $31 = $q$01 | 2;
  $32 = (($quads) + ($31<<1)|0);
  $33 = HEAP16[$32>>1]|0;
  $34 = $33&65535;
  $35 = (($t$02) + 2)|0;
  $36 = (($20) + ($35<<2)|0);
  HEAP32[$36>>2] = $34;
  $37 = (($t$02) + 3)|0;
  $38 = (($20) + ($37<<2)|0);
  HEAP32[$38>>2] = $23;
  $39 = (($t$02) + 4)|0;
  $40 = (($20) + ($39<<2)|0);
  HEAP32[$40>>2] = $34;
  $41 = $q$01 | 3;
  $42 = (($quads) + ($41<<1)|0);
  $43 = HEAP16[$42>>1]|0;
  $44 = $43&65535;
  $45 = (($t$02) + 5)|0;
  $46 = (($20) + ($45<<2)|0);
  HEAP32[$46>>2] = $44;
  $47 = (($q$01) + 4)|0;
  $48 = (($t$02) + 6)|0;
  $49 = ($47|0)<($1|0);
  if ($49) {
   $q$01 = $47;$t$02 = $48;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4Mesh15AppendTrianglesERNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEjRKNS1_I7SubMeshS2_IS7_LS3_10ELi16EEEEP14SharedMeshData($triangles,$submesh,$subMeshes,$sharedData) {
 $triangles = $triangles|0;
 $submesh = $submesh|0;
 $subMeshes = $subMeshes|0;
 $sharedData = $sharedData|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($subMeshes) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$subMeshes>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = ($8>>>0)>($submesh>>>0);
 if (!($9)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($4) + (($submesh*56)|0)|0);
 $11 = HEAP32[$10>>2]|0;
 if ((($11|0) == 1)) {
  $12 = (($sharedData) + 112|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($sharedData) + 108|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($13|0)==($15|0);
  if ($16) {
   $26 = 0;
  } else {
   $17 = $13;
   $18 = $15;
   $19 = (($17) - ($18))|0;
   $20 = ((($4) + (($submesh*56)|0)|0) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21>>>0)<($19>>>0);
   if ($22) {
    $23 = (($15) + ($21)|0);
    $26 = $23;
   } else {
    $26 = 0;
   }
  }
  $24 = ((($4) + (($submesh*56)|0)|0) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  __Z10DestripifyPKtiRNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEE($26,$25,$triangles);
  $$0 = 8;
  STACKTOP = sp;return ($$0|0);
 } else if ((($11|0) == 2)) {
  $27 = (($sharedData) + 112|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($sharedData) + 108|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28|0)==($30|0);
  if ($31) {
   $41 = 0;
  } else {
   $32 = $28;
   $33 = $30;
   $34 = (($32) - ($33))|0;
   $35 = ((($4) + (($submesh*56)|0)|0) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36>>>0)<($34>>>0);
   if ($37) {
    $38 = (($30) + ($36)|0);
    $41 = $38;
   } else {
    $41 = 0;
   }
  }
  $39 = ((($4) + (($submesh*56)|0)|0) + 8|0);
  $40 = HEAP32[$39>>2]|0;
  __Z16QuadsToTrianglesPKtiRNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEE($41,$40,$triangles);
  $$0 = 8;
  STACKTOP = sp;return ($$0|0);
 } else if ((($11|0) == 0)) {
  $42 = (($sharedData) + 112|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($sharedData) + 108|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($43|0)==($45|0);
  if ($46) {
   $$0 = 8;
   STACKTOP = sp;return ($$0|0);
  }
  $47 = $43;
  $48 = $45;
  $49 = (($47) - ($48))|0;
  $50 = ((($4) + (($submesh*56)|0)|0) + 4|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51>>>0)<($49>>>0);
  if (!($52)) {
   $$0 = 8;
   STACKTOP = sp;return ($$0|0);
  }
  $53 = (($45) + ($51)|0);
  $54 = ($53|0)==(0|0);
  if ($54) {
   $$0 = 8;
   STACKTOP = sp;return ($$0|0);
  }
  $55 = (($triangles) + 4|0);
  $56 = HEAP32[$55>>2]|0;
  HEAP32[$0>>2] = $56;
  $57 = ((($4) + (($submesh*56)|0)|0) + 8|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($53) + ($58<<1)|0);
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE6insertIPKtEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS9_E9referenceEEE5valueENS_11__wrap_iterIPjEEE4typeENSD_IPKjEES9_S9_($1,$triangles,$$byval_copy,$53,$59);
  $$0 = 8;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 4;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE6insertIPKtEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS9_E9referenceEEE5valueENS_11__wrap_iterIPjEEE4typeENSD_IPKjEES9_S9_($agg$result,$this,$__position,$__first,$__last) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i14 = 0, $$0$i15 = 0, $$01$i = 0, $$01$i8 = 0, $$012$i$i = 0, $$03$i$i = 0, $$byval_copy1 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__first3$i1 = 0, $__i$01$i = 0, $__n$0 = 0, $__p$0 = 0, $scevgep$i = 0, $scevgep$i3 = 0, $scevgep5$i = 0, $scevgep5$i10 = 0, $uglygep$i = 0, $uglygep$i5 = 0, $uglygep4$i = 0, $uglygep4$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = HEAP32[$__position>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($1) + ($6<<2)|0);
 $8 = $__last;
 $9 = $__first;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 1;
 $12 = ($10|0)>(0);
 if (!($12)) {
  $__p$0 = $7;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $14;
 $18 = $16;
 $19 = (($17) - ($18))|0;
 $20 = $19 >> 2;
 $21 = ($11|0)>($20|0);
 if ($21) {
  $62 = (($18) - ($4))|0;
  $63 = $62 >> 2;
  $64 = (($63) + ($11))|0;
  $65 = ($64|0)<(0);
  if ($65) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $66 = (($17) - ($4))|0;
  $67 = $66 >> 2;
  $68 = ($67>>>0)<(1073741823);
  if ($68) {
   $71 = $66 >> 1;
   $72 = ($71>>>0)<($64>>>0);
   $73 = $72 ? $64 : $71;
   $74 = $7;
   $75 = $5 >> 2;
   $76 = ($73|0)==(0);
   if ($76) {
    $$0$i15 = 0;$80 = 0;$81 = $75;$97 = $74;
   } else {
    $$0$i14 = $73;$112 = $75;$113 = $74;
    label = 23;
   }
  } else {
   $69 = $7;
   $70 = $5 >> 2;
   $$0$i14 = 2147483647;$112 = $70;$113 = $69;
   label = 23;
  }
  if ((label|0) == 23) {
   $77 = $$0$i14 << 2;
   HEAP32[$0>>2] = 90;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   $78 = (__Z15malloc_internaljj10MemLabelIdiPKci($77,16,$$byval_copy1,0,585592,79)|0);
   $$0$i15 = $$0$i14;$80 = $78;$81 = $112;$97 = $113;
  }
  $79 = (($80) + ($81<<2)|0);
  $82 = (($80) + ($$0$i15<<2)|0);
  $83 = ($__first|0)==($__last|0);
  if ($83) {
   $104 = $79;
  } else {
   $scevgep$i = (($__last) + -2|0);
   $84 = (0 - ($9))|0;
   $uglygep$i = (($scevgep$i) + ($84)|0);
   $uglygep4$i = $uglygep$i;
   $85 = $uglygep4$i >>> 1;
   $$01$i = $__first;$87 = $79;
   while(1) {
    $86 = ($87|0)==(0|0);
    if (!($86)) {
     $88 = HEAP16[$$01$i>>1]|0;
     $89 = $88&65535;
     HEAP32[$87>>2] = $89;
    }
    $90 = (($87) + 4|0);
    $91 = (($$01$i) + 2|0);
    $92 = ($91|0)==($__last|0);
    if ($92) {
     break;
    } else {
     $$01$i = $91;$87 = $90;
    }
   }
   $93 = (($85) + 1)|0;
   $$sum17 = (($93) + ($81))|0;
   $scevgep5$i = (($80) + ($$sum17<<2)|0);
   $104 = $scevgep5$i;
  }
  $94 = HEAP32[$this>>2]|0;
  $95 = $94;
  $96 = (($97) - ($95))|0;
  $98 = $96 >> 2;
  $$sum18 = (($81) - ($98))|0;
  $99 = (($80) + ($$sum18<<2)|0);
  _memcpy(($99|0),($94|0),($96|0))|0;
  $100 = HEAP32[$15>>2]|0;
  $101 = $100;
  $102 = (($101) - ($97))|0;
  $103 = $102 >> 2;
  _memcpy(($104|0),($7|0),($102|0))|0;
  $105 = (($104) + ($103<<2)|0);
  $106 = HEAP32[$this>>2]|0;
  HEAP32[$this>>2] = $99;
  HEAP32[$15>>2] = $105;
  HEAP32[$13>>2] = $82;
  $107 = ($106|0)==(0|0);
  if ($107) {
   $__p$0 = $79;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($106|0),($$byval_copy1|0));
  $108 = __THREW__; __THREW__ = 0;
  $109 = $108&1;
  if ($109) {
   $110 = ___cxa_find_matching_catch()|0;
   $111 = tempRet0;
   ___cxa_call_unexpected(($110|0));
   // unreachable;
  } else {
   $__p$0 = $79;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
 }
 $22 = $7;
 $23 = (($18) - ($22))|0;
 $24 = $23 >> 2;
 $25 = ($11|0)>($24|0);
 if ($25) {
  $26 = (($__first) + ($24<<1)|0);
  $27 = ($26|0)==($__last|0);
  if ($27) {
   $41 = $16;$56 = $__last;$__n$0 = $24;
  } else {
   $__first3$i1 = $26;
   $scevgep$i3 = (($__last) + -2|0);
   $28 = (0 - ($__first3$i1))|0;
   $uglygep$i5 = (($scevgep$i3) + ($28)|0);
   $uglygep4$i6 = $uglygep$i5;
   $29 = $uglygep4$i6 >>> 1;
   $$01$i8 = $26;$31 = $16;
   while(1) {
    $30 = ($31|0)==(0|0);
    if (!($30)) {
     $32 = HEAP16[$$01$i8>>1]|0;
     $33 = $32&65535;
     HEAP32[$31>>2] = $33;
    }
    $34 = (($31) + 4|0);
    $35 = (($$01$i8) + 2|0);
    $36 = ($35|0)==($__last|0);
    if ($36) {
     break;
    } else {
     $$01$i8 = $35;$31 = $34;
    }
   }
   $37 = (($29) + 1)|0;
   $scevgep5$i10 = (($16) + ($37<<2)|0);
   HEAP32[$15>>2] = $scevgep5$i10;
   $41 = $scevgep5$i10;$56 = $26;$__n$0 = $24;
  }
 } else {
  $41 = $16;$56 = $__last;$__n$0 = $11;
 }
 $38 = ($__n$0|0)>(0);
 if (!($38)) {
  $__p$0 = $7;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $$sum = (($6) + ($11))|0;
 $39 = (($1) + ($$sum<<2)|0);
 $40 = $41;
 $42 = $39;
 $43 = (($40) - ($42))|0;
 $44 = $43 >> 2;
 $$sum16 = (($44) + ($6))|0;
 $45 = (($1) + ($$sum16<<2)|0);
 $46 = ($45>>>0)<($16>>>0);
 if ($46) {
  $48 = $41;$__i$01$i = $45;
  while(1) {
   $47 = ($48|0)==(0|0);
   if (!($47)) {
    $49 = HEAP32[$__i$01$i>>2]|0;
    HEAP32[$48>>2] = $49;
   }
   $50 = (($__i$01$i) + 4|0);
   $51 = (($48) + 4|0);
   $52 = ($50>>>0)<($16>>>0);
   if ($52) {
    $48 = $51;$__i$01$i = $50;
   } else {
    break;
   }
  }
  HEAP32[$15>>2] = $51;
 }
 $53 = (0 - ($44))|0;
 $54 = (($41) + ($53<<2)|0);
 _memmove(($54|0),($7|0),($43|0))|0;
 $55 = ($56|0)==($__first|0);
 if ($55) {
  $__p$0 = $7;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 } else {
  $$012$i$i = $__first;$$03$i$i = $7;
 }
 while(1) {
  $57 = HEAP16[$$012$i$i>>1]|0;
  $58 = $57&65535;
  HEAP32[$$03$i$i>>2] = $58;
  $59 = (($$012$i$i) + 2|0);
  $60 = (($$03$i$i) + 4|0);
  $61 = ($59|0)==($56|0);
  if ($61) {
   $__p$0 = $7;
   break;
  } else {
   $$012$i$i = $59;$$03$i$i = $60;
  }
 }
 HEAP32[$agg$result>>2] = $__p$0;
 STACKTOP = sp;return;
}
function __ZN4Mesh17SetIndicesComplexEPKvjj16GfxPrimitiveTypei($this,$indices,$count,$submesh,$topology,$mode) {
 $this = $this|0;
 $indices = $indices|0;
 $count = $count|0;
 $submesh = $submesh|0;
 $topology = $topology|0;
 $mode = $mode|0;
 var $$0 = 0, $$byval_copy2 = 0, $$lcssa$i$i = 0, $$lcssa1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$01$i2 = 0, $inData$c$i$i$i = 0, $index$02$i$i = 0, $or$cond = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp;
 $0 = sp + 24|0;
 $1 = sp + 12|0;
 $2 = ($indices|0)!=(0|0);
 $3 = ($count|0)==(0);
 $or$cond = $2 | $3;
 if (!($or$cond)) {
  $4 = $mode & 8;
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = ($this|0)==(0|0);
   if ($6) {
    $9 = 0;
   } else {
    $7 = (($this) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = $8;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(585744,0,585592,1135,1,$9,0,0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $10 = (($this) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 56)&-1;
 $18 = ($17>>>0)>($submesh>>>0);
 if (!($18)) {
  $19 = (($this) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(585792,0,585592,1141,1,$20,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = ($topology|0)==(0);
 if ($21) {
  $22 = (($count>>>0) % 3)&-1;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $24 = ($this|0)==(0|0);
   if ($24) {
    $27 = 0;
   } else {
    $25 = (($this) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = $26;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(585856,0,585592,1147,1,$27,0,0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $28 = $mode & 8;
 $29 = ($28|0)==(0);
 L21: do {
  if ($29) {
   $30 = $mode & 1;
   $31 = ($30|0)==(0);
   $32 = (($this) + 28|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 100|0);
   $35 = HEAP32[$34>>2]|0;
   L23: do {
    if ($31) {
     if ($3) {
      break L21;
     } else {
      $i$01$i2 = 0;
     }
     while(1) {
      $44 = (($indices) + ($i$01$i2<<2)|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45>>>0)<($35>>>0);
      $43 = (($i$01$i2) + 1)|0;
      if (!($46)) {
       break L23;
      }
      $42 = ($43>>>0)<($count>>>0);
      if ($42) {
       $i$01$i2 = $43;
      } else {
       break L21;
      }
     }
    } else {
     if ($3) {
      break L21;
     } else {
      $i$01$i = 0;
     }
     while(1) {
      $38 = (($indices) + ($i$01$i<<1)|0);
      $39 = HEAP16[$38>>1]|0;
      $40 = $39&65535;
      $41 = ($40>>>0)<($35>>>0);
      $37 = (($i$01$i) + 1)|0;
      if (!($41)) {
       break L23;
      }
      $36 = ($37>>>0)<($count>>>0);
      if ($36) {
       $i$01$i = $37;
      } else {
       break L21;
      }
     }
    }
   } while(0);
   HEAP32[$$byval_copy2>>2] = $count;
   $vararg_ptr1 = (($$byval_copy2) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $35;
   __Z12FormatStringI8UnityStrET_PKcz($1,585952,$$byval_copy2);
   $47 = ($this|0)==(0|0);
   if ($47) {
    $57 = 0;
   } else {
    $48 = (($this) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $57 = $49;
   }
   $50 = HEAP8[$1>>0]|0;
   $51 = $50 & 1;
   $52 = ($51<<24>>24)==(0);
   if ($52) {
    $55 = (($1) + 1|0);
    $56 = $55;
   } else {
    $53 = (($1) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    $56 = $54;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($56|0),0,(585592|0),1161,1,($57|0),0,(0|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    $71 = HEAP8[$1>>0]|0;
    $72 = $71 & 1;
    $73 = ($72<<24>>24)==(0);
    if ($73) {
     ___resumeException($69|0);
     // unreachable;
    }
    $74 = (($1) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($75|0),($$byval_copy2|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     $78 = ___cxa_find_matching_catch()|0;
     $79 = tempRet0;
     ___cxa_call_unexpected(($78|0));
     // unreachable;
    } else {
     ___resumeException($69|0);
     // unreachable;
    }
   } else {
    $60 = HEAP8[$1>>0]|0;
    $61 = $60 & 1;
    $62 = ($61<<24>>24)==(0);
    if ($62) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $63 = (($1) + 8|0);
    $64 = HEAP32[$63>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($64|0),($$byval_copy2|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     $67 = ___cxa_find_matching_catch()|0;
     $68 = tempRet0;
     ___cxa_call_unexpected(($67|0));
     // unreachable;
    } else {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 __ZN4Mesh12SetIndexDataEiiPKv16GfxPrimitiveTypei($this,$submesh,$count,$indices,$topology,$mode);
 $80 = $mode & 16;
 $81 = ($80|0)==(0);
 $82 = HEAP32[$12>>2]|0;
 if ($81) {
  $91 = ((($82) + (($submesh*56)|0)|0) + 8|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($92|0)==(0);
  if ($93) {
   $126 = ((($82) + (($submesh*56)|0)|0) + 16|0);
   HEAP32[$126>>2] = 0;
   $127 = ((($82) + (($submesh*56)|0)|0) + 20|0);
   HEAP32[$127>>2] = 0;
  } else {
   $94 = (($this) + 28|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($95) + 112|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($95) + 108|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($97|0)==($99|0);
   if ($100) {
    $110 = 0;
   } else {
    $101 = $97;
    $102 = $99;
    $103 = (($101) - ($102))|0;
    $104 = ((($82) + (($submesh*56)|0)|0) + 4|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($105>>>0)<($103>>>0);
    if ($106) {
     $107 = (($99) + ($105)|0);
     $110 = $107;
    } else {
     $110 = 0;
    }
   }
   $108 = ((($82) + (($submesh*56)|0)|0) + 16|0);
   $109 = (($110) + ($92<<1)|0);
   $111 = ($92|0)>(0);
   if ($111) {
    $114 = -1;$117 = 0;$index$02$i$i = $110;
    while(1) {
     $112 = HEAP16[$index$02$i$i>>1]|0;
     $113 = ($112&65535)<($114&65535);
     $115 = $113 ? $112 : $114;
     $116 = ($117&65535)<($112&65535);
     $118 = $116 ? $112 : $117;
     $119 = (($index$02$i$i) + 2|0);
     $120 = ($119>>>0)<($109>>>0);
     if ($120) {
      $114 = $115;$117 = $118;$index$02$i$i = $119;
     } else {
      $$lcssa$i$i = $115;$$lcssa1$i$i = $118;
      break;
     }
    }
   } else {
    $$lcssa$i$i = -1;$$lcssa1$i$i = 0;
   }
   $121 = $$lcssa$i$i&65535;
   HEAP32[$108>>2] = $121;
   $122 = $$lcssa1$i$i&65535;
   $123 = (($122) + 1)|0;
   $124 = (($123) - ($121))|0;
   $125 = ((($82) + (($submesh*56)|0)|0) + 20|0);
   HEAP32[$125>>2] = $124;
  }
  __ZN4Mesh32RecalculateSubmeshBoundsInternalEj($this,$submesh);
  $128 = (($$byval_copy2) + 8|0);
  HEAP32[$128>>2] = 0;
  $129 = (($$byval_copy2) + 4|0);
  $inData$c$i$i$i = $this;
  HEAP32[$129>>2] = $inData$c$i$i$i;
  HEAP32[$$byval_copy2>>2] = 43;
  $130 = (($this) + 216|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = (($this) + 212|0);
  $133 = ($131|0)==($132|0);
  if (!($133)) {
   $135 = $131;
   while(1) {
    $134 = (($135) + 4|0);
    $136 = HEAP32[$134>>2]|0;
    $137 = (($135) + 8|0);
    $138 = HEAP32[$137>>2]|0;
    __ZN5Unity17SendMessageDirectER6ObjectRK17MessageIdentifierR11MessageData($138,564464,$$byval_copy2);
    $139 = ($136|0)==($132|0);
    if ($139) {
     break;
    } else {
     $135 = $136;
    }
   }
  }
  $140 = (($this) + 220|0);
  __ZN17IntermediateUsers6NotifyE18IntermediateNotify($140,1);
 } else {
  $83 = (($82) + 16|0);
  HEAP32[$83>>2] = 0;
  $84 = (($this) + 28|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($85) + 100|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (($82) + 20|0);
  HEAP32[$88>>2] = $87;
  $89 = (($82) + 32|0);
  $90 = (($this) + 168|0);
  ;HEAP32[$89+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$90+12>>2]|0;HEAP32[$89+16>>2]=HEAP32[$90+16>>2]|0;HEAP32[$89+20>>2]=HEAP32[$90+20>>2]|0;
 }
 $141 = $mode & 4;
 $142 = ($141|0)==(0);
 if (!($142)) {
  $143 = (($this) + 192|0);
  __ZN17CollisionMeshData20VertexDataHasChangedEv($143);
 }
 __ZN4Mesh16SetChannelsDirtyEjb($this,0,1);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4Mesh10SetIndicesEPKtjj16GfxPrimitiveType($this,$indices,$count,$submesh,$topology) {
 $this = $this|0;
 $indices = $indices|0;
 $count = $count|0;
 $submesh = $submesh|0;
 $topology = $topology|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4Mesh17SetIndicesComplexEPKvjj16GfxPrimitiveTypei($this,$indices,$count,$submesh,$topology,5)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z12FormatStringI8UnityStrET_PKcz($agg$result,$format,$varargs) {
 $agg$result = $agg$result|0;
 $format = $format|0;
 $varargs = $varargs|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $buffer = 0, $va = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 10272|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $buffer = sp + 32|0;
 $va = sp + 8|0;
 HEAP32[$va>>2] = $varargs;
 __Z13VFormatBufferPciPKcPi($buffer,10240,$format,$va);
 $1 = (_strlen(($buffer|0))|0);
 $2 = ($1>>>0)>(2147483631);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$agg$result>>0] = $5;
  $6 = (($agg$result) + 1|0);
  $__p$0$i$i$i$i = $6;
  _memcpy(($__p$0$i$i$i$i|0),($buffer|0),($1|0))|0;
  $13 = (($__p$0$i$i$i$i) + ($1)|0);
  HEAP8[$13>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  HEAP32[$0>>2] = 59;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $9 = (__Z15malloc_internaljj10MemLabelIdiPKci($8,16,$$byval_copy,0,585592,79)|0);
  $10 = (($agg$result) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$agg$result>>2] = $11;
  $12 = (($agg$result) + 4|0);
  HEAP32[$12>>2] = $1;
  $__p$0$i$i$i$i = $9;
  _memcpy(($__p$0$i$i$i$i|0),($buffer|0),($1|0))|0;
  $13 = (($__p$0$i$i$i$i) + ($1)|0);
  HEAP8[$13>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN4Mesh12SetIndexDataEiiPKv16GfxPrimitiveTypei($this,$submeshIndex,$indexCount,$indices,$topology,$mode) {
 $this = $this|0;
 $submeshIndex = $submeshIndex|0;
 $indexCount = $indexCount|0;
 $indices = $indices|0;
 $topology = $topology|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $$phi$trans$insert = 0, $$phi$trans$insert28 = 0, $$pre = 0, $$pre29 = 0, $$sum = 0, $$sum1$i = 0, $$sum17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $exitcond = 0, $exitcond26 = 0, $i$0 = 0, $i$022 = 0;
 var $i$024 = 0, $i1$020 = 0, $i4$018 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = sp + 4|0;
 $3 = $indexCount << 1;
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5) + (($submeshIndex*56)|0)|0) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 << 1;
 $9 = (($3) - ($8))|0;
 $10 = ((($5) + (($submeshIndex*56)|0)|0) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)>(0);
 $13 = (($this) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 108|0);
 $16 = HEAP32[$15>>2]|0;
 if ($12) {
  $$sum17 = (($11) + ($8))|0;
  $17 = (($16) + ($$sum17)|0);
  HEAP32[$0>>2] = $17;
  HEAP8[$1>>0] = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE6insertENS_11__wrap_iterIPKhEEjRS6_($2,$15,$$byval_copy,$9,$1);
 } else {
  $18 = ($3|0)==($8|0);
  if (!($18)) {
   $$sum = (($11) - ($9))|0;
   $19 = (($16) + ($11)|0);
   $20 = (($16) + ($$sum)|0);
   $21 = (($14) + 112|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = $22;
   $24 = $20;
   $25 = (($23) - ($24))|0;
   _memmove(($19|0),($20|0),($25|0))|0;
   $$sum1$i = (($25) + ($11))|0;
   $26 = (($16) + ($$sum1$i)|0);
   $27 = HEAP32[$21>>2]|0;
   $28 = ($27|0)==($26|0);
   if (!($28)) {
    HEAP32[$21>>2] = $26;
   }
  }
 }
 $29 = HEAP32[$4>>2]|0;
 $30 = ((($29) + (($submeshIndex*56)|0)|0) + 8|0);
 HEAP32[$30>>2] = $indexCount;
 $31 = (($29) + (($submeshIndex*56)|0)|0);
 HEAP32[$31>>2] = $topology;
 $i$022 = (($submeshIndex) + 1)|0;
 $32 = (($this) + 48|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33;
 $35 = $29;
 $36 = (($34) - ($35))|0;
 $37 = (($36|0) / 56)&-1;
 $38 = ($i$022>>>0)<($37>>>0);
 L7: do {
  if ($38) {
   $$phi$trans$insert = ((($29) + (($submeshIndex*56)|0)|0) + 4|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $40 = $indexCount;$42 = $$pre;$i$024 = $i$022;
   while(1) {
    $39 = $40 << 1;
    $41 = (($39) + ($42))|0;
    $43 = ((($29) + (($i$024*56)|0)|0) + 4|0);
    HEAP32[$43>>2] = $41;
    $i$0 = (($i$024) + 1)|0;
    $44 = ($i$0>>>0)<($37>>>0);
    if (!($44)) {
     break L7;
    }
    $$phi$trans$insert28 = ((($29) + (($i$024*56)|0)|0) + 8|0);
    $$pre29 = HEAP32[$$phi$trans$insert28>>2]|0;
    $40 = $$pre29;$42 = $41;$i$024 = $i$0;
   }
  }
 } while(0);
 $45 = $mode & 8;
 $46 = ($45|0)==(0);
 if (!($46)) {
  STACKTOP = sp;return;
 }
 $47 = $mode & 1;
 $48 = ($47|0)==(0);
 if ($48) {
  $68 = HEAP32[$13>>2]|0;
  $69 = (($68) + 112|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($68) + 108|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($70|0)==($72|0);
  if ($73) {
   $86 = 0;
  } else {
   $74 = $70;
   $75 = $72;
   $76 = (($74) - ($75))|0;
   $77 = ((($29) + (($submeshIndex*56)|0)|0) + 4|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78>>>0)<($76>>>0);
   if ($79) {
    $80 = (($72) + ($78)|0);
    $86 = $80;
   } else {
    $86 = 0;
   }
  }
  $81 = ($indexCount|0)>(0);
  if ($81) {
   $i4$018 = 0;
  } else {
   STACKTOP = sp;return;
  }
  while(1) {
   $82 = (($indices) + ($i4$018<<2)|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = $83&65535;
   $85 = (($86) + ($i4$018<<1)|0);
   HEAP16[$85>>1] = $84;
   $87 = (($i4$018) + 1)|0;
   $exitcond = ($87|0)==($indexCount|0);
   if ($exitcond) {
    break;
   } else {
    $i4$018 = $87;
   }
  }
  STACKTOP = sp;return;
 } else {
  $49 = HEAP32[$13>>2]|0;
  $50 = (($49) + 112|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 108|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($51|0)==($53|0);
  if ($54) {
   $66 = 0;
  } else {
   $55 = $51;
   $56 = $53;
   $57 = (($55) - ($56))|0;
   $58 = ((($29) + (($submeshIndex*56)|0)|0) + 4|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59>>>0)<($57>>>0);
   if ($60) {
    $61 = (($53) + ($59)|0);
    $66 = $61;
   } else {
    $66 = 0;
   }
  }
  $62 = ($indexCount|0)>(0);
  if ($62) {
   $i1$020 = 0;
  } else {
   STACKTOP = sp;return;
  }
  while(1) {
   $63 = (($indices) + ($i1$020<<1)|0);
   $64 = HEAP16[$63>>1]|0;
   $65 = (($66) + ($i1$020<<1)|0);
   HEAP16[$65>>1] = $64;
   $67 = (($i1$020) + 1)|0;
   $exitcond26 = ($67|0)==($indexCount|0);
   if ($exitcond26) {
    break;
   } else {
    $i1$020 = $67;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE6insertENS_11__wrap_iterIPKhEEjRS6_($agg$result,$this,$__position,$__n,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0 = 0, $$0$i = 0, $$0$i2 = 0, $$0$i78 = 0, $$0$i79 = 0, $$byval_copy1 = 0, $$pre$i5 = 0, $$pre1$i = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $__i$01$i = 0, $__p$0 = 0;
 var $__xr$0 = 0, $exitcond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = HEAP32[$__position>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($1) + ($5)|0);
 $7 = ($__n|0)==(0);
 if ($7) {
  $__p$0 = $6;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $8 = (($this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = ($14>>>0)<($__n>>>0);
 if ($15) {
  $48 = (($13) - ($4))|0;
  $49 = (($48) + ($__n))|0;
  $50 = ($49|0)<(0);
  if ($50) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $51 = (($12) - ($4))|0;
  $52 = ($51>>>0)<(1073741823);
  if ($52) {
   $54 = $51 << 1;
   $55 = ($54>>>0)<($49>>>0);
   $56 = $55 ? $49 : $54;
   $57 = $6;
   $58 = ($56|0)==(0);
   if ($58) {
    $$0$i79 = 0;$61 = 0;$73 = $57;
   } else {
    $$0$i78 = $56;$85 = $57;
    label = 22;
   }
  } else {
   $53 = $6;
   $$0$i78 = 2147483647;$85 = $53;
   label = 22;
  }
  if ((label|0) == 22) {
   HEAP32[$0>>2] = 8;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   $59 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i78,16,$$byval_copy1,0,585592,79)|0);
   $$0$i79 = $$0$i78;$61 = $59;$73 = $85;
  }
  $60 = (($61) + ($5)|0);
  $$0$i2 = $__n;$63 = $60;
  while(1) {
   $62 = ($63|0)==(0|0);
   if ($62) {
    $66 = 0;
   } else {
    $64 = HEAP8[$__x>>0]|0;
    HEAP8[$63>>0] = $64;
    $66 = $63;
   }
   $65 = (($66) + 1|0);
   $67 = (($$0$i2) + -1)|0;
   $68 = ($67|0)==(0);
   if ($68) {
    break;
   } else {
    $$0$i2 = $67;$63 = $65;
   }
  }
  $69 = (($61) + ($$0$i79)|0);
  $70 = HEAP32[$this>>2]|0;
  $71 = $70;
  $72 = (($73) - ($71))|0;
  $$sum11 = (($5) - ($72))|0;
  $74 = (($61) + ($$sum11)|0);
  _memcpy(($74|0),($70|0),($72|0))|0;
  $75 = HEAP32[$10>>2]|0;
  $76 = $75;
  $77 = (($76) - ($73))|0;
  _memcpy(($65|0),($6|0),($77|0))|0;
  $$sum12 = (($77) + 1)|0;
  $78 = (($66) + ($$sum12)|0);
  $79 = HEAP32[$this>>2]|0;
  HEAP32[$this>>2] = $74;
  HEAP32[$10>>2] = $78;
  HEAP32[$8>>2] = $69;
  $80 = ($79|0)==(0|0);
  if ($80) {
   $__p$0 = $60;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 8;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($79|0),($$byval_copy1|0));
  $81 = __THREW__; __THREW__ = 0;
  $82 = $81&1;
  if ($82) {
   $83 = ___cxa_find_matching_catch()|0;
   $84 = tempRet0;
   ___cxa_call_unexpected(($83|0));
   // unreachable;
  } else {
   $__p$0 = $60;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
 }
 $16 = $6;
 $17 = (($13) - ($16))|0;
 $18 = ($17>>>0)<($__n>>>0);
 if ($18) {
  $19 = (($__n) - ($17))|0;
  $$0$i = $19;$21 = $11;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $24 = 0;
   } else {
    $22 = HEAP8[$__x>>0]|0;
    HEAP8[$21>>0] = $22;
    $$pre1$i = HEAP32[$10>>2]|0;
    $24 = $$pre1$i;
   }
   $23 = (($24) + 1|0);
   HEAP32[$10>>2] = $23;
   $25 = (($$0$i) + -1)|0;
   $26 = ($25|0)==(0);
   if ($26) {
    $$0 = $17;$30 = $23;
    break;
   } else {
    $$0$i = $25;$21 = $23;
   }
  }
 } else {
  $$0 = $__n;$30 = $11;
 }
 $27 = ($$0|0)==(0);
 if ($27) {
  $__p$0 = $6;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $$sum = (($5) + ($__n))|0;
 $28 = (($1) + ($$sum)|0);
 $29 = $30;
 $31 = $28;
 $32 = (($29) - ($31))|0;
 $$sum10 = (($32) + ($5))|0;
 $33 = (($1) + ($$sum10)|0);
 $34 = ($33>>>0)<($11>>>0);
 if ($34) {
  $36 = $30;$__i$01$i = $33;
  while(1) {
   $35 = ($36|0)==(0|0);
   if ($35) {
    $40 = 0;
   } else {
    $37 = HEAP8[$__i$01$i>>0]|0;
    HEAP8[$36>>0] = $37;
    $$pre$i5 = HEAP32[$10>>2]|0;
    $40 = $$pre$i5;
   }
   $38 = (($__i$01$i) + 1|0);
   $39 = (($40) + 1|0);
   HEAP32[$10>>2] = $39;
   $exitcond$i = ($38|0)==($11|0);
   if ($exitcond$i) {
    break;
   } else {
    $36 = $39;$__i$01$i = $38;
   }
  }
 }
 $41 = (0 - ($32))|0;
 $42 = (($30) + ($41)|0);
 _memmove(($42|0),($6|0),($32|0))|0;
 $43 = ($6>>>0)>($__x>>>0);
 if ($43) {
  $__xr$0 = $__x;
 } else {
  $44 = HEAP32[$10>>2]|0;
  $45 = ($44>>>0)>($__x>>>0);
  if ($45) {
   $46 = (($__x) + ($__n)|0);
   $__xr$0 = $46;
  } else {
   $__xr$0 = $__x;
  }
 }
 $47 = HEAP8[$__xr$0>>0]|0;
 _memset(($6|0),($47|0),($$0|0))|0;
 $__p$0 = $6;
 HEAP32[$agg$result>>2] = $__p$0;
 STACKTOP = sp;return;
}
function __ZN4Mesh9SetBoundsERK4AABB($this,$aabb) {
 $this = $this|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i = 0, $inData$c$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i = sp;
 $0 = (($this) + 168|0);
 ;HEAP32[$0+0>>2]=HEAP32[$aabb+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$aabb+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$aabb+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$aabb+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$aabb+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$aabb+20>>2]|0;
 $1 = (($data$i) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($data$i) + 4|0);
 $inData$c$i$i = $this;
 HEAP32[$2>>2] = $inData$c$i$i;
 HEAP32[$data$i>>2] = 43;
 $3 = (($this) + 216|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 212|0);
 $6 = ($4|0)==($5|0);
 if ($6) {
  $13 = (($this) + 220|0);
  __ZN17IntermediateUsers6NotifyE18IntermediateNotify($13,1);
  STACKTOP = sp;return;
 } else {
  $8 = $4;
 }
 while(1) {
  $7 = (($8) + 4|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = (($8) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZN5Unity17SendMessageDirectER6ObjectRK17MessageIdentifierR11MessageData($11,564464,$data$i);
  $12 = ($9|0)==($5|0);
  if ($12) {
   break;
  } else {
   $8 = $9;
  }
 }
 $13 = (($this) + 220|0);
 __ZN17IntermediateUsers6NotifyE18IntermediateNotify($13,1);
 STACKTOP = sp;return;
}
function __ZN4Mesh15SetSubMeshCountEj($this,$count) {
 $this = $this|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i8 = 0, $data = 0, $data$i$i = 0, $inData$c$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i9 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i13 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i11 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i12 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $data$i$i = sp + 80|0;
 $data = sp;
 $0 = sp + 56|0;
 $1 = ($count|0)==(0);
 if ($1) {
  $2 = (($this) + 28|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 108|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 112|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($5|0);
  if (!($8)) {
   HEAP32[$6>>2] = $5;
  }
  $9 = (($this) + 44|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 48|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($10|0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i$i = $10;
  $scevgep$i$i$i = (($12) + -56|0);
  $14 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($14)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $15 = (($uglygep3$i$i$i>>>0) / 56)&-1;
  $16 = $15 ^ -1;
  $scevgep4$i$i$i = (($12) + (($16*56)|0)|0);
  HEAP32[$11>>2] = $scevgep4$i$i$i;
  STACKTOP = sp;return;
 }
 $17 = (($this) + 44|0);
 $18 = (($this) + 48|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$17>>2]|0;
 $21 = $19;
 $22 = $20;
 $23 = (($21) - ($22))|0;
 $24 = (($23|0) / 56)&-1;
 $25 = ($24>>>0)>($count>>>0);
 if (!($25)) {
  $56 = ($24>>>0)<($count>>>0);
  if (!($56)) {
   STACKTOP = sp;return;
  }
  $57 = (($data) + 32|0);
  ;HEAP32[$data+0>>2]=0|0;HEAP32[$data+4>>2]=0|0;HEAP32[$data+8>>2]=0|0;HEAP32[$data+12>>2]=0|0;HEAP32[$data+16>>2]=0|0;HEAP32[$data+20>>2]=0|0;HEAP32[$data+24>>2]=0|0;HEAP32[$data+28>>2]=0|0;
  $58 = (($this) + 28|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + 112|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) + 108|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = $61;
  $65 = $63;
  $66 = (($64) - ($65))|0;
  $67 = (($data) + 4|0);
  HEAP32[$67>>2] = $66;
  $68 = (($data) + 8|0);
  HEAP32[$68>>2] = 0;
  HEAP32[$data>>2] = 0;
  $69 = (($data) + 16|0);
  HEAP32[$69>>2] = 0;
  $70 = (($data) + 20|0);
  HEAP32[$70>>2] = 0;
  $71 = (($0) + 12|0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  ;HEAP32[$0+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[616680+8>>2]|0;
  ;HEAP32[$71+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[616680+8>>2]|0;
  ;HEAP32[$57+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$57+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$57+20>>2]=HEAP32[$0+20>>2]|0;
  $72 = (($count) - ($24))|0;
  __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE8__appendEjRKS1_($17,$72,$data);
  __ZN4Mesh25RecalculateBoundsInternalEv($this);
  $73 = (($data$i$i) + 8|0);
  HEAP32[$73>>2] = 0;
  $74 = (($data$i$i) + 4|0);
  $inData$c$i$i$i = $this;
  HEAP32[$74>>2] = $inData$c$i$i$i;
  HEAP32[$data$i$i>>2] = 43;
  $75 = (($this) + 216|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($this) + 212|0);
  $78 = ($76|0)==($77|0);
  if (!($78)) {
   $80 = $76;
   while(1) {
    $79 = (($80) + 4|0);
    $81 = HEAP32[$79>>2]|0;
    $82 = (($80) + 8|0);
    $83 = HEAP32[$82>>2]|0;
    __ZN5Unity17SendMessageDirectER6ObjectRK17MessageIdentifierR11MessageData($83,564464,$data$i$i);
    $84 = ($81|0)==($77|0);
    if ($84) {
     break;
    } else {
     $80 = $81;
    }
   }
  }
  $85 = (($this) + 220|0);
  __ZN17IntermediateUsers6NotifyE18IntermediateNotify($85,1);
  STACKTOP = sp;return;
 }
 $26 = (($this) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 108|0);
 $29 = ((($20) + (($count*56)|0)|0) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($27) + 112|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$28>>2]|0;
 $34 = $32;
 $35 = $33;
 $36 = (($34) - ($35))|0;
 $37 = ($36>>>0)<($30>>>0);
 if ($37) {
  $38 = (($30) - ($36))|0;
  __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE8__appendEj($28,$38);
 } else {
  $39 = ($36>>>0)>($30>>>0);
  if ($39) {
   $40 = (($33) + ($30)|0);
   $41 = ($32|0)==($40|0);
   if (!($41)) {
    HEAP32[$31>>2] = $40;
   }
  }
 }
 $42 = HEAP32[$18>>2]|0;
 $43 = HEAP32[$17>>2]|0;
 $44 = $42;
 $45 = $43;
 $46 = (($44) - ($45))|0;
 $47 = (($46|0) / 56)&-1;
 $48 = ($47>>>0)<($count>>>0);
 if ($48) {
  $49 = (($count) - ($47))|0;
  __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE8__appendEj($17,$49);
  STACKTOP = sp;return;
 }
 $50 = ($47>>>0)>($count>>>0);
 if (!($50)) {
  STACKTOP = sp;return;
 }
 $51 = (($43) + (($count*56)|0)|0);
 $52 = ($42|0)==($51|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i8 = $51;
 $scevgep$i$i$i9 = (($42) + -56|0);
 $53 = (0 - ($__new_last2$i$i$i8))|0;
 $uglygep$i$i$i11 = (($scevgep$i$i$i9) + ($53)|0);
 $uglygep3$i$i$i12 = $uglygep$i$i$i11;
 $54 = (($uglygep3$i$i$i12>>>0) / 56)&-1;
 $55 = $54 ^ -1;
 $scevgep4$i$i$i13 = (($42) + (($55*56)|0)|0);
 HEAP32[$18>>2] = $scevgep4$i$i$i13;
 STACKTOP = sp;return;
}
function __ZNK4Mesh17GetPrimitiveCountEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$0$lcssa = 0, $count$02 = 0, $m$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 56)&-1;
 $8 = ($6|0)>(0);
 if ($8) {
  $count$02 = 0;$m$01 = 0;
 } else {
  $count$0$lcssa = 0;
  STACKTOP = sp;return ($count$0$lcssa|0);
 }
 while(1) {
  $9 = ((($3) + (($m$01*56)|0)|0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($3) + (($m$01*56)|0)|0);
  $12 = HEAP32[$11>>2]|0;
  switch ($12|0) {
  case 3:  {
   $16 = (($10|0) / 2)&-1;
   $$0$i = $16;
   break;
  }
  case 2:  {
   $15 = (($10|0) / 4)&-1;
   $$$i = $15 << 1;
   $$0$i = $$$i;
   break;
  }
  case 5:  {
   $$0$i = $10;
   break;
  }
  case 0:  {
   $13 = (($10|0) / 3)&-1;
   $$0$i = $13;
   break;
  }
  case 1:  {
   $14 = (($10) + -2)|0;
   $$0$i = $14;
   break;
  }
  case 4:  {
   $17 = (($10) + -1)|0;
   $$0$i = $17;
   break;
  }
  default: {
   $$0$i = 0;
  }
  }
  $18 = (($$0$i) + ($count$02))|0;
  $19 = (($m$01) + 1)|0;
  $20 = ($19|0)<($7|0);
  if ($20) {
   $count$02 = $18;$m$01 = $19;
  } else {
   $count$0$lcssa = $18;
   break;
  }
 }
 STACKTOP = sp;return ($count$0$lcssa|0);
}
function __ZN4Mesh19GetVertexBufferDataER16VertexBufferData($this,$buffer) {
 $this = $this|0;
 $buffer = $buffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 ;HEAP32[$buffer+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$buffer+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$buffer+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$buffer+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$buffer+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$buffer+20>>2]=HEAP32[$2+20>>2]|0;HEAP32[$buffer+24>>2]=HEAP32[$2+24>>2]|0;HEAP32[$buffer+28>>2]=HEAP32[$2+28>>2]|0;
 $3 = (($buffer) + 32|0);
 $4 = HEAP32[$0>>2]|0;
 $5 = (($4) + 40|0);
 dest=$3+0|0; src=$5+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = HEAP32[$0>>2]|0;
 $7 = (($6) + 92|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($buffer) + 80|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$0>>2]|0;
 $11 = (($10) + 104|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($buffer) + 84|0);
 HEAP32[$13>>2] = $12;
 $14 = (($10) + 100|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($buffer) + 88|0);
 HEAP32[$16>>2] = $15;
 $17 = HEAP32[$14>>2]|0;
 HEAP32[$16>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN4Mesh21AcquireSharedMeshDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = HEAP32[$2>>2]|0;
 $6 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZN4Mesh14GetMeshBuffersEjPS_($agg$result,$this,$wantedChannels,$secondaryChannels) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $wantedChannels = $wantedChannels|0;
 $secondaryChannels = $secondaryChannels|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $pSecondaryFormat$0 = 0;
 var $s$01$i = 0, $s$02 = 0, $s1$01 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $s$01$i = 0;
 while(1) {
  $3 = ((($this) + ($s$01$i<<3)|0) + 236|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   break;
  }
  $6 = HEAP32[$4>>2]|0;
  $7 = (($6) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_ii[$8 & 4095]($4)|0);
  $2 = (($s$01$i) + 1)|0;
  if ($9) {
   label = 5;
   break;
  }
  $1 = ($2|0)<(4);
  if ($1) {
   $s$01$i = $2;
  } else {
   break;
  }
 }
 if ((label|0) == 5) {
  $10 = (($this) + 272|0);
  HEAP8[$10>>0] = 1;
 }
 $11 = (($this) + 232|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = HEAP32[$12>>2]|0;
  $15 = (($14) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_ii[$16 & 4095]($12)|0);
  if ($17) {
   $18 = (($this) + 273|0);
   HEAP8[$18>>0] = 1;
  }
 }
 __ZN4Mesh10CreateMeshEv($this);
 $19 = (($this) + 268|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  dest=$agg$result+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$11>>2]|0;
 HEAP32[$agg$result>>2] = $22;
 $23 = (($agg$result) + 4|0);
 HEAP32[$23>>2] = 0;
 $96 = 0;$s$02 = 0;
 while(1) {
  $24 = ((($this) + ($s$02<<3)|0) + 236|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   $47 = $96;
   break;
  }
  $27 = ((($agg$result) + ($s$02<<3)|0) + 8|0);
  $28 = $24;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 4)|0;
  $32 = $31;
  $33 = HEAP32[$32>>2]|0;
  $34 = $27;
  $35 = $34;
  HEAP32[$35>>2] = $30;
  $36 = (($34) + 4)|0;
  $37 = $36;
  HEAP32[$37>>2] = $33;
  $38 = HEAP32[$23>>2]|0;
  $39 = (($38) + 1)|0;
  HEAP32[$23>>2] = $39;
  $40 = (($s$02) + 1)|0;
  $41 = ($40|0)<(4);
  if ($41) {
   $96 = $39;$s$02 = $40;
  } else {
   $47 = $39;
   break;
  }
 }
 $42 = ($secondaryChannels|0)==(0|0);
 if ($42) {
  $75 = $47;$pSecondaryFormat$0 = 0;
 } else {
  $97 = $47;$s1$01 = 0;
  while(1) {
   $43 = ((($secondaryChannels) + ($s1$01<<3)|0) + 236|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0|0);
   if ($45) {
    $64 = $97;
    break;
   }
   $46 = (($s1$01) + ($47))|0;
   $48 = ((($agg$result) + ($46<<3)|0) + 8|0);
   $49 = $43;
   $50 = $49;
   $51 = HEAP32[$50>>2]|0;
   $52 = (($49) + 4)|0;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = $48;
   $56 = $55;
   HEAP32[$56>>2] = $51;
   $57 = (($55) + 4)|0;
   $58 = $57;
   HEAP32[$58>>2] = $54;
   $59 = HEAP32[$23>>2]|0;
   $60 = (($59) + 1)|0;
   HEAP32[$23>>2] = $60;
   $61 = (($s1$01) + 1)|0;
   $62 = ($61|0)<(4);
   if ($62) {
    $97 = $60;$s1$01 = $61;
   } else {
    $64 = $60;
    break;
   }
  }
  $63 = ($47|0)==($64|0);
  if ($63) {
   $75 = $47;$pSecondaryFormat$0 = 0;
  } else {
   $65 = (($secondaryChannels) + 268|0);
   $66 = HEAP32[$65>>2]|0;
   $75 = $64;$pSecondaryFormat$0 = $66;
  }
 }
 $67 = HEAP32[((640792 + 76|0))>>2]|0;
 $68 = $wantedChannels & 4;
 $69 = $68 & $67;
 $70 = ($69|0)==(0);
 if ($70) {
  $93 = $20;
 } else {
  $71 = (($20) + 19|0);
  $72 = HEAP8[$71>>0]|0;
  $73 = ($72<<24>>24)==(0);
  if ($73) {
   $74 = ((($agg$result) + ($75<<3)|0) + 8|0);
   $76 = (__Z12GetGfxDevicev()|0);
   $77 = (($this) + 28|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (($78) + 100|0);
   $80 = HEAP32[$79>>2]|0;
   __ZN9GfxDevice23GetAllWhiteVertexStreamEj($0,$76,$80);
   $81 = $0;
   $82 = $81;
   $83 = HEAP32[$82>>2]|0;
   $84 = (($81) + 4)|0;
   $85 = $84;
   $86 = HEAP32[$85>>2]|0;
   $87 = $74;
   $88 = $87;
   HEAP32[$88>>2] = $83;
   $89 = (($87) + 4)|0;
   $90 = $89;
   HEAP32[$90>>2] = $86;
   $91 = HEAP32[$23>>2]|0;
   $92 = (($91) + 1)|0;
   HEAP32[$23>>2] = $92;
   $$pre = HEAP32[$19>>2]|0;
   $93 = $$pre;
  } else {
   $93 = $20;
  }
 }
 $94 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($93,$wantedChannels,$pSecondaryFormat$0)|0);
 $95 = (($agg$result) + 40|0);
 HEAP32[$95>>2] = $94;
 STACKTOP = sp;return;
}
function __ZN4Mesh10CreateMeshEv($this) {
 $this = $this|0;
 var $$$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $flags$0 = 0, $i$01$i = 0, $i$01$i3 = 0, $indexCount$0 = 0, $newIndices = 0, $s$013 = 0;
 var $srcIndices$0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy2 = sp + 56|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $newIndices = sp + 40|0;
 $3 = (($this) + 272|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (($this) + 273|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   STACKTOP = sp;return;
  }
 }
 $9 = (($this) + 274|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = (($this) + 275|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = (($this) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 1)|0;
 HEAP32[$17>>2] = $19;
 $20 = HEAP32[$17>>2]|0;
 $21 = HEAP32[$15>>2]|0;
 $22 = (__Z21GetUncheckedGfxDevicev()|0);
 $23 = HEAP8[$3>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if (!($24)) {
  dest=$$byval_copy2+0|0; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $25 = HEAP32[$15>>2]|0;
  $26 = (($25) + 8|0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$$byval_copy2+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$$byval_copy2+20>>2]=HEAP32[$26+20>>2]|0;HEAP32[$$byval_copy2+24>>2]=HEAP32[$26+24>>2]|0;HEAP32[$$byval_copy2+28>>2]=HEAP32[$26+28>>2]|0;
  $27 = (($$byval_copy2) + 32|0);
  $28 = (($25) + 40|0);
  dest=$27+0|0; src=$28+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $29 = (($25) + 92|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($$byval_copy2) + 80|0);
  HEAP32[$31>>2] = $30;
  $32 = (($25) + 104|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($$byval_copy2) + 84|0);
  HEAP32[$34>>2] = $33;
  $35 = (($25) + 100|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($$byval_copy2) + 88|0);
  HEAP32[$37>>2] = $36;
  $38 = HEAP32[$35>>2]|0;
  HEAP32[$37>>2] = $38;
  $39 = (($this) + 152|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = (__Z12GetGfxDevicev()|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($43) + 292|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$39>>2]|0;
   FUNCTION_TABLE_vii[$45 & 4095]($42,$46);
   HEAP32[$39>>2] = 0;
  }
  $47 = (($this) + 156|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = (__Z12GetGfxDevicev()|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + 292|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$47>>2]|0;
   FUNCTION_TABLE_vii[$53 & 4095]($50,$54);
   HEAP32[$47>>2] = 0;
  }
  $55 = (($this) + 160|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if (!($57)) {
   $58 = (__Z12GetGfxDevicev()|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 292|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vii[$61 & 4095]($58,$62);
   HEAP32[$55>>2] = 0;
  }
  $s$013 = 0;
  while(1) {
   $63 = ((($$byval_copy2) + (($s$013*12)|0)|0) + 32|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   if ($65) {
    label = 16;
   } else {
    $66 = HEAP32[$37>>2]|0;
    $67 = ($66|0)>(0);
    if ($67) {
     $68 = ((($this) + ($s$013<<3)|0) + 236|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = ($69|0)==(0|0);
     if ($70) {
      $71 = HEAP32[$22>>2]|0;
      $72 = (($71) + 276|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (FUNCTION_TABLE_ii[$73 & 4095]($22)|0);
      HEAP32[$68>>2] = $74;
      $$pre16 = HEAP32[$37>>2]|0;
      $82 = $$pre16;$87 = $74;
     } else {
      $82 = $66;$87 = $69;
     }
     $75 = HEAP32[$22>>2]|0;
     $76 = (($75) + 280|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ((($$byval_copy2) + (($s$013*12)|0)|0) + 42|0);
     $79 = HEAP8[$78>>0]|0;
     $80 = $79&255;
     $81 = Math_imul($80, $82)|0;
     $83 = HEAP32[$31>>2]|0;
     $84 = ((($$byval_copy2) + (($s$013*12)|0)|0) + 36|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = (($83) + ($85)|0);
     FUNCTION_TABLE_viiiiiii[$77 & 127]($22,$87,$11,$14,$81,$86,1);
     $88 = HEAP32[$22>>2]|0;
     $89 = (($88) + 656|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = HEAP32[$68>>2]|0;
     $92 = HEAP32[$this>>2]|0;
     $93 = (($92) + 32|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = (FUNCTION_TABLE_ii[$94 & 4095]($this)|0);
     FUNCTION_TABLE_viii[$90 & 4095]($22,$91,$95);
     $96 = HEAP8[$78>>0]|0;
     $97 = $96&255;
     $98 = ((($this) + ($s$013<<3)|0) + 240|0);
     HEAP32[$98>>2] = $97;
    } else {
     label = 16;
    }
   }
   if ((label|0) == 16) {
    label = 0;
    $99 = ((($this) + ($s$013<<3)|0) + 236|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = ($100|0)==(0|0);
    if (!($101)) {
     $102 = (__Z12GetGfxDevicev()|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = (($103) + 292|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = HEAP32[$99>>2]|0;
     FUNCTION_TABLE_vii[$105 & 4095]($102,$106);
     HEAP32[$99>>2] = 0;
     $107 = ((($this) + ($s$013<<3)|0) + 240|0);
     HEAP32[$107>>2] = 0;
    }
   }
   $108 = (($s$013) + 1)|0;
   $exitcond = ($108|0)==(4);
   if ($exitcond) {
    break;
   } else {
    $s$013 = $108;
   }
  }
  $109 = (__Z26GetMeshVertexFormatManagerv()|0);
  __ZN18VertexChannelsInfoC2ERA8_K11ChannelInfo($2,$$byval_copy2);
  $110 = (__ZN23MeshVertexFormatManager19GetMeshVertexFormatERK18VertexChannelsInfo($109,$2)|0);
  $111 = (($this) + 268|0);
  HEAP32[$111>>2] = $110;
 }
 $112 = (($this) + 273|0);
 $113 = HEAP8[$112>>0]|0;
 $114 = ($113<<24>>24)==(0);
 do {
  if (!($114)) {
   $115 = HEAP32[$15>>2]|0;
   $116 = (($115) + 112|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = (($115) + 108|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = $117;
   $121 = $119;
   $122 = (($120) - ($121))|0;
   $123 = ($122>>>0)>(1);
   $124 = (($this) + 232|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = ($125|0)==(0|0);
   if (!($123)) {
    if ($126) {
     break;
    }
    $211 = (__Z12GetGfxDevicev()|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = (($212) + 272|0);
    $214 = HEAP32[$213>>2]|0;
    $215 = HEAP32[$124>>2]|0;
    FUNCTION_TABLE_vii[$214 & 4095]($211,$215);
    HEAP32[$124>>2] = 0;
    break;
   }
   if ($126) {
    $127 = (__Z12GetGfxDevicev()|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = (($128) + 256|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = (FUNCTION_TABLE_ii[$130 & 4095]($127)|0);
    HEAP32[$124>>2] = $131;
    $$pre = HEAP32[$15>>2]|0;
    $137 = $$pre;$245 = $131;
   } else {
    $137 = $115;$245 = $125;
   }
   $132 = HEAP32[628512>>2]|0;
   HEAP32[$newIndices>>2] = 0;
   $133 = (($newIndices) + 4|0);
   HEAP32[$133>>2] = $132;
   $134 = (($newIndices) + 8|0);
   HEAP32[$134>>2] = 0;
   $135 = (($newIndices) + 12|0);
   HEAP32[$135>>2] = 0;
   $136 = (($137) + 108|0);
   $138 = HEAP32[$136>>2]|0;
   $139 = (($137) + 112|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ($138|0)==($140|0);
   $$$i = $141 ? 0 : $138;
   $142 = $140;
   $143 = $138;
   $144 = (($142) - ($143))|0;
   $145 = $144 >>> 1;
   $146 = (($this) + 48|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = (($this) + 44|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = ($147|0)==($149|0);
   L39: do {
    if ($150) {
     $192 = $245;$flags$0 = 1;$indexCount$0 = $145;$srcIndices$0 = $$$i;
     label = 41;
    } else {
     $151 = $147;
     $152 = $149;
     $153 = (($151) - ($152))|0;
     $154 = (($153|0) / 56)&-1;
     $i$01$i = 0;
     while(1) {
      $157 = (($149) + (($i$01$i*56)|0)|0);
      $158 = HEAP32[$157>>2]|0;
      $159 = ($158|0)==(2);
      $156 = (($i$01$i) + 1)|0;
      if ($159) {
       break;
      }
      $155 = ($156>>>0)<($154>>>0);
      if ($155) {
       $i$01$i = $156;
      } else {
       label = 28;
       break;
      }
     }
     L44: do {
      if ((label|0) == 28) {
       if ($150) {
        $192 = $245;$flags$0 = 1;$indexCount$0 = $145;$srcIndices$0 = $$$i;
        label = 41;
        break L39;
       }
       $160 = $147;
       $161 = $149;
       $162 = (($160) - ($161))|0;
       $163 = (($162|0) / 56)&-1;
       $i$01$i3 = 0;
       while(1) {
        $166 = (($149) + (($i$01$i3*56)|0)|0);
        $167 = HEAP32[$166>>2]|0;
        $168 = ($167|0)==(1);
        $165 = (($i$01$i3) + 1)|0;
        if ($168) {
         break L44;
        }
        $164 = ($165>>>0)<($163>>>0);
        if ($164) {
         $i$01$i3 = $165;
        } else {
         $192 = $245;$flags$0 = 1;$indexCount$0 = $145;$srcIndices$0 = $$$i;
         label = 41;
         break L39;
        }
       }
      }
     } while(0);
     HEAP32[$134>>2] = $145;
     $169 = ($145|0)==(0);
     if ($169) {
      $$pre17 = $145 << 1;
      $$pre$phiZ2D = $$pre17;$174 = 0;
     } else {
      HEAP32[$135>>2] = $145;
      $170 = $145 << 1;
      HEAP32[$1>>2] = $132;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
      $171 = (invoke_iiiiiiii(108,(0|0),($170|0),2,($$byval_copy2|0),0,(585592|0),370)|0);
      $172 = __THREW__; __THREW__ = 0;
      $173 = $172&1;
      if ($173) {
       break;
      }
      HEAP32[$newIndices>>2] = $171;
      $$pre$phiZ2D = $170;$174 = $171;
     }
     _memcpy(($174|0),($$$i|0),($$pre$phiZ2D|0))|0;
     $175 = (($this) + 44|0);
     __THREW__ = 0;
     invoke_vii(2668,($175|0),($newIndices|0));
     $176 = __THREW__; __THREW__ = 0;
     $177 = $176&1;
     if (!($177)) {
      $178 = HEAP32[$newIndices>>2]|0;
      $179 = HEAP32[$134>>2]|0;
      $$pre15 = HEAP32[$124>>2]|0;
      $192 = $$pre15;$flags$0 = 0;$indexCount$0 = $179;$srcIndices$0 = $178;
      label = 41;
     }
    }
   } while(0);
   if ((label|0) == 41) {
    $188 = HEAP32[$22>>2]|0;
    $189 = (($188) + 260|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = $indexCount$0 << 1;
    __THREW__ = 0;
    invoke_viiiiiii($190|0,($22|0),($192|0),($11|0),($14|0),($191|0),($srcIndices$0|0),($flags$0|0));
    $193 = __THREW__; __THREW__ = 0;
    $194 = $193&1;
    if (!($194)) {
     $195 = HEAP32[$22>>2]|0;
     $196 = (($195) + 660|0);
     $197 = HEAP32[$196>>2]|0;
     $198 = HEAP32[$124>>2]|0;
     $199 = HEAP32[$this>>2]|0;
     $200 = (($199) + 32|0);
     $201 = HEAP32[$200>>2]|0;
     __THREW__ = 0;
     $202 = (invoke_ii($201|0,($this|0))|0);
     $203 = __THREW__; __THREW__ = 0;
     $204 = $203&1;
     if (!($204)) {
      __THREW__ = 0;
      invoke_viii($197|0,($22|0),($198|0),($202|0));
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if (!($206)) {
       $207 = HEAP32[$135>>2]|0;
       $208 = ($207|0)>(-1);
       if (!($208)) {
        break;
       }
       $209 = HEAP32[$newIndices>>2]|0;
       $210 = HEAP32[$133>>2]|0;
       HEAP32[$0>>2] = $210;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId($209,$$byval_copy2);
       HEAP32[$newIndices>>2] = 0;
       break;
      }
     }
    }
   }
   $180 = ___cxa_find_matching_catch()|0;
   $181 = tempRet0;
   $182 = HEAP32[$135>>2]|0;
   $183 = ($182|0)>(-1);
   if (!($183)) {
    ___resumeException($180|0);
    // unreachable;
   }
   $184 = HEAP32[$newIndices>>2]|0;
   $185 = HEAP32[$133>>2]|0;
   HEAP32[$0>>2] = $185;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($184|0),($$byval_copy2|0));
   $186 = __THREW__; __THREW__ = 0;
   $187 = $186&1;
   if ($187) {
    $243 = ___cxa_find_matching_catch(0|0)|0;
    $244 = tempRet0;
    ___clang_call_terminate($243);
    // unreachable;
   }
   HEAP32[$newIndices>>2] = 0;
   ___resumeException($180|0);
   // unreachable;
  }
 } while(0);
 $216 = HEAP32[$22>>2]|0;
 $217 = (($216) + 360|0);
 $218 = HEAP32[$217>>2]|0;
 FUNCTION_TABLE_vii[$218 & 4095]($22,$21);
 HEAP8[$3>>0] = 0;
 HEAP8[$112>>0] = 0;
 $219 = (($this) + 152|0);
 $220 = HEAP32[$219>>2]|0;
 $221 = ($220|0)==(0|0);
 if (!($221)) {
  $222 = (__Z12GetGfxDevicev()|0);
  $223 = HEAP32[$222>>2]|0;
  $224 = (($223) + 292|0);
  $225 = HEAP32[$224>>2]|0;
  $226 = HEAP32[$219>>2]|0;
  FUNCTION_TABLE_vii[$225 & 4095]($222,$226);
  HEAP32[$219>>2] = 0;
 }
 $227 = (($this) + 156|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = ($228|0)==(0|0);
 if (!($229)) {
  $230 = (__Z12GetGfxDevicev()|0);
  $231 = HEAP32[$230>>2]|0;
  $232 = (($231) + 292|0);
  $233 = HEAP32[$232>>2]|0;
  $234 = HEAP32[$227>>2]|0;
  FUNCTION_TABLE_vii[$233 & 4095]($230,$234);
  HEAP32[$227>>2] = 0;
 }
 $235 = (($this) + 160|0);
 $236 = HEAP32[$235>>2]|0;
 $237 = ($236|0)==(0|0);
 if ($237) {
  STACKTOP = sp;return;
 }
 $238 = (__Z12GetGfxDevicev()|0);
 $239 = HEAP32[$238>>2]|0;
 $240 = (($239) + 292|0);
 $241 = HEAP32[$240>>2]|0;
 $242 = HEAP32[$235>>2]|0;
 FUNCTION_TABLE_vii[$241 & 4095]($238,$242);
 HEAP32[$235>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4Mesh12UploadedData6UnloadEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (__Z12GetGfxDevicev()|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 272|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$this>>2]|0;
  FUNCTION_TABLE_vii[$5 & 4095]($2,$6);
  HEAP32[$this>>2] = 0;
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = (__Z12GetGfxDevicev()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 292|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($10,$14);
  HEAP32[$7>>2] = 0;
  $15 = (($this) + 8|0);
  HEAP32[$15>>2] = 0;
 }
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (__Z12GetGfxDevicev()|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($20) + 292|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$22 & 4095]($19,$23);
  HEAP32[$16>>2] = 0;
  $24 = (($this) + 16|0);
  HEAP32[$24>>2] = 0;
 }
 $25 = (($this) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = (__Z12GetGfxDevicev()|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 292|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$25>>2]|0;
  FUNCTION_TABLE_vii[$31 & 4095]($28,$32);
  HEAP32[$25>>2] = 0;
  $33 = (($this) + 24|0);
  HEAP32[$33>>2] = 0;
 }
 $34 = (($this) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = (__Z12GetGfxDevicev()|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 292|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$40 & 4095]($37,$41);
 HEAP32[$34>>2] = 0;
 $42 = (($this) + 32|0);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4Mesh15CopyTransformedERKS_RK10Matrix4x4f($this,$mesh,$transform) {
 $this = $this|0;
 $mesh = $mesh|0;
 $transform = $transform|0;
 var $$byval_copy1 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0);
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0;
 var $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $invTranspose3x3 = 0, $transform3x3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy1 = sp + 96|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 104|0;
 $transform3x3 = sp + 60|0;
 $invTranspose3x3 = sp + 24|0;
 $3 = (($mesh) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 100|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 96|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = $8 ^ -1;
 $13 = (($4) + 8|0);
 __ZNK14VertexDataInfo16GetStreamsLayoutEv($1,$13);
 __ZNK14VertexDataInfo17GetChannelsLayoutEv($2,$13);
 __ZN10VertexData6ResizeEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($11,$6,$8,$12,$1,$2);
 $14 = $8 & 1;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = HEAP32[$3>>2]|0;
  $17 = (($16) + 92|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) + 8|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20&255;
  $22 = ((($16) + (($21*12)|0)|0) + 44|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($16) + 9|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25&255;
  $27 = (($26) + ($23))|0;
  $28 = (($18) + ($27)|0);
  $29 = ((($16) + (($21*12)|0)|0) + 50|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = HEAP32[$9>>2]|0;
  $33 = (($32) + 92|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 8|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = ((($32) + (($37*12)|0)|0) + 44|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($32) + 9|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41&255;
  $43 = (($42) + ($39))|0;
  $44 = (($34) + ($43)|0);
  $45 = ((($32) + (($37*12)|0)|0) + 50|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  __Z18TransformPoints3x4RK10Matrix4x4fPK8Vector3fjPS2_ji($transform,$28,$31,$44,$47,$6);
 }
 __ZN10Matrix3x3fC2ERK10Matrix4x4f($transform3x3,$transform);
 dest=$invTranspose3x3+0|0; src=$transform3x3+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __ZN10Matrix3x3f15InvertTransposeEv($invTranspose3x3);
 $48 = $8 & 2;
 $49 = ($48|0)==(0);
 if (!($49)) {
  $50 = HEAP32[$3>>2]|0;
  $51 = (($50) + 14|0);
  $52 = HEAP8[$51>>0]|0;
  $53 = ($52<<24>>24)==(0);
  do {
   if ($53) {
    $54 = (($50) + 15|0);
    $55 = HEAP8[$54>>0]|0;
    $56 = ($55&255)<(3);
    if ($56) {
     $376 = 0;$377 = 0;
    } else {
     $57 = (($50) + 92|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $378 = 1;$379 = 0;
     } else {
      $60 = (($50) + 12|0);
      $61 = HEAP8[$60>>0]|0;
      $62 = $61&255;
      $63 = ((($50) + (($62*12)|0)|0) + 50|0);
      $64 = HEAP8[$63>>0]|0;
      $65 = $64&255;
      $66 = ((($50) + (($62*12)|0)|0) + 44|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($50) + 13|0);
      $69 = HEAP8[$68>>0]|0;
      $70 = $69&255;
      $71 = (($70) + ($67))|0;
      $72 = (($58) + ($71)|0);
      $378 = $65;$379 = $72;
     }
     if ($53) {
      $376 = $379;$377 = $378;
     } else {
      $120 = $379;$121 = 0;$181 = $378;
      break;
     }
    }
    $73 = (($50) + 15|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = ($74&255)<(3);
    if ($75) {
     $120 = $376;$121 = 0;$181 = $377;
    } else {
     $76 = (($50) + 92|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      $120 = $376;$121 = 0;$181 = $377;
     } else {
      $79 = (($50) + 100|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($50) + 12|0);
      $82 = HEAP8[$81>>0]|0;
      $83 = $82&255;
      $84 = ((($50) + (($83*12)|0)|0) + 50|0);
      $85 = HEAP8[$84>>0]|0;
      $86 = $85&255;
      $87 = ((($50) + (($83*12)|0)|0) + 44|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (($50) + 13|0);
      $90 = HEAP8[$89>>0]|0;
      $91 = $90&255;
      $92 = Math_imul($86, $80)|0;
      $93 = (($92) + ($88))|0;
      $94 = (($93) + ($91))|0;
      $95 = (($77) + ($94)|0);
      $120 = $376;$121 = $95;$181 = $377;
     }
    }
   } else {
    $120 = 0;$121 = 0;$181 = 0;
   }
  } while(0);
  $96 = HEAP32[$9>>2]|0;
  $97 = (($96) + 14|0);
  $98 = HEAP8[$97>>0]|0;
  $99 = ($98<<24>>24)==(0);
  if ($99) {
   $100 = (($96) + 15|0);
   $101 = HEAP8[$100>>0]|0;
   $102 = ($101&255)<(3);
   if ($102) {
    $183 = 0;$380 = 0;
   } else {
    $103 = (($96) + 92|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($104|0)==(0|0);
    if ($105) {
     $183 = 1;$380 = 0;
    } else {
     $106 = (($96) + 12|0);
     $107 = HEAP8[$106>>0]|0;
     $108 = $107&255;
     $109 = ((($96) + (($108*12)|0)|0) + 50|0);
     $110 = HEAP8[$109>>0]|0;
     $111 = $110&255;
     $112 = ((($96) + (($108*12)|0)|0) + 44|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = (($96) + 13|0);
     $115 = HEAP8[$114>>0]|0;
     $116 = $115&255;
     $117 = (($116) + ($113))|0;
     $118 = (($104) + ($117)|0);
     $183 = $111;$380 = $118;
    }
   }
  } else {
   $183 = 0;$380 = 0;
  }
  $119 = ($120|0)==($121|0);
  if (!($119)) {
   $122 = (($invTranspose3x3) + 12|0);
   $123 = (($invTranspose3x3) + 24|0);
   $124 = (($invTranspose3x3) + 4|0);
   $125 = (($invTranspose3x3) + 16|0);
   $126 = (($invTranspose3x3) + 28|0);
   $127 = (($invTranspose3x3) + 8|0);
   $128 = (($invTranspose3x3) + 20|0);
   $129 = (($invTranspose3x3) + 32|0);
   $130 = Math_fround(HEAPF32[616648>>2]);
   $133 = $120;$175 = $380;
   while(1) {
    $131 = Math_fround(HEAPF32[$invTranspose3x3>>2]);
    $132 = Math_fround(HEAPF32[$133>>2]);
    $134 = Math_fround($131 * $132);
    $135 = Math_fround(HEAPF32[$122>>2]);
    $136 = (($133) + 4|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = Math_fround($135 * $137);
    $139 = Math_fround($134 + $138);
    $140 = Math_fround(HEAPF32[$123>>2]);
    $141 = (($133) + 8|0);
    $142 = Math_fround(HEAPF32[$141>>2]);
    $143 = Math_fround($140 * $142);
    $144 = Math_fround($139 + $143);
    $145 = Math_fround(HEAPF32[$124>>2]);
    $146 = Math_fround($132 * $145);
    $147 = Math_fround(HEAPF32[$125>>2]);
    $148 = Math_fround($137 * $147);
    $149 = Math_fround($146 + $148);
    $150 = Math_fround(HEAPF32[$126>>2]);
    $151 = Math_fround($142 * $150);
    $152 = Math_fround($149 + $151);
    $153 = Math_fround(HEAPF32[$127>>2]);
    $154 = Math_fround($132 * $153);
    $155 = Math_fround(HEAPF32[$128>>2]);
    $156 = Math_fround($137 * $155);
    $157 = Math_fround($154 + $156);
    $158 = Math_fround(HEAPF32[$129>>2]);
    $159 = Math_fround($142 * $158);
    $160 = Math_fround($157 + $159);
    $161 = Math_fround($144 * $144);
    $162 = Math_fround($152 * $152);
    $163 = Math_fround($161 + $162);
    $164 = Math_fround($160 * $160);
    $165 = Math_fround($163 + $164);
    $166 = (Math_fround(Math_sqrt((Math_fround($165)))));
    $167 = $166 > $130;
    if ($167) {
     $168 = Math_fround($144 / $166);
     $169 = Math_fround($152 / $166);
     $170 = Math_fround($160 / $166);
     $174 = $168;$177 = $169;$179 = $170;
    } else {
     $171 = Math_fround(HEAPF32[616680>>2]);
     $172 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
     $173 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
     $174 = $171;$177 = $172;$179 = $173;
    }
    HEAPF32[$175>>2] = $174;
    $176 = (($175) + 4|0);
    HEAPF32[$176>>2] = $177;
    $178 = (($175) + 8|0);
    HEAPF32[$178>>2] = $179;
    $180 = (($133) + ($181)|0);
    $182 = (($175) + ($183)|0);
    $184 = ($180|0)==($121|0);
    if ($184) {
     break;
    } else {
     $133 = $180;$175 = $182;
    }
   }
  }
 }
 $185 = $8 & 128;
 $186 = ($185|0)==(0);
 if (!($186)) {
  $187 = HEAP32[$3>>2]|0;
  $188 = (($187) + 38|0);
  $189 = HEAP8[$188>>0]|0;
  $190 = ($189<<24>>24)==(0);
  do {
   if ($190) {
    $191 = (($187) + 39|0);
    $192 = HEAP8[$191>>0]|0;
    $193 = ($192&255)<(4);
    if ($193) {
     $381 = 0;$382 = 0;
    } else {
     $194 = (($187) + 92|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = ($195|0)==(0|0);
     if ($196) {
      $383 = 1;$384 = 0;
     } else {
      $197 = (($187) + 36|0);
      $198 = HEAP8[$197>>0]|0;
      $199 = $198&255;
      $200 = ((($187) + (($199*12)|0)|0) + 50|0);
      $201 = HEAP8[$200>>0]|0;
      $202 = $201&255;
      $203 = ((($187) + (($199*12)|0)|0) + 44|0);
      $204 = HEAP32[$203>>2]|0;
      $205 = (($187) + 37|0);
      $206 = HEAP8[$205>>0]|0;
      $207 = $206&255;
      $208 = (($207) + ($204))|0;
      $209 = (($195) + ($208)|0);
      $383 = $202;$384 = $209;
     }
     if ($190) {
      $381 = $384;$382 = $383;
     } else {
      $257 = $384;$258 = 0;$321 = $383;
      break;
     }
    }
    $210 = (($187) + 39|0);
    $211 = HEAP8[$210>>0]|0;
    $212 = ($211&255)<(4);
    if ($212) {
     $257 = $381;$258 = 0;$321 = $382;
    } else {
     $213 = (($187) + 92|0);
     $214 = HEAP32[$213>>2]|0;
     $215 = ($214|0)==(0|0);
     if ($215) {
      $257 = $381;$258 = 0;$321 = $382;
     } else {
      $216 = (($187) + 100|0);
      $217 = HEAP32[$216>>2]|0;
      $218 = (($187) + 36|0);
      $219 = HEAP8[$218>>0]|0;
      $220 = $219&255;
      $221 = ((($187) + (($220*12)|0)|0) + 50|0);
      $222 = HEAP8[$221>>0]|0;
      $223 = $222&255;
      $224 = ((($187) + (($220*12)|0)|0) + 44|0);
      $225 = HEAP32[$224>>2]|0;
      $226 = (($187) + 37|0);
      $227 = HEAP8[$226>>0]|0;
      $228 = $227&255;
      $229 = Math_imul($223, $217)|0;
      $230 = (($229) + ($225))|0;
      $231 = (($230) + ($228))|0;
      $232 = (($214) + ($231)|0);
      $257 = $381;$258 = $232;$321 = $382;
     }
    }
   } else {
    $257 = 0;$258 = 0;$321 = 0;
   }
  } while(0);
  $233 = HEAP32[$9>>2]|0;
  $234 = (($233) + 38|0);
  $235 = HEAP8[$234>>0]|0;
  $236 = ($235<<24>>24)==(0);
  if ($236) {
   $237 = (($233) + 39|0);
   $238 = HEAP8[$237>>0]|0;
   $239 = ($238&255)<(4);
   if ($239) {
    $323 = 0;$385 = 0;
   } else {
    $240 = (($233) + 92|0);
    $241 = HEAP32[$240>>2]|0;
    $242 = ($241|0)==(0|0);
    if ($242) {
     $323 = 1;$385 = 0;
    } else {
     $243 = (($233) + 36|0);
     $244 = HEAP8[$243>>0]|0;
     $245 = $244&255;
     $246 = ((($233) + (($245*12)|0)|0) + 50|0);
     $247 = HEAP8[$246>>0]|0;
     $248 = $247&255;
     $249 = ((($233) + (($245*12)|0)|0) + 44|0);
     $250 = HEAP32[$249>>2]|0;
     $251 = (($233) + 37|0);
     $252 = HEAP8[$251>>0]|0;
     $253 = $252&255;
     $254 = (($253) + ($250))|0;
     $255 = (($241) + ($254)|0);
     $323 = $248;$385 = $255;
    }
   }
  } else {
   $323 = 0;$385 = 0;
  }
  $256 = ($257|0)==($258|0);
  if (!($256)) {
   $259 = (($transform3x3) + 12|0);
   $260 = (($transform3x3) + 24|0);
   $261 = (($transform3x3) + 4|0);
   $262 = (($transform3x3) + 16|0);
   $263 = (($transform3x3) + 28|0);
   $264 = (($transform3x3) + 8|0);
   $265 = (($transform3x3) + 20|0);
   $266 = (($transform3x3) + 32|0);
   $267 = Math_fround(HEAPF32[616648>>2]);
   $269 = $257;$314 = $385;
   while(1) {
    $268 = Math_fround(HEAPF32[$269>>2]);
    $270 = (($269) + 4|0);
    $271 = Math_fround(HEAPF32[$270>>2]);
    $272 = (($269) + 8|0);
    $273 = Math_fround(HEAPF32[$272>>2]);
    $274 = Math_fround(HEAPF32[$transform3x3>>2]);
    $275 = Math_fround($268 * $274);
    $276 = Math_fround(HEAPF32[$259>>2]);
    $277 = Math_fround($271 * $276);
    $278 = Math_fround($275 + $277);
    $279 = Math_fround(HEAPF32[$260>>2]);
    $280 = Math_fround($273 * $279);
    $281 = Math_fround($278 + $280);
    $282 = Math_fround(HEAPF32[$261>>2]);
    $283 = Math_fround($268 * $282);
    $284 = Math_fround(HEAPF32[$262>>2]);
    $285 = Math_fround($271 * $284);
    $286 = Math_fround($283 + $285);
    $287 = Math_fround(HEAPF32[$263>>2]);
    $288 = Math_fround($273 * $287);
    $289 = Math_fround($286 + $288);
    $290 = Math_fround(HEAPF32[$264>>2]);
    $291 = Math_fround($268 * $290);
    $292 = Math_fround(HEAPF32[$265>>2]);
    $293 = Math_fround($271 * $292);
    $294 = Math_fround($291 + $293);
    $295 = Math_fround(HEAPF32[$266>>2]);
    $296 = Math_fround($273 * $295);
    $297 = Math_fround($294 + $296);
    $298 = Math_fround($281 * $281);
    $299 = Math_fround($289 * $289);
    $300 = Math_fround($298 + $299);
    $301 = Math_fround($297 * $297);
    $302 = Math_fround($300 + $301);
    $303 = (Math_fround(Math_sqrt((Math_fround($302)))));
    $304 = $303 > $267;
    if ($304) {
     $305 = Math_fround($281 / $303);
     $306 = Math_fround($289 / $303);
     $307 = Math_fround($297 / $303);
     $313 = $305;$316 = $306;$318 = $307;
    } else {
     $308 = Math_fround(HEAPF32[616680>>2]);
     $309 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
     $310 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
     $313 = $308;$316 = $309;$318 = $310;
    }
    $311 = (($269) + 12|0);
    $312 = Math_fround(HEAPF32[$311>>2]);
    HEAPF32[$314>>2] = $313;
    $315 = (($314) + 4|0);
    HEAPF32[$315>>2] = $316;
    $317 = (($314) + 8|0);
    HEAPF32[$317>>2] = $318;
    $319 = (($314) + 12|0);
    HEAPF32[$319>>2] = $312;
    $320 = (($269) + ($321)|0);
    $322 = (($314) + ($323)|0);
    $324 = ($320|0)==($258|0);
    if ($324) {
     break;
    } else {
     $269 = $320;$314 = $322;
    }
   }
  }
 }
 $325 = HEAP32[$9>>2]|0;
 $326 = HEAP32[$3>>2]|0;
 $327 = ($325|0)==($326|0);
 if (!($327)) {
  $328 = (($325) + 108|0);
  $329 = (($326) + 108|0);
  $330 = HEAP32[$329>>2]|0;
  $331 = (($326) + 112|0);
  $332 = HEAP32[$331>>2]|0;
  __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE6assignIPhEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($328,$330,$332);
 }
 $333 = ($this|0)==($mesh|0);
 if (!($333)) {
  $334 = (($this) + 44|0);
  $335 = (($mesh) + 44|0);
  $336 = HEAP32[$335>>2]|0;
  $337 = (($mesh) + 48|0);
  $338 = HEAP32[$337>>2]|0;
  __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($334,$336,$338);
 }
 $339 = HEAP32[$9>>2]|0;
 $340 = (($339) + 136|0);
 $341 = HEAP32[$3>>2]|0;
 $342 = ($341|0)==($339|0);
 if ($342) {
  $369 = $339;
  $367 = $8 & 124;
  $368 = (($369) + 8|0);
  __Z22CopyVertexDataChannelsjjRK14VertexDataInfoRS_($6,$367,$13,$368);
  $370 = (($mesh) + 276|0);
  $371 = HEAP8[$370>>0]|0;
  $372 = (($this) + 276|0);
  HEAP8[$372>>0] = $371;
  $373 = (($this) + 168|0);
  $374 = (($mesh) + 168|0);
  ;HEAP32[$373+0>>2]=HEAP32[$374+0>>2]|0;HEAP32[$373+4>>2]=HEAP32[$374+4>>2]|0;HEAP32[$373+8>>2]=HEAP32[$374+8>>2]|0;HEAP32[$373+12>>2]=HEAP32[$374+12>>2]|0;HEAP32[$373+16>>2]=HEAP32[$374+16>>2]|0;HEAP32[$373+20>>2]=HEAP32[$374+20>>2]|0;
  $375 = (($this) + 192|0);
  __ZN17CollisionMeshData20VertexDataHasChangedEv($375);
  __ZN4Mesh16SetChannelsDirtyEjb($this,$8,1);
  __ZN4Mesh14ClearSkinCacheEv($this);
  STACKTOP = sp;return;
 }
 $343 = (($341) + 136|0);
 $344 = HEAP32[$343>>2]|0;
 $345 = (($341) + 144|0);
 $346 = HEAP32[$345>>2]|0;
 $$idx = $346 << 5;
 $347 = $$idx >> 5;
 $348 = (($339) + 144|0);
 HEAP32[$348>>2] = $347;
 $349 = (($339) + 148|0);
 $350 = HEAP32[$349>>2]|0;
 $351 = $350 & 2147483647;
 $352 = ($351>>>0)<($347>>>0);
 do {
  if ($352) {
   $353 = ($350|0)>(-1);
   if ($353) {
    HEAP32[$349>>2] = $347;
    $354 = HEAP32[$340>>2]|0;
    $355 = (($339) + 140|0);
    $356 = HEAP32[$355>>2]|0;
    HEAP32[$0>>2] = $356;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $357 = (__Z16realloc_internalPvji10MemLabelIdiPKci($354,$$idx,16,$$byval_copy1,0,585592,370)|0);
    HEAP32[$340>>2] = $357;
    $366 = $357;
    break;
   } else {
    $358 = (($339) + 140|0);
    $359 = HEAP32[$358>>2]|0;
    HEAP32[$0>>2] = $359;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $360 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx,16,$$byval_copy1,0,585592,352)|0);
    $361 = HEAP32[$340>>2]|0;
    $362 = HEAP32[$348>>2]|0;
    $363 = $362 << 5;
    _memcpy(($360|0),($361|0),($363|0))|0;
    HEAP32[$349>>2] = $347;
    HEAP32[$340>>2] = $360;
    $366 = $360;
    break;
   }
  } else {
   $$pre$i = HEAP32[$340>>2]|0;
   $366 = $$pre$i;
  }
 } while(0);
 $364 = HEAP32[$348>>2]|0;
 $365 = $364 << 5;
 _memcpy(($366|0),($344|0),($365|0))|0;
 $$pre = HEAP32[$9>>2]|0;
 $369 = $$pre;
 $367 = $8 & 124;
 $368 = (($369) + 8|0);
 __Z22CopyVertexDataChannelsjjRK14VertexDataInfoRS_($6,$367,$13,$368);
 $370 = (($mesh) + 276|0);
 $371 = HEAP8[$370>>0]|0;
 $372 = (($this) + 276|0);
 HEAP8[$372>>0] = $371;
 $373 = (($this) + 168|0);
 $374 = (($mesh) + 168|0);
 ;HEAP32[$373+0>>2]=HEAP32[$374+0>>2]|0;HEAP32[$373+4>>2]=HEAP32[$374+4>>2]|0;HEAP32[$373+8>>2]=HEAP32[$374+8>>2]|0;HEAP32[$373+12>>2]=HEAP32[$374+12>>2]|0;HEAP32[$373+16>>2]=HEAP32[$374+16>>2]|0;HEAP32[$373+20>>2]=HEAP32[$374+20>>2]|0;
 $375 = (($this) + 192|0);
 __ZN17CollisionMeshData20VertexDataHasChangedEv($375);
 __ZN4Mesh16SetChannelsDirtyEjb($this,$8,1);
 __ZN4Mesh14ClearSkinCacheEv($this);
 STACKTOP = sp;return;
}
function __ZN4Mesh18UpdateVertexFormatEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $changedChannels$0$lcssa = 0, $changedChannels$04$us = 0, $changedChannels$04$us5 = 0;
 var $changedChannels$2$us = 0, $changedChannels$2$us8 = 0, $changedChannels$3$us = 0, $changedChannels$3$us9 = 0, $channelsLayout = 0, $exitcond = 0, $exitcond10 = 0, $exitcond11 = 0, $layout$i = 0, $or$cond3$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $layout$i = sp + 16|0;
 $channelsLayout = sp + 32|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 __ZNK14VertexDataInfo17GetChannelsLayoutEv($channelsLayout,$3);
 $4 = HEAP16[((640792 + 256|0))>>1]|0;
 $5 = $4&255;
 $6 = ($5<<24>>24)==(0);
 $7 = ($4&65535)<(256);
 L1: do {
  if ($6) {
   $16 = 1;$9 = 0;$changedChannels$04$us = 0;
   while(1) {
    $8 = ((($channelsLayout) + ($9<<1)|0) + 1|0);
    $10 = HEAP8[$8>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $changedChannels$3$us = $changedChannels$04$us;
    } else {
     $12 = (($channelsLayout) + ($9<<1)|0);
     $13 = HEAP8[$12>>0]|0;
     $14 = ($13<<24>>24)==(1);
     if ($14) {
      HEAP8[$12>>0] = 0;
      $15 = $changedChannels$04$us | $16;
      $21 = 0;$changedChannels$2$us = $15;
     } else {
      $17 = ($13<<24>>24)==(3);
      $or$cond3$us = $17 & $7;
      if ($or$cond3$us) {
       HEAP8[$12>>0] = 0;
       $18 = $changedChannels$04$us | $16;
       $21 = 0;$changedChannels$2$us = $18;
      } else {
       $21 = $13;$changedChannels$2$us = $changedChannels$04$us;
      }
     }
     $19 = ($9|0)==(1);
     if ($19) {
      $20 = ($21<<24>>24)==(0);
      if ($20) {
       HEAP8[$8>>0] = 3;
      }
      $22 = (($9) + 1)|0;
      $23 = $16 << 1;
      $16 = $23;$9 = $22;$changedChannels$04$us = $changedChannels$2$us;
      continue;
     } else {
      $changedChannels$3$us = $changedChannels$2$us;
     }
    }
    $24 = (($9) + 1)|0;
    $25 = $16 << 1;
    $exitcond10 = ($24|0)==(8);
    if ($exitcond10) {
     $changedChannels$0$lcssa = $changedChannels$3$us;
     break;
    } else {
     $16 = $25;$9 = $24;$changedChannels$04$us = $changedChannels$3$us;
    }
   }
  } else {
   if ($7) {
    $27 = 0;$34 = 1;$changedChannels$04$us5 = 0;
   } else {
    $43 = 0;
    L4: while(1) {
     $42 = ((($channelsLayout) + ($43<<1)|0) + 1|0);
     $44 = HEAP8[$42>>0]|0;
     $45 = ($44<<24>>24)==(0);
     do {
      if (!($45)) {
       $46 = ($43|0)==(1);
       if ($46) {
        $47 = (($channelsLayout) + ($43<<1)|0);
        $48 = HEAP8[$47>>0]|0;
        $49 = ($48<<24>>24)==(0);
        if ($49) {
         HEAP8[$42>>0] = 3;
         break;
        } else {
         $50 = (($43) + 1)|0;
         $43 = $50;
         continue L4;
        }
       }
      }
     } while(0);
     $51 = (($43) + 1)|0;
     $exitcond = ($51|0)==(8);
     if ($exitcond) {
      $changedChannels$0$lcssa = 0;
      break L1;
     } else {
      $43 = $51;
     }
    }
   }
   while(1) {
    $26 = ((($channelsLayout) + ($27<<1)|0) + 1|0);
    $28 = HEAP8[$26>>0]|0;
    $29 = ($28<<24>>24)==(0);
    if ($29) {
     $changedChannels$3$us9 = $changedChannels$04$us5;
    } else {
     $30 = (($channelsLayout) + ($27<<1)|0);
     $31 = HEAP8[$30>>0]|0;
     $32 = ($31<<24>>24)==(3);
     if ($32) {
      HEAP8[$30>>0] = 0;
      $33 = $changedChannels$04$us5 | $34;
      $37 = 0;$changedChannels$2$us8 = $33;
     } else {
      $37 = $31;$changedChannels$2$us8 = $changedChannels$04$us5;
     }
     $35 = ($27|0)==(1);
     if ($35) {
      $36 = ($37<<24>>24)==(0);
      if ($36) {
       HEAP8[$26>>0] = 3;
      }
      $38 = (($27) + 1)|0;
      $39 = $34 << 1;
      $27 = $38;$34 = $39;$changedChannels$04$us5 = $changedChannels$2$us8;
      continue;
     } else {
      $changedChannels$3$us9 = $changedChannels$2$us8;
     }
    }
    $40 = (($27) + 1)|0;
    $41 = $34 << 1;
    $exitcond11 = ($40|0)==(8);
    if ($exitcond11) {
     $changedChannels$0$lcssa = $changedChannels$3$us9;
     break;
    } else {
     $27 = $40;$34 = $41;$changedChannels$04$us5 = $changedChannels$3$us9;
    }
   }
  }
 } while(0);
 $52 = HEAP32[$1>>2]|0;
 $53 = (($52) + 8|0);
 $54 = (($52) + 100|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($52) + 144|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0);
 if ($58) {
  $59 = (($this) + 92|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($this) + 88|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($60|0)==($62|0);
  if ($63) {
   $64 = (($52) + 8|0);
   __ZNK14VertexDataInfo16GetStreamsLayoutEv($layout$i,$64);
   $65 = (($layout$i) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = $66 & 255;
   $68 = $67 ^ 255;
   $69 = (($layout$i) + 8|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = $70 ^ -1;
   $72 = $68 & $71;
   $73 = (($layout$i) + 12|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = $74 ^ -1;
   $76 = $72 & $75;
   HEAP32[$layout$i>>2] = $76;
   ;HEAP32[$0+0>>2]=HEAP32[$layout$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$layout$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$layout$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$layout$i+12>>2]|0;
   __ZN10VertexData6ResizeEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($53,$55,$changedChannels$0$lcssa,0,$0,$channelsLayout);
   __ZN4Mesh27SwizzleVertexColorsIfNeededEb($this,1);
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$0+0>>2]=HEAP32[588160+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[588160+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[588160+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[588160+12>>2]|0;
 __ZN10VertexData6ResizeEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($53,$55,$changedChannels$0$lcssa,0,$0,$channelsLayout);
 __ZN4Mesh27SwizzleVertexColorsIfNeededEb($this,1);
 STACKTOP = sp;return;
}
function __ZN4Mesh17VerifyBoneIndicesEj($this,$maxBoneIndex) {
 $this = $this|0;
 $maxBoneIndex = $maxBoneIndex|0;
 var $$0 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 164|0);
 $1 = HEAP32[$0>>2]|0;
 L1: do {
  if ((($1|0) == -2)) {
   $$0 = 0;
  } else if ((($1|0) == -1)) {
   HEAP32[$0>>2] = -2;
   $3 = (($this) + 28|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 144|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0);
   if ($7) {
    $$lcssa = 0;
   } else {
    $8 = (($4) + 136|0);
    $9 = HEAP32[$8>>2]|0;
    $23 = 0;$i$02 = 0;
    while(1) {
     $10 = ((($9) + ($i$02<<5)|0) + 16|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)<(0);
     if ($12) {
      $$0 = 0;
      break L1;
     }
     $13 = ((($9) + ($i$02<<5)|0) + 20|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)<(0);
     if ($15) {
      $$0 = 0;
      break L1;
     }
     $16 = ((($9) + ($i$02<<5)|0) + 24|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)<(0);
     if ($18) {
      $$0 = 0;
      break L1;
     }
     $19 = ((($9) + ($i$02<<5)|0) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)<(0);
     if ($21) {
      $$0 = 0;
      break L1;
     }
     $22 = ($23|0)<($11|0);
     $24 = $22 ? $11 : $23;
     $25 = ($24|0)<($14|0);
     $26 = $25 ? $14 : $24;
     $27 = ($26|0)<($17|0);
     $28 = $27 ? $17 : $26;
     $29 = ($28|0)<($20|0);
     $30 = $29 ? $20 : $28;
     $31 = (($i$02) + 1)|0;
     $32 = ($31>>>0)<($6>>>0);
     if ($32) {
      $23 = $30;$i$02 = $31;
     } else {
      $$lcssa = $30;
      break;
     }
    }
   }
   HEAP32[$0>>2] = $$lcssa;
   $33 = ($$lcssa|0)<($maxBoneIndex|0);
   $$0 = $33;
  } else {
   $2 = ($1|0)<($maxBoneIndex|0);
   $$0 = $2;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN4Mesh16GetSkinInfluenceEi($this,$bonesPerVertex) {
 $this = $this|0;
 $bonesPerVertex = $bonesPerVertex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 120|0);
 $3 = (__ZN16MeshSkinningData16GetSkinInfluenceEi($2,$bonesPerVertex)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN16MeshSkinningData16GetSkinInfluenceEi($this,$bonesPerVertex) {
 $this = $this|0;
 $bonesPerVertex = $bonesPerVertex|0;
 var $$0 = 0, $$byval_copy3 = 0, $$pre = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $exitcond5 = 0, $i$01 = 0, $i2$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 if ((($bonesPerVertex|0) == 4)) {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 } else if ((($bonesPerVertex|0) == 1)) {
  $6 = (($this) + 48|0);
  $7 = (($this) + 56|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = HEAP32[$6>>2]|0;
   $$0 = $10;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$7>>2] = $2;
  $11 = (($this) + 60|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 & 2147483647;
  $14 = ($13>>>0)<($2>>>0);
  do {
   if ($14) {
    $15 = ($12|0)>(-1);
    if ($15) {
     HEAP32[$11>>2] = $2;
     $16 = HEAP32[$6>>2]|0;
     $17 = $2 << 2;
     $18 = (($this) + 52|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$0>>2] = $19;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($16,$17,4,$$byval_copy3,0,585592,370)|0);
     HEAP32[$6>>2] = $20;
     $32 = $20;
     break;
    } else {
     $21 = $2 << 2;
     $22 = (($this) + 52|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,4,$$byval_copy3,0,585592,352)|0);
     $25 = HEAP32[$6>>2]|0;
     $26 = HEAP32[$7>>2]|0;
     $27 = $26 << 2;
     _memcpy(($24|0),($25|0),($27|0))|0;
     HEAP32[$11>>2] = $2;
     HEAP32[$6>>2] = $24;
     $32 = $24;
     break;
    }
   } else {
    $$pre = HEAP32[$6>>2]|0;
    $32 = $$pre;
   }
  } while(0);
  $28 = ($2|0)>(0);
  if ($28) {
   $i$01 = 0;
   while(1) {
    $29 = ((($5) + ($i$01<<5)|0) + 16|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($32) + ($i$01<<2)|0);
    HEAP32[$31>>2] = $30;
    $33 = (($i$01) + 1)|0;
    $exitcond = ($33|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $i$01 = $33;
    }
   }
  }
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 } else if ((($bonesPerVertex|0) == 2)) {
  $34 = (($this) + 32|0);
  $35 = (($this) + 40|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0);
  if (!($37)) {
   $38 = HEAP32[$34>>2]|0;
   $$0 = $38;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$35>>2] = $2;
  $39 = (($this) + 44|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & 2147483647;
  $42 = ($41>>>0)<($2>>>0);
  do {
   if ($42) {
    $43 = ($40|0)>(-1);
    if ($43) {
     HEAP32[$39>>2] = $2;
     $44 = HEAP32[$34>>2]|0;
     $45 = $2 << 4;
     $46 = (($this) + 36|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$0>>2] = $47;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $48 = (__Z16realloc_internalPvji10MemLabelIdiPKci($44,$45,16,$$byval_copy3,0,585592,370)|0);
     HEAP32[$34>>2] = $48;
     $60 = $48;
     break;
    } else {
     $49 = $2 << 4;
     $50 = (($this) + 36|0);
     $51 = HEAP32[$50>>2]|0;
     HEAP32[$0>>2] = $51;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $52 = (__Z15malloc_internaljj10MemLabelIdiPKci($49,16,$$byval_copy3,0,585592,352)|0);
     $53 = HEAP32[$34>>2]|0;
     $54 = HEAP32[$35>>2]|0;
     $55 = $54 << 4;
     _memcpy(($52|0),($53|0),($55|0))|0;
     HEAP32[$39>>2] = $2;
     HEAP32[$34>>2] = $52;
     $60 = $52;
     break;
    }
   } else {
    $$pre7 = HEAP32[$34>>2]|0;
    $60 = $$pre7;
   }
  } while(0);
  $56 = ($2|0)>(0);
  if ($56) {
   $i2$02 = 0;
   while(1) {
    $57 = ((($5) + ($i2$02<<5)|0) + 16|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ((($60) + ($i2$02<<4)|0) + 8|0);
    HEAP32[$59>>2] = $58;
    $61 = ((($5) + ($i2$02<<5)|0) + 20|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ((($60) + ($i2$02<<4)|0) + 12|0);
    HEAP32[$63>>2] = $62;
    $64 = (($5) + ($i2$02<<5)|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    $66 = ((($5) + ($i2$02<<5)|0) + 4|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = Math_fround($65 + $67);
    $69 = Math_fround(Math_fround(1.0) / $68);
    $70 = Math_fround($65 * $69);
    $71 = (($60) + ($i2$02<<4)|0);
    HEAPF32[$71>>2] = $70;
    $72 = Math_fround(HEAPF32[$66>>2]);
    $73 = Math_fround($69 * $72);
    $74 = ((($60) + ($i2$02<<4)|0) + 4|0);
    HEAPF32[$74>>2] = $73;
    $75 = (($i2$02) + 1)|0;
    $exitcond5 = ($75|0)==($2|0);
    if ($exitcond5) {
     break;
    } else {
     $i2$02 = $75;
    }
   }
  }
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN4Mesh24QueryGpuSkinSourceBufferEi($this,$bonesPerVertex) {
 $this = $this|0;
 $bonesPerVertex = $bonesPerVertex|0;
 var $$0$i = 0, $$1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mesh = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $mesh = sp;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 120|0);
 $3 = (__ZN16MeshSkinningData16GetSkinInfluenceEi($2,$bonesPerVertex)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 96|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN4Mesh14GetMeshBuffersEjPS_($mesh,$this,$7,0);
 $8 = HEAP32[$mesh>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $10 = ($bonesPerVertex|0)==(4);
 if ($10) {
  $11 = (($this) + 152|0);
  $17 = $11;
 } else {
  $12 = ($bonesPerVertex|0)==(2);
  $13 = (($this) + 156|0);
  $14 = (($this) + 160|0);
  $15 = $12 ? $13 : $14;
  $17 = $15;
 }
 $16 = HEAP32[$17>>2]|0;
 $18 = ($16|0)==(0|0);
 if (!($18)) {
  $$1 = $16;
  STACKTOP = sp;return ($$1|0);
 }
 $19 = (__Z12GetGfxDevicev()|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 276|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
 HEAP32[$17>>2] = $23;
 if ((($bonesPerVertex|0) == 4)) {
  $$0$i = 32;
 } else if ((($bonesPerVertex|0) == 1)) {
  $$0$i = 4;
 } else if ((($bonesPerVertex|0) == 2)) {
  $$0$i = 16;
 } else {
  $$0$i = 1;
 }
 $24 = (__Z12GetGfxDevicev()|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 280|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$17>>2]|0;
 $29 = HEAP32[$0>>2]|0;
 $30 = (($29) + 100|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = Math_imul($31, $$0$i)|0;
 FUNCTION_TABLE_viiiiiii[$27 & 127]($24,$28,0,0,$32,$3,0);
 $$pre = HEAP32[$17>>2]|0;
 $$1 = $$pre;
 STACKTOP = sp;return ($$1|0);
}
function __ZNK4Mesh20GetRuntimeMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6Object20GetRuntimeMemorySizeEv($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN4Mesh15GetSharedPxMeshEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 192|0);
 $1 = (__ZN17CollisionMeshData15GetSharedNxMeshER4Mesh($0,$this)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN4Mesh21GetSharedPxConvexMeshEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 192|0);
 $1 = (__ZN17CollisionMeshData21GetSharedNxConvexMeshER4Mesh($0,$this)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN4Mesh13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 33|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  HEAP8[$0>>0] = 0;
 }
 __ZN4Mesh14ClearSkinCacheEv($this);
 __ZN4Mesh18UpdateVertexFormatEv($this);
 __ZN4Mesh10CreateMeshEv($this);
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (__ZN17UniqueIDGenerator10AllocateIDEv(585464)|0);
 HEAP32[$3>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN4Mesh21AwakeFromLoadThreadedEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 192|0);
 __ZN17CollisionMeshData21AwakeFromLoadThreadedER4Mesh($0,$this);
 STACKTOP = sp;return;
}
function __ZN4Mesh11MarkDynamicEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 274|0);
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN4Mesh39ShouldIgnoreInGarbageDependencyTrackingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN4MeshD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4MeshD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN4MeshD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3457,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE8__appendEjRKS1_($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    dest=$11+0|0; src=$__x+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 56|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = (($18|0) / 56)&-1;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = (($22|0) / 56)&-1;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $23 << 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 10;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $29 = ($$0$i56*56)|0;
  HEAP32[$0>>2] = 10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,585592,79)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + (($19*56)|0)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $36 = 0;
  } else {
   dest=$34+0|0; src=$__x+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $36 = $34;
  }
  $35 = (($36) + 56|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $35;
  }
 }
 $39 = (($32) + (($$0$i57*56)|0)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = (($44|0) / -56)&-1;
 $$sum = (($45) + ($19))|0;
 $46 = (($32) + (($$sum*56)|0)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $35;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $10 = (($$byval_copy1) + 12|0);
  $$0$i = $__n;$12 = $4;
  while(1) {
   $11 = ($12|0)==(0|0);
   if ($11) {
    $15 = 0;
   } else {
    $13 = (($12) + 32|0);
    dest=$12+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[616680+8>>2]|0;
    ;HEAP32[$10+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[616680+8>>2]|0;
    ;HEAP32[$13+0>>2]=HEAP32[$$byval_copy1+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$$byval_copy1+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$$byval_copy1+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$$byval_copy1+12>>2]|0;HEAP32[$13+16>>2]=HEAP32[$$byval_copy1+16>>2]|0;HEAP32[$13+20>>2]=HEAP32[$$byval_copy1+20>>2]|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $15 = $$pre1$i;
   }
   $14 = (($15) + 56|0);
   HEAP32[$3>>2] = $14;
   $16 = (($$0$i) + -1)|0;
   $17 = ($16|0)==(0);
   if ($17) {
    break;
   } else {
    $$0$i = $16;$12 = $14;
   }
  }
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = $18;
 $20 = (($6) - ($19))|0;
 $21 = (($20|0) / 56)&-1;
 $22 = (($21) + ($__n))|0;
 $23 = ($22|0)<(0);
 if ($23) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $24 = (($5) - ($19))|0;
 $25 = (($24|0) / 56)&-1;
 $26 = ($25>>>0)<(1073741823);
 if ($26) {
  $27 = $25 << 1;
  $28 = ($27>>>0)<($22>>>0);
  $29 = $28 ? $22 : $27;
  $30 = ($29|0)==(0);
  if ($30) {
   $$0$i57 = 0;$34 = 0;
  } else {
   $$0$i56 = $29;
   label = 10;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $31 = ($$0$i56*56)|0;
  HEAP32[$0>>2] = 10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $32 = (__Z15malloc_internaljj10MemLabelIdiPKci($31,16,$$byval_copy1,0,585592,79)|0);
  $$0$i57 = $$0$i56;$34 = $32;
 }
 $33 = (($34) + (($21*56)|0)|0);
 $35 = (($$byval_copy1) + 12|0);
 $$0$i2 = $__n;$37 = $33;
 while(1) {
  $36 = ($37|0)==(0|0);
  if ($36) {
   $40 = 0;
  } else {
   $38 = (($37) + 32|0);
   dest=$37+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[616680+8>>2]|0;
   ;HEAP32[$35+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[616680+8>>2]|0;
   ;HEAP32[$38+0>>2]=HEAP32[$$byval_copy1+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$$byval_copy1+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$$byval_copy1+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$$byval_copy1+12>>2]|0;HEAP32[$38+16>>2]=HEAP32[$$byval_copy1+16>>2]|0;HEAP32[$38+20>>2]=HEAP32[$$byval_copy1+20>>2]|0;
   $40 = $37;
  }
  $39 = (($40) + 56|0);
  $41 = (($$0$i2) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $$0$i2 = $41;$37 = $39;
  }
 }
 $43 = (($34) + (($$0$i57*56)|0)|0);
 $44 = HEAP32[$this>>2]|0;
 $45 = HEAP32[$3>>2]|0;
 $46 = $45;
 $47 = $44;
 $48 = (($46) - ($47))|0;
 $49 = (($48|0) / -56)&-1;
 $$sum = (($49) + ($21))|0;
 $50 = (($34) + (($$sum*56)|0)|0);
 _memcpy(($50|0),($44|0),($48|0))|0;
 $51 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $50;
 HEAP32[$3>>2] = $39;
 HEAP32[$1>>2] = $43;
 $52 = ($51|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($51|0),($$byval_copy1|0));
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 if ($54) {
  $55 = ___cxa_find_matching_catch()|0;
  $56 = tempRet0;
  ___cxa_call_unexpected(($55|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP32[$11>>2] = 0;
   }
   $12 = (($11) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<2)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy1,0,585592,79)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAP32[$33>>2] = 0;
  }
  $34 = (($33) + 4|0);
  $35 = (($$0$i2) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i2 = $35;$33 = $34;
  }
 }
 $37 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 $38 = HEAP32[$this>>2]|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = $39;
 $41 = $38;
 $42 = (($40) - ($41))|0;
 $43 = $42 >> 2;
 $$sum6 = (($18) - ($43))|0;
 $44 = (($31) + ($$sum6<<2)|0);
 _memcpy(($44|0),($38|0),($42|0))|0;
 $45 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $44;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $37;
 $46 = ($45|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($45|0),($$byval_copy1|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN4Mesh8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$6 = 0, $$67 = 0, $$7 = 0, $$78 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $m_CompressedMesh = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $$byval_copy4 = sp + 348|0;
 $0 = sp;
 $1 = sp + 4|0;
 $m_CompressedMesh = sp + 104|0;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $2 = (($this) + 276|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 __ZN4Mesh21UnswizzleVertexColorsEb($this,1);
 $5 = (($this) + 32|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 L1: do {
  if ($7) {
   label = 3;
  } else {
   $8 = HEAP32[$transfer>>2]|0;
   $9 = $8 & 16384;
   $10 = ($9|0)==(0);
   if ($10) {
    __THREW__ = 0;
    invoke_vi(3452,($1|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    do {
     if ($15) {
      label = 9;
     } else {
      __THREW__ = 0;
      invoke_vii(2669,($transfer|0),1);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       invoke_vii(2670,($1|0),($transfer|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vi(3458,($transfer|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         invoke_vi(3456,($1|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if ($23) {
          label = 9;
          break;
         }
         HEAP32[$0>>2] = 61;
         ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
         __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy4);
         __ZN14CompressedMeshC2Ev($m_CompressedMesh);
         $144 = $m_CompressedMesh;
         break L1;
        }
       }
      }
      $26 = ___cxa_find_matching_catch()|0;
      $27 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3456,($1|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       $142 = ___cxa_find_matching_catch(0|0)|0;
       $143 = tempRet0;
       ___clang_call_terminate($142);
       // unreachable;
      } else {
       $$6 = $27;$$67 = $26;
      }
     }
    } while(0);
    if ((label|0) == 9) {
     $24 = ___cxa_find_matching_catch()|0;
     $25 = tempRet0;
     $$6 = $25;$$67 = $24;
    }
    HEAP32[$0>>2] = 61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,(0|0),($$byval_copy4|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     $142 = ___cxa_find_matching_catch(0|0)|0;
     $143 = tempRet0;
     ___clang_call_terminate($142);
     // unreachable;
    } else {
     $$7 = $$6;$$78 = $$67;
     ___resumeException($$78|0);
     // unreachable;
    }
   } else {
    label = 3;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $11 = (($this) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 8|0);
  __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
  __ZN10VertexData8TransferI17RemapPPtrTransferEEvRT_($13,$transfer);
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  __ZN14CompressedMeshC2Ev($m_CompressedMesh);
  $144 = $m_CompressedMesh;
 }
 __THREW__ = 0;
 invoke_vii(2669,($transfer|0),1);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if (!($37)) {
  __THREW__ = 0;
  invoke_vi(3458,($transfer|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if (!($39)) {
   __ZN14CompressedMeshD2Ev($m_CompressedMesh);
   if (!($4)) {
    $40 = (($this) + 28|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 18|0);
    $43 = HEAP8[$42>>0]|0;
    $44 = ($43<<24>>24)==(2);
    if ($44) {
     $45 = (($41) + 19|0);
     $46 = HEAP8[$45>>0]|0;
     $47 = ($46&255)<(4);
     if ($47) {
      $145 = 0;$146 = 0;
      label = 22;
     } else {
      $48 = (($41) + 92|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       $147 = 1;$148 = 0;
      } else {
       $51 = (($41) + 16|0);
       $52 = HEAP8[$51>>0]|0;
       $53 = $52&255;
       $54 = ((($41) + (($53*12)|0)|0) + 50|0);
       $55 = HEAP8[$54>>0]|0;
       $56 = $55&255;
       $57 = ((($41) + (($53*12)|0)|0) + 44|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($41) + 17|0);
       $60 = HEAP8[$59>>0]|0;
       $61 = $60&255;
       $62 = (($61) + ($58))|0;
       $63 = (($49) + ($62)|0);
       $147 = $56;$148 = $63;
      }
      if ($44) {
       $145 = $148;$146 = $147;
       label = 22;
      } else {
       $107 = $148;$108 = 0;$129 = $147;$131 = 0;$149 = 0;
      }
     }
     if ((label|0) == 22) {
      $64 = (($41) + 19|0);
      $65 = HEAP8[$64>>0]|0;
      $66 = ($65&255)<(4);
      if ($66) {
       $150 = 0;
      } else {
       $67 = (($41) + 92|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = ($68|0)==(0|0);
       if ($69) {
        $150 = 0;
       } else {
        $70 = (($41) + 100|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = (($41) + 16|0);
        $73 = HEAP8[$72>>0]|0;
        $74 = $73&255;
        $75 = ((($41) + (($74*12)|0)|0) + 50|0);
        $76 = HEAP8[$75>>0]|0;
        $77 = $76&255;
        $78 = ((($41) + (($74*12)|0)|0) + 44|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = (($41) + 17|0);
        $81 = HEAP8[$80>>0]|0;
        $82 = $81&255;
        $83 = Math_imul($77, $71)|0;
        $84 = (($83) + ($79))|0;
        $85 = (($84) + ($82))|0;
        $86 = (($68) + ($85)|0);
        $150 = $86;
       }
      }
      if ($44) {
       $87 = (($41) + 19|0);
       $88 = HEAP8[$87>>0]|0;
       $89 = ($88&255)<(4);
       if ($89) {
        $107 = $145;$108 = $150;$129 = $146;$131 = 0;$149 = 0;
       } else {
        $90 = (($41) + 92|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = ($91|0)==(0|0);
        if ($92) {
         $107 = $145;$108 = $150;$129 = $146;$131 = 1;$149 = 0;
        } else {
         $93 = (($41) + 16|0);
         $94 = HEAP8[$93>>0]|0;
         $95 = $94&255;
         $96 = ((($41) + (($95*12)|0)|0) + 50|0);
         $97 = HEAP8[$96>>0]|0;
         $98 = $97&255;
         $99 = ((($41) + (($95*12)|0)|0) + 44|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = (($41) + 17|0);
         $102 = HEAP8[$101>>0]|0;
         $103 = $102&255;
         $104 = (($103) + ($100))|0;
         $105 = (($91) + ($104)|0);
         $107 = $145;$108 = $150;$129 = $146;$131 = $98;$149 = $105;
        }
       }
      } else {
       $107 = $145;$108 = $150;$129 = $146;$131 = 0;$149 = 0;
      }
     }
     $106 = ($107|0)==($108|0);
     if (!($106)) {
      $110 = $107;$127 = $149;
      while(1) {
       $109 = (($110) + 2|0);
       $111 = HEAP8[$109>>0]|0;
       $112 = (($110) + 1|0);
       $113 = HEAP8[$112>>0]|0;
       $114 = HEAP8[$110>>0]|0;
       $115 = (($110) + 3|0);
       $116 = HEAP8[$115>>0]|0;
       $117 = $116&255;
       $118 = $117 << 24;
       $119 = $114&255;
       $120 = $119 << 16;
       $121 = $113&255;
       $122 = $121 << 8;
       $123 = $111&255;
       $124 = $122 | $123;
       $125 = $124 | $120;
       $126 = $125 | $118;
       HEAP32[$127>>2] = $126;
       $128 = (($110) + ($129)|0);
       $130 = (($127) + ($131)|0);
       $132 = ($128|0)==($108|0);
       if ($132) {
        break;
       } else {
        $110 = $128;$127 = $130;
       }
      }
     }
    }
    HEAP8[$2>>0] = 1;
   }
   $133 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $133;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,(0|0),($$byval_copy4|0));
   $134 = __THREW__; __THREW__ = 0;
   $135 = $134&1;
   if (!($135)) {
    HEAP32[$0>>2] = $133;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy4);
    STACKTOP = sp;return;
   }
   $136 = ___cxa_find_matching_catch()|0;
   $137 = tempRet0;
   HEAP32[$1>>2] = $133;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,(0|0),($$byval_copy4|0));
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   if ($139) {
    $140 = ___cxa_find_matching_catch(0|0)|0;
    $141 = tempRet0;
    ___clang_call_terminate($140);
    // unreachable;
   } else {
    ___resumeException($136|0);
    // unreachable;
   }
  }
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3459,($m_CompressedMesh|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $142 = ___cxa_find_matching_catch(0|0)|0;
  $143 = tempRet0;
  ___clang_call_terminate($142);
  // unreachable;
 } else {
  $$7 = $33;$$78 = $32;
  ___resumeException($$78|0);
  // unreachable;
 }
}
function __ZN14CompressedMeshD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 228|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 232|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if (!($5)) {
   HEAP32[$3>>2] = $1;
  }
  __ZdlPv($1);
 }
 $6 = (($this) + 208|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 212|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   HEAP32[$9>>2] = $7;
  }
  __ZdlPv($7);
 }
 $12 = (($this) + 188|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($this) + 192|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($13|0);
  if (!($17)) {
   HEAP32[$15>>2] = $13;
  }
  __ZdlPv($13);
 }
 $18 = (($this) + 168|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = (($this) + 172|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==($19|0);
  if (!($23)) {
   HEAP32[$21>>2] = $19;
  }
  __ZdlPv($19);
 }
 $24 = (($this) + 140|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (($this) + 144|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($25|0);
  if (!($29)) {
   HEAP32[$27>>2] = $25;
  }
  __ZdlPv($25);
 }
 $30 = (($this) + 120|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = (($this) + 124|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==($31|0);
  if (!($35)) {
   HEAP32[$33>>2] = $31;
  }
  __ZdlPv($31);
 }
 $36 = (($this) + 92|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  $39 = (($this) + 96|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==($37|0);
  if (!($41)) {
   HEAP32[$39>>2] = $37;
  }
  __ZdlPv($37);
 }
 $42 = (($this) + 72|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = (($this) + 76|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==($43|0);
  if (!($47)) {
   HEAP32[$45>>2] = $43;
  }
  __ZdlPv($43);
 }
 $48 = (($this) + 44|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = (($this) + 48|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==($49|0);
  if (!($53)) {
   HEAP32[$51>>2] = $49;
  }
  __ZdlPv($49);
 }
 $54 = (($this) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  STACKTOP = sp;return;
 }
 $57 = (($this) + 20|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==($55|0);
 if (!($59)) {
  HEAP32[$57>>2] = $55;
 }
 __ZdlPv($55);
 STACKTOP = sp;return;
}
function __ZN4Mesh8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i = 0, $$01$i = 0, $$6 = 0, $$67 = 0, $$7 = 0, $$78 = 0, $$byval_copy5 = 0, $$pre = 0, $$pre56 = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i$i$i = 0, $i$01$i$i$i14 = 0, $i$01$i$i$i23 = 0;
 var $size$i$i$i$i = 0, $size$i$i$i25 = 0, $size$i$i$i32 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy5 = sp + 116|0;
 $0 = sp;
 $size$i$i$i32 = sp + 4|0;
 $size$i$i$i25 = sp + 8|0;
 $size$i$i$i$i = sp + 12|0;
 $1 = sp + 112|0;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $2 = (($this) + 276|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 __ZN4Mesh21UnswizzleVertexColorsEb($this,1);
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = (($11|0) / 56)&-1;
 HEAP32[$$byval_copy5>>2] = $12;
 $13 = (($transfer) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 4|0);
 $16 = (($transfer) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15>>>0)<($17>>>0);
 if ($18) {
  HEAP32[$14>>2] = $12;
  HEAP32[$13>>2] = $15;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$$byval_copy5,4);
 }
 $19 = HEAP32[$5>>2]|0;
 $20 = HEAP32[$7>>2]|0;
 $21 = ($20|0)==($19|0);
 if (!($21)) {
  $22 = $20;
  while(1) {
   __ZN7SubMesh8TransferI19StreamedBinaryWriteILb0EEEEvRT_($22,$transfer);
   $23 = (($22) + 56|0);
   $24 = ($23|0)==($19|0);
   if ($24) {
    break;
   } else {
    $22 = $23;
   }
  }
 }
 $25 = (($this) + 56|0);
 __ZN14BlendShapeData8TransferI19StreamedBinaryWriteILb0EEEEvRT_($25,$transfer);
 $26 = (($this) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 128|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$$byval_copy5>>2] = $29;
 $30 = HEAP32[$13>>2]|0;
 $31 = (($30) + 4|0);
 $32 = HEAP32[$16>>2]|0;
 $33 = ($31>>>0)<($32>>>0);
 if ($33) {
  HEAP32[$30>>2] = $29;
  HEAP32[$13>>2] = $31;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$$byval_copy5,4);
 }
 $34 = (($27) + 120|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$28>>2]|0;
 $37 = (($35) + ($36<<6)|0);
 $38 = ($36|0)==(0);
 if (!($38)) {
  $i$01$i$i$i = $35;
  while(1) {
   __ZN10Matrix4x4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $39 = (($i$01$i$i$i) + 64|0);
   $40 = ($39|0)==($37|0);
   if ($40) {
    break;
   } else {
    $i$01$i$i$i = $39;
   }
  }
 }
 $41 = (($this) + 124|0);
 $42 = HEAP32[$41>>2]|0;
 HEAP32[$$byval_copy5>>2] = $42;
 $43 = HEAP32[$13>>2]|0;
 $44 = (($43) + 4|0);
 $45 = HEAP32[$16>>2]|0;
 $46 = ($44>>>0)<($45>>>0);
 if ($46) {
  HEAP32[$43>>2] = $42;
  HEAP32[$13>>2] = $44;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$$byval_copy5,4);
 }
 $47 = (($this) + 116|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$41>>2]|0;
 $50 = (($48) + ($49<<2)|0);
 $51 = ($49|0)==(0);
 if (!($51)) {
  $i$01$i$i$i14 = $48;
  while(1) {
   $52 = HEAP32[$13>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$16>>2]|0;
   $55 = ($53>>>0)<($54>>>0);
   if ($55) {
    $56 = HEAP32[$i$01$i$i$i14>>2]|0;
    HEAP32[$52>>2] = $56;
    HEAP32[$13>>2] = $53;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$i$01$i$i$i14,4);
   }
   $57 = (($i$01$i$i$i14) + 4|0);
   $58 = ($57|0)==($50|0);
   if ($58) {
    break;
   } else {
    $i$01$i$i$i14 = $57;
   }
  }
 }
 $59 = (($this) + 132|0);
 $60 = HEAP32[$13>>2]|0;
 $61 = (($60) + 4|0);
 $62 = HEAP32[$16>>2]|0;
 $63 = ($61>>>0)<($62>>>0);
 if ($63) {
  $64 = HEAP32[$59>>2]|0;
  HEAP32[$60>>2] = $64;
  HEAP32[$13>>2] = $61;
  $67 = $61;$69 = $62;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$59,4);
  $$pre = HEAP32[$13>>2]|0;
  $$pre56 = HEAP32[$16>>2]|0;
  $67 = $$pre;$69 = $$pre56;
 }
 $65 = (($this) + 32|0);
 $66 = (($67) + 1|0);
 $68 = ($66>>>0)<($69>>>0);
 if ($68) {
  $70 = HEAP8[$65>>0]|0;
  HEAP8[$67>>0] = $70;
  $71 = HEAP32[$13>>2]|0;
  $72 = (($71) + 1|0);
  HEAP32[$13>>2] = $72;
  $75 = $72;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$65,1);
  $$pre57 = HEAP32[$13>>2]|0;
  $75 = $$pre57;
 }
 $73 = (($this) + 33|0);
 $74 = (($75) + 1|0);
 $76 = HEAP32[$16>>2]|0;
 $77 = ($74>>>0)<($76>>>0);
 if ($77) {
  $78 = HEAP8[$73>>0]|0;
  HEAP8[$75>>0] = $78;
  $79 = HEAP32[$13>>2]|0;
  $80 = (($79) + 1|0);
  HEAP32[$13>>2] = $80;
  $83 = $80;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$73,1);
  $$pre58 = HEAP32[$13>>2]|0;
  $83 = $$pre58;
 }
 $81 = (($this) + 34|0);
 $82 = (($83) + 1|0);
 $84 = HEAP32[$16>>2]|0;
 $85 = ($82>>>0)<($84>>>0);
 if ($85) {
  $86 = HEAP8[$81>>0]|0;
  HEAP8[$83>>0] = $86;
  $87 = HEAP32[$13>>2]|0;
  $88 = (($87) + 1|0);
  HEAP32[$13>>2] = $88;
  $91 = $88;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$81,1);
  $$pre59 = HEAP32[$13>>2]|0;
  $91 = $$pre59;
 }
 $89 = (($this) + 35|0);
 $90 = (($91) + 1|0);
 $92 = HEAP32[$16>>2]|0;
 $93 = ($90>>>0)<($92>>>0);
 if ($93) {
  $94 = HEAP8[$89>>0]|0;
  HEAP8[$91>>0] = $94;
  $95 = HEAP32[$13>>2]|0;
  $96 = (($95) + 1|0);
  HEAP32[$13>>2] = $96;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$89,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $97 = HEAP8[$65>>0]|0;
 $98 = ($97<<24>>24)==(0);
 L49: do {
  if ($98) {
   label = 36;
  } else {
   $99 = HEAP32[$transfer>>2]|0;
   $100 = $99 & 16384;
   $101 = ($100|0)==(0);
   if ($101) {
    __THREW__ = 0;
    invoke_vi(3452,($size$i$i$i$i|0));
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    L52: do {
     if ($144) {
      label = 61;
     } else {
      HEAP32[$size$i$i$i25>>2] = 0;
      $145 = HEAP32[$13>>2]|0;
      $146 = (($145) + 4|0);
      $147 = HEAP32[$16>>2]|0;
      $148 = ($146>>>0)<($147>>>0);
      if ($148) {
       HEAP32[$145>>2] = 0;
       HEAP32[$13>>2] = $146;
       label = 54;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($13|0),($size$i$i$i25|0),4);
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if (!($150)) {
        label = 54;
       }
      }
      do {
       if ((label|0) == 54) {
        __THREW__ = 0;
        invoke_vi(3378,($transfer|0));
        $151 = __THREW__; __THREW__ = 0;
        $152 = $151&1;
        if (!($152)) {
         HEAP32[$size$i$i$i32>>2] = 0;
         $153 = HEAP32[$13>>2]|0;
         $154 = (($153) + 4|0);
         $155 = HEAP32[$16>>2]|0;
         $156 = ($154>>>0)<($155>>>0);
         if ($156) {
          HEAP32[$153>>2] = 0;
          HEAP32[$13>>2] = $154;
         } else {
          __THREW__ = 0;
          invoke_viii(1640,($13|0),($size$i$i$i32|0),4);
          $157 = __THREW__; __THREW__ = 0;
          $158 = $157&1;
          if ($158) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(2671,($size$i$i$i$i|0),($transfer|0));
         $159 = __THREW__; __THREW__ = 0;
         $160 = $159&1;
         if ($160) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3456,($size$i$i$i$i|0));
         $161 = __THREW__; __THREW__ = 0;
         $162 = $161&1;
         if ($162) {
          label = 61;
          break L52;
         }
         HEAP32[$0>>2] = 61;
         ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
         __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
         $316 = 1;
         break L49;
        }
       }
      } while(0);
      $165 = ___cxa_find_matching_catch()|0;
      $166 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3456,($size$i$i$i$i|0));
      $167 = __THREW__; __THREW__ = 0;
      $168 = $167&1;
      if ($168) {
       $314 = ___cxa_find_matching_catch(0|0)|0;
       $315 = tempRet0;
       ___clang_call_terminate($314);
       // unreachable;
      } else {
       $$6 = $166;$$67 = $165;
      }
     }
    } while(0);
    if ((label|0) == 61) {
     $163 = ___cxa_find_matching_catch()|0;
     $164 = tempRet0;
     $$6 = $164;$$67 = $163;
    }
    HEAP32[$0>>2] = 61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,(0|0),($$byval_copy5|0));
    $169 = __THREW__; __THREW__ = 0;
    $170 = $169&1;
    if ($170) {
     $314 = ___cxa_find_matching_catch(0|0)|0;
     $315 = tempRet0;
     ___clang_call_terminate($314);
     // unreachable;
    } else {
     $$7 = $$6;$$78 = $$67;
     ___resumeException($$78|0);
     // unreachable;
    }
   } else {
    label = 36;
   }
  }
 } while(0);
 if ((label|0) == 36) {
  $102 = HEAP32[$26>>2]|0;
  $103 = (($102) + 112|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($102) + 108|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = $104;
  $108 = $106;
  $109 = (($107) - ($108))|0;
  HEAP32[$$byval_copy5>>2] = $109;
  $110 = HEAP32[$13>>2]|0;
  $111 = (($110) + 4|0);
  $112 = HEAP32[$16>>2]|0;
  $113 = ($111>>>0)<($112>>>0);
  if ($113) {
   HEAP32[$110>>2] = $109;
   HEAP32[$13>>2] = $111;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$$byval_copy5,4);
  }
  $114 = HEAP32[$103>>2]|0;
  $115 = HEAP32[$105>>2]|0;
  $116 = ($115|0)==($114|0);
  if (!($116)) {
   $122 = $115;
   while(1) {
    $117 = HEAP32[$13>>2]|0;
    $118 = (($117) + 1|0);
    $119 = HEAP32[$16>>2]|0;
    $120 = ($118>>>0)<($119>>>0);
    if ($120) {
     $121 = HEAP8[$122>>0]|0;
     HEAP8[$117>>0] = $121;
     $123 = HEAP32[$13>>2]|0;
     $124 = (($123) + 1|0);
     HEAP32[$13>>2] = $124;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$122,1);
    }
    $125 = (($122) + 1|0);
    $126 = ($125|0)==($114|0);
    if ($126) {
     break;
    } else {
     $122 = $125;
    }
   }
  }
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  $127 = HEAP32[$26>>2]|0;
  $128 = (($127) + 144|0);
  $129 = HEAP32[$128>>2]|0;
  HEAP32[$$byval_copy5>>2] = $129;
  $130 = HEAP32[$13>>2]|0;
  $131 = (($130) + 4|0);
  $132 = HEAP32[$16>>2]|0;
  $133 = ($131>>>0)<($132>>>0);
  if ($133) {
   HEAP32[$130>>2] = $129;
   HEAP32[$13>>2] = $131;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$$byval_copy5,4);
  }
  $134 = (($127) + 136|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = HEAP32[$128>>2]|0;
  $137 = (($135) + ($136<<5)|0);
  $138 = ($136|0)==(0);
  if (!($138)) {
   $i$01$i$i$i23 = $135;
   while(1) {
    __ZN13BoneInfluence8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i23,$transfer);
    $139 = (($i$01$i$i$i23) + 32|0);
    $140 = ($139|0)==($137|0);
    if ($140) {
     break;
    } else {
     $i$01$i$i$i23 = $139;
    }
   }
  }
  $141 = HEAP32[$26>>2]|0;
  $142 = (($141) + 8|0);
  __ZN10VertexData8TransferI19StreamedBinaryWriteILb0EEEEvRT_($142,$transfer);
  $316 = 0;
 }
 __ZN14CompressedMeshC2Ev($$byval_copy5);
 __THREW__ = 0;
 invoke_vi(3378,($transfer|0));
 $171 = __THREW__; __THREW__ = 0;
 $172 = $171&1;
 do {
  if (!($172)) {
   if ($316) {
    $173 = HEAP8[$65>>0]|0;
    $174 = $173&255;
    __THREW__ = 0;
    $175 = (invoke_ii(3235,($174|0))|0);
    $176 = __THREW__; __THREW__ = 0;
    $177 = $176&1;
    if ($177) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(1699,($$byval_copy5|0),($this|0),($175|0));
    $178 = __THREW__; __THREW__ = 0;
    $179 = $178&1;
    if ($179) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_vii(2672,($$byval_copy5|0),($transfer|0));
   $184 = __THREW__; __THREW__ = 0;
   $185 = $184&1;
   if (!($185)) {
    __ZN14CompressedMeshD2Ev($$byval_copy5);
    if (!($4)) {
     $186 = HEAP32[$26>>2]|0;
     $187 = (($186) + 18|0);
     $188 = HEAP8[$187>>0]|0;
     $189 = ($188<<24>>24)==(2);
     do {
      if ($189) {
       $190 = (($186) + 19|0);
       $191 = HEAP8[$190>>0]|0;
       $192 = ($191&255)<(4);
       if ($192) {
        $317 = 0;$318 = 0;
        label = 76;
       } else {
        $193 = (($186) + 92|0);
        $194 = HEAP32[$193>>2]|0;
        $195 = ($194|0)==(0|0);
        if ($195) {
         $319 = 1;$320 = 0;
        } else {
         $196 = (($186) + 16|0);
         $197 = HEAP8[$196>>0]|0;
         $198 = $197&255;
         $199 = ((($186) + (($198*12)|0)|0) + 50|0);
         $200 = HEAP8[$199>>0]|0;
         $201 = $200&255;
         $202 = ((($186) + (($198*12)|0)|0) + 44|0);
         $203 = HEAP32[$202>>2]|0;
         $204 = (($186) + 17|0);
         $205 = HEAP8[$204>>0]|0;
         $206 = $205&255;
         $207 = (($206) + ($203))|0;
         $208 = (($194) + ($207)|0);
         $319 = $201;$320 = $208;
        }
        if ($189) {
         $317 = $320;$318 = $319;
         label = 76;
        } else {
         $252 = $320;$253 = 0;$274 = $319;$276 = 0;$321 = 0;
        }
       }
       do {
        if ((label|0) == 76) {
         $209 = (($186) + 19|0);
         $210 = HEAP8[$209>>0]|0;
         $211 = ($210&255)<(4);
         do {
          if ($211) {
           $322 = 0;
          } else {
           $212 = (($186) + 92|0);
           $213 = HEAP32[$212>>2]|0;
           $214 = ($213|0)==(0|0);
           if ($214) {
            $322 = 0;
            break;
           }
           $215 = (($186) + 100|0);
           $216 = HEAP32[$215>>2]|0;
           $217 = (($186) + 16|0);
           $218 = HEAP8[$217>>0]|0;
           $219 = $218&255;
           $220 = ((($186) + (($219*12)|0)|0) + 50|0);
           $221 = HEAP8[$220>>0]|0;
           $222 = $221&255;
           $223 = ((($186) + (($219*12)|0)|0) + 44|0);
           $224 = HEAP32[$223>>2]|0;
           $225 = (($186) + 17|0);
           $226 = HEAP8[$225>>0]|0;
           $227 = $226&255;
           $228 = Math_imul($222, $216)|0;
           $229 = (($228) + ($224))|0;
           $230 = (($229) + ($227))|0;
           $231 = (($213) + ($230)|0);
           $322 = $231;
          }
         } while(0);
         if (!($189)) {
          $252 = $317;$253 = $322;$274 = $318;$276 = 0;$321 = 0;
          break;
         }
         $232 = (($186) + 19|0);
         $233 = HEAP8[$232>>0]|0;
         $234 = ($233&255)<(4);
         if ($234) {
          $252 = $317;$253 = $322;$274 = $318;$276 = 0;$321 = 0;
          break;
         }
         $235 = (($186) + 92|0);
         $236 = HEAP32[$235>>2]|0;
         $237 = ($236|0)==(0|0);
         if ($237) {
          $252 = $317;$253 = $322;$274 = $318;$276 = 1;$321 = 0;
          break;
         }
         $238 = (($186) + 16|0);
         $239 = HEAP8[$238>>0]|0;
         $240 = $239&255;
         $241 = ((($186) + (($240*12)|0)|0) + 50|0);
         $242 = HEAP8[$241>>0]|0;
         $243 = $242&255;
         $244 = ((($186) + (($240*12)|0)|0) + 44|0);
         $245 = HEAP32[$244>>2]|0;
         $246 = (($186) + 17|0);
         $247 = HEAP8[$246>>0]|0;
         $248 = $247&255;
         $249 = (($248) + ($245))|0;
         $250 = (($236) + ($249)|0);
         $252 = $317;$253 = $322;$274 = $318;$276 = $243;$321 = $250;
        }
       } while(0);
       $251 = ($252|0)==($253|0);
       if ($251) {
        break;
       } else {
        $255 = $252;$272 = $321;
       }
       while(1) {
        $254 = (($255) + 2|0);
        $256 = HEAP8[$254>>0]|0;
        $257 = (($255) + 1|0);
        $258 = HEAP8[$257>>0]|0;
        $259 = HEAP8[$255>>0]|0;
        $260 = (($255) + 3|0);
        $261 = HEAP8[$260>>0]|0;
        $262 = $261&255;
        $263 = $262 << 24;
        $264 = $259&255;
        $265 = $264 << 16;
        $266 = $258&255;
        $267 = $266 << 8;
        $268 = $256&255;
        $269 = $267 | $268;
        $270 = $269 | $265;
        $271 = $270 | $263;
        HEAP32[$272>>2] = $271;
        $273 = (($255) + ($274)|0);
        $275 = (($272) + ($276)|0);
        $277 = ($273|0)==($253|0);
        if ($277) {
         break;
        } else {
         $255 = $273;$272 = $275;
        }
       }
      }
     } while(0);
     HEAP8[$2>>0] = 1;
    }
    $278 = (($this) + 168|0);
    __ZN4AABB8TransferI19StreamedBinaryWriteILb0EEEEvRT_($278,$transfer);
    $279 = (($this) + 40|0);
    $280 = HEAP32[$13>>2]|0;
    $281 = (($280) + 4|0);
    $282 = HEAP32[$16>>2]|0;
    $283 = ($281>>>0)<($282>>>0);
    if ($283) {
     $284 = HEAP32[$279>>2]|0;
     HEAP32[$280>>2] = $284;
     HEAP32[$13>>2] = $281;
     $287 = $281;$289 = $282;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$279,4);
     $$pre60 = HEAP32[$13>>2]|0;
     $$pre61 = HEAP32[$16>>2]|0;
     $287 = $$pre60;$289 = $$pre61;
    }
    $285 = HEAP32[628512>>2]|0;
    HEAP32[$size$i$i$i$i>>2] = 0;
    $286 = (($287) + 4|0);
    $288 = ($286>>>0)<($289>>>0);
    if ($288) {
     HEAP32[$287>>2] = 0;
     HEAP32[$13>>2] = $286;
     label = 92;
    } else {
     __THREW__ = 0;
     invoke_viii(1640,($13|0),($size$i$i$i$i|0),4);
     $290 = __THREW__; __THREW__ = 0;
     $291 = $290&1;
     if ($291) {
      label = 99;
     } else {
      label = 92;
     }
    }
    do {
     if ((label|0) == 92) {
      __THREW__ = 0;
      invoke_vi(3378,($transfer|0));
      $292 = __THREW__; __THREW__ = 0;
      $293 = $292&1;
      if ($293) {
       label = 99;
       break;
      }
      HEAP32[$size$i$i$i25>>2] = 0;
      $294 = HEAP32[$13>>2]|0;
      $295 = (($294) + 4|0);
      $296 = HEAP32[$16>>2]|0;
      $297 = ($295>>>0)<($296>>>0);
      if ($297) {
       HEAP32[$294>>2] = 0;
       HEAP32[$13>>2] = $295;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($13|0),($size$i$i$i25|0),4);
       $298 = __THREW__; __THREW__ = 0;
       $299 = $298&1;
       if ($299) {
        label = 99;
        break;
       }
      }
      __THREW__ = 0;
      invoke_vi(3378,($transfer|0));
      $300 = __THREW__; __THREW__ = 0;
      $301 = $300&1;
      if ($301) {
       label = 99;
       break;
      }
      HEAP32[$size$i$i$i32>>2] = $285;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$size$i$i$i32+0>>2]|0;
      invoke_vii(2591,(0|0),($$byval_copy5|0));
      $302 = __THREW__; __THREW__ = 0;
      $303 = $302&1;
      if ($303) {
       $304 = ___cxa_find_matching_catch()|0;
       $305 = tempRet0;
       $$0$i = $304;$$01$i = $305;
       break;
      } else {
       HEAP32[$0>>2] = $285;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    do {
     if ((label|0) == 99) {
      $306 = ___cxa_find_matching_catch()|0;
      $307 = tempRet0;
      HEAP32[$0>>2] = $285;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,(0|0),($$byval_copy5|0));
      $308 = __THREW__; __THREW__ = 0;
      $309 = $308&1;
      if (!($309)) {
       $$0$i = $306;$$01$i = $307;
       break;
      }
      $312 = ___cxa_find_matching_catch(0|0)|0;
      $313 = tempRet0;
      ___clang_call_terminate($312);
      // unreachable;
     }
    } while(0);
    HEAP32[$1>>2] = $285;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,(0|0),($$byval_copy5|0));
    $310 = __THREW__; __THREW__ = 0;
    $311 = $310&1;
    if ($311) {
     $312 = ___cxa_find_matching_catch(0|0)|0;
     $313 = tempRet0;
     ___clang_call_terminate($312);
     // unreachable;
    } else {
     ___resumeException($$0$i|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $180 = ___cxa_find_matching_catch()|0;
 $181 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3459,($$byval_copy5|0));
 $182 = __THREW__; __THREW__ = 0;
 $183 = $182&1;
 if ($183) {
  $314 = ___cxa_find_matching_catch(0|0)|0;
  $315 = tempRet0;
  ___clang_call_terminate($314);
  // unreachable;
 } else {
  $$7 = $181;$$78 = $180;
  ___resumeException($$78|0);
  // unreachable;
 }
}
function __ZN14CompressedMesh8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17PackedFloatVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN17PackedFloatVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 56|0);
 __ZN17PackedFloatVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($1,$transfer);
 $2 = (($this) + 104|0);
 __ZN17PackedFloatVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($2,$transfer);
 $3 = (($this) + 180|0);
 __ZN15PackedIntVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($3,$transfer);
 $4 = (($this) + 84|0);
 __ZN15PackedIntVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($4,$transfer);
 $5 = (($this) + 132|0);
 __ZN15PackedIntVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($5,$transfer);
 $6 = (($this) + 152|0);
 __ZN17PackedFloatVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($6,$transfer);
 $7 = (($this) + 200|0);
 __ZN15PackedIntVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($7,$transfer);
 $8 = (($this) + 220|0);
 __ZN15PackedIntVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 240|0);
 $10 = (($transfer) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = (($transfer) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)<($14>>>0);
 if ($15) {
  $16 = HEAP32[$9>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$10>>2] = $12;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($10,$9,4);
  STACKTOP = sp;return;
 }
}
function __ZN15PackedIntVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $15 = $2;$17 = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre1 = HEAP32[$3>>2]|0;
  $15 = $$pre;$17 = $$pre1;
 }
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $8;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 HEAP32[$size$i$i$i>>2] = $13;
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  HEAP32[$15>>2] = $13;
  HEAP32[$0>>2] = $14;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$size$i$i$i,4);
 }
 $18 = HEAP32[$7>>2]|0;
 $19 = HEAP32[$9>>2]|0;
 $20 = ($19|0)==($18|0);
 if (!($20)) {
  $26 = $19;
  while(1) {
   $21 = HEAP32[$0>>2]|0;
   $22 = (($21) + 1|0);
   $23 = HEAP32[$3>>2]|0;
   $24 = ($22>>>0)<($23>>>0);
   if ($24) {
    $25 = HEAP8[$26>>0]|0;
    HEAP8[$21>>0] = $25;
    $27 = HEAP32[$0>>2]|0;
    $28 = (($27) + 1|0);
    HEAP32[$0>>2] = $28;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$26,1);
   }
   $29 = (($26) + 1|0);
   $30 = ($29|0)==($18|0);
   if ($30) {
    break;
   } else {
    $26 = $29;
   }
  }
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $31 = (($this) + 4|0);
 $32 = HEAP32[$0>>2]|0;
 $33 = (($32) + 1|0);
 $34 = HEAP32[$3>>2]|0;
 $35 = ($33>>>0)<($34>>>0);
 if ($35) {
  $36 = HEAP8[$31>>0]|0;
  HEAP8[$32>>0] = $36;
  $37 = HEAP32[$0>>2]|0;
  $38 = (($37) + 1|0);
  HEAP32[$0>>2] = $38;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN17PackedFloatVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre2 = HEAP32[$3>>2]|0;
  $11 = $$pre2;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre3 = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $15 = $$pre3;$17 = $$pre4;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $27 = $14;$29 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $27 = $$pre5;$29 = $$pre6;
 }
 $19 = (($this) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $20;
 $24 = $22;
 $25 = (($23) - ($24))|0;
 HEAP32[$size$i$i$i>>2] = $25;
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  HEAP32[$27>>2] = $25;
  HEAP32[$0>>2] = $26;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$size$i$i$i,4);
 }
 $30 = HEAP32[$19>>2]|0;
 $31 = HEAP32[$21>>2]|0;
 $32 = ($31|0)==($30|0);
 if (!($32)) {
  $38 = $31;
  while(1) {
   $33 = HEAP32[$0>>2]|0;
   $34 = (($33) + 1|0);
   $35 = HEAP32[$3>>2]|0;
   $36 = ($34>>>0)<($35>>>0);
   if ($36) {
    $37 = HEAP8[$38>>0]|0;
    HEAP8[$33>>0] = $37;
    $39 = HEAP32[$0>>2]|0;
    $40 = (($39) + 1|0);
    HEAP32[$0>>2] = $40;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$38,1);
   }
   $41 = (($38) + 1|0);
   $42 = ($41|0)==($30|0);
   if ($42) {
    break;
   } else {
    $38 = $41;
   }
  }
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $43 = (($this) + 12|0);
 $44 = HEAP32[$0>>2]|0;
 $45 = (($44) + 1|0);
 $46 = HEAP32[$3>>2]|0;
 $47 = ($45>>>0)<($46>>>0);
 if ($47) {
  $48 = HEAP8[$43>>0]|0;
  HEAP8[$44>>0] = $48;
  $49 = HEAP32[$0>>2]|0;
  $50 = (($49) + 1|0);
  HEAP32[$0>>2] = $50;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$43,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN13BoneInfluence8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $11 = $$pre7;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $15 = $$pre8;$17 = $$pre9;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $21 = $$pre10;$23 = $$pre11;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $27 = $$pre12;$29 = $$pre13;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $$pre14 = HEAP32[$0>>2]|0;
  $$pre15 = HEAP32[$3>>2]|0;
  $33 = $$pre14;$35 = $$pre15;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = HEAP32[$31>>2]|0;
  HEAP32[$33>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,4);
  $$pre16 = HEAP32[$0>>2]|0;
  $$pre17 = HEAP32[$3>>2]|0;
  $39 = $$pre16;$41 = $$pre17;
 }
 $37 = (($this) + 24|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = HEAP32[$37>>2]|0;
  HEAP32[$39>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$37,4);
  $$pre18 = HEAP32[$0>>2]|0;
  $$pre19 = HEAP32[$3>>2]|0;
  $45 = $$pre18;$47 = $$pre19;
 }
 $43 = (($this) + 28|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)<($47>>>0);
 if ($46) {
  $48 = HEAP32[$43>>2]|0;
  HEAP32[$45>>2] = $48;
  HEAP32[$0>>2] = $44;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$43,4);
  STACKTOP = sp;return;
 }
}
function __ZN10Matrix4x4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0;
 var $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $11 = $$pre16;$9 = $$pre;
 }
 $7 = (($this) + 16|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $15 = $$pre17;$17 = $$pre18;
 }
 $13 = (($this) + 32|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $21 = $$pre19;$23 = $$pre20;
 }
 $19 = (($this) + 48|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre21 = HEAP32[$0>>2]|0;
  $$pre22 = HEAP32[$3>>2]|0;
  $27 = $$pre21;$29 = $$pre22;
 }
 $25 = (($this) + 4|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $$pre23 = HEAP32[$0>>2]|0;
  $$pre24 = HEAP32[$3>>2]|0;
  $33 = $$pre23;$35 = $$pre24;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$33>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,4);
  $$pre25 = HEAP32[$0>>2]|0;
  $$pre26 = HEAP32[$3>>2]|0;
  $39 = $$pre25;$41 = $$pre26;
 }
 $37 = (($this) + 36|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$39>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$37,4);
  $$pre27 = HEAP32[$0>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $45 = $$pre27;$47 = $$pre28;
 }
 $43 = (($this) + 52|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)<($47>>>0);
 if ($46) {
  $48 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$45>>2] = $48;
  HEAP32[$0>>2] = $44;
  $51 = $44;$53 = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$43,4);
  $$pre29 = HEAP32[$0>>2]|0;
  $$pre30 = HEAP32[$3>>2]|0;
  $51 = $$pre29;$53 = $$pre30;
 }
 $49 = (($this) + 8|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)<($53>>>0);
 if ($52) {
  $54 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$51>>2] = $54;
  HEAP32[$0>>2] = $50;
  $57 = $50;$59 = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$49,4);
  $$pre31 = HEAP32[$0>>2]|0;
  $$pre32 = HEAP32[$3>>2]|0;
  $57 = $$pre31;$59 = $$pre32;
 }
 $55 = (($this) + 24|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)<($59>>>0);
 if ($58) {
  $60 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$57>>2] = $60;
  HEAP32[$0>>2] = $56;
  $63 = $56;$65 = $59;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$55,4);
  $$pre33 = HEAP32[$0>>2]|0;
  $$pre34 = HEAP32[$3>>2]|0;
  $63 = $$pre33;$65 = $$pre34;
 }
 $61 = (($this) + 40|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)<($65>>>0);
 if ($64) {
  $66 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$63>>2] = $66;
  HEAP32[$0>>2] = $62;
  $69 = $62;$71 = $65;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$61,4);
  $$pre35 = HEAP32[$0>>2]|0;
  $$pre36 = HEAP32[$3>>2]|0;
  $69 = $$pre35;$71 = $$pre36;
 }
 $67 = (($this) + 56|0);
 $68 = (($69) + 4|0);
 $70 = ($68>>>0)<($71>>>0);
 if ($70) {
  $72 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$69>>2] = $72;
  HEAP32[$0>>2] = $68;
  $75 = $68;$77 = $71;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$67,4);
  $$pre37 = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$3>>2]|0;
  $75 = $$pre37;$77 = $$pre38;
 }
 $73 = (($this) + 12|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)<($77>>>0);
 if ($76) {
  $78 = Math_fround(HEAPF32[$73>>2]);
  HEAPF32[$75>>2] = $78;
  HEAP32[$0>>2] = $74;
  $81 = $74;$83 = $77;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$73,4);
  $$pre39 = HEAP32[$0>>2]|0;
  $$pre40 = HEAP32[$3>>2]|0;
  $81 = $$pre39;$83 = $$pre40;
 }
 $79 = (($this) + 28|0);
 $80 = (($81) + 4|0);
 $82 = ($80>>>0)<($83>>>0);
 if ($82) {
  $84 = Math_fround(HEAPF32[$79>>2]);
  HEAPF32[$81>>2] = $84;
  HEAP32[$0>>2] = $80;
  $87 = $80;$89 = $83;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$79,4);
  $$pre41 = HEAP32[$0>>2]|0;
  $$pre42 = HEAP32[$3>>2]|0;
  $87 = $$pre41;$89 = $$pre42;
 }
 $85 = (($this) + 44|0);
 $86 = (($87) + 4|0);
 $88 = ($86>>>0)<($89>>>0);
 if ($88) {
  $90 = Math_fround(HEAPF32[$85>>2]);
  HEAPF32[$87>>2] = $90;
  HEAP32[$0>>2] = $86;
  $93 = $86;$95 = $89;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$85,4);
  $$pre43 = HEAP32[$0>>2]|0;
  $$pre44 = HEAP32[$3>>2]|0;
  $93 = $$pre43;$95 = $$pre44;
 }
 $91 = (($this) + 60|0);
 $92 = (($93) + 4|0);
 $94 = ($92>>>0)<($95>>>0);
 if ($94) {
  $96 = Math_fround(HEAPF32[$91>>2]);
  HEAPF32[$93>>2] = $96;
  HEAP32[$0>>2] = $92;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$91,4);
  STACKTOP = sp;return;
 }
}
function __ZN14BlendShapeData8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i12 = 0, $$pre$i$i$i19 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i13 = 0, $$pre3$i$i$i20 = 0, $$pre30 = 0, $$pre4$i$i$i = 0, $$pre4$i$i$i15 = 0, $$pre4$i$i$i22 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i16 = 0, $$pre5$i$i$i23 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $i$01$i$i$i = 0, $i$01$i$i$i10 = 0, $i$01$i$i$i3 = 0, $size$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i8 = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i8>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i8,4);
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) + (($9*40)|0)|0);
 $11 = ($9|0)==(0);
 if (!($11)) {
  $i$01$i$i$i = $8;
  while(1) {
   $12 = HEAP32[$2>>2]|0;
   $13 = (($12) + 4|0);
   $14 = HEAP32[$5>>2]|0;
   $15 = ($13>>>0)<($14>>>0);
   if ($15) {
    $16 = Math_fround(HEAPF32[$i$01$i$i$i>>2]);
    HEAPF32[$12>>2] = $16;
    HEAP32[$2>>2] = $13;
    $19 = $13;$21 = $14;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i,4);
    $$pre$i$i$i19 = HEAP32[$2>>2]|0;
    $$pre3$i$i$i20 = HEAP32[$5>>2]|0;
    $19 = $$pre$i$i$i19;$21 = $$pre3$i$i$i20;
   }
   $17 = (($i$01$i$i$i) + 4|0);
   $18 = (($19) + 4|0);
   $20 = ($18>>>0)<($21>>>0);
   if ($20) {
    $22 = Math_fround(HEAPF32[$17>>2]);
    HEAPF32[$19>>2] = $22;
    HEAP32[$2>>2] = $18;
    $25 = $18;$27 = $21;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$17,4);
    $$pre4$i$i$i22 = HEAP32[$2>>2]|0;
    $$pre5$i$i$i23 = HEAP32[$5>>2]|0;
    $25 = $$pre4$i$i$i22;$27 = $$pre5$i$i$i23;
   }
   $23 = (($i$01$i$i$i) + 8|0);
   $24 = (($25) + 4|0);
   $26 = ($24>>>0)<($27>>>0);
   if ($26) {
    $28 = Math_fround(HEAPF32[$23>>2]);
    HEAPF32[$25>>2] = $28;
    HEAP32[$2>>2] = $24;
    $31 = $24;$33 = $27;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$23,4);
    $$pre = HEAP32[$2>>2]|0;
    $$pre26 = HEAP32[$5>>2]|0;
    $31 = $$pre;$33 = $$pre26;
   }
   $29 = (($i$01$i$i$i) + 12|0);
   $30 = (($31) + 4|0);
   $32 = ($30>>>0)<($33>>>0);
   if ($32) {
    $34 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$31>>2] = $34;
    HEAP32[$2>>2] = $30;
    $37 = $30;$39 = $33;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$29,4);
    $$pre$i$i$i = HEAP32[$2>>2]|0;
    $$pre3$i$i$i = HEAP32[$5>>2]|0;
    $37 = $$pre$i$i$i;$39 = $$pre3$i$i$i;
   }
   $35 = (($i$01$i$i$i) + 16|0);
   $36 = (($37) + 4|0);
   $38 = ($36>>>0)<($39>>>0);
   if ($38) {
    $40 = Math_fround(HEAPF32[$35>>2]);
    HEAPF32[$37>>2] = $40;
    HEAP32[$2>>2] = $36;
    $43 = $36;$45 = $39;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$35,4);
    $$pre4$i$i$i = HEAP32[$2>>2]|0;
    $$pre5$i$i$i = HEAP32[$5>>2]|0;
    $43 = $$pre4$i$i$i;$45 = $$pre5$i$i$i;
   }
   $41 = (($i$01$i$i$i) + 20|0);
   $42 = (($43) + 4|0);
   $44 = ($42>>>0)<($45>>>0);
   if ($44) {
    $46 = Math_fround(HEAPF32[$41>>2]);
    HEAPF32[$43>>2] = $46;
    HEAP32[$2>>2] = $42;
    $49 = $42;$51 = $45;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$41,4);
    $$pre27 = HEAP32[$2>>2]|0;
    $$pre28 = HEAP32[$5>>2]|0;
    $49 = $$pre27;$51 = $$pre28;
   }
   $47 = (($i$01$i$i$i) + 24|0);
   $48 = (($49) + 4|0);
   $50 = ($48>>>0)<($51>>>0);
   if ($50) {
    $52 = Math_fround(HEAPF32[$47>>2]);
    HEAPF32[$49>>2] = $52;
    HEAP32[$2>>2] = $48;
    $55 = $48;$57 = $51;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$47,4);
    $$pre$i$i$i12 = HEAP32[$2>>2]|0;
    $$pre3$i$i$i13 = HEAP32[$5>>2]|0;
    $55 = $$pre$i$i$i12;$57 = $$pre3$i$i$i13;
   }
   $53 = (($i$01$i$i$i) + 28|0);
   $54 = (($55) + 4|0);
   $56 = ($54>>>0)<($57>>>0);
   if ($56) {
    $58 = Math_fround(HEAPF32[$53>>2]);
    HEAPF32[$55>>2] = $58;
    HEAP32[$2>>2] = $54;
    $61 = $54;$63 = $57;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$53,4);
    $$pre4$i$i$i15 = HEAP32[$2>>2]|0;
    $$pre5$i$i$i16 = HEAP32[$5>>2]|0;
    $61 = $$pre4$i$i$i15;$63 = $$pre5$i$i$i16;
   }
   $59 = (($i$01$i$i$i) + 32|0);
   $60 = (($61) + 4|0);
   $62 = ($60>>>0)<($63>>>0);
   if ($62) {
    $64 = Math_fround(HEAPF32[$59>>2]);
    HEAPF32[$61>>2] = $64;
    HEAP32[$2>>2] = $60;
    $67 = $60;$69 = $63;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$59,4);
    $$pre29 = HEAP32[$2>>2]|0;
    $$pre30 = HEAP32[$5>>2]|0;
    $67 = $$pre29;$69 = $$pre30;
   }
   $65 = (($i$01$i$i$i) + 36|0);
   $66 = (($67) + 4|0);
   $68 = ($66>>>0)<($69>>>0);
   if ($68) {
    $70 = HEAP32[$65>>2]|0;
    HEAP32[$67>>2] = $70;
    HEAP32[$2>>2] = $66;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$65,4);
   }
   $71 = (($i$01$i$i$i) + 40|0);
   $72 = ($71|0)==($10|0);
   if ($72) {
    break;
   } else {
    $i$01$i$i$i = $71;
   }
  }
 }
 $73 = (($this) + 24|0);
 $74 = HEAP32[$73>>2]|0;
 HEAP32[$size$i$i$i8>>2] = $74;
 $75 = HEAP32[$2>>2]|0;
 $76 = (($75) + 4|0);
 $77 = HEAP32[$5>>2]|0;
 $78 = ($76>>>0)<($77>>>0);
 if ($78) {
  HEAP32[$75>>2] = $74;
  HEAP32[$2>>2] = $76;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i8,4);
 }
 $79 = (($this) + 16|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = HEAP32[$73>>2]|0;
 $82 = (($80) + (($81*12)|0)|0);
 $83 = ($81|0)==(0);
 if (!($83)) {
  $i$01$i$i$i3 = $80;
  while(1) {
   __ZN10BlendShape8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i3,$transfer);
   $84 = (($i$01$i$i$i3) + 12|0);
   $85 = ($84|0)==($82|0);
   if ($85) {
    break;
   } else {
    $i$01$i$i$i3 = $84;
   }
  }
 }
 $86 = (($this) + 36|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($this) + 32|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = $87;
 $91 = $89;
 $92 = (($90) - ($91))|0;
 $93 = $92 >> 4;
 HEAP32[$size$i$i$i8>>2] = $93;
 $94 = HEAP32[$2>>2]|0;
 $95 = (($94) + 4|0);
 $96 = HEAP32[$5>>2]|0;
 $97 = ($95>>>0)<($96>>>0);
 if ($97) {
  HEAP32[$94>>2] = $93;
  HEAP32[$2>>2] = $95;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i8,4);
 }
 $98 = HEAP32[$86>>2]|0;
 $99 = HEAP32[$88>>2]|0;
 $100 = ($99|0)==($98|0);
 if (!($100)) {
  $101 = $99;
  while(1) {
   __ZN17BlendShapeChannel8TransferI19StreamedBinaryWriteILb0EEEEvRT_($101,$transfer);
   $102 = (($101) + 16|0);
   $103 = ($102|0)==($98|0);
   if ($103) {
    break;
   } else {
    $101 = $102;
   }
  }
 }
 $104 = (($this) + 52|0);
 $105 = HEAP32[$104>>2]|0;
 HEAP32[$size$i$i$i8>>2] = $105;
 $106 = HEAP32[$2>>2]|0;
 $107 = (($106) + 4|0);
 $108 = HEAP32[$5>>2]|0;
 $109 = ($107>>>0)<($108>>>0);
 if ($109) {
  HEAP32[$106>>2] = $105;
  HEAP32[$2>>2] = $107;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i8,4);
 }
 $110 = (($this) + 44|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = HEAP32[$104>>2]|0;
 $113 = (($111) + ($112<<2)|0);
 $114 = ($112|0)==(0);
 if ($114) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i10 = $111;
 }
 while(1) {
  $115 = HEAP32[$2>>2]|0;
  $116 = (($115) + 4|0);
  $117 = HEAP32[$5>>2]|0;
  $118 = ($116>>>0)<($117>>>0);
  if ($118) {
   $119 = Math_fround(HEAPF32[$i$01$i$i$i10>>2]);
   HEAPF32[$115>>2] = $119;
   HEAP32[$2>>2] = $116;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i10,4);
  }
  $120 = (($i$01$i$i$i10) + 4|0);
  $121 = ($120|0)==($113|0);
  if ($121) {
   break;
  } else {
   $i$01$i$i$i10 = $120;
  }
 }
 STACKTOP = sp;return;
}
function __ZN17BlendShapeChannel8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 $1 = HEAP32[$this>>2]|0;
 __THREW__ = 0;
 (invoke_iii(2353,($tempStr$i$i|0),($1|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viii(1624,($transfer|0),($tempStr$i$i|0),0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   invoke_vi(3378,($transfer|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP8[$tempStr$i$i>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $22 = (($tempStr$i$i) + 8|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($23|0),($$byval_copy1|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      $26 = ___cxa_find_matching_catch()|0;
      $27 = tempRet0;
      ___cxa_call_unexpected(($26|0));
      // unreachable;
     }
    }
    $28 = (($this) + 4|0);
    $29 = (($transfer) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + 4|0);
    $32 = (($transfer) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($31>>>0)<($33>>>0);
    if ($34) {
     $35 = HEAP32[$28>>2]|0;
     HEAP32[$30>>2] = $35;
     HEAP32[$29>>2] = $31;
     $38 = $31;$40 = $33;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($29,$28,4);
     $$pre = HEAP32[$29>>2]|0;
     $$pre2 = HEAP32[$32>>2]|0;
     $38 = $$pre;$40 = $$pre2;
    }
    $36 = (($this) + 8|0);
    $37 = (($38) + 4|0);
    $39 = ($37>>>0)<($40>>>0);
    if ($39) {
     $41 = HEAP32[$36>>2]|0;
     HEAP32[$38>>2] = $41;
     HEAP32[$29>>2] = $37;
     $44 = $37;$46 = $40;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($29,$36,4);
     $$pre3 = HEAP32[$29>>2]|0;
     $$pre4 = HEAP32[$32>>2]|0;
     $44 = $$pre3;$46 = $$pre4;
    }
    $42 = (($this) + 12|0);
    $43 = (($44) + 4|0);
    $45 = ($43>>>0)<($46>>>0);
    if ($45) {
     $47 = HEAP32[$42>>2]|0;
     HEAP32[$44>>2] = $47;
     HEAP32[$29>>2] = $43;
     STACKTOP = sp;return;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($29,$42,4);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 $6 = HEAP8[$tempStr$i$i>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  ___resumeException($4|0);
  // unreachable;
 }
 $9 = (($tempStr$i$i) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($10|0),($$byval_copy1|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_call_unexpected(($13|0));
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN10BlendShape8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $11 = $$pre3;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $15 = $$pre4;$17 = $$pre5;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 1|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP8[$13>>0]|0;
  HEAP8[$15>>0] = $18;
  $19 = HEAP32[$0>>2]|0;
  $20 = (($19) + 1|0);
  HEAP32[$0>>2] = $20;
  $23 = $20;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,1);
  $$pre6 = HEAP32[$0>>2]|0;
  $23 = $$pre6;
 }
 $21 = (($this) + 9|0);
 $22 = (($23) + 1|0);
 $24 = HEAP32[$3>>2]|0;
 $25 = ($22>>>0)<($24>>>0);
 if ($25) {
  $26 = HEAP8[$21>>0]|0;
  HEAP8[$23>>0] = $26;
  $27 = HEAP32[$0>>2]|0;
  $28 = (($27) + 1|0);
  HEAP32[$0>>2] = $28;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$21,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN7SubMesh8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre4 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre4;
 }
 $8 = (($this) + 8|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = HEAP32[$8>>2]|0;
  HEAP32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $15 = $9;$17 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$4>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$this>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$1>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$this,4);
  $$pre7 = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 16|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$1>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$19,4);
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $27 = $$pre9;$29 = $$pre10;
 }
 $25 = (($this) + 20|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$27>>2] = $30;
  HEAP32[$1>>2] = $26;
  $31 = (($this) + 32|0);
  __ZN4AABB8TransferI19StreamedBinaryWriteILb0EEEEvRT_($31,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$25,4);
  $31 = (($this) + 32|0);
  __ZN4AABB8TransferI19StreamedBinaryWriteILb0EEEEvRT_($31,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4Mesh8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$6 = 0, $$67 = 0, $$7 = 0, $$78 = 0, $$byval_copy3 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i11 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dummyIndexContainer = 0, $dummySkin = 0, $dummyVertexData = 0, $exitcond$i$i = 0, $i$02$i$i = 0, $p$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $$byval_copy3 = sp + 144|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $dummySkin = sp + 16|0;
 $dummyVertexData = sp + 32|0;
 $dummyIndexContainer = sp + 132|0;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $3 = (($this) + 276|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 __ZN4Mesh21UnswizzleVertexColorsEb($this,1);
 $6 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI7SubMesh13stl_allocatorIS4_L18MemLabelIdentifier10ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$6,0);
 $7 = (($this) + 56|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI16BlendShapeVertexLj4EEEEvRT_17TransferMetaFlags($transfer,$7,0);
 $8 = (($this) + 72|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI10BlendShapeLj4EEEEvRT_17TransferMetaFlags($transfer,$8,0);
 $9 = (($this) + 88|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17BlendShapeChannelNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$9,0);
 $10 = (($this) + 100|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIfLj4EEEEvRT_17TransferMetaFlags($transfer,$10,0);
 $11 = (($this) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 120|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI10Matrix4x4fLj4EEEEvRT_17TransferMetaFlags($transfer,$13,0);
 $14 = (($this) + 116|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$14,0);
 $15 = (($this) + 132|0);
 $16 = (($transfer) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 4|0);
 $19 = (($transfer) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$15,4);
  $$pre$i$i$i = HEAP32[$15>>2]|0;
  $$pre = HEAP32[$16>>2]|0;
  $$pre30 = HEAP32[$19>>2]|0;
  $23 = $$pre$i$i$i;$27 = $$pre;$29 = $$pre30;
 } else {
  $22 = HEAP32[$17>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$16>>2] = $18;
  $23 = $22;$27 = $18;$29 = $20;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$15>>2] = $24;
 $25 = (($this) + 32|0);
 $26 = (($27) + 1|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$25,1);
  $$pre31 = HEAP32[$16>>2]|0;
  $35 = $$pre31;
 } else {
  $30 = HEAP8[$27>>0]|0;
  HEAP8[$25>>0] = $30;
  $31 = HEAP32[$16>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$16>>2] = $32;
  $35 = $32;
 }
 $33 = (($this) + 33|0);
 $34 = (($35) + 1|0);
 $36 = HEAP32[$19>>2]|0;
 $37 = ($34>>>0)>($36>>>0);
 if ($37) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$33,1);
  $$pre32 = HEAP32[$16>>2]|0;
  $43 = $$pre32;
 } else {
  $38 = HEAP8[$35>>0]|0;
  HEAP8[$33>>0] = $38;
  $39 = HEAP32[$16>>2]|0;
  $40 = (($39) + 1|0);
  HEAP32[$16>>2] = $40;
  $43 = $40;
 }
 $41 = (($this) + 34|0);
 $42 = (($43) + 1|0);
 $44 = HEAP32[$19>>2]|0;
 $45 = ($42>>>0)>($44>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$41,1);
  $$pre33 = HEAP32[$16>>2]|0;
  $51 = $$pre33;
 } else {
  $46 = HEAP8[$43>>0]|0;
  HEAP8[$41>>0] = $46;
  $47 = HEAP32[$16>>2]|0;
  $48 = (($47) + 1|0);
  HEAP32[$16>>2] = $48;
  $51 = $48;
 }
 $49 = (($this) + 35|0);
 $50 = (($51) + 1|0);
 $52 = HEAP32[$19>>2]|0;
 $53 = ($50>>>0)>($52>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$49,1);
 } else {
  $54 = HEAP8[$51>>0]|0;
  HEAP8[$49>>0] = $54;
  $55 = HEAP32[$16>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$16>>2] = $56;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $57 = HEAP8[$25>>0]|0;
 $58 = ($57<<24>>24)==(0);
 L21: do {
  if ($58) {
   label = 18;
  } else {
   $59 = HEAP32[$transfer>>2]|0;
   $60 = $59 & 16384;
   $61 = ($60|0)==(0);
   if ($61) {
    HEAP32[$dummySkin>>2] = 0;
    $87 = (($dummySkin) + 8|0);
    HEAP32[$87>>2] = 0;
    $88 = (($dummySkin) + 12|0);
    HEAP32[$88>>2] = 0;
    $89 = (($dummySkin) + 4|0);
    HEAP32[$89>>2] = 61;
    __THREW__ = 0;
    invoke_vi(3452,($dummyVertexData|0));
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    do {
     if ($91) {
      label = 35;
     } else {
      HEAP32[$dummyIndexContainer>>2] = 0;
      $92 = (($dummyIndexContainer) + 4|0);
      HEAP32[$92>>2] = 0;
      $93 = (($dummyIndexContainer) + 8|0);
      HEAP32[$93>>2] = 0;
      __THREW__ = 0;
      invoke_viii(1700,($transfer|0),($dummyIndexContainer|0),0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if (!($95)) {
       __THREW__ = 0;
       invoke_vi(3377,($transfer|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        __THREW__ = 0;
        invoke_viii(1701,($transfer|0),($dummySkin|0),0);
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if (!($99)) {
         __THREW__ = 0;
         invoke_vii(2673,($dummyVertexData|0),($transfer|0));
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if (!($101)) {
          $102 = HEAP32[$dummyIndexContainer>>2]|0;
          $103 = ($102|0)==(0|0);
          if (!($103)) {
           $104 = HEAP32[$92>>2]|0;
           $105 = ($104|0)==($102|0);
           if (!($105)) {
            HEAP32[$92>>2] = $102;
           }
           HEAP32[$0>>2] = 8;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($102|0),($$byval_copy3|0));
           $106 = __THREW__; __THREW__ = 0;
           $107 = $106&1;
           if ($107) {
            $108 = ___cxa_find_matching_catch()|0;
            $109 = tempRet0;
            ___cxa_call_unexpected(($108|0));
            // unreachable;
           }
          }
          __THREW__ = 0;
          invoke_vi(3456,($dummyVertexData|0));
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           label = 35;
           break;
          }
          $112 = HEAP32[$88>>2]|0;
          $113 = ($112|0)>(-1);
          if (!($113)) {
           $251 = 1;
           break L21;
          }
          $114 = HEAP32[$dummySkin>>2]|0;
          $115 = HEAP32[$89>>2]|0;
          HEAP32[$1>>2] = $115;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
          __Z19free_alloc_internalPv10MemLabelId($114,$$byval_copy3);
          HEAP32[$dummySkin>>2] = 0;
          $251 = 1;
          break L21;
         }
        }
       }
      }
      $118 = ___cxa_find_matching_catch()|0;
      $119 = tempRet0;
      $120 = HEAP32[$dummyIndexContainer>>2]|0;
      $121 = ($120|0)==(0|0);
      if (!($121)) {
       $122 = HEAP32[$92>>2]|0;
       $123 = ($122|0)==($120|0);
       if (!($123)) {
        HEAP32[$92>>2] = $120;
       }
       HEAP32[$1>>2] = 8;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($120|0),($$byval_copy3|0));
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       if ($125) {
        $126 = ___cxa_find_matching_catch()|0;
        $127 = tempRet0;
        ___cxa_call_unexpected(($126|0));
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_vi(3456,($dummyVertexData|0));
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if ($129) {
       $249 = ___cxa_find_matching_catch(0|0)|0;
       $250 = tempRet0;
       ___clang_call_terminate($249);
       // unreachable;
      } else {
       $$6 = $119;$$67 = $118;
      }
     }
    } while(0);
    if ((label|0) == 35) {
     $116 = ___cxa_find_matching_catch()|0;
     $117 = tempRet0;
     $$6 = $117;$$67 = $116;
    }
    $130 = HEAP32[$88>>2]|0;
    $131 = ($130|0)>(-1);
    if (!($131)) {
     $$7 = $$6;$$78 = $$67;
     ___resumeException($$78|0);
     // unreachable;
    }
    $132 = HEAP32[$dummySkin>>2]|0;
    $133 = HEAP32[$89>>2]|0;
    HEAP32[$2>>2] = $133;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($132|0),($$byval_copy3|0));
    $134 = __THREW__; __THREW__ = 0;
    $135 = $134&1;
    if ($135) {
     $249 = ___cxa_find_matching_catch(0|0)|0;
     $250 = tempRet0;
     ___clang_call_terminate($249);
     // unreachable;
    }
    HEAP32[$dummySkin>>2] = 0;
    $$7 = $$6;$$78 = $$67;
    ___resumeException($$78|0);
    // unreachable;
   } else {
    label = 18;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $62 = HEAP32[$11>>2]|0;
  $63 = (($62) + 108|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$63,0);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  $64 = HEAP32[$11>>2]|0;
  $65 = (($64) + 112|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($64) + 108|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = $66;
  $70 = $68;
  $71 = (($69) - ($70))|0;
  $72 = $71 >>> 1;
  $73 = ($72|0)==(0);
  if (!($73)) {
   $i$02$i$i = 0;$p$01$i$i = $68;
   while(1) {
    $74 = (($p$01$i$i) + 2|0);
    $75 = HEAP16[$p$01$i$i>>1]|0;
    $76 = $75&65535;
    $77 = $76 << 8;
    $78 = $76 >>> 8;
    $79 = $77 | $78;
    $80 = $79&65535;
    HEAP16[$p$01$i$i>>1] = $80;
    $81 = (($i$02$i$i) + 1)|0;
    $exitcond$i$i = ($81|0)==($72|0);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$02$i$i = $81;$p$01$i$i = $74;
    }
   }
  }
  $82 = (($64) + 136|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags($transfer,$82,0);
  $83 = HEAP32[$11>>2]|0;
  $84 = (($83) + 8|0);
  __ZN10VertexData8TransferI18StreamedBinaryReadILb1EEEEvRT_($84,$transfer);
  $85 = HEAP32[$11>>2]|0;
  $86 = (($85) + 8|0);
  __ZN10VertexData13SwapEndianessEv($86);
  $251 = 0;
 }
 __ZN14CompressedMeshC2Ev($$byval_copy3);
 __THREW__ = 0;
 invoke_vi(3377,($transfer|0));
 $136 = __THREW__; __THREW__ = 0;
 $137 = $136&1;
 do {
  if (!($137)) {
   __THREW__ = 0;
   invoke_vii(2674,($$byval_copy3|0),($transfer|0));
   $142 = __THREW__; __THREW__ = 0;
   $143 = $142&1;
   if (!($143)) {
    if ($251) {
     __THREW__ = 0;
     invoke_vii(2675,($$byval_copy3|0),($this|0));
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if ($145) {
      break;
     }
    }
    __ZN14CompressedMeshD2Ev($$byval_copy3);
    if (!($5)) {
     $146 = HEAP32[$11>>2]|0;
     $147 = (($146) + 18|0);
     $148 = HEAP8[$147>>0]|0;
     $149 = ($148<<24>>24)==(2);
     if ($149) {
      $150 = (($146) + 19|0);
      $151 = HEAP8[$150>>0]|0;
      $152 = ($151&255)<(4);
      if ($152) {
       $252 = 0;$253 = 0;
       label = 56;
      } else {
       $153 = (($146) + 92|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = ($154|0)==(0|0);
       if ($155) {
        $254 = 1;$255 = 0;
       } else {
        $156 = (($146) + 16|0);
        $157 = HEAP8[$156>>0]|0;
        $158 = $157&255;
        $159 = ((($146) + (($158*12)|0)|0) + 50|0);
        $160 = HEAP8[$159>>0]|0;
        $161 = $160&255;
        $162 = ((($146) + (($158*12)|0)|0) + 44|0);
        $163 = HEAP32[$162>>2]|0;
        $164 = (($146) + 17|0);
        $165 = HEAP8[$164>>0]|0;
        $166 = $165&255;
        $167 = (($166) + ($163))|0;
        $168 = (($154) + ($167)|0);
        $254 = $161;$255 = $168;
       }
       if ($149) {
        $252 = $255;$253 = $254;
        label = 56;
       } else {
        $212 = $255;$213 = 0;$234 = $254;$236 = 0;$256 = 0;
       }
      }
      if ((label|0) == 56) {
       $169 = (($146) + 19|0);
       $170 = HEAP8[$169>>0]|0;
       $171 = ($170&255)<(4);
       if ($171) {
        $257 = 0;
       } else {
        $172 = (($146) + 92|0);
        $173 = HEAP32[$172>>2]|0;
        $174 = ($173|0)==(0|0);
        if ($174) {
         $257 = 0;
        } else {
         $175 = (($146) + 100|0);
         $176 = HEAP32[$175>>2]|0;
         $177 = (($146) + 16|0);
         $178 = HEAP8[$177>>0]|0;
         $179 = $178&255;
         $180 = ((($146) + (($179*12)|0)|0) + 50|0);
         $181 = HEAP8[$180>>0]|0;
         $182 = $181&255;
         $183 = ((($146) + (($179*12)|0)|0) + 44|0);
         $184 = HEAP32[$183>>2]|0;
         $185 = (($146) + 17|0);
         $186 = HEAP8[$185>>0]|0;
         $187 = $186&255;
         $188 = Math_imul($182, $176)|0;
         $189 = (($188) + ($184))|0;
         $190 = (($189) + ($187))|0;
         $191 = (($173) + ($190)|0);
         $257 = $191;
        }
       }
       if ($149) {
        $192 = (($146) + 19|0);
        $193 = HEAP8[$192>>0]|0;
        $194 = ($193&255)<(4);
        if ($194) {
         $212 = $252;$213 = $257;$234 = $253;$236 = 0;$256 = 0;
        } else {
         $195 = (($146) + 92|0);
         $196 = HEAP32[$195>>2]|0;
         $197 = ($196|0)==(0|0);
         if ($197) {
          $212 = $252;$213 = $257;$234 = $253;$236 = 1;$256 = 0;
         } else {
          $198 = (($146) + 16|0);
          $199 = HEAP8[$198>>0]|0;
          $200 = $199&255;
          $201 = ((($146) + (($200*12)|0)|0) + 50|0);
          $202 = HEAP8[$201>>0]|0;
          $203 = $202&255;
          $204 = ((($146) + (($200*12)|0)|0) + 44|0);
          $205 = HEAP32[$204>>2]|0;
          $206 = (($146) + 17|0);
          $207 = HEAP8[$206>>0]|0;
          $208 = $207&255;
          $209 = (($208) + ($205))|0;
          $210 = (($196) + ($209)|0);
          $212 = $252;$213 = $257;$234 = $253;$236 = $203;$256 = $210;
         }
        }
       } else {
        $212 = $252;$213 = $257;$234 = $253;$236 = 0;$256 = 0;
       }
      }
      $211 = ($212|0)==($213|0);
      if (!($211)) {
       $215 = $212;$232 = $256;
       while(1) {
        $214 = (($215) + 2|0);
        $216 = HEAP8[$214>>0]|0;
        $217 = (($215) + 1|0);
        $218 = HEAP8[$217>>0]|0;
        $219 = HEAP8[$215>>0]|0;
        $220 = (($215) + 3|0);
        $221 = HEAP8[$220>>0]|0;
        $222 = $221&255;
        $223 = $222 << 24;
        $224 = $219&255;
        $225 = $224 << 16;
        $226 = $218&255;
        $227 = $226 << 8;
        $228 = $216&255;
        $229 = $227 | $228;
        $230 = $229 | $225;
        $231 = $230 | $223;
        HEAP32[$232>>2] = $231;
        $233 = (($215) + ($234)|0);
        $235 = (($232) + ($236)|0);
        $237 = ($233|0)==($213|0);
        if ($237) {
         break;
        } else {
         $215 = $233;$232 = $235;
        }
       }
      }
     }
     HEAP8[$3>>0] = 1;
    }
    $238 = (($this) + 168|0);
    __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$238,0,0);
    $239 = (($this) + 180|0);
    __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$239,0,0);
    $240 = (($this) + 40|0);
    $241 = HEAP32[$16>>2]|0;
    $242 = (($241) + 4|0);
    $243 = HEAP32[$19>>2]|0;
    $244 = ($242>>>0)>($243>>>0);
    if ($244) {
     __ZN12CachedReader15UpdateReadCacheEPvj($16,$240,4);
     $$pre$i$i$i11 = HEAP32[$240>>2]|0;
     $246 = $$pre$i$i$i11;
     $247 = (_llvm_bswap_i32(($246|0))|0);
     HEAP32[$240>>2] = $247;
     $248 = (($this) + 192|0);
     __ZN17CollisionMeshData8TransferI18StreamedBinaryReadILb1EEEEvRT_R4Mesh($248,$transfer,0);
     STACKTOP = sp;return;
    } else {
     $245 = HEAP32[$241>>2]|0;
     HEAP32[$240>>2] = $245;
     HEAP32[$16>>2] = $242;
     $246 = $245;
     $247 = (_llvm_bswap_i32(($246|0))|0);
     HEAP32[$240>>2] = $247;
     $248 = (($this) + 192|0);
     __ZN17CollisionMeshData8TransferI18StreamedBinaryReadILb1EEEEvRT_R4Mesh($248,$transfer,0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $138 = ___cxa_find_matching_catch()|0;
 $139 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3459,($$byval_copy3|0));
 $140 = __THREW__; __THREW__ = 0;
 $141 = $140&1;
 if ($141) {
  $249 = ___cxa_find_matching_catch(0|0)|0;
  $250 = tempRet0;
  ___clang_call_terminate($249);
  // unreachable;
 } else {
  $$7 = $139;$$78 = $138;
  ___resumeException($$78|0);
  // unreachable;
 }
}
function __ZN17CollisionMeshData8TransferI18StreamedBinaryReadILb1EEEEvRT_R4Mesh($this,$transfer,$mesh) {
 $this = $this|0;
 $transfer = $transfer|0;
 $mesh = $mesh|0;
 var $$0 = 0, $$01 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $bakedConcave = 0, $bakedConvex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $bakedConvex = sp + 16|0;
 $bakedConcave = sp + 32|0;
 $3 = HEAP32[628512>>2]|0;
 HEAP32[$bakedConvex>>2] = 0;
 $4 = (($bakedConvex) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($bakedConvex) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($bakedConvex) + 12|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$bakedConcave>>2] = 0;
 $7 = (($bakedConcave) + 4|0);
 HEAP32[$7>>2] = $3;
 $8 = (($bakedConcave) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($bakedConcave) + 12|0);
 HEAP32[$9>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1702,($transfer|0),($bakedConvex|0),0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 10;
  } else {
   __THREW__ = 0;
   invoke_vi(3377,($transfer|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    label = 10;
   } else {
    __THREW__ = 0;
    invoke_viii(1702,($transfer|0),($bakedConcave|0),0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     label = 10;
    } else {
     __THREW__ = 0;
     invoke_vi(3377,($transfer|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 10;
     } else {
      __THREW__ = 0;
      $18 = (invoke_i(83)|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 10;
      } else {
       $21 = HEAP32[$5>>2]|0;
       $22 = ($21|0)==(0);
       if (!($22)) {
        $23 = HEAP32[$18>>2]|0;
        $24 = (($23) + 60|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = HEAP32[$bakedConvex>>2]|0;
        __THREW__ = 0;
        $27 = (invoke_iiiii($25|0,($18|0),1,($26|0),($21|0))|0);
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         label = 10;
         break;
        }
        $30 = (($this) + 8|0);
        HEAP32[$30>>2] = $27;
       }
       $41 = HEAP32[$8>>2]|0;
       $42 = ($41|0)==(0);
       if (!($42)) {
        $43 = HEAP32[$18>>2]|0;
        $44 = (($43) + 60|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = HEAP32[$bakedConcave>>2]|0;
        __THREW__ = 0;
        $47 = (invoke_iiiii($45|0,($18|0),0,($46|0),($41|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 10;
         break;
        }
        $50 = (($this) + 12|0);
        HEAP32[$50>>2] = $47;
       }
       $51 = HEAP32[$9>>2]|0;
       $52 = ($51|0)>(-1);
       do {
        if ($52) {
         $53 = HEAP32[$bakedConcave>>2]|0;
         $54 = HEAP32[$7>>2]|0;
         HEAP32[$1>>2] = $54;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
         invoke_vii(2591,($53|0),($$byval_copy3|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          $31 = ___cxa_find_matching_catch()|0;
          $32 = tempRet0;
          $$0 = $31;$$01 = $32;
          break L1;
         } else {
          HEAP32[$bakedConcave>>2] = 0;
          break;
         }
        }
       } while(0);
       $57 = HEAP32[$6>>2]|0;
       $58 = ($57|0)>(-1);
       if (!($58)) {
        STACKTOP = sp;return;
       }
       $59 = HEAP32[$bakedConvex>>2]|0;
       $60 = HEAP32[$4>>2]|0;
       HEAP32[$0>>2] = $60;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId($59,$$byval_copy3);
       HEAP32[$bakedConvex>>2] = 0;
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 10) {
   $33 = ___cxa_find_matching_catch()|0;
   $34 = tempRet0;
   $35 = HEAP32[$9>>2]|0;
   $36 = ($35|0)>(-1);
   if ($36) {
    $37 = HEAP32[$bakedConcave>>2]|0;
    $38 = HEAP32[$7>>2]|0;
    HEAP32[$0>>2] = $38;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($37|0),($$byval_copy3|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     $67 = ___cxa_find_matching_catch(0|0)|0;
     $68 = tempRet0;
     ___clang_call_terminate($67);
     // unreachable;
    } else {
     HEAP32[$bakedConcave>>2] = 0;
     $$0 = $33;$$01 = $34;
     break;
    }
   } else {
    $$0 = $33;$$01 = $34;
   }
  }
 } while(0);
 $61 = HEAP32[$6>>2]|0;
 $62 = ($61|0)>(-1);
 if (!($62)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $63 = HEAP32[$bakedConvex>>2]|0;
 $64 = HEAP32[$4>>2]|0;
 HEAP32[$2>>2] = $64;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($63|0),($$byval_copy3|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch(0|0)|0;
  $68 = tempRet0;
  ___clang_call_terminate($67);
  // unreachable;
 }
 HEAP32[$bakedConvex>>2] = 0;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN14CompressedMesh8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($this) + 56|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($1,$transfer);
 $2 = (($this) + 104|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($2,$transfer);
 $3 = (($this) + 180|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($3,$transfer);
 $4 = (($this) + 84|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($4,$transfer);
 $5 = (($this) + 132|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($5,$transfer);
 $6 = (($this) + 152|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($6,$transfer);
 $7 = (($this) + 200|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($7,$transfer);
 $8 = (($this) + 220|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($8,$transfer);
 $9 = (($this) + 240|0);
 $10 = (($transfer) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = (($transfer) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$9,4);
  $$pre$i$i$i = HEAP32[$9>>2]|0;
  $17 = $$pre$i$i$i;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$9>>2] = $18;
  STACKTOP = sp;return;
 } else {
  $16 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $16;
  HEAP32[$10>>2] = $12;
  $17 = $16;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$9>>2] = $18;
  STACKTOP = sp;return;
 }
}
function __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 8|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIhNS2_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$9,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = (($11) + 1|0);
 $13 = HEAP32[$3>>2]|0;
 $14 = ($12>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $15 = HEAP8[$11>>0]|0;
  HEAP8[$10>>0] = $15;
  $16 = HEAP32[$0>>2]|0;
  $17 = (($16) + 1|0);
  HEAP32[$0>>2] = $17;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIhNS2_9allocatorIhEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$20 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$20 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $22 = $$pre$i$i$i4;
 } else {
  $21 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $21;
  HEAP32[$1>>2] = $6;
  $22 = $21;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$size1>>2] = $23;
 __Z14resize_trimmedINSt3__16vectorIhNS0_9allocatorIhEEEEEvRT_j($data,$23);
 $24 = (($data) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$data>>2]|0;
 $27 = ($26|0)==($25|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $33 = $26;
 }
 while(1) {
  $28 = HEAP32[$1>>2]|0;
  $29 = (($28) + 1|0);
  $30 = HEAP32[$7>>2]|0;
  $31 = ($29>>>0)>($30>>>0);
  if ($31) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$33,1);
  } else {
   $32 = HEAP8[$28>>0]|0;
   HEAP8[$33>>0] = $32;
   $34 = HEAP32[$1>>2]|0;
   $35 = (($34) + 1|0);
   HEAP32[$1>>2] = $35;
  }
  $36 = (($33) + 1|0);
  $37 = ($36|0)==($25|0);
  if ($37) {
   break;
  } else {
   $33 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIhNS0_9allocatorIhEEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<($sz>>>0);
 if (!($8)) {
  $50 = ($7>>>0)>($sz>>>0);
  if (!($50)) {
   STACKTOP = sp;return;
  }
  $51 = (($4) + ($sz)|0);
  $52 = ($sz|0)==(0);
  if ($52) {
   $64 = 0;$65 = 0;$67 = 0;$69 = $4;
  } else {
   $53 = ($sz|0)<(0);
   if ($53) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $54 = (__Znwj($sz)|0);
   $56 = $54;$58 = $4;
   while(1) {
    $55 = ($56|0)==(0|0);
    if ($55) {
     $60 = 0;
    } else {
     $57 = HEAP8[$58>>0]|0;
     HEAP8[$56>>0] = $57;
     $60 = $56;
    }
    $59 = (($60) + 1|0);
    $61 = (($58) + 1|0);
    $62 = ($61|0)==($51|0);
    if ($62) {
     break;
    } else {
     $56 = $59;$58 = $61;
    }
   }
   $63 = (($54) + ($sz)|0);
   $$pre21 = HEAP32[$v>>2]|0;
   $64 = $54;$65 = $59;$67 = $63;$69 = $$pre21;
  }
  HEAP32[$v>>2] = $64;
  HEAP32[$2>>2] = $65;
  $66 = (($v) + 8|0);
  HEAP32[$66>>2] = $67;
  $68 = ($69|0)==(0|0);
  if ($68) {
   STACKTOP = sp;return;
  }
  __ZdlPv($69);
  STACKTOP = sp;return;
 }
 $9 = (($v) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($6))|0;
 $13 = ($12|0)==($sz|0);
 if ($13) {
  $49 = (($sz) - ($7))|0;
  __ZNSt3__16vectorIhNS_9allocatorIhEEE8__appendEj($v,$49);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $14 = (($temp) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = (($temp) + 8|0);
 HEAP32[$15>>2] = 0;
 $16 = ($sz|0)==(0);
 if ($16) {
  label = 6;
 } else {
  __THREW__ = 0;
  $17 = (invoke_ii(2988,($sz|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = (($17) + ($sz)|0);
   HEAP32[$temp>>2] = $17;
   HEAP32[$14>>2] = $17;
   HEAP32[$15>>2] = $20;
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$0>>2] = $4;
   HEAP32[$1>>2] = $3;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1703,($temp|0),($$byval_copy|0),($$byval_copy1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $23 = HEAP32[$14>>2]|0;
    $24 = HEAP32[$temp>>2]|0;
    $25 = $23;
    $26 = $24;
    $27 = (($25) - ($26))|0;
    $28 = ($27>>>0)<($sz>>>0);
    if ($28) {
     $29 = (($sz) - ($27))|0;
     __THREW__ = 0;
     invoke_vii(2676,($temp|0),($29|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     $$pre22 = HEAP32[$temp>>2]|0;
     $$pre23 = HEAP32[$14>>2]|0;
     $36 = $$pre22;$38 = $$pre23;
    } else {
     $32 = ($27>>>0)>($sz>>>0);
     if ($32) {
      $33 = (($24) + ($sz)|0);
      $34 = ($23|0)==($33|0);
      if ($34) {
       $36 = $24;$38 = $23;
      } else {
       HEAP32[$14>>2] = $33;
       $36 = $24;$38 = $33;
      }
     } else {
      $36 = $24;$38 = $23;
     }
    }
    $35 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $35;
    HEAP32[$v>>2] = $36;
    $37 = HEAP32[$2>>2]|0;
    HEAP32[$14>>2] = $37;
    HEAP32[$2>>2] = $38;
    $39 = HEAP32[$15>>2]|0;
    $40 = HEAP32[$9>>2]|0;
    HEAP32[$15>>2] = $40;
    HEAP32[$9>>2] = $39;
    $41 = ($35|0)==(0|0);
    if ($41) {
     STACKTOP = sp;return;
    }
    $42 = ($37|0)==($35|0);
    if (!($42)) {
     HEAP32[$14>>2] = $35;
    }
    __ZdlPv($35);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $43 = ___cxa_find_matching_catch()|0;
 $44 = tempRet0;
 $45 = HEAP32[$temp>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  ___resumeException($43|0);
  // unreachable;
 }
 $47 = HEAP32[$14>>2]|0;
 $48 = ($47|0)==($45|0);
 if (!($48)) {
  HEAP32[$14>>2] = $45;
 }
 __ZdlPv($45);
 ___resumeException($43|0);
 // unreachable;
}
function __ZNSt3__16vectorIhNS_9allocatorIhEEE6assignINS_11__wrap_iterIPhEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$pre$i8 = 0, $$pre1$i = 0, $$pre1$i10 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$this>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = ($4>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($9))|0;
  $16 = ($4>>>0)>($15>>>0);
  if (!($16)) {
   $27 = $1;
   $28 = (($27) - ($3))|0;
   _memmove(($7|0),($0|0),($28|0))|0;
   $29 = (($7) + ($28)|0);
   $30 = HEAP32[$12>>2]|0;
   $31 = ($30|0)==($29|0);
   if ($31) {
    STACKTOP = sp;return;
   }
   HEAP32[$12>>2] = $29;
   STACKTOP = sp;return;
  }
  $17 = (($0) + ($15)|0);
  _memmove(($7|0),($0|0),($15|0))|0;
  $18 = ($17|0)==($1|0);
  if ($18) {
   STACKTOP = sp;return;
  }
  $$pre$i8 = HEAP32[$12>>2]|0;
  $20 = $$pre$i8;$22 = $17;
  while(1) {
   $19 = ($20|0)==(0|0);
   if ($19) {
    $24 = 0;
   } else {
    $21 = HEAP8[$22>>0]|0;
    HEAP8[$20>>0] = $21;
    $$pre1$i10 = HEAP32[$12>>2]|0;
    $24 = $$pre1$i10;
   }
   $23 = (($24) + 1|0);
   HEAP32[$12>>2] = $23;
   $25 = (($22) + 1|0);
   $26 = ($25|0)==($1|0);
   if ($26) {
    break;
   } else {
    $20 = $23;$22 = $25;
   }
  }
  STACKTOP = sp;return;
 }
 $32 = ($7|0)==(0|0);
 if ($32) {
  $38 = $6;
 } else {
  $33 = (($this) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==($7|0);
  if (!($35)) {
   HEAP32[$33>>2] = $7;
  }
  __ZdlPv($7);
  HEAP32[$5>>2] = 0;
  HEAP32[$33>>2] = 0;
  HEAP32[$this>>2] = 0;
  $38 = 0;
 }
 $36 = ($4|0)<(0);
 if ($36) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $37 = ($38>>>0)<((1073741823)>>>0);
 if ($37) {
  $39 = $38;
  $40 = $39 << 1;
  $41 = ($40>>>0)<($4>>>0);
  $42 = $41 ? $4 : $40;
  $43 = ($42|0)<(0);
  if ($43) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i31 = $42;
  }
 } else {
  $$0$i31 = 2147483647;
 }
 $44 = (__Znwj($$0$i31)|0);
 $45 = (($this) + 4|0);
 HEAP32[$45>>2] = $44;
 HEAP32[$this>>2] = $44;
 $46 = (($44) + ($$0$i31)|0);
 HEAP32[$5>>2] = $46;
 $47 = ($0|0)==($1|0);
 if ($47) {
  STACKTOP = sp;return;
 } else {
  $49 = $44;$51 = $0;
 }
 while(1) {
  $48 = ($49|0)==(0|0);
  if ($48) {
   $53 = 0;
  } else {
   $50 = HEAP8[$51>>0]|0;
   HEAP8[$49>>0] = $50;
   $$pre1$i = HEAP32[$45>>2]|0;
   $53 = $$pre1$i;
  }
  $52 = (($53) + 1|0);
  HEAP32[$45>>2] = $52;
  $54 = (($51) + 1|0);
  $55 = ($54|0)==($1|0);
  if ($55) {
   break;
  } else {
   $49 = $52;$51 = $54;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIhNS_9allocatorIhEEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  $$0$i = $__n;$9 = $3;
  while(1) {
   $8 = ($9|0)==(0|0);
   if ($8) {
    $11 = 0;
   } else {
    HEAP8[$9>>0] = 0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $11 = $$pre1$i;
   }
   $10 = (($11) + 1|0);
   HEAP32[$2>>2] = $10;
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$9 = $10;
   }
  }
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = (($16) + ($__n))|0;
 $18 = ($17|0)<(0);
 if ($18) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $19 = (($4) - ($15))|0;
 $20 = ($19>>>0)<(1073741823);
 if ($20) {
  $21 = $19 << 1;
  $22 = ($21>>>0)<($17>>>0);
  $23 = $22 ? $17 : $21;
  $24 = ($23|0)==(0);
  if ($24) {
   $$0$i57 = 0;$27 = 0;
  } else {
   $$0$i56 = $23;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $25 = (__Znwj($$0$i56)|0);
  $$0$i57 = $$0$i56;$27 = $25;
 }
 $26 = (($27) + ($16)|0);
 $$0$i2 = $__n;$29 = $26;
 while(1) {
  $28 = ($29|0)==(0|0);
  if ($28) {
   $31 = 0;
  } else {
   HEAP8[$29>>0] = 0;
   $31 = $29;
  }
  $30 = (($31) + 1|0);
  $32 = (($$0$i2) + -1)|0;
  $33 = ($32|0)==(0);
  if ($33) {
   break;
  } else {
   $$0$i2 = $32;$29 = $30;
  }
 }
 $34 = (($27) + ($$0$i57)|0);
 $35 = HEAP32[$this>>2]|0;
 $36 = HEAP32[$2>>2]|0;
 $37 = $36;
 $38 = $35;
 $39 = (($37) - ($38))|0;
 $$sum = (($16) - ($39))|0;
 $40 = (($27) + ($$sum)|0);
 _memcpy(($40|0),($35|0),($39|0))|0;
 HEAP32[$this>>2] = $40;
 HEAP32[$2>>2] = $30;
 HEAP32[$0>>2] = $34;
 $41 = ($35|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 __ZdlPv($35);
 STACKTOP = sp;return;
}
function __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$i$i5Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre7;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $9;$16 = $$pre$i$i$i1;$20 = $$pre8;$22 = $$pre9;
 } else {
  $14 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = (HEAPF32[tempDoublePtr>>2]=$14,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $9;$16 = $15;$20 = $10;$22 = $13;
 }
 $17 = (_llvm_bswap_i32(($16|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $17;
 $18 = (($this) + 8|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)>($22>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$18,4);
  $$pre$i$i$i4 = HEAP32[$18>>2]|0;
  $$pre$phi$i$i$i5Z2D = $18;$25 = $$pre$i$i$i4;
 } else {
  $23 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$18>>2] = $23;
  HEAP32[$0>>2] = $19;
  $24 = (HEAPF32[tempDoublePtr>>2]=$23,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i5Z2D = $18;$25 = $24;
 }
 $26 = (_llvm_bswap_i32(($25|0))|0);
 HEAP32[$$pre$phi$i$i$i5Z2D>>2] = $26;
 $27 = (($this) + 16|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIhNS2_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$27,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $28 = (($this) + 12|0);
 $29 = HEAP32[$0>>2]|0;
 $30 = (($29) + 1|0);
 $31 = HEAP32[$3>>2]|0;
 $32 = ($30>>>0)>($31>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $33 = HEAP8[$29>>0]|0;
  HEAP8[$28>>0] = $33;
  $34 = HEAP32[$0>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$0>>2] = $35;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI13dynamic_arrayI8Vector4fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($data) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = $rs << 4;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,4,$$byval_copy1,0,585592,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = $rs << 4;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,4,$$byval_copy1,0,585592,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 << 4;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + ($rs<<4)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + ($24<<4)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$01$i$i+12>>2]=HEAP32[$1+12>>2]|0;
  }
  $31 = (($$01$i$i) + 16|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI8Vector2fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 3;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,585592,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 3;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,585592,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 3;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<3)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<3)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   $30 = $$01$i$i;
   $31 = $30;
   HEAP32[$31>>2] = 0;
   $32 = (($30) + 4)|0;
   $33 = $32;
   HEAP32[$33>>2] = 0;
  }
  $34 = (($$01$i$i) + 8|0);
  $35 = ($34|0)==($25|0);
  if ($35) {
   break;
  } else {
   $$01$i$i = $34;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($5) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $34 = $$pre$i$i$i4;
  } else {
   $33 = HEAP32[$6>>2]|0;
   HEAP32[$size1>>2] = $33;
   HEAP32[$2>>2] = $7;
   $34 = $33;
  }
  $35 = (_llvm_bswap_i32(($34|0))|0);
  HEAP32[$size1>>2] = $35;
  $36 = (($this) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$data>>2]|0;
  $39 = ($38|0)==(0|0);
  if ($39) {
   $40 = (($data) + 4|0);
   HEAP32[$40>>2] = $37;
  }
  ;HEAP32[$$byval_copy+0>>2]=0|0;HEAP32[$$byval_copy+4>>2]=0|0;HEAP32[$$byval_copy+8>>2]=0|0;HEAP32[$$byval_copy+12>>2]=0|0;HEAP32[$$byval_copy+16>>2]=0|0;HEAP32[$$byval_copy+20>>2]=0|0;HEAP32[$$byval_copy+24>>2]=0|0;HEAP32[$$byval_copy+28>>2]=0|0;
  __ZN13dynamic_arrayI13BoneInfluenceLj16EE18resize_initializedEjRKS0_b($data,$35,$$byval_copy,0);
  $41 = HEAP32[$data>>2]|0;
  $42 = (($data) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + ($43<<5)|0);
  $45 = ($43|0)==(0);
  if ($45) {
   STACKTOP = sp;return;
  } else {
   $i$06 = $41;
  }
  while(1) {
   __ZN13BoneInfluence8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$06,$this);
   $46 = (($i$06) + 32|0);
   $47 = ($46|0)==($44|0);
   if ($47) {
    break;
   } else {
    $i$06 = $46;
   }
  }
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre7 = HEAP32[$8>>2]|0;
  $12 = $$pre$i$i$i;$15 = $$pre;$17 = $$pre7;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$size>>2] = $11;
  HEAP32[$2>>2] = $7;
  $12 = $11;$15 = $7;$17 = $9;
 }
 $13 = (_llvm_bswap_i32(($12|0))|0);
 HEAP32[$size>>2] = $13;
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $19 = $$pre$i$i$i1;$22 = $$pre8;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$offset>>2] = $18;
  HEAP32[$2>>2] = $14;
  $19 = $18;$22 = $13;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$offset>>2] = $20;
 $21 = $22 << 5;
 $23 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$20,$21)|0);
 $24 = (($data) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if ($26) {
  $27 = HEAP32[$data>>2]|0;
  $28 = (($data) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$1>>2] = $29;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy);
  HEAP32[$data>>2] = 0;
 }
 $30 = $21 >> 5;
 $31 = (($data) + 8|0);
 HEAP32[$31>>2] = $30;
 $32 = $30 | -2147483648;
 HEAP32[$24>>2] = $32;
 HEAP32[$data>>2] = $23;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13BoneInfluence8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i17 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i21 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0;
 var $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre23 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $this;$12 = $$pre;$14 = $$pre23;$8 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i3 = HEAP32[$10>>2]|0;
  $$pre24 = HEAP32[$0>>2]|0;
  $$pre25 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $10;$17 = $$pre$i$i$i3;$21 = $$pre24;$23 = $$pre25;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i8 = HEAP32[$19>>2]|0;
  $$pre26 = HEAP32[$0>>2]|0;
  $$pre27 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $19;$26 = $$pre$i$i$i8;$30 = $$pre26;$32 = $$pre27;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i13 = HEAP32[$28>>2]|0;
  $$pre28 = HEAP32[$0>>2]|0;
  $$pre29 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $28;$35 = $$pre$i$i$i13;$39 = $$pre28;$41 = $$pre29;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $28;$35 = $34;$39 = $29;$41 = $32;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $36;
 $37 = (($this) + 16|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre$i$i$i16 = HEAP32[$37>>2]|0;
  $$pre30 = HEAP32[$0>>2]|0;
  $$pre31 = HEAP32[$3>>2]|0;
  $43 = $$pre$i$i$i16;$47 = $$pre30;$49 = $$pre31;
 } else {
  $42 = HEAP32[$39>>2]|0;
  HEAP32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $43 = $42;$47 = $38;$49 = $41;
 }
 $44 = (_llvm_bswap_i32(($43|0))|0);
 HEAP32[$37>>2] = $44;
 $45 = (($this) + 20|0);
 $46 = (($47) + 4|0);
 $48 = ($46>>>0)>($49>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$45,4);
  $$pre$i$i$i17 = HEAP32[$45>>2]|0;
  $$pre32 = HEAP32[$0>>2]|0;
  $$pre33 = HEAP32[$3>>2]|0;
  $51 = $$pre$i$i$i17;$55 = $$pre32;$57 = $$pre33;
 } else {
  $50 = HEAP32[$47>>2]|0;
  HEAP32[$45>>2] = $50;
  HEAP32[$0>>2] = $46;
  $51 = $50;$55 = $46;$57 = $49;
 }
 $52 = (_llvm_bswap_i32(($51|0))|0);
 HEAP32[$45>>2] = $52;
 $53 = (($this) + 24|0);
 $54 = (($55) + 4|0);
 $56 = ($54>>>0)>($57>>>0);
 if ($56) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$53,4);
  $$pre$i$i$i19 = HEAP32[$53>>2]|0;
  $$pre34 = HEAP32[$0>>2]|0;
  $$pre35 = HEAP32[$3>>2]|0;
  $59 = $$pre$i$i$i19;$63 = $$pre34;$65 = $$pre35;
 } else {
  $58 = HEAP32[$55>>2]|0;
  HEAP32[$53>>2] = $58;
  HEAP32[$0>>2] = $54;
  $59 = $58;$63 = $54;$65 = $57;
 }
 $60 = (_llvm_bswap_i32(($59|0))|0);
 HEAP32[$53>>2] = $60;
 $61 = (($this) + 28|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)>($65>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$61,4);
  $$pre$i$i$i21 = HEAP32[$61>>2]|0;
  $67 = $$pre$i$i$i21;
  $68 = (_llvm_bswap_i32(($67|0))|0);
  HEAP32[$61>>2] = $68;
  STACKTOP = sp;return;
 } else {
  $66 = HEAP32[$63>>2]|0;
  HEAP32[$61>>2] = $66;
  HEAP32[$0>>2] = $62;
  $67 = $66;
  $68 = (_llvm_bswap_i32(($67|0))|0);
  HEAP32[$61>>2] = $68;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$20 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$20 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $22 = $$pre$i$i$i4;
 } else {
  $21 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $21;
  HEAP32[$1>>2] = $6;
  $22 = $21;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$size1>>2] = $23;
 __Z14resize_trimmedINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEvRT_j($data,$23);
 $24 = (($data) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$data>>2]|0;
 $27 = ($26|0)==($25|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $33 = $26;
 }
 while(1) {
  $28 = HEAP32[$1>>2]|0;
  $29 = (($28) + 1|0);
  $30 = HEAP32[$7>>2]|0;
  $31 = ($29>>>0)>($30>>>0);
  if ($31) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$33,1);
  } else {
   $32 = HEAP8[$28>>0]|0;
   HEAP8[$33>>0] = $32;
   $34 = HEAP32[$1>>2]|0;
   $35 = (($34) + 1|0);
   HEAP32[$1>>2] = $35;
  }
  $36 = (($33) + 1|0);
  $37 = ($36|0)==($25|0);
  if ($37) {
   break;
  } else {
   $33 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre20 = 0, $$pre21 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $72 = ($10>>>0)>($sz>>>0);
  if (!($72)) {
   STACKTOP = sp;return;
  }
  $73 = (($7) + ($sz)|0);
  $74 = ($sz|0)==(0);
  do {
   if ($74) {
    $90 = 0;$91 = 0;$93 = 0;$95 = $7;
   } else {
    $75 = ($sz|0)<(0);
    if ($75) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if (!($77)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 8;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $78 = (invoke_iiiiiii(102,($sz|0),16,($$byval_copy7|0),0,(585592|0),79)|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      $82 = $78;$84 = $7;
      while(1) {
       $81 = ($82|0)==(0|0);
       if ($81) {
        $86 = 0;
       } else {
        $83 = HEAP8[$84>>0]|0;
        HEAP8[$82>>0] = $83;
        $86 = $82;
       }
       $85 = (($86) + 1|0);
       $87 = (($84) + 1|0);
       $88 = ($87|0)==($73|0);
       if ($88) {
        break;
       } else {
        $82 = $85;$84 = $87;
       }
      }
      $89 = (($78) + ($sz)|0);
      $$pre = HEAP32[$v>>2]|0;
      $90 = $78;$91 = $85;$93 = $89;$95 = $$pre;
      break;
     }
    }
    $100 = ___cxa_find_matching_catch()|0;
    $101 = tempRet0;
    $$0 = $101;$$01 = $100;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $90;
  HEAP32[$5>>2] = $91;
  $92 = (($v) + 8|0);
  HEAP32[$92>>2] = $93;
  $94 = ($95|0)==(0|0);
  if ($94) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 8;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($95|0),($$byval_copy7|0));
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   $98 = ___cxa_find_matching_catch()|0;
   $99 = tempRet0;
   ___cxa_call_unexpected(($98|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($9))|0;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $71 = (($sz) - ($10))|0;
  __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE8__appendEj($v,$71);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = ($sz|0)==(0);
 if ($19) {
  label = 8;
 } else {
  HEAP32[$0>>2] = 8;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (invoke_iiiiiii(102,($sz|0),16,($$byval_copy7|0),0,(585592|0),79)|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$17>>2]|0;
   $phitmp = $$pre1$i;
   $23 = (($20) + ($sz)|0);
   $24 = $$pre$i;
   $25 = (($phitmp) - ($24))|0;
   $$sum$i = (0 - ($25))|0;
   $26 = (($20) + ($$sum$i)|0);
   _memcpy(($26|0),($$pre$i|0),($25|0))|0;
   $27 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $26;
   HEAP32[$17>>2] = $20;
   HEAP32[$18>>2] = $23;
   $28 = ($27|0)==(0|0);
   if ($28) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 8;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy7|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $33 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $33;
   $34 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $34;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1704,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    $37 = HEAP32[$17>>2]|0;
    $38 = HEAP32[$temp>>2]|0;
    $39 = $37;
    $40 = $38;
    $41 = (($39) - ($40))|0;
    $42 = ($41>>>0)<($sz>>>0);
    if ($42) {
     $43 = (($sz) - ($41))|0;
     __THREW__ = 0;
     invoke_vii(2677,($temp|0),($43|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     $$pre20 = HEAP32[$temp>>2]|0;
     $$pre21 = HEAP32[$17>>2]|0;
     $50 = $$pre20;$52 = $$pre21;
    } else {
     $46 = ($41>>>0)>($sz>>>0);
     if ($46) {
      $47 = (($38) + ($sz)|0);
      $48 = ($37|0)==($47|0);
      if ($48) {
       $50 = $38;$52 = $37;
      } else {
       HEAP32[$17>>2] = $47;
       $50 = $38;$52 = $47;
      }
     } else {
      $50 = $38;$52 = $37;
     }
    }
    $49 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $49;
    HEAP32[$v>>2] = $50;
    $51 = HEAP32[$5>>2]|0;
    HEAP32[$17>>2] = $51;
    HEAP32[$5>>2] = $52;
    $53 = HEAP32[$18>>2]|0;
    $54 = HEAP32[$12>>2]|0;
    HEAP32[$18>>2] = $54;
    HEAP32[$12>>2] = $53;
    $55 = ($49|0)==(0|0);
    if ($55) {
     STACKTOP = sp;return;
    }
    $56 = ($51|0)==($49|0);
    if (!($56)) {
     HEAP32[$17>>2] = $49;
    }
    HEAP32[$$byval_copy2>>2] = 8;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($49|0),($$byval_copy7|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $59 = ___cxa_find_matching_catch()|0;
     $60 = tempRet0;
     ___cxa_call_unexpected(($59|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $61 = ___cxa_find_matching_catch()|0;
 $62 = tempRet0;
 $63 = HEAP32[$temp>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  $$0 = $62;$$01 = $61;
  ___resumeException($$01|0);
  // unreachable;
 }
 $65 = HEAP32[$17>>2]|0;
 $66 = ($65|0)==($63|0);
 if (!($66)) {
  HEAP32[$17>>2] = $63;
 }
 HEAP32[$$byval_copy2>>2] = 8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($63|0),($$byval_copy7|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  ___cxa_call_unexpected(($69|0));
  // unreachable;
 } else {
  $$0 = $62;$$01 = $61;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE6assignINS_11__wrap_iterIPhEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$byval_copy1 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = ($5>>>0)>($11>>>0);
 if (!($12)) {
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14;
  $16 = (($15) - ($10))|0;
  $17 = ($5>>>0)>($16>>>0);
  if (!($17)) {
   $28 = $2;
   $29 = (($28) - ($4))|0;
   _memmove(($8|0),($1|0),($29|0))|0;
   $30 = (($8) + ($29)|0);
   $31 = HEAP32[$13>>2]|0;
   $32 = ($31|0)==($30|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   HEAP32[$13>>2] = $30;
   STACKTOP = sp;return;
  }
  $18 = (($1) + ($16)|0);
  _memmove(($8|0),($1|0),($16|0))|0;
  $19 = ($18|0)==($2|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$13>>2]|0;
  $21 = $$pre$i12;$23 = $18;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $25 = 0;
   } else {
    $22 = HEAP8[$23>>0]|0;
    HEAP8[$21>>0] = $22;
    $$pre1$i14 = HEAP32[$13>>2]|0;
    $25 = $$pre1$i14;
   }
   $24 = (($25) + 1|0);
   HEAP32[$13>>2] = $24;
   $26 = (($23) + 1|0);
   $27 = ($26|0)==($2|0);
   if ($27) {
    break;
   } else {
    $21 = $24;$23 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 $33 = ($8|0)==(0|0);
 do {
  if ($33) {
   $43 = $7;
  } else {
   $34 = (($this) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($8|0);
   if (!($36)) {
    HEAP32[$34>>2] = $8;
   }
   HEAP32[$0>>2] = 8;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy1|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    ___cxa_call_unexpected(($39|0));
    // unreachable;
   } else {
    HEAP32[$6>>2] = 0;
    HEAP32[$34>>2] = 0;
    HEAP32[$this>>2] = 0;
    $43 = 0;
    break;
   }
  }
 } while(0);
 $41 = ($5|0)<(0);
 if ($41) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $42 = ($43>>>0)<((1073741823)>>>0);
 if ($42) {
  $44 = $43;
  $45 = $44 << 1;
  $46 = ($45>>>0)<($5>>>0);
  $47 = $46 ? $5 : $45;
  $48 = ($47|0)<(0);
  if ($48) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i31 = $47;
  }
 } else {
  $$0$i31 = 2147483647;
 }
 HEAP32[$0>>2] = 8;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $49 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i31,16,$$byval_copy1,0,585592,79)|0);
 $50 = (($this) + 4|0);
 HEAP32[$50>>2] = $49;
 HEAP32[$this>>2] = $49;
 $51 = (($49) + ($$0$i31)|0);
 HEAP32[$6>>2] = $51;
 $52 = ($1|0)==($2|0);
 if ($52) {
  STACKTOP = sp;return;
 } else {
  $54 = $49;$56 = $1;
 }
 while(1) {
  $53 = ($54|0)==(0|0);
  if ($53) {
   $58 = 0;
  } else {
   $55 = HEAP8[$56>>0]|0;
   HEAP8[$54>>0] = $55;
   $$pre1$i = HEAP32[$50>>2]|0;
   $58 = $$pre1$i;
  }
  $57 = (($58) + 1|0);
  HEAP32[$50>>2] = $57;
  $59 = (($56) + 1|0);
  $60 = ($59|0)==($2|0);
  if ($60) {
   break;
  } else {
   $54 = $57;$56 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i5;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayIjLj4EEE19ResizeSTLStyleArrayERS1_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<2)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$06 = $39;
  }
  while(1) {
   $44 = HEAP32[$3>>2]|0;
   $45 = (($44) + 4|0);
   $46 = HEAP32[$9>>2]|0;
   $47 = ($45>>>0)>($46>>>0);
   if ($47) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$06,4);
    $$pre$i$i$i = HEAP32[$i$06>>2]|0;
    $49 = $$pre$i$i$i;
   } else {
    $48 = HEAP32[$44>>2]|0;
    HEAP32[$i$06>>2] = $48;
    HEAP32[$3>>2] = $45;
    $49 = $48;
   }
   $50 = (_llvm_bswap_i32(($49|0))|0);
   HEAP32[$i$06>>2] = $50;
   $51 = (($i$06) + 4|0);
   $52 = ($51|0)==($42|0);
   if ($52) {
    break;
   } else {
    $i$06 = $51;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre7 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i1;$16 = $$pre;$18 = $$pre7;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i3 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i3;$23 = $$pre8;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = $23 << 2;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = $22 >> 2;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI13dynamic_arrayIjLj4EEE19ResizeSTLStyleArrayERS1_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 2;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,585592,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 2;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,585592,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 2;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<2)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<2)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   HEAP32[$$01$i$i>>2] = 0;
  }
  $30 = (($$01$i$i) + 4|0);
  $31 = ($30|0)==($25|0);
  if ($31) {
   break;
  } else {
   $$01$i$i = $30;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI10Matrix4x4fLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI10Matrix4x4fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<6)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN10Matrix4x4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 64|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = $23 << 6;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = $22 >> 6;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI10Matrix4x4fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$sroa$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 72|0;
 $0 = sp;
 $$sroa$0 = sp + 8|0;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 6;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,585592,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 6;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,585592,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 6;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<6)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<6)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   dest=$$01$i$i+0|0; src=$$sroa$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $30 = (($$01$i$i) + 64|0);
  $31 = ($30|0)==($25|0);
  if ($31) {
   break;
  } else {
   $$01$i$i = $30;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i28 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i33 = 0, $$pre$i$i$i38 = 0, $$pre$i$i$i43 = 0, $$pre$i$i$i48 = 0, $$pre$i$i$i53 = 0, $$pre$i$i$i58 = 0, $$pre$i$i$i63 = 0, $$pre$i$i$i68 = 0, $$pre$i$i$i73 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i19Z2D = 0, $$pre$phi$i$i$i24Z2D = 0;
 var $$pre$phi$i$i$i29Z2D = 0, $$pre$phi$i$i$i34Z2D = 0, $$pre$phi$i$i$i39Z2D = 0, $$pre$phi$i$i$i44Z2D = 0, $$pre$phi$i$i$i49Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i54Z2D = 0, $$pre$phi$i$i$i59Z2D = 0, $$pre$phi$i$i$i64Z2D = 0, $$pre$phi$i$i$i69Z2D = 0, $$pre$phi$i$i$i74Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre100 = 0, $$pre101 = 0, $$pre102 = 0, $$pre103 = 0, $$pre104 = 0, $$pre76 = 0, $$pre77 = 0;
 var $$pre78 = 0, $$pre79 = 0, $$pre80 = 0, $$pre81 = 0, $$pre82 = 0, $$pre83 = 0, $$pre84 = 0, $$pre85 = 0, $$pre86 = 0, $$pre87 = 0, $$pre88 = 0, $$pre89 = 0, $$pre90 = 0, $$pre91 = 0, $$pre92 = 0, $$pre93 = 0, $$pre94 = 0, $$pre95 = 0, $$pre96 = 0, $$pre97 = 0;
 var $$pre98 = 0, $$pre99 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i3 = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre76 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $this;$12 = $$pre;$14 = $$pre76;$8 = $$pre$i$i$i3;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $9;
 $10 = (($this) + 16|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i13 = HEAP32[$10>>2]|0;
  $$pre77 = HEAP32[$0>>2]|0;
  $$pre78 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $10;$17 = $$pre$i$i$i13;$21 = $$pre77;$23 = $$pre78;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $18;
 $19 = (($this) + 32|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i23 = HEAP32[$19>>2]|0;
  $$pre79 = HEAP32[$0>>2]|0;
  $$pre80 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i24Z2D = $19;$26 = $$pre$i$i$i23;$30 = $$pre79;$32 = $$pre80;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i24Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i24Z2D>>2] = $27;
 $28 = (($this) + 48|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i33 = HEAP32[$28>>2]|0;
  $$pre81 = HEAP32[$0>>2]|0;
  $$pre82 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i34Z2D = $28;$35 = $$pre$i$i$i33;$39 = $$pre81;$41 = $$pre82;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i34Z2D = $28;$35 = $34;$39 = $29;$41 = $32;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$$pre$phi$i$i$i34Z2D>>2] = $36;
 $37 = (($this) + 4|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre$i$i$i43 = HEAP32[$37>>2]|0;
  $$pre83 = HEAP32[$0>>2]|0;
  $$pre84 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i44Z2D = $37;$44 = $$pre$i$i$i43;$48 = $$pre83;$50 = $$pre84;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $43 = (HEAPF32[tempDoublePtr>>2]=$42,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i44Z2D = $37;$44 = $43;$48 = $38;$50 = $41;
 }
 $45 = (_llvm_bswap_i32(($44|0))|0);
 HEAP32[$$pre$phi$i$i$i44Z2D>>2] = $45;
 $46 = (($this) + 20|0);
 $47 = (($48) + 4|0);
 $49 = ($47>>>0)>($50>>>0);
 if ($49) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$46,4);
  $$pre$i$i$i53 = HEAP32[$46>>2]|0;
  $$pre85 = HEAP32[$0>>2]|0;
  $$pre86 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i54Z2D = $46;$53 = $$pre$i$i$i53;$57 = $$pre85;$59 = $$pre86;
 } else {
  $51 = Math_fround(HEAPF32[$48>>2]);
  HEAPF32[$46>>2] = $51;
  HEAP32[$0>>2] = $47;
  $52 = (HEAPF32[tempDoublePtr>>2]=$51,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i54Z2D = $46;$53 = $52;$57 = $47;$59 = $50;
 }
 $54 = (_llvm_bswap_i32(($53|0))|0);
 HEAP32[$$pre$phi$i$i$i54Z2D>>2] = $54;
 $55 = (($this) + 36|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)>($59>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$55,4);
  $$pre$i$i$i63 = HEAP32[$55>>2]|0;
  $$pre87 = HEAP32[$0>>2]|0;
  $$pre88 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i64Z2D = $55;$62 = $$pre$i$i$i63;$66 = $$pre87;$68 = $$pre88;
 } else {
  $60 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$55>>2] = $60;
  HEAP32[$0>>2] = $56;
  $61 = (HEAPF32[tempDoublePtr>>2]=$60,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i64Z2D = $55;$62 = $61;$66 = $56;$68 = $59;
 }
 $63 = (_llvm_bswap_i32(($62|0))|0);
 HEAP32[$$pre$phi$i$i$i64Z2D>>2] = $63;
 $64 = (($this) + 52|0);
 $65 = (($66) + 4|0);
 $67 = ($65>>>0)>($68>>>0);
 if ($67) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$64,4);
  $$pre$i$i$i73 = HEAP32[$64>>2]|0;
  $$pre89 = HEAP32[$0>>2]|0;
  $$pre90 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i74Z2D = $64;$71 = $$pre$i$i$i73;$75 = $$pre89;$77 = $$pre90;
 } else {
  $69 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$64>>2] = $69;
  HEAP32[$0>>2] = $65;
  $70 = (HEAPF32[tempDoublePtr>>2]=$69,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i74Z2D = $64;$71 = $70;$75 = $65;$77 = $68;
 }
 $72 = (_llvm_bswap_i32(($71|0))|0);
 HEAP32[$$pre$phi$i$i$i74Z2D>>2] = $72;
 $73 = (($this) + 8|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)>($77>>>0);
 if ($76) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$73,4);
  $$pre$i$i$i68 = HEAP32[$73>>2]|0;
  $$pre91 = HEAP32[$0>>2]|0;
  $$pre92 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i69Z2D = $73;$80 = $$pre$i$i$i68;$84 = $$pre91;$86 = $$pre92;
 } else {
  $78 = Math_fround(HEAPF32[$75>>2]);
  HEAPF32[$73>>2] = $78;
  HEAP32[$0>>2] = $74;
  $79 = (HEAPF32[tempDoublePtr>>2]=$78,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i69Z2D = $73;$80 = $79;$84 = $74;$86 = $77;
 }
 $81 = (_llvm_bswap_i32(($80|0))|0);
 HEAP32[$$pre$phi$i$i$i69Z2D>>2] = $81;
 $82 = (($this) + 24|0);
 $83 = (($84) + 4|0);
 $85 = ($83>>>0)>($86>>>0);
 if ($85) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$82,4);
  $$pre$i$i$i58 = HEAP32[$82>>2]|0;
  $$pre93 = HEAP32[$0>>2]|0;
  $$pre94 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i59Z2D = $82;$89 = $$pre$i$i$i58;$93 = $$pre93;$95 = $$pre94;
 } else {
  $87 = Math_fround(HEAPF32[$84>>2]);
  HEAPF32[$82>>2] = $87;
  HEAP32[$0>>2] = $83;
  $88 = (HEAPF32[tempDoublePtr>>2]=$87,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i59Z2D = $82;$89 = $88;$93 = $83;$95 = $86;
 }
 $90 = (_llvm_bswap_i32(($89|0))|0);
 HEAP32[$$pre$phi$i$i$i59Z2D>>2] = $90;
 $91 = (($this) + 40|0);
 $92 = (($93) + 4|0);
 $94 = ($92>>>0)>($95>>>0);
 if ($94) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$91,4);
  $$pre$i$i$i48 = HEAP32[$91>>2]|0;
  $$pre95 = HEAP32[$0>>2]|0;
  $$pre96 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i49Z2D = $91;$102 = $$pre95;$104 = $$pre96;$98 = $$pre$i$i$i48;
 } else {
  $96 = Math_fround(HEAPF32[$93>>2]);
  HEAPF32[$91>>2] = $96;
  HEAP32[$0>>2] = $92;
  $97 = (HEAPF32[tempDoublePtr>>2]=$96,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i49Z2D = $91;$102 = $92;$104 = $95;$98 = $97;
 }
 $99 = (_llvm_bswap_i32(($98|0))|0);
 HEAP32[$$pre$phi$i$i$i49Z2D>>2] = $99;
 $100 = (($this) + 56|0);
 $101 = (($102) + 4|0);
 $103 = ($101>>>0)>($104>>>0);
 if ($103) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$100,4);
  $$pre$i$i$i38 = HEAP32[$100>>2]|0;
  $$pre97 = HEAP32[$0>>2]|0;
  $$pre98 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i39Z2D = $100;$107 = $$pre$i$i$i38;$111 = $$pre97;$113 = $$pre98;
 } else {
  $105 = Math_fround(HEAPF32[$102>>2]);
  HEAPF32[$100>>2] = $105;
  HEAP32[$0>>2] = $101;
  $106 = (HEAPF32[tempDoublePtr>>2]=$105,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i39Z2D = $100;$107 = $106;$111 = $101;$113 = $104;
 }
 $108 = (_llvm_bswap_i32(($107|0))|0);
 HEAP32[$$pre$phi$i$i$i39Z2D>>2] = $108;
 $109 = (($this) + 12|0);
 $110 = (($111) + 4|0);
 $112 = ($110>>>0)>($113>>>0);
 if ($112) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$109,4);
  $$pre$i$i$i28 = HEAP32[$109>>2]|0;
  $$pre99 = HEAP32[$0>>2]|0;
  $$pre100 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i29Z2D = $109;$116 = $$pre$i$i$i28;$120 = $$pre99;$122 = $$pre100;
 } else {
  $114 = Math_fround(HEAPF32[$111>>2]);
  HEAPF32[$109>>2] = $114;
  HEAP32[$0>>2] = $110;
  $115 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i29Z2D = $109;$116 = $115;$120 = $110;$122 = $113;
 }
 $117 = (_llvm_bswap_i32(($116|0))|0);
 HEAP32[$$pre$phi$i$i$i29Z2D>>2] = $117;
 $118 = (($this) + 28|0);
 $119 = (($120) + 4|0);
 $121 = ($119>>>0)>($122>>>0);
 if ($121) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$118,4);
  $$pre$i$i$i18 = HEAP32[$118>>2]|0;
  $$pre101 = HEAP32[$0>>2]|0;
  $$pre102 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i19Z2D = $118;$125 = $$pre$i$i$i18;$129 = $$pre101;$131 = $$pre102;
 } else {
  $123 = Math_fround(HEAPF32[$120>>2]);
  HEAPF32[$118>>2] = $123;
  HEAP32[$0>>2] = $119;
  $124 = (HEAPF32[tempDoublePtr>>2]=$123,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i19Z2D = $118;$125 = $124;$129 = $119;$131 = $122;
 }
 $126 = (_llvm_bswap_i32(($125|0))|0);
 HEAP32[$$pre$phi$i$i$i19Z2D>>2] = $126;
 $127 = (($this) + 44|0);
 $128 = (($129) + 4|0);
 $130 = ($128>>>0)>($131>>>0);
 if ($130) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$127,4);
  $$pre$i$i$i8 = HEAP32[$127>>2]|0;
  $$pre103 = HEAP32[$0>>2]|0;
  $$pre104 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $127;$134 = $$pre$i$i$i8;$138 = $$pre103;$140 = $$pre104;
 } else {
  $132 = Math_fround(HEAPF32[$129>>2]);
  HEAPF32[$127>>2] = $132;
  HEAP32[$0>>2] = $128;
  $133 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $127;$134 = $133;$138 = $128;$140 = $131;
 }
 $135 = (_llvm_bswap_i32(($134|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $135;
 $136 = (($this) + 60|0);
 $137 = (($138) + 4|0);
 $139 = ($137>>>0)>($140>>>0);
 if ($139) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$136,4);
  $$pre$i$i$i = HEAP32[$136>>2]|0;
  $$pre$phi$i$i$iZ2D = $136;$143 = $$pre$i$i$i;
  $144 = (_llvm_bswap_i32(($143|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $144;
  STACKTOP = sp;return;
 } else {
  $141 = Math_fround(HEAPF32[$138>>2]);
  HEAPF32[$136>>2] = $141;
  HEAP32[$0>>2] = $137;
  $142 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $136;$143 = $142;
  $144 = (_llvm_bswap_i32(($143|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $144;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17BlendShapeChannelNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI17BlendShapeChannelNS0_9allocatorIS2_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN17BlendShapeChannel8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 16|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17BlendShapeChannel8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $1 = sp + 16|0;
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1623,($transfer|0),($tempStr$i$i|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3377,($transfer|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $17 = HEAP8[$tempStr$i$i>>0]|0;
   $18 = $17 & 1;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    $22 = (($tempStr$i$i) + 1|0);
    $24 = $22;
   } else {
    $20 = (($tempStr$i$i) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $24 = $21;
   }
   $23 = HEAP32[628448>>2]|0;
   HEAP32[$1>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1621,($this|0),($24|0),($$byval_copy2|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP8[$tempStr$i$i>>0]|0;
    $28 = $27 & 1;
    $29 = ($28<<24>>24)==(0);
    if (!($29)) {
     $30 = (($tempStr$i$i) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($31|0),($$byval_copy2|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      $34 = ___cxa_find_matching_catch()|0;
      $35 = tempRet0;
      ___cxa_call_unexpected(($34|0));
      // unreachable;
     }
    }
    $36 = (($this) + 4|0);
    $37 = (($transfer) + 12|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 4|0);
    $40 = (($transfer) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($39>>>0)>($41>>>0);
    if ($42) {
     __ZN12CachedReader15UpdateReadCacheEPvj($37,$36,4);
     $$pre$i$i$i = HEAP32[$36>>2]|0;
     $$pre = HEAP32[$37>>2]|0;
     $$pre4 = HEAP32[$40>>2]|0;
     $44 = $$pre$i$i$i;$48 = $$pre;$50 = $$pre4;
    } else {
     $43 = HEAP32[$38>>2]|0;
     HEAP32[$36>>2] = $43;
     HEAP32[$37>>2] = $39;
     $44 = $43;$48 = $39;$50 = $41;
    }
    $45 = (_llvm_bswap_i32(($44|0))|0);
    HEAP32[$36>>2] = $45;
    $46 = (($this) + 8|0);
    $47 = (($48) + 4|0);
    $49 = ($47>>>0)>($50>>>0);
    if ($49) {
     __ZN12CachedReader15UpdateReadCacheEPvj($37,$46,4);
     $$pre$i$i$i1 = HEAP32[$46>>2]|0;
     $$pre5 = HEAP32[$37>>2]|0;
     $$pre6 = HEAP32[$40>>2]|0;
     $52 = $$pre$i$i$i1;$56 = $$pre5;$58 = $$pre6;
    } else {
     $51 = HEAP32[$48>>2]|0;
     HEAP32[$46>>2] = $51;
     HEAP32[$37>>2] = $47;
     $52 = $51;$56 = $47;$58 = $50;
    }
    $53 = (_llvm_bswap_i32(($52|0))|0);
    HEAP32[$46>>2] = $53;
    $54 = (($this) + 12|0);
    $55 = (($56) + 4|0);
    $57 = ($55>>>0)>($58>>>0);
    if ($57) {
     __ZN12CachedReader15UpdateReadCacheEPvj($37,$54,4);
     $$pre$i$i$i2 = HEAP32[$54>>2]|0;
     $60 = $$pre$i$i$i2;
     $61 = (_llvm_bswap_i32(($60|0))|0);
     HEAP32[$54>>2] = $61;
     STACKTOP = sp;return;
    } else {
     $59 = HEAP32[$56>>2]|0;
     HEAP32[$54>>2] = $59;
     HEAP32[$37>>2] = $55;
     $60 = $59;
     $61 = (_llvm_bswap_i32(($60|0))|0);
     HEAP32[$54>>2] = $61;
     STACKTOP = sp;return;
    }
   }
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 $6 = HEAP8[$tempStr$i$i>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  ___resumeException($4|0);
  // unreachable;
 }
 $9 = (($tempStr$i$i) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($10|0),($$byval_copy2|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_call_unexpected(($13|0));
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __Z14resize_trimmedINSt3__16vectorI17BlendShapeChannelNS0_9allocatorIS2_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy8 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lpad$phi$i25$index = 0, $lpad$phi$i25$index3 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($sz>>>0);
 if ($9) {
  $10 = (($v) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($6))|0;
  $14 = $13 >> 4;
  $15 = ($14|0)==($sz|0);
  if ($15) {
   $71 = (($sz) - ($8))|0;
   __ZNSt3__16vectorI17BlendShapeChannelNS_9allocatorIS1_EEE8__appendEj($v,$71);
   STACKTOP = sp;return;
  }
  HEAP32[$temp>>2] = 0;
  $16 = (($temp) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($temp) + 8|0);
  HEAP32[$17>>2] = 0;
  __THREW__ = 0;
  invoke_vii(2678,($temp|0),($sz|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  L7: do {
   if (!($19)) {
    $20 = HEAP32[$v>>2]|0;
    HEAP32[$0>>2] = $20;
    $21 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viii(1705,($temp|0),($$byval_copy|0),($$byval_copy8|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[$16>>2]|0;
     $25 = HEAP32[$temp>>2]|0;
     $26 = $24;
     $27 = $25;
     $28 = (($26) - ($27))|0;
     $29 = $28 >> 4;
     $30 = ($29>>>0)<($sz>>>0);
     L10: do {
      if ($30) {
       $31 = (($sz) - ($29))|0;
       __THREW__ = 0;
       invoke_vii(2679,($temp|0),($31|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break L7;
       }
       $$pre32 = HEAP32[$16>>2]|0;
       $47 = $$pre32;
      } else {
       $34 = ($29>>>0)>($sz>>>0);
       if ($34) {
        $35 = (($25) + ($sz<<4)|0);
        $36 = ($24|0)==($35|0);
        if ($36) {
         $47 = $24;
        } else {
         $38 = $24;
         while(1) {
          $37 = (($38) + -16|0);
          HEAP32[$16>>2] = $37;
          __THREW__ = 0;
          invoke_vi(3382,($37|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          $$pre$i = HEAP32[$16>>2]|0;
          $41 = ($$pre$i|0)==($35|0);
          if ($41) {
           $47 = $35;
           break L10;
          } else {
           $38 = $$pre$i;
          }
         }
         $42 = ___cxa_find_matching_catch()|0;
         $43 = tempRet0;
         ___cxa_call_unexpected(($42|0));
         // unreachable;
        }
       } else {
        $47 = $24;
       }
      }
     } while(0);
     $44 = HEAP32[$temp>>2]|0;
     $45 = HEAP32[$v>>2]|0;
     HEAP32[$temp>>2] = $45;
     HEAP32[$v>>2] = $44;
     $46 = HEAP32[$2>>2]|0;
     HEAP32[$16>>2] = $46;
     HEAP32[$2>>2] = $47;
     $48 = HEAP32[$17>>2]|0;
     $49 = HEAP32[$10>>2]|0;
     HEAP32[$17>>2] = $49;
     HEAP32[$10>>2] = $48;
     $50 = ($45|0)==(0|0);
     if ($50) {
      STACKTOP = sp;return;
     } else {
      $52 = $46;
     }
     while(1) {
      $51 = ($52|0)==($45|0);
      if ($51) {
       break;
      }
      $53 = (($52) + -16|0);
      HEAP32[$16>>2] = $53;
      __THREW__ = 0;
      invoke_vi(3382,($53|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 17;
       break;
      }
      $$pre33 = HEAP32[$16>>2]|0;
      $52 = $$pre33;
     }
     if ((label|0) == 17) {
      $56 = ___cxa_find_matching_catch()|0;
      $57 = tempRet0;
      ___cxa_call_unexpected(($56|0));
      // unreachable;
     }
     $58 = HEAP32[$temp>>2]|0;
     __ZdlPv($58);
     STACKTOP = sp;return;
    }
   }
  } while(0);
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $61 = HEAP32[$temp>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   ___resumeException($59|0);
   // unreachable;
  }
  while(1) {
   $63 = HEAP32[$16>>2]|0;
   $64 = ($63|0)==($61|0);
   if ($64) {
    break;
   }
   $65 = (($63) + -16|0);
   HEAP32[$16>>2] = $65;
   __THREW__ = 0;
   invoke_vi(3382,($65|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 22;
    break;
   }
  }
  if ((label|0) == 22) {
   $68 = ___cxa_find_matching_catch()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
  $70 = HEAP32[$temp>>2]|0;
  __ZdlPv($70);
  ___resumeException($59|0);
  // unreachable;
 }
 $72 = ($8>>>0)>($sz>>>0);
 if (!($72)) {
  STACKTOP = sp;return;
 }
 $73 = (($4) + ($sz<<4)|0);
 $$idx = $sz << 4;
 $74 = $$idx >> 4;
 $75 = ($74|0)==(0);
 do {
  if ($75) {
   $107 = 0;$108 = 0;$110 = 0;$112 = $4;$120 = $3;
  } else {
   $76 = ($74>>>0)>(268435455);
   if ($76) {
    __THREW__ = 0;
    invoke_vi(3308,0);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if (!($78)) {
     // unreachable;
    }
   } else {
    __THREW__ = 0;
    $79 = (invoke_ii(2988,($$idx|0))|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if (!($81)) {
     $82 = (($79) + ($74<<4)|0);
     $83 = ($sz|0)==(0);
     if ($83) {
      $107 = $79;$108 = $79;$110 = $82;$112 = $4;$120 = $3;
      break;
     } else {
      $85 = $79;$86 = $4;
     }
     while(1) {
      $84 = ($85|0)==(0|0);
      if ($84) {
       $92 = 0;
      } else {
       HEAP32[$85>>2] = 0;
       __THREW__ = 0;
       invoke_vii(2680,($85|0),($86|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        break;
       }
       $89 = (($85) + 4|0);
       $90 = (($86) + 4|0);
       ;HEAP32[$89+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$90+8>>2]|0;
       $92 = $85;
      }
      $91 = (($92) + 16|0);
      $93 = (($86) + 16|0);
      $94 = ($93|0)==($73|0);
      if ($94) {
       label = 43;
       break;
      } else {
       $85 = $91;$86 = $93;
      }
     }
     if ((label|0) == 43) {
      $$pre = HEAP32[$v>>2]|0;
      $$pre31 = HEAP32[$2>>2]|0;
      $107 = $79;$108 = $91;$110 = $82;$112 = $$pre;$120 = $$pre31;
      break;
     }
     $97 = ___cxa_find_matching_catch()|0;
     $98 = tempRet0;
     $99 = ($79|0)==(0|0);
     if ($99) {
      $lpad$phi$i25$index = $97;$lpad$phi$i25$index3 = $98;
      ___resumeException($lpad$phi$i25$index|0);
      // unreachable;
     } else {
      $101 = $85;
     }
     while(1) {
      $100 = ($101|0)==($79|0);
      if ($100) {
       break;
      }
      $102 = (($101) + -16|0);
      __THREW__ = 0;
      invoke_vi(3382,($102|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       label = 40;
       break;
      } else {
       $101 = $102;
      }
     }
     if ((label|0) == 40) {
      $105 = ___cxa_find_matching_catch()|0;
      $106 = tempRet0;
      ___cxa_call_unexpected(($105|0));
      // unreachable;
     }
     __ZdlPv($79);
     $lpad$phi$i25$index = $97;$lpad$phi$i25$index3 = $98;
     ___resumeException($lpad$phi$i25$index|0);
     // unreachable;
    }
   }
   $95 = ___cxa_find_matching_catch()|0;
   $96 = tempRet0;
   $lpad$phi$i25$index = $95;$lpad$phi$i25$index3 = $96;
   ___resumeException($lpad$phi$i25$index|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$v>>2] = $107;
 HEAP32[$2>>2] = $108;
 $109 = (($v) + 8|0);
 HEAP32[$109>>2] = $110;
 $111 = ($112|0)==(0|0);
 if ($111) {
  STACKTOP = sp;return;
 } else {
  $114 = $120;
 }
 while(1) {
  $113 = ($114|0)==($112|0);
  if ($113) {
   break;
  }
  $115 = (($114) + -16|0);
  __THREW__ = 0;
  invoke_vi(3382,($115|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 47;
   break;
  } else {
   $114 = $115;
  }
 }
 if ((label|0) == 47) {
  $118 = ___cxa_find_matching_catch()|0;
  $119 = tempRet0;
  ___cxa_call_unexpected(($118|0));
  // unreachable;
 }
 __ZdlPv($112);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI17BlendShapeChannelNS_9allocatorIS1_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 4;
 $13 = ($__n|0)==(0);
 if ($13) {
  $17 = 0;
 } else {
  $14 = $__n << 4;
  $15 = (__Znwj($14)|0);
  $17 = $15;
 }
 $16 = (($17) + ($12<<4)|0);
 $18 = (($17) + ($__n<<4)|0);
 $19 = ($9|0)==($2|0);
 do {
  if ($19) {
   $28 = $16;$31 = $2;$48 = $2;
  } else {
   $$01$i$i = $9;$21 = $16;
   while(1) {
    $20 = (($21) + -16|0);
    $22 = (($$01$i$i) + -16|0);
    HEAP32[$20>>2] = 0;
    __THREW__ = 0;
    invoke_vii(2680,($20|0),($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = (($21) + -12|0);
    $26 = (($$01$i$i) + -12|0);
    ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;
    $27 = ($22|0)==($2|0);
    if ($27) {
     label = 7;
     break;
    } else {
     $$01$i$i = $22;$21 = $20;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$8>>2]|0;
    $28 = $20;$31 = $$pre$i;$48 = $$pre;
    break;
   }
   $38 = ___cxa_find_matching_catch()|0;
   $39 = tempRet0;
   $41 = $16;
   while(1) {
    $40 = ($41|0)==($21|0);
    if ($40) {
     break;
    }
    $42 = (($41) + -16|0);
    __THREW__ = 0;
    invoke_vi(3382,($42|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     label = 17;
     break;
    } else {
     $41 = $42;
    }
   }
   if ((label|0) == 17) {
    $45 = ___cxa_find_matching_catch()|0;
    $46 = tempRet0;
    ___cxa_call_unexpected(($45|0));
    // unreachable;
   }
   $47 = ($17|0)==(0|0);
   if ($47) {
    ___resumeException($38|0);
    // unreachable;
   }
   __ZdlPv($17);
   ___resumeException($38|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$this>>2] = $28;
 HEAP32[$8>>2] = $16;
 HEAP32[$0>>2] = $18;
 $30 = $48;
 while(1) {
  $29 = ($30|0)==($31|0);
  if ($29) {
   break;
  }
  $32 = (($30) + -16|0);
  __THREW__ = 0;
  invoke_vi(3382,($32|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   label = 11;
   break;
  } else {
   $30 = $32;
  }
 }
 if ((label|0) == 11) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 }
 $37 = ($31|0)==(0|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 __ZdlPv($31);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI17BlendShapeChannelNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 4;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 4;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $49 = ($8|0)==(0|0);
  do {
   if ($49) {
    $61 = $7;
   } else {
    $50 = (($this) + 4|0);
    while(1) {
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($8|0);
     if ($52) {
      label = 22;
      break;
     }
     $53 = (($51) + -16|0);
     HEAP32[$50>>2] = $53;
     __THREW__ = 0;
     invoke_vi(3382,($53|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      label = 21;
      break;
     }
    }
    if ((label|0) == 21) {
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     ___cxa_call_unexpected(($56|0));
     // unreachable;
    }
    else if ((label|0) == 22) {
     $58 = HEAP32[$this>>2]|0;
     __ZdlPv($58);
     HEAP32[$6>>2] = 0;
     HEAP32[$50>>2] = 0;
     HEAP32[$this>>2] = 0;
     $61 = 0;
     break;
    }
   }
  } while(0);
  $59 = ($5>>>0)>(268435455);
  if ($59) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $60 = $61;
  $62 = $60 >> 4;
  $63 = ($62>>>0)<(134217727);
  if ($63) {
   $64 = $60 >> 3;
   $65 = ($64>>>0)<($5>>>0);
   $66 = $65 ? $5 : $64;
   $67 = ($66>>>0)>(268435455);
   if ($67) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i31 = $66;
   }
  } else {
   $$0$i31 = 268435455;
  }
  $68 = $$0$i31 << 4;
  $69 = (__Znwj($68)|0);
  $70 = (($this) + 4|0);
  HEAP32[$70>>2] = $69;
  HEAP32[$this>>2] = $69;
  $71 = (($69) + ($$0$i31<<4)|0);
  HEAP32[$6>>2] = $71;
  $72 = ($0|0)==($1|0);
  if ($72) {
   STACKTOP = sp;return;
  } else {
   $74 = $69;$75 = $0;
  }
  while(1) {
   $73 = ($74|0)==(0|0);
   if ($73) {
    $79 = 0;
   } else {
    HEAP32[$74>>2] = 0;
    __ZN14ConstantString6assignERKS_($74,$75);
    $76 = (($74) + 4|0);
    $77 = (($75) + 4|0);
    ;HEAP32[$76+0>>2]=HEAP32[$77+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$77+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$77+8>>2]|0;
    $$pre1$i = HEAP32[$70>>2]|0;
    $79 = $$pre1$i;
   }
   $78 = (($79) + 16|0);
   HEAP32[$70>>2] = $78;
   $80 = (($75) + 16|0);
   $81 = ($80|0)==($1|0);
   if ($81) {
    break;
   } else {
    $74 = $78;$75 = $80;
   }
  }
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 4;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<4)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i = (($22) + -16|0);
  $23 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($23)|0);
  $uglygep16$i = $uglygep$i;
  $24 = $uglygep16$i >>> 4;
  $$01$i$i = $8;$25 = $0;
  while(1) {
   __ZN14ConstantStringaSERKS_($$01$i$i,$25);
   $26 = (($$01$i$i) + 4|0);
   $27 = (($25) + 4|0);
   ;HEAP32[$26+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$27+8>>2]|0;
   $28 = (($25) + 16|0);
   $29 = (($$01$i$i) + 16|0);
   $30 = ($28|0)==($22|0);
   if ($30) {
    break;
   } else {
    $$01$i$i = $29;$25 = $28;
   }
  }
  $31 = (($24) + 1)|0;
  $scevgep17$i = (($8) + ($31<<4)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if (!($__growing$0$off0)) {
  while(1) {
   $42 = HEAP32[$14>>2]|0;
   $43 = ($42|0)==($$0$lcssa$i$i|0);
   if ($43) {
    label = 32;
    break;
   }
   $44 = (($42) + -16|0);
   HEAP32[$14>>2] = $44;
   __THREW__ = 0;
   invoke_vi(3382,($44|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    label = 16;
    break;
   }
  }
  if ((label|0) == 16) {
   $47 = ___cxa_find_matching_catch()|0;
   $48 = tempRet0;
   ___cxa_call_unexpected(($47|0));
   // unreachable;
  }
  else if ((label|0) == 32) {
   STACKTOP = sp;return;
  }
 }
 $32 = ($22|0)==($1|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $$pre$i12 = HEAP32[$14>>2]|0;
 $34 = $$pre$i12;$35 = $22;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $39 = 0;
  } else {
   HEAP32[$34>>2] = 0;
   __ZN14ConstantString6assignERKS_($34,$35);
   $36 = (($34) + 4|0);
   $37 = (($35) + 4|0);
   ;HEAP32[$36+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$37+8>>2]|0;
   $$pre1$i14 = HEAP32[$14>>2]|0;
   $39 = $$pre1$i14;
  }
  $38 = (($39) + 16|0);
  HEAP32[$14>>2] = $38;
  $40 = (($35) + 16|0);
  $41 = ($40|0)==($1|0);
  if ($41) {
   break;
  } else {
   $34 = $38;$35 = $40;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI17BlendShapeChannelNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i122 = 0, $$0$i123 = 0, $$0$i6 = 0, $$01$i$i = 0, $$pre = 0, $$pre$i10 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
    HEAP32[$10>>2] = 0;
    __ZN14ConstantString12create_emptyEv($10);
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 16|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 4;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(268435455);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 4;
 $23 = ($22>>>0)<(134217727);
 if ($23) {
  $24 = $21 >> 3;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i123 = 0;$31 = 0;
  } else {
   $$0$i122 = $26;
   label = 9;
  }
 } else {
  $$0$i122 = 268435455;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = $$0$i122 << 4;
  $29 = (__Znwj($28)|0);
  $$0$i123 = $$0$i122;$31 = $29;
 }
 $30 = (($31) + ($18<<4)|0);
 $32 = (($31) + ($$0$i123<<4)|0);
 $$0$i6 = $__n;$34 = $30;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $38 = 0;
  } else {
   ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
   HEAP32[$34>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3379,($34|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    label = 25;
    break;
   } else {
    $38 = $34;
   }
  }
  $37 = (($38) + 16|0);
  $39 = (($$0$i6) + -1)|0;
  $40 = ($39|0)==(0);
  if ($40) {
   label = 14;
   break;
  } else {
   $$0$i6 = $39;$34 = $37;
  }
 }
 L22: do {
  if ((label|0) == 14) {
   $41 = HEAP32[$this>>2]|0;
   $42 = HEAP32[$2>>2]|0;
   $43 = ($42|0)==($41|0);
   do {
    if ($43) {
     $52 = $30;$55 = $41;$75 = $41;
    } else {
     $$01$i$i = $42;$45 = $30;
     while(1) {
      $44 = (($45) + -16|0);
      $46 = (($$01$i$i) + -16|0);
      HEAP32[$44>>2] = 0;
      __THREW__ = 0;
      invoke_vii(2680,($44|0),($46|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 24;
       break;
      }
      $49 = (($45) + -12|0);
      $50 = (($$01$i$i) + -12|0);
      ;HEAP32[$49+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$50+8>>2]|0;
      $51 = ($46|0)==($41|0);
      if ($51) {
       label = 17;
       break;
      } else {
       $$01$i$i = $46;$45 = $44;
      }
     }
     if ((label|0) == 17) {
      $$pre$i10 = HEAP32[$this>>2]|0;
      $$pre = HEAP32[$2>>2]|0;
      $52 = $44;$55 = $$pre$i10;$75 = $$pre;
      break;
     }
     else if ((label|0) == 24) {
      $62 = ___cxa_find_matching_catch()|0;
      $63 = tempRet0;
      $68 = $45;$76 = $37;$lpad$phi$index = $62;$lpad$phi$index2 = $63;
      break L22;
     }
    }
   } while(0);
   HEAP32[$this>>2] = $52;
   HEAP32[$2>>2] = $37;
   HEAP32[$0>>2] = $32;
   $54 = $75;
   while(1) {
    $53 = ($54|0)==($55|0);
    if ($53) {
     break;
    }
    $56 = (($54) + -16|0);
    __THREW__ = 0;
    invoke_vi(3382,($56|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     label = 21;
     break;
    } else {
     $54 = $56;
    }
   }
   if ((label|0) == 21) {
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    ___cxa_call_unexpected(($59|0));
    // unreachable;
   }
   $61 = ($55|0)==(0|0);
   if ($61) {
    STACKTOP = sp;return;
   }
   __ZdlPv($55);
   STACKTOP = sp;return;
  }
  else if ((label|0) == 25) {
   $64 = ___cxa_find_matching_catch()|0;
   $65 = tempRet0;
   $68 = $30;$76 = $34;$lpad$phi$index = $64;$lpad$phi$index2 = $65;
  }
 } while(0);
 $67 = $76;
 while(1) {
  $66 = ($67|0)==($68|0);
  if ($66) {
   break;
  }
  $69 = (($67) + -16|0);
  __THREW__ = 0;
  invoke_vi(3382,($69|0));
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if ($71) {
   label = 29;
   break;
  } else {
   $67 = $69;
  }
 }
 if ((label|0) == 29) {
  $72 = ___cxa_find_matching_catch()|0;
  $73 = tempRet0;
  ___cxa_call_unexpected(($72|0));
  // unreachable;
 }
 $74 = ($31|0)==(0|0);
 if ($74) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __ZdlPv($31);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI10BlendShapeLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI10BlendShapeLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*12)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN10BlendShape8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 12|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = ($23*12)|0;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = (($22|0) / 12)&-1;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI10BlendShapeLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP16[$1+8>>1]=0|0;
 $6 = (($data) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = ($rs*12)|0;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,4,$$byval_copy1,0,585592,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = ($rs*12)|0;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,4,$$byval_copy1,0,585592,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21*12)|0;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + (($rs*12)|0)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + (($24*12)|0)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$1+8>>2]|0;
  }
  $31 = (($$01$i$i) + 12|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN10BlendShape8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre4;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre5;$21 = $$pre6;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 1|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,1);
  $$pre7 = HEAP32[$0>>2]|0;
  $27 = $$pre7;
 } else {
  $22 = HEAP8[$19>>0]|0;
  HEAP8[$17>>0] = $22;
  $23 = HEAP32[$0>>2]|0;
  $24 = (($23) + 1|0);
  HEAP32[$0>>2] = $24;
  $27 = $24;
 }
 $25 = (($this) + 9|0);
 $26 = (($27) + 1|0);
 $28 = HEAP32[$3>>2]|0;
 $29 = ($26>>>0)>($28>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $30 = HEAP8[$27>>0]|0;
  HEAP8[$25>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI16BlendShapeVertexLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI16BlendShapeVertexLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*40)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$i$04,0,0);
   $44 = (($i$04) + 12|0);
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$44,0,0);
   $45 = (($i$04) + 24|0);
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$45,0,0);
   $46 = (($i$04) + 36|0);
   $47 = HEAP32[$3>>2]|0;
   $48 = (($47) + 4|0);
   $49 = HEAP32[$9>>2]|0;
   $50 = ($48>>>0)>($49>>>0);
   if ($50) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$46,4);
    $$pre$i$i$i$i$i$i = HEAP32[$46>>2]|0;
    $52 = $$pre$i$i$i$i$i$i;
   } else {
    $51 = HEAP32[$47>>2]|0;
    HEAP32[$46>>2] = $51;
    HEAP32[$3>>2] = $48;
    $52 = $51;
   }
   $53 = (_llvm_bswap_i32(($52|0))|0);
   HEAP32[$46>>2] = $53;
   $54 = (($i$04) + 40|0);
   $55 = ($54|0)==($42|0);
   if ($55) {
    break;
   } else {
    $i$04 = $54;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre5 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre6 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i1;$23 = $$pre6;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = ($23*40)|0;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = (($22|0) / 40)&-1;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI13dynamic_arrayI16BlendShapeVertexLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$sroa$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 40|0;
 $0 = sp + 36|0;
 $$sroa$0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 ;HEAP32[$$sroa$0+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$$sroa$0+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$$sroa$0+8>>2]=HEAP32[616680+8>>2]|0;
 $5 = (($$sroa$0) + 12|0);
 ;HEAP32[$5+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[616680+8>>2]|0;
 $6 = (($$sroa$0) + 24|0);
 ;HEAP32[$6+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[616680+8>>2]|0;
 $7 = (($data) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9>>>0)<($rs>>>0);
 do {
  if ($10) {
   $11 = ($8|0)>(-1);
   if ($11) {
    HEAP32[$7>>2] = $rs;
    $12 = ($rs*40)|0;
    $13 = (($data) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$0>>2] = $14;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $15 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$12,4,$$byval_copy1,0,585592,370)|0);
    HEAP32[$data>>2] = $15;
    $28 = $15;
    break;
   } else {
    $16 = ($rs*40)|0;
    $17 = (($data) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$0>>2] = $18;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $19 = (__Z15malloc_internaljj10MemLabelIdiPKci($16,4,$$byval_copy1,0,585592,352)|0);
    $20 = HEAP32[$data>>2]|0;
    $21 = (($data) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22*40)|0;
    _memcpy(($19|0),($20|0),($23|0))|0;
    HEAP32[$7>>2] = $rs;
    HEAP32[$data>>2] = $19;
    $28 = $19;
    break;
   }
  } else {
   $28 = $1;
  }
 } while(0);
 $24 = (($data) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25>>>0)<($rs>>>0);
 if (!($26)) {
  HEAP32[$24>>2] = $rs;
  STACKTOP = sp;return;
 }
 $27 = (($28) + (($rs*40)|0)|0);
 $29 = ($25|0)==($rs|0);
 if ($29) {
  HEAP32[$24>>2] = $rs;
  STACKTOP = sp;return;
 }
 $30 = (($28) + (($25*40)|0)|0);
 $$01$i$i = $30;
 while(1) {
  $31 = ($$01$i$i|0)==(0|0);
  if (!($31)) {
   dest=$$01$i$i+0|0; src=$$sroa$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $32 = (($$01$i$i) + 36|0);
   HEAP32[$32>>2] = 0;
  }
  $33 = (($$01$i$i) + 40|0);
  $34 = ($33|0)==($27|0);
  if ($34) {
   break;
  } else {
   $$01$i$i = $33;
  }
 }
 HEAP32[$24>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI7SubMesh13stl_allocatorIS4_L18MemLabelIdentifier10ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI7SubMesh13stl_allocatorIS2_L18MemLabelIdentifier10ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN7SubMesh8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 56|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*56)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7SubMesh8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i6 = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $12 = $$pre;$14 = $$pre8;$8 = $$pre$i$i$i;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $12 = $3;$14 = $5;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 8|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,4);
  $$pre$i$i$i1 = HEAP32[$10>>2]|0;
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $16 = $$pre$i$i$i1;$19 = $$pre9;$21 = $$pre10;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$1>>2] = $11;
  $16 = $15;$19 = $11;$21 = $14;
 }
 $17 = (_llvm_bswap_i32(($16|0))|0);
 HEAP32[$10>>2] = $17;
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$this,4);
  $$pre$i$i$i3 = HEAP32[$this>>2]|0;
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $23 = $$pre$i$i$i3;$27 = $$pre11;$29 = $$pre12;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$this>>2] = $22;
  HEAP32[$1>>2] = $18;
  $23 = $22;$27 = $18;$29 = $21;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$this>>2] = $24;
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$25,4);
  $$pre$i$i$i4 = HEAP32[$25>>2]|0;
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $31 = $$pre$i$i$i4;$35 = $$pre13;$37 = $$pre14;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$1>>2] = $26;
  $31 = $30;$35 = $26;$37 = $29;
 }
 $32 = (_llvm_bswap_i32(($31|0))|0);
 HEAP32[$25>>2] = $32;
 $33 = (($this) + 20|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$33,4);
  $$pre$i$i$i6 = HEAP32[$33>>2]|0;
  $39 = $$pre$i$i$i6;
  $40 = (_llvm_bswap_i32(($39|0))|0);
  HEAP32[$33>>2] = $40;
  $41 = (($this) + 32|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$41,0,0);
  $42 = (($this) + 44|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$42,0,0);
  STACKTOP = sp;return;
 } else {
  $38 = HEAP32[$35>>2]|0;
  HEAP32[$33>>2] = $38;
  HEAP32[$1>>2] = $34;
  $39 = $38;
  $40 = (_llvm_bswap_i32(($39|0))|0);
  HEAP32[$33>>2] = $40;
  $41 = (($this) + 32|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$41,0,0);
  $42 = (($this) + 44|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$42,0,0);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI7SubMesh13stl_allocatorIS2_L18MemLabelIdentifier10ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i27 = 0;
 var $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 56)&-1;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + (($sz*56)|0)|0);
  $$idx = ($sz*56)|0;
  $88 = (($$idx|0) / 56)&-1;
  $89 = ($sz|0)==(0);
  do {
   if ($89) {
    $104 = 0;$105 = 0;$107 = 0;$109 = $7;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 10;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(585592|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $97 = $93;$98 = $7;
      while(1) {
       $96 = ($97|0)==(0|0);
       if ($96) {
        $100 = 0;
       } else {
        dest=$97+0|0; src=$98+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $100 = $97;
       }
       $99 = (($100) + 56|0);
       $101 = (($98) + 56|0);
       $102 = ($101|0)==($87|0);
       if ($102) {
        break;
       } else {
        $97 = $99;$98 = $101;
       }
      }
      $103 = (($93) + (($88*56)|0)|0);
      $$pre = HEAP32[$v>>2]|0;
      $104 = $93;$105 = $99;$107 = $103;$109 = $$pre;
      break;
     }
    }
    $114 = ___cxa_find_matching_catch()|0;
    $115 = tempRet0;
    $$0 = $115;$$01 = $114;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $104;
  HEAP32[$5>>2] = $105;
  $106 = (($v) + 8|0);
  HEAP32[$106>>2] = $107;
  $108 = ($109|0)==(0|0);
  if ($108) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 10;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($109|0),($$byval_copy7|0));
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if ($111) {
   $112 = ___cxa_find_matching_catch()|0;
   $113 = tempRet0;
   ___cxa_call_unexpected(($112|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 56)&-1;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = ($sz*56)|0;
  HEAP32[$0>>2] = 10;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(585592|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + (($sz*56)|0)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = (($28|0) / -56)&-1;
   $30 = (($23) + (($29*56)|0)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 10;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1706,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = (($45|0) / 56)&-1;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2681,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre45 = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre45;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + (($sz*56)|0)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -56|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = (($uglygep3$i$i$i>>>0) / 56)&-1;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + (($56*56)|0)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -56|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = (($uglygep3$i$i$i$i$i19>>>0) / 56)&-1;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + (($67*56)|0)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 10;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -56|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = (($uglygep3$i$i$i$i$i28>>>0) / 56)&-1;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + (($80*56)|0)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 56)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 56)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = (($18|0) / 56)&-1;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = (($31|0) / 56)&-1;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + (($32*56)|0)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -56|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = (($uglygep3$i$i>>>0) / 56)&-1;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + (($38*56)|0)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + (($19*56)|0)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    dest=$24+0|0; src=$25+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 56|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 56|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -56|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = (($uglygep3$i$i$i$i>>>0) / 56)&-1;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + (($45*56)|0)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = (($51|0) / 56)&-1;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $53 << 1;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = ($$0$i37*56)|0;
 HEAP32[$0>>2] = 10;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,585592,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + (($$0$i37*56)|0)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   dest=$65+0|0; src=$66+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 56|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 56|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4Mesh8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$6 = 0, $$67 = 0, $$7 = 0, $$78 = 0, $$byval_copy3 = 0, $$pre = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dummyIndexContainer = 0, $dummySkin = 0, $dummyVertexData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $$byval_copy3 = sp + 144|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $dummySkin = sp + 16|0;
 $dummyVertexData = sp + 32|0;
 $dummyIndexContainer = sp + 132|0;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $3 = (($this) + 276|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 __ZN4Mesh21UnswizzleVertexColorsEb($this,1);
 $6 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI7SubMesh13stl_allocatorIS4_L18MemLabelIdentifier10ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$6,0);
 $7 = (($this) + 56|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI16BlendShapeVertexLj4EEEEvRT_17TransferMetaFlags($transfer,$7,0);
 $8 = (($this) + 72|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI10BlendShapeLj4EEEEvRT_17TransferMetaFlags($transfer,$8,0);
 $9 = (($this) + 88|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17BlendShapeChannelNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$9,0);
 $10 = (($this) + 100|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIfLj4EEEEvRT_17TransferMetaFlags($transfer,$10,0);
 $11 = (($this) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 120|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI10Matrix4x4fLj4EEEEvRT_17TransferMetaFlags($transfer,$13,0);
 $14 = (($this) + 116|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$14,0);
 $15 = (($this) + 132|0);
 $16 = (($transfer) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 4|0);
 $19 = (($transfer) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$15,4);
  $$pre = HEAP32[$16>>2]|0;
  $$pre29 = HEAP32[$19>>2]|0;
  $25 = $$pre;$27 = $$pre29;
 } else {
  $22 = HEAP32[$17>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$16>>2] = $18;
  $25 = $18;$27 = $20;
 }
 $23 = (($this) + 32|0);
 $24 = (($25) + 1|0);
 $26 = ($24>>>0)>($27>>>0);
 if ($26) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$23,1);
  $$pre30 = HEAP32[$16>>2]|0;
  $33 = $$pre30;
 } else {
  $28 = HEAP8[$25>>0]|0;
  HEAP8[$23>>0] = $28;
  $29 = HEAP32[$16>>2]|0;
  $30 = (($29) + 1|0);
  HEAP32[$16>>2] = $30;
  $33 = $30;
 }
 $31 = (($this) + 33|0);
 $32 = (($33) + 1|0);
 $34 = HEAP32[$19>>2]|0;
 $35 = ($32>>>0)>($34>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$31,1);
  $$pre31 = HEAP32[$16>>2]|0;
  $41 = $$pre31;
 } else {
  $36 = HEAP8[$33>>0]|0;
  HEAP8[$31>>0] = $36;
  $37 = HEAP32[$16>>2]|0;
  $38 = (($37) + 1|0);
  HEAP32[$16>>2] = $38;
  $41 = $38;
 }
 $39 = (($this) + 34|0);
 $40 = (($41) + 1|0);
 $42 = HEAP32[$19>>2]|0;
 $43 = ($40>>>0)>($42>>>0);
 if ($43) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$39,1);
  $$pre32 = HEAP32[$16>>2]|0;
  $49 = $$pre32;
 } else {
  $44 = HEAP8[$41>>0]|0;
  HEAP8[$39>>0] = $44;
  $45 = HEAP32[$16>>2]|0;
  $46 = (($45) + 1|0);
  HEAP32[$16>>2] = $46;
  $49 = $46;
 }
 $47 = (($this) + 35|0);
 $48 = (($49) + 1|0);
 $50 = HEAP32[$19>>2]|0;
 $51 = ($48>>>0)>($50>>>0);
 if ($51) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$47,1);
 } else {
  $52 = HEAP8[$49>>0]|0;
  HEAP8[$47>>0] = $52;
  $53 = HEAP32[$16>>2]|0;
  $54 = (($53) + 1|0);
  HEAP32[$16>>2] = $54;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $55 = HEAP8[$23>>0]|0;
 $56 = ($55<<24>>24)==(0);
 L21: do {
  if ($56) {
   label = 18;
  } else {
   $57 = HEAP32[$transfer>>2]|0;
   $58 = $57 & 16384;
   $59 = ($58|0)==(0);
   if ($59) {
    HEAP32[$dummySkin>>2] = 0;
    $66 = (($dummySkin) + 8|0);
    HEAP32[$66>>2] = 0;
    $67 = (($dummySkin) + 12|0);
    HEAP32[$67>>2] = 0;
    $68 = (($dummySkin) + 4|0);
    HEAP32[$68>>2] = 61;
    __THREW__ = 0;
    invoke_vi(3452,($dummyVertexData|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    do {
     if ($70) {
      label = 32;
     } else {
      HEAP32[$dummyIndexContainer>>2] = 0;
      $71 = (($dummyIndexContainer) + 4|0);
      HEAP32[$71>>2] = 0;
      $72 = (($dummyIndexContainer) + 8|0);
      HEAP32[$72>>2] = 0;
      __THREW__ = 0;
      invoke_viii(1707,($transfer|0),($dummyIndexContainer|0),0);
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if (!($74)) {
       __THREW__ = 0;
       invoke_vi(3376,($transfer|0));
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if (!($76)) {
        __THREW__ = 0;
        invoke_viii(1708,($transfer|0),($dummySkin|0),0);
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if (!($78)) {
         __THREW__ = 0;
         invoke_vii(2682,($dummyVertexData|0),($transfer|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if (!($80)) {
          $81 = HEAP32[$dummyIndexContainer>>2]|0;
          $82 = ($81|0)==(0|0);
          if (!($82)) {
           $83 = HEAP32[$71>>2]|0;
           $84 = ($83|0)==($81|0);
           if (!($84)) {
            HEAP32[$71>>2] = $81;
           }
           HEAP32[$0>>2] = 8;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($81|0),($$byval_copy3|0));
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if ($86) {
            $87 = ___cxa_find_matching_catch()|0;
            $88 = tempRet0;
            ___cxa_call_unexpected(($87|0));
            // unreachable;
           }
          }
          __THREW__ = 0;
          invoke_vi(3456,($dummyVertexData|0));
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           label = 32;
           break;
          }
          $91 = HEAP32[$67>>2]|0;
          $92 = ($91|0)>(-1);
          if (!($92)) {
           $227 = 1;
           break L21;
          }
          $93 = HEAP32[$dummySkin>>2]|0;
          $94 = HEAP32[$68>>2]|0;
          HEAP32[$1>>2] = $94;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
          __Z19free_alloc_internalPv10MemLabelId($93,$$byval_copy3);
          HEAP32[$dummySkin>>2] = 0;
          $227 = 1;
          break L21;
         }
        }
       }
      }
      $97 = ___cxa_find_matching_catch()|0;
      $98 = tempRet0;
      $99 = HEAP32[$dummyIndexContainer>>2]|0;
      $100 = ($99|0)==(0|0);
      if (!($100)) {
       $101 = HEAP32[$71>>2]|0;
       $102 = ($101|0)==($99|0);
       if (!($102)) {
        HEAP32[$71>>2] = $99;
       }
       HEAP32[$1>>2] = 8;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($99|0),($$byval_copy3|0));
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        $105 = ___cxa_find_matching_catch()|0;
        $106 = tempRet0;
        ___cxa_call_unexpected(($105|0));
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_vi(3456,($dummyVertexData|0));
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       $225 = ___cxa_find_matching_catch(0|0)|0;
       $226 = tempRet0;
       ___clang_call_terminate($225);
       // unreachable;
      } else {
       $$6 = $98;$$67 = $97;
      }
     }
    } while(0);
    if ((label|0) == 32) {
     $95 = ___cxa_find_matching_catch()|0;
     $96 = tempRet0;
     $$6 = $96;$$67 = $95;
    }
    $109 = HEAP32[$67>>2]|0;
    $110 = ($109|0)>(-1);
    if (!($110)) {
     $$7 = $$6;$$78 = $$67;
     ___resumeException($$78|0);
     // unreachable;
    }
    $111 = HEAP32[$dummySkin>>2]|0;
    $112 = HEAP32[$68>>2]|0;
    HEAP32[$2>>2] = $112;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($111|0),($$byval_copy3|0));
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    if ($114) {
     $225 = ___cxa_find_matching_catch(0|0)|0;
     $226 = tempRet0;
     ___clang_call_terminate($225);
     // unreachable;
    }
    HEAP32[$dummySkin>>2] = 0;
    $$7 = $$6;$$78 = $$67;
    ___resumeException($$78|0);
    // unreachable;
   } else {
    label = 18;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $60 = HEAP32[$11>>2]|0;
  $61 = (($60) + 108|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$61,0);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  $62 = HEAP32[$11>>2]|0;
  $63 = (($62) + 136|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags($transfer,$63,0);
  $64 = HEAP32[$11>>2]|0;
  $65 = (($64) + 8|0);
  __ZN10VertexData8TransferI18StreamedBinaryReadILb0EEEEvRT_($65,$transfer);
  $227 = 0;
 }
 __ZN14CompressedMeshC2Ev($$byval_copy3);
 __THREW__ = 0;
 invoke_vi(3376,($transfer|0));
 $115 = __THREW__; __THREW__ = 0;
 $116 = $115&1;
 do {
  if (!($116)) {
   __THREW__ = 0;
   invoke_vii(2683,($$byval_copy3|0),($transfer|0));
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if (!($122)) {
    if ($227) {
     __THREW__ = 0;
     invoke_vii(2675,($$byval_copy3|0),($this|0));
     $123 = __THREW__; __THREW__ = 0;
     $124 = $123&1;
     if ($124) {
      break;
     }
    }
    __ZN14CompressedMeshD2Ev($$byval_copy3);
    if (!($5)) {
     $125 = HEAP32[$11>>2]|0;
     $126 = (($125) + 18|0);
     $127 = HEAP8[$126>>0]|0;
     $128 = ($127<<24>>24)==(2);
     if ($128) {
      $129 = (($125) + 19|0);
      $130 = HEAP8[$129>>0]|0;
      $131 = ($130&255)<(4);
      if ($131) {
       $228 = 0;$229 = 0;
       label = 53;
      } else {
       $132 = (($125) + 92|0);
       $133 = HEAP32[$132>>2]|0;
       $134 = ($133|0)==(0|0);
       if ($134) {
        $230 = 1;$231 = 0;
       } else {
        $135 = (($125) + 16|0);
        $136 = HEAP8[$135>>0]|0;
        $137 = $136&255;
        $138 = ((($125) + (($137*12)|0)|0) + 50|0);
        $139 = HEAP8[$138>>0]|0;
        $140 = $139&255;
        $141 = ((($125) + (($137*12)|0)|0) + 44|0);
        $142 = HEAP32[$141>>2]|0;
        $143 = (($125) + 17|0);
        $144 = HEAP8[$143>>0]|0;
        $145 = $144&255;
        $146 = (($145) + ($142))|0;
        $147 = (($133) + ($146)|0);
        $230 = $140;$231 = $147;
       }
       if ($128) {
        $228 = $231;$229 = $230;
        label = 53;
       } else {
        $191 = $231;$192 = 0;$213 = $230;$215 = 0;$232 = 0;
       }
      }
      if ((label|0) == 53) {
       $148 = (($125) + 19|0);
       $149 = HEAP8[$148>>0]|0;
       $150 = ($149&255)<(4);
       if ($150) {
        $233 = 0;
       } else {
        $151 = (($125) + 92|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = ($152|0)==(0|0);
        if ($153) {
         $233 = 0;
        } else {
         $154 = (($125) + 100|0);
         $155 = HEAP32[$154>>2]|0;
         $156 = (($125) + 16|0);
         $157 = HEAP8[$156>>0]|0;
         $158 = $157&255;
         $159 = ((($125) + (($158*12)|0)|0) + 50|0);
         $160 = HEAP8[$159>>0]|0;
         $161 = $160&255;
         $162 = ((($125) + (($158*12)|0)|0) + 44|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = (($125) + 17|0);
         $165 = HEAP8[$164>>0]|0;
         $166 = $165&255;
         $167 = Math_imul($161, $155)|0;
         $168 = (($167) + ($163))|0;
         $169 = (($168) + ($166))|0;
         $170 = (($152) + ($169)|0);
         $233 = $170;
        }
       }
       if ($128) {
        $171 = (($125) + 19|0);
        $172 = HEAP8[$171>>0]|0;
        $173 = ($172&255)<(4);
        if ($173) {
         $191 = $228;$192 = $233;$213 = $229;$215 = 0;$232 = 0;
        } else {
         $174 = (($125) + 92|0);
         $175 = HEAP32[$174>>2]|0;
         $176 = ($175|0)==(0|0);
         if ($176) {
          $191 = $228;$192 = $233;$213 = $229;$215 = 1;$232 = 0;
         } else {
          $177 = (($125) + 16|0);
          $178 = HEAP8[$177>>0]|0;
          $179 = $178&255;
          $180 = ((($125) + (($179*12)|0)|0) + 50|0);
          $181 = HEAP8[$180>>0]|0;
          $182 = $181&255;
          $183 = ((($125) + (($179*12)|0)|0) + 44|0);
          $184 = HEAP32[$183>>2]|0;
          $185 = (($125) + 17|0);
          $186 = HEAP8[$185>>0]|0;
          $187 = $186&255;
          $188 = (($187) + ($184))|0;
          $189 = (($175) + ($188)|0);
          $191 = $228;$192 = $233;$213 = $229;$215 = $182;$232 = $189;
         }
        }
       } else {
        $191 = $228;$192 = $233;$213 = $229;$215 = 0;$232 = 0;
       }
      }
      $190 = ($191|0)==($192|0);
      if (!($190)) {
       $194 = $191;$211 = $232;
       while(1) {
        $193 = (($194) + 2|0);
        $195 = HEAP8[$193>>0]|0;
        $196 = (($194) + 1|0);
        $197 = HEAP8[$196>>0]|0;
        $198 = HEAP8[$194>>0]|0;
        $199 = (($194) + 3|0);
        $200 = HEAP8[$199>>0]|0;
        $201 = $200&255;
        $202 = $201 << 24;
        $203 = $198&255;
        $204 = $203 << 16;
        $205 = $197&255;
        $206 = $205 << 8;
        $207 = $195&255;
        $208 = $206 | $207;
        $209 = $208 | $204;
        $210 = $209 | $202;
        HEAP32[$211>>2] = $210;
        $212 = (($194) + ($213)|0);
        $214 = (($211) + ($215)|0);
        $216 = ($212|0)==($192|0);
        if ($216) {
         break;
        } else {
         $194 = $212;$211 = $214;
        }
       }
      }
     }
     HEAP8[$3>>0] = 1;
    }
    $217 = (($this) + 168|0);
    __ZN4AABB8TransferI18StreamedBinaryReadILb0EEEEvRT_($217,$transfer);
    $218 = (($this) + 40|0);
    $219 = HEAP32[$16>>2]|0;
    $220 = (($219) + 4|0);
    $221 = HEAP32[$19>>2]|0;
    $222 = ($220>>>0)>($221>>>0);
    if ($222) {
     __ZN12CachedReader15UpdateReadCacheEPvj($16,$218,4);
     $224 = (($this) + 192|0);
     __ZN17CollisionMeshData8TransferI18StreamedBinaryReadILb0EEEEvRT_R4Mesh($224,$transfer,0);
     STACKTOP = sp;return;
    } else {
     $223 = HEAP32[$219>>2]|0;
     HEAP32[$218>>2] = $223;
     HEAP32[$16>>2] = $220;
     $224 = (($this) + 192|0);
     __ZN17CollisionMeshData8TransferI18StreamedBinaryReadILb0EEEEvRT_R4Mesh($224,$transfer,0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $117 = ___cxa_find_matching_catch()|0;
 $118 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3459,($$byval_copy3|0));
 $119 = __THREW__; __THREW__ = 0;
 $120 = $119&1;
 if ($120) {
  $225 = ___cxa_find_matching_catch(0|0)|0;
  $226 = tempRet0;
  ___clang_call_terminate($225);
  // unreachable;
 } else {
  $$7 = $118;$$78 = $117;
  ___resumeException($$78|0);
  // unreachable;
 }
}
function __ZN17CollisionMeshData8TransferI18StreamedBinaryReadILb0EEEEvRT_R4Mesh($this,$transfer,$mesh) {
 $this = $this|0;
 $transfer = $transfer|0;
 $mesh = $mesh|0;
 var $$0 = 0, $$01 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $bakedConcave = 0, $bakedConvex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $bakedConvex = sp + 16|0;
 $bakedConcave = sp + 32|0;
 $3 = HEAP32[628512>>2]|0;
 HEAP32[$bakedConvex>>2] = 0;
 $4 = (($bakedConvex) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($bakedConvex) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($bakedConvex) + 12|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$bakedConcave>>2] = 0;
 $7 = (($bakedConcave) + 4|0);
 HEAP32[$7>>2] = $3;
 $8 = (($bakedConcave) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($bakedConcave) + 12|0);
 HEAP32[$9>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1709,($transfer|0),($bakedConvex|0),0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 10;
  } else {
   __THREW__ = 0;
   invoke_vi(3376,($transfer|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    label = 10;
   } else {
    __THREW__ = 0;
    invoke_viii(1709,($transfer|0),($bakedConcave|0),0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     label = 10;
    } else {
     __THREW__ = 0;
     invoke_vi(3376,($transfer|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 10;
     } else {
      __THREW__ = 0;
      $18 = (invoke_i(83)|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 10;
      } else {
       $21 = HEAP32[$5>>2]|0;
       $22 = ($21|0)==(0);
       if (!($22)) {
        $23 = HEAP32[$18>>2]|0;
        $24 = (($23) + 60|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = HEAP32[$bakedConvex>>2]|0;
        __THREW__ = 0;
        $27 = (invoke_iiiii($25|0,($18|0),1,($26|0),($21|0))|0);
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         label = 10;
         break;
        }
        $30 = (($this) + 8|0);
        HEAP32[$30>>2] = $27;
       }
       $41 = HEAP32[$8>>2]|0;
       $42 = ($41|0)==(0);
       if (!($42)) {
        $43 = HEAP32[$18>>2]|0;
        $44 = (($43) + 60|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = HEAP32[$bakedConcave>>2]|0;
        __THREW__ = 0;
        $47 = (invoke_iiiii($45|0,($18|0),0,($46|0),($41|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 10;
         break;
        }
        $50 = (($this) + 12|0);
        HEAP32[$50>>2] = $47;
       }
       $51 = HEAP32[$9>>2]|0;
       $52 = ($51|0)>(-1);
       do {
        if ($52) {
         $53 = HEAP32[$bakedConcave>>2]|0;
         $54 = HEAP32[$7>>2]|0;
         HEAP32[$1>>2] = $54;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
         invoke_vii(2591,($53|0),($$byval_copy3|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          $31 = ___cxa_find_matching_catch()|0;
          $32 = tempRet0;
          $$0 = $31;$$01 = $32;
          break L1;
         } else {
          HEAP32[$bakedConcave>>2] = 0;
          break;
         }
        }
       } while(0);
       $57 = HEAP32[$6>>2]|0;
       $58 = ($57|0)>(-1);
       if (!($58)) {
        STACKTOP = sp;return;
       }
       $59 = HEAP32[$bakedConvex>>2]|0;
       $60 = HEAP32[$4>>2]|0;
       HEAP32[$0>>2] = $60;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId($59,$$byval_copy3);
       HEAP32[$bakedConvex>>2] = 0;
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 10) {
   $33 = ___cxa_find_matching_catch()|0;
   $34 = tempRet0;
   $35 = HEAP32[$9>>2]|0;
   $36 = ($35|0)>(-1);
   if ($36) {
    $37 = HEAP32[$bakedConcave>>2]|0;
    $38 = HEAP32[$7>>2]|0;
    HEAP32[$0>>2] = $38;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($37|0),($$byval_copy3|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     $67 = ___cxa_find_matching_catch(0|0)|0;
     $68 = tempRet0;
     ___clang_call_terminate($67);
     // unreachable;
    } else {
     HEAP32[$bakedConcave>>2] = 0;
     $$0 = $33;$$01 = $34;
     break;
    }
   } else {
    $$0 = $33;$$01 = $34;
   }
  }
 } while(0);
 $61 = HEAP32[$6>>2]|0;
 $62 = ($61|0)>(-1);
 if (!($62)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $63 = HEAP32[$bakedConvex>>2]|0;
 $64 = HEAP32[$4>>2]|0;
 HEAP32[$2>>2] = $64;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($63|0),($$byval_copy3|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch(0|0)|0;
  $68 = tempRet0;
  ___clang_call_terminate($67);
  // unreachable;
 }
 HEAP32[$bakedConvex>>2] = 0;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN14CompressedMesh8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 56|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($1,$transfer);
 $2 = (($this) + 104|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($2,$transfer);
 $3 = (($this) + 180|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($3,$transfer);
 $4 = (($this) + 84|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($4,$transfer);
 $5 = (($this) + 132|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($5,$transfer);
 $6 = (($this) + 152|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($6,$transfer);
 $7 = (($this) + 200|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($7,$transfer);
 $8 = (($this) + 220|0);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 240|0);
 $10 = (($transfer) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = (($transfer) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$9,4);
  STACKTOP = sp;return;
 } else {
  $16 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $16;
  HEAP32[$10>>2] = $12;
  STACKTOP = sp;return;
 }
}
function __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
 }
 $7 = (($this) + 8|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIhNS2_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$7,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $8 = (($this) + 4|0);
 $9 = HEAP32[$0>>2]|0;
 $10 = (($9) + 1|0);
 $11 = HEAP32[$3>>2]|0;
 $12 = ($10>>>0)>($11>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$8,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $13 = HEAP8[$9>>0]|0;
  HEAP8[$8>>0] = $13;
  $14 = HEAP32[$0>>2]|0;
  $15 = (($14) + 1|0);
  HEAP32[$0>>2] = $15;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIhNS2_9allocatorIhEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $19 = $$pre;
  } else {
   $18 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $18;
   HEAP32[$1>>2] = $6;
   $19 = $18;
  }
  __Z14resize_trimmedINSt3__16vectorIhNS0_9allocatorIhEEEEEvRT_j($data,$19);
  $20 = HEAP32[$size1>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   STACKTOP = sp;return;
  }
  $22 = HEAP32[$data>>2]|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$22,$20);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $17 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $17 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$17,$16)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre2 = HEAP32[$3>>2]|0;
  $11 = $$pre2;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre3 = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $15 = $$pre3;$17 = $$pre4;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
 }
 $19 = (($this) + 16|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIhNS2_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$19,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $20 = (($this) + 12|0);
 $21 = HEAP32[$0>>2]|0;
 $22 = (($21) + 1|0);
 $23 = HEAP32[$3>>2]|0;
 $24 = ($22>>>0)>($23>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$20,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $25 = HEAP8[$21>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$0>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$0>>2] = $27;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($5) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $36 = $$pre;
  } else {
   $30 = HEAP32[$6>>2]|0;
   HEAP32[$size1>>2] = $30;
   HEAP32[$2>>2] = $7;
   $36 = $30;
  }
  $31 = (($this) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$data>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $35 = (($data) + 4|0);
   HEAP32[$35>>2] = $32;
  }
  ;HEAP32[$$byval_copy+0>>2]=0|0;HEAP32[$$byval_copy+4>>2]=0|0;HEAP32[$$byval_copy+8>>2]=0|0;HEAP32[$$byval_copy+12>>2]=0|0;HEAP32[$$byval_copy+16>>2]=0|0;HEAP32[$$byval_copy+20>>2]=0|0;HEAP32[$$byval_copy+24>>2]=0|0;HEAP32[$$byval_copy+28>>2]=0|0;
  __ZN13dynamic_arrayI13BoneInfluenceLj16EE18resize_initializedEjRKS0_b($data,$36,$$byval_copy,0);
  $37 = HEAP32[$size1>>2]|0;
  $38 = ($37|0)==(0);
  if ($38) {
   STACKTOP = sp;return;
  }
  $39 = HEAP32[$data>>2]|0;
  $40 = $37 << 5;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$39,$40);
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre4 = HEAP32[$2>>2]|0;
  $$pre5 = HEAP32[$8>>2]|0;
  $13 = $$pre4;$15 = $$pre5;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$size>>2] = $11;
  HEAP32[$2>>2] = $7;
  $13 = $7;$15 = $9;
 }
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
  $$pre6 = HEAP32[$offset>>2]|0;
  $19 = $$pre6;
 } else {
  $16 = HEAP32[$13>>2]|0;
  HEAP32[$offset>>2] = $16;
  HEAP32[$2>>2] = $12;
  $19 = $16;
 }
 $17 = HEAP32[$size>>2]|0;
 $18 = $17 << 5;
 $20 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$19,$18)|0);
 $21 = (($data) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(-1);
 if ($23) {
  $24 = HEAP32[$data>>2]|0;
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  HEAP32[$1>>2] = $26;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($24,$$byval_copy);
  HEAP32[$data>>2] = 0;
 }
 $27 = $18 >> 5;
 $28 = (($data) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = $27 | -2147483648;
 HEAP32[$21>>2] = $29;
 HEAP32[$data>>2] = $20;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $19 = $$pre;
  } else {
   $18 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $18;
   HEAP32[$1>>2] = $6;
   $19 = $18;
  }
  __Z14resize_trimmedINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEvRT_j($data,$19);
  $20 = HEAP32[$size1>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   STACKTOP = sp;return;
  }
  $22 = HEAP32[$data>>2]|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$22,$20);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $17 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $17 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$17,$16)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayIjLj4EEE19ResizeSTLStyleArrayERS1_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$size1>>2]|0;
  $36 = ($35|0)==(0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $37 = HEAP32[$data>>2]|0;
  $38 = $35 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$37,$38);
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre2 = HEAP32[$3>>2]|0;
  $$pre3 = HEAP32[$9>>2]|0;
  $14 = $$pre2;$16 = $$pre3;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre4 = HEAP32[$offset>>2]|0;
  $20 = $$pre4;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 2;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 2;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI10Matrix4x4fLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI10Matrix4x4fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<6)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN10Matrix4x4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 64|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 6;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 6;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0;
 var $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $11 = $$pre16;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 16|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $15 = $$pre17;$17 = $$pre18;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 32|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $21 = $$pre19;$23 = $$pre20;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 48|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre21 = HEAP32[$0>>2]|0;
  $$pre22 = HEAP32[$3>>2]|0;
  $27 = $$pre21;$29 = $$pre22;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 4|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre23 = HEAP32[$0>>2]|0;
  $$pre24 = HEAP32[$3>>2]|0;
  $33 = $$pre23;$35 = $$pre24;
 } else {
  $30 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $33 = $26;$35 = $29;
 }
 $31 = (($this) + 20|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$31,4);
  $$pre25 = HEAP32[$0>>2]|0;
  $$pre26 = HEAP32[$3>>2]|0;
  $39 = $$pre25;$41 = $$pre26;
 } else {
  $36 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$31>>2] = $36;
  HEAP32[$0>>2] = $32;
  $39 = $32;$41 = $35;
 }
 $37 = (($this) + 36|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$37,4);
  $$pre27 = HEAP32[$0>>2]|0;
  $$pre28 = HEAP32[$3>>2]|0;
  $45 = $$pre27;$47 = $$pre28;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$0>>2] = $38;
  $45 = $38;$47 = $41;
 }
 $43 = (($this) + 52|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)>($47>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$43,4);
  $$pre29 = HEAP32[$0>>2]|0;
  $$pre30 = HEAP32[$3>>2]|0;
  $51 = $$pre29;$53 = $$pre30;
 } else {
  $48 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$43>>2] = $48;
  HEAP32[$0>>2] = $44;
  $51 = $44;$53 = $47;
 }
 $49 = (($this) + 8|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)>($53>>>0);
 if ($52) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$49,4);
  $$pre31 = HEAP32[$0>>2]|0;
  $$pre32 = HEAP32[$3>>2]|0;
  $57 = $$pre31;$59 = $$pre32;
 } else {
  $54 = Math_fround(HEAPF32[$51>>2]);
  HEAPF32[$49>>2] = $54;
  HEAP32[$0>>2] = $50;
  $57 = $50;$59 = $53;
 }
 $55 = (($this) + 24|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)>($59>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$55,4);
  $$pre33 = HEAP32[$0>>2]|0;
  $$pre34 = HEAP32[$3>>2]|0;
  $63 = $$pre33;$65 = $$pre34;
 } else {
  $60 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$55>>2] = $60;
  HEAP32[$0>>2] = $56;
  $63 = $56;$65 = $59;
 }
 $61 = (($this) + 40|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)>($65>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$61,4);
  $$pre35 = HEAP32[$0>>2]|0;
  $$pre36 = HEAP32[$3>>2]|0;
  $69 = $$pre35;$71 = $$pre36;
 } else {
  $66 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$61>>2] = $66;
  HEAP32[$0>>2] = $62;
  $69 = $62;$71 = $65;
 }
 $67 = (($this) + 56|0);
 $68 = (($69) + 4|0);
 $70 = ($68>>>0)>($71>>>0);
 if ($70) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$67,4);
  $$pre37 = HEAP32[$0>>2]|0;
  $$pre38 = HEAP32[$3>>2]|0;
  $75 = $$pre37;$77 = $$pre38;
 } else {
  $72 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$67>>2] = $72;
  HEAP32[$0>>2] = $68;
  $75 = $68;$77 = $71;
 }
 $73 = (($this) + 12|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)>($77>>>0);
 if ($76) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$73,4);
  $$pre39 = HEAP32[$0>>2]|0;
  $$pre40 = HEAP32[$3>>2]|0;
  $81 = $$pre39;$83 = $$pre40;
 } else {
  $78 = Math_fround(HEAPF32[$75>>2]);
  HEAPF32[$73>>2] = $78;
  HEAP32[$0>>2] = $74;
  $81 = $74;$83 = $77;
 }
 $79 = (($this) + 28|0);
 $80 = (($81) + 4|0);
 $82 = ($80>>>0)>($83>>>0);
 if ($82) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$79,4);
  $$pre41 = HEAP32[$0>>2]|0;
  $$pre42 = HEAP32[$3>>2]|0;
  $87 = $$pre41;$89 = $$pre42;
 } else {
  $84 = Math_fround(HEAPF32[$81>>2]);
  HEAPF32[$79>>2] = $84;
  HEAP32[$0>>2] = $80;
  $87 = $80;$89 = $83;
 }
 $85 = (($this) + 44|0);
 $86 = (($87) + 4|0);
 $88 = ($86>>>0)>($89>>>0);
 if ($88) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$85,4);
  $$pre43 = HEAP32[$0>>2]|0;
  $$pre44 = HEAP32[$3>>2]|0;
  $93 = $$pre43;$95 = $$pre44;
 } else {
  $90 = Math_fround(HEAPF32[$87>>2]);
  HEAPF32[$85>>2] = $90;
  HEAP32[$0>>2] = $86;
  $93 = $86;$95 = $89;
 }
 $91 = (($this) + 60|0);
 $92 = (($93) + 4|0);
 $94 = ($92>>>0)>($95>>>0);
 if ($94) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$91,4);
  STACKTOP = sp;return;
 } else {
  $96 = Math_fround(HEAPF32[$93>>2]);
  HEAPF32[$91>>2] = $96;
  HEAP32[$0>>2] = $92;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17BlendShapeChannelNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI17BlendShapeChannelNS0_9allocatorIS2_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN17BlendShapeChannel8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 16|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17BlendShapeChannel8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $1 = sp + 16|0;
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1622,($transfer|0),($tempStr$i$i|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3376,($transfer|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $17 = HEAP8[$tempStr$i$i>>0]|0;
   $18 = $17 & 1;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    $22 = (($tempStr$i$i) + 1|0);
    $24 = $22;
   } else {
    $20 = (($tempStr$i$i) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $24 = $21;
   }
   $23 = HEAP32[628448>>2]|0;
   HEAP32[$1>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1621,($this|0),($24|0),($$byval_copy2|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP8[$tempStr$i$i>>0]|0;
    $28 = $27 & 1;
    $29 = ($28<<24>>24)==(0);
    if (!($29)) {
     $30 = (($tempStr$i$i) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($31|0),($$byval_copy2|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      $34 = ___cxa_find_matching_catch()|0;
      $35 = tempRet0;
      ___cxa_call_unexpected(($34|0));
      // unreachable;
     }
    }
    $36 = (($this) + 4|0);
    $37 = (($transfer) + 12|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 4|0);
    $40 = (($transfer) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($39>>>0)>($41>>>0);
    if ($42) {
     __ZN12CachedReader15UpdateReadCacheEPvj($37,$36,4);
     $$pre = HEAP32[$37>>2]|0;
     $$pre2 = HEAP32[$40>>2]|0;
     $46 = $$pre;$48 = $$pre2;
    } else {
     $43 = HEAP32[$38>>2]|0;
     HEAP32[$36>>2] = $43;
     HEAP32[$37>>2] = $39;
     $46 = $39;$48 = $41;
    }
    $44 = (($this) + 8|0);
    $45 = (($46) + 4|0);
    $47 = ($45>>>0)>($48>>>0);
    if ($47) {
     __ZN12CachedReader15UpdateReadCacheEPvj($37,$44,4);
     $$pre3 = HEAP32[$37>>2]|0;
     $$pre4 = HEAP32[$40>>2]|0;
     $52 = $$pre3;$54 = $$pre4;
    } else {
     $49 = HEAP32[$46>>2]|0;
     HEAP32[$44>>2] = $49;
     HEAP32[$37>>2] = $45;
     $52 = $45;$54 = $48;
    }
    $50 = (($this) + 12|0);
    $51 = (($52) + 4|0);
    $53 = ($51>>>0)>($54>>>0);
    if ($53) {
     __ZN12CachedReader15UpdateReadCacheEPvj($37,$50,4);
     STACKTOP = sp;return;
    } else {
     $55 = HEAP32[$52>>2]|0;
     HEAP32[$50>>2] = $55;
     HEAP32[$37>>2] = $51;
     STACKTOP = sp;return;
    }
   }
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 $6 = HEAP8[$tempStr$i$i>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  ___resumeException($4|0);
  // unreachable;
 }
 $9 = (($tempStr$i$i) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($10|0),($$byval_copy2|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_call_unexpected(($13|0));
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI10BlendShapeLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI10BlendShapeLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + (($37*12)|0)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN10BlendShape8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 12|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = ($18*12)|0;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = (($19|0) / 12)&-1;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10BlendShape8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $11 = $$pre3;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $15 = $$pre4;$17 = $$pre5;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 1|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,1);
  $$pre6 = HEAP32[$0>>2]|0;
  $23 = $$pre6;
 } else {
  $18 = HEAP8[$15>>0]|0;
  HEAP8[$13>>0] = $18;
  $19 = HEAP32[$0>>2]|0;
  $20 = (($19) + 1|0);
  HEAP32[$0>>2] = $20;
  $23 = $20;
 }
 $21 = (($this) + 9|0);
 $22 = (($23) + 1|0);
 $24 = HEAP32[$3>>2]|0;
 $25 = ($22>>>0)>($24>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$21,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $26 = HEAP8[$23>>0]|0;
  HEAP8[$21>>0] = $26;
  $27 = HEAP32[$0>>2]|0;
  $28 = (($27) + 1|0);
  HEAP32[$0>>2] = $28;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI16BlendShapeVertexLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i9 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i10 = 0, $$pre3$i$i$i3 = 0, $$pre4$i$i$i = 0, $$pre4$i$i$i12 = 0, $$pre4$i$i$i5 = 0;
 var $$pre5$i$i$i = 0, $$pre5$i$i$i13 = 0, $$pre5$i$i$i6 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $i$016 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if (!($6)) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre23 = HEAP32[$3>>2]|0;
   $$pre24 = HEAP32[$9>>2]|0;
   $14 = $$pre23;$16 = $$pre24;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $14 = $8;$16 = $10;
  }
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre25 = HEAP32[$offset>>2]|0;
   $20 = $$pre25;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$3>>2] = $13;
   $20 = $17;
  }
  $18 = HEAP32[$size>>2]|0;
  $19 = ($18*40)|0;
  $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
  $22 = (($data) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>(-1);
  if ($24) {
   $25 = HEAP32[$data>>2]|0;
   $26 = (($data) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $28 = (($19|0) / 40)&-1;
  $29 = (($data) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $28 | -2147483648;
  HEAP32[$22>>2] = $30;
  HEAP32[$data>>2] = $21;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $34 = $$pre;
 } else {
  $31 = HEAP32[$7>>2]|0;
  HEAP32[$size1>>2] = $31;
  HEAP32[$3>>2] = $8;
  $34 = $31;
 }
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$2>>2] = $33;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI16BlendShapeVertexLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
 $35 = HEAP32[$data>>2]|0;
 $36 = (($data) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + (($37*40)|0)|0);
 $39 = ($37|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 } else {
  $i$016 = $35;
 }
 while(1) {
  $40 = HEAP32[$3>>2]|0;
  $41 = (($40) + 4|0);
  $42 = HEAP32[$9>>2]|0;
  $43 = ($41>>>0)>($42>>>0);
  if ($43) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$016,4);
   $$pre$i$i$i2 = HEAP32[$3>>2]|0;
   $$pre3$i$i$i3 = HEAP32[$9>>2]|0;
   $47 = $$pre$i$i$i2;$49 = $$pre3$i$i$i3;
  } else {
   $44 = Math_fround(HEAPF32[$40>>2]);
   HEAPF32[$i$016>>2] = $44;
   HEAP32[$3>>2] = $41;
   $47 = $41;$49 = $42;
  }
  $45 = (($i$016) + 4|0);
  $46 = (($47) + 4|0);
  $48 = ($46>>>0)>($49>>>0);
  if ($48) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$45,4);
   $$pre4$i$i$i5 = HEAP32[$3>>2]|0;
   $$pre5$i$i$i6 = HEAP32[$9>>2]|0;
   $53 = $$pre4$i$i$i5;$55 = $$pre5$i$i$i6;
  } else {
   $50 = Math_fround(HEAPF32[$47>>2]);
   HEAPF32[$45>>2] = $50;
   HEAP32[$3>>2] = $46;
   $53 = $46;$55 = $49;
  }
  $51 = (($i$016) + 8|0);
  $52 = (($53) + 4|0);
  $54 = ($52>>>0)>($55>>>0);
  if ($54) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$51,4);
   $$pre17 = HEAP32[$3>>2]|0;
   $$pre18 = HEAP32[$9>>2]|0;
   $59 = $$pre17;$61 = $$pre18;
  } else {
   $56 = Math_fround(HEAPF32[$53>>2]);
   HEAPF32[$51>>2] = $56;
   HEAP32[$3>>2] = $52;
   $59 = $52;$61 = $55;
  }
  $57 = (($i$016) + 12|0);
  $58 = (($59) + 4|0);
  $60 = ($58>>>0)>($61>>>0);
  if ($60) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$57,4);
   $$pre$i$i$i = HEAP32[$3>>2]|0;
   $$pre3$i$i$i = HEAP32[$9>>2]|0;
   $65 = $$pre$i$i$i;$67 = $$pre3$i$i$i;
  } else {
   $62 = Math_fround(HEAPF32[$59>>2]);
   HEAPF32[$57>>2] = $62;
   HEAP32[$3>>2] = $58;
   $65 = $58;$67 = $61;
  }
  $63 = (($i$016) + 16|0);
  $64 = (($65) + 4|0);
  $66 = ($64>>>0)>($67>>>0);
  if ($66) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$63,4);
   $$pre4$i$i$i = HEAP32[$3>>2]|0;
   $$pre5$i$i$i = HEAP32[$9>>2]|0;
   $71 = $$pre4$i$i$i;$73 = $$pre5$i$i$i;
  } else {
   $68 = Math_fround(HEAPF32[$65>>2]);
   HEAPF32[$63>>2] = $68;
   HEAP32[$3>>2] = $64;
   $71 = $64;$73 = $67;
  }
  $69 = (($i$016) + 20|0);
  $70 = (($71) + 4|0);
  $72 = ($70>>>0)>($73>>>0);
  if ($72) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$69,4);
   $$pre19 = HEAP32[$3>>2]|0;
   $$pre20 = HEAP32[$9>>2]|0;
   $77 = $$pre19;$79 = $$pre20;
  } else {
   $74 = Math_fround(HEAPF32[$71>>2]);
   HEAPF32[$69>>2] = $74;
   HEAP32[$3>>2] = $70;
   $77 = $70;$79 = $73;
  }
  $75 = (($i$016) + 24|0);
  $76 = (($77) + 4|0);
  $78 = ($76>>>0)>($79>>>0);
  if ($78) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$75,4);
   $$pre$i$i$i9 = HEAP32[$3>>2]|0;
   $$pre3$i$i$i10 = HEAP32[$9>>2]|0;
   $83 = $$pre$i$i$i9;$85 = $$pre3$i$i$i10;
  } else {
   $80 = Math_fround(HEAPF32[$77>>2]);
   HEAPF32[$75>>2] = $80;
   HEAP32[$3>>2] = $76;
   $83 = $76;$85 = $79;
  }
  $81 = (($i$016) + 28|0);
  $82 = (($83) + 4|0);
  $84 = ($82>>>0)>($85>>>0);
  if ($84) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$81,4);
   $$pre4$i$i$i12 = HEAP32[$3>>2]|0;
   $$pre5$i$i$i13 = HEAP32[$9>>2]|0;
   $89 = $$pre4$i$i$i12;$91 = $$pre5$i$i$i13;
  } else {
   $86 = Math_fround(HEAPF32[$83>>2]);
   HEAPF32[$81>>2] = $86;
   HEAP32[$3>>2] = $82;
   $89 = $82;$91 = $85;
  }
  $87 = (($i$016) + 32|0);
  $88 = (($89) + 4|0);
  $90 = ($88>>>0)>($91>>>0);
  if ($90) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$87,4);
   $$pre21 = HEAP32[$3>>2]|0;
   $$pre22 = HEAP32[$9>>2]|0;
   $95 = $$pre21;$97 = $$pre22;
  } else {
   $92 = Math_fround(HEAPF32[$89>>2]);
   HEAPF32[$87>>2] = $92;
   HEAP32[$3>>2] = $88;
   $95 = $88;$97 = $91;
  }
  $93 = (($i$016) + 36|0);
  $94 = (($95) + 4|0);
  $96 = ($94>>>0)>($97>>>0);
  if ($96) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$93,4);
  } else {
   $98 = HEAP32[$95>>2]|0;
   HEAP32[$93>>2] = $98;
   HEAP32[$3>>2] = $94;
  }
  $99 = (($i$016) + 40|0);
  $100 = ($99|0)==($38|0);
  if ($100) {
   break;
  } else {
   $i$016 = $99;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI7SubMesh13stl_allocatorIS4_L18MemLabelIdentifier10ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI7SubMesh13stl_allocatorIS2_L18MemLabelIdentifier10ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN7SubMesh8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 56|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*56)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7SubMesh8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre4 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre4;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 8|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$4>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $13 = HEAP32[$10>>2]|0;
  HEAP32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $15 = $9;$17 = $12;
 }
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$this,4);
  $$pre7 = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$this>>2] = $18;
  HEAP32[$1>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 16|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$19,4);
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $27 = $$pre9;$29 = $$pre10;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$1>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 20|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$25,4);
  $31 = (($this) + 32|0);
  __ZN4AABB8TransferI18StreamedBinaryReadILb0EEEEvRT_($31,$transfer);
  STACKTOP = sp;return;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$1>>2] = $26;
  $31 = (($this) + 32|0);
  __ZN4AABB8TransferI18StreamedBinaryReadILb0EEEEvRT_($31,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4Mesh8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$01$i = 0, $$01$i64 = 0, $$01$i68 = 0, $$01$i72 = 0, $$01$i80 = 0, $$01$i90 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$6 = 0, $$67 = 0, $$7 = 0;
 var $$78 = 0, $$byval_copy15 = 0, $$pre = 0, $$pre157 = 0, $$pre158 = 0, $$pre159 = 0, $$pre160 = 0, $$pre161 = 0, $$pre162 = 0, $$pre163 = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i14 = 0, $$sum$i$i$i$i$i17 = 0, $$sum$i$i$i$i$i22 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i15 = 0, $$sum1$i$i$i$i$i18 = 0, $$sum1$i$i$i$i$i23 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0;
 var $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0;
 var $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0;
 var $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0;
 var $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0;
 var $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0;
 var $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0;
 var $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0;
 var $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0;
 var $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0;
 var $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0;
 var $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0;
 var $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0;
 var $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0;
 var $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0;
 var $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0;
 var $875 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $colors = 0, $converter$i$i114 = 0, $converter$i$i121 = 0, $converter$i$i127 = 0, $converter$i$i28 = 0, $converter$i$i32 = 0;
 var $converter$i$i37 = 0, $converter$i$i43 = 0, $converter$i$i48 = 0, $converter$i$i54 = 0, $dummyIndexContainer = 0, $dummySkin = 0, $dummyVertexData = 0, $exitcond$i$i = 0, $format$1 = 0, $format$1$ = 0, $format$3 = 0, $format$3$ = 0, $format$5 = 0, $i$02$i$i = 0, $layout$i$i$i = 0, $m_CompressedMesh = 0, $normals = 0, $not$ = 0, $p$01$i$i = 0, $tangents = 0;
 var $uvs = 0, $uvs1 = 0, $vertices = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 608|0;
 $$byval_copy15 = sp + 600|0;
 $converter$i$i127 = sp + 596|0;
 $converter$i$i121 = sp + 592|0;
 $converter$i$i114 = sp + 588|0;
 $0 = sp + 584|0;
 $1 = sp + 580|0;
 $2 = sp + 576|0;
 $3 = sp + 572|0;
 $4 = sp + 568|0;
 $5 = sp + 564|0;
 $6 = sp + 560|0;
 $7 = sp + 556|0;
 $8 = sp + 552|0;
 $9 = sp + 548|0;
 $10 = sp + 544|0;
 $11 = sp + 540|0;
 $12 = sp + 536|0;
 $layout$i$i$i = sp + 520|0;
 $13 = sp + 504|0;
 $14 = sp + 40|0;
 $converter$i$i54 = sp;
 $converter$i$i48 = sp + 4|0;
 $converter$i$i43 = sp + 8|0;
 $converter$i$i37 = sp + 12|0;
 $converter$i$i32 = sp + 16|0;
 $converter$i$i28 = sp + 20|0;
 $tangents = sp + 24|0;
 $vertices = sp + 48|0;
 $normals = sp + 64|0;
 $uvs = sp + 80|0;
 $uvs1 = sp + 96|0;
 $colors = sp + 112|0;
 $dummySkin = sp + 128|0;
 $dummyVertexData = sp + 144|0;
 $dummyIndexContainer = sp + 244|0;
 $m_CompressedMesh = sp + 256|0;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,8);
 $15 = (($this) + 276|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 __ZN4Mesh21UnswizzleVertexColorsEb($this,1);
 $18 = (($this) + 44|0);
 $19 = HEAP32[580760>>2]|0;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586064,$19,$$byval_copy15,1)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = ($20|0)>(0);
  if ($22) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI7SubMesh13stl_allocatorIS3_L18MemLabelIdentifier10ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$18,0);
  } else {
   $23 = HEAP32[$$byval_copy15>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    (FUNCTION_TABLE_iii[$23 & 4095]($18,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $25 = (($this) + 56|0);
 $26 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586080,587368,$$byval_copy15,1)|0);
 $27 = ($26|0)==(0);
 if (!($27)) {
  $28 = ($26|0)>(0);
  if ($28) {
   __ZN14BlendShapeData8TransferI14SafeBinaryReadEEvRT_($25,$transfer);
  } else {
   $29 = HEAP32[$$byval_copy15>>2]|0;
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    (FUNCTION_TABLE_iii[$29 & 4095]($25,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $31 = (($this) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 120|0);
 $34 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586096,$19,$$byval_copy15,1)|0);
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = ($34|0)>(0);
  if ($36) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI10Matrix4x4fLj4EEEEvRT_17TransferMetaFlags($transfer,$33,0);
  } else {
   $37 = HEAP32[$$byval_copy15>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    (FUNCTION_TABLE_iii[$37 & 4095]($33,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $39 = (($this) + 116|0);
 $40 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586112,$19,$$byval_copy15,1)|0);
 $41 = ($40|0)==(0);
 if (!($41)) {
  $42 = ($40|0)>(0);
  if ($42) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$39,0);
  } else {
   $43 = HEAP32[$$byval_copy15>>2]|0;
   $44 = ($43|0)==(0|0);
   if (!($44)) {
    (FUNCTION_TABLE_iii[$43 & 4095]($39,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $45 = (($this) + 132|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$45,586136,0);
 $46 = (($this) + 32|0);
 $47 = HEAP32[580744>>2]|0;
 $48 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586160,$47,$$byval_copy15,0)|0);
 $49 = ($48|0)==(0);
 if (!($49)) {
  $50 = ($48|0)>(0);
  do {
   if ($50) {
    $51 = (($transfer) + 12|0);
    $52 = (($transfer) + 80|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + 12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($transfer) + 16|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($transfer) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($transfer) + 32|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = Math_imul($61, $59)|0;
    $$sum$i$i$i$i$i = (($55) - ($62))|0;
    $63 = (($57) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$51>>2] = $63;
    $64 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($64)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $65 = (($57) + ($$sum1$i$i$i$i$i)|0);
     $66 = (($transfer) + 20|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($65>>>0)>($67>>>0);
     if (!($68)) {
      $69 = HEAP8[$63>>0]|0;
      HEAP8[$46>>0] = $69;
      $70 = HEAP32[$51>>2]|0;
      $71 = (($70) + 1|0);
      HEAP32[$51>>2] = $71;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($51,$46,1);
   } else {
    $72 = HEAP32[$$byval_copy15>>2]|0;
    $73 = ($72|0)==(0|0);
    if (!($73)) {
     (FUNCTION_TABLE_iii[$72 & 4095]($46,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $74 = (($this) + 33|0);
 $75 = HEAP32[580544>>2]|0;
 $76 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586184,$75,$$byval_copy15,0)|0);
 $77 = ($76|0)==(0);
 if (!($77)) {
  $78 = ($76|0)>(0);
  do {
   if ($78) {
    $79 = (($transfer) + 12|0);
    $80 = (($transfer) + 80|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($81) + 12|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($transfer) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($transfer) + 28|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = (($transfer) + 32|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = Math_imul($89, $87)|0;
    $$sum$i$i$i$i$i14 = (($83) - ($90))|0;
    $91 = (($85) + ($$sum$i$i$i$i$i14)|0);
    HEAP32[$79>>2] = $91;
    $92 = ($$sum$i$i$i$i$i14|0)<(0);
    if (!($92)) {
     $$sum1$i$i$i$i$i15 = (($$sum$i$i$i$i$i14) + 1)|0;
     $93 = (($85) + ($$sum1$i$i$i$i$i15)|0);
     $94 = (($transfer) + 20|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($93>>>0)>($95>>>0);
     if (!($96)) {
      $97 = HEAP8[$91>>0]|0;
      HEAP8[$74>>0] = $97;
      $98 = HEAP32[$79>>2]|0;
      $99 = (($98) + 1|0);
      HEAP32[$79>>2] = $99;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($79,$74,1);
   } else {
    $100 = HEAP32[$$byval_copy15>>2]|0;
    $101 = ($100|0)==(0|0);
    if (!($101)) {
     (FUNCTION_TABLE_iii[$100 & 4095]($74,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $102 = (($this) + 34|0);
 $103 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586200,$75,$$byval_copy15,0)|0);
 $104 = ($103|0)==(0);
 if (!($104)) {
  $105 = ($103|0)>(0);
  do {
   if ($105) {
    $106 = (($transfer) + 12|0);
    $107 = (($transfer) + 80|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = (($108) + 12|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = (($transfer) + 16|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($transfer) + 28|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = (($transfer) + 32|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = Math_imul($116, $114)|0;
    $$sum$i$i$i$i$i17 = (($110) - ($117))|0;
    $118 = (($112) + ($$sum$i$i$i$i$i17)|0);
    HEAP32[$106>>2] = $118;
    $119 = ($$sum$i$i$i$i$i17|0)<(0);
    if (!($119)) {
     $$sum1$i$i$i$i$i18 = (($$sum$i$i$i$i$i17) + 1)|0;
     $120 = (($112) + ($$sum1$i$i$i$i$i18)|0);
     $121 = (($transfer) + 20|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ($120>>>0)>($122>>>0);
     if (!($123)) {
      $124 = HEAP8[$118>>0]|0;
      HEAP8[$102>>0] = $124;
      $125 = HEAP32[$106>>2]|0;
      $126 = (($125) + 1|0);
      HEAP32[$106>>2] = $126;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($106,$102,1);
   } else {
    $127 = HEAP32[$$byval_copy15>>2]|0;
    $128 = ($127|0)==(0|0);
    if (!($128)) {
     (FUNCTION_TABLE_iii[$127 & 4095]($102,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $129 = (($this) + 35|0);
 $130 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586216,$75,$$byval_copy15,0)|0);
 $131 = ($130|0)==(0);
 if (!($131)) {
  $132 = ($130|0)>(0);
  do {
   if ($132) {
    $133 = (($transfer) + 12|0);
    $134 = (($transfer) + 80|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($135) + 12|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = (($transfer) + 16|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = (($transfer) + 28|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (($transfer) + 32|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = Math_imul($143, $141)|0;
    $$sum$i$i$i$i$i22 = (($137) - ($144))|0;
    $145 = (($139) + ($$sum$i$i$i$i$i22)|0);
    HEAP32[$133>>2] = $145;
    $146 = ($$sum$i$i$i$i$i22|0)<(0);
    if (!($146)) {
     $$sum1$i$i$i$i$i23 = (($$sum$i$i$i$i$i22) + 1)|0;
     $147 = (($139) + ($$sum1$i$i$i$i$i23)|0);
     $148 = (($transfer) + 20|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ($147>>>0)>($149>>>0);
     if (!($150)) {
      $151 = HEAP8[$145>>0]|0;
      HEAP8[$129>>0] = $151;
      $152 = HEAP32[$133>>2]|0;
      $153 = (($152) + 1|0);
      HEAP32[$133>>2] = $153;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($133,$129,1);
   } else {
    $154 = HEAP32[$$byval_copy15>>2]|0;
    $155 = ($154|0)==(0|0);
    if (!($155)) {
     (FUNCTION_TABLE_iii[$154 & 4095]($129,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $156 = HEAP8[$46>>0]|0;
 $157 = ($156<<24>>24)==(0);
 L81: do {
  if ($157) {
   label = 63;
  } else {
   $158 = HEAP32[$transfer>>2]|0;
   $159 = $158 & 16384;
   $160 = ($159|0)==(0);
   if ($160) {
    HEAP32[$dummySkin>>2] = 0;
    $657 = (($dummySkin) + 8|0);
    HEAP32[$657>>2] = 0;
    $658 = (($dummySkin) + 12|0);
    HEAP32[$658>>2] = 0;
    $659 = (($dummySkin) + 4|0);
    HEAP32[$659>>2] = 61;
    __THREW__ = 0;
    invoke_vi(3452,($dummyVertexData|0));
    $660 = __THREW__; __THREW__ = 0;
    $661 = $660&1;
    L84: do {
     if ($661) {
      label = 250;
     } else {
      HEAP32[$dummyIndexContainer>>2] = 0;
      $662 = (($dummyIndexContainer) + 4|0);
      HEAP32[$662>>2] = 0;
      $663 = (($dummyIndexContainer) + 8|0);
      HEAP32[$663>>2] = 0;
      __THREW__ = 0;
      $664 = (invoke_iiiiii(192,($transfer|0),(586232|0),($19|0),($converter$i$i121|0),1)|0);
      $665 = __THREW__; __THREW__ = 0;
      $666 = $665&1;
      L86: do {
       if (!($666)) {
        $667 = ($664|0)==(0);
        if (!($667)) {
         $668 = ($664|0)>(0);
         if ($668) {
          __THREW__ = 0;
          invoke_viii(1714,($transfer|0),($dummyIndexContainer|0),0);
          $669 = __THREW__; __THREW__ = 0;
          $670 = $669&1;
          if ($670) {
           break;
          }
         } else {
          $671 = HEAP32[$converter$i$i121>>2]|0;
          $672 = ($671|0)==(0|0);
          if (!($672)) {
           __THREW__ = 0;
           (invoke_iii($671|0,($dummyIndexContainer|0),($transfer|0))|0);
           $673 = __THREW__; __THREW__ = 0;
           $674 = $673&1;
           if ($674) {
            break;
           }
          }
         }
         __THREW__ = 0;
         invoke_vi(3389,($transfer|0));
         $675 = __THREW__; __THREW__ = 0;
         $676 = $675&1;
         if ($676) {
          break;
         }
        }
        __THREW__ = 0;
        $677 = (invoke_iiiiii(192,($transfer|0),(586248|0),($19|0),($converter$i$i127|0),1)|0);
        $678 = __THREW__; __THREW__ = 0;
        $679 = $678&1;
        if (!($679)) {
         $680 = ($677|0)==(0);
         if (!($680)) {
          $681 = ($677|0)>(0);
          do {
           if ($681) {
            __THREW__ = 0;
            invoke_viii(1715,($transfer|0),($dummySkin|0),0);
            $682 = __THREW__; __THREW__ = 0;
            $683 = $682&1;
            if ($683) {
             break L86;
            }
           } else {
            $684 = HEAP32[$converter$i$i127>>2]|0;
            $685 = ($684|0)==(0|0);
            if ($685) {
             break;
            }
            __THREW__ = 0;
            (invoke_iii($684|0,($dummySkin|0),($transfer|0))|0);
            $686 = __THREW__; __THREW__ = 0;
            $687 = $686&1;
            if ($687) {
             break L86;
            }
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3389,($transfer|0));
          $688 = __THREW__; __THREW__ = 0;
          $689 = $688&1;
          if ($689) {
           break;
          }
         }
         __THREW__ = 0;
         $690 = (invoke_iiiiii(192,($transfer|0),(586336|0),(587320|0),($converter$i$i114|0),1)|0);
         $691 = __THREW__; __THREW__ = 0;
         $692 = $691&1;
         if (!($692)) {
          $693 = ($690|0)==(0);
          if (!($693)) {
           $694 = ($690|0)>(0);
           do {
            if ($694) {
             __THREW__ = 0;
             invoke_vii(2685,($dummyVertexData|0),($transfer|0));
             $695 = __THREW__; __THREW__ = 0;
             $696 = $695&1;
             if ($696) {
              break L86;
             }
            } else {
             $697 = HEAP32[$converter$i$i114>>2]|0;
             $698 = ($697|0)==(0|0);
             if ($698) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii($697|0,($dummyVertexData|0),($transfer|0))|0);
             $699 = __THREW__; __THREW__ = 0;
             $700 = $699&1;
             if ($700) {
              break L86;
             }
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(3389,($transfer|0));
           $701 = __THREW__; __THREW__ = 0;
           $702 = $701&1;
           if ($702) {
            break;
           }
          }
          $703 = HEAP32[$dummyIndexContainer>>2]|0;
          $704 = ($703|0)==(0|0);
          do {
           if (!($704)) {
            $705 = HEAP32[$662>>2]|0;
            $706 = ($705|0)==($703|0);
            if (!($706)) {
             HEAP32[$662>>2] = $703;
            }
            HEAP32[$0>>2] = 8;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
            invoke_vii(2591,($703|0),($$byval_copy15|0));
            $707 = __THREW__; __THREW__ = 0;
            $708 = $707&1;
            if (!($708)) {
             break;
            }
            $709 = ___cxa_find_matching_catch()|0;
            $710 = tempRet0;
            ___cxa_call_unexpected(($709|0));
            // unreachable;
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3456,($dummyVertexData|0));
          $711 = __THREW__; __THREW__ = 0;
          $712 = $711&1;
          if ($712) {
           label = 250;
           break L84;
          }
          $713 = HEAP32[$658>>2]|0;
          $714 = ($713|0)>(-1);
          if (!($714)) {
           $868 = 1;
           label = 260;
           break L81;
          }
          $715 = HEAP32[$dummySkin>>2]|0;
          $716 = HEAP32[$659>>2]|0;
          HEAP32[$converter$i$i127>>2] = $716;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$converter$i$i127+0>>2]|0;
          __Z19free_alloc_internalPv10MemLabelId($715,$$byval_copy15);
          HEAP32[$dummySkin>>2] = 0;
          __ZN14CompressedMeshC2Ev($m_CompressedMesh);
          $750 = $m_CompressedMesh;$869 = 1;
          break L81;
         }
        }
       }
      } while(0);
      $719 = ___cxa_find_matching_catch()|0;
      $720 = tempRet0;
      $721 = HEAP32[$dummyIndexContainer>>2]|0;
      $722 = ($721|0)==(0|0);
      if (!($722)) {
       $723 = HEAP32[$662>>2]|0;
       $724 = ($723|0)==($721|0);
       if (!($724)) {
        HEAP32[$662>>2] = $721;
       }
       HEAP32[$11>>2] = 8;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$11+0>>2]|0;
       invoke_vii(2591,($721|0),($$byval_copy15|0));
       $725 = __THREW__; __THREW__ = 0;
       $726 = $725&1;
       if ($726) {
        $727 = ___cxa_find_matching_catch()|0;
        $728 = tempRet0;
        ___cxa_call_unexpected(($727|0));
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_vi(3456,($dummyVertexData|0));
      $729 = __THREW__; __THREW__ = 0;
      $730 = $729&1;
      if ($730) {
       $860 = ___cxa_find_matching_catch(0|0)|0;
       $861 = tempRet0;
       ___clang_call_terminate($860);
       // unreachable;
      } else {
       $$6 = $720;$$67 = $719;
      }
     }
    } while(0);
    if ((label|0) == 250) {
     $717 = ___cxa_find_matching_catch()|0;
     $718 = tempRet0;
     $$6 = $718;$$67 = $717;
    }
    $731 = HEAP32[$658>>2]|0;
    $732 = ($731|0)>(-1);
    if (!($732)) {
     $$7 = $$6;$$78 = $$67;
     ___resumeException($$78|0);
     // unreachable;
    }
    $733 = HEAP32[$dummySkin>>2]|0;
    $734 = HEAP32[$659>>2]|0;
    HEAP32[$12>>2] = $734;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$12+0>>2]|0;
    invoke_vii(2591,($733|0),($$byval_copy15|0));
    $735 = __THREW__; __THREW__ = 0;
    $736 = $735&1;
    if ($736) {
     $860 = ___cxa_find_matching_catch(0|0)|0;
     $861 = tempRet0;
     ___clang_call_terminate($860);
     // unreachable;
    }
    HEAP32[$dummySkin>>2] = 0;
    $$7 = $$6;$$78 = $$67;
    ___resumeException($$78|0);
    // unreachable;
   } else {
    label = 63;
   }
  }
 } while(0);
 L142: do {
  if ((label|0) == 63) {
   $161 = HEAP32[$31>>2]|0;
   $162 = (($161) + 108|0);
   $163 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586232,$19,$$byval_copy15,1)|0);
   $164 = ($163|0)==(0);
   if (!($164)) {
    $165 = ($163|0)>(0);
    if ($165) {
     __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$162,0);
    } else {
     $166 = HEAP32[$$byval_copy15>>2]|0;
     $167 = ($166|0)==(0|0);
     if (!($167)) {
      (FUNCTION_TABLE_iii[$166 & 4095]($162,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
   $168 = HEAP32[$transfer>>2]|0;
   $169 = $168 & 512;
   $170 = ($169|0)==(0);
   $$pre161 = HEAP32[$31>>2]|0;
   if (!($170)) {
    $171 = (($$pre161) + 112|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = (($$pre161) + 108|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = $172;
    $176 = $174;
    $177 = (($175) - ($176))|0;
    $178 = $177 >>> 1;
    $179 = ($178|0)==(0);
    if (!($179)) {
     $i$02$i$i = 0;$p$01$i$i = $174;
     while(1) {
      $180 = (($p$01$i$i) + 2|0);
      $181 = HEAP16[$p$01$i$i>>1]|0;
      $182 = $181&65535;
      $183 = $182 << 8;
      $184 = $182 >>> 8;
      $185 = $183 | $184;
      $186 = $185&65535;
      HEAP16[$p$01$i$i>>1] = $186;
      $187 = (($i$02$i$i) + 1)|0;
      $exitcond$i$i = ($187|0)==($178|0);
      if ($exitcond$i$i) {
       break;
      } else {
       $i$02$i$i = $187;$p$01$i$i = $180;
      }
     }
    }
   }
   $188 = (($$pre161) + 136|0);
   $189 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586248,$19,$$byval_copy15,1)|0);
   $190 = ($189|0)==(0);
   if (!($190)) {
    $191 = ($189|0)>(0);
    if ($191) {
     __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags($transfer,$188,0);
    } else {
     $192 = HEAP32[$$byval_copy15>>2]|0;
     $193 = ($192|0)==(0|0);
     if (!($193)) {
      (FUNCTION_TABLE_iii[$192 & 4095]($188,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
   $194 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,5)|0);
   if (!($194)) {
    $645 = HEAP32[$31>>2]|0;
    $646 = (($645) + 8|0);
    $647 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586336,587320,$$byval_copy15,1)|0);
    $648 = ($647|0)==(0);
    if (!($648)) {
     $649 = ($647|0)>(0);
     if ($649) {
      __ZN10VertexData8TransferI14SafeBinaryReadEEvRT_($646,$transfer);
     } else {
      $650 = HEAP32[$$byval_copy15>>2]|0;
      $651 = ($650|0)==(0|0);
      if (!($651)) {
       (FUNCTION_TABLE_iii[$650 & 4095]($646,$transfer)|0);
      }
     }
     __ZN14SafeBinaryRead11EndTransferEv($transfer);
    }
    $652 = HEAP32[$transfer>>2]|0;
    $653 = $652 & 512;
    $654 = ($653|0)==(0);
    if ($654) {
     $868 = 0;
     label = 260;
     break;
    }
    $655 = HEAP32[$31>>2]|0;
    $656 = (($655) + 8|0);
    __ZN10VertexData13SwapEndianessEv($656);
    __ZN14CompressedMeshC2Ev($m_CompressedMesh);
    $750 = $m_CompressedMesh;$869 = 0;
    break;
   }
   HEAP32[$tangents>>2] = 0;
   $195 = (($tangents) + 8|0);
   HEAP32[$195>>2] = 0;
   $196 = (($tangents) + 12|0);
   HEAP32[$196>>2] = 0;
   $197 = (($tangents) + 4|0);
   HEAP32[$197>>2] = 61;
   HEAP32[$vertices>>2] = 0;
   $198 = (($vertices) + 8|0);
   HEAP32[$198>>2] = 0;
   $199 = (($vertices) + 12|0);
   HEAP32[$199>>2] = 0;
   $200 = (($vertices) + 4|0);
   HEAP32[$200>>2] = 61;
   HEAP32[$normals>>2] = 0;
   $201 = (($normals) + 8|0);
   HEAP32[$201>>2] = 0;
   $202 = (($normals) + 12|0);
   HEAP32[$202>>2] = 0;
   $203 = (($normals) + 4|0);
   HEAP32[$203>>2] = 61;
   HEAP32[$uvs>>2] = 0;
   $204 = (($uvs) + 8|0);
   HEAP32[$204>>2] = 0;
   $205 = (($uvs) + 12|0);
   HEAP32[$205>>2] = 0;
   $206 = (($uvs) + 4|0);
   HEAP32[$206>>2] = 61;
   HEAP32[$uvs1>>2] = 0;
   $207 = (($uvs1) + 8|0);
   HEAP32[$207>>2] = 0;
   $208 = (($uvs1) + 12|0);
   HEAP32[$208>>2] = 0;
   $209 = (($uvs1) + 4|0);
   HEAP32[$209>>2] = 61;
   HEAP32[$colors>>2] = 0;
   $210 = (($colors) + 8|0);
   HEAP32[$210>>2] = 0;
   $211 = (($colors) + 12|0);
   HEAP32[$211>>2] = 0;
   $212 = (($colors) + 4|0);
   HEAP32[$212>>2] = 61;
   __THREW__ = 0;
   $213 = (invoke_iiiiii(192,($transfer|0),(586256|0),($19|0),($converter$i$i28|0),1)|0);
   $214 = __THREW__; __THREW__ = 0;
   $215 = $214&1;
   L178: do {
    if ($215) {
     label = 128;
    } else {
     $216 = ($213|0)==(0);
     if (!($216)) {
      $217 = ($213|0)>(0);
      do {
       if ($217) {
        __THREW__ = 0;
        invoke_viii(1710,($transfer|0),($vertices|0),0);
        $218 = __THREW__; __THREW__ = 0;
        $219 = $218&1;
        if ($219) {
         label = 128;
         break L178;
        }
       } else {
        $220 = HEAP32[$converter$i$i28>>2]|0;
        $221 = ($220|0)==(0|0);
        if ($221) {
         break;
        }
        __THREW__ = 0;
        (invoke_iii($220|0,($vertices|0),($transfer|0))|0);
        $222 = __THREW__; __THREW__ = 0;
        $223 = $222&1;
        if ($223) {
         label = 128;
         break L178;
        }
       }
      } while(0);
      __THREW__ = 0;
      invoke_vi(3389,($transfer|0));
      $224 = __THREW__; __THREW__ = 0;
      $225 = $224&1;
      if ($225) {
       label = 128;
       break;
      }
     }
     __THREW__ = 0;
     $226 = (invoke_iiiiii(192,($transfer|0),(586272|0),($19|0),($converter$i$i32|0),1)|0);
     $227 = __THREW__; __THREW__ = 0;
     $228 = $227&1;
     if ($228) {
      label = 128;
     } else {
      $229 = ($226|0)==(0);
      if (!($229)) {
       $230 = ($226|0)>(0);
       do {
        if ($230) {
         __THREW__ = 0;
         invoke_viii(1711,($transfer|0),($uvs|0),0);
         $231 = __THREW__; __THREW__ = 0;
         $232 = $231&1;
         if ($232) {
          label = 128;
          break L178;
         }
        } else {
         $233 = HEAP32[$converter$i$i32>>2]|0;
         $234 = ($233|0)==(0|0);
         if ($234) {
          break;
         }
         __THREW__ = 0;
         (invoke_iii($233|0,($uvs|0),($transfer|0))|0);
         $235 = __THREW__; __THREW__ = 0;
         $236 = $235&1;
         if ($236) {
          label = 128;
          break L178;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3389,($transfer|0));
       $237 = __THREW__; __THREW__ = 0;
       $238 = $237&1;
       if ($238) {
        label = 128;
        break;
       }
      }
      __THREW__ = 0;
      $239 = (invoke_iiiiii(192,($transfer|0),(586280|0),($19|0),($converter$i$i37|0),1)|0);
      $240 = __THREW__; __THREW__ = 0;
      $241 = $240&1;
      if ($241) {
       label = 128;
      } else {
       $242 = ($239|0)==(0);
       if (!($242)) {
        $243 = ($239|0)>(0);
        do {
         if ($243) {
          __THREW__ = 0;
          invoke_viii(1711,($transfer|0),($uvs1|0),0);
          $244 = __THREW__; __THREW__ = 0;
          $245 = $244&1;
          if ($245) {
           label = 128;
           break L178;
          }
         } else {
          $246 = HEAP32[$converter$i$i37>>2]|0;
          $247 = ($246|0)==(0|0);
          if ($247) {
           break;
          }
          __THREW__ = 0;
          (invoke_iii($246|0,($uvs1|0),($transfer|0))|0);
          $248 = __THREW__; __THREW__ = 0;
          $249 = $248&1;
          if ($249) {
           label = 128;
           break L178;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3389,($transfer|0));
        $250 = __THREW__; __THREW__ = 0;
        $251 = $250&1;
        if ($251) {
         label = 128;
         break;
        }
       }
       __THREW__ = 0;
       $252 = (invoke_iiiiii(192,($transfer|0),(586288|0),($19|0),($converter$i$i43|0),1)|0);
       $253 = __THREW__; __THREW__ = 0;
       $254 = $253&1;
       if ($254) {
        label = 128;
        break;
       }
       $255 = ($252|0)==(0);
       if (!($255)) {
        $256 = ($252|0)>(0);
        do {
         if ($256) {
          __THREW__ = 0;
          invoke_viii(1712,($transfer|0),($tangents|0),0);
          $257 = __THREW__; __THREW__ = 0;
          $258 = $257&1;
          if ($258) {
           label = 128;
           break L178;
          }
         } else {
          $259 = HEAP32[$converter$i$i43>>2]|0;
          $260 = ($259|0)==(0|0);
          if ($260) {
           break;
          }
          __THREW__ = 0;
          (invoke_iii($259|0,($tangents|0),($transfer|0))|0);
          $261 = __THREW__; __THREW__ = 0;
          $262 = $261&1;
          if ($262) {
           label = 128;
           break L178;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3389,($transfer|0));
        $263 = __THREW__; __THREW__ = 0;
        $264 = $263&1;
        if ($264) {
         label = 128;
         break;
        }
       }
       __THREW__ = 0;
       $265 = (invoke_iiiiii(192,($transfer|0),(586304|0),($19|0),($converter$i$i48|0),1)|0);
       $266 = __THREW__; __THREW__ = 0;
       $267 = $266&1;
       if ($267) {
        label = 128;
        break;
       }
       $268 = ($265|0)==(0);
       if (!($268)) {
        $269 = ($265|0)>(0);
        do {
         if ($269) {
          __THREW__ = 0;
          invoke_viii(1710,($transfer|0),($normals|0),0);
          $270 = __THREW__; __THREW__ = 0;
          $271 = $270&1;
          if ($271) {
           label = 128;
           break L178;
          }
         } else {
          $272 = HEAP32[$converter$i$i48>>2]|0;
          $273 = ($272|0)==(0|0);
          if ($273) {
           break;
          }
          __THREW__ = 0;
          (invoke_iii($272|0,($normals|0),($transfer|0))|0);
          $274 = __THREW__; __THREW__ = 0;
          $275 = $274&1;
          if ($275) {
           label = 128;
           break L178;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3389,($transfer|0));
        $276 = __THREW__; __THREW__ = 0;
        $277 = $276&1;
        if ($277) {
         label = 128;
         break;
        }
       }
       __THREW__ = 0;
       $278 = (invoke_iiiiii(192,($transfer|0),(586320|0),($19|0),($converter$i$i54|0),1)|0);
       $279 = __THREW__; __THREW__ = 0;
       $280 = $279&1;
       if ($280) {
        label = 128;
        break;
       }
       $281 = ($278|0)==(0);
       if (!($281)) {
        $282 = ($278|0)>(0);
        do {
         if ($282) {
          __THREW__ = 0;
          invoke_viii(1713,($transfer|0),($colors|0),0);
          $283 = __THREW__; __THREW__ = 0;
          $284 = $283&1;
          if ($284) {
           label = 128;
           break L178;
          }
         } else {
          $285 = HEAP32[$converter$i$i54>>2]|0;
          $286 = ($285|0)==(0|0);
          if ($286) {
           break;
          }
          __THREW__ = 0;
          (invoke_iii($285|0,($colors|0),($transfer|0))|0);
          $287 = __THREW__; __THREW__ = 0;
          $288 = $287&1;
          if ($288) {
           label = 128;
           break L178;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3389,($transfer|0));
        $289 = __THREW__; __THREW__ = 0;
        $290 = $289&1;
        if ($290) {
         label = 128;
         break;
        }
       }
       $291 = HEAP32[$198>>2]|0;
       $not$ = ($291|0)!=(0);
       $$ = $not$&1;
       $292 = HEAP32[$195>>2]|0;
       $293 = ($292|0)==(0);
       $294 = $$ | 128;
       $format$1 = $293 ? $$ : $294;
       $295 = HEAP32[$201>>2]|0;
       $296 = ($295|0)==(0);
       $297 = $format$1 | 2;
       $format$1$ = $296 ? $format$1 : $297;
       $298 = HEAP32[$204>>2]|0;
       $299 = ($298|0)==(0);
       $300 = $format$1$ | 8;
       $format$3 = $299 ? $format$1$ : $300;
       $301 = HEAP32[$207>>2]|0;
       $302 = ($301|0)==(0);
       $303 = $format$3 | 16;
       $format$3$ = $302 ? $format$3 : $303;
       $304 = HEAP32[$210>>2]|0;
       $305 = ($304|0)==(0);
       $306 = $format$3$ | 4;
       $format$5 = $305 ? $format$3$ : $306;
       $307 = HEAP32[$31>>2]|0;
       $308 = (($307) + 100|0);
       $309 = HEAP32[$308>>2]|0;
       $310 = ($309|0)==($291|0);
       if ($310) {
        $329 = (($307) + 96|0);
        $330 = HEAP32[$329>>2]|0;
        $331 = ($330|0)==($format$5|0);
        if ($331) {
         $359 = $291;$362 = $307;
        } else {
         label = 132;
        }
       } else {
        label = 132;
       }
       if ((label|0) == 132) {
        $332 = (($307) + 144|0);
        $333 = HEAP32[$332>>2]|0;
        $334 = ($333|0)==(0);
        do {
         if ($334) {
          $335 = (($this) + 92|0);
          $336 = HEAP32[$335>>2]|0;
          $337 = (($this) + 88|0);
          $338 = HEAP32[$337>>2]|0;
          $339 = ($336|0)==($338|0);
          if (!($339)) {
           label = 134;
           break;
          }
          $340 = (($307) + 8|0);
          __THREW__ = 0;
          invoke_vii(2684,($layout$i$i$i|0),($340|0));
          $341 = __THREW__; __THREW__ = 0;
          $342 = $341&1;
          if ($342) {
           label = 128;
           break L178;
          }
          $343 = (($layout$i$i$i) + 4|0);
          $344 = HEAP32[$343>>2]|0;
          $345 = $344 & 255;
          $346 = $345 ^ 255;
          $347 = (($layout$i$i$i) + 8|0);
          $348 = HEAP32[$347>>2]|0;
          $349 = $348 ^ -1;
          $350 = $346 & $349;
          $351 = (($layout$i$i$i) + 12|0);
          $352 = HEAP32[$351>>2]|0;
          $353 = $352 ^ -1;
          $354 = $350 & $353;
          HEAP32[$layout$i$i$i>>2] = $354;
          ;HEAP32[$13+0>>2]=HEAP32[$layout$i$i$i+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$layout$i$i$i+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$layout$i$i$i+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$layout$i$i$i+12>>2]|0;
         } else {
          label = 134;
         }
        } while(0);
        if ((label|0) == 134) {
         ;HEAP32[$13+0>>2]=HEAP32[588160+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[588160+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[588160+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[588160+12>>2]|0;
        }
        __THREW__ = 0;
        invoke_viiiiii(107,($this|0),($291|0),($format$5|0),0,(588176|0),($13|0));
        $355 = __THREW__; __THREW__ = 0;
        $356 = $355&1;
        if ($356) {
         label = 128;
         break;
        }
        $$pre162 = HEAP32[$198>>2]|0;
        $$pre163 = HEAP32[$31>>2]|0;
        $359 = $$pre162;$362 = $$pre163;
       }
       $357 = HEAP32[$vertices>>2]|0;
       $358 = ($291>>>0)<($359>>>0);
       $360 = $358 ? $291 : $359;
       $361 = (($362) + 10|0);
       $363 = HEAP8[$361>>0]|0;
       $364 = ($363<<24>>24)==(0);
       do {
        if ($364) {
         $365 = (($362) + 11|0);
         $366 = HEAP8[$365>>0]|0;
         $367 = ($366&255)<(3);
         if ($367) {
          $389 = 0;$862 = 0;
          break;
         }
         $368 = (($362) + 92|0);
         $369 = HEAP32[$368>>2]|0;
         $370 = ($369|0)==(0|0);
         if ($370) {
          $389 = 1;$862 = 0;
          break;
         }
         $371 = (($362) + 8|0);
         $372 = HEAP8[$371>>0]|0;
         $373 = $372&255;
         $374 = ((($362) + (($373*12)|0)|0) + 50|0);
         $375 = HEAP8[$374>>0]|0;
         $376 = $375&255;
         $377 = ((($362) + (($373*12)|0)|0) + 44|0);
         $378 = HEAP32[$377>>2]|0;
         $379 = (($362) + 9|0);
         $380 = HEAP8[$379>>0]|0;
         $381 = $380&255;
         $382 = (($381) + ($378))|0;
         $383 = (($369) + ($382)|0);
         $389 = $376;$862 = $383;
        } else {
         $389 = 0;$862 = 0;
        }
       } while(0);
       $384 = (($357) + (($360*12)|0)|0);
       $385 = ($360|0)==(0);
       if ($385) {
        $396 = $362;
       } else {
        $$01$i = $357;$386 = $862;
        while(1) {
         ;HEAP32[$386+0>>2]=HEAP32[$$01$i+0>>2]|0;HEAP32[$386+4>>2]=HEAP32[$$01$i+4>>2]|0;HEAP32[$386+8>>2]=HEAP32[$$01$i+8>>2]|0;
         $387 = (($$01$i) + 12|0);
         $388 = (($386) + ($389)|0);
         $390 = ($387|0)==($384|0);
         if ($390) {
          break;
         } else {
          $$01$i = $387;$386 = $388;
         }
        }
        $$pre = HEAP32[$31>>2]|0;
        $396 = $$pre;
       }
       $391 = HEAP32[$normals>>2]|0;
       $392 = HEAP32[$201>>2]|0;
       $393 = ($291>>>0)<($392>>>0);
       $394 = $393 ? $291 : $392;
       $395 = (($396) + 14|0);
       $397 = HEAP8[$395>>0]|0;
       $398 = ($397<<24>>24)==(0);
       do {
        if ($398) {
         $399 = (($396) + 15|0);
         $400 = HEAP8[$399>>0]|0;
         $401 = ($400&255)<(3);
         if ($401) {
          $423 = 0;$863 = 0;
          break;
         }
         $402 = (($396) + 92|0);
         $403 = HEAP32[$402>>2]|0;
         $404 = ($403|0)==(0|0);
         if ($404) {
          $423 = 1;$863 = 0;
          break;
         }
         $405 = (($396) + 12|0);
         $406 = HEAP8[$405>>0]|0;
         $407 = $406&255;
         $408 = ((($396) + (($407*12)|0)|0) + 50|0);
         $409 = HEAP8[$408>>0]|0;
         $410 = $409&255;
         $411 = ((($396) + (($407*12)|0)|0) + 44|0);
         $412 = HEAP32[$411>>2]|0;
         $413 = (($396) + 13|0);
         $414 = HEAP8[$413>>0]|0;
         $415 = $414&255;
         $416 = (($415) + ($412))|0;
         $417 = (($403) + ($416)|0);
         $423 = $410;$863 = $417;
        } else {
         $423 = 0;$863 = 0;
        }
       } while(0);
       $418 = (($391) + (($394*12)|0)|0);
       $419 = ($394|0)==(0);
       if ($419) {
        $430 = $396;
       } else {
        $$01$i64 = $391;$420 = $863;
        while(1) {
         ;HEAP32[$420+0>>2]=HEAP32[$$01$i64+0>>2]|0;HEAP32[$420+4>>2]=HEAP32[$$01$i64+4>>2]|0;HEAP32[$420+8>>2]=HEAP32[$$01$i64+8>>2]|0;
         $421 = (($$01$i64) + 12|0);
         $422 = (($420) + ($423)|0);
         $424 = ($421|0)==($418|0);
         if ($424) {
          break;
         } else {
          $$01$i64 = $421;$420 = $422;
         }
        }
        $$pre157 = HEAP32[$31>>2]|0;
        $430 = $$pre157;
       }
       $425 = HEAP32[$uvs>>2]|0;
       $426 = HEAP32[$204>>2]|0;
       $427 = ($291>>>0)<($426>>>0);
       $428 = $427 ? $291 : $426;
       $429 = (($430) + 22|0);
       $431 = HEAP8[$429>>0]|0;
       $432 = ($431<<24>>24)==(0);
       do {
        if ($432) {
         $433 = (($430) + 23|0);
         $434 = HEAP8[$433>>0]|0;
         $435 = ($434&255)<(2);
         if ($435) {
          $467 = 0;$864 = 0;
          break;
         }
         $436 = (($430) + 92|0);
         $437 = HEAP32[$436>>2]|0;
         $438 = ($437|0)==(0|0);
         if ($438) {
          $467 = 1;$864 = 0;
          break;
         }
         $439 = (($430) + 20|0);
         $440 = HEAP8[$439>>0]|0;
         $441 = $440&255;
         $442 = ((($430) + (($441*12)|0)|0) + 50|0);
         $443 = HEAP8[$442>>0]|0;
         $444 = $443&255;
         $445 = ((($430) + (($441*12)|0)|0) + 44|0);
         $446 = HEAP32[$445>>2]|0;
         $447 = (($430) + 21|0);
         $448 = HEAP8[$447>>0]|0;
         $449 = $448&255;
         $450 = (($449) + ($446))|0;
         $451 = (($437) + ($450)|0);
         $467 = $444;$864 = $451;
        } else {
         $467 = 0;$864 = 0;
        }
       } while(0);
       $452 = (($425) + ($428<<3)|0);
       $453 = ($428|0)==(0);
       if ($453) {
        $474 = $430;
       } else {
        $$01$i68 = $425;$461 = $864;
        while(1) {
         $454 = $$01$i68;
         $455 = $454;
         $456 = HEAP32[$455>>2]|0;
         $457 = (($454) + 4)|0;
         $458 = $457;
         $459 = HEAP32[$458>>2]|0;
         $460 = $461;
         $462 = $460;
         HEAP32[$462>>2] = $456;
         $463 = (($460) + 4)|0;
         $464 = $463;
         HEAP32[$464>>2] = $459;
         $465 = (($$01$i68) + 8|0);
         $466 = (($461) + ($467)|0);
         $468 = ($465|0)==($452|0);
         if ($468) {
          break;
         } else {
          $$01$i68 = $465;$461 = $466;
         }
        }
        $$pre158 = HEAP32[$31>>2]|0;
        $474 = $$pre158;
       }
       $469 = HEAP32[$uvs1>>2]|0;
       $470 = HEAP32[$207>>2]|0;
       $471 = ($291>>>0)<($470>>>0);
       $472 = $471 ? $291 : $470;
       $473 = (($474) + 26|0);
       $475 = HEAP8[$473>>0]|0;
       $476 = ($475<<24>>24)==(0);
       do {
        if ($476) {
         $477 = (($474) + 27|0);
         $478 = HEAP8[$477>>0]|0;
         $479 = ($478&255)<(2);
         if ($479) {
          $511 = 0;$865 = 0;
          break;
         }
         $480 = (($474) + 92|0);
         $481 = HEAP32[$480>>2]|0;
         $482 = ($481|0)==(0|0);
         if ($482) {
          $511 = 1;$865 = 0;
          break;
         }
         $483 = (($474) + 24|0);
         $484 = HEAP8[$483>>0]|0;
         $485 = $484&255;
         $486 = ((($474) + (($485*12)|0)|0) + 50|0);
         $487 = HEAP8[$486>>0]|0;
         $488 = $487&255;
         $489 = ((($474) + (($485*12)|0)|0) + 44|0);
         $490 = HEAP32[$489>>2]|0;
         $491 = (($474) + 25|0);
         $492 = HEAP8[$491>>0]|0;
         $493 = $492&255;
         $494 = (($493) + ($490))|0;
         $495 = (($481) + ($494)|0);
         $511 = $488;$865 = $495;
        } else {
         $511 = 0;$865 = 0;
        }
       } while(0);
       $496 = (($469) + ($472<<3)|0);
       $497 = ($472|0)==(0);
       if ($497) {
        $518 = $474;
       } else {
        $$01$i72 = $469;$505 = $865;
        while(1) {
         $498 = $$01$i72;
         $499 = $498;
         $500 = HEAP32[$499>>2]|0;
         $501 = (($498) + 4)|0;
         $502 = $501;
         $503 = HEAP32[$502>>2]|0;
         $504 = $505;
         $506 = $504;
         HEAP32[$506>>2] = $500;
         $507 = (($504) + 4)|0;
         $508 = $507;
         HEAP32[$508>>2] = $503;
         $509 = (($$01$i72) + 8|0);
         $510 = (($505) + ($511)|0);
         $512 = ($509|0)==($496|0);
         if ($512) {
          break;
         } else {
          $$01$i72 = $509;$505 = $510;
         }
        }
        $$pre159 = HEAP32[$31>>2]|0;
        $518 = $$pre159;
       }
       $513 = HEAP32[$tangents>>2]|0;
       $514 = HEAP32[$195>>2]|0;
       $515 = ($291>>>0)<($514>>>0);
       $516 = $515 ? $291 : $514;
       $517 = (($518) + 38|0);
       $519 = HEAP8[$517>>0]|0;
       $520 = ($519<<24>>24)==(0);
       do {
        if ($520) {
         $521 = (($518) + 39|0);
         $522 = HEAP8[$521>>0]|0;
         $523 = ($522&255)<(4);
         if ($523) {
          $545 = 0;$866 = 0;
          break;
         }
         $524 = (($518) + 92|0);
         $525 = HEAP32[$524>>2]|0;
         $526 = ($525|0)==(0|0);
         if ($526) {
          $545 = 1;$866 = 0;
          break;
         }
         $527 = (($518) + 36|0);
         $528 = HEAP8[$527>>0]|0;
         $529 = $528&255;
         $530 = ((($518) + (($529*12)|0)|0) + 50|0);
         $531 = HEAP8[$530>>0]|0;
         $532 = $531&255;
         $533 = ((($518) + (($529*12)|0)|0) + 44|0);
         $534 = HEAP32[$533>>2]|0;
         $535 = (($518) + 37|0);
         $536 = HEAP8[$535>>0]|0;
         $537 = $536&255;
         $538 = (($537) + ($534))|0;
         $539 = (($525) + ($538)|0);
         $545 = $532;$866 = $539;
        } else {
         $545 = 0;$866 = 0;
        }
       } while(0);
       $540 = (($513) + ($516<<4)|0);
       $541 = ($516|0)==(0);
       if ($541) {
        $552 = $518;
       } else {
        $$01$i80 = $513;$542 = $866;
        while(1) {
         ;HEAP32[$542+0>>2]=HEAP32[$$01$i80+0>>2]|0;HEAP32[$542+4>>2]=HEAP32[$$01$i80+4>>2]|0;HEAP32[$542+8>>2]=HEAP32[$$01$i80+8>>2]|0;HEAP32[$542+12>>2]=HEAP32[$$01$i80+12>>2]|0;
         $543 = (($$01$i80) + 16|0);
         $544 = (($542) + ($545)|0);
         $546 = ($543|0)==($540|0);
         if ($546) {
          break;
         } else {
          $$01$i80 = $543;$542 = $544;
         }
        }
        $$pre160 = HEAP32[$31>>2]|0;
        $552 = $$pre160;
       }
       $547 = HEAP32[$colors>>2]|0;
       $548 = HEAP32[$210>>2]|0;
       $549 = ($291>>>0)<($548>>>0);
       $550 = $549 ? $291 : $548;
       $551 = (($552) + 18|0);
       $553 = HEAP8[$551>>0]|0;
       $554 = ($553<<24>>24)==(2);
       do {
        if ($554) {
         $555 = (($552) + 19|0);
         $556 = HEAP8[$555>>0]|0;
         $557 = ($556&255)<(4);
         if ($557) {
          $580 = 0;$867 = 0;
          break;
         }
         $558 = (($552) + 92|0);
         $559 = HEAP32[$558>>2]|0;
         $560 = ($559|0)==(0|0);
         if ($560) {
          $580 = 1;$867 = 0;
          break;
         }
         $561 = (($552) + 16|0);
         $562 = HEAP8[$561>>0]|0;
         $563 = $562&255;
         $564 = ((($552) + (($563*12)|0)|0) + 50|0);
         $565 = HEAP8[$564>>0]|0;
         $566 = $565&255;
         $567 = ((($552) + (($563*12)|0)|0) + 44|0);
         $568 = HEAP32[$567>>2]|0;
         $569 = (($552) + 17|0);
         $570 = HEAP8[$569>>0]|0;
         $571 = $570&255;
         $572 = (($571) + ($568))|0;
         $573 = (($559) + ($572)|0);
         $580 = $566;$867 = $573;
        } else {
         $580 = 0;$867 = 0;
        }
       } while(0);
       $574 = (($547) + ($550<<2)|0);
       $575 = ($550|0)==(0);
       if (!($575)) {
        $$01$i90 = $547;$577 = $867;
        while(1) {
         $576 = HEAP32[$$01$i90>>2]|0;
         HEAP32[$577>>2] = $576;
         $578 = (($$01$i90) + 4|0);
         $579 = (($577) + ($580)|0);
         $581 = ($578|0)==($574|0);
         if ($581) {
          break;
         } else {
          $$01$i90 = $578;$577 = $579;
         }
        }
       }
       $582 = HEAP32[$211>>2]|0;
       $583 = ($582|0)>(-1);
       do {
        if ($583) {
         $584 = HEAP32[$212>>2]|0;
         HEAP32[$10>>2] = $584;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$10+0>>2]|0;
         invoke_vii(2591,($547|0),($$byval_copy15|0));
         $585 = __THREW__; __THREW__ = 0;
         $586 = $585&1;
         if ($586) {
          $319 = ___cxa_find_matching_catch()|0;
          $320 = tempRet0;
          $$0 = $320;$$01 = $319;
          label = 197;
          break L178;
         } else {
          HEAP32[$colors>>2] = 0;
          break;
         }
        }
       } while(0);
       $587 = HEAP32[$208>>2]|0;
       $588 = ($587|0)>(-1);
       do {
        if ($588) {
         $589 = HEAP32[$uvs1>>2]|0;
         $590 = HEAP32[$209>>2]|0;
         HEAP32[$9>>2] = $590;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$9+0>>2]|0;
         invoke_vii(2591,($589|0),($$byval_copy15|0));
         $591 = __THREW__; __THREW__ = 0;
         $592 = $591&1;
         if ($592) {
          $317 = ___cxa_find_matching_catch()|0;
          $318 = tempRet0;
          $$1 = $318;$$12 = $317;
          label = 200;
          break L178;
         } else {
          HEAP32[$uvs1>>2] = 0;
          break;
         }
        }
       } while(0);
       $593 = HEAP32[$205>>2]|0;
       $594 = ($593|0)>(-1);
       do {
        if ($594) {
         $595 = HEAP32[$uvs>>2]|0;
         $596 = HEAP32[$206>>2]|0;
         HEAP32[$8>>2] = $596;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$8+0>>2]|0;
         invoke_vii(2591,($595|0),($$byval_copy15|0));
         $597 = __THREW__; __THREW__ = 0;
         $598 = $597&1;
         if ($598) {
          $315 = ___cxa_find_matching_catch()|0;
          $316 = tempRet0;
          $$2 = $316;$$23 = $315;
          label = 203;
          break L178;
         } else {
          HEAP32[$uvs>>2] = 0;
          break;
         }
        }
       } while(0);
       $599 = HEAP32[$202>>2]|0;
       $600 = ($599|0)>(-1);
       do {
        if ($600) {
         $601 = HEAP32[$normals>>2]|0;
         $602 = HEAP32[$203>>2]|0;
         HEAP32[$7>>2] = $602;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$7+0>>2]|0;
         invoke_vii(2591,($601|0),($$byval_copy15|0));
         $603 = __THREW__; __THREW__ = 0;
         $604 = $603&1;
         if ($604) {
          $313 = ___cxa_find_matching_catch()|0;
          $314 = tempRet0;
          $$3 = $314;$$34 = $313;
          label = 206;
          break L178;
         } else {
          HEAP32[$normals>>2] = 0;
          break;
         }
        }
       } while(0);
       $605 = HEAP32[$199>>2]|0;
       $606 = ($605|0)>(-1);
       do {
        if ($606) {
         $607 = HEAP32[$vertices>>2]|0;
         $608 = HEAP32[$200>>2]|0;
         HEAP32[$6>>2] = $608;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$6+0>>2]|0;
         invoke_vii(2591,($607|0),($$byval_copy15|0));
         $609 = __THREW__; __THREW__ = 0;
         $610 = $609&1;
         if ($610) {
          $311 = ___cxa_find_matching_catch()|0;
          $312 = tempRet0;
          $$4 = $312;$$45 = $311;
          break L178;
         } else {
          HEAP32[$vertices>>2] = 0;
          break;
         }
        }
       } while(0);
       $611 = HEAP32[$196>>2]|0;
       $612 = ($611|0)>(-1);
       if (!($612)) {
        $868 = 0;
        label = 260;
        break L142;
       }
       $613 = HEAP32[$tangents>>2]|0;
       $614 = HEAP32[$197>>2]|0;
       HEAP32[$converter$i$i127>>2] = $614;
       ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$converter$i$i127+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId($613,$$byval_copy15);
       HEAP32[$tangents>>2] = 0;
       __ZN14CompressedMeshC2Ev($m_CompressedMesh);
       $750 = $m_CompressedMesh;$869 = 0;
       break L142;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 128) {
     $321 = ___cxa_find_matching_catch()|0;
     $322 = tempRet0;
     $323 = HEAP32[$211>>2]|0;
     $324 = ($323|0)>(-1);
     if ($324) {
      $325 = HEAP32[$colors>>2]|0;
      $326 = HEAP32[$212>>2]|0;
      HEAP32[$14>>2] = $326;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$14+0>>2]|0;
      invoke_vii(2591,($325|0),($$byval_copy15|0));
      $327 = __THREW__; __THREW__ = 0;
      $328 = $327&1;
      if ($328) {
       $860 = ___cxa_find_matching_catch(0|0)|0;
       $861 = tempRet0;
       ___clang_call_terminate($860);
       // unreachable;
      } else {
       HEAP32[$colors>>2] = 0;
       $$0 = $322;$$01 = $321;
       label = 197;
       break;
      }
     } else {
      $$0 = $322;$$01 = $321;
      label = 197;
     }
    }
   } while(0);
   do {
    if ((label|0) == 197) {
     $615 = HEAP32[$208>>2]|0;
     $616 = ($615|0)>(-1);
     if ($616) {
      $617 = HEAP32[$uvs1>>2]|0;
      $618 = HEAP32[$209>>2]|0;
      HEAP32[$5>>2] = $618;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_vii(2591,($617|0),($$byval_copy15|0));
      $619 = __THREW__; __THREW__ = 0;
      $620 = $619&1;
      if ($620) {
       $860 = ___cxa_find_matching_catch(0|0)|0;
       $861 = tempRet0;
       ___clang_call_terminate($860);
       // unreachable;
      } else {
       HEAP32[$uvs1>>2] = 0;
       $$1 = $$0;$$12 = $$01;
       label = 200;
       break;
      }
     } else {
      $$1 = $$0;$$12 = $$01;
      label = 200;
     }
    }
   } while(0);
   do {
    if ((label|0) == 200) {
     $621 = HEAP32[$205>>2]|0;
     $622 = ($621|0)>(-1);
     if ($622) {
      $623 = HEAP32[$uvs>>2]|0;
      $624 = HEAP32[$206>>2]|0;
      HEAP32[$4>>2] = $624;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($623|0),($$byval_copy15|0));
      $625 = __THREW__; __THREW__ = 0;
      $626 = $625&1;
      if ($626) {
       $860 = ___cxa_find_matching_catch(0|0)|0;
       $861 = tempRet0;
       ___clang_call_terminate($860);
       // unreachable;
      } else {
       HEAP32[$uvs>>2] = 0;
       $$2 = $$1;$$23 = $$12;
       label = 203;
       break;
      }
     } else {
      $$2 = $$1;$$23 = $$12;
      label = 203;
     }
    }
   } while(0);
   do {
    if ((label|0) == 203) {
     $627 = HEAP32[$202>>2]|0;
     $628 = ($627|0)>(-1);
     if ($628) {
      $629 = HEAP32[$normals>>2]|0;
      $630 = HEAP32[$203>>2]|0;
      HEAP32[$3>>2] = $630;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($629|0),($$byval_copy15|0));
      $631 = __THREW__; __THREW__ = 0;
      $632 = $631&1;
      if ($632) {
       $860 = ___cxa_find_matching_catch(0|0)|0;
       $861 = tempRet0;
       ___clang_call_terminate($860);
       // unreachable;
      } else {
       HEAP32[$normals>>2] = 0;
       $$3 = $$2;$$34 = $$23;
       label = 206;
       break;
      }
     } else {
      $$3 = $$2;$$34 = $$23;
      label = 206;
     }
    }
   } while(0);
   do {
    if ((label|0) == 206) {
     $633 = HEAP32[$199>>2]|0;
     $634 = ($633|0)>(-1);
     if ($634) {
      $635 = HEAP32[$vertices>>2]|0;
      $636 = HEAP32[$200>>2]|0;
      HEAP32[$2>>2] = $636;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($635|0),($$byval_copy15|0));
      $637 = __THREW__; __THREW__ = 0;
      $638 = $637&1;
      if ($638) {
       $860 = ___cxa_find_matching_catch(0|0)|0;
       $861 = tempRet0;
       ___clang_call_terminate($860);
       // unreachable;
      } else {
       HEAP32[$vertices>>2] = 0;
       $$4 = $$3;$$45 = $$34;
       break;
      }
     } else {
      $$4 = $$3;$$45 = $$34;
     }
    }
   } while(0);
   $639 = HEAP32[$196>>2]|0;
   $640 = ($639|0)>(-1);
   if (!($640)) {
    $$7 = $$4;$$78 = $$45;
    ___resumeException($$78|0);
    // unreachable;
   }
   $641 = HEAP32[$tangents>>2]|0;
   $642 = HEAP32[$197>>2]|0;
   HEAP32[$1>>2] = $642;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($641|0),($$byval_copy15|0));
   $643 = __THREW__; __THREW__ = 0;
   $644 = $643&1;
   if ($644) {
    $860 = ___cxa_find_matching_catch(0|0)|0;
    $861 = tempRet0;
    ___clang_call_terminate($860);
    // unreachable;
   }
   HEAP32[$tangents>>2] = 0;
   $$7 = $$4;$$78 = $$45;
   ___resumeException($$78|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 260) {
  __ZN14CompressedMeshC2Ev($m_CompressedMesh);
  $750 = $m_CompressedMesh;$869 = $868;
 }
 __THREW__ = 0;
 $741 = (invoke_iiiiii(192,($transfer|0),(586352|0),(587288|0),($$byval_copy15|0),1)|0);
 $742 = __THREW__; __THREW__ = 0;
 $743 = $742&1;
 do {
  if (!($743)) {
   $744 = ($741|0)==(0);
   if (!($744)) {
    $745 = ($741|0)>(0);
    if ($745) {
     __THREW__ = 0;
     invoke_vii(2686,($m_CompressedMesh|0),($transfer|0));
     $746 = __THREW__; __THREW__ = 0;
     $747 = $746&1;
     if ($747) {
      break;
     }
    } else {
     $748 = HEAP32[$$byval_copy15>>2]|0;
     $749 = ($748|0)==(0|0);
     if (!($749)) {
      __THREW__ = 0;
      (invoke_iii($748|0,($750|0),($transfer|0))|0);
      $751 = __THREW__; __THREW__ = 0;
      $752 = $751&1;
      if ($752) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($transfer|0));
    $753 = __THREW__; __THREW__ = 0;
    $754 = $753&1;
    if ($754) {
     break;
    }
   }
   if ($869) {
    $755 = (($transfer) + 136|0);
    $756 = HEAP8[$755>>0]|0;
    $757 = ($756<<24>>24)==(0);
    if (!($757)) {
     __THREW__ = 0;
     invoke_vii(2675,($m_CompressedMesh|0),($this|0));
     $758 = __THREW__; __THREW__ = 0;
     $759 = $758&1;
     if ($759) {
      break;
     }
    }
   }
   __ZN14CompressedMeshD2Ev($m_CompressedMesh);
   if (!($17)) {
    $760 = HEAP32[$31>>2]|0;
    $761 = (($760) + 18|0);
    $762 = HEAP8[$761>>0]|0;
    $763 = ($762<<24>>24)==(2);
    if ($763) {
     $764 = (($760) + 19|0);
     $765 = HEAP8[$764>>0]|0;
     $766 = ($765&255)<(4);
     if ($766) {
      $870 = 0;$871 = 0;
      label = 278;
     } else {
      $767 = (($760) + 92|0);
      $768 = HEAP32[$767>>2]|0;
      $769 = ($768|0)==(0|0);
      if ($769) {
       $872 = 1;$873 = 0;
      } else {
       $770 = (($760) + 16|0);
       $771 = HEAP8[$770>>0]|0;
       $772 = $771&255;
       $773 = ((($760) + (($772*12)|0)|0) + 50|0);
       $774 = HEAP8[$773>>0]|0;
       $775 = $774&255;
       $776 = ((($760) + (($772*12)|0)|0) + 44|0);
       $777 = HEAP32[$776>>2]|0;
       $778 = (($760) + 17|0);
       $779 = HEAP8[$778>>0]|0;
       $780 = $779&255;
       $781 = (($780) + ($777))|0;
       $782 = (($768) + ($781)|0);
       $872 = $775;$873 = $782;
      }
      if ($763) {
       $870 = $873;$871 = $872;
       label = 278;
      } else {
       $826 = $873;$827 = 0;$848 = $872;$850 = 0;$874 = 0;
      }
     }
     do {
      if ((label|0) == 278) {
       $783 = (($760) + 19|0);
       $784 = HEAP8[$783>>0]|0;
       $785 = ($784&255)<(4);
       do {
        if ($785) {
         $875 = 0;
        } else {
         $786 = (($760) + 92|0);
         $787 = HEAP32[$786>>2]|0;
         $788 = ($787|0)==(0|0);
         if ($788) {
          $875 = 0;
          break;
         }
         $789 = (($760) + 100|0);
         $790 = HEAP32[$789>>2]|0;
         $791 = (($760) + 16|0);
         $792 = HEAP8[$791>>0]|0;
         $793 = $792&255;
         $794 = ((($760) + (($793*12)|0)|0) + 50|0);
         $795 = HEAP8[$794>>0]|0;
         $796 = $795&255;
         $797 = ((($760) + (($793*12)|0)|0) + 44|0);
         $798 = HEAP32[$797>>2]|0;
         $799 = (($760) + 17|0);
         $800 = HEAP8[$799>>0]|0;
         $801 = $800&255;
         $802 = Math_imul($796, $790)|0;
         $803 = (($802) + ($798))|0;
         $804 = (($803) + ($801))|0;
         $805 = (($787) + ($804)|0);
         $875 = $805;
        }
       } while(0);
       if (!($763)) {
        $826 = $870;$827 = $875;$848 = $871;$850 = 0;$874 = 0;
        break;
       }
       $806 = (($760) + 19|0);
       $807 = HEAP8[$806>>0]|0;
       $808 = ($807&255)<(4);
       if ($808) {
        $826 = $870;$827 = $875;$848 = $871;$850 = 0;$874 = 0;
        break;
       }
       $809 = (($760) + 92|0);
       $810 = HEAP32[$809>>2]|0;
       $811 = ($810|0)==(0|0);
       if ($811) {
        $826 = $870;$827 = $875;$848 = $871;$850 = 1;$874 = 0;
        break;
       }
       $812 = (($760) + 16|0);
       $813 = HEAP8[$812>>0]|0;
       $814 = $813&255;
       $815 = ((($760) + (($814*12)|0)|0) + 50|0);
       $816 = HEAP8[$815>>0]|0;
       $817 = $816&255;
       $818 = ((($760) + (($814*12)|0)|0) + 44|0);
       $819 = HEAP32[$818>>2]|0;
       $820 = (($760) + 17|0);
       $821 = HEAP8[$820>>0]|0;
       $822 = $821&255;
       $823 = (($822) + ($819))|0;
       $824 = (($810) + ($823)|0);
       $826 = $870;$827 = $875;$848 = $871;$850 = $817;$874 = $824;
      }
     } while(0);
     $825 = ($826|0)==($827|0);
     if (!($825)) {
      $829 = $826;$846 = $874;
      while(1) {
       $828 = (($829) + 2|0);
       $830 = HEAP8[$828>>0]|0;
       $831 = (($829) + 1|0);
       $832 = HEAP8[$831>>0]|0;
       $833 = HEAP8[$829>>0]|0;
       $834 = (($829) + 3|0);
       $835 = HEAP8[$834>>0]|0;
       $836 = $835&255;
       $837 = $836 << 24;
       $838 = $833&255;
       $839 = $838 << 16;
       $840 = $832&255;
       $841 = $840 << 8;
       $842 = $830&255;
       $843 = $841 | $842;
       $844 = $843 | $839;
       $845 = $844 | $837;
       HEAP32[$846>>2] = $845;
       $847 = (($829) + ($848)|0);
       $849 = (($846) + ($850)|0);
       $851 = ($847|0)==($827|0);
       if ($851) {
        break;
       } else {
        $829 = $847;$846 = $849;
       }
      }
     }
    }
    HEAP8[$15>>0] = 1;
   }
   $852 = (($this) + 168|0);
   $853 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586376,587280,$$byval_copy15,1)|0);
   $854 = ($853|0)==(0);
   if ($854) {
    $858 = (($this) + 40|0);
    __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$858,586392,0);
    $859 = (($this) + 192|0);
    __ZN17CollisionMeshData8TransferI14SafeBinaryReadEEvRT_R4Mesh($859,$transfer,0);
    STACKTOP = sp;return;
   }
   $855 = ($853|0)>(0);
   if ($855) {
    __ZN4AABB8TransferI14SafeBinaryReadEEvRT_($852,$transfer);
   } else {
    $856 = HEAP32[$$byval_copy15>>2]|0;
    $857 = ($856|0)==(0|0);
    if (!($857)) {
     (FUNCTION_TABLE_iii[$856 & 4095]($852,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
   $858 = (($this) + 40|0);
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$858,586392,0);
   $859 = (($this) + 192|0);
   __ZN17CollisionMeshData8TransferI14SafeBinaryReadEEvRT_R4Mesh($859,$transfer,0);
   STACKTOP = sp;return;
  }
 } while(0);
 $737 = ___cxa_find_matching_catch()|0;
 $738 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3459,($m_CompressedMesh|0));
 $739 = __THREW__; __THREW__ = 0;
 $740 = $739&1;
 if ($740) {
  $860 = ___cxa_find_matching_catch(0|0)|0;
  $861 = tempRet0;
  ___clang_call_terminate($860);
  // unreachable;
 } else {
  $$7 = $738;$$78 = $737;
  ___resumeException($$78|0);
  // unreachable;
 }
}
function __ZN17CollisionMeshData8TransferI14SafeBinaryReadEEvRT_R4Mesh($this,$transfer,$mesh) {
 $this = $this|0;
 $transfer = $transfer|0;
 $mesh = $mesh|0;
 var $$0 = 0, $$01 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $bakedConcave = 0, $bakedConvex = 0, $converter$i$i = 0, $converter$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 56|0;
 $0 = sp;
 $1 = sp + 4|0;
 $converter$i$i9 = sp + 8|0;
 $converter$i$i = sp + 12|0;
 $2 = sp + 16|0;
 $bakedConvex = sp + 24|0;
 $bakedConcave = sp + 40|0;
 $3 = HEAP32[628512>>2]|0;
 HEAP32[$bakedConvex>>2] = 0;
 $4 = (($bakedConvex) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($bakedConvex) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($bakedConvex) + 12|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$bakedConcave>>2] = 0;
 $7 = (($bakedConcave) + 4|0);
 HEAP32[$7>>2] = $3;
 $8 = (($bakedConcave) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($bakedConcave) + 12|0);
 HEAP32[$9>>2] = 0;
 $10 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiiiii(192,($transfer|0),(586416|0),($10|0),($converter$i$i|0),1)|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L1: do {
  if ($13) {
   label = 20;
  } else {
   $14 = ($11|0)==(0);
   if (!($14)) {
    $15 = ($11|0)>(0);
    if ($15) {
     __THREW__ = 0;
     invoke_viii(1716,($transfer|0),($bakedConvex|0),0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 20;
      break;
     }
    } else {
     $18 = HEAP32[$converter$i$i>>2]|0;
     $19 = ($18|0)==(0|0);
     if (!($19)) {
      __THREW__ = 0;
      (invoke_iii($18|0,($bakedConvex|0),($transfer|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       label = 20;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($transfer|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 20;
     break;
    }
   }
   __THREW__ = 0;
   $24 = (invoke_iiiiii(192,($transfer|0),(586448|0),($10|0),($converter$i$i9|0),1)|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 20;
   } else {
    $27 = ($24|0)==(0);
    if (!($27)) {
     $28 = ($24|0)>(0);
     if ($28) {
      __THREW__ = 0;
      invoke_viii(1716,($transfer|0),($bakedConcave|0),0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 20;
       break;
      }
     } else {
      $31 = HEAP32[$converter$i$i9>>2]|0;
      $32 = ($31|0)==(0|0);
      if (!($32)) {
       __THREW__ = 0;
       (invoke_iii($31|0,($bakedConcave|0),($transfer|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        label = 20;
        break;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3389,($transfer|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 20;
      break;
     }
    }
    __THREW__ = 0;
    $37 = (invoke_i(83)|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 20;
    } else {
     $40 = HEAP32[$5>>2]|0;
     $41 = ($40|0)==(0);
     if (!($41)) {
      $42 = HEAP32[$37>>2]|0;
      $43 = (($42) + 60|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = HEAP32[$bakedConvex>>2]|0;
      __THREW__ = 0;
      $46 = (invoke_iiiii($44|0,($37|0),1,($45|0),($40|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 20;
       break;
      }
      $49 = (($this) + 8|0);
      HEAP32[$49>>2] = $46;
     }
     $60 = HEAP32[$8>>2]|0;
     $61 = ($60|0)==(0);
     if (!($61)) {
      $62 = HEAP32[$37>>2]|0;
      $63 = (($62) + 60|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = HEAP32[$bakedConcave>>2]|0;
      __THREW__ = 0;
      $66 = (invoke_iiiii($64|0,($37|0),0,($65|0),($60|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 20;
       break;
      }
      $69 = (($this) + 12|0);
      HEAP32[$69>>2] = $66;
     }
     $70 = HEAP32[$9>>2]|0;
     $71 = ($70|0)>(-1);
     do {
      if ($71) {
       $72 = HEAP32[$bakedConcave>>2]|0;
       $73 = HEAP32[$7>>2]|0;
       HEAP32[$0>>2] = $73;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($72|0),($$byval_copy3|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        $50 = ___cxa_find_matching_catch()|0;
        $51 = tempRet0;
        $$0 = $50;$$01 = $51;
        break L1;
       } else {
        HEAP32[$bakedConcave>>2] = 0;
        break;
       }
      }
     } while(0);
     $76 = HEAP32[$6>>2]|0;
     $77 = ($76|0)>(-1);
     if (!($77)) {
      STACKTOP = sp;return;
     }
     $78 = HEAP32[$bakedConvex>>2]|0;
     $79 = HEAP32[$4>>2]|0;
     HEAP32[$0>>2] = $79;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($78,$$byval_copy3);
     HEAP32[$bakedConvex>>2] = 0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   $52 = ___cxa_find_matching_catch()|0;
   $53 = tempRet0;
   $54 = HEAP32[$9>>2]|0;
   $55 = ($54|0)>(-1);
   if ($55) {
    $56 = HEAP32[$bakedConcave>>2]|0;
    $57 = HEAP32[$7>>2]|0;
    HEAP32[$1>>2] = $57;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($56|0),($$byval_copy3|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     $86 = ___cxa_find_matching_catch(0|0)|0;
     $87 = tempRet0;
     ___clang_call_terminate($86);
     // unreachable;
    } else {
     HEAP32[$bakedConcave>>2] = 0;
     $$0 = $52;$$01 = $53;
     break;
    }
   } else {
    $$0 = $52;$$01 = $53;
   }
  }
 } while(0);
 $80 = HEAP32[$6>>2]|0;
 $81 = ($80|0)>(-1);
 if (!($81)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $82 = HEAP32[$bakedConvex>>2]|0;
 $83 = HEAP32[$4>>2]|0;
 HEAP32[$2>>2] = $83;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy3|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch(0|0)|0;
  $87 = tempRet0;
  ___clang_call_terminate($86);
  // unreachable;
 }
 HEAP32[$bakedConvex>>2] = 0;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN14CompressedMesh8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $converter$i$i16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i16 = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586256,587304,$converter$i$i16,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   __ZN17PackedFloatVector8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  } else {
   $3 = HEAP32[$converter$i$i16>>2]|0;
   $4 = ($3|0)==(0|0);
   if (!($4)) {
    (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $5 = (($this) + 28|0);
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586272,587304,$converter$i$i16,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN17PackedFloatVector8TransferI14SafeBinaryReadEEvRT_($5,$transfer);
  } else {
   $9 = HEAP32[$converter$i$i16>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($5,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 56|0);
 $12 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586304,587304,$converter$i$i16,1)|0);
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = ($12|0)>(0);
  if ($14) {
   __ZN17PackedFloatVector8TransferI14SafeBinaryReadEEvRT_($11,$transfer);
  } else {
   $15 = HEAP32[$converter$i$i16>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    (FUNCTION_TABLE_iii[$15 & 4095]($11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $17 = (($this) + 104|0);
 $18 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586288,587304,$converter$i$i16,1)|0);
 $19 = ($18|0)==(0);
 if (!($19)) {
  $20 = ($18|0)>(0);
  if ($20) {
   __ZN17PackedFloatVector8TransferI14SafeBinaryReadEEvRT_($17,$transfer);
  } else {
   $21 = HEAP32[$converter$i$i16>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    (FUNCTION_TABLE_iii[$21 & 4095]($17,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $23 = (($this) + 180|0);
 $24 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586544,587304,$converter$i$i16,1)|0);
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = ($24|0)>(0);
  if ($26) {
   __ZN15PackedIntVector8TransferI14SafeBinaryReadEEvRT_($23,$transfer);
  } else {
   $27 = HEAP32[$converter$i$i16>>2]|0;
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    (FUNCTION_TABLE_iii[$27 & 4095]($23,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $29 = (($this) + 84|0);
 $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586560,587304,$converter$i$i16,1)|0);
 $31 = ($30|0)==(0);
 if (!($31)) {
  $32 = ($30|0)>(0);
  if ($32) {
   __ZN15PackedIntVector8TransferI14SafeBinaryReadEEvRT_($29,$transfer);
  } else {
   $33 = HEAP32[$converter$i$i16>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    (FUNCTION_TABLE_iii[$33 & 4095]($29,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $35 = (($this) + 132|0);
 $36 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586576,587304,$converter$i$i16,1)|0);
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = ($36|0)>(0);
  if ($38) {
   __ZN15PackedIntVector8TransferI14SafeBinaryReadEEvRT_($35,$transfer);
  } else {
   $39 = HEAP32[$converter$i$i16>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    (FUNCTION_TABLE_iii[$39 & 4095]($35,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $41 = (($this) + 152|0);
 $42 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586592,587304,$converter$i$i16,1)|0);
 $43 = ($42|0)==(0);
 if (!($43)) {
  $44 = ($42|0)>(0);
  if ($44) {
   __ZN17PackedFloatVector8TransferI14SafeBinaryReadEEvRT_($41,$transfer);
  } else {
   $45 = HEAP32[$converter$i$i16>>2]|0;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    (FUNCTION_TABLE_iii[$45 & 4095]($41,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $47 = (($this) + 200|0);
 $48 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586608,587304,$converter$i$i16,1)|0);
 $49 = ($48|0)==(0);
 if (!($49)) {
  $50 = ($48|0)>(0);
  if ($50) {
   __ZN15PackedIntVector8TransferI14SafeBinaryReadEEvRT_($47,$transfer);
  } else {
   $51 = HEAP32[$converter$i$i16>>2]|0;
   $52 = ($51|0)==(0|0);
   if (!($52)) {
    (FUNCTION_TABLE_iii[$51 & 4095]($47,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $53 = (($this) + 220|0);
 $54 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586624,587304,$converter$i$i16,1)|0);
 $55 = ($54|0)==(0);
 if ($55) {
  $59 = (($this) + 240|0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$59,586640,0);
  STACKTOP = sp;return;
 }
 $56 = ($54|0)>(0);
 if ($56) {
  __ZN15PackedIntVector8TransferI14SafeBinaryReadEEvRT_($53,$transfer);
 } else {
  $57 = HEAP32[$converter$i$i16>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   (FUNCTION_TABLE_iii[$57 & 4095]($53,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $59 = (($this) + 240|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$59,586640,0);
 STACKTOP = sp;return;
}
function __ZN15PackedIntVector8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,586656,0);
 $0 = (($this) + 8|0);
 $1 = HEAP32[580760>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586672,$1,$converter$i$i1,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIhNS1_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[580744>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586680,$8,$converter$i$i1,0)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 do {
  if ($11) {
   $12 = (($transfer) + 12|0);
   $13 = (($transfer) + 80|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($transfer) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($transfer) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($transfer) + 32|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = Math_imul($22, $20)|0;
   $$sum$i$i$i$i$i = (($16) - ($23))|0;
   $24 = (($18) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$12>>2] = $24;
   $25 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($25)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $26 = (($18) + ($$sum1$i$i$i$i$i)|0);
    $27 = (($transfer) + 20|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($26>>>0)>($28>>>0);
    if (!($29)) {
     $30 = HEAP8[$24>>0]|0;
     HEAP8[$7>>0] = $30;
     $31 = HEAP32[$12>>2]|0;
     $32 = (($31) + 1|0);
     HEAP32[$12>>2] = $32;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($12,$7,1);
  } else {
   $33 = HEAP32[$converter$i$i1>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    (FUNCTION_TABLE_iii[$33 & 4095]($7,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIhNS1_9allocatorIhEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 HEAP32[$size>>2] = $7;
 $8 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIhNS0_9allocatorIhEEEEEvRT_j($data,$9);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$size>>2]|0;
 $12 = ($11|0)==(0);
 do {
  if (!($12)) {
   $13 = HEAP32[580744>>2]|0;
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$13,0,0)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($10|0);
    L8: do {
     if (!($27)) {
      $28 = (($this) + 12|0);
      $29 = (($this) + 16|0);
      $30 = (($this) + 28|0);
      $31 = (($this) + 32|0);
      $32 = (($this) + 20|0);
      $34 = 0;$37 = $23;$66 = $26;
      while(1) {
       $33 = Math_imul($34, $19)|0;
       $35 = (($33) + ($25))|0;
       $36 = (($37) + 20|0);
       HEAP32[$36>>2] = $35;
       $38 = (($37) + 12|0);
       HEAP32[$38>>2] = $35;
       $39 = (($37) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$37);
       $40 = $1;
       $41 = $40;
       $42 = HEAP32[$41>>2]|0;
       $43 = (($40) + 4)|0;
       $44 = $43;
       $45 = HEAP32[$44>>2]|0;
       $46 = $39;
       $47 = $46;
       HEAP32[$47>>2] = $42;
       $48 = (($46) + 4)|0;
       $49 = $48;
       HEAP32[$49>>2] = $45;
       $50 = HEAP32[$20>>2]|0;
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 1)|0;
       HEAP32[$50>>2] = $52;
       $53 = HEAP32[$15>>2]|0;
       $54 = (($53) + 12|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = HEAP32[$29>>2]|0;
       $57 = HEAP32[$30>>2]|0;
       $58 = HEAP32[$31>>2]|0;
       $59 = Math_imul($58, $57)|0;
       $$sum$i$i$i = (($55) - ($59))|0;
       $60 = (($56) + ($$sum$i$i$i)|0);
       HEAP32[$28>>2] = $60;
       $61 = ($$sum$i$i$i|0)<(0);
       if ($61) {
        label = 9;
       } else {
        $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
        $62 = (($56) + ($$sum1$i$i$i)|0);
        $63 = HEAP32[$32>>2]|0;
        $64 = ($62>>>0)>($63>>>0);
        if ($64) {
         label = 9;
        } else {
         $65 = HEAP8[$60>>0]|0;
         HEAP8[$66>>0] = $65;
         $67 = HEAP32[$28>>2]|0;
         $68 = (($67) + 1|0);
         HEAP32[$28>>2] = $68;
        }
       }
       if ((label|0) == 9) {
        label = 0;
        __ZN12CachedReader15UpdateReadCacheEPvj($28,$66,1);
       }
       $69 = (($66) + 1|0);
       $70 = ($69|0)==($10|0);
       if ($70) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$15>>2]|0;
       $34 = $$pre8;$37 = $$pre9;$66 = $69;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $71 = HEAP32[$data>>2]|0;
   $72 = ($71|0)==($10|0);
   if (!($72)) {
    $73 = (($this) + 12|0);
    $74 = (($this) + 16|0);
    $75 = (($this) + 28|0);
    $76 = (($this) + 32|0);
    $77 = (($this) + 20|0);
    $94 = $71;
    while(1) {
     $78 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$13,$converter$i$i,0)|0);
     $79 = ($78|0)==(0);
     if (!($79)) {
      $80 = ($78|0)>(0);
      do {
       if ($80) {
        $81 = HEAP32[$15>>2]|0;
        $82 = (($81) + 12|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = HEAP32[$74>>2]|0;
        $85 = HEAP32[$75>>2]|0;
        $86 = HEAP32[$76>>2]|0;
        $87 = Math_imul($86, $85)|0;
        $$sum$i$i$i$i$i = (($83) - ($87))|0;
        $88 = (($84) + ($$sum$i$i$i$i$i)|0);
        HEAP32[$73>>2] = $88;
        $89 = ($$sum$i$i$i$i$i|0)<(0);
        if (!($89)) {
         $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
         $90 = (($84) + ($$sum1$i$i$i$i$i)|0);
         $91 = HEAP32[$77>>2]|0;
         $92 = ($90>>>0)>($91>>>0);
         if (!($92)) {
          $93 = HEAP8[$88>>0]|0;
          HEAP8[$94>>0] = $93;
          $95 = HEAP32[$73>>2]|0;
          $96 = (($95) + 1|0);
          HEAP32[$73>>2] = $96;
          break;
         }
        }
        __ZN12CachedReader15UpdateReadCacheEPvj($73,$94,1);
       } else {
        $97 = HEAP32[$converter$i$i>>2]|0;
        $98 = ($97|0)==(0|0);
        if (!($98)) {
         (FUNCTION_TABLE_iii[$97 & 4095]($94,$this)|0);
        }
       }
      } while(0);
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($94) + 1|0);
     $100 = ($99|0)==($10|0);
     if ($100) {
      break;
     } else {
      $94 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN17PackedFloatVector8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,586656,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,586696,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,586704,0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[580760>>2]|0;
 $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586672,$3,$converter$i$i1,1)|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = ($4|0)>(0);
  if ($6) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIhNS1_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$2,0);
  } else {
   $7 = HEAP32[$converter$i$i1>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    (FUNCTION_TABLE_iii[$7 & 4095]($2,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $9 = (($this) + 12|0);
 $10 = HEAP32[580744>>2]|0;
 $11 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586680,$10,$converter$i$i1,0)|0);
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = ($11|0)>(0);
 do {
  if ($13) {
   $14 = (($transfer) + 12|0);
   $15 = (($transfer) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($transfer) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($transfer) + 28|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($transfer) + 32|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = Math_imul($24, $22)|0;
   $$sum$i$i$i$i$i = (($18) - ($25))|0;
   $26 = (($20) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$14>>2] = $26;
   $27 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($27)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $28 = (($20) + ($$sum1$i$i$i$i$i)|0);
    $29 = (($transfer) + 20|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($28>>>0)>($30>>>0);
    if (!($31)) {
     $32 = HEAP8[$26>>0]|0;
     HEAP8[$9>>0] = $32;
     $33 = HEAP32[$14>>2]|0;
     $34 = (($33) + 1|0);
     HEAP32[$14>>2] = $34;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($14,$9,1);
  } else {
   $35 = HEAP32[$converter$i$i1>>2]|0;
   $36 = ($35|0)==(0|0);
   if (!($36)) {
    (FUNCTION_TABLE_iii[$35 & 4095]($9,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11ColorRGBA32Lj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $1 = sp + 12|0;
 $size = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$data>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($data) + 4|0);
  HEAP32[$11>>2] = $10;
 }
 $12 = (($data) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14>>>0)<($6>>>0);
 do {
  if ($15) {
   $16 = ($13|0)>(-1);
   if ($16) {
    HEAP32[$12>>2] = $6;
    $17 = $6 << 2;
    $18 = (($data) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    HEAP32[$1>>2] = $19;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($7,$17,4,$$byval_copy1,0,585592,370)|0);
    HEAP32[$data>>2] = $20;
    $29 = $20;
    break;
   } else {
    $21 = $6 << 2;
    $22 = (($data) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    HEAP32[$1>>2] = $23;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,4,$$byval_copy1,0,585592,352)|0);
    $25 = HEAP32[$data>>2]|0;
    $26 = HEAP32[$3>>2]|0;
    $27 = $26 << 2;
    _memcpy(($24|0),($25|0),($27|0))|0;
    HEAP32[$12>>2] = $6;
    HEAP32[$data>>2] = $24;
    $29 = $24;
    break;
   }
  } else {
   $29 = $7;
  }
 } while(0);
 HEAP32[$3>>2] = $6;
 $28 = (($29) + ($6<<2)|0);
 $30 = HEAP32[$size>>2]|0;
 $31 = ($30|0)==(0);
 do {
  if (!($31)) {
   $32 = HEAP32[580560>>2]|0;
   $33 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$32,0,1)|0);
   $34 = (($this) + 80|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (__ZNK16TypeTreeIterator7GetNodeEv($35)|0);
   $37 = (($36) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($this) + 84|0);
   $40 = HEAP32[$39>>2]|0;
   HEAP32[$40>>2] = 0;
   $41 = ($33|0)==(2);
   if ($41) {
    $42 = HEAP32[$34>>2]|0;
    $43 = (($42) + 12|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = HEAP32[$data>>2]|0;
    $46 = ($45|0)==($28|0);
    L17: do {
     if (!($46)) {
      $48 = 0;$51 = $42;$i$03 = $45;
      while(1) {
       $47 = Math_imul($48, $38)|0;
       $49 = (($47) + ($44))|0;
       $50 = (($51) + 20|0);
       HEAP32[$50>>2] = $49;
       $52 = (($51) + 12|0);
       HEAP32[$52>>2] = $49;
       $53 = (($51) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$51);
       $54 = $2;
       $55 = $54;
       $56 = HEAP32[$55>>2]|0;
       $57 = (($54) + 4)|0;
       $58 = $57;
       $59 = HEAP32[$58>>2]|0;
       $60 = $53;
       $61 = $60;
       HEAP32[$61>>2] = $56;
       $62 = (($60) + 4)|0;
       $63 = $62;
       HEAP32[$63>>2] = $59;
       $64 = HEAP32[$39>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = (($65) + 1)|0;
       HEAP32[$64>>2] = $66;
       __ZN14SafeBinaryRead10SetVersionEi($this,2);
       $67 = HEAP32[$this>>2]|0;
       $68 = $67 & 512;
       $69 = ($68|0)==(0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$i$03,586712,0);
       if (!($69)) {
        $70 = HEAP32[$i$03>>2]|0;
        $71 = (_llvm_bswap_i32(($70|0))|0);
        HEAP32[$i$03>>2] = $71;
       }
       $72 = (($i$03) + 4|0);
       $73 = ($72|0)==($28|0);
       if ($73) {
        break L17;
       }
       $$pre = HEAP32[$39>>2]|0;
       $$pre7 = HEAP32[$$pre>>2]|0;
       $$pre8 = HEAP32[$34>>2]|0;
       $48 = $$pre7;$51 = $$pre8;$i$03 = $72;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $74 = HEAP32[$data>>2]|0;
   $75 = ($74|0)==($28|0);
   if (!($75)) {
    $i$14 = $74;
    while(1) {
     $76 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$32,$$byval_copy1,1)|0);
     $77 = ($76|0)==(0);
     if (!($77)) {
      $78 = ($76|0)>(0);
      if ($78) {
       __ZN14SafeBinaryRead10SetVersionEi($this,2);
       $79 = HEAP32[$this>>2]|0;
       $80 = $79 & 512;
       $81 = ($80|0)==(0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$i$14,586712,0);
       if (!($81)) {
        $82 = HEAP32[$i$14>>2]|0;
        $83 = (_llvm_bswap_i32(($82|0))|0);
        HEAP32[$i$14>>2] = $83;
       }
      } else {
       $84 = HEAP32[$$byval_copy1>>2]|0;
       $85 = ($84|0)==(0|0);
       if (!($85)) {
        (FUNCTION_TABLE_iii[$84 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $86 = (($i$14) + 4|0);
     $87 = ($86|0)==($28|0);
     if ($87) {
      break;
     } else {
      $i$14 = $86;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI8Vector4fLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI8Vector4fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<4)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580784>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$i$01 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$33);
       $36 = $2;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$01,586520,0);
       $49 = (($i$01) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,586528,0);
       $50 = (($i$01) + 8|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,586536,0);
       $51 = (($i$01) + 12|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$51,586720,0);
       $52 = (($i$01) + 16|0);
       $53 = ($52|0)==($11|0);
       if ($53) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$16>>2]|0;
       $30 = $$pre6;$33 = $$pre7;$i$01 = $52;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $54 = HEAP32[$data>>2]|0;
   $55 = ($54|0)==($11|0);
   if (!($55)) {
    $i$12 = $54;
    while(1) {
     $56 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$14,$$byval_copy,1)|0);
     $57 = ($56|0)==(0);
     if (!($57)) {
      $58 = ($56|0)>(0);
      if ($58) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$12,586520,0);
       $59 = (($i$12) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$59,586528,0);
       $60 = (($i$12) + 8|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$60,586536,0);
       $61 = (($i$12) + 12|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$61,586720,0);
      } else {
       $62 = HEAP32[$$byval_copy>>2]|0;
       $63 = ($62|0)==(0|0);
       if (!($63)) {
        (FUNCTION_TABLE_iii[$62 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $64 = (($i$12) + 16|0);
     $65 = ($64|0)==($11|0);
     if ($65) {
      break;
     } else {
      $i$12 = $64;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI8Vector2fLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI8Vector2fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<3)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580768>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$i$01 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$33);
       $36 = $2;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$01,586520,0);
       $49 = (($i$01) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,586528,0);
       $50 = (($i$01) + 8|0);
       $51 = ($50|0)==($11|0);
       if ($51) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$16>>2]|0;
       $30 = $$pre6;$33 = $$pre7;$i$01 = $50;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $52 = HEAP32[$data>>2]|0;
   $53 = ($52|0)==($11|0);
   if (!($53)) {
    $i$12 = $52;
    while(1) {
     $54 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$14,$$byval_copy,1)|0);
     $55 = ($54|0)==(0);
     if (!($55)) {
      $56 = ($54|0)>(0);
      if ($56) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$12,586520,0);
       $57 = (($i$12) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$57,586528,0);
      } else {
       $58 = HEAP32[$$byval_copy>>2]|0;
       $59 = ($58|0)==(0|0);
       if (!($59)) {
        (FUNCTION_TABLE_iii[$58 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $60 = (($i$12) + 8|0);
     $61 = ($60|0)==($11|0);
     if ($61) {
      break;
     } else {
      $i$12 = $60;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i$14 = 0;
 var $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $1 = sp + 16|0;
 $size = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$data>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (($data) + 4|0);
  HEAP32[$11>>2] = $8;
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;HEAP32[$1+28>>2]=0|0;
 __ZN13dynamic_arrayI13BoneInfluenceLj16EE18resize_initializedEjRKS0_b($data,$6,$1,0);
 $12 = HEAP32[$data>>2]|0;
 $13 = HEAP32[$3>>2]|0;
 $14 = (($12) + ($13<<5)|0);
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)==(0);
 do {
  if (!($16)) {
   $17 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587336,0,1)|0);
   $18 = (($this) + 80|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (__ZNK16TypeTreeIterator7GetNodeEv($19)|0);
   $21 = (($20) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($this) + 84|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$24>>2] = 0;
   $25 = ($17|0)==(2);
   if ($25) {
    $26 = HEAP32[$18>>2]|0;
    $27 = (($26) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$data>>2]|0;
    $30 = ($29|0)==($14|0);
    L11: do {
     if (!($30)) {
      $32 = 0;$35 = $26;$i$03 = $29;
      while(1) {
       $31 = Math_imul($32, $22)|0;
       $33 = (($31) + ($28))|0;
       $34 = (($35) + 20|0);
       HEAP32[$34>>2] = $33;
       $36 = (($35) + 12|0);
       HEAP32[$36>>2] = $33;
       $37 = (($35) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$35);
       $38 = $2;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = (($38) + 4)|0;
       $42 = $41;
       $43 = HEAP32[$42>>2]|0;
       $44 = $37;
       $45 = $44;
       HEAP32[$45>>2] = $40;
       $46 = (($44) + 4)|0;
       $47 = $46;
       HEAP32[$47>>2] = $43;
       $48 = HEAP32[$23>>2]|0;
       $49 = HEAP32[$48>>2]|0;
       $50 = (($49) + 1)|0;
       HEAP32[$48>>2] = $50;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$03,586728,0);
       $51 = (($i$03) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$51,586744,0);
       $52 = (($i$03) + 8|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$52,586760,0);
       $53 = (($i$03) + 12|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$53,586776,0);
       $54 = (($i$03) + 16|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$54,586792,0);
       $55 = (($i$03) + 20|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$55,586808,0);
       $56 = (($i$03) + 24|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$56,586824,0);
       $57 = (($i$03) + 28|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$57,586840,0);
       $58 = (($i$03) + 32|0);
       $59 = ($58|0)==($14|0);
       if ($59) {
        break L11;
       }
       $$pre = HEAP32[$23>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$18>>2]|0;
       $32 = $$pre8;$35 = $$pre9;$i$03 = $58;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $60 = HEAP32[$data>>2]|0;
   $61 = ($60|0)==($14|0);
   if (!($61)) {
    $i$14 = $60;
    while(1) {
     $62 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587336,$1,1)|0);
     $63 = ($62|0)==(0);
     if (!($63)) {
      $64 = ($62|0)>(0);
      if ($64) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$14,586728,0);
       $65 = (($i$14) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$65,586744,0);
       $66 = (($i$14) + 8|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$66,586760,0);
       $67 = (($i$14) + 12|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$67,586776,0);
       $68 = (($i$14) + 16|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$68,586792,0);
       $69 = (($i$14) + 20|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$69,586808,0);
       $70 = (($i$14) + 24|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$70,586824,0);
       $71 = (($i$14) + 28|0);
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$71,586840,0);
      } else {
       $72 = HEAP32[$1>>2]|0;
       $73 = ($72|0)==(0|0);
       if (!($73)) {
        (FUNCTION_TABLE_iii[$72 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $74 = (($i$14) + 32|0);
     $75 = ($74|0)==($14|0);
     if ($75) {
      break;
     } else {
      $i$14 = $74;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 HEAP32[$size>>2] = $7;
 $8 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEvRT_j($data,$9);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$size>>2]|0;
 $12 = ($11|0)==(0);
 do {
  if (!($12)) {
   $13 = HEAP32[580744>>2]|0;
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$13,0,0)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($10|0);
    L8: do {
     if (!($27)) {
      $28 = (($this) + 12|0);
      $29 = (($this) + 16|0);
      $30 = (($this) + 28|0);
      $31 = (($this) + 32|0);
      $32 = (($this) + 20|0);
      $34 = 0;$37 = $23;$66 = $26;
      while(1) {
       $33 = Math_imul($34, $19)|0;
       $35 = (($33) + ($25))|0;
       $36 = (($37) + 20|0);
       HEAP32[$36>>2] = $35;
       $38 = (($37) + 12|0);
       HEAP32[$38>>2] = $35;
       $39 = (($37) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$37);
       $40 = $1;
       $41 = $40;
       $42 = HEAP32[$41>>2]|0;
       $43 = (($40) + 4)|0;
       $44 = $43;
       $45 = HEAP32[$44>>2]|0;
       $46 = $39;
       $47 = $46;
       HEAP32[$47>>2] = $42;
       $48 = (($46) + 4)|0;
       $49 = $48;
       HEAP32[$49>>2] = $45;
       $50 = HEAP32[$20>>2]|0;
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 1)|0;
       HEAP32[$50>>2] = $52;
       $53 = HEAP32[$15>>2]|0;
       $54 = (($53) + 12|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = HEAP32[$29>>2]|0;
       $57 = HEAP32[$30>>2]|0;
       $58 = HEAP32[$31>>2]|0;
       $59 = Math_imul($58, $57)|0;
       $$sum$i$i$i = (($55) - ($59))|0;
       $60 = (($56) + ($$sum$i$i$i)|0);
       HEAP32[$28>>2] = $60;
       $61 = ($$sum$i$i$i|0)<(0);
       if ($61) {
        label = 9;
       } else {
        $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
        $62 = (($56) + ($$sum1$i$i$i)|0);
        $63 = HEAP32[$32>>2]|0;
        $64 = ($62>>>0)>($63>>>0);
        if ($64) {
         label = 9;
        } else {
         $65 = HEAP8[$60>>0]|0;
         HEAP8[$66>>0] = $65;
         $67 = HEAP32[$28>>2]|0;
         $68 = (($67) + 1|0);
         HEAP32[$28>>2] = $68;
        }
       }
       if ((label|0) == 9) {
        label = 0;
        __ZN12CachedReader15UpdateReadCacheEPvj($28,$66,1);
       }
       $69 = (($66) + 1|0);
       $70 = ($69|0)==($10|0);
       if ($70) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$15>>2]|0;
       $34 = $$pre8;$37 = $$pre9;$66 = $69;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $71 = HEAP32[$data>>2]|0;
   $72 = ($71|0)==($10|0);
   if (!($72)) {
    $73 = (($this) + 12|0);
    $74 = (($this) + 16|0);
    $75 = (($this) + 28|0);
    $76 = (($this) + 32|0);
    $77 = (($this) + 20|0);
    $94 = $71;
    while(1) {
     $78 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$13,$converter$i$i,0)|0);
     $79 = ($78|0)==(0);
     if (!($79)) {
      $80 = ($78|0)>(0);
      do {
       if ($80) {
        $81 = HEAP32[$15>>2]|0;
        $82 = (($81) + 12|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = HEAP32[$74>>2]|0;
        $85 = HEAP32[$75>>2]|0;
        $86 = HEAP32[$76>>2]|0;
        $87 = Math_imul($86, $85)|0;
        $$sum$i$i$i$i$i = (($83) - ($87))|0;
        $88 = (($84) + ($$sum$i$i$i$i$i)|0);
        HEAP32[$73>>2] = $88;
        $89 = ($$sum$i$i$i$i$i|0)<(0);
        if (!($89)) {
         $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
         $90 = (($84) + ($$sum1$i$i$i$i$i)|0);
         $91 = HEAP32[$77>>2]|0;
         $92 = ($90>>>0)>($91>>>0);
         if (!($92)) {
          $93 = HEAP8[$88>>0]|0;
          HEAP8[$94>>0] = $93;
          $95 = HEAP32[$73>>2]|0;
          $96 = (($95) + 1|0);
          HEAP32[$73>>2] = $96;
          break;
         }
        }
        __ZN12CachedReader15UpdateReadCacheEPvj($73,$94,1);
       } else {
        $97 = HEAP32[$converter$i$i>>2]|0;
        $98 = ($97|0)==(0|0);
        if (!($98)) {
         (FUNCTION_TABLE_iii[$97 & 4095]($94,$this)|0);
        }
       }
      } while(0);
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($94) + 1|0);
     $100 = ($99|0)==($10|0);
     if ($100) {
      break;
     } else {
      $94 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$13 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayIjLj4EEE19ResizeSTLStyleArrayERS1_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<2)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580752>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $74 = HEAP32[$data>>2]|0;
    $75 = ($74|0)==($11|0);
    if ($75) {
     break;
    } else {
     $i$13 = $74;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$i$13,586480,0);
     $76 = (($i$13) + 4|0);
     $77 = ($76|0)==($11|0);
     if ($77) {
      break L4;
     } else {
      $i$13 = $76;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$i$01 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($2,$38);
      $41 = $2;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = HEAP32[$61>>2]|0;
        HEAP32[$i$01>>2] = $66;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$i$01,4);
      }
      $67 = HEAP32[$this>>2]|0;
      $68 = $67 & 512;
      $69 = ($68|0)==(0);
      if (!($69)) {
       $70 = HEAP32[$i$01>>2]|0;
       $71 = (_llvm_bswap_i32(($70|0))|0);
       HEAP32[$i$01>>2] = $71;
      }
      $72 = (($i$01) + 4|0);
      $73 = ($72|0)==($11|0);
      if ($73) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre6 = HEAP32[$$pre>>2]|0;
      $$pre7 = HEAP32[$16>>2]|0;
      $35 = $$pre6;$38 = $$pre7;$i$01 = $72;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI10Matrix4x4fLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI10Matrix4x4fLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<6)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587352,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN10Matrix4x4f8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 64|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587352,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN10Matrix4x4f8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 64|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4f8TransferI14SafeBinaryReadEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$this,586856,0);
 $0 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$0,586864,0);
 $1 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$1,586872,0);
 $2 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$2,586880,0);
 $3 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$3,586888,0);
 $4 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$4,586896,0);
 $5 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$5,586904,0);
 $6 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$6,586912,0);
 $7 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$7,586920,0);
 $8 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$8,586928,0);
 $9 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$9,586936,0);
 $10 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$10,586944,0);
 $11 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$11,586952,0);
 $12 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$12,586960,0);
 $13 = (($this) + 44|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$13,586968,0);
 $14 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($t,$14,586976,0);
 STACKTOP = sp;return;
}
function __ZN14BlendShapeData8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 $0 = HEAP32[580760>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,586984,$0,$converter$i$i3,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI16BlendShapeVertexLj4EEEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 16|0);
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587000,$0,$converter$i$i3,1)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  if ($9) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI10BlendShapeLj4EEEEvRT_17TransferMetaFlags($transfer,$6,0);
  } else {
   $10 = HEAP32[$converter$i$i3>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    (FUNCTION_TABLE_iii[$10 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $12 = (($this) + 32|0);
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587008,$0,$converter$i$i3,1)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI17BlendShapeChannelNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$12,0);
  } else {
   $16 = HEAP32[$converter$i$i3>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    (FUNCTION_TABLE_iii[$16 & 4095]($12,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $18 = (($this) + 44|0);
 $19 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587024,$0,$converter$i$i3,1)|0);
 $20 = ($19|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = ($19|0)>(0);
 if ($21) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIfLj4EEEEvRT_17TransferMetaFlags($transfer,$18,0);
 } else {
  $22 = HEAP32[$converter$i$i3>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   (FUNCTION_TABLE_iii[$22 & 4095]($18,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI17BlendShapeChannelNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI17BlendShapeChannelNS0_9allocatorIS2_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587384,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN17BlendShapeChannel8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 16|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587384,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN17BlendShapeChannel8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 16|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN17BlendShapeChannel8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $tempStr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 24|0;
 $0 = sp;
 $tempStr$i = sp + 4|0;
 $1 = sp + 16|0;
 $converter$i$i = sp + 20|0;
 $2 = HEAP32[580712>>2]|0;
 $3 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587040,$2,$converter$i$i,1)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $40 = (($this) + 4|0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$40,587048,0);
  $41 = (($this) + 8|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$41,587064,0);
  $42 = (($this) + 12|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$42,587080,0);
  STACKTOP = sp;return;
 }
 $5 = ($3|0)>(0);
 do {
  if ($5) {
   ;HEAP32[$tempStr$i+0>>2]=0|0;HEAP32[$tempStr$i+4>>2]=0|0;HEAP32[$tempStr$i+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viii(1620,($transfer|0),($tempStr$i|0),0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $19 = HEAP8[$tempStr$i>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     $24 = (($tempStr$i) + 1|0);
     $26 = $24;
    } else {
     $22 = (($tempStr$i) + 8|0);
     $23 = HEAP32[$22>>2]|0;
     $26 = $23;
    }
    $25 = HEAP32[628448>>2]|0;
    HEAP32[$1>>2] = $25;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viii(1621,($this|0),($26|0),($$byval_copy2|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = HEAP8[$tempStr$i>>0]|0;
     $30 = $29 & 1;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      break;
     }
     $32 = (($tempStr$i) + 8|0);
     $33 = HEAP32[$32>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($33|0),($$byval_copy2|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      break;
     }
     $36 = ___cxa_find_matching_catch()|0;
     $37 = tempRet0;
     ___cxa_call_unexpected(($36|0));
     // unreachable;
    }
   }
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   $10 = HEAP8[$tempStr$i>>0]|0;
   $11 = $10 & 1;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    ___resumeException($8|0);
    // unreachable;
   }
   $13 = (($tempStr$i) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($14|0),($$byval_copy2|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $17 = ___cxa_find_matching_catch()|0;
    $18 = tempRet0;
    ___cxa_call_unexpected(($17|0));
    // unreachable;
   } else {
    ___resumeException($8|0);
    // unreachable;
   }
  } else {
   $38 = HEAP32[$converter$i$i>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    (FUNCTION_TABLE_iii[$38 & 4095]($this,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $40 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$40,587048,0);
 $41 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$41,587064,0);
 $42 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$42,587080,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI10BlendShapeLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI10BlendShapeLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*12)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587408,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN15SerializeTraitsI10BlendShapeE8TransferI14SafeBinaryReadEEvRS0_RT_($i$01,$this);
       $48 = (($i$01) + 12|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587408,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN15SerializeTraitsI10BlendShapeE8TransferI14SafeBinaryReadEEvRS0_RT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 12|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI10BlendShapeE8TransferI14SafeBinaryReadEEvRS0_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i2 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$data,587096,0);
 $0 = (($data) + 4|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$0,587112,0);
 $1 = (($data) + 8|0);
 $2 = HEAP32[580544>>2]|0;
 $3 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587128,$2,$converter$i$i1,0)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ($3|0)>(0);
  do {
   if ($5) {
    $6 = (($transfer) + 12|0);
    $7 = (($transfer) + 80|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 12|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($transfer) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($transfer) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($transfer) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = Math_imul($16, $14)|0;
    $$sum$i$i$i$i$i2 = (($10) - ($17))|0;
    $18 = (($12) + ($$sum$i$i$i$i$i2)|0);
    HEAP32[$6>>2] = $18;
    $19 = ($$sum$i$i$i$i$i2|0)<(0);
    if (!($19)) {
     $$sum1$i$i$i$i$i3 = (($$sum$i$i$i$i$i2) + 1)|0;
     $20 = (($12) + ($$sum1$i$i$i$i$i3)|0);
     $21 = (($transfer) + 20|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($20>>>0)>($22>>>0);
     if (!($23)) {
      $24 = HEAP8[$18>>0]|0;
      HEAP8[$1>>0] = $24;
      $25 = HEAP32[$6>>2]|0;
      $26 = (($25) + 1|0);
      HEAP32[$6>>2] = $26;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($6,$1,1);
   } else {
    $27 = HEAP32[$converter$i$i1>>2]|0;
    $28 = ($27|0)==(0|0);
    if (!($28)) {
     (FUNCTION_TABLE_iii[$27 & 4095]($1,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $29 = (($data) + 9|0);
 $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587144,$2,$converter$i$i1,0)|0);
 $31 = ($30|0)==(0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = ($30|0)>(0);
 do {
  if ($32) {
   $33 = (($transfer) + 12|0);
   $34 = (($transfer) + 80|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($transfer) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($transfer) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($transfer) + 32|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = Math_imul($43, $41)|0;
   $$sum$i$i$i$i$i = (($37) - ($44))|0;
   $45 = (($39) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$33>>2] = $45;
   $46 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($46)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $47 = (($39) + ($$sum1$i$i$i$i$i)|0);
    $48 = (($transfer) + 20|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($47>>>0)>($49>>>0);
    if (!($50)) {
     $51 = HEAP8[$45>>0]|0;
     HEAP8[$29>>0] = $51;
     $52 = HEAP32[$33>>2]|0;
     $53 = (($52) + 1|0);
     HEAP32[$33>>2] = $53;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($33,$29,1);
  } else {
   $54 = HEAP32[$converter$i$i1>>2]|0;
   $55 = ($54|0)==(0|0);
   if (!($55)) {
    (FUNCTION_TABLE_iii[$54 & 4095]($29,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI16BlendShapeVertexLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI16BlendShapeVertexLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*40)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587424,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN15SerializeTraitsI16BlendShapeVertexE8TransferI14SafeBinaryReadEEvRS0_RT_($i$01,$this);
       $48 = (($i$01) + 40|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587424,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN15SerializeTraitsI16BlendShapeVertexE8TransferI14SafeBinaryReadEEvRS0_RT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 40|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI16BlendShapeVertexE8TransferI14SafeBinaryReadEEvRS0_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 $0 = HEAP32[580776>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587160,$0,$converter$i$i3,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$data,586520,0);
   $4 = (($data) + 4|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$4,586528,0);
   $5 = (($data) + 8|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,586536,0);
  } else {
   $6 = HEAP32[$converter$i$i3>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    (FUNCTION_TABLE_iii[$6 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $8 = (($data) + 12|0);
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587168,$0,$converter$i$i3,1)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = ($9|0)>(0);
  if ($11) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$8,586520,0);
   $12 = (($data) + 16|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,586528,0);
   $13 = (($data) + 20|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,586536,0);
  } else {
   $14 = HEAP32[$converter$i$i3>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    (FUNCTION_TABLE_iii[$14 & 4095]($8,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $16 = (($data) + 24|0);
 $17 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587176,$0,$converter$i$i3,1)|0);
 $18 = ($17|0)==(0);
 if ($18) {
  $24 = (($data) + 36|0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$24,587184,0);
  STACKTOP = sp;return;
 }
 $19 = ($17|0)>(0);
 if ($19) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,586520,0);
  $20 = (($data) + 28|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$20,586528,0);
  $21 = (($data) + 32|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$21,586536,0);
 } else {
  $22 = HEAP32[$converter$i$i3>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   (FUNCTION_TABLE_iii[$22 & 4095]($16,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $24 = (($data) + 36|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$24,587184,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI7SubMesh13stl_allocatorIS3_L18MemLabelIdentifier10ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,587272,587272,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI7SubMesh13stl_allocatorIS2_L18MemLabelIdentifier10ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587448,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN7SubMesh8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 56|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,586480,587448,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN7SubMesh8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 56|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7SubMesh8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $triStrip = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 4|0;
 $triStrip = sp;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$0,587192,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$1,587208,0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,587224,0);
 $2 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$2,587096,0);
 $3 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$3,587112,0);
 $4 = (($this) + 32|0);
 $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587240,587280,$converter$i$i,1)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = ($5|0)>(0);
  if ($7) {
   __ZN4AABB8TransferI14SafeBinaryReadEEvRT_($4,$transfer);
  } else {
   $8 = HEAP32[$converter$i$i>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    (FUNCTION_TABLE_iii[$8 & 4095]($4,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $10 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,1)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$triStrip,587256,0);
 $11 = HEAP32[$triStrip>>2]|0;
 $12 = ($11|0)!=(0);
 $13 = $12&1;
 HEAP32[$this>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN4Mesh8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$6 = 0, $$67 = 0, $$7 = 0, $$78 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dummyIndexContainer = 0, $dummySkin = 0, $dummyVertexData = 0, $p$i$i$i18 = 0, $p$i$i$i26 = 0, $size$i$i$i$i17 = 0, $size$i$i$i$i25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 496|0;
 $$byval_copy3 = sp + 248|0;
 $0 = sp + 184|0;
 $1 = sp + 176|0;
 $2 = sp + 172|0;
 $size$i$i$i$i25 = sp + 168|0;
 $p$i$i$i26 = sp + 136|0;
 $size$i$i$i$i17 = sp + 120|0;
 $p$i$i$i18 = sp + 492|0;
 $dummySkin = sp + 104|0;
 $dummyVertexData = sp;
 $dummyIndexContainer = sp + 124|0;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,8);
 $3 = (($this) + 276|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 __ZN4Mesh21UnswizzleVertexColorsEb($this,1);
 $6 = (($this) + 44|0);
 $7 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586064,$7,$6,1);
 $8 = (($0) + 32|0);
 $9 = (($$byval_copy3) + 12|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$$byval_copy3+8>>2]=HEAP32[616680+8>>2]|0;
 ;HEAP32[$9+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[616680+8>>2]|0;
 ;HEAP32[$8+0>>2]=HEAP32[$$byval_copy3+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$$byval_copy3+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$$byval_copy3+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$$byval_copy3+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$$byval_copy3+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$$byval_copy3+20>>2]|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$$byval_copy3,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,587448,$0,0);
 __ZN7SubMesh8TransferI13ProxyTransferEEvRT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586080,587368,$10,1);
 __ZN14BlendShapeData8TransferI13ProxyTransferEEvRT_($10,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $11 = (($this) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 120|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586096,$7,$13,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$$byval_copy3,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,587352,$0,0);
 __ZN10Matrix4x4f8TransferI13ProxyTransferEEvRT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($this) + 116|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586112,$7,$14,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$$byval_copy3,0);
 $15 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,$15,$0,0);
 $16 = (($transfer) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($transfer) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 132|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586136,$15,$22,1);
 $23 = HEAP32[$16>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$19>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $27 = (($this) + 32|0);
 $28 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586160,$28,$27,1);
 $29 = HEAP32[$16>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$19>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = (($this) + 33|0);
 $34 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586184,$34,$33,1);
 $35 = HEAP32[$16>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$19>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $39 = (($this) + 34|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586200,$34,$39,1);
 $40 = HEAP32[$16>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$19>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = (($this) + 35|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586216,$34,$44,1);
 $45 = HEAP32[$16>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$19>>2]|0;
 $48 = ((($46) + (($47*24)|0)|0) + 12|0);
 HEAP32[$48>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $49 = HEAP8[$27>>0]|0;
 $50 = ($49<<24>>24)==(0);
 L1: do {
  if ($50) {
   label = 3;
  } else {
   $51 = HEAP32[$transfer>>2]|0;
   $52 = $51 & 16384;
   $53 = ($52|0)==(0);
   if ($53) {
    HEAP32[$dummySkin>>2] = 0;
    $65 = (($dummySkin) + 8|0);
    HEAP32[$65>>2] = 0;
    $66 = (($dummySkin) + 12|0);
    HEAP32[$66>>2] = 0;
    $67 = (($dummySkin) + 4|0);
    HEAP32[$67>>2] = 61;
    __THREW__ = 0;
    invoke_vi(3452,($dummyVertexData|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    L4: do {
     if ($69) {
      label = 30;
     } else {
      HEAP32[$dummyIndexContainer>>2] = 0;
      $70 = (($dummyIndexContainer) + 4|0);
      HEAP32[$70>>2] = 0;
      $71 = (($dummyIndexContainer) + 8|0);
      HEAP32[$71>>2] = 0;
      $72 = HEAP32[580760>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(86,($transfer|0),(586232|0),($72|0),($dummyIndexContainer|0),1);
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      do {
       if (!($74)) {
        __THREW__ = 0;
        invoke_viiiii(87,($transfer|0),(587272|0),(587272|0),($size$i$i$i$i17|0),0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if (!($76)) {
         __THREW__ = 0;
         invoke_viiiii(86,($transfer|0),(586480|0),($28|0),($p$i$i$i18|0),0);
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if (!($78)) {
          $79 = HEAP32[$16>>2]|0;
          $80 = HEAP32[$79>>2]|0;
          $81 = HEAP32[$19>>2]|0;
          $82 = ((($80) + (($81*24)|0)|0) + 12|0);
          HEAP32[$82>>2] = 1;
          __THREW__ = 0;
          invoke_vi(3390,($transfer|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if (!($84)) {
           __THREW__ = 0;
           invoke_vi(3391,($transfer|0));
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if (!($86)) {
            __THREW__ = 0;
            invoke_vi(3392,($transfer|0));
            $87 = __THREW__; __THREW__ = 0;
            $88 = $87&1;
            if (!($88)) {
             __THREW__ = 0;
             invoke_vi(3390,($transfer|0));
             $89 = __THREW__; __THREW__ = 0;
             $90 = $89&1;
             if (!($90)) {
              __THREW__ = 0;
              invoke_viiiii(86,($transfer|0),(586248|0),($72|0),($dummySkin|0),1);
              $91 = __THREW__; __THREW__ = 0;
              $92 = $91&1;
              if (!($92)) {
               __THREW__ = 0;
               invoke_viiiii(87,($transfer|0),(587272|0),(587272|0),($size$i$i$i$i25|0),0);
               $93 = __THREW__; __THREW__ = 0;
               $94 = $93&1;
               if (!($94)) {
                __THREW__ = 0;
                invoke_viiiii(86,($transfer|0),(586480|0),(587336|0),($p$i$i$i26|0),0);
                $95 = __THREW__; __THREW__ = 0;
                $96 = $95&1;
                if (!($96)) {
                 __THREW__ = 0;
                 invoke_vii(2687,($p$i$i$i26|0),($transfer|0));
                 $97 = __THREW__; __THREW__ = 0;
                 $98 = $97&1;
                 if (!($98)) {
                  __THREW__ = 0;
                  invoke_vi(3390,($transfer|0));
                  $99 = __THREW__; __THREW__ = 0;
                  $100 = $99&1;
                  if (!($100)) {
                   __THREW__ = 0;
                   invoke_vi(3391,($transfer|0));
                   $101 = __THREW__; __THREW__ = 0;
                   $102 = $101&1;
                   if (!($102)) {
                    __THREW__ = 0;
                    invoke_vi(3390,($transfer|0));
                    $103 = __THREW__; __THREW__ = 0;
                    $104 = $103&1;
                    if (!($104)) {
                     __THREW__ = 0;
                     invoke_viiiii(86,($transfer|0),(586336|0),(587320|0),($dummyVertexData|0),1);
                     $105 = __THREW__; __THREW__ = 0;
                     $106 = $105&1;
                     if ($106) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(2688,($dummyVertexData|0),($transfer|0));
                     $107 = __THREW__; __THREW__ = 0;
                     $108 = $107&1;
                     if ($108) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3390,($transfer|0));
                     $109 = __THREW__; __THREW__ = 0;
                     $110 = $109&1;
                     if ($110) {
                      break;
                     }
                     $111 = HEAP32[$dummyIndexContainer>>2]|0;
                     $112 = ($111|0)==(0|0);
                     do {
                      if (!($112)) {
                       $113 = HEAP32[$70>>2]|0;
                       $114 = ($113|0)==($111|0);
                       if (!($114)) {
                        HEAP32[$70>>2] = $111;
                       }
                       HEAP32[$2>>2] = 8;
                       __THREW__ = 0;
                       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
                       invoke_vii(2591,($111|0),($$byval_copy3|0));
                       $115 = __THREW__; __THREW__ = 0;
                       $116 = $115&1;
                       if (!($116)) {
                        break;
                       }
                       $117 = ___cxa_find_matching_catch()|0;
                       $118 = tempRet0;
                       ___cxa_call_unexpected(($117|0));
                       // unreachable;
                      }
                     } while(0);
                     __THREW__ = 0;
                     invoke_vi(3456,($dummyVertexData|0));
                     $119 = __THREW__; __THREW__ = 0;
                     $120 = $119&1;
                     if ($120) {
                      label = 30;
                      break L4;
                     }
                     $121 = HEAP32[$66>>2]|0;
                     $122 = ($121|0)>(-1);
                     if (!($122)) {
                      break L1;
                     }
                     $123 = HEAP32[$dummySkin>>2]|0;
                     $124 = HEAP32[$67>>2]|0;
                     HEAP32[$0>>2] = $124;
                     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
                     __Z19free_alloc_internalPv10MemLabelId($123,$$byval_copy3);
                     HEAP32[$dummySkin>>2] = 0;
                     break L1;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      } while(0);
      $127 = ___cxa_find_matching_catch()|0;
      $128 = tempRet0;
      $129 = HEAP32[$dummyIndexContainer>>2]|0;
      $130 = ($129|0)==(0|0);
      if (!($130)) {
       $131 = HEAP32[$70>>2]|0;
       $132 = ($131|0)==($129|0);
       if (!($132)) {
        HEAP32[$70>>2] = $129;
       }
       HEAP32[$1>>2] = 8;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($129|0),($$byval_copy3|0));
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       if ($134) {
        $135 = ___cxa_find_matching_catch()|0;
        $136 = tempRet0;
        ___cxa_call_unexpected(($135|0));
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_vi(3456,($dummyVertexData|0));
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       $257 = ___cxa_find_matching_catch(0|0)|0;
       $258 = tempRet0;
       ___clang_call_terminate($257);
       // unreachable;
      } else {
       $$6 = $128;$$67 = $127;
      }
     }
    } while(0);
    if ((label|0) == 30) {
     $125 = ___cxa_find_matching_catch()|0;
     $126 = tempRet0;
     $$6 = $126;$$67 = $125;
    }
    $139 = HEAP32[$66>>2]|0;
    $140 = ($139|0)>(-1);
    if (!($140)) {
     $$7 = $$6;$$78 = $$67;
     ___resumeException($$78|0);
     // unreachable;
    }
    $141 = HEAP32[$dummySkin>>2]|0;
    $142 = HEAP32[$67>>2]|0;
    HEAP32[$0>>2] = $142;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($141|0),($$byval_copy3|0));
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if ($144) {
     $257 = ___cxa_find_matching_catch(0|0)|0;
     $258 = tempRet0;
     ___clang_call_terminate($257);
     // unreachable;
    }
    HEAP32[$dummySkin>>2] = 0;
    $$7 = $$6;$$78 = $$67;
    ___resumeException($$78|0);
    // unreachable;
   } else {
    label = 3;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $54 = HEAP32[$11>>2]|0;
  $55 = (($54) + 108|0);
  $56 = HEAP32[580760>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586232,$56,$55,1);
  __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$$byval_copy3,0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,$28,$0,0);
  $57 = HEAP32[$16>>2]|0;
  $58 = HEAP32[$57>>2]|0;
  $59 = HEAP32[$19>>2]|0;
  $60 = ((($58) + (($59*24)|0)|0) + 12|0);
  HEAP32[$60>>2] = 1;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
  __ZN13ProxyTransfer5AlignEv($transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $61 = HEAP32[$11>>2]|0;
  $62 = (($61) + 136|0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586248,$56,$62,1);
  __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$$byval_copy3,0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,587336,$0,0);
  __ZN13BoneInfluence8TransferI13ProxyTransferEEvRT_($0,$transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $63 = HEAP32[$11>>2]|0;
  $64 = (($63) + 8|0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586336,587320,$64,1);
  __ZN10VertexData8TransferI13ProxyTransferEEvRT_($64,$transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
 }
 __ZN14CompressedMeshC2Ev($$byval_copy3);
 __THREW__ = 0;
 invoke_vi(3392,($transfer|0));
 $145 = __THREW__; __THREW__ = 0;
 $146 = $145&1;
 if (!($146)) {
  __THREW__ = 0;
  invoke_viiiii(86,($transfer|0),(586352|0),(587288|0),($$byval_copy3|0),1);
  $151 = __THREW__; __THREW__ = 0;
  $152 = $151&1;
  if (!($152)) {
   __THREW__ = 0;
   invoke_vii(2689,($$byval_copy3|0),($transfer|0));
   $153 = __THREW__; __THREW__ = 0;
   $154 = $153&1;
   if (!($154)) {
    __THREW__ = 0;
    invoke_vi(3390,($transfer|0));
    $155 = __THREW__; __THREW__ = 0;
    $156 = $155&1;
    if (!($156)) {
     __ZN14CompressedMeshD2Ev($$byval_copy3);
     if ($5) {
      $249 = (($this) + 168|0);
      __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586376,587280,$249,1);
      __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$249,586488,0);
      $250 = (($this) + 180|0);
      __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$250,586504,0);
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      $251 = (($this) + 40|0);
      $252 = HEAP32[580592>>2]|0;
      __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586392,$252,$251,1);
      $253 = HEAP32[$16>>2]|0;
      $254 = HEAP32[$253>>2]|0;
      $255 = HEAP32[$19>>2]|0;
      $256 = ((($254) + (($255*24)|0)|0) + 12|0);
      HEAP32[$256>>2] = 4;
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      __ZN17CollisionMeshData8TransferI13ProxyTransferEEvRT_R4Mesh(0,$transfer,0);
      STACKTOP = sp;return;
     }
     $157 = HEAP32[$11>>2]|0;
     $158 = (($157) + 18|0);
     $159 = HEAP8[$158>>0]|0;
     $160 = ($159<<24>>24)==(2);
     if ($160) {
      $161 = (($157) + 19|0);
      $162 = HEAP8[$161>>0]|0;
      $163 = ($162&255)<(4);
      if ($163) {
       $259 = 0;$260 = 0;
       label = 51;
      } else {
       $164 = (($157) + 92|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ($165|0)==(0|0);
       if ($166) {
        $261 = 1;$262 = 0;
       } else {
        $167 = (($157) + 16|0);
        $168 = HEAP8[$167>>0]|0;
        $169 = $168&255;
        $170 = ((($157) + (($169*12)|0)|0) + 50|0);
        $171 = HEAP8[$170>>0]|0;
        $172 = $171&255;
        $173 = ((($157) + (($169*12)|0)|0) + 44|0);
        $174 = HEAP32[$173>>2]|0;
        $175 = (($157) + 17|0);
        $176 = HEAP8[$175>>0]|0;
        $177 = $176&255;
        $178 = (($177) + ($174))|0;
        $179 = (($165) + ($178)|0);
        $261 = $172;$262 = $179;
       }
       if ($160) {
        $259 = $262;$260 = $261;
        label = 51;
       } else {
        $223 = $262;$224 = 0;$245 = $261;$247 = 0;$263 = 0;
       }
      }
      if ((label|0) == 51) {
       $180 = (($157) + 19|0);
       $181 = HEAP8[$180>>0]|0;
       $182 = ($181&255)<(4);
       if ($182) {
        $264 = 0;
       } else {
        $183 = (($157) + 92|0);
        $184 = HEAP32[$183>>2]|0;
        $185 = ($184|0)==(0|0);
        if ($185) {
         $264 = 0;
        } else {
         $186 = (($157) + 100|0);
         $187 = HEAP32[$186>>2]|0;
         $188 = (($157) + 16|0);
         $189 = HEAP8[$188>>0]|0;
         $190 = $189&255;
         $191 = ((($157) + (($190*12)|0)|0) + 50|0);
         $192 = HEAP8[$191>>0]|0;
         $193 = $192&255;
         $194 = ((($157) + (($190*12)|0)|0) + 44|0);
         $195 = HEAP32[$194>>2]|0;
         $196 = (($157) + 17|0);
         $197 = HEAP8[$196>>0]|0;
         $198 = $197&255;
         $199 = Math_imul($193, $187)|0;
         $200 = (($199) + ($195))|0;
         $201 = (($200) + ($198))|0;
         $202 = (($184) + ($201)|0);
         $264 = $202;
        }
       }
       if ($160) {
        $203 = (($157) + 19|0);
        $204 = HEAP8[$203>>0]|0;
        $205 = ($204&255)<(4);
        if ($205) {
         $223 = $259;$224 = $264;$245 = $260;$247 = 0;$263 = 0;
        } else {
         $206 = (($157) + 92|0);
         $207 = HEAP32[$206>>2]|0;
         $208 = ($207|0)==(0|0);
         if ($208) {
          $223 = $259;$224 = $264;$245 = $260;$247 = 1;$263 = 0;
         } else {
          $209 = (($157) + 16|0);
          $210 = HEAP8[$209>>0]|0;
          $211 = $210&255;
          $212 = ((($157) + (($211*12)|0)|0) + 50|0);
          $213 = HEAP8[$212>>0]|0;
          $214 = $213&255;
          $215 = ((($157) + (($211*12)|0)|0) + 44|0);
          $216 = HEAP32[$215>>2]|0;
          $217 = (($157) + 17|0);
          $218 = HEAP8[$217>>0]|0;
          $219 = $218&255;
          $220 = (($219) + ($216))|0;
          $221 = (($207) + ($220)|0);
          $223 = $259;$224 = $264;$245 = $260;$247 = $214;$263 = $221;
         }
        }
       } else {
        $223 = $259;$224 = $264;$245 = $260;$247 = 0;$263 = 0;
       }
      }
      $222 = ($223|0)==($224|0);
      if (!($222)) {
       $226 = $223;$243 = $263;
       while(1) {
        $225 = (($226) + 2|0);
        $227 = HEAP8[$225>>0]|0;
        $228 = (($226) + 1|0);
        $229 = HEAP8[$228>>0]|0;
        $230 = HEAP8[$226>>0]|0;
        $231 = (($226) + 3|0);
        $232 = HEAP8[$231>>0]|0;
        $233 = $232&255;
        $234 = $233 << 24;
        $235 = $230&255;
        $236 = $235 << 16;
        $237 = $229&255;
        $238 = $237 << 8;
        $239 = $227&255;
        $240 = $238 | $239;
        $241 = $240 | $236;
        $242 = $241 | $234;
        HEAP32[$243>>2] = $242;
        $244 = (($226) + ($245)|0);
        $246 = (($243) + ($247)|0);
        $248 = ($244|0)==($224|0);
        if ($248) {
         break;
        } else {
         $226 = $244;$243 = $246;
        }
       }
      }
     }
     HEAP8[$3>>0] = 1;
     $249 = (($this) + 168|0);
     __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586376,587280,$249,1);
     __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$249,586488,0);
     $250 = (($this) + 180|0);
     __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$250,586504,0);
     __ZN13ProxyTransfer11EndTransferEv($transfer);
     $251 = (($this) + 40|0);
     $252 = HEAP32[580592>>2]|0;
     __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586392,$252,$251,1);
     $253 = HEAP32[$16>>2]|0;
     $254 = HEAP32[$253>>2]|0;
     $255 = HEAP32[$19>>2]|0;
     $256 = ((($254) + (($255*24)|0)|0) + 12|0);
     HEAP32[$256>>2] = 4;
     __ZN13ProxyTransfer11EndTransferEv($transfer);
     __ZN17CollisionMeshData8TransferI13ProxyTransferEEvRT_R4Mesh(0,$transfer,0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $147 = ___cxa_find_matching_catch()|0;
 $148 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3459,($$byval_copy3|0));
 $149 = __THREW__; __THREW__ = 0;
 $150 = $149&1;
 if ($150) {
  $257 = ___cxa_find_matching_catch(0|0)|0;
  $258 = tempRet0;
  ___clang_call_terminate($257);
  // unreachable;
 } else {
  $$7 = $148;$$78 = $147;
  ___resumeException($$78|0);
  // unreachable;
 }
}
function __ZN17CollisionMeshData8TransferI13ProxyTransferEEvRT_R4Mesh($this,$transfer,$mesh) {
 $this = $this|0;
 $transfer = $transfer|0;
 $mesh = $mesh|0;
 var $$0 = 0, $$01 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $bakedConcave = 0, $bakedConvex = 0, $p$i$i$i = 0, $p$i$i$i13 = 0, $size$i$i$i$i = 0, $size$i$i$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 56|0;
 $0 = sp + 48|0;
 $1 = sp + 52|0;
 $size$i$i$i$i12 = sp + 44|0;
 $p$i$i$i13 = sp + 61|0;
 $size$i$i$i$i = sp + 40|0;
 $p$i$i$i = sp + 60|0;
 $2 = sp + 16|0;
 $bakedConvex = sp;
 $bakedConcave = sp + 24|0;
 $3 = HEAP32[628512>>2]|0;
 HEAP32[$bakedConvex>>2] = 0;
 $4 = (($bakedConvex) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($bakedConvex) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($bakedConvex) + 12|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$bakedConcave>>2] = 0;
 $7 = (($bakedConcave) + 4|0);
 HEAP32[$7>>2] = $3;
 $8 = (($bakedConcave) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($bakedConcave) + 12|0);
 HEAP32[$9>>2] = 0;
 $10 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($transfer|0),(586416|0),($10|0),($bakedConvex|0),1);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   label = 19;
  } else {
   __THREW__ = 0;
   invoke_viiiii(87,($transfer|0),(587272|0),(587272|0),($size$i$i$i$i|0),0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 19;
   } else {
    $15 = HEAP32[580744>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($transfer|0),(586480|0),($15|0),($p$i$i$i|0),0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 19;
    } else {
     $18 = (($transfer) + 12|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     $21 = (($transfer) + 20|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ((($20) + (($22*24)|0)|0) + 12|0);
     HEAP32[$23>>2] = 1;
     __THREW__ = 0;
     invoke_vi(3390,($transfer|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 19;
     } else {
      __THREW__ = 0;
      invoke_vi(3391,($transfer|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 19;
      } else {
       __THREW__ = 0;
       invoke_vi(3392,($transfer|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        label = 19;
       } else {
        __THREW__ = 0;
        invoke_vi(3390,($transfer|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 19;
        } else {
         __THREW__ = 0;
         invoke_viiiii(86,($transfer|0),(586448|0),($10|0),($bakedConcave|0),1);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          label = 19;
         } else {
          __THREW__ = 0;
          invoke_viiiii(87,($transfer|0),(587272|0),(587272|0),($size$i$i$i$i12|0),0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if ($35) {
           label = 19;
          } else {
           __THREW__ = 0;
           invoke_viiiii(86,($transfer|0),(586480|0),($15|0),($p$i$i$i13|0),0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            label = 19;
           } else {
            $38 = HEAP32[$18>>2]|0;
            $39 = HEAP32[$38>>2]|0;
            $40 = HEAP32[$21>>2]|0;
            $41 = ((($39) + (($40*24)|0)|0) + 12|0);
            HEAP32[$41>>2] = 1;
            __THREW__ = 0;
            invoke_vi(3390,($transfer|0));
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if ($43) {
             label = 19;
            } else {
             __THREW__ = 0;
             invoke_vi(3391,($transfer|0));
             $44 = __THREW__; __THREW__ = 0;
             $45 = $44&1;
             if ($45) {
              label = 19;
             } else {
              __THREW__ = 0;
              invoke_vi(3392,($transfer|0));
              $46 = __THREW__; __THREW__ = 0;
              $47 = $46&1;
              if ($47) {
               label = 19;
              } else {
               __THREW__ = 0;
               invoke_vi(3390,($transfer|0));
               $48 = __THREW__; __THREW__ = 0;
               $49 = $48&1;
               if ($49) {
                label = 19;
               } else {
                $50 = HEAP32[$9>>2]|0;
                $51 = ($50|0)>(-1);
                do {
                 if ($51) {
                  $52 = HEAP32[$bakedConcave>>2]|0;
                  $53 = HEAP32[$7>>2]|0;
                  HEAP32[$1>>2] = $53;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
                  invoke_vii(2591,($52|0),($$byval_copy3|0));
                  $54 = __THREW__; __THREW__ = 0;
                  $55 = $54&1;
                  if ($55) {
                   $56 = ___cxa_find_matching_catch()|0;
                   $57 = tempRet0;
                   $$0 = $56;$$01 = $57;
                   break L1;
                  } else {
                   HEAP32[$bakedConcave>>2] = 0;
                   break;
                  }
                 }
                } while(0);
                $66 = HEAP32[$6>>2]|0;
                $67 = ($66|0)>(-1);
                if (!($67)) {
                 STACKTOP = sp;return;
                }
                $68 = HEAP32[$bakedConvex>>2]|0;
                $69 = HEAP32[$4>>2]|0;
                HEAP32[$0>>2] = $69;
                ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
                __Z19free_alloc_internalPv10MemLabelId($68,$$byval_copy3);
                HEAP32[$bakedConvex>>2] = 0;
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 19) {
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $60 = HEAP32[$9>>2]|0;
   $61 = ($60|0)>(-1);
   if ($61) {
    $62 = HEAP32[$bakedConcave>>2]|0;
    $63 = HEAP32[$7>>2]|0;
    HEAP32[$0>>2] = $63;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($62|0),($$byval_copy3|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     $76 = ___cxa_find_matching_catch(0|0)|0;
     $77 = tempRet0;
     ___clang_call_terminate($76);
     // unreachable;
    } else {
     HEAP32[$bakedConcave>>2] = 0;
     $$0 = $58;$$01 = $59;
     break;
    }
   } else {
    $$0 = $58;$$01 = $59;
   }
  }
 } while(0);
 $70 = HEAP32[$6>>2]|0;
 $71 = ($70|0)>(-1);
 if (!($71)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $72 = HEAP32[$bakedConvex>>2]|0;
 $73 = HEAP32[$4>>2]|0;
 HEAP32[$2>>2] = $73;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($72|0),($$byval_copy3|0));
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if ($75) {
  $76 = ___cxa_find_matching_catch(0|0)|0;
  $77 = tempRet0;
  ___clang_call_terminate($76);
  // unreachable;
 }
 HEAP32[$bakedConvex>>2] = 0;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN14CompressedMesh8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586256,587304,$this,0);
 __ZN17PackedFloatVector8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $0 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586272,587304,$0,0);
 __ZN17PackedFloatVector8TransferI13ProxyTransferEEvRT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $1 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586304,587304,$1,0);
 __ZN17PackedFloatVector8TransferI13ProxyTransferEEvRT_($1,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($this) + 104|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586288,587304,$2,0);
 __ZN17PackedFloatVector8TransferI13ProxyTransferEEvRT_($2,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $3 = (($this) + 180|0);
 __ZN13ProxyTransfer8TransferI15PackedIntVectorEEvRT_PKc17TransferMetaFlags($transfer,$3,586544,0);
 $4 = (($this) + 84|0);
 __ZN13ProxyTransfer8TransferI15PackedIntVectorEEvRT_PKc17TransferMetaFlags($transfer,$4,586560,0);
 $5 = (($this) + 132|0);
 __ZN13ProxyTransfer8TransferI15PackedIntVectorEEvRT_PKc17TransferMetaFlags($transfer,$5,586576,0);
 $6 = (($this) + 152|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586592,587304,$6,0);
 __ZN17PackedFloatVector8TransferI13ProxyTransferEEvRT_($6,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 200|0);
 __ZN13ProxyTransfer8TransferI15PackedIntVectorEEvRT_PKc17TransferMetaFlags($transfer,$7,586608,0);
 $8 = (($this) + 220|0);
 __ZN13ProxyTransfer8TransferI15PackedIntVectorEEvRT_PKc17TransferMetaFlags($transfer,$8,586624,0);
 $9 = (($this) + 240|0);
 $10 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586640,$10,$9,0);
 $11 = (($transfer) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($transfer) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($13) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI15PackedIntVectorEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0;
 var $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,587304,$data,$metaFlag);
 $0 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,586656,$0,$data,0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $7 = (($data) + 8|0);
 $8 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,586672,$8,$7,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,587272,587272,$size$i$i$i$i,0);
 $9 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,586480,$9,$p$i$i$i,0);
 $10 = HEAP32[$1>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$4>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer5AlignEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $14 = (($data) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,586680,$9,$14,0);
 $15 = HEAP32[$1>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$4>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer5AlignEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN17PackedFloatVector8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586656,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 $8 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586696,$8,$7,0);
 $9 = HEAP32[$1>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$4>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586704,$8,$13,0);
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$4>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 16|0);
 $19 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586672,$19,$18,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$size$i$i$i$i,0);
 $20 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,$20,$p$i$i$i,0);
 $21 = HEAP32[$1>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$4>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $25 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586680,$20,$25,0);
 $26 = HEAP32[$1>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$4>>2]|0;
 $29 = ((($27) + (($28*24)|0)|0) + 12|0);
 HEAP32[$29>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13BoneInfluence8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586728,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586744,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586760,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586776,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 16|0);
 $23 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586792,$23,$22,0);
 $24 = HEAP32[$1>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$4>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586808,$23,$28,0);
 $29 = HEAP32[$1>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$4>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586824,$23,$33,0);
 $34 = HEAP32[$1>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$4>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586840,$23,$38,0);
 $39 = HEAP32[$1>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$4>>2]|0;
 $42 = ((($40) + (($41*24)|0)|0) + 12|0);
 HEAP32[$42>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4f8TransferI13ProxyTransferEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586856,$0,$this,0);
 $1 = (($t) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($t) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $7 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586864,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $12 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586872,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $17 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586880,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $22 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586888,$0,$22,0);
 $23 = HEAP32[$1>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$4>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $27 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586896,$0,$27,0);
 $28 = HEAP32[$1>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$4>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $32 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586904,$0,$32,0);
 $33 = HEAP32[$1>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$4>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $37 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586912,$0,$37,0);
 $38 = HEAP32[$1>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$4>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $42 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586920,$0,$42,0);
 $43 = HEAP32[$1>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ((($44) + (($45*24)|0)|0) + 12|0);
 HEAP32[$46>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $47 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586928,$0,$47,0);
 $48 = HEAP32[$1>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$4>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $52 = (($this) + 40|0);
 $53 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586936,$53,$52,0);
 $54 = HEAP32[$1>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$4>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $58 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586944,$53,$58,0);
 $59 = HEAP32[$1>>2]|0;
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$4>>2]|0;
 $62 = ((($60) + (($61*24)|0)|0) + 12|0);
 HEAP32[$62>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $63 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586952,$53,$63,0);
 $64 = HEAP32[$1>>2]|0;
 $65 = HEAP32[$64>>2]|0;
 $66 = HEAP32[$4>>2]|0;
 $67 = ((($65) + (($66*24)|0)|0) + 12|0);
 HEAP32[$67>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $68 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586960,$53,$68,0);
 $69 = HEAP32[$1>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$4>>2]|0;
 $72 = ((($70) + (($71*24)|0)|0) + 12|0);
 HEAP32[$72>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $73 = (($this) + 44|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586968,$53,$73,0);
 $74 = HEAP32[$1>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 $76 = HEAP32[$4>>2]|0;
 $77 = ((($75) + (($76*24)|0)|0) + 12|0);
 HEAP32[$77>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $78 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,586976,$53,$78,0);
 $79 = HEAP32[$1>>2]|0;
 $80 = HEAP32[$79>>2]|0;
 $81 = HEAP32[$4>>2]|0;
 $82 = ((($80) + (($81*24)|0)|0) + 12|0);
 HEAP32[$82>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 STACKTOP = sp;return;
}
function __ZN14BlendShapeData8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i4 = 0, $size$i$i$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $size$i$i$i$i3 = sp + 40|0;
 $p$i$i$i4 = sp;
 $0 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586984,$0,$this,0);
 ;HEAP32[$p$i$i$i4+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$p$i$i$i4+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$p$i$i$i4+8>>2]=HEAP32[616680+8>>2]|0;
 $1 = (($p$i$i$i4) + 12|0);
 ;HEAP32[$1+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[616680+8>>2]|0;
 $2 = (($p$i$i$i4) + 24|0);
 ;HEAP32[$2+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[616680+8>>2]|0;
 $3 = (($p$i$i$i4) + 36|0);
 HEAP32[$3>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$size$i$i$i$i3,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,587424,$p$i$i$i4,0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$p$i$i$i4,587160,0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$1,587168,0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$2,587176,0);
 $4 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587184,$4,$3,0);
 $5 = (($transfer) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($transfer) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($7) + (($9*24)|0)|0) + 12|0);
 HEAP32[$10>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $11 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587000,$0,$11,0);
 ;HEAP32[$p$i$i$i4+0>>2]=0|0;HEAP32[$p$i$i$i4+4>>2]=0|0;HEAP16[$p$i$i$i4+8>>1]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$size$i$i$i$i3,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,587408,$p$i$i$i4,0);
 __ZN10BlendShape8TransferI13ProxyTransferEEvRT_($p$i$i$i4,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587008,$0,$12,0);
 HEAP32[$p$i$i$i4>>2] = 0;
 __ZN14ConstantString12create_emptyEv($p$i$i$i4);
 __THREW__ = 0;
 invoke_viiiii(87,($transfer|0),(587272|0),(587272|0),($size$i$i$i$i3|0),0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  __THREW__ = 0;
  invoke_viiiii(86,($transfer|0),(586480|0),(587384|0),($p$i$i$i4|0),0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   invoke_vii(2690,($p$i$i$i4|0),($transfer|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    invoke_vi(3390,($transfer|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     invoke_vi(3391,($transfer|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __ZN14ConstantStringD2Ev($p$i$i$i4);
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      $29 = (($this) + 44|0);
      __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587024,$0,$29,0);
      __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$size$i$i$i$i3,0);
      $30 = HEAP32[580584>>2]|0;
      __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,$30,$p$i$i$i4,0);
      $31 = HEAP32[$5>>2]|0;
      $32 = HEAP32[$31>>2]|0;
      $33 = HEAP32[$8>>2]|0;
      $34 = ((($32) + (($33*24)|0)|0) + 12|0);
      HEAP32[$34>>2] = 4;
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3382,($p$i$i$i4|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZN17BlendShapeChannel8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587040,$0,$this,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,587272,587272,$size$i$i$i$i,1);
 $1 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,586480,$1,$p$i$i$i,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 4|0);
 $9 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587048,$9,$8,0);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($this) + 8|0);
 $15 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587064,$15,$14,0);
 $16 = HEAP32[$2>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$5>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587080,$15,$20,0);
 $21 = HEAP32[$2>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$5>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10BlendShape8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587096,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587112,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 $13 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587128,$13,$12,0);
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$4>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 9|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587144,$13,$18,0);
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$4>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7SubMesh8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 4|0);
 $1 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587192,$1,$0,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587208,$1,$8,0);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587224,$13,$this,0);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587096,$1,$18,0);
 $19 = HEAP32[$2>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587112,$1,$23,0);
 $24 = HEAP32[$2>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587240,587280,$28,0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$28,586488,0);
 $29 = (($this) + 44|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$29,586504,0);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 56)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 56)&-1;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $14 << 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = ($$0$i2*56)|0;
  HEAP32[$0>>2] = 10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,585592,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + (($7*56)|0)|0);
 $24 = (($23) + (($$0$i3*56)|0)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  dest=$22+0|0; src=$__x+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $26 = (($23) + (($8*56)|0)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = $28;
 $30 = $27;
 $31 = (($29) - ($30))|0;
 $32 = (($31|0) / -56)&-1;
 $$sum1 = (($32) + ($7))|0;
 $33 = (($23) + (($$sum1*56)|0)|0);
 _memcpy(($33|0),($27|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$1>>2] = $26;
 HEAP32[$10>>2] = $24;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN4MeshD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$5 = 0, $$56 = 0, $$6 = 0, $$67 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i13 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i14 = 0, $scevgep4$i$i$i$i$i = 0;
 var $scevgep4$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i16 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 HEAP32[$this>>2] = ((585488 + 8|0));
 $5 = (($this) + 192|0);
 __THREW__ = 0;
 invoke_vi(3460,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   $48 = ___cxa_find_matching_catch()|0;
   $49 = tempRet0;
   $50 = (($this) + 232|0);
   __THREW__ = 0;
   invoke_vi(3453,($50|0));
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    $102 = ___cxa_find_matching_catch(0|0)|0;
    $103 = tempRet0;
    ___clang_call_terminate($102);
    // unreachable;
   } else {
    $$0 = $49;$$01 = $48;
    label = 20;
   }
  } else {
   $8 = (($this) + 232|0);
   __THREW__ = 0;
   invoke_vi(3453,($8|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $53 = ___cxa_find_matching_catch()|0;
    $54 = tempRet0;
    $$0 = $54;$$01 = $53;
    label = 20;
    break;
   }
   $11 = (($this) + 212|0);
   ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
   __THREW__ = 0;
   invoke_vi(3454,($5|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    $$3 = $56;$$34 = $55;
    label = 22;
    break;
   }
   $14 = (($this) + 148|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>(-1);
   do {
    if ($16) {
     $17 = (($this) + 136|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($this) + 140|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$4>>2] = $20;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($18|0),($$byval_copy5|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      $60 = ___cxa_find_matching_catch()|0;
      $61 = tempRet0;
      $$4 = $61;$$45 = $60;
      label = 26;
      break L1;
     } else {
      HEAP32[$17>>2] = 0;
      break;
     }
    }
   } while(0);
   $23 = (($this) + 128|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)>(-1);
   do {
    if ($25) {
     $26 = (($this) + 116|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($this) + 120|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$3>>2] = $29;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($27|0),($$byval_copy5|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $71 = ___cxa_find_matching_catch()|0;
      $72 = tempRet0;
      $$5 = $72;$$56 = $71;
      label = 30;
      break L1;
     } else {
      HEAP32[$26>>2] = 0;
      break;
     }
    }
   } while(0);
   $32 = (($this) + 56|0);
   __THREW__ = 0;
   invoke_vi(3455,($32|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    $$6 = $83;$$67 = $82;
    break;
   }
   $35 = (($this) + 44|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
   $38 = (($this) + 48|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==($36|0);
   if (!($40)) {
    $__new_last2$i$i$i$i$i = $36;
    $scevgep$i$i$i$i$i = (($39) + -56|0);
    $41 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($41)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $42 = (($uglygep3$i$i$i$i$i>>>0) / 56)&-1;
    $43 = $42 ^ -1;
    $scevgep4$i$i$i$i$i = (($39) + (($43*56)|0)|0);
    HEAP32[$38>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($36|0),($$byval_copy5|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $46 = ___cxa_find_matching_catch()|0;
    $47 = tempRet0;
    ___cxa_call_unexpected(($46|0));
    // unreachable;
   } else {
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $57 = (($this) + 212|0);
  ;HEAP32[$57+0>>2]=0|0;HEAP32[$57+4>>2]=0|0;HEAP32[$57+8>>2]=0|0;HEAP32[$57+12>>2]=0|0;
  __THREW__ = 0;
  invoke_vi(3454,($5|0));
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if ($59) {
   $102 = ___cxa_find_matching_catch(0|0)|0;
   $103 = tempRet0;
   ___clang_call_terminate($102);
   // unreachable;
  } else {
   $$3 = $$0;$$34 = $$01;
   label = 22;
  }
 }
 do {
  if ((label|0) == 22) {
   $62 = (($this) + 148|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)>(-1);
   if ($64) {
    $65 = (($this) + 136|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($this) + 140|0);
    $68 = HEAP32[$67>>2]|0;
    HEAP32[$1>>2] = $68;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($66|0),($$byval_copy5|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     $102 = ___cxa_find_matching_catch(0|0)|0;
     $103 = tempRet0;
     ___clang_call_terminate($102);
     // unreachable;
    } else {
     HEAP32[$65>>2] = 0;
     $$4 = $$3;$$45 = $$34;
     label = 26;
     break;
    }
   } else {
    $$4 = $$3;$$45 = $$34;
    label = 26;
   }
  }
 } while(0);
 do {
  if ((label|0) == 26) {
   $73 = (($this) + 128|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)>(-1);
   if ($75) {
    $76 = (($this) + 116|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($this) + 120|0);
    $79 = HEAP32[$78>>2]|0;
    HEAP32[$0>>2] = $79;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($77|0),($$byval_copy5|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     $102 = ___cxa_find_matching_catch(0|0)|0;
     $103 = tempRet0;
     ___clang_call_terminate($102);
     // unreachable;
    } else {
     HEAP32[$76>>2] = 0;
     $$5 = $$4;$$56 = $$45;
     label = 30;
     break;
    }
   } else {
    $$5 = $$4;$$56 = $$45;
    label = 30;
   }
  }
 } while(0);
 if ((label|0) == 30) {
  $84 = (($this) + 56|0);
  __THREW__ = 0;
  invoke_vi(3455,($84|0));
  $85 = __THREW__; __THREW__ = 0;
  $86 = $85&1;
  if ($86) {
   $102 = ___cxa_find_matching_catch(0|0)|0;
   $103 = tempRet0;
   ___clang_call_terminate($102);
   // unreachable;
  } else {
   $$6 = $$5;$$67 = $$56;
  }
 }
 $87 = (($this) + 44|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0|0);
 if (!($89)) {
  $90 = (($this) + 48|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($91|0)==($88|0);
  if (!($92)) {
   $__new_last2$i$i$i$i$i13 = $88;
   $scevgep$i$i$i$i$i14 = (($91) + -56|0);
   $93 = (0 - ($__new_last2$i$i$i$i$i13))|0;
   $uglygep$i$i$i$i$i16 = (($scevgep$i$i$i$i$i14) + ($93)|0);
   $uglygep3$i$i$i$i$i17 = $uglygep$i$i$i$i$i16;
   $94 = (($uglygep3$i$i$i$i$i17>>>0) / 56)&-1;
   $95 = $94 ^ -1;
   $scevgep4$i$i$i$i$i18 = (($91) + (($95*56)|0)|0);
   HEAP32[$90>>2] = $scevgep4$i$i$i$i$i18;
  }
  HEAP32[$2>>2] = 10;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($88|0),($$byval_copy5|0));
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   $98 = ___cxa_find_matching_catch()|0;
   $99 = tempRet0;
   ___cxa_call_unexpected(($98|0));
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $100 = __THREW__; __THREW__ = 0;
 $101 = $100&1;
 if ($101) {
  $102 = ___cxa_find_matching_catch(0|0)|0;
  $103 = tempRet0;
  ___clang_call_terminate($102);
  // unreachable;
 } else {
  ___resumeException($$67|0);
  // unreachable;
 }
}
function __ZN14BlendShapeDataD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(-1);
 do {
  if ($6) {
   $7 = (($this) + 44|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 48|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$3>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy4|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    HEAP32[$7>>2] = 0;
    label = 4;
    break;
   }
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $42 = (($this) + 32|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   do {
    if (!($44)) {
     $45 = (($this) + 36|0);
     while(1) {
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==($43|0);
      if ($47) {
       label = 21;
       break;
      }
      $48 = (($46) + -16|0);
      HEAP32[$45>>2] = $48;
      __THREW__ = 0;
      invoke_vi(3382,($48|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 20;
       break;
      }
     }
     if ((label|0) == 20) {
      $51 = ___cxa_find_matching_catch()|0;
      $52 = tempRet0;
      ___cxa_call_unexpected(($51|0));
      // unreachable;
     }
     else if ((label|0) == 21) {
      $53 = HEAP32[$42>>2]|0;
      __ZdlPv($53);
      break;
     }
    }
   } while(0);
   $56 = (($this) + 28|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)>(-1);
   if ($58) {
    $59 = (($this) + 16|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($this) + 20|0);
    $62 = HEAP32[$61>>2]|0;
    HEAP32[$1>>2] = $62;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($60|0),($$byval_copy4|0));
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     $73 = ___cxa_find_matching_catch(0|0)|0;
     $74 = tempRet0;
     ___clang_call_terminate($73);
     // unreachable;
    } else {
     HEAP32[$59>>2] = 0;
     $$1 = $41;$$12 = $40;
     break;
    }
   } else {
    $$1 = $41;$$12 = $40;
   }
  } else {
   label = 4;
  }
 } while(0);
 L19: do {
  if ((label|0) == 4) {
   $13 = (($this) + 32|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   do {
    if (!($15)) {
     $16 = (($this) + 36|0);
     while(1) {
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17|0)==($14|0);
      if ($18) {
       label = 9;
       break;
      }
      $19 = (($17) + -16|0);
      HEAP32[$16>>2] = $19;
      __THREW__ = 0;
      invoke_vi(3382,($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       label = 8;
       break;
      }
     }
     if ((label|0) == 8) {
      $22 = ___cxa_find_matching_catch()|0;
      $23 = tempRet0;
      ___cxa_call_unexpected(($22|0));
      // unreachable;
     }
     else if ((label|0) == 9) {
      $24 = HEAP32[$13>>2]|0;
      __ZdlPv($24);
      break;
     }
    }
   } while(0);
   $25 = (($this) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)>(-1);
   do {
    if ($27) {
     $28 = (($this) + 16|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($this) + 20|0);
     $31 = HEAP32[$30>>2]|0;
     HEAP32[$2>>2] = $31;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($29|0),($$byval_copy4|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      $54 = ___cxa_find_matching_catch()|0;
      $55 = tempRet0;
      $$1 = $55;$$12 = $54;
      break L19;
     } else {
      HEAP32[$28>>2] = 0;
      break;
     }
    }
   } while(0);
   $34 = (($this) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)>(-1);
   if (!($36)) {
    STACKTOP = sp;return;
   }
   $37 = HEAP32[$this>>2]|0;
   $38 = (($this) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$0>>2] = $39;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy4);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $65 = (($this) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)>(-1);
 if (!($67)) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $68 = HEAP32[$this>>2]|0;
 $69 = (($this) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 HEAP32[$0>>2] = $70;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($68|0),($$byval_copy4|0));
 $71 = __THREW__; __THREW__ = 0;
 $72 = $71&1;
 if ($72) {
  $73 = ___cxa_find_matching_catch(0|0)|0;
  $74 = tempRet0;
  ___clang_call_terminate($73);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN14SharedMeshDataD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14SharedMeshDataD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN14SharedMeshDataD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3461,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN14SharedMeshDataD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((587456 + 8|0));
 $2 = (($this) + 120|0);
 __THREW__ = 0;
 invoke_vi(3462,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $20 = (($this) + 108|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   $23 = (($this) + 112|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==($21|0);
   if (!($25)) {
    HEAP32[$23>>2] = $21;
   }
   HEAP32[$0>>2] = 8;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($21|0),($$byval_copy1|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
  }
  $32 = (($this) + 8|0);
  __THREW__ = 0;
  invoke_vi(3456,($32|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $35 = ___cxa_find_matching_catch(0|0)|0;
   $36 = tempRet0;
   ___clang_call_terminate($35);
   // unreachable;
  } else {
   $$1 = $19;$$12 = $18;
   ___resumeException($$12|0);
   // unreachable;
  }
 }
 $5 = (($this) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($this) + 112|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($6|0);
  if (!($10)) {
   HEAP32[$8>>2] = $6;
  }
  HEAP32[$1>>2] = 8;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($6|0),($$byval_copy1|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 $15 = (($this) + 8|0);
 __THREW__ = 0;
 invoke_vi(3456,($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 $$1 = $31;$$12 = $30;
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN16MeshSkinningDataD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 do {
  if ($8) {
   $9 = (($this) + 48|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 52|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$5>>2] = $12;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($10|0),($$byval_copy6|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$9>>2] = 0;
    label = 4;
    break;
   }
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   $41 = (($this) + 44|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)>(-1);
   if ($43) {
    $44 = (($this) + 32|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($this) + 36|0);
    $47 = HEAP32[$46>>2]|0;
    HEAP32[$2>>2] = $47;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($45|0),($$byval_copy6|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $71 = ___cxa_find_matching_catch(0|0)|0;
     $72 = tempRet0;
     ___clang_call_terminate($71);
     // unreachable;
    } else {
     HEAP32[$44>>2] = 0;
     $$0 = $40;$$01 = $39;
     label = 18;
     break;
    }
   } else {
    $$0 = $40;$$01 = $39;
    label = 18;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $15 = (($this) + 44|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(-1);
   do {
    if ($17) {
     $18 = (($this) + 32|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($this) + 36|0);
     $21 = HEAP32[$20>>2]|0;
     HEAP32[$4>>2] = $21;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($19|0),($$byval_copy6|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $50 = ___cxa_find_matching_catch()|0;
      $51 = tempRet0;
      $$0 = $51;$$01 = $50;
      label = 18;
      break L10;
     } else {
      HEAP32[$18>>2] = 0;
      break;
     }
    }
   } while(0);
   $24 = (($this) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(-1);
   do {
    if ($26) {
     $27 = (($this) + 16|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($this) + 20|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$3>>2] = $30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($28|0),($$byval_copy6|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $52 = ___cxa_find_matching_catch()|0;
      $53 = tempRet0;
      $$1 = $53;$$12 = $52;
      break L10;
     } else {
      HEAP32[$27>>2] = 0;
      break;
     }
    }
   } while(0);
   $33 = (($this) + 12|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)>(-1);
   if (!($35)) {
    STACKTOP = sp;return;
   }
   $36 = HEAP32[$this>>2]|0;
   $37 = (($this) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   HEAP32[$0>>2] = $38;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($36,$$byval_copy6);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 18) {
   $54 = (($this) + 28|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)>(-1);
   if ($56) {
    $57 = (($this) + 16|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($this) + 20|0);
    $60 = HEAP32[$59>>2]|0;
    HEAP32[$1>>2] = $60;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($58|0),($$byval_copy6|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $71 = ___cxa_find_matching_catch(0|0)|0;
     $72 = tempRet0;
     ___clang_call_terminate($71);
     // unreachable;
    } else {
     HEAP32[$57>>2] = 0;
     $$1 = $$0;$$12 = $$01;
     break;
    }
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 $63 = (($this) + 12|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)>(-1);
 if (!($65)) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $66 = HEAP32[$this>>2]|0;
 $67 = (($this) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$0>>2] = $68;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($66|0),($$byval_copy6|0));
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $71 = ___cxa_find_matching_catch(0|0)|0;
  $72 = tempRet0;
  ___clang_call_terminate($71);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN18ThreadSharedObjectD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18ThreadSharedObjectD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a3258() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628456>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN17UniqueIDGeneratorC2E10MemLabelId(585464,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN10MeshFilter13SetSharedMeshE4PPtrI4MeshE($this,$mesh) {
 $this = $this|0;
 $mesh = $mesh|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$mesh>>2]|0;
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($4,23)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  __ZN12MeshRenderer13SetSharedMeshE4PPtrI4MeshE($5,$0);
 }
 $8 = HEAP32[$3>>2]|0;
 $9 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($8,87)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$2>>2]|0;
 $12 = (($9) + 228|0);
 HEAP32[$12>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN10MeshFilter13GetSharedMeshEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 STACKTOP = sp;return;
}
function __Z24RegisterClass_MeshFilterv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(33,112,113,0,114);
 STACKTOP = sp;return;
}
function __ZN10MeshFilter13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(2)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity9Component13RegisterClassEv();
 }
 HEAP8[$0>>0] = 20;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=587608+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 11|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,33,2,($0|0),32,(2386|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN10MeshFilter15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z27RegisterAllowNameConversionPKcS0_S0_(587608,587632,587648);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(33,564640,1717,0);
 STACKTOP = sp;return;
}
function __ZN10MeshFilter12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10MeshFilter7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(32,$$byval_copy2,1,16,587704,13)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((587488 + 8|0));
  $6 = (($3) + 28|0);
  HEAP32[$6>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(587704|0),13);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK10MeshFilter25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 33;
}
function __ZN10MeshFilter23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587624,587608,$this,0);
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587648,587688,$0,2048);
 $1 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587656,$6,$0,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587672,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10MeshFilter23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i$i = sp + 4|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587624,587608,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN5Unity9Component8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  $3 = (($this) + 28|0);
  $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587648,587688,$converter$i$i$i$i,1)|0);
  $5 = ($4|0)==(0);
  if (!($5)) {
   $6 = ($4|0)>(0);
   if ($6) {
    __ZN4PPtrI4MeshE8TransferI14SafeBinaryReadEEvRT_($3,$transfer);
   } else {
    $7 = HEAP32[$converter$i$i$i$i>>2]|0;
    $8 = ($7|0)==(0|0);
    if (!($8)) {
     (FUNCTION_TABLE_iii[$7 & 4095]($3,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $9 = HEAP32[$converter$i$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   (FUNCTION_TABLE_iii[$9 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10MeshFilter23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN4PPtrI4MeshE8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 STACKTOP = sp;return;
}
function __ZN10MeshFilter23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN4PPtrI4MeshE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 STACKTOP = sp;return;
}
function __ZN10MeshFilter23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN4PPtrI4MeshE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 STACKTOP = sp;return;
}
function __ZN10MeshFilter23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $8;
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZZN10MeshFilter15InitializeClassEvEN39FunctorImpl_MeshFilter_kDidAddComponent4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $2 = sp + 4|0;
 $3 = sp;
 $4 = (($object) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($5,23)|0);
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  __ZNK12MeshRenderer13GetSharedMeshEv($2,$7);
  $9 = HEAP32[$2>>2]|0;
  $10 = (($object) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if (!($12)) {
   HEAP32[$3>>2] = $11;
   __ZN12MeshRenderer13SetSharedMeshE4PPtrI4MeshE($7,$3);
  }
 }
 $13 = HEAP32[$4>>2]|0;
 $14 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($13,87)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($14) + 228|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($object) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 HEAP32[$16>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN10MeshFilter13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($3,23)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZNK12MeshRenderer13GetSharedMeshEv($0,$5);
  $7 = HEAP32[$0>>2]|0;
  $8 = (($this) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  if (!($10)) {
   HEAP32[$1>>2] = $9;
   __ZN12MeshRenderer13SetSharedMeshE4PPtrI4MeshE($5,$1);
  }
 }
 $11 = HEAP32[$2>>2]|0;
 $12 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($11,87)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($12) + 228|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 HEAP32[$14>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN10MeshFilterD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((562072 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   STACKTOP = sp;return;
  }
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __THREW__ = 0;
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   ___resumeException($4|0);
   // unreachable;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 HEAP32[$this>>2] = ((560936 + 8|0));
 __THREW__ = 0;
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$i$i$indexZ2D = $16;
   ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  ___resumeException($10|0);
  // unreachable;
 }
 $22 = ___cxa_find_matching_catch(0|0)|0;
 $23 = tempRet0;
 $eh$lpad$body$i$i$indexZ2D = $22;
 ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
 // unreachable;
}
function __ZN10MeshFilterD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((562072 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $16 = ___cxa_find_matching_catch(0|0)|0;
   $17 = tempRet0;
   __THREW__ = 0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $20 = ___cxa_find_matching_catch(0|0)|0;
    $21 = tempRet0;
    ___clang_call_terminate($20);
    // unreachable;
   } else {
    $eh$lpad$body$i$i$i$indexZ2D = $16;
    ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $eh$lpad$body$index8Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  $eh$lpad$body$i$i$i$indexZ2D = $22;
  ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   $4 = ___cxa_find_matching_catch()|0;
   $5 = tempRet0;
   __THREW__ = 0;
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $8 = ___cxa_find_matching_catch(0|0)|0;
    $9 = tempRet0;
    ___clang_call_terminate($8);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $5;$eh$lpad$body$indexZ2D = $4;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $eh$lpad$body$index8Z2D = $27;$eh$lpad$body$indexZ2D = $26;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __Z15GetChannelIndexRK14BlendShapeDataPKc($data,$name) {
 $data = $data|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($data) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$01 = 0;
 }
 while(1) {
  $11 = (($3) + ($i$01<<4)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (_strcmp($12,$name)|0);
  $14 = ($13|0)==(0);
  $10 = (($i$01) + 1)|0;
  if ($14) {
   $$0 = $i$01;
   label = 4;
   break;
  }
  $5 = $1;
  $6 = $3;
  $7 = (($5) - ($6))|0;
  $8 = $7 >> 4;
  $9 = ($10>>>0)<($8>>>0);
  if ($9) {
   $i$01 = $10;
  } else {
   $$0 = -1;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z16ClearBlendShapesR14BlendShapeData($data) {
 $data = $data|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($data) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = HEAP32[$data>>2]|0;
  $5 = (($data) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$0>>2] = $6;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($4,$$byval_copy2);
  HEAP32[$data>>2] = 0;
 }
 $7 = (($data) + 8|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$1>>2] = 0;
 $8 = (($data) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(-1);
 if ($10) {
  $11 = (($data) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($data) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$0>>2] = $14;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($12,$$byval_copy2);
  HEAP32[$11>>2] = 0;
 }
 $15 = (($data) + 24|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$8>>2] = 0;
 $16 = (($data) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($data) + 36|0);
 while(1) {
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($17|0);
  if ($20) {
   break;
  }
  $21 = (($19) + -16|0);
  HEAP32[$18>>2] = $21;
  __THREW__ = 0;
  invoke_vi(3382,($21|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  ___cxa_call_unexpected(($24|0));
  // unreachable;
 }
 $26 = (($data) + 56|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  $33 = (($data) + 52|0);
  HEAP32[$33>>2] = 0;
  HEAP32[$26>>2] = 0;
  STACKTOP = sp;return;
 }
 $29 = (($data) + 44|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($data) + 48|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP32[$0>>2] = $32;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($30,$$byval_copy2);
 HEAP32[$29>>2] = 0;
 $33 = (($data) + 52|0);
 HEAP32[$33>>2] = 0;
 HEAP32[$26>>2] = 0;
 STACKTOP = sp;return;
}
function __Z15ApplyBlendShapeRK10BlendShapeRK13dynamic_arrayI16BlendShapeVertexLj4EEfRK12SkinMeshInfoPh($target,$vertices,$weight,$info,$dst) {
 $target = $target|0;
 $vertices = $vertices|0;
 $weight = Math_fround($weight);
 $info = $info|0;
 $dst = $dst|0;
 var $$sum = 0, $$sum$i = 0, $$sum$i1 = 0, $$sum1$i = 0, $$sum10 = 0, $$sum4$i = 0, $$sum5$i = 0, $$sum6$i = 0, $$sum7$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0;
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond$i = 0, $exitcond$i2 = 0, $i$02$i = 0, $i$08$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $weight > Math_fround(9.99999974737875163555E-5);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = $weight > Math_fround(1.0);
 $2 = $1 ? Math_fround(1.0) : $weight;
 $3 = HEAP32[$vertices>>2]|0;
 $4 = HEAP32[$target>>2]|0;
 $5 = (($3) + (($4*40)|0)|0);
 $6 = (($info) + 36|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($info) + 37|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $12 = (($target) + 8|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if (!($14)) {
    $15 = (($target) + 9|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if (!($17)) {
     $18 = (($target) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($info) + 28|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($info) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($info) + 20|0);
     $25 = HEAP32[$24>>2]|0;
     __Z19ApplyBlendShapeTmplILb1ELb1EEvPK16BlendShapeVertexjjfiiiPh($5,$19,0,$2,$21,$23,$25,$dst);
     STACKTOP = sp;return;
    }
   }
  }
  $26 = (($target) + 8|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if (!($28)) {
   $29 = (($target) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($info) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($info) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($30|0)==(0);
   if ($35) {
    STACKTOP = sp;return;
   } else {
    $i$08$i = 0;
   }
   while(1) {
    $$sum = (($i$08$i) + ($4))|0;
    $36 = ((($3) + (($$sum*40)|0)|0) + 36|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = Math_imul($37, $34)|0;
    $39 = (($dst) + ($38)|0);
    $40 = (($3) + (($$sum*40)|0)|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = Math_fround($2 * $41);
    $43 = ((($3) + (($$sum*40)|0)|0) + 4|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = Math_fround($2 * $44);
    $46 = ((($3) + (($$sum*40)|0)|0) + 8|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = Math_fround($2 * $47);
    $49 = Math_fround(HEAPF32[$39>>2]);
    $50 = Math_fround($42 + $49);
    HEAPF32[$39>>2] = $50;
    $$sum4$i = (($38) + 4)|0;
    $51 = (($dst) + ($$sum4$i)|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = Math_fround($45 + $52);
    HEAPF32[$51>>2] = $53;
    $$sum5$i = (($38) + 8)|0;
    $54 = (($dst) + ($$sum5$i)|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = Math_fround($48 + $55);
    HEAPF32[$54>>2] = $56;
    $$sum$i1 = (($38) + ($32))|0;
    $57 = (($dst) + ($$sum$i1)|0);
    $58 = ((($3) + (($$sum*40)|0)|0) + 12|0);
    $59 = Math_fround(HEAPF32[$58>>2]);
    $60 = Math_fround($2 * $59);
    $61 = ((($3) + (($$sum*40)|0)|0) + 16|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = Math_fround($2 * $62);
    $64 = ((($3) + (($$sum*40)|0)|0) + 20|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    $66 = Math_fround($2 * $65);
    $67 = Math_fround(HEAPF32[$57>>2]);
    $68 = Math_fround($60 + $67);
    HEAPF32[$57>>2] = $68;
    $$sum6$i = (($$sum$i1) + 4)|0;
    $69 = (($dst) + ($$sum6$i)|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = Math_fround($63 + $70);
    HEAPF32[$69>>2] = $71;
    $$sum7$i = (($$sum$i1) + 8)|0;
    $72 = (($dst) + ($$sum7$i)|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = Math_fround($66 + $73);
    HEAPF32[$72>>2] = $74;
    $75 = (($i$08$i) + 1)|0;
    $exitcond$i2 = ($75|0)==($30|0);
    if ($exitcond$i2) {
     break;
    } else {
     $i$08$i = $75;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $76 = (($target) + 4|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($info) + 20|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($77|0)==(0);
 if ($80) {
  STACKTOP = sp;return;
 } else {
  $i$02$i = 0;
 }
 while(1) {
  $$sum10 = (($i$02$i) + ($4))|0;
  $81 = ((($3) + (($$sum10*40)|0)|0) + 36|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = Math_imul($82, $79)|0;
  $84 = (($dst) + ($83)|0);
  $85 = (($3) + (($$sum10*40)|0)|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround($2 * $86);
  $88 = ((($3) + (($$sum10*40)|0)|0) + 4|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = Math_fround($2 * $89);
  $91 = ((($3) + (($$sum10*40)|0)|0) + 8|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = Math_fround($2 * $92);
  $94 = Math_fround(HEAPF32[$84>>2]);
  $95 = Math_fround($87 + $94);
  HEAPF32[$84>>2] = $95;
  $$sum$i = (($83) + 4)|0;
  $96 = (($dst) + ($$sum$i)|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = Math_fround($90 + $97);
  HEAPF32[$96>>2] = $98;
  $$sum1$i = (($83) + 8)|0;
  $99 = (($dst) + ($$sum1$i)|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($93 + $100);
  HEAPF32[$99>>2] = $101;
  $102 = (($i$02$i) + 1)|0;
  $exitcond$i = ($102|0)==($77|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$02$i = $102;
  }
 }
 STACKTOP = sp;return;
}
function __Z19ApplyBlendShapeTmplILb1ELb1EEvPK16BlendShapeVertexjjfiiiPh($vertices,$vertexCount,$dstVertexCount,$weight,$normalOffset,$tangentOffset,$inStride,$dst) {
 $vertices = $vertices|0;
 $vertexCount = $vertexCount|0;
 $dstVertexCount = $dstVertexCount|0;
 $weight = Math_fround($weight);
 $normalOffset = $normalOffset|0;
 $tangentOffset = $tangentOffset|0;
 $inStride = $inStride|0;
 $dst = $dst|0;
 var $$sum = 0, $$sum1 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0;
 var $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0;
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0;
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $exitcond = 0, $i$014 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($vertexCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i$014 = 0;
 }
 while(1) {
  $1 = ((($vertices) + (($i$014*40)|0)|0) + 36|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = Math_imul($2, $inStride)|0;
  $4 = (($dst) + ($3)|0);
  $5 = (($vertices) + (($i$014*40)|0)|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($6 * $weight);
  $8 = ((($vertices) + (($i$014*40)|0)|0) + 4|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($9 * $weight);
  $11 = ((($vertices) + (($i$014*40)|0)|0) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($12 * $weight);
  $14 = Math_fround(HEAPF32[$4>>2]);
  $15 = Math_fround($7 + $14);
  HEAPF32[$4>>2] = $15;
  $$sum8 = (($3) + 4)|0;
  $16 = (($dst) + ($$sum8)|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($10 + $17);
  HEAPF32[$16>>2] = $18;
  $$sum9 = (($3) + 8)|0;
  $19 = (($dst) + ($$sum9)|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($13 + $20);
  HEAPF32[$19>>2] = $21;
  $$sum = (($3) + ($normalOffset))|0;
  $22 = (($dst) + ($$sum)|0);
  $23 = ((($vertices) + (($i$014*40)|0)|0) + 12|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($24 * $weight);
  $26 = ((($vertices) + (($i$014*40)|0)|0) + 16|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($27 * $weight);
  $29 = ((($vertices) + (($i$014*40)|0)|0) + 20|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($30 * $weight);
  $32 = Math_fround(HEAPF32[$22>>2]);
  $33 = Math_fround($25 + $32);
  HEAPF32[$22>>2] = $33;
  $$sum10 = (($$sum) + 4)|0;
  $34 = (($dst) + ($$sum10)|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($28 + $35);
  HEAPF32[$34>>2] = $36;
  $$sum11 = (($$sum) + 8)|0;
  $37 = (($dst) + ($$sum11)|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround($31 + $38);
  HEAPF32[$37>>2] = $39;
  $$sum1 = (($3) + ($tangentOffset))|0;
  $40 = (($dst) + ($$sum1)|0);
  $41 = ((($vertices) + (($i$014*40)|0)|0) + 24|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($42 * $weight);
  $44 = ((($vertices) + (($i$014*40)|0)|0) + 28|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($45 * $weight);
  $47 = ((($vertices) + (($i$014*40)|0)|0) + 32|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($48 * $weight);
  $50 = Math_fround(HEAPF32[$40>>2]);
  $51 = Math_fround($43 + $50);
  HEAPF32[$40>>2] = $51;
  $$sum12 = (($$sum1) + 4)|0;
  $52 = (($dst) + ($$sum12)|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($46 + $53);
  HEAPF32[$52>>2] = $54;
  $$sum13 = (($$sum1) + 8)|0;
  $55 = (($dst) + ($$sum13)|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($49 + $56);
  HEAPF32[$55>>2] = $57;
  $58 = (($i$014) + 1)|0;
  $exitcond = ($58|0)==($vertexCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$014 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __Z16ApplyBlendShapesR12SkinMeshInfoPh($info,$dst) {
 $info = $info|0;
 $dst = $dst|0;
 var $$sum = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$05 = 0, $frame$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_imul($3, $1)|0;
 _memcpy(($dst|0),($5|0),($6|0))|0;
 $7 = (($info) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($info) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)>(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($info) + 52|0);
 $13 = (($8) + 32|0);
 $14 = (($8) + 16|0);
 $15 = (($8) + 44|0);
 $c$05 = 0;
 while(1) {
  $16 = HEAP32[$12>>2]|0;
  $17 = (($16) + ($c$05<<2)|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = $18 > Math_fround(9.99999974737875163555E-5);
  do {
   if ($19) {
    $20 = HEAP32[$13>>2]|0;
    $21 = ((($20) + ($c$05<<4)|0) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$14>>2]|0;
    $24 = (($23) + (($22*12)|0)|0);
    $25 = HEAP32[$15>>2]|0;
    $26 = (($25) + ($22<<2)|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = $18 < $27;
    if (!($28)) {
     $29 = ((($20) + ($c$05<<4)|0) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(1);
     if (!($31)) {
      $33 = (($30) + -1)|0;
      $frame$0$i = 0;
      while(1) {
       $34 = ($frame$0$i>>>0)<($33>>>0);
       $35 = (($frame$0$i) + 1)|0;
       $$sum4 = (($35) + ($22))|0;
       $36 = (($25) + ($$sum4<<2)|0);
       if (!($34)) {
        break;
       }
       $37 = Math_fround(HEAPF32[$36>>2]);
       $38 = $37 < $18;
       if ($38) {
        $frame$0$i = $35;
       } else {
        break;
       }
      }
      $$sum = (($frame$0$i) + ($22))|0;
      $39 = (($25) + ($$sum<<2)|0);
      $40 = Math_fround(HEAPF32[$39>>2]);
      $41 = Math_fround(HEAPF32[$36>>2]);
      $42 = Math_fround($18 - $40);
      $43 = Math_fround($41 - $40);
      $44 = Math_fround($42 / $43);
      $45 = (($23) + (($$sum*12)|0)|0);
      $46 = Math_fround(Math_fround(1.0) - $44);
      __Z15ApplyBlendShapeRK10BlendShapeRK13dynamic_arrayI16BlendShapeVertexLj4EEfRK12SkinMeshInfoPh($45,$8,$46,$info,$dst);
      $47 = (($23) + (($$sum4*12)|0)|0);
      __Z15ApplyBlendShapeRK10BlendShapeRK13dynamic_arrayI16BlendShapeVertexLj4EEfRK12SkinMeshInfoPh($47,$8,$44,$info,$dst);
      break;
     }
    }
    $32 = Math_fround($18 / $27);
    __Z15ApplyBlendShapeRK10BlendShapeRK13dynamic_arrayI16BlendShapeVertexLj4EEfRK12SkinMeshInfoPh($24,$8,$32,$info,$dst);
   }
  } while(0);
  $48 = (($c$05) + 1)|0;
  $49 = HEAP32[$9>>2]|0;
  $50 = ($48|0)<($49|0);
  if ($50) {
   $c$05 = $48;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z26RegisterClass_MeshRendererv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(23,115,116,0,0);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(25)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN8Renderer13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 12;
 dest=$3+0|0; src=587712+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 12|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,23,25,($0|0),312,(2387|0),0,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN12MeshRenderer15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(23,564464,1718,0);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(23,564416,1719,0);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(23,564512,1720,0);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(312,$$byval_copy2,1,16,588072,14)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(352,($3|0),1,($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((587736 + 8|0));
  $6 = (($3) + 28|0);
  HEAP32[$6>>2] = ((587736 + 192|0));
  $7 = (($3) + 284|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 288|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 292|0);
  HEAP32[$9>>2] = $3;
  $10 = (($3) + 296|0);
  ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP8[$10+12>>0]=0|0;
  STACKTOP = sp;return ($3|0);
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(588072|0),14);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK12MeshRenderer25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 23;
}
function __ZN12MeshRenderer23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587728,587712,$this,0);
 __ZN8Renderer8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 304|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,587992,588056,$0,1);
 $1 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,588024,$6,$0,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,588040,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i$i = sp + 4|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587728,587712,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN8Renderer8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  $3 = (($this) + 304|0);
  $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,587992,588056,$converter$i$i$i$i,1)|0);
  $5 = ($4|0)==(0);
  if (!($5)) {
   $6 = ($4|0)>(0);
   if ($6) {
    __ZN4PPtrI4MeshE8TransferI14SafeBinaryReadEEvRT_($3,$transfer);
   } else {
    $7 = HEAP32[$converter$i$i$i$i>>2]|0;
    $8 = ($7|0)==(0|0);
    if (!($8)) {
     (FUNCTION_TABLE_iii[$7 & 4095]($3,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $9 = HEAP32[$converter$i$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   (FUNCTION_TABLE_iii[$9 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 304|0);
 __ZN4PPtrI4MeshE8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 304|0);
 __ZN4PPtrI4MeshE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 304|0);
 __ZN4PPtrI4MeshE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
 $0 = (($this) + 304|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $8;
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 288|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 __ZN8Renderer17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 __ZN12MeshRenderer16UpdateCachedMeshEv($this);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer16UpdateCachedMeshEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0;
 var $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 300|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   label = 10;
  } else {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
     $16 = HEAP32[$pos$i$i$i$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if ($30) {
    label = 10;
   } else {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     label = 10;
    } else {
     $temp$0$i = $33;
    }
   }
  }
  if ((label|0) == 10) {
   $35 = HEAP32[$1>>2]|0;
   $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
   $temp$0$i = $36;
  }
  $$0$i = $temp$0$i;
 }
 $37 = (($this) + 296|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($$0$i|0)==($38|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = ($38|0)==(0|0);
 if (!($40)) {
  __ZN8Renderer18ClearSubsetIndicesEv($this);
 }
 HEAP32[$37>>2] = $$0$i;
 $41 = (($this) + 76|0);
 HEAP8[$41>>0] = 1;
 __ZN8Renderer13BoundsChangedEv($this);
 $42 = (($this) + 284|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = (($this) + 288|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($43) + 4|0);
  HEAP32[$47>>2] = $46;
  $48 = HEAP32[$42>>2]|0;
  $49 = HEAP32[$45>>2]|0;
  HEAP32[$49>>2] = $48;
  HEAP32[$42>>2] = 0;
  HEAP32[$45>>2] = 0;
 }
 $50 = HEAP32[$37>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $52 = (($50) + 212|0);
 $53 = ($42|0)==($52|0);
 if ($53) {
  STACKTOP = sp;return;
 }
 $$pre$i$i$i = (($this) + 288|0);
 $54 = HEAP32[$52>>2]|0;
 HEAP32[$42>>2] = $54;
 HEAP32[$$pre$i$i$i>>2] = $52;
 $55 = (($54) + 4|0);
 HEAP32[$55>>2] = $42;
 $56 = HEAP32[$$pre$i$i$i>>2]|0;
 HEAP32[$56>>2] = $42;
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer10DeactivateEN5Unity19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer10DeactivateEN5Unity19DeactivateOperationE($this,$operation);
 STACKTOP = sp;return;
}
function __ZZN12MeshRenderer15InitializeClassEvEN41FunctorImpl_MeshRenderer_kDidModifyBounds4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($object) + 76|0);
 HEAP8[$2>>0] = 1;
 __ZN8Renderer13BoundsChangedEv($object);
 STACKTOP = sp;return;
}
function __ZZN12MeshRenderer15InitializeClassEvEN39FunctorImpl_MeshRenderer_kDidDeleteMesh4CallE_0PviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($object) + 296|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZZN12MeshRenderer15InitializeClassEvEN39FunctorImpl_MeshRenderer_kDidModifyMesh4CallE_1PviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($object) + 76|0);
 HEAP8[$2>>0] = 1;
 __ZN8Renderer13BoundsChangedEv($object);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer15UpdateLocalAABBEv($this) {
 $this = $this|0;
 var $$lcssa = Math_fround(0), $$lcssa1 = Math_fround(0), $$lcssa2 = Math_fround(0), $$lcssa3 = Math_fround(0), $$lcssa4 = Math_fround(0), $$lcssa5 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0;
 var $m$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 296|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $112 = (($this) + 168|0);
  ;HEAP32[$112+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$112+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$112+8>>2]=HEAP32[616680+8>>2]|0;
  $113 = (($this) + 180|0);
  ;HEAP32[$113+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[616680+8>>2]|0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 244|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $110 = (($this) + 168|0);
  $111 = (($1) + 168|0);
  ;HEAP32[$110+0>>2]=HEAP32[$111+0>>2]|0;HEAP32[$110+4>>2]=HEAP32[$111+4>>2]|0;HEAP32[$110+8>>2]=HEAP32[$111+8>>2]|0;HEAP32[$110+12>>2]=HEAP32[$111+12>>2]|0;HEAP32[$110+16>>2]=HEAP32[$111+16>>2]|0;HEAP32[$110+20>>2]=HEAP32[$111+20>>2]|0;
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 128|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($this)|0);
 $10 = ($9|0)==(1);
 if ($10) {
  $11 = (($this) + 168|0);
  $12 = HEAP32[$0>>2]|0;
  $13 = HEAP32[$this>>2]|0;
  $14 = (($13) + 136|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_iii[$15 & 4095]($this,0)|0);
  $17 = (($12) + 44|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($18) + (($16*56)|0)|0) + 32|0);
  ;HEAP32[$11+0>>2]=HEAP32[$19+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$19+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$19+12>>2]|0;HEAP32[$11+16>>2]=HEAP32[$19+16>>2]|0;HEAP32[$11+20>>2]=HEAP32[$19+20>>2]|0;
  STACKTOP = sp;return;
 }
 $20 = Math_fround(HEAPF32[616664>>2]);
 $21 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $22 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $23 = Math_fround(-$20);
 $24 = Math_fround(-$21);
 $25 = Math_fround(-$22);
 $26 = HEAP32[$this>>2]|0;
 $27 = (($26) + 128|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 4095]($this)|0);
 $30 = ($29|0)>(0);
 if ($30) {
  $54 = $20;$57 = $21;$60 = $22;$63 = $23;$66 = $24;$69 = $25;$m$06 = 0;
  while(1) {
   $31 = HEAP32[$0>>2]|0;
   $32 = HEAP32[$this>>2]|0;
   $33 = (($32) + 136|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (FUNCTION_TABLE_iii[$34 & 4095]($this,$m$06)|0);
   $36 = (($31) + 44|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($37) + (($35*56)|0)|0) + 32|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = ((($37) + (($35*56)|0)|0) + 44|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = Math_fround($39 + $41);
   $43 = ((($37) + (($35*56)|0)|0) + 36|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = ((($37) + (($35*56)|0)|0) + 48|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = Math_fround($44 + $46);
   $48 = ((($37) + (($35*56)|0)|0) + 40|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = ((($37) + (($35*56)|0)|0) + 52|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = Math_fround($49 + $51);
   $53 = $42 < $54;
   $55 = $53 ? $42 : $54;
   $56 = $47 < $57;
   $58 = $56 ? $47 : $57;
   $59 = $52 < $60;
   $61 = $59 ? $52 : $60;
   $62 = $63 < $42;
   $64 = $62 ? $42 : $63;
   $65 = $66 < $47;
   $67 = $65 ? $47 : $66;
   $68 = $69 < $52;
   $70 = $68 ? $52 : $69;
   $71 = Math_fround($39 - $41);
   $72 = Math_fround($44 - $46);
   $73 = Math_fround($49 - $51);
   $74 = $71 < $55;
   $75 = $74 ? $71 : $55;
   $76 = $72 < $58;
   $77 = $76 ? $72 : $58;
   $78 = $73 < $61;
   $79 = $78 ? $73 : $61;
   $80 = $64 < $71;
   $81 = $80 ? $71 : $64;
   $82 = $67 < $72;
   $83 = $82 ? $72 : $67;
   $84 = $70 < $73;
   $85 = $84 ? $73 : $70;
   $86 = (($m$06) + 1)|0;
   $87 = HEAP32[$this>>2]|0;
   $88 = (($87) + 128|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (FUNCTION_TABLE_ii[$89 & 4095]($this)|0);
   $91 = ($86|0)<($90|0);
   if ($91) {
    $54 = $75;$57 = $77;$60 = $79;$63 = $81;$66 = $83;$69 = $85;$m$06 = $86;
   } else {
    $$lcssa = $85;$$lcssa1 = $83;$$lcssa2 = $81;$$lcssa3 = $79;$$lcssa4 = $77;$$lcssa5 = $75;
    break;
   }
  }
 } else {
  $$lcssa = $25;$$lcssa1 = $24;$$lcssa2 = $23;$$lcssa3 = $22;$$lcssa4 = $21;$$lcssa5 = $20;
 }
 $92 = Math_fround($$lcssa2 + $$lcssa5);
 $93 = Math_fround($$lcssa1 + $$lcssa4);
 $94 = Math_fround($$lcssa + $$lcssa3);
 $95 = Math_fround($92 * Math_fround(0.5));
 $96 = Math_fround($93 * Math_fround(0.5));
 $97 = Math_fround($94 * Math_fround(0.5));
 $98 = (($this) + 168|0);
 HEAPF32[$98>>2] = $95;
 $99 = (($this) + 172|0);
 HEAPF32[$99>>2] = $96;
 $100 = (($this) + 176|0);
 HEAPF32[$100>>2] = $97;
 $101 = Math_fround($$lcssa2 - $$lcssa5);
 $102 = Math_fround($$lcssa1 - $$lcssa4);
 $103 = Math_fround($$lcssa - $$lcssa3);
 $104 = Math_fround($101 * Math_fround(0.5));
 $105 = Math_fround($102 * Math_fround(0.5));
 $106 = Math_fround($103 * Math_fround(0.5));
 $107 = (($this) + 180|0);
 HEAPF32[$107>>2] = $104;
 $108 = (($this) + 184|0);
 HEAPF32[$108>>2] = $105;
 $109 = (($this) + 188|0);
 HEAPF32[$109>>2] = $106;
 STACKTOP = sp;return;
}
function __ZNK12MeshRenderer19GetStaticBatchIndexEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 296|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $8 = 0;
 } else {
  $3 = (($this) + 244|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   $8 = 0;
  } else {
   $6 = (($1) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $7;
  }
 }
 STACKTOP = sp;return ($8|0);
}
function __ZNK12MeshRenderer23GetMeshStaticBatchIndexEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 296|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $8 = 0;
 } else {
  $3 = (($this) + 244|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   $8 = 0;
  } else {
   $6 = (($1) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $7;
  }
 }
 STACKTOP = sp;return ($8|0);
}
function __ZThn28_NK12MeshRenderer19GetStaticBatchIndexEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 $1 = (($0) + 296|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $9 = 0;
 } else {
  $4 = (($0) + 244|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0);
  if ($6) {
   $9 = 0;
  } else {
   $7 = (($2) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8;
  }
 }
 STACKTOP = sp;return ($9|0);
}
function __ZNK12MeshRenderer14GetMeshIDSmallEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 296|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = 0;
 } else {
  $3 = (($1) + 36|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4;
 }
 STACKTOP = sp;return ($5|0);
}
function __ZThn28_NK12MeshRenderer14GetMeshIDSmallEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 $1 = (($0) + 296|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $6 = 0;
  STACKTOP = sp;return ($6|0);
 }
 $4 = (($2) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 STACKTOP = sp;return ($6|0);
}
function __ZNK12MeshRenderer23GetMeshUsedForRenderingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 296|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN12MeshRenderer6RenderEiRK14ChannelAssigns($this,$subsetIndex,$channels) {
 $this = $this|0;
 $subsetIndex = $subsetIndex|0;
 $channels = $channels|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 296|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (__Z12GetGfxDevicev()|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 216|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vii[$10 & 4095]($7,$11);
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 304|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $15;
  $17 = HEAP32[560624>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   label = 13;
  } else {
   $19 = (($17) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($17) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($20|0)==($22|0);
   do {
    if ($23) {
     $24 = (($17) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($17) + 32|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($25) + ($27<<3)|0);
     $44 = $28;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$17,$0);
     $29 = HEAP32[$pos$i$i$i$i>>2]|0;
     $30 = ($29|0)==(-1);
     $31 = (($17) + 28|0);
     $32 = HEAP32[$31>>2]|0;
     if ($30) {
      $33 = (($17) + 32|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($32) + ($34<<3)|0);
      $44 = $35;
      break;
     } else {
      $36 = (($32) + ($29<<3)|0);
      $44 = $36;
      break;
     }
    }
   } while(0);
   $37 = HEAP32[560624>>2]|0;
   $38 = (($37) + 28|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($37) + 32|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + ($41<<3)|0);
   $43 = ($44|0)==($42|0);
   if ($43) {
    label = 13;
   } else {
    $45 = (($44) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)==(0|0);
    if ($47) {
     label = 13;
    } else {
     $temp$0$i = $46;
    }
   }
  }
  if ((label|0) == 13) {
   $48 = HEAP32[$14>>2]|0;
   $49 = (__Z31ReadObjectFromPersistentManageri($48)|0);
   $temp$0$i = $49;
  }
  $$0$i = $temp$0$i;
 }
 __ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_($channels,$2,$subsetIndex,$13,$$0$i);
 STACKTOP = sp;return;
}
function __ZThn28_N12MeshRenderer6RenderEiRK14ChannelAssigns($this,$subsetIndex,$channels) {
 $this = $this|0;
 $subsetIndex = $subsetIndex|0;
 $channels = $channels|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 __ZN12MeshRenderer6RenderEiRK14ChannelAssigns($0,$subsetIndex,$channels);
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer13SetSharedMeshE4PPtrI4MeshE($this,$mesh) {
 $this = $this|0;
 $mesh = $mesh|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$mesh>>2]|0;
 $1 = (($this) + 300|0);
 HEAP32[$1>>2] = $0;
 __ZN12MeshRenderer16UpdateCachedMeshEv($this);
 STACKTOP = sp;return;
}
function __ZNK12MeshRenderer13GetSharedMeshEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 300|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN12MeshRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns($this,$renderData,$channels) {
 $this = $this|0;
 $renderData = $renderData|0;
 $channels = $channels|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z20RenderMultipleMeshesRK22RenderMultipleMeshDataRK14ChannelAssigns($renderData,$channels);
 STACKTOP = sp;return;
}
function __ZThn28_N12MeshRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns($this,$renderData,$channels) {
 $this = $this|0;
 $renderData = $renderData|0;
 $channels = $channels|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z20RenderMultipleMeshesRK22RenderMultipleMeshDataRK14ChannelAssigns($renderData,$channels);
 STACKTOP = sp;return;
}
function __ZNK12MeshRenderer26GetAdditionalVertexStreamsEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 304|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN12MeshRendererD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((587736 + 8|0));
 $0 = (($this) + 28|0);
 HEAP32[$0>>2] = ((587736 + 192|0));
 __ZN8RendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN12MeshRendererD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((587736 + 8|0));
 $0 = (($this) + 28|0);
 HEAP32[$0>>2] = ((587736 + 192|0));
 __THREW__ = 0;
 invoke_vi(3449,($this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($this);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK12MeshRenderer14AllowsBatchingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 308|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 STACKTOP = sp;return ($2|0);
}
function __ZThn28_N12MeshRendererD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 HEAP32[$0>>2] = ((587736 + 8|0));
 $1 = (($0) + 28|0);
 HEAP32[$1>>2] = ((587736 + 192|0));
 __ZN8RendererD2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn28_N12MeshRendererD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 HEAP32[$0>>2] = ((587736 + 8|0));
 $1 = (($0) + 28|0);
 HEAP32[$1>>2] = ((587736 + 192|0));
 __THREW__ = 0;
 invoke_vi(3449,($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
}
function __ZThn28_NK12MeshRenderer14AllowsBatchingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 $1 = (($0) + 308|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 STACKTOP = sp;return ($3|0);
}
function __Z8SkinMeshR12SkinMeshInfo($info) {
 $info = $info|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = HEAP32[$info>>2]|0;
   if ((($3|0) == 1)) {
    __Z11SkinGenericILi1ELb0ELb0EEvR12SkinMeshInfo($info);
    break;
   } else if ((($3|0) == 4)) {
    __Z11SkinGenericILi4ELb0ELb0EEvR12SkinMeshInfo($info);
    break;
   } else if ((($3|0) == 2)) {
    __Z11SkinGenericILi2ELb0ELb0EEvR12SkinMeshInfo($info);
    break;
   } else {
    break;
   }
  } else {
   $4 = (($info) + 37|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   $7 = HEAP32[$info>>2]|0;
   if ($6) {
    if ((($7|0) == 4)) {
     __Z11SkinGenericILi4ELb1ELb0EEvR12SkinMeshInfo($info);
     break;
    } else if ((($7|0) == 1)) {
     __Z11SkinGenericILi1ELb1ELb0EEvR12SkinMeshInfo($info);
     break;
    } else if ((($7|0) == 2)) {
     __Z11SkinGenericILi2ELb1ELb0EEvR12SkinMeshInfo($info);
     break;
    } else {
     break;
    }
   } else {
    if ((($7|0) == 1)) {
     __Z11SkinGenericILi1ELb1ELb1EEvR12SkinMeshInfo($info);
     break;
    } else if ((($7|0) == 2)) {
     __Z11SkinGenericILi2ELb1ELb1EEvR12SkinMeshInfo($info);
     break;
    } else if ((($7|0) == 4)) {
     __Z11SkinGenericILi4ELb1ELb1EEvR12SkinMeshInfo($info);
     break;
    } else {
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi1ELb1ELb1EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $influence1$013 = 0, $inputVertex$012 = 0, $outputVertex$011 = 0, $v$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($info) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($7|0)>(0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($info) + 4|0);
 $14 = (($info) + 16|0);
 $15 = (($info) + 12|0);
 $16 = HEAP32[$13>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $$sum2 = (($9) + 4)|0;
 $$sum3 = (($9) + 8)|0;
 $$sum4 = (($11) + 4)|0;
 $$sum5 = (($11) + 8)|0;
 $$sum = (($11) + 12)|0;
 $influence1$013 = $16;$inputVertex$012 = $18;$outputVertex$011 = $17;$v$010 = 0;
 while(1) {
  $19 = HEAP32[$influence1$013>>2]|0;
  $20 = (($inputVertex$012) + ($9)|0);
  $21 = (($inputVertex$012) + ($11)|0);
  $22 = (($1) + ($19<<6)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround(HEAPF32[$inputVertex$012>>2]);
  $25 = Math_fround($23 * $24);
  $26 = ((($1) + ($19<<6)|0) + 16|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($inputVertex$012) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($27 * $29);
  $31 = Math_fround($25 + $30);
  $32 = ((($1) + ($19<<6)|0) + 32|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($inputVertex$012) + 8|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($33 * $35);
  $37 = Math_fround($31 + $36);
  $38 = ((($1) + ($19<<6)|0) + 48|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($39 + $37);
  $41 = ((($1) + ($19<<6)|0) + 4|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($24 * $42);
  $44 = ((($1) + ($19<<6)|0) + 20|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($29 * $45);
  $47 = Math_fround($43 + $46);
  $48 = ((($1) + ($19<<6)|0) + 36|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = Math_fround($35 * $49);
  $51 = Math_fround($47 + $50);
  $52 = ((($1) + ($19<<6)|0) + 52|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($53 + $51);
  $55 = ((($1) + ($19<<6)|0) + 8|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($24 * $56);
  $58 = ((($1) + ($19<<6)|0) + 24|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($29 * $59);
  $61 = Math_fround($57 + $60);
  $62 = ((($1) + ($19<<6)|0) + 40|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($35 * $63);
  $65 = Math_fround($61 + $64);
  $66 = ((($1) + ($19<<6)|0) + 56|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($67 + $65);
  $69 = Math_fround(HEAPF32[$20>>2]);
  $70 = Math_fround($23 * $69);
  $71 = (($inputVertex$012) + ($$sum2)|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($27 * $72);
  $74 = Math_fround($70 + $73);
  $75 = (($inputVertex$012) + ($$sum3)|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($33 * $76);
  $78 = Math_fround($74 + $77);
  $79 = Math_fround($42 * $69);
  $80 = Math_fround($45 * $72);
  $81 = Math_fround($79 + $80);
  $82 = Math_fround($49 * $76);
  $83 = Math_fround($81 + $82);
  $84 = Math_fround($56 * $69);
  $85 = Math_fround($59 * $72);
  $86 = Math_fround($84 + $85);
  $87 = Math_fround($63 * $76);
  $88 = Math_fround($86 + $87);
  $89 = Math_fround(HEAPF32[$21>>2]);
  $90 = Math_fround($23 * $89);
  $91 = (($inputVertex$012) + ($$sum4)|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = Math_fround($27 * $92);
  $94 = Math_fround($90 + $93);
  $95 = (($inputVertex$012) + ($$sum5)|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = Math_fround($33 * $96);
  $98 = Math_fround($94 + $97);
  $99 = Math_fround($42 * $89);
  $100 = Math_fround($45 * $92);
  $101 = Math_fround($99 + $100);
  $102 = Math_fround($49 * $96);
  $103 = Math_fround($101 + $102);
  $104 = Math_fround($56 * $89);
  $105 = Math_fround($59 * $92);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($63 * $96);
  $108 = Math_fround($106 + $107);
  HEAPF32[$outputVertex$011>>2] = $40;
  $109 = (($outputVertex$011) + 4|0);
  HEAPF32[$109>>2] = $54;
  $110 = (($outputVertex$011) + 8|0);
  HEAPF32[$110>>2] = $68;
  $111 = (($outputVertex$011) + ($9)|0);
  HEAPF32[$111>>2] = $78;
  $112 = (($outputVertex$011) + ($$sum2)|0);
  HEAPF32[$112>>2] = $83;
  $113 = (($outputVertex$011) + ($$sum3)|0);
  HEAPF32[$113>>2] = $88;
  $114 = (($outputVertex$011) + ($11)|0);
  HEAPF32[$114>>2] = $98;
  $115 = (($outputVertex$011) + ($$sum4)|0);
  HEAPF32[$115>>2] = $103;
  $116 = (($outputVertex$011) + ($$sum5)|0);
  HEAPF32[$116>>2] = $108;
  $117 = (($inputVertex$012) + ($$sum)|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = (($outputVertex$011) + ($$sum)|0);
  HEAPF32[$119>>2] = $118;
  $120 = (($outputVertex$011) + ($5)|0);
  $121 = (($inputVertex$012) + ($3)|0);
  $122 = (($influence1$013) + 4|0);
  $123 = (($v$010) + 1)|0;
  $exitcond = ($123|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence1$013 = $122;$inputVertex$012 = $121;$outputVertex$011 = $120;$v$010 = $123;
  }
 }
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi2ELb1ELb1EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0;
 var $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0);
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond = 0, $influence2$013 = 0, $inputVertex$012 = 0, $outputVertex$011 = 0, $v$010 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($info) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($7|0)>(0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($info) + 4|0);
 $14 = (($info) + 16|0);
 $15 = (($info) + 12|0);
 $16 = HEAP32[$13>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $$sum2 = (($9) + 4)|0;
 $$sum3 = (($9) + 8)|0;
 $$sum4 = (($11) + 4)|0;
 $$sum5 = (($11) + 8)|0;
 $$sum = (($11) + 12)|0;
 $influence2$013 = $16;$inputVertex$012 = $18;$outputVertex$011 = $17;$v$010 = 0;
 while(1) {
  $19 = Math_fround(HEAPF32[$influence2$013>>2]);
  $20 = (($influence2$013) + 4|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($influence2$013) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($1) + ($23<<6)|0);
  $25 = (($influence2$013) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($1) + ($26<<6)|0);
  $28 = Math_fround(HEAPF32[$24>>2]);
  $29 = Math_fround($19 * $28);
  $30 = Math_fround(HEAPF32[$27>>2]);
  $31 = Math_fround($21 * $30);
  $32 = Math_fround($29 + $31);
  $33 = ((($1) + ($23<<6)|0) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($19 * $34);
  $36 = ((($1) + ($26<<6)|0) + 4|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($21 * $37);
  $39 = Math_fround($35 + $38);
  $40 = ((($1) + ($23<<6)|0) + 8|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($19 * $41);
  $43 = ((($1) + ($26<<6)|0) + 8|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($21 * $44);
  $46 = Math_fround($42 + $45);
  $47 = ((($1) + ($23<<6)|0) + 16|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($19 * $48);
  $50 = ((($1) + ($26<<6)|0) + 16|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($21 * $51);
  $53 = Math_fround($49 + $52);
  $54 = ((($1) + ($23<<6)|0) + 20|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($19 * $55);
  $57 = ((($1) + ($26<<6)|0) + 20|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($21 * $58);
  $60 = Math_fround($56 + $59);
  $61 = ((($1) + ($23<<6)|0) + 24|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = Math_fround($19 * $62);
  $64 = ((($1) + ($26<<6)|0) + 24|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($21 * $65);
  $67 = Math_fround($63 + $66);
  $68 = ((($1) + ($23<<6)|0) + 32|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($19 * $69);
  $71 = ((($1) + ($26<<6)|0) + 32|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($21 * $72);
  $74 = Math_fround($70 + $73);
  $75 = ((($1) + ($23<<6)|0) + 36|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($19 * $76);
  $78 = ((($1) + ($26<<6)|0) + 36|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($21 * $79);
  $81 = Math_fround($77 + $80);
  $82 = ((($1) + ($23<<6)|0) + 40|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($19 * $83);
  $85 = ((($1) + ($26<<6)|0) + 40|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround($21 * $86);
  $88 = Math_fround($84 + $87);
  $89 = ((($1) + ($23<<6)|0) + 48|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = Math_fround($19 * $90);
  $92 = ((($1) + ($26<<6)|0) + 48|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = Math_fround($21 * $93);
  $95 = Math_fround($91 + $94);
  $96 = ((($1) + ($23<<6)|0) + 52|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = Math_fround($19 * $97);
  $99 = ((($1) + ($26<<6)|0) + 52|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($21 * $100);
  $102 = Math_fround($98 + $101);
  $103 = ((($1) + ($23<<6)|0) + 56|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = Math_fround($19 * $104);
  $106 = ((($1) + ($26<<6)|0) + 56|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = Math_fround($21 * $107);
  $109 = Math_fround($105 + $108);
  $110 = (($inputVertex$012) + ($9)|0);
  $111 = (($inputVertex$012) + ($11)|0);
  $112 = Math_fround(HEAPF32[$inputVertex$012>>2]);
  $113 = Math_fround($32 * $112);
  $114 = (($inputVertex$012) + 4|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($53 * $115);
  $117 = Math_fround($113 + $116);
  $118 = (($inputVertex$012) + 8|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround($74 * $119);
  $121 = Math_fround($117 + $120);
  $122 = Math_fround($95 + $121);
  $123 = Math_fround($39 * $112);
  $124 = Math_fround($60 * $115);
  $125 = Math_fround($123 + $124);
  $126 = Math_fround($81 * $119);
  $127 = Math_fround($125 + $126);
  $128 = Math_fround($102 + $127);
  $129 = Math_fround($46 * $112);
  $130 = Math_fround($67 * $115);
  $131 = Math_fround($129 + $130);
  $132 = Math_fround($88 * $119);
  $133 = Math_fround($131 + $132);
  $134 = Math_fround($109 + $133);
  $135 = Math_fround(HEAPF32[$110>>2]);
  $136 = Math_fround($32 * $135);
  $137 = (($inputVertex$012) + ($$sum2)|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = Math_fround($53 * $138);
  $140 = Math_fround($136 + $139);
  $141 = (($inputVertex$012) + ($$sum3)|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = Math_fround($74 * $142);
  $144 = Math_fround($140 + $143);
  $145 = Math_fround($39 * $135);
  $146 = Math_fround($60 * $138);
  $147 = Math_fround($145 + $146);
  $148 = Math_fround($81 * $142);
  $149 = Math_fround($147 + $148);
  $150 = Math_fround($46 * $135);
  $151 = Math_fround($67 * $138);
  $152 = Math_fround($150 + $151);
  $153 = Math_fround($88 * $142);
  $154 = Math_fround($152 + $153);
  $155 = Math_fround(HEAPF32[$111>>2]);
  $156 = Math_fround($32 * $155);
  $157 = (($inputVertex$012) + ($$sum4)|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = Math_fround($53 * $158);
  $160 = Math_fround($156 + $159);
  $161 = (($inputVertex$012) + ($$sum5)|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($74 * $162);
  $164 = Math_fround($160 + $163);
  $165 = Math_fround($39 * $155);
  $166 = Math_fround($60 * $158);
  $167 = Math_fround($165 + $166);
  $168 = Math_fround($81 * $162);
  $169 = Math_fround($167 + $168);
  $170 = Math_fround($46 * $155);
  $171 = Math_fround($67 * $158);
  $172 = Math_fround($170 + $171);
  $173 = Math_fround($88 * $162);
  $174 = Math_fround($172 + $173);
  HEAPF32[$outputVertex$011>>2] = $122;
  $175 = (($outputVertex$011) + 4|0);
  HEAPF32[$175>>2] = $128;
  $176 = (($outputVertex$011) + 8|0);
  HEAPF32[$176>>2] = $134;
  $177 = (($outputVertex$011) + ($9)|0);
  HEAPF32[$177>>2] = $144;
  $178 = (($outputVertex$011) + ($$sum2)|0);
  HEAPF32[$178>>2] = $149;
  $179 = (($outputVertex$011) + ($$sum3)|0);
  HEAPF32[$179>>2] = $154;
  $180 = (($outputVertex$011) + ($11)|0);
  HEAPF32[$180>>2] = $164;
  $181 = (($outputVertex$011) + ($$sum4)|0);
  HEAPF32[$181>>2] = $169;
  $182 = (($outputVertex$011) + ($$sum5)|0);
  HEAPF32[$182>>2] = $174;
  $183 = (($inputVertex$012) + ($$sum)|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = (($outputVertex$011) + ($$sum)|0);
  HEAPF32[$185>>2] = $184;
  $186 = (($outputVertex$011) + ($5)|0);
  $187 = (($inputVertex$012) + ($3)|0);
  $188 = (($influence2$013) + 16|0);
  $189 = (($v$010) + 1)|0;
  $exitcond = ($189|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence2$013 = $188;$inputVertex$012 = $187;$outputVertex$011 = $186;$v$010 = $189;
  }
 }
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi4ELb1ELb1EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0);
 var $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0);
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0;
 var $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0);
 var $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0);
 var $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0);
 var $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0);
 var $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0);
 var $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0);
 var $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0;
 var $influence4$013 = 0, $inputVertex$012 = 0, $outputVertex$011 = 0, $v$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($info) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($7|0)>(0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($info) + 4|0);
 $14 = (($info) + 16|0);
 $15 = (($info) + 12|0);
 $16 = HEAP32[$13>>2]|0;
 $17 = HEAP32[$14>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $$sum2 = (($9) + 4)|0;
 $$sum3 = (($9) + 8)|0;
 $$sum4 = (($11) + 4)|0;
 $$sum5 = (($11) + 8)|0;
 $$sum = (($11) + 12)|0;
 $influence4$013 = $16;$inputVertex$012 = $18;$outputVertex$011 = $17;$v$010 = 0;
 while(1) {
  $19 = Math_fround(HEAPF32[$influence4$013>>2]);
  $20 = (($influence4$013) + 4|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($influence4$013) + 8|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($influence4$013) + 12|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($influence4$013) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($1) + ($27<<6)|0);
  $29 = (($influence4$013) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($1) + ($30<<6)|0);
  $32 = (($influence4$013) + 24|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($1) + ($33<<6)|0);
  $35 = (($influence4$013) + 28|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($1) + ($36<<6)|0);
  $38 = Math_fround(HEAPF32[$28>>2]);
  $39 = Math_fround($19 * $38);
  $40 = Math_fround(HEAPF32[$31>>2]);
  $41 = Math_fround($21 * $40);
  $42 = Math_fround($39 + $41);
  $43 = Math_fround(HEAPF32[$34>>2]);
  $44 = Math_fround($23 * $43);
  $45 = Math_fround($42 + $44);
  $46 = Math_fround(HEAPF32[$37>>2]);
  $47 = Math_fround($25 * $46);
  $48 = Math_fround($45 + $47);
  $49 = ((($1) + ($27<<6)|0) + 4|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($19 * $50);
  $52 = ((($1) + ($30<<6)|0) + 4|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($21 * $53);
  $55 = Math_fround($51 + $54);
  $56 = ((($1) + ($33<<6)|0) + 4|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($23 * $57);
  $59 = Math_fround($55 + $58);
  $60 = ((($1) + ($36<<6)|0) + 4|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($25 * $61);
  $63 = Math_fround($59 + $62);
  $64 = ((($1) + ($27<<6)|0) + 8|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($19 * $65);
  $67 = ((($1) + ($30<<6)|0) + 8|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($21 * $68);
  $70 = Math_fround($66 + $69);
  $71 = ((($1) + ($33<<6)|0) + 8|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($23 * $72);
  $74 = Math_fround($70 + $73);
  $75 = ((($1) + ($36<<6)|0) + 8|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($25 * $76);
  $78 = Math_fround($74 + $77);
  $79 = ((($1) + ($27<<6)|0) + 16|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = Math_fround($19 * $80);
  $82 = ((($1) + ($30<<6)|0) + 16|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($21 * $83);
  $85 = Math_fround($81 + $84);
  $86 = ((($1) + ($33<<6)|0) + 16|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = Math_fround($23 * $87);
  $89 = Math_fround($85 + $88);
  $90 = ((($1) + ($36<<6)|0) + 16|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($25 * $91);
  $93 = Math_fround($89 + $92);
  $94 = ((($1) + ($27<<6)|0) + 20|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = Math_fround($19 * $95);
  $97 = ((($1) + ($30<<6)|0) + 20|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = Math_fround($21 * $98);
  $100 = Math_fround($96 + $99);
  $101 = ((($1) + ($33<<6)|0) + 20|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($23 * $102);
  $104 = Math_fround($100 + $103);
  $105 = ((($1) + ($36<<6)|0) + 20|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = Math_fround($25 * $106);
  $108 = Math_fround($104 + $107);
  $109 = ((($1) + ($27<<6)|0) + 24|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = Math_fround($19 * $110);
  $112 = ((($1) + ($30<<6)|0) + 24|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($21 * $113);
  $115 = Math_fround($111 + $114);
  $116 = ((($1) + ($33<<6)|0) + 24|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = Math_fround($23 * $117);
  $119 = Math_fround($115 + $118);
  $120 = ((($1) + ($36<<6)|0) + 24|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = Math_fround($25 * $121);
  $123 = Math_fround($119 + $122);
  $124 = ((($1) + ($27<<6)|0) + 32|0);
  $125 = Math_fround(HEAPF32[$124>>2]);
  $126 = Math_fround($19 * $125);
  $127 = ((($1) + ($30<<6)|0) + 32|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = Math_fround($21 * $128);
  $130 = Math_fround($126 + $129);
  $131 = ((($1) + ($33<<6)|0) + 32|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = Math_fround($23 * $132);
  $134 = Math_fround($130 + $133);
  $135 = ((($1) + ($36<<6)|0) + 32|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = Math_fround($25 * $136);
  $138 = Math_fround($134 + $137);
  $139 = ((($1) + ($27<<6)|0) + 36|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = Math_fround($19 * $140);
  $142 = ((($1) + ($30<<6)|0) + 36|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = Math_fround($21 * $143);
  $145 = Math_fround($141 + $144);
  $146 = ((($1) + ($33<<6)|0) + 36|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  $148 = Math_fround($23 * $147);
  $149 = Math_fround($145 + $148);
  $150 = ((($1) + ($36<<6)|0) + 36|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = Math_fround($25 * $151);
  $153 = Math_fround($149 + $152);
  $154 = ((($1) + ($27<<6)|0) + 40|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = Math_fround($19 * $155);
  $157 = ((($1) + ($30<<6)|0) + 40|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = Math_fround($21 * $158);
  $160 = Math_fround($156 + $159);
  $161 = ((($1) + ($33<<6)|0) + 40|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($23 * $162);
  $164 = Math_fround($160 + $163);
  $165 = ((($1) + ($36<<6)|0) + 40|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = Math_fround($25 * $166);
  $168 = Math_fround($164 + $167);
  $169 = ((($1) + ($27<<6)|0) + 48|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround($19 * $170);
  $172 = ((($1) + ($30<<6)|0) + 48|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($21 * $173);
  $175 = Math_fround($171 + $174);
  $176 = ((($1) + ($33<<6)|0) + 48|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround($23 * $177);
  $179 = Math_fround($175 + $178);
  $180 = ((($1) + ($36<<6)|0) + 48|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = Math_fround($25 * $181);
  $183 = Math_fround($179 + $182);
  $184 = ((($1) + ($27<<6)|0) + 52|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = Math_fround($19 * $185);
  $187 = ((($1) + ($30<<6)|0) + 52|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = Math_fround($21 * $188);
  $190 = Math_fround($186 + $189);
  $191 = ((($1) + ($33<<6)|0) + 52|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = Math_fround($23 * $192);
  $194 = Math_fround($190 + $193);
  $195 = ((($1) + ($36<<6)|0) + 52|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = Math_fround($25 * $196);
  $198 = Math_fround($194 + $197);
  $199 = ((($1) + ($27<<6)|0) + 56|0);
  $200 = Math_fround(HEAPF32[$199>>2]);
  $201 = Math_fround($19 * $200);
  $202 = ((($1) + ($30<<6)|0) + 56|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = Math_fround($21 * $203);
  $205 = Math_fround($201 + $204);
  $206 = ((($1) + ($33<<6)|0) + 56|0);
  $207 = Math_fround(HEAPF32[$206>>2]);
  $208 = Math_fround($23 * $207);
  $209 = Math_fround($205 + $208);
  $210 = ((($1) + ($36<<6)|0) + 56|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = Math_fround($25 * $211);
  $213 = Math_fround($209 + $212);
  $214 = (($inputVertex$012) + ($9)|0);
  $215 = (($inputVertex$012) + ($11)|0);
  $216 = Math_fround(HEAPF32[$inputVertex$012>>2]);
  $217 = Math_fround($48 * $216);
  $218 = (($inputVertex$012) + 4|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = Math_fround($93 * $219);
  $221 = Math_fround($217 + $220);
  $222 = (($inputVertex$012) + 8|0);
  $223 = Math_fround(HEAPF32[$222>>2]);
  $224 = Math_fround($138 * $223);
  $225 = Math_fround($221 + $224);
  $226 = Math_fround($183 + $225);
  $227 = Math_fround($63 * $216);
  $228 = Math_fround($108 * $219);
  $229 = Math_fround($227 + $228);
  $230 = Math_fround($153 * $223);
  $231 = Math_fround($229 + $230);
  $232 = Math_fround($198 + $231);
  $233 = Math_fround($78 * $216);
  $234 = Math_fround($123 * $219);
  $235 = Math_fround($233 + $234);
  $236 = Math_fround($168 * $223);
  $237 = Math_fround($235 + $236);
  $238 = Math_fround($213 + $237);
  $239 = Math_fround(HEAPF32[$214>>2]);
  $240 = Math_fround($48 * $239);
  $241 = (($inputVertex$012) + ($$sum2)|0);
  $242 = Math_fround(HEAPF32[$241>>2]);
  $243 = Math_fround($93 * $242);
  $244 = Math_fround($240 + $243);
  $245 = (($inputVertex$012) + ($$sum3)|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = Math_fround($138 * $246);
  $248 = Math_fround($244 + $247);
  $249 = Math_fround($63 * $239);
  $250 = Math_fround($108 * $242);
  $251 = Math_fround($249 + $250);
  $252 = Math_fround($153 * $246);
  $253 = Math_fround($251 + $252);
  $254 = Math_fround($78 * $239);
  $255 = Math_fround($123 * $242);
  $256 = Math_fround($254 + $255);
  $257 = Math_fround($168 * $246);
  $258 = Math_fround($256 + $257);
  $259 = Math_fround(HEAPF32[$215>>2]);
  $260 = Math_fround($48 * $259);
  $261 = (($inputVertex$012) + ($$sum4)|0);
  $262 = Math_fround(HEAPF32[$261>>2]);
  $263 = Math_fround($93 * $262);
  $264 = Math_fround($260 + $263);
  $265 = (($inputVertex$012) + ($$sum5)|0);
  $266 = Math_fround(HEAPF32[$265>>2]);
  $267 = Math_fround($138 * $266);
  $268 = Math_fround($264 + $267);
  $269 = Math_fround($63 * $259);
  $270 = Math_fround($108 * $262);
  $271 = Math_fround($269 + $270);
  $272 = Math_fround($153 * $266);
  $273 = Math_fround($271 + $272);
  $274 = Math_fround($78 * $259);
  $275 = Math_fround($123 * $262);
  $276 = Math_fround($274 + $275);
  $277 = Math_fround($168 * $266);
  $278 = Math_fround($276 + $277);
  HEAPF32[$outputVertex$011>>2] = $226;
  $279 = (($outputVertex$011) + 4|0);
  HEAPF32[$279>>2] = $232;
  $280 = (($outputVertex$011) + 8|0);
  HEAPF32[$280>>2] = $238;
  $281 = (($outputVertex$011) + ($9)|0);
  HEAPF32[$281>>2] = $248;
  $282 = (($outputVertex$011) + ($$sum2)|0);
  HEAPF32[$282>>2] = $253;
  $283 = (($outputVertex$011) + ($$sum3)|0);
  HEAPF32[$283>>2] = $258;
  $284 = (($outputVertex$011) + ($11)|0);
  HEAPF32[$284>>2] = $268;
  $285 = (($outputVertex$011) + ($$sum4)|0);
  HEAPF32[$285>>2] = $273;
  $286 = (($outputVertex$011) + ($$sum5)|0);
  HEAPF32[$286>>2] = $278;
  $287 = (($inputVertex$012) + ($$sum)|0);
  $288 = Math_fround(HEAPF32[$287>>2]);
  $289 = (($outputVertex$011) + ($$sum)|0);
  HEAPF32[$289>>2] = $288;
  $290 = (($outputVertex$011) + ($5)|0);
  $291 = (($inputVertex$012) + ($3)|0);
  $292 = (($influence4$013) + 32|0);
  $293 = (($v$010) + 1)|0;
  $exitcond = ($293|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence4$013 = $292;$inputVertex$012 = $291;$outputVertex$011 = $290;$v$010 = $293;
  }
 }
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi1ELb1ELb0EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $exitcond = 0, $influence1$07 = 0, $inputVertex$06 = 0;
 var $outputVertex$05 = 0, $v$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)>(0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($info) + 4|0);
 $12 = (($info) + 16|0);
 $13 = (($info) + 12|0);
 $14 = HEAP32[$11>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = HEAP32[$13>>2]|0;
 $$sum = (($9) + 4)|0;
 $$sum1 = (($9) + 8)|0;
 $influence1$07 = $14;$inputVertex$06 = $16;$outputVertex$05 = $15;$v$04 = 0;
 while(1) {
  $17 = HEAP32[$influence1$07>>2]|0;
  $18 = (($inputVertex$06) + ($9)|0);
  $19 = (($1) + ($17<<6)|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround(HEAPF32[$inputVertex$06>>2]);
  $22 = Math_fround($20 * $21);
  $23 = ((($1) + ($17<<6)|0) + 16|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($inputVertex$06) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($24 * $26);
  $28 = Math_fround($22 + $27);
  $29 = ((($1) + ($17<<6)|0) + 32|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($inputVertex$06) + 8|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($30 * $32);
  $34 = Math_fround($28 + $33);
  $35 = ((($1) + ($17<<6)|0) + 48|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($36 + $34);
  $38 = ((($1) + ($17<<6)|0) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($21 * $39);
  $41 = ((($1) + ($17<<6)|0) + 20|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($26 * $42);
  $44 = Math_fround($40 + $43);
  $45 = ((($1) + ($17<<6)|0) + 36|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($32 * $46);
  $48 = Math_fround($44 + $47);
  $49 = ((($1) + ($17<<6)|0) + 52|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($50 + $48);
  $52 = ((($1) + ($17<<6)|0) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($21 * $53);
  $55 = ((($1) + ($17<<6)|0) + 24|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($26 * $56);
  $58 = Math_fround($54 + $57);
  $59 = ((($1) + ($17<<6)|0) + 40|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($32 * $60);
  $62 = Math_fround($58 + $61);
  $63 = ((($1) + ($17<<6)|0) + 56|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($64 + $62);
  $66 = Math_fround(HEAPF32[$18>>2]);
  $67 = Math_fround($20 * $66);
  $68 = (($inputVertex$06) + ($$sum)|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($24 * $69);
  $71 = Math_fround($67 + $70);
  $72 = (($inputVertex$06) + ($$sum1)|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($30 * $73);
  $75 = Math_fround($71 + $74);
  $76 = Math_fround($39 * $66);
  $77 = Math_fround($42 * $69);
  $78 = Math_fround($76 + $77);
  $79 = Math_fround($46 * $73);
  $80 = Math_fround($78 + $79);
  $81 = Math_fround($53 * $66);
  $82 = Math_fround($56 * $69);
  $83 = Math_fround($81 + $82);
  $84 = Math_fround($60 * $73);
  $85 = Math_fround($83 + $84);
  HEAPF32[$outputVertex$05>>2] = $37;
  $86 = (($outputVertex$05) + 4|0);
  HEAPF32[$86>>2] = $51;
  $87 = (($outputVertex$05) + 8|0);
  HEAPF32[$87>>2] = $65;
  $88 = (($outputVertex$05) + ($9)|0);
  HEAPF32[$88>>2] = $75;
  $89 = (($outputVertex$05) + ($$sum)|0);
  HEAPF32[$89>>2] = $80;
  $90 = (($outputVertex$05) + ($$sum1)|0);
  HEAPF32[$90>>2] = $85;
  $91 = (($outputVertex$05) + ($5)|0);
  $92 = (($inputVertex$06) + ($3)|0);
  $93 = (($influence1$07) + 4|0);
  $94 = (($v$04) + 1)|0;
  $exitcond = ($94|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence1$07 = $93;$inputVertex$06 = $92;$outputVertex$05 = $91;$v$04 = $94;
  }
 }
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi2ELb1ELb0EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $influence2$07 = 0, $inputVertex$06 = 0, $outputVertex$05 = 0, $v$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)>(0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($info) + 4|0);
 $12 = (($info) + 16|0);
 $13 = (($info) + 12|0);
 $14 = HEAP32[$11>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = HEAP32[$13>>2]|0;
 $$sum = (($9) + 4)|0;
 $$sum1 = (($9) + 8)|0;
 $influence2$07 = $14;$inputVertex$06 = $16;$outputVertex$05 = $15;$v$04 = 0;
 while(1) {
  $17 = Math_fround(HEAPF32[$influence2$07>>2]);
  $18 = (($influence2$07) + 4|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($influence2$07) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($1) + ($21<<6)|0);
  $23 = (($influence2$07) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($1) + ($24<<6)|0);
  $26 = Math_fround(HEAPF32[$22>>2]);
  $27 = Math_fround($17 * $26);
  $28 = Math_fround(HEAPF32[$25>>2]);
  $29 = Math_fround($19 * $28);
  $30 = Math_fround($27 + $29);
  $31 = ((($1) + ($21<<6)|0) + 4|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($17 * $32);
  $34 = ((($1) + ($24<<6)|0) + 4|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($19 * $35);
  $37 = Math_fround($33 + $36);
  $38 = ((($1) + ($21<<6)|0) + 8|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($17 * $39);
  $41 = ((($1) + ($24<<6)|0) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($19 * $42);
  $44 = Math_fround($40 + $43);
  $45 = ((($1) + ($21<<6)|0) + 16|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($17 * $46);
  $48 = ((($1) + ($24<<6)|0) + 16|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = Math_fround($19 * $49);
  $51 = Math_fround($47 + $50);
  $52 = ((($1) + ($21<<6)|0) + 20|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($17 * $53);
  $55 = ((($1) + ($24<<6)|0) + 20|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($19 * $56);
  $58 = Math_fround($54 + $57);
  $59 = ((($1) + ($21<<6)|0) + 24|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($17 * $60);
  $62 = ((($1) + ($24<<6)|0) + 24|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($19 * $63);
  $65 = Math_fround($61 + $64);
  $66 = ((($1) + ($21<<6)|0) + 32|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($17 * $67);
  $69 = ((($1) + ($24<<6)|0) + 32|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($19 * $70);
  $72 = Math_fround($68 + $71);
  $73 = ((($1) + ($21<<6)|0) + 36|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($17 * $74);
  $76 = ((($1) + ($24<<6)|0) + 36|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = Math_fround($19 * $77);
  $79 = Math_fround($75 + $78);
  $80 = ((($1) + ($21<<6)|0) + 40|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround($17 * $81);
  $83 = ((($1) + ($24<<6)|0) + 40|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = Math_fround($19 * $84);
  $86 = Math_fround($82 + $85);
  $87 = ((($1) + ($21<<6)|0) + 48|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($17 * $88);
  $90 = ((($1) + ($24<<6)|0) + 48|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($19 * $91);
  $93 = Math_fround($89 + $92);
  $94 = ((($1) + ($21<<6)|0) + 52|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = Math_fround($17 * $95);
  $97 = ((($1) + ($24<<6)|0) + 52|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = Math_fround($19 * $98);
  $100 = Math_fround($96 + $99);
  $101 = ((($1) + ($21<<6)|0) + 56|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($17 * $102);
  $104 = ((($1) + ($24<<6)|0) + 56|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = Math_fround($19 * $105);
  $107 = Math_fround($103 + $106);
  $108 = (($inputVertex$06) + ($9)|0);
  $109 = Math_fround(HEAPF32[$inputVertex$06>>2]);
  $110 = Math_fround($30 * $109);
  $111 = (($inputVertex$06) + 4|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = Math_fround($51 * $112);
  $114 = Math_fround($110 + $113);
  $115 = (($inputVertex$06) + 8|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = Math_fround($72 * $116);
  $118 = Math_fround($114 + $117);
  $119 = Math_fround($93 + $118);
  $120 = Math_fround($37 * $109);
  $121 = Math_fround($58 * $112);
  $122 = Math_fround($120 + $121);
  $123 = Math_fround($79 * $116);
  $124 = Math_fround($122 + $123);
  $125 = Math_fround($100 + $124);
  $126 = Math_fround($44 * $109);
  $127 = Math_fround($65 * $112);
  $128 = Math_fround($126 + $127);
  $129 = Math_fround($86 * $116);
  $130 = Math_fround($128 + $129);
  $131 = Math_fround($107 + $130);
  $132 = Math_fround(HEAPF32[$108>>2]);
  $133 = Math_fround($30 * $132);
  $134 = (($inputVertex$06) + ($$sum)|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = Math_fround($51 * $135);
  $137 = Math_fround($133 + $136);
  $138 = (($inputVertex$06) + ($$sum1)|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($72 * $139);
  $141 = Math_fround($137 + $140);
  $142 = Math_fround($37 * $132);
  $143 = Math_fround($58 * $135);
  $144 = Math_fround($142 + $143);
  $145 = Math_fround($79 * $139);
  $146 = Math_fround($144 + $145);
  $147 = Math_fround($44 * $132);
  $148 = Math_fround($65 * $135);
  $149 = Math_fround($147 + $148);
  $150 = Math_fround($86 * $139);
  $151 = Math_fround($149 + $150);
  HEAPF32[$outputVertex$05>>2] = $119;
  $152 = (($outputVertex$05) + 4|0);
  HEAPF32[$152>>2] = $125;
  $153 = (($outputVertex$05) + 8|0);
  HEAPF32[$153>>2] = $131;
  $154 = (($outputVertex$05) + ($9)|0);
  HEAPF32[$154>>2] = $141;
  $155 = (($outputVertex$05) + ($$sum)|0);
  HEAPF32[$155>>2] = $146;
  $156 = (($outputVertex$05) + ($$sum1)|0);
  HEAPF32[$156>>2] = $151;
  $157 = (($outputVertex$05) + ($5)|0);
  $158 = (($inputVertex$06) + ($3)|0);
  $159 = (($influence2$07) + 16|0);
  $160 = (($v$04) + 1)|0;
  $exitcond = ($160|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence2$07 = $159;$inputVertex$06 = $158;$outputVertex$05 = $157;$v$04 = $160;
  }
 }
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi4ELb1ELb0EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0;
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0;
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond = 0, $influence4$07 = 0, $inputVertex$06 = 0, $outputVertex$05 = 0, $v$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)>(0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($info) + 4|0);
 $12 = (($info) + 16|0);
 $13 = (($info) + 12|0);
 $14 = HEAP32[$11>>2]|0;
 $15 = HEAP32[$12>>2]|0;
 $16 = HEAP32[$13>>2]|0;
 $$sum = (($9) + 4)|0;
 $$sum1 = (($9) + 8)|0;
 $influence4$07 = $14;$inputVertex$06 = $16;$outputVertex$05 = $15;$v$04 = 0;
 while(1) {
  $17 = Math_fround(HEAPF32[$influence4$07>>2]);
  $18 = (($influence4$07) + 4|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($influence4$07) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($influence4$07) + 12|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($influence4$07) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($1) + ($25<<6)|0);
  $27 = (($influence4$07) + 20|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($1) + ($28<<6)|0);
  $30 = (($influence4$07) + 24|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($1) + ($31<<6)|0);
  $33 = (($influence4$07) + 28|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($1) + ($34<<6)|0);
  $36 = Math_fround(HEAPF32[$26>>2]);
  $37 = Math_fround($17 * $36);
  $38 = Math_fround(HEAPF32[$29>>2]);
  $39 = Math_fround($19 * $38);
  $40 = Math_fround($37 + $39);
  $41 = Math_fround(HEAPF32[$32>>2]);
  $42 = Math_fround($21 * $41);
  $43 = Math_fround($40 + $42);
  $44 = Math_fround(HEAPF32[$35>>2]);
  $45 = Math_fround($23 * $44);
  $46 = Math_fround($43 + $45);
  $47 = ((($1) + ($25<<6)|0) + 4|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($17 * $48);
  $50 = ((($1) + ($28<<6)|0) + 4|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($19 * $51);
  $53 = Math_fround($49 + $52);
  $54 = ((($1) + ($31<<6)|0) + 4|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($21 * $55);
  $57 = Math_fround($53 + $56);
  $58 = ((($1) + ($34<<6)|0) + 4|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($23 * $59);
  $61 = Math_fround($57 + $60);
  $62 = ((($1) + ($25<<6)|0) + 8|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($17 * $63);
  $65 = ((($1) + ($28<<6)|0) + 8|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($19 * $66);
  $68 = Math_fround($64 + $67);
  $69 = ((($1) + ($31<<6)|0) + 8|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($21 * $70);
  $72 = Math_fround($68 + $71);
  $73 = ((($1) + ($34<<6)|0) + 8|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($23 * $74);
  $76 = Math_fround($72 + $75);
  $77 = ((($1) + ($25<<6)|0) + 16|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($17 * $78);
  $80 = ((($1) + ($28<<6)|0) + 16|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround($19 * $81);
  $83 = Math_fround($79 + $82);
  $84 = ((($1) + ($31<<6)|0) + 16|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($21 * $85);
  $87 = Math_fround($83 + $86);
  $88 = ((($1) + ($34<<6)|0) + 16|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = Math_fround($23 * $89);
  $91 = Math_fround($87 + $90);
  $92 = ((($1) + ($25<<6)|0) + 20|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = Math_fround($17 * $93);
  $95 = ((($1) + ($28<<6)|0) + 20|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = Math_fround($19 * $96);
  $98 = Math_fround($94 + $97);
  $99 = ((($1) + ($31<<6)|0) + 20|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($21 * $100);
  $102 = Math_fround($98 + $101);
  $103 = ((($1) + ($34<<6)|0) + 20|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = Math_fround($23 * $104);
  $106 = Math_fround($102 + $105);
  $107 = ((($1) + ($25<<6)|0) + 24|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($17 * $108);
  $110 = ((($1) + ($28<<6)|0) + 24|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = Math_fround($19 * $111);
  $113 = Math_fround($109 + $112);
  $114 = ((($1) + ($31<<6)|0) + 24|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($21 * $115);
  $117 = Math_fround($113 + $116);
  $118 = ((($1) + ($34<<6)|0) + 24|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround($23 * $119);
  $121 = Math_fround($117 + $120);
  $122 = ((($1) + ($25<<6)|0) + 32|0);
  $123 = Math_fround(HEAPF32[$122>>2]);
  $124 = Math_fround($17 * $123);
  $125 = ((($1) + ($28<<6)|0) + 32|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = Math_fround($19 * $126);
  $128 = Math_fround($124 + $127);
  $129 = ((($1) + ($31<<6)|0) + 32|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($21 * $130);
  $132 = Math_fround($128 + $131);
  $133 = ((($1) + ($34<<6)|0) + 32|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($23 * $134);
  $136 = Math_fround($132 + $135);
  $137 = ((($1) + ($25<<6)|0) + 36|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = Math_fround($17 * $138);
  $140 = ((($1) + ($28<<6)|0) + 36|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = Math_fround($19 * $141);
  $143 = Math_fround($139 + $142);
  $144 = ((($1) + ($31<<6)|0) + 36|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = Math_fround($21 * $145);
  $147 = Math_fround($143 + $146);
  $148 = ((($1) + ($34<<6)|0) + 36|0);
  $149 = Math_fround(HEAPF32[$148>>2]);
  $150 = Math_fround($23 * $149);
  $151 = Math_fround($147 + $150);
  $152 = ((($1) + ($25<<6)|0) + 40|0);
  $153 = Math_fround(HEAPF32[$152>>2]);
  $154 = Math_fround($17 * $153);
  $155 = ((($1) + ($28<<6)|0) + 40|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = Math_fround($19 * $156);
  $158 = Math_fround($154 + $157);
  $159 = ((($1) + ($31<<6)|0) + 40|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = Math_fround($21 * $160);
  $162 = Math_fround($158 + $161);
  $163 = ((($1) + ($34<<6)|0) + 40|0);
  $164 = Math_fround(HEAPF32[$163>>2]);
  $165 = Math_fround($23 * $164);
  $166 = Math_fround($162 + $165);
  $167 = ((($1) + ($25<<6)|0) + 48|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = Math_fround($17 * $168);
  $170 = ((($1) + ($28<<6)|0) + 48|0);
  $171 = Math_fround(HEAPF32[$170>>2]);
  $172 = Math_fround($19 * $171);
  $173 = Math_fround($169 + $172);
  $174 = ((($1) + ($31<<6)|0) + 48|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = Math_fround($21 * $175);
  $177 = Math_fround($173 + $176);
  $178 = ((($1) + ($34<<6)|0) + 48|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = Math_fround($23 * $179);
  $181 = Math_fround($177 + $180);
  $182 = ((($1) + ($25<<6)|0) + 52|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = Math_fround($17 * $183);
  $185 = ((($1) + ($28<<6)|0) + 52|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = Math_fround($19 * $186);
  $188 = Math_fround($184 + $187);
  $189 = ((($1) + ($31<<6)|0) + 52|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = Math_fround($21 * $190);
  $192 = Math_fround($188 + $191);
  $193 = ((($1) + ($34<<6)|0) + 52|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = Math_fround($23 * $194);
  $196 = Math_fround($192 + $195);
  $197 = ((($1) + ($25<<6)|0) + 56|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = Math_fround($17 * $198);
  $200 = ((($1) + ($28<<6)|0) + 56|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = Math_fround($19 * $201);
  $203 = Math_fround($199 + $202);
  $204 = ((($1) + ($31<<6)|0) + 56|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = Math_fround($21 * $205);
  $207 = Math_fround($203 + $206);
  $208 = ((($1) + ($34<<6)|0) + 56|0);
  $209 = Math_fround(HEAPF32[$208>>2]);
  $210 = Math_fround($23 * $209);
  $211 = Math_fround($207 + $210);
  $212 = (($inputVertex$06) + ($9)|0);
  $213 = Math_fround(HEAPF32[$inputVertex$06>>2]);
  $214 = Math_fround($46 * $213);
  $215 = (($inputVertex$06) + 4|0);
  $216 = Math_fround(HEAPF32[$215>>2]);
  $217 = Math_fround($91 * $216);
  $218 = Math_fround($214 + $217);
  $219 = (($inputVertex$06) + 8|0);
  $220 = Math_fround(HEAPF32[$219>>2]);
  $221 = Math_fround($136 * $220);
  $222 = Math_fround($218 + $221);
  $223 = Math_fround($181 + $222);
  $224 = Math_fround($61 * $213);
  $225 = Math_fround($106 * $216);
  $226 = Math_fround($224 + $225);
  $227 = Math_fround($151 * $220);
  $228 = Math_fround($226 + $227);
  $229 = Math_fround($196 + $228);
  $230 = Math_fround($76 * $213);
  $231 = Math_fround($121 * $216);
  $232 = Math_fround($230 + $231);
  $233 = Math_fround($166 * $220);
  $234 = Math_fround($232 + $233);
  $235 = Math_fround($211 + $234);
  $236 = Math_fround(HEAPF32[$212>>2]);
  $237 = Math_fround($46 * $236);
  $238 = (($inputVertex$06) + ($$sum)|0);
  $239 = Math_fround(HEAPF32[$238>>2]);
  $240 = Math_fround($91 * $239);
  $241 = Math_fround($237 + $240);
  $242 = (($inputVertex$06) + ($$sum1)|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = Math_fround($136 * $243);
  $245 = Math_fround($241 + $244);
  $246 = Math_fround($61 * $236);
  $247 = Math_fround($106 * $239);
  $248 = Math_fround($246 + $247);
  $249 = Math_fround($151 * $243);
  $250 = Math_fround($248 + $249);
  $251 = Math_fround($76 * $236);
  $252 = Math_fround($121 * $239);
  $253 = Math_fround($251 + $252);
  $254 = Math_fround($166 * $243);
  $255 = Math_fround($253 + $254);
  HEAPF32[$outputVertex$05>>2] = $223;
  $256 = (($outputVertex$05) + 4|0);
  HEAPF32[$256>>2] = $229;
  $257 = (($outputVertex$05) + 8|0);
  HEAPF32[$257>>2] = $235;
  $258 = (($outputVertex$05) + ($9)|0);
  HEAPF32[$258>>2] = $245;
  $259 = (($outputVertex$05) + ($$sum)|0);
  HEAPF32[$259>>2] = $250;
  $260 = (($outputVertex$05) + ($$sum1)|0);
  HEAPF32[$260>>2] = $255;
  $261 = (($outputVertex$05) + ($5)|0);
  $262 = (($inputVertex$06) + ($3)|0);
  $263 = (($influence4$07) + 32|0);
  $264 = (($v$04) + 1)|0;
  $exitcond = ($264|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence4$07 = $263;$inputVertex$06 = $262;$outputVertex$05 = $261;$v$04 = $264;
  }
 }
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi1ELb0ELb0EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $influence1$04 = 0, $inputVertex$03 = 0, $outputVertex$02 = 0, $v$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($info) + 4|0);
 $10 = (($info) + 16|0);
 $11 = (($info) + 12|0);
 $12 = HEAP32[$9>>2]|0;
 $13 = HEAP32[$10>>2]|0;
 $14 = HEAP32[$11>>2]|0;
 $influence1$04 = $12;$inputVertex$03 = $14;$outputVertex$02 = $13;$v$01 = 0;
 while(1) {
  $15 = HEAP32[$influence1$04>>2]|0;
  $16 = (($1) + ($15<<6)|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround(HEAPF32[$inputVertex$03>>2]);
  $19 = Math_fround($17 * $18);
  $20 = ((($1) + ($15<<6)|0) + 16|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($inputVertex$03) + 4|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($21 * $23);
  $25 = Math_fround($19 + $24);
  $26 = ((($1) + ($15<<6)|0) + 32|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($inputVertex$03) + 8|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($27 * $29);
  $31 = Math_fround($25 + $30);
  $32 = ((($1) + ($15<<6)|0) + 48|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($33 + $31);
  $35 = ((($1) + ($15<<6)|0) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($18 * $36);
  $38 = ((($1) + ($15<<6)|0) + 20|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($23 * $39);
  $41 = Math_fround($37 + $40);
  $42 = ((($1) + ($15<<6)|0) + 36|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($29 * $43);
  $45 = Math_fround($41 + $44);
  $46 = ((($1) + ($15<<6)|0) + 52|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($47 + $45);
  $49 = ((($1) + ($15<<6)|0) + 8|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($18 * $50);
  $52 = ((($1) + ($15<<6)|0) + 24|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($23 * $53);
  $55 = Math_fround($51 + $54);
  $56 = ((($1) + ($15<<6)|0) + 40|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($29 * $57);
  $59 = Math_fround($55 + $58);
  $60 = ((($1) + ($15<<6)|0) + 56|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($61 + $59);
  HEAPF32[$outputVertex$02>>2] = $34;
  $63 = (($outputVertex$02) + 4|0);
  HEAPF32[$63>>2] = $48;
  $64 = (($outputVertex$02) + 8|0);
  HEAPF32[$64>>2] = $62;
  $65 = (($outputVertex$02) + ($5)|0);
  $66 = (($inputVertex$03) + ($3)|0);
  $67 = (($influence1$04) + 4|0);
  $68 = (($v$01) + 1)|0;
  $exitcond = ($68|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence1$04 = $67;$inputVertex$03 = $66;$outputVertex$02 = $65;$v$01 = $68;
  }
 }
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi2ELb0ELb0EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0;
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond = 0, $influence2$04 = 0, $inputVertex$03 = 0, $outputVertex$02 = 0, $v$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($info) + 4|0);
 $10 = (($info) + 16|0);
 $11 = (($info) + 12|0);
 $12 = HEAP32[$9>>2]|0;
 $13 = HEAP32[$10>>2]|0;
 $14 = HEAP32[$11>>2]|0;
 $influence2$04 = $12;$inputVertex$03 = $14;$outputVertex$02 = $13;$v$01 = 0;
 while(1) {
  $15 = Math_fround(HEAPF32[$influence2$04>>2]);
  $16 = (($influence2$04) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($influence2$04) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($1) + ($19<<6)|0);
  $21 = (($influence2$04) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($1) + ($22<<6)|0);
  $24 = Math_fround(HEAPF32[$20>>2]);
  $25 = Math_fround($15 * $24);
  $26 = Math_fround(HEAPF32[$23>>2]);
  $27 = Math_fround($17 * $26);
  $28 = Math_fround($25 + $27);
  $29 = ((($1) + ($19<<6)|0) + 4|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($15 * $30);
  $32 = ((($1) + ($22<<6)|0) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($17 * $33);
  $35 = Math_fround($31 + $34);
  $36 = ((($1) + ($19<<6)|0) + 8|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($15 * $37);
  $39 = ((($1) + ($22<<6)|0) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($17 * $40);
  $42 = Math_fround($38 + $41);
  $43 = ((($1) + ($19<<6)|0) + 16|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($15 * $44);
  $46 = ((($1) + ($22<<6)|0) + 16|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround($17 * $47);
  $49 = Math_fround($45 + $48);
  $50 = ((($1) + ($19<<6)|0) + 20|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = Math_fround($15 * $51);
  $53 = ((($1) + ($22<<6)|0) + 20|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($17 * $54);
  $56 = Math_fround($52 + $55);
  $57 = ((($1) + ($19<<6)|0) + 24|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($15 * $58);
  $60 = ((($1) + ($22<<6)|0) + 24|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($17 * $61);
  $63 = Math_fround($59 + $62);
  $64 = ((($1) + ($19<<6)|0) + 32|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($15 * $65);
  $67 = ((($1) + ($22<<6)|0) + 32|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($17 * $68);
  $70 = Math_fround($66 + $69);
  $71 = ((($1) + ($19<<6)|0) + 36|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($15 * $72);
  $74 = ((($1) + ($22<<6)|0) + 36|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($17 * $75);
  $77 = Math_fround($73 + $76);
  $78 = ((($1) + ($19<<6)|0) + 40|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($15 * $79);
  $81 = ((($1) + ($22<<6)|0) + 40|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($17 * $82);
  $84 = Math_fround($80 + $83);
  $85 = ((($1) + ($19<<6)|0) + 48|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround($15 * $86);
  $88 = ((($1) + ($22<<6)|0) + 48|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = Math_fround($17 * $89);
  $91 = Math_fround($87 + $90);
  $92 = ((($1) + ($19<<6)|0) + 52|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = Math_fround($15 * $93);
  $95 = ((($1) + ($22<<6)|0) + 52|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = Math_fround($17 * $96);
  $98 = Math_fround($94 + $97);
  $99 = ((($1) + ($19<<6)|0) + 56|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($15 * $100);
  $102 = ((($1) + ($22<<6)|0) + 56|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = Math_fround($17 * $103);
  $105 = Math_fround($101 + $104);
  $106 = Math_fround(HEAPF32[$inputVertex$03>>2]);
  $107 = Math_fround($28 * $106);
  $108 = (($inputVertex$03) + 4|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = Math_fround($49 * $109);
  $111 = Math_fround($107 + $110);
  $112 = (($inputVertex$03) + 8|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($70 * $113);
  $115 = Math_fround($111 + $114);
  $116 = Math_fround($91 + $115);
  $117 = Math_fround($35 * $106);
  $118 = Math_fround($56 * $109);
  $119 = Math_fround($117 + $118);
  $120 = Math_fround($77 * $113);
  $121 = Math_fround($119 + $120);
  $122 = Math_fround($98 + $121);
  $123 = Math_fround($42 * $106);
  $124 = Math_fround($63 * $109);
  $125 = Math_fround($123 + $124);
  $126 = Math_fround($84 * $113);
  $127 = Math_fround($125 + $126);
  $128 = Math_fround($105 + $127);
  HEAPF32[$outputVertex$02>>2] = $116;
  $129 = (($outputVertex$02) + 4|0);
  HEAPF32[$129>>2] = $122;
  $130 = (($outputVertex$02) + 8|0);
  HEAPF32[$130>>2] = $128;
  $131 = (($outputVertex$02) + ($5)|0);
  $132 = (($inputVertex$03) + ($3)|0);
  $133 = (($influence2$04) + 16|0);
  $134 = (($v$01) + 1)|0;
  $exitcond = ($134|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence2$04 = $133;$inputVertex$03 = $132;$outputVertex$02 = $131;$v$01 = $134;
  }
 }
 STACKTOP = sp;return;
}
function __Z11SkinGenericILi4ELb0ELb0EEvR12SkinMeshInfo($info) {
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0;
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0;
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0;
 var $influence4$04 = 0, $inputVertex$03 = 0, $outputVertex$02 = 0, $v$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($info) + 4|0);
 $10 = (($info) + 16|0);
 $11 = (($info) + 12|0);
 $12 = HEAP32[$9>>2]|0;
 $13 = HEAP32[$10>>2]|0;
 $14 = HEAP32[$11>>2]|0;
 $influence4$04 = $12;$inputVertex$03 = $14;$outputVertex$02 = $13;$v$01 = 0;
 while(1) {
  $15 = Math_fround(HEAPF32[$influence4$04>>2]);
  $16 = (($influence4$04) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($influence4$04) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($influence4$04) + 12|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($influence4$04) + 16|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($1) + ($23<<6)|0);
  $25 = (($influence4$04) + 20|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($1) + ($26<<6)|0);
  $28 = (($influence4$04) + 24|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($1) + ($29<<6)|0);
  $31 = (($influence4$04) + 28|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($1) + ($32<<6)|0);
  $34 = Math_fround(HEAPF32[$24>>2]);
  $35 = Math_fround($15 * $34);
  $36 = Math_fround(HEAPF32[$27>>2]);
  $37 = Math_fround($17 * $36);
  $38 = Math_fround($35 + $37);
  $39 = Math_fround(HEAPF32[$30>>2]);
  $40 = Math_fround($19 * $39);
  $41 = Math_fround($38 + $40);
  $42 = Math_fround(HEAPF32[$33>>2]);
  $43 = Math_fround($21 * $42);
  $44 = Math_fround($41 + $43);
  $45 = ((($1) + ($23<<6)|0) + 4|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($15 * $46);
  $48 = ((($1) + ($26<<6)|0) + 4|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = Math_fround($17 * $49);
  $51 = Math_fround($47 + $50);
  $52 = ((($1) + ($29<<6)|0) + 4|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($19 * $53);
  $55 = Math_fround($51 + $54);
  $56 = ((($1) + ($32<<6)|0) + 4|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($21 * $57);
  $59 = Math_fround($55 + $58);
  $60 = ((($1) + ($23<<6)|0) + 8|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($15 * $61);
  $63 = ((($1) + ($26<<6)|0) + 8|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($17 * $64);
  $66 = Math_fround($62 + $65);
  $67 = ((($1) + ($29<<6)|0) + 8|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($19 * $68);
  $70 = Math_fround($66 + $69);
  $71 = ((($1) + ($32<<6)|0) + 8|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($21 * $72);
  $74 = Math_fround($70 + $73);
  $75 = ((($1) + ($23<<6)|0) + 16|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($15 * $76);
  $78 = ((($1) + ($26<<6)|0) + 16|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($17 * $79);
  $81 = Math_fround($77 + $80);
  $82 = ((($1) + ($29<<6)|0) + 16|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($19 * $83);
  $85 = Math_fround($81 + $84);
  $86 = ((($1) + ($32<<6)|0) + 16|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = Math_fround($21 * $87);
  $89 = Math_fround($85 + $88);
  $90 = ((($1) + ($23<<6)|0) + 20|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($15 * $91);
  $93 = ((($1) + ($26<<6)|0) + 20|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = Math_fround($17 * $94);
  $96 = Math_fround($92 + $95);
  $97 = ((($1) + ($29<<6)|0) + 20|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = Math_fround($19 * $98);
  $100 = Math_fround($96 + $99);
  $101 = ((($1) + ($32<<6)|0) + 20|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($21 * $102);
  $104 = Math_fround($100 + $103);
  $105 = ((($1) + ($23<<6)|0) + 24|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = Math_fround($15 * $106);
  $108 = ((($1) + ($26<<6)|0) + 24|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = Math_fround($17 * $109);
  $111 = Math_fround($107 + $110);
  $112 = ((($1) + ($29<<6)|0) + 24|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($19 * $113);
  $115 = Math_fround($111 + $114);
  $116 = ((($1) + ($32<<6)|0) + 24|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = Math_fround($21 * $117);
  $119 = Math_fround($115 + $118);
  $120 = ((($1) + ($23<<6)|0) + 32|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = Math_fround($15 * $121);
  $123 = ((($1) + ($26<<6)|0) + 32|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = Math_fround($17 * $124);
  $126 = Math_fround($122 + $125);
  $127 = ((($1) + ($29<<6)|0) + 32|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = Math_fround($19 * $128);
  $130 = Math_fround($126 + $129);
  $131 = ((($1) + ($32<<6)|0) + 32|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = Math_fround($21 * $132);
  $134 = Math_fround($130 + $133);
  $135 = ((($1) + ($23<<6)|0) + 36|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = Math_fround($15 * $136);
  $138 = ((($1) + ($26<<6)|0) + 36|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($17 * $139);
  $141 = Math_fround($137 + $140);
  $142 = ((($1) + ($29<<6)|0) + 36|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = Math_fround($19 * $143);
  $145 = Math_fround($141 + $144);
  $146 = ((($1) + ($32<<6)|0) + 36|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  $148 = Math_fround($21 * $147);
  $149 = Math_fround($145 + $148);
  $150 = ((($1) + ($23<<6)|0) + 40|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = Math_fround($15 * $151);
  $153 = ((($1) + ($26<<6)|0) + 40|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = Math_fround($17 * $154);
  $156 = Math_fround($152 + $155);
  $157 = ((($1) + ($29<<6)|0) + 40|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = Math_fround($19 * $158);
  $160 = Math_fround($156 + $159);
  $161 = ((($1) + ($32<<6)|0) + 40|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($21 * $162);
  $164 = Math_fround($160 + $163);
  $165 = ((($1) + ($23<<6)|0) + 48|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = Math_fround($15 * $166);
  $168 = ((($1) + ($26<<6)|0) + 48|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = Math_fround($17 * $169);
  $171 = Math_fround($167 + $170);
  $172 = ((($1) + ($29<<6)|0) + 48|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($19 * $173);
  $175 = Math_fround($171 + $174);
  $176 = ((($1) + ($32<<6)|0) + 48|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround($21 * $177);
  $179 = Math_fround($175 + $178);
  $180 = ((($1) + ($23<<6)|0) + 52|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = Math_fround($15 * $181);
  $183 = ((($1) + ($26<<6)|0) + 52|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = Math_fround($17 * $184);
  $186 = Math_fround($182 + $185);
  $187 = ((($1) + ($29<<6)|0) + 52|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = Math_fround($19 * $188);
  $190 = Math_fround($186 + $189);
  $191 = ((($1) + ($32<<6)|0) + 52|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = Math_fround($21 * $192);
  $194 = Math_fround($190 + $193);
  $195 = ((($1) + ($23<<6)|0) + 56|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = Math_fround($15 * $196);
  $198 = ((($1) + ($26<<6)|0) + 56|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = Math_fround($17 * $199);
  $201 = Math_fround($197 + $200);
  $202 = ((($1) + ($29<<6)|0) + 56|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = Math_fround($19 * $203);
  $205 = Math_fround($201 + $204);
  $206 = ((($1) + ($32<<6)|0) + 56|0);
  $207 = Math_fround(HEAPF32[$206>>2]);
  $208 = Math_fround($21 * $207);
  $209 = Math_fround($205 + $208);
  $210 = Math_fround(HEAPF32[$inputVertex$03>>2]);
  $211 = Math_fround($44 * $210);
  $212 = (($inputVertex$03) + 4|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = Math_fround($89 * $213);
  $215 = Math_fround($211 + $214);
  $216 = (($inputVertex$03) + 8|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = Math_fround($134 * $217);
  $219 = Math_fround($215 + $218);
  $220 = Math_fround($179 + $219);
  $221 = Math_fround($59 * $210);
  $222 = Math_fround($104 * $213);
  $223 = Math_fround($221 + $222);
  $224 = Math_fround($149 * $217);
  $225 = Math_fround($223 + $224);
  $226 = Math_fround($194 + $225);
  $227 = Math_fround($74 * $210);
  $228 = Math_fround($119 * $213);
  $229 = Math_fround($227 + $228);
  $230 = Math_fround($164 * $217);
  $231 = Math_fround($229 + $230);
  $232 = Math_fround($209 + $231);
  HEAPF32[$outputVertex$02>>2] = $220;
  $233 = (($outputVertex$02) + 4|0);
  HEAPF32[$233>>2] = $226;
  $234 = (($outputVertex$02) + 8|0);
  HEAPF32[$234>>2] = $232;
  $235 = (($outputVertex$02) + ($5)|0);
  $236 = (($inputVertex$03) + ($3)|0);
  $237 = (($influence4$04) + 32|0);
  $238 = (($v$01) + 1)|0;
  $exitcond = ($238|0)==($7|0);
  if ($exitcond) {
   break;
  } else {
   $influence4$04 = $237;$inputVertex$03 = $236;$outputVertex$02 = $235;$v$01 = $238;
  }
 }
 STACKTOP = sp;return;
}
function __Z17DeformSkinnedMeshR12SkinMeshInfo($info) {
 $info = $info|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $tmpBlendShapes$03 = 0, $tmpBlendShapes$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = (($info) + 64|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  __Z21CompleteFenceInternalR8JobFence($6);
 }
 $9 = (($info) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($info) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)!=(0);
 $14 = $12 | $10;
 $15 = ($14|0)==(0);
 if ($15) {
  $16 = (($info) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($info) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($info) + 20|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($info) + 40|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = Math_imul($23, $21)|0;
  _memcpy(($17|0),($19|0),($24|0))|0;
  $25 = (($info) + 48|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   $28 = HEAP32[$18>>2]|0;
   $29 = HEAP32[$20>>2]|0;
   $30 = HEAP32[$16>>2]|0;
   $31 = (($info) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$22>>2]|0;
   __Z18TransformPoints3x3RK10Matrix4x4fPK8Vector3fjPS2_ji($26,$28,$29,$30,$32,$33);
  }
  $34 = HEAP32[$6>>2]|0;
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   __Z21CompleteFenceInternalR8JobFence($6);
  }
  $36 = (($info) + 44|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   $39 = HEAP32[628432>>2]|0;
   HEAP32[$3>>2] = $39;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy5);
  }
  $40 = (($info) + 88|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $43 = HEAP32[628248>>2]|0;
  $44 = (($41) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + -1)|0;
  HEAP32[$44>>2] = $46;
  $47 = HEAP32[$44>>2]|0;
  $48 = ($47|0)==(0);
  if (!($48)) {
   STACKTOP = sp;return;
  }
  $49 = HEAP32[$41>>2]|0;
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_vi[$50 & 4095]($41);
  HEAP32[$2>>2] = $43;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($41,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $51 = ($10|0)==(0);
 do {
  if ($51) {
   if ($13) {
    $tmpBlendShapes$04 = 0;
    label = 18;
   }
  } else {
   $52 = (($info) + 20|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($info) + 40|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = Math_imul($55, $53)|0;
   $57 = HEAP32[628512>>2]|0;
   HEAP32[$4>>2] = $57;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
   $58 = (__Z15malloc_internaljj10MemLabelIdiPKci($56,16,$$byval_copy5,0,588080,100)|0);
   __Z16ApplyBlendShapesR12SkinMeshInfoPh($info,$58);
   if ($13) {
    $59 = (($info) + 12|0);
    HEAP32[$59>>2] = $58;
    $tmpBlendShapes$04 = $58;
    label = 18;
    break;
   } else {
    $60 = (($info) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    _memcpy(($61|0),($58|0),($56|0))|0;
    $tmpBlendShapes$03 = $58;
    label = 19;
    break;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  __Z8SkinMeshR12SkinMeshInfo($info);
  $tmpBlendShapes$03 = $tmpBlendShapes$04;
  label = 19;
 }
 if ((label|0) == 19) {
  $62 = ($tmpBlendShapes$03|0)==(0|0);
  if (!($62)) {
   $63 = HEAP32[628512>>2]|0;
   HEAP32[$5>>2] = $63;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($tmpBlendShapes$03,$$byval_copy5);
  }
 }
 $64 = HEAP32[$6>>2]|0;
 $65 = ($64|0)==(0|0);
 if (!($65)) {
  __Z21CompleteFenceInternalR8JobFence($6);
 }
 $66 = (($info) + 44|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0|0);
 if (!($68)) {
  $69 = HEAP32[628432>>2]|0;
  HEAP32[$1>>2] = $69;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($67,$$byval_copy5);
 }
 $70 = (($info) + 88|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  STACKTOP = sp;return;
 }
 $73 = HEAP32[628248>>2]|0;
 $74 = (($71) + 4|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($75) + -1)|0;
 HEAP32[$74>>2] = $76;
 $77 = HEAP32[$74>>2]|0;
 $78 = ($77|0)==(0);
 if (!($78)) {
  STACKTOP = sp;return;
 }
 $79 = HEAP32[$71>>2]|0;
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vi[$80 & 4095]($71);
 HEAP32[$0>>2] = $73;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($71,$$byval_copy5);
 STACKTOP = sp;return;
}
function __ZN12SkinMeshInfo7ReleaseEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __Z21CompleteFenceInternalR8JobFence($2);
 }
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[628432>>2]|0;
  HEAP32[$1>>2] = $8;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy1);
 }
 $9 = (($this) + 88|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[628248>>2]|0;
 $13 = (($10) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + -1)|0;
 HEAP32[$13>>2] = $15;
 $16 = HEAP32[$13>>2]|0;
 $17 = ($16|0)==(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$10>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 4095]($10);
 HEAP32[$0>>2] = $12;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($10,$$byval_copy1);
 STACKTOP = sp;return;
}
function __Z20DeformSkinnedMeshJobPv($rawData) {
 $rawData = $rawData|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DeformSkinnedMeshR12SkinMeshInfo($rawData);
 STACKTOP = sp;return;
}
function __ZN12SkinMeshInfo8AllocateEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $head$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 6;
 $5 = (($this) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 << 2;
 $8 = (($7) + ($4))|0;
 $9 = ($8|0)==(0);
 $10 = HEAP32[628432>>2]|0;
 if ($9) {
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $11 = (__Z15malloc_internaljj10MemLabelIdiPKci(64,64,$$byval_copy1,0,588080,142)|0);
  $12 = (($this) + 44|0);
  HEAP32[$12>>2] = $11;
  $13 = (($this) + 48|0);
  HEAP32[$13>>2] = $11;
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $10;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $14 = (__Z15malloc_internaljj10MemLabelIdiPKci($8,64,$$byval_copy1,0,588080,147)|0);
 $15 = (($this) + 44|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$2>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  $head$0 = $14;
 } else {
  $18 = (($this) + 48|0);
  HEAP32[$18>>2] = $14;
  $19 = $16 << 6;
  $20 = (($14) + ($19)|0);
  $head$0 = $20;
 }
 $21 = HEAP32[$5>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (($this) + 52|0);
 HEAP32[$23>>2] = $head$0;
 STACKTOP = sp;return;
}
function __Z33CopySkinMeshInfoAndFenceOwnershipR12SkinMeshInfoS0_($src,$dst) {
 $src = $src|0;
 $dst = $dst|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($dst) + 64|0);
 __Z21ClearFenceWithoutSyncR8JobFence($0);
 $1 = (($dst) + 72|0);
 __Z21ClearFenceWithoutSyncR8JobFence($1);
 dest=$dst+0|0; src=$src+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($src) + 64|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($src) + 72|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $1;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = (($dst) + 80|0);
 $25 = (($src) + 80|0);
 dest=$24+0|0; src=$25+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 __Z21ClearFenceWithoutSyncR8JobFence($2);
 __Z21ClearFenceWithoutSyncR8JobFence($13);
 STACKTOP = sp;return;
}
function __ZN16MeshVertexFormatC2EjRK18VertexChannelsInfob($this,$uniqueID,$sourceChannels,$renderThread) {
 $this = $this|0;
 $uniqueID = $uniqueID|0;
 $sourceChannels = $sourceChannels|0;
 $renderThread = $renderThread|0;
 var $$channelMask$0$1$i = 0, $$channelMask$0$2$i = 0, $$channelMask$0$3$i = 0, $$channelMask$0$4$i = 0, $$channelMask$0$5$i = 0, $$channelMask$0$6$i = 0, $$channelMask$0$7$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $uniqueID;
 $0 = (($this) + 8|0);
 ;HEAP32[$0+0>>2]=HEAP32[$sourceChannels+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$sourceChannels+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$sourceChannels+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$sourceChannels+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$sourceChannels+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$sourceChannels+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$sourceChannels+24>>2]|0;HEAP32[$0+28>>2]=HEAP32[$sourceChannels+28>>2]|0;
 $1 = (($this) + 44|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 48|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 52|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 56|0);
 $5 = $renderThread&1;
 HEAP8[$4>>0] = $5;
 $6 = (($sourceChannels) + 3|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = $8&1;
 $10 = (($sourceChannels) + 7|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)!=(0);
 $13 = $12 ? 2 : 0;
 $$channelMask$0$1$i = $13 | $9;
 $14 = (($sourceChannels) + 11|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)!=(0);
 $17 = $16 ? 4 : 0;
 $$channelMask$0$2$i = $$channelMask$0$1$i | $17;
 $18 = (($sourceChannels) + 15|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)!=(0);
 $21 = $20 ? 8 : 0;
 $$channelMask$0$3$i = $$channelMask$0$2$i | $21;
 $22 = (($sourceChannels) + 19|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)!=(0);
 $25 = $24 ? 16 : 0;
 $$channelMask$0$4$i = $$channelMask$0$3$i | $25;
 $26 = (($sourceChannels) + 23|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)!=(0);
 $29 = $28 ? 32 : 0;
 $$channelMask$0$5$i = $$channelMask$0$4$i | $29;
 $30 = (($sourceChannels) + 27|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)!=(0);
 $33 = $32 ? 64 : 0;
 $$channelMask$0$6$i = $$channelMask$0$5$i | $33;
 $34 = (($sourceChannels) + 31|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = ($35<<24>>24)!=(0);
 $37 = $36 ? 128 : 0;
 $$channelMask$0$7$i = $$channelMask$0$6$i | $37;
 $38 = (($this) + 4|0);
 HEAP32[$38>>2] = $$channelMask$0$7$i;
 STACKTOP = sp;return;
}
function __ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($this,$shaderChannels,$secondaryStreams) {
 $this = $this|0;
 $shaderChannels = $shaderChannels|0;
 $secondaryStreams = $secondaryStreams|0;
 var $$ = 0, $$0$lcssa$i = 0, $$02$i = 0, $$byval_copy = 0, $$neg2$i$i$i$i$i = 0, $$neg2$i$i$i$i$i4 = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i5 = 0, $__len$03$i$i$i$i$i = 0, $__len$03$i$i$i$i$i2 = 0;
 var $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 16|0;
 $2 = sp;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 | -131;
 $6 = $5 & $shaderChannels;
 $$02$i = $6;$i$01$i = 0;
 while(1) {
  $7 = (($i$01$i) + 3)|0;
  $8 = 1 << $7;
  $9 = $8 & $4;
  $10 = ($9|0)==(0);
  if (!($10)) {
   $$0$lcssa$i = $$02$i;
   break;
  }
  $11 = $8 ^ -1;
  $12 = $$02$i & $11;
  $13 = (($i$01$i) + 1)|0;
  $14 = ($13|0)<(4);
  if ($14) {
   $$02$i = $12;$i$01$i = $13;
  } else {
   $$0$lcssa$i = $12;
   break;
  }
 }
 $15 = ($secondaryStreams|0)==(0|0);
 if ($15) {
  $36 = 0;$39 = $$0$lcssa$i;
 } else {
  $16 = HEAP32[$secondaryStreams>>2]|0;
  $36 = $16;$39 = $$0$lcssa$i;
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 $22 = $18;
 $23 = (($21) - ($22))|0;
 $24 = $23 >> 4;
 $25 = ($24|0)==(0);
 if ($25) {
  $46 = $18;
 } else {
  $28 = $18;$__len$03$i$i$i$i$i2 = $24;
  while(1) {
   $26 = (($__len$03$i$i$i$i$i2|0) / 2)&-1;
   $27 = (($28) + ($26<<4)|0);
   $29 = $27;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34>>>0)<($36>>>0);
   $37 = ($34|0)==($36|0);
   $38 = ($31>>>0)<($39>>>0);
   $40 = $37 & $38;
   $41 = $35 | $40;
   if ($41) {
    $$sum$i$i$i$i$i3 = (($26) + 1)|0;
    $42 = (($28) + ($$sum$i$i$i$i$i3<<4)|0);
    $$neg2$i$i$i$i$i4 = (($__len$03$i$i$i$i$i2) + -1)|0;
    $43 = (($$neg2$i$i$i$i$i4) - ($26))|0;
    $106 = $42;$__len$0$be$i$i$i$i$i5 = $43;
   } else {
    $106 = $28;$__len$0$be$i$i$i$i$i5 = $26;
   }
   $44 = ($__len$0$be$i$i$i$i$i5|0)==(0);
   if ($44) {
    $46 = $106;
    break;
   } else {
    $28 = $106;$__len$03$i$i$i$i$i2 = $__len$0$be$i$i$i$i$i5;
   }
  }
 }
 $45 = ($46|0)==($20|0);
 if (!($45)) {
  $47 = $46;
  $48 = $47;
  $49 = HEAP32[$48>>2]|0;
  $50 = (($47) + 4)|0;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = ($36>>>0)<($52>>>0);
  $54 = ($36|0)==($52|0);
  $55 = ($39>>>0)<($49>>>0);
  $56 = $54 & $55;
  $57 = $53 | $56;
  $$ = $57 ? $20 : $46;
  $58 = ($$|0)==($20|0);
  if (!($58)) {
   $59 = (($$) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   $105 = $60;
   STACKTOP = sp;return ($105|0);
  }
 }
 $61 = (__ZN16MeshVertexFormat23CreateVertexDeclarationEjPKS_($this,$$0$lcssa$i,$secondaryStreams)|0);
 $62 = $2;
 $63 = $62;
 HEAP32[$63>>2] = $39;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = $36;
 $66 = (($2) + 8|0);
 HEAP32[$66>>2] = $61;
 $67 = HEAP32[$17>>2]|0;
 $68 = HEAP32[$19>>2]|0;
 $69 = $68;
 $70 = $67;
 $71 = (($69) - ($70))|0;
 $72 = $71 >> 4;
 $73 = ($72|0)==(0);
 if ($73) {
  $92 = $67;
 } else {
  $76 = $67;$__len$03$i$i$i$i$i = $72;
  while(1) {
   $74 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $75 = (($76) + ($74<<4)|0);
   $77 = $75;
   $78 = $77;
   $79 = HEAP32[$78>>2]|0;
   $80 = (($77) + 4)|0;
   $81 = $80;
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82>>>0)<($36>>>0);
   $84 = ($82|0)==($36|0);
   $85 = ($79>>>0)<($39>>>0);
   $86 = $84 & $85;
   $87 = $83 | $86;
   if ($87) {
    $$sum$i$i$i$i$i = (($74) + 1)|0;
    $88 = (($76) + ($$sum$i$i$i$i$i<<4)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $89 = (($$neg2$i$i$i$i$i) - ($74))|0;
    $107 = $88;$__len$0$be$i$i$i$i$i = $89;
   } else {
    $107 = $76;$__len$0$be$i$i$i$i$i = $74;
   }
   $90 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($90) {
    $92 = $107;
    break;
   } else {
    $76 = $107;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $91 = ($92|0)==($68|0);
 if (!($91)) {
  $93 = $92;
  $94 = $93;
  $95 = HEAP32[$94>>2]|0;
  $96 = (($93) + 4)|0;
  $97 = $96;
  $98 = HEAP32[$97>>2]|0;
  $99 = ($36>>>0)<($98>>>0);
  $100 = ($36|0)==($98|0);
  $101 = ($39>>>0)<($95>>>0);
  $102 = $100 & $101;
  $103 = $99 | $102;
  if (!($103)) {
   $105 = $61;
   STACKTOP = sp;return ($105|0);
  }
 }
 $104 = (($this) + 44|0);
 HEAP32[$1>>2] = $92;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__16vectorINS_4pairIyP17VertexDeclarationEENS_9allocatorIS4_EEE6insertENS_11__wrap_iterIPKS4_EERS9_($0,$104,$$byval_copy,$2);
 $105 = $61;
 STACKTOP = sp;return ($105|0);
}
function __ZN16MeshVertexFormat23CreateVertexDeclarationEjPKS_($this,$shaderChannels,$secondaryStreams) {
 $this = $this|0;
 $shaderChannels = $shaderChannels|0;
 $secondaryStreams = $secondaryStreams|0;
 var $$in = 0, $$in10 = 0, $$in10$in = 0, $$lcssa$i = 0, $$lcssa$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $channelsInfo = 0, $firstFreeStream$0 = 0, $firstFreeStream$0$in = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i4 = 0, $or$cond$us = 0, $or$cond7 = 0, $or$cond7$us = 0, $secondaryChannels = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $secondaryChannels = sp + 32|0;
 $channelsInfo = sp;
 $0 = ($secondaryStreams|0)!=(0|0);
 ;HEAP32[$secondaryChannels+0>>2]=0|0;HEAP32[$secondaryChannels+4>>2]=0|0;HEAP32[$secondaryChannels+8>>2]=0|0;HEAP32[$secondaryChannels+12>>2]=0|0;HEAP32[$secondaryChannels+16>>2]=0|0;HEAP32[$secondaryChannels+20>>2]=0|0;HEAP32[$secondaryChannels+24>>2]=0|0;HEAP32[$secondaryChannels+28>>2]=0|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$lcssa$i = 0;
 } else {
  $11 = 0;$15 = 1;$5 = 0;
  while(1) {
   $4 = ((($this) + ($5<<2)|0) + 11|0);
   $6 = HEAP8[$4>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $179 = $11;
   } else {
    $8 = ((($this) + ($5<<2)|0) + 8|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($11&255)<($9&255);
    $12 = $10 ? $9 : $11;
    $179 = $12;
   }
   $13 = (($5) + 1)|0;
   $14 = $15 << 1;
   $16 = ($13|0)<(8);
   $17 = ($14>>>0)<=($2>>>0);
   $or$cond$i = $16 & $17;
   if ($or$cond$i) {
    $11 = $179;$15 = $14;$5 = $13;
   } else {
    $$lcssa$i = $179;
    break;
   }
  }
 }
 $18 = $$lcssa$i&255;
 $19 = (($18) + 1)|0;
 if ($0) {
  $20 = (($secondaryStreams) + 8|0);
  ;HEAP32[$secondaryChannels+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$secondaryChannels+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$secondaryChannels+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$secondaryChannels+12>>2]=HEAP32[$20+12>>2]|0;HEAP32[$secondaryChannels+16>>2]=HEAP32[$20+16>>2]|0;HEAP32[$secondaryChannels+20>>2]=HEAP32[$20+20>>2]|0;HEAP32[$secondaryChannels+24>>2]=HEAP32[$20+24>>2]|0;HEAP32[$secondaryChannels+28>>2]=HEAP32[$20+28>>2]|0;
  $21 = (($secondaryChannels) + 3|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)==(0);
  if (!($23)) {
   $24 = HEAP8[$secondaryChannels>>0]|0;
   $25 = $24&255;
   $26 = (($25) + ($19))|0;
   $27 = $26&255;
   HEAP8[$secondaryChannels>>0] = $27;
  }
  $28 = (($secondaryChannels) + 7|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = ($29<<24>>24)==(0);
  if (!($30)) {
   $124 = (($secondaryChannels) + 4|0);
   $125 = HEAP8[$124>>0]|0;
   $126 = $125&255;
   $127 = (($126) + ($19))|0;
   $128 = $127&255;
   HEAP8[$124>>0] = $128;
  }
  $129 = (($secondaryChannels) + 11|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = ($130<<24>>24)==(0);
  if (!($131)) {
   $132 = (($secondaryChannels) + 8|0);
   $133 = HEAP8[$132>>0]|0;
   $134 = $133&255;
   $135 = (($134) + ($19))|0;
   $136 = $135&255;
   HEAP8[$132>>0] = $136;
  }
  $137 = (($secondaryChannels) + 15|0);
  $138 = HEAP8[$137>>0]|0;
  $139 = ($138<<24>>24)==(0);
  if (!($139)) {
   $140 = (($secondaryChannels) + 12|0);
   $141 = HEAP8[$140>>0]|0;
   $142 = $141&255;
   $143 = (($142) + ($19))|0;
   $144 = $143&255;
   HEAP8[$140>>0] = $144;
  }
  $145 = (($secondaryChannels) + 19|0);
  $146 = HEAP8[$145>>0]|0;
  $147 = ($146<<24>>24)==(0);
  if (!($147)) {
   $148 = (($secondaryChannels) + 16|0);
   $149 = HEAP8[$148>>0]|0;
   $150 = $149&255;
   $151 = (($150) + ($19))|0;
   $152 = $151&255;
   HEAP8[$148>>0] = $152;
  }
  $153 = (($secondaryChannels) + 23|0);
  $154 = HEAP8[$153>>0]|0;
  $155 = ($154<<24>>24)==(0);
  if (!($155)) {
   $156 = (($secondaryChannels) + 20|0);
   $157 = HEAP8[$156>>0]|0;
   $158 = $157&255;
   $159 = (($158) + ($19))|0;
   $160 = $159&255;
   HEAP8[$156>>0] = $160;
  }
  $161 = (($secondaryChannels) + 27|0);
  $162 = HEAP8[$161>>0]|0;
  $163 = ($162<<24>>24)==(0);
  if (!($163)) {
   $164 = (($secondaryChannels) + 24|0);
   $165 = HEAP8[$164>>0]|0;
   $166 = $165&255;
   $167 = (($166) + ($19))|0;
   $168 = $167&255;
   HEAP8[$164>>0] = $168;
  }
  $169 = (($secondaryChannels) + 31|0);
  $170 = HEAP8[$169>>0]|0;
  $171 = ($170<<24>>24)==(0);
  if (!($171)) {
   $172 = (($secondaryChannels) + 28|0);
   $173 = HEAP8[$172>>0]|0;
   $174 = $173&255;
   $175 = (($174) + ($19))|0;
   $176 = $175&255;
   HEAP8[$172>>0] = $176;
  }
  $177 = (($secondaryStreams) + 4|0);
  $45 = HEAP32[$177>>2]|0;
  $178 = ($45|0)==(0);
  if ($178) {
   $$lcssa$i5 = 0;
  } else {
   $32 = 0;$38 = 0;$42 = 1;
   while(1) {
    $31 = ((($secondaryStreams) + ($32<<2)|0) + 11|0);
    $33 = HEAP8[$31>>0]|0;
    $34 = ($33<<24>>24)==(0);
    if ($34) {
     $180 = $38;
    } else {
     $35 = ((($secondaryStreams) + ($32<<2)|0) + 8|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = ($38&255)<($36&255);
     $39 = $37 ? $36 : $38;
     $180 = $39;
    }
    $40 = (($32) + 1)|0;
    $41 = $42 << 1;
    $43 = ($40|0)<(8);
    $44 = ($41>>>0)<=($45>>>0);
    $or$cond$i4 = $43 & $44;
    if ($or$cond$i4) {
     $32 = $40;$38 = $180;$42 = $41;
    } else {
     $$lcssa$i5 = $180;
     break;
    }
   }
  }
  $46 = $$lcssa$i5&255;
  $47 = (($18) + 2)|0;
  $48 = (($47) + ($46))|0;
  $firstFreeStream$0$in = $48;
 } else {
  $firstFreeStream$0$in = $19;
 }
 $firstFreeStream$0 = $firstFreeStream$0$in&255;
 ;HEAP32[$channelsInfo+0>>2]=0|0;HEAP32[$channelsInfo+4>>2]=0|0;HEAP32[$channelsInfo+8>>2]=0|0;HEAP32[$channelsInfo+12>>2]=0|0;HEAP32[$channelsInfo+16>>2]=0|0;HEAP32[$channelsInfo+20>>2]=0|0;HEAP32[$channelsInfo+24>>2]=0|0;HEAP32[$channelsInfo+28>>2]=0|0;
 $49 = ($shaderChannels|0)==(0);
 L42: do {
  if (!($49)) {
   if ($0) {
    $181 = 0;$51 = 1;$54 = 0;
   } else {
    $182 = 0;$80 = 1;$83 = 0;
    while(1) {
     $79 = $80 & 120;
     $81 = ($79|0)!=(0);
     $82 = ((($this) + ($83<<2)|0) + 8|0);
     $84 = HEAP32[$82>>2]|0;
     $85 = $84 >>> 24;
     $86 = $85&255;
     $87 = ($86<<24>>24)!=(0);
     $or$cond7 = $81 & $87;
     if ($or$cond7) {
      $88 = $85 << 24;
      $89 = $84 & 16777215;
      $90 = $88 | $89;
      $99 = $90;
     } else {
      $99 = $182;
     }
     $91 = $80 & $shaderChannels;
     $92 = ($91|0)==(0);
     do {
      if (!($92)) {
       $93 = ($86<<24>>24)==(0);
       if (!($93)) {
        $94 = (($channelsInfo) + ($83<<2)|0);
        $95 = $85 << 24;
        $96 = $84 & 16777215;
        $97 = $95 | $96;
        HEAP32[$94>>2] = $97;
        break;
       }
       if ($81) {
        $98 = (($channelsInfo) + ($83<<2)|0);
        HEAP32[$98>>2] = $99;
       }
      }
     } while(0);
     $100 = (($83) + 1)|0;
     $101 = $80 << 1;
     $102 = ($100|0)<(8);
     $103 = ($101>>>0)<=($shaderChannels>>>0);
     $or$cond = $102 & $103;
     if ($or$cond) {
      $182 = $99;$80 = $101;$83 = $100;
     } else {
      break L42;
     }
    }
   }
   while(1) {
    $50 = $51 & 120;
    $52 = ($50|0)!=(0);
    $53 = ((($this) + ($54<<2)|0) + 8|0);
    $55 = HEAP32[$53>>2]|0;
    $56 = ((($secondaryChannels) + ($54<<2)|0) + 3|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = ($57<<24>>24)==(0);
    if ($58) {
     $$in = $55;$$in10$in = $55;
    } else {
     $59 = (($secondaryChannels) + ($54<<2)|0);
     $60 = HEAP32[$59>>2]|0;
     $$in = $60;$$in10$in = $60;
    }
    $$in10 = $$in10$in >>> 24;
    $61 = $$in10&255;
    $62 = ($61<<24>>24)!=(0);
    $or$cond7$us = $52 & $62;
    if ($or$cond7$us) {
     $63 = $$in10 << 24;
     $64 = $$in & 16777215;
     $65 = $63 | $64;
     $74 = $65;
    } else {
     $74 = $181;
    }
    $66 = $51 & $shaderChannels;
    $67 = ($66|0)==(0);
    do {
     if (!($67)) {
      $68 = ($61<<24>>24)==(0);
      if (!($68)) {
       $69 = (($channelsInfo) + ($54<<2)|0);
       $70 = $$in10 << 24;
       $71 = $$in & 16777215;
       $72 = $70 | $71;
       HEAP32[$69>>2] = $72;
       break;
      }
      if ($52) {
       $73 = (($channelsInfo) + ($54<<2)|0);
       HEAP32[$73>>2] = $74;
      }
     }
    } while(0);
    $75 = (($54) + 1)|0;
    $76 = $51 << 1;
    $77 = ($75|0)<(8);
    $78 = ($76>>>0)<=($shaderChannels>>>0);
    $or$cond$us = $77 & $78;
    if ($or$cond$us) {
     $181 = $74;$51 = $76;$54 = $75;
    } else {
     break;
    }
   }
  }
 } while(0);
 $104 = HEAP32[((640792 + 76|0))>>2]|0;
 $105 = $shaderChannels & 4;
 $106 = $105 & $104;
 $107 = ($106|0)==(0);
 if (!($107)) {
  $108 = (($channelsInfo) + 11|0);
  $109 = HEAP8[$108>>0]|0;
  $110 = ($109<<24>>24)==(0);
  if ($110) {
   $111 = (($channelsInfo) + 8|0);
   HEAP8[$111>>0] = $firstFreeStream$0;
   $112 = (($channelsInfo) + 9|0);
   HEAP8[$112>>0] = 0;
   $113 = (($channelsInfo) + 10|0);
   HEAP8[$113>>0] = 2;
   HEAP8[$108>>0] = 4;
  }
 }
 $114 = (($this) + 56|0);
 $115 = HEAP8[$114>>0]|0;
 $116 = ($115<<24>>24)==(0);
 if ($116) {
  $118 = (__Z12GetGfxDevicev()|0);
  $120 = $118;
  $119 = HEAP32[$120>>2]|0;
  $121 = (($119) + 296|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = (FUNCTION_TABLE_iii[$122 & 4095]($120,$channelsInfo)|0);
  STACKTOP = sp;return ($123|0);
 } else {
  $117 = (__Z16GetRealGfxDevicev()|0);
  $120 = $117;
  $119 = HEAP32[$120>>2]|0;
  $121 = (($119) + 296|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = (FUNCTION_TABLE_iii[$122 & 4095]($120,$channelsInfo)|0);
  STACKTOP = sp;return ($123|0);
 }
 return 0|0;
}
function __ZN23MeshVertexFormatManager19GetMeshVertexFormatERK18VertexChannelsInfo($this,$sourceChannels) {
 $this = $this|0;
 $sourceChannels = $sourceChannels|0;
 var $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i40 = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$02 = 0, $$byval_copy = 0, $$channelMask$0$1$i$i = 0, $$channelMask$0$2$i$i = 0, $$channelMask$0$3$i$i = 0, $$channelMask$0$4$i$i = 0, $$channelMask$0$5$i$i = 0, $$channelMask$0$6$i$i = 0, $$channelMask$0$7$i$i = 0, $$pn = 0, $$pre$i$i$i = 0, $$sroa$027 = 0, $$sroa$330 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i5$i = 0, $__parent$i$i = 0, $__r$0$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i10$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i8$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy = sp + 176|0;
 $__parent$i$i = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 20|0;
 $$sroa$027 = sp + 112|0;
 $$sroa$330 = sp + 144|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 $6 = ($4|0)==(0|0);
 if ($6) {
  $$0$ph5$i$i$i40 = $5;
 } else {
  $$0$ph7$i$i$i = $5;$$01$ph6$i$in$i$i = $4;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i) + 16|0);
    $8 = (__ZNK18VertexChannelsInfoltERKS_($7,$sourceChannels)|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($5|0);
  if ($14) {
   $$0$ph5$i$i$i40 = $5;
  } else {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = (__ZNK18VertexChannelsInfoltERKS_($sourceChannels,$15)|0);
   if ($16) {
    $$0$ph5$i$i$i40 = $$0$ph5$i$i$i;
   } else {
    $$pn = $15;
    $$02 = (($$pn) + 32|0);
    STACKTOP = sp;return ($$02|0);
   }
  }
 }
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 1)|0;
 HEAP32[$17>>2] = $19;
 ;HEAP32[$$sroa$330+0>>2]=HEAP32[$sourceChannels+0>>2]|0;HEAP32[$$sroa$330+4>>2]=HEAP32[$sourceChannels+4>>2]|0;HEAP32[$$sroa$330+8>>2]=HEAP32[$sourceChannels+8>>2]|0;HEAP32[$$sroa$330+12>>2]=HEAP32[$sourceChannels+12>>2]|0;HEAP32[$$sroa$330+16>>2]=HEAP32[$sourceChannels+16>>2]|0;HEAP32[$$sroa$330+20>>2]=HEAP32[$sourceChannels+20>>2]|0;HEAP32[$$sroa$330+24>>2]=HEAP32[$sourceChannels+24>>2]|0;HEAP32[$$sroa$330+28>>2]=HEAP32[$sourceChannels+28>>2]|0;
 $20 = (($sourceChannels) + 3|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)!=(0);
 $23 = $22&1;
 $24 = (($sourceChannels) + 7|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)!=(0);
 $27 = $26 ? 2 : 0;
 $$channelMask$0$1$i$i = $27 | $23;
 $28 = (($sourceChannels) + 11|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)!=(0);
 $31 = $30 ? 4 : 0;
 $$channelMask$0$2$i$i = $$channelMask$0$1$i$i | $31;
 $32 = (($sourceChannels) + 15|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)!=(0);
 $35 = $34 ? 8 : 0;
 $$channelMask$0$3$i$i = $$channelMask$0$2$i$i | $35;
 $36 = (($sourceChannels) + 19|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)!=(0);
 $39 = $38 ? 16 : 0;
 $$channelMask$0$4$i$i = $$channelMask$0$3$i$i | $39;
 $40 = (($sourceChannels) + 23|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)!=(0);
 $43 = $42 ? 32 : 0;
 $$channelMask$0$5$i$i = $$channelMask$0$4$i$i | $43;
 $44 = (($sourceChannels) + 27|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = ($45<<24>>24)!=(0);
 $47 = $46 ? 64 : 0;
 $$channelMask$0$6$i$i = $$channelMask$0$5$i$i | $47;
 $48 = (($sourceChannels) + 31|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = ($49<<24>>24)!=(0);
 $51 = $50 ? 128 : 0;
 $$channelMask$0$7$i$i = $$channelMask$0$6$i$i | $51;
 ;HEAP32[$$sroa$027+0>>2]=HEAP32[$sourceChannels+0>>2]|0;HEAP32[$$sroa$027+4>>2]=HEAP32[$sourceChannels+4>>2]|0;HEAP32[$$sroa$027+8>>2]=HEAP32[$sourceChannels+8>>2]|0;HEAP32[$$sroa$027+12>>2]=HEAP32[$sourceChannels+12>>2]|0;HEAP32[$$sroa$027+16>>2]=HEAP32[$sourceChannels+16>>2]|0;HEAP32[$$sroa$027+20>>2]=HEAP32[$sourceChannels+20>>2]|0;HEAP32[$$sroa$027+24>>2]=HEAP32[$sourceChannels+24>>2]|0;HEAP32[$$sroa$027+28>>2]=HEAP32[$sourceChannels+28>>2]|0;
 $52 = (($2) + 32|0);
 HEAP32[$52>>2] = $19;
 $53 = (($2) + 36|0);
 HEAP32[$53>>2] = $$channelMask$0$7$i$i;
 $54 = (($2) + 40|0);
 ;HEAP32[$54+0>>2]=HEAP32[$$sroa$330+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$$sroa$330+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$$sroa$330+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$$sroa$330+12>>2]|0;HEAP32[$54+16>>2]=HEAP32[$$sroa$330+16>>2]|0;HEAP32[$54+20>>2]=HEAP32[$$sroa$330+20>>2]|0;HEAP32[$54+24>>2]=HEAP32[$$sroa$330+24>>2]|0;HEAP32[$54+28>>2]=HEAP32[$$sroa$330+28>>2]|0;
 $55 = (($2) + 76|0);
 $56 = (($2) + 80|0);
 ;HEAP32[$55+0>>2]=0|0;HEAP32[$55+4>>2]=0|0;HEAP32[$55+8>>2]=0|0;HEAP8[$55+12>>0]=0|0;
 ;HEAP32[$2+0>>2]=HEAP32[$$sroa$027+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$$sroa$027+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$$sroa$027+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$$sroa$027+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$$sroa$027+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$$sroa$027+20>>2]|0;HEAP32[$2+24>>2]=HEAP32[$$sroa$027+24>>2]|0;HEAP32[$2+28>>2]=HEAP32[$$sroa$027+28>>2]|0;
 HEAP32[$0>>2] = $$0$ph5$i$i$i40;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $57 = (invoke_iiiii(235,($this|0),($$byval_copy|0),($__parent$i$i|0),($2|0))|0);
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 do {
  if (!($59)) {
   $60 = HEAP32[$57>>2]|0;
   $61 = ($60|0)==(0|0);
   if ($61) {
    __THREW__ = 0;
    invoke_viii(1721,($1|0),($this|0),($2|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    $64 = HEAP32[$1>>2]|0;
    HEAP32[$1>>2] = 0;
    $65 = HEAP32[$__parent$i$i>>2]|0;
    HEAP32[$64>>2] = 0;
    $66 = (($64) + 4|0);
    HEAP32[$66>>2] = 0;
    $67 = (($64) + 8|0);
    HEAP32[$67>>2] = $65;
    HEAP32[$57>>2] = $64;
    $68 = HEAP32[$this>>2]|0;
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(0|0);
    if ($70) {
     $72 = $64;
    } else {
     HEAP32[$this>>2] = $69;
     $$pre$i$i$i = HEAP32[$57>>2]|0;
     $72 = $$pre$i$i$i;
    }
    $71 = HEAP32[$3>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($71,$72);
    $73 = (($this) + 8|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($74) + 1)|0;
    HEAP32[$73>>2] = $75;
    $__r$0$i$i = $64;
   } else {
    $__r$0$i$i = $60;
   }
   $76 = HEAP32[$55>>2]|0;
   $77 = ($76|0)==(0|0);
   if (!($77)) {
    $78 = HEAP32[$56>>2]|0;
    $79 = ($78|0)==($76|0);
    if (!($79)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $76;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($78) + -16|0);
     $80 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($80)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
     $81 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 4;
     $82 = $81 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($78) + ($82<<4)|0);
     HEAP32[$56>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($76);
   }
   $92 = (($__r$0$i$i) + 16|0);
   $$pn = $92;
   $$02 = (($$pn) + 32|0);
   STACKTOP = sp;return ($$02|0);
  }
 } while(0);
 $83 = ___cxa_find_matching_catch()|0;
 $84 = tempRet0;
 $85 = HEAP32[$55>>2]|0;
 $86 = ($85|0)==(0|0);
 if ($86) {
  ___resumeException($83|0);
  // unreachable;
 }
 $87 = HEAP32[$56>>2]|0;
 $88 = ($87|0)==($85|0);
 if (!($88)) {
  $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i5$i = $85;
  $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6$i = (($87) + -16|0);
  $89 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i5$i))|0;
  $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i8$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6$i) + ($89)|0);
  $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i9$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i8$i;
  $90 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i9$i >>> 4;
  $91 = $90 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i10$i = (($87) + ($91<<4)|0);
  HEAP32[$56>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i10$i;
 }
 __ZdlPv($85);
 ___resumeException($83|0);
 // unreachable;
 return 0|0;
}
function __ZN23MeshVertexFormatManager10GetDefaultEj($this,$shaderChannels) {
 $this = $this|0;
 $shaderChannels = $shaderChannels|0;
 var $0 = 0, $sourceChannels = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sourceChannels = sp;
 ;HEAP32[$sourceChannels+0>>2]=0|0;HEAP32[$sourceChannels+4>>2]=0|0;HEAP32[$sourceChannels+8>>2]=0|0;HEAP32[$sourceChannels+12>>2]=0|0;HEAP32[$sourceChannels+16>>2]=0|0;HEAP32[$sourceChannels+20>>2]=0|0;HEAP32[$sourceChannels+24>>2]=0|0;HEAP32[$sourceChannels+28>>2]=0|0;
 (__Z28BuildSingleStreamChannelInfojRK20VertexChannelsLayoutP11ChannelInfo($shaderChannels,588176,$sourceChannels)|0);
 $0 = (__ZN23MeshVertexFormatManager19GetMeshVertexFormatERK18VertexChannelsInfo($this,$sourceChannels)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL29CreateMeshVertexFormatManagerv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$0>>2] = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy,0,16,588096,190)|0);
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$1>>2] = $2;
 $4 = (($1) + 12|0);
 HEAP32[$4>>2] = 0;
 HEAP32[588088>>2] = $1;
 STACKTOP = sp;return;
}
function __ZL30DestroyMeshVertexFormatManagerv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[588088>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfo16MeshVertexFormatEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($1,$4);
 }
 HEAP32[$0>>2] = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[588088>>2] = 0;
 STACKTOP = sp;return;
}
function __Z26GetMeshVertexFormatManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[588088>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfo16MeshVertexFormatEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS4_PNS_11__tree_nodeIS4_SE_EEiEESH_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = (($1) + 16|0);
  $4 = (__ZNK18VertexChannelsInfoltERKS_($__v,$3)|0);
  if (!($4)) {
   $33 = (__ZNK18VertexChannelsInfoltERKS_($3,$__v)|0);
   if (!($33)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $34 = (($1) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $39 = (($$01$i$i$i$i$i) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==($$01$i$i$i$i$i|0);
     if ($42) {
      $$0$i$i$i$i$i = $40;
      break;
     } else {
      $$01$i$i$i$i$i = $40;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $35;
    while(1) {
     $37 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $37;
     }
    }
   }
   $43 = ($$0$i$i$i$i$i|0)==($0|0);
   do {
    if ($43) {
     $47 = $35;
    } else {
     $44 = (($$0$i$i$i$i$i) + 16|0);
     $45 = (__ZNK18VertexChannelsInfoltERKS_($__v,$44)|0);
     if ($45) {
      $$pre = HEAP32[$34>>2]|0;
      $47 = $$pre;
      break;
     }
     $48 = (($this) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0|0);
     if ($50) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $49;
     }
     while(1) {
      $51 = (($__nd$0$in$i) + 16|0);
      $52 = (__ZNK18VertexChannelsInfoltERKS_($__v,$51)|0);
      if ($52) {
       $53 = HEAP32[$__nd$0$in$i>>2]|0;
       $54 = ($53|0)==(0|0);
       if ($54) {
        label = 35;
        break;
       } else {
        $__nd$0$in$i = $53;
        continue;
       }
      }
      $55 = (__ZNK18VertexChannelsInfoltERKS_($51,$__v)|0);
      if (!($55)) {
       label = 39;
       break;
      }
      $56 = (($__nd$0$in$i) + 4|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0|0);
      if ($58) {
       label = 38;
       break;
      } else {
       $__nd$0$in$i = $57;
      }
     }
     if ((label|0) == 35) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $56;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 39) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $46 = ($47|0)==(0|0);
   if ($46) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $34;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = ($1|0)==($5|0);
 if ($6) {
  $20 = $1;
 } else {
  $7 = HEAP32[$1>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$01$i$i = $1;
   while(1) {
    $12 = (($$01$i$i) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($$01$i$i|0);
    if ($15) {
     $$01$i$i = $13;
    } else {
     $$0$i$i = $13;
     break;
    }
   }
  } else {
   $$0$i$i$i = $7;
   while(1) {
    $9 = (($$0$i$i$i) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $10;
    }
   }
  }
  $16 = (($$0$i$i) + 16|0);
  $17 = (__ZNK18VertexChannelsInfoltERKS_($16,$__v)|0);
  if ($17) {
   $20 = $$0$i$i;
  } else {
   $22 = (($this) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i7 = $23;
   }
   while(1) {
    $25 = (($__nd$0$in$i7) + 16|0);
    $26 = (__ZNK18VertexChannelsInfoltERKS_($__v,$25)|0);
    if ($26) {
     $27 = HEAP32[$__nd$0$in$i7>>2]|0;
     $28 = ($27|0)==(0|0);
     if ($28) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i7 = $27;
      continue;
     }
    }
    $29 = (__ZNK18VertexChannelsInfoltERKS_($25,$__v)|0);
    if (!($29)) {
     label = 19;
     break;
    }
    $30 = (($__nd$0$in$i7) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i7 = $31;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i7;
    $$0 = $__nd$0$in$i7;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i7;
    $$0 = $30;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i7;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $18 = HEAP32[$1>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $20;
  $21 = (($20) + 4|0);
  $$0 = $21;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfo16MeshVertexFormatEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEENS_9allocatorIS4_EEE16__construct_nodeERKS4_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $$pre2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (__Znwj(108)|0);
 $2 = $0;
 $3 = (($1) + 16|0);
 ;HEAP32[$3+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$__v+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$__v+20>>2]|0;HEAP32[$3+24>>2]=HEAP32[$__v+24>>2]|0;HEAP32[$3+28>>2]=HEAP32[$__v+28>>2]|0;
 $4 = (($1) + 48|0);
 $5 = (($__v) + 32|0);
 dest=$4+0|0; src=$5+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = (($1) + 88|0);
 $7 = (($__v) + 72|0);
 $8 = HEAP8[$7>>0]|0;
 HEAP8[$6>>0] = $8;
 $9 = (($1) + 92|0);
 HEAP32[$9>>2] = 0;
 $10 = (($1) + 96|0);
 HEAP32[$10>>2] = 0;
 $11 = (($1) + 100|0);
 HEAP32[$11>>2] = 0;
 $12 = (($__v) + 80|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($__v) + 76|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $13;
 $17 = $15;
 $18 = (($16) - ($17))|0;
 $19 = $18 >> 4;
 $20 = ($19|0)==(0);
 L1: do {
  if (!($20)) {
   $21 = ($19>>>0)>(268435455);
   if ($21) {
    __THREW__ = 0;
    invoke_vi(3308,0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   } else {
    __THREW__ = 0;
    $24 = (invoke_ii(2988,($18|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     HEAP32[$10>>2] = $24;
     HEAP32[$9>>2] = $24;
     $27 = (($24) + ($19<<4)|0);
     HEAP32[$11>>2] = $27;
     $28 = ($15|0)==($13|0);
     if ($28) {
      break;
     } else {
      $$01$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $15;$30 = $24;
     }
     while(1) {
      $29 = ($30|0)==(0|0);
      if ($29) {
       $32 = 0;
      } else {
       ;HEAP32[$30+0>>2]=HEAP32[$$01$i$i$i$i$i$i$i$i$i$i$i$i$i$i+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$$01$i$i$i$i$i$i$i$i$i$i$i$i$i$i+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$$01$i$i$i$i$i$i$i$i$i$i$i$i$i$i+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$$01$i$i$i$i$i$i$i$i$i$i$i$i$i$i+12>>2]|0;
       $$pre2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = HEAP32[$10>>2]|0;
       $32 = $$pre2$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      }
      $31 = (($32) + 16|0);
      HEAP32[$10>>2] = $31;
      $33 = (($$01$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + 16|0);
      $34 = ($33|0)==($13|0);
      if ($34) {
       break L1;
      } else {
       $$01$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $33;$30 = $31;
      }
     }
    }
   }
   $35 = ___cxa_find_matching_catch()|0;
   $36 = tempRet0;
   $37 = HEAP32[$9>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    $39 = HEAP32[$10>>2]|0;
    $40 = ($39|0)==($37|0);
    if (!($40)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $37;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($39) + -16|0);
     $41 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($41)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
     $42 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 4;
     $43 = $42 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($39) + ($43<<4)|0);
     HEAP32[$10>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($37);
   }
   $52 = ($1|0)==(0|0);
   if ($52) {
    ___resumeException($35|0);
    // unreachable;
   }
   __ZdlPv($1);
   ___resumeException($35|0);
   // unreachable;
  }
 } while(0);
 $44 = (($1) + 104|0);
 $45 = (($__v) + 88|0);
 $46 = HEAP8[$45>>0]|0;
 HEAP8[$44>>0] = $46;
 ;HEAP32[$3+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$__v+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$__v+20>>2]|0;HEAP32[$3+24>>2]=HEAP32[$__v+24>>2]|0;HEAP32[$3+28>>2]=HEAP32[$__v+28>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 $47 = (($agg$result) + 4|0);
 $48 = $47;
 $49 = $48;
 HEAP32[$49>>2] = $2;
 $50 = (($48) + 4)|0;
 $51 = $50;
 HEAP32[$51>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_4pairIyP17VertexDeclarationEENS_9allocatorIS4_EEE6insertENS_11__wrap_iterIPKS4_EERS9_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i14 = 0, $$0$i15 = 0, $$012$i$i$i12 = 0, $$03$i$i$i11 = 0, $$pre = 0, $$pre$i10 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$__position>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 4;
 $6 = (($0) + ($5<<4)|0);
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)<($10>>>0);
 if ($11) {
  $12 = ($6|0)==($8|0);
  if ($12) {
   $13 = ($6|0)==(0|0);
   if ($13) {
    $15 = 0;
   } else {
    ;HEAP32[$6+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$__x+12>>2]|0;
    $$pre = HEAP32[$7>>2]|0;
    $15 = $$pre;
   }
   $14 = (($15) + 16|0);
   HEAP32[$7>>2] = $14;
   $__p$0 = $6;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($5) + 1)|0;
  $16 = (($0) + ($$sum<<4)|0);
  $17 = $8;
  $18 = $16;
  $19 = (($17) - ($18))|0;
  $20 = $19 >> 4;
  $$sum18 = (($20) + ($5))|0;
  $21 = (($0) + ($$sum18<<4)|0);
  $22 = ($21>>>0)<($8>>>0);
  if ($22) {
   $24 = $8;$__i$01$i = $21;
   while(1) {
    $23 = ($24|0)==(0|0);
    if ($23) {
     $27 = 0;
    } else {
     ;HEAP32[$24+0>>2]=HEAP32[$__i$01$i+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__i$01$i+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__i$01$i+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__i$01$i+12>>2]|0;
     $$pre$i10 = HEAP32[$7>>2]|0;
     $27 = $$pre$i10;
    }
    $25 = (($__i$01$i) + 16|0);
    $26 = (($27) + 16|0);
    HEAP32[$7>>2] = $26;
    $28 = ($25>>>0)<($8>>>0);
    if ($28) {
     $24 = $26;$__i$01$i = $25;
    } else {
     break;
    }
   }
  }
  $29 = ($20|0)==(0);
  if (!($29)) {
   $$012$i$i$i12 = $21;$$03$i$i$i11 = $8;
   while(1) {
    $30 = (($$03$i$i$i11) + -16|0);
    $31 = (($$012$i$i$i12) + -16|0);
    $32 = $31;
    $33 = $32;
    $34 = HEAP32[$33>>2]|0;
    $35 = (($32) + 4)|0;
    $36 = $35;
    $37 = HEAP32[$36>>2]|0;
    $38 = $30;
    $39 = $38;
    HEAP32[$39>>2] = $34;
    $40 = (($38) + 4)|0;
    $41 = $40;
    HEAP32[$41>>2] = $37;
    $42 = (($$012$i$i$i12) + -8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($$03$i$i$i11) + -8|0);
    HEAP32[$44>>2] = $43;
    $45 = ($31|0)==($6|0);
    if ($45) {
     break;
    } else {
     $$012$i$i$i12 = $31;$$03$i$i$i11 = $30;
    }
   }
  }
  $46 = ($6>>>0)>($__x>>>0);
  if ($46) {
   $__xr$0 = $__x;
  } else {
   $47 = HEAP32[$7>>2]|0;
   $48 = ($47>>>0)>($__x>>>0);
   $49 = (($__x) + 16|0);
   $$ = $48 ? $49 : $__x;
   $__xr$0 = $$;
  }
  $50 = $__xr$0;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = (($50) + 4)|0;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = $6;
  $57 = $56;
  HEAP32[$57>>2] = $52;
  $58 = (($56) + 4)|0;
  $59 = $58;
  HEAP32[$59>>2] = $55;
  $60 = (($__xr$0) + 8|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($0) + ($5<<4)|0) + 8|0);
  HEAP32[$62>>2] = $61;
  $__p$0 = $6;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $63 = $8;
 $64 = (($63) - ($3))|0;
 $65 = $64 >> 4;
 $66 = (($65) + 1)|0;
 $67 = ($66>>>0)>(268435455);
 if ($67) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $68 = $10;
 $69 = (($68) - ($3))|0;
 $70 = $69 >> 4;
 $71 = ($70>>>0)<(134217727);
 if ($71) {
  $74 = $69 >> 3;
  $75 = ($74>>>0)<($66>>>0);
  $76 = $75 ? $66 : $74;
  $77 = $6;
  $78 = $4 >> 4;
  $79 = ($76|0)==(0);
  if ($79) {
   $$0$i15 = 0;$109 = $77;$83 = 0;$84 = $78;
  } else {
   $$0$i14 = $76;$124 = $78;$125 = $77;
   label = 20;
  }
 } else {
  $72 = $6;
  $73 = $4 >> 4;
  $$0$i14 = 268435455;$124 = $73;$125 = $72;
  label = 20;
 }
 if ((label|0) == 20) {
  $80 = $$0$i14 << 4;
  $81 = (__Znwj($80)|0);
  $$0$i15 = $$0$i14;$109 = $125;$83 = $81;$84 = $124;
 }
 $82 = (($83) + ($84<<4)|0);
 $85 = (($83) + ($$0$i15<<4)|0);
 $86 = ($84|0)==($$0$i15|0);
 do {
  if ($86) {
   $87 = ($84|0)>(0);
   if ($87) {
    $88 = (($84) + 1)|0;
    $89 = (($88|0) / -2)&-1;
    $$sum17 = (($89) + ($84))|0;
    $90 = (($83) + ($$sum17<<4)|0);
    $103 = $90;$119 = $85;
    break;
   }
   $91 = $84 << 1;
   $92 = ($84|0)==(0);
   $93 = $92 ? 1 : $91;
   $94 = $93 << 4;
   __THREW__ = 0;
   $95 = (invoke_ii(2988,($94|0))|0);
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if (!($97)) {
    $98 = $93 >>> 2;
    $99 = (($95) + ($98<<4)|0);
    $100 = (($95) + ($93<<4)|0);
    $101 = ($83|0)==(0|0);
    if ($101) {
     $103 = $99;$119 = $100;
     break;
    }
    __ZdlPv($83);
    $103 = $99;$119 = $100;
    break;
   }
   $121 = ___cxa_find_matching_catch()|0;
   $122 = tempRet0;
   $123 = ($83|0)==(0|0);
   if ($123) {
    ___resumeException($121|0);
    // unreachable;
   }
   __ZdlPv($83);
   ___resumeException($121|0);
   // unreachable;
  } else {
   $103 = $82;$119 = $85;
  }
 } while(0);
 $102 = ($103|0)==(0|0);
 if ($102) {
  $105 = 0;
 } else {
  ;HEAP32[$103+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$__x+12>>2]|0;
  $105 = $103;
 }
 $104 = (($105) + 16|0);
 $106 = HEAP32[$this>>2]|0;
 $107 = $106;
 $108 = (($109) - ($107))|0;
 $110 = $108 >> 4;
 $111 = (0 - ($110))|0;
 $112 = (($103) + ($111<<4)|0);
 _memcpy(($112|0),($106|0),($108|0))|0;
 $113 = HEAP32[$7>>2]|0;
 $114 = $113;
 $115 = (($114) - ($109))|0;
 $116 = $115 >> 4;
 _memcpy(($104|0),($6|0),($115|0))|0;
 $$sum16 = (($116) + 1)|0;
 $117 = (($105) + ($$sum16<<4)|0);
 $118 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $112;
 HEAP32[$7>>2] = $117;
 HEAP32[$9>>2] = $119;
 $120 = ($118|0)==(0|0);
 if ($120) {
  $__p$0 = $103;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 __ZdlPv($118);
 $__p$0 = $103;
 HEAP32[$agg$result>>2] = $__p$0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfo16MeshVertexFormatEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfo16MeshVertexFormatEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfo16MeshVertexFormatEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$3);
 $4 = (($__nd) + 92|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($__nd) + 96|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  if (!($9)) {
   $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $5;
   $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($8) + -16|0);
   $10 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($10)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
   $11 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 4;
   $12 = $11 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($8) + ($12<<4)|0);
   HEAP32[$7>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($5);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a3392() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588104);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588120);
 STACKTOP = sp;return;
}
function __ZNK17IAnimationBinding38SerializedPropertyPathToCurveAttributeER6ObjectPKc($agg$result,$this,$target,$propertyPath) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $target = $target|0;
 $propertyPath = $propertyPath|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNK17IAnimationBinding30CurveAttributeToSerializedPathERKN11UnityEngine9Animation10BoundCurveE($agg$result,$this,$bound) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $bound = $bound|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __Z27TransformVerticesStridedREFPhRK10Matrix4x4fjPKhiiiS4_iib($dstData,$m,$vertexCount,$vertexData,$normalOffset,$tangentOffset,$vertexStride,$copyData,$copyStride,$copySize,$addWhiteColor) {
 $dstData = $dstData|0;
 $m = $m|0;
 $vertexCount = $vertexCount|0;
 $vertexData = $vertexData|0;
 $normalOffset = $normalOffset|0;
 $tangentOffset = $tangentOffset|0;
 $vertexStride = $vertexStride|0;
 $copyData = $copyData|0;
 $copyStride = $copyStride|0;
 $copySize = $copySize|0;
 $addWhiteColor = $addWhiteColor|0;
 var $$014 = 0, $$014$us = 0, $$0213 = 0, $$0213$us = 0, $$0312 = 0, $$0312$us = 0, $$14 = 0, $$14$us = 0, $$2 = 0, $$2$us = 0, $$3 = 0, $$3$us = 0, $$4 = 0, $$4$us = 0, $$op22 = 0, $$sum = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0);
 var $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0;
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $copyIn32$09 = 0, $copyIn32$09$us = 0, $copyOut32$0$lcssa = 0, $copyOut32$0$lcssa$us = 0, $copyOut32$010 = 0, $copyOut32$010$us = 0;
 var $i$011 = 0, $i$011$us = 0, $scevgep = 0, $scevgep20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($copySize|0) / 4)&-1;
 $1 = (($vertexCount) + -1)|0;
 $2 = ($vertexCount|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($m) + 16|0);
 $4 = (($m) + 32|0);
 $5 = (($m) + 48|0);
 $6 = (($m) + 4|0);
 $7 = (($m) + 20|0);
 $8 = (($m) + 36|0);
 $9 = (($m) + 52|0);
 $10 = (($m) + 8|0);
 $11 = (($m) + 24|0);
 $12 = (($m) + 40|0);
 $13 = (($m) + 56|0);
 $14 = ($normalOffset|0)>(-1);
 $$sum7 = (($normalOffset) + 4)|0;
 $$sum8 = (($normalOffset) + 8)|0;
 $15 = ($tangentOffset|0)>(-1);
 $$sum5 = (($tangentOffset) + 4)|0;
 $$sum6 = (($tangentOffset) + 8)|0;
 $$sum = (($tangentOffset) + 12)|0;
 $16 = ($copySize|0)>(3);
 $17 = ($copySize|0)>(7);
 $$op22 = $0 << 2;
 $18 = $17 ? $$op22 : 4;
 if ($14) {
  $$014$us = $dstData;$$0213$us = $vertexData;$$0312$us = $copyData;$154 = $1;
  while(1) {
   $19 = Math_fround(HEAPF32[$m>>2]);
   $20 = Math_fround(HEAPF32[$$0213$us>>2]);
   $21 = Math_fround($19 * $20);
   $22 = Math_fround(HEAPF32[$3>>2]);
   $23 = (($$0213$us) + 4|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($22 * $24);
   $26 = Math_fround($21 + $25);
   $27 = Math_fround(HEAPF32[$4>>2]);
   $28 = (($$0213$us) + 8|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($27 * $29);
   $31 = Math_fround($26 + $30);
   $32 = Math_fround(HEAPF32[$5>>2]);
   $33 = Math_fround($32 + $31);
   HEAPF32[$$014$us>>2] = $33;
   $34 = Math_fround(HEAPF32[$6>>2]);
   $35 = Math_fround(HEAPF32[$$0213$us>>2]);
   $36 = Math_fround($34 * $35);
   $37 = Math_fround(HEAPF32[$7>>2]);
   $38 = Math_fround(HEAPF32[$23>>2]);
   $39 = Math_fround($37 * $38);
   $40 = Math_fround($36 + $39);
   $41 = Math_fround(HEAPF32[$8>>2]);
   $42 = Math_fround(HEAPF32[$28>>2]);
   $43 = Math_fround($41 * $42);
   $44 = Math_fround($40 + $43);
   $45 = Math_fround(HEAPF32[$9>>2]);
   $46 = Math_fround($45 + $44);
   $47 = (($$014$us) + 4|0);
   HEAPF32[$47>>2] = $46;
   $48 = Math_fround(HEAPF32[$10>>2]);
   $49 = Math_fround(HEAPF32[$$0213$us>>2]);
   $50 = Math_fround($48 * $49);
   $51 = Math_fround(HEAPF32[$11>>2]);
   $52 = Math_fround(HEAPF32[$23>>2]);
   $53 = Math_fround($51 * $52);
   $54 = Math_fround($50 + $53);
   $55 = Math_fround(HEAPF32[$12>>2]);
   $56 = Math_fround(HEAPF32[$28>>2]);
   $57 = Math_fround($55 * $56);
   $58 = Math_fround($54 + $57);
   $59 = Math_fround(HEAPF32[$13>>2]);
   $60 = Math_fround($59 + $58);
   $61 = (($$014$us) + 8|0);
   HEAPF32[$61>>2] = $60;
   $62 = (($$014$us) + 12|0);
   $63 = (($$0213$us) + ($normalOffset)|0);
   $64 = Math_fround(HEAPF32[$m>>2]);
   $65 = Math_fround(HEAPF32[$63>>2]);
   $66 = Math_fround($64 * $65);
   $67 = Math_fround(HEAPF32[$3>>2]);
   $68 = (($$0213$us) + ($$sum7)|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($67 * $69);
   $71 = Math_fround($66 + $70);
   $72 = Math_fround(HEAPF32[$4>>2]);
   $73 = (($$0213$us) + ($$sum8)|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = Math_fround($72 * $74);
   $76 = Math_fround($71 + $75);
   HEAPF32[$62>>2] = $76;
   $77 = Math_fround(HEAPF32[$6>>2]);
   $78 = Math_fround(HEAPF32[$63>>2]);
   $79 = Math_fround($77 * $78);
   $80 = Math_fround(HEAPF32[$7>>2]);
   $81 = Math_fround(HEAPF32[$68>>2]);
   $82 = Math_fround($80 * $81);
   $83 = Math_fround($79 + $82);
   $84 = Math_fround(HEAPF32[$8>>2]);
   $85 = Math_fround(HEAPF32[$73>>2]);
   $86 = Math_fround($84 * $85);
   $87 = Math_fround($83 + $86);
   $88 = (($$014$us) + 16|0);
   HEAPF32[$88>>2] = $87;
   $89 = Math_fround(HEAPF32[$10>>2]);
   $90 = Math_fround(HEAPF32[$63>>2]);
   $91 = Math_fround($89 * $90);
   $92 = Math_fround(HEAPF32[$11>>2]);
   $93 = Math_fround(HEAPF32[$68>>2]);
   $94 = Math_fround($92 * $93);
   $95 = Math_fround($91 + $94);
   $96 = Math_fround(HEAPF32[$12>>2]);
   $97 = Math_fround(HEAPF32[$73>>2]);
   $98 = Math_fround($96 * $97);
   $99 = Math_fround($95 + $98);
   $100 = (($$014$us) + 20|0);
   HEAPF32[$100>>2] = $99;
   $101 = (($$014$us) + 24|0);
   if ($addWhiteColor) {
    HEAP32[$101>>2] = -1;
    $102 = (($$014$us) + 28|0);
    $$2$us = $102;
   } else {
    $$2$us = $101;
   }
   $103 = ($$0312$us|0)==(0|0);
   if ($103) {
    $$14$us = 0;$$3$us = $$2$us;
   } else {
    if ($16) {
     $scevgep20 = (($$2$us) + ($18)|0);
     $copyIn32$09$us = $$0312$us;$copyOut32$010$us = $$2$us;$i$011$us = 0;
     while(1) {
      $105 = (($copyIn32$09$us) + 4|0);
      $106 = HEAP32[$copyIn32$09$us>>2]|0;
      $107 = (($copyOut32$010$us) + 4|0);
      HEAP32[$copyOut32$010$us>>2] = $106;
      $108 = (($i$011$us) + 1)|0;
      $109 = ($108|0)<($0|0);
      if ($109) {
       $copyIn32$09$us = $105;$copyOut32$010$us = $107;$i$011$us = $108;
      } else {
       break;
      }
     }
     $copyOut32$0$lcssa$us = $scevgep20;
    } else {
     $copyOut32$0$lcssa$us = $$2$us;
    }
    $104 = (($$0312$us) + ($copyStride)|0);
    $$14$us = $104;$$3$us = $copyOut32$0$lcssa$us;
   }
   if ($15) {
    $110 = (($$0213$us) + ($tangentOffset)|0);
    $111 = Math_fround(HEAPF32[$m>>2]);
    $112 = Math_fround(HEAPF32[$110>>2]);
    $113 = Math_fround($111 * $112);
    $114 = Math_fround(HEAPF32[$3>>2]);
    $115 = (($$0213$us) + ($$sum5)|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = Math_fround($114 * $116);
    $118 = Math_fround($113 + $117);
    $119 = Math_fround(HEAPF32[$4>>2]);
    $120 = (($$0213$us) + ($$sum6)|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    $122 = Math_fround($119 * $121);
    $123 = Math_fround($118 + $122);
    HEAPF32[$$3$us>>2] = $123;
    $124 = Math_fround(HEAPF32[$6>>2]);
    $125 = Math_fround(HEAPF32[$110>>2]);
    $126 = Math_fround($124 * $125);
    $127 = Math_fround(HEAPF32[$7>>2]);
    $128 = Math_fround(HEAPF32[$115>>2]);
    $129 = Math_fround($127 * $128);
    $130 = Math_fround($126 + $129);
    $131 = Math_fround(HEAPF32[$8>>2]);
    $132 = Math_fround(HEAPF32[$120>>2]);
    $133 = Math_fround($131 * $132);
    $134 = Math_fround($130 + $133);
    $135 = (($$3$us) + 4|0);
    HEAPF32[$135>>2] = $134;
    $136 = Math_fround(HEAPF32[$10>>2]);
    $137 = Math_fround(HEAPF32[$110>>2]);
    $138 = Math_fround($136 * $137);
    $139 = Math_fround(HEAPF32[$11>>2]);
    $140 = Math_fround(HEAPF32[$115>>2]);
    $141 = Math_fround($139 * $140);
    $142 = Math_fround($138 + $141);
    $143 = Math_fround(HEAPF32[$12>>2]);
    $144 = Math_fround(HEAPF32[$120>>2]);
    $145 = Math_fround($143 * $144);
    $146 = Math_fround($142 + $145);
    $147 = (($$3$us) + 8|0);
    HEAPF32[$147>>2] = $146;
    $148 = (($$0213$us) + ($$sum)|0);
    $149 = Math_fround(HEAPF32[$148>>2]);
    $150 = (($$3$us) + 12|0);
    HEAPF32[$150>>2] = $149;
    $151 = (($$3$us) + 16|0);
    $$4$us = $151;
   } else {
    $$4$us = $$3$us;
   }
   $152 = (($$0213$us) + ($vertexStride)|0);
   $153 = (($154) + -1)|0;
   $155 = ($154|0)==(0);
   if ($155) {
    break;
   } else {
    $$014$us = $$4$us;$$0213$us = $152;$$0312$us = $$14$us;$154 = $153;
   }
  }
  STACKTOP = sp;return;
 } else {
  $$014 = $dstData;$$0213 = $vertexData;$$0312 = $copyData;$252 = $1;
  while(1) {
   $156 = Math_fround(HEAPF32[$m>>2]);
   $157 = Math_fround(HEAPF32[$$0213>>2]);
   $158 = Math_fround($156 * $157);
   $159 = Math_fround(HEAPF32[$3>>2]);
   $160 = (($$0213) + 4|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = Math_fround($159 * $161);
   $163 = Math_fround($158 + $162);
   $164 = Math_fround(HEAPF32[$4>>2]);
   $165 = (($$0213) + 8|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   $167 = Math_fround($164 * $166);
   $168 = Math_fround($163 + $167);
   $169 = Math_fround(HEAPF32[$5>>2]);
   $170 = Math_fround($169 + $168);
   HEAPF32[$$014>>2] = $170;
   $171 = Math_fround(HEAPF32[$6>>2]);
   $172 = Math_fround(HEAPF32[$$0213>>2]);
   $173 = Math_fround($171 * $172);
   $174 = Math_fround(HEAPF32[$7>>2]);
   $175 = Math_fround(HEAPF32[$160>>2]);
   $176 = Math_fround($174 * $175);
   $177 = Math_fround($173 + $176);
   $178 = Math_fround(HEAPF32[$8>>2]);
   $179 = Math_fround(HEAPF32[$165>>2]);
   $180 = Math_fround($178 * $179);
   $181 = Math_fround($177 + $180);
   $182 = Math_fround(HEAPF32[$9>>2]);
   $183 = Math_fround($182 + $181);
   $184 = (($$014) + 4|0);
   HEAPF32[$184>>2] = $183;
   $185 = Math_fround(HEAPF32[$10>>2]);
   $186 = Math_fround(HEAPF32[$$0213>>2]);
   $187 = Math_fround($185 * $186);
   $188 = Math_fround(HEAPF32[$11>>2]);
   $189 = Math_fround(HEAPF32[$160>>2]);
   $190 = Math_fround($188 * $189);
   $191 = Math_fround($187 + $190);
   $192 = Math_fround(HEAPF32[$12>>2]);
   $193 = Math_fround(HEAPF32[$165>>2]);
   $194 = Math_fround($192 * $193);
   $195 = Math_fround($191 + $194);
   $196 = Math_fround(HEAPF32[$13>>2]);
   $197 = Math_fround($196 + $195);
   $198 = (($$014) + 8|0);
   HEAPF32[$198>>2] = $197;
   $199 = (($$014) + 12|0);
   if ($addWhiteColor) {
    HEAP32[$199>>2] = -1;
    $200 = (($$014) + 16|0);
    $$2 = $200;
   } else {
    $$2 = $199;
   }
   $201 = ($$0312|0)==(0|0);
   if ($201) {
    $$14 = 0;$$3 = $$2;
   } else {
    if ($16) {
     $scevgep = (($$2) + ($18)|0);
     $copyIn32$09 = $$0312;$copyOut32$010 = $$2;$i$011 = 0;
     while(1) {
      $202 = (($copyIn32$09) + 4|0);
      $203 = HEAP32[$copyIn32$09>>2]|0;
      $204 = (($copyOut32$010) + 4|0);
      HEAP32[$copyOut32$010>>2] = $203;
      $205 = (($i$011) + 1)|0;
      $206 = ($205|0)<($0|0);
      if ($206) {
       $copyIn32$09 = $202;$copyOut32$010 = $204;$i$011 = $205;
      } else {
       break;
      }
     }
     $copyOut32$0$lcssa = $scevgep;
    } else {
     $copyOut32$0$lcssa = $$2;
    }
    $207 = (($$0312) + ($copyStride)|0);
    $$14 = $207;$$3 = $copyOut32$0$lcssa;
   }
   if ($15) {
    $208 = (($$0213) + ($tangentOffset)|0);
    $209 = Math_fround(HEAPF32[$m>>2]);
    $210 = Math_fround(HEAPF32[$208>>2]);
    $211 = Math_fround($209 * $210);
    $212 = Math_fround(HEAPF32[$3>>2]);
    $213 = (($$0213) + ($$sum5)|0);
    $214 = Math_fround(HEAPF32[$213>>2]);
    $215 = Math_fround($212 * $214);
    $216 = Math_fround($211 + $215);
    $217 = Math_fround(HEAPF32[$4>>2]);
    $218 = (($$0213) + ($$sum6)|0);
    $219 = Math_fround(HEAPF32[$218>>2]);
    $220 = Math_fround($217 * $219);
    $221 = Math_fround($216 + $220);
    HEAPF32[$$3>>2] = $221;
    $222 = Math_fround(HEAPF32[$6>>2]);
    $223 = Math_fround(HEAPF32[$208>>2]);
    $224 = Math_fround($222 * $223);
    $225 = Math_fround(HEAPF32[$7>>2]);
    $226 = Math_fround(HEAPF32[$213>>2]);
    $227 = Math_fround($225 * $226);
    $228 = Math_fround($224 + $227);
    $229 = Math_fround(HEAPF32[$8>>2]);
    $230 = Math_fround(HEAPF32[$218>>2]);
    $231 = Math_fround($229 * $230);
    $232 = Math_fround($228 + $231);
    $233 = (($$3) + 4|0);
    HEAPF32[$233>>2] = $232;
    $234 = Math_fround(HEAPF32[$10>>2]);
    $235 = Math_fround(HEAPF32[$208>>2]);
    $236 = Math_fround($234 * $235);
    $237 = Math_fround(HEAPF32[$11>>2]);
    $238 = Math_fround(HEAPF32[$213>>2]);
    $239 = Math_fround($237 * $238);
    $240 = Math_fround($236 + $239);
    $241 = Math_fround(HEAPF32[$12>>2]);
    $242 = Math_fround(HEAPF32[$218>>2]);
    $243 = Math_fround($241 * $242);
    $244 = Math_fround($240 + $243);
    $245 = (($$3) + 8|0);
    HEAPF32[$245>>2] = $244;
    $246 = (($$0213) + ($$sum)|0);
    $247 = Math_fround(HEAPF32[$246>>2]);
    $248 = (($$3) + 12|0);
    HEAPF32[$248>>2] = $247;
    $249 = (($$3) + 16|0);
    $$4 = $249;
   } else {
    $$4 = $$3;
   }
   $250 = (($$0213) + ($vertexStride)|0);
   $251 = (($252) + -1)|0;
   $253 = ($252|0)==(0);
   if ($253) {
    break;
   } else {
    $$014 = $$4;$$0213 = $250;$$0312 = $$14;$252 = $251;
   }
  }
  STACKTOP = sp;return;
 }
}
function __Z43TransformVerticesStridedSeparatePointersREFPhRK10Matrix4x4fj14StrideIteratorI8Vector3fES5_S3_I11ColorRGBA32ES3_I8Vector2fES9_S3_I8Vector4fE($dstData,$m,$vertexCount,$inPos,$inNormal,$inColor,$inTexCoord0,$inTexCoord1,$inTangent) {
 $dstData = $dstData|0;
 $m = $m|0;
 $vertexCount = $vertexCount|0;
 $inPos = $inPos|0;
 $inNormal = $inNormal|0;
 $inColor = $inColor|0;
 $inTexCoord0 = $inTexCoord0|0;
 $inTexCoord1 = $inTexCoord1|0;
 $inTangent = $inTangent|0;
 var $$0$be = 0, $$02 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$in = 0, $$pre = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0);
 var $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0);
 var $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0);
 var $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0);
 var $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $nm = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $nm = sp;
 __Z13CopyMatrixREFPKfPf($m,$nm);
 $0 = Math_fround(HEAPF32[$m>>2]);
 $1 = (($m) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($m) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($0 * $0);
 $6 = Math_fround($2 * $2);
 $7 = Math_fround($5 + $6);
 $8 = Math_fround($4 * $4);
 $9 = Math_fround($7 + $8);
 $10 = (Math_fround(Math_sqrt((Math_fround($9)))));
 $11 = $10 > Math_fround(9.99999997475242707878E-7);
 if ($11) {
  $12 = Math_fround(Math_fround(1.0) / $10);
  $15 = $12;
 } else {
  $15 = Math_fround(1.0);
 }
 $13 = Math_fround(HEAPF32[$nm>>2]);
 $14 = Math_fround($15 * $13);
 HEAPF32[$nm>>2] = $14;
 $16 = (($nm) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $17);
 HEAPF32[$16>>2] = $18;
 $19 = (($nm) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($15 * $20);
 HEAPF32[$19>>2] = $21;
 $22 = (($nm) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($15 * $23);
 HEAPF32[$22>>2] = $24;
 $25 = (($nm) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($15 * $26);
 HEAPF32[$25>>2] = $27;
 $28 = (($nm) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($15 * $29);
 HEAPF32[$28>>2] = $30;
 $31 = (($nm) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($15 * $32);
 HEAPF32[$31>>2] = $33;
 $34 = (($nm) + 36|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($15 * $35);
 HEAPF32[$34>>2] = $36;
 $37 = (($nm) + 40|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($15 * $38);
 HEAPF32[$37>>2] = $39;
 $40 = ($vertexCount|0)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($m) + 16|0);
 $42 = (($m) + 32|0);
 $43 = (($m) + 48|0);
 $44 = (($m) + 20|0);
 $45 = (($m) + 36|0);
 $46 = (($m) + 52|0);
 $47 = (($m) + 24|0);
 $48 = (($m) + 40|0);
 $49 = (($m) + 56|0);
 $50 = (($inPos) + 4|0);
 $51 = (($inTangent) + 4|0);
 $52 = (($inTexCoord1) + 4|0);
 $53 = (($inTexCoord0) + 4|0);
 $54 = (($inColor) + 4|0);
 $55 = (($inNormal) + 4|0);
 $$02 = $dstData;$$in = $vertexCount;$60 = $0;
 while(1) {
  $56 = (($$in) + -1)|0;
  $57 = HEAP32[$inPos>>2]|0;
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($60 * $58);
  $61 = Math_fround(HEAPF32[$41>>2]);
  $62 = (($57) + 4|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($61 * $63);
  $65 = Math_fround($59 + $64);
  $66 = Math_fround(HEAPF32[$42>>2]);
  $67 = (($57) + 8|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = Math_fround($66 * $68);
  $70 = Math_fround($65 + $69);
  $71 = Math_fround(HEAPF32[$43>>2]);
  $72 = Math_fround($71 + $70);
  HEAPF32[$$02>>2] = $72;
  $73 = Math_fround(HEAPF32[$1>>2]);
  $74 = Math_fround(HEAPF32[$57>>2]);
  $75 = Math_fround($73 * $74);
  $76 = Math_fround(HEAPF32[$44>>2]);
  $77 = Math_fround(HEAPF32[$62>>2]);
  $78 = Math_fround($76 * $77);
  $79 = Math_fround($75 + $78);
  $80 = Math_fround(HEAPF32[$45>>2]);
  $81 = Math_fround(HEAPF32[$67>>2]);
  $82 = Math_fround($80 * $81);
  $83 = Math_fround($79 + $82);
  $84 = Math_fround(HEAPF32[$46>>2]);
  $85 = Math_fround($84 + $83);
  $86 = (($$02) + 4|0);
  HEAPF32[$86>>2] = $85;
  $87 = Math_fround(HEAPF32[$3>>2]);
  $88 = Math_fround(HEAPF32[$57>>2]);
  $89 = Math_fround($87 * $88);
  $90 = Math_fround(HEAPF32[$47>>2]);
  $91 = Math_fround(HEAPF32[$62>>2]);
  $92 = Math_fround($90 * $91);
  $93 = Math_fround($89 + $92);
  $94 = Math_fround(HEAPF32[$48>>2]);
  $95 = Math_fround(HEAPF32[$67>>2]);
  $96 = Math_fround($94 * $95);
  $97 = Math_fround($93 + $96);
  $98 = Math_fround(HEAPF32[$49>>2]);
  $99 = Math_fround($98 + $97);
  $100 = (($$02) + 8|0);
  HEAPF32[$100>>2] = $99;
  $101 = (($$02) + 12|0);
  $102 = HEAP32[$50>>2]|0;
  $103 = (($57) + ($102)|0);
  HEAP32[$inPos>>2] = $103;
  $104 = HEAP32[$inNormal>>2]|0;
  $105 = ($104|0)==(0|0);
  if ($105) {
   $$1 = $101;
  } else {
   $106 = Math_fround(HEAPF32[$nm>>2]);
   $107 = Math_fround(HEAPF32[$104>>2]);
   $108 = Math_fround($106 * $107);
   $109 = Math_fround(HEAPF32[$22>>2]);
   $110 = (($104) + 4|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = Math_fround($109 * $111);
   $113 = Math_fround($108 + $112);
   $114 = Math_fround(HEAPF32[$31>>2]);
   $115 = (($104) + 8|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   $117 = Math_fround($114 * $116);
   $118 = Math_fround($113 + $117);
   HEAPF32[$101>>2] = $118;
   $119 = Math_fround(HEAPF32[$16>>2]);
   $120 = Math_fround(HEAPF32[$104>>2]);
   $121 = Math_fround($119 * $120);
   $122 = Math_fround(HEAPF32[$25>>2]);
   $123 = Math_fround(HEAPF32[$110>>2]);
   $124 = Math_fround($122 * $123);
   $125 = Math_fround($121 + $124);
   $126 = Math_fround(HEAPF32[$34>>2]);
   $127 = Math_fround(HEAPF32[$115>>2]);
   $128 = Math_fround($126 * $127);
   $129 = Math_fround($125 + $128);
   $130 = (($$02) + 16|0);
   HEAPF32[$130>>2] = $129;
   $131 = Math_fround(HEAPF32[$19>>2]);
   $132 = Math_fround(HEAPF32[$104>>2]);
   $133 = Math_fround($131 * $132);
   $134 = Math_fround(HEAPF32[$28>>2]);
   $135 = Math_fround(HEAPF32[$110>>2]);
   $136 = Math_fround($134 * $135);
   $137 = Math_fround($133 + $136);
   $138 = Math_fround(HEAPF32[$37>>2]);
   $139 = Math_fround(HEAPF32[$115>>2]);
   $140 = Math_fround($138 * $139);
   $141 = Math_fround($137 + $140);
   $142 = (($$02) + 20|0);
   HEAPF32[$142>>2] = $141;
   $143 = (($$02) + 24|0);
   $144 = HEAP32[$55>>2]|0;
   $145 = (($104) + ($144)|0);
   HEAP32[$inNormal>>2] = $145;
   $$1 = $143;
  }
  $146 = HEAP32[$inColor>>2]|0;
  $147 = ($146|0)==(0|0);
  if ($147) {
   $$2 = $$1;
  } else {
   $148 = HEAPU8[$146>>0]|(HEAPU8[$146+1>>0]<<8)|(HEAPU8[$146+2>>0]<<16)|(HEAPU8[$146+3>>0]<<24);
   HEAP8[$$1>>0]=$148&255;HEAP8[$$1+1>>0]=($148>>8)&255;HEAP8[$$1+2>>0]=($148>>16)&255;HEAP8[$$1+3>>0]=$148>>24;
   $149 = (($$1) + 4|0);
   $150 = HEAP32[$54>>2]|0;
   $151 = HEAP32[$inColor>>2]|0;
   $152 = (($151) + ($150)|0);
   HEAP32[$inColor>>2] = $152;
   $$2 = $149;
  }
  $153 = HEAP32[$inTexCoord0>>2]|0;
  $154 = ($153|0)==(0|0);
  if ($154) {
   $$3 = $$2;
  } else {
   $155 = $153;
   $156 = $155;
   $157 = HEAPU8[$156>>0]|(HEAPU8[$156+1>>0]<<8)|(HEAPU8[$156+2>>0]<<16)|(HEAPU8[$156+3>>0]<<24);
   $158 = (($155) + 4)|0;
   $159 = $158;
   $160 = HEAPU8[$159>>0]|(HEAPU8[$159+1>>0]<<8)|(HEAPU8[$159+2>>0]<<16)|(HEAPU8[$159+3>>0]<<24);
   $161 = $$2;
   $162 = $161;
   HEAP8[$162>>0]=$157&255;HEAP8[$162+1>>0]=($157>>8)&255;HEAP8[$162+2>>0]=($157>>16)&255;HEAP8[$162+3>>0]=$157>>24;
   $163 = (($161) + 4)|0;
   $164 = $163;
   HEAP8[$164>>0]=$160&255;HEAP8[$164+1>>0]=($160>>8)&255;HEAP8[$164+2>>0]=($160>>16)&255;HEAP8[$164+3>>0]=$160>>24;
   $165 = (($$2) + 8|0);
   $166 = HEAP32[$53>>2]|0;
   $167 = HEAP32[$inTexCoord0>>2]|0;
   $168 = (($167) + ($166)|0);
   HEAP32[$inTexCoord0>>2] = $168;
   $$3 = $165;
  }
  $169 = HEAP32[$inTexCoord1>>2]|0;
  $170 = ($169|0)==(0|0);
  if ($170) {
   $$4 = $$3;
  } else {
   $171 = $169;
   $172 = $171;
   $173 = HEAPU8[$172>>0]|(HEAPU8[$172+1>>0]<<8)|(HEAPU8[$172+2>>0]<<16)|(HEAPU8[$172+3>>0]<<24);
   $174 = (($171) + 4)|0;
   $175 = $174;
   $176 = HEAPU8[$175>>0]|(HEAPU8[$175+1>>0]<<8)|(HEAPU8[$175+2>>0]<<16)|(HEAPU8[$175+3>>0]<<24);
   $177 = $$3;
   $178 = $177;
   HEAP8[$178>>0]=$173&255;HEAP8[$178+1>>0]=($173>>8)&255;HEAP8[$178+2>>0]=($173>>16)&255;HEAP8[$178+3>>0]=$173>>24;
   $179 = (($177) + 4)|0;
   $180 = $179;
   HEAP8[$180>>0]=$176&255;HEAP8[$180+1>>0]=($176>>8)&255;HEAP8[$180+2>>0]=($176>>16)&255;HEAP8[$180+3>>0]=$176>>24;
   $181 = (($$3) + 8|0);
   $182 = HEAP32[$52>>2]|0;
   $183 = HEAP32[$inTexCoord1>>2]|0;
   $184 = (($183) + ($182)|0);
   HEAP32[$inTexCoord1>>2] = $184;
   $$4 = $181;
  }
  $185 = HEAP32[$inTangent>>2]|0;
  $186 = ($185|0)==(0|0);
  if ($186) {
   $$0$be = $$4;
  } else {
   $187 = Math_fround(HEAPF32[$nm>>2]);
   $188 = Math_fround(HEAPF32[$185>>2]);
   $189 = Math_fround($187 * $188);
   $190 = Math_fround(HEAPF32[$22>>2]);
   $191 = (($185) + 4|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = Math_fround($190 * $192);
   $194 = Math_fround($189 + $193);
   $195 = Math_fround(HEAPF32[$31>>2]);
   $196 = (($185) + 8|0);
   $197 = Math_fround(HEAPF32[$196>>2]);
   $198 = Math_fround($195 * $197);
   $199 = Math_fround($194 + $198);
   HEAPF32[$$4>>2] = $199;
   $200 = Math_fround(HEAPF32[$16>>2]);
   $201 = Math_fround(HEAPF32[$185>>2]);
   $202 = Math_fround($200 * $201);
   $203 = Math_fround(HEAPF32[$25>>2]);
   $204 = Math_fround(HEAPF32[$191>>2]);
   $205 = Math_fround($203 * $204);
   $206 = Math_fround($202 + $205);
   $207 = Math_fround(HEAPF32[$34>>2]);
   $208 = Math_fround(HEAPF32[$196>>2]);
   $209 = Math_fround($207 * $208);
   $210 = Math_fround($206 + $209);
   $211 = (($$4) + 4|0);
   HEAPF32[$211>>2] = $210;
   $212 = Math_fround(HEAPF32[$19>>2]);
   $213 = Math_fround(HEAPF32[$185>>2]);
   $214 = Math_fround($212 * $213);
   $215 = Math_fround(HEAPF32[$28>>2]);
   $216 = Math_fround(HEAPF32[$191>>2]);
   $217 = Math_fround($215 * $216);
   $218 = Math_fround($214 + $217);
   $219 = Math_fround(HEAPF32[$37>>2]);
   $220 = Math_fround(HEAPF32[$196>>2]);
   $221 = Math_fround($219 * $220);
   $222 = Math_fround($218 + $221);
   $223 = (($$4) + 8|0);
   HEAPF32[$223>>2] = $222;
   $224 = (($185) + 12|0);
   $225 = Math_fround(HEAPF32[$224>>2]);
   $226 = (($$4) + 12|0);
   HEAPF32[$226>>2] = $225;
   $227 = (($$4) + 16|0);
   $228 = HEAP32[$51>>2]|0;
   $229 = (($185) + ($228)|0);
   HEAP32[$inTangent>>2] = $229;
   $$0$be = $227;
  }
  $230 = ($56|0)==(0);
  if ($230) {
   break;
  }
  $$pre = Math_fround(HEAPF32[$m>>2]);
  $$02 = $$0$be;$$in = $56;$60 = $$pre;
 }
 STACKTOP = sp;return;
}
function __ZN18VertexChannelsInfoC2ERA8_K11ChannelInfo($this,$src) {
 $this = $this|0;
 $src = $src|0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$this+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$this+0>>2]=HEAP32[$src+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$src+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$src+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$src+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$src+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$src+20>>2]|0;HEAP32[$this+24>>2]=HEAP32[$src+24>>2]|0;HEAP32[$this+28>>2]=HEAP32[$src+28>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK18VertexChannelsInfoltERKS_($this,$rhs) {
 $this = $this|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_memcmp($this,$rhs,32)|0);
 $1 = ($0|0)<(0);
 STACKTOP = sp;return ($1|0);
}
function __ZN10VertexData8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $channels = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $0 = sp;
 $size$i$i$i$i = sp + 4|0;
 $p$i$i$i = sp + 8|0;
 $channels = sp + 16|0;
 $1 = (($this) + 88|0);
 $2 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,588192,$2,$1,1);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($this) + 92|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,588216,$2,$9,1);
 $10 = HEAP32[$3>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$6>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 HEAP32[$channels>>2] = 0;
 $14 = (($channels) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($channels) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($channels) + 4|0);
 HEAP32[$16>>2] = 61;
 $17 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($transfer|0),(588232|0),($17|0),($channels|0),1);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  HEAP32[$p$i$i$i>>2] = 0;
  __THREW__ = 0;
  invoke_viiiii(87,($transfer|0),(588360|0),(588360|0),($size$i$i$i$i|0),0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   __THREW__ = 0;
   invoke_viiiii(86,($transfer|0),(588312|0),(588368|0),($p$i$i$i|0),0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    invoke_vii(2691,($p$i$i$i|0),($transfer|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __THREW__ = 0;
     invoke_vi(3390,($transfer|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      invoke_vi(3391,($transfer|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vi(3390,($transfer|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        $40 = (($this) + 96|0);
        __THREW__ = 0;
        invoke_viiii(353,($transfer|0),($40|0),(588288|0),1);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if (!($42)) {
         $43 = HEAP32[$40>>2]|0;
         $44 = (($this) + 84|0);
         $45 = HEAP32[$44>>2]|0;
         __THREW__ = 0;
         invoke_viiii(354,($transfer|0),($43|0),($45|0),0);
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if (!($47)) {
          $48 = HEAP32[$15>>2]|0;
          $49 = ($48|0)>(-1);
          if (!($49)) {
           STACKTOP = sp;return;
          }
          $50 = HEAP32[$channels>>2]|0;
          $51 = HEAP32[$16>>2]|0;
          HEAP32[$0>>2] = $51;
          ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
          __Z19free_alloc_internalPv10MemLabelId($50,$$byval_copy1);
          HEAP32[$channels>>2] = 0;
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 $34 = HEAP32[$15>>2]|0;
 $35 = ($34|0)>(-1);
 if (!($35)) {
  ___resumeException($32|0);
  // unreachable;
 }
 $36 = HEAP32[$channels>>2]|0;
 $37 = HEAP32[$16>>2]|0;
 HEAP32[$0>>2] = $37;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($36|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $52 = ___cxa_find_matching_catch(0|0)|0;
  $53 = tempRet0;
  ___clang_call_terminate($52);
  // unreachable;
 }
 HEAP32[$channels>>2] = 0;
 ___resumeException($32|0);
 // unreachable;
}
function __ZN14VertexDataInfo13UpdateStreamsEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$vertexCount,$createChannels,$removeChannels,$streams,$channels) {
 $this = $this|0;
 $vertexCount = $vertexCount|0;
 $createChannels = $createChannels|0;
 $removeChannels = $removeChannels|0;
 $streams = $streams|0;
 $channels = $channels|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert8 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $$pre5 = 0, $$pre7 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $exitcond = 0, $or$cond = 0, $s$02 = 0, $streamOffset$04 = 0, $streamOffset$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $removeChannels ^ -1;
 $4 = $2 & $3;
 $5 = $4 | $createChannels;
 $6 = (($this) + 92|0);
 HEAP32[$6>>2] = $vertexCount;
 HEAP32[$1>>2] = 0;
 $7 = (($this) + 80|0);
 HEAP32[$7>>2] = 0;
 $s$02 = 0;$streamOffset$04 = 0;
 while(1) {
  $11 = ((($this) + (($s$02*12)|0)|0) + 32|0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
  ;HEAP32[$11+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$0+8>>2]|0;
  $12 = (($streams) + ($s$02<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 & $5;
  HEAP32[$11>>2] = $14;
  $15 = ($14|0)==(0);
  if ($15) {
   $streamOffset$1 = $streamOffset$04;
  } else {
   $16 = HEAP32[$1>>2]|0;
   $17 = $16 | $14;
   HEAP32[$1>>2] = $17;
   $18 = HEAP32[$11>>2]|0;
   $19 = ($18|0)==(0);
   if ($19) {
    $$pre10 = ((($this) + (($s$02*12)|0)|0) + 42|0);
    $$pre$phiZ2D = $$pre10;
   } else {
    $20 = $s$02&255;
    $21 = ((($this) + (($s$02*12)|0)|0) + 42|0);
    $23 = $18;$24 = 1;$27 = 0;
    while(1) {
     $22 = $23 & $24;
     $25 = ($22|0)==(0);
     if ($25) {
      $54 = $23;
     } else {
      $26 = (($this) + ($27<<2)|0);
      HEAP8[$26>>0] = $20;
      $28 = HEAP8[$21>>0]|0;
      $29 = ((($this) + ($27<<2)|0) + 1|0);
      HEAP8[$29>>0] = $28;
      $30 = $24 & $createChannels;
      $31 = ($30|0)==(0);
      if ($31) {
       $$phi$trans$insert = ((($this) + ($27<<2)|0) + 2|0);
       $$pre7 = HEAP8[$$phi$trans$insert>>0]|0;
       $$phi$trans$insert8 = ((($this) + ($27<<2)|0) + 3|0);
       $$pre9 = HEAP8[$$phi$trans$insert8>>0]|0;
       $39 = $$pre7;$44 = $$pre9;$47 = $28;
      } else {
       $32 = (($channels) + ($27<<1)|0);
       $33 = HEAP8[$32>>0]|0;
       $34 = ((($this) + ($27<<2)|0) + 2|0);
       HEAP8[$34>>0] = $33;
       $35 = ((($channels) + ($27<<1)|0) + 1|0);
       $36 = HEAP8[$35>>0]|0;
       $37 = ((($this) + ($27<<2)|0) + 3|0);
       HEAP8[$37>>0] = $36;
       $$pre5 = HEAP8[$21>>0]|0;
       $39 = $33;$44 = $36;$47 = $$pre5;
      }
      $38 = $39&255;
      $40 = (588304 + ($38)|0);
      $41 = HEAP8[$40>>0]|0;
      $42 = $41&255;
      $43 = $44&255;
      $45 = Math_imul($42, $43)|0;
      $46 = $47&255;
      $48 = (($46) + ($45))|0;
      $49 = $48&255;
      HEAP8[$21>>0] = $49;
      $$pre = HEAP32[$11>>2]|0;
      $54 = $$pre;
     }
     $50 = (($27) + 1)|0;
     $51 = $24 << 1;
     $52 = ($50|0)<(8);
     $53 = ($51>>>0)<=($54>>>0);
     $or$cond = $52 & $53;
     if ($or$cond) {
      $23 = $54;$24 = $51;$27 = $50;
     } else {
      $$pre$phiZ2D = $21;
      break;
     }
    }
   }
   $55 = (($streamOffset$04) + 15)|0;
   $56 = $55 & -16;
   $57 = ((($this) + (($s$02*12)|0)|0) + 36|0);
   HEAP32[$57>>2] = $56;
   $58 = HEAP8[$$pre$phiZ2D>>0]|0;
   $59 = $58&255;
   $60 = Math_imul($59, $vertexCount)|0;
   $61 = (($60) + ($56))|0;
   $62 = HEAP32[$7>>2]|0;
   $63 = (($62) + ($59))|0;
   HEAP32[$7>>2] = $63;
   $streamOffset$1 = $61;
  }
  $64 = (($s$02) + 1)|0;
  $exitcond = ($64|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $s$02 = $64;$streamOffset$04 = $streamOffset$1;
  }
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($10) {
  HEAP32[$this>>2] = 0;
 }
 $65 = $8 & 2;
 $66 = ($65|0)==(0);
 if ($66) {
  $67 = (($this) + 4|0);
  HEAP32[$67>>2] = 0;
 }
 $68 = $8 & 4;
 $69 = ($68|0)==(0);
 if ($69) {
  $70 = (($this) + 8|0);
  HEAP32[$70>>2] = 0;
 }
 $71 = $8 & 8;
 $72 = ($71|0)==(0);
 if ($72) {
  $73 = (($this) + 12|0);
  HEAP32[$73>>2] = 0;
 }
 $74 = $8 & 16;
 $75 = ($74|0)==(0);
 if ($75) {
  $76 = (($this) + 16|0);
  HEAP32[$76>>2] = 0;
 }
 $77 = $8 & 32;
 $78 = ($77|0)==(0);
 if ($78) {
  $79 = (($this) + 20|0);
  HEAP32[$79>>2] = 0;
 }
 $80 = $8 & 64;
 $81 = ($80|0)==(0);
 if ($81) {
  $82 = (($this) + 24|0);
  HEAP32[$82>>2] = 0;
 }
 $83 = $8 & 128;
 $84 = ($83|0)==(0);
 if (!($84)) {
  $86 = (($this) + 96|0);
  HEAP32[$86>>2] = $streamOffset$1;
  STACKTOP = sp;return;
 }
 $85 = (($this) + 28|0);
 HEAP32[$85>>2] = 0;
 $86 = (($this) + 96|0);
 HEAP32[$86>>2] = $streamOffset$1;
 STACKTOP = sp;return;
}
function __ZNK14VertexDataInfo17GetChannelsLayoutEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$agg$result+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $0 = (($this) + 2|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = (($this) + 3|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = ($4 << 8)&65535;
 $6 = $1&255;
 $7 = $5 | $6;
 HEAP8[$agg$result>>0]=$7&255;HEAP8[$agg$result+1>>0]=$7>>8;
 $8 = (($this) + 6|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = (($this) + 7|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = (($agg$result) + 2|0);
 $13 = $11&255;
 $14 = ($13 << 8)&65535;
 $15 = $9&255;
 $16 = $14 | $15;
 HEAP8[$12>>0]=$16&255;HEAP8[$12+1>>0]=$16>>8;
 $17 = (($this) + 10|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = (($this) + 11|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = (($agg$result) + 4|0);
 $22 = $20&255;
 $23 = ($22 << 8)&65535;
 $24 = $18&255;
 $25 = $23 | $24;
 HEAP8[$21>>0]=$25&255;HEAP8[$21+1>>0]=$25>>8;
 $26 = (($this) + 14|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = (($this) + 15|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = (($agg$result) + 6|0);
 $31 = $29&255;
 $32 = ($31 << 8)&65535;
 $33 = $27&255;
 $34 = $32 | $33;
 HEAP8[$30>>0]=$34&255;HEAP8[$30+1>>0]=$34>>8;
 $35 = (($this) + 18|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = (($this) + 19|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = (($agg$result) + 8|0);
 $40 = $38&255;
 $41 = ($40 << 8)&65535;
 $42 = $36&255;
 $43 = $41 | $42;
 HEAP8[$39>>0]=$43&255;HEAP8[$39+1>>0]=$43>>8;
 $44 = (($this) + 22|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = (($this) + 23|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = (($agg$result) + 10|0);
 $49 = $47&255;
 $50 = ($49 << 8)&65535;
 $51 = $45&255;
 $52 = $50 | $51;
 HEAP8[$48>>0]=$52&255;HEAP8[$48+1>>0]=$52>>8;
 $53 = (($this) + 26|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = (($this) + 27|0);
 $56 = HEAP8[$55>>0]|0;
 $57 = (($agg$result) + 12|0);
 $58 = $56&255;
 $59 = ($58 << 8)&65535;
 $60 = $54&255;
 $61 = $59 | $60;
 HEAP8[$57>>0]=$61&255;HEAP8[$57+1>>0]=$61>>8;
 $62 = (($this) + 30|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = (($this) + 31|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = (($agg$result) + 14|0);
 $67 = $65&255;
 $68 = ($67 << 8)&65535;
 $69 = $63&255;
 $70 = $68 | $69;
 HEAP8[$66>>0]=$70&255;HEAP8[$66+1>>0]=$70>>8;
 STACKTOP = sp;return;
}
function __ZN10VertexData8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy3 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $allChannelsMask$1 = 0, $allChannelsMask$1$1 = 0, $allChannelsMask$1$2 = 0, $allChannelsMask$1$3 = 0, $allChannelsMask$1$4 = 0, $allChannelsMask$1$5 = 0, $allChannelsMask$1$6 = 0, $allChannelsMask$1$714 = 0, $channels = 0, $converter$i$i = 0, $scevgep2$i = 0, $streamsLayout = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy3 = sp + 48|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $channels = sp + 8|0;
 $streamsLayout = sp + 24|0;
 $1 = sp + 56|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = (($this) + 88|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$4,588192,0);
 $5 = (($this) + 92|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$5,588216,0);
 HEAP32[$channels>>2] = 0;
 $6 = (($channels) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($channels) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = (($channels) + 4|0);
 HEAP32[$8>>2] = 61;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $10 = (invoke_iiiiii(192,($transfer|0),(588232|0),($9|0),($converter$i$i|0),1)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if (!($12)) {
   $13 = ($10|0)==(0);
   if (!($13)) {
    $14 = ($10|0)>(0);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(1722,($transfer|0),($channels|0),0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
    } else {
     $17 = HEAP32[$converter$i$i>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      __THREW__ = 0;
      (invoke_iii($17|0,($channels|0),($transfer|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($transfer|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
   }
   $31 = HEAP32[$6>>2]|0;
   if ((($31|0) == 6)) {
    $33 = HEAP32[$channels>>2]|0;
    _memmove(($this|0),($33|0),20)|0;
    $scevgep2$i = (($this) + 20|0);
    $34 = $scevgep2$i;
    $35 = $34;
    HEAP32[$35>>2] = 0;
    $36 = (($34) + 4)|0;
    $37 = $36;
    HEAP32[$37>>2] = 0;
    $38 = (($33) + 20|0);
    $39 = (($this) + 28|0);
    $40 = HEAP32[$38>>2]|0;
    HEAP32[$39>>2] = $40;
    $41 = (($this) + 10|0);
    $42 = HEAP8[$41>>0]|0;
    $43 = ($42<<24>>24)==(2);
    if ($43) {
     $44 = (($this) + 11|0);
     HEAP8[$44>>0] = 4;
    }
   } else if ((($31|0) == 0)) {
    $45 = HEAP32[$4>>2]|0;
    $46 = $45 & 31;
    $47 = $45 << 2;
    $48 = $47 & 128;
    $49 = $48 | $46;
    HEAP32[$4>>2] = $49;
    ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
   } else if ((($31|0) == 8)) {
    $32 = HEAP32[$channels>>2]|0;
    _memmove(($this|0),($32|0),32)|0;
   } else {
    __THREW__ = 0;
    invoke_viiiiiiii(21,(588248|0),0,(588280|0),121,1,0,0,(0|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    HEAP32[$4>>2] = 0;
   }
   ;HEAP32[$streamsLayout+0>>2]=0|0;HEAP32[$streamsLayout+4>>2]=0|0;HEAP32[$streamsLayout+8>>2]=0|0;HEAP32[$streamsLayout+12>>2]=0|0;
   $52 = (($this) + 3|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = ($53<<24>>24)==(0);
   if ($54) {
    $allChannelsMask$1 = 0;
   } else {
    $55 = HEAP8[$this>>0]|0;
    $56 = $55&255;
    $57 = (($streamsLayout) + ($56<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = $58 | 1;
    HEAP32[$57>>2] = $59;
    $allChannelsMask$1 = 1;
   }
   $60 = (($this) + 7|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = ($61<<24>>24)==(0);
   if ($62) {
    $allChannelsMask$1$1 = $allChannelsMask$1;
   } else {
    $155 = (($this) + 4|0);
    $156 = HEAP8[$155>>0]|0;
    $157 = $156&255;
    $158 = (($streamsLayout) + ($157<<2)|0);
    $159 = HEAP32[$158>>2]|0;
    $160 = $159 | 2;
    HEAP32[$158>>2] = $160;
    $161 = $allChannelsMask$1 | 2;
    $allChannelsMask$1$1 = $161;
   }
   $162 = (($this) + 11|0);
   $80 = HEAP8[$162>>0]|0;
   $163 = ($80<<24>>24)==(0);
   if ($163) {
    $allChannelsMask$1$2 = $allChannelsMask$1$1;
   } else {
    $164 = (($this) + 8|0);
    $165 = HEAP8[$164>>0]|0;
    $166 = $165&255;
    $167 = (($streamsLayout) + ($166<<2)|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = $168 | 4;
    HEAP32[$167>>2] = $169;
    $170 = $allChannelsMask$1$1 | 4;
    $allChannelsMask$1$2 = $170;
   }
   $171 = (($this) + 15|0);
   $88 = HEAP8[$171>>0]|0;
   $172 = ($88<<24>>24)==(0);
   if ($172) {
    $allChannelsMask$1$3 = $allChannelsMask$1$2;
   } else {
    $173 = (($this) + 12|0);
    $174 = HEAP8[$173>>0]|0;
    $175 = $174&255;
    $176 = (($streamsLayout) + ($175<<2)|0);
    $177 = HEAP32[$176>>2]|0;
    $178 = $177 | 8;
    HEAP32[$176>>2] = $178;
    $179 = $allChannelsMask$1$2 | 8;
    $allChannelsMask$1$3 = $179;
   }
   $180 = (($this) + 19|0);
   $96 = HEAP8[$180>>0]|0;
   $181 = ($96<<24>>24)==(0);
   if ($181) {
    $allChannelsMask$1$4 = $allChannelsMask$1$3;
   } else {
    $182 = (($this) + 16|0);
    $183 = HEAP8[$182>>0]|0;
    $184 = $183&255;
    $185 = (($streamsLayout) + ($184<<2)|0);
    $186 = HEAP32[$185>>2]|0;
    $187 = $186 | 16;
    HEAP32[$185>>2] = $187;
    $188 = $allChannelsMask$1$3 | 16;
    $allChannelsMask$1$4 = $188;
   }
   $189 = (($this) + 23|0);
   $104 = HEAP8[$189>>0]|0;
   $190 = ($104<<24>>24)==(0);
   if ($190) {
    $allChannelsMask$1$5 = $allChannelsMask$1$4;
   } else {
    $191 = (($this) + 20|0);
    $192 = HEAP8[$191>>0]|0;
    $193 = $192&255;
    $194 = (($streamsLayout) + ($193<<2)|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = $195 | 32;
    HEAP32[$194>>2] = $196;
    $197 = $allChannelsMask$1$4 | 32;
    $allChannelsMask$1$5 = $197;
   }
   $198 = (($this) + 27|0);
   $112 = HEAP8[$198>>0]|0;
   $199 = ($112<<24>>24)==(0);
   if ($199) {
    $allChannelsMask$1$6 = $allChannelsMask$1$5;
   } else {
    $200 = (($this) + 24|0);
    $201 = HEAP8[$200>>0]|0;
    $202 = $201&255;
    $203 = (($streamsLayout) + ($202<<2)|0);
    $204 = HEAP32[$203>>2]|0;
    $205 = $204 | 64;
    HEAP32[$203>>2] = $205;
    $206 = $allChannelsMask$1$5 | 64;
    $allChannelsMask$1$6 = $206;
   }
   $207 = (($this) + 31|0);
   $120 = HEAP8[$207>>0]|0;
   $208 = ($120<<24>>24)==(0);
   if ($208) {
    $217 = ($allChannelsMask$1$6|0)==(0);
    $128 = HEAP32[$5>>2]|0;
    if ($217) {
     $126 = HEAP32[$4>>2]|0;
     $127 = $126 ^ -1;
     __ZN14VertexDataInfo13UpdateStreamsEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$128,$126,$127,588144,588176);
    } else {
     $125 = $128;$allChannelsMask$1$714 = $allChannelsMask$1$6;
     label = 21;
    }
   } else {
    $209 = (($this) + 28|0);
    $210 = HEAP8[$209>>0]|0;
    $211 = $210&255;
    $212 = (($streamsLayout) + ($211<<2)|0);
    $213 = HEAP32[$212>>2]|0;
    $214 = $213 | 128;
    HEAP32[$212>>2] = $214;
    $215 = $allChannelsMask$1$6 | 128;
    $216 = HEAP32[$5>>2]|0;
    $125 = $216;$allChannelsMask$1$714 = $215;
    label = 21;
   }
   if ((label|0) == 21) {
    ;HEAP16[$1+0>>1]=0|0;HEAP16[$1+2>>1]=0|0;HEAP16[$1+4>>1]=0|0;HEAP16[$1+6>>1]=0|0;HEAP16[$1+8>>1]=0|0;HEAP16[$1+10>>1]=0|0;
    $63 = (($this) + 2|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = $53&255;
    $66 = ($65 << 8)&65535;
    $67 = $64&255;
    $68 = $66 | $67;
    HEAP16[$1>>1] = $68;
    $69 = (($this) + 6|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = (($1) + 2|0);
    $72 = $61&255;
    $73 = ($72 << 8)&65535;
    $74 = $70&255;
    $75 = $73 | $74;
    HEAP16[$71>>1] = $75;
    $76 = (($this) + 10|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = (($1) + 4|0);
    $79 = $80&255;
    $81 = ($79 << 8)&65535;
    $82 = $77&255;
    $83 = $81 | $82;
    HEAP16[$78>>1] = $83;
    $84 = (($this) + 14|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = (($1) + 6|0);
    $87 = $88&255;
    $89 = ($87 << 8)&65535;
    $90 = $85&255;
    $91 = $89 | $90;
    HEAP16[$86>>1] = $91;
    $92 = (($this) + 18|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = (($1) + 8|0);
    $95 = $96&255;
    $97 = ($95 << 8)&65535;
    $98 = $93&255;
    $99 = $97 | $98;
    HEAP16[$94>>1] = $99;
    $100 = (($this) + 22|0);
    $101 = HEAP8[$100>>0]|0;
    $102 = (($1) + 10|0);
    $103 = $104&255;
    $105 = ($103 << 8)&65535;
    $106 = $101&255;
    $107 = $105 | $106;
    HEAP16[$102>>1] = $107;
    $108 = (($this) + 26|0);
    $109 = HEAP8[$108>>0]|0;
    $110 = (($1) + 12|0);
    $111 = $112&255;
    $113 = ($111 << 8)&65535;
    $114 = $109&255;
    $115 = $113 | $114;
    HEAP16[$110>>1] = $115;
    $116 = (($this) + 30|0);
    $117 = HEAP8[$116>>0]|0;
    $118 = (($1) + 14|0);
    $119 = $120&255;
    $121 = ($119 << 8)&65535;
    $122 = $117&255;
    $123 = $121 | $122;
    HEAP16[$118>>1] = $123;
    $124 = $allChannelsMask$1$714 ^ -1;
    __ZN14VertexDataInfo13UpdateStreamsEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$125,$allChannelsMask$1$714,$124,$streamsLayout,$1);
   }
   $129 = (($this) + 96|0);
   __THREW__ = 0;
   invoke_viiii(355,($transfer|0),($129|0),(588288|0),1);
   $130 = __THREW__; __THREW__ = 0;
   $131 = $130&1;
   if (!($131)) {
    $132 = (($transfer) + 136|0);
    $133 = HEAP8[$132>>0]|0;
    $134 = ($133<<24>>24)==(0);
    $$phi$trans$insert = (($this) + 84|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    if ($134) {
     $146 = $$pre;
    } else {
     $135 = ($$pre|0)==(0|0);
     if (!($135)) {
      $136 = HEAP32[628248>>2]|0;
      HEAP32[$2>>2] = $136;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($$pre|0),($$byval_copy3|0));
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break;
      }
     }
     $139 = HEAP32[$129>>2]|0;
     $140 = (($139) + 16)|0;
     $141 = HEAP32[628248>>2]|0;
     HEAP32[$3>>2] = $141;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
     $142 = (invoke_iiiiiii(102,($140|0),32,($$byval_copy3|0),0,(588280|0),150)|0);
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if ($144) {
      break;
     }
     HEAP32[$$phi$trans$insert>>2] = $142;
     $146 = $142;
    }
    $145 = HEAP32[$129>>2]|0;
    __THREW__ = 0;
    invoke_viiii(356,($transfer|0),($145|0),($146|0),0);
    $147 = __THREW__; __THREW__ = 0;
    $148 = $147&1;
    if (!($148)) {
     $149 = HEAP32[$7>>2]|0;
     $150 = ($149|0)>(-1);
     if (!($150)) {
      STACKTOP = sp;return;
     }
     $151 = HEAP32[$channels>>2]|0;
     $152 = HEAP32[$8>>2]|0;
     HEAP32[$0>>2] = $152;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($151,$$byval_copy3);
     HEAP32[$channels>>2] = 0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$7>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$channels>>2]|0;
 $28 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy3|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $153 = ___cxa_find_matching_catch(0|0)|0;
  $154 = tempRet0;
  ___clang_call_terminate($153);
  // unreachable;
 }
 HEAP32[$channels>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZN10VertexData8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy3 = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allChannelsMask$1 = 0;
 var $allChannelsMask$1$1 = 0, $allChannelsMask$1$2 = 0, $allChannelsMask$1$3 = 0, $allChannelsMask$1$4 = 0, $allChannelsMask$1$5 = 0, $allChannelsMask$1$6 = 0, $allChannelsMask$1$711 = 0, $channels = 0, $scevgep2$i = 0, $streamsLayout = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy3 = sp + 48|0;
 $0 = sp;
 $channels = sp + 8|0;
 $streamsLayout = sp + 24|0;
 $1 = sp + 56|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = (($this) + 88|0);
 $5 = (($transfer) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($transfer) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$4,4);
  $$pre = HEAP32[$5>>2]|0;
  $$pre5 = HEAP32[$8>>2]|0;
  $14 = $$pre;$16 = $$pre5;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$4>>2] = $11;
  HEAP32[$5>>2] = $7;
  $14 = $7;$16 = $9;
 }
 $12 = (($this) + 92|0);
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$12,4);
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$5>>2] = $13;
 }
 HEAP32[$channels>>2] = 0;
 $18 = (($channels) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = (($channels) + 12|0);
 HEAP32[$19>>2] = 0;
 $20 = (($channels) + 4|0);
 HEAP32[$20>>2] = 61;
 __THREW__ = 0;
 invoke_viii(1723,($transfer|0),($channels|0),0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 do {
  if (!($22)) {
   $31 = HEAP32[$18>>2]|0;
   if ((($31|0) == 8)) {
    $32 = HEAP32[$channels>>2]|0;
    _memmove(($this|0),($32|0),32)|0;
   } else if ((($31|0) == 6)) {
    $33 = HEAP32[$channels>>2]|0;
    _memmove(($this|0),($33|0),20)|0;
    $scevgep2$i = (($this) + 20|0);
    $34 = $scevgep2$i;
    $35 = $34;
    HEAP32[$35>>2] = 0;
    $36 = (($34) + 4)|0;
    $37 = $36;
    HEAP32[$37>>2] = 0;
    $38 = (($33) + 20|0);
    $39 = (($this) + 28|0);
    $40 = HEAP32[$38>>2]|0;
    HEAP32[$39>>2] = $40;
    $41 = (($this) + 10|0);
    $42 = HEAP8[$41>>0]|0;
    $43 = ($42<<24>>24)==(2);
    if ($43) {
     $44 = (($this) + 11|0);
     HEAP8[$44>>0] = 4;
    }
   } else if ((($31|0) == 0)) {
    $45 = HEAP32[$4>>2]|0;
    $46 = $45 & 31;
    $47 = $45 << 2;
    $48 = $47 & 128;
    $49 = $48 | $46;
    HEAP32[$4>>2] = $49;
    ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
   } else {
    __THREW__ = 0;
    invoke_viiiiiiii(21,(588248|0),0,(588280|0),121,1,0,0,(0|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    HEAP32[$4>>2] = 0;
   }
   ;HEAP32[$streamsLayout+0>>2]=0|0;HEAP32[$streamsLayout+4>>2]=0|0;HEAP32[$streamsLayout+8>>2]=0|0;HEAP32[$streamsLayout+12>>2]=0|0;
   $52 = (($this) + 3|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = ($53<<24>>24)==(0);
   if ($54) {
    $allChannelsMask$1 = 0;
   } else {
    $55 = HEAP8[$this>>0]|0;
    $56 = $55&255;
    $57 = (($streamsLayout) + ($56<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = $58 | 1;
    HEAP32[$57>>2] = $59;
    $allChannelsMask$1 = 1;
   }
   $60 = (($this) + 7|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = ($61<<24>>24)==(0);
   if ($62) {
    $allChannelsMask$1$1 = $allChannelsMask$1;
   } else {
    $153 = (($this) + 4|0);
    $154 = HEAP8[$153>>0]|0;
    $155 = $154&255;
    $156 = (($streamsLayout) + ($155<<2)|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = $157 | 2;
    HEAP32[$156>>2] = $158;
    $159 = $allChannelsMask$1 | 2;
    $allChannelsMask$1$1 = $159;
   }
   $160 = (($this) + 11|0);
   $80 = HEAP8[$160>>0]|0;
   $161 = ($80<<24>>24)==(0);
   if ($161) {
    $allChannelsMask$1$2 = $allChannelsMask$1$1;
   } else {
    $162 = (($this) + 8|0);
    $163 = HEAP8[$162>>0]|0;
    $164 = $163&255;
    $165 = (($streamsLayout) + ($164<<2)|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = $166 | 4;
    HEAP32[$165>>2] = $167;
    $168 = $allChannelsMask$1$1 | 4;
    $allChannelsMask$1$2 = $168;
   }
   $169 = (($this) + 15|0);
   $88 = HEAP8[$169>>0]|0;
   $170 = ($88<<24>>24)==(0);
   if ($170) {
    $allChannelsMask$1$3 = $allChannelsMask$1$2;
   } else {
    $171 = (($this) + 12|0);
    $172 = HEAP8[$171>>0]|0;
    $173 = $172&255;
    $174 = (($streamsLayout) + ($173<<2)|0);
    $175 = HEAP32[$174>>2]|0;
    $176 = $175 | 8;
    HEAP32[$174>>2] = $176;
    $177 = $allChannelsMask$1$2 | 8;
    $allChannelsMask$1$3 = $177;
   }
   $178 = (($this) + 19|0);
   $96 = HEAP8[$178>>0]|0;
   $179 = ($96<<24>>24)==(0);
   if ($179) {
    $allChannelsMask$1$4 = $allChannelsMask$1$3;
   } else {
    $180 = (($this) + 16|0);
    $181 = HEAP8[$180>>0]|0;
    $182 = $181&255;
    $183 = (($streamsLayout) + ($182<<2)|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = $184 | 16;
    HEAP32[$183>>2] = $185;
    $186 = $allChannelsMask$1$3 | 16;
    $allChannelsMask$1$4 = $186;
   }
   $187 = (($this) + 23|0);
   $104 = HEAP8[$187>>0]|0;
   $188 = ($104<<24>>24)==(0);
   if ($188) {
    $allChannelsMask$1$5 = $allChannelsMask$1$4;
   } else {
    $189 = (($this) + 20|0);
    $190 = HEAP8[$189>>0]|0;
    $191 = $190&255;
    $192 = (($streamsLayout) + ($191<<2)|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = $193 | 32;
    HEAP32[$192>>2] = $194;
    $195 = $allChannelsMask$1$4 | 32;
    $allChannelsMask$1$5 = $195;
   }
   $196 = (($this) + 27|0);
   $112 = HEAP8[$196>>0]|0;
   $197 = ($112<<24>>24)==(0);
   if ($197) {
    $allChannelsMask$1$6 = $allChannelsMask$1$5;
   } else {
    $198 = (($this) + 24|0);
    $199 = HEAP8[$198>>0]|0;
    $200 = $199&255;
    $201 = (($streamsLayout) + ($200<<2)|0);
    $202 = HEAP32[$201>>2]|0;
    $203 = $202 | 64;
    HEAP32[$201>>2] = $203;
    $204 = $allChannelsMask$1$5 | 64;
    $allChannelsMask$1$6 = $204;
   }
   $205 = (($this) + 31|0);
   $120 = HEAP8[$205>>0]|0;
   $206 = ($120<<24>>24)==(0);
   if ($206) {
    $215 = ($allChannelsMask$1$6|0)==(0);
    $128 = HEAP32[$12>>2]|0;
    if ($215) {
     $126 = HEAP32[$4>>2]|0;
     $127 = $126 ^ -1;
     __ZN14VertexDataInfo13UpdateStreamsEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$128,$126,$127,588144,588176);
    } else {
     $125 = $128;$allChannelsMask$1$711 = $allChannelsMask$1$6;
     label = 21;
    }
   } else {
    $207 = (($this) + 28|0);
    $208 = HEAP8[$207>>0]|0;
    $209 = $208&255;
    $210 = (($streamsLayout) + ($209<<2)|0);
    $211 = HEAP32[$210>>2]|0;
    $212 = $211 | 128;
    HEAP32[$210>>2] = $212;
    $213 = $allChannelsMask$1$6 | 128;
    $214 = HEAP32[$12>>2]|0;
    $125 = $214;$allChannelsMask$1$711 = $213;
    label = 21;
   }
   if ((label|0) == 21) {
    ;HEAP16[$1+0>>1]=0|0;HEAP16[$1+2>>1]=0|0;HEAP16[$1+4>>1]=0|0;HEAP16[$1+6>>1]=0|0;HEAP16[$1+8>>1]=0|0;HEAP16[$1+10>>1]=0|0;
    $63 = (($this) + 2|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = $53&255;
    $66 = ($65 << 8)&65535;
    $67 = $64&255;
    $68 = $66 | $67;
    HEAP16[$1>>1] = $68;
    $69 = (($this) + 6|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = (($1) + 2|0);
    $72 = $61&255;
    $73 = ($72 << 8)&65535;
    $74 = $70&255;
    $75 = $73 | $74;
    HEAP16[$71>>1] = $75;
    $76 = (($this) + 10|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = (($1) + 4|0);
    $79 = $80&255;
    $81 = ($79 << 8)&65535;
    $82 = $77&255;
    $83 = $81 | $82;
    HEAP16[$78>>1] = $83;
    $84 = (($this) + 14|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = (($1) + 6|0);
    $87 = $88&255;
    $89 = ($87 << 8)&65535;
    $90 = $85&255;
    $91 = $89 | $90;
    HEAP16[$86>>1] = $91;
    $92 = (($this) + 18|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = (($1) + 8|0);
    $95 = $96&255;
    $97 = ($95 << 8)&65535;
    $98 = $93&255;
    $99 = $97 | $98;
    HEAP16[$94>>1] = $99;
    $100 = (($this) + 22|0);
    $101 = HEAP8[$100>>0]|0;
    $102 = (($1) + 10|0);
    $103 = $104&255;
    $105 = ($103 << 8)&65535;
    $106 = $101&255;
    $107 = $105 | $106;
    HEAP16[$102>>1] = $107;
    $108 = (($this) + 26|0);
    $109 = HEAP8[$108>>0]|0;
    $110 = (($1) + 12|0);
    $111 = $112&255;
    $113 = ($111 << 8)&65535;
    $114 = $109&255;
    $115 = $113 | $114;
    HEAP16[$110>>1] = $115;
    $116 = (($this) + 30|0);
    $117 = HEAP8[$116>>0]|0;
    $118 = (($1) + 14|0);
    $119 = $120&255;
    $121 = ($119 << 8)&65535;
    $122 = $117&255;
    $123 = $121 | $122;
    HEAP16[$118>>1] = $123;
    $124 = $allChannelsMask$1$711 ^ -1;
    __ZN14VertexDataInfo13UpdateStreamsEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$125,$allChannelsMask$1$711,$124,$streamsLayout,$1);
   }
   $129 = (($this) + 96|0);
   __THREW__ = 0;
   invoke_viiii(357,($transfer|0),($129|0),(588288|0),1);
   $130 = __THREW__; __THREW__ = 0;
   $131 = $130&1;
   if (!($131)) {
    $132 = (($this) + 84|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = ($133|0)==(0|0);
    if (!($134)) {
     $135 = HEAP32[628248>>2]|0;
     HEAP32[$2>>2] = $135;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($133|0),($$byval_copy3|0));
     $136 = __THREW__; __THREW__ = 0;
     $137 = $136&1;
     if ($137) {
      break;
     }
    }
    $138 = HEAP32[$129>>2]|0;
    $139 = (($138) + 16)|0;
    $140 = HEAP32[628248>>2]|0;
    HEAP32[$3>>2] = $140;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
    $141 = (invoke_iiiiiii(102,($139|0),32,($$byval_copy3|0),0,(588280|0),150)|0);
    $142 = __THREW__; __THREW__ = 0;
    $143 = $142&1;
    if (!($143)) {
     HEAP32[$132>>2] = $141;
     $144 = HEAP32[$129>>2]|0;
     __THREW__ = 0;
     invoke_viiii(358,($transfer|0),($144|0),($141|0),0);
     $145 = __THREW__; __THREW__ = 0;
     $146 = $145&1;
     if (!($146)) {
      $147 = HEAP32[$19>>2]|0;
      $148 = ($147|0)>(-1);
      if (!($148)) {
       STACKTOP = sp;return;
      }
      $149 = HEAP32[$channels>>2]|0;
      $150 = HEAP32[$20>>2]|0;
      HEAP32[$0>>2] = $150;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($149,$$byval_copy3);
      HEAP32[$channels>>2] = 0;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$19>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$channels>>2]|0;
 $28 = HEAP32[$20>>2]|0;
 HEAP32[$0>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy3|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $151 = ___cxa_find_matching_catch(0|0)|0;
  $152 = tempRet0;
  ___clang_call_terminate($151);
  // unreachable;
 }
 HEAP32[$channels>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZN10VertexData8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy3 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allChannelsMask$1 = 0, $allChannelsMask$1$1 = 0, $allChannelsMask$1$2 = 0, $allChannelsMask$1$3 = 0, $allChannelsMask$1$4 = 0, $allChannelsMask$1$5 = 0, $allChannelsMask$1$6 = 0, $allChannelsMask$1$712 = 0, $channels = 0, $scevgep2$i = 0, $streamsLayout = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy3 = sp + 48|0;
 $0 = sp;
 $channels = sp + 8|0;
 $streamsLayout = sp + 24|0;
 $1 = sp + 56|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = (($this) + 88|0);
 $5 = (($transfer) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($transfer) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$4,4);
  $$pre$i$i$i = HEAP32[$4>>2]|0;
  $$pre = HEAP32[$5>>2]|0;
  $$pre6 = HEAP32[$8>>2]|0;
  $12 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre6;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$4>>2] = $11;
  HEAP32[$5>>2] = $7;
  $12 = $11;$16 = $7;$18 = $9;
 }
 $13 = (_llvm_bswap_i32(($12|0))|0);
 HEAP32[$4>>2] = $13;
 $14 = (($this) + 92|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$14,4);
  $$pre$i$i$i1 = HEAP32[$14>>2]|0;
  $20 = $$pre$i$i$i1;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$14>>2] = $19;
  HEAP32[$5>>2] = $15;
  $20 = $19;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$14>>2] = $21;
 HEAP32[$channels>>2] = 0;
 $22 = (($channels) + 8|0);
 HEAP32[$22>>2] = 0;
 $23 = (($channels) + 12|0);
 HEAP32[$23>>2] = 0;
 $24 = (($channels) + 4|0);
 HEAP32[$24>>2] = 61;
 __THREW__ = 0;
 invoke_viii(1724,($transfer|0),($channels|0),0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 do {
  if (!($26)) {
   $35 = HEAP32[$22>>2]|0;
   if ((($35|0) == 8)) {
    $36 = HEAP32[$channels>>2]|0;
    _memmove(($this|0),($36|0),32)|0;
   } else if ((($35|0) == 0)) {
    $49 = HEAP32[$4>>2]|0;
    $50 = $49 & 31;
    $51 = $49 << 2;
    $52 = $51 & 128;
    $53 = $52 | $50;
    HEAP32[$4>>2] = $53;
    ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
   } else if ((($35|0) == 6)) {
    $37 = HEAP32[$channels>>2]|0;
    _memmove(($this|0),($37|0),20)|0;
    $scevgep2$i = (($this) + 20|0);
    $38 = $scevgep2$i;
    $39 = $38;
    HEAP32[$39>>2] = 0;
    $40 = (($38) + 4)|0;
    $41 = $40;
    HEAP32[$41>>2] = 0;
    $42 = (($37) + 20|0);
    $43 = (($this) + 28|0);
    $44 = HEAP32[$42>>2]|0;
    HEAP32[$43>>2] = $44;
    $45 = (($this) + 10|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = ($46<<24>>24)==(2);
    if ($47) {
     $48 = (($this) + 11|0);
     HEAP8[$48>>0] = 4;
    }
   } else {
    __THREW__ = 0;
    invoke_viiiiiiii(21,(588248|0),0,(588280|0),121,1,0,0,(0|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     break;
    }
    HEAP32[$4>>2] = 0;
   }
   ;HEAP32[$streamsLayout+0>>2]=0|0;HEAP32[$streamsLayout+4>>2]=0|0;HEAP32[$streamsLayout+8>>2]=0|0;HEAP32[$streamsLayout+12>>2]=0|0;
   $56 = (($this) + 3|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ($57<<24>>24)==(0);
   if ($58) {
    $allChannelsMask$1 = 0;
   } else {
    $59 = HEAP8[$this>>0]|0;
    $60 = $59&255;
    $61 = (($streamsLayout) + ($60<<2)|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = $62 | 1;
    HEAP32[$61>>2] = $63;
    $allChannelsMask$1 = 1;
   }
   $64 = (($this) + 7|0);
   $65 = HEAP8[$64>>0]|0;
   $66 = ($65<<24>>24)==(0);
   if ($66) {
    $allChannelsMask$1$1 = $allChannelsMask$1;
   } else {
    $157 = (($this) + 4|0);
    $158 = HEAP8[$157>>0]|0;
    $159 = $158&255;
    $160 = (($streamsLayout) + ($159<<2)|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = $161 | 2;
    HEAP32[$160>>2] = $162;
    $163 = $allChannelsMask$1 | 2;
    $allChannelsMask$1$1 = $163;
   }
   $164 = (($this) + 11|0);
   $84 = HEAP8[$164>>0]|0;
   $165 = ($84<<24>>24)==(0);
   if ($165) {
    $allChannelsMask$1$2 = $allChannelsMask$1$1;
   } else {
    $166 = (($this) + 8|0);
    $167 = HEAP8[$166>>0]|0;
    $168 = $167&255;
    $169 = (($streamsLayout) + ($168<<2)|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = $170 | 4;
    HEAP32[$169>>2] = $171;
    $172 = $allChannelsMask$1$1 | 4;
    $allChannelsMask$1$2 = $172;
   }
   $173 = (($this) + 15|0);
   $92 = HEAP8[$173>>0]|0;
   $174 = ($92<<24>>24)==(0);
   if ($174) {
    $allChannelsMask$1$3 = $allChannelsMask$1$2;
   } else {
    $175 = (($this) + 12|0);
    $176 = HEAP8[$175>>0]|0;
    $177 = $176&255;
    $178 = (($streamsLayout) + ($177<<2)|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = $179 | 8;
    HEAP32[$178>>2] = $180;
    $181 = $allChannelsMask$1$2 | 8;
    $allChannelsMask$1$3 = $181;
   }
   $182 = (($this) + 19|0);
   $100 = HEAP8[$182>>0]|0;
   $183 = ($100<<24>>24)==(0);
   if ($183) {
    $allChannelsMask$1$4 = $allChannelsMask$1$3;
   } else {
    $184 = (($this) + 16|0);
    $185 = HEAP8[$184>>0]|0;
    $186 = $185&255;
    $187 = (($streamsLayout) + ($186<<2)|0);
    $188 = HEAP32[$187>>2]|0;
    $189 = $188 | 16;
    HEAP32[$187>>2] = $189;
    $190 = $allChannelsMask$1$3 | 16;
    $allChannelsMask$1$4 = $190;
   }
   $191 = (($this) + 23|0);
   $108 = HEAP8[$191>>0]|0;
   $192 = ($108<<24>>24)==(0);
   if ($192) {
    $allChannelsMask$1$5 = $allChannelsMask$1$4;
   } else {
    $193 = (($this) + 20|0);
    $194 = HEAP8[$193>>0]|0;
    $195 = $194&255;
    $196 = (($streamsLayout) + ($195<<2)|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = $197 | 32;
    HEAP32[$196>>2] = $198;
    $199 = $allChannelsMask$1$4 | 32;
    $allChannelsMask$1$5 = $199;
   }
   $200 = (($this) + 27|0);
   $116 = HEAP8[$200>>0]|0;
   $201 = ($116<<24>>24)==(0);
   if ($201) {
    $allChannelsMask$1$6 = $allChannelsMask$1$5;
   } else {
    $202 = (($this) + 24|0);
    $203 = HEAP8[$202>>0]|0;
    $204 = $203&255;
    $205 = (($streamsLayout) + ($204<<2)|0);
    $206 = HEAP32[$205>>2]|0;
    $207 = $206 | 64;
    HEAP32[$205>>2] = $207;
    $208 = $allChannelsMask$1$5 | 64;
    $allChannelsMask$1$6 = $208;
   }
   $209 = (($this) + 31|0);
   $124 = HEAP8[$209>>0]|0;
   $210 = ($124<<24>>24)==(0);
   if ($210) {
    $219 = ($allChannelsMask$1$6|0)==(0);
    $132 = HEAP32[$14>>2]|0;
    if ($219) {
     $130 = HEAP32[$4>>2]|0;
     $131 = $130 ^ -1;
     __ZN14VertexDataInfo13UpdateStreamsEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$132,$130,$131,588144,588176);
    } else {
     $129 = $132;$allChannelsMask$1$712 = $allChannelsMask$1$6;
     label = 21;
    }
   } else {
    $211 = (($this) + 28|0);
    $212 = HEAP8[$211>>0]|0;
    $213 = $212&255;
    $214 = (($streamsLayout) + ($213<<2)|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = $215 | 128;
    HEAP32[$214>>2] = $216;
    $217 = $allChannelsMask$1$6 | 128;
    $218 = HEAP32[$14>>2]|0;
    $129 = $218;$allChannelsMask$1$712 = $217;
    label = 21;
   }
   if ((label|0) == 21) {
    ;HEAP16[$1+0>>1]=0|0;HEAP16[$1+2>>1]=0|0;HEAP16[$1+4>>1]=0|0;HEAP16[$1+6>>1]=0|0;HEAP16[$1+8>>1]=0|0;HEAP16[$1+10>>1]=0|0;
    $67 = (($this) + 2|0);
    $68 = HEAP8[$67>>0]|0;
    $69 = $57&255;
    $70 = ($69 << 8)&65535;
    $71 = $68&255;
    $72 = $70 | $71;
    HEAP16[$1>>1] = $72;
    $73 = (($this) + 6|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = (($1) + 2|0);
    $76 = $65&255;
    $77 = ($76 << 8)&65535;
    $78 = $74&255;
    $79 = $77 | $78;
    HEAP16[$75>>1] = $79;
    $80 = (($this) + 10|0);
    $81 = HEAP8[$80>>0]|0;
    $82 = (($1) + 4|0);
    $83 = $84&255;
    $85 = ($83 << 8)&65535;
    $86 = $81&255;
    $87 = $85 | $86;
    HEAP16[$82>>1] = $87;
    $88 = (($this) + 14|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = (($1) + 6|0);
    $91 = $92&255;
    $93 = ($91 << 8)&65535;
    $94 = $89&255;
    $95 = $93 | $94;
    HEAP16[$90>>1] = $95;
    $96 = (($this) + 18|0);
    $97 = HEAP8[$96>>0]|0;
    $98 = (($1) + 8|0);
    $99 = $100&255;
    $101 = ($99 << 8)&65535;
    $102 = $97&255;
    $103 = $101 | $102;
    HEAP16[$98>>1] = $103;
    $104 = (($this) + 22|0);
    $105 = HEAP8[$104>>0]|0;
    $106 = (($1) + 10|0);
    $107 = $108&255;
    $109 = ($107 << 8)&65535;
    $110 = $105&255;
    $111 = $109 | $110;
    HEAP16[$106>>1] = $111;
    $112 = (($this) + 26|0);
    $113 = HEAP8[$112>>0]|0;
    $114 = (($1) + 12|0);
    $115 = $116&255;
    $117 = ($115 << 8)&65535;
    $118 = $113&255;
    $119 = $117 | $118;
    HEAP16[$114>>1] = $119;
    $120 = (($this) + 30|0);
    $121 = HEAP8[$120>>0]|0;
    $122 = (($1) + 14|0);
    $123 = $124&255;
    $125 = ($123 << 8)&65535;
    $126 = $121&255;
    $127 = $125 | $126;
    HEAP16[$122>>1] = $127;
    $128 = $allChannelsMask$1$712 ^ -1;
    __ZN14VertexDataInfo13UpdateStreamsEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$129,$allChannelsMask$1$712,$128,$streamsLayout,$1);
   }
   $133 = (($this) + 96|0);
   __THREW__ = 0;
   invoke_viiii(359,($transfer|0),($133|0),(588288|0),1);
   $134 = __THREW__; __THREW__ = 0;
   $135 = $134&1;
   if (!($135)) {
    $136 = (($this) + 84|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = ($137|0)==(0|0);
    if (!($138)) {
     $139 = HEAP32[628248>>2]|0;
     HEAP32[$2>>2] = $139;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($137|0),($$byval_copy3|0));
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if ($141) {
      break;
     }
    }
    $142 = HEAP32[$133>>2]|0;
    $143 = (($142) + 16)|0;
    $144 = HEAP32[628248>>2]|0;
    HEAP32[$3>>2] = $144;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
    $145 = (invoke_iiiiiii(102,($143|0),32,($$byval_copy3|0),0,(588280|0),150)|0);
    $146 = __THREW__; __THREW__ = 0;
    $147 = $146&1;
    if (!($147)) {
     HEAP32[$136>>2] = $145;
     $148 = HEAP32[$133>>2]|0;
     __THREW__ = 0;
     invoke_viiii(360,($transfer|0),($148|0),($145|0),0);
     $149 = __THREW__; __THREW__ = 0;
     $150 = $149&1;
     if (!($150)) {
      $151 = HEAP32[$23>>2]|0;
      $152 = ($151|0)>(-1);
      if (!($152)) {
       STACKTOP = sp;return;
      }
      $153 = HEAP32[$channels>>2]|0;
      $154 = HEAP32[$24>>2]|0;
      HEAP32[$0>>2] = $154;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($153,$$byval_copy3);
      HEAP32[$channels>>2] = 0;
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $29 = HEAP32[$23>>2]|0;
 $30 = ($29|0)>(-1);
 if (!($30)) {
  ___resumeException($27|0);
  // unreachable;
 }
 $31 = HEAP32[$channels>>2]|0;
 $32 = HEAP32[$24>>2]|0;
 HEAP32[$0>>2] = $32;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy3|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $155 = ___cxa_find_matching_catch(0|0)|0;
  $156 = tempRet0;
  ___clang_call_terminate($155);
  // unreachable;
 }
 HEAP32[$channels>>2] = 0;
 ___resumeException($27|0);
 // unreachable;
}
function __ZN10VertexData8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy8 = 0, $$index = 0, $$index3 = 0, $$pre = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 88|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = HEAP32[$2>>2]|0;
  HEAP32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre7 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre7;
 }
 $10 = (($this) + 92|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)<($14>>>0);
 if ($13) {
  $15 = HEAP32[$10>>2]|0;
  HEAP32[$12>>2] = $15;
  HEAP32[$3>>2] = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$10,4);
 }
 HEAP32[$1>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy8|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  HEAP32[$0>>2] = 61;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,(0|0),($$byval_copy8|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $45 = ___cxa_find_matching_catch(0|0)|0;
   $46 = tempRet0;
   ___clang_call_terminate($45);
   // unreachable;
  } else {
   $$index = $22;$$index3 = $23;
   ___resumeException($$index|0);
   // unreachable;
  }
 }
 HEAP32[$$byval_copy8>>2] = 8;
 $26 = HEAP32[$3>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$6>>2]|0;
 $29 = ($27>>>0)<($28>>>0);
 if ($29) {
  HEAP32[$26>>2] = 8;
  HEAP32[$3>>2] = $27;
  label = 14;
 } else {
  __THREW__ = 0;
  invoke_viii(1640,($3|0),($$byval_copy8|0),4);
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if (!($31)) {
   label = 14;
  }
 }
 if ((label|0) == 14) {
  $32 = (($this) + 32|0);
  $i$01$i$i$i = $this;
  while(1) {
   __THREW__ = 0;
   invoke_vii(2692,($i$01$i$i$i|0),($transfer|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 8;
    break;
   }
   $35 = (($i$01$i$i$i) + 4|0);
   $36 = ($35|0)==($32|0);
   if ($36) {
    break;
   } else {
    $i$01$i$i$i = $35;
   }
  }
  if ((label|0) == 8) {
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   $$index = $18;$$index3 = $19;
   ___resumeException($$index|0);
   // unreachable;
  }
  $37 = (($this) + 96|0);
  __THREW__ = 0;
  invoke_viiii(361,($transfer|0),($37|0),(588288|0),1);
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if (!($39)) {
   $40 = HEAP32[$37>>2]|0;
   $41 = (($this) + 84|0);
   $42 = HEAP32[$41>>2]|0;
   __THREW__ = 0;
   invoke_viiii(362,($transfer|0),($40|0),($42|0),0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    STACKTOP = sp;return;
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $$index = $20;$$index3 = $21;
 ___resumeException($$index|0);
 // unreachable;
}
function __ZN10VertexData8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy = 0, $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$0>>2] = 61;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN14VertexDataInfo18SetAsSingleChannelEPvj13ShaderChannelRK22ChannelFormatDimension($this,$data,$vertexCount,$channel,$fmtDim) {
 $this = $this|0;
 $data = $data|0;
 $vertexCount = $vertexCount|0;
 $channel = $channel|0;
 $fmtDim = $fmtDim|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 HEAP32[$0>>2] = $data;
 $1 = (($this) + 92|0);
 HEAP32[$1>>2] = $vertexCount;
 $2 = HEAPU8[$fmtDim>>0]|(HEAPU8[$fmtDim+1>>0]<<8);
 $3 = $2&65535;
 $4 = ($2&65535) >>> 8;
 $5 = $4&65535;
 $6 = $3 & 255;
 $7 = (588304 + ($6)|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = Math_imul($5, $9)|0;
 $11 = (($this) + 80|0);
 HEAP32[$11>>2] = $10;
 $12 = Math_imul($10, $vertexCount)|0;
 $13 = (($this) + 96|0);
 HEAP32[$13>>2] = $12;
 $14 = 1 << $channel;
 $15 = $14 & 255;
 $16 = (($this) + 88|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 32|0);
 HEAP32[$17>>2] = $15;
 $18 = $10&255;
 $19 = (($this) + 42|0);
 HEAP8[$19>>0] = $18;
 $20 = HEAP8[$fmtDim>>0]|0;
 $21 = ((($this) + ($channel<<2)|0) + 2|0);
 HEAP8[$21>>0] = $20;
 $22 = (($fmtDim) + 1|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ((($this) + ($channel<<2)|0) + 3|0);
 HEAP8[$24>>0] = $23;
 STACKTOP = sp;return;
}
function __ZNK14VertexDataInfo16GetStreamsLayoutEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($agg$result) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($agg$result) + 8|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($agg$result) + 12|0);
 HEAP32[$10>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN14VertexDataInfoC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 dest=$this+0|0; stop=dest+44|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $1 = (($this) + 56|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $2 = (($this) + 68|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $3 = (($this) + 80|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZL12CopyChannelsjjRA4_K10StreamInfoRA8_K11ChannelInfoPKhS2_S6_Ph($vertexCount,$copyChannels,$srcStreams,$srcChannels,$srcData,$dstStreams,$dstChannels,$dstData) {
 $vertexCount = $vertexCount|0;
 $copyChannels = $copyChannels|0;
 $srcStreams = $srcStreams|0;
 $srcChannels = $srcChannels|0;
 $srcData = $srcData|0;
 $dstStreams = $dstStreams|0;
 $dstChannels = $dstChannels|0;
 $dstData = $dstData|0;
 var $$010$i = 0, $$0116$us$i = 0, $$012$i = 0, $$017$i = 0, $$017$us$i = 0, $$019$i = 0, $$03$i = 0, $$115$i = 0, $$1214$i = 0, $$1228$us$i = 0, $$1228$us$i$us = 0, $$129$i = 0, $$129$us$i = 0, $$129$us$i$us = 0, $$220$i = 0, $$2319$i = 0, $$2340$i = 0, $$241$i = 0, $$345$i = 0, $$3452$i = 0;
 var $$353$i = 0, $$36$i = 0, $$4564$i = 0, $$465$i = 0, $$op$i$i = Math_fround(0), $$op$i10$i = Math_fround(0), $$sink$i$i$i$i = Math_fround(0), $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8$us = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0;
 var $245 = Math_fround(0), $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0);
 var $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $comp2$0$lcssa$i = 0, $comp3$0$lcssa$i = 0, $comp4$0$lcssa$i = 0, $exitcond = 0, $exitcond28 = 0;
 var $exitcond31 = 0, $exitcond34 = 0, $exitcond37 = 0, $exitcond40 = 0, $indvar$i = 0, $indvar$next$i = 0, $indvar$next105$i = 0, $indvar$next116$i$us = 0, $indvar$next67$i = 0, $indvar$next72$i = 0, $indvar$next83$i = 0, $indvar$next94$i = 0, $indvar104$i = 0, $indvar115$i$us = 0, $indvar66$i = 0, $indvar71$i = 0, $indvar82$i = 0, $indvar93$i = 0, $indvars$iv$i = 0, $indvars$iv$next$i = 0;
 var $indvars$iv$next109$i = 0, $indvars$iv$next109$i$us = 0, $indvars$iv$next76$i = 0, $indvars$iv$next87$i = 0, $indvars$iv$next98$i = 0, $indvars$iv108$i = 0, $indvars$iv108$i$us = 0, $indvars$iv75$i = 0, $indvars$iv86$i = 0, $indvars$iv97$i = 0, $lftr$wideiv = 0, $lftr$wideiv27 = 0, $lftr$wideiv30 = 0, $lftr$wideiv33 = 0, $lftr$wideiv36 = 0, $lftr$wideiv39 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond6$i = 0, $or$cond7$i = 0;
 var $or$cond8$i = 0, $or$cond9$i = 0, $scevgep$i = 0, $scevgep106$sum$i = 0, $scevgep107$i = 0, $scevgep117$sum$i = 0, $scevgep118$i$us = 0, $scevgep68$i = 0, $scevgep73$sum$i = 0, $scevgep74$i = 0, $scevgep84$sum$i = 0, $scevgep85$i = 0, $scevgep95$sum$i = 0, $scevgep96$i = 0, $umax = 0, $umax$i = 0, $umax110$i = 0, $umax26 = 0, $umax29 = 0, $umax35 = 0;
 var $umax38 = 0, $umax77$i = 0, $umax88$i = 0, $umax99$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($copyChannels|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $2 = 1;$5 = 0;
 }
 while(1) {
  $1 = $2 & $copyChannels;
  $3 = ($1|0)==(0);
  L5: do {
   if (!($3)) {
    $4 = (($srcChannels) + ($5<<2)|0);
    $6 = HEAP8[$4>>0]|0;
    $7 = $6&255;
    $8 = ((($srcStreams) + (($7*12)|0)|0) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ((($srcChannels) + ($5<<2)|0) + 1|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11&255;
    $13 = (($12) + ($9))|0;
    $14 = (($srcData) + ($13)|0);
    $15 = (($dstChannels) + ($5<<2)|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = $16&255;
    $18 = ((($dstStreams) + (($17*12)|0)|0) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ((($dstChannels) + ($5<<2)|0) + 1|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21&255;
    $23 = (($22) + ($19))|0;
    $24 = (($dstData) + ($23)|0);
    $25 = ((($srcStreams) + (($7*12)|0)|0) + 10|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ((($dstStreams) + (($17*12)|0)|0) + 10|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ((($srcChannels) + ($5<<2)|0) + 2|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = ((($dstChannels) + ($5<<2)|0) + 2|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = ($30<<24>>24)==($32<<24>>24);
    $34 = ((($srcChannels) + ($5<<2)|0) + 3|0);
    $35 = HEAP8[$34>>0]|0;
    if ($33) {
     $36 = $30&255;
     $37 = (588304 + ($36)|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = $38&255;
     $40 = $35&255;
     $41 = Math_imul($39, $40)|0;
     $42 = ((($dstChannels) + ($5<<2)|0) + 3|0);
     $43 = HEAP8[$42>>0]|0;
     $44 = $38&255;
     $45 = $43&255;
     $46 = Math_imul($44, $45)|0;
     $47 = ($46>>>0)<($41>>>0);
     $48 = $47 ? $46 : $41;
     $49 = ($46|0)==($48|0);
     if (!($49)) {
      $85 = (($46) - ($48))|0;
      $86 = $26&255;
      $87 = Math_imul($86, $vertexCount)|0;
      $$sum12 = (($87) + ($13))|0;
      $88 = (($srcData) + ($$sum12)|0);
      $89 = ($87|0)==(0);
      if ($89) {
       break;
      }
      $90 = $28&255;
      $$012$i = $24;$$03$i = $14;
      while(1) {
       _memcpy(($$012$i|0),($$03$i|0),($48|0))|0;
       $91 = (($$012$i) + ($48)|0);
       _memset(($91|0),0,($85|0))|0;
       $92 = (($$03$i) + ($86)|0);
       $93 = (($$012$i) + ($90)|0);
       $94 = ($92|0)==($88|0);
       if ($94) {
        break L5;
       } else {
        $$012$i = $93;$$03$i = $92;
       }
      }
     }
     $50 = $26&255;
     $51 = Math_imul($50, $vertexCount)|0;
     $$sum13 = (($51) + ($13))|0;
     $52 = (($srcData) + ($$sum13)|0);
     if ((($46|0) == 8)) {
      $55 = ($51|0)==(0);
      if ($55) {
       break;
      }
      $56 = $28&255;
      $$115$i = $14;$$1214$i = $24;
      while(1) {
       $65 = HEAP32[$$115$i>>2]|0;
       HEAP32[$$1214$i>>2] = $65;
       $66 = (($$115$i) + 4|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($$1214$i) + 4|0);
       HEAP32[$68>>2] = $67;
       $69 = (($$115$i) + ($50)|0);
       $70 = (($$1214$i) + ($56)|0);
       $71 = ($69|0)==($52|0);
       if ($71) {
        break L5;
       } else {
        $$115$i = $69;$$1214$i = $70;
       }
      }
     } else if ((($46|0) == 12)) {
      $53 = ($51|0)==(0);
      if ($53) {
       break;
      }
      $54 = $28&255;
      $$220$i = $14;$$2319$i = $24;
      while(1) {
       $72 = HEAP32[$$220$i>>2]|0;
       HEAP32[$$2319$i>>2] = $72;
       $73 = (($$220$i) + 4|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = (($$2319$i) + 4|0);
       HEAP32[$75>>2] = $74;
       $76 = (($$220$i) + 8|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = (($$2319$i) + 8|0);
       HEAP32[$78>>2] = $77;
       $79 = (($$220$i) + ($50)|0);
       $80 = (($$2319$i) + ($54)|0);
       $81 = ($79|0)==($52|0);
       if ($81) {
        break L5;
       } else {
        $$220$i = $79;$$2319$i = $80;
       }
      }
     } else if ((($46|0) == 4)) {
      $57 = ($51|0)==(0);
      if ($57) {
       break;
      }
      $58 = $28&255;
      $$010$i = $14;$$019$i = $24;
      while(1) {
       $61 = HEAP32[$$010$i>>2]|0;
       HEAP32[$$019$i>>2] = $61;
       $62 = (($$010$i) + ($50)|0);
       $63 = (($$019$i) + ($58)|0);
       $64 = ($62|0)==($52|0);
       if ($64) {
        break L5;
       } else {
        $$010$i = $62;$$019$i = $63;
       }
      }
     } else {
      $59 = ($51|0)==(0);
      if ($59) {
       break;
      }
      $60 = $28&255;
      $$345$i = $24;$$36$i = $14;
      while(1) {
       _memcpy(($$345$i|0),($$36$i|0),($46|0))|0;
       $82 = (($$36$i) + ($50)|0);
       $83 = (($$345$i) + ($60)|0);
       $84 = ($82|0)==($52|0);
       if ($84) {
        break L5;
       } else {
        $$345$i = $83;$$36$i = $82;
       }
      }
     }
    }
    $95 = ((($dstChannels) + ($5<<2)|0) + 3|0);
    $96 = HEAP8[$95>>0]|0;
    $97 = ($96&255)<($35&255);
    $98 = $97 ? $96 : $35;
    $99 = $26&255;
    $100 = Math_imul($99, $vertexCount)|0;
    $$sum = (($100) + ($13))|0;
    $101 = (($srcData) + ($$sum)|0);
    $102 = ($30<<24>>24)==(1);
    $103 = ($32<<24>>24)==(0);
    $or$cond$i = $102 & $103;
    if ($or$cond$i) {
     $104 = ($100|0)==(0);
     if ($104) {
      break;
     }
     $105 = ($98<<24>>24)==(0);
     $106 = $28&255;
     if ($105) {
      $107 = (($96) + -1)<<24>>24;
      $108 = $107&255;
      $109 = $108 << 2;
      $110 = (($109) + 4)|0;
      $111 = ($96<<24>>24)==(0);
      $$017$i = $14;$indvar$i = 0;
      while(1) {
       if (!($111)) {
        $149 = Math_imul($indvar$i, $106)|0;
        $$sum11 = (($149) + ($23))|0;
        $scevgep$i = (($dstData) + ($$sum11)|0);
        _memset(($scevgep$i|0),0,($110|0))|0;
       }
       $150 = (($$017$i) + ($99)|0);
       $151 = ($150|0)==($101|0);
       $indvar$next$i = (($indvar$i) + 1)|0;
       if ($151) {
        break L5;
       } else {
        $$017$i = $150;$indvar$i = $indvar$next$i;
       }
      }
     }
     $112 = $96 ^ -1;
     $113 = $35 ^ -1;
     $114 = ($112&255)>($113&255);
     $umax99$i = $114 ? $112 : $113;
     $115 = $umax99$i ^ -1;
     $116 = ($96&255)>($115&255);
     $117 = $115&255;
     $118 = $117 << 2;
     $scevgep106$sum$i = (($118) + ($23))|0;
     $119 = (($96) + ($umax99$i))<<24>>24;
     $120 = $119&255;
     $121 = $120 << 2;
     $122 = (($121) + 4)|0;
     $123 = $35 ^ -1;
     $124 = $96 ^ -1;
     $125 = ($123&255)>($124&255);
     $umax35 = $125 ? $123 : $124;
     $126 = $umax35 ^ -1;
     $$0116$us$i = $24;$$017$us$i = $14;$indvar104$i = 0;
     while(1) {
      $indvars$iv97$i = 0;
      while(1) {
       $130 = (($$017$us$i) + ($indvars$iv97$i<<1)|0);
       $131 = HEAP16[$130>>1]|0;
       $132 = (($$0116$us$i) + ($indvars$iv97$i<<2)|0);
       $133 = $131&65535;
       $134 = $133 & 32767;
       HEAP32[$132>>2] = $134;
       $135 = ($134|0)==(0);
       do {
        if ($135) {
         $147 = 0;
        } else {
         $136 = $134 << 13;
         HEAP32[$132>>2] = $136;
         $137 = $136 & 260046848;
         if ((($137|0) == 260046848)) {
          $138 = $136 | 1879048192;
          HEAP32[$132>>2] = $138;
          $147 = $138;
          break;
         } else if ((($137|0) == 0)) {
          $139 = (($136) + 947912704)|0;
          $140 = (HEAP32[tempDoublePtr>>2]=$139,Math_fround(HEAPF32[tempDoublePtr>>2]));
          $141 = Math_fround($140 + Math_fround(-6.103515625E-5));
          HEAPF32[$132>>2] = $141;
          $142 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
          $147 = $142;
          break;
         } else {
          $143 = (($136) + 939524096)|0;
          HEAP32[$132>>2] = $143;
          $147 = $143;
          break;
         }
        }
       } while(0);
       $144 = $133 << 16;
       $145 = $144 & -2147483648;
       $146 = $147 | $145;
       HEAP32[$132>>2] = $146;
       $indvars$iv$next98$i = (($indvars$iv97$i) + 1)|0;
       $lftr$wideiv36 = $indvars$iv$next98$i&255;
       $exitcond37 = ($lftr$wideiv36<<24>>24)==($126<<24>>24);
       if ($exitcond37) {
        break;
       } else {
        $indvars$iv97$i = $indvars$iv$next98$i;
       }
      }
      if ($116) {
       $148 = Math_imul($indvar104$i, $106)|0;
       $$sum10 = (($scevgep106$sum$i) + ($148))|0;
       $scevgep107$i = (($dstData) + ($$sum10)|0);
       _memset(($scevgep107$i|0),0,($122|0))|0;
      }
      $127 = (($$017$us$i) + ($99)|0);
      $128 = (($$0116$us$i) + ($106)|0);
      $129 = ($127|0)==($101|0);
      $indvar$next105$i = (($indvar104$i) + 1)|0;
      if ($129) {
       break L5;
      } else {
       $$0116$us$i = $128;$$017$us$i = $127;$indvar104$i = $indvar$next105$i;
      }
     }
    }
    $152 = ($30<<24>>24)==(2);
    $or$cond6$i = $152 & $103;
    if ($or$cond6$i) {
     $153 = ($100|0)==(0);
     if ($153) {
      break;
     }
     $154 = ($98<<24>>24)==(0);
     $155 = $28&255;
     if ($154) {
      $156 = (($96) + -1)<<24>>24;
      $157 = $156&255;
      $158 = $157 << 2;
      $159 = (($158) + 4)|0;
      $160 = ($96<<24>>24)==(0);
      $$129$i = $14;$indvar66$i = 0;
      while(1) {
       if (!($160)) {
        $195 = Math_imul($indvar66$i, $155)|0;
        $$sum9 = (($195) + ($23))|0;
        $scevgep68$i = (($dstData) + ($$sum9)|0);
        _memset(($scevgep68$i|0),0,($159|0))|0;
       }
       $196 = (($$129$i) + ($99)|0);
       $197 = ($196|0)==($101|0);
       $indvar$next67$i = (($indvar66$i) + 1)|0;
       if ($197) {
        break L5;
       } else {
        $$129$i = $196;$indvar66$i = $indvar$next67$i;
       }
      }
     }
     $161 = $96 ^ -1;
     $162 = $35 ^ -1;
     $163 = ($161&255)>($162&255);
     $umax110$i = $163 ? $161 : $162;
     $164 = $umax110$i ^ -1;
     $165 = ($96&255)>($164&255);
     $166 = $164&255;
     $167 = $166 << 2;
     $scevgep117$sum$i = (($167) + ($23))|0;
     $168 = (($96) + ($umax110$i))<<24>>24;
     $169 = $168&255;
     $170 = $169 << 2;
     $171 = (($170) + 4)|0;
     $172 = $35 ^ -1;
     $173 = $96 ^ -1;
     $174 = ($172&255)>($173&255);
     $umax38 = $174 ? $172 : $173;
     $175 = $umax38 ^ -1;
     if ($165) {
      $$1228$us$i$us = $24;$$129$us$i$us = $14;$indvar115$i$us = 0;
      while(1) {
       $indvars$iv108$i$us = 0;
       while(1) {
        $176 = (($$129$us$i$us) + ($indvars$iv108$i$us)|0);
        $177 = HEAP8[$176>>0]|0;
        $178 = $177&255;
        $179 = (Math_fround(($178|0)));
        $180 = Math_fround($179 / Math_fround(255.0));
        $181 = (($$1228$us$i$us) + ($indvars$iv108$i$us<<2)|0);
        HEAPF32[$181>>2] = $180;
        $indvars$iv$next109$i$us = (($indvars$iv108$i$us) + 1)|0;
        $lftr$wideiv39 = $indvars$iv$next109$i$us&255;
        $exitcond40 = ($lftr$wideiv39<<24>>24)==($175<<24>>24);
        if ($exitcond40) {
         break;
        } else {
         $indvars$iv108$i$us = $indvars$iv$next109$i$us;
        }
       }
       $182 = Math_imul($indvar115$i$us, $155)|0;
       $$sum8$us = (($scevgep117$sum$i) + ($182))|0;
       $scevgep118$i$us = (($dstData) + ($$sum8$us)|0);
       _memset(($scevgep118$i$us|0),0,($171|0))|0;
       $183 = (($$129$us$i$us) + ($99)|0);
       $184 = (($$1228$us$i$us) + ($155)|0);
       $185 = ($183|0)==($101|0);
       $indvar$next116$i$us = (($indvar115$i$us) + 1)|0;
       if ($185) {
        break L5;
       } else {
        $$1228$us$i$us = $184;$$129$us$i$us = $183;$indvar115$i$us = $indvar$next116$i$us;
       }
      }
     } else {
      $$1228$us$i = $24;$$129$us$i = $14;
      while(1) {
       $indvars$iv108$i = 0;
       while(1) {
        $189 = (($$129$us$i) + ($indvars$iv108$i)|0);
        $190 = HEAP8[$189>>0]|0;
        $191 = $190&255;
        $192 = (Math_fround(($191|0)));
        $193 = Math_fround($192 / Math_fround(255.0));
        $194 = (($$1228$us$i) + ($indvars$iv108$i<<2)|0);
        HEAPF32[$194>>2] = $193;
        $indvars$iv$next109$i = (($indvars$iv108$i) + 1)|0;
        $lftr$wideiv33 = $indvars$iv$next109$i&255;
        $exitcond34 = ($lftr$wideiv33<<24>>24)==($175<<24>>24);
        if ($exitcond34) {
         break;
        } else {
         $indvars$iv108$i = $indvars$iv$next109$i;
        }
       }
       $186 = (($$129$us$i) + ($99)|0);
       $187 = (($$1228$us$i) + ($155)|0);
       $188 = ($186|0)==($101|0);
       if ($188) {
        break L5;
       } else {
        $$1228$us$i = $187;$$129$us$i = $186;
       }
      }
     }
    }
    $198 = ($30<<24>>24)==(3);
    $or$cond7$i = $198 & $103;
    if ($or$cond7$i) {
     $199 = ($100|0)==(0);
     if ($199) {
      break;
     }
     $200 = ($98<<24>>24)==(0);
     $201 = $28&255;
     $202 = $96 ^ -1;
     $203 = $35 ^ -1;
     $204 = ($202&255)>($203&255);
     $umax$i = $204 ? $202 : $203;
     $205 = $umax$i ^ -1;
     $206 = (($96) + -1)<<24>>24;
     $207 = $35 ^ -1;
     $208 = $96 ^ -1;
     $209 = ($207&255)>($208&255);
     $umax29 = $209 ? $207 : $208;
     $210 = $umax29 ^ -1;
     $$2340$i = $24;$$241$i = $14;$indvar71$i = 0;
     while(1) {
      $211 = Math_imul($indvar71$i, $201)|0;
      if ($200) {
       $comp2$0$lcssa$i = 0;
      } else {
       $indvars$iv$i = 0;
       while(1) {
        $212 = (($$241$i) + ($indvars$iv$i)|0);
        $213 = HEAP8[$212>>0]|0;
        $214 = (Math_fround(($213<<24>>24)));
        $215 = Math_fround($214 * Math_fround(0.00787401571869850158691));
        $216 = (($$2340$i) + ($indvars$iv$i<<2)|0);
        HEAPF32[$216>>2] = $215;
        $indvars$iv$next$i = (($indvars$iv$i) + 1)|0;
        $lftr$wideiv30 = $indvars$iv$next$i&255;
        $exitcond31 = ($lftr$wideiv30<<24>>24)==($210<<24>>24);
        if ($exitcond31) {
         $comp2$0$lcssa$i = $205;
         break;
        } else {
         $indvars$iv$i = $indvars$iv$next$i;
        }
       }
      }
      $217 = ($comp2$0$lcssa$i&255)<($96&255);
      if ($217) {
       $218 = $comp2$0$lcssa$i&255;
       $219 = $218 << 2;
       $scevgep73$sum$i = (($211) + ($23))|0;
       $$sum7 = (($scevgep73$sum$i) + ($219))|0;
       $scevgep74$i = (($dstData) + ($$sum7)|0);
       $220 = (($206) - ($comp2$0$lcssa$i))<<24>>24;
       $221 = $220&255;
       $222 = $221 << 2;
       $223 = (($222) + 4)|0;
       _memset(($scevgep74$i|0),0,($223|0))|0;
      }
      $224 = (($$241$i) + ($99)|0);
      $225 = (($$2340$i) + ($201)|0);
      $226 = ($224|0)==($101|0);
      $indvar$next72$i = (($indvar71$i) + 1)|0;
      if ($226) {
       break L5;
      } else {
       $$2340$i = $225;$$241$i = $224;$indvar71$i = $indvar$next72$i;
      }
     }
    }
    $227 = ($30<<24>>24)==(0);
    $228 = ($32<<24>>24)==(2);
    $or$cond8$i = $227 & $228;
    if ($or$cond8$i) {
     $229 = ($100|0)==(0);
     if ($229) {
      break;
     }
     $230 = ($98<<24>>24)==(0);
     $231 = $28&255;
     $232 = $96 ^ -1;
     $233 = $35 ^ -1;
     $234 = ($232&255)>($233&255);
     $umax77$i = $234 ? $232 : $233;
     $235 = $umax77$i ^ -1;
     $236 = (($96) + -1)<<24>>24;
     $237 = $35 ^ -1;
     $238 = $96 ^ -1;
     $239 = ($237&255)>($238&255);
     $umax26 = $239 ? $237 : $238;
     $240 = $umax26 ^ -1;
     $$3452$i = $24;$$353$i = $14;$indvar82$i = 0;
     while(1) {
      $241 = Math_imul($indvar82$i, $231)|0;
      if ($230) {
       $comp3$0$lcssa$i = 0;
      } else {
       $indvars$iv75$i = 0;
       while(1) {
        $242 = (($$353$i) + ($indvars$iv75$i<<2)|0);
        $243 = Math_fround(HEAPF32[$242>>2]);
        $244 = $243 < Math_fround(0.0);
        $245 = $244 ? Math_fround(0.0) : $243;
        $246 = $245 > Math_fround(1.0);
        $$op$i10$i = Math_fround($245 * Math_fround(255.0));
        $247 = $246 ? Math_fround(255.0) : $$op$i10$i;
        $248 = Math_fround($247 + Math_fround(0.5));
        $249 = (~~(($248))>>>0);
        $250 = $249&255;
        $251 = (($$3452$i) + ($indvars$iv75$i)|0);
        HEAP8[$251>>0] = $250;
        $indvars$iv$next76$i = (($indvars$iv75$i) + 1)|0;
        $lftr$wideiv27 = $indvars$iv$next76$i&255;
        $exitcond28 = ($lftr$wideiv27<<24>>24)==($240<<24>>24);
        if ($exitcond28) {
         $comp3$0$lcssa$i = $235;
         break;
        } else {
         $indvars$iv75$i = $indvars$iv$next76$i;
        }
       }
      }
      $252 = ($comp3$0$lcssa$i&255)<($96&255);
      if ($252) {
       $253 = $comp3$0$lcssa$i&255;
       $scevgep84$sum$i = (($241) + ($23))|0;
       $$sum6 = (($scevgep84$sum$i) + ($253))|0;
       $scevgep85$i = (($dstData) + ($$sum6)|0);
       $254 = (($236) - ($comp3$0$lcssa$i))<<24>>24;
       $255 = $254&255;
       $256 = (($255) + 1)|0;
       _memset(($scevgep85$i|0),0,($256|0))|0;
      }
      $257 = (($$353$i) + ($99)|0);
      $258 = (($$3452$i) + ($231)|0);
      $259 = ($257|0)==($101|0);
      $indvar$next83$i = (($indvar82$i) + 1)|0;
      if ($259) {
       break L5;
      } else {
       $$3452$i = $258;$$353$i = $257;$indvar82$i = $indvar$next83$i;
      }
     }
    }
    $260 = ($32<<24>>24)==(3);
    $or$cond9$i = $227 & $260;
    if (!($or$cond9$i)) {
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(588384,0,588280,347,1,0,0,0);
     break;
    }
    $261 = ($100|0)==(0);
    if (!($261)) {
     $262 = ($98<<24>>24)==(0);
     $263 = $28&255;
     $264 = $96 ^ -1;
     $265 = $35 ^ -1;
     $266 = ($264&255)>($265&255);
     $umax88$i = $266 ? $264 : $265;
     $267 = $umax88$i ^ -1;
     $268 = (($96) + -1)<<24>>24;
     $269 = $35 ^ -1;
     $270 = $96 ^ -1;
     $271 = ($269&255)>($270&255);
     $umax = $271 ? $269 : $270;
     $272 = $umax ^ -1;
     $$4564$i = $24;$$465$i = $14;$indvar93$i = 0;
     while(1) {
      $273 = Math_imul($indvar93$i, $263)|0;
      if ($262) {
       $comp4$0$lcssa$i = 0;
      } else {
       $indvars$iv86$i = 0;
       while(1) {
        $274 = (($$465$i) + ($indvars$iv86$i<<2)|0);
        $275 = Math_fround(HEAPF32[$274>>2]);
        $276 = $275 < Math_fround(-1.0);
        $277 = $276 ? Math_fround(-1.0) : $275;
        $278 = $277 > Math_fround(1.0);
        $$op$i$i = Math_fround($277 * Math_fround(127.0));
        $279 = $278 ? Math_fround(127.0) : $$op$i$i;
        $280 = Math_fround($279 + Math_fround(0.5));
        $281 = !($280 >= Math_fround(0.0));
        if ($281) {
         $282 = Math_fround($280 + Math_fround(-0.999999940395355224609));
         $$sink$i$i$i$i = $282;
        } else {
         $$sink$i$i$i$i = $280;
        }
        $283 = (~~(($$sink$i$i$i$i)));
        $284 = $283&255;
        $285 = (($$4564$i) + ($indvars$iv86$i)|0);
        HEAP8[$285>>0] = $284;
        $indvars$iv$next87$i = (($indvars$iv86$i) + 1)|0;
        $lftr$wideiv = $indvars$iv$next87$i&255;
        $exitcond = ($lftr$wideiv<<24>>24)==($272<<24>>24);
        if ($exitcond) {
         $comp4$0$lcssa$i = $267;
         break;
        } else {
         $indvars$iv86$i = $indvars$iv$next87$i;
        }
       }
      }
      $286 = ($comp4$0$lcssa$i&255)<($96&255);
      if ($286) {
       $287 = $comp4$0$lcssa$i&255;
       $scevgep95$sum$i = (($273) + ($23))|0;
       $$sum5 = (($scevgep95$sum$i) + ($287))|0;
       $scevgep96$i = (($dstData) + ($$sum5)|0);
       $288 = (($268) - ($comp4$0$lcssa$i))<<24>>24;
       $289 = $288&255;
       $290 = (($289) + 1)|0;
       _memset(($scevgep96$i|0),0,($290|0))|0;
      }
      $291 = (($$465$i) + ($99)|0);
      $292 = (($$4564$i) + ($263)|0);
      $293 = ($291|0)==($101|0);
      $indvar$next94$i = (($indvar93$i) + 1)|0;
      if ($293) {
       break;
      } else {
       $$4564$i = $292;$$465$i = $291;$indvar93$i = $indvar$next94$i;
      }
     }
    }
   }
  } while(0);
  $294 = (($5) + 1)|0;
  $295 = $2 << 1;
  $296 = ($294|0)<(8);
  $297 = ($295>>>0)<=($copyChannels>>>0);
  $or$cond = $296 & $297;
  if ($or$cond) {
   $2 = $295;$5 = $294;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN10VertexDataD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  STACKTOP = sp;return;
 }
 $4 = HEAP32[628248>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10VertexData6ResizeEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$vertexCount,$createChannels,$removeChannels,$streams,$channels) {
 $this = $this|0;
 $vertexCount = $vertexCount|0;
 $createChannels = $createChannels|0;
 $removeChannels = $removeChannels|0;
 $streams = $streams|0;
 $channels = $channels|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $i$01$i$i1 = 0, $srcChannels = 0, $srcStreams = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy3 = sp + 96|0;
 $srcChannels = sp;
 $srcStreams = sp + 32|0;
 $0 = sp + 80|0;
 $1 = sp + 84|0;
 $2 = sp + 88|0;
 $3 = sp + 92|0;
 ;HEAP32[$srcChannels+0>>2]=HEAP32[$this+0>>2]|0;HEAP32[$srcChannels+4>>2]=HEAP32[$this+4>>2]|0;HEAP32[$srcChannels+8>>2]=HEAP32[$this+8>>2]|0;HEAP32[$srcChannels+12>>2]=HEAP32[$this+12>>2]|0;HEAP32[$srcChannels+16>>2]=HEAP32[$this+16>>2]|0;HEAP32[$srcChannels+20>>2]=HEAP32[$this+20>>2]|0;HEAP32[$srcChannels+24>>2]=HEAP32[$this+24>>2]|0;HEAP32[$srcChannels+28>>2]=HEAP32[$this+28>>2]|0;
 $4 = (($this) + 32|0);
 dest=$srcStreams+0|0; src=$4+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = (($this) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 92|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN14VertexDataInfo13UpdateStreamsEjjjRK19VertexStreamsLayoutRK20VertexChannelsLayout($this,$vertexCount,$createChannels,$removeChannels,$streams,$channels);
 $11 = ($vertexCount|0)==(0);
 $12 = HEAP32[$9>>2]|0;
 $13 = ($12|0)!=(0|0);
 if ($11) {
  if ($13) {
   $14 = HEAP32[628248>>2]|0;
   HEAP32[$0>>2] = $14;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($12,$$byval_copy3);
  }
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return;
 }
 L8: do {
  if ($13) {
   $i$01$i$i1 = 0;
   while(1) {
    $17 = (($srcChannels) + ($i$01$i$i1<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($this) + ($i$01$i$i1<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    $16 = (($i$01$i$i1) + 1)|0;
    if (!($21)) {
     break L8;
    }
    $15 = ($16|0)<(8);
    if ($15) {
     $i$01$i$i1 = $16;
    } else {
     break;
    }
   }
   $i$01$i$i = 0;
   while(1) {
    $24 = (($srcStreams) + ($i$01$i$i<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($4) + ($i$01$i$i<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($25|0)==($27|0);
    $23 = (($i$01$i$i) + 1)|0;
    if (!($28)) {
     break L8;
    }
    $22 = ($23|0)<(12);
    if ($22) {
     $i$01$i$i = $23;
    } else {
     break;
    }
   }
   $29 = (($this) + 96|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 16)|0;
   $32 = HEAP32[628248>>2]|0;
   HEAP32[$1>>2] = $32;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
   $33 = (__Z16realloc_internalPvji10MemLabelIdiPKci($12,$31,32,$$byval_copy3,0,588280,528)|0);
   HEAP32[$9>>2] = $33;
   STACKTOP = sp;return;
  }
 } while(0);
 $34 = (($this) + 96|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 16)|0;
 $37 = HEAP32[628248>>2]|0;
 HEAP32[$2>>2] = $37;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 $38 = (__Z15malloc_internaljj10MemLabelIdiPKci($36,32,$$byval_copy3,0,588280,532)|0);
 HEAP32[$9>>2] = $38;
 $39 = ($10|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$5>>2]|0;
 $41 = $40 & $6;
 $42 = HEAP32[$7>>2]|0;
 $43 = ($42>>>0)<($8>>>0);
 $44 = $43 ? $42 : $8;
 __ZL12CopyChannelsjjRA4_K10StreamInfoRA8_K11ChannelInfoPKhS2_S6_Ph($44,$41,$srcStreams,$srcChannels,$10,$4,$this,$38);
 $45 = HEAP32[628248>>2]|0;
 HEAP32[$3>>2] = $45;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($10,$$byval_copy3);
 STACKTOP = sp;return;
}
function __ZN10VertexData13SwapEndianessEv($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond7$i = 0, $i$02$i = 0, $i2$05$i = 0, $localOffset$04 = 0, $localOffset$1 = 0, $or$cond = 0, $or$cond1 = 0, $p$01$i = 0, $p$05 = 0, $p1$04$i = 0, $s$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = (($this) + 92|0);
 $s$06 = 0;
 while(1) {
  $2 = ((($this) + (($s$06*12)|0)|0) + 42|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   $5 = $3&255;
   $6 = HEAP32[$0>>2]|0;
   $7 = ((($this) + (($s$06*12)|0)|0) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$1>>2]|0;
   $10 = Math_imul($9, $5)|0;
   $$sum = (($10) + ($8))|0;
   $11 = (($6) + ($$sum)|0);
   $12 = ((($this) + (($s$06*12)|0)|0) + 32|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($10|0)==(0);
   if (!($14)) {
    $15 = (($6) + ($8)|0);
    $16 = ($13|0)==(0);
    $17 = $13 & 4;
    $18 = ($17|0)!=(0);
    $p$05 = $15;
    while(1) {
     if (!($16)) {
      $20 = 1;$23 = 0;$localOffset$04 = 0;
      while(1) {
       $19 = $20 & $13;
       $21 = ($19|0)==(0);
       if ($21) {
        $localOffset$1 = $localOffset$04;
       } else {
        $22 = ((($this) + ($23<<2)|0) + 3|0);
        $24 = HEAP8[$22>>0]|0;
        $25 = $24&255;
        $26 = ((($this) + ($23<<2)|0) + 2|0);
        $27 = HEAP8[$26>>0]|0;
        $28 = $27&255;
        $29 = (588304 + ($28)|0);
        $30 = HEAP8[$29>>0]|0;
        $31 = $30&255;
        $32 = $20 & 155;
        $33 = ($32|0)==(0);
        if ($33) {
         $34 = $28 & 251;
         $35 = ($34|0)==(0);
         $or$cond = $18 & $35;
         if ($or$cond) {
          label = 9;
         }
        } else {
         label = 9;
        }
        do {
         if ((label|0) == 9) {
          label = 0;
          $36 = (($p$05) + ($localOffset$04)|0);
          if ((($31|0) == 4)) {
           $46 = ($24<<24>>24)==(0);
           if ($46) {
            break;
           }
           $i2$05$i = 0;$p1$04$i = $36;
           while(1) {
            $47 = (($p1$04$i) + 4|0);
            $48 = HEAP32[$p1$04$i>>2]|0;
            $49 = (_llvm_bswap_i32(($48|0))|0);
            HEAP32[$p1$04$i>>2] = $49;
            $50 = (($i2$05$i) + 1)|0;
            $exitcond7$i = ($50|0)==($25|0);
            if ($exitcond7$i) {
             break;
            } else {
             $i2$05$i = $50;$p1$04$i = $47;
            }
           }
          } else if ((($31|0) == 2)) {
           $37 = ($24<<24>>24)==(0);
           if ($37) {
            break;
           }
           $i$02$i = 0;$p$01$i = $36;
           while(1) {
            $38 = (($p$01$i) + 2|0);
            $39 = HEAP16[$p$01$i>>1]|0;
            $40 = $39&65535;
            $41 = $40 << 8;
            $42 = $40 >>> 8;
            $43 = $41 | $42;
            $44 = $43&65535;
            HEAP16[$p$01$i>>1] = $44;
            $45 = (($i$02$i) + 1)|0;
            $exitcond$i = ($45|0)==($25|0);
            if ($exitcond$i) {
             break;
            } else {
             $i$02$i = $45;$p$01$i = $38;
            }
           }
          } else {
           break;
          }
         }
        } while(0);
        $51 = Math_imul($31, $25)|0;
        $52 = (($51) + ($localOffset$04))|0;
        $localOffset$1 = $52;
       }
       $53 = (($23) + 1)|0;
       $54 = $20 << 1;
       $55 = ($53|0)<(8);
       $56 = ($54>>>0)<=($13>>>0);
       $or$cond1 = $55 & $56;
       if ($or$cond1) {
        $20 = $54;$23 = $53;$localOffset$04 = $localOffset$1;
       } else {
        break;
       }
      }
     }
     $57 = (($p$05) + ($5)|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $p$05 = $57;
     }
    }
   }
  }
  $59 = (($s$06) + 1)|0;
  $exitcond = ($59|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $s$06 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __Z20GetChannelFormatSizeh($format) {
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $format&255;
 $1 = (588304 + ($0)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 STACKTOP = sp;return ($3|0);
}
function __Z4swapR10VertexDataS0_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__t$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i$i$i = sp;
 $0 = HEAP32[$a>>2]|0;
 $1 = HEAP32[$b>>2]|0;
 HEAP32[$a>>2] = $1;
 HEAP32[$b>>2] = $0;
 $2 = (($a) + 4|0);
 $3 = (($b) + 4|0);
 $4 = HEAP32[$2>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$3>>2] = $4;
 $6 = (($a) + 8|0);
 $7 = (($b) + 8|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $9;
 HEAP32[$7>>2] = $8;
 $10 = (($a) + 12|0);
 $11 = (($b) + 12|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 HEAP32[$10>>2] = $13;
 HEAP32[$11>>2] = $12;
 $14 = (($a) + 16|0);
 $15 = (($b) + 16|0);
 $16 = HEAP32[$14>>2]|0;
 $17 = HEAP32[$15>>2]|0;
 HEAP32[$14>>2] = $17;
 HEAP32[$15>>2] = $16;
 $18 = (($a) + 20|0);
 $19 = (($b) + 20|0);
 $20 = HEAP32[$18>>2]|0;
 $21 = HEAP32[$19>>2]|0;
 HEAP32[$18>>2] = $21;
 HEAP32[$19>>2] = $20;
 $22 = (($a) + 24|0);
 $23 = (($b) + 24|0);
 $24 = HEAP32[$22>>2]|0;
 $25 = HEAP32[$23>>2]|0;
 HEAP32[$22>>2] = $25;
 HEAP32[$23>>2] = $24;
 $26 = (($a) + 28|0);
 $27 = (($b) + 28|0);
 $28 = HEAP32[$26>>2]|0;
 $29 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $29;
 HEAP32[$27>>2] = $28;
 $30 = (($a) + 32|0);
 $31 = (($b) + 32|0);
 ;HEAP32[$__t$i$i$i+0>>2]=HEAP32[$30+0>>2]|0;HEAP32[$__t$i$i$i+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$__t$i$i$i+8>>2]=HEAP32[$30+8>>2]|0;
 ;HEAP32[$30+0>>2]=HEAP32[$31+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$31+8>>2]|0;
 ;HEAP32[$31+0>>2]=HEAP32[$__t$i$i$i+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$__t$i$i$i+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$__t$i$i$i+8>>2]|0;
 $32 = (($a) + 44|0);
 $33 = (($b) + 44|0);
 ;HEAP32[$__t$i$i$i+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$__t$i$i$i+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$__t$i$i$i+8>>2]=HEAP32[$32+8>>2]|0;
 ;HEAP32[$32+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$33+8>>2]|0;
 ;HEAP32[$33+0>>2]=HEAP32[$__t$i$i$i+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$__t$i$i$i+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$__t$i$i$i+8>>2]|0;
 $34 = (($a) + 56|0);
 $35 = (($b) + 56|0);
 ;HEAP32[$__t$i$i$i+0>>2]=HEAP32[$34+0>>2]|0;HEAP32[$__t$i$i$i+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$__t$i$i$i+8>>2]=HEAP32[$34+8>>2]|0;
 ;HEAP32[$34+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$35+8>>2]|0;
 ;HEAP32[$35+0>>2]=HEAP32[$__t$i$i$i+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$__t$i$i$i+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$__t$i$i$i+8>>2]|0;
 $36 = (($a) + 68|0);
 $37 = (($b) + 68|0);
 ;HEAP32[$__t$i$i$i+0>>2]=HEAP32[$36+0>>2]|0;HEAP32[$__t$i$i$i+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$__t$i$i$i+8>>2]=HEAP32[$36+8>>2]|0;
 ;HEAP32[$36+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$37+8>>2]|0;
 ;HEAP32[$37+0>>2]=HEAP32[$__t$i$i$i+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$__t$i$i$i+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$__t$i$i$i+8>>2]|0;
 $38 = (($a) + 88|0);
 $39 = (($b) + 88|0);
 $40 = HEAP32[$38>>2]|0;
 $41 = HEAP32[$39>>2]|0;
 HEAP32[$38>>2] = $41;
 HEAP32[$39>>2] = $40;
 $42 = (($a) + 80|0);
 $43 = (($b) + 80|0);
 $44 = HEAP32[$42>>2]|0;
 $45 = HEAP32[$43>>2]|0;
 HEAP32[$42>>2] = $45;
 HEAP32[$43>>2] = $44;
 $46 = (($a) + 92|0);
 $47 = (($b) + 92|0);
 $48 = HEAP32[$46>>2]|0;
 $49 = HEAP32[$47>>2]|0;
 HEAP32[$46>>2] = $49;
 HEAP32[$47>>2] = $48;
 $50 = (($a) + 96|0);
 $51 = (($b) + 96|0);
 $52 = HEAP32[$50>>2]|0;
 $53 = HEAP32[$51>>2]|0;
 HEAP32[$50>>2] = $53;
 HEAP32[$51>>2] = $52;
 $54 = (($a) + 84|0);
 $55 = (($b) + 84|0);
 $56 = HEAP32[$54>>2]|0;
 $57 = HEAP32[$55>>2]|0;
 HEAP32[$54>>2] = $57;
 HEAP32[$55>>2] = $56;
 STACKTOP = sp;return;
}
function __Z22CopyVertexDataChannelsjjRK14VertexDataInfoRS_($vertexCount,$copyChannels,$srcData,$dstData) {
 $vertexCount = $vertexCount|0;
 $copyChannels = $copyChannels|0;
 $srcData = $srcData|0;
 $dstData = $dstData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($srcData) + 32|0);
 $1 = (($srcData) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($dstData) + 32|0);
 $4 = (($dstData) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 __ZL12CopyChannelsjjRA4_K10StreamInfoRA8_K11ChannelInfoPKhS2_S6_Ph($vertexCount,$copyChannels,$0,$srcData,$2,$3,$dstData,$5);
 STACKTOP = sp;return;
}
function __Z28BuildSingleStreamChannelInfojRK20VertexChannelsLayoutP11ChannelInfo($shaderChannelMask,$vertexChannels,$channels) {
 $shaderChannelMask = $shaderChannelMask|0;
 $vertexChannels = $vertexChannels|0;
 $channels = $channels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset$0$lcssa = 0, $offset$01 = 0, $offset$1 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($shaderChannelMask|0)==(0);
 if ($0) {
  $offset$0$lcssa = 0;
  STACKTOP = sp;return ($offset$0$lcssa|0);
 } else {
  $2 = 1;$5 = 0;$offset$01 = 0;
 }
 while(1) {
  $1 = $2 & $shaderChannelMask;
  $3 = ($1|0)==(0);
  if ($3) {
   $offset$1 = $offset$01;
  } else {
   $4 = (($vertexChannels) + ($5<<1)|0);
   $6 = (($channels) + ($5<<2)|0);
   HEAP8[$6>>0] = 0;
   $7 = $offset$01&255;
   $8 = ((($channels) + ($5<<2)|0) + 1|0);
   HEAP8[$8>>0] = $7;
   $9 = HEAP8[$4>>0]|0;
   $10 = ((($channels) + ($5<<2)|0) + 2|0);
   HEAP8[$10>>0] = $9;
   $11 = ((($vertexChannels) + ($5<<1)|0) + 1|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = ((($channels) + ($5<<2)|0) + 3|0);
   HEAP8[$13>>0] = $12;
   $14 = HEAPU8[$4>>0]|(HEAPU8[$4+1>>0]<<8);
   $15 = $14&65535;
   $16 = ($14&65535) >>> 8;
   $17 = $16&65535;
   $18 = $15 & 255;
   $19 = (588304 + ($18)|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20&255;
   $22 = Math_imul($17, $21)|0;
   $23 = (($22) + ($offset$01))|0;
   $offset$1 = $23;
  }
  $24 = (($5) + 1)|0;
  $25 = $2 << 1;
  $26 = ($24|0)<(8);
  $27 = ($25>>>0)<=($shaderChannelMask>>>0);
  $or$cond = $26 & $27;
  if ($or$cond) {
   $2 = $25;$5 = $24;$offset$01 = $offset$1;
  } else {
   $offset$0$lcssa = $offset$1;
   break;
  }
 }
 STACKTOP = sp;return ($offset$0$lcssa|0);
}
function __Z28BuildSingleStreamChannelInfojRK20VertexChannelsLayoutjS1_P11ChannelInfo($shaderChannelMask1,$vertexChannels1,$shaderChannelMask2,$vertexChannels2,$channels) {
 $shaderChannelMask1 = $shaderChannelMask1|0;
 $vertexChannels1 = $vertexChannels1|0;
 $shaderChannelMask2 = $shaderChannelMask2|0;
 $vertexChannels2 = $vertexChannels2|0;
 $channels = $channels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset$0$lcssa = 0, $offset$01 = 0, $offset$1 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $shaderChannelMask2 | $shaderChannelMask1;
 $1 = ($0|0)==(0);
 if ($1) {
  $offset$0$lcssa = 0;
  STACKTOP = sp;return ($offset$0$lcssa|0);
 } else {
  $3 = 1;$9 = 0;$offset$01 = 0;
 }
 while(1) {
  $2 = $3 & $0;
  $4 = ($2|0)==(0);
  if ($4) {
   $offset$1 = $offset$01;
  } else {
   $5 = $3 & $shaderChannelMask1;
   $6 = ($5|0)!=(0);
   $7 = $6 ? $vertexChannels1 : $vertexChannels2;
   $8 = (($7) + ($9<<1)|0);
   $10 = (($channels) + ($9<<2)|0);
   HEAP8[$10>>0] = 0;
   $11 = $offset$01&255;
   $12 = ((($channels) + ($9<<2)|0) + 1|0);
   HEAP8[$12>>0] = $11;
   $13 = HEAP8[$8>>0]|0;
   $14 = ((($channels) + ($9<<2)|0) + 2|0);
   HEAP8[$14>>0] = $13;
   $15 = ((($7) + ($9<<1)|0) + 1|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ((($channels) + ($9<<2)|0) + 3|0);
   HEAP8[$17>>0] = $16;
   $18 = HEAPU8[$8>>0]|(HEAPU8[$8+1>>0]<<8);
   $19 = $18&65535;
   $20 = ($18&65535) >>> 8;
   $21 = $20&65535;
   $22 = $19 & 255;
   $23 = (588304 + ($22)|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24&255;
   $26 = Math_imul($21, $25)|0;
   $27 = (($26) + ($offset$01))|0;
   $offset$1 = $27;
  }
  $28 = (($9) + 1)|0;
  $29 = $3 << 1;
  $30 = ($28|0)<(8);
  $31 = ($29>>>0)<=($0>>>0);
  $or$cond = $30 & $31;
  if ($or$cond) {
   $3 = $29;$9 = $28;$offset$01 = $offset$1;
  } else {
   $offset$0$lcssa = $offset$1;
   break;
  }
 }
 STACKTOP = sp;return ($offset$0$lcssa|0);
}
function __ZN11ChannelInfo8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP8[$this>>0]|0;
  HEAP8[$1>>0] = $6;
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 1|0);
  HEAP32[$0>>2] = $8;
  $11 = $8;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,1);
  $$pre = HEAP32[$0>>2]|0;
  $11 = $$pre;
 }
 $9 = (($this) + 1|0);
 $10 = (($11) + 1|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = HEAP8[$9>>0]|0;
  HEAP8[$11>>0] = $14;
  $15 = HEAP32[$0>>2]|0;
  $16 = (($15) + 1|0);
  HEAP32[$0>>2] = $16;
  $19 = $16;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$9,1);
  $$pre4 = HEAP32[$0>>2]|0;
  $19 = $$pre4;
 }
 $17 = (($this) + 2|0);
 $18 = (($19) + 1|0);
 $20 = HEAP32[$3>>2]|0;
 $21 = ($18>>>0)<($20>>>0);
 if ($21) {
  $22 = HEAP8[$17>>0]|0;
  HEAP8[$19>>0] = $22;
  $23 = HEAP32[$0>>2]|0;
  $24 = (($23) + 1|0);
  HEAP32[$0>>2] = $24;
  $27 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$17,1);
  $$pre5 = HEAP32[$0>>2]|0;
  $27 = $$pre5;
 }
 $25 = (($this) + 3|0);
 $26 = (($27) + 1|0);
 $28 = HEAP32[$3>>2]|0;
 $29 = ($26>>>0)<($28>>>0);
 if ($29) {
  $30 = HEAP8[$25>>0]|0;
  HEAP8[$27>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,1);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11ChannelInfoLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11ChannelInfoLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<2)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN11ChannelInfo8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 4|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = $23 << 2;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = $22 >> 2;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI11ChannelInfoLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 2;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,588280,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 2;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,588280,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 2;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<2)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<2)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   HEAP32[$$01$i$i>>2] = 0;
  }
  $30 = (($$01$i$i) + 4|0);
  $31 = ($30|0)==($25|0);
  if ($31) {
   break;
  } else {
   $$01$i$i = $30;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN11ChannelInfo8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,1);
  $$pre = HEAP32[$0>>2]|0;
  $11 = $$pre;
 } else {
  $6 = HEAP8[$1>>0]|0;
  HEAP8[$this>>0] = $6;
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 1|0);
  HEAP32[$0>>2] = $8;
  $11 = $8;
 }
 $9 = (($this) + 1|0);
 $10 = (($11) + 1|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,1);
  $$pre4 = HEAP32[$0>>2]|0;
  $19 = $$pre4;
 } else {
  $14 = HEAP8[$11>>0]|0;
  HEAP8[$9>>0] = $14;
  $15 = HEAP32[$0>>2]|0;
  $16 = (($15) + 1|0);
  HEAP32[$0>>2] = $16;
  $19 = $16;
 }
 $17 = (($this) + 2|0);
 $18 = (($19) + 1|0);
 $20 = HEAP32[$3>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,1);
  $$pre5 = HEAP32[$0>>2]|0;
  $27 = $$pre5;
 } else {
  $22 = HEAP8[$19>>0]|0;
  HEAP8[$17>>0] = $22;
  $23 = HEAP32[$0>>2]|0;
  $24 = (($23) + 1|0);
  HEAP32[$0>>2] = $24;
  $27 = $24;
 }
 $25 = (($this) + 3|0);
 $26 = (($27) + 1|0);
 $28 = HEAP32[$3>>2]|0;
 $29 = ($26>>>0)>($28>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,1);
  STACKTOP = sp;return;
 } else {
  $30 = HEAP8[$27>>0]|0;
  HEAP8[$25>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11ChannelInfoLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11ChannelInfoLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<2)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN11ChannelInfo8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 4|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 2;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 2;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11ChannelInfo8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,1);
  $$pre = HEAP32[$0>>2]|0;
  $11 = $$pre;
 } else {
  $6 = HEAP8[$1>>0]|0;
  HEAP8[$this>>0] = $6;
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 1|0);
  HEAP32[$0>>2] = $8;
  $11 = $8;
 }
 $9 = (($this) + 1|0);
 $10 = (($11) + 1|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,1);
  $$pre4 = HEAP32[$0>>2]|0;
  $19 = $$pre4;
 } else {
  $14 = HEAP8[$11>>0]|0;
  HEAP8[$9>>0] = $14;
  $15 = HEAP32[$0>>2]|0;
  $16 = (($15) + 1|0);
  HEAP32[$0>>2] = $16;
  $19 = $16;
 }
 $17 = (($this) + 2|0);
 $18 = (($19) + 1|0);
 $20 = HEAP32[$3>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,1);
  $$pre5 = HEAP32[$0>>2]|0;
  $27 = $$pre5;
 } else {
  $22 = HEAP8[$19>>0]|0;
  HEAP8[$17>>0] = $22;
  $23 = HEAP32[$0>>2]|0;
  $24 = (($23) + 1|0);
  HEAP32[$0>>2] = $24;
  $27 = $24;
 }
 $25 = (($this) + 3|0);
 $26 = (($27) + 1|0);
 $28 = HEAP32[$3>>2]|0;
 $29 = ($26>>>0)>($28>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,1);
  STACKTOP = sp;return;
 } else {
  $30 = HEAP8[$27>>0]|0;
  HEAP8[$25>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11ChannelInfoLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,588360,588360,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI11ChannelInfoLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<2)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,588312,588368,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN15SerializeTraitsI11ChannelInfoE8TransferI14SafeBinaryReadEEvRS0_RT_($i$01,$this);
       $48 = (($i$01) + 4|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,588312,588368,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN15SerializeTraitsI11ChannelInfoE8TransferI14SafeBinaryReadEEvRS0_RT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 4|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI11ChannelInfoE8TransferI14SafeBinaryReadEEvRS0_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i12 = 0, $$sum$i$i$i$i$i2 = 0, $$sum$i$i$i$i$i7 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i13 = 0, $$sum1$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i11 = sp;
 $0 = HEAP32[580744>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,588320,$0,$converter$i$i11,0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  do {
   if ($3) {
    $4 = (($transfer) + 12|0);
    $5 = (($transfer) + 80|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($6) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($transfer) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($transfer) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($transfer) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = Math_imul($14, $12)|0;
    $$sum$i$i$i$i$i2 = (($8) - ($15))|0;
    $16 = (($10) + ($$sum$i$i$i$i$i2)|0);
    HEAP32[$4>>2] = $16;
    $17 = ($$sum$i$i$i$i$i2|0)<(0);
    if (!($17)) {
     $$sum1$i$i$i$i$i3 = (($$sum$i$i$i$i$i2) + 1)|0;
     $18 = (($10) + ($$sum1$i$i$i$i$i3)|0);
     $19 = (($transfer) + 20|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($18>>>0)>($20>>>0);
     if (!($21)) {
      $22 = HEAP8[$16>>0]|0;
      HEAP8[$data>>0] = $22;
      $23 = HEAP32[$4>>2]|0;
      $24 = (($23) + 1|0);
      HEAP32[$4>>2] = $24;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($4,$data,1);
   } else {
    $25 = HEAP32[$converter$i$i11>>2]|0;
    $26 = ($25|0)==(0|0);
    if (!($26)) {
     (FUNCTION_TABLE_iii[$25 & 4095]($data,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $27 = (($data) + 1|0);
 $28 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,588328,$0,$converter$i$i11,0)|0);
 $29 = ($28|0)==(0);
 if (!($29)) {
  $30 = ($28|0)>(0);
  do {
   if ($30) {
    $31 = (($transfer) + 12|0);
    $32 = (($transfer) + 80|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($transfer) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($transfer) + 28|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($transfer) + 32|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = Math_imul($41, $39)|0;
    $$sum$i$i$i$i$i7 = (($35) - ($42))|0;
    $43 = (($37) + ($$sum$i$i$i$i$i7)|0);
    HEAP32[$31>>2] = $43;
    $44 = ($$sum$i$i$i$i$i7|0)<(0);
    if (!($44)) {
     $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
     $45 = (($37) + ($$sum1$i$i$i$i$i8)|0);
     $46 = (($transfer) + 20|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($45>>>0)>($47>>>0);
     if (!($48)) {
      $49 = HEAP8[$43>>0]|0;
      HEAP8[$27>>0] = $49;
      $50 = HEAP32[$31>>2]|0;
      $51 = (($50) + 1|0);
      HEAP32[$31>>2] = $51;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($31,$27,1);
   } else {
    $52 = HEAP32[$converter$i$i11>>2]|0;
    $53 = ($52|0)==(0|0);
    if (!($53)) {
     (FUNCTION_TABLE_iii[$52 & 4095]($27,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $54 = (($data) + 2|0);
 $55 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,588336,$0,$converter$i$i11,0)|0);
 $56 = ($55|0)==(0);
 if (!($56)) {
  $57 = ($55|0)>(0);
  do {
   if ($57) {
    $58 = (($transfer) + 12|0);
    $59 = (($transfer) + 80|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($60) + 12|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($transfer) + 16|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($transfer) + 28|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($transfer) + 32|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = Math_imul($68, $66)|0;
    $$sum$i$i$i$i$i12 = (($62) - ($69))|0;
    $70 = (($64) + ($$sum$i$i$i$i$i12)|0);
    HEAP32[$58>>2] = $70;
    $71 = ($$sum$i$i$i$i$i12|0)<(0);
    if (!($71)) {
     $$sum1$i$i$i$i$i13 = (($$sum$i$i$i$i$i12) + 1)|0;
     $72 = (($64) + ($$sum1$i$i$i$i$i13)|0);
     $73 = (($transfer) + 20|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($72>>>0)>($74>>>0);
     if (!($75)) {
      $76 = HEAP8[$70>>0]|0;
      HEAP8[$54>>0] = $76;
      $77 = HEAP32[$58>>2]|0;
      $78 = (($77) + 1|0);
      HEAP32[$58>>2] = $78;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($58,$54,1);
   } else {
    $79 = HEAP32[$converter$i$i11>>2]|0;
    $80 = ($79|0)==(0|0);
    if (!($80)) {
     (FUNCTION_TABLE_iii[$79 & 4095]($54,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $81 = (($data) + 3|0);
 $82 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,588344,$0,$converter$i$i11,0)|0);
 $83 = ($82|0)==(0);
 if ($83) {
  STACKTOP = sp;return;
 }
 $84 = ($82|0)>(0);
 do {
  if ($84) {
   $85 = (($transfer) + 12|0);
   $86 = (($transfer) + 80|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 12|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($transfer) + 16|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($transfer) + 28|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($transfer) + 32|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = Math_imul($95, $93)|0;
   $$sum$i$i$i$i$i = (($89) - ($96))|0;
   $97 = (($91) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$85>>2] = $97;
   $98 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($98)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $99 = (($91) + ($$sum1$i$i$i$i$i)|0);
    $100 = (($transfer) + 20|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ($99>>>0)>($101>>>0);
    if (!($102)) {
     $103 = HEAP8[$97>>0]|0;
     HEAP8[$81>>0] = $103;
     $104 = HEAP32[$85>>2]|0;
     $105 = (($104) + 1|0);
     HEAP32[$85>>2] = $105;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($85,$81,1);
  } else {
   $106 = HEAP32[$converter$i$i11>>2]|0;
   $107 = ($106|0)==(0|0);
   if (!($107)) {
    (FUNCTION_TABLE_iii[$106 & 4095]($81,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11ChannelInfo8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,588320,$0,$this,1);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 1|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,588328,$0,$7,1);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 2|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,588336,$0,$12,1);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 3|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,588344,$0,$17,1);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i3 = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $this;$12 = $$pre;$14 = $$pre16;$8 = $$pre$i$i$i3;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i8 = HEAP32[$10>>2]|0;
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $10;$17 = $$pre$i$i$i8;$21 = $$pre17;$23 = $$pre18;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i13 = HEAP32[$19>>2]|0;
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $19;$26 = $$pre$i$i$i13;$30 = $$pre19;$32 = $$pre20;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i = HEAP32[$28>>2]|0;
  $$pre$phi$i$i$iZ2D = $28;$35 = $$pre$i$i$i;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $36;
  STACKTOP = sp;return;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $28;$35 = $34;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $36;
  STACKTOP = sp;return;
 }
}
function __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 16|0);
 $1 = (__ZNK16TypeTreeIterator7GetNodeEv($0)|0);
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 | 2097152;
 $5 = (($t) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($t) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($7) + (($9*24)|0)|0) + 20|0);
 HEAP32[$10>>2] = $4;
 $11 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,588432,$11,$this,0);
 $12 = HEAP32[$5>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$8>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $16 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,588440,$11,$16,0);
 $17 = HEAP32[$5>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$8>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $21 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,588448,$11,$21,0);
 $22 = HEAP32[$5>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$8>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 $26 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($t,588456,$11,$26,0);
 $27 = HEAP32[$5>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$8>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($t);
 STACKTOP = sp;return;
}
function __ZN9BillboardD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = (($this) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 do {
  if ($8) {
   $9 = (($this) + 60|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 64|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$5>>2] = $12;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($10|0),($$byval_copy6|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$9>>2] = 0;
    label = 4;
    break;
   }
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $42 = (($this) + 56|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)>(-1);
   if ($44) {
    $45 = (($this) + 44|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($this) + 48|0);
    $48 = HEAP32[$47>>2]|0;
    HEAP32[$2>>2] = $48;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($46|0),($$byval_copy6|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     $73 = ___cxa_find_matching_catch(0|0)|0;
     $74 = tempRet0;
     ___clang_call_terminate($73);
     // unreachable;
    } else {
     HEAP32[$45>>2] = 0;
     $$0 = $41;$$01 = $40;
     label = 18;
     break;
    }
   } else {
    $$0 = $41;$$01 = $40;
    label = 18;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $15 = (($this) + 56|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(-1);
   do {
    if ($17) {
     $18 = (($this) + 44|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($this) + 48|0);
     $21 = HEAP32[$20>>2]|0;
     HEAP32[$4>>2] = $21;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($19|0),($$byval_copy6|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $51 = ___cxa_find_matching_catch()|0;
      $52 = tempRet0;
      $$0 = $52;$$01 = $51;
      label = 18;
      break L10;
     } else {
      HEAP32[$18>>2] = 0;
      break;
     }
    }
   } while(0);
   $24 = (($this) + 40|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(-1);
   do {
    if ($26) {
     $27 = (($this) + 28|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($this) + 32|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$3>>2] = $30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($28|0),($$byval_copy6|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $53 = ___cxa_find_matching_catch()|0;
      $54 = tempRet0;
      $$1 = $54;$$12 = $53;
      break L10;
     } else {
      HEAP32[$27>>2] = 0;
      break;
     }
    }
   } while(0);
   $33 = (($this) + 24|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)>(-1);
   if (!($35)) {
    STACKTOP = sp;return;
   }
   $36 = (($this) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($this) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$0>>2] = $39;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy6);
   HEAP32[$36>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 18) {
   $55 = (($this) + 40|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)>(-1);
   if ($57) {
    $58 = (($this) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($this) + 32|0);
    $61 = HEAP32[$60>>2]|0;
    HEAP32[$1>>2] = $61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($59|0),($$byval_copy6|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $73 = ___cxa_find_matching_catch(0|0)|0;
     $74 = tempRet0;
     ___clang_call_terminate($73);
     // unreachable;
    } else {
     HEAP32[$58>>2] = 0;
     $$1 = $$0;$$12 = $$01;
     break;
    }
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 $64 = (($this) + 24|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)>(-1);
 if (!($66)) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $67 = (($this) + 12|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($this) + 16|0);
 $70 = HEAP32[$69>>2]|0;
 HEAP32[$0>>2] = $70;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($68|0),($$byval_copy6|0));
 $71 = __THREW__; __THREW__ = 0;
 $72 = $71&1;
 if ($72) {
  $73 = ___cxa_find_matching_catch(0|0)|0;
  $74 = tempRet0;
  ___clang_call_terminate($73);
  // unreachable;
 }
 HEAP32[$67>>2] = 0;
 ___resumeException($$12|0);
 // unreachable;
}
function __Z24GetBillboardBatchManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[589736>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZL31InitializeBillboardBatchManagerv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628440>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(96,$$byval_copy,0,16,589824,149)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$2>>2] = $3;
 $5 = (($2) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($2) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 12|0);
 HEAP32[$7>>2] = $5;
 $8 = (($2) + 28|0);
 HEAP32[$8>>2] = 0;
 $9 = (($2) + 32|0);
 HEAP32[$9>>2] = 0;
 $10 = HEAP32[628512>>2]|0;
 $11 = (($2) + 36|0);
 HEAP32[$11>>2] = 0;
 $12 = (($2) + 40|0);
 HEAP32[$12>>2] = $10;
 $13 = (($2) + 44|0);
 ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
 $14 = HEAP32[628440>>2]|0;
 $15 = (($2) + 60|0);
 HEAP32[$15>>2] = 0;
 $16 = (($2) + 64|0);
 HEAP32[$16>>2] = $14;
 $17 = (($2) + 68|0);
 HEAP32[$17>>2] = 0;
 $18 = (($2) + 72|0);
 HEAP32[$18>>2] = 0;
 $19 = (($2) + 76|0);
 HEAP32[$19>>2] = 0;
 $20 = (($2) + 80|0);
 HEAP32[$20>>2] = $14;
 $21 = (($2) + 84|0);
 HEAP32[$21>>2] = 0;
 $22 = (($2) + 88|0);
 HEAP32[$22>>2] = 0;
 $23 = (($2) + 92|0);
 $24 = HEAP32[641904>>2]|0;
 HEAP32[$23>>2] = $24;
 $25 = (($2) + 24|0);
 HEAP8[$25>>0] = 0;
 HEAP32[589736>>2] = $2;
 STACKTOP = sp;return;
}
function __ZL28DestroyBillboardBatchManagerv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[589736>>2]|0;
 $2 = HEAP32[628440>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN21BillboardBatchManagerD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[589736>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN21BillboardBatchManagerD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy11 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 60|0);
 $4 = (($this) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(-1);
 do {
  if ($6) {
   $7 = (($this) + 76|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 80|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$2>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy11|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    HEAP32[$7>>2] = 0;
    label = 4;
    break;
   }
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $23 = (($this) + 72|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)>(-1);
   if ($25) {
    $26 = HEAP32[$3>>2]|0;
    $27 = (($this) + 64|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$0>>2] = $28;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($26|0),($$byval_copy11|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     HEAP32[$3>>2] = 0;
     $eh$lpad$body$index3Z2D = $22;$eh$lpad$body$indexZ2D = $21;
     label = 16;
     break;
    }
   } else {
    $eh$lpad$body$index3Z2D = $22;$eh$lpad$body$indexZ2D = $21;
    label = 16;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $13 = (($this) + 72|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)>(-1);
   do {
    if ($15) {
     $16 = HEAP32[$3>>2]|0;
     $17 = (($this) + 64|0);
     $18 = HEAP32[$17>>2]|0;
     HEAP32[$1>>2] = $18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($16|0),($$byval_copy11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      $47 = ___cxa_find_matching_catch()|0;
      $48 = tempRet0;
      $eh$lpad$body$index3Z2D = $48;$eh$lpad$body$indexZ2D = $47;
      label = 16;
      break L10;
     } else {
      HEAP32[$3>>2] = 0;
      break;
     }
    }
   } while(0);
   $33 = (($this) + 48|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)>(-1);
   if (!($35)) {
    $42 = (($this) + 12|0);
    $43 = (($this) + 16|0);
    $44 = HEAP32[$43>>2]|0;
    __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($42,$44);
    $45 = (($this) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeIiN21BillboardBatchManager18BillboardAssetDataEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$46);
    STACKTOP = sp;return;
   }
   $36 = (($this) + 36|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($this) + 40|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$0>>2] = $39;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($37|0),($$byval_copy11|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    $$0 = $59;$$01 = $58;
    break;
   }
   HEAP32[$36>>2] = 0;
   $42 = (($this) + 12|0);
   $43 = (($this) + 16|0);
   $44 = HEAP32[$43>>2]|0;
   __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($42,$44);
   $45 = (($this) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIiN21BillboardBatchManager18BillboardAssetDataEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$46);
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   $49 = (($this) + 48|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)>(-1);
   if ($51) {
    $52 = (($this) + 36|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($this) + 40|0);
    $55 = HEAP32[$54>>2]|0;
    HEAP32[$0>>2] = $55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($53|0),($$byval_copy11|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $65 = ___cxa_find_matching_catch(0|0)|0;
     $66 = tempRet0;
     ___clang_call_terminate($65);
     // unreachable;
    } else {
     HEAP32[$52>>2] = 0;
     $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
     break;
    }
   } else {
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
   }
  }
 } while(0);
 $60 = (($this) + 12|0);
 $61 = (($this) + 16|0);
 $62 = HEAP32[$61>>2]|0;
 __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($60,$62);
 $63 = (($this) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN21BillboardBatchManager18BillboardAssetDataEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$64);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN21BillboardBatchManager8RegisterERK4PPtrI14BillboardAssetE($this,$asset) {
 $this = $this|0;
 $asset = $asset|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $0 = sp + 312|0;
 $1 = sp;
 $2 = sp + 104|0;
 $3 = sp + 208|0;
 $4 = HEAP32[$asset>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($3) + 16|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 $7 = HEAP32[628440>>2]|0;
 $8 = (($3) + 32|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;
 HEAP32[$8>>2] = $7;
 $9 = (($3) + 36|0);
 HEAP32[$9>>2] = 0;
 $10 = (($3) + 40|0);
 HEAP32[$10>>2] = 0;
 $11 = (($3) + 44|0);
 HEAP32[$11>>2] = 0;
 $12 = (($3) + 48|0);
 HEAP32[$12>>2] = $7;
 $13 = (($3) + 52|0);
 HEAP32[$13>>2] = 0;
 $14 = (($3) + 56|0);
 HEAP32[$14>>2] = 0;
 $15 = (($3) + 60|0);
 HEAP32[$15>>2] = 0;
 $16 = (($3) + 64|0);
 HEAP32[$16>>2] = $7;
 $17 = (($3) + 68|0);
 HEAP32[$17>>2] = 0;
 $18 = (($3) + 72|0);
 HEAP32[$18>>2] = 0;
 $19 = (($3) + 76|0);
 HEAP32[$19>>2] = 0;
 $20 = (($3) + 80|0);
 HEAP32[$20>>2] = $7;
 $21 = (($3) + 84|0);
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
 HEAP32[$2>>2] = $4;
 $22 = (($2) + 4|0);
 ;HEAP32[$22+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$3+12>>2]|0;
 $23 = (($2) + 20|0);
 __THREW__ = 0;
 invoke_vii(2693,($23|0),($6|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 L4: do {
  if ($25) {
   label = 11;
  } else {
   $26 = (($2) + 100|0);
   $27 = (($3) + 96|0);
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$26>>2] = $28;
   $29 = HEAP32[$2>>2]|0;
   HEAP32[$1>>2] = $29;
   $30 = (($1) + 4|0);
   ;HEAP32[$30+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$22+12>>2]|0;
   $31 = (($1) + 20|0);
   __THREW__ = 0;
   invoke_vii(2693,($31|0),($23|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   do {
    if ($33) {
     label = 12;
    } else {
     $34 = (($1) + 100|0);
     $35 = HEAP32[$26>>2]|0;
     HEAP32[$34>>2] = $35;
     $36 = HEAP32[$2>>2]|0;
     HEAP32[$1>>2] = $36;
     __THREW__ = 0;
     invoke_viii(1725,($0|0),($this|0),($1|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $42 = ___cxa_find_matching_catch()|0;
      $43 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3463,($31|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       $eh$lpad$body$index2Z2D = $43;$eh$lpad$body$indexZ2D = $42;
       break;
      }
      $46 = ___cxa_find_matching_catch(0|0)|0;
      $47 = tempRet0;
      ___clang_call_terminate($46);
      // unreachable;
     }
     $39 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3463,($31|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      label = 12;
     } else {
      __THREW__ = 0;
      invoke_vi(3463,($23|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 11;
       break L4;
      }
      __ZN9BillboardD2Ev($6);
      $50 = (($39) + 16|0);
      $51 = (($39) + 20|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      (__ZN21BillboardBatchManager5BatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$50)|0);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 12) {
    $56 = ___cxa_find_matching_catch()|0;
    $57 = tempRet0;
    $eh$lpad$body$index2Z2D = $57;$eh$lpad$body$indexZ2D = $56;
   }
   __THREW__ = 0;
   invoke_vi(3463,($23|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $62 = ___cxa_find_matching_catch(0|0)|0;
    $63 = tempRet0;
    ___clang_call_terminate($62);
    // unreachable;
   } else {
    $$0 = $eh$lpad$body$index2Z2D;$$01 = $eh$lpad$body$indexZ2D;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  $$0 = $55;$$01 = $54;
 }
 __THREW__ = 0;
 invoke_vi(3463,($6|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 if ($61) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN21BillboardBatchManager5BatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$assetMapItem) {
 $this = $this|0;
 $assetMapItem = $assetMapItem|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i6 = 0, $$0$i5 = 0, $$01$i$i = 0, $$byval_copy3 = 0, $$ph = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $$pre26 = 0, $$pre26$pre = 0, $$pre28 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $billboardsInBatch$012 = 0, $billboardsInBatch$1 = 0, $i$014 = 0, $i1$010 = 0, $imagesInBatch$0$lcssa29 = 0, $imagesInBatch$013 = 0, $imagesInBatch$1 = 0;
 var $indexInBatch$030 = 0, $indexInBatch$031 = 0, $phitmp$i = 0, $selectedBatch = 0, $temp$0$i = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy3 = sp;
 $0 = sp + 36|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $selectedBatch = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($assetMapItem) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP32[$assetMapItem>>2]|0;
 HEAP32[$0>>2] = $8;
 $9 = HEAP32[560624>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($9) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($9) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12|0)==($14|0);
 do {
  if ($15) {
   $16 = (($9) + 28|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($9) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + ($19<<3)|0);
   $36 = $20;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$9,$0);
   $21 = HEAP32[$$byval_copy3>>2]|0;
   $22 = ($21|0)==(-1);
   $23 = (($9) + 28|0);
   $24 = HEAP32[$23>>2]|0;
   if ($22) {
    $25 = (($9) + 32|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + ($26<<3)|0);
    $36 = $27;
    break;
   } else {
    $28 = (($24) + ($21<<3)|0);
    $36 = $28;
    break;
   }
  }
 } while(0);
 $29 = HEAP32[560624>>2]|0;
 $30 = (($29) + 28|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 32|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + ($33<<3)|0);
 $35 = ($36|0)==($34|0);
 if ($35) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = (($36) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = (($38) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 >>> 21;
 $43 = HEAP32[560640>>2]|0;
 $44 = Math_imul($43, $42)|0;
 $45 = (($44) + 226)|0;
 $46 = $45 >> 5;
 $47 = $46 << 5;
 $48 = (($45) - ($47))|0;
 $49 = HEAP32[560632>>2]|0;
 $50 = (($49) + ($46<<2)|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = 1 << $48;
 $53 = $52 & $51;
 $54 = ($53|0)==(0);
 if ($54) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $55 = (($38) + 28|0);
 $56 = (($38) + 104|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0);
 if ($58) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$2>>2] = $57;
 $59 = ($29|0)==(0|0);
 if ($59) {
  label = 19;
 } else {
  $60 = (($29) + 36|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($29) + 4|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($61|0)==($63|0);
  do {
   if ($64) {
    $78 = $34;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$29,$2);
    $65 = HEAP32[$$byval_copy3>>2]|0;
    $66 = ($65|0)==(-1);
    $67 = HEAP32[$30>>2]|0;
    if ($66) {
     $68 = HEAP32[$32>>2]|0;
     $69 = (($67) + ($68<<3)|0);
     $78 = $69;
     break;
    } else {
     $70 = (($67) + ($65<<3)|0);
     $78 = $70;
     break;
    }
   }
  } while(0);
  $71 = HEAP32[560624>>2]|0;
  $72 = (($71) + 28|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($71) + 32|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($73) + ($75<<3)|0);
  $77 = ($78|0)==($76|0);
  if ($77) {
   label = 19;
  } else {
   $79 = (($78) + 4|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    label = 19;
   }
  }
 }
 if ((label|0) == 19) {
  $82 = HEAP32[$56>>2]|0;
  $83 = (__Z31ReadObjectFromPersistentManageri($82)|0);
  $phitmp$i = ($83|0)==(0|0);
  if ($phitmp$i) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $84 = (($38) + 40|0);
 $85 = (($84) + 8|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(0);
 if ($87) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $88 = ($86>>>0)>(32);
 if ($88) {
  $89 = HEAP32[$38>>2]|0;
  $90 = (($89) + 32|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (FUNCTION_TABLE_ii[$91 & 4095]($38)|0);
  HEAP32[$$byval_copy3>>2] = $92;
  $vararg_ptr1 = (($$byval_copy3) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 32;
  __Z6FormatPKcz($3,589768,$$byval_copy3);
  $93 = HEAP8[$3>>0]|0;
  $94 = $93 & 1;
  $95 = ($94<<24>>24)==(0);
  if ($95) {
   $98 = (($3) + 1|0);
   $99 = $98;
  } else {
   $96 = (($3) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $99 = $97;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($99|0),0,(589824|0),523,1,0,0,(0|0));
  $100 = __THREW__; __THREW__ = 0;
  $101 = $100&1;
  if ($101) {
   $107 = ___cxa_find_matching_catch()|0;
   $108 = tempRet0;
   $109 = HEAP8[$3>>0]|0;
   $110 = $109 & 1;
   $111 = ($110<<24>>24)==(0);
   if ($111) {
    ___resumeException($107|0);
    // unreachable;
   }
   $112 = (($3) + 8|0);
   $113 = HEAP32[$112>>2]|0;
   __ZdlPv($113);
   ___resumeException($107|0);
   // unreachable;
  } else {
   $102 = HEAP8[$3>>0]|0;
   $103 = $102 & 1;
   $104 = ($103<<24>>24)==(0);
   if ($104) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $105 = (($3) + 8|0);
   $106 = HEAP32[$105>>2]|0;
   __ZdlPv($106);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $114 = HEAP32[$56>>2]|0;
 $115 = ($114|0)==(0);
 if ($115) {
  $$0$i5 = 0;
 } else {
  HEAP32[$1>>2] = $114;
  $116 = HEAP32[560624>>2]|0;
  $117 = ($116|0)==(0|0);
  if ($117) {
   label = 39;
  } else {
   $118 = (($116) + 36|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = (($116) + 4|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($119|0)==($121|0);
   do {
    if ($122) {
     $123 = (($116) + 28|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = (($116) + 32|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = (($124) + ($126<<3)|0);
     $143 = $127;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$116,$1);
     $128 = HEAP32[$$byval_copy3>>2]|0;
     $129 = ($128|0)==(-1);
     $130 = (($116) + 28|0);
     $131 = HEAP32[$130>>2]|0;
     if ($129) {
      $132 = (($116) + 32|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = (($131) + ($133<<3)|0);
      $143 = $134;
      break;
     } else {
      $135 = (($131) + ($128<<3)|0);
      $143 = $135;
      break;
     }
    }
   } while(0);
   $136 = HEAP32[560624>>2]|0;
   $137 = (($136) + 28|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = (($136) + 32|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = (($138) + ($140<<3)|0);
   $142 = ($143|0)==($141|0);
   if ($142) {
    label = 39;
   } else {
    $144 = (($143) + 4|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = ($145|0)==(0|0);
    if ($146) {
     label = 39;
    } else {
     $temp$0$i = $145;
    }
   }
  }
  if ((label|0) == 39) {
   $147 = HEAP32[$56>>2]|0;
   $148 = (__Z31ReadObjectFromPersistentManageri($147)|0);
   $temp$0$i = $148;
  }
  $$0$i5 = $temp$0$i;
 }
 $149 = (__ZL28ComputeBillboardMaterialHashPN5Unity8MaterialE($$0$i5)|0);
 HEAP32[$selectedBatch>>2] = 0;
 $150 = (($this) + 12|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = (($this) + 16|0);
 $153 = ($151|0)==($152|0);
 L76: do {
  if ($153) {
   label = 56;
  } else {
   $155 = $151;
   L77: while(1) {
    $154 = (($155) + 16|0);
    $156 = HEAP32[$154>>2]|0;
    $157 = HEAP32[$156>>2]|0;
    $158 = ($157|0)==($149|0);
    do {
     if ($158) {
      $159 = (($156) + 28|0);
      $160 = HEAP32[$159>>2]|0;
      $161 = ($160|0)==(0);
      if ($161) {
       $imagesInBatch$0$lcssa29 = 0;
      } else {
       $162 = (($156) + 20|0);
       $163 = HEAP32[$162>>2]|0;
       $billboardsInBatch$012 = 0;$i$014 = 0;$imagesInBatch$013 = 0;
       while(1) {
        $164 = (($163) + ($i$014<<2)|0);
        $165 = HEAP32[$164>>2]|0;
        $166 = ($165|0)==(0|0);
        if ($166) {
         $billboardsInBatch$1 = $billboardsInBatch$012;$imagesInBatch$1 = $imagesInBatch$013;
        } else {
         $167 = (($billboardsInBatch$012) + 1)|0;
         $168 = (($165) + 40|0);
         $169 = HEAP32[$168>>2]|0;
         $170 = (($169) + ($imagesInBatch$013))|0;
         $billboardsInBatch$1 = $167;$imagesInBatch$1 = $170;
        }
        $171 = (($i$014) + 1)|0;
        $172 = ($171>>>0)<($160>>>0);
        if ($172) {
         $billboardsInBatch$012 = $billboardsInBatch$1;$i$014 = $171;$imagesInBatch$013 = $imagesInBatch$1;
        } else {
         break;
        }
       }
       $173 = ($billboardsInBatch$1>>>0)>(3);
       if ($173) {
        break;
       } else {
        $imagesInBatch$0$lcssa29 = $imagesInBatch$1;
       }
      }
      $174 = (($imagesInBatch$0$lcssa29) + ($86))|0;
      $175 = ($174>>>0)>(32);
      if (!($175)) {
       break L77;
      }
     }
    } while(0);
    $176 = (($155) + 4|0);
    $177 = HEAP32[$176>>2]|0;
    $178 = ($177|0)==(0|0);
    if ($178) {
     $$01$i$i = $155;
     while(1) {
      $181 = (($$01$i$i) + 8|0);
      $182 = HEAP32[$181>>2]|0;
      $183 = HEAP32[$182>>2]|0;
      $184 = ($183|0)==($$01$i$i|0);
      if ($184) {
       $$0$i$i6 = $182;
       break;
      } else {
       $$01$i$i = $182;
      }
     }
    } else {
     $$0$i$i$i = $177;
     while(1) {
      $179 = HEAP32[$$0$i$i$i>>2]|0;
      $180 = ($179|0)==(0|0);
      if ($180) {
       $$0$i$i6 = $$0$i$i$i;
       break;
      } else {
       $$0$i$i$i = $179;
      }
     }
    }
    $185 = ($$0$i$i6|0)==($152|0);
    if ($185) {
     label = 56;
     break L76;
    } else {
     $155 = $$0$i$i6;
    }
   }
   HEAP32[$selectedBatch>>2] = $156;
   $186 = ($156|0)==(0|0);
   if ($186) {
    label = 56;
   } else {
    $199 = $156;
   }
  }
 } while(0);
 if ((label|0) == 56) {
  $187 = HEAP32[628440>>2]|0;
  HEAP32[$4>>2] = $187;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;
  $188 = (__Znwj10MemLabelIdbiPKci(36,$$byval_copy3,0,16,589824,560)|0);
  $189 = (($188) + 4|0);
  HEAP32[$189>>2] = 0;
  $190 = (($188) + 8|0);
  HEAP8[$190>>0] = 1;
  $191 = (($188) + 12|0);
  HEAP32[$191>>2] = 0;
  $192 = (($188) + 16|0);
  HEAP8[$192>>0] = 1;
  $193 = HEAP32[628440>>2]|0;
  $194 = (($188) + 20|0);
  HEAP32[$194>>2] = 0;
  $195 = (($188) + 24|0);
  HEAP32[$195>>2] = $193;
  $196 = (($188) + 28|0);
  HEAP32[$196>>2] = 0;
  $197 = (($188) + 32|0);
  HEAP32[$197>>2] = 0;
  HEAP32[$selectedBatch>>2] = $188;
  HEAP32[$188>>2] = $149;
  __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE15__insert_uniqueERKS3_($$byval_copy3,$150,$selectedBatch);
  $$pre = HEAP32[$selectedBatch>>2]|0;
  $199 = $$pre;
 }
 $198 = (($199) + 8|0);
 HEAP8[$198>>0] = 1;
 $200 = (($199) + 16|0);
 HEAP8[$200>>0] = 1;
 $201 = (($199) + 28|0);
 $202 = HEAP32[$201>>2]|0;
 $203 = ($202|0)==(0);
 L102: do {
  if ($203) {
   $$ph = 0;
   label = 61;
  } else {
   $$phi$trans$insert = (($199) + 20|0);
   $$pre28 = HEAP32[$$phi$trans$insert>>2]|0;
   $i1$010 = 0;
   while(1) {
    $206 = (($$pre28) + ($i1$010<<2)|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = ($207|0)==(0|0);
    $205 = (($i1$010) + 1)|0;
    if ($208) {
     break;
    }
    $204 = ($205>>>0)<($202>>>0);
    if ($204) {
     $i1$010 = $205;
    } else {
     $$ph = $202;
     label = 61;
     break L102;
    }
   }
   $210 = (($199) + 20|0);
   $211 = ($i1$010>>>0)<($202>>>0);
   if ($211) {
    $212 = HEAP32[$210>>2]|0;
    $213 = (($212) + ($i1$010<<2)|0);
    HEAP32[$213>>2] = $assetMapItem;
    $242 = $199;$indexInBatch$030 = $i1$010;
   } else {
    $215 = $202;$226 = $210;$indexInBatch$031 = $i1$010;
    label = 64;
   }
  }
 } while(0);
 if ((label|0) == 61) {
  $209 = (($199) + 20|0);
  $215 = $$ph;$226 = $209;$indexInBatch$031 = $$ph;
  label = 64;
 }
 if ((label|0) == 64) {
  $214 = (($215) + 1)|0;
  HEAP32[$201>>2] = $214;
  $216 = (($199) + 32|0);
  $217 = HEAP32[$216>>2]|0;
  $218 = $217 & 2147483647;
  $219 = ($214>>>0)>($218>>>0);
  if ($219) {
   $220 = $217 << 1;
   $221 = ($220|0)==(0);
   $222 = $221 ? 1 : $220;
   $223 = ($218>>>0)<($222>>>0);
   do {
    if ($223) {
     $224 = ($217|0)>(-1);
     if ($224) {
      HEAP32[$216>>2] = $222;
      $225 = HEAP32[$226>>2]|0;
      $227 = $222 << 2;
      $228 = (($199) + 24|0);
      $229 = HEAP32[$228>>2]|0;
      HEAP32[$0>>2] = $229;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $230 = (__Z16realloc_internalPvji10MemLabelIdiPKci($225,$227,4,$$byval_copy3,0,589824,370)|0);
      HEAP32[$226>>2] = $230;
      break;
     } else {
      $231 = $222 << 2;
      $232 = (($199) + 24|0);
      $233 = HEAP32[$232>>2]|0;
      HEAP32[$0>>2] = $233;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $234 = (__Z15malloc_internaljj10MemLabelIdiPKci($231,4,$$byval_copy3,0,589824,352)|0);
      $235 = HEAP32[$226>>2]|0;
      $236 = HEAP32[$201>>2]|0;
      $237 = $236 << 2;
      _memcpy(($234|0),($235|0),($237|0))|0;
      HEAP32[$216>>2] = $222;
      HEAP32[$226>>2] = $234;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$201>>2]|0;
   $$pre26$pre = HEAP32[$selectedBatch>>2]|0;
   $$pre26 = $$pre26$pre;$239 = $$pre$i$i;
  } else {
   $$pre26 = $199;$239 = $214;
  }
  $238 = (($239) + -1)|0;
  $240 = HEAP32[$226>>2]|0;
  $241 = (($240) + ($238<<2)|0);
  HEAP32[$241>>2] = $assetMapItem;
  $242 = $$pre26;$indexInBatch$030 = $indexInBatch$031;
 }
 HEAP32[$5>>2] = $242;
 $243 = (($assetMapItem) + 20|0);
 (__ZN9BillboardaSERKS_($243,$55)|0);
 $244 = (__Z8CRCBeginv()|0);
 $245 = (__Z7CRCFeedjPKhj($244,$55,4)|0);
 $246 = (($55) + 8|0);
 $247 = (__Z7CRCFeedjPKhj($245,$246,4)|0);
 $248 = (($55) + 4|0);
 $249 = (__Z7CRCFeedjPKhj($247,$248,4)|0);
 $250 = (($55) + 12|0);
 $251 = HEAP32[$250>>2]|0;
 $252 = (($55) + 20|0);
 $253 = HEAP32[$252>>2]|0;
 $254 = $253 << 4;
 $255 = (__Z7CRCFeedjPKhj($249,$251,$254)|0);
 $256 = (($55) + 28|0);
 $257 = HEAP32[$256>>2]|0;
 $258 = (($55) + 36|0);
 $259 = HEAP32[$258>>2]|0;
 $260 = (__Z7CRCFeedjPKhj($255,$257,$259)|0);
 $261 = (__Z7CRCDonej($260)|0);
 $262 = (($assetMapItem) + 8|0);
 HEAP32[$262>>2] = $261;
 $263 = (__Z8CRCBeginv()|0);
 $264 = (($55) + 44|0);
 $265 = HEAP32[$264>>2]|0;
 $266 = (($55) + 52|0);
 $267 = HEAP32[$266>>2]|0;
 $268 = $267 << 3;
 $269 = (__Z7CRCFeedjPKhj($263,$265,$268)|0);
 $270 = (($55) + 60|0);
 $271 = HEAP32[$270>>2]|0;
 $272 = (($55) + 68|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = $273 << 1;
 $275 = (__Z7CRCFeedjPKhj($269,$271,$274)|0);
 $276 = (__Z7CRCDonej($275)|0);
 $277 = (($assetMapItem) + 12|0);
 HEAP32[$277>>2] = $276;
 $278 = (__ZN21BillboardBatchManager19CreateBillboardMeshERK9Billboardj(0,$55,$indexInBatch$030)|0);
 $279 = (($assetMapItem) + 100|0);
 HEAP32[$279>>2] = $278;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN21BillboardBatchManager10UnregisterERK4PPtrI14BillboardAssetE($this,$asset) {
 $this = $this|0;
 $asset = $asset|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$i$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$asset>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = ($3|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $$0$ph7$i$i$i = $4;$$01$ph6$i$in$i$i = $3;
 }
 L3: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $6 = (($$013$i$in$i$i) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)<($1|0);
   if (!($8)) {
    break;
   }
   $11 = (($$013$i$in$i$i) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L3;
   } else {
    $$013$i$in$i$i = $12;
   }
  }
  $9 = HEAP32[$$013$i$in$i$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
  }
 }
 $14 = ($$0$ph5$i$i$i|0)==($4|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($$0$ph5$i$i$i) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($1|0)<($16|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = (($$0$ph5$i$i$i) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + -1)|0;
 HEAP32[$18>>2] = $20;
 $21 = ($20|0)==(0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($$0$ph5$i$i$i) + 16|0);
 __ZN21BillboardBatchManager7UnbatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$22);
 $23 = (($$0$ph5$i$i$i) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $$01$i$i$i$i = $$0$ph5$i$i$i;
  while(1) {
   $28 = (($$01$i$i$i$i) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==($$01$i$i$i$i|0);
   if ($31) {
    $$0$i$i$i$i = $29;
    break;
   } else {
    $$01$i$i$i$i = $29;
   }
  }
 } else {
  $$0$i$i$i$i$i = $24;
  while(1) {
   $26 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $27 = ($26|0)==(0|0);
   if ($27) {
    $$0$i$i$i$i = $$0$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i = $26;
   }
  }
 }
 $32 = HEAP32[$this>>2]|0;
 $33 = ($32|0)==($$0$ph5$i$i$i|0);
 if ($33) {
  HEAP32[$this>>2] = $$0$i$i$i$i;
 }
 $34 = (($this) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + -1)|0;
 HEAP32[$34>>2] = $36;
 $37 = (($$0$ph5$i$i$i) + 36|0);
 __ZN9BillboardD2Ev($37);
 $38 = HEAP32[$2>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$$0$ph5$i$i$i);
 HEAP32[$0>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($$0$ph5$i$i$i|0),($$byval_copy|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  ___cxa_call_unexpected(($41|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN21BillboardBatchManager7UnbatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$assetMapItem) {
 $this = $this|0;
 $assetMapItem = $assetMapItem|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $batchIsEmpty$0$off0$ = 0, $batchIsEmpty$0$off05 = 0;
 var $batchIsEmpty$1$off0 = 0, $belongingBatch = 0, $i$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $belongingBatch = sp + 8|0;
 $2 = (($assetMapItem) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$belongingBatch>>2] = $3;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  label = 8;
 } else {
  $batchIsEmpty$0$off05 = 1;$i$06 = 0;
  while(1) {
   $8 = (($3) + 20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + ($i$06<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==($assetMapItem|0);
   if ($12) {
    HEAP32[$10>>2] = 0;
    $batchIsEmpty$1$off0 = $batchIsEmpty$0$off05;
   } else {
    $13 = ($11|0)==(0|0);
    $batchIsEmpty$0$off0$ = $13 & $batchIsEmpty$0$off05;
    $batchIsEmpty$1$off0 = $batchIsEmpty$0$off0$;
   }
   $14 = (($i$06) + 1)|0;
   $15 = ($14>>>0)<($6>>>0);
   if ($15) {
    $batchIsEmpty$0$off05 = $batchIsEmpty$1$off0;$i$06 = $14;
   } else {
    break;
   }
  }
  if ($batchIsEmpty$1$off0) {
   label = 8;
  } else {
   $31 = (($3) + 8|0);
   HEAP8[$31>>0] = 1;
   $32 = (($3) + 16|0);
   HEAP8[$32>>0] = 1;
  }
 }
 if ((label|0) == 8) {
  $16 = (($3) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  __Z19DestroySingleObjectP6Object($17);
  $18 = (($3) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  __Z19DestroySingleObjectP6Object($19);
  $20 = (($this) + 12|0);
  (__ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE14__erase_uniqueIS3_EEjRKT_($20,$belongingBatch)|0);
  $21 = HEAP32[$belongingBatch>>2]|0;
  $22 = HEAP32[628440>>2]|0;
  $23 = ($21|0)==(0|0);
  if (!($23)) {
   $24 = (($21) + 32|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(-1);
   if ($26) {
    $27 = (($21) + 20|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($21) + 24|0);
    $30 = HEAP32[$29>>2]|0;
    HEAP32[$0>>2] = $30;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
    HEAP32[$27>>2] = 0;
   }
  }
  HEAP32[$1>>2] = $22;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($21,$$byval_copy1);
  HEAP32[$belongingBatch>>2] = 0;
 }
 $33 = (($assetMapItem) + 100|0);
 $34 = HEAP32[$33>>2]|0;
 __Z19DestroySingleObjectP6Object($34);
 HEAP32[$2>>2] = 0;
 HEAP32[$33>>2] = 0;
 $35 = (($assetMapItem) + 8|0);
 HEAP32[$35>>2] = 0;
 $36 = (($assetMapItem) + 12|0);
 HEAP32[$36>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN21BillboardBatchManager19UpdateBatchMaterialERNS_14BillboardBatchEPPN5Unity8MaterialE($this,$batch,$materialPtr) {
 $this = $this|0;
 $batch = $batch|0;
 $materialPtr = $materialPtr|0;
 var $$byval_copy2 = 0, $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$06 = 0, $i1$04 = 0, $imageCount = 0;
 var $temp$0$i14 = 0, $validData$0$ = 0, $validData$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $imageCount = sp + 44|0;
 $3 = HEAP32[$materialPtr>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $5 = HEAP32[628384>>2]|0;
   HEAP32[$0>>2] = $5;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $6 = (__Znwj10MemLabelIdbiPKci(144,$$byval_copy2,1,16,589824,1111)|0);
   HEAP32[$1>>2] = $5;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1726,($6|0),($$byval_copy2|0),0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $15 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($6)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + 24|0);
    $18 = HEAP32[$17>>2]|0;
    FUNCTION_TABLE_vi[$18 & 4095]($15);
    $19 = HEAP32[$15>>2]|0;
    $20 = (($19) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    FUNCTION_TABLE_vii[$21 & 4095]($15,4);
    HEAP32[$materialPtr>>2] = $15;
    $22 = HEAP32[$15>>2]|0;
    $23 = (($22) + 44|0);
    $24 = HEAP32[$23>>2]|0;
    FUNCTION_TABLE_vii[$24 & 4095]($15,61);
    $25 = HEAP32[$materialPtr>>2]|0;
    $26 = HEAP32[$25>>2]|0;
    $27 = (($26) + 36|0);
    $28 = HEAP32[$27>>2]|0;
    FUNCTION_TABLE_vii[$28 & 4095]($25,589832);
    break;
   }
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viiiiii(97,($6|0),($$byval_copy2|0),1,16,(589824|0),1111);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $13 = ___cxa_find_matching_catch(0|0)|0;
    $14 = tempRet0;
    ___clang_call_terminate($13);
    // unreachable;
   } else {
    ___resumeException($9|0);
    // unreachable;
   }
  }
 } while(0);
 $29 = (($batch) + 20|0);
 $30 = (($batch) + 28|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$29>>2]|0;
 $i$06 = 0;$validData$07 = 0;
 while(1) {
  $33 = (($32) + ($i$06<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  $36 = (($34) + 4|0);
  $validData$0$ = $35 ? $validData$07 : $36;
  $37 = (($i$06) + 1)|0;
  $38 = ($37>>>0)<($31>>>0);
  if ($38) {
   $i$06 = $37;$validData$07 = $validData$0$;
  } else {
   break;
  }
 }
 $39 = (($validData$0$) + 92|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0);
 do {
  if ($41) {
   $42 = HEAP32[$materialPtr>>2]|0;
   $79 = $42;
  } else {
   HEAP32[$0>>2] = $40;
   $43 = HEAP32[560624>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    label = 20;
   } else {
    $45 = (($43) + 36|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($43) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($46|0)==($48|0);
    do {
     if ($49) {
      $50 = (($43) + 28|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = (($43) + 32|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (($51) + ($53<<3)|0);
      $70 = $54;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$43,$0);
      $55 = HEAP32[$$byval_copy2>>2]|0;
      $56 = ($55|0)==(-1);
      $57 = (($43) + 28|0);
      $58 = HEAP32[$57>>2]|0;
      if ($56) {
       $59 = (($43) + 32|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = (($58) + ($60<<3)|0);
       $70 = $61;
       break;
      } else {
       $62 = (($58) + ($55<<3)|0);
       $70 = $62;
       break;
      }
     }
    } while(0);
    $63 = HEAP32[560624>>2]|0;
    $64 = (($63) + 28|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($63) + 32|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($65) + ($67<<3)|0);
    $69 = ($70|0)==($68|0);
    if ($69) {
     label = 20;
    } else {
     $71 = (($70) + 4|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)==(0|0);
     if ($73) {
      label = 20;
     } else {
      $74 = HEAP32[$materialPtr>>2]|0;
      $$in = $72;$81 = $74;$temp$0$i14 = $72;
     }
    }
   }
   if ((label|0) == 20) {
    $75 = HEAP32[$39>>2]|0;
    $76 = (__Z31ReadObjectFromPersistentManageri($75)|0);
    $77 = ($76|0)==(0|0);
    $78 = HEAP32[$materialPtr>>2]|0;
    if ($77) {
     $79 = $78;
     break;
    } else {
     $$in = $76;$81 = $78;$temp$0$i14 = $76;
    }
   }
   $80 = (($81) + 72|0);
   $82 = (($2) + 4|0);
   $83 = (($2) + 4|0);
   ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
   HEAP32[$2>>2] = $83;
   $84 = (($2) + 16|0);
   HEAP32[$84>>2] = 0;
   $85 = (($2) + 20|0);
   HEAP32[$85>>2] = 0;
   $86 = (($2) + 16|0);
   $87 = (($2) + 12|0);
   HEAP32[$87>>2] = $86;
   $88 = (($2) + 28|0);
   HEAP32[$88>>2] = 0;
   $89 = (($2) + 32|0);
   HEAP32[$89>>2] = 0;
   $90 = (($2) + 28|0);
   $91 = (($2) + 24|0);
   HEAP32[$91>>2] = $90;
   __THREW__ = 0;
   (invoke_iii(2388,($80|0),($2|0))|0);
   $92 = __THREW__; __THREW__ = 0;
   $93 = $92&1;
   if ($93) {
    $126 = ___cxa_find_matching_catch()|0;
    $127 = tempRet0;
    $128 = (($2) + 24|0);
    $129 = HEAP32[$88>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($128,$129);
    $130 = (($2) + 12|0);
    $131 = HEAP32[$84>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($130,$131);
    $132 = HEAP32[$82>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($2,$132);
    ___resumeException($126|0);
    // unreachable;
   }
   $94 = (($2) + 24|0);
   $95 = HEAP32[$88>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($94,$95);
   $96 = (($2) + 12|0);
   $97 = HEAP32[$84>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($96,$97);
   $98 = HEAP32[$82>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($2,$98);
   $99 = (($temp$0$i14) + 72|0);
   __ZN18UnityPropertySheet21AddNewSerializedPropsERKS_($80,$99);
   $100 = (($81) + 96|0);
   $101 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_($100,589712)|0);
   ;HEAP32[$101+0>>2]=0|0;HEAP32[$101+4>>2]=0|0;HEAP32[$101+8>>2]=0|0;HEAP32[$101+12>>2]=0|0;
   HEAP32[$imageCount>>2] = 0;
   $102 = HEAP32[$30>>2]|0;
   $103 = ($102|0)==(0);
   if (!($103)) {
    $133 = $102;$i1$04 = 0;
    while(1) {
     $104 = HEAP32[$29>>2]|0;
     $105 = (($104) + ($i1$04<<2)|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ($106|0)==(0|0);
     if ($107) {
      $111 = $133;
     } else {
      $108 = (($106) + 20|0);
      __ZL19FillBatchPropertiesR18UnityPropertySheetRK9BillboardiRi($80,$108,$i1$04,$imageCount);
      $$pre = HEAP32[$30>>2]|0;
      $111 = $$pre;
     }
     $109 = (($i1$04) + 1)|0;
     $110 = ($109>>>0)<($111>>>0);
     if ($110) {
      $133 = $111;$i1$04 = $109;
     } else {
      break;
     }
    }
   }
   $112 = HEAP32[$materialPtr>>2]|0;
   $113 = (__ZN5Unity8Material9GetShaderEv($$in)|0);
   __ZN5Unity8Material9SetShaderEP6Shader($112,$113);
   $114 = HEAP32[$materialPtr>>2]|0;
   $115 = (($temp$0$i14) + 108|0);
   __ZN5Unity8Material17SetShaderKeywordsERK8UnityStr($114,$115);
   $116 = (__Z18GetQualitySettingsv()|0);
   $117 = (($116) + 40|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($116) + 24|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ((($120) + (($118*96)|0)|0) + 79|0);
   $122 = HEAP8[$121>>0]|0;
   $123 = ($122<<24>>24)==(0);
   $124 = HEAP32[$materialPtr>>2]|0;
   if ($123) {
    __ZN5Unity8Material14DisableKeywordERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($124,589664);
   } else {
    __ZN5Unity8Material13EnableKeywordERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($124,589664);
   }
   $125 = HEAP32[$materialPtr>>2]|0;
   __ZN5Unity8Material15ClearPropertiesEv($125);
   STACKTOP = sp;return;
  }
 } while(0);
 __ZN5Unity8Material9SetShaderEP6Shader($79,0);
 STACKTOP = sp;return;
}
function __ZN21BillboardBatchManager23GetMaterialIntermediateERK4PPtrI14BillboardAssetE($this,$asset) {
 $this = $this|0;
 $asset = $asset|0;
 var $$0 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$asset>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = ($2|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$ph7$i$i$i$i = $3;$$01$ph6$i$in$i$i$i = $2;
 }
 L3: while(1) {
  $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
  while(1) {
   $5 = (($$013$i$in$i$i$i) + 16|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)<($0|0);
   if (!($7)) {
    break;
   }
   $10 = (($$013$i$in$i$i$i) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
    break L3;
   } else {
    $$013$i$in$i$i$i = $11;
   }
  }
  $8 = HEAP32[$$013$i$in$i$i$i>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
   break;
  } else {
   $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $8;
  }
 }
 $13 = ($$0$ph5$i$i$i$i|0)==($3|0);
 if ($13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($$0$ph5$i$i$i$i) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($0|0)<($15|0);
 if ($16) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = (($$0$ph5$i$i$i$i) + 32|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = (($18) + 16|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $25 = $18;
 } else {
  $23 = (($18) + 12|0);
  __ZN21BillboardBatchManager19UpdateBatchMaterialERNS_14BillboardBatchEPPN5Unity8MaterialE(0,$18,$23);
  $$pre = HEAP32[$17>>2]|0;
  $25 = $$pre;
 }
 $24 = (($25) + 16|0);
 HEAP8[$24>>0] = 0;
 $26 = (($25) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function __ZN21BillboardBatchManager7GetMeshERK4PPtrI14BillboardAssetE($this,$asset) {
 $this = $this|0;
 $asset = $asset|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$asset>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = ($2|0)==(0|0);
 if ($4) {
  $19 = 0;
  STACKTOP = sp;return ($19|0);
 } else {
  $$0$ph7$i$i$i$i = $3;$$01$ph6$i$in$i$i$i = $2;
 }
 L3: while(1) {
  $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
  while(1) {
   $5 = (($$013$i$in$i$i$i) + 16|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)<($0|0);
   if (!($7)) {
    break;
   }
   $10 = (($$013$i$in$i$i$i) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
    break L3;
   } else {
    $$013$i$in$i$i$i = $11;
   }
  }
  $8 = HEAP32[$$013$i$in$i$i$i>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
   break;
  } else {
   $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $8;
  }
 }
 $13 = ($$0$ph5$i$i$i$i|0)==($3|0);
 if ($13) {
  $19 = 0;
  STACKTOP = sp;return ($19|0);
 }
 $14 = (($$0$ph5$i$i$i$i) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($0|0)<($15|0);
 if ($16) {
  $19 = 0;
  STACKTOP = sp;return ($19|0);
 }
 $17 = (($$0$ph5$i$i$i$i) + 116|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18;
 STACKTOP = sp;return ($19|0);
}
function __ZL19FillBatchPropertiesR18UnityPropertySheetRK9BillboardiRi($properties,$billboard,$shaderArrayIndex,$imageCount) {
 $properties = $properties|0;
 $billboard = $billboard|0;
 $shaderArrayIndex = $shaderArrayIndex|0;
 $imageCount = $imageCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $i$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($billboard) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (Math_fround(($1>>>0)));
 $3 = Math_fround(Math_fround(6.28318548202514648438) / $2);
 $4 = Math_fround(Math_fround(1.0) / $3);
 $5 = HEAP32[$imageCount>>2]|0;
 $6 = (Math_fround(($5|0)));
 $7 = (($properties) + 24|0);
 $8 = (588608 + ($shaderArrayIndex<<2)|0);
 $9 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_($7,$8)|0);
 HEAPF32[$9>>2] = $2;
 $10 = (($9) + 4|0);
 HEAPF32[$10>>2] = $4;
 $11 = (($9) + 8|0);
 HEAPF32[$11>>2] = $6;
 $12 = (($9) + 12|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = Math_fround(HEAPF32[$billboard>>2]);
 $14 = (($billboard) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($billboard) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (588688 + ($shaderArrayIndex<<2)|0);
 $19 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_($7,$18)|0);
 HEAPF32[$19>>2] = $13;
 $20 = (($19) + 4|0);
 HEAPF32[$20>>2] = $15;
 $21 = (($19) + 8|0);
 HEAPF32[$21>>2] = $17;
 $22 = (($19) + 12|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = HEAP32[$0>>2]|0;
 $24 = ($23|0)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (($billboard) + 12|0);
 $26 = (($billboard) + 28|0);
 $i$09 = 0;
 while(1) {
  $27 = HEAP32[$25>>2]|0;
  $28 = (($27) + ($i$09<<4)|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = ((($27) + ($i$09<<4)|0) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = ((($27) + ($i$09<<4)|0) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = ((($27) + ($i$09<<4)|0) + 12|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = HEAP32[$26>>2]|0;
  $37 = (($36) + ($i$09)|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $48 = $33;$50 = $35;
  } else {
   $40 = Math_fround($33 * Math_fround(-1.0));
   $41 = Math_fround($35 * Math_fround(-1.0));
   $48 = $40;$50 = $41;
  }
  $42 = HEAP32[$imageCount>>2]|0;
  $43 = (($42) + 1)|0;
  HEAP32[$imageCount>>2] = $43;
  $44 = (588768 + ($42<<2)|0);
  $45 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_($7,$44)|0);
  HEAPF32[$45>>2] = $29;
  $46 = (($45) + 4|0);
  HEAPF32[$46>>2] = $31;
  $47 = (($45) + 8|0);
  HEAPF32[$47>>2] = $48;
  $49 = (($45) + 12|0);
  HEAPF32[$49>>2] = $50;
  $51 = (($i$09) + 1)|0;
  $52 = HEAP32[$0>>2]|0;
  $53 = ($51>>>0)<($52>>>0);
  if ($53) {
   $i$09 = $51;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZL20FillCameraPropertiesR21MaterialPropertyBlockRK6Camera($properties,$camera) {
 $properties = $properties|0;
 $camera = $camera|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $angle$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = sp + 16|0;
 __ZNK6Camera22GetCameraToWorldMatrixEv($0,$camera);
 $3 = (($0) + 32|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($0) + 36|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($0) + 40|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[((616728 + 8|0))>>2]);
 $10 = Math_fround($6 * $9);
 $11 = Math_fround(HEAPF32[((616728 + 4|0))>>2]);
 $12 = Math_fround($8 * $11);
 $13 = Math_fround($10 - $12);
 $14 = Math_fround(HEAPF32[616728>>2]);
 $15 = Math_fround($8 * $14);
 $16 = Math_fround($4 * $9);
 $17 = Math_fround($15 - $16);
 $18 = Math_fround($4 * $11);
 $19 = Math_fround($6 * $14);
 $20 = Math_fround($18 - $19);
 $21 = Math_fround($13 * $13);
 $22 = Math_fround($17 * $17);
 $23 = Math_fround($21 + $22);
 $24 = Math_fround($20 * $20);
 $25 = Math_fround($24 + $23);
 $26 = $25 < Math_fround(0.0);
 if ($26) {
  $27 = Math_fround(-$25);
  $29 = $27;
 } else {
  $29 = $25;
 }
 $28 = !($29 <= Math_fround(9.99999997475242707878E-7));
 if ($28) {
  $30 = (Math_fround(Math_sqrt((Math_fround($25)))));
  $31 = Math_fround($13 / $30);
  $32 = Math_fround($17 / $30);
  $33 = Math_fround($20 / $30);
  $40 = $33;$42 = $32;$45 = $31;
 } else {
  $34 = Math_fround(HEAPF32[$0>>2]);
  $35 = (($0) + 4|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($0) + 8|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $40 = $38;$42 = $36;$45 = $34;
 }
 $39 = Math_fround($40 * $11);
 $41 = Math_fround($42 * $9);
 $43 = Math_fround($39 - $41);
 $44 = Math_fround($45 * $9);
 $46 = Math_fround($40 * $14);
 $47 = Math_fround($44 - $46);
 $48 = Math_fround($42 * $14);
 $49 = Math_fround($45 * $11);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($43 * $43);
 $52 = Math_fround($47 * $47);
 $53 = Math_fround($51 + $52);
 $54 = Math_fround($50 * $50);
 $55 = Math_fround($54 + $53);
 $56 = (Math_fround(Math_sqrt((Math_fround($55)))));
 $57 = Math_fround($43 / $56);
 $58 = Math_fround($47 / $56);
 $59 = Math_fround($50 / $56);
 $60 = Math_fround($40 * Math_fround(0.0));
 $61 = Math_fround($60 - $45);
 $62 = Math_fround($45 * Math_fround(0.0));
 $63 = Math_fround($40 + $62);
 $64 = (Math_fround(+(Math_atan2((+$61),(+$63)))));
 $65 = $64 < Math_fround(0.0);
 if ($65) {
  $66 = Math_fround($64 + Math_fround(6.28318548202514648438));
  $angle$0 = $66;
 } else {
  $angle$0 = $64;
 }
 HEAPF32[$1>>2] = $45;
 $67 = (($1) + 4|0);
 HEAPF32[$67>>2] = $42;
 $68 = (($1) + 8|0);
 HEAPF32[$68>>2] = $40;
 $69 = (($1) + 12|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($properties,588520,$1);
 HEAPF32[$2>>2] = $57;
 $70 = (($2) + 4|0);
 HEAPF32[$70>>2] = $58;
 $71 = (($2) + 8|0);
 HEAPF32[$71>>2] = $59;
 $72 = (($2) + 12|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($properties,588552,$2);
 __ZN21MaterialPropertyBlock16AddPropertyFloatERKN9ShaderLab16FastPropertyNameEf($properties,588584,$angle$0);
 STACKTOP = sp;return;
}
function __ZN21BillboardBatchManager10BeginBatchEPN5Unity8MaterialERK14ChannelAssigns($this,$rendererMaterial,$channels) {
 $this = $this|0;
 $rendererMaterial = $rendererMaterial|0;
 $channels = $channels|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 16|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $6 = $2;
 }
 while(1) {
  $5 = (($6) + 16|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($rendererMaterial|0);
  if ($10) {
   label = 9;
   break;
  }
  $11 = (($7) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($rendererMaterial|0);
  if ($13) {
   break;
  }
  $14 = (($6) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$01$i$i = $6;
   while(1) {
    $19 = (($$01$i$i) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$01$i$i|0);
    if ($22) {
     $$0$i$i = $20;
     break;
    } else {
     $$01$i$i = $20;
    }
   }
  } else {
   $$0$i$i$i = $15;
   while(1) {
    $17 = HEAP32[$$0$i$i$i>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $17;
    }
   }
  }
  $23 = ($$0$i$i|0)==($3|0);
  if ($23) {
   $$0 = 0;
   label = 13;
   break;
  } else {
   $6 = $$0$i$i;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 if ((label|0) == 9) {
  $24 = ($7|0)==(0|0);
  if ($24) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $25 = (($this) + 28|0);
 HEAP32[$25>>2] = $7;
 $26 = (($this) + 32|0);
 HEAP32[$26>>2] = $channels;
 $27 = (($this) + 48|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)>(-1);
 if ($29) {
  $30 = (($this) + 36|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($this) + 40|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$0>>2] = $33;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy);
  HEAP32[$30>>2] = 0;
 }
 $34 = (($this) + 44|0);
 ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN21BillboardBatchManager16AddBatchInstanceERK4PPtrI14BillboardAssetERK8Vector3fffff($this,$asset,$position,$widthScale,$heightScale,$rotation,$animationTime) {
 $this = $this|0;
 $asset = $asset|0;
 $position = $position|0;
 $widthScale = Math_fround($widthScale);
 $heightScale = Math_fround($heightScale);
 $rotation = Math_fround($rotation);
 $animationTime = Math_fround($animationTime);
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $indexOfBatch$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $indexOfBatch$0 = 255;
  } else {
   $$phi$trans$insert = (($1) + 20|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $i$02 = 0;
   while(1) {
    $5 = (($$pre) + ($i$02<<2)|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)==(0|0);
    if (!($7)) {
     $8 = HEAP32[$6>>2]|0;
     $9 = HEAP32[$asset>>2]|0;
     $10 = ($8|0)==($9|0);
     if ($10) {
      $indexOfBatch$0 = $i$02;
      break L1;
     }
    }
    $11 = (($i$02) + 1)|0;
    $12 = ($11>>>0)<($3>>>0);
    if ($12) {
     $i$02 = $11;
    } else {
     $indexOfBatch$0 = 255;
     break;
    }
   }
  }
 } while(0);
 $13 = Math_fround(HEAPF32[$position>>2]);
 $14 = (($this) + 36|0);
 $15 = (__ZN13dynamic_arrayIfLj4EE9push_backEv($14)|0);
 HEAPF32[$15>>2] = $13;
 $16 = (($position) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (__ZN13dynamic_arrayIfLj4EE9push_backEv($14)|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($position) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (__ZN13dynamic_arrayIfLj4EE9push_backEv($14)|0);
 HEAPF32[$21>>2] = $20;
 $22 = (__ZN13dynamic_arrayIfLj4EE9push_backEv($14)|0);
 $23 = $indexOfBatch$0 << 24;
 HEAP32[$22>>2] = $23;
 $24 = (__ZN13dynamic_arrayIfLj4EE9push_backEv($14)|0);
 HEAPF32[$24>>2] = $widthScale;
 $25 = (__ZN13dynamic_arrayIfLj4EE9push_backEv($14)|0);
 HEAPF32[$25>>2] = $heightScale;
 $26 = (__ZN13dynamic_arrayIfLj4EE9push_backEv($14)|0);
 HEAPF32[$26>>2] = $rotation;
 $27 = (__ZN13dynamic_arrayIfLj4EE9push_backEv($14)|0);
 HEAPF32[$27>>2] = $animationTime;
 $28 = HEAP32[$0>>2]|0;
 $29 = (($28) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + ($indexOfBatch$0<<2)|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 72|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 52|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + ($34))|0;
 HEAP32[$35>>2] = $37;
 $38 = (($32) + 88|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($this) + 56|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + ($39))|0;
 HEAP32[$40>>2] = $42;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIfLj4EE9push_backEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 do {
  if ($7) {
   $8 = $5 << 1;
   $9 = ($8|0)==(0);
   $10 = $9 ? 1 : $8;
   $11 = ($6>>>0)<($10>>>0);
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = $10 << 2;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,589824,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = $10 << 2;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,589824,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = $23 << 2;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($25) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + ($26<<2)|0);
 STACKTOP = sp;return ($28|0);
}
function __ZN21BillboardBatchManager17EndBatchAndSubmitEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $billboards = 0, $i$01 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $billboards = sp + 8|0;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $i$01 = 0;
  while(1) {
   $7 = (($3) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + ($i$01<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = (($10) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)>(0);
    if ($14) {
     $15 = (($10) + 20|0);
     $16 = (($billboards) + ($i$01<<2)|0);
     HEAP32[$16>>2] = $15;
    }
   }
   $17 = (($i$01) + 1)|0;
   $18 = ($17>>>0)<($5>>>0);
   if ($18) {
    $i$01 = $17;
   } else {
    break;
   }
  }
 }
 $19 = (($this) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[589752>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $25 = HEAP32[589864>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   $27 = HEAP8[589888>>0]|0;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    dest=589872+0|0; src=588176+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    HEAP8[589888>>0] = 1;
   }
   HEAP8[((589872 + 9|0))>>0] = 4;
   HEAP32[589864>>2] = 589872;
   $29 = 589872;
  } else {
   $29 = $25;
  }
  ;HEAP32[$$byval_copy+0>>2]=0|0;HEAP32[$$byval_copy+4>>2]=0|0;HEAP32[$$byval_copy+8>>2]=0|0;HEAP32[$$byval_copy+12>>2]=0|0;HEAP32[$$byval_copy+16>>2]=0|0;HEAP32[$$byval_copy+20>>2]=0|0;HEAP32[$$byval_copy+24>>2]=0|0;HEAP32[$$byval_copy+28>>2]=0|0;
  $30 = (__Z28BuildSingleStreamChannelInfojRK20VertexChannelsLayoutP11ChannelInfo(29,$29,$$byval_copy)|0);
  HEAP32[589760>>2] = $30;
  $31 = (__Z26GetMeshVertexFormatManagerv()|0);
  $32 = (__ZN23MeshVertexFormatManager19GetMeshVertexFormatERK18VertexChannelsInfo($31,$$byval_copy)|0);
  HEAP32[589752>>2] = $32;
  $33 = $32;
 } else {
  $33 = $23;
 }
 $34 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($33,$22,0)|0);
 $35 = HEAP32[$1>>2]|0;
 $36 = (($35) + 336|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$19>>2]|0;
 $39 = HEAP32[589760>>2]|0;
 $40 = (($this) + 52|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($this) + 56|0);
 $43 = HEAP32[$42>>2]|0;
 FUNCTION_TABLE_viiiiiiiii[$37 & 31]($1,$38,29,0,$39,$34,$41,$43,0);
 $44 = HEAP32[$1>>2]|0;
 $45 = (($44) + 348|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 36|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 44|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_viiiii[$46 & 255]($1,$billboards,4,$48,$50);
 $51 = HEAP32[$1>>2]|0;
 $52 = (($51) + 344|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vii[$53 & 4095]($1,0);
 HEAP32[$2>>2] = 0;
 HEAP32[$19>>2] = 0;
 $54 = (($this) + 48|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)>(-1);
 if (!($56)) {
  ;HEAP32[$49+0>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;HEAP32[$49+12>>2]=0|0;
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$47>>2]|0;
 $58 = (($this) + 40|0);
 $59 = HEAP32[$58>>2]|0;
 HEAP32[$0>>2] = $59;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($57,$$byval_copy);
 HEAP32[$47>>2] = 0;
 ;HEAP32[$49+0>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;HEAP32[$49+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN21BillboardBatchManager12BeforeRenderERK6Camera($this,$camera) {
 $this = $this|0;
 $camera = $camera|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($camera) + 412|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2147483648);
 $3 = (__ZNK6Camera25GetRenderImmediateObjectsEv($camera)|0);
 $4 = $2 | $3;
 if (!($4)) {
  __ZN21BillboardBatchManager32PurgeUnreferencedBillboardAssetsEb($this,0);
  __ZN21BillboardBatchManager30RearrangeBatchesIfAssetChangedEv($this);
 }
 $5 = (($this) + 60|0);
 $6 = (($this) + 68|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 84|0);
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[641904>>2]|0;
 $9 = (($this) + 92|0);
 HEAP32[$9>>2] = $8;
 __ZL20FillCameraPropertiesR21MaterialPropertyBlockRK6Camera($5,$camera);
 __ZN21MaterialPropertyBlock11ComputeHashEv($5);
 STACKTOP = sp;return;
}
function __ZN21BillboardBatchManager32PurgeUnreferencedBillboardAssetsEb($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i6 = 0, $$0$i$i$i$i10 = 0, $$0$i$i$i$i2 = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i8 = 0, $$be$in = 0, $$byval_copy = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($this) + 4|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 8|0);
 $6 = (($this) + 4|0);
 $8 = $2;
 L4: while(1) {
  $7 = (($8) + 20|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = ($9|0)==(0);
  L6: do {
   if ($10) {
    $11 = (($8) + 16|0);
    __ZN21BillboardBatchManager7UnbatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$11);
    $12 = (($8) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$01$i$i$i$i8 = $8;
     while(1) {
      $17 = (($$01$i$i$i$i8) + 8|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = HEAP32[$18>>2]|0;
      $20 = ($19|0)==($$01$i$i$i$i8|0);
      if ($20) {
       $$0$i$i$i$i10 = $18;
       break;
      } else {
       $$01$i$i$i$i8 = $18;
      }
     }
    } else {
     $$0$i$i$i$i$i6 = $13;
     while(1) {
      $15 = HEAP32[$$0$i$i$i$i$i6>>2]|0;
      $16 = ($15|0)==(0|0);
      if ($16) {
       $$0$i$i$i$i10 = $$0$i$i$i$i$i6;
       break;
      } else {
       $$0$i$i$i$i$i6 = $15;
      }
     }
    }
    if ($14) {
     $$01$i$i$i$i = $8;
     while(1) {
      $23 = (($$01$i$i$i$i) + 8|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25|0)==($$01$i$i$i$i|0);
      if ($26) {
       $$0$i$i$i$i2 = $24;
       break;
      } else {
       $$01$i$i$i$i = $24;
      }
     }
    } else {
     $$0$i$i$i$i$i = $13;
     while(1) {
      $21 = HEAP32[$$0$i$i$i$i$i>>2]|0;
      $22 = ($21|0)==(0|0);
      if ($22) {
       $$0$i$i$i$i2 = $$0$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i = $21;
      }
     }
    }
    $27 = HEAP32[$this>>2]|0;
    $28 = ($27|0)==($8|0);
    if ($28) {
     HEAP32[$this>>2] = $$0$i$i$i$i2;
    }
    $29 = HEAP32[$5>>2]|0;
    $30 = (($29) + -1)|0;
    HEAP32[$5>>2] = $30;
    $31 = (($8) + 36|0);
    __ZN9BillboardD2Ev($31);
    $32 = HEAP32[$6>>2]|0;
    __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($32,$8);
    HEAP32[$1>>2] = 55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($8|0),($$byval_copy|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     label = 15;
     break L4;
    } else {
     $$be$in = $$0$i$i$i$i10;
    }
   } else {
    $37 = (($8) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)==(0|0);
    if (!($39)) {
     $$0$i$i$i$i = $38;
     while(1) {
      $40 = HEAP32[$$0$i$i$i$i>>2]|0;
      $41 = ($40|0)==(0|0);
      if ($41) {
       $$be$in = $$0$i$i$i$i;
       break L6;
      } else {
       $$0$i$i$i$i = $40;
      }
     }
    }
    $$01$i$i$i = $8;
    while(1) {
     $42 = (($$01$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i|0);
     if ($45) {
      $$be$in = $43;
      break;
     } else {
      $$01$i$i$i = $43;
     }
    }
   }
  } while(0);
  $46 = ($$be$in|0)==($3|0);
  if ($46) {
   label = 21;
   break;
  } else {
   $8 = $$be$in;
  }
 }
 if ((label|0) == 15) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function __ZN21BillboardBatchManager30RearrangeBatchesIfAssetChangedEv($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i2 = 0, $$0$lcssa$i = 0, $$01$i = 0, $$01$i$i$i = 0, $$pr = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $i$05 = 0, $i1$07 = 0, $imagesInBatch$0$lcssa = 0, $imagesInBatch$08 = 0, $imagesInBatch$1 = 0, $or$cond3 = 0;
 var $or$cond4 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (__Z18GetQualitySettingsv()|0);
 $3 = (($2) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6) + (($4*96)|0)|0) + 79|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = (($this) + 4|0);
 $11 = ($9|0)==($10|0);
 if ($11) {
  $$pre = (($this) + 24|0);
  $$pre$phiZ2D = $$pre;
  HEAP8[$$pre$phiZ2D>>0] = $8;
  STACKTOP = sp;return;
 }
 $12 = (($this) + 24|0);
 $14 = $9;
 while(1) {
  $13 = (($14) + 16|0);
  $15 = (($14) + 32|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   (__ZN21BillboardBatchManager5BatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$13)|0);
   $$pr = HEAP32[$15>>2]|0;
   $18 = ($$pr|0)==(0|0);
   if (!($18)) {
    $97 = $$pr;
    label = 6;
   }
  } else {
   $97 = $16;
   label = 6;
  }
  L9: do {
   if ((label|0) == 6) {
    label = 0;
    $19 = HEAP32[$13>>2]|0;
    HEAP32[$1>>2] = $19;
    $20 = HEAP32[560624>>2]|0;
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     $22 = (($20) + 36|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($20) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($23|0)==($25|0);
     do {
      if ($26) {
       $27 = (($20) + 28|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = (($20) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = (($28) + ($30<<3)|0);
       $47 = $31;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$20,$1);
       $32 = HEAP32[$pos$i$i$i$i>>2]|0;
       $33 = ($32|0)==(-1);
       $34 = (($20) + 28|0);
       $35 = HEAP32[$34>>2]|0;
       if ($33) {
        $36 = (($20) + 32|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = (($35) + ($37<<3)|0);
        $47 = $38;
        break;
       } else {
        $39 = (($35) + ($32<<3)|0);
        $47 = $39;
        break;
       }
      }
     } while(0);
     $40 = HEAP32[560624>>2]|0;
     $41 = (($40) + 28|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($40) + 32|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + ($44<<3)|0);
     $46 = ($47|0)==($45|0);
     if (!($46)) {
      $48 = (($47) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if (!($50)) {
       $51 = (($49) + 8|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = $52 >>> 21;
       $54 = HEAP32[560640>>2]|0;
       $55 = Math_imul($54, $53)|0;
       $56 = (($55) + 226)|0;
       $57 = $56 >> 5;
       $58 = $57 << 5;
       $59 = (($56) - ($58))|0;
       $60 = HEAP32[560632>>2]|0;
       $61 = (($60) + ($57<<2)|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = 1 << $59;
       $64 = $63 & $62;
       $65 = ($64|0)==(0);
       if (!($65)) {
        $66 = (($49) + 28|0);
        $67 = (($49) + 104|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = ($68|0)==(0);
        if ($69) {
         $$0$i2 = 0;
        } else {
         HEAP32[$0>>2] = $68;
         $70 = ($40|0)==(0|0);
         if ($70) {
          label = 24;
         } else {
          $71 = (($40) + 36|0);
          $72 = HEAP32[$71>>2]|0;
          $73 = (($40) + 4|0);
          $74 = HEAP32[$73>>2]|0;
          $75 = ($72|0)==($74|0);
          do {
           if ($75) {
            $89 = $45;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$40,$0);
            $76 = HEAP32[$pos$i$i$i$i>>2]|0;
            $77 = ($76|0)==(-1);
            $78 = HEAP32[$41>>2]|0;
            if ($77) {
             $79 = HEAP32[$43>>2]|0;
             $80 = (($78) + ($79<<3)|0);
             $89 = $80;
             break;
            } else {
             $81 = (($78) + ($76<<3)|0);
             $89 = $81;
             break;
            }
           }
          } while(0);
          $82 = HEAP32[560624>>2]|0;
          $83 = (($82) + 28|0);
          $84 = HEAP32[$83>>2]|0;
          $85 = (($82) + 32|0);
          $86 = HEAP32[$85>>2]|0;
          $87 = (($84) + ($86<<3)|0);
          $88 = ($89|0)==($87|0);
          if ($88) {
           label = 24;
          } else {
           $90 = (($89) + 4|0);
           $91 = HEAP32[$90>>2]|0;
           $92 = ($91|0)==(0|0);
           if ($92) {
            label = 24;
           } else {
            $temp$0$i = $91;
           }
          }
         }
         if ((label|0) == 24) {
          label = 0;
          $93 = HEAP32[$67>>2]|0;
          $94 = (__Z31ReadObjectFromPersistentManageri($93)|0);
          $temp$0$i = $94;
         }
         $$0$i2 = $temp$0$i;
        }
        $95 = (__ZL28ComputeBillboardMaterialHashPN5Unity8MaterialE($$0$i2)|0);
        $96 = HEAP32[$97>>2]|0;
        $98 = ($95|0)==($96|0);
        if ($98) {
         $99 = HEAP8[$12>>0]|0;
         $100 = ($99<<24>>24)==($8<<24>>24);
         if (!($100)) {
          label = 28;
         }
        } else {
         label = 28;
        }
        if ((label|0) == 28) {
         label = 0;
         $101 = (($97) + 28|0);
         $102 = HEAP32[$101>>2]|0;
         $103 = ($102|0)==(0);
         L42: do {
          if (!($103)) {
           $104 = (($97) + 20|0);
           $105 = HEAP32[$104>>2]|0;
           $i$05 = 0;
           while(1) {
            $108 = (($105) + ($i$05<<2)|0);
            $109 = HEAP32[$108>>2]|0;
            $110 = ($109|0)==(0|0);
            $111 = ($109|0)==($13|0);
            $or$cond3 = $110 | $111;
            $107 = (($i$05) + 1)|0;
            if (!($or$cond3)) {
             break;
            }
            $106 = ($107>>>0)<($102>>>0);
            if ($106) {
             $i$05 = $107;
            } else {
             break L42;
            }
           }
           __ZN21BillboardBatchManager7UnbatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$13);
           (__ZN21BillboardBatchManager5BatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$13)|0);
           break L9;
          }
         } while(0);
         HEAP32[$97>>2] = $95;
         $112 = (($97) + 8|0);
         HEAP8[$112>>0] = 1;
         $113 = (($97) + 16|0);
         HEAP8[$113>>0] = 1;
        }
        $114 = (($14) + 36|0);
        $115 = (($14) + 56|0);
        $116 = HEAP32[$115>>2]|0;
        $117 = (($49) + 40|0);
        $118 = (($117) + 8|0);
        $119 = HEAP32[$118>>2]|0;
        $120 = ($116|0)==($119|0);
        if (!($120)) {
         $121 = (($97) + 28|0);
         $122 = HEAP32[$121>>2]|0;
         $123 = ($122|0)==(0);
         if ($123) {
          $imagesInBatch$0$lcssa = 0;
         } else {
          $124 = (($97) + 20|0);
          $125 = HEAP32[$124>>2]|0;
          $i1$07 = 0;$imagesInBatch$08 = 0;
          while(1) {
           $126 = (($125) + ($i1$07<<2)|0);
           $127 = HEAP32[$126>>2]|0;
           $128 = ($127|0)==(0|0);
           $129 = ($127|0)==($13|0);
           $or$cond4 = $128 | $129;
           if ($or$cond4) {
            $imagesInBatch$1 = $imagesInBatch$08;
           } else {
            $130 = (($127) + 40|0);
            $131 = HEAP32[$130>>2]|0;
            $132 = (($131) + ($imagesInBatch$08))|0;
            $imagesInBatch$1 = $132;
           }
           $133 = (($i1$07) + 1)|0;
           $134 = ($133>>>0)<($122>>>0);
           if ($134) {
            $i1$07 = $133;$imagesInBatch$08 = $imagesInBatch$1;
           } else {
            $imagesInBatch$0$lcssa = $imagesInBatch$1;
            break;
           }
          }
         }
         $135 = (($119) + ($imagesInBatch$0$lcssa))|0;
         $136 = ($135|0)>(32);
         if ($136) {
          __ZN21BillboardBatchManager7UnbatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$13);
          (__ZN21BillboardBatchManager5BatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$13)|0);
          break;
         }
        }
        $137 = (__Z8CRCBeginv()|0);
        $138 = (__Z7CRCFeedjPKhj($137,$66,4)|0);
        $139 = (($66) + 8|0);
        $140 = (__Z7CRCFeedjPKhj($138,$139,4)|0);
        $141 = (($66) + 4|0);
        $142 = (__Z7CRCFeedjPKhj($140,$141,4)|0);
        $143 = (($66) + 12|0);
        $144 = HEAP32[$143>>2]|0;
        $145 = (($66) + 20|0);
        $146 = HEAP32[$145>>2]|0;
        $147 = $146 << 4;
        $148 = (__Z7CRCFeedjPKhj($142,$144,$147)|0);
        $149 = (($66) + 28|0);
        $150 = HEAP32[$149>>2]|0;
        $151 = (($66) + 36|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = (__Z7CRCFeedjPKhj($148,$150,$152)|0);
        $154 = (__Z7CRCDonej($153)|0);
        $155 = (($14) + 24|0);
        $156 = HEAP32[$155>>2]|0;
        $157 = ($154|0)!=($156|0);
        if ($157) {
         $158 = (($97) + 8|0);
         HEAP8[$158>>0] = 1;
         $159 = (($97) + 16|0);
         HEAP8[$159>>0] = 1;
         HEAP32[$155>>2] = $154;
        }
        $160 = (__Z8CRCBeginv()|0);
        $161 = (($66) + 44|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = (($66) + 52|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = $164 << 3;
        $166 = (__Z7CRCFeedjPKhj($160,$162,$165)|0);
        $167 = (($66) + 60|0);
        $168 = HEAP32[$167>>2]|0;
        $169 = (($66) + 68|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = $170 << 1;
        $172 = (__Z7CRCFeedjPKhj($166,$168,$171)|0);
        $173 = (__Z7CRCDonej($172)|0);
        $174 = (($14) + 28|0);
        $175 = HEAP32[$174>>2]|0;
        $176 = ($173|0)!=($175|0);
        if ($176) {
         $177 = (($14) + 116|0);
         $178 = HEAP32[$177>>2]|0;
         __Z19DestroySingleObjectP6Object($178);
         $179 = (($97) + 20|0);
         $180 = HEAP32[$179>>2]|0;
         $181 = (($97) + 28|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = (($180) + ($182<<2)|0);
         $184 = ($182|0)==(0);
         L67: do {
          if ($184) {
           $$0$lcssa$i = $180;
          } else {
           $$01$i = $180;
           while(1) {
            $187 = HEAP32[$$01$i>>2]|0;
            $188 = ($187|0)==($13|0);
            $186 = (($$01$i) + 4|0);
            if ($188) {
             $$0$lcssa$i = $$01$i;
             break L67;
            }
            $185 = ($186|0)==($183|0);
            if ($185) {
             $$0$lcssa$i = $183;
             break;
            } else {
             $$01$i = $186;
            }
           }
          }
         } while(0);
         $189 = $$0$lcssa$i;
         $190 = $180;
         $191 = (($189) - ($190))|0;
         $192 = $191 >> 2;
         $193 = (__ZN21BillboardBatchManager19CreateBillboardMeshERK9Billboardj(0,$66,$192)|0);
         HEAP32[$177>>2] = $193;
         HEAP32[$174>>2] = $173;
        }
        $brmerge = $157 | $176;
        if (!($brmerge)) {
         break;
        }
        (__ZN9BillboardaSERKS_($114,$66)|0);
        break;
       }
      }
     }
    }
    __ZN21BillboardBatchManager7UnbatchERNSt3__14pairIKiNS_18BillboardAssetDataEEE($this,$13);
   }
  } while(0);
  $194 = (($14) + 4|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = ($195|0)==(0|0);
  if ($196) {
   $$01$i$i$i = $14;
   while(1) {
    $199 = (($$01$i$i$i) + 8|0);
    $200 = HEAP32[$199>>2]|0;
    $201 = HEAP32[$200>>2]|0;
    $202 = ($201|0)==($$01$i$i$i|0);
    if ($202) {
     $$0$i$i$i = $200;
     break;
    } else {
     $$01$i$i$i = $200;
    }
   }
  } else {
   $$0$i$i$i$i = $195;
   while(1) {
    $197 = HEAP32[$$0$i$i$i$i>>2]|0;
    $198 = ($197|0)==(0|0);
    if ($198) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $197;
    }
   }
  }
  $203 = ($$0$i$i$i|0)==($10|0);
  if ($203) {
   $$pre$phiZ2D = $12;
   break;
  } else {
   $14 = $$0$i$i$i;
  }
 }
 HEAP8[$$pre$phiZ2D>>0] = $8;
 STACKTOP = sp;return;
}
function __ZL28ComputeBillboardMaterialHashPN5Unity8MaterialE($material) {
 $material = $material|0;
 var $$0 = 0, $$byval_copy9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i2$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy9 = sp + 92|0;
 $0 = sp + 88|0;
 $1 = sp + 72|0;
 $2 = sp + 64|0;
 $3 = sp + 48|0;
 $4 = sp + 24|0;
 $5 = sp + 8|0;
 $6 = sp;
 $7 = sp + 32|0;
 $8 = ($material|0)==(0|0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = HEAP32[589712>>2]|0;
 HEAP32[$0>>2] = $9;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$1);
 $10 = HEAP32[588608>>2]|0;
 HEAP32[$2>>2] = $10;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$3);
 $11 = HEAP32[((588608 + 4|0))>>2]|0;
 HEAP32[$2>>2] = $11;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$3);
 $12 = HEAP32[((588608 + 8|0))>>2]|0;
 HEAP32[$2>>2] = $12;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$3);
 $13 = HEAP32[((588608 + 12|0))>>2]|0;
 HEAP32[$2>>2] = $13;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$3);
 $14 = HEAP32[588688>>2]|0;
 HEAP32[$4>>2] = $14;
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$5);
 $15 = HEAP32[((588688 + 4|0))>>2]|0;
 HEAP32[$4>>2] = $15;
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$5);
 $16 = HEAP32[((588688 + 8|0))>>2]|0;
 HEAP32[$4>>2] = $16;
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$5);
 $17 = HEAP32[((588688 + 12|0))>>2]|0;
 HEAP32[$4>>2] = $17;
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
 __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$5);
 $i2$01 = 0;
 while(1) {
  $18 = (588768 + ($i2$01<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$6>>2] = $19;
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$6+0>>2]|0;
  __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($material,$$byval_copy9,$7);
  $20 = (($i2$01) + 1)|0;
  $exitcond = ($20|0)==(32);
  if ($exitcond) {
   break;
  } else {
   $i2$01 = $20;
  }
 }
 $21 = (__ZNK5Unity8Material10ComputeCRCEv($material)|0);
 $$0 = $21;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9BillboardaSERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy7 = 0, $$idx = 0, $$idx7 = 0, $$idx8 = 0, $$pre$i = 0, $$pre$i2 = 0, $$pre$i4 = 0, $$pre$i6 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 4|0;
 $1 = sp;
 ;HEAP32[$this+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$0+8>>2]|0;
 $2 = (($this) + 12|0);
 $3 = ($0|0)==($this|0);
 if ($3) {
  $104 = (($0) + 76|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($this) + 76|0);
  HEAP32[$106>>2] = $105;
  STACKTOP = sp;return ($this|0);
 }
 $4 = (($0) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $$idx = $7 << 4;
 $8 = $$idx >> 4;
 $9 = (($this) + 20|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 2147483647;
 $13 = ($12>>>0)<($8>>>0);
 if ($13) {
  $16 = ($11|0)>(-1);
  if ($16) {
   HEAP32[$10>>2] = $8;
   $17 = HEAP32[$2>>2]|0;
   $18 = (($this) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$1>>2] = $19;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($17,$$idx,4,$$byval_copy7,0,589824,370)|0);
   HEAP32[$2>>2] = $20;
   $29 = $20;
  } else {
   $21 = (($this) + 16|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$1>>2] = $22;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx,4,$$byval_copy7,0,589824,352)|0);
   $24 = HEAP32[$2>>2]|0;
   $25 = HEAP32[$9>>2]|0;
   $26 = $25 << 4;
   _memcpy(($23|0),($24|0),($26|0))|0;
   HEAP32[$10>>2] = $8;
   HEAP32[$2>>2] = $23;
   $29 = $23;
  }
  $27 = HEAP32[$9>>2]|0;
  $28 = $27 << 4;
  _memcpy(($29|0),($5|0),($28|0))|0;
  if ($3) {
   $104 = (($0) + 76|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($this) + 76|0);
   HEAP32[$106>>2] = $105;
   STACKTOP = sp;return ($this|0);
  }
 } else {
  $$pre$i = HEAP32[$2>>2]|0;
  $14 = HEAP32[$9>>2]|0;
  $15 = $14 << 4;
  _memcpy(($$pre$i|0),($5|0),($15|0))|0;
 }
 $30 = (($this) + 28|0);
 $31 = (($0) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($0) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 36|0);
 HEAP32[$35>>2] = $34;
 $36 = (($this) + 40|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 2147483647;
 $39 = ($38>>>0)<($34>>>0);
 do {
  if ($39) {
   $40 = ($37|0)>(-1);
   if ($40) {
    HEAP32[$36>>2] = $34;
    $41 = HEAP32[$30>>2]|0;
    $42 = (($this) + 32|0);
    $43 = HEAP32[$42>>2]|0;
    HEAP32[$1>>2] = $43;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    $44 = (__Z16realloc_internalPvji10MemLabelIdiPKci($41,$34,1,$$byval_copy7,0,589824,370)|0);
    HEAP32[$30>>2] = $44;
    $51 = $44;
    break;
   } else {
    $45 = (($this) + 32|0);
    $46 = HEAP32[$45>>2]|0;
    HEAP32[$1>>2] = $46;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    $47 = (__Z15malloc_internaljj10MemLabelIdiPKci($34,1,$$byval_copy7,0,589824,352)|0);
    $48 = HEAP32[$30>>2]|0;
    $49 = HEAP32[$35>>2]|0;
    _memcpy(($47|0),($48|0),($49|0))|0;
    HEAP32[$36>>2] = $34;
    HEAP32[$30>>2] = $47;
    $51 = $47;
    break;
   }
  } else {
   $$pre$i2 = HEAP32[$30>>2]|0;
   $51 = $$pre$i2;
  }
 } while(0);
 $50 = HEAP32[$35>>2]|0;
 _memcpy(($51|0),($32|0),($50|0))|0;
 $52 = (($this) + 44|0);
 if ($3) {
  $104 = (($0) + 76|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($this) + 76|0);
  HEAP32[$106>>2] = $105;
  STACKTOP = sp;return ($this|0);
 }
 $53 = (($0) + 44|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($0) + 52|0);
 $56 = HEAP32[$55>>2]|0;
 $$idx7 = $56 << 3;
 $57 = $$idx7 >> 3;
 $58 = (($this) + 52|0);
 HEAP32[$58>>2] = $57;
 $59 = (($this) + 56|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $60 & 2147483647;
 $62 = ($61>>>0)<($57>>>0);
 if ($62) {
  $65 = ($60|0)>(-1);
  if ($65) {
   HEAP32[$59>>2] = $57;
   $66 = HEAP32[$52>>2]|0;
   $67 = (($this) + 48|0);
   $68 = HEAP32[$67>>2]|0;
   HEAP32[$1>>2] = $68;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   $69 = (__Z16realloc_internalPvji10MemLabelIdiPKci($66,$$idx7,4,$$byval_copy7,0,589824,370)|0);
   HEAP32[$52>>2] = $69;
   $78 = $69;
  } else {
   $70 = (($this) + 48|0);
   $71 = HEAP32[$70>>2]|0;
   HEAP32[$1>>2] = $71;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   $72 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx7,4,$$byval_copy7,0,589824,352)|0);
   $73 = HEAP32[$52>>2]|0;
   $74 = HEAP32[$58>>2]|0;
   $75 = $74 << 3;
   _memcpy(($72|0),($73|0),($75|0))|0;
   HEAP32[$59>>2] = $57;
   HEAP32[$52>>2] = $72;
   $78 = $72;
  }
  $76 = HEAP32[$58>>2]|0;
  $77 = $76 << 3;
  _memcpy(($78|0),($54|0),($77|0))|0;
  if ($3) {
   $104 = (($0) + 76|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($this) + 76|0);
   HEAP32[$106>>2] = $105;
   STACKTOP = sp;return ($this|0);
  }
 } else {
  $$pre$i4 = HEAP32[$52>>2]|0;
  $63 = HEAP32[$58>>2]|0;
  $64 = $63 << 3;
  _memcpy(($$pre$i4|0),($54|0),($64|0))|0;
 }
 $79 = (($this) + 60|0);
 $80 = (($0) + 60|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($0) + 68|0);
 $83 = HEAP32[$82>>2]|0;
 $$idx8 = $83 << 1;
 $84 = $$idx8 >> 1;
 $85 = (($this) + 68|0);
 HEAP32[$85>>2] = $84;
 $86 = (($this) + 72|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = $87 & 2147483647;
 $89 = ($88>>>0)<($84>>>0);
 do {
  if ($89) {
   $90 = ($87|0)>(-1);
   if ($90) {
    HEAP32[$86>>2] = $84;
    $91 = HEAP32[$79>>2]|0;
    $92 = (($this) + 64|0);
    $93 = HEAP32[$92>>2]|0;
    HEAP32[$1>>2] = $93;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    $94 = (__Z16realloc_internalPvji10MemLabelIdiPKci($91,$$idx8,2,$$byval_copy7,0,589824,370)|0);
    HEAP32[$79>>2] = $94;
    $103 = $94;
    break;
   } else {
    $95 = (($this) + 64|0);
    $96 = HEAP32[$95>>2]|0;
    HEAP32[$1>>2] = $96;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    $97 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx8,2,$$byval_copy7,0,589824,352)|0);
    $98 = HEAP32[$79>>2]|0;
    $99 = HEAP32[$85>>2]|0;
    $100 = $99 << 1;
    _memcpy(($97|0),($98|0),($100|0))|0;
    HEAP32[$86>>2] = $84;
    HEAP32[$79>>2] = $97;
    $103 = $97;
    break;
   }
  } else {
   $$pre$i6 = HEAP32[$79>>2]|0;
   $103 = $$pre$i6;
  }
 } while(0);
 $101 = HEAP32[$85>>2]|0;
 $102 = $101 << 1;
 _memcpy(($103|0),($81|0),($102|0))|0;
 $104 = (($0) + 76|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($this) + 76|0);
 HEAP32[$106>>2] = $105;
 STACKTOP = sp;return ($this|0);
}
function __ZN21BillboardBatchManager19CreateBillboardMeshERK9Billboardj($this,$billboard,$indexInBatch) {
 $this = $this|0;
 $billboard = $billboard|0;
 $indexInBatch = $indexInBatch|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $j$015 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628440>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(280,$$byval_copy2,1,16,589824,1111)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1698,($3|0),($$byval_copy2|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(589824|0),1111);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch(0|0)|0;
   $11 = tempRet0;
   ___clang_call_terminate($10);
   // unreachable;
  } else {
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $12 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 4095]($12);
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($12,4);
 $19 = HEAP32[$12>>2]|0;
 $20 = (($19) + 44|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vii[$21 & 4095]($12,61);
 $22 = (($billboard) + 52|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[589864>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $26 = HEAP8[589888>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   dest=589872+0|0; src=588176+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   HEAP8[589888>>0] = 1;
  }
  HEAP8[((589872 + 9|0))>>0] = 4;
  HEAP32[589864>>2] = 589872;
  $28 = 589872;
 } else {
  $28 = $24;
 }
 __ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayout($12,$23,29,0,$28);
 $29 = (($12) + 28|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 10|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  $34 = (($30) + 11|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ($35&255)<(3);
  if ($36) {
   $139 = 0;$157 = 0;
  } else {
   $37 = (($30) + 92|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $139 = 1;$157 = 0;
   } else {
    $40 = (($30) + 8|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = $41&255;
    $43 = ((($30) + (($42*12)|0)|0) + 50|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = $44&255;
    $46 = ((($30) + (($42*12)|0)|0) + 44|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($30) + 9|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = $49&255;
    $51 = (($50) + ($47))|0;
    $52 = (($38) + ($51)|0);
    $139 = $45;$157 = $52;
   }
  }
 } else {
  $139 = 0;$157 = 0;
 }
 $53 = (($30) + 22|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  $56 = (($30) + 23|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = ($57&255)<(2);
  if ($58) {
   $143 = 0;$158 = 0;
  } else {
   $59 = (($30) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==(0|0);
   if ($61) {
    $143 = 1;$158 = 0;
   } else {
    $62 = (($30) + 20|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = $63&255;
    $65 = ((($30) + (($64*12)|0)|0) + 50|0);
    $66 = HEAP8[$65>>0]|0;
    $67 = $66&255;
    $68 = ((($30) + (($64*12)|0)|0) + 44|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($30) + 21|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = $71&255;
    $73 = (($72) + ($69))|0;
    $74 = (($60) + ($73)|0);
    $143 = $67;$158 = $74;
   }
  }
 } else {
  $143 = 0;$158 = 0;
 }
 $75 = (($30) + 26|0);
 $76 = HEAP8[$75>>0]|0;
 $77 = ($76<<24>>24)==(0);
 if ($77) {
  $78 = (($30) + 27|0);
  $79 = HEAP8[$78>>0]|0;
  $80 = ($79&255)<(2);
  if ($80) {
   $146 = 0;$159 = 0;
  } else {
   $81 = (($30) + 92|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==(0|0);
   if ($83) {
    $146 = 1;$159 = 0;
   } else {
    $84 = (($30) + 24|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = ((($30) + (($86*12)|0)|0) + 50|0);
    $88 = HEAP8[$87>>0]|0;
    $89 = $88&255;
    $90 = ((($30) + (($86*12)|0)|0) + 44|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($30) + 25|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = $93&255;
    $95 = (($94) + ($91))|0;
    $96 = (($82) + ($95)|0);
    $146 = $89;$159 = $96;
   }
  }
 } else {
  $146 = 0;$159 = 0;
 }
 $97 = (($30) + 18|0);
 $98 = HEAP8[$97>>0]|0;
 $99 = ($98<<24>>24)==(2);
 if ($99) {
  $100 = (($30) + 19|0);
  $101 = HEAP8[$100>>0]|0;
  $102 = ($101&255)<(4);
  if ($102) {
   $141 = 0;$160 = 0;
  } else {
   $103 = (($30) + 92|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($104|0)==(0|0);
   if ($105) {
    $141 = 1;$160 = 0;
   } else {
    $106 = (($30) + 16|0);
    $107 = HEAP8[$106>>0]|0;
    $108 = $107&255;
    $109 = ((($30) + (($108*12)|0)|0) + 50|0);
    $110 = HEAP8[$109>>0]|0;
    $111 = $110&255;
    $112 = ((($30) + (($108*12)|0)|0) + 44|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = (($30) + 17|0);
    $115 = HEAP8[$114>>0]|0;
    $116 = $115&255;
    $117 = (($116) + ($113))|0;
    $118 = (($104) + ($117)|0);
    $141 = $111;$160 = $118;
   }
  }
 } else {
  $141 = 0;$160 = 0;
 }
 $119 = HEAP32[$22>>2]|0;
 $120 = ($119|0)==(0);
 if ($120) {
  __ZN4Mesh15SetSubMeshCountEj($12,1);
  $150 = (($billboard) + 60|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = (($billboard) + 68|0);
  $153 = HEAP32[$152>>2]|0;
  (__ZN4Mesh10SetIndicesEPKtjj16GfxPrimitiveType($12,$151,$153,0,0)|0);
  $154 = HEAP32[$29>>2]|0;
  $155 = (($154) + 96|0);
  $156 = HEAP32[$155>>2]|0;
  __ZN4Mesh16SetChannelsDirtyEjb($12,$156,1);
  STACKTOP = sp;return ($12|0);
 }
 $121 = $indexInBatch << 24;
 $122 = (($billboard) + 44|0);
 $123 = $157;$124 = $160;$134 = $158;$145 = $159;$j$015 = 0;
 while(1) {
  ;HEAP32[$123+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$123+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$123+8>>2]=HEAP32[616680+8>>2]|0;
  HEAP32[$124>>2] = $121;
  $125 = HEAP32[$122>>2]|0;
  $126 = (($125) + ($j$015<<3)|0);
  $127 = $126;
  $128 = $127;
  $129 = HEAP32[$128>>2]|0;
  $130 = (($127) + 4)|0;
  $131 = $130;
  $132 = HEAP32[$131>>2]|0;
  $133 = $134;
  $135 = $133;
  HEAP32[$135>>2] = $129;
  $136 = (($133) + 4)|0;
  $137 = $136;
  HEAP32[$137>>2] = $132;
  $138 = (($123) + ($139)|0);
  $140 = (($124) + ($141)|0);
  $142 = (($134) + ($143)|0);
  $144 = (($145) + ($146)|0);
  $147 = (($j$015) + 1)|0;
  ;HEAP32[$145+0>>2]=0|0;HEAP32[$145+4>>2]=0|0;HEAP32[$145+8>>2]=0|0;HEAP32[$145+12>>2]=0|0;
  $148 = HEAP32[$22>>2]|0;
  $149 = ($147>>>0)<($148>>>0);
  if ($149) {
   $123 = $138;$124 = $140;$134 = $142;$145 = $144;$j$015 = $147;
  } else {
   break;
  }
 }
 __ZN4Mesh15SetSubMeshCountEj($12,1);
 $150 = (($billboard) + 60|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = (($billboard) + 68|0);
 $153 = HEAP32[$152>>2]|0;
 (__ZN4Mesh10SetIndicesEPKtjj16GfxPrimitiveType($12,$151,$153,0,0)|0);
 $154 = HEAP32[$29>>2]|0;
 $155 = (($154) + 96|0);
 $156 = HEAP32[$155>>2]|0;
 __ZN4Mesh16SetChannelsDirtyEjb($12,$156,1);
 STACKTOP = sp;return ($12|0);
}
function __ZN18UnityPropertySheetaSERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i14 = 0, $$0$i$i$i$i$i$i5 = 0, $$0$i$i$i$i$i18 = 0, $$0$i$i$i$i$i9 = 0, $$01$i$i$i$i$i = 0, $$01$i$i$i$i$i16 = 0, $$01$i$i$i$i$i7 = 0, $$byval_copy2 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i12 = 0, $$pre$i$i$i$i$i3 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__parent$i$i$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy2 = sp + 32|0;
 $__parent$i$i$i$i10 = sp + 28|0;
 $1 = sp + 24|0;
 $2 = sp;
 $3 = ($this|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return ($this|0);
 }
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$5);
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$this>>2] = $7;
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[$0>>2]|0;
 $9 = (($0) + 4|0);
 $10 = ($8|0)==($9|0);
 if ($10) {
 } else {
  $11 = (($2) + 4|0);
  $12 = (($2) + 20|0);
  $14 = $8;
  while(1) {
   $13 = (($14) + 16|0);
   $15 = HEAP32[$13>>2]|0;
   $16 = (($14) + 20|0);
   ;HEAP32[$11+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$16+12>>2]|0;
   $17 = (($14) + 36|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$12>>2] = $18;
   HEAP32[$2>>2] = $15;
   HEAP32[$1>>2] = $7;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   $19 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SG_EEiEESJ_RKT_($this,$$byval_copy2,$__parent$i$i$i$i10,$2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $22 = (__Znwj(40)|0);
    $23 = (($22) + 16|0);
    $24 = HEAP32[$2>>2]|0;
    $25 = (($22) + 20|0);
    ;HEAP32[$25+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$11+12>>2]|0;
    $26 = HEAP32[$12>>2]|0;
    $27 = (($22) + 36|0);
    HEAP32[$27>>2] = $26;
    HEAP32[$23>>2] = $24;
    $28 = HEAP32[$__parent$i$i$i$i10>>2]|0;
    HEAP32[$22>>2] = 0;
    $29 = (($22) + 4|0);
    HEAP32[$29>>2] = 0;
    $30 = (($22) + 8|0);
    HEAP32[$30>>2] = $28;
    HEAP32[$19>>2] = $22;
    $31 = HEAP32[$this>>2]|0;
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     $35 = $22;
    } else {
     HEAP32[$this>>2] = $32;
     $$pre$i$i$i$i$i = HEAP32[$19>>2]|0;
     $35 = $$pre$i$i$i$i$i;
    }
    $34 = HEAP32[$4>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($34,$35);
    $36 = HEAP32[$6>>2]|0;
    $37 = (($36) + 1)|0;
    HEAP32[$6>>2] = $37;
   }
   $38 = (($14) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if ($40) {
    $$01$i$i$i$i$i = $14;
    while(1) {
     $43 = (($$01$i$i$i$i$i) + 8|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45|0)==($$01$i$i$i$i$i|0);
     if ($46) {
      $$0$i$i$i$i$i = $44;
      break;
     } else {
      $$01$i$i$i$i$i = $44;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $39;
    while(1) {
     $41 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $41;
     }
    }
   }
   $47 = ($$0$i$i$i$i$i|0)==($9|0);
   if ($47) {
    break;
   } else {
    $14 = $$0$i$i$i$i$i;
   }
  }
  if ($3) {
   STACKTOP = sp;return ($this|0);
  }
 }
 $48 = (($this) + 12|0);
 $49 = (($this) + 16|0);
 $50 = HEAP32[$49>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($48,$50);
 $51 = (($this) + 20|0);
 HEAP32[$51>>2] = 0;
 $52 = (($this) + 16|0);
 HEAP32[$48>>2] = $52;
 HEAP32[$52>>2] = 0;
 $53 = (($0) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($0) + 16|0);
 $56 = ($54|0)==($55|0);
 if (!($56)) {
  $58 = $54;
  while(1) {
   $57 = (($58) + 16|0);
   $59 = $57;
   $60 = $59;
   $61 = HEAP32[$60>>2]|0;
   $62 = (($59) + 4)|0;
   $63 = $62;
   $64 = HEAP32[$63>>2]|0;
   $65 = $2;
   $66 = $65;
   HEAP32[$66>>2] = $61;
   $67 = (($65) + 4)|0;
   $68 = $67;
   HEAP32[$68>>2] = $64;
   HEAP32[$1>>2] = $52;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   $69 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS4_PNS_11__tree_nodeIS4_SE_EEiEESH_RKT_($48,$$byval_copy2,$__parent$i$i$i$i10,$2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==(0|0);
   if ($71) {
    $72 = (__Znwj(24)|0);
    $73 = (($72) + 16|0);
    $74 = $2;
    $75 = $74;
    $76 = HEAP32[$75>>2]|0;
    $77 = (($74) + 4)|0;
    $78 = $77;
    $79 = HEAP32[$78>>2]|0;
    $80 = $73;
    $81 = $80;
    HEAP32[$81>>2] = $76;
    $82 = (($80) + 4)|0;
    $83 = $82;
    HEAP32[$83>>2] = $79;
    $84 = HEAP32[$__parent$i$i$i$i10>>2]|0;
    HEAP32[$72>>2] = 0;
    $85 = (($72) + 4|0);
    HEAP32[$85>>2] = 0;
    $86 = (($72) + 8|0);
    HEAP32[$86>>2] = $84;
    HEAP32[$69>>2] = $72;
    $87 = HEAP32[$48>>2]|0;
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==(0|0);
    if ($89) {
     $91 = $72;
    } else {
     HEAP32[$48>>2] = $88;
     $$pre$i$i$i$i$i3 = HEAP32[$69>>2]|0;
     $91 = $$pre$i$i$i$i$i3;
    }
    $90 = HEAP32[$49>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($90,$91);
    $92 = HEAP32[$51>>2]|0;
    $93 = (($92) + 1)|0;
    HEAP32[$51>>2] = $93;
   }
   $94 = (($58) + 4|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)==(0|0);
   if ($96) {
    $$01$i$i$i$i$i7 = $58;
    while(1) {
     $99 = (($$01$i$i$i$i$i7) + 8|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101|0)==($$01$i$i$i$i$i7|0);
     if ($102) {
      $$0$i$i$i$i$i9 = $100;
      break;
     } else {
      $$01$i$i$i$i$i7 = $100;
     }
    }
   } else {
    $$0$i$i$i$i$i$i5 = $95;
    while(1) {
     $97 = HEAP32[$$0$i$i$i$i$i$i5>>2]|0;
     $98 = ($97|0)==(0|0);
     if ($98) {
      $$0$i$i$i$i$i9 = $$0$i$i$i$i$i$i5;
      break;
     } else {
      $$0$i$i$i$i$i$i5 = $97;
     }
    }
   }
   $103 = ($$0$i$i$i$i$i9|0)==($55|0);
   if ($103) {
    break;
   } else {
    $58 = $$0$i$i$i$i$i9;
   }
  }
 }
 $104 = (($this) + 24|0);
 if ($3) {
  STACKTOP = sp;return ($this|0);
 }
 $105 = (($this) + 28|0);
 $106 = HEAP32[$105>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($104,$106);
 $107 = (($this) + 32|0);
 HEAP32[$107>>2] = 0;
 $108 = (($this) + 28|0);
 HEAP32[$104>>2] = $108;
 HEAP32[$108>>2] = 0;
 $109 = (($0) + 24|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = (($0) + 28|0);
 $112 = ($110|0)==($111|0);
 if ($112) {
  STACKTOP = sp;return ($this|0);
 }
 $114 = $110;
 while(1) {
  $113 = (($114) + 16|0);
  ;HEAP32[$2+0>>2]=HEAP32[$113+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$113+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$113+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$113+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$113+16>>2]|0;
  HEAP32[$1>>2] = $108;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $115 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($104,$$byval_copy2,$__parent$i$i$i$i10,$2)|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = ($116|0)==(0|0);
  if ($117) {
   $118 = (__Znwj(36)|0);
   $119 = (($118) + 16|0);
   ;HEAP32[$119+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$119+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$119+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$119+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$119+16>>2]=HEAP32[$2+16>>2]|0;
   $120 = HEAP32[$__parent$i$i$i$i10>>2]|0;
   HEAP32[$118>>2] = 0;
   $121 = (($118) + 4|0);
   HEAP32[$121>>2] = 0;
   $122 = (($118) + 8|0);
   HEAP32[$122>>2] = $120;
   HEAP32[$115>>2] = $118;
   $123 = HEAP32[$104>>2]|0;
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)==(0|0);
   if ($125) {
    $127 = $118;
   } else {
    HEAP32[$104>>2] = $124;
    $$pre$i$i$i$i$i12 = HEAP32[$115>>2]|0;
    $127 = $$pre$i$i$i$i$i12;
   }
   $126 = HEAP32[$105>>2]|0;
   __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($126,$127);
   $128 = HEAP32[$107>>2]|0;
   $129 = (($128) + 1)|0;
   HEAP32[$107>>2] = $129;
  }
  $130 = (($114) + 4|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ($131|0)==(0|0);
  if ($132) {
   $$01$i$i$i$i$i16 = $114;
   while(1) {
    $135 = (($$01$i$i$i$i$i16) + 8|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = HEAP32[$136>>2]|0;
    $138 = ($137|0)==($$01$i$i$i$i$i16|0);
    if ($138) {
     $$0$i$i$i$i$i18 = $136;
     break;
    } else {
     $$01$i$i$i$i$i16 = $136;
    }
   }
  } else {
   $$0$i$i$i$i$i$i14 = $131;
   while(1) {
    $133 = HEAP32[$$0$i$i$i$i$i$i14>>2]|0;
    $134 = ($133|0)==(0|0);
    if ($134) {
     $$0$i$i$i$i$i18 = $$0$i$i$i$i$i$i14;
     break;
    } else {
     $$0$i$i$i$i$i$i14 = $133;
    }
   }
  }
  $139 = ($$0$i$i$i$i$i18|0)==($111|0);
  if ($139) {
   break;
  } else {
   $114 = $$0$i$i$i$i$i18;
  }
 }
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $30 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($30|0);
 }
 $16 = (__Znwj(36)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $__r$0 = $16;
 $30 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($30|0);
}
function __Z19TransformBillboardsPhPtjPKPK9BillboardiPfiPjS7_($vb,$ib,$baseVertex,$billboards,$numBillboards,$billboardInstances,$instanceBufferSize,$batchedVertices,$batchedIndices) {
 $vb = $vb|0;
 $ib = $ib|0;
 $baseVertex = $baseVertex|0;
 $billboards = $billboards|0;
 $numBillboards = $numBillboards|0;
 $billboardInstances = $billboardInstances|0;
 $instanceBufferSize = $instanceBufferSize|0;
 $batchedVertices = $batchedVertices|0;
 $batchedIndices = $batchedIndices|0;
 var $$masked = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $exitcond = 0, $i$018 = 0, $i1$05 = 0, $indexCount$0$lcssa31 = 0, $indexCount$021 = 0, $instances$020 = 0, $instances$16 = 0, $j$013 = 0, $j4$03 = 0, $outIndices$019 = 0, $outIndices$1$lcssa = 0, $outIndices$111 = 0, $outVertices$04 = 0, $outVertices$1$lcssa = 0, $outVertices$12 = 0, $scevgep = 0, $scevgep28 = 0;
 var $smax = 0, $src$012 = 0, $vertCount$0$lcssa30 = 0, $vertCount$022 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $instanceBufferSize >>> 3;
 $1 = ($0|0)==(0);
 if ($1) {
  $indexCount$0$lcssa31 = 0;$vertCount$0$lcssa30 = $baseVertex;
  $81 = (($vertCount$0$lcssa30) - ($baseVertex))|0;
  HEAP32[$batchedVertices>>2] = $81;
  HEAP32[$batchedIndices>>2] = $indexCount$0$lcssa31;
  STACKTOP = sp;return ($0|0);
 }
 $i$018 = 0;$indexCount$021 = 0;$instances$020 = $billboardInstances;$outIndices$019 = $ib;$vertCount$022 = $baseVertex;
 while(1) {
  $2 = (($instances$020) + 12|0);
  $3 = (($2) + 3|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = (($billboards) + ($5<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 68|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 52|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $9 >>> 1;
  $13 = $vertCount$022 << 16;
  $14 = $13 | $vertCount$022;
  $15 = ($12|0)==(0);
  if ($15) {
   $outIndices$1$lcssa = $outIndices$019;
  } else {
   $16 = (($7) + 60|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($12>>>0)>(1);
   $smax = $18 ? $12 : 1;
   $j$013 = 0;$outIndices$111 = $outIndices$019;$src$012 = $17;
   while(1) {
    $19 = (($src$012) + 4|0);
    $20 = HEAP32[$src$012>>2]|0;
    $21 = (($20) + ($14))|0;
    $22 = (($outIndices$111) + 4|0);
    HEAP32[$outIndices$111>>2] = $21;
    $23 = (($j$013) + 1)|0;
    $24 = ($23|0)<($12|0);
    if ($24) {
     $j$013 = $23;$outIndices$111 = $22;$src$012 = $19;
    } else {
     break;
    }
   }
   $scevgep28 = (($outIndices$019) + ($smax<<2)|0);
   $outIndices$1$lcssa = $scevgep28;
  }
  $25 = (($instances$020) + 32|0);
  $26 = (($11) + ($vertCount$022))|0;
  $27 = (($9) + ($indexCount$021))|0;
  $28 = (($i$018) + 1)|0;
  $29 = ($28>>>0)<($0>>>0);
  if ($29) {
   $i$018 = $28;$indexCount$021 = $27;$instances$020 = $25;$outIndices$019 = $outIndices$1$lcssa;$vertCount$022 = $26;
  } else {
   break;
  }
 }
 if ($1) {
  $indexCount$0$lcssa31 = $27;$vertCount$0$lcssa30 = $26;
  $81 = (($vertCount$0$lcssa30) - ($baseVertex))|0;
  HEAP32[$batchedVertices>>2] = $81;
  HEAP32[$batchedIndices>>2] = $indexCount$0$lcssa31;
  STACKTOP = sp;return ($0|0);
 }
 $i1$05 = 0;$instances$16 = $billboardInstances;$outVertices$04 = $vb;
 while(1) {
  $30 = (($instances$16) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $31 >>> 24;
  $33 = (($billboards) + ($32<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 44|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 52|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0);
  if ($39) {
   $outVertices$1$lcssa = $outVertices$04;
  } else {
   $40 = $31 << 16;
   $$masked = $31 & 65280;
   $41 = $40 & 16711680;
   $42 = $41 | $$masked;
   $43 = $32 << 24;
   $44 = $31 >>> 16;
   $45 = $42 | $43;
   $46 = $44 & 255;
   $47 = $45 | $46;
   $48 = (($instances$16) + 4|0);
   $49 = (($instances$16) + 8|0);
   $50 = (HEAP32[tempDoublePtr>>2]=$47,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $51 = (($instances$16) + 16|0);
   $52 = (($instances$16) + 20|0);
   $53 = (($instances$16) + 24|0);
   $54 = (($instances$16) + 28|0);
   $55 = ($38*10)|0;
   $j4$03 = 0;$outVertices$12 = $outVertices$04;
   while(1) {
    $56 = Math_fround(HEAPF32[$instances$16>>2]);
    $57 = (($outVertices$12) + 4|0);
    HEAPF32[$outVertices$12>>2] = $56;
    $58 = Math_fround(HEAPF32[$48>>2]);
    $59 = (($outVertices$12) + 8|0);
    HEAPF32[$57>>2] = $58;
    $60 = Math_fround(HEAPF32[$49>>2]);
    $61 = (($outVertices$12) + 12|0);
    HEAPF32[$59>>2] = $60;
    $62 = (($outVertices$12) + 16|0);
    HEAPF32[$61>>2] = $50;
    $63 = (($36) + ($j4$03<<3)|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = (($outVertices$12) + 20|0);
    HEAPF32[$62>>2] = $64;
    $66 = ((($36) + ($j4$03<<3)|0) + 4|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = (($outVertices$12) + 24|0);
    HEAPF32[$65>>2] = $67;
    $69 = Math_fround(HEAPF32[$51>>2]);
    $70 = (($outVertices$12) + 28|0);
    HEAPF32[$68>>2] = $69;
    $71 = Math_fround(HEAPF32[$52>>2]);
    $72 = (($outVertices$12) + 32|0);
    HEAPF32[$70>>2] = $71;
    $73 = Math_fround(HEAPF32[$53>>2]);
    $74 = (($outVertices$12) + 36|0);
    HEAPF32[$72>>2] = $73;
    $75 = Math_fround(HEAPF32[$54>>2]);
    $76 = (($outVertices$12) + 40|0);
    HEAPF32[$74>>2] = $75;
    $77 = (($j4$03) + 1)|0;
    $exitcond = ($77|0)==($38|0);
    if ($exitcond) {
     break;
    } else {
     $j4$03 = $77;$outVertices$12 = $76;
    }
   }
   $scevgep = (($outVertices$04) + ($55<<2)|0);
   $outVertices$1$lcssa = $scevgep;
  }
  $78 = (($instances$16) + 32|0);
  $79 = (($i1$05) + 1)|0;
  $80 = ($79>>>0)<($0>>>0);
  if ($80) {
   $i1$05 = $79;$instances$16 = $78;$outVertices$04 = $outVertices$1$lcssa;
  } else {
   $indexCount$0$lcssa31 = $27;$vertCount$0$lcssa30 = $26;
   break;
  }
 }
 $81 = (($vertCount$0$lcssa30) - ($baseVertex))|0;
 HEAP32[$batchedVertices>>2] = $81;
 HEAP32[$batchedIndices>>2] = $indexCount$0$lcssa31;
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE14__erase_uniqueIS3_EEjRKT_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$ph5$i$i = 0, $$0$ph7$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i = 0, $$013$i$in$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = ($2|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$__k>>2]|0;
 $$0$ph7$i$i = $3;$$01$ph6$i$in$i = $2;
 L4: while(1) {
  $$013$i$in$i = $$01$ph6$i$in$i;
  while(1) {
   $6 = (($$013$i$in$i) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7>>>0)<($5>>>0);
   if (!($8)) {
    break;
   }
   $11 = (($$013$i$in$i) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$ph5$i$i = $$0$ph7$i$i;
    break L4;
   } else {
    $$013$i$in$i = $12;
   }
  }
  $9 = HEAP32[$$013$i$in$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$0$ph5$i$i = $$013$i$in$i;
   break;
  } else {
   $$0$ph7$i$i = $$013$i$in$i;$$01$ph6$i$in$i = $9;
  }
 }
 $14 = ($$0$ph5$i$i|0)==($3|0);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($$0$ph5$i$i) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($5>>>0)<($16>>>0);
 if ($17) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($$0$ph5$i$i) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $$01$i$i$i = $$0$ph5$i$i;
  while(1) {
   $23 = (($$01$i$i$i) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==($$01$i$i$i|0);
   if ($26) {
    $$0$i$i$i = $24;
    break;
   } else {
    $$01$i$i$i = $24;
   }
  }
 } else {
  $$0$i$i$i$i = $19;
  while(1) {
   $21 = HEAP32[$$0$i$i$i$i>>2]|0;
   $22 = ($21|0)==(0|0);
   if ($22) {
    $$0$i$i$i = $$0$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i = $21;
   }
  }
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==($$0$ph5$i$i|0);
 if ($28) {
  HEAP32[$this>>2] = $$0$i$i$i;
 }
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + -1)|0;
 HEAP32[$29>>2] = $31;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($2,$$0$ph5$i$i);
 HEAP32[$0>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($$0$ph5$i$i|0),($$byval_copy|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 } else {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$22 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4>>>0)<($6>>>0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6>>>0)<($4>>>0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $32 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $31 = (($agg$result) + 4|0);
  HEAP8[$31>>0] = $32;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 55;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $17 = (__Z15malloc_internaljj10MemLabelIdiPKci(20,16,$$byval_copy,0,589824,79)|0);
 $18 = (($17) + 16|0);
 $19 = HEAP32[$__v>>2]|0;
 HEAP32[$18>>2] = $19;
 HEAP32[$17>>2] = 0;
 $20 = (($17) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($17) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $17;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $17;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $32 = 1;$__r$0 = $17;
 HEAP32[$agg$result>>2] = $__r$0;
 $31 = (($agg$result) + 4|0);
 HEAP8[$31>>0] = $32;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIiN21BillboardBatchManager18BillboardAssetDataEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE15__insert_uniqueERKS4_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$39 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)<($6|0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6|0)<($4|0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$39 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$39 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$39 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $49 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $48 = (($agg$result) + 4|0);
  HEAP8[$48>>0] = $49;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 55;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $17 = (__Z15malloc_internaljj10MemLabelIdiPKci(120,16,$$byval_copy1,0,589824,79)|0);
 $18 = (($17) + 16|0);
 $19 = HEAP32[$__v>>2]|0;
 HEAP32[$18>>2] = $19;
 $20 = (($17) + 20|0);
 $21 = (($__v) + 4|0);
 ;HEAP32[$20+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$21+12>>2]|0;
 $22 = (($17) + 36|0);
 $23 = (($__v) + 20|0);
 __THREW__ = 0;
 invoke_vii(2693,($22|0),($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  $33 = (($17) + 116|0);
  $34 = (($__v) + 100|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$33>>2] = $35;
  $36 = HEAP32[$__v>>2]|0;
  HEAP32[$18>>2] = $36;
  HEAP32[$17>>2] = 0;
  $37 = (($17) + 4|0);
  HEAP32[$37>>2] = 0;
  $38 = (($17) + 8|0);
  HEAP32[$38>>2] = $39;
  HEAP32[$$0$i>>2] = $17;
  $40 = HEAP32[$this>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   $44 = $17;
  } else {
   HEAP32[$this>>2] = $41;
   $$pre$i = HEAP32[$$0$i>>2]|0;
   $44 = $$pre$i;
  }
  $43 = HEAP32[$1>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($43,$44);
  $45 = (($this) + 8|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + 1)|0;
  HEAP32[$45>>2] = $47;
  $49 = 1;$__r$0 = $17;
  HEAP32[$agg$result>>2] = $__r$0;
  $48 = (($agg$result) + 4|0);
  HEAP8[$48>>0] = $49;
  STACKTOP = sp;return;
 }
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 $28 = ($17|0)==(0|0);
 if ($28) {
  ___resumeException($26|0);
  // unreachable;
 }
 HEAP32[$0>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($17|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  ___cxa_call_unexpected(($31|0));
  // unreachable;
 } else {
  ___resumeException($26|0);
  // unreachable;
 }
}
function __ZN9BillboardC2ERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy6 = 0, $$idx$i$i = 0, $$idx$i$i5 = 0, $$idx$i$i9 = 0, $$pre$i = 0, $$pre$i10 = 0, $$pre$i4 = 0, $$pre$i6 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $phitmp$i11 = 0, $phitmp$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = sp + 8|0;
 $4 = sp + 12|0;
 $5 = sp + 16|0;
 $6 = sp + 20|0;
 ;HEAP32[$this+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$0+8>>2]|0;
 $7 = (($0) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 16|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 20|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 24|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 12|0);
 HEAP32[$12>>2] = 0;
 $13 = (($0) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($0) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $$idx$i$i = $16 << 4;
 $17 = $$idx$i$i >> 4;
 HEAP32[$10>>2] = $17;
 $18 = ($17|0)==(0);
 if ($18) {
  $20 = 0;$21 = 0;
 } else {
  HEAP32[$11>>2] = $17;
  HEAP32[$1>>2] = $8;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  $19 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i,4,$$byval_copy6,0,589824,370)|0);
  HEAP32[$12>>2] = $19;
  $$pre$i = HEAP32[$10>>2]|0;
  $phitmp$i = $$pre$i << 4;
  $20 = $19;$21 = $phitmp$i;
 }
 _memcpy(($20|0),($14|0),($21|0))|0;
 $22 = (($0) + 32|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 32|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 36|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 40|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 28|0);
 HEAP32[$27>>2] = 0;
 $28 = (($0) + 28|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($0) + 36|0);
 $31 = HEAP32[$30>>2]|0;
 HEAP32[$25>>2] = $31;
 $32 = ($31|0)==(0);
 do {
  if ($32) {
   $36 = 0;$37 = 0;
   label = 6;
  } else {
   HEAP32[$26>>2] = $31;
   HEAP32[$6>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$6+0>>2]|0;
   $33 = (invoke_iiiiiiii(108,(0|0),($31|0),1,($$byval_copy6|0),0,(589824|0),370)|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    $$2 = $76;$$23 = $75;
    break;
   } else {
    HEAP32[$27>>2] = $33;
    $$pre$i4 = HEAP32[$25>>2]|0;
    $36 = $33;$37 = $$pre$i4;
    label = 6;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 6) {
   _memcpy(($36|0),($29|0),($37|0))|0;
   $38 = (($0) + 48|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($this) + 48|0);
   HEAP32[$40>>2] = $39;
   $41 = (($this) + 52|0);
   HEAP32[$41>>2] = 0;
   $42 = (($this) + 56|0);
   HEAP32[$42>>2] = 0;
   $43 = (($this) + 44|0);
   HEAP32[$43>>2] = 0;
   $44 = (($0) + 44|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($0) + 52|0);
   $47 = HEAP32[$46>>2]|0;
   $$idx$i$i5 = $47 << 3;
   $48 = $$idx$i$i5 >> 3;
   HEAP32[$41>>2] = $48;
   $49 = ($48|0)==(0);
   do {
    if ($49) {
     $53 = 0;$54 = 0;
     label = 9;
    } else {
     HEAP32[$42>>2] = $48;
     HEAP32[$5>>2] = $39;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
     $50 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i5|0),4,($$byval_copy6|0),0,(589824|0),370)|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      $77 = ___cxa_find_matching_catch()|0;
      $78 = tempRet0;
      $$1 = $78;$$12 = $77;
      break;
     } else {
      HEAP32[$43>>2] = $50;
      $$pre$i6 = HEAP32[$41>>2]|0;
      $phitmp$i7 = $$pre$i6 << 3;
      $53 = $50;$54 = $phitmp$i7;
      label = 9;
      break;
     }
    }
   } while(0);
   do {
    if ((label|0) == 9) {
     _memcpy(($53|0),($45|0),($54|0))|0;
     $55 = (($0) + 64|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($this) + 64|0);
     HEAP32[$57>>2] = $56;
     $58 = (($this) + 68|0);
     HEAP32[$58>>2] = 0;
     $59 = (($this) + 72|0);
     HEAP32[$59>>2] = 0;
     $60 = (($this) + 60|0);
     HEAP32[$60>>2] = 0;
     $61 = (($0) + 60|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($0) + 68|0);
     $64 = HEAP32[$63>>2]|0;
     $$idx$i$i9 = $64 << 1;
     $65 = $$idx$i$i9 >> 1;
     HEAP32[$58>>2] = $65;
     $66 = ($65|0)==(0);
     if ($66) {
      $70 = 0;$71 = 0;
      _memcpy(($70|0),($62|0),($71|0))|0;
      $72 = (($0) + 76|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($this) + 76|0);
      HEAP32[$74>>2] = $73;
      STACKTOP = sp;return;
     }
     HEAP32[$59>>2] = $65;
     HEAP32[$4>>2] = $56;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
     $67 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i9|0),2,($$byval_copy6|0),0,(589824|0),370)|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if (!($69)) {
      HEAP32[$60>>2] = $67;
      $$pre$i10 = HEAP32[$58>>2]|0;
      $phitmp$i11 = $$pre$i10 << 1;
      $70 = $67;$71 = $phitmp$i11;
      _memcpy(($70|0),($62|0),($71|0))|0;
      $72 = (($0) + 76|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($this) + 76|0);
      HEAP32[$74>>2] = $73;
      STACKTOP = sp;return;
     }
     $79 = ___cxa_find_matching_catch()|0;
     $80 = tempRet0;
     $81 = HEAP32[$42>>2]|0;
     $82 = ($81|0)>(-1);
     if ($82) {
      $83 = HEAP32[$43>>2]|0;
      $84 = HEAP32[$40>>2]|0;
      HEAP32[$3>>2] = $84;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($83|0),($$byval_copy6|0));
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if ($86) {
       $99 = ___cxa_find_matching_catch(0|0)|0;
       $100 = tempRet0;
       ___clang_call_terminate($99);
       // unreachable;
      } else {
       HEAP32[$43>>2] = 0;
       $$1 = $80;$$12 = $79;
       break;
      }
     } else {
      $$1 = $80;$$12 = $79;
     }
    }
   } while(0);
   $87 = HEAP32[$26>>2]|0;
   $88 = ($87|0)>(-1);
   if ($88) {
    $89 = HEAP32[$27>>2]|0;
    $90 = HEAP32[$24>>2]|0;
    HEAP32[$2>>2] = $90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($89|0),($$byval_copy6|0));
    $91 = __THREW__; __THREW__ = 0;
    $92 = $91&1;
    if ($92) {
     $99 = ___cxa_find_matching_catch(0|0)|0;
     $100 = tempRet0;
     ___clang_call_terminate($99);
     // unreachable;
    } else {
     HEAP32[$27>>2] = 0;
     $$2 = $$1;$$23 = $$12;
     break;
    }
   } else {
    $$2 = $$1;$$23 = $$12;
   }
  }
 } while(0);
 $93 = HEAP32[$11>>2]|0;
 $94 = ($93|0)>(-1);
 if (!($94)) {
  ___resumeException($$23|0);
  // unreachable;
 }
 $95 = HEAP32[$12>>2]|0;
 $96 = HEAP32[$9>>2]|0;
 HEAP32[$1>>2] = $96;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($95|0),($$byval_copy6|0));
 $97 = __THREW__; __THREW__ = 0;
 $98 = $97&1;
 if ($98) {
  $99 = ___cxa_find_matching_catch(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 }
 HEAP32[$12>>2] = 0;
 ___resumeException($$23|0);
 // unreachable;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = HEAP32[$__v>>2]|0;
  $4 = (($1) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($3|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($3|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($3|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($3|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS4_PNS_11__tree_nodeIS4_SE_EEiEESH_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = HEAP32[$__v>>2]|0;
  $4 = (($1) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($3|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($3|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($3|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($3|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS6_PNS_11__tree_nodeIS6_SG_EEiEESJ_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = HEAP32[$__v>>2]|0;
  $4 = (($1) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($3|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($3|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($3|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($3|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIiN21BillboardBatchManager18BillboardAssetDataEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN21BillboardBatchManager18BillboardAssetDataEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN21BillboardBatchManager18BillboardAssetDataEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$4);
 $5 = (($__nd) + 36|0);
 __THREW__ = 0;
 invoke_vi(3463,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  ___cxa_call_unexpected(($12|0));
  // unreachable;
 }
 HEAP32[$0>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  ___cxa_call_unexpected(($10|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeIPN21BillboardBatchManager14BillboardBatchENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier55ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$4);
 HEAP32[$0>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  ___cxa_call_unexpected(($7|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __GLOBAL__I_a3547() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588464);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588480);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588496);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588504);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588528);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[588520>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588560);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[588552>>2] = $2;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588592);
 $3 = HEAP32[$0>>2]|0;
 HEAP32[588584>>2] = $3;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588624);
 $4 = HEAP32[$0>>2]|0;
 HEAP32[588608>>2] = $4;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588640);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[((588608 + 4|0))>>2] = $5;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588656);
 $6 = HEAP32[$0>>2]|0;
 HEAP32[((588608 + 8|0))>>2] = $6;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588672);
 $7 = HEAP32[$0>>2]|0;
 HEAP32[((588608 + 12|0))>>2] = $7;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588704);
 $8 = HEAP32[$0>>2]|0;
 HEAP32[588688>>2] = $8;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588720);
 $9 = HEAP32[$0>>2]|0;
 HEAP32[((588688 + 4|0))>>2] = $9;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588736);
 $10 = HEAP32[$0>>2]|0;
 HEAP32[((588688 + 8|0))>>2] = $10;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588752);
 $11 = HEAP32[$0>>2]|0;
 HEAP32[((588688 + 12|0))>>2] = $11;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588896);
 $12 = HEAP32[$0>>2]|0;
 HEAP32[588768>>2] = $12;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588920);
 $13 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 4|0))>>2] = $13;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588944);
 $14 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 8|0))>>2] = $14;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588968);
 $15 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 12|0))>>2] = $15;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,588992);
 $16 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 16|0))>>2] = $16;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589016);
 $17 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 20|0))>>2] = $17;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589040);
 $18 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 24|0))>>2] = $18;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589064);
 $19 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 28|0))>>2] = $19;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589088);
 $20 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 32|0))>>2] = $20;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589112);
 $21 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 36|0))>>2] = $21;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589136);
 $22 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 40|0))>>2] = $22;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589160);
 $23 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 44|0))>>2] = $23;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589184);
 $24 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 48|0))>>2] = $24;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589208);
 $25 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 52|0))>>2] = $25;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589232);
 $26 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 56|0))>>2] = $26;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589256);
 $27 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 60|0))>>2] = $27;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589280);
 $28 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 64|0))>>2] = $28;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589304);
 $29 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 68|0))>>2] = $29;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589328);
 $30 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 72|0))>>2] = $30;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589352);
 $31 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 76|0))>>2] = $31;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589376);
 $32 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 80|0))>>2] = $32;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589400);
 $33 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 84|0))>>2] = $33;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589424);
 $34 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 88|0))>>2] = $34;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589448);
 $35 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 92|0))>>2] = $35;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589472);
 $36 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 96|0))>>2] = $36;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589496);
 $37 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 100|0))>>2] = $37;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589520);
 $38 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 104|0))>>2] = $38;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589544);
 $39 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 108|0))>>2] = $39;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589568);
 $40 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 112|0))>>2] = $40;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589592);
 $41 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 116|0))>>2] = $41;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589616);
 $42 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 120|0))>>2] = $42;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589640);
 $43 = HEAP32[$0>>2]|0;
 HEAP32[((588768 + 124|0))>>2] = $43;
 $44 = (__Znwj(32)|0);
 HEAP32[((589664 + 8|0))>>2] = $44;
 HEAP32[589664>>2] = 33;
 HEAP32[((589664 + 4|0))>>2] = 25;
 dest=$44+0|0; src=589680+0|0; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $45 = (($44) + 25|0);
 HEAP8[$45>>0] = 0;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,589720);
 $46 = HEAP32[$0>>2]|0;
 HEAP32[589712>>2] = $46;
 __ZN35RegisterRuntimeInitializeAndCleanupC2EPFvvES1_i(589744,117,118,0);
 STACKTOP = sp;return;
}
function __ZN10GISettingsC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = Math_fround(1.0);
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 17|0);
 HEAP8[$4>>0] = 1;
 STACKTOP = sp;return;
}
function __Z13GetGISettingsv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetLightmapSettingsv()|0);
 $1 = (($0) + 100|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN9Behaviour15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Behaviour10SetEnabledEb($this,$enab) {
 $this = $this|0;
 $enab = $enab|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $tmp = $2 ^ $enab;
 if (!($tmp)) {
  STACKTOP = sp;return;
 }
 $3 = $enab&1;
 HEAP8[$0>>0] = $3;
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 4;
 } else {
  $7 = (__ZNK5Unity10GameObject8IsActiveEv($5)|0);
  if ($7) {
   $11 = HEAP8[$0>>0]|0;
   $12 = ($11<<24>>24)!=(0);
   $13 = (($this) + 29|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)!=(0);
   $tmp$i = $12 ^ $15;
   if (!($tmp$i)) {
    STACKTOP = sp;return;
   }
   if ($12) {
    HEAP8[$13>>0] = 1;
    $16 = HEAP32[$this>>2]|0;
    $17 = (($16) + 124|0);
    $18 = HEAP32[$17>>2]|0;
    FUNCTION_TABLE_vi[$18 & 4095]($this);
    STACKTOP = sp;return;
   } else {
    $19 = $13;
   }
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $8 = (($this) + 29|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $19 = $8;
  }
 }
 HEAP8[$19>>0] = 0;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 128|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $tmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 3;
 } else {
  $3 = (__ZNK5Unity10GameObject8IsActiveEv($1)|0);
  if ($3) {
   $7 = (($this) + 28|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)!=(0);
   $10 = (($this) + 29|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)!=(0);
   $tmp$i = $9 ^ $12;
   if (!($tmp$i)) {
    STACKTOP = sp;return;
   }
   if ($9) {
    HEAP8[$10>>0] = 1;
    $13 = HEAP32[$this>>2]|0;
    $14 = (($13) + 124|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vi[$15 & 4095]($this);
    STACKTOP = sp;return;
   } else {
    $16 = $10;
   }
  } else {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $4 = (($this) + 29|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   STACKTOP = sp;return;
  } else {
   $16 = $4;
  }
 }
 HEAP8[$16>>0] = 0;
 $17 = HEAP32[$this>>2]|0;
 $18 = (($17) + 128|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN9Behaviour10DeactivateEN5Unity19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 29|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN9Behaviour23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,589896,589960,$this,0);
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,589976,$1,$0,257);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Behaviour23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,589896,589960,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Behaviour23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9Behaviour23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9Behaviour23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP8[$0>>0]|0;
  HEAP8[$2>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9Behaviour23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN20BaseBehaviourManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1000,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN20BaseBehaviourManagerD2Ev($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((589904 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = ($1|0)==($2|0);
 if (!($3)) {
  $5 = $1;
  while(1) {
   $4 = (($5) + 20|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    __ZdlPv($6);
   }
   $8 = (($5) + 24|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    __ZdlPv($9);
   }
   $11 = (($5) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$01$i$i$i$i = $5;
    while(1) {
     $16 = (($$01$i$i$i$i) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==($$01$i$i$i$i|0);
     if ($19) {
      $$0$i$i$i$i = $17;
      break;
     } else {
      $$01$i$i$i$i = $17;
     }
    }
   } else {
    $$0$i$i$i$i$i = $12;
    while(1) {
     $14 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $14;
     }
    }
   }
   $20 = ($$0$i$i$i$i|0)==($2|0);
   if ($20) {
    break;
   } else {
    $5 = $$0$i$i$i$i;
   }
  }
 }
 $21 = (($this) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiNS_4pairIP4ListI8ListNodeI9BehaviourEES8_EEEENS_19__map_value_compareIiSA_NS_4lessIiEELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,$22);
 $23 = (($this) + 12|0);
 HEAP32[$23>>2] = 0;
 HEAP32[$0>>2] = $2;
 HEAP32[$2>>2] = 0;
 __ZNSt3__16__treeINS_12__value_typeIiNS_4pairIP4ListI8ListNodeI9BehaviourEES8_EEEENS_19__map_value_compareIiSA_NS_4lessIiEELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($0,0);
 STACKTOP = sp;return;
}
function __ZN20BaseBehaviourManager12AddBehaviourER8ListNodeI9BehaviourEi($this,$p,$queueIndex) {
 $this = $this|0;
 $p = $p|0;
 $queueIndex = $queueIndex|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $queueIndex;
 $1 = (($this) + 4|0);
 $2 = (__ZNSt3__13mapIiNS_4pairIP4ListI8ListNodeI9BehaviourEES7_EENS_4lessIiEENS_9allocatorINS1_IKiS8_EEEEEixERSC_($1,$0)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (__Znwj(8)|0);
  $6 = (($5) + 4|0);
  HEAP32[$5>>2] = $5;
  HEAP32[$6>>2] = $5;
  HEAP32[$2>>2] = $5;
  $7 = (__Znwj(8)|0);
  $8 = (($7) + 4|0);
  HEAP32[$7>>2] = $7;
  HEAP32[$8>>2] = $7;
  $9 = (($2) + 4|0);
  HEAP32[$9>>2] = $7;
  $11 = $7;
 } else {
  $$phi$trans$insert = (($2) + 4|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $11 = $$pre;
 }
 $10 = ($p|0)==($11|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$p>>2]|0;
 $13 = ($12|0)==(0|0);
 $$pre$i$i = (($p) + 4|0);
 if (!($13)) {
  $14 = HEAP32[$$pre$i$i>>2]|0;
  $15 = (($12) + 4|0);
  HEAP32[$15>>2] = $14;
  $16 = HEAP32[$p>>2]|0;
  $17 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$17>>2] = $16;
  HEAP32[$p>>2] = 0;
  HEAP32[$$pre$i$i>>2] = 0;
 }
 $18 = HEAP32[$11>>2]|0;
 HEAP32[$p>>2] = $18;
 HEAP32[$$pre$i$i>>2] = $11;
 $19 = (($18) + 4|0);
 HEAP32[$19>>2] = $p;
 $20 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$20>>2] = $p;
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIiNS_4pairIP4ListI8ListNodeI9BehaviourEES7_EENS_4lessIiEENS_9allocatorINS1_IKiS8_EEEEEixERSC_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$23 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$23 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $32 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($32|0);
 }
 $16 = (__Znwj(28)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 24|0);
 HEAP32[$20>>2] = 0;
 HEAP32[$16>>2] = 0;
 $21 = (($16) + 4|0);
 HEAP32[$21>>2] = 0;
 $22 = (($16) + 8|0);
 HEAP32[$22>>2] = $23;
 HEAP32[$$0$i>>2] = $16;
 $24 = HEAP32[$this>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $28 = $16;
 } else {
  HEAP32[$this>>2] = $25;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $28 = $$pre$i;
 }
 $27 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 $__r$0 = $16;
 $32 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($32|0);
}
function __Z19GetBehaviourManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[589928>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z24GetFixedBehaviourManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[589936>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z23GetLateBehaviourManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[589944>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z16GetUpdateManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[589952>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN9Behaviour15InitializeClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(16)|0);
 $1 = (($0) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($0) + 4|0);
 HEAP32[$3>>2] = $1;
 HEAP32[$0>>2] = ((590208 + 8|0));
 HEAP32[589928>>2] = $0;
 $4 = (__Znwj(16)|0);
 $5 = (($4) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = (($4) + 4|0);
 HEAP32[$7>>2] = $5;
 HEAP32[$4>>2] = ((590184 + 8|0));
 HEAP32[589936>>2] = $4;
 $8 = (__Znwj(16)|0);
 $9 = (($8) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 12|0);
 HEAP32[$10>>2] = 0;
 $11 = (($8) + 4|0);
 HEAP32[$11>>2] = $9;
 HEAP32[$8>>2] = ((590160 + 8|0));
 HEAP32[589944>>2] = $8;
 $12 = (__Znwj(16)|0);
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($12) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($12) + 4|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$12>>2] = ((590136 + 8|0));
 HEAP32[589952>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN9Behaviour12CleanupClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[589928>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[$0>>2]|0;
  $3 = (($2) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095]($0);
 }
 $5 = HEAP32[589936>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 4095]($5);
 }
 $10 = HEAP32[589944>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 4095]($10);
 }
 $15 = HEAP32[589952>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$15>>2]|0;
 $18 = (($17) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 4095]($15);
 STACKTOP = sp;return;
}
function __Z23RegisterClass_Behaviourv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(8,119,120,0,121);
 STACKTOP = sp;return;
}
function __ZN9Behaviour13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(2)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity9Component13RegisterClassEv();
 }
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=589960+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,8,2,($0|0),32,(2389|0),1,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN9Behaviour7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK9Behaviour25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 8;
}
function __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,589976,$1,$0,257);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN5Unity9Component8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580744>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,589976,$1,$converter$i$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 do {
  if ($4) {
   $5 = (($transfer) + 12|0);
   $6 = (($transfer) + 80|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($transfer) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($transfer) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($transfer) + 32|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = Math_imul($15, $13)|0;
   $$sum$i$i$i$i$i = (($9) - ($16))|0;
   $17 = (($11) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$5>>2] = $17;
   $18 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($18)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $19 = (($11) + ($$sum1$i$i$i$i$i)|0);
    $20 = (($transfer) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($19>>>0)>($21>>>0);
    if (!($22)) {
     $23 = HEAP8[$17>>0]|0;
     HEAP8[$0>>0] = $23;
     $24 = HEAP32[$5>>2]|0;
     $25 = (($24) + 1|0);
     HEAP32[$5>>2] = $25;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$0,1);
  } else {
   $26 = HEAP32[$converter$i$i>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    (FUNCTION_TABLE_iii[$26 & 4095]($0,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP8[$0>>0]|0;
  HEAP8[$2>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIiNS_4pairIP4ListI8ListNodeI9BehaviourEES8_EEEENS_19__map_value_compareIiSA_NS_4lessIiEELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiNS_4pairIP4ListI8ListNodeI9BehaviourEES8_EEEENS_19__map_value_compareIiSA_NS_4lessIiEELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiNS_4pairIP4ListI8ListNodeI9BehaviourEES8_EEEENS_19__map_value_compareIiSA_NS_4lessIiEELb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN13UpdateManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20BaseBehaviourManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN13UpdateManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1000,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN13UpdateManager6UpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20BaseBehaviourManager12CommonUpdateI16BehaviourManagerEEvv($this);
 STACKTOP = sp;return;
}
function __ZN20BaseBehaviourManager12CommonUpdateI16BehaviourManagerEEvv($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i1 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $iterator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iterator = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  $29 = $1;
 } else {
  $5 = $1;
  while(1) {
   $4 = (($5) + 20|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = (($5) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($8|0);
   if (!($11)) {
    $12 = HEAP32[$6>>2]|0;
    $13 = (($12) + 4|0);
    HEAP32[$13>>2] = $10;
    $14 = HEAP32[$8>>2]|0;
    HEAP32[$6>>2] = $14;
    $15 = HEAP32[$13>>2]|0;
    HEAP32[$15>>2] = $12;
    $16 = HEAP32[$6>>2]|0;
    $17 = (($16) + 4|0);
    HEAP32[$17>>2] = $6;
    HEAP32[$9>>2] = $8;
    HEAP32[$8>>2] = $8;
   }
   $18 = (($5) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $$01$i$i$i$i$i = $5;
    while(1) {
     $23 = (($$01$i$i$i$i$i) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($$01$i$i$i$i$i|0);
     if ($26) {
      $$0$i$i$i$i$i = $24;
      break;
     } else {
      $$01$i$i$i$i$i = $24;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $19;
    while(1) {
     $21 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $21;
     }
    }
   }
   $27 = ($$0$i$i$i$i$i|0)==($2|0);
   if ($27) {
    break;
   } else {
    $5 = $$0$i$i$i$i$i;
   }
  }
  $$pre = HEAP32[$0>>2]|0;
  $29 = $$pre;
 }
 $28 = ($29|0)==($2|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $30 = (($iterator) + 4|0);
 $31 = (($iterator) + 8|0);
 $32 = (($iterator) + 12|0);
 $34 = $29;
 while(1) {
  $33 = (($34) + 20|0);
  $35 = HEAP32[$33>>2]|0;
  HEAP32[$iterator>>2] = $iterator;
  HEAP32[$30>>2] = $iterator;
  HEAP32[$31>>2] = $35;
  HEAP32[$32>>2] = 0;
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$35>>2] = $iterator;
  HEAP32[$iterator>>2] = $36;
  $37 = (($35) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$30>>2]|0;
  HEAP32[$37>>2] = $39;
  HEAP32[$30>>2] = $38;
  $40 = HEAP32[$35>>2]|0;
  $41 = ($40|0)==($iterator|0);
  if ($41) {
   HEAP32[$35>>2] = $35;
  }
  $42 = HEAP32[$iterator>>2]|0;
  $43 = ($42|0)==($35|0);
  if ($43) {
   HEAP32[$iterator>>2] = $iterator;
  }
  $44 = HEAP32[$37>>2]|0;
  $45 = ($44|0)==($iterator|0);
  if ($45) {
   HEAP32[$37>>2] = $35;
  }
  $46 = HEAP32[$30>>2]|0;
  $47 = ($46|0)==($35|0);
  if ($47) {
   HEAP32[$30>>2] = $iterator;
  }
  $48 = HEAP32[$35>>2]|0;
  $49 = (($48) + 4|0);
  HEAP32[$49>>2] = $35;
  $50 = HEAP32[$37>>2]|0;
  HEAP32[$50>>2] = $35;
  $51 = HEAP32[$iterator>>2]|0;
  $52 = (($51) + 4|0);
  HEAP32[$52>>2] = $iterator;
  $53 = HEAP32[$30>>2]|0;
  HEAP32[$53>>2] = $iterator;
  while(1) {
   $54 = HEAP32[$30>>2]|0;
   $55 = ($54|0)==($iterator|0);
   if ($55) {
    label = 29;
    break;
   }
   HEAP32[$32>>2] = $54;
   $56 = HEAP32[$54>>2]|0;
   $57 = ($56|0)==(0|0);
   if ($57) {
    $65 = $54;
   } else {
    $58 = (($54) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($56) + 4|0);
    HEAP32[$60>>2] = $59;
    $61 = HEAP32[$54>>2]|0;
    $62 = HEAP32[$58>>2]|0;
    HEAP32[$62>>2] = $61;
    HEAP32[$54>>2] = 0;
    HEAP32[$58>>2] = 0;
    $$pre3$i = HEAP32[$32>>2]|0;
    $65 = $$pre3$i;
   }
   $63 = HEAP32[$31>>2]|0;
   $64 = ($65|0)==($63|0);
   if ($64) {
    $76 = $65;
   } else {
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    $$pre$i$i$i = (($65) + 4|0);
    if (!($67)) {
     $68 = HEAP32[$$pre$i$i$i>>2]|0;
     $69 = (($66) + 4|0);
     HEAP32[$69>>2] = $68;
     $70 = HEAP32[$65>>2]|0;
     $71 = HEAP32[$$pre$i$i$i>>2]|0;
     HEAP32[$71>>2] = $70;
     HEAP32[$65>>2] = 0;
     HEAP32[$$pre$i$i$i>>2] = 0;
    }
    $72 = HEAP32[$63>>2]|0;
    HEAP32[$65>>2] = $72;
    HEAP32[$$pre$i$i$i>>2] = $63;
    $73 = (($72) + 4|0);
    HEAP32[$73>>2] = $65;
    $74 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$74>>2] = $65;
    $$pre$i = HEAP32[$32>>2]|0;
    $76 = $$pre$i;
   }
   $75 = ($76|0)==(0|0);
   if ($75) {
    break;
   }
   $77 = (($76) + 8|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = HEAP32[$78>>2]|0;
   $80 = (($79) + 108|0);
   $81 = HEAP32[$80>>2]|0;
   FUNCTION_TABLE_vi[$81 & 4095]($78);
  }
  if ((label|0) == 29) {
   label = 0;
   HEAP32[$32>>2] = 0;
  }
  HEAP32[$30>>2] = 0;
  HEAP32[$iterator>>2] = 0;
  $82 = (($34) + 4|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $$01$i$i$i$i = $34;
   while(1) {
    $87 = (($$01$i$i$i$i) + 8|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)==($$01$i$i$i$i|0);
    if ($90) {
     $$0$i$i$i$i = $88;
     break;
    } else {
     $$01$i$i$i$i = $88;
    }
   }
  } else {
   $$0$i$i$i$i$i1 = $83;
   while(1) {
    $85 = HEAP32[$$0$i$i$i$i$i1>>2]|0;
    $86 = ($85|0)==(0|0);
    if ($86) {
     $$0$i$i$i$i = $$0$i$i$i$i$i1;
     break;
    } else {
     $$0$i$i$i$i$i1 = $85;
    }
   }
  }
  $91 = ($$0$i$i$i$i|0)==($2|0);
  if ($91) {
   break;
  } else {
   $34 = $$0$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN20LateBehaviourManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20BaseBehaviourManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN20LateBehaviourManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1000,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN20LateBehaviourManager6UpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20BaseBehaviourManager12CommonUpdateI20LateBehaviourManagerEEvv($this);
 STACKTOP = sp;return;
}
function __ZN20BaseBehaviourManager12CommonUpdateI20LateBehaviourManagerEEvv($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i1 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $iterator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iterator = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  $29 = $1;
 } else {
  $5 = $1;
  while(1) {
   $4 = (($5) + 20|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = (($5) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($8|0);
   if (!($11)) {
    $12 = HEAP32[$6>>2]|0;
    $13 = (($12) + 4|0);
    HEAP32[$13>>2] = $10;
    $14 = HEAP32[$8>>2]|0;
    HEAP32[$6>>2] = $14;
    $15 = HEAP32[$13>>2]|0;
    HEAP32[$15>>2] = $12;
    $16 = HEAP32[$6>>2]|0;
    $17 = (($16) + 4|0);
    HEAP32[$17>>2] = $6;
    HEAP32[$9>>2] = $8;
    HEAP32[$8>>2] = $8;
   }
   $18 = (($5) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $$01$i$i$i$i$i = $5;
    while(1) {
     $23 = (($$01$i$i$i$i$i) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($$01$i$i$i$i$i|0);
     if ($26) {
      $$0$i$i$i$i$i = $24;
      break;
     } else {
      $$01$i$i$i$i$i = $24;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $19;
    while(1) {
     $21 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $21;
     }
    }
   }
   $27 = ($$0$i$i$i$i$i|0)==($2|0);
   if ($27) {
    break;
   } else {
    $5 = $$0$i$i$i$i$i;
   }
  }
  $$pre = HEAP32[$0>>2]|0;
  $29 = $$pre;
 }
 $28 = ($29|0)==($2|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $30 = (($iterator) + 4|0);
 $31 = (($iterator) + 8|0);
 $32 = (($iterator) + 12|0);
 $34 = $29;
 while(1) {
  $33 = (($34) + 20|0);
  $35 = HEAP32[$33>>2]|0;
  HEAP32[$iterator>>2] = $iterator;
  HEAP32[$30>>2] = $iterator;
  HEAP32[$31>>2] = $35;
  HEAP32[$32>>2] = 0;
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$35>>2] = $iterator;
  HEAP32[$iterator>>2] = $36;
  $37 = (($35) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$30>>2]|0;
  HEAP32[$37>>2] = $39;
  HEAP32[$30>>2] = $38;
  $40 = HEAP32[$35>>2]|0;
  $41 = ($40|0)==($iterator|0);
  if ($41) {
   HEAP32[$35>>2] = $35;
  }
  $42 = HEAP32[$iterator>>2]|0;
  $43 = ($42|0)==($35|0);
  if ($43) {
   HEAP32[$iterator>>2] = $iterator;
  }
  $44 = HEAP32[$37>>2]|0;
  $45 = ($44|0)==($iterator|0);
  if ($45) {
   HEAP32[$37>>2] = $35;
  }
  $46 = HEAP32[$30>>2]|0;
  $47 = ($46|0)==($35|0);
  if ($47) {
   HEAP32[$30>>2] = $iterator;
  }
  $48 = HEAP32[$35>>2]|0;
  $49 = (($48) + 4|0);
  HEAP32[$49>>2] = $35;
  $50 = HEAP32[$37>>2]|0;
  HEAP32[$50>>2] = $35;
  $51 = HEAP32[$iterator>>2]|0;
  $52 = (($51) + 4|0);
  HEAP32[$52>>2] = $iterator;
  $53 = HEAP32[$30>>2]|0;
  HEAP32[$53>>2] = $iterator;
  while(1) {
   $54 = HEAP32[$30>>2]|0;
   $55 = ($54|0)==($iterator|0);
   if ($55) {
    label = 29;
    break;
   }
   HEAP32[$32>>2] = $54;
   $56 = HEAP32[$54>>2]|0;
   $57 = ($56|0)==(0|0);
   if ($57) {
    $65 = $54;
   } else {
    $58 = (($54) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($56) + 4|0);
    HEAP32[$60>>2] = $59;
    $61 = HEAP32[$54>>2]|0;
    $62 = HEAP32[$58>>2]|0;
    HEAP32[$62>>2] = $61;
    HEAP32[$54>>2] = 0;
    HEAP32[$58>>2] = 0;
    $$pre3$i = HEAP32[$32>>2]|0;
    $65 = $$pre3$i;
   }
   $63 = HEAP32[$31>>2]|0;
   $64 = ($65|0)==($63|0);
   if ($64) {
    $76 = $65;
   } else {
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    $$pre$i$i$i = (($65) + 4|0);
    if (!($67)) {
     $68 = HEAP32[$$pre$i$i$i>>2]|0;
     $69 = (($66) + 4|0);
     HEAP32[$69>>2] = $68;
     $70 = HEAP32[$65>>2]|0;
     $71 = HEAP32[$$pre$i$i$i>>2]|0;
     HEAP32[$71>>2] = $70;
     HEAP32[$65>>2] = 0;
     HEAP32[$$pre$i$i$i>>2] = 0;
    }
    $72 = HEAP32[$63>>2]|0;
    HEAP32[$65>>2] = $72;
    HEAP32[$$pre$i$i$i>>2] = $63;
    $73 = (($72) + 4|0);
    HEAP32[$73>>2] = $65;
    $74 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$74>>2] = $65;
    $$pre$i = HEAP32[$32>>2]|0;
    $76 = $$pre$i;
   }
   $75 = ($76|0)==(0|0);
   if ($75) {
    break;
   }
   $77 = (($76) + 8|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = HEAP32[$78>>2]|0;
   $80 = (($79) + 116|0);
   $81 = HEAP32[$80>>2]|0;
   FUNCTION_TABLE_vi[$81 & 4095]($78);
  }
  if ((label|0) == 29) {
   label = 0;
   HEAP32[$32>>2] = 0;
  }
  HEAP32[$30>>2] = 0;
  HEAP32[$iterator>>2] = 0;
  $82 = (($34) + 4|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $$01$i$i$i$i = $34;
   while(1) {
    $87 = (($$01$i$i$i$i) + 8|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)==($$01$i$i$i$i|0);
    if ($90) {
     $$0$i$i$i$i = $88;
     break;
    } else {
     $$01$i$i$i$i = $88;
    }
   }
  } else {
   $$0$i$i$i$i$i1 = $83;
   while(1) {
    $85 = HEAP32[$$0$i$i$i$i$i1>>2]|0;
    $86 = ($85|0)==(0|0);
    if ($86) {
     $$0$i$i$i$i = $$0$i$i$i$i$i1;
     break;
    } else {
     $$0$i$i$i$i$i1 = $85;
    }
   }
  }
  $91 = ($$0$i$i$i$i|0)==($2|0);
  if ($91) {
   break;
  } else {
   $34 = $$0$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN21FixedBehaviourManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20BaseBehaviourManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN21FixedBehaviourManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1000,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN21FixedBehaviourManager6UpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20BaseBehaviourManager12CommonUpdateI21FixedBehaviourManagerEEvv($this);
 STACKTOP = sp;return;
}
function __ZN20BaseBehaviourManager12CommonUpdateI21FixedBehaviourManagerEEvv($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i1 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $iterator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iterator = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  $29 = $1;
 } else {
  $5 = $1;
  while(1) {
   $4 = (($5) + 20|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = (($5) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($8|0);
   if (!($11)) {
    $12 = HEAP32[$6>>2]|0;
    $13 = (($12) + 4|0);
    HEAP32[$13>>2] = $10;
    $14 = HEAP32[$8>>2]|0;
    HEAP32[$6>>2] = $14;
    $15 = HEAP32[$13>>2]|0;
    HEAP32[$15>>2] = $12;
    $16 = HEAP32[$6>>2]|0;
    $17 = (($16) + 4|0);
    HEAP32[$17>>2] = $6;
    HEAP32[$9>>2] = $8;
    HEAP32[$8>>2] = $8;
   }
   $18 = (($5) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $$01$i$i$i$i$i = $5;
    while(1) {
     $23 = (($$01$i$i$i$i$i) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($$01$i$i$i$i$i|0);
     if ($26) {
      $$0$i$i$i$i$i = $24;
      break;
     } else {
      $$01$i$i$i$i$i = $24;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $19;
    while(1) {
     $21 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $21;
     }
    }
   }
   $27 = ($$0$i$i$i$i$i|0)==($2|0);
   if ($27) {
    break;
   } else {
    $5 = $$0$i$i$i$i$i;
   }
  }
  $$pre = HEAP32[$0>>2]|0;
  $29 = $$pre;
 }
 $28 = ($29|0)==($2|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $30 = (($iterator) + 4|0);
 $31 = (($iterator) + 8|0);
 $32 = (($iterator) + 12|0);
 $34 = $29;
 while(1) {
  $33 = (($34) + 20|0);
  $35 = HEAP32[$33>>2]|0;
  HEAP32[$iterator>>2] = $iterator;
  HEAP32[$30>>2] = $iterator;
  HEAP32[$31>>2] = $35;
  HEAP32[$32>>2] = 0;
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$35>>2] = $iterator;
  HEAP32[$iterator>>2] = $36;
  $37 = (($35) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$30>>2]|0;
  HEAP32[$37>>2] = $39;
  HEAP32[$30>>2] = $38;
  $40 = HEAP32[$35>>2]|0;
  $41 = ($40|0)==($iterator|0);
  if ($41) {
   HEAP32[$35>>2] = $35;
  }
  $42 = HEAP32[$iterator>>2]|0;
  $43 = ($42|0)==($35|0);
  if ($43) {
   HEAP32[$iterator>>2] = $iterator;
  }
  $44 = HEAP32[$37>>2]|0;
  $45 = ($44|0)==($iterator|0);
  if ($45) {
   HEAP32[$37>>2] = $35;
  }
  $46 = HEAP32[$30>>2]|0;
  $47 = ($46|0)==($35|0);
  if ($47) {
   HEAP32[$30>>2] = $iterator;
  }
  $48 = HEAP32[$35>>2]|0;
  $49 = (($48) + 4|0);
  HEAP32[$49>>2] = $35;
  $50 = HEAP32[$37>>2]|0;
  HEAP32[$50>>2] = $35;
  $51 = HEAP32[$iterator>>2]|0;
  $52 = (($51) + 4|0);
  HEAP32[$52>>2] = $iterator;
  $53 = HEAP32[$30>>2]|0;
  HEAP32[$53>>2] = $iterator;
  while(1) {
   $54 = HEAP32[$30>>2]|0;
   $55 = ($54|0)==($iterator|0);
   if ($55) {
    label = 29;
    break;
   }
   HEAP32[$32>>2] = $54;
   $56 = HEAP32[$54>>2]|0;
   $57 = ($56|0)==(0|0);
   if ($57) {
    $65 = $54;
   } else {
    $58 = (($54) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($56) + 4|0);
    HEAP32[$60>>2] = $59;
    $61 = HEAP32[$54>>2]|0;
    $62 = HEAP32[$58>>2]|0;
    HEAP32[$62>>2] = $61;
    HEAP32[$54>>2] = 0;
    HEAP32[$58>>2] = 0;
    $$pre3$i = HEAP32[$32>>2]|0;
    $65 = $$pre3$i;
   }
   $63 = HEAP32[$31>>2]|0;
   $64 = ($65|0)==($63|0);
   if ($64) {
    $76 = $65;
   } else {
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    $$pre$i$i$i = (($65) + 4|0);
    if (!($67)) {
     $68 = HEAP32[$$pre$i$i$i>>2]|0;
     $69 = (($66) + 4|0);
     HEAP32[$69>>2] = $68;
     $70 = HEAP32[$65>>2]|0;
     $71 = HEAP32[$$pre$i$i$i>>2]|0;
     HEAP32[$71>>2] = $70;
     HEAP32[$65>>2] = 0;
     HEAP32[$$pre$i$i$i>>2] = 0;
    }
    $72 = HEAP32[$63>>2]|0;
    HEAP32[$65>>2] = $72;
    HEAP32[$$pre$i$i$i>>2] = $63;
    $73 = (($72) + 4|0);
    HEAP32[$73>>2] = $65;
    $74 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$74>>2] = $65;
    $$pre$i = HEAP32[$32>>2]|0;
    $76 = $$pre$i;
   }
   $75 = ($76|0)==(0|0);
   if ($75) {
    break;
   }
   $77 = (($76) + 8|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = HEAP32[$78>>2]|0;
   $80 = (($79) + 112|0);
   $81 = HEAP32[$80>>2]|0;
   FUNCTION_TABLE_vi[$81 & 4095]($78);
  }
  if ((label|0) == 29) {
   label = 0;
   HEAP32[$32>>2] = 0;
  }
  HEAP32[$30>>2] = 0;
  HEAP32[$iterator>>2] = 0;
  $82 = (($34) + 4|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $$01$i$i$i$i = $34;
   while(1) {
    $87 = (($$01$i$i$i$i) + 8|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)==($$01$i$i$i$i|0);
    if ($90) {
     $$0$i$i$i$i = $88;
     break;
    } else {
     $$01$i$i$i$i = $88;
    }
   }
  } else {
   $$0$i$i$i$i$i1 = $83;
   while(1) {
    $85 = HEAP32[$$0$i$i$i$i$i1>>2]|0;
    $86 = ($85|0)==(0|0);
    if ($86) {
     $$0$i$i$i$i = $$0$i$i$i$i$i1;
     break;
    } else {
     $$0$i$i$i$i$i1 = $85;
    }
   }
  }
  $91 = ($$0$i$i$i$i|0)==($2|0);
  if ($91) {
   break;
  } else {
   $34 = $$0$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16BehaviourManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20BaseBehaviourManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN16BehaviourManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1000,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN16BehaviourManager6UpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20BaseBehaviourManager12CommonUpdateI16BehaviourManagerEEvv($this);
 STACKTOP = sp;return;
}
function __ZN18DelayedCallManager17MainThreadCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18DelayedCallManager8ClearAllEv($this);
 __ZN11GameManager17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN18DelayedCallManager8ClearAllEv($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 28|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  $62 = (($this) + 28|0);
  $63 = HEAP32[$62>>2]|0;
  __ZNSt3__16__treeIN18DelayedCallManager8CallbackENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1,$63);
  $64 = (($this) + 32|0);
  HEAP32[$64>>2] = 0;
  HEAP32[$1>>2] = $3;
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 }
 $6 = $2;
 while(1) {
  $5 = (($6) + 52|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = $7 & 64;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = (($6) + 48|0);
   $11 = HEAP32[$10>>2]|0;
   HEAP32[$0>>2] = $11;
   $12 = HEAP32[560624>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = (($12) + 36|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($12) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($15|0)==($17|0);
    do {
     if ($18) {
      $19 = (($12) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($12) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $39 = $23;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$12,$0);
      $24 = HEAP32[$pos$i$i$i>>2]|0;
      $25 = ($24|0)==(-1);
      $26 = (($12) + 28|0);
      $27 = HEAP32[$26>>2]|0;
      if ($25) {
       $28 = (($12) + 32|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($27) + ($29<<3)|0);
       $39 = $30;
       break;
      } else {
       $31 = (($27) + ($24<<3)|0);
       $39 = $31;
       break;
      }
     }
    } while(0);
    $32 = HEAP32[560624>>2]|0;
    $33 = (($32) + 28|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($32) + 32|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + ($36<<3)|0);
    $38 = ($39|0)==($37|0);
    if (!($38)) {
     $40 = (($39) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if (!($42)) {
      $43 = (($6) + 40|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = (($6) + 36|0);
      $46 = HEAP32[$45>>2]|0;
      FUNCTION_TABLE_vii[$44 & 4095]($41,$46);
     }
    }
   }
  }
  $47 = (($6) + 44|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = (($6) + 36|0);
   $51 = HEAP32[$50>>2]|0;
   FUNCTION_TABLE_vi[$48 & 4095]($51);
  }
  $52 = (($6) + 4|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $$01$i$i$i = $6;
   while(1) {
    $57 = (($$01$i$i$i) + 8|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59|0)==($$01$i$i$i|0);
    if ($60) {
     $$0$i$i$i = $58;
     break;
    } else {
     $$01$i$i$i = $58;
    }
   }
  } else {
   $$0$i$i$i$i = $53;
   while(1) {
    $55 = HEAP32[$$0$i$i$i$i>>2]|0;
    $56 = ($55|0)==(0|0);
    if ($56) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $55;
    }
   }
  }
  $61 = ($$0$i$i$i|0)==($3|0);
  if ($61) {
   break;
  } else {
   $6 = $$0$i$i$i;
  }
 }
 $62 = (($this) + 28|0);
 $63 = HEAP32[$62>>2]|0;
 __ZNSt3__16__treeIN18DelayedCallManager8CallbackENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1,$63);
 $64 = (($this) + 32|0);
 HEAP32[$64>>2] = 0;
 HEAP32[$1>>2] = $3;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE($func,$o,$time,$userData,$repeatRate,$cleanup,$mode) {
 $func = $func|0;
 $o = $o|0;
 $time = Math_fround($time);
 $userData = $userData|0;
 $repeatRate = Math_fround($repeatRate);
 $cleanup = $cleanup|0;
 $mode = $mode|0;
 var $$0$i$i$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0, $8 = 0, $9 = 0.0, $__nd$0$in$i$i$i = 0, $callback$sroa$4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $callback$sroa$4 = sp;
 $0 = $mode & 1;
 $1 = ($0|0)==(0);
 if ($1) {
  $11 = 1.79769313486231570815E+308;
 } else {
  $2 = (__Z14GetTimeManagerv()|0);
  $3 = (($2) + 24|0);
  $4 = +HEAPF64[$3>>3];
  $11 = $4;
 }
 $5 = $mode & 2;
 $6 = ($5|0)==(0);
 if ($6) {
  $73 = $11;
 } else {
  $7 = (__Z14GetTimeManagerv()|0);
  $8 = (($7) + 56|0);
  $9 = +HEAPF64[$8>>3];
  $10 = $9 < $11;
  $12 = $10 ? $9 : $11;
  $73 = $12;
 }
 $13 = $mode & 3;
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = (__Z14GetTimeManagerv()|0);
  $16 = (($15) + 88|0);
  $17 = +HEAPF64[$16>>3];
  $20 = $17;
 } else {
  $20 = $73;
 }
 $18 = +$time;
 $19 = $18 + $20;
 $21 = $mode & 8;
 $22 = ($21|0)==(0);
 if ($22) {
  $49 = -1;
 } else {
  $23 = (__Z14GetTimeManagerv()|0);
  $24 = (($23) + 124|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 1)|0;
  $49 = $26;
 }
 $27 = $repeatRate != Math_fround(0.0);
 $28 = $27&1;
 $29 = HEAP32[$o>>2]|0;
 $30 = (__Z21GetManagerFromContexti(8)|0);
 $31 = (($30) + 40|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (__Z21GetManagerFromContexti(8)|0);
 $34 = (($33) + 24|0);
 $35 = (($33) + 28|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $$0$i$i$i = $35;$64 = $35;
 } else {
  $__nd$0$in$i$i$i = $36;
  while(1) {
   $38 = (($__nd$0$in$i$i$i) + 16|0);
   $39 = +HEAPF64[$38>>3];
   $40 = $19 < $39;
   if ($40) {
    $41 = HEAP32[$__nd$0$in$i$i$i>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     $$0$i$i$i = $__nd$0$in$i$i$i;$64 = $__nd$0$in$i$i$i;
     break;
    } else {
     $__nd$0$in$i$i$i = $41;
     continue;
    }
   } else {
    $43 = (($__nd$0$in$i$i$i) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     $$0$i$i$i = $43;$64 = $__nd$0$in$i$i$i;
     break;
    } else {
     $__nd$0$in$i$i$i = $44;
     continue;
    }
   }
  }
 }
 $46 = (__Znwj(64)|0);
 $47 = (($46) + 16|0);
 HEAPF64[$47>>3] = $19;
 $48 = (($46) + 24|0);
 HEAP32[$48>>2] = $49;
 $50 = (($46) + 28|0);
 HEAPF32[$50>>2] = $repeatRate;
 $51 = (($46) + 32|0);
 HEAP8[$51>>0] = $28;
 $52 = (($46) + 33|0);
 ;HEAP8[$52+0>>0]=HEAP8[$callback$sroa$4+0>>0]|0;HEAP8[$52+1>>0]=HEAP8[$callback$sroa$4+1>>0]|0;HEAP8[$52+2>>0]=HEAP8[$callback$sroa$4+2>>0]|0;
 $53 = (($46) + 36|0);
 HEAP32[$53>>2] = $userData;
 $54 = (($46) + 40|0);
 HEAP32[$54>>2] = $func;
 $55 = (($46) + 44|0);
 HEAP32[$55>>2] = $cleanup;
 $56 = (($46) + 48|0);
 HEAP32[$56>>2] = $29;
 $57 = (($46) + 52|0);
 $58 = $57;
 $59 = $58;
 HEAP32[$59>>2] = $mode;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $32;
 HEAP32[$46>>2] = 0;
 $62 = (($46) + 4|0);
 HEAP32[$62>>2] = 0;
 $63 = (($46) + 8|0);
 HEAP32[$63>>2] = $64;
 HEAP32[$$0$i$i$i>>2] = $46;
 $65 = HEAP32[$34>>2]|0;
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 if ($67) {
  $69 = $46;
  $68 = HEAP32[$35>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($68,$69);
  $70 = (($33) + 32|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($71) + 1)|0;
  HEAP32[$70>>2] = $72;
  STACKTOP = sp;return;
 }
 HEAP32[$34>>2] = $66;
 $$pre$i$i$i = HEAP32[$$0$i$i$i>>2]|0;
 $69 = $$pre$i$i$i;
 $68 = HEAP32[$35>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($68,$69);
 $70 = (($33) + 32|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + 1)|0;
 HEAP32[$70>>2] = $72;
 STACKTOP = sp;return;
}
function __Z21GetDelayedCallManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(8)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN18DelayedCallManager17CancelCallDelayedE4PPtrI6ObjectEPFvPS1_PvEPFbS4_S4_ES4_($this,$o,$callback,$shouldCancel,$userData) {
 $this = $this|0;
 $o = $o|0;
 $callback = $callback|0;
 $shouldCancel = $shouldCancel|0;
 $userData = $userData|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$us = 0, $$0$i$i$i$us = 0, $$01$i$i$i = 0, $$01$i$i$i$us = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 28|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = ($shouldCancel|0)==(0|0);
 if ($5) {
  $7 = $2;
  while(1) {
   $6 = (($7) + 4|0);
   $8 = HEAP32[$6>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$01$i$i$i$us = $7;
    while(1) {
     $12 = (($$01$i$i$i$us) + 8|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==($$01$i$i$i$us|0);
     if ($15) {
      $$0$i$i$i$us = $13;
      break;
     } else {
      $$01$i$i$i$us = $13;
     }
    }
   } else {
    $$0$i$i$i$i$us = $8;
    while(1) {
     $10 = HEAP32[$$0$i$i$i$i$us>>2]|0;
     $11 = ($10|0)==(0|0);
     if ($11) {
      $$0$i$i$i$us = $$0$i$i$i$i$us;
      break;
     } else {
      $$0$i$i$i$i$us = $10;
     }
    }
   }
   $16 = (($7) + 16|0);
   $17 = (($7) + 48|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$o>>2]|0;
   $20 = ($18|0)==($19|0);
   if ($20) {
    $21 = (($7) + 40|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($callback|0);
    if ($23) {
     HEAP32[$0>>2] = $7;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     __ZN18DelayedCallManager6RemoveERKNS_8CallbackENSt3__121__tree_const_iteratorIS0_PNS3_11__tree_nodeIS0_PvEEiEE($this,$16,$$byval_copy1);
    }
   }
   $24 = ($$0$i$i$i$us|0)==($3|0);
   if ($24) {
    break;
   } else {
    $7 = $$0$i$i$i$us;
   }
  }
  STACKTOP = sp;return;
 } else {
  $26 = $2;
 }
 while(1) {
  $25 = (($26) + 4|0);
  $27 = HEAP32[$25>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   $$01$i$i$i = $26;
   while(1) {
    $31 = (($$01$i$i$i) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==($$01$i$i$i|0);
    if ($34) {
     $$0$i$i$i = $32;
     break;
    } else {
     $$01$i$i$i = $32;
    }
   }
  } else {
   $$0$i$i$i$i = $27;
   while(1) {
    $29 = HEAP32[$$0$i$i$i$i>>2]|0;
    $30 = ($29|0)==(0|0);
    if ($30) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $29;
    }
   }
  }
  $35 = (($26) + 16|0);
  $36 = (($26) + 48|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$o>>2]|0;
  $39 = ($37|0)==($38|0);
  if ($39) {
   $40 = (($26) + 40|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($callback|0);
   if ($42) {
    $44 = (($26) + 36|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (FUNCTION_TABLE_iii[$shouldCancel & 4095]($45,$userData)|0);
    if ($46) {
     HEAP32[$0>>2] = $26;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     __ZN18DelayedCallManager6RemoveERKNS_8CallbackENSt3__121__tree_const_iteratorIS0_PNS3_11__tree_nodeIS0_PvEEiEE($this,$35,$$byval_copy1);
    }
   }
  }
  $43 = ($$0$i$i$i|0)==($3|0);
  if ($43) {
   break;
  } else {
   $26 = $$0$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18DelayedCallManager6RemoveERKNS_8CallbackENSt3__121__tree_const_iteratorIS0_PNS3_11__tree_nodeIS0_PvEEiEE($this,$cb,$i) {
 $this = $this|0;
 $cb = $cb|0;
 $i = $i|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i6 = 0, $$0$i$i$i$i10 = 0, $$0$i$i$i$i2 = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cb) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cb) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$i>>2]|0;
 $7 = ($5|0)==($6|0);
 if ($7) {
  $25 = (($5) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(0|0);
  if ($27) {
   $$01$i$i$i = $5;
   while(1) {
    $30 = (($$01$i$i$i) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==($$01$i$i$i|0);
    if ($33) {
     $$0$i$i$i = $31;
     break;
    } else {
     $$01$i$i$i = $31;
    }
   }
  } else {
   $$0$i$i$i$i2 = $26;
   while(1) {
    $28 = HEAP32[$$0$i$i$i$i2>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     $$0$i$i$i = $$0$i$i$i$i2;
     break;
    } else {
     $$0$i$i$i$i2 = $28;
    }
   }
  }
  HEAP32[$4>>2] = $$0$i$i$i;
  $34 = HEAP32[$25>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$01$i$i$i$i8 = $5;
   while(1) {
    $38 = (($$01$i$i$i$i8) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==($$01$i$i$i$i8|0);
    if ($41) {
     $$0$i$i$i$i10 = $39;
     break;
    } else {
     $$01$i$i$i$i8 = $39;
    }
   }
  } else {
   $$0$i$i$i$i$i6 = $34;
   while(1) {
    $36 = HEAP32[$$0$i$i$i$i$i6>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$0$i$i$i$i10 = $$0$i$i$i$i$i6;
     break;
    } else {
     $$0$i$i$i$i$i6 = $36;
    }
   }
  }
  $42 = (($this) + 24|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==($5|0);
  if ($44) {
   HEAP32[$42>>2] = $$0$i$i$i$i10;
  }
  $45 = (($this) + 32|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + -1)|0;
  HEAP32[$45>>2] = $47;
  $48 = (($this) + 28|0);
  $49 = HEAP32[$48>>2]|0;
  __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($49,$5);
  __ZdlPv($5);
 } else {
  $8 = (($6) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$01$i$i$i$i = $6;
   while(1) {
    $13 = (($$01$i$i$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i$i$i|0);
    if ($16) {
     $$0$i$i$i$i = $14;
     break;
    } else {
     $$01$i$i$i$i = $14;
    }
   }
  } else {
   $$0$i$i$i$i$i = $9;
   while(1) {
    $11 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $11;
    }
   }
  }
  $17 = (($this) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==($6|0);
  if ($19) {
   HEAP32[$17>>2] = $$0$i$i$i$i;
  }
  $20 = (($this) + 32|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + -1)|0;
  HEAP32[$20>>2] = $22;
  $23 = (($this) + 28|0);
  $24 = HEAP32[$23>>2]|0;
  __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$6);
  __ZdlPv($6);
 }
 $50 = ($1|0)==(0|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 FUNCTION_TABLE_vi[$1 & 4095]($3);
 STACKTOP = sp;return;
}
function __ZN18DelayedCallManager18CancelCallDelayed2E4PPtrI6ObjectEPFvPS1_PvES6_($this,$o,$callback,$otherCallback) {
 $this = $this|0;
 $o = $o|0;
 $callback = $callback|0;
 $otherCallback = $otherCallback|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 28|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $6 = $2;
 while(1) {
  $5 = (($6) + 4|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$01$i$i$i = $6;
   while(1) {
    $11 = (($$01$i$i$i) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==($$01$i$i$i|0);
    if ($14) {
     $$0$i$i$i = $12;
     break;
    } else {
     $$01$i$i$i = $12;
    }
   }
  } else {
   $$0$i$i$i$i = $7;
   while(1) {
    $9 = HEAP32[$$0$i$i$i$i>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $9;
    }
   }
  }
  $15 = (($6) + 16|0);
  $16 = (($6) + 48|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$o>>2]|0;
  $19 = ($17|0)==($18|0);
  if ($19) {
   $20 = (($6) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==($callback|0);
   $23 = ($21|0)==($otherCallback|0);
   $or$cond = $22 | $23;
   if ($or$cond) {
    HEAP32[$0>>2] = $6;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    __ZN18DelayedCallManager6RemoveERKNS_8CallbackENSt3__121__tree_const_iteratorIS0_PNS3_11__tree_nodeIS0_PvEEiEE($this,$15,$$byval_copy);
   }
  }
  $24 = ($$0$i$i$i|0)==($3|0);
  if ($24) {
   break;
  } else {
   $6 = $$0$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18DelayedCallManager6UpdateEi($this,$modeMask) {
 $this = $this|0;
 $modeMask = $modeMask|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i2 = 0, $$01$i$i$i = 0, $$byval_copy2 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__nd$0$in$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (__Z14GetTimeManagerv()|0);
 $5 = (($4) + 88|0);
 $6 = +HEAPF64[$5>>3];
 $7 = (__Z14GetTimeManagerv()|0);
 $8 = (($7) + 124|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[$12>>2] = $14;
 $15 = (($this) + 28|0);
 $16 = ($11|0)==($15|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 36|0);
 $18 = (($this) + 28|0);
 $19 = (($this) + 32|0);
 $21 = $11;
 while(1) {
  $20 = (($21) + 16|0);
  $22 = +HEAPF64[$20>>3];
  $23 = !($22 <= $6);
  if ($23) {
   label = 34;
   break;
  }
  HEAP32[$17>>2] = $21;
  $24 = (($21) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   $$01$i$i$i = $21;
   while(1) {
    $29 = (($$01$i$i$i) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==($$01$i$i$i|0);
    if ($32) {
     $$0$i$i$i2 = $30;
     break;
    } else {
     $$01$i$i$i = $30;
    }
   }
  } else {
   $$0$i$i$i$i = $25;
   while(1) {
    $27 = HEAP32[$$0$i$i$i$i>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     $$0$i$i$i2 = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $27;
    }
   }
  }
  HEAP32[$17>>2] = $$0$i$i$i2;
  $33 = (($21) + 52|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $34 & $modeMask;
  $36 = ($35|0)==(0);
  do {
   if (!($36)) {
    $37 = (($21) + 56|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = HEAP32[$12>>2]|0;
    $40 = ($38|0)==($39|0);
    if (!($40)) {
     $41 = (($21) + 24|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)>($9|0);
     if (!($43)) {
      $44 = (($21) + 48|0);
      $45 = HEAP32[$44>>2]|0;
      HEAP32[$0>>2] = $45;
      $46 = HEAP32[560624>>2]|0;
      $47 = ($46|0)==(0|0);
      if (!($47)) {
       $48 = (($46) + 36|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = (($46) + 4|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = ($49|0)==($51|0);
       do {
        if ($52) {
         $53 = (($46) + 28|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = (($46) + 32|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = (($54) + ($56<<3)|0);
         $73 = $57;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$46,$0);
         $58 = HEAP32[$$byval_copy2>>2]|0;
         $59 = ($58|0)==(-1);
         $60 = (($46) + 28|0);
         $61 = HEAP32[$60>>2]|0;
         if ($59) {
          $62 = (($46) + 32|0);
          $63 = HEAP32[$62>>2]|0;
          $64 = (($61) + ($63<<3)|0);
          $73 = $64;
          break;
         } else {
          $65 = (($61) + ($58<<3)|0);
          $73 = $65;
          break;
         }
        }
       } while(0);
       $66 = HEAP32[560624>>2]|0;
       $67 = (($66) + 28|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = (($66) + 32|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = (($68) + ($70<<3)|0);
       $72 = ($73|0)==($71|0);
       if (!($72)) {
        $74 = (($73) + 4|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = ($75|0)==(0|0);
        if (!($76)) {
         $77 = (($21) + 36|0);
         $78 = HEAP32[$77>>2]|0;
         $79 = (($21) + 40|0);
         $80 = HEAP32[$79>>2]|0;
         $81 = (($21) + 32|0);
         $82 = HEAP8[$81>>0]|0;
         $83 = ($82<<24>>24)==(0);
         if ($83) {
          $84 = (($21) + 44|0);
          $85 = HEAP32[$84>>2]|0;
          HEAP32[$1>>2] = $21;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
          __ZN18DelayedCallManager15RemoveNoCleanupERKNS_8CallbackENSt3__121__tree_const_iteratorIS0_PNS3_11__tree_nodeIS0_PvEEiEE($this,0,$$byval_copy2);
          FUNCTION_TABLE_vii[$80 & 4095]($75,$78);
          $86 = ($85|0)==(0|0);
          if ($86) {
           break;
          }
          FUNCTION_TABLE_vi[$85 & 4095]($78);
          break;
         }
         $87 = (($21) + 28|0);
         $88 = Math_fround(HEAPF32[$87>>2]);
         $89 = +$88;
         $90 = +HEAPF64[$20>>3];
         $91 = $90 + $89;
         HEAPF64[$20>>3] = $91;
         $92 = HEAP32[$33>>2]|0;
         $93 = $92 & 8;
         $94 = ($93|0)==(0);
         if (!($94)) {
          $95 = (__Z14GetTimeManagerv()|0);
          $96 = (($95) + 124|0);
          $97 = HEAP32[$96>>2]|0;
          $98 = (($97) + 1)|0;
          HEAP32[$41>>2] = $98;
         }
         $99 = HEAP32[$18>>2]|0;
         $100 = ($99|0)==(0|0);
         if ($100) {
          $$0$i$i$i = $15;$127 = $15;
         } else {
          $101 = +HEAPF64[$20>>3];
          $__nd$0$in$i$i$i = $99;
          while(1) {
           $102 = (($__nd$0$in$i$i$i) + 16|0);
           $103 = +HEAPF64[$102>>3];
           $104 = $101 < $103;
           if ($104) {
            $105 = HEAP32[$__nd$0$in$i$i$i>>2]|0;
            $106 = ($105|0)==(0|0);
            if ($106) {
             $$0$i$i$i = $__nd$0$in$i$i$i;$127 = $__nd$0$in$i$i$i;
             break;
            } else {
             $__nd$0$in$i$i$i = $105;
             continue;
            }
           } else {
            $107 = (($__nd$0$in$i$i$i) + 4|0);
            $108 = HEAP32[$107>>2]|0;
            $109 = ($108|0)==(0|0);
            if ($109) {
             $$0$i$i$i = $107;$127 = $__nd$0$in$i$i$i;
             break;
            } else {
             $__nd$0$in$i$i$i = $108;
             continue;
            }
           }
          }
         }
         $110 = (__Znwj(64)|0);
         $111 = (($110) + 16|0);
         ;HEAP32[$111+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$111+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$111+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$111+12>>2]=HEAP32[$20+12>>2]|0;HEAP32[$111+16>>2]=HEAP32[$20+16>>2]|0;HEAP32[$111+20>>2]=HEAP32[$20+20>>2]|0;HEAP32[$111+24>>2]=HEAP32[$20+24>>2]|0;HEAP32[$111+28>>2]=HEAP32[$20+28>>2]|0;
         $112 = HEAP32[$44>>2]|0;
         $113 = (($110) + 48|0);
         HEAP32[$113>>2] = $112;
         $114 = (($110) + 52|0);
         $115 = $33;
         $116 = $115;
         $117 = HEAP32[$116>>2]|0;
         $118 = (($115) + 4)|0;
         $119 = $118;
         $120 = HEAP32[$119>>2]|0;
         $121 = $114;
         $122 = $121;
         HEAP32[$122>>2] = $117;
         $123 = (($121) + 4)|0;
         $124 = $123;
         HEAP32[$124>>2] = $120;
         HEAP32[$110>>2] = 0;
         $125 = (($110) + 4|0);
         HEAP32[$125>>2] = 0;
         $126 = (($110) + 8|0);
         HEAP32[$126>>2] = $127;
         HEAP32[$$0$i$i$i>>2] = $110;
         $128 = HEAP32[$10>>2]|0;
         $129 = HEAP32[$128>>2]|0;
         $130 = ($129|0)==(0|0);
         if ($130) {
          $132 = $110;
         } else {
          HEAP32[$10>>2] = $129;
          $$pre$i$i$i = HEAP32[$$0$i$i$i>>2]|0;
          $132 = $$pre$i$i$i;
         }
         $131 = HEAP32[$18>>2]|0;
         __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($131,$132);
         $133 = HEAP32[$19>>2]|0;
         $134 = (($133) + 1)|0;
         HEAP32[$19>>2] = $134;
         HEAP32[$2>>2] = $21;
         ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
         __ZN18DelayedCallManager15RemoveNoCleanupERKNS_8CallbackENSt3__121__tree_const_iteratorIS0_PNS3_11__tree_nodeIS0_PvEEiEE($this,0,$$byval_copy2);
         FUNCTION_TABLE_vii[$80 & 4095]($75,$78);
         break;
        }
       }
      }
      HEAP32[$3>>2] = $21;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
      __ZN18DelayedCallManager6RemoveERKNS_8CallbackENSt3__121__tree_const_iteratorIS0_PNS3_11__tree_nodeIS0_PvEEiEE($this,$20,$$byval_copy2);
     }
    }
   }
  } while(0);
  $135 = HEAP32[$17>>2]|0;
  $136 = ($135|0)==($15|0);
  if ($136) {
   label = 34;
   break;
  } else {
   $21 = $135;
  }
 }
 if ((label|0) == 34) {
  STACKTOP = sp;return;
 }
}
function __ZN18DelayedCallManager15RemoveNoCleanupERKNS_8CallbackENSt3__121__tree_const_iteratorIS0_PNS3_11__tree_nodeIS0_PvEEiEE($this,$cb,$i) {
 $this = $this|0;
 $cb = $cb|0;
 $i = $i|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i5 = 0, $$0$i$i$i$i12 = 0, $$0$i$i$i$i9 = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$i>>2]|0;
 $3 = ($1|0)==($2|0);
 if (!($3)) {
  $4 = (($2) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $$01$i$i$i$i7 = $2;
   while(1) {
    $9 = (($$01$i$i$i$i7) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==($$01$i$i$i$i7|0);
    if ($12) {
     $$0$i$i$i$i9 = $10;
     break;
    } else {
     $$01$i$i$i$i7 = $10;
    }
   }
  } else {
   $$0$i$i$i$i$i5 = $5;
   while(1) {
    $7 = HEAP32[$$0$i$i$i$i$i5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $$0$i$i$i$i9 = $$0$i$i$i$i$i5;
     break;
    } else {
     $$0$i$i$i$i$i5 = $7;
    }
   }
  }
  $13 = (($this) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==($2|0);
  if ($15) {
   HEAP32[$13>>2] = $$0$i$i$i$i9;
  }
  $16 = (($this) + 32|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + -1)|0;
  HEAP32[$16>>2] = $18;
  $19 = (($this) + 28|0);
  $20 = HEAP32[$19>>2]|0;
  __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($20,$2);
  __ZdlPv($2);
  STACKTOP = sp;return;
 }
 $21 = (($1) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $$01$i$i$i = $1;
  while(1) {
   $26 = (($$01$i$i$i) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==($$01$i$i$i|0);
   if ($29) {
    $$0$i$i$i = $27;
    break;
   } else {
    $$01$i$i$i = $27;
   }
  }
 } else {
  $$0$i$i$i$i12 = $22;
  while(1) {
   $24 = HEAP32[$$0$i$i$i$i12>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    $$0$i$i$i = $$0$i$i$i$i12;
    break;
   } else {
    $$0$i$i$i$i12 = $24;
   }
  }
 }
 HEAP32[$0>>2] = $$0$i$i$i;
 $30 = HEAP32[$21>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $$01$i$i$i$i = $1;
  while(1) {
   $34 = (($$01$i$i$i$i) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==($$01$i$i$i$i|0);
   if ($37) {
    $$0$i$i$i$i = $35;
    break;
   } else {
    $$01$i$i$i$i = $35;
   }
  }
 } else {
  $$0$i$i$i$i$i = $30;
  while(1) {
   $32 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    $$0$i$i$i$i = $$0$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i = $32;
   }
  }
 }
 $38 = (($this) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==($1|0);
 if ($40) {
  HEAP32[$38>>2] = $$0$i$i$i$i;
 }
 $41 = (($this) + 32|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + -1)|0;
 HEAP32[$41>>2] = $43;
 $44 = (($this) + 28|0);
 $45 = HEAP32[$44>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($45,$1);
 __ZdlPv($1);
 STACKTOP = sp;return;
}
function __Z32RegisterClass_DelayedCallManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(98,122,0,0,0);
 STACKTOP = sp;return;
}
function __ZN18DelayedCallManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 18;
 dest=$3+0|0; src=590344+0|0; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 18|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,98,6,($0|0),44,(2390|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN18DelayedCallManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(44,$$byval_copy2,1,16,590368,24)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1678,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((590232 + 8|0));
  $6 = (($3) + 28|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 32|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 24|0);
  HEAP32[$8>>2] = $6;
  $9 = (($3) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 36|0);
  HEAP32[$10>>2] = $6;
  STACKTOP = sp;return ($3|0);
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(590368|0),24);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK18DelayedCallManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 98;
}
function __ZN18DelayedCallManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18DelayedCallManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN18DelayedCallManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3464,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIN18DelayedCallManager8CallbackENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeIN18DelayedCallManager8CallbackENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeIN18DelayedCallManager8CallbackENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN18DelayedCallManagerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((590232 + 8|0));
 $0 = (($this) + 24|0);
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeIN18DelayedCallManager8CallbackENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($0,$2);
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   STACKTOP = sp;return;
  }
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __THREW__ = 0;
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   ___resumeException($7|0);
   // unreachable;
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $19 = ___cxa_find_matching_catch(0|0)|0;
  $20 = tempRet0;
  __THREW__ = 0;
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $23 = ___cxa_find_matching_catch(0|0)|0;
   $24 = tempRet0;
   ___clang_call_terminate($23);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $19;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  ___resumeException($13|0);
  // unreachable;
 }
 $25 = ___cxa_find_matching_catch(0|0)|0;
 $26 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $25;
 ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
 // unreachable;
}
function __Z29CollectAndProduceSingleObjectR6ObjectR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS2_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($singleObject,$remappedPtrs) {
 $singleObject = $singleObject|0;
 $remappedPtrs = $remappedPtrs|0;
 var $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($singleObject) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 21;
 $5 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__ZN6Object7ProduceEii10MemLabelId18ObjectCreationMode($4,0,$$byval_copy,2)|0);
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($6) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 >>> 21;
  $11 = HEAP32[560640>>2]|0;
  $12 = Math_imul($11, $10)|0;
  $13 = (($12) + 114)|0;
  $14 = $13 >> 5;
  $15 = $14 << 5;
  $16 = (($13) - ($15))|0;
  $17 = HEAP32[560632>>2]|0;
  $18 = (($17) + ($14<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = 1 << $16;
  $21 = $20 & $19;
  $22 = ($21|0)==(0);
  if (!($22)) {
   __ZN13MonoBehaviour20SetScriptingDataFromERKS_($6,$singleObject);
  }
 }
 $23 = (($singleObject) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($6) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$1>>2] = $24;
 $27 = (($1) + 4|0);
 HEAP32[$27>>2] = $26;
 $28 = (($remappedPtrs) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($remappedPtrs) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($29|0)==($31|0);
 if ($32) {
  $46 = (($remappedPtrs) + 4|0);
  __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($46,$1);
  STACKTOP = sp;return;
 }
 $33 = ($29|0)==(0|0);
 if ($33) {
  $45 = 0;
 } else {
  $34 = $1;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 4)|0;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = $29;
  $41 = $40;
  HEAP32[$41>>2] = $36;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = $39;
  $$pre$i = HEAP32[$28>>2]|0;
  $45 = $$pre$i;
 }
 $44 = (($45) + 8|0);
 HEAP32[$28>>2] = $44;
 STACKTOP = sp;return;
}
function __Z36CollectAndProduceGameObjectHierarchyRN5Unity10GameObjectEP9TransformR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS5_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($go,$transform,$remappedPtrs) {
 $go = $go|0;
 $transform = $transform|0;
 $remappedPtrs = $remappedPtrs|0;
 var $$0 = 0, $$byval_copy5 = 0, $$c5 = 0, $$c7 = 0, $$pre$i = 0, $$pre$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$010 = 0, $i1$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 16|0;
 $2 = sp;
 $3 = sp + 8|0;
 $4 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $4;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 $5 = (__ZN6Object7ProduceEii10MemLabelId18ObjectCreationMode(1,0,$$byval_copy5,2)|0);
 $6 = (($remappedPtrs) + 4|0);
 $7 = (($go) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$2>>2] = $8;
 $11 = (($2) + 4|0);
 HEAP32[$11>>2] = $10;
 $12 = (($remappedPtrs) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($remappedPtrs) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==($15|0);
 if ($16) {
  __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($6,$2);
 } else {
  $17 = ($13|0)==(0|0);
  if ($17) {
   $29 = 0;
  } else {
   $18 = $2;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $13;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   $$pre$i = HEAP32[$12>>2]|0;
   $29 = $$pre$i;
  }
  $28 = (($29) + 8|0);
  HEAP32[$12>>2] = $28;
 }
 __ZN5Unity10GameObject14CopyPropertiesERS0_($go,$5);
 $30 = (($5) + 24|0);
 $31 = (($go) + 32|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($5) + 32|0);
 HEAP32[$33>>2] = $32;
 $34 = (($5) + 36|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35 & 2147483647;
 $37 = ($36>>>0)<($32>>>0);
 do {
  if ($37) {
   $38 = ($35|0)>(-1);
   if ($38) {
    $$c7 = $32;
    HEAP32[$34>>2] = $$c7;
    $39 = HEAP32[$30>>2]|0;
    $40 = $32 << 3;
    $41 = (($5) + 28|0);
    $42 = HEAP32[$41>>2]|0;
    HEAP32[$0>>2] = $42;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $43 = (__Z16realloc_internalPvji10MemLabelIdiPKci($39,$40,4,$$byval_copy5,0,590384,370)|0);
    HEAP32[$30>>2] = $43;
    break;
   } else {
    $44 = $32 << 3;
    $45 = (($5) + 28|0);
    $46 = HEAP32[$45>>2]|0;
    HEAP32[$0>>2] = $46;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $47 = (__Z15malloc_internaljj10MemLabelIdiPKci($44,4,$$byval_copy5,0,590384,352)|0);
    $48 = HEAP32[$30>>2]|0;
    $49 = HEAP32[$33>>2]|0;
    $50 = $49 << 3;
    _memcpy(($47|0),($48|0),($50|0))|0;
    $$c5 = $32;
    HEAP32[$34>>2] = $$c5;
    HEAP32[$30>>2] = $47;
    break;
   }
  }
 } while(0);
 $51 = HEAP32[$31>>2]|0;
 $52 = ($51|0)==(0);
 if (!($52)) {
  $53 = (($go) + 24|0);
  $54 = (($3) + 4|0);
  $i$010 = 0;
  while(1) {
   $55 = HEAP32[$53>>2]|0;
   $56 = ((($55) + ($i$010<<3)|0) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 8|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 >>> 21;
   $61 = HEAP32[628384>>2]|0;
   HEAP32[$0>>2] = $61;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   $62 = (__ZN6Object7ProduceEii10MemLabelId18ObjectCreationMode($60,0,$$byval_copy5,2)|0);
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = (($62) + 8|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = $65 >>> 21;
    $67 = HEAP32[560640>>2]|0;
    $68 = Math_imul($67, $66)|0;
    $69 = (($68) + 114)|0;
    $70 = $69 >> 5;
    $71 = $70 << 5;
    $72 = (($69) - ($71))|0;
    $73 = HEAP32[560632>>2]|0;
    $74 = (($73) + ($70<<2)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = 1 << $72;
    $77 = $76 & $75;
    $78 = ($77|0)==(0);
    if (!($78)) {
     __ZN13MonoBehaviour20SetScriptingDataFromERKS_($62,$57);
    }
   }
   $79 = HEAP32[$53>>2]|0;
   $80 = (($79) + ($i$010<<3)|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = HEAP32[$30>>2]|0;
   $83 = (($82) + ($i$010<<3)|0);
   HEAP32[$83>>2] = $81;
   $84 = ((($82) + ($i$010<<3)|0) + 4|0);
   HEAP32[$84>>2] = $62;
   $85 = (($62) + 24|0);
   HEAP32[$85>>2] = $5;
   $86 = (($57) + 4|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($62) + 4|0);
   $89 = HEAP32[$88>>2]|0;
   HEAP32[$3>>2] = $87;
   HEAP32[$54>>2] = $89;
   $90 = HEAP32[$12>>2]|0;
   $91 = HEAP32[$14>>2]|0;
   $92 = ($90|0)==($91|0);
   if ($92) {
    __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($6,$3);
   } else {
    $93 = ($90|0)==(0|0);
    if ($93) {
     $105 = 0;
    } else {
     $94 = $3;
     $95 = $94;
     $96 = HEAP32[$95>>2]|0;
     $97 = (($94) + 4)|0;
     $98 = $97;
     $99 = HEAP32[$98>>2]|0;
     $100 = $90;
     $101 = $100;
     HEAP32[$101>>2] = $96;
     $102 = (($100) + 4)|0;
     $103 = $102;
     HEAP32[$103>>2] = $99;
     $$pre$i1 = HEAP32[$12>>2]|0;
     $105 = $$pre$i1;
    }
    $104 = (($105) + 8|0);
    HEAP32[$12>>2] = $104;
   }
   $106 = (($i$010) + 1)|0;
   $107 = HEAP32[$31>>2]|0;
   $108 = ($106>>>0)<($107>>>0);
   if ($108) {
    $i$010 = $106;
   } else {
    break;
   }
  }
 }
 $109 = ($transform|0)==(0|0);
 if ($109) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $110 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($5)|0);
 $111 = (($110) + 140|0);
 __ZN9Transform21CopyTRSNoNotificationERKS_($110,$transform);
 $112 = (($transform) + 148|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($110) + 148|0);
 HEAP32[$114>>2] = $113;
 $115 = (($110) + 152|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = $116 & 2147483647;
 $118 = ($117>>>0)<($113>>>0);
 do {
  if ($118) {
   $119 = ($116|0)>(-1);
   if ($119) {
    HEAP32[$115>>2] = $113;
    $120 = HEAP32[$111>>2]|0;
    $121 = $113 << 2;
    $122 = (($110) + 144|0);
    $123 = HEAP32[$122>>2]|0;
    HEAP32[$0>>2] = $123;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $124 = (__Z16realloc_internalPvji10MemLabelIdiPKci($120,$121,4,$$byval_copy5,0,590384,370)|0);
    HEAP32[$111>>2] = $124;
    break;
   } else {
    $125 = $113 << 2;
    $126 = (($110) + 144|0);
    $127 = HEAP32[$126>>2]|0;
    HEAP32[$0>>2] = $127;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $128 = (__Z15malloc_internaljj10MemLabelIdiPKci($125,4,$$byval_copy5,0,590384,352)|0);
    $129 = HEAP32[$111>>2]|0;
    $130 = HEAP32[$114>>2]|0;
    $131 = $130 << 2;
    _memcpy(($128|0),($129|0),($131|0))|0;
    HEAP32[$115>>2] = $113;
    HEAP32[$111>>2] = $128;
    break;
   }
  }
 } while(0);
 $132 = HEAP32[$112>>2]|0;
 $133 = ($132|0)==(0);
 if ($133) {
  $$0 = $110;
  STACKTOP = sp;return ($$0|0);
 }
 $134 = (($transform) + 140|0);
 $i1$09 = 0;
 while(1) {
  $135 = HEAP32[$134>>2]|0;
  $136 = (($135) + ($i1$09<<2)|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = (($137) + 24|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = (__Z36CollectAndProduceGameObjectHierarchyRN5Unity10GameObjectEP9TransformR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS5_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($139,$137,$remappedPtrs)|0);
  $141 = (($140) + 156|0);
  HEAP32[$141>>2] = $110;
  $142 = HEAP32[$111>>2]|0;
  $143 = (($142) + ($i1$09<<2)|0);
  HEAP32[$143>>2] = $140;
  $144 = (($i1$09) + 1)|0;
  $145 = HEAP32[$112>>2]|0;
  $146 = ($144>>>0)<($145>>>0);
  if ($146) {
   $i1$09 = $144;
  } else {
   $$0 = $110;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z29CollectAndProduceClonedIslandR6ObjectR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS2_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($o,$remappedPtrs) {
 $o = $o|0;
 $remappedPtrs = $remappedPtrs|0;
 var $$$$i = 0, $$$i = 0, $$byval_copy1 = 0, $$pre$i$i$i = 0, $$pre1$i$i$i = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp;
 $0 = sp + 4|0;
 $1 = (($remappedPtrs) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($remappedPtrs) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<(64);
 if ($9) {
  $10 = (($remappedPtrs) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($6))|0;
  $14 = $13 >> 3;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $15 = (__Z15malloc_internaljj10MemLabelIdiPKci(512,16,$$byval_copy1,0,590384,79)|0);
  $$pre$i$i$i = HEAP32[$3>>2]|0;
  $$pre1$i$i$i = HEAP32[$10>>2]|0;
  $16 = (($15) + ($14<<3)|0);
  $17 = (($15) + 512|0);
  $18 = $$pre1$i$i$i;
  $19 = $$pre$i$i$i;
  $20 = (($18) - ($19))|0;
  $21 = $20 >> 3;
  $$sum$i$i$i = (($14) - ($21))|0;
  $22 = (($15) + ($$sum$i$i$i<<3)|0);
  _memcpy(($22|0),($$pre$i$i$i|0),($20|0))|0;
  $23 = HEAP32[$3>>2]|0;
  HEAP32[$3>>2] = $22;
  HEAP32[$10>>2] = $16;
  HEAP32[$1>>2] = $17;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($23|0),($$byval_copy1|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch()|0;
    $28 = tempRet0;
    ___cxa_call_unexpected(($27|0));
    // unreachable;
   }
  }
 }
 $29 = ($o|0)==(0|0);
 if ($29) {
 } else {
  $30 = (($o) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $31 >>> 21;
  $33 = HEAP32[560640>>2]|0;
  $34 = Math_imul($33, $32)|0;
  $35 = (($34) + 1)|0;
  $36 = $35 >> 5;
  $37 = $36 << 5;
  $38 = (($35) - ($37))|0;
  $39 = HEAP32[560632>>2]|0;
  $40 = (($39) + ($36<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = 1 << $38;
  $43 = $42 & $41;
  $44 = ($43|0)==(0);
  $$$i = $44 ? 0 : $o;
  $45 = (($34) + 2)|0;
  $46 = $45 >> 5;
  $47 = $46 << 5;
  $48 = (($45) - ($47))|0;
  $49 = (($39) + ($46<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = 1 << $48;
  $52 = $51 & $50;
  $53 = ($52|0)==(0);
  if ($53) {
   $58 = $$$i;
  } else {
   $54 = (($o) + 24|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0|0);
   $$$$i = $56 ? $$$i : $55;
   $58 = $$$$i;
  }
  $57 = ($58|0)==(0|0);
  if (!($57)) {
   $59 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($58)|0);
   (__Z36CollectAndProduceGameObjectHierarchyRN5Unity10GameObjectEP9TransformR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS5_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($58,$59,$remappedPtrs)|0);
   $60 = HEAP32[$3>>2]|0;
   $61 = (($remappedPtrs) + 8|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = HEAP8[$remappedPtrs>>0]|0;
   HEAP8[$$byval_copy1>>0] = $63;
   __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEvT0_SD_T_($60,$62,$$byval_copy1);
   STACKTOP = sp;return;
  }
 }
 __Z29CollectAndProduceSingleObjectR6ObjectR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS2_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($o,$remappedPtrs);
 $60 = HEAP32[$3>>2]|0;
 $61 = (($remappedPtrs) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP8[$remappedPtrs>>0]|0;
 HEAP8[$$byval_copy1>>0] = $63;
 __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEvT0_SD_T_($60,$62,$$byval_copy1);
 STACKTOP = sp;return;
}
function __Z29AwakeAndActivateClonedObjectsRK10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS0_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($ptrs) {
 $ptrs = $ptrs|0;
 var $$byval_copy9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $queue = 0, $temp$0$i = 0, $temp$0$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy9 = sp + 152|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $queue = sp + 16|0;
 $4 = sp + 144|0;
 $5 = HEAP32[628512>>2]|0;
 HEAP32[$4>>2] = $5;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
 __ZN18AwakeFromLoadQueueC2E10MemLabelId($queue,$$byval_copy9);
 $6 = (($ptrs) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($ptrs) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 3;
 __THREW__ = 0;
 invoke_vii(2694,($queue|0),($13|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 L1: do {
  if ($15) {
   label = 26;
  } else {
   $16 = HEAP32[$8>>2]|0;
   $17 = HEAP32[$6>>2]|0;
   $18 = ($16|0)==($17|0);
   L3: do {
    if (!($18)) {
     $20 = $16;
     while(1) {
      $19 = (($20) + 4|0);
      $21 = HEAP32[$19>>2]|0;
      HEAP32[$1>>2] = $21;
      $22 = HEAP32[560624>>2]|0;
      $23 = ($22|0)==(0|0);
      if ($23) {
       label = 12;
      } else {
       $24 = (($22) + 36|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (($22) + 4|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($25|0)==($27|0);
       do {
        if ($28) {
         $29 = (($22) + 28|0);
         $30 = HEAP32[$29>>2]|0;
         $31 = (($22) + 32|0);
         $32 = HEAP32[$31>>2]|0;
         $33 = (($30) + ($32<<3)|0);
         $49 = $33;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy9,$22,$1);
         $34 = HEAP32[$$byval_copy9>>2]|0;
         $35 = ($34|0)==(-1);
         $36 = (($22) + 28|0);
         $37 = HEAP32[$36>>2]|0;
         if ($35) {
          $38 = (($22) + 32|0);
          $39 = HEAP32[$38>>2]|0;
          $40 = (($37) + ($39<<3)|0);
          $49 = $40;
          break;
         } else {
          $41 = (($37) + ($34<<3)|0);
          $49 = $41;
          break;
         }
        }
       } while(0);
       $42 = HEAP32[560624>>2]|0;
       $43 = (($42) + 28|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = (($42) + 32|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = (($44) + ($46<<3)|0);
       $48 = ($49|0)==($47|0);
       if ($48) {
        label = 12;
       } else {
        $50 = (($49) + 4|0);
        $51 = HEAP32[$50>>2]|0;
        $52 = ($51|0)==(0|0);
        if ($52) {
         label = 12;
        } else {
         $temp$0$i = $51;
        }
       }
      }
      if ((label|0) == 12) {
       label = 0;
       __THREW__ = 0;
       $53 = (invoke_ii(3215,($21|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       } else {
        $temp$0$i = $53;
       }
      }
      $56 = HEAP32[$temp$0$i>>2]|0;
      $57 = (($56) + 44|0);
      $58 = HEAP32[$57>>2]|0;
      __THREW__ = 0;
      invoke_vii($58|0,($temp$0$i|0),0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
      $61 = HEAP32[$19>>2]|0;
      HEAP32[$0>>2] = $61;
      $62 = HEAP32[560624>>2]|0;
      $63 = ($62|0)==(0|0);
      if ($63) {
       label = 22;
      } else {
       $64 = (($62) + 36|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = (($62) + 4|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = ($65|0)==($67|0);
       do {
        if ($68) {
         $69 = (($62) + 28|0);
         $70 = HEAP32[$69>>2]|0;
         $71 = (($62) + 32|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = (($70) + ($72<<3)|0);
         $89 = $73;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy9,$62,$0);
         $74 = HEAP32[$$byval_copy9>>2]|0;
         $75 = ($74|0)==(-1);
         $76 = (($62) + 28|0);
         $77 = HEAP32[$76>>2]|0;
         if ($75) {
          $78 = (($62) + 32|0);
          $79 = HEAP32[$78>>2]|0;
          $80 = (($77) + ($79<<3)|0);
          $89 = $80;
          break;
         } else {
          $81 = (($77) + ($74<<3)|0);
          $89 = $81;
          break;
         }
        }
       } while(0);
       $82 = HEAP32[560624>>2]|0;
       $83 = (($82) + 28|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = (($82) + 32|0);
       $86 = HEAP32[$85>>2]|0;
       $87 = (($84) + ($86<<3)|0);
       $88 = ($89|0)==($87|0);
       if ($88) {
        label = 22;
       } else {
        $90 = (($89) + 4|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = ($91|0)==(0|0);
        if ($92) {
         label = 22;
        } else {
         $temp$0$i12 = $91;
        }
       }
      }
      if ((label|0) == 22) {
       label = 0;
       __THREW__ = 0;
       $93 = (invoke_ii(3215,($61|0))|0);
       $94 = __THREW__; __THREW__ = 0;
       $95 = $94&1;
       if ($95) {
        break;
       } else {
        $temp$0$i12 = $93;
       }
      }
      __THREW__ = 0;
      invoke_viiiii(96,($queue|0),($temp$0$i12|0),(0|0),0,-1);
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       break;
      }
      $98 = (($20) + 8|0);
      $99 = HEAP32[$6>>2]|0;
      $100 = ($98|0)==($99|0);
      if ($100) {
       break L3;
      } else {
       $20 = $98;
      }
     }
     $101 = ___cxa_find_matching_catch()|0;
     $102 = tempRet0;
     $lpad$phi$index = $101;$lpad$phi$index2 = $102;
     break L1;
    }
   } while(0);
   __THREW__ = 0;
   invoke_viii(1626,($queue|0),4,0);
   $133 = __THREW__; __THREW__ = 0;
   $134 = $133&1;
   if ($134) {
    label = 26;
   } else {
    $135 = (($queue) + 128|0);
    $137 = $135;
    while(1) {
     $136 = (($137) + -16|0);
     $138 = (($137) + -4|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = ($139|0)>(-1);
     if ($140) {
      $141 = HEAP32[$136>>2]|0;
      $142 = (($137) + -12|0);
      $143 = HEAP32[$142>>2]|0;
      HEAP32[$3>>2] = $143;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($141|0),($$byval_copy9|0));
      $144 = __THREW__; __THREW__ = 0;
      $145 = $144&1;
      if ($145) {
       break;
      }
      HEAP32[$136>>2] = 0;
     }
     $146 = ($136|0)==($queue|0);
     if ($146) {
      label = 53;
      break;
     } else {
      $137 = $136;
     }
    }
    if ((label|0) == 53) {
     STACKTOP = sp;return;
    }
    $147 = ___cxa_find_matching_catch()|0;
    $148 = tempRet0;
    $149 = ($queue|0)==($136|0);
    if ($149) {
     ___resumeException($147|0);
     // unreachable;
    }
    $151 = $136;
    while(1) {
     $150 = (($151) + -16|0);
     $152 = (($151) + -4|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = ($153|0)>(-1);
     if ($154) {
      $155 = HEAP32[$150>>2]|0;
      $156 = (($151) + -12|0);
      $157 = HEAP32[$156>>2]|0;
      HEAP32[$2>>2] = $157;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($155|0),($$byval_copy9|0));
      $158 = __THREW__; __THREW__ = 0;
      $159 = $158&1;
      if ($159) {
       label = 52;
       break;
      }
      HEAP32[$150>>2] = 0;
     }
     $160 = ($150|0)==($queue|0);
     if ($160) {
      label = 51;
      break;
     } else {
      $151 = $150;
     }
    }
    if ((label|0) == 51) {
     ___resumeException($147|0);
     // unreachable;
    }
    else if ((label|0) == 52) {
     $161 = ___cxa_find_matching_catch(0|0)|0;
     $162 = tempRet0;
     ___clang_call_terminate($161);
     // unreachable;
    }
   }
  }
 } while(0);
 if ((label|0) == 26) {
  $103 = ___cxa_find_matching_catch()|0;
  $104 = tempRet0;
  $lpad$phi$index = $103;$lpad$phi$index2 = $104;
 }
 $105 = (($queue) + 128|0);
 $107 = $105;
 while(1) {
  $106 = (($107) + -16|0);
  $108 = (($107) + -4|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)>(-1);
  if ($110) {
   $111 = HEAP32[$106>>2]|0;
   $112 = (($107) + -12|0);
   $113 = HEAP32[$112>>2]|0;
   HEAP32[$3>>2] = $113;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($111|0),($$byval_copy9|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if ($115) {
    break;
   }
   HEAP32[$106>>2] = 0;
  }
  $116 = ($106|0)==($queue|0);
  if ($116) {
   label = 54;
   break;
  } else {
   $107 = $106;
  }
 }
 if ((label|0) == 54) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $117 = ___cxa_find_matching_catch(0|0)|0;
 $118 = tempRet0;
 $119 = ($queue|0)==($106|0);
 if ($119) {
  ___clang_call_terminate($117);
  // unreachable;
 }
 $121 = $106;
 while(1) {
  $120 = (($121) + -16|0);
  $122 = (($121) + -4|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)>(-1);
  if ($124) {
   $125 = HEAP32[$120>>2]|0;
   $126 = (($121) + -12|0);
   $127 = HEAP32[$126>>2]|0;
   HEAP32[$2>>2] = $127;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($125|0),($$byval_copy9|0));
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    label = 38;
    break;
   }
   HEAP32[$120>>2] = 0;
  }
  $130 = ($120|0)==($queue|0);
  if ($130) {
   label = 55;
   break;
  } else {
   $121 = $120;
  }
 }
 if ((label|0) == 38) {
  $131 = ___cxa_find_matching_catch(0|0)|0;
  $132 = tempRet0;
  ___clang_call_terminate($131);
  // unreachable;
 }
 else if ((label|0) == 55) {
  ___clang_call_terminate($117);
  // unreachable;
 }
}
function __Z11CloneObjectR6Object($inObject) {
 $inObject = $inObject|0;
 var $$0 = 0, $$01 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i3 = 0, $ptrs = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i7 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 36|0;
 $0 = sp;
 $ptrs = sp + 8|0;
 $1 = sp + 24|0;
 $2 = (($ptrs) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($ptrs) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($ptrs) + 12|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 $5 = (invoke_iii(2391,($inObject|0),($ptrs|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 11;
  } else {
   $8 = ($5|0)==(0|0);
   do {
    if (!($8)) {
     $9 = HEAP32[$5>>2]|0;
     $10 = (($9) + 36|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($9) + 32|0);
     $13 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     $14 = (invoke_ii($13|0,($5|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 11;
      break L1;
     }
     __THREW__ = 0;
     invoke_viii(1727,($1|0),($14|0),(590376|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 11;
      break L1;
     }
     $19 = HEAP8[$1>>0]|0;
     $20 = $19 & 1;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      $24 = (($1) + 1|0);
      $25 = $24;
     } else {
      $22 = (($1) + 8|0);
      $23 = HEAP32[$22>>2]|0;
      $25 = $23;
     }
     __THREW__ = 0;
     invoke_vii($11|0,($5|0),($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      $35 = ___cxa_find_matching_catch()|0;
      $36 = tempRet0;
      $37 = HEAP8[$1>>0]|0;
      $38 = $37 & 1;
      $39 = ($38<<24>>24)==(0);
      if ($39) {
       $$0 = $35;$$01 = $36;
       break L1;
      }
      $40 = (($1) + 8|0);
      $41 = HEAP32[$40>>2]|0;
      __ZdlPv($41);
      $$0 = $35;$$01 = $36;
      break L1;
     } else {
      $28 = HEAP8[$1>>0]|0;
      $29 = $28 & 1;
      $30 = ($29<<24>>24)==(0);
      if ($30) {
       break;
      }
      $31 = (($1) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      __ZdlPv($32);
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3465,($ptrs|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    label = 11;
   } else {
    $44 = HEAP32[$2>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     STACKTOP = sp;return ($5|0);
    }
    $46 = HEAP32[$3>>2]|0;
    $47 = ($46|0)==($44|0);
    if (!($47)) {
     $__new_last2$i$i$i$i$i$i$i$i$i3 = $44;
     $scevgep$i$i$i$i$i$i$i$i$i4 = (($46) + -8|0);
     $48 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i3))|0;
     $uglygep$i$i$i$i$i$i$i$i$i6 = (($scevgep$i$i$i$i$i$i$i$i$i4) + ($48)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i7 = $uglygep$i$i$i$i$i$i$i$i$i6;
     $49 = $uglygep3$i$i$i$i$i$i$i$i$i7 >>> 3;
     $50 = $49 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i8 = (($46) + ($50<<3)|0);
     HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i$i$i$i8;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($44|0),($$byval_copy1|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     $53 = ___cxa_find_matching_catch()|0;
     $54 = tempRet0;
     ___cxa_call_unexpected(($53|0));
     // unreachable;
    } else {
     STACKTOP = sp;return ($5|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $$0 = $33;$$01 = $34;
 }
 $55 = HEAP32[$2>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $57 = HEAP32[$3>>2]|0;
 $58 = ($57|0)==($55|0);
 if (!($58)) {
  $__new_last2$i$i$i$i$i$i$i$i$i = $55;
  $scevgep$i$i$i$i$i$i$i$i$i = (($57) + -8|0);
  $59 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($59)|0);
  $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
  $60 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
  $61 = $60 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i$i = (($57) + ($61<<3)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($55|0),($$byval_copy1|0));
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 if ($63) {
  $64 = ___cxa_find_matching_catch()|0;
  $65 = tempRet0;
  ___cxa_call_unexpected(($64|0));
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
 return 0|0;
}
function __ZL15CloneObjectImplP6ObjectR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS2_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($object,$ptrs) {
 $object = $object|0;
 $ptrs = $ptrs|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$54 = 0, $$byval_copy9 = 0, $$lcssa45 = 0, $$neg2$i$i$i$i$i = 0, $$pre = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i9 = 0, $cacheReader = 0, $cacheWriter = 0, $functor = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $readStream = 0, $remapTransfer = 0, $scevgep$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i10 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i14 = 0, $temp$0$i = 0, $temp$0$i22 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i12 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i13 = 0, $writeStream = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $$byval_copy9 = sp + 224|0;
 $0 = sp + 220|0;
 $1 = sp + 216|0;
 $2 = sp + 212|0;
 $3 = sp + 208|0;
 $cacheWriter = sp + 176|0;
 $functor = sp + 168|0;
 $remapTransfer = sp + 64|0;
 $writeStream = sp + 24|0;
 $4 = sp + 16|0;
 $cacheReader = sp;
 $readStream = sp + 104|0;
 __Z29CollectAndProduceClonedIslandR6ObjectR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS2_4pairIiiEEL18MemLabelIdentifier90ELi16EEE($object,$ptrs);
 $5 = HEAP32[628512>>2]|0;
 HEAP32[$cacheWriter>>2] = ((590392 + 8|0));
 $6 = (($cacheWriter) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (($cacheWriter) + 16|0);
 HEAP32[$7>>2] = 0;
 $8 = (($cacheWriter) + 20|0);
 HEAP32[$8>>2] = $5;
 $9 = (($cacheWriter) + 24|0);
 HEAP32[$9>>2] = 0;
 $10 = (($cacheWriter) + 28|0);
 HEAP32[$10>>2] = 256;
 HEAP32[$0>>2] = $5;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 $11 = (invoke_iiiiiiii(108,(0|0),1024,4,($$byval_copy9|0),0,(590384|0),370)|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP32[$10>>2]|0;
  $22 = ($21|0)>(-1);
  do {
   if ($22) {
    $23 = HEAP32[$7>>2]|0;
    $24 = HEAP32[$8>>2]|0;
    HEAP32[$1>>2] = $24;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($23|0),($$byval_copy9|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $29 = ___cxa_find_matching_catch(0|0)|0;
     $30 = tempRet0;
     ___clang_call_terminate($29);
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     break;
    }
   }
  } while(0);
  __THREW__ = 0;
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   $29 = ___cxa_find_matching_catch(0|0)|0;
   $30 = tempRet0;
   ___clang_call_terminate($29);
   // unreachable;
  } else {
   ___resumeException($19|0);
   // unreachable;
  }
 }
 HEAP32[$7>>2] = $11;
 $14 = (($cacheWriter) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = (($cacheWriter) + 8|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$functor>>2] = ((590456 + 8|0));
 $16 = (($functor) + 4|0);
 HEAP32[$16>>2] = $ptrs;
 __THREW__ = 0;
 invoke_viii(1728,($remapTransfer|0),16384,1);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $88 = ___cxa_find_matching_catch()|0;
  $89 = tempRet0;
  $$2 = $88;$$24 = $89;
 } else {
  $31 = (($remapTransfer) + 12|0);
  HEAP32[$31>>2] = $functor;
  $32 = (($ptrs) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($ptrs) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($33|0)==($35|0);
  do {
   if ($36) {
    $$lcssa45 = $33;$189 = $33;
    label = 53;
   } else {
    $37 = (($writeStream) + 4|0);
    $38 = (($writeStream) + 12|0);
    $39 = (($writeStream) + 16|0);
    $40 = (($writeStream) + 20|0);
    $41 = (($writeStream) + 24|0);
    $42 = (($writeStream) + 28|0);
    $43 = (($writeStream) + 32|0);
    $44 = (($writeStream) + 36|0);
    $45 = (($4) + 4|0);
    $46 = (($readStream) + 4|0);
    $47 = (($readStream) + 12|0);
    $48 = (($readStream) + 8|0);
    $50 = $33;
    while(1) {
     $49 = HEAP32[$50>>2]|0;
     HEAP32[$3>>2] = $49;
     $51 = HEAP32[560624>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      label = 19;
     } else {
      $53 = (($51) + 36|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = (($51) + 4|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($54|0)==($56|0);
      do {
       if ($57) {
        $58 = (($51) + 28|0);
        $59 = HEAP32[$58>>2]|0;
        $60 = (($51) + 32|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = (($59) + ($61<<3)|0);
        $78 = $62;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy9,$51,$3);
        $63 = HEAP32[$$byval_copy9>>2]|0;
        $64 = ($63|0)==(-1);
        $65 = (($51) + 28|0);
        $66 = HEAP32[$65>>2]|0;
        if ($64) {
         $67 = (($51) + 32|0);
         $68 = HEAP32[$67>>2]|0;
         $69 = (($66) + ($68<<3)|0);
         $78 = $69;
         break;
        } else {
         $70 = (($66) + ($63<<3)|0);
         $78 = $70;
         break;
        }
       }
      } while(0);
      $71 = HEAP32[560624>>2]|0;
      $72 = (($71) + 28|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($71) + 32|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($73) + ($75<<3)|0);
      $77 = ($78|0)==($76|0);
      if ($77) {
       label = 19;
      } else {
       $79 = (($78) + 4|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = ($80|0)==(0|0);
       if ($81) {
        label = 19;
       } else {
        $temp$0$i = $80;
       }
      }
     }
     if ((label|0) == 19) {
      label = 0;
      __THREW__ = 0;
      $82 = (invoke_ii(3215,($49|0))|0);
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if ($84) {
       label = 22;
       break;
      } else {
       $temp$0$i = $82;
      }
     }
     $85 = (($temp$0$i) + 8|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = $86 >>> 21;
     if (!((($87|0) == 1) | (($87|0) == 4))) {
      $94 = (($50) + 4|0);
      $95 = HEAP32[$94>>2]|0;
      HEAP32[$1>>2] = $95;
      $96 = HEAP32[560624>>2]|0;
      $97 = ($96|0)==(0|0);
      if ($97) {
       label = 33;
      } else {
       $98 = (($96) + 36|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = (($96) + 4|0);
       $101 = HEAP32[$100>>2]|0;
       $102 = ($99|0)==($101|0);
       do {
        if ($102) {
         $103 = (($96) + 28|0);
         $104 = HEAP32[$103>>2]|0;
         $105 = (($96) + 32|0);
         $106 = HEAP32[$105>>2]|0;
         $107 = (($104) + ($106<<3)|0);
         $123 = $107;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy9,$96,$1);
         $108 = HEAP32[$$byval_copy9>>2]|0;
         $109 = ($108|0)==(-1);
         $110 = (($96) + 28|0);
         $111 = HEAP32[$110>>2]|0;
         if ($109) {
          $112 = (($96) + 32|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = (($111) + ($113<<3)|0);
          $123 = $114;
          break;
         } else {
          $115 = (($111) + ($108<<3)|0);
          $123 = $115;
          break;
         }
        }
       } while(0);
       $116 = HEAP32[560624>>2]|0;
       $117 = (($116) + 28|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = (($116) + 32|0);
       $120 = HEAP32[$119>>2]|0;
       $121 = (($118) + ($120<<3)|0);
       $122 = ($123|0)==($121|0);
       if ($122) {
        label = 33;
       } else {
        $124 = (($123) + 4|0);
        $125 = HEAP32[$124>>2]|0;
        $126 = ($125|0)==(0|0);
        if ($126) {
         label = 33;
        } else {
         $temp$0$i22 = $125;
        }
       }
      }
      if ((label|0) == 33) {
       label = 0;
       __THREW__ = 0;
       $127 = (invoke_ii(3215,($95|0))|0);
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 22;
        break;
       } else {
        $temp$0$i22 = $127;
       }
      }
      HEAP32[$writeStream>>2] = 0;
      HEAP32[$37>>2] = 0;
      HEAP32[$38>>2] = 0;
      HEAP32[$39>>2] = 0;
      HEAP32[$40>>2] = 0;
      HEAP32[$41>>2] = -1;
      HEAP32[$42>>2] = 0;
      HEAP32[$43>>2] = -2;
      HEAP32[$44>>2] = 0;
      HEAP32[$4>>2] = -2;
      HEAP32[$45>>2] = 0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy9+4>>2]=HEAP32[$4+4>>2]|0;
      $130 = (invoke_iiii(1542,($writeStream|0),16384,($$byval_copy9|0))|0);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       label = 22;
       break;
      }
      __THREW__ = 0;
      invoke_vii(2695,($130|0),($cacheWriter|0));
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       label = 22;
       break;
      }
      $135 = HEAP32[$temp$0$i>>2]|0;
      $136 = (($135) + 64|0);
      $137 = HEAP32[$136>>2]|0;
      __THREW__ = 0;
      invoke_vii($137|0,($temp$0$i|0),($writeStream|0));
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       label = 22;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(3236,($130|0))|0);
      $140 = __THREW__; __THREW__ = 0;
      $141 = $140&1;
      if ($141) {
       label = 22;
       break;
      }
      $142 = HEAP32[$9>>2]|0;
      $143 = ($142|0)==(0);
      $144 = HEAP32[$7>>2]|0;
      $$54 = $143 ? 0 : $144;
      $145 = HEAP32[$14>>2]|0;
      __THREW__ = 0;
      invoke_viiii(363,($cacheReader|0),($$54|0),($145|0),256);
      $146 = __THREW__; __THREW__ = 0;
      $147 = $146&1;
      if ($147) {
       label = 22;
       break;
      }
      HEAP32[$readStream>>2] = 0;
      HEAP32[$46>>2] = 0;
      __THREW__ = 0;
      invoke_vi(3466,($47|0));
      $148 = __THREW__; __THREW__ = 0;
      $149 = $148&1;
      if ($149) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $150 = (invoke_ii(3223,($temp$0$i22|0))|0);
      $151 = __THREW__; __THREW__ = 0;
      $152 = $151&1;
      if ($152) {
       label = 50;
       break;
      }
      HEAP32[$48>>2] = $150;
      HEAP32[$46>>2] = 0;
      HEAP32[$readStream>>2] = 268451840;
      __THREW__ = 0;
      $153 = (invoke_ii(3237,($130|0))|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       label = 50;
       break;
      }
      __THREW__ = 0;
      invoke_viiii(364,($47|0),($cacheReader|0),0,($153|0));
      $156 = __THREW__; __THREW__ = 0;
      $157 = $156&1;
      if ($157) {
       label = 50;
       break;
      }
      $158 = HEAP32[$temp$0$i22>>2]|0;
      $159 = (($158) + 68|0);
      $160 = HEAP32[$159>>2]|0;
      __THREW__ = 0;
      invoke_vii($160|0,($temp$0$i22|0),($readStream|0));
      $161 = __THREW__; __THREW__ = 0;
      $162 = $161&1;
      if ($162) {
       label = 50;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(3238,($47|0))|0);
      $163 = __THREW__; __THREW__ = 0;
      $164 = $163&1;
      if ($164) {
       label = 50;
       break;
      }
      $165 = HEAP32[$temp$0$i22>>2]|0;
      $166 = (($165) + 72|0);
      $167 = HEAP32[$166>>2]|0;
      __THREW__ = 0;
      invoke_vii($167|0,($temp$0$i22|0),($remapTransfer|0));
      $168 = __THREW__; __THREW__ = 0;
      $169 = $168&1;
      if ($169) {
       label = 50;
       break;
      }
      __THREW__ = 0;
      $170 = __THREW__; __THREW__ = 0;
      $171 = $170&1;
      if ($171) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      invoke_vi(1163,($cacheReader|0));
      $172 = __THREW__; __THREW__ = 0;
      $173 = $172&1;
      if ($173) {
       label = 22;
       break;
      }
     }
     $174 = (($50) + 8|0);
     $175 = HEAP32[$34>>2]|0;
     $176 = ($174|0)==($175|0);
     if ($176) {
      label = 52;
      break;
     } else {
      $50 = $174;
     }
    }
    if ((label|0) == 22) {
     $90 = ___cxa_find_matching_catch()|0;
     $91 = tempRet0;
     $lpad$phi$index = $90;$lpad$phi$index2 = $91;
     label = 24;
     break;
    }
    else if ((label|0) == 49) {
     $177 = ___cxa_find_matching_catch()|0;
     $178 = tempRet0;
     $$0 = $177;$$02 = $178;
    }
    else if ((label|0) == 50) {
     $179 = ___cxa_find_matching_catch()|0;
     $180 = tempRet0;
     __THREW__ = 0;
     $181 = __THREW__; __THREW__ = 0;
     $182 = $181&1;
     if ($182) {
      $271 = ___cxa_find_matching_catch(0|0)|0;
      $272 = tempRet0;
      ___clang_call_terminate($271);
      // unreachable;
     } else {
      $$0 = $179;$$02 = $180;
     }
    }
    else if ((label|0) == 52) {
     $$pre = HEAP32[$32>>2]|0;
     $$lcssa45 = $174;$189 = $$pre;
     label = 53;
     break;
    }
    __THREW__ = 0;
    invoke_vi(1163,($cacheReader|0));
    $183 = __THREW__; __THREW__ = 0;
    $184 = $183&1;
    if ($184) {
     $271 = ___cxa_find_matching_catch(0|0)|0;
     $272 = tempRet0;
     ___clang_call_terminate($271);
     // unreachable;
    } else {
     $$1 = $$0;$$13 = $$02;
    }
   }
  } while(0);
  L69: do {
   if ((label|0) == 53) {
    $185 = (($object) + 4|0);
    $186 = HEAP32[$185>>2]|0;
    $187 = $$lcssa45;
    $188 = $189;
    $190 = (($187) - ($188))|0;
    $191 = $190 >> 3;
    $192 = ($191|0)==(0);
    if ($192) {
     $202 = $189;
    } else {
     $195 = $189;$__len$03$i$i$i$i$i = $191;
     while(1) {
      $193 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
      $194 = (($195) + ($193<<3)|0);
      $196 = HEAP32[$194>>2]|0;
      $197 = ($196|0)<($186|0);
      if ($197) {
       $$sum$i$i$i$i$i = (($193) + 1)|0;
       $198 = (($195) + ($$sum$i$i$i$i$i<<3)|0);
       $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
       $199 = (($$neg2$i$i$i$i$i) - ($193))|0;
       $273 = $198;$__len$0$be$i$i$i$i$i = $199;
      } else {
       $273 = $195;$__len$0$be$i$i$i$i$i = $193;
      }
      $200 = ($__len$0$be$i$i$i$i$i|0)==(0);
      if ($200) {
       $202 = $273;
       break;
      } else {
       $195 = $273;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
      }
     }
    }
    $201 = ($202|0)==($$lcssa45|0);
    if ($201) {
     $206 = $$lcssa45;
    } else {
     $203 = HEAP32[$202>>2]|0;
     $204 = ($186|0)<($203|0);
     $$ = $204 ? $$lcssa45 : $202;
     $206 = $$;
    }
    $205 = (($206) + 4|0);
    $207 = HEAP32[$205>>2]|0;
    $208 = ($207|0)==(0);
    do {
     if ($208) {
      $$0$i = 0;
     } else {
      HEAP32[$0>>2] = $207;
      $209 = HEAP32[560624>>2]|0;
      $210 = ($209|0)==(0|0);
      if (!($210)) {
       $211 = (($209) + 36|0);
       $212 = HEAP32[$211>>2]|0;
       $213 = (($209) + 4|0);
       $214 = HEAP32[$213>>2]|0;
       $215 = ($212|0)==($214|0);
       do {
        if ($215) {
         $216 = (($209) + 28|0);
         $217 = HEAP32[$216>>2]|0;
         $218 = (($209) + 32|0);
         $219 = HEAP32[$218>>2]|0;
         $220 = (($217) + ($219<<3)|0);
         $236 = $220;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy9,$209,$0);
         $221 = HEAP32[$$byval_copy9>>2]|0;
         $222 = ($221|0)==(-1);
         $223 = (($209) + 28|0);
         $224 = HEAP32[$223>>2]|0;
         if ($222) {
          $225 = (($209) + 32|0);
          $226 = HEAP32[$225>>2]|0;
          $227 = (($224) + ($226<<3)|0);
          $236 = $227;
          break;
         } else {
          $228 = (($224) + ($221<<3)|0);
          $236 = $228;
          break;
         }
        }
       } while(0);
       $229 = HEAP32[560624>>2]|0;
       $230 = (($229) + 28|0);
       $231 = HEAP32[$230>>2]|0;
       $232 = (($229) + 32|0);
       $233 = HEAP32[$232>>2]|0;
       $234 = (($231) + ($233<<3)|0);
       $235 = ($236|0)==($234|0);
       if (!($235)) {
        $237 = (($236) + 4|0);
        $238 = HEAP32[$237>>2]|0;
        $239 = ($238|0)==(0|0);
        if (!($239)) {
         $$0$i = $238;
         break;
        }
       }
      }
      __THREW__ = 0;
      $240 = (invoke_ii(3215,($207|0))|0);
      $241 = __THREW__; __THREW__ = 0;
      $242 = $241&1;
      if ($242) {
       $92 = ___cxa_find_matching_catch()|0;
       $93 = tempRet0;
       $lpad$phi$index = $92;$lpad$phi$index2 = $93;
       label = 24;
       break L69;
      } else {
       $$0$i = $240;
      }
     }
    } while(0);
    $243 = (($remapTransfer) + 16|0);
    $244 = HEAP32[$243>>2]|0;
    $245 = ($244|0)==(0|0);
    if ($245) {
     __ZN22BlockMemoryCacheWriterD2Ev($cacheWriter);
     STACKTOP = sp;return ($$0$i|0);
    }
    $246 = (($remapTransfer) + 20|0);
    $247 = HEAP32[$246>>2]|0;
    $248 = ($247|0)==($244|0);
    if (!($248)) {
     $__new_last2$i$i$i$i$i$i$i9 = $244;
     $scevgep$i$i$i$i$i$i$i10 = (($247) + -4|0);
     $249 = (0 - ($__new_last2$i$i$i$i$i$i$i9))|0;
     $uglygep$i$i$i$i$i$i$i12 = (($scevgep$i$i$i$i$i$i$i10) + ($249)|0);
     $uglygep3$i$i$i$i$i$i$i13 = $uglygep$i$i$i$i$i$i$i12;
     $250 = $uglygep3$i$i$i$i$i$i$i13 >>> 2;
     $251 = $250 ^ -1;
     $scevgep4$i$i$i$i$i$i$i14 = (($247) + ($251<<2)|0);
     HEAP32[$246>>2] = $scevgep4$i$i$i$i$i$i$i14;
    }
    HEAP32[$2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($244|0),($$byval_copy9|0));
    $252 = __THREW__; __THREW__ = 0;
    $253 = $252&1;
    if ($253) {
     $254 = ___cxa_find_matching_catch()|0;
     $255 = tempRet0;
     ___cxa_call_unexpected(($254|0));
     // unreachable;
    } else {
     __ZN22BlockMemoryCacheWriterD2Ev($cacheWriter);
     STACKTOP = sp;return ($$0$i|0);
    }
   }
  } while(0);
  if ((label|0) == 24) {
   $$1 = $lpad$phi$index;$$13 = $lpad$phi$index2;
  }
  $256 = (($remapTransfer) + 16|0);
  $257 = HEAP32[$256>>2]|0;
  $258 = ($257|0)==(0|0);
  if ($258) {
   $$2 = $$1;$$24 = $$13;
  } else {
   $259 = (($remapTransfer) + 20|0);
   $260 = HEAP32[$259>>2]|0;
   $261 = ($260|0)==($257|0);
   if (!($261)) {
    $__new_last2$i$i$i$i$i$i$i = $257;
    $scevgep$i$i$i$i$i$i$i = (($260) + -4|0);
    $262 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($262)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $263 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $264 = $263 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($260) + ($264<<2)|0);
    HEAP32[$259>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($257|0),($$byval_copy9|0));
   $265 = __THREW__; __THREW__ = 0;
   $266 = $265&1;
   if ($266) {
    $267 = ___cxa_find_matching_catch()|0;
    $268 = tempRet0;
    ___cxa_call_unexpected(($267|0));
    // unreachable;
   } else {
    $$2 = $$1;$$24 = $$13;
   }
  }
 }
 __THREW__ = 0;
 invoke_vi(3467,($cacheWriter|0));
 $269 = __THREW__; __THREW__ = 0;
 $270 = $269&1;
 if ($270) {
  $271 = ___cxa_find_matching_catch(0|0)|0;
  $272 = tempRet0;
  ___clang_call_terminate($271);
  // unreachable;
 } else {
  ___resumeException($$2|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEvT0_SD_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$013 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0;
 var $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $2 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $3 = $$0;
   $4 = (($0) - ($3))|0;
   $5 = $4 >> 3;
   switch ($5|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 70;
    break L1;
    break;
   }
   default: {
   }
   }
   $66 = ($4|0)<(56);
   if ($66) {
    label = 21;
    break L1;
   }
   $67 = ($4|0)>(7992);
   $68 = (($5|0) / 2)&-1;
   $69 = (($$0) + ($68<<3)|0);
   do {
    if ($67) {
     $70 = (($5|0) / 4)&-1;
     $71 = (($$0) + ($70<<3)|0);
     $$sum = (($70) + ($68))|0;
     $72 = (($$0) + ($$sum<<3)|0);
     $73 = (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEjT0_SD_SD_SD_T_($$0,$71,$69,$72,$__comp)|0);
     $74 = HEAP32[$1>>2]|0;
     $75 = HEAP32[$72>>2]|0;
     $76 = ($74|0)<($75|0);
     if (!($76)) {
      $$pre$phiZ2D = $69;$__n_swaps$0 = $73;
      break;
     }
     HEAP32[$72>>2] = $74;
     HEAP32[$1>>2] = $75;
     $77 = ((($$0) + ($$sum<<3)|0) + 4|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$2>>2]|0;
     HEAP32[$77>>2] = $79;
     HEAP32[$2>>2] = $78;
     $80 = HEAP32[$72>>2]|0;
     $81 = HEAP32[$69>>2]|0;
     $82 = ($80|0)<($81|0);
     if (!($82)) {
      $83 = (($73) + 1)|0;
      $$pre$phiZ2D = $69;$__n_swaps$0 = $83;
      break;
     }
     HEAP32[$69>>2] = $80;
     HEAP32[$72>>2] = $81;
     $84 = ((($$0) + ($68<<3)|0) + 4|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = HEAP32[$77>>2]|0;
     HEAP32[$84>>2] = $86;
     HEAP32[$77>>2] = $85;
     $87 = HEAP32[$69>>2]|0;
     $88 = HEAP32[$71>>2]|0;
     $89 = ($87|0)<($88|0);
     if (!($89)) {
      $90 = (($73) + 2)|0;
      $$pre$phiZ2D = $69;$__n_swaps$0 = $90;
      break;
     }
     HEAP32[$71>>2] = $87;
     HEAP32[$69>>2] = $88;
     $91 = ((($$0) + ($70<<3)|0) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = HEAP32[$84>>2]|0;
     HEAP32[$91>>2] = $93;
     HEAP32[$84>>2] = $92;
     $94 = (($73) + 3)|0;
     $95 = HEAP32[$71>>2]|0;
     $96 = HEAP32[$$0>>2]|0;
     $97 = ($95|0)<($96|0);
     if ($97) {
      HEAP32[$$0>>2] = $95;
      HEAP32[$71>>2] = $96;
      $98 = (($$0) + 4|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = HEAP32[$91>>2]|0;
      HEAP32[$98>>2] = $100;
      HEAP32[$91>>2] = $99;
      $101 = (($73) + 4)|0;
      $$pre$phiZ2D = $69;$__n_swaps$0 = $101;
     } else {
      $$pre$phiZ2D = $69;$__n_swaps$0 = $94;
     }
    } else {
     $102 = HEAP32[$69>>2]|0;
     $103 = HEAP32[$$0>>2]|0;
     $104 = ($102|0)<($103|0);
     $105 = HEAP32[$1>>2]|0;
     $106 = ($105|0)<($102|0);
     if (!($104)) {
      if (!($106)) {
       $$pre$phiZ2D = $69;$__n_swaps$0 = 0;
       break;
      }
      HEAP32[$69>>2] = $105;
      HEAP32[$1>>2] = $102;
      $107 = ((($$0) + ($68<<3)|0) + 4|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = HEAP32[$2>>2]|0;
      HEAP32[$107>>2] = $109;
      HEAP32[$2>>2] = $108;
      $110 = HEAP32[$69>>2]|0;
      $111 = HEAP32[$$0>>2]|0;
      $112 = ($110|0)<($111|0);
      if (!($112)) {
       $$pre$phiZ2D = $69;$__n_swaps$0 = 1;
       break;
      }
      HEAP32[$$0>>2] = $110;
      HEAP32[$69>>2] = $111;
      $113 = (($$0) + 4|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = HEAP32[$107>>2]|0;
      HEAP32[$113>>2] = $115;
      HEAP32[$107>>2] = $114;
      $$pre$phiZ2D = $69;$__n_swaps$0 = 2;
      break;
     }
     if ($106) {
      HEAP32[$$0>>2] = $105;
      HEAP32[$1>>2] = $103;
      $116 = (($$0) + 4|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = HEAP32[$2>>2]|0;
      HEAP32[$116>>2] = $118;
      HEAP32[$2>>2] = $117;
      $$pre$phiZ2D = $69;$__n_swaps$0 = 1;
      break;
     }
     HEAP32[$$0>>2] = $102;
     HEAP32[$69>>2] = $103;
     $119 = (($$0) + 4|0);
     $120 = ((($$0) + ($68<<3)|0) + 4|0);
     $121 = HEAP32[$119>>2]|0;
     $122 = HEAP32[$120>>2]|0;
     HEAP32[$119>>2] = $122;
     HEAP32[$120>>2] = $121;
     $123 = HEAP32[$1>>2]|0;
     $124 = ($123|0)<($103|0);
     if ($124) {
      HEAP32[$69>>2] = $123;
      HEAP32[$1>>2] = $103;
      $125 = HEAP32[$120>>2]|0;
      $126 = HEAP32[$2>>2]|0;
      HEAP32[$120>>2] = $126;
      HEAP32[$2>>2] = $125;
      $$pre$phiZ2D = $69;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $69;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $127 = HEAP32[$$0>>2]|0;
   $128 = HEAP32[$$pre$phiZ2D>>2]|0;
   $129 = ($127|0)<($128|0);
   do {
    if ($129) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $130 = (($__j$0) + -8|0);
      $131 = ($$0|0)==($130|0);
      if ($131) {
       break;
      }
      $156 = HEAP32[$130>>2]|0;
      $157 = ($156|0)<($128|0);
      if ($157) {
       label = 53;
       break;
      } else {
       $__j$0 = $130;
      }
     }
     if ((label|0) == 53) {
      label = 0;
      HEAP32[$$0>>2] = $156;
      HEAP32[$130>>2] = $127;
      $158 = (($$0) + 4|0);
      $159 = (($__j$0) + -4|0);
      $160 = HEAP32[$158>>2]|0;
      $161 = HEAP32[$159>>2]|0;
      HEAP32[$158>>2] = $161;
      HEAP32[$159>>2] = $160;
      $162 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $130;$__n_swaps$3 = $162;
      break;
     }
     $132 = (($$0) + 8|0);
     $133 = HEAP32[$1>>2]|0;
     $134 = ($127|0)<($133|0);
     if ($134) {
      $__i$1 = $132;
     } else {
      $135 = ($132|0)==($1|0);
      if ($135) {
       label = 70;
       break L1;
      } else {
       $__i$013 = $132;
      }
      while(1) {
       $138 = HEAP32[$__i$013>>2]|0;
       $139 = ($127|0)<($138|0);
       $137 = (($__i$013) + 8|0);
       if ($139) {
        break;
       }
       $136 = ($137|0)==($1|0);
       if ($136) {
        label = 70;
        break L1;
       } else {
        $__i$013 = $137;
       }
      }
      HEAP32[$__i$013>>2] = $133;
      HEAP32[$1>>2] = $138;
      $140 = (($__i$013) + 4|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = HEAP32[$2>>2]|0;
      HEAP32[$140>>2] = $142;
      HEAP32[$2>>2] = $141;
      $__i$1 = $137;
     }
     $143 = ($__i$1|0)==($1|0);
     if ($143) {
      label = 70;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $144 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $145 = HEAP32[$__i$2>>2]|0;
       $146 = ($144|0)<($145|0);
       $147 = (($__i$2) + 8|0);
       if ($146) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $147;
       }
      }
      while(1) {
       $148 = (($__j$2) + -8|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = ($144|0)<($149|0);
       if ($150) {
        $__j$2 = $148;
       } else {
        break;
       }
      }
      $151 = ($__i$2>>>0)<($148>>>0);
      if (!($151)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__i$2>>2] = $149;
      HEAP32[$148>>2] = $145;
      $152 = (($__i$2) + 4|0);
      $153 = (($__j$2) + -4|0);
      $154 = HEAP32[$152>>2]|0;
      $155 = HEAP32[$153>>2]|0;
      HEAP32[$152>>2] = $155;
      HEAP32[$153>>2] = $154;
      $__i$2$ph = $147;$__j$1$ph = $148;
     }
    }
   } while(0);
   $163 = (($$0) + 8|0);
   $164 = ($163>>>0)<($__j$3>>>0);
   L53: do {
    if ($164) {
     $__i$3$ph = $163;$__j$4$ph = $__j$3;$__m$0$ph = $69;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $165 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $166 = HEAP32[$__i$3>>2]|0;
       $167 = ($166|0)<($165|0);
       $168 = (($__i$3) + 8|0);
       if ($167) {
        $__i$3 = $168;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $169 = (($__j$5) + -8|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = ($170|0)<($165|0);
       if ($171) {
        break;
       } else {
        $__j$5 = $169;
       }
      }
      $172 = ($__i$3>>>0)>($169>>>0);
      if ($172) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L53;
      }
      HEAP32[$__i$3>>2] = $170;
      HEAP32[$169>>2] = $166;
      $173 = (($__i$3) + 4|0);
      $174 = (($__j$5) + -4|0);
      $175 = HEAP32[$173>>2]|0;
      $176 = HEAP32[$174>>2]|0;
      HEAP32[$173>>2] = $176;
      HEAP32[$174>>2] = $175;
      $177 = (($__n_swaps$4$ph) + 1)|0;
      $178 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $178 ? $169 : $__m$0$ph;
      $__i$3$ph = $168;$__j$4$ph = $169;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $177;
     }
    } else {
     $__i$4 = $163;$__m$2 = $69;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $179 = ($__i$4|0)==($__m$2|0);
   if ($179) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $180 = HEAP32[$__m$2>>2]|0;
    $181 = HEAP32[$__i$4>>2]|0;
    $182 = ($180|0)<($181|0);
    if ($182) {
     HEAP32[$__i$4>>2] = $180;
     HEAP32[$__m$2>>2] = $181;
     $183 = (($__i$4) + 4|0);
     $184 = (($__m$2) + 4|0);
     $185 = HEAP32[$183>>2]|0;
     $186 = HEAP32[$184>>2]|0;
     HEAP32[$183>>2] = $186;
     HEAP32[$184>>2] = $185;
     $187 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $187;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $188 = ($__n_swaps$6|0)==(0);
   if ($188) {
    $189 = (__ZNSt3__127__insertion_sort_incompleteIRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEbT0_SD_T_($$0,$__i$4,$__comp)|0);
    $190 = (($__i$4) + 8|0);
    $191 = (__ZNSt3__127__insertion_sort_incompleteIRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEbT0_SD_T_($190,$$01$ph,$__comp)|0);
    if ($191) {
     label = 65;
     break;
    }
    if ($189) {
     $$0 = $190;
     continue;
    }
   }
   $192 = $__i$4;
   $193 = (($192) - ($3))|0;
   $194 = (($0) - ($192))|0;
   $195 = ($193|0)<($194|0);
   if (!($195)) {
    label = 69;
    break;
   }
   __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEvT0_SD_T_($$0,$__i$4,$__comp);
   $196 = (($__i$4) + 8|0);
   $$0 = $196;
  }
  if ((label|0) == 65) {
   label = 0;
   if ($189) {
    label = 70;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 69) {
   label = 0;
   $197 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEvT0_SD_T_($197,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $6 = (($$01$ph) + -8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$$0>>2]|0;
  $9 = ($7|0)<($8|0);
  if (!($9)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $7;
  HEAP32[$6>>2] = $8;
  $10 = (($$0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$2>>2]|0;
  HEAP32[$10>>2] = $12;
  HEAP32[$2>>2] = $11;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $13 = (($$0) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$$0>>2]|0;
  $16 = ($14|0)<($15|0);
  $17 = (($$01$ph) + -8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)<($14|0);
  if (!($16)) {
   if (!($19)) {
    STACKTOP = sp;return;
   }
   HEAP32[$13>>2] = $18;
   HEAP32[$17>>2] = $14;
   $20 = (($$0) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$2>>2]|0;
   HEAP32[$20>>2] = $22;
   HEAP32[$2>>2] = $21;
   $23 = HEAP32[$13>>2]|0;
   $24 = HEAP32[$$0>>2]|0;
   $25 = ($23|0)<($24|0);
   if (!($25)) {
    STACKTOP = sp;return;
   }
   HEAP32[$$0>>2] = $23;
   HEAP32[$13>>2] = $24;
   $26 = (($$0) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$20>>2]|0;
   HEAP32[$26>>2] = $28;
   HEAP32[$20>>2] = $27;
   STACKTOP = sp;return;
  }
  if ($19) {
   HEAP32[$$0>>2] = $18;
   HEAP32[$17>>2] = $15;
   $29 = (($$0) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$2>>2]|0;
   HEAP32[$29>>2] = $31;
   HEAP32[$2>>2] = $30;
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $14;
  HEAP32[$13>>2] = $15;
  $32 = (($$0) + 4|0);
  $33 = (($$0) + 12|0);
  $34 = HEAP32[$32>>2]|0;
  $35 = HEAP32[$33>>2]|0;
  HEAP32[$32>>2] = $35;
  HEAP32[$33>>2] = $34;
  $36 = HEAP32[$17>>2]|0;
  $37 = ($36|0)<($15|0);
  if (!($37)) {
   STACKTOP = sp;return;
  }
  HEAP32[$13>>2] = $36;
  HEAP32[$17>>2] = $15;
  $38 = HEAP32[$33>>2]|0;
  $39 = HEAP32[$2>>2]|0;
  HEAP32[$33>>2] = $39;
  HEAP32[$2>>2] = $38;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $40 = (($$0) + 8|0);
  $41 = (($$0) + 16|0);
  (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEjT0_SD_SD_SD_T_($$0,$40,$41,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $42 = (($$0) + 8|0);
  $43 = (($$0) + 16|0);
  $44 = (($$0) + 24|0);
  (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEjT0_SD_SD_SD_T_($$0,$42,$43,$44,$__comp)|0);
  $45 = (($$01$ph) + -8|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$44>>2]|0;
  $48 = ($46|0)<($47|0);
  if (!($48)) {
   STACKTOP = sp;return;
  }
  HEAP32[$44>>2] = $46;
  HEAP32[$45>>2] = $47;
  $49 = (($$0) + 28|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = HEAP32[$2>>2]|0;
  HEAP32[$49>>2] = $51;
  HEAP32[$2>>2] = $50;
  $52 = HEAP32[$44>>2]|0;
  $53 = HEAP32[$43>>2]|0;
  $54 = ($52|0)<($53|0);
  if (!($54)) {
   STACKTOP = sp;return;
  }
  HEAP32[$43>>2] = $52;
  HEAP32[$44>>2] = $53;
  $55 = (($$0) + 20|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = HEAP32[$49>>2]|0;
  HEAP32[$55>>2] = $57;
  HEAP32[$49>>2] = $56;
  $58 = HEAP32[$42>>2]|0;
  $59 = ($52|0)<($58|0);
  if (!($59)) {
   STACKTOP = sp;return;
  }
  HEAP32[$42>>2] = $52;
  HEAP32[$43>>2] = $58;
  $60 = (($$0) + 12|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$60>>2] = $57;
  HEAP32[$55>>2] = $61;
  $62 = HEAP32[$$0>>2]|0;
  $63 = ($52|0)<($62|0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $52;
  HEAP32[$42>>2] = $62;
  $64 = (($$0) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  HEAP32[$64>>2] = $57;
  HEAP32[$60>>2] = $65;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEvT0_SD_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 70) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEjT0_SD_SD_SD_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3|0)<($0|0);
 do {
  if ($2) {
   if ($4) {
    HEAP32[$__x1>>2] = $3;
    HEAP32[$__x3>>2] = $1;
    $15 = (($__x1) + 4|0);
    $16 = (($__x3) + 4|0);
    $17 = HEAP32[$15>>2]|0;
    $18 = HEAP32[$16>>2]|0;
    HEAP32[$15>>2] = $18;
    HEAP32[$16>>2] = $17;
    $$0$i = 1;
    break;
   }
   HEAP32[$__x1>>2] = $0;
   HEAP32[$__x2>>2] = $1;
   $19 = (($__x1) + 4|0);
   $20 = (($__x2) + 4|0);
   $21 = HEAP32[$19>>2]|0;
   $22 = HEAP32[$20>>2]|0;
   HEAP32[$19>>2] = $22;
   HEAP32[$20>>2] = $21;
   $23 = HEAP32[$__x3>>2]|0;
   $24 = HEAP32[$__x2>>2]|0;
   $25 = ($23|0)<($24|0);
   if ($25) {
    HEAP32[$__x2>>2] = $23;
    HEAP32[$__x3>>2] = $24;
    $26 = (($__x3) + 4|0);
    $27 = HEAP32[$20>>2]|0;
    $28 = HEAP32[$26>>2]|0;
    HEAP32[$20>>2] = $28;
    HEAP32[$26>>2] = $27;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($4) {
    HEAP32[$__x2>>2] = $3;
    HEAP32[$__x3>>2] = $0;
    $5 = (($__x2) + 4|0);
    $6 = (($__x3) + 4|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = HEAP32[$6>>2]|0;
    HEAP32[$5>>2] = $8;
    HEAP32[$6>>2] = $7;
    $9 = HEAP32[$__x2>>2]|0;
    $10 = HEAP32[$__x1>>2]|0;
    $11 = ($9|0)<($10|0);
    if ($11) {
     HEAP32[$__x1>>2] = $9;
     HEAP32[$__x2>>2] = $10;
     $12 = (($__x1) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = HEAP32[$5>>2]|0;
     HEAP32[$12>>2] = $14;
     HEAP32[$5>>2] = $13;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $29 = HEAP32[$__x4>>2]|0;
 $30 = HEAP32[$__x3>>2]|0;
 $31 = ($29|0)<($30|0);
 if (!($31)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $29;
 HEAP32[$__x4>>2] = $30;
 $32 = (($__x3) + 4|0);
 $33 = (($__x4) + 4|0);
 $34 = HEAP32[$32>>2]|0;
 $35 = HEAP32[$33>>2]|0;
 HEAP32[$32>>2] = $35;
 HEAP32[$33>>2] = $34;
 $36 = (($$0$i) + 1)|0;
 $37 = HEAP32[$__x3>>2]|0;
 $38 = HEAP32[$__x2>>2]|0;
 $39 = ($37|0)<($38|0);
 if (!($39)) {
  $__r$0 = $36;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $37;
 HEAP32[$__x3>>2] = $38;
 $40 = (($__x2) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$32>>2]|0;
 HEAP32[$40>>2] = $42;
 HEAP32[$32>>2] = $41;
 $43 = (($$0$i) + 2)|0;
 $44 = HEAP32[$__x2>>2]|0;
 $45 = HEAP32[$__x1>>2]|0;
 $46 = ($44|0)<($45|0);
 if (!($46)) {
  $__r$0 = $43;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $44;
 HEAP32[$__x2>>2] = $45;
 $47 = (($__x1) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$40>>2]|0;
 HEAP32[$47>>2] = $49;
 HEAP32[$40>>2] = $48;
 $50 = (($$0$i) + 3)|0;
 $__r$0 = $50;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEvT0_SD_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$03 = 0, $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 16|0);
 $1 = (($__first) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = ($2|0)<($3|0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)<($2|0);
 do {
  if ($4) {
   if ($6) {
    HEAP32[$__first>>2] = $5;
    HEAP32[$0>>2] = $3;
    $14 = (($__first) + 4|0);
    $15 = (($__first) + 20|0);
    $16 = HEAP32[$14>>2]|0;
    $17 = HEAP32[$15>>2]|0;
    HEAP32[$14>>2] = $17;
    HEAP32[$15>>2] = $16;
    $46 = $3;
    break;
   }
   HEAP32[$__first>>2] = $2;
   HEAP32[$1>>2] = $3;
   $18 = (($__first) + 4|0);
   $19 = (($__first) + 12|0);
   $20 = HEAP32[$18>>2]|0;
   $21 = HEAP32[$19>>2]|0;
   HEAP32[$18>>2] = $21;
   HEAP32[$19>>2] = $20;
   $22 = ($5|0)<($3|0);
   if ($22) {
    HEAP32[$1>>2] = $5;
    HEAP32[$0>>2] = $3;
    $23 = (($__first) + 20|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$19>>2] = $24;
    HEAP32[$23>>2] = $20;
    $46 = $3;
   } else {
    $46 = $5;
   }
  } else {
   if ($6) {
    HEAP32[$1>>2] = $5;
    HEAP32[$0>>2] = $2;
    $7 = (($__first) + 12|0);
    $8 = (($__first) + 20|0);
    $9 = HEAP32[$7>>2]|0;
    $10 = HEAP32[$8>>2]|0;
    HEAP32[$7>>2] = $10;
    HEAP32[$8>>2] = $9;
    $11 = ($5|0)<($3|0);
    if ($11) {
     HEAP32[$__first>>2] = $5;
     HEAP32[$1>>2] = $3;
     $12 = (($__first) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     HEAP32[$12>>2] = $10;
     HEAP32[$7>>2] = $13;
     $46 = $2;
    } else {
     $46 = $2;
    }
   } else {
    $46 = $5;
   }
  }
 } while(0);
 $25 = (($__first) + 24|0);
 $26 = ($25|0)==($__last|0);
 if ($26) {
  STACKTOP = sp;return;
 } else {
  $29 = $46;$__i$03 = $25;$__j$02 = $0;
 }
 while(1) {
  $27 = HEAP32[$__i$03>>2]|0;
  $28 = ($27|0)<($29|0);
  if ($28) {
   $30 = $__i$03;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $29;$__j$1 = $__i$03;$__k$0 = $__j$02;
   while(1) {
    HEAP32[$__j$1>>2] = $36;
    $37 = (($__k$0) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($__j$1) + 4|0);
    HEAP32[$39>>2] = $38;
    $40 = ($__k$0|0)==($__first|0);
    if ($40) {
     break;
    }
    $41 = (($__k$0) + -8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($32|0)<($42|0);
    if ($43) {
     $__j$1$phi = $__k$0;$36 = $42;$__k$0 = $41;$__j$1 = $__j$1$phi;
    } else {
     break;
    }
   }
   HEAP32[$__k$0>>2] = $32;
   HEAP32[$37>>2] = $35;
  }
  $44 = (($__i$03) + 8|0);
  $45 = ($44|0)==($__last|0);
  if ($45) {
   break;
  }
  $$pre = HEAP32[$__i$03>>2]|0;
  $__j$02$phi = $__i$03;$29 = $$pre;$__i$03 = $44;$__j$02 = $__j$02$phi;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEbT0_SD_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__count$06 = 0, $__count$1 = 0, $__i$07 = 0, $__j$05 = 0, $__j$05$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 5:  {
  $45 = (($__first) + 8|0);
  $46 = (($__first) + 16|0);
  $47 = (($__first) + 24|0);
  (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEjT0_SD_SD_SD_T_($__first,$45,$46,$47,$__comp)|0);
  $48 = (($__last) + -8|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = HEAP32[$47>>2]|0;
  $51 = ($49|0)<($50|0);
  if (!($51)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$47>>2] = $49;
  HEAP32[$48>>2] = $50;
  $52 = (($__first) + 28|0);
  $53 = (($__last) + -4|0);
  $54 = HEAP32[$52>>2]|0;
  $55 = HEAP32[$53>>2]|0;
  HEAP32[$52>>2] = $55;
  HEAP32[$53>>2] = $54;
  $56 = HEAP32[$47>>2]|0;
  $57 = HEAP32[$46>>2]|0;
  $58 = ($56|0)<($57|0);
  if (!($58)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$46>>2] = $56;
  HEAP32[$47>>2] = $57;
  $59 = (($__first) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$52>>2]|0;
  HEAP32[$59>>2] = $61;
  HEAP32[$52>>2] = $60;
  $62 = HEAP32[$45>>2]|0;
  $63 = ($56|0)<($62|0);
  if (!($63)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$45>>2] = $56;
  HEAP32[$46>>2] = $62;
  $64 = (($__first) + 12|0);
  $65 = HEAP32[$64>>2]|0;
  HEAP32[$64>>2] = $61;
  HEAP32[$59>>2] = $65;
  $66 = HEAP32[$__first>>2]|0;
  $67 = ($56|0)<($66|0);
  if (!($67)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $56;
  HEAP32[$45>>2] = $66;
  $68 = (($__first) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  HEAP32[$68>>2] = $61;
  HEAP32[$64>>2] = $69;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $12 = (($__first) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$__first>>2]|0;
  $15 = ($13|0)<($14|0);
  $16 = (($__last) + -8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)<($13|0);
  if (!($15)) {
   if (!($18)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$12>>2] = $17;
   HEAP32[$16>>2] = $13;
   $19 = (($__first) + 12|0);
   $20 = (($__last) + -4|0);
   $21 = HEAP32[$19>>2]|0;
   $22 = HEAP32[$20>>2]|0;
   HEAP32[$19>>2] = $22;
   HEAP32[$20>>2] = $21;
   $23 = HEAP32[$12>>2]|0;
   $24 = HEAP32[$__first>>2]|0;
   $25 = ($23|0)<($24|0);
   if (!($25)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__first>>2] = $23;
   HEAP32[$12>>2] = $24;
   $26 = (($__first) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$19>>2]|0;
   HEAP32[$26>>2] = $28;
   HEAP32[$19>>2] = $27;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($18) {
   HEAP32[$__first>>2] = $17;
   HEAP32[$16>>2] = $14;
   $29 = (($__first) + 4|0);
   $30 = (($__last) + -4|0);
   $31 = HEAP32[$29>>2]|0;
   $32 = HEAP32[$30>>2]|0;
   HEAP32[$29>>2] = $32;
   HEAP32[$30>>2] = $31;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $13;
  HEAP32[$12>>2] = $14;
  $33 = (($__first) + 4|0);
  $34 = (($__first) + 12|0);
  $35 = HEAP32[$33>>2]|0;
  $36 = HEAP32[$34>>2]|0;
  HEAP32[$33>>2] = $36;
  HEAP32[$34>>2] = $35;
  $37 = HEAP32[$16>>2]|0;
  $38 = ($37|0)<($14|0);
  if (!($38)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$12>>2] = $37;
  HEAP32[$16>>2] = $14;
  $39 = (($__last) + -4|0);
  $40 = HEAP32[$34>>2]|0;
  $41 = HEAP32[$39>>2]|0;
  HEAP32[$34>>2] = $41;
  HEAP32[$39>>2] = $40;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $8 = (($__first) + 4|0);
  $9 = (($__last) + -4|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $11;
  HEAP32[$9>>2] = $10;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $42 = (($__first) + 8|0);
  $43 = (($__first) + 16|0);
  $44 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRN10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier90ELi16EEE13value_compareEPS6_EEjT0_SD_SD_SD_T_($__first,$42,$43,$44,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $70 = (($__first) + 16|0);
  $71 = (($__first) + 8|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = HEAP32[$__first>>2]|0;
  $74 = ($72|0)<($73|0);
  $75 = HEAP32[$70>>2]|0;
  $76 = ($75|0)<($72|0);
  do {
   if ($74) {
    if ($76) {
     HEAP32[$__first>>2] = $75;
     HEAP32[$70>>2] = $73;
     $84 = (($__first) + 4|0);
     $85 = (($__first) + 20|0);
     $86 = HEAP32[$84>>2]|0;
     $87 = HEAP32[$85>>2]|0;
     HEAP32[$84>>2] = $87;
     HEAP32[$85>>2] = $86;
     $120 = $73;
     break;
    }
    HEAP32[$__first>>2] = $72;
    HEAP32[$71>>2] = $73;
    $88 = (($__first) + 4|0);
    $89 = (($__first) + 12|0);
    $90 = HEAP32[$88>>2]|0;
    $91 = HEAP32[$89>>2]|0;
    HEAP32[$88>>2] = $91;
    HEAP32[$89>>2] = $90;
    $92 = ($75|0)<($73|0);
    if ($92) {
     HEAP32[$71>>2] = $75;
     HEAP32[$70>>2] = $73;
     $93 = (($__first) + 20|0);
     $94 = HEAP32[$93>>2]|0;
     HEAP32[$89>>2] = $94;
     HEAP32[$93>>2] = $90;
     $120 = $73;
    } else {
     $120 = $75;
    }
   } else {
    if ($76) {
     HEAP32[$71>>2] = $75;
     HEAP32[$70>>2] = $72;
     $77 = (($__first) + 12|0);
     $78 = (($__first) + 20|0);
     $79 = HEAP32[$77>>2]|0;
     $80 = HEAP32[$78>>2]|0;
     HEAP32[$77>>2] = $80;
     HEAP32[$78>>2] = $79;
     $81 = ($75|0)<($73|0);
     if ($81) {
      HEAP32[$__first>>2] = $75;
      HEAP32[$71>>2] = $73;
      $82 = (($__first) + 4|0);
      $83 = HEAP32[$82>>2]|0;
      HEAP32[$82>>2] = $80;
      HEAP32[$77>>2] = $83;
      $120 = $72;
     } else {
      $120 = $72;
     }
    } else {
     $120 = $75;
    }
   }
  } while(0);
  $95 = (($__first) + 24|0);
  $96 = ($95|0)==($__last|0);
  if ($96) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $99 = $120;$__count$06 = 0;$__i$07 = $95;$__j$05 = $70;
  }
  while(1) {
   $97 = HEAP32[$__i$07>>2]|0;
   $98 = ($97|0)<($99|0);
   if ($98) {
    $100 = $__i$07;
    $101 = $100;
    $102 = HEAP32[$101>>2]|0;
    $103 = (($100) + 4)|0;
    $104 = $103;
    $105 = HEAP32[$104>>2]|0;
    $106 = $99;$__j$1 = $__i$07;$__k$0 = $__j$05;
    while(1) {
     HEAP32[$__j$1>>2] = $106;
     $107 = (($__k$0) + 4|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = (($__j$1) + 4|0);
     HEAP32[$109>>2] = $108;
     $110 = ($__k$0|0)==($__first|0);
     if ($110) {
      break;
     }
     $111 = (($__k$0) + -8|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ($102|0)<($112|0);
     if ($113) {
      $__j$1$phi = $__k$0;$106 = $112;$__k$0 = $111;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    HEAP32[$__k$0>>2] = $102;
    HEAP32[$107>>2] = $105;
    $114 = (($__count$06) + 1)|0;
    $115 = ($114|0)==(8);
    if ($115) {
     break;
    } else {
     $__count$1 = $114;
    }
   } else {
    $__count$1 = $__count$06;
   }
   $118 = (($__i$07) + 8|0);
   $119 = ($118|0)==($__last|0);
   if ($119) {
    $$0 = 1;
    label = 35;
    break;
   }
   $$pre = HEAP32[$__i$07>>2]|0;
   $__j$05$phi = $__i$07;$99 = $$pre;$__count$06 = $__count$1;$__i$07 = $118;$__j$05 = $__j$05$phi;
  }
  if ((label|0) == 35) {
   STACKTOP = sp;return ($$0|0);
  }
  $116 = (($__i$07) + 8|0);
  $117 = ($116|0)==($__last|0);
  $$0 = $117;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 3;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 2;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 3;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,590384,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<3)|0);
 $24 = (($23) + ($$0$i3<<3)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = $__x;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = $22;
  $33 = $32;
  HEAP32[$33>>2] = $28;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP32[$35>>2] = $31;
 }
 $36 = (($23) + ($8<<3)|0);
 $37 = HEAP32[$this>>2]|0;
 $38 = HEAP32[$1>>2]|0;
 $39 = $38;
 $40 = $37;
 $41 = (($39) - ($40))|0;
 $42 = $41 >> 3;
 $$sum1 = (($7) - ($42))|0;
 $43 = (($23) + ($$sum1<<3)|0);
 _memcpy(($43|0),($37|0),($41|0))|0;
 $44 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $43;
 HEAP32[$1>>2] = $36;
 HEAP32[$10>>2] = $24;
 $45 = ($44|0)==(0|0);
 if ($45) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($44|0),($$byval_copy1|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN22BlockMemoryCacheWriter13GetFileLengthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN22BlockMemoryCacheWriter12GetCacheSizeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 256;
}
function __ZN22BlockMemoryCacheWriterD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN22BlockMemoryCacheWriterD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN22BlockMemoryCacheWriterD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((590392 + 8|0));
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 L1: do {
  if ($7) {
   $$lcssa = $4;
   label = 8;
  } else {
   $8 = (($this) + 12|0);
   $i$05 = $4;
   while(1) {
    $9 = HEAP32[$i$05>>2]|0;
    $10 = HEAP32[$8>>2]|0;
    HEAP32[$2>>2] = $10;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy2|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = (($i$05) + 4|0);
    $14 = HEAP32[$3>>2]|0;
    $15 = HEAP32[$5>>2]|0;
    $16 = (($14) + ($15<<2)|0);
    $17 = ($13|0)==($16|0);
    if ($17) {
     $$lcssa = $14;
     label = 8;
     break L1;
    } else {
     $i$05 = $13;
    }
   }
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   $20 = (($this) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)>(-1);
   if ($22) {
    $23 = HEAP32[$3>>2]|0;
    $24 = (($this) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$0>>2] = $25;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($23|0),($$byval_copy2|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     $39 = ___cxa_find_matching_catch(0|0)|0;
     $40 = tempRet0;
     ___clang_call_terminate($39);
     // unreachable;
    } else {
     HEAP32[$3>>2] = 0;
     $$0 = $19;$$01 = $18;
     break;
    }
   } else {
    $$0 = $19;$$01 = $18;
   }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $28 = (($this) + 28|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>(-1);
   if (!($30)) {
    STACKTOP = sp;return;
   }
   $31 = (($this) + 20|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$1>>2] = $32;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($$lcssa|0),($$byval_copy2|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $35 = ___cxa_find_matching_catch()|0;
    $36 = tempRet0;
    $$0 = $36;$$01 = $35;
    break;
   }
   HEAP32[$3>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 __THREW__ = 0;
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch(0|0)|0;
  $40 = tempRet0;
  ___clang_call_terminate($39);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN22BlockMemoryCacheWriterD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3467,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN22BlockMemoryCacheWriter15CompleteWritingEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $size;
 $1 = $size >>> 8;
 $2 = (($1) + 1)|0;
 __ZN22BlockMemoryCacheWriter12ResizeBlocksEj($this,$2);
 STACKTOP = sp;return 1;
}
function __ZN22BlockMemoryCacheWriter14LockCacheBlockEjPPhS1_($this,$block,$startPos,$endPos) {
 $this = $this|0;
 $block = $block|0;
 $startPos = $startPos|0;
 $endPos = $endPos|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($block) + 1)|0;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)<($2|0);
 $4 = $3 ? $2 : $0;
 __ZN22BlockMemoryCacheWriter12ResizeBlocksEj($this,$4);
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($block<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$startPos>>2] = $8;
 $9 = (($8) + 256|0);
 HEAP32[$endPos>>2] = $9;
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 1)|0;
 HEAP32[$10>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN22BlockMemoryCacheWriter16UnlockCacheBlockEj($this,$block) {
 $this = $this|0;
 $block = $block|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN22BlockMemoryCacheWriter11GetPathNameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__Znwj(16)|0);
 $1 = (($agg$result) + 8|0);
 HEAP32[$1>>2] = $0;
 HEAP32[$agg$result>>2] = 17;
 $2 = (($agg$result) + 4|0);
 HEAP32[$2>>2] = 12;
 dest=$0+0|0; src=590440+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $3 = (($0) + 12|0);
 HEAP8[$3>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN22BlockMemoryCacheWriter12ResizeBlocksEj($this,$newBlockSize) {
 $this = $this|0;
 $newBlockSize = $newBlockSize|0;
 var $$01$i$i = 0, $$byval_copy5 = 0, $$pr$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $block$03 = 0, $block1$02 = 0, $exitcond = 0, $exitcond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 16|0);
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)>($newBlockSize>>>0);
 if ($6) {
  $7 = (($this) + 12|0);
  $block$03 = $newBlockSize;
  while(1) {
   $8 = HEAP32[$3>>2]|0;
   $9 = (($8) + ($block$03<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$7>>2]|0;
   HEAP32[$1>>2] = $11;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($10,$$byval_copy5);
   $12 = (($block$03) + 1)|0;
   $exitcond5 = ($12|0)==($5|0);
   if ($exitcond5) {
    break;
   } else {
    $block$03 = $12;
   }
  }
 }
 $13 = (($this) + 28|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 2147483647;
 $16 = ($15>>>0)<($newBlockSize>>>0);
 do {
  if ($16) {
   $17 = $14 << 1;
   $18 = ($15>>>0)<($17>>>0);
   if ($18) {
    $19 = ($14|0)>(-1);
    if ($19) {
     HEAP32[$13>>2] = $17;
     $20 = HEAP32[$3>>2]|0;
     $21 = $14 << 3;
     $22 = (($this) + 20|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z16realloc_internalPvji10MemLabelIdiPKci($20,$21,4,$$byval_copy5,0,590384,370)|0);
     HEAP32[$3>>2] = $24;
     $$pr$pre = HEAP32[$13>>2]|0;
     $33 = $$pr$pre;
     break;
    } else {
     $25 = $14 << 3;
     $26 = (($this) + 20|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$0>>2] = $27;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,4,$$byval_copy5,0,590384,352)|0);
     $29 = HEAP32[$3>>2]|0;
     $30 = HEAP32[$4>>2]|0;
     $31 = $30 << 2;
     _memcpy(($28|0),($29|0),($31|0))|0;
     HEAP32[$13>>2] = $17;
     HEAP32[$3>>2] = $28;
     $33 = $17;
     break;
    }
   } else {
    $33 = $14;
   }
  } else {
   $33 = $14;
  }
 } while(0);
 $32 = $33 & 2147483647;
 $34 = ($32>>>0)<($newBlockSize>>>0);
 do {
  if ($34) {
   $35 = ($33|0)>(-1);
   if ($35) {
    HEAP32[$13>>2] = $newBlockSize;
    $36 = HEAP32[$3>>2]|0;
    $37 = $newBlockSize << 2;
    $38 = (($this) + 20|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$0>>2] = $39;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $40 = (__Z16realloc_internalPvji10MemLabelIdiPKci($36,$37,4,$$byval_copy5,0,590384,370)|0);
    HEAP32[$3>>2] = $40;
    break;
   } else {
    $41 = $newBlockSize << 2;
    $42 = (($this) + 20|0);
    $43 = HEAP32[$42>>2]|0;
    HEAP32[$0>>2] = $43;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $44 = (__Z15malloc_internaljj10MemLabelIdiPKci($41,4,$$byval_copy5,0,590384,352)|0);
    $45 = HEAP32[$3>>2]|0;
    $46 = HEAP32[$4>>2]|0;
    $47 = $46 << 2;
    _memcpy(($44|0),($45|0),($47|0))|0;
    HEAP32[$13>>2] = $newBlockSize;
    HEAP32[$3>>2] = $44;
    break;
   }
  }
 } while(0);
 $48 = HEAP32[$4>>2]|0;
 $49 = ($48>>>0)<($newBlockSize>>>0);
 if ($49) {
  $50 = HEAP32[$3>>2]|0;
  $51 = (($50) + ($newBlockSize<<2)|0);
  $52 = ($48|0)==($newBlockSize|0);
  if (!($52)) {
   $53 = (($50) + ($48<<2)|0);
   $$01$i$i = $53;
   while(1) {
    $54 = ($$01$i$i|0)==(0|0);
    if (!($54)) {
     HEAP32[$$01$i$i>>2] = 0;
    }
    $55 = (($$01$i$i) + 4|0);
    $56 = ($55|0)==($51|0);
    if ($56) {
     break;
    } else {
     $$01$i$i = $55;
    }
   }
  }
 }
 HEAP32[$4>>2] = $newBlockSize;
 $57 = ($5>>>0)<($newBlockSize>>>0);
 if (!($57)) {
  STACKTOP = sp;return;
 }
 $58 = (($this) + 12|0);
 $block1$02 = $5;
 while(1) {
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$2>>2] = $59;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  $60 = (__Z15malloc_internaljj10MemLabelIdiPKci(256,16,$$byval_copy5,0,590384,67)|0);
  $61 = HEAP32[$3>>2]|0;
  $62 = (($61) + ($block1$02<<2)|0);
  HEAP32[$62>>2] = $60;
  $63 = (($block1$02) + 1)|0;
  $exitcond = ($63|0)==($newBlockSize|0);
  if ($exitcond) {
   break;
  } else {
   $block1$02 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZN26RemapFunctorTempRemapTable18GenerateInstanceIDEi17TransferMetaFlags($this,$oldInstanceID,$metaFlags) {
 $this = $this|0;
 $oldInstanceID = $oldInstanceID|0;
 $metaFlags = $metaFlags|0;
 var $$ = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = $3;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 3;
 $10 = ($9|0)==(0);
 if ($10) {
  $20 = $3;
 } else {
  $13 = $3;$__len$03$i$i$i$i$i = $9;
  while(1) {
   $11 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $12 = (($13) + ($11<<3)|0);
   $14 = HEAP32[$12>>2]|0;
   $15 = ($14|0)<($oldInstanceID|0);
   if ($15) {
    $$sum$i$i$i$i$i = (($11) + 1)|0;
    $16 = (($13) + ($$sum$i$i$i$i$i<<3)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $17 = (($$neg2$i$i$i$i$i) - ($11))|0;
    $27 = $16;$__len$0$be$i$i$i$i$i = $17;
   } else {
    $27 = $13;$__len$0$be$i$i$i$i$i = $11;
   }
   $18 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($18) {
    $20 = $27;
    break;
   } else {
    $13 = $27;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $19 = ($20|0)==($5|0);
 if ($19) {
  $26 = $oldInstanceID;
  STACKTOP = sp;return ($26|0);
 }
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)>($oldInstanceID|0);
 $$ = $22 ? $5 : $20;
 $23 = ($$|0)==($5|0);
 if ($23) {
  $26 = $oldInstanceID;
  STACKTOP = sp;return ($26|0);
 }
 $24 = (($$) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25;
 STACKTOP = sp;return ($26|0);
}
function __Z22DelayedDestroyCallbackP6ObjectPv($o,$userData) {
 $o = $o|0;
 $userData = $userData|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22DestroyObjectHighLevelP6Objectb($o,0);
 STACKTOP = sp;return;
}
function __Z20DestroyObjectDelayedP6Objectf($o,$time) {
 $o = $o|0;
 $time = Math_fround($time);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($o|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 0;
 } else {
  $2 = (($o) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $3;
 }
 __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(2696,$0,$time,0,Math_fround(0.0),0,67);
 STACKTOP = sp;return;
}
function __Z21CalculateClosestPointRK8Vector3fRK4AABBRS_Rf($rkPoint,$rkBox,$outPoint,$outSqrDistance) {
 $rkPoint = $rkPoint|0;
 $rkBox = $rkBox|0;
 $outPoint = $outPoint|0;
 $outSqrDistance = $outSqrDistance|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $fSqrDistance$1 = Math_fround(0), $fSqrDistance$1$1 = Math_fround(0), $fSqrDistance$1$2 = Math_fround(0), $storemerge = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$rkPoint>>2]);
 $1 = Math_fround(HEAPF32[$rkBox>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($rkPoint) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($rkBox) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($rkPoint) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($rkBox) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($rkBox) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(-$14);
 $16 = $2 < $15;
 if ($16) {
  $17 = Math_fround($2 + $14);
  $18 = Math_fround($17 * $17);
  $19 = Math_fround($18 + Math_fround(0.0));
  $29 = $15;$fSqrDistance$1 = $19;
 } else {
  $20 = $2 > $14;
  if ($20) {
   $21 = Math_fround($2 - $14);
   $22 = Math_fround($21 * $21);
   $23 = Math_fround($22 + Math_fround(0.0));
   $29 = $14;$fSqrDistance$1 = $23;
  } else {
   $29 = $2;$fSqrDistance$1 = Math_fround(0.0);
  }
 }
 $24 = (($13) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround(-$25);
 $27 = $7 < $26;
 if ($27) {
  $40 = Math_fround($7 + $25);
  $41 = Math_fround($40 * $40);
  $42 = Math_fround($fSqrDistance$1 + $41);
  $31 = $26;$fSqrDistance$1$1 = $42;
 } else {
  $36 = $7 > $25;
  if ($36) {
   $37 = Math_fround($7 - $25);
   $38 = Math_fround($37 * $37);
   $39 = Math_fround($fSqrDistance$1 + $38);
   $31 = $25;$fSqrDistance$1$1 = $39;
  } else {
   $31 = $7;$fSqrDistance$1$1 = $fSqrDistance$1;
  }
 }
 $43 = (($13) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround(-$44);
 $46 = $12 < $45;
 if ($46) {
  $51 = Math_fround($12 + $44);
  $52 = Math_fround($51 * $51);
  $53 = Math_fround($fSqrDistance$1$1 + $52);
  $33 = $45;$fSqrDistance$1$2 = $53;
 } else {
  $47 = $12 > $44;
  if ($47) {
   $48 = Math_fround($12 - $44);
   $49 = Math_fround($48 * $48);
   $50 = Math_fround($fSqrDistance$1$1 + $49);
   $33 = $44;$fSqrDistance$1$2 = $50;
  } else {
   $33 = $12;$fSqrDistance$1$2 = $fSqrDistance$1$1;
  }
 }
 $54 = $fSqrDistance$1$2 == Math_fround(0.0);
 if ($54) {
  ;HEAP32[$outPoint+0>>2]=HEAP32[$rkPoint+0>>2]|0;HEAP32[$outPoint+4>>2]=HEAP32[$rkPoint+4>>2]|0;HEAP32[$outPoint+8>>2]=HEAP32[$rkPoint+8>>2]|0;
  $storemerge = Math_fround(0.0);
  HEAPF32[$outSqrDistance>>2] = $storemerge;
  STACKTOP = sp;return;
 } else {
  $28 = Math_fround($29 + $1);
  $30 = Math_fround($31 + $6);
  $32 = Math_fround($33 + $11);
  HEAPF32[$outPoint>>2] = $28;
  $34 = (($outPoint) + 4|0);
  HEAPF32[$34>>2] = $30;
  $35 = (($outPoint) + 8|0);
  HEAPF32[$35>>2] = $32;
  $storemerge = $fSqrDistance$1$2;
  HEAPF32[$outSqrDistance>>2] = $storemerge;
  STACKTOP = sp;return;
 }
}
function __Z20CalculateSqrDistanceRK8Vector3fRK4AABB($rkPoint,$rkBox) {
 $rkPoint = $rkPoint|0;
 $rkBox = $rkBox|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $sqrDistance$1 = Math_fround(0), $sqrDistance$1$1 = Math_fround(0), $sqrDistance$1$2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$rkPoint>>2]);
 $1 = Math_fround(HEAPF32[$rkBox>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($rkPoint) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($rkBox) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($rkPoint) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($rkBox) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($rkBox) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(-$14);
 $16 = $2 < $15;
 if ($16) {
  $17 = Math_fround($2 + $14);
  $18 = Math_fround($17 * $17);
  $19 = Math_fround($18 + Math_fround(0.0));
  $sqrDistance$1 = $19;
 } else {
  $20 = $2 > $14;
  if ($20) {
   $21 = Math_fround($2 - $14);
   $22 = Math_fround($21 * $21);
   $23 = Math_fround($22 + Math_fround(0.0));
   $sqrDistance$1 = $23;
  } else {
   $sqrDistance$1 = Math_fround(0.0);
  }
 }
 $24 = (($13) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround(-$25);
 $27 = $7 < $26;
 if ($27) {
  $32 = Math_fround($7 + $25);
  $33 = Math_fround($32 * $32);
  $34 = Math_fround($sqrDistance$1 + $33);
  $sqrDistance$1$1 = $34;
 } else {
  $28 = $7 > $25;
  if ($28) {
   $29 = Math_fround($7 - $25);
   $30 = Math_fround($29 * $29);
   $31 = Math_fround($sqrDistance$1 + $30);
   $sqrDistance$1$1 = $31;
  } else {
   $sqrDistance$1$1 = $sqrDistance$1;
  }
 }
 $35 = (($13) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(-$36);
 $38 = $12 < $37;
 if ($38) {
  $43 = Math_fround($12 + $36);
  $44 = Math_fround($43 * $43);
  $45 = Math_fround($sqrDistance$1$1 + $44);
  $sqrDistance$1$2 = $45;
  STACKTOP = sp;return (Math_fround($sqrDistance$1$2));
 }
 $39 = $12 > $36;
 if (!($39)) {
  $sqrDistance$1$2 = $sqrDistance$1$1;
  STACKTOP = sp;return (Math_fround($sqrDistance$1$2));
 }
 $40 = Math_fround($12 - $36);
 $41 = Math_fround($40 * $40);
 $42 = Math_fround($sqrDistance$1$1 + $41);
 $sqrDistance$1$2 = $42;
 STACKTOP = sp;return (Math_fround($sqrDistance$1$2));
}
function __ZNK4AABB11GetVerticesEP8Vector3f($this,$outVertices) {
 $this = $this|0;
 $outVertices = $outVertices|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 20|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$this>>2]);
 $7 = Math_fround($6 - $1);
 $8 = (($this) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 - $3);
 $11 = (($this) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 - $5);
 HEAPF32[$outVertices>>2] = $7;
 $14 = (($outVertices) + 4|0);
 HEAPF32[$14>>2] = $10;
 $15 = (($outVertices) + 8|0);
 HEAPF32[$15>>2] = $13;
 $16 = Math_fround(HEAPF32[$0>>2]);
 $17 = Math_fround(HEAPF32[$2>>2]);
 $18 = Math_fround(HEAPF32[$4>>2]);
 $19 = Math_fround(HEAPF32[$this>>2]);
 $20 = Math_fround($16 + $19);
 $21 = Math_fround(HEAPF32[$8>>2]);
 $22 = Math_fround($21 - $17);
 $23 = Math_fround(HEAPF32[$11>>2]);
 $24 = Math_fround($23 - $18);
 $25 = (($outVertices) + 12|0);
 HEAPF32[$25>>2] = $20;
 $26 = (($outVertices) + 16|0);
 HEAPF32[$26>>2] = $22;
 $27 = (($outVertices) + 20|0);
 HEAPF32[$27>>2] = $24;
 $28 = Math_fround(HEAPF32[$0>>2]);
 $29 = Math_fround(HEAPF32[$2>>2]);
 $30 = Math_fround(HEAPF32[$4>>2]);
 $31 = Math_fround(HEAPF32[$this>>2]);
 $32 = Math_fround($31 - $28);
 $33 = Math_fround(HEAPF32[$8>>2]);
 $34 = Math_fround($29 + $33);
 $35 = Math_fround(HEAPF32[$11>>2]);
 $36 = Math_fround($35 - $30);
 $37 = (($outVertices) + 24|0);
 HEAPF32[$37>>2] = $32;
 $38 = (($outVertices) + 28|0);
 HEAPF32[$38>>2] = $34;
 $39 = (($outVertices) + 32|0);
 HEAPF32[$39>>2] = $36;
 $40 = Math_fround(HEAPF32[$0>>2]);
 $41 = Math_fround(HEAPF32[$2>>2]);
 $42 = Math_fround(HEAPF32[$4>>2]);
 $43 = Math_fround(HEAPF32[$this>>2]);
 $44 = Math_fround($40 + $43);
 $45 = Math_fround(HEAPF32[$8>>2]);
 $46 = Math_fround($41 + $45);
 $47 = Math_fround(HEAPF32[$11>>2]);
 $48 = Math_fround($47 - $42);
 $49 = (($outVertices) + 36|0);
 HEAPF32[$49>>2] = $44;
 $50 = (($outVertices) + 40|0);
 HEAPF32[$50>>2] = $46;
 $51 = (($outVertices) + 44|0);
 HEAPF32[$51>>2] = $48;
 $52 = Math_fround(HEAPF32[$0>>2]);
 $53 = Math_fround(HEAPF32[$2>>2]);
 $54 = Math_fround(HEAPF32[$4>>2]);
 $55 = Math_fround(HEAPF32[$this>>2]);
 $56 = Math_fround($55 - $52);
 $57 = Math_fround(HEAPF32[$8>>2]);
 $58 = Math_fround($57 - $53);
 $59 = Math_fround(HEAPF32[$11>>2]);
 $60 = Math_fround($54 + $59);
 $61 = (($outVertices) + 48|0);
 HEAPF32[$61>>2] = $56;
 $62 = (($outVertices) + 52|0);
 HEAPF32[$62>>2] = $58;
 $63 = (($outVertices) + 56|0);
 HEAPF32[$63>>2] = $60;
 $64 = Math_fround(HEAPF32[$0>>2]);
 $65 = Math_fround(HEAPF32[$2>>2]);
 $66 = Math_fround(HEAPF32[$4>>2]);
 $67 = Math_fround(HEAPF32[$this>>2]);
 $68 = Math_fround($64 + $67);
 $69 = Math_fround(HEAPF32[$8>>2]);
 $70 = Math_fround($69 - $65);
 $71 = Math_fround(HEAPF32[$11>>2]);
 $72 = Math_fround($66 + $71);
 $73 = (($outVertices) + 60|0);
 HEAPF32[$73>>2] = $68;
 $74 = (($outVertices) + 64|0);
 HEAPF32[$74>>2] = $70;
 $75 = (($outVertices) + 68|0);
 HEAPF32[$75>>2] = $72;
 $76 = Math_fround(HEAPF32[$0>>2]);
 $77 = Math_fround(HEAPF32[$2>>2]);
 $78 = Math_fround(HEAPF32[$4>>2]);
 $79 = Math_fround(HEAPF32[$this>>2]);
 $80 = Math_fround($79 - $76);
 $81 = Math_fround(HEAPF32[$8>>2]);
 $82 = Math_fround($77 + $81);
 $83 = Math_fround(HEAPF32[$11>>2]);
 $84 = Math_fround($78 + $83);
 $85 = (($outVertices) + 72|0);
 HEAPF32[$85>>2] = $80;
 $86 = (($outVertices) + 76|0);
 HEAPF32[$86>>2] = $82;
 $87 = (($outVertices) + 80|0);
 HEAPF32[$87>>2] = $84;
 $88 = Math_fround(HEAPF32[$0>>2]);
 $89 = Math_fround(HEAPF32[$2>>2]);
 $90 = Math_fround(HEAPF32[$4>>2]);
 $91 = Math_fround(HEAPF32[$this>>2]);
 $92 = Math_fround($88 + $91);
 $93 = Math_fround(HEAPF32[$8>>2]);
 $94 = Math_fround($89 + $93);
 $95 = Math_fround(HEAPF32[$11>>2]);
 $96 = Math_fround($90 + $95);
 $97 = (($outVertices) + 84|0);
 HEAPF32[$97>>2] = $92;
 $98 = (($outVertices) + 88|0);
 HEAPF32[$98>>2] = $94;
 $99 = (($outVertices) + 92|0);
 HEAPF32[$99>>2] = $96;
 STACKTOP = sp;return;
}
function __ZNK10MinMaxAABB11GetVerticesEP8Vector3f($this,$outVertices) {
 $this = $this|0;
 $outVertices = $outVertices|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$this>>2]);
 $1 = (($this) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$outVertices>>2] = $0;
 $5 = (($outVertices) + 4|0);
 HEAPF32[$5>>2] = $2;
 $6 = (($outVertices) + 8|0);
 HEAPF32[$6>>2] = $4;
 $7 = (($this) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$1>>2]);
 $10 = Math_fround(HEAPF32[$3>>2]);
 $11 = (($outVertices) + 12|0);
 HEAPF32[$11>>2] = $8;
 $12 = (($outVertices) + 16|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($outVertices) + 20|0);
 HEAPF32[$13>>2] = $10;
 $14 = Math_fround(HEAPF32[$7>>2]);
 $15 = (($this) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(HEAPF32[$3>>2]);
 $18 = (($outVertices) + 24|0);
 HEAPF32[$18>>2] = $14;
 $19 = (($outVertices) + 28|0);
 HEAPF32[$19>>2] = $16;
 $20 = (($outVertices) + 32|0);
 HEAPF32[$20>>2] = $17;
 $21 = Math_fround(HEAPF32[$this>>2]);
 $22 = Math_fround(HEAPF32[$15>>2]);
 $23 = Math_fround(HEAPF32[$3>>2]);
 $24 = (($outVertices) + 36|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($outVertices) + 40|0);
 HEAPF32[$25>>2] = $22;
 $26 = (($outVertices) + 44|0);
 HEAPF32[$26>>2] = $23;
 $27 = Math_fround(HEAPF32[$this>>2]);
 $28 = Math_fround(HEAPF32[$1>>2]);
 $29 = (($this) + 20|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($outVertices) + 48|0);
 HEAPF32[$31>>2] = $27;
 $32 = (($outVertices) + 52|0);
 HEAPF32[$32>>2] = $28;
 $33 = (($outVertices) + 56|0);
 HEAPF32[$33>>2] = $30;
 $34 = Math_fround(HEAPF32[$7>>2]);
 $35 = Math_fround(HEAPF32[$1>>2]);
 $36 = Math_fround(HEAPF32[$29>>2]);
 $37 = (($outVertices) + 60|0);
 HEAPF32[$37>>2] = $34;
 $38 = (($outVertices) + 64|0);
 HEAPF32[$38>>2] = $35;
 $39 = (($outVertices) + 68|0);
 HEAPF32[$39>>2] = $36;
 $40 = Math_fround(HEAPF32[$7>>2]);
 $41 = Math_fround(HEAPF32[$15>>2]);
 $42 = Math_fround(HEAPF32[$29>>2]);
 $43 = (($outVertices) + 72|0);
 HEAPF32[$43>>2] = $40;
 $44 = (($outVertices) + 76|0);
 HEAPF32[$44>>2] = $41;
 $45 = (($outVertices) + 80|0);
 HEAPF32[$45>>2] = $42;
 $46 = Math_fround(HEAPF32[$this>>2]);
 $47 = Math_fround(HEAPF32[$15>>2]);
 $48 = Math_fround(HEAPF32[$29>>2]);
 $49 = (($outVertices) + 84|0);
 HEAPF32[$49>>2] = $46;
 $50 = (($outVertices) + 88|0);
 HEAPF32[$50>>2] = $47;
 $51 = (($outVertices) + 92|0);
 HEAPF32[$51>>2] = $48;
 STACKTOP = sp;return;
}
function __ZNK4AABB8IsInsideERK8Vector3f($this,$inPoint) {
 $this = $this|0;
 $inPoint = $inPoint|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $not$ = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inPoint>>2]);
 $1 = Math_fround(HEAPF32[$this>>2]);
 $2 = (($this) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = $0 < $4;
 $6 = Math_fround($1 + $3);
 $7 = $0 > $6;
 $or$cond = $5 | $7;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($inPoint) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($2) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = $9 < $14;
 $16 = Math_fround($11 + $13);
 $17 = $9 > $16;
 $or$cond3 = $15 | $17;
 if ($or$cond3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($inPoint) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($2) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 $25 = $19 < $24;
 if ($25) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = Math_fround($21 + $23);
 $not$ = !($19 > $26);
 $$0 = $not$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4AABB11EncapsulateERK8Vector3f($this,$inPoint) {
 $this = $this|0;
 $inPoint = $inPoint|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$this>>2]);
 $1 = (($this) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 - $2);
 $4 = (($this) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($this) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = Math_fround($0 + $2);
 $15 = Math_fround($5 + $7);
 $16 = Math_fround($10 + $12);
 $17 = Math_fround(HEAPF32[$inPoint>>2]);
 $18 = $17 < $3;
 $19 = $18 ? $17 : $3;
 $20 = (($inPoint) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = $21 < $8;
 $23 = $22 ? $21 : $8;
 $24 = (($inPoint) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = $25 < $13;
 $27 = $26 ? $25 : $13;
 $28 = $14 < $17;
 $29 = $28 ? $17 : $14;
 $30 = $15 < $21;
 $31 = $30 ? $21 : $15;
 $32 = $16 < $25;
 $33 = $32 ? $25 : $16;
 $34 = Math_fround($29 + $19);
 $35 = Math_fround($31 + $23);
 $36 = Math_fround($33 + $27);
 $37 = Math_fround($34 * Math_fround(0.5));
 $38 = Math_fround($35 * Math_fround(0.5));
 $39 = Math_fround($36 * Math_fround(0.5));
 HEAPF32[$this>>2] = $37;
 HEAPF32[$4>>2] = $38;
 HEAPF32[$9>>2] = $39;
 $40 = Math_fround($29 - $19);
 $41 = Math_fround($31 - $23);
 $42 = Math_fround($33 - $27);
 $43 = Math_fround($40 * Math_fround(0.5));
 $44 = Math_fround($41 * Math_fround(0.5));
 $45 = Math_fround($42 * Math_fround(0.5));
 HEAPF32[$1>>2] = $43;
 HEAPF32[$6>>2] = $44;
 HEAPF32[$11>>2] = $45;
 STACKTOP = sp;return;
}
function __Z7AddAABBRK10MinMaxAABBS1_($agg$result,$lhs,$rhs) {
 $agg$result = $agg$result|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $or$cond = 0;
 var $phitmp2$i = 0, $phitmp2$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 12|0);
 $1 = (($agg$result) + 16|0);
 $2 = (($agg$result) + 20|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 ;HEAP32[$agg$result+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[616664+8>>2]|0;
 $3 = Math_fround(HEAPF32[616664>>2]);
 $4 = Math_fround(-$3);
 $5 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $6 = Math_fround(-$5);
 $7 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $8 = Math_fround(-$7);
 HEAPF32[$0>>2] = $4;
 HEAPF32[$1>>2] = $6;
 HEAPF32[$2>>2] = $8;
 $9 = Math_fround(HEAPF32[$lhs>>2]);
 $10 = $9 == $3;
 if ($10) {
  $11 = (($lhs) + 4|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = $12 == $5;
  if ($13) {
   $14 = (($lhs) + 8|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = $15 == $7;
   if (!($16)) {
    label = 4;
   }
  } else {
   label = 4;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $17 = (($lhs) + 12|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = $18 == $4;
   if ($19) {
    $20 = (($lhs) + 16|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = $21 == $6;
    if ($22) {
     $23 = (($lhs) + 20|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $phitmp2$i3 = $24 != $8;
     if (!($phitmp2$i3)) {
      break;
     }
    }
   }
   ;HEAP32[$agg$result+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$lhs+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$lhs+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$lhs+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$lhs+20>>2]|0;
  }
 } while(0);
 $25 = Math_fround(HEAPF32[$rhs>>2]);
 $26 = $25 == $3;
 if ($26) {
  $27 = (($rhs) + 4|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = $28 == $5;
  if ($29) {
   $30 = (($rhs) + 8|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = $31 == $7;
   if ($32) {
    STACKTOP = sp;return;
   }
  }
 }
 $33 = (($rhs) + 12|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = $34 == $4;
 $36 = (($rhs) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = $37 == $6;
 $or$cond = $35 & $38;
 if ($or$cond) {
  $39 = (($rhs) + 20|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $phitmp2$i = $40 != $8;
  if (!($phitmp2$i)) {
   STACKTOP = sp;return;
  }
 }
 $41 = Math_fround(HEAPF32[$agg$result>>2]);
 $42 = $34 < $41;
 $43 = $42 ? $34 : $41;
 $44 = (($agg$result) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = $37 < $45;
 $47 = $46 ? $37 : $45;
 $48 = (($agg$result) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($rhs) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = $51 < $49;
 $53 = $52 ? $51 : $49;
 $54 = Math_fround(HEAPF32[$0>>2]);
 $55 = $54 < $34;
 $56 = $55 ? $34 : $54;
 $57 = Math_fround(HEAPF32[$1>>2]);
 $58 = $57 < $37;
 $59 = $58 ? $37 : $57;
 $60 = Math_fround(HEAPF32[$2>>2]);
 $61 = $60 < $51;
 $62 = $61 ? $51 : $60;
 $63 = $25 < $43;
 $64 = $63 ? $25 : $43;
 $65 = (($rhs) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = $66 < $47;
 $68 = $67 ? $66 : $47;
 $69 = (($rhs) + 8|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = $70 < $53;
 $72 = $71 ? $70 : $53;
 HEAPF32[$agg$result>>2] = $64;
 HEAPF32[$44>>2] = $68;
 HEAPF32[$48>>2] = $72;
 $73 = $56 < $25;
 $74 = $73 ? $25 : $56;
 $75 = $59 < $66;
 $76 = $75 ? $66 : $59;
 $77 = $62 < $70;
 $78 = $77 ? $70 : $62;
 HEAPF32[$0>>2] = $74;
 HEAPF32[$1>>2] = $76;
 HEAPF32[$2>>2] = $78;
 STACKTOP = sp;return;
}
function __Z13TransformAABBRK4AABBRK10Matrix4x4fRS_($aabb,$transform,$result) {
 $aabb = $aabb|0;
 $transform = $transform|0;
 $result = $result|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $extents = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $extents = sp;
 $0 = (($aabb) + 12|0);
 __Z13RotateExtentsRK8Vector3fRK10Matrix4x4f($extents,$0,$transform);
 $1 = Math_fround(HEAPF32[$transform>>2]);
 $2 = Math_fround(HEAPF32[$aabb>>2]);
 $3 = Math_fround($1 * $2);
 $4 = (($transform) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($aabb) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = Math_fround($3 + $8);
 $10 = (($transform) + 32|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($aabb) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 * $13);
 $15 = Math_fround($9 + $14);
 $16 = (($transform) + 48|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 + $15);
 $19 = (($transform) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($2 * $20);
 $22 = (($transform) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($7 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (($transform) + 36|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($13 * $27);
 $29 = Math_fround($25 + $28);
 $30 = (($transform) + 52|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 + $29);
 $33 = (($transform) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($2 * $34);
 $36 = (($transform) + 24|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($7 * $37);
 $39 = Math_fround($35 + $38);
 $40 = (($transform) + 40|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($13 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (($transform) + 56|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 + $43);
 HEAPF32[$result>>2] = $18;
 $47 = (($result) + 4|0);
 HEAPF32[$47>>2] = $32;
 $48 = (($result) + 8|0);
 HEAPF32[$48>>2] = $46;
 $49 = (($result) + 12|0);
 ;HEAP32[$49+0>>2]=HEAP32[$extents+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$extents+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$extents+8>>2]|0;
 STACKTOP = sp;return;
}
function __Z13RotateExtentsRK8Vector3fRK10Matrix4x4f($agg$result,$extents,$rotation) {
 $agg$result = $agg$result|0;
 $extents = $extents|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $0 = (($agg$result) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($agg$result) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = Math_fround(HEAPF32[$extents>>2]);
 $3 = (($extents) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($extents) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$rotation>>2]);
 $8 = Math_fround($7 * $2);
 $9 = $8 < Math_fround(0.0);
 if ($9) {
  $10 = Math_fround(-$8);
  $18 = $10;
 } else {
  $18 = $8;
 }
 $11 = (($rotation) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $4);
 $14 = $13 < Math_fround(0.0);
 if ($14) {
  $15 = Math_fround(-$13);
  $17 = $15;
 } else {
  $17 = $13;
 }
 $16 = Math_fround($18 + $17);
 $19 = (($rotation) + 32|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $6);
 $22 = $21 < Math_fround(0.0);
 if ($22) {
  $23 = Math_fround(-$21);
  $25 = $23;
 } else {
  $25 = $21;
 }
 $24 = Math_fround($16 + $25);
 HEAPF32[$agg$result>>2] = $24;
 $26 = (($rotation) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 * $2);
 $29 = $28 < Math_fround(0.0);
 if ($29) {
  $30 = Math_fround(-$28);
  $38 = $30;
 } else {
  $38 = $28;
 }
 $31 = (($rotation) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $4);
 $34 = $33 < Math_fround(0.0);
 if ($34) {
  $35 = Math_fround(-$33);
  $37 = $35;
 } else {
  $37 = $33;
 }
 $36 = Math_fround($38 + $37);
 $39 = (($rotation) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($40 * $6);
 $42 = $41 < Math_fround(0.0);
 if ($42) {
  $43 = Math_fround(-$41);
  $45 = $43;
 } else {
  $45 = $41;
 }
 $44 = Math_fround($36 + $45);
 $46 = (($agg$result) + 4|0);
 HEAPF32[$46>>2] = $44;
 $47 = (($rotation) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($48 * $2);
 $50 = $49 < Math_fround(0.0);
 if ($50) {
  $51 = Math_fround(-$49);
  $59 = $51;
 } else {
  $59 = $49;
 }
 $52 = (($rotation) + 24|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 * $4);
 $55 = $54 < Math_fround(0.0);
 if ($55) {
  $56 = Math_fround(-$54);
  $58 = $56;
 } else {
  $58 = $54;
 }
 $57 = Math_fround($59 + $58);
 $60 = (($rotation) + 40|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 * $6);
 $63 = $62 < Math_fround(0.0);
 if (!($63)) {
  $66 = $62;
  $65 = Math_fround($57 + $66);
  $67 = (($agg$result) + 8|0);
  HEAPF32[$67>>2] = $65;
  STACKTOP = sp;return;
 }
 $64 = Math_fround(-$62);
 $66 = $64;
 $65 = Math_fround($57 + $66);
 $67 = (($agg$result) + 8|0);
 HEAPF32[$67>>2] = $65;
 STACKTOP = sp;return;
}
function __Z17TransformAABBSlowRK4AABBRK10Matrix4x4fRS_($aabb,$transform,$result) {
 $aabb = $aabb|0;
 $transform = $transform|0;
 $result = $result|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $exitcond = 0, $i$06 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $v = sp;
 $0 = Math_fround(HEAPF32[616664>>2]);
 $1 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $2 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $3 = Math_fround(-$1);
 $4 = (($v) + 16|0);
 ;HEAP32[$v+0>>2]=0|0;HEAP32[$v+4>>2]=0|0;HEAP32[$v+8>>2]=0|0;HEAP32[$v+12>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($v) + 20|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($v) + 24|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($v) + 28|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($v) + 32|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($v) + 36|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($v) + 40|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($v) + 44|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($v) + 48|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($v) + 52|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($v) + 56|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($v) + 60|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($v) + 64|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($v) + 68|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($v) + 72|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($v) + 76|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($v) + 80|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($v) + 84|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($v) + 88|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($v) + 92|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = Math_fround(-$0);
 $25 = Math_fround(-$2);
 __ZNK4AABB11GetVerticesEP8Vector3f($aabb,$v);
 $26 = Math_fround(HEAPF32[$transform>>2]);
 $27 = (($transform) + 16|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($transform) + 32|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($transform) + 48|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($transform) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($transform) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($transform) + 36|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($transform) + 52|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($transform) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($transform) + 24|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($transform) + 40|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($transform) + 56|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $74 = $0;$77 = $1;$80 = $2;$83 = $24;$86 = $3;$89 = $25;$i$06 = 0;
 while(1) {
  $49 = (($v) + (($i$06*12)|0)|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($26 * $50);
  $52 = ((($v) + (($i$06*12)|0)|0) + 4|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($28 * $53);
  $55 = Math_fround($51 + $54);
  $56 = ((($v) + (($i$06*12)|0)|0) + 8|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($30 * $57);
  $59 = Math_fround($55 + $58);
  $60 = Math_fround($32 + $59);
  $61 = Math_fround($50 * $34);
  $62 = Math_fround($53 * $36);
  $63 = Math_fround($61 + $62);
  $64 = Math_fround($57 * $38);
  $65 = Math_fround($63 + $64);
  $66 = Math_fround($40 + $65);
  $67 = Math_fround($50 * $42);
  $68 = Math_fround($53 * $44);
  $69 = Math_fround($67 + $68);
  $70 = Math_fround($57 * $46);
  $71 = Math_fround($69 + $70);
  $72 = Math_fround($48 + $71);
  $73 = $60 < $74;
  $75 = $73 ? $60 : $74;
  $76 = $66 < $77;
  $78 = $76 ? $66 : $77;
  $79 = $72 < $80;
  $81 = $79 ? $72 : $80;
  $82 = $83 < $60;
  $84 = $82 ? $60 : $83;
  $85 = $86 < $66;
  $87 = $85 ? $66 : $86;
  $88 = $89 < $72;
  $90 = $88 ? $72 : $89;
  $91 = (($i$06) + 1)|0;
  $exitcond = ($91|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $74 = $75;$77 = $78;$80 = $81;$83 = $84;$86 = $87;$89 = $90;$i$06 = $91;
  }
 }
 $92 = Math_fround($84 + $75);
 $93 = Math_fround($87 + $78);
 $94 = Math_fround($90 + $81);
 $95 = Math_fround($92 * Math_fround(0.5));
 $96 = Math_fround($93 * Math_fround(0.5));
 $97 = Math_fround($94 * Math_fround(0.5));
 HEAPF32[$result>>2] = $95;
 $98 = (($result) + 4|0);
 HEAPF32[$98>>2] = $96;
 $99 = (($result) + 8|0);
 HEAPF32[$99>>2] = $97;
 $100 = Math_fround($84 - $75);
 $101 = Math_fround($87 - $78);
 $102 = Math_fround($90 - $81);
 $103 = Math_fround($100 * Math_fround(0.5));
 $104 = Math_fround($101 * Math_fround(0.5));
 $105 = Math_fround($102 * Math_fround(0.5));
 $106 = (($result) + 12|0);
 HEAPF32[$106>>2] = $103;
 $107 = (($result) + 16|0);
 HEAPF32[$107>>2] = $104;
 $108 = (($result) + 20|0);
 HEAPF32[$108>>2] = $105;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a3708() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[590472+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[590472+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[590472+8>>2]=HEAP32[616680+8>>2]|0;
 ;HEAP32[((590472 + 12|0))+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[((590472 + 12|0))+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[((590472 + 12|0))+8>>2]=HEAP32[616680+8>>2]|0;
 STACKTOP = sp;return;
}
function __Z18CalculateLocalAABBRN5Unity10GameObjectEP4AABB($go,$aabb) {
 $go = $go|0;
 $aabb = $aabb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $rendererLocalToTransformLocal = 0, $transformWorldToLocal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $transformWorldToLocal = sp + 64|0;
 $rendererLocalToTransformLocal = sp;
 $0 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($go,25)|0);
 $1 = ($0|0)==(0|0);
 do {
  if (!($1)) {
   $2 = (($0) + 28|0);
   $3 = (($0) + 76|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   $6 = (($2) + 49|0);
   if ($5) {
    $7 = HEAP8[$6>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if (!($8)) {
     label = 4;
    }
   } else {
    label = 4;
   }
   if ((label|0) == 4) {
    $9 = HEAP32[$2>>2]|0;
    $10 = (($9) + 20|0);
    $11 = HEAP32[$10>>2]|0;
    FUNCTION_TABLE_vi[$11 & 4095]($2);
    HEAP8[$3>>0] = 0;
    HEAP8[$6>>0] = 0;
   }
   $12 = (($0) + 80|0);
   $13 = (($12) + 88|0);
   $14 = (($12) + 100|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround(HEAPF32[616680>>2]);
   $17 = $15 != $16;
   if (!($17)) {
    $18 = (($12) + 104|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
    $21 = $19 != $20;
    if (!($21)) {
     $22 = (($12) + 108|0);
     $23 = Math_fround(HEAPF32[$22>>2]);
     $24 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
     $25 = $23 != $24;
     if (!($25)) {
      break;
     }
    }
   }
   $26 = (($0) + 24|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($27)|0);
   __ZNK9Transform21GetWorldToLocalMatrixEv($transformWorldToLocal,$28);
   __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($transformWorldToLocal,$12,$rendererLocalToTransformLocal);
   __Z13TransformAABBRK4AABBRK10Matrix4x4fRS_($13,$rendererLocalToTransformLocal,$aabb);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 ;HEAP32[$aabb+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$aabb+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$aabb+8>>2]=HEAP32[616680+8>>2]|0;
 $29 = (($aabb) + 12|0);
 ;HEAP32[$29+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[616680+8>>2]|0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __Z16GetFrustumPointsRK10Matrix4x4fP8Vector3f($clipToWorld,$frustum) {
 $clipToWorld = $clipToWorld|0;
 $frustum = $frustum|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0;
 var $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = Math_fround(0), $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0);
 var $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $1 = Math_fround($0 * Math_fround(-1.0));
 $2 = (($clipToWorld) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(-1.0));
 $5 = Math_fround($1 + $4);
 $6 = (($clipToWorld) + 32|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(-1.0));
 $9 = Math_fround($5 + $8);
 $10 = (($clipToWorld) + 48|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 + $9);
 $13 = (($clipToWorld) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * Math_fround(-1.0));
 $16 = (($clipToWorld) + 20|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * Math_fround(-1.0));
 $19 = Math_fround($15 + $18);
 $20 = (($clipToWorld) + 36|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * Math_fround(-1.0));
 $23 = Math_fround($19 + $22);
 $24 = (($clipToWorld) + 52|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 + $23);
 $27 = (($clipToWorld) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * Math_fround(-1.0));
 $30 = (($clipToWorld) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * Math_fround(-1.0));
 $33 = Math_fround($29 + $32);
 $34 = (($clipToWorld) + 40|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * Math_fround(-1.0));
 $37 = Math_fround($33 + $36);
 $38 = (($clipToWorld) + 56|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 + $37);
 $41 = (($clipToWorld) + 12|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($42 * Math_fround(-1.0));
 $44 = (($clipToWorld) + 28|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 * Math_fround(-1.0));
 $47 = Math_fround($43 + $46);
 $48 = (($clipToWorld) + 44|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * Math_fround(-1.0));
 $51 = Math_fround($47 + $50);
 $52 = (($clipToWorld) + 60|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 + $51);
 $55 = $54 < Math_fround(0.0);
 if ($55) {
  $56 = Math_fround(-$54);
  $58 = $56;
 } else {
  $58 = $54;
 }
 $57 = $58 > Math_fround(1.00000001168609742308E-7);
 if ($57) {
  $59 = Math_fround(Math_fround(1.0) / $54);
  $60 = Math_fround($12 * $59);
  HEAPF32[$frustum>>2] = $60;
  $61 = Math_fround($26 * $59);
  $62 = (($frustum) + 4|0);
  HEAPF32[$62>>2] = $61;
  $63 = Math_fround($40 * $59);
  $64 = (($frustum) + 8|0);
  HEAPF32[$64>>2] = $63;
 } else {
  HEAPF32[$frustum>>2] = Math_fround(0.0);
  $65 = (($frustum) + 4|0);
  HEAPF32[$65>>2] = Math_fround(0.0);
  $66 = (($frustum) + 8|0);
  HEAPF32[$66>>2] = Math_fround(0.0);
 }
 $67 = (($frustum) + 12|0);
 $68 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $69 = Math_fround(HEAPF32[$2>>2]);
 $70 = Math_fround($69 * Math_fround(-1.0));
 $71 = Math_fround($68 + $70);
 $72 = Math_fround(HEAPF32[$6>>2]);
 $73 = Math_fround($72 * Math_fround(-1.0));
 $74 = Math_fround($71 + $73);
 $75 = Math_fround(HEAPF32[$10>>2]);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround(HEAPF32[$13>>2]);
 $78 = Math_fround(HEAPF32[$16>>2]);
 $79 = Math_fround($78 * Math_fround(-1.0));
 $80 = Math_fround($77 + $79);
 $81 = Math_fround(HEAPF32[$20>>2]);
 $82 = Math_fround($81 * Math_fround(-1.0));
 $83 = Math_fround($80 + $82);
 $84 = Math_fround(HEAPF32[$24>>2]);
 $85 = Math_fround($84 + $83);
 $86 = Math_fround(HEAPF32[$27>>2]);
 $87 = Math_fround(HEAPF32[$30>>2]);
 $88 = Math_fround($87 * Math_fround(-1.0));
 $89 = Math_fround($86 + $88);
 $90 = Math_fround(HEAPF32[$34>>2]);
 $91 = Math_fround($90 * Math_fround(-1.0));
 $92 = Math_fround($89 + $91);
 $93 = Math_fround(HEAPF32[$38>>2]);
 $94 = Math_fround($93 + $92);
 $95 = Math_fround(HEAPF32[$41>>2]);
 $96 = Math_fround(HEAPF32[$44>>2]);
 $97 = Math_fround($96 * Math_fround(-1.0));
 $98 = Math_fround($95 + $97);
 $99 = Math_fround(HEAPF32[$48>>2]);
 $100 = Math_fround($99 * Math_fround(-1.0));
 $101 = Math_fround($98 + $100);
 $102 = Math_fround(HEAPF32[$52>>2]);
 $103 = Math_fround($102 + $101);
 $104 = $103 < Math_fround(0.0);
 if ($104) {
  $105 = Math_fround(-$103);
  $107 = $105;
 } else {
  $107 = $103;
 }
 $106 = $107 > Math_fround(1.00000001168609742308E-7);
 if ($106) {
  $108 = Math_fround(Math_fround(1.0) / $103);
  $109 = Math_fround($76 * $108);
  HEAPF32[$67>>2] = $109;
  $110 = Math_fround($85 * $108);
  $111 = (($frustum) + 16|0);
  HEAPF32[$111>>2] = $110;
  $112 = Math_fround($94 * $108);
  $113 = (($frustum) + 20|0);
  HEAPF32[$113>>2] = $112;
 } else {
  HEAPF32[$67>>2] = Math_fround(0.0);
  $114 = (($frustum) + 16|0);
  HEAPF32[$114>>2] = Math_fround(0.0);
  $115 = (($frustum) + 20|0);
  HEAPF32[$115>>2] = Math_fround(0.0);
 }
 $116 = (($frustum) + 24|0);
 $117 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $118 = Math_fround(HEAPF32[$2>>2]);
 $119 = Math_fround($117 + $118);
 $120 = Math_fround(HEAPF32[$6>>2]);
 $121 = Math_fround($120 * Math_fround(-1.0));
 $122 = Math_fround($119 + $121);
 $123 = Math_fround(HEAPF32[$10>>2]);
 $124 = Math_fround($123 + $122);
 $125 = Math_fround(HEAPF32[$13>>2]);
 $126 = Math_fround(HEAPF32[$16>>2]);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround(HEAPF32[$20>>2]);
 $129 = Math_fround($128 * Math_fround(-1.0));
 $130 = Math_fround($127 + $129);
 $131 = Math_fround(HEAPF32[$24>>2]);
 $132 = Math_fround($131 + $130);
 $133 = Math_fround(HEAPF32[$27>>2]);
 $134 = Math_fround(HEAPF32[$30>>2]);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround(HEAPF32[$34>>2]);
 $137 = Math_fround($136 * Math_fround(-1.0));
 $138 = Math_fround($135 + $137);
 $139 = Math_fround(HEAPF32[$38>>2]);
 $140 = Math_fround($139 + $138);
 $141 = Math_fround(HEAPF32[$41>>2]);
 $142 = Math_fround(HEAPF32[$44>>2]);
 $143 = Math_fround($141 + $142);
 $144 = Math_fround(HEAPF32[$48>>2]);
 $145 = Math_fround($144 * Math_fround(-1.0));
 $146 = Math_fround($143 + $145);
 $147 = Math_fround(HEAPF32[$52>>2]);
 $148 = Math_fround($147 + $146);
 $149 = $148 < Math_fround(0.0);
 if ($149) {
  $150 = Math_fround(-$148);
  $152 = $150;
 } else {
  $152 = $148;
 }
 $151 = $152 > Math_fround(1.00000001168609742308E-7);
 if ($151) {
  $153 = Math_fround(Math_fround(1.0) / $148);
  $154 = Math_fround($124 * $153);
  HEAPF32[$116>>2] = $154;
  $155 = Math_fround($132 * $153);
  $156 = (($frustum) + 28|0);
  HEAPF32[$156>>2] = $155;
  $157 = Math_fround($140 * $153);
  $158 = (($frustum) + 32|0);
  HEAPF32[$158>>2] = $157;
 } else {
  HEAPF32[$116>>2] = Math_fround(0.0);
  $159 = (($frustum) + 28|0);
  HEAPF32[$159>>2] = Math_fround(0.0);
  $160 = (($frustum) + 32|0);
  HEAPF32[$160>>2] = Math_fround(0.0);
 }
 $161 = (($frustum) + 36|0);
 $162 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $163 = Math_fround($162 * Math_fround(-1.0));
 $164 = Math_fround(HEAPF32[$2>>2]);
 $165 = Math_fround($163 + $164);
 $166 = Math_fround(HEAPF32[$6>>2]);
 $167 = Math_fround($166 * Math_fround(-1.0));
 $168 = Math_fround($165 + $167);
 $169 = Math_fround(HEAPF32[$10>>2]);
 $170 = Math_fround($169 + $168);
 $171 = Math_fround(HEAPF32[$13>>2]);
 $172 = Math_fround($171 * Math_fround(-1.0));
 $173 = Math_fround(HEAPF32[$16>>2]);
 $174 = Math_fround($172 + $173);
 $175 = Math_fround(HEAPF32[$20>>2]);
 $176 = Math_fround($175 * Math_fround(-1.0));
 $177 = Math_fround($174 + $176);
 $178 = Math_fround(HEAPF32[$24>>2]);
 $179 = Math_fround($178 + $177);
 $180 = Math_fround(HEAPF32[$27>>2]);
 $181 = Math_fround($180 * Math_fround(-1.0));
 $182 = Math_fround(HEAPF32[$30>>2]);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround(HEAPF32[$34>>2]);
 $185 = Math_fround($184 * Math_fround(-1.0));
 $186 = Math_fround($183 + $185);
 $187 = Math_fround(HEAPF32[$38>>2]);
 $188 = Math_fround($187 + $186);
 $189 = Math_fround(HEAPF32[$41>>2]);
 $190 = Math_fround($189 * Math_fround(-1.0));
 $191 = Math_fround(HEAPF32[$44>>2]);
 $192 = Math_fround($190 + $191);
 $193 = Math_fround(HEAPF32[$48>>2]);
 $194 = Math_fround($193 * Math_fround(-1.0));
 $195 = Math_fround($192 + $194);
 $196 = Math_fround(HEAPF32[$52>>2]);
 $197 = Math_fround($196 + $195);
 $198 = $197 < Math_fround(0.0);
 if ($198) {
  $199 = Math_fround(-$197);
  $201 = $199;
 } else {
  $201 = $197;
 }
 $200 = $201 > Math_fround(1.00000001168609742308E-7);
 if ($200) {
  $202 = Math_fround(Math_fround(1.0) / $197);
  $203 = Math_fround($170 * $202);
  HEAPF32[$161>>2] = $203;
  $204 = Math_fround($179 * $202);
  $205 = (($frustum) + 40|0);
  HEAPF32[$205>>2] = $204;
  $206 = Math_fround($188 * $202);
  $207 = (($frustum) + 44|0);
  HEAPF32[$207>>2] = $206;
 } else {
  HEAPF32[$161>>2] = Math_fround(0.0);
  $208 = (($frustum) + 40|0);
  HEAPF32[$208>>2] = Math_fround(0.0);
  $209 = (($frustum) + 44|0);
  HEAPF32[$209>>2] = Math_fround(0.0);
 }
 $210 = (($frustum) + 48|0);
 $211 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $212 = Math_fround($211 * Math_fround(-1.0));
 $213 = Math_fround(HEAPF32[$2>>2]);
 $214 = Math_fround($213 * Math_fround(-1.0));
 $215 = Math_fround($212 + $214);
 $216 = Math_fround(HEAPF32[$6>>2]);
 $217 = Math_fround($216 + $215);
 $218 = Math_fround(HEAPF32[$10>>2]);
 $219 = Math_fround($218 + $217);
 $220 = Math_fround(HEAPF32[$13>>2]);
 $221 = Math_fround($220 * Math_fround(-1.0));
 $222 = Math_fround(HEAPF32[$16>>2]);
 $223 = Math_fround($222 * Math_fround(-1.0));
 $224 = Math_fround($221 + $223);
 $225 = Math_fround(HEAPF32[$20>>2]);
 $226 = Math_fround($225 + $224);
 $227 = Math_fround(HEAPF32[$24>>2]);
 $228 = Math_fround($227 + $226);
 $229 = Math_fround(HEAPF32[$27>>2]);
 $230 = Math_fround($229 * Math_fround(-1.0));
 $231 = Math_fround(HEAPF32[$30>>2]);
 $232 = Math_fround($231 * Math_fround(-1.0));
 $233 = Math_fround($230 + $232);
 $234 = Math_fround(HEAPF32[$34>>2]);
 $235 = Math_fround($234 + $233);
 $236 = Math_fround(HEAPF32[$38>>2]);
 $237 = Math_fround($236 + $235);
 $238 = Math_fround(HEAPF32[$41>>2]);
 $239 = Math_fround($238 * Math_fround(-1.0));
 $240 = Math_fround(HEAPF32[$44>>2]);
 $241 = Math_fround($240 * Math_fround(-1.0));
 $242 = Math_fround($239 + $241);
 $243 = Math_fround(HEAPF32[$48>>2]);
 $244 = Math_fround($243 + $242);
 $245 = Math_fround(HEAPF32[$52>>2]);
 $246 = Math_fround($245 + $244);
 $247 = $246 < Math_fround(0.0);
 if ($247) {
  $248 = Math_fround(-$246);
  $250 = $248;
 } else {
  $250 = $246;
 }
 $249 = $250 > Math_fround(1.00000001168609742308E-7);
 if ($249) {
  $251 = Math_fround(Math_fround(1.0) / $246);
  $252 = Math_fround($219 * $251);
  HEAPF32[$210>>2] = $252;
  $253 = Math_fround($228 * $251);
  $254 = (($frustum) + 52|0);
  HEAPF32[$254>>2] = $253;
  $255 = Math_fround($237 * $251);
  $256 = (($frustum) + 56|0);
  HEAPF32[$256>>2] = $255;
 } else {
  HEAPF32[$210>>2] = Math_fround(0.0);
  $257 = (($frustum) + 52|0);
  HEAPF32[$257>>2] = Math_fround(0.0);
  $258 = (($frustum) + 56|0);
  HEAPF32[$258>>2] = Math_fround(0.0);
 }
 $259 = (($frustum) + 60|0);
 $260 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $261 = Math_fround(HEAPF32[$2>>2]);
 $262 = Math_fround($261 * Math_fround(-1.0));
 $263 = Math_fround($260 + $262);
 $264 = Math_fround(HEAPF32[$6>>2]);
 $265 = Math_fround($264 + $263);
 $266 = Math_fround(HEAPF32[$10>>2]);
 $267 = Math_fround($266 + $265);
 $268 = Math_fround(HEAPF32[$13>>2]);
 $269 = Math_fround(HEAPF32[$16>>2]);
 $270 = Math_fround($269 * Math_fround(-1.0));
 $271 = Math_fround($268 + $270);
 $272 = Math_fround(HEAPF32[$20>>2]);
 $273 = Math_fround($272 + $271);
 $274 = Math_fround(HEAPF32[$24>>2]);
 $275 = Math_fround($274 + $273);
 $276 = Math_fround(HEAPF32[$27>>2]);
 $277 = Math_fround(HEAPF32[$30>>2]);
 $278 = Math_fround($277 * Math_fround(-1.0));
 $279 = Math_fround($276 + $278);
 $280 = Math_fround(HEAPF32[$34>>2]);
 $281 = Math_fround($280 + $279);
 $282 = Math_fround(HEAPF32[$38>>2]);
 $283 = Math_fround($282 + $281);
 $284 = Math_fround(HEAPF32[$41>>2]);
 $285 = Math_fround(HEAPF32[$44>>2]);
 $286 = Math_fround($285 * Math_fround(-1.0));
 $287 = Math_fround($284 + $286);
 $288 = Math_fround(HEAPF32[$48>>2]);
 $289 = Math_fround($288 + $287);
 $290 = Math_fround(HEAPF32[$52>>2]);
 $291 = Math_fround($290 + $289);
 $292 = $291 < Math_fround(0.0);
 if ($292) {
  $293 = Math_fround(-$291);
  $295 = $293;
 } else {
  $295 = $291;
 }
 $294 = $295 > Math_fround(1.00000001168609742308E-7);
 if ($294) {
  $296 = Math_fround(Math_fround(1.0) / $291);
  $297 = Math_fround($267 * $296);
  HEAPF32[$259>>2] = $297;
  $298 = Math_fround($275 * $296);
  $299 = (($frustum) + 64|0);
  HEAPF32[$299>>2] = $298;
  $300 = Math_fround($283 * $296);
  $301 = (($frustum) + 68|0);
  HEAPF32[$301>>2] = $300;
 } else {
  HEAPF32[$259>>2] = Math_fround(0.0);
  $302 = (($frustum) + 64|0);
  HEAPF32[$302>>2] = Math_fround(0.0);
  $303 = (($frustum) + 68|0);
  HEAPF32[$303>>2] = Math_fround(0.0);
 }
 $304 = (($frustum) + 72|0);
 $305 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $306 = Math_fround(HEAPF32[$2>>2]);
 $307 = Math_fround($305 + $306);
 $308 = Math_fround(HEAPF32[$6>>2]);
 $309 = Math_fround($307 + $308);
 $310 = Math_fround(HEAPF32[$10>>2]);
 $311 = Math_fround($310 + $309);
 $312 = Math_fround(HEAPF32[$13>>2]);
 $313 = Math_fround(HEAPF32[$16>>2]);
 $314 = Math_fround($312 + $313);
 $315 = Math_fround(HEAPF32[$20>>2]);
 $316 = Math_fround($314 + $315);
 $317 = Math_fround(HEAPF32[$24>>2]);
 $318 = Math_fround($317 + $316);
 $319 = Math_fround(HEAPF32[$27>>2]);
 $320 = Math_fround(HEAPF32[$30>>2]);
 $321 = Math_fround($319 + $320);
 $322 = Math_fround(HEAPF32[$34>>2]);
 $323 = Math_fround($321 + $322);
 $324 = Math_fround(HEAPF32[$38>>2]);
 $325 = Math_fround($324 + $323);
 $326 = Math_fround(HEAPF32[$41>>2]);
 $327 = Math_fround(HEAPF32[$44>>2]);
 $328 = Math_fround($326 + $327);
 $329 = Math_fround(HEAPF32[$48>>2]);
 $330 = Math_fround($328 + $329);
 $331 = Math_fround(HEAPF32[$52>>2]);
 $332 = Math_fround($331 + $330);
 $333 = $332 < Math_fround(0.0);
 if ($333) {
  $334 = Math_fround(-$332);
  $336 = $334;
 } else {
  $336 = $332;
 }
 $335 = $336 > Math_fround(1.00000001168609742308E-7);
 if ($335) {
  $337 = Math_fround(Math_fround(1.0) / $332);
  $338 = Math_fround($311 * $337);
  HEAPF32[$304>>2] = $338;
  $339 = Math_fround($318 * $337);
  $340 = (($frustum) + 76|0);
  HEAPF32[$340>>2] = $339;
  $341 = Math_fround($325 * $337);
  $342 = (($frustum) + 80|0);
  HEAPF32[$342>>2] = $341;
 } else {
  HEAPF32[$304>>2] = Math_fround(0.0);
  $343 = (($frustum) + 76|0);
  HEAPF32[$343>>2] = Math_fround(0.0);
  $344 = (($frustum) + 80|0);
  HEAPF32[$344>>2] = Math_fround(0.0);
 }
 $345 = (($frustum) + 84|0);
 $346 = Math_fround(HEAPF32[$clipToWorld>>2]);
 $347 = Math_fround($346 * Math_fround(-1.0));
 $348 = Math_fround(HEAPF32[$2>>2]);
 $349 = Math_fround($347 + $348);
 $350 = Math_fround(HEAPF32[$6>>2]);
 $351 = Math_fround($349 + $350);
 $352 = Math_fround(HEAPF32[$10>>2]);
 $353 = Math_fround($352 + $351);
 $354 = Math_fround(HEAPF32[$13>>2]);
 $355 = Math_fround($354 * Math_fround(-1.0));
 $356 = Math_fround(HEAPF32[$16>>2]);
 $357 = Math_fround($355 + $356);
 $358 = Math_fround(HEAPF32[$20>>2]);
 $359 = Math_fround($357 + $358);
 $360 = Math_fround(HEAPF32[$24>>2]);
 $361 = Math_fround($360 + $359);
 $362 = Math_fround(HEAPF32[$27>>2]);
 $363 = Math_fround($362 * Math_fround(-1.0));
 $364 = Math_fround(HEAPF32[$30>>2]);
 $365 = Math_fround($363 + $364);
 $366 = Math_fround(HEAPF32[$34>>2]);
 $367 = Math_fround($365 + $366);
 $368 = Math_fround(HEAPF32[$38>>2]);
 $369 = Math_fround($368 + $367);
 $370 = Math_fround(HEAPF32[$41>>2]);
 $371 = Math_fround($370 * Math_fround(-1.0));
 $372 = Math_fround(HEAPF32[$44>>2]);
 $373 = Math_fround($371 + $372);
 $374 = Math_fround(HEAPF32[$48>>2]);
 $375 = Math_fround($373 + $374);
 $376 = Math_fround(HEAPF32[$52>>2]);
 $377 = Math_fround($376 + $375);
 $378 = $377 < Math_fround(0.0);
 if ($378) {
  $379 = Math_fround(-$377);
  $381 = $379;
 } else {
  $381 = $377;
 }
 $380 = $381 > Math_fround(1.00000001168609742308E-7);
 if ($380) {
  $382 = Math_fround(Math_fround(1.0) / $377);
  $383 = Math_fround($353 * $382);
  HEAPF32[$345>>2] = $383;
  $384 = Math_fround($361 * $382);
  $385 = (($frustum) + 88|0);
  HEAPF32[$385>>2] = $384;
  $386 = Math_fround($369 * $382);
  $387 = (($frustum) + 92|0);
  HEAPF32[$387>>2] = $386;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$345>>2] = Math_fround(0.0);
  $388 = (($frustum) + 88|0);
  HEAPF32[$388>>2] = Math_fround(0.0);
  $389 = (($frustum) + 92|0);
  HEAPF32[$389>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __Z17GetFrustumPortionPK8Vector3fffPS_($frustum,$nearSplit,$farSplit,$outPortion) {
 $frustum = $frustum|0;
 $nearSplit = Math_fround($nearSplit);
 $farSplit = Math_fround($farSplit);
 $outPortion = $outPortion|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0);
 var $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($frustum) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * $nearSplit);
 $3 = (($frustum) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $nearSplit);
 $6 = (($frustum) + 56|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $nearSplit);
 $9 = Math_fround(Math_fround(1.0) - $nearSplit);
 $10 = Math_fround(HEAPF32[$frustum>>2]);
 $11 = Math_fround($9 * $10);
 $12 = (($frustum) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($9 * $13);
 $15 = (($frustum) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($9 * $16);
 $18 = Math_fround($2 + $11);
 $19 = Math_fround($5 + $14);
 $20 = Math_fround($8 + $17);
 HEAPF32[$outPortion>>2] = $18;
 $21 = (($outPortion) + 4|0);
 HEAPF32[$21>>2] = $19;
 $22 = (($outPortion) + 8|0);
 HEAPF32[$22>>2] = $20;
 $23 = (($frustum) + 60|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 * $nearSplit);
 $26 = (($frustum) + 64|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 * $nearSplit);
 $29 = (($frustum) + 68|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $nearSplit);
 $32 = (($frustum) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($9 * $33);
 $35 = (($frustum) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($9 * $36);
 $38 = (($frustum) + 20|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($9 * $39);
 $41 = Math_fround($25 + $34);
 $42 = Math_fround($28 + $37);
 $43 = Math_fround($31 + $40);
 $44 = (($outPortion) + 12|0);
 HEAPF32[$44>>2] = $41;
 $45 = (($outPortion) + 16|0);
 HEAPF32[$45>>2] = $42;
 $46 = (($outPortion) + 20|0);
 HEAPF32[$46>>2] = $43;
 $47 = (($frustum) + 72|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($48 * $nearSplit);
 $50 = (($frustum) + 76|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $nearSplit);
 $53 = (($frustum) + 80|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 * $nearSplit);
 $56 = (($frustum) + 24|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($9 * $57);
 $59 = (($frustum) + 28|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($9 * $60);
 $62 = (($frustum) + 32|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($9 * $63);
 $65 = Math_fround($49 + $58);
 $66 = Math_fround($52 + $61);
 $67 = Math_fround($55 + $64);
 $68 = (($outPortion) + 24|0);
 HEAPF32[$68>>2] = $65;
 $69 = (($outPortion) + 28|0);
 HEAPF32[$69>>2] = $66;
 $70 = (($outPortion) + 32|0);
 HEAPF32[$70>>2] = $67;
 $71 = (($frustum) + 84|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 * $nearSplit);
 $74 = (($frustum) + 88|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 * $nearSplit);
 $77 = (($frustum) + 92|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($78 * $nearSplit);
 $80 = (($frustum) + 36|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($9 * $81);
 $83 = (($frustum) + 40|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($9 * $84);
 $86 = (($frustum) + 44|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($9 * $87);
 $89 = Math_fround($73 + $82);
 $90 = Math_fround($76 + $85);
 $91 = Math_fround($79 + $88);
 $92 = (($outPortion) + 36|0);
 HEAPF32[$92>>2] = $89;
 $93 = (($outPortion) + 40|0);
 HEAPF32[$93>>2] = $90;
 $94 = (($outPortion) + 44|0);
 HEAPF32[$94>>2] = $91;
 $95 = Math_fround(HEAPF32[$0>>2]);
 $96 = Math_fround($95 * $farSplit);
 $97 = Math_fround(HEAPF32[$3>>2]);
 $98 = Math_fround($97 * $farSplit);
 $99 = Math_fround(HEAPF32[$6>>2]);
 $100 = Math_fround($99 * $farSplit);
 $101 = Math_fround(Math_fround(1.0) - $farSplit);
 $102 = Math_fround(HEAPF32[$frustum>>2]);
 $103 = Math_fround($101 * $102);
 $104 = Math_fround(HEAPF32[$12>>2]);
 $105 = Math_fround($101 * $104);
 $106 = Math_fround(HEAPF32[$15>>2]);
 $107 = Math_fround($101 * $106);
 $108 = Math_fround($96 + $103);
 $109 = Math_fround($98 + $105);
 $110 = Math_fround($100 + $107);
 $111 = (($outPortion) + 48|0);
 HEAPF32[$111>>2] = $108;
 $112 = (($outPortion) + 52|0);
 HEAPF32[$112>>2] = $109;
 $113 = (($outPortion) + 56|0);
 HEAPF32[$113>>2] = $110;
 $114 = Math_fround(HEAPF32[$23>>2]);
 $115 = Math_fround($114 * $farSplit);
 $116 = Math_fround(HEAPF32[$26>>2]);
 $117 = Math_fround($116 * $farSplit);
 $118 = Math_fround(HEAPF32[$29>>2]);
 $119 = Math_fround($118 * $farSplit);
 $120 = Math_fround(HEAPF32[$32>>2]);
 $121 = Math_fround($101 * $120);
 $122 = Math_fround(HEAPF32[$35>>2]);
 $123 = Math_fround($101 * $122);
 $124 = Math_fround(HEAPF32[$38>>2]);
 $125 = Math_fround($101 * $124);
 $126 = Math_fround($115 + $121);
 $127 = Math_fround($117 + $123);
 $128 = Math_fround($119 + $125);
 $129 = (($outPortion) + 60|0);
 HEAPF32[$129>>2] = $126;
 $130 = (($outPortion) + 64|0);
 HEAPF32[$130>>2] = $127;
 $131 = (($outPortion) + 68|0);
 HEAPF32[$131>>2] = $128;
 $132 = Math_fround(HEAPF32[$47>>2]);
 $133 = Math_fround($132 * $farSplit);
 $134 = Math_fround(HEAPF32[$50>>2]);
 $135 = Math_fround($134 * $farSplit);
 $136 = Math_fround(HEAPF32[$53>>2]);
 $137 = Math_fround($136 * $farSplit);
 $138 = Math_fround(HEAPF32[$56>>2]);
 $139 = Math_fround($101 * $138);
 $140 = Math_fround(HEAPF32[$59>>2]);
 $141 = Math_fround($101 * $140);
 $142 = Math_fround(HEAPF32[$62>>2]);
 $143 = Math_fround($101 * $142);
 $144 = Math_fround($133 + $139);
 $145 = Math_fround($135 + $141);
 $146 = Math_fround($137 + $143);
 $147 = (($outPortion) + 72|0);
 HEAPF32[$147>>2] = $144;
 $148 = (($outPortion) + 76|0);
 HEAPF32[$148>>2] = $145;
 $149 = (($outPortion) + 80|0);
 HEAPF32[$149>>2] = $146;
 $150 = Math_fround(HEAPF32[$71>>2]);
 $151 = Math_fround($150 * $farSplit);
 $152 = Math_fround(HEAPF32[$74>>2]);
 $153 = Math_fround($152 * $farSplit);
 $154 = Math_fround(HEAPF32[$77>>2]);
 $155 = Math_fround($154 * $farSplit);
 $156 = Math_fround(HEAPF32[$80>>2]);
 $157 = Math_fround($101 * $156);
 $158 = Math_fround(HEAPF32[$83>>2]);
 $159 = Math_fround($101 * $158);
 $160 = Math_fround(HEAPF32[$86>>2]);
 $161 = Math_fround($101 * $160);
 $162 = Math_fround($151 + $157);
 $163 = Math_fround($153 + $159);
 $164 = Math_fround($155 + $161);
 $165 = (($outPortion) + 84|0);
 HEAPF32[$165>>2] = $162;
 $166 = (($outPortion) + 88|0);
 HEAPF32[$166>>2] = $163;
 $167 = (($outPortion) + 92|0);
 HEAPF32[$167>>2] = $164;
 STACKTOP = sp;return;
}
function __Z14CalcHullBoundsPK8Vector3fPKhhRK5PlaneRK10Matrix4x4fR10MinMaxAABB($hullPoints,$hullCounts,$hullFaces,$nearPlane,$cameraWorldToClip,$aabb) {
 $hullPoints = $hullPoints|0;
 $hullCounts = $hullCounts|0;
 $hullFaces = $hullFaces|0;
 $nearPlane = $nearPlane|0;
 $cameraWorldToClip = $cameraWorldToClip|0;
 $aabb = $aabb|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $f$05 = 0;
 var $i$011 = 0, $i1$01 = 0, $inputCounts$012 = 0, $inputPoints$013 = 0, $intermData = 0, $intermDataCounts = 0, $outputCounts$010 = 0, $outputCounts$14 = 0, $outputData = 0, $outputDataCounts = 0, $outputPoints$09 = 0, $outputPoints$12 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3200|0;
 $outputData = sp + 1536|0;
 $intermData = sp;
 $outputDataCounts = sp + 3136|0;
 $intermDataCounts = sp + 3072|0;
 $0 = (($outputData) + 1536|0);
 $1 = $outputData;
 while(1) {
  HEAPF32[$1>>2] = Math_fround(0.0);
  $2 = (($1) + 4|0);
  HEAPF32[$2>>2] = Math_fround(0.0);
  $3 = (($1) + 8|0);
  HEAPF32[$3>>2] = Math_fround(0.0);
  $4 = (($1) + 12|0);
  $5 = ($4|0)==($0|0);
  if ($5) {
   break;
  } else {
   $1 = $4;
  }
 }
 $6 = (($intermData) + 1536|0);
 $7 = $intermData;
 while(1) {
  HEAPF32[$7>>2] = Math_fround(0.0);
  $8 = (($7) + 4|0);
  HEAPF32[$8>>2] = Math_fround(0.0);
  $9 = (($7) + 8|0);
  HEAPF32[$9>>2] = Math_fround(0.0);
  $10 = (($7) + 12|0);
  $11 = ($10|0)==($6|0);
  if ($11) {
   break;
  } else {
   $7 = $10;
  }
 }
 HEAP8[$intermDataCounts>>0] = 0;
 $12 = $hullFaces&255;
 $13 = ($hullFaces<<24>>24)==(0);
 L7: do {
  if ($13) {
   label = 7;
  } else {
   $i$011 = 0;$inputCounts$012 = $hullCounts;$inputPoints$013 = $hullPoints;$outputCounts$010 = $outputDataCounts;$outputPoints$09 = $outputData;
   while(1) {
    $34 = (($inputCounts$012) + 1|0);
    $35 = HEAP8[$inputCounts$012>>0]|0;
    (__Z16ClipPolysByPlanehPK8Vector3fRK5PlanePhPS_S5_S6_($35,$inputPoints$013,$nearPlane,$outputCounts$010,$outputPoints$09,$intermDataCounts,$intermData)|0);
    $36 = $35&255;
    $37 = (($inputPoints$013) + (($36*12)|0)|0);
    $38 = HEAP8[$outputCounts$010>>0]|0;
    $39 = $38&255;
    $40 = (($outputPoints$09) + (($39*12)|0)|0);
    $41 = (($outputCounts$010) + 1|0);
    $42 = (($i$011) + 1)<<24>>24;
    $43 = ($42<<24>>24)==($hullFaces<<24>>24);
    if ($43) {
     break;
    } else {
     $i$011 = $42;$inputCounts$012 = $34;$inputPoints$013 = $37;$outputCounts$010 = $41;$outputPoints$09 = $40;
    }
   }
   if ($13) {
    label = 7;
   } else {
    $14 = (($cameraWorldToClip) + 16|0);
    $15 = (($cameraWorldToClip) + 32|0);
    $16 = (($cameraWorldToClip) + 48|0);
    $17 = (($cameraWorldToClip) + 4|0);
    $18 = (($cameraWorldToClip) + 20|0);
    $19 = (($cameraWorldToClip) + 36|0);
    $20 = (($cameraWorldToClip) + 52|0);
    $21 = (($cameraWorldToClip) + 8|0);
    $22 = (($cameraWorldToClip) + 24|0);
    $23 = (($cameraWorldToClip) + 40|0);
    $24 = (($cameraWorldToClip) + 56|0);
    $25 = (($cameraWorldToClip) + 12|0);
    $26 = (($cameraWorldToClip) + 28|0);
    $27 = (($cameraWorldToClip) + 44|0);
    $28 = (($cameraWorldToClip) + 60|0);
    $29 = (($aabb) + 4|0);
    $30 = (($aabb) + 8|0);
    $31 = (($aabb) + 12|0);
    $32 = (($aabb) + 16|0);
    $33 = (($aabb) + 20|0);
    $f$05 = 1;$outputCounts$14 = $outputDataCounts;$outputPoints$12 = $outputData;
    while(1) {
     $44 = (($outputCounts$14) + 1|0);
     $45 = HEAP8[$outputCounts$14>>0]|0;
     $46 = $45&255;
     $47 = ($45<<24>>24)==(0);
     if (!($47)) {
      $i1$01 = 0;
      while(1) {
       $48 = Math_fround(HEAPF32[$cameraWorldToClip>>2]);
       $49 = (($outputPoints$12) + (($i1$01*12)|0)|0);
       $50 = Math_fround(HEAPF32[$49>>2]);
       $51 = Math_fround($48 * $50);
       $52 = Math_fround(HEAPF32[$14>>2]);
       $53 = ((($outputPoints$12) + (($i1$01*12)|0)|0) + 4|0);
       $54 = Math_fround(HEAPF32[$53>>2]);
       $55 = Math_fround($52 * $54);
       $56 = Math_fround($51 + $55);
       $57 = Math_fround(HEAPF32[$15>>2]);
       $58 = ((($outputPoints$12) + (($i1$01*12)|0)|0) + 8|0);
       $59 = Math_fround(HEAPF32[$58>>2]);
       $60 = Math_fround($57 * $59);
       $61 = Math_fround($56 + $60);
       $62 = Math_fround(HEAPF32[$16>>2]);
       $63 = Math_fround($62 + $61);
       $64 = Math_fround(HEAPF32[$17>>2]);
       $65 = Math_fround($50 * $64);
       $66 = Math_fround(HEAPF32[$18>>2]);
       $67 = Math_fround($54 * $66);
       $68 = Math_fround($65 + $67);
       $69 = Math_fround(HEAPF32[$19>>2]);
       $70 = Math_fround($59 * $69);
       $71 = Math_fround($68 + $70);
       $72 = Math_fround(HEAPF32[$20>>2]);
       $73 = Math_fround($72 + $71);
       $74 = Math_fround(HEAPF32[$21>>2]);
       $75 = Math_fround($50 * $74);
       $76 = Math_fround(HEAPF32[$22>>2]);
       $77 = Math_fround($54 * $76);
       $78 = Math_fround($75 + $77);
       $79 = Math_fround(HEAPF32[$23>>2]);
       $80 = Math_fround($59 * $79);
       $81 = Math_fround($78 + $80);
       $82 = Math_fround(HEAPF32[$24>>2]);
       $83 = Math_fround($82 + $81);
       $84 = Math_fround(HEAPF32[$25>>2]);
       $85 = Math_fround($50 * $84);
       $86 = Math_fround(HEAPF32[$26>>2]);
       $87 = Math_fround($54 * $86);
       $88 = Math_fround($85 + $87);
       $89 = Math_fround(HEAPF32[$27>>2]);
       $90 = Math_fround($59 * $89);
       $91 = Math_fround($88 + $90);
       $92 = Math_fround(HEAPF32[$28>>2]);
       $93 = Math_fround($92 + $91);
       $94 = $93 < Math_fround(0.0);
       if ($94) {
        $95 = Math_fround(-$93);
        $97 = $95;
       } else {
        $97 = $93;
       }
       $96 = $97 > Math_fround(1.00000001168609742308E-7);
       if ($96) {
        $98 = Math_fround(Math_fround(1.0) / $93);
        $99 = Math_fround($63 * $98);
        $100 = Math_fround($73 * $98);
        $101 = Math_fround($83 * $98);
        $104 = $99;$108 = $100;$112 = $101;
       } else {
        $104 = Math_fround(0.0);$108 = Math_fround(0.0);$112 = Math_fround(0.0);
       }
       $102 = Math_fround(HEAPF32[$aabb>>2]);
       $103 = $104 < $102;
       $105 = $103 ? $104 : $102;
       $106 = Math_fround(HEAPF32[$29>>2]);
       $107 = $108 < $106;
       $109 = $107 ? $108 : $106;
       $110 = Math_fround(HEAPF32[$30>>2]);
       $111 = $112 < $110;
       $113 = $111 ? $112 : $110;
       HEAPF32[$aabb>>2] = $105;
       HEAPF32[$29>>2] = $109;
       HEAPF32[$30>>2] = $113;
       $114 = Math_fround(HEAPF32[$31>>2]);
       $115 = $114 < $104;
       $116 = $115 ? $104 : $114;
       $117 = Math_fround(HEAPF32[$32>>2]);
       $118 = $117 < $108;
       $119 = $118 ? $108 : $117;
       $120 = Math_fround(HEAPF32[$33>>2]);
       $121 = $120 < $112;
       $122 = $121 ? $112 : $120;
       HEAPF32[$31>>2] = $116;
       HEAPF32[$32>>2] = $119;
       HEAPF32[$33>>2] = $122;
       $123 = (($i1$01) + 1)|0;
       $124 = ($123|0)<($46|0);
       if ($124) {
        $i1$01 = $123;
       } else {
        break;
       }
      }
     }
     $125 = ($f$05|0)<($12|0);
     if (!($125)) {
      $$pre$phiZ2D = $aabb;
      break L7;
     }
     $126 = (($outputPoints$12) + (($46*12)|0)|0);
     $phitmp = (($f$05) + 1)|0;
     $f$05 = $phitmp;$outputCounts$14 = $44;$outputPoints$12 = $126;
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $$pre$phiZ2D = $aabb;
 }
 $127 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $128 = $127 < Math_fround(-1.0);
 if ($128) {
  HEAPF32[$$pre$phiZ2D>>2] = Math_fround(-1.0);
 }
 $129 = (($aabb) + 4|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = $130 < Math_fround(-1.0);
 if ($131) {
  HEAPF32[$129>>2] = Math_fround(-1.0);
 }
 $132 = (($aabb) + 12|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = $133 > Math_fround(1.0);
 if ($134) {
  HEAPF32[$132>>2] = Math_fround(1.0);
 }
 $135 = (($aabb) + 16|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = $136 > Math_fround(1.0);
 if (!($137)) {
  STACKTOP = sp;return;
 }
 HEAPF32[$135>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __Z16ClipPolysByPlanehPK8Vector3fRK5PlanePhPS_S5_S6_($numPoints,$input,$A,$pNumOutPoints,$output,$pNumIntermPoints,$interm) {
 $numPoints = $numPoints|0;
 $input = $input|0;
 $A = $A|0;
 $pNumOutPoints = $pNumOutPoints|0;
 $output = $output|0;
 $pNumIntermPoints = $pNumIntermPoints|0;
 $interm = $interm|0;
 var $$ = 0, $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $i$09 = 0, $i$1$ph15 = 0, $i$18 = 0, $numOutPoints$0$ph$be = 0, $numOutPoints$0$ph$be$in = 0, $numOutPoints$0$ph13 = 0, $numOutPoints$0$ph14 = 0, $numOutPoints$1 = 0, $phitmp = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $temp = sp;
 $0 = $numPoints&255;
 $1 = ($numPoints&255)<(3);
 if ($1) {
  HEAP8[$pNumOutPoints>>0] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$temp>>2] = Math_fround(0.0);
 $2 = (($temp) + 4|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($temp) + 8|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = STACKTOP; STACKTOP = STACKTOP + ((((1*$0)|0)+15)&-16)|0;;
 $5 = Math_fround(HEAPF32[$A>>2]);
 $6 = (($A) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($A) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($A) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $i$09 = 0;
 while(1) {
  $12 = (($input) + (($i$09*12)|0)|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($5 * $13);
  $15 = ((($input) + (($i$09*12)|0)|0) + 4|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($7 * $16);
  $18 = Math_fround($14 + $17);
  $19 = ((($input) + (($i$09*12)|0)|0) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($9 * $20);
  $22 = Math_fround($18 + $21);
  $23 = Math_fround($11 + $22);
  $24 = $23 < Math_fround(0.0);
  $25 = (($4) + ($i$09)|0);
  $26 = $24&1;
  HEAP8[$25>>0] = $26;
  $27 = (($i$09) + 1)|0;
  $28 = ($27|0)<($0|0);
  if ($28) {
   $i$09 = $27;
  } else {
   break;
  }
 }
 $i$1$ph15 = 0;$numOutPoints$0$ph14 = 0;
 L8: while(1) {
  $i$18 = $i$1$ph15;
  while(1) {
   $29 = (($i$18) + 1)|0;
   $30 = ($29|0)<($0|0);
   $$ = $30 ? $29 : 0;
   $31 = (($4) + ($i$18)|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)==(0);
   $$phi$trans$insert = (($4) + ($$)|0);
   $$pre = HEAP8[$$phi$trans$insert>>0]|0;
   $phitmp = ($$pre<<24>>24)==(0);
   if ($33) {
    if ($phitmp) {
     label = 17;
     break;
    }
    $46 = (($input) + (($i$18*12)|0)|0);
    $47 = (($input) + (($$*12)|0)|0);
    $48 = (__Z21IntersectSegmentPlaneRK8Vector3fS1_RK5PlanePS_($46,$47,$A,$temp)|0);
    if ($48) {
     label = 16;
     break;
    }
   } else {
    if ($phitmp) {
     label = 9;
     break;
    }
   }
   if ($30) {
    $i$18 = $29;
   } else {
    $numOutPoints$0$ph13 = $numOutPoints$0$ph14;
    break L8;
   }
  }
  if ((label|0) == 9) {
   label = 0;
   $34 = (($input) + (($i$18*12)|0)|0);
   $35 = (($input) + (($$*12)|0)|0);
   $36 = (__Z21IntersectSegmentPlaneRK8Vector3fS1_RK5PlanePS_($34,$35,$A,$temp)|0);
   if ($36) {
    $37 = (($numOutPoints$0$ph14) + 1)<<24>>24;
    $38 = $numOutPoints$0$ph14&255;
    $39 = (($output) + (($38*12)|0)|0);
    ;HEAP32[$39+0>>2]=HEAP32[$temp+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$temp+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$temp+8>>2]|0;
    $40 = HEAP8[$pNumIntermPoints>>0]|0;
    $41 = (($40) + 1)<<24>>24;
    HEAP8[$pNumIntermPoints>>0] = $41;
    $42 = $40&255;
    $43 = (($interm) + (($42*12)|0)|0);
    ;HEAP32[$43+0>>2]=HEAP32[$temp+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$temp+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$temp+8>>2]|0;
    $numOutPoints$1 = $37;
   } else {
    $numOutPoints$1 = $numOutPoints$0$ph14;
   }
   $44 = $numOutPoints$1&255;
   $45 = (($output) + (($44*12)|0)|0);
   ;HEAP32[$45+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$35+8>>2]|0;
   $numOutPoints$0$ph$be$in = $numOutPoints$1;
  }
  else if ((label|0) == 16) {
   label = 0;
   $49 = $numOutPoints$0$ph14&255;
   $50 = (($output) + (($49*12)|0)|0);
   ;HEAP32[$50+0>>2]=HEAP32[$temp+0>>2]|0;HEAP32[$50+4>>2]=HEAP32[$temp+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$temp+8>>2]|0;
   $51 = HEAP8[$pNumIntermPoints>>0]|0;
   $52 = (($51) + 1)<<24>>24;
   HEAP8[$pNumIntermPoints>>0] = $52;
   $53 = $51&255;
   $54 = (($interm) + (($53*12)|0)|0);
   ;HEAP32[$54+0>>2]=HEAP32[$temp+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$temp+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$temp+8>>2]|0;
   $numOutPoints$0$ph$be$in = $numOutPoints$0$ph14;
  }
  else if ((label|0) == 17) {
   label = 0;
   $55 = $numOutPoints$0$ph14&255;
   $56 = (($output) + (($55*12)|0)|0);
   $57 = (($input) + (($$*12)|0)|0);
   ;HEAP32[$56+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$57+8>>2]|0;
   $numOutPoints$0$ph$be$in = $numOutPoints$0$ph14;
  }
  $numOutPoints$0$ph$be = (($numOutPoints$0$ph$be$in) + 1)<<24>>24;
  if ($30) {
   $i$1$ph15 = $29;$numOutPoints$0$ph14 = $numOutPoints$0$ph$be;
  } else {
   $numOutPoints$0$ph13 = $numOutPoints$0$ph$be;
   break;
  }
 }
 HEAP8[$pNumOutPoints>>0] = $numOutPoints$0$ph13;
 $58 = ($numOutPoints$0$ph13<<24>>24)!=(0);
 $$0 = $58;
 STACKTOP = sp;return ($$0|0);
}
function __Z25CalculateFocusedLightHullPK8Vector3fRS0_RK10MinMaxAABBRNSt3__16vectorIS_NS6_9allocatorIS_EEEE($frustum,$lightDir,$sceneAABB,$points) {
 $frustum = $frustum|0;
 $lightDir = $lightDir|0;
 $sceneAABB = $sceneAABB|0;
 $points = $points|0;
 var $$ph = Math_fround(0), $$ph40 = Math_fround(0), $$ph43 = Math_fround(0), $$pre$i = 0, $$pre$i1 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0;
 var $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0;
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond28 = 0, $exitcond32 = 0, $i$017 = 0, $i$19 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $inputCounts$012 = 0, $inputCounts2$08 = 0;
 var $inputPoints$014 = 0, $inputPoints1$06 = 0, $intersect$0$i = 0, $lftr$wideiv = 0, $numFaces$027 = 0, $numFaces$116 = 0, $numFaces$2 = 0, $numFaces$3 = 0, $numFaces$4 = 0, $numTotalPoints$1$lcssa = 0, $numTotalPoints$115 = 0, $numTotalPoints$2 = 0, $or$cond = 0, $outputCounts$0$lcssa = 0, $outputCounts$013 = 0, $outputCounts$1 = 0, $outputPoints$0$lcssa = 0, $outputPoints$011 = 0, $outputPoints$1 = 0, $p$025 = 0;
 var $pData = 0, $pDataCounts = 0, $planes = 0, $pt = 0, $tempCounts = 0, $tempPoints = 0, $vIn$026 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 9728|0;
 $tempPoints = sp + 128|0;
 $tempCounts = sp + 9344|0;
 $planes = sp + 16|0;
 $pData = sp + 112|0;
 $pDataCounts = sp + 120|0;
 $pt = sp;
 $0 = (($tempPoints) + 9216|0);
 $1 = $tempPoints;
 while(1) {
  HEAPF32[$1>>2] = Math_fround(0.0);
  $2 = (($1) + 4|0);
  HEAPF32[$2>>2] = Math_fround(0.0);
  $3 = (($1) + 8|0);
  HEAPF32[$3>>2] = Math_fround(0.0);
  $4 = (($1) + 12|0);
  $5 = ($4|0)==($0|0);
  if ($5) {
   break;
  } else {
   $1 = $4;
  }
 }
 $6 = (($sceneAABB) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(-$7);
 HEAPF32[$planes>>2] = Math_fround(0.0);
 $9 = (($planes) + 4|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($planes) + 8|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($planes) + 12|0);
 HEAPF32[$11>>2] = $8;
 $12 = (($sceneAABB) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($planes) + 16|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($planes) + 20|0);
 HEAPF32[$15>>2] = Math_fround(-1.0);
 $16 = (($planes) + 24|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($planes) + 28|0);
 HEAPF32[$17>>2] = $13;
 $18 = Math_fround(HEAPF32[$sceneAABB>>2]);
 $19 = Math_fround(-$18);
 $20 = (($planes) + 32|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($planes) + 36|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($planes) + 40|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($planes) + 44|0);
 HEAPF32[$23>>2] = $19;
 $24 = (($sceneAABB) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($planes) + 48|0);
 HEAPF32[$26>>2] = Math_fround(-1.0);
 $27 = (($planes) + 52|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($planes) + 56|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($planes) + 60|0);
 HEAPF32[$29>>2] = $25;
 $30 = (($sceneAABB) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround(-$31);
 $33 = (($planes) + 64|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($planes) + 68|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($planes) + 72|0);
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($planes) + 76|0);
 HEAPF32[$36>>2] = $32;
 $37 = (($sceneAABB) + 20|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($planes) + 80|0);
 HEAPF32[$39>>2] = Math_fround(0.0);
 $40 = (($planes) + 84|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($planes) + 88|0);
 HEAPF32[$41>>2] = Math_fround(-1.0);
 $42 = (($planes) + 92|0);
 HEAPF32[$42>>2] = $38;
 HEAP32[$pData>>2] = $tempPoints;
 $43 = (($pData) + 4|0);
 $44 = (($tempPoints) + 3072|0);
 HEAP32[$43>>2] = $44;
 HEAP32[$pDataCounts>>2] = $tempCounts;
 $45 = (($pDataCounts) + 4|0);
 $46 = (($tempCounts) + 128|0);
 HEAP32[$45>>2] = $46;
 ;HEAP8[$tempCounts+0>>0]=4|0;HEAP8[$tempCounts+1>>0]=4|0;HEAP8[$tempCounts+2>>0]=4|0;HEAP8[$tempCounts+3>>0]=4|0;HEAP8[$tempCounts+4>>0]=4|0;HEAP8[$tempCounts+5>>0]=4|0;
 ;HEAP32[$tempPoints+0>>2]=HEAP32[$frustum+0>>2]|0;HEAP32[$tempPoints+4>>2]=HEAP32[$frustum+4>>2]|0;HEAP32[$tempPoints+8>>2]=HEAP32[$frustum+8>>2]|0;
 $47 = (($tempPoints) + 12|0);
 $48 = (($frustum) + 12|0);
 ;HEAP32[$47+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$48+8>>2]|0;
 $49 = (($tempPoints) + 24|0);
 $50 = (($frustum) + 24|0);
 ;HEAP32[$49+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$50+8>>2]|0;
 $51 = (($tempPoints) + 36|0);
 $52 = (($frustum) + 36|0);
 ;HEAP32[$51+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$51+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$52+8>>2]|0;
 $53 = (($tempPoints) + 48|0);
 $54 = (($frustum) + 84|0);
 ;HEAP32[$53+0>>2]=HEAP32[$54+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$54+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$54+8>>2]|0;
 $55 = (($tempPoints) + 60|0);
 $56 = (($frustum) + 72|0);
 ;HEAP32[$55+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$56+8>>2]|0;
 $57 = (($tempPoints) + 72|0);
 $58 = (($frustum) + 60|0);
 ;HEAP32[$57+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$58+8>>2]|0;
 $59 = (($tempPoints) + 84|0);
 $60 = (($frustum) + 48|0);
 ;HEAP32[$59+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$60+8>>2]|0;
 $61 = (($tempPoints) + 96|0);
 ;HEAP32[$61+0>>2]=HEAP32[$frustum+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$frustum+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$frustum+8>>2]|0;
 $62 = (($tempPoints) + 108|0);
 ;HEAP32[$62+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$62+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$62+8>>2]=HEAP32[$52+8>>2]|0;
 $63 = (($tempPoints) + 120|0);
 ;HEAP32[$63+0>>2]=HEAP32[$54+0>>2]|0;HEAP32[$63+4>>2]=HEAP32[$54+4>>2]|0;HEAP32[$63+8>>2]=HEAP32[$54+8>>2]|0;
 $64 = (($tempPoints) + 132|0);
 ;HEAP32[$64+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$64+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$64+8>>2]=HEAP32[$60+8>>2]|0;
 $65 = (($tempPoints) + 144|0);
 ;HEAP32[$65+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$48+8>>2]|0;
 $66 = (($tempPoints) + 156|0);
 ;HEAP32[$66+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$58+8>>2]|0;
 $67 = (($tempPoints) + 168|0);
 ;HEAP32[$67+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$67+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$67+8>>2]=HEAP32[$56+8>>2]|0;
 $68 = (($tempPoints) + 180|0);
 ;HEAP32[$68+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$68+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$68+8>>2]=HEAP32[$50+8>>2]|0;
 $69 = (($tempPoints) + 192|0);
 ;HEAP32[$69+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$69+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$69+8>>2]=HEAP32[$60+8>>2]|0;
 $70 = (($tempPoints) + 204|0);
 ;HEAP32[$70+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$70+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$58+8>>2]|0;
 $71 = (($tempPoints) + 216|0);
 ;HEAP32[$71+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$48+8>>2]|0;
 $72 = (($tempPoints) + 228|0);
 ;HEAP32[$72+0>>2]=HEAP32[$frustum+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$frustum+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$frustum+8>>2]|0;
 $73 = (($tempPoints) + 240|0);
 ;HEAP32[$73+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$56+8>>2]|0;
 $74 = (($tempPoints) + 252|0);
 ;HEAP32[$74+0>>2]=HEAP32[$54+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$54+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$54+8>>2]|0;
 $75 = (($tempPoints) + 264|0);
 ;HEAP32[$75+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$52+8>>2]|0;
 $76 = (($tempPoints) + 276|0);
 ;HEAP32[$76+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$50+8>>2]|0;
 $77 = (($tempPoints) + 6144|0);
 $78 = (($tempCounts) + 256|0);
 $numFaces$027 = 6;$p$025 = 0;$vIn$026 = 0;
 while(1) {
  $79 = (($pData) + ($vIn$026<<2)|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (1 - ($vIn$026))|0;
  $82 = (($pData) + ($81<<2)|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($pDataCounts) + ($vIn$026<<2)|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($pDataCounts) + ($81<<2)|0);
  $87 = HEAP32[$86>>2]|0;
  HEAP8[$78>>0] = 0;
  $88 = ($numFaces$027|0)==(0);
  L6: do {
   if ($88) {
    $numFaces$3 = 0;$numTotalPoints$1$lcssa = 0;$outputCounts$0$lcssa = $87;$outputPoints$0$lcssa = $83;
   } else {
    $89 = (($planes) + ($p$025<<4)|0);
    $i$017 = 0;$inputCounts$012 = $85;$inputPoints$014 = $80;$numFaces$116 = $numFaces$027;$numTotalPoints$115 = 0;$outputCounts$013 = $87;$outputPoints$011 = $83;
    while(1) {
     $90 = HEAP8[$inputCounts$012>>0]|0;
     $91 = (__Z16ClipPolysByPlanehPK8Vector3fRK5PlanePhPS_S5_S6_($90,$inputPoints$014,$89,$outputCounts$013,$outputPoints$011,$78,$77)|0);
     if ($91) {
      $92 = (($outputCounts$013) + 1|0);
      $93 = HEAP8[$outputCounts$013>>0]|0;
      $94 = $93&255;
      $95 = (($94) + ($numTotalPoints$115))|0;
      $96 = (($outputPoints$011) + (($94*12)|0)|0);
      $numFaces$2 = $numFaces$116;$numTotalPoints$2 = $95;$outputCounts$1 = $92;$outputPoints$1 = $96;
     } else {
      $97 = (($numFaces$116) + -1)|0;
      $98 = ($97|0)==(0);
      if ($98) {
       $numFaces$3 = 0;$numTotalPoints$1$lcssa = $numTotalPoints$115;$outputCounts$0$lcssa = $outputCounts$013;$outputPoints$0$lcssa = $outputPoints$011;
       break L6;
      } else {
       $numFaces$2 = $97;$numTotalPoints$2 = $numTotalPoints$115;$outputCounts$1 = $outputCounts$013;$outputPoints$1 = $outputPoints$011;
      }
     }
     $99 = (($inputCounts$012) + 1|0);
     $100 = $90&255;
     $101 = (($inputPoints$014) + (($100*12)|0)|0);
     $102 = (($i$017) + 1)|0;
     $103 = ($102>>>0)<($numFaces$027>>>0);
     if ($103) {
      $i$017 = $102;$inputCounts$012 = $99;$inputPoints$014 = $101;$numFaces$116 = $numFaces$2;$numTotalPoints$115 = $numTotalPoints$2;$outputCounts$013 = $outputCounts$1;$outputPoints$011 = $outputPoints$1;
     } else {
      $numFaces$3 = $numFaces$2;$numTotalPoints$1$lcssa = $numTotalPoints$2;$outputCounts$0$lcssa = $outputCounts$1;$outputPoints$0$lcssa = $outputPoints$1;
      break;
     }
    }
   }
  } while(0);
  $104 = HEAP8[$78>>0]|0;
  $105 = ($104<<24>>24)!=(0);
  $106 = ($p$025|0)<(5);
  $or$cond = $105 & $106;
  if ($or$cond) {
   $107 = (($numFaces$3) + 1)|0;
   HEAP8[$outputCounts$0$lcssa>>0] = $104;
   $108 = $104&255;
   $109 = ($108*12)|0;
   _memcpy(($outputPoints$0$lcssa|0),($77|0),($109|0))|0;
   $numFaces$4 = $107;
  } else {
   $numFaces$4 = $numFaces$3;
  }
  $110 = (($p$025) + 1)|0;
  $exitcond32 = ($110|0)==(6);
  if ($exitcond32) {
   break;
  } else {
   $numFaces$027 = $numFaces$4;$p$025 = $110;$vIn$026 = $81;
  }
 }
 $111 = ($numFaces$4|0)==(0);
 if ($111) {
  STACKTOP = sp;return;
 }
 HEAPF32[$pt>>2] = Math_fround(0.0);
 $112 = (($pt) + 4|0);
 HEAPF32[$112>>2] = Math_fround(0.0);
 $113 = (($pt) + 8|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = Math_fround(HEAPF32[$lightDir>>2]);
 $115 = Math_fround(-$114);
 $116 = (($lightDir) + 4|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround(-$117);
 $119 = (($lightDir) + 8|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround(-$120);
 $122 = $numTotalPoints$1$lcssa << 1;
 $123 = (($points) + 8|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = HEAP32[$points>>2]|0;
 $126 = $124;
 $127 = $125;
 $128 = (($126) - ($127))|0;
 $129 = (($128|0) / 12)&-1;
 $130 = ($129>>>0)<($122>>>0);
 if ($130) {
  $131 = (($points) + 4|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = $132;
  $134 = (($133) - ($127))|0;
  $135 = (($134|0) / 12)&-1;
  $136 = ($122|0)==(0);
  if ($136) {
   $140 = 0;
  } else {
   $137 = ($numTotalPoints$1$lcssa*24)|0;
   $138 = (__Znwj($137)|0);
   $140 = $138;
  }
  $139 = (($140) + (($135*12)|0)|0);
  $141 = (($140) + (($122*12)|0)|0);
  $142 = (($134|0) / -12)&-1;
  $$sum$i = (($142) + ($135))|0;
  $143 = (($140) + (($$sum$i*12)|0)|0);
  _memcpy(($143|0),($125|0),($134|0))|0;
  HEAP32[$points>>2] = $143;
  HEAP32[$131>>2] = $139;
  HEAP32[$123>>2] = $141;
  $144 = ($125|0)==(0|0);
  if (!($144)) {
   __ZdlPv($125);
  }
 }
 $145 = HEAP32[$pDataCounts>>2]|0;
 $146 = HEAP32[$pData>>2]|0;
 $147 = (($points) + 4|0);
 $148 = $120 < Math_fround(-1.00000001335143196002E-10);
 $149 = $120 > Math_fround(1.00000001335143196002E-10);
 $150 = $117 < Math_fround(-1.00000001335143196002E-10);
 $151 = $117 > Math_fround(1.00000001335143196002E-10);
 $152 = $114 < Math_fround(-1.00000001335143196002E-10);
 $153 = $114 > Math_fround(1.00000001335143196002E-10);
 $i$19 = 0;$inputCounts2$08 = $145;$inputPoints1$06 = $146;
 while(1) {
  $154 = (($inputCounts2$08) + 1|0);
  $155 = HEAP8[$inputCounts2$08>>0]|0;
  $156 = ($155<<24>>24)==(0);
  if (!($156)) {
   $indvars$iv = 0;
   while(1) {
    $157 = (($inputPoints1$06) + (($indvars$iv*12)|0)|0);
    $158 = HEAP32[$147>>2]|0;
    $159 = HEAP32[$123>>2]|0;
    $160 = ($158|0)==($159|0);
    if ($160) {
     __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($points,$157);
    } else {
     $161 = ($158|0)==(0|0);
     if ($161) {
      $163 = 0;
     } else {
      ;HEAP32[$158+0>>2]=HEAP32[$157+0>>2]|0;HEAP32[$158+4>>2]=HEAP32[$157+4>>2]|0;HEAP32[$158+8>>2]=HEAP32[$157+8>>2]|0;
      $$pre$i1 = HEAP32[$147>>2]|0;
      $163 = $$pre$i1;
     }
     $162 = (($163) + 12|0);
     HEAP32[$147>>2] = $162;
    }
    $164 = ((($inputPoints1$06) + (($indvars$iv*12)|0)|0) + 8|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = Math_fround(HEAPF32[$30>>2]);
    $167 = Math_fround($165 - $166);
    do {
     if ($148) {
      $168 = Math_fround($167 / $120);
      $169 = $168 > Math_fround(1.00000001504746621988E+30);
      if (!($169)) {
       $170 = $168 > Math_fround(0.0);
       $171 = $170 ? $168 : Math_fround(0.0);
       $172 = Math_fround(HEAPF32[$37>>2]);
       $173 = Math_fround($172 - $165);
       if ($149) {
        $183 = $173;$185 = Math_fround(1.00000001504746621988E+30);$187 = $171;
        label = 34;
       } else {
        if ($148) {
         $188 = Math_fround($173 / $121);
         $189 = $188 < $171;
         if (!($189)) {
          $190 = $188 < Math_fround(1.00000001504746621988E+30);
          if ($190) {
           $199 = $188;$201 = $171;
           label = 42;
          } else {
           $199 = Math_fround(1.00000001504746621988E+30);$201 = $171;
           label = 42;
          }
         }
        } else {
         $192 = $173;$282 = $171;
         label = 41;
        }
       }
      }
     } else {
      if ($149) {
       $174 = Math_fround($167 / $120);
       $175 = $174 < Math_fround(0.0);
       if ($175) {
        break;
       }
       $176 = $174 < Math_fround(1.00000001504746621988E+30);
       $$ph = $176 ? $174 : Math_fround(1.00000001504746621988E+30);
       $177 = Math_fround(HEAPF32[$37>>2]);
       $178 = Math_fround($177 - $165);
       $183 = $178;$185 = $$ph;$187 = Math_fround(0.0);
       label = 34;
       break;
      } else {
       $179 = !($167 >= Math_fround(0.0));
       if ($179) {
        break;
       }
       $180 = Math_fround(HEAPF32[$37>>2]);
       $181 = Math_fround($180 - $165);
       $192 = $181;$282 = Math_fround(0.0);
       label = 41;
       break;
      }
     }
    } while(0);
    if ((label|0) == 34) {
     label = 0;
     $182 = Math_fround($183 / $121);
     $184 = $182 > $185;
     if (!($184)) {
      $186 = $182 > $187;
      if ($186) {
       $199 = $185;$201 = $182;
       label = 42;
      } else {
       $199 = $185;$201 = $187;
       label = 42;
      }
     }
    }
    else if ((label|0) == 41) {
     label = 0;
     $191 = !($192 >= Math_fround(0.0));
     if (!($191)) {
      $199 = Math_fround(1.00000001504746621988E+30);$201 = $282;
      label = 42;
     }
    }
    L59: do {
     if ((label|0) == 42) {
      label = 0;
      $193 = ((($inputPoints1$06) + (($indvars$iv*12)|0)|0) + 4|0);
      $194 = Math_fround(HEAPF32[$193>>2]);
      $195 = Math_fround(HEAPF32[$6>>2]);
      $196 = Math_fround($194 - $195);
      do {
       if ($150) {
        $197 = Math_fround($196 / $117);
        $198 = $197 > $199;
        if ($198) {
         break L59;
        }
        $200 = $197 > $201;
        $202 = $200 ? $197 : $201;
        $203 = Math_fround(HEAPF32[$12>>2]);
        $204 = Math_fround($203 - $194);
        if ($151) {
         $214 = $204;$216 = $199;$218 = $202;
         label = 50;
        } else {
         if ($150) {
          $219 = Math_fround($204 / $118);
          $220 = $219 < $202;
          if ($220) {
           break L59;
          }
          $221 = $219 < $199;
          if ($221) {
           $229 = $219;$231 = $202;
          } else {
           $229 = $199;$231 = $202;
          }
         } else {
          $223 = $204;$283 = $202;
          label = 57;
         }
        }
       } else {
        if ($151) {
         $205 = Math_fround($196 / $117);
         $206 = $205 < $201;
         if ($206) {
          break L59;
         }
         $207 = $205 < $199;
         $$ph40 = $207 ? $205 : $199;
         $208 = Math_fround(HEAPF32[$12>>2]);
         $209 = Math_fround($208 - $194);
         $214 = $209;$216 = $$ph40;$218 = $201;
         label = 50;
         break;
        } else {
         $210 = !($196 >= Math_fround(0.0));
         if ($210) {
          break L59;
         }
         $211 = Math_fround(HEAPF32[$12>>2]);
         $212 = Math_fround($211 - $194);
         $223 = $212;$283 = $201;
         label = 57;
         break;
        }
       }
      } while(0);
      if ((label|0) == 50) {
       label = 0;
       $213 = Math_fround($214 / $118);
       $215 = $213 > $216;
       if ($215) {
        break;
       }
       $217 = $213 > $218;
       if ($217) {
        $229 = $216;$231 = $213;
       } else {
        $229 = $216;$231 = $218;
       }
      }
      else if ((label|0) == 57) {
       label = 0;
       $222 = !($223 >= Math_fround(0.0));
       if ($222) {
        break;
       } else {
        $229 = $199;$231 = $283;
       }
      }
      $224 = Math_fround(HEAPF32[$157>>2]);
      $225 = Math_fround(HEAPF32[$sceneAABB>>2]);
      $226 = Math_fround($224 - $225);
      do {
       if ($152) {
        $227 = Math_fround($226 / $114);
        $228 = $227 > $229;
        if ($228) {
         break L59;
        }
        $230 = $227 > $231;
        $232 = $230 ? $227 : $231;
        $233 = Math_fround(HEAPF32[$24>>2]);
        $234 = Math_fround($233 - $224);
        if ($153) {
         $244 = $234;$246 = $229;$248 = $232;
         label = 66;
        } else {
         if ($152) {
          $249 = Math_fround($234 / $115);
          $250 = $249 < $232;
          if ($250) {
           break L59;
          }
          $251 = $249 < $229;
          if ($251) {
           $255 = $232;$263 = $249;
          } else {
           $255 = $232;$263 = $229;
          }
         } else {
          $253 = $234;$284 = $232;
          label = 73;
         }
        }
       } else {
        if ($153) {
         $235 = Math_fround($226 / $114);
         $236 = $235 < $231;
         if ($236) {
          break L59;
         }
         $237 = $235 < $229;
         $$ph43 = $237 ? $235 : $229;
         $238 = Math_fround(HEAPF32[$24>>2]);
         $239 = Math_fround($238 - $224);
         $244 = $239;$246 = $$ph43;$248 = $231;
         label = 66;
         break;
        } else {
         $240 = !($226 >= Math_fround(0.0));
         if ($240) {
          break L59;
         }
         $241 = Math_fround(HEAPF32[$24>>2]);
         $242 = Math_fround($241 - $224);
         $253 = $242;$284 = $231;
         label = 73;
         break;
        }
       }
      } while(0);
      if ((label|0) == 66) {
       label = 0;
       $243 = Math_fround($244 / $115);
       $245 = $243 > $246;
       if ($245) {
        break;
       }
       $247 = $243 > $248;
       if ($247) {
        $255 = $243;$263 = $246;
       } else {
        $255 = $248;$263 = $246;
       }
      }
      else if ((label|0) == 73) {
       label = 0;
       $252 = !($253 >= Math_fround(0.0));
       if ($252) {
        break;
       } else {
        $255 = $284;$263 = $229;
       }
      }
      $254 = !($255 >= Math_fround(0.0));
      if ($254) {
       $intersect$0$i = 0;
      } else {
       $256 = Math_fround($255 * $115);
       $257 = Math_fround($255 * $118);
       $258 = Math_fround($255 * $121);
       $259 = Math_fround($224 + $256);
       $260 = Math_fround($194 + $257);
       $261 = Math_fround($165 + $258);
       HEAPF32[$pt>>2] = $259;
       HEAPF32[$112>>2] = $260;
       HEAPF32[$113>>2] = $261;
       $intersect$0$i = 1;
      }
      $262 = !($263 >= Math_fround(0.0));
      if ($262) {
       if (!($intersect$0$i)) {
        break;
       }
      } else {
       $264 = Math_fround($263 * $115);
       $265 = Math_fround($263 * $118);
       $266 = Math_fround($263 * $121);
       $267 = Math_fround(HEAPF32[$157>>2]);
       $268 = Math_fround($264 + $267);
       $269 = Math_fround(HEAPF32[$193>>2]);
       $270 = Math_fround($265 + $269);
       $271 = Math_fround(HEAPF32[$164>>2]);
       $272 = Math_fround($266 + $271);
       HEAPF32[$pt>>2] = $268;
       HEAPF32[$112>>2] = $270;
       HEAPF32[$113>>2] = $272;
      }
      $273 = HEAP32[$147>>2]|0;
      $274 = HEAP32[$123>>2]|0;
      $275 = ($273|0)==($274|0);
      if ($275) {
       __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($points,$pt);
       break;
      }
      $276 = ($273|0)==(0|0);
      if ($276) {
       $278 = 0;
      } else {
       ;HEAP32[$273+0>>2]=HEAP32[$pt+0>>2]|0;HEAP32[$273+4>>2]=HEAP32[$pt+4>>2]|0;HEAP32[$273+8>>2]=HEAP32[$pt+8>>2]|0;
       $$pre$i = HEAP32[$147>>2]|0;
       $278 = $$pre$i;
      }
      $277 = (($278) + 12|0);
      HEAP32[$147>>2] = $277;
     }
    } while(0);
    $indvars$iv$next = (($indvars$iv) + 1)|0;
    $lftr$wideiv = $indvars$iv$next&255;
    $exitcond = ($lftr$wideiv<<24>>24)==($155<<24>>24);
    if ($exitcond) {
     break;
    } else {
     $indvars$iv = $indvars$iv$next;
    }
   }
  }
  $279 = $155&255;
  $280 = (($inputPoints1$06) + (($279*12)|0)|0);
  $281 = (($i$19) + 1)|0;
  $exitcond28 = ($281|0)==($numFaces$4|0);
  if ($exitcond28) {
   break;
  } else {
   $i$19 = $281;$inputCounts2$08 = $154;$inputPoints1$06 = $280;
  }
 }
 STACKTOP = sp;return;
}
function __Z40CalculateBoundingSphereFromFrustumPointsPK8Vector3fRS_Rf($points,$outCenter,$outRadius) {
 $points = $points|0;
 $outCenter = $outCenter|0;
 $outRadius = $outRadius|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $8 = Math_fround(0), $9 = 0, $plane$013 = 0, $spherePoints = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $spherePoints = sp;
 ;HEAP32[$spherePoints+0>>2]=0|0;HEAP32[$spherePoints+4>>2]=0|0;HEAP32[$spherePoints+8>>2]=0|0;
 ;HEAP32[$spherePoints+0>>2]=HEAP32[$points+0>>2]|0;HEAP32[$spherePoints+4>>2]=HEAP32[$points+4>>2]|0;HEAP32[$spherePoints+8>>2]=HEAP32[$points+8>>2]|0;
 $0 = (($spherePoints) + 12|0);
 $1 = (($points) + 36|0);
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($spherePoints) + 24|0);
 $3 = (($points) + 60|0);
 ;HEAP32[$2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$3+8>>2]|0;
 $4 = (($spherePoints) + 36|0);
 $5 = (($points) + 84|0);
 ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;
 $plane$013 = 1;
 while(1) {
  $6 = $plane$013 << 1;
  $7 = (($spherePoints) + (($6*12)|0)|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = ((($spherePoints) + (($6*12)|0)|0) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = ((($spherePoints) + (($6*12)|0)|0) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = $6 | 1;
  $14 = (($spherePoints) + (($13*12)|0)|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = ((($spherePoints) + (($13*12)|0)|0) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = ((($spherePoints) + (($13*12)|0)|0) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($8 + $15);
  $21 = Math_fround($10 + $17);
  $22 = Math_fround($12 + $19);
  $23 = Math_fround($20 * Math_fround(0.5));
  $24 = Math_fround($21 * Math_fround(0.5));
  $25 = Math_fround($22 * Math_fround(0.5));
  $26 = Math_fround($8 - $23);
  $27 = Math_fround($10 - $24);
  $28 = Math_fround($12 - $25);
  $29 = Math_fround($26 * $26);
  $30 = Math_fround($27 * $27);
  $31 = Math_fround($29 + $30);
  $32 = Math_fround($28 * $28);
  $33 = Math_fround($31 + $32);
  $34 = (1 - ($plane$013))|0;
  $35 = $34 << 1;
  $36 = (($spherePoints) + (($35*12)|0)|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = ((($spherePoints) + (($35*12)|0)|0) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = ((($spherePoints) + (($35*12)|0)|0) + 8|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = $35 | 1;
  $43 = Math_fround($37 - $23);
  $44 = Math_fround($39 - $24);
  $45 = Math_fround($41 - $25);
  $46 = Math_fround($43 * $43);
  $47 = Math_fround($44 * $44);
  $48 = Math_fround($46 + $47);
  $49 = Math_fround($45 * $45);
  $50 = Math_fround($48 + $49);
  $51 = !($50 <= $33);
  if (!($51)) {
   $52 = ((($spherePoints) + (($42*12)|0)|0) + 8|0);
   $53 = ((($spherePoints) + (($42*12)|0)|0) + 4|0);
   $54 = (($spherePoints) + (($42*12)|0)|0);
   $55 = Math_fround(HEAPF32[$52>>2]);
   $56 = Math_fround(HEAPF32[$53>>2]);
   $57 = Math_fround(HEAPF32[$54>>2]);
   $58 = Math_fround($57 - $23);
   $59 = Math_fround($56 - $24);
   $60 = Math_fround($55 - $25);
   $61 = Math_fround($58 * $58);
   $62 = Math_fround($59 * $59);
   $63 = Math_fround($62 + $61);
   $64 = Math_fround($60 * $60);
   $65 = Math_fround($64 + $63);
   $66 = !($65 <= $33);
   if (!($66)) {
    label = 4;
    break;
   }
  }
  $70 = (($plane$013) + -1)|0;
  $71 = ($plane$013|0)>(0);
  if ($71) {
   $plane$013 = $70;
  } else {
   label = 6;
   break;
  }
 }
 if ((label|0) == 4) {
  HEAPF32[$outCenter>>2] = $23;
  $67 = (($outCenter) + 4|0);
  HEAPF32[$67>>2] = $24;
  $68 = (($outCenter) + 8|0);
  HEAPF32[$68>>2] = $25;
  $69 = (Math_fround(Math_sqrt((Math_fround($33)))));
  HEAPF32[$outRadius>>2] = $69;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  __Z26CalculateSphereFrom4PointsPK8Vector3fRS_Rf($spherePoints,$outCenter,$outRadius);
  STACKTOP = sp;return;
 }
}
function __Z26CalculateSphereFrom4PointsPK8Vector3fRS_Rf($points,$outCenter,$outRadius) {
 $points = $points|0;
 $outCenter = $outCenter|0;
 $outRadius = $outRadius|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0.0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0.0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0.0, $175 = Math_fround(0), $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = Math_fround(0), $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = Math_fround(0), $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0;
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0.0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0.0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $mat = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $mat = sp;
 $0 = Math_fround(HEAPF32[$points>>2]);
 HEAPF32[$mat>>2] = $0;
 $1 = (($points) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($mat) + 16|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($points) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($mat) + 32|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($mat) + 48|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($points) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($mat) + 4|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($points) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($mat) + 20|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($points) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($mat) + 36|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($mat) + 52|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($points) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($mat) + 8|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($points) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($mat) + 24|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($points) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($mat) + 40|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($mat) + 56|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($points) + 36|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($mat) + 12|0);
 HEAPF32[$30>>2] = $29;
 $31 = (($points) + 40|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($mat) + 28|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($points) + 44|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($mat) + 44|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($mat) + 60|0);
 HEAPF32[$37>>2] = Math_fround(1.0);
 $38 = (+__ZNK10Matrix4x4f14GetDeterminantEv($mat));
 $39 = Math_fround(HEAPF32[$points>>2]);
 $40 = Math_fround($39 * $39);
 $41 = Math_fround(HEAPF32[$1>>2]);
 $42 = Math_fround($41 * $41);
 $43 = Math_fround($40 + $42);
 $44 = Math_fround(HEAPF32[$4>>2]);
 $45 = Math_fround($44 * $44);
 $46 = Math_fround($43 + $45);
 HEAPF32[$mat>>2] = $46;
 HEAPF32[$3>>2] = $41;
 HEAPF32[$6>>2] = $44;
 HEAPF32[$7>>2] = Math_fround(1.0);
 $47 = Math_fround(HEAPF32[$8>>2]);
 $48 = Math_fround($47 * $47);
 $49 = Math_fround(HEAPF32[$11>>2]);
 $50 = Math_fround($49 * $49);
 $51 = Math_fround($48 + $50);
 $52 = Math_fround(HEAPF32[$14>>2]);
 $53 = Math_fround($52 * $52);
 $54 = Math_fround($51 + $53);
 HEAPF32[$10>>2] = $54;
 HEAPF32[$13>>2] = $49;
 HEAPF32[$16>>2] = $52;
 HEAPF32[$17>>2] = Math_fround(1.0);
 $55 = Math_fround(HEAPF32[$18>>2]);
 $56 = Math_fround($55 * $55);
 $57 = Math_fround(HEAPF32[$21>>2]);
 $58 = Math_fround($57 * $57);
 $59 = Math_fround($56 + $58);
 $60 = Math_fround(HEAPF32[$24>>2]);
 $61 = Math_fround($60 * $60);
 $62 = Math_fround($59 + $61);
 HEAPF32[$20>>2] = $62;
 HEAPF32[$23>>2] = $57;
 HEAPF32[$26>>2] = $60;
 HEAPF32[$27>>2] = Math_fround(1.0);
 $63 = Math_fround(HEAPF32[$28>>2]);
 $64 = Math_fround($63 * $63);
 $65 = Math_fround(HEAPF32[$31>>2]);
 $66 = Math_fround($65 * $65);
 $67 = Math_fround($64 + $66);
 $68 = Math_fround(HEAPF32[$34>>2]);
 $69 = Math_fround($68 * $68);
 $70 = Math_fround($67 + $69);
 HEAPF32[$30>>2] = $70;
 HEAPF32[$33>>2] = $65;
 HEAPF32[$36>>2] = $68;
 HEAPF32[$37>>2] = Math_fround(1.0);
 $71 = Math_fround($38);
 $72 = (+__ZNK10Matrix4x4f14GetDeterminantEv($mat));
 $73 = Math_fround(HEAPF32[$points>>2]);
 HEAPF32[$mat>>2] = $73;
 $74 = Math_fround($73 * $73);
 $75 = Math_fround(HEAPF32[$1>>2]);
 $76 = Math_fround($75 * $75);
 $77 = Math_fround($74 + $76);
 $78 = Math_fround(HEAPF32[$4>>2]);
 $79 = Math_fround($78 * $78);
 $80 = Math_fround($77 + $79);
 HEAPF32[$3>>2] = $80;
 HEAPF32[$6>>2] = $78;
 HEAPF32[$7>>2] = Math_fround(1.0);
 $81 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$10>>2] = $81;
 $82 = Math_fround($81 * $81);
 $83 = Math_fround(HEAPF32[$11>>2]);
 $84 = Math_fround($83 * $83);
 $85 = Math_fround($82 + $84);
 $86 = Math_fround(HEAPF32[$14>>2]);
 $87 = Math_fround($86 * $86);
 $88 = Math_fround($85 + $87);
 HEAPF32[$13>>2] = $88;
 HEAPF32[$16>>2] = $86;
 HEAPF32[$17>>2] = Math_fround(1.0);
 $89 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$20>>2] = $89;
 $90 = Math_fround($89 * $89);
 $91 = Math_fround(HEAPF32[$21>>2]);
 $92 = Math_fround($91 * $91);
 $93 = Math_fround($90 + $92);
 $94 = Math_fround(HEAPF32[$24>>2]);
 $95 = Math_fround($94 * $94);
 $96 = Math_fround($93 + $95);
 HEAPF32[$23>>2] = $96;
 HEAPF32[$26>>2] = $94;
 HEAPF32[$27>>2] = Math_fround(1.0);
 $97 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$30>>2] = $97;
 $98 = Math_fround($97 * $97);
 $99 = Math_fround(HEAPF32[$31>>2]);
 $100 = Math_fround($99 * $99);
 $101 = Math_fround($98 + $100);
 $102 = Math_fround(HEAPF32[$34>>2]);
 $103 = Math_fround($102 * $102);
 $104 = Math_fround($101 + $103);
 HEAPF32[$33>>2] = $104;
 HEAPF32[$36>>2] = $102;
 HEAPF32[$37>>2] = Math_fround(1.0);
 $105 = Math_fround($72);
 $106 = (+__ZNK10Matrix4x4f14GetDeterminantEv($mat));
 $107 = Math_fround(HEAPF32[$points>>2]);
 HEAPF32[$mat>>2] = $107;
 $108 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$3>>2] = $108;
 $109 = Math_fround($107 * $107);
 $110 = Math_fround($108 * $108);
 $111 = Math_fround($109 + $110);
 $112 = Math_fround(HEAPF32[$4>>2]);
 $113 = Math_fround($112 * $112);
 $114 = Math_fround($111 + $113);
 HEAPF32[$6>>2] = $114;
 HEAPF32[$7>>2] = Math_fround(1.0);
 $115 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$10>>2] = $115;
 $116 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$13>>2] = $116;
 $117 = Math_fround($115 * $115);
 $118 = Math_fround($116 * $116);
 $119 = Math_fround($117 + $118);
 $120 = Math_fround(HEAPF32[$14>>2]);
 $121 = Math_fround($120 * $120);
 $122 = Math_fround($119 + $121);
 HEAPF32[$16>>2] = $122;
 HEAPF32[$17>>2] = Math_fround(1.0);
 $123 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$20>>2] = $123;
 $124 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$23>>2] = $124;
 $125 = Math_fround($123 * $123);
 $126 = Math_fround($124 * $124);
 $127 = Math_fround($125 + $126);
 $128 = Math_fround(HEAPF32[$24>>2]);
 $129 = Math_fround($128 * $128);
 $130 = Math_fround($127 + $129);
 HEAPF32[$26>>2] = $130;
 HEAPF32[$27>>2] = Math_fround(1.0);
 $131 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$30>>2] = $131;
 $132 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$33>>2] = $132;
 $133 = Math_fround($131 * $131);
 $134 = Math_fround($132 * $132);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround(HEAPF32[$34>>2]);
 $137 = Math_fround($136 * $136);
 $138 = Math_fround($135 + $137);
 HEAPF32[$36>>2] = $138;
 HEAPF32[$37>>2] = Math_fround(1.0);
 $139 = Math_fround($106);
 $140 = (+__ZNK10Matrix4x4f14GetDeterminantEv($mat));
 $141 = Math_fround(HEAPF32[$points>>2]);
 $142 = Math_fround($141 * $141);
 $143 = Math_fround(HEAPF32[$1>>2]);
 $144 = Math_fround($143 * $143);
 $145 = Math_fround($142 + $144);
 $146 = Math_fround(HEAPF32[$4>>2]);
 $147 = Math_fround($146 * $146);
 $148 = Math_fround($145 + $147);
 HEAPF32[$mat>>2] = $148;
 HEAPF32[$3>>2] = $141;
 HEAPF32[$6>>2] = $143;
 HEAPF32[$7>>2] = $146;
 $149 = Math_fround(HEAPF32[$8>>2]);
 $150 = Math_fround($149 * $149);
 $151 = Math_fround(HEAPF32[$11>>2]);
 $152 = Math_fround($151 * $151);
 $153 = Math_fround($150 + $152);
 $154 = Math_fround(HEAPF32[$14>>2]);
 $155 = Math_fround($154 * $154);
 $156 = Math_fround($153 + $155);
 HEAPF32[$10>>2] = $156;
 HEAPF32[$13>>2] = $149;
 HEAPF32[$16>>2] = $151;
 HEAPF32[$17>>2] = $154;
 $157 = Math_fround(HEAPF32[$18>>2]);
 $158 = Math_fround($157 * $157);
 $159 = Math_fround(HEAPF32[$21>>2]);
 $160 = Math_fround($159 * $159);
 $161 = Math_fround($158 + $160);
 $162 = Math_fround(HEAPF32[$24>>2]);
 $163 = Math_fround($162 * $162);
 $164 = Math_fround($161 + $163);
 HEAPF32[$20>>2] = $164;
 HEAPF32[$23>>2] = $157;
 HEAPF32[$26>>2] = $159;
 HEAPF32[$27>>2] = $162;
 $165 = Math_fround(HEAPF32[$28>>2]);
 $166 = Math_fround($165 * $165);
 $167 = Math_fround(HEAPF32[$31>>2]);
 $168 = Math_fround($167 * $167);
 $169 = Math_fround($166 + $168);
 $170 = Math_fround(HEAPF32[$34>>2]);
 $171 = Math_fround($170 * $170);
 $172 = Math_fround($169 + $171);
 HEAPF32[$30>>2] = $172;
 HEAPF32[$33>>2] = $165;
 HEAPF32[$36>>2] = $167;
 HEAPF32[$37>>2] = $170;
 $173 = Math_fround($140);
 $174 = (+__ZNK10Matrix4x4f14GetDeterminantEv($mat));
 $175 = Math_fround($174);
 $176 = +$105;
 $177 = $176 * 0.5;
 $178 = +$71;
 $179 = $177 / $178;
 $180 = Math_fround($179);
 $181 = +$139;
 $182 = $181 * 0.5;
 $183 = $182 / $178;
 $184 = Math_fround($183);
 $185 = +$173;
 $186 = $185 * 0.5;
 $187 = $186 / $178;
 $188 = Math_fround($187);
 $189 = Math_fround($180 * $180);
 $190 = Math_fround($184 * $184);
 $191 = Math_fround($189 + $190);
 $192 = Math_fround($188 * $188);
 $193 = Math_fround($191 + $192);
 $194 = Math_fround($175 / $71);
 $195 = Math_fround($193 - $194);
 $196 = (Math_fround(Math_sqrt((Math_fround($195)))));
 HEAPF32[$outRadius>>2] = $196;
 HEAPF32[$outCenter>>2] = $180;
 $197 = (($outCenter) + 4|0);
 HEAPF32[$197>>2] = $184;
 $198 = (($outCenter) + 8|0);
 HEAPF32[$198>>2] = $188;
 STACKTOP = sp;return;
}
function __Z24CalculateSpotLightBoundsffRK10Matrix4x4fR15SpotLightBounds($range,$cotanHalfSpotAngle,$lightMatrix,$outBounds) {
 $range = Math_fround($range);
 $cotanHalfSpotAngle = Math_fround($cotanHalfSpotAngle);
 $lightMatrix = $lightMatrix|0;
 $outBounds = $outBounds|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0);
 var $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0;
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($range / $cotanHalfSpotAngle);
 $1 = (($lightMatrix) + 48|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($lightMatrix) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($lightMatrix) + 56|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$outBounds>>2] = $2;
 $7 = (($outBounds) + 4|0);
 HEAPF32[$7>>2] = $4;
 $8 = (($outBounds) + 8|0);
 HEAPF32[$8>>2] = $6;
 $9 = Math_fround(-$0);
 $10 = Math_fround(HEAPF32[$lightMatrix>>2]);
 $11 = Math_fround($10 * $9);
 $12 = (($lightMatrix) + 16|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $9);
 $15 = Math_fround($11 + $14);
 $16 = (($lightMatrix) + 32|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * $range);
 $19 = Math_fround($15 + $18);
 $20 = Math_fround(HEAPF32[$1>>2]);
 $21 = Math_fround($20 + $19);
 $22 = (($lightMatrix) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $9);
 $25 = (($lightMatrix) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $9);
 $28 = Math_fround($24 + $27);
 $29 = (($lightMatrix) + 36|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $range);
 $32 = Math_fround($28 + $31);
 $33 = Math_fround(HEAPF32[$3>>2]);
 $34 = Math_fround($33 + $32);
 $35 = (($lightMatrix) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * $9);
 $38 = (($lightMatrix) + 24|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $9);
 $41 = Math_fround($37 + $40);
 $42 = (($lightMatrix) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $range);
 $45 = Math_fround($41 + $44);
 $46 = Math_fround(HEAPF32[$5>>2]);
 $47 = Math_fround($46 + $45);
 $48 = (($outBounds) + 12|0);
 HEAPF32[$48>>2] = $21;
 $49 = (($outBounds) + 16|0);
 HEAPF32[$49>>2] = $34;
 $50 = (($outBounds) + 20|0);
 HEAPF32[$50>>2] = $47;
 $51 = Math_fround(HEAPF32[$lightMatrix>>2]);
 $52 = Math_fround($0 * $51);
 $53 = Math_fround(HEAPF32[$12>>2]);
 $54 = Math_fround($53 * $9);
 $55 = Math_fround($52 + $54);
 $56 = Math_fround(HEAPF32[$16>>2]);
 $57 = Math_fround($56 * $range);
 $58 = Math_fround($55 + $57);
 $59 = Math_fround(HEAPF32[$1>>2]);
 $60 = Math_fround($59 + $58);
 $61 = Math_fround(HEAPF32[$22>>2]);
 $62 = Math_fround($0 * $61);
 $63 = Math_fround(HEAPF32[$25>>2]);
 $64 = Math_fround($63 * $9);
 $65 = Math_fround($62 + $64);
 $66 = Math_fround(HEAPF32[$29>>2]);
 $67 = Math_fround($66 * $range);
 $68 = Math_fround($65 + $67);
 $69 = Math_fround(HEAPF32[$3>>2]);
 $70 = Math_fround($69 + $68);
 $71 = Math_fround(HEAPF32[$35>>2]);
 $72 = Math_fround($0 * $71);
 $73 = Math_fround(HEAPF32[$38>>2]);
 $74 = Math_fround($73 * $9);
 $75 = Math_fround($72 + $74);
 $76 = Math_fround(HEAPF32[$42>>2]);
 $77 = Math_fround($76 * $range);
 $78 = Math_fround($75 + $77);
 $79 = Math_fround(HEAPF32[$5>>2]);
 $80 = Math_fround($79 + $78);
 $81 = (($outBounds) + 24|0);
 HEAPF32[$81>>2] = $60;
 $82 = (($outBounds) + 28|0);
 HEAPF32[$82>>2] = $70;
 $83 = (($outBounds) + 32|0);
 HEAPF32[$83>>2] = $80;
 $84 = Math_fround(HEAPF32[$lightMatrix>>2]);
 $85 = Math_fround($0 * $84);
 $86 = Math_fround(HEAPF32[$12>>2]);
 $87 = Math_fround($0 * $86);
 $88 = Math_fround($85 + $87);
 $89 = Math_fround(HEAPF32[$16>>2]);
 $90 = Math_fround($89 * $range);
 $91 = Math_fround($88 + $90);
 $92 = Math_fround(HEAPF32[$1>>2]);
 $93 = Math_fround($92 + $91);
 $94 = Math_fround(HEAPF32[$22>>2]);
 $95 = Math_fround($0 * $94);
 $96 = Math_fround(HEAPF32[$25>>2]);
 $97 = Math_fround($0 * $96);
 $98 = Math_fround($95 + $97);
 $99 = Math_fround(HEAPF32[$29>>2]);
 $100 = Math_fround($99 * $range);
 $101 = Math_fround($98 + $100);
 $102 = Math_fround(HEAPF32[$3>>2]);
 $103 = Math_fround($102 + $101);
 $104 = Math_fround(HEAPF32[$35>>2]);
 $105 = Math_fround($0 * $104);
 $106 = Math_fround(HEAPF32[$38>>2]);
 $107 = Math_fround($0 * $106);
 $108 = Math_fround($105 + $107);
 $109 = Math_fround(HEAPF32[$42>>2]);
 $110 = Math_fround($109 * $range);
 $111 = Math_fround($108 + $110);
 $112 = Math_fround(HEAPF32[$5>>2]);
 $113 = Math_fround($112 + $111);
 $114 = (($outBounds) + 36|0);
 HEAPF32[$114>>2] = $93;
 $115 = (($outBounds) + 40|0);
 HEAPF32[$115>>2] = $103;
 $116 = (($outBounds) + 44|0);
 HEAPF32[$116>>2] = $113;
 $117 = Math_fround(HEAPF32[$lightMatrix>>2]);
 $118 = Math_fround($117 * $9);
 $119 = Math_fround(HEAPF32[$12>>2]);
 $120 = Math_fround($0 * $119);
 $121 = Math_fround($118 + $120);
 $122 = Math_fround(HEAPF32[$16>>2]);
 $123 = Math_fround($122 * $range);
 $124 = Math_fround($121 + $123);
 $125 = Math_fround(HEAPF32[$1>>2]);
 $126 = Math_fround($125 + $124);
 $127 = Math_fround(HEAPF32[$22>>2]);
 $128 = Math_fround($127 * $9);
 $129 = Math_fround(HEAPF32[$25>>2]);
 $130 = Math_fround($0 * $129);
 $131 = Math_fround($128 + $130);
 $132 = Math_fround(HEAPF32[$29>>2]);
 $133 = Math_fround($132 * $range);
 $134 = Math_fround($131 + $133);
 $135 = Math_fround(HEAPF32[$3>>2]);
 $136 = Math_fround($135 + $134);
 $137 = Math_fround(HEAPF32[$35>>2]);
 $138 = Math_fround($137 * $9);
 $139 = Math_fround(HEAPF32[$38>>2]);
 $140 = Math_fround($0 * $139);
 $141 = Math_fround($138 + $140);
 $142 = Math_fround(HEAPF32[$42>>2]);
 $143 = Math_fround($142 * $range);
 $144 = Math_fround($141 + $143);
 $145 = Math_fround(HEAPF32[$5>>2]);
 $146 = Math_fround($145 + $144);
 $147 = (($outBounds) + 48|0);
 HEAPF32[$147>>2] = $126;
 $148 = (($outBounds) + 52|0);
 HEAPF32[$148>>2] = $136;
 $149 = (($outBounds) + 56|0);
 HEAPF32[$149>>2] = $146;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($13>>>0)<(178956970);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 357913941;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*12)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*12)|0)|0);
 $23 = (($22) + (($$0$i3*12)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  ;HEAP32[$21+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__x+8>>2]|0;
 }
 $25 = (($22) + (($7*12)|0)|0);
 $26 = (($5|0) / -12)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*12)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __Z16IntersectRayAABBRK3RayRK4AABBPf($ray,$inAABB,$outT0) {
 $ray = $ray|0;
 $inAABB = $inAABB|0;
 $outT0 = $outT0|0;
 var $$0$i = 0, $$phi$trans$insert$i = 0, $$pre$i = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $extent$i = 0, $i$06$i = 0, $or$cond$i = 0, $or$cond1$i = 0, $p$i = 0, $tmax$04$i = Math_fround(0), $tmax$1$i = Math_fround(0), $tmax$2$i = Math_fround(0), $tmax$3$i = Math_fround(0), $tmin$05$i = Math_fround(0), $tmin$1$i = Math_fround(0), $tmin$2$i = Math_fround(0), $tmin$3$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p$i = sp + 12|0;
 $extent$i = sp;
 $0 = Math_fround(HEAPF32[616656>>2]);
 $1 = Math_fround(-$0);
 $2 = Math_fround(HEAPF32[$inAABB>>2]);
 $3 = Math_fround(HEAPF32[$ray>>2]);
 $4 = Math_fround($2 - $3);
 $5 = (($inAABB) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($ray) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($inAABB) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($ray) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 HEAPF32[$p$i>>2] = $4;
 $15 = (($p$i) + 4|0);
 HEAPF32[$15>>2] = $9;
 $16 = (($p$i) + 8|0);
 HEAPF32[$16>>2] = $14;
 $17 = (($inAABB) + 12|0);
 ;HEAP32[$extent$i+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$extent$i+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$extent$i+8>>2]=HEAP32[$17+8>>2]|0;
 $18 = (($ray) + 12|0);
 $25 = $4;$i$06$i = 0;$tmax$04$i = $0;$tmin$05$i = $1;
 while(1) {
  $19 = (($18) + ($i$06$i<<2)|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround(Math_fround(1.0) / $20);
  $22 = (($extent$i) + ($i$06$i<<2)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($25 + $23);
  $26 = Math_fround($21 * $24);
  $27 = Math_fround($25 - $23);
  $28 = Math_fround($21 * $27);
  $29 = $26 < $28;
  if ($29) {
   $30 = $26 > $tmin$05$i;
   $tmin$1$i = $30 ? $26 : $tmin$05$i;
   $31 = $28 < $tmax$04$i;
   $tmax$1$i = $31 ? $28 : $tmax$04$i;
   $32 = $tmin$1$i > $tmax$1$i;
   $33 = $tmax$1$i < Math_fround(0.0);
   $or$cond$i = $32 | $33;
   if ($or$cond$i) {
    $$0$i = 0;
    label = 8;
    break;
   } else {
    $tmax$3$i = $tmax$1$i;$tmin$3$i = $tmin$1$i;
   }
  } else {
   $34 = $28 > $tmin$05$i;
   $tmin$2$i = $34 ? $28 : $tmin$05$i;
   $35 = $26 < $tmax$04$i;
   $tmax$2$i = $35 ? $26 : $tmax$04$i;
   $36 = $tmin$2$i > $tmax$2$i;
   $37 = $tmax$2$i < Math_fround(0.0);
   $or$cond1$i = $36 | $37;
   if ($or$cond1$i) {
    $$0$i = 0;
    label = 8;
    break;
   } else {
    $tmax$3$i = $tmax$2$i;$tmin$3$i = $tmin$2$i;
   }
  }
  $38 = (($i$06$i) + 1)|0;
  $39 = ($38|0)<(3);
  if (!($39)) {
   label = 7;
   break;
  }
  $$phi$trans$insert$i = (($p$i) + ($38<<2)|0);
  $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
  $25 = $$pre$i;$i$06$i = $38;$tmax$04$i = $tmax$3$i;$tmin$05$i = $tmin$3$i;
 }
 if ((label|0) == 7) {
  HEAPF32[$outT0>>2] = $tmin$3$i;
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 8) {
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __Z17IntersectAABBAABBRK4AABBS1_($b0,$b1) {
 $b0 = $b0|0;
 $b1 = $b1|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0;
 var $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b1>>2]);
 $1 = Math_fround(HEAPF32[$b0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($b1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($b0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($b1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($b0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = $2 < Math_fround(0.0);
 if ($13) {
  $14 = Math_fround(-$2);
  $21 = $14;
 } else {
  $21 = $2;
 }
 $15 = (($b0) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($b1) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 + $18);
 $20 = $21 < $19;
 if (!($20)) {
  $40 = 0;
  STACKTOP = sp;return ($40|0);
 }
 $22 = $7 < Math_fround(0.0);
 if ($22) {
  $23 = Math_fround(-$7);
  $30 = $23;
 } else {
  $30 = $7;
 }
 $24 = (($15) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($17) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 + $27);
 $29 = $30 < $28;
 if (!($29)) {
  $40 = 0;
  STACKTOP = sp;return ($40|0);
 }
 $31 = $12 < Math_fround(0.0);
 if ($31) {
  $32 = Math_fround(-$12);
  $39 = $32;
 } else {
  $39 = $12;
 }
 $33 = (($15) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($17) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 + $36);
 $38 = $39 < $37;
 $40 = $38;
 STACKTOP = sp;return ($40|0);
}
function __Z17IntersectAABBAABBRK10MinMaxAABBS1_PS_($a,$b,$outBoxIntersect) {
 $a = $a|0;
 $b = $b|0;
 $outBoxIntersect = $outBoxIntersect|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = (($b) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $0 > $2;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($a) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$b>>2]);
 $7 = $5 < $6;
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($a) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($b) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = $9 > $11;
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($a) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($b) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = $14 < $16;
 if ($17) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($a) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($b) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = $19 > $21;
 if ($22) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = (($a) + 20|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($b) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = $24 < $26;
 if ($27) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = ($outBoxIntersect|0)==(0|0);
 if ($28) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = $0 < $6;
 $30 = $29 ? $b : $a;
 $31 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$outBoxIntersect>>2] = $31;
 $32 = Math_fround(HEAPF32[$1>>2]);
 $33 = Math_fround(HEAPF32[$4>>2]);
 $34 = $32 < $33;
 $35 = $34 ? $32 : $33;
 $36 = (($outBoxIntersect) + 12|0);
 HEAPF32[$36>>2] = $35;
 $37 = Math_fround(HEAPF32[$8>>2]);
 $38 = Math_fround(HEAPF32[$15>>2]);
 $39 = $37 < $38;
 $40 = $39 ? $38 : $37;
 $41 = (($outBoxIntersect) + 4|0);
 HEAPF32[$41>>2] = $40;
 $42 = Math_fround(HEAPF32[$10>>2]);
 $43 = Math_fround(HEAPF32[$13>>2]);
 $44 = $42 < $43;
 $45 = $44 ? $42 : $43;
 $46 = (($outBoxIntersect) + 16|0);
 HEAPF32[$46>>2] = $45;
 $47 = Math_fround(HEAPF32[$18>>2]);
 $48 = Math_fround(HEAPF32[$25>>2]);
 $49 = $47 < $48;
 $50 = $49 ? $48 : $47;
 $51 = (($outBoxIntersect) + 8|0);
 HEAPF32[$51>>2] = $50;
 $52 = Math_fround(HEAPF32[$20>>2]);
 $53 = Math_fround(HEAPF32[$23>>2]);
 $54 = $52 < $53;
 $55 = $54 ? $52 : $53;
 $56 = (($outBoxIntersect) + 20|0);
 HEAPF32[$56>>2] = $55;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z26IntersectAABBAABBInclusiveRK4AABBS1_($b0,$b1) {
 $b0 = $b0|0;
 $b1 = $b1|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0;
 var $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b1>>2]);
 $1 = Math_fround(HEAPF32[$b0>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($b1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($b0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($b1) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($b0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = $2 < Math_fround(0.0);
 if ($13) {
  $14 = Math_fround(-$2);
  $21 = $14;
 } else {
  $21 = $2;
 }
 $15 = (($b0) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($b1) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 + $18);
 $20 = !($21 <= $19);
 if ($20) {
  $40 = 0;
  STACKTOP = sp;return ($40|0);
 }
 $22 = $7 < Math_fround(0.0);
 if ($22) {
  $23 = Math_fround(-$7);
  $30 = $23;
 } else {
  $30 = $7;
 }
 $24 = (($15) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($17) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 + $27);
 $29 = !($30 <= $28);
 if ($29) {
  $40 = 0;
  STACKTOP = sp;return ($40|0);
 }
 $31 = $12 < Math_fround(0.0);
 if ($31) {
  $32 = Math_fround(-$12);
  $39 = $32;
 } else {
  $39 = $12;
 }
 $33 = (($15) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($17) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 + $36);
 $38 = $39 <= $37;
 $40 = $38;
 STACKTOP = sp;return ($40|0);
}
function __Z19IntersectAABBSphereRK4AABBRK6Sphere($aabb,$s) {
 $aabb = $aabb|0;
 $s = $s|0;
 var $0 = Math_fround(0), $1 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($s,$aabb)));
 $1 = (($s) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($2 * $2);
 $4 = $0 < $3;
 STACKTOP = sp;return ($4|0);
}
function __Z30IntersectTransformedAABBSphereRK4AABBRK10Matrix4x4f13TransformTypeRK6Sphere($aabb,$transform,$type,$s) {
 $aabb = $aabb|0;
 $transform = $transform|0;
 $type = $type|0;
 $s = $s|0;
 var $$0 = 0, $$phi$trans$insert30 = 0, $$phi$trans$insert32 = 0, $$pre27 = Math_fround(0), $$pre29 = Math_fround(0), $$pre31 = Math_fround(0), $$pre33 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0;
 var $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0);
 var $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0);
 var $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0;
 var $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0);
 var $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0);
 var $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = Math_fround(0);
 var $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0;
 var $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0;
 var $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0;
 var $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0);
 var $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0);
 var $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0);
 var $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = Math_fround(0);
 var $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0);
 var $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0;
 var $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0);
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $axis2$020$us = 0, $axisDistances = 0, $exitcond = 0, $localSphere = 0, $normalInverse = 0, $normalMatrix = 0, $normals = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $localSphere = sp + 184|0;
 $normals = sp;
 $normalMatrix = sp + 40|0;
 $normalInverse = sp + 104|0;
 $axisDistances = sp + 168|0;
 $0 = $type & 2;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = ($type|0)==(0);
  $$pre29 = Math_fround(HEAPF32[$transform>>2]);
  $$phi$trans$insert30 = (($transform) + 4|0);
  $$pre31 = Math_fround(HEAPF32[$$phi$trans$insert30>>2]);
  $$phi$trans$insert32 = (($transform) + 8|0);
  $$pre33 = Math_fround(HEAPF32[$$phi$trans$insert32>>2]);
  if ($2) {
   $52 = Math_fround(1.0);
  } else {
   $3 = Math_fround($$pre29 * $$pre29);
   $4 = Math_fround($$pre31 * $$pre31);
   $5 = Math_fround($3 + $4);
   $6 = Math_fround($$pre33 * $$pre33);
   $7 = Math_fround($5 + $6);
   $8 = (Math_fround(Math_sqrt((Math_fround($7)))));
   $9 = Math_fround(Math_fround(1.0) / $8);
   $52 = $9;
  }
  $10 = Math_fround(HEAPF32[$s>>2]);
  $11 = (($transform) + 48|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($10 - $12);
  $14 = (($s) + 4|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($transform) + 52|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($15 - $17);
  $19 = (($s) + 8|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($transform) + 56|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($20 - $22);
  $24 = Math_fround($13 * $$pre29);
  $25 = Math_fround($18 * $$pre31);
  $26 = Math_fround($24 + $25);
  $27 = Math_fround($23 * $$pre33);
  $28 = Math_fround($26 + $27);
  $29 = (($transform) + 16|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($13 * $30);
  $32 = (($transform) + 20|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($18 * $33);
  $35 = Math_fround($31 + $34);
  $36 = (($transform) + 24|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($23 * $37);
  $39 = Math_fround($35 + $38);
  $40 = (($transform) + 32|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($13 * $41);
  $43 = (($transform) + 36|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($18 * $44);
  $46 = Math_fround($42 + $45);
  $47 = (($transform) + 40|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($23 * $48);
  $50 = Math_fround($46 + $49);
  $51 = Math_fround($52 * $28);
  $53 = Math_fround($52 * $39);
  $54 = Math_fround($52 * $50);
  $55 = Math_fround($52 * $51);
  $56 = Math_fround($52 * $53);
  $57 = Math_fround($52 * $54);
  $58 = (($s) + 12|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($52 * $59);
  $61 = (($localSphere) + 4|0);
  $62 = (($localSphere) + 8|0);
  HEAPF32[$localSphere>>2] = $55;
  HEAPF32[$61>>2] = $56;
  HEAPF32[$62>>2] = $57;
  $63 = (($localSphere) + 12|0);
  HEAPF32[$63>>2] = $60;
  $64 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($localSphere,$aabb)));
  $65 = Math_fround(HEAPF32[$63>>2]);
  $66 = Math_fround($65 * $65);
  $67 = $64 < $66;
  $$0 = $67;
  STACKTOP = sp;return ($$0|0);
 }
 $68 = Math_fround(HEAPF32[$transform>>2]);
 $69 = Math_fround(HEAPF32[$aabb>>2]);
 $70 = Math_fround($68 * $69);
 $71 = (($transform) + 16|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($aabb) + 4|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($72 * $74);
 $76 = Math_fround($70 + $75);
 $77 = (($transform) + 32|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($aabb) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($78 * $80);
 $82 = Math_fround($76 + $81);
 $83 = (($transform) + 48|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 + $82);
 $86 = (($transform) + 4|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($69 * $87);
 $89 = (($transform) + 20|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($74 * $90);
 $92 = Math_fround($88 + $91);
 $93 = (($transform) + 36|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($80 * $94);
 $96 = Math_fround($92 + $95);
 $97 = (($transform) + 52|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($98 + $96);
 $100 = (($transform) + 8|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($69 * $101);
 $103 = (($transform) + 24|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($74 * $104);
 $106 = Math_fround($102 + $105);
 $107 = (($transform) + 40|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($80 * $108);
 $110 = Math_fround($106 + $109);
 $111 = (($transform) + 56|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($112 + $110);
 $114 = Math_fround(HEAPF32[$s>>2]);
 $115 = Math_fround($114 - $85);
 $116 = (($s) + 4|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($117 - $99);
 $119 = (($s) + 8|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($120 - $113);
 $122 = Math_fround($115 * $115);
 $123 = Math_fround($118 * $118);
 $124 = Math_fround($122 + $123);
 $125 = Math_fround($121 * $121);
 $126 = Math_fround($124 + $125);
 $127 = (($s) + 12|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($128 * $128);
 $130 = $126 < $129;
 if ($130) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $131 = (($normals) + 16|0);
 ;HEAP32[$normals+0>>2]=0|0;HEAP32[$normals+4>>2]=0|0;HEAP32[$normals+8>>2]=0|0;HEAP32[$normals+12>>2]=0|0;
 HEAPF32[$131>>2] = Math_fround(0.0);
 $132 = (($normals) + 20|0);
 HEAPF32[$132>>2] = Math_fround(0.0);
 $133 = (($normals) + 24|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = (($normals) + 28|0);
 HEAPF32[$134>>2] = Math_fround(0.0);
 $135 = (($normals) + 32|0);
 HEAPF32[$135>>2] = Math_fround(0.0);
 HEAPF32[$normals>>2] = $68;
 $136 = (($normals) + 4|0);
 HEAPF32[$136>>2] = $87;
 $137 = (($normals) + 8|0);
 HEAPF32[$137>>2] = $101;
 $138 = Math_fround($68 * $68);
 $139 = Math_fround($87 * $87);
 $140 = Math_fround($138 + $139);
 $141 = Math_fround($101 * $101);
 $142 = Math_fround($141 + $140);
 $143 = (Math_fround(Math_sqrt((Math_fround($142)))));
 $144 = $143 > Math_fround(0.0);
 if ($144) {
  $145 = Math_fround(Math_fround(1.0) / $143);
  $146 = Math_fround($145 * $68);
  HEAPF32[$normals>>2] = $146;
  $147 = Math_fround($145 * $87);
  HEAPF32[$136>>2] = $147;
  $148 = Math_fround($145 * $101);
  HEAPF32[$137>>2] = $148;
  $181 = $146;$183 = $147;$186 = $148;
 } else {
  $181 = $68;$183 = $87;$186 = $101;
 }
 $149 = (($normals) + 12|0);
 HEAPF32[$149>>2] = $72;
 $150 = (($normals) + 16|0);
 HEAPF32[$150>>2] = $90;
 $151 = (($normals) + 20|0);
 HEAPF32[$151>>2] = $104;
 $152 = Math_fround($72 * $72);
 $153 = Math_fround($90 * $90);
 $154 = Math_fround($152 + $153);
 $155 = Math_fround($104 * $104);
 $156 = Math_fround($155 + $154);
 $157 = (Math_fround(Math_sqrt((Math_fround($156)))));
 $158 = $157 > Math_fround(0.0);
 if ($158) {
  $384 = Math_fround(Math_fround(1.0) / $157);
  $385 = Math_fround($384 * $72);
  HEAPF32[$149>>2] = $385;
  $386 = Math_fround($384 * $90);
  HEAPF32[$150>>2] = $386;
  $387 = Math_fround($384 * $104);
  HEAPF32[$151>>2] = $387;
  $166 = $385;$169 = $386;$173 = $387;
 } else {
  $166 = $72;$169 = $90;$173 = $104;
 }
 $379 = (($normals) + 24|0);
 HEAPF32[$379>>2] = $78;
 $381 = (($normals) + 28|0);
 HEAPF32[$381>>2] = $94;
 $383 = (($normals) + 32|0);
 HEAPF32[$383>>2] = $108;
 $388 = Math_fround($78 * $78);
 $389 = Math_fround($94 * $94);
 $390 = Math_fround($388 + $389);
 $391 = Math_fround($108 * $108);
 $392 = Math_fround($391 + $390);
 $337 = (Math_fround(Math_sqrt((Math_fround($392)))));
 $393 = $337 > Math_fround(0.0);
 if ($393) {
  $394 = Math_fround(Math_fround(1.0) / $337);
  $395 = Math_fround($394 * $78);
  HEAPF32[$379>>2] = $395;
  $396 = Math_fround($394 * $94);
  HEAPF32[$381>>2] = $396;
  $397 = Math_fround($394 * $108);
  HEAPF32[$383>>2] = $397;
  $165 = $395;$168 = $396;$172 = $397;
 } else {
  $165 = $78;$168 = $94;$172 = $108;
 }
 $398 = Math_fround($181 * $166);
 $399 = Math_fround($183 * $169);
 $400 = Math_fround($398 + $399);
 $401 = Math_fround($186 * $173);
 $160 = Math_fround($400 + $401);
 $402 = $160 < Math_fround(0.0);
 if ($402) {
  $159 = Math_fround(-$160);
  $162 = $159;
 } else {
  $162 = $160;
 }
 $161 = $162 < Math_fround(0.0);
 $163 = $161 ? Math_fround(0.0) : $162;
 $164 = Math_fround($166 * $165);
 $167 = Math_fround($169 * $168);
 $170 = Math_fround($164 + $167);
 $171 = Math_fround($173 * $172);
 $174 = Math_fround($170 + $171);
 $175 = $174 < Math_fround(0.0);
 if ($175) {
  $176 = Math_fround(-$174);
  $178 = $176;
 } else {
  $178 = $174;
 }
 $177 = $178 < $163;
 $179 = $177 ? $163 : $178;
 $180 = Math_fround($181 * $165);
 $182 = Math_fround($183 * $168);
 $184 = Math_fround($180 + $182);
 $185 = Math_fround($186 * $172);
 $187 = Math_fround($184 + $185);
 $188 = $187 < Math_fround(0.0);
 if ($188) {
  $189 = Math_fround(-$187);
  $191 = $189;
 } else {
  $191 = $187;
 }
 $190 = $191 < $179;
 $192 = $190 ? $179 : $191;
 $193 = $192 > Math_fround(9.99999974737875163555E-5);
 if ($193) {
  $194 = (($normals) + 12|0);
  $195 = (($normals) + 24|0);
  (__ZN10Matrix4x4f8SetBasisERK8Vector3fS2_S2_($normalMatrix,$normals,$194,$195)|0);
  (__Z25InvertMatrix4x4_General3DPKfPf($normalMatrix,$normalInverse)|0);
  (__ZN10Matrix4x4f9TransposeEv($normalInverse)|0);
  $196 = Math_fround(HEAPF32[616648>>2]);
  $197 = Math_fround(HEAPF32[616680>>2]);
  $198 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
  $199 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
  $200 = Math_fround(HEAPF32[$normalInverse>>2]);
  $201 = (($normalInverse) + 4|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($normalInverse) + 8|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = Math_fround($200 * $200);
  $206 = Math_fround($202 * $202);
  $207 = Math_fround($205 + $206);
  $208 = Math_fround($204 * $204);
  $209 = Math_fround($207 + $208);
  $210 = (Math_fround(Math_sqrt((Math_fround($209)))));
  $211 = $210 > $196;
  if ($211) {
   $212 = Math_fround($200 / $210);
   $213 = Math_fround($202 / $210);
   $214 = Math_fround($204 / $210);
   $215 = $212;$216 = $213;$217 = $214;
  } else {
   $215 = $197;$216 = $198;$217 = $199;
  }
  HEAPF32[$normals>>2] = $215;
  HEAPF32[$136>>2] = $216;
  HEAPF32[$137>>2] = $217;
  $218 = (($normalInverse) + 16|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = (($normalInverse) + 20|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = (($normalInverse) + 24|0);
  $223 = Math_fround(HEAPF32[$222>>2]);
  $224 = Math_fround($219 * $219);
  $225 = Math_fround($221 * $221);
  $226 = Math_fround($224 + $225);
  $227 = Math_fround($223 * $223);
  $228 = Math_fround($226 + $227);
  $229 = (Math_fround(Math_sqrt((Math_fround($228)))));
  $230 = $229 > $196;
  if ($230) {
   $356 = Math_fround($219 / $229);
   $357 = Math_fround($221 / $229);
   $358 = Math_fround($223 / $229);
   $359 = $356;$360 = $357;$361 = $358;
  } else {
   $359 = $197;$360 = $198;$361 = $199;
  }
  HEAPF32[$149>>2] = $359;
  HEAPF32[$150>>2] = $360;
  HEAPF32[$151>>2] = $361;
  $362 = (($normalInverse) + 32|0);
  $363 = Math_fround(HEAPF32[$362>>2]);
  $364 = (($normalInverse) + 36|0);
  $365 = Math_fround(HEAPF32[$364>>2]);
  $366 = (($normalInverse) + 40|0);
  $367 = Math_fround(HEAPF32[$366>>2]);
  $368 = Math_fround($363 * $363);
  $369 = Math_fround($365 * $365);
  $370 = Math_fround($368 + $369);
  $371 = Math_fround($367 * $367);
  $372 = Math_fround($370 + $371);
  $373 = (Math_fround(Math_sqrt((Math_fround($372)))));
  $374 = $373 > $196;
  if ($374) {
   $375 = Math_fround($363 / $373);
   $376 = Math_fround($365 / $373);
   $377 = Math_fround($367 / $373);
   $378 = $375;$380 = $376;$382 = $377;
  } else {
   $378 = $197;$380 = $198;$382 = $199;
  }
  HEAPF32[$379>>2] = $378;
  HEAPF32[$381>>2] = $380;
  HEAPF32[$383>>2] = $382;
  $278 = $215;$280 = $216;$283 = $217;$317 = $359;$319 = $360;$322 = $361;$339 = $378;$341 = $380;$344 = $382;
 } else {
  $278 = $181;$280 = $183;$283 = $186;$317 = $166;$319 = $169;$322 = $173;$339 = $165;$341 = $168;$344 = $172;
 }
 HEAPF32[$axisDistances>>2] = Math_fround(0.0);
 $231 = (($axisDistances) + 4|0);
 HEAPF32[$231>>2] = Math_fround(0.0);
 $232 = (($axisDistances) + 8|0);
 HEAPF32[$232>>2] = Math_fround(0.0);
 $233 = (($aabb) + 12|0);
 if ($193) {
  $axis2$020$us = 0;
  while(1) {
   $234 = (($233) + ($axis2$020$us<<2)|0);
   $235 = Math_fround(HEAPF32[$234>>2]);
   $236 = $axis2$020$us << 2;
   $237 = (($transform) + ($236<<2)|0);
   $238 = Math_fround(HEAPF32[$237>>2]);
   $239 = $236 | 1;
   $240 = (($transform) + ($239<<2)|0);
   $241 = Math_fround(HEAPF32[$240>>2]);
   $242 = $236 | 2;
   $243 = (($transform) + ($242<<2)|0);
   $244 = Math_fround(HEAPF32[$243>>2]);
   $245 = Math_fround($235 * $238);
   $246 = Math_fround($235 * $241);
   $247 = Math_fround($235 * $244);
   $248 = (($normals) + (($axis2$020$us*12)|0)|0);
   $249 = Math_fround(HEAPF32[$248>>2]);
   $250 = Math_fround($245 * $249);
   $251 = ((($normals) + (($axis2$020$us*12)|0)|0) + 4|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = Math_fround($246 * $252);
   $254 = Math_fround($250 + $253);
   $255 = ((($normals) + (($axis2$020$us*12)|0)|0) + 8|0);
   $256 = Math_fround(HEAPF32[$255>>2]);
   $257 = Math_fround($247 * $256);
   $258 = Math_fround($254 + $257);
   $259 = Math_fround($115 * $249);
   $260 = Math_fround($118 * $252);
   $261 = Math_fround($259 + $260);
   $262 = Math_fround($121 * $256);
   $263 = Math_fround($261 + $262);
   $264 = $263 < Math_fround(0.0);
   if ($264) {
    $265 = Math_fround(-$263);
    $270 = $265;
   } else {
    $270 = $263;
   }
   $266 = $258 < Math_fround(0.0);
   if ($266) {
    $267 = Math_fround(-$258);
    $269 = $267;
   } else {
    $269 = $258;
   }
   $268 = Math_fround($270 - $269);
   $271 = $268 < Math_fround(0.0);
   $272 = $271 ? Math_fround(0.0) : $268;
   $273 = (($axisDistances) + ($axis2$020$us<<2)|0);
   HEAPF32[$273>>2] = $272;
   $274 = (($axis2$020$us) + 1)|0;
   $exitcond = ($274|0)==(3);
   if ($exitcond) {
    break;
   } else {
    $axis2$020$us = $274;
   }
  }
  $$pre27 = Math_fround(HEAPF32[$axisDistances>>2]);
  $291 = $$pre27;
 } else {
  $275 = Math_fround(HEAPF32[$233>>2]);
  $276 = Math_fround($275 * $143);
  $277 = Math_fround($115 * $278);
  $279 = Math_fround($118 * $280);
  $281 = Math_fround($277 + $279);
  $282 = Math_fround($121 * $283);
  $284 = Math_fround($281 + $282);
  $285 = $284 < Math_fround(0.0);
  if ($285) {
   $286 = Math_fround(-$284);
   $310 = $286;
  } else {
   $310 = $284;
  }
  $287 = $276 < Math_fround(0.0);
  if ($287) {
   $288 = Math_fround(-$276);
   $309 = $288;
  } else {
   $309 = $276;
  }
  $308 = Math_fround($310 - $309);
  $311 = $308 < Math_fround(0.0);
  $312 = $311 ? Math_fround(0.0) : $308;
  HEAPF32[$axisDistances>>2] = $312;
  $313 = (($233) + 4|0);
  $314 = Math_fround(HEAPF32[$313>>2]);
  $315 = Math_fround($314 * $157);
  $316 = Math_fround($115 * $317);
  $318 = Math_fround($118 * $319);
  $320 = Math_fround($316 + $318);
  $321 = Math_fround($121 * $322);
  $323 = Math_fround($320 + $321);
  $324 = $323 < Math_fround(0.0);
  if ($324) {
   $325 = Math_fround(-$323);
   $330 = $325;
  } else {
   $330 = $323;
  }
  $326 = $315 < Math_fround(0.0);
  if ($326) {
   $327 = Math_fround(-$315);
   $329 = $327;
  } else {
   $329 = $315;
  }
  $328 = Math_fround($330 - $329);
  $331 = $328 < Math_fround(0.0);
  $332 = $331 ? Math_fround(0.0) : $328;
  $333 = (($axisDistances) + 4|0);
  HEAPF32[$333>>2] = $332;
  $334 = (($233) + 8|0);
  $335 = Math_fround(HEAPF32[$334>>2]);
  $336 = Math_fround($335 * $337);
  $338 = Math_fround($115 * $339);
  $340 = Math_fround($118 * $341);
  $342 = Math_fround($338 + $340);
  $343 = Math_fround($121 * $344);
  $345 = Math_fround($342 + $343);
  $346 = $345 < Math_fround(0.0);
  if ($346) {
   $347 = Math_fround(-$345);
   $352 = $347;
  } else {
   $352 = $345;
  }
  $348 = $336 < Math_fround(0.0);
  if ($348) {
   $349 = Math_fround(-$336);
   $351 = $349;
  } else {
   $351 = $336;
  }
  $350 = Math_fround($352 - $351);
  $353 = $350 < Math_fround(0.0);
  $354 = $353 ? Math_fround(0.0) : $350;
  $355 = (($axisDistances) + 8|0);
  HEAPF32[$355>>2] = $354;
  $291 = $312;
 }
 if ($193) {
  $289 = Math_fround(HEAPF32[$231>>2]);
  $290 = $291 < $289;
  $292 = $290 ? $289 : $291;
  $293 = Math_fround(HEAPF32[$232>>2]);
  $294 = $292 < $293;
  $295 = $294 ? $293 : $292;
  $296 = Math_fround(HEAPF32[$127>>2]);
  $297 = $295 < $296;
  $$0 = $297;
  STACKTOP = sp;return ($$0|0);
 } else {
  $298 = Math_fround($291 * $291);
  $299 = Math_fround(HEAPF32[$231>>2]);
  $300 = Math_fround($299 * $299);
  $301 = Math_fround($298 + $300);
  $302 = Math_fround(HEAPF32[$232>>2]);
  $303 = Math_fround($302 * $302);
  $304 = Math_fround($301 + $303);
  $305 = Math_fround(HEAPF32[$127>>2]);
  $306 = Math_fround($305 * $305);
  $307 = $304 < $306;
  $$0 = $307;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z20IntersectAABBFrustumRK4AABBPK5Planej($a,$p,$inClipMask) {
 $a = $a|0;
 $p = $p|0;
 $inClipMask = $inClipMask|0;
 var $$0 = 0, $$013 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $mk$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($inClipMask|0)==(0);
 if ($0) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($a) + 4|0);
 $2 = (($a) + 8|0);
 $3 = (($a) + 12|0);
 $4 = (($a) + 16|0);
 $5 = (($a) + 20|0);
 $$013 = $p;$mk$02 = 1;
 while(1) {
  $6 = $mk$02 & $inClipMask;
  $7 = ($6|0)==(0);
  if (!($7)) {
   $8 = Math_fround(HEAPF32[$$013>>2]);
   $9 = Math_fround(HEAPF32[$a>>2]);
   $10 = Math_fround($8 * $9);
   $11 = (($$013) + 4|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = Math_fround(HEAPF32[$1>>2]);
   $14 = Math_fround($12 * $13);
   $15 = Math_fround($10 + $14);
   $16 = (($$013) + 8|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround(HEAPF32[$2>>2]);
   $19 = Math_fround($17 * $18);
   $20 = Math_fround($15 + $19);
   $21 = (($$013) + 12|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = Math_fround($22 + $20);
   $24 = $8 < Math_fround(0.0);
   if ($24) {
    $25 = Math_fround(-$8);
    $32 = $25;
   } else {
    $32 = $8;
   }
   $26 = $12 < Math_fround(0.0);
   if ($26) {
    $27 = Math_fround(-$12);
    $35 = $27;
   } else {
    $35 = $12;
   }
   $28 = $17 < Math_fround(0.0);
   if ($28) {
    $29 = Math_fround(-$17);
    $39 = $29;
   } else {
    $39 = $17;
   }
   $30 = Math_fround(HEAPF32[$3>>2]);
   $31 = Math_fround($32 * $30);
   $33 = Math_fround(HEAPF32[$4>>2]);
   $34 = Math_fround($35 * $33);
   $36 = Math_fround($31 + $34);
   $37 = Math_fround(HEAPF32[$5>>2]);
   $38 = Math_fround($39 * $37);
   $40 = Math_fround($36 + $38);
   $41 = Math_fround($23 + $40);
   $42 = $41 < Math_fround(0.0);
   if ($42) {
    $$0 = 0;
    label = 12;
    break;
   }
  }
  $43 = $mk$02 << 1;
  $44 = (($$013) + 16|0);
  $45 = ($43>>>0)>($inClipMask>>>0);
  if ($45) {
   $$0 = 1;
   label = 12;
   break;
  } else {
   $$013 = $44;$mk$02 = $43;
  }
 }
 if ((label|0) == 12) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z24IntersectAABBFrustumFullRK4AABBPK5Plane($a,$p) {
 $a = $a|0;
 $p = $p|0;
 var $$0$i = 0, $$013$i = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = (($a) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($a) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($a) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($a) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($a) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $$013$i = $p;$i$02$i = 0;
 while(1) {
  $11 = Math_fround(HEAPF32[$$013$i>>2]);
  $12 = Math_fround($0 * $11);
  $13 = (($$013$i) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($2 * $14);
  $16 = Math_fround($12 + $15);
  $17 = (($$013$i) + 8|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = Math_fround($4 * $18);
  $20 = Math_fround($16 + $19);
  $21 = (($$013$i) + 12|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($22 + $20);
  $24 = $11 < Math_fround(0.0);
  if ($24) {
   $25 = Math_fround(-$11);
   $31 = $25;
  } else {
   $31 = $11;
  }
  $26 = $14 < Math_fround(0.0);
  if ($26) {
   $27 = Math_fround(-$14);
   $33 = $27;
  } else {
   $33 = $14;
  }
  $28 = $18 < Math_fround(0.0);
  if ($28) {
   $29 = Math_fround(-$18);
   $36 = $29;
  } else {
   $36 = $18;
  }
  $30 = Math_fround($6 * $31);
  $32 = Math_fround($8 * $33);
  $34 = Math_fround($30 + $32);
  $35 = Math_fround($10 * $36);
  $37 = Math_fround($34 + $35);
  $38 = Math_fround($23 + $37);
  $39 = $38 < Math_fround(0.0);
  if ($39) {
   $$0$i = 0;
   label = 10;
   break;
  }
  $40 = (($i$02$i) + 1)|0;
  $41 = (($$013$i) + 16|0);
  $42 = ($40|0)<(6);
  if ($42) {
   $$013$i = $41;$i$02$i = $40;
  } else {
   $$0$i = 1;
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __Z24IntersectAABBPlaneBoundsRK4AABBPK5Planei($a,$p,$planeCount) {
 $a = $a|0;
 $p = $p|0;
 $planeCount = $planeCount|0;
 var $$0 = 0, $$013 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($planeCount|0)>(0);
 if (!($0)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = Math_fround(HEAPF32[$a>>2]);
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($a) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($a) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($a) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($a) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $$013 = $p;$i$02 = 0;
 while(1) {
  $12 = Math_fround(HEAPF32[$$013>>2]);
  $13 = Math_fround($12 * $1);
  $14 = (($$013) + 4|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($15 * $3);
  $17 = Math_fround($13 + $16);
  $18 = (($$013) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($19 * $5);
  $21 = Math_fround($17 + $20);
  $22 = (($$013) + 12|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($23 + $21);
  $25 = $12 < Math_fround(0.0);
  if ($25) {
   $26 = Math_fround(-$12);
   $32 = $26;
  } else {
   $32 = $12;
  }
  $27 = $15 < Math_fround(0.0);
  if ($27) {
   $28 = Math_fround(-$15);
   $34 = $28;
  } else {
   $34 = $15;
  }
  $29 = $19 < Math_fround(0.0);
  if ($29) {
   $30 = Math_fround(-$19);
   $37 = $30;
  } else {
   $37 = $19;
  }
  $31 = Math_fround($32 * $7);
  $33 = Math_fround($34 * $9);
  $35 = Math_fround($31 + $33);
  $36 = Math_fround($37 * $11);
  $38 = Math_fround($35 + $36);
  $39 = Math_fround($24 + $38);
  $40 = $39 < Math_fround(0.0);
  if ($40) {
   $$0 = 0;
   label = 11;
   break;
  }
  $41 = (($i$02) + 1)|0;
  $42 = (($$013) + 16|0);
  $43 = ($41|0)<($planeCount|0);
  if ($43) {
   $$013 = $42;$i$02 = $41;
  } else {
   $$0 = 1;
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z22PrepareOptimizedPlanesPK5PlaneiPKN4math7_float4E($planes,$planeCount,$outPlanesSOA) {
 $planes = $planes|0;
 $planeCount = $planeCount|0;
 $outPlanesSOA = $outPlanesSOA|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$lcssa = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($planeCount|0)>(0);
 if (!($0)) {
  $i$0$lcssa = 0;
  STACKTOP = sp;return ($i$0$lcssa|0);
 }
 $1 = (($planeCount) + -1)|0;
 $i$02 = 0;
 while(1) {
  $2 = $i$02 | 1;
  $3 = ($1|0)<($2|0);
  $4 = $3 ? $1 : $2;
  $5 = $i$02 | 2;
  $6 = ($1|0)<($5|0);
  $7 = $6 ? $1 : $5;
  $8 = $i$02 | 3;
  $9 = ($1|0)<($8|0);
  $10 = $9 ? $1 : $8;
  $11 = (($planes) + ($i$02<<4)|0);
  $12 = (($planes) + ($4<<4)|0);
  $13 = (($planes) + ($7<<4)|0);
  $14 = (($planes) + ($10<<4)|0);
  $15 = Math_fround(HEAPF32[$11>>2]);
  $16 = Math_fround(HEAPF32[$12>>2]);
  $17 = Math_fround(HEAPF32[$13>>2]);
  $18 = Math_fround(HEAPF32[$14>>2]);
  $19 = (($outPlanesSOA) + ($i$02<<4)|0);
  HEAPF32[$19>>2] = $15;
  $20 = ((($outPlanesSOA) + ($i$02<<4)|0) + 4|0);
  HEAPF32[$20>>2] = $16;
  $21 = ((($outPlanesSOA) + ($i$02<<4)|0) + 8|0);
  HEAPF32[$21>>2] = $17;
  $22 = ((($outPlanesSOA) + ($i$02<<4)|0) + 12|0);
  HEAPF32[$22>>2] = $18;
  $23 = $i$02 | 1;
  $24 = (($11) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($12) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($13) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($14) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($outPlanesSOA) + ($23<<4)|0);
  HEAPF32[$32>>2] = $25;
  $33 = ((($outPlanesSOA) + ($23<<4)|0) + 4|0);
  HEAPF32[$33>>2] = $27;
  $34 = ((($outPlanesSOA) + ($23<<4)|0) + 8|0);
  HEAPF32[$34>>2] = $29;
  $35 = ((($outPlanesSOA) + ($23<<4)|0) + 12|0);
  HEAPF32[$35>>2] = $31;
  $36 = $i$02 | 2;
  $37 = (($11) + 8|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($12) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($13) + 8|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($14) + 8|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($outPlanesSOA) + ($36<<4)|0);
  HEAPF32[$45>>2] = $38;
  $46 = ((($outPlanesSOA) + ($36<<4)|0) + 4|0);
  HEAPF32[$46>>2] = $40;
  $47 = ((($outPlanesSOA) + ($36<<4)|0) + 8|0);
  HEAPF32[$47>>2] = $42;
  $48 = ((($outPlanesSOA) + ($36<<4)|0) + 12|0);
  HEAPF32[$48>>2] = $44;
  $49 = $i$02 | 3;
  $50 = (($11) + 12|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($12) + 12|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = (($13) + 12|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($14) + 12|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($outPlanesSOA) + ($49<<4)|0);
  HEAPF32[$58>>2] = $51;
  $59 = ((($outPlanesSOA) + ($49<<4)|0) + 4|0);
  HEAPF32[$59>>2] = $53;
  $60 = ((($outPlanesSOA) + ($49<<4)|0) + 8|0);
  HEAPF32[$60>>2] = $55;
  $61 = ((($outPlanesSOA) + ($49<<4)|0) + 12|0);
  HEAPF32[$61>>2] = $57;
  $62 = (($i$02) + 4)|0;
  $63 = ($62|0)<($planeCount|0);
  if ($63) {
   $i$02 = $62;
  } else {
   $i$0$lcssa = $62;
   break;
  }
 }
 STACKTOP = sp;return ($i$0$lcssa|0);
}
function __Z33IntersectAABBPlaneBoundsOptimizedRK4AABBPKN4math7_float4Ei($a,$optimizedPlanes,$planeCount) {
 $a = $a|0;
 $optimizedPlanes = $optimizedPlanes|0;
 $planeCount = $planeCount|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0;
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$053 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = (($a) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($a) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($a) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($a) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($a) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = ($planeCount|0)>(0);
 if ($11) {
  $i$053 = 0;
 } else {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $14 = (($optimizedPlanes) + ($i$053<<4)|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = ((($optimizedPlanes) + ($i$053<<4)|0) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = ((($optimizedPlanes) + ($i$053<<4)|0) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = ((($optimizedPlanes) + ($i$053<<4)|0) + 12|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = $i$053 | 1;
  $23 = (($optimizedPlanes) + ($22<<4)|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = ((($optimizedPlanes) + ($22<<4)|0) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = ((($optimizedPlanes) + ($22<<4)|0) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = ((($optimizedPlanes) + ($22<<4)|0) + 12|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = $i$053 | 2;
  $32 = (($optimizedPlanes) + ($31<<4)|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = ((($optimizedPlanes) + ($31<<4)|0) + 4|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = ((($optimizedPlanes) + ($31<<4)|0) + 8|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = ((($optimizedPlanes) + ($31<<4)|0) + 12|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = $i$053 | 3;
  $41 = (($optimizedPlanes) + ($40<<4)|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = ((($optimizedPlanes) + ($40<<4)|0) + 4|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = ((($optimizedPlanes) + ($40<<4)|0) + 8|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = ((($optimizedPlanes) + ($40<<4)|0) + 12|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (Math_fround(Math_abs((Math_fround($15)))));
  $50 = (Math_fround(Math_abs((Math_fround($17)))));
  $51 = (Math_fround(Math_abs((Math_fround($19)))));
  $52 = (Math_fround(Math_abs((Math_fround($21)))));
  $53 = (Math_fround(Math_abs((Math_fround($24)))));
  $54 = (Math_fround(Math_abs((Math_fround($26)))));
  $55 = (Math_fround(Math_abs((Math_fround($28)))));
  $56 = (Math_fround(Math_abs((Math_fround($30)))));
  $57 = (Math_fround(Math_abs((Math_fround($33)))));
  $58 = (Math_fround(Math_abs((Math_fround($35)))));
  $59 = (Math_fround(Math_abs((Math_fround($37)))));
  $60 = (Math_fround(Math_abs((Math_fround($39)))));
  $61 = Math_fround($0 * $15);
  $62 = Math_fround($0 * $17);
  $63 = Math_fround($0 * $19);
  $64 = Math_fround($0 * $21);
  $65 = Math_fround($61 + $42);
  $66 = Math_fround($62 + $44);
  $67 = Math_fround($63 + $46);
  $68 = Math_fround($64 + $48);
  $69 = Math_fround($2 * $24);
  $70 = Math_fround($2 * $26);
  $71 = Math_fround($2 * $28);
  $72 = Math_fround($2 * $30);
  $73 = Math_fround($69 + $65);
  $74 = Math_fround($70 + $66);
  $75 = Math_fround($71 + $67);
  $76 = Math_fround($72 + $68);
  $77 = Math_fround($4 * $33);
  $78 = Math_fround($4 * $35);
  $79 = Math_fround($4 * $37);
  $80 = Math_fround($4 * $39);
  $81 = Math_fround($77 + $73);
  $82 = Math_fround($78 + $74);
  $83 = Math_fround($79 + $75);
  $84 = Math_fround($80 + $76);
  $85 = Math_fround($6 * $49);
  $86 = Math_fround($6 * $50);
  $87 = Math_fround($6 * $51);
  $88 = Math_fround($6 * $52);
  $89 = Math_fround($8 * $53);
  $90 = Math_fround($8 * $54);
  $91 = Math_fround($8 * $55);
  $92 = Math_fround($8 * $56);
  $93 = Math_fround($85 + $89);
  $94 = Math_fround($86 + $90);
  $95 = Math_fround($87 + $91);
  $96 = Math_fround($88 + $92);
  $97 = Math_fround($10 * $57);
  $98 = Math_fround($10 * $58);
  $99 = Math_fround($10 * $59);
  $100 = Math_fround($10 * $60);
  $101 = Math_fround($93 + $97);
  $102 = Math_fround($94 + $98);
  $103 = Math_fround($95 + $99);
  $104 = Math_fround($96 + $100);
  $105 = Math_fround($81 + $101);
  $106 = Math_fround($82 + $102);
  $107 = Math_fround($83 + $103);
  $108 = Math_fround($84 + $104);
  $109 = $105 < Math_fround(0.0);
  $110 = $106 < Math_fround(0.0);
  $111 = $107 < Math_fround(0.0);
  $112 = $108 < Math_fround(0.0);
  $113 = $110 | $109;
  $114 = $113 | $111;
  $115 = $114 | $112;
  $13 = (($i$053) + 4)|0;
  if ($115) {
   $$0 = 0;
   label = 4;
   break;
  }
  $12 = ($13|0)<($planeCount|0);
  if ($12) {
   $i$053 = $13;
  } else {
   $$0 = 1;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z22PointDistanceToFrustumRK8Vector4fPK5Planei($point,$p,$planeCount) {
 $point = $point|0;
 $p = $p|0;
 $planeCount = $planeCount|0;
 var $$0 = Math_fround(0), $$012 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $exitcond = 0, $i$04 = 0, $maxDistanceNegative$03 = Math_fround(0), $maxDistanceNegative$1 = Math_fround(0), $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($planeCount|0)>(0);
 if (!($0)) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $1 = Math_fround(HEAPF32[$point>>2]);
 $2 = (($point) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($point) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $$012 = $p;$i$04 = 0;$maxDistanceNegative$03 = Math_fround(-inf);
 while(1) {
  $6 = Math_fround(HEAPF32[$$012>>2]);
  $7 = Math_fround($6 * $1);
  $8 = (($$012) + 4|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($9 * $3);
  $11 = Math_fround($7 + $10);
  $12 = (($$012) + 8|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($13 * $5);
  $15 = Math_fround($11 + $14);
  $16 = (($$012) + 12|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($17 + $15);
  $19 = $18 < Math_fround(0.0);
  $20 = $18 > $maxDistanceNegative$03;
  $or$cond = $19 & $20;
  $maxDistanceNegative$1 = $or$cond ? $18 : $maxDistanceNegative$03;
  $21 = (($i$04) + 1)|0;
  $22 = (($$012) + 16|0);
  $exitcond = ($21|0)==($planeCount|0);
  if ($exitcond) {
   break;
  } else {
   $$012 = $22;$i$04 = $21;$maxDistanceNegative$03 = $maxDistanceNegative$1;
  }
 }
 $23 = $maxDistanceNegative$1 != Math_fround(-inf);
 if (!($23)) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $24 = Math_fround(-$maxDistanceNegative$1);
 $$0 = $24;
 STACKTOP = sp;return (Math_fround($$0));
}
function __Z21IntersectSegmentPlaneRK8Vector3fS1_RK5PlanePS_($p1,$p2,$plane,$result) {
 $p1 = $p1|0;
 $p2 = $p2|0;
 $plane = $plane|0;
 $result = $result|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$p2>>2]);
 $1 = Math_fround(HEAPF32[$p1>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($p2) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($p1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($p2) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($p1) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = Math_fround(HEAPF32[$plane>>2]);
 $14 = Math_fround($2 * $13);
 $15 = (($plane) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($7 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($plane) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($12 * $20);
 $22 = Math_fround($18 + $21);
 $23 = $22 < Math_fround(0.0);
 if ($23) {
  $24 = Math_fround(-$22);
  $26 = $24;
 } else {
  $26 = $22;
 }
 $25 = !($26 <= Math_fround(9.99999997475242707878E-7));
 if (!($25)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = Math_fround($1 * $13);
 $28 = Math_fround($6 * $16);
 $29 = Math_fround($27 + $28);
 $30 = Math_fround($11 * $20);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround(-$31);
 $33 = (($plane) + 12|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($32 - $34);
 $36 = Math_fround($35 / $22);
 $37 = $36 < Math_fround(0.0);
 $38 = $36 > Math_fround(1.0);
 $or$cond = $37 | $38;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = Math_fround($2 * $36);
 $40 = Math_fround($7 * $36);
 $41 = Math_fround($12 * $36);
 $42 = Math_fround($1 + $39);
 $43 = Math_fround($6 + $40);
 $44 = Math_fround($11 + $41);
 HEAPF32[$result>>2] = $42;
 $45 = (($result) + 4|0);
 HEAPF32[$45>>2] = $43;
 $46 = (($result) + 8|0);
 HEAPF32[$46>>2] = $44;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4Node6InsertEfffb($this,$width,$height,$padding,$use4PixelBoundaries) {
 $this = $this|0;
 $width = Math_fround($width);
 $height = Math_fround($height);
 $padding = Math_fround($padding);
 $use4PixelBoundaries = $use4PixelBoundaries|0;
 var $$02 = 0, $$lcssa = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0;
 var $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond$us = 0, $or$cond4$us = 0, $this$tr = 0, $this$tr$be = 0;
 var $this$tr$be$in = 0, $this$tr$be$us = 0, $this$tr$be$us$in = 0, $this$tr$lcssa17 = 0, $this$tr$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($padding * Math_fround(2.0));
 $1 = Math_fround($width + $padding);
 $2 = (~~(($1)));
 $3 = (($2) + 3)|0;
 $4 = $3 & -4;
 $5 = Math_fround($height + $padding);
 $6 = (~~(($5)));
 $7 = (($6) + 3)|0;
 $8 = $7 & -4;
 L1: do {
  if ($use4PixelBoundaries) {
   $this$tr$us = $this;
   L21: while(1) {
    $9 = HEAP32[$this$tr$us>>2]|0;
    $10 = ($9|0)==(0|0);
    do {
     if ($10) {
      $14 = (($this$tr$us) + 24|0);
      $15 = HEAP8[$14>>0]|0;
      $16 = ($15<<24>>24)==(0);
      if (!($16)) {
       $$02 = 0;
       label = 27;
       break L21;
      }
      $17 = (($this$tr$us) + 16|0);
      $18 = Math_fround(HEAPF32[$17>>2]);
      $19 = Math_fround($18 - $padding);
      $20 = Math_fround($19 + Math_fround(0.5));
      $21 = $20 < $width;
      if ($21) {
       $$02 = 0;
       label = 27;
       break L21;
      }
      $22 = (($this$tr$us) + 20|0);
      $23 = Math_fround(HEAPF32[$22>>2]);
      $24 = Math_fround($23 - $padding);
      $25 = Math_fround($24 + Math_fround(0.5));
      $26 = $25 < $height;
      if ($26) {
       $$02 = 0;
       label = 27;
       break L21;
      }
      $27 = Math_fround($18 - $width);
      $28 = Math_fround($23 - $height);
      $29 = !($27 <= $0);
      $30 = !($28 <= $0);
      $or$cond$us = $29 | $30;
      if (!($or$cond$us)) {
       $$lcssa = $14;$this$tr$lcssa17 = $this$tr$us;
       break L1;
      }
      $31 = $27 < Math_fround(4.0);
      $32 = $28 < Math_fround(4.0);
      $or$cond4$us = $31 & $32;
      if ($or$cond4$us) {
       label = 23;
       break L21;
      }
      $33 = (__Znwj(28)|0);
      ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;HEAP32[$33+16>>2]=0|0;HEAP32[$33+20>>2]=0|0;HEAP8[$33+24>>0]=0|0;
      HEAP32[$this$tr$us>>2] = $33;
      $34 = (__Znwj(28)|0);
      ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;HEAP8[$34+24>>0]=0|0;
      $35 = (($this$tr$us) + 4|0);
      HEAP32[$35>>2] = $34;
      $36 = $27 > $28;
      $37 = HEAP32[$this$tr$us>>2]|0;
      $38 = (($this$tr$us) + 8|0);
      $39 = Math_fround(HEAPF32[$38>>2]);
      $40 = (($this$tr$us) + 12|0);
      $41 = Math_fround(HEAPF32[$40>>2]);
      if ($36) {
       $67 = Math_fround($39 + $width);
       $68 = Math_fround($67 + $padding);
       $69 = Math_fround(HEAPF32[$22>>2]);
       $70 = Math_fround($41 + $69);
       $71 = Math_fround($68 - $39);
       $72 = Math_fround($70 - $41);
       $73 = (($37) + 8|0);
       HEAPF32[$73>>2] = $39;
       $74 = (($37) + 12|0);
       HEAPF32[$74>>2] = $41;
       $75 = (($37) + 16|0);
       HEAPF32[$75>>2] = $71;
       $76 = (($37) + 20|0);
       HEAPF32[$76>>2] = $72;
       $77 = HEAP32[$35>>2]|0;
       $78 = Math_fround(HEAPF32[$38>>2]);
       $79 = (Math_fround(($4|0)));
       $80 = Math_fround($79 + $78);
       $81 = Math_fround(HEAPF32[$40>>2]);
       $82 = Math_fround(HEAPF32[$17>>2]);
       $83 = Math_fround($78 + $82);
       $84 = Math_fround(HEAPF32[$22>>2]);
       $85 = Math_fround($81 + $84);
       $86 = Math_fround($83 - $80);
       $87 = Math_fround($85 - $81);
       $88 = (($77) + 8|0);
       HEAPF32[$88>>2] = $80;
       $89 = (($77) + 12|0);
       HEAPF32[$89>>2] = $81;
       $90 = (($77) + 16|0);
       HEAPF32[$90>>2] = $86;
       $91 = (($77) + 20|0);
       HEAPF32[$91>>2] = $87;
       $this$tr$be$us$in = $this$tr$us;
       break;
      } else {
       $42 = Math_fround(HEAPF32[$17>>2]);
       $43 = Math_fround($39 + $42);
       $44 = Math_fround($41 + $height);
       $45 = Math_fround($44 + $padding);
       $46 = Math_fround($43 - $39);
       $47 = Math_fround($45 - $41);
       $48 = (($37) + 8|0);
       HEAPF32[$48>>2] = $39;
       $49 = (($37) + 12|0);
       HEAPF32[$49>>2] = $41;
       $50 = (($37) + 16|0);
       HEAPF32[$50>>2] = $46;
       $51 = (($37) + 20|0);
       HEAPF32[$51>>2] = $47;
       $52 = HEAP32[$35>>2]|0;
       $53 = Math_fround(HEAPF32[$38>>2]);
       $54 = Math_fround(HEAPF32[$40>>2]);
       $55 = (Math_fround(($8|0)));
       $56 = Math_fround($55 + $54);
       $57 = Math_fround(HEAPF32[$17>>2]);
       $58 = Math_fround($53 + $57);
       $59 = Math_fround(HEAPF32[$22>>2]);
       $60 = Math_fround($54 + $59);
       $61 = Math_fround($58 - $53);
       $62 = Math_fround($60 - $56);
       $63 = (($52) + 8|0);
       HEAPF32[$63>>2] = $53;
       $64 = (($52) + 12|0);
       HEAPF32[$64>>2] = $56;
       $65 = (($52) + 16|0);
       HEAPF32[$65>>2] = $61;
       $66 = (($52) + 20|0);
       HEAPF32[$66>>2] = $62;
       $this$tr$be$us$in = $this$tr$us;
       break;
      }
     } else {
      $11 = (__ZN4Node6InsertEfffb($9,$width,$height,$padding,1)|0);
      $12 = ($11|0)==(0|0);
      if (!($12)) {
       $$02 = $11;
       label = 27;
       break L21;
      }
      $13 = (($this$tr$us) + 4|0);
      $this$tr$be$us$in = $13;
     }
    } while(0);
    $this$tr$be$us = HEAP32[$this$tr$be$us$in>>2]|0;
    $this$tr$us = $this$tr$be$us;
   }
   if ((label|0) == 23) {
    HEAP8[$14>>0] = 1;
    $$02 = $this$tr$us;
    STACKTOP = sp;return ($$02|0);
   }
   else if ((label|0) == 27) {
    STACKTOP = sp;return ($$02|0);
   }
  } else {
   $this$tr = $this;
   L2: while(1) {
    $92 = HEAP32[$this$tr>>2]|0;
    $93 = ($92|0)==(0|0);
    do {
     if ($93) {
      $97 = (($this$tr) + 24|0);
      $98 = HEAP8[$97>>0]|0;
      $99 = ($98<<24>>24)==(0);
      if (!($99)) {
       $$02 = 0;
       label = 27;
       break L2;
      }
      $100 = (($this$tr) + 16|0);
      $101 = Math_fround(HEAPF32[$100>>2]);
      $102 = Math_fround($101 - $padding);
      $103 = Math_fround($102 + Math_fround(0.5));
      $104 = $103 < $width;
      if ($104) {
       $$02 = 0;
       label = 27;
       break L2;
      }
      $105 = (($this$tr) + 20|0);
      $106 = Math_fround(HEAPF32[$105>>2]);
      $107 = Math_fround($106 - $padding);
      $108 = Math_fround($107 + Math_fround(0.5));
      $109 = $108 < $height;
      if ($109) {
       $$02 = 0;
       label = 27;
       break L2;
      }
      $110 = Math_fround($101 - $width);
      $111 = Math_fround($106 - $height);
      $112 = !($110 <= $0);
      $113 = !($111 <= $0);
      $or$cond = $112 | $113;
      if (!($or$cond)) {
       $$lcssa = $97;$this$tr$lcssa17 = $this$tr;
       break L1;
      }
      $114 = (__Znwj(28)|0);
      ;HEAP32[$114+0>>2]=0|0;HEAP32[$114+4>>2]=0|0;HEAP32[$114+8>>2]=0|0;HEAP32[$114+12>>2]=0|0;HEAP32[$114+16>>2]=0|0;HEAP32[$114+20>>2]=0|0;HEAP8[$114+24>>0]=0|0;
      HEAP32[$this$tr>>2] = $114;
      $115 = (__Znwj(28)|0);
      ;HEAP32[$115+0>>2]=0|0;HEAP32[$115+4>>2]=0|0;HEAP32[$115+8>>2]=0|0;HEAP32[$115+12>>2]=0|0;HEAP32[$115+16>>2]=0|0;HEAP32[$115+20>>2]=0|0;HEAP8[$115+24>>0]=0|0;
      $116 = (($this$tr) + 4|0);
      HEAP32[$116>>2] = $115;
      $117 = $110 > $111;
      $118 = HEAP32[$this$tr>>2]|0;
      $119 = (($this$tr) + 8|0);
      $120 = Math_fround(HEAPF32[$119>>2]);
      $121 = (($this$tr) + 12|0);
      $122 = Math_fround(HEAPF32[$121>>2]);
      if ($117) {
       $123 = Math_fround($120 + $width);
       $124 = Math_fround($123 + $padding);
       $125 = Math_fround(HEAPF32[$105>>2]);
       $126 = Math_fround($122 + $125);
       $127 = Math_fround($124 - $120);
       $128 = Math_fround($126 - $122);
       $129 = (($118) + 8|0);
       HEAPF32[$129>>2] = $120;
       $130 = (($118) + 12|0);
       HEAPF32[$130>>2] = $122;
       $131 = (($118) + 16|0);
       HEAPF32[$131>>2] = $127;
       $132 = (($118) + 20|0);
       HEAPF32[$132>>2] = $128;
       $133 = HEAP32[$116>>2]|0;
       $134 = Math_fround(HEAPF32[$119>>2]);
       $135 = (Math_fround(($2|0)));
       $136 = Math_fround($135 + $134);
       $137 = Math_fround(HEAPF32[$121>>2]);
       $138 = Math_fround(HEAPF32[$100>>2]);
       $139 = Math_fround($134 + $138);
       $140 = Math_fround(HEAPF32[$105>>2]);
       $141 = Math_fround($137 + $140);
       $142 = Math_fround($139 - $136);
       $143 = Math_fround($141 - $137);
       $144 = (($133) + 8|0);
       HEAPF32[$144>>2] = $136;
       $145 = (($133) + 12|0);
       HEAPF32[$145>>2] = $137;
       $146 = (($133) + 16|0);
       HEAPF32[$146>>2] = $142;
       $147 = (($133) + 20|0);
       HEAPF32[$147>>2] = $143;
       $this$tr$be$in = $this$tr;
       break;
      } else {
       $148 = Math_fround(HEAPF32[$100>>2]);
       $149 = Math_fround($120 + $148);
       $150 = Math_fround($122 + $height);
       $151 = Math_fround($150 + $padding);
       $152 = Math_fround($149 - $120);
       $153 = Math_fround($151 - $122);
       $154 = (($118) + 8|0);
       HEAPF32[$154>>2] = $120;
       $155 = (($118) + 12|0);
       HEAPF32[$155>>2] = $122;
       $156 = (($118) + 16|0);
       HEAPF32[$156>>2] = $152;
       $157 = (($118) + 20|0);
       HEAPF32[$157>>2] = $153;
       $158 = HEAP32[$116>>2]|0;
       $159 = Math_fround(HEAPF32[$119>>2]);
       $160 = Math_fround(HEAPF32[$121>>2]);
       $161 = (Math_fround(($6|0)));
       $162 = Math_fround($161 + $160);
       $163 = Math_fround(HEAPF32[$100>>2]);
       $164 = Math_fround($159 + $163);
       $165 = Math_fround(HEAPF32[$105>>2]);
       $166 = Math_fround($160 + $165);
       $167 = Math_fround($164 - $159);
       $168 = Math_fround($166 - $162);
       $169 = (($158) + 8|0);
       HEAPF32[$169>>2] = $159;
       $170 = (($158) + 12|0);
       HEAPF32[$170>>2] = $162;
       $171 = (($158) + 16|0);
       HEAPF32[$171>>2] = $167;
       $172 = (($158) + 20|0);
       HEAPF32[$172>>2] = $168;
       $this$tr$be$in = $this$tr;
       break;
      }
     } else {
      $94 = (__ZN4Node6InsertEfffb($92,$width,$height,$padding,0)|0);
      $95 = ($94|0)==(0|0);
      if (!($95)) {
       $$02 = $94;
       label = 27;
       break L2;
      }
      $96 = (($this$tr) + 4|0);
      $this$tr$be$in = $96;
     }
    } while(0);
    $this$tr$be = HEAP32[$this$tr$be$in>>2]|0;
    $this$tr = $this$tr$be;
   }
   if ((label|0) == 27) {
    STACKTOP = sp;return ($$02|0);
   }
  }
 } while(0);
 HEAP8[$$lcssa>>0] = 1;
 $$02 = $this$tr$lcssa17;
 STACKTOP = sp;return ($$02|0);
}
function __ZN4NodeD1Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$0$i$i = 0, $$01$i = 0, $$01$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 L1: do {
  if (!($1)) {
   $2 = HEAP32[$0>>2]|0;
   $3 = ($2|0)==(0|0);
   do {
    if ($3) {
     label = 5;
    } else {
     __THREW__ = 0;
     invoke_vi(3468,($2|0));
     $4 = __THREW__; __THREW__ = 0;
     $5 = $4&1;
     if ($5) {
      $11 = ___cxa_find_matching_catch()|0;
      $12 = tempRet0;
      __ZdlPv($2);
      $$0$i$i = $12;$$01$i$i = $11;
      break;
     } else {
      __ZdlPv($2);
      label = 5;
      break;
     }
    }
   } while(0);
   L8: do {
    if ((label|0) == 5) {
     $6 = (($0) + 4|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = ($7|0)==(0|0);
     do {
      if (!($8)) {
       __THREW__ = 0;
       invoke_vi(3469,($7|0));
       $9 = __THREW__; __THREW__ = 0;
       $10 = $9&1;
       if ($10) {
        $13 = ___cxa_find_matching_catch()|0;
        $14 = tempRet0;
        __ZdlPv($7);
        $$0$i$i = $14;$$01$i$i = $13;
        break L8;
       } else {
        __ZdlPv($7);
        break;
       }
      }
     } while(0);
     __ZdlPv($0);
     break L1;
    }
   } while(0);
   __ZdlPv($0);
   $$0$i = $$0$i$i;$$01$i = $$01$i$i;
   ___resumeException($$01$i|0);
   // unreachable;
  }
 } while(0);
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3469,($16|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  __ZdlPv($16);
  $$0$i = $21;$$01$i = $20;
  ___resumeException($$01$i|0);
  // unreachable;
 } else {
  __ZdlPv($16);
  STACKTOP = sp;return;
 }
}
function __Z18UploadTextureAtlasP9Texture2Db($atlas,$markNoLongerReadable) {
 $atlas = $atlas|0;
 $markNoLongerReadable = $markNoLongerReadable|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($atlas) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = 5;
 } else {
  $3 = (($1) + 32|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4;
 }
 $format$off$i$i = (($5) + -10)|0;
 $6 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($5) + -30)|0;
 $7 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $6 | $7;
 $8 = ($5|0)==(34);
 $or$cond7$i = $or$cond$i | $8;
 $format$off$i4$i = (($5) + -35)|0;
 $9 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $9;
 $format$off$i3$i = (($5) + -41)|0;
 $10 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $10;
 $format$off$i2$i = (($5) + -45)|0;
 $11 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $11;
 $format$off$i1$i = (($5) + -48)|0;
 $12 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $12;
 if (!($or$cond)) {
  $13 = HEAP32[$atlas>>2]|0;
  $14 = (($13) + 160|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$15 & 4095]($atlas);
 }
 if (!($markNoLongerReadable)) {
  $18 = HEAP32[$atlas>>2]|0;
  $19 = (($18) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vii[$20 & 4095]($atlas,0);
  STACKTOP = sp;return;
 }
 $16 = (($atlas) + 127|0);
 HEAP8[$16>>0] = 0;
 $17 = (($atlas) + 129|0);
 HEAP8[$17>>0] = 0;
 $18 = HEAP32[$atlas>>2]|0;
 $19 = (($18) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vii[$20 & 4095]($atlas,0);
 STACKTOP = sp;return;
}
function __Z22PackTextureAtlasSimpleP9Texture2DiiPS0_P5RectTIfEibb($atlas,$atlasMaximumSize,$textureCount,$textures,$outRects,$padding,$upload,$markNoLongerReadable) {
 $atlas = $atlas|0;
 $atlasMaximumSize = $atlasMaximumSize|0;
 $textureCount = $textureCount|0;
 $textures = $textures|0;
 $outRects = $outRects|0;
 $padding = $padding|0;
 $upload = $upload|0;
 $markNoLongerReadable = $markNoLongerReadable|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$15 = 0, $$lcssa7588 = 0, $$lcssa7589 = 0, $$lcssa7591 = 0, $$mux = 0, $$not = 0, $$not92 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i13 = 0, $__new_last2$i$i$i$i$i33 = 0, $__new_last2$i$i$i$i$i43 = 0, $brmerge = 0, $brmerge93 = 0, $cond$not = 0, $exitcond = 0, $format$off$i$i$i = 0, $format$off$i1$i$i = 0, $format$off$i2$i$i = 0, $format$off$i3$i$i = 0;
 var $format$off$i4$i$i = 0, $format$off$i5$i$i = 0, $i$078 = 0, $i1$069 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$cond$not = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond11$i$i = 0, $or$cond13$i$i = 0, $or$cond7$i$i = 0, $or$cond9$i$i = 0, $remap = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i14 = 0, $scevgep$i$i$i$i$i34 = 0, $scevgep$i$i$i$i$i44 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i18 = 0;
 var $scevgep4$i$i$i$i$i38 = 0, $scevgep4$i$i$i$i$i48 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i16 = 0, $uglygep$i$i$i$i$i36 = 0, $uglygep$i$i$i$i$i46 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i17 = 0, $uglygep3$i$i$i$i$i37 = 0, $uglygep3$i$i$i$i$i47 = 0, $uniqueRects = 0, $upload$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $remap = sp + 12|0;
 $uniqueRects = sp;
 $0 = HEAP32[((640792 + 108|0))>>2]|0;
 $1 = ($0|0)>($atlasMaximumSize|0);
 $2 = $1 ? $atlasMaximumSize : $0;
 HEAP32[$remap>>2] = 0;
 $3 = (($remap) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($remap) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ($textureCount|0)==(0);
 do {
  if ($5) {
   $$lcssa7589 = 0;
   label = 50;
  } else {
   __THREW__ = 0;
   invoke_vii(2697,($remap|0),($textureCount|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $14 = ___cxa_find_matching_catch()|0;
    $15 = tempRet0;
    $$1 = $15;$$13 = $14;
    break;
   }
   $8 = ($textureCount|0)>(0);
   if ($8) {
    $21 = 0;$22 = 0;$43 = 0;$i$078 = 0;
    L6: while(1) {
     $9 = (($textures) + ($i$078<<2)|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = ($10|0)==(0|0);
     do {
      if ($11) {
       ;HEAP32[$outRects+0>>2]=0|0;HEAP32[$outRects+4>>2]=0|0;HEAP32[$outRects+8>>2]=0|0;HEAP32[$outRects+12>>2]=0|0;
       $12 = HEAP32[$remap>>2]|0;
       $13 = (($12) + ($i$078<<2)|0);
       HEAP32[$13>>2] = -1;
       $150 = $43;$69 = $21;$70 = $22;
      } else {
       $20 = ($21|0)==($22|0);
       L11: do {
        if ($20) {
         $29 = $21;
         label = 13;
        } else {
         $24 = $21;
         while(1) {
          $23 = HEAP32[$24>>2]|0;
          $25 = ($23|0)==($10|0);
          if ($25) {
           $29 = $24;
           label = 13;
           break L11;
          }
          $26 = (($24) + 4|0);
          $27 = ($26|0)==($22|0);
          if ($27) {
           break;
          } else {
           $24 = $26;
          }
         }
        }
       } while(0);
       if ((label|0) == 13) {
        label = 0;
        $28 = ($29|0)==($22|0);
        if (!($28)) {
         $30 = $29;
         $31 = $21;
         $32 = (($30) - ($31))|0;
         $33 = $32 >> 2;
         $34 = HEAP32[$remap>>2]|0;
         $35 = (($34) + ($i$078<<2)|0);
         HEAP32[$35>>2] = $33;
         $150 = $43;$69 = $21;$70 = $22;
         break;
        }
       }
       $36 = $22;
       $37 = $21;
       $38 = (($36) - ($37))|0;
       $39 = $38 >> 2;
       $40 = HEAP32[$remap>>2]|0;
       $41 = (($40) + ($i$078<<2)|0);
       HEAP32[$41>>2] = $39;
       $42 = ($22|0)==($43|0);
       if (!($42)) {
        $44 = ($22|0)==(0|0);
        if ($44) {
         $46 = 0;
        } else {
         HEAP32[$22>>2] = $10;
         $46 = $22;
        }
        $45 = (($46) + 4|0);
        $150 = $43;$69 = $21;$70 = $45;
        break;
       }
       $47 = (($39) + 1)|0;
       $48 = ($47>>>0)>(1073741823);
       if ($48) {
        label = 20;
        break L6;
       }
       $51 = ($39>>>0)<(536870911);
       if ($51) {
        $52 = $38 >> 1;
        $53 = ($52>>>0)<($47>>>0);
        $54 = $53 ? $47 : $52;
        $55 = ($54|0)==(0);
        if ($55) {
         $$0$i3$i$i = 0;$61 = 0;
        } else {
         $$0$i2$i$i = $54;
         label = 24;
        }
       } else {
        $$0$i2$i$i = 1073741823;
        label = 24;
       }
       if ((label|0) == 24) {
        label = 0;
        $56 = $$0$i2$i$i << 2;
        __THREW__ = 0;
        $57 = (invoke_ii(2988,($56|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 7;
         break L6;
        }
        $$0$i3$i$i = $$0$i2$i$i;$61 = $57;
       }
       $60 = (($61) + ($39<<2)|0);
       $62 = (($61) + ($$0$i3$i$i<<2)|0);
       $63 = ($60|0)==(0|0);
       if (!($63)) {
        HEAP32[$60>>2] = $10;
       }
       $64 = (($61) + ($47<<2)|0);
       _memcpy(($61|0),($21|0),($38|0))|0;
       $65 = ($21|0)==(0|0);
       if ($65) {
        $150 = $62;$69 = $61;$70 = $64;
       } else {
        __ZdlPv($21);
        $150 = $62;$69 = $61;$70 = $64;
       }
      }
     } while(0);
     $66 = (($i$078) + 1)|0;
     $67 = ($66|0)<($textureCount|0);
     if ($67) {
      $21 = $69;$22 = $70;$43 = $150;$i$078 = $66;
     } else {
      label = 31;
      break;
     }
    }
    if ((label|0) == 7) {
     $16 = ___cxa_find_matching_catch()|0;
     $17 = tempRet0;
     $151 = $21;$lpad$phi$index = $16;$lpad$phi$index2 = $17;
     label = 9;
     break;
    }
    else if ((label|0) == 20) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      $152 = $21;
      label = 8;
      break;
     }
     // unreachable;
    }
    else if ((label|0) == 31) {
     $68 = ($69|0)==($70|0);
     if ($68) {
      $$lcssa7589 = $69;
      label = 50;
      break;
     }
     HEAP32[$uniqueRects>>2] = 0;
     $71 = (($uniqueRects) + 4|0);
     HEAP32[$71>>2] = 0;
     $72 = (($uniqueRects) + 8|0);
     HEAP32[$72>>2] = 0;
     $73 = $70;
     $74 = $69;
     $75 = (($73) - ($74))|0;
     $76 = $75 >> 2;
     $77 = ($76|0)==(0);
     if ($77) {
      $80 = 0;
      label = 35;
     } else {
      __THREW__ = 0;
      invoke_vii(2698,($uniqueRects|0),($76|0));
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if (!($79)) {
       $$pre = HEAP32[$uniqueRects>>2]|0;
       $80 = $$pre;
       label = 35;
      }
     }
     if ((label|0) == 35) {
      __THREW__ = 0;
      $81 = (invoke_iiiiiiii(110,($atlas|0),($2|0),($76|0),($69|0),($80|0),($padding|0),0)|0);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if (!($83)) {
       $$not = $81 ^ 1;
       $$not92 = $8 ^ 1;
       $brmerge93 = $$not | $$not92;
       $$mux = $$not&1;
       if ($brmerge93) {
        $$0 = $$mux;
       } else {
        $84 = HEAP32[$remap>>2]|0;
        $85 = HEAP32[$uniqueRects>>2]|0;
        $i1$069 = 0;
        while(1) {
         $95 = (($84) + ($i1$069<<2)|0);
         $96 = HEAP32[$95>>2]|0;
         $97 = ($96|0)==(-1);
         if (!($97)) {
          $98 = (($outRects) + ($i1$069<<4)|0);
          $99 = (($85) + ($96<<4)|0);
          ;HEAP32[$98+0>>2]=HEAP32[$99+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$99+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$99+8>>2]|0;HEAP32[$98+12>>2]=HEAP32[$99+12>>2]|0;
         }
         $100 = (($i1$069) + 1)|0;
         $exitcond = ($100|0)==($textureCount|0);
         if ($exitcond) {
          $$0 = 0;
          break;
         } else {
          $i1$069 = $100;
         }
        }
       }
       $101 = HEAP32[$uniqueRects>>2]|0;
       $102 = ($101|0)==(0|0);
       if (!($102)) {
        $103 = HEAP32[$71>>2]|0;
        $104 = ($103|0)==($101|0);
        if (!($104)) {
         $__new_last2$i$i$i$i$i33 = $101;
         $scevgep$i$i$i$i$i34 = (($103) + -16|0);
         $105 = (0 - ($__new_last2$i$i$i$i$i33))|0;
         $uglygep$i$i$i$i$i36 = (($scevgep$i$i$i$i$i34) + ($105)|0);
         $uglygep3$i$i$i$i$i37 = $uglygep$i$i$i$i$i36;
         $106 = $uglygep3$i$i$i$i$i37 >>> 4;
         $107 = $106 ^ -1;
         $scevgep4$i$i$i$i$i38 = (($103) + ($107<<4)|0);
         HEAP32[$71>>2] = $scevgep4$i$i$i$i$i38;
        }
        __ZdlPv($101);
       }
       $cond$not = ($$0|0)!=(0);
       $upload$not = $upload ^ 1;
       $brmerge = $cond$not | $upload$not;
       $not$cond$not = $cond$not ^ 1;
       if ($brmerge) {
        $$15 = $not$cond$not;$$lcssa7591 = $69;
        label = 58;
        break;
       } else {
        $$lcssa7588 = $69;
        label = 51;
        break;
       }
      }
     }
     $86 = ___cxa_find_matching_catch()|0;
     $87 = tempRet0;
     $88 = HEAP32[$uniqueRects>>2]|0;
     $89 = ($88|0)==(0|0);
     if ($89) {
      $$01 = $87;$$02 = $86;$142 = $69;
      label = 65;
      break;
     }
     $90 = HEAP32[$71>>2]|0;
     $91 = ($90|0)==($88|0);
     if (!($91)) {
      $__new_last2$i$i$i$i$i43 = $88;
      $scevgep$i$i$i$i$i44 = (($90) + -16|0);
      $92 = (0 - ($__new_last2$i$i$i$i$i43))|0;
      $uglygep$i$i$i$i$i46 = (($scevgep$i$i$i$i$i44) + ($92)|0);
      $uglygep3$i$i$i$i$i47 = $uglygep$i$i$i$i$i46;
      $93 = $uglygep3$i$i$i$i$i47 >>> 4;
      $94 = $93 ^ -1;
      $scevgep4$i$i$i$i$i48 = (($90) + ($94<<4)|0);
      HEAP32[$71>>2] = $scevgep4$i$i$i$i$i48;
     }
     __ZdlPv($88);
     $$01 = $87;$$02 = $86;$142 = $69;
     label = 65;
     break;
    }
   } else {
    $$lcssa7589 = 0;
    label = 50;
   }
  }
 } while(0);
 if ((label|0) == 50) {
  if ($upload) {
   $$lcssa7588 = $$lcssa7589;
   label = 51;
  } else {
   $$15 = 1;$$lcssa7591 = $$lcssa7589;
   label = 58;
  }
 }
 do {
  if ((label|0) == 51) {
   $108 = (($atlas) + 48|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ($109|0)==(0|0);
   if ($110) {
    $113 = 5;
   } else {
    $111 = (($109) + 32|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = $112;
   }
   $format$off$i$i$i = (($113) + -10)|0;
   $114 = ($format$off$i$i$i>>>0)<(3);
   $format$off$i5$i$i = (($113) + -30)|0;
   $115 = ($format$off$i5$i$i>>>0)<(4);
   $or$cond$i$i = $114 | $115;
   $116 = ($113|0)==(34);
   $or$cond7$i$i = $or$cond$i$i | $116;
   $format$off$i4$i$i = (($113) + -35)|0;
   $117 = ($format$off$i4$i$i>>>0)<(2);
   $or$cond9$i$i = $or$cond7$i$i | $117;
   $format$off$i3$i$i = (($113) + -41)|0;
   $118 = ($format$off$i3$i$i>>>0)<(4);
   $or$cond11$i$i = $or$cond9$i$i | $118;
   $format$off$i2$i$i = (($113) + -45)|0;
   $119 = ($format$off$i2$i$i>>>0)<(3);
   $or$cond13$i$i = $or$cond11$i$i | $119;
   $format$off$i1$i$i = (($113) + -48)|0;
   $120 = ($format$off$i1$i$i>>>0)<(12);
   $or$cond$i = $or$cond13$i$i | $120;
   if (!($or$cond$i)) {
    $121 = HEAP32[$atlas>>2]|0;
    $122 = (($121) + 160|0);
    $123 = HEAP32[$122>>2]|0;
    __THREW__ = 0;
    invoke_vi($123|0,($atlas|0));
    $124 = __THREW__; __THREW__ = 0;
    $125 = $124&1;
    if ($125) {
     $152 = $$lcssa7588;
     label = 8;
     break;
    }
   }
   if ($markNoLongerReadable) {
    $126 = (($atlas) + 127|0);
    HEAP8[$126>>0] = 0;
    $127 = (($atlas) + 129|0);
    HEAP8[$127>>0] = 0;
   }
   $128 = HEAP32[$atlas>>2]|0;
   $129 = (($128) + 12|0);
   $130 = HEAP32[$129>>2]|0;
   __THREW__ = 0;
   invoke_vii($130|0,($atlas|0),0);
   $131 = __THREW__; __THREW__ = 0;
   $132 = $131&1;
   if ($132) {
    $152 = $$lcssa7588;
    label = 8;
   } else {
    $$15 = 1;$$lcssa7591 = $$lcssa7588;
    label = 58;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $151 = $152;$lpad$phi$index = $18;$lpad$phi$index2 = $19;
  label = 9;
 }
 else if ((label|0) == 58) {
  $133 = ($$lcssa7591|0)==(0|0);
  if (!($133)) {
   __ZdlPv($$lcssa7591);
  }
  $134 = HEAP32[$remap>>2]|0;
  $135 = ($134|0)==(0|0);
  if ($135) {
   STACKTOP = sp;return ($$15|0);
  }
  $136 = HEAP32[$3>>2]|0;
  $137 = ($136|0)==($134|0);
  if (!($137)) {
   $__new_last2$i$i$i$i$i13 = $134;
   $scevgep$i$i$i$i$i14 = (($136) + -4|0);
   $138 = (0 - ($__new_last2$i$i$i$i$i13))|0;
   $uglygep$i$i$i$i$i16 = (($scevgep$i$i$i$i$i14) + ($138)|0);
   $uglygep3$i$i$i$i$i17 = $uglygep$i$i$i$i$i16;
   $139 = $uglygep3$i$i$i$i$i17 >>> 2;
   $140 = $139 ^ -1;
   $scevgep4$i$i$i$i$i18 = (($136) + ($140<<2)|0);
   HEAP32[$3>>2] = $scevgep4$i$i$i$i$i18;
  }
  __ZdlPv($134);
  STACKTOP = sp;return ($$15|0);
 }
 if ((label|0) == 9) {
  $$01 = $lpad$phi$index2;$$02 = $lpad$phi$index;$142 = $151;
  label = 65;
 }
 if ((label|0) == 65) {
  $141 = ($142|0)==(0|0);
  if ($141) {
   $$1 = $$01;$$13 = $$02;
  } else {
   __ZdlPv($142);
   $$1 = $$01;$$13 = $$02;
  }
 }
 $143 = HEAP32[$remap>>2]|0;
 $144 = ($143|0)==(0|0);
 if ($144) {
  ___resumeException($$13|0);
  // unreachable;
 }
 $145 = HEAP32[$3>>2]|0;
 $146 = ($145|0)==($143|0);
 if (!($146)) {
  $__new_last2$i$i$i$i$i = $143;
  $scevgep$i$i$i$i$i = (($145) + -4|0);
  $147 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($147)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $148 = $uglygep3$i$i$i$i$i >>> 2;
  $149 = $148 ^ -1;
  $scevgep4$i$i$i$i$i = (($145) + ($149<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($143);
 ___resumeException($$13|0);
 // unreachable;
 return 0|0;
}
function __Z16PackTextureAtlasP9Texture2DiiPS0_P5RectTIfEii($atlas,$atlasMaximumSize,$textureCount,$textures,$outRects,$padding,$textureOptions) {
 $atlas = $atlas|0;
 $atlasMaximumSize = $atlasMaximumSize|0;
 $textureCount = $textureCount|0;
 $textures = $textures|0;
 $outRects = $outRects|0;
 $padding = $padding|0;
 $textureOptions = $textureOptions|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$01$i = 0, $$04 = 0, $$05 = 0, $$1 = 0, $$14 = 0, $$16 = 0, $$2 = 0, $$27 = 0, $$289 = 0, $$291 = 0, $$3 = 0, $$38 = 0, $$byval_copy = 0, $$packFormat$2 = 0, $$packWithMipmaps$0$off0 = 0, $$pre = 0, $$pre271 = 0;
 var $$pre272 = 0, $$pre278 = 0, $$pre279 = 0, $$pre280 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $69$phi = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i18 = 0;
 var $__new_last2$i$i$i$i$i25 = 0, $__new_last2$i$i$i$i$i34 = 0, $__new_last2$i$i$i$i$i49 = 0, $__new_last2$i$i$i$i$i58 = 0, $atlasFormat$0 = 0, $atlasHeight$0 = 0, $atlasHeight$1 = 0, $atlasImgRef = 0, $atlasMipData$0147 = 0, $atlasMipHeight22$0149 = 0, $atlasMipWidth21$0148 = 0, $atlasWidth$0 = 0, $atlasWidth$1 = 0, $blit_mode$0 = 0, $blit_mode11$0 = 0, $decompressedImage$0133 = 0, $decompressedImage$1$lcssa = 0, $decompressedImage$1117 = 0, $decompressedImage$2 = 0, $decompressedImage$3 = 0;
 var $destCoordX$0118 = 0, $destCoordX17$0143 = 0, $destCoordY$0119 = 0, $destCoordY18$0144 = 0, $destHeight$0122 = 0, $destHeight20$0146 = 0, $destRect = 0, $destWidth$0120 = 0, $destWidth19$0145 = 0, $eh$lpad$body$index12Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond = 0, $exitcond236 = 0, $exitcond267 = 0, $exitcond268 = 0, $i$0230 = 0, $i$1207 = 0, $i$2201 = 0, $i$3163 = 0, $i$4167 = 0;
 var $i$5159 = 0, $i$6134 = 0, $i$7157 = 0, $lpad$phi223$index = 0, $lpad$phi223$index2 = 0, $mip$0126 = 0, $mip23$0151 = 0, $not$ = 0, $or$cond = 0, $or$cond11 = 0, $or$cond11210 = 0, $or$cond12 = 0, $or$cond12215 = 0, $or$cond15 = 0, $or$cond16 = 0, $or$cond17 = 0, $or$cond17$not = 0, $or$cond290 = 0, $packFormat$0229 = 0, $packFormat$1$lcssa = 0;
 var $packFormat$2$lcssa = 0, $packFormat$3 = 0, $packFormat$4 = 0, $packFormat$4284285 = 0, $packFormat$5 = 0, $packFormat$6 = 0, $packIterations$0 = 0, $packIterations$1 = 0, $packWithMipmaps$0$off0$lcssa282 = 0, $packWithMipmaps$0$off0$lcssa282283287 = 0, $packWithMipmaps$0$off0228 = 0, $phitmp = 0, $phitmp112 = 0, $phitmp235 = 0, $phitmp235$packFormat$3 = 0, $phitmp281 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i19 = 0, $scevgep$i$i$i$i$i26 = 0, $scevgep$i$i$i$i$i35 = 0;
 var $scevgep$i$i$i$i$i50 = 0, $scevgep$i$i$i$i$i59 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i23 = 0, $scevgep4$i$i$i$i$i30 = 0, $scevgep4$i$i$i$i$i39 = 0, $scevgep4$i$i$i$i$i54 = 0, $scevgep4$i$i$i$i$i63 = 0, $someInputHasNoMipmaps$0$off0$ = 0, $someInputHasNoMipmaps$0$off0227 = 0, $sortedIndices = 0, $srcMip = 0, $srcPointer$0150 = 0, $texHeight15$0142 = 0, $texWidth14$0141 = 0, $textureNodes = 0, $textureSizes = 0, $totalPixels$0$lcssa = 0, $totalPixels$0200 = 0, $tree = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i21 = 0, $uglygep$i$i$i$i$i28 = 0, $uglygep$i$i$i$i$i37 = 0, $uglygep$i$i$i$i$i52 = 0, $uglygep$i$i$i$i$i61 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i22 = 0, $uglygep3$i$i$i$i$i29 = 0, $uglygep3$i$i$i$i$i38 = 0, $uglygep3$i$i$i$i$i53 = 0, $uglygep3$i$i$i$i$i62 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy = sp + 8|0;
 $0 = sp + 136|0;
 $1 = sp;
 $textureSizes = sp + 124|0;
 $sortedIndices = sp + 112|0;
 $textureNodes = sp + 140|0;
 $tree = sp + 64|0;
 $atlasImgRef = sp + 32|0;
 $destRect = sp + 12|0;
 $srcMip = sp + 92|0;
 $2 = sp + 52|0;
 $3 = ($atlasMaximumSize|0)<(8);
 $4 = $3 ? 8 : $atlasMaximumSize;
 HEAP32[$textureSizes>>2] = 0;
 $5 = (($textureSizes) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($textureSizes) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = ($textureCount|0)!=(0);
 L1: do {
  if ($7) {
   __THREW__ = 0;
   invoke_vii(2699,($textureSizes|0),($textureCount|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   L4: do {
    if ($11) {
     $40 = ___cxa_find_matching_catch()|0;
     $41 = tempRet0;
     $lpad$phi223$index = $40;$lpad$phi223$index2 = $41;
    } else {
     $12 = ($textureCount|0)>(0);
     do {
      if ($12) {
       $i$0230 = 0;$packFormat$0229 = 1;$packWithMipmaps$0$off0228 = 0;$someInputHasNoMipmaps$0$off0227 = 0;
       while(1) {
        $13 = HEAP32[$textureSizes>>2]|0;
        $14 = (($textures) + ($i$0230<<2)|0);
        $15 = HEAP32[$14>>2]|0;
        $16 = HEAP32[$15>>2]|0;
        $17 = (($16) + 104|0);
        $18 = HEAP32[$17>>2]|0;
        __THREW__ = 0;
        $19 = (invoke_ii($18|0,($15|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         label = 9;
         break;
        }
        $22 = (($13) + ($i$0230<<3)|0);
        HEAP32[$22>>2] = $19;
        $23 = HEAP32[$14>>2]|0;
        $24 = HEAP32[$23>>2]|0;
        $25 = (($24) + 108|0);
        $26 = HEAP32[$25>>2]|0;
        __THREW__ = 0;
        $27 = (invoke_ii($26|0,($23|0))|0);
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         label = 9;
         break;
        }
        $30 = ((($13) + ($i$0230<<3)|0) + 4|0);
        HEAP32[$30>>2] = $27;
        $31 = HEAP32[$22>>2]|0;
        $32 = ($31|0)>($4|0);
        $33 = ($31|0)>(4);
        $or$cond11210 = $32 & $33;
        if ($or$cond11210) {
         $35 = $31;
         while(1) {
          $34 = (($35|0) / 2)&-1;
          $36 = ($34|0)>($4|0);
          $37 = ($35|0)>(9);
          $or$cond11 = $36 & $37;
          if ($or$cond11) {
           $35 = $34;
          } else {
           break;
          }
         }
         HEAP32[$22>>2] = $34;
         $packFormat$1$lcssa = 0;
        } else {
         $packFormat$1$lcssa = $packFormat$0229;
        }
        $42 = ($27|0)>($4|0);
        $43 = ($27|0)>(4);
        $or$cond12215 = $42 & $43;
        if ($or$cond12215) {
         $45 = $27;
         while(1) {
          $44 = (($45|0) / 2)&-1;
          $46 = ($44|0)>($4|0);
          $47 = ($45|0)>(9);
          $or$cond12 = $46 & $47;
          if ($or$cond12) {
           $45 = $44;
          } else {
           break;
          }
         }
         HEAP32[$30>>2] = $44;
         $packFormat$2$lcssa = 0;
        } else {
         $packFormat$2$lcssa = $packFormat$1$lcssa;
        }
        $48 = HEAP32[$14>>2]|0;
        $49 = (($48) + 48|0);
        $50 = HEAP32[$49>>2]|0;
        $51 = ($50|0)==(0|0);
        if ($51) {
         $packFormat$3 = 0;
        } else {
         $52 = (($50) + 32|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = ($53|0)==(12);
         if ((($53|0) == 10) | (($53|0) == 12)) {
          $55 = ($packFormat$2$lcssa|0)==(1);
          if ($55) {
           $$packFormat$2 = $54 ? 2 : 1;
           $packFormat$3 = $$packFormat$2;
          } else {
           $packFormat$3 = $packFormat$2$lcssa;
          }
         } else {
          $packFormat$3 = 0;
         }
        }
        $56 = HEAP32[$48>>2]|0;
        $57 = (($56) + 124|0);
        $58 = HEAP32[$57>>2]|0;
        __THREW__ = 0;
        $59 = (invoke_ii($58|0,($48|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 9;
         break;
        }
        $not$ = $59 ^ 1;
        $someInputHasNoMipmaps$0$off0$ = $someInputHasNoMipmaps$0$off0227 | $not$;
        $$packWithMipmaps$0$off0 = $59 | $packWithMipmaps$0$off0228;
        $62 = (($i$0230) + 1)|0;
        $63 = ($62|0)<($textureCount|0);
        if ($63) {
         $i$0230 = $62;$packFormat$0229 = $packFormat$3;$packWithMipmaps$0$off0228 = $$packWithMipmaps$0$off0;$someInputHasNoMipmaps$0$off0227 = $someInputHasNoMipmaps$0$off0$;
        } else {
         label = 22;
         break;
        }
       }
       if ((label|0) == 9) {
        $38 = ___cxa_find_matching_catch()|0;
        $39 = tempRet0;
        $lpad$phi223$index = $38;$lpad$phi223$index2 = $39;
        break L4;
       }
       else if ((label|0) == 22) {
        $phitmp235 = $someInputHasNoMipmaps$0$off0$ ? 0 : $packFormat$3;
        $$289 = $59 | $packWithMipmaps$0$off0228;
        $phitmp235$packFormat$3 = $$packWithMipmaps$0$off0 ? $phitmp235 : $packFormat$3;
        $551 = $12;$packFormat$4 = $phitmp235$packFormat$3;$packWithMipmaps$0$off0$lcssa282 = $$289;
        break;
       }
      } else {
       $551 = 0;$packFormat$4 = 1;$packWithMipmaps$0$off0$lcssa282 = 0;
      }
     } while(0);
     HEAP32[$sortedIndices>>2] = 0;
     $64 = (($sortedIndices) + 4|0);
     HEAP32[$64>>2] = 0;
     $65 = (($sortedIndices) + 8|0);
     HEAP32[$65>>2] = 0;
     do {
      if ($7) {
       __THREW__ = 0;
       invoke_vii(2697,($sortedIndices|0),($textureCount|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        $71 = ___cxa_find_matching_catch()|0;
        $72 = tempRet0;
        $$2 = $71;$$27 = $72;$533 = $sortedIndices;$536 = $64;
        label = 167;
        break L1;
       } else {
        $$pre278 = HEAP32[$sortedIndices>>2]|0;
        if ($551) {
         $69 = $$pre278;$i$1207 = 0;
         break;
        } else {
         $142 = $sortedIndices;$550 = 0;$74 = $64;$75 = $$pre278;$packFormat$4284285 = $packFormat$4;$packWithMipmaps$0$off0$lcssa282283287 = $packWithMipmaps$0$off0$lcssa282;
         label = 29;
         break L1;
        }
       }
      } else {
       if ($551) {
        $69 = 0;$i$1207 = 0;
       } else {
        $142 = $sortedIndices;$550 = 0;$74 = $64;$75 = 0;$packFormat$4284285 = $packFormat$4;$packWithMipmaps$0$off0$lcssa282283287 = $packWithMipmaps$0$off0$lcssa282;
        label = 29;
        break L1;
       }
      }
     } while(0);
     while(1) {
      $68 = (($69) + ($i$1207<<2)|0);
      HEAP32[$68>>2] = $i$1207;
      $70 = (($i$1207) + 1)|0;
      $exitcond268 = ($70|0)==($textureCount|0);
      if ($exitcond268) {
       $142 = $sortedIndices;$550 = 1;$74 = $64;$75 = $69;$packFormat$4284285 = $packFormat$4;$packWithMipmaps$0$off0$lcssa282283287 = $packWithMipmaps$0$off0$lcssa282;
       label = 29;
       break L1;
      } else {
       $69$phi = $69;$i$1207 = $70;$69 = $69$phi;
      }
     }
    }
   } while(0);
   $$3 = $lpad$phi223$index;$$38 = $lpad$phi223$index2;
  } else {
   HEAP32[$sortedIndices>>2] = 0;
   $8 = (($sortedIndices) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($sortedIndices) + 8|0);
   HEAP32[$9>>2] = 0;
   $142 = $sortedIndices;$550 = 0;$74 = $8;$75 = 0;$packFormat$4284285 = 1;$packWithMipmaps$0$off0$lcssa282283287 = 0;
   label = 29;
  }
 } while(0);
 if ((label|0) == 29) {
  $73 = HEAP32[$74>>2]|0;
  HEAP32[$1>>2] = $textureSizes;
  __ZNSt3__16__sortIR11IndexSorterPiEEvT0_S4_T_($75,$73,$1);
  if ($550) {
   $76 = HEAP32[$textureSizes>>2]|0;
   $i$2201 = 0;$totalPixels$0200 = 0;
   while(1) {
    $77 = (($76) + ($i$2201<<3)|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ((($76) + ($i$2201<<3)|0) + 4|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = Math_imul($80, $78)|0;
    $82 = (($81) + ($totalPixels$0200))|0;
    $83 = (($i$2201) + 1)|0;
    $exitcond267 = ($83|0)==($textureCount|0);
    if ($exitcond267) {
     $totalPixels$0$lcssa = $82;
     break;
    } else {
     $i$2201 = $83;$totalPixels$0200 = $82;
    }
   }
  } else {
   $totalPixels$0$lcssa = 0;
  }
  $84 = (Math_fround(($totalPixels$0$lcssa|0)));
  $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
  $86 = (~~(($85))>>>0);
  $87 = (($86) + -1)|0;
  $88 = $87 >>> 16;
  $89 = $88 | $87;
  $90 = $89 >>> 8;
  $91 = $90 | $89;
  $92 = $91 >>> 4;
  $93 = $92 | $91;
  $94 = $93 >>> 2;
  $95 = $94 | $93;
  $96 = $95 >>> 1;
  $97 = $96 | $95;
  $98 = (($97) + 1)|0;
  $99 = ($4|0)<($98|0);
  $100 = $99 ? $4 : $98;
  $101 = (($totalPixels$0$lcssa|0) / ($100|0))&-1;
  $102 = (($101) + -1)|0;
  $103 = $102 >>> 16;
  $104 = $103 | $102;
  $105 = $104 >>> 8;
  $106 = $105 | $104;
  $107 = $106 >>> 4;
  $108 = $107 | $106;
  $109 = $108 >>> 2;
  $110 = $109 | $108;
  $111 = $110 >>> 1;
  $112 = $111 | $110;
  $113 = (($112) + 1)|0;
  $114 = ($4|0)<($113|0);
  $115 = $114 ? $4 : $113;
  HEAP32[$textureNodes>>2] = 0;
  $116 = (($textureNodes) + 4|0);
  HEAP32[$116>>2] = 0;
  $117 = (($textureNodes) + 8|0);
  HEAP32[$117>>2] = 0;
  if ($7) {
   __THREW__ = 0;
   invoke_vii(2700,($textureNodes|0),($textureCount|0));
   $118 = __THREW__; __THREW__ = 0;
   $119 = $118&1;
   if ($119) {
    label = 50;
   } else {
    label = 34;
   }
  } else {
   label = 34;
  }
  do {
   if ((label|0) == 34) {
    ;HEAP32[$tree+0>>2]=0|0;HEAP32[$tree+4>>2]=0|0;HEAP32[$tree+8>>2]=0|0;HEAP32[$tree+12>>2]=0|0;HEAP32[$tree+16>>2]=0|0;HEAP32[$tree+20>>2]=0|0;HEAP8[$tree+24>>0]=0|0;
    $120 = (($tree) + 4|0);
    $121 = (($tree) + 24|0);
    $122 = (($tree) + 16|0);
    $123 = (($tree) + 20|0);
    $124 = (Math_fround(($padding|0)));
    $126 = 0;$atlasHeight$0 = $115;$atlasWidth$0 = $100;$packFormat$5 = $packFormat$4284285;$packIterations$0 = 0;
    L52: while(1) {
     $125 = ($126|0)==(0|0);
     if (!($125)) {
      __THREW__ = 0;
      invoke_vi(3468,($126|0));
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       label = 41;
       break;
      }
      __ZdlPv($126);
     }
     $129 = HEAP32[$120>>2]|0;
     $130 = ($129|0)==(0|0);
     if (!($130)) {
      __THREW__ = 0;
      invoke_vi(3468,($129|0));
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       label = 42;
       break;
      }
      __ZdlPv($129);
     }
     HEAP8[$121>>0] = 0;
     $137 = (Math_fround(($atlasWidth$0|0)));
     $138 = (Math_fround(($atlasHeight$0|0)));
     ;HEAP32[$tree+0>>2]=0|0;HEAP32[$tree+4>>2]=0|0;HEAP32[$tree+8>>2]=0|0;HEAP32[$tree+12>>2]=0|0;
     HEAPF32[$122>>2] = $137;
     HEAPF32[$123>>2] = $138;
     $139 = ($packFormat$5|0)!=(0);
     if ($550) {
      $i$3163 = 0;
     } else {
      $552 = 0;
      label = 75;
      break;
     }
     while(1) {
      $143 = HEAP32[$142>>2]|0;
      $144 = (($143) + ($i$3163<<2)|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = HEAP32[$textureSizes>>2]|0;
      $147 = (($146) + ($145<<3)|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ((($146) + ($145<<3)|0) + 4|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = (Math_fround(($148|0)));
      $152 = (Math_fround(($150|0)));
      __THREW__ = 0;
      $153 = (invoke_iifffi(1,($tree|0),(+$151),(+$152),(+$124),($139|0))|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       label = 55;
       break L52;
      }
      $156 = HEAP32[$textureNodes>>2]|0;
      $157 = (($156) + ($145<<2)|0);
      HEAP32[$157>>2] = $153;
      $158 = ($153|0)==(0|0);
      $141 = (($i$3163) + 1)|0;
      if ($158) {
       break;
      }
      $140 = ($141|0)<($textureCount|0);
      if ($140) {
       $i$3163 = $141;
      } else {
       label = 46;
       break L52;
      }
     }
     $173 = ($atlasWidth$0|0)==($4|0);
     $174 = ($atlasHeight$0|0)==($4|0);
     $or$cond = $173 & $174;
     do {
      if ($or$cond) {
       $175 = HEAP32[$textureSizes>>2]|0;
       $i$4167 = 0;
       while(1) {
        $181 = (($175) + ($i$4167<<3)|0);
        $182 = HEAP32[$181>>2]|0;
        $183 = ($182|0)>(4);
        if ($183) {
         $184 = ((($175) + ($i$4167<<3)|0) + 4|0);
         $185 = HEAP32[$184>>2]|0;
         $186 = ($185|0)>(4);
         if ($186) {
          $187 = ($182*3)|0;
          $188 = (($187|0) / 4)&-1;
          HEAP32[$181>>2] = $188;
          $189 = ($185*3)|0;
          $190 = (($189|0) / 4)&-1;
          HEAP32[$184>>2] = $190;
         }
        }
        $191 = (($i$4167) + 1)|0;
        $exitcond236 = ($191|0)==($textureCount|0);
        if ($exitcond236) {
         break;
        } else {
         $i$4167 = $191;
        }
       }
       $192 = (($packIterations$0) + 1)|0;
       $atlasHeight$1 = $4;$atlasWidth$1 = $4;$packFormat$6 = 0;$packIterations$1 = $192;
      } else {
       if ($173) {
        $176 = $atlasHeight$0 << 1;
        $atlasHeight$1 = $176;$atlasWidth$1 = $4;$packFormat$6 = $packFormat$5;$packIterations$1 = $packIterations$0;
        break;
       }
       if ($174) {
        $177 = $atlasWidth$0 << 1;
        $atlasHeight$1 = $4;$atlasWidth$1 = $177;$packFormat$6 = $packFormat$5;$packIterations$1 = $packIterations$0;
        break;
       }
       $178 = ($atlasWidth$0|0)<($atlasHeight$0|0);
       if ($178) {
        $179 = $atlasWidth$0 << 1;
        $atlasHeight$1 = $atlasHeight$0;$atlasWidth$1 = $179;$packFormat$6 = $packFormat$5;$packIterations$1 = $packIterations$0;
        break;
       } else {
        $180 = $atlasHeight$0 << 1;
        $atlasHeight$1 = $180;$atlasWidth$1 = $atlasWidth$0;$packFormat$6 = $packFormat$5;$packIterations$1 = $packIterations$0;
        break;
       }
      }
     } while(0);
     $193 = ($packIterations$1|0)<(100);
     if (!($193)) {
      $$0 = 0;
      label = 148;
      break;
     }
     $$pre279 = HEAP32[$tree>>2]|0;
     $126 = $$pre279;$atlasHeight$0 = $atlasHeight$1;$atlasWidth$0 = $atlasWidth$1;$packFormat$5 = $packFormat$6;$packIterations$0 = $packIterations$1;
    }
    if ((label|0) == 41) {
     $133 = ___cxa_find_matching_catch()|0;
     $134 = tempRet0;
     __ZdlPv($126);
     $$0$i = $134;$$01$i = $133;
     label = 43;
    }
    else if ((label|0) == 42) {
     $135 = ___cxa_find_matching_catch()|0;
     $136 = tempRet0;
     __ZdlPv($129);
     $$0$i = $136;$$01$i = $135;
     label = 43;
    }
    else if ((label|0) == 46) {
     if ($550) {
      $$pre = HEAP32[$142>>2]|0;
      $$pre271 = HEAP32[$textureSizes>>2]|0;
      $$pre272 = HEAP32[$textureNodes>>2]|0;
      $i$5159 = 0;
      while(1) {
       $194 = (($$pre) + ($i$5159<<2)|0);
       $195 = HEAP32[$194>>2]|0;
       $196 = (($$pre271) + ($195<<3)|0);
       $197 = HEAP32[$196>>2]|0;
       $198 = ((($$pre271) + ($195<<3)|0) + 4|0);
       $199 = HEAP32[$198>>2]|0;
       $200 = (($$pre272) + ($195<<2)|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = (($201) + 8|0);
       $203 = Math_fround(HEAPF32[$202>>2]);
       $204 = Math_fround($203 / $137);
       $205 = (($201) + 12|0);
       $206 = Math_fround(HEAPF32[$205>>2]);
       $207 = Math_fround($206 / $138);
       $208 = (Math_fround(($197|0)));
       $209 = Math_fround($208 + $203);
       $210 = Math_fround($209 / $137);
       $211 = (Math_fround(($199|0)));
       $212 = Math_fround($211 + $206);
       $213 = Math_fround($212 / $138);
       $214 = Math_fround($210 - $204);
       $215 = Math_fround($213 - $207);
       $216 = (($outRects) + ($195<<4)|0);
       HEAPF32[$216>>2] = $204;
       $217 = ((($outRects) + ($195<<4)|0) + 4|0);
       HEAPF32[$217>>2] = $207;
       $218 = ((($outRects) + ($195<<4)|0) + 8|0);
       HEAPF32[$218>>2] = $214;
       $219 = ((($outRects) + ($195<<4)|0) + 12|0);
       HEAPF32[$219>>2] = $215;
       $220 = (($i$5159) + 1)|0;
       $exitcond = ($220|0)==($textureCount|0);
       if ($exitcond) {
        $552 = $550;
        label = 75;
        break;
       } else {
        $i$5159 = $220;
       }
      }
     } else {
      $552 = 0;
      label = 75;
     }
    }
    else if ((label|0) == 55) {
     $169 = ___cxa_find_matching_catch()|0;
     $170 = tempRet0;
     $eh$lpad$body$index12Z2D = $170;$eh$lpad$body$indexZ2D = $169;
     label = 57;
    }
    L96: do {
     if ((label|0) == 43) {
      $eh$lpad$body$index12Z2D = $$0$i;$eh$lpad$body$indexZ2D = $$01$i;
      label = 57;
     }
     else if ((label|0) == 75) {
      if ((($packFormat$5|0) == 2)) {
       $atlasFormat$0 = 12;
      } else if ((($packFormat$5|0) == 1)) {
       $atlasFormat$0 = 10;
      } else {
       $atlasFormat$0 = 5;
      }
      $221 = $packWithMipmaps$0$off0$lcssa282283287&1;
      $222 = $221 | $textureOptions;
      $223 = HEAP32[$atlas>>2]|0;
      $224 = (($223) + 148|0);
      $225 = HEAP32[$224>>2]|0;
      __THREW__ = 0;
      $226 = (invoke_iiiiiiii($225|0,($atlas|0),($atlasWidth$0|0),($atlasHeight$0|0),($atlasFormat$0|0),($222|0),1,0)|0);
      $227 = __THREW__; __THREW__ = 0;
      $228 = $227&1;
      do {
       if (!($228)) {
        if (!($226)) {
         __THREW__ = 0;
         invoke_viiiiiiii(21,(590496|0),0,(590528|0),455,1,0,0,(0|0));
         $229 = __THREW__; __THREW__ = 0;
         $230 = $229&1;
         if ($230) {
          break;
         } else {
          $$0 = 0;
          label = 148;
          break L96;
         }
        }
        $231 = ($packFormat$5|0)==(0);
        if (!($231)) {
         __THREW__ = 0;
         invoke_vi(3470,($atlas|0));
         $360 = __THREW__; __THREW__ = 0;
         $361 = $360&1;
         if ($361) {
          break;
         }
         $362 = (($atlas) + 48|0);
         $363 = HEAP32[$362>>2]|0;
         $364 = ($363|0)==(0|0);
         if ($364) {
          $379 = 0;
         } else {
          $365 = (($363) + 8|0);
          $366 = HEAP32[$365>>2]|0;
          $379 = $366;
         }
         $367 = ($atlasFormat$0|0)==(10);
         $368 = $367 ? 8 : 16;
         __THREW__ = 0;
         invoke_vi(3470,($atlas|0));
         $369 = __THREW__; __THREW__ = 0;
         $370 = $369&1;
         if ($370) {
          break;
         }
         $371 = HEAP32[$362>>2]|0;
         $372 = ($371|0)==(0|0);
         if ($372) {
          $381 = 0;
         } else {
          $373 = (($371) + 36|0);
          $374 = HEAP32[$373>>2]|0;
          $375 = (($371) + 8|0);
          $376 = HEAP32[$375>>2]|0;
          $377 = (($376) + ($374)|0);
          $phitmp = $377;
          $381 = $phitmp;
         }
         $378 = $379;
         $380 = (($381) - ($378))|0;
         _memset(($379|0),0,($380|0))|0;
         if (!($552)) {
          $$0 = 1;
          label = 148;
          break L96;
         }
         $382 = (($2) + 1|0);
         $383 = (($2) + 8|0);
         $384 = ($atlasFormat$0|0)==(12);
         $i$7157 = 0;
         L119: while(1) {
          $385 = HEAP32[$142>>2]|0;
          $386 = (($385) + ($i$7157<<2)|0);
          $387 = HEAP32[$386>>2]|0;
          $388 = HEAP32[$textureSizes>>2]|0;
          $389 = (($388) + ($387<<3)|0);
          $390 = HEAP32[$389>>2]|0;
          $391 = ((($388) + ($387<<3)|0) + 4|0);
          $392 = HEAP32[$391>>2]|0;
          $393 = (($textures) + ($387<<2)|0);
          $394 = HEAP32[$393>>2]|0;
          __THREW__ = 0;
          $395 = (invoke_ii(3239,($394|0))|0);
          $396 = __THREW__; __THREW__ = 0;
          $397 = $396&1;
          if ($397) {
           label = 54;
           break;
          }
          __THREW__ = 0;
          $398 = (invoke_ii(3239,($atlas|0))|0);
          $399 = __THREW__; __THREW__ = 0;
          $400 = $399&1;
          if ($400) {
           label = 54;
           break;
          }
          $401 = ($398|0)<($395|0);
          $402 = $401 ? $398 : $395;
          $403 = HEAP32[$textureNodes>>2]|0;
          $404 = (($403) + ($387<<2)|0);
          $405 = HEAP32[$404>>2]|0;
          $406 = (($394) + 48|0);
          $407 = HEAP32[$406>>2]|0;
          $408 = ($407|0)==(0|0);
          L123: do {
           if ($408) {
            label = 140;
           } else {
            $409 = (($407) + 8|0);
            $410 = HEAP32[$409>>2]|0;
            $411 = ($410|0)==(0|0);
            if ($411) {
             label = 140;
             break;
            }
            $412 = (($405) + 8|0);
            $413 = (($405) + 12|0);
            $414 = (($405) + 16|0);
            $415 = (($405) + 20|0);
            $416 = Math_fround(HEAPF32[$412>>2]);
            $417 = Math_fround(HEAPF32[$413>>2]);
            $418 = Math_fround(HEAPF32[$414>>2]);
            $419 = Math_fround(HEAPF32[$415>>2]);
            $420 = (~~(($416)));
            $421 = (~~(($417)));
            $422 = (~~(($418)));
            $423 = (~~(($419)));
            $424 = ($402|0)>(0);
            if ($424) {
             $449 = $407;$atlasMipData$0147 = $379;$atlasMipHeight22$0149 = $atlasHeight$0;$atlasMipWidth21$0148 = $atlasWidth$0;$destCoordX17$0143 = $420;$destCoordY18$0144 = $421;$destHeight20$0146 = $423;$destWidth19$0145 = $422;$mip23$0151 = 1;$srcPointer$0150 = $410;$texHeight15$0142 = $392;$texWidth14$0141 = $390;
            } else {
             break;
            }
            while(1) {
             $441 = (($destCoordX17$0143|0) / 4)&-1;
             $442 = (($destCoordY18$0144|0) / 4)&-1;
             $443 = Math_imul($442, $atlasMipWidth21$0148)|0;
             $444 = (($443|0) / 4)&-1;
             $445 = (($444) + ($441))|0;
             $446 = Math_imul($445, $368)|0;
             $447 = (($atlasMipData$0147) + ($446)|0);
             $448 = ($449|0)==(0|0);
             if ($448) {
              $453 = 5;
             } else {
              $450 = (($449) + 32|0);
              $451 = HEAP32[$450>>2]|0;
              $453 = $451;
             }
             $452 = ($453|0)==($atlasFormat$0|0);
             do {
              if ($452) {
               __THREW__ = 0;
               invoke_viiiiiiii(27,($atlasFormat$0|0),($srcPointer$0150|0),($texWidth14$0141|0),($texHeight15$0142|0),($447|0),($atlasMipWidth21$0148|0),($atlasMipHeight22$0149|0),0);
               $454 = __THREW__; __THREW__ = 0;
               $455 = $454&1;
               if ($455) {
                label = 53;
                break L119;
               }
              } else {
               $456 = ($453|0)==(10);
               $or$cond15 = $456 & $384;
               if (!($or$cond15)) {
                break;
               }
               __THREW__ = 0;
               invoke_viiiiii(109,($srcPointer$0150|0),($texWidth14$0141|0),($texHeight15$0142|0),($447|0),($atlasMipWidth21$0148|0),($atlasMipHeight22$0149|0));
               $457 = __THREW__; __THREW__ = 0;
               $458 = $457&1;
               if ($458) {
                label = 53;
                break L119;
               }
              }
             } while(0);
             __THREW__ = 0;
             $459 = (invoke_iiii(1543,($texWidth14$0141|0),($texHeight15$0142|0),($453|0))|0);
             $460 = __THREW__; __THREW__ = 0;
             $461 = $460&1;
             if ($461) {
              label = 53;
              break L119;
             }
             $462 = (($srcPointer$0150) + ($459)|0);
             __THREW__ = 0;
             $434 = (invoke_iiii(1543,($atlasMipWidth21$0148|0),($atlasMipHeight22$0149|0),($atlasFormat$0|0))|0);
             $463 = __THREW__; __THREW__ = 0;
             $464 = $463&1;
             if ($464) {
              label = 53;
              break L119;
             }
             $465 = (($destCoordX17$0143|0) / 2)&-1;
             $466 = (($destCoordY18$0144|0) / 2)&-1;
             $437 = (($atlasMipWidth21$0148|0) / 2)&-1;
             $436 = ($437|0)<(4);
             $440 = (($atlasMipHeight22$0149|0) / 2)&-1;
             $439 = ($440|0)<(4);
             $427 = (($texWidth14$0141|0) / 2)&-1;
             $426 = ($427|0)<(4);
             $430 = (($texHeight15$0142|0) / 2)&-1;
             $429 = ($430|0)<(4);
             $467 = $465 & 3;
             $468 = ($467|0)==(0);
             if (!($468)) {
              break L123;
             }
             $469 = $466 & 3;
             $470 = ($469|0)!=(0);
             $471 = ($destWidth19$0145|0)<(8);
             $or$cond16 = $470 | $471;
             $472 = ($destHeight20$0146|0)<(8);
             $or$cond17 = $or$cond16 | $472;
             $or$cond17$not = $or$cond17 ^ 1;
             $473 = ($mip23$0151|0)<($402|0);
             $or$cond290 = $473 & $or$cond17$not;
             if (!($or$cond290)) {
              break L123;
             }
             $425 = $426 ? 4 : $427;
             $428 = $429 ? 4 : $430;
             $431 = (($destWidth19$0145|0) / 2)&-1;
             $432 = (($destHeight20$0146|0) / 2)&-1;
             $433 = (($atlasMipData$0147) + ($434)|0);
             $435 = $436 ? 4 : $437;
             $438 = $439 ? 4 : $440;
             $$pre280 = HEAP32[$406>>2]|0;
             $phitmp281 = (($mip23$0151) + 1)|0;
             $449 = $$pre280;$atlasMipData$0147 = $433;$atlasMipHeight22$0149 = $438;$atlasMipWidth21$0148 = $435;$destCoordX17$0143 = $465;$destCoordY18$0144 = $466;$destHeight20$0146 = $432;$destWidth19$0145 = $431;$mip23$0151 = $phitmp281;$srcPointer$0150 = $462;$texHeight15$0142 = $428;$texWidth14$0141 = $425;
            }
           }
          } while(0);
          do {
           if ((label|0) == 140) {
            label = 0;
            $474 = HEAP32[$394>>2]|0;
            $475 = (($474) + 32|0);
            $476 = HEAP32[$475>>2]|0;
            __THREW__ = 0;
            $477 = (invoke_ii($476|0,($394|0))|0);
            $478 = __THREW__; __THREW__ = 0;
            $479 = $478&1;
            if ($479) {
             label = 54;
             break L119;
            }
            __THREW__ = 0;
            HEAP32[$$byval_copy>>2] = $477;
            invoke_viii(1617,($2|0),(590536|0),($$byval_copy|0));
            $480 = __THREW__; __THREW__ = 0;
            $481 = $480&1;
            if ($481) {
             label = 54;
             break L119;
            }
            $482 = HEAP8[$2>>0]|0;
            $483 = $482 & 1;
            $484 = ($483<<24>>24)==(0);
            $485 = HEAP32[$383>>2]|0;
            $$291 = $484 ? $382 : $485;
            __THREW__ = 0;
            invoke_viiiiiiii(21,($$291|0),0,(590528|0),610,1,0,0,(0|0));
            $486 = __THREW__; __THREW__ = 0;
            $487 = $486&1;
            if ($487) {
             label = 145;
             break L119;
            }
            $488 = HEAP8[$2>>0]|0;
            $489 = $488 & 1;
            $490 = ($489<<24>>24)==(0);
            if ($490) {
             break;
            }
            $491 = HEAP32[$383>>2]|0;
            __ZdlPv($491);
           }
          } while(0);
          $498 = (($i$7157) + 1)|0;
          $499 = ($498|0)<($textureCount|0);
          if ($499) {
           $i$7157 = $498;
          } else {
           $$0 = 1;
           label = 148;
           break L96;
          }
         }
         if ((label|0) == 53) {
          $165 = ___cxa_find_matching_catch()|0;
          $166 = tempRet0;
          $eh$lpad$body$index12Z2D = $166;$eh$lpad$body$indexZ2D = $165;
          label = 57;
          break L96;
         }
         else if ((label|0) == 54) {
          $167 = ___cxa_find_matching_catch()|0;
          $168 = tempRet0;
          $eh$lpad$body$index12Z2D = $168;$eh$lpad$body$indexZ2D = $167;
          label = 57;
          break L96;
         }
         else if ((label|0) == 145) {
          $492 = ___cxa_find_matching_catch()|0;
          $493 = tempRet0;
          $494 = HEAP8[$2>>0]|0;
          $495 = $494 & 1;
          $496 = ($495<<24>>24)==(0);
          if ($496) {
           $$04 = $492;$$05 = $493;
           break L96;
          }
          $497 = HEAP32[$383>>2]|0;
          __ZdlPv($497);
          $$04 = $492;$$05 = $493;
          break L96;
         }
        }
        __THREW__ = 0;
        invoke_vi(3470,($atlas|0));
        $232 = __THREW__; __THREW__ = 0;
        $233 = $232&1;
        if (!($233)) {
         $234 = (($atlas) + 48|0);
         $235 = HEAP32[$234>>2]|0;
         $236 = ($235|0)==(0|0);
         if ($236) {
          $249 = 0;
         } else {
          $237 = (($235) + 8|0);
          $238 = HEAP32[$237>>2]|0;
          $249 = $238;
         }
         __THREW__ = 0;
         invoke_vi(3470,($atlas|0));
         $239 = __THREW__; __THREW__ = 0;
         $240 = $239&1;
         if (!($240)) {
          $241 = HEAP32[$234>>2]|0;
          $242 = ($241|0)==(0|0);
          if ($242) {
           $251 = 0;
          } else {
           $243 = (($241) + 36|0);
           $244 = HEAP32[$243>>2]|0;
           $245 = (($241) + 8|0);
           $246 = HEAP32[$245>>2]|0;
           $247 = (($246) + ($244)|0);
           $phitmp112 = $247;
           $251 = $phitmp112;
          }
          $248 = $249;
          $250 = (($251) - ($248))|0;
          _memset(($249|0),0,($250|0))|0;
          __THREW__ = 0;
          $252 = (invoke_ii(3239,($atlas|0))|0);
          $253 = __THREW__; __THREW__ = 0;
          $254 = $253&1;
          if (!($254)) {
           if (!($552)) {
            $$0 = 1;
            label = 148;
            break L96;
           }
           $255 = (($srcMip) + 4|0);
           $256 = (($srcMip) + 8|0);
           $decompressedImage$0133 = 0;$i$6134 = 0;
           L163: while(1) {
            $257 = HEAP32[$142>>2]|0;
            $258 = (($257) + ($i$6134<<2)|0);
            $259 = HEAP32[$258>>2]|0;
            $260 = HEAP32[$textureSizes>>2]|0;
            $261 = (($260) + ($259<<3)|0);
            $262 = HEAP32[$261>>2]|0;
            $263 = ((($260) + ($259<<3)|0) + 4|0);
            $264 = HEAP32[$263>>2]|0;
            $265 = HEAP32[$textureNodes>>2]|0;
            $266 = (($265) + ($259<<2)|0);
            $267 = HEAP32[$266>>2]|0;
            $268 = (($267) + 8|0);
            $269 = Math_fround(HEAPF32[$268>>2]);
            $270 = (($267) + 12|0);
            $271 = Math_fround(HEAPF32[$270>>2]);
            $272 = (($267) + 16|0);
            $273 = Math_fround(HEAPF32[$272>>2]);
            $274 = (~~(($273)));
            $275 = (($274) - ($padding))|0;
            $276 = ($275|0)>(1);
            $277 = $276 ? $275 : 1;
            $278 = (($267) + 20|0);
            $279 = Math_fround(HEAPF32[$278>>2]);
            $280 = (~~(($279)));
            $281 = (($280) - ($padding))|0;
            $282 = ($281|0)>(1);
            $283 = $282 ? $281 : 1;
            $284 = (($textures) + ($259<<2)|0);
            $285 = HEAP32[$284>>2]|0;
            __THREW__ = 0;
            $286 = (invoke_ii(3239,($285|0))|0);
            $287 = __THREW__; __THREW__ = 0;
            $288 = $287&1;
            if ($288) {
             label = 52;
             break;
            }
            $289 = ($252|0)<($286|0);
            $290 = $289 ? $252 : $286;
            $291 = ($290|0)==(0);
            if ($291) {
             $decompressedImage$1$lcssa = $decompressedImage$0133;
            } else {
             $292 = ($277|0)<($262|0);
             $293 = ($283|0)<($264|0);
             $294 = (~~(($269)));
             $295 = (~~(($271)));
             $296 = $292 ? $277 : $262;
             $297 = $293 ? $283 : $264;
             $316 = $262;$317 = $264;$decompressedImage$1117 = $decompressedImage$0133;$destCoordX$0118 = $294;$destCoordY$0119 = $295;$destHeight$0122 = $297;$destWidth$0120 = $296;$mip$0126 = 0;
             while(1) {
              ;HEAP32[$atlasImgRef+0>>2]=0|0;HEAP32[$atlasImgRef+4>>2]=0|0;HEAP32[$atlasImgRef+8>>2]=0|0;HEAP32[$atlasImgRef+12>>2]=0|0;HEAP32[$atlasImgRef+16>>2]=0|0;
              __THREW__ = 0;
              (invoke_iiiii(236,($atlas|0),($atlasImgRef|0),0,($mip$0126|0))|0);
              $298 = __THREW__; __THREW__ = 0;
              $299 = $298&1;
              if ($299) {
               label = 51;
               break L163;
              }
              __THREW__ = 0;
              invoke_viiiiii(108,($destRect|0),($atlasImgRef|0),($destCoordX$0118|0),($destCoordY$0119|0),($destWidth$0120|0),($destHeight$0122|0));
              $300 = __THREW__; __THREW__ = 0;
              $301 = $300&1;
              if ($301) {
               label = 51;
               break L163;
              }
              ;HEAP32[$srcMip+0>>2]=0|0;HEAP32[$srcMip+4>>2]=0|0;HEAP32[$srcMip+8>>2]=0|0;HEAP32[$srcMip+12>>2]=0|0;HEAP32[$srcMip+16>>2]=0|0;
              $302 = HEAP32[$284>>2]|0;
              __THREW__ = 0;
              $303 = (invoke_iiiii(236,($302|0),($srcMip|0),0,($mip$0126|0))|0);
              $304 = __THREW__; __THREW__ = 0;
              $305 = $304&1;
              if ($305) {
               label = 51;
               break L163;
              }
              if ($303) {
               $306 = HEAP32[$255>>2]|0;
               $307 = ($destWidth$0120|0)==($306|0);
               if ($307) {
                $308 = HEAP32[$256>>2]|0;
                $309 = ($destHeight$0122|0)==($308|0);
                $$ = $309 ? 0 : 2;
                $blit_mode$0 = $$;
               } else {
                $blit_mode$0 = 2;
               }
               __THREW__ = 0;
               invoke_viii(1729,($destRect|0),($srcMip|0),($blit_mode$0|0));
               $310 = __THREW__; __THREW__ = 0;
               $311 = $310&1;
               if ($311) {
                label = 51;
                break L163;
               } else {
                $decompressedImage$3 = $decompressedImage$1117;
               }
              } else {
               $312 = ($decompressedImage$1117|0)==(0|0);
               if ($312) {
                __THREW__ = 0;
                $313 = (invoke_ii(2988,20)|0);
                $314 = __THREW__; __THREW__ = 0;
                $315 = $314&1;
                if ($315) {
                 label = 51;
                 break L163;
                }
                __THREW__ = 0;
                invoke_viiii(365,($313|0),($316|0),($317|0),4);
                $318 = __THREW__; __THREW__ = 0;
                $319 = $318&1;
                if ($319) {
                 label = 104;
                 break L163;
                } else {
                 $decompressedImage$2 = $313;
                }
               } else {
                __THREW__ = 0;
                invoke_viiiii(97,($decompressedImage$1117|0),($316|0),($317|0),4,0);
                $322 = __THREW__; __THREW__ = 0;
                $323 = $322&1;
                if ($323) {
                 label = 51;
                 break L163;
                } else {
                 $decompressedImage$2 = $decompressedImage$1117;
                }
               }
               $324 = HEAP32[$284>>2]|0;
               $325 = HEAP32[$324>>2]|0;
               $326 = (($325) + 96|0);
               $327 = HEAP32[$326>>2]|0;
               __THREW__ = 0;
               (invoke_iiii($327|0,($324|0),($decompressedImage$2|0),0)|0);
               $328 = __THREW__; __THREW__ = 0;
               $329 = $328&1;
               if ($329) {
                label = 51;
                break L163;
               }
               $330 = (($decompressedImage$2) + 4|0);
               $331 = HEAP32[$330>>2]|0;
               $332 = ($destWidth$0120|0)==($331|0);
               if ($332) {
                $333 = (($decompressedImage$2) + 8|0);
                $334 = HEAP32[$333>>2]|0;
                $335 = ($destHeight$0122|0)==($334|0);
                $$14 = $335 ? 0 : 2;
                $blit_mode11$0 = $$14;
               } else {
                $blit_mode11$0 = 2;
               }
               __THREW__ = 0;
               invoke_viii(1729,($destRect|0),($decompressedImage$2|0),($blit_mode11$0|0));
               $336 = __THREW__; __THREW__ = 0;
               $337 = $336&1;
               if ($337) {
                label = 51;
                break L163;
               } else {
                $decompressedImage$3 = $decompressedImage$2;
               }
              }
              $338 = (($destCoordX$0118|0) / 2)&-1;
              $339 = (($destCoordY$0119|0) / 2)&-1;
              $340 = (($destWidth$0120|0) / 2)&-1;
              $341 = (($destHeight$0122|0) / 2)&-1;
              $342 = (($316|0) / 2)&-1;
              $343 = ($342|0)<(1);
              $344 = $343 ? 1 : $342;
              $345 = (($317|0) / 2)&-1;
              $346 = ($345|0)<(1);
              $347 = $346 ? 1 : $345;
              $348 = (($mip$0126) + 1)|0;
              $349 = ($348|0)==($290|0);
              if ($349) {
               $decompressedImage$1$lcssa = $decompressedImage$3;
               break;
              } else {
               $316 = $344;$317 = $347;$decompressedImage$1117 = $decompressedImage$3;$destCoordX$0118 = $338;$destCoordY$0119 = $339;$destHeight$0122 = $341;$destWidth$0120 = $340;$mip$0126 = $348;
              }
             }
            }
            $350 = (($i$6134) + 1)|0;
            $351 = ($350|0)<($textureCount|0);
            if ($351) {
             $decompressedImage$0133 = $decompressedImage$1$lcssa;$i$6134 = $350;
            } else {
             label = 112;
             break;
            }
           }
           if ((label|0) == 51) {
            $161 = ___cxa_find_matching_catch()|0;
            $162 = tempRet0;
            $eh$lpad$body$index12Z2D = $162;$eh$lpad$body$indexZ2D = $161;
            label = 57;
            break L96;
           }
           else if ((label|0) == 52) {
            $163 = ___cxa_find_matching_catch()|0;
            $164 = tempRet0;
            $eh$lpad$body$index12Z2D = $164;$eh$lpad$body$indexZ2D = $163;
            label = 57;
            break L96;
           }
           else if ((label|0) == 104) {
            $320 = ___cxa_find_matching_catch()|0;
            $321 = tempRet0;
            __ZdlPv($313);
            $$04 = $320;$$05 = $321;
            break L96;
           }
           else if ((label|0) == 112) {
            $352 = ($decompressedImage$1$lcssa|0)==(0|0);
            if ($352) {
             $$0 = 1;
             label = 148;
             break L96;
            }
            $353 = (($decompressedImage$1$lcssa) + 16|0);
            $354 = HEAP32[$353>>2]|0;
            $355 = HEAP32[628224>>2]|0;
            HEAP32[$0>>2] = $355;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
            invoke_vii(2591,($354|0),($$byval_copy|0));
            $356 = __THREW__; __THREW__ = 0;
            $357 = $356&1;
            if ($357) {
             $358 = ___cxa_find_matching_catch()|0;
             $359 = tempRet0;
             __ZdlPv($decompressedImage$1$lcssa);
             $$04 = $358;$$05 = $359;
             break L96;
            } else {
             __ZdlPv($decompressedImage$1$lcssa);
             $$0 = 1;
             label = 148;
             break L96;
            }
           }
          }
         }
        }
       }
      } while(0);
      $171 = ___cxa_find_matching_catch()|0;
      $172 = tempRet0;
      $eh$lpad$body$index12Z2D = $172;$eh$lpad$body$indexZ2D = $171;
      label = 57;
     }
    } while(0);
    if ((label|0) == 57) {
     $$04 = $eh$lpad$body$indexZ2D;$$05 = $eh$lpad$body$index12Z2D;
    }
    else if ((label|0) == 148) {
     __THREW__ = 0;
     invoke_vi(3468,($tree|0));
     $500 = __THREW__; __THREW__ = 0;
     $501 = $500&1;
     if ($501) {
      label = 50;
      break;
     }
     $502 = HEAP32[$textureNodes>>2]|0;
     $503 = ($502|0)==(0|0);
     if (!($503)) {
      $504 = HEAP32[$116>>2]|0;
      $505 = ($504|0)==($502|0);
      if (!($505)) {
       $__new_last2$i$i$i$i$i58 = $502;
       $scevgep$i$i$i$i$i59 = (($504) + -4|0);
       $506 = (0 - ($__new_last2$i$i$i$i$i58))|0;
       $uglygep$i$i$i$i$i61 = (($scevgep$i$i$i$i$i59) + ($506)|0);
       $uglygep3$i$i$i$i$i62 = $uglygep$i$i$i$i$i61;
       $507 = $uglygep3$i$i$i$i$i62 >>> 2;
       $508 = $507 ^ -1;
       $scevgep4$i$i$i$i$i63 = (($504) + ($508<<2)|0);
       HEAP32[$116>>2] = $scevgep4$i$i$i$i$i63;
      }
      __ZdlPv($502);
     }
     $511 = HEAP32[$142>>2]|0;
     $512 = ($511|0)==(0|0);
     if (!($512)) {
      $513 = HEAP32[$74>>2]|0;
      $514 = ($513|0)==($511|0);
      if (!($514)) {
       $__new_last2$i$i$i$i$i49 = $511;
       $scevgep$i$i$i$i$i50 = (($513) + -4|0);
       $515 = (0 - ($__new_last2$i$i$i$i$i49))|0;
       $uglygep$i$i$i$i$i52 = (($scevgep$i$i$i$i$i50) + ($515)|0);
       $uglygep3$i$i$i$i$i53 = $uglygep$i$i$i$i$i52;
       $516 = $uglygep3$i$i$i$i$i53 >>> 2;
       $517 = $516 ^ -1;
       $scevgep4$i$i$i$i$i54 = (($513) + ($517<<2)|0);
       HEAP32[$74>>2] = $scevgep4$i$i$i$i$i54;
      }
      __ZdlPv($511);
     }
     $525 = HEAP32[$textureSizes>>2]|0;
     $526 = ($525|0)==(0|0);
     if ($526) {
      STACKTOP = sp;return ($$0|0);
     }
     $527 = HEAP32[$5>>2]|0;
     $528 = ($527|0)==($525|0);
     if (!($528)) {
      $__new_last2$i$i$i$i$i25 = $525;
      $scevgep$i$i$i$i$i26 = (($527) + -8|0);
      $529 = (0 - ($__new_last2$i$i$i$i$i25))|0;
      $uglygep$i$i$i$i$i28 = (($scevgep$i$i$i$i$i26) + ($529)|0);
      $uglygep3$i$i$i$i$i29 = $uglygep$i$i$i$i$i28;
      $530 = $uglygep3$i$i$i$i$i29 >>> 3;
      $531 = $530 ^ -1;
      $scevgep4$i$i$i$i$i30 = (($527) + ($531<<3)|0);
      HEAP32[$5>>2] = $scevgep4$i$i$i$i$i30;
     }
     __ZdlPv($525);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3468,($tree|0));
    $509 = __THREW__; __THREW__ = 0;
    $510 = $509&1;
    if ($510) {
     $548 = ___cxa_find_matching_catch(0|0)|0;
     $549 = tempRet0;
     ___clang_call_terminate($548);
     // unreachable;
    } else {
     $$1 = $$04;$$16 = $$05;
    }
   }
  } while(0);
  if ((label|0) == 50) {
   $159 = ___cxa_find_matching_catch()|0;
   $160 = tempRet0;
   $$1 = $159;$$16 = $160;
  }
  $518 = HEAP32[$textureNodes>>2]|0;
  $519 = ($518|0)==(0|0);
  if ($519) {
   $$2 = $$1;$$27 = $$16;$533 = $142;$536 = $74;
   label = 167;
  } else {
   $520 = HEAP32[$116>>2]|0;
   $521 = ($520|0)==($518|0);
   if (!($521)) {
    $__new_last2$i$i$i$i$i34 = $518;
    $scevgep$i$i$i$i$i35 = (($520) + -4|0);
    $522 = (0 - ($__new_last2$i$i$i$i$i34))|0;
    $uglygep$i$i$i$i$i37 = (($scevgep$i$i$i$i$i35) + ($522)|0);
    $uglygep3$i$i$i$i$i38 = $uglygep$i$i$i$i$i37;
    $523 = $uglygep3$i$i$i$i$i38 >>> 2;
    $524 = $523 ^ -1;
    $scevgep4$i$i$i$i$i39 = (($520) + ($524<<2)|0);
    HEAP32[$116>>2] = $scevgep4$i$i$i$i$i39;
   }
   __ZdlPv($518);
   $$2 = $$1;$$27 = $$16;$533 = $142;$536 = $74;
   label = 167;
  }
 }
 if ((label|0) == 167) {
  $532 = HEAP32[$533>>2]|0;
  $534 = ($532|0)==(0|0);
  if ($534) {
   $$3 = $$2;$$38 = $$27;
  } else {
   $535 = HEAP32[$536>>2]|0;
   $537 = ($535|0)==($532|0);
   if (!($537)) {
    $__new_last2$i$i$i$i$i18 = $532;
    $scevgep$i$i$i$i$i19 = (($535) + -4|0);
    $538 = (0 - ($__new_last2$i$i$i$i$i18))|0;
    $uglygep$i$i$i$i$i21 = (($scevgep$i$i$i$i$i19) + ($538)|0);
    $uglygep3$i$i$i$i$i22 = $uglygep$i$i$i$i$i21;
    $539 = $uglygep3$i$i$i$i$i22 >>> 2;
    $540 = $539 ^ -1;
    $scevgep4$i$i$i$i$i23 = (($535) + ($540<<2)|0);
    HEAP32[$536>>2] = $scevgep4$i$i$i$i$i23;
   }
   __ZdlPv($532);
   $$3 = $$2;$$38 = $$27;
  }
 }
 $541 = HEAP32[$textureSizes>>2]|0;
 $542 = ($541|0)==(0|0);
 if ($542) {
  ___resumeException($$3|0);
  // unreachable;
 }
 $543 = HEAP32[$5>>2]|0;
 $544 = ($543|0)==($541|0);
 if (!($544)) {
  $__new_last2$i$i$i$i$i = $541;
  $scevgep$i$i$i$i$i = (($543) + -8|0);
  $545 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($545)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $546 = $uglygep3$i$i$i$i$i >>> 3;
  $547 = $546 ^ -1;
  $scevgep4$i$i$i$i$i = (($543) + ($547<<3)|0);
  HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($541);
 ___resumeException($$3|0);
 // unreachable;
 return 0|0;
}
function __ZNSt3__16vectorIP4NodeNS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    HEAP32[$10>>2] = 0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 4|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i57 = 0;$31 = 0;
  } else {
   $$0$i56 = $26;
   label = 9;
  }
 } else {
  $$0$i56 = 1073741823;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = $$0$i56 << 2;
  $29 = (__Znwj($28)|0);
  $$0$i57 = $$0$i56;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if ($32) {
   $35 = 0;
  } else {
   HEAP32[$33>>2] = 0;
   $35 = $33;
  }
  $34 = (($35) + 4|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $34;
  }
 }
 $38 = (($31) + ($$0$i57<<2)|0);
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = $40;
 $42 = $39;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 2;
 $$sum = (($18) - ($44))|0;
 $45 = (($31) + ($$sum<<2)|0);
 _memcpy(($45|0),($39|0),($43|0))|0;
 HEAP32[$this>>2] = $45;
 HEAP32[$2>>2] = $34;
 HEAP32[$0>>2] = $38;
 $46 = ($39|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZdlPv($39);
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIR11IndexSorterPiEEvT0_S4_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__i$02$i = 0, $__i$07 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0;
 var $__j$5 = 0, $__k$0$i = 0, $__k$0$lcssa$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 2;
   switch ($4|0) {
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 50;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   default: {
   }
   }
   $26 = ($3|0)<(124);
   if ($26) {
    label = 10;
    break L1;
   }
   $65 = ($3|0)>(3996);
   $66 = (($4|0) / 2)&-1;
   $67 = (($$0) + ($66<<2)|0);
   if ($65) {
    $68 = (($4|0) / 4)&-1;
    $69 = (($$0) + ($68<<2)|0);
    $$sum = (($68) + ($66))|0;
    $70 = (($$0) + ($$sum<<2)|0);
    $71 = (__ZNSt3__17__sort5IR11IndexSorterPiEEjT0_S4_S4_S4_S4_T_($$0,$69,$67,$70,$1,$__comp)|0);
    $__n_swaps$0 = $71;
   } else {
    $72 = (__ZNSt3__17__sort3IR11IndexSorterPiEEjT0_S4_S4_T_($$0,$67,$1,$__comp)|0);
    $__n_swaps$0 = $72;
   }
   $73 = HEAP32[$$0>>2]|0;
   $74 = HEAP32[$67>>2]|0;
   $75 = HEAP32[$__comp>>2]|0;
   $76 = HEAP32[$75>>2]|0;
   $77 = (($76) + ($73<<3)|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ((($76) + ($73<<3)|0) + 4|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = Math_imul($80, $78)|0;
   $82 = (($76) + ($74<<3)|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ((($76) + ($74<<3)|0) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = Math_imul($85, $83)|0;
   $87 = ($81|0)>($86|0);
   do {
    if ($87) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $88 = (($__j$0) + -4|0);
      $89 = ($$0|0)==($88|0);
      if ($89) {
       break;
      }
      $134 = HEAP32[$88>>2]|0;
      $135 = (($76) + ($134<<3)|0);
      $136 = HEAP32[$135>>2]|0;
      $137 = ((($76) + ($134<<3)|0) + 4|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = Math_imul($138, $136)|0;
      $140 = ($139|0)>($86|0);
      if ($140) {
       label = 33;
       break;
      } else {
       $__j$0 = $88;
      }
     }
     if ((label|0) == 33) {
      label = 0;
      HEAP32[$$0>>2] = $134;
      HEAP32[$88>>2] = $73;
      $141 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $88;$__n_swaps$3 = $141;
      break;
     }
     $90 = (($$0) + 4|0);
     $91 = HEAP32[$1>>2]|0;
     $92 = (($76) + ($91<<3)|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ((($76) + ($91<<3)|0) + 4|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = Math_imul($95, $93)|0;
     $97 = ($81|0)>($96|0);
     if ($97) {
      $__i$1 = $90;
     } else {
      $98 = ($90|0)==($1|0);
      if ($98) {
       label = 50;
       break L1;
      } else {
       $__i$07 = $90;
      }
      while(1) {
       $101 = HEAP32[$__i$07>>2]|0;
       $102 = (($76) + ($101<<3)|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = ((($76) + ($101<<3)|0) + 4|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = Math_imul($105, $103)|0;
       $107 = ($81|0)>($106|0);
       $100 = (($__i$07) + 4|0);
       if ($107) {
        break;
       }
       $99 = ($100|0)==($1|0);
       if ($99) {
        label = 50;
        break L1;
       } else {
        $__i$07 = $100;
       }
      }
      HEAP32[$__i$07>>2] = $91;
      HEAP32[$1>>2] = $101;
      $__i$1 = $100;
     }
     $108 = ($__i$1|0)==($1|0);
     if ($108) {
      label = 50;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $109 = HEAP32[$$0>>2]|0;
      $110 = HEAP32[$__comp>>2]|0;
      $111 = HEAP32[$110>>2]|0;
      $112 = (($111) + ($109<<3)|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = ((($111) + ($109<<3)|0) + 4|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = Math_imul($115, $113)|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $117 = HEAP32[$__i$2>>2]|0;
       $118 = (($111) + ($117<<3)|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ((($111) + ($117<<3)|0) + 4|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = Math_imul($121, $119)|0;
       $123 = ($116|0)>($122|0);
       $124 = (($__i$2) + 4|0);
       if ($123) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $124;
       }
      }
      while(1) {
       $125 = (($__j$2) + -4|0);
       $126 = HEAP32[$125>>2]|0;
       $127 = (($111) + ($126<<3)|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = ((($111) + ($126<<3)|0) + 4|0);
       $130 = HEAP32[$129>>2]|0;
       $131 = Math_imul($130, $128)|0;
       $132 = ($116|0)>($131|0);
       if ($132) {
        $__j$2 = $125;
       } else {
        break;
       }
      }
      $133 = ($__i$2>>>0)<($125>>>0);
      if (!($133)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__i$2>>2] = $126;
      HEAP32[$125>>2] = $117;
      $__i$2$ph = $124;$__j$1$ph = $125;
     }
    }
   } while(0);
   $142 = (($$0) + 4|0);
   $143 = ($142>>>0)<($__j$3>>>0);
   L34: do {
    if ($143) {
     $__i$3$ph = $142;$__j$4$ph = $__j$3;$__m$0$ph = $67;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $144 = HEAP32[$__m$0$ph>>2]|0;
      $145 = HEAP32[$__comp>>2]|0;
      $146 = HEAP32[$145>>2]|0;
      $147 = (($146) + ($144<<3)|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ((($146) + ($144<<3)|0) + 4|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = Math_imul($150, $148)|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $152 = HEAP32[$__i$3>>2]|0;
       $153 = (($146) + ($152<<3)|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = ((($146) + ($152<<3)|0) + 4|0);
       $156 = HEAP32[$155>>2]|0;
       $157 = Math_imul($156, $154)|0;
       $158 = ($157|0)>($151|0);
       $159 = (($__i$3) + 4|0);
       if ($158) {
        $__i$3 = $159;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $160 = (($__j$5) + -4|0);
       $161 = HEAP32[$160>>2]|0;
       $162 = (($146) + ($161<<3)|0);
       $163 = HEAP32[$162>>2]|0;
       $164 = ((($146) + ($161<<3)|0) + 4|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = Math_imul($165, $163)|0;
       $167 = ($166|0)>($151|0);
       if ($167) {
        break;
       } else {
        $__j$5 = $160;
       }
      }
      $168 = ($__i$3>>>0)>($160>>>0);
      if ($168) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      HEAP32[$__i$3>>2] = $161;
      HEAP32[$160>>2] = $152;
      $169 = (($__n_swaps$4$ph) + 1)|0;
      $170 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $170 ? $160 : $__m$0$ph;
      $__i$3$ph = $159;$__j$4$ph = $160;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $169;
     }
    } else {
     $__i$4 = $142;$__m$2 = $67;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $171 = ($__i$4|0)==($__m$2|0);
   if ($171) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $172 = HEAP32[$__m$2>>2]|0;
    $173 = HEAP32[$__i$4>>2]|0;
    $174 = HEAP32[$__comp>>2]|0;
    $175 = HEAP32[$174>>2]|0;
    $176 = (($175) + ($172<<3)|0);
    $177 = HEAP32[$176>>2]|0;
    $178 = ((($175) + ($172<<3)|0) + 4|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = Math_imul($179, $177)|0;
    $181 = (($175) + ($173<<3)|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = ((($175) + ($173<<3)|0) + 4|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = Math_imul($184, $182)|0;
    $186 = ($180|0)>($185|0);
    if ($186) {
     HEAP32[$__i$4>>2] = $172;
     HEAP32[$__m$2>>2] = $173;
     $187 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $187;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $188 = ($__n_swaps$6|0)==(0);
   if ($188) {
    $189 = (__ZNSt3__127__insertion_sort_incompleteIR11IndexSorterPiEEbT0_S4_T_($$0,$__i$4,$__comp)|0);
    $190 = (($__i$4) + 4|0);
    $191 = (__ZNSt3__127__insertion_sort_incompleteIR11IndexSorterPiEEbT0_S4_T_($190,$$01$ph,$__comp)|0);
    if ($191) {
     label = 45;
     break;
    }
    if ($189) {
     $$0 = $190;
     continue;
    }
   }
   $192 = $__i$4;
   $193 = (($192) - ($2))|0;
   $194 = (($0) - ($192))|0;
   $195 = ($193|0)<($194|0);
   if (!($195)) {
    label = 49;
    break;
   }
   __ZNSt3__16__sortIR11IndexSorterPiEEvT0_S4_T_($$0,$__i$4,$__comp);
   $196 = (($__i$4) + 4|0);
   $$0 = $196;
  }
  if ((label|0) == 45) {
   label = 0;
   if ($189) {
    label = 50;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 49) {
   label = 0;
   $197 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIR11IndexSorterPiEEvT0_S4_T_($197,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = HEAP32[$__comp>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($5<<3)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($8) + ($5<<3)|0) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = Math_imul($12, $10)|0;
  $14 = (($8) + ($6<<3)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($8) + ($6<<3)|0) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = Math_imul($17, $15)|0;
  $19 = ($13|0)>($18|0);
  if (!($19)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $5;
  HEAP32[$1>>2] = $6;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $20 = (($$0) + 4|0);
  (__ZNSt3__17__sort3IR11IndexSorterPiEEjT0_S4_S4_T_($$0,$20,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $21 = (($$0) + 4|0);
  $22 = (($$0) + 8|0);
  (__ZNSt3__17__sort4IR11IndexSorterPiEEjT0_S4_S4_S4_T_($$0,$21,$22,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $23 = (($$0) + 4|0);
  $24 = (($$0) + 8|0);
  $25 = (($$0) + 12|0);
  (__ZNSt3__17__sort5IR11IndexSorterPiEEjT0_S4_S4_S4_S4_T_($$0,$23,$24,$25,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  $27 = (($$0) + 8|0);
  $28 = (($$0) + 4|0);
  (__ZNSt3__17__sort3IR11IndexSorterPiEEjT0_S4_S4_T_($$0,$28,$27,$__comp)|0);
  $29 = (($$0) + 12|0);
  $30 = ($29|0)==($$01$ph|0);
  if ($30) {
   STACKTOP = sp;return;
  } else {
   $__i$02$i = $29;$__j$01$i = $27;
  }
  while(1) {
   $31 = HEAP32[$__i$02$i>>2]|0;
   $32 = HEAP32[$__j$01$i>>2]|0;
   $33 = HEAP32[$__comp>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + ($31<<3)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($34) + ($31<<3)|0) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = Math_imul($38, $36)|0;
   $40 = (($34) + ($32<<3)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ((($34) + ($32<<3)|0) + 4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = Math_imul($43, $41)|0;
   $45 = ($39|0)>($44|0);
   if ($45) {
    $46 = $32;$__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     HEAP32[$__j$1$i>>2] = $46;
     $47 = ($__k$0$i|0)==($$0|0);
     if ($47) {
      $__k$0$lcssa$i = $$0;
      break;
     }
     $48 = (($__k$0$i) + -4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = HEAP32[$__comp>>2]|0;
     $51 = HEAP32[$50>>2]|0;
     $52 = (($51) + ($31<<3)|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($51) + ($31<<3)|0) + 4|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = Math_imul($55, $53)|0;
     $57 = (($51) + ($49<<3)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ((($51) + ($49<<3)|0) + 4|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = Math_imul($60, $58)|0;
     $62 = ($56|0)>($61|0);
     if ($62) {
      $__j$1$i$phi = $__k$0$i;$46 = $49;$__k$0$i = $48;$__j$1$i = $__j$1$i$phi;
     } else {
      $__k$0$lcssa$i = $__k$0$i;
      break;
     }
    }
    HEAP32[$__k$0$lcssa$i>>2] = $31;
   }
   $63 = (($__i$02$i) + 4|0);
   $64 = ($63|0)==($$01$ph|0);
   if ($64) {
    break;
   } else {
    $__j$01$i$phi = $__i$02$i;$__i$02$i = $63;$__j$01$i = $__j$01$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 50) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IR11IndexSorterPiEEjT0_S4_S4_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__y>>2]|0;
 $1 = HEAP32[$__x>>2]|0;
 $2 = HEAP32[$__c>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($0<<3)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + ($0<<3)|0) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = Math_imul($7, $5)|0;
 $9 = (($3) + ($1<<3)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($3) + ($1<<3)|0) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = Math_imul($12, $10)|0;
 $14 = ($8|0)>($13|0);
 $15 = HEAP32[$__z>>2]|0;
 $16 = (($3) + ($15<<3)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($3) + ($15<<3)|0) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = Math_imul($19, $17)|0;
 $21 = ($20|0)>($8|0);
 if (!($14)) {
  if (!($21)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__y>>2] = $15;
  HEAP32[$__z>>2] = $0;
  $22 = HEAP32[$__y>>2]|0;
  $23 = HEAP32[$__x>>2]|0;
  $24 = HEAP32[$__c>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + ($22<<3)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($25) + ($22<<3)|0) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = Math_imul($29, $27)|0;
  $31 = (($25) + ($23<<3)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($25) + ($23<<3)|0) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = Math_imul($34, $32)|0;
  $36 = ($30|0)>($35|0);
  if (!($36)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__x>>2] = $22;
  HEAP32[$__y>>2] = $23;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($21) {
  HEAP32[$__x>>2] = $15;
  HEAP32[$__z>>2] = $1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$__x>>2] = $0;
 HEAP32[$__y>>2] = $1;
 $37 = HEAP32[$__z>>2]|0;
 $38 = HEAP32[$__c>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + ($37<<3)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ((($39) + ($37<<3)|0) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = Math_imul($43, $41)|0;
 $45 = (($39) + ($1<<3)|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($39) + ($1<<3)|0) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = Math_imul($48, $46)|0;
 $50 = ($44|0)>($49|0);
 if (!($50)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$__y>>2] = $37;
 HEAP32[$__z>>2] = $1;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IR11IndexSorterPiEEjT0_S4_S4_S4_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IR11IndexSorterPiEEjT0_S4_S4_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = HEAP32[$__x4>>2]|0;
 $2 = HEAP32[$__x3>>2]|0;
 $3 = HEAP32[$__c>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<3)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + ($1<<3)|0) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_imul($8, $6)|0;
 $10 = (($4) + ($2<<3)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($4) + ($2<<3)|0) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_imul($13, $11)|0;
 $15 = ($9|0)>($14|0);
 if (!($15)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $1;
 HEAP32[$__x4>>2] = $2;
 $16 = (($0) + 1)|0;
 $17 = HEAP32[$__x3>>2]|0;
 $18 = HEAP32[$__x2>>2]|0;
 $19 = HEAP32[$__c>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($17<<3)|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($20) + ($17<<3)|0) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = Math_imul($24, $22)|0;
 $26 = (($20) + ($18<<3)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($20) + ($18<<3)|0) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = Math_imul($29, $27)|0;
 $31 = ($25|0)>($30|0);
 if (!($31)) {
  $__r$0 = $16;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $17;
 HEAP32[$__x3>>2] = $18;
 $32 = (($0) + 2)|0;
 $33 = HEAP32[$__x2>>2]|0;
 $34 = HEAP32[$__x1>>2]|0;
 $35 = HEAP32[$__c>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + ($33<<3)|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ((($36) + ($33<<3)|0) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = Math_imul($40, $38)|0;
 $42 = (($36) + ($34<<3)|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ((($36) + ($34<<3)|0) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = Math_imul($45, $43)|0;
 $47 = ($41|0)>($46|0);
 if (!($47)) {
  $__r$0 = $32;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $33;
 HEAP32[$__x2>>2] = $34;
 $48 = (($0) + 3)|0;
 $__r$0 = $48;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IR11IndexSorterPiEEjT0_S4_S4_S4_S4_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IR11IndexSorterPiEEjT0_S4_S4_S4_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $1 = HEAP32[$__x5>>2]|0;
 $2 = HEAP32[$__x4>>2]|0;
 $3 = HEAP32[$__c>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<3)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + ($1<<3)|0) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_imul($8, $6)|0;
 $10 = (($4) + ($2<<3)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($4) + ($2<<3)|0) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_imul($13, $11)|0;
 $15 = ($9|0)>($14|0);
 if (!($15)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x4>>2] = $1;
 HEAP32[$__x5>>2] = $2;
 $16 = (($0) + 1)|0;
 $17 = HEAP32[$__x4>>2]|0;
 $18 = HEAP32[$__x3>>2]|0;
 $19 = HEAP32[$__c>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($17<<3)|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($20) + ($17<<3)|0) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = Math_imul($24, $22)|0;
 $26 = (($20) + ($18<<3)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($20) + ($18<<3)|0) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = Math_imul($29, $27)|0;
 $31 = ($25|0)>($30|0);
 if (!($31)) {
  $__r$0 = $16;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $17;
 HEAP32[$__x4>>2] = $18;
 $32 = (($0) + 2)|0;
 $33 = HEAP32[$__x3>>2]|0;
 $34 = HEAP32[$__x2>>2]|0;
 $35 = HEAP32[$__c>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + ($33<<3)|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ((($36) + ($33<<3)|0) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = Math_imul($40, $38)|0;
 $42 = (($36) + ($34<<3)|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ((($36) + ($34<<3)|0) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = Math_imul($45, $43)|0;
 $47 = ($41|0)>($46|0);
 if (!($47)) {
  $__r$0 = $32;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $33;
 HEAP32[$__x3>>2] = $34;
 $48 = (($0) + 3)|0;
 $49 = HEAP32[$__x2>>2]|0;
 $50 = HEAP32[$__x1>>2]|0;
 $51 = HEAP32[$__c>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + ($49<<3)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($52) + ($49<<3)|0) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = Math_imul($56, $54)|0;
 $58 = (($52) + ($50<<3)|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($52) + ($50<<3)|0) + 4|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = Math_imul($61, $59)|0;
 $63 = ($57|0)>($62|0);
 if (!($63)) {
  $__r$0 = $48;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $49;
 HEAP32[$__x2>>2] = $50;
 $64 = (($0) + 4)|0;
 $__r$0 = $64;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIR11IndexSorterPiEEbT0_S4_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0, $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0;
 var $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 4:  {
  $22 = (($__first) + 4|0);
  $23 = (($__first) + 8|0);
  $24 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IR11IndexSorterPiEEjT0_S4_S4_S4_T_($__first,$22,$23,$24,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $25 = (($__first) + 4|0);
  $26 = (($__first) + 8|0);
  $27 = (($__first) + 12|0);
  $28 = (($__last) + -4|0);
  (__ZNSt3__17__sort5IR11IndexSorterPiEEjT0_S4_S4_S4_S4_T_($__first,$25,$26,$27,$28,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $20 = (($__first) + 4|0);
  $21 = (($__last) + -4|0);
  (__ZNSt3__17__sort3IR11IndexSorterPiEEjT0_S4_S4_T_($__first,$20,$21,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = HEAP32[$__comp>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($5<<3)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($8) + ($5<<3)|0) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = Math_imul($12, $10)|0;
  $14 = (($8) + ($6<<3)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($8) + ($6<<3)|0) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = Math_imul($17, $15)|0;
  $19 = ($13|0)>($18|0);
  if (!($19)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $29 = (($__first) + 8|0);
  $30 = (($__first) + 4|0);
  (__ZNSt3__17__sort3IR11IndexSorterPiEEjT0_S4_S4_T_($__first,$30,$29,$__comp)|0);
  $31 = (($__first) + 12|0);
  $32 = ($31|0)==($__last|0);
  if ($32) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$03 = 0;$__i$04 = $31;$__j$02 = $29;
  while(1) {
   $33 = HEAP32[$__i$04>>2]|0;
   $34 = HEAP32[$__j$02>>2]|0;
   $35 = HEAP32[$__comp>>2]|0;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + ($33<<3)|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($36) + ($33<<3)|0) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = Math_imul($40, $38)|0;
   $42 = (($36) + ($34<<3)|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ((($36) + ($34<<3)|0) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = Math_imul($45, $43)|0;
   $47 = ($41|0)>($46|0);
   if ($47) {
    $48 = $34;$__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     HEAP32[$__j$1>>2] = $48;
     $49 = ($__k$0|0)==($__first|0);
     if ($49) {
      $__k$0$lcssa = $__first;
      break;
     }
     $50 = (($__k$0) + -4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = HEAP32[$__comp>>2]|0;
     $53 = HEAP32[$52>>2]|0;
     $54 = (($53) + ($33<<3)|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ((($53) + ($33<<3)|0) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = Math_imul($57, $55)|0;
     $59 = (($53) + ($51<<3)|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($53) + ($51<<3)|0) + 4|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = Math_imul($62, $60)|0;
     $64 = ($58|0)>($63|0);
     if ($64) {
      $__j$1$phi = $__k$0;$48 = $51;$__k$0 = $50;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $33;
    $65 = (($__count$03) + 1)|0;
    $66 = ($65|0)==(8);
    if ($66) {
     break;
    } else {
     $__count$1 = $65;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $69 = (($__i$04) + 4|0);
   $70 = ($69|0)==($__last|0);
   if ($70) {
    $$0 = 1;
    label = 15;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $69;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 15) {
   STACKTOP = sp;return ($$0|0);
  }
  $67 = (($__i$04) + 4|0);
  $68 = ($67|0)==($__last|0);
  $$0 = $68;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16vectorINS_4pairIiiEENS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
    $11 = (($10) + 4|0);
    HEAP32[$11>>2] = 0;
   }
   $12 = (($10) + 8|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  $scevgep$i = (($3) + ($__n<<3)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 3;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(536870911);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 3;
 $23 = ($22>>>0)<(268435455);
 if ($23) {
  $24 = $21 >> 2;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 536870911;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 3;
  $29 = (__Znwj($28)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<3)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAP32[$33>>2] = 0;
   $34 = (($33) + 4|0);
   HEAP32[$34>>2] = 0;
  }
  $35 = (($33) + 8|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $35;
  }
 }
 $38 = (($31) + ($$0$i58<<3)|0);
 $scevgep$i4 = (($31) + ($19<<3)|0);
 _memcpy(($31|0),($15|0),($17|0))|0;
 HEAP32[$this>>2] = $31;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $38;
 $39 = ($15|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI5RectTIfENS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 16|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 4;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(268435455);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 4;
 $23 = ($22>>>0)<(134217727);
 if ($23) {
  $24 = $21 >> 3;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i57 = 0;$31 = 0;
  } else {
   $$0$i56 = $26;
   label = 9;
  }
 } else {
  $$0$i56 = 268435455;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = $$0$i56 << 4;
  $29 = (__Znwj($28)|0);
  $$0$i57 = $$0$i56;$31 = $29;
 }
 $30 = (($31) + ($18<<4)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if ($32) {
   $35 = 0;
  } else {
   ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;
   $35 = $33;
  }
  $34 = (($35) + 16|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $34;
  }
 }
 $38 = (($31) + ($$0$i57<<4)|0);
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = $40;
 $42 = $39;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 4;
 $$sum = (($18) - ($44))|0;
 $45 = (($31) + ($$sum<<4)|0);
 _memcpy(($45|0),($39|0),($43|0))|0;
 HEAP32[$this>>2] = $45;
 HEAP32[$2>>2] = $34;
 HEAP32[$0>>2] = $38;
 $46 = ($39|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZdlPv($39);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIiNS_9allocatorIiEEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
   }
   $11 = (($10) + 4|0);
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$10 = $11;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($__n))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 if ($22) {
  $23 = $20 >> 1;
  $24 = ($23>>>0)<($18>>>0);
  $25 = $24 ? $18 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 2;
  $28 = (__Znwj($27)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($17<<2)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP32[$32>>2] = 0;
  }
  $33 = (($32) + 4|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($30) + ($18<<2)|0);
 _memcpy(($30|0),($14|0),($16|0))|0;
 HEAP32[$this>>2] = $30;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $36;
 $37 = ($14|0)==(0|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 __ZdlPv($14);
 STACKTOP = sp;return;
}
function __ZN4NodeD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i$i = 0, $$01 = 0, $$01$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 L1: do {
  if (!($1)) {
   $2 = HEAP32[$0>>2]|0;
   $3 = ($2|0)==(0|0);
   do {
    if ($3) {
     label = 5;
    } else {
     __THREW__ = 0;
     invoke_vi(3468,($2|0));
     $4 = __THREW__; __THREW__ = 0;
     $5 = $4&1;
     if ($5) {
      $11 = ___cxa_find_matching_catch()|0;
      $12 = tempRet0;
      __ZdlPv($2);
      $$0$i$i = $12;$$01$i$i = $11;
      break;
     } else {
      __ZdlPv($2);
      label = 5;
      break;
     }
    }
   } while(0);
   L8: do {
    if ((label|0) == 5) {
     $6 = (($0) + 4|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = ($7|0)==(0|0);
     do {
      if (!($8)) {
       __THREW__ = 0;
       invoke_vi(3469,($7|0));
       $9 = __THREW__; __THREW__ = 0;
       $10 = $9&1;
       if ($10) {
        $13 = ___cxa_find_matching_catch()|0;
        $14 = tempRet0;
        __ZdlPv($7);
        $$0$i$i = $14;$$01$i$i = $13;
        break L8;
       } else {
        __ZdlPv($7);
        break;
       }
      }
     } while(0);
     __ZdlPv($0);
     break L1;
    }
   } while(0);
   __ZdlPv($0);
   $$0 = $$0$i$i;$$01 = $$01$i$i;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3469,($16|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  __ZdlPv($16);
  $$0 = $21;$$01 = $20;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  __ZdlPv($16);
  STACKTOP = sp;return;
 }
}
function __Z20RenderMultipleMeshesRK22RenderMultipleMeshDataRK14ChannelAssigns($renderData,$channels) {
 $renderData = $renderData|0;
 $channels = $channels|0;
 var $$ = 0, $$$i = 0, $$0$lcssa$i = 0, $$03$i = 0, $$4 = 0, $$4$batchIndexCount$3 = 0, $$batchVertexCount$0 = 0, $$idx = 0, $$idx$val = 0, $$idx9 = 0, $$idx9$val = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $batchIndexCount$124 = 0, $batchIndexCount$124$us = 0, $batchIndexCount$331 = 0, $batchIndexCount$5 = 0, $batchVertexCount$033 = 0, $batchVertexCount$2 = 0, $brmerge = 0, $channels$i = 0, $channelsLayout = 0, $dynamicBatchingStarted$0$off05$i = 0, $dynamicBatchingStarted$2$off0$i = 0, $iBatchBegin$0$be = 0;
 var $iBatchBegin$042 = 0, $iBatchBegin$1$ph55 = 0, $iBatchBegin$139 = 0, $iBatchEnd$0$lcssa = 0, $iBatchEnd$0$lcssa$ph = 0, $iBatchEnd$023 = 0, $iBatchEnd$023$us = 0, $iBatchEnd$127 = 0, $iBatchEnd$130 = 0, $iBatchEnd$2$ph = 0, $iBatchEnd$2$ph65 = 0, $it$04$i = 0, $mask$0$i = 0, $mask$12$i = 0, $meshBuffers = 0, $meshBuffers14 = 0, $nextMeshBuffers = 0, $nextMeshBuffers7 = 0, $not$$i = 0, $not$$i16 = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond$i = 0, $or$cond$i12 = 0, $or$cond$i15 = 0, $or$cond$i18 = 0, $or$cond$not = 0, $or$cond21 = 0, $or$cond22 = 0, $or$cond3 = 0, $or$cond3$not = 0, $or$cond5 = 0, $or$cond7 = 0, $phitmp = 0, $phitmp$i$i = 0, $scevgep$sum = 0, $scevgep53 = 0, $scevgep57 = 0, $uglygep = 0, $uglygep56 = 0;
 var $vbData$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $vbData$i = sp + 252|0;
 $channels$i = sp;
 $meshBuffers = sp + 32|0;
 $0 = sp + 76|0;
 $nextMeshBuffers = sp + 120|0;
 $channelsLayout = sp + 344|0;
 $nextMeshBuffers7 = sp + 208|0;
 $meshBuffers14 = sp + 164|0;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = HEAP32[$renderData>>2]|0;
 $3 = (($2) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 168|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)!=(0|0);
 if ($7) {
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 216|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$10 & 4095]($1,$6);
 }
 $11 = (($channels) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 124;
 $mask$0$i = 4;
 while(1) {
  $14 = ($mask$0$i>>>0)<=($13>>>0);
  $15 = $mask$0$i & $13;
  $16 = ($15|0)==(0);
  $or$cond$i = $14 & $16;
  $17 = $mask$0$i << 1;
  if ($or$cond$i) {
   $mask$0$i = $17;
  } else {
   break;
  }
 }
 $18 = ($mask$0$i>>>0)>($13>>>0);
 if ($18) {
  $$0$lcssa$i = $12;
 } else {
  $$03$i = $12;$mask$12$i = $mask$0$i;
  while(1) {
   $19 = $mask$12$i | $$03$i;
   $20 = $mask$12$i << 1;
   $21 = ($20>>>0)>($13>>>0);
   if ($21) {
    $$0$lcssa$i = $19;
    break;
   } else {
    $$03$i = $19;$mask$12$i = $20;
   }
  }
 }
 $22 = (($renderData) + 8|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 $25 = $12 & 130;
 $26 = ($25|0)==(0);
 $$$i = $26 ? 4 : 6;
 $27 = HEAP32[$renderData>>2]|0;
 $28 = (($renderData) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + (($29*76)|0)|0);
 $31 = ($29|0)==(0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = $$0$lcssa$i >>> 1;
 $33 = $32 & 1431655765;
 $34 = (($$0$lcssa$i) - ($33))|0;
 $35 = $34 & 858993459;
 $36 = $34 >>> 2;
 $37 = $36 & 858993459;
 $38 = (($37) + ($35))|0;
 $39 = $38 >>> 4;
 $40 = (($39) + ($38))|0;
 $41 = $40 & 252645135;
 $42 = Math_imul($41, 16843009)|0;
 $43 = $42 >>> 24;
 $44 = $$0$lcssa$i & 120;
 $45 = ($44>>>0)>(7);
 $iBatchBegin$042 = $27;
 while(1) {
  $47 = (($iBatchBegin$042) + 64|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 40|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = ($50<<24>>24)==(1);
  do {
   if ($51) {
    $52 = (($48) + -28|0);
    $53 = (__ZNK12MeshRenderer23GetMeshUsedForRenderingEv($52)|0);
    $54 = (__ZNK12MeshRenderer26GetAdditionalVertexStreamsEv($52)|0);
    $55 = (__ZNK12MeshRenderer23GetMeshStaticBatchIndexEv($52)|0);
    $192 = $54;$62 = $53;$86 = $55;
    label = 15;
   } else {
    $56 = ($50&255)>(9);
    if ($56) {
     $57 = HEAP32[$48>>2]|0;
     $58 = (($57) + 68|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = (FUNCTION_TABLE_ii[$59 & 4095]($48)|0);
     $192 = 0;$62 = $60;$86 = 0;
     label = 15;
     break;
    } else {
     HEAP32[$meshBuffers>>2] = 0;
     label = 17;
     break;
    }
   }
  } while(0);
  do {
   if ((label|0) == 15) {
    label = 0;
    HEAP32[$meshBuffers>>2] = 0;
    $61 = ($62|0)==(0|0);
    if ($61) {
     label = 17;
    } else {
     __ZN4Mesh14GetMeshBuffersEjPS_($0,$62,$12,0);
     dest=$meshBuffers+0|0; src=$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $$pre = HEAP32[$meshBuffers>>2]|0;
     $phitmp = ($$pre|0)==(0|0);
     if ($phitmp) {
      label = 17;
     } else {
      $65 = (($iBatchBegin$042) + 68|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = (__ZNK4Mesh15GetSubMeshCountEv($62)|0);
      $68 = ($67|0)==(0);
      if ($68) {
       $72 = 0;
      } else {
       $69 = (__ZNK4Mesh15GetSubMeshCountEv($62)|0);
       $70 = (($69) + -1)|0;
       $72 = $70;
      }
      $71 = ($72|0)<($66|0);
      $73 = $71 ? $72 : $66;
      $74 = (($62) + 44|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($75) + (($73*56)|0)|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = ((($75) + (($73*56)|0)|0) + 20|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = ((($75) + (($73*56)|0)|0) + 8|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ($77|0)==(1);
      $83 = $82&1;
      $$ = (($81) + ($83))|0;
      $84 = (($iBatchBegin$042) + 76|0);
      $85 = ($86|0)==(0);
      if ($85) {
       $178 = HEAP32[$meshBuffers>>2]|0;
       $179 = ($178|0)==(0|0);
       $brmerge = $179 | $24;
       if ($brmerge) {
        $iBatchEnd$2$ph65 = $84;
       } else {
        $180 = (($iBatchBegin$042) + 72|0);
        $181 = HEAP32[$180>>2]|0;
        $$idx9 = (($62) + 28|0);
        $$idx9$val = HEAP32[$$idx9>>2]|0;
        $182 = (($$idx9$val) + 108|0);
        $183 = HEAP32[$182>>2]|0;
        $184 = (($$idx9$val) + 112|0);
        $185 = HEAP32[$184>>2]|0;
        $186 = ($183|0)==($185|0);
        $187 = ($79|0)>(300);
        $or$cond$i12 = $186 | $187;
        if ($or$cond$i12) {
         $iBatchEnd$2$ph65 = $84;
        } else {
         $188 = Math_imul($79, $43)|0;
         $not$$i = ($188|0)<(901);
         if ($not$$i) {
          $189 = $181 & $$$i;
          $notlhs = ($189|0)!=(0);
          $notrhs = ($$|0)>(31999);
          $or$cond$not = $notrhs | $notlhs;
          $190 = ($77|0)==(4);
          $or$cond3 = $or$cond$not | $190;
          $or$cond3$not = $or$cond3 ^ 1;
          $191 = ($192|0)==(0|0);
          $or$cond21 = $191 & $or$cond3$not;
          if ($or$cond21) {
           $193 = (($$idx9$val) + 8|0);
           $194 = (($$idx9$val) + 96|0);
           $195 = HEAP32[$194>>2]|0;
           $196 = $195 & $$0$lcssa$i;
           __ZNK14VertexDataInfo17GetChannelsLayoutEv($channelsLayout,$193);
           $197 = ($84|0)==($30|0);
           L35: do {
            if ($197) {
             $batchIndexCount$5 = $$;$batchVertexCount$2 = $79;$iBatchEnd$127 = $30;
            } else {
             $batchIndexCount$331 = $$;$batchVertexCount$033 = $79;$iBatchEnd$130 = $84;
             while(1) {
              $200 = (($iBatchEnd$130) + 72|0);
              $201 = HEAP32[$200>>2]|0;
              $202 = $201 & $$$i;
              $203 = ($202|0)==(0);
              if (!($203)) {
               $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
               break L35;
              }
              $204 = (($iBatchEnd$130) + 64|0);
              $205 = HEAP32[$204>>2]|0;
              $206 = (($205) + 40|0);
              $207 = HEAP8[$206>>0]|0;
              $208 = ($207<<24>>24)==(1);
              if ($208) {
               $214 = (($205) + -28|0);
               $215 = (__ZNK12MeshRenderer23GetMeshUsedForRenderingEv($214)|0);
               $216 = (__ZNK12MeshRenderer26GetAdditionalVertexStreamsEv($214)|0);
               $217 = (__ZNK12MeshRenderer23GetMeshStaticBatchIndexEv($214)|0);
               $218 = ($217|0)==(0);
               if ($218) {
                $220 = $215;$222 = $216;
               } else {
                $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
                break L35;
               }
              } else {
               $209 = ($207&255)>(9);
               if (!($209)) {
                $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
                break L35;
               }
               $210 = HEAP32[$205>>2]|0;
               $211 = (($210) + 68|0);
               $212 = HEAP32[$211>>2]|0;
               $213 = (FUNCTION_TABLE_ii[$212 & 4095]($205)|0);
               $220 = $213;$222 = 0;
              }
              $219 = ($220|0)!=(0|0);
              $221 = ($222|0)==(0|0);
              $or$cond22 = $219 & $221;
              if (!($or$cond22)) {
               $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
               break L35;
              }
              $223 = (($iBatchEnd$130) + 68|0);
              $224 = HEAP32[$223>>2]|0;
              $225 = (__ZNK4Mesh15GetSubMeshCountEv($220)|0);
              $226 = ($225|0)==(0);
              if ($226) {
               $230 = 0;
              } else {
               $227 = (__ZNK4Mesh15GetSubMeshCountEv($220)|0);
               $228 = (($227) + -1)|0;
               $230 = $228;
              }
              $229 = ($230|0)<($224|0);
              $231 = $229 ? $230 : $224;
              $232 = (($220) + 44|0);
              $233 = HEAP32[$232>>2]|0;
              $234 = (($233) + (($231*56)|0)|0);
              $235 = HEAP32[$234>>2]|0;
              $236 = ($235|0)==($77|0);
              if (!($236)) {
               $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
               break L35;
              }
              $237 = ((($233) + (($231*56)|0)|0) + 20|0);
              $238 = HEAP32[$237>>2]|0;
              $$idx = (($220) + 28|0);
              $$idx$val = HEAP32[$$idx>>2]|0;
              $239 = (($$idx$val) + 108|0);
              $240 = HEAP32[$239>>2]|0;
              $241 = (($$idx$val) + 112|0);
              $242 = HEAP32[$241>>2]|0;
              $243 = ($240|0)==($242|0);
              $244 = ($238|0)>(300);
              $or$cond$i15 = $243 | $244;
              if ($or$cond$i15) {
               $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
               break L35;
              }
              $245 = Math_imul($238, $43)|0;
              $not$$i16 = ($245|0)<(901);
              if (!($not$$i16)) {
               $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
               break L35;
              }
              $246 = (($238) + ($batchVertexCount$033))|0;
              $247 = ((($233) + (($231*56)|0)|0) + 8|0);
              $248 = HEAP32[$247>>2]|0;
              $249 = (($248) + ($batchIndexCount$331))|0;
              $250 = (($249) + 3)|0;
              $$4 = $82 ? $250 : $249;
              $251 = ($246>>>0)>(65535);
              $252 = ($$4>>>0)>(32000);
              $or$cond5 = $251 | $252;
              if ($or$cond5) {
               $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
               break L35;
              }
              __ZN4Mesh14GetMeshBuffersEjPS_($nextMeshBuffers7,$220,$12,0);
              $253 = HEAP32[$nextMeshBuffers7>>2]|0;
              $254 = ($253|0)==(0|0);
              if ($254) {
               $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
               break L35;
              }
              if ($45) {
               $256 = 8;$260 = 3;
               while(1) {
                $255 = $256 & $44;
                $257 = ($255|0)==(0);
                if (!($257)) {
                 $258 = HEAP32[$$idx>>2]|0;
                 $259 = ((($258) + ($260<<2)|0) + 10|0);
                 $261 = HEAP8[$259>>0]|0;
                 $262 = (($channelsLayout) + ($260<<1)|0);
                 $263 = HEAP8[$262>>0]|0;
                 $264 = ($261<<24>>24)==($263<<24>>24);
                 if (!($264)) {
                  $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
                  break L35;
                 }
                 $265 = ((($258) + ($260<<2)|0) + 11|0);
                 $266 = HEAP8[$265>>0]|0;
                 $267 = ((($channelsLayout) + ($260<<1)|0) + 1|0);
                 $268 = HEAP8[$267>>0]|0;
                 $phitmp$i$i = ($266<<24>>24)==($268<<24>>24);
                 if (!($phitmp$i$i)) {
                  $batchIndexCount$5 = $batchIndexCount$331;$batchVertexCount$2 = $batchVertexCount$033;$iBatchEnd$127 = $iBatchEnd$130;
                  break L35;
                 }
                }
                $269 = (($260) + 1)|0;
                $270 = $256 << 1;
                $271 = ($269|0)<(8);
                $272 = ($270>>>0)<=($44>>>0);
                $or$cond$i18 = $271 & $272;
                if ($or$cond$i18) {
                 $256 = $270;$260 = $269;
                } else {
                 break;
                }
               }
              }
              $273 = HEAP32[$$idx>>2]|0;
              $274 = (($273) + 96|0);
              $275 = HEAP32[$274>>2]|0;
              $276 = $275 & $$0$lcssa$i;
              $277 = ($196|0)==($276|0);
              $$4$batchIndexCount$3 = $277 ? $$4 : $batchIndexCount$331;
              $$batchVertexCount$0 = $277 ? $246 : $batchVertexCount$033;
              $199 = (($iBatchEnd$130) + 76|0);
              if (!($277)) {
               $batchIndexCount$5 = $$4$batchIndexCount$3;$batchVertexCount$2 = $$batchVertexCount$0;$iBatchEnd$127 = $iBatchEnd$130;
               break L35;
              }
              $198 = ($199|0)==($30|0);
              if ($198) {
               $batchIndexCount$5 = $$4$batchIndexCount$3;$batchVertexCount$2 = $$batchVertexCount$0;$iBatchEnd$127 = $30;
               break;
              } else {
               $batchIndexCount$331 = $$4$batchIndexCount$3;$batchVertexCount$033 = $$batchVertexCount$0;$iBatchEnd$130 = $199;
              }
             }
            }
           } while(0);
           $278 = ($batchVertexCount$2|0)==(0);
           $279 = ($batchIndexCount$5|0)==(0);
           $or$cond7 = $278 | $279;
           if ($or$cond7) {
            $iBatchBegin$0$be = $iBatchEnd$127;
            break;
           }
           $280 = $iBatchEnd$127;
           $281 = $iBatchBegin$042;
           $282 = (($280) - ($281))|0;
           $283 = (($282|0) / 76)&-1;
           $284 = ($283>>>0)<(2);
           if ($284) {
            $iBatchEnd$2$ph = $iBatchEnd$127;
            label = 91;
           } else {
            $285 = (__Z12GetGfxDevicev()|0);
            $286 = (($iBatchBegin$042) + (($283*76)|0)|0);
            $287 = ($282|0)>(0);
            if (!($287)) {
             $iBatchBegin$0$be = $iBatchEnd$127;
             break;
            }
            $288 = $196 & 4;
            $289 = $288 ^ 4;
            $dynamicBatchingStarted$0$off05$i = 0;$it$04$i = $iBatchBegin$042;
            while(1) {
             $290 = (($it$04$i) + 64|0);
             $291 = HEAP32[$290>>2]|0;
             $292 = (($291) + 40|0);
             $293 = HEAP8[$292>>0]|0;
             $294 = ($293<<24>>24)==(1);
             do {
              if ($294) {
               $295 = (($291) + -28|0);
               $296 = (__ZNK12MeshRenderer23GetMeshUsedForRenderingEv($295)|0);
               (__ZNK12MeshRenderer26GetAdditionalVertexStreamsEv($295)|0);
               $303 = $296;
               label = 82;
              } else {
               $297 = ($293&255)>(9);
               if (!($297)) {
                $dynamicBatchingStarted$2$off0$i = $dynamicBatchingStarted$0$off05$i;
                break;
               }
               $298 = HEAP32[$291>>2]|0;
               $299 = (($298) + 68|0);
               $300 = HEAP32[$299>>2]|0;
               $301 = (FUNCTION_TABLE_ii[$300 & 4095]($291)|0);
               $303 = $301;
               label = 82;
              }
             } while(0);
             do {
              if ((label|0) == 82) {
               label = 0;
               $302 = ($303|0)==(0|0);
               if ($302) {
                $dynamicBatchingStarted$2$off0$i = $dynamicBatchingStarted$0$off05$i;
                break;
               }
               $304 = (($it$04$i) + 68|0);
               $305 = HEAP32[$304>>2]|0;
               $306 = (__ZNK4Mesh15GetSubMeshCountEv($303)|0);
               $307 = ($306|0)==(0);
               if ($307) {
                $311 = 0;
               } else {
                $308 = (__ZNK4Mesh15GetSubMeshCountEv($303)|0);
                $309 = (($308) + -1)|0;
                $311 = $309;
               }
               $310 = ($311|0)<($305|0);
               $312 = $310 ? $311 : $305;
               $313 = (($303) + 44|0);
               $314 = HEAP32[$313>>2]|0;
               dest=$vbData$i+0|0; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
               __ZN4Mesh19GetVertexBufferDataER16VertexBufferData($303,$vbData$i);
               $315 = (__ZN4Mesh18GetSubMeshBuffer16Ei($303,$312)|0);
               if (!($dynamicBatchingStarted$0$off05$i)) {
                $316 = HEAP32[$11>>2]|0;
                $317 = HEAP32[((640792 + 76|0))>>2]|0;
                $318 = $316 & $289;
                $319 = $318 & $317;
                ;HEAP32[$channels$i+0>>2]=0|0;HEAP32[$channels$i+4>>2]=0|0;HEAP32[$channels$i+8>>2]=0|0;HEAP32[$channels$i+12>>2]=0|0;HEAP32[$channels$i+16>>2]=0|0;HEAP32[$channels$i+20>>2]=0|0;HEAP32[$channels$i+24>>2]=0|0;HEAP32[$channels$i+28>>2]=0|0;
                $320 = (__Z28BuildSingleStreamChannelInfojRK20VertexChannelsLayoutjS1_P11ChannelInfo($196,$channelsLayout,$319,588176,$channels$i)|0);
                $321 = (__Z26GetMeshVertexFormatManagerv()|0);
                $322 = (__ZN23MeshVertexFormatManager19GetMeshVertexFormatERK18VertexChannelsInfo($321,$channels$i)|0);
                $323 = HEAP32[$11>>2]|0;
                $324 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($322,$323,0)|0);
                $325 = HEAP32[$285>>2]|0;
                $326 = (($325) + 336|0);
                $327 = HEAP32[$326>>2]|0;
                $328 = ($319|0)!=(0);
                FUNCTION_TABLE_viiiiiiiii[$327 & 31]($285,$channels,$196,$328,$320,$324,$batchVertexCount$2,$batchIndexCount$5,$77);
               }
               $329 = HEAP32[$285>>2]|0;
               $330 = (($329) + 340|0);
               $331 = HEAP32[$330>>2]|0;
               $332 = ((($314) + (($312*56)|0)|0) + 16|0);
               $333 = HEAP32[$332>>2]|0;
               $334 = ((($314) + (($312*56)|0)|0) + 20|0);
               $335 = HEAP32[$334>>2]|0;
               $336 = ((($314) + (($312*56)|0)|0) + 8|0);
               $337 = HEAP32[$336>>2]|0;
               FUNCTION_TABLE_viiiiiii[$331 & 127]($285,$it$04$i,$vbData$i,$333,$335,$315,$337);
               $dynamicBatchingStarted$2$off0$i = 1;
              }
             } while(0);
             $338 = (($it$04$i) + 76|0);
             $339 = ($338>>>0)<($286>>>0);
             if ($339) {
              $dynamicBatchingStarted$0$off05$i = $dynamicBatchingStarted$2$off0$i;$it$04$i = $338;
             } else {
              break;
             }
            }
            if (!($dynamicBatchingStarted$2$off0$i)) {
             $iBatchBegin$0$be = $iBatchEnd$127;
             break;
            }
            $340 = HEAP32[$285>>2]|0;
            $341 = (($340) + 344|0);
            $342 = HEAP32[$341>>2]|0;
            FUNCTION_TABLE_vii[$342 & 4095]($285,0);
            $iBatchBegin$0$be = $iBatchEnd$127;
            break;
           }
          } else {
           $iBatchEnd$2$ph65 = $84;
          }
         } else {
          $iBatchEnd$2$ph65 = $84;
         }
        }
       }
      } else {
       (__Z12GetGfxDevicev()|0);
       $87 = (__ZN9GfxDevice24GetMaxStaticBatchIndicesEv()|0);
       $88 = (($62) + 28|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = (($89) + 96|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($84|0)==($30|0);
       L85: do {
        if ($92) {
         $iBatchEnd$0$lcssa$ph = $30;
         label = 46;
        } else {
         if ($82) {
          $batchIndexCount$124$us = $$;$iBatchEnd$023$us = $84;
          while(1) {
           $93 = (($iBatchEnd$023$us) + 64|0);
           $94 = HEAP32[$93>>2]|0;
           $95 = ($94|0)==(0|0);
           if ($95) {
            $97 = 0;
           } else {
            $96 = (($94) + -28|0);
            $97 = $96;
           }
           $98 = (__ZNK12MeshRenderer23GetMeshStaticBatchIndexEv($97)|0);
           $99 = ($86|0)==($98|0);
           if (!($99)) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023$us;
            label = 46;
            break L85;
           }
           $100 = (__ZNK12MeshRenderer23GetMeshUsedForRenderingEv($97)|0);
           $101 = ($100|0)==(0|0);
           if ($101) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023$us;
            label = 46;
            break L85;
           }
           $102 = (($iBatchEnd$023$us) + 68|0);
           $103 = HEAP32[$102>>2]|0;
           $104 = (__ZNK4Mesh15GetSubMeshCountEv($100)|0);
           $105 = ($104|0)==(0);
           if ($105) {
            $109 = 0;
           } else {
            $106 = (__ZNK4Mesh15GetSubMeshCountEv($100)|0);
            $107 = (($106) + -1)|0;
            $109 = $107;
           }
           $108 = ($109|0)<($103|0);
           $110 = $108 ? $109 : $103;
           $111 = (($100) + 44|0);
           $112 = HEAP32[$111>>2]|0;
           $113 = (($112) + (($110*56)|0)|0);
           $114 = HEAP32[$113>>2]|0;
           $115 = ($114|0)==(1);
           if (!($115)) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023$us;
            label = 46;
            break L85;
           }
           __ZN4Mesh14GetMeshBuffersEjPS_($nextMeshBuffers,$100,$12,0);
           $116 = HEAP32[$nextMeshBuffers>>2]|0;
           $117 = HEAP32[$meshBuffers>>2]|0;
           $118 = ($116|0)==($117|0);
           if (!($118)) {
            $173 = $117;$iBatchEnd$0$lcssa = $iBatchEnd$023$us;
            break L85;
           }
           $119 = (($100) + 28|0);
           $120 = HEAP32[$119>>2]|0;
           $121 = (($120) + 96|0);
           $122 = HEAP32[$121>>2]|0;
           $123 = $122 ^ $91;
           $124 = $123 & $12;
           $125 = ($124|0)==(0);
           if (!($125)) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023$us;
            label = 46;
            break L85;
           }
           $126 = ((($112) + (($110*56)|0)|0) + 8|0);
           $127 = HEAP32[$126>>2]|0;
           $128 = (($127) + ($batchIndexCount$124$us))|0;
           $129 = (($128) + 3)|0;
           $130 = ($129>>>0)>($87>>>0);
           if ($130) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023$us;
            label = 46;
            break L85;
           }
           $131 = (($iBatchEnd$023$us) + 76|0);
           $132 = ($131|0)==($30|0);
           if ($132) {
            $iBatchEnd$0$lcssa$ph = $30;
            label = 46;
            break;
           } else {
            $batchIndexCount$124$us = $129;$iBatchEnd$023$us = $131;
           }
          }
         } else {
          $batchIndexCount$124 = $$;$iBatchEnd$023 = $84;
          while(1) {
           $133 = (($iBatchEnd$023) + 64|0);
           $134 = HEAP32[$133>>2]|0;
           $135 = ($134|0)==(0|0);
           if ($135) {
            $137 = 0;
           } else {
            $136 = (($134) + -28|0);
            $137 = $136;
           }
           $138 = (__ZNK12MeshRenderer23GetMeshStaticBatchIndexEv($137)|0);
           $139 = ($86|0)==($138|0);
           if (!($139)) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023;
            label = 46;
            break L85;
           }
           $140 = (__ZNK12MeshRenderer23GetMeshUsedForRenderingEv($137)|0);
           $141 = ($140|0)==(0|0);
           if ($141) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023;
            label = 46;
            break L85;
           }
           $142 = (($iBatchEnd$023) + 68|0);
           $143 = HEAP32[$142>>2]|0;
           $144 = (__ZNK4Mesh15GetSubMeshCountEv($140)|0);
           $145 = ($144|0)==(0);
           if ($145) {
            $149 = 0;
           } else {
            $146 = (__ZNK4Mesh15GetSubMeshCountEv($140)|0);
            $147 = (($146) + -1)|0;
            $149 = $147;
           }
           $148 = ($149|0)<($143|0);
           $150 = $148 ? $149 : $143;
           $151 = (($140) + 44|0);
           $152 = HEAP32[$151>>2]|0;
           $153 = (($152) + (($150*56)|0)|0);
           $154 = HEAP32[$153>>2]|0;
           $155 = ($154|0)==($77|0);
           if (!($155)) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023;
            label = 46;
            break L85;
           }
           __ZN4Mesh14GetMeshBuffersEjPS_($nextMeshBuffers,$140,$12,0);
           $156 = HEAP32[$nextMeshBuffers>>2]|0;
           $157 = HEAP32[$meshBuffers>>2]|0;
           $158 = ($156|0)==($157|0);
           if (!($158)) {
            $173 = $157;$iBatchEnd$0$lcssa = $iBatchEnd$023;
            break L85;
           }
           $159 = (($140) + 28|0);
           $160 = HEAP32[$159>>2]|0;
           $161 = (($160) + 96|0);
           $162 = HEAP32[$161>>2]|0;
           $163 = $162 ^ $91;
           $164 = $163 & $12;
           $165 = ($164|0)==(0);
           if (!($165)) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023;
            label = 46;
            break L85;
           }
           $166 = ((($152) + (($150*56)|0)|0) + 8|0);
           $167 = HEAP32[$166>>2]|0;
           $168 = (($167) + ($batchIndexCount$124))|0;
           $169 = ($168>>>0)>($87>>>0);
           if ($169) {
            $iBatchEnd$0$lcssa$ph = $iBatchEnd$023;
            label = 46;
            break L85;
           }
           $170 = (($iBatchEnd$023) + 76|0);
           $171 = ($170|0)==($30|0);
           if ($171) {
            $iBatchEnd$0$lcssa$ph = $30;
            label = 46;
            break;
           } else {
            $batchIndexCount$124 = $168;$iBatchEnd$023 = $170;
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 46) {
        label = 0;
        $$pr = HEAP32[$meshBuffers>>2]|0;
        $173 = $$pr;$iBatchEnd$0$lcssa = $iBatchEnd$0$lcssa$ph;
       }
       $172 = ($173|0)==(0|0);
       if ($172) {
        $iBatchEnd$2$ph = $iBatchEnd$0$lcssa;
        label = 91;
       } else {
        $174 = $iBatchEnd$0$lcssa;
        $175 = $iBatchBegin$042;
        $176 = (($174) - ($175))|0;
        $177 = (($176|0) / 76)&-1;
        __ZL27RenderStaticBatchDrawRangesR4MeshRK11MeshBuffersPK17BatchInstanceDatajRK14ChannelAssigns($62,$meshBuffers,$iBatchBegin$042,$177,$channels);
        $iBatchBegin$0$be = $iBatchEnd$0$lcssa;
        break;
       }
      }
      if ((label|0) == 91) {
       label = 0;
       $343 = ($iBatchBegin$042|0)==($iBatchEnd$2$ph|0);
       if ($343) {
        $iBatchBegin$0$be = $iBatchEnd$2$ph;
        break;
       } else {
        $iBatchEnd$2$ph65 = $iBatchEnd$2$ph;
       }
      }
      $iBatchBegin$1$ph55 = $iBatchBegin$042;
      $scevgep53 = (($iBatchEnd$2$ph65) + -76|0);
      $344 = (0 - ($iBatchBegin$1$ph55))|0;
      $uglygep = (($scevgep53) + ($344)|0);
      $uglygep56 = $uglygep;
      $46 = (($uglygep56>>>0) / 76)&-1;
      $iBatchBegin$139 = $iBatchBegin$042;
      while(1) {
       $345 = (($iBatchBegin$139) + 64|0);
       $346 = HEAP32[$345>>2]|0;
       $347 = (($346) + 40|0);
       $348 = HEAP8[$347>>0]|0;
       $349 = ($348<<24>>24)==(1);
       if ($349) {
        $350 = (($346) + -28|0);
        $351 = (__ZNK12MeshRenderer23GetMeshUsedForRenderingEv($350)|0);
        $352 = (__ZNK12MeshRenderer26GetAdditionalVertexStreamsEv($350)|0);
        $353 = (($350) + 4|0);
        $354 = HEAP32[$353>>2]|0;
        $361 = $351;$362 = $352;$372 = $354;
        label = 97;
       } else {
        $355 = ($348&255)>(9);
        if ($355) {
         $356 = HEAP32[$346>>2]|0;
         $357 = (($356) + 68|0);
         $358 = HEAP32[$357>>2]|0;
         $359 = (FUNCTION_TABLE_ii[$358 & 4095]($346)|0);
         $361 = $359;$362 = 0;$372 = 0;
         label = 97;
        }
       }
       if ((label|0) == 97) {
        label = 0;
        $360 = ($361|0)==(0|0);
        if (!($360)) {
         __ZN4Mesh14GetMeshBuffersEjPS_($meshBuffers14,$361,$12,$362);
         $363 = HEAP32[$meshBuffers14>>2]|0;
         $364 = ($363|0)==(0|0);
         if (!($364)) {
          if ($7) {
           $365 = HEAP32[$1>>2]|0;
           $366 = (($365) + 216|0);
           $367 = HEAP32[$366>>2]|0;
           FUNCTION_TABLE_vii[$367 & 4095]($1,$6);
          }
          $368 = (($iBatchBegin$139) + 72|0);
          $369 = HEAP32[$368>>2]|0;
          __Z17SetupObjectMatrixRK10Matrix4x4fi($iBatchBegin$139,$369);
          $370 = (($iBatchBegin$139) + 68|0);
          $371 = HEAP32[$370>>2]|0;
          __ZN8DrawUtil18DrawMeshBuffersRawERK11MeshBuffersR4MeshRK14ChannelAssignsii($meshBuffers14,$361,$channels,$371,$372);
         }
        }
       }
       $373 = (($iBatchBegin$139) + 76|0);
       $374 = ($373|0)==($iBatchEnd$2$ph65|0);
       if ($374) {
        break;
       } else {
        $iBatchBegin$139 = $373;
       }
      }
      $scevgep$sum = (($46) + 1)|0;
      $scevgep57 = (($iBatchBegin$042) + (($scevgep$sum*76)|0)|0);
      $iBatchBegin$0$be = $scevgep57;
     }
    }
   }
  } while(0);
  if ((label|0) == 17) {
   label = 0;
   $63 = (($iBatchBegin$042) + 76|0);
   $iBatchBegin$0$be = $63;
  }
  $64 = ($iBatchBegin$0$be|0)==($30|0);
  if ($64) {
   break;
  } else {
   $iBatchBegin$042 = $iBatchBegin$0$be;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27RenderStaticBatchDrawRangesR4MeshRK11MeshBuffersPK17BatchInstanceDatajRK14ChannelAssigns($mesh,$meshBuffers,$instances,$count,$channels) {
 $mesh = $mesh|0;
 $meshBuffers = $meshBuffers|0;
 $instances = $instances|0;
 $count = $count|0;
 $channels = $channels|0;
 var $$byval_copy14 = 0, $$index = 0, $$index8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $allocPtr$0 = 0, $i$02 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy14 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (__Z12GetGfxDevicev()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 92|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$6 & 4095]($3,$instances,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 228|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$9 & 4095]($3,4)|0);
 if ($10) {
  $42 = 1;
 } else {
  $11 = HEAP32[$3>>2]|0;
  $12 = (($11) + 228|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_iii[$13 & 4095]($3,5)|0);
  $42 = $14;
 }
 $15 = ($count*24)|0;
 $16 = (($15) + 15)|0;
 $17 = ($16>>>0)<(2000);
 $18 = ($count|0)!=(0);
 if ($17) {
  if ($18) {
   $19 = STACKTOP; STACKTOP = STACKTOP + ((((1*$16)|0)+15)&-16)|0;;
   $65 = 0;$allocPtr$0 = $19;
   label = 13;
  } else {
   $57 = 0;$61 = 0;
   label = 17;
  }
 } else {
  if ($18) {
   $20 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $20;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
   $21 = (invoke_iiiiiii(102,($16|0),16,($$byval_copy14|0),0,(590672|0),114)|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    $$index = $24;$$index8 = $25;$66 = $0;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $65 = $21;$allocPtr$0 = $21;
    label = 13;
   }
  } else {
   $57 = 0;$61 = 0;
   label = 17;
  }
 }
 L11: do {
  if ((label|0) == 13) {
   $35 = $allocPtr$0;
   $36 = (($35) + 15)|0;
   $37 = $36 & -16;
   $38 = $37;
   $39 = ($count|0)==(0);
   if ($39) {
    $57 = $38;$61 = $65;
    label = 17;
   } else {
    $i$02 = 0;
    while(1) {
     $40 = ((($instances) + (($i$02*76)|0)|0) + 68|0);
     $41 = HEAP32[$40>>2]|0;
     __THREW__ = 0;
     invoke_viiii(366,($2|0),($mesh|0),($41|0),($42|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     $45 = (($38) + (($i$02*24)|0)|0);
     ;HEAP32[$45+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$45+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$45+20>>2]=HEAP32[$2+20>>2]|0;
     $46 = (($i$02) + 1)|0;
     $47 = ($46>>>0)<($count>>>0);
     if ($47) {
      $i$02 = $46;
     } else {
      $57 = $38;$61 = $65;
      label = 17;
      break L11;
     }
    }
    $26 = ___cxa_find_matching_catch()|0;
    $27 = tempRet0;
    $31 = $65;$lpad$phi$index = $26;$lpad$phi$index2 = $27;
   }
  }
 } while(0);
 do {
  if ((label|0) == 17) {
   $48 = HEAP32[$3>>2]|0;
   $49 = (($48) + 300|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = HEAP32[$meshBuffers>>2]|0;
   $52 = (($meshBuffers) + 8|0);
   $53 = (($meshBuffers) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($meshBuffers) + 40|0);
   $56 = HEAP32[$55>>2]|0;
   __THREW__ = 0;
   invoke_viiiiiiii($50|0,($3|0),($51|0),($52|0),($54|0),($57|0),($count|0),($56|0),($channels|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    $31 = $61;$lpad$phi$index = $28;$lpad$phi$index2 = $29;
    break;
   }
   $60 = ($61|0)==(0|0);
   if ($60) {
    STACKTOP = sp;return;
   }
   $62 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $62;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($61,$$byval_copy14);
   STACKTOP = sp;return;
  }
 } while(0);
 $30 = ($31|0)==(0|0);
 if ($30) {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$66 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $32 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $32;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy14|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $63 = ___cxa_find_matching_catch(0|0)|0;
  $64 = tempRet0;
  ___clang_call_terminate($63);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$66 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __Z17AppendMeshIndicesPtRjPKtjb($dstIndices,$dstIndexCount,$srcIndices,$srcIndexCount,$isTriStrip) {
 $dstIndices = $dstIndices|0;
 $dstIndexCount = $dstIndexCount|0;
 $srcIndices = $srcIndices|0;
 $srcIndexCount = $srcIndexCount|0;
 $isTriStrip = $isTriStrip|0;
 var $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $srcIndexCount << 1;
 $1 = HEAP32[$dstIndexCount>>2]|0;
 if (!($isTriStrip)) {
  $16 = (($dstIndices) + ($1<<1)|0);
  _memcpy(($16|0),($srcIndices|0),($0|0))|0;
  $17 = HEAP32[$dstIndexCount>>2]|0;
  $18 = (($17) + ($srcIndexCount))|0;
  HEAP32[$dstIndexCount>>2] = $18;
  STACKTOP = sp;return;
 }
 $2 = ($1|0)==(0);
 if ($2) {
  $$ph = 0;
 } else {
  $3 = (($1) + -1)|0;
  $4 = (($dstIndices) + ($3<<1)|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = (($dstIndices) + ($1<<1)|0);
  HEAP16[$6>>1] = $5;
  $7 = (($1) + 1)|0;
  $8 = HEAP16[$srcIndices>>1]|0;
  $9 = (($dstIndices) + ($7<<1)|0);
  HEAP16[$9>>1] = $8;
  $10 = (($1) + 2)|0;
  HEAP32[$dstIndexCount>>2] = $10;
  $$ph = $10;
 }
 $11 = (($dstIndices) + ($$ph<<1)|0);
 _memcpy(($11|0),($srcIndices|0),($0|0))|0;
 $12 = HEAP32[$dstIndexCount>>2]|0;
 $13 = (($12) + ($srcIndexCount))|0;
 HEAP32[$dstIndexCount>>2] = $13;
 $14 = $srcIndexCount & 1;
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $19 = (($13) + -1)|0;
 $20 = (($dstIndices) + ($19<<1)|0);
 $21 = HEAP16[$20>>1]|0;
 $22 = (($dstIndices) + ($13<<1)|0);
 HEAP16[$22>>1] = $21;
 $23 = (($13) + 1)|0;
 HEAP32[$dstIndexCount>>2] = $23;
 STACKTOP = sp;return;
}
function __Z16TransformIndicesPtPKvjjjjb($dst,$srcIB,$firstByte,$indexCount,$firstVertex,$batchVertexOffset,$isTriStrip) {
 $dst = $dst|0;
 $srcIB = $srcIB|0;
 $firstByte = $firstByte|0;
 $indexCount = $indexCount|0;
 $firstVertex = $firstVertex|0;
 $batchVertexOffset = $batchVertexOffset|0;
 $isTriStrip = $isTriStrip|0;
 var $$0 = 0, $$012$i = 0, $$012$i6 = 0, $$03$i = 0, $$03$i5 = 0, $$1 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0;
 var $exitcond$i7 = 0, $i$04$i = 0, $i$04$i4 = 0, $isTriStrip$not = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($srcIB) + ($firstByte)|0);
 $isTriStrip$not = $isTriStrip ^ 1;
 $1 = ($batchVertexOffset|0)==(0);
 $or$cond = $1 | $isTriStrip$not;
 if ($or$cond) {
  $$pre = (($batchVertexOffset) - ($firstVertex))|0;
  $$0 = $dst;$$pre$phiZ2D = $$pre;
 } else {
  $2 = (($dst) + -2|0);
  $3 = HEAP16[$2>>1]|0;
  HEAP16[$dst>>1] = $3;
  $4 = HEAP16[$0>>1]|0;
  $5 = $4&65535;
  $6 = (($batchVertexOffset) - ($firstVertex))|0;
  $7 = (($6) + ($5))|0;
  $8 = $7&65535;
  $9 = (($dst) + 2|0);
  HEAP16[$9>>1] = $8;
  $10 = (($dst) + 4|0);
  $$0 = $10;$$pre$phiZ2D = $6;
 }
 $11 = $indexCount >>> 1;
 $12 = ($$pre$phiZ2D|0)>(-1);
 $13 = ($11|0)==(0);
 if ($12) {
  if (!($13)) {
   $14 = $11 << 1;
   $$012$i6 = $0;$$03$i5 = $$0;$i$04$i4 = 0;
   while(1) {
    $15 = (($$012$i6) + 2|0);
    $16 = HEAP16[$$012$i6>>1]|0;
    $17 = $16&65535;
    $18 = (($17) + ($$pre$phiZ2D))|0;
    $19 = $18&65535;
    $20 = (($$03$i5) + 2|0);
    HEAP16[$$03$i5>>1] = $19;
    $21 = (($i$04$i4) + 1)|0;
    $exitcond$i7 = ($21|0)==($14|0);
    if ($exitcond$i7) {
     break;
    } else {
     $$012$i6 = $15;$$03$i5 = $20;$i$04$i4 = $21;
    }
   }
  }
 } else {
  if (!($13)) {
   $22 = $11 << 1;
   $$012$i = $0;$$03$i = $$0;$i$04$i = 0;
   while(1) {
    $23 = (($$012$i) + 2|0);
    $24 = HEAP16[$$012$i>>1]|0;
    $25 = $24&65535;
    $26 = (($25) + ($$pre$phiZ2D))|0;
    $27 = $26&65535;
    $28 = (($$03$i) + 2|0);
    HEAP16[$$03$i>>1] = $27;
    $29 = (($i$04$i) + 1)|0;
    $exitcond$i = ($29|0)==($22|0);
    if ($exitcond$i) {
     break;
    } else {
     $$012$i = $23;$$03$i = $28;$i$04$i = $29;
    }
   }
  }
 }
 $30 = $11 << 1;
 $31 = ($30|0)==($indexCount|0);
 if (!($31)) {
  $32 = (($indexCount) + -1)|0;
  $33 = (($0) + ($32<<1)|0);
  $34 = HEAP16[$33>>1]|0;
  $35 = $34&65535;
  $36 = (($$pre$phiZ2D) + ($35))|0;
  $37 = $36&65535;
  $38 = (($$0) + ($32<<1)|0);
  HEAP16[$38>>1] = $37;
 }
 $39 = (($$0) + ($indexCount<<1)|0);
 if (!($isTriStrip)) {
  $$1 = $39;
  $45 = $$1;
  $46 = $dst;
  $47 = (($45) - ($46))|0;
  $48 = $47 >> 1;
  STACKTOP = sp;return ($48|0);
 }
 $40 = $indexCount & 1;
 $41 = ($40|0)==(0);
 if ($41) {
  $$1 = $39;
  $45 = $$1;
  $46 = $dst;
  $47 = (($45) - ($46))|0;
  $48 = $47 >> 1;
  STACKTOP = sp;return ($48|0);
 }
 $$sum = (($indexCount) + -1)|0;
 $42 = (($$0) + ($$sum<<1)|0);
 $43 = HEAP16[$42>>1]|0;
 HEAP16[$39>>1] = $43;
 $$sum1 = (($indexCount) + 1)|0;
 $44 = (($$0) + ($$sum1<<1)|0);
 $$1 = $44;
 $45 = $$1;
 $46 = $dst;
 $47 = (($45) - ($46))|0;
 $48 = $47 >> 1;
 STACKTOP = sp;return ($48|0);
}
function __Z17TransformVerticesPhRK10Matrix4x4fRK16VertexBufferDatajjjb($dst,$m,$src,$firstVertex,$vertexCount,$channelsInVBO,$addWhiteColor) {
 $dst = $dst|0;
 $m = $m|0;
 $src = $src|0;
 $firstVertex = $firstVertex|0;
 $vertexCount = $vertexCount|0;
 $channelsInVBO = $channelsInVBO|0;
 $addWhiteColor = $addWhiteColor|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $copyData$0 = 0, $copyOffset$04 = 0, $copyOffset$1 = 0, $copyOffset$2 = 0, $copySize$06 = 0, $copySize$1 = 0, $copyStride$05 = 0, $copyStride$1 = 0, $copyStride$2 = 0, $exitcond = 0, $normalOffset$0 = 0, $tangentOffset$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($src) + 42|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $channelsInVBO & 2;
 $4 = ($3|0)==(0);
 if ($4) {
  $normalOffset$0 = -1;
 } else {
  $5 = (($src) + 5|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6&255;
  $normalOffset$0 = $7;
 }
 $8 = $channelsInVBO & 128;
 $9 = ($8|0)==(0);
 if ($9) {
  $tangentOffset$0 = -1;
 } else {
  $10 = (($src) + 29|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $tangentOffset$0 = $12;
 }
 $14 = 4;$18 = 2;$copyOffset$04 = -1;$copySize$06 = 0;$copyStride$05 = 0;
 while(1) {
  $13 = $14 & $channelsInVBO;
  $15 = ($13|0)==(0);
  if ($15) {
   $copyOffset$2 = $copyOffset$04;$copySize$1 = $copySize$06;$copyStride$2 = $copyStride$05;
  } else {
   $16 = ($copySize$06|0)==(0);
   if ($16) {
    $17 = (($src) + ($18<<2)|0);
    $19 = HEAP8[$17>>0]|0;
    $20 = $19&255;
    $21 = ((($src) + (($20*12)|0)|0) + 36|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ((($src) + ($18<<2)|0) + 1|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24&255;
    $26 = (($25) + ($22))|0;
    $27 = ((($src) + (($20*12)|0)|0) + 42|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28&255;
    $copyOffset$1 = $26;$copyStride$1 = $29;
   } else {
    $copyOffset$1 = $copyOffset$04;$copyStride$1 = $copyStride$05;
   }
   $30 = ((($src) + ($18<<2)|0) + 2|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ((($src) + ($18<<2)|0) + 3|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = (__Z20GetChannelFormatSizeh($31)|0);
   $35 = $33&255;
   $36 = Math_imul($35, $34)|0;
   $37 = (($36) + ($copySize$06))|0;
   $copyOffset$2 = $copyOffset$1;$copySize$1 = $37;$copyStride$2 = $copyStride$1;
  }
  $38 = (($18) + 1)|0;
  $39 = $14 << 1;
  $exitcond = ($38|0)==(7);
  if ($exitcond) {
   break;
  } else {
   $14 = $39;$18 = $38;$copyOffset$04 = $copyOffset$2;$copySize$06 = $copySize$1;$copyStride$05 = $copyStride$2;
  }
 }
 $40 = (($src) + 80|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = Math_imul($2, $firstVertex)|0;
 $43 = (($41) + ($42)|0);
 $44 = ($copySize$1|0)>(0);
 if (!($44)) {
  $copyData$0 = 0;
  __Z27TransformVerticesStridedREFPhRK10Matrix4x4fjPKhiiiS4_iib($dst,$m,$vertexCount,$43,$normalOffset$0,$tangentOffset$0,$2,$copyData$0,$copyStride$2,$copySize$1,$addWhiteColor);
  STACKTOP = sp;return ($vertexCount|0);
 }
 $45 = Math_imul($copyStride$2, $firstVertex)|0;
 $$sum = (($45) + ($copyOffset$2))|0;
 $46 = (($41) + ($$sum)|0);
 $copyData$0 = $46;
 __Z27TransformVerticesStridedREFPhRK10Matrix4x4fjPKhiiiS4_iib($dst,$m,$vertexCount,$43,$normalOffset$0,$tangentOffset$0,$2,$copyData$0,$copyStride$2,$copySize$1,$addWhiteColor);
 STACKTOP = sp;return ($vertexCount|0);
}
function __Z15TransformSpritePhPtjPK10Matrix4x4fPK12SpriteVertexjPKtj11ColorRGBA32j($vb,$ib,$channelMask,$m,$srcVertices,$vertexCount,$srcIndices,$indexCount,$color,$firstVertex) {
 $vb = $vb|0;
 $ib = $ib|0;
 $channelMask = $channelMask|0;
 $m = $m|0;
 $srcVertices = $srcVertices|0;
 $vertexCount = $vertexCount|0;
 $srcIndices = $srcIndices|0;
 $indexCount = $indexCount|0;
 $color = $color|0;
 $firstVertex = $firstVertex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $normal = 0, $tangent = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $normal = sp + 64|0;
 $tangent = sp;
 $0 = sp + 16|0;
 $1 = sp + 24|0;
 $2 = sp + 32|0;
 $3 = sp + 40|0;
 $4 = sp + 48|0;
 $5 = sp + 56|0;
 $6 = $channelMask & 2;
 $7 = ($6|0)!=(0);
 $8 = $channelMask & 128;
 $9 = ($8|0)!=(0);
 HEAPF32[$normal>>2] = Math_fround(0.0);
 $10 = (($normal) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($normal) + 8|0);
 HEAPF32[$11>>2] = Math_fround(-1.0);
 HEAPF32[$tangent>>2] = Math_fround(1.0);
 $12 = (($tangent) + 4|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($tangent) + 8|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($tangent) + 12|0);
 HEAPF32[$14>>2] = Math_fround(-1.0);
 HEAP32[$0>>2] = $srcVertices;
 $15 = (($0) + 4|0);
 HEAP32[$15>>2] = 20;
 $16 = $7 ? $normal : 0;
 HEAP32[$1>>2] = $16;
 $17 = (($1) + 4|0);
 HEAP32[$17>>2] = 0;
 HEAP32[$2>>2] = $color;
 $18 = (($2) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($srcVertices) + 12|0);
 HEAP32[$3>>2] = $19;
 $20 = (($3) + 4|0);
 HEAP32[$20>>2] = 20;
 HEAP32[$4>>2] = 0;
 $21 = (($4) + 4|0);
 HEAP32[$21>>2] = 0;
 $22 = $9 ? $tangent : 0;
 HEAP32[$5>>2] = $22;
 $23 = (($5) + 4|0);
 HEAP32[$23>>2] = 0;
 __Z43TransformVerticesStridedSeparatePointersREFPhRK10Matrix4x4fj14StrideIteratorI8Vector3fES5_S3_I11ColorRGBA32ES3_I8Vector2fES9_S3_I8Vector4fE($vb,$m,$vertexCount,$0,$1,$2,$3,$4,$5);
 $24 = ($firstVertex|0)==(0);
 if ($24) {
  $33 = $indexCount << 1;
  _memcpy(($ib|0),($srcIndices|0),($33|0))|0;
  STACKTOP = sp;return;
 }
 $25 = ($indexCount|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $26 = (($srcIndices) + ($i$01<<1)|0);
  $27 = HEAP16[$26>>1]|0;
  $28 = $27&65535;
  $29 = (($28) + ($firstVertex))|0;
  $30 = $29&65535;
  $31 = (($ib) + ($i$01<<1)|0);
  HEAP16[$31>>1] = $30;
  $32 = (($i$01) + 1)|0;
  $exitcond = ($32|0)==($indexCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZN24BuiltinShaderParamValuesC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 3744|0);
 $1 = (($this) + 5280|0);
 $3 = $0;
 while(1) {
  $2 = (($3) + 8|0);
  $4 = (($3) + 12|0);
  $5 = (($3) + 60|0);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
  HEAP32[$5>>2] = -1;
  HEAP32[$2>>2] = 0;
  HEAP32[$4>>2] = 0;
  HEAP32[$3>>2] = 0;
  $6 = (($3) + 4|0);
  HEAP32[$6>>2] = 5;
  $7 = (($3) + 36|0);
  HEAPF32[$7>>2] = Math_fround(1.0);
  $8 = (($3) + 32|0);
  HEAPF32[$8>>2] = Math_fround(1.0);
  $9 = (($3) + 40|0);
  HEAPF32[$9>>2] = Math_fround(0.0);
  $10 = (($3) + 44|0);
  HEAPF32[$10>>2] = Math_fround(1.0);
  $11 = (($3) + 48|0);
  HEAPF32[$11>>2] = Math_fround(1.0);
  $12 = (($3) + 52|0);
  HEAPF32[$12>>2] = Math_fround(0.0);
  $13 = (($3) + 56|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = (($3) + 64|0);
  $15 = ($14|0)==($1|0);
  if ($15) {
   break;
  } else {
   $3 = $14;
  }
 }
 $16 = (($this) + 128|0);
 _memset(($this|0),0,3744)|0;
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($this) + 144|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($this) + 160|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 176|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($this) + 192|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($this) + 208|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 224|0);
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($this) + 240|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN25BuiltinShaderParamIndices16CheckMatrixParamEPKciiii($this,$name,$index,$rowCount,$colCount,$cbKey) {
 $this = $this|0;
 $name = $name|0;
 $index = $index|0;
 $rowCount = $rowCount|0;
 $colCount = $colCount|0;
 $cbKey = $cbKey|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $paramIndex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $paramIndex = sp;
 $0 = (__Z27IsShaderInstanceMatrixParamPKcPi($name,$paramIndex)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$paramIndex>>2]|0;
 $2 = (($this) + (($1*12)|0)|0);
 HEAP32[$2>>2] = $index;
 $3 = $rowCount&65535;
 $4 = ((($this) + (($1*12)|0)|0) + 4|0);
 HEAP16[$4>>1] = $3;
 $5 = $colCount&65535;
 $6 = ((($this) + (($1*12)|0)|0) + 6|0);
 HEAP16[$6>>1] = $5;
 $7 = ((($this) + (($1*12)|0)|0) + 8|0);
 HEAP32[$7>>2] = $cbKey;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z32GetShaderInstanceMatrixParamNamei($paramIndex) {
 $paramIndex = $paramIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (597056 + ($paramIndex<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z25GetBuiltinMatrixParamNamei($paramIndex) {
 $paramIndex = $paramIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (596672 + ($paramIndex<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z25GetBuiltinVectorParamNamei($paramIndex) {
 $paramIndex = $paramIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (591960 + ($paramIndex<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z25GetBuiltinTexEnvParamNamei($paramIndex) {
 $paramIndex = $paramIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (591424 + ($paramIndex<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z33InitializeBuiltinShaderParamNamesv() {
 var $$idx$i = 0, $$idx$i5 = 0, $$idx$i9 = 0, $$idx$val$i = 0, $$idx$val$i10 = 0, $$idx$val$i2 = 0, $$idx$val$i6 = 0, $$idx1$i = 0, $$idx1$i11 = 0, $$idx1$i3 = 0, $$idx1$i7 = 0, $$idx1$val$i = 0, $$idx1$val$i12 = 0, $$idx1$val$i4 = 0, $$idx1$val$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[590680>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__Znwj(48)|0);
 dest=$2+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[590680>>2] = $2;
 __ZN12_GLOBAL__N_115ParamNameLookup15AddBuiltinNamesEPPKci($2,597056,7);
 $3 = HEAP32[590680>>2]|0;
 $$idx$val$i2 = HEAP32[$3>>2]|0;
 $$idx1$i3 = (($3) + 4|0);
 $$idx1$val$i4 = HEAP32[$$idx1$i3>>2]|0;
 __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEvT0_S7_T_($$idx$val$i2,$$idx1$val$i4);
 $4 = HEAP32[590680>>2]|0;
 $5 = (($4) + 12|0);
 __ZN12_GLOBAL__N_115ParamNameLookup15AddBuiltinNamesEPPKci($5,591960,170);
 $6 = HEAP32[590680>>2]|0;
 $7 = (($6) + 12|0);
 __ZN12_GLOBAL__N_115ParamNameLookup11AddSynonymsEPNS_14ParamNameIndexEi($7,590688,16);
 $8 = HEAP32[590680>>2]|0;
 $$idx$i9 = (($8) + 12|0);
 $$idx$val$i10 = HEAP32[$$idx$i9>>2]|0;
 $$idx1$i11 = (($8) + 16|0);
 $$idx1$val$i12 = HEAP32[$$idx1$i11>>2]|0;
 __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEvT0_S7_T_($$idx$val$i10,$$idx1$val$i12);
 $9 = HEAP32[590680>>2]|0;
 $10 = (($9) + 24|0);
 __ZN12_GLOBAL__N_115ParamNameLookup15AddBuiltinNamesEPPKci($10,596672,16);
 $11 = HEAP32[590680>>2]|0;
 $12 = (($11) + 24|0);
 __ZN12_GLOBAL__N_115ParamNameLookup11AddSynonymsEPNS_14ParamNameIndexEi($12,590816,5);
 $13 = HEAP32[590680>>2]|0;
 $$idx$i5 = (($13) + 24|0);
 $$idx$val$i6 = HEAP32[$$idx$i5>>2]|0;
 $$idx1$i7 = (($13) + 28|0);
 $$idx1$val$i8 = HEAP32[$$idx1$i7>>2]|0;
 __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEvT0_S7_T_($$idx$val$i6,$$idx1$val$i8);
 $14 = HEAP32[590680>>2]|0;
 $15 = (($14) + 36|0);
 __ZN12_GLOBAL__N_115ParamNameLookup15AddBuiltinNamesEPPKci($15,591424,24);
 $16 = HEAP32[590680>>2]|0;
 $$idx$i = (($16) + 36|0);
 $$idx$val$i = HEAP32[$$idx$i>>2]|0;
 $$idx1$i = (($16) + 40|0);
 $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
 __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEvT0_S7_T_($$idx$val$i,$$idx1$val$i);
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_115ParamNameLookup15AddBuiltinNamesEPPKci($this,$names,$count) {
 $this = $this|0;
 $names = $names|0;
 $count = $count|0;
 var $$0$i$i$i = 0, $$0$i5$i$i = 0, $$0$i810$i$i = 0, $$0$i89$i$i = 0, $$idx$val = 0, $$idx1$val = 0, $$idx1$val$pre = 0, $$pre1$i$i$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $exitcond = 0, $i$02 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $this$idx$val$i = 0;
 var $this$idx1$i = 0, $this$idx1$val$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $this$idx$val$i = HEAP32[$this>>2]|0;
 $this$idx1$i = (($this) + 4|0);
 $this$idx1$val$i = HEAP32[$this$idx1$i>>2]|0;
 $0 = $this$idx1$val$i;
 $1 = $this$idx$val$i;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 $4 = ($3>>>0)<($count>>>0);
 L1: do {
  if ($4) {
   $5 = (($count) - ($3))|0;
   $6 = (($this) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $7;
   $9 = (($8) - ($0))|0;
   $10 = $9 >> 3;
   $11 = ($10>>>0)<($5>>>0);
   if (!($11)) {
    $$0$i$i$i = $5;$13 = $this$idx1$val$i;
    while(1) {
     $12 = ($13|0)==(0|0);
     if ($12) {
      $19 = 0;
     } else {
      $14 = $13;
      $15 = $14;
      HEAP32[$15>>2] = 0;
      $16 = (($14) + 4)|0;
      $17 = $16;
      HEAP32[$17>>2] = 0;
      $$pre1$i$i$i = HEAP32[$this$idx1$i>>2]|0;
      $19 = $$pre1$i$i$i;
     }
     $18 = (($19) + 8|0);
     HEAP32[$this$idx1$i>>2] = $18;
     $20 = (($$0$i$i$i) + -1)|0;
     $21 = ($20|0)==(0);
     if ($21) {
      break L1;
     } else {
      $$0$i$i$i = $20;$13 = $18;
     }
    }
   }
   $22 = ($count>>>0)>(536870911);
   if ($22) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $23 = (($8) - ($1))|0;
   $24 = $23 >> 3;
   $25 = ($24>>>0)<(268435455);
   if ($25) {
    $26 = $23 >> 2;
    $27 = ($26>>>0)<($count>>>0);
    $28 = $27 ? $count : $26;
    $29 = ($28|0)==(0);
    if ($29) {
     $$0$i810$i$i = 0;$33 = 0;
    } else {
     $$0$i89$i$i = $28;
     label = 10;
    }
   } else {
    $$0$i89$i$i = 536870911;
    label = 10;
   }
   if ((label|0) == 10) {
    $30 = $$0$i89$i$i << 3;
    $31 = (__Znwj($30)|0);
    $$0$i810$i$i = $$0$i89$i$i;$33 = $31;
   }
   $32 = (($33) + ($3<<3)|0);
   $$0$i5$i$i = $5;$35 = $32;
   while(1) {
    $34 = ($35|0)==(0|0);
    if ($34) {
     $41 = 0;
    } else {
     $36 = $35;
     $37 = $36;
     HEAP32[$37>>2] = 0;
     $38 = (($36) + 4)|0;
     $39 = $38;
     HEAP32[$39>>2] = 0;
     $41 = $35;
    }
    $40 = (($41) + 8|0);
    $42 = (($$0$i5$i$i) + -1)|0;
    $43 = ($42|0)==(0);
    if ($43) {
     break;
    } else {
     $$0$i5$i$i = $42;$35 = $40;
    }
   }
   $44 = (($33) + ($$0$i810$i$i<<3)|0);
   $45 = HEAP32[$this>>2]|0;
   $46 = HEAP32[$this$idx1$i>>2]|0;
   $47 = $46;
   $48 = $45;
   $49 = (($47) - ($48))|0;
   $50 = $49 >> 3;
   $$sum$i$i = (($3) - ($50))|0;
   $51 = (($33) + ($$sum$i$i<<3)|0);
   _memcpy(($51|0),($45|0),($49|0))|0;
   HEAP32[$this>>2] = $51;
   HEAP32[$this$idx1$i>>2] = $40;
   HEAP32[$6>>2] = $44;
   $52 = ($45|0)==(0|0);
   if (!($52)) {
    __ZdlPv($45);
   }
  } else {
   $53 = ($3>>>0)>($count>>>0);
   if ($53) {
    $54 = (($this$idx$val$i) + ($count<<3)|0);
    $55 = ($this$idx1$val$i|0)==($54|0);
    if (!($55)) {
     $__new_last2$i$i$i = $54;
     $scevgep$i$i$i = (($this$idx1$val$i) + -8|0);
     $56 = (0 - ($__new_last2$i$i$i))|0;
     $uglygep$i$i$i = (($scevgep$i$i$i) + ($56)|0);
     $uglygep3$i$i$i = $uglygep$i$i$i;
     $57 = $uglygep3$i$i$i >>> 3;
     $58 = $57 ^ -1;
     $scevgep4$i$i$i = (($this$idx1$val$i) + ($58<<3)|0);
     HEAP32[$this$idx1$i>>2] = $scevgep4$i$i$i;
    }
   }
  }
 } while(0);
 $59 = ($count|0)>(0);
 if (!($59)) {
  STACKTOP = sp;return;
 }
 $$idx1$val$pre = HEAP32[$this>>2]|0;
 $$idx1$val = $$idx1$val$pre;$i$02 = 0;
 while(1) {
  $60 = (($names) + ($i$02<<2)|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($$idx1$val) + ($i$02<<3)|0);
  HEAP32[$62>>2] = $61;
  $$idx$val = HEAP32[$this>>2]|0;
  $63 = ((($$idx$val) + ($i$02<<3)|0) + 4|0);
  HEAP32[$63>>2] = $i$02;
  $64 = (($i$02) + 1)|0;
  $exitcond = ($64|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $$idx1$val = $$idx$val;$i$02 = $64;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_115ParamNameLookup11AddSynonymsEPNS_14ParamNameIndexEi($this,$params,$count) {
 $this = $this|0;
 $params = $params|0;
 $count = $count|0;
 var $$0$i5$i$i = 0, $$0$i6$i$i = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$i$i = 0, $$idx1$val = 0, $$idx1$val$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $this$idx2$val$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$idx$val = HEAP32[$this>>2]|0;
 $$idx1 = (($this) + 4|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $0 = $$idx1$val;
 $1 = $$idx$val;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 $4 = (($3) + ($count))|0;
 $$idx1$i$i = (($this) + 8|0);
 $$idx1$val$i$i = HEAP32[$$idx1$i$i>>2]|0;
 $5 = $$idx1$val$i$i;
 $6 = (($5) - ($1))|0;
 $7 = $6 >> 3;
 $8 = ($7>>>0)<($4>>>0);
 if ($8) {
  $9 = ($4|0)==(0);
  if ($9) {
   $13 = 0;
  } else {
   $10 = $4 << 3;
   $11 = (__Znwj($10)|0);
   $13 = $11;
  }
  $12 = (($13) + ($3<<3)|0);
  $14 = (($13) + ($4<<3)|0);
  _memcpy(($13|0),($$idx$val|0),($2|0))|0;
  HEAP32[$this>>2] = $13;
  HEAP32[$$idx1>>2] = $12;
  HEAP32[$$idx1$i$i>>2] = $14;
  $15 = ($$idx$val|0)==(0|0);
  if (!($15)) {
   __ZdlPv($$idx$val);
  }
 }
 $16 = ($count|0)>(0);
 if ($16) {
  $i$02 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $17 = (($params) + ($i$02<<3)|0);
  $18 = HEAP32[$$idx1>>2]|0;
  $19 = HEAP32[$$idx1$i$i>>2]|0;
  $20 = ($18|0)==($19|0);
  if ($20) {
   $this$idx2$val$i$i = HEAP32[$this>>2]|0;
   $34 = $18;
   $35 = $this$idx2$val$i$i;
   $36 = (($34) - ($35))|0;
   $37 = $36 >> 3;
   $38 = (($37) + 1)|0;
   $39 = ($38>>>0)>(536870911);
   if ($39) {
    label = 12;
    break;
   }
   $40 = ($37>>>0)<(268435455);
   if ($40) {
    $41 = $36 >> 2;
    $42 = ($41>>>0)<($38>>>0);
    $43 = $42 ? $38 : $41;
    $44 = ($43|0)==(0);
    if ($44) {
     $$0$i6$i$i = 0;$48 = 0;
    } else {
     $$0$i5$i$i = $43;
     label = 15;
    }
   } else {
    $$0$i5$i$i = 536870911;
    label = 15;
   }
   if ((label|0) == 15) {
    label = 0;
    $45 = $$0$i5$i$i << 3;
    $46 = (__Znwj($45)|0);
    $$0$i6$i$i = $$0$i5$i$i;$48 = $46;
   }
   $47 = (($48) + ($37<<3)|0);
   $49 = (($48) + ($$0$i6$i$i<<3)|0);
   $50 = ($47|0)==(0|0);
   if (!($50)) {
    $51 = $17;
    $52 = $51;
    $53 = HEAP32[$52>>2]|0;
    $54 = (($51) + 4)|0;
    $55 = $54;
    $56 = HEAP32[$55>>2]|0;
    $57 = $47;
    $58 = $57;
    HEAP32[$58>>2] = $53;
    $59 = (($57) + 4)|0;
    $60 = $59;
    HEAP32[$60>>2] = $56;
   }
   $61 = (($48) + ($38<<3)|0);
   _memcpy(($48|0),($this$idx2$val$i$i|0),($36|0))|0;
   HEAP32[$this>>2] = $48;
   HEAP32[$$idx1>>2] = $61;
   HEAP32[$$idx1$i$i>>2] = $49;
   $62 = ($this$idx2$val$i$i|0)==(0|0);
   if (!($62)) {
    __ZdlPv($this$idx2$val$i$i);
   }
  } else {
   $21 = ($18|0)==(0|0);
   if ($21) {
    $33 = 0;
   } else {
    $22 = $17;
    $23 = $22;
    $24 = HEAP32[$23>>2]|0;
    $25 = (($22) + 4)|0;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = $18;
    $29 = $28;
    HEAP32[$29>>2] = $24;
    $30 = (($28) + 4)|0;
    $31 = $30;
    HEAP32[$31>>2] = $27;
    $$pre$i = HEAP32[$$idx1>>2]|0;
    $33 = $$pre$i;
   }
   $32 = (($33) + 8|0);
   HEAP32[$$idx1>>2] = $32;
  }
  $63 = (($i$02) + 1)|0;
  $64 = ($63|0)<($count|0);
  if ($64) {
   $i$02 = $63;
  } else {
   label = 21;
   break;
  }
 }
 if ((label|0) == 12) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function __Z27IsShaderInstanceMatrixParamPKcPi($name,$paramIndex) {
 $name = $name|0;
 $paramIndex = $paramIndex|0;
 var $$0$i = 0, $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx2$i = 0, $$idx2$val$i = 0, $$lcssa$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[590680>>2]|0;
 $$idx$val$i = HEAP32[$0>>2]|0;
 $$idx2$i = (($0) + 4|0);
 $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
 $1 = ($$idx$val$i|0)==($$idx2$val$i|0);
 L1: do {
  if ($1) {
   $$lcssa$i$i = $$idx$val$i;
  } else {
   $4 = $$idx$val$i;
   while(1) {
    $$idx$val$i$i = HEAP32[$4>>2]|0;
    $5 = (_strcmp($$idx$val$i$i,$name)|0);
    $6 = ($5|0)==(0);
    $3 = (($4) + 8|0);
    if ($6) {
     $$lcssa$i$i = $4;
     break L1;
    }
    $2 = ($3|0)==($$idx2$val$i|0);
    if ($2) {
     $$0$i = 0;
     break;
    } else {
     $4 = $3;
    }
   }
   STACKTOP = sp;return ($$0$i|0);
  }
 } while(0);
 $7 = ($$lcssa$i$i|0)==($$idx2$val$i|0);
 if ($7) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $8 = ($paramIndex|0)==(0|0);
 if ($8) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $9 = (($$lcssa$i$i) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$paramIndex>>2] = $10;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __Z20IsVectorBuiltinParamPKcPi($name,$paramIndex) {
 $name = $name|0;
 $paramIndex = $paramIndex|0;
 var $$0$i = 0, $$idx$i = 0, $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx2$i = 0, $$idx2$val$i = 0, $$lcssa$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[590680>>2]|0;
 $$idx$i = (($0) + 12|0);
 $$idx$val$i = HEAP32[$$idx$i>>2]|0;
 $$idx2$i = (($0) + 16|0);
 $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
 $1 = ($$idx$val$i|0)==($$idx2$val$i|0);
 L1: do {
  if ($1) {
   $$lcssa$i$i = $$idx$val$i;
  } else {
   $4 = $$idx$val$i;
   while(1) {
    $$idx$val$i$i = HEAP32[$4>>2]|0;
    $5 = (_strcmp($$idx$val$i$i,$name)|0);
    $6 = ($5|0)==(0);
    $3 = (($4) + 8|0);
    if ($6) {
     $$lcssa$i$i = $4;
     break L1;
    }
    $2 = ($3|0)==($$idx2$val$i|0);
    if ($2) {
     $$0$i = 0;
     break;
    } else {
     $4 = $3;
    }
   }
   STACKTOP = sp;return ($$0$i|0);
  }
 } while(0);
 $7 = ($$lcssa$i$i|0)==($$idx2$val$i|0);
 if ($7) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $8 = ($paramIndex|0)==(0|0);
 if ($8) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $9 = (($$lcssa$i$i) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$paramIndex>>2] = $10;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __Z20IsMatrixBuiltinParamPKcPi($name,$paramIndex) {
 $name = $name|0;
 $paramIndex = $paramIndex|0;
 var $$0$i = 0, $$idx$i = 0, $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx2$i = 0, $$idx2$val$i = 0, $$lcssa$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[590680>>2]|0;
 $$idx$i = (($0) + 24|0);
 $$idx$val$i = HEAP32[$$idx$i>>2]|0;
 $$idx2$i = (($0) + 28|0);
 $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
 $1 = ($$idx$val$i|0)==($$idx2$val$i|0);
 L1: do {
  if ($1) {
   $$lcssa$i$i = $$idx$val$i;
  } else {
   $4 = $$idx$val$i;
   while(1) {
    $$idx$val$i$i = HEAP32[$4>>2]|0;
    $5 = (_strcmp($$idx$val$i$i,$name)|0);
    $6 = ($5|0)==(0);
    $3 = (($4) + 8|0);
    if ($6) {
     $$lcssa$i$i = $4;
     break L1;
    }
    $2 = ($3|0)==($$idx2$val$i|0);
    if ($2) {
     $$0$i = 0;
     break;
    } else {
     $4 = $3;
    }
   }
   STACKTOP = sp;return ($$0$i|0);
  }
 } while(0);
 $7 = ($$lcssa$i$i|0)==($$idx2$val$i|0);
 if ($7) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $8 = ($paramIndex|0)==(0|0);
 if ($8) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $9 = (($$lcssa$i$i) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$paramIndex>>2] = $10;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __Z20IsTexEnvBuiltinParamPKcPi($name,$paramIndex) {
 $name = $name|0;
 $paramIndex = $paramIndex|0;
 var $$0$i = 0, $$idx$i = 0, $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx2$i = 0, $$idx2$val$i = 0, $$lcssa$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[590680>>2]|0;
 $$idx$i = (($0) + 36|0);
 $$idx$val$i = HEAP32[$$idx$i>>2]|0;
 $$idx2$i = (($0) + 40|0);
 $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
 $1 = ($$idx$val$i|0)==($$idx2$val$i|0);
 L1: do {
  if ($1) {
   $$lcssa$i$i = $$idx$val$i;
  } else {
   $4 = $$idx$val$i;
   while(1) {
    $$idx$val$i$i = HEAP32[$4>>2]|0;
    $5 = (_strcmp($$idx$val$i$i,$name)|0);
    $6 = ($5|0)==(0);
    $3 = (($4) + 8|0);
    if ($6) {
     $$lcssa$i$i = $4;
     break L1;
    }
    $2 = ($3|0)==($$idx2$val$i|0);
    if ($2) {
     $$0$i = 0;
     break;
    } else {
     $4 = $3;
    }
   }
   STACKTOP = sp;return ($$0$i|0);
  }
 } while(0);
 $7 = ($$lcssa$i$i|0)==($$idx2$val$i|0);
 if ($7) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $8 = ($paramIndex|0)==(0|0);
 if ($8) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $9 = (($$lcssa$i$i) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$paramIndex>>2] = $10;
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEvT0_S7_T_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$idx$val = 0, $$0$idx1$val = 0, $$0$idx6$val = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$idx$val = 0, $$idx$val$i = 0, $$idx11$val = 0, $$idx2$val = 0, $$idx4$val = 0, $$idx8$val = 0, $$idx9$val = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$0$idx$val = 0, $__i$0$idx$val$i = 0;
 var $__i$018 = 0, $__i$02$i = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$idx$val = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$idx$val = 0, $__i$3$ph = 0, $__i$4 = 0, $__i$4$idx$val = 0, $__j$0 = 0, $__j$0$idx$val$i = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0;
 var $__j$4$ph = 0, $__j$5 = 0, $__k$0$i = 0, $__m$0$idx$val = 0, $__m$0$ph = 0, $__m$2 = 0, $__m$2$idx$val = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 51;
    break L1;
    break;
   }
   default: {
   }
   }
   $33 = ($3|0)<(248);
   if ($33) {
    label = 10;
    break L1;
   }
   $67 = ($3|0)>(7992);
   $68 = (($4|0) / 2)&-1;
   $69 = (($$0) + ($68<<3)|0);
   if ($67) {
    $70 = (($4|0) / 4)&-1;
    $71 = (($$0) + ($70<<3)|0);
    $$sum = (($70) + ($68))|0;
    $72 = (($$0) + ($$sum<<3)|0);
    $73 = (__ZNSt3__17__sort5IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($$0,$71,$69,$72,$1)|0);
    $__n_swaps$0 = $73;
   } else {
    $74 = (__ZNSt3__17__sort3IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_T_($$0,$69,$1)|0);
    $__n_swaps$0 = $74;
   }
   $$0$idx1$val = HEAP32[$$0>>2]|0;
   $$idx2$val = HEAP32[$69>>2]|0;
   $75 = (_strcmp($$0$idx1$val,$$idx2$val)|0);
   $76 = ($75|0)<(0);
   do {
    if ($76) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $77 = (($__j$0) + -8|0);
      $78 = ($$0|0)==($77|0);
      if ($78) {
       break;
      }
      $$idx9$val = HEAP32[$77>>2]|0;
      $135 = (_strcmp($$idx9$val,$$idx2$val)|0);
      $136 = ($135|0)<(0);
      if ($136) {
       label = 34;
       break;
      } else {
       $__j$0 = $77;
      }
     }
     if ((label|0) == 34) {
      label = 0;
      $137 = $$0;
      $138 = $137;
      $139 = HEAP32[$138>>2]|0;
      $140 = (($137) + 4)|0;
      $141 = $140;
      $142 = HEAP32[$141>>2]|0;
      $143 = $77;
      $144 = $143;
      $145 = HEAP32[$144>>2]|0;
      $146 = (($143) + 4)|0;
      $147 = $146;
      $148 = HEAP32[$147>>2]|0;
      $149 = $$0;
      $150 = $149;
      HEAP32[$150>>2] = $145;
      $151 = (($149) + 4)|0;
      $152 = $151;
      HEAP32[$152>>2] = $148;
      $153 = $77;
      $154 = $153;
      HEAP32[$154>>2] = $139;
      $155 = (($153) + 4)|0;
      $156 = $155;
      HEAP32[$156>>2] = $142;
      $157 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $77;$__n_swaps$3 = $157;
      break;
     }
     $79 = (($$0) + 8|0);
     $$idx4$val = HEAP32[$1>>2]|0;
     $80 = (_strcmp($$0$idx1$val,$$idx4$val)|0);
     $81 = ($80|0)<(0);
     if ($81) {
      $__i$1 = $79;
     } else {
      $82 = ($79|0)==($1|0);
      if ($82) {
       label = 51;
       break L1;
      } else {
       $__i$018 = $79;
      }
      while(1) {
       $__i$0$idx$val = HEAP32[$__i$018>>2]|0;
       $85 = (_strcmp($$0$idx1$val,$__i$0$idx$val)|0);
       $86 = ($85|0)<(0);
       $84 = (($__i$018) + 8|0);
       if ($86) {
        break;
       }
       $83 = ($84|0)==($1|0);
       if ($83) {
        label = 51;
        break L1;
       } else {
        $__i$018 = $84;
       }
      }
      $87 = $__i$018;
      $88 = $87;
      $89 = HEAP32[$88>>2]|0;
      $90 = (($87) + 4)|0;
      $91 = $90;
      $92 = HEAP32[$91>>2]|0;
      $93 = $1;
      $94 = $93;
      $95 = HEAP32[$94>>2]|0;
      $96 = (($93) + 4)|0;
      $97 = $96;
      $98 = HEAP32[$97>>2]|0;
      $99 = $__i$018;
      $100 = $99;
      HEAP32[$100>>2] = $95;
      $101 = (($99) + 4)|0;
      $102 = $101;
      HEAP32[$102>>2] = $98;
      $103 = $1;
      $104 = $103;
      HEAP32[$104>>2] = $89;
      $105 = (($103) + 4)|0;
      $106 = $105;
      HEAP32[$106>>2] = $92;
      $__i$1 = $84;
     }
     $107 = ($__i$1|0)==($1|0);
     if ($107) {
      label = 51;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $$0$idx6$val = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $__i$2$idx$val = HEAP32[$__i$2>>2]|0;
       $108 = (_strcmp($$0$idx6$val,$__i$2$idx$val)|0);
       $109 = ($108|0)<(0);
       $110 = (($__i$2) + 8|0);
       if ($109) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $110;
       }
      }
      while(1) {
       $111 = (($__j$2) + -8|0);
       $$idx8$val = HEAP32[$111>>2]|0;
       $112 = (_strcmp($$0$idx6$val,$$idx8$val)|0);
       $113 = ($112|0)<(0);
       if ($113) {
        $__j$2 = $111;
       } else {
        break;
       }
      }
      $114 = ($__i$2>>>0)<($111>>>0);
      if (!($114)) {
       $$0 = $__i$2;
       continue L3;
      }
      $115 = $__i$2;
      $116 = $115;
      $117 = HEAP32[$116>>2]|0;
      $118 = (($115) + 4)|0;
      $119 = $118;
      $120 = HEAP32[$119>>2]|0;
      $121 = $111;
      $122 = $121;
      $123 = HEAP32[$122>>2]|0;
      $124 = (($121) + 4)|0;
      $125 = $124;
      $126 = HEAP32[$125>>2]|0;
      $127 = $__i$2;
      $128 = $127;
      HEAP32[$128>>2] = $123;
      $129 = (($127) + 4)|0;
      $130 = $129;
      HEAP32[$130>>2] = $126;
      $131 = $111;
      $132 = $131;
      HEAP32[$132>>2] = $117;
      $133 = (($131) + 4)|0;
      $134 = $133;
      HEAP32[$134>>2] = $120;
      $__i$2$ph = $110;$__j$1$ph = $111;
     }
    }
   } while(0);
   $158 = (($$0) + 8|0);
   $159 = ($158>>>0)<($__j$3>>>0);
   L34: do {
    if ($159) {
     $__i$3$ph = $158;$__j$4$ph = $__j$3;$__m$0$ph = $69;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__m$0$idx$val = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $__i$3$idx$val = HEAP32[$__i$3>>2]|0;
       $160 = (_strcmp($__i$3$idx$val,$__m$0$idx$val)|0);
       $161 = ($160|0)<(0);
       $162 = (($__i$3) + 8|0);
       if ($161) {
        $__i$3 = $162;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $163 = (($__j$5) + -8|0);
       $$idx11$val = HEAP32[$163>>2]|0;
       $164 = (_strcmp($$idx11$val,$__m$0$idx$val)|0);
       $165 = ($164|0)<(0);
       if ($165) {
        break;
       } else {
        $__j$5 = $163;
       }
      }
      $166 = ($__i$3>>>0)>($163>>>0);
      if ($166) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $167 = $__i$3;
      $168 = $167;
      $169 = HEAP32[$168>>2]|0;
      $170 = (($167) + 4)|0;
      $171 = $170;
      $172 = HEAP32[$171>>2]|0;
      $173 = $163;
      $174 = $173;
      $175 = HEAP32[$174>>2]|0;
      $176 = (($173) + 4)|0;
      $177 = $176;
      $178 = HEAP32[$177>>2]|0;
      $179 = $__i$3;
      $180 = $179;
      HEAP32[$180>>2] = $175;
      $181 = (($179) + 4)|0;
      $182 = $181;
      HEAP32[$182>>2] = $178;
      $183 = $163;
      $184 = $183;
      HEAP32[$184>>2] = $169;
      $185 = (($183) + 4)|0;
      $186 = $185;
      HEAP32[$186>>2] = $172;
      $187 = (($__n_swaps$4$ph) + 1)|0;
      $188 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $188 ? $163 : $__m$0$ph;
      $__i$3$ph = $162;$__j$4$ph = $163;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $187;
     }
    } else {
     $__i$4 = $158;$__m$2 = $69;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $189 = ($__i$4|0)==($__m$2|0);
   if ($189) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $__m$2$idx$val = HEAP32[$__m$2>>2]|0;
    $__i$4$idx$val = HEAP32[$__i$4>>2]|0;
    $190 = (_strcmp($__m$2$idx$val,$__i$4$idx$val)|0);
    $191 = ($190|0)<(0);
    if ($191) {
     $192 = $__i$4;
     $193 = $192;
     $194 = HEAP32[$193>>2]|0;
     $195 = (($192) + 4)|0;
     $196 = $195;
     $197 = HEAP32[$196>>2]|0;
     $198 = $__m$2;
     $199 = $198;
     $200 = HEAP32[$199>>2]|0;
     $201 = (($198) + 4)|0;
     $202 = $201;
     $203 = HEAP32[$202>>2]|0;
     $204 = $__i$4;
     $205 = $204;
     HEAP32[$205>>2] = $200;
     $206 = (($204) + 4)|0;
     $207 = $206;
     HEAP32[$207>>2] = $203;
     $208 = $__m$2;
     $209 = $208;
     HEAP32[$209>>2] = $194;
     $210 = (($208) + 4)|0;
     $211 = $210;
     HEAP32[$211>>2] = $197;
     $212 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $212;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $213 = ($__n_swaps$6|0)==(0);
   if ($213) {
    $214 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEbT0_S7_T_($$0,$__i$4)|0);
    $215 = (($__i$4) + 8|0);
    $216 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEbT0_S7_T_($215,$$01$ph)|0);
    if ($216) {
     label = 46;
     break;
    }
    if ($214) {
     $$0 = $215;
     continue;
    }
   }
   $217 = $__i$4;
   $218 = (($217) - ($2))|0;
   $219 = (($0) - ($217))|0;
   $220 = ($218|0)<($219|0);
   if (!($220)) {
    label = 50;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEvT0_S7_T_($$0,$__i$4);
   $221 = (($__i$4) + 8|0);
   $$0 = $221;
  }
  if ((label|0) == 46) {
   label = 0;
   if ($214) {
    label = 51;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 50) {
   label = 0;
   $222 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEvT0_S7_T_($222,$$01$ph);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $$idx$val = HEAP32[$1>>2]|0;
  $$0$idx$val = HEAP32[$$0>>2]|0;
  $5 = (_strcmp($$idx$val,$$0$idx$val)|0);
  $6 = ($5|0)<(0);
  if (!($6)) {
   STACKTOP = sp;return;
  }
  $7 = $$0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = $1;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $$0;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $23 = $1;
  $24 = $23;
  HEAP32[$24>>2] = $9;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $12;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $27 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_T_($$0,$27,$1)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $28 = (($$0) + 8|0);
  $29 = (($$0) + 16|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$28,$29,$1)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $30 = (($$0) + 8|0);
  $31 = (($$0) + 16|0);
  $32 = (($$0) + 24|0);
  (__ZNSt3__17__sort5IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($$0,$30,$31,$32,$1)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  $34 = (($$0) + 16|0);
  $35 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_T_($$0,$35,$34)|0);
  $36 = (($$0) + 24|0);
  $37 = ($36|0)==($$01$ph|0);
  if ($37) {
   STACKTOP = sp;return;
  } else {
   $__i$02$i = $36;$__j$01$i = $34;
  }
  while(1) {
   $__i$0$idx$val$i = HEAP32[$__i$02$i>>2]|0;
   $__j$0$idx$val$i = HEAP32[$__j$01$i>>2]|0;
   $38 = (_strcmp($__i$0$idx$val$i,$__j$0$idx$val$i)|0);
   $39 = ($38|0)<(0);
   if ($39) {
    $40 = $__i$02$i;
    $41 = $40;
    $42 = HEAP32[$41>>2]|0;
    $43 = (($40) + 4)|0;
    $44 = $43;
    $45 = HEAP32[$44>>2]|0;
    $46 = $42;
    $__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     $47 = $__k$0$i;
     $48 = $47;
     $49 = HEAP32[$48>>2]|0;
     $50 = (($47) + 4)|0;
     $51 = $50;
     $52 = HEAP32[$51>>2]|0;
     $53 = $__j$1$i;
     $54 = $53;
     HEAP32[$54>>2] = $49;
     $55 = (($53) + 4)|0;
     $56 = $55;
     HEAP32[$56>>2] = $52;
     $57 = ($__k$0$i|0)==($$0|0);
     if ($57) {
      break;
     }
     $58 = (($__k$0$i) + -8|0);
     $$idx$val$i = HEAP32[$58>>2]|0;
     $59 = (_strcmp($46,$$idx$val$i)|0);
     $60 = ($59|0)<(0);
     if ($60) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $58;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $61 = $__k$0$i;
    $62 = $61;
    HEAP32[$62>>2] = $42;
    $63 = (($61) + 4)|0;
    $64 = $63;
    HEAP32[$64>>2] = $45;
   }
   $65 = (($__i$02$i) + 8|0);
   $66 = ($65|0)==($$01$ph|0);
   if ($66) {
    break;
   } else {
    $__j$01$i$phi = $__i$02$i;$__i$02$i = $65;$__j$01$i = $__j$01$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 51) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_T_($__x,$__y,$__z) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $__x$idx$val = 0, $__x$idx2$val = 0, $__y$idx$val = 0;
 var $__y$idx1$val = 0, $__z$idx$val = 0, $__z$idx4$val = 0, $inttoptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $__y$idx$val = HEAP32[$__y>>2]|0;
 $__x$idx$val = HEAP32[$__x>>2]|0;
 $0 = (_strcmp($__y$idx$val,$__x$idx$val)|0);
 $1 = ($0|0)<(0);
 $__z$idx$val = HEAP32[$__z>>2]|0;
 $2 = (_strcmp($__z$idx$val,$__y$idx$val)|0);
 $3 = ($2|0)<(0);
 if (!($1)) {
  if (!($3)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $4 = $__y;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $__z;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + 4)|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = $__y;
  $17 = $16;
  HEAP32[$17>>2] = $12;
  $18 = (($16) + 4)|0;
  $19 = $18;
  HEAP32[$19>>2] = $15;
  $20 = $__z;
  $21 = $20;
  HEAP32[$21>>2] = $6;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $9;
  $__y$idx1$val = HEAP32[$__y>>2]|0;
  $__x$idx2$val = HEAP32[$__x>>2]|0;
  $24 = (_strcmp($__y$idx1$val,$__x$idx2$val)|0);
  $25 = ($24|0)<(0);
  if (!($25)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $26 = $__x;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = $__y;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $__x;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  $42 = $__y;
  $43 = $42;
  HEAP32[$43>>2] = $28;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $31;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = $__x;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 if ($3) {
  $52 = $__z;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 4)|0;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = $__x;
  $59 = $58;
  HEAP32[$59>>2] = $54;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = $57;
  $62 = $__z;
  $63 = $62;
  HEAP32[$63>>2] = $48;
  $64 = (($62) + 4)|0;
  $65 = $64;
  HEAP32[$65>>2] = $51;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = $__y;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + 4)|0;
 $70 = $69;
 $71 = HEAP32[$70>>2]|0;
 $72 = $__x;
 $73 = $72;
 HEAP32[$73>>2] = $68;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP32[$75>>2] = $71;
 $76 = $__y;
 $77 = $76;
 HEAP32[$77>>2] = $48;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $51;
 $__z$idx4$val = HEAP32[$__z>>2]|0;
 $inttoptr = $48;
 $80 = (_strcmp($__z$idx4$val,$inttoptr)|0);
 $81 = ($80|0)<(0);
 if (!($81)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $82 = $__z;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $__y;
 $89 = $88;
 HEAP32[$89>>2] = $84;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $87;
 $92 = $__z;
 $93 = $92;
 HEAP32[$93>>2] = $48;
 $94 = (($92) + 4)|0;
 $95 = $94;
 HEAP32[$95>>2] = $51;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__x1$idx$val = 0, $__x2$idx$val = 0, $__x2$idx2$val = 0, $__x3$idx$val = 0, $__x3$idx1$val = 0, $__x4$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_T_($__x1,$__x2,$__x3)|0);
 $__x4$idx$val = HEAP32[$__x4>>2]|0;
 $__x3$idx$val = HEAP32[$__x3>>2]|0;
 $1 = (_strcmp($__x4$idx$val,$__x3$idx$val)|0);
 $2 = ($1|0)<(0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = $__x3;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $__x4;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $__x3;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = $__x4;
 $20 = $19;
 HEAP32[$20>>2] = $5;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $8;
 $23 = (($0) + 1)|0;
 $__x3$idx1$val = HEAP32[$__x3>>2]|0;
 $__x2$idx$val = HEAP32[$__x2>>2]|0;
 $24 = (_strcmp($__x3$idx1$val,$__x2$idx$val)|0);
 $25 = ($24|0)<(0);
 if (!($25)) {
  $__r$0 = $23;
  STACKTOP = sp;return ($__r$0|0);
 }
 $26 = $__x2;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $__x3;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $__x2;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = $__x3;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $31;
 $46 = (($0) + 2)|0;
 $__x2$idx2$val = HEAP32[$__x2>>2]|0;
 $__x1$idx$val = HEAP32[$__x1>>2]|0;
 $47 = (_strcmp($__x2$idx2$val,$__x1$idx$val)|0);
 $48 = ($47|0)<(0);
 if (!($48)) {
  $__r$0 = $46;
  STACKTOP = sp;return ($__r$0|0);
 }
 $49 = $__x1;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $__x2;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $__x1;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $__x2;
 $66 = $65;
 HEAP32[$66>>2] = $51;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $54;
 $69 = (($0) + 3)|0;
 $__r$0 = $69;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__x5) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $__r$0 = 0, $__x1$idx$val = 0, $__x2$idx$val = 0, $__x2$idx3$val = 0, $__x3$idx$val = 0, $__x3$idx2$val = 0, $__x4$idx$val = 0;
 var $__x4$idx1$val = 0, $__x5$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4)|0);
 $__x5$idx$val = HEAP32[$__x5>>2]|0;
 $__x4$idx$val = HEAP32[$__x4>>2]|0;
 $1 = (_strcmp($__x5$idx$val,$__x4$idx$val)|0);
 $2 = ($1|0)<(0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = $__x4;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $__x5;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $__x4;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = $__x5;
 $20 = $19;
 HEAP32[$20>>2] = $5;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $8;
 $23 = (($0) + 1)|0;
 $__x4$idx1$val = HEAP32[$__x4>>2]|0;
 $__x3$idx$val = HEAP32[$__x3>>2]|0;
 $24 = (_strcmp($__x4$idx1$val,$__x3$idx$val)|0);
 $25 = ($24|0)<(0);
 if (!($25)) {
  $__r$0 = $23;
  STACKTOP = sp;return ($__r$0|0);
 }
 $26 = $__x3;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $__x4;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $__x3;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = $__x4;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $31;
 $46 = (($0) + 2)|0;
 $__x3$idx2$val = HEAP32[$__x3>>2]|0;
 $__x2$idx$val = HEAP32[$__x2>>2]|0;
 $47 = (_strcmp($__x3$idx2$val,$__x2$idx$val)|0);
 $48 = ($47|0)<(0);
 if (!($48)) {
  $__r$0 = $46;
  STACKTOP = sp;return ($__r$0|0);
 }
 $49 = $__x2;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $__x3;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $__x2;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $__x3;
 $66 = $65;
 HEAP32[$66>>2] = $51;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $54;
 $69 = (($0) + 3)|0;
 $__x2$idx3$val = HEAP32[$__x2>>2]|0;
 $__x1$idx$val = HEAP32[$__x1>>2]|0;
 $70 = (_strcmp($__x2$idx3$val,$__x1$idx$val)|0);
 $71 = ($70|0)<(0);
 if (!($71)) {
  $__r$0 = $69;
  STACKTOP = sp;return ($__r$0|0);
 }
 $72 = $__x1;
 $73 = $72;
 $74 = HEAP32[$73>>2]|0;
 $75 = (($72) + 4)|0;
 $76 = $75;
 $77 = HEAP32[$76>>2]|0;
 $78 = $__x2;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__x1;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__x2;
 $89 = $88;
 HEAP32[$89>>2] = $74;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $77;
 $92 = (($0) + 4)|0;
 $__r$0 = $92;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEbT0_S7_T_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0 = 0, $$idx$val = 0, $$idx1$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $__count$04 = 0, $__count$1 = 0, $__first$idx$val = 0, $__i$0$idx$val = 0;
 var $__i$05 = 0, $__j$0$idx$val = 0, $__j$03 = 0, $__j$03$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 2:  {
  $4 = (($__last) + -8|0);
  $$idx$val = HEAP32[$4>>2]|0;
  $__first$idx$val = HEAP32[$__first>>2]|0;
  $5 = (_strcmp($$idx$val,$__first$idx$val)|0);
  $6 = ($5|0)<(0);
  if (!($6)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $7 = $__first;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = $4;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $__first;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $23 = $4;
  $24 = $23;
  HEAP32[$24>>2] = $9;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $12;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $29 = (($__first) + 8|0);
  $30 = (($__first) + 16|0);
  $31 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$29,$30,$31)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $27 = (($__first) + 8|0);
  $28 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_T_($__first,$27,$28)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $32 = (($__first) + 8|0);
  $33 = (($__first) + 16|0);
  $34 = (($__first) + 24|0);
  $35 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($__first,$32,$33,$34,$35)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $36 = (($__first) + 16|0);
  $37 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN12_GLOBAL__N_114ParamNameIndexES3_EEPS3_EEjT0_S7_S7_T_($__first,$37,$36)|0);
  $38 = (($__first) + 24|0);
  $39 = ($38|0)==($__last|0);
  if ($39) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$04 = 0;$__i$05 = $38;$__j$03 = $36;
  }
  while(1) {
   $__i$0$idx$val = HEAP32[$__i$05>>2]|0;
   $__j$0$idx$val = HEAP32[$__j$03>>2]|0;
   $40 = (_strcmp($__i$0$idx$val,$__j$0$idx$val)|0);
   $41 = ($40|0)<(0);
   if ($41) {
    $42 = $__i$05;
    $43 = $42;
    $44 = HEAP32[$43>>2]|0;
    $45 = (($42) + 4)|0;
    $46 = $45;
    $47 = HEAP32[$46>>2]|0;
    $48 = $44;
    $__j$1 = $__i$05;$__k$0 = $__j$03;
    while(1) {
     $49 = $__k$0;
     $50 = $49;
     $51 = HEAP32[$50>>2]|0;
     $52 = (($49) + 4)|0;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = $__j$1;
     $56 = $55;
     HEAP32[$56>>2] = $51;
     $57 = (($55) + 4)|0;
     $58 = $57;
     HEAP32[$58>>2] = $54;
     $59 = ($__k$0|0)==($__first|0);
     if ($59) {
      break;
     }
     $60 = (($__k$0) + -8|0);
     $$idx1$val = HEAP32[$60>>2]|0;
     $61 = (_strcmp($48,$$idx1$val)|0);
     $62 = ($61|0)<(0);
     if ($62) {
      $__j$1$phi = $__k$0;$__k$0 = $60;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $63 = $__k$0;
    $64 = $63;
    HEAP32[$64>>2] = $44;
    $65 = (($63) + 4)|0;
    $66 = $65;
    HEAP32[$66>>2] = $47;
    $67 = (($__count$04) + 1)|0;
    $68 = ($67|0)==(8);
    if ($68) {
     break;
    } else {
     $__count$1 = $67;
    }
   } else {
    $__count$1 = $__count$04;
   }
   $71 = (($__i$05) + 8|0);
   $72 = ($71|0)==($__last|0);
   if ($72) {
    $$0 = 1;
    label = 15;
    break;
   } else {
    $__j$03$phi = $__i$05;$__count$04 = $__count$1;$__i$05 = $71;$__j$03 = $__j$03$phi;
   }
  }
  if ((label|0) == 15) {
   STACKTOP = sp;return ($$0|0);
  }
  $69 = (($__i$05) + 8|0);
  $70 = ($69|0)==($__last|0);
  $$0 = $70;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __Z24GetShaderChannelFromNameRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($name) {
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var $i$01$us = 0, $nameUpper = 0, $not$ = 0, $not$$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $nameUpper = sp;
 __Z7ToUpperINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_($nameUpper,$name);
 $0 = HEAP8[$nameUpper>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 $3 = $0&255;
 $4 = $3 >>> 1;
 $5 = (($nameUpper) + 1|0);
 $6 = (($nameUpper) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($nameUpper) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 L1: do {
  if ($2) {
   $i$01$us = 0;
   while(1) {
    $10 = (597280 + ($i$01$us<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (_strlen(($11|0))|0);
    $13 = ($12|0)==(-1);
    if ($13) {
     label = 7;
     break L1;
    }
    $14 = ($4>>>0)>($12>>>0);
    $15 = $14 ? $12 : $4;
    $16 = (_memcmp($5,$11,$15)|0);
    $17 = ($16|0)==(0);
    if ($17) {
     $18 = $14 ^ 1;
     $not$$us = ($4>>>0)>=($12>>>0);
     $19 = $not$$us & $18;
     if ($19) {
      $$0 = $i$01$us;
      break L1;
     }
    }
    $20 = (($i$01$us) + 1)|0;
    $21 = ($20|0)<(8);
    if ($21) {
     $i$01$us = $20;
    } else {
     $$0 = -1;
     break;
    }
   }
  } else {
   $i$01 = 0;
   while(1) {
    $22 = (597280 + ($i$01<<2)|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (_strlen(($23|0))|0);
    $25 = ($24|0)==(-1);
    if ($25) {
     label = 7;
     break L1;
    }
    $28 = ($9>>>0)>($24>>>0);
    $29 = $28 ? $24 : $9;
    $30 = (_memcmp($7,$23,$29)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     $34 = $28 ^ 1;
     $not$ = ($9>>>0)>=($24>>>0);
     $35 = $not$ & $34;
     if ($35) {
      $$0 = $i$01;
      break L1;
     }
    }
    $36 = (($i$01) + 1)|0;
    $37 = ($36|0)<(8);
    if ($37) {
     $i$01 = $36;
    } else {
     $$0 = -1;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  __THREW__ = 0;
  invoke_vi(3304,0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   ___cxa_call_unexpected(($32|0));
   // unreachable;
  } else {
   // unreachable;
  }
 }
 if ($2) {
  STACKTOP = sp;return ($$0|0);
 }
 __ZdlPv($7);
 STACKTOP = sp;return ($$0|0);
}
function __Z7ToUpperINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_($agg$result,$input) {
 $agg$result = $agg$result|0;
 $input = $input|0;
 var $$0$i = 0, $$ph = 0, $$pre = 0, $$pre$phi6Z2D = 0, $$pre$phi8Z2D = 0, $$pre$phiZ2D = 0, $$pre2$pre$phiZZ2D = 0, $$pre5 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $v$off$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$input>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$input+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$input+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$input+8>>2]|0;
  $$pre = HEAP8[$agg$result>>0]|0;
  $$pre$phiZ2D = $agg$result;$21 = $$pre;
 } else {
  $3 = (($input) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($input) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6>>>0)>(4294967279);
  if ($7) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $8 = ($6>>>0)<(11);
  if ($8) {
   $9 = $6 << 1;
   $10 = $9&255;
   HEAP8[$agg$result>>0] = $10;
   $11 = (($agg$result) + 1|0);
   $$pre2$pre$phiZZ2D = $agg$result;$45 = $10;$__p$0$i$i$i = $11;
  } else {
   $12 = (($6) + 16)|0;
   $13 = $12 & -16;
   $14 = (__Znwj($13)|0);
   $15 = (($agg$result) + 8|0);
   HEAP32[$15>>2] = $14;
   $16 = $13 | 1;
   HEAP32[$agg$result>>2] = $16;
   $17 = (($agg$result) + 4|0);
   HEAP32[$17>>2] = $6;
   $18 = $16&255;
   $$pre2$pre$phiZZ2D = $agg$result;$45 = $18;$__p$0$i$i$i = $14;
  }
  _memcpy(($__p$0$i$i$i|0),($4|0),($6|0))|0;
  $19 = (($__p$0$i$i$i) + ($6)|0);
  HEAP8[$19>>0] = 0;
  $$pre$phiZ2D = $$pre2$pre$phiZZ2D;$21 = $45;
 }
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($22) {
  $25 = (($agg$result) + 1|0);
  $$pre7 = (($agg$result) + 8|0);
  $$ph = $25;$$pre$phi6Z2D = $25;$$pre$phi8Z2D = $$pre7;
 } else {
  $23 = (($agg$result) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $$pre5 = (($agg$result) + 1|0);
  $$ph = $24;$$pre$phi6Z2D = $$pre5;$$pre$phi8Z2D = $23;
 }
 $26 = (($agg$result) + 4|0);
 $38 = $$ph;
 while(1) {
  $27 = HEAP8[$$pre$phiZ2D>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $32 = $27&255;
   $33 = $32 >>> 1;
   $35 = $$pre$phi6Z2D;$36 = $33;
  } else {
   $30 = HEAP32[$$pre$phi8Z2D>>2]|0;
   $31 = HEAP32[$26>>2]|0;
   $35 = $30;$36 = $31;
  }
  $34 = (($35) + ($36)|0);
  $37 = ($38|0)==($34|0);
  if ($37) {
   break;
  }
  $39 = HEAP8[$38>>0]|0;
  $v$off$i = (($39) + -97)<<24>>24;
  $40 = ($v$off$i&255)<(26);
  if ($40) {
   $41 = $39&255;
   $42 = $41 & 223;
   $43 = $42&255;
   $$0$i = $43;
  } else {
   $$0$i = $39;
  }
  HEAP8[$38>>0] = $$0$i;
  $44 = (($38) + 1|0);
  $38 = $44;
 }
 STACKTOP = sp;return;
}
function __ZN14ChannelAssignsC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $scevgep = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $scevgep = (($this) + 8|0);
 dest=$scevgep+0|0; stop=dest+28|0; do { HEAP8[dest>>0]=255|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($this,$source,$target) {
 $this = $this|0;
 $source = $source|0;
 $target = $target|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($target|0)==(-1);
 if (!($0)) {
  $1 = $source&255;
  $2 = ((($this) + ($target)|0) + 8|0);
  HEAP8[$2>>0] = $1;
  $3 = 1 << $target;
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 | $3;
  HEAP32[$this>>2] = $5;
 }
 $6 = 1 << $source;
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 | $6;
 HEAP32[$7>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN14ChannelAssigns6UnbindE15VertexComponent($this,$target) {
 $this = $this|0;
 $target = $target|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 1 << $target;
 $1 = $0 ^ -1;
 $2 = HEAP32[$this>>2]|0;
 $3 = $2 & $1;
 HEAP32[$this>>2] = $3;
 $4 = ((($this) + ($target)|0) + 8|0);
 HEAP8[$4>>0] = -1;
 STACKTOP = sp;return;
}
function __ZN13DrawImmediateC2ER9GfxDevice($this,$device) {
 $this = $this|0;
 $device = $device|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $device;
 $0 = (($this) + 4|0);
 __ZN14ChannelAssignsC2Ev($0);
 $1 = (($this) + 40|0);
 __ZN14ChannelAssignsC2Ev($1);
 $2 = (($this) + 76|0);
 $3 = (($this) + 116|0);
 dest=$2+0|0; stop=dest+104|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 120|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 124|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 128|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($this) + 180|0);
 dest=$7+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $8 = (($this) + 204|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 208|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 212|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($this) + 216|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($this) + 268|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 272|0);
 HEAP32[$13>>2] = 0;
 $14 = HEAP8[((640792 + 262|0))>>0]|0;
 $15 = (($this) + 276|0);
 HEAP8[$15>>0] = $14;
 __ZN13DrawImmediate6CreateEv($this);
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate6CreateEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $allChannelsInfo = 0, $exitcond = 0, $offset$08 = 0, $offset$1 = 0, $or$cond = 0, $s$0$off = 0, $s$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 36|0;
 $allChannelsInfo = sp;
 $0 = sp + 32|0;
 $1 = (($this) + 40|0);
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,0,0);
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,1,2);
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,2,1);
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,3,4);
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,4,5);
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,5,6);
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,6,7);
 ;HEAP32[$allChannelsInfo+0>>2]=0|0;HEAP32[$allChannelsInfo+4>>2]=0|0;HEAP32[$allChannelsInfo+8>>2]=0|0;HEAP32[$allChannelsInfo+12>>2]=0|0;HEAP32[$allChannelsInfo+16>>2]=0|0;HEAP32[$allChannelsInfo+20>>2]=0|0;HEAP32[$allChannelsInfo+24>>2]=0|0;HEAP32[$allChannelsInfo+28>>2]=0|0;
 $offset$08 = 0;$s$07 = 0;
 while(1) {
  $2 = ($s$07>>>0)<(3);
  $s$0$off = (($s$07) + -3)|0;
  $3 = ($s$0$off>>>0)<(4);
  $or$cond = $2 | $3;
  if ($or$cond) {
   $4 = ($s$07|0)==(2);
   $5 = $offset$08&255;
   $6 = ((($allChannelsInfo) + ($s$07<<2)|0) + 1|0);
   HEAP8[$6>>0] = $5;
   $7 = ((($allChannelsInfo) + ($s$07<<2)|0) + 2|0);
   HEAP8[$7>>0] = 0;
   $8 = $4 ? 4 : 3;
   $9 = ((($allChannelsInfo) + ($s$07<<2)|0) + 3|0);
   HEAP8[$9>>0] = $8;
   $10 = $8&255;
   $11 = $10 << 2;
   $12 = (($11) + ($offset$08))|0;
   $offset$1 = $12;
  } else {
   $offset$1 = $offset$08;
  }
  $13 = (($s$07) + 1)|0;
  $exitcond = ($13|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $offset$08 = $offset$1;$s$07 = $13;
  }
 }
 $14 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $14;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $15 = (__Znwj10MemLabelIdbiPKci(60,$$byval_copy1,0,16,597408,170)|0);
 __THREW__ = 0;
 invoke_viiii(367,($15|0),1,($allChannelsInfo|0),1);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  $18 = (($this) + 76|0);
  HEAP32[$18>>2] = $15;
  STACKTOP = sp;return;
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($15|0),($$byval_copy1|0),0,16,(597408|0),170);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN13DrawImmediate5BeginE16GfxPrimitiveTypePK14ChannelAssigns($this,$type,$channelAssigns) {
 $this = $this|0;
 $type = $type|0;
 $channelAssigns = $channelAssigns|0;
 var $$pr = 0, $$sroa$0$i = 0, $$sroa$5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$sroa$0$i = sp + 48|0;
 $$sroa$5$i = sp;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 276|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   $6 = (($this) + 80|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $15 = $this;
    label = 7;
   } else {
    $9 = HEAP32[$7>>2]|0;
    $10 = (($9) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (FUNCTION_TABLE_ii[$11 & 4095]($7)|0);
    if (!($12)) {
     break;
    }
    $$pr = HEAP32[$6>>2]|0;
    $13 = ($$pr|0)==(0|0);
    if ($13) {
     $15 = $this;
     label = 7;
    } else {
     $21 = $this;$25 = $$pr;
    }
   }
   if ((label|0) == 7) {
    $14 = HEAP32[$15>>2]|0;
    $16 = HEAP32[$14>>2]|0;
    $17 = (($16) + 276|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (FUNCTION_TABLE_ii[$18 & 4095]($14)|0);
    HEAP32[$6>>2] = $19;
    $21 = $15;$25 = $19;
   }
   $20 = HEAP32[$21>>2]|0;
   $22 = HEAP32[$20>>2]|0;
   $23 = (($22) + 280|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_viiiiiii[$24 & 127]($20,$25,1,1,67584,0,0);
  }
 } while(0);
 $26 = (($this) + 4|0);
 $27 = ($channelAssigns|0)!=(0|0);
 $28 = (($this) + 40|0);
 $29 = $27 ? $channelAssigns : $28;
 dest=$26+0|0; src=$29+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $30 = (($this) + 268|0);
 HEAP32[$30>>2] = $type;
 $31 = HEAP8[$3>>0]|0;
 $32 = ($31<<24>>24)==(0);
 $33 = HEAP32[$this>>2]|0;
 if ($32) {
  $41 = HEAP32[$33>>2]|0;
  $42 = (($41) + 284|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($this) + 80|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (FUNCTION_TABLE_iiiii[$43 & 511]($33,$45,0,0)|0);
  HEAP32[$0>>2] = $46;
 } else {
  $34 = (__ZN9GfxDevice13GetDynamicVBOEv($33)|0);
  HEAP32[$$sroa$0$i>>2] = 0;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$30>>2]|0;
  $39 = (FUNCTION_TABLE_iiiiiiii[$37 & 127]($34,88,768,0,$38,$$sroa$0$i,0)|0);
  if ($39) {
   $40 = HEAP32[$$sroa$0$i>>2]|0;
   HEAP32[$0>>2] = $40;
  }
 }
 ;HEAP32[$$sroa$0$i+0>>2]=0|0;HEAP32[$$sroa$0$i+4>>2]=0|0;HEAP32[$$sroa$0$i+8>>2]=0|0;HEAP32[$$sroa$0$i+12>>2]=0|0;HEAP32[$$sroa$0$i+16>>2]=0|0;HEAP32[$$sroa$0$i+20>>2]=0|0;
 dest=$$sroa$5$i+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $47 = (($this) + 92|0);
 ;HEAP32[$47+0>>2]=HEAP32[$$sroa$0$i+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$$sroa$0$i+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$$sroa$0$i+8>>2]|0;HEAP32[$47+12>>2]=HEAP32[$$sroa$0$i+12>>2]|0;HEAP32[$47+16>>2]=HEAP32[$$sroa$0$i+16>>2]|0;HEAP32[$47+20>>2]=HEAP32[$$sroa$0$i+20>>2]|0;
 $48 = (($this) + 116|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($this) + 120|0);
 HEAPF32[$49>>2] = Math_fround(1.0);
 $50 = (($this) + 124|0);
 HEAPF32[$50>>2] = Math_fround(1.0);
 $51 = (($this) + 128|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 $52 = (($this) + 132|0);
 dest=$52+0|0; src=$$sroa$5$i+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate10InvalidateEv($this) {
 $this = $this|0;
 var $$sroa$0 = 0, $$sroa$5 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$sroa$0 = sp + 48|0;
 $$sroa$5 = sp;
 ;HEAP32[$$sroa$0+0>>2]=0|0;HEAP32[$$sroa$0+4>>2]=0|0;HEAP32[$$sroa$0+8>>2]=0|0;HEAP32[$$sroa$0+12>>2]=0|0;HEAP32[$$sroa$0+16>>2]=0|0;HEAP32[$$sroa$0+20>>2]=0|0;
 dest=$$sroa$5+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($this) + 92|0);
 ;HEAP32[$0+0>>2]=HEAP32[$$sroa$0+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$$sroa$0+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$$sroa$0+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$$sroa$0+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$$sroa$0+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$$sroa$0+20>>2]|0;
 $1 = (($this) + 116|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 120|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 124|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 128|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 132|0);
 dest=$5+0|0; src=$$sroa$5+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate3EndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN13DrawImmediate11FlushBufferEv($this);
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate11FlushBufferEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $drawRange = 0, $indexBuffer$0 = 0, $indexCount$0 = 0, $or$cond = 0, $streamSource = 0, $topology$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $streamSource = sp + 24|0;
 $drawRange = sp;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 272|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 268|0);
 $6 = HEAP32[$5>>2]|0;
 switch ($6|0) {
 case 4:  {
  $11 = (($4) + -1)|0;
  $$0$i = $11;
  break;
 }
 case 0:  {
  $7 = (($4|0) / 3)&-1;
  $$0$i = $7;
  break;
 }
 case 5:  {
  $$0$i = $4;
  break;
 }
 case 1:  {
  $8 = (($4) + -2)|0;
  $$0$i = $8;
  break;
 }
 case 2:  {
  $9 = (($4|0) / 4)&-1;
  $$0$i = $9;
  break;
 }
 case 3:  {
  $10 = (($4|0) / 2)&-1;
  $$0$i = $10;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $12 = (($this) + 76|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 4|0);
 $15 = (($this) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($13,$16,0)|0);
 $18 = (($this) + 276|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 $21 = HEAP32[$this>>2]|0;
 if ($20) {
  $31 = HEAP32[$21>>2]|0;
  $32 = (($31) + 288|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($this) + 80|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$3>>2]|0;
  $37 = ($36*88)|0;
  FUNCTION_TABLE_viii[$33 & 4095]($21,$35,$37);
  $38 = ($$0$i|0)>(0);
  if ($38) {
   $39 = HEAP32[$5>>2]|0;
   $40 = ($39|0)==(2);
   $41 = HEAP8[((640792 + 224|0))>>0]|0;
   $42 = ($41<<24>>24)==(0);
   $or$cond = $40 & $42;
   if ($or$cond) {
    $43 = (($this) + 84|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     __ZN13DrawImmediate15BuildQuadBufferEv($this);
     $$pre = HEAP32[$43>>2]|0;
     $58 = $$pre;
    } else {
     $58 = $44;
    }
    $46 = HEAP32[$3>>2]|0;
    $47 = $46 >>> 2;
    $48 = ($47*6)|0;
    $53 = $46;$indexBuffer$0 = $58;$indexCount$0 = $48;$topology$0 = 0;
   } else {
    $$pre2 = HEAP32[$3>>2]|0;
    $53 = $$pre2;$indexBuffer$0 = 0;$indexCount$0 = 0;$topology$0 = $39;
   }
   $49 = HEAP32[$34>>2]|0;
   HEAP32[$streamSource>>2] = $49;
   $50 = (($streamSource) + 4|0);
   HEAP32[$50>>2] = 88;
   ;HEAP32[$drawRange+0>>2]=0|0;HEAP32[$drawRange+4>>2]=0|0;HEAP32[$drawRange+8>>2]=0|0;HEAP32[$drawRange+12>>2]=0|0;HEAP32[$drawRange+16>>2]=0|0;
   HEAP32[$drawRange>>2] = $topology$0;
   $51 = (($drawRange) + 8|0);
   HEAP32[$51>>2] = $indexCount$0;
   $52 = (($drawRange) + 20|0);
   HEAP32[$52>>2] = $53;
   $54 = HEAP32[$this>>2]|0;
   $55 = HEAP32[$54>>2]|0;
   $56 = (($55) + 300|0);
   $57 = HEAP32[$56>>2]|0;
   FUNCTION_TABLE_viiiiiiii[$57 & 63]($54,$indexBuffer$0,$streamSource,1,$drawRange,1,$17,$14);
  }
 } else {
  $22 = (__ZN9GfxDevice13GetDynamicVBOEv($21)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_viii[$25 & 4095]($22,$26,0);
  $27 = ($$0$i|0)>(0);
  if ($27) {
   $28 = HEAP32[$22>>2]|0;
   $29 = (($28) + 16|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_viii[$30 & 4095]($22,$14,$17);
  }
 }
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate6VertexEfff($this,$x,$y,$z) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dest$i = 0, $or$cond = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dest$i = sp;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 92|0);
 $4 = (($this) + 92|0);
 HEAPF32[$4>>2] = $x;
 $5 = (($this) + 96|0);
 HEAPF32[$5>>2] = $y;
 $6 = (($this) + 100|0);
 HEAPF32[$6>>2] = $z;
 $7 = (($1) + 88|0);
 HEAP32[$0>>2] = $7;
 dest=$1+0|0; src=$3+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $8 = (($this) + 272|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$8>>2] = $10;
 $11 = ($10>>>0)>(766);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 268|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(1);
 $15 = ($10|0)==(767);
 $or$cond = $14 & $15;
 if ($or$cond) {
  $16 = (($this) + 180|0);
  dest=$16+0|0; src=$3+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $17 = ($10|0)==(768);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 __ZN13DrawImmediate11FlushBufferEv($this);
 $18 = (($this) + 276|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 $21 = HEAP32[$this>>2]|0;
 do {
  if ($20) {
   $29 = HEAP32[$21>>2]|0;
   $30 = (($29) + 284|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($this) + 80|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (FUNCTION_TABLE_iiiii[$31 & 511]($21,$33,0,0)|0);
   HEAP32[$0>>2] = $34;
   $36 = $34;
  } else {
   $22 = (__ZN9GfxDevice13GetDynamicVBOEv($21)|0);
   HEAP32[$dest$i>>2] = 0;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[$12>>2]|0;
   $27 = (FUNCTION_TABLE_iiiiiiii[$25 & 127]($22,88,768,0,$26,$dest$i,0)|0);
   if ($27) {
    $28 = HEAP32[$dest$i>>2]|0;
    HEAP32[$0>>2] = $28;
    $36 = $28;
    break;
   } else {
    $$pre$i = HEAP32[$0>>2]|0;
    $36 = $$pre$i;
    break;
   }
  }
 } while(0);
 $35 = ($36|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$12>>2]|0;
 $38 = ($37|0)==(1);
 if (!($38)) {
  STACKTOP = sp;return;
 }
 $39 = (($36) + 88|0);
 HEAP32[$0>>2] = $39;
 $40 = (($this) + 180|0);
 dest=$36+0|0; src=$40+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $41 = HEAP32[$0>>2]|0;
 $42 = (($41) + 88|0);
 HEAP32[$0>>2] = $42;
 dest=$41+0|0; src=$3+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$8>>2] = 2;
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate6NormalEfff($this,$x,$y,$z) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 HEAPF32[$0>>2] = $x;
 $1 = (($this) + 108|0);
 HEAPF32[$1>>2] = $y;
 $2 = (($this) + 112|0);
 HEAPF32[$2>>2] = $z;
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate5ColorEffff($this,$r,$g,$b,$a) {
 $this = $this|0;
 $r = Math_fround($r);
 $g = Math_fround($g);
 $b = Math_fround($b);
 $a = Math_fround($a);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 HEAPF32[$0>>2] = $r;
 $1 = (($this) + 120|0);
 HEAPF32[$1>>2] = $g;
 $2 = (($this) + 124|0);
 HEAPF32[$2>>2] = $b;
 $3 = (($this) + 128|0);
 HEAPF32[$3>>2] = $a;
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate11TexCoordAllEfff($this,$x,$y,$z) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 HEAPF32[$0>>2] = $x;
 $1 = (($this) + 136|0);
 HEAPF32[$1>>2] = $y;
 $2 = (($this) + 140|0);
 HEAPF32[$2>>2] = $z;
 $3 = (($this) + 144|0);
 HEAPF32[$3>>2] = $x;
 $4 = (($this) + 148|0);
 HEAPF32[$4>>2] = $y;
 $5 = (($this) + 152|0);
 HEAPF32[$5>>2] = $z;
 $6 = (($this) + 156|0);
 HEAPF32[$6>>2] = $x;
 $7 = (($this) + 160|0);
 HEAPF32[$7>>2] = $y;
 $8 = (($this) + 164|0);
 HEAPF32[$8>>2] = $z;
 $9 = (($this) + 168|0);
 HEAPF32[$9>>2] = $x;
 $10 = (($this) + 172|0);
 HEAPF32[$10>>2] = $y;
 $11 = (($this) + 176|0);
 HEAPF32[$11>>2] = $z;
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate8TexCoordEifff($this,$unit,$x,$y,$z) {
 $this = $this|0;
 $unit = $unit|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($unit>>>0)<(4);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = ((($this) + (($unit*12)|0)|0) + 132|0);
 HEAPF32[$1>>2] = $x;
 $2 = ((($this) + (($unit*12)|0)|0) + 136|0);
 HEAPF32[$2>>2] = $y;
 $3 = ((($this) + (($unit*12)|0)|0) + 140|0);
 HEAPF32[$3>>2] = $z;
 STACKTOP = sp;return;
}
function __ZN13DrawImmediate15BuildQuadBufferEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $baseIndex$05 = 0, $q$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 256|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = (($this) + 84|0);
 HEAP32[$6>>2] = $5;
 $7 = ($5|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $8;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $9 = (__Z15malloc_internaljj10MemLabelIdiPKci(2304,2,$$byval_copy2,0,597408,352)|0);
 $baseIndex$05 = 0;$q$04 = 0;
 while(1) {
  $10 = $baseIndex$05 | 1;
  $11 = $10&65535;
  $12 = $q$04 | 1;
  $13 = (($9) + ($q$04<<1)|0);
  HEAP16[$13>>1] = $11;
  $14 = $baseIndex$05 | 2;
  $15 = $14&65535;
  $16 = (($q$04) + 2)|0;
  $17 = (($9) + ($12<<1)|0);
  HEAP16[$17>>1] = $15;
  $18 = $baseIndex$05&65535;
  $19 = (($q$04) + 3)|0;
  $20 = (($9) + ($16<<1)|0);
  HEAP16[$20>>1] = $18;
  $21 = (($q$04) + 4)|0;
  $22 = (($9) + ($19<<1)|0);
  HEAP16[$22>>1] = $15;
  $23 = $baseIndex$05 | 3;
  $24 = $23&65535;
  $25 = (($q$04) + 5)|0;
  $26 = (($9) + ($21<<1)|0);
  HEAP16[$26>>1] = $24;
  $27 = (($q$04) + 6)|0;
  $28 = (($9) + ($25<<1)|0);
  HEAP16[$28>>1] = $18;
  $29 = (($baseIndex$05) + 4)|0;
  $30 = ($27>>>0)<(1152);
  if ($30) {
   $baseIndex$05 = $29;$q$04 = $27;
  } else {
   break;
  }
 }
 $35 = HEAP32[$this>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 260|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_viiiiiii($38|0,($35|0),($39|0),0,1,2304,($9|0),0);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if (!($41)) {
  HEAP32[$0>>2] = $8;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy2);
  STACKTOP = sp;return;
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($9|0),($$byval_copy2|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($31|0);
  // unreachable;
 }
}
function __Z11IsGfxDevicev() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[597544>>2]|0;
 $1 = ($0|0)!=(0|0);
 STACKTOP = sp;return ($1|0);
}
function __Z12GetGfxDevicev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[597544>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z21GetUncheckedGfxDevicev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[597544>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z12SetGfxDeviceP9GfxDevice($device) {
 $device = $device|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[597544>>2] = $device;
 STACKTOP = sp;return;
}
function __Z16GetRealGfxDevicev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[597544>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z25GetUncheckedRealGfxDevicev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[597544>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN9GfxDeviceC2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((597552 + 8|0));
 $1 = (($this) + 4|0);
 __ZN24BuiltinShaderParamValuesC2Ev($1);
 $2 = (($this) + 5320|0);
 __THREW__ = 0;
 invoke_vi(3471,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if ($4) {
   label = 5;
  } else {
   $5 = (($this) + 5552|0);
   __THREW__ = 0;
   invoke_vi(3471,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    $8 = (($this) + 5828|0);
    HEAP32[$8>>2] = -1;
    $9 = (($this) + 5832|0);
    $10 = $9;
    $11 = $10;
    HEAP16[$11>>1]=0&65535;HEAP16[$11+2>>1]=0>>>16;
    $12 = (($10) + 4)|0;
    $13 = $12;
    HEAP16[$13>>1]=0&65535;HEAP16[$13+2>>1]=0>>>16;
    $14 = (($this) + 5840|0);
    HEAP32[$14>>2] = -1;
    $15 = (($this) + 5844|0);
    $16 = $15;
    $17 = $16;
    HEAP16[$17>>1]=0&65535;HEAP16[$17+2>>1]=0>>>16;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP16[$19>>1]=0&65535;HEAP16[$19+2>>1]=0>>>16;
    $20 = (($this) + 5852|0);
    HEAP32[$20>>2] = -1;
    $21 = (($this) + 5856|0);
    $22 = $21;
    $23 = $22;
    HEAP16[$23>>1]=0&65535;HEAP16[$23+2>>1]=0>>>16;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP16[$25>>1]=0&65535;HEAP16[$25+2>>1]=0>>>16;
    $26 = (($this) + 5864|0);
    HEAP32[$26>>2] = -1;
    $27 = (($this) + 5868|0);
    $28 = $27;
    $29 = $28;
    HEAP16[$29>>1]=0&65535;HEAP16[$29+2>>1]=0>>>16;
    $30 = (($28) + 4)|0;
    $31 = $30;
    HEAP16[$31>>1]=0&65535;HEAP16[$31+2>>1]=0>>>16;
    $32 = (($this) + 5876|0);
    HEAP32[$32>>2] = -1;
    $33 = (($this) + 5880|0);
    $34 = $33;
    $35 = $34;
    HEAP16[$35>>1]=0&65535;HEAP16[$35+2>>1]=0>>>16;
    $36 = (($34) + 4)|0;
    $37 = $36;
    HEAP16[$37>>1]=0&65535;HEAP16[$37+2>>1]=0>>>16;
    $38 = (($this) + 5888|0);
    HEAP32[$38>>2] = -1;
    $39 = (($this) + 5892|0);
    $40 = $39;
    $41 = $40;
    HEAP16[$41>>1]=0&65535;HEAP16[$41+2>>1]=0>>>16;
    $42 = (($40) + 4)|0;
    $43 = $42;
    HEAP16[$43>>1]=0&65535;HEAP16[$43+2>>1]=0>>>16;
    $44 = (($this) + 5900|0);
    HEAP32[$44>>2] = -1;
    $45 = (($this) + 5904|0);
    $46 = $45;
    $47 = $46;
    HEAP16[$47>>1]=0&65535;HEAP16[$47+2>>1]=0>>>16;
    $48 = (($46) + 4)|0;
    $49 = $48;
    HEAP16[$49>>1]=0&65535;HEAP16[$49+2>>1]=0>>>16;
    $50 = (($this) + 5948|0);
    $51 = (($this) + 5968|0);
    HEAP32[$51>>2] = 0;
    $52 = (($this) + 5976|0);
    HEAP32[$52>>2] = 0;
    $53 = (($this) + 5980|0);
    HEAP32[$53>>2] = 0;
    $54 = (($this) + 5972|0);
    ;HEAP32[$50+0>>2]=0|0;HEAP32[$50+4>>2]=0|0;HEAP32[$50+8>>2]=0|0;HEAP32[$50+12>>2]=0|0;
    HEAP32[$54>>2] = 61;
    $55 = (($this) + 6000|0);
    $56 = (($this) + 6004|0);
    HEAP32[$56>>2] = 0;
    $57 = (($this) + 6008|0);
    HEAP32[$57>>2] = 0;
    $58 = (($this) + 6004|0);
    HEAP32[$55>>2] = $58;
    __THREW__ = 0;
    invoke_vi(3472,($this|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if (!($60)) {
     STACKTOP = sp;return;
    }
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    $65 = HEAP32[$56>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeI9TextureIDjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($55,$65);
    $66 = HEAP32[$53>>2]|0;
    $67 = ($66|0)>(-1);
    if ($67) {
     $68 = HEAP32[$51>>2]|0;
     $69 = HEAP32[$54>>2]|0;
     HEAP32[$0>>2] = $69;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($68|0),($$byval_copy|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if (!($71)) {
      HEAP32[$51>>2] = 0;
      $$1 = $64;$$12 = $63;
      break;
     }
     $89 = ___cxa_find_matching_catch(0|0)|0;
     $90 = tempRet0;
     $eh$lpad$body$indexZ2D = $89;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    } else {
     $$1 = $64;$$12 = $63;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $61 = ___cxa_find_matching_catch()|0;
  $62 = tempRet0;
  $$1 = $62;$$12 = $61;
 }
 $72 = (($this) + 3748|0);
 $73 = (($this) + 5284|0);
 $75 = $73;
 while(1) {
  $74 = (($75) + -64|0);
  __THREW__ = 0;
  invoke_vi(3473,($74|0));
  $76 = __THREW__; __THREW__ = 0;
  $77 = $76&1;
  if ($77) {
   break;
  }
  $78 = ($74|0)==($72|0);
  if ($78) {
   label = 16;
   break;
  } else {
   $75 = $74;
  }
 }
 if ((label|0) == 16) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $79 = ___cxa_find_matching_catch(0|0)|0;
 $80 = tempRet0;
 $81 = ($72|0)==($74|0);
 if ($81) {
  $eh$lpad$body$indexZ2D = $79;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 } else {
  $83 = $74;
 }
 while(1) {
  $82 = (($83) + -64|0);
  __THREW__ = 0;
  invoke_vi(3473,($82|0));
  $84 = __THREW__; __THREW__ = 0;
  $85 = $84&1;
  if ($85) {
   label = 15;
   break;
  }
  $86 = ($82|0)==($72|0);
  if ($86) {
   $eh$lpad$body$indexZ2D = $79;
   label = 18;
   break;
  } else {
   $83 = $82;
  }
 }
 if ((label|0) == 15) {
  $87 = ___cxa_find_matching_catch(0|0)|0;
  $88 = tempRet0;
  ___clang_call_terminate($87);
  // unreachable;
 }
 else if ((label|0) == 18) {
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __ZN9GfxDevice8OnCreateEv($this) {
 $this = $this|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 5320|0);
 __ZN14GfxDeviceStats10ResetFrameEv($4);
 $5 = (($this) + 5552|0);
 __ZN14GfxDeviceStats10ResetFrameEv($5);
 $6 = (($this) + 5788|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 5916|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 5912|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 5920|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 5792|0);
 HEAP32[$10>>2] = -1;
 $11 = (($this) + 5784|0);
 HEAP8[$11>>0] = 0;
 $12 = (($this) + 5785|0);
 HEAP8[$12>>0] = 0;
 $13 = (($this) + 5786|0);
 HEAP8[$13>>0] = 0;
 $14 = (($this) + 5924|0);
 HEAP8[$14>>0] = 0;
 $15 = (($this) + 5925|0);
 HEAP8[$15>>0] = 0;
 $16 = (($this) + 5940|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 5828|0);
 $18 = (($this) + 5804|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 5808|0);
 HEAP32[$19>>2] = $17;
 $20 = (($this) + 5812|0);
 HEAP32[$20>>2] = $17;
 $21 = (($this) + 5816|0);
 HEAP32[$21>>2] = $17;
 $22 = (($this) + 5820|0);
 HEAP32[$22>>2] = $17;
 $23 = (($this) + 5824|0);
 HEAP32[$23>>2] = $17;
 $24 = (($this) + 5984|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 5796|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 5800|0);
 HEAP32[$26>>2] = 0;
 $27 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $27;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 $28 = (__Znwj10MemLabelIdbiPKci(280,$$byval_copy4,0,16,598360,208)|0);
 __THREW__ = 0;
 invoke_vii(2701,($28|0),($this|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if (!($30)) {
  $31 = (($this) + 5964|0);
  HEAP32[$31>>2] = $28;
  $32 = HEAP32[628280>>2]|0;
  HEAP32[$1>>2] = $32;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  $33 = (__Znwj10MemLabelIdbiPKci(8,$$byval_copy4,0,16,598360,209)|0);
  $34 = (($33) + 4|0);
  HEAP32[$33>>2] = $33;
  HEAP32[$34>>2] = $33;
  $35 = (($this) + 5988|0);
  HEAP32[$35>>2] = $33;
  $36 = HEAP32[628280>>2]|0;
  HEAP32[$2>>2] = $36;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
  $37 = (__Znwj10MemLabelIdbiPKci(8,$$byval_copy4,0,16,598360,210)|0);
  $38 = (($37) + 4|0);
  HEAP32[$37>>2] = $37;
  HEAP32[$38>>2] = $37;
  $39 = (($this) + 5992|0);
  HEAP32[$39>>2] = $37;
  $40 = HEAP32[628280>>2]|0;
  HEAP32[$3>>2] = $40;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
  $41 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy4,0,16,598360,211)|0);
  HEAP32[$41>>2] = 0;
  $42 = (($41) + 8|0);
  HEAP32[$42>>2] = 0;
  $43 = (($41) + 12|0);
  HEAP32[$43>>2] = 0;
  $44 = (($41) + 4|0);
  HEAP32[$44>>2] = 61;
  $45 = (($this) + 5996|0);
  HEAP32[$45>>2] = $41;
  __ZN12TextureIdMap10InitializeEv();
  $46 = (($this) + 5944|0);
  HEAP32[$46>>2] = 0;
  STACKTOP = sp;return;
 }
 $47 = ___cxa_find_matching_catch()|0;
 $48 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($28|0),($$byval_copy4|0),0,16,(598360|0),208);
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch(0|0)|0;
  $52 = tempRet0;
  ___clang_call_terminate($51);
  // unreachable;
 } else {
  ___resumeException($47|0);
  // unreachable;
 }
}
function __ZN9GfxDeviceD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1021,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9GfxDeviceD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((597552 + 8|0));
 __THREW__ = 0;
 invoke_vi(3474,($this|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if ($3) {
   $35 = ___cxa_find_matching_catch()|0;
   $36 = tempRet0;
   $37 = (($this) + 6000|0);
   $38 = (($this) + 6004|0);
   $39 = HEAP32[$38>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeI9TextureIDjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($37,$39);
   $40 = (($this) + 5980|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)>(-1);
   if ($42) {
    $43 = (($this) + 5968|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($this) + 5972|0);
    $46 = HEAP32[$45>>2]|0;
    HEAP32[$0>>2] = $46;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($44|0),($$byval_copy8|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if (!($48)) {
     HEAP32[$43>>2] = 0;
     $$1 = $36;$$12 = $35;
     break;
    }
    $66 = ___cxa_find_matching_catch(0|0)|0;
    $67 = tempRet0;
    $eh$lpad$body$indexZ2D = $66;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   } else {
    $$1 = $36;$$12 = $35;
   }
  } else {
   $4 = (($this) + 6000|0);
   $5 = (($this) + 6004|0);
   $6 = HEAP32[$5>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeI9TextureIDjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($4,$6);
   $7 = (($this) + 5980|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)>(-1);
   do {
    if ($9) {
     $10 = (($this) + 5968|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($this) + 5972|0);
     $13 = HEAP32[$12>>2]|0;
     HEAP32[$1>>2] = $13;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($11|0),($$byval_copy8|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      $33 = ___cxa_find_matching_catch()|0;
      $34 = tempRet0;
      $$1 = $34;$$12 = $33;
      break L1;
     } else {
      HEAP32[$10>>2] = 0;
      break;
     }
    }
   } while(0);
   $16 = (($this) + 3748|0);
   $17 = (($this) + 5284|0);
   $19 = $17;
   while(1) {
    $18 = (($19) + -64|0);
    __THREW__ = 0;
    invoke_vi(3473,($18|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = ($18|0)==($16|0);
    if ($22) {
     label = 13;
     break;
    } else {
     $19 = $18;
    }
   }
   if ((label|0) == 13) {
    STACKTOP = sp;return;
   }
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   $25 = ($16|0)==($18|0);
   if ($25) {
    ___resumeException($23|0);
    // unreachable;
   } else {
    $27 = $18;
   }
   while(1) {
    $26 = (($27) + -64|0);
    __THREW__ = 0;
    invoke_vi(3473,($26|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 12;
     break;
    }
    $30 = ($26|0)==($16|0);
    if ($30) {
     label = 11;
     break;
    } else {
     $27 = $26;
    }
   }
   if ((label|0) == 11) {
    ___resumeException($23|0);
    // unreachable;
   }
   else if ((label|0) == 12) {
    $31 = ___cxa_find_matching_catch(0|0)|0;
    $32 = tempRet0;
    ___clang_call_terminate($31);
    // unreachable;
   }
  }
 } while(0);
 $49 = (($this) + 3748|0);
 $50 = (($this) + 5284|0);
 $52 = $50;
 while(1) {
  $51 = (($52) + -64|0);
  __THREW__ = 0;
  invoke_vi(3473,($51|0));
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if ($54) {
   break;
  }
  $55 = ($51|0)==($49|0);
  if ($55) {
   label = 25;
   break;
  } else {
   $52 = $51;
  }
 }
 if ((label|0) == 25) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $56 = ___cxa_find_matching_catch(0|0)|0;
 $57 = tempRet0;
 $58 = ($49|0)==($51|0);
 if ($58) {
  $eh$lpad$body$indexZ2D = $56;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 } else {
  $60 = $51;
 }
 while(1) {
  $59 = (($60) + -64|0);
  __THREW__ = 0;
  invoke_vi(3473,($59|0));
  $61 = __THREW__; __THREW__ = 0;
  $62 = $61&1;
  if ($62) {
   label = 24;
   break;
  }
  $63 = ($59|0)==($49|0);
  if ($63) {
   $eh$lpad$body$indexZ2D = $56;
   label = 27;
   break;
  } else {
   $60 = $59;
  }
 }
 if ((label|0) == 24) {
  $64 = ___cxa_find_matching_catch(0|0)|0;
  $65 = tempRet0;
  ___clang_call_terminate($64);
  // unreachable;
 }
 else if ((label|0) == 27) {
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __ZN9GfxDevice8OnDeleteEv($this) {
 $this = $this|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 312|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($this);
 $5 = (($this) + 5984|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 4095]($6);
 }
 HEAP32[$5>>2] = 0;
 $11 = (($this) + 5980|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)>(-1);
 if ($13) {
  $14 = (($this) + 5968|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 5972|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$0>>2] = $17;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($15,$$byval_copy5);
  HEAP32[$14>>2] = 0;
 }
 $18 = (($this) + 5976|0);
 HEAP32[$18>>2] = 0;
 HEAP32[$11>>2] = 0;
 $19 = (($this) + 5988|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[628280>>2]|0;
 $22 = ($20|0)==(0|0);
 if (!($22)) {
  $23 = (($20) + 4|0);
  HEAP32[$23>>2] = 0;
  HEAP32[$20>>2] = 0;
 }
 HEAP32[$0>>2] = $21;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($20,$$byval_copy5);
 HEAP32[$19>>2] = 0;
 $24 = (($this) + 5992|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[628280>>2]|0;
 $27 = ($25|0)==(0|0);
 if (!($27)) {
  $28 = (($25) + 4|0);
  HEAP32[$28>>2] = 0;
  HEAP32[$25>>2] = 0;
 }
 HEAP32[$0>>2] = $26;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy5);
 HEAP32[$24>>2] = 0;
 $29 = (($this) + 5996|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[628280>>2]|0;
 $32 = ($30|0)==(0|0);
 if (!($32)) {
  $33 = (($30) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)>(-1);
  if ($35) {
   $36 = HEAP32[$30>>2]|0;
   $37 = (($30) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   HEAP32[$0>>2] = $38;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($36,$$byval_copy5);
   HEAP32[$30>>2] = 0;
  }
 }
 HEAP32[$1>>2] = $31;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($30,$$byval_copy5);
 HEAP32[$29>>2] = 0;
 $39 = HEAP32[((598504 + 76|0))>>2]|0;
 $40 = HEAP32[628256>>2]|0;
 HEAP32[$0>>2] = $40;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($39,$$byval_copy5);
 HEAP32[((598504 + 76|0))>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice15InvalidateStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5925|0);
 HEAP8[$0>>0] = 0;
 $1 = (($this) + 5284|0);
 HEAP32[$1>>2] = -1;
 $2 = (($this) + 5288|0);
 HEAPF32[$2>>2] = Math_fround(-1.0);
 $3 = (($this) + 5292|0);
 HEAPF32[$3>>2] = Math_fround(-1.0);
 $4 = (($this) + 5296|0);
 HEAPF32[$4>>2] = Math_fround(-1.0);
 $5 = (($this) + 5300|0);
 HEAPF32[$5>>2] = Math_fround(-1.0);
 $6 = (($this) + 5304|0);
 HEAPF32[$6>>2] = Math_fround(-1.0);
 $7 = (($this) + 5308|0);
 HEAPF32[$7>>2] = Math_fround(-1.0);
 $8 = (($this) + 5312|0);
 HEAPF32[$8>>2] = Math_fround(-1.0);
 $9 = (($this) + 5964|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN13DrawImmediate10InvalidateEv($10);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16DeleteDynamicVBOEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5984|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($1);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice19OnCreateIndexBufferEP11IndexBuffer($this,$indexBuf) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5988|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($indexBuf) + 4|0);
 $3 = ($2|0)==($1|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 $$pre$i$i = (($indexBuf) + 8|0);
 if (!($5)) {
  $6 = HEAP32[$$pre$i$i>>2]|0;
  $7 = (($4) + 4|0);
  HEAP32[$7>>2] = $6;
  $8 = HEAP32[$2>>2]|0;
  $9 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$9>>2] = $8;
  HEAP32[$2>>2] = 0;
  HEAP32[$$pre$i$i>>2] = 0;
 }
 $10 = HEAP32[$1>>2]|0;
 HEAP32[$2>>2] = $10;
 HEAP32[$$pre$i$i>>2] = $1;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $2;
 $12 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$12>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice19OnDeleteIndexBufferEP11IndexBuffer($this,$indexBuf) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 var $$$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($indexBuf|0)==(0|0);
 $1 = (($indexBuf) + 4|0);
 $$$i$i = $0 ? 0 : $1;
 $2 = (($$$i$i) + -4|0);
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($2) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$6>>2]|0;
 HEAP32[$10>>2] = $9;
 HEAP32[$3>>2] = 0;
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20OnCreateVertexBufferEP12VertexBuffer($this,$vertexBuf) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5992|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($vertexBuf) + 4|0);
 $3 = ($2|0)==($1|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 $$pre$i$i = (($vertexBuf) + 8|0);
 if (!($5)) {
  $6 = HEAP32[$$pre$i$i>>2]|0;
  $7 = (($4) + 4|0);
  HEAP32[$7>>2] = $6;
  $8 = HEAP32[$2>>2]|0;
  $9 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$9>>2] = $8;
  HEAP32[$2>>2] = 0;
  HEAP32[$$pre$i$i>>2] = 0;
 }
 $10 = HEAP32[$1>>2]|0;
 HEAP32[$2>>2] = $10;
 HEAP32[$$pre$i$i>>2] = $1;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $2;
 $12 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$12>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20OnDeleteVertexBufferEP12VertexBuffer($this,$vertexBuf) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 var $$$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($vertexBuf|0)==(0|0);
 $1 = (($vertexBuf) + 4|0);
 $$$i$i = $0 ? 0 : $1;
 $2 = (($$$i$i) + -4|0);
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($2) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$6>>2]|0;
 HEAP32[$10>>2] = $9;
 HEAP32[$3>>2] = 0;
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice13GetDynamicVBOEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5984|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $7 = $1;
  STACKTOP = sp;return ($7|0);
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 792|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($this)|0);
 HEAP32[$0>>2] = $6;
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZN9GfxDevice15ResetAllBuffersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5992|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if (!($4)) {
  $6 = $3;
  while(1) {
   $5 = (($6) + -4|0);
   $7 = HEAP32[$5>>2]|0;
   $8 = (($7) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   FUNCTION_TABLE_vi[$9 & 4095]($5);
   $10 = (($6) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==($1|0);
   if ($12) {
    break;
   } else {
    $6 = $11;
   }
  }
 }
 $13 = (($this) + 5988|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==($14|0);
 if ($17) {
  STACKTOP = sp;return;
 } else {
  $19 = $16;
 }
 while(1) {
  $18 = (($19) + -4|0);
  $20 = HEAP32[$18>>2]|0;
  $21 = (($20) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_vi[$22 & 4095]($18);
  $23 = (($19) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==($14|0);
  if ($25) {
   break;
  } else {
   $19 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9GfxDevice21SetWorldMatrixAndTypeERK10Matrix4x4f13TransformType($this,$matrix,$type) {
 $this = $this|0;
 $matrix = $matrix|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($this,$matrix);
 $3 = $type & 4;
 $4 = ($3|0)!=(0);
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 136|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($this,$4);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice10SetLODFadeEf($this,$lodFade) {
 $this = $this|0;
 $lodFade = Math_fround($lodFade);
 var $$op = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($lodFade * Math_fround(16.0));
 $1 = (Math_fround(Math_floor((Math_fround($0)))));
 $2 = $1 > Math_fround(15.0);
 $$op = Math_fround($1 * Math_fround(0.0625));
 $3 = $2 ? Math_fround(0.9375) : $$op;
 $4 = (($this) + 948|0);
 HEAPF32[$4>>2] = $lodFade;
 $5 = (($this) + 952|0);
 HEAPF32[$5>>2] = $3;
 $6 = (($this) + 956|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 960|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice24SetFFLightmapScaleOffsetERK8Vector4f($this,$st) {
 $this = $this|0;
 $st = $st|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 964|0);
 ;HEAP32[$0+0>>2]=HEAP32[$st+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$st+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$st+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$st+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16CreateGpuProgramERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER22CreateGpuProgramOutput($this,$source,$output) {
 $this = $this|0;
 $source = $source|0;
 $output = $output|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16CreateGpuProgramRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER22CreateGpuProgramOutput($source,$output)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN9GfxDevice19RecordSetBlendStateEPK16DeviceBlendStateRKN9ShaderLab8FloatValEPKNS3_13PropertySheetERKNS3_17ShaderPassContextE($this,$state,$alphaRef,$props,$passContext) {
 $this = $this|0;
 $state = $state|0;
 $alphaRef = $alphaRef|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(598368,0,598360,412,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice19RecordSetFFMaterialERKN9ShaderLab9VectorValES3_S3_S3_RKNS0_8FloatValEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($this,$ambient,$diffuse,$specular,$emissive,$shininess,$props,$passContext) {
 $this = $this|0;
 $ambient = $ambient|0;
 $diffuse = $diffuse|0;
 $specular = $specular|0;
 $emissive = $emissive|0;
 $shininess = $shininess|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(598368,0,598360,417,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16RecordSetFFColorERKN9ShaderLab9VectorValEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($this,$color,$props,$passContext) {
 $this = $this|0;
 $color = $color|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(598368,0,598360,422,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17RecordEnableFFFogE7FogModeRKN9ShaderLab8FloatValES4_S4_RKNS1_9VectorValEPKNS1_13PropertySheetERKNS1_17ShaderPassContextE($this,$fogMode,$fogStart,$fogEnd,$fogDensity,$fogColor,$props,$passContext) {
 $this = $this|0;
 $fogMode = $fogMode|0;
 $fogStart = $fogStart|0;
 $fogEnd = $fogEnd|0;
 $fogDensity = $fogDensity|0;
 $fogColor = $fogColor|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(598368,0,598360,427,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17DestroyGpuProgramEPK10GpuProgram($this,$program) {
 $this = $this|0;
 $program = $program|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($program|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$program>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($program);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice24DrawBuffersCustomIndicesEPKtj16GfxPrimitiveTypePK18VertexStreamSourcejjjP17VertexDeclarationRK14ChannelAssigns($this,$indices,$indexCount,$topology,$vertexStreams,$vertexStreamCount,$firstVertex,$vertexCount,$vertexDecl,$channels) {
 $this = $this|0;
 $indices = $indices|0;
 $indexCount = $indexCount|0;
 $topology = $topology|0;
 $vertexStreams = $vertexStreams|0;
 $vertexStreamCount = $vertexStreamCount|0;
 $firstVertex = $firstVertex|0;
 $vertexCount = $vertexCount|0;
 $vertexDecl = $vertexDecl|0;
 $channels = $channels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $drawRange = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $drawRange = sp;
 $0 = $indexCount << 1;
 $1 = (__ZN9GfxDevice24AcquireCustomIndexBufferEj($this,$0)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 264|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$5 & 511]($this,$1,0,$0)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(598408,0,598360,451,1,0,0,0);
  STACKTOP = sp;return;
 } else {
  _memcpy(($6|0),($indices|0),($0|0))|0;
  $8 = HEAP32[$this>>2]|0;
  $9 = (($8) + 268|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_viii[$10 & 4095]($this,$1,$0);
  ;HEAP32[$drawRange+0>>2]=0|0;HEAP32[$drawRange+4>>2]=0|0;HEAP32[$drawRange+8>>2]=0|0;HEAP32[$drawRange+12>>2]=0|0;HEAP32[$drawRange+16>>2]=0|0;
  HEAP32[$drawRange>>2] = 0;
  $11 = (($drawRange) + 8|0);
  HEAP32[$11>>2] = $indexCount;
  $12 = (($drawRange) + 16|0);
  HEAP32[$12>>2] = $firstVertex;
  $13 = (($drawRange) + 20|0);
  HEAP32[$13>>2] = $vertexCount;
  $14 = HEAP32[$this>>2]|0;
  $15 = (($14) + 300|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiiiiiii[$16 & 63]($this,$1,$vertexStreams,$vertexStreamCount,$drawRange,1,$vertexDecl,$channels);
  STACKTOP = sp;return;
 }
}
function __ZN9GfxDevice24AcquireCustomIndexBufferEj($this,$requiredSize) {
 $this = $this|0;
 $requiredSize = $requiredSize|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 5796|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 256|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
  HEAP32[$1>>2] = $7;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $22 = $7;
  }
 } else {
  $22 = $2;
 }
 $9 = (($requiredSize) + -1)|0;
 $10 = $9 >>> 16;
 $11 = $10 | $9;
 $12 = $11 >>> 8;
 $13 = $12 | $11;
 $14 = $13 >>> 4;
 $15 = $14 | $13;
 $16 = $15 >>> 2;
 $17 = $16 | $15;
 $18 = $17 >>> 1;
 $19 = $18 | $17;
 $20 = (($19) + 1)|0;
 $21 = (($22) + 20|0);
 $23 = HEAP32[$21>>2]|0;
 $24 = ($23>>>0)<($20>>>0);
 if ($24) {
  $25 = HEAP32[$this>>2]|0;
  $26 = (($25) + 260|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_viiiiiii[$27 & 127]($this,$22,1,1,$20,0,0);
  $$pre = HEAP32[$1>>2]|0;
  $$phi$trans$insert = (($$pre) + 20|0);
  $$pre2 = HEAP32[$$phi$trans$insert>>2]|0;
  $29 = $$pre2;$51 = $$pre;
 } else {
  $29 = $23;$51 = $22;
 }
 $28 = ($29>>>0)<($20>>>0);
 if (!($28)) {
  $$0 = $51;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = $20;
 __Z6FormatPKcz($0,598448,$vararg_buffer);
 $30 = HEAP8[$0>>0]|0;
 $31 = $30 & 1;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  $35 = (($0) + 1|0);
  $36 = $35;
 } else {
  $33 = (($0) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $36 = $34;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($36|0),0,(598360|0),499,1,0,0,(0|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $46 = HEAP8[$0>>0]|0;
  $47 = $46 & 1;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   ___resumeException($44|0);
   // unreachable;
  }
  $49 = (($0) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  __ZdlPv($50);
  ___resumeException($44|0);
  // unreachable;
 } else {
  $39 = HEAP8[$0>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $42 = (($0) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  __ZdlPv($43);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9GfxDevice23GetAllWhiteVertexStreamEj($agg$result,$this,$size) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $size = $size|0;
 var $$01$i$i$i = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 5800|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 276|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
  HEAP32[$1>>2] = $7;
  $9 = $7;
 } else {
  $9 = $2;
 }
 $8 = (($9) + 20|0);
 $10 = HEAP32[$8>>2]|0;
 $11 = $size << 2;
 $12 = ($10>>>0)<($11>>>0);
 if (!($12)) {
  $45 = HEAP32[$1>>2]|0;
  HEAP32[$agg$result>>2] = $45;
  $46 = (($agg$result) + 4|0);
  HEAP32[$46>>2] = 4;
  STACKTOP = sp;return;
 }
 $13 = (($size) + -1)|0;
 $14 = $13 >>> 16;
 $15 = $14 | $13;
 $16 = $15 >>> 8;
 $17 = $16 | $15;
 $18 = $17 >>> 4;
 $19 = $18 | $17;
 $20 = $19 >>> 2;
 $21 = $20 | $19;
 $22 = $21 >>> 1;
 $23 = $22 | $21;
 $24 = (($23) + 1)|0;
 $25 = HEAP32[628512>>2]|0;
 $26 = $24 << 2;
 HEAP32[$0>>2] = $25;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $27 = (__Z15malloc_internaljj10MemLabelIdiPKci($26,4,$$byval_copy2,0,598360,352)|0);
 $28 = (($27) + ($24<<2)|0);
 $29 = ($27|0)==($28|0);
 if (!($29)) {
  $$01$i$i$i = $27;
  while(1) {
   $30 = ($$01$i$i$i|0)==(0|0);
   if (!($30)) {
    HEAP32[$$01$i$i$i>>2] = -1;
   }
   $31 = (($$01$i$i$i) + 4|0);
   $32 = ($31|0)==($28|0);
   if ($32) {
    break;
   } else {
    $$01$i$i$i = $31;
   }
  }
 }
 $33 = HEAP32[$this>>2]|0;
 $34 = (($33) + 280|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_viiiiiii($35|0,($this|0),($36|0),0,1,($26|0),($27|0),0);
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if (!($38)) {
  $39 = ($24|0)>(-1);
  if (!($39)) {
   $45 = HEAP32[$1>>2]|0;
   HEAP32[$agg$result>>2] = $45;
   $46 = (($agg$result) + 4|0);
   HEAP32[$46>>2] = 4;
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $25;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy2);
  $45 = HEAP32[$1>>2]|0;
  HEAP32[$agg$result>>2] = $45;
  $46 = (($agg$result) + 4|0);
  HEAP32[$46>>2] = 4;
  STACKTOP = sp;return;
 }
 $40 = ___cxa_find_matching_catch()|0;
 $41 = tempRet0;
 $42 = ($24|0)>(-1);
 if (!($42)) {
  ___resumeException($40|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $25;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy2|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $47 = ___cxa_find_matching_catch(0|0)|0;
  $48 = tempRet0;
  ___clang_call_terminate($47);
  // unreachable;
 } else {
  ___resumeException($40|0);
  // unreachable;
 }
}
function __ZN9GfxDevice11EndSkinningEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5996|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $i$01 = 0;
  while(1) {
   $5 = HEAP32[$this>>2]|0;
   $6 = (($5) + 320|0);
   $7 = HEAP32[$6>>2]|0;
   FUNCTION_TABLE_vii[$7 & 4095]($this,$i$01);
   $8 = (($i$01) + 1)|0;
   $9 = HEAP32[$2>>2]|0;
   $10 = ($8>>>0)<($9>>>0);
   if ($10) {
    $i$01 = $8;
   } else {
    break;
   }
  }
 }
 $11 = (($this) + 5976|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice13BeginSkinningEi($this,$maxSkinCount) {
 $this = $this|0;
 $maxSkinCount = $maxSkinCount|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 5996|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = ($5>>>0)<($maxSkinCount>>>0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 312|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$9 & 4095]($this);
 $10 = ($maxSkinCount|0)<(64);
 $11 = $10 ? 64 : $maxSkinCount;
 $12 = HEAP32[$3>>2]|0;
 $13 = $12 & 2147483647;
 $14 = ($13>>>0)<($11>>>0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = ($12|0)>(-1);
 if ($15) {
  HEAP32[$3>>2] = $11;
  $16 = HEAP32[$2>>2]|0;
  $17 = ($11*96)|0;
  $18 = (($2) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$0>>2] = $19;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($16,$17,4,$$byval_copy1,0,598360,370)|0);
  HEAP32[$2>>2] = $20;
  STACKTOP = sp;return;
 } else {
  $21 = ($11*96)|0;
  $22 = (($2) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$0>>2] = $23;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,4,$$byval_copy1,0,598360,352)|0);
  $25 = HEAP32[$2>>2]|0;
  $26 = (($2) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27*96)|0;
  _memcpy(($24|0),($25|0),($28|0))|0;
  HEAP32[$3>>2] = $11;
  HEAP32[$2>>2] = $24;
  STACKTOP = sp;return;
 }
}
function __ZN9GfxDevice8SkinMeshER12SkinMeshInfoP12VertexBuffer($this,$skin,$vertexBuf) {
 $this = $this|0;
 $skin = $skin|0;
 $vertexBuf = $vertexBuf|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $skinIndex$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 5996|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4|0)==($7|0);
 if ($8) {
  $9 = HEAP32[$this>>2]|0;
  $10 = (($9) + 308|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $4 << 1;
  FUNCTION_TABLE_vii[$11 & 4095]($this,$12);
 }
 $13 = (($this) + 5976|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 do {
  if ($15) {
   $21 = HEAP32[$3>>2]|0;
   $22 = (($21) + 1)|0;
   HEAP32[$3>>2] = $22;
   $23 = HEAP32[$5>>2]|0;
   $24 = $23 & 2147483647;
   $25 = ($22>>>0)>($24>>>0);
   if ($25) {
    $26 = $23 << 1;
    $27 = ($26|0)==(0);
    $28 = $27 ? 1 : $26;
    $29 = ($24>>>0)<($28>>>0);
    if ($29) {
     $30 = ($23|0)>(-1);
     if ($30) {
      HEAP32[$5>>2] = $28;
      $31 = HEAP32[$2>>2]|0;
      $32 = ($28*96)|0;
      $33 = (($2) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      HEAP32[$0>>2] = $34;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $35 = (__Z16realloc_internalPvji10MemLabelIdiPKci($31,$32,4,$$byval_copy1,0,598360,370)|0);
      HEAP32[$2>>2] = $35;
      $skinIndex$0 = $21;
      break;
     } else {
      $36 = ($28*96)|0;
      $37 = (($2) + 4|0);
      $38 = HEAP32[$37>>2]|0;
      HEAP32[$0>>2] = $38;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $39 = (__Z15malloc_internaljj10MemLabelIdiPKci($36,4,$$byval_copy1,0,598360,352)|0);
      $40 = HEAP32[$2>>2]|0;
      $41 = HEAP32[$3>>2]|0;
      $42 = ($41*96)|0;
      _memcpy(($39|0),($40|0),($42|0))|0;
      HEAP32[$5>>2] = $28;
      HEAP32[$2>>2] = $39;
      $skinIndex$0 = $21;
      break;
     }
    } else {
     $skinIndex$0 = $21;
    }
   } else {
    $skinIndex$0 = $21;
   }
  } else {
   $16 = (($14) + -1)|0;
   $17 = (($this) + 5968|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + ($16<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[$13>>2] = $16;
   $skinIndex$0 = $20;
  }
 } while(0);
 $43 = HEAP32[$2>>2]|0;
 $44 = (($43) + (($skinIndex$0*96)|0)|0);
 __Z33CopySkinMeshInfoAndFenceOwnershipR12SkinMeshInfoS0_($skin,$44);
 $45 = ((($43) + (($skinIndex$0*96)|0)|0) + 92|0);
 HEAP32[$45>>2] = $vertexBuf;
 $46 = HEAP32[$this>>2]|0;
 $47 = (($46) + 284|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (FUNCTION_TABLE_iiiii[$48 & 511]($this,$vertexBuf,0,0)|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  __ZN12SkinMeshInfo7ReleaseEv($44);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $51 = ((($43) + (($skinIndex$0*96)|0)|0) + 16|0);
  HEAP32[$51>>2] = $49;
  __Z17DeformSkinnedMeshR12SkinMeshInfo($44);
  $52 = HEAP32[$this>>2]|0;
  $53 = (($52) + 320|0);
  $54 = HEAP32[$53>>2]|0;
  FUNCTION_TABLE_vii[$54 & 4095]($this,$skinIndex$0);
  $$0 = $skinIndex$0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9GfxDevice19EndSkinningInstanceEi($this,$skinningInstance) {
 $this = $this|0;
 $skinningInstance = $skinningInstance|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 5996|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>($skinningInstance>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 5968|0);
 $7 = (($this) + 5976|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 1)|0;
 HEAP32[$7>>2] = $9;
 $10 = (($this) + 5980|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 2147483647;
 $13 = ($9>>>0)>($12>>>0);
 if ($13) {
  $14 = $11 << 1;
  $15 = ($14|0)==(0);
  $16 = $15 ? 1 : $14;
  $17 = ($12>>>0)<($16>>>0);
  do {
   if ($17) {
    $18 = ($11|0)>(-1);
    if ($18) {
     HEAP32[$10>>2] = $16;
     $19 = HEAP32[$6>>2]|0;
     $20 = $16 << 2;
     $21 = (($this) + 5972|0);
     $22 = HEAP32[$21>>2]|0;
     HEAP32[$0>>2] = $22;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $23 = (__Z16realloc_internalPvji10MemLabelIdiPKci($19,$20,4,$$byval_copy1,0,598360,370)|0);
     HEAP32[$6>>2] = $23;
     break;
    } else {
     $24 = $16 << 2;
     $25 = (($this) + 5972|0);
     $26 = HEAP32[$25>>2]|0;
     HEAP32[$0>>2] = $26;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $27 = (__Z15malloc_internaljj10MemLabelIdiPKci($24,4,$$byval_copy1,0,598360,352)|0);
     $28 = HEAP32[$6>>2]|0;
     $29 = HEAP32[$7>>2]|0;
     $30 = $29 << 2;
     _memcpy(($27|0),($28|0),($30|0))|0;
     HEAP32[$10>>2] = $16;
     HEAP32[$6>>2] = $27;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$7>>2]|0;
  $32 = $$pre$i$i;
 } else {
  $32 = $9;
 }
 $31 = (($32) + -1)|0;
 $33 = HEAP32[$6>>2]|0;
 $34 = (($33) + ($31<<2)|0);
 HEAP32[$34>>2] = $skinningInstance;
 $35 = HEAP32[$2>>2]|0;
 $36 = ((($35) + (($skinningInstance*96)|0)|0) + 92|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = ((($35) + (($skinningInstance*96)|0)|0) + 72|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  $46 = $37;
 } else {
  __Z21CompleteFenceInternalR8JobFence($39);
  $$pre = HEAP32[$36>>2]|0;
  $46 = $$pre;
 }
 $42 = HEAP32[$this>>2]|0;
 $43 = (($42) + 288|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($46) + 20|0);
 $47 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_viii[$44 & 4095]($this,$46,$47);
 HEAP32[$36>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice24GetMaxStaticBatchIndicesEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 32000;
}
function __ZN9GfxDevice19BeginStaticBatchingERK14ChannelAssigns16GfxPrimitiveType($this,$channels,$topology) {
 $this = $this|0;
 $channels = $channels|0;
 $topology = $topology|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[((598504 + 76|0))>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[628256>>2]|0;
  HEAP32[$0>>2] = $3;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $4 = (__Z15malloc_internaljj10MemLabelIdiPKci(64000,32,$$byval_copy,0,598360,642)|0);
  HEAP32[((598504 + 76|0))>>2] = $4;
 }
 $5 = (+_emscripten_get_now());
 $6 = $5 * 1.0E+6;
 $7 = (~~$6)>>>0;
 $8 = +Math_abs($6) >= 1.0 ? $6 > 0.0 ? (Math_min(+Math_floor($6 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($6 - +(~~$6 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $9 = ((598504 + 8|0));
 $10 = $9;
 HEAP32[$10>>2] = $7;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 dest=((598504 + 16|0))+0|0; src=$channels+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[((598504 + 52|0))>>2] = 0;
 HEAP32[((598504 + 56|0))>>2] = 0;
 HEAP32[((598504 + 60|0))>>2] = 0;
 HEAP32[((598504 + 64|0))>>2] = $topology;
 HEAP32[((598504 + 68|0))>>2] = -1;
 HEAP32[((598504 + 72|0))>>2] = 0;
 HEAP8[598504>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice15StaticBatchMeshEjjPKtj($this,$firstVertex,$vertexCount,$indices,$indexCount) {
 $this = $this|0;
 $firstVertex = $firstVertex|0;
 $vertexCount = $vertexCount|0;
 $indices = $indices|0;
 $indexCount = $indexCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((598504 + 56|0))>>2]|0;
 $1 = (($0) + ($vertexCount))|0;
 HEAP32[((598504 + 56|0))>>2] = $1;
 $2 = HEAP32[((598504 + 68|0))>>2]|0;
 $3 = ($2>>>0)>($firstVertex>>>0);
 $4 = $3 ? $firstVertex : $2;
 HEAP32[((598504 + 68|0))>>2] = $4;
 $5 = (($vertexCount) + ($firstVertex))|0;
 $6 = HEAP32[((598504 + 72|0))>>2]|0;
 $7 = ($6>>>0)<($5>>>0);
 $8 = $7 ? $5 : $6;
 HEAP32[((598504 + 72|0))>>2] = $8;
 $9 = HEAP32[((598504 + 64|0))>>2]|0;
 $10 = ($9|0)==(1);
 $11 = HEAP32[((598504 + 76|0))>>2]|0;
 __Z17AppendMeshIndicesPtRjPKtjb($11,((598504 + 52|0)),$indices,$indexCount,$10);
 $12 = HEAP32[((598504 + 60|0))>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[((598504 + 60|0))>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17EndStaticBatchingEPK18VertexStreamSourcejP17VertexDeclarationRK10Matrix4x4fi($this,$vertexStreams,$vertexStreamCount,$vertexDecl,$matrix,$sourceChannels) {
 $this = $this|0;
 $vertexStreams = $vertexStreams|0;
 $vertexStreamCount = $vertexStreamCount|0;
 $vertexDecl = $vertexDecl|0;
 $matrix = $matrix|0;
 $sourceChannels = $sourceChannels|0;
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$2 & 4095]($this,$matrix,0);
 $3 = HEAP32[((598504 + 72|0))>>2]|0;
 $4 = HEAP32[((598504 + 68|0))>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 304|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[((598504 + 76|0))>>2]|0;
 $10 = HEAP32[((598504 + 52|0))>>2]|0;
 $11 = HEAP32[((598504 + 64|0))>>2]|0;
 FUNCTION_TABLE_viiiiiiiiii[$8 & 15]($this,$9,$10,$11,$vertexStreams,$vertexStreamCount,$4,$5,$vertexDecl,((598504 + 16|0)));
 $12 = (+_emscripten_get_now());
 $13 = $12 * 1.0E+6;
 $14 = (~~$13)>>>0;
 $15 = +Math_abs($13) >= 1.0 ? $13 > 0.0 ? (Math_min(+Math_floor($13 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($13 - +(~~$13 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $16 = ((598504 + 8|0));
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (_i64Subtract(($14|0),($15|0),($18|0),($21|0))|0);
 $23 = tempRet0;
 $24 = HEAP32[((598504 + 52|0))>>2]|0;
 $25 = HEAP32[((598504 + 64|0))>>2]|0;
 switch ($25|0) {
 case 1:  {
  $27 = (($24) + -2)|0;
  $$0$i = $27;
  break;
 }
 case 5:  {
  $$0$i = $24;
  break;
 }
 case 0:  {
  $26 = (($24|0) / 3)&-1;
  $$0$i = $26;
  break;
 }
 case 2:  {
  $28 = (($24|0) / 4)&-1;
  $$$i = $28 << 1;
  $$0$i = $$$i;
  break;
 }
 case 3:  {
  $29 = (($24|0) / 2)&-1;
  $$0$i = $29;
  break;
 }
 case 4:  {
  $30 = (($24) + -1)|0;
  $$0$i = $30;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $31 = (($this) + 5544|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  HEAP8[598504>>0] = 0;
  STACKTOP = sp;return;
 }
 $34 = HEAP32[((598504 + 60|0))>>2]|0;
 $35 = HEAP32[((598504 + 56|0))>>2]|0;
 $36 = (($this) + 5360|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $39 = (($this) + 5364|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($34))|0;
 HEAP32[$39>>2] = $41;
 $42 = (($this) + 5384|0);
 $43 = $42;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (_i64Add(($22|0),($23|0),($45|0),($48|0))|0);
 $50 = tempRet0;
 $51 = $42;
 $52 = $51;
 HEAP32[$52>>2] = $49;
 $53 = (($51) + 4)|0;
 $54 = $53;
 HEAP32[$54>>2] = $50;
 $55 = (($this) + 5368|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + ($$0$i))|0;
 HEAP32[$55>>2] = $57;
 $58 = (($this) + 5372|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + ($35))|0;
 HEAP32[$58>>2] = $60;
 HEAP8[598504>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20BeginDynamicBatchingERK14ChannelAssignsjbjP17VertexDeclarationjj16GfxPrimitiveType($this,$shaderChannels,$channelsMask,$addWhiteColor,$stride,$vertexDecl,$maxVertices,$maxIndices,$topology) {
 $this = $this|0;
 $shaderChannels = $shaderChannels|0;
 $channelsMask = $channelsMask|0;
 $addWhiteColor = $addWhiteColor|0;
 $stride = $stride|0;
 $vertexDecl = $vertexDecl|0;
 $maxVertices = $maxVertices|0;
 $maxIndices = $maxIndices|0;
 $topology = $topology|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0.0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (+_emscripten_get_now());
 $1 = $0 * 1.0E+6;
 $2 = (~~$1)>>>0;
 $3 = +Math_abs($1) >= 1.0 ? $1 > 0.0 ? (Math_min(+Math_floor($1 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($1 - +(~~$1 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $4 = ((598584 + 8|0));
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 dest=((598584 + 16|0))+0|0; src=$shaderChannels+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[((598584 + 52|0))>>2] = $channelsMask;
 $8 = $addWhiteColor&1;
 HEAP8[((598584 + 56|0))>>0] = $8;
 HEAP32[((598584 + 60|0))>>2] = $maxVertices;
 $9 = ($topology|0)==(2);
 if ($9) {
  $10 = $maxIndices >>> 2;
  $11 = ($10*6)|0;
  $12 = $11;
 } else {
  $12 = $maxIndices;
 }
 HEAP32[((598584 + 64|0))>>2] = $12;
 HEAP32[((598584 + 68|0))>>2] = 0;
 HEAP32[((598584 + 72|0))>>2] = 0;
 HEAP32[((598584 + 76|0))>>2] = 0;
 HEAP32[((598584 + 80|0))>>2] = $topology;
 HEAP32[((598584 + 84|0))>>2] = $stride;
 HEAP32[((598584 + 96|0))>>2] = $vertexDecl;
 $13 = (($this) + 5984|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $21 = $14;$25 = $stride;$26 = $12;
  $20 = HEAP32[$21>>2]|0;
  $22 = (($20) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $9 ? 0 : $topology;
  $27 = (FUNCTION_TABLE_iiiiiiii[$23 & 127]($21,$25,$maxVertices,$26,$24,((598584 + 88|0)),((598584 + 92|0)))|0);
  $28 = $27&1;
  HEAP8[598584>>0] = $28;
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = (($16) + 792|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 4095]($this)|0);
 HEAP32[$13>>2] = $19;
 $$pre = HEAP32[((598584 + 84|0))>>2]|0;
 $$pre1 = HEAP32[((598584 + 64|0))>>2]|0;
 $21 = $19;$25 = $$pre;$26 = $$pre1;
 $20 = HEAP32[$21>>2]|0;
 $22 = (($20) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $9 ? 0 : $topology;
 $27 = (FUNCTION_TABLE_iiiiiiii[$23 & 127]($21,$25,$maxVertices,$26,$24,((598584 + 88|0)),((598584 + 92|0)))|0);
 $28 = $27&1;
 HEAP8[598584>>0] = $28;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16DynamicBatchMeshERK10Matrix4x4fRK16VertexBufferDatajjPKtj($this,$matrix,$vertices,$firstVertex,$vertexCount,$indices,$indexCount) {
 $this = $this|0;
 $matrix = $matrix|0;
 $vertices = $vertices|0;
 $firstVertex = $firstVertex|0;
 $vertexCount = $vertexCount|0;
 $indices = $indices|0;
 $indexCount = $indexCount|0;
 var $$02 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$01 = 0, $outIndexCount$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[((598584 + 80|0))>>2]|0;
 $3 = ($2|0)==(2);
 if ($3) {
  $4 = $indexCount >>> 2;
  $5 = ($4*6)|0;
  $6 = ($4*12)|0;
  $7 = HEAP32[628512>>2]|0;
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $8 = (__Z15malloc_internaljj10MemLabelIdiPKci($6,16,$$byval_copy1,0,598360,740)|0);
  $9 = ($4|0)==(0);
  if (!($9)) {
   $$02 = $indices;$i$01 = 0;
   while(1) {
    $10 = HEAP16[$$02>>1]|0;
    $11 = ($i$01*6)|0;
    $12 = (($8) + ($11<<1)|0);
    HEAP16[$12>>1] = $10;
    $13 = (($$02) + 2|0);
    $14 = HEAP16[$13>>1]|0;
    $15 = $11 | 1;
    $16 = (($8) + ($15<<1)|0);
    HEAP16[$16>>1] = $14;
    $17 = (($$02) + 4|0);
    $18 = HEAP16[$17>>1]|0;
    $19 = (($11) + 2)|0;
    $20 = (($8) + ($19<<1)|0);
    HEAP16[$20>>1] = $18;
    $21 = HEAP16[$$02>>1]|0;
    $22 = (($11) + 3)|0;
    $23 = (($8) + ($22<<1)|0);
    HEAP16[$23>>1] = $21;
    $24 = HEAP16[$17>>1]|0;
    $25 = (($11) + 4)|0;
    $26 = (($8) + ($25<<1)|0);
    HEAP16[$26>>1] = $24;
    $27 = (($$02) + 6|0);
    $28 = HEAP16[$27>>1]|0;
    $29 = (($11) + 5)|0;
    $30 = (($8) + ($29<<1)|0);
    HEAP16[$30>>1] = $28;
    $31 = (($$02) + 8|0);
    $32 = (($i$01) + 1)|0;
    $33 = ($32>>>0)<($4>>>0);
    if ($33) {
     $$02 = $31;$i$01 = $32;
    } else {
     break;
    }
   }
  }
  $34 = HEAP32[((598584 + 92|0))>>2]|0;
  $35 = HEAP32[((598584 + 68|0))>>2]|0;
  $36 = (__Z16TransformIndicesPtPKvjjjjb($34,$8,0,$5,$firstVertex,$35,0)|0);
  $37 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $37;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($8,$$byval_copy1);
  $outIndexCount$0 = $36;
 } else {
  $38 = HEAP32[((598584 + 92|0))>>2]|0;
  $39 = HEAP32[((598584 + 68|0))>>2]|0;
  $40 = ($2|0)==(1);
  $41 = (__Z16TransformIndicesPtPKvjjjjb($38,$indices,0,$indexCount,$firstVertex,$39,$40)|0);
  $outIndexCount$0 = $41;
 }
 $42 = HEAP32[((598584 + 88|0))>>2]|0;
 $43 = HEAP32[((598584 + 52|0))>>2]|0;
 $44 = HEAP8[((598584 + 56|0))>>0]|0;
 $45 = ($44<<24>>24)!=(0);
 $46 = (__Z17TransformVerticesPhRK10Matrix4x4fRK16VertexBufferDatajjjb($42,$matrix,$vertices,$firstVertex,$vertexCount,$43,$45)|0);
 $47 = HEAP32[((598584 + 92|0))>>2]|0;
 $48 = (($47) + ($outIndexCount$0<<1)|0);
 HEAP32[((598584 + 92|0))>>2] = $48;
 $49 = HEAP32[((598584 + 84|0))>>2]|0;
 $50 = Math_imul($49, $46)|0;
 $51 = HEAP32[((598584 + 88|0))>>2]|0;
 $52 = (($51) + ($50)|0);
 HEAP32[((598584 + 88|0))>>2] = $52;
 $53 = HEAP32[((598584 + 72|0))>>2]|0;
 $54 = (($53) + ($outIndexCount$0))|0;
 HEAP32[((598584 + 72|0))>>2] = $54;
 $55 = HEAP32[((598584 + 68|0))>>2]|0;
 $56 = (($55) + ($46))|0;
 HEAP32[((598584 + 68|0))>>2] = $56;
 $57 = HEAP32[((598584 + 76|0))>>2]|0;
 $58 = (($57) + 1)|0;
 HEAP32[((598584 + 76|0))>>2] = $58;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18EndDynamicBatchingE13TransformType($this,$transformType) {
 $this = $this|0;
 $transformType = $transformType|0;
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5984|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 792|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 4095]($this)|0);
  HEAP32[$0>>2] = $6;
  $8 = $6;
 } else {
  $8 = $1;
 }
 $7 = HEAP32[$8>>2]|0;
 $9 = (($7) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[((598584 + 68|0))>>2]|0;
 $12 = HEAP32[((598584 + 72|0))>>2]|0;
 FUNCTION_TABLE_viii[$10 & 4095]($8,$11,$12);
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 92|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_viii[$15 & 4095]($this,616552,$transformType);
 $16 = HEAP32[$0>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $18 = HEAP32[$this>>2]|0;
  $19 = (($18) + 792|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_ii[$20 & 4095]($this)|0);
  HEAP32[$0>>2] = $21;
  $23 = $21;
 } else {
  $23 = $16;
 }
 $22 = HEAP32[$23>>2]|0;
 $24 = (($22) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[((598584 + 96|0))>>2]|0;
 FUNCTION_TABLE_viii[$25 & 4095]($23,((598584 + 16|0)),$26);
 $27 = (+_emscripten_get_now());
 $28 = $27 * 1.0E+6;
 $29 = (~~$28)>>>0;
 $30 = +Math_abs($28) >= 1.0 ? $28 > 0.0 ? (Math_min(+Math_floor($28 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($28 - +(~~$28 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $31 = ((598584 + 8|0));
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (_i64Subtract(($29|0),($30|0),($33|0),($36|0))|0);
 $38 = tempRet0;
 $39 = HEAP32[((598584 + 72|0))>>2]|0;
 $40 = HEAP32[((598584 + 80|0))>>2]|0;
 switch ($40|0) {
 case 1:  {
  $42 = (($39) + -2)|0;
  $$0$i = $42;
  break;
 }
 case 2:  {
  $43 = (($39|0) / 4)&-1;
  $$$i = $43 << 1;
  $$0$i = $$$i;
  break;
 }
 case 5:  {
  $$0$i = $39;
  break;
 }
 case 0:  {
  $41 = (($39|0) / 3)&-1;
  $$0$i = $41;
  break;
 }
 case 3:  {
  $44 = (($39|0) / 2)&-1;
  $$0$i = $44;
  break;
 }
 case 4:  {
  $45 = (($39) + -1)|0;
  $$0$i = $45;
  break;
 }
 default: {
  $$0$i = 0;
 }
 }
 $46 = (($this) + 5544|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = ($47<<24>>24)==(0);
 if ($48) {
  HEAP8[598584>>0] = 0;
  STACKTOP = sp;return;
 }
 $49 = HEAP32[((598584 + 76|0))>>2]|0;
 $50 = HEAP32[((598584 + 68|0))>>2]|0;
 $51 = (($this) + 5360|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 1)|0;
 HEAP32[$51>>2] = $53;
 $54 = (($this) + 5364|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + ($49))|0;
 HEAP32[$54>>2] = $56;
 $57 = (($this) + 5384|0);
 $58 = $57;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = (($58) + 4)|0;
 $62 = $61;
 $63 = HEAP32[$62>>2]|0;
 $64 = (_i64Add(($37|0),($38|0),($60|0),($63|0))|0);
 $65 = tempRet0;
 $66 = $57;
 $67 = $66;
 HEAP32[$67>>2] = $64;
 $68 = (($66) + 4)|0;
 $69 = $68;
 HEAP32[$69>>2] = $65;
 $70 = (($this) + 5368|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + ($$0$i))|0;
 HEAP32[$70>>2] = $72;
 $73 = (($this) + 5372|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($74) + ($50))|0;
 HEAP32[$73>>2] = $75;
 HEAP8[598584>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice22DynamicBatchBillboardsEPKPK9BillboardiPfi($this,$billboards,$numBillboards,$billboardInstances,$instanceBufferSize) {
 $this = $this|0;
 $billboards = $billboards|0;
 $numBillboards = $numBillboards|0;
 $billboardInstances = $billboardInstances|0;
 $instanceBufferSize = $instanceBufferSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $batchedIndices = 0, $batchedVertices = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $batchedVertices = sp + 4|0;
 $batchedIndices = sp;
 $0 = HEAP32[((598584 + 88|0))>>2]|0;
 $1 = HEAP32[((598584 + 92|0))>>2]|0;
 $2 = HEAP32[((598584 + 68|0))>>2]|0;
 $3 = (__Z19TransformBillboardsPhPtjPKPK9BillboardiPfiPjS7_($0,$1,$2,$billboards,$numBillboards,$billboardInstances,$instanceBufferSize,$batchedVertices,$batchedIndices)|0);
 $4 = HEAP32[$batchedVertices>>2]|0;
 $5 = HEAP32[((598584 + 84|0))>>2]|0;
 $6 = Math_imul($5, $4)|0;
 $7 = HEAP32[((598584 + 88|0))>>2]|0;
 $8 = (($7) + ($6)|0);
 HEAP32[((598584 + 88|0))>>2] = $8;
 $9 = HEAP32[((598584 + 68|0))>>2]|0;
 $10 = (($9) + ($4))|0;
 HEAP32[((598584 + 68|0))>>2] = $10;
 $11 = HEAP32[$batchedIndices>>2]|0;
 $12 = HEAP32[((598584 + 92|0))>>2]|0;
 $13 = (($12) + ($11<<1)|0);
 HEAP32[((598584 + 92|0))>>2] = $13;
 $14 = HEAP32[((598584 + 72|0))>>2]|0;
 $15 = (($14) + ($11))|0;
 HEAP32[((598584 + 72|0))>>2] = $15;
 $16 = HEAP32[((598584 + 76|0))>>2]|0;
 $17 = (($16) + ($3))|0;
 HEAP32[((598584 + 76|0))>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18DynamicBatchSpriteEPK10Matrix4x4fPK12SpriteVertexjPKtj11ColorRGBA32($this,$matrix,$srcVertices,$vertexCount,$srcIndices,$indexCount,$color) {
 $this = $this|0;
 $matrix = $matrix|0;
 $srcVertices = $srcVertices|0;
 $vertexCount = $vertexCount|0;
 $srcIndices = $srcIndices|0;
 $indexCount = $indexCount|0;
 $color = $color|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[((598584 + 88|0))>>2]|0;
 $2 = HEAP32[((598584 + 92|0))>>2]|0;
 $3 = HEAP32[((598584 + 52|0))>>2]|0;
 $4 = HEAP32[$color>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = HEAP32[((598584 + 68|0))>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z15TransformSpritePhPtjPK10Matrix4x4fPK12SpriteVertexjPKtj11ColorRGBA32j($1,$2,$3,$matrix,$srcVertices,$vertexCount,$srcIndices,$indexCount,$tmpcast$byval_copy,$5);
 $6 = HEAP32[((598584 + 92|0))>>2]|0;
 $7 = (($6) + ($indexCount<<1)|0);
 HEAP32[((598584 + 92|0))>>2] = $7;
 $8 = HEAP32[((598584 + 84|0))>>2]|0;
 $9 = Math_imul($8, $vertexCount)|0;
 $10 = HEAP32[((598584 + 88|0))>>2]|0;
 $11 = (($10) + ($9)|0);
 HEAP32[((598584 + 88|0))>>2] = $11;
 $12 = HEAP32[((598584 + 72|0))>>2]|0;
 $13 = (($12) + ($indexCount))|0;
 HEAP32[((598584 + 72|0))>>2] = $13;
 $14 = HEAP32[((598584 + 68|0))>>2]|0;
 $15 = (($14) + ($vertexCount))|0;
 HEAP32[((598584 + 68|0))>>2] = $15;
 $16 = HEAP32[((598584 + 76|0))>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[((598584 + 76|0))>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16AddBatchingStatsEiii($this,$batchedTris,$batchedVerts,$batchedCalls) {
 $this = $this|0;
 $batchedTris = $batchedTris|0;
 $batchedVerts = $batchedVerts|0;
 $batchedCalls = $batchedCalls|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5544|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 5360|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 HEAP32[$3>>2] = $5;
 $6 = (($this) + 5364|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($batchedCalls))|0;
 HEAP32[$6>>2] = $8;
 $9 = (($this) + 5368|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($batchedTris))|0;
 HEAP32[$9>>2] = $11;
 $12 = (($this) + 5372|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($batchedVerts))|0;
 HEAP32[$12>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice21ReleaseSharedMeshDataEP14SharedMeshData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628248>>2]|0;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$data>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 4095]($data);
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($data,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice24ReleaseSharedTextureDataEP17SharedTextureData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628264>>2]|0;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$data>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 4095]($data);
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($data,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice15CreateTextureIDEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[598688>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[598688>>2] = $1;
 $2 = HEAP32[598688>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN9GfxDevice13FreeTextureIDE9TextureID($this,$texture) {
 $this = $this|0;
 $texture = $texture|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice21RegisterNativeTextureE9TextureIDi($this,$texture,$nativeTex) {
 $this = $this|0;
 $texture = $texture|0;
 $nativeTex = $nativeTex|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i = sp + 32|0;
 $0 = sp + 24|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = HEAP32[$texture>>2]|0;
 HEAP32[$2>>2] = $3;
 $4 = HEAP32[((599640 + 36|0))>>2]|0;
 $5 = HEAP32[((599640 + 4|0))>>2]|0;
 $6 = ($4|0)==($5|0);
 do {
  if ($6) {
   $7 = HEAP32[((599640 + 28|0))>>2]|0;
   $8 = HEAP32[((599640 + 32|0))>>2]|0;
   $9 = (($7) + ($8<<3)|0);
   $17 = $7;$18 = $8;$20 = $9;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i,599640,$2);
   $10 = HEAP32[$pos$i$i$i>>2]|0;
   $11 = ($10|0)==(-1);
   $12 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($11) {
    $13 = HEAP32[((599640 + 32|0))>>2]|0;
    $14 = (($12) + ($13<<3)|0);
    $17 = $12;$18 = $13;$20 = $14;
    break;
   } else {
    $15 = (($12) + ($10<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $17 = $12;$18 = $$pre$i;$20 = $15;
    break;
   }
  }
 } while(0);
 $16 = (($17) + ($18<<3)|0);
 $19 = ($20|0)==($16|0);
 if ($19) {
  $22 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $22;
  $23 = (($0) + 4|0);
  HEAP32[$23>>2] = $nativeTex;
  __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj(599640,1,0);
  __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS4_($1,599640,$0);
  STACKTOP = sp;return;
 } else {
  $21 = (($20) + 4|0);
  HEAP32[$21>>2] = $nativeTex;
  STACKTOP = sp;return;
 }
}
function __ZN9GfxDevice23UnregisterNativeTextureE9TextureID($this,$texture) {
 $this = $this|0;
 $texture = $texture|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$texture>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[((599640 + 36|0))>>2]|0;
 $3 = HEAP32[((599640 + 4|0))>>2]|0;
 $4 = ($2|0)==($3|0);
 do {
  if ($4) {
   $5 = HEAP32[((599640 + 28|0))>>2]|0;
   $6 = HEAP32[((599640 + 32|0))>>2]|0;
   $7 = (($5) + ($6<<3)|0);
   $15 = $5;$16 = $6;$18 = $7;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i$i,599640,$0);
   $8 = HEAP32[$pos$i$i$i$i>>2]|0;
   $9 = ($8|0)==(-1);
   $10 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($9) {
    $11 = HEAP32[((599640 + 32|0))>>2]|0;
    $12 = (($10) + ($11<<3)|0);
    $15 = $10;$16 = $11;$18 = $12;
    break;
   } else {
    $13 = (($10) + ($8<<3)|0);
    $$pre$i$i$i = HEAP32[((599640 + 32|0))>>2]|0;
    $15 = $10;$16 = $$pre$i$i$i;$18 = $13;
    break;
   }
  }
 } while(0);
 $14 = (($15) + ($16<<3)|0);
 $17 = ($18|0)==($14|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = ((599640 + 12|0));
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + 4)|0;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = $18;
  $27 = $26;
  HEAP32[$27>>2] = $22;
  $28 = (($26) + 4)|0;
  $29 = $28;
  HEAP32[$29>>2] = $25;
 }
 $30 = HEAP32[((599640 + 4|0))>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[((599640 + 4|0))>>2] = $31;
 HEAP8[((599640 + 48|0))>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice21CreateComputeBufferIDEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[598696>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[598696>>2] = $1;
 $2 = HEAP32[598696>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN9GfxDevice19FreeComputeBufferIDE15ComputeBufferID($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice15ResetFrameStatsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5320|0);
 __ZN14GfxDeviceStats10ResetFrameEv($0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice15BeginFrameStatsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5320|0);
 __ZN14GfxDeviceStats15BeginFrameStatsEv($0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice13EndFrameStatsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5320|0);
 __ZN14GfxDeviceStats19EndClientFrameStatsEv($0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice13SaveDrawStatsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5552|0);
 $1 = (($this) + 5320|0);
 __ZN14GfxDeviceStats16CopyAllDrawStatsERKS_($0,$1);
 __ZN14GfxDeviceStats15CopyClientStatsERKS_($0,$1);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16RestoreDrawStatsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5320|0);
 $1 = (($this) + 5552|0);
 __ZN14GfxDeviceStats16CopyAllDrawStatsERKS_($0,$1);
 __ZN14GfxDeviceStats15CopyClientStatsERKS_($0,$1);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16SynchronizeStatsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN19GfxThreadableDevice20SetShadersMainThreadEPPN9ShaderLab10SubProgramEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($this,$programs,$props,$passContext) {
 $this = $this|0;
 $programs = $programs|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(598704,0,598360,946,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice21CommonReloadResourcesEj($flags) {
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flags & 4;
 $1 = ($0|0)==(0);
 if (!($1)) {
  __ZN7Texture9ReloadAllEbbb(1,1,0);
 }
 $2 = $flags & 2;
 $3 = ($2|0)==(0);
 if (!($3)) {
  __ZN6Shader16ReloadAllShadersEv();
 }
 $4 = $flags & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 __ZN13RenderTexture10ReleaseAllEv();
 STACKTOP = sp;return;
}
function __ZNK9GfxDevice31CalculateDeviceProjectionMatrixER10Matrix4x4fbb($this,$m,$usesOpenGLTextureCoords,$invertY) {
 $this = $this|0;
 $m = $m|0;
 $usesOpenGLTextureCoords = $usesOpenGLTextureCoords|0;
 $invertY = $invertY|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 if ($usesOpenGLTextureCoords) {
  STACKTOP = sp;return;
 }
 if ($invertY) {
  $0 = (($m) + 4|0);
  $1 = Math_fround(HEAPF32[$0>>2]);
  $2 = Math_fround(-$1);
  HEAPF32[$0>>2] = $2;
  $3 = (($m) + 20|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = Math_fround(-$4);
  HEAPF32[$3>>2] = $5;
  $6 = (($m) + 36|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround(-$7);
  HEAPF32[$6>>2] = $8;
  $9 = (($m) + 52|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround(-$10);
  HEAPF32[$9>>2] = $11;
 }
 $12 = (($m) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * Math_fround(0.5));
 $15 = (($m) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * Math_fround(0.5));
 $18 = Math_fround($14 + $17);
 HEAPF32[$12>>2] = $18;
 $19 = (($m) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * Math_fround(0.5));
 $22 = (($m) + 28|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * Math_fround(0.5));
 $25 = Math_fround($21 + $24);
 HEAPF32[$19>>2] = $25;
 $26 = (($m) + 40|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 * Math_fround(0.5));
 $29 = (($m) + 44|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * Math_fround(0.5));
 $32 = Math_fround($28 + $31);
 HEAPF32[$26>>2] = $32;
 $33 = (($m) + 56|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * Math_fround(0.5));
 $36 = (($m) + 60|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * Math_fround(0.5));
 $39 = Math_fround($35 + $38);
 HEAPF32[$33>>2] = $39;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice25SetInvertProjectionMatrixEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5924|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $enable&1;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $enable&1;
 HEAP8[$0>>0] = $5;
 $6 = $enable ? Math_fround(-1.0) : Math_fround(1.0);
 $7 = (($this) + 580|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($this) + 2808|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround(-$9);
 HEAPF32[$8>>2] = $10;
 $11 = (($this) + 2840|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(-$12);
 HEAPF32[$11>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice22SetupVertexLightParamsEiRK14GfxVertexLight($this,$light,$data) {
 $this = $this|0;
 $light = $light|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0);
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0;
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($light) + 8)|0;
 $1 = ((($this) + ($0<<4)|0) + 4|0);
 $2 = (($light) + 16)|0;
 $3 = ((($this) + ($2<<4)|0) + 4|0);
 $4 = (($light) + 24)|0;
 $5 = ((($this) + ($4<<4)|0) + 4|0);
 $6 = (($data) + 32|0);
 $7 = ((($this) + ($light<<4)|0) + 4|0);
 ;HEAP32[$7+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$6+12>>2]|0;
 $8 = (($data) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(1);
 $11 = (($this) + 2724|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(HEAPF32[$data>>2]);
 $14 = Math_fround($12 * $13);
 $15 = (($this) + 2740|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($data) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 + $19);
 $21 = (($this) + 2756|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($data) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 * $24);
 $26 = Math_fround($20 + $25);
 if ($10) {
  $27 = (($this) + 2728|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround($13 * $28);
  $30 = (($this) + 2744|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($18 * $31);
  $33 = Math_fround($29 + $32);
  $34 = (($this) + 2760|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($24 * $35);
  $37 = Math_fround($33 + $36);
  $38 = (($this) + 2732|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($13 * $39);
  $41 = (($this) + 2748|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround($18 * $42);
  $44 = Math_fround($40 + $43);
  $45 = (($this) + 2764|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($24 * $46);
  $48 = Math_fround($44 + $47);
  $49 = Math_fround(-$26);
  $50 = Math_fround(-$37);
  $51 = Math_fround(-$48);
  HEAPF32[$1>>2] = $49;
  $52 = ((($this) + ($0<<4)|0) + 8|0);
  HEAPF32[$52>>2] = $50;
  $53 = ((($this) + ($0<<4)|0) + 12|0);
  HEAPF32[$53>>2] = $51;
  $54 = ((($this) + ($0<<4)|0) + 16|0);
  HEAPF32[$54>>2] = Math_fround(0.0);
 } else {
  $55 = (($this) + 2772|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($26 + $56);
  $58 = (($this) + 2728|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($13 * $59);
  $61 = (($this) + 2744|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = Math_fround($18 * $62);
  $64 = Math_fround($60 + $63);
  $65 = (($this) + 2760|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($24 * $66);
  $68 = Math_fround($64 + $67);
  $69 = (($this) + 2776|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($70 + $68);
  $72 = (($this) + 2732|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = Math_fround($13 * $73);
  $75 = (($this) + 2748|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($18 * $76);
  $78 = Math_fround($74 + $77);
  $79 = (($this) + 2764|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = Math_fround($24 * $80);
  $82 = Math_fround($78 + $81);
  $83 = (($this) + 2780|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = Math_fround($84 + $82);
  HEAPF32[$1>>2] = $57;
  $86 = ((($this) + ($0<<4)|0) + 8|0);
  HEAPF32[$86>>2] = $71;
  $87 = ((($this) + ($0<<4)|0) + 12|0);
  HEAPF32[$87>>2] = $85;
  $88 = ((($this) + ($0<<4)|0) + 16|0);
  HEAPF32[$88>>2] = Math_fround(1.0);
 }
 $89 = (($data) + 48|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($90 * $90);
 $92 = (($data) + 56|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = $93 > Math_fround(0.0);
 if (!($94)) {
  HEAPF32[$3>>2] = Math_fround(0.0);
  $154 = ((($this) + ($2<<4)|0) + 8|0);
  HEAPF32[$154>>2] = Math_fround(0.0);
  $155 = ((($this) + ($2<<4)|0) + 12|0);
  HEAPF32[$155>>2] = Math_fround(1.0);
  $156 = ((($this) + ($2<<4)|0) + 16|0);
  HEAPF32[$156>>2] = Math_fround(0.0);
  $157 = (($data) + 52|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  HEAPF32[$5>>2] = Math_fround(-1.0);
  $159 = ((($this) + ($4<<4)|0) + 8|0);
  HEAPF32[$159>>2] = Math_fround(1.0);
  $160 = ((($this) + ($4<<4)|0) + 12|0);
  HEAPF32[$160>>2] = $158;
  $161 = ((($this) + ($4<<4)|0) + 16|0);
  HEAPF32[$161>>2] = $91;
  STACKTOP = sp;return;
 }
 $95 = Math_fround(HEAPF32[$11>>2]);
 $96 = (($data) + 16|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($95 * $97);
 $99 = Math_fround(HEAPF32[$15>>2]);
 $100 = (($data) + 20|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($99 * $101);
 $103 = Math_fround($98 + $102);
 $104 = Math_fround(HEAPF32[$21>>2]);
 $105 = (($data) + 24|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($104 * $106);
 $108 = Math_fround($103 + $107);
 $109 = (($this) + 2728|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($97 * $110);
 $112 = (($this) + 2744|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($101 * $113);
 $115 = Math_fround($111 + $114);
 $116 = (($this) + 2760|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($106 * $117);
 $119 = Math_fround($115 + $118);
 $120 = (($this) + 2732|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround($97 * $121);
 $123 = (($this) + 2748|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = Math_fround($101 * $124);
 $126 = Math_fround($122 + $125);
 $127 = (($this) + 2764|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($106 * $128);
 $130 = Math_fround($126 + $129);
 $131 = Math_fround(-$108);
 $132 = Math_fround(-$119);
 $133 = Math_fround(-$130);
 HEAPF32[$3>>2] = $131;
 $134 = ((($this) + ($2<<4)|0) + 8|0);
 HEAPF32[$134>>2] = $132;
 $135 = ((($this) + ($2<<4)|0) + 12|0);
 HEAPF32[$135>>2] = $133;
 $136 = ((($this) + ($2<<4)|0) + 16|0);
 HEAPF32[$136>>2] = Math_fround(0.0);
 $137 = Math_fround(HEAPF32[$92>>2]);
 $138 = Math_fround($137 / Math_fround(360.0));
 $139 = Math_fround($138 * Math_fround(2.0));
 $140 = Math_fround($139 * Math_fround(3.14159274101257324219));
 $141 = Math_fround($140 * Math_fround(0.25));
 $142 = (Math_fround(+(Math_cos((+$141)))));
 $143 = Math_fround($140 * Math_fround(0.5));
 $144 = (Math_fround(+(Math_cos((+$143)))));
 $145 = Math_fround($142 - $144);
 $146 = $145 != Math_fround(0.0);
 if ($146) {
  $147 = Math_fround(Math_fround(1.0) / $145);
  $151 = $147;
 } else {
  $151 = Math_fround(1.0);
 }
 $148 = (($data) + 52|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 HEAPF32[$5>>2] = $144;
 $150 = ((($this) + ($4<<4)|0) + 8|0);
 HEAPF32[$150>>2] = $151;
 $152 = ((($this) + ($4<<4)|0) + 12|0);
 HEAPF32[$152>>2] = $149;
 $153 = ((($this) + ($4<<4)|0) + 16|0);
 HEAPF32[$153>>2] = $91;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice14ImmediateShapeEffffNS_18ImmediateShapeTypeE($this,$x,$y,$z,$scale,$shape) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 $scale = Math_fround($scale);
 $shape = $shape|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0;
 var $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0);
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 if ((($shape|0) == 1)) {
  $87 = Math_fround($scale * Math_fround(1.25840795040130615234));
  $88 = HEAP32[$this>>2]|0;
  $89 = (($88) + 580|0);
  $90 = HEAP32[$89>>2]|0;
  FUNCTION_TABLE_viii[$90 & 4095]($this,0,0);
  $91 = HEAP32[$this>>2]|0;
  $92 = (($91) + 564|0);
  $93 = HEAP32[$92>>2]|0;
  FUNCTION_TABLE_vifff[$93 & 15]($this,Math_fround(0.0),Math_fround(0.0),Math_fround(0.0));
  $94 = HEAP32[$this>>2]|0;
  $95 = (($94) + 560|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = Math_fround($87 * Math_fround(0.606999993324279785156));
  $98 = Math_fround($97 + $x);
  $99 = Math_fround($87 * Math_fround(0.0));
  $100 = Math_fround($99 + $y);
  $101 = Math_fround($87 * Math_fround(0.795000016689300537109));
  $102 = Math_fround($101 + $z);
  FUNCTION_TABLE_vifff[$96 & 15]($this,$98,$100,$102);
  $103 = HEAP32[$this>>2]|0;
  $104 = (($103) + 560|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = Math_fround($87 * Math_fround(0.187999993562698364258));
  $107 = Math_fround($106 + $x);
  $108 = Math_fround($87 * Math_fround(0.577000021934509277344));
  $109 = Math_fround($108 + $y);
  FUNCTION_TABLE_vifff[$105 & 15]($this,$107,$109,$102);
  $110 = HEAP32[$this>>2]|0;
  $111 = (($110) + 560|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = Math_fround($87 * Math_fround(-0.490999996662139892578));
  $114 = Math_fround($113 + $x);
  $115 = Math_fround($87 * Math_fround(0.356999993324279785156));
  $116 = Math_fround($115 + $y);
  FUNCTION_TABLE_vifff[$112 & 15]($this,$114,$116,$102);
  $117 = HEAP32[$this>>2]|0;
  $118 = (($117) + 560|0);
  $119 = HEAP32[$118>>2]|0;
  FUNCTION_TABLE_vifff[$119 & 15]($this,$98,$100,$102);
  $120 = HEAP32[$this>>2]|0;
  $121 = (($120) + 560|0);
  $122 = HEAP32[$121>>2]|0;
  FUNCTION_TABLE_vifff[$122 & 15]($this,$114,$116,$102);
  $123 = HEAP32[$this>>2]|0;
  $124 = (($123) + 560|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = Math_fround($87 * Math_fround(-0.356999993324279785156));
  $127 = Math_fround($126 + $y);
  FUNCTION_TABLE_vifff[$125 & 15]($this,$114,$127,$102);
  $128 = HEAP32[$this>>2]|0;
  $129 = (($128) + 560|0);
  $130 = HEAP32[$129>>2]|0;
  FUNCTION_TABLE_vifff[$130 & 15]($this,$98,$100,$102);
  $131 = HEAP32[$this>>2]|0;
  $132 = (($131) + 560|0);
  $133 = HEAP32[$132>>2]|0;
  FUNCTION_TABLE_vifff[$133 & 15]($this,$114,$127,$102);
  $134 = HEAP32[$this>>2]|0;
  $135 = (($134) + 560|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = Math_fround($87 * Math_fround(-0.577000021934509277344));
  $138 = Math_fround($137 + $y);
  FUNCTION_TABLE_vifff[$136 & 15]($this,$107,$138,$102);
  $139 = HEAP32[$this>>2]|0;
  $140 = (($139) + 560|0);
  $141 = HEAP32[$140>>2]|0;
  FUNCTION_TABLE_vifff[$141 & 15]($this,$98,$100,$102);
  $142 = HEAP32[$this>>2]|0;
  $143 = (($142) + 560|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = Math_fround($87 * Math_fround(0.981999993324279785156));
  $146 = Math_fround($145 + $x);
  $147 = Math_fround($106 + $z);
  FUNCTION_TABLE_vifff[$144 & 15]($this,$146,$100,$147);
  $148 = HEAP32[$this>>2]|0;
  $149 = (($148) + 560|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = Math_fround($101 + $x);
  $152 = Math_fround($87 * Math_fround(-0.187999993562698364258));
  $153 = Math_fround($152 + $z);
  FUNCTION_TABLE_vifff[$150 & 15]($this,$151,$109,$153);
  $154 = HEAP32[$this>>2]|0;
  $155 = (($154) + 560|0);
  $156 = HEAP32[$155>>2]|0;
  FUNCTION_TABLE_vifff[$156 & 15]($this,$98,$100,$102);
  $157 = HEAP32[$this>>2]|0;
  $158 = (($157) + 560|0);
  $159 = HEAP32[$158>>2]|0;
  FUNCTION_TABLE_vifff[$159 & 15]($this,$151,$109,$153);
  $160 = HEAP32[$this>>2]|0;
  $161 = (($160) + 560|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = Math_fround($87 * Math_fround(0.303999990224838256836));
  $164 = Math_fround($163 + $x);
  $165 = Math_fround($87 * Math_fround(0.9340000152587890625));
  $166 = Math_fround($165 + $y);
  FUNCTION_TABLE_vifff[$162 & 15]($this,$164,$166,$147);
  $167 = HEAP32[$this>>2]|0;
  $168 = (($167) + 560|0);
  $169 = HEAP32[$168>>2]|0;
  FUNCTION_TABLE_vifff[$169 & 15]($this,$98,$100,$102);
  $170 = HEAP32[$this>>2]|0;
  $171 = (($170) + 560|0);
  $172 = HEAP32[$171>>2]|0;
  FUNCTION_TABLE_vifff[$172 & 15]($this,$164,$166,$147);
  $173 = HEAP32[$this>>2]|0;
  $174 = (($173) + 560|0);
  $175 = HEAP32[$174>>2]|0;
  FUNCTION_TABLE_vifff[$175 & 15]($this,$107,$109,$102);
  $176 = HEAP32[$this>>2]|0;
  $177 = (($176) + 560|0);
  $178 = HEAP32[$177>>2]|0;
  FUNCTION_TABLE_vifff[$178 & 15]($this,$107,$109,$102);
  $179 = HEAP32[$this>>2]|0;
  $180 = (($179) + 560|0);
  $181 = HEAP32[$180>>2]|0;
  FUNCTION_TABLE_vifff[$181 & 15]($this,$164,$166,$147);
  $182 = HEAP32[$this>>2]|0;
  $183 = (($182) + 560|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = Math_fround($87 * Math_fround(-0.303999990224838256836));
  $186 = Math_fround($185 + $x);
  FUNCTION_TABLE_vifff[$184 & 15]($this,$186,$166,$153);
  $187 = HEAP32[$this>>2]|0;
  $188 = (($187) + 560|0);
  $189 = HEAP32[$188>>2]|0;
  FUNCTION_TABLE_vifff[$189 & 15]($this,$107,$109,$102);
  $190 = HEAP32[$this>>2]|0;
  $191 = (($190) + 560|0);
  $192 = HEAP32[$191>>2]|0;
  FUNCTION_TABLE_vifff[$192 & 15]($this,$186,$166,$153);
  $193 = HEAP32[$this>>2]|0;
  $194 = (($193) + 560|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = Math_fround($87 * Math_fround(-0.795000016689300537109));
  $197 = Math_fround($196 + $x);
  FUNCTION_TABLE_vifff[$195 & 15]($this,$197,$109,$147);
  $198 = HEAP32[$this>>2]|0;
  $199 = (($198) + 560|0);
  $200 = HEAP32[$199>>2]|0;
  FUNCTION_TABLE_vifff[$200 & 15]($this,$107,$109,$102);
  $201 = HEAP32[$this>>2]|0;
  $202 = (($201) + 560|0);
  $203 = HEAP32[$202>>2]|0;
  FUNCTION_TABLE_vifff[$203 & 15]($this,$197,$109,$147);
  $204 = HEAP32[$this>>2]|0;
  $205 = (($204) + 560|0);
  $206 = HEAP32[$205>>2]|0;
  FUNCTION_TABLE_vifff[$206 & 15]($this,$114,$116,$102);
  $207 = HEAP32[$this>>2]|0;
  $208 = (($207) + 560|0);
  $209 = HEAP32[$208>>2]|0;
  FUNCTION_TABLE_vifff[$209 & 15]($this,$114,$116,$102);
  $210 = HEAP32[$this>>2]|0;
  $211 = (($210) + 560|0);
  $212 = HEAP32[$211>>2]|0;
  FUNCTION_TABLE_vifff[$212 & 15]($this,$197,$109,$147);
  $213 = HEAP32[$this>>2]|0;
  $214 = (($213) + 560|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = Math_fround($87 * Math_fround(-0.981999993324279785156));
  $217 = Math_fround($216 + $x);
  FUNCTION_TABLE_vifff[$215 & 15]($this,$217,$100,$153);
  $218 = HEAP32[$this>>2]|0;
  $219 = (($218) + 560|0);
  $220 = HEAP32[$219>>2]|0;
  FUNCTION_TABLE_vifff[$220 & 15]($this,$114,$116,$102);
  $221 = HEAP32[$this>>2]|0;
  $222 = (($221) + 560|0);
  $223 = HEAP32[$222>>2]|0;
  FUNCTION_TABLE_vifff[$223 & 15]($this,$217,$100,$153);
  $224 = HEAP32[$this>>2]|0;
  $225 = (($224) + 560|0);
  $226 = HEAP32[$225>>2]|0;
  FUNCTION_TABLE_vifff[$226 & 15]($this,$197,$138,$147);
  $227 = HEAP32[$this>>2]|0;
  $228 = (($227) + 560|0);
  $229 = HEAP32[$228>>2]|0;
  FUNCTION_TABLE_vifff[$229 & 15]($this,$114,$116,$102);
  $230 = HEAP32[$this>>2]|0;
  $231 = (($230) + 560|0);
  $232 = HEAP32[$231>>2]|0;
  FUNCTION_TABLE_vifff[$232 & 15]($this,$197,$138,$147);
  $233 = HEAP32[$this>>2]|0;
  $234 = (($233) + 560|0);
  $235 = HEAP32[$234>>2]|0;
  FUNCTION_TABLE_vifff[$235 & 15]($this,$114,$127,$102);
  $236 = HEAP32[$this>>2]|0;
  $237 = (($236) + 560|0);
  $238 = HEAP32[$237>>2]|0;
  FUNCTION_TABLE_vifff[$238 & 15]($this,$114,$127,$102);
  $239 = HEAP32[$this>>2]|0;
  $240 = (($239) + 560|0);
  $241 = HEAP32[$240>>2]|0;
  FUNCTION_TABLE_vifff[$241 & 15]($this,$197,$138,$147);
  $242 = HEAP32[$this>>2]|0;
  $243 = (($242) + 560|0);
  $244 = HEAP32[$243>>2]|0;
  $245 = Math_fround($87 * Math_fround(-0.9340000152587890625));
  $246 = Math_fround($245 + $y);
  FUNCTION_TABLE_vifff[$244 & 15]($this,$186,$246,$153);
  $247 = HEAP32[$this>>2]|0;
  $248 = (($247) + 560|0);
  $249 = HEAP32[$248>>2]|0;
  FUNCTION_TABLE_vifff[$249 & 15]($this,$114,$127,$102);
  $250 = HEAP32[$this>>2]|0;
  $251 = (($250) + 560|0);
  $252 = HEAP32[$251>>2]|0;
  FUNCTION_TABLE_vifff[$252 & 15]($this,$186,$246,$153);
  $253 = HEAP32[$this>>2]|0;
  $254 = (($253) + 560|0);
  $255 = HEAP32[$254>>2]|0;
  FUNCTION_TABLE_vifff[$255 & 15]($this,$164,$246,$147);
  $256 = HEAP32[$this>>2]|0;
  $257 = (($256) + 560|0);
  $258 = HEAP32[$257>>2]|0;
  FUNCTION_TABLE_vifff[$258 & 15]($this,$114,$127,$102);
  $259 = HEAP32[$this>>2]|0;
  $260 = (($259) + 560|0);
  $261 = HEAP32[$260>>2]|0;
  FUNCTION_TABLE_vifff[$261 & 15]($this,$164,$246,$147);
  $262 = HEAP32[$this>>2]|0;
  $263 = (($262) + 560|0);
  $264 = HEAP32[$263>>2]|0;
  FUNCTION_TABLE_vifff[$264 & 15]($this,$107,$138,$102);
  $265 = HEAP32[$this>>2]|0;
  $266 = (($265) + 560|0);
  $267 = HEAP32[$266>>2]|0;
  FUNCTION_TABLE_vifff[$267 & 15]($this,$107,$138,$102);
  $268 = HEAP32[$this>>2]|0;
  $269 = (($268) + 560|0);
  $270 = HEAP32[$269>>2]|0;
  FUNCTION_TABLE_vifff[$270 & 15]($this,$164,$246,$147);
  $271 = HEAP32[$this>>2]|0;
  $272 = (($271) + 560|0);
  $273 = HEAP32[$272>>2]|0;
  FUNCTION_TABLE_vifff[$273 & 15]($this,$151,$138,$153);
  $274 = HEAP32[$this>>2]|0;
  $275 = (($274) + 560|0);
  $276 = HEAP32[$275>>2]|0;
  FUNCTION_TABLE_vifff[$276 & 15]($this,$107,$138,$102);
  $277 = HEAP32[$this>>2]|0;
  $278 = (($277) + 560|0);
  $279 = HEAP32[$278>>2]|0;
  FUNCTION_TABLE_vifff[$279 & 15]($this,$151,$138,$153);
  $280 = HEAP32[$this>>2]|0;
  $281 = (($280) + 560|0);
  $282 = HEAP32[$281>>2]|0;
  FUNCTION_TABLE_vifff[$282 & 15]($this,$146,$100,$147);
  $283 = HEAP32[$this>>2]|0;
  $284 = (($283) + 560|0);
  $285 = HEAP32[$284>>2]|0;
  FUNCTION_TABLE_vifff[$285 & 15]($this,$107,$138,$102);
  $286 = HEAP32[$this>>2]|0;
  $287 = (($286) + 560|0);
  $288 = HEAP32[$287>>2]|0;
  FUNCTION_TABLE_vifff[$288 & 15]($this,$146,$100,$147);
  $289 = HEAP32[$this>>2]|0;
  $290 = (($289) + 560|0);
  $291 = HEAP32[$290>>2]|0;
  FUNCTION_TABLE_vifff[$291 & 15]($this,$98,$100,$102);
  $292 = HEAP32[$this>>2]|0;
  $293 = (($292) + 560|0);
  $294 = HEAP32[$293>>2]|0;
  $295 = Math_fround($87 * Math_fround(0.490999996662139892578));
  $296 = Math_fround($295 + $x);
  $297 = Math_fround($196 + $z);
  FUNCTION_TABLE_vifff[$294 & 15]($this,$296,$116,$297);
  $298 = HEAP32[$this>>2]|0;
  $299 = (($298) + 560|0);
  $300 = HEAP32[$299>>2]|0;
  $301 = Math_fround($152 + $x);
  FUNCTION_TABLE_vifff[$300 & 15]($this,$301,$109,$297);
  $302 = HEAP32[$this>>2]|0;
  $303 = (($302) + 560|0);
  $304 = HEAP32[$303>>2]|0;
  FUNCTION_TABLE_vifff[$304 & 15]($this,$186,$166,$153);
  $305 = HEAP32[$this>>2]|0;
  $306 = (($305) + 560|0);
  $307 = HEAP32[$306>>2]|0;
  FUNCTION_TABLE_vifff[$307 & 15]($this,$296,$116,$297);
  $308 = HEAP32[$this>>2]|0;
  $309 = (($308) + 560|0);
  $310 = HEAP32[$309>>2]|0;
  FUNCTION_TABLE_vifff[$310 & 15]($this,$186,$166,$153);
  $311 = HEAP32[$this>>2]|0;
  $312 = (($311) + 560|0);
  $313 = HEAP32[$312>>2]|0;
  FUNCTION_TABLE_vifff[$313 & 15]($this,$164,$166,$147);
  $314 = HEAP32[$this>>2]|0;
  $315 = (($314) + 560|0);
  $316 = HEAP32[$315>>2]|0;
  FUNCTION_TABLE_vifff[$316 & 15]($this,$296,$116,$297);
  $317 = HEAP32[$this>>2]|0;
  $318 = (($317) + 560|0);
  $319 = HEAP32[$318>>2]|0;
  FUNCTION_TABLE_vifff[$319 & 15]($this,$164,$166,$147);
  $320 = HEAP32[$this>>2]|0;
  $321 = (($320) + 560|0);
  $322 = HEAP32[$321>>2]|0;
  FUNCTION_TABLE_vifff[$322 & 15]($this,$151,$109,$153);
  $323 = HEAP32[$this>>2]|0;
  $324 = (($323) + 560|0);
  $325 = HEAP32[$324>>2]|0;
  FUNCTION_TABLE_vifff[$325 & 15]($this,$301,$109,$297);
  $326 = HEAP32[$this>>2]|0;
  $327 = (($326) + 560|0);
  $328 = HEAP32[$327>>2]|0;
  $329 = Math_fround($87 * Math_fround(-0.606999993324279785156));
  $330 = Math_fround($329 + $x);
  FUNCTION_TABLE_vifff[$328 & 15]($this,$330,$100,$297);
  $331 = HEAP32[$this>>2]|0;
  $332 = (($331) + 560|0);
  $333 = HEAP32[$332>>2]|0;
  FUNCTION_TABLE_vifff[$333 & 15]($this,$217,$100,$153);
  $334 = HEAP32[$this>>2]|0;
  $335 = (($334) + 560|0);
  $336 = HEAP32[$335>>2]|0;
  FUNCTION_TABLE_vifff[$336 & 15]($this,$301,$109,$297);
  $337 = HEAP32[$this>>2]|0;
  $338 = (($337) + 560|0);
  $339 = HEAP32[$338>>2]|0;
  FUNCTION_TABLE_vifff[$339 & 15]($this,$217,$100,$153);
  $340 = HEAP32[$this>>2]|0;
  $341 = (($340) + 560|0);
  $342 = HEAP32[$341>>2]|0;
  FUNCTION_TABLE_vifff[$342 & 15]($this,$197,$109,$147);
  $343 = HEAP32[$this>>2]|0;
  $344 = (($343) + 560|0);
  $345 = HEAP32[$344>>2]|0;
  FUNCTION_TABLE_vifff[$345 & 15]($this,$301,$109,$297);
  $346 = HEAP32[$this>>2]|0;
  $347 = (($346) + 560|0);
  $348 = HEAP32[$347>>2]|0;
  FUNCTION_TABLE_vifff[$348 & 15]($this,$197,$109,$147);
  $349 = HEAP32[$this>>2]|0;
  $350 = (($349) + 560|0);
  $351 = HEAP32[$350>>2]|0;
  FUNCTION_TABLE_vifff[$351 & 15]($this,$186,$166,$153);
  $352 = HEAP32[$this>>2]|0;
  $353 = (($352) + 560|0);
  $354 = HEAP32[$353>>2]|0;
  FUNCTION_TABLE_vifff[$354 & 15]($this,$330,$100,$297);
  $355 = HEAP32[$this>>2]|0;
  $356 = (($355) + 560|0);
  $357 = HEAP32[$356>>2]|0;
  FUNCTION_TABLE_vifff[$357 & 15]($this,$301,$138,$297);
  $358 = HEAP32[$this>>2]|0;
  $359 = (($358) + 560|0);
  $360 = HEAP32[$359>>2]|0;
  FUNCTION_TABLE_vifff[$360 & 15]($this,$186,$246,$153);
  $361 = HEAP32[$this>>2]|0;
  $362 = (($361) + 560|0);
  $363 = HEAP32[$362>>2]|0;
  FUNCTION_TABLE_vifff[$363 & 15]($this,$330,$100,$297);
  $364 = HEAP32[$this>>2]|0;
  $365 = (($364) + 560|0);
  $366 = HEAP32[$365>>2]|0;
  FUNCTION_TABLE_vifff[$366 & 15]($this,$186,$246,$153);
  $367 = HEAP32[$this>>2]|0;
  $368 = (($367) + 560|0);
  $369 = HEAP32[$368>>2]|0;
  FUNCTION_TABLE_vifff[$369 & 15]($this,$197,$138,$147);
  $370 = HEAP32[$this>>2]|0;
  $371 = (($370) + 560|0);
  $372 = HEAP32[$371>>2]|0;
  FUNCTION_TABLE_vifff[$372 & 15]($this,$330,$100,$297);
  $373 = HEAP32[$this>>2]|0;
  $374 = (($373) + 560|0);
  $375 = HEAP32[$374>>2]|0;
  FUNCTION_TABLE_vifff[$375 & 15]($this,$197,$138,$147);
  $376 = HEAP32[$this>>2]|0;
  $377 = (($376) + 560|0);
  $378 = HEAP32[$377>>2]|0;
  FUNCTION_TABLE_vifff[$378 & 15]($this,$217,$100,$153);
  $379 = HEAP32[$this>>2]|0;
  $380 = (($379) + 560|0);
  $381 = HEAP32[$380>>2]|0;
  FUNCTION_TABLE_vifff[$381 & 15]($this,$301,$138,$297);
  $382 = HEAP32[$this>>2]|0;
  $383 = (($382) + 560|0);
  $384 = HEAP32[$383>>2]|0;
  FUNCTION_TABLE_vifff[$384 & 15]($this,$296,$127,$297);
  $385 = HEAP32[$this>>2]|0;
  $386 = (($385) + 560|0);
  $387 = HEAP32[$386>>2]|0;
  FUNCTION_TABLE_vifff[$387 & 15]($this,$151,$138,$153);
  $388 = HEAP32[$this>>2]|0;
  $389 = (($388) + 560|0);
  $390 = HEAP32[$389>>2]|0;
  FUNCTION_TABLE_vifff[$390 & 15]($this,$301,$138,$297);
  $391 = HEAP32[$this>>2]|0;
  $392 = (($391) + 560|0);
  $393 = HEAP32[$392>>2]|0;
  FUNCTION_TABLE_vifff[$393 & 15]($this,$151,$138,$153);
  $394 = HEAP32[$this>>2]|0;
  $395 = (($394) + 560|0);
  $396 = HEAP32[$395>>2]|0;
  FUNCTION_TABLE_vifff[$396 & 15]($this,$164,$246,$147);
  $397 = HEAP32[$this>>2]|0;
  $398 = (($397) + 560|0);
  $399 = HEAP32[$398>>2]|0;
  FUNCTION_TABLE_vifff[$399 & 15]($this,$301,$138,$297);
  $400 = HEAP32[$this>>2]|0;
  $401 = (($400) + 560|0);
  $402 = HEAP32[$401>>2]|0;
  FUNCTION_TABLE_vifff[$402 & 15]($this,$164,$246,$147);
  $403 = HEAP32[$this>>2]|0;
  $404 = (($403) + 560|0);
  $405 = HEAP32[$404>>2]|0;
  FUNCTION_TABLE_vifff[$405 & 15]($this,$186,$246,$153);
  $406 = HEAP32[$this>>2]|0;
  $407 = (($406) + 560|0);
  $408 = HEAP32[$407>>2]|0;
  FUNCTION_TABLE_vifff[$408 & 15]($this,$296,$127,$297);
  $409 = HEAP32[$this>>2]|0;
  $410 = (($409) + 560|0);
  $411 = HEAP32[$410>>2]|0;
  FUNCTION_TABLE_vifff[$411 & 15]($this,$296,$116,$297);
  $412 = HEAP32[$this>>2]|0;
  $413 = (($412) + 560|0);
  $414 = HEAP32[$413>>2]|0;
  FUNCTION_TABLE_vifff[$414 & 15]($this,$151,$109,$153);
  $415 = HEAP32[$this>>2]|0;
  $416 = (($415) + 560|0);
  $417 = HEAP32[$416>>2]|0;
  FUNCTION_TABLE_vifff[$417 & 15]($this,$296,$127,$297);
  $418 = HEAP32[$this>>2]|0;
  $419 = (($418) + 560|0);
  $420 = HEAP32[$419>>2]|0;
  FUNCTION_TABLE_vifff[$420 & 15]($this,$151,$109,$153);
  $421 = HEAP32[$this>>2]|0;
  $422 = (($421) + 560|0);
  $423 = HEAP32[$422>>2]|0;
  FUNCTION_TABLE_vifff[$423 & 15]($this,$146,$100,$147);
  $424 = HEAP32[$this>>2]|0;
  $425 = (($424) + 560|0);
  $426 = HEAP32[$425>>2]|0;
  FUNCTION_TABLE_vifff[$426 & 15]($this,$296,$127,$297);
  $427 = HEAP32[$this>>2]|0;
  $428 = (($427) + 560|0);
  $429 = HEAP32[$428>>2]|0;
  FUNCTION_TABLE_vifff[$429 & 15]($this,$146,$100,$147);
  $430 = HEAP32[$this>>2]|0;
  $431 = (($430) + 560|0);
  $432 = HEAP32[$431>>2]|0;
  FUNCTION_TABLE_vifff[$432 & 15]($this,$151,$138,$153);
  $433 = HEAP32[$this>>2]|0;
  $434 = (($433) + 560|0);
  $435 = HEAP32[$434>>2]|0;
  FUNCTION_TABLE_vifff[$435 & 15]($this,$296,$116,$297);
  $436 = HEAP32[$this>>2]|0;
  $437 = (($436) + 560|0);
  $438 = HEAP32[$437>>2]|0;
  FUNCTION_TABLE_vifff[$438 & 15]($this,$296,$127,$297);
  $439 = HEAP32[$this>>2]|0;
  $440 = (($439) + 560|0);
  $441 = HEAP32[$440>>2]|0;
  FUNCTION_TABLE_vifff[$441 & 15]($this,$301,$138,$297);
  $442 = HEAP32[$this>>2]|0;
  $443 = (($442) + 560|0);
  $444 = HEAP32[$443>>2]|0;
  FUNCTION_TABLE_vifff[$444 & 15]($this,$296,$116,$297);
  $445 = HEAP32[$this>>2]|0;
  $446 = (($445) + 560|0);
  $447 = HEAP32[$446>>2]|0;
  FUNCTION_TABLE_vifff[$447 & 15]($this,$301,$138,$297);
  $448 = HEAP32[$this>>2]|0;
  $449 = (($448) + 560|0);
  $450 = HEAP32[$449>>2]|0;
  FUNCTION_TABLE_vifff[$450 & 15]($this,$330,$100,$297);
  $451 = HEAP32[$this>>2]|0;
  $452 = (($451) + 560|0);
  $453 = HEAP32[$452>>2]|0;
  FUNCTION_TABLE_vifff[$453 & 15]($this,$296,$116,$297);
  $454 = HEAP32[$this>>2]|0;
  $455 = (($454) + 560|0);
  $456 = HEAP32[$455>>2]|0;
  FUNCTION_TABLE_vifff[$456 & 15]($this,$330,$100,$297);
  $457 = HEAP32[$this>>2]|0;
  $458 = (($457) + 560|0);
  $459 = HEAP32[$458>>2]|0;
  FUNCTION_TABLE_vifff[$459 & 15]($this,$301,$109,$297);
  $460 = HEAP32[$this>>2]|0;
  $461 = (($460) + 584|0);
  $462 = HEAP32[$461>>2]|0;
  FUNCTION_TABLE_vi[$462 & 4095]($this);
  STACKTOP = sp;return;
 } else if ((($shape|0) == 0)) {
  $0 = HEAP32[$this>>2]|0;
  $1 = (($0) + 580|0);
  $2 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_viii[$2 & 4095]($this,2,0);
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 564|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vifff[$5 & 15]($this,Math_fround(0.0),Math_fround(0.0),Math_fround(0.0));
  $6 = HEAP32[$this>>2]|0;
  $7 = (($6) + 560|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = Math_fround($x + $scale);
  $10 = Math_fround($y - $scale);
  $11 = Math_fround($z - $scale);
  FUNCTION_TABLE_vifff[$8 & 15]($this,$9,$10,$11);
  $12 = HEAP32[$this>>2]|0;
  $13 = (($12) + 560|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = Math_fround($x - $scale);
  FUNCTION_TABLE_vifff[$14 & 15]($this,$15,$10,$11);
  $16 = HEAP32[$this>>2]|0;
  $17 = (($16) + 560|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = Math_fround($y + $scale);
  FUNCTION_TABLE_vifff[$18 & 15]($this,$15,$19,$11);
  $20 = HEAP32[$this>>2]|0;
  $21 = (($20) + 560|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_vifff[$22 & 15]($this,$9,$19,$11);
  $23 = HEAP32[$this>>2]|0;
  $24 = (($23) + 560|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = Math_fround($z + $scale);
  FUNCTION_TABLE_vifff[$25 & 15]($this,$15,$10,$26);
  $27 = HEAP32[$this>>2]|0;
  $28 = (($27) + 560|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vifff[$29 & 15]($this,$9,$10,$26);
  $30 = HEAP32[$this>>2]|0;
  $31 = (($30) + 560|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vifff[$32 & 15]($this,$9,$19,$26);
  $33 = HEAP32[$this>>2]|0;
  $34 = (($33) + 560|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vifff[$35 & 15]($this,$15,$19,$26);
  $36 = HEAP32[$this>>2]|0;
  $37 = (($36) + 560|0);
  $38 = HEAP32[$37>>2]|0;
  FUNCTION_TABLE_vifff[$38 & 15]($this,$15,$19,$11);
  $39 = HEAP32[$this>>2]|0;
  $40 = (($39) + 560|0);
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vifff[$41 & 15]($this,$15,$10,$11);
  $42 = HEAP32[$this>>2]|0;
  $43 = (($42) + 560|0);
  $44 = HEAP32[$43>>2]|0;
  FUNCTION_TABLE_vifff[$44 & 15]($this,$15,$10,$26);
  $45 = HEAP32[$this>>2]|0;
  $46 = (($45) + 560|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_vifff[$47 & 15]($this,$15,$19,$26);
  $48 = HEAP32[$this>>2]|0;
  $49 = (($48) + 560|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_vifff[$50 & 15]($this,$9,$10,$11);
  $51 = HEAP32[$this>>2]|0;
  $52 = (($51) + 560|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vifff[$53 & 15]($this,$9,$19,$11);
  $54 = HEAP32[$this>>2]|0;
  $55 = (($54) + 560|0);
  $56 = HEAP32[$55>>2]|0;
  FUNCTION_TABLE_vifff[$56 & 15]($this,$9,$19,$26);
  $57 = HEAP32[$this>>2]|0;
  $58 = (($57) + 560|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vifff[$59 & 15]($this,$9,$10,$26);
  $60 = HEAP32[$this>>2]|0;
  $61 = (($60) + 560|0);
  $62 = HEAP32[$61>>2]|0;
  FUNCTION_TABLE_vifff[$62 & 15]($this,$15,$10,$11);
  $63 = HEAP32[$this>>2]|0;
  $64 = (($63) + 560|0);
  $65 = HEAP32[$64>>2]|0;
  FUNCTION_TABLE_vifff[$65 & 15]($this,$9,$10,$11);
  $66 = HEAP32[$this>>2]|0;
  $67 = (($66) + 560|0);
  $68 = HEAP32[$67>>2]|0;
  FUNCTION_TABLE_vifff[$68 & 15]($this,$9,$10,$26);
  $69 = HEAP32[$this>>2]|0;
  $70 = (($69) + 560|0);
  $71 = HEAP32[$70>>2]|0;
  FUNCTION_TABLE_vifff[$71 & 15]($this,$15,$10,$26);
  $72 = HEAP32[$this>>2]|0;
  $73 = (($72) + 560|0);
  $74 = HEAP32[$73>>2]|0;
  FUNCTION_TABLE_vifff[$74 & 15]($this,$9,$19,$11);
  $75 = HEAP32[$this>>2]|0;
  $76 = (($75) + 560|0);
  $77 = HEAP32[$76>>2]|0;
  FUNCTION_TABLE_vifff[$77 & 15]($this,$15,$19,$11);
  $78 = HEAP32[$this>>2]|0;
  $79 = (($78) + 560|0);
  $80 = HEAP32[$79>>2]|0;
  FUNCTION_TABLE_vifff[$80 & 15]($this,$15,$19,$26);
  $81 = HEAP32[$this>>2]|0;
  $82 = (($81) + 560|0);
  $83 = HEAP32[$82>>2]|0;
  FUNCTION_TABLE_vifff[$83 & 15]($this,$9,$19,$26);
  $84 = HEAP32[$this>>2]|0;
  $85 = (($84) + 584|0);
  $86 = HEAP32[$85>>2]|0;
  FUNCTION_TABLE_vi[$86 & 4095]($this);
  STACKTOP = sp;return;
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(598792,0,598360,1190,32785,0,0,0);
  STACKTOP = sp;return;
 }
}
function __ZN9GfxDevice15ImmediateVertexEfff($this,$x,$y,$z) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5964|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13DrawImmediate6VertexEfff($1,$x,$y,$z);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice15ImmediateNormalEfff($this,$x,$y,$z) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5964|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13DrawImmediate6NormalEfff($1,$x,$y,$z);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice14ImmediateColorEffff($this,$r,$g,$b,$a) {
 $this = $this|0;
 $r = Math_fround($r);
 $g = Math_fround($g);
 $b = Math_fround($b);
 $a = Math_fround($a);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5964|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13DrawImmediate5ColorEffff($1,$r,$g,$b,$a);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20ImmediateTexCoordAllEfff($this,$x,$y,$z) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5964|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13DrawImmediate11TexCoordAllEfff($1,$x,$y,$z);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17ImmediateTexCoordEifff($this,$unit,$x,$y,$z) {
 $this = $this|0;
 $unit = $unit|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5964|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13DrawImmediate8TexCoordEifff($1,$unit,$x,$y,$z);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice14ImmediateBeginE16GfxPrimitiveTypePK14ChannelAssigns($this,$type,$channelAssigns) {
 $this = $this|0;
 $type = $type|0;
 $channelAssigns = $channelAssigns|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5964|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13DrawImmediate5BeginE16GfxPrimitiveTypePK14ChannelAssigns($1,$type,$channelAssigns);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice12ImmediateEndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5964|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13DrawImmediate3EndEv($1);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18GetNativeTextureIDE9TextureID($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$id>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[((599640 + 36|0))>>2]|0;
 $3 = HEAP32[((599640 + 4|0))>>2]|0;
 $4 = ($2|0)==($3|0);
 do {
  if ($4) {
   $5 = HEAP32[((599640 + 28|0))>>2]|0;
   $6 = HEAP32[((599640 + 32|0))>>2]|0;
   $7 = (($5) + ($6<<3)|0);
   $15 = $5;$16 = $6;$18 = $7;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i,599640,$0);
   $8 = HEAP32[$pos$i$i$i>>2]|0;
   $9 = ($8|0)==(-1);
   $10 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($9) {
    $11 = HEAP32[((599640 + 32|0))>>2]|0;
    $12 = (($10) + ($11<<3)|0);
    $15 = $10;$16 = $11;$18 = $12;
    break;
   } else {
    $13 = (($10) + ($8<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $15 = $10;$16 = $$pre$i;$18 = $13;
    break;
   }
  }
 } while(0);
 $14 = (($15) + ($16<<3)|0);
 $17 = ($18|0)==($14|0);
 if ($17) {
  $21 = 0;
  STACKTOP = sp;return ($21|0);
 }
 $19 = (($18) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 STACKTOP = sp;return ($21|0);
}
function __ZN9GfxDevice18InsertCustomMarkerEi($this,$marker) {
 $this = $this|0;
 $marker = $marker|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18BeforePluginRenderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17AfterPluginRenderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20SetMaxBufferedFramesEi($this,$bufferSize) {
 $this = $this|0;
 $bufferSize = $bufferSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5936|0);
 HEAP32[$0>>2] = $bufferSize;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice34SetStencilRefWhenStencilWasSkippedEi($this,$stencilRef) {
 $this = $this|0;
 $stencilRef = $stencilRef|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5920|0);
 HEAP32[$0>>2] = $stencilRef;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice13SetFFLightingEbb17ColorMaterialMode($this,$on,$separateSpecular,$colorMaterial) {
 $this = $this|0;
 $on = $on|0;
 $separateSpecular = $separateSpecular|0;
 $colorMaterial = $colorMaterial|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice13SetFFMaterialERK17GfxMaterialParams($this,$params) {
 $this = $this|0;
 $params = $params|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice10SetFFColorERK10ColorRGBAf($this,$color) {
 $this = $this|0;
 $color = $color|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice11EnableFFFogERK12GfxFogParams($this,$fog) {
 $this = $this|0;
 $fog = $fog|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice12DisableFFFogEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice19SetTextureCombinersE12ObjectHandleI20TextureCombiners_TagPvEPKN9ShaderLab13PropertySheetERKNS4_17ShaderPassContextE($this,$textureCombiners,$props,$passContext) {
 $this = $this|0;
 $textureCombiners = $textureCombiners|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice21SetConstantBufferInfoEii($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17CreateIndexBufferEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice17UpdateIndexBufferEP11IndexBuffer13GfxBufferMode14GfxBufferLabeljPKvj($this,$indexBuf,$mode,$label,$size,$indices,$flags) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 $mode = $mode|0;
 $label = $label|0;
 $size = $size|0;
 $indices = $indices|0;
 $flags = $flags|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17BeginWriteIndicesEP11IndexBufferjj($this,$indexBuf,$offset,$size) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 $offset = $offset|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice15EndWriteIndicesEP11IndexBufferj($this,$indexBuf,$bytesWritten) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 $bytesWritten = $bytesWritten|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17DeleteIndexBufferEP11IndexBuffer($this,$indexBuf) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18CreateVertexBufferEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice18UpdateVertexBufferEP12VertexBuffer13GfxBufferMode14GfxBufferLabeljPKvj($this,$vertexBuf,$mode,$label,$size,$vertices,$flags) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 $mode = $mode|0;
 $label = $label|0;
 $size = $size|0;
 $vertices = $vertices|0;
 $flags = $flags|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18BeginWriteVerticesEP12VertexBufferjj($this,$vertexBuf,$offset,$size) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 $offset = $offset|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice16EndWriteVerticesEP12VertexBufferj($this,$vertexBuf,$bytesWritten) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 $bytesWritten = $bytesWritten|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18DeleteVertexBufferEP12VertexBuffer($this,$vertexBuf) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20GetVertexDeclarationERK18VertexChannelsInfo($this,$declKey) {
 $this = $this|0;
 $declKey = $declKey|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice11DrawBuffersEP11IndexBufferPK18VertexStreamSourceiPK16DrawBuffersRangeiP17VertexDeclarationRK14ChannelAssigns($this,$indexBuf,$vertexStreams,$vertexStreamCount,$drawRanges,$drawRangeCount,$vertexDecl,$channels) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 $vertexStreams = $vertexStreams|0;
 $vertexStreamCount = $vertexStreamCount|0;
 $drawRanges = $drawRanges|0;
 $drawRangeCount = $drawRangeCount|0;
 $vertexDecl = $vertexDecl|0;
 $channels = $channels|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice23CreateGPUSkinPoseBufferEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice23DeleteGPUSkinPoseBufferEP17GPUSkinPoseBuffer($this,$poseBuffer) {
 $this = $this|0;
 $poseBuffer = $poseBuffer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20UpdateSkinPoseBufferEP17GPUSkinPoseBufferPK10Matrix4x4fi($this,$poseBuffer,$boneMatrices,$boneCount) {
 $this = $this|0;
 $poseBuffer = $poseBuffer|0;
 $boneMatrices = $boneMatrices|0;
 $boneCount = $boneCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice9SkinOnGPUERK18VertexStreamSourceP12VertexBufferP17GPUSkinPoseBufferS4_iijb($this,$sourceMesh,$skinBuffer,$poseBuffer,$destBuffer,$vertexCount,$bonesPerVertex,$channelMask,$lastThisFrame) {
 $this = $this|0;
 $sourceMesh = $sourceMesh|0;
 $skinBuffer = $skinBuffer|0;
 $poseBuffer = $poseBuffer|0;
 $destBuffer = $destBuffer|0;
 $vertexCount = $vertexCount|0;
 $bonesPerVertex = $bonesPerVertex|0;
 $channelMask = $channelMask|0;
 $lastThisFrame = $lastThisFrame|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice40IgnoreNextUnresolveOnCurrentRenderTargetEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice23IgnoreNextUnresolveOnRSE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseE($this,$rs) {
 $this = $this|0;
 $rs = $rs|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice23ResolveDepthIntoTextureE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice25GetBackBufferColorSurfaceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5956|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9GfxDevice25GetBackBufferDepthSurfaceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5960|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9GfxDevice25SetBackBufferColorSurfaceEP17RenderSurfaceBase($this,$color) {
 $this = $this|0;
 $color = $color|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5956|0);
 HEAP32[$0>>2] = $color;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice25SetBackBufferDepthSurfaceEP17RenderSurfaceBase($this,$depth) {
 $this = $this|0;
 $depth = $depth|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5960|0);
 HEAP32[$0>>2] = $depth;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice25IsRenderTargetConfigValidEjj19RenderTextureFormat17DepthBufferFormat($this,$width,$height,$0,$1) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $2 = 0, $3 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[((640792 + 116|0))>>2]|0;
 $3 = ($2|0)>=($height|0);
 $not$ = ($2|0)>=($width|0);
 $$ = $3 & $not$;
 STACKTOP = sp;return ($$|0);
}
function __ZN9GfxDevice19CreateSparseTextureE9TextureIDii13TextureFormati17TextureColorSpace($agg$result,$this,$texture,$width,$height,$format,$mipCount,$colorSpace) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $texture = $texture|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $mipCount = $mipCount|0;
 $colorSpace = $colorSpace|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 1;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 1;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice23UploadSparseTextureTileE9TextureIDiiiPKhii($this,$texture,$tileX,$tileY,$mip,$srcData,$srcSize,$srcPitch) {
 $this = $this|0;
 $texture = $texture|0;
 $tileX = $tileX|0;
 $tileY = $tileY|0;
 $mip = $mip|0;
 $srcData = $srcData|0;
 $srcSize = $srcSize|0;
 $srcPitch = $srcPitch|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18HandleInvalidStateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN9GfxDevice21ResetDynamicResourcesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice19IsReadyToBeginFrameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN9GfxDevice14InsertCPUFenceEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN9GfxDevice15GetNextCPUFenceEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN9GfxDevice14WaitOnCPUFenceEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice22AcquireThreadOwnershipEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice22ReleaseThreadOwnershipEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice14BeginRecordingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN9GfxDevice12EndRecordingEPP14GfxDisplayListRKN9ShaderLab17ShaderPassContextE($this,$outDisplayList,$passContext) {
 $this = $this|0;
 $outDisplayList = $outDisplayList|0;
 $passContext = $passContext|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN9GfxDevice13AfterDrawCallEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16SetActiveContextEPv($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18SetGlobalDepthBiasEff($this,$bias,$slopeBias) {
 $this = $this|0;
 $bias = Math_fround($bias);
 $slopeBias = Math_fround($slopeBias);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5912|0);
 HEAPF32[$0>>2] = $bias;
 $1 = (($this) + 5916|0);
 HEAPF32[$1>>2] = $slopeBias;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice14SetTextureNameE9TextureIDPKc($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20SetRenderSurfaceNameEP17RenderSurfaceBasePKc($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice19SetVertexBufferNameEP12VertexBufferPKc($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice18SetIndexBufferNameEP11IndexBufferPKc($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17SetGpuProgramNameEP10GpuProgramPKc($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK9GfxDevice18GetDefaultRTFormatEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK9GfxDevice21GetDefaultHDRRTFormatEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2;
}
function __ZN9GfxDevice18GetNativeGfxDeviceEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice23GetNativeTexturePointerE9TextureID($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice20SetComputeBufferDataE15ComputeBufferIDPKvj($this,$0,$1,$2) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20GetComputeBufferDataE15ComputeBufferIDPvj($this,$0,$1,$2) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice22CopyComputeBufferCountE15ComputeBufferIDS0_j($this,$0,$1,$2) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice27SetRandomWriteTargetTextureEi9TextureID($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice26SetRandomWriteTargetBufferEi15ComputeBufferID($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice23ClearRandomWriteTargetsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20CreateComputeProgramEPKhj($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN9GfxDevice21DestroyComputeProgramER12ObjectHandleI18ComputeProgram_TagPvE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice28CreateComputeConstantBuffersEjPKjP12ObjectHandleI18ConstantBuffer_TagPvE($this,$0,$1,$2) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice29DestroyComputeConstantBuffersEjP12ObjectHandleI18ConstantBuffer_TagPvE($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice19CreateComputeBufferE15ComputeBufferIDjjj($this,$0,$1,$2,$3) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice20DestroyComputeBufferE15ComputeBufferID($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice28UpdateComputeConstantBuffersEjP12ObjectHandleI18ConstantBuffer_TagPvEjjPKhPKjS8_PKi($this,$0,$1,$2,$3,$4,$5,$6,$7) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice22UpdateComputeResourcesEjPK9TextureIDPKijPKjjPK15ComputeBufferIDS4_jS9_S2_S6_($this,$0,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 $6 = $6|0;
 $7 = $7|0;
 $8 = $8|0;
 $9 = $9|0;
 $10 = $10|0;
 $11 = $11|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice17SetComputeProgramE12ObjectHandleI18ComputeProgram_TagPvE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice22DispatchComputeProgramE12ObjectHandleI18ComputeProgram_TagPvEjjj($this,$0,$1,$2,$3) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16DrawNullGeometryE16GfxPrimitiveTypeii($this,$0,$1,$2) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice24DrawNullGeometryIndirectE16GfxPrimitiveType15ComputeBufferIDj($this,$0,$1,$2) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice16SetStereoBuffersE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_($this,$left,$right) {
 $this = $this|0;
 $left = $left|0;
 $right = $right|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$left>>2]|0;
 $1 = (($this) + 5948|0);
 HEAP32[$1>>2] = $0;
 $2 = HEAP32[$right>>2]|0;
 $3 = (($this) + 5952|0);
 HEAP32[$3>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN9GfxDevice13GetStereoModeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5944|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9GfxDevice16GetMultiGPUCountEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN9GfxDevice13GetCurrentGPUEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN19GfxThreadableDevice15OnDeviceCreatedEb($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($agg$result,$this,$key) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $key = $key|0;
 var $$ = 0, $$lcssa2$ph = 0, $$lcssa214 = 0, $$lcssa3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $num_probes$04 = 0, $num_probes$04$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$key>>2]|0;
 $4 = (($3) + 2127912214)|0;
 $5 = $3 << 12;
 $6 = (($4) + ($5))|0;
 $7 = $6 ^ -949894596;
 $8 = $6 >>> 19;
 $9 = $7 ^ $8;
 $10 = (($9) + 374761393)|0;
 $11 = $9 << 5;
 $12 = (($10) + ($11))|0;
 $13 = (($12) + -744332180)|0;
 $14 = $12 << 9;
 $15 = $13 ^ $14;
 $16 = (($15) + -42973499)|0;
 $17 = $15 << 3;
 $18 = (($16) + ($17))|0;
 $19 = $18 ^ -1252372727;
 $20 = $18 >>> 16;
 $21 = $19 ^ $20;
 $22 = $21 & $2;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + ($22<<3)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($26|0)==($28|0);
 L1: do {
  if ($29) {
   $$lcssa2$ph = $22;
   label = 5;
  } else {
   $30 = (($this) + 8|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   $33 = (($this) + 4|0);
   $34 = (($this) + 12|0);
   L3: do {
    if ($32) {
     $36 = $28;$39 = $22;$num_probes$04$us = 0;
     while(1) {
      $35 = ($3|0)==($36|0);
      if ($35) {
       $$lcssa3 = $39;
       break L3;
      }
      $37 = (($num_probes$04$us) + 1)|0;
      $38 = (($37) + ($39))|0;
      $40 = $38 & $2;
      $41 = (($24) + ($40<<3)|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($26|0)==($42|0);
      if ($43) {
       $$lcssa2$ph = $40;
       label = 5;
       break L1;
      } else {
       $36 = $42;$39 = $40;$num_probes$04$us = $37;
      }
     }
    } else {
     $53 = $28;$55 = -1;$56 = $22;$num_probes$04 = 0;
     while(1) {
      $49 = HEAP32[$33>>2]|0;
      $50 = ($49|0)==(0);
      if ($50) {
       label = 12;
      } else {
       $51 = HEAP32[$34>>2]|0;
       $52 = ($51|0)==($53|0);
       if ($52) {
        $54 = ($55|0)==(-1);
        $$ = $54 ? $56 : $55;
        $46 = $$;
       } else {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       label = 0;
       $57 = ($3|0)==($53|0);
       if ($57) {
        $$lcssa3 = $56;
        break L3;
       } else {
        $46 = $55;
       }
      }
      $59 = (($num_probes$04) + 1)|0;
      $60 = (($59) + ($56))|0;
      $61 = $60 & $2;
      $62 = (($24) + ($61<<3)|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($26|0)==($63|0);
      if ($64) {
       break;
      } else {
       $53 = $63;$55 = $46;$56 = $61;$num_probes$04 = $59;
      }
     }
     $45 = ($46|0)==(-1);
     HEAP32[$agg$result>>2] = -1;
     $47 = (($agg$result) + 4|0);
     if ($45) {
      $$lcssa214 = $61;$48 = $47;
      break L1;
     }
     HEAP32[$47>>2] = $46;
     STACKTOP = sp;return;
    }
   } while(0);
   HEAP32[$agg$result>>2] = $$lcssa3;
   $58 = (($agg$result) + 4|0);
   HEAP32[$58>>2] = -1;
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 5) {
  HEAP32[$agg$result>>2] = -1;
  $44 = (($agg$result) + 4|0);
  $$lcssa214 = $$lcssa2$ph;$48 = $44;
 }
 HEAP32[$48>>2] = $$lcssa214;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj($this,$delta,$min_buckets_wanted) {
 $this = $this|0;
 $delta = $delta|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sz$0$i = 0, $sz$0$i1 = 0, $tmp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 48|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12maybe_shrinkEv($this);
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)>($min_buckets_wanted>>>0);
 $7 = (($this) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $9 = (($8) + ($delta))|0;
  $10 = (($this) + 44|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9>>>0)>($11>>>0);
  if (!($12)) {
   STACKTOP = sp;return;
  }
 }
 $13 = (($this) + 36|0);
 $14 = (($8) + ($delta))|0;
 $15 = (Math_fround(($14>>>0)));
 $sz$0$i = 32;
 while(1) {
  $16 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($16)) {
   $17 = (Math_fround(($sz$0$i>>>0)));
   $18 = Math_fround($17 * Math_fround(0.5));
   $19 = !($15 >= $18);
   if ($19) {
    break;
   }
  }
  $20 = $sz$0$i << 1;
  $sz$0$i = $20;
 }
 $21 = ($sz$0$i>>>0)>($5>>>0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($14) - ($23))|0;
 $25 = (Math_fround(($24>>>0)));
 $sz$0$i1 = 32;
 while(1) {
  $26 = ($sz$0$i1>>>0)<($min_buckets_wanted>>>0);
  if (!($26)) {
   $27 = (Math_fround(($sz$0$i1>>>0)));
   $28 = Math_fround($27 * Math_fround(0.5));
   $29 = !($25 >= $28);
   if ($29) {
    break;
   }
  }
  $30 = $sz$0$i1 << 1;
  $sz$0$i1 = $30;
 }
 $31 = (($tmp) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = (($tmp) + 8|0);
 $33 = (($this) + 8|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = (($tmp) + 9|0);
 $36 = (($this) + 9|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP8[$35>>0] = $37;
 $38 = (($tmp) + 12|0);
 $39 = (($this) + 12|0);
 $40 = $39;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 4)|0;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = $38;
 $47 = $46;
 HEAP32[$47>>2] = $42;
 $48 = (($46) + 4)|0;
 $49 = $48;
 HEAP32[$49>>2] = $45;
 $50 = (($tmp) + 20|0);
 $51 = (($this) + 20|0);
 $52 = $51;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($52) + 4)|0;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = $50;
 $59 = $58;
 HEAP32[$59>>2] = $54;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $57;
 $62 = (($tmp) + 28|0);
 ;HEAP32[$62+0>>2]=0|0;HEAP32[$62+4>>2]=0|0;HEAP32[$62+8>>2]=0|0;HEAP32[$62+12>>2]=0|0;HEAP32[$62+16>>2]=0|0;HEAP8[$62+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E9copy_fromERKSF_j($tmp,$this,$sz$0$i1);
 $63 = HEAP32[$22>>2]|0;
 $64 = HEAP32[$31>>2]|0;
 HEAP32[$22>>2] = $64;
 HEAP32[$31>>2] = $63;
 $65 = HEAP8[$33>>0]|0;
 $66 = HEAP16[$32>>1]|0;
 $67 = $66&255;
 HEAP8[$33>>0] = $67;
 HEAP8[$32>>0] = $65;
 $68 = HEAP8[$36>>0]|0;
 $69 = ($66&65535) >>> 8;
 $70 = $69&255;
 HEAP8[$36>>0] = $70;
 HEAP8[$35>>0] = $68;
 $71 = $39;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($71) + 4)|0;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = $38;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = (($77) + 4)|0;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = $39;
 $84 = $83;
 HEAP32[$84>>2] = $79;
 $85 = (($83) + 4)|0;
 $86 = $85;
 HEAP32[$86>>2] = $82;
 $87 = $38;
 $88 = $87;
 HEAP32[$88>>2] = $73;
 $89 = (($87) + 4)|0;
 $90 = $89;
 HEAP32[$90>>2] = $76;
 $91 = $51;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = (($91) + 4)|0;
 $95 = $94;
 $96 = HEAP32[$95>>2]|0;
 $97 = $50;
 $98 = $97;
 $99 = HEAP32[$98>>2]|0;
 $100 = (($97) + 4)|0;
 $101 = $100;
 $102 = HEAP32[$101>>2]|0;
 $103 = $51;
 $104 = $103;
 HEAP32[$104>>2] = $99;
 $105 = (($103) + 4)|0;
 $106 = $105;
 HEAP32[$106>>2] = $102;
 $107 = $50;
 $108 = $107;
 HEAP32[$108>>2] = $93;
 $109 = (($107) + 4)|0;
 $110 = $109;
 HEAP32[$110>>2] = $96;
 $111 = (($this) + 28|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = HEAP32[$62>>2]|0;
 HEAP32[$111>>2] = $113;
 HEAP32[$62>>2] = $112;
 $114 = (($tmp) + 32|0);
 $115 = HEAP32[$4>>2]|0;
 $116 = HEAP32[$114>>2]|0;
 HEAP32[$4>>2] = $116;
 HEAP32[$114>>2] = $115;
 $117 = (($tmp) + 36|0);
 $118 = HEAP32[$13>>2]|0;
 $119 = HEAP32[$117>>2]|0;
 HEAP32[$13>>2] = $119;
 HEAP32[$117>>2] = $118;
 $120 = (Math_fround(($116>>>0)));
 $121 = Math_fround($120 * Math_fround(0.5));
 $122 = (~~(($121))>>>0);
 $123 = (($this) + 44|0);
 HEAP32[$123>>2] = $122;
 $124 = Math_fround($120 * Math_fround(0.20000000298023223877));
 $125 = (~~(($124))>>>0);
 $126 = (($this) + 40|0);
 HEAP32[$126>>2] = $125;
 HEAP8[$1>>0] = 0;
 $127 = (Math_fround(($115>>>0)));
 $128 = Math_fround($127 * Math_fround(0.5));
 $129 = (~~(($128))>>>0);
 $130 = (($tmp) + 44|0);
 HEAP32[$130>>2] = $129;
 $131 = Math_fround($127 * Math_fround(0.20000000298023223877));
 $132 = (~~(($131))>>>0);
 $133 = (($tmp) + 40|0);
 HEAP32[$133>>2] = $132;
 $134 = (($tmp) + 48|0);
 HEAP8[$134>>0] = 0;
 $135 = ($112|0)==(0|0);
 if ($135) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($112,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS4_($agg$result,$this,$obj) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $obj = $obj|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos = sp;
 __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos,$this,$obj);
 $0 = HEAP32[$pos>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  $2 = (($this) + 28|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + ($0<<3)|0);
  $5 = (($this) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + ($6<<3)|0);
  HEAP32[$agg$result>>2] = $this;
  $8 = (($agg$result) + 4|0);
  HEAP32[$8>>2] = $4;
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $7;
  $10 = (($agg$result) + 12|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($pos) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  label = 7;
 } else {
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if ($18) {
   label = 7;
  } else {
   $19 = (($this) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + ($12<<3)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22|0)==($24|0);
   if ($25) {
    $26 = (($17) + -1)|0;
    HEAP32[$16>>2] = $26;
    $32 = $20;
   } else {
    label = 7;
   }
  }
 }
 if ((label|0) == 7) {
  $27 = (($this) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 1)|0;
  HEAP32[$27>>2] = $29;
  $$phi$trans$insert = (($this) + 28|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $32 = $$pre;
 }
 $30 = (($this) + 28|0);
 $31 = (($32) + ($12<<3)|0);
 $33 = ($31|0)==(0|0);
 if (!($33)) {
  $34 = $obj;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 4)|0;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = $31;
  $41 = $40;
  HEAP32[$41>>2] = $36;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = $39;
 }
 $44 = HEAP32[$30>>2]|0;
 $45 = (($44) + ($12<<3)|0);
 $46 = (($this) + 32|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($44) + ($47<<3)|0);
 HEAP32[$agg$result>>2] = $this;
 $49 = (($agg$result) + 4|0);
 HEAP32[$49>>2] = $45;
 $50 = (($agg$result) + 8|0);
 HEAP32[$50>>2] = $48;
 $51 = (($agg$result) + 12|0);
 HEAP8[$51>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12maybe_shrinkEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sz$0 = 0, $sz$0$in = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) - ($4))|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if (!($8)) {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 $9 = (($this) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)>(32);
 if ($11) {
  $sz$0$in = $10;
 } else {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $sz$0 = $sz$0$in >>> 1;
  $12 = ($sz$0$in>>>0)<(66);
  if ($12) {
   break;
  }
  $13 = (Math_fround(($5>>>0)));
  $14 = (Math_fround(($sz$0>>>0)));
  $15 = Math_fround($14 * Math_fround(0.20000000298023223877));
  $16 = $13 < $15;
  if ($16) {
   $sz$0$in = $sz$0;
  } else {
   break;
  }
 }
 $17 = (($tmp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($tmp) + 8|0);
 $19 = (($this) + 8|0);
 $20 = HEAP8[$19>>0]|0;
 HEAP8[$18>>0] = $20;
 $21 = (($tmp) + 9|0);
 $22 = (($this) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 HEAP8[$21>>0] = $23;
 $24 = (($tmp) + 12|0);
 $25 = (($this) + 12|0);
 $26 = $25;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $24;
 $33 = $32;
 HEAP32[$33>>2] = $28;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $31;
 $36 = (($tmp) + 20|0);
 $37 = (($this) + 20|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $36;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 $48 = (($tmp) + 28|0);
 ;HEAP32[$48+0>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;HEAP8[$48+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E9copy_fromERKSF_j($tmp,$this,$sz$0);
 $49 = HEAP32[$3>>2]|0;
 $50 = HEAP32[$17>>2]|0;
 HEAP32[$3>>2] = $50;
 HEAP32[$17>>2] = $49;
 $51 = HEAP8[$19>>0]|0;
 $52 = HEAP16[$18>>1]|0;
 $53 = $52&255;
 HEAP8[$19>>0] = $53;
 HEAP8[$18>>0] = $51;
 $54 = HEAP8[$22>>0]|0;
 $55 = ($52&65535) >>> 8;
 $56 = $55&255;
 HEAP8[$22>>0] = $56;
 HEAP8[$21>>0] = $54;
 $57 = $25;
 $58 = $57;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 4)|0;
 $61 = $60;
 $62 = HEAP32[$61>>2]|0;
 $63 = $24;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $25;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $24;
 $74 = $73;
 HEAP32[$74>>2] = $59;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $62;
 $77 = $37;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = (($77) + 4)|0;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = $36;
 $84 = $83;
 $85 = HEAP32[$84>>2]|0;
 $86 = (($83) + 4)|0;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = $37;
 $90 = $89;
 HEAP32[$90>>2] = $85;
 $91 = (($89) + 4)|0;
 $92 = $91;
 HEAP32[$92>>2] = $88;
 $93 = $36;
 $94 = $93;
 HEAP32[$94>>2] = $79;
 $95 = (($93) + 4)|0;
 $96 = $95;
 HEAP32[$96>>2] = $82;
 $97 = (($this) + 28|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$48>>2]|0;
 HEAP32[$97>>2] = $99;
 HEAP32[$48>>2] = $98;
 $100 = (($tmp) + 32|0);
 $101 = HEAP32[$9>>2]|0;
 $102 = HEAP32[$100>>2]|0;
 HEAP32[$9>>2] = $102;
 HEAP32[$100>>2] = $101;
 $103 = (($tmp) + 36|0);
 $104 = HEAP32[$1>>2]|0;
 $105 = HEAP32[$103>>2]|0;
 HEAP32[$1>>2] = $105;
 HEAP32[$103>>2] = $104;
 $106 = (Math_fround(($102>>>0)));
 $107 = Math_fround($106 * Math_fround(0.5));
 $108 = (~~(($107))>>>0);
 $109 = (($this) + 44|0);
 HEAP32[$109>>2] = $108;
 $110 = Math_fround($106 * Math_fround(0.20000000298023223877));
 $111 = (~~(($110))>>>0);
 HEAP32[$6>>2] = $111;
 $112 = (($this) + 48|0);
 HEAP8[$112>>0] = 0;
 $113 = (Math_fround(($101>>>0)));
 $114 = Math_fround($113 * Math_fround(0.5));
 $115 = (~~(($114))>>>0);
 $116 = (($tmp) + 44|0);
 HEAP32[$116>>2] = $115;
 $117 = Math_fround($113 * Math_fround(0.20000000298023223877));
 $118 = (~~(($117))>>>0);
 $119 = (($tmp) + 40|0);
 HEAP32[$119>>2] = $118;
 $120 = (($tmp) + 48|0);
 HEAP8[$120>>0] = 0;
 $121 = ($98|0)==(0|0);
 if ($121) {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($98,$$byval_copy);
 $122 = (($this) + 48|0);
 HEAP8[$122>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E9copy_fromERKSF_j($this,$ht,$min_buckets_wanted) {
 $this = $this|0;
 $ht = $ht|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$01$i$i$i = 0, $$01$i$i$i4 = 0, $$012$i$i = 0, $$03$i$i = 0, $$be = 0, $$byval_copy3 = 0, $$ph12 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucknum$0 = 0, $bucknum$0$lcssa = 0, $bucknum$010 = 0, $bucknum$08 = 0, $num_probes$09 = 0, $sz$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = 32;
 $3 = (($this) + 44|0);
 HEAP32[$3>>2] = 16;
 $4 = (($this) + 40|0);
 HEAP32[$4>>2] = 6;
 $5 = (($this) + 48|0);
 HEAP8[$5>>0] = 0;
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Z15malloc_internaljj10MemLabelIdiPKci(256,16,$$byval_copy3,0,598360,79)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy3);
 }
 HEAP32[$1>>2] = $6;
 $9 = HEAP32[$2>>2]|0;
 $10 = (($6) + ($9<<3)|0);
 $11 = ($6|0)==($10|0);
 if (!($11)) {
  $12 = (($this) + 20|0);
  $$01$i$i$i = $6;
  while(1) {
   $13 = ($$01$i$i$i|0)==(0|0);
   if (!($13)) {
    $14 = $12;
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + 4)|0;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = $$01$i$i$i;
    $21 = $20;
    HEAP32[$21>>2] = $16;
    $22 = (($20) + 4)|0;
    $23 = $22;
    HEAP32[$23>>2] = $19;
   }
   $24 = (($$01$i$i$i) + 8|0);
   $25 = ($24|0)==($10|0);
   if ($25) {
    break;
   } else {
    $$01$i$i$i = $24;
   }
  }
 }
 $26 = (($this) + 36|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 4|0);
 HEAP32[$27>>2] = 0;
 $28 = (($ht) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($ht) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) - ($31))|0;
 $33 = (Math_fround(($32>>>0)));
 $sz$0$i = 32;
 while(1) {
  $34 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($34)) {
   $35 = (Math_fround(($sz$0$i>>>0)));
   $36 = Math_fround($35 * Math_fround(0.5));
   $37 = !($33 >= $36);
   if ($37) {
    break;
   }
  }
  $38 = $sz$0$i << 1;
  $sz$0$i = $38;
 }
 $39 = HEAP32[$2>>2]|0;
 $40 = ($sz$0$i>>>0)>($39>>>0);
 if ($40) {
  $41 = $sz$0$i << 3;
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($41,16,$$byval_copy3,0,598360,79)|0);
  $43 = HEAP32[$1>>2]|0;
  $44 = HEAP32[$2>>2]|0;
  $45 = ($44>>>0)>($sz$0$i>>>0);
  $46 = $45 ? $sz$0$i : $44;
  $47 = (($43) + ($46<<3)|0);
  $48 = ($46|0)==(0);
  if ($48) {
   $65 = $44;
  } else {
   $$012$i$i = $42;$$03$i$i = $43;
   while(1) {
    $49 = ($$012$i$i|0)==(0|0);
    if (!($49)) {
     $50 = $$03$i$i;
     $51 = $50;
     $52 = HEAP32[$51>>2]|0;
     $53 = (($50) + 4)|0;
     $54 = $53;
     $55 = HEAP32[$54>>2]|0;
     $56 = $$012$i$i;
     $57 = $56;
     HEAP32[$57>>2] = $52;
     $58 = (($56) + 4)|0;
     $59 = $58;
     HEAP32[$59>>2] = $55;
    }
    $60 = (($$03$i$i) + 8|0);
    $61 = (($$012$i$i) + 8|0);
    $62 = ($60|0)==($47|0);
    if ($62) {
     break;
    } else {
     $$012$i$i = $61;$$03$i$i = $60;
    }
   }
   $$pre$i = HEAP32[$2>>2]|0;
   $65 = $$pre$i;
  }
  $63 = (($42) + ($sz$0$i<<3)|0);
  $64 = ($65|0)==($sz$0$i|0);
  if (!($64)) {
   $66 = (($42) + ($65<<3)|0);
   $67 = (($this) + 20|0);
   $$01$i$i$i4 = $66;
   while(1) {
    $68 = ($$01$i$i$i4|0)==(0|0);
    if (!($68)) {
     $69 = $67;
     $70 = $69;
     $71 = HEAP32[$70>>2]|0;
     $72 = (($69) + 4)|0;
     $73 = $72;
     $74 = HEAP32[$73>>2]|0;
     $75 = $$01$i$i$i4;
     $76 = $75;
     HEAP32[$76>>2] = $71;
     $77 = (($75) + 4)|0;
     $78 = $77;
     HEAP32[$78>>2] = $74;
    }
    $79 = (($$01$i$i$i4) + 8|0);
    $80 = ($79|0)==($63|0);
    if ($80) {
     break;
    } else {
     $$01$i$i$i4 = $79;
    }
   }
  }
  $81 = HEAP32[$1>>2]|0;
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($81,$$byval_copy3);
  HEAP32[$1>>2] = $42;
  HEAP32[$2>>2] = $sz$0$i;
  $82 = (~~(($36))>>>0);
  HEAP32[$3>>2] = $82;
  $83 = Math_fround($35 * Math_fround(0.20000000298023223877));
  $84 = (~~(($83))>>>0);
  HEAP32[$4>>2] = $84;
  HEAP8[$5>>0] = 0;
  $175 = $sz$0$i;
 } else {
  $175 = $39;
 }
 $85 = (($ht) + 28|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($ht) + 32|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($86) + ($88<<3)|0);
 $90 = ($88|0)==(0);
 L37: do {
  if ($90) {
   $$ph12 = $86;
  } else {
   $91 = (($ht) + 20|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($ht) + 8|0);
   $94 = (($ht) + 12|0);
   $96 = $86;
   while(1) {
    $95 = HEAP32[$96>>2]|0;
    $97 = ($92|0)==($95|0);
    if (!($97)) {
     $98 = HEAP8[$93>>0]|0;
     $99 = ($98<<24>>24)==(0);
     if ($99) {
      $$ph12 = $96;
      break L37;
     }
     $100 = HEAP32[$30>>2]|0;
     $101 = ($100|0)==(0);
     if ($101) {
      $$ph12 = $96;
      break L37;
     }
     $102 = HEAP32[$94>>2]|0;
     $103 = ($102|0)==($95|0);
     if (!($103)) {
      $$ph12 = $96;
      break L37;
     }
    }
    $104 = (($96) + 8|0);
    $105 = ($104|0)==($89|0);
    if ($105) {
     break;
    } else {
     $96 = $104;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $106 = ($$ph12|0)==($89|0);
 if ($106) {
  STACKTOP = sp;return;
 }
 $107 = (($this) + 20|0);
 $108 = (($ht) + 20|0);
 $109 = (($ht) + 8|0);
 $110 = (($ht) + 12|0);
 $112 = $175;$114 = $$ph12;
 while(1) {
  $111 = (($112) + -1)|0;
  $113 = HEAP32[$114>>2]|0;
  $115 = (($113) + 2127912214)|0;
  $116 = $113 << 12;
  $117 = (($115) + ($116))|0;
  $118 = $117 ^ -949894596;
  $119 = $117 >>> 19;
  $120 = $118 ^ $119;
  $121 = (($120) + 374761393)|0;
  $122 = $120 << 5;
  $123 = (($121) + ($122))|0;
  $124 = (($123) + -744332180)|0;
  $125 = $123 << 9;
  $126 = $124 ^ $125;
  $127 = (($126) + -42973499)|0;
  $128 = $126 << 3;
  $129 = (($127) + ($128))|0;
  $130 = $129 ^ -1252372727;
  $131 = $129 >>> 16;
  $132 = $130 ^ $131;
  $bucknum$08 = $132 & $111;
  $133 = HEAP32[$1>>2]|0;
  $134 = HEAP32[$107>>2]|0;
  $135 = (($133) + ($bucknum$08<<3)|0);
  $136 = HEAP32[$135>>2]|0;
  $137 = ($134|0)==($136|0);
  if ($137) {
   $bucknum$0$lcssa = $bucknum$08;
  } else {
   $bucknum$010 = $bucknum$08;$num_probes$09 = 0;
   while(1) {
    $138 = (($num_probes$09) + 1)|0;
    $139 = (($138) + ($bucknum$010))|0;
    $bucknum$0 = $139 & $111;
    $140 = (($133) + ($bucknum$0<<3)|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = ($134|0)==($141|0);
    if ($142) {
     $bucknum$0$lcssa = $bucknum$0;
     break;
    } else {
     $bucknum$010 = $bucknum$0;$num_probes$09 = $138;
    }
   }
  }
  $143 = (($133) + ($bucknum$0$lcssa<<3)|0);
  $144 = ($143|0)==(0|0);
  if (!($144)) {
   $145 = $114;
   $146 = $145;
   $147 = HEAP32[$146>>2]|0;
   $148 = (($145) + 4)|0;
   $149 = $148;
   $150 = HEAP32[$149>>2]|0;
   $151 = $143;
   $152 = $151;
   HEAP32[$152>>2] = $147;
   $153 = (($151) + 4)|0;
   $154 = $153;
   HEAP32[$154>>2] = $150;
  }
  $155 = HEAP32[$26>>2]|0;
  $156 = (($155) + 1)|0;
  HEAP32[$26>>2] = $156;
  $157 = (($114) + 8|0);
  $158 = ($157|0)==($89|0);
  L60: do {
   if ($158) {
    $$be = $89;
   } else {
    $163 = HEAP32[$108>>2]|0;
    $165 = $157;
    while(1) {
     $164 = HEAP32[$165>>2]|0;
     $166 = ($163|0)==($164|0);
     if (!($166)) {
      $167 = HEAP8[$109>>0]|0;
      $168 = ($167<<24>>24)==(0);
      if ($168) {
       $$be = $165;
       break L60;
      }
      $169 = HEAP32[$30>>2]|0;
      $170 = ($169|0)==(0);
      if ($170) {
       $$be = $165;
       break L60;
      }
      $171 = HEAP32[$110>>2]|0;
      $172 = ($171|0)==($164|0);
      if (!($172)) {
       $$be = $165;
       break L60;
      }
     }
     $173 = (($165) + 8|0);
     $174 = ($173|0)==($89|0);
     if ($174) {
      $$be = $89;
      break;
     } else {
      $165 = $173;
     }
    }
   }
  } while(0);
  $159 = HEAP32[$85>>2]|0;
  $160 = HEAP32[$87>>2]|0;
  $161 = (($159) + ($160<<3)|0);
  $162 = ($$be|0)==($161|0);
  if ($162) {
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $112 = $$pre;$114 = $$be;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI9TextureIDjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI9TextureIDjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI9TextureIDjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __GLOBAL__I_a4056() {
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=597416+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=597480+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN14ChannelAssignsC2Ev(((598504 + 16|0)));
 __ZN14ChannelAssignsC2Ev(((598584 + 16|0)));
 STACKTOP = sp;return;
}
function __ZN13CallbackArray6InvokeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  FUNCTION_TABLE_v[$0 & 1023]();
 }
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  FUNCTION_TABLE_v[$3 & 1023]();
 }
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  FUNCTION_TABLE_v[$6 & 1023]();
 }
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  FUNCTION_TABLE_v[$9 & 1023]();
 }
 $11 = (($this) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  FUNCTION_TABLE_v[$12 & 1023]();
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  FUNCTION_TABLE_v[$15 & 1023]();
 }
 $17 = (($this) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  FUNCTION_TABLE_v[$18 & 1023]();
 }
 $20 = (($this) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  FUNCTION_TABLE_v[$21 & 1023]();
 }
 $23 = (($this) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  FUNCTION_TABLE_v[$24 & 1023]();
 }
 $26 = (($this) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  FUNCTION_TABLE_v[$27 & 1023]();
 }
 $29 = (($this) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  FUNCTION_TABLE_v[$30 & 1023]();
 }
 $32 = (($this) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  FUNCTION_TABLE_v[$33 & 1023]();
 }
 $35 = (($this) + 48|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  FUNCTION_TABLE_v[$36 & 1023]();
 }
 $38 = (($this) + 52|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  FUNCTION_TABLE_v[$39 & 1023]();
 }
 $41 = (($this) + 56|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if (!($43)) {
  FUNCTION_TABLE_v[$42 & 1023]();
 }
 $44 = (($this) + 60|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 FUNCTION_TABLE_v[$45 & 1023]();
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier60ELi16EEEaSERKS6_($this,$__str) {
 $this = $this|0;
 $__str = $__str|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==($__str|0);
 if ($0) {
  STACKTOP = sp;return ($this|0);
 }
 $1 = HEAP8[$__str>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $8 = (($__str) + 1|0);
  $9 = $1&255;
  $10 = $9 >>> 1;
  $19 = $10;$27 = $8;
 } else {
  $4 = (($__str) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($__str) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $19 = $7;$27 = $5;
 }
 $11 = HEAP8[$this>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $18 = 10;$21 = $11;
 } else {
  $14 = HEAP32[$this>>2]|0;
  $15 = $14 & -2;
  $phitmp$i$i$i = (($15) + -1)|0;
  $16 = $14&255;
  $18 = $phitmp$i$i$i;$21 = $16;
 }
 $17 = ($18>>>0)<($19>>>0);
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($17) {
  if ($22) {
   $37 = $21&255;
   $38 = $37 >>> 1;
   $40 = $38;
  } else {
   $35 = (($this) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $40 = $36;
  }
  $39 = (($19) - ($18))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier60ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$18,$39,$40,0,$40,$19,$27);
  STACKTOP = sp;return ($this|0);
 }
 if ($22) {
  $25 = (($this) + 1|0);
  $26 = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $26 = $24;
 }
 _memmove(($26|0),($27|0),($19|0))|0;
 $28 = (($26) + ($19)|0);
 HEAP8[$28>>0] = 0;
 $29 = HEAP8[$this>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $33 = $19 << 1;
  $34 = $33&255;
  HEAP8[$this>>0] = $34;
  STACKTOP = sp;return ($this|0);
 } else {
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $19;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier60ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add,$__p_new_stuff) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 $__p_new_stuff = $__p_new_stuff|0;
 var $$byval_copy1 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (2147483630 - ($__old_cap))|0;
 $2 = ($1>>>0)<($__delta_cap>>>0);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($this) + 1|0);
  $20 = $8;
 } else {
  $6 = (($this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $20 = $7;
 }
 $9 = ($__old_cap>>>0)<(1073741799);
 if ($9) {
  $10 = (($__delta_cap) + ($__old_cap))|0;
  $11 = $__old_cap << 1;
  $12 = ($10>>>0)<($11>>>0);
  $13 = $12 ? $11 : $10;
  $14 = ($13>>>0)<(11);
  if ($14) {
   $17 = 11;
  } else {
   $15 = (($13) + 16)|0;
   $16 = $15 & -16;
   $17 = $16;
  }
 } else {
  $17 = 2147483631;
 }
 HEAP32[$0>>2] = 60;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($17,16,$$byval_copy1,0,598816,79)|0);
 $19 = ($__n_copy|0)==(0);
 if (!($19)) {
  _memcpy(($18|0),($20|0),($__n_copy|0))|0;
 }
 $21 = ($__n_add|0)==(0);
 if (!($21)) {
  $22 = (($18) + ($__n_copy)|0);
  _memcpy(($22|0),($__p_new_stuff|0),($__n_add|0))|0;
 }
 $23 = (($__old_sz) - ($__n_del))|0;
 $24 = ($23|0)==($__n_copy|0);
 if (!($24)) {
  $25 = (($23) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $26 = (($18) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $27 = (($20) + ($$sum1)|0);
  _memcpy(($26|0),($27|0),($25|0))|0;
 }
 $28 = ($__old_cap|0)==(10);
 if ($28) {
  $33 = (($this) + 8|0);
  HEAP32[$33>>2] = $18;
  $34 = $17 | 1;
  HEAP32[$this>>2] = $34;
  $35 = (($23) + ($__n_add))|0;
  $36 = (($this) + 4|0);
  HEAP32[$36>>2] = $35;
  $37 = (($18) + ($35)|0);
  HEAP8[$37>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 60;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($20|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  ___cxa_call_unexpected(($31|0));
  // unreachable;
 } else {
  $33 = (($this) + 8|0);
  HEAP32[$33>>2] = $18;
  $34 = $17 | 1;
  HEAP32[$this>>2] = $34;
  $35 = (($23) + ($__n_add))|0;
  $36 = (($this) + 4|0);
  HEAP32[$36>>2] = $35;
  $37 = (($18) + ($35)|0);
  HEAP8[$37>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __Z19InitializeGfxDevicev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__Z20GetPlayerSettingsPtrv()|0);
 $0 = (_JS_SystemInfo_HasWebGL()|0);
 $1 = ($0|0)==(0);
 if ($1) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(598824,0,598888,421,1,0,0,0);
  _exit(-1);
  // unreachable;
 } else {
  $2 = (__Z21CreateGLES20GfxDevicev()|0);
  __Z12SetGfxDeviceP9GfxDevice($2);
  __ZN12GraphicsCaps24SharedCapsPostInitializeEv(640792);
  $3 = ($2|0)!=(0|0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN14GfxDeviceStatsC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((598896 + 8|0));
 $0 = (($this) + 104|0);
 HEAP32[$0>>2] = 64;
 $1 = (($this) + 108|0);
 HEAP32[$1>>2] = 64;
 $2 = (($this) + 112|0);
 HEAP32[$2>>2] = 4;
 $3 = (($this) + 116|0);
 HEAP32[$3>>2] = 4;
 $4 = (($this) + 120|0);
 HEAP32[$4>>2] = 4;
 $5 = (($this) + 124|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 128|0);
 HEAP32[$6>>2] = 49152;
 $7 = (($this) + 136|0);
 $8 = $7;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14GfxDeviceStats26AccumulateUsedTextureUsageEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN14GfxDeviceStats10ResetFrameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 88|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 $2 = (($this) + 144|0);
 dest=$2+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$0+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN14GfxDeviceStats15SetScreenParamsEiiiiii($this,$width,$height,$backbufferBPP,$frontbufferBPP,$depthBPP,$fsaa) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $backbufferBPP = $backbufferBPP|0;
 $frontbufferBPP = $frontbufferBPP|0;
 $depthBPP = $depthBPP|0;
 $fsaa = $fsaa|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 HEAP32[$0>>2] = $width;
 $1 = (($this) + 108|0);
 HEAP32[$1>>2] = $height;
 $2 = ($frontbufferBPP|0)>(-1);
 if ($2) {
  $3 = (($this) + 112|0);
  HEAP32[$3>>2] = $frontbufferBPP;
 }
 $4 = ($backbufferBPP|0)>(-1);
 if ($4) {
  $5 = (($this) + 116|0);
  HEAP32[$5>>2] = $backbufferBPP;
 }
 $6 = ($depthBPP|0)>(-1);
 if ($6) {
  $7 = (($this) + 120|0);
  HEAP32[$7>>2] = $depthBPP;
 }
 $8 = ($fsaa|0)>(-1);
 $9 = (($this) + 124|0);
 if ($8) {
  HEAP32[$9>>2] = $fsaa;
  $12 = $fsaa;
 } else {
  $$pre = HEAP32[$9>>2]|0;
  $12 = $$pre;
 }
 $10 = Math_imul($height, $width)|0;
 $11 = ($12|0)<(1);
 $13 = $11 ? 1 : $12;
 $14 = (($this) + 116|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 120|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($15))|0;
 $19 = Math_imul($18, $13)|0;
 $20 = (($this) + 112|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + ($21))|0;
 $23 = Math_imul($10, $22)|0;
 $24 = (($this) + 128|0);
 HEAP32[$24>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN14GfxDeviceStats15BeginFrameStatsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 224|0);
 HEAP8[$0>>0] = 1;
 $1 = (+__Z19GetTimeSinceStartupv());
 $2 = (($this) + 208|0);
 HEAPF64[$2>>3] = $1;
 STACKTOP = sp;return;
}
function __ZN14GfxDeviceStats19EndClientFrameStatsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = Math_fround(0), $7 = 0.0, $8 = 0.0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 224|0);
 HEAP8[$0>>0] = 0;
 $1 = (+__Z19GetTimeSinceStartupv());
 $2 = (($this) + 208|0);
 $3 = +HEAPF64[$2>>3];
 $4 = $1 - $3;
 $5 = (($this) + 216|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = +$6;
 $8 = $4 + $7;
 $9 = Math_fround($8);
 HEAPF32[$5>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN14GfxDeviceStats16CopyAllDrawStatsERKS_($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = (($s) + 24|0);
 dest=$0+0|0; src=$1+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($this) + 4|0);
 $3 = (($s) + 4|0);
 ;HEAP32[$2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$3+16>>2]|0;
 $4 = (($s) + 220|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 220|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 144|0);
 $8 = (($s) + 144|0);
 dest=$7+0|0; src=$8+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN14GfxDeviceStats15CopyClientStatsERKS_($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = (($s) + 80|0);
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;
 $2 = (($s) + 216|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 216|0);
 HEAPF32[$4>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN12GfxPatchInfo18AddPatchableTexEnvERKN9ShaderLab16FastPropertyNameE16TextureDimensionP10TexEnvDataP8Vector4fPKvPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($this,$name,$dim,$dest,$destST,$bufferStart,$props,$passContext) {
 $this = $this|0;
 $name = $name|0;
 $dim = $dim|0;
 $dest = $dest|0;
 $destST = $destST|0;
 $bufferStart = $bufferStart|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$byval_copy2 = 0, $$not = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = Math_fround(0), $7 = 0;
 var $8 = Math_fround(0), $9 = Math_fround(0), $brmerge = 0, $location$off$i = 0, $texEnvLocation = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $texEnvLocation = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$name>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__ZN9ShaderLab11shaderprops9GetTexEnvEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameE16TextureDimensionRNS0_16PropertyLocationE($props,$passContext,$$byval_copy2,$dim,$texEnvLocation)|0);
 __ZNK9ShaderLab6TexEnv11PrepareDataEP10TexEnvData($3,$dest);
 $4 = ($destST|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 44|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($3) + 32|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround($6 * $8);
  $10 = (($3) + 48|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($3) + 36|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($11 * $13);
  $15 = (($3) + 52|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($3) + 56|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$destST>>2] = $9;
  $19 = (($destST) + 4|0);
  HEAPF32[$19>>2] = $14;
  $20 = (($destST) + 8|0);
  HEAPF32[$20>>2] = $16;
  $21 = (($destST) + 12|0);
  HEAPF32[$21>>2] = $18;
 }
 $22 = HEAP32[$texEnvLocation>>2]|0;
 $23 = ($22|0)==(4);
 $location$off$i = (($22) + -1)|0;
 $24 = $23 ^ 1;
 $$not = ($location$off$i>>>0)>(1);
 $brmerge = $23 | $$not;
 if ($brmerge) {
  STACKTOP = sp;return ($24|0);
 }
 $25 = $dest;
 $26 = $bufferStart;
 $27 = (($25) - ($26))|0;
 $28 = (($this) + 64|0);
 $29 = (($this) + 72|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 $32 = (($this) + 76|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 & 2147483647;
 $35 = ($31>>>0)>($34>>>0);
 if ($35) {
  $36 = $33 << 1;
  $37 = ($36|0)==(0);
  $38 = $37 ? 1 : $36;
  $39 = ($34>>>0)<($38>>>0);
  do {
   if ($39) {
    $40 = ($33|0)>(-1);
    if ($40) {
     HEAP32[$32>>2] = $38;
     $41 = HEAP32[$28>>2]|0;
     $42 = ($38*12)|0;
     $43 = (($this) + 68|0);
     $44 = HEAP32[$43>>2]|0;
     HEAP32[$0>>2] = $44;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $45 = (__Z16realloc_internalPvji10MemLabelIdiPKci($41,$42,4,$$byval_copy2,0,598912,370)|0);
     HEAP32[$28>>2] = $45;
     break;
    } else {
     $46 = ($38*12)|0;
     $47 = (($this) + 68|0);
     $48 = HEAP32[$47>>2]|0;
     HEAP32[$0>>2] = $48;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $49 = (__Z15malloc_internaljj10MemLabelIdiPKci($46,4,$$byval_copy2,0,598912,352)|0);
     $50 = HEAP32[$28>>2]|0;
     $51 = HEAP32[$29>>2]|0;
     $52 = ($51*12)|0;
     _memcpy(($49|0),($50|0),($52|0))|0;
     HEAP32[$32>>2] = $38;
     HEAP32[$28>>2] = $49;
     break;
    }
   }
  } while(0);
  $$pre$i$i$i = HEAP32[$29>>2]|0;
  $54 = $$pre$i$i$i;
 } else {
  $54 = $31;
 }
 $53 = (($54) + -1)|0;
 $55 = HEAP32[$28>>2]|0;
 $56 = (($55) + (($53*12)|0)|0);
 HEAP32[$56>>2] = $3;
 $57 = ((($55) + (($53*12)|0)|0) + 4|0);
 HEAP32[$57>>2] = $dim;
 $58 = ((($55) + (($53*12)|0)|0) + 8|0);
 HEAP32[$58>>2] = $27;
 STACKTOP = sp;return ($24|0);
}
function __Z22IsShaderParameterArrayPKcjiPb($name,$nameLen,$arraySize,$isZeroElem) {
 $name = $name|0;
 $nameLen = $nameLen|0;
 $arraySize = $arraySize|0;
 $isZeroElem = $isZeroElem|0;
 var $$$off0 = 0, $$off0 = 0, $$sum = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nameLen>>>0)>(3);
 if ($0) {
  $$sum = (($nameLen) + -3)|0;
  $1 = (($name) + ($$sum)|0);
  $2 = (_strcmp($1,598920)|0);
  $3 = ($2|0)==(0);
  $$off0 = $3;
 } else {
  $$off0 = 0;
 }
 $4 = ($isZeroElem|0)==(0|0);
 if (!($4)) {
  $5 = $$off0&1;
  HEAP8[$isZeroElem>>0] = $5;
 }
 $6 = ($arraySize|0)>(1);
 $$$off0 = $6 | $$off0;
 STACKTOP = sp;return ($$$off0|0);
}
function __ZN13dynamic_arrayIN20GpuProgramParameters14ValueParameterELj4EE9push_backERKS1_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = $5 << 1;
  $9 = ($8|0)==(0);
  $10 = $9 ? 1 : $8;
  $11 = ($6>>>0)<($10>>>0);
  do {
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*20)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,599472,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*20)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,599472,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*20)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$1>>2]|0;
  $26 = $$pre$i;
 } else {
  $26 = $3;
 }
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($25*20)|0)|0);
 ;HEAP32[$28+0>>2]=HEAP32[$t+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$t+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$t+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$t+12>>2]|0;HEAP16[$28+16>>1]=HEAP16[$t+16>>1]|0;HEAP8[$28+18>>0]=HEAP8[$t+18>>0]|0;
 STACKTOP = sp;return;
}
function __ZN20GpuProgramParameters14AddVectorParamEi15ShaderParamTypeiPKciP16PropertyNamesSet($this,$index,$type,$dimension,$nameStr,$cbIndex,$outNames) {
 $this = $this|0;
 $index = $index|0;
 $type = $type|0;
 $dimension = $dimension|0;
 $nameStr = $nameStr|0;
 $cbIndex = $cbIndex|0;
 $outNames = $outNames|0;
 var $$$i = 0, $$byval_copy = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $name = 0, $values$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $name = sp + 8|0;
 $2 = sp + 12|0;
 $3 = ($cbIndex|0)>(-1);
 if ($3) {
  $4 = (($this) + 60|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($5) + (($cbIndex*28)|0)|0) + 4|0);
  $values$0$i = $6;
 } else {
  $values$0$i = $this;
 }
 HEAP32[$$byval_copy>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy,$nameStr);
 $7 = HEAP32[$$byval_copy>>2]|0;
 HEAP32[$name>>2] = $7;
 HEAP32[$2>>2] = $7;
 $8 = (($2) + 4|0);
 HEAP32[$8>>2] = $index;
 $9 = (($2) + 8|0);
 HEAP32[$9>>2] = 1;
 $10 = (($2) + 12|0);
 HEAP32[$10>>2] = $type;
 $11 = (($2) + 16|0);
 HEAP8[$11>>0] = 1;
 $12 = (($2) + 17|0);
 $13 = $dimension&255;
 HEAP8[$12>>0] = $13;
 $14 = (($2) + 18|0);
 HEAP8[$14>>0] = 0;
 __ZN13dynamic_arrayIN20GpuProgramParameters14ValueParameterELj4EE9push_backERKS1_($values$0$i,$2);
 $15 = (($this) + 156|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 16)|0;
 HEAP32[$15>>2] = $17;
 $18 = (($this) + 160|0);
 HEAP32[$18>>2] = 1;
 $19 = ($outNames|0)==(0|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$name>>2]|0;
 $21 = ($20|0)!=(-1);
 $22 = ($20>>>0)>(1073741823);
 $$$i = $21 & $22;
 if ($$$i) {
  STACKTOP = sp;return;
 }
 $23 = HEAP32[$outNames>>2]|0;
 $24 = (($outNames) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25;
 $27 = $23;
 $28 = (($26) - ($27))|0;
 $29 = $28 >> 2;
 $30 = ($29|0)==(0);
 if ($30) {
  $40 = $23;
 } else {
  $33 = $23;$__len$03$i$i$i$i$i = $29;
  while(1) {
   $31 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $32 = (($33) + ($31<<2)|0);
   $34 = HEAP32[$32>>2]|0;
   $35 = ($34|0)<($20|0);
   if ($35) {
    $$sum$i$i$i$i$i = (($31) + 1)|0;
    $36 = (($33) + ($$sum$i$i$i$i$i<<2)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $37 = (($$neg2$i$i$i$i$i) - ($31))|0;
    $46 = $36;$__len$0$be$i$i$i$i$i = $37;
   } else {
    $46 = $33;$__len$0$be$i$i$i$i$i = $31;
   }
   $38 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($38) {
    $40 = $46;
    break;
   } else {
    $33 = $46;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $39 = ($40|0)==($25|0);
 if (!($39)) {
  $41 = HEAP32[$40>>2]|0;
  $42 = ($20|0)<($41|0);
  if (!($42)) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$1>>2] = $40;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($0,$outNames,$$byval_copy,$name);
 $43 = (($outNames) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 16)|0;
 HEAP32[$43>>2] = $45;
 STACKTOP = sp;return;
}
function __ZN20GpuProgramParameters14AddMatrixParamEi15ShaderParamTypePKciiiP16PropertyNamesSet($this,$index,$type,$nameStr,$rowCount,$colCount,$cbIndex,$outNames) {
 $this = $this|0;
 $index = $index|0;
 $type = $type|0;
 $nameStr = $nameStr|0;
 $rowCount = $rowCount|0;
 $colCount = $colCount|0;
 $cbIndex = $cbIndex|0;
 $outNames = $outNames|0;
 var $$$i = 0, $$byval_copy = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $cbKey$0 = 0, $name = 0, $values$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $name = sp + 8|0;
 $2 = sp + 12|0;
 $3 = ($cbIndex|0)>(-1);
 if ($3) {
  $4 = (($this) + 60|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + (($cbIndex*28)|0)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($5) + (($cbIndex*28)|0)|0) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 << 16;
  $11 = $10 | $7;
  $cbKey$0 = $11;
 } else {
  $cbKey$0 = 0;
 }
 $12 = (($this) + 72|0);
 $13 = (__ZN25BuiltinShaderParamIndices16CheckMatrixParamEPKciiii($12,$nameStr,$index,$rowCount,$colCount,$cbKey$0)|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 if ($3) {
  $14 = (($this) + 60|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15) + (($cbIndex*28)|0)|0) + 4|0);
  $values$0$i = $16;
 } else {
  $values$0$i = $this;
 }
 HEAP32[$$byval_copy>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy,$nameStr);
 $17 = HEAP32[$$byval_copy>>2]|0;
 HEAP32[$name>>2] = $17;
 HEAP32[$2>>2] = $17;
 $18 = (($2) + 4|0);
 HEAP32[$18>>2] = $index;
 $19 = (($2) + 8|0);
 HEAP32[$19>>2] = 1;
 $20 = (($2) + 12|0);
 HEAP32[$20>>2] = $type;
 $21 = (($2) + 16|0);
 $22 = $rowCount&255;
 HEAP8[$21>>0] = $22;
 $23 = (($2) + 17|0);
 $24 = $colCount&255;
 HEAP8[$23>>0] = $24;
 $25 = (($2) + 18|0);
 HEAP8[$25>>0] = 1;
 __ZN13dynamic_arrayIN20GpuProgramParameters14ValueParameterELj4EE9push_backERKS1_($values$0$i,$2);
 $26 = (($this) + 156|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 68)|0;
 HEAP32[$26>>2] = $28;
 $29 = (($this) + 160|0);
 HEAP32[$29>>2] = 1;
 $30 = ($outNames|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$name>>2]|0;
 $32 = ($31|0)!=(-1);
 $33 = ($31>>>0)>(1073741823);
 $$$i = $32 & $33;
 if ($$$i) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$outNames>>2]|0;
 $35 = (($outNames) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36;
 $38 = $34;
 $39 = (($37) - ($38))|0;
 $40 = $39 >> 2;
 $41 = ($40|0)==(0);
 if ($41) {
  $51 = $34;
 } else {
  $44 = $34;$__len$03$i$i$i$i$i = $40;
  while(1) {
   $42 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $43 = (($44) + ($42<<2)|0);
   $45 = HEAP32[$43>>2]|0;
   $46 = ($45|0)<($31|0);
   if ($46) {
    $$sum$i$i$i$i$i = (($42) + 1)|0;
    $47 = (($44) + ($$sum$i$i$i$i$i<<2)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $48 = (($$neg2$i$i$i$i$i) - ($42))|0;
    $57 = $47;$__len$0$be$i$i$i$i$i = $48;
   } else {
    $57 = $44;$__len$0$be$i$i$i$i$i = $42;
   }
   $49 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($49) {
    $51 = $57;
    break;
   } else {
    $44 = $57;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $50 = ($51|0)==($36|0);
 if (!($50)) {
  $52 = HEAP32[$51>>2]|0;
  $53 = ($31|0)<($52|0);
  if (!($53)) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$1>>2] = $51;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($0,$outNames,$$byval_copy,$name);
 $54 = (($outNames) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 68)|0;
 HEAP32[$54>>2] = $56;
 STACKTOP = sp;return;
}
function __ZN20GpuProgramParameters15AddTextureParamEiiPKc16TextureDimensionP16PropertyNamesSet($this,$index,$samplerIndex,$nameStr,$dim,$outNames) {
 $this = $this|0;
 $index = $index|0;
 $samplerIndex = $samplerIndex|0;
 $nameStr = $nameStr|0;
 $dim = $dim|0;
 $outNames = $outNames|0;
 var $$$i = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$byval_copy = 0, $$neg2$i$i$i$i$i = 0, $$pre$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $name = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $name = sp + 8|0;
 HEAP32[$$byval_copy>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy,$nameStr);
 $2 = HEAP32[$$byval_copy>>2]|0;
 HEAP32[$name>>2] = $2;
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $4;
  $17 = $15;
  $18 = (($16) - ($17))|0;
  $19 = $18 >> 4;
  $20 = (($19) + 1)|0;
  $21 = ($20>>>0)>(268435455);
  if ($21) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $22 = ($19>>>0)<(134217727);
  if ($22) {
   $23 = $18 >> 3;
   $24 = ($23>>>0)<($20>>>0);
   $25 = $24 ? $20 : $23;
   $26 = ($25|0)==(0);
   if ($26) {
    $$0$i3$i$i = 0;$30 = 0;
   } else {
    $$0$i2$i$i = $25;
    label = 9;
   }
  } else {
   $$0$i2$i$i = 268435455;
   label = 9;
  }
  if ((label|0) == 9) {
   $27 = $$0$i2$i$i << 4;
   $28 = (__Znwj($27)|0);
   $$0$i3$i$i = $$0$i2$i$i;$30 = $28;
  }
  $29 = (($30) + ($19<<4)|0);
  $31 = (($30) + ($$0$i3$i$i<<4)|0);
  $32 = ($29|0)==(0|0);
  if (!($32)) {
   HEAP32[$29>>2] = $2;
   $33 = ((($30) + ($19<<4)|0) + 4|0);
   HEAP32[$33>>2] = $index;
   $34 = ((($30) + ($19<<4)|0) + 8|0);
   HEAP32[$34>>2] = $samplerIndex;
   $35 = ((($30) + ($19<<4)|0) + 12|0);
   HEAP32[$35>>2] = $dim;
  }
  $36 = (($30) + ($20<<4)|0);
  _memcpy(($30|0),($15|0),($18|0))|0;
  HEAP32[$14>>2] = $30;
  HEAP32[$3>>2] = $36;
  HEAP32[$5>>2] = $31;
  $37 = ($15|0)==(0|0);
  if (!($37)) {
   __ZdlPv($15);
  }
 } else {
  $8 = ($4|0)==(0|0);
  if ($8) {
   $13 = 0;
  } else {
   HEAP32[$4>>2] = $2;
   $9 = (($4) + 4|0);
   HEAP32[$9>>2] = $index;
   $10 = (($4) + 8|0);
   HEAP32[$10>>2] = $samplerIndex;
   $11 = (($4) + 12|0);
   HEAP32[$11>>2] = $dim;
   $$pre$i = HEAP32[$3>>2]|0;
   $13 = $$pre$i;
  }
  $12 = (($13) + 16|0);
  HEAP32[$3>>2] = $12;
 }
 $38 = (($this) + 156|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 12)|0;
 HEAP32[$38>>2] = $40;
 $41 = (($this) + 160|0);
 HEAP32[$41>>2] = 1;
 $42 = ($outNames|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = HEAP32[$name>>2]|0;
 $44 = ($43|0)!=(-1);
 $45 = ($43>>>0)>(1073741823);
 $$$i = $44 & $45;
 if ($$$i) {
  STACKTOP = sp;return;
 }
 $46 = HEAP32[$outNames>>2]|0;
 $47 = (($outNames) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48;
 $50 = $46;
 $51 = (($49) - ($50))|0;
 $52 = $51 >> 2;
 $53 = ($52|0)==(0);
 if ($53) {
  $63 = $46;
 } else {
  $56 = $46;$__len$03$i$i$i$i$i = $52;
  while(1) {
   $54 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $55 = (($56) + ($54<<2)|0);
   $57 = HEAP32[$55>>2]|0;
   $58 = ($57|0)<($43|0);
   if ($58) {
    $$sum$i$i$i$i$i = (($54) + 1)|0;
    $59 = (($56) + ($$sum$i$i$i$i$i<<2)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $60 = (($$neg2$i$i$i$i$i) - ($54))|0;
    $69 = $59;$__len$0$be$i$i$i$i$i = $60;
   } else {
    $69 = $56;$__len$0$be$i$i$i$i$i = $54;
   }
   $61 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($61) {
    $63 = $69;
    break;
   } else {
    $56 = $69;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $62 = ($63|0)==($48|0);
 if (!($62)) {
  $64 = HEAP32[$63>>2]|0;
  $65 = ($43|0)<($64|0);
  if (!($65)) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$1>>2] = $63;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($0,$outNames,$$byval_copy,$name);
 $66 = (($outNames) + 12|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 12)|0;
 HEAP32[$66>>2] = $68;
 STACKTOP = sp;return;
}
function __ZN20GpuProgramParameters14AddBufferParamEiPKcP16PropertyNamesSet($this,$index,$nameStr,$outNames) {
 $this = $this|0;
 $index = $index|0;
 $nameStr = $nameStr|0;
 $outNames = $outNames|0;
 var $$$i = 0, $$byval_copy2 = 0, $$neg2$i$i$i$i$i = 0, $$pre$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $name = sp + 8|0;
 HEAP32[$$byval_copy2>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy2,$nameStr);
 $2 = HEAP32[$$byval_copy2>>2]|0;
 HEAP32[$name>>2] = $2;
 $3 = (($this) + 44|0);
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$4>>2] = $6;
 $7 = (($this) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($6>>>0)>($9>>>0);
 if ($10) {
  $11 = $8 << 1;
  $12 = ($11|0)==(0);
  $13 = $12 ? 1 : $11;
  $14 = ($9>>>0)<($13>>>0);
  do {
   if ($14) {
    $15 = ($8|0)>(-1);
    if ($15) {
     HEAP32[$7>>2] = $13;
     $16 = HEAP32[$3>>2]|0;
     $17 = $13 << 3;
     $18 = (($this) + 48|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$0>>2] = $19;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($16,$17,4,$$byval_copy2,0,599472,370)|0);
     HEAP32[$3>>2] = $20;
     break;
    } else {
     $21 = $13 << 3;
     $22 = (($this) + 48|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,4,$$byval_copy2,0,599472,352)|0);
     $25 = HEAP32[$3>>2]|0;
     $26 = HEAP32[$4>>2]|0;
     $27 = $26 << 3;
     _memcpy(($24|0),($25|0),($27|0))|0;
     HEAP32[$7>>2] = $13;
     HEAP32[$3>>2] = $24;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$4>>2]|0;
  $29 = $$pre$i$i;
 } else {
  $29 = $6;
 }
 $28 = (($29) + -1)|0;
 $30 = HEAP32[$3>>2]|0;
 $31 = (($30) + ($28<<3)|0);
 $32 = $31;
 $33 = $32;
 HEAP32[$33>>2] = $2;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $index;
 $36 = (($this) + 156|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 4)|0;
 HEAP32[$36>>2] = $38;
 $39 = ($outNames|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$name>>2]|0;
 $41 = ($40|0)!=(-1);
 $42 = ($40>>>0)>(1073741823);
 $$$i = $41 & $42;
 if ($$$i) {
  STACKTOP = sp;return;
 }
 $43 = HEAP32[$outNames>>2]|0;
 $44 = (($outNames) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45;
 $47 = $43;
 $48 = (($46) - ($47))|0;
 $49 = $48 >> 2;
 $50 = ($49|0)==(0);
 if ($50) {
  $60 = $43;
 } else {
  $53 = $43;$__len$03$i$i$i$i$i = $49;
  while(1) {
   $51 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $52 = (($53) + ($51<<2)|0);
   $54 = HEAP32[$52>>2]|0;
   $55 = ($54|0)<($40|0);
   if ($55) {
    $$sum$i$i$i$i$i = (($51) + 1)|0;
    $56 = (($53) + ($$sum$i$i$i$i$i<<2)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $57 = (($$neg2$i$i$i$i$i) - ($51))|0;
    $66 = $56;$__len$0$be$i$i$i$i$i = $57;
   } else {
    $66 = $53;$__len$0$be$i$i$i$i$i = $51;
   }
   $58 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($58) {
    $60 = $66;
    break;
   } else {
    $53 = $66;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $59 = ($60|0)==($45|0);
 if (!($59)) {
  $61 = HEAP32[$60>>2]|0;
  $62 = ($40|0)<($61|0);
  if (!($62)) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$1>>2] = $60;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($0,$outNames,$$byval_copy2,$name);
 $63 = (($outNames) + 12|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + 4)|0;
 HEAP32[$63>>2] = $65;
 STACKTOP = sp;return;
}
function __ZNK20GpuProgramParameters14GetValueParamsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if ($2) {
  __ZN20GpuProgramParameters9MakeReadyEv($this);
 }
 STACKTOP = sp;return ($this|0);
}
function __ZN20GpuProgramParameters9MakeReadyEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cb$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 160|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(1);
 if (!($3)) {
  HEAP32[$1>>2] = 2;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 16|0);
 $5 = (($this) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(-1);
 if ($7) {
  $8 = HEAP32[$4>>2]|0;
  $9 = (($this) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($8,$$byval_copy);
  HEAP32[$4>>2] = 0;
 }
 $11 = (($this) + 24|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$5>>2] = 0;
 __ZN20GpuProgramParameters20MakeValueParamsReadyER13dynamic_arrayINS_14ValueParameterELj4EEi($this,$this,-1);
 $12 = (($this) + 64|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 60|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==($15|0);
 if (!($16)) {
  $18 = $15;$cb$01 = 0;
  while(1) {
   $17 = ((($18) + (($cb$01*28)|0)|0) + 4|0);
   __ZN20GpuProgramParameters20MakeValueParamsReadyER13dynamic_arrayINS_14ValueParameterELj4EEi($this,$17,$cb$01);
   $19 = (($cb$01) + 1)|0;
   $20 = HEAP32[$12>>2]|0;
   $21 = HEAP32[$14>>2]|0;
   $22 = $20;
   $23 = $21;
   $24 = (($22) - ($23))|0;
   $25 = (($24|0) / 28)&-1;
   $26 = ($19>>>0)<($25>>>0);
   if ($26) {
    $18 = $21;$cb$01 = $19;
   } else {
    break;
   }
  }
 }
 $27 = HEAP32[$4>>2]|0;
 $28 = HEAP32[$11>>2]|0;
 $29 = (($27) + ($28<<3)|0);
 __ZNSt3__16__sortIRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEvT0_S7_T_($27,$29,$$byval_copy);
 HEAP32[$1>>2] = 2;
 STACKTOP = sp;return;
}
function __ZNK20GpuProgramParameters16FindTextureParamERKN9ShaderLab16FastPropertyNameE16TextureDimension($this,$name,$dim) {
 $this = $this|0;
 $name = $name|0;
 $dim = $dim|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$name>>2]|0;
 $7 = $1;
 while(1) {
  $6 = HEAP32[$7>>2]|0;
  $8 = ($6|0)==($5|0);
  if ($8) {
   $9 = (($7) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($dim|0);
   if ($11) {
    $$0 = $7;
    label = 6;
    break;
   }
  }
  $12 = (($7) + 16|0);
  $13 = ($12|0)==($3|0);
  if ($13) {
   $$0 = 0;
   label = 6;
   break;
  } else {
   $7 = $12;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK20GpuProgramParameters9FindParamERKN9ShaderLab16FastPropertyNameEPi($this,$name,$outCBIndex) {
 $this = $this|0;
 $name = $name|0;
 $outCBIndex = $outCBIndex|0;
 var $$0$lcssa$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $param$0 = 0, $values$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$name>>2]|0;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + ($4<<3)|0);
 $6 = ($4|0)==(0);
 L1: do {
  if ($6) {
   $$0$lcssa$i = $2;
  } else {
   $$01$i = $2;
   while(1) {
    $9 = HEAP32[$$01$i>>2]|0;
    $10 = ($9|0)==($0|0);
    $8 = (($$01$i) + 8|0);
    if ($10) {
     $$0$lcssa$i = $$01$i;
     break L1;
    }
    $7 = ($8|0)==($5|0);
    if ($7) {
     $param$0 = 0;
     break;
    } else {
     $$01$i = $8;
    }
   }
   STACKTOP = sp;return ($param$0|0);
  }
 } while(0);
 $11 = ($$0$lcssa$i|0)==($5|0);
 if ($11) {
  $param$0 = 0;
  STACKTOP = sp;return ($param$0|0);
 }
 $12 = (($$0$lcssa$i) + 4|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = ($13<<16>>16)>(-1);
 if ($14) {
  $15 = $13 << 16 >> 16;
  $16 = (($this) + 60|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($17) + (($15*28)|0)|0) + 4|0);
  $values$0$i = $18;
 } else {
  $values$0$i = $this;
 }
 $19 = (($$0$lcssa$i) + 6|0);
 $20 = HEAP16[$19>>1]|0;
 $21 = $20&65535;
 $22 = HEAP32[$values$0$i>>2]|0;
 $23 = (($22) + (($21*20)|0)|0);
 $24 = ($outCBIndex|0)==(0|0);
 if ($24) {
  $param$0 = $23;
  STACKTOP = sp;return ($param$0|0);
 }
 $25 = $13 << 16 >> 16;
 HEAP32[$outCBIndex>>2] = $25;
 $param$0 = $23;
 STACKTOP = sp;return ($param$0|0);
}
function __ZNK20GpuProgramParameters13PrepareValuesEPKN9ShaderLab13PropertySheetERKNS0_17ShaderPassContextEPhPKhP12GfxPatchInfoPb($this,$props,$passContext,$buffer,$bufferStart,$outPatchInfo,$outMissingTextures) {
 $this = $this|0;
 $props = $props|0;
 $passContext = $passContext|0;
 $buffer = $buffer|0;
 $bufferStart = $bufferStart|0;
 $outPatchInfo = $outPatchInfo|0;
 $outMissingTextures = $outMissingTextures|0;
 var $$$i = 0, $$0$lcssa = 0, $$015 = 0, $$1$lcssa = 0, $$19 = 0, $$19$us = 0, $$2$lcssa = 0, $$28 = 0, $$28$us = 0, $$byval_copy4 = 0, $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx2$val = 0, $$idx3 = 0, $$idx3$val = 0, $$pn = 0, $$pn$in = 0, $$pn$in$in = 0;
 var $$pn$in$in$in = 0, $$pn31 = 0, $$pn31$in = 0, $$pn31$in$in = 0, $$pn31$in$in$in = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$014 = 0, $i2$07 = 0, $i2$07$us = 0, $location = 0, $location$i = 0, $location$off$i = 0, $name = 0, $scevgep26 = 0, $split = 0, $split13 = 0, $uglygep28 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 20|0;
 $location$i = sp;
 $0 = sp + 4|0;
 $name = sp + 8|0;
 $location = sp + 12|0;
 $1 = sp + 16|0;
 $2 = (($this) + 160|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1);
 if ($4) {
  __ZN20GpuProgramParameters9MakeReadyEv($this);
 }
 $$idx2$val = HEAP32[$this>>2]|0;
 $$idx3 = (($this) + 8|0);
 $$idx3$val = HEAP32[$$idx3>>2]|0;
 $5 = (__ZL22PrepareValueParametersRK13dynamic_arrayIN20GpuProgramParameters14ValueParameterELj4EEPKN9ShaderLab13PropertySheetERKNS5_17ShaderPassContextEPhPKhP12GfxPatchInfo($$idx2$val,$$idx3$val,$props,$passContext,$buffer,$bufferStart,$outPatchInfo)|0);
 $6 = (($this) + 64|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if ($10) {
  $$0$lcssa = $5;
 } else {
  $$015 = $5;$11 = $9;$i$014 = 0;
  while(1) {
   $$idx = ((($11) + (($i$014*28)|0)|0) + 4|0);
   $$idx$val = HEAP32[$$idx>>2]|0;
   $$idx1 = ((($11) + (($i$014*28)|0)|0) + 12|0);
   $$idx1$val = HEAP32[$$idx1>>2]|0;
   $12 = (__ZL22PrepareValueParametersRK13dynamic_arrayIN20GpuProgramParameters14ValueParameterELj4EEPKN9ShaderLab13PropertySheetERKNS5_17ShaderPassContextEPhPKhP12GfxPatchInfo($$idx$val,$$idx1$val,$props,$passContext,$$015,$bufferStart,$outPatchInfo)|0);
   $13 = (($i$014) + 1)|0;
   $14 = HEAP32[$6>>2]|0;
   $15 = HEAP32[$8>>2]|0;
   $16 = $14;
   $17 = $15;
   $18 = (($16) - ($17))|0;
   $19 = (($18|0) / 28)&-1;
   $20 = ($13>>>0)<($19>>>0);
   if ($20) {
    $$015 = $12;$11 = $15;$i$014 = $13;
   } else {
    $$0$lcssa = $12;
    break;
   }
  }
 }
 $21 = (($this) + 36|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($22|0);
 if ($25) {
  $$1$lcssa = $$0$lcssa;
 } else {
  $26 = $24;
  $27 = ($outPatchInfo|0)==(0|0);
  $scevgep26 = (($22) + -16|0);
  $28 = (0 - ($26))|0;
  $uglygep28 = (($scevgep26) + ($28)|0);
  if ($27) {
   $$19$us = $$0$lcssa;$30 = $24;
   while(1) {
    $29 = HEAP32[$30>>2]|0;
    HEAP32[$name>>2] = $29;
    $31 = (($30) + 12|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$0>>2] = $29;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $33 = (__ZN9ShaderLab11shaderprops9GetTexEnvEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameE16TextureDimensionRNS0_16PropertyLocationE($props,$passContext,$$byval_copy4,$32,$location$i)|0);
    __ZNK9ShaderLab6TexEnv11PrepareDataEP10TexEnvData($33,$$19$us);
    $34 = (($$19$us) + 12|0);
    $35 = (($30) + 16|0);
    $36 = ($35|0)==($22|0);
    if ($36) {
     break;
    } else {
     $$19$us = $34;$30 = $35;
    }
   }
  } else {
   $$19 = $$0$lcssa;$38 = $24;
   while(1) {
    $37 = HEAP32[$38>>2]|0;
    HEAP32[$name>>2] = $37;
    $39 = (($38) + 12|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (__ZN12GfxPatchInfo18AddPatchableTexEnvERKN9ShaderLab16FastPropertyNameE16TextureDimensionP10TexEnvDataP8Vector4fPKvPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($outPatchInfo,$name,$40,$$19,0,$bufferStart,$props,$passContext)|0);
    if (!($41)) {
     HEAP8[$outMissingTextures>>0] = 1;
    }
    $42 = (($$19) + 12|0);
    $43 = (($38) + 16|0);
    $44 = ($43|0)==($22|0);
    if ($44) {
     break;
    } else {
     $$19 = $42;$38 = $43;
    }
   }
  }
  $$pn$in$in$in = $uglygep28;
  $$pn$in$in = $$pn$in$in$in >>> 4;
  $$pn$in = ($$pn$in$in*12)|0;
  $$pn = (($$pn$in) + 12)|0;
  $split13 = (($$0$lcssa) + ($$pn)|0);
  $$1$lcssa = $split13;
 }
 $45 = (($this) + 44|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($this) + 52|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + ($48<<3)|0);
 $50 = ($48|0)==(0);
 if ($50) {
  $$2$lcssa = $$1$lcssa;
  STACKTOP = sp;return ($$2$lcssa|0);
 }
 $51 = ($outPatchInfo|0)==(0|0);
 $52 = $bufferStart;
 $53 = (($outPatchInfo) + 56|0);
 $54 = (($outPatchInfo) + 60|0);
 $55 = (($outPatchInfo) + 48|0);
 $56 = (($outPatchInfo) + 52|0);
 if ($51) {
  $$28$us = $$1$lcssa;$i2$07$us = $46;
  while(1) {
   $57 = HEAP32[$i2$07$us>>2]|0;
   HEAP32[$1>>2] = $57;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   $58 = (__ZN9ShaderLab11shaderprops16GetComputeBufferEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy4,$location)|0);
   $59 = HEAP32[$58>>2]|0;
   HEAP32[$$28$us>>2] = $59;
   $60 = (($$28$us) + 4|0);
   $61 = (($i2$07$us) + 8|0);
   $62 = ($61|0)==($49|0);
   if ($62) {
    break;
   } else {
    $$28$us = $60;$i2$07$us = $61;
   }
  }
 } else {
  $$28 = $$1$lcssa;$i2$07 = $46;
  while(1) {
   $63 = HEAP32[$i2$07>>2]|0;
   HEAP32[$1>>2] = $63;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   $64 = (__ZN9ShaderLab11shaderprops16GetComputeBufferEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy4,$location)|0);
   $65 = HEAP32[$location>>2]|0;
   $66 = ($65|0)==(4);
   $location$off$i = (($65) + -1)|0;
   $67 = ($location$off$i>>>0)<(2);
   $$$i = $67 | $66;
   if ($$$i) {
    $68 = $66 ? 0 : $64;
    $69 = $$28;
    $70 = (($69) - ($52))|0;
    $71 = HEAP32[$i2$07>>2]|0;
    $72 = HEAP32[$53>>2]|0;
    $73 = (($72) + 1)|0;
    HEAP32[$53>>2] = $73;
    $74 = HEAP32[$54>>2]|0;
    $75 = $74 & 2147483647;
    $76 = ($73>>>0)>($75>>>0);
    if ($76) {
     $77 = $74 << 1;
     $78 = ($77|0)==(0);
     $79 = $78 ? 1 : $77;
     $80 = ($75>>>0)<($79>>>0);
     do {
      if ($80) {
       $81 = ($74|0)>(-1);
       if ($81) {
        HEAP32[$54>>2] = $79;
        $82 = HEAP32[$55>>2]|0;
        $83 = ($79*12)|0;
        $84 = HEAP32[$56>>2]|0;
        HEAP32[$location$i>>2] = $84;
        ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$location$i+0>>2]|0;
        $85 = (__Z16realloc_internalPvji10MemLabelIdiPKci($82,$83,4,$$byval_copy4,0,599472,370)|0);
        HEAP32[$55>>2] = $85;
        break;
       } else {
        $86 = ($79*12)|0;
        $87 = HEAP32[$56>>2]|0;
        HEAP32[$location$i>>2] = $87;
        ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$location$i+0>>2]|0;
        $88 = (__Z15malloc_internaljj10MemLabelIdiPKci($86,4,$$byval_copy4,0,599472,352)|0);
        $89 = HEAP32[$55>>2]|0;
        $90 = HEAP32[$53>>2]|0;
        $91 = ($90*12)|0;
        _memcpy(($88|0),($89|0),($91|0))|0;
        HEAP32[$54>>2] = $79;
        HEAP32[$55>>2] = $88;
        break;
       }
      }
     } while(0);
     $$pre$i$i$i = HEAP32[$53>>2]|0;
     $93 = $$pre$i$i$i;
    } else {
     $93 = $73;
    }
    $92 = (($93) + -1)|0;
    $94 = HEAP32[$55>>2]|0;
    $95 = (($94) + (($92*12)|0)|0);
    HEAP32[$95>>2] = $71;
    $96 = ((($94) + (($92*12)|0)|0) + 4|0);
    HEAP32[$96>>2] = $68;
    $97 = ((($94) + (($92*12)|0)|0) + 8|0);
    HEAP32[$97>>2] = $70;
   }
   $98 = HEAP32[$64>>2]|0;
   HEAP32[$$28>>2] = $98;
   $99 = (($$28) + 4|0);
   $100 = (($i2$07) + 8|0);
   $101 = ($100|0)==($49|0);
   if ($101) {
    break;
   } else {
    $$28 = $99;$i2$07 = $100;
   }
  }
 }
 $$pn31$in$in$in = $48 << 3;
 $$pn31$in$in = (($$pn31$in$in$in) + -8)|0;
 $$pn31$in = $$pn31$in$in >>> 1;
 $$pn31 = (($$pn31$in) + 4)|0;
 $split = (($$1$lcssa) + ($$pn31)|0);
 $$2$lcssa = $split;
 STACKTOP = sp;return ($$2$lcssa|0);
}
function __ZL22PrepareValueParametersRK13dynamic_arrayIN20GpuProgramParameters14ValueParameterELj4EEPKN9ShaderLab13PropertySheetERKNS5_17ShaderPassContextEPhPKhP12GfxPatchInfo($valueParams$0$0$val,$valueParams$0$2$val,$props,$passContext,$buffer,$bufferStart,$outPatchInfo) {
 $valueParams$0$0$val = $valueParams$0$0$val|0;
 $valueParams$0$2$val = $valueParams$0$2$val|0;
 $props = $props|0;
 $passContext = $passContext|0;
 $buffer = $buffer|0;
 $bufferStart = $bufferStart|0;
 $outPatchInfo = $outPatchInfo|0;
 var $$$i = 0, $$$i10 = 0, $$$i2 = 0, $$0$lcssa = 0, $$08 = 0, $$1 = 0, $$byval_copy8 = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$07 = 0, $location = 0, $location$off$i = 0, $location$off$i1 = 0, $location$off$i9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 20|0;
 $0 = sp;
 $location = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = (($valueParams$0$0$val) + (($valueParams$0$2$val*20)|0)|0);
 $5 = ($valueParams$0$2$val|0)==(0);
 if ($5) {
  $$0$lcssa = $buffer;
  STACKTOP = sp;return ($$0$lcssa|0);
 }
 $6 = ($outPatchInfo|0)==(0|0);
 $7 = $bufferStart;
 $8 = (($outPatchInfo) + 8|0);
 $9 = (($outPatchInfo) + 12|0);
 $10 = (($outPatchInfo) + 4|0);
 $11 = (($outPatchInfo) + 24|0);
 $12 = (($outPatchInfo) + 28|0);
 $13 = (($outPatchInfo) + 16|0);
 $14 = (($outPatchInfo) + 20|0);
 $15 = (($outPatchInfo) + 40|0);
 $16 = (($outPatchInfo) + 44|0);
 $17 = (($outPatchInfo) + 32|0);
 $18 = (($outPatchInfo) + 36|0);
 $$08 = $buffer;$i$07 = $valueParams$0$0$val;
 while(1) {
  $19 = HEAP32[$i$07>>2]|0;
  $20 = (($i$07) + 17|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = (($i$07) + 18|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  do {
   if ($24) {
    $25 = (($i$07) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)<(2);
    if ($27) {
     $28 = ($21<<24>>24)==(1);
     if ($28) {
      HEAP32[$1>>2] = $19;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      $29 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location)|0);
      if (!($6)) {
       $30 = HEAP32[$location>>2]|0;
       $31 = ($30|0)==(4);
       $location$off$i = (($30) + -1)|0;
       $32 = ($location$off$i>>>0)<(2);
       $$$i = $32 | $31;
       if ($$$i) {
        $33 = $31 ? 0 : $29;
        $34 = $$08;
        $35 = (($34) - ($7))|0;
        $36 = HEAP32[$8>>2]|0;
        $37 = (($36) + 1)|0;
        HEAP32[$8>>2] = $37;
        $38 = HEAP32[$9>>2]|0;
        $39 = $38 & 2147483647;
        $40 = ($37>>>0)>($39>>>0);
        if ($40) {
         $41 = $38 << 1;
         $42 = ($41|0)==(0);
         $43 = $42 ? 1 : $41;
         $44 = ($39>>>0)<($43>>>0);
         do {
          if ($44) {
           $45 = ($38|0)>(-1);
           if ($45) {
            HEAP32[$9>>2] = $43;
            $46 = HEAP32[$outPatchInfo>>2]|0;
            $47 = ($43*12)|0;
            $48 = HEAP32[$10>>2]|0;
            HEAP32[$0>>2] = $48;
            ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
            $49 = (__Z16realloc_internalPvji10MemLabelIdiPKci($46,$47,4,$$byval_copy8,0,599472,370)|0);
            HEAP32[$outPatchInfo>>2] = $49;
            break;
           } else {
            $50 = ($43*12)|0;
            $51 = HEAP32[$10>>2]|0;
            HEAP32[$0>>2] = $51;
            ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
            $52 = (__Z15malloc_internaljj10MemLabelIdiPKci($50,4,$$byval_copy8,0,599472,352)|0);
            $53 = HEAP32[$outPatchInfo>>2]|0;
            $54 = HEAP32[$8>>2]|0;
            $55 = ($54*12)|0;
            _memcpy(($52|0),($53|0),($55|0))|0;
            HEAP32[$9>>2] = $43;
            HEAP32[$outPatchInfo>>2] = $52;
            break;
           }
          }
         } while(0);
         $$pre$i$i$i6 = HEAP32[$8>>2]|0;
         $57 = $$pre$i$i$i6;
        } else {
         $57 = $37;
        }
        $56 = (($57) + -1)|0;
        $58 = HEAP32[$outPatchInfo>>2]|0;
        $59 = (($58) + (($56*12)|0)|0);
        HEAP32[$59>>2] = $19;
        $60 = ((($58) + (($56*12)|0)|0) + 4|0);
        HEAP32[$60>>2] = $33;
        $61 = ((($58) + (($56*12)|0)|0) + 8|0);
        HEAP32[$61>>2] = $35;
       }
      }
      $62 = Math_fround(HEAPF32[$29>>2]);
      HEAPF32[tempDoublePtr>>2]=$62;HEAP8[$$08>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$$08+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$$08+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$$08+3>>0]=HEAP8[tempDoublePtr+3>>0];
      $63 = (($$08) + 4|0);
      HEAPF32[tempDoublePtr>>2]=Math_fround(0.0);HEAP8[$63>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$63+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$63+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$63+3>>0]=HEAP8[tempDoublePtr+3>>0];
      $64 = (($$08) + 8|0);
      HEAPF32[tempDoublePtr>>2]=Math_fround(0.0);HEAP8[$64>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$64+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$64+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$64+3>>0]=HEAP8[tempDoublePtr+3>>0];
      $65 = (($$08) + 12|0);
      HEAPF32[tempDoublePtr>>2]=Math_fround(0.0);HEAP8[$65>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$65+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$65+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$65+3>>0]=HEAP8[tempDoublePtr+3>>0];
      $66 = (($$08) + 16|0);
      $$1 = $66;
      break;
     } else {
      HEAP32[$2>>2] = $19;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
      $67 = (__ZN9ShaderLab11shaderprops9GetVectorEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location)|0);
      if (!($6)) {
       $68 = HEAP32[$location>>2]|0;
       $69 = ($68|0)==(4);
       $location$off$i9 = (($68) + -1)|0;
       $70 = ($location$off$i9>>>0)<(2);
       $$$i10 = $70 | $69;
       if ($$$i10) {
        $71 = $69 ? 0 : $67;
        $72 = $$08;
        $73 = (($72) - ($7))|0;
        $74 = HEAP32[$11>>2]|0;
        $75 = (($74) + 1)|0;
        HEAP32[$11>>2] = $75;
        $76 = HEAP32[$12>>2]|0;
        $77 = $76 & 2147483647;
        $78 = ($75>>>0)>($77>>>0);
        if ($78) {
         $79 = $76 << 1;
         $80 = ($79|0)==(0);
         $81 = $80 ? 1 : $79;
         $82 = ($77>>>0)<($81>>>0);
         do {
          if ($82) {
           $83 = ($76|0)>(-1);
           if ($83) {
            HEAP32[$12>>2] = $81;
            $84 = HEAP32[$13>>2]|0;
            $85 = ($81*12)|0;
            $86 = HEAP32[$14>>2]|0;
            HEAP32[$0>>2] = $86;
            ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
            $87 = (__Z16realloc_internalPvji10MemLabelIdiPKci($84,$85,4,$$byval_copy8,0,599472,370)|0);
            HEAP32[$13>>2] = $87;
            break;
           } else {
            $88 = ($81*12)|0;
            $89 = HEAP32[$14>>2]|0;
            HEAP32[$0>>2] = $89;
            ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
            $90 = (__Z15malloc_internaljj10MemLabelIdiPKci($88,4,$$byval_copy8,0,599472,352)|0);
            $91 = HEAP32[$13>>2]|0;
            $92 = HEAP32[$11>>2]|0;
            $93 = ($92*12)|0;
            _memcpy(($90|0),($91|0),($93|0))|0;
            HEAP32[$12>>2] = $81;
            HEAP32[$13>>2] = $90;
            break;
           }
          }
         } while(0);
         $$pre$i$i$i3 = HEAP32[$11>>2]|0;
         $95 = $$pre$i$i$i3;
        } else {
         $95 = $75;
        }
        $94 = (($95) + -1)|0;
        $96 = HEAP32[$13>>2]|0;
        $97 = (($96) + (($94*12)|0)|0);
        HEAP32[$97>>2] = $19;
        $98 = ((($96) + (($94*12)|0)|0) + 4|0);
        HEAP32[$98>>2] = $71;
        $99 = ((($96) + (($94*12)|0)|0) + 8|0);
        HEAP32[$99>>2] = $73;
       }
      }
      dest=$$08+0|0; src=$67+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $100 = (($$08) + 16|0);
      $$1 = $100;
      break;
     }
    } else {
     label = 26;
    }
   } else {
    label = 26;
   }
  } while(0);
  if ((label|0) == 26) {
   label = 0;
   HEAP32[$3>>2] = $19;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
   $101 = (__ZN9ShaderLab11shaderprops9GetMatrixEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location)|0);
   HEAP32[$$08>>2] = 16;
   $102 = (($$08) + 4|0);
   if (!($6)) {
    $103 = HEAP32[$location>>2]|0;
    $104 = ($103|0)==(4);
    $location$off$i1 = (($103) + -1)|0;
    $105 = ($location$off$i1>>>0)<(2);
    $$$i2 = $105 | $104;
    if ($$$i2) {
     $106 = $104 ? 0 : $101;
     $107 = $102;
     $108 = (($107) - ($7))|0;
     $109 = HEAP32[$15>>2]|0;
     $110 = (($109) + 1)|0;
     HEAP32[$15>>2] = $110;
     $111 = HEAP32[$16>>2]|0;
     $112 = $111 & 2147483647;
     $113 = ($110>>>0)>($112>>>0);
     if ($113) {
      $114 = $111 << 1;
      $115 = ($114|0)==(0);
      $116 = $115 ? 1 : $114;
      $117 = ($112>>>0)<($116>>>0);
      do {
       if ($117) {
        $118 = ($111|0)>(-1);
        if ($118) {
         HEAP32[$16>>2] = $116;
         $119 = HEAP32[$17>>2]|0;
         $120 = ($116*12)|0;
         $121 = HEAP32[$18>>2]|0;
         HEAP32[$0>>2] = $121;
         ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
         $122 = (__Z16realloc_internalPvji10MemLabelIdiPKci($119,$120,4,$$byval_copy8,0,599472,370)|0);
         HEAP32[$17>>2] = $122;
         break;
        } else {
         $123 = ($116*12)|0;
         $124 = HEAP32[$18>>2]|0;
         HEAP32[$0>>2] = $124;
         ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
         $125 = (__Z15malloc_internaljj10MemLabelIdiPKci($123,4,$$byval_copy8,0,599472,352)|0);
         $126 = HEAP32[$17>>2]|0;
         $127 = HEAP32[$15>>2]|0;
         $128 = ($127*12)|0;
         _memcpy(($125|0),($126|0),($128|0))|0;
         HEAP32[$16>>2] = $116;
         HEAP32[$17>>2] = $125;
         break;
        }
       }
      } while(0);
      $$pre$i$i$i = HEAP32[$15>>2]|0;
      $130 = $$pre$i$i$i;
     } else {
      $130 = $110;
     }
     $129 = (($130) + -1)|0;
     $131 = HEAP32[$17>>2]|0;
     $132 = (($131) + (($129*12)|0)|0);
     HEAP32[$132>>2] = $19;
     $133 = ((($131) + (($129*12)|0)|0) + 4|0);
     HEAP32[$133>>2] = $106;
     $134 = ((($131) + (($129*12)|0)|0) + 8|0);
     HEAP32[$134>>2] = $108;
    }
   }
   dest=$102+0|0; src=$101+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $135 = (($$08) + 68|0);
   $$1 = $135;
  }
  $136 = (($i$07) + 20|0);
  $137 = ($136|0)==($4|0);
  if ($137) {
   $$0$lcssa = $$1;
   break;
  } else {
   $$08 = $$1;$i$07 = $136;
  }
 }
 STACKTOP = sp;return ($$0$lcssa|0);
}
function __ZN20GpuProgramParameters20MakeValueParamsReadyER13dynamic_arrayINS_14ValueParameterELj4EEi($this,$values,$cbIndex) {
 $this = $this|0;
 $values = $values|0;
 $cbIndex = $cbIndex|0;
 var $$byval_copy1 = 0, $$mask1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[$values>>2]|0;
 $2 = (($values) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + (($3*20)|0)|0);
 __ZNSt3__16__sortIRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEvT0_S7_T_($1,$4,$$byval_copy1);
 $5 = HEAP32[$2>>2]|0;
 $6 = ($5|0)>(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 24|0);
 $8 = (($this) + 28|0);
 $9 = (($this) + 16|0);
 $10 = (($this) + 20|0);
 $$mask1 = $cbIndex & 65535;
 $i$02 = 0;
 while(1) {
  $11 = HEAP32[$values>>2]|0;
  $12 = (($11) + (($i$02*20)|0)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$7>>2]|0;
  $15 = (($14) + 1)|0;
  HEAP32[$7>>2] = $15;
  $16 = HEAP32[$8>>2]|0;
  $17 = $16 & 2147483647;
  $18 = ($15>>>0)>($17>>>0);
  if ($18) {
   $19 = $16 << 1;
   $20 = ($19|0)==(0);
   $21 = $20 ? 1 : $19;
   $22 = ($17>>>0)<($21>>>0);
   do {
    if ($22) {
     $23 = ($16|0)>(-1);
     if ($23) {
      HEAP32[$8>>2] = $21;
      $24 = HEAP32[$9>>2]|0;
      $25 = $21 << 3;
      $26 = HEAP32[$10>>2]|0;
      HEAP32[$0>>2] = $26;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $27 = (__Z16realloc_internalPvji10MemLabelIdiPKci($24,$25,4,$$byval_copy1,0,599472,370)|0);
      HEAP32[$9>>2] = $27;
      break;
     } else {
      $28 = $21 << 3;
      $29 = HEAP32[$10>>2]|0;
      HEAP32[$0>>2] = $29;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,4,$$byval_copy1,0,599472,352)|0);
      $31 = HEAP32[$9>>2]|0;
      $32 = HEAP32[$7>>2]|0;
      $33 = $32 << 3;
      _memcpy(($30|0),($31|0),($33|0))|0;
      HEAP32[$8>>2] = $21;
      HEAP32[$9>>2] = $30;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$7>>2]|0;
   $35 = $$pre$i$i;
  } else {
   $35 = $15;
  }
  $34 = (($35) + -1)|0;
  $36 = HEAP32[$9>>2]|0;
  $37 = (($36) + ($34<<3)|0);
  $38 = (_bitshift64Shl(($i$02|0),0,48)|0);
  $39 = tempRet0;
  $40 = $39 | $$mask1;
  $41 = $38 | $13;
  $42 = $37;
  $43 = $42;
  HEAP32[$43>>2] = $41;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $40;
  $46 = (($i$02) + 1)|0;
  $exitcond = ($46|0)==($5|0);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $46;
  }
 }
 STACKTOP = sp;return;
}
function __Z21CheckGpuProgramUsablePKc($str) {
 $str = $str|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($0) + 5928|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(4);
 do {
  if ($3) {
   $$0 = 0;
  } else {
   $4 = (_strncmp($str,598928,6)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $$0 = 1;
   } else {
    $6 = (_strncmp($str,598936,7)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     $$0 = 1;
    } else {
     $8 = (_strncmp($str,598944,6)|0);
     $9 = ($8|0)==(0);
     if ($9) {
      $not$ = ($2|0)!=(8);
      $$ = $not$&1;
      $$0 = $$;
      break;
     }
     $10 = (_strncmp($str,598952,6)|0);
     $11 = ($10|0)==(0);
     if ($11) {
      $$0 = 1;
     } else {
      $12 = (_strncmp($str,598960,6)|0);
      $13 = ($12|0)==(0);
      if ($13) {
       $$0 = 1;
      } else {
       $14 = (_strncmp($str,598968,6)|0);
       $15 = ($14|0)==(0);
       if ($15) {
        $$0 = 1;
       } else {
        $16 = (_strncmp($str,598976,6)|0);
        $17 = ($16|0)==(0);
        if ($17) {
         $$0 = 1;
        } else {
         $18 = (_strncmp($str,598984,14)|0);
         $19 = ($18|0)==(0);
         if ($19) {
          $$0 = 1;
         } else {
          $20 = (_strncmp($str,599000,14)|0);
          $21 = ($20|0)==(0);
          if ($21) {
           $$0 = 1;
          } else {
           $22 = (_strncmp($str,599016,7)|0);
           $23 = ($22|0)==(0);
           if ($23) {
            $$0 = 1;
           } else {
            $24 = (_strncmp($str,599024,6)|0);
            $25 = ($24|0)==(0);
            if ($25) {
             $$0 = 1;
            } else {
             $26 = (_strncmp($str,599032,6)|0);
             $27 = ($26|0)==(0);
             if ($27) {
              $$0 = 1;
             } else {
              $28 = (_strncmp($str,599040,7)|0);
              $29 = ($28|0)==(0);
              if ($29) {
               $$0 = 1;
              } else {
               $30 = (_strncmp($str,599048,6)|0);
               $31 = ($30|0)==(0);
               if ($31) {
                $$0 = 1;
               } else {
                $32 = (_strncmp($str,599056,6)|0);
                $33 = ($32|0)==(0);
                if ($33) {
                 $$0 = 1;
                } else {
                 $34 = (_strncmp($str,599064,6)|0);
                 $35 = ($34|0)==(0);
                 if ($35) {
                  $$0 = 1;
                 } else {
                  $36 = (_strncmp($str,599072,6)|0);
                  $37 = ($36|0)==(0);
                  if ($37) {
                   $$0 = 1;
                  } else {
                   $38 = (_strncmp($str,599080,6)|0);
                   $39 = ($38|0)==(0);
                   if ($39) {
                    $$0 = 1;
                   } else {
                    $40 = (_strncmp($str,599088,6)|0);
                    $41 = ($40|0)==(0);
                    if ($41) {
                     $$0 = 1;
                     break;
                    }
                    $42 = (_strncmp($str,599096,6)|0);
                    $43 = ($42|0)==(0);
                    if ($43) {
                     $$0 = 1;
                     break;
                    }
                    $44 = (_strncmp($str,599104,6)|0);
                    $45 = ($44|0)==(0);
                    if ($45) {
                     $$0 = 1;
                     break;
                    }
                    $46 = (_strncmp($str,599112,10)|0);
                    $47 = ($46|0)==(0);
                    if ($47) {
                     $$0 = 1;
                     break;
                    }
                    $48 = (_strncmp($str,599128,10)|0);
                    $49 = ($48|0)==(0);
                    if ($49) {
                     $$0 = 1;
                     break;
                    }
                    $50 = (_strncmp($str,599144,11)|0);
                    $51 = ($50|0)==(0);
                    if ($51) {
                     $$0 = 1;
                     break;
                    }
                    $52 = (_strncmp($str,599160,11)|0);
                    $53 = ($52|0)==(0);
                    if ($53) {
                     $$0 = 1;
                     break;
                    }
                    $54 = (_strncmp($str,599176,10)|0);
                    $55 = ($54|0)==(0);
                    if ($55) {
                     $$0 = 1;
                     break;
                    }
                    $56 = (_strncmp($str,599192,10)|0);
                    $57 = ($56|0)==(0);
                    if ($57) {
                     $$0 = 1;
                     break;
                    }
                    $58 = (_strncmp($str,599208,6)|0);
                    $59 = ($58|0)==(0);
                    if ($59) {
                     $$0 = 1;
                     break;
                    }
                    $60 = (_strncmp($str,599216,6)|0);
                    $61 = ($60|0)==(0);
                    if ($61) {
                     $$0 = 1;
                     break;
                    }
                    $62 = (_strncmp($str,599224,6)|0);
                    $63 = ($62|0)==(0);
                    if ($63) {
                     $$0 = 1;
                     break;
                    }
                    $64 = (_strncmp($str,599232,6)|0);
                    $65 = ($64|0)==(0);
                    if ($65) {
                     $$0 = 1;
                     break;
                    }
                    $66 = (_strncmp($str,599240,6)|0);
                    $67 = ($66|0)==(0);
                    if ($67) {
                     $$0 = 1;
                     break;
                    }
                    $68 = (_strncmp($str,599248,8)|0);
                    $69 = ($68|0)==(0);
                    if ($69) {
                     $$0 = 1;
                     break;
                    }
                    $70 = (_strncmp($str,599264,8)|0);
                    $71 = ($70|0)==(0);
                    if ($71) {
                     $$0 = 1;
                     break;
                    }
                    $72 = (_strncmp($str,599280,10)|0);
                    $73 = ($72|0)==(0);
                    if ($73) {
                     $$0 = 1;
                     break;
                    }
                    $74 = (_strncmp($str,599296,14)|0);
                    $75 = ($74|0)==(0);
                    if ($75) {
                     $$0 = 1;
                     break;
                    }
                    $76 = (_strncmp($str,599312,10)|0);
                    $77 = ($76|0)==(0);
                    if ($77) {
                     $$0 = 1;
                     break;
                    }
                    $78 = (_strncmp($str,599328,14)|0);
                    $79 = ($78|0)==(0);
                    $$1 = $79&1;
                    STACKTOP = sp;return ($$1|0);
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z16CreateGpuProgramRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER22CreateGpuProgramOutput($source,$output) {
 $source = $source|0;
 $output = $output|0;
 var $$0 = 0, $$03 = 0, $$1 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$in = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i26 = 0, $not$ = 0, $program$0 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer3 = sp;
 $0 = sp + 40|0;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 $4 = (__Z16GetRealGfxDevicev()|0);
 $5 = (($4) + 5928|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP8[$source>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $12 = (($source) + 1|0);
  $13 = $12;
 } else {
  $10 = (($source) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $13 = $11;
 }
 $14 = (_strncmp($13,598928,6)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $18 = (($source) + 1|0);
  $19 = $18;
 } else {
  $16 = (($source) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $19 = $17;
 }
 $20 = (_strncmp($19,598936,7)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $24 = (($source) + 1|0);
  $25 = $24;
 } else {
  $22 = (($source) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $25 = $23;
 }
 $26 = (_strncmp($25,598944,6)|0);
 $27 = ($26|0)==(0);
 if ($27) {
  $28 = ($6|0)==(8);
  if (!($28)) {
   $program$0 = 0;
   STACKTOP = sp;return ($program$0|0);
  }
  $29 = (__Znwj(32)|0);
  if ($9) {
   $32 = $7&255;
   $33 = $32 >>> 1;
   $34 = $7&255;
   $35 = $34 >>> 1;
   $$in = $33;$38 = $35;
  } else {
   $30 = (($source) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $$in = $31;$38 = $31;
  }
  $36 = (($$in) + -6)|0;
  $37 = ($38>>>0)<(6);
  do {
   if ($37) {
    __THREW__ = 0;
    invoke_vi(3304,0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 33;
    } else {
     // unreachable;
    }
   } else {
    if ($9) {
     $43 = (($source) + 1|0);
     $45 = $43;
    } else {
     $41 = (($source) + 8|0);
     $42 = HEAP32[$41>>2]|0;
     $45 = $42;
    }
    $44 = (($45) + 6|0);
    $46 = (($38) + -6)|0;
    $47 = ($46>>>0)<($36>>>0);
    $48 = $47 ? $46 : $36;
    $49 = ($48>>>0)>(4294967279);
    if ($49) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 33;
      break;
     }
     // unreachable;
    }
    $52 = ($48>>>0)<(11);
    if ($52) {
     $53 = $48 << 1;
     $54 = $53&255;
     HEAP8[$0>>0] = $54;
     $55 = (($0) + 1|0);
     $__p$0$i$i = $55;
    } else {
     $56 = (($48) + 16)|0;
     $57 = $56 & -16;
     __THREW__ = 0;
     $58 = (invoke_ii(2988,($57|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 33;
      break;
     }
     $61 = (($0) + 8|0);
     HEAP32[$61>>2] = $58;
     $62 = $57 | 1;
     HEAP32[$0>>2] = $62;
     $63 = (($0) + 4|0);
     HEAP32[$63>>2] = $48;
     $__p$0$i$i = $58;
    }
    _memcpy(($__p$0$i$i|0),($44|0),($48|0))|0;
    $64 = (($__p$0$i$i) + ($48)|0);
    HEAP8[$64>>0] = 0;
    __THREW__ = 0;
    invoke_viii(1730,($29|0),($0|0),($output|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     $74 = ___cxa_find_matching_catch()|0;
     $75 = tempRet0;
     $76 = HEAP8[$0>>0]|0;
     $77 = $76 & 1;
     $78 = ($77<<24>>24)==(0);
     if ($78) {
      $$0 = $74;$$03 = $75;
      break;
     }
     $79 = (($0) + 8|0);
     $80 = HEAP32[$79>>2]|0;
     __ZdlPv($80);
     $$0 = $74;$$03 = $75;
     break;
    }
    $67 = HEAP8[$0>>0]|0;
    $68 = $67 & 1;
    $69 = ($68<<24>>24)==(0);
    if ($69) {
     $program$0 = $29;
     STACKTOP = sp;return ($program$0|0);
    }
    $70 = (($0) + 8|0);
    $71 = HEAP32[$70>>2]|0;
    __ZdlPv($71);
    $program$0 = $29;
    STACKTOP = sp;return ($program$0|0);
   }
  } while(0);
  if ((label|0) == 33) {
   $72 = ___cxa_find_matching_catch()|0;
   $73 = tempRet0;
   $$0 = $72;$$03 = $73;
  }
  __ZdlPv($29);
  $$2 = $$0;$$25 = $$03;
  ___resumeException($$2|0);
  // unreachable;
 }
 if ($9) {
  $83 = (($source) + 1|0);
  $84 = $83;
 } else {
  $81 = (($source) + 8|0);
  $82 = HEAP32[$81>>2]|0;
  $84 = $82;
 }
 $85 = (_strncmp($84,598952,6)|0);
 $86 = ($85|0)==(0);
 if ($86) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $89 = (($source) + 1|0);
  $90 = $89;
 } else {
  $87 = (($source) + 8|0);
  $88 = HEAP32[$87>>2]|0;
  $90 = $88;
 }
 $91 = (_strncmp($90,598960,6)|0);
 $92 = ($91|0)==(0);
 if ($92) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $95 = (($source) + 1|0);
  $96 = $95;
 } else {
  $93 = (($source) + 8|0);
  $94 = HEAP32[$93>>2]|0;
  $96 = $94;
 }
 $97 = (_strncmp($96,598968,6)|0);
 $98 = ($97|0)==(0);
 if ($98) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $101 = (($source) + 1|0);
  $102 = $101;
 } else {
  $99 = (($source) + 8|0);
  $100 = HEAP32[$99>>2]|0;
  $102 = $100;
 }
 $103 = (_strncmp($102,598976,6)|0);
 $104 = ($103|0)==(0);
 if ($104) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $107 = (($source) + 1|0);
  $108 = $107;
 } else {
  $105 = (($source) + 8|0);
  $106 = HEAP32[$105>>2]|0;
  $108 = $106;
 }
 $109 = (_strncmp($108,598984,14)|0);
 $110 = ($109|0)==(0);
 if ($110) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $113 = (($source) + 1|0);
  $114 = $113;
 } else {
  $111 = (($source) + 8|0);
  $112 = HEAP32[$111>>2]|0;
  $114 = $112;
 }
 $115 = (_strncmp($114,599000,14)|0);
 $116 = ($115|0)==(0);
 if ($116) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $119 = (($source) + 1|0);
  $120 = $119;
 } else {
  $117 = (($source) + 8|0);
  $118 = HEAP32[$117>>2]|0;
  $120 = $118;
 }
 $121 = (_strncmp($120,599016,7)|0);
 $122 = ($121|0)==(0);
 if ($122) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $125 = (($source) + 1|0);
  $126 = $125;
 } else {
  $123 = (($source) + 8|0);
  $124 = HEAP32[$123>>2]|0;
  $126 = $124;
 }
 $127 = (_strncmp($126,599024,6)|0);
 $128 = ($127|0)==(0);
 if ($128) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $131 = (($source) + 1|0);
  $132 = $131;
 } else {
  $129 = (($source) + 8|0);
  $130 = HEAP32[$129>>2]|0;
  $132 = $130;
 }
 $133 = (_strncmp($132,599032,6)|0);
 $134 = ($133|0)==(0);
 if ($134) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $137 = (($source) + 1|0);
  $138 = $137;
 } else {
  $135 = (($source) + 8|0);
  $136 = HEAP32[$135>>2]|0;
  $138 = $136;
 }
 $139 = (_strncmp($138,599040,7)|0);
 $140 = ($139|0)==(0);
 if ($140) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $143 = (($source) + 1|0);
  $144 = $143;
 } else {
  $141 = (($source) + 8|0);
  $142 = HEAP32[$141>>2]|0;
  $144 = $142;
 }
 $145 = (_strncmp($144,599048,6)|0);
 $146 = ($145|0)==(0);
 if ($146) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $149 = (($source) + 1|0);
  $150 = $149;
 } else {
  $147 = (($source) + 8|0);
  $148 = HEAP32[$147>>2]|0;
  $150 = $148;
 }
 $151 = (_strncmp($150,599056,6)|0);
 $152 = ($151|0)==(0);
 if ($152) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $155 = (($source) + 1|0);
  $156 = $155;
 } else {
  $153 = (($source) + 8|0);
  $154 = HEAP32[$153>>2]|0;
  $156 = $154;
 }
 $157 = (_strncmp($156,599064,6)|0);
 $158 = ($157|0)==(0);
 if ($158) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $161 = (($source) + 1|0);
  $162 = $161;
 } else {
  $159 = (($source) + 8|0);
  $160 = HEAP32[$159>>2]|0;
  $162 = $160;
 }
 $163 = (_strncmp($162,599072,6)|0);
 $164 = ($163|0)==(0);
 if ($164) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $167 = (($source) + 1|0);
  $168 = $167;
 } else {
  $165 = (($source) + 8|0);
  $166 = HEAP32[$165>>2]|0;
  $168 = $166;
 }
 $169 = (_strncmp($168,599080,6)|0);
 $170 = ($169|0)==(0);
 if ($170) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $173 = (($source) + 1|0);
  $174 = $173;
 } else {
  $171 = (($source) + 8|0);
  $172 = HEAP32[$171>>2]|0;
  $174 = $172;
 }
 $175 = (_strncmp($174,599088,6)|0);
 $176 = ($175|0)==(0);
 if ($176) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $179 = (($source) + 1|0);
  $180 = $179;
 } else {
  $177 = (($source) + 8|0);
  $178 = HEAP32[$177>>2]|0;
  $180 = $178;
 }
 $181 = (_strncmp($180,599096,6)|0);
 $182 = ($181|0)==(0);
 if ($182) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $185 = (($source) + 1|0);
  $186 = $185;
 } else {
  $183 = (($source) + 8|0);
  $184 = HEAP32[$183>>2]|0;
  $186 = $184;
 }
 $187 = (_strncmp($186,599104,6)|0);
 $188 = ($187|0)==(0);
 if ($188) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $191 = (($source) + 1|0);
  $192 = $191;
 } else {
  $189 = (($source) + 8|0);
  $190 = HEAP32[$189>>2]|0;
  $192 = $190;
 }
 $193 = (_strncmp($192,599112,10)|0);
 $194 = ($193|0)==(0);
 if ($194) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $197 = (($source) + 1|0);
  $198 = $197;
 } else {
  $195 = (($source) + 8|0);
  $196 = HEAP32[$195>>2]|0;
  $198 = $196;
 }
 $199 = (_strncmp($198,599128,10)|0);
 $200 = ($199|0)==(0);
 if ($200) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $203 = (($source) + 1|0);
  $204 = $203;
 } else {
  $201 = (($source) + 8|0);
  $202 = HEAP32[$201>>2]|0;
  $204 = $202;
 }
 $205 = (_strncmp($204,599344,7)|0);
 $206 = ($205|0)==(0);
 if ($206) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $209 = (($source) + 1|0);
  $210 = $209;
 } else {
  $207 = (($source) + 8|0);
  $208 = HEAP32[$207>>2]|0;
  $210 = $208;
 }
 $211 = (_strncmp($210,599352,7)|0);
 $212 = ($211|0)==(0);
 if ($212) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $215 = (($source) + 1|0);
  $216 = $215;
 } else {
  $213 = (($source) + 8|0);
  $214 = HEAP32[$213>>2]|0;
  $216 = $214;
 }
 $217 = (_strncmp($216,599144,11)|0);
 $218 = ($217|0)==(0);
 if ($218) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $221 = (($source) + 1|0);
  $222 = $221;
 } else {
  $219 = (($source) + 8|0);
  $220 = HEAP32[$219>>2]|0;
  $222 = $220;
 }
 $223 = (_strncmp($222,599160,11)|0);
 $224 = ($223|0)==(0);
 if ($224) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $227 = (($source) + 1|0);
  $228 = $227;
 } else {
  $225 = (($source) + 8|0);
  $226 = HEAP32[$225>>2]|0;
  $228 = $226;
 }
 $229 = (_strncmp($228,599176,10)|0);
 $230 = ($229|0)==(0);
 if ($230) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $233 = (($source) + 1|0);
  $234 = $233;
 } else {
  $231 = (($source) + 8|0);
  $232 = HEAP32[$231>>2]|0;
  $234 = $232;
 }
 $235 = (_strncmp($234,599192,10)|0);
 $236 = ($235|0)==(0);
 if ($236) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $239 = (($source) + 1|0);
  $240 = $239;
 } else {
  $237 = (($source) + 8|0);
  $238 = HEAP32[$237>>2]|0;
  $240 = $238;
 }
 $241 = (_strncmp($240,599208,6)|0);
 $242 = ($241|0)==(0);
 if ($242) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $245 = (($source) + 1|0);
  $246 = $245;
 } else {
  $243 = (($source) + 8|0);
  $244 = HEAP32[$243>>2]|0;
  $246 = $244;
 }
 $247 = (_strncmp($246,599216,6)|0);
 $248 = ($247|0)==(0);
 if ($248) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $251 = (($source) + 1|0);
  $252 = $251;
 } else {
  $249 = (($source) + 8|0);
  $250 = HEAP32[$249>>2]|0;
  $252 = $250;
 }
 $253 = (_strncmp($252,599224,6)|0);
 $254 = ($253|0)==(0);
 if ($254) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $257 = (($source) + 1|0);
  $258 = $257;
 } else {
  $255 = (($source) + 8|0);
  $256 = HEAP32[$255>>2]|0;
  $258 = $256;
 }
 $259 = (_strncmp($258,599232,6)|0);
 $260 = ($259|0)==(0);
 if ($260) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $263 = (($source) + 1|0);
  $264 = $263;
 } else {
  $261 = (($source) + 8|0);
  $262 = HEAP32[$261>>2]|0;
  $264 = $262;
 }
 $265 = (_strncmp($264,599240,6)|0);
 $266 = ($265|0)==(0);
 if ($266) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $269 = (($source) + 1|0);
  $270 = $269;
 } else {
  $267 = (($source) + 8|0);
  $268 = HEAP32[$267>>2]|0;
  $270 = $268;
 }
 $271 = (_strncmp($270,599248,8)|0);
 $272 = ($271|0)==(0);
 if ($272) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $275 = (($source) + 1|0);
  $276 = $275;
 } else {
  $273 = (($source) + 8|0);
  $274 = HEAP32[$273>>2]|0;
  $276 = $274;
 }
 $277 = (_strncmp($276,599264,8)|0);
 $278 = ($277|0)==(0);
 if ($278) {
  $program$0 = 0;
  STACKTOP = sp;return ($program$0|0);
 }
 if ($9) {
  $283 = $7&255;
  $284 = $283 >>> 1;
  $285 = (($source) + 1|0);
  $287 = $284;$289 = $285;
 } else {
  $279 = (($source) + 4|0);
  $280 = HEAP32[$279>>2]|0;
  $281 = (($source) + 8|0);
  $282 = HEAP32[$281>>2]|0;
  $287 = $280;$289 = $282;
 }
 $286 = ($287>>>0)>(7);
 $288 = $286 ? 7 : $287;
 $290 = (_memcmp($289,599360,$288)|0);
 $291 = ($290|0)==(0);
 do {
  if ($291) {
   $292 = $286 ^ 1;
   $not$ = ($287>>>0)>(6);
   $293 = $not$ & $292;
   if (!($293)) {
    break;
   }
   _printf_console(599368,$vararg_buffer3);
   $program$0 = 0;
   STACKTOP = sp;return ($program$0|0);
  }
 } while(0);
 if ($9) {
  $296 = $7&255;
  $297 = $296 >>> 1;
  $299 = $297;
 } else {
  $294 = (($source) + 4|0);
  $295 = HEAP32[$294>>2]|0;
  $299 = $295;
 }
 $298 = ($299|0)==(0);
 if ($298) {
  __Z6FormatPKcz($1,599424,$vararg_buffer3);
  $300 = HEAP8[$1>>0]|0;
  $301 = $300 & 1;
  $302 = ($301<<24>>24)==(0);
  if ($302) {
   $305 = (($1) + 1|0);
   $306 = $305;
  } else {
   $303 = (($1) + 8|0);
   $304 = HEAP32[$303>>2]|0;
   $306 = $304;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($306|0),0,(599472|0),638,512,0,0,(0|0));
  $307 = __THREW__; __THREW__ = 0;
  $308 = $307&1;
  if ($308) {
   $314 = ___cxa_find_matching_catch()|0;
   $315 = tempRet0;
   $316 = HEAP8[$1>>0]|0;
   $317 = $316 & 1;
   $318 = ($317<<24>>24)==(0);
   if ($318) {
    $$2 = $314;$$25 = $315;
    ___resumeException($$2|0);
    // unreachable;
   }
   $319 = (($1) + 8|0);
   $320 = HEAP32[$319>>2]|0;
   __ZdlPv($320);
   $$2 = $314;$$25 = $315;
   ___resumeException($$2|0);
   // unreachable;
  } else {
   $309 = HEAP8[$1>>0]|0;
   $310 = $309 & 1;
   $311 = ($310<<24>>24)==(0);
   if ($311) {
    $program$0 = 0;
    STACKTOP = sp;return ($program$0|0);
   }
   $312 = (($1) + 8|0);
   $313 = HEAP32[$312>>2]|0;
   __ZdlPv($313);
   $program$0 = 0;
   STACKTOP = sp;return ($program$0|0);
  }
 }
 if ($9) {
  $323 = $7&255;
  $324 = $323 >>> 1;
  $326 = $324;
 } else {
  $321 = (($source) + 4|0);
  $322 = HEAP32[$321>>2]|0;
  $326 = $322;
 }
 $325 = ($326>>>0)<(10);
 do {
  if ($325) {
   if ($9) {
    $329 = $7&255;
    $330 = $329 >>> 1;
    $399 = $330;
    label = 196;
    break;
   } else {
    $327 = (($source) + 4|0);
    $328 = HEAP32[$327>>2]|0;
    $398 = $328;
    label = 195;
    break;
   }
  } else {
   if ($9) {
    $399 = 10;
    label = 196;
   } else {
    $398 = 10;
    label = 195;
   }
  }
 } while(0);
 if ((label|0) == 195) {
  $331 = (($source) + 4|0);
  $332 = HEAP32[$331>>2]|0;
  $333 = (($source) + 8|0);
  $334 = HEAP32[$333>>2]|0;
  $339 = $332;$340 = $398;$354 = $334;
 }
 else if ((label|0) == 196) {
  $335 = $7&255;
  $336 = $335 >>> 1;
  $337 = (($source) + 1|0);
  $339 = $336;$340 = $399;$354 = $337;
 }
 $338 = ($339>>>0)<($340>>>0);
 $341 = $338 ? $339 : $340;
 $342 = ($341>>>0)>(4294967279);
 if ($342) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $343 = ($341>>>0)<(11);
 if ($343) {
  $344 = $341 << 1;
  $345 = $344&255;
  HEAP8[$3>>0] = $345;
  $346 = (($3) + 1|0);
  $$pre$phiZ2D = $3;$357 = $345;$__p$0$i$i26 = $346;
 } else {
  $347 = (($341) + 16)|0;
  $348 = $347 & -16;
  $349 = (__Znwj($348)|0);
  $350 = (($3) + 8|0);
  HEAP32[$350>>2] = $349;
  $351 = $348 | 1;
  HEAP32[$3>>2] = $351;
  $352 = (($3) + 4|0);
  HEAP32[$352>>2] = $341;
  $353 = $351&255;
  $$pre$phiZ2D = $3;$357 = $353;$__p$0$i$i26 = $349;
 }
 _memcpy(($__p$0$i$i26|0),($354|0),($341|0))|0;
 $355 = (($__p$0$i$i26) + ($341)|0);
 HEAP8[$355>>0] = 0;
 $356 = $357 & 1;
 $358 = ($356<<24>>24)==(0);
 if ($358) {
  $361 = (($3) + 1|0);
  $362 = $361;
 } else {
  $359 = (($3) + 8|0);
  $360 = HEAP32[$359>>2]|0;
  $362 = $360;
 }
 __THREW__ = 0;
 HEAP32[$vararg_buffer3>>2] = $362;
 invoke_viii(1617,($2|0),(599480|0),($vararg_buffer3|0));
 $363 = __THREW__; __THREW__ = 0;
 $364 = $363&1;
 do {
  if ($364) {
   $384 = ___cxa_find_matching_catch()|0;
   $385 = tempRet0;
   $$1 = $384;$$14 = $385;
  } else {
   $365 = HEAP8[$2>>0]|0;
   $366 = $365 & 1;
   $367 = ($366<<24>>24)==(0);
   if ($367) {
    $370 = (($2) + 1|0);
    $371 = $370;
   } else {
    $368 = (($2) + 8|0);
    $369 = HEAP32[$368>>2]|0;
    $371 = $369;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($371|0),0,(599472|0),644,512,0,0,(0|0));
   $372 = __THREW__; __THREW__ = 0;
   $373 = $372&1;
   if ($373) {
    $386 = ___cxa_find_matching_catch()|0;
    $387 = tempRet0;
    $388 = HEAP8[$2>>0]|0;
    $389 = $388 & 1;
    $390 = ($389<<24>>24)==(0);
    if ($390) {
     $$1 = $386;$$14 = $387;
     break;
    }
    $391 = (($2) + 8|0);
    $392 = HEAP32[$391>>2]|0;
    __ZdlPv($392);
    $$1 = $386;$$14 = $387;
    break;
   }
   $374 = HEAP8[$2>>0]|0;
   $375 = $374 & 1;
   $376 = ($375<<24>>24)==(0);
   if (!($376)) {
    $377 = (($2) + 8|0);
    $378 = HEAP32[$377>>2]|0;
    __ZdlPv($378);
   }
   $379 = HEAP8[$$pre$phiZ2D>>0]|0;
   $380 = $379 & 1;
   $381 = ($380<<24>>24)==(0);
   if ($381) {
    $program$0 = 0;
    STACKTOP = sp;return ($program$0|0);
   }
   $382 = (($3) + 8|0);
   $383 = HEAP32[$382>>2]|0;
   __ZdlPv($383);
   $program$0 = 0;
   STACKTOP = sp;return ($program$0|0);
  }
 } while(0);
 $393 = HEAP8[$$pre$phiZ2D>>0]|0;
 $394 = $393 & 1;
 $395 = ($394<<24>>24)==(0);
 if ($395) {
  $$2 = $$1;$$25 = $$14;
  ___resumeException($$2|0);
  // unreachable;
 }
 $396 = (($3) + 8|0);
 $397 = HEAP32[$396>>2]|0;
 __ZdlPv($397);
 $$2 = $$1;$$25 = $$14;
 ___resumeException($$2|0);
 // unreachable;
 return 0|0;
}
function __ZN10GpuProgramC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((599608 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = -1;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8|0);
 HEAP8[$2>>0] = 0;
 $3 = (($this) + 9|0);
 HEAP8[$3>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN10GpuProgramD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN10GpuProgramD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK10GpuProgram11IsSupportedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN22CreateGpuProgramOutputC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN22CreateGpuProgramOutputD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3475,($0|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if ($3) {
    $7 = ___cxa_find_matching_catch()|0;
    $8 = tempRet0;
    __ZdlPv($0);
    ___resumeException($7|0);
    // unreachable;
   } else {
    __ZdlPv($0);
    break;
   }
  }
 } while(0);
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 __ZdlPv($5);
 STACKTOP = sp;return;
}
function __ZN22CreateGpuProgramOutput12CreateParamsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(164)|0);
 HEAP32[$0>>2] = 0;
 $1 = (($0) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($0) + 4|0);
 HEAP32[$3>>2] = 61;
 $4 = (($0) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($0) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($0) + 28|0);
 HEAP32[$6>>2] = 0;
 $7 = (($0) + 20|0);
 HEAP32[$7>>2] = 61;
 $8 = (($0) + 32|0);
 $9 = (($0) + 52|0);
 HEAP32[$9>>2] = 0;
 $10 = (($0) + 56|0);
 HEAP32[$10>>2] = 0;
 $11 = (($0) + 48|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
 HEAP32[$11>>2] = 61;
 $12 = (($0) + 60|0);
 HEAP32[$12>>2] = 0;
 $13 = (($0) + 64|0);
 HEAP32[$13>>2] = 0;
 $14 = (($0) + 68|0);
 HEAP32[$14>>2] = 0;
 $15 = (($0) + 72|0);
 HEAP32[$15>>2] = -1;
 $16 = (($0) + 76|0);
 $17 = $16;
 $18 = $17;
 HEAP16[$18>>1]=0&65535;HEAP16[$18+2>>1]=0>>>16;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP16[$20>>1]=0&65535;HEAP16[$20+2>>1]=0>>>16;
 $21 = (($0) + 84|0);
 HEAP32[$21>>2] = -1;
 $22 = (($0) + 88|0);
 $23 = $22;
 $24 = $23;
 HEAP16[$24>>1]=0&65535;HEAP16[$24+2>>1]=0>>>16;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP16[$26>>1]=0&65535;HEAP16[$26+2>>1]=0>>>16;
 $27 = (($0) + 96|0);
 HEAP32[$27>>2] = -1;
 $28 = (($0) + 100|0);
 $29 = $28;
 $30 = $29;
 HEAP16[$30>>1]=0&65535;HEAP16[$30+2>>1]=0>>>16;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP16[$32>>1]=0&65535;HEAP16[$32+2>>1]=0>>>16;
 $33 = (($0) + 108|0);
 HEAP32[$33>>2] = -1;
 $34 = (($0) + 112|0);
 $35 = $34;
 $36 = $35;
 HEAP16[$36>>1]=0&65535;HEAP16[$36+2>>1]=0>>>16;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP16[$38>>1]=0&65535;HEAP16[$38+2>>1]=0>>>16;
 $39 = (($0) + 120|0);
 HEAP32[$39>>2] = -1;
 $40 = (($0) + 124|0);
 $41 = $40;
 $42 = $41;
 HEAP16[$42>>1]=0&65535;HEAP16[$42+2>>1]=0>>>16;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP16[$44>>1]=0&65535;HEAP16[$44+2>>1]=0>>>16;
 $45 = (($0) + 132|0);
 HEAP32[$45>>2] = -1;
 $46 = (($0) + 136|0);
 $47 = $46;
 $48 = $47;
 HEAP16[$48>>1]=0&65535;HEAP16[$48+2>>1]=0>>>16;
 $49 = (($47) + 4)|0;
 $50 = $49;
 HEAP16[$50>>1]=0&65535;HEAP16[$50+2>>1]=0>>>16;
 $51 = (($0) + 144|0);
 HEAP32[$51>>2] = -1;
 $52 = (($0) + 148|0);
 ;HEAP16[$52+0>>1]=0|0;HEAP16[$52+2>>1]=0|0;HEAP16[$52+4>>1]=0|0;HEAP16[$52+6>>1]=0|0;HEAP16[$52+8>>1]=0|0;HEAP16[$52+10>>1]=0|0;HEAP16[$52+12>>1]=0|0;HEAP16[$52+14>>1]=0|0;
 HEAP32[$this>>2] = $0;
 STACKTOP = sp;return ($0|0);
}
function __ZN22CreateGpuProgramOutput20CreateChannelAssignsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(36)|0);
 __THREW__ = 0;
 invoke_vi(3476,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($this) + 4|0);
  HEAP32[$3>>2] = $0;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZNSt3__16__sortIRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0;
 var $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0;
 var $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0;
 var $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0;
 var $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0;
 var $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0;
 var $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$013 = 0, $__i$02$i = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0;
 var $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__k$0$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 85;
    break L1;
    break;
   }
   default: {
   }
   }
   $210 = ($3|0)<(248);
   if ($210) {
    label = 21;
    break L1;
   }
   $333 = ($3|0)>(7992);
   $334 = (($4|0) / 2)&-1;
   $335 = (($$0) + ($334<<3)|0);
   do {
    if ($333) {
     $336 = (($4|0) / 4)&-1;
     $337 = (($$0) + ($336<<3)|0);
     $$sum = (($336) + ($334))|0;
     $338 = (($$0) + ($$sum<<3)|0);
     $339 = (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$337,$335,$338,0)|0);
     $340 = HEAP32[$1>>2]|0;
     $341 = HEAP32[$338>>2]|0;
     $342 = ($340|0)<($341|0);
     if (!($342)) {
      $$pre$phiZ2D = $335;$__n_swaps$0 = $339;
      break;
     }
     $343 = $338;
     $344 = $343;
     $345 = HEAP32[$344>>2]|0;
     $346 = (($343) + 4)|0;
     $347 = $346;
     $348 = HEAP32[$347>>2]|0;
     $349 = $1;
     $350 = $349;
     $351 = HEAP32[$350>>2]|0;
     $352 = (($349) + 4)|0;
     $353 = $352;
     $354 = HEAP32[$353>>2]|0;
     $355 = $338;
     $356 = $355;
     HEAP32[$356>>2] = $351;
     $357 = (($355) + 4)|0;
     $358 = $357;
     HEAP32[$358>>2] = $354;
     $359 = $1;
     $360 = $359;
     HEAP32[$360>>2] = $345;
     $361 = (($359) + 4)|0;
     $362 = $361;
     HEAP32[$362>>2] = $348;
     $363 = HEAP32[$338>>2]|0;
     $364 = HEAP32[$335>>2]|0;
     $365 = ($363|0)<($364|0);
     if (!($365)) {
      $366 = (($339) + 1)|0;
      $$pre$phiZ2D = $335;$__n_swaps$0 = $366;
      break;
     }
     $367 = $335;
     $368 = $367;
     $369 = HEAP32[$368>>2]|0;
     $370 = (($367) + 4)|0;
     $371 = $370;
     $372 = HEAP32[$371>>2]|0;
     $373 = $338;
     $374 = $373;
     $375 = HEAP32[$374>>2]|0;
     $376 = (($373) + 4)|0;
     $377 = $376;
     $378 = HEAP32[$377>>2]|0;
     $379 = $335;
     $380 = $379;
     HEAP32[$380>>2] = $375;
     $381 = (($379) + 4)|0;
     $382 = $381;
     HEAP32[$382>>2] = $378;
     $383 = $338;
     $384 = $383;
     HEAP32[$384>>2] = $369;
     $385 = (($383) + 4)|0;
     $386 = $385;
     HEAP32[$386>>2] = $372;
     $387 = HEAP32[$335>>2]|0;
     $388 = HEAP32[$337>>2]|0;
     $389 = ($387|0)<($388|0);
     if (!($389)) {
      $390 = (($339) + 2)|0;
      $$pre$phiZ2D = $335;$__n_swaps$0 = $390;
      break;
     }
     $391 = $337;
     $392 = $391;
     $393 = HEAP32[$392>>2]|0;
     $394 = (($391) + 4)|0;
     $395 = $394;
     $396 = HEAP32[$395>>2]|0;
     $397 = $335;
     $398 = $397;
     $399 = HEAP32[$398>>2]|0;
     $400 = (($397) + 4)|0;
     $401 = $400;
     $402 = HEAP32[$401>>2]|0;
     $403 = $337;
     $404 = $403;
     HEAP32[$404>>2] = $399;
     $405 = (($403) + 4)|0;
     $406 = $405;
     HEAP32[$406>>2] = $402;
     $407 = $335;
     $408 = $407;
     HEAP32[$408>>2] = $393;
     $409 = (($407) + 4)|0;
     $410 = $409;
     HEAP32[$410>>2] = $396;
     $411 = (($339) + 3)|0;
     $412 = HEAP32[$337>>2]|0;
     $413 = HEAP32[$$0>>2]|0;
     $414 = ($412|0)<($413|0);
     if ($414) {
      $415 = $$0;
      $416 = $415;
      $417 = HEAP32[$416>>2]|0;
      $418 = (($415) + 4)|0;
      $419 = $418;
      $420 = HEAP32[$419>>2]|0;
      $421 = $337;
      $422 = $421;
      $423 = HEAP32[$422>>2]|0;
      $424 = (($421) + 4)|0;
      $425 = $424;
      $426 = HEAP32[$425>>2]|0;
      $427 = $$0;
      $428 = $427;
      HEAP32[$428>>2] = $423;
      $429 = (($427) + 4)|0;
      $430 = $429;
      HEAP32[$430>>2] = $426;
      $431 = $337;
      $432 = $431;
      HEAP32[$432>>2] = $417;
      $433 = (($431) + 4)|0;
      $434 = $433;
      HEAP32[$434>>2] = $420;
      $435 = (($339) + 4)|0;
      $$pre$phiZ2D = $335;$__n_swaps$0 = $435;
     } else {
      $$pre$phiZ2D = $335;$__n_swaps$0 = $411;
     }
    } else {
     $436 = HEAP32[$335>>2]|0;
     $437 = HEAP32[$$0>>2]|0;
     $438 = ($436|0)<($437|0);
     $439 = HEAP32[$1>>2]|0;
     $440 = ($439|0)<($436|0);
     if (!($438)) {
      if (!($440)) {
       $$pre$phiZ2D = $335;$__n_swaps$0 = 0;
       break;
      }
      $441 = $335;
      $442 = $441;
      $443 = HEAP32[$442>>2]|0;
      $444 = (($441) + 4)|0;
      $445 = $444;
      $446 = HEAP32[$445>>2]|0;
      $447 = $1;
      $448 = $447;
      $449 = HEAP32[$448>>2]|0;
      $450 = (($447) + 4)|0;
      $451 = $450;
      $452 = HEAP32[$451>>2]|0;
      $453 = $335;
      $454 = $453;
      HEAP32[$454>>2] = $449;
      $455 = (($453) + 4)|0;
      $456 = $455;
      HEAP32[$456>>2] = $452;
      $457 = $1;
      $458 = $457;
      HEAP32[$458>>2] = $443;
      $459 = (($457) + 4)|0;
      $460 = $459;
      HEAP32[$460>>2] = $446;
      $461 = HEAP32[$335>>2]|0;
      $462 = HEAP32[$$0>>2]|0;
      $463 = ($461|0)<($462|0);
      if (!($463)) {
       $$pre$phiZ2D = $335;$__n_swaps$0 = 1;
       break;
      }
      $464 = $$0;
      $465 = $464;
      $466 = HEAP32[$465>>2]|0;
      $467 = (($464) + 4)|0;
      $468 = $467;
      $469 = HEAP32[$468>>2]|0;
      $470 = $335;
      $471 = $470;
      $472 = HEAP32[$471>>2]|0;
      $473 = (($470) + 4)|0;
      $474 = $473;
      $475 = HEAP32[$474>>2]|0;
      $476 = $$0;
      $477 = $476;
      HEAP32[$477>>2] = $472;
      $478 = (($476) + 4)|0;
      $479 = $478;
      HEAP32[$479>>2] = $475;
      $480 = $335;
      $481 = $480;
      HEAP32[$481>>2] = $466;
      $482 = (($480) + 4)|0;
      $483 = $482;
      HEAP32[$483>>2] = $469;
      $$pre$phiZ2D = $335;$__n_swaps$0 = 2;
      break;
     }
     $484 = $$0;
     $485 = $484;
     $486 = HEAP32[$485>>2]|0;
     $487 = (($484) + 4)|0;
     $488 = $487;
     $489 = HEAP32[$488>>2]|0;
     if ($440) {
      $490 = $1;
      $491 = $490;
      $492 = HEAP32[$491>>2]|0;
      $493 = (($490) + 4)|0;
      $494 = $493;
      $495 = HEAP32[$494>>2]|0;
      $496 = $$0;
      $497 = $496;
      HEAP32[$497>>2] = $492;
      $498 = (($496) + 4)|0;
      $499 = $498;
      HEAP32[$499>>2] = $495;
      $500 = $1;
      $501 = $500;
      HEAP32[$501>>2] = $486;
      $502 = (($500) + 4)|0;
      $503 = $502;
      HEAP32[$503>>2] = $489;
      $$pre$phiZ2D = $335;$__n_swaps$0 = 1;
      break;
     }
     $504 = $335;
     $505 = $504;
     $506 = HEAP32[$505>>2]|0;
     $507 = (($504) + 4)|0;
     $508 = $507;
     $509 = HEAP32[$508>>2]|0;
     $510 = $$0;
     $511 = $510;
     HEAP32[$511>>2] = $506;
     $512 = (($510) + 4)|0;
     $513 = $512;
     HEAP32[$513>>2] = $509;
     $514 = $335;
     $515 = $514;
     HEAP32[$515>>2] = $486;
     $516 = (($514) + 4)|0;
     $517 = $516;
     HEAP32[$517>>2] = $489;
     $518 = HEAP32[$1>>2]|0;
     $519 = ($518|0)<($486|0);
     if ($519) {
      $520 = $1;
      $521 = $520;
      $522 = HEAP32[$521>>2]|0;
      $523 = (($520) + 4)|0;
      $524 = $523;
      $525 = HEAP32[$524>>2]|0;
      $526 = $335;
      $527 = $526;
      HEAP32[$527>>2] = $522;
      $528 = (($526) + 4)|0;
      $529 = $528;
      HEAP32[$529>>2] = $525;
      $530 = $1;
      $531 = $530;
      HEAP32[$531>>2] = $486;
      $532 = (($530) + 4)|0;
      $533 = $532;
      HEAP32[$533>>2] = $489;
      $$pre$phiZ2D = $335;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $335;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $534 = HEAP32[$$0>>2]|0;
   $535 = HEAP32[$$pre$phiZ2D>>2]|0;
   $536 = ($534|0)<($535|0);
   do {
    if ($536) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $537 = (($__j$0) + -8|0);
      $538 = ($$0|0)==($537|0);
      if ($538) {
       break;
      }
      $596 = HEAP32[$537>>2]|0;
      $597 = ($596|0)<($535|0);
      if ($597) {
       label = 68;
       break;
      } else {
       $__j$0 = $537;
      }
     }
     if ((label|0) == 68) {
      label = 0;
      $598 = $$0;
      $599 = $598;
      $600 = HEAP32[$599>>2]|0;
      $601 = (($598) + 4)|0;
      $602 = $601;
      $603 = HEAP32[$602>>2]|0;
      $604 = $537;
      $605 = $604;
      $606 = HEAP32[$605>>2]|0;
      $607 = (($604) + 4)|0;
      $608 = $607;
      $609 = HEAP32[$608>>2]|0;
      $610 = $$0;
      $611 = $610;
      HEAP32[$611>>2] = $606;
      $612 = (($610) + 4)|0;
      $613 = $612;
      HEAP32[$613>>2] = $609;
      $614 = $537;
      $615 = $614;
      HEAP32[$615>>2] = $600;
      $616 = (($614) + 4)|0;
      $617 = $616;
      HEAP32[$617>>2] = $603;
      $618 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $537;$__n_swaps$3 = $618;
      break;
     }
     $539 = (($$0) + 8|0);
     $540 = HEAP32[$1>>2]|0;
     $541 = ($534|0)<($540|0);
     if ($541) {
      $__i$1 = $539;
     } else {
      $542 = ($539|0)==($1|0);
      if ($542) {
       label = 85;
       break L1;
      } else {
       $__i$013 = $539;
      }
      while(1) {
       $545 = HEAP32[$__i$013>>2]|0;
       $546 = ($534|0)<($545|0);
       $544 = (($__i$013) + 8|0);
       if ($546) {
        break;
       }
       $543 = ($544|0)==($1|0);
       if ($543) {
        label = 85;
        break L1;
       } else {
        $__i$013 = $544;
       }
      }
      $547 = $__i$013;
      $548 = $547;
      $549 = HEAP32[$548>>2]|0;
      $550 = (($547) + 4)|0;
      $551 = $550;
      $552 = HEAP32[$551>>2]|0;
      $553 = $1;
      $554 = $553;
      $555 = HEAP32[$554>>2]|0;
      $556 = (($553) + 4)|0;
      $557 = $556;
      $558 = HEAP32[$557>>2]|0;
      $559 = $__i$013;
      $560 = $559;
      HEAP32[$560>>2] = $555;
      $561 = (($559) + 4)|0;
      $562 = $561;
      HEAP32[$562>>2] = $558;
      $563 = $1;
      $564 = $563;
      HEAP32[$564>>2] = $549;
      $565 = (($563) + 4)|0;
      $566 = $565;
      HEAP32[$566>>2] = $552;
      $__i$1 = $544;
     }
     $567 = ($__i$1|0)==($1|0);
     if ($567) {
      label = 85;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $568 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $569 = HEAP32[$__i$2>>2]|0;
       $570 = ($568|0)<($569|0);
       $571 = (($__i$2) + 8|0);
       if ($570) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $571;
       }
      }
      while(1) {
       $572 = (($__j$2) + -8|0);
       $573 = HEAP32[$572>>2]|0;
       $574 = ($568|0)<($573|0);
       if ($574) {
        $__j$2 = $572;
       } else {
        break;
       }
      }
      $575 = ($__i$2>>>0)<($572>>>0);
      if (!($575)) {
       $$0 = $__i$2;
       continue L3;
      }
      $576 = $__i$2;
      $577 = $576;
      $578 = HEAP32[$577>>2]|0;
      $579 = (($576) + 4)|0;
      $580 = $579;
      $581 = HEAP32[$580>>2]|0;
      $582 = $572;
      $583 = $582;
      $584 = HEAP32[$583>>2]|0;
      $585 = (($582) + 4)|0;
      $586 = $585;
      $587 = HEAP32[$586>>2]|0;
      $588 = $__i$2;
      $589 = $588;
      HEAP32[$589>>2] = $584;
      $590 = (($588) + 4)|0;
      $591 = $590;
      HEAP32[$591>>2] = $587;
      $592 = $572;
      $593 = $592;
      HEAP32[$593>>2] = $578;
      $594 = (($592) + 4)|0;
      $595 = $594;
      HEAP32[$595>>2] = $581;
      $__i$2$ph = $571;$__j$1$ph = $572;
     }
    }
   } while(0);
   $619 = (($$0) + 8|0);
   $620 = ($619>>>0)<($__j$3>>>0);
   L53: do {
    if ($620) {
     $__i$3$ph = $619;$__j$4$ph = $__j$3;$__m$0$ph = $335;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $621 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $622 = HEAP32[$__i$3>>2]|0;
       $623 = ($622|0)<($621|0);
       $624 = (($__i$3) + 8|0);
       if ($623) {
        $__i$3 = $624;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $625 = (($__j$5) + -8|0);
       $626 = HEAP32[$625>>2]|0;
       $627 = ($626|0)<($621|0);
       if ($627) {
        break;
       } else {
        $__j$5 = $625;
       }
      }
      $628 = ($__i$3>>>0)>($625>>>0);
      if ($628) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L53;
      }
      $629 = $__i$3;
      $630 = $629;
      $631 = HEAP32[$630>>2]|0;
      $632 = (($629) + 4)|0;
      $633 = $632;
      $634 = HEAP32[$633>>2]|0;
      $635 = $625;
      $636 = $635;
      $637 = HEAP32[$636>>2]|0;
      $638 = (($635) + 4)|0;
      $639 = $638;
      $640 = HEAP32[$639>>2]|0;
      $641 = $__i$3;
      $642 = $641;
      HEAP32[$642>>2] = $637;
      $643 = (($641) + 4)|0;
      $644 = $643;
      HEAP32[$644>>2] = $640;
      $645 = $625;
      $646 = $645;
      HEAP32[$646>>2] = $631;
      $647 = (($645) + 4)|0;
      $648 = $647;
      HEAP32[$648>>2] = $634;
      $649 = (($__n_swaps$4$ph) + 1)|0;
      $650 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $650 ? $625 : $__m$0$ph;
      $__i$3$ph = $624;$__j$4$ph = $625;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $649;
     }
    } else {
     $__i$4 = $619;$__m$2 = $335;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $651 = ($__i$4|0)==($__m$2|0);
   if ($651) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $652 = HEAP32[$__m$2>>2]|0;
    $653 = HEAP32[$__i$4>>2]|0;
    $654 = ($652|0)<($653|0);
    if ($654) {
     $655 = $__i$4;
     $656 = $655;
     $657 = HEAP32[$656>>2]|0;
     $658 = (($655) + 4)|0;
     $659 = $658;
     $660 = HEAP32[$659>>2]|0;
     $661 = $__m$2;
     $662 = $661;
     $663 = HEAP32[$662>>2]|0;
     $664 = (($661) + 4)|0;
     $665 = $664;
     $666 = HEAP32[$665>>2]|0;
     $667 = $__i$4;
     $668 = $667;
     HEAP32[$668>>2] = $663;
     $669 = (($667) + 4)|0;
     $670 = $669;
     HEAP32[$670>>2] = $666;
     $671 = $__m$2;
     $672 = $671;
     HEAP32[$672>>2] = $657;
     $673 = (($671) + 4)|0;
     $674 = $673;
     HEAP32[$674>>2] = $660;
     $675 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $675;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $676 = ($__n_swaps$6|0)==(0);
   if ($676) {
    $677 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEbT0_S7_T_($$0,$__i$4,0)|0);
    $678 = (($__i$4) + 8|0);
    $679 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEbT0_S7_T_($678,$$01$ph,0)|0);
    if ($679) {
     label = 80;
     break;
    }
    if ($677) {
     $$0 = $678;
     continue;
    }
   }
   $680 = $__i$4;
   $681 = (($680) - ($2))|0;
   $682 = (($0) - ($680))|0;
   $683 = ($681|0)<($682|0);
   if (!($683)) {
    label = 84;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEvT0_S7_T_($$0,$__i$4,$__comp);
   $684 = (($__i$4) + 8|0);
   $$0 = $684;
  }
  if ((label|0) == 80) {
   label = 0;
   if ($677) {
    label = 85;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 84) {
   label = 0;
   $685 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEvT0_S7_T_($685,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  $8 = $$0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $1;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = $$0;
  $21 = $20;
  HEAP32[$21>>2] = $16;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  $24 = $1;
  $25 = $24;
  HEAP32[$25>>2] = $10;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $13;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $28 = (($$0) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$$0>>2]|0;
  $31 = ($29|0)<($30|0);
  $32 = HEAP32[$1>>2]|0;
  $33 = ($32|0)<($29|0);
  if (!($31)) {
   if (!($33)) {
    STACKTOP = sp;return;
   }
   $34 = $28;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $1;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $28;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $50 = $1;
   $51 = $50;
   HEAP32[$51>>2] = $36;
   $52 = (($50) + 4)|0;
   $53 = $52;
   HEAP32[$53>>2] = $39;
   $54 = HEAP32[$28>>2]|0;
   $55 = HEAP32[$$0>>2]|0;
   $56 = ($54|0)<($55|0);
   if (!($56)) {
    STACKTOP = sp;return;
   }
   $57 = $$0;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + 4)|0;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = $28;
   $64 = $63;
   $65 = HEAP32[$64>>2]|0;
   $66 = (($63) + 4)|0;
   $67 = $66;
   $68 = HEAP32[$67>>2]|0;
   $69 = $$0;
   $70 = $69;
   HEAP32[$70>>2] = $65;
   $71 = (($69) + 4)|0;
   $72 = $71;
   HEAP32[$72>>2] = $68;
   $73 = $28;
   $74 = $73;
   HEAP32[$74>>2] = $59;
   $75 = (($73) + 4)|0;
   $76 = $75;
   HEAP32[$76>>2] = $62;
   STACKTOP = sp;return;
  }
  $77 = $$0;
  $78 = $77;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($77) + 4)|0;
  $81 = $80;
  $82 = HEAP32[$81>>2]|0;
  if ($33) {
   $83 = $1;
   $84 = $83;
   $85 = HEAP32[$84>>2]|0;
   $86 = (($83) + 4)|0;
   $87 = $86;
   $88 = HEAP32[$87>>2]|0;
   $89 = $$0;
   $90 = $89;
   HEAP32[$90>>2] = $85;
   $91 = (($89) + 4)|0;
   $92 = $91;
   HEAP32[$92>>2] = $88;
   $93 = $1;
   $94 = $93;
   HEAP32[$94>>2] = $79;
   $95 = (($93) + 4)|0;
   $96 = $95;
   HEAP32[$96>>2] = $82;
   STACKTOP = sp;return;
  }
  $97 = $28;
  $98 = $97;
  $99 = HEAP32[$98>>2]|0;
  $100 = (($97) + 4)|0;
  $101 = $100;
  $102 = HEAP32[$101>>2]|0;
  $103 = $$0;
  $104 = $103;
  HEAP32[$104>>2] = $99;
  $105 = (($103) + 4)|0;
  $106 = $105;
  HEAP32[$106>>2] = $102;
  $107 = $28;
  $108 = $107;
  HEAP32[$108>>2] = $79;
  $109 = (($107) + 4)|0;
  $110 = $109;
  HEAP32[$110>>2] = $82;
  $111 = HEAP32[$1>>2]|0;
  $112 = ($111|0)<($79|0);
  if (!($112)) {
   STACKTOP = sp;return;
  }
  $113 = $1;
  $114 = $113;
  $115 = HEAP32[$114>>2]|0;
  $116 = (($113) + 4)|0;
  $117 = $116;
  $118 = HEAP32[$117>>2]|0;
  $119 = $28;
  $120 = $119;
  HEAP32[$120>>2] = $115;
  $121 = (($119) + 4)|0;
  $122 = $121;
  HEAP32[$122>>2] = $118;
  $123 = $1;
  $124 = $123;
  HEAP32[$124>>2] = $79;
  $125 = (($123) + 4)|0;
  $126 = $125;
  HEAP32[$126>>2] = $82;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $127 = (($$0) + 8|0);
  $128 = (($$0) + 16|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$127,$128,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $129 = (($$0) + 8|0);
  $130 = (($$0) + 16|0);
  $131 = (($$0) + 24|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$129,$130,$131,0)|0);
  $132 = HEAP32[$1>>2]|0;
  $133 = HEAP32[$131>>2]|0;
  $134 = ($132|0)<($133|0);
  if (!($134)) {
   STACKTOP = sp;return;
  }
  $135 = $131;
  $136 = $135;
  $137 = HEAP32[$136>>2]|0;
  $138 = (($135) + 4)|0;
  $139 = $138;
  $140 = HEAP32[$139>>2]|0;
  $141 = $1;
  $142 = $141;
  $143 = HEAP32[$142>>2]|0;
  $144 = (($141) + 4)|0;
  $145 = $144;
  $146 = HEAP32[$145>>2]|0;
  $147 = $131;
  $148 = $147;
  HEAP32[$148>>2] = $143;
  $149 = (($147) + 4)|0;
  $150 = $149;
  HEAP32[$150>>2] = $146;
  $151 = $1;
  $152 = $151;
  HEAP32[$152>>2] = $137;
  $153 = (($151) + 4)|0;
  $154 = $153;
  HEAP32[$154>>2] = $140;
  $155 = HEAP32[$131>>2]|0;
  $156 = HEAP32[$130>>2]|0;
  $157 = ($155|0)<($156|0);
  if (!($157)) {
   STACKTOP = sp;return;
  }
  $158 = $130;
  $159 = $158;
  $160 = HEAP32[$159>>2]|0;
  $161 = (($158) + 4)|0;
  $162 = $161;
  $163 = HEAP32[$162>>2]|0;
  $164 = $131;
  $165 = $164;
  $166 = HEAP32[$165>>2]|0;
  $167 = (($164) + 4)|0;
  $168 = $167;
  $169 = HEAP32[$168>>2]|0;
  $170 = $130;
  $171 = $170;
  HEAP32[$171>>2] = $166;
  $172 = (($170) + 4)|0;
  $173 = $172;
  HEAP32[$173>>2] = $169;
  $174 = $131;
  $175 = $174;
  HEAP32[$175>>2] = $160;
  $176 = (($174) + 4)|0;
  $177 = $176;
  HEAP32[$177>>2] = $163;
  $178 = HEAP32[$129>>2]|0;
  $179 = ($166|0)<($178|0);
  if (!($179)) {
   STACKTOP = sp;return;
  }
  $180 = $129;
  $181 = $180;
  $182 = HEAP32[$181>>2]|0;
  $183 = (($180) + 4)|0;
  $184 = $183;
  $185 = HEAP32[$184>>2]|0;
  $186 = $129;
  $187 = $186;
  HEAP32[$187>>2] = $166;
  $188 = (($186) + 4)|0;
  $189 = $188;
  HEAP32[$189>>2] = $169;
  $190 = $130;
  $191 = $190;
  HEAP32[$191>>2] = $182;
  $192 = (($190) + 4)|0;
  $193 = $192;
  HEAP32[$193>>2] = $185;
  $194 = HEAP32[$$0>>2]|0;
  $195 = ($166|0)<($194|0);
  if (!($195)) {
   STACKTOP = sp;return;
  }
  $196 = $$0;
  $197 = $196;
  $198 = HEAP32[$197>>2]|0;
  $199 = (($196) + 4)|0;
  $200 = $199;
  $201 = HEAP32[$200>>2]|0;
  $202 = $$0;
  $203 = $202;
  HEAP32[$203>>2] = $166;
  $204 = (($202) + 4)|0;
  $205 = $204;
  HEAP32[$205>>2] = $169;
  $206 = $129;
  $207 = $206;
  HEAP32[$207>>2] = $198;
  $208 = (($206) + 4)|0;
  $209 = $208;
  HEAP32[$209>>2] = $201;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $211 = (($$0) + 16|0);
  $212 = (($$0) + 8|0);
  $213 = HEAP32[$212>>2]|0;
  $214 = HEAP32[$$0>>2]|0;
  $215 = ($213|0)<($214|0);
  $216 = HEAP32[$211>>2]|0;
  $217 = ($216|0)<($213|0);
  do {
   if ($215) {
    $253 = $$0;
    $254 = $253;
    $255 = HEAP32[$254>>2]|0;
    $256 = (($253) + 4)|0;
    $257 = $256;
    $258 = HEAP32[$257>>2]|0;
    if ($217) {
     $259 = $211;
     $260 = $259;
     $261 = HEAP32[$260>>2]|0;
     $262 = (($259) + 4)|0;
     $263 = $262;
     $264 = HEAP32[$263>>2]|0;
     $265 = $$0;
     $266 = $265;
     HEAP32[$266>>2] = $261;
     $267 = (($265) + 4)|0;
     $268 = $267;
     HEAP32[$268>>2] = $264;
     $269 = $211;
     $270 = $269;
     HEAP32[$270>>2] = $255;
     $271 = (($269) + 4)|0;
     $272 = $271;
     HEAP32[$272>>2] = $258;
     $686 = $255;
     break;
    }
    $273 = $212;
    $274 = $273;
    $275 = HEAP32[$274>>2]|0;
    $276 = (($273) + 4)|0;
    $277 = $276;
    $278 = HEAP32[$277>>2]|0;
    $279 = $$0;
    $280 = $279;
    HEAP32[$280>>2] = $275;
    $281 = (($279) + 4)|0;
    $282 = $281;
    HEAP32[$282>>2] = $278;
    $283 = $212;
    $284 = $283;
    HEAP32[$284>>2] = $255;
    $285 = (($283) + 4)|0;
    $286 = $285;
    HEAP32[$286>>2] = $258;
    $287 = ($216|0)<($255|0);
    if ($287) {
     $288 = $211;
     $289 = $288;
     $290 = HEAP32[$289>>2]|0;
     $291 = (($288) + 4)|0;
     $292 = $291;
     $293 = HEAP32[$292>>2]|0;
     $294 = $212;
     $295 = $294;
     HEAP32[$295>>2] = $290;
     $296 = (($294) + 4)|0;
     $297 = $296;
     HEAP32[$297>>2] = $293;
     $298 = $211;
     $299 = $298;
     HEAP32[$299>>2] = $255;
     $300 = (($298) + 4)|0;
     $301 = $300;
     HEAP32[$301>>2] = $258;
     $686 = $255;
    } else {
     $686 = $216;
    }
   } else {
    if ($217) {
     $218 = $212;
     $219 = $218;
     $220 = HEAP32[$219>>2]|0;
     $221 = (($218) + 4)|0;
     $222 = $221;
     $223 = HEAP32[$222>>2]|0;
     $224 = $211;
     $225 = $224;
     $226 = HEAP32[$225>>2]|0;
     $227 = (($224) + 4)|0;
     $228 = $227;
     $229 = HEAP32[$228>>2]|0;
     $230 = $212;
     $231 = $230;
     HEAP32[$231>>2] = $226;
     $232 = (($230) + 4)|0;
     $233 = $232;
     HEAP32[$233>>2] = $229;
     $234 = $211;
     $235 = $234;
     HEAP32[$235>>2] = $220;
     $236 = (($234) + 4)|0;
     $237 = $236;
     HEAP32[$237>>2] = $223;
     $238 = ($226|0)<($214|0);
     if ($238) {
      $239 = $$0;
      $240 = $239;
      $241 = HEAP32[$240>>2]|0;
      $242 = (($239) + 4)|0;
      $243 = $242;
      $244 = HEAP32[$243>>2]|0;
      $245 = $$0;
      $246 = $245;
      HEAP32[$246>>2] = $226;
      $247 = (($245) + 4)|0;
      $248 = $247;
      HEAP32[$248>>2] = $229;
      $249 = $212;
      $250 = $249;
      HEAP32[$250>>2] = $241;
      $251 = (($249) + 4)|0;
      $252 = $251;
      HEAP32[$252>>2] = $244;
      $686 = $220;
     } else {
      $686 = $220;
     }
    } else {
     $686 = $216;
    }
   }
  } while(0);
  $302 = (($$0) + 24|0);
  $303 = ($302|0)==($$01$ph|0);
  if ($303) {
   STACKTOP = sp;return;
  } else {
   $306 = $686;$__i$02$i = $302;$__j$01$i = $211;
  }
  while(1) {
   $304 = HEAP32[$__i$02$i>>2]|0;
   $305 = ($304|0)<($306|0);
   if ($305) {
    $307 = $__i$02$i;
    $308 = $307;
    $309 = HEAP32[$308>>2]|0;
    $310 = (($307) + 4)|0;
    $311 = $310;
    $312 = HEAP32[$311>>2]|0;
    $__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     $313 = $__k$0$i;
     $314 = $313;
     $315 = HEAP32[$314>>2]|0;
     $316 = (($313) + 4)|0;
     $317 = $316;
     $318 = HEAP32[$317>>2]|0;
     $319 = $__j$1$i;
     $320 = $319;
     HEAP32[$320>>2] = $315;
     $321 = (($319) + 4)|0;
     $322 = $321;
     HEAP32[$322>>2] = $318;
     $323 = ($__k$0$i|0)==($$0|0);
     if ($323) {
      break;
     }
     $324 = (($__k$0$i) + -8|0);
     $325 = HEAP32[$324>>2]|0;
     $326 = ($309|0)<($325|0);
     if ($326) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $324;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $327 = $__k$0$i;
    $328 = $327;
    HEAP32[$328>>2] = $309;
    $329 = (($327) + 4)|0;
    $330 = $329;
    HEAP32[$330>>2] = $312;
   }
   $331 = (($__i$02$i) + 8|0);
   $332 = ($331|0)==($$01$ph|0);
   if ($332) {
    break;
   }
   $$pre$i = HEAP32[$__i$02$i>>2]|0;
   $__j$01$i$phi = $__i$02$i;$306 = $$pre$i;$__i$02$i = $331;$__j$01$i = $__j$01$i$phi;
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 85) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3|0)<($0|0);
 do {
  if ($2) {
   $48 = $__x1;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   if ($4) {
    $54 = $__x3;
    $55 = $54;
    $56 = HEAP32[$55>>2]|0;
    $57 = (($54) + 4)|0;
    $58 = $57;
    $59 = HEAP32[$58>>2]|0;
    $60 = $__x1;
    $61 = $60;
    HEAP32[$61>>2] = $56;
    $62 = (($60) + 4)|0;
    $63 = $62;
    HEAP32[$63>>2] = $59;
    $64 = $__x3;
    $65 = $64;
    HEAP32[$65>>2] = $50;
    $66 = (($64) + 4)|0;
    $67 = $66;
    HEAP32[$67>>2] = $53;
    $$0$i = 1;$100 = $50;
    break;
   }
   $68 = $__x2;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $__x1;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   $78 = $__x2;
   $79 = $78;
   HEAP32[$79>>2] = $50;
   $80 = (($78) + 4)|0;
   $81 = $80;
   HEAP32[$81>>2] = $53;
   $82 = HEAP32[$__x3>>2]|0;
   $83 = ($82|0)<($50|0);
   if ($83) {
    $84 = $__x3;
    $85 = $84;
    $86 = HEAP32[$85>>2]|0;
    $87 = (($84) + 4)|0;
    $88 = $87;
    $89 = HEAP32[$88>>2]|0;
    $90 = $__x2;
    $91 = $90;
    HEAP32[$91>>2] = $86;
    $92 = (($90) + 4)|0;
    $93 = $92;
    HEAP32[$93>>2] = $89;
    $94 = $__x3;
    $95 = $94;
    HEAP32[$95>>2] = $50;
    $96 = (($94) + 4)|0;
    $97 = $96;
    HEAP32[$97>>2] = $53;
    $$0$i = 2;$100 = $50;
   } else {
    $$0$i = 1;$100 = $82;
   }
  } else {
   if ($4) {
    $5 = $__x2;
    $6 = $5;
    $7 = HEAP32[$6>>2]|0;
    $8 = (($5) + 4)|0;
    $9 = $8;
    $10 = HEAP32[$9>>2]|0;
    $11 = $__x3;
    $12 = $11;
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + 4)|0;
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = $__x2;
    $18 = $17;
    HEAP32[$18>>2] = $13;
    $19 = (($17) + 4)|0;
    $20 = $19;
    HEAP32[$20>>2] = $16;
    $21 = $__x3;
    $22 = $21;
    HEAP32[$22>>2] = $7;
    $23 = (($21) + 4)|0;
    $24 = $23;
    HEAP32[$24>>2] = $10;
    $25 = HEAP32[$__x2>>2]|0;
    $26 = HEAP32[$__x1>>2]|0;
    $27 = ($25|0)<($26|0);
    if ($27) {
     $28 = $__x1;
     $29 = $28;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + 4)|0;
     $32 = $31;
     $33 = HEAP32[$32>>2]|0;
     $34 = $__x2;
     $35 = $34;
     $36 = HEAP32[$35>>2]|0;
     $37 = (($34) + 4)|0;
     $38 = $37;
     $39 = HEAP32[$38>>2]|0;
     $40 = $__x1;
     $41 = $40;
     HEAP32[$41>>2] = $36;
     $42 = (($40) + 4)|0;
     $43 = $42;
     HEAP32[$43>>2] = $39;
     $44 = $__x2;
     $45 = $44;
     HEAP32[$45>>2] = $30;
     $46 = (($44) + 4)|0;
     $47 = $46;
     HEAP32[$47>>2] = $33;
     $$pre = HEAP32[$__x3>>2]|0;
     $$0$i = 2;$100 = $$pre;
    } else {
     $$0$i = 1;$100 = $7;
    }
   } else {
    $$0$i = 0;$100 = $3;
   }
  }
 } while(0);
 $98 = HEAP32[$__x4>>2]|0;
 $99 = ($98|0)<($100|0);
 if (!($99)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $101 = $__x3;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = (($101) + 4)|0;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = $__x4;
 $108 = $107;
 $109 = HEAP32[$108>>2]|0;
 $110 = (($107) + 4)|0;
 $111 = $110;
 $112 = HEAP32[$111>>2]|0;
 $113 = $__x3;
 $114 = $113;
 HEAP32[$114>>2] = $109;
 $115 = (($113) + 4)|0;
 $116 = $115;
 HEAP32[$116>>2] = $112;
 $117 = $__x4;
 $118 = $117;
 HEAP32[$118>>2] = $103;
 $119 = (($117) + 4)|0;
 $120 = $119;
 HEAP32[$120>>2] = $106;
 $121 = (($$0$i) + 1)|0;
 $122 = HEAP32[$__x3>>2]|0;
 $123 = HEAP32[$__x2>>2]|0;
 $124 = ($122|0)<($123|0);
 if (!($124)) {
  $__r$0 = $121;
  STACKTOP = sp;return ($__r$0|0);
 }
 $125 = $__x2;
 $126 = $125;
 $127 = HEAP32[$126>>2]|0;
 $128 = (($125) + 4)|0;
 $129 = $128;
 $130 = HEAP32[$129>>2]|0;
 $131 = $__x3;
 $132 = $131;
 $133 = HEAP32[$132>>2]|0;
 $134 = (($131) + 4)|0;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = $__x2;
 $138 = $137;
 HEAP32[$138>>2] = $133;
 $139 = (($137) + 4)|0;
 $140 = $139;
 HEAP32[$140>>2] = $136;
 $141 = $__x3;
 $142 = $141;
 HEAP32[$142>>2] = $127;
 $143 = (($141) + 4)|0;
 $144 = $143;
 HEAP32[$144>>2] = $130;
 $145 = (($$0$i) + 2)|0;
 $146 = HEAP32[$__x2>>2]|0;
 $147 = HEAP32[$__x1>>2]|0;
 $148 = ($146|0)<($147|0);
 if (!($148)) {
  $__r$0 = $145;
  STACKTOP = sp;return ($__r$0|0);
 }
 $149 = $__x1;
 $150 = $149;
 $151 = HEAP32[$150>>2]|0;
 $152 = (($149) + 4)|0;
 $153 = $152;
 $154 = HEAP32[$153>>2]|0;
 $155 = $__x2;
 $156 = $155;
 $157 = HEAP32[$156>>2]|0;
 $158 = (($155) + 4)|0;
 $159 = $158;
 $160 = HEAP32[$159>>2]|0;
 $161 = $__x1;
 $162 = $161;
 HEAP32[$162>>2] = $157;
 $163 = (($161) + 4)|0;
 $164 = $163;
 HEAP32[$164>>2] = $160;
 $165 = $__x2;
 $166 = $165;
 HEAP32[$166>>2] = $151;
 $167 = (($165) + 4)|0;
 $168 = $167;
 HEAP32[$168>>2] = $154;
 $169 = (($$0$i) + 3)|0;
 $__r$0 = $169;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__count$06 = 0, $__count$1 = 0, $__i$07 = 0, $__j$05 = 0, $__j$05$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $28 = (($__first) + 8|0);
  $29 = (($__last) + -8|0);
  $30 = HEAP32[$28>>2]|0;
  $31 = HEAP32[$__first>>2]|0;
  $32 = ($30|0)<($31|0);
  $33 = HEAP32[$29>>2]|0;
  $34 = ($33|0)<($30|0);
  if (!($32)) {
   if (!($34)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $35 = $28;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $38 = (($35) + 4)|0;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = $29;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $28;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   $51 = $29;
   $52 = $51;
   HEAP32[$52>>2] = $37;
   $53 = (($51) + 4)|0;
   $54 = $53;
   HEAP32[$54>>2] = $40;
   $55 = HEAP32[$28>>2]|0;
   $56 = HEAP32[$__first>>2]|0;
   $57 = ($55|0)<($56|0);
   if (!($57)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $58 = $__first;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = (($58) + 4)|0;
   $62 = $61;
   $63 = HEAP32[$62>>2]|0;
   $64 = $28;
   $65 = $64;
   $66 = HEAP32[$65>>2]|0;
   $67 = (($64) + 4)|0;
   $68 = $67;
   $69 = HEAP32[$68>>2]|0;
   $70 = $__first;
   $71 = $70;
   HEAP32[$71>>2] = $66;
   $72 = (($70) + 4)|0;
   $73 = $72;
   HEAP32[$73>>2] = $69;
   $74 = $28;
   $75 = $74;
   HEAP32[$75>>2] = $60;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $63;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $78 = $__first;
  $79 = $78;
  $80 = HEAP32[$79>>2]|0;
  $81 = (($78) + 4)|0;
  $82 = $81;
  $83 = HEAP32[$82>>2]|0;
  if ($34) {
   $84 = $29;
   $85 = $84;
   $86 = HEAP32[$85>>2]|0;
   $87 = (($84) + 4)|0;
   $88 = $87;
   $89 = HEAP32[$88>>2]|0;
   $90 = $__first;
   $91 = $90;
   HEAP32[$91>>2] = $86;
   $92 = (($90) + 4)|0;
   $93 = $92;
   HEAP32[$93>>2] = $89;
   $94 = $29;
   $95 = $94;
   HEAP32[$95>>2] = $80;
   $96 = (($94) + 4)|0;
   $97 = $96;
   HEAP32[$97>>2] = $83;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $98 = $28;
  $99 = $98;
  $100 = HEAP32[$99>>2]|0;
  $101 = (($98) + 4)|0;
  $102 = $101;
  $103 = HEAP32[$102>>2]|0;
  $104 = $__first;
  $105 = $104;
  HEAP32[$105>>2] = $100;
  $106 = (($104) + 4)|0;
  $107 = $106;
  HEAP32[$107>>2] = $103;
  $108 = $28;
  $109 = $108;
  HEAP32[$109>>2] = $80;
  $110 = (($108) + 4)|0;
  $111 = $110;
  HEAP32[$111>>2] = $83;
  $112 = HEAP32[$29>>2]|0;
  $113 = ($112|0)<($80|0);
  if (!($113)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $114 = $29;
  $115 = $114;
  $116 = HEAP32[$115>>2]|0;
  $117 = (($114) + 4)|0;
  $118 = $117;
  $119 = HEAP32[$118>>2]|0;
  $120 = $28;
  $121 = $120;
  HEAP32[$121>>2] = $116;
  $122 = (($120) + 4)|0;
  $123 = $122;
  HEAP32[$123>>2] = $119;
  $124 = $29;
  $125 = $124;
  HEAP32[$125>>2] = $80;
  $126 = (($124) + 4)|0;
  $127 = $126;
  HEAP32[$127>>2] = $83;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $128 = (($__first) + 8|0);
  $129 = (($__first) + 16|0);
  $130 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$128,$129,$130,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $8 = $__first;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $4;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = $__first;
  $21 = $20;
  HEAP32[$21>>2] = $16;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  $24 = $4;
  $25 = $24;
  HEAP32[$25>>2] = $10;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $13;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $131 = (($__first) + 8|0);
  $132 = (($__first) + 16|0);
  $133 = (($__first) + 24|0);
  $134 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters16NameToValueIndexES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$131,$132,$133,0)|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = HEAP32[$133>>2]|0;
  $137 = ($135|0)<($136|0);
  if (!($137)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $138 = $133;
  $139 = $138;
  $140 = HEAP32[$139>>2]|0;
  $141 = (($138) + 4)|0;
  $142 = $141;
  $143 = HEAP32[$142>>2]|0;
  $144 = $134;
  $145 = $144;
  $146 = HEAP32[$145>>2]|0;
  $147 = (($144) + 4)|0;
  $148 = $147;
  $149 = HEAP32[$148>>2]|0;
  $150 = $133;
  $151 = $150;
  HEAP32[$151>>2] = $146;
  $152 = (($150) + 4)|0;
  $153 = $152;
  HEAP32[$153>>2] = $149;
  $154 = $134;
  $155 = $154;
  HEAP32[$155>>2] = $140;
  $156 = (($154) + 4)|0;
  $157 = $156;
  HEAP32[$157>>2] = $143;
  $158 = HEAP32[$133>>2]|0;
  $159 = HEAP32[$132>>2]|0;
  $160 = ($158|0)<($159|0);
  if (!($160)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $161 = $132;
  $162 = $161;
  $163 = HEAP32[$162>>2]|0;
  $164 = (($161) + 4)|0;
  $165 = $164;
  $166 = HEAP32[$165>>2]|0;
  $167 = $133;
  $168 = $167;
  $169 = HEAP32[$168>>2]|0;
  $170 = (($167) + 4)|0;
  $171 = $170;
  $172 = HEAP32[$171>>2]|0;
  $173 = $132;
  $174 = $173;
  HEAP32[$174>>2] = $169;
  $175 = (($173) + 4)|0;
  $176 = $175;
  HEAP32[$176>>2] = $172;
  $177 = $133;
  $178 = $177;
  HEAP32[$178>>2] = $163;
  $179 = (($177) + 4)|0;
  $180 = $179;
  HEAP32[$180>>2] = $166;
  $181 = HEAP32[$131>>2]|0;
  $182 = ($169|0)<($181|0);
  if (!($182)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $183 = $131;
  $184 = $183;
  $185 = HEAP32[$184>>2]|0;
  $186 = (($183) + 4)|0;
  $187 = $186;
  $188 = HEAP32[$187>>2]|0;
  $189 = $131;
  $190 = $189;
  HEAP32[$190>>2] = $169;
  $191 = (($189) + 4)|0;
  $192 = $191;
  HEAP32[$192>>2] = $172;
  $193 = $132;
  $194 = $193;
  HEAP32[$194>>2] = $185;
  $195 = (($193) + 4)|0;
  $196 = $195;
  HEAP32[$196>>2] = $188;
  $197 = HEAP32[$__first>>2]|0;
  $198 = ($169|0)<($197|0);
  if (!($198)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $199 = $__first;
  $200 = $199;
  $201 = HEAP32[$200>>2]|0;
  $202 = (($199) + 4)|0;
  $203 = $202;
  $204 = HEAP32[$203>>2]|0;
  $205 = $__first;
  $206 = $205;
  HEAP32[$206>>2] = $169;
  $207 = (($205) + 4)|0;
  $208 = $207;
  HEAP32[$208>>2] = $172;
  $209 = $131;
  $210 = $209;
  HEAP32[$210>>2] = $201;
  $211 = (($209) + 4)|0;
  $212 = $211;
  HEAP32[$212>>2] = $204;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $213 = (($__first) + 16|0);
  $214 = (($__first) + 8|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = HEAP32[$__first>>2]|0;
  $217 = ($215|0)<($216|0);
  $218 = HEAP32[$213>>2]|0;
  $219 = ($218|0)<($215|0);
  do {
   if ($217) {
    $255 = $__first;
    $256 = $255;
    $257 = HEAP32[$256>>2]|0;
    $258 = (($255) + 4)|0;
    $259 = $258;
    $260 = HEAP32[$259>>2]|0;
    if ($219) {
     $261 = $213;
     $262 = $261;
     $263 = HEAP32[$262>>2]|0;
     $264 = (($261) + 4)|0;
     $265 = $264;
     $266 = HEAP32[$265>>2]|0;
     $267 = $__first;
     $268 = $267;
     HEAP32[$268>>2] = $263;
     $269 = (($267) + 4)|0;
     $270 = $269;
     HEAP32[$270>>2] = $266;
     $271 = $213;
     $272 = $271;
     HEAP32[$272>>2] = $257;
     $273 = (($271) + 4)|0;
     $274 = $273;
     HEAP32[$274>>2] = $260;
     $339 = $257;
     break;
    }
    $275 = $214;
    $276 = $275;
    $277 = HEAP32[$276>>2]|0;
    $278 = (($275) + 4)|0;
    $279 = $278;
    $280 = HEAP32[$279>>2]|0;
    $281 = $__first;
    $282 = $281;
    HEAP32[$282>>2] = $277;
    $283 = (($281) + 4)|0;
    $284 = $283;
    HEAP32[$284>>2] = $280;
    $285 = $214;
    $286 = $285;
    HEAP32[$286>>2] = $257;
    $287 = (($285) + 4)|0;
    $288 = $287;
    HEAP32[$288>>2] = $260;
    $289 = ($218|0)<($257|0);
    if ($289) {
     $290 = $213;
     $291 = $290;
     $292 = HEAP32[$291>>2]|0;
     $293 = (($290) + 4)|0;
     $294 = $293;
     $295 = HEAP32[$294>>2]|0;
     $296 = $214;
     $297 = $296;
     HEAP32[$297>>2] = $292;
     $298 = (($296) + 4)|0;
     $299 = $298;
     HEAP32[$299>>2] = $295;
     $300 = $213;
     $301 = $300;
     HEAP32[$301>>2] = $257;
     $302 = (($300) + 4)|0;
     $303 = $302;
     HEAP32[$303>>2] = $260;
     $339 = $257;
    } else {
     $339 = $218;
    }
   } else {
    if ($219) {
     $220 = $214;
     $221 = $220;
     $222 = HEAP32[$221>>2]|0;
     $223 = (($220) + 4)|0;
     $224 = $223;
     $225 = HEAP32[$224>>2]|0;
     $226 = $213;
     $227 = $226;
     $228 = HEAP32[$227>>2]|0;
     $229 = (($226) + 4)|0;
     $230 = $229;
     $231 = HEAP32[$230>>2]|0;
     $232 = $214;
     $233 = $232;
     HEAP32[$233>>2] = $228;
     $234 = (($232) + 4)|0;
     $235 = $234;
     HEAP32[$235>>2] = $231;
     $236 = $213;
     $237 = $236;
     HEAP32[$237>>2] = $222;
     $238 = (($236) + 4)|0;
     $239 = $238;
     HEAP32[$239>>2] = $225;
     $240 = ($228|0)<($216|0);
     if ($240) {
      $241 = $__first;
      $242 = $241;
      $243 = HEAP32[$242>>2]|0;
      $244 = (($241) + 4)|0;
      $245 = $244;
      $246 = HEAP32[$245>>2]|0;
      $247 = $__first;
      $248 = $247;
      HEAP32[$248>>2] = $228;
      $249 = (($247) + 4)|0;
      $250 = $249;
      HEAP32[$250>>2] = $231;
      $251 = $214;
      $252 = $251;
      HEAP32[$252>>2] = $243;
      $253 = (($251) + 4)|0;
      $254 = $253;
      HEAP32[$254>>2] = $246;
      $339 = $222;
     } else {
      $339 = $222;
     }
    } else {
     $339 = $218;
    }
   }
  } while(0);
  $304 = (($__first) + 24|0);
  $305 = ($304|0)==($__last|0);
  if ($305) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $308 = $339;$__count$06 = 0;$__i$07 = $304;$__j$05 = $213;
  }
  while(1) {
   $306 = HEAP32[$__i$07>>2]|0;
   $307 = ($306|0)<($308|0);
   if ($307) {
    $309 = $__i$07;
    $310 = $309;
    $311 = HEAP32[$310>>2]|0;
    $312 = (($309) + 4)|0;
    $313 = $312;
    $314 = HEAP32[$313>>2]|0;
    $__j$1 = $__i$07;$__k$0 = $__j$05;
    while(1) {
     $315 = $__k$0;
     $316 = $315;
     $317 = HEAP32[$316>>2]|0;
     $318 = (($315) + 4)|0;
     $319 = $318;
     $320 = HEAP32[$319>>2]|0;
     $321 = $__j$1;
     $322 = $321;
     HEAP32[$322>>2] = $317;
     $323 = (($321) + 4)|0;
     $324 = $323;
     HEAP32[$324>>2] = $320;
     $325 = ($__k$0|0)==($__first|0);
     if ($325) {
      break;
     }
     $326 = (($__k$0) + -8|0);
     $327 = HEAP32[$326>>2]|0;
     $328 = ($311|0)<($327|0);
     if ($328) {
      $__j$1$phi = $__k$0;$__k$0 = $326;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $329 = $__k$0;
    $330 = $329;
    HEAP32[$330>>2] = $311;
    $331 = (($329) + 4)|0;
    $332 = $331;
    HEAP32[$332>>2] = $314;
    $333 = (($__count$06) + 1)|0;
    $334 = ($333|0)==(8);
    if ($334) {
     break;
    } else {
     $__count$1 = $333;
    }
   } else {
    $__count$1 = $__count$06;
   }
   $337 = (($__i$07) + 8|0);
   $338 = ($337|0)==($__last|0);
   if ($338) {
    $$0 = 1;
    label = 35;
    break;
   }
   $$pre = HEAP32[$__i$07>>2]|0;
   $__j$05$phi = $__i$07;$308 = $$pre;$__count$06 = $__count$1;$__i$07 = $337;$__j$05 = $__j$05$phi;
  }
  if ((label|0) == 35) {
   STACKTOP = sp;return ($$0|0);
  }
  $335 = (($__i$07) + 8|0);
  $336 = ($335|0)==($__last|0);
  $$0 = $336;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16__sortIRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$027 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0;
 var $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i23 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -20|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = (($3|0) / 20)&-1;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 71;
    break L1;
    break;
   }
   default: {
   }
   }
   $37 = ($3|0)<(620);
   if ($37) {
    label = 21;
    break L1;
   }
   $38 = ($3|0)>(19980);
   $39 = (($3|0) / 40)&-1;
   $40 = (($$0) + (($39*20)|0)|0);
   do {
    if ($38) {
     $41 = (($3|0) / 80)&-1;
     $42 = (($$0) + (($41*20)|0)|0);
     $$sum = (($41) + ($39))|0;
     $43 = (($$0) + (($$sum*20)|0)|0);
     $44 = (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$42,$40,$43,0)|0);
     $45 = HEAP32[$1>>2]|0;
     $46 = HEAP32[$43>>2]|0;
     $47 = ($45|0)<($46|0);
     if (!($47)) {
      $$pre$phiZ2D = $40;$__n_swaps$0 = $44;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$43+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$43+16>>2]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$43+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$43+18>>0]=HEAP8[$1+18>>0]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
     $48 = HEAP32[$43>>2]|0;
     $49 = HEAP32[$40>>2]|0;
     $50 = ($48|0)<($49|0);
     if (!($50)) {
      $51 = (($44) + 1)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $51;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$40+16>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$43+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$43+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$43+18>>0]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$43+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$43+18>>0]=HEAP8[$__t$i23+18>>0]|0;
     $52 = HEAP32[$40>>2]|0;
     $53 = HEAP32[$42>>2]|0;
     $54 = ($52|0)<($53|0);
     if (!($54)) {
      $55 = (($44) + 2)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $55;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$42+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$42+16>>2]|0;
     ;HEAP32[$42+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$40+12>>2]|0;HEAP16[$42+16>>1]=HEAP16[$40+16>>1]|0;HEAP8[$42+18>>0]=HEAP8[$40+18>>0]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$__t$i23+18>>0]|0;
     $56 = HEAP32[$42>>2]|0;
     $57 = HEAP32[$$0>>2]|0;
     $58 = ($56|0)<($57|0);
     if ($58) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$42+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$42+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$42+18>>0]|0;
      ;HEAP32[$42+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$42+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$42+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $60 = (($44) + 4)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $60;
      break;
     } else {
      $59 = (($44) + 3)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $59;
      break;
     }
    } else {
     $61 = HEAP32[$40>>2]|0;
     $62 = HEAP32[$$0>>2]|0;
     $63 = ($61|0)<($62|0);
     $64 = HEAP32[$1>>2]|0;
     $65 = ($64|0)<($61|0);
     if (!($63)) {
      if (!($65)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 0;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$40+16>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$1+18>>0]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $66 = HEAP32[$40>>2]|0;
      $67 = HEAP32[$$0>>2]|0;
      $68 = ($66|0)<($67|0);
      if (!($68)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$40+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$40+18>>0]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
      break;
     }
     if ($65) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$1+18>>0]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
     ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$40+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$40+18>>0]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$__t$i23+18>>0]|0;
     $69 = HEAP32[$1>>2]|0;
     $70 = HEAP32[$40>>2]|0;
     $71 = ($69|0)<($70|0);
     if ($71) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$40+16>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$1+18>>0]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $72 = HEAP32[$$0>>2]|0;
   $73 = HEAP32[$$pre$phiZ2D>>2]|0;
   $74 = ($72|0)<($73|0);
   do {
    if ($74) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $75 = (($__j$0) + -20|0);
      $76 = ($$0|0)==($75|0);
      if ($76) {
       break;
      }
      $94 = HEAP32[$75>>2]|0;
      $95 = ($94|0)<($73|0);
      if ($95) {
       label = 54;
       break;
      } else {
       $__j$0 = $75;
      }
     }
     if ((label|0) == 54) {
      label = 0;
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$75+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$75+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$75+18>>0]|0;
      ;HEAP32[$75+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$75+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$75+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $96 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $75;$__n_swaps$3 = $96;
      break;
     }
     $77 = (($$0) + 20|0);
     $78 = HEAP32[$1>>2]|0;
     $79 = ($72|0)<($78|0);
     if ($79) {
      $__i$1 = $77;
     } else {
      $80 = ($77|0)==($1|0);
      if ($80) {
       label = 71;
       break L1;
      } else {
       $__i$027 = $77;
      }
      while(1) {
       $83 = HEAP32[$__i$027>>2]|0;
       $84 = ($72|0)<($83|0);
       $82 = (($__i$027) + 20|0);
       if ($84) {
        break;
       }
       $81 = ($82|0)==($1|0);
       if ($81) {
        label = 71;
        break L1;
       } else {
        $__i$027 = $82;
       }
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$027+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$027+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$027+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$027+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$__i$027+16>>2]|0;
      ;HEAP32[$__i$027+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$027+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$027+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$027+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$__i$027+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$__i$027+18>>0]=HEAP8[$1+18>>0]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $__i$1 = $82;
     }
     $85 = ($__i$1|0)==($1|0);
     if ($85) {
      label = 71;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $86 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $87 = HEAP32[$__i$2>>2]|0;
       $88 = ($86|0)<($87|0);
       $89 = (($__i$2) + 20|0);
       if ($88) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $89;
       }
      }
      while(1) {
       $90 = (($__j$2) + -20|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($86|0)<($91|0);
       if ($92) {
        $__j$2 = $90;
       } else {
        break;
       }
      }
      $93 = ($__i$2>>>0)<($90>>>0);
      if (!($93)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$2+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$__i$2+16>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$90+12>>2]|0;HEAP16[$__i$2+16>>1]=HEAP16[$90+16>>1]|0;HEAP8[$__i$2+18>>0]=HEAP8[$90+18>>0]|0;
      ;HEAP32[$90+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$90+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$90+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $__i$2$ph = $89;$__j$1$ph = $90;
     }
    }
   } while(0);
   $97 = (($$0) + 20|0);
   $98 = ($97>>>0)<($__j$3>>>0);
   L55: do {
    if ($98) {
     $__i$3$ph = $97;$__j$4$ph = $__j$3;$__m$0$ph = $40;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $99 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $100 = HEAP32[$__i$3>>2]|0;
       $101 = ($100|0)<($99|0);
       $102 = (($__i$3) + 20|0);
       if ($101) {
        $__i$3 = $102;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $103 = (($__j$5) + -20|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ($104|0)<($99|0);
       if ($105) {
        break;
       } else {
        $__j$5 = $103;
       }
      }
      $106 = ($__i$3>>>0)>($103>>>0);
      if ($106) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L55;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$3+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$__i$3+16>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$103+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$103+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$103+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$103+12>>2]|0;HEAP16[$__i$3+16>>1]=HEAP16[$103+16>>1]|0;HEAP8[$__i$3+18>>0]=HEAP8[$103+18>>0]|0;
      ;HEAP32[$103+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$103+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$103+18>>0]=HEAP8[$__t$i23+18>>0]|0;
      $107 = (($__n_swaps$4$ph) + 1)|0;
      $108 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $108 ? $103 : $__m$0$ph;
      $__i$3$ph = $102;$__j$4$ph = $103;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $107;
     }
    } else {
     $__i$4 = $97;$__m$2 = $40;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $109 = ($__i$4|0)==($__m$2|0);
   if ($109) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $110 = HEAP32[$__m$2>>2]|0;
    $111 = HEAP32[$__i$4>>2]|0;
    $112 = ($110|0)<($111|0);
    if ($112) {
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$4+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$__i$4+16>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;HEAP16[$__i$4+16>>1]=HEAP16[$__m$2+16>>1]|0;HEAP8[$__i$4+18>>0]=HEAP8[$__m$2+18>>0]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$__m$2+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$__m$2+18>>0]=HEAP8[$__t$i23+18>>0]|0;
     $113 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $113;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $114 = ($__n_swaps$6|0)==(0);
   if ($114) {
    $115 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEbT0_S7_T_($$0,$__i$4,0)|0);
    $116 = (($__i$4) + 20|0);
    $117 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEbT0_S7_T_($116,$$01$ph,0)|0);
    if ($117) {
     label = 66;
     break;
    }
    if ($115) {
     $$0 = $116;
     continue;
    }
   }
   $118 = $__i$4;
   $119 = (($118) - ($2))|0;
   $120 = (($0) - ($118))|0;
   $121 = ($119|0)<($120|0);
   if (!($121)) {
    label = 70;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEvT0_S7_T_($$0,$__i$4,$__comp);
   $122 = (($__i$4) + 20|0);
   $$0 = $122;
  }
  if ((label|0) == 66) {
   label = 0;
   if ($115) {
    label = 71;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 70) {
   label = 0;
   $123 = (($__i$4) + 20|0);
   __ZNSt3__16__sortIRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEvT0_S7_T_($123,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$1+18>>0]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $8 = (($$0) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$$0>>2]|0;
  $11 = ($9|0)<($10|0);
  $12 = HEAP32[$1>>2]|0;
  $13 = ($12|0)<($9|0);
  if (!($11)) {
   if (!($13)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$8+16>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$8+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$8+18>>0]=HEAP8[$1+18>>0]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
   $14 = HEAP32[$8>>2]|0;
   $15 = HEAP32[$$0>>2]|0;
   $16 = ($14|0)<($15|0);
   if (!($16)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$8+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$8+18>>0]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$8+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$8+18>>0]=HEAP8[$__t$i23+18>>0]|0;
   STACKTOP = sp;return;
  }
  if ($13) {
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$1+18>>0]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$8+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$8+18>>0]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$8+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$8+18>>0]=HEAP8[$__t$i23+18>>0]|0;
  $17 = HEAP32[$1>>2]|0;
  $18 = HEAP32[$8>>2]|0;
  $19 = ($17|0)<($18|0);
  if (!($19)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$8+16>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$8+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$8+18>>0]=HEAP8[$1+18>>0]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $20 = (($$0) + 20|0);
  $21 = (($$0) + 40|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$20,$21,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $22 = (($$0) + 20|0);
  $23 = (($$0) + 40|0);
  $24 = (($$0) + 60|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$22,$23,$24,0)|0);
  $25 = HEAP32[$1>>2]|0;
  $26 = HEAP32[$24>>2]|0;
  $27 = ($25|0)<($26|0);
  if (!($27)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$24+16>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$24+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$24+18>>0]=HEAP8[$1+18>>0]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i23+18>>0]|0;
  $28 = HEAP32[$24>>2]|0;
  $29 = HEAP32[$23>>2]|0;
  $30 = ($28|0)<($29|0);
  if (!($30)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$23+16>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;HEAP16[$23+16>>1]=HEAP16[$24+16>>1]|0;HEAP8[$23+18>>0]=HEAP8[$24+18>>0]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$24+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$24+18>>0]=HEAP8[$__t$i23+18>>0]|0;
  $31 = HEAP32[$23>>2]|0;
  $32 = HEAP32[$22>>2]|0;
  $33 = ($31|0)<($32|0);
  if (!($33)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$22+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$22+16>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;HEAP16[$22+16>>1]=HEAP16[$23+16>>1]|0;HEAP8[$22+18>>0]=HEAP8[$23+18>>0]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$23+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$23+18>>0]=HEAP8[$__t$i23+18>>0]|0;
  $34 = HEAP32[$22>>2]|0;
  $35 = HEAP32[$$0>>2]|0;
  $36 = ($34|0)<($35|0);
  if (!($36)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i23+16>>2]=HEAP32[$$0+16>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$22+12>>2]|0;HEAP16[$$0+16>>1]=HEAP16[$22+16>>1]|0;HEAP8[$$0+18>>0]=HEAP8[$22+18>>0]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i23+12>>2]|0;HEAP16[$22+16>>1]=HEAP16[$__t$i23+16>>1]|0;HEAP8[$22+18>>0]=HEAP8[$__t$i23+18>>0]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEvT0_S7_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 71) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i2 = sp;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3|0)<($0|0);
 do {
  if ($2) {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;
    ;HEAP32[$__x1+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP16[$__x1+16>>1]=HEAP16[$__x3+16>>1]|0;HEAP8[$__x1+18>>0]=HEAP8[$__x3+18>>0]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP16[$__x3+16>>1]=HEAP16[$__t$i2+16>>1]|0;HEAP8[$__x3+18>>0]=HEAP8[$__t$i2+18>>0]|0;
    $$0$i = 1;
    break;
   }
   ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;
   ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP16[$__x1+16>>1]=HEAP16[$__x2+16>>1]|0;HEAP8[$__x1+18>>0]=HEAP8[$__x2+18>>0]|0;
   ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP16[$__x2+16>>1]=HEAP16[$__t$i2+16>>1]|0;HEAP8[$__x2+18>>0]=HEAP8[$__t$i2+18>>0]|0;
   $8 = HEAP32[$__x3>>2]|0;
   $9 = HEAP32[$__x2>>2]|0;
   $10 = ($8|0)<($9|0);
   if ($10) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x2+16>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP16[$__x2+16>>1]=HEAP16[$__x3+16>>1]|0;HEAP8[$__x2+18>>0]=HEAP8[$__x3+18>>0]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP16[$__x3+16>>1]=HEAP16[$__t$i2+16>>1]|0;HEAP8[$__x3+18>>0]=HEAP8[$__t$i2+18>>0]|0;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x2+16>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP16[$__x2+16>>1]=HEAP16[$__x3+16>>1]|0;HEAP8[$__x2+18>>0]=HEAP8[$__x3+18>>0]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP16[$__x3+16>>1]=HEAP16[$__t$i2+16>>1]|0;HEAP8[$__x3+18>>0]=HEAP8[$__t$i2+18>>0]|0;
    $5 = HEAP32[$__x2>>2]|0;
    $6 = HEAP32[$__x1>>2]|0;
    $7 = ($5|0)<($6|0);
    if ($7) {
     ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;
     ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP16[$__x1+16>>1]=HEAP16[$__x2+16>>1]|0;HEAP8[$__x1+18>>0]=HEAP8[$__x2+18>>0]|0;
     ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP16[$__x2+16>>1]=HEAP16[$__t$i2+16>>1]|0;HEAP8[$__x2+18>>0]=HEAP8[$__t$i2+18>>0]|0;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $11 = HEAP32[$__x4>>2]|0;
 $12 = HEAP32[$__x3>>2]|0;
 $13 = ($11|0)<($12|0);
 if (!($13)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x3+16>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP16[$__x3+16>>1]=HEAP16[$__x4+16>>1]|0;HEAP8[$__x3+18>>0]=HEAP8[$__x4+18>>0]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP16[$__x4+16>>1]=HEAP16[$__t$i2+16>>1]|0;HEAP8[$__x4+18>>0]=HEAP8[$__t$i2+18>>0]|0;
 $14 = (($$0$i) + 1)|0;
 $15 = HEAP32[$__x3>>2]|0;
 $16 = HEAP32[$__x2>>2]|0;
 $17 = ($15|0)<($16|0);
 if (!($17)) {
  $__r$0 = $14;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x2+16>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP16[$__x2+16>>1]=HEAP16[$__x3+16>>1]|0;HEAP8[$__x2+18>>0]=HEAP8[$__x3+18>>0]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP16[$__x3+16>>1]=HEAP16[$__t$i2+16>>1]|0;HEAP8[$__x3+18>>0]=HEAP8[$__t$i2+18>>0]|0;
 $18 = (($$0$i) + 2)|0;
 $19 = HEAP32[$__x2>>2]|0;
 $20 = HEAP32[$__x1>>2]|0;
 $21 = ($19|0)<($20|0);
 if (!($21)) {
  $__r$0 = $18;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP16[$__x1+16>>1]=HEAP16[$__x2+16>>1]|0;HEAP8[$__x1+18>>0]=HEAP8[$__x2+18>>0]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP16[$__x2+16>>1]=HEAP16[$__t$i2+16>>1]|0;HEAP8[$__x2+18>>0]=HEAP8[$__t$i2+18>>0]|0;
 $22 = (($$0$i) + 3)|0;
 $__r$0 = $22;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i = 0, $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i4$i = sp + 16|0;
 $__t$sroa$1 = sp;
 $0 = (($__first) + 40|0);
 $1 = (($__first) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = ($2|0)<($3|0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)<($2|0);
 do {
  if ($4) {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$__first+16>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$0+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$0+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$0+18>>0]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP16[$0+16>>1]=HEAP16[$__t$i4$i+16>>1]|0;HEAP8[$0+18>>0]=HEAP8[$__t$i4$i+18>>0]|0;
    break;
   }
   ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$__first+16>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$1+18>>0]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i4$i+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i4$i+18>>0]|0;
   $9 = HEAP32[$1>>2]|0;
   $10 = ($5|0)<($9|0);
   if ($10) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$1+16>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$0+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$0+18>>0]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP16[$0+16>>1]=HEAP16[$__t$i4$i+16>>1]|0;HEAP8[$0+18>>0]=HEAP8[$__t$i4$i+18>>0]|0;
   }
  } else {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$1+16>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$0+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$0+18>>0]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP16[$0+16>>1]=HEAP16[$__t$i4$i+16>>1]|0;HEAP8[$0+18>>0]=HEAP8[$__t$i4$i+18>>0]|0;
    $7 = HEAP32[$1>>2]|0;
    $8 = ($7|0)<($3|0);
    if ($8) {
     ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i+16>>2]=HEAP32[$__first+16>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$1+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$1+18>>0]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;HEAP16[$1+16>>1]=HEAP16[$__t$i4$i+16>>1]|0;HEAP8[$1+18>>0]=HEAP8[$__t$i4$i+18>>0]|0;
    }
   }
  }
 } while(0);
 $11 = (($__first) + 60|0);
 $12 = ($11|0)==($__last|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $__i$02 = $11;$__j$01 = $0;
 while(1) {
  $13 = HEAP32[$__i$02>>2]|0;
  $14 = HEAP32[$__j$01>>2]|0;
  $15 = ($13|0)<($14|0);
  if ($15) {
   $16 = (($__i$02) + 4|0);
   ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$__t$sroa$1+12>>2]=HEAP32[$16+12>>2]|0;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;HEAP16[$__j$1+16>>1]=HEAP16[$__k$0+16>>1]|0;HEAP8[$__j$1+18>>0]=HEAP8[$__k$0+18>>0]|0;
    $17 = ($__k$0|0)==($__first|0);
    if ($17) {
     $__k$0$lcssa = $__first;
     break;
    }
    $18 = (($__k$0) + -20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($13|0)<($19|0);
    if ($20) {
     $__j$1$phi = $__k$0;$__k$0 = $18;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAP32[$__k$0$lcssa>>2] = $13;
   $21 = (($__k$0$lcssa) + 4|0);
   ;HEAP32[$21+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;HEAP16[$21+12>>1]=HEAP16[$__t$sroa$1+12>>1]|0;HEAP8[$21+14>>0]=HEAP8[$__t$sroa$1+14>>0]|0;
  }
  $22 = (($__i$02) + 20|0);
  $23 = ($22|0)==($__last|0);
  if ($23) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $22;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$014 = 0, $__count$1 = 0, $__i$015 = 0, $__j$013 = 0, $__j$013$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i5 = 0, $__t$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i4$i5 = sp + 16|0;
 $__t$sroa$1 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 20)&-1;
 switch ($3|0) {
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $24 = (($__first) + 20|0);
  $25 = (($__first) + 40|0);
  $26 = (($__first) + 60|0);
  $27 = (($__last) + -20|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$24,$25,$26,0)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$26>>2]|0;
  $30 = ($28|0)<($29|0);
  if (!($30)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$26+16>>2]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$27+12>>2]|0;HEAP16[$26+16>>1]=HEAP16[$27+16>>1]|0;HEAP8[$26+18>>0]=HEAP8[$27+18>>0]|0;
  ;HEAP32[$27+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$27+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$27+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
  $31 = HEAP32[$26>>2]|0;
  $32 = HEAP32[$25>>2]|0;
  $33 = ($31|0)<($32|0);
  if (!($33)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$25+16>>2]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;HEAP16[$25+16>>1]=HEAP16[$26+16>>1]|0;HEAP8[$25+18>>0]=HEAP8[$26+18>>0]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$26+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$26+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
  $34 = HEAP32[$25>>2]|0;
  $35 = HEAP32[$24>>2]|0;
  $36 = ($34|0)<($35|0);
  if (!($36)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$24+16>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;HEAP16[$24+16>>1]=HEAP16[$25+16>>1]|0;HEAP8[$24+18>>0]=HEAP8[$25+18>>0]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$25+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$25+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
  $37 = HEAP32[$24>>2]|0;
  $38 = HEAP32[$__first>>2]|0;
  $39 = ($37|0)<($38|0);
  if (!($39)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$24+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$24+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$24+18>>0]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$24+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$24+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $8 = (($__first) + 20|0);
  $9 = (($__last) + -20|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$__first>>2]|0;
  $12 = ($10|0)<($11|0);
  $13 = HEAP32[$9>>2]|0;
  $14 = ($13|0)<($10|0);
  if (!($12)) {
   if (!($14)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$8+16>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;HEAP16[$8+16>>1]=HEAP16[$9+16>>1]|0;HEAP8[$8+18>>0]=HEAP8[$9+18>>0]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$9+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$9+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
   $15 = HEAP32[$8>>2]|0;
   $16 = HEAP32[$__first>>2]|0;
   $17 = ($15|0)<($16|0);
   if (!($17)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$8+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$8+18>>0]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$8+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$8+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($14) {
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$9+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$9+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$9+18>>0]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$9+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$9+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$8+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$8+18>>0]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$8+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$8+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
  $18 = HEAP32[$9>>2]|0;
  $19 = HEAP32[$8>>2]|0;
  $20 = ($18|0)<($19|0);
  if (!($20)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$8+16>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;HEAP16[$8+16>>1]=HEAP16[$9+16>>1]|0;HEAP8[$8+18>>0]=HEAP8[$9+18>>0]|0;
  ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$9+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$9+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $21 = (($__first) + 20|0);
  $22 = (($__first) + 40|0);
  $23 = (($__last) + -20|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN20GpuProgramParameters14ValueParameterES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$21,$22,$23,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$4+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$4+18>>0]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$4+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$4+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $40 = (($__first) + 40|0);
  $41 = (($__first) + 20|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$__first>>2]|0;
  $44 = ($42|0)<($43|0);
  $45 = HEAP32[$40>>2]|0;
  $46 = ($45|0)<($42|0);
  do {
   if ($44) {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$40+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$40+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$40+18>>0]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
     break;
    }
    ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$41+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$41+18>>0]|0;
    ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$41+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$41+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
    $49 = HEAP32[$41>>2]|0;
    $50 = ($45|0)<($49|0);
    if ($50) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$41+16>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;HEAP16[$41+16>>1]=HEAP16[$40+16>>1]|0;HEAP8[$41+18>>0]=HEAP8[$40+18>>0]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
    }
   } else {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$41+16>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;HEAP16[$41+16>>1]=HEAP16[$40+16>>1]|0;HEAP8[$41+18>>0]=HEAP8[$40+18>>0]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$40+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$40+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
     $47 = HEAP32[$41>>2]|0;
     $48 = ($47|0)<($43|0);
     if ($48) {
      ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i4$i5+16>>2]=HEAP32[$__first+16>>2]|0;
      ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;HEAP16[$__first+16>>1]=HEAP16[$41+16>>1]|0;HEAP8[$__first+18>>0]=HEAP8[$41+18>>0]|0;
      ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;HEAP16[$41+16>>1]=HEAP16[$__t$i4$i5+16>>1]|0;HEAP8[$41+18>>0]=HEAP8[$__t$i4$i5+18>>0]|0;
     }
    }
   }
  } while(0);
  $51 = (($__first) + 60|0);
  $52 = ($51|0)==($__last|0);
  if ($52) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$014 = 0;$__i$015 = $51;$__j$013 = $40;
  while(1) {
   $53 = HEAP32[$__i$015>>2]|0;
   $54 = HEAP32[$__j$013>>2]|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($__i$015) + 4|0);
    ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$__t$sroa$1+12>>2]=HEAP32[$56+12>>2]|0;
    $__j$1 = $__i$015;$__k$0 = $__j$013;
    while(1) {
     ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;HEAP16[$__j$1+16>>1]=HEAP16[$__k$0+16>>1]|0;HEAP8[$__j$1+18>>0]=HEAP8[$__k$0+18>>0]|0;
     $57 = ($__k$0|0)==($__first|0);
     if ($57) {
      $__k$0$lcssa = $__first;
      break;
     }
     $58 = (($__k$0) + -20|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($53|0)<($59|0);
     if ($60) {
      $__j$1$phi = $__k$0;$__k$0 = $58;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $53;
    $61 = (($__k$0$lcssa) + 4|0);
    ;HEAP32[$61+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;HEAP16[$61+12>>1]=HEAP16[$__t$sroa$1+12>>1]|0;HEAP8[$61+14>>0]=HEAP8[$__t$sroa$1+14>>0]|0;
    $62 = (($__count$014) + 1)|0;
    $63 = ($62|0)==(8);
    if ($63) {
     break;
    } else {
     $__count$1 = $62;
    }
   } else {
    $__count$1 = $__count$014;
   }
   $66 = (($__i$015) + 20|0);
   $67 = ($66|0)==($__last|0);
   if ($67) {
    $$0 = 1;
    label = 35;
    break;
   } else {
    $__j$013$phi = $__i$015;$__count$014 = $__count$1;$__i$015 = $66;$__j$013 = $__j$013$phi;
   }
  }
  if ((label|0) == 35) {
   STACKTOP = sp;return ($$0|0);
  }
  $64 = (($__i$015) + 20|0);
  $65 = ($64|0)==($__last|0);
  $$0 = $65;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i10 = 0, $$0$i11 = 0, $$sum = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$__position>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($0) + ($5<<2)|0);
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)<($10>>>0);
 if ($11) {
  $12 = ($6|0)==($8|0);
  if ($12) {
   $13 = ($6|0)==(0|0);
   if (!($13)) {
    $14 = HEAP32[$__x>>2]|0;
    HEAP32[$6>>2] = $14;
   }
   $$sum15 = (($5) + 1)|0;
   $15 = (($0) + ($$sum15<<2)|0);
   HEAP32[$7>>2] = $15;
   $__p$0 = $6;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($5) + 1)|0;
  $16 = (($0) + ($$sum<<2)|0);
  $17 = $8;
  $18 = $16;
  $19 = (($17) - ($18))|0;
  $20 = $19 >> 2;
  $$sum14 = (($20) + ($5))|0;
  $21 = (($0) + ($$sum14<<2)|0);
  $22 = ($21>>>0)<($8>>>0);
  if ($22) {
   $24 = $8;$__i$01$i = $21;
   while(1) {
    $23 = ($24|0)==(0|0);
    if (!($23)) {
     $25 = HEAP32[$__i$01$i>>2]|0;
     HEAP32[$24>>2] = $25;
    }
    $26 = (($__i$01$i) + 4|0);
    $27 = (($24) + 4|0);
    $28 = ($26>>>0)<($8>>>0);
    if ($28) {
     $24 = $27;$__i$01$i = $26;
    } else {
     break;
    }
   }
   HEAP32[$7>>2] = $27;
  }
  $29 = (0 - ($20))|0;
  $30 = (($8) + ($29<<2)|0);
  _memmove(($30|0),($6|0),($19|0))|0;
  $31 = ($6>>>0)>($__x>>>0);
  if ($31) {
   $__xr$0 = $__x;
  } else {
   $32 = HEAP32[$7>>2]|0;
   $33 = ($32>>>0)>($__x>>>0);
   $34 = (($__x) + 4|0);
   $$ = $33 ? $34 : $__x;
   $__xr$0 = $$;
  }
  $35 = HEAP32[$__xr$0>>2]|0;
  HEAP32[$6>>2] = $35;
  $__p$0 = $6;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $36 = $8;
 $37 = (($36) - ($3))|0;
 $38 = $37 >> 2;
 $39 = (($38) + 1)|0;
 $40 = ($39>>>0)>(1073741823);
 if ($40) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $41 = $10;
 $42 = (($41) - ($3))|0;
 $43 = $42 >> 2;
 $44 = ($43>>>0)<(536870911);
 if ($44) {
  $47 = $42 >> 1;
  $48 = ($47>>>0)<($39>>>0);
  $49 = $48 ? $39 : $47;
  $50 = $6;
  $51 = $4 >> 2;
  $52 = ($49|0)==(0);
  if ($52) {
   $$0$i11 = 0;$56 = 0;$57 = $51;$82 = $50;
  } else {
   $$0$i10 = $49;$96 = $51;$97 = $50;
   label = 19;
  }
 } else {
  $45 = $6;
  $46 = $4 >> 2;
  $$0$i10 = 1073741823;$96 = $46;$97 = $45;
  label = 19;
 }
 if ((label|0) == 19) {
  $53 = $$0$i10 << 2;
  $54 = (__Znwj($53)|0);
  $$0$i11 = $$0$i10;$56 = $54;$57 = $96;$82 = $97;
 }
 $55 = (($56) + ($57<<2)|0);
 $58 = (($56) + ($$0$i11<<2)|0);
 $59 = ($57|0)==($$0$i11|0);
 do {
  if ($59) {
   $60 = ($57|0)>(0);
   if ($60) {
    $61 = (($57) + 1)|0;
    $62 = (($61|0) / -2)&-1;
    $$sum13 = (($62) + ($57))|0;
    $63 = (($56) + ($$sum13<<2)|0);
    $76 = $63;$91 = $58;
    break;
   }
   $64 = $57 << 1;
   $65 = ($57|0)==(0);
   $66 = $65 ? 1 : $64;
   $67 = $66 << 2;
   __THREW__ = 0;
   $68 = (invoke_ii(2988,($67|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    $71 = $66 >>> 2;
    $72 = (($68) + ($71<<2)|0);
    $73 = (($68) + ($66<<2)|0);
    $74 = ($56|0)==(0|0);
    if ($74) {
     $76 = $72;$91 = $73;
     break;
    }
    __ZdlPv($56);
    $76 = $72;$91 = $73;
    break;
   }
   $93 = ___cxa_find_matching_catch()|0;
   $94 = tempRet0;
   $95 = ($56|0)==(0|0);
   if ($95) {
    ___resumeException($93|0);
    // unreachable;
   }
   __ZdlPv($56);
   ___resumeException($93|0);
   // unreachable;
  } else {
   $76 = $55;$91 = $58;
  }
 } while(0);
 $75 = ($76|0)==(0|0);
 if (!($75)) {
  $77 = HEAP32[$__x>>2]|0;
  HEAP32[$76>>2] = $77;
 }
 $78 = (($76) + 4|0);
 $79 = HEAP32[$this>>2]|0;
 $80 = $79;
 $81 = (($82) - ($80))|0;
 $83 = $81 >> 2;
 $84 = (0 - ($83))|0;
 $85 = (($76) + ($84<<2)|0);
 _memcpy(($85|0),($79|0),($81|0))|0;
 $86 = HEAP32[$7>>2]|0;
 $87 = $86;
 $88 = (($87) - ($82))|0;
 $89 = $88 >> 2;
 _memcpy(($78|0),($6|0),($88|0))|0;
 $$sum12 = (($89) + 1)|0;
 $90 = (($76) + ($$sum12<<2)|0);
 HEAP32[$this>>2] = $85;
 HEAP32[$7>>2] = $90;
 HEAP32[$9>>2] = $91;
 $92 = ($79|0)==(0|0);
 if ($92) {
  $__p$0 = $76;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 __ZdlPv($79);
 $__p$0 = $76;
 HEAP32[$agg$result>>2] = $__p$0;
 STACKTOP = sp;return;
}
function __ZN20GpuProgramParametersD2Ev($this) {
 $this = $this|0;
 var $$2 = 0, $$23 = 0, $$byval_copy5 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i6 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i7 = 0;
 var $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i11 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i9 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($this) + 64|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  do {
   if ($9) {
    $25 = $5;
   } else {
    $11 = $8;
    while(1) {
     $10 = (($11) + -28|0);
     HEAP32[$7>>2] = $10;
     $12 = (($11) + -12|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)>(-1);
     if ($14) {
      $17 = (($11) + -24|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($11) + -20|0);
      $20 = HEAP32[$19>>2]|0;
      HEAP32[$0>>2] = $20;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($18|0),($$byval_copy5|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 8;
       break;
      }
      HEAP32[$17>>2] = 0;
      $$pre$i$i$i$i$i = HEAP32[$7>>2]|0;
      $16 = $$pre$i$i$i$i$i;
     } else {
      $16 = $10;
     }
     $15 = ($16|0)==($5|0);
     if ($15) {
      label = 9;
      break;
     } else {
      $11 = $16;
     }
    }
    if ((label|0) == 8) {
     $23 = ___cxa_find_matching_catch()|0;
     $24 = tempRet0;
     ___cxa_call_unexpected(($23|0));
     // unreachable;
    }
    else if ((label|0) == 9) {
     $$pre$i$i$i = HEAP32[$4>>2]|0;
     $25 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($25);
 }
 $26 = (($this) + 56|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)>(-1);
 do {
  if ($28) {
   $29 = (($this) + 44|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($this) + 48|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$3>>2] = $32;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($30|0),($$byval_copy5|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    HEAP32[$29>>2] = 0;
    label = 14;
    break;
   }
   $59 = ___cxa_find_matching_catch()|0;
   $60 = tempRet0;
   $61 = (($this) + 32|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    $64 = (($this) + 36|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65|0)==($62|0);
    if (!($66)) {
     $__new_last2$i$i$i$i$i6 = $62;
     $scevgep$i$i$i$i$i7 = (($65) + -16|0);
     $67 = (0 - ($__new_last2$i$i$i$i$i6))|0;
     $uglygep$i$i$i$i$i9 = (($scevgep$i$i$i$i$i7) + ($67)|0);
     $uglygep3$i$i$i$i$i10 = $uglygep$i$i$i$i$i9;
     $68 = $uglygep3$i$i$i$i$i10 >>> 4;
     $69 = $68 ^ -1;
     $scevgep4$i$i$i$i$i11 = (($65) + ($69<<4)|0);
     HEAP32[$64>>2] = $scevgep4$i$i$i$i$i11;
    }
    __ZdlPv($62);
   }
   $72 = (($this) + 28|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)>(-1);
   if ($74) {
    $75 = (($this) + 16|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = (($this) + 20|0);
    $78 = HEAP32[$77>>2]|0;
    HEAP32[$1>>2] = $78;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($76|0),($$byval_copy5|0));
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     $89 = ___cxa_find_matching_catch(0|0)|0;
     $90 = tempRet0;
     ___clang_call_terminate($89);
     // unreachable;
    } else {
     HEAP32[$75>>2] = 0;
     $$2 = $60;$$23 = $59;
     break;
    }
   } else {
    $$2 = $60;$$23 = $59;
   }
  } else {
   label = 14;
  }
 } while(0);
 L31: do {
  if ((label|0) == 14) {
   $35 = (($this) + 32|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if (!($37)) {
    $38 = (($this) + 36|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==($36|0);
    if (!($40)) {
     $__new_last2$i$i$i$i$i = $36;
     $scevgep$i$i$i$i$i = (($39) + -16|0);
     $41 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($41)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $42 = $uglygep3$i$i$i$i$i >>> 4;
     $43 = $42 ^ -1;
     $scevgep4$i$i$i$i$i = (($39) + ($43<<4)|0);
     HEAP32[$38>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($36);
   }
   $44 = (($this) + 28|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)>(-1);
   do {
    if ($46) {
     $47 = (($this) + 16|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($this) + 20|0);
     $50 = HEAP32[$49>>2]|0;
     HEAP32[$2>>2] = $50;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($48|0),($$byval_copy5|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      $70 = ___cxa_find_matching_catch()|0;
      $71 = tempRet0;
      $$2 = $71;$$23 = $70;
      break L31;
     } else {
      HEAP32[$47>>2] = 0;
      break;
     }
    }
   } while(0);
   $53 = (($this) + 12|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)>(-1);
   if (!($55)) {
    STACKTOP = sp;return;
   }
   $56 = HEAP32[$this>>2]|0;
   $57 = (($this) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   HEAP32[$0>>2] = $58;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($56,$$byval_copy5);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $81 = (($this) + 12|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)>(-1);
 if (!($83)) {
  ___resumeException($$23|0);
  // unreachable;
 }
 $84 = HEAP32[$this>>2]|0;
 $85 = (($this) + 4|0);
 $86 = HEAP32[$85>>2]|0;
 HEAP32[$0>>2] = $86;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($84|0),($$byval_copy5|0));
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if ($88) {
  $89 = ___cxa_find_matching_catch(0|0)|0;
  $90 = tempRet0;
  ___clang_call_terminate($89);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$23|0);
 // unreachable;
}
function __ZN12TextureIdMap10InitializeEv() {
 var $$01$i$i$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP8[599632>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 HEAP8[((599640 + 9|0))>>0] = 1;
 $3 = ((599640 + 20|0));
 $4 = $3;
 HEAP32[$4>>2] = -1;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[((599640 + 32|0))>>2]|0;
 $8 = $7 << 3;
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $9 = (__Z15malloc_internaljj10MemLabelIdiPKci($8,16,$$byval_copy,0,599696,79)|0);
 HEAP32[((599640 + 28|0))>>2] = $9;
 $10 = HEAP32[((599640 + 32|0))>>2]|0;
 $11 = (($9) + ($10<<3)|0);
 $12 = ($9|0)==($11|0);
 if (!($12)) {
  $$01$i$i$i$i = $9;
  while(1) {
   $13 = ($$01$i$i$i$i|0)==(0|0);
   if (!($13)) {
    $14 = ((599640 + 20|0));
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + 4)|0;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = $$01$i$i$i$i;
    $21 = $20;
    HEAP32[$21>>2] = $16;
    $22 = (($20) + 4)|0;
    $23 = $22;
    HEAP32[$23>>2] = $19;
   }
   $24 = (($$01$i$i$i$i) + 8|0);
   $25 = ($24|0)==($11|0);
   if ($25) {
    break;
   } else {
    $$01$i$i$i$i = $24;
   }
  }
 }
 __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E14squash_deletedEv(599640);
 HEAP8[((599640 + 8|0))>>0] = 1;
 $26 = ((599640 + 12|0));
 $27 = $26;
 HEAP32[$27>>2] = -2;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = 0;
 HEAP8[599632>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN12TextureIdMap12UninitializeEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E14squash_deletedEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($tmp) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($tmp) + 8|0);
 $6 = (($this) + 8|0);
 $7 = HEAP8[$6>>0]|0;
 HEAP8[$5>>0] = $7;
 $8 = (($tmp) + 9|0);
 $9 = (($this) + 9|0);
 $10 = HEAP8[$9>>0]|0;
 HEAP8[$8>>0] = $10;
 $11 = (($tmp) + 12|0);
 $12 = (($this) + 12|0);
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $11;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 $23 = (($tmp) + 20|0);
 $24 = (($this) + 20|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $23;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = (($tmp) + 28|0);
 ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;HEAP8[$35+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E9copy_fromERKSF_j($tmp,$this,0);
 $36 = HEAP32[$1>>2]|0;
 $37 = HEAP32[$4>>2]|0;
 HEAP32[$1>>2] = $37;
 HEAP32[$4>>2] = $36;
 $38 = HEAP8[$6>>0]|0;
 $39 = HEAP16[$5>>1]|0;
 $40 = $39&255;
 HEAP8[$6>>0] = $40;
 HEAP8[$5>>0] = $38;
 $41 = HEAP8[$9>>0]|0;
 $42 = ($39&65535) >>> 8;
 $43 = $42&255;
 HEAP8[$9>>0] = $43;
 HEAP8[$8>>0] = $41;
 $44 = $12;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = (($44) + 4)|0;
 $48 = $47;
 $49 = HEAP32[$48>>2]|0;
 $50 = $11;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 4)|0;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = $12;
 $57 = $56;
 HEAP32[$57>>2] = $52;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = $55;
 $60 = $11;
 $61 = $60;
 HEAP32[$61>>2] = $46;
 $62 = (($60) + 4)|0;
 $63 = $62;
 HEAP32[$63>>2] = $49;
 $64 = $24;
 $65 = $64;
 $66 = HEAP32[$65>>2]|0;
 $67 = (($64) + 4)|0;
 $68 = $67;
 $69 = HEAP32[$68>>2]|0;
 $70 = $23;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = (($70) + 4)|0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = $24;
 $77 = $76;
 HEAP32[$77>>2] = $72;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $75;
 $80 = $23;
 $81 = $80;
 HEAP32[$81>>2] = $66;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $69;
 $84 = (($this) + 28|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = HEAP32[$35>>2]|0;
 HEAP32[$84>>2] = $86;
 HEAP32[$35>>2] = $85;
 $87 = (($this) + 32|0);
 $88 = (($tmp) + 32|0);
 $89 = HEAP32[$87>>2]|0;
 $90 = HEAP32[$88>>2]|0;
 HEAP32[$87>>2] = $90;
 HEAP32[$88>>2] = $89;
 $91 = (($this) + 36|0);
 $92 = (($tmp) + 36|0);
 $93 = HEAP32[$91>>2]|0;
 $94 = HEAP32[$92>>2]|0;
 HEAP32[$91>>2] = $94;
 HEAP32[$92>>2] = $93;
 $95 = (Math_fround(($90>>>0)));
 $96 = Math_fround($95 * Math_fround(0.5));
 $97 = (~~(($96))>>>0);
 $98 = (($this) + 44|0);
 HEAP32[$98>>2] = $97;
 $99 = Math_fround($95 * Math_fround(0.20000000298023223877));
 $100 = (~~(($99))>>>0);
 $101 = (($this) + 40|0);
 HEAP32[$101>>2] = $100;
 $102 = (($this) + 48|0);
 HEAP8[$102>>0] = 0;
 $103 = (Math_fround(($89>>>0)));
 $104 = Math_fround($103 * Math_fround(0.5));
 $105 = (~~(($104))>>>0);
 $106 = (($tmp) + 44|0);
 HEAP32[$106>>2] = $105;
 $107 = Math_fround($103 * Math_fround(0.20000000298023223877));
 $108 = (~~(($107))>>>0);
 $109 = (($tmp) + 40|0);
 HEAP32[$109>>2] = $108;
 $110 = (($tmp) + 48|0);
 HEAP8[$110>>0] = 0;
 $111 = ($85|0)==(0|0);
 if ($111) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($85,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN22VertexDeclarationCache13GetVertexDeclERK18VertexChannelsInfo($this,$key) {
 $this = $this|0;
 $key = $key|0;
 var $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i10 = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy1 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__parent$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $0 = sp;
 $__parent$i$i = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = (($this) + 4|0);
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 8|0);
 $7 = ($5|0)==(0|0);
 if ($7) {
  $$0$ph5$i$i$i10 = $6;
 } else {
  $$0$ph7$i$i$i = $6;$$01$ph6$i$in$i$i = $5;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $8 = (($$013$i$in$i$i) + 16|0);
    $9 = (__ZNK18VertexChannelsInfoltERKS_($8,$key)|0);
    if (!($9)) {
     break;
    }
    $12 = (($$013$i$in$i$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $13;
    }
   }
   $10 = HEAP32[$$013$i$in$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $10;
   }
  }
  $15 = ($$0$ph5$i$i$i|0)==($6|0);
  if ($15) {
   $$0$ph5$i$i$i10 = $6;
  } else {
   $16 = (($$0$ph5$i$i$i) + 16|0);
   $17 = (__ZNK18VertexChannelsInfoltERKS_($key,$16)|0);
   if ($17) {
    $$0$ph5$i$i$i10 = $$0$ph5$i$i$i;
   } else {
    $39 = (($$0$ph5$i$i$i) + 48|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = $40;
    STACKTOP = sp;return ($41|0);
   }
  }
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_iii[$20 & 4095]($this,$key)|0);
 ;HEAP32[$2+0>>2]=HEAP32[$key+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$key+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$key+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$key+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$key+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$key+20>>2]|0;HEAP32[$2+24>>2]=HEAP32[$key+24>>2]|0;HEAP32[$2+28>>2]=HEAP32[$key+28>>2]|0;
 $22 = (($2) + 32|0);
 HEAP32[$22>>2] = $21;
 HEAP32[$1>>2] = $$0$ph5$i$i$i10;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $23 = (__ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SG_EEiEESJ_RKT_($3,$$byval_copy1,$__parent$i$i,$2)|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $41 = $21;
  STACKTOP = sp;return ($41|0);
 }
 HEAP32[$0>>2] = 8;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $26 = (__Z15malloc_internaljj10MemLabelIdiPKci(52,16,$$byval_copy1,0,599704,79)|0);
 $27 = (($26) + 16|0);
 dest=$27+0|0; src=$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $28 = HEAP32[$__parent$i$i>>2]|0;
 HEAP32[$26>>2] = 0;
 $29 = (($26) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($26) + 8|0);
 HEAP32[$30>>2] = $28;
 HEAP32[$23>>2] = $26;
 $31 = HEAP32[$3>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $35 = $26;
 } else {
  HEAP32[$3>>2] = $32;
  $$pre$i$i$i = HEAP32[$23>>2]|0;
  $35 = $$pre$i$i$i;
 }
 $34 = HEAP32[$4>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($34,$35);
 $36 = (($this) + 12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $41 = $21;
 STACKTOP = sp;return ($41|0);
}
function __ZN22VertexDeclarationCache5ClearEv($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = ($1|0)==($2|0);
 if (!($3)) {
  $8 = $1;
  while(1) {
   $4 = HEAP32[$this>>2]|0;
   $5 = (($4) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($8) + 48|0);
   $9 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vii[$6 & 4095]($this,$9);
   $10 = (($8) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$01$i$i$i = $8;
    while(1) {
     $15 = (($$01$i$i$i) + 8|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==($$01$i$i$i|0);
     if ($18) {
      $$0$i$i$i = $16;
      break;
     } else {
      $$01$i$i$i = $16;
     }
    }
   } else {
    $$0$i$i$i$i = $11;
    while(1) {
     $13 = HEAP32[$$0$i$i$i$i>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      $$0$i$i$i = $$0$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i = $13;
     }
    }
   }
   $19 = ($$0$i$i$i|0)==($2|0);
   if ($19) {
    break;
   } else {
    $8 = $$0$i$i$i;
   }
  }
 }
 $20 = (($this) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$21);
 $22 = (($this) + 12|0);
 HEAP32[$22>>2] = 0;
 HEAP32[$0>>2] = $2;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$4);
 HEAP32[$0>>2] = 8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  ___cxa_call_unexpected(($7|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SG_EEiEESJ_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = (($1) + 16|0);
  $4 = (__ZNK18VertexChannelsInfoltERKS_($__v,$3)|0);
  if (!($4)) {
   $33 = (__ZNK18VertexChannelsInfoltERKS_($3,$__v)|0);
   if (!($33)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $34 = (($1) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $39 = (($$01$i$i$i$i$i) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==($$01$i$i$i$i$i|0);
     if ($42) {
      $$0$i$i$i$i$i = $40;
      break;
     } else {
      $$01$i$i$i$i$i = $40;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $35;
    while(1) {
     $37 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $37;
     }
    }
   }
   $43 = ($$0$i$i$i$i$i|0)==($0|0);
   do {
    if ($43) {
     $47 = $35;
    } else {
     $44 = (($$0$i$i$i$i$i) + 16|0);
     $45 = (__ZNK18VertexChannelsInfoltERKS_($__v,$44)|0);
     if ($45) {
      $$pre = HEAP32[$34>>2]|0;
      $47 = $$pre;
      break;
     }
     $48 = (($this) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0|0);
     if ($50) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $49;
     }
     while(1) {
      $51 = (($__nd$0$in$i) + 16|0);
      $52 = (__ZNK18VertexChannelsInfoltERKS_($__v,$51)|0);
      if ($52) {
       $53 = HEAP32[$__nd$0$in$i>>2]|0;
       $54 = ($53|0)==(0|0);
       if ($54) {
        label = 35;
        break;
       } else {
        $__nd$0$in$i = $53;
        continue;
       }
      }
      $55 = (__ZNK18VertexChannelsInfoltERKS_($51,$__v)|0);
      if (!($55)) {
       label = 39;
       break;
      }
      $56 = (($__nd$0$in$i) + 4|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0|0);
      if ($58) {
       label = 38;
       break;
      } else {
       $__nd$0$in$i = $57;
      }
     }
     if ((label|0) == 35) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $56;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 39) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $46 = ($47|0)==(0|0);
   if ($46) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $34;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = ($1|0)==($5|0);
 if ($6) {
  $20 = $1;
 } else {
  $7 = HEAP32[$1>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$01$i$i = $1;
   while(1) {
    $12 = (($$01$i$i) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($$01$i$i|0);
    if ($15) {
     $$01$i$i = $13;
    } else {
     $$0$i$i = $13;
     break;
    }
   }
  } else {
   $$0$i$i$i = $7;
   while(1) {
    $9 = (($$0$i$i$i) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $10;
    }
   }
  }
  $16 = (($$0$i$i) + 16|0);
  $17 = (__ZNK18VertexChannelsInfoltERKS_($16,$__v)|0);
  if ($17) {
   $20 = $$0$i$i;
  } else {
   $22 = (($this) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i7 = $23;
   }
   while(1) {
    $25 = (($__nd$0$in$i7) + 16|0);
    $26 = (__ZNK18VertexChannelsInfoltERKS_($__v,$25)|0);
    if ($26) {
     $27 = HEAP32[$__nd$0$in$i7>>2]|0;
     $28 = ($27|0)==(0|0);
     if ($28) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i7 = $27;
      continue;
     }
    }
    $29 = (__ZNK18VertexChannelsInfoltERKS_($25,$__v)|0);
    if (!($29)) {
     label = 19;
     break;
    }
    $30 = (($__nd$0$in$i7) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i7 = $31;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i7;
    $$0 = $__nd$0$in$i7;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i7;
    $$0 = $30;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i7;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $18 = HEAP32[$1>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $20;
  $21 = (($20) + 4|0);
  $$0 = $21;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL16StaticInitializev4150() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628240>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,599720,19)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[599712>>2] = $2;
 STACKTOP = sp;return;
}
function __ZL13StaticDestroyv4151() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[599712>>2]|0;
 $2 = HEAP32[628240>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPvEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_S8_EE($1,$5);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[599712>>2] = 0;
 STACKTOP = sp;return;
}
function __Z22mono_add_internal_callPKcPKv($name,$method) {
 $name = $name|0;
 $method = $method|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _il2cpp_add_internal_call($name,$method);
 STACKTOP = sp;return;
}
function __Z21GetScriptingArraySizeP14ScriptingArray($a) {
 $a = $a|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($a|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_il2cpp_array_length($a)|0);
  $$0 = $1;
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z24GetBuiltinScriptingClassPKcb($name,$optional) {
 $name = $name|0;
 $optional = $optional|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14GetMonoManagerv()|0);
 $1 = (__ZN11MonoManager19GetBuiltinMonoClassEPKcb($0,$name,$optional)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z20il2cpp_invoke_method21ScriptingMethodIl2CppP15ScriptingObjectP18ScriptingArgumentsPP18ScriptingExceptionb($method,$object,$arguments,$exception,$convertArgs) {
 $method = $method|0;
 $object = $object|0;
 $arguments = $arguments|0;
 $exception = $exception|0;
 $convertArgs = $convertArgs|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN18ScriptingArguments8GetCountEv($arguments)|0);
 $1 = HEAP32[$method>>2]|0;
 (_il2cpp_method_get_param_count($1)|0);
 $2 = (($arguments) + 80|0);
 if ($convertArgs) {
  $4 = (_il2cpp_runtime_invoke_convert_args($1,$object,$2,$0,$exception)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (_il2cpp_runtime_invoke($1,$object,$2,$exception)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _InitializeScriptingBackend() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __Z24RegisterAllInternalCallsv();
 _il2cpp_init(599728);
 _il2cpp_runtime_unhandled_exception_policy_set(0);
 $0 = (__Z7GetArgcv()|0);
 $1 = (__Z7GetArgvv()|0);
 _il2cpp_set_commandline_arguments($0,$1,0);
 STACKTOP = sp;return;
}
function __ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($object) {
 $object = $object|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($object|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (($object) + 12|0);
  $2 = HEAP32[$1>>2]|0;
  $$0 = $2;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Scripting30SetCachedPtrOnScriptingWrapperEP15ScriptingObjectPv($object,$cachedPtr) {
 $object = $object|0;
 $cachedPtr = $cachedPtr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($object) + 12|0);
 HEAP32[$0>>2] = $cachedPtr;
 STACKTOP = sp;return;
}
function __ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($object) {
 $object = $object|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($object|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (($object) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $$0 = $2;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Scripting31SetInstanceIDOnScriptingWrapperEP15ScriptingObjecti($object,$instanceID) {
 $object = $object|0;
 $instanceID = $instanceID|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($object) + 8|0);
 HEAP32[$0>>2] = $instanceID;
 STACKTOP = sp;return;
}
function __ZN9Scripting37InstantiateScriptingWrapperForClassIDEi($classID) {
 $classID = $classID|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $classID$tr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $classID$tr = $classID;
 while(1) {
  $0 = (__ZN6Object15ClassIDToStringEi($classID$tr)|0);
  $1 = HEAP8[$0>>0]|0;
  $2 = $1 & 1;
  $3 = ($2<<24>>24)==(0);
  if ($3) {
   $6 = (($0) + 1|0);
   $7 = $6;
  } else {
   $4 = (($0) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $7 = $5;
  }
  $8 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,$7)|0);
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   break;
  }
  $11 = (__ZN6Object15GetSuperClassIDEi($classID$tr)|0);
  $12 = ($11|0)==(0);
  if ($12) {
   $$0 = 0;
   label = 8;
   break;
  } else {
   $classID$tr = $11;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (__Z20scripting_object_newP14ScriptingClass($8)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Scripting24RaiseDotNetExceptionImplEPKcS1_S1_Pi($ns,$type,$format,$list) {
 $ns = $ns|0;
 $type = $type|0;
 $format = $format|0;
 $list = $list|0;
 var $0 = 0, $1 = 0, $ap = 0, $buffer = 0, $vacopy_currentptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5136|0;
 $ap = sp;
 $buffer = sp + 16|0;
 $vacopy_currentptr = HEAP32[$list>>2]|0;
 HEAP32[$ap>>2] = $vacopy_currentptr;
 (_vsnprintf($buffer,5120,$format,$ap)|0);
 $0 = (_il2cpp_get_corlib()|0);
 $1 = (_il2cpp_exception_from_name_msg($0,$ns,$type,$buffer)|0);
 _il2cpp_raise_exception($1);
 // unreachable;
}
function __ZN9Scripting24RaiseSystemExceptionImplEPKcS1_Pi($type,$format,$list) {
 $type = $type|0;
 $format = $format|0;
 $list = $list|0;
 var $ap = 0, $vacopy_currentptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ap = sp;
 $vacopy_currentptr = HEAP32[$list>>2]|0;
 HEAP32[$ap>>2] = $vacopy_currentptr;
 __ZN9Scripting24RaiseDotNetExceptionImplEPKcS1_S1_Pi(599752,$type,$format,$ap);
 // unreachable;
}
function __ZN9Scripting18RaiseMonoExceptionEPKcz($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $2 = 0, $buffer = 0, $va = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 5136|0;
 $va = sp;
 $buffer = sp + 16|0;
 HEAP32[$va>>2] = $varargs;
 (_vsnprintf($buffer,5120,$format,$va)|0);
 $0 = (__Z14GetMonoManagerv()|0);
 $1 = (__ZN11MonoManager25GetImageFromAssemblyIndexEi($0,0)|0);
 $2 = (_il2cpp_exception_from_name_msg($1,637608,599760,$buffer)|0);
 _il2cpp_raise_exception($2);
 // unreachable;
}
function __ZN9Scripting18RaiseNullExceptionEPKcz($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $va = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $va = sp;
 HEAP32[$va>>2] = $varargs;
 __ZN9Scripting24RaiseSystemExceptionImplEPKcS1_Pi(599776,$format,$va);
 // unreachable;
}
function __ZN9Scripting22RaiseArgumentExceptionEPKcz($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $va = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $va = sp;
 HEAP32[$va>>2] = $varargs;
 __ZN9Scripting24RaiseSystemExceptionImplEPKcS1_Pi(599800,$format,$va);
 // unreachable;
}
function __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($object) {
 $object = $object|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_get_corlib()|0);
 $1 = (_il2cpp_exception_from_name_msg($0,599752,599776,599824)|0);
 _il2cpp_raise_exception($1);
 // unreachable;
}
function __ZN9Scripting11RaiseIfNullEP15ScriptingObject($object) {
 $object = $object|0;
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($object|0)==(0|0);
 if ($0) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(599832,$vararg_buffer);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN9Scripting11RaiseIfNullEPv($object) {
 $object = $object|0;
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($object|0)==(0|0);
 if ($0) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(599832,$vararg_buffer);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($a,$i,$value) {
 $a = $a|0;
 $i = $i|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($a,$i,4)|0);
 HEAP32[$0>>2] = $value;
 STACKTOP = sp;return;
}
function __ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi($a,$i) {
 $a = $a|0;
 $i = $i|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($a,$i,4)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN9Scripting39GetScriptingArrayObjectElementNoRefImplEP14ScriptingArrayi($a,$i) {
 $a = $a|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($a,$i,4)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9Scripting30IsSystemCollectionsGenericListEP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24scripting_class_get_nameP14ScriptingClass($klass)|0);
 $1 = (_strcmp($0,599840)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__Z25scripting_class_get_imageP14ScriptingClass($klass)|0);
 $4 = (__Z20scripting_get_corlibv()|0);
 $5 = ($3|0)==($4|0);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($agg$result,$field) {
 $agg$result = $agg$result|0;
 $field = $field|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__Z24scripting_field_get_typeP14ScriptingField($field)|0);
 $1 = (__Z25scripting_class_from_typeP13ScriptingType($0)|0);
 $2 = (__Z26scripting_field_get_parentP14ScriptingField($field)|0);
 $3 = (__Z24scripting_class_get_nameP14ScriptingClass($2)|0);
 $4 = (__Z24scripting_class_get_typeP14ScriptingClass($1)|0);
 $5 = (__Z23scripting_type_get_nameP13ScriptingType($4)|0);
 $6 = (__Z24scripting_field_get_nameP14ScriptingField($field)|0);
 HEAP32[$vararg_buffer>>2] = $5;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $6;
 $vararg_ptr2 = (($vararg_buffer) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $3;
 __Z6FormatPKcz($agg$result,599848,$vararg_buffer);
 _free($5);
 STACKTOP = sp;return;
}
function __ZN9Scripting27BackingArrayFieldForListOfTEP14ScriptingClass($ListOfTClass) {
 $ListOfTClass = $ListOfTClass|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i1 = 0, $fields = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $fields = sp + 4|0;
 $1 = (__Z24scripting_class_get_nameP14ScriptingClass($ListOfTClass)|0);
 $2 = (_strcmp($1,599840)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (__Z25scripting_class_get_imageP14ScriptingClass($ListOfTClass)|0);
 $5 = (__Z20scripting_get_corlibv()|0);
 $6 = ($4|0)==($5|0);
 if (!($6)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$fields>>2] = 0;
 $7 = (($fields) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($fields) + 8|0);
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2702,($ListOfTClass|0),($fields|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if (!($10)) {
   $11 = HEAP32[$7>>2]|0;
   $12 = HEAP32[$fields>>2]|0;
   $13 = $11;
   $14 = $12;
   $15 = (($13) - ($14))|0;
   $16 = $15 >> 2;
   $17 = ($16>>>0)>(1);
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3477,0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    // unreachable;
   }
   $20 = (($12) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($12|0)==(0|0);
   if ($22) {
    $$0 = $21;
    STACKTOP = sp;return ($$0|0);
   }
   $23 = ($11|0)==($12|0);
   if (!($23)) {
    $scevgep$i$i$i$i$i = (($11) + -4|0);
    $24 = (0 - ($14))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($24)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $25 = $uglygep3$i$i$i$i$i >>> 2;
    $26 = $25 ^ -1;
    $scevgep4$i$i$i$i$i = (($11) + ($26<<2)|0);
    HEAP32[$7>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($12|0),($$byval_copy1|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $29 = ___cxa_find_matching_catch()|0;
    $30 = tempRet0;
    ___cxa_call_unexpected(($29|0));
    // unreachable;
   } else {
    $$0 = $21;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $33 = HEAP32[$fields>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  ___resumeException($31|0);
  // unreachable;
 }
 $35 = HEAP32[$7>>2]|0;
 $36 = ($35|0)==($33|0);
 if (!($36)) {
  $__new_last2$i$i$i$i$i1 = $33;
  $scevgep$i$i$i$i$i2 = (($35) + -4|0);
  $37 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($37)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $38 = $uglygep3$i$i$i$i$i5 >>> 2;
  $39 = $38 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($35) + ($39<<2)|0);
  HEAP32[$7>>2] = $scevgep4$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy1|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  ___cxa_call_unexpected(($42|0));
  // unreachable;
 } else {
  ___resumeException($31|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($tthis) {
 $tthis = $tthis|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exc = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $exc = sp + 12|0;
 $0 = sp;
 $1 = ($tthis|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 HEAP32[$exc>>2] = 0;
 _il2cpp_runtime_object_init_exception($tthis,$exc);
 $2 = HEAP32[$exc>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1731,($2|0),0,($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $13 = HEAP8[$0>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   ___resumeException($11|0);
   // unreachable;
  }
  $16 = (($0) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  __ZdlPv($17);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $6 = HEAP8[$0>>0]|0;
  $7 = $6 & 1;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   STACKTOP = sp;return;
  }
  $9 = (($0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
  STACKTOP = sp;return;
 }
}
function __ZN9Scripting18IsFieldFlagsPublicEi($fieldFlags) {
 $fieldFlags = $fieldFlags|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $fieldFlags & 15;
 $1 = ($0|0)==(6);
 STACKTOP = sp;return ($1|0);
}
function __Z24scripting_cpp_string_forP15ScriptingString($agg$result,$str) {
 $agg$result = $agg$result|0;
 $str = $str|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $buffer = 0, $outLength = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buffer = sp + 4|0;
 $outLength = sp;
 $0 = ($str|0)==(0|0);
 if ($0) {
  ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
  STACKTOP = sp;return;
 }
 $1 = (_il2cpp_string_length($str)|0);
 $2 = (_il2cpp_string_chars($str)|0);
 ;HEAP32[$buffer+0>>2]=0|0;HEAP32[$buffer+4>>2]=0|0;HEAP32[$buffer+8>>2]=0|0;
 $3 = $1 << 2;
 $4 = ($3|0)==(0);
 if ($4) {
  $7 = ((($buffer) + ($3)|0) + 1|0);
  HEAP8[$7>>0] = 0;
  $8 = $1 << 3;
  $9 = $8&255;
  HEAP8[$buffer>>0] = $9;
  label = 6;
 } else {
  __THREW__ = 0;
  (invoke_iiii(1479,($buffer|0),($3|0),0)|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   label = 6;
  }
 }
 L8: do {
  if ((label|0) == 6) {
   HEAP32[$outLength>>2] = 0;
   $10 = HEAP8[$buffer>>0]|0;
   $11 = $10 & 1;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    $15 = (($buffer) + 1|0);
    $16 = $15;
   } else {
    $13 = (($buffer) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $16 = $14;
   }
   __THREW__ = 0;
   (invoke_iiiii(237,($2|0),($1|0),($16|0),($outLength|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[$outLength>>2]|0;
    $20 = HEAP8[$buffer>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $25 = $20&255;
     $26 = $25 >>> 1;
     $28 = $26;
    } else {
     $23 = (($buffer) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $28 = $24;
    }
    $27 = ($28>>>0)<($19>>>0);
    do {
     if ($27) {
      $29 = (($19) - ($28))|0;
      __THREW__ = 0;
      (invoke_iiii(1479,($buffer|0),($29|0),0)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break L8;
      }
     } else {
      if ($22) {
       $36 = ((($buffer) + ($19)|0) + 1|0);
       HEAP8[$36>>0] = 0;
       $37 = $19 << 1;
       $38 = $37&255;
       HEAP8[$buffer>>0] = $38;
       break;
      } else {
       $32 = (($buffer) + 8|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = (($33) + ($19)|0);
       HEAP8[$34>>0] = 0;
       $35 = (($buffer) + 4|0);
       HEAP32[$35>>2] = $19;
       break;
      }
     }
    } while(0);
    $39 = HEAP8[$buffer>>0]|0;
    $40 = $39 & 1;
    $41 = ($40<<24>>24)==(0);
    if ($41) {
     ;HEAP32[$agg$result+0>>2]=HEAP32[$buffer+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$buffer+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$buffer+8>>2]|0;
     STACKTOP = sp;return;
    }
    $42 = (($buffer) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($buffer) + 4|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45>>>0)>(4294967279);
    if ($46) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     // unreachable;
    }
    $49 = ($45>>>0)<(11);
    if ($49) {
     $50 = $45 << 1;
     $51 = $50&255;
     HEAP8[$agg$result>>0] = $51;
     $52 = (($agg$result) + 1|0);
     $__p$0$i$i$i = $52;
    } else {
     $53 = (($45) + 16)|0;
     $54 = $53 & -16;
     __THREW__ = 0;
     $55 = (invoke_ii(2988,($54|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     $58 = (($agg$result) + 8|0);
     HEAP32[$58>>2] = $55;
     $59 = $54 | 1;
     HEAP32[$agg$result>>2] = $59;
     $60 = (($agg$result) + 4|0);
     HEAP32[$60>>2] = $45;
     $__p$0$i$i$i = $55;
    }
    _memcpy(($__p$0$i$i$i|0),($43|0),($45|0))|0;
    $61 = (($__p$0$i$i$i) + ($45)|0);
    HEAP8[$61>>0] = 0;
    if ($41) {
     STACKTOP = sp;return;
    }
    $62 = (($buffer) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    __ZdlPv($63);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $64 = ___cxa_find_matching_catch()|0;
 $65 = tempRet0;
 $66 = HEAP8[$buffer>>0]|0;
 $67 = $66 & 1;
 $68 = ($67<<24>>24)==(0);
 if ($68) {
  ___resumeException($64|0);
  // unreachable;
 }
 $69 = (($buffer) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 __ZdlPv($70);
 ___resumeException($64|0);
 // unreachable;
}
function __Z28scripting_method_is_instance21ScriptingMethodIl2Cpp($method) {
 $method = $method|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 $1 = (_il2cpp_method_is_instance($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z35scripting_method_get_argument_count21ScriptingMethodIl2Cpp($method) {
 $method = $method|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 $1 = (_il2cpp_method_get_param_count($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z37scripting_method_get_nth_argumenttype21ScriptingMethodIl2Cppi($method,$index) {
 $method = $method|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 $1 = (_il2cpp_method_get_param($0,$index)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z25scripting_method_get_name21ScriptingMethodIl2Cpp($method) {
 $method = $method|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 $1 = (_il2cpp_method_get_name($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z30scripting_method_has_attribute21ScriptingMethodIl2CppP14ScriptingClass($method,$attribute) {
 $method = $method|0;
 $attribute = $attribute|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 $1 = (_il2cpp_method_has_attribute($0,$attribute)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z25scripting_class_from_nameP14ScriptingImagePKcS2_($image,$ns,$name) {
 $image = $image|0;
 $ns = $ns|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_from_name($image,$ns,$name)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z28scripting_class_is_valuetypeP14ScriptingClass($c) {
 $c = $c|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_is_valuetype($c)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z29scripting_class_instance_sizeP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_instance_size($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z26scripting_class_get_objectP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($klass|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_il2cpp_class_get_type($klass)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (_il2cpp_type_get_object($1)|0);
   $$0 = $3;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z24scripting_class_get_typeP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_get_type($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z30scripting_cast_object_to_arrayP15ScriptingObject($o) {
 $o = $o|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($o|0);
}
function __Z26scripting_class_get_parentP14ScriptingClass($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_get_parent($type)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z23scripting_class_is_enumP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_is_enum($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z24scripting_class_get_nameP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_get_name($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z29scripting_class_get_namespaceP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_get_namespace($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($t1,$t2) {
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_is_subclass_of($t1,$t2,1)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z27scripting_class_get_methodsP14ScriptingClassRNSt3__16vectorI21ScriptingMethodIl2Cpp13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEE($t,$result) {
 $t = $t|0;
 $result = $result|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $iterator = 0, $scriptingMethod = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iterator = sp + 8|0;
 $scriptingMethod = sp;
 HEAP32[$iterator>>2] = 0;
 HEAP32[$scriptingMethod>>2] = 0;
 $0 = (_il2cpp_class_get_methods($t,$iterator)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($result) + 4|0);
 $3 = (($result) + 8|0);
 $4 = $0;
 while(1) {
  HEAP32[$scriptingMethod>>2] = $4;
  $5 = HEAP32[$2>>2]|0;
  $6 = HEAP32[$3>>2]|0;
  $7 = ($5|0)==($6|0);
  if ($7) {
   __ZNSt3__16vectorI21ScriptingMethodIl2Cpp13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($result,$scriptingMethod);
  } else {
   $8 = ($5|0)==(0|0);
   if ($8) {
    $20 = 0;
   } else {
    $9 = $scriptingMethod;
    $10 = $9;
    $11 = HEAP32[$10>>2]|0;
    $12 = (($9) + 4)|0;
    $13 = $12;
    $14 = HEAP32[$13>>2]|0;
    $15 = $5;
    $16 = $15;
    HEAP32[$16>>2] = $11;
    $17 = (($15) + 4)|0;
    $18 = $17;
    HEAP32[$18>>2] = $14;
    $$pre$i = HEAP32[$2>>2]|0;
    $20 = $$pre$i;
   }
   $19 = (($20) + 8|0);
   HEAP32[$2>>2] = $19;
  }
  $21 = (_il2cpp_class_get_methods($t,$iterator)|0);
  $22 = ($21|0)==(0|0);
  if ($22) {
   break;
  } else {
   $4 = $21;
  }
 }
 STACKTOP = sp;return;
}
function __Z36scripting_class_get_method_from_nameP14ScriptingClassPKci($agg$result,$klass,$name,$argsCount) {
 $agg$result = $agg$result|0;
 $klass = $klass|0;
 $name = $name|0;
 $argsCount = $argsCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z43scripting_class_get_method_from_name_filterP14ScriptingClassPKcii($agg$result,$klass,$name,$argsCount,0);
 STACKTOP = sp;return;
}
function __Z43scripting_class_get_method_from_name_filterP14ScriptingClassPKcii($agg$result,$klass,$name,$argsCount,$searchFilter) {
 $agg$result = $agg$result|0;
 $klass = $klass|0;
 $name = $name|0;
 $argsCount = $argsCount|0;
 $searchFilter = $searchFilter|0;
 var $$lcssa1 = 0, $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $iterator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iterator = sp;
 HEAP32[$iterator>>2] = 0;
 $0 = (_il2cpp_class_get_methods($klass,$iterator)|0);
 $1 = ($0|0)==(0|0);
 L1: do {
  if (!($1)) {
   $2 = ($argsCount|0)==(-1);
   $3 = ($searchFilter|0)==(0);
   L3: do {
    if ($2) {
     if ($3) {
      $4 = $0;
      while(1) {
       $5 = (_il2cpp_method_get_name($4)|0);
       $6 = (_strcmp($5,$name)|0);
       $7 = ($6|0)==(0);
       if ($7) {
        $$lcssa1 = $4;
        label = 15;
        break L3;
       }
       $8 = (_il2cpp_class_get_methods($klass,$iterator)|0);
       $9 = ($8|0)==(0|0);
       if ($9) {
        break L1;
       } else {
        $4 = $8;
       }
      }
     } else {
      $10 = $0;
     }
     while(1) {
      $11 = (_il2cpp_method_get_name($10)|0);
      $12 = (_strcmp($11,$name)|0);
      $13 = ($12|0)==(0);
      if ($13) {
       $14 = (_il2cpp_method_is_instance($10)|0);
       $15 = (_il2cpp_method_get_param_count($10)|0);
       $16 = (__ZN24ScriptingMethodFiltering36MethodDescriptionMatchesSearchFilterEibi($searchFilter,$14,$15)|0);
       if ($16) {
        $$lcssa2 = $10;
        label = 18;
        break L3;
       }
      }
      $17 = (_il2cpp_class_get_methods($klass,$iterator)|0);
      $18 = ($17|0)==(0|0);
      if ($18) {
       break L1;
      } else {
       $10 = $17;
      }
     }
    } else {
     if ($3) {
      $19 = $0;
      while(1) {
       $20 = (_il2cpp_method_get_name($19)|0);
       $21 = (_strcmp($20,$name)|0);
       $22 = ($21|0)==(0);
       if ($22) {
        $23 = (_il2cpp_method_get_param_count($19)|0);
        $24 = ($23|0)==($argsCount|0);
        if ($24) {
         $$lcssa1 = $19;
         label = 15;
         break L3;
        }
       }
       $25 = (_il2cpp_class_get_methods($klass,$iterator)|0);
       $26 = ($25|0)==(0|0);
       if ($26) {
        break L1;
       } else {
        $19 = $25;
       }
      }
     } else {
      $27 = $0;
     }
     while(1) {
      $28 = (_il2cpp_method_get_name($27)|0);
      $29 = (_strcmp($28,$name)|0);
      $30 = ($29|0)==(0);
      if ($30) {
       $31 = (_il2cpp_method_get_param_count($27)|0);
       $32 = ($31|0)==($argsCount|0);
       if ($32) {
        $33 = (_il2cpp_method_is_instance($27)|0);
        $34 = (_il2cpp_method_get_param_count($27)|0);
        $35 = (__ZN24ScriptingMethodFiltering36MethodDescriptionMatchesSearchFilterEibi($searchFilter,$33,$34)|0);
        if ($35) {
         $$lcssa2 = $27;
         label = 18;
         break L3;
        }
       }
      }
      $36 = (_il2cpp_class_get_methods($klass,$iterator)|0);
      $37 = ($36|0)==(0|0);
      if ($37) {
       break L1;
      } else {
       $27 = $36;
      }
     }
    }
   } while(0);
   if ((label|0) == 15) {
    HEAP32[$agg$result>>2] = $$lcssa1;
    STACKTOP = sp;return;
   }
   else if ((label|0) == 18) {
    HEAP32[$agg$result>>2] = $$lcssa2;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $38 = $agg$result;
 $39 = $38;
 HEAP32[$39>>2] = 0;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = 0;
 STACKTOP = sp;return;
}
function __Z31scripting_method_get_returntype21ScriptingMethodIl2Cpp($method) {
 $method = $method|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 $1 = (_il2cpp_method_get_return_type($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z23scripting_method_invoke21ScriptingMethodIl2CppP15ScriptingObjectR18ScriptingArgumentsPP18ScriptingException($method,$object,$arguments,$exception) {
 $method = $method|0;
 $object = $object|0;
 $arguments = $arguments|0;
 $exception = $exception|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 (_il2cpp_method_get_param_count($0)|0);
 $1 = (($arguments) + 80|0);
 $2 = (_il2cpp_runtime_invoke($0,$object,$1,$exception)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z39scripting_class_from_systemtypeinstanceP15ScriptingObject($systemTypeInstance) {
 $systemTypeInstance = $systemTypeInstance|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($systemTypeInstance|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_il2cpp_class_from_system_type($systemTypeInstance)|0);
  $$0 = $1;
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z20scripting_object_newP14ScriptingClass($t) {
 $t = $t|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_object_new($t)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z43scripting_object_invoke_default_constructorP15ScriptingObjectPP18ScriptingException($o,$exc) {
 $o = $o|0;
 $exc = $exc|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _il2cpp_runtime_object_init_exception($o,$exc);
 STACKTOP = sp;return;
}
function __Z26scripting_object_get_classP15ScriptingObject($o) {
 $o = $o|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_object_get_class($o)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($agg$result,$o,$method) {
 $agg$result = $agg$result|0;
 $o = $o|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$method>>2]|0;
 $1 = (_il2cpp_object_get_virtual_method($o,$0)|0);
 HEAP32[$agg$result>>2] = $1;
 STACKTOP = sp;return;
}
function __Z22scripting_gchandle_newP15ScriptingObject($o) {
 $o = $o|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_gchandle_new($o,1)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z23scripting_gchandle_freei($handle) {
 $handle = $handle|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _il2cpp_gchandle_free($handle);
 STACKTOP = sp;return;
}
function __Z29scripting_gchandle_get_targeti($handle) {
 $handle = $handle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_gchandle_get_target($handle)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z20scripting_string_newRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($str) {
 $str = $str|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$str>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($str) + 1|0);
  $6 = $5;
 } else {
  $3 = (($str) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 $7 = (_il2cpp_string_new_wrapper($6)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z20scripting_string_newPKc($str) {
 $str = $str|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_string_new_wrapper($str)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z21PostprocessStacktracePKcRNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($stackTrace,$processedStackTrace) {
 $stackTrace = $stackTrace|0;
 $processedStackTrace = $processedStackTrace|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $arg = 0;
 var $args = 0, $exception = 0, $exception1 = 0, $projectFolder = 0, $stripEngineInternalInformation = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer = sp;
 $exception = sp + 52|0;
 $projectFolder = sp + 40|0;
 $args = sp + 36|0;
 $0 = sp + 56|0;
 $exception1 = sp + 8|0;
 $stripEngineInternalInformation = sp + 4|0;
 $arg = sp + 16|0;
 $1 = sp + 24|0;
 $2 = HEAP8[599928>>0]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   HEAP8[599928>>0] = 1;
   $4 = (__Z19GetScriptingManagerv()|0);
   $5 = (($4) + 520|0);
   $6 = $5;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = ($8|0)==(0);
   if (!($12)) {
    $13 = (__Znwj(32)|0);
    $14 = (($projectFolder) + 8|0);
    HEAP32[$14>>2] = $13;
    HEAP32[$projectFolder>>2] = 33;
    $15 = (($projectFolder) + 4|0);
    HEAP32[$15>>2] = 21;
    dest=$13+0|0; src=599936+0|0; stop=dest+21|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $16 = (($13) + 21|0);
    HEAP8[$16>>0] = 0;
    __THREW__ = 0;
    $17 = (invoke_ii(3240,($13|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    L4: do {
     if ($19) {
      label = 9;
     } else {
      HEAP32[$args>>2] = $17;
      $20 = $8;
      __THREW__ = 0;
      (invoke_iiiii(238,($20|0),(0|0),($args|0),($exception|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 9;
      } else {
       $23 = HEAP32[$exception>>2]|0;
       $24 = ($23|0)==(0|0);
       do {
        if (!($24)) {
         ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
         __THREW__ = 0;
         invoke_viii(1731,($23|0),0,($0|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if ($26) {
          $34 = ___cxa_find_matching_catch()|0;
          $35 = tempRet0;
          $36 = HEAP8[$0>>0]|0;
          $37 = $36 & 1;
          $38 = ($37<<24>>24)==(0);
          if ($38) {
           $$0 = $34;$$01 = $35;
           break L4;
          }
          $39 = (($0) + 8|0);
          $40 = HEAP32[$39>>2]|0;
          __ZdlPv($40);
          $$0 = $34;$$01 = $35;
          break L4;
         } else {
          $27 = HEAP8[$0>>0]|0;
          $28 = $27 & 1;
          $29 = ($28<<24>>24)==(0);
          if ($29) {
           break;
          }
          $30 = (($0) + 8|0);
          $31 = HEAP32[$30>>2]|0;
          __ZdlPv($31);
          break;
         }
        }
       } while(0);
       $41 = HEAP8[$projectFolder>>0]|0;
       $42 = $41 & 1;
       $43 = ($42<<24>>24)==(0);
       if ($43) {
        break L1;
       }
       $44 = HEAP32[$14>>2]|0;
       __ZdlPv($44);
       break L1;
      }
     }
    } while(0);
    if ((label|0) == 9) {
     $32 = ___cxa_find_matching_catch()|0;
     $33 = tempRet0;
     $$0 = $32;$$01 = $33;
    }
    $45 = HEAP8[$projectFolder>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $$1 = $$0;$$12 = $$01;
     ___resumeException($$1|0);
     // unreachable;
    }
    $48 = HEAP32[$14>>2]|0;
    __ZdlPv($48);
    $$1 = $$0;$$12 = $$01;
    ___resumeException($$1|0);
    // unreachable;
   }
  }
 } while(0);
 $49 = (__Z19GetScriptingManagerv()|0);
 $50 = (($49) + 368|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 HEAP32[$exception1>>2] = 0;
 HEAP32[$stripEngineInternalInformation>>2] = 1;
 $53 = (_il2cpp_string_new_wrapper($stackTrace)|0);
 HEAP32[$arg>>2] = $53;
 $54 = (($arg) + 4|0);
 HEAP32[$54>>2] = $stripEngineInternalInformation;
 $55 = (__Z19GetScriptingManagerv()|0);
 $56 = (($55) + 368|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (_il2cpp_runtime_invoke($57,0,$arg,$exception1)|0);
 $59 = HEAP32[$exception1>>2]|0;
 $60 = ($59|0)==(0|0);
 if (!($60)) {
  _printf_console(599960,$vararg_buffer);
  STACKTOP = sp;return;
 }
 __Z24scripting_cpp_string_forP15ScriptingString($1,$58);
 __THREW__ = 0;
 (invoke_iii(2233,($processedStackTrace|0),($1|0))|0);
 $61 = __THREW__; __THREW__ = 0;
 $62 = $61&1;
 if ($62) {
  $68 = ___cxa_find_matching_catch()|0;
  $69 = tempRet0;
  $70 = HEAP8[$1>>0]|0;
  $71 = $70 & 1;
  $72 = ($71<<24>>24)==(0);
  if ($72) {
   $$1 = $68;$$12 = $69;
   ___resumeException($$1|0);
   // unreachable;
  }
  $73 = (($1) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  __ZdlPv($74);
  $$1 = $68;$$12 = $69;
  ___resumeException($$1|0);
  // unreachable;
 } else {
  $63 = HEAP8[$1>>0]|0;
  $64 = $63 & 1;
  $65 = ($64<<24>>24)==(0);
  if ($65) {
   STACKTOP = sp;return;
  }
  $66 = (($1) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  __ZdlPv($67);
  STACKTOP = sp;return;
 }
}
function __Z30scripting_stack_trace_info_forP18ScriptingExceptionR14StackTraceInfo($exception,$info) {
 $exception = $exception|0;
 $info = $info|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i$i = 0, $args = 0, $extractedTrace = 0;
 var $processedStackTrace = 0, $scriptingStringMessage = 0, $scriptingStringTrace = 0, $tempException = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $extractedTrace = sp + 96|0;
 $tempException = sp + 92|0;
 $scriptingStringMessage = sp + 88|0;
 $scriptingStringTrace = sp + 84|0;
 $args = sp + 72|0;
 $0 = sp + 60|0;
 $1 = sp + 36|0;
 $2 = sp + 24|0;
 $3 = sp + 12|0;
 $4 = sp;
 $processedStackTrace = sp + 48|0;
 ;HEAP32[$extractedTrace+0>>2]=0|0;HEAP32[$extractedTrace+4>>2]=0|0;HEAP32[$extractedTrace+8>>2]=0|0;
 HEAP32[$tempException>>2] = 0;
 HEAP32[$scriptingStringMessage>>2] = 0;
 HEAP32[$scriptingStringTrace>>2] = 0;
 HEAP32[$args>>2] = $exception;
 $5 = (($args) + 4|0);
 HEAP32[$5>>2] = $scriptingStringMessage;
 $6 = (($args) + 8|0);
 HEAP32[$6>>2] = $scriptingStringTrace;
 __THREW__ = 0;
 $7 = (invoke_i(84)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   label = 5;
  } else {
   $10 = (($7) + 360|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    __THREW__ = 0;
    $13 = (invoke_i(84)|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     label = 5;
     break;
    }
    $16 = (($13) + 360|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    (invoke_iiiii(238,($17|0),($exception|0),($args|0),($tempException|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 5;
     break;
    }
   }
   $22 = HEAP32[$tempException>>2]|0;
   $23 = ($22|0)==(0|0);
   L7: do {
    if ($23) {
     $131 = HEAP32[$scriptingStringMessage>>2]|0;
     $132 = ($131|0)==(0|0);
     do {
      if (!($132)) {
       __THREW__ = 0;
       invoke_vii(2703,($3|0),($131|0));
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       if ($134) {
        label = 5;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2233,($info|0),($3|0))|0);
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if ($136) {
        $142 = ___cxa_find_matching_catch()|0;
        $143 = tempRet0;
        $144 = HEAP8[$3>>0]|0;
        $145 = $144 & 1;
        $146 = ($145<<24>>24)==(0);
        if ($146) {
         $$2 = $142;$$23 = $143;
         break L1;
        }
        $147 = (($3) + 8|0);
        $148 = HEAP32[$147>>2]|0;
        __ZdlPv($148);
        $$2 = $142;$$23 = $143;
        break L1;
       } else {
        $137 = HEAP8[$3>>0]|0;
        $138 = $137 & 1;
        $139 = ($138<<24>>24)==(0);
        if ($139) {
         break;
        }
        $140 = (($3) + 8|0);
        $141 = HEAP32[$140>>2]|0;
        __ZdlPv($141);
        break;
       }
      }
     } while(0);
     $149 = HEAP32[$scriptingStringTrace>>2]|0;
     $150 = ($149|0)==(0|0);
     do {
      if (!($150)) {
       __THREW__ = 0;
       invoke_vii(2703,($4|0),($149|0));
       $151 = __THREW__; __THREW__ = 0;
       $152 = $151&1;
       if ($152) {
        label = 5;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2233,($extractedTrace|0),($4|0))|0);
       $153 = __THREW__; __THREW__ = 0;
       $154 = $153&1;
       if ($154) {
        $160 = ___cxa_find_matching_catch()|0;
        $161 = tempRet0;
        $162 = HEAP8[$4>>0]|0;
        $163 = $162 & 1;
        $164 = ($163<<24>>24)==(0);
        if ($164) {
         $$2 = $160;$$23 = $161;
         break L1;
        }
        $165 = (($4) + 8|0);
        $166 = HEAP32[$165>>2]|0;
        __ZdlPv($166);
        $$2 = $160;$$23 = $161;
        break L1;
       } else {
        $155 = HEAP8[$4>>0]|0;
        $156 = $155 & 1;
        $157 = ($156<<24>>24)==(0);
        if ($157) {
         break;
        }
        $158 = (($4) + 8|0);
        $159 = HEAP32[$158>>2]|0;
        __ZdlPv($159);
        break;
       }
      }
     } while(0);
     ;HEAP32[$processedStackTrace+0>>2]=0|0;HEAP32[$processedStackTrace+4>>2]=0|0;HEAP32[$processedStackTrace+8>>2]=0|0;
     $167 = HEAP8[$extractedTrace>>0]|0;
     $168 = $167 & 1;
     $169 = ($168<<24>>24)==(0);
     if ($169) {
      $172 = (($extractedTrace) + 1|0);
      $173 = $172;
     } else {
      $170 = (($extractedTrace) + 8|0);
      $171 = HEAP32[$170>>2]|0;
      $173 = $171;
     }
     __THREW__ = 0;
     invoke_vii(2704,($173|0),($processedStackTrace|0));
     $174 = __THREW__; __THREW__ = 0;
     $175 = $174&1;
     if (!($175)) {
      $176 = (($info) + 12|0);
      __THREW__ = 0;
      (invoke_iii(2233,($176|0),($processedStackTrace|0))|0);
      $177 = __THREW__; __THREW__ = 0;
      $178 = $177&1;
      if (!($178)) {
       $179 = (($info) + 24|0);
       __THREW__ = 0;
       (invoke_iii(2233,($179|0),($extractedTrace|0))|0);
       $180 = __THREW__; __THREW__ = 0;
       $181 = $180&1;
       if (!($181)) {
        $182 = (($info) + 36|0);
        HEAP32[$182>>2] = 0;
        $183 = (($info) + 40|0);
        __THREW__ = 0;
        (invoke_iii(2392,($183|0),(600128|0))|0);
        $184 = __THREW__; __THREW__ = 0;
        $185 = $184&1;
        if (!($185)) {
         $186 = (($info) + 52|0);
         HEAP32[$186>>2] = -1;
         $187 = HEAP8[$processedStackTrace>>0]|0;
         $188 = $187 & 1;
         $189 = ($188<<24>>24)==(0);
         if ($189) {
          break;
         }
         $190 = (($processedStackTrace) + 8|0);
         $191 = HEAP32[$190>>2]|0;
         __ZdlPv($191);
         break;
        }
       }
      }
     }
     $197 = ___cxa_find_matching_catch()|0;
     $198 = tempRet0;
     $199 = HEAP8[$processedStackTrace>>0]|0;
     $200 = $199 & 1;
     $201 = ($200<<24>>24)==(0);
     if ($201) {
      $$2 = $197;$$23 = $198;
      break L1;
     }
     $202 = (($processedStackTrace) + 8|0);
     $203 = HEAP32[$202>>2]|0;
     __ZdlPv($203);
     $$2 = $197;$$23 = $198;
     break L1;
    } else {
     __THREW__ = 0;
     $24 = (invoke_ii(3241,($22|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 5;
      break L1;
     }
     __THREW__ = 0;
     $27 = (invoke_ii(3242,($24|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 5;
      break L1;
     }
     $30 = (_strlen(($27|0))|0);
     $31 = ($30>>>0)>(4294967279);
     if ($31) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 5;
       break L1;
      }
      // unreachable;
     }
     $34 = ($30>>>0)<(11);
     if ($34) {
      $35 = $30 << 1;
      $36 = $35&255;
      HEAP8[$2>>0] = $36;
      $37 = (($2) + 1|0);
      $$pre$phiZ2D = $2;$49 = $36;$__p$0$i$i$i = $37;
     } else {
      $38 = (($30) + 16)|0;
      $39 = $38 & -16;
      __THREW__ = 0;
      $40 = (invoke_ii(2988,($39|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 5;
       break L1;
      }
      $43 = (($2) + 8|0);
      HEAP32[$43>>2] = $40;
      $44 = $39 | 1;
      HEAP32[$2>>2] = $44;
      $45 = (($2) + 4|0);
      HEAP32[$45>>2] = $30;
      $46 = $44&255;
      $$pre$phiZ2D = $2;$49 = $46;$__p$0$i$i$i = $40;
     }
     _memcpy(($__p$0$i$i$i|0),($27|0),($30|0))|0;
     $47 = (($__p$0$i$i$i) + ($30)|0);
     HEAP8[$47>>0] = 0;
     ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
     $48 = $49 & 1;
     $50 = ($48<<24>>24)==(0);
     if ($50) {
      $53 = $49&255;
      $54 = $53 >>> 1;
      $56 = $54;
     } else {
      $51 = (($2) + 4|0);
      $52 = HEAP32[$51>>2]|0;
      $56 = $52;
     }
     $55 = (($56) + 78)|0;
     $57 = ($55>>>0)>(4294967279);
     do {
      if ($57) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        label = 30;
       } else {
        // unreachable;
       }
      } else {
       $60 = ($55>>>0)<(11);
       if ($60) {
        HEAP8[$1>>0] = -100;
        $61 = (($1) + 1|0);
        $__p$0$i$i = $61;
       } else {
        $62 = (($56) + 94)|0;
        $63 = $62 & -16;
        __THREW__ = 0;
        $64 = (invoke_ii(2988,($63|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 30;
         break;
        }
        $67 = (($1) + 8|0);
        HEAP32[$67>>2] = $64;
        $68 = $63 | 1;
        HEAP32[$1>>2] = $68;
        $69 = (($1) + 4|0);
        HEAP32[$69>>2] = 78;
        $__p$0$i$i = $64;
       }
       dest=$__p$0$i$i+0|0; src=600000+0|0; stop=dest+78|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $70 = (($__p$0$i$i) + 78|0);
       HEAP8[$70>>0] = 0;
       $71 = $49 & 1;
       $72 = ($71<<24>>24)==(0);
       if ($72) {
        $75 = (($2) + 1|0);
        $76 = $75;
       } else {
        $73 = (($2) + 8|0);
        $74 = HEAP32[$73>>2]|0;
        $76 = $74;
       }
       __THREW__ = 0;
       (invoke_iiii(1480,($1|0),($76|0),($56|0))|0);
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        label = 30;
       } else {
        __THREW__ = 0;
        invoke_viii(1627,($0|0),($1|0),(600080|0));
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        do {
         if ($87) {
          $112 = ___cxa_find_matching_catch()|0;
          $113 = tempRet0;
          $$0 = $112;$$01 = $113;
         } else {
          $88 = HEAP8[$0>>0]|0;
          $89 = $88 & 1;
          $90 = ($89<<24>>24)==(0);
          if ($90) {
           $93 = (($0) + 1|0);
           $94 = $93;
          } else {
           $91 = (($0) + 8|0);
           $92 = HEAP32[$91>>2]|0;
           $94 = $92;
          }
          __THREW__ = 0;
          invoke_viiiiiiii(21,($94|0),0,(599920|0),346,1,0,0,(0|0));
          $95 = __THREW__; __THREW__ = 0;
          $96 = $95&1;
          if ($96) {
           $114 = ___cxa_find_matching_catch()|0;
           $115 = tempRet0;
           $116 = HEAP8[$0>>0]|0;
           $117 = $116 & 1;
           $118 = ($117<<24>>24)==(0);
           if ($118) {
            $$0 = $114;$$01 = $115;
            break;
           }
           $119 = (($0) + 8|0);
           $120 = HEAP32[$119>>2]|0;
           __ZdlPv($120);
           $$0 = $114;$$01 = $115;
           break;
          }
          $97 = HEAP8[$0>>0]|0;
          $98 = $97 & 1;
          $99 = ($98<<24>>24)==(0);
          if (!($99)) {
           $100 = (($0) + 8|0);
           $101 = HEAP32[$100>>2]|0;
           __ZdlPv($101);
          }
          $102 = HEAP8[$1>>0]|0;
          $103 = $102 & 1;
          $104 = ($103<<24>>24)==(0);
          if (!($104)) {
           $105 = (($1) + 8|0);
           $106 = HEAP32[$105>>2]|0;
           __ZdlPv($106);
          }
          $107 = HEAP8[$$pre$phiZ2D>>0]|0;
          $108 = $107 & 1;
          $109 = ($108<<24>>24)==(0);
          if ($109) {
           break L7;
          }
          $110 = (($2) + 8|0);
          $111 = HEAP32[$110>>2]|0;
          __ZdlPv($111);
          break L7;
         }
        } while(0);
        $121 = HEAP8[$1>>0]|0;
        $122 = $121 & 1;
        $123 = ($122<<24>>24)==(0);
        if ($123) {
         $$1 = $$0;$$12 = $$01;
        } else {
         $124 = (($1) + 8|0);
         $125 = HEAP32[$124>>2]|0;
         __ZdlPv($125);
         $$1 = $$0;$$12 = $$01;
        }
       }
      }
     } while(0);
     if ((label|0) == 30) {
      $79 = ___cxa_find_matching_catch()|0;
      $80 = tempRet0;
      $81 = HEAP8[$1>>0]|0;
      $82 = $81 & 1;
      $83 = ($82<<24>>24)==(0);
      if (!($83)) {
       $84 = (($1) + 8|0);
       $85 = HEAP32[$84>>2]|0;
       __ZdlPv($85);
      }
      $$1 = $79;$$12 = $80;
     }
     $126 = HEAP8[$$pre$phiZ2D>>0]|0;
     $127 = $126 & 1;
     $128 = ($127<<24>>24)==(0);
     if ($128) {
      $$2 = $$1;$$23 = $$12;
      break L1;
     }
     $129 = (($2) + 8|0);
     $130 = HEAP32[$129>>2]|0;
     __ZdlPv($130);
     $$2 = $$1;$$23 = $$12;
     break L1;
    }
   } while(0);
   $192 = HEAP8[$extractedTrace>>0]|0;
   $193 = $192 & 1;
   $194 = ($193<<24>>24)==(0);
   if ($194) {
    STACKTOP = sp;return;
   }
   $195 = (($extractedTrace) + 8|0);
   $196 = HEAP32[$195>>2]|0;
   __ZdlPv($196);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 5) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $$2 = $20;$$23 = $21;
 }
 $204 = HEAP8[$extractedTrace>>0]|0;
 $205 = $204 & 1;
 $206 = ($205<<24>>24)==(0);
 if ($206) {
  ___resumeException($$2|0);
  // unreachable;
 }
 $207 = (($extractedTrace) + 8|0);
 $208 = HEAP32[$207>>2]|0;
 __ZdlPv($208);
 ___resumeException($$2|0);
 // unreachable;
}
function __Z27scripting_array_element_ptrP14ScriptingArrayij($array,$i,$element_size) {
 $array = $array|0;
 $i = $i|0;
 $element_size = $element_size|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_imul($element_size, $i)|0;
 $1 = (($0) + 16)|0;
 $2 = (($array) + ($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z25scripting_array_class_getP14ScriptingClassj($elementClass,$rank) {
 $elementClass = $elementClass|0;
 $rank = $rank|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_array_class_get($elementClass,$rank)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z19scripting_array_newP14ScriptingClassjj($klass,$element_size,$count) {
 $klass = $klass|0;
 $element_size = $element_size|0;
 $count = $count|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_array_new($klass,$count)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z32scripting_class_get_assemblynameP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_get_assemblyname($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z24scripting_field_get_nameP14ScriptingField($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_field_get_name($field)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z25scripting_field_get_flagsP14ScriptingField($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_field_get_flags($field)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z26scripting_field_get_parentP14ScriptingField($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_field_get_parent($field)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z26scripting_field_get_offsetP14ScriptingField($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_field_get_offset($field)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z24scripting_field_get_typeP14ScriptingField($field) {
 $field = $field|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_field_get_type($field)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z23scripting_type_get_typeP13ScriptingType($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_type_get_type($type)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z41scripting_type_get_class_or_element_classP13ScriptingType($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_type_get_class_or_element_class($type)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z25scripting_class_get_flagsP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_get_flags($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z26scripting_class_get_fieldsP14ScriptingClassRNSt3__16vectorIP14ScriptingField13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEE($klass,$fields) {
 $klass = $klass|0;
 $fields = $fields|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $field = 0, $iterator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $iterator = sp + 4|0;
 $field = sp;
 HEAP32[$iterator>>2] = 0;
 $0 = (_il2cpp_class_get_fields($klass,$iterator)|0);
 HEAP32[$field>>2] = $0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($fields) + 4|0);
 $3 = (($fields) + 8|0);
 $8 = $0;
 while(1) {
  $4 = HEAP32[$2>>2]|0;
  $5 = HEAP32[$3>>2]|0;
  $6 = ($4|0)==($5|0);
  if ($6) {
   __ZNSt3__16vectorIP14ScriptingField13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($fields,$field);
  } else {
   $7 = ($4|0)==(0|0);
   if ($7) {
    $10 = 0;
   } else {
    HEAP32[$4>>2] = $8;
    $$pre$i = HEAP32[$2>>2]|0;
    $10 = $$pre$i;
   }
   $9 = (($10) + 4|0);
   HEAP32[$2>>2] = $9;
  }
  $11 = (_il2cpp_class_get_fields($klass,$iterator)|0);
  HEAP32[$field>>2] = $11;
  $12 = ($11|0)==(0|0);
  if ($12) {
   break;
  } else {
   $8 = $11;
  }
 }
 STACKTOP = sp;return;
}
function __Z35scripting_class_get_field_from_nameP14ScriptingClassPKc($klass,$name) {
 $klass = $klass|0;
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_get_field_from_name($klass,$name)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z29scripting_class_enum_basetypeP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_enum_basetype($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z27scripting_class_is_abstractP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_is_abstract($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z28scripting_class_is_interfaceP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_is_interface($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z26scripting_class_is_genericP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_is_generic($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z22scripting_array_lengthP14ScriptingArray($array) {
 $array = $array|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_array_length($array)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z34scripting_class_array_element_sizeP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_array_element_size($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z28scripting_array_element_sizeP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_array_element_size($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z25scripting_class_from_typeP13ScriptingType($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_from_type($type)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z29scripting_class_from_fullnamePKcS0_S0_($assembly,$namespaze,$name) {
 $assembly = $assembly|0;
 $namespaze = $namespaze|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14GetMonoManagerv()|0);
 $1 = (__ZN11MonoManager17GetScriptingClassEPKcS1_S1_($0,$assembly,$namespaze,$name)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z29scripting_field_has_attributeP14ScriptingClassP14ScriptingFieldS0_($klass,$field,$attr) {
 $klass = $klass|0;
 $field = $field|0;
 $attr = $attr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_field_has_attribute($field,$attr)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z29scripting_class_has_attributeP14ScriptingClassS0_($klass,$attr) {
 $klass = $klass|0;
 $attr = $attr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_has_attribute($klass,$attr)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z23scripting_type_get_nameP13ScriptingType($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_type_get_name($type)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z20scripting_get_corlibv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_get_corlib()|0);
 STACKTOP = sp;return ($0|0);
}
function __Z25scripting_class_get_imageP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_class_get_image($klass)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z36scripting_liveness_calculation_beginP14ScriptingClassiPFvPPviS1_ES1_($filter,$max_object_count,$callback,$userdata) {
 $filter = $filter|0;
 $max_object_count = $max_object_count|0;
 $callback = $callback|0;
 $userdata = $userdata|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_unity_liveness_calculation_begin($filter,$max_object_count,$callback,$userdata)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z34scripting_liveness_calculation_endPv($state) {
 $state = $state|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _il2cpp_unity_liveness_calculation_end($state);
 STACKTOP = sp;return;
}
function __Z40scripting_liveness_calculation_from_rootP15ScriptingObjectPv($root,$state) {
 $root = $root|0;
 $state = $state|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _il2cpp_unity_liveness_calculation_from_root($root,$state);
 STACKTOP = sp;return;
}
function __Z43scripting_liveness_calculation_from_staticsPv($state) {
 $state = $state|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _il2cpp_unity_liveness_calculation_from_statics($state);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIP14ScriptingField13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,599920,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<2)|0);
 $24 = (($23) + ($$0$i3<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$__x>>2]|0;
  HEAP32[$22>>2] = $26;
 }
 $27 = (($23) + ($8<<2)|0);
 $28 = HEAP32[$this>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = $29;
 $31 = $28;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $$sum1 = (($7) - ($33))|0;
 $34 = (($23) + ($$sum1<<2)|0);
 _memcpy(($34|0),($28|0),($32|0))|0;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $34;
 HEAP32[$1>>2] = $27;
 HEAP32[$10>>2] = $24;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI21ScriptingMethodIl2Cpp13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 3;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 2;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 3;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,599920,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<3)|0);
 $24 = (($23) + ($$0$i3<<3)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = $__x;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = $22;
  $33 = $32;
  HEAP32[$33>>2] = $28;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP32[$35>>2] = $31;
 }
 $36 = (($23) + ($8<<3)|0);
 $37 = HEAP32[$this>>2]|0;
 $38 = HEAP32[$1>>2]|0;
 $39 = $38;
 $40 = $37;
 $41 = (($39) - ($40))|0;
 $42 = $41 >> 3;
 $$sum1 = (($7) - ($42))|0;
 $43 = (($23) + ($$sum1<<3)|0);
 _memcpy(($43|0),($37|0),($41|0))|0;
 $44 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $43;
 HEAP32[$1>>2] = $36;
 HEAP32[$10>>2] = $24;
 $45 = ($44|0)==(0|0);
 if ($45) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($44|0),($$byval_copy1|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEED1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 do {
  if ($5) {
   $19 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = (($7) + -12|0);
    HEAP32[$3>>2] = $6;
    $8 = HEAP8[$6>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $12 = $6;
    } else {
     $13 = (($7) + -4|0);
     $14 = HEAP32[$13>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($14|0),($$byval_copy|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 8;
      break;
     }
     $$pre$i$i$i$i = HEAP32[$3>>2]|0;
     $12 = $$pre$i$i$i$i;
    }
    $11 = ($12|0)==($1|0);
    if ($11) {
     label = 9;
     break;
    } else {
     $7 = $12;
    }
   }
   if ((label|0) == 8) {
    $17 = ___cxa_find_matching_catch()|0;
    $18 = tempRet0;
    ___cxa_call_unexpected(($17|0));
    // unreachable;
   }
   else if ((label|0) == 9) {
    $$pre$i$i = HEAP32[$this>>2]|0;
    $19 = $$pre$i$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($19);
 STACKTOP = sp;return;
}
function __ZN11MonoManager13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11MonoManager14LoadAssembliesEv($this);
 $0 = (($this) + 36|0);
 __Z26FillCommonScriptingClassesR22CommonScriptingClasses($0);
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN11MonoManager14LoadAssembliesEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $i$01 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 708|0);
 $1 = (($this) + 700|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 696|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = (($this) + 712|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$0>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = $14 >> 2;
 $16 = ($15>>>0)<($8>>>0);
 if ($16) {
  $17 = (($8) - ($15))|0;
  __ZNSt3__16vectorIP14ScriptingImageNS_9allocatorIS2_EEE8__appendEj($0,$17);
  $$pre = HEAP32[$1>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $25 = $$pre;$26 = $$pre3;
 } else {
  $18 = ($15>>>0)>($8>>>0);
  if ($18) {
   $19 = (($11) + ($8<<2)|0);
   $20 = ($10|0)==($19|0);
   if ($20) {
    $25 = $2;$26 = $4;
   } else {
    $__new_last2$i$i$i = $19;
    $scevgep$i$i$i = (($10) + -4|0);
    $21 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($21)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $22 = $uglygep3$i$i$i >>> 2;
    $23 = $22 ^ -1;
    $scevgep4$i$i$i = (($10) + ($23<<2)|0);
    HEAP32[$9>>2] = $scevgep4$i$i$i;
    $25 = $2;$26 = $4;
   }
  } else {
   $25 = $2;$26 = $4;
  }
 }
 $24 = ($25|0)==($26|0);
 if ($24) {
  STACKTOP = sp;return;
 } else {
  $28 = $26;$62 = $25;$i$01 = 0;
 }
 while(1) {
  $27 = (($28) + (($i$01*12)|0)|0);
  $29 = HEAP8[$27>>0]|0;
  $30 = $29 & 1;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $34 = $29&255;
   $35 = $34 >>> 1;
   $37 = $35;
  } else {
   $32 = ((($28) + (($i$01*12)|0)|0) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $37 = $33;
  }
  $36 = ($37|0)==(0);
  if ($36) {
   $56 = $62;$58 = $28;
  } else {
   $38 = (_il2cpp_domain_get()|0);
   $39 = HEAP32[$3>>2]|0;
   $40 = (($39) + (($i$01*12)|0)|0);
   $41 = HEAP8[$40>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $46 = (($40) + 1|0);
    $47 = $46;
   } else {
    $44 = ((($39) + (($i$01*12)|0)|0) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $47 = $45;
   }
   $48 = (_il2cpp_domain_assembly_open($38,$47)|0);
   $49 = ($48|0)==(0|0);
   if ($49) {
    $53 = 0;
   } else {
    $50 = (_il2cpp_assembly_get_image($48)|0);
    $53 = $50;
   }
   $51 = HEAP32[$0>>2]|0;
   $52 = (($51) + ($i$01<<2)|0);
   HEAP32[$52>>2] = $53;
   $$pre4 = HEAP32[$1>>2]|0;
   $$pre5 = HEAP32[$3>>2]|0;
   $56 = $$pre4;$58 = $$pre5;
  }
  $54 = (($i$01) + 1)|0;
  $55 = $56;
  $57 = $58;
  $59 = (($55) - ($57))|0;
  $60 = (($59|0) / 12)&-1;
  $61 = ($54>>>0)<($60>>>0);
  if ($61) {
   $28 = $58;$62 = $56;$i$01 = $54;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11MonoManager17GetScriptingClassEPKcS1_S1_($this,$assembly,$namespaze,$name) {
 $this = $this|0;
 $assembly = $assembly|0;
 $namespaze = $namespaze|0;
 $name = $name|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $klass$0$lcssa = 0, $klass$1 = 0;
 var $or$cond = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_il2cpp_get_corlib()|0);
 $1 = (_il2cpp_class_from_name($0,$namespaze,$name)|0);
 $2 = (($this) + 708|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 712|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)!=($5|0);
 $7 = ($1|0)==(0|0);
 $or$cond2 = $6 & $7;
 if ($or$cond2) {
  $16 = $5;$9 = $3;
 } else {
  $klass$0$lcssa = $1;
  STACKTOP = sp;return ($klass$0$lcssa|0);
 }
 while(1) {
  $8 = HEAP32[$9>>2]|0;
  $10 = ($8|0)==(0|0);
  if ($10) {
   $14 = $16;$klass$1 = 0;
  } else {
   $11 = (_il2cpp_class_from_name($8,$namespaze,$name)|0);
   $$pre = HEAP32[$4>>2]|0;
   $14 = $$pre;$klass$1 = $11;
  }
  $12 = (($9) + 4|0);
  $13 = ($12|0)!=($14|0);
  $15 = ($klass$1|0)==(0|0);
  $or$cond = $13 & $15;
  if ($or$cond) {
   $16 = $14;$9 = $12;
  } else {
   $klass$0$lcssa = $klass$1;
   break;
  }
 }
 STACKTOP = sp;return ($klass$0$lcssa|0);
}
function __ZN11MonoManager25GetAssemblyIndexFromImageEP14ScriptingImage($this,$image) {
 $this = $this|0;
 $image = $image|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 712|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 708|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$01 = 0;
 }
 while(1) {
  $11 = (($3) + ($i$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($image|0);
  $10 = (($i$01) + 1)|0;
  if ($13) {
   $$0 = $i$01;
   label = 4;
   break;
  }
  $5 = $1;
  $6 = $3;
  $7 = (($5) - ($6))|0;
  $8 = $7 >> 2;
  $9 = ($10>>>0)<($8>>>0);
  if ($9) {
   $i$01 = $10;
  } else {
   $$0 = -1;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN11MonoManager25GetImageFromAssemblyIndexEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 708|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN11MonoManager19GetBuiltinMonoClassEPKcb($this,$name,$optional) {
 $this = $this|0;
 $name = $name|0;
 $optional = $optional|0;
 var $$0 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $klass$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 708|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $klass$0 = 0;
 } else {
  $5 = (__Z25scripting_class_from_nameP14ScriptingImagePKcS2_($3,600288,$name)|0);
  $klass$0 = $5;
 }
 $$not = ($klass$0|0)!=(0|0);
 $brmerge = $$not | $optional;
 if ($brmerge) {
  $$0 = $klass$0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = $name;
 __Z6FormatPKcz($0,600304,$vararg_buffer);
 $6 = HEAP8[$0>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $11 = (($0) + 1|0);
  $12 = $11;
 } else {
  $9 = (($0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $12 = $10;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($12|0),0,(600384|0),108,1,0,0,(0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $22 = HEAP8[$0>>0]|0;
  $23 = $22 & 1;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   ___resumeException($20|0);
   // unreachable;
  }
  $25 = (($0) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  __ZdlPv($26);
  ___resumeException($20|0);
  // unreachable;
 } else {
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $18 = (($0) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  __ZdlPv($19);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN11MonoManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer8TransferI11MonoManagerEEvRT_PKc17TransferMetaFlags($transfer,$this,600392,0);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI11MonoManagerEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $p$i$i$i = 0, $size$i = 0, $size$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp;
 $size$i$i = sp + 40|0;
 $p$i$i = sp + 16|0;
 $size$i = sp + 20|0;
 $0 = sp + 24|0;
 $p$i$i$i = sp + 28|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,600400,$data,$metaFlag);
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($data,$this);
 __ZN13ProxyTransfer10SetVersionEi($this,2);
 $1 = (($data) + 24|0);
 $2 = HEAP32[580664>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,600416,$2,$1,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,600488,600488,$size$i$i,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,600448,600496,$p$i$i,0);
 $3 = (($$byval_copy1) + 8|0);
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 HEAP32[$$byval_copy1>>2] = 0;
 $8 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,600456,$8,$p$i$i,1);
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($11) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $15 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,600472,$15,$3,1);
 $16 = HEAP32[$9>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$12>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $20 = (($data) + 696|0);
 $21 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,600432,$21,$20,0);
 ;HEAP32[$p$i$i$i+0>>2]=0|0;HEAP32[$p$i$i$i+4>>2]=0|0;HEAP32[$p$i$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(600488|0),(600488|0),($size$i|0),0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if (!($23)) {
  $24 = HEAP32[580712>>2]|0;
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(600448|0),($24|0),($p$i$i$i|0),0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   __THREW__ = 0;
   invoke_viiiii(87,($this|0),(600488|0),(600488|0),($size$i$i|0),1);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[580552>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($this|0),(600448|0),($29|0),($p$i$i|0),0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = HEAP32[$9>>2]|0;
     $33 = HEAP32[$32>>2]|0;
     $34 = HEAP32[$12>>2]|0;
     $35 = ((($33) + (($34*24)|0)|0) + 12|0);
     HEAP32[$35>>2] = 1;
     __THREW__ = 0;
     invoke_vi(3390,($this|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      invoke_vi(3391,($this|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       __THREW__ = 0;
       invoke_vi(3392,($this|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __THREW__ = 0;
        invoke_vi(3390,($this|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if (!($43)) {
         __THREW__ = 0;
         invoke_vi(3391,($this|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if (!($45)) {
          $46 = HEAP8[$p$i$i$i>>0]|0;
          $47 = $46 & 1;
          $48 = ($47<<24>>24)==(0);
          if ($48) {
           __ZN13ProxyTransfer11EndTransferEv($this);
           __ZN13ProxyTransfer11EndTransferEv($this);
           STACKTOP = sp;return;
          }
          $49 = (($p$i$i$i) + 8|0);
          $50 = HEAP32[$49>>2]|0;
          HEAP32[$size$i$i>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i+0>>2]|0;
          invoke_vii(2591,($50|0),($$byval_copy1|0));
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           $53 = ___cxa_find_matching_catch()|0;
           $54 = tempRet0;
           ___cxa_call_unexpected(($53|0));
           // unreachable;
          } else {
           __ZN13ProxyTransfer11EndTransferEv($this);
           __ZN13ProxyTransfer11EndTransferEv($this);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $55 = ___cxa_find_matching_catch()|0;
 $56 = tempRet0;
 $57 = HEAP8[$p$i$i$i>>0]|0;
 $58 = $57 & 1;
 $59 = ($58<<24>>24)==(0);
 if ($59) {
  ___resumeException($55|0);
  // unreachable;
 }
 $60 = (($p$i$i$i) + 8|0);
 $61 = HEAP32[$60>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($61|0),($$byval_copy1|0));
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 if ($63) {
  $64 = ___cxa_find_matching_catch()|0;
  $65 = tempRet0;
  ___cxa_call_unexpected(($64|0));
  // unreachable;
 } else {
  ___resumeException($55|0);
  // unreachable;
 }
}
function __ZN11MonoManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,600392,600400,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN11MonoManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11MonoManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13setI4PPtrI10MonoScriptENS2_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier69ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 696|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 STACKTOP = sp;return;
}
function __ZN11MonoManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13setI4PPtrI10MonoScriptENS2_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier69ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 696|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 STACKTOP = sp;return;
}
function __ZN11MonoManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11MonoManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11MonoManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i$i$i = 0, $$01$i$i$i$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($transfer) + 12|0);
 $5 = (($transfer) + 28|0);
 $6 = (($transfer) + 32|0);
 $8 = $1;
 while(1) {
  $7 = (($8) + 16|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = HEAP32[$4>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$5>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($10,$9,$13)|0);
  $15 = HEAP8[$6>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   HEAP32[$7>>2] = $14;
  }
  $17 = (($8) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   $$01$i$i$i$i$i$i$i$i$i = $8;
   while(1) {
    $22 = (($$01$i$i$i$i$i$i$i$i$i) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==($$01$i$i$i$i$i$i$i$i$i|0);
    if ($25) {
     $$0$i$i$i$i$i$i$i$i$i = $23;
     break;
    } else {
     $$01$i$i$i$i$i$i$i$i$i = $23;
    }
   }
  } else {
   $$0$i$i$i$i$i$i$i$i$i$i = $18;
   while(1) {
    $20 = HEAP32[$$0$i$i$i$i$i$i$i$i$i$i>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     $$0$i$i$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i$i$i$i$i$i = $20;
    }
   }
  }
  $26 = ($$0$i$i$i$i$i$i$i$i$i|0)==($2|0);
  if ($26) {
   break;
  } else {
   $8 = $$0$i$i$i$i$i$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __Z25RegisterClass_MonoManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(116,123,0,0,0);
 STACKTOP = sp;return;
}
function __ZN11MonoManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 11;
 dest=$3+0|0; src=600400+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 11|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,116,6,($0|0),720,(2393|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN11MonoManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(720,$$byval_copy2,1,16,600384,16)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1732,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((600168 + 8|0));
  $6 = (($3) + 696|0);
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  STACKTOP = sp;return ($3|0);
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(600384|0),16);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK11MonoManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 116;
}
function __Z14GetMonoManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(5)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z17GetMonoManagerPtrv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24GetManagerPtrFromContexti(5)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN11MonoManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((600168 + 8|0));
 $0 = (($this) + 708|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 712|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if (!($5)) {
   $__new_last2$i$i$i$i$i$i = $1;
   $scevgep$i$i$i$i$i$i = (($4) + -4|0);
   $6 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($6)|0);
   $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
   $7 = $uglygep3$i$i$i$i$i$i >>> 2;
   $8 = $7 ^ -1;
   $scevgep4$i$i$i$i$i$i = (($4) + ($8<<2)|0);
   HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i;
  }
  __ZdlPv($1);
 }
 $9 = (($this) + 696|0);
 __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEED1Ev($9);
 __ZN16ScriptingManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN11MonoManagerD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((600168 + 8|0));
 $1 = (($this) + 708|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 712|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $__new_last2$i$i$i$i$i$i$i = $2;
   $scevgep$i$i$i$i$i$i$i = (($5) + -4|0);
   $7 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($7)|0);
   $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
   $8 = $uglygep3$i$i$i$i$i$i$i >>> 2;
   $9 = $8 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($5) + ($9<<2)|0);
   HEAP32[$4>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  __ZdlPv($2);
 }
 $10 = (($this) + 696|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = (($this) + 700|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==($11|0);
  do {
   if ($15) {
    $29 = $11;
   } else {
    $17 = $14;
    while(1) {
     $16 = (($17) + -12|0);
     HEAP32[$13>>2] = $16;
     $18 = HEAP8[$16>>0]|0;
     $19 = $18 & 1;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      $22 = $16;
     } else {
      $23 = (($17) + -4|0);
      $24 = HEAP32[$23>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($24|0),($$byval_copy|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       label = 12;
       break;
      }
      $$pre$i$i$i$i$i = HEAP32[$13>>2]|0;
      $22 = $$pre$i$i$i$i$i;
     }
     $21 = ($22|0)==($11|0);
     if ($21) {
      label = 13;
      break;
     } else {
      $17 = $22;
     }
    }
    if ((label|0) == 12) {
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     ___cxa_call_unexpected(($27|0));
     // unreachable;
    }
    else if ((label|0) == 13) {
     $$pre$i$i$i = HEAP32[$10>>2]|0;
     $29 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($29);
 }
 __THREW__ = 0;
 invoke_vi(1151,($this|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  __ZdlPv($this);
  ___resumeException($32|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN16ScriptingManager14IsTrustedTokenERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN11MonoManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i1 = sp;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i1>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i1,4);
 }
 $8 = (($this) + 28|0);
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($8|0);
 if (!($11)) {
  $13 = $10;
  while(1) {
   $12 = (($13) + 16|0);
   __ZN4PPtrI10MonoScriptE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($12,$transfer);
   $14 = (($13) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $$01$i$i$i$i$i = $13;
    while(1) {
     $19 = (($$01$i$i$i$i$i) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($$01$i$i$i$i$i|0);
     if ($22) {
      $$0$i$i$i$i$i = $20;
      break;
     } else {
      $$01$i$i$i$i$i = $20;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $15;
    while(1) {
     $17 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $17;
     }
    }
   }
   $23 = ($$0$i$i$i$i$i|0)==($8|0);
   if ($23) {
    break;
   } else {
    $13 = $$0$i$i$i$i$i;
   }
  }
 }
 $24 = (($this) + 700|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 696|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $25;
 $29 = $27;
 $30 = (($28) - ($29))|0;
 $31 = (($30|0) / 12)&-1;
 HEAP32[$size$i$i$i1>>2] = $31;
 $32 = HEAP32[$2>>2]|0;
 $33 = (($32) + 4|0);
 $34 = HEAP32[$5>>2]|0;
 $35 = ($33>>>0)<($34>>>0);
 if ($35) {
  HEAP32[$32>>2] = $31;
  HEAP32[$2>>2] = $33;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i1,4);
 }
 $36 = HEAP32[$24>>2]|0;
 $37 = HEAP32[$26>>2]|0;
 $38 = ($37|0)==($36|0);
 if ($38) {
  STACKTOP = sp;return;
 } else {
  $39 = $37;
 }
 while(1) {
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$39,0);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  $40 = (($39) + 12|0);
  $41 = ($40|0)==($36|0);
  if ($41) {
   break;
  } else {
   $39 = $40;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4PPtrI10MonoScriptE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13setI4PPtrI10MonoScriptENS2_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier69ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $1 = sp + 8|0;
 $size = sp;
 $p = sp + 4|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $9 = $$pre$i$i$i;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$size>>2] = $8;
  HEAP32[$2>>2] = $4;
  $9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$size>>2] = $10;
 HEAP32[$p>>2] = 0;
 $11 = (($data) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($data,$12);
 $13 = (($data) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($data) + 4|0);
 HEAP32[$data>>2] = $14;
 HEAP32[$14>>2] = 0;
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)>(0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $i$01 = 0;
 while(1) {
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb1EEEEvRT_($p,$this);
  __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE15__insert_uniqueERKS3_($1,$data,$p);
  $17 = (($i$01) + 1)|0;
  $18 = HEAP32[$size>>2]|0;
  $19 = ($17|0)<($18|0);
  if ($19) {
   $i$01 = $17;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$22 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)<($6|0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6|0)<($4|0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $32 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $31 = (($agg$result) + 4|0);
  HEAP8[$31>>0] = $32;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 69;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $17 = (__Z15malloc_internaljj10MemLabelIdiPKci(20,16,$$byval_copy,0,600384,79)|0);
 $18 = (($17) + 16|0);
 $19 = HEAP32[$__v>>2]|0;
 HEAP32[$18>>2] = $19;
 HEAP32[$17>>2] = 0;
 $20 = (($17) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($17) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $17;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $17;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $32 = 1;$__r$0 = $17;
 HEAP32[$agg$result>>2] = $__r$0;
 $31 = (($agg$result) + 4|0);
 HEAP8[$31>>0] = $32;
 STACKTOP = sp;return;
}
function __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$4);
 HEAP32[$0>>2] = 69;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  ___cxa_call_unexpected(($7|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13setI4PPtrI10MonoScriptENS2_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier69ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $p = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $1 = sp + 8|0;
 $size = sp;
 $p = sp + 4|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$size>>2] = $8;
  HEAP32[$2>>2] = $4;
 }
 HEAP32[$p>>2] = 0;
 $9 = (($data) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($data,$10);
 $11 = (($data) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (($data) + 4|0);
 HEAP32[$data>>2] = $12;
 HEAP32[$12>>2] = 0;
 $13 = HEAP32[$size>>2]|0;
 $14 = ($13|0)>(0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $i$01 = 0;
 while(1) {
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb0EEEEvRT_($p,$this);
  __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE15__insert_uniqueERKS3_($1,$data,$p);
  $15 = (($i$01) + 1)|0;
  $16 = HEAP32[$size>>2]|0;
  $17 = ($15|0)<($16|0);
  if ($17) {
   $i$01 = $15;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN11MonoManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 24|0);
 $1 = HEAP32[580664>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,600416,$1,$converter$i$i1,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13setI4PPtrI10MonoScriptENS1_4lessIS5_EE13stl_allocatorIS5_L18MemLabelIdentifier69ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 696|0);
 $8 = HEAP32[580760>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,600432,$8,$converter$i$i1,1)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 if ($11) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$7,0);
 } else {
  $12 = HEAP32[$converter$i$i1>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   (FUNCTION_TABLE_iii[$12 & 4095]($7,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13setI4PPtrI10MonoScriptENS1_4lessIS5_EE13stl_allocatorIS5_L18MemLabelIdentifier69ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $i$01 = 0, $p = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 8|0;
 $size = sp;
 $p = sp + 4|0;
 $1 = (($data) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,600488,600488,$size)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 HEAP32[$p>>2] = 0;
 $4 = (($data) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($data,$5);
 HEAP32[$1>>2] = 0;
 $6 = (($data) + 4|0);
 HEAP32[$data>>2] = $6;
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[$size>>2]|0;
 $8 = ($7|0)>(0);
 if ($8) {
  $i$01 = 0;
  while(1) {
   $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,600448,600496,$converter$i$i,1)|0);
   $10 = ($9|0)==(0);
   if (!($10)) {
    $11 = ($9|0)>(0);
    if ($11) {
     __ZN4PPtrI10MonoScriptE8TransferI14SafeBinaryReadEEvRT_($p,$this);
    } else {
     $12 = HEAP32[$converter$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if (!($13)) {
      (FUNCTION_TABLE_iii[$12 & 4095]($p,$this)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
   }
   __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE15__insert_uniqueERKS3_($converter$i$i,$data,$p);
   $14 = (($i$01) + 1)|0;
   $15 = HEAP32[$size>>2]|0;
   $16 = ($14|0)<($15|0);
   if ($16) {
    $i$01 = $14;
   } else {
    break;
   }
  }
 }
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI10MonoScriptE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,600456,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,600472,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,600456,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,600472,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIP14ScriptingImageNS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    HEAP32[$10>>2] = 0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 4|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i57 = 0;$31 = 0;
  } else {
   $$0$i56 = $26;
   label = 9;
  }
 } else {
  $$0$i56 = 1073741823;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = $$0$i56 << 2;
  $29 = (__Znwj($28)|0);
  $$0$i57 = $$0$i56;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if ($32) {
   $35 = 0;
  } else {
   HEAP32[$33>>2] = 0;
   $35 = $33;
  }
  $34 = (($35) + 4|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $34;
  }
 }
 $38 = (($31) + ($$0$i57<<2)|0);
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = $40;
 $42 = $39;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 2;
 $$sum = (($18) - ($44))|0;
 $45 = (($31) + ($$sum<<2)|0);
 _memcpy(($45|0),($39|0),($43|0))|0;
 HEAP32[$this>>2] = $45;
 HEAP32[$2>>2] = $34;
 HEAP32[$0>>2] = $38;
 $46 = ($39|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZdlPv($39);
 STACKTOP = sp;return;
}
function __ZN11ICallStringC2EPv($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $handle;
 STACKTOP = sp;return;
}
function __ZNK11ICallString6IsNullEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK11ICallString6AsUTF8Ev($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __Z24scripting_cpp_string_forP15ScriptingString($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __Z24scripting_cpp_string_forP15ScriptingString($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZN8LODGroup25RemoveFromCachedRenderersEP8Renderer($this,$renderer) {
 $this = $this|0;
 $renderer = $renderer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $i$04 = 0;
 while(1) {
  $7 = (($4) + ($i$04<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($renderer|0);
  $6 = (($i$04) + 1)|0;
  if ($9) {
   break;
  }
  $5 = ($6>>>0)<($1>>>0);
  if ($5) {
   $i$04 = $6;
  } else {
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
 $10 = (($1) + -1)|0;
 $11 = (($4) + ($10<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$7>>2] = $12;
 HEAP32[$0>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN8LODGroup23GetLODGroupIndexAndMaskEP8RendererPjS2_($this,$renderer,$outGroup,$outMask) {
 $this = $this|0;
 $renderer = $renderer|0;
 $outGroup = $outGroup|0;
 $outMask = $outMask|0;
 var $$mask$11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $mask$0$lcssa = 0, $mask$04 = 0, $mask$1$lcssa = 0, $mask$11 = 0, $r$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($renderer|0)==(0|0);
 if ($0) {
  $21 = 0;
 } else {
  $1 = (($renderer) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  $21 = $2;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $mask$0$lcssa = 0;
  HEAP32[$outMask>>2] = $mask$0$lcssa;
  $27 = (($this) + 56|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$outGroup>>2] = $28;
  STACKTOP = sp;return;
 }
 $8 = $4;
 $9 = $6;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 28)&-1;
 $i$03 = 0;$mask$04 = 0;
 while(1) {
  $12 = ((($6) + (($i$03*28)|0)|0) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   $mask$1$lcssa = $mask$04;
  } else {
   $15 = ((($6) + (($i$03*28)|0)|0) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = 1 << $i$03;
   $mask$11 = $mask$04;$r$02 = 0;
   while(1) {
    $18 = (($16) + ($r$02<<2)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($21|0);
    $22 = $20 ? $17 : 0;
    $$mask$11 = $mask$11 | $22;
    $23 = (($r$02) + 1)|0;
    $24 = ($23>>>0)<($13>>>0);
    if ($24) {
     $mask$11 = $$mask$11;$r$02 = $23;
    } else {
     $mask$1$lcssa = $$mask$11;
     break;
    }
   }
  }
  $25 = (($i$03) + 1)|0;
  $26 = ($25>>>0)<($11>>>0);
  if ($26) {
   $i$03 = $25;$mask$04 = $mask$1$lcssa;
  } else {
   $mask$0$lcssa = $mask$1$lcssa;
   break;
  }
 }
 HEAP32[$outMask>>2] = $mask$0$lcssa;
 $27 = (($this) + 56|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$outGroup>>2] = $28;
 STACKTOP = sp;return;
}
function __ZNK8LODGroup6GetLODEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($index*28)|0)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN8LODGroup17GetWorldSpaceSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0);
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $scale$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scale$i = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($1)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($scale$i,$2);
 $3 = Math_fround(HEAPF32[$scale$i>>2]);
 $4 = $3 < Math_fround(0.0);
 if ($4) {
  $5 = Math_fround(-$3);
  $11 = $5;
 } else {
  $11 = $3;
 }
 $6 = (($scale$i) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $7 < Math_fround(0.0);
 if ($8) {
  $9 = Math_fround(-$7);
  $12 = $9;
 } else {
  $12 = $7;
 }
 $10 = $11 < $12;
 $13 = $10 ? $12 : $11;
 $14 = (($scale$i) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = $15 < Math_fround(0.0);
 if ($16) {
  $17 = Math_fround(-$15);
  $19 = $17;
 } else {
  $19 = $15;
 }
 $18 = $13 < $19;
 $20 = $18 ? $19 : $13;
 $21 = (($this) + 40|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 STACKTOP = sp;return (Math_fround($23));
}
function __ZN15LODGroupManager13GetIDPoolSizeEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[600528>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __Z18GetLODGroupManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[600520>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z21GetLODGroupManagerPtrv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[600520>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z22CleanupLODGroupManagerv() {
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[600520>>2]|0;
 $3 = HEAP32[628400>>2]|0;
 $4 = ($2|0)==(0|0);
 do {
  if (!($4)) {
   $5 = HEAP32[600528>>2]|0;
   $6 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vii(2705,($5|0),($6|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = (($2) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)>(-1);
    if (!($11)) {
     break;
    }
    $12 = (($2) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($2) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    HEAP32[$0>>2] = $15;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($13,$$byval_copy4);
    HEAP32[$12>>2] = 0;
    break;
   }
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   $18 = (($2) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)>(-1);
   if (!($20)) {
    ___resumeException($16|0);
    // unreachable;
   }
   $21 = (($2) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($2) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$0>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($22|0),($$byval_copy4|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch(0|0)|0;
    $28 = tempRet0;
    ___clang_call_terminate($27);
    // unreachable;
   }
   HEAP32[$21>>2] = 0;
   ___resumeException($16|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy4);
 HEAP32[600520>>2] = 0;
 $29 = HEAP32[600528>>2]|0;
 $30 = HEAP32[628400>>2]|0;
 $31 = ($29|0)==(0|0);
 if ($31) {
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($29,$$byval_copy4);
  HEAP32[600528>>2] = 0;
  STACKTOP = sp;return;
 }
 $32 = (($29) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)>(-1);
 if (!($34)) {
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($29,$$byval_copy4);
  HEAP32[600528>>2] = 0;
  STACKTOP = sp;return;
 }
 $35 = HEAP32[$29>>2]|0;
 $36 = (($29) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$0>>2] = $37;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($35,$$byval_copy4);
 HEAP32[$29>>2] = 0;
 HEAP32[$1>>2] = $30;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($29,$$byval_copy4);
 HEAP32[600528>>2] = 0;
 STACKTOP = sp;return;
}
function __Z25InitializeLODGroupManagerv() {
 var $$0 = 0, $$01 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = HEAP32[628400>>2]|0;
 HEAP32[$1>>2] = $4;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 $5 = (__Znwj10MemLabelIdbiPKci(20,$$byval_copy5,0,16,600536,44)|0);
 $6 = HEAP32[628400>>2]|0;
 HEAP32[$2>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2706,($5|0),($$byval_copy5|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viiiiii(97,($5|0),($$byval_copy5|0),0,16,(600536|0),44);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   $41 = ___cxa_find_matching_catch(0|0)|0;
   $42 = tempRet0;
   ___clang_call_terminate($41);
   // unreachable;
  } else {
   $$0 = $36;$$01 = $35;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 HEAP32[600528>>2] = $5;
 $9 = HEAP32[628400>>2]|0;
 HEAP32[$3>>2] = $9;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 $10 = (__Znwj10MemLabelIdbiPKci(28,$$byval_copy5,1,16,600536,46)|0);
 $11 = HEAP32[628400>>2]|0;
 $12 = (($10) + 4|0);
 HEAP32[$12>>2] = 0;
 $13 = (($10) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (($10) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($10) + 16|0);
 HEAP32[$15>>2] = 0;
 $16 = HEAP32[600528>>2]|0;
 __THREW__ = 0;
 $17 = (invoke_ii(3243,($16|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  HEAP32[$10>>2] = $17;
  $20 = (($10) + 20|0);
  HEAPF32[$20>>2] = Math_fround(1.0);
  $21 = (($10) + 24|0);
  HEAP32[$21>>2] = 0;
  __THREW__ = 0;
  $22 = (invoke_ii(3244,($12|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   dest=$22+0|0; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[600520>>2] = $10;
   STACKTOP = sp;return;
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$15>>2]|0;
 $28 = ($27|0)>(-1);
 do {
  if ($28) {
   $29 = HEAP32[$12>>2]|0;
   $30 = HEAP32[$13>>2]|0;
   HEAP32[$0>>2] = $30;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($29|0),($$byval_copy5|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $33 = ___cxa_find_matching_catch(0|0)|0;
    $34 = tempRet0;
    ___clang_call_terminate($33);
    // unreachable;
   } else {
    HEAP32[$12>>2] = 0;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_viiiiii(97,($10|0),($$byval_copy5|0),1,16,(600536|0),46);
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 } else {
  $$0 = $26;$$01 = $25;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN15LODGroupManagerC2E10MemLabelId($this,$label) {
 $this = $this|0;
 $label = $label|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = 0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = HEAP32[600528>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_ii(3243,($6|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  HEAP32[$this>>2] = $7;
  $10 = (($this) + 20|0);
  HEAPF32[$10>>2] = Math_fround(1.0);
  $11 = (($this) + 24|0);
  HEAP32[$11>>2] = 0;
  __THREW__ = 0;
  $12 = (invoke_ii(3244,($1|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   dest=$12+0|0; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   STACKTOP = sp;return;
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $17 = HEAP32[$5>>2]|0;
 $18 = ($17|0)>(-1);
 if (!($18)) {
  ___resumeException($15|0);
  // unreachable;
 }
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $20;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($19|0),($$byval_copy|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 }
 HEAP32[$1>>2] = 0;
 ___resumeException($15|0);
 // unreachable;
}
function __ZN13dynamic_arrayIN15LODGroupManager16LODSelectionDataELj4EE9push_backEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 do {
  if ($7) {
   $8 = $5 << 1;
   $9 = ($8|0)==(0);
   $10 = $9 ? 1 : $8;
   $11 = ($6>>>0)<($10>>>0);
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*92)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,600536,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*92)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,600536,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*92)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($25) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($26*92)|0)|0);
 STACKTOP = sp;return ($28|0);
}
function __ZN15LODGroupManagerD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[600528>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 __THREW__ = 0;
 invoke_vii(2705,($1|0),($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($this) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>(-1);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  $8 = (($this) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = $11;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy1);
  HEAP32[$8>>2] = 0;
  STACKTOP = sp;return;
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $14 = (($this) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(-1);
 if (!($16)) {
  ___resumeException($12|0);
  // unreachable;
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$0>>2] = $20;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($18|0),($$byval_copy1|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 }
 HEAP32[$17>>2] = 0;
 ___resumeException($12|0);
 // unreachable;
}
function __ZN15LODGroupManager27CalculatePerspectiveLODMaskERKNS_16LODSelectionDataERK8Vector3fiifPhPf($selection,$position,$maximumLOD,$currentMask,$sqrScreenRelativeMetric,$output,$fade) {
 $selection = $selection|0;
 $position = $position|0;
 $maximumLOD = $maximumLOD|0;
 $currentMask = $currentMask|0;
 $sqrScreenRelativeMetric = Math_fround($sqrScreenRelativeMetric);
 $output = $output|0;
 $fade = $fade|0;
 var $$05 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0;
 var $7 = 0, $8 = Math_fround(0), $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($selection) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = $1&255;
  HEAP8[$output>>0] = $3;
  HEAPF32[$fade>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $4 = Math_fround(HEAPF32[$selection>>2]);
 $5 = Math_fround(HEAPF32[$position>>2]);
 $6 = Math_fround($4 - $5);
 $7 = (($selection) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($position) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 - $10);
 $12 = (($selection) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($position) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = Math_fround($6 * $6);
 $18 = Math_fround($11 * $11);
 $19 = Math_fround($17 + $18);
 $20 = Math_fround($16 * $16);
 $21 = Math_fround($19 + $20);
 $22 = Math_fround($21 * $sqrScreenRelativeMetric);
 HEAP8[$output>>0] = 0;
 HEAPF32[$fade>>2] = Math_fround(0.0);
 $23 = (($selection) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $22 > $24;
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($selection) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)>($maximumLOD|0);
 if ($28) {
  $$05 = $currentMask;$i$04 = $maximumLOD;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $29 = ((($selection) + ($i$04<<2)|0) + 20|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($30 * $30);
  $32 = ((($selection) + ($i$04<<2)|0) + 52|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = $22 < $31;
  if ($34) {
   break;
  }
  $59 = $$05 << 1;
  $60 = (($i$04) + 1)|0;
  $61 = ($60|0)<($27|0);
  if ($61) {
   $$05 = $59;$i$04 = $60;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
 $35 = $33 < Math_fround(0.0);
 if ($35) {
  $36 = $$05&255;
  HEAP8[$output>>0] = $36;
  $37 = ($i$04|0)>(0);
  if ($37) {
   $38 = (($i$04) + -1)|0;
   $39 = ((($selection) + ($38<<2)|0) + 20|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $46 = $40;
  } else {
   $41 = (($selection) + 84|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (Math_fround(__ZN8LODGroup17GetWorldSpaceSizeEv($42)));
   $46 = $43;
  }
  $44 = (Math_fround(Math_sqrt((Math_fround($22)))));
  $45 = Math_fround($44 - $46);
  $47 = Math_fround($30 - $46);
  $48 = Math_fround($45 / $47);
  HEAPF32[$fade>>2] = $48;
  STACKTOP = sp;return;
 }
 $49 = $33 > Math_fround(0.0);
 if (!($49)) {
  $58 = $$05&255;
  HEAP8[$output>>0] = $58;
  HEAPF32[$fade>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $50 = (Math_fround(Math_sqrt((Math_fround($22)))));
 $51 = Math_fround($30 - $50);
 $52 = $51 < $33;
 if ($52) {
  $53 = $$05 << 1;
  $54 = $53 | $$05;
  $55 = $54&255;
  HEAP8[$output>>0] = $55;
  $56 = Math_fround($51 / $33);
  HEAPF32[$fade>>2] = $56;
  STACKTOP = sp;return;
 } else {
  $57 = $$05&255;
  HEAP8[$output>>0] = $57;
  HEAPF32[$fade>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
}
function __ZNK15LODGroupManager17CalculateLODMasksERK17CullingParametersPhPf($this,$parameters,$outMasks,$outFades) {
 $this = $this|0;
 $parameters = $parameters|0;
 $outMasks = $outMasks|0;
 $outFades = $outFades|0;
 var $$05$i = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0);
 var $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $exitcond = 0, $exitcond16 = 0, $i$04$i = 0, $i$08 = 0, $i1$01 = 0, $screenRelativeMetric$0$i = Math_fround(0);
 var $screenRelativeMetric$0$in$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$parameters>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $4 = (($parameters) + 16|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = Math_fround($5 / Math_fround(360.0));
  $7 = Math_fround($6 * Math_fround(2.0));
  $8 = Math_fround($7 * Math_fround(3.14159274101257324219));
  $9 = Math_fround($8 * Math_fround(0.5));
  $10 = +$9;
  $11 = (+Math_tan((+$10)));
  $12 = Math_fround($11);
  $screenRelativeMetric$0$in$i = $12;
 } else {
  $2 = (($parameters) + 20|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $screenRelativeMetric$0$in$i = $3;
 }
 $screenRelativeMetric$0$i = Math_fround($screenRelativeMetric$0$in$i * Math_fround(2.0));
 $13 = (($this) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($screenRelativeMetric$0$i / $14);
 $16 = (($this) + 4|0);
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 HEAPF32[$outFades>>2] = Math_fround(0.0);
 $19 = (($this) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = 1 << $20;
 if ($1) {
  $62 = Math_fround($15 * $15);
  $63 = ($18|0)>(1);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  $64 = (($parameters) + 4|0);
  $69 = $20;$i1$01 = 1;
  while(1) {
   $65 = HEAP32[$16>>2]|0;
   $66 = (($65) + (($i1$01*92)|0)|0);
   $67 = (($outMasks) + ($i1$01)|0);
   $68 = (($outFades) + ($i1$01<<2)|0);
   __ZN15LODGroupManager27CalculatePerspectiveLODMaskERKNS_16LODSelectionDataERK8Vector3fiifPhPf($66,$64,$69,$21,$62,$67,$68);
   $70 = (($i1$01) + 1)|0;
   $exitcond = ($70|0)==($18|0);
   if ($exitcond) {
    break;
   }
   $$pre = HEAP32[$19>>2]|0;
   $69 = $$pre;$i1$01 = $70;
  }
  STACKTOP = sp;return;
 }
 $22 = ($18|0)>(1);
 if (!($22)) {
  STACKTOP = sp;return;
 }
 $33 = $20;$i$08 = 1;
 while(1) {
  $23 = HEAP32[$16>>2]|0;
  $24 = (($outMasks) + ($i$08)|0);
  $25 = (($outFades) + ($i$08<<2)|0);
  $26 = ((($23) + (($i$08*92)|0)|0) + 88|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0);
  L20: do {
   if ($28) {
    HEAP8[$24>>0] = 0;
    HEAPF32[$25>>2] = Math_fround(0.0);
    $30 = ((($23) + (($i$08*92)|0)|0) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)>($33|0);
    if ($32) {
     $$05$i = $21;$i$04$i = $33;
     while(1) {
      $34 = (((($23) + (($i$08*92)|0)|0) + ($i$04$i<<2)|0) + 20|0);
      $35 = Math_fround(HEAPF32[$34>>2]);
      $36 = (((($23) + (($i$08*92)|0)|0) + ($i$04$i<<2)|0) + 52|0);
      $37 = Math_fround(HEAPF32[$36>>2]);
      $38 = $35 > $15;
      if ($38) {
       break;
      }
      $58 = $$05$i << 1;
      $59 = (($i$04$i) + 1)|0;
      $60 = ($59|0)<($31|0);
      if ($60) {
       $$05$i = $58;$i$04$i = $59;
      } else {
       break L20;
      }
     }
     $39 = $37 < Math_fround(0.0);
     if ($39) {
      $40 = $$05$i&255;
      HEAP8[$24>>0] = $40;
      $41 = ($i$04$i|0)>(0);
      if ($41) {
       $42 = (($i$04$i) + -1)|0;
       $43 = (((($23) + (($i$08*92)|0)|0) + ($42<<2)|0) + 20|0);
       $44 = Math_fround(HEAPF32[$43>>2]);
       $46 = $44;
      } else {
       $46 = Math_fround(0.0);
      }
      $45 = Math_fround($15 - $46);
      $47 = Math_fround($35 - $46);
      $48 = Math_fround($45 / $47);
      HEAPF32[$25>>2] = $48;
      break;
     }
     $49 = $37 > Math_fround(0.0);
     if (!($49)) {
      $57 = $$05$i&255;
      HEAP8[$24>>0] = $57;
      HEAPF32[$25>>2] = Math_fround(0.0);
      break;
     }
     $50 = Math_fround($35 - $15);
     $51 = $50 < $37;
     if ($51) {
      $52 = $$05$i << 1;
      $53 = $52 | $$05$i;
      $54 = $53&255;
      HEAP8[$24>>0] = $54;
      $55 = Math_fround($50 / $37);
      HEAPF32[$25>>2] = $55;
      break;
     } else {
      $56 = $$05$i&255;
      HEAP8[$24>>0] = $56;
      HEAPF32[$25>>2] = Math_fround(0.0);
      break;
     }
    }
   } else {
    $29 = $27&255;
    HEAP8[$24>>0] = $29;
    HEAPF32[$25>>2] = Math_fround(0.0);
   }
  } while(0);
  $61 = (($i$08) + 1)|0;
  $exitcond16 = ($61|0)==($18|0);
  if ($exitcond16) {
   break;
  }
  $$pre17 = HEAP32[$19>>2]|0;
  $33 = $$pre17;$i$08 = $61;
 }
 STACKTOP = sp;return;
}
function __ZN15LODGroupManager16CalculateLODFadeEjjPKhPKf($lodGroupIndex,$rendererActiveLODMask,$lodMasks,$lodFades) {
 $lodGroupIndex = $lodGroupIndex|0;
 $rendererActiveLODMask = $rendererActiveLODMask|0;
 $lodMasks = $lodMasks|0;
 $lodFades = $lodFades|0;
 var $$$i$i = Math_fround(0), $$$i$i2 = Math_fround(0), $$0 = Math_fround(0), $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $table$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $table$i = sp;
 $0 = ($rendererActiveLODMask|0)==(0);
 if ($0) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $1 = (($lodMasks) + ($lodGroupIndex)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 >>> 1;
 $5 = $4 & 85;
 $6 = (($3) - ($5))|0;
 $7 = $6 & 858993459;
 $8 = $6 >>> 2;
 $9 = $8 & 858993459;
 $10 = (($9) + ($7))|0;
 $11 = $10 >>> 4;
 $12 = (($11) + ($10))|0;
 $13 = $12 & 252645135;
 $14 = Math_imul($13, 16843009)|0;
 $$mask = $14 & -16777216;
 $15 = ($$mask|0)==(16777216);
 $16 = $3 & $rendererActiveLODMask;
 $17 = ($16|0)==($3|0);
 if ($17) {
  if (!($15)) {
   $$0 = Math_fround(0.0);
   STACKTOP = sp;return (Math_fround($$0));
  }
  $18 = (($lodFades) + ($lodGroupIndex<<2)|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = $19 != Math_fround(0.5);
  if ($20) {
   $21 = $19 < Math_fround(0.0);
   if ($21) {
    $24 = Math_fround(0.0);
   } else {
    $22 = $19 > Math_fround(0.999000012874603271484);
    $$$i$i2 = $22 ? Math_fround(0.999000012874603271484) : $19;
    $24 = $$$i$i2;
   }
  } else {
   $24 = Math_fround(0.499000012874603271484);
  }
  $23 = Math_fround(-$24);
  $$0 = $23;
  STACKTOP = sp;return (Math_fround($$0));
 }
 $25 = (($3) + 255)|0;
 $26 = $25 & $3;
 $27 = ($26|0)==(0);
 $28 = $27&1;
 $29 = $4 | $3;
 $30 = $29 >>> 2;
 $31 = $30 | $29;
 $32 = $31 >>> 4;
 $33 = $32 | $31;
 $34 = (($33) + 1)|0;
 $35 = $34 >>> 2;
 HEAP32[$table$i>>2] = $35;
 $36 = (($table$i) + 4|0);
 $37 = $34 >>> 1;
 HEAP32[$36>>2] = $37;
 $38 = (($table$i) + ($28<<2)|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39 & $rendererActiveLODMask;
 $41 = ($40|0)==(0);
 $42 = (($lodFades) + ($lodGroupIndex<<2)|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 if ($41) {
  $44 = Math_fround(Math_fround(1.0) - $43);
  $46 = $44;
 } else {
  $46 = $43;
 }
 $45 = $46 != Math_fround(0.5);
 if ($45) {
  $47 = $46 < Math_fround(0.0);
  if ($47) {
   $50 = Math_fround(0.0);
  } else {
   $48 = $46 > Math_fround(0.999000012874603271484);
   $$$i$i = $48 ? Math_fround(0.999000012874603271484) : $46;
   $50 = $$$i$i;
  }
 } else {
  $50 = Math_fround(0.499000012874603271484);
 }
 if (!($15)) {
  $$0 = $50;
  STACKTOP = sp;return (Math_fround($$0));
 }
 $49 = Math_fround(-$50);
 $$0 = $49;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN15LODGroupManager11AddLODGroupER8LODGroupRK8Vector3f($this,$group,$position) {
 $this = $this|0;
 $group = $group|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 (__ZN13dynamic_arrayIN15LODGroupManager16LODSelectionDataELj4EE9push_backEv($0)|0);
 $3 = (Math_fround(__ZN8LODGroup17GetWorldSpaceSizeEv($group)));
 __ZN15LODGroupManager24UpdateLODGroupParametersEiR8LODGroupRK8Vector3ff($this,$2,$group,$position,$3);
 $4 = HEAP32[$1>>2]|0;
 $5 = (($4) + -1)|0;
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($6) + (($5*92)|0)|0) + 88|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return ($2|0);
}
function __ZN15LODGroupManager24UpdateLODGroupParametersEiR8LODGroupRK8Vector3ff($this,$index,$group,$position,$worldSpaceSize) {
 $this = $this|0;
 $index = $index|0;
 $group = $group|0;
 $position = $position|0;
 $worldSpaceSize = Math_fround($worldSpaceSize);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($index*92)|0)|0);
 ;HEAP32[$2+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$position+8>>2]|0;
 $3 = ((($1) + (($index*92)|0)|0) + 84|0);
 HEAP32[$3>>2] = $group;
 $4 = (($group) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($group) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 28)&-1;
 $12 = ((($1) + (($index*92)|0)|0) + 16|0);
 HEAP32[$12>>2] = $11;
 $13 = ((($1) + (($index*92)|0)|0) + 12|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (__Z16GetBuildSettingsv()|0);
 $15 = (($14) + 94|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $25 = HEAP32[$12>>2]|0;
  $26 = ($25|0)>(1);
  $27 = $26 ? $25 : 1;
  HEAP32[$12>>2] = $27;
  $28 = Math_fround($worldSpaceSize / Math_fround(9.99999974737875163555E-5));
  $29 = ((($1) + (($index*92)|0)|0) + 20|0);
  HEAPF32[$29>>2] = $28;
  $30 = ((($1) + (($index*92)|0)|0) + 52|0);
  HEAPF32[$30>>2] = Math_fround(0.0);
  $62 = $28;
  $61 = Math_fround($62 * $62);
  HEAPF32[$13>>2] = $61;
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$4>>2]|0;
 $19 = HEAP32[$6>>2]|0;
 $20 = ($18|0)==($19|0);
 if ($20) {
  $62 = Math_fround(0.0);
  $61 = Math_fround($62 * $62);
  HEAPF32[$13>>2] = $61;
  STACKTOP = sp;return;
 }
 $21 = $18;
 $22 = $19;
 $23 = (($21) - ($22))|0;
 $24 = (($23|0) / 28)&-1;
 $35 = Math_fround(0.0);$i$01 = 0;
 while(1) {
  $31 = (($19) + (($i$01*28)|0)|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($worldSpaceSize / $32);
  $34 = $33 < $35;
  $36 = $34 ? $35 : $33;
  $37 = (((($1) + (($index*92)|0)|0) + ($i$01<<2)|0) + 20|0);
  HEAPF32[$37>>2] = $33;
  $38 = ((($19) + (($i$01*28)|0)|0) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(2);
  do {
   if ($40) {
    $41 = ((($19) + (($i$01*28)|0)|0) + 8|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = $42 > Math_fround(9.99999974737875163555E-6);
    if (!($43)) {
     $44 = (((($1) + (($index*92)|0)|0) + ($i$01<<2)|0) + 52|0);
     $58 = $44;
     label = 13;
     break;
    }
    $45 = ($i$01|0)==(0);
    if ($45) {
     $50 = Math_fround(1.0);
    } else {
     $46 = (($i$01) + -1)|0;
     $47 = (($19) + (($46*28)|0)|0);
     $48 = Math_fround(HEAPF32[$47>>2]);
     $50 = $48;
    }
    $49 = Math_fround($50 - $32);
    $51 = Math_fround($49 * $42);
    $52 = Math_fround($32 + $51);
    $53 = Math_fround($worldSpaceSize / $52);
    $54 = Math_fround($33 - $53);
    $55 = (((($1) + (($index*92)|0)|0) + ($i$01<<2)|0) + 52|0);
    HEAPF32[$55>>2] = $54;
   } else {
    $56 = ($39|0)==(1);
    $57 = (((($1) + (($index*92)|0)|0) + ($i$01<<2)|0) + 52|0);
    if ($56) {
     HEAPF32[$57>>2] = Math_fround(-1.0);
    } else {
     $58 = $57;
     label = 13;
    }
   }
  } while(0);
  if ((label|0) == 13) {
   label = 0;
   HEAPF32[$58>>2] = Math_fround(0.0);
  }
  $59 = (($i$01) + 1)|0;
  $60 = ($59>>>0)<($24>>>0);
  if ($60) {
   $35 = $36;$i$01 = $59;
  } else {
   $62 = $36;
   break;
  }
 }
 $61 = Math_fround($62 * $62);
 HEAPF32[$13>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN15LODGroupManager20ReserveInternalArrayEi($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)<($size>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = ($3|0)>(-1);
 if ($6) {
  HEAP32[$2>>2] = $size;
  $7 = HEAP32[$1>>2]|0;
  $8 = ($size*92)|0;
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $11 = (__Z16realloc_internalPvji10MemLabelIdiPKci($7,$8,4,$$byval_copy1,0,600536,370)|0);
  HEAP32[$1>>2] = $11;
  STACKTOP = sp;return;
 } else {
  $12 = ($size*92)|0;
  $13 = (($this) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$0>>2] = $14;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $15 = (__Z15malloc_internaljj10MemLabelIdiPKci($12,4,$$byval_copy1,0,600536,352)|0);
  $16 = HEAP32[$1>>2]|0;
  $17 = (($this) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18*92)|0;
  _memcpy(($15|0),($16|0),($19|0))|0;
  HEAP32[$2>>2] = $size;
  HEAP32[$1>>2] = $15;
  STACKTOP = sp;return;
 }
}
function __ZN15LODGroupManager18ClearInternalArrayEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 1;
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = ($5|0)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = ($4|0)>(-1);
 if ($7) {
  HEAP32[$3>>2] = 1;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $11 = (__Z16realloc_internalPvji10MemLabelIdiPKci($8,92,4,$$byval_copy1,0,600536,370)|0);
  HEAP32[$1>>2] = $11;
  STACKTOP = sp;return;
 } else {
  $12 = (($this) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$0>>2] = $13;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $14 = (__Z15malloc_internaljj10MemLabelIdiPKci(92,4,$$byval_copy1,0,600536,352)|0);
  $15 = HEAP32[$1>>2]|0;
  $16 = HEAP32[$2>>2]|0;
  $17 = ($16*92)|0;
  _memcpy(($14|0),($15|0),($17|0))|0;
  HEAP32[$3>>2] = 1;
  HEAP32[$1>>2] = $14;
  STACKTOP = sp;return;
 }
}
function __ZN7CubemapC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN9Texture2DC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((600544 + 8|0));
 $2 = (($this) + 136|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 140|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 144|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2707,($2|0),6);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $9 = HEAP32[$2>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$3>>2]|0;
  $12 = ($11|0)==($9|0);
  if (!($12)) {
   $__new_last2$i$i$i$i$i = $9;
   $scevgep$i$i$i$i$i = (($11) + -4|0);
   $13 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($13)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $14 = $uglygep3$i$i$i$i$i >>> 2;
   $15 = $14 ^ -1;
   $scevgep4$i$i$i$i$i = (($11) + ($15<<2)|0);
   HEAP32[$3>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($9);
 }
 __THREW__ = 0;
 invoke_vi(3478,($this|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN9Texture2DD2Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$01$i = 0, $$01$i3 = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((608208 + 8|0));
 __THREW__ = 0;
 invoke_vi(3479,($this|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  HEAP32[$this>>2] = ((608008 + 8|0));
  __THREW__ = 0;
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  do {
   if ($5) {
    $15 = ___cxa_find_matching_catch()|0;
    $16 = tempRet0;
    $17 = (($this) + 92|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)>(-1);
    if ($19) {
     $20 = (($this) + 80|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($this) + 84|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($21|0),($$byval_copy8|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      $30 = ___cxa_find_matching_catch(0|0)|0;
      $31 = tempRet0;
      ___clang_call_terminate($30);
      // unreachable;
     } else {
      HEAP32[$20>>2] = 0;
      $$0$i = $16;$$01$i = $15;
      break;
     }
    } else {
     $$0$i = $16;$$01$i = $15;
    }
   } else {
    $6 = (($this) + 92|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)>(-1);
    if (!($8)) {
     __ZN11NamedObjectD2Ev($this);
     STACKTOP = sp;return;
    }
    $9 = (($this) + 80|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($this) + 84|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$1>>2] = $12;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($10|0),($$byval_copy8|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $26 = ___cxa_find_matching_catch()|0;
     $27 = tempRet0;
     $$0$i = $27;$$01$i = $26;
     break;
    }
    HEAP32[$9>>2] = 0;
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
  } while(0);
  __THREW__ = 0;
  invoke_vi(3423,($this|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $30 = ___cxa_find_matching_catch(0|0)|0;
   $31 = tempRet0;
   ___clang_call_terminate($30);
   // unreachable;
  } else {
   ___resumeException($$01$i|0);
   // unreachable;
  }
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 HEAP32[$this>>2] = ((608008 + 8|0));
 __THREW__ = 0;
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 L22: do {
  if ($35) {
   $47 = ___cxa_find_matching_catch(0|0)|0;
   $48 = tempRet0;
   $49 = (($this) + 92|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)>(-1);
   if ($51) {
    $52 = (($this) + 80|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($this) + 84|0);
    $55 = HEAP32[$54>>2]|0;
    HEAP32[$0>>2] = $55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($53|0),($$byval_copy8|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $62 = ___cxa_find_matching_catch(0|0)|0;
     $63 = tempRet0;
     ___clang_call_terminate($62);
     // unreachable;
    } else {
     HEAP32[$52>>2] = 0;
     $$01$i3 = $47;
     break;
    }
   } else {
    $$01$i3 = $47;
   }
  } else {
   $36 = (($this) + 92|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)>(-1);
   do {
    if ($38) {
     $39 = (($this) + 80|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($this) + 84|0);
     $42 = HEAP32[$41>>2]|0;
     HEAP32[$1>>2] = $42;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($40|0),($$byval_copy8|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      $58 = ___cxa_find_matching_catch(0|0)|0;
      $59 = tempRet0;
      $$01$i3 = $58;
      break L22;
     } else {
      HEAP32[$39>>2] = 0;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    ___resumeException($32|0);
    // unreachable;
   }
   $64 = ___cxa_find_matching_catch(0|0)|0;
   $65 = tempRet0;
   $eh$lpad$body$indexZ2D = $64;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 if ($61) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 }
 $eh$lpad$body$indexZ2D = $$01$i3;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN7Cubemap11InitTextureEii13TextureFormatiii($this,$width,$height,$format,$flags,$imageCount,$nativeTex) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $flags = $flags|0;
 $imageCount = $imageCount|0;
 $nativeTex = $nativeTex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($width) + -1)|0;
 $1 = $0 & $width;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($height) + -1)|0;
  $4 = $3 & $height;
  $5 = ($4|0)==(0);
  if ($5) {
   $10 = ($width|0)==($height|0);
   if ($10) {
    $15 = (__ZN9Texture2D11InitTextureEii13TextureFormatiii($this,$width,$width,$format,$flags,6,$nativeTex)|0);
    $$0 = $15;
    STACKTOP = sp;return ($$0|0);
   }
   $11 = ($this|0)==(0|0);
   if ($11) {
    $14 = 0;
   } else {
    $12 = (($this) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = $13;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(600768,0,600760,32,1,$14,0,0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $6 = ($this|0)==(0|0);
 if ($6) {
  $9 = 0;
 } else {
  $7 = (($this) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(600720,0,600760,27,1,$9,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7Cubemap13UploadTextureEb($this,$dontUseSubImage) {
 $this = $this|0;
 $dontUseSubImage = $dontUseSubImage|0;
 var $$byval_copy2 = 0, $$pr10 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, $phitmp11 = 0, $uploadFlags$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 116|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($this)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 120|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($this)|0);
 $11 = ($6|0)==($10|0);
 $12 = (($this) + 48|0);
 if ($11) {
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   label = 5;
  } else {
   $15 = (($13) + 40|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(6);
   if ($17) {
    $18 = (($this) + 48|0);
    $$pr10 = $13;$104 = $18;
    label = 6;
   } else {
    label = 5;
   }
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(600800,0,600760,44,1,0,0,0);
  $$pre = HEAP32[$12>>2]|0;
  $19 = (($this) + 48|0);
  $20 = ($$pre|0)==(0|0);
  if ($20) {
   $27 = 0;$28 = 0;$31 = 0;$45 = $19;
  } else {
   $$pr10 = $$pre;$104 = $19;
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $21 = (($$pr10) + 36|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($$pr10) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + ($22)|0);
  $phitmp = $24;
  $phitmp11 = $25;
  $27 = $phitmp11;$28 = $phitmp;$31 = $$pr10;$45 = $104;
 }
 $26 = (($27) - ($28))|0;
 $29 = ($26*6)|0;
 $30 = (($31) + 4|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = (($32) + 1)|0;
 HEAP32[$30>>2] = $33;
 $34 = HEAP32[$30>>2]|0;
 if ($dontUseSubImage) {
  label = 9;
 } else {
  $35 = (($this) + 125|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   label = 9;
  } else {
   $uploadFlags$0 = 1;
  }
 }
 if ((label|0) == 9) {
  $uploadFlags$0 = 3;
 }
 $38 = (__Z21GetUncheckedGfxDevicev()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 480|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($this) + 44|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$1>>2] = $43;
 $44 = HEAP32[$45>>2]|0;
 $46 = ($44|0)==(0|0);
 if ($46) {
  $65 = 0;
 } else {
  $47 = (($44) + 8|0);
  $48 = HEAP32[$47>>2]|0;
  $65 = $48;
 }
 $49 = HEAP32[$this>>2]|0;
 $50 = (($49) + 116|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (FUNCTION_TABLE_ii[$51 & 4095]($this)|0);
 $53 = HEAP32[$45>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  $66 = 5;
 } else {
  $55 = (($53) + 32|0);
  $56 = HEAP32[$55>>2]|0;
  $66 = $56;
 }
 $57 = HEAP32[$this>>2]|0;
 $58 = (($57) + 128|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (FUNCTION_TABLE_ii[$59 & 4095]($this)|0);
 $61 = (__Z19GetActiveColorSpacev()|0);
 $62 = ($61|0)==(1);
 if ($62) {
  $63 = (($this) + 56|0);
  $64 = HEAP32[$63>>2]|0;
  $67 = $64;
 } else {
  $67 = 0;
 }
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_viiiiiiiiii[$41 & 15]($38,$$byval_copy2,$65,$29,$26,$52,$66,$60,$uploadFlags$0,$67);
 $68 = HEAP32[$38>>2]|0;
 $69 = (($68) + 364|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_vii[$70 & 4095]($38,$71);
 $72 = HEAP32[$42>>2]|0;
 $73 = $this;
 $74 = $0;
 $75 = $74;
 HEAP32[$75>>2] = $72;
 $76 = (($74) + 4)|0;
 $77 = $76;
 HEAP32[$77>>2] = $73;
 __ZNSt3__16__treeINS_12__value_typeI9TextureIDP7TextureEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($$byval_copy2,607992,$0);
 $78 = (($this) + 40|0);
 HEAP32[$78>>2] = 1;
 $79 = HEAP32[$this>>2]|0;
 $80 = (($79) + 132|0);
 $81 = HEAP32[$80>>2]|0;
 FUNCTION_TABLE_vi[$81 & 4095]($this);
 $82 = (($this) + 125|0);
 HEAP8[$82>>0] = 1;
 $83 = (__Z12GetGfxDevicev()|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($84) + 648|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = HEAP32[$42>>2]|0;
 HEAP32[$2>>2] = $87;
 $88 = HEAP32[$this>>2]|0;
 $89 = (($88) + 32|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = (FUNCTION_TABLE_ii[$90 & 4095]($this)|0);
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 FUNCTION_TABLE_viii[$86 & 4095]($83,$$byval_copy2,$91);
 $92 = (($this) + 127|0);
 $93 = HEAP8[$92>>0]|0;
 $94 = ($93<<24>>24)==(0);
 if (!($94)) {
  STACKTOP = sp;return;
 }
 $95 = HEAP32[$45>>2]|0;
 $96 = HEAP32[628264>>2]|0;
 $97 = (($95) + 4|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (($98) + -1)|0;
 HEAP32[$97>>2] = $99;
 $100 = HEAP32[$97>>2]|0;
 $101 = ($100|0)==(0);
 if ($101) {
  $102 = HEAP32[$95>>2]|0;
  $103 = HEAP32[$102>>2]|0;
  FUNCTION_TABLE_vi[$103 & 4095]($95);
  HEAP32[$0>>2] = $96;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($95,$$byval_copy2);
 }
 HEAP32[$45>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7Cubemap13RebuildMipMapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0;
 var $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $9 = 5;
 } else {
  $7 = (($5) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8;
 }
 $format$off$i$i = (($9) + -10)|0;
 $10 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($9) + -30)|0;
 $11 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $10 | $11;
 $12 = ($9|0)==(34);
 $or$cond7$i = $or$cond$i | $12;
 $format$off$i4$i = (($9) + -35)|0;
 $13 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $13;
 $format$off$i3$i = (($9) + -41)|0;
 $14 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $14;
 $format$off$i2$i = (($9) + -45)|0;
 $15 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $15;
 $format$off$i1$i = (($9) + -48)|0;
 $16 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $16;
 if ($or$cond) {
  $17 = ($this|0)==(0|0);
  if ($17) {
   $20 = 0;
  } else {
   $18 = (($this) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = $19;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(600856,0,600760,161,1,$20,0,0);
  STACKTOP = sp;return;
 }
 if (!($6)) {
  $21 = (($5) + 40|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(6);
  if ($23) {
   __ZN9Texture2D18UnshareTextureDataEv($this);
   $26 = HEAP32[$4>>2]|0;
   $27 = (($26) + 24|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($26) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   __Z12CreateMipMapPhiii13TextureFormat($30,$28,$28,1,$32);
   $33 = HEAP32[$4>>2]|0;
   $34 = (($33) + 36|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + ($35)|0);
   $39 = (($33) + 32|0);
   $40 = HEAP32[$39>>2]|0;
   __Z12CreateMipMapPhiii13TextureFormat($38,$28,$28,1,$40);
   $41 = HEAP32[$4>>2]|0;
   $42 = (($41) + 36|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = $43 << 1;
   $45 = (($41) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($46) + ($44)|0);
   $48 = (($41) + 32|0);
   $49 = HEAP32[$48>>2]|0;
   __Z12CreateMipMapPhiii13TextureFormat($47,$28,$28,1,$49);
   $50 = HEAP32[$4>>2]|0;
   $51 = (($50) + 36|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52*3)|0;
   $54 = (($50) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($55) + ($53)|0);
   $57 = (($50) + 32|0);
   $58 = HEAP32[$57>>2]|0;
   __Z12CreateMipMapPhiii13TextureFormat($56,$28,$28,1,$58);
   $59 = HEAP32[$4>>2]|0;
   $60 = (($59) + 36|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = $61 << 2;
   $63 = (($59) + 8|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + ($62)|0);
   $66 = (($59) + 32|0);
   $67 = HEAP32[$66>>2]|0;
   __Z12CreateMipMapPhiii13TextureFormat($65,$28,$28,1,$67);
   $68 = HEAP32[$4>>2]|0;
   $69 = (($68) + 36|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70*5)|0;
   $72 = (($68) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($73) + ($71)|0);
   $75 = (($68) + 32|0);
   $76 = HEAP32[$75>>2]|0;
   __Z12CreateMipMapPhiii13TextureFormat($74,$28,$28,1,$76);
   STACKTOP = sp;return;
  }
 }
 $24 = (($this) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(600920,0,600760,166,1,$25,0,0);
 STACKTOP = sp;return;
}
function __Z21RegisterClass_Cubemapv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(89,124,0,0,0);
 STACKTOP = sp;return;
}
function __ZN7Cubemap13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(28)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Texture2D13RegisterClassEv();
 }
 HEAP8[$0>>0] = 14;
 $3 = (($0) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[600952+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[600952+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[600952+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[600952+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[600952+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[600952+5>>0]|0;HEAP8[$3+6>>0]=HEAP8[600952+6>>0]|0;
 $4 = (($0) + 8|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,89,28,($0|0),148,(2394|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $13 = HEAP8[$0>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   ___resumeException($11|0);
   // unreachable;
  }
  $16 = HEAP32[$4>>2]|0;
  __ZdlPv($16);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = HEAP32[$4>>2]|0;
  __ZdlPv($10);
  STACKTOP = sp;return;
 }
}
function __ZN7Cubemap7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(148,$$byval_copy7,1,16,600760,10)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1733,($3|0),($$byval_copy7|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  $eh$lpad$body$index2Z2D = $25;$eh$lpad$body$indexZ2D = $24;
 } else {
  HEAP32[$3>>2] = ((600544 + 8|0));
  $6 = (($3) + 136|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 140|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 144|0);
  HEAP32[$8>>2] = 0;
  __THREW__ = 0;
  invoke_vii(2707,($6|0),6);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   STACKTOP = sp;return ($3|0);
  }
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $13 = HEAP32[$6>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = HEAP32[$7>>2]|0;
   $16 = ($15|0)==($13|0);
   if (!($16)) {
    $__new_last2$i$i$i$i$i$i = $13;
    $scevgep$i$i$i$i$i$i = (($15) + -4|0);
    $17 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($17)|0);
    $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
    $18 = $uglygep3$i$i$i$i$i$i >>> 2;
    $19 = $18 ^ -1;
    $scevgep4$i$i$i$i$i$i = (($15) + ($19<<2)|0);
    HEAP32[$7>>2] = $scevgep4$i$i$i$i$i$i;
   }
   __ZdlPv($13);
  }
  __THREW__ = 0;
  invoke_vi(3478,($3|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $22 = ___cxa_find_matching_catch(0|0)|0;
   $23 = tempRet0;
   ___clang_call_terminate($22);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $12;$eh$lpad$body$indexZ2D = $11;
  }
 }
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy7|0),1,16,(600760|0),10);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK7Cubemap25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 89;
}
function __ZN7Cubemap23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i$i = 0;
 var $p$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 $size$i$i$i = sp + 20|0;
 $p$i$i = sp + 16|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,600960,600952,$this,0);
 __ZN9Texture2D8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 136|0);
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,600968,$1,$0,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,601032,601032,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,600992,601040,$p$i$i,0);
 $2 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $7 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,601000,$7,$p$i$i,1);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($10) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,601016,$14,$2,1);
 $15 = HEAP32[$8>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$11>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Cubemap23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i$i = sp + 4|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,600960,600952,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9Texture2D8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  $3 = (($this) + 136|0);
  $4 = HEAP32[580760>>2]|0;
  $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,600968,$4,$converter$i$i$i$i,1)|0);
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = ($5|0)>(0);
   if ($7) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI9Texture2DENS1_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$3,0);
   } else {
    $8 = HEAP32[$converter$i$i$i$i>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     (FUNCTION_TABLE_iii[$8 & 4095]($3,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $10 = HEAP32[$converter$i$i>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   (FUNCTION_TABLE_iii[$10 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Cubemap23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture2D8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 136|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI9Texture2DENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Cubemap23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture2D8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 136|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI9Texture2DENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Cubemap23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $size$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i = sp;
 __ZN9Texture2D8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 HEAP32[$size$i$i$i$i$i$i>>2] = $7;
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i$i$i$i,4);
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==($14|0);
 if ($16) {
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $17 = $15;
 }
 while(1) {
  __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($17,$transfer);
  $18 = (($17) + 4|0);
  $19 = ($18|0)==($14|0);
  if ($19) {
   break;
  } else {
   $17 = $18;
  }
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Cubemap23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN9Texture2D8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 140|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($transfer) + 12|0);
 $6 = (($transfer) + 28|0);
 $7 = (($transfer) + 32|0);
 $9 = $1;
 while(1) {
  $8 = HEAP32[$9>>2]|0;
  $10 = HEAP32[$5>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$6>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($10,$8,$13)|0);
  $15 = HEAP8[$7>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   HEAP32[$9>>2] = $14;
  }
  $17 = (($9) + 4|0);
  $18 = ($17|0)==($3|0);
  if ($18) {
   break;
  } else {
   $9 = $17;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7CubemapD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__new_last2$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((600544 + 8|0));
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Texture2DD2Ev($this);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if (!($5)) {
  $__new_last2$i$i$i$i$i$i = $1;
  $scevgep$i$i$i$i$i$i = (($4) + -4|0);
  $6 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($6)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $7 = $uglygep3$i$i$i$i$i$i >>> 2;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($4) + ($8<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i;
 }
 __ZdlPv($1);
 __ZN9Texture2DD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN7CubemapD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((600544 + 8|0));
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 140|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if (!($5)) {
   $__new_last2$i$i$i$i$i$i$i = $1;
   $scevgep$i$i$i$i$i$i$i = (($4) + -4|0);
   $6 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($6)|0);
   $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
   $7 = $uglygep3$i$i$i$i$i$i$i >>> 2;
   $8 = $7 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($4) + ($8<<2)|0);
   HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  __ZdlPv($1);
 }
 __THREW__ = 0;
 invoke_vi(3478,($this|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZdlPv($this);
  ___resumeException($11|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK7Cubemap12GetDimensionEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 4;
}
function __ZNK9Texture2D10GetGLWidthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK9Texture2D11GetGLHeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK7Texture9HasMipMapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI9Texture2DENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4PPtrI9Texture2DENS0_9allocatorIS4_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI4PPtrI9Texture2DENS0_9allocatorIS4_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$idx = 0, $$pre54 = 0, $$pre55 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i30 = 0, $__new_last2$i$i$i$i$i39 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i31 = 0, $scevgep$i$i$i$i$i40 = 0, $scevgep$i$i$i17 = 0, $scevgep4$i$i$i$i$i35 = 0, $scevgep4$i$i$i$i$i44 = 0;
 var $scevgep4$i$i$i19 = 0, $scevgep8$i$i$i = 0, $scevgep8$i$i$i52 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i42 = 0, $uglygep$i$i$i18 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i34 = 0, $uglygep3$i$i$i$i$i43 = 0, $uglygep6$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($sz>>>0);
 if (!($9)) {
  $63 = ($8>>>0)>($sz>>>0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  $64 = (($4) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $65 = $$idx >> 2;
  $66 = ($65|0)==(0);
  if ($66) {
   $81 = 0;$83 = 0;$scevgep8$i$i$i52 = 0;
  } else {
   $67 = ($65>>>0)>(1073741823);
   if ($67) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $68 = (__Znwj($$idx)|0);
   $69 = (($68) + ($65<<2)|0);
   $70 = ($sz|0)==(0);
   if ($70) {
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $68;
   } else {
    $$sum = (($sz) + -1)|0;
    $scevgep$i$i$i = (($4) + ($$sum<<2)|0);
    $71 = (0 - ($6))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($71)|0);
    $73 = $68;$75 = $4;
    while(1) {
     $72 = ($73|0)==(0|0);
     if (!($72)) {
      $74 = HEAP32[$75>>2]|0;
      HEAP32[$73>>2] = $74;
     }
     $76 = (($73) + 4|0);
     $77 = (($75) + 4|0);
     $78 = ($77|0)==($64|0);
     if ($78) {
      break;
     } else {
      $73 = $76;$75 = $77;
     }
    }
    $uglygep6$i$i$i = $uglygep$i$i$i;
    $79 = $uglygep6$i$i$i >>> 2;
    $80 = (($79) + 1)|0;
    $scevgep8$i$i$i = (($68) + ($80<<2)|0);
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $scevgep8$i$i$i;
   }
  }
  HEAP32[$v>>2] = $81;
  HEAP32[$2>>2] = $scevgep8$i$i$i52;
  $82 = (($v) + 8|0);
  HEAP32[$82>>2] = $83;
  $84 = ($4|0)==(0|0);
  if ($84) {
   STACKTOP = sp;return;
  }
  __ZdlPv($4);
  STACKTOP = sp;return;
 }
 $10 = (($v) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($6))|0;
 $14 = $13 >> 2;
 $15 = ($14|0)==($sz|0);
 if ($15) {
  $62 = (($sz) - ($8))|0;
  __ZNSt3__16vectorI4PPtrI9Texture2DENS_9allocatorIS3_EEE8__appendEj($v,$62);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $16 = (($temp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($temp) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = ($sz|0)==(0);
 if ($18) {
  label = 6;
 } else {
  $19 = $sz << 2;
  __THREW__ = 0;
  $20 = (invoke_ii(2988,($19|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $23 = (($20) + ($sz<<2)|0);
   HEAP32[$temp>>2] = $20;
   HEAP32[$16>>2] = $20;
   HEAP32[$17>>2] = $23;
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$0>>2] = $4;
   HEAP32[$1>>2] = $3;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1734,($temp|0),($$byval_copy|0),($$byval_copy1|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$16>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = $30 >> 2;
    $32 = ($31>>>0)<($sz>>>0);
    if ($32) {
     $33 = (($sz) - ($31))|0;
     __THREW__ = 0;
     invoke_vii(2707,($temp|0),($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $$pre54 = HEAP32[$temp>>2]|0;
     $$pre55 = HEAP32[$16>>2]|0;
     $43 = $$pre54;$45 = $$pre55;
    } else {
     $36 = ($31>>>0)>($sz>>>0);
     if ($36) {
      $37 = (($27) + ($sz<<2)|0);
      $38 = ($26|0)==($37|0);
      if ($38) {
       $43 = $27;$45 = $26;
      } else {
       $__new_last2$i$i$i = $37;
       $scevgep$i$i$i17 = (($26) + -4|0);
       $39 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i18 = (($scevgep$i$i$i17) + ($39)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i18;
       $40 = $uglygep3$i$i$i >>> 2;
       $41 = $40 ^ -1;
       $scevgep4$i$i$i19 = (($26) + ($41<<2)|0);
       HEAP32[$16>>2] = $scevgep4$i$i$i19;
       $43 = $27;$45 = $scevgep4$i$i$i19;
      }
     } else {
      $43 = $27;$45 = $26;
     }
    }
    $42 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $42;
    HEAP32[$v>>2] = $43;
    $44 = HEAP32[$2>>2]|0;
    HEAP32[$16>>2] = $44;
    HEAP32[$2>>2] = $45;
    $46 = HEAP32[$17>>2]|0;
    $47 = HEAP32[$10>>2]|0;
    HEAP32[$17>>2] = $47;
    HEAP32[$10>>2] = $46;
    $48 = ($42|0)==(0|0);
    if ($48) {
     STACKTOP = sp;return;
    }
    $49 = ($44|0)==($42|0);
    if (!($49)) {
     $__new_last2$i$i$i$i$i30 = $42;
     $scevgep$i$i$i$i$i31 = (($44) + -4|0);
     $50 = (0 - ($__new_last2$i$i$i$i$i30))|0;
     $uglygep$i$i$i$i$i33 = (($scevgep$i$i$i$i$i31) + ($50)|0);
     $uglygep3$i$i$i$i$i34 = $uglygep$i$i$i$i$i33;
     $51 = $uglygep3$i$i$i$i$i34 >>> 2;
     $52 = $51 ^ -1;
     $scevgep4$i$i$i$i$i35 = (($44) + ($52<<2)|0);
     HEAP32[$16>>2] = $scevgep4$i$i$i$i$i35;
    }
    __ZdlPv($42);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $53 = ___cxa_find_matching_catch()|0;
 $54 = tempRet0;
 $55 = HEAP32[$temp>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($53|0);
  // unreachable;
 }
 $57 = HEAP32[$16>>2]|0;
 $58 = ($57|0)==($55|0);
 if (!($58)) {
  $__new_last2$i$i$i$i$i39 = $55;
  $scevgep$i$i$i$i$i40 = (($57) + -4|0);
  $59 = (0 - ($__new_last2$i$i$i$i$i39))|0;
  $uglygep$i$i$i$i$i42 = (($scevgep$i$i$i$i$i40) + ($59)|0);
  $uglygep3$i$i$i$i$i43 = $uglygep$i$i$i$i$i42;
  $60 = $uglygep3$i$i$i$i$i43 >>> 2;
  $61 = $60 ^ -1;
  $scevgep4$i$i$i$i$i44 = (($57) + ($61<<2)|0);
  HEAP32[$16>>2] = $scevgep4$i$i$i$i$i44;
 }
 __ZdlPv($55);
 ___resumeException($53|0);
 // unreachable;
}
function __ZNSt3__16vectorI4PPtrI9Texture2DENS_9allocatorIS3_EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$promoted15$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0;
 var $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i24 = 0, $scevgep$i10 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i17 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i25 = 0, $uglygep$i12 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0;
 var $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $46 = ($8|0)==(0|0);
  if ($46) {
   $55 = $7;
  } else {
   $47 = (($this) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($8|0);
   if (!($49)) {
    $scevgep$i$i$i$i = (($48) + -4|0);
    $50 = (0 - ($10))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($50)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $51 = $uglygep3$i$i$i$i >>> 2;
    $52 = $51 ^ -1;
    $scevgep4$i$i$i$i = (($48) + ($52<<2)|0);
    HEAP32[$47>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($8);
   HEAP32[$6>>2] = 0;
   HEAP32[$47>>2] = 0;
   HEAP32[$this>>2] = 0;
   $55 = 0;
  }
  $53 = ($5>>>0)>(1073741823);
  if ($53) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $54 = $55;
  $56 = $54 >> 2;
  $57 = ($56>>>0)<(536870911);
  if ($57) {
   $58 = $54 >> 1;
   $59 = ($58>>>0)<($5>>>0);
   $60 = $59 ? $5 : $58;
   $61 = ($60>>>0)>(1073741823);
   if ($61) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $60;
   }
  } else {
   $$0$i40 = 1073741823;
  }
  $62 = $$0$i40 << 2;
  $63 = (__Znwj($62)|0);
  $64 = (($this) + 4|0);
  HEAP32[$64>>2] = $63;
  HEAP32[$this>>2] = $63;
  $65 = (($63) + ($$0$i40<<2)|0);
  HEAP32[$6>>2] = $65;
  $66 = ($0|0)==($1|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($1) + -4|0);
  $67 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($67)|0);
  $uglygep6$i = $uglygep$i;
  $68 = $uglygep6$i >>> 2;
  $70 = $63;$72 = $0;
  while(1) {
   $69 = ($70|0)==(0|0);
   if (!($69)) {
    $71 = HEAP32[$72>>2]|0;
    HEAP32[$70>>2] = $71;
   }
   $73 = (($70) + 4|0);
   $74 = (($72) + 4|0);
   $75 = ($74|0)==($1|0);
   if ($75) {
    break;
   } else {
    $70 = $73;$72 = $74;
   }
  }
  $76 = (($68) + 1)|0;
  $scevgep8$i = (($63) + ($76<<2)|0);
  HEAP32[$64>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 2;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<2)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i24 = (($22) + -4|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i25 = (($scevgep$i$i24) + ($23)|0);
  $uglygep5$i$i = $uglygep$i$i25;
  $24 = $uglygep5$i$i >>> 2;
  $$01$i$i = $8;$26 = $0;
  while(1) {
   $25 = HEAP32[$26>>2]|0;
   HEAP32[$$01$i$i>>2] = $25;
   $27 = (($26) + 4|0);
   $28 = (($$01$i$i) + 4|0);
   $29 = ($27|0)==($22|0);
   if ($29) {
    break;
   } else {
    $$01$i$i = $28;$26 = $27;
   }
  }
  $30 = (($24) + 1)|0;
  $scevgep6$i$i = (($8) + ($30<<2)|0);
  $$0$lcssa$i$i = $scevgep6$i$i;
 }
 if (!($__growing$0$off0)) {
  $42 = ($15|0)==($$0$lcssa$i$i|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($15) + -4|0);
  $43 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($43)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $44 = $uglygep3$i$i >>> 2;
  $45 = $44 ^ -1;
  $scevgep4$i$i = (($15) + ($45<<2)|0);
  HEAP32[$14>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $31 = ($22|0)==($1|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $$promoted15$i9 = $22;
 $scevgep$i10 = (($1) + -4|0);
 $32 = (0 - ($$promoted15$i9))|0;
 $uglygep$i12 = (($scevgep$i10) + ($32)|0);
 $uglygep6$i13 = $uglygep$i12;
 $33 = $uglygep6$i13 >>> 2;
 $35 = $15;$37 = $22;
 while(1) {
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   $36 = HEAP32[$37>>2]|0;
   HEAP32[$35>>2] = $36;
  }
  $38 = (($35) + 4|0);
  $39 = (($37) + 4|0);
  $40 = ($39|0)==($1|0);
  if ($40) {
   break;
  } else {
   $35 = $38;$37 = $39;
  }
 }
 $41 = (($33) + 1)|0;
 $scevgep8$i17 = (($15) + ($41<<2)|0);
 HEAP32[$14>>2] = $scevgep8$i17;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI9Texture2DENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4PPtrI9Texture2DENS0_9allocatorIS4_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI9Texture2DENS1_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,601032,601032,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4PPtrI9Texture2DENS0_9allocatorIS4_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,600992,601040,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 4|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,600992,601040,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 4|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI9TextureIDP7TextureEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$30 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3>>>0)<($5>>>0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5>>>0)<($3>>>0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$30 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$30 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$30 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $40 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $39 = (($agg$result) + 4|0);
  HEAP8[$39>>0] = $40;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(24)|0);
 $17 = (($16) + 16|0);
 $18 = $__v;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $17;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 HEAP32[$16>>2] = 0;
 $28 = (($16) + 4|0);
 HEAP32[$28>>2] = 0;
 $29 = (($16) + 8|0);
 HEAP32[$29>>2] = $30;
 HEAP32[$$0$i>>2] = $16;
 $31 = HEAP32[$this>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $35 = $16;
 } else {
  HEAP32[$this>>2] = $32;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $35 = $$pre$i;
 }
 $34 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($34,$35);
 $36 = (($this) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $40 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $39 = (($agg$result) + 4|0);
 HEAP8[$39>>0] = $40;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI4PPtrI9Texture2DENS_9allocatorIS3_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0;
 var $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
   }
   $11 = (($10) + 4|0);
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$10 = $11;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($__n))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 if ($22) {
  $23 = $20 >> 1;
  $24 = ($23>>>0)<($18>>>0);
  $25 = $24 ? $18 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 2;
  $28 = (__Znwj($27)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($17<<2)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP32[$32>>2] = 0;
  }
  $33 = (($32) + 4|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($30) + ($18<<2)|0);
 $37 = ($3|0)==($14|0);
 if ($37) {
  $47 = $29;$49 = $3;
 } else {
  $scevgep$i$i = (($3) + -4|0);
  $38 = (0 - ($15))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($38)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $3;$42 = $29;
  while(1) {
   $39 = (($$01$i$i) + -4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($42) + -4|0);
   HEAP32[$41>>2] = $40;
   $43 = (($42) + -4|0);
   $44 = ($39|0)==($14|0);
   if ($44) {
    break;
   } else {
    $$01$i$i = $39;$42 = $43;
   }
  }
  $45 = $uglygep4$i$i >>> 2;
  $46 = $45 ^ -1;
  $$sum6 = (($17) + ($46))|0;
  $scevgep5$i$i = (($30) + ($$sum6<<2)|0);
  $47 = $scevgep5$i$i;$49 = $14;
 }
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $36;
 $48 = ($49|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($49);
 STACKTOP = sp;return;
}
function __ZN9Texture2DD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture2DD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN9Texture2DD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3478,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK9Texture2D12GetDimensionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN7TextureD1Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$01$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((608008 + 8|0));
 __THREW__ = 0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if ($3) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   $15 = (($this) + 92|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(-1);
   if ($17) {
    $18 = (($this) + 80|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($this) + 84|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($19|0),($$byval_copy1|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $28 = ___cxa_find_matching_catch(0|0)|0;
     $29 = tempRet0;
     ___clang_call_terminate($28);
     // unreachable;
    } else {
     HEAP32[$18>>2] = 0;
     $$0$i = $14;$$01$i = $13;
     break;
    }
   } else {
    $$0$i = $14;$$01$i = $13;
   }
  } else {
   $4 = (($this) + 92|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)>(-1);
   if (!($6)) {
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
   $7 = (($this) + 80|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 84|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$1>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy1|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    $$0$i = $25;$$01$i = $24;
    break;
   }
   HEAP32[$7>>2] = 0;
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($$01$i|0);
  // unreachable;
 }
}
function __ZN7TextureD0Ev($this) {
 $this = $this|0;
 var $$0$i$i = 0, $$01$i$i = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy6 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((608008 + 8|0));
 __THREW__ = 0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if ($3) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   $15 = (($this) + 92|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(-1);
   if ($17) {
    $18 = (($this) + 80|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($this) + 84|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($19|0),($$byval_copy6|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $28 = ___cxa_find_matching_catch(0|0)|0;
     $29 = tempRet0;
     ___clang_call_terminate($28);
     // unreachable;
    } else {
     HEAP32[$18>>2] = 0;
     $$0$i$i = $14;$$01$i$i = $13;
     break;
    }
   } else {
    $$0$i$i = $14;$$01$i$i = $13;
   }
  } else {
   $4 = (($this) + 92|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)>(-1);
   do {
    if ($6) {
     $7 = (($this) + 80|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = (($this) + 84|0);
     $10 = HEAP32[$9>>2]|0;
     HEAP32[$1>>2] = $10;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($8|0),($$byval_copy6|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      $24 = ___cxa_find_matching_catch()|0;
      $25 = tempRet0;
      $$0$i$i = $25;$$01$i$i = $24;
      break L1;
     } else {
      HEAP32[$7>>2] = 0;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    __ZdlPv($this);
    STACKTOP = sp;return;
   }
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   $eh$lpad$body$index2Z2D = $33;$eh$lpad$body$indexZ2D = $32;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 }
 $eh$lpad$body$index2Z2D = $$0$i$i;$eh$lpad$body$indexZ2D = $$01$i$i;
 __ZdlPv($this);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK7Texture20GetUnscaledTextureIDEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK7Texture13IsNPOTAllowedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK7Texture10GetGLWidthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNK7Texture11GetGLHeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z13DrawWaterMarkb($alwaysDisplay) {
 $alwaysDisplay = $alwaysDisplay|0;
 var $$$i$i = Math_fround(0), $$0 = 0, $$0$i$i = Math_fround(0), $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0.0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $a$0 = Math_fround(0), $a$04 = Math_fround(0), $alwaysDisplay$not = 0, $or$cond = 0, $preserveMVP = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $tmpcast$byval_copy = sp + 228|0;
 $0 = sp;
 $preserveMVP = sp + 16|0;
 $1 = sp + 208|0;
 $2 = sp + 224|0;
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 24;
 dest=$3+0|0; src=601056+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 24|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 $7 = (invoke_i(58)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  $10 = (invoke_iiii(1532,($7|0),28,($0|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP8[$0>>0]|0;
   $14 = $13 & 1;
   $15 = ($14<<24>>24)==(0);
   if (!($15)) {
    $16 = HEAP32[$4>>2]|0;
    __ZdlPv($16);
   }
   $17 = ($10|0)==(0|0);
   if ($17) {
    STACKTOP = sp;return;
   }
   $24 = (__Z14GetTimeManagerv()|0);
   $25 = (+__ZN11TimeManager11GetRealtimeEv($24));
   $26 = Math_fround($25);
   $alwaysDisplay$not = $alwaysDisplay ^ 1;
   $27 = $26 > Math_fround(9.0);
   $or$cond = $27 & $alwaysDisplay$not;
   if ($or$cond) {
    STACKTOP = sp;return;
   }
   $28 = $26 < Math_fround(2.5);
   if ($28) {
    $29 = Math_fround($26 + Math_fround(-1.5));
    $a$0 = $29;
    label = 13;
   } else {
    if ($alwaysDisplay) {
     $a$04 = Math_fround(1.0);
     label = 14;
    } else {
     $30 = Math_fround($26 + Math_fround(-7.5));
     $31 = Math_fround($30 / Math_fround(1.5));
     $32 = Math_fround(Math_fround(1.0) - $31);
     $a$0 = $32;
     label = 13;
    }
   }
   if ((label|0) == 13) {
    $33 = $a$0 < Math_fround(0.0);
    if ($33) {
     $$0$i$i = Math_fround(0.0);
    } else {
     $a$04 = $a$0;
     label = 14;
    }
   }
   if ((label|0) == 14) {
    $34 = $a$04 > Math_fround(1.0);
    $$$i$i = $34 ? Math_fround(1.0) : $a$04;
    $$0$i$i = $$$i$i;
   }
   $35 = Math_fround($$0$i$i * Math_fround(-2.0));
   $36 = Math_fround($$0$i$i * $35);
   $37 = Math_fround($$0$i$i * $36);
   $38 = Math_fround($$0$i$i * Math_fround(3.0));
   $39 = Math_fround($$0$i$i * $38);
   $40 = Math_fround($39 + $37);
   $41 = (__Z16GetRenderManagerv()|0);
   __ZN22DeviceMVPMatricesStateC2Ev($preserveMVP);
   __THREW__ = 0;
   invoke_v(76);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    $44 = Math_fround(Math_fround(1.0) - $40);
    $45 = Math_fround($44 * Math_fround(0.0));
    $46 = Math_fround($40 * Math_fround(128.0));
    $47 = Math_fround($46 + $45);
    $48 = (($41) + 64|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = Math_fround($49 - $47);
    HEAPF32[$1>>2] = $50;
    $51 = (($1) + 8|0);
    HEAPF32[$51>>2] = Math_fround(128.0);
    $52 = (($1) + 4|0);
    HEAPF32[$52>>2] = Math_fround(62.0);
    $53 = (($1) + 12|0);
    HEAPF32[$53>>2] = Math_fround(-58.0);
    HEAP32[$2>>2] = -2139062144;
    __THREW__ = 0;
    ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viiii(329,($1|0),($10|0),($tmpcast$byval_copy|0),(0|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     __ZN22DeviceMVPMatricesStateD2Ev($preserveMVP);
     STACKTOP = sp;return;
    }
   }
   $56 = ___cxa_find_matching_catch()|0;
   $57 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3375,($preserveMVP|0));
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $60 = ___cxa_find_matching_catch(0|0)|0;
    $61 = tempRet0;
    ___clang_call_terminate($60);
    // unreachable;
   } else {
    $$0 = $56;$$01 = $57;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $20 = HEAP8[$0>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $$0 = $18;$$01 = $19;
  ___resumeException($$0|0);
  // unreachable;
 }
 $23 = HEAP32[$4>>2]|0;
 __ZdlPv($23);
 $$0 = $18;$$01 = $19;
 ___resumeException($$0|0);
 // unreachable;
}
function __Z26IsSplashScreenFadeCompletev() {
 var $0 = 0.0, $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__Z19GetTimeSinceStartupv());
 $1 = 0.0 + 4.5;
 $2 = $0 >= $1;
 STACKTOP = sp;return ($2|0);
}
function __Z25GetShouldShowSplashScreenv() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetBuildSettingsv()|0);
 $1 = (($0) + 96|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $4 = (($0) + 100|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $$0 = 1;
  } else {
   $7 = (($0) + 93|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   $$0 = $9;
  }
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z16DrawSplashScreenb($fullDraw) {
 $fullDraw = $fullDraw|0;
 var $$$i$i = Math_fround(0), $$$i$i24 = Math_fround(0), $$0 = 0, $$0$i$i = Math_fround(0), $$0$i$i25 = Math_fround(0), $$01 = 0, $$byval_copy2 = 0, $$op$i1$i$i$i = Math_fround(0), $$op$i1$i$i$i30 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0.0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0);
 var $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0.0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0.0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0;
 var $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $fullDraw$not = 0, $or$cond = 0, $preserveMVP = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $$byval_copy2 = sp + 308|0;
 $0 = sp + 296|0;
 $1 = sp + 284|0;
 $2 = sp + 272|0;
 $3 = sp + 256|0;
 $preserveMVP = sp + 64|0;
 $4 = sp + 48|0;
 $5 = sp + 40|0;
 $6 = sp + 24|0;
 $7 = sp + 16|0;
 $8 = sp;
 $9 = sp + 44|0;
 $10 = (+__Z19GetTimeSinceStartupv());
 $11 = $10 - 0.0;
 $12 = $fullDraw ? 0.0 : 4.5;
 $13 = $11 - $12;
 $14 = Math_fround($13);
 $fullDraw$not = $fullDraw ^ 1;
 $15 = $14 > Math_fround(0.400000005960464477539);
 $or$cond = $15 & $fullDraw$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(16)|0);
 $17 = (($0) + 8|0);
 HEAP32[$17>>2] = $16;
 HEAP32[$0>>2] = 17;
 $18 = (($0) + 4|0);
 HEAP32[$18>>2] = 15;
 dest=$16+0|0; src=601088+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $19 = (($16) + 15|0);
 HEAP8[$19>>0] = 0;
 __THREW__ = 0;
 $20 = (invoke_i(58)|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  __THREW__ = 0;
  $23 = (invoke_iiii(1532,($20|0),28,($0|0))|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $26 = HEAP8[$0>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if (!($28)) {
    $29 = HEAP32[$17>>2]|0;
    __ZdlPv($29);
   }
   $30 = ($23|0)==(0|0);
   if ($30) {
    STACKTOP = sp;return;
   }
   $37 = (__Znwj(32)|0);
   $38 = (($1) + 8|0);
   HEAP32[$38>>2] = $37;
   HEAP32[$1>>2] = 33;
   $39 = (($1) + 4|0);
   HEAP32[$39>>2] = 16;
   dest=$37+0|0; src=601104+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $40 = (($37) + 16|0);
   HEAP8[$40>>0] = 0;
   __THREW__ = 0;
   $41 = (invoke_i(58)|0);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    __THREW__ = 0;
    $44 = (invoke_iiii(1532,($41|0),28,($1|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     $47 = HEAP8[$1>>0]|0;
     $48 = $47 & 1;
     $49 = ($48<<24>>24)==(0);
     if (!($49)) {
      $50 = HEAP32[$38>>2]|0;
      __ZdlPv($50);
     }
     $51 = ($44|0)==(0|0);
     if ($51) {
      STACKTOP = sp;return;
     }
     $58 = (__Znwj(32)|0);
     $59 = (($2) + 8|0);
     HEAP32[$59>>2] = $58;
     HEAP32[$2>>2] = 33;
     $60 = (($2) + 4|0);
     HEAP32[$60>>2] = 19;
     dest=$58+0|0; src=601128+0|0; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $61 = (($58) + 19|0);
     HEAP8[$61>>0] = 0;
     __THREW__ = 0;
     $62 = (invoke_i(58)|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if (!($64)) {
      __THREW__ = 0;
      $65 = (invoke_iiii(1532,($62|0),28,($2|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if (!($67)) {
       $68 = HEAP8[$2>>0]|0;
       $69 = $68 & 1;
       $70 = ($69<<24>>24)==(0);
       if (!($70)) {
        $71 = HEAP32[$59>>2]|0;
        __ZdlPv($71);
       }
       $72 = ($65|0)==(0|0);
       if ($72) {
        STACKTOP = sp;return;
       }
       $79 = (__Z16GetRenderManagerv()|0);
       $80 = (($79) + 64|0);
       $81 = Math_fround(HEAPF32[$80>>2]);
       $82 = Math_fround($81 * Math_fround(0.5));
       $83 = (($79) + 68|0);
       $84 = Math_fround(HEAPF32[$83>>2]);
       $85 = Math_fround($84 * Math_fround(0.5));
       $86 = (__Z12GetGfxDevicev()|0);
       do {
        if ($fullDraw) {
         $87 = HEAP32[$86>>2]|0;
         $88 = (($87) + 504|0);
         $89 = HEAP32[$88>>2]|0;
         FUNCTION_TABLE_vi[$89 & 4095]($86);
         $90 = HEAP32[$86>>2]|0;
         $91 = (($90) + 516|0);
         $92 = HEAP32[$91>>2]|0;
         $93 = (FUNCTION_TABLE_ii[$92 & 4095]($86)|0);
         if ($93) {
          HEAPF32[$3>>2] = Math_fround(0.301960796117782592773);
          $97 = (($3) + 4|0);
          HEAPF32[$97>>2] = Math_fround(0.301960796117782592773);
          $98 = (($3) + 8|0);
          HEAPF32[$98>>2] = Math_fround(0.301960796117782592773);
          $99 = (($3) + 12|0);
          HEAPF32[$99>>2] = Math_fround(0.0);
          $100 = HEAP32[652824>>2]|0;
          __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE(7,$3,Math_fround(1.0),0,$100);
          break;
         }
         $94 = HEAP32[$86>>2]|0;
         $95 = (($94) + 520|0);
         $96 = HEAP32[$95>>2]|0;
         (FUNCTION_TABLE_ii[$96 & 4095]($86)|0);
         STACKTOP = sp;return;
        }
       } while(0);
       __ZN22DeviceMVPMatricesStateC2Ev($preserveMVP);
       __THREW__ = 0;
       invoke_v(76);
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       do {
        if (!($102)) {
         if ($fullDraw) {
          $103 = Math_fround($14 + Math_fround(-3.0));
          $104 = Math_fround($103 / Math_fround(1.5));
          $105 = $104 < Math_fround(0.0);
          if ($105) {
           $$0$i$i = Math_fround(0.0);
          } else {
           $106 = $104 > Math_fround(1.0);
           $$$i$i = $106 ? Math_fround(1.0) : $104;
           $$0$i$i = $$$i$i;
          }
          $107 = Math_fround($$0$i$i * Math_fround(-2.0));
          $108 = Math_fround($$0$i$i * $107);
          $109 = Math_fround($$0$i$i * $108);
          $110 = Math_fround($$0$i$i * Math_fround(3.0));
          $111 = Math_fround($$0$i$i * $110);
          $112 = Math_fround($111 + $109);
          $113 = Math_fround($112 * Math_fround(0.0));
          $114 = Math_fround(Math_fround(1.0) - $112);
          $115 = Math_fround($113 + $114);
          $116 = Math_fround($82 + Math_fround(-75.0));
          $117 = Math_fround($85 + Math_fround(-75.0));
          HEAPF32[$4>>2] = $116;
          $118 = (($4) + 8|0);
          HEAPF32[$118>>2] = Math_fround(150.0);
          $119 = (($4) + 4|0);
          HEAPF32[$119>>2] = $117;
          $120 = (($4) + 12|0);
          HEAPF32[$120>>2] = Math_fround(-66.0);
          HEAP8[$5>>0] = -1;
          $121 = (($5) + 1|0);
          HEAP8[$121>>0] = -1;
          $122 = (($5) + 2|0);
          HEAP8[$122>>0] = -1;
          $123 = $115 < Math_fround(0.0);
          $124 = $123 ? Math_fround(0.0) : $115;
          $125 = $124 > Math_fround(1.0);
          $$op$i1$i$i$i = Math_fround($124 * Math_fround(255.0));
          $126 = $125 ? Math_fround(255.0) : $$op$i1$i$i$i;
          $127 = Math_fround($126 + Math_fround(0.5));
          $128 = (~~(($127))>>>0);
          $129 = $128&255;
          $130 = (($5) + 3|0);
          HEAP8[$130>>0] = $129;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$5+0>>2]|0;
          invoke_viiii(329,($4|0),($44|0),($$byval_copy2|0),(0|0));
          $131 = __THREW__; __THREW__ = 0;
          $132 = $131&1;
          if ($132) {
           break;
          }
          $133 = Math_fround($82 + Math_fround(-77.0));
          $134 = Math_fround($85 + Math_fround(65.0));
          HEAPF32[$6>>2] = $133;
          $135 = (($6) + 8|0);
          HEAPF32[$135>>2] = Math_fround(154.0);
          $136 = (($6) + 4|0);
          HEAPF32[$136>>2] = $134;
          $137 = (($6) + 12|0);
          HEAPF32[$137>>2] = Math_fround(-130.0);
          HEAP8[$7>>0] = -1;
          $138 = (($7) + 1|0);
          HEAP8[$138>>0] = -1;
          $139 = (($7) + 2|0);
          HEAP8[$139>>0] = -1;
          $140 = (($7) + 3|0);
          HEAP8[$140>>0] = $129;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$7+0>>2]|0;
          invoke_viiii(329,($6|0),($23|0),($$byval_copy2|0),(0|0));
          $141 = __THREW__; __THREW__ = 0;
          $142 = $141&1;
          if ($142) {
           break;
          }
         } else {
          $147 = Math_fround($14 / Math_fround(0.400000005960464477539));
          $148 = $147 < Math_fround(0.0);
          if ($148) {
           $$0$i$i25 = Math_fround(0.0);
          } else {
           $149 = $147 > Math_fround(1.0);
           $$$i$i24 = $149 ? Math_fround(1.0) : $147;
           $$0$i$i25 = $$$i$i24;
          }
          $150 = Math_fround($$0$i$i25 * Math_fround(-2.0));
          $151 = Math_fround($$0$i$i25 * $150);
          $152 = Math_fround($$0$i$i25 * $151);
          $153 = Math_fround($$0$i$i25 * Math_fround(3.0));
          $154 = Math_fround($$0$i$i25 * $153);
          $155 = Math_fround($154 + $152);
          $156 = Math_fround($155 * Math_fround(0.0));
          $157 = Math_fround(Math_fround(1.0) - $155);
          $158 = Math_fround($157 * Math_fround(0.5));
          $159 = Math_fround($156 + $158);
          $160 = Math_fround(HEAPF32[$80>>2]);
          $161 = Math_fround($160 + Math_fround(10.0));
          $162 = Math_fround(HEAPF32[$83>>2]);
          $163 = Math_fround($162 + Math_fround(10.0));
          HEAPF32[$8>>2] = Math_fround(0.0);
          $164 = (($8) + 8|0);
          HEAPF32[$164>>2] = $161;
          $165 = (($8) + 4|0);
          HEAPF32[$165>>2] = Math_fround(0.0);
          $166 = (($8) + 12|0);
          HEAPF32[$166>>2] = $163;
          HEAP8[$9>>0] = -128;
          $167 = (($9) + 1|0);
          HEAP8[$167>>0] = -128;
          $168 = (($9) + 2|0);
          HEAP8[$168>>0] = -128;
          $169 = $159 < Math_fround(0.0);
          $170 = $169 ? Math_fround(0.0) : $159;
          $171 = $170 > Math_fround(1.0);
          $$op$i1$i$i$i30 = Math_fround($170 * Math_fround(255.0));
          $172 = $171 ? Math_fround(255.0) : $$op$i1$i$i$i30;
          $173 = Math_fround($172 + Math_fround(0.5));
          $174 = (~~(($173))>>>0);
          $175 = $174&255;
          $176 = (($9) + 3|0);
          HEAP8[$176>>0] = $175;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$9+0>>2]|0;
          invoke_viiii(329,($8|0),($65|0),($$byval_copy2|0),(0|0));
          $177 = __THREW__; __THREW__ = 0;
          $178 = $177&1;
          if ($178) {
           break;
          }
         }
         if ($fullDraw) {
          $179 = HEAP32[$86>>2]|0;
          $180 = (($179) + 508|0);
          $181 = HEAP32[$180>>2]|0;
          __THREW__ = 0;
          invoke_vi($181|0,($86|0));
          $182 = __THREW__; __THREW__ = 0;
          $183 = $182&1;
          if ($183) {
           break;
          }
          $184 = HEAP32[$86>>2]|0;
          $185 = (($184) + 512|0);
          $186 = HEAP32[$185>>2]|0;
          __THREW__ = 0;
          invoke_vi($186|0,($86|0));
          $187 = __THREW__; __THREW__ = 0;
          $188 = $187&1;
          if ($188) {
           break;
          }
         }
         __ZN22DeviceMVPMatricesStateD2Ev($preserveMVP);
         STACKTOP = sp;return;
        }
       } while(0);
       $143 = ___cxa_find_matching_catch()|0;
       $144 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3375,($preserveMVP|0));
       $145 = __THREW__; __THREW__ = 0;
       $146 = $145&1;
       if ($146) {
        $189 = ___cxa_find_matching_catch(0|0)|0;
        $190 = tempRet0;
        ___clang_call_terminate($189);
        // unreachable;
       } else {
        $$0 = $143;$$01 = $144;
        ___resumeException($$0|0);
        // unreachable;
       }
      }
     }
     $73 = ___cxa_find_matching_catch()|0;
     $74 = tempRet0;
     $75 = HEAP8[$2>>0]|0;
     $76 = $75 & 1;
     $77 = ($76<<24>>24)==(0);
     if ($77) {
      $$0 = $73;$$01 = $74;
      ___resumeException($$0|0);
      // unreachable;
     }
     $78 = HEAP32[$59>>2]|0;
     __ZdlPv($78);
     $$0 = $73;$$01 = $74;
     ___resumeException($$0|0);
     // unreachable;
    }
   }
   $52 = ___cxa_find_matching_catch()|0;
   $53 = tempRet0;
   $54 = HEAP8[$1>>0]|0;
   $55 = $54 & 1;
   $56 = ($55<<24>>24)==(0);
   if ($56) {
    $$0 = $52;$$01 = $53;
    ___resumeException($$0|0);
    // unreachable;
   }
   $57 = HEAP32[$38>>2]|0;
   __ZdlPv($57);
   $$0 = $52;$$01 = $53;
   ___resumeException($$0|0);
   // unreachable;
  }
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $33 = HEAP8[$0>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $$0 = $31;$$01 = $32;
  ___resumeException($$0|0);
  // unreachable;
 }
 $36 = HEAP32[$17>>2]|0;
 __ZdlPv($36);
 $$0 = $31;$$01 = $32;
 ___resumeException($$0|0);
 // unreachable;
}
function __Z23DrawSplashAndWatermarksv() {
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $phitmp = Math_fround(0), dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = (__ZN10systeminfo18GetRuntimePlatformEv()|0);
 $4 = (__Z16GetBuildSettingsv()|0);
 $5 = (($4) + 96|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 $8 = (__Z16GetBuildSettingsv()|0);
 $9 = (($8) + 98|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 $12 = (__Z16GetBuildSettingsv()|0);
 $13 = (($12) + 97|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 $16 = (__Z16GetBuildSettingsv()|0);
 $17 = (($16) + 100|0);
 $18 = HEAP8[$17>>0]|0;
 $not$ = ($18<<24>>24)==(0);
 $19 = (__Z16GetBuildSettingsv()|0);
 $20 = (($19) + 93|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $23 = (__ZN10systeminfo19IsPlatformWebPlayerE15RuntimePlatform($3)|0);
  $105 = $23;
 } else {
  $105 = 0;
 }
 $24 = (__Z16GetBuildSettingsv()|0);
 $25 = (($24) + 104|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if ($105) {
  __Z13DrawWaterMarkb(0);
 }
 do {
  if ($27) {
   $50 = Math_fround(3.0);
  } else {
   $28 = (__Znwj(32)|0);
   $29 = (($0) + 8|0);
   HEAP32[$29>>2] = $28;
   HEAP32[$0>>2] = 33;
   $30 = (($0) + 4|0);
   HEAP32[$30>>2] = 22;
   dest=$28+0|0; src=601240+0|0; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $31 = (($28) + 22|0);
   HEAP8[$31>>0] = 0;
   __THREW__ = 0;
   $32 = (invoke_iif(28,($0|0),3.0)|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    $35 = HEAP8[$0>>0]|0;
    $36 = $35 & 1;
    $37 = ($36<<24>>24)==(0);
    if (!($37)) {
     $38 = HEAP32[$29>>2]|0;
     __ZdlPv($38);
    }
    $45 = (($32) + 6)|0;
    $phitmp = (Math_fround(($45|0)));
    $50 = $phitmp;
    break;
   }
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   $41 = HEAP8[$0>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    ___resumeException($39|0);
    // unreachable;
   }
   $44 = HEAP32[$29>>2]|0;
   __ZdlPv($44);
   ___resumeException($39|0);
   // unreachable;
  }
 } while(0);
 do {
  if ($7) {
   if (!($11)) {
    $46 = (__Znwj(32)|0);
    $47 = (($2) + 8|0);
    HEAP32[$47>>2] = $46;
    HEAP32[$2>>2] = 33;
    $48 = (($2) + 4|0);
    HEAP32[$48>>2] = 22;
    dest=$46+0|0; src=601216+0|0; stop=dest+22|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $49 = (($46) + 22|0);
    HEAP8[$49>>0] = 0;
    __THREW__ = 0;
    (invoke_iif(28,($2|0),(+$50))|0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if (!($52)) {
     $53 = HEAP8[$2>>0]|0;
     $54 = $53 & 1;
     $55 = ($54<<24>>24)==(0);
     if ($55) {
      break;
     }
     $56 = HEAP32[$47>>2]|0;
     __ZdlPv($56);
     break;
    }
    $57 = ___cxa_find_matching_catch()|0;
    $58 = tempRet0;
    $59 = HEAP8[$2>>0]|0;
    $60 = $59 & 1;
    $61 = ($60<<24>>24)==(0);
    if ($61) {
     ___resumeException($57|0);
     // unreachable;
    }
    $62 = HEAP32[$47>>2]|0;
    __ZdlPv($62);
    ___resumeException($57|0);
    // unreachable;
   }
   if (!($15)) {
    $63 = (__Znwj(32)|0);
    $64 = (($1) + 8|0);
    HEAP32[$64>>2] = $63;
    HEAP32[$1>>2] = 33;
    $65 = (($1) + 4|0);
    HEAP32[$65>>2] = 24;
    dest=$63+0|0; src=601184+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $66 = (($63) + 24|0);
    HEAP8[$66>>0] = 0;
    __THREW__ = 0;
    (invoke_iif(28,($1|0),(+$50))|0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if (!($68)) {
     $69 = HEAP8[$1>>0]|0;
     $70 = $69 & 1;
     $71 = ($70<<24>>24)==(0);
     if ($71) {
      break;
     }
     $72 = HEAP32[$64>>2]|0;
     __ZdlPv($72);
     break;
    }
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    $75 = HEAP8[$1>>0]|0;
    $76 = $75 & 1;
    $77 = ($76<<24>>24)==(0);
    if ($77) {
     ___resumeException($73|0);
     // unreachable;
    }
    $78 = HEAP32[$64>>2]|0;
    __ZdlPv($78);
    ___resumeException($73|0);
    // unreachable;
   }
   if ($not$) {
    $79 = (__Znwj(32)|0);
    $80 = (($0) + 8|0);
    HEAP32[$80>>2] = $79;
    HEAP32[$0>>2] = 33;
    $81 = (($0) + 4|0);
    HEAP32[$81>>2] = 24;
    dest=$79+0|0; src=601152+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $82 = (($79) + 24|0);
    HEAP8[$82>>0] = 0;
    __THREW__ = 0;
    (invoke_iif(28,($0|0),(+$50))|0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if (!($84)) {
     $85 = HEAP8[$0>>0]|0;
     $86 = $85 & 1;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      break;
     }
     $88 = HEAP32[$80>>2]|0;
     __ZdlPv($88);
     break;
    }
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    $91 = HEAP8[$0>>0]|0;
    $92 = $91 & 1;
    $93 = ($92<<24>>24)==(0);
    if ($93) {
     ___resumeException($89|0);
     // unreachable;
    }
    $94 = HEAP32[$80>>2]|0;
    __ZdlPv($94);
    ___resumeException($89|0);
    // unreachable;
   }
  }
 } while(0);
 $95 = (__Z16GetBuildSettingsv()|0);
 $96 = (($95) + 96|0);
 $97 = HEAP8[$96>>0]|0;
 $98 = ($97<<24>>24)==(0);
 if (!($98)) {
  STACKTOP = sp;return;
 }
 $99 = (($95) + 100|0);
 $100 = HEAP8[$99>>0]|0;
 $101 = ($100<<24>>24)==(0);
 if (!($101)) {
  $102 = (($95) + 93|0);
  $103 = HEAP8[$102>>0]|0;
  $104 = ($103<<24>>24)==(0);
  if (!($104)) {
   STACKTOP = sp;return;
  }
 }
 __Z16DrawSplashScreenb(0);
 STACKTOP = sp;return;
}
function __ZL19DrawSimpleWatermarkRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEff($name,$y) {
 $name = $name|0;
 $y = Math_fround($y);
 var $$0$i = 0, $$02$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $preserveMVP$i = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$byval_copy = sp + 212|0;
 $preserveMVP$i = sp;
 $0 = sp + 192|0;
 $1 = sp + 208|0;
 $2 = (__Z25GetBuiltinResourceManagerv()|0);
 $3 = (__ZNK22BuiltinResourceManager11GetResourceEiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($2,28,$name)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $5 = (__Z16GetRenderManagerv()|0);
 __ZN22DeviceMVPMatricesStateC2Ev($preserveMVP$i);
 __THREW__ = 0;
 invoke_v(76);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $8 = HEAP32[$3>>2]|0;
  $9 = (($8) + 104|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  $11 = (invoke_ii($10|0,($3|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = (Math_fround(($11|0)));
   $15 = HEAP32[$3>>2]|0;
   $16 = (($15) + 108|0);
   $17 = HEAP32[$16>>2]|0;
   __THREW__ = 0;
   $18 = (invoke_ii($17|0,($3|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = (0 - ($18))|0;
    $22 = (Math_fround(($21|0)));
    $23 = (($5) + 64|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = Math_fround($24 - $14);
    $26 = Math_fround($25 + Math_fround(-1.0));
    $27 = $y < Math_fround(0.0);
    if ($27) {
     $32 = Math_fround($y + Math_fround(1.0));
     $33 = (($5) + 68|0);
     $34 = Math_fround(HEAPF32[$33>>2]);
     $35 = Math_fround($22 + $34);
     $36 = Math_fround($32 + $35);
     $$02$i = $36;
    } else {
     $$02$i = $y;
    }
    $37 = Math_fround($$02$i - $22);
    HEAPF32[$0>>2] = $26;
    $38 = (($0) + 8|0);
    HEAPF32[$38>>2] = $14;
    $39 = (($0) + 4|0);
    HEAPF32[$39>>2] = $37;
    $40 = (($0) + 12|0);
    HEAPF32[$40>>2] = $22;
    HEAP32[$1>>2] = -2139062144;
    __THREW__ = 0;
    ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viiii(329,($0|0),($3|0),($tmpcast$byval_copy|0),(0|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     $43 = HEAP32[$3>>2]|0;
     $44 = (($43) + 108|0);
     $45 = HEAP32[$44>>2]|0;
     __THREW__ = 0;
     $46 = (invoke_ii($45|0,($3|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if (!($48)) {
      __ZN22DeviceMVPMatricesStateD2Ev($preserveMVP$i);
      $$0$i = $46;
      STACKTOP = sp;return ($$0$i|0);
     }
    }
   }
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3375,($preserveMVP$i|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $49 = ___cxa_find_matching_catch(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($28|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN8DrawUtil18DrawMeshBuffersRawERK11MeshBuffersR4MeshRK14ChannelAssignsii($buffers,$mesh,$channels,$subsetIndex,$rendererInstanceID) {
 $buffers = $buffers|0;
 $mesh = $mesh|0;
 $channels = $channels|0;
 $subsetIndex = $subsetIndex|0;
 $rendererInstanceID = $rendererInstanceID|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $drawRange = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $drawRange = sp;
 $0 = (__ZNK4Mesh15GetSubMeshCountEv($mesh)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $5 = 0;
 } else {
  $2 = (__ZNK4Mesh15GetSubMeshCountEv($mesh)|0);
  $3 = (($2) + -1)|0;
  $5 = $3;
 }
 $4 = ($5>>>0)<($subsetIndex>>>0);
 $6 = $4 ? $5 : $subsetIndex;
 $7 = (__Z12GetGfxDevicev()|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 228|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iii[$10 & 4095]($7,4)|0);
 if ($11) {
  $16 = 1;
 } else {
  $12 = HEAP32[$7>>2]|0;
  $13 = (($12) + 228|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_iii[$14 & 4095]($7,5)|0);
  $16 = $15;
 }
 __ZNK4Mesh26GetSubMeshDrawBuffersRangeEib($drawRange,$mesh,$6,$16);
 $17 = HEAP32[$7>>2]|0;
 $18 = (($17) + 300|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$buffers>>2]|0;
 $21 = (($buffers) + 8|0);
 $22 = (($buffers) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($buffers) + 40|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$19 & 63]($7,$20,$21,$23,$drawRange,1,$25,$channels);
 STACKTOP = sp;return;
}
function __ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_($channels,$mesh,$subsetIndex,$rendererInstanceID,$secondaryMesh) {
 $channels = $channels|0;
 $mesh = $mesh|0;
 $subsetIndex = $subsetIndex|0;
 $rendererInstanceID = $rendererInstanceID|0;
 $secondaryMesh = $secondaryMesh|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $buffers = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $buffers = sp;
 $0 = (($channels) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN4Mesh14GetMeshBuffersEjPS_($buffers,$mesh,$1,$secondaryMesh);
 $2 = HEAP32[$buffers>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __ZN8DrawUtil18DrawMeshBuffersRawERK11MeshBuffersR4MeshRK14ChannelAssignsii($buffers,$mesh,$channels,$subsetIndex,0);
 STACKTOP = sp;return;
}
function __ZN8DrawUtil15DrawTextMeshRawERK14ChannelAssignsR4Meshj($channels,$mesh,$vertexFormat) {
 $channels = $channels|0;
 $mesh = $mesh|0;
 $vertexFormat = $vertexFormat|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $buffers$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $buffers$i = sp;
 $0 = (($channels) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN4Mesh14GetMeshBuffersEjPS_($buffers$i,$mesh,$1,0);
 $2 = HEAP32[$buffers$i>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __ZN8DrawUtil18DrawMeshBuffersRawERK11MeshBuffersR4MeshRK14ChannelAssignsii($buffers$i,$mesh,$channels,0,0);
 STACKTOP = sp;return;
}
function __ZN8DrawUtil8DrawMeshERK14ChannelAssignsR4MeshRK8Vector3fRK11Quaternionfi($channels,$mesh,$position,$rotation,$subsetIndex) {
 $channels = $channels|0;
 $mesh = $mesh|0;
 $position = $position|0;
 $rotation = $rotation|0;
 $subsetIndex = $subsetIndex|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $matrix = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $matrix = sp;
 __Z18QuaternionToMatrixRK11QuaternionfR10Matrix4x4f($rotation,$matrix);
 $0 = Math_fround(HEAPF32[$position>>2]);
 $1 = (($matrix) + 48|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($position) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($matrix) + 52|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($position) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($matrix) + 56|0);
 HEAPF32[$7>>2] = $6;
 __ZL16DrawMeshInternalRK14ChannelAssignsR4MeshRK10Matrix4x4fi13TransformType($channels,$mesh,$matrix,$subsetIndex,0);
 STACKTOP = sp;return;
}
function __ZL16DrawMeshInternalRK14ChannelAssignsR4MeshRK10Matrix4x4fi13TransformType($channels,$mesh,$matrix,$subsetIndex,$transformType) {
 $channels = $channels|0;
 $mesh = $mesh|0;
 $matrix = $matrix|0;
 $subsetIndex = $subsetIndex|0;
 $transformType = $transformType|0;
 var $$0$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $buffers$i1 = 0, $exitcond = 0, $i$03 = 0, $matView = 0, $matWorld = 0, $temp$0$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $buffers$i1 = sp + 136|0;
 $0 = sp;
 $matView = sp + 8|0;
 $matWorld = sp + 72|0;
 $1 = (__Z16GetRenderManagerv()|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i$i$i = 0;
 } else {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   label = 10;
  } else {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($buffers$i1,$4,$0);
     $16 = HEAP32[$buffers$i1>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if ($30) {
    label = 10;
   } else {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     label = 10;
    } else {
     $temp$0$i$i$i = $33;
    }
   }
  }
  if ((label|0) == 10) {
   $35 = HEAP32[$1>>2]|0;
   $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
   $temp$0$i$i$i = $36;
  }
  $$0$i$i$i = $temp$0$i$i$i;
 }
 $37 = (__Z12GetGfxDevicev()|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 116|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (FUNCTION_TABLE_ii[$40 & 4095]($37)|0);
 dest=$matView+0|0; src=$41+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $42 = HEAP32[$37>>2]|0;
 $43 = (($42) + 112|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (FUNCTION_TABLE_ii[$44 & 4095]($37)|0);
 dest=$matWorld+0|0; src=$45+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $46 = ($$0$i$i$i|0)==(0|0);
 if (!($46)) {
  $47 = HEAP32[$37>>2]|0;
  $48 = (($47) + 100|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (__ZNK6Camera22GetWorldToCameraMatrixEv($$0$i$i$i)|0);
  FUNCTION_TABLE_vii[$49 & 4095]($37,$50);
 }
 __Z17SetupObjectMatrixRK10Matrix4x4fi($matrix,$transformType);
 $51 = ($subsetIndex|0)==(-1);
 if ($51) {
  $56 = (__ZNK4Mesh15GetSubMeshCountEv($mesh)|0);
  $57 = ($56|0)>(0);
  if ($57) {
   $58 = (($channels) + 4|0);
   $i$03 = 0;
   while(1) {
    $59 = HEAP32[$58>>2]|0;
    __ZN4Mesh14GetMeshBuffersEjPS_($buffers$i1,$mesh,$59,0);
    $60 = HEAP32[$buffers$i1>>2]|0;
    $61 = ($60|0)==(0|0);
    if (!($61)) {
     __ZN8DrawUtil18DrawMeshBuffersRawERK11MeshBuffersR4MeshRK14ChannelAssignsii($buffers$i1,$mesh,$channels,$i$03,0);
    }
    $62 = (($i$03) + 1)|0;
    $exitcond = ($62|0)==($56|0);
    if ($exitcond) {
     break;
    } else {
     $i$03 = $62;
    }
   }
  }
 } else {
  $52 = (($channels) + 4|0);
  $53 = HEAP32[$52>>2]|0;
  __ZN4Mesh14GetMeshBuffersEjPS_($buffers$i1,$mesh,$53,0);
  $54 = HEAP32[$buffers$i1>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   __ZN8DrawUtil18DrawMeshBuffersRawERK11MeshBuffersR4MeshRK14ChannelAssignsii($buffers$i1,$mesh,$channels,$subsetIndex,0);
  }
 }
 $63 = HEAP32[$37>>2]|0;
 $64 = (($63) + 100|0);
 $65 = HEAP32[$64>>2]|0;
 FUNCTION_TABLE_vii[$65 & 4095]($37,$matView);
 $66 = HEAP32[$37>>2]|0;
 $67 = (($66) + 96|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($37,$matWorld);
 STACKTOP = sp;return;
}
function __ZN8DrawUtil8DrawMeshERK14ChannelAssignsR4MeshRK10Matrix4x4fi($channels,$mesh,$matrix,$subsetIndex) {
 $channels = $channels|0;
 $mesh = $mesh|0;
 $matrix = $matrix|0;
 $subsetIndex = $subsetIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZL16DrawMeshInternalRK14ChannelAssignsR4MeshRK10Matrix4x4fi13TransformType($channels,$mesh,$matrix,$subsetIndex,1);
 STACKTOP = sp;return;
}
function __ZNK21EnlightenSceneMapping22GetTerrainInstanceHashEi($agg$result,$this,$terrainInstanceID) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $terrainInstanceID = $terrainInstanceID|0;
 var $$$i$i = 0, $$0$i1 = 0, $$neg2$i$i$i$i$i$i$i = 0, $$sum$i$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i$i$i = 0, $__len$03$i$i$i$i$i$i$i = 0, $i$03$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = (($this) + 48|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($this) + 16|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$this>>2]|0;
   $i$03$i = 0;
   while(1) {
    $10 = (($4) + (($i$03$i*12)|0)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($6) + (($11*56)|0)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($7) + (($13*40)|0)|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($terrainInstanceID|0);
    $9 = (($i$03$i) + 1)|0;
    if ($16) {
     break;
    }
    $8 = ($9>>>0)<($1>>>0);
    if ($8) {
     $i$03$i = $9;
    } else {
     break L1;
    }
   }
   $45 = ($11|0)<(0);
   if ($45) {
    $$0$i1 = 0;
   } else {
    $46 = (($this) + 24|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47>>>0)>($11>>>0);
    if ($48) {
     $49 = (($7) + (($13*40)|0)|0);
     $$0$i1 = $49;
    } else {
     $$0$i1 = 0;
    }
   }
   $50 = (($$0$i1) + 24|0);
   ;HEAP32[$agg$result+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$50+12>>2]|0;
   STACKTOP = sp;return;
  }
 } while(0);
 $17 = (($this) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 72|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 $22 = $18;
 $23 = (($21) - ($22))|0;
 $24 = $23 >> 3;
 $25 = ($24|0)==(0);
 if ($25) {
  $35 = $18;
 } else {
  $28 = $18;$__len$03$i$i$i$i$i$i$i = $24;
  while(1) {
   $26 = (($__len$03$i$i$i$i$i$i$i|0) / 2)&-1;
   $27 = (($28) + ($26<<3)|0);
   $29 = HEAP32[$27>>2]|0;
   $30 = ($29|0)<($terrainInstanceID|0);
   if ($30) {
    $$sum$i$i$i$i$i$i$i = (($26) + 1)|0;
    $31 = (($28) + ($$sum$i$i$i$i$i$i$i<<3)|0);
    $$neg2$i$i$i$i$i$i$i = (($__len$03$i$i$i$i$i$i$i) + -1)|0;
    $32 = (($$neg2$i$i$i$i$i$i$i) - ($26))|0;
    $51 = $31;$__len$0$be$i$i$i$i$i$i$i = $32;
   } else {
    $51 = $28;$__len$0$be$i$i$i$i$i$i$i = $26;
   }
   $33 = ($__len$0$be$i$i$i$i$i$i$i|0)==(0);
   if ($33) {
    $35 = $51;
    break;
   } else {
    $28 = $51;$__len$03$i$i$i$i$i$i$i = $__len$0$be$i$i$i$i$i$i$i;
   }
  }
 }
 $34 = ($35|0)==($20|0);
 if (!($34)) {
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)>($terrainInstanceID|0);
  $$$i$i = $37 ? $20 : $35;
  $38 = ($$$i$i|0)==($20|0);
  if (!($38)) {
   $39 = (($$$i$i) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$this>>2]|0;
   $42 = (($41) + (($40*40)|0)|0);
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = ((($41) + (($40*40)|0)|0) + 24|0);
    ;HEAP32[$agg$result+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$44+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$44+12>>2]|0;
    STACKTOP = sp;return;
   }
  }
 }
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN21EnlightenSceneMapping16BuildRemapTablesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 $5 = (($this) + 64|0);
 if (!($4)) {
  $i$01 = 0;
  while(1) {
   $6 = HEAP32[$this>>2]|0;
   $7 = (($6) + (($i$01*40)|0)|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$0>>2] = $8;
   HEAP32[$1>>2] = $i$01;
   __ZN10vector_mapIijNSt3__14lessIiEENS0_9allocatorINS0_4pairIijEEEEE13push_unsortedERKiRKj($5,$0,$1);
   $9 = (($i$01) + 1)|0;
   $exitcond = ($9|0)==($3|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $9;
   }
  }
 }
 __ZN13sorted_vectorINSt3__14pairIijEEN10vector_mapIijNS0_4lessIiEENS0_9allocatorIS2_EEE13value_compareES7_E21sort_clear_duplicatesEv($5);
 STACKTOP = sp;return;
}
function __ZN10vector_mapIijNSt3__14lessIiEENS0_9allocatorINS0_4pairIijEEEEE13push_unsortedERKiRKj($this,$x,$value) {
 $this = $this|0;
 $x = $x|0;
 $value = $value|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$x>>2]|0;
 $1 = HEAP32[$value>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = ($3|0)==(0|0);
  if ($7) {
   $13 = 0;
  } else {
   $8 = $3;
   $9 = $8;
   HEAP32[$9>>2] = $0;
   $10 = (($8) + 4)|0;
   $11 = $10;
   HEAP32[$11>>2] = $1;
   $$pre$i = HEAP32[$2>>2]|0;
   $13 = $$pre$i;
  }
  $12 = (($13) + 8|0);
  HEAP32[$2>>2] = $12;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $3;
 $17 = $15;
 $18 = (($16) - ($17))|0;
 $19 = $18 >> 3;
 $20 = (($19) + 1)|0;
 $21 = ($20>>>0)>(536870911);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = ($19>>>0)<(268435455);
 if ($22) {
  $23 = $18 >> 2;
  $24 = ($23>>>0)<($20>>>0);
  $25 = $24 ? $20 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i3$i$i = 0;$30 = 0;
  } else {
   $$0$i2$i$i = $25;
   label = 9;
  }
 } else {
  $$0$i2$i$i = 536870911;
  label = 9;
 }
 if ((label|0) == 9) {
  $27 = $$0$i2$i$i << 3;
  $28 = (__Znwj($27)|0);
  $$0$i3$i$i = $$0$i2$i$i;$30 = $28;
 }
 $29 = (($30) + ($19<<3)|0);
 $31 = (($30) + ($$0$i3$i$i<<3)|0);
 $32 = ($29|0)==(0|0);
 if (!($32)) {
  $33 = $29;
  $34 = $33;
  HEAP32[$34>>2] = $0;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = $1;
 }
 $37 = (($30) + ($20<<3)|0);
 _memcpy(($30|0),($15|0),($18|0))|0;
 HEAP32[$14>>2] = $30;
 HEAP32[$2>>2] = $37;
 HEAP32[$4>>2] = $31;
 $38 = ($15|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZN13sorted_vectorINSt3__14pairIijEEN10vector_mapIijNS0_4lessIiEENS0_9allocatorIS2_EEE13value_compareES7_E21sort_clear_duplicatesEv($this) {
 $this = $this|0;
 var $$0$lcssa$i$i$i = 0, $$012$i$i$i = 0, $$02$i$i = 0, $$03$i$i$i = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$pre$i = 0, $$pre17$i = 0, $$sum$i = 0, $$sum5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $__first5$i$i$i = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i1$i = 0, $scevgep4$i$i$i = 0, $scevgep7$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i3$i = 0, $uglygep3$i$i$i = 0, $uglygep6$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp + 12|0;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP8[$this>>0]|0;
 HEAP8[$2>>0] = $8;
 $9 = $6;
 $10 = $4;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 3;
 $13 = ($11|0)>(0);
 L4: do {
  if ($13) {
   $$02$i$i = $12;
   while(1) {
    $14 = $$02$i$i << 3;
    $15 = (__ZnwjRKSt9nothrow_t($14,3106360)|0);
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     $22 = $15;$23 = $$02$i$i;
     break L4;
    }
    $17 = (($$02$i$i|0) / 2)&-1;
    $18 = ($$02$i$i|0)>(1);
    if ($18) {
     $$02$i$i = $17;
    } else {
     $22 = $15;$23 = 0;
     break;
    }
   }
  } else {
   $22 = 0;$23 = 0;
  }
 } while(0);
 HEAP32[$0>>2] = $4;
 HEAP32[$1>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(110,($$byval_copy|0),($$byval_copy1|0),($2|0),($12|0),($22|0),($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = ($22|0)==(0|0);
  if ($21) {
   ___resumeException($19|0);
   // unreachable;
  }
  __ZdlPv($22);
  ___resumeException($19|0);
  // unreachable;
 }
 $26 = ($22|0)==(0|0);
 if (!($26)) {
  __ZdlPv($22);
 }
 $27 = HEAP32[$3>>2]|0;
 $28 = HEAP32[$5>>2]|0;
 $29 = ($27|0)==($28|0);
 L19: do {
  if ($29) {
   $51 = $27;
  } else {
   $31 = $27;
   while(1) {
    $30 = (($31) + 8|0);
    $32 = ($30|0)==($28|0);
    if ($32) {
     label = 26;
     break;
    }
    $33 = HEAP32[$31>>2]|0;
    $34 = HEAP32[$30>>2]|0;
    $35 = ($33|0)<($34|0);
    if ($35) {
     $31 = $30;
    } else {
     break;
    }
   }
   if ((label|0) == 26) {
    STACKTOP = sp;return;
   }
   $36 = ($31|0)==($28|0);
   if ($36) {
    STACKTOP = sp;return;
   } else {
    $38 = $33;$39 = $34;$40 = $30;$42 = $30;$48 = $31;
   }
   while(1) {
    $37 = ($38|0)<($39|0);
    if ($37) {
     HEAP32[$40>>2] = $39;
     $41 = (($42) + 4|0);
     $43 = HEAP32[$41>>2]|0;
     $44 = (($40) + 4|0);
     HEAP32[$44>>2] = $43;
     $45 = (($40) + 8|0);
     $76 = $45;
    } else {
     $76 = $40;
    }
    $46 = (($42) + 8|0);
    $47 = (($48) + 8|0);
    $49 = ($46|0)==($28|0);
    if ($49) {
     $51 = $76;
     break L19;
    }
    $$pre$i = HEAP32[$47>>2]|0;
    $$pre17$i = HEAP32[$46>>2]|0;
    $38 = $$pre$i;$39 = $$pre17$i;$40 = $76;$42 = $46;$48 = $47;
   }
  }
 } while(0);
 $50 = ($51|0)==($28|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 $52 = $51;
 $53 = $27;
 $54 = (($52) - ($53))|0;
 $55 = $54 >> 3;
 $56 = (($27) + ($55<<3)|0);
 $57 = $28;
 $58 = (($57) - ($52))|0;
 $59 = $58 >> 3;
 $$sum$i = (($55) + ($59))|0;
 $60 = (($27) + ($$sum$i<<3)|0);
 $61 = ($60|0)==($28|0);
 if ($61) {
  $$0$lcssa$i$i$i = $56;
 } else {
  $__first5$i$i$i = $60;
  $scevgep$i$i1$i = (($28) + -8|0);
  $62 = (0 - ($__first5$i$i$i))|0;
  $uglygep$i$i3$i = (($scevgep$i$i1$i) + ($62)|0);
  $$012$i$i$i = $60;$$03$i$i$i = $56;
  while(1) {
   $63 = HEAP32[$$012$i$i$i>>2]|0;
   HEAP32[$$03$i$i$i>>2] = $63;
   $64 = (($$012$i$i$i) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($$03$i$i$i) + 4|0);
   HEAP32[$66>>2] = $65;
   $67 = (($$012$i$i$i) + 8|0);
   $68 = (($$03$i$i$i) + 8|0);
   $69 = ($67|0)==($28|0);
   if ($69) {
    break;
   } else {
    $$012$i$i$i = $67;$$03$i$i$i = $68;
   }
  }
  $uglygep6$i$i$i = $uglygep$i$i3$i;
  $70 = $uglygep6$i$i$i >>> 3;
  $71 = (($55) + 1)|0;
  $$sum5$i = (($71) + ($70))|0;
  $scevgep7$i$i$i = (($27) + ($$sum5$i<<3)|0);
  $$0$lcssa$i$i$i = $scevgep7$i$i$i;
 }
 $72 = ($28|0)==($$0$lcssa$i$i$i|0);
 if ($72) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i = $$0$lcssa$i$i$i;
 $scevgep$i$i$i = (($28) + -8|0);
 $73 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($73)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $74 = $uglygep3$i$i$i >>> 3;
 $75 = $74 ^ -1;
 $scevgep4$i$i$i = (($28) + ($75<<3)|0);
 HEAP32[$5>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __ZNSt3__113__stable_sortIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeEi($__first,$__last,$__comp,$__len,$__buff,$__buff_size) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len = $__len|0;
 $__buff = $__buff|0;
 $__buff_size = $__buff_size|0;
 var $$01$lcssa$i = 0, $$0113$i = 0, $$014$i = 0, $$12$i = 0, $$17$i = 0, $$2$i = 0, $$234$i = 0, $$byval_copy10 = 0, $$byval_copy8 = 0, $$byval_copy9 = 0, $$lcssa$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $__len$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy10 = sp + 52|0;
 $$byval_copy9 = sp + 48|0;
 $$byval_copy8 = sp + 44|0;
 $0 = sp + 40|0;
 $1 = sp + 36|0;
 $2 = sp + 32|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = sp + 20|0;
 if ((($__len|0) == 1) | (($__len|0) == 0)) {
  STACKTOP = sp;return;
 } else if ((($__len|0) == 2)) {
  $11 = HEAP32[$__last>>2]|0;
  $12 = (($11) + -8|0);
  HEAP32[$__last>>2] = $12;
  $13 = HEAP32[$__first>>2]|0;
  $14 = HEAP32[$12>>2]|0;
  $15 = HEAP32[$13>>2]|0;
  $16 = ($14|0)<($15|0);
  if (!($16)) {
   STACKTOP = sp;return;
  }
  HEAP32[$13>>2] = $14;
  HEAP32[$12>>2] = $15;
  $17 = (($13) + 4|0);
  $18 = (($11) + -4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$18>>2]|0;
  HEAP32[$17>>2] = $20;
  HEAP32[$18>>2] = $19;
  STACKTOP = sp;return;
 } else {
  $21 = ($__len|0)<(1);
  if ($21) {
   $22 = HEAP32[$__first>>2]|0;
   $23 = HEAP32[$__last>>2]|0;
   $24 = ($22|0)==($23|0);
   if ($24) {
    STACKTOP = sp;return;
   }
   $25 = (($22) + 8|0);
   $26 = ($25|0)==($23|0);
   if ($26) {
    STACKTOP = sp;return;
   } else {
    $28 = $25;
   }
   while(1) {
    $27 = $28;
    $29 = $27;
    $30 = HEAP32[$29>>2]|0;
    $31 = (($27) + 4)|0;
    $32 = $31;
    $33 = HEAP32[$32>>2]|0;
    $34 = ($28|0)==($22|0);
    L18: do {
     if ($34) {
      $$lcssa$i = $22;
     } else {
      $36 = $28;
      while(1) {
       $35 = (($36) + -8|0);
       $37 = HEAP32[$35>>2]|0;
       $38 = ($30|0)<($37|0);
       if (!($38)) {
        $$lcssa$i = $36;
        break L18;
       }
       HEAP32[$36>>2] = $37;
       $39 = (($36) + -4|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = (($36) + 4|0);
       HEAP32[$41>>2] = $40;
       $42 = ($35|0)==($22|0);
       if ($42) {
        $$lcssa$i = $22;
        break;
       } else {
        $36 = $35;
       }
      }
     }
    } while(0);
    HEAP32[$$lcssa$i>>2] = $30;
    $43 = (($$lcssa$i) + 4|0);
    HEAP32[$43>>2] = $33;
    $44 = (($28) + 8|0);
    $45 = ($44|0)==($23|0);
    if ($45) {
     break;
    } else {
     $28 = $44;
    }
   }
   STACKTOP = sp;return;
  }
  $46 = (($__len|0) / 2)&-1;
  $47 = HEAP32[$__first>>2]|0;
  $48 = (($47) + ($46<<3)|0);
  $49 = ($__len|0)>($__buff_size|0);
  if ($49) {
   HEAP32[$4>>2] = $47;
   HEAP32[$5>>2] = $48;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$5+0>>2]|0;
   __ZNSt3__113__stable_sortIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeEi($$byval_copy9,$$byval_copy10,$__comp,$46,$__buff,$__buff_size);
   HEAP32[$6>>2] = $48;
   $88 = HEAP32[$__last>>2]|0;
   HEAP32[$7>>2] = $88;
   $89 = (($__len) - ($46))|0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$6+0>>2]|0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$7+0>>2]|0;
   __ZNSt3__113__stable_sortIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeEi($$byval_copy9,$$byval_copy10,$__comp,$89,$__buff,$__buff_size);
   HEAP32[$8>>2] = $47;
   HEAP32[$9>>2] = $48;
   HEAP32[$10>>2] = $88;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$8+0>>2]|0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$9+0>>2]|0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$10+0>>2]|0;
   __ZNSt3__115__inplace_mergeIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_SE_T_NS_15iterator_traitsISE_E15difference_typeESI_PNSH_10value_typeEi($$byval_copy8,$$byval_copy9,$$byval_copy10,$__comp,$46,$89,$__buff,$__buff_size);
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $47;
  HEAP32[$1>>2] = $48;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__118__stable_sort_moveIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeE($$byval_copy9,$$byval_copy10,$__comp,$46,$__buff);
  HEAP32[$2>>2] = $48;
  $50 = HEAP32[$__last>>2]|0;
  HEAP32[$3>>2] = $50;
  $51 = (($__len) - ($46))|0;
  $52 = (($__buff) + ($46<<3)|0);
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
  __ZNSt3__118__stable_sort_moveIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeE($$byval_copy9,$$byval_copy10,$__comp,$51,$52);
  $53 = (($__buff) + ($__len<<3)|0);
  $__len$off = (($__len) + 1)|0;
  $54 = ($__len$off>>>0)<(3);
  L29: do {
   if ($54) {
    $$01$lcssa$i = $52;$90 = $47;
   } else {
    $$0113$i = $52;$$014$i = $__buff;$69 = $47;
    while(1) {
     $56 = ($$0113$i|0)==($53|0);
     if ($56) {
      break;
     }
     $66 = HEAP32[$$0113$i>>2]|0;
     $67 = HEAP32[$$014$i>>2]|0;
     $68 = ($66|0)<($67|0);
     if ($68) {
      HEAP32[$69>>2] = $66;
      $70 = (($$0113$i) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = (($69) + 4|0);
      HEAP32[$72>>2] = $71;
      $73 = (($$0113$i) + 8|0);
      $$12$i = $73;$$2$i = $$014$i;
     } else {
      HEAP32[$69>>2] = $67;
      $74 = (($$014$i) + 4|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($69) + 4|0);
      HEAP32[$76>>2] = $75;
      $77 = (($$014$i) + 8|0);
      $$12$i = $$0113$i;$$2$i = $77;
     }
     $78 = (($69) + 8|0);
     $79 = ($$2$i|0)==($52|0);
     if ($79) {
      $$01$lcssa$i = $$12$i;$90 = $78;
      break L29;
     } else {
      $$0113$i = $$12$i;$$014$i = $$2$i;$69 = $78;
     }
    }
    $57 = ($$014$i|0)==($52|0);
    if ($57) {
     STACKTOP = sp;return;
    } else {
     $$17$i = $$014$i;$59 = $69;
    }
    while(1) {
     $58 = HEAP32[$$17$i>>2]|0;
     HEAP32[$59>>2] = $58;
     $60 = (($$17$i) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($59) + 4|0);
     HEAP32[$62>>2] = $61;
     $63 = (($$17$i) + 8|0);
     $64 = (($59) + 8|0);
     $65 = ($63|0)==($52|0);
     if ($65) {
      break;
     } else {
      $$17$i = $63;$59 = $64;
     }
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $55 = ($$01$lcssa$i|0)==($53|0);
  if ($55) {
   STACKTOP = sp;return;
  } else {
   $$234$i = $$01$lcssa$i;$81 = $90;
  }
  while(1) {
   $80 = HEAP32[$$234$i>>2]|0;
   HEAP32[$81>>2] = $80;
   $82 = (($$234$i) + 4|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($81) + 4|0);
   HEAP32[$84>>2] = $83;
   $85 = (($$234$i) + 8|0);
   $86 = (($81) + 8|0);
   $87 = ($85|0)==($53|0);
   if ($87) {
    break;
   } else {
    $$234$i = $85;$81 = $86;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__118__stable_sort_moveIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeE($__first1,$__last1,$__comp,$__len,$__first2) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__comp = $__comp|0;
 $__len = $__len|0;
 $__first2 = $__first2|0;
 var $$0$lcssa$i = 0, $$013$i = 0, $$11$i = 0, $$24$i = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$promoted6$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__first2$pn$ph$i = 0, $__first2$pn$ph$pn$i = 0, $__i2$02$i = 0, $__j2$0$lcssa$i = 0, $__last2$05$i = 0, $__len$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 20|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 if ((($__len|0) == 2)) {
  $16 = HEAP32[$__last1>>2]|0;
  $17 = (($16) + -8|0);
  HEAP32[$__last1>>2] = $17;
  $18 = HEAP32[$__first1>>2]|0;
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$18>>2]|0;
  $21 = ($19|0)<($20|0);
  $22 = ($__first2|0)==(0|0);
  if ($21) {
   if (!($22)) {
    $23 = $17;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 4)|0;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = $__first2;
    $30 = $29;
    HEAP32[$30>>2] = $25;
    $31 = (($29) + 4)|0;
    $32 = $31;
    HEAP32[$32>>2] = $28;
   }
   $33 = (($__first2) + 8|0);
   $34 = $18;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $33;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   STACKTOP = sp;return;
  } else {
   if (!($22)) {
    $44 = $18;
    $45 = $44;
    $46 = HEAP32[$45>>2]|0;
    $47 = (($44) + 4)|0;
    $48 = $47;
    $49 = HEAP32[$48>>2]|0;
    $50 = $__first2;
    $51 = $50;
    HEAP32[$51>>2] = $46;
    $52 = (($50) + 4)|0;
    $53 = $52;
    HEAP32[$53>>2] = $49;
   }
   $54 = (($__first2) + 8|0);
   $55 = $17;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = (($55) + 4)|0;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = $54;
   $62 = $61;
   HEAP32[$62>>2] = $57;
   $63 = (($61) + 4)|0;
   $64 = $63;
   HEAP32[$64>>2] = $60;
   STACKTOP = sp;return;
  }
 } else if ((($__len|0) == 0)) {
  STACKTOP = sp;return;
 } else if ((($__len|0) == 1)) {
  $4 = ($__first2|0)==(0|0);
  if ($4) {
   STACKTOP = sp;return;
  }
  $5 = HEAP32[$__first1>>2]|0;
  $6 = $5;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $__first2;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  STACKTOP = sp;return;
 } else {
  $65 = ($__len|0)<(9);
  if ($65) {
   $66 = HEAP32[$__first1>>2]|0;
   $67 = HEAP32[$__last1>>2]|0;
   $68 = ($66|0)==($67|0);
   if ($68) {
    STACKTOP = sp;return;
   }
   $69 = ($__first2|0)==(0|0);
   if ($69) {
    $__first2$pn$ph$i = 0;
   } else {
    $70 = $66;
    $71 = $70;
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + 4)|0;
    $74 = $73;
    $75 = HEAP32[$74>>2]|0;
    $76 = $__first2;
    $77 = $76;
    HEAP32[$77>>2] = $72;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = $75;
    $__first2$pn$ph$i = $__first2;
   }
   $80 = (($66) + 8|0);
   $81 = ($80|0)==($67|0);
   if ($81) {
    STACKTOP = sp;return;
   } else {
    $83 = $80;$__first2$pn$ph$pn$i = $__first2$pn$ph$i;
   }
   while(1) {
    $__last2$05$i = (($__first2$pn$ph$pn$i) + 8|0);
    $82 = HEAP32[$83>>2]|0;
    $84 = HEAP32[$__first2$pn$ph$pn$i>>2]|0;
    $85 = ($82|0)<($84|0);
    if ($85) {
     $86 = $__first2$pn$ph$pn$i;
     $87 = $86;
     $88 = HEAP32[$87>>2]|0;
     $89 = (($86) + 4)|0;
     $90 = $89;
     $91 = HEAP32[$90>>2]|0;
     $92 = $__last2$05$i;
     $93 = $92;
     HEAP32[$93>>2] = $88;
     $94 = (($92) + 4)|0;
     $95 = $94;
     HEAP32[$95>>2] = $91;
     $96 = ($__first2$pn$ph$pn$i|0)==($__first2|0);
     L35: do {
      if ($96) {
       $__j2$0$lcssa$i = $__first2;
      } else {
       $__i2$02$i = $__first2$pn$ph$pn$i;
       while(1) {
        $97 = (($__i2$02$i) + -8|0);
        $98 = HEAP32[$83>>2]|0;
        $99 = HEAP32[$97>>2]|0;
        $100 = ($98|0)<($99|0);
        if (!($100)) {
         $__j2$0$lcssa$i = $__i2$02$i;
         break L35;
        }
        HEAP32[$__i2$02$i>>2] = $99;
        $101 = (($__i2$02$i) + -4|0);
        $102 = HEAP32[$101>>2]|0;
        $103 = (($__i2$02$i) + 4|0);
        HEAP32[$103>>2] = $102;
        $104 = ($97|0)==($__first2|0);
        if ($104) {
         $__j2$0$lcssa$i = $__first2;
         break;
        } else {
         $__i2$02$i = $97;
        }
       }
      }
     } while(0);
     $105 = HEAP32[$83>>2]|0;
     HEAP32[$__j2$0$lcssa$i>>2] = $105;
     $106 = (($83) + 4|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = (($__j2$0$lcssa$i) + 4|0);
     HEAP32[$108>>2] = $107;
    } else {
     $111 = $83;
     $112 = $111;
     $113 = HEAP32[$112>>2]|0;
     $114 = (($111) + 4)|0;
     $115 = $114;
     $116 = HEAP32[$115>>2]|0;
     $117 = $__last2$05$i;
     $118 = $117;
     HEAP32[$118>>2] = $113;
     $119 = (($117) + 4)|0;
     $120 = $119;
     HEAP32[$120>>2] = $116;
    }
    $109 = (($83) + 8|0);
    $110 = ($109|0)==($67|0);
    if ($110) {
     break;
    } else {
     $83 = $109;$__first2$pn$ph$pn$i = $__last2$05$i;
    }
   }
   STACKTOP = sp;return;
  }
  $121 = (($__len|0) / 2)&-1;
  $122 = HEAP32[$__first1>>2]|0;
  $123 = (($122) + ($121<<3)|0);
  HEAP32[$0>>2] = $122;
  HEAP32[$1>>2] = $123;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__113__stable_sortIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeEi($$byval_copy2,$$byval_copy3,$__comp,$121,$__first2,$121);
  HEAP32[$2>>2] = $123;
  $124 = HEAP32[$__last1>>2]|0;
  HEAP32[$3>>2] = $124;
  $125 = (($__len) - ($121))|0;
  $126 = (($__first2) + ($121<<3)|0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
  __ZNSt3__113__stable_sortIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeEi($$byval_copy2,$$byval_copy3,$__comp,$125,$126,$125);
  $__len$off = (($__len) + 1)|0;
  $127 = ($__len$off>>>0)<(3);
  L44: do {
   if ($127) {
    $$0$lcssa$i = $__first2;$129 = $122;
   } else {
    $$013$i = $__first2;$$promoted6$i = $122;$146 = $123;
    while(1) {
     $145 = ($146|0)==($124|0);
     if ($145) {
      break;
     }
     $163 = HEAP32[$146>>2]|0;
     $164 = HEAP32[$$promoted6$i>>2]|0;
     $165 = ($163|0)<($164|0);
     $166 = ($$013$i|0)==(0|0);
     if ($165) {
      if (!($166)) {
       $167 = $146;
       $168 = $167;
       $169 = HEAP32[$168>>2]|0;
       $170 = (($167) + 4)|0;
       $171 = $170;
       $172 = HEAP32[$171>>2]|0;
       $173 = $$013$i;
       $174 = $173;
       HEAP32[$174>>2] = $169;
       $175 = (($173) + 4)|0;
       $176 = $175;
       HEAP32[$176>>2] = $172;
      }
      $177 = (($146) + 8|0);
      $191 = $$promoted6$i;$192 = $177;
     } else {
      if (!($166)) {
       $178 = $$promoted6$i;
       $179 = $178;
       $180 = HEAP32[$179>>2]|0;
       $181 = (($178) + 4)|0;
       $182 = $181;
       $183 = HEAP32[$182>>2]|0;
       $184 = $$013$i;
       $185 = $184;
       HEAP32[$185>>2] = $180;
       $186 = (($184) + 4)|0;
       $187 = $186;
       HEAP32[$187>>2] = $183;
      }
      $188 = (($$promoted6$i) + 8|0);
      $191 = $188;$192 = $146;
     }
     $189 = (($$013$i) + 8|0);
     $190 = ($191|0)==($123|0);
     if ($190) {
      $$0$lcssa$i = $189;$129 = $192;
      break L44;
     } else {
      $$013$i = $189;$$promoted6$i = $191;$146 = $192;
     }
    }
    $147 = ($$promoted6$i|0)==($123|0);
    if ($147) {
     STACKTOP = sp;return;
    } else {
     $$24$i = $$013$i;$150 = $$promoted6$i;
    }
    while(1) {
     $148 = ($$24$i|0)==(0|0);
     if (!($148)) {
      $149 = $150;
      $151 = $149;
      $152 = HEAP32[$151>>2]|0;
      $153 = (($149) + 4)|0;
      $154 = $153;
      $155 = HEAP32[$154>>2]|0;
      $156 = $$24$i;
      $157 = $156;
      HEAP32[$157>>2] = $152;
      $158 = (($156) + 4)|0;
      $159 = $158;
      HEAP32[$159>>2] = $155;
     }
     $160 = (($150) + 8|0);
     $161 = (($$24$i) + 8|0);
     $162 = ($160|0)==($123|0);
     if ($162) {
      break;
     } else {
      $$24$i = $161;$150 = $160;
     }
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $128 = ($129|0)==($124|0);
  if ($128) {
   STACKTOP = sp;return;
  } else {
   $$11$i = $$0$lcssa$i;$132 = $129;
  }
  while(1) {
   $130 = ($$11$i|0)==(0|0);
   if (!($130)) {
    $131 = $132;
    $133 = $131;
    $134 = HEAP32[$133>>2]|0;
    $135 = (($131) + 4)|0;
    $136 = $135;
    $137 = HEAP32[$136>>2]|0;
    $138 = $$11$i;
    $139 = $138;
    HEAP32[$139>>2] = $134;
    $140 = (($138) + 4)|0;
    $141 = $140;
    HEAP32[$141>>2] = $137;
   }
   $142 = (($132) + 8|0);
   $143 = (($$11$i) + 8|0);
   $144 = ($142|0)==($124|0);
   if ($144) {
    break;
   } else {
    $$11$i = $143;$132 = $142;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__115__inplace_mergeIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_SE_T_NS_15iterator_traitsISE_E15difference_typeESI_PNSH_10value_typeEi($__first,$__middle,$__last,$__comp,$__len1,$__len2,$__buff,$__buff_size) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len1 = $__len1|0;
 $__len2 = $__len2|0;
 $__buff = $__buff|0;
 $__buff_size = $__buff_size|0;
 var $$$i$i = 0, $$0$be = 0, $$01$be = 0, $$0172 = 0, $$073 = 0, $$11$i$i = 0, $$150 = 0, $$byval_copy6 = 0, $$byval_copy7 = 0, $$byval_copy8 = 0, $$neg2$i = 0, $$neg2$i18 = 0, $$ph$i$i = 0, $$ph12$i$i = 0, $$ph13$i$i = 0, $$pre = 0, $$promoted$i$i$i = 0, $$sum$i = 0, $$sum$i$i$i = 0, $$sum$i17 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__len$0$be$i = 0, $__len$0$be$i19 = 0, $__len$03$i = 0, $__len$03$i16 = 0, $__len11$0 = 0, $__len21$0 = 0, $or$cond = 0, $scevgep$i$i$i = 0, $scevgep13$i$i$i = 0, $storemerge = 0, $uglygep$i$i$i = 0, $uglygep12$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 44|0;
 $$byval_copy7 = sp + 40|0;
 $$byval_copy6 = sp + 36|0;
 $0 = sp + 32|0;
 $1 = sp + 28|0;
 $2 = sp + 24|0;
 $3 = sp + 20|0;
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = sp + 16|0;
 $9 = ($__len2|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $$0172 = $__len2;$$073 = $__len1;
 L4: while(1) {
  $10 = ($$073|0)==(0);
  if ($10) {
   label = 39;
   break;
  }
  $11 = HEAP32[$__middle>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $$pre = HEAP32[$__first>>2]|0;
  $$150 = $$073;$14 = $$pre;
  while(1) {
   $13 = HEAP32[$14>>2]|0;
   $15 = ($12|0)<($13|0);
   if ($15) {
    break;
   }
   $16 = (($14) + 8|0);
   HEAP32[$__first>>2] = $16;
   $17 = (($$150) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    label = 39;
    break L4;
   } else {
    $$150 = $17;$14 = $16;
   }
  }
  $19 = ($$150|0)>($__buff_size|0);
  $20 = ($$0172|0)>($__buff_size|0);
  $or$cond = $19 & $20;
  if (!($or$cond)) {
   label = 8;
   break;
  }
  $22 = ($$150|0)<($$0172|0);
  if ($22) {
   $23 = (($$0172|0) / 2)&-1;
   $24 = (($11) + ($23<<3)|0);
   $25 = $11;
   $26 = $14;
   $27 = (($25) - ($26))|0;
   $28 = $27 >> 3;
   $29 = ($28|0)==(0);
   if ($29) {
    $40 = $14;
   } else {
    $30 = HEAP32[$24>>2]|0;
    $33 = $14;$__len$03$i16 = $28;
    while(1) {
     $31 = (($__len$03$i16|0) / 2)&-1;
     $32 = (($33) + ($31<<3)|0);
     $34 = HEAP32[$32>>2]|0;
     $35 = ($30|0)<($34|0);
     if ($35) {
      $119 = $33;$__len$0$be$i19 = $31;
     } else {
      $$sum$i17 = (($31) + 1)|0;
      $36 = (($33) + ($$sum$i17<<3)|0);
      $$neg2$i18 = (($__len$03$i16) + -1)|0;
      $37 = (($$neg2$i18) - ($31))|0;
      $119 = $36;$__len$0$be$i19 = $37;
     }
     $38 = ($__len$0$be$i19|0)==(0);
     if ($38) {
      $40 = $119;
      break;
     } else {
      $33 = $119;$__len$03$i16 = $__len$0$be$i19;
     }
    }
   }
   $39 = $40;
   $41 = (($39) - ($26))|0;
   $42 = $41 >> 3;
   $72 = $40;$74 = $24;$__len11$0 = $42;$__len21$0 = $23;
  } else {
   $43 = ($$150|0)==(1);
   if ($43) {
    label = 17;
    break;
   }
   $48 = (($$150|0) / 2)&-1;
   $49 = (($14) + ($48<<3)|0);
   $50 = HEAP32[$__last>>2]|0;
   $51 = $50;
   $52 = $11;
   $53 = (($51) - ($52))|0;
   $54 = $53 >> 3;
   $55 = ($54|0)==(0);
   if ($55) {
    $66 = $11;
   } else {
    $56 = HEAP32[$49>>2]|0;
    $59 = $11;$__len$03$i = $54;
    while(1) {
     $57 = (($__len$03$i|0) / 2)&-1;
     $58 = (($59) + ($57<<3)|0);
     $60 = HEAP32[$58>>2]|0;
     $61 = ($60|0)<($56|0);
     if ($61) {
      $$sum$i = (($57) + 1)|0;
      $62 = (($59) + ($$sum$i<<3)|0);
      $$neg2$i = (($__len$03$i) + -1)|0;
      $63 = (($$neg2$i) - ($57))|0;
      $120 = $62;$__len$0$be$i = $63;
     } else {
      $120 = $59;$__len$0$be$i = $57;
     }
     $64 = ($__len$0$be$i|0)==(0);
     if ($64) {
      $66 = $120;
      break;
     } else {
      $59 = $120;$__len$03$i = $__len$0$be$i;
     }
    }
   }
   $65 = $66;
   $67 = (($65) - ($52))|0;
   $68 = $67 >> 3;
   $72 = $49;$74 = $66;$__len11$0 = $48;$__len21$0 = $68;
  }
  $69 = (($$150) - ($__len11$0))|0;
  $70 = (($$0172) - ($__len21$0))|0;
  $71 = ($72|0)==($11|0);
  L33: do {
   if ($71) {
    $113 = $74;
   } else {
    $73 = ($11|0)==($74|0);
    if ($73) {
     $113 = $72;
    } else {
     $75 = HEAP32[$72>>2]|0;
     HEAP32[$72>>2] = $12;
     HEAP32[$11>>2] = $75;
     $76 = (($72) + 4|0);
     $77 = (($11) + 4|0);
     $78 = HEAP32[$76>>2]|0;
     $79 = HEAP32[$77>>2]|0;
     HEAP32[$76>>2] = $79;
     HEAP32[$77>>2] = $78;
     $80 = (($72) + 8|0);
     $81 = (($11) + 8|0);
     $82 = ($81|0)==($74|0);
     if ($82) {
      $$promoted$i$i$i = $80;$100 = $11;
     } else {
      $83 = $11;
      $scevgep$i$i$i = (($74) + -16|0);
      $84 = (0 - ($83))|0;
      $86 = $80;$87 = $11;$88 = $81;
      while(1) {
       $85 = ($86|0)==($87|0);
       $$$i$i = $85 ? $88 : $87;
       $89 = HEAP32[$86>>2]|0;
       $90 = HEAP32[$88>>2]|0;
       HEAP32[$86>>2] = $90;
       HEAP32[$88>>2] = $89;
       $91 = (($86) + 4|0);
       $92 = (($88) + 4|0);
       $93 = HEAP32[$91>>2]|0;
       $94 = HEAP32[$92>>2]|0;
       HEAP32[$91>>2] = $94;
       HEAP32[$92>>2] = $93;
       $95 = (($86) + 8|0);
       $96 = (($88) + 8|0);
       $97 = ($96|0)==($74|0);
       if ($97) {
        break;
       } else {
        $86 = $95;$87 = $$$i$i;$88 = $96;
       }
      }
      $uglygep$i$i$i = (($scevgep$i$i$i) + ($84)|0);
      $uglygep12$i$i$i = $uglygep$i$i$i;
      $98 = $uglygep12$i$i$i >>> 3;
      $$sum$i$i$i = (($98) + 2)|0;
      $scevgep13$i$i$i = (($72) + ($$sum$i$i$i<<3)|0);
      $$promoted$i$i$i = $scevgep13$i$i$i;$100 = $$$i$i;
     }
     $99 = ($$promoted$i$i$i|0)==($100|0);
     if ($99) {
      $113 = $100;
     } else {
      $$ph$i$i = $100;$$ph12$i$i = $$promoted$i$i$i;$$ph13$i$i = $100;
      while(1) {
       $102 = $$ph12$i$i;$104 = $$ph13$i$i;
       while(1) {
        $101 = HEAP32[$102>>2]|0;
        $103 = HEAP32[$104>>2]|0;
        HEAP32[$102>>2] = $103;
        HEAP32[$104>>2] = $101;
        $105 = (($102) + 4|0);
        $106 = (($104) + 4|0);
        $107 = HEAP32[$105>>2]|0;
        $108 = HEAP32[$106>>2]|0;
        HEAP32[$105>>2] = $108;
        HEAP32[$106>>2] = $107;
        $109 = (($102) + 8|0);
        $110 = (($104) + 8|0);
        $111 = ($110|0)==($74|0);
        $112 = ($109|0)==($$ph$i$i|0);
        if (!($111)) {
         break;
        }
        if ($112) {
         $113 = $$promoted$i$i$i;
         break L33;
        } else {
         $102 = $109;$104 = $$ph$i$i;
        }
       }
       $$11$i$i = $112 ? $110 : $$ph$i$i;
       $$ph$i$i = $$11$i$i;$$ph12$i$i = $109;$$ph13$i$i = $110;
      }
     }
    }
   }
  } while(0);
  HEAP32[$__middle>>2] = $113;
  $114 = (($__len21$0) + ($__len11$0))|0;
  $115 = (($70) + ($69))|0;
  $116 = ($114|0)<($115|0);
  if ($116) {
   HEAP32[$3>>2] = $14;
   HEAP32[$4>>2] = $72;
   HEAP32[$5>>2] = $113;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$5+0>>2]|0;
   __ZNSt3__115__inplace_mergeIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_SE_T_NS_15iterator_traitsISE_E15difference_typeESI_PNSH_10value_typeEi($$byval_copy6,$$byval_copy7,$$byval_copy8,$__comp,$__len11$0,$__len21$0,$__buff,$__buff_size);
   HEAP32[$__first>>2] = $113;
   $$0$be = $69;$$01$be = $70;$storemerge = $74;
  } else {
   HEAP32[$6>>2] = $113;
   HEAP32[$7>>2] = $74;
   $117 = HEAP32[$__last>>2]|0;
   HEAP32[$8>>2] = $117;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$6+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$7+0>>2]|0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$8+0>>2]|0;
   __ZNSt3__115__inplace_mergeIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_SE_T_NS_15iterator_traitsISE_E15difference_typeESI_PNSH_10value_typeEi($$byval_copy6,$$byval_copy7,$$byval_copy8,$__comp,$69,$70,$__buff,$__buff_size);
   HEAP32[$__last>>2] = $113;
   $$0$be = $__len11$0;$$01$be = $__len21$0;$storemerge = $72;
  }
  HEAP32[$__middle>>2] = $storemerge;
  $118 = ($$01$be|0)==(0);
  if ($118) {
   label = 39;
   break;
  } else {
   $$0172 = $$01$be;$$073 = $$0$be;
  }
 }
 if ((label|0) == 8) {
  HEAP32[$0>>2] = $14;
  HEAP32[$1>>2] = $11;
  $21 = HEAP32[$__last>>2]|0;
  HEAP32[$2>>2] = $21;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
  __ZNSt3__124__buffered_inplace_mergeIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_SE_T_NS_15iterator_traitsISE_E15difference_typeESI_PNSH_10value_typeE($$byval_copy6,$$byval_copy7,$$byval_copy8,$__comp,$$150,$$0172,$__buff);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 17) {
  HEAP32[$14>>2] = $12;
  HEAP32[$11>>2] = $13;
  $44 = (($14) + 4|0);
  $45 = (($11) + 4|0);
  $46 = HEAP32[$44>>2]|0;
  $47 = HEAP32[$45>>2]|0;
  HEAP32[$44>>2] = $47;
  HEAP32[$45>>2] = $46;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 39) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__124__buffered_inplace_mergeIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_SE_T_NS_15iterator_traitsISE_E15difference_typeESI_PNSH_10value_typeE($__first,$__middle,$__last,$__comp,$__len1,$__len2,$__buff) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len1 = $__len1|0;
 $__len2 = $__len2|0;
 $__buff = $__buff|0;
 var $$c$i$i = 0, $$c$i$i$i$i = 0, $$c$i$i$i$i$i = 0, $$c$i$i$i25$i = 0, $$c$i$i14$i = 0, $$lcssa$i = 0, $$lcssa109 = 0, $$lcssa35$off32$i = 0, $$off32$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__p$0121 = 0, $__p1$0$lcssa = 0, $__p1$0110 = 0, $scevgep = 0, $scevgep137 = 0, $scevgep145 = 0, $scevgep149 = 0, $uglygep = 0, $uglygep136 = 0, $uglygep147 = 0, $uglygep147148 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__len1|0)>($__len2|0);
 if (!($0)) {
  $1 = HEAP32[$__first>>2]|0;
  $2 = HEAP32[$__middle>>2]|0;
  $3 = ($1|0)==($2|0);
  L3: do {
   if ($3) {
    $4 = HEAP32[$__last>>2]|0;
    $$lcssa$i = $1;$149 = $1;$55 = $4;
   } else {
    $5 = $1;
    $scevgep145 = (($2) + -8|0);
    $6 = (0 - ($5))|0;
    $uglygep147 = (($scevgep145) + ($6)|0);
    $uglygep147148 = $uglygep147;
    $7 = $uglygep147148 >>> 3;
    $8 = (($7) + 1)|0;
    $11 = $1;$__p$0121 = $__buff;
    while(1) {
     $9 = ($__p$0121|0)==(0|0);
     if (!($9)) {
      $10 = $11;
      $12 = $10;
      $13 = HEAP32[$12>>2]|0;
      $14 = (($10) + 4)|0;
      $15 = $14;
      $16 = HEAP32[$15>>2]|0;
      $17 = $__p$0121;
      $18 = $17;
      HEAP32[$18>>2] = $13;
      $19 = (($17) + 4)|0;
      $20 = $19;
      HEAP32[$20>>2] = $16;
     }
     $21 = (($11) + 8|0);
     $22 = (($__p$0121) + 8|0);
     $23 = ($21|0)==($2|0);
     if ($23) {
      break;
     } else {
      $11 = $21;$__p$0121 = $22;
     }
    }
    $scevgep149 = (($__buff) + ($8<<3)|0);
    $24 = HEAP32[$__last>>2]|0;
    $25 = ($scevgep149|0)==($__buff|0);
    if ($25) {
     $$lcssa$i = $2;$149 = $1;$55 = $24;
    } else {
     $27 = $2;$29 = $__buff;$42 = $1;
     while(1) {
      $26 = ($27|0)==($24|0);
      if ($26) {
       break;
      }
      $39 = HEAP32[$27>>2]|0;
      $40 = HEAP32[$29>>2]|0;
      $41 = ($39|0)<($40|0);
      if ($41) {
       HEAP32[$42>>2] = $39;
       $43 = (($27) + 4|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = (($42) + 4|0);
       HEAP32[$45>>2] = $44;
       $46 = (($27) + 8|0);
       $150 = $46;$53 = $29;
      } else {
       HEAP32[$42>>2] = $40;
       $47 = (($29) + 4|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = (($42) + 4|0);
       HEAP32[$49>>2] = $48;
       $50 = (($29) + 8|0);
       $150 = $27;$53 = $50;
      }
      $51 = (($42) + 8|0);
      $52 = ($53|0)==($scevgep149|0);
      if ($52) {
       $$lcssa$i = $150;$149 = $51;$55 = $24;
       break L3;
      } else {
       $27 = $150;$29 = $53;$42 = $51;
      }
     }
     $28 = ($29|0)==($scevgep149|0);
     if ($28) {
      STACKTOP = sp;return;
     } else {
      $31 = $29;$32 = $42;
     }
     while(1) {
      $30 = HEAP32[$31>>2]|0;
      HEAP32[$32>>2] = $30;
      $33 = (($31) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($32) + 4|0);
      HEAP32[$35>>2] = $34;
      $36 = (($31) + 8|0);
      $37 = (($32) + 8|0);
      $38 = ($36|0)==($scevgep149|0);
      if ($38) {
       break;
      } else {
       $31 = $36;$32 = $37;
      }
     }
     STACKTOP = sp;return;
    }
   }
  } while(0);
  $54 = ($$lcssa$i|0)==($55|0);
  if ($54) {
   STACKTOP = sp;return;
  } else {
   $57 = $$lcssa$i;$58 = $149;
  }
  while(1) {
   $56 = HEAP32[$57>>2]|0;
   HEAP32[$58>>2] = $56;
   $59 = (($57) + 4|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($58) + 4|0);
   HEAP32[$61>>2] = $60;
   $62 = (($57) + 8|0);
   $63 = (($58) + 8|0);
   $64 = ($62|0)==($55|0);
   if ($64) {
    break;
   } else {
    $57 = $62;$58 = $63;
   }
  }
  STACKTOP = sp;return;
 }
 $65 = HEAP32[$__middle>>2]|0;
 $66 = $65;
 $67 = HEAP32[$__last>>2]|0;
 $68 = ($65|0)==($67|0);
 if ($68) {
  $$lcssa109 = $65;$__p1$0$lcssa = $__buff;
 } else {
  $scevgep = (($67) + -8|0);
  $69 = (0 - ($66))|0;
  $uglygep = (($scevgep) + ($69)|0);
  $uglygep136 = $uglygep;
  $70 = $uglygep136 >>> 3;
  $71 = (($70) + 1)|0;
  $74 = $65;$__p1$0110 = $__buff;
  while(1) {
   $72 = ($__p1$0110|0)==(0|0);
   if (!($72)) {
    $73 = $74;
    $75 = $73;
    $76 = HEAP32[$75>>2]|0;
    $77 = (($73) + 4)|0;
    $78 = $77;
    $79 = HEAP32[$78>>2]|0;
    $80 = $__p1$0110;
    $81 = $80;
    HEAP32[$81>>2] = $76;
    $82 = (($80) + 4)|0;
    $83 = $82;
    HEAP32[$83>>2] = $79;
   }
   $84 = (($74) + 8|0);
   $85 = (($__p1$0110) + 8|0);
   $86 = ($84|0)==($67|0);
   if ($86) {
    break;
   } else {
    $74 = $84;$__p1$0110 = $85;
   }
  }
  $scevgep137 = (($__buff) + ($71<<3)|0);
  $$lcssa109 = $67;$__p1$0$lcssa = $scevgep137;
 }
 $87 = HEAP32[$__first>>2]|0;
 $88 = $$lcssa109;
 $89 = ($65|0)==($87|0);
 $90 = $__p1$0$lcssa;
 L41: do {
  if ($89) {
   $$lcssa35$off32$i = $90;$136 = $88;
  } else {
   $$off32$i = $90;$113 = $__p1$0$lcssa;$114 = $66;$94 = $65;$96 = $88;
   while(1) {
    $91 = $$off32$i;
    $92 = ($91|0)==($__buff|0);
    if ($92) {
     break;
    }
    $112 = (($113) + -8|0);
    $$c$i$i14$i = $114;
    $115 = (($$c$i$i14$i) + -8|0);
    $116 = HEAP32[$112>>2]|0;
    $117 = HEAP32[$115>>2]|0;
    $118 = ($116|0)<($117|0);
    $$c$i$i = $96;
    $119 = (($$c$i$i) + -8|0);
    if ($118) {
     HEAP32[$119>>2] = $117;
     $123 = (($$c$i$i14$i) + -4|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = (($$c$i$i) + -4|0);
     HEAP32[$125>>2] = $124;
     $126 = $115;
     $129 = $126;$132 = $113;
    } else {
     HEAP32[$119>>2] = $116;
     $120 = (($113) + -4|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = (($$c$i$i) + -4|0);
     HEAP32[$122>>2] = $121;
     $129 = $114;$132 = $112;
    }
    $127 = $119;
    $128 = $129;
    $130 = ($128|0)==($87|0);
    $131 = $132;
    if ($130) {
     $$lcssa35$off32$i = $131;$136 = $127;
     break L41;
    } else {
     $$off32$i = $131;$113 = $132;$114 = $129;$94 = $128;$96 = $127;
    }
   }
   $93 = ($94|0)==($87|0);
   if ($93) {
    STACKTOP = sp;return;
   }
   $95 = $96;
   $106 = $94;$109 = $95;$97 = $96;$98 = $114;
   while(1) {
    $$c$i$i$i25$i = $97;
    $$c$i$i$i$i$i = $98;
    $99 = (($$c$i$i$i$i$i) + -8|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($$c$i$i$i25$i) + -8|0);
    HEAP32[$101>>2] = $100;
    $102 = (($$c$i$i$i$i$i) + -4|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($$c$i$i$i25$i) + -4|0);
    HEAP32[$104>>2] = $103;
    $105 = (($106) + -8|0);
    $107 = $105;
    $108 = (($109) + -8|0);
    $110 = $108;
    $111 = ($105|0)==($87|0);
    if ($111) {
     break;
    } else {
     $106 = $105;$109 = $108;$97 = $110;$98 = $107;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $133 = $$lcssa35$off32$i;
 $134 = ($133|0)==($__buff|0);
 if ($134) {
  STACKTOP = sp;return;
 }
 $135 = $136;
 $137 = $136;$139 = $133;$146 = $135;
 while(1) {
  $$c$i$i$i$i = $137;
  $138 = (($139) + -8|0);
  $140 = HEAP32[$138>>2]|0;
  $141 = (($$c$i$i$i$i) + -8|0);
  HEAP32[$141>>2] = $140;
  $142 = (($139) + -4|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = (($$c$i$i$i$i) + -4|0);
  HEAP32[$144>>2] = $143;
  $145 = (($146) + -8|0);
  $147 = $145;
  $148 = ($138|0)==($__buff|0);
  if ($148) {
   break;
  } else {
   $137 = $147;$139 = $138;$146 = $145;
  }
 }
 STACKTOP = sp;return;
}
function __Z19DecompressETC2_RGB8PhPKhiiii($dst,$src,$srcWidth,$srcHeight,$destWidth,$destHeight) {
 $dst = $dst|0;
 $src = $src|0;
 $srcWidth = $srcWidth|0;
 $srcHeight = $srcHeight|0;
 $destWidth = $destWidth|0;
 $destHeight = $destHeight|0;
 var $$sum = 0, $$sum1 = 0, $$sum23 = 0, $$sum4 = 0, $$sum56 = 0, $$sum78 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blockX$013 = 0, $blockY$016 = 0, $exitcond = 0, $exitcond21 = 0, $exitcond22 = 0, $exitcond23 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$next19 = 0, $indvars$iv$op = 0, $indvars$iv18 = 0, $indvars$iv18$op = 0, $uncompressedBlock = 0;
 var $x$09 = 0, $y$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $uncompressedBlock = sp;
 $0 = (($srcWidth|0) / 4)&-1;
 $1 = $srcWidth & 3;
 $2 = ($1|0)!=(0);
 $3 = $2&1;
 $4 = (($0) + ($3))|0;
 $5 = (($srcHeight|0) / 4)&-1;
 $6 = $srcHeight & 3;
 $7 = ($6|0)!=(0);
 $8 = $7&1;
 $9 = (($5) + ($8))|0;
 $10 = $destWidth << 2;
 $11 = ($9|0)>(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ($4|0)>(0);
 $13 = $destWidth ^ -1;
 $14 = $destHeight ^ -1;
 $blockY$016 = 0;$indvars$iv18 = $14;
 while(1) {
  $15 = ($indvars$iv18|0)>(-5);
  $indvars$iv18$op = $indvars$iv18 ^ -1;
  $16 = $15 ? $indvars$iv18$op : 4;
  if ($12) {
   $17 = Math_imul($blockY$016, $4)|0;
   $18 = $blockY$016 << 2;
   $19 = (($destHeight) - ($18))|0;
   $20 = ($19|0)>(0);
   $blockX$013 = 0;$indvars$iv = $13;
   while(1) {
    $21 = ($indvars$iv|0)>(-5);
    $indvars$iv$op = $indvars$iv ^ -1;
    $22 = $21 ? $indvars$iv$op : 4;
    $23 = (($blockX$013) + ($17))|0;
    $24 = $23 << 3;
    $25 = (($src) + ($24)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26&255;
    $28 = (_bitshift64Shl(($27|0),0,8)|0);
    $29 = tempRet0;
    $30 = $24 | 1;
    $31 = (($src) + ($30)|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = $32&255;
    $34 = $33 | $28;
    $35 = (_bitshift64Shl(($34|0),($29|0),8)|0);
    $36 = tempRet0;
    $37 = $24 | 2;
    $38 = (($src) + ($37)|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = $39&255;
    $41 = $35 | $40;
    $42 = (_bitshift64Shl(($41|0),($36|0),8)|0);
    $43 = tempRet0;
    $44 = $24 | 3;
    $45 = (($src) + ($44)|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46&255;
    $48 = $42 | $47;
    $49 = (_bitshift64Shl(($48|0),($43|0),8)|0);
    $50 = tempRet0;
    $51 = $24 | 4;
    $52 = (($src) + ($51)|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = $49 | $54;
    $56 = (_bitshift64Shl(($55|0),($50|0),8)|0);
    $57 = tempRet0;
    $58 = $24 | 5;
    $59 = (($src) + ($58)|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = $60&255;
    $62 = $56 | $61;
    $63 = (_bitshift64Shl(($62|0),($57|0),8)|0);
    $64 = tempRet0;
    $65 = $24 | 6;
    $66 = (($src) + ($65)|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67&255;
    $69 = $63 | $68;
    $70 = (_bitshift64Shl(($69|0),($64|0),8)|0);
    $71 = tempRet0;
    $72 = $24 | 7;
    $73 = (($src) + ($72)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = $70 | $75;
    __ZL19DecompressETC2BlockyPhS_b($76,$71,$uncompressedBlock,0,0);
    $77 = $blockX$013 << 2;
    if ($20) {
     $78 = (($destWidth) - ($77))|0;
     $79 = ($78|0)>(0);
     $y$010 = 0;
     while(1) {
      if ($79) {
       $80 = $y$010 << 2;
       $81 = (($y$010) + ($18))|0;
       $82 = Math_imul($10, $81)|0;
       $x$09 = 0;
       while(1) {
        $83 = (($x$09) + ($80))|0;
        $84 = ($83*3)|0;
        $85 = (($uncompressedBlock) + ($84)|0);
        $86 = (($x$09) + ($77))|0;
        $87 = $86 << 2;
        $$sum = (($87) + ($82))|0;
        $88 = (($dst) + ($$sum)|0);
        $89 = HEAP8[$85>>0]|0;
        HEAP8[$88>>0] = $89;
        $$sum1 = (($84) + 1)|0;
        $90 = (($uncompressedBlock) + ($$sum1)|0);
        $91 = HEAP8[$90>>0]|0;
        $$sum23 = $$sum | 1;
        $92 = (($dst) + ($$sum23)|0);
        HEAP8[$92>>0] = $91;
        $$sum4 = (($84) + 2)|0;
        $93 = (($uncompressedBlock) + ($$sum4)|0);
        $94 = HEAP8[$93>>0]|0;
        $$sum56 = $$sum | 2;
        $95 = (($dst) + ($$sum56)|0);
        HEAP8[$95>>0] = $94;
        $$sum78 = $$sum | 3;
        $96 = (($dst) + ($$sum78)|0);
        HEAP8[$96>>0] = -1;
        $97 = (($x$09) + 1)|0;
        $exitcond = ($97|0)==($22|0);
        if ($exitcond) {
         break;
        } else {
         $x$09 = $97;
        }
       }
      }
      $98 = (($y$010) + 1)|0;
      $exitcond21 = ($98|0)==($16|0);
      if ($exitcond21) {
       break;
      } else {
       $y$010 = $98;
      }
     }
    }
    $99 = (($blockX$013) + 1)|0;
    $indvars$iv$next = (($indvars$iv) + 4)|0;
    $exitcond22 = ($99|0)==($4|0);
    if ($exitcond22) {
     break;
    } else {
     $blockX$013 = $99;$indvars$iv = $indvars$iv$next;
    }
   }
  }
  $100 = (($blockY$016) + 1)|0;
  $indvars$iv$next19 = (($indvars$iv18) + 4)|0;
  $exitcond23 = ($100|0)==($9|0);
  if ($exitcond23) {
   break;
  } else {
   $blockY$016 = $100;$indvars$iv18 = $indvars$iv$next19;
  }
 }
 STACKTOP = sp;return;
}
function __ZL19DecompressETC2BlockyPhS_b($0,$1,$dst,$alphaDst,$alphaMode) {
 $0 = $0|0;
 $1 = $1|0;
 $dst = $dst|0;
 $alphaDst = $alphaDst|0;
 $alphaMode = $alphaMode|0;
 var $$ = 0, $$0$i = 0, $$0$i17 = 0, $$0$i20 = 0, $$0$i31 = 0, $$0$i34 = 0, $$0$i37 = 0, $$0$i40 = 0, $$0$i43 = 0, $$0$i46 = 0, $$0$i49 = 0, $$0$i52 = 0, $$0$i55 = 0, $$0$i58 = 0, $$0$i61 = 0, $$0$i64 = 0, $$0$i71 = 0, $$0$i74 = 0, $$0$i77 = 0, $$0$i80 = 0;
 var $$0$i83 = 0, $$0$i86 = 0, $$0$i90 = 0, $$0$i90$us = 0, $$0$i93 = 0, $$0$i93$us = 0, $$0$i96 = 0, $$0$i96$us = 0, $$masked = 0, $$masked149 = 0, $$masked151 = 0, $$masked153 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alphaMode$not = 0, $baseB = 0, $baseG = 0, $baseR = 0, $cond = 0, $exitcond = 0, $exitcond205 = 0, $exitcond206 = 0;
 var $exitcond207 = 0, $exitcond208 = 0, $exitcond209 = 0, $mode$0103 = 0, $modifier$0$us = 0, $or$cond = 0, $or$cond11 = 0, $or$cond14 = 0, $paintB = 0, $paintG = 0, $paintR = 0, $phitmp = 0, $phitmp131 = 0, $phitmp132 = 0, $phitmp135 = 0, $phitmp135$us = 0, $phitmp136 = 0, $phitmp136$us = 0, $phitmp137 = 0, $phitmp137$us = 0;
 var $phitmp157 = 0, $phitmp158 = 0, $phitmp159 = 0, $phitmp160 = 0, $phitmp161 = 0, $phitmp162 = 0, $phitmp163 = 0, $phitmp164 = 0, $phitmp165 = 0, $phitmp166 = 0, $phitmp167 = 0, $phitmp168 = 0, $phitmp179 = 0, $phitmp180 = 0, $phitmp181 = 0, $phitmp182 = 0, $phitmp183 = 0, $phitmp184 = 0, $pixelNdx$0197 = 0, $pixelNdx$0197$us = 0;
 var $pixelNdx9$0204 = 0, $pixelNdx9$0204$us = 0, $sext = 0, $sext114 = 0, $sext115 = 0, $table = 0, $x15$0199 = 0, $y14$0201 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $table = sp;
 $baseR = sp + 24|0;
 $baseG = sp + 8|0;
 $baseB = sp + 10|0;
 $paintR = sp + 12|0;
 $paintG = sp + 16|0;
 $paintB = sp + 20|0;
 $2 = (_bitshift64Lshr(($0|0),($1|0),59)|0);
 $3 = tempRet0;
 $4 = (_bitshift64Lshr(($0|0),($1|0),51)|0);
 $5 = tempRet0;
 $6 = $4 & 31;
 $7 = (_bitshift64Lshr(($0|0),($1|0),43)|0);
 $8 = tempRet0;
 $9 = $7 & 31;
 $10 = (_bitshift64Lshr(($0|0),($1|0),56)|0);
 $11 = tempRet0;
 $12 = $10 & 7;
 $13 = $10 & 4;
 $14 = ($13|0)!=(0);
 $15 = $14 ? 248 : 0;
 $16 = $15 | $12;
 $17 = (_bitshift64Lshr(($0|0),($1|0),48)|0);
 $18 = tempRet0;
 $19 = $17 & 7;
 $20 = $17 & 4;
 $21 = ($20|0)!=(0);
 $22 = $21 ? 248 : 0;
 $23 = $22 | $19;
 $24 = (_bitshift64Lshr(($0|0),($1|0),40)|0);
 $25 = tempRet0;
 $26 = $24 & 7;
 $27 = $24 & 4;
 $28 = ($27|0)!=(0);
 $29 = $28 ? 248 : 0;
 $30 = $29 | $26;
 $alphaMode$not = $alphaMode ^ 1;
 $31 = $1 & 2;
 $32 = (0)==(0);
 $33 = ($31|0)==(0);
 $34 = $32 & $33;
 $or$cond = $34 & $alphaMode$not;
 do {
  if ($or$cond) {
   $mode$0103 = 0;
  } else {
   $sext = $16 << 24;
   $35 = $sext >> 24;
   $36 = (($35) + ($2))|0;
   $37 = ($36>>>0)<(32);
   if ($37) {
    $sext114 = $23 << 24;
    $38 = $sext114 >> 24;
    $39 = (($38) + ($6))|0;
    $40 = ($39>>>0)<(32);
    if ($40) {
     $sext115 = $30 << 24;
     $41 = $sext115 >> 24;
     $42 = (($41) + ($9))|0;
     $43 = ($42>>>0)<(32);
     $$ = $43 ? 1 : 4;
     $44 = $$ & 4;
     $cond = ($44|0)==(0);
     if ($cond) {
      $mode$0103 = $$;
      break;
     }
     $489 = (_bitshift64Lshr(($0|0),($1|0),49)|0);
     $490 = tempRet0;
     $491 = $489 & 63;
     $492 = (_bitshift64Lshr(($0|0),($1|0),39)|0);
     $493 = tempRet0;
     $494 = $492 & 7;
     $495 = $1 & 1;
     $496 = (_bitshift64Lshr(($0|0),($1|0),55)|0);
     $497 = tempRet0;
     $498 = (_bitshift64Lshr(($0|0),($1|0),61)|0);
     $499 = tempRet0;
     $500 = $498 & 3;
     $501 = (_bitshift64Shl(($10|0),($11|0),6)|0);
     $502 = tempRet0;
     $503 = $501 & 64;
     $504 = $503 | $491;
     $505 = $504 << 1;
     $506 = $503 >>> 6;
     $507 = $505 | $506;
     $508 = (_bitshift64Shl(($17|0),($18|0),5)|0);
     $509 = tempRet0;
     $510 = $508 & 32;
     $511 = (_bitshift64Shl(($7|0),($8|0),3)|0);
     $512 = tempRet0;
     $513 = $511 & 24;
     $514 = $510 | $513;
     $515 = $514 | $494;
     $516 = $515 << 2;
     $517 = $514 >>> 4;
     $518 = $516 | $517;
     $519 = (_bitshift64Lshr(($0|0),($1|0),33)|0);
     $520 = tempRet0;
     $521 = $519 & 62;
     $522 = $521 | $495;
     $523 = $522 << 2;
     $524 = $521 >>> 4;
     $525 = $523 | $524;
     $526 = (_bitshift64Lshr(($0|0),($1|0),25)|0);
     $527 = tempRet0;
     $528 = $526 & 127;
     $529 = $528 << 1;
     $530 = $528 >>> 6;
     $531 = $530 | $529;
     $532 = (_bitshift64Lshr(($0|0),($1|0),19)|0);
     $533 = tempRet0;
     $534 = $532 & 63;
     $535 = $534 << 2;
     $536 = $534 >>> 4;
     $537 = $536 | $535;
     $538 = (_bitshift64Lshr(($0|0),($1|0),13)|0);
     $539 = tempRet0;
     $540 = $538 & 63;
     $541 = $540 << 2;
     $542 = $540 >>> 4;
     $543 = $542 | $541;
     $544 = (_bitshift64Lshr(($0|0),($1|0),6)|0);
     $545 = tempRet0;
     $546 = $544 & 127;
     $547 = $546 << 1;
     $548 = $546 >>> 6;
     $549 = $548 | $547;
     $550 = $0 & 63;
     $551 = $550 << 2;
     $552 = $550 >>> 4;
     $553 = $552 | $551;
     $$masked = $496 & 252;
     $554 = $500 | $$masked;
     $555 = (($525) - ($554))|0;
     $556 = (($543) - ($554))|0;
     $557 = $554 << 2;
     $558 = $557 | 2;
     $559 = (($531) - ($507))|0;
     $560 = (($549) - ($507))|0;
     $561 = $507 << 2;
     $562 = $561 | 2;
     $563 = (($537) - ($518))|0;
     $564 = (($553) - ($518))|0;
     $565 = $518 << 2;
     $566 = $565 | 2;
     $y14$0201 = 0;
     while(1) {
      $567 = $y14$0201 << 2;
      $568 = Math_imul($y14$0201, $556)|0;
      $569 = (($558) + ($568))|0;
      $570 = Math_imul($y14$0201, $560)|0;
      $571 = (($562) + ($570))|0;
      $572 = Math_imul($y14$0201, $564)|0;
      $573 = (($566) + ($572))|0;
      $x15$0199 = 0;
      while(1) {
       $574 = (($x15$0199) + ($567))|0;
       $575 = ($574*3)|0;
       $576 = Math_imul($x15$0199, $555)|0;
       $577 = (($569) + ($576))|0;
       $578 = $577 >> 2;
       $579 = Math_imul($x15$0199, $559)|0;
       $580 = (($571) + ($579))|0;
       $581 = $580 >> 2;
       $582 = Math_imul($x15$0199, $563)|0;
       $583 = (($573) + ($582))|0;
       $584 = $583 >> 2;
       $585 = ($578|0)<(0);
       if ($585) {
        $$0$i20 = 0;
       } else {
        $586 = ($578|0)>(255);
        $587 = $578&255;
        $phitmp = $586 ? -1 : $587;
        $$0$i20 = $phitmp;
       }
       $588 = (($dst) + ($575)|0);
       HEAP8[$588>>0] = $$0$i20;
       $589 = ($581|0)<(0);
       if ($589) {
        $$0$i17 = 0;
       } else {
        $590 = ($581|0)>(255);
        $591 = $581&255;
        $phitmp131 = $590 ? -1 : $591;
        $$0$i17 = $phitmp131;
       }
       $592 = (($575) + 1)|0;
       $593 = (($dst) + ($592)|0);
       HEAP8[$593>>0] = $$0$i17;
       $594 = ($584|0)<(0);
       if ($594) {
        $$0$i = 0;
       } else {
        $595 = ($584|0)>(255);
        $596 = $584&255;
        $phitmp132 = $595 ? -1 : $596;
        $$0$i = $phitmp132;
       }
       $597 = (($575) + 2)|0;
       $598 = (($dst) + ($597)|0);
       HEAP8[$598>>0] = $$0$i;
       if ($alphaMode) {
        $599 = (($alphaDst) + ($574)|0);
        HEAP8[$599>>0] = -1;
       }
       $600 = (($x15$0199) + 1)|0;
       $exitcond205 = ($600|0)==(4);
       if ($exitcond205) {
        break;
       } else {
        $x15$0199 = $600;
       }
      }
      $601 = (($y14$0201) + 1)|0;
      $exitcond206 = ($601|0)==(4);
      if ($exitcond206) {
       break;
      } else {
       $y14$0201 = $601;
      }
     }
     STACKTOP = sp;return;
    }
    $318 = $2 & 15;
    $319 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
    $320 = tempRet0;
    $321 = $319 & 1;
    $322 = (_bitshift64Lshr(($0|0),($1|0),47)|0);
    $323 = tempRet0;
    $324 = $322 & 7;
    $325 = $7 & 15;
    $326 = (_bitshift64Lshr(($0|0),($1|0),39)|0);
    $327 = tempRet0;
    $328 = $326 & 15;
    $329 = (_bitshift64Lshr(($0|0),($1|0),35)|0);
    $330 = tempRet0;
    $331 = $329 & 15;
    $332 = (_bitshift64Shl(($2|0),($3|0),4)|0);
    $333 = tempRet0;
    $334 = $12 << 1;
    $335 = $334 | $321;
    $336 = $335 << 4;
    $337 = $336 | $335;
    $338 = (_bitshift64Shl(($4|0),($5|0),3)|0);
    $339 = tempRet0;
    $340 = $338 & 8;
    $341 = $340 | $324;
    $342 = $341 << 4;
    $343 = $342 | $341;
    $344 = (_bitshift64Shl(($7|0),($8|0),4)|0);
    $345 = tempRet0;
    $346 = (_bitshift64Shl(($326|0),($327|0),4)|0);
    $347 = tempRet0;
    $348 = $331 << 4;
    $349 = $348 | $331;
    $$masked149 = $332 & 240;
    $350 = $$masked149 | $318;
    $351 = $350 << 16;
    $352 = $337 << 8;
    $353 = $343 | $351;
    $354 = $353 | $352;
    $$masked151 = $344 & 240;
    $355 = $$masked151 | $325;
    $356 = $355 << 16;
    $$masked153 = $346 & 240;
    $357 = $$masked153 | $328;
    $358 = $357 << 8;
    $359 = $358 | $349;
    $360 = $359 | $356;
    $361 = $1 & 4;
    $362 = (_bitshift64Lshr(($0|0),($1|0),31)|0);
    $363 = tempRet0;
    $364 = $362 & 2;
    $365 = $361 | $364;
    $366 = ($354>>>0)>=($360>>>0);
    $367 = $366&1;
    $368 = $365 | $367;
    $369 = (601904 + ($368<<2)|0);
    $370 = HEAP32[$369>>2]|0;
    $371 = (($370) + ($350))|0;
    $372 = ($371|0)<(0);
    if ($372) {
     $$0$i64 = 0;
    } else {
     $373 = ($371|0)>(255);
     $374 = $371&255;
     $phitmp157 = $373 ? -1 : $374;
     $$0$i64 = $phitmp157;
    }
    HEAP8[$paintR>>0] = $$0$i64;
    $375 = (($370) + ($337))|0;
    $376 = ($375|0)<(0);
    if ($376) {
     $$0$i61 = 0;
    } else {
     $377 = ($375|0)>(255);
     $378 = $375&255;
     $phitmp158 = $377 ? -1 : $378;
     $$0$i61 = $phitmp158;
    }
    HEAP8[$paintG>>0] = $$0$i61;
    $379 = (($370) + ($343))|0;
    $380 = ($379|0)<(0);
    if ($380) {
     $$0$i58 = 0;
    } else {
     $381 = ($379|0)>(255);
     $382 = $379&255;
     $phitmp159 = $381 ? -1 : $382;
     $$0$i58 = $phitmp159;
    }
    HEAP8[$paintB>>0] = $$0$i58;
    $383 = (($350) - ($370))|0;
    $384 = ($383|0)<(0);
    if ($384) {
     $$0$i55 = 0;
    } else {
     $385 = ($383|0)>(255);
     $386 = $383&255;
     $phitmp160 = $385 ? -1 : $386;
     $$0$i55 = $phitmp160;
    }
    $387 = (($paintR) + 1|0);
    HEAP8[$387>>0] = $$0$i55;
    $388 = (($337) - ($370))|0;
    $389 = ($388|0)<(0);
    if ($389) {
     $$0$i52 = 0;
    } else {
     $390 = ($388|0)>(255);
     $391 = $388&255;
     $phitmp161 = $390 ? -1 : $391;
     $$0$i52 = $phitmp161;
    }
    $392 = (($paintG) + 1|0);
    HEAP8[$392>>0] = $$0$i52;
    $393 = (($343) - ($370))|0;
    $394 = ($393|0)<(0);
    if ($394) {
     $$0$i49 = 0;
    } else {
     $395 = ($393|0)>(255);
     $396 = $393&255;
     $phitmp162 = $395 ? -1 : $396;
     $$0$i49 = $phitmp162;
    }
    $397 = (($paintB) + 1|0);
    HEAP8[$397>>0] = $$0$i49;
    $398 = (($370) + ($355))|0;
    $399 = ($398|0)<(0);
    if ($399) {
     $$0$i46 = 0;
    } else {
     $400 = ($398|0)>(255);
     $401 = $398&255;
     $phitmp163 = $400 ? -1 : $401;
     $$0$i46 = $phitmp163;
    }
    $402 = (($paintR) + 2|0);
    HEAP8[$402>>0] = $$0$i46;
    $403 = (($370) + ($357))|0;
    $404 = ($403|0)<(0);
    if ($404) {
     $$0$i43 = 0;
    } else {
     $405 = ($403|0)>(255);
     $406 = $403&255;
     $phitmp164 = $405 ? -1 : $406;
     $$0$i43 = $phitmp164;
    }
    $407 = (($paintG) + 2|0);
    HEAP8[$407>>0] = $$0$i43;
    $408 = (($370) + ($349))|0;
    $409 = ($408|0)<(0);
    if ($409) {
     $$0$i40 = 0;
    } else {
     $410 = ($408|0)>(255);
     $411 = $408&255;
     $phitmp165 = $410 ? -1 : $411;
     $$0$i40 = $phitmp165;
    }
    $412 = (($paintB) + 2|0);
    HEAP8[$412>>0] = $$0$i40;
    $413 = (($355) - ($370))|0;
    $414 = ($413|0)<(0);
    if ($414) {
     $$0$i37 = 0;
    } else {
     $415 = ($413|0)>(255);
     $416 = $413&255;
     $phitmp166 = $415 ? -1 : $416;
     $$0$i37 = $phitmp166;
    }
    $417 = (($paintR) + 3|0);
    HEAP8[$417>>0] = $$0$i37;
    $418 = (($357) - ($370))|0;
    $419 = ($418|0)<(0);
    if ($419) {
     $$0$i34 = 0;
    } else {
     $420 = ($418|0)>(255);
     $421 = $418&255;
     $phitmp167 = $420 ? -1 : $421;
     $$0$i34 = $phitmp167;
    }
    $422 = (($paintG) + 3|0);
    HEAP8[$422>>0] = $$0$i34;
    $423 = (($349) - ($370))|0;
    $424 = ($423|0)<(0);
    if ($424) {
     $$0$i31 = 0;
    } else {
     $425 = ($423|0)>(255);
     $426 = $423&255;
     $phitmp168 = $425 ? -1 : $426;
     $$0$i31 = $phitmp168;
    }
    $427 = (($paintB) + 3|0);
    HEAP8[$427>>0] = $$0$i31;
   } else {
    $238 = $10 & 3;
    $239 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
    $240 = tempRet0;
    $241 = $239 & 15;
    $242 = $17 & 15;
    $243 = (_bitshift64Lshr(($0|0),($1|0),44)|0);
    $244 = tempRet0;
    $245 = $243 & 15;
    $246 = $24 & 15;
    $247 = (_bitshift64Lshr(($0|0),($1|0),36)|0);
    $248 = tempRet0;
    $249 = $247 & 15;
    $250 = (_bitshift64Lshr(($0|0),($1|0),33)|0);
    $251 = tempRet0;
    $252 = $250 & 6;
    $253 = $1 & 1;
    $254 = $252 | $253;
    $255 = (601904 + ($254<<2)|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = (_bitshift64Shl(($2|0),($3|0),2)|0);
    $258 = tempRet0;
    $259 = $257 & 12;
    $260 = $259 | $238;
    $261 = $260 << 4;
    $262 = $261 | $260;
    $263 = $262&255;
    HEAP8[$paintR>>0] = $263;
    $264 = (_bitshift64Shl(($239|0),($240|0),4)|0);
    $265 = tempRet0;
    $266 = $241 | $264;
    $267 = $266&255;
    HEAP8[$paintG>>0] = $267;
    $268 = (_bitshift64Shl(($17|0),($18|0),4)|0);
    $269 = tempRet0;
    $270 = $242 | $268;
    $271 = $270&255;
    HEAP8[$paintB>>0] = $271;
    $272 = (_bitshift64Shl(($243|0),($244|0),4)|0);
    $273 = tempRet0;
    $274 = $245 | $272;
    $275 = $274&255;
    $276 = (($paintR) + 2|0);
    HEAP8[$276>>0] = $275;
    $277 = (_bitshift64Shl(($24|0),($25|0),4)|0);
    $278 = tempRet0;
    $279 = $246 | $277;
    $280 = $279&255;
    $281 = (($paintG) + 2|0);
    HEAP8[$281>>0] = $280;
    $282 = $249 << 4;
    $283 = $282 | $249;
    $284 = $283&255;
    $285 = (($paintB) + 2|0);
    HEAP8[$285>>0] = $284;
    $286 = $274 & 255;
    $287 = (($286) + ($256))|0;
    $288 = ($287|0)<(0);
    if ($288) {
     $$0$i86 = 0;
    } else {
     $289 = ($287|0)>(255);
     $290 = $287&255;
     $phitmp179 = $289 ? -1 : $290;
     $$0$i86 = $phitmp179;
    }
    $291 = (($paintR) + 1|0);
    HEAP8[$291>>0] = $$0$i86;
    $292 = $279 & 255;
    $293 = (($292) + ($256))|0;
    $294 = ($293|0)<(0);
    if ($294) {
     $$0$i83 = 0;
    } else {
     $295 = ($293|0)>(255);
     $296 = $293&255;
     $phitmp180 = $295 ? -1 : $296;
     $$0$i83 = $phitmp180;
    }
    $297 = (($paintG) + 1|0);
    HEAP8[$297>>0] = $$0$i83;
    $298 = (($283) + ($256))|0;
    $299 = ($298|0)<(0);
    if ($299) {
     $$0$i80 = 0;
    } else {
     $300 = ($298|0)>(255);
     $301 = $298&255;
     $phitmp181 = $300 ? -1 : $301;
     $$0$i80 = $phitmp181;
    }
    $302 = (($paintB) + 1|0);
    HEAP8[$302>>0] = $$0$i80;
    $303 = (($286) - ($256))|0;
    $304 = ($303|0)<(0);
    if ($304) {
     $$0$i77 = 0;
    } else {
     $305 = ($303|0)>(255);
     $306 = $303&255;
     $phitmp182 = $305 ? -1 : $306;
     $$0$i77 = $phitmp182;
    }
    $307 = (($paintR) + 3|0);
    HEAP8[$307>>0] = $$0$i77;
    $308 = (($292) - ($256))|0;
    $309 = ($308|0)<(0);
    if ($309) {
     $$0$i74 = 0;
    } else {
     $310 = ($308|0)>(255);
     $311 = $308&255;
     $phitmp183 = $310 ? -1 : $311;
     $$0$i74 = $phitmp183;
    }
    $312 = (($paintG) + 3|0);
    HEAP8[$312>>0] = $$0$i74;
    $313 = (($283) - ($256))|0;
    $314 = ($313|0)<(0);
    if ($314) {
     $$0$i71 = 0;
    } else {
     $315 = ($313|0)>(255);
     $316 = $313&255;
     $phitmp184 = $315 ? -1 : $316;
     $$0$i71 = $phitmp184;
    }
    $317 = (($paintB) + 3|0);
    HEAP8[$317>>0] = $$0$i71;
   }
   $or$cond14 = $34 & $alphaMode;
   if ($or$cond14) {
    $pixelNdx9$0204$us = 0;
   } else {
    $pixelNdx9$0204 = 0;
    while(1) {
     $462 = (($pixelNdx9$0204|0) / 4)&-1;
     $463 = (($pixelNdx9$0204|0) % 4)&-1;
     $464 = $463 << 2;
     $465 = (($464) + ($462))|0;
     $466 = ($465*3)|0;
     $467 = (($pixelNdx9$0204) + 16)|0;
     $468 = (_bitshift64Lshr(($0|0),($1|0),($467|0))|0);
     $469 = tempRet0;
     $470 = $468 << 1;
     $471 = $470 & 2;
     $472 = (_bitshift64Lshr(($0|0),($1|0),($pixelNdx9$0204|0))|0);
     $473 = tempRet0;
     $474 = $472 & 1;
     $475 = $471 | $474;
     $476 = (($paintR) + ($475)|0);
     $477 = HEAP8[$476>>0]|0;
     $478 = (($dst) + ($466)|0);
     HEAP8[$478>>0] = $477;
     $479 = (($paintG) + ($475)|0);
     $480 = HEAP8[$479>>0]|0;
     $481 = (($466) + 1)|0;
     $482 = (($dst) + ($481)|0);
     HEAP8[$482>>0] = $480;
     $483 = (($paintB) + ($475)|0);
     $484 = HEAP8[$483>>0]|0;
     $485 = (($466) + 2)|0;
     $486 = (($dst) + ($485)|0);
     HEAP8[$486>>0] = $484;
     if ($alphaMode) {
      $487 = (($alphaDst) + ($465)|0);
      HEAP8[$487>>0] = -1;
     }
     $488 = (($pixelNdx9$0204) + 1)|0;
     $exitcond207 = ($488|0)==(16);
     if ($exitcond207) {
      break;
     } else {
      $pixelNdx9$0204 = $488;
     }
    }
    STACKTOP = sp;return;
   }
   while(1) {
    $428 = (($pixelNdx9$0204$us|0) / 4)&-1;
    $429 = (($pixelNdx9$0204$us|0) % 4)&-1;
    $430 = $429 << 2;
    $431 = (($430) + ($428))|0;
    $432 = ($431*3)|0;
    $433 = (($pixelNdx9$0204$us) + 16)|0;
    $434 = (_bitshift64Lshr(($0|0),($1|0),($433|0))|0);
    $435 = tempRet0;
    $436 = $434 << 1;
    $437 = $436 & 2;
    $438 = (_bitshift64Lshr(($0|0),($1|0),($pixelNdx9$0204$us|0))|0);
    $439 = tempRet0;
    $440 = $438 & 1;
    $441 = $437 | $440;
    $442 = ($441|0)==(2);
    if ($442) {
     $455 = (($dst) + ($432)|0);
     HEAP8[$455>>0] = 0;
     $456 = (($432) + 1)|0;
     $457 = (($dst) + ($456)|0);
     HEAP8[$457>>0] = 0;
     $458 = (($432) + 2)|0;
     $459 = (($dst) + ($458)|0);
     HEAP8[$459>>0] = 0;
     $460 = (($alphaDst) + ($431)|0);
     HEAP8[$460>>0] = 0;
    } else {
     $443 = (($paintR) + ($441)|0);
     $444 = HEAP8[$443>>0]|0;
     $445 = (($dst) + ($432)|0);
     HEAP8[$445>>0] = $444;
     $446 = (($paintG) + ($441)|0);
     $447 = HEAP8[$446>>0]|0;
     $448 = (($432) + 1)|0;
     $449 = (($dst) + ($448)|0);
     HEAP8[$449>>0] = $447;
     $450 = (($paintB) + ($441)|0);
     $451 = HEAP8[$450>>0]|0;
     $452 = (($432) + 2)|0;
     $453 = (($dst) + ($452)|0);
     HEAP8[$453>>0] = $451;
     $454 = (($alphaDst) + ($431)|0);
     HEAP8[$454>>0] = -1;
    }
    $461 = (($pixelNdx9$0204$us) + 1)|0;
    $exitcond209 = ($461|0)==(16);
    if ($exitcond209) {
     break;
    } else {
     $pixelNdx9$0204$us = $461;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $45 = ($mode$0103|0)==(0);
 $46 = (_bitshift64Lshr(($0|0),($1|0),37)|0);
 $47 = tempRet0;
 $48 = $46 & 7;
 HEAP32[$table>>2] = $48;
 $49 = (($table) + 4|0);
 $50 = (_bitshift64Lshr(($0|0),($1|0),34)|0);
 $51 = tempRet0;
 $52 = $50 & 7;
 HEAP32[$49>>2] = $52;
 if ($45) {
  $53 = (_bitshift64Lshr(($0|0),($1|0),60)|0);
  $54 = tempRet0;
  $55 = (_bitshift64Shl(($53|0),($54|0),4)|0);
  $56 = tempRet0;
  $57 = $55 | $53;
  $56 | $54;
  $58 = $57&255;
  HEAP8[$baseR>>0] = $58;
  $59 = $10 & 15;
  $60 = (_bitshift64Shl(($10|0),($11|0),4)|0);
  $61 = tempRet0;
  $62 = $59 | $60;
  $63 = $62&255;
  $64 = (($baseR) + 1|0);
  HEAP8[$64>>0] = $63;
  $65 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
  $66 = tempRet0;
  $67 = $65 & 15;
  $68 = (_bitshift64Shl(($65|0),($66|0),4)|0);
  $69 = tempRet0;
  $70 = $67 | $68;
  $71 = $70&255;
  HEAP8[$baseG>>0] = $71;
  $72 = $17 & 15;
  $73 = (_bitshift64Shl(($17|0),($18|0),4)|0);
  $74 = tempRet0;
  $75 = $72 | $73;
  $76 = $75&255;
  $77 = (($baseG) + 1|0);
  HEAP8[$77>>0] = $76;
  $78 = (_bitshift64Lshr(($0|0),($1|0),44)|0);
  $79 = tempRet0;
  $80 = $78 & 15;
  $81 = (_bitshift64Shl(($78|0),($79|0),4)|0);
  $82 = tempRet0;
  $83 = $80 | $81;
  $84 = $83&255;
  HEAP8[$baseB>>0] = $84;
  $85 = $24 & 15;
  $86 = (_bitshift64Shl(($24|0),($25|0),4)|0);
  $87 = tempRet0;
  $88 = $85 | $86;
  $89 = $88&255;
  $90 = (($baseB) + 1|0);
  HEAP8[$90>>0] = $89;
 } else {
  $91 = (_bitshift64Shl(($2|0),($3|0),3)|0);
  $92 = tempRet0;
  $93 = (_bitshift64Lshr(($0|0),($1|0),61)|0);
  $94 = tempRet0;
  $95 = $91 | $93;
  $92 | $94;
  $96 = $95&255;
  HEAP8[$baseR>>0] = $96;
  $97 = (_bitshift64Shl(($4|0),($5|0),3)|0);
  $98 = tempRet0;
  $99 = $6 >>> 2;
  $100 = $99 | $97;
  $101 = $100&255;
  HEAP8[$baseG>>0] = $101;
  $102 = (_bitshift64Shl(($7|0),($8|0),3)|0);
  $103 = tempRet0;
  $104 = $9 >>> 2;
  $105 = $104 | $102;
  $106 = $105&255;
  HEAP8[$baseB>>0] = $106;
  $107 = (($16) + ($2))|0;
  $108 = $107 & 255;
  $109 = $108 << 3;
  $110 = $108 >>> 2;
  $111 = $110 | $109;
  $112 = $111&255;
  $113 = (($baseR) + 1|0);
  HEAP8[$113>>0] = $112;
  $114 = (($23) + ($6))|0;
  $115 = $114 & 255;
  $116 = $115 << 3;
  $117 = $115 >>> 2;
  $118 = $117 | $116;
  $119 = $118&255;
  $120 = (($baseG) + 1|0);
  HEAP8[$120>>0] = $119;
  $121 = (($30) + ($9))|0;
  $122 = $121 & 255;
  $123 = $122 << 3;
  $124 = $122 >>> 2;
  $125 = $124 | $123;
  $126 = $125&255;
  $127 = (($baseB) + 1|0);
  HEAP8[$127>>0] = $126;
 }
 $128 = $1 & 1;
 $129 = (0)!=(0);
 $130 = ($128|0)!=(0);
 $131 = $129 | $130;
 $or$cond11 = $34 & $alphaMode;
 if ($or$cond11) {
  $pixelNdx$0197$us = 0;
 } else {
  $pixelNdx$0197 = 0;
  while(1) {
   $189 = (($pixelNdx$0197|0) / 4)&-1;
   $190 = (($pixelNdx$0197|0) % 4)&-1;
   $191 = $190 << 2;
   $192 = (($191) + ($189))|0;
   $193 = ($192*3)|0;
   $194 = $131 ? $190 : $189;
   $195 = ($194|0)>(1);
   $196 = $195&1;
   $197 = (($table) + ($196<<2)|0);
   $198 = HEAP32[$197>>2]|0;
   $199 = (($pixelNdx$0197) + 16)|0;
   $200 = (_bitshift64Lshr(($0|0),($1|0),($199|0))|0);
   $201 = tempRet0;
   $202 = $200 << 1;
   $203 = $202 & 2;
   $204 = (_bitshift64Lshr(($0|0),($1|0),($pixelNdx$0197|0))|0);
   $205 = tempRet0;
   $206 = $204 & 1;
   $207 = $203 | $206;
   $208 = ((601776 + ($198<<4)|0) + ($207<<2)|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = (($baseR) + ($196)|0);
   $211 = HEAP8[$210>>0]|0;
   $212 = $211&255;
   $213 = (($212) + ($209))|0;
   $214 = ($213|0)<(0);
   if ($214) {
    $$0$i96 = 0;
   } else {
    $215 = ($213|0)>(255);
    $216 = $213&255;
    $phitmp135 = $215 ? -1 : $216;
    $$0$i96 = $phitmp135;
   }
   $217 = (($dst) + ($193)|0);
   HEAP8[$217>>0] = $$0$i96;
   $218 = (($baseG) + ($196)|0);
   $219 = HEAP8[$218>>0]|0;
   $220 = $219&255;
   $221 = (($220) + ($209))|0;
   $222 = ($221|0)<(0);
   if ($222) {
    $$0$i93 = 0;
   } else {
    $223 = ($221|0)>(255);
    $224 = $221&255;
    $phitmp136 = $223 ? -1 : $224;
    $$0$i93 = $phitmp136;
   }
   $225 = (($193) + 1)|0;
   $226 = (($dst) + ($225)|0);
   HEAP8[$226>>0] = $$0$i93;
   $227 = (($baseB) + ($196)|0);
   $228 = HEAP8[$227>>0]|0;
   $229 = $228&255;
   $230 = (($229) + ($209))|0;
   $231 = ($230|0)<(0);
   if ($231) {
    $$0$i90 = 0;
   } else {
    $232 = ($230|0)>(255);
    $233 = $230&255;
    $phitmp137 = $232 ? -1 : $233;
    $$0$i90 = $phitmp137;
   }
   $234 = (($193) + 2)|0;
   $235 = (($dst) + ($234)|0);
   HEAP8[$235>>0] = $$0$i90;
   if ($alphaMode) {
    $236 = (($alphaDst) + ($192)|0);
    HEAP8[$236>>0] = -1;
   }
   $237 = (($pixelNdx$0197) + 1)|0;
   $exitcond = ($237|0)==(16);
   if ($exitcond) {
    break;
   } else {
    $pixelNdx$0197 = $237;
   }
  }
  STACKTOP = sp;return;
 }
 while(1) {
  $132 = (($pixelNdx$0197$us|0) / 4)&-1;
  $133 = (($pixelNdx$0197$us|0) % 4)&-1;
  $134 = $133 << 2;
  $135 = (($134) + ($132))|0;
  $136 = ($135*3)|0;
  $137 = $131 ? $133 : $132;
  $138 = ($137|0)>(1);
  $139 = $138&1;
  $140 = (($table) + ($139<<2)|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = (($pixelNdx$0197$us) + 16)|0;
  $143 = (_bitshift64Lshr(($0|0),($1|0),($142|0))|0);
  $144 = tempRet0;
  $145 = $143 << 1;
  $146 = $145 & 2;
  $147 = (_bitshift64Lshr(($0|0),($1|0),($pixelNdx$0197$us|0))|0);
  $148 = tempRet0;
  $149 = $147 & 1;
  $150 = $146 | $149;
  $151 = ($150|0)==(2);
  if ($151) {
   $182 = (($dst) + ($136)|0);
   HEAP8[$182>>0] = 0;
   $183 = (($136) + 1)|0;
   $184 = (($dst) + ($183)|0);
   HEAP8[$184>>0] = 0;
   $185 = (($136) + 2)|0;
   $186 = (($dst) + ($185)|0);
   HEAP8[$186>>0] = 0;
   $187 = (($alphaDst) + ($135)|0);
   HEAP8[$187>>0] = 0;
  } else {
   $152 = ($149|0)==(0);
   if ($152) {
    $modifier$0$us = 0;
   } else {
    $153 = ((601776 + ($141<<4)|0) + ($150<<2)|0);
    $154 = HEAP32[$153>>2]|0;
    $modifier$0$us = $154;
   }
   $155 = (($baseR) + ($139)|0);
   $156 = HEAP8[$155>>0]|0;
   $157 = $156&255;
   $158 = (($157) + ($modifier$0$us))|0;
   $159 = ($158|0)<(0);
   if ($159) {
    $$0$i96$us = 0;
   } else {
    $160 = ($158|0)>(255);
    $161 = $158&255;
    $phitmp135$us = $160 ? -1 : $161;
    $$0$i96$us = $phitmp135$us;
   }
   $162 = (($dst) + ($136)|0);
   HEAP8[$162>>0] = $$0$i96$us;
   $163 = (($baseG) + ($139)|0);
   $164 = HEAP8[$163>>0]|0;
   $165 = $164&255;
   $166 = (($165) + ($modifier$0$us))|0;
   $167 = ($166|0)<(0);
   if ($167) {
    $$0$i93$us = 0;
   } else {
    $168 = ($166|0)>(255);
    $169 = $166&255;
    $phitmp136$us = $168 ? -1 : $169;
    $$0$i93$us = $phitmp136$us;
   }
   $170 = (($136) + 1)|0;
   $171 = (($dst) + ($170)|0);
   HEAP8[$171>>0] = $$0$i93$us;
   $172 = (($baseB) + ($139)|0);
   $173 = HEAP8[$172>>0]|0;
   $174 = $173&255;
   $175 = (($174) + ($modifier$0$us))|0;
   $176 = ($175|0)<(0);
   if ($176) {
    $$0$i90$us = 0;
   } else {
    $177 = ($175|0)>(255);
    $178 = $175&255;
    $phitmp137$us = $177 ? -1 : $178;
    $$0$i90$us = $phitmp137$us;
   }
   $179 = (($136) + 2)|0;
   $180 = (($dst) + ($179)|0);
   HEAP8[$180>>0] = $$0$i90$us;
   $181 = (($alphaDst) + ($135)|0);
   HEAP8[$181>>0] = -1;
  }
  $188 = (($pixelNdx$0197$us) + 1)|0;
  $exitcond208 = ($188|0)==(16);
  if ($exitcond208) {
   break;
  } else {
   $pixelNdx$0197$us = $188;
  }
 }
 STACKTOP = sp;return;
}
function __Z22DecompressETC2_RGB8_A1PhPKhiiii($dst,$src,$srcWidth,$srcHeight,$destWidth,$destHeight) {
 $dst = $dst|0;
 $src = $src|0;
 $srcWidth = $srcWidth|0;
 $srcHeight = $srcHeight|0;
 $destWidth = $destWidth|0;
 $destHeight = $destHeight|0;
 var $$sum = 0, $$sum1 = 0, $$sum23 = 0, $$sum4 = 0, $$sum56 = 0, $$sum78 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blockX$013 = 0, $blockY$016 = 0, $exitcond = 0, $exitcond21 = 0, $exitcond22 = 0, $exitcond23 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$next19 = 0, $indvars$iv$op = 0, $indvars$iv18 = 0;
 var $indvars$iv18$op = 0, $uncompressedBlockAlpha = 0, $uncompressedBlockRGB = 0, $x$09 = 0, $y$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $uncompressedBlockRGB = sp + 16|0;
 $uncompressedBlockAlpha = sp;
 $0 = (($srcWidth|0) / 4)&-1;
 $1 = $srcWidth & 3;
 $2 = ($1|0)!=(0);
 $3 = $2&1;
 $4 = (($0) + ($3))|0;
 $5 = (($srcHeight|0) / 4)&-1;
 $6 = $srcHeight & 3;
 $7 = ($6|0)!=(0);
 $8 = $7&1;
 $9 = (($5) + ($8))|0;
 $10 = $destWidth << 2;
 $11 = ($9|0)>(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ($4|0)>(0);
 $13 = $destWidth ^ -1;
 $14 = $destHeight ^ -1;
 $blockY$016 = 0;$indvars$iv18 = $14;
 while(1) {
  $15 = ($indvars$iv18|0)>(-5);
  $indvars$iv18$op = $indvars$iv18 ^ -1;
  $16 = $15 ? $indvars$iv18$op : 4;
  if ($12) {
   $17 = Math_imul($blockY$016, $4)|0;
   $18 = $blockY$016 << 2;
   $19 = (($destHeight) - ($18))|0;
   $20 = ($19|0)>(0);
   $blockX$013 = 0;$indvars$iv = $13;
   while(1) {
    $21 = ($indvars$iv|0)>(-5);
    $indvars$iv$op = $indvars$iv ^ -1;
    $22 = $21 ? $indvars$iv$op : 4;
    $23 = (($blockX$013) + ($17))|0;
    $24 = $23 << 3;
    $25 = (($src) + ($24)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26&255;
    $28 = (_bitshift64Shl(($27|0),0,8)|0);
    $29 = tempRet0;
    $30 = $24 | 1;
    $31 = (($src) + ($30)|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = $32&255;
    $34 = $33 | $28;
    $35 = (_bitshift64Shl(($34|0),($29|0),8)|0);
    $36 = tempRet0;
    $37 = $24 | 2;
    $38 = (($src) + ($37)|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = $39&255;
    $41 = $35 | $40;
    $42 = (_bitshift64Shl(($41|0),($36|0),8)|0);
    $43 = tempRet0;
    $44 = $24 | 3;
    $45 = (($src) + ($44)|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46&255;
    $48 = $42 | $47;
    $49 = (_bitshift64Shl(($48|0),($43|0),8)|0);
    $50 = tempRet0;
    $51 = $24 | 4;
    $52 = (($src) + ($51)|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = $49 | $54;
    $56 = (_bitshift64Shl(($55|0),($50|0),8)|0);
    $57 = tempRet0;
    $58 = $24 | 5;
    $59 = (($src) + ($58)|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = $60&255;
    $62 = $56 | $61;
    $63 = (_bitshift64Shl(($62|0),($57|0),8)|0);
    $64 = tempRet0;
    $65 = $24 | 6;
    $66 = (($src) + ($65)|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67&255;
    $69 = $63 | $68;
    $70 = (_bitshift64Shl(($69|0),($64|0),8)|0);
    $71 = tempRet0;
    $72 = $24 | 7;
    $73 = (($src) + ($72)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = $70 | $75;
    __ZL19DecompressETC2BlockyPhS_b($76,$71,$uncompressedBlockRGB,$uncompressedBlockAlpha,1);
    $77 = $blockX$013 << 2;
    if ($20) {
     $78 = (($destWidth) - ($77))|0;
     $79 = ($78|0)>(0);
     $y$010 = 0;
     while(1) {
      if ($79) {
       $80 = $y$010 << 2;
       $81 = (($y$010) + ($18))|0;
       $82 = Math_imul($10, $81)|0;
       $x$09 = 0;
       while(1) {
        $83 = (($x$09) + ($80))|0;
        $84 = ($83*3)|0;
        $85 = (($uncompressedBlockRGB) + ($84)|0);
        $86 = (($uncompressedBlockAlpha) + ($83)|0);
        $87 = (($x$09) + ($77))|0;
        $88 = $87 << 2;
        $$sum = (($88) + ($82))|0;
        $89 = (($dst) + ($$sum)|0);
        $90 = HEAP8[$85>>0]|0;
        HEAP8[$89>>0] = $90;
        $$sum1 = (($84) + 1)|0;
        $91 = (($uncompressedBlockRGB) + ($$sum1)|0);
        $92 = HEAP8[$91>>0]|0;
        $$sum23 = $$sum | 1;
        $93 = (($dst) + ($$sum23)|0);
        HEAP8[$93>>0] = $92;
        $$sum4 = (($84) + 2)|0;
        $94 = (($uncompressedBlockRGB) + ($$sum4)|0);
        $95 = HEAP8[$94>>0]|0;
        $$sum56 = $$sum | 2;
        $96 = (($dst) + ($$sum56)|0);
        HEAP8[$96>>0] = $95;
        $97 = HEAP8[$86>>0]|0;
        $$sum78 = $$sum | 3;
        $98 = (($dst) + ($$sum78)|0);
        HEAP8[$98>>0] = $97;
        $99 = (($x$09) + 1)|0;
        $exitcond = ($99|0)==($22|0);
        if ($exitcond) {
         break;
        } else {
         $x$09 = $99;
        }
       }
      }
      $100 = (($y$010) + 1)|0;
      $exitcond21 = ($100|0)==($16|0);
      if ($exitcond21) {
       break;
      } else {
       $y$010 = $100;
      }
     }
    }
    $101 = (($blockX$013) + 1)|0;
    $indvars$iv$next = (($indvars$iv) + 4)|0;
    $exitcond22 = ($101|0)==($4|0);
    if ($exitcond22) {
     break;
    } else {
     $blockX$013 = $101;$indvars$iv = $indvars$iv$next;
    }
   }
  }
  $102 = (($blockY$016) + 1)|0;
  $indvars$iv$next19 = (($indvars$iv18) + 4)|0;
  $exitcond23 = ($102|0)==($9|0);
  if ($exitcond23) {
   break;
  } else {
   $blockY$016 = $102;$indvars$iv18 = $indvars$iv$next19;
  }
 }
 STACKTOP = sp;return;
}
function __Z20DecompressETC2_RGBA8PhPKhiiii($dst,$src,$srcWidth,$srcHeight,$destWidth,$destHeight) {
 $dst = $dst|0;
 $src = $src|0;
 $srcWidth = $srcWidth|0;
 $srcHeight = $srcHeight|0;
 $destWidth = $destWidth|0;
 $destHeight = $destHeight|0;
 var $$0$i$i = 0, $$sum = 0, $$sum1 = 0, $$sum23 = 0, $$sum4 = 0, $$sum56 = 0, $$sum78 = 0, $$tr$i = 0, $$tr3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blockX$013 = 0, $blockY$016 = 0;
 var $exitcond = 0, $exitcond$i = 0, $exitcond21 = 0, $exitcond22 = 0, $exitcond23 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$next19 = 0, $indvars$iv$op = 0, $indvars$iv18 = 0, $indvars$iv18$op = 0, $phitmp$i = 0, $pixelNdx$04$i = 0, $uncompressedBlockAlpha = 0, $uncompressedBlockRGB = 0, $x$09 = 0, $y$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $uncompressedBlockAlpha = sp + 48|0;
 $uncompressedBlockRGB = sp;
 $0 = (($srcWidth|0) / 4)&-1;
 $1 = $srcWidth & 3;
 $2 = ($1|0)!=(0);
 $3 = $2&1;
 $4 = (($0) + ($3))|0;
 $5 = (($srcHeight|0) / 4)&-1;
 $6 = $srcHeight & 3;
 $7 = ($6|0)!=(0);
 $8 = $7&1;
 $9 = (($5) + ($8))|0;
 $10 = $destWidth << 2;
 $11 = ($9|0)>(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = ($4|0)>(0);
 $13 = $destWidth ^ -1;
 $14 = $destHeight ^ -1;
 $blockY$016 = 0;$indvars$iv18 = $14;
 while(1) {
  $15 = ($indvars$iv18|0)>(-5);
  $indvars$iv18$op = $indvars$iv18 ^ -1;
  $16 = $15 ? $indvars$iv18$op : 4;
  if ($12) {
   $17 = Math_imul($blockY$016, $4)|0;
   $18 = $blockY$016 << 2;
   $19 = (($destHeight) - ($18))|0;
   $20 = ($19|0)>(0);
   $blockX$013 = 0;$indvars$iv = $13;
   while(1) {
    $21 = ($indvars$iv|0)>(-5);
    $indvars$iv$op = $indvars$iv ^ -1;
    $22 = $21 ? $indvars$iv$op : 4;
    $23 = (($blockX$013) + ($17))|0;
    $24 = $23 << 4;
    $25 = (($src) + ($24)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26&255;
    $28 = (_bitshift64Shl(($27|0),0,8)|0);
    $29 = tempRet0;
    $30 = $24 | 1;
    $31 = (($src) + ($30)|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = $32&255;
    $34 = $33 | $28;
    $35 = (_bitshift64Shl(($34|0),($29|0),8)|0);
    $36 = tempRet0;
    $37 = $24 | 2;
    $38 = (($src) + ($37)|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = $39&255;
    $41 = $35 | $40;
    $42 = (_bitshift64Shl(($41|0),($36|0),8)|0);
    $43 = tempRet0;
    $44 = $24 | 3;
    $45 = (($src) + ($44)|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46&255;
    $48 = $42 | $47;
    $49 = (_bitshift64Shl(($48|0),($43|0),8)|0);
    $50 = tempRet0;
    $51 = $24 | 4;
    $52 = (($src) + ($51)|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = $49 | $54;
    $56 = (_bitshift64Shl(($55|0),($50|0),8)|0);
    $57 = tempRet0;
    $58 = $24 | 5;
    $59 = (($src) + ($58)|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = $60&255;
    $62 = $56 | $61;
    $63 = (_bitshift64Shl(($62|0),($57|0),8)|0);
    $64 = tempRet0;
    $65 = $24 | 6;
    $66 = (($src) + ($65)|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67&255;
    $69 = $63 | $68;
    $70 = (_bitshift64Shl(($69|0),($64|0),8)|0);
    $71 = tempRet0;
    $72 = $24 | 7;
    $73 = (($src) + ($72)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = $70 | $75;
    $77 = $24 | 8;
    $78 = (($src) + ($77)|0);
    $79 = HEAP8[$78>>0]|0;
    $80 = $79&255;
    $81 = (_bitshift64Shl(($80|0),0,8)|0);
    $82 = tempRet0;
    $83 = $24 | 9;
    $84 = (($src) + ($83)|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = $86 | $81;
    $88 = (_bitshift64Shl(($87|0),($82|0),8)|0);
    $89 = tempRet0;
    $90 = $24 | 10;
    $91 = (($src) + ($90)|0);
    $92 = HEAP8[$91>>0]|0;
    $93 = $92&255;
    $94 = $88 | $93;
    $95 = (_bitshift64Shl(($94|0),($89|0),8)|0);
    $96 = tempRet0;
    $97 = $24 | 11;
    $98 = (($src) + ($97)|0);
    $99 = HEAP8[$98>>0]|0;
    $100 = $99&255;
    $101 = $95 | $100;
    $102 = (_bitshift64Shl(($101|0),($96|0),8)|0);
    $103 = tempRet0;
    $104 = $24 | 12;
    $105 = (($src) + ($104)|0);
    $106 = HEAP8[$105>>0]|0;
    $107 = $106&255;
    $108 = $102 | $107;
    $109 = (_bitshift64Shl(($108|0),($103|0),8)|0);
    $110 = tempRet0;
    $111 = $24 | 13;
    $112 = (($src) + ($111)|0);
    $113 = HEAP8[$112>>0]|0;
    $114 = $113&255;
    $115 = $109 | $114;
    $116 = (_bitshift64Shl(($115|0),($110|0),8)|0);
    $117 = tempRet0;
    $118 = $24 | 14;
    $119 = (($src) + ($118)|0);
    $120 = HEAP8[$119>>0]|0;
    $121 = $120&255;
    $122 = $116 | $121;
    $123 = (_bitshift64Shl(($122|0),($117|0),8)|0);
    $124 = tempRet0;
    $125 = $24 | 15;
    $126 = (($src) + ($125)|0);
    $127 = HEAP8[$126>>0]|0;
    $128 = $127&255;
    $129 = $123 | $128;
    __ZL19DecompressETC2BlockyPhS_b($129,$124,$uncompressedBlockRGB,0,0);
    $130 = $26&255;
    $131 = ($32&255) >>> 4;
    $$tr$i = $131&255;
    $$tr3$i = $32&255;
    $132 = $$tr3$i & 15;
    $pixelNdx$04$i = 0;
    while(1) {
     $133 = (($pixelNdx$04$i|0) / 4)&-1;
     $134 = (($pixelNdx$04$i|0) % 4)&-1;
     $135 = $134 << 2;
     $136 = (($135) + ($133))|0;
     $137 = Math_imul($pixelNdx$04$i, -3)|0;
     $138 = (($137) + 45)|0;
     $139 = (($137) + 47)|0;
     $140 = (_bitshift64Lshr(($76|0),($71|0),($139|0))|0);
     $141 = tempRet0;
     $142 = $140 << 2;
     $143 = $142 & 4;
     $144 = (($137) + 46)|0;
     $145 = (_bitshift64Lshr(($76|0),($71|0),($144|0))|0);
     $146 = tempRet0;
     $147 = $145 << 1;
     $148 = $147 & 2;
     $149 = (_bitshift64Lshr(($76|0),($71|0),($138|0))|0);
     $150 = tempRet0;
     $151 = $149 & 1;
     $152 = $148 | $151;
     $153 = $152 | $143;
     $154 = ((601264 + ($132<<5)|0) + ($153<<2)|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = Math_imul($155, $$tr$i)|0;
     $157 = (($156) + ($130))|0;
     $158 = ($157|0)<(0);
     if ($158) {
      $$0$i$i = 0;
     } else {
      $159 = ($157|0)>(255);
      $160 = $157&255;
      $phitmp$i = $159 ? -1 : $160;
      $$0$i$i = $phitmp$i;
     }
     $161 = (($uncompressedBlockAlpha) + ($136)|0);
     HEAP8[$161>>0] = $$0$i$i;
     $162 = (($pixelNdx$04$i) + 1)|0;
     $exitcond$i = ($162|0)==(16);
     if ($exitcond$i) {
      break;
     } else {
      $pixelNdx$04$i = $162;
     }
    }
    $163 = $blockX$013 << 2;
    if ($20) {
     $164 = (($destWidth) - ($163))|0;
     $165 = ($164|0)>(0);
     $y$010 = 0;
     while(1) {
      if ($165) {
       $166 = $y$010 << 2;
       $167 = (($y$010) + ($18))|0;
       $168 = Math_imul($10, $167)|0;
       $x$09 = 0;
       while(1) {
        $169 = (($x$09) + ($166))|0;
        $170 = ($169*3)|0;
        $171 = (($uncompressedBlockRGB) + ($170)|0);
        $172 = (($uncompressedBlockAlpha) + ($169)|0);
        $173 = (($x$09) + ($163))|0;
        $174 = $173 << 2;
        $$sum = (($174) + ($168))|0;
        $175 = (($dst) + ($$sum)|0);
        $176 = HEAP8[$171>>0]|0;
        HEAP8[$175>>0] = $176;
        $$sum1 = (($170) + 1)|0;
        $177 = (($uncompressedBlockRGB) + ($$sum1)|0);
        $178 = HEAP8[$177>>0]|0;
        $$sum23 = $$sum | 1;
        $179 = (($dst) + ($$sum23)|0);
        HEAP8[$179>>0] = $178;
        $$sum4 = (($170) + 2)|0;
        $180 = (($uncompressedBlockRGB) + ($$sum4)|0);
        $181 = HEAP8[$180>>0]|0;
        $$sum56 = $$sum | 2;
        $182 = (($dst) + ($$sum56)|0);
        HEAP8[$182>>0] = $181;
        $183 = HEAP8[$172>>0]|0;
        $$sum78 = $$sum | 3;
        $184 = (($dst) + ($$sum78)|0);
        HEAP8[$184>>0] = $183;
        $185 = (($x$09) + 1)|0;
        $exitcond = ($185|0)==($22|0);
        if ($exitcond) {
         break;
        } else {
         $x$09 = $185;
        }
       }
      }
      $186 = (($y$010) + 1)|0;
      $exitcond21 = ($186|0)==($16|0);
      if ($exitcond21) {
       break;
      } else {
       $y$010 = $186;
      }
     }
    }
    $187 = (($blockX$013) + 1)|0;
    $indvars$iv$next = (($indvars$iv) + 4)|0;
    $exitcond22 = ($187|0)==($4|0);
    if ($exitcond22) {
     break;
    } else {
     $blockX$013 = $187;$indvars$iv = $indvars$iv$next;
    }
   }
  }
  $188 = (($blockY$016) + 1)|0;
  $indvars$iv$next19 = (($indvars$iv18) + 4)|0;
  $exitcond23 = ($188|0)==($9|0);
  if ($exitcond23) {
   break;
  } else {
   $blockY$016 = $188;$indvars$iv18 = $indvars$iv$next19;
  }
 }
 STACKTOP = sp;return;
}
function __Z22GenerateDitherTexturesv() {
 var $$byval_copy5 = 0, $$pre = 0, $$pre89 = 0, $$pre90 = 0, $$pre91 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0;
 var $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0;
 var $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0;
 var $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0;
 var $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0;
 var $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0;
 var $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0;
 var $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0;
 var $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0;
 var $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0;
 var $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond88 = 0, $i$086 = 0, $not$ = 0, $slice$087 = 0, $storemerge = 0, $storemerge85 = 0, $temp$0$i = 0, $temp$0$i13 = 0, $temp$0$i19 = 0, $temp$0$i25 = 0, $temp$0$i31 = 0, $temp$0$i39 = 0, $temp$0$i44 = 0, $temp$0$i50 = 0, $temp$0$i56 = 0, $temp$0$i62 = 0;
 var $temp$0$i68 = 0, $temp$0$i7 = 0, $temp$0$i74 = 0, $temp$0$i80 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy5 = sp + 56|0;
 $0 = sp + 52|0;
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = sp + 36|0;
 $5 = sp + 32|0;
 $6 = sp + 28|0;
 $7 = sp + 20|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 4|0;
 $12 = sp;
 $13 = sp + 24|0;
 $14 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $14;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 $15 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy5,1,16,602528,1111)|0);
 HEAP32[$1>>2] = $14;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1733,($15|0),($$byval_copy5|0),0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($15|0),($$byval_copy5|0),1,16,(602528|0),1111);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $22 = ___cxa_find_matching_catch(0|0)|0;
   $23 = tempRet0;
   ___clang_call_terminate($22);
   // unreachable;
  } else {
   ___resumeException($18|0);
   // unreachable;
  }
 }
 $24 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($15)|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vi[$27 & 4095]($24);
 $28 = HEAP32[$24>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($24,4);
 $31 = ($24|0)==(0|0);
 if ($31) {
  $storemerge = 0;
 } else {
  $32 = (($24) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $storemerge = $33;
 }
 HEAP32[601976>>2] = $storemerge;
 HEAP32[$13>>2] = $storemerge;
 $34 = HEAP32[560624>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  label = 15;
 } else {
  $36 = (($34) + 36|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($34) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)==($39|0);
  do {
   if ($40) {
    $41 = (($34) + 28|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($34) + 32|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($42) + ($44<<3)|0);
    $61 = $45;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$34,$13);
    $46 = HEAP32[$$byval_copy5>>2]|0;
    $47 = ($46|0)==(-1);
    $48 = (($34) + 28|0);
    $49 = HEAP32[$48>>2]|0;
    if ($47) {
     $50 = (($34) + 32|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($49) + ($51<<3)|0);
     $61 = $52;
     break;
    } else {
     $53 = (($49) + ($46<<3)|0);
     $61 = $53;
     break;
    }
   }
  } while(0);
  $54 = HEAP32[560624>>2]|0;
  $55 = (($54) + 28|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($54) + 32|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($56) + ($58<<3)|0);
  $60 = ($61|0)==($59|0);
  if ($60) {
   label = 15;
  } else {
   $62 = (($61) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    label = 15;
   } else {
    $temp$0$i = $63;
   }
  }
 }
 if ((label|0) == 15) {
  $65 = HEAP32[601976>>2]|0;
  $66 = (__Z31ReadObjectFromPersistentManageri($65)|0);
  $temp$0$i = $66;
 }
 $67 = HEAP32[$temp$0$i>>2]|0;
 $68 = (($67) + 44|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vii[$69 & 4095]($temp$0$i,61);
 $70 = HEAP32[601976>>2]|0;
 HEAP32[$12>>2] = $70;
 $71 = HEAP32[560624>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  label = 24;
 } else {
  $73 = (($71) + 36|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($71) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($74|0)==($76|0);
  do {
   if ($77) {
    $78 = (($71) + 28|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($71) + 32|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($79) + ($81<<3)|0);
    $98 = $82;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$71,$12);
    $83 = HEAP32[$$byval_copy5>>2]|0;
    $84 = ($83|0)==(-1);
    $85 = (($71) + 28|0);
    $86 = HEAP32[$85>>2]|0;
    if ($84) {
     $87 = (($71) + 32|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = (($86) + ($88<<3)|0);
     $98 = $89;
     break;
    } else {
     $90 = (($86) + ($83<<3)|0);
     $98 = $90;
     break;
    }
   }
  } while(0);
  $91 = HEAP32[560624>>2]|0;
  $92 = (($91) + 28|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (($91) + 32|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($93) + ($95<<3)|0);
  $97 = ($98|0)==($96|0);
  if ($97) {
   label = 24;
  } else {
   $99 = (($98) + 4|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==(0|0);
   if ($101) {
    label = 24;
   } else {
    $temp$0$i7 = $100;
   }
  }
 }
 if ((label|0) == 24) {
  $102 = HEAP32[601976>>2]|0;
  $103 = (__Z31ReadObjectFromPersistentManageri($102)|0);
  $temp$0$i7 = $103;
 }
 $104 = HEAP32[$temp$0$i7>>2]|0;
 $105 = (($104) + 148|0);
 $106 = HEAP32[$105>>2]|0;
 (FUNCTION_TABLE_iiiiiiii[$106 & 127]($temp$0$i7,4,64,1,0,1,0)|0);
 $107 = HEAP32[601976>>2]|0;
 HEAP32[$11>>2] = $107;
 $108 = HEAP32[560624>>2]|0;
 $109 = ($108|0)==(0|0);
 if ($109) {
  label = 33;
 } else {
  $110 = (($108) + 36|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = (($108) + 4|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ($111|0)==($113|0);
  do {
   if ($114) {
    $115 = (($108) + 28|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($108) + 32|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (($116) + ($118<<3)|0);
    $135 = $119;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$108,$11);
    $120 = HEAP32[$$byval_copy5>>2]|0;
    $121 = ($120|0)==(-1);
    $122 = (($108) + 28|0);
    $123 = HEAP32[$122>>2]|0;
    if ($121) {
     $124 = (($108) + 32|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = (($123) + ($125<<3)|0);
     $135 = $126;
     break;
    } else {
     $127 = (($123) + ($120<<3)|0);
     $135 = $127;
     break;
    }
   }
  } while(0);
  $128 = HEAP32[560624>>2]|0;
  $129 = (($128) + 28|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($128) + 32|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = (($130) + ($132<<3)|0);
  $134 = ($135|0)==($133|0);
  if ($134) {
   label = 33;
  } else {
   $136 = (($135) + 4|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = ($137|0)==(0|0);
   if ($138) {
    label = 33;
   } else {
    $145 = $128;$temp$0$i13 = $137;
   }
  }
 }
 if ((label|0) == 33) {
  $139 = HEAP32[601976>>2]|0;
  $140 = (__Z31ReadObjectFromPersistentManageri($139)|0);
  $$pre = HEAP32[560624>>2]|0;
  $145 = $$pre;$temp$0$i13 = $140;
 }
 $141 = (($temp$0$i13) + 28|0);
 $142 = (($141) + 4|0);
 HEAP32[$142>>2] = 0;
 $143 = HEAP32[601976>>2]|0;
 HEAP32[$10>>2] = $143;
 $144 = ($145|0)==(0|0);
 if ($144) {
  label = 42;
 } else {
  $146 = (($145) + 36|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = (($145) + 4|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = ($147|0)==($149|0);
  do {
   if ($150) {
    $151 = (($145) + 28|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = (($145) + 32|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = (($152) + ($154<<3)|0);
    $171 = $155;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$145,$10);
    $156 = HEAP32[$$byval_copy5>>2]|0;
    $157 = ($156|0)==(-1);
    $158 = (($145) + 28|0);
    $159 = HEAP32[$158>>2]|0;
    if ($157) {
     $160 = (($145) + 32|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = (($159) + ($161<<3)|0);
     $171 = $162;
     break;
    } else {
     $163 = (($159) + ($156<<3)|0);
     $171 = $163;
     break;
    }
   }
  } while(0);
  $164 = HEAP32[560624>>2]|0;
  $165 = (($164) + 28|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = (($164) + 32|0);
  $168 = HEAP32[$167>>2]|0;
  $169 = (($166) + ($168<<3)|0);
  $170 = ($171|0)==($169|0);
  if ($170) {
   label = 42;
  } else {
   $172 = (($171) + 4|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = ($173|0)==(0|0);
   if ($174) {
    label = 42;
   } else {
    $180 = $164;$temp$0$i19 = $173;
   }
  }
 }
 if ((label|0) == 42) {
  $175 = HEAP32[601976>>2]|0;
  $176 = (__Z31ReadObjectFromPersistentManageri($175)|0);
  $$pre89 = HEAP32[560624>>2]|0;
  $180 = $$pre89;$temp$0$i19 = $176;
 }
 $177 = (($temp$0$i19) + 28|0);
 HEAP32[$177>>2] = 0;
 $178 = HEAP32[601976>>2]|0;
 HEAP32[$9>>2] = $178;
 $179 = ($180|0)==(0|0);
 if ($179) {
  label = 51;
 } else {
  $181 = (($180) + 36|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = (($180) + 4|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ($182|0)==($184|0);
  do {
   if ($185) {
    $186 = (($180) + 28|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = (($180) + 32|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = (($187) + ($189<<3)|0);
    $206 = $190;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$180,$9);
    $191 = HEAP32[$$byval_copy5>>2]|0;
    $192 = ($191|0)==(-1);
    $193 = (($180) + 28|0);
    $194 = HEAP32[$193>>2]|0;
    if ($192) {
     $195 = (($180) + 32|0);
     $196 = HEAP32[$195>>2]|0;
     $197 = (($194) + ($196<<3)|0);
     $206 = $197;
     break;
    } else {
     $198 = (($194) + ($191<<3)|0);
     $206 = $198;
     break;
    }
   }
  } while(0);
  $199 = HEAP32[560624>>2]|0;
  $200 = (($199) + 28|0);
  $201 = HEAP32[$200>>2]|0;
  $202 = (($199) + 32|0);
  $203 = HEAP32[$202>>2]|0;
  $204 = (($201) + ($203<<3)|0);
  $205 = ($206|0)==($204|0);
  if ($205) {
   label = 51;
  } else {
   $207 = (($206) + 4|0);
   $208 = HEAP32[$207>>2]|0;
   $209 = ($208|0)==(0|0);
   if ($209) {
    label = 51;
   } else {
    $temp$0$i25 = $208;
   }
  }
 }
 if ((label|0) == 51) {
  $210 = HEAP32[601976>>2]|0;
  $211 = (__Z31ReadObjectFromPersistentManageri($210)|0);
  $temp$0$i25 = $211;
 }
 $212 = HEAP32[$temp$0$i25>>2]|0;
 $213 = (($212) + 132|0);
 $214 = HEAP32[$213>>2]|0;
 FUNCTION_TABLE_vi[$214 & 4095]($temp$0$i25);
 $215 = HEAP32[601976>>2]|0;
 HEAP32[$8>>2] = $215;
 $216 = HEAP32[560624>>2]|0;
 $217 = ($216|0)==(0|0);
 if ($217) {
  label = 60;
 } else {
  $218 = (($216) + 36|0);
  $219 = HEAP32[$218>>2]|0;
  $220 = (($216) + 4|0);
  $221 = HEAP32[$220>>2]|0;
  $222 = ($219|0)==($221|0);
  do {
   if ($222) {
    $223 = (($216) + 28|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = (($216) + 32|0);
    $226 = HEAP32[$225>>2]|0;
    $227 = (($224) + ($226<<3)|0);
    $243 = $227;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$216,$8);
    $228 = HEAP32[$$byval_copy5>>2]|0;
    $229 = ($228|0)==(-1);
    $230 = (($216) + 28|0);
    $231 = HEAP32[$230>>2]|0;
    if ($229) {
     $232 = (($216) + 32|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = (($231) + ($233<<3)|0);
     $243 = $234;
     break;
    } else {
     $235 = (($231) + ($228<<3)|0);
     $243 = $235;
     break;
    }
   }
  } while(0);
  $236 = HEAP32[560624>>2]|0;
  $237 = (($236) + 28|0);
  $238 = HEAP32[$237>>2]|0;
  $239 = (($236) + 32|0);
  $240 = HEAP32[$239>>2]|0;
  $241 = (($238) + ($240<<3)|0);
  $242 = ($243|0)==($241|0);
  if ($242) {
   label = 60;
  } else {
   $244 = (($243) + 4|0);
   $245 = HEAP32[$244>>2]|0;
   $246 = ($245|0)==(0|0);
   if ($246) {
    label = 60;
   } else {
    $temp$0$i31 = $245;
   }
  }
 }
 if ((label|0) == 60) {
  $247 = HEAP32[601976>>2]|0;
  $248 = (__Z31ReadObjectFromPersistentManageri($247)|0);
  $temp$0$i31 = $248;
 }
 __ZN9Texture2D18UnshareTextureDataEv($temp$0$i31);
 $249 = (($temp$0$i31) + 48|0);
 $250 = HEAP32[$249>>2]|0;
 $251 = ($250|0)==(0|0);
 if ($251) {
  $262 = 0;
 } else {
  $252 = (($250) + 8|0);
  $253 = HEAP32[$252>>2]|0;
  $262 = $253;
 }
 $slice$087 = 0;
 while(1) {
  $254 = (15 - ($slice$087))|0;
  $255 = $slice$087 << 4;
  $256 = $254 << 4;
  $i$086 = 0;
  while(1) {
   $257 = (602096 + ($i$086)|0);
   $258 = HEAP8[$257>>0]|0;
   $259 = $258&255;
   $not$ = ($259|0)<($slice$087|0);
   $260 = $not$ << 31 >> 31;
   $$sum = (($i$086) + ($255))|0;
   $261 = (($262) + ($$sum)|0);
   HEAP8[$261>>0] = $260;
   $263 = $260&255;
   $264 = $263 ^ 255;
   $265 = $264&255;
   $$sum1 = (($i$086) + ($256))|0;
   $266 = (($262) + ($$sum1)|0);
   HEAP8[$266>>0] = $265;
   $267 = (($i$086) + 1)|0;
   $exitcond = ($267|0)==(16);
   if ($exitcond) {
    break;
   } else {
    $i$086 = $267;
   }
  }
  $268 = (($slice$087) + 1)|0;
  $exitcond88 = ($268|0)==(8);
  if ($exitcond88) {
   break;
  } else {
   $slice$087 = $268;
  }
 }
 $269 = HEAP8[((640792 + 225|0))>>0]|0;
 $270 = ($269<<24>>24)==(0);
 if (!($270)) {
  $271 = HEAP32[628384>>2]|0;
  HEAP32[$0>>2] = $271;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  $272 = (__Znwj10MemLabelIdbiPKci(128,$$byval_copy5,1,16,602528,1111)|0);
  HEAP32[$1>>2] = $271;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viii(1735,($272|0),($$byval_copy5|0),0);
  $273 = __THREW__; __THREW__ = 0;
  $274 = $273&1;
  if ($274) {
   $275 = ___cxa_find_matching_catch()|0;
   $276 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viiiiii(97,($272|0),($$byval_copy5|0),1,16,(602528|0),1111);
   $277 = __THREW__; __THREW__ = 0;
   $278 = $277&1;
   if ($278) {
    $279 = ___cxa_find_matching_catch(0|0)|0;
    $280 = tempRet0;
    ___clang_call_terminate($279);
    // unreachable;
   } else {
    ___resumeException($275|0);
    // unreachable;
   }
  }
  $281 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($272)|0);
  $282 = HEAP32[$281>>2]|0;
  $283 = (($282) + 24|0);
  $284 = HEAP32[$283>>2]|0;
  FUNCTION_TABLE_vi[$284 & 4095]($281);
  $285 = HEAP32[$281>>2]|0;
  $286 = (($285) + 12|0);
  $287 = HEAP32[$286>>2]|0;
  FUNCTION_TABLE_vii[$287 & 4095]($281,4);
  $288 = ($281|0)==(0|0);
  if ($288) {
   $storemerge85 = 0;
  } else {
   $289 = (($281) + 4|0);
   $290 = HEAP32[$289>>2]|0;
   $storemerge85 = $290;
  }
  HEAP32[601984>>2] = $storemerge85;
  HEAP32[$7>>2] = $storemerge85;
  $291 = HEAP32[560624>>2]|0;
  $292 = ($291|0)==(0|0);
  if ($292) {
   label = 82;
  } else {
   $293 = (($291) + 36|0);
   $294 = HEAP32[$293>>2]|0;
   $295 = (($291) + 4|0);
   $296 = HEAP32[$295>>2]|0;
   $297 = ($294|0)==($296|0);
   do {
    if ($297) {
     $298 = (($291) + 28|0);
     $299 = HEAP32[$298>>2]|0;
     $300 = (($291) + 32|0);
     $301 = HEAP32[$300>>2]|0;
     $302 = (($299) + ($301<<3)|0);
     $318 = $302;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$291,$7);
     $303 = HEAP32[$$byval_copy5>>2]|0;
     $304 = ($303|0)==(-1);
     $305 = (($291) + 28|0);
     $306 = HEAP32[$305>>2]|0;
     if ($304) {
      $307 = (($291) + 32|0);
      $308 = HEAP32[$307>>2]|0;
      $309 = (($306) + ($308<<3)|0);
      $318 = $309;
      break;
     } else {
      $310 = (($306) + ($303<<3)|0);
      $318 = $310;
      break;
     }
    }
   } while(0);
   $311 = HEAP32[560624>>2]|0;
   $312 = (($311) + 28|0);
   $313 = HEAP32[$312>>2]|0;
   $314 = (($311) + 32|0);
   $315 = HEAP32[$314>>2]|0;
   $316 = (($313) + ($315<<3)|0);
   $317 = ($318|0)==($316|0);
   if ($317) {
    label = 82;
   } else {
    $319 = (($318) + 4|0);
    $320 = HEAP32[$319>>2]|0;
    $321 = ($320|0)==(0|0);
    if ($321) {
     label = 82;
    } else {
     $temp$0$i39 = $320;
    }
   }
  }
  if ((label|0) == 82) {
   $322 = HEAP32[601984>>2]|0;
   $323 = (__Z31ReadObjectFromPersistentManageri($322)|0);
   $temp$0$i39 = $323;
  }
  $324 = HEAP32[$temp$0$i39>>2]|0;
  $325 = (($324) + 44|0);
  $326 = HEAP32[$325>>2]|0;
  FUNCTION_TABLE_vii[$326 & 4095]($temp$0$i39,61);
  $327 = HEAP32[601984>>2]|0;
  HEAP32[$6>>2] = $327;
  $328 = HEAP32[560624>>2]|0;
  $329 = ($328|0)==(0|0);
  if ($329) {
   label = 91;
  } else {
   $330 = (($328) + 36|0);
   $331 = HEAP32[$330>>2]|0;
   $332 = (($328) + 4|0);
   $333 = HEAP32[$332>>2]|0;
   $334 = ($331|0)==($333|0);
   do {
    if ($334) {
     $335 = (($328) + 28|0);
     $336 = HEAP32[$335>>2]|0;
     $337 = (($328) + 32|0);
     $338 = HEAP32[$337>>2]|0;
     $339 = (($336) + ($338<<3)|0);
     $355 = $339;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$328,$6);
     $340 = HEAP32[$$byval_copy5>>2]|0;
     $341 = ($340|0)==(-1);
     $342 = (($328) + 28|0);
     $343 = HEAP32[$342>>2]|0;
     if ($341) {
      $344 = (($328) + 32|0);
      $345 = HEAP32[$344>>2]|0;
      $346 = (($343) + ($345<<3)|0);
      $355 = $346;
      break;
     } else {
      $347 = (($343) + ($340<<3)|0);
      $355 = $347;
      break;
     }
    }
   } while(0);
   $348 = HEAP32[560624>>2]|0;
   $349 = (($348) + 28|0);
   $350 = HEAP32[$349>>2]|0;
   $351 = (($348) + 32|0);
   $352 = HEAP32[$351>>2]|0;
   $353 = (($350) + ($352<<3)|0);
   $354 = ($355|0)==($353|0);
   if ($354) {
    label = 91;
   } else {
    $356 = (($355) + 4|0);
    $357 = HEAP32[$356>>2]|0;
    $358 = ($357|0)==(0|0);
    if ($358) {
     label = 91;
    } else {
     $temp$0$i44 = $357;
    }
   }
  }
  if ((label|0) == 91) {
   $359 = HEAP32[601984>>2]|0;
   $360 = (__Z31ReadObjectFromPersistentManageri($359)|0);
   $temp$0$i44 = $360;
  }
  (__ZN9Texture3D11InitTextureEiii13TextureFormatb($temp$0$i44,4,4,16,1,0)|0);
  $361 = HEAP32[601984>>2]|0;
  HEAP32[$5>>2] = $361;
  $362 = HEAP32[560624>>2]|0;
  $363 = ($362|0)==(0|0);
  if ($363) {
   label = 100;
  } else {
   $364 = (($362) + 36|0);
   $365 = HEAP32[$364>>2]|0;
   $366 = (($362) + 4|0);
   $367 = HEAP32[$366>>2]|0;
   $368 = ($365|0)==($367|0);
   do {
    if ($368) {
     $369 = (($362) + 28|0);
     $370 = HEAP32[$369>>2]|0;
     $371 = (($362) + 32|0);
     $372 = HEAP32[$371>>2]|0;
     $373 = (($370) + ($372<<3)|0);
     $389 = $373;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$362,$5);
     $374 = HEAP32[$$byval_copy5>>2]|0;
     $375 = ($374|0)==(-1);
     $376 = (($362) + 28|0);
     $377 = HEAP32[$376>>2]|0;
     if ($375) {
      $378 = (($362) + 32|0);
      $379 = HEAP32[$378>>2]|0;
      $380 = (($377) + ($379<<3)|0);
      $389 = $380;
      break;
     } else {
      $381 = (($377) + ($374<<3)|0);
      $389 = $381;
      break;
     }
    }
   } while(0);
   $382 = HEAP32[560624>>2]|0;
   $383 = (($382) + 28|0);
   $384 = HEAP32[$383>>2]|0;
   $385 = (($382) + 32|0);
   $386 = HEAP32[$385>>2]|0;
   $387 = (($384) + ($386<<3)|0);
   $388 = ($389|0)==($387|0);
   if ($388) {
    label = 100;
   } else {
    $390 = (($389) + 4|0);
    $391 = HEAP32[$390>>2]|0;
    $392 = ($391|0)==(0|0);
    if ($392) {
     label = 100;
    } else {
     $399 = $382;$temp$0$i50 = $391;
    }
   }
  }
  if ((label|0) == 100) {
   $393 = HEAP32[601984>>2]|0;
   $394 = (__Z31ReadObjectFromPersistentManageri($393)|0);
   $$pre90 = HEAP32[560624>>2]|0;
   $399 = $$pre90;$temp$0$i50 = $394;
  }
  $395 = (($temp$0$i50) + 28|0);
  $396 = (($395) + 4|0);
  HEAP32[$396>>2] = 0;
  $397 = HEAP32[601984>>2]|0;
  HEAP32[$4>>2] = $397;
  $398 = ($399|0)==(0|0);
  if ($398) {
   label = 109;
  } else {
   $400 = (($399) + 36|0);
   $401 = HEAP32[$400>>2]|0;
   $402 = (($399) + 4|0);
   $403 = HEAP32[$402>>2]|0;
   $404 = ($401|0)==($403|0);
   do {
    if ($404) {
     $405 = (($399) + 28|0);
     $406 = HEAP32[$405>>2]|0;
     $407 = (($399) + 32|0);
     $408 = HEAP32[$407>>2]|0;
     $409 = (($406) + ($408<<3)|0);
     $425 = $409;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$399,$4);
     $410 = HEAP32[$$byval_copy5>>2]|0;
     $411 = ($410|0)==(-1);
     $412 = (($399) + 28|0);
     $413 = HEAP32[$412>>2]|0;
     if ($411) {
      $414 = (($399) + 32|0);
      $415 = HEAP32[$414>>2]|0;
      $416 = (($413) + ($415<<3)|0);
      $425 = $416;
      break;
     } else {
      $417 = (($413) + ($410<<3)|0);
      $425 = $417;
      break;
     }
    }
   } while(0);
   $418 = HEAP32[560624>>2]|0;
   $419 = (($418) + 28|0);
   $420 = HEAP32[$419>>2]|0;
   $421 = (($418) + 32|0);
   $422 = HEAP32[$421>>2]|0;
   $423 = (($420) + ($422<<3)|0);
   $424 = ($425|0)==($423|0);
   if ($424) {
    label = 109;
   } else {
    $426 = (($425) + 4|0);
    $427 = HEAP32[$426>>2]|0;
    $428 = ($427|0)==(0|0);
    if ($428) {
     label = 109;
    } else {
     $434 = $418;$temp$0$i56 = $427;
    }
   }
  }
  if ((label|0) == 109) {
   $429 = HEAP32[601984>>2]|0;
   $430 = (__Z31ReadObjectFromPersistentManageri($429)|0);
   $$pre91 = HEAP32[560624>>2]|0;
   $434 = $$pre91;$temp$0$i56 = $430;
  }
  $431 = (($temp$0$i56) + 28|0);
  HEAP32[$431>>2] = 0;
  $432 = HEAP32[601984>>2]|0;
  HEAP32[$3>>2] = $432;
  $433 = ($434|0)==(0|0);
  do {
   if ($433) {
    label = 118;
   } else {
    $435 = (($434) + 36|0);
    $436 = HEAP32[$435>>2]|0;
    $437 = (($434) + 4|0);
    $438 = HEAP32[$437>>2]|0;
    $439 = ($436|0)==($438|0);
    do {
     if ($439) {
      $440 = (($434) + 28|0);
      $441 = HEAP32[$440>>2]|0;
      $442 = (($434) + 32|0);
      $443 = HEAP32[$442>>2]|0;
      $444 = (($441) + ($443<<3)|0);
      $460 = $444;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$434,$3);
      $445 = HEAP32[$$byval_copy5>>2]|0;
      $446 = ($445|0)==(-1);
      $447 = (($434) + 28|0);
      $448 = HEAP32[$447>>2]|0;
      if ($446) {
       $449 = (($434) + 32|0);
       $450 = HEAP32[$449>>2]|0;
       $451 = (($448) + ($450<<3)|0);
       $460 = $451;
       break;
      } else {
       $452 = (($448) + ($445<<3)|0);
       $460 = $452;
       break;
      }
     }
    } while(0);
    $453 = HEAP32[560624>>2]|0;
    $454 = (($453) + 28|0);
    $455 = HEAP32[$454>>2]|0;
    $456 = (($453) + 32|0);
    $457 = HEAP32[$456>>2]|0;
    $458 = (($455) + ($457<<3)|0);
    $459 = ($460|0)==($458|0);
    if ($459) {
     label = 118;
     break;
    }
    $461 = (($460) + 4|0);
    $462 = HEAP32[$461>>2]|0;
    $463 = ($462|0)==(0|0);
    if ($463) {
     label = 118;
    } else {
     $temp$0$i62 = $462;
    }
   }
  } while(0);
  if ((label|0) == 118) {
   $464 = HEAP32[601984>>2]|0;
   $465 = (__Z31ReadObjectFromPersistentManageri($464)|0);
   $temp$0$i62 = $465;
  }
  $466 = HEAP32[$temp$0$i62>>2]|0;
  $467 = (($466) + 132|0);
  $468 = HEAP32[$467>>2]|0;
  FUNCTION_TABLE_vi[$468 & 4095]($temp$0$i62);
  $469 = HEAP32[601984>>2]|0;
  HEAP32[$2>>2] = $469;
  $470 = HEAP32[560624>>2]|0;
  $471 = ($470|0)==(0|0);
  do {
   if ($471) {
    label = 127;
   } else {
    $472 = (($470) + 36|0);
    $473 = HEAP32[$472>>2]|0;
    $474 = (($470) + 4|0);
    $475 = HEAP32[$474>>2]|0;
    $476 = ($473|0)==($475|0);
    do {
     if ($476) {
      $477 = (($470) + 28|0);
      $478 = HEAP32[$477>>2]|0;
      $479 = (($470) + 32|0);
      $480 = HEAP32[$479>>2]|0;
      $481 = (($478) + ($480<<3)|0);
      $497 = $481;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$470,$2);
      $482 = HEAP32[$$byval_copy5>>2]|0;
      $483 = ($482|0)==(-1);
      $484 = (($470) + 28|0);
      $485 = HEAP32[$484>>2]|0;
      if ($483) {
       $486 = (($470) + 32|0);
       $487 = HEAP32[$486>>2]|0;
       $488 = (($485) + ($487<<3)|0);
       $497 = $488;
       break;
      } else {
       $489 = (($485) + ($482<<3)|0);
       $497 = $489;
       break;
      }
     }
    } while(0);
    $490 = HEAP32[560624>>2]|0;
    $491 = (($490) + 28|0);
    $492 = HEAP32[$491>>2]|0;
    $493 = (($490) + 32|0);
    $494 = HEAP32[$493>>2]|0;
    $495 = (($492) + ($494<<3)|0);
    $496 = ($497|0)==($495|0);
    if ($496) {
     label = 127;
     break;
    }
    $498 = (($497) + 4|0);
    $499 = HEAP32[$498>>2]|0;
    $500 = ($499|0)==(0|0);
    if ($500) {
     label = 127;
    } else {
     $temp$0$i68 = $499;
    }
   }
  } while(0);
  if ((label|0) == 127) {
   $501 = HEAP32[601984>>2]|0;
   $502 = (__Z31ReadObjectFromPersistentManageri($501)|0);
   $temp$0$i68 = $502;
  }
  $503 = (($temp$0$i68) + 116|0);
  $504 = HEAP32[$503>>2]|0;
  _memcpy(($504|0),($262|0),256)|0;
  $505 = HEAP32[601984>>2]|0;
  HEAP32[$1>>2] = $505;
  $506 = HEAP32[560624>>2]|0;
  $507 = ($506|0)==(0|0);
  do {
   if ($507) {
    label = 136;
   } else {
    $508 = (($506) + 36|0);
    $509 = HEAP32[$508>>2]|0;
    $510 = (($506) + 4|0);
    $511 = HEAP32[$510>>2]|0;
    $512 = ($509|0)==($511|0);
    do {
     if ($512) {
      $513 = (($506) + 28|0);
      $514 = HEAP32[$513>>2]|0;
      $515 = (($506) + 32|0);
      $516 = HEAP32[$515>>2]|0;
      $517 = (($514) + ($516<<3)|0);
      $533 = $517;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$506,$1);
      $518 = HEAP32[$$byval_copy5>>2]|0;
      $519 = ($518|0)==(-1);
      $520 = (($506) + 28|0);
      $521 = HEAP32[$520>>2]|0;
      if ($519) {
       $522 = (($506) + 32|0);
       $523 = HEAP32[$522>>2]|0;
       $524 = (($521) + ($523<<3)|0);
       $533 = $524;
       break;
      } else {
       $525 = (($521) + ($518<<3)|0);
       $533 = $525;
       break;
      }
     }
    } while(0);
    $526 = HEAP32[560624>>2]|0;
    $527 = (($526) + 28|0);
    $528 = HEAP32[$527>>2]|0;
    $529 = (($526) + 32|0);
    $530 = HEAP32[$529>>2]|0;
    $531 = (($528) + ($530<<3)|0);
    $532 = ($533|0)==($531|0);
    if ($532) {
     label = 136;
     break;
    }
    $534 = (($533) + 4|0);
    $535 = HEAP32[$534>>2]|0;
    $536 = ($535|0)==(0|0);
    if ($536) {
     label = 136;
    } else {
     $temp$0$i74 = $535;
    }
   }
  } while(0);
  if ((label|0) == 136) {
   $537 = HEAP32[601984>>2]|0;
   $538 = (__Z31ReadObjectFromPersistentManageri($537)|0);
   $temp$0$i74 = $538;
  }
  __ZN9Texture3D15UpdateImageDataEb($temp$0$i74,0);
 }
 $539 = HEAP32[601976>>2]|0;
 HEAP32[$0>>2] = $539;
 $540 = HEAP32[560624>>2]|0;
 $541 = ($540|0)==(0|0);
 if (!($541)) {
  $542 = (($540) + 36|0);
  $543 = HEAP32[$542>>2]|0;
  $544 = (($540) + 4|0);
  $545 = HEAP32[$544>>2]|0;
  $546 = ($543|0)==($545|0);
  do {
   if ($546) {
    $547 = (($540) + 28|0);
    $548 = HEAP32[$547>>2]|0;
    $549 = (($540) + 32|0);
    $550 = HEAP32[$549>>2]|0;
    $551 = (($548) + ($550<<3)|0);
    $567 = $551;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$540,$0);
    $552 = HEAP32[$$byval_copy5>>2]|0;
    $553 = ($552|0)==(-1);
    $554 = (($540) + 28|0);
    $555 = HEAP32[$554>>2]|0;
    if ($553) {
     $556 = (($540) + 32|0);
     $557 = HEAP32[$556>>2]|0;
     $558 = (($555) + ($557<<3)|0);
     $567 = $558;
     break;
    } else {
     $559 = (($555) + ($552<<3)|0);
     $567 = $559;
     break;
    }
   }
  } while(0);
  $560 = HEAP32[560624>>2]|0;
  $561 = (($560) + 28|0);
  $562 = HEAP32[$561>>2]|0;
  $563 = (($560) + 32|0);
  $564 = HEAP32[$563>>2]|0;
  $565 = (($562) + ($564<<3)|0);
  $566 = ($567|0)==($565|0);
  if (!($566)) {
   $568 = (($567) + 4|0);
   $569 = HEAP32[$568>>2]|0;
   $570 = ($569|0)==(0|0);
   if (!($570)) {
    $temp$0$i80 = $569;
    $573 = HEAP32[$temp$0$i80>>2]|0;
    $574 = (($573) + 152|0);
    $575 = HEAP32[$574>>2]|0;
    FUNCTION_TABLE_vi[$575 & 4095]($temp$0$i80);
    STACKTOP = sp;return;
   }
  }
 }
 $571 = HEAP32[601976>>2]|0;
 $572 = (__Z31ReadObjectFromPersistentManageri($571)|0);
 $temp$0$i80 = $572;
 $573 = HEAP32[$temp$0$i80>>2]|0;
 $574 = (($573) + 152|0);
 $575 = HEAP32[$574>>2]|0;
 FUNCTION_TABLE_vi[$575 & 4095]($temp$0$i80);
 STACKTOP = sp;return;
}
function __ZN10builtintex21ReinitBuiltinTexturesEv() {
 var $$0$i = 0, $$0$i102 = 0, $$0$i109 = 0, $$0$i116 = 0, $$0$i12 = 0, $$0$i123 = 0, $$0$i130 = 0, $$0$i19 = 0, $$0$i26 = 0, $$0$i33 = 0, $$0$i40 = 0, $$0$i47 = 0, $$0$i54 = 0, $$0$i6 = 0, $$0$i61 = 0, $$0$i68 = 0, $$0$i75 = 0, $$0$i81 = 0, $$0$i88 = 0, $$0$i95 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $pos$i$i$i$i125 = 0, $temp$0$i = 0, $temp$0$i101 = 0, $temp$0$i108 = 0, $temp$0$i11 = 0, $temp$0$i115 = 0, $temp$0$i122 = 0, $temp$0$i129 = 0, $temp$0$i18 = 0, $temp$0$i25 = 0, $temp$0$i32 = 0, $temp$0$i39 = 0, $temp$0$i46 = 0, $temp$0$i5 = 0, $temp$0$i53 = 0, $temp$0$i60 = 0, $temp$0$i67 = 0, $temp$0$i74 = 0, $temp$0$i80 = 0, $temp$0$i87 = 0;
 var $temp$0$i94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $pos$i$i$i$i125 = sp + 80|0;
 $0 = sp + 76|0;
 $1 = sp + 72|0;
 $2 = sp + 68|0;
 $3 = sp + 64|0;
 $4 = sp + 60|0;
 $5 = sp + 56|0;
 $6 = sp + 52|0;
 $7 = sp + 48|0;
 $8 = sp + 44|0;
 $9 = sp + 40|0;
 $10 = sp + 12|0;
 $11 = sp;
 $12 = sp + 4|0;
 $13 = sp + 8|0;
 $14 = sp + 16|0;
 $15 = sp + 20|0;
 $16 = sp + 24|0;
 $17 = sp + 28|0;
 $18 = sp + 32|0;
 $19 = sp + 36|0;
 $20 = (__Z12GetGfxDevicev()|0);
 $21 = (($20) + 3748|0);
 $22 = HEAP32[601936>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0$i6 = 0;
 } else {
  HEAP32[$18>>2] = $22;
  $24 = HEAP32[560624>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   label = 10;
  } else {
   $26 = (($24) + 36|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($24) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)==($29|0);
   do {
    if ($30) {
     $31 = (($24) + 28|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($24) + 32|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + ($34<<3)|0);
     $51 = $35;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$24,$18);
     $36 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $37 = ($36|0)==(-1);
     $38 = (($24) + 28|0);
     $39 = HEAP32[$38>>2]|0;
     if ($37) {
      $40 = (($24) + 32|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($39) + ($41<<3)|0);
      $51 = $42;
      break;
     } else {
      $43 = (($39) + ($36<<3)|0);
      $51 = $43;
      break;
     }
    }
   } while(0);
   $44 = HEAP32[560624>>2]|0;
   $45 = (($44) + 28|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 32|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($46) + ($48<<3)|0);
   $50 = ($51|0)==($49|0);
   if ($50) {
    label = 10;
   } else {
    $52 = (($51) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     label = 10;
    } else {
     $temp$0$i5 = $53;
    }
   }
  }
  if ((label|0) == 10) {
   $55 = HEAP32[601936>>2]|0;
   $56 = (__Z31ReadObjectFromPersistentManageri($55)|0);
   $temp$0$i5 = $56;
  }
  $$0$i6 = $temp$0$i5;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($21,$$0$i6,0,103,0,124);
 $57 = (__Z12GetGfxDevicev()|0);
 $58 = (($57) + 3812|0);
 $59 = HEAP32[601944>>2]|0;
 $60 = ($59|0)==(0);
 if ($60) {
  $$0$i19 = 0;
 } else {
  HEAP32[$16>>2] = $59;
  $61 = HEAP32[560624>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   label = 21;
  } else {
   $63 = (($61) + 36|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($61) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($64|0)==($66|0);
   do {
    if ($67) {
     $68 = (($61) + 28|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (($61) + 32|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = (($69) + ($71<<3)|0);
     $88 = $72;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$61,$16);
     $73 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $74 = ($73|0)==(-1);
     $75 = (($61) + 28|0);
     $76 = HEAP32[$75>>2]|0;
     if ($74) {
      $77 = (($61) + 32|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($76) + ($78<<3)|0);
      $88 = $79;
      break;
     } else {
      $80 = (($76) + ($73<<3)|0);
      $88 = $80;
      break;
     }
    }
   } while(0);
   $81 = HEAP32[560624>>2]|0;
   $82 = (($81) + 28|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($81) + 32|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($83) + ($85<<3)|0);
   $87 = ($88|0)==($86|0);
   if ($87) {
    label = 21;
   } else {
    $89 = (($88) + 4|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = ($90|0)==(0|0);
    if ($91) {
     label = 21;
    } else {
     $temp$0$i18 = $90;
    }
   }
  }
  if ((label|0) == 21) {
   $92 = HEAP32[601944>>2]|0;
   $93 = (__Z31ReadObjectFromPersistentManageri($92)|0);
   $temp$0$i18 = $93;
  }
  $$0$i19 = $temp$0$i18;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($58,$$0$i19,0,104,0,125);
 $94 = (__Z12GetGfxDevicev()|0);
 $95 = (($94) + 3876|0);
 $96 = HEAP32[602008>>2]|0;
 $97 = ($96|0)==(0);
 if ($97) {
  $$0$i26 = 0;
 } else {
  HEAP32[$15>>2] = $96;
  $98 = HEAP32[560624>>2]|0;
  $99 = ($98|0)==(0|0);
  if ($99) {
   label = 32;
  } else {
   $100 = (($98) + 36|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (($98) + 4|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($101|0)==($103|0);
   do {
    if ($104) {
     $105 = (($98) + 28|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = (($98) + 32|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = (($106) + ($108<<3)|0);
     $125 = $109;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$98,$15);
     $110 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $111 = ($110|0)==(-1);
     $112 = (($98) + 28|0);
     $113 = HEAP32[$112>>2]|0;
     if ($111) {
      $114 = (($98) + 32|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = (($113) + ($115<<3)|0);
      $125 = $116;
      break;
     } else {
      $117 = (($113) + ($110<<3)|0);
      $125 = $117;
      break;
     }
    }
   } while(0);
   $118 = HEAP32[560624>>2]|0;
   $119 = (($118) + 28|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = (($118) + 32|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = (($120) + ($122<<3)|0);
   $124 = ($125|0)==($123|0);
   if ($124) {
    label = 32;
   } else {
    $126 = (($125) + 4|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ($127|0)==(0|0);
    if ($128) {
     label = 32;
    } else {
     $temp$0$i25 = $127;
    }
   }
  }
  if ((label|0) == 32) {
   $129 = HEAP32[602008>>2]|0;
   $130 = (__Z31ReadObjectFromPersistentManageri($129)|0);
   $temp$0$i25 = $130;
  }
  $$0$i26 = $temp$0$i25;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($95,$$0$i26,0,105,0,126);
 $131 = (__Z12GetGfxDevicev()|0);
 $132 = (($131) + 3940|0);
 $133 = HEAP32[602016>>2]|0;
 $134 = ($133|0)==(0);
 if ($134) {
  $$0$i40 = 0;
 } else {
  HEAP32[$13>>2] = $133;
  $135 = HEAP32[560624>>2]|0;
  $136 = ($135|0)==(0|0);
  if ($136) {
   label = 43;
  } else {
   $137 = (($135) + 36|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = (($135) + 4|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ($138|0)==($140|0);
   do {
    if ($141) {
     $142 = (($135) + 28|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = (($135) + 32|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = (($143) + ($145<<3)|0);
     $162 = $146;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$135,$13);
     $147 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $148 = ($147|0)==(-1);
     $149 = (($135) + 28|0);
     $150 = HEAP32[$149>>2]|0;
     if ($148) {
      $151 = (($135) + 32|0);
      $152 = HEAP32[$151>>2]|0;
      $153 = (($150) + ($152<<3)|0);
      $162 = $153;
      break;
     } else {
      $154 = (($150) + ($147<<3)|0);
      $162 = $154;
      break;
     }
    }
   } while(0);
   $155 = HEAP32[560624>>2]|0;
   $156 = (($155) + 28|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($155) + 32|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($157) + ($159<<3)|0);
   $161 = ($162|0)==($160|0);
   if ($161) {
    label = 43;
   } else {
    $163 = (($162) + 4|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = ($164|0)==(0|0);
    if ($165) {
     label = 43;
    } else {
     $temp$0$i39 = $164;
    }
   }
  }
  if ((label|0) == 43) {
   $166 = HEAP32[602016>>2]|0;
   $167 = (__Z31ReadObjectFromPersistentManageri($166)|0);
   $temp$0$i39 = $167;
  }
  $$0$i40 = $temp$0$i39;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($132,$$0$i40,0,106,0,127);
 $168 = (__Z12GetGfxDevicev()|0);
 $169 = (($168) + 4004|0);
 $170 = HEAP32[602016>>2]|0;
 $171 = ($170|0)==(0);
 if ($171) {
  $$0$i47 = 0;
 } else {
  HEAP32[$12>>2] = $170;
  $172 = HEAP32[560624>>2]|0;
  $173 = ($172|0)==(0|0);
  if ($173) {
   label = 54;
  } else {
   $174 = (($172) + 36|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = (($172) + 4|0);
   $177 = HEAP32[$176>>2]|0;
   $178 = ($175|0)==($177|0);
   do {
    if ($178) {
     $179 = (($172) + 28|0);
     $180 = HEAP32[$179>>2]|0;
     $181 = (($172) + 32|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = (($180) + ($182<<3)|0);
     $199 = $183;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$172,$12);
     $184 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $185 = ($184|0)==(-1);
     $186 = (($172) + 28|0);
     $187 = HEAP32[$186>>2]|0;
     if ($185) {
      $188 = (($172) + 32|0);
      $189 = HEAP32[$188>>2]|0;
      $190 = (($187) + ($189<<3)|0);
      $199 = $190;
      break;
     } else {
      $191 = (($187) + ($184<<3)|0);
      $199 = $191;
      break;
     }
    }
   } while(0);
   $192 = HEAP32[560624>>2]|0;
   $193 = (($192) + 28|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = (($192) + 32|0);
   $196 = HEAP32[$195>>2]|0;
   $197 = (($194) + ($196<<3)|0);
   $198 = ($199|0)==($197|0);
   if ($198) {
    label = 54;
   } else {
    $200 = (($199) + 4|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = ($201|0)==(0|0);
    if ($202) {
     label = 54;
    } else {
     $temp$0$i46 = $201;
    }
   }
  }
  if ((label|0) == 54) {
   $203 = HEAP32[602016>>2]|0;
   $204 = (__Z31ReadObjectFromPersistentManageri($203)|0);
   $temp$0$i46 = $204;
  }
  $$0$i47 = $temp$0$i46;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($169,$$0$i47,0,107,0,128);
 $205 = (__Z12GetGfxDevicev()|0);
 $206 = (($205) + 4068|0);
 $207 = HEAP32[602024>>2]|0;
 $208 = ($207|0)==(0);
 if ($208) {
  $$0$i61 = 0;
 } else {
  HEAP32[$10>>2] = $207;
  $209 = HEAP32[560624>>2]|0;
  $210 = ($209|0)==(0|0);
  if ($210) {
   label = 65;
  } else {
   $211 = (($209) + 36|0);
   $212 = HEAP32[$211>>2]|0;
   $213 = (($209) + 4|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = ($212|0)==($214|0);
   do {
    if ($215) {
     $216 = (($209) + 28|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = (($209) + 32|0);
     $219 = HEAP32[$218>>2]|0;
     $220 = (($217) + ($219<<3)|0);
     $236 = $220;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$209,$10);
     $221 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $222 = ($221|0)==(-1);
     $223 = (($209) + 28|0);
     $224 = HEAP32[$223>>2]|0;
     if ($222) {
      $225 = (($209) + 32|0);
      $226 = HEAP32[$225>>2]|0;
      $227 = (($224) + ($226<<3)|0);
      $236 = $227;
      break;
     } else {
      $228 = (($224) + ($221<<3)|0);
      $236 = $228;
      break;
     }
    }
   } while(0);
   $229 = HEAP32[560624>>2]|0;
   $230 = (($229) + 28|0);
   $231 = HEAP32[$230>>2]|0;
   $232 = (($229) + 32|0);
   $233 = HEAP32[$232>>2]|0;
   $234 = (($231) + ($233<<3)|0);
   $235 = ($236|0)==($234|0);
   if ($235) {
    label = 65;
   } else {
    $237 = (($236) + 4|0);
    $238 = HEAP32[$237>>2]|0;
    $239 = ($238|0)==(0|0);
    if ($239) {
     label = 65;
    } else {
     $temp$0$i60 = $238;
    }
   }
  }
  if ((label|0) == 65) {
   $240 = HEAP32[602024>>2]|0;
   $241 = (__Z31ReadObjectFromPersistentManageri($240)|0);
   $temp$0$i60 = $241;
  }
  $$0$i61 = $temp$0$i60;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($206,$$0$i61,0,108,0,129);
 $242 = (__Z12GetGfxDevicev()|0);
 $243 = (($242) + 4132|0);
 $244 = HEAP32[602024>>2]|0;
 $245 = ($244|0)==(0);
 if ($245) {
  $$0$i68 = 0;
 } else {
  HEAP32[$9>>2] = $244;
  $246 = HEAP32[560624>>2]|0;
  $247 = ($246|0)==(0|0);
  if ($247) {
   label = 76;
  } else {
   $248 = (($246) + 36|0);
   $249 = HEAP32[$248>>2]|0;
   $250 = (($246) + 4|0);
   $251 = HEAP32[$250>>2]|0;
   $252 = ($249|0)==($251|0);
   do {
    if ($252) {
     $253 = (($246) + 28|0);
     $254 = HEAP32[$253>>2]|0;
     $255 = (($246) + 32|0);
     $256 = HEAP32[$255>>2]|0;
     $257 = (($254) + ($256<<3)|0);
     $273 = $257;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$246,$9);
     $258 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $259 = ($258|0)==(-1);
     $260 = (($246) + 28|0);
     $261 = HEAP32[$260>>2]|0;
     if ($259) {
      $262 = (($246) + 32|0);
      $263 = HEAP32[$262>>2]|0;
      $264 = (($261) + ($263<<3)|0);
      $273 = $264;
      break;
     } else {
      $265 = (($261) + ($258<<3)|0);
      $273 = $265;
      break;
     }
    }
   } while(0);
   $266 = HEAP32[560624>>2]|0;
   $267 = (($266) + 28|0);
   $268 = HEAP32[$267>>2]|0;
   $269 = (($266) + 32|0);
   $270 = HEAP32[$269>>2]|0;
   $271 = (($268) + ($270<<3)|0);
   $272 = ($273|0)==($271|0);
   if ($272) {
    label = 76;
   } else {
    $274 = (($273) + 4|0);
    $275 = HEAP32[$274>>2]|0;
    $276 = ($275|0)==(0|0);
    if ($276) {
     label = 76;
    } else {
     $temp$0$i67 = $275;
    }
   }
  }
  if ((label|0) == 76) {
   $277 = HEAP32[602024>>2]|0;
   $278 = (__Z31ReadObjectFromPersistentManageri($277)|0);
   $temp$0$i67 = $278;
  }
  $$0$i68 = $temp$0$i67;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($243,$$0$i68,0,109,0,130);
 $279 = (__Z12GetGfxDevicev()|0);
 $280 = (($279) + 4196|0);
 $281 = HEAP32[602000>>2]|0;
 $282 = ($281|0)==(0);
 if ($282) {
  $$0$i81 = 0;
 } else {
  HEAP32[$7>>2] = $281;
  $283 = HEAP32[560624>>2]|0;
  $284 = ($283|0)==(0|0);
  if ($284) {
   label = 87;
  } else {
   $285 = (($283) + 36|0);
   $286 = HEAP32[$285>>2]|0;
   $287 = (($283) + 4|0);
   $288 = HEAP32[$287>>2]|0;
   $289 = ($286|0)==($288|0);
   do {
    if ($289) {
     $290 = (($283) + 28|0);
     $291 = HEAP32[$290>>2]|0;
     $292 = (($283) + 32|0);
     $293 = HEAP32[$292>>2]|0;
     $294 = (($291) + ($293<<3)|0);
     $310 = $294;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$283,$7);
     $295 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $296 = ($295|0)==(-1);
     $297 = (($283) + 28|0);
     $298 = HEAP32[$297>>2]|0;
     if ($296) {
      $299 = (($283) + 32|0);
      $300 = HEAP32[$299>>2]|0;
      $301 = (($298) + ($300<<3)|0);
      $310 = $301;
      break;
     } else {
      $302 = (($298) + ($295<<3)|0);
      $310 = $302;
      break;
     }
    }
   } while(0);
   $303 = HEAP32[560624>>2]|0;
   $304 = (($303) + 28|0);
   $305 = HEAP32[$304>>2]|0;
   $306 = (($303) + 32|0);
   $307 = HEAP32[$306>>2]|0;
   $308 = (($305) + ($307<<3)|0);
   $309 = ($310|0)==($308|0);
   if ($309) {
    label = 87;
   } else {
    $311 = (($310) + 4|0);
    $312 = HEAP32[$311>>2]|0;
    $313 = ($312|0)==(0|0);
    if ($313) {
     label = 87;
    } else {
     $temp$0$i80 = $312;
    }
   }
  }
  if ((label|0) == 87) {
   $314 = HEAP32[602000>>2]|0;
   $315 = (__Z31ReadObjectFromPersistentManageri($314)|0);
   $temp$0$i80 = $315;
  }
  $$0$i81 = $temp$0$i80;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($280,$$0$i81,0,110,0,131);
 $316 = (__Z12GetGfxDevicev()|0);
 $317 = (($316) + 4260|0);
 $318 = HEAP32[601952>>2]|0;
 $319 = ($318|0)==(0);
 if ($319) {
  $$0$i88 = 0;
 } else {
  HEAP32[$6>>2] = $318;
  $320 = HEAP32[560624>>2]|0;
  $321 = ($320|0)==(0|0);
  if ($321) {
   label = 98;
  } else {
   $322 = (($320) + 36|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = (($320) + 4|0);
   $325 = HEAP32[$324>>2]|0;
   $326 = ($323|0)==($325|0);
   do {
    if ($326) {
     $327 = (($320) + 28|0);
     $328 = HEAP32[$327>>2]|0;
     $329 = (($320) + 32|0);
     $330 = HEAP32[$329>>2]|0;
     $331 = (($328) + ($330<<3)|0);
     $347 = $331;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$320,$6);
     $332 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $333 = ($332|0)==(-1);
     $334 = (($320) + 28|0);
     $335 = HEAP32[$334>>2]|0;
     if ($333) {
      $336 = (($320) + 32|0);
      $337 = HEAP32[$336>>2]|0;
      $338 = (($335) + ($337<<3)|0);
      $347 = $338;
      break;
     } else {
      $339 = (($335) + ($332<<3)|0);
      $347 = $339;
      break;
     }
    }
   } while(0);
   $340 = HEAP32[560624>>2]|0;
   $341 = (($340) + 28|0);
   $342 = HEAP32[$341>>2]|0;
   $343 = (($340) + 32|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = (($342) + ($344<<3)|0);
   $346 = ($347|0)==($345|0);
   if ($346) {
    label = 98;
   } else {
    $348 = (($347) + 4|0);
    $349 = HEAP32[$348>>2]|0;
    $350 = ($349|0)==(0|0);
    if ($350) {
     label = 98;
    } else {
     $temp$0$i87 = $349;
    }
   }
  }
  if ((label|0) == 98) {
   $351 = HEAP32[601952>>2]|0;
   $352 = (__Z31ReadObjectFromPersistentManageri($351)|0);
   $temp$0$i87 = $352;
  }
  $$0$i88 = $temp$0$i87;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($317,$$0$i88,0,111,0,132);
 $353 = (__Z12GetGfxDevicev()|0);
 $354 = (($353) + 4324|0);
 $355 = HEAP32[601944>>2]|0;
 $356 = ($355|0)==(0);
 if ($356) {
  $$0$i102 = 0;
 } else {
  HEAP32[$4>>2] = $355;
  $357 = HEAP32[560624>>2]|0;
  $358 = ($357|0)==(0|0);
  if ($358) {
   label = 109;
  } else {
   $359 = (($357) + 36|0);
   $360 = HEAP32[$359>>2]|0;
   $361 = (($357) + 4|0);
   $362 = HEAP32[$361>>2]|0;
   $363 = ($360|0)==($362|0);
   do {
    if ($363) {
     $364 = (($357) + 28|0);
     $365 = HEAP32[$364>>2]|0;
     $366 = (($357) + 32|0);
     $367 = HEAP32[$366>>2]|0;
     $368 = (($365) + ($367<<3)|0);
     $384 = $368;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$357,$4);
     $369 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $370 = ($369|0)==(-1);
     $371 = (($357) + 28|0);
     $372 = HEAP32[$371>>2]|0;
     if ($370) {
      $373 = (($357) + 32|0);
      $374 = HEAP32[$373>>2]|0;
      $375 = (($372) + ($374<<3)|0);
      $384 = $375;
      break;
     } else {
      $376 = (($372) + ($369<<3)|0);
      $384 = $376;
      break;
     }
    }
   } while(0);
   $377 = HEAP32[560624>>2]|0;
   $378 = (($377) + 28|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = (($377) + 32|0);
   $381 = HEAP32[$380>>2]|0;
   $382 = (($379) + ($381<<3)|0);
   $383 = ($384|0)==($382|0);
   if ($383) {
    label = 109;
   } else {
    $385 = (($384) + 4|0);
    $386 = HEAP32[$385>>2]|0;
    $387 = ($386|0)==(0|0);
    if ($387) {
     label = 109;
    } else {
     $temp$0$i101 = $386;
    }
   }
  }
  if ((label|0) == 109) {
   $388 = HEAP32[601944>>2]|0;
   $389 = (__Z31ReadObjectFromPersistentManageri($388)|0);
   $temp$0$i101 = $389;
  }
  $$0$i102 = $temp$0$i101;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($354,$$0$i102,0,112,0,133);
 $390 = (__Z12GetGfxDevicev()|0);
 $391 = (($390) + 4388|0);
 $392 = HEAP32[601944>>2]|0;
 $393 = ($392|0)==(0);
 if ($393) {
  $$0$i109 = 0;
 } else {
  HEAP32[$3>>2] = $392;
  $394 = HEAP32[560624>>2]|0;
  $395 = ($394|0)==(0|0);
  if ($395) {
   label = 120;
  } else {
   $396 = (($394) + 36|0);
   $397 = HEAP32[$396>>2]|0;
   $398 = (($394) + 4|0);
   $399 = HEAP32[$398>>2]|0;
   $400 = ($397|0)==($399|0);
   do {
    if ($400) {
     $401 = (($394) + 28|0);
     $402 = HEAP32[$401>>2]|0;
     $403 = (($394) + 32|0);
     $404 = HEAP32[$403>>2]|0;
     $405 = (($402) + ($404<<3)|0);
     $421 = $405;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$394,$3);
     $406 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $407 = ($406|0)==(-1);
     $408 = (($394) + 28|0);
     $409 = HEAP32[$408>>2]|0;
     if ($407) {
      $410 = (($394) + 32|0);
      $411 = HEAP32[$410>>2]|0;
      $412 = (($409) + ($411<<3)|0);
      $421 = $412;
      break;
     } else {
      $413 = (($409) + ($406<<3)|0);
      $421 = $413;
      break;
     }
    }
   } while(0);
   $414 = HEAP32[560624>>2]|0;
   $415 = (($414) + 28|0);
   $416 = HEAP32[$415>>2]|0;
   $417 = (($414) + 32|0);
   $418 = HEAP32[$417>>2]|0;
   $419 = (($416) + ($418<<3)|0);
   $420 = ($421|0)==($419|0);
   if ($420) {
    label = 120;
   } else {
    $422 = (($421) + 4|0);
    $423 = HEAP32[$422>>2]|0;
    $424 = ($423|0)==(0|0);
    if ($424) {
     label = 120;
    } else {
     $temp$0$i108 = $423;
    }
   }
  }
  if ((label|0) == 120) {
   $425 = HEAP32[601944>>2]|0;
   $426 = (__Z31ReadObjectFromPersistentManageri($425)|0);
   $temp$0$i108 = $426;
  }
  $$0$i109 = $temp$0$i108;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($391,$$0$i109,0,113,0,134);
 $427 = (__Z12GetGfxDevicev()|0);
 $428 = (($427) + 4452|0);
 $429 = HEAP32[601944>>2]|0;
 $430 = ($429|0)==(0);
 if ($430) {
  $$0$i123 = 0;
 } else {
  HEAP32[$1>>2] = $429;
  $431 = HEAP32[560624>>2]|0;
  $432 = ($431|0)==(0|0);
  if ($432) {
   label = 131;
  } else {
   $433 = (($431) + 36|0);
   $434 = HEAP32[$433>>2]|0;
   $435 = (($431) + 4|0);
   $436 = HEAP32[$435>>2]|0;
   $437 = ($434|0)==($436|0);
   do {
    if ($437) {
     $438 = (($431) + 28|0);
     $439 = HEAP32[$438>>2]|0;
     $440 = (($431) + 32|0);
     $441 = HEAP32[$440>>2]|0;
     $442 = (($439) + ($441<<3)|0);
     $458 = $442;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$431,$1);
     $443 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $444 = ($443|0)==(-1);
     $445 = (($431) + 28|0);
     $446 = HEAP32[$445>>2]|0;
     if ($444) {
      $447 = (($431) + 32|0);
      $448 = HEAP32[$447>>2]|0;
      $449 = (($446) + ($448<<3)|0);
      $458 = $449;
      break;
     } else {
      $450 = (($446) + ($443<<3)|0);
      $458 = $450;
      break;
     }
    }
   } while(0);
   $451 = HEAP32[560624>>2]|0;
   $452 = (($451) + 28|0);
   $453 = HEAP32[$452>>2]|0;
   $454 = (($451) + 32|0);
   $455 = HEAP32[$454>>2]|0;
   $456 = (($453) + ($455<<3)|0);
   $457 = ($458|0)==($456|0);
   if ($457) {
    label = 131;
   } else {
    $459 = (($458) + 4|0);
    $460 = HEAP32[$459>>2]|0;
    $461 = ($460|0)==(0|0);
    if ($461) {
     label = 131;
    } else {
     $temp$0$i122 = $460;
    }
   }
  }
  if ((label|0) == 131) {
   $462 = HEAP32[601944>>2]|0;
   $463 = (__Z31ReadObjectFromPersistentManageri($462)|0);
   $temp$0$i122 = $463;
  }
  $$0$i123 = $temp$0$i122;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($428,$$0$i123,0,114,0,135);
 $464 = (__Z12GetGfxDevicev()|0);
 $465 = (($464) + 4516|0);
 $466 = HEAP32[601944>>2]|0;
 $467 = ($466|0)==(0);
 if ($467) {
  $$0$i130 = 0;
 } else {
  HEAP32[$0>>2] = $466;
  $468 = HEAP32[560624>>2]|0;
  $469 = ($468|0)==(0|0);
  if ($469) {
   label = 142;
  } else {
   $470 = (($468) + 36|0);
   $471 = HEAP32[$470>>2]|0;
   $472 = (($468) + 4|0);
   $473 = HEAP32[$472>>2]|0;
   $474 = ($471|0)==($473|0);
   do {
    if ($474) {
     $475 = (($468) + 28|0);
     $476 = HEAP32[$475>>2]|0;
     $477 = (($468) + 32|0);
     $478 = HEAP32[$477>>2]|0;
     $479 = (($476) + ($478<<3)|0);
     $495 = $479;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$468,$0);
     $480 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $481 = ($480|0)==(-1);
     $482 = (($468) + 28|0);
     $483 = HEAP32[$482>>2]|0;
     if ($481) {
      $484 = (($468) + 32|0);
      $485 = HEAP32[$484>>2]|0;
      $486 = (($483) + ($485<<3)|0);
      $495 = $486;
      break;
     } else {
      $487 = (($483) + ($480<<3)|0);
      $495 = $487;
      break;
     }
    }
   } while(0);
   $488 = HEAP32[560624>>2]|0;
   $489 = (($488) + 28|0);
   $490 = HEAP32[$489>>2]|0;
   $491 = (($488) + 32|0);
   $492 = HEAP32[$491>>2]|0;
   $493 = (($490) + ($492<<3)|0);
   $494 = ($495|0)==($493|0);
   if ($494) {
    label = 142;
   } else {
    $496 = (($495) + 4|0);
    $497 = HEAP32[$496>>2]|0;
    $498 = ($497|0)==(0|0);
    if ($498) {
     label = 142;
    } else {
     $temp$0$i129 = $497;
    }
   }
  }
  if ((label|0) == 142) {
   $499 = HEAP32[601944>>2]|0;
   $500 = (__Z31ReadObjectFromPersistentManageri($499)|0);
   $temp$0$i129 = $500;
  }
  $$0$i130 = $temp$0$i129;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($465,$$0$i130,0,115,0,136);
 $501 = (__Z12GetGfxDevicev()|0);
 $502 = (($501) + 4580|0);
 $503 = HEAP32[601944>>2]|0;
 $504 = ($503|0)==(0);
 if ($504) {
  $$0$i116 = 0;
 } else {
  HEAP32[$2>>2] = $503;
  $505 = HEAP32[560624>>2]|0;
  $506 = ($505|0)==(0|0);
  if ($506) {
   label = 153;
  } else {
   $507 = (($505) + 36|0);
   $508 = HEAP32[$507>>2]|0;
   $509 = (($505) + 4|0);
   $510 = HEAP32[$509>>2]|0;
   $511 = ($508|0)==($510|0);
   do {
    if ($511) {
     $512 = (($505) + 28|0);
     $513 = HEAP32[$512>>2]|0;
     $514 = (($505) + 32|0);
     $515 = HEAP32[$514>>2]|0;
     $516 = (($513) + ($515<<3)|0);
     $532 = $516;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$505,$2);
     $517 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $518 = ($517|0)==(-1);
     $519 = (($505) + 28|0);
     $520 = HEAP32[$519>>2]|0;
     if ($518) {
      $521 = (($505) + 32|0);
      $522 = HEAP32[$521>>2]|0;
      $523 = (($520) + ($522<<3)|0);
      $532 = $523;
      break;
     } else {
      $524 = (($520) + ($517<<3)|0);
      $532 = $524;
      break;
     }
    }
   } while(0);
   $525 = HEAP32[560624>>2]|0;
   $526 = (($525) + 28|0);
   $527 = HEAP32[$526>>2]|0;
   $528 = (($525) + 32|0);
   $529 = HEAP32[$528>>2]|0;
   $530 = (($527) + ($529<<3)|0);
   $531 = ($532|0)==($530|0);
   if ($531) {
    label = 153;
   } else {
    $533 = (($532) + 4|0);
    $534 = HEAP32[$533>>2]|0;
    $535 = ($534|0)==(0|0);
    if ($535) {
     label = 153;
    } else {
     $temp$0$i115 = $534;
    }
   }
  }
  if ((label|0) == 153) {
   $536 = HEAP32[601944>>2]|0;
   $537 = (__Z31ReadObjectFromPersistentManageri($536)|0);
   $temp$0$i115 = $537;
  }
  $$0$i116 = $temp$0$i115;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($502,$$0$i116,0,116,0,137);
 $538 = (__Z12GetGfxDevicev()|0);
 $539 = (($538) + 4644|0);
 $540 = HEAP32[601944>>2]|0;
 $541 = ($540|0)==(0);
 if ($541) {
  $$0$i95 = 0;
 } else {
  HEAP32[$5>>2] = $540;
  $542 = HEAP32[560624>>2]|0;
  $543 = ($542|0)==(0|0);
  if ($543) {
   label = 164;
  } else {
   $544 = (($542) + 36|0);
   $545 = HEAP32[$544>>2]|0;
   $546 = (($542) + 4|0);
   $547 = HEAP32[$546>>2]|0;
   $548 = ($545|0)==($547|0);
   do {
    if ($548) {
     $549 = (($542) + 28|0);
     $550 = HEAP32[$549>>2]|0;
     $551 = (($542) + 32|0);
     $552 = HEAP32[$551>>2]|0;
     $553 = (($550) + ($552<<3)|0);
     $569 = $553;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$542,$5);
     $554 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $555 = ($554|0)==(-1);
     $556 = (($542) + 28|0);
     $557 = HEAP32[$556>>2]|0;
     if ($555) {
      $558 = (($542) + 32|0);
      $559 = HEAP32[$558>>2]|0;
      $560 = (($557) + ($559<<3)|0);
      $569 = $560;
      break;
     } else {
      $561 = (($557) + ($554<<3)|0);
      $569 = $561;
      break;
     }
    }
   } while(0);
   $562 = HEAP32[560624>>2]|0;
   $563 = (($562) + 28|0);
   $564 = HEAP32[$563>>2]|0;
   $565 = (($562) + 32|0);
   $566 = HEAP32[$565>>2]|0;
   $567 = (($564) + ($566<<3)|0);
   $568 = ($569|0)==($567|0);
   if ($568) {
    label = 164;
   } else {
    $570 = (($569) + 4|0);
    $571 = HEAP32[$570>>2]|0;
    $572 = ($571|0)==(0|0);
    if ($572) {
     label = 164;
    } else {
     $temp$0$i94 = $571;
    }
   }
  }
  if ((label|0) == 164) {
   $573 = HEAP32[601944>>2]|0;
   $574 = (__Z31ReadObjectFromPersistentManageri($573)|0);
   $temp$0$i94 = $574;
  }
  $$0$i95 = $temp$0$i94;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($539,$$0$i95,0,116,0,137);
 $575 = (__Z12GetGfxDevicev()|0);
 $576 = (($575) + 4708|0);
 $577 = HEAP32[601984>>2]|0;
 $578 = ($577|0)==(0);
 if ($578) {
  $$0$i75 = 0;
 } else {
  HEAP32[$8>>2] = $577;
  $579 = HEAP32[560624>>2]|0;
  $580 = ($579|0)==(0|0);
  do {
   if ($580) {
    label = 175;
   } else {
    $581 = (($579) + 36|0);
    $582 = HEAP32[$581>>2]|0;
    $583 = (($579) + 4|0);
    $584 = HEAP32[$583>>2]|0;
    $585 = ($582|0)==($584|0);
    do {
     if ($585) {
      $586 = (($579) + 28|0);
      $587 = HEAP32[$586>>2]|0;
      $588 = (($579) + 32|0);
      $589 = HEAP32[$588>>2]|0;
      $590 = (($587) + ($589<<3)|0);
      $606 = $590;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$579,$8);
      $591 = HEAP32[$pos$i$i$i$i125>>2]|0;
      $592 = ($591|0)==(-1);
      $593 = (($579) + 28|0);
      $594 = HEAP32[$593>>2]|0;
      if ($592) {
       $595 = (($579) + 32|0);
       $596 = HEAP32[$595>>2]|0;
       $597 = (($594) + ($596<<3)|0);
       $606 = $597;
       break;
      } else {
       $598 = (($594) + ($591<<3)|0);
       $606 = $598;
       break;
      }
     }
    } while(0);
    $599 = HEAP32[560624>>2]|0;
    $600 = (($599) + 28|0);
    $601 = HEAP32[$600>>2]|0;
    $602 = (($599) + 32|0);
    $603 = HEAP32[$602>>2]|0;
    $604 = (($601) + ($603<<3)|0);
    $605 = ($606|0)==($604|0);
    if ($605) {
     label = 175;
     break;
    }
    $607 = (($606) + 4|0);
    $608 = HEAP32[$607>>2]|0;
    $609 = ($608|0)==(0|0);
    if ($609) {
     label = 175;
    } else {
     $temp$0$i74 = $608;
    }
   }
  } while(0);
  if ((label|0) == 175) {
   $610 = HEAP32[601984>>2]|0;
   $611 = (__Z31ReadObjectFromPersistentManageri($610)|0);
   $temp$0$i74 = $611;
  }
  $$0$i75 = $temp$0$i74;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($576,$$0$i75,0,119,0,140);
 $612 = (__Z12GetGfxDevicev()|0);
 $613 = (($612) + 4772|0);
 $614 = HEAP32[601976>>2]|0;
 $615 = ($614|0)==(0);
 if ($615) {
  $$0$i54 = 0;
 } else {
  HEAP32[$11>>2] = $614;
  $616 = HEAP32[560624>>2]|0;
  $617 = ($616|0)==(0|0);
  do {
   if ($617) {
    label = 186;
   } else {
    $618 = (($616) + 36|0);
    $619 = HEAP32[$618>>2]|0;
    $620 = (($616) + 4|0);
    $621 = HEAP32[$620>>2]|0;
    $622 = ($619|0)==($621|0);
    do {
     if ($622) {
      $623 = (($616) + 28|0);
      $624 = HEAP32[$623>>2]|0;
      $625 = (($616) + 32|0);
      $626 = HEAP32[$625>>2]|0;
      $627 = (($624) + ($626<<3)|0);
      $643 = $627;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$616,$11);
      $628 = HEAP32[$pos$i$i$i$i125>>2]|0;
      $629 = ($628|0)==(-1);
      $630 = (($616) + 28|0);
      $631 = HEAP32[$630>>2]|0;
      if ($629) {
       $632 = (($616) + 32|0);
       $633 = HEAP32[$632>>2]|0;
       $634 = (($631) + ($633<<3)|0);
       $643 = $634;
       break;
      } else {
       $635 = (($631) + ($628<<3)|0);
       $643 = $635;
       break;
      }
     }
    } while(0);
    $636 = HEAP32[560624>>2]|0;
    $637 = (($636) + 28|0);
    $638 = HEAP32[$637>>2]|0;
    $639 = (($636) + 32|0);
    $640 = HEAP32[$639>>2]|0;
    $641 = (($638) + ($640<<3)|0);
    $642 = ($643|0)==($641|0);
    if ($642) {
     label = 186;
     break;
    }
    $644 = (($643) + 4|0);
    $645 = HEAP32[$644>>2]|0;
    $646 = ($645|0)==(0|0);
    if ($646) {
     label = 186;
    } else {
     $temp$0$i53 = $645;
    }
   }
  } while(0);
  if ((label|0) == 186) {
   $647 = HEAP32[601976>>2]|0;
   $648 = (__Z31ReadObjectFromPersistentManageri($647)|0);
   $temp$0$i53 = $648;
  }
  $$0$i54 = $temp$0$i53;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($613,$$0$i54,0,120,0,141);
 $649 = (__Z12GetGfxDevicev()|0);
 $650 = (($649) + 4836|0);
 $651 = HEAP32[601992>>2]|0;
 $652 = ($651|0)==(0);
 if ($652) {
  $$0$i33 = 0;
 } else {
  HEAP32[$14>>2] = $651;
  $653 = HEAP32[560624>>2]|0;
  $654 = ($653|0)==(0|0);
  do {
   if ($654) {
    label = 197;
   } else {
    $655 = (($653) + 36|0);
    $656 = HEAP32[$655>>2]|0;
    $657 = (($653) + 4|0);
    $658 = HEAP32[$657>>2]|0;
    $659 = ($656|0)==($658|0);
    do {
     if ($659) {
      $660 = (($653) + 28|0);
      $661 = HEAP32[$660>>2]|0;
      $662 = (($653) + 32|0);
      $663 = HEAP32[$662>>2]|0;
      $664 = (($661) + ($663<<3)|0);
      $680 = $664;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$653,$14);
      $665 = HEAP32[$pos$i$i$i$i125>>2]|0;
      $666 = ($665|0)==(-1);
      $667 = (($653) + 28|0);
      $668 = HEAP32[$667>>2]|0;
      if ($666) {
       $669 = (($653) + 32|0);
       $670 = HEAP32[$669>>2]|0;
       $671 = (($668) + ($670<<3)|0);
       $680 = $671;
       break;
      } else {
       $672 = (($668) + ($665<<3)|0);
       $680 = $672;
       break;
      }
     }
    } while(0);
    $673 = HEAP32[560624>>2]|0;
    $674 = (($673) + 28|0);
    $675 = HEAP32[$674>>2]|0;
    $676 = (($673) + 32|0);
    $677 = HEAP32[$676>>2]|0;
    $678 = (($675) + ($677<<3)|0);
    $679 = ($680|0)==($678|0);
    if ($679) {
     label = 197;
     break;
    }
    $681 = (($680) + 4|0);
    $682 = HEAP32[$681>>2]|0;
    $683 = ($682|0)==(0|0);
    if ($683) {
     label = 197;
    } else {
     $temp$0$i32 = $682;
    }
   }
  } while(0);
  if ((label|0) == 197) {
   $684 = HEAP32[601992>>2]|0;
   $685 = (__Z31ReadObjectFromPersistentManageri($684)|0);
   $temp$0$i32 = $685;
  }
  $$0$i33 = $temp$0$i32;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($650,$$0$i33,0,121,0,142);
 $686 = (__Z12GetGfxDevicev()|0);
 $687 = (($686) + 4900|0);
 $688 = HEAP32[602032>>2]|0;
 $689 = ($688|0)==(0);
 if ($689) {
  $$0$i12 = 0;
 } else {
  HEAP32[$17>>2] = $688;
  $690 = HEAP32[560624>>2]|0;
  $691 = ($690|0)==(0|0);
  do {
   if ($691) {
    label = 208;
   } else {
    $692 = (($690) + 36|0);
    $693 = HEAP32[$692>>2]|0;
    $694 = (($690) + 4|0);
    $695 = HEAP32[$694>>2]|0;
    $696 = ($693|0)==($695|0);
    do {
     if ($696) {
      $697 = (($690) + 28|0);
      $698 = HEAP32[$697>>2]|0;
      $699 = (($690) + 32|0);
      $700 = HEAP32[$699>>2]|0;
      $701 = (($698) + ($700<<3)|0);
      $717 = $701;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$690,$17);
      $702 = HEAP32[$pos$i$i$i$i125>>2]|0;
      $703 = ($702|0)==(-1);
      $704 = (($690) + 28|0);
      $705 = HEAP32[$704>>2]|0;
      if ($703) {
       $706 = (($690) + 32|0);
       $707 = HEAP32[$706>>2]|0;
       $708 = (($705) + ($707<<3)|0);
       $717 = $708;
       break;
      } else {
       $709 = (($705) + ($702<<3)|0);
       $717 = $709;
       break;
      }
     }
    } while(0);
    $710 = HEAP32[560624>>2]|0;
    $711 = (($710) + 28|0);
    $712 = HEAP32[$711>>2]|0;
    $713 = (($710) + 32|0);
    $714 = HEAP32[$713>>2]|0;
    $715 = (($712) + ($714<<3)|0);
    $716 = ($717|0)==($715|0);
    if ($716) {
     label = 208;
     break;
    }
    $718 = (($717) + 4|0);
    $719 = HEAP32[$718>>2]|0;
    $720 = ($719|0)==(0|0);
    if ($720) {
     label = 208;
    } else {
     $temp$0$i11 = $719;
    }
   }
  } while(0);
  if ((label|0) == 208) {
   $721 = HEAP32[602032>>2]|0;
   $722 = (__Z31ReadObjectFromPersistentManageri($721)|0);
   $temp$0$i11 = $722;
  }
  $$0$i12 = $temp$0$i11;
 }
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($687,$$0$i12,0,122,0,143);
 $723 = (__Z12GetGfxDevicev()|0);
 $724 = (($723) + 4964|0);
 $725 = HEAP32[601952>>2]|0;
 $726 = ($725|0)==(0);
 if ($726) {
  $$0$i = 0;
  __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($724,$$0$i,0,123,0,144);
  STACKTOP = sp;return;
 }
 HEAP32[$19>>2] = $725;
 $727 = HEAP32[560624>>2]|0;
 $728 = ($727|0)==(0|0);
 do {
  if ($728) {
   label = 219;
  } else {
   $729 = (($727) + 36|0);
   $730 = HEAP32[$729>>2]|0;
   $731 = (($727) + 4|0);
   $732 = HEAP32[$731>>2]|0;
   $733 = ($730|0)==($732|0);
   do {
    if ($733) {
     $734 = (($727) + 28|0);
     $735 = HEAP32[$734>>2]|0;
     $736 = (($727) + 32|0);
     $737 = HEAP32[$736>>2]|0;
     $738 = (($735) + ($737<<3)|0);
     $754 = $738;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i125,$727,$19);
     $739 = HEAP32[$pos$i$i$i$i125>>2]|0;
     $740 = ($739|0)==(-1);
     $741 = (($727) + 28|0);
     $742 = HEAP32[$741>>2]|0;
     if ($740) {
      $743 = (($727) + 32|0);
      $744 = HEAP32[$743>>2]|0;
      $745 = (($742) + ($744<<3)|0);
      $754 = $745;
      break;
     } else {
      $746 = (($742) + ($739<<3)|0);
      $754 = $746;
      break;
     }
    }
   } while(0);
   $747 = HEAP32[560624>>2]|0;
   $748 = (($747) + 28|0);
   $749 = HEAP32[$748>>2]|0;
   $750 = (($747) + 32|0);
   $751 = HEAP32[$750>>2]|0;
   $752 = (($749) + ($751<<3)|0);
   $753 = ($754|0)==($752|0);
   if ($753) {
    label = 219;
    break;
   }
   $755 = (($754) + 4|0);
   $756 = HEAP32[$755>>2]|0;
   $757 = ($756|0)==(0|0);
   if ($757) {
    label = 219;
   } else {
    $temp$0$i = $756;
   }
  }
 } while(0);
 if ((label|0) == 219) {
  $758 = HEAP32[601952>>2]|0;
  $759 = (__Z31ReadObjectFromPersistentManageri($758)|0);
  $temp$0$i = $759;
 }
 $$0$i = $temp$0$i;
 __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($724,$$0$i,0,123,0,144);
 STACKTOP = sp;return;
}
function __ZN10builtintex23GenerateBuiltinTexturesEv() {
 var $$pre = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $pos$i$i$i$i50 = 0, $storemerge = 0, $storemerge56 = 0, $storemerge57 = 0, $storemerge58 = 0, $storemerge59 = 0, $storemerge60 = 0, $storemerge61 = 0, $storemerge62 = 0, $storemerge63 = 0, $temp$0$i = 0, $temp$0$i11 = 0;
 var $temp$0$i20 = 0, $temp$0$i26 = 0, $temp$0$i33 = 0, $temp$0$i39 = 0, $temp$0$i48 = 0, $temp$0$i54 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $pos$i$i$i$i50 = sp + 96|0;
 $0 = sp + 92|0;
 $1 = sp + 88|0;
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 72|0;
 $6 = sp + 68|0;
 $7 = sp + 64|0;
 $8 = sp + 60|0;
 $9 = sp + 56|0;
 $10 = sp + 52|0;
 $11 = sp + 48|0;
 $12 = sp + 16|0;
 $13 = sp;
 $14 = sp + 4|0;
 $15 = sp + 8|0;
 $16 = sp + 12|0;
 $17 = sp + 20|0;
 $18 = sp + 24|0;
 $19 = sp + 28|0;
 $20 = sp + 32|0;
 $21 = sp + 36|0;
 $22 = sp + 40|0;
 $23 = sp + 44|0;
 $24 = HEAP8[602112>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 HEAP8[602112>>0] = 1;
 HEAP32[$8>>2] = 111;
 $26 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602120,4,4,4,$8,0)|0);
 $27 = ($26|0)==(0|0);
 if ($27) {
  $storemerge = 0;
 } else {
  $28 = (($26) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $storemerge = $29;
 }
 HEAP32[602000>>2] = $storemerge;
 HEAP32[$9>>2] = 112;
 $30 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602136,4,4,4,$9,0)|0);
 $31 = ($30|0)==(0|0);
 if ($31) {
  $storemerge56 = 0;
 } else {
  $32 = (($30) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $storemerge56 = $33;
 }
 HEAP32[601936>>2] = $storemerge56;
 HEAP32[$10>>2] = 113;
 $34 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602152,4,4,4,$10,0)|0);
 $35 = ($34|0)==(0|0);
 if ($35) {
  $storemerge57 = 0;
 } else {
  $36 = (($34) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $storemerge57 = $37;
 }
 HEAP32[601944>>2] = $storemerge57;
 HEAP32[$11>>2] = 114;
 $38 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602168,16,16,4,$11,0)|0);
 $39 = ($38|0)==(0|0);
 if ($39) {
  $storemerge58 = 0;
 } else {
  $40 = (($38) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $storemerge58 = $41;
 }
 HEAP32[601992>>2] = $storemerge58;
 HEAP32[$12>>2] = 115;
 $42 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602192,4,4,4,$12,1)|0);
 $43 = ($42|0)==(0|0);
 if ($43) {
  $storemerge59 = 0;
 } else {
  $44 = (($42) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $storemerge59 = $45;
 }
 HEAP32[602008>>2] = $storemerge59;
 HEAP32[$13>>2] = 116;
 $46 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602208,4,4,4,$13,0)|0);
 $47 = ($46|0)==(0|0);
 if ($47) {
  $storemerge60 = 0;
 } else {
  $48 = (($46) + 4|0);
  $49 = HEAP32[$48>>2]|0;
  $storemerge60 = $49;
 }
 HEAP32[602016>>2] = $storemerge60;
 HEAP32[$14>>2] = 117;
 $50 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602224,256,2,4,$14,0)|0);
 $51 = ($50|0)==(0|0);
 if ($51) {
  $storemerge61 = 0;
 } else {
  $52 = (($50) + 4|0);
  $53 = HEAP32[$52>>2]|0;
  $storemerge61 = $53;
 }
 HEAP32[602024>>2] = $storemerge61;
 HEAP32[$5>>2] = $storemerge61;
 $54 = HEAP32[560624>>2]|0;
 $55 = ($54|0)==(0|0);
 if ($55) {
  label = 24;
 } else {
  $56 = (($54) + 36|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($54) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ($57|0)==($59|0);
  do {
   if ($60) {
    $61 = (($54) + 28|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($54) + 32|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($62) + ($64<<3)|0);
    $81 = $65;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i50,$54,$5);
    $66 = HEAP32[$pos$i$i$i$i50>>2]|0;
    $67 = ($66|0)==(-1);
    $68 = (($54) + 28|0);
    $69 = HEAP32[$68>>2]|0;
    if ($67) {
     $70 = (($54) + 32|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = (($69) + ($71<<3)|0);
     $81 = $72;
     break;
    } else {
     $73 = (($69) + ($66<<3)|0);
     $81 = $73;
     break;
    }
   }
  } while(0);
  $74 = HEAP32[560624>>2]|0;
  $75 = (($74) + 28|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = (($74) + 32|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($76) + ($78<<3)|0);
  $80 = ($81|0)==($79|0);
  if ($80) {
   label = 24;
  } else {
   $82 = (($81) + 4|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==(0|0);
   if ($84) {
    label = 24;
   } else {
    $91 = $74;$temp$0$i20 = $83;
   }
  }
 }
 if ((label|0) == 24) {
  $85 = HEAP32[602024>>2]|0;
  $86 = (__Z31ReadObjectFromPersistentManageri($85)|0);
  $$pre = HEAP32[560624>>2]|0;
  $91 = $$pre;$temp$0$i20 = $86;
 }
 $87 = (($temp$0$i20) + 28|0);
 $88 = (($87) + 12|0);
 HEAP32[$88>>2] = 1;
 $89 = HEAP32[602024>>2]|0;
 HEAP32[$4>>2] = $89;
 $90 = ($91|0)==(0|0);
 if ($90) {
  label = 33;
 } else {
  $92 = (($91) + 36|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (($91) + 4|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ($93|0)==($95|0);
  do {
   if ($96) {
    $97 = (($91) + 28|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (($91) + 32|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($98) + ($100<<3)|0);
    $117 = $101;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i50,$91,$4);
    $102 = HEAP32[$pos$i$i$i$i50>>2]|0;
    $103 = ($102|0)==(-1);
    $104 = (($91) + 28|0);
    $105 = HEAP32[$104>>2]|0;
    if ($103) {
     $106 = (($91) + 32|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = (($105) + ($107<<3)|0);
     $117 = $108;
     break;
    } else {
     $109 = (($105) + ($102<<3)|0);
     $117 = $109;
     break;
    }
   }
  } while(0);
  $110 = HEAP32[560624>>2]|0;
  $111 = (($110) + 28|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = (($110) + 32|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (($112) + ($114<<3)|0);
  $116 = ($117|0)==($115|0);
  if ($116) {
   label = 33;
  } else {
   $118 = (($117) + 4|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = ($119|0)==(0|0);
   if ($120) {
    label = 33;
   } else {
    $temp$0$i26 = $119;
   }
  }
 }
 if ((label|0) == 33) {
  $121 = HEAP32[602024>>2]|0;
  $122 = (__Z31ReadObjectFromPersistentManageri($121)|0);
  $temp$0$i26 = $122;
 }
 $123 = HEAP32[$temp$0$i26>>2]|0;
 $124 = (($123) + 132|0);
 $125 = HEAP32[$124>>2]|0;
 FUNCTION_TABLE_vi[$125 & 4095]($temp$0$i26);
 HEAP32[$15>>2] = 118;
 $126 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602248,64,64,1,$15,0)|0);
 $127 = ($126|0)==(0|0);
 if ($127) {
  $storemerge62 = 0;
 } else {
  $128 = (($126) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $storemerge62 = $129;
 }
 HEAP32[601968>>2] = $storemerge62;
 HEAP32[$3>>2] = $storemerge62;
 $130 = HEAP32[560624>>2]|0;
 $131 = ($130|0)==(0|0);
 if ($131) {
  label = 44;
 } else {
  $132 = (($130) + 36|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = (($130) + 4|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ($133|0)==($135|0);
  do {
   if ($136) {
    $137 = (($130) + 28|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = (($130) + 32|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = (($138) + ($140<<3)|0);
    $157 = $141;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i50,$130,$3);
    $142 = HEAP32[$pos$i$i$i$i50>>2]|0;
    $143 = ($142|0)==(-1);
    $144 = (($130) + 28|0);
    $145 = HEAP32[$144>>2]|0;
    if ($143) {
     $146 = (($130) + 32|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = (($145) + ($147<<3)|0);
     $157 = $148;
     break;
    } else {
     $149 = (($145) + ($142<<3)|0);
     $157 = $149;
     break;
    }
   }
  } while(0);
  $150 = HEAP32[560624>>2]|0;
  $151 = (($150) + 28|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = (($150) + 32|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = (($152) + ($154<<3)|0);
  $156 = ($157|0)==($155|0);
  if ($156) {
   label = 44;
  } else {
   $158 = (($157) + 4|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = ($159|0)==(0|0);
   if ($160) {
    label = 44;
   } else {
    $167 = $150;$temp$0$i33 = $159;
   }
  }
 }
 if ((label|0) == 44) {
  $161 = HEAP32[601968>>2]|0;
  $162 = (__Z31ReadObjectFromPersistentManageri($161)|0);
  $$pre64 = HEAP32[560624>>2]|0;
  $167 = $$pre64;$temp$0$i33 = $162;
 }
 $163 = (($temp$0$i33) + 28|0);
 $164 = (($163) + 12|0);
 HEAP32[$164>>2] = 1;
 $165 = HEAP32[601968>>2]|0;
 HEAP32[$2>>2] = $165;
 $166 = ($167|0)==(0|0);
 if ($166) {
  label = 53;
 } else {
  $168 = (($167) + 36|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = (($167) + 4|0);
  $171 = HEAP32[$170>>2]|0;
  $172 = ($169|0)==($171|0);
  do {
   if ($172) {
    $173 = (($167) + 28|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = (($167) + 32|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = (($174) + ($176<<3)|0);
    $193 = $177;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i50,$167,$2);
    $178 = HEAP32[$pos$i$i$i$i50>>2]|0;
    $179 = ($178|0)==(-1);
    $180 = (($167) + 28|0);
    $181 = HEAP32[$180>>2]|0;
    if ($179) {
     $182 = (($167) + 32|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = (($181) + ($183<<3)|0);
     $193 = $184;
     break;
    } else {
     $185 = (($181) + ($178<<3)|0);
     $193 = $185;
     break;
    }
   }
  } while(0);
  $186 = HEAP32[560624>>2]|0;
  $187 = (($186) + 28|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = (($186) + 32|0);
  $190 = HEAP32[$189>>2]|0;
  $191 = (($188) + ($190<<3)|0);
  $192 = ($193|0)==($191|0);
  if ($192) {
   label = 53;
  } else {
   $194 = (($193) + 4|0);
   $195 = HEAP32[$194>>2]|0;
   $196 = ($195|0)==(0|0);
   if ($196) {
    label = 53;
   } else {
    $temp$0$i39 = $195;
   }
  }
 }
 if ((label|0) == 53) {
  $197 = HEAP32[601968>>2]|0;
  $198 = (__Z31ReadObjectFromPersistentManageri($197)|0);
  $temp$0$i39 = $198;
 }
 $199 = HEAP32[$temp$0$i39>>2]|0;
 $200 = (($199) + 132|0);
 $201 = HEAP32[$200>>2]|0;
 FUNCTION_TABLE_vi[$201 & 4095]($temp$0$i39);
 $202 = HEAP8[((640792 + 150|0))>>0]|0;
 $203 = ($202<<24>>24)==(0);
 do {
  if ($203) {
   HEAP32[$17>>2] = 120;
   $208 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602264,1024,1,1,$17,0)|0);
   $209 = ($208|0)==(0|0);
   if ($209) {
    HEAP32[601960>>2] = 0;
    $212 = 0;
    break;
   } else {
    $210 = (($208) + 4|0);
    $211 = HEAP32[$210>>2]|0;
    HEAP32[601960>>2] = $211;
    $212 = $211;
    break;
   }
  } else {
   HEAP32[$16>>2] = 119;
   $204 = (__Z12BuildTextureItPFvP9Texture2DPtiiiiEES1_PKcii13TextureFormatRKT0_b(602264,1024,1,9,$16,0)|0);
   $205 = ($204|0)==(0|0);
   if ($205) {
    HEAP32[601960>>2] = 0;
    $212 = 0;
    break;
   } else {
    $206 = (($204) + 4|0);
    $207 = HEAP32[$206>>2]|0;
    HEAP32[601960>>2] = $207;
    $212 = $207;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = $212;
 $213 = HEAP32[560624>>2]|0;
 $214 = ($213|0)==(0|0);
 if ($214) {
  label = 69;
 } else {
  $215 = (($213) + 36|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = (($213) + 4|0);
  $218 = HEAP32[$217>>2]|0;
  $219 = ($216|0)==($218|0);
  do {
   if ($219) {
    $220 = (($213) + 28|0);
    $221 = HEAP32[$220>>2]|0;
    $222 = (($213) + 32|0);
    $223 = HEAP32[$222>>2]|0;
    $224 = (($221) + ($223<<3)|0);
    $240 = $224;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i50,$213,$1);
    $225 = HEAP32[$pos$i$i$i$i50>>2]|0;
    $226 = ($225|0)==(-1);
    $227 = (($213) + 28|0);
    $228 = HEAP32[$227>>2]|0;
    if ($226) {
     $229 = (($213) + 32|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = (($228) + ($230<<3)|0);
     $240 = $231;
     break;
    } else {
     $232 = (($228) + ($225<<3)|0);
     $240 = $232;
     break;
    }
   }
  } while(0);
  $233 = HEAP32[560624>>2]|0;
  $234 = (($233) + 28|0);
  $235 = HEAP32[$234>>2]|0;
  $236 = (($233) + 32|0);
  $237 = HEAP32[$236>>2]|0;
  $238 = (($235) + ($237<<3)|0);
  $239 = ($240|0)==($238|0);
  if ($239) {
   label = 69;
  } else {
   $241 = (($240) + 4|0);
   $242 = HEAP32[$241>>2]|0;
   $243 = ($242|0)==(0|0);
   if ($243) {
    label = 69;
   } else {
    $250 = $233;$temp$0$i48 = $242;
   }
  }
 }
 if ((label|0) == 69) {
  $244 = HEAP32[601960>>2]|0;
  $245 = (__Z31ReadObjectFromPersistentManageri($244)|0);
  $$pre65 = HEAP32[560624>>2]|0;
  $250 = $$pre65;$temp$0$i48 = $245;
 }
 $246 = (($temp$0$i48) + 28|0);
 $247 = (($246) + 12|0);
 HEAP32[$247>>2] = 1;
 $248 = HEAP32[601960>>2]|0;
 HEAP32[$0>>2] = $248;
 $249 = ($250|0)==(0|0);
 if ($249) {
  label = 78;
 } else {
  $251 = (($250) + 36|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = (($250) + 4|0);
  $254 = HEAP32[$253>>2]|0;
  $255 = ($252|0)==($254|0);
  do {
   if ($255) {
    $256 = (($250) + 28|0);
    $257 = HEAP32[$256>>2]|0;
    $258 = (($250) + 32|0);
    $259 = HEAP32[$258>>2]|0;
    $260 = (($257) + ($259<<3)|0);
    $276 = $260;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i50,$250,$0);
    $261 = HEAP32[$pos$i$i$i$i50>>2]|0;
    $262 = ($261|0)==(-1);
    $263 = (($250) + 28|0);
    $264 = HEAP32[$263>>2]|0;
    if ($262) {
     $265 = (($250) + 32|0);
     $266 = HEAP32[$265>>2]|0;
     $267 = (($264) + ($266<<3)|0);
     $276 = $267;
     break;
    } else {
     $268 = (($264) + ($261<<3)|0);
     $276 = $268;
     break;
    }
   }
  } while(0);
  $269 = HEAP32[560624>>2]|0;
  $270 = (($269) + 28|0);
  $271 = HEAP32[$270>>2]|0;
  $272 = (($269) + 32|0);
  $273 = HEAP32[$272>>2]|0;
  $274 = (($271) + ($273<<3)|0);
  $275 = ($276|0)==($274|0);
  if ($275) {
   label = 78;
  } else {
   $277 = (($276) + 4|0);
   $278 = HEAP32[$277>>2]|0;
   $279 = ($278|0)==(0|0);
   if ($279) {
    label = 78;
   } else {
    $temp$0$i54 = $278;
   }
  }
 }
 if ((label|0) == 78) {
  $280 = HEAP32[601960>>2]|0;
  $281 = (__Z31ReadObjectFromPersistentManageri($280)|0);
  $temp$0$i54 = $281;
 }
 $282 = HEAP32[$temp$0$i54>>2]|0;
 $283 = (($282) + 132|0);
 $284 = HEAP32[$283>>2]|0;
 FUNCTION_TABLE_vi[$284 & 4095]($temp$0$i54);
 HEAP32[$18>>2] = 2708;
 $285 = (__Z16BuildCubeTextureIhPFvPh8Vector3fEEP7CubemapPKci13TextureFormatRKT0_(602288,1,4,$18)|0);
 $286 = ($285|0)==(0|0);
 if ($286) {
  $storemerge63 = 0;
 } else {
  $287 = (($285) + 4|0);
  $288 = HEAP32[$287>>2]|0;
  $storemerge63 = $288;
 }
 HEAP32[601952>>2] = $storemerge63;
 HEAP32[$19>>2] = 121;
 $289 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602304,16,16,4,$19,0)|0);
 $290 = (($289) + 44|0);
 $291 = HEAP32[$290>>2]|0;
 HEAP32[((602040 + 8|0))>>2] = $291;
 $292 = HEAP8[((640792 + 225|0))>>0]|0;
 $293 = ($292<<24>>24)==(0);
 if (!($293)) {
  HEAP32[$20>>2] = 67;
  $294 = (__Z14Build3DTextureIhPFvPhiiiiiiEEP9Texture3DPKciii13TextureFormatRKT0_(602320,1,1,1,4,$20)|0);
  $295 = (($294) + 44|0);
  $296 = HEAP32[$295>>2]|0;
  HEAP32[((602040 + 12|0))>>2] = $296;
 }
 HEAP32[$21>>2] = 2709;
 $297 = (__Z16BuildCubeTextureIhPFvPh8Vector3fEEP7CubemapPKci13TextureFormatRKT0_(602336,1,4,$21)|0);
 $298 = (($297) + 44|0);
 $299 = HEAP32[$298>>2]|0;
 HEAP32[((602040 + 16|0))>>2] = $299;
 __Z22GenerateDitherTexturesv();
 $300 = HEAP8[((640792 + 150|0))>>0]|0;
 $301 = ($300<<24>>24)==(0);
 do {
  if ($301) {
   HEAP32[$23>>2] = 123;
   $306 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(602360,256,64,1,$23,0)|0);
   $307 = ($306|0)==(0|0);
   if ($307) {
    HEAP32[602032>>2] = 0;
    $310 = 0;
    break;
   } else {
    $308 = (($306) + 4|0);
    $309 = HEAP32[$308>>2]|0;
    HEAP32[602032>>2] = $309;
    $310 = $309;
    break;
   }
  } else {
   HEAP32[$22>>2] = 122;
   $302 = (__Z12BuildTextureItPFvP9Texture2DPtiiiiEES1_PKcii13TextureFormatRKT0_b(602360,256,64,9,$22,0)|0);
   $303 = ($302|0)==(0|0);
   if ($303) {
    HEAP32[602032>>2] = 0;
    $310 = 0;
    break;
   } else {
    $304 = (($302) + 4|0);
    $305 = HEAP32[$304>>2]|0;
    HEAP32[602032>>2] = $305;
    $310 = $305;
    break;
   }
  }
 } while(0);
 HEAP32[$6>>2] = $310;
 $311 = HEAP32[560624>>2]|0;
 $312 = ($311|0)==(0|0);
 do {
  if ($312) {
   label = 98;
  } else {
   $313 = (($311) + 36|0);
   $314 = HEAP32[$313>>2]|0;
   $315 = (($311) + 4|0);
   $316 = HEAP32[$315>>2]|0;
   $317 = ($314|0)==($316|0);
   do {
    if ($317) {
     $318 = (($311) + 28|0);
     $319 = HEAP32[$318>>2]|0;
     $320 = (($311) + 32|0);
     $321 = HEAP32[$320>>2]|0;
     $322 = (($319) + ($321<<3)|0);
     $338 = $322;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i50,$311,$6);
     $323 = HEAP32[$pos$i$i$i$i50>>2]|0;
     $324 = ($323|0)==(-1);
     $325 = (($311) + 28|0);
     $326 = HEAP32[$325>>2]|0;
     if ($324) {
      $327 = (($311) + 32|0);
      $328 = HEAP32[$327>>2]|0;
      $329 = (($326) + ($328<<3)|0);
      $338 = $329;
      break;
     } else {
      $330 = (($326) + ($323<<3)|0);
      $338 = $330;
      break;
     }
    }
   } while(0);
   $331 = HEAP32[560624>>2]|0;
   $332 = (($331) + 28|0);
   $333 = HEAP32[$332>>2]|0;
   $334 = (($331) + 32|0);
   $335 = HEAP32[$334>>2]|0;
   $336 = (($333) + ($335<<3)|0);
   $337 = ($338|0)==($336|0);
   if ($337) {
    label = 98;
    break;
   }
   $339 = (($338) + 4|0);
   $340 = HEAP32[$339>>2]|0;
   $341 = ($340|0)==(0|0);
   if ($341) {
    label = 98;
   } else {
    $348 = $331;$temp$0$i11 = $340;
   }
  }
 } while(0);
 if ((label|0) == 98) {
  $342 = HEAP32[602032>>2]|0;
  $343 = (__Z31ReadObjectFromPersistentManageri($342)|0);
  $$pre66 = HEAP32[560624>>2]|0;
  $348 = $$pre66;$temp$0$i11 = $343;
 }
 $344 = (($temp$0$i11) + 28|0);
 $345 = (($344) + 12|0);
 HEAP32[$345>>2] = 1;
 $346 = HEAP32[602032>>2]|0;
 HEAP32[$7>>2] = $346;
 $347 = ($348|0)==(0|0);
 do {
  if ($347) {
   label = 107;
  } else {
   $349 = (($348) + 36|0);
   $350 = HEAP32[$349>>2]|0;
   $351 = (($348) + 4|0);
   $352 = HEAP32[$351>>2]|0;
   $353 = ($350|0)==($352|0);
   do {
    if ($353) {
     $354 = (($348) + 28|0);
     $355 = HEAP32[$354>>2]|0;
     $356 = (($348) + 32|0);
     $357 = HEAP32[$356>>2]|0;
     $358 = (($355) + ($357<<3)|0);
     $374 = $358;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i50,$348,$7);
     $359 = HEAP32[$pos$i$i$i$i50>>2]|0;
     $360 = ($359|0)==(-1);
     $361 = (($348) + 28|0);
     $362 = HEAP32[$361>>2]|0;
     if ($360) {
      $363 = (($348) + 32|0);
      $364 = HEAP32[$363>>2]|0;
      $365 = (($362) + ($364<<3)|0);
      $374 = $365;
      break;
     } else {
      $366 = (($362) + ($359<<3)|0);
      $374 = $366;
      break;
     }
    }
   } while(0);
   $367 = HEAP32[560624>>2]|0;
   $368 = (($367) + 28|0);
   $369 = HEAP32[$368>>2]|0;
   $370 = (($367) + 32|0);
   $371 = HEAP32[$370>>2]|0;
   $372 = (($369) + ($371<<3)|0);
   $373 = ($374|0)==($372|0);
   if ($373) {
    label = 107;
    break;
   }
   $375 = (($374) + 4|0);
   $376 = HEAP32[$375>>2]|0;
   $377 = ($376|0)==(0|0);
   if ($377) {
    label = 107;
   } else {
    $temp$0$i = $376;
   }
  }
 } while(0);
 if ((label|0) == 107) {
  $378 = HEAP32[602032>>2]|0;
  $379 = (__Z31ReadObjectFromPersistentManageri($378)|0);
  $temp$0$i = $379;
 }
 $380 = HEAP32[$temp$0$i>>2]|0;
 $381 = (($380) + 132|0);
 $382 = HEAP32[$381>>2]|0;
 FUNCTION_TABLE_vi[$382 & 4095]($temp$0$i);
 $383 = HEAP32[((602040 + 8|0))>>2]|0;
 HEAP32[((602040 + 20|0))>>2] = $383;
 __ZN10builtintex21ReinitBuiltinTexturesEv();
 STACKTOP = sp;return;
}
function __Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b($name,$width,$height,$format,$fun,$mipmaps) {
 $name = $name|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $fun = $fun|0;
 $mipmaps = $mipmaps|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $data$03$us$i = 0, $data$11$us$i = 0, $exitcond$i = 0, $exitcond6$i = 0, $or$cond$i = 0, $scevgep$i = 0, $x$02$us$i = 0, $y$04$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy2,1,16,602528,1111)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1733,($3|0),($$byval_copy2|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(602528|0),1111);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch(0|0)|0;
   $11 = tempRet0;
   ___clang_call_terminate($10);
   // unreachable;
  } else {
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $12 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 4095]($12);
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($12,4);
 $19 = HEAP32[$12>>2]|0;
 $20 = (($19) + 44|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vii[$21 & 4095]($12,61);
 $22 = HEAP32[$12>>2]|0;
 $23 = (($22) + 148|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $mipmaps&1;
 (FUNCTION_TABLE_iiiiiiii[$24 & 127]($12,$width,$height,$format,$25,1,0)|0);
 $26 = ($name|0)==(0|0);
 if (!($26)) {
  $27 = HEAP32[$12>>2]|0;
  $28 = (($27) + 36|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vii[$29 & 4095]($12,$name);
 }
 $30 = (($12) + 28|0);
 $31 = (($30) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = HEAP32[$12>>2]|0;
 $33 = (($32) + 116|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (FUNCTION_TABLE_ii[$34 & 4095]($12)|0);
 $36 = HEAP32[$12>>2]|0;
 $37 = (($36) + 120|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 4095]($12)|0);
 __ZN9Texture2D18UnshareTextureDataEv($12);
 $40 = (($12) + 48|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  $47 = 5;$61 = 0;
 } else {
  $43 = (($41) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($41) + 32|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46;$61 = $44;
 }
 $48 = (__Z25GetBytesFromTextureFormat13TextureFormat($47)|0);
 $49 = ($39|0)>(0);
 $50 = ($35|0)>(0);
 $or$cond$i = $49 & $50;
 if ($or$cond$i) {
  $51 = Math_imul($48, $35)|0;
  $data$03$us$i = $61;$y$04$us$i = 0;
  while(1) {
   $data$11$us$i = $data$03$us$i;$x$02$us$i = 0;
   while(1) {
    $53 = HEAP32[$fun>>2]|0;
    FUNCTION_TABLE_viiiiii[$53 & 255]($12,$data$11$us$i,$x$02$us$i,$y$04$us$i,$35,$39);
    $54 = (($data$11$us$i) + ($48)|0);
    $55 = (($x$02$us$i) + 1)|0;
    $exitcond$i = ($55|0)==($35|0);
    if ($exitcond$i) {
     break;
    } else {
     $data$11$us$i = $54;$x$02$us$i = $55;
    }
   }
   $scevgep$i = (($data$03$us$i) + ($51)|0);
   $52 = (($y$04$us$i) + 1)|0;
   $exitcond6$i = ($52|0)==($39|0);
   if ($exitcond6$i) {
    break;
   } else {
    $data$03$us$i = $scevgep$i;$y$04$us$i = $52;
   }
  }
 }
 $56 = HEAP32[$12>>2]|0;
 if ($mipmaps) {
  $57 = (($56) + 152|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vi[$58 & 4095]($12);
  STACKTOP = sp;return ($12|0);
 } else {
  $59 = (($56) + 156|0);
  $60 = HEAP32[$59>>2]|0;
  FUNCTION_TABLE_vi[$60 & 4095]($12);
  STACKTOP = sp;return ($12|0);
 }
 return 0|0;
}
function __Z14EmptyNormalMapP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0] = 127;
 $0 = (($data) + 1|0);
 HEAP8[$0>>0] = 127;
 $1 = (($data) + 2|0);
 HEAP8[$1>>0] = -1;
 $2 = (($data) + 3|0);
 HEAP8[$2>>0] = 127;
 STACKTOP = sp;return;
}
function __Z5WhiteP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0]=-1&255;HEAP8[$data+1>>0]=(-1>>8)&255;HEAP8[$data+2>>0]=(-1>>16)&255;HEAP8[$data+3>>0]=-1>>24;
 STACKTOP = sp;return;
}
function __Z5BlackP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0]=0&255;HEAP8[$data+1>>0]=(0>>8)&255;HEAP8[$data+2>>0]=(0>>16)&255;HEAP8[$data+3>>0]=0>>24;
 STACKTOP = sp;return;
}
function __Z14RandomRotationP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $$op$i1 = Math_fround(0), $$op$i2 = Math_fround(0), $$op$i3 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0;
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[602064>>2]|0;
 $1 = $0 << 11;
 $2 = $1 ^ $0;
 $3 = HEAP32[602072>>2]|0;
 HEAP32[602064>>2] = $3;
 $4 = HEAP32[602080>>2]|0;
 HEAP32[602072>>2] = $4;
 $5 = HEAP32[602088>>2]|0;
 HEAP32[602080>>2] = $5;
 $6 = $5 >>> 19;
 $7 = $2 >>> 8;
 $8 = $7 ^ $2;
 $9 = $8 ^ $5;
 $10 = $9 ^ $6;
 HEAP32[602088>>2] = $10;
 $11 = $10 & 8388607;
 $12 = (Math_fround(($11>>>0)));
 $13 = Math_fround($12 * Math_fround(1.19209303761635965202E-7));
 $14 = Math_fround($13 * Math_fround(6.28318548202514648438));
 $15 = (Math_fround(+(Math_cos((+$14)))));
 $16 = Math_fround($15 * Math_fround(0.5));
 $17 = Math_fround($16 + Math_fround(0.5));
 $18 = $17 < Math_fround(0.0);
 $19 = $18 ? Math_fround(0.0) : $17;
 $20 = $19 > Math_fround(1.0);
 $$op$i2 = Math_fround($19 * Math_fround(255.0));
 $21 = $20 ? Math_fround(255.0) : $$op$i2;
 $22 = Math_fround($21 + Math_fround(0.5));
 $23 = (~~(($22))>>>0);
 $24 = $23&255;
 HEAP8[$data>>0] = $24;
 $25 = (Math_fround(+(Math_sin((+$14)))));
 $26 = Math_fround($25 * Math_fround(-0.5));
 $27 = Math_fround($26 + Math_fround(0.5));
 $28 = $27 < Math_fround(0.0);
 $29 = $28 ? Math_fround(0.0) : $27;
 $30 = $29 > Math_fround(1.0);
 $$op$i3 = Math_fround($29 * Math_fround(255.0));
 $31 = $30 ? Math_fround(255.0) : $$op$i3;
 $32 = Math_fround($31 + Math_fround(0.5));
 $33 = (~~(($32))>>>0);
 $34 = $33&255;
 $35 = (($data) + 1|0);
 HEAP8[$35>>0] = $34;
 $36 = Math_fround($25 * Math_fround(0.5));
 $37 = Math_fround($36 + Math_fround(0.5));
 $38 = $37 < Math_fround(0.0);
 $39 = $38 ? Math_fround(0.0) : $37;
 $40 = $39 > Math_fround(1.0);
 $$op$i1 = Math_fround($39 * Math_fround(255.0));
 $41 = $40 ? Math_fround(255.0) : $$op$i1;
 $42 = Math_fround($41 + Math_fround(0.5));
 $43 = (~~(($42))>>>0);
 $44 = $43&255;
 $45 = (($data) + 2|0);
 HEAP8[$45>>0] = $44;
 $46 = (($data) + 3|0);
 HEAP8[$46>>0] = $24;
 STACKTOP = sp;return;
}
function __Z3RedP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0] = -1;
 $0 = (($data) + 1|0);
 HEAP8[$0>>0] = 0;
 $1 = (($data) + 2|0);
 HEAP8[$1>>0] = 0;
 $2 = (($data) + 3|0);
 HEAP8[$2>>0] = 0;
 STACKTOP = sp;return;
}
function __Z4GrayP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0]=2139062143&255;HEAP8[$data+1>>0]=(2139062143>>8)&255;HEAP8[$data+2>>0]=(2139062143>>16)&255;HEAP8[$data+3>>0]=2139062143>>24;
 STACKTOP = sp;return;
}
function __Z13GrayscaleRampP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x&255;
 _memset(($data|0),($0|0),4)|0;
 STACKTOP = sp;return;
}
function __Z7HaloTexP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $$sink$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0);
 var $8 = Math_fround(0), $9 = Math_fround(0), $sqrRange$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $maxX >> 1;
 $1 = $maxY >> 1;
 $2 = (($x) - ($0))|0;
 $3 = (Math_fround(($2|0)));
 $4 = (Math_fround(($0|0)));
 $5 = Math_fround($3 / $4);
 $6 = (($y) - ($1))|0;
 $7 = (Math_fround(($6|0)));
 $8 = (Math_fround(($1|0)));
 $9 = Math_fround($7 / $8);
 $10 = Math_fround($5 * $5);
 $11 = Math_fround($9 * $9);
 $12 = Math_fround($10 + $11);
 $13 = $12 > Math_fround(1.0);
 $sqrRange$0 = $13 ? Math_fround(1.0) : $12;
 $14 = Math_fround(Math_fround(1.0) - $sqrRange$0);
 $15 = Math_fround($14 * Math_fround(255.0));
 $16 = Math_fround($15 + Math_fround(0.5));
 $17 = !($16 >= Math_fround(0.0));
 if (!($17)) {
  $$sink$i$i = $16;
  $19 = (~~(($$sink$i$i)));
  $20 = $19&255;
  HEAP8[$data>>0] = $20;
  STACKTOP = sp;return;
 }
 $18 = Math_fround($16 + Math_fround(-0.999999940395355224609));
 $$sink$i$i = $18;
 $19 = (~~(($$sink$i$i)));
 $20 = $19&255;
 HEAP8[$data>>0] = $20;
 STACKTOP = sp;return;
}
function __Z12BuildTextureItPFvP9Texture2DPtiiiiEES1_PKcii13TextureFormatRKT0_b($name,$width,$height,$format,$fun,$mipmaps) {
 $name = $name|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $fun = $fun|0;
 $mipmaps = $mipmaps|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $data$03$us$i = 0, $data$11$us$i = 0, $exitcond$i = 0, $exitcond6$i = 0, $or$cond$i = 0, $scevgep$i = 0, $x$02$us$i = 0, $y$04$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy2,1,16,602528,1111)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1733,($3|0),($$byval_copy2|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(602528|0),1111);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch(0|0)|0;
   $11 = tempRet0;
   ___clang_call_terminate($10);
   // unreachable;
  } else {
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $12 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 4095]($12);
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($12,4);
 $19 = HEAP32[$12>>2]|0;
 $20 = (($19) + 44|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vii[$21 & 4095]($12,61);
 $22 = HEAP32[$12>>2]|0;
 $23 = (($22) + 148|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $mipmaps&1;
 (FUNCTION_TABLE_iiiiiiii[$24 & 127]($12,$width,$height,$format,$25,1,0)|0);
 $26 = ($name|0)==(0|0);
 if (!($26)) {
  $27 = HEAP32[$12>>2]|0;
  $28 = (($27) + 36|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vii[$29 & 4095]($12,$name);
 }
 $30 = (($12) + 28|0);
 $31 = (($30) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = HEAP32[$12>>2]|0;
 $33 = (($32) + 116|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (FUNCTION_TABLE_ii[$34 & 4095]($12)|0);
 $36 = HEAP32[$12>>2]|0;
 $37 = (($36) + 120|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 4095]($12)|0);
 __ZN9Texture2D18UnshareTextureDataEv($12);
 $40 = (($12) + 48|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  $47 = 5;$62 = 0;
 } else {
  $43 = (($41) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($41) + 32|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46;$62 = $44;
 }
 $48 = (__Z25GetBytesFromTextureFormat13TextureFormat($47)|0);
 $49 = $48 >>> 1;
 $50 = ($39|0)>(0);
 $51 = ($35|0)>(0);
 $or$cond$i = $50 & $51;
 if ($or$cond$i) {
  $52 = Math_imul($49, $35)|0;
  $data$03$us$i = $62;$y$04$us$i = 0;
  while(1) {
   $data$11$us$i = $data$03$us$i;$x$02$us$i = 0;
   while(1) {
    $54 = HEAP32[$fun>>2]|0;
    FUNCTION_TABLE_viiiiii[$54 & 255]($12,$data$11$us$i,$x$02$us$i,$y$04$us$i,$35,$39);
    $55 = (($data$11$us$i) + ($49<<1)|0);
    $56 = (($x$02$us$i) + 1)|0;
    $exitcond$i = ($56|0)==($35|0);
    if ($exitcond$i) {
     break;
    } else {
     $data$11$us$i = $55;$x$02$us$i = $56;
    }
   }
   $scevgep$i = (($data$03$us$i) + ($52<<1)|0);
   $53 = (($y$04$us$i) + 1)|0;
   $exitcond6$i = ($53|0)==($39|0);
   if ($exitcond6$i) {
    break;
   } else {
    $data$03$us$i = $scevgep$i;$y$04$us$i = $53;
   }
  }
 }
 $57 = HEAP32[$12>>2]|0;
 if ($mipmaps) {
  $58 = (($57) + 152|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vi[$59 & 4095]($12);
  STACKTOP = sp;return ($12|0);
 } else {
  $60 = (($57) + 156|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_vi[$61 & 4095]($12);
  STACKTOP = sp;return ($12|0);
 }
 return 0|0;
}
function __Z16LightAttenuationItEvP9Texture2DPT_iiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $$sink$i$i = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(($x|0)));
 $1 = (Math_fround(($maxX|0)));
 $2 = Math_fround($0 / $1);
 $3 = (Math_fround(__ZN5Light19AttenuateNormalizedEf($2)));
 $4 = Math_fround($3 * Math_fround(65535.0));
 $5 = Math_fround($4 + Math_fround(0.5));
 $6 = !($5 >= Math_fround(0.0));
 if ($6) {
  $7 = Math_fround($5 + Math_fround(-0.999999940395355224609));
  $$sink$i$i = $7;
 } else {
  $$sink$i$i = $5;
 }
 $8 = (~~(($$sink$i$i)));
 $9 = $8&65535;
 HEAP16[$data>>1] = $9;
 STACKTOP = sp;return;
}
function __Z16LightAttenuationIhEvP9Texture2DPT_iiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $$sink$i$i = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(($x|0)));
 $1 = (Math_fround(($maxX|0)));
 $2 = Math_fround($0 / $1);
 $3 = (Math_fround(__ZN5Light19AttenuateNormalizedEf($2)));
 $4 = Math_fround($3 * Math_fround(255.0));
 $5 = Math_fround($4 + Math_fround(0.5));
 $6 = !($5 >= Math_fround(0.0));
 if ($6) {
  $7 = Math_fround($5 + Math_fround(-0.999999940395355224609));
  $$sink$i$i = $7;
 } else {
  $$sink$i$i = $5;
 }
 $8 = (~~(($$sink$i$i)));
 $9 = $8&255;
 HEAP8[$data>>0] = $9;
 STACKTOP = sp;return;
}
function __Z16BuildCubeTextureIhPFvPh8Vector3fEEP7CubemapPKci13TextureFormatRKT0_($name,$size,$format,$fun) {
 $name = $name|0;
 $size = $size|0;
 $format = $format|0;
 $fun = $fun|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(148,$$byval_copy2,1,16,602528,1111)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1736,($3|0),($$byval_copy2|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(602528|0),1111);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch(0|0)|0;
   $11 = tempRet0;
   ___clang_call_terminate($10);
   // unreachable;
  } else {
   ___resumeException($6|0);
   // unreachable;
  }
 } else {
  $12 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 24|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$15 & 4095]($12);
  $16 = HEAP32[$12>>2]|0;
  $17 = (($16) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vii[$18 & 4095]($12,4);
  $19 = HEAP32[$12>>2]|0;
  $20 = (($19) + 44|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_vii[$21 & 4095]($12,61);
  $22 = HEAP32[$12>>2]|0;
  $23 = (($22) + 148|0);
  $24 = HEAP32[$23>>2]|0;
  (FUNCTION_TABLE_iiiiiiii[$24 & 127]($12,$size,$size,$format,0,6,0)|0);
  $25 = ($name|0)==(0|0);
  if (!($25)) {
   $26 = HEAP32[$12>>2]|0;
   $27 = (($26) + 36|0);
   $28 = HEAP32[$27>>2]|0;
   FUNCTION_TABLE_vii[$28 & 4095]($12,$name);
  }
  __Z19GenerateCubeTextureIhPFvPh8Vector3fEEvP7CubemapRKT0_($12,$fun);
  $29 = HEAP32[$12>>2]|0;
  $30 = (($29) + 156|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vi[$31 & 4095]($12);
  $32 = (($12) + 28|0);
  $33 = (($32) + 12|0);
  HEAP32[$33>>2] = 1;
  $34 = HEAP32[$12>>2]|0;
  $35 = (($34) + 132|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_vi[$36 & 4095]($12);
  STACKTOP = sp;return ($12|0);
 }
 return 0|0;
}
function __Z9BlackCubePh8Vector3f($data,$normal) {
 $data = $data|0;
 $normal = $normal|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0]=0&255;HEAP8[$data+1>>0]=(0>>8)&255;HEAP8[$data+2>>0]=(0>>16)&255;HEAP8[$data+3>>0]=0>>24;
 STACKTOP = sp;return;
}
function __Z7Empty2DP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0]=-2139062144&255;HEAP8[$data+1>>0]=(-2139062144>>8)&255;HEAP8[$data+2>>0]=(-2139062144>>16)&255;HEAP8[$data+3>>0]=-2139062144>>24;
 STACKTOP = sp;return;
}
function __Z14Build3DTextureIhPFvPhiiiiiiEEP9Texture3DPKciii13TextureFormatRKT0_($name,$width,$height,$depth,$format,$fun) {
 $name = $name|0;
 $width = $width|0;
 $height = $height|0;
 $depth = $depth|0;
 $format = $format|0;
 $fun = $fun|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$08$i = 0, $data$1$lcssa$i = 0, $data$14$i = 0, $data$2$lcssa$i = 0, $data$21$i = 0, $exitcond$i = 0, $exitcond11$i = 0, $exitcond12$i = 0, $scevgep$i = 0;
 var $x$02$i = 0, $y$05$i = 0, $z$09$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(128,$$byval_copy2,1,16,602528,1111)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1735,($3|0),($$byval_copy2|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(602528|0),1111);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch(0|0)|0;
   $11 = tempRet0;
   ___clang_call_terminate($10);
   // unreachable;
  } else {
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $12 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 4095]($12);
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($12,4);
 $19 = HEAP32[$12>>2]|0;
 $20 = (($19) + 44|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vii[$21 & 4095]($12,61);
 (__ZN9Texture3D11InitTextureEiii13TextureFormatb($12,$width,$height,$depth,$format,0)|0);
 $22 = ($name|0)==(0|0);
 if (!($22)) {
  $23 = HEAP32[$12>>2]|0;
  $24 = (($23) + 36|0);
  $25 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_vii[$25 & 4095]($12,$name);
 }
 $26 = HEAP32[$12>>2]|0;
 $27 = (($26) + 116|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 4095]($12)|0);
 $30 = HEAP32[$12>>2]|0;
 $31 = (($30) + 120|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 4095]($12)|0);
 $34 = (($12) + 108|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($12) + 116|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($12) + 112|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (__Z25GetBytesFromTextureFormat13TextureFormat($39)|0);
 $41 = ($35|0)>(0);
 if (!($41)) {
  __ZN9Texture3D15UpdateImageDataEb($12,0);
  STACKTOP = sp;return ($12|0);
 }
 $42 = ($33|0)>(0);
 $43 = ($29|0)>(0);
 $44 = Math_imul($40, $29)|0;
 $data$08$i = $37;$z$09$i = 0;
 while(1) {
  if ($42) {
   $data$14$i = $data$08$i;$y$05$i = 0;
   while(1) {
    if ($43) {
     $data$21$i = $data$14$i;$x$02$i = 0;
     while(1) {
      $45 = HEAP32[$fun>>2]|0;
      FUNCTION_TABLE_viiiiiii[$45 & 127]($data$21$i,$x$02$i,$y$05$i,$z$09$i,$29,$33,$35);
      $46 = (($data$21$i) + ($40)|0);
      $47 = (($x$02$i) + 1)|0;
      $exitcond$i = ($47|0)==($29|0);
      if ($exitcond$i) {
       break;
      } else {
       $data$21$i = $46;$x$02$i = $47;
      }
     }
     $scevgep$i = (($data$14$i) + ($44)|0);
     $data$2$lcssa$i = $scevgep$i;
    } else {
     $data$2$lcssa$i = $data$14$i;
    }
    $48 = (($y$05$i) + 1)|0;
    $exitcond11$i = ($48|0)==($33|0);
    if ($exitcond11$i) {
     $data$1$lcssa$i = $data$2$lcssa$i;
     break;
    } else {
     $data$14$i = $data$2$lcssa$i;$y$05$i = $48;
    }
   }
  } else {
   $data$1$lcssa$i = $data$08$i;
  }
  $49 = (($z$09$i) + 1)|0;
  $exitcond12$i = ($49|0)==($35|0);
  if ($exitcond12$i) {
   break;
  } else {
   $data$08$i = $data$1$lcssa$i;$z$09$i = $49;
  }
 }
 __ZN9Texture3D15UpdateImageDataEb($12,0);
 STACKTOP = sp;return ($12|0);
}
function __Z7Empty3DPhiiiiii($data,$x,$y,$z,$maxX,$maxY,$maxZ) {
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $z = $z|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 $maxZ = $maxZ|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0]=-2139062144&255;HEAP8[$data+1>>0]=(-2139062144>>8)&255;HEAP8[$data+2>>0]=(-2139062144>>16)&255;HEAP8[$data+3>>0]=-2139062144>>24;
 STACKTOP = sp;return;
}
function __Z9EmptyCubePh8Vector3f($data,$normal) {
 $data = $data|0;
 $normal = $normal|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$data>>0]=-2139062144&255;HEAP8[$data+1>>0]=(-2139062144>>8)&255;HEAP8[$data+2>>0]=(-2139062144>>16)&255;HEAP8[$data+3>>0]=-2139062144>>24;
 STACKTOP = sp;return;
}
function __Z12NHxRoughnessItEvP9Texture2DPT_iiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $$op = Math_fround(0), $$sink$i$i = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(($x|0)));
 $1 = (Math_fround(($maxX|0)));
 $2 = Math_fround($1 + Math_fround(-1.0));
 $3 = Math_fround($0 / $2);
 $4 = (Math_fround(($y|0)));
 $5 = (Math_fround(($maxY|0)));
 $6 = Math_fround($5 + Math_fround(-0.5));
 $7 = Math_fround($4 / $6);
 $8 = (Math_fround(+(Math_pow((+$7),3.0))));
 $9 = Math_fround($8 + Math_fround(9.99999974737875163555E-5));
 $10 = Math_fround(Math_fround(2.0) / $9);
 $11 = Math_fround($10 + Math_fround(-2.0));
 $12 = $11 < Math_fround(9.99999974737875163555E-6);
 $13 = $12 ? Math_fround(9.99999974737875163555E-6) : $11;
 $14 = Math_fround($13 + Math_fround(1.0));
 $15 = Math_fround($14 / Math_fround(6.28318023681640625));
 $16 = (Math_fround(+(Math_pow((+$3),(+$13)))));
 $17 = Math_fround($15 * $16);
 $18 = Math_fround($17 * Math_fround(0.0625));
 $19 = $18 < Math_fround(0.0);
 $20 = $19 ? Math_fround(0.0) : $18;
 $21 = $20 > Math_fround(1.0);
 $$op = Math_fround($20 * Math_fround(65535.0));
 $22 = $21 ? Math_fround(65535.0) : $$op;
 $23 = Math_fround($22 + Math_fround(0.5));
 $24 = !($23 >= Math_fround(0.0));
 if (!($24)) {
  $$sink$i$i = $23;
  $26 = (~~(($$sink$i$i)));
  $27 = $26&65535;
  HEAP16[$data>>1] = $27;
  STACKTOP = sp;return;
 }
 $25 = Math_fround($23 + Math_fround(-0.999999940395355224609));
 $$sink$i$i = $25;
 $26 = (~~(($$sink$i$i)));
 $27 = $26&65535;
 HEAP16[$data>>1] = $27;
 STACKTOP = sp;return;
}
function __Z12NHxRoughnessIhEvP9Texture2DPT_iiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $$op = Math_fround(0), $$sink$i$i = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(($x|0)));
 $1 = (Math_fround(($maxX|0)));
 $2 = Math_fround($1 + Math_fround(-1.0));
 $3 = Math_fround($0 / $2);
 $4 = (Math_fround(($y|0)));
 $5 = (Math_fround(($maxY|0)));
 $6 = Math_fround($5 + Math_fround(-0.5));
 $7 = Math_fround($4 / $6);
 $8 = (Math_fround(+(Math_pow((+$7),3.0))));
 $9 = Math_fround($8 + Math_fround(9.99999974737875163555E-5));
 $10 = Math_fround(Math_fround(2.0) / $9);
 $11 = Math_fround($10 + Math_fround(-2.0));
 $12 = $11 < Math_fround(9.99999974737875163555E-6);
 $13 = $12 ? Math_fround(9.99999974737875163555E-6) : $11;
 $14 = Math_fround($13 + Math_fround(1.0));
 $15 = Math_fround($14 / Math_fround(6.28318023681640625));
 $16 = (Math_fround(+(Math_pow((+$3),(+$13)))));
 $17 = Math_fround($15 * $16);
 $18 = Math_fround($17 * Math_fround(0.0625));
 $19 = $18 < Math_fround(0.0);
 $20 = $19 ? Math_fround(0.0) : $18;
 $21 = $20 > Math_fround(1.0);
 $$op = Math_fround($20 * Math_fround(255.0));
 $22 = $21 ? Math_fround(255.0) : $$op;
 $23 = Math_fround($22 + Math_fround(0.5));
 $24 = !($23 >= Math_fround(0.0));
 if (!($24)) {
  $$sink$i$i = $23;
  $26 = (~~(($$sink$i$i)));
  $27 = $26&255;
  HEAP8[$data>>0] = $27;
  STACKTOP = sp;return;
 }
 $25 = Math_fround($23 + Math_fround(-0.999999940395355224609));
 $$sink$i$i = $25;
 $26 = (~~(($$sink$i$i)));
 $27 = $26&255;
 HEAP8[$data>>0] = $27;
 STACKTOP = sp;return;
}
function __ZN10builtintex15GetWhiteTextureEv() {
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[601936>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $1;
 $3 = HEAP32[560624>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 10;
 } else {
  $5 = (($3) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $10 = (($3) + 28|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($3) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + ($13<<3)|0);
    $30 = $14;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
    $15 = HEAP32[$pos$i$i$i$i>>2]|0;
    $16 = ($15|0)==(-1);
    $17 = (($3) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    if ($16) {
     $19 = (($3) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $30 = $21;
     break;
    } else {
     $22 = (($18) + ($15<<3)|0);
     $30 = $22;
     break;
    }
   }
  } while(0);
  $23 = HEAP32[560624>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + ($27<<3)|0);
  $29 = ($30|0)==($28|0);
  if ($29) {
   label = 10;
  } else {
   $31 = (($30) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 10;
   } else {
    $temp$0$i = $32;
   }
  }
 }
 if ((label|0) == 10) {
  $34 = HEAP32[601936>>2]|0;
  $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
  $temp$0$i = $35;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN10builtintex15GetBlackTextureEv() {
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[601944>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $1;
 $3 = HEAP32[560624>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 10;
 } else {
  $5 = (($3) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $10 = (($3) + 28|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($3) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + ($13<<3)|0);
    $30 = $14;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
    $15 = HEAP32[$pos$i$i$i$i>>2]|0;
    $16 = ($15|0)==(-1);
    $17 = (($3) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    if ($16) {
     $19 = (($3) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $30 = $21;
     break;
    } else {
     $22 = (($18) + ($15<<3)|0);
     $30 = $22;
     break;
    }
   }
  } while(0);
  $23 = HEAP32[560624>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + ($27<<3)|0);
  $29 = ($30|0)==($28|0);
  if ($29) {
   label = 10;
  } else {
   $31 = (($30) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 10;
   } else {
    $temp$0$i = $32;
   }
  }
 }
 if ((label|0) == 10) {
  $34 = HEAP32[601944>>2]|0;
  $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
  $temp$0$i = $35;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN10builtintex21GetAttenuationTextureEv() {
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[601960>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $1;
 $3 = HEAP32[560624>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 10;
 } else {
  $5 = (($3) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $10 = (($3) + 28|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($3) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + ($13<<3)|0);
    $30 = $14;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
    $15 = HEAP32[$pos$i$i$i$i>>2]|0;
    $16 = ($15|0)==(-1);
    $17 = (($3) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    if ($16) {
     $19 = (($3) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $30 = $21;
     break;
    } else {
     $22 = (($18) + ($15<<3)|0);
     $30 = $22;
     break;
    }
   }
  } while(0);
  $23 = HEAP32[560624>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + ($27<<3)|0);
  $29 = ($30|0)==($28|0);
  if ($29) {
   label = 10;
  } else {
   $31 = (($30) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 10;
   } else {
    $temp$0$i = $32;
   }
  }
 }
 if ((label|0) == 10) {
  $34 = HEAP32[601960>>2]|0;
  $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
  $temp$0$i = $35;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN10builtintex14GetHaloTextureEv() {
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[601968>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $1;
 $3 = HEAP32[560624>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 10;
 } else {
  $5 = (($3) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $10 = (($3) + 28|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($3) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + ($13<<3)|0);
    $30 = $14;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
    $15 = HEAP32[$pos$i$i$i$i>>2]|0;
    $16 = ($15|0)==(-1);
    $17 = (($3) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    if ($16) {
     $19 = (($3) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $30 = $21;
     break;
    } else {
     $22 = (($18) + ($15<<3)|0);
     $30 = $22;
     break;
    }
   }
  } while(0);
  $23 = HEAP32[560624>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + ($27<<3)|0);
  $29 = ($30|0)==($28|0);
  if ($29) {
   label = 10;
  } else {
   $31 = (($30) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 10;
   } else {
    $temp$0$i = $32;
   }
  }
 }
 if ((label|0) == 10) {
  $34 = HEAP32[601968>>2]|0;
  $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
  $temp$0$i = $35;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN10builtintex17GetDefaultTextureE16TextureDimension($texDim) {
 $texDim = $texDim|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (602040 + ($texDim<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN10builtintex17GetBlackTextureIDEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[601944>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[560624>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($2) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $9 = (($2) + 28|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($2) + 32|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + ($12<<3)|0);
    $29 = $13;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$2,$0);
    $14 = HEAP32[$pos$i$i$i$i>>2]|0;
    $15 = ($14|0)==(-1);
    $16 = (($2) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    if ($15) {
     $18 = (($2) + 32|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($17) + ($19<<3)|0);
     $29 = $20;
     break;
    } else {
     $21 = (($17) + ($14<<3)|0);
     $29 = $21;
     break;
    }
   }
  } while(0);
  $22 = HEAP32[560624>>2]|0;
  $23 = (($22) + 28|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($22) + 32|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + ($26<<3)|0);
  $28 = ($29|0)==($27|0);
  if (!($28)) {
   $30 = (($29) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $temp$0$i = $31;
    $35 = (($temp$0$i) + 44|0);
    $36 = HEAP32[$35>>2]|0;
    STACKTOP = sp;return ($36|0);
   }
  }
 }
 $33 = HEAP32[601944>>2]|0;
 $34 = (__Z31ReadObjectFromPersistentManageri($33)|0);
 $temp$0$i = $34;
 $35 = (($temp$0$i) + 44|0);
 $36 = HEAP32[$35>>2]|0;
 STACKTOP = sp;return ($36|0);
}
function __ZN10builtintex21GetBlackCubeTextureIDEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[601952>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[560624>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($2) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $9 = (($2) + 28|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($2) + 32|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + ($12<<3)|0);
    $29 = $13;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$2,$0);
    $14 = HEAP32[$pos$i$i$i$i>>2]|0;
    $15 = ($14|0)==(-1);
    $16 = (($2) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    if ($15) {
     $18 = (($2) + 32|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($17) + ($19<<3)|0);
     $29 = $20;
     break;
    } else {
     $21 = (($17) + ($14<<3)|0);
     $29 = $21;
     break;
    }
   }
  } while(0);
  $22 = HEAP32[560624>>2]|0;
  $23 = (($22) + 28|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($22) + 32|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + ($26<<3)|0);
  $28 = ($29|0)==($27|0);
  if (!($28)) {
   $30 = (($29) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $temp$0$i = $31;
    $35 = (($temp$0$i) + 44|0);
    $36 = HEAP32[$35>>2]|0;
    STACKTOP = sp;return ($36|0);
   }
  }
 }
 $33 = HEAP32[601952>>2]|0;
 $34 = (__Z31ReadObjectFromPersistentManageri($33)|0);
 $temp$0$i = $34;
 $35 = (($temp$0$i) + 44|0);
 $36 = HEAP32[$35>>2]|0;
 STACKTOP = sp;return ($36|0);
}
function __Z19GenerateCubeTextureIhPFvPh8Vector3fEEvP7CubemapRKT0_($cubemap,$fun) {
 $cubemap = $cubemap|0;
 $fun = $fun|0;
 var $$pre = 0, $$pre14 = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $dest$0$ph = 0, $dest$09$us = 0, $dest$17$us = 0, $direction$011 = 0, $exitcond = 0, $exitcond12 = 0, $exitcond13 = 0, $scevgep = 0, $worldDir = 0, $worldDir$byval_copy = 0, $x$08$us = 0, $y$010$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $worldDir$byval_copy = sp + 12|0;
 $worldDir = sp;
 $0 = (($cubemap) + 48|0);
 $1 = (($worldDir) + 4|0);
 $2 = (($worldDir) + 8|0);
 $direction$011 = 0;
 while(1) {
  $3 = HEAP32[$cubemap>>2]|0;
  $4 = (($3) + 116|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 4095]($cubemap)|0);
  $7 = HEAP32[$cubemap>>2]|0;
  $8 = (($7) + 120|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_ii[$9 & 4095]($cubemap)|0);
  $11 = (602456 + ($direction$011<<2)|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (602480 + ($direction$011<<2)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (602504 + ($direction$011<<2)|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = HEAP32[$0>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $21 = 5;
  } else {
   $19 = (($17) + 32|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20;
  }
  $22 = (__Z25GetBytesFromTextureFormat13TextureFormat($21)|0);
  $23 = (Math_fround(($6|0)));
  $24 = Math_fround(Math_fround(1.0) / $23);
  $25 = (Math_fround(($10|0)));
  $26 = Math_fround(Math_fround(1.0) / $25);
  __ZN9Texture2D18UnshareTextureDataEv($cubemap);
  $27 = HEAP32[$0>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   $dest$0$ph = 0;
  } else {
   $29 = (($27) + 36|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = Math_imul($30, $direction$011)|0;
   $32 = (($27) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + ($31)|0);
   $dest$0$ph = $34;
  }
  $35 = ($10|0)>(0);
  if ($35) {
   $36 = ($6|0)>(0);
   $37 = (602384 + ($direction$011<<2)|0);
   $38 = (602408 + ($direction$011<<2)|0);
   $39 = (602432 + ($direction$011<<2)|0);
   if ($36) {
    $40 = Math_imul($22, $6)|0;
    $dest$09$us = $dest$0$ph;$y$010$us = 0;
    while(1) {
     $54 = (Math_fround(($y$010$us|0)));
     $55 = Math_fround($26 * $54);
     $56 = Math_fround($55 * Math_fround(2.0));
     $57 = Math_fround($56 + Math_fround(-1.0));
     $49 = Math_fround($14 * $57);
     $$pre = HEAP32[$37>>2]|0;
     $$pre14 = HEAP32[$38>>2]|0;
     $$pre15 = HEAP32[$39>>2]|0;
     $dest$17$us = $dest$09$us;$x$08$us = 0;
     while(1) {
      $42 = (Math_fround(($x$08$us|0)));
      $43 = Math_fround($24 * $42);
      $44 = Math_fround($43 * Math_fround(2.0));
      $45 = Math_fround($44 + Math_fround(-1.0));
      $46 = Math_fround($12 * $45);
      HEAPF32[$worldDir>>2] = Math_fround(0.0);
      HEAPF32[$1>>2] = Math_fround(0.0);
      HEAPF32[$2>>2] = Math_fround(0.0);
      $47 = (($worldDir) + ($$pre<<2)|0);
      HEAPF32[$47>>2] = $46;
      $48 = (($worldDir) + ($$pre14<<2)|0);
      HEAPF32[$48>>2] = $49;
      $50 = (($worldDir) + ($$pre15<<2)|0);
      HEAPF32[$50>>2] = $16;
      $51 = HEAP32[$fun>>2]|0;
      ;HEAP32[$worldDir$byval_copy+0>>2]=HEAP32[$worldDir+0>>2]|0;HEAP32[$worldDir$byval_copy+4>>2]=HEAP32[$worldDir+4>>2]|0;HEAP32[$worldDir$byval_copy+8>>2]=HEAP32[$worldDir+8>>2]|0;
      FUNCTION_TABLE_vii[$51 & 4095]($dest$17$us,$worldDir$byval_copy);
      $52 = (($x$08$us) + 1)|0;
      $exitcond = ($52|0)==($6|0);
      if ($exitcond) {
       break;
      }
      $53 = (($dest$17$us) + ($22)|0);
      $dest$17$us = $53;$x$08$us = $52;
     }
     $scevgep = (($dest$09$us) + ($40)|0);
     $41 = (($y$010$us) + 1)|0;
     $exitcond12 = ($41|0)==($10|0);
     if ($exitcond12) {
      break;
     } else {
      $dest$09$us = $scevgep;$y$010$us = $41;
     }
    }
   }
  }
  $58 = (($direction$011) + 1)|0;
  $exitcond13 = ($58|0)==(6);
  if ($exitcond13) {
   break;
  } else {
   $direction$011 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE($clearFlags,$color,$depth,$stencil,$passContext) {
 $clearFlags = $clearFlags|0;
 $color = $color|0;
 $depth = Math_fround($depth);
 $stencil = $stencil|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiifi[$3 & 7]($0,$clearFlags,$color,$depth,$stencil);
 STACKTOP = sp;return;
}
function __ZN14GraphicsHelper13SetBlendStateEPK16DeviceBlendStateRKN9ShaderLab8FloatValEPKNS3_13PropertySheetERKNS3_17ShaderPassContextE($state,$alphaRef,$props,$passContext) {
 $state = $state|0;
 $alphaRef = $alphaRef|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$byval_copy = 0, $$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $location$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $location$i$i = sp;
 $0 = sp + 4|0;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = (($1) + 5785|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = HEAP32[$1>>2]|0;
  $6 = (($5) + 48|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viiiii[$7 & 255]($1,$state,$alphaRef,$props,$passContext);
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + 52|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($alphaRef) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(-1);
 if ($13) {
  $$in$i = $alphaRef;
 } else {
  HEAP32[$0>>2] = $12;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $14 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy,$location$i$i)|0);
  $$in$i = $14;
 }
 $15 = Math_fround(HEAPF32[$$in$i>>2]);
 FUNCTION_TABLE_viif[$10 & 63]($1,$state,$15);
 STACKTOP = sp;return;
}
function __ZN14GraphicsHelper13SetFFMaterialERKN9ShaderLab9VectorValES3_S3_S3_RKNS0_8FloatValEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($ambient,$diffuse,$specular,$emissive,$shininess,$props,$passContext) {
 $ambient = $ambient|0;
 $diffuse = $diffuse|0;
 $specular = $specular|0;
 $emissive = $emissive|0;
 $shininess = $shininess|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$byval_copy = 0, $$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $location$i$i = 0, $material = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy = sp + 144|0;
 $location$i$i = sp;
 $0 = sp + 4|0;
 $material = sp + 8|0;
 $1 = sp + 80|0;
 $2 = sp + 96|0;
 $3 = sp + 112|0;
 $4 = sp + 128|0;
 $5 = (__Z12GetGfxDevicev()|0);
 $6 = (($5) + 5785|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = HEAP32[$5>>2]|0;
  $10 = (($9) + 144|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viiiiiiii[$11 & 63]($5,$ambient,$diffuse,$specular,$emissive,$shininess,$props,$passContext);
  STACKTOP = sp;return;
 }
 __ZNK9ShaderLab9VectorVal3GetEPKNS_13PropertySheetERKNS_17ShaderPassContextE($1,$ambient,$props,$passContext);
 $12 = Math_fround(HEAPF32[$1>>2]);
 $13 = (($1) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($1) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($1) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$material>>2] = $12;
 $19 = (($material) + 4|0);
 HEAPF32[$19>>2] = $14;
 $20 = (($material) + 8|0);
 HEAPF32[$20>>2] = $16;
 $21 = (($material) + 12|0);
 HEAPF32[$21>>2] = $18;
 __ZNK9ShaderLab9VectorVal3GetEPKNS_13PropertySheetERKNS_17ShaderPassContextE($2,$diffuse,$props,$passContext);
 $22 = Math_fround(HEAPF32[$2>>2]);
 $23 = (($2) + 4|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($2) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($2) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($material) + 16|0);
 HEAPF32[$29>>2] = $22;
 $30 = (($material) + 20|0);
 HEAPF32[$30>>2] = $24;
 $31 = (($material) + 24|0);
 HEAPF32[$31>>2] = $26;
 $32 = (($material) + 28|0);
 HEAPF32[$32>>2] = $28;
 __ZNK9ShaderLab9VectorVal3GetEPKNS_13PropertySheetERKNS_17ShaderPassContextE($3,$specular,$props,$passContext);
 $33 = Math_fround(HEAPF32[$3>>2]);
 $34 = (($3) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($3) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($3) + 12|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($material) + 32|0);
 HEAPF32[$40>>2] = $33;
 $41 = (($material) + 36|0);
 HEAPF32[$41>>2] = $35;
 $42 = (($material) + 40|0);
 HEAPF32[$42>>2] = $37;
 $43 = (($material) + 44|0);
 HEAPF32[$43>>2] = $39;
 __ZNK9ShaderLab9VectorVal3GetEPKNS_13PropertySheetERKNS_17ShaderPassContextE($4,$emissive,$props,$passContext);
 $44 = Math_fround(HEAPF32[$4>>2]);
 $45 = (($4) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($4) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($4) + 12|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($material) + 48|0);
 HEAPF32[$51>>2] = $44;
 $52 = (($material) + 52|0);
 HEAPF32[$52>>2] = $46;
 $53 = (($material) + 56|0);
 HEAPF32[$53>>2] = $48;
 $54 = (($material) + 60|0);
 HEAPF32[$54>>2] = $50;
 $55 = (($shininess) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(-1);
 if ($57) {
  $$in$i = $shininess;
 } else {
  HEAP32[$0>>2] = $56;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $58 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy,$location$i$i)|0);
  $$in$i = $58;
 }
 $59 = Math_fround(HEAPF32[$$in$i>>2]);
 $60 = (($material) + 64|0);
 HEAPF32[$60>>2] = $59;
 $61 = HEAP32[$5>>2]|0;
 $62 = (($61) + 148|0);
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_vii[$63 & 4095]($5,$material);
 STACKTOP = sp;return;
}
function __ZNK9ShaderLab9VectorVal3GetEPKNS_13PropertySheetERKNS_17ShaderPassContextE($agg$result,$this,$props,$passContext) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$byval_copy4 = 0, $$in$i = 0, $$in$i3 = 0, $$in$i6 = 0, $$in$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0);
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $location$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $location$i$i8 = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 if (!($3)) {
  HEAP32[$0>>2] = $2;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $4 = (__ZN9ShaderLab11shaderprops9GetVectorEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy4,$location$i$i8)|0);
  ;HEAP32[$agg$result+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$4+12>>2]|0;
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $$in$i3 = $this;
 } else {
  HEAP32[$0>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $8 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy4,$location$i$i8)|0);
  $$in$i3 = $8;
 }
 $9 = Math_fround(HEAPF32[$$in$i3>>2]);
 $10 = (($this) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(-1);
 if ($12) {
  $14 = (($this) + 8|0);
  $$in$i6 = $14;
 } else {
  HEAP32[$0>>2] = $11;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $13 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy4,$location$i$i8)|0);
  $$in$i6 = $13;
 }
 $15 = Math_fround(HEAPF32[$$in$i6>>2]);
 $16 = (($this) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(-1);
 if ($18) {
  $20 = (($this) + 16|0);
  $$in$i9 = $20;
 } else {
  HEAP32[$0>>2] = $17;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $19 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy4,$location$i$i8)|0);
  $$in$i9 = $19;
 }
 $21 = Math_fround(HEAPF32[$$in$i9>>2]);
 $22 = (($this) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(-1);
 if ($24) {
  $26 = (($this) + 24|0);
  $$in$i = $26;
 } else {
  HEAP32[$0>>2] = $23;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $25 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy4,$location$i$i8)|0);
  $$in$i = $25;
 }
 $27 = Math_fround(HEAPF32[$$in$i>>2]);
 HEAPF32[$agg$result>>2] = $9;
 $28 = (($agg$result) + 4|0);
 HEAPF32[$28>>2] = $15;
 $29 = (($agg$result) + 8|0);
 HEAPF32[$29>>2] = $21;
 $30 = (($agg$result) + 12|0);
 HEAPF32[$30>>2] = $27;
 STACKTOP = sp;return;
}
function __ZN14GraphicsHelper10SetFFColorERKN9ShaderLab9VectorValEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($color,$props,$passContext) {
 $color = $color|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = (($2) + 5785|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $9 = HEAP32[$2>>2]|0;
  $10 = (($9) + 156|0);
  $11 = HEAP32[$10>>2]|0;
  __ZNK9ShaderLab9VectorVal3GetEPKNS_13PropertySheetERKNS_17ShaderPassContextE($1,$color,$props,$passContext);
  $12 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$0>>2] = $12;
  $13 = (($0) + 4|0);
  $14 = (($1) + 4|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$13>>2] = $15;
  $16 = (($0) + 8|0);
  $17 = (($1) + 8|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$16>>2] = $18;
  $19 = (($0) + 12|0);
  $20 = (($1) + 12|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$19>>2] = $21;
  FUNCTION_TABLE_vii[$11 & 4095]($2,$0);
  STACKTOP = sp;return;
 } else {
  $6 = HEAP32[$2>>2]|0;
  $7 = (($6) + 152|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_viiii[$8 & 511]($2,$color,$props,$passContext);
  STACKTOP = sp;return;
 }
}
function __ZN14GraphicsHelper11EnableFFFogE7FogModeRKN9ShaderLab8FloatValES4_S4_RKNS1_9VectorValEPKNS1_13PropertySheetERKNS1_17ShaderPassContextE($fogMode,$fogStart,$fogEnd,$fogDensity,$fogColor,$props,$passContext) {
 $fogMode = $fogMode|0;
 $fogStart = $fogStart|0;
 $fogEnd = $fogEnd|0;
 $fogDensity = $fogDensity|0;
 $fogColor = $fogColor|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$byval_copy2 = 0, $$in$i = 0, $$in$i2 = 0, $$in$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $fog = 0, $location$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp + 56|0;
 $location$i$i4 = sp;
 $0 = sp + 4|0;
 $fog = sp + 8|0;
 $1 = sp + 40|0;
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = (($2) + 5785|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = HEAP32[$2>>2]|0;
  $7 = (($6) + 160|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_viiiiiiii[$8 & 63]($2,$fogMode,$fogStart,$fogEnd,$fogDensity,$fogColor,$props,$passContext);
  STACKTOP = sp;return;
 }
 HEAP32[$fog>>2] = $fogMode;
 __ZNK9ShaderLab9VectorVal3GetEPKNS_13PropertySheetERKNS_17ShaderPassContextE($1,$fogColor,$props,$passContext);
 $9 = Math_fround(HEAPF32[$1>>2]);
 $10 = (($1) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($1) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($1) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($fog) + 4|0);
 HEAPF32[$16>>2] = $9;
 $17 = (($fog) + 8|0);
 HEAPF32[$17>>2] = $11;
 $18 = (($fog) + 12|0);
 HEAPF32[$18>>2] = $13;
 $19 = (($fog) + 16|0);
 HEAPF32[$19>>2] = $15;
 $20 = (($fogStart) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(-1);
 if ($22) {
  $$in$i5 = $fogStart;
 } else {
  HEAP32[$0>>2] = $21;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy2,$location$i$i4)|0);
  $$in$i5 = $23;
 }
 $24 = Math_fround(HEAPF32[$$in$i5>>2]);
 $25 = (($fog) + 20|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($fogEnd) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(-1);
 if ($28) {
  $$in$i2 = $fogEnd;
 } else {
  HEAP32[$0>>2] = $27;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy2,$location$i$i4)|0);
  $$in$i2 = $29;
 }
 $30 = Math_fround(HEAPF32[$$in$i2>>2]);
 $31 = (($fog) + 24|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($fogDensity) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(-1);
 if ($34) {
  $$in$i = $fogDensity;
 } else {
  HEAP32[$0>>2] = $33;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $35 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy2,$location$i$i4)|0);
  $$in$i = $35;
 }
 $36 = Math_fround(HEAPF32[$$in$i>>2]);
 $37 = (($fog) + 28|0);
 HEAPF32[$37>>2] = $36;
 $38 = HEAP32[$2>>2]|0;
 $39 = (($38) + 164|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_vii[$40 & 4095]($2,$fog);
 STACKTOP = sp;return;
}
function __Z23BlitCopyCompressedImage13TextureFormatPKhiiPhiib($format,$src,$srcWidth,$srcHeight,$dst,$dstWidth,$dstHeight,$fillRest) {
 $format = $format|0;
 $src = $src|0;
 $srcWidth = $srcWidth|0;
 $srcHeight = $srcHeight|0;
 $dst = $dst|0;
 $dstWidth = $dstWidth|0;
 $dstHeight = $dstHeight|0;
 $fillRest = $fillRest|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dstPtr$0$lcssa = 0, $dstPtr$011 = 0, $dstPtr$011$us = 0, $phitmp = 0, $smax13 = 0, $split = 0, $srcPtr$010 = 0, $srcPtr$010$us = 0, $y$012 = 0, $y$012$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($format|0) {
 case 10: case 34: case 35: case 41: case 45: case 46:  {
  $10 = 8;
  break;
 }
 default: {
  $0 = ($format|0)==(42);
  $phitmp = $0 ? 8 : 16;
  $10 = $phitmp;
 }
 }
 $1 = (($srcWidth) + 3)|0;
 $2 = (($1|0) / 4)&-1;
 $3 = (($srcHeight) + 3)|0;
 $4 = (($3|0) / 4)&-1;
 $5 = (($dstWidth) + 3)|0;
 $6 = (($5|0) / 4)&-1;
 $7 = (($dstHeight) + 3)|0;
 $8 = (($7|0) / 4)&-1;
 $9 = Math_imul($2, $10)|0;
 $11 = Math_imul($6, $10)|0;
 $12 = ($srcHeight|0)>(0);
 if ($12) {
  $13 = (($11) - ($9))|0;
  $14 = ($4|0)>(1);
  $smax13 = $14 ? $4 : 1;
  if ($fillRest) {
   $dstPtr$011$us = $dst;$srcPtr$010$us = $src;$y$012$us = 0;
   while(1) {
    _memcpy(($dstPtr$011$us|0),($srcPtr$010$us|0),($9|0))|0;
    $15 = (($dstPtr$011$us) + ($9)|0);
    _memset(($15|0),0,($13|0))|0;
    $16 = (($srcPtr$010$us) + ($9)|0);
    $17 = (($dstPtr$011$us) + ($11)|0);
    $18 = (($y$012$us) + 1)|0;
    $19 = ($18|0)<($4|0);
    if ($19) {
     $dstPtr$011$us = $17;$srcPtr$010$us = $16;$y$012$us = $18;
    } else {
     break;
    }
   }
  } else {
   $dstPtr$011 = $dst;$srcPtr$010 = $src;$y$012 = 0;
   while(1) {
    _memcpy(($dstPtr$011|0),($srcPtr$010|0),($9|0))|0;
    $20 = (($srcPtr$010) + ($9)|0);
    $21 = (($dstPtr$011) + ($11)|0);
    $22 = (($y$012) + 1)|0;
    $23 = ($22|0)<($4|0);
    if ($23) {
     $dstPtr$011 = $21;$srcPtr$010 = $20;$y$012 = $22;
    } else {
     break;
    }
   }
  }
  $$pn = Math_imul($11, $smax13)|0;
  $split = (($dst) + ($$pn)|0);
  $dstPtr$0$lcssa = $split;
 } else {
  $dstPtr$0$lcssa = $dst;
 }
 if (!($fillRest)) {
  STACKTOP = sp;return;
 }
 $24 = (($8) - ($4))|0;
 $25 = Math_imul($24, $11)|0;
 _memset(($dstPtr$0$lcssa|0),0,($25|0))|0;
 STACKTOP = sp;return;
}
function __Z28BlitCopyCompressedDXT1ToDXT5PKhiiPhii($src,$srcWidth,$srcHeight,$dst,$dstWidth,$dstHeight) {
 $src = $src|0;
 $srcWidth = $srcWidth|0;
 $srcHeight = $srcHeight|0;
 $dst = $dst|0;
 $dstWidth = $dstWidth|0;
 $dstHeight = $dstHeight|0;
 var $$sum1$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dstPtr$04$us = 0, $or$cond = 0, $srcPtr$03$us = 0, $x$02$us = 0;
 var $y$06$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($srcWidth) + 3)|0;
 $1 = (($0|0) / 4)&-1;
 $2 = (($srcHeight) + 3)|0;
 $3 = (($2|0) / 4)&-1;
 $4 = (($dstWidth) + 3)|0;
 $5 = (($4|0) / 4)&-1;
 $6 = $1 << 3;
 $7 = $5 << 4;
 $8 = ($srcHeight|0)>(0);
 $9 = ($srcWidth|0)>(0);
 $or$cond = $8 & $9;
 if ($or$cond) {
  $dstPtr$04$us = $dst;$srcPtr$03$us = $src;$y$06$us = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $x$02$us = 0;
  while(1) {
   $14 = $x$02$us << 4;
   $15 = (($dstPtr$04$us) + ($14)|0);
   $16 = $15;
   $17 = $16;
   HEAP8[$17>>0]=-1&255;HEAP8[$17+1>>0]=(-1>>8)&255;HEAP8[$17+2>>0]=(-1>>16)&255;HEAP8[$17+3>>0]=-1>>24;
   $18 = (($16) + 4)|0;
   $19 = $18;
   HEAP8[$19>>0]=-1&255;HEAP8[$19+1>>0]=(-1>>8)&255;HEAP8[$19+2>>0]=(-1>>16)&255;HEAP8[$19+3>>0]=-1>>24;
   $$sum1$us = $14 | 8;
   $20 = (($dstPtr$04$us) + ($$sum1$us)|0);
   $21 = $x$02$us << 3;
   $22 = (($srcPtr$03$us) + ($21)|0);
   $23 = $22;
   $24 = $23;
   $25 = HEAPU8[$24>>0]|(HEAPU8[$24+1>>0]<<8)|(HEAPU8[$24+2>>0]<<16)|(HEAPU8[$24+3>>0]<<24);
   $26 = (($23) + 4)|0;
   $27 = $26;
   $28 = HEAPU8[$27>>0]|(HEAPU8[$27+1>>0]<<8)|(HEAPU8[$27+2>>0]<<16)|(HEAPU8[$27+3>>0]<<24);
   $29 = $20;
   $30 = $29;
   HEAP8[$30>>0]=$25&255;HEAP8[$30+1>>0]=($25>>8)&255;HEAP8[$30+2>>0]=($25>>16)&255;HEAP8[$30+3>>0]=$25>>24;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP8[$32>>0]=$28&255;HEAP8[$32+1>>0]=($28>>8)&255;HEAP8[$32+2>>0]=($28>>16)&255;HEAP8[$32+3>>0]=$28>>24;
   $33 = (($x$02$us) + 1)|0;
   $34 = ($33|0)<($1|0);
   if ($34) {
    $x$02$us = $33;
   } else {
    break;
   }
  }
  $10 = (($srcPtr$03$us) + ($6)|0);
  $11 = (($dstPtr$04$us) + ($7)|0);
  $12 = (($y$06$us) + 1)|0;
  $13 = ($12|0)<($3|0);
  if ($13) {
   $dstPtr$04$us = $11;$srcPtr$03$us = $10;$y$06$us = $12;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z14PadImageBorderR14ImageReferenceii($image,$sizeX,$sizeY) {
 $image = $image|0;
 $sizeX = $sizeX|0;
 $sizeY = $sizeY|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b$023 = 0, $b1$028 = 0;
 var $b5$03$us$us = 0, $exitcond = 0, $exitcond42 = 0, $exitcond43 = 0, $exitcond45 = 0, $exitcond46 = 0, $exitcond48 = 0, $exitcond50 = 0, $exitcond51 = 0, $pixel = 0, $ptr$031 = 0, $ptr3$04$us$us = 0, $rowptr$0$lcssa = 0, $rowptr$034 = 0, $rowptr$18 = 0, $rowptr$18$us = 0, $scevgep = 0, $x$032 = 0, $x4$05$us$us = 0, $y$036 = 0;
 var $y$19 = 0, $y$19$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pixel = sp;
 $0 = (($image) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($image) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($image) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$image>>2]|0;
 $7 = (__Z25GetBytesFromTextureFormat13TextureFormat($6)|0);
 $8 = ($sizeY|0)>(0);
 if ($8) {
  $9 = (($sizeX) + -1)|0;
  $10 = Math_imul($7, $9)|0;
  $11 = ($7|0)>(0);
  $$sum = (($10) + ($7))|0;
  $12 = ($1|0)>($sizeX|0);
  $13 = (($image) + 12|0);
  $rowptr$034 = $5;$y$036 = 0;
  while(1) {
   if ($11) {
    $b$023 = 0;
    while(1) {
     $$sum1 = (($b$023) + ($10))|0;
     $14 = (($rowptr$034) + ($$sum1)|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = (($pixel) + ($b$023)|0);
     HEAP8[$16>>0] = $15;
     $17 = (($b$023) + 1)|0;
     $exitcond42 = ($17|0)==($7|0);
     if ($exitcond42) {
      break;
     } else {
      $b$023 = $17;
     }
    }
   }
   if ($12) {
    $18 = (($rowptr$034) + ($$sum)|0);
    $ptr$031 = $18;$x$032 = $sizeX;
    while(1) {
     if ($11) {
      $b1$028 = 0;
      while(1) {
       $19 = (($pixel) + ($b1$028)|0);
       $20 = HEAP8[$19>>0]|0;
       $21 = (($ptr$031) + ($b1$028)|0);
       HEAP8[$21>>0] = $20;
       $22 = (($b1$028) + 1)|0;
       $exitcond43 = ($22|0)==($7|0);
       if ($exitcond43) {
        break;
       } else {
        $b1$028 = $22;
       }
      }
     }
     $23 = (($ptr$031) + ($7)|0);
     $24 = (($x$032) + 1)|0;
     $exitcond45 = ($24|0)==($1|0);
     if ($exitcond45) {
      break;
     } else {
      $ptr$031 = $23;$x$032 = $24;
     }
    }
   }
   $25 = HEAP32[$13>>2]|0;
   $26 = (($rowptr$034) + ($25)|0);
   $27 = (($y$036) + 1)|0;
   $exitcond46 = ($27|0)==($sizeY|0);
   if ($exitcond46) {
    $32 = $25;$rowptr$0$lcssa = $26;
    break;
   } else {
    $rowptr$034 = $26;$y$036 = $27;
   }
  }
 } else {
  $$phi$trans$insert = (($image) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $32 = $$pre;$rowptr$0$lcssa = $5;
 }
 $28 = (($sizeY) + -1)|0;
 $29 = HEAP32[$4>>2]|0;
 $30 = (($image) + 12|0);
 $31 = Math_imul($32, $28)|0;
 $33 = (($29) + ($31)|0);
 $34 = ($7|0)>(0);
 if ($34) {
  $35 = (($sizeX) + -1)|0;
  $36 = Math_imul($7, $35)|0;
  $37 = (($31) + ($36))|0;
  $scevgep = (($29) + ($37)|0);
  _memcpy(($pixel|0),($scevgep|0),($7|0))|0;
 }
 $38 = ($3|0)>($sizeY|0);
 if (!($38)) {
  STACKTOP = sp;return;
 }
 $39 = Math_imul($7, $sizeX)|0;
 $40 = ($1|0)>($sizeX|0);
 if ($40) {
  $rowptr$18$us = $rowptr$0$lcssa;$y$19$us = $sizeY;
 } else {
  $rowptr$18 = $rowptr$0$lcssa;$y$19 = $sizeY;
  while(1) {
   _memcpy(($rowptr$18|0),($33|0),($39|0))|0;
   $51 = HEAP32[$30>>2]|0;
   $52 = (($rowptr$18) + ($51)|0);
   $53 = (($y$19) + 1)|0;
   $exitcond = ($53|0)==($3|0);
   if ($exitcond) {
    break;
   } else {
    $rowptr$18 = $52;$y$19 = $53;
   }
  }
  STACKTOP = sp;return;
 }
 while(1) {
  _memcpy(($rowptr$18$us|0),($33|0),($39|0))|0;
  $44 = (($rowptr$18$us) + ($39)|0);
  if ($34) {
   $ptr3$04$us$us = $44;$x4$05$us$us = $sizeX;
   while(1) {
    $b5$03$us$us = 0;
    while(1) {
     $47 = (($pixel) + ($b5$03$us$us)|0);
     $48 = HEAP8[$47>>0]|0;
     $49 = (($ptr3$04$us$us) + ($b5$03$us$us)|0);
     HEAP8[$49>>0] = $48;
     $50 = (($b5$03$us$us) + 1)|0;
     $exitcond48 = ($50|0)==($7|0);
     if ($exitcond48) {
      break;
     } else {
      $b5$03$us$us = $50;
     }
    }
    $45 = (($ptr3$04$us$us) + ($7)|0);
    $46 = (($x4$05$us$us) + 1)|0;
    $exitcond50 = ($46|0)==($1|0);
    if ($exitcond50) {
     break;
    } else {
     $ptr3$04$us$us = $45;$x4$05$us$us = $46;
    }
   }
  }
  $41 = HEAP32[$30>>2]|0;
  $42 = (($rowptr$18$us) + ($41)|0);
  $43 = (($y$19$us) + 1)|0;
  $exitcond51 = ($43|0)==($3|0);
  if ($exitcond51) {
   break;
  } else {
   $rowptr$18$us = $42;$y$19$us = $43;
  }
 }
 STACKTOP = sp;return;
}
function __Z22CalculateMipMapCount3Diii($width,$height,$depth) {
 $width = $width|0;
 $height = $height|0;
 $depth = $depth|0;
 var $$$i = 0, $$$i2 = 0, $$$i9 = 0, $$1$i = 0, $$1$i10 = 0, $$1$i3 = 0, $$2$i = 0, $$2$i12 = 0, $$2$i5 = 0, $$mask$i = 0, $$mask$i1 = 0, $$mask$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $base$1$i = 0;
 var $base$1$i11 = 0, $base$1$i4 = 0, $base$2$i = 0, $base$2$i13 = 0, $base$2$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($width>>>0)>(65535);
 $1 = $width >>> 16;
 $$mask$i = $0 ? $1 : $width;
 $$$i = $0 ? 16 : 0;
 $2 = $$mask$i & 65280;
 $3 = ($2|0)==(0);
 if ($3) {
  $$1$i = $$mask$i;$base$1$i = $$$i;
 } else {
  $4 = $$$i | 8;
  $5 = $$mask$i >>> 8;
  $$1$i = $5;$base$1$i = $4;
 }
 $6 = $$1$i & 240;
 $7 = ($6|0)==(0);
 if ($7) {
  $$2$i = $$1$i;$base$2$i = $base$1$i;
 } else {
  $8 = (($base$1$i) + 4)|0;
  $9 = $$1$i >>> 4;
  $$2$i = $9;$base$2$i = $8;
 }
 $10 = (602544 + ($$2$i)|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11 << 24 >> 24;
 $13 = (($12) + ($base$2$i))|0;
 $14 = ($height>>>0)>(65535);
 $15 = $height >>> 16;
 $$mask$i8 = $14 ? $15 : $height;
 $$$i9 = $14 ? 16 : 0;
 $16 = $$mask$i8 & 65280;
 $17 = ($16|0)==(0);
 if ($17) {
  $$1$i10 = $$mask$i8;$base$1$i11 = $$$i9;
 } else {
  $18 = $$$i9 | 8;
  $19 = $$mask$i8 >>> 8;
  $$1$i10 = $19;$base$1$i11 = $18;
 }
 $20 = $$1$i10 & 240;
 $21 = ($20|0)==(0);
 if ($21) {
  $$2$i12 = $$1$i10;$base$2$i13 = $base$1$i11;
 } else {
  $22 = (($base$1$i11) + 4)|0;
  $23 = $$1$i10 >>> 4;
  $$2$i12 = $23;$base$2$i13 = $22;
 }
 $24 = (602544 + ($$2$i12)|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25 << 24 >> 24;
 $27 = (($26) + ($base$2$i13))|0;
 $28 = ($13|0)<($27|0);
 $29 = $28 ? $27 : $13;
 $30 = ($depth>>>0)>(65535);
 $31 = $depth >>> 16;
 $$mask$i1 = $30 ? $31 : $depth;
 $$$i2 = $30 ? 16 : 0;
 $32 = $$mask$i1 & 65280;
 $33 = ($32|0)==(0);
 if ($33) {
  $$1$i3 = $$mask$i1;$base$1$i4 = $$$i2;
 } else {
  $34 = $$$i2 | 8;
  $35 = $$mask$i1 >>> 8;
  $$1$i3 = $35;$base$1$i4 = $34;
 }
 $36 = $$1$i3 & 240;
 $37 = ($36|0)==(0);
 if ($37) {
  $$2$i5 = $$1$i3;$base$2$i6 = $base$1$i4;
  $40 = (602544 + ($$2$i5)|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41 << 24 >> 24;
  $43 = (($42) + ($base$2$i6))|0;
  $44 = ($29|0)<($43|0);
  $45 = $44 ? $43 : $29;
  $46 = (($45) + 1)|0;
  STACKTOP = sp;return ($46|0);
 }
 $38 = (($base$1$i4) + 4)|0;
 $39 = $$1$i3 >>> 4;
 $$2$i5 = $39;$base$2$i6 = $38;
 $40 = (602544 + ($$2$i5)|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41 << 24 >> 24;
 $43 = (($42) + ($base$2$i6))|0;
 $44 = ($29|0)<($43|0);
 $45 = $44 ? $43 : $29;
 $46 = (($45) + 1)|0;
 STACKTOP = sp;return ($46|0);
}
function __Z18CalculateImageSizeii13TextureFormat($width,$height,$format) {
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $format$off = 0, $or$cond21 = 0, $or$cond5 = 0, $width$op = 0, $width$op34 = 0, $width$op35 = 0, $width$op36 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($format|0) == 10) | (($format|0) == 35)) {
  $0 = (($width) + 3)|0;
  $1 = (($0|0) / 4)&-1;
  $2 = (($height) + 3)|0;
  $3 = (($2|0) / 4)&-1;
  $4 = $1 << 3;
  $5 = Math_imul($4, $3)|0;
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $format$off = (($format) + -11)|0;
 $6 = ($format$off>>>0)<(2);
 $7 = ($format|0)==(36);
 $or$cond5 = $6 | $7;
 if ($or$cond5) {
  $8 = (($width) + 3)|0;
  $9 = (($8|0) / 4)&-1;
  $10 = (($height) + 3)|0;
  $11 = (($10|0) / 4)&-1;
  $12 = $9 << 4;
  $13 = Math_imul($12, $11)|0;
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = $format & -2;
 if ((($14|0) == 32)) {
  $15 = ($width|0)<(8);
  $16 = ($height|0)<(8);
  $17 = $16 ? 8 : $height;
  $width$op34 = $width << 2;
  $18 = $15 ? 32 : $width$op34;
  $19 = Math_imul($18, $17)|0;
  $20 = (($19) + 7)|0;
  $21 = (($20|0) / 8)&-1;
  $$0 = $21;
  STACKTOP = sp;return ($$0|0);
 } else if ((($14|0) == 30)) {
  $22 = ($width|0)<(16);
  $23 = ($height|0)<(8);
  $24 = $23 ? 8 : $height;
  $width$op = $width << 1;
  $25 = $22 ? 32 : $width$op;
  $26 = Math_imul($25, $24)|0;
  $27 = (($26) + 7)|0;
  $28 = (($27|0) / 8)&-1;
  $$0 = $28;
  STACKTOP = sp;return ($$0|0);
 } else {
  switch ($format|0) {
  case 34: case 41: case 42: case 45: case 46:  {
   $29 = ($width|0)<(4);
   $30 = ($height|0)<(4);
   $31 = $30 ? 4 : $height;
   $width$op35 = $width << 2;
   $32 = $29 ? 16 : $width$op35;
   $33 = Math_imul($32, $31)|0;
   $34 = (($33) + 7)|0;
   $35 = (($34|0) / 8)&-1;
   $$0 = $35;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  default: {
  }
  }
  $36 = $format & -5;
  $37 = ($36|0)==(43);
  $38 = ($format|0)==(44);
  $or$cond21 = $37 | $38;
  if ($or$cond21) {
   $39 = ($width|0)<(4);
   $40 = ($height|0)<(4);
   $41 = $40 ? 4 : $height;
   $width$op36 = $width << 3;
   $42 = $39 ? 32 : $width$op36;
   $43 = Math_imul($42, $41)|0;
   $44 = $43 | 7;
   $45 = (($44|0) / 8)&-1;
   $$0 = $45;
   STACKTOP = sp;return ($$0|0);
  }
  switch ($format|0) {
  case 49: case 55:  {
   $54 = (($width) + 4)|0;
   $55 = (($54|0) / 5)&-1;
   $56 = (($height) + 4)|0;
   $57 = (($56|0) / 5)&-1;
   $58 = $55 << 4;
   $59 = Math_imul($58, $57)|0;
   $$0 = $59;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 50: case 56:  {
   $60 = (($width) + 5)|0;
   $61 = (($60|0) / 6)&-1;
   $62 = (($height) + 5)|0;
   $63 = (($62|0) / 6)&-1;
   $64 = $61 << 4;
   $65 = Math_imul($64, $63)|0;
   $$0 = $65;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 51: case 57:  {
   $66 = (($width) + 7)|0;
   $67 = (($66|0) / 8)&-1;
   $68 = (($height) + 7)|0;
   $69 = (($68|0) / 8)&-1;
   $70 = $67 << 4;
   $71 = Math_imul($70, $69)|0;
   $$0 = $71;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 48: case 54:  {
   $48 = (($width) + 3)|0;
   $49 = (($48|0) / 4)&-1;
   $50 = (($height) + 3)|0;
   $51 = (($50|0) / 4)&-1;
   $52 = $49 << 4;
   $53 = Math_imul($52, $51)|0;
   $$0 = $53;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 52: case 58:  {
   $72 = (($width) + 9)|0;
   $73 = (($72|0) / 10)&-1;
   $74 = (($height) + 9)|0;
   $75 = (($74|0) / 10)&-1;
   $76 = $73 << 4;
   $77 = Math_imul($76, $75)|0;
   $$0 = $77;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 53: case 59:  {
   $78 = (($width) + 11)|0;
   $79 = (($78|0) / 12)&-1;
   $80 = (($height) + 11)|0;
   $81 = (($80|0) / 12)&-1;
   $82 = $79 << 4;
   $83 = Math_imul($82, $81)|0;
   $$0 = $83;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 21:  {
   $46 = $width << 1;
   $47 = Math_imul($46, $height)|0;
   $$0 = $47;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  default: {
   $84 = (__Z29GetRowBytesFromWidthAndFormati13TextureFormat($width,$format)|0);
   $85 = Math_imul($84, $height)|0;
   $$0 = $85;
   STACKTOP = sp;return ($$0|0);
  }
  }
 }
 return 0|0;
}
function __Z21CalculateMipMapOffsetii13TextureFormati($width,$height,$format,$miplevel) {
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $miplevel = $miplevel|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $completeSize$01 = 0, $exitcond = 0, $i$02 = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $notlhs = ($width|0)!=(0);
 $notrhs = ($height|0)!=(0);
 $or$cond$not = $notrhs & $notlhs;
 $0 = ($miplevel|0)>(0);
 $or$cond3 = $or$cond$not & $0;
 if ($or$cond3) {
  $completeSize$01 = 0;$i$02 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $1 = $width >> $i$02;
  $2 = ($1|0)<(1);
  $3 = $2 ? 1 : $1;
  $4 = $height >> $i$02;
  $5 = ($4|0)<(1);
  $6 = $5 ? 1 : $4;
  $7 = (__Z18CalculateImageSizeii13TextureFormat($3,$6,$format)|0);
  $8 = (($7) + ($completeSize$01))|0;
  $9 = (($i$02) + 1)|0;
  $exitcond = ($9|0)==($miplevel|0);
  if ($exitcond) {
   $$0 = $8;
   break;
  } else {
   $completeSize$01 = $8;$i$02 = $9;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z24CalculateImageMipMapSizeii13TextureFormat($width,$height,$format) {
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $completeSize$01$i = 0, $exitcond$i = 0, $i$02$i = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$not$i = 0, $or$cond3$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__Z22CalculateMipMapCount3Diii($width,$height,1)|0);
 $notlhs$i = ($width|0)!=(0);
 $notrhs$i = ($height|0)!=(0);
 $or$cond$not$i = $notrhs$i & $notlhs$i;
 $1 = ($0|0)>(0);
 $or$cond3$i = $or$cond$not$i & $1;
 if ($or$cond3$i) {
  $completeSize$01$i = 0;$i$02$i = 0;
 } else {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 while(1) {
  $2 = $width >> $i$02$i;
  $3 = ($2|0)<(1);
  $4 = $3 ? 1 : $2;
  $5 = $height >> $i$02$i;
  $6 = ($5|0)<(1);
  $7 = $6 ? 1 : $5;
  $8 = (__Z18CalculateImageSizeii13TextureFormat($4,$7,$format)|0);
  $9 = (($8) + ($completeSize$01$i))|0;
  $10 = (($i$02$i) + 1)|0;
  $exitcond$i = ($10|0)==($0|0);
  if ($exitcond$i) {
   $$0$i = $9;
   break;
  } else {
   $completeSize$01$i = $9;$i$02$i = $10;
  }
 }
 STACKTOP = sp;return ($$0$i|0);
}
function __Z12CreateMipMapPhiii13TextureFormat($inData,$width,$height,$depth,$format) {
 $inData = $inData|0;
 $width = $width|0;
 $height = $height|0;
 $depth = $depth|0;
 $format = $format|0;
 var $$0175 = 0, $$0274 = 0, $$076 = 0, $$1$i = 0, $$1$i34 = 0, $$1$i39 = 0, $$12$i = 0, $$12$i33 = 0, $$12$i38 = 0, $$byval_copy1 = 0, $$phitmp3$i$i42 = 0, $$phitmp3$i$i4282 = 0, $$phitmp3$i$i4283 = 0, $$phitmp3$i$i4284 = 0, $$phitmp3$i$i4285 = 0, $$phitmp3$i$i4286 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $d$059 = 0, $dstPtr$056 = 0, $dstSurface$i = 0, $dstSurface$i32 = 0;
 var $dstSurface$i37 = 0, $exitcond = 0, $format$off$i$i41 = 0, $i$052 = 0, $mip$071 = 0, $not$brmerge$i$i = 0, $not$brmerge$i$i14 = 0, $not$brmerge$i$i21 = 0, $not$brmerge$i$i28 = 0, $not$brmerge$i$i45 = 0, $not$brmerge$i$i7 = 0, $or$cond$i$i19 = 0, $or$cond$i$i26 = 0, $or$cond$i$i43 = 0, $or$cond$i$i5 = 0, $or$cond1$i$i20 = 0, $or$cond1$i$i27 = 0, $or$cond1$i$i44 = 0, $or$cond1$i$i6 = 0, $phitmp3$i$i42 = 0;
 var $smax = 0, $smax81 = 0, $srcPtr$048 = 0, $srcPtr$073 = 0, $srcPtr$153 = 0, $srcSurface$i = 0, $srcSurface$i31 = 0, $srcSurface$i36 = 0, $tempBuffer$0$lcssa = 0, $tempBuffer$072 = 0, $tempBuffer$1 = 0, $tempBuffer$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $$byval_copy1 = sp + 440|0;
 $srcSurface$i36 = sp + 396|0;
 $0 = sp + 368|0;
 $dstSurface$i37 = sp + 324|0;
 $1 = sp + 296|0;
 $srcSurface$i31 = sp + 252|0;
 $2 = sp + 224|0;
 $dstSurface$i32 = sp + 180|0;
 $3 = sp + 148|0;
 $srcSurface$i = sp + 104|0;
 $4 = sp + 76|0;
 $dstSurface$i = sp + 32|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 176|0;
 $8 = (__Z25GetBytesFromTextureFormat13TextureFormat($format)|0);
 $9 = (__Z22CalculateMipMapCount3Diii($width,$height,$depth)|0);
 $10 = (($9) + -1)|0;
 $11 = ($10|0)>(0);
 if (!($11)) {
  $tempBuffer$0$lcssa = 0;
  $118 = HEAP32[628512>>2]|0;
  HEAP32[$7>>2] = $118;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$7+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($tempBuffer$0$lcssa,$$byval_copy1);
  STACKTOP = sp;return;
 }
 $12 = ($format|0)<(9);
 $13 = ($format|0)>(0);
 $format$off$i$i41 = (($format) + -13)|0;
 $phitmp3$i$i42 = ($format$off$i$i41>>>0)<(9);
 $$0175 = $height;$$0274 = $depth;$$076 = $width;$mip$071 = 0;$srcPtr$073 = $inData;$tempBuffer$072 = 0;
 L4: while(1) {
  $14 = (($$076|0) / 2)&-1;
  $15 = ($14|0)<(1);
  $16 = $15 ? 1 : $14;
  $17 = (($$0175|0) / 2)&-1;
  $18 = ($17|0)<(1);
  $19 = $18 ? 1 : $17;
  $20 = (($$0274|0) / 2)&-1;
  $21 = ($20|0)<(1);
  $22 = $21 ? 1 : $20;
  $23 = Math_imul($$076, $$0175)|0;
  $24 = Math_imul($$0274, $8)|0;
  $25 = Math_imul($24, $23)|0;
  $26 = (($srcPtr$073) + ($25)|0);
  $27 = ($$0274|0)>(1);
  if ($27) {
   $28 = ($tempBuffer$072|0)==(0|0);
   if ($28) {
    $29 = Math_imul($16, $8)|0;
    $30 = Math_imul($29, $19)|0;
    $31 = (($30) + ($8))|0;
    $32 = HEAP32[628512>>2]|0;
    HEAP32[$6>>2] = $32;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$6+0>>2]|0;
    $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($31,16,$$byval_copy1,0,602536,265)|0);
    $tempBuffer$1 = $33;
   } else {
    $tempBuffer$1 = $tempBuffer$072;
   }
   $34 = ($22|0)>(0);
   if ($34) {
    $35 = Math_imul($$076, $8)|0;
    $36 = Math_imul($23, $8)|0;
    $$sum = $36 << 1;
    $37 = Math_imul($16, $8)|0;
    $38 = ($tempBuffer$1|0)==(0|0);
    $39 = Math_imul($37, $19)|0;
    $40 = ($39|0)>(0);
    $41 = ($16|0)>(0);
    $42 = ($19|0)>(0);
    $or$cond$i$i43 = $41 & $42;
    $or$cond1$i$i44 = $or$cond$i$i43 & $13;
    $43 = ($$076|0)>(0);
    $44 = ($$0175|0)>(0);
    $or$cond$i$i5 = $43 & $44;
    $or$cond1$i$i6 = $or$cond$i$i5 & $13;
    $45 = ($14|0)>(1);
    $smax = $45 ? $14 : 1;
    $46 = Math_imul($8, $smax)|0;
    $47 = ($17|0)>(1);
    $smax81 = $47 ? $17 : 1;
    $48 = Math_imul($46, $smax81)|0;
    $d$059 = 0;$dstPtr$056 = $26;$srcPtr$153 = $srcPtr$073;
    while(1) {
     $49 = ($srcPtr$153|0)==(0|0);
     if ($49) {
      label = 10;
     } else {
      $$phitmp3$i$i42 = $12 | $phitmp3$i$i42;
      $not$brmerge$i$i = $or$cond1$i$i6 & $$phitmp3$i$i42;
      if ($not$brmerge$i$i) {
       $55 = $srcPtr$153;
      } else {
       label = 10;
      }
     }
     if ((label|0) == 10) {
      label = 0;
      $55 = 0;
     }
     $50 = (($srcPtr$153) + ($36)|0);
     $51 = ($50|0)==(0|0);
     if ($51) {
      label = 13;
     } else {
      $$phitmp3$i$i4282 = $12 | $phitmp3$i$i42;
      $not$brmerge$i$i7 = $or$cond1$i$i6 & $$phitmp3$i$i4282;
      if ($not$brmerge$i$i7) {
       $69 = $50;
      } else {
       label = 13;
      }
     }
     if ((label|0) == 13) {
      label = 0;
      $69 = 0;
     }
     $52 = (($srcPtr$153) + ($$sum)|0);
     $53 = ($dstPtr$056|0)==(0|0);
     if (!($53)) {
      $$phitmp3$i$i4283 = $12 | $phitmp3$i$i42;
      $not$brmerge$i$i14 = $or$cond1$i$i44 & $$phitmp3$i$i4283;
      if ($not$brmerge$i$i14) {
       $54 = ($55|0)==(0|0);
       if (!($54)) {
        __Z22GetProphecyPixelFormat13TextureFormat($0,$format);
        __THREW__ = 0;
        invoke_viiiiii(124,($srcSurface$i36|0),($$076|0),($$0175|0),($35|0),($0|0),($55|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 20;
         break L4;
        }
        __Z22GetProphecyPixelFormat13TextureFormat($1,$format);
        __THREW__ = 0;
        invoke_viiiiii(124,($dstSurface$i37|0),($16|0),($19|0),($37|0),($1|0),($dstPtr$056|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 21;
         break L4;
        }
        __THREW__ = 0;
        invoke_viii(1737,($dstSurface$i37|0),($srcSurface$i36|0),2);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 22;
         break L4;
        }
       }
      }
     }
     if (!($38)) {
      $$phitmp3$i$i4284 = $12 | $phitmp3$i$i42;
      $not$brmerge$i$i45 = $or$cond1$i$i44 & $$phitmp3$i$i4284;
      if ($not$brmerge$i$i45) {
       $68 = ($69|0)==(0|0);
       if (!($68)) {
        __Z22GetProphecyPixelFormat13TextureFormat($2,$format);
        __THREW__ = 0;
        invoke_viiiiii(124,($srcSurface$i31|0),($$076|0),($$0175|0),($35|0),($2|0),($69|0));
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 30;
         break L4;
        }
        __Z22GetProphecyPixelFormat13TextureFormat($3,$format);
        __THREW__ = 0;
        invoke_viiiiii(124,($dstSurface$i32|0),($16|0),($19|0),($37|0),($3|0),($tempBuffer$1|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         label = 31;
         break L4;
        }
        __THREW__ = 0;
        invoke_viii(1737,($dstSurface$i32|0),($srcSurface$i31|0),2);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 32;
         break L4;
        }
       }
      }
     }
     if ($40) {
      $i$052 = 0;
      while(1) {
       $82 = (($dstPtr$056) + ($i$052)|0);
       $83 = HEAP8[$82>>0]|0;
       $84 = $83&255;
       $85 = (($tempBuffer$1) + ($i$052)|0);
       $86 = HEAP8[$85>>0]|0;
       $87 = $86&255;
       $88 = (($87) + ($84))|0;
       $89 = $88 >>> 1;
       $90 = $89&255;
       HEAP8[$82>>0] = $90;
       $91 = (($i$052) + 1)|0;
       $exitcond = ($91|0)==($48|0);
       if ($exitcond) {
        break;
       } else {
        $i$052 = $91;
       }
      }
     }
     $92 = (($dstPtr$056) + ($39)|0);
     $93 = (($d$059) + 1)|0;
     $94 = ($93|0)<($22|0);
     if ($94) {
      $d$059 = $93;$dstPtr$056 = $92;$srcPtr$153 = $52;
     } else {
      $tempBuffer$2 = $tempBuffer$1;
      break;
     }
    }
   } else {
    $tempBuffer$2 = $tempBuffer$1;
   }
  } else {
   $95 = Math_imul($$076, $8)|0;
   $96 = ($srcPtr$073|0)==(0|0);
   if ($96) {
    label = 39;
   } else {
    $$phitmp3$i$i4285 = $12 | $phitmp3$i$i42;
    $97 = ($$076|0)>(0);
    $98 = ($$0175|0)>(0);
    $or$cond$i$i26 = $97 & $98;
    $or$cond1$i$i27 = $or$cond$i$i26 & $13;
    $not$brmerge$i$i28 = $or$cond1$i$i27 & $$phitmp3$i$i4285;
    if ($not$brmerge$i$i28) {
     $srcPtr$048 = $srcPtr$073;
    } else {
     label = 39;
    }
   }
   if ((label|0) == 39) {
    label = 0;
    $srcPtr$048 = 0;
   }
   $99 = Math_imul($16, $8)|0;
   $100 = ($26|0)==(0|0);
   if ($100) {
    $tempBuffer$2 = $tempBuffer$072;
   } else {
    $$phitmp3$i$i4286 = $12 | $phitmp3$i$i42;
    $101 = ($16|0)>(0);
    $102 = ($19|0)>(0);
    $or$cond$i$i19 = $101 & $102;
    $or$cond1$i$i20 = $or$cond$i$i19 & $13;
    $not$brmerge$i$i21 = $or$cond1$i$i20 & $$phitmp3$i$i4286;
    if ($not$brmerge$i$i21) {
     $103 = ($srcPtr$048|0)==(0|0);
     if ($103) {
      $tempBuffer$2 = $tempBuffer$072;
     } else {
      __Z22GetProphecyPixelFormat13TextureFormat($4,$format);
      __THREW__ = 0;
      invoke_viiiiii(124,($srcSurface$i|0),($$076|0),($$0175|0),($95|0),($4|0),($srcPtr$048|0));
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       label = 46;
       break;
      }
      __Z22GetProphecyPixelFormat13TextureFormat($5,$format);
      __THREW__ = 0;
      invoke_viiiiii(124,($dstSurface$i|0),($16|0),($19|0),($99|0),($5|0),($26|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       label = 47;
       break;
      }
      __THREW__ = 0;
      invoke_viii(1737,($dstSurface$i|0),($srcSurface$i|0),2);
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       label = 48;
       break;
      } else {
       $tempBuffer$2 = $tempBuffer$072;
      }
     }
    } else {
     $tempBuffer$2 = $tempBuffer$072;
    }
   }
  }
  $116 = (($mip$071) + 1)|0;
  $117 = ($116|0)<($10|0);
  if ($117) {
   $$0175 = $19;$$0274 = $22;$$076 = $16;$mip$071 = $116;$srcPtr$073 = $26;$tempBuffer$072 = $tempBuffer$2;
  } else {
   $tempBuffer$0$lcssa = $tempBuffer$2;
   label = 51;
   break;
  }
 }
 switch (label|0) {
  case 20: {
   $62 = ___cxa_find_matching_catch()|0;
   $63 = tempRet0;
   $$1$i39 = $63;$$12$i38 = $62;
   ___resumeException($$12$i38|0);
   // unreachable;
   break;
  }
  case 21: {
   $64 = ___cxa_find_matching_catch()|0;
   $65 = tempRet0;
   $$1$i39 = $65;$$12$i38 = $64;
   ___resumeException($$12$i38|0);
   // unreachable;
   break;
  }
  case 22: {
   $66 = ___cxa_find_matching_catch()|0;
   $67 = tempRet0;
   $$1$i39 = $67;$$12$i38 = $66;
   ___resumeException($$12$i38|0);
   // unreachable;
   break;
  }
  case 30: {
   $76 = ___cxa_find_matching_catch()|0;
   $77 = tempRet0;
   $$1$i34 = $77;$$12$i33 = $76;
   ___resumeException($$12$i33|0);
   // unreachable;
   break;
  }
  case 31: {
   $78 = ___cxa_find_matching_catch()|0;
   $79 = tempRet0;
   $$1$i34 = $79;$$12$i33 = $78;
   ___resumeException($$12$i33|0);
   // unreachable;
   break;
  }
  case 32: {
   $80 = ___cxa_find_matching_catch()|0;
   $81 = tempRet0;
   $$1$i34 = $81;$$12$i33 = $80;
   ___resumeException($$12$i33|0);
   // unreachable;
   break;
  }
  case 46: {
   $110 = ___cxa_find_matching_catch()|0;
   $111 = tempRet0;
   $$1$i = $111;$$12$i = $110;
   ___resumeException($$12$i|0);
   // unreachable;
   break;
  }
  case 47: {
   $112 = ___cxa_find_matching_catch()|0;
   $113 = tempRet0;
   $$1$i = $113;$$12$i = $112;
   ___resumeException($$12$i|0);
   // unreachable;
   break;
  }
  case 48: {
   $114 = ___cxa_find_matching_catch()|0;
   $115 = tempRet0;
   $$1$i = $115;$$12$i = $114;
   ___resumeException($$12$i|0);
   // unreachable;
   break;
  }
  case 51: {
   $118 = HEAP32[628512>>2]|0;
   HEAP32[$7>>2] = $118;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$7+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($tempBuffer$0$lcssa,$$byval_copy1);
   STACKTOP = sp;return;
   break;
  }
 }
}
function __ZN14ImageReference9BlitImageERKS_NS_8BlitModeE($this,$source,$mode) {
 $this = $this|0;
 $source = $source|0;
 $mode = $mode|0;
 var $$1 = 0, $$12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dstSurface = 0, $srcSurface = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $srcSurface = sp + 100|0;
 $0 = sp;
 $dstSurface = sp + 28|0;
 $1 = sp + 72|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($source) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($source) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($source) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($source) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$source>>2]|0;
 __Z22GetProphecyPixelFormat13TextureFormat($0,$14);
 $15 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(124,($srcSurface|0),($9|0),($11|0),($13|0),($0|0),($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $$1 = $31;$$12 = $30;
  ___resumeException($$12|0);
  // unreachable;
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$this>>2]|0;
 __Z22GetProphecyPixelFormat13TextureFormat($1,$24);
 $25 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(124,($dstSurface|0),($19|0),($21|0),($23|0),($1|0),($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  $$1 = $33;$$12 = $32;
  ___resumeException($$12|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viii(1737,($dstSurface|0),($srcSurface|0),($mode|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  STACKTOP = sp;return;
 }
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 $$1 = $35;$$12 = $34;
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN14ImageReferenceC2Eiii13TextureFormatPv($this,$width,$height,$rowbytes,$format,$image) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $rowbytes = $rowbytes|0;
 $format = $format|0;
 $image = $image|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i = 0, $not$brmerge$i = 0, $or$cond$i = 0, $or$cond1$i = 0, $phitmp3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $width;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $height;
 HEAP32[$this>>2] = $format;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $rowbytes;
 $3 = ($image|0)==(0|0);
 if (!($3)) {
  $4 = ($format|0)<(9);
  if ($4) {
   $8 = 1;
  } else {
   $format$off$i = (($format) + -13)|0;
   $phitmp3$i = ($format$off$i>>>0)<(9);
   $8 = $phitmp3$i;
  }
  $5 = ($width|0)>(0);
  $6 = ($height|0)>(0);
  $or$cond$i = $5 & $6;
  $7 = ($format|0)>(0);
  $or$cond1$i = $or$cond$i & $7;
  $not$brmerge$i = $or$cond1$i & $8;
  if ($not$brmerge$i) {
   $9 = (($this) + 16|0);
   HEAP32[$9>>2] = $image;
   STACKTOP = sp;return;
  }
 }
 $10 = (($this) + 16|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14ImageReference10FlipImageYEv($this) {
 $this = $this|0;
 var $$01 = 0, $$sink$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $srcSurface = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $srcSurface = sp + 28|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 __Z22GetProphecyPixelFormat13TextureFormat($0,$10);
 $11 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(124,($srcSurface|0),($5|0),($7|0),($9|0),($0|0),($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $$01 = $16;$$sink$index2 = $17;
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3480,($srcSurface|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $$01 = $18;$$sink$index2 = $19;
 ___resumeException($$01|0);
 // unreachable;
}
function __Z22GetProphecyPixelFormat13TextureFormat($agg$result,$format) {
 $agg$result = $agg$result|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($format|0) {
  case 8:  {
   HEAP32[$agg$result>>2] = -1879048168;
   $92 = (($agg$result) + 4|0);
   HEAP32[$92>>2] = 16711680;
   $93 = (($agg$result) + 8|0);
   HEAP32[$93>>2] = 65280;
   $94 = (($agg$result) + 12|0);
   HEAP32[$94>>2] = 255;
   $95 = (($agg$result) + 16|0);
   HEAP32[$95>>2] = 0;
   $96 = (($agg$result) + 22|0);
   $97 = (($agg$result) + 26|0);
   HEAP8[$97>>0] = 23;
   HEAP8[$96>>0] = 8;
   $98 = (($agg$result) + 21|0);
   $99 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$98,$99);
   $100 = (($agg$result) + 20|0);
   $101 = (($agg$result) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$100,$101);
   $102 = (($agg$result) + 23|0);
   $103 = (($agg$result) + 27|0);
   HEAP8[$103>>0] = -1;
   HEAP8[$102>>0] = 0;
   STACKTOP = sp;return;
   break;
  }
  case 19:  {
   HEAP32[$agg$result>>2] = 805306432;
   $164 = (($agg$result) + 4|0);
   HEAP32[$164>>2] = 1;
   $165 = (($agg$result) + 8|0);
   HEAP32[$165>>2] = 2;
   $166 = (($agg$result) + 12|0);
   HEAP32[$166>>2] = 0;
   $167 = (($agg$result) + 16|0);
   HEAP32[$167>>2] = 0;
   $168 = (($agg$result) + 22|0);
   $169 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,1,$168,$169);
   $170 = (($agg$result) + 21|0);
   $171 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,2,$170,$171);
   $172 = (($agg$result) + 20|0);
   $173 = (($agg$result) + 24|0);
   HEAP8[$173>>0] = -1;
   HEAP8[$172>>0] = 0;
   $174 = (($agg$result) + 23|0);
   $175 = (($agg$result) + 27|0);
   HEAP8[$175>>0] = -1;
   HEAP8[$174>>0] = 0;
   STACKTOP = sp;return;
   break;
  }
  case 5:  {
   HEAP32[$agg$result>>2] = -1879048160;
   $68 = (($agg$result) + 4|0);
   HEAP32[$68>>2] = 65280;
   $69 = (($agg$result) + 8|0);
   HEAP32[$69>>2] = 16711680;
   $70 = (($agg$result) + 12|0);
   HEAP32[$70>>2] = -16777216;
   $71 = (($agg$result) + 16|0);
   HEAP32[$71>>2] = 255;
   $72 = (($agg$result) + 22|0);
   $73 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$72,$73);
   $74 = (($agg$result) + 21|0);
   $75 = (($agg$result) + 25|0);
   HEAP8[$75>>0] = 23;
   HEAP8[$74>>0] = 8;
   $76 = (($agg$result) + 20|0);
   $77 = (($agg$result) + 24|0);
   HEAP8[$77>>0] = 31;
   HEAP8[$76>>0] = 8;
   $78 = (($agg$result) + 23|0);
   $79 = (($agg$result) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$78,$79);
   STACKTOP = sp;return;
   break;
  }
  case 14:  {
   HEAP32[$agg$result>>2] = -1879048160;
   $56 = (($agg$result) + 4|0);
   HEAP32[$56>>2] = 16711680;
   $57 = (($agg$result) + 8|0);
   HEAP32[$57>>2] = 65280;
   $58 = (($agg$result) + 12|0);
   HEAP32[$58>>2] = 255;
   $59 = (($agg$result) + 16|0);
   HEAP32[$59>>2] = -16777216;
   $60 = (($agg$result) + 22|0);
   $61 = (($agg$result) + 26|0);
   HEAP8[$61>>0] = 23;
   HEAP8[$60>>0] = 8;
   $62 = (($agg$result) + 21|0);
   $63 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$62,$63);
   $64 = (($agg$result) + 20|0);
   $65 = (($agg$result) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$64,$65);
   $66 = (($agg$result) + 23|0);
   $67 = (($agg$result) + 27|0);
   HEAP8[$67>>0] = 31;
   HEAP8[$66>>0] = 8;
   STACKTOP = sp;return;
   break;
  }
  case 1:  {
   HEAP32[$agg$result>>2] = -2013265912;
   $0 = (($agg$result) + 4|0);
   HEAP32[$0>>2] = 0;
   $1 = (($agg$result) + 8|0);
   HEAP32[$1>>2] = 0;
   $2 = (($agg$result) + 12|0);
   HEAP32[$2>>2] = 0;
   $3 = (($agg$result) + 16|0);
   HEAP32[$3>>2] = 255;
   $4 = (($agg$result) + 20|0);
   HEAP32[$4>>2] = 0;
   $5 = (($agg$result) + 24|0);
   HEAP32[$5>>2] = 0;
   HEAP8[$5>>0] = -1;
   HEAP8[$4>>0] = 0;
   $6 = (($agg$result) + 23|0);
   $7 = (($agg$result) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$6,$7);
   STACKTOP = sp;return;
   break;
  }
  case 7:  {
   HEAP32[$agg$result>>2] = -1879048176;
   $32 = (($agg$result) + 4|0);
   HEAP32[$32>>2] = 63488;
   $33 = (($agg$result) + 8|0);
   HEAP32[$33>>2] = 2016;
   $34 = (($agg$result) + 12|0);
   HEAP32[$34>>2] = 31;
   $35 = (($agg$result) + 16|0);
   HEAP32[$35>>2] = 0;
   $36 = (($agg$result) + 22|0);
   $37 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,63488,$36,$37);
   $38 = (($agg$result) + 21|0);
   $39 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,2016,$38,$39);
   $40 = (($agg$result) + 20|0);
   $41 = (($agg$result) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,31,$40,$41);
   $42 = (($agg$result) + 23|0);
   $43 = (($agg$result) + 27|0);
   HEAP8[$43>>0] = -1;
   HEAP8[$42>>0] = 0;
   STACKTOP = sp;return;
   break;
  }
  case 15:  {
   HEAP32[$agg$result>>2] = 1342177296;
   $116 = (($agg$result) + 4|0);
   HEAP32[$116>>2] = 1;
   $117 = (($agg$result) + 8|0);
   HEAP32[$117>>2] = 0;
   $118 = (($agg$result) + 12|0);
   HEAP32[$118>>2] = 0;
   $119 = (($agg$result) + 16|0);
   HEAP32[$119>>2] = 0;
   $120 = (($agg$result) + 22|0);
   $121 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,1,$120,$121);
   $122 = (($agg$result) + 21|0);
   $123 = (($agg$result) + 25|0);
   HEAP8[$123>>0] = -1;
   HEAP8[$122>>0] = 0;
   $124 = (($agg$result) + 20|0);
   $125 = (($agg$result) + 24|0);
   HEAP8[$125>>0] = -1;
   HEAP8[$124>>0] = 0;
   $126 = (($agg$result) + 23|0);
   $127 = (($agg$result) + 27|0);
   HEAP8[$127>>0] = -1;
   HEAP8[$126>>0] = 0;
   STACKTOP = sp;return;
   break;
  }
  case 13:  {
   HEAP32[$agg$result>>2] = -1879048176;
   $20 = (($agg$result) + 4|0);
   HEAP32[$20>>2] = 61440;
   $21 = (($agg$result) + 8|0);
   HEAP32[$21>>2] = 3840;
   $22 = (($agg$result) + 12|0);
   HEAP32[$22>>2] = 240;
   $23 = (($agg$result) + 16|0);
   HEAP32[$23>>2] = 15;
   $24 = (($agg$result) + 22|0);
   $25 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,61440,$24,$25);
   $26 = (($agg$result) + 21|0);
   $27 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,3840,$26,$27);
   $28 = (($agg$result) + 20|0);
   $29 = (($agg$result) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,240,$28,$29);
   $30 = (($agg$result) + 23|0);
   $31 = (($agg$result) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,15,$30,$31);
   STACKTOP = sp;return;
   break;
  }
  case 16:  {
   HEAP32[$agg$result>>2] = 1342177312;
   $128 = (($agg$result) + 4|0);
   HEAP32[$128>>2] = 1;
   $129 = (($agg$result) + 8|0);
   HEAP32[$129>>2] = 2;
   $130 = (($agg$result) + 12|0);
   HEAP32[$130>>2] = 0;
   $131 = (($agg$result) + 16|0);
   HEAP32[$131>>2] = 0;
   $132 = (($agg$result) + 22|0);
   $133 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,1,$132,$133);
   $134 = (($agg$result) + 21|0);
   $135 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,2,$134,$135);
   $136 = (($agg$result) + 20|0);
   $137 = (($agg$result) + 24|0);
   HEAP8[$137>>0] = -1;
   HEAP8[$136>>0] = 0;
   $138 = (($agg$result) + 23|0);
   $139 = (($agg$result) + 27|0);
   HEAP8[$139>>0] = -1;
   HEAP8[$138>>0] = 0;
   STACKTOP = sp;return;
   break;
  }
  case 2:  {
   HEAP32[$agg$result>>2] = -1879048176;
   $8 = (($agg$result) + 4|0);
   HEAP32[$8>>2] = 3840;
   $9 = (($agg$result) + 8|0);
   HEAP32[$9>>2] = 240;
   $10 = (($agg$result) + 12|0);
   HEAP32[$10>>2] = 15;
   $11 = (($agg$result) + 16|0);
   HEAP32[$11>>2] = 61440;
   $12 = (($agg$result) + 22|0);
   $13 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,3840,$12,$13);
   $14 = (($agg$result) + 21|0);
   $15 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,240,$14,$15);
   $16 = (($agg$result) + 20|0);
   $17 = (($agg$result) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,15,$16,$17);
   $18 = (($agg$result) + 23|0);
   $19 = (($agg$result) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,61440,$18,$19);
   STACKTOP = sp;return;
   break;
  }
  case 17:  {
   HEAP32[$agg$result>>2] = 1342177344;
   $140 = (($agg$result) + 4|0);
   HEAP32[$140>>2] = 1;
   $141 = (($agg$result) + 8|0);
   HEAP32[$141>>2] = 2;
   $142 = (($agg$result) + 12|0);
   HEAP32[$142>>2] = 4;
   $143 = (($agg$result) + 16|0);
   HEAP32[$143>>2] = 8;
   $144 = (($agg$result) + 22|0);
   $145 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,1,$144,$145);
   $146 = (($agg$result) + 21|0);
   $147 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,2,$146,$147);
   $148 = (($agg$result) + 20|0);
   $149 = (($agg$result) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,4,$148,$149);
   $150 = (($agg$result) + 23|0);
   $151 = (($agg$result) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,8,$150,$151);
   STACKTOP = sp;return;
   break;
  }
  case 18:  {
   HEAP32[$agg$result>>2] = 805306400;
   $152 = (($agg$result) + 4|0);
   HEAP32[$152>>2] = 1;
   $153 = (($agg$result) + 8|0);
   HEAP32[$153>>2] = 0;
   $154 = (($agg$result) + 12|0);
   HEAP32[$154>>2] = 0;
   $155 = (($agg$result) + 16|0);
   HEAP32[$155>>2] = 0;
   $156 = (($agg$result) + 22|0);
   $157 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,1,$156,$157);
   $158 = (($agg$result) + 21|0);
   $159 = (($agg$result) + 25|0);
   HEAP8[$159>>0] = -1;
   HEAP8[$158>>0] = 0;
   $160 = (($agg$result) + 20|0);
   $161 = (($agg$result) + 24|0);
   HEAP8[$161>>0] = -1;
   HEAP8[$160>>0] = 0;
   $162 = (($agg$result) + 23|0);
   $163 = (($agg$result) + 27|0);
   HEAP8[$163>>0] = -1;
   HEAP8[$162>>0] = 0;
   STACKTOP = sp;return;
   break;
  }
  case 20:  {
   HEAP32[$agg$result>>2] = 805306496;
   $176 = (($agg$result) + 4|0);
   HEAP32[$176>>2] = 1;
   $177 = (($agg$result) + 8|0);
   HEAP32[$177>>2] = 2;
   $178 = (($agg$result) + 12|0);
   HEAP32[$178>>2] = 4;
   $179 = (($agg$result) + 16|0);
   HEAP32[$179>>2] = 8;
   $180 = (($agg$result) + 22|0);
   $181 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,1,$180,$181);
   $182 = (($agg$result) + 21|0);
   $183 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,2,$182,$183);
   $184 = (($agg$result) + 20|0);
   $185 = (($agg$result) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,4,$184,$185);
   $186 = (($agg$result) + 23|0);
   $187 = (($agg$result) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,8,$186,$187);
   STACKTOP = sp;return;
   break;
  }
  case 4:  {
   HEAP32[$agg$result>>2] = -1879048160;
   $44 = (($agg$result) + 4|0);
   HEAP32[$44>>2] = 255;
   $45 = (($agg$result) + 8|0);
   HEAP32[$45>>2] = 65280;
   $46 = (($agg$result) + 12|0);
   HEAP32[$46>>2] = 16711680;
   $47 = (($agg$result) + 16|0);
   HEAP32[$47>>2] = -16777216;
   $48 = (($agg$result) + 22|0);
   $49 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$48,$49);
   $50 = (($agg$result) + 21|0);
   $51 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$50,$51);
   $52 = (($agg$result) + 20|0);
   $53 = (($agg$result) + 24|0);
   HEAP8[$53>>0] = 23;
   HEAP8[$52>>0] = 8;
   $54 = (($agg$result) + 23|0);
   $55 = (($agg$result) + 27|0);
   HEAP8[$55>>0] = 31;
   HEAP8[$54>>0] = 8;
   STACKTOP = sp;return;
   break;
  }
  case 6:  {
   HEAP32[$agg$result>>2] = 805306496;
   $104 = (($agg$result) + 4|0);
   HEAP32[$104>>2] = 2;
   $105 = (($agg$result) + 8|0);
   HEAP32[$105>>2] = 4;
   $106 = (($agg$result) + 12|0);
   HEAP32[$106>>2] = 8;
   $107 = (($agg$result) + 16|0);
   HEAP32[$107>>2] = 1;
   $108 = (($agg$result) + 22|0);
   $109 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,2,$108,$109);
   $110 = (($agg$result) + 21|0);
   $111 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,4,$110,$111);
   $112 = (($agg$result) + 20|0);
   $113 = (($agg$result) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,8,$112,$113);
   $114 = (($agg$result) + 23|0);
   $115 = (($agg$result) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,1,$114,$115);
   STACKTOP = sp;return;
   break;
  }
  case 3:  {
   HEAP32[$agg$result>>2] = -1879048168;
   $80 = (($agg$result) + 4|0);
   HEAP32[$80>>2] = 255;
   $81 = (($agg$result) + 8|0);
   HEAP32[$81>>2] = 65280;
   $82 = (($agg$result) + 12|0);
   HEAP32[$82>>2] = 16711680;
   $83 = (($agg$result) + 16|0);
   HEAP32[$83>>2] = 0;
   $84 = (($agg$result) + 22|0);
   $85 = (($agg$result) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$84,$85);
   $86 = (($agg$result) + 21|0);
   $87 = (($agg$result) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$86,$87);
   $88 = (($agg$result) + 20|0);
   $89 = (($agg$result) + 24|0);
   HEAP8[$89>>0] = 23;
   HEAP8[$88>>0] = 8;
   $90 = (($agg$result) + 23|0);
   $91 = (($agg$result) + 27|0);
   HEAP8[$91>>0] = -1;
   HEAP8[$90>>0] = 0;
   STACKTOP = sp;return;
   break;
  }
  default: {
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;
   STACKTOP = sp;return;
  }
  }
 } while(0);
}
function __ZNK14ImageReference9ClipImageEiiii($agg$result,$this,$x,$y,$width,$height) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $width = $width|0;
 $height = $height|0;
 var $$$i = 0, $$$i1 = 0, $$0$i = 0, $$0$i2 = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0, $not$brmerge$i$i = 0, $or$cond$i$i = 0, $or$cond1$i$i = 0, $phitmp3$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $41 = HEAP32[$this>>2]|0;
  $42 = (($agg$result) + 4|0);
  HEAP32[$42>>2] = 0;
  $43 = (($agg$result) + 8|0);
  HEAP32[$43>>2] = 0;
  HEAP32[$agg$result>>2] = $41;
  $44 = (($agg$result) + 12|0);
  HEAP32[$44>>2] = 0;
  $45 = (($agg$result) + 16|0);
  HEAP32[$45>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = ($x|0)<(0);
 if ($4) {
  $$0$i = 0;
 } else {
  $5 = HEAP32[$3>>2]|0;
  $6 = ($5|0)<($x|0);
  $$$i = $6 ? $5 : $x;
  $$0$i = $$$i;
 }
 $7 = (($this) + 8|0);
 $8 = ($y|0)<(0);
 $$pre = HEAP32[$7>>2]|0;
 if ($8) {
  $$0$i2 = 0;
 } else {
  $9 = ($$pre|0)<($y|0);
  $$$i1 = $9 ? $$pre : $y;
  $$0$i2 = $$$i1;
 }
 $10 = (($$0$i) + ($width))|0;
 $11 = HEAP32[$3>>2]|0;
 $12 = ($10|0)<($11|0);
 $13 = $12 ? $10 : $11;
 $14 = (($13) - ($$0$i))|0;
 $15 = (($$0$i2) + ($height))|0;
 $16 = ($15|0)<($$pre|0);
 $17 = $16 ? $15 : $$pre;
 $18 = (($17) - ($$0$i2))|0;
 $19 = ($14|0)>(0);
 $20 = $19 ? $14 : 0;
 $21 = ($18|0)>(0);
 $22 = $21 ? $18 : 0;
 $23 = HEAP32[$this>>2]|0;
 $24 = (__Z25GetBytesFromTextureFormat13TextureFormat($23)|0);
 $25 = (($this) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$0>>2]|0;
 $29 = Math_imul($24, $$0$i)|0;
 $30 = Math_imul($26, $$0$i2)|0;
 $$sum = (($30) + ($29))|0;
 $31 = (($28) + ($$sum)|0);
 $32 = (($agg$result) + 4|0);
 HEAP32[$32>>2] = $20;
 $33 = (($agg$result) + 8|0);
 HEAP32[$33>>2] = $22;
 HEAP32[$agg$result>>2] = $27;
 $34 = (($agg$result) + 12|0);
 HEAP32[$34>>2] = $26;
 $35 = ($31|0)==(0|0);
 if (!($35)) {
  $36 = ($27|0)<(9);
  if ($36) {
   $38 = 1;
  } else {
   $format$off$i$i = (($27) + -13)|0;
   $phitmp3$i$i = ($format$off$i$i>>>0)<(9);
   $38 = $phitmp3$i$i;
  }
  $or$cond$i$i = $19 & $21;
  $37 = ($27|0)>(0);
  $or$cond1$i$i = $or$cond$i$i & $37;
  $not$brmerge$i$i = $or$cond1$i$i & $38;
  if ($not$brmerge$i$i) {
   $39 = (($agg$result) + 16|0);
   HEAP32[$39>>2] = $31;
   STACKTOP = sp;return;
  }
 }
 $40 = (($agg$result) + 16|0);
 HEAP32[$40>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5ImageC2Eii13TextureFormat($this,$width,$height,$format) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $format$off$i = 0, $not$brmerge$i = 0, $or$cond$i = 0, $or$cond1$i = 0, $phitmp3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $height;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $width;
 HEAP32[$this>>2] = $format;
 $3 = (__Z25GetBytesFromTextureFormat13TextureFormat($format)|0);
 $4 = HEAP32[$2>>2]|0;
 $5 = Math_imul($4, $3)|0;
 $6 = (($this) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = ($format|0)<(9);
 if ($7) {
  $11 = 1;
 } else {
  $format$off$i = (($format) + -13)|0;
  $phitmp3$i = ($format$off$i>>>0)<(9);
  $11 = $phitmp3$i;
 }
 $8 = ($width|0)>(0);
 $9 = ($height|0)>(0);
 $or$cond$i = $8 & $9;
 $10 = ($format|0)>(0);
 $or$cond1$i = $or$cond$i & $10;
 $not$brmerge$i = $or$cond1$i & $11;
 if ($not$brmerge$i) {
  $12 = HEAP32[$1>>2]|0;
  $13 = Math_imul($12, $5)|0;
  $14 = HEAP32[$this>>2]|0;
  $15 = (__Z19GetMaxBytesPerPixel13TextureFormat($14)|0);
  $16 = (($15) + ($13))|0;
  $17 = HEAP32[628224>>2]|0;
  HEAP32[$0>>2] = $17;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($16,16,$$byval_copy,0,602536,441)|0);
  $19 = (($this) + 16|0);
  HEAP32[$19>>2] = $18;
  STACKTOP = sp;return;
 } else {
  $20 = (($this) + 16|0);
  HEAP32[$20>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN5Image8SetImageEii13TextureFormatb($this,$width,$height,$format,$shrinkAllowed) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $shrinkAllowed = $shrinkAllowed|0;
 var $$byval_copy1 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i = 0, $not$brmerge$i = 0;
 var $or$cond$i = 0, $or$cond$not = 0, $or$cond1$i = 0, $or$cond2 = 0, $or$cond3 = 0, $phitmp3$i = 0, $shrinkAllowed$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_imul($5, $3)|0;
 $7 = HEAP32[$this>>2]|0;
 $8 = (__Z25GetBytesFromTextureFormat13TextureFormat($7)|0);
 $9 = (($8) + ($6))|0;
 $10 = (($this) + 4|0);
 HEAP32[$10>>2] = $width;
 HEAP32[$4>>2] = $height;
 HEAP32[$this>>2] = $format;
 $11 = (__Z25GetBytesFromTextureFormat13TextureFormat($format)|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = Math_imul($12, $11)|0;
 HEAP32[$2>>2] = $13;
 $14 = HEAP32[$4>>2]|0;
 $15 = Math_imul($13, $14)|0;
 $16 = (($15) + ($11))|0;
 $shrinkAllowed$not = $shrinkAllowed ^ 1;
 $$not = ($9|0)>=($16|0);
 $or$cond$not = $$not | $shrinkAllowed;
 $17 = ($9|0)==($16|0);
 $or$cond2 = $17 | $shrinkAllowed$not;
 $or$cond3 = $or$cond$not & $or$cond2;
 if ($or$cond3) {
  STACKTOP = sp;return;
 }
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[628224>>2]|0;
 HEAP32[$0>>2] = $20;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy1);
 HEAP32[$18>>2] = 0;
 $21 = HEAP32[$this>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = HEAP32[$10>>2]|0;
 $24 = HEAP32[$4>>2]|0;
 $25 = ($21|0)<(9);
 if ($25) {
  $29 = 1;
 } else {
  $format$off$i = (($21) + -13)|0;
  $phitmp3$i = ($format$off$i>>>0)<(9);
  $29 = $phitmp3$i;
 }
 $26 = ($23|0)>(0);
 $27 = ($24|0)>(0);
 $or$cond$i = $26 & $27;
 $28 = ($21|0)>(0);
 $or$cond1$i = $or$cond$i & $28;
 $not$brmerge$i = $or$cond1$i & $29;
 if (!($not$brmerge$i)) {
  STACKTOP = sp;return;
 }
 $30 = HEAP32[$2>>2]|0;
 $31 = Math_imul($24, $30)|0;
 $32 = (__Z19GetMaxBytesPerPixel13TextureFormat($21)|0);
 $33 = (($32) + ($31))|0;
 $34 = HEAP32[628224>>2]|0;
 HEAP32[$1>>2] = $34;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $35 = (__Z15malloc_internaljj10MemLabelIdiPKci($33,16,$$byval_copy1,0,602536,482)|0);
 HEAP32[$18>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN5Image13ReformatImageERK14ImageReferenceii13TextureFormatNS0_8BlitModeE($this,$image,$width,$height,$format,$mode) {
 $this = $this|0;
 $image = $image|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $mode = $mode|0;
 var $$1$i = 0, $$12$i = 0, $$byval_copy1 = 0, $$pre$phiZ2D = 0, $$pre$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dstSurface$i = 0, $format$off$i = 0, $format$off$i$i = 0, $newImageData$024 = 0, $newImageData$03 = 0, $not$brmerge$i = 0;
 var $or$cond = 0, $or$cond$i = 0, $or$cond1$i = 0, $phitmp3$i = 0, $phitmp3$i$i = 0, $srcSurface$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy1 = sp + 152|0;
 $srcSurface$i = sp;
 $0 = sp + 44|0;
 $dstSurface$i = sp + 72|0;
 $1 = sp + 116|0;
 $2 = sp + 144|0;
 $3 = sp + 148|0;
 $4 = (__Z25GetBytesFromTextureFormat13TextureFormat($format)|0);
 $5 = Math_imul($4, $width)|0;
 $6 = ($format|0)<(9);
 if ($6) {
  $10 = 1;
 } else {
  $format$off$i = (($format) + -13)|0;
  $phitmp3$i = ($format$off$i>>>0)<(9);
  $10 = $phitmp3$i;
 }
 $7 = ($width|0)>(0);
 $8 = ($height|0)>(0);
 $or$cond$i = $7 & $8;
 $9 = ($format|0)>(0);
 $or$cond1$i = $or$cond$i & $9;
 $not$brmerge$i = $or$cond1$i & $10;
 if ($not$brmerge$i) {
  $11 = Math_imul($5, $height)|0;
  $12 = HEAP32[$this>>2]|0;
  $13 = (__Z19GetMaxBytesPerPixel13TextureFormat($12)|0);
  $14 = (($13) + ($11))|0;
  $15 = HEAP32[628224>>2]|0;
  HEAP32[$2>>2] = $15;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,16,$$byval_copy1,0,602536,503)|0);
  $17 = ($16|0)==(0|0);
  if ($17) {
   $$pre$pre$phiZZ2D = $this;$newImageData$03 = 0;
   label = 7;
  } else {
   $format$off$i$i = (($format) + -13)|0;
   $phitmp3$i$i = ($format$off$i$i>>>0)<(9);
   $or$cond = $6 | $phitmp3$i$i;
   if ($or$cond) {
    $18 = (($image) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     $$pre$phiZ2D = $this;$47 = $1;$48 = $0;$newImageData$024 = $16;
    } else {
     $21 = (($image) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($image) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($image) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$image>>2]|0;
     __Z22GetProphecyPixelFormat13TextureFormat($0,$27);
     $28 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     invoke_viiiiii(124,($srcSurface$i|0),($22|0),($24|0),($26|0),($0|0),($28|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      $35 = ___cxa_find_matching_catch()|0;
      $36 = tempRet0;
      $$1$i = $36;$$12$i = $35;
      ___resumeException($$12$i|0);
      // unreachable;
     }
     __Z22GetProphecyPixelFormat13TextureFormat($1,$format);
     __THREW__ = 0;
     invoke_viiiiii(124,($dstSurface$i|0),($width|0),($height|0),($5|0),($1|0),($16|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $37 = ___cxa_find_matching_catch()|0;
      $38 = tempRet0;
      $$1$i = $38;$$12$i = $37;
      ___resumeException($$12$i|0);
      // unreachable;
     }
     __THREW__ = 0;
     invoke_viii(1737,($dstSurface$i|0),($srcSurface$i|0),($mode|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      $39 = ___cxa_find_matching_catch()|0;
      $40 = tempRet0;
      $$1$i = $40;$$12$i = $39;
      ___resumeException($$12$i|0);
      // unreachable;
     } else {
      $$pre$phiZ2D = $this;$47 = $1;$48 = $0;$newImageData$024 = $16;
     }
    }
   } else {
    $$pre$pre$phiZZ2D = $this;$newImageData$03 = $16;
    label = 7;
   }
  }
 } else {
  $$pre$pre$phiZZ2D = $this;$newImageData$03 = 0;
  label = 7;
 }
 if ((label|0) == 7) {
  $$pre$phiZ2D = $$pre$pre$phiZZ2D;$47 = $1;$48 = $0;$newImageData$024 = $newImageData$03;
 }
 $41 = (($this) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[628224>>2]|0;
 HEAP32[$3>>2] = $43;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$3+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($42,$$byval_copy1);
 $44 = (($this) + 8|0);
 HEAP32[$44>>2] = $height;
 $45 = (($this) + 4|0);
 HEAP32[$45>>2] = $width;
 HEAP32[$$pre$phiZ2D>>2] = $format;
 $46 = (($this) + 12|0);
 HEAP32[$46>>2] = $5;
 HEAP32[$41>>2] = $newImageData$024;
 STACKTOP = sp;return;
}
function __ZN5Image13ReformatImageEii13TextureFormatN14ImageReference8BlitModeE($this,$width,$height,$format,$mode) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($width|0);
 if ($2) {
  $3 = (($this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($height|0);
  if ($5) {
   $6 = HEAP32[$this>>2]|0;
   $7 = ($6|0)==($format|0);
   if ($7) {
    STACKTOP = sp;return;
   }
  }
 }
 __ZN5Image13ReformatImageERK14ImageReferenceii13TextureFormatNS0_8BlitModeE($this,$this,$width,$height,$format,$mode);
 STACKTOP = sp;return;
}
function __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($agg$result,$usageMode,$activeTextureColorSpace,$linearIntensityMultiplier) {
 $agg$result = $agg$result|0;
 $usageMode = $usageMode|0;
 $activeTextureColorSpace = $activeTextureColorSpace|0;
 $linearIntensityMultiplier = Math_fround($linearIntensityMultiplier);
 var $$0$i1 = Math_fround(0), $$0$i3 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $bias$0 = Math_fround(0), $exponent$0 = Math_fround(0), $multiplier$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 L1: do {
  switch ($usageMode|0) {
  case 4:  {
   $bias$0 = Math_fround(-1.0);$exponent$0 = Math_fround(0.00999999977648258209228);$multiplier$0 = Math_fround(2.0);
   break;
  }
  case 5: case 2:  {
   $16 = ($activeTextureColorSpace|0)==(0);
   if (!($16)) {
    $17 = Math_fround($linearIntensityMultiplier * Math_fround(97.00586700439453125));
    $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(2.20000004768371582031);$multiplier$0 = $17;
    break L1;
   }
   $18 = !($linearIntensityMultiplier <= Math_fround(0.0));
   do {
    if ($18) {
     $19 = !($linearIntensityMultiplier <= Math_fround(0.0031308000907301902771));
     if (!($19)) {
      $20 = Math_fround($linearIntensityMultiplier * Math_fround(12.9200000762939453125));
      $$0$i1 = $20;
      break;
     }
     $21 = !($linearIntensityMultiplier <= Math_fround(1.0));
     $22 = (Math_fround(+(Math_pow((+$linearIntensityMultiplier),0.416660010814666748047))));
     if ($21) {
      $$0$i1 = $22;
     } else {
      $23 = Math_fround($22 * Math_fround(1.05499994754791259766));
      $24 = Math_fround($23 + Math_fround(-0.054999999701976776123));
      $$0$i1 = $24;
     }
    } else {
     $$0$i1 = Math_fround(0.0);
    }
   } while(0);
   $25 = Math_fround($$0$i1 * Math_fround(8.0));
   $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(1.0);$multiplier$0 = $25;
   break;
  }
  case 1:  {
   $8 = !($linearIntensityMultiplier <= Math_fround(0.0));
   do {
    if ($8) {
     $9 = !($linearIntensityMultiplier <= Math_fround(0.0031308000907301902771));
     if (!($9)) {
      $10 = Math_fround($linearIntensityMultiplier * Math_fround(12.9200000762939453125));
      $$0$i3 = $10;
      break;
     }
     $11 = !($linearIntensityMultiplier <= Math_fround(1.0));
     $12 = (Math_fround(+(Math_pow((+$linearIntensityMultiplier),0.416660010814666748047))));
     if ($11) {
      $$0$i3 = $12;
     } else {
      $13 = Math_fround($12 * Math_fround(1.05499994754791259766));
      $14 = Math_fround($13 + Math_fround(-0.054999999701976776123));
      $$0$i3 = $14;
     }
    } else {
     $$0$i3 = Math_fround(0.0);
    }
   } while(0);
   $15 = Math_fround($$0$i3 * Math_fround(2.0));
   $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(0.00999999977648258209228);$multiplier$0 = $15;
   break;
  }
  case 0:  {
   $0 = ($activeTextureColorSpace|0)==(0);
   if ($0) {
    $1 = !($linearIntensityMultiplier <= Math_fround(0.0));
    if ($1) {
     $2 = !($linearIntensityMultiplier <= Math_fround(0.0031308000907301902771));
     if (!($2)) {
      $3 = Math_fround($linearIntensityMultiplier * Math_fround(12.9200000762939453125));
      $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(0.00999999977648258209228);$multiplier$0 = $3;
      break L1;
     }
     $4 = !($linearIntensityMultiplier <= Math_fround(1.0));
     $5 = (Math_fround(+(Math_pow((+$linearIntensityMultiplier),0.416660010814666748047))));
     if ($4) {
      $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(0.00999999977648258209228);$multiplier$0 = $5;
     } else {
      $6 = Math_fround($5 * Math_fround(1.05499994754791259766));
      $7 = Math_fround($6 + Math_fround(-0.054999999701976776123));
      $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(0.00999999977648258209228);$multiplier$0 = $7;
     }
    } else {
     $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(0.00999999977648258209228);$multiplier$0 = Math_fround(0.0);
    }
   } else {
    $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(0.00999999977648258209228);$multiplier$0 = $linearIntensityMultiplier;
   }
   break;
  }
  default: {
   $bias$0 = Math_fround(0.0);$exponent$0 = Math_fround(0.00999999977648258209228);$multiplier$0 = Math_fround(1.0);
  }
  }
 } while(0);
 HEAPF32[$agg$result>>2] = $multiplier$0;
 $26 = (($agg$result) + 4|0);
 HEAPF32[$26>>2] = $exponent$0;
 $27 = (($agg$result) + 8|0);
 HEAPF32[$27>>2] = $bias$0;
 $28 = (($agg$result) + 12|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_($this,$mask,$count,$shift) {
 $this = $this|0;
 $mask = $mask|0;
 $count = $count|0;
 $shift = $shift|0;
 var $$$i = 0, $$$i1 = 0, $$0$i = 0, $$0$i2 = 0, $$01$i8 = 0, $$01$i9 = 0, $$1$i = 0, $$1$i4 = 0, $$2$i = 0, $$2$i6 = 0, $$3$i = 0, $$4$i = 0, $$mask$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $base$0$i = 0, $base$0$i3 = 0, $base$1$i = 0, $base$1$i5 = 0, $base$2$i = 0, $base$2$i7 = 0, $base$3$i = 0, $base$4$i = 0, $mask$$i = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mask|0)==(0);
 do {
  if ($0) {
   $$01$i9 = -1;
   label = 15;
  } else {
   $1 = $mask & 65535;
   $2 = ($1|0)==(0);
   do {
    if ($2) {
     $3 = $mask & 16711680;
     $4 = ($3|0)==(0);
     if ($4) {
      $5 = $mask >>> 24;
      $$0$i = $5;$base$0$i = 24;
      break;
     } else {
      $6 = $mask >>> 16;
      $$0$i = $6;$base$0$i = 16;
      break;
     }
    } else {
     $7 = $mask & 255;
     $8 = ($7|0)==(0);
     $9 = $mask >>> 8;
     $$mask$i = $8 ? $9 : $mask;
     $$$i = $8 ? 8 : 0;
     $$0$i = $$mask$i;$base$0$i = $$$i;
    }
   } while(0);
   $10 = $$0$i & 15;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = $base$0$i | 4;
    $13 = $$0$i >>> 4;
    $$1$i = $13;$base$1$i = $12;
   } else {
    $$1$i = $$0$i;$base$1$i = $base$0$i;
   }
   $14 = $$1$i & 3;
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = (($base$1$i) + 2)|0;
    $17 = $$1$i >>> 2;
    $$2$i = $17;$base$2$i = $16;
   } else {
    $$2$i = $$1$i;$base$2$i = $base$1$i;
   }
   $18 = (($base$2$i) + 1)|0;
   $19 = $$2$i & 1;
   $20 = (($18) - ($19))|0;
   $21 = ($mask>>>0)>(65535);
   if ($21) {
    $22 = ($mask>>>0)>(16777215);
    if ($22) {
     $23 = $mask >>> 24;
     $$0$i2 = $23;$$01$i8 = $20;$base$0$i3 = 24;
     break;
    } else {
     $24 = $mask >>> 16;
     $$0$i2 = $24;$$01$i8 = $20;$base$0$i3 = 16;
     break;
    }
   } else {
    $$01$i9 = $20;
    label = 15;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $25 = $mask & 65280;
  $26 = ($25|0)==(0);
  $27 = $mask >>> 8;
  $mask$$i = $26 ? $mask : $27;
  $$$i1 = $26 ? 0 : 8;
  $$0$i2 = $mask$$i;$$01$i8 = $$01$i9;$base$0$i3 = $$$i1;
 }
 $28 = $$0$i2 & 65280;
 $29 = ($28|0)==(0);
 if ($29) {
  $$1$i4 = $$0$i2;$base$1$i5 = $base$0$i3;
 } else {
  $30 = (($base$0$i3) + 8)|0;
  $31 = $$0$i2 >>> 8;
  $$1$i4 = $31;$base$1$i5 = $30;
 }
 $32 = $$1$i4 & 240;
 $33 = ($32|0)==(0);
 if ($33) {
  $$2$i6 = $$1$i4;$base$2$i7 = $base$1$i5;
 } else {
  $34 = (($base$1$i5) + 4)|0;
  $35 = $$1$i4 >>> 4;
  $$2$i6 = $35;$base$2$i7 = $34;
 }
 $36 = $$2$i6 & 12;
 $37 = ($36|0)==(0);
 if ($37) {
  $$3$i = $$2$i6;$base$3$i = $base$2$i7;
 } else {
  $38 = (($base$2$i7) + 2)|0;
  $39 = $$2$i6 >>> 2;
  $$3$i = $39;$base$3$i = $38;
 }
 $40 = $$3$i & 2;
 $41 = ($40|0)==(0);
 if ($41) {
  $$4$i = $$3$i;$base$4$i = $base$3$i;
 } else {
  $42 = (($base$3$i) + 1)|0;
  $43 = $$3$i >>> 1;
  $$4$i = $43;$base$4$i = $42;
 }
 $44 = (($base$4$i) + -1)|0;
 $45 = $$4$i & 1;
 $46 = (($44) + ($45))|0;
 $47 = $46&255;
 HEAP8[$shift>>0] = $47;
 if ($0) {
  $50 = 0;
  HEAP8[$count>>0] = $50;
  STACKTOP = sp;return;
 }
 $48 = (1 - ($$01$i8))|0;
 $49 = (($48) + ($46))|0;
 $phitmp = $49&255;
 $50 = $phitmp;
 HEAP8[$count>>0] = $50;
 STACKTOP = sp;return;
}
function __Z23ConvertImageToPNGBufferRK14ImageReferenceR13dynamic_arrayIhLj1EE($inputImage,$buffer) {
 $inputImage = $inputImage|0;
 $buffer = $buffer|0;
 var $$ = 0, $$0$reg2mem$0 = 0, $$byval_copy211 = 0, $$lcssa$reg2mem$0 = 0, $$pre = 0, $$pre$phi5$reg2mem$0Z2D = 0, $$pre4 = 0, $$reg2mem194$0 = 0, $$reg2mem196$0 = 0, $$reg2mem202$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$02$reg2mem192$0 = 0, $image = 0, $info_ptr = 0, $lpad$phi$reg2mem200$0$index = 0, $lpad$phi$reg2mem200$0$index205 = 0, $png_ptr = 0, $source$0$reg2mem198$0 = 0, _setjmpTable = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy211 = sp + 44|0;
 _setjmpTable = STACKTOP; STACKTOP = STACKTOP + 168|0;HEAP32[_setjmpTable>>2]=0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $png_ptr = sp + 16|0;
 $info_ptr = sp + 20|0;
 $image = sp + 24|0;
 __THREW__ = 0;
 $4 = (invoke_iiiii(239,(602560|0),(0|0),(0|0),(0|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 if ((($5|0) != 0) & ((threwValue|0) != 0)) { $6 = _testSetjmp(HEAP32[$5>>2]|0, _setjmpTable)|0; if (($6|0) == 0) { _longjmp($5|0, threwValue|0); } tempRet0 = threwValue; } else { $6 = -1; };
 $7 = tempRet0;
 if ((($6|0) == 1)) {
  $$reg2mem202$0 = $7;
 } else {
  HEAP32[$png_ptr>>2] = $4;
  $8 = ($4|0)==(0|0);
  if ($8) {
   $$0$reg2mem$0 = 0;
   STACKTOP = sp;return ($$0$reg2mem$0|0);
  }
  __THREW__ = 0;
  $9 = (invoke_ii(3245,($4|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  if ((($10|0) != 0) & ((threwValue|0) != 0)) { $11 = _testSetjmp(HEAP32[$10>>2]|0, _setjmpTable)|0; if (($11|0) == 0) { _longjmp($10|0, threwValue|0); } tempRet0 = threwValue; } else { $11 = -1; };
  $12 = tempRet0;
  if ((($11|0) == 1)) {
   $$reg2mem202$0 = $12;
  } else {
   HEAP32[$info_ptr>>2] = $9;
   $13 = ($9|0)==(0|0);
   if ($13) {
    $$0$reg2mem$0 = 0;
    STACKTOP = sp;return ($$0$reg2mem$0|0);
   }
   $14 = HEAP32[$png_ptr>>2]|0;
   __THREW__ = 0;
   $15 = (invoke_iiii(1544,($14|0),(2525|0),156)|0);
   $16 = __THREW__; __THREW__ = 0;
   if ((($16|0) != 0) & ((threwValue|0) != 0)) { $17 = _testSetjmp(HEAP32[$16>>2]|0, _setjmpTable)|0; if (($17|0) == 0) { _longjmp($16|0, threwValue|0); } tempRet0 = threwValue; } else { $17 = -1; };
   $18 = tempRet0;
   if ((($17|0) == 1)) {
    $$reg2mem202$0 = $18;
   } else {
    _saveSetjmp($15,1,_setjmpTable|0)|0;
    __THREW__ = 0;
    $19 = __THREW__; __THREW__ = 0;
    if ((($19|0) != 0) & ((threwValue|0) != 0)) { $20 = _testSetjmp(HEAP32[$19>>2]|0, _setjmpTable)|0; if (($20|0) == 0) { _longjmp($19|0, threwValue|0); } tempRet0 = threwValue; } else { $20 = -1; };
    $21 = tempRet0;
    if ((($20|0) == 1)) {
     $$reg2mem202$0 = $21;
    } else {
     $$reg2mem202$0 = 0;
    }
   }
  }
 }
 L12: while(1) {
  $22 = ($$reg2mem202$0|0)==(0);
  if (!($22)) {
   $$0$reg2mem$0 = 0;
   label = 47;
   break;
  }
  $23 = (($buffer) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 & 2147479552;
  $26 = ($25>>>0)<(4096);
  do {
   if ($26) {
    $27 = ($24|0)>(-1);
    if ($27) {
     HEAP32[$23>>2] = 4096;
     $28 = HEAP32[$buffer>>2]|0;
     $29 = (($buffer) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$2>>2] = $30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy211+0>>2]=HEAP32[$2+0>>2]|0;
     $31 = (invoke_iiiiiiii(108,($28|0),4096,1,($$byval_copy211|0),0,(602568|0),370)|0);
     $32 = __THREW__; __THREW__ = 0;
     if ((($32|0) != 0) & ((threwValue|0) != 0)) { $33 = _testSetjmp(HEAP32[$32>>2]|0, _setjmpTable)|0; if (($33|0) == 0) { _longjmp($32|0, threwValue|0); } tempRet0 = threwValue; } else { $33 = -1; };
     $34 = tempRet0;
     if ((($33|0) == 1)) {
      $$reg2mem202$0 = $34;
      continue L12;
     }
     HEAP32[$buffer>>2] = $31;
     break;
    } else {
     $35 = (($buffer) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     HEAP32[$3>>2] = $36;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy211+0>>2]=HEAP32[$3+0>>2]|0;
     $37 = (invoke_iiiiiii(102,4096,1,($$byval_copy211|0),0,(602568|0),352)|0);
     $38 = __THREW__; __THREW__ = 0;
     if ((($38|0) != 0) & ((threwValue|0) != 0)) { $39 = _testSetjmp(HEAP32[$38>>2]|0, _setjmpTable)|0; if (($39|0) == 0) { _longjmp($38|0, threwValue|0); } tempRet0 = threwValue; } else { $39 = -1; };
     $40 = tempRet0;
     if ((($39|0) == 1)) {
      $$reg2mem202$0 = $40;
      continue L12;
     }
     $41 = HEAP32[$buffer>>2]|0;
     $42 = (($buffer) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     _memcpy(($37|0),($41|0),($43|0))|0;
     HEAP32[$23>>2] = 4096;
     HEAP32[$buffer>>2] = $37;
     break;
    }
   }
  } while(0);
  $44 = HEAP32[$png_ptr>>2]|0;
  __THREW__ = 0;
  invoke_viiii(368,($44|0),($buffer|0),(1738|0),(3481|0));
  $45 = __THREW__; __THREW__ = 0;
  if ((($45|0) != 0) & ((threwValue|0) != 0)) { $46 = _testSetjmp(HEAP32[$45>>2]|0, _setjmpTable)|0; if (($46|0) == 0) { _longjmp($45|0, threwValue|0); } tempRet0 = threwValue; } else { $46 = -1; };
  $47 = tempRet0;
  if ((($46|0) == 1)) {
   $$reg2mem202$0 = $47;
   continue;
  }
  $48 = HEAP32[$png_ptr>>2]|0;
  __THREW__ = 0;
  invoke_vii(2710,($48|0),1);
  $49 = __THREW__; __THREW__ = 0;
  if ((($49|0) != 0) & ((threwValue|0) != 0)) { $50 = _testSetjmp(HEAP32[$49>>2]|0, _setjmpTable)|0; if (($50|0) == 0) { _longjmp($49|0, threwValue|0); } tempRet0 = threwValue; } else { $50 = -1; };
  $51 = tempRet0;
  if ((($50|0) == 1)) {
   $$reg2mem202$0 = $51;
   continue;
  }
  $52 = HEAP32[$inputImage>>2]|0;
  __THREW__ = 0;
  $53 = (invoke_ii(3246,($52|0))|0);
  $54 = __THREW__; __THREW__ = 0;
  if ((($54|0) != 0) & ((threwValue|0) != 0)) { $55 = _testSetjmp(HEAP32[$54>>2]|0, _setjmpTable)|0; if (($55|0) == 0) { _longjmp($54|0, threwValue|0); } tempRet0 = threwValue; } else { $55 = -1; };
  $56 = tempRet0;
  if ((($55|0) == 1)) {
   $$reg2mem202$0 = $56;
   continue;
  }
  $$ = $53 ? 4 : 3;
  ;HEAP32[$image+0>>2]=0|0;HEAP32[$image+4>>2]=0|0;HEAP32[$image+8>>2]=0|0;HEAP32[$image+12>>2]=0|0;HEAP32[$image+16>>2]=0|0;
  $57 = HEAP32[$inputImage>>2]|0;
  $58 = ($57|0)==($$|0);
  $$pre = (($inputImage) + 4|0);
  if ($58) {
   $$pre4 = (($inputImage) + 8|0);
   $$pre$phi5$reg2mem$0Z2D = $$pre4;$source$0$reg2mem198$0 = $inputImage;
   label = 32;
  } else {
   $82 = HEAP32[$$pre>>2]|0;
   $83 = (($inputImage) + 8|0);
   $84 = HEAP32[$83>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(97,($image|0),($82|0),($84|0),($$|0),1);
   $85 = __THREW__; __THREW__ = 0;
   if ((($85|0) != 0) & ((threwValue|0) != 0)) { $86 = _testSetjmp(HEAP32[$85>>2]|0, _setjmpTable)|0; if (($86|0) == 0) { _longjmp($85|0, threwValue|0); } tempRet0 = threwValue; } else { $86 = -1; };
   $87 = tempRet0;
   if ((($86|0) == 1)) {
    $$reg2mem202$0 = $87;
    continue;
   }
   $88 = $85&1;
   if ($88) {
    label = 23;
   } else {
    __THREW__ = 0;
    invoke_viii(1729,($image|0),($inputImage|0),0);
    $89 = __THREW__; __THREW__ = 0;
    if ((($89|0) != 0) & ((threwValue|0) != 0)) { $90 = _testSetjmp(HEAP32[$89>>2]|0, _setjmpTable)|0; if (($90|0) == 0) { _longjmp($89|0, threwValue|0); } tempRet0 = threwValue; } else { $90 = -1; };
    $91 = tempRet0;
    if ((($90|0) == 1)) {
     $$reg2mem202$0 = $91;
     continue;
    }
    $92 = $89&1;
    if ($92) {
     label = 23;
    } else {
     $$pre$phi5$reg2mem$0Z2D = $83;$source$0$reg2mem198$0 = $image;
     label = 32;
    }
   }
  }
  L32: do {
   if ((label|0) == 32) {
    label = 0;
    $93 = HEAP32[$png_ptr>>2]|0;
    $94 = HEAP32[$info_ptr>>2]|0;
    $95 = HEAP32[$$pre>>2]|0;
    $96 = HEAP32[$$pre$phi5$reg2mem$0Z2D>>2]|0;
    $97 = $53 ? 6 : 2;
    __THREW__ = 0;
    invoke_viiiiiiiii(12,($93|0),($94|0),($95|0),($96|0),8,($97|0),0,0,0);
    $98 = __THREW__; __THREW__ = 0;
    if ((($98|0) != 0) & ((threwValue|0) != 0)) { $99 = _testSetjmp(HEAP32[$98>>2]|0, _setjmpTable)|0; if (($99|0) == 0) { _longjmp($98|0, threwValue|0); } tempRet0 = threwValue; } else { $99 = -1; };
    $100 = tempRet0;
    if ((($99|0) == 1)) {
     $$reg2mem202$0 = $100;
     continue L12;
    }
    $101 = $98&1;
    if ($101) {
     label = 23;
    } else {
     $102 = HEAP32[$png_ptr>>2]|0;
     $103 = HEAP32[$info_ptr>>2]|0;
     __THREW__ = 0;
     invoke_vii(2711,($102|0),($103|0));
     $104 = __THREW__; __THREW__ = 0;
     if ((($104|0) != 0) & ((threwValue|0) != 0)) { $105 = _testSetjmp(HEAP32[$104>>2]|0, _setjmpTable)|0; if (($105|0) == 0) { _longjmp($104|0, threwValue|0); } tempRet0 = threwValue; } else { $105 = -1; };
     $106 = tempRet0;
     if ((($105|0) == 1)) {
      $$reg2mem202$0 = $106;
      continue L12;
     }
     $107 = $104&1;
     if ($107) {
      label = 23;
     } else {
      $108 = (($source$0$reg2mem198$0) + 8|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($109|0)>(0);
      $111 = HEAP32[$png_ptr>>2]|0;
      L38: do {
       if ($110) {
        $112 = (($source$0$reg2mem198$0) + 16|0);
        $113 = (($source$0$reg2mem198$0) + 12|0);
        $$reg2mem194$0 = $109;$$reg2mem196$0 = $111;$i$02$reg2mem192$0 = 0;
        while(1) {
         $114 = $i$02$reg2mem192$0 ^ -1;
         $115 = (($$reg2mem194$0) + ($114))|0;
         $116 = HEAP32[$112>>2]|0;
         $117 = HEAP32[$113>>2]|0;
         $118 = Math_imul($117, $115)|0;
         $119 = (($116) + ($118)|0);
         __THREW__ = 0;
         invoke_vii(2712,($$reg2mem196$0|0),($119|0));
         $120 = __THREW__; __THREW__ = 0;
         if ((($120|0) != 0) & ((threwValue|0) != 0)) { $121 = _testSetjmp(HEAP32[$120>>2]|0, _setjmpTable)|0; if (($121|0) == 0) { _longjmp($120|0, threwValue|0); } tempRet0 = threwValue; } else { $121 = -1; };
         $122 = tempRet0;
         if ((($121|0) == 1)) {
          $$reg2mem202$0 = $122;
          continue L12;
         }
         $123 = $120&1;
         if ($123) {
          break;
         }
         $124 = (($i$02$reg2mem192$0) + 1)|0;
         $125 = HEAP32[$108>>2]|0;
         $126 = ($124|0)<($125|0);
         $127 = HEAP32[$png_ptr>>2]|0;
         if ($126) {
          $$reg2mem194$0 = $125;$$reg2mem196$0 = $127;$i$02$reg2mem192$0 = $124;
         } else {
          $$lcssa$reg2mem$0 = $127;
          break L38;
         }
        }
        __THREW__ = 0;
        $59 = ___cxa_find_matching_catch()|0;
        $60 = __THREW__; __THREW__ = 0;
        if ((($60|0) != 0) & ((threwValue|0) != 0)) { $61 = _testSetjmp(HEAP32[$60>>2]|0, _setjmpTable)|0; if (($61|0) == 0) { _longjmp($60|0, threwValue|0); } tempRet0 = threwValue; } else { $61 = -1; };
        $62 = tempRet0;
        if ((($61|0) == 1)) {
         $$reg2mem202$0 = $62;
         continue L12;
        }
        __THREW__ = 0;
        $63 = tempRet0;
        $64 = __THREW__; __THREW__ = 0;
        if ((($64|0) != 0) & ((threwValue|0) != 0)) { $65 = _testSetjmp(HEAP32[$64>>2]|0, _setjmpTable)|0; if (($65|0) == 0) { _longjmp($64|0, threwValue|0); } tempRet0 = threwValue; } else { $65 = -1; };
        $66 = tempRet0;
        if ((($65|0) == 1)) {
         $$reg2mem202$0 = $66;
         continue L12;
        }
        $lpad$phi$reg2mem200$0$index = $59;$lpad$phi$reg2mem200$0$index205 = $63;
        break L32;
       } else {
        $$lcssa$reg2mem$0 = $111;
       }
      } while(0);
      $128 = HEAP32[$info_ptr>>2]|0;
      __THREW__ = 0;
      invoke_vii(2713,($$lcssa$reg2mem$0|0),($128|0));
      $129 = __THREW__; __THREW__ = 0;
      if ((($129|0) != 0) & ((threwValue|0) != 0)) { $130 = _testSetjmp(HEAP32[$129>>2]|0, _setjmpTable)|0; if (($130|0) == 0) { _longjmp($129|0, threwValue|0); } tempRet0 = threwValue; } else { $130 = -1; };
      $131 = tempRet0;
      if ((($130|0) == 1)) {
       $$reg2mem202$0 = $131;
       continue L12;
      }
      $132 = $129&1;
      if ($132) {
       label = 23;
      } else {
       __THREW__ = 0;
       invoke_vii(2714,($png_ptr|0),($info_ptr|0));
       $133 = __THREW__; __THREW__ = 0;
       if ((($133|0) != 0) & ((threwValue|0) != 0)) { $134 = _testSetjmp(HEAP32[$133>>2]|0, _setjmpTable)|0; if (($134|0) == 0) { _longjmp($133|0, threwValue|0); } tempRet0 = threwValue; } else { $134 = -1; };
       $135 = tempRet0;
       if ((($134|0) == 1)) {
        $$reg2mem202$0 = $135;
        continue L12;
       }
       $136 = $133&1;
       if ($136) {
        label = 23;
       } else {
        $137 = (($buffer) + 8|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = ($138|0)!=(0);
        $140 = (($image) + 16|0);
        $141 = HEAP32[$140>>2]|0;
        $142 = HEAP32[628224>>2]|0;
        HEAP32[$1>>2] = $142;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy211+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($141|0),($$byval_copy211|0));
        $143 = __THREW__; __THREW__ = 0;
        if ((($143|0) != 0) & ((threwValue|0) != 0)) { $144 = _testSetjmp(HEAP32[$143>>2]|0, _setjmpTable)|0; if (($144|0) == 0) { _longjmp($143|0, threwValue|0); } tempRet0 = threwValue; } else { $144 = -1; };
        $145 = tempRet0;
        if ((($144|0) == 1)) {
         $$reg2mem202$0 = $145;
         continue L12;
        } else {
         label = 46;
         break L12;
        }
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 23) {
   label = 0;
   __THREW__ = 0;
   $67 = ___cxa_find_matching_catch()|0;
   $68 = __THREW__; __THREW__ = 0;
   if ((($68|0) != 0) & ((threwValue|0) != 0)) { $69 = _testSetjmp(HEAP32[$68>>2]|0, _setjmpTable)|0; if (($69|0) == 0) { _longjmp($68|0, threwValue|0); } tempRet0 = threwValue; } else { $69 = -1; };
   $70 = tempRet0;
   if ((($69|0) == 1)) {
    $$reg2mem202$0 = $70;
    continue;
   }
   __THREW__ = 0;
   $71 = tempRet0;
   $72 = __THREW__; __THREW__ = 0;
   if ((($72|0) != 0) & ((threwValue|0) != 0)) { $73 = _testSetjmp(HEAP32[$72>>2]|0, _setjmpTable)|0; if (($73|0) == 0) { _longjmp($72|0, threwValue|0); } tempRet0 = threwValue; } else { $73 = -1; };
   $74 = tempRet0;
   if ((($73|0) == 1)) {
    $$reg2mem202$0 = $74;
    continue;
   }
   $lpad$phi$reg2mem200$0$index = $67;$lpad$phi$reg2mem200$0$index205 = $71;
  }
  $75 = (($image) + 16|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = HEAP32[628224>>2]|0;
  HEAP32[$0>>2] = $77;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy211+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($76|0),($$byval_copy211|0));
  $78 = __THREW__; __THREW__ = 0;
  if ((($78|0) != 0) & ((threwValue|0) != 0)) { $79 = _testSetjmp(HEAP32[$78>>2]|0, _setjmpTable)|0; if (($79|0) == 0) { _longjmp($78|0, threwValue|0); } tempRet0 = threwValue; } else { $79 = -1; };
  $80 = tempRet0;
  if ((($79|0) == 1)) {
   $$reg2mem202$0 = $80;
   continue;
  }
  $81 = $78&1;
  if (!($81)) {
   __THREW__ = 0;
   ___resumeException($lpad$phi$reg2mem200$0$index|0);
   $146 = __THREW__; __THREW__ = 0;
   if ((($146|0) != 0) & ((threwValue|0) != 0)) { $147 = _testSetjmp(HEAP32[$146>>2]|0, _setjmpTable)|0; if (($147|0) == 0) { _longjmp($146|0, threwValue|0); } tempRet0 = threwValue; } else { $147 = -1; };
   $148 = tempRet0;
   if ((($147|0) == 1)) {
    $$reg2mem202$0 = $148;
    continue;
   } else {
    label = 49;
    break;
   }
  }
  __THREW__ = 0;
  $149 = ___cxa_find_matching_catch(0|0)|0;
  $150 = __THREW__; __THREW__ = 0;
  if ((($150|0) != 0) & ((threwValue|0) != 0)) { $151 = _testSetjmp(HEAP32[$150>>2]|0, _setjmpTable)|0; if (($151|0) == 0) { _longjmp($150|0, threwValue|0); } tempRet0 = threwValue; } else { $151 = -1; };
  $152 = tempRet0;
  if ((($151|0) == 1)) {
   $$reg2mem202$0 = $152;
   continue;
  }
  __THREW__ = 0;
  $153 = tempRet0;
  $154 = __THREW__; __THREW__ = 0;
  if ((($154|0) != 0) & ((threwValue|0) != 0)) { $155 = _testSetjmp(HEAP32[$154>>2]|0, _setjmpTable)|0; if (($155|0) == 0) { _longjmp($154|0, threwValue|0); } tempRet0 = threwValue; } else { $155 = -1; };
  $156 = tempRet0;
  if ((($155|0) == 1)) {
   $$reg2mem202$0 = $156;
   continue;
  }
  __THREW__ = 0;
  invoke_vi(3482,($149|0));
  $157 = __THREW__; __THREW__ = 0;
  if ((($157|0) != 0) & ((threwValue|0) != 0)) { $158 = _testSetjmp(HEAP32[$157>>2]|0, _setjmpTable)|0; if (($158|0) == 0) { _longjmp($157|0, threwValue|0); } tempRet0 = threwValue; } else { $158 = -1; };
  $159 = tempRet0;
  if ((($158|0) == 1)) {
   $$reg2mem202$0 = $159;
  } else {
   label = 53;
   break;
  }
 }
 if ((label|0) == 46) {
  $$0$reg2mem$0 = $139;
  STACKTOP = sp;return ($$0$reg2mem$0|0);
 }
 else if ((label|0) == 47) {
  STACKTOP = sp;return ($$0$reg2mem$0|0);
 }
 else if ((label|0) == 49) {
  // unreachable;
 }
 else if ((label|0) == 53) {
  // unreachable;
 }
 return 0|0;
}
function __ZL20PngWriteToMemoryFuncP14png_struct_defPhj($png,$data,$size) {
 $png = $png|0;
 $data = $data|0;
 $size = $size|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_png_get_io_ptr($png)|0);
 __ZL34AppendToBufferWithSpaceReservationR13dynamic_arrayIhLj1EEPKhj($0,$data,$size);
 STACKTOP = sp;return;
}
function __ZL17PngWriteFlushFuncP14png_struct_def($png) {
 $png = $png|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z21ConvertImageToPNGFileRK14ImageReferenceRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($inputImage,$path) {
 $inputImage = $inputImage|0;
 $path = $path|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 4|0);
 HEAP32[$3>>2] = 61;
 __THREW__ = 0;
 $4 = (invoke_iii(2395,($inputImage|0),($buffer|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   if ($4) {
    $15 = HEAP32[$buffer>>2]|0;
    $16 = HEAP32[$1>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iiii(1545,($15|0),($16|0),($path|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    } else {
     $$0 = $17;
    }
   } else {
    $$0 = 0;
   }
   $20 = HEAP32[$2>>2]|0;
   $21 = ($20|0)>(-1);
   if (!($21)) {
    STACKTOP = sp;return ($$0|0);
   }
   $22 = HEAP32[$buffer>>2]|0;
   $23 = HEAP32[$3>>2]|0;
   HEAP32[$0>>2] = $23;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($22,$$byval_copy1);
   HEAP32[$buffer>>2] = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $9 = HEAP32[$2>>2]|0;
 $10 = ($9|0)>(-1);
 if (!($10)) {
  ___resumeException($7|0);
  // unreachable;
 }
 $11 = HEAP32[$buffer>>2]|0;
 $12 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $12;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($11|0),($$byval_copy1|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $24 = ___cxa_find_matching_catch(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 }
 HEAP32[$buffer>>2] = 0;
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZL34AppendToBufferWithSpaceReservationR13dynamic_arrayIhLj1EEPKhj($buffer,$data,$size) {
 $buffer = $buffer|0;
 $data = $data|0;
 $size = $size|0;
 var $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($buffer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = (($buffer) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($size))|0;
 $7 = ($3>>>0)<($6>>>0);
 do {
  if ($7) {
   $8 = $3 >>> 1;
   $9 = (($8) + ($3))|0;
   $10 = ($6>>>0)<($9>>>0);
   $11 = $10 ? $9 : $6;
   $12 = ($3>>>0)<($11>>>0);
   if ($12) {
    $13 = ($2|0)>(-1);
    if ($13) {
     HEAP32[$1>>2] = $11;
     $14 = HEAP32[$buffer>>2]|0;
     $15 = (($buffer) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$11,1,$$byval_copy3,0,602568,370)|0);
     HEAP32[$buffer>>2] = $17;
     $$pre = HEAP32[$1>>2]|0;
     $27 = $$pre;
     break;
    } else {
     $18 = (($buffer) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$0>>2] = $19;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($11,1,$$byval_copy3,0,602568,352)|0);
     $21 = HEAP32[$buffer>>2]|0;
     $22 = HEAP32[$4>>2]|0;
     _memcpy(($20|0),($21|0),($22|0))|0;
     HEAP32[$1>>2] = $11;
     HEAP32[$buffer>>2] = $20;
     $27 = $11;
     break;
    }
   } else {
    $27 = $2;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = HEAP32[$buffer>>2]|0;
 $24 = HEAP32[$4>>2]|0;
 $25 = (($24) + ($size))|0;
 HEAP32[$4>>2] = $25;
 $26 = $27 & 2147483647;
 $28 = ($26>>>0)<($25>>>0);
 if (!($28)) {
  $39 = $23;
  $38 = (($39) + ($24)|0);
  _memcpy(($38|0),($data|0),($size|0))|0;
  STACKTOP = sp;return;
 }
 $29 = ($27|0)>(-1);
 if ($29) {
  HEAP32[$1>>2] = $25;
  $30 = (($buffer) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$0>>2] = $31;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $32 = (__Z16realloc_internalPvji10MemLabelIdiPKci($23,$25,1,$$byval_copy3,0,602568,370)|0);
  HEAP32[$buffer>>2] = $32;
  $39 = $32;
  $38 = (($39) + ($24)|0);
  _memcpy(($38|0),($data|0),($size|0))|0;
  STACKTOP = sp;return;
 } else {
  $33 = (($buffer) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  HEAP32[$0>>2] = $34;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $35 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,1,$$byval_copy3,0,602568,352)|0);
  $36 = HEAP32[$buffer>>2]|0;
  $37 = HEAP32[$4>>2]|0;
  _memcpy(($35|0),($36|0),($37|0))|0;
  HEAP32[$1>>2] = $25;
  HEAP32[$buffer>>2] = $35;
  $39 = $35;
  $38 = (($39) + ($24)|0);
  _memcpy(($38|0),($data|0),($size|0))|0;
  STACKTOP = sp;return;
 }
}
function __ZN16LightmapSettingsC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy13 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN16LevelGameManagerC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy13,$mode);
 HEAP32[$this>>2] = ((602664 + 8|0));
 $3 = (($this) + 24|0);
 $4 = (($this) + 68|0);
 $5 = (($this) + 76|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 80|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 72|0);
 dest=$3+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$7>>2] = 61;
 $8 = (($this) + 84|0);
 HEAP32[$8>>2] = 2;
 $9 = (($this) + 88|0);
 HEAP32[$9>>2] = 1;
 $10 = (($this) + 92|0);
 HEAP32[$10>>2] = 1;
 $11 = (($this) + 96|0);
 HEAP8[$11>>0] = 0;
 $12 = (($this) + 100|0);
 __THREW__ = 0;
 invoke_vi(3483,($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  $15 = (($this) + 120|0);
  HEAP32[$15>>2] = 0;
  $16 = (($this) + 128|0);
  HEAP32[$16>>2] = 0;
  $17 = (($this) + 132|0);
  HEAP32[$17>>2] = 0;
  $18 = (($this) + 124|0);
  HEAP32[$18>>2] = 61;
  $19 = (($this) + 136|0);
  HEAP32[$19>>2] = 0;
  $20 = (($this) + 144|0);
  HEAP32[$20>>2] = 0;
  $21 = (($this) + 148|0);
  HEAP32[$21>>2] = 0;
  $22 = (($this) + 140|0);
  HEAP32[$22>>2] = 61;
  $23 = (($this) + 152|0);
  HEAP32[$23>>2] = 0;
  $24 = (($this) + 160|0);
  HEAP32[$24>>2] = 0;
  $25 = (($this) + 164|0);
  HEAP32[$25>>2] = 0;
  $26 = (($this) + 156|0);
  HEAP32[$26>>2] = 61;
  $27 = (($this) + 168|0);
  HEAP32[$27>>2] = 0;
  $28 = (($this) + 176|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 180|0);
  HEAP32[$29>>2] = 0;
  $30 = (($this) + 172|0);
  HEAP32[$30>>2] = 61;
  $31 = (($this) + 188|0);
  HEAP32[$31>>2] = 0;
  $32 = (($this) + 192|0);
  HEAP32[$32>>2] = 0;
  $33 = (($this) + 196|0);
  HEAP32[$33>>2] = 0;
  $34 = (($this) + 200|0);
  HEAP32[$34>>2] = 25;
  STACKTOP = sp;return;
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 $37 = HEAP32[$6>>2]|0;
 $38 = ($37|0)>(-1);
 if ($38) {
  $39 = HEAP32[$4>>2]|0;
  $40 = HEAP32[$7>>2]|0;
  HEAP32[$0>>2] = $40;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($39|0),($$byval_copy13|0));
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if (!($42)) {
   HEAP32[$4>>2] = 0;
   label = 6;
  }
 } else {
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$this>>2] = ((561080 + 8|0));
   __THREW__ = 0;
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     __THREW__ = 0;
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     ___resumeException($35|0);
     // unreachable;
    }
    $47 = ___cxa_find_matching_catch(0|0)|0;
    $48 = tempRet0;
    __THREW__ = 0;
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     $51 = ___cxa_find_matching_catch(0|0)|0;
     $52 = tempRet0;
     ___clang_call_terminate($51);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $47;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $55 = ___cxa_find_matching_catch(0|0)|0;
   $56 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $61 = ___cxa_find_matching_catch(0|0)|0;
    $62 = tempRet0;
    __THREW__ = 0;
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     $65 = ___cxa_find_matching_catch(0|0)|0;
     $66 = tempRet0;
     ___clang_call_terminate($65);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $61;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if (!($60)) {
    $eh$lpad$body$indexZ2D = $55;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $67 = ___cxa_find_matching_catch(0|0)|0;
   $68 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $67;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 $69 = ___cxa_find_matching_catch(0|0)|0;
 $70 = tempRet0;
 $eh$lpad$body$indexZ2D = $69;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZNK16LightmapSettings24GetEnlightenSceneMappingEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN16LightmapSettings13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LightmapSettings7RebuildEv($this);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings7RebuildEv($this) {
 $this = $this|0;
 var $$arith = 0, $$overflow = 0, $$sroa$0$0$i = 0, $$sroa$0$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$011 = 0, $pos$i$i$i$i4 = 0, $temp$0$i15 = 0, $temp$0$i813 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZdaPv($3);
 }
 $5 = (($this) + 76|0);
 $6 = HEAP32[$5>>2]|0;
 $$arith = $6<<3;
 $$overflow = ($6>>>0)>(536870911);
 $7 = $$overflow ? -1 : $$arith;
 $8 = (__Znaj($7)|0);
 $9 = ($6|0)==(0);
 if ($9) {
  HEAP32[$2>>2] = $8;
  $10 = (($this) + 28|0);
  HEAP32[$10>>2] = $6;
  STACKTOP = sp;return;
 }
 $11 = (($8) + ($6<<3)|0);
 $13 = $8;
 while(1) {
  $12 = (($13) + 4|0);
  HEAP32[$12>>2] = 0;
  HEAP32[$13>>2] = 0;
  $14 = (($13) + 8|0);
  $15 = ($14|0)==($11|0);
  if ($15) {
   break;
  } else {
   $13 = $14;
  }
 }
 HEAP32[$2>>2] = $8;
 $16 = (($this) + 28|0);
 HEAP32[$16>>2] = $6;
 if ($9) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 68|0);
 $i$011 = 0;
 while(1) {
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($i$011<<3)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  do {
   if ($21) {
    label = 20;
   } else {
    HEAP32[$0>>2] = $20;
    $22 = HEAP32[560624>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     label = 18;
    } else {
     $24 = (($22) + 36|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($22) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($25|0)==($27|0);
     do {
      if ($28) {
       $29 = (($22) + 28|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = (($22) + 32|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($30) + ($32<<3)|0);
       $49 = $33;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i4,$22,$0);
       $34 = HEAP32[$pos$i$i$i$i4>>2]|0;
       $35 = ($34|0)==(-1);
       $36 = (($22) + 28|0);
       $37 = HEAP32[$36>>2]|0;
       if ($35) {
        $38 = (($22) + 32|0);
        $39 = HEAP32[$38>>2]|0;
        $40 = (($37) + ($39<<3)|0);
        $49 = $40;
        break;
       } else {
        $41 = (($37) + ($34<<3)|0);
        $49 = $41;
        break;
       }
      }
     } while(0);
     $42 = HEAP32[560624>>2]|0;
     $43 = (($42) + 28|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + 32|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($44) + ($46<<3)|0);
     $48 = ($49|0)==($47|0);
     if ($48) {
      label = 18;
     } else {
      $50 = (($49) + 4|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==(0|0);
      if ($52) {
       label = 18;
      } else {
       $temp$0$i813 = $51;
      }
     }
    }
    if ((label|0) == 18) {
     label = 0;
     $53 = HEAP32[$19>>2]|0;
     $54 = (__Z31ReadObjectFromPersistentManageri($53)|0);
     $55 = ($54|0)==(0|0);
     if ($55) {
      label = 20;
      break;
     } else {
      $temp$0$i813 = $54;
     }
    }
    $56 = (($temp$0$i813) + 44|0);
    $57 = HEAP32[$56>>2]|0;
    $$sroa$0$0$i2 = $57;
   }
  } while(0);
  if ((label|0) == 20) {
   label = 0;
   $58 = (__ZN10builtintex17GetBlackTextureIDEv()|0);
   $$sroa$0$0$i2 = $58;
  }
  $59 = HEAP32[$17>>2]|0;
  $60 = ((($59) + ($i$011<<3)|0) + 4|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($61|0)==(0);
  do {
   if ($62) {
    label = 32;
   } else {
    HEAP32[$1>>2] = $61;
    $63 = HEAP32[560624>>2]|0;
    $64 = ($63|0)==(0|0);
    if ($64) {
     label = 30;
    } else {
     $65 = (($63) + 36|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = (($63) + 4|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ($66|0)==($68|0);
     do {
      if ($69) {
       $70 = (($63) + 28|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = (($63) + 32|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = (($71) + ($73<<3)|0);
       $90 = $74;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i4,$63,$1);
       $75 = HEAP32[$pos$i$i$i$i4>>2]|0;
       $76 = ($75|0)==(-1);
       $77 = (($63) + 28|0);
       $78 = HEAP32[$77>>2]|0;
       if ($76) {
        $79 = (($63) + 32|0);
        $80 = HEAP32[$79>>2]|0;
        $81 = (($78) + ($80<<3)|0);
        $90 = $81;
        break;
       } else {
        $82 = (($78) + ($75<<3)|0);
        $90 = $82;
        break;
       }
      }
     } while(0);
     $83 = HEAP32[560624>>2]|0;
     $84 = (($83) + 28|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = (($83) + 32|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = (($85) + ($87<<3)|0);
     $89 = ($90|0)==($88|0);
     if ($89) {
      label = 30;
     } else {
      $91 = (($90) + 4|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = ($92|0)==(0|0);
      if ($93) {
       label = 30;
      } else {
       $temp$0$i15 = $92;
      }
     }
    }
    if ((label|0) == 30) {
     label = 0;
     $94 = HEAP32[$60>>2]|0;
     $95 = (__Z31ReadObjectFromPersistentManageri($94)|0);
     $96 = ($95|0)==(0|0);
     if ($96) {
      label = 32;
      break;
     } else {
      $temp$0$i15 = $95;
     }
    }
    $97 = (($temp$0$i15) + 44|0);
    $98 = HEAP32[$97>>2]|0;
    $$sroa$0$0$i = $98;
   }
  } while(0);
  if ((label|0) == 32) {
   label = 0;
   $99 = (__ZN10builtintex17GetBlackTextureIDEv()|0);
   $$sroa$0$0$i = $99;
  }
  $100 = HEAP32[$2>>2]|0;
  $101 = (($100) + ($i$011<<3)|0);
  $102 = $101;
  $103 = $102;
  HEAP32[$103>>2] = $$sroa$0$0$i2;
  $104 = (($102) + 4)|0;
  $105 = $104;
  HEAP32[$105>>2] = $$sroa$0$0$i;
  $106 = (($i$011) + 1)|0;
  $exitcond = ($106|0)==($6|0);
  if ($exitcond) {
   break;
  } else {
   $i$011 = $106;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings14GetLightProbesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK16LightmapSettings19AreLightProbesBakedEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $pos$i$i$i$i12 = 0, $temp$0$i16 = 0, $temp$0$i5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i12 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(2);
 if ($6) {
  $7 = (($this) + 64|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$3>>2] = $8;
  $10 = HEAP32[560624>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   label = 11;
  } else {
   $12 = (($10) + 36|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($10) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($13|0)==($15|0);
   do {
    if ($16) {
     $17 = (($10) + 28|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($10) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $37 = $21;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i12,$10,$3);
     $22 = HEAP32[$pos$i$i$i$i12>>2]|0;
     $23 = ($22|0)==(-1);
     $24 = (($10) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     if ($23) {
      $26 = (($10) + 32|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = (($25) + ($27<<3)|0);
      $37 = $28;
      break;
     } else {
      $29 = (($25) + ($22<<3)|0);
      $37 = $29;
      break;
     }
    }
   } while(0);
   $30 = HEAP32[560624>>2]|0;
   $31 = (($30) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 32|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + ($34<<3)|0);
   $36 = ($37|0)==($35|0);
   if ($36) {
    label = 11;
   } else {
    $38 = (($37) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     label = 11;
    }
   }
  }
  if ((label|0) == 11) {
   $41 = HEAP32[$7>>2]|0;
   $42 = (__Z31ReadObjectFromPersistentManageri($41)|0);
   $43 = ($42|0)==(0|0);
   if ($43) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $44 = HEAP32[$7>>2]|0;
  HEAP32[$2>>2] = $44;
  $45 = HEAP32[560624>>2]|0;
  $46 = ($45|0)==(0|0);
  if ($46) {
   label = 20;
  } else {
   $47 = (($45) + 36|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($45) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($48|0)==($50|0);
   do {
    if ($51) {
     $52 = (($45) + 28|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = (($45) + 32|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($53) + ($55<<3)|0);
     $72 = $56;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i12,$45,$2);
     $57 = HEAP32[$pos$i$i$i$i12>>2]|0;
     $58 = ($57|0)==(-1);
     $59 = (($45) + 28|0);
     $60 = HEAP32[$59>>2]|0;
     if ($58) {
      $61 = (($45) + 32|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = (($60) + ($62<<3)|0);
      $72 = $63;
      break;
     } else {
      $64 = (($60) + ($57<<3)|0);
      $72 = $64;
      break;
     }
    }
   } while(0);
   $65 = HEAP32[560624>>2]|0;
   $66 = (($65) + 28|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($65) + 32|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($67) + ($69<<3)|0);
   $71 = ($72|0)==($70|0);
   if ($71) {
    label = 20;
   } else {
    $73 = (($72) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)==(0|0);
    if ($75) {
     label = 20;
    } else {
     $temp$0$i5 = $74;
    }
   }
  }
  if ((label|0) == 20) {
   $76 = HEAP32[$7>>2]|0;
   $77 = (__Z31ReadObjectFromPersistentManageri($76)|0);
   $temp$0$i5 = $77;
  }
  $78 = (($temp$0$i5) + 68|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)>(0);
  $$0 = $80;
  STACKTOP = sp;return ($$0|0);
 } else {
  $81 = (($this) + 60|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(0);
  if ($83) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$1>>2] = $82;
  $84 = HEAP32[560624>>2]|0;
  $85 = ($84|0)==(0|0);
  if ($85) {
   label = 31;
  } else {
   $86 = (($84) + 36|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($84) + 4|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($87|0)==($89|0);
   do {
    if ($90) {
     $91 = (($84) + 28|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = (($84) + 32|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = (($92) + ($94<<3)|0);
     $111 = $95;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i12,$84,$1);
     $96 = HEAP32[$pos$i$i$i$i12>>2]|0;
     $97 = ($96|0)==(-1);
     $98 = (($84) + 28|0);
     $99 = HEAP32[$98>>2]|0;
     if ($97) {
      $100 = (($84) + 32|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = (($99) + ($101<<3)|0);
      $111 = $102;
      break;
     } else {
      $103 = (($99) + ($96<<3)|0);
      $111 = $103;
      break;
     }
    }
   } while(0);
   $104 = HEAP32[560624>>2]|0;
   $105 = (($104) + 28|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = (($104) + 32|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($106) + ($108<<3)|0);
   $110 = ($111|0)==($109|0);
   if ($110) {
    label = 31;
   } else {
    $112 = (($111) + 4|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = ($113|0)==(0|0);
    if ($114) {
     label = 31;
    }
   }
  }
  if ((label|0) == 31) {
   $115 = HEAP32[$81>>2]|0;
   $116 = (__Z31ReadObjectFromPersistentManageri($115)|0);
   $117 = ($116|0)==(0|0);
   if ($117) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $118 = HEAP32[$81>>2]|0;
  HEAP32[$0>>2] = $118;
  $119 = HEAP32[560624>>2]|0;
  $120 = ($119|0)==(0|0);
  if ($120) {
   label = 40;
  } else {
   $121 = (($119) + 36|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = (($119) + 4|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($122|0)==($124|0);
   do {
    if ($125) {
     $126 = (($119) + 28|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = (($119) + 32|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = (($127) + ($129<<3)|0);
     $146 = $130;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i12,$119,$0);
     $131 = HEAP32[$pos$i$i$i$i12>>2]|0;
     $132 = ($131|0)==(-1);
     $133 = (($119) + 28|0);
     $134 = HEAP32[$133>>2]|0;
     if ($132) {
      $135 = (($119) + 32|0);
      $136 = HEAP32[$135>>2]|0;
      $137 = (($134) + ($136<<3)|0);
      $146 = $137;
      break;
     } else {
      $138 = (($134) + ($131<<3)|0);
      $146 = $138;
      break;
     }
    }
   } while(0);
   $139 = HEAP32[560624>>2]|0;
   $140 = (($139) + 28|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = (($139) + 32|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = (($141) + ($143<<3)|0);
   $145 = ($146|0)==($144|0);
   if ($145) {
    label = 40;
   } else {
    $147 = (($146) + 4|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ($148|0)==(0|0);
    if ($149) {
     label = 40;
    } else {
     $temp$0$i16 = $148;
    }
   }
  }
  if ((label|0) == 40) {
   $150 = HEAP32[$81>>2]|0;
   $151 = (__Z31ReadObjectFromPersistentManageri($150)|0);
   $temp$0$i16 = $151;
  }
  $152 = (($temp$0$i16) + 84|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = ($153|0)!=(0);
  $$0 = $154;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK16LightmapSettings23HasLightProbeTetrahedraEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $pos$i$i$i$i1 = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(2);
 if ($4) {
  $5 = (__ZNK16LightmapSettings19AreLightProbesBakedEv($this)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $7;
 $9 = HEAP32[560624>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  label = 12;
 } else {
  $11 = (($9) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($9) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  do {
   if ($15) {
    $16 = (($9) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($9) + 32|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($17) + ($19<<3)|0);
    $36 = $20;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$9,$1);
    $21 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $22 = ($21|0)==(-1);
    $23 = (($9) + 28|0);
    $24 = HEAP32[$23>>2]|0;
    if ($22) {
     $25 = (($9) + 32|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($24) + ($26<<3)|0);
     $36 = $27;
     break;
    } else {
     $28 = (($24) + ($21<<3)|0);
     $36 = $28;
     break;
    }
   }
  } while(0);
  $29 = HEAP32[560624>>2]|0;
  $30 = (($29) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 32|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + ($33<<3)|0);
  $35 = ($36|0)==($34|0);
  if ($35) {
   label = 12;
  } else {
   $37 = (($36) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    label = 12;
   }
  }
 }
 if ((label|0) == 12) {
  $40 = HEAP32[$6>>2]|0;
  $41 = (__Z31ReadObjectFromPersistentManageri($40)|0);
  $42 = ($41|0)==(0|0);
  if ($42) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $43 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $43;
 $44 = HEAP32[560624>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  label = 21;
 } else {
  $46 = (($44) + 36|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($44) + 4|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($47|0)==($49|0);
  do {
   if ($50) {
    $51 = (($44) + 28|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($44) + 32|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($52) + ($54<<3)|0);
    $71 = $55;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$44,$0);
    $56 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $57 = ($56|0)==(-1);
    $58 = (($44) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    if ($57) {
     $60 = (($44) + 32|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (($59) + ($61<<3)|0);
     $71 = $62;
     break;
    } else {
     $63 = (($59) + ($56<<3)|0);
     $71 = $63;
     break;
    }
   }
  } while(0);
  $64 = HEAP32[560624>>2]|0;
  $65 = (($64) + 28|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($64) + 32|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($66) + ($68<<3)|0);
  $70 = ($71|0)==($69|0);
  if ($70) {
   label = 21;
  } else {
   $72 = (($71) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    label = 21;
   } else {
    $temp$0$i5 = $73;
   }
  }
 }
 if ((label|0) == 21) {
  $75 = HEAP32[$6>>2]|0;
  $76 = (__Z31ReadObjectFromPersistentManageri($75)|0);
  $temp$0$i5 = $76;
 }
 $77 = (($temp$0$i5) + 36|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)>(0);
 $$0 = $79;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK16LightmapSettings28GetUseDualLightmapsInForwardEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if (!($2)) {
  $6 = 0;
  STACKTOP = sp;return ($6|0);
 }
 $3 = (($this) + 96|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = $5;
 STACKTOP = sp;return ($6|0);
}
function __ZN16LightmapSettings15AppendLightmapsERK13dynamic_arrayI12LightmapDataLj4EE($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$012$i$i = 0, $$03$i$i = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $dataSize$0 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp;
 $0 = sp + 24|0;
 $1 = sp + 12|0;
 $2 = (($this) + 68|0);
 $3 = (($this) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($data) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4))|0;
 $8 = ($7>>>0)>(254);
 do {
  if ($8) {
   $9 = (254 - ($4))|0;
   $10 = ($9|0)>(0);
   $11 = $10 ? $9 : 0;
   HEAP32[$$byval_copy3>>2] = $6;
   $vararg_ptr1 = (($$byval_copy3) + 4|0);
   HEAP32[$vararg_ptr1>>2] = 254;
   $vararg_ptr2 = (($$byval_copy3) + 8|0);
   HEAP32[$vararg_ptr2>>2] = $11;
   __Z6FormatPKcz($1,602784,$$byval_copy3);
   $12 = HEAP8[$1>>0]|0;
   $13 = $12 & 1;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $17 = (($1) + 1|0);
    $18 = $17;
   } else {
    $15 = (($1) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $18 = $16;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($18|0),0,(602776|0),245,1,0,0,(0|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP8[$1>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     $dataSize$0 = $11;
     break;
    }
    $24 = (($1) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    __ZdlPv($25);
    $dataSize$0 = $11;
    break;
   }
   $26 = ___cxa_find_matching_catch()|0;
   $27 = tempRet0;
   $28 = HEAP8[$1>>0]|0;
   $29 = $28 & 1;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    ___resumeException($26|0);
    // unreachable;
   }
   $31 = (($1) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   __ZdlPv($32);
   ___resumeException($26|0);
   // unreachable;
  } else {
   $dataSize$0 = $6;
  }
 } while(0);
 $33 = ($dataSize$0|0)<(1);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = (($dataSize$0) + ($4))|0;
 HEAP32[$3>>2] = $34;
 $35 = (($this) + 80|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 2147483647;
 $38 = ($37>>>0)<($34>>>0);
 do {
  if ($38) {
   $39 = ($36|0)>(-1);
   if ($39) {
    HEAP32[$35>>2] = $34;
    $40 = HEAP32[$2>>2]|0;
    $41 = $34 << 3;
    $42 = (($this) + 72|0);
    $43 = HEAP32[$42>>2]|0;
    HEAP32[$0>>2] = $43;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $44 = (__Z16realloc_internalPvji10MemLabelIdiPKci($40,$41,4,$$byval_copy3,0,602776,370)|0);
    HEAP32[$2>>2] = $44;
    break;
   } else {
    $45 = $34 << 3;
    $46 = (($this) + 72|0);
    $47 = HEAP32[$46>>2]|0;
    HEAP32[$0>>2] = $47;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $48 = (__Z15malloc_internaljj10MemLabelIdiPKci($45,4,$$byval_copy3,0,602776,352)|0);
    $49 = HEAP32[$2>>2]|0;
    $50 = HEAP32[$3>>2]|0;
    $51 = $50 << 3;
    _memcpy(($48|0),($49|0),($51|0))|0;
    HEAP32[$35>>2] = $34;
    HEAP32[$2>>2] = $48;
    break;
   }
  }
 } while(0);
 $52 = HEAP32[$data>>2]|0;
 $53 = (($52) + ($dataSize$0<<3)|0);
 $54 = ($dataSize$0|0)==(0);
 if (!($54)) {
  $55 = HEAP32[$2>>2]|0;
  $56 = (($55) + ($4<<3)|0);
  $$012$i$i = $52;$$03$i$i = $56;
  while(1) {
   $57 = HEAP32[$$012$i$i>>2]|0;
   HEAP32[$$03$i$i>>2] = $57;
   $58 = (($$012$i$i) + 4|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($$03$i$i) + 4|0);
   HEAP32[$60>>2] = $59;
   $61 = (($$012$i$i) + 8|0);
   $62 = (($$03$i$i) + 8|0);
   $63 = ($61|0)==($53|0);
   if ($63) {
    break;
   } else {
    $$012$i$i = $61;$$03$i$i = $62;
   }
  }
 }
 __ZN16LightmapSettings7RebuildEv($this);
 STACKTOP = sp;return;
}
function __ZNK16LightmapSettings22GetLightmapsModeLegacyEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2);
 if ($2) {
  $3 = (($this) + 88|0);
  $4 = HEAP32[$3>>2]|0;
  $$0 = $4;
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK16LightmapSettings25GetInterpolatedLightProbeERK8Vector3fRiPf($this,$position,$tetIndex,$coefficients) {
 $this = $this|0;
 $position = $position|0;
 $tetIndex = $tetIndex|0;
 $coefficients = $coefficients|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $8 = 0, $9 = 0, $pos$i$i$i$i1 = 0, $temp = 0, $temp$0$i = 0;
 var $temp$0$i5 = 0, $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i1 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $temp = sp + 8|0;
 $temp1 = sp + 24|0;
 $2 = (($this) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(2);
 if ($4) {
  $5 = (($this) + 64|0);
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$1>>2] = $6;
  $7 = HEAP32[560624>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   label = 10;
  } else {
   $9 = (($7) + 36|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($7) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($10|0)==($12|0);
   do {
    if ($13) {
     $14 = (($7) + 28|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($7) + 32|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($15) + ($17<<3)|0);
     $34 = $18;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$7,$1);
     $19 = HEAP32[$pos$i$i$i$i1>>2]|0;
     $20 = ($19|0)==(-1);
     $21 = (($7) + 28|0);
     $22 = HEAP32[$21>>2]|0;
     if ($20) {
      $23 = (($7) + 32|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($22) + ($24<<3)|0);
      $34 = $25;
      break;
     } else {
      $26 = (($22) + ($19<<3)|0);
      $34 = $26;
      break;
     }
    }
   } while(0);
   $27 = HEAP32[560624>>2]|0;
   $28 = (($27) + 28|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + 32|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + ($31<<3)|0);
   $33 = ($34|0)==($32|0);
   if ($33) {
    label = 10;
   } else {
    $35 = (($34) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     label = 10;
    } else {
     $temp$0$i = $36;
    }
   }
  }
  if ((label|0) == 10) {
   $38 = HEAP32[$5>>2]|0;
   $39 = (__Z31ReadObjectFromPersistentManageri($38)|0);
   $temp$0$i = $39;
  }
  __ZNK17LightProbesLegacy25GetInterpolatedLightProbeERK8Vector3fPfRiR8Vector4fRf($temp$0$i,$position,$coefficients,$tetIndex,$temp,$temp1);
  STACKTOP = sp;return;
 } else {
  $40 = (($this) + 60|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$0>>2] = $41;
  $42 = HEAP32[560624>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   label = 20;
  } else {
   $44 = (($42) + 36|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($42) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($45|0)==($47|0);
   do {
    if ($48) {
     $49 = (($42) + 28|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (($42) + 32|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (($50) + ($52<<3)|0);
     $69 = $53;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$42,$0);
     $54 = HEAP32[$pos$i$i$i$i1>>2]|0;
     $55 = ($54|0)==(-1);
     $56 = (($42) + 28|0);
     $57 = HEAP32[$56>>2]|0;
     if ($55) {
      $58 = (($42) + 32|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = (($57) + ($59<<3)|0);
      $69 = $60;
      break;
     } else {
      $61 = (($57) + ($54<<3)|0);
      $69 = $61;
      break;
     }
    }
   } while(0);
   $62 = HEAP32[560624>>2]|0;
   $63 = (($62) + 28|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($62) + 32|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($64) + ($66<<3)|0);
   $68 = ($69|0)==($67|0);
   if ($68) {
    label = 20;
   } else {
    $70 = (($69) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71|0)==(0|0);
    if ($72) {
     label = 20;
    } else {
     $temp$0$i5 = $71;
    }
   }
  }
  if ((label|0) == 20) {
   $73 = HEAP32[$40>>2]|0;
   $74 = (__Z31ReadObjectFromPersistentManageri($73)|0);
   $temp$0$i5 = $74;
  }
  $75 = (($this) + 104|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  __ZNK11LightProbes25GetInterpolatedLightProbeERK8Vector3ffRiPfR8Vector4fRf($temp$0$i5,$position,$76,$tetIndex,$coefficients,$pos$i$i$i$i1,$1);
  STACKTOP = sp;return;
 }
}
function __ZNK16LightmapSettings28GetNonInterpolatedLightProbeEiPf($this,$probeIndex,$coefficients) {
 $this = $this|0;
 $probeIndex = $probeIndex|0;
 $coefficients = $coefficients|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0;
 var $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[560624>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $10 = (($3) + 28|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($3) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + ($13<<3)|0);
    $30 = $14;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
    $15 = HEAP32[$pos$i$i$i$i>>2]|0;
    $16 = ($15|0)==(-1);
    $17 = (($3) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    if ($16) {
     $19 = (($3) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $30 = $21;
     break;
    } else {
     $22 = (($18) + ($15<<3)|0);
     $30 = $22;
     break;
    }
   }
  } while(0);
  $23 = HEAP32[560624>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + ($27<<3)|0);
  $29 = ($30|0)==($28|0);
  if (!($29)) {
   $31 = (($30) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $temp$0$i = $32;
    $36 = (($this) + 104|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = (__ZNK11LightProbes15GetCoefficientsEjfPf($temp$0$i,$probeIndex,$37,$coefficients)|0);
    STACKTOP = sp;return ($38|0);
   }
  }
 }
 $34 = HEAP32[$1>>2]|0;
 $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
 $temp$0$i = $35;
 $36 = (($this) + 104|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (__ZNK11LightProbes15GetCoefficientsEjfPf($temp$0$i,$probeIndex,$37,$coefficients)|0);
 STACKTOP = sp;return ($38|0);
}
function __ZNK16LightmapSettings23GetLightmapDecodeValuesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($agg$result,0,0,Math_fround(1.0));
  STACKTOP = sp;return;
 }
 $4 = (($this) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 do {
  if (!($7)) {
   HEAP32[$0>>2] = $6;
   $8 = HEAP32[560624>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    label = 12;
   } else {
    $10 = (($8) + 36|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($8) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    do {
     if ($14) {
      $15 = (($8) + 28|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($8) + 32|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($16) + ($18<<3)|0);
      $35 = $19;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$8,$0);
      $20 = HEAP32[$pos$i$i$i$i>>2]|0;
      $21 = ($20|0)==(-1);
      $22 = (($8) + 28|0);
      $23 = HEAP32[$22>>2]|0;
      if ($21) {
       $24 = (($8) + 32|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (($23) + ($25<<3)|0);
       $35 = $26;
       break;
      } else {
       $27 = (($23) + ($20<<3)|0);
       $35 = $27;
       break;
      }
     }
    } while(0);
    $28 = HEAP32[560624>>2]|0;
    $29 = (($28) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 32|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + ($32<<3)|0);
    $34 = ($35|0)==($33|0);
    if ($34) {
     label = 12;
    } else {
     $36 = (($35) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      label = 12;
     } else {
      $temp$0$i2 = $37;
     }
    }
   }
   if ((label|0) == 12) {
    $39 = HEAP32[$5>>2]|0;
    $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
    $41 = ($40|0)==(0|0);
    if ($41) {
     break;
    } else {
     $temp$0$i2 = $40;
    }
   }
   $42 = (($temp$0$i2) + 52|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__Z19GetActiveColorSpacev()|0);
   $45 = ($44|0)==(1);
   if ($45) {
    $46 = (($temp$0$i2) + 56|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = $47;
   } else {
    $48 = 0;
   }
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($agg$result,$43,$48,Math_fround(1.0));
   STACKTOP = sp;return;
  }
 } while(0);
 __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($agg$result,0,0,Math_fround(1.0));
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings16CheckConsistencyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z30RegisterClass_LightmapSettingsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(157,125,0,0,0);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(3)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN16LevelGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 16;
 dest=$3+0|0; src=602960+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 16|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,157,3,($0|0),204,(2396|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN16LightmapSettings7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(204,$$byval_copy2,1,16,602776,55)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1739,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(602776|0),55);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK16LightmapSettings25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 157;
}
function __ZN16LightmapSettings23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,602984,602960,$this,0);
 __ZN16LightmapSettings8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,602984,602960,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN16LightmapSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LightmapSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LightmapSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LightmapSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LightmapSettings8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z19GetLightmapSettingsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(18)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN16LightmapSettingsD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LightmapSettingsD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettingsD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3484,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN16LightmapSettings8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01$i$i$i = 0, $i$01$us$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LevelGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 $12 = (($this) + 120|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 128|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + (($15*40)|0)|0);
 $17 = ($15|0)==(0);
 if (!($17)) {
  $i$01$us$i$i$i$i$i$i = $13;
  while(1) {
   $18 = HEAP32[$i$01$us$i$i$i$i$i$i>>2]|0;
   $19 = HEAP32[$2>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$6>>2]|0;
   $23 = (FUNCTION_TABLE_iiii[$21 & 2047]($19,$18,$22)|0);
   $24 = HEAP8[$9>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if (!($25)) {
    HEAP32[$i$01$us$i$i$i$i$i$i>>2] = $23;
   }
   $26 = (($i$01$us$i$i$i$i$i$i) + 40|0);
   $27 = ($26|0)==($16|0);
   if ($27) {
    break;
   } else {
    $i$01$us$i$i$i$i$i$i = $26;
   }
  }
 }
 $28 = (($this) + 60|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$2>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$6>>2]|0;
 $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$29,$33)|0);
 $35 = HEAP8[$9>>0]|0;
 $36 = ($35<<24>>24)==(0);
 if (!($36)) {
  HEAP32[$28>>2] = $34;
 }
 $37 = (($this) + 68|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($this) + 76|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + ($40<<3)|0);
 $42 = ($40|0)==(0);
 if ($42) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i = $38;
 }
 while(1) {
  $43 = HEAP32[$i$01$i$i$i>>2]|0;
  $44 = HEAP32[$2>>2]|0;
  $45 = HEAP32[$44>>2]|0;
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$6>>2]|0;
  $48 = (FUNCTION_TABLE_iiii[$46 & 2047]($44,$43,$47)|0);
  $49 = HEAP8[$9>>0]|0;
  $50 = ($49<<24>>24)==(0);
  if (!($50)) {
   HEAP32[$i$01$i$i$i>>2] = $48;
  }
  $51 = (($i$01$i$i$i) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = HEAP32[$2>>2]|0;
  $54 = HEAP32[$53>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = HEAP32[$6>>2]|0;
  $57 = (FUNCTION_TABLE_iiii[$55 & 2047]($53,$52,$56)|0);
  $58 = HEAP8[$9>>0]|0;
  $59 = ($58<<24>>24)==(0);
  if (!($59)) {
   HEAP32[$51>>2] = $57;
  }
  $60 = (($i$01$i$i$i) + 8|0);
  $61 = ($60|0)==($41|0);
  if ($61) {
   break;
  } else {
   $i$01$i$i$i = $60;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16LightmapSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 __ZN16LevelGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 64|0);
 __ZN4PPtrI17LightProbesLegacyE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 84|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  $8 = HEAP32[$1>>2]|0;
  HEAP32[$3>>2] = $8;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$1,4);
 }
 $9 = (($this) + 120|0);
 __ZN21EnlightenSceneMapping8TransferI19StreamedBinaryWriteILb0EEEEvRT_($9,$transfer);
 $10 = (($this) + 60|0);
 __ZN4PPtrI11LightProbesE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 76|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$size$i$i$i>>2] = $12;
 $13 = HEAP32[$2>>2]|0;
 $14 = (($13) + 4|0);
 $15 = HEAP32[$5>>2]|0;
 $16 = ($14>>>0)<($15>>>0);
 if ($16) {
  HEAP32[$13>>2] = $12;
  HEAP32[$2>>2] = $14;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i,4);
 }
 $17 = (($this) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$11>>2]|0;
 $20 = (($18) + ($19<<3)|0);
 $21 = ($19|0)==(0);
 if (!($21)) {
  $i$01$i$i$i = $18;
  while(1) {
   __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $22 = (($i$01$i$i$i) + 4|0);
   __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($22,$transfer);
   $23 = (($i$01$i$i$i) + 8|0);
   $24 = ($23|0)==($20|0);
   if ($24) {
    break;
   } else {
    $i$01$i$i$i = $23;
   }
  }
 }
 $25 = (($this) + 88|0);
 $26 = HEAP32[$2>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$5>>2]|0;
 $29 = ($27>>>0)<($28>>>0);
 if ($29) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$26>>2] = $30;
  HEAP32[$2>>2] = $27;
  $33 = $27;$35 = $28;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$25,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre4 = HEAP32[$5>>2]|0;
  $33 = $$pre;$35 = $$pre4;
 }
 $31 = (($this) + 92|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = HEAP32[$31>>2]|0;
  HEAP32[$33>>2] = $36;
  HEAP32[$2>>2] = $32;
  $39 = $32;$41 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$31,4);
  $$pre5 = HEAP32[$2>>2]|0;
  $$pre6 = HEAP32[$5>>2]|0;
  $39 = $$pre5;$41 = $$pre6;
 }
 $37 = (($this) + 96|0);
 $38 = (($39) + 1|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = HEAP8[$37>>0]|0;
  HEAP8[$39>>0] = $42;
  $43 = HEAP32[$2>>2]|0;
  $44 = (($43) + 1|0);
  HEAP32[$2>>2] = $44;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$37,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $45 = (($this) + 100|0);
 __ZN10GISettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($45,$transfer);
 $46 = (($this) + 200|0);
 $47 = HEAP32[$2>>2]|0;
 $48 = (($47) + 4|0);
 $49 = HEAP32[$5>>2]|0;
 $50 = ($48>>>0)<($49>>>0);
 if ($50) {
  $51 = HEAP32[$46>>2]|0;
  HEAP32[$47>>2] = $51;
  HEAP32[$2>>2] = $48;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$46,4);
  STACKTOP = sp;return;
 }
}
function __ZN10GISettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0);
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $27 = $$pre9;$29 = $$pre10;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 1|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = HEAP8[$25>>0]|0;
  HEAP8[$27>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  $35 = $32;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,1);
  $$pre11 = HEAP32[$0>>2]|0;
  $35 = $$pre11;
 }
 $33 = (($this) + 17|0);
 $34 = (($35) + 1|0);
 $36 = HEAP32[$3>>2]|0;
 $37 = ($34>>>0)<($36>>>0);
 if ($37) {
  $38 = HEAP8[$33>>0]|0;
  HEAP8[$35>>0] = $38;
  $39 = HEAP32[$0>>2]|0;
  $40 = (($39) + 1|0);
  HEAP32[$0>>2] = $40;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$33,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI11LightProbesE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN21EnlightenSceneMapping8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, $i$01$i$i$i3 = 0, $i$01$i$i$i7 = 0, $size$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i5 = sp;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI13dynamic_arrayI28EnlightenRendererInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$this,0);
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i5>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i5,4);
 }
 $8 = (($this) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = (($9) + (($10*56)|0)|0);
 $12 = ($10|0)==(0);
 if (!($12)) {
  $i$01$i$i$i = $9;
  while(1) {
   __ZN26EnlightenSystemInformation8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $13 = (($i$01$i$i$i) + 56|0);
   $14 = ($13|0)==($11|0);
   if ($14) {
    break;
   } else {
    $i$01$i$i$i = $13;
   }
  }
 }
 $15 = (($this) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$size$i$i$i5>>2] = $16;
 $17 = HEAP32[$2>>2]|0;
 $18 = (($17) + 4|0);
 $19 = HEAP32[$5>>2]|0;
 $20 = ($18>>>0)<($19>>>0);
 if ($20) {
  HEAP32[$17>>2] = $16;
  HEAP32[$2>>2] = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i5,4);
 }
 $21 = (($this) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$15>>2]|0;
 $24 = (($22) + ($23<<5)|0);
 $25 = ($23|0)==(0);
 if (!($25)) {
  $i$01$i$i$i3 = $22;
  while(1) {
   $26 = HEAP32[$2>>2]|0;
   $27 = (($26) + 4|0);
   $28 = HEAP32[$5>>2]|0;
   $29 = ($27>>>0)<($28>>>0);
   if ($29) {
    $30 = HEAP32[$i$01$i$i$i3>>2]|0;
    HEAP32[$26>>2] = $30;
    HEAP32[$2>>2] = $27;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i3,4);
   }
   $31 = (($i$01$i$i$i3) + 8|0);
   __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($31,$transfer);
   $32 = (($i$01$i$i$i3) + 24|0);
   $33 = HEAP32[$2>>2]|0;
   $34 = (($33) + 4|0);
   $35 = HEAP32[$5>>2]|0;
   $36 = ($34>>>0)<($35>>>0);
   if ($36) {
    $37 = HEAP32[$32>>2]|0;
    HEAP32[$33>>2] = $37;
    HEAP32[$2>>2] = $34;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$32,4);
   }
   $38 = (($i$01$i$i$i3) + 32|0);
   $39 = ($38|0)==($24|0);
   if ($39) {
    break;
   } else {
    $i$01$i$i$i3 = $38;
   }
  }
 }
 $40 = (($this) + 56|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$size$i$i$i5>>2] = $41;
 $42 = HEAP32[$2>>2]|0;
 $43 = (($42) + 4|0);
 $44 = HEAP32[$5>>2]|0;
 $45 = ($43>>>0)<($44>>>0);
 if ($45) {
  HEAP32[$42>>2] = $41;
  HEAP32[$2>>2] = $43;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i5,4);
 }
 $46 = (($this) + 48|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$40>>2]|0;
 $49 = (($47) + (($48*12)|0)|0);
 $50 = ($48|0)==(0);
 if ($50) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i7 = $47;
 }
 while(1) {
  $51 = HEAP32[$2>>2]|0;
  $52 = (($51) + 4|0);
  $53 = HEAP32[$5>>2]|0;
  $54 = ($52>>>0)<($53>>>0);
  if ($54) {
   $55 = HEAP32[$i$01$i$i$i7>>2]|0;
   HEAP32[$51>>2] = $55;
   HEAP32[$2>>2] = $52;
   $58 = $52;$60 = $53;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i7,4);
   $$pre$i$i$i = HEAP32[$2>>2]|0;
   $$pre3$i$i$i = HEAP32[$5>>2]|0;
   $58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  }
  $56 = (($i$01$i$i$i7) + 4|0);
  $57 = (($58) + 4|0);
  $59 = ($57>>>0)<($60>>>0);
  if ($59) {
   $61 = HEAP32[$56>>2]|0;
   HEAP32[$58>>2] = $61;
   HEAP32[$2>>2] = $57;
   $64 = $57;$66 = $60;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$56,4);
   $$pre4$i$i$i = HEAP32[$2>>2]|0;
   $$pre5$i$i$i = HEAP32[$5>>2]|0;
   $64 = $$pre4$i$i$i;$66 = $$pre5$i$i$i;
  }
  $62 = (($i$01$i$i$i7) + 8|0);
  $63 = (($64) + 4|0);
  $65 = ($63>>>0)<($66>>>0);
  if ($65) {
   $67 = HEAP32[$62>>2]|0;
   HEAP32[$64>>2] = $67;
   HEAP32[$2>>2] = $63;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$62,4);
  }
  $68 = (($i$01$i$i$i7) + 12|0);
  $69 = ($68|0)==($49|0);
  if ($69) {
   break;
  } else {
   $i$01$i$i$i7 = $68;
  }
 }
 STACKTOP = sp;return;
}
function __ZN26EnlightenSystemInformation8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$13>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $27 = $$pre9;$29 = $$pre10;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$27>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = (($this) + 24|0);
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($31,$transfer);
  $32 = (($this) + 40|0);
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($32,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,4);
  $31 = (($this) + 24|0);
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($31,$transfer);
  $32 = (($this) + 40|0);
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($32,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI13dynamic_arrayI28EnlightenRendererInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size,4);
 }
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$1>>2]|0;
 $11 = (($9) + (($10*40)|0)|0);
 $12 = ($10|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $9;
 }
 while(1) {
  __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01,$this);
  $13 = (($i$01) + 4|0);
  __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($13,$this);
  $14 = (($i$01) + 20|0);
  $15 = HEAP32[$3>>2]|0;
  $16 = (($15) + 4|0);
  $17 = HEAP32[$6>>2]|0;
  $18 = ($16>>>0)<($17>>>0);
  if ($18) {
   $19 = HEAP32[$14>>2]|0;
   HEAP32[$15>>2] = $19;
   HEAP32[$3>>2] = $16;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$14,4);
  }
  $20 = (($i$01) + 24|0);
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($20,$this);
  $21 = (($i$01) + 40|0);
  $22 = ($21|0)==($11|0);
  if ($22) {
   break;
  } else {
   $i$01 = $21;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI17LightProbesLegacyE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN16LightmapSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LevelGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 64|0);
 __ZN4PPtrI17LightProbesLegacyE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($this) + 84|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre$i$i$i1 = HEAP32[$1>>2]|0;
  $9 = $$pre$i$i$i1;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$1>>2] = $10;
 $11 = (($this) + 120|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI28EnlightenRendererInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$11,0);
 $12 = (($this) + 136|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI26EnlightenSystemInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$12,0);
 $13 = (($this) + 152|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$13,0);
 $14 = (($this) + 168|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEEEvRT_17TransferMetaFlags($transfer,$14,0);
 __ZN21EnlightenSceneMapping16BuildRemapTablesEv($11);
 $15 = (($this) + 60|0);
 __ZN4PPtrI11LightProbesE8TransferI18StreamedBinaryReadILb1EEEEvRT_($15,$transfer);
 $16 = (($this) + 68|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI12LightmapDataLj4EEEEvRT_17TransferMetaFlags($transfer,$16,0);
 $17 = (($this) + 88|0);
 $18 = HEAP32[$2>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$5>>2]|0;
 $21 = ($19>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre7 = HEAP32[$5>>2]|0;
  $23 = $$pre$i$i$i3;$27 = $$pre;$29 = $$pre7;
 } else {
  $22 = HEAP32[$18>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$2>>2] = $19;
  $23 = $22;$27 = $19;$29 = $20;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$17>>2] = $24;
 $25 = (($this) + 92|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$25,4);
  $$pre$i$i$i5 = HEAP32[$25>>2]|0;
  $$pre8 = HEAP32[$2>>2]|0;
  $$pre9 = HEAP32[$5>>2]|0;
  $31 = $$pre$i$i$i5;$35 = $$pre8;$37 = $$pre9;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$2>>2] = $26;
  $31 = $30;$35 = $26;$37 = $29;
 }
 $32 = (_llvm_bswap_i32(($31|0))|0);
 HEAP32[$25>>2] = $32;
 $33 = (($this) + 96|0);
 $34 = (($35) + 1|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$33,1);
 } else {
  $38 = HEAP8[$35>>0]|0;
  HEAP8[$33>>0] = $38;
  $39 = HEAP32[$2>>2]|0;
  $40 = (($39) + 1|0);
  HEAP32[$2>>2] = $40;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $41 = (($this) + 100|0);
 __ZN10GISettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($41,$transfer);
 $42 = (($this) + 200|0);
 $43 = HEAP32[$2>>2]|0;
 $44 = (($43) + 4|0);
 $45 = HEAP32[$5>>2]|0;
 $46 = ($44>>>0)>($45>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$42,4);
  $$pre$i$i$i = HEAP32[$42>>2]|0;
  $48 = $$pre$i$i$i;
  $49 = (_llvm_bswap_i32(($48|0))|0);
  HEAP32[$42>>2] = $49;
  STACKTOP = sp;return;
 } else {
  $47 = HEAP32[$43>>2]|0;
  HEAP32[$42>>2] = $47;
  HEAP32[$2>>2] = $44;
  $48 = $47;
  $49 = (_llvm_bswap_i32(($48|0))|0);
  HEAP32[$42>>2] = $49;
  STACKTOP = sp;return;
 }
}
function __ZN10GISettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $this;$12 = $$pre;$14 = $$pre13;$8 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i3 = HEAP32[$10>>2]|0;
  $$pre14 = HEAP32[$0>>2]|0;
  $$pre15 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $10;$17 = $$pre$i$i$i3;$21 = $$pre14;$23 = $$pre15;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i8 = HEAP32[$19>>2]|0;
  $$pre16 = HEAP32[$0>>2]|0;
  $$pre17 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $19;$26 = $$pre$i$i$i8;$30 = $$pre16;$32 = $$pre17;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i11 = HEAP32[$28>>2]|0;
  $$pre18 = HEAP32[$0>>2]|0;
  $$pre19 = HEAP32[$3>>2]|0;
  $34 = $$pre$i$i$i11;$38 = $$pre18;$40 = $$pre19;
 } else {
  $33 = HEAP32[$30>>2]|0;
  HEAP32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = $33;$38 = $29;$40 = $32;
 }
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$28>>2] = $35;
 $36 = (($this) + 16|0);
 $37 = (($38) + 1|0);
 $39 = ($37>>>0)>($40>>>0);
 if ($39) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$36,1);
  $$pre20 = HEAP32[$0>>2]|0;
  $46 = $$pre20;
 } else {
  $41 = HEAP8[$38>>0]|0;
  HEAP8[$36>>0] = $41;
  $42 = HEAP32[$0>>2]|0;
  $43 = (($42) + 1|0);
  HEAP32[$0>>2] = $43;
  $46 = $43;
 }
 $44 = (($this) + 17|0);
 $45 = (($46) + 1|0);
 $47 = HEAP32[$3>>2]|0;
 $48 = ($45>>>0)>($47>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$44,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $49 = HEAP8[$46>>0]|0;
  HEAP8[$44>>0] = $49;
  $50 = HEAP32[$0>>2]|0;
  $51 = (($50) + 1|0);
  HEAP32[$0>>2] = $51;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI12LightmapDataLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI12LightmapDataLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<3)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 4|0);
   __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($44,$this);
   $45 = (($i$04) + 8|0);
   $46 = ($45|0)==($42|0);
   if ($46) {
    break;
   } else {
    $i$04 = $45;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = $23 << 3;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = $22 >> 3;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI12LightmapDataLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 3;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,602776,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 3;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,602776,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 3;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<3)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<3)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   HEAP32[$$01$i$i>>2] = 0;
   $30 = (($$01$i$i) + 4|0);
   HEAP32[$30>>2] = 0;
  }
  $31 = (($$01$i$i) + 8|0);
  $32 = ($31|0)==($25|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN4PPtrI11LightProbesE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*12)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN33EnlightenTerrainChunksInformation8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 12|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = ($23*12)|0;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = (($22|0) / 12)&-1;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $6 = (($data) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = ($rs*12)|0;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,4,$$byval_copy1,0,602776,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = ($rs*12)|0;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,4,$$byval_copy1,0,602776,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21*12)|0;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + (($rs*12)|0)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + (($24*12)|0)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$1+8>>2]|0;
  }
  $31 = (($$01$i$i) + 12|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN33EnlightenTerrainChunksInformation8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre5;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre6;$21 = $$pre7;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $23 = $$pre$i$i$i3;
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$17>>2] = $24;
  STACKTOP = sp;return;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = $22;
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$17>>2] = $24;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i1$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if (!($6)) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre5 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre6 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i1;$23 = $$pre6;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = $23 << 5;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = $22 >> 5;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
  $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
  $35 = $$pre$i$i$i3;
 } else {
  $34 = HEAP32[$7>>2]|0;
  HEAP32[$size1>>2] = $34;
  HEAP32[$3>>2] = $8;
  $35 = $34;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$size1>>2] = $36;
 $37 = (($this) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$2>>2] = $38;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
 $39 = HEAP32[$data>>2]|0;
 $40 = (($data) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + ($41<<5)|0);
 $43 = ($41|0)==(0);
 if ($43) {
  STACKTOP = sp;return;
 } else {
  $i$04 = $39;
 }
 while(1) {
  $44 = HEAP32[$3>>2]|0;
  $45 = (($44) + 4|0);
  $46 = HEAP32[$9>>2]|0;
  $47 = ($45>>>0)>($46>>>0);
  if ($47) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$04,4);
   $$pre$i$i$i$i$i$i = HEAP32[$i$04>>2]|0;
   $49 = $$pre$i$i$i$i$i$i;
  } else {
   $48 = HEAP32[$44>>2]|0;
   HEAP32[$i$04>>2] = $48;
   HEAP32[$3>>2] = $45;
   $49 = $48;
  }
  $50 = (_llvm_bswap_i32(($49|0))|0);
  HEAP32[$i$04>>2] = $50;
  $51 = (($i$04) + 8|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($51,$this);
  $52 = (($i$04) + 24|0);
  $53 = HEAP32[$3>>2]|0;
  $54 = (($53) + 4|0);
  $55 = HEAP32[$9>>2]|0;
  $56 = ($54>>>0)>($55>>>0);
  if ($56) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$52,4);
   $$pre$i$i$i1$i$i$i = HEAP32[$52>>2]|0;
   $58 = $$pre$i$i$i1$i$i$i;
  } else {
   $57 = HEAP32[$53>>2]|0;
   HEAP32[$52>>2] = $57;
   HEAP32[$3>>2] = $54;
   $58 = $57;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  HEAP32[$52>>2] = $59;
  $60 = (($i$04) + 32|0);
  $61 = ($60|0)==($42|0);
  if ($61) {
   break;
  } else {
   $i$04 = $60;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 36|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($data) + 12|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;HEAP32[$1+28>>2]=0|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = $rs << 5;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,8,$$byval_copy1,0,602776,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = $rs << 5;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,8,$$byval_copy1,0,602776,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 << 5;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + ($rs<<5)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + ($24<<5)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$01$i$i+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$01$i$i+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$01$i$i+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$$01$i$i+24>>2]=HEAP32[$1+24>>2]|0;HEAP32[$$01$i$i+28>>2]=HEAP32[$1+28>>2]|0;
  }
  $31 = (($$01$i$i) + 32|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI26EnlightenSystemInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI26EnlightenSystemInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*56)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN26EnlightenSystemInformation8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 56|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = ($23*56)|0;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = (($22|0) / 56)&-1;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI26EnlightenSystemInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 60|0;
 $0 = sp + 56|0;
 $1 = sp;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($data) + 12|0);
 dest=$1+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = ($rs*56)|0;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,8,$$byval_copy1,0,602776,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = ($rs*56)|0;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,8,$$byval_copy1,0,602776,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21*56)|0;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + (($rs*56)|0)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + (($24*56)|0)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   dest=$$01$i$i+0|0; src=$1+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $31 = (($$01$i$i) + 56|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN26EnlightenSystemInformation8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i6 = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre8;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre9;$21 = $$pre10;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $$pre11 = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $23 = $$pre$i$i$i3;$27 = $$pre11;$29 = $$pre12;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = $22;$27 = $18;$29 = $21;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$17>>2] = $24;
 $25 = (($this) + 12|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre$i$i$i4 = HEAP32[$25>>2]|0;
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $31 = $$pre$i$i$i4;$35 = $$pre13;$37 = $$pre14;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = $30;$35 = $26;$37 = $29;
 }
 $32 = (_llvm_bswap_i32(($31|0))|0);
 HEAP32[$25>>2] = $32;
 $33 = (($this) + 16|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$33,4);
  $$pre$i$i$i6 = HEAP32[$33>>2]|0;
  $39 = $$pre$i$i$i6;
  $40 = (_llvm_bswap_i32(($39|0))|0);
  HEAP32[$33>>2] = $40;
  $41 = (($this) + 24|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($41,$transfer);
  $42 = (($this) + 40|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($42,$transfer);
  STACKTOP = sp;return;
 } else {
  $38 = HEAP32[$35>>2]|0;
  HEAP32[$33>>2] = $38;
  HEAP32[$0>>2] = $34;
  $39 = $38;
  $40 = (_llvm_bswap_i32(($39|0))|0);
  HEAP32[$33>>2] = $40;
  $41 = (($this) + 24|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($41,$transfer);
  $42 = (($this) + 40|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($42,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI28EnlightenRendererInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI28EnlightenRendererInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*40)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 4|0);
   __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($44,$this);
   $45 = (($i$04) + 20|0);
   $46 = HEAP32[$3>>2]|0;
   $47 = (($46) + 4|0);
   $48 = HEAP32[$9>>2]|0;
   $49 = ($47>>>0)>($48>>>0);
   if ($49) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$45,4);
    $$pre$i$i$i$i$i$i = HEAP32[$45>>2]|0;
    $51 = $$pre$i$i$i$i$i$i;
   } else {
    $50 = HEAP32[$46>>2]|0;
    HEAP32[$45>>2] = $50;
    HEAP32[$3>>2] = $47;
    $51 = $50;
   }
   $52 = (_llvm_bswap_i32(($51|0))|0);
   HEAP32[$45>>2] = $52;
   $53 = (($i$04) + 24|0);
   __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($53,$this);
   $54 = (($i$04) + 40|0);
   $55 = ($54|0)==($42|0);
   if ($55) {
    break;
   } else {
    $i$04 = $54;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre5 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre6 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i1;$23 = $$pre6;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = ($23*40)|0;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = (($22|0) / 40)&-1;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI13dynamic_arrayI28EnlightenRendererInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 40|0;
 $0 = sp;
 $$sroa$1 = sp + 4|0;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 dest=$$sroa$1+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = ($rs*40)|0;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,8,$$byval_copy1,0,602776,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = ($rs*40)|0;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,8,$$byval_copy1,0,602776,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20*40)|0;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + (($rs*40)|0)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + (($23*40)|0)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   HEAP32[$$01$i$i>>2] = 0;
   $30 = (($$01$i$i) + 4|0);
   dest=$30+0|0; src=$$sroa$1+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $31 = (($$01$i$i) + 40|0);
  $32 = ($31|0)==($25|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI17LightProbesLegacyE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN16LightmapSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16LevelGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 64|0);
 __ZN4PPtrI17LightProbesLegacyE8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 84|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
 }
 $9 = (($this) + 120|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI28EnlightenRendererInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$9,0);
 $10 = (($this) + 136|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI26EnlightenSystemInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$10,0);
 $11 = (($this) + 152|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$11,0);
 $12 = (($this) + 168|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEEEvRT_17TransferMetaFlags($transfer,$12,0);
 __ZN21EnlightenSceneMapping16BuildRemapTablesEv($9);
 $13 = (($this) + 60|0);
 __ZN4PPtrI11LightProbesE8TransferI18StreamedBinaryReadILb0EEEEvRT_($13,$transfer);
 $14 = (($this) + 68|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI12LightmapDataLj4EEEEvRT_17TransferMetaFlags($transfer,$14,0);
 $15 = (($this) + 88|0);
 $16 = HEAP32[$2>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$5>>2]|0;
 $19 = ($17>>>0)>($18>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$15,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre4 = HEAP32[$5>>2]|0;
  $23 = $$pre;$25 = $$pre4;
 } else {
  $20 = HEAP32[$16>>2]|0;
  HEAP32[$15>>2] = $20;
  HEAP32[$2>>2] = $17;
  $23 = $17;$25 = $18;
 }
 $21 = (($this) + 92|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$21,4);
  $$pre5 = HEAP32[$2>>2]|0;
  $$pre6 = HEAP32[$5>>2]|0;
  $29 = $$pre5;$31 = $$pre6;
 } else {
  $26 = HEAP32[$23>>2]|0;
  HEAP32[$21>>2] = $26;
  HEAP32[$2>>2] = $22;
  $29 = $22;$31 = $25;
 }
 $27 = (($this) + 96|0);
 $28 = (($29) + 1|0);
 $30 = ($28>>>0)>($31>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$27,1);
 } else {
  $32 = HEAP8[$29>>0]|0;
  HEAP8[$27>>0] = $32;
  $33 = HEAP32[$2>>2]|0;
  $34 = (($33) + 1|0);
  HEAP32[$2>>2] = $34;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $35 = (($this) + 100|0);
 __ZN10GISettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($35,$transfer);
 $36 = (($this) + 200|0);
 $37 = HEAP32[$2>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$5>>2]|0;
 $40 = ($38>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$36,4);
  STACKTOP = sp;return;
 } else {
  $41 = HEAP32[$37>>2]|0;
  HEAP32[$36>>2] = $41;
  HEAP32[$2>>2] = $38;
  STACKTOP = sp;return;
 }
}
function __ZN10GISettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0);
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $27 = $$pre9;$29 = $$pre10;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 1|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,1);
  $$pre11 = HEAP32[$0>>2]|0;
  $35 = $$pre11;
 } else {
  $30 = HEAP8[$27>>0]|0;
  HEAP8[$25>>0] = $30;
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + 1|0);
  HEAP32[$0>>2] = $32;
  $35 = $32;
 }
 $33 = (($this) + 17|0);
 $34 = (($35) + 1|0);
 $36 = HEAP32[$3>>2]|0;
 $37 = ($34>>>0)>($36>>>0);
 if ($37) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$33,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $38 = HEAP8[$35>>0]|0;
  HEAP8[$33>>0] = $38;
  $39 = HEAP32[$0>>2]|0;
  $40 = (($39) + 1|0);
  HEAP32[$0>>2] = $40;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI12LightmapDataLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI12LightmapDataLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<3)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 4|0);
   __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($40,$this);
   $41 = (($i$02) + 8|0);
   $42 = ($41|0)==($38|0);
   if ($42) {
    break;
   } else {
    $i$02 = $41;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 3;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 3;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI11LightProbesE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre3 = 0, $$pre3$i$i$i = 0, $$pre4 = 0, $$pre4$i$i$i = 0, $$pre5 = 0, $$pre5$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if (!($6)) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre3 = HEAP32[$3>>2]|0;
   $$pre4 = HEAP32[$9>>2]|0;
   $14 = $$pre3;$16 = $$pre4;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $14 = $8;$16 = $10;
  }
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre5 = HEAP32[$offset>>2]|0;
   $20 = $$pre5;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$3>>2] = $13;
   $20 = $17;
  }
  $18 = HEAP32[$size>>2]|0;
  $19 = ($18*12)|0;
  $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
  $22 = (($data) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>(-1);
  if ($24) {
   $25 = HEAP32[$data>>2]|0;
   $26 = (($data) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $28 = (($19|0) / 12)&-1;
  $29 = (($data) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $28 | -2147483648;
  HEAP32[$22>>2] = $30;
  HEAP32[$data>>2] = $21;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $34 = $$pre;
 } else {
  $31 = HEAP32[$7>>2]|0;
  HEAP32[$size1>>2] = $31;
  HEAP32[$3>>2] = $8;
  $34 = $31;
 }
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$2>>2] = $33;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
 $35 = HEAP32[$data>>2]|0;
 $36 = (($data) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + (($37*12)|0)|0);
 $39 = ($37|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 } else {
  $i$02 = $35;
 }
 while(1) {
  $40 = HEAP32[$3>>2]|0;
  $41 = (($40) + 4|0);
  $42 = HEAP32[$9>>2]|0;
  $43 = ($41>>>0)>($42>>>0);
  if ($43) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$02,4);
   $$pre$i$i$i = HEAP32[$3>>2]|0;
   $$pre3$i$i$i = HEAP32[$9>>2]|0;
   $47 = $$pre$i$i$i;$49 = $$pre3$i$i$i;
  } else {
   $44 = HEAP32[$40>>2]|0;
   HEAP32[$i$02>>2] = $44;
   HEAP32[$3>>2] = $41;
   $47 = $41;$49 = $42;
  }
  $45 = (($i$02) + 4|0);
  $46 = (($47) + 4|0);
  $48 = ($46>>>0)>($49>>>0);
  if ($48) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$45,4);
   $$pre4$i$i$i = HEAP32[$3>>2]|0;
   $$pre5$i$i$i = HEAP32[$9>>2]|0;
   $53 = $$pre4$i$i$i;$55 = $$pre5$i$i$i;
  } else {
   $50 = HEAP32[$47>>2]|0;
   HEAP32[$45>>2] = $50;
   HEAP32[$3>>2] = $46;
   $53 = $46;$55 = $49;
  }
  $51 = (($i$02) + 8|0);
  $52 = (($53) + 4|0);
  $54 = ($52>>>0)>($55>>>0);
  if ($54) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$51,4);
  } else {
   $56 = HEAP32[$53>>2]|0;
   HEAP32[$51>>2] = $56;
   HEAP32[$3>>2] = $52;
  }
  $57 = (($i$02) + 12|0);
  $58 = ($57|0)==($38|0);
  if ($58) {
   break;
  } else {
   $i$02 = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0;
 var $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if (!($6)) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre3 = HEAP32[$3>>2]|0;
   $$pre4 = HEAP32[$9>>2]|0;
   $14 = $$pre3;$16 = $$pre4;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $14 = $8;$16 = $10;
  }
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre5 = HEAP32[$offset>>2]|0;
   $20 = $$pre5;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$3>>2] = $13;
   $20 = $17;
  }
  $18 = HEAP32[$size>>2]|0;
  $19 = $18 << 5;
  $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
  $22 = (($data) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>(-1);
  if ($24) {
   $25 = HEAP32[$data>>2]|0;
   $26 = (($data) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $28 = $19 >> 5;
  $29 = (($data) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $28 | -2147483648;
  HEAP32[$22>>2] = $30;
  HEAP32[$data>>2] = $21;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $34 = $$pre;
 } else {
  $31 = HEAP32[$7>>2]|0;
  HEAP32[$size1>>2] = $31;
  HEAP32[$3>>2] = $8;
  $34 = $31;
 }
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$2>>2] = $33;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
 $35 = HEAP32[$data>>2]|0;
 $36 = (($data) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + ($37<<5)|0);
 $39 = ($37|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 } else {
  $i$02 = $35;
 }
 while(1) {
  $40 = HEAP32[$3>>2]|0;
  $41 = (($40) + 4|0);
  $42 = HEAP32[$9>>2]|0;
  $43 = ($41>>>0)>($42>>>0);
  if ($43) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$02,4);
  } else {
   $44 = HEAP32[$40>>2]|0;
   HEAP32[$i$02>>2] = $44;
   HEAP32[$3>>2] = $41;
  }
  $45 = (($i$02) + 8|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($45,$this);
  $46 = (($i$02) + 24|0);
  $47 = HEAP32[$3>>2]|0;
  $48 = (($47) + 4|0);
  $49 = HEAP32[$9>>2]|0;
  $50 = ($48>>>0)>($49>>>0);
  if ($50) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$46,4);
  } else {
   $51 = HEAP32[$47>>2]|0;
   HEAP32[$46>>2] = $51;
   HEAP32[$3>>2] = $48;
  }
  $52 = (($i$02) + 32|0);
  $53 = ($52|0)==($38|0);
  if ($53) {
   break;
  } else {
   $i$02 = $52;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI26EnlightenSystemInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI26EnlightenSystemInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + (($37*56)|0)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN26EnlightenSystemInformation8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 56|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = ($18*56)|0;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = (($19|0) / 56)&-1;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN26EnlightenSystemInformation8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $27 = $$pre9;$29 = $$pre10;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 16|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $31 = (($this) + 24|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($31,$transfer);
  $32 = (($this) + 40|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($32,$transfer);
  STACKTOP = sp;return;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = (($this) + 24|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($31,$transfer);
  $32 = (($this) + 40|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($32,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI28EnlightenRendererInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI28EnlightenRendererInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + (($37*40)|0)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 4|0);
   __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($40,$this);
   $41 = (($i$02) + 20|0);
   $42 = HEAP32[$3>>2]|0;
   $43 = (($42) + 4|0);
   $44 = HEAP32[$9>>2]|0;
   $45 = ($43>>>0)>($44>>>0);
   if ($45) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$41,4);
   } else {
    $46 = HEAP32[$42>>2]|0;
    HEAP32[$41>>2] = $46;
    HEAP32[$3>>2] = $43;
   }
   $47 = (($i$02) + 24|0);
   __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($47,$this);
   $48 = (($i$02) + 40|0);
   $49 = ($48|0)==($38|0);
   if ($49) {
    break;
   } else {
    $i$02 = $48;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre3 = HEAP32[$3>>2]|0;
   $$pre4 = HEAP32[$9>>2]|0;
   $14 = $$pre3;$16 = $$pre4;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $14 = $8;$16 = $10;
  }
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre5 = HEAP32[$offset>>2]|0;
   $20 = $$pre5;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$3>>2] = $13;
   $20 = $17;
  }
  $18 = HEAP32[$size>>2]|0;
  $19 = ($18*40)|0;
  $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
  $22 = (($data) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>(-1);
  if ($24) {
   $25 = HEAP32[$data>>2]|0;
   $26 = (($data) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $28 = (($19|0) / 40)&-1;
  $29 = (($data) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $28 | -2147483648;
  HEAP32[$22>>2] = $30;
  HEAP32[$data>>2] = $21;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($t) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI17LightProbesLegacyE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN16LightmapSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i1 = 0, $converter$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i7 = sp + 8|0;
 $converter$i$i1 = sp;
 $converter$i$i = sp + 4|0;
 __ZN16LevelGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,4);
 $0 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 $1 = (($this) + 64|0);
 if ($0) {
  $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,602992,604072,$converter$i$i,1)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = ($2|0)>(0);
   if ($4) {
    __ZN4PPtrI17LightProbesLegacyE8TransferI14SafeBinaryReadEEvRT_($1,$transfer);
   } else {
    $5 = HEAP32[$converter$i$i>>2]|0;
    $6 = ($5|0)==(0|0);
    if (!($6)) {
     (FUNCTION_TABLE_iii[$5 & 4095]($1,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603008,604072,$converter$i$i1,1)|0);
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = ($7|0)>(0);
   if ($9) {
    __ZN4PPtrI17LightProbesLegacyE8TransferI14SafeBinaryReadEEvRT_($1,$transfer);
   } else {
    $10 = HEAP32[$converter$i$i1>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     (FUNCTION_TABLE_iii[$10 & 4095]($1,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 }
 $12 = (($this) + 84|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$12,603032,0);
 $13 = (($this) + 120|0);
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603056,603904,$converter$i$i7,1)|0);
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = ($14|0)>(0);
  if ($16) {
   __ZN21EnlightenSceneMapping8TransferI14SafeBinaryReadEEvRT_($13,$transfer);
  } else {
   $17 = HEAP32[$converter$i$i7>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    (FUNCTION_TABLE_iii[$17 & 4095]($13,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $19 = (($this) + 60|0);
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,602992,603880,$converter$i$i7,1)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = ($20|0)>(0);
  if ($22) {
   __ZN4PPtrI11LightProbesE8TransferI14SafeBinaryReadEEvRT_($19,$transfer);
  } else {
   $23 = HEAP32[$converter$i$i7>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    (FUNCTION_TABLE_iii[$23 & 4095]($19,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $25 = (($this) + 68|0);
 $26 = HEAP32[580760>>2]|0;
 $27 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603080,$26,$converter$i$i7,1)|0);
 $28 = ($27|0)==(0);
 if (!($28)) {
  $29 = ($27|0)>(0);
  if ($29) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI12LightmapDataLj4EEEEvRT_17TransferMetaFlags($transfer,$25,0);
  } else {
   $30 = HEAP32[$converter$i$i7>>2]|0;
   $31 = ($30|0)==(0|0);
   if (!($31)) {
    (FUNCTION_TABLE_iii[$30 & 4095]($25,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $32 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,2)|0);
 $33 = (($this) + 88|0);
 if ($32) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$33,603096,0);
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$33,603112,0);
  $34 = (($this) + 92|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$34,603096,0);
 }
 $35 = (($this) + 96|0);
 $36 = HEAP32[580544>>2]|0;
 $37 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603136,$36,$converter$i$i7,0)|0);
 $38 = ($37|0)==(0);
 if (!($38)) {
  $39 = ($37|0)>(0);
  do {
   if ($39) {
    $40 = (($transfer) + 12|0);
    $41 = (($transfer) + 80|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + 12|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($transfer) + 16|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($transfer) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($transfer) + 32|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = Math_imul($50, $48)|0;
    $$sum$i$i$i$i$i = (($44) - ($51))|0;
    $52 = (($46) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$40>>2] = $52;
    $53 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($53)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $54 = (($46) + ($$sum1$i$i$i$i$i)|0);
     $55 = (($transfer) + 20|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($54>>>0)>($56>>>0);
     if (!($57)) {
      $58 = HEAP8[$52>>0]|0;
      HEAP8[$35>>0] = $58;
      $59 = HEAP32[$40>>2]|0;
      $60 = (($59) + 1|0);
      HEAP32[$40>>2] = $60;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($40,$35,1);
   } else {
    $61 = HEAP32[$converter$i$i7>>2]|0;
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     (FUNCTION_TABLE_iii[$61 & 4095]($35,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $63 = (($this) + 100|0);
 $64 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603168,603824,$converter$i$i7,1)|0);
 $65 = ($64|0)==(0);
 if (!($65)) {
  $66 = ($64|0)>(0);
  if ($66) {
   __ZN10GISettings8TransferI14SafeBinaryReadEEvRT_($63,$transfer);
  } else {
   $67 = HEAP32[$converter$i$i7>>2]|0;
   $68 = ($67|0)==(0|0);
   if (!($68)) {
    (FUNCTION_TABLE_iii[$67 & 4095]($63,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $69 = (($this) + 200|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$69,603184,0);
 $70 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,3)|0);
 if (!($70)) {
  STACKTOP = sp;return;
 }
 $71 = (($this) + 92|0);
 HEAP32[$71>>2] = 1;
 STACKTOP = sp;return;
}
function __ZN10GISettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i2 = 0, $$sum$i$i$i$i$i7 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $converter$i$i6 = 0, $m_DynamicEnv = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i6 = sp;
 $m_DynamicEnv = sp + 4|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$this,603208,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,603224,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,603248,0);
 $2 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$2,603264,0);
 $3 = (($this) + 16|0);
 $4 = HEAP32[580544>>2]|0;
 $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603296,$4,$converter$i$i6,0)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = ($5|0)>(0);
  do {
   if ($7) {
    $8 = (($transfer) + 12|0);
    $9 = (($transfer) + 80|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($transfer) + 16|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($transfer) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($transfer) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = Math_imul($18, $16)|0;
    $$sum$i$i$i$i$i = (($12) - ($19))|0;
    $20 = (($14) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$8>>2] = $20;
    $21 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($21)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $22 = (($14) + ($$sum1$i$i$i$i$i)|0);
     $23 = (($transfer) + 20|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($22>>>0)>($24>>>0);
     if (!($25)) {
      $26 = HEAP8[$20>>0]|0;
      HEAP8[$3>>0] = $26;
      $27 = HEAP32[$8>>2]|0;
      $28 = (($27) + 1|0);
      HEAP32[$8>>2] = $28;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($8,$3,1);
   } else {
    $29 = HEAP32[$converter$i$i6>>2]|0;
    $30 = ($29|0)==(0|0);
    if (!($30)) {
     (FUNCTION_TABLE_iii[$29 & 4095]($3,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $31 = (($this) + 17|0);
 $32 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603320,$4,$converter$i$i6,0)|0);
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = ($32|0)>(0);
  do {
   if ($34) {
    $35 = (($transfer) + 12|0);
    $36 = (($transfer) + 80|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($transfer) + 16|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($transfer) + 28|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($transfer) + 32|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = Math_imul($45, $43)|0;
    $$sum$i$i$i$i$i2 = (($39) - ($46))|0;
    $47 = (($41) + ($$sum$i$i$i$i$i2)|0);
    HEAP32[$35>>2] = $47;
    $48 = ($$sum$i$i$i$i$i2|0)<(0);
    if (!($48)) {
     $$sum1$i$i$i$i$i3 = (($$sum$i$i$i$i$i2) + 1)|0;
     $49 = (($41) + ($$sum1$i$i$i$i$i3)|0);
     $50 = (($transfer) + 20|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($49>>>0)>($51>>>0);
     if (!($52)) {
      $53 = HEAP8[$47>>0]|0;
      HEAP8[$31>>0] = $53;
      $54 = HEAP32[$35>>2]|0;
      $55 = (($54) + 1|0);
      HEAP32[$35>>2] = $55;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($35,$31,1);
   } else {
    $56 = HEAP32[$converter$i$i6>>2]|0;
    $57 = ($56|0)==(0|0);
    if (!($57)) {
     (FUNCTION_TABLE_iii[$56 & 4095]($31,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $58 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 if (!($58)) {
  STACKTOP = sp;return;
 }
 HEAP8[$m_DynamicEnv>>0] = 1;
 $59 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603352,$4,$converter$i$i6,0)|0);
 $60 = ($59|0)==(0);
 if ($60) {
  $85 = 0;
 } else {
  $61 = ($59|0)>(0);
  do {
   if ($61) {
    $62 = (($transfer) + 12|0);
    $63 = (($transfer) + 80|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($64) + 12|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($transfer) + 16|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($transfer) + 28|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($transfer) + 32|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = Math_imul($72, $70)|0;
    $$sum$i$i$i$i$i7 = (($66) - ($73))|0;
    $74 = (($68) + ($$sum$i$i$i$i$i7)|0);
    HEAP32[$62>>2] = $74;
    $75 = ($$sum$i$i$i$i$i7|0)<(0);
    if (!($75)) {
     $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
     $76 = (($68) + ($$sum1$i$i$i$i$i8)|0);
     $77 = (($transfer) + 20|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ($76>>>0)>($78>>>0);
     if (!($79)) {
      $80 = HEAP8[$74>>0]|0;
      HEAP8[$m_DynamicEnv>>0] = $80;
      $$sum = (($$sum$i$i$i$i$i7) + 1)|0;
      $81 = (($68) + ($$sum)|0);
      HEAP32[$62>>2] = $81;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($62,$m_DynamicEnv,1);
   } else {
    $82 = HEAP32[$converter$i$i6>>2]|0;
    $83 = ($82|0)==(0|0);
    if (!($83)) {
     (FUNCTION_TABLE_iii[$82 & 4095]($m_DynamicEnv,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
  $$pre = HEAP8[$m_DynamicEnv>>0]|0;
  $phitmp = $$pre ^ 1;
  $85 = $phitmp;
 }
 $84 = $85&255;
 HEAP32[$2>>2] = $84;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI12LightmapDataLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,603840,603840,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI12LightmapDataLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<3)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,603864,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN12LightmapData8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 8|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,603864,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN12LightmapData8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 8|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN12LightmapData8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603376,603848,$converter$i$i1,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  } else {
   $3 = HEAP32[$converter$i$i1>>2]|0;
   $4 = ($3|0)==(0|0);
   if (!($4)) {
    (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $5 = (($this) + 4|0);
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603392,603848,$converter$i$i1,1)|0);
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ($6|0)>(0);
 if ($8) {
  __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($5,$transfer);
 } else {
  $9 = HEAP32[$converter$i$i1>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   (FUNCTION_TABLE_iii[$9 & 4095]($5,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN4PPtrI11LightProbesE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,603416,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,603432,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,603416,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,603432,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN21EnlightenSceneMapping8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 $0 = HEAP32[580760>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603448,$0,$converter$i$i3,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI28EnlightenRendererInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i3>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 16|0);
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603464,$0,$converter$i$i3,1)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  if ($9) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI26EnlightenSystemInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$6,0);
  } else {
   $10 = HEAP32[$converter$i$i3>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    (FUNCTION_TABLE_iii[$10 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $12 = (($this) + 32|0);
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603480,$0,$converter$i$i3,1)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEEEvRT_17TransferMetaFlags($transfer,$12,0);
  } else {
   $16 = HEAP32[$converter$i$i3>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    (FUNCTION_TABLE_iii[$16 & 4095]($12,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $18 = (($this) + 48|0);
 $19 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603496,$0,$converter$i$i3,1)|0);
 $20 = ($19|0)==(0);
 if ($20) {
  __ZN21EnlightenSceneMapping16BuildRemapTablesEv($this);
  STACKTOP = sp;return;
 }
 $21 = ($19|0)>(0);
 if ($21) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEEEvRT_17TransferMetaFlags($transfer,$18,0);
 } else {
  $22 = HEAP32[$converter$i$i3>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   (FUNCTION_TABLE_iii[$22 & 4095]($18,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 __ZN21EnlightenSceneMapping16BuildRemapTablesEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,603840,603840,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI33EnlightenTerrainChunksInformationLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*12)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,603928,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if (!($22)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $52 = HEAP32[$data>>2]|0;
    $53 = ($52|0)==($11|0);
    if ($53) {
     break;
    } else {
     $i$12 = $52;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI33EnlightenTerrainChunksInformationEEvRT_PKc17TransferMetaFlags($this,$i$12,603368,0);
     $54 = (($i$12) + 12|0);
     $55 = ($54|0)==($11|0);
     if ($55) {
      break L4;
     } else {
      $i$12 = $54;
     }
    }
   }
   $23 = HEAP32[$15>>2]|0;
   $24 = (($23) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[$data>>2]|0;
   $27 = ($26|0)==($11|0);
   L11: do {
    if (!($27)) {
     $29 = 0;$32 = $23;$i$01 = $26;
     while(1) {
      $28 = Math_imul($29, $19)|0;
      $30 = (($28) + ($25))|0;
      $31 = (($32) + 20|0);
      HEAP32[$31>>2] = $30;
      $33 = (($32) + 12|0);
      HEAP32[$33>>2] = $30;
      $34 = (($32) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
      $35 = $2;
      $36 = $35;
      $37 = HEAP32[$36>>2]|0;
      $38 = (($35) + 4)|0;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = $34;
      $42 = $41;
      HEAP32[$42>>2] = $37;
      $43 = (($41) + 4)|0;
      $44 = $43;
      HEAP32[$44>>2] = $40;
      $45 = HEAP32[$20>>2]|0;
      $46 = HEAP32[$45>>2]|0;
      $47 = (($46) + 1)|0;
      HEAP32[$45>>2] = $47;
      __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$i$01,603512,0);
      $48 = (($i$01) + 4|0);
      __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$48,603528,0);
      $49 = (($i$01) + 8|0);
      __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$49,603544,0);
      $50 = (($i$01) + 12|0);
      $51 = ($50|0)==($11|0);
      if ($51) {
       break L11;
      }
      $$pre = HEAP32[$20>>2]|0;
      $$pre6 = HEAP32[$$pre>>2]|0;
      $$pre7 = HEAP32[$15>>2]|0;
      $29 = $$pre6;$32 = $$pre7;$i$01 = $50;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI33EnlightenTerrainChunksInformationEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,603928,$converter$i,1)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ($1|0)>(0);
 if ($3) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$data,603512,0);
  $4 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$4,603528,0);
  $5 = (($data) + 8|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$5,603544,0);
 } else {
  $6 = HEAP32[$converter$i>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   (FUNCTION_TABLE_iii[$6 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,603840,603840,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI31EnlightenSystemAtlasInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<5)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,603976,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN31EnlightenSystemAtlasInformation8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 32|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,603976,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN31EnlightenSystemAtlasInformation8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 32|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN31EnlightenSystemAtlasInformation8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,603560,0);
 $0 = (($this) + 8|0);
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603576,603968,$converter$i$i,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($0,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$6,603512,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI26EnlightenSystemInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,603840,603840,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI26EnlightenSystemInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*56)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,604008,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN26EnlightenSystemInformation8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 56|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,604008,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN26EnlightenSystemInformation8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 56|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN26EnlightenSystemInformation8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,603592,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$0,603608,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$1,603624,0);
 $2 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$2,603640,0);
 $3 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$3,603656,0);
 $4 = (($this) + 24|0);
 $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603672,603968,$converter$i$i1,1)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = ($5|0)>(0);
  if ($7) {
   __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($4,$transfer);
  } else {
   $8 = HEAP32[$converter$i$i1>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    (FUNCTION_TABLE_iii[$8 & 4095]($4,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $10 = (($this) + 40|0);
 $11 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603688,603968,$converter$i$i1,1)|0);
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = ($11|0)>(0);
 if ($13) {
  __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($10,$transfer);
 } else {
  $14 = HEAP32[$converter$i$i1>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   (FUNCTION_TABLE_iii[$14 & 4095]($10,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI28EnlightenRendererInformationLj8EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,603840,603840,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI28EnlightenRendererInformationLj8EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*40)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,604040,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN28EnlightenRendererInformation8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 40|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,603368,604040,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN28EnlightenRendererInformation8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 40|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN28EnlightenRendererInformation8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i2 = sp;
 $0 = HEAP32[580624>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603712,$0,$converter$i$i2,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i2>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 4|0);
 $7 = HEAP32[580784>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603728,$7,$converter$i$i2,1)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($8|0)>(0);
  if ($10) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,603792,0);
   $11 = (($this) + 8|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$11,603800,0);
   $12 = (($this) + 12|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,603808,0);
   $13 = (($this) + 16|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,603816,0);
  } else {
   $14 = HEAP32[$converter$i$i2>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    (FUNCTION_TABLE_iii[$14 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $16 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$16,603760,0);
 $17 = (($this) + 24|0);
 $18 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,603776,603968,$converter$i$i2,1)|0);
 $19 = ($18|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = ($18|0)>(0);
 if ($20) {
  __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($17,$transfer);
 } else {
  $21 = HEAP32[$converter$i$i2>>2]|0;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   (FUNCTION_TABLE_iii[$21 & 4095]($17,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,603416,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,603432,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,603416,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,603432,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI17LightProbesLegacyE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,603416,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,603432,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,603416,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,603432,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN16LightmapSettings8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 16|0;
 __ZN16LevelGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,4);
 $0 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603008,604072,$0,0);
 $1 = (($size$i$i$i$i) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$size$i$i$i$i>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603416,$6,$0,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603432,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 84|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603032,$6,$18,0);
 $19 = HEAP32[$7>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$10>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 120|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603056,603904,$23,0);
 __ZN15SerializeTraitsI21EnlightenSceneMappingE8TransferI13ProxyTransferEEvRS0_RT_($23,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,602992,603880,$24,0);
 $25 = (($size$i$i$i$i) + 8|0);
 $26 = $25;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = 0;
 HEAP32[$size$i$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603416,$6,$24,1);
 $30 = HEAP32[$7>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$10>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603432,$13,$25,1);
 $34 = HEAP32[$7>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$10>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($this) + 68|0);
 $39 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603080,$39,$38,0);
 HEAP32[$p$i$i$i>>2] = 0;
 $40 = (($p$i$i$i) + 4|0);
 HEAP32[$40>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,603840,603840,$size$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603368,603864,$p$i$i$i,0);
 __ZN12LightmapData8TransferI13ProxyTransferEEvRT_($p$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $41 = (($this) + 88|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603112,$6,$41,0);
 $42 = HEAP32[$7>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$10>>2]|0;
 $45 = ((($43) + (($44*24)|0)|0) + 12|0);
 HEAP32[$45>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $46 = (($this) + 92|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603096,$6,$46,0);
 $47 = HEAP32[$7>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$10>>2]|0;
 $50 = ((($48) + (($49*24)|0)|0) + 12|0);
 HEAP32[$50>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $51 = (($this) + 96|0);
 $52 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603136,$52,$51,0);
 $53 = HEAP32[$7>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$10>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $57 = (($this) + 100|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603168,603824,$57,0);
 __ZN10GISettings8TransferI13ProxyTransferEEvRT_($57,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $58 = (($this) + 200|0);
 $59 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603184,$59,$58,0);
 $60 = HEAP32[$7>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$10>>2]|0;
 $63 = ((($61) + (($62*24)|0)|0) + 12|0);
 HEAP32[$63>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10GISettings8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603208,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603224,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603248,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 $18 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603264,$18,$17,0);
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$4>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 16|0);
 $24 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603296,$24,$23,0);
 $25 = HEAP32[$1>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$4>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 17|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603320,$24,$29,0);
 $30 = HEAP32[$1>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$4>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12LightmapData8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i1 = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603376,603848,$this,0);
 $0 = (($localIdentifier$i$i$i1) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 $5 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603416,$5,$this,1);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($8) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603432,$12,$0,1);
 $13 = HEAP32[$6>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$9>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603392,603848,$17,0);
 $18 = (($localIdentifier$i$i$i1) + 8|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = 0;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603416,$5,$17,1);
 $23 = HEAP32[$6>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$9>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603432,$12,$18,1);
 $27 = HEAP32[$6>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$9>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI21EnlightenSceneMappingE8TransferI13ProxyTransferEEvRS0_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i6 = 0, $size$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $size$i$i$i$i5 = sp + 56|0;
 $p$i$i$i6 = sp;
 $0 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603448,$0,$data,0);
 HEAP32[$p$i$i$i6>>2] = 0;
 $1 = (($p$i$i$i6) + 24|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,603840,603840,$size$i$i$i$i5,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603368,604040,$p$i$i$i6,0);
 __ZN28EnlightenRendererInformation8TransferI13ProxyTransferEEvRT_($p$i$i$i6,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($data) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603464,$0,$2,0);
 $3 = (($p$i$i$i6) + 24|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;HEAP32[$3+24>>2]=0|0;HEAP32[$3+28>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,603840,603840,$size$i$i$i$i5,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603368,604008,$p$i$i$i6,0);
 __ZN26EnlightenSystemInformation8TransferI13ProxyTransferEEvRT_($p$i$i$i6,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $4 = (($data) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603480,$0,$4,0);
 $5 = (($p$i$i$i6) + 8|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,603840,603840,$size$i$i$i$i5,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603368,603976,$p$i$i$i6,0);
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603560,$6,$p$i$i$i6,0);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603576,603968,$5,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($5,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($p$i$i$i6) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603512,$6,$13,0);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($data) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603496,$0,$18,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,603840,603840,$size$i$i$i$i5,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603368,603928,$p$i$i$i6,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603512,$6,$p$i$i$i6,0);
 $19 = HEAP32[$7>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$10>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($p$i$i$i6) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603528,$6,$23,0);
 $24 = HEAP32[$7>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$10>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($p$i$i$i6) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603544,$6,$28,0);
 $29 = HEAP32[$7>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$10>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN26EnlightenSystemInformation8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603592,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603608,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 $13 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603624,$13,$12,0);
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$4>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603640,$13,$18,0);
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$4>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603656,$13,$23,0);
 $24 = HEAP32[$1>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$4>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603672,603968,$28,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($28,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603688,603968,$29,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($29,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN28EnlightenRendererInformation8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 $0 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603712,$0,$this,0);
 $1 = (($localIdentifier$i$i$i) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603416,$6,$this,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603432,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 4|0);
 $19 = HEAP32[580784>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603728,$19,$18,0);
 __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($18,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603760,$6,$20,0);
 $21 = HEAP32[$7>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$10>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $25 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,603776,603968,$25,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($25,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN16LightmapSettingsD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i5$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy18 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((602664 + 8|0));
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZdaPv($3);
 }
 $5 = (($this) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __ZdaPv($6);
 }
 $8 = (($this) + 120|0);
 __THREW__ = 0;
 invoke_vi(3485,($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L7: do {
  if ($10) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)>(-1);
   if ($48) {
    $49 = (($this) + 68|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($this) + 72|0);
    $52 = HEAP32[$51>>2]|0;
    HEAP32[$0>>2] = $52;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($50|0),($$byval_copy18|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     HEAP32[$49>>2] = 0;
     $$0 = $45;$$01 = $44;
     label = 26;
    }
   } else {
    $$0 = $45;$$01 = $44;
    label = 26;
   }
  } else {
   $11 = (($this) + 80|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)>(-1);
   do {
    if ($13) {
     $14 = (($this) + 68|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($this) + 72|0);
     $17 = HEAP32[$16>>2]|0;
     HEAP32[$1>>2] = $17;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy18|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      $55 = ___cxa_find_matching_catch()|0;
      $56 = tempRet0;
      $$0 = $56;$$01 = $55;
      label = 26;
      break L7;
     } else {
      HEAP32[$14>>2] = 0;
      break;
     }
    }
   } while(0);
   HEAP32[$this>>2] = ((561080 + 8|0));
   __THREW__ = 0;
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     STACKTOP = sp;return;
    }
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    __THREW__ = 0;
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     $28 = ___cxa_find_matching_catch(0|0)|0;
     $29 = tempRet0;
     ___clang_call_terminate($28);
     // unreachable;
    } else {
     ___resumeException($24|0);
     // unreachable;
    }
   }
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $36 = ___cxa_find_matching_catch(0|0)|0;
    $37 = tempRet0;
    __THREW__ = 0;
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     $40 = ___cxa_find_matching_catch(0|0)|0;
     $41 = tempRet0;
     ___clang_call_terminate($40);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $36;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    ___resumeException($30|0);
    // unreachable;
   }
   $42 = ___cxa_find_matching_catch(0|0)|0;
   $43 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $42;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 do {
  if ((label|0) == 26) {
   HEAP32[$this>>2] = ((561080 + 8|0));
   __THREW__ = 0;
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if (!($58)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if (!($60)) {
     __THREW__ = 0;
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     ___resumeException($$01|0);
     // unreachable;
    }
    $61 = ___cxa_find_matching_catch(0|0)|0;
    $62 = tempRet0;
    __THREW__ = 0;
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     $65 = ___cxa_find_matching_catch(0|0)|0;
     $66 = tempRet0;
     ___clang_call_terminate($65);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $61;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $69 = ___cxa_find_matching_catch(0|0)|0;
   $70 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $75 = ___cxa_find_matching_catch(0|0)|0;
    $76 = tempRet0;
    __THREW__ = 0;
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     $79 = ___cxa_find_matching_catch(0|0)|0;
     $80 = tempRet0;
     ___clang_call_terminate($79);
     // unreachable;
    } else {
     $eh$lpad$body$i5$indexZ2D = $75;
     ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if (!($74)) {
    $eh$lpad$body$indexZ2D = $69;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $81 = ___cxa_find_matching_catch(0|0)|0;
   $82 = tempRet0;
   $eh$lpad$body$i5$indexZ2D = $81;
   ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
   // unreachable;
  }
 } while(0);
 $83 = ___cxa_find_matching_catch(0|0)|0;
 $84 = tempRet0;
 $eh$lpad$body$indexZ2D = $83;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN21EnlightenSceneMappingD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = (($this) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 72|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $7;
   $scevgep$i$i$i$i$i$i$i$i$i = (($10) + -8|0);
   $12 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($12)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $13 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
   $14 = $13 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($10) + ($14<<3)|0);
   HEAP32[$9>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 $15 = (($this) + 60|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)>(-1);
 do {
  if ($17) {
   $18 = (($this) + 48|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 52|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$5>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($19|0),($$byval_copy6|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    HEAP32[$18>>2] = 0;
    label = 8;
    break;
   }
   $50 = ___cxa_find_matching_catch()|0;
   $51 = tempRet0;
   $52 = (($this) + 44|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)>(-1);
   if ($54) {
    $55 = (($this) + 32|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($this) + 36|0);
    $58 = HEAP32[$57>>2]|0;
    HEAP32[$2>>2] = $58;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($56|0),($$byval_copy6|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     $80 = ___cxa_find_matching_catch(0|0)|0;
     $81 = tempRet0;
     ___clang_call_terminate($80);
     // unreachable;
    } else {
     HEAP32[$55>>2] = 0;
     $$1 = $51;$$12 = $50;
     label = 22;
     break;
    }
   } else {
    $$1 = $51;$$12 = $50;
    label = 22;
   }
  } else {
   label = 8;
  }
 } while(0);
 L16: do {
  if ((label|0) == 8) {
   $24 = (($this) + 44|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(-1);
   do {
    if ($26) {
     $27 = (($this) + 32|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($this) + 36|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$4>>2] = $30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($28|0),($$byval_copy6|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $48 = ___cxa_find_matching_catch()|0;
      $49 = tempRet0;
      $$1 = $49;$$12 = $48;
      label = 22;
      break L16;
     } else {
      HEAP32[$27>>2] = 0;
      break;
     }
    }
   } while(0);
   $33 = (($this) + 28|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)>(-1);
   do {
    if ($35) {
     $36 = (($this) + 16|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($this) + 20|0);
     $39 = HEAP32[$38>>2]|0;
     HEAP32[$3>>2] = $39;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($37|0),($$byval_copy6|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      $61 = ___cxa_find_matching_catch()|0;
      $62 = tempRet0;
      $$2 = $62;$$23 = $61;
      break L16;
     } else {
      HEAP32[$36>>2] = 0;
      break;
     }
    }
   } while(0);
   $42 = (($this) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)>(-1);
   if (!($44)) {
    STACKTOP = sp;return;
   }
   $45 = HEAP32[$this>>2]|0;
   $46 = (($this) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$0>>2] = $47;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($45,$$byval_copy6);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 22) {
   $63 = (($this) + 28|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)>(-1);
   if ($65) {
    $66 = (($this) + 16|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($this) + 20|0);
    $69 = HEAP32[$68>>2]|0;
    HEAP32[$1>>2] = $69;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($67|0),($$byval_copy6|0));
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $80 = ___cxa_find_matching_catch(0|0)|0;
     $81 = tempRet0;
     ___clang_call_terminate($80);
     // unreachable;
    } else {
     HEAP32[$66>>2] = 0;
     $$2 = $$1;$$23 = $$12;
     break;
    }
   } else {
    $$2 = $$1;$$23 = $$12;
   }
  }
 } while(0);
 $72 = (($this) + 12|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)>(-1);
 if (!($74)) {
  ___resumeException($$23|0);
  // unreachable;
 }
 $75 = HEAP32[$this>>2]|0;
 $76 = (($this) + 4|0);
 $77 = HEAP32[$76>>2]|0;
 HEAP32[$0>>2] = $77;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($75|0),($$byval_copy6|0));
 $78 = __THREW__; __THREW__ = 0;
 $79 = $78&1;
 if ($79) {
  $80 = ___cxa_find_matching_catch(0|0)|0;
  $81 = tempRet0;
  ___clang_call_terminate($80);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$23|0);
 // unreachable;
}
function __ZN15LightProbeUtils32BarycentricCoordinates3DTriangleEPK8Vector3fRS1_($agg$result,$tri,$p) {
 $agg$result = $agg$result|0;
 $tri = $tri|0;
 $p = $p|0;
 var $$pn = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $nu$0 = Math_fround(0), $nv$0 = Math_fround(0);
 var $ood$0 = Math_fround(0), $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($tri) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$tri>>2]);
 $3 = Math_fround($1 - $2);
 $4 = (($tri) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($tri) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 - $7);
 $9 = (($tri) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($tri) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 - $12);
 $14 = (($tri) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 - $2);
 $17 = (($tri) + 28|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 - $7);
 $20 = (($tri) + 32|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 - $12);
 $23 = Math_fround($8 * $22);
 $24 = Math_fround($13 * $19);
 $25 = Math_fround($23 - $24);
 $26 = Math_fround($13 * $16);
 $27 = Math_fround($3 * $22);
 $28 = Math_fround($26 - $27);
 $29 = Math_fround($3 * $19);
 $30 = Math_fround($8 * $16);
 $31 = Math_fround($29 - $30);
 $32 = $25 < Math_fround(0.0);
 if ($32) {
  $33 = Math_fround(-$25);
  $39 = $33;
 } else {
  $39 = $25;
 }
 $34 = $28 < Math_fround(0.0);
 if ($34) {
  $35 = Math_fround(-$28);
  $40 = $35;
 } else {
  $40 = $28;
 }
 $36 = $31 < Math_fround(0.0);
 if ($36) {
  $37 = Math_fround(-$31);
  $42 = $37;
 } else {
  $42 = $31;
 }
 $38 = !($39 >= $40);
 $41 = !($39 >= $42);
 $or$cond = $38 | $41;
 do {
  if ($or$cond) {
   $59 = !($40 >= $39);
   $60 = !($40 >= $42);
   $or$cond1 = $59 | $60;
   $61 = Math_fround(HEAPF32[$p>>2]);
   if ($or$cond1) {
    $77 = (($p) + 4|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = Math_fround($61 - $1);
    $80 = Math_fround($5 - $18);
    $81 = Math_fround($79 * $80);
    $82 = Math_fround($1 - $15);
    $83 = Math_fround($78 - $5);
    $84 = Math_fround($83 * $82);
    $85 = Math_fround($81 - $84);
    $86 = Math_fround($61 - $15);
    $87 = Math_fround($86 * $19);
    $88 = Math_fround($78 - $18);
    $89 = Math_fround($88 * $16);
    $90 = Math_fround($87 - $89);
    $$pn = $31;$nu$0 = $85;$nv$0 = $90;
    break;
   } else {
    $62 = (($p) + 8|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    $64 = Math_fround($61 - $1);
    $65 = Math_fround($10 - $21);
    $66 = Math_fround($64 * $65);
    $67 = Math_fround($1 - $15);
    $68 = Math_fround($63 - $10);
    $69 = Math_fround($68 * $67);
    $70 = Math_fround($66 - $69);
    $71 = Math_fround($61 - $15);
    $72 = Math_fround($71 * $22);
    $73 = Math_fround($63 - $21);
    $74 = Math_fround($73 * $16);
    $75 = Math_fround($72 - $74);
    $76 = Math_fround(-$28);
    $$pn = $76;$nu$0 = $70;$nv$0 = $75;
    break;
   }
  } else {
   $43 = (($p) + 4|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($p) + 8|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = Math_fround($44 - $5);
   $48 = Math_fround($10 - $21);
   $49 = Math_fround($47 * $48);
   $50 = Math_fround($5 - $18);
   $51 = Math_fround($46 - $10);
   $52 = Math_fround($51 * $50);
   $53 = Math_fround($49 - $52);
   $54 = Math_fround($44 - $18);
   $55 = Math_fround($54 * $22);
   $56 = Math_fround($46 - $21);
   $57 = Math_fround($56 * $19);
   $58 = Math_fround($55 - $57);
   $$pn = $25;$nu$0 = $53;$nv$0 = $58;
  }
 } while(0);
 $ood$0 = Math_fround(Math_fround(1.0) / $$pn);
 $91 = Math_fround($nu$0 * $ood$0);
 $92 = Math_fround($nv$0 * $ood$0);
 $93 = Math_fround(Math_fround(1.0) - $91);
 $94 = Math_fround($93 - $92);
 HEAPF32[$agg$result>>2] = $91;
 $95 = (($agg$result) + 4|0);
 HEAPF32[$95>>2] = $92;
 $96 = (($agg$result) + 8|0);
 HEAPF32[$96>>2] = $94;
 STACKTOP = sp;return;
}
function __ZN17GlobalGameManagerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   STACKTOP = sp;return;
  }
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __THREW__ = 0;
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   ___resumeException($4|0);
   // unreachable;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$indexZ2D = $16;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  ___resumeException($10|0);
  // unreachable;
 }
 $22 = ___cxa_find_matching_catch(0|0)|0;
 $23 = tempRet0;
 $eh$lpad$body$indexZ2D = $22;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __Z29RegisterClass_QualitySettingsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(47,126,127,0,128);
 STACKTOP = sp;return;
}
function __ZN15QualitySettings13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 15;
 dest=$3+0|0; src=604216+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 15|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,47,6,($0|0),44,(2397|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN15QualitySettings15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15QualitySettings12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15QualitySettings7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(44,$$byval_copy2,1,16,604264,26)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1678,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((604096 + 8|0));
  $6 = (($3) + 24|0);
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;
  STACKTOP = sp;return ($3|0);
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(604264|0),26);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK15QualitySettings25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 47;
}
function __ZN15QualitySettings23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604232,604216,$this,0);
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,5);
 $0 = (($this) + 40|0);
 $1 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604272,$1,$0,2048);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 24|0);
 __ZN13ProxyTransfer8TransferINSt3__16vectorIN15QualitySettings14QualitySettingENS1_9allocatorIS4_EEEEEEvRT_PKc17TransferMetaFlags($transfer,$8,604296,2048);
 $9 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604480,$1,$9,0);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15QualitySettings23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604232,604216,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN15QualitySettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15QualitySettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
 }
 $8 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN15QualitySettings14QualitySettingENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$8,0);
 $9 = (($this) + 36|0);
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($11>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$9,4);
  STACKTOP = sp;return;
 } else {
  $14 = HEAP32[$10>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$1>>2] = $11;
  STACKTOP = sp;return;
 }
}
function __ZN15QualitySettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15QualitySettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN15QualitySettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15QualitySettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN15QualitySettings23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __Z18GetQualitySettingsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(11)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN15QualitySettings5ResetEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $tempQuality = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 592|0;
 $$byval_copy1 = sp + 584|0;
 $0 = sp;
 $tempQuality = sp + 8|0;
 $1 = (($tempQuality) + 576|0);
 HEAP8[$tempQuality>>0] = 14;
 $2 = (($tempQuality) + 1|0);
 ;HEAP8[$2+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$2+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$2+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$2+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$2+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$2+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$2+6>>0]=HEAP8[604208+6>>0]|0;
 $3 = (($tempQuality) + 8|0);
 HEAP8[$3>>0] = 0;
 $4 = (($tempQuality) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($tempQuality) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($tempQuality) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($tempQuality) + 24|0);
 HEAP32[$7>>2] = 1;
 $8 = (($tempQuality) + 28|0);
 HEAP32[$8>>2] = 1;
 $9 = (($tempQuality) + 32|0);
 HEAP32[$9>>2] = 1;
 $10 = (($tempQuality) + 36|0);
 HEAPF32[$10>>2] = Math_fround(15.0);
 $11 = (($tempQuality) + 40|0);
 HEAPF32[$11>>2] = Math_fround(0.333333343267440795898);
 $12 = (($tempQuality) + 44|0);
 HEAPF32[$12>>2] = Math_fround(0.0666666701436042785645);
 $13 = (($tempQuality) + 48|0);
 HEAPF32[$13>>2] = Math_fround(0.20000000298023223877);
 $14 = (($tempQuality) + 52|0);
 HEAPF32[$14>>2] = Math_fround(0.46666666865348815918);
 $15 = (($tempQuality) + 56|0);
 HEAP32[$15>>2] = 1;
 $16 = (($tempQuality) + 60|0);
 HEAP32[$16>>2] = 1;
 $17 = (($tempQuality) + 64|0);
 $18 = (($tempQuality) + 80|0);
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;
 HEAPF32[$18>>2] = Math_fround(0.300000011920928955078);
 $19 = (($tempQuality) + 84|0);
 HEAP32[$19>>2] = 0;
 $20 = (($tempQuality) + 88|0);
 HEAP32[$20>>2] = 4;
 $21 = (($tempQuality) + 92|0);
 HEAPF32[$21>>2] = Math_fround(512.0);
 $22 = (($tempQuality) + 96|0);
 HEAP8[$22>>0] = 14;
 $23 = (($22) + 1|0);
 ;HEAP8[$23+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$23+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$23+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$23+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$23+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$23+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$23+6>>0]=HEAP8[604208+6>>0]|0;
 $24 = (($tempQuality) + 104|0);
 HEAP8[$24>>0] = 0;
 $25 = (($tempQuality) + 108|0);
 HEAP32[$25>>2] = 0;
 $26 = (($tempQuality) + 112|0);
 HEAP32[$26>>2] = 0;
 $27 = (($tempQuality) + 116|0);
 HEAP32[$27>>2] = 0;
 $28 = (($tempQuality) + 120|0);
 HEAP32[$28>>2] = 1;
 $29 = (($tempQuality) + 124|0);
 HEAP32[$29>>2] = 1;
 $30 = (($tempQuality) + 128|0);
 HEAP32[$30>>2] = 1;
 $31 = (($tempQuality) + 132|0);
 HEAPF32[$31>>2] = Math_fround(15.0);
 $32 = (($tempQuality) + 136|0);
 HEAPF32[$32>>2] = Math_fround(0.333333343267440795898);
 $33 = (($tempQuality) + 140|0);
 HEAPF32[$33>>2] = Math_fround(0.0666666701436042785645);
 $34 = (($tempQuality) + 144|0);
 HEAPF32[$34>>2] = Math_fround(0.20000000298023223877);
 $35 = (($tempQuality) + 148|0);
 HEAPF32[$35>>2] = Math_fround(0.46666666865348815918);
 $36 = (($tempQuality) + 152|0);
 HEAP32[$36>>2] = 1;
 $37 = (($tempQuality) + 156|0);
 HEAP32[$37>>2] = 1;
 $38 = (($tempQuality) + 160|0);
 $39 = (($tempQuality) + 176|0);
 ;HEAP32[$38+0>>2]=0|0;HEAP32[$38+4>>2]=0|0;HEAP32[$38+8>>2]=0|0;HEAP32[$38+12>>2]=0|0;
 HEAPF32[$39>>2] = Math_fround(0.300000011920928955078);
 $40 = (($tempQuality) + 180|0);
 HEAP32[$40>>2] = 0;
 $41 = (($tempQuality) + 184|0);
 HEAP32[$41>>2] = 4;
 $42 = (($tempQuality) + 188|0);
 HEAPF32[$42>>2] = Math_fround(512.0);
 $43 = (($tempQuality) + 192|0);
 HEAP8[$43>>0] = 14;
 $44 = (($43) + 1|0);
 ;HEAP8[$44+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$44+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$44+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$44+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$44+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$44+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$44+6>>0]=HEAP8[604208+6>>0]|0;
 $45 = (($tempQuality) + 200|0);
 HEAP8[$45>>0] = 0;
 $46 = (($tempQuality) + 204|0);
 HEAP32[$46>>2] = 0;
 $47 = (($tempQuality) + 208|0);
 HEAP32[$47>>2] = 0;
 $48 = (($tempQuality) + 212|0);
 HEAP32[$48>>2] = 0;
 $49 = (($tempQuality) + 216|0);
 HEAP32[$49>>2] = 1;
 $50 = (($tempQuality) + 220|0);
 HEAP32[$50>>2] = 1;
 $51 = (($tempQuality) + 224|0);
 HEAP32[$51>>2] = 1;
 $52 = (($tempQuality) + 228|0);
 HEAPF32[$52>>2] = Math_fround(15.0);
 $53 = (($tempQuality) + 232|0);
 HEAPF32[$53>>2] = Math_fround(0.333333343267440795898);
 $54 = (($tempQuality) + 236|0);
 HEAPF32[$54>>2] = Math_fround(0.0666666701436042785645);
 $55 = (($tempQuality) + 240|0);
 HEAPF32[$55>>2] = Math_fround(0.20000000298023223877);
 $56 = (($tempQuality) + 244|0);
 HEAPF32[$56>>2] = Math_fround(0.46666666865348815918);
 $57 = (($tempQuality) + 248|0);
 HEAP32[$57>>2] = 1;
 $58 = (($tempQuality) + 252|0);
 HEAP32[$58>>2] = 1;
 $59 = (($tempQuality) + 256|0);
 $60 = (($tempQuality) + 272|0);
 ;HEAP32[$59+0>>2]=0|0;HEAP32[$59+4>>2]=0|0;HEAP32[$59+8>>2]=0|0;HEAP32[$59+12>>2]=0|0;
 HEAPF32[$60>>2] = Math_fround(0.300000011920928955078);
 $61 = (($tempQuality) + 276|0);
 HEAP32[$61>>2] = 0;
 $62 = (($tempQuality) + 280|0);
 HEAP32[$62>>2] = 4;
 $63 = (($tempQuality) + 284|0);
 HEAPF32[$63>>2] = Math_fround(512.0);
 $64 = (($tempQuality) + 288|0);
 HEAP8[$64>>0] = 14;
 $65 = (($64) + 1|0);
 ;HEAP8[$65+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$65+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$65+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$65+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$65+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$65+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$65+6>>0]=HEAP8[604208+6>>0]|0;
 $66 = (($tempQuality) + 296|0);
 HEAP8[$66>>0] = 0;
 $67 = (($tempQuality) + 300|0);
 HEAP32[$67>>2] = 0;
 $68 = (($tempQuality) + 304|0);
 HEAP32[$68>>2] = 0;
 $69 = (($tempQuality) + 308|0);
 HEAP32[$69>>2] = 0;
 $70 = (($tempQuality) + 312|0);
 HEAP32[$70>>2] = 1;
 $71 = (($tempQuality) + 316|0);
 HEAP32[$71>>2] = 1;
 $72 = (($tempQuality) + 320|0);
 HEAP32[$72>>2] = 1;
 $73 = (($tempQuality) + 324|0);
 HEAPF32[$73>>2] = Math_fround(15.0);
 $74 = (($tempQuality) + 328|0);
 HEAPF32[$74>>2] = Math_fround(0.333333343267440795898);
 $75 = (($tempQuality) + 332|0);
 HEAPF32[$75>>2] = Math_fround(0.0666666701436042785645);
 $76 = (($tempQuality) + 336|0);
 HEAPF32[$76>>2] = Math_fround(0.20000000298023223877);
 $77 = (($tempQuality) + 340|0);
 HEAPF32[$77>>2] = Math_fround(0.46666666865348815918);
 $78 = (($tempQuality) + 344|0);
 HEAP32[$78>>2] = 1;
 $79 = (($tempQuality) + 348|0);
 HEAP32[$79>>2] = 1;
 $80 = (($tempQuality) + 352|0);
 $81 = (($tempQuality) + 368|0);
 ;HEAP32[$80+0>>2]=0|0;HEAP32[$80+4>>2]=0|0;HEAP32[$80+8>>2]=0|0;HEAP32[$80+12>>2]=0|0;
 HEAPF32[$81>>2] = Math_fround(0.300000011920928955078);
 $82 = (($tempQuality) + 372|0);
 HEAP32[$82>>2] = 0;
 $83 = (($tempQuality) + 376|0);
 HEAP32[$83>>2] = 4;
 $84 = (($tempQuality) + 380|0);
 HEAPF32[$84>>2] = Math_fround(512.0);
 $85 = (($tempQuality) + 384|0);
 HEAP8[$85>>0] = 14;
 $86 = (($85) + 1|0);
 ;HEAP8[$86+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$86+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$86+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$86+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$86+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$86+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$86+6>>0]=HEAP8[604208+6>>0]|0;
 $87 = (($tempQuality) + 392|0);
 HEAP8[$87>>0] = 0;
 $88 = (($tempQuality) + 396|0);
 HEAP32[$88>>2] = 0;
 $89 = (($tempQuality) + 400|0);
 HEAP32[$89>>2] = 0;
 $90 = (($tempQuality) + 404|0);
 HEAP32[$90>>2] = 0;
 $91 = (($tempQuality) + 408|0);
 HEAP32[$91>>2] = 1;
 $92 = (($tempQuality) + 412|0);
 HEAP32[$92>>2] = 1;
 $93 = (($tempQuality) + 416|0);
 HEAP32[$93>>2] = 1;
 $94 = (($tempQuality) + 420|0);
 HEAPF32[$94>>2] = Math_fround(15.0);
 $95 = (($tempQuality) + 424|0);
 HEAPF32[$95>>2] = Math_fround(0.333333343267440795898);
 $96 = (($tempQuality) + 428|0);
 HEAPF32[$96>>2] = Math_fround(0.0666666701436042785645);
 $97 = (($tempQuality) + 432|0);
 HEAPF32[$97>>2] = Math_fround(0.20000000298023223877);
 $98 = (($tempQuality) + 436|0);
 HEAPF32[$98>>2] = Math_fround(0.46666666865348815918);
 $99 = (($tempQuality) + 440|0);
 HEAP32[$99>>2] = 1;
 $100 = (($tempQuality) + 444|0);
 HEAP32[$100>>2] = 1;
 $101 = (($tempQuality) + 448|0);
 $102 = (($tempQuality) + 464|0);
 ;HEAP32[$101+0>>2]=0|0;HEAP32[$101+4>>2]=0|0;HEAP32[$101+8>>2]=0|0;HEAP32[$101+12>>2]=0|0;
 HEAPF32[$102>>2] = Math_fround(0.300000011920928955078);
 $103 = (($tempQuality) + 468|0);
 HEAP32[$103>>2] = 0;
 $104 = (($tempQuality) + 472|0);
 HEAP32[$104>>2] = 4;
 $105 = (($tempQuality) + 476|0);
 HEAPF32[$105>>2] = Math_fround(512.0);
 $106 = (($tempQuality) + 480|0);
 HEAP8[$106>>0] = 14;
 $107 = (($106) + 1|0);
 ;HEAP8[$107+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$107+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$107+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$107+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$107+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$107+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$107+6>>0]=HEAP8[604208+6>>0]|0;
 $108 = (($tempQuality) + 488|0);
 HEAP8[$108>>0] = 0;
 $109 = (($tempQuality) + 492|0);
 HEAP32[$109>>2] = 0;
 $110 = (($tempQuality) + 496|0);
 HEAP32[$110>>2] = 0;
 $111 = (($tempQuality) + 500|0);
 HEAP32[$111>>2] = 0;
 $112 = (($tempQuality) + 504|0);
 HEAP32[$112>>2] = 1;
 $113 = (($tempQuality) + 508|0);
 HEAP32[$113>>2] = 1;
 $114 = (($tempQuality) + 512|0);
 HEAP32[$114>>2] = 1;
 $115 = (($tempQuality) + 516|0);
 HEAPF32[$115>>2] = Math_fround(15.0);
 $116 = (($tempQuality) + 520|0);
 HEAPF32[$116>>2] = Math_fround(0.333333343267440795898);
 $117 = (($tempQuality) + 524|0);
 HEAPF32[$117>>2] = Math_fround(0.0666666701436042785645);
 $118 = (($tempQuality) + 528|0);
 HEAPF32[$118>>2] = Math_fround(0.20000000298023223877);
 $119 = (($tempQuality) + 532|0);
 HEAPF32[$119>>2] = Math_fround(0.46666666865348815918);
 $120 = (($tempQuality) + 536|0);
 HEAP32[$120>>2] = 1;
 $121 = (($tempQuality) + 540|0);
 HEAP32[$121>>2] = 1;
 $122 = (($tempQuality) + 544|0);
 $123 = (($tempQuality) + 560|0);
 ;HEAP32[$122+0>>2]=0|0;HEAP32[$122+4>>2]=0|0;HEAP32[$122+8>>2]=0|0;HEAP32[$122+12>>2]=0|0;
 HEAPF32[$123>>2] = Math_fround(0.300000011920928955078);
 $124 = (($tempQuality) + 564|0);
 HEAP32[$124>>2] = 0;
 $125 = (($tempQuality) + 568|0);
 HEAP32[$125>>2] = 4;
 $126 = (($tempQuality) + 572|0);
 HEAPF32[$126>>2] = Math_fround(512.0);
 __THREW__ = 0;
 invoke_vi(3486,($tempQuality|0));
 $127 = __THREW__; __THREW__ = 0;
 $128 = $127&1;
 if (!($128)) {
  $129 = (($this) + 24|0);
  __THREW__ = 0;
  invoke_viii(1740,($129|0),($tempQuality|0),($1|0));
  $130 = __THREW__; __THREW__ = 0;
  $131 = $130&1;
  if (!($131)) {
   $132 = (($this) + 40|0);
   HEAP32[$132>>2] = 5;
   $134 = $1;
   while(1) {
    $133 = (($134) + -96|0);
    $135 = HEAP8[$133>>0]|0;
    $136 = $135 & 1;
    $137 = ($136<<24>>24)==(0);
    if (!($137)) {
     $138 = (($134) + -88|0);
     $139 = HEAP32[$138>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($139|0),($$byval_copy1|0));
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if ($141) {
      label = 6;
      break;
     }
    }
    $144 = ($133|0)==($tempQuality|0);
    if ($144) {
     label = 8;
     break;
    } else {
     $134 = $133;
    }
   }
   if ((label|0) == 6) {
    $142 = ___cxa_find_matching_catch()|0;
    $143 = tempRet0;
    ___cxa_call_unexpected(($142|0));
    // unreachable;
   }
   else if ((label|0) == 8) {
    STACKTOP = sp;return;
   }
  }
 }
 $145 = ___cxa_find_matching_catch()|0;
 $146 = tempRet0;
 $148 = $1;
 while(1) {
  $147 = (($148) + -96|0);
  $149 = HEAP8[$147>>0]|0;
  $150 = $149 & 1;
  $151 = ($150<<24>>24)==(0);
  if (!($151)) {
   $152 = (($148) + -88|0);
   $153 = HEAP32[$152>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($153|0),($$byval_copy1|0));
   $154 = __THREW__; __THREW__ = 0;
   $155 = $154&1;
   if ($155) {
    label = 12;
    break;
   }
  }
  $158 = ($147|0)==($tempQuality|0);
  if ($158) {
   label = 14;
   break;
  } else {
   $148 = $147;
  }
 }
 if ((label|0) == 12) {
  $156 = ___cxa_find_matching_catch()|0;
  $157 = tempRet0;
  ___cxa_call_unexpected(($156|0));
  // unreachable;
 }
 else if ((label|0) == 14) {
  ___resumeException($145|0);
  // unreachable;
 }
}
function __ZL32InitializeDefaultQualitySettingsPN15QualitySettings14QualitySettingE($m_Quality) {
 $m_Quality = $m_Quality|0;
 var $$0 = 0, $$01 = 0, $$byval_copy11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $qualitySetting = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy11 = sp + 196|0;
 $0 = sp + 192|0;
 $1 = sp + 188|0;
 $2 = sp + 184|0;
 $3 = sp + 180|0;
 $4 = sp + 176|0;
 $5 = sp + 172|0;
 $6 = sp + 168|0;
 $7 = sp + 164|0;
 $8 = sp + 148|0;
 $9 = sp + 144|0;
 $qualitySetting = sp + 48|0;
 $10 = sp + 36|0;
 $11 = sp + 24|0;
 $12 = sp + 12|0;
 $13 = sp;
 $14 = sp + 152|0;
 HEAP8[$qualitySetting>>0] = 14;
 $15 = (($qualitySetting) + 1|0);
 ;HEAP8[$15+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$15+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$15+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$15+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$15+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$15+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$15+6>>0]=HEAP8[604208+6>>0]|0;
 $16 = (($qualitySetting) + 8|0);
 HEAP8[$16>>0] = 0;
 $17 = (($qualitySetting) + 12|0);
 HEAP32[$17>>2] = 0;
 $18 = (($qualitySetting) + 16|0);
 HEAP32[$18>>2] = 0;
 $19 = (($qualitySetting) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($qualitySetting) + 24|0);
 HEAP32[$20>>2] = 1;
 $21 = (($qualitySetting) + 28|0);
 HEAP32[$21>>2] = 1;
 $22 = (($qualitySetting) + 32|0);
 HEAP32[$22>>2] = 1;
 $23 = (($qualitySetting) + 36|0);
 HEAPF32[$23>>2] = Math_fround(15.0);
 $24 = (($qualitySetting) + 40|0);
 HEAPF32[$24>>2] = Math_fround(0.333333343267440795898);
 $25 = (($qualitySetting) + 44|0);
 HEAPF32[$25>>2] = Math_fround(0.0666666701436042785645);
 $26 = (($qualitySetting) + 48|0);
 HEAPF32[$26>>2] = Math_fround(0.20000000298023223877);
 $27 = (($qualitySetting) + 52|0);
 HEAPF32[$27>>2] = Math_fround(0.46666666865348815918);
 $28 = (($qualitySetting) + 56|0);
 HEAP32[$28>>2] = 1;
 $29 = (($qualitySetting) + 60|0);
 HEAP32[$29>>2] = 1;
 $30 = (($qualitySetting) + 64|0);
 $31 = (($qualitySetting) + 80|0);
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;
 HEAPF32[$31>>2] = Math_fround(0.300000011920928955078);
 $32 = (($qualitySetting) + 84|0);
 HEAP32[$32>>2] = 0;
 $33 = (($qualitySetting) + 88|0);
 HEAP32[$33>>2] = 4;
 $34 = (($qualitySetting) + 92|0);
 HEAPF32[$34>>2] = Math_fround(512.0);
 $35 = (($m_Quality) + 480|0);
 __THREW__ = 0;
 (invoke_iii(2359,($35|0),($qualitySetting|0))|0);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 do {
  if ($37) {
   label = 31;
  } else {
   $38 = (($m_Quality) + 492|0);
   dest=$38+0|0; src=$17+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $39 = (($m_Quality) + 384|0);
   __THREW__ = 0;
   (invoke_iii(2359,($39|0),($35|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    label = 31;
   } else {
    $42 = (($m_Quality) + 396|0);
    dest=$42+0|0; src=$38+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $43 = (($m_Quality) + 288|0);
    __THREW__ = 0;
    (invoke_iii(2359,($43|0),($39|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     label = 31;
    } else {
     $46 = (($m_Quality) + 300|0);
     dest=$46+0|0; src=$42+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $47 = (($m_Quality) + 192|0);
     __THREW__ = 0;
     (invoke_iii(2359,($47|0),($43|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      label = 31;
     } else {
      $50 = (($m_Quality) + 204|0);
      dest=$50+0|0; src=$46+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $51 = (($m_Quality) + 96|0);
      __THREW__ = 0;
      (invoke_iii(2359,($51|0),($47|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 31;
      } else {
       $54 = (($m_Quality) + 108|0);
       dest=$54+0|0; src=$50+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       __THREW__ = 0;
       (invoke_iii(2359,($m_Quality|0),($51|0))|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        label = 31;
       } else {
        $57 = (($m_Quality) + 12|0);
        dest=$57+0|0; src=$54+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        HEAP8[$10>>0] = 8;
        $58 = (($10) + 1|0);
        HEAP8[$58>>0]=1953718598&255;HEAP8[$58+1>>0]=(1953718598>>8)&255;HEAP8[$58+2>>0]=(1953718598>>16)&255;HEAP8[$58+3>>0]=1953718598>>24;
        $59 = (($10) + 5|0);
        HEAP8[$59>>0] = 0;
        __THREW__ = 0;
        (invoke_iii(2359,($51|0),($10|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         $189 = ___cxa_find_matching_catch()|0;
         $190 = tempRet0;
         $191 = HEAP8[$10>>0]|0;
         $192 = $191 & 1;
         $193 = ($192<<24>>24)==(0);
         if ($193) {
          $$0 = $190;$$01 = $189;
          break;
         }
         $194 = (($10) + 8|0);
         $195 = HEAP32[$194>>2]|0;
         HEAP32[$4>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$4+0>>2]|0;
         invoke_vii(2591,($195|0),($$byval_copy11|0));
         $196 = __THREW__; __THREW__ = 0;
         $197 = $196&1;
         if (!($197)) {
          $$0 = $190;$$01 = $189;
          break;
         }
         $198 = ___cxa_find_matching_catch()|0;
         $199 = tempRet0;
         ___cxa_call_unexpected(($198|0));
         // unreachable;
        }
        $62 = HEAP8[$10>>0]|0;
        $63 = $62 & 1;
        $64 = ($63<<24>>24)==(0);
        if (!($64)) {
         $65 = (($10) + 8|0);
         $66 = HEAP32[$65>>2]|0;
         HEAP32[$8>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$8+0>>2]|0;
         invoke_vii(2591,($66|0),($$byval_copy11|0));
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          $69 = ___cxa_find_matching_catch()|0;
          $70 = tempRet0;
          ___cxa_call_unexpected(($69|0));
          // unreachable;
         }
        }
        $71 = (($m_Quality) + 132|0);
        HEAPF32[$71>>2] = Math_fround(20.0);
        $72 = (($m_Quality) + 152|0);
        HEAP32[$72>>2] = 2;
        $73 = (($m_Quality) + 156|0);
        $74 = (($m_Quality) + 176|0);
        ;HEAP32[$73+0>>2]=0|0;HEAP32[$73+4>>2]=0|0;HEAP32[$73+8>>2]=0|0;HEAP32[$73+12>>2]=0|0;HEAP16[$73+16>>1]=0|0;
        HEAPF32[$74>>2] = Math_fround(0.400000005960464477539);
        $75 = (($m_Quality) + 184|0);
        HEAP32[$75>>2] = 16;
        HEAP8[$11>>0] = 12;
        $76 = (($11) + 1|0);
        ;HEAP8[$76+0>>0]=HEAP8[604432+0>>0]|0;HEAP8[$76+1>>0]=HEAP8[604432+1>>0]|0;HEAP8[$76+2>>0]=HEAP8[604432+2>>0]|0;HEAP8[$76+3>>0]=HEAP8[604432+3>>0]|0;HEAP8[$76+4>>0]=HEAP8[604432+4>>0]|0;HEAP8[$76+5>>0]=HEAP8[604432+5>>0]|0;
        $77 = (($11) + 7|0);
        HEAP8[$77>>0] = 0;
        __THREW__ = 0;
        (invoke_iii(2359,($47|0),($11|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         $200 = ___cxa_find_matching_catch()|0;
         $201 = tempRet0;
         $202 = HEAP8[$11>>0]|0;
         $203 = $202 & 1;
         $204 = ($203<<24>>24)==(0);
         if ($204) {
          $$0 = $201;$$01 = $200;
          break;
         }
         $205 = (($11) + 8|0);
         $206 = HEAP32[$205>>2]|0;
         HEAP32[$3>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
         invoke_vii(2591,($206|0),($$byval_copy11|0));
         $207 = __THREW__; __THREW__ = 0;
         $208 = $207&1;
         if (!($208)) {
          $$0 = $201;$$01 = $200;
          break;
         }
         $209 = ___cxa_find_matching_catch()|0;
         $210 = tempRet0;
         ___cxa_call_unexpected(($209|0));
         // unreachable;
        }
        $80 = HEAP8[$11>>0]|0;
        $81 = $80 & 1;
        $82 = ($81<<24>>24)==(0);
        if (!($82)) {
         $83 = (($11) + 8|0);
         $84 = HEAP32[$83>>2]|0;
         HEAP32[$7>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$7+0>>2]|0;
         invoke_vii(2591,($84|0),($$byval_copy11|0));
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          $87 = ___cxa_find_matching_catch()|0;
          $88 = tempRet0;
          ___cxa_call_unexpected(($87|0));
          // unreachable;
         }
        }
        HEAP32[$50>>2] = 1;
        $89 = (($m_Quality) + 208|0);
        HEAP32[$89>>2] = 1;
        $90 = (($m_Quality) + 228|0);
        HEAPF32[$90>>2] = Math_fround(20.0);
        $91 = (($m_Quality) + 248|0);
        HEAP32[$91>>2] = 2;
        $92 = (($m_Quality) + 252|0);
        HEAP32[$92>>2] = 0;
        $93 = (($m_Quality) + 256|0);
        HEAP32[$93>>2] = 1;
        $94 = (($m_Quality) + 260|0);
        $95 = (($m_Quality) + 272|0);
        ;HEAP32[$94+0>>2]=0|0;HEAP32[$94+4>>2]=0|0;HEAP16[$94+8>>1]=0|0;
        HEAPF32[$95>>2] = Math_fround(0.699999988079071044921);
        $96 = (($m_Quality) + 280|0);
        HEAP32[$96>>2] = 64;
        HEAP8[$12>>0] = 8;
        $97 = (($12) + 1|0);
        HEAP8[$97>>0]=1685024583&255;HEAP8[$97+1>>0]=(1685024583>>8)&255;HEAP8[$97+2>>0]=(1685024583>>16)&255;HEAP8[$97+3>>0]=1685024583>>24;
        $98 = (($12) + 5|0);
        HEAP8[$98>>0] = 0;
        __THREW__ = 0;
        (invoke_iii(2359,($43|0),($12|0))|0);
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         $211 = ___cxa_find_matching_catch()|0;
         $212 = tempRet0;
         $213 = HEAP8[$12>>0]|0;
         $214 = $213 & 1;
         $215 = ($214<<24>>24)==(0);
         if ($215) {
          $$0 = $212;$$01 = $211;
          break;
         }
         $216 = (($12) + 8|0);
         $217 = HEAP32[$216>>2]|0;
         HEAP32[$2>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
         invoke_vii(2591,($217|0),($$byval_copy11|0));
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if (!($219)) {
          $$0 = $212;$$01 = $211;
          break;
         }
         $220 = ___cxa_find_matching_catch()|0;
         $221 = tempRet0;
         ___cxa_call_unexpected(($220|0));
         // unreachable;
        }
        $101 = HEAP8[$12>>0]|0;
        $102 = $101 & 1;
        $103 = ($102<<24>>24)==(0);
        if (!($103)) {
         $104 = (($12) + 8|0);
         $105 = HEAP32[$104>>2]|0;
         HEAP32[$6>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$6+0>>2]|0;
         invoke_vii(2591,($105|0),($$byval_copy11|0));
         $106 = __THREW__; __THREW__ = 0;
         $107 = $106&1;
         if ($107) {
          $108 = ___cxa_find_matching_catch()|0;
          $109 = tempRet0;
          ___cxa_call_unexpected(($108|0));
          // unreachable;
         }
        }
        HEAP32[$46>>2] = 2;
        $110 = (($m_Quality) + 304|0);
        HEAP32[$110>>2] = 2;
        $111 = (($m_Quality) + 308|0);
        HEAP32[$111>>2] = 1;
        $112 = (($m_Quality) + 316|0);
        HEAP32[$112>>2] = 2;
        $113 = (($m_Quality) + 324|0);
        HEAPF32[$113>>2] = Math_fround(40.0);
        $114 = (($m_Quality) + 328|0);
        HEAPF32[$114>>2] = Math_fround(0.333333343267440795898);
        $115 = (($m_Quality) + 344|0);
        HEAP32[$115>>2] = 2;
        $116 = (($m_Quality) + 348|0);
        HEAP32[$116>>2] = 0;
        $117 = (($m_Quality) + 352|0);
        HEAP32[$117>>2] = 1;
        $118 = (($m_Quality) + 360|0);
        HEAP32[$118>>2] = 1;
        $119 = (($m_Quality) + 365|0);
        HEAP8[$119>>0] = 1;
        $120 = (($m_Quality) + 366|0);
        HEAP8[$120>>0] = 1;
        $121 = (($m_Quality) + 367|0);
        HEAP8[$121>>0] = 1;
        $122 = (($m_Quality) + 368|0);
        HEAPF32[$122>>2] = Math_fround(1.0);
        $123 = (($m_Quality) + 376|0);
        HEAP32[$123>>2] = 256;
        HEAP8[$13>>0] = 18;
        $124 = (($13) + 1|0);
        dest=$124+0|0; src=604448+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $125 = (($13) + 10|0);
        HEAP8[$125>>0] = 0;
        __THREW__ = 0;
        (invoke_iii(2359,($39|0),($13|0))|0);
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if ($127) {
         $222 = ___cxa_find_matching_catch()|0;
         $223 = tempRet0;
         $224 = HEAP8[$13>>0]|0;
         $225 = $224 & 1;
         $226 = ($225<<24>>24)==(0);
         if ($226) {
          $$0 = $223;$$01 = $222;
          break;
         }
         $227 = (($13) + 8|0);
         $228 = HEAP32[$227>>2]|0;
         HEAP32[$1>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
         invoke_vii(2591,($228|0),($$byval_copy11|0));
         $229 = __THREW__; __THREW__ = 0;
         $230 = $229&1;
         if (!($230)) {
          $$0 = $223;$$01 = $222;
          break;
         }
         $231 = ___cxa_find_matching_catch()|0;
         $232 = tempRet0;
         ___cxa_call_unexpected(($231|0));
         // unreachable;
        }
        $128 = HEAP8[$13>>0]|0;
        $129 = $128 & 1;
        $130 = ($129<<24>>24)==(0);
        if (!($130)) {
         $131 = (($13) + 8|0);
         $132 = HEAP32[$131>>2]|0;
         HEAP32[$5>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$5+0>>2]|0;
         invoke_vii(2591,($132|0),($$byval_copy11|0));
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          $135 = ___cxa_find_matching_catch()|0;
          $136 = tempRet0;
          ___cxa_call_unexpected(($135|0));
          // unreachable;
         }
        }
        HEAP32[$42>>2] = 3;
        $137 = (($m_Quality) + 400|0);
        HEAP32[$137>>2] = 2;
        $138 = (($m_Quality) + 404|0);
        HEAP32[$138>>2] = 2;
        $139 = (($m_Quality) + 412|0);
        HEAP32[$139>>2] = 2;
        $140 = (($m_Quality) + 420|0);
        HEAPF32[$140>>2] = Math_fround(70.0);
        $141 = (($m_Quality) + 424|0);
        HEAPF32[$141>>2] = Math_fround(0.333333343267440795898);
        $142 = (($m_Quality) + 440|0);
        HEAP32[$142>>2] = 4;
        $143 = (($m_Quality) + 444|0);
        HEAP32[$143>>2] = 0;
        $144 = (($m_Quality) + 448|0);
        HEAP32[$144>>2] = 2;
        $145 = (($m_Quality) + 452|0);
        HEAP32[$145>>2] = 2;
        $146 = (($m_Quality) + 456|0);
        HEAP32[$146>>2] = 1;
        $147 = (($m_Quality) + 460|0);
        $148 = (($m_Quality) + 464|0);
        HEAP8[$147>>0]=16843009&255;HEAP8[$147+1>>0]=(16843009>>8)&255;HEAP8[$147+2>>0]=(16843009>>16)&255;HEAP8[$147+3>>0]=16843009>>24;
        HEAPF32[$148>>2] = Math_fround(1.5);
        $149 = (($m_Quality) + 472|0);
        HEAP32[$149>>2] = 1024;
        HEAP8[$14>>0] = 18;
        $150 = (($14) + 1|0);
        dest=$150+0|0; src=604464+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $151 = (($14) + 10|0);
        HEAP8[$151>>0] = 0;
        __THREW__ = 0;
        (invoke_iii(2359,($35|0),($14|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         $233 = ___cxa_find_matching_catch()|0;
         $234 = tempRet0;
         $235 = HEAP8[$14>>0]|0;
         $236 = $235 & 1;
         $237 = ($236<<24>>24)==(0);
         if ($237) {
          $$0 = $234;$$01 = $233;
          break;
         }
         $238 = (($14) + 8|0);
         $239 = HEAP32[$238>>2]|0;
         HEAP32[$0>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($239|0),($$byval_copy11|0));
         $240 = __THREW__; __THREW__ = 0;
         $241 = $240&1;
         if (!($241)) {
          $$0 = $234;$$01 = $233;
          break;
         }
         $242 = ___cxa_find_matching_catch()|0;
         $243 = tempRet0;
         ___cxa_call_unexpected(($242|0));
         // unreachable;
        }
        $154 = HEAP8[$14>>0]|0;
        $155 = $154 & 1;
        $156 = ($155<<24>>24)==(0);
        if (!($156)) {
         $157 = (($14) + 8|0);
         $158 = HEAP32[$157>>2]|0;
         HEAP32[$1>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
         invoke_vii(2591,($158|0),($$byval_copy11|0));
         $159 = __THREW__; __THREW__ = 0;
         $160 = $159&1;
         if ($160) {
          $161 = ___cxa_find_matching_catch()|0;
          $162 = tempRet0;
          ___cxa_call_unexpected(($161|0));
          // unreachable;
         }
        }
        HEAP32[$38>>2] = 4;
        $163 = (($m_Quality) + 496|0);
        HEAP32[$163>>2] = 2;
        $164 = (($m_Quality) + 500|0);
        HEAP32[$164>>2] = 3;
        $165 = (($m_Quality) + 508|0);
        HEAP32[$165>>2] = 4;
        $166 = (($m_Quality) + 516|0);
        HEAPF32[$166>>2] = Math_fround(150.0);
        $167 = (($m_Quality) + 332|0);
        HEAPF32[$167>>2] = Math_fround(0.0666666701436042785645);
        $168 = (($m_Quality) + 336|0);
        HEAPF32[$168>>2] = Math_fround(0.20000000298023223877);
        $169 = (($m_Quality) + 340|0);
        HEAPF32[$169>>2] = Math_fround(0.46666666865348815918);
        $170 = (($m_Quality) + 536|0);
        HEAP32[$170>>2] = 4;
        $171 = (($m_Quality) + 540|0);
        HEAP32[$171>>2] = 0;
        $172 = (($m_Quality) + 544|0);
        HEAP32[$172>>2] = 2;
        $173 = (($m_Quality) + 548|0);
        HEAP32[$173>>2] = 2;
        $174 = (($m_Quality) + 552|0);
        HEAP32[$174>>2] = 1;
        $175 = (($m_Quality) + 556|0);
        $176 = (($m_Quality) + 504|0);
        HEAP8[$175>>0]=16843009&255;HEAP8[$175+1>>0]=(16843009>>8)&255;HEAP8[$175+2>>0]=(16843009>>16)&255;HEAP8[$175+3>>0]=16843009>>24;
        HEAP32[$176>>2] = 0;
        $177 = (($m_Quality) + 560|0);
        HEAPF32[$177>>2] = Math_fround(2.0);
        $178 = (($m_Quality) + 568|0);
        HEAP32[$178>>2] = 4096;
        $179 = HEAP8[$qualitySetting>>0]|0;
        $180 = $179 & 1;
        $181 = ($180<<24>>24)==(0);
        if ($181) {
         STACKTOP = sp;return;
        }
        $182 = HEAP32[$16>>2]|0;
        HEAP32[$0>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($182|0),($$byval_copy11|0));
        $183 = __THREW__; __THREW__ = 0;
        $184 = $183&1;
        if ($184) {
         $185 = ___cxa_find_matching_catch()|0;
         $186 = tempRet0;
         ___cxa_call_unexpected(($185|0));
         // unreachable;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 31) {
  $187 = ___cxa_find_matching_catch()|0;
  $188 = tempRet0;
  $$0 = $188;$$01 = $187;
 }
 $244 = HEAP8[$qualitySetting>>0]|0;
 $245 = $244 & 1;
 $246 = ($245<<24>>24)==(0);
 if ($246) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $247 = HEAP32[$16>>2]|0;
 HEAP32[$9>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$9+0>>2]|0;
 invoke_vii(2591,($247|0),($$byval_copy11|0));
 $248 = __THREW__; __THREW__ = 0;
 $249 = $248&1;
 if ($249) {
  $250 = ___cxa_find_matching_catch()|0;
  $251 = tempRet0;
  ___cxa_call_unexpected(($250|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i2 = 0, $$0$lcssa$i$i = 0, $$012$i$i = 0, $$03$i$i = 0, $$byval_copy1 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep6$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = $__last;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = (($4|0) / 96)&-1;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = (($11|0) / 96)&-1;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $46 = ($8|0)==(0|0);
  if ($46) {
   $66 = $7;
  } else {
   $47 = (($this) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($8|0);
   do {
    if ($49) {
     $63 = $8;
    } else {
     $51 = $48;
     while(1) {
      $50 = (($51) + -96|0);
      HEAP32[$47>>2] = $50;
      $52 = HEAP8[$50>>0]|0;
      $53 = $52 & 1;
      $54 = ($53<<24>>24)==(0);
      if ($54) {
       $56 = $50;
      } else {
       $57 = (($51) + -88|0);
       $58 = HEAP32[$57>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($58|0),($$byval_copy1|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$47>>2]|0;
       $56 = $$pre$i$i$i$i;
      }
      $55 = ($56|0)==($8|0);
      if ($55) {
       label = 25;
       break;
      } else {
       $51 = $56;
      }
     }
     if ((label|0) == 24) {
      $61 = ___cxa_find_matching_catch()|0;
      $62 = tempRet0;
      ___cxa_call_unexpected(($61|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $63 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($63);
   HEAP32[$6>>2] = 0;
   HEAP32[$47>>2] = 0;
   HEAP32[$this>>2] = 0;
   $66 = 0;
  }
  $64 = ($5>>>0)>(44739242);
  if ($64) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $65 = $66;
  $67 = (($65|0) / 96)&-1;
  $68 = ($67>>>0)<(22369621);
  if ($68) {
   $69 = $67 << 1;
   $70 = ($69>>>0)<($5>>>0);
   $71 = $70 ? $5 : $69;
   $72 = ($71>>>0)>(44739242);
   if ($72) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i2 = $71;
   }
  } else {
   $$0$i2 = 44739242;
  }
  $73 = ($$0$i2*96)|0;
  $74 = (__Znwj($73)|0);
  $75 = (($this) + 4|0);
  HEAP32[$75>>2] = $74;
  HEAP32[$this>>2] = $74;
  $76 = (($74) + (($$0$i2*96)|0)|0);
  HEAP32[$6>>2] = $76;
  __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE18__construct_at_endIPS2_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_($this,$__first,$__last);
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = (($17|0) / 96)&-1;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($__first) + (($18*96)|0)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $__last;$__growing$0$off0 = 0;
 }
 $21 = ($22|0)==($__first|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i = (($22) + -96|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($23)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $8;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($$03$i$i,$$012$i$i)|0);
   $24 = (($$03$i$i) + 12|0);
   $25 = (($$012$i$i) + 12|0);
   dest=$24+0|0; src=$25+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $26 = (($$012$i$i) + 96|0);
   $27 = (($$03$i$i) + 96|0);
   $28 = ($26|0)==($22|0);
   if ($28) {
    break;
   } else {
    $$012$i$i = $26;$$03$i$i = $27;
   }
  }
  $29 = (($uglygep6$i$i>>>0) / 96)&-1;
  $30 = (($29) + 1)|0;
  $scevgep7$i$i = (($8) + (($30*96)|0)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if ($__growing$0$off0) {
  __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE18__construct_at_endIPS2_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_($this,$22,$__last);
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$14>>2]|0;
 $32 = ($31|0)==($$0$lcssa$i$i|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $34 = $31;
 while(1) {
  $33 = (($34) + -96|0);
  HEAP32[$14>>2] = $33;
  $35 = HEAP8[$33>>0]|0;
  $36 = $35 & 1;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   $39 = $33;
  } else {
   $40 = (($34) + -88|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($41|0),($$byval_copy1|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    label = 16;
    break;
   }
   $$pre$i$i = HEAP32[$14>>2]|0;
   $39 = $$pre$i$i;
  }
  $38 = ($39|0)==($$0$lcssa$i$i|0);
  if ($38) {
   label = 33;
   break;
  } else {
   $34 = $39;
  }
 }
 if ((label|0) == 16) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 }
 else if ((label|0) == 33) {
  STACKTOP = sp;return;
 }
}
function __ZN15QualitySettings16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$ = 0, $$$i = 0, $$$i10 = 0, $$$i13 = 0, $$$i16 = 0, $$$i4 = 0, $$$i7 = 0, $$0$i = 0, $$0$i11 = 0, $$0$i14 = 0, $$0$i17 = 0, $$0$i5 = 0, $$0$i8 = 0, $$3 = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i = 0, $$pre25 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $i$024 = 0, $tempQuality = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 592|0;
 $$byval_copy2 = sp + 584|0;
 $0 = sp;
 $1 = sp + 4|0;
 $tempQuality = sp + 8|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 L1: do {
  if ($6) {
   $14 = (($tempQuality) + 576|0);
   HEAP8[$tempQuality>>0] = 14;
   $15 = (($tempQuality) + 1|0);
   ;HEAP8[$15+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$15+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$15+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$15+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$15+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$15+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$15+6>>0]=HEAP8[604208+6>>0]|0;
   $16 = (($tempQuality) + 8|0);
   HEAP8[$16>>0] = 0;
   $17 = (($tempQuality) + 12|0);
   HEAP32[$17>>2] = 0;
   $18 = (($tempQuality) + 16|0);
   HEAP32[$18>>2] = 0;
   $19 = (($tempQuality) + 20|0);
   HEAP32[$19>>2] = 0;
   $20 = (($tempQuality) + 24|0);
   HEAP32[$20>>2] = 1;
   $21 = (($tempQuality) + 28|0);
   HEAP32[$21>>2] = 1;
   $22 = (($tempQuality) + 32|0);
   HEAP32[$22>>2] = 1;
   $23 = (($tempQuality) + 36|0);
   HEAPF32[$23>>2] = Math_fround(15.0);
   $24 = (($tempQuality) + 40|0);
   HEAPF32[$24>>2] = Math_fround(0.333333343267440795898);
   $25 = (($tempQuality) + 44|0);
   HEAPF32[$25>>2] = Math_fround(0.0666666701436042785645);
   $26 = (($tempQuality) + 48|0);
   HEAPF32[$26>>2] = Math_fround(0.20000000298023223877);
   $27 = (($tempQuality) + 52|0);
   HEAPF32[$27>>2] = Math_fround(0.46666666865348815918);
   $28 = (($tempQuality) + 56|0);
   HEAP32[$28>>2] = 1;
   $29 = (($tempQuality) + 60|0);
   HEAP32[$29>>2] = 1;
   $30 = (($tempQuality) + 64|0);
   $31 = (($tempQuality) + 80|0);
   ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;
   HEAPF32[$31>>2] = Math_fround(0.300000011920928955078);
   $32 = (($tempQuality) + 84|0);
   HEAP32[$32>>2] = 0;
   $33 = (($tempQuality) + 88|0);
   HEAP32[$33>>2] = 4;
   $34 = (($tempQuality) + 92|0);
   HEAPF32[$34>>2] = Math_fround(512.0);
   $35 = (($tempQuality) + 96|0);
   HEAP8[$35>>0] = 14;
   $36 = (($35) + 1|0);
   ;HEAP8[$36+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$36+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$36+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$36+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$36+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$36+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$36+6>>0]=HEAP8[604208+6>>0]|0;
   $37 = (($tempQuality) + 104|0);
   HEAP8[$37>>0] = 0;
   $38 = (($tempQuality) + 108|0);
   HEAP32[$38>>2] = 0;
   $39 = (($tempQuality) + 112|0);
   HEAP32[$39>>2] = 0;
   $40 = (($tempQuality) + 116|0);
   HEAP32[$40>>2] = 0;
   $41 = (($tempQuality) + 120|0);
   HEAP32[$41>>2] = 1;
   $42 = (($tempQuality) + 124|0);
   HEAP32[$42>>2] = 1;
   $43 = (($tempQuality) + 128|0);
   HEAP32[$43>>2] = 1;
   $44 = (($tempQuality) + 132|0);
   HEAPF32[$44>>2] = Math_fround(15.0);
   $45 = (($tempQuality) + 136|0);
   HEAPF32[$45>>2] = Math_fround(0.333333343267440795898);
   $46 = (($tempQuality) + 140|0);
   HEAPF32[$46>>2] = Math_fround(0.0666666701436042785645);
   $47 = (($tempQuality) + 144|0);
   HEAPF32[$47>>2] = Math_fround(0.20000000298023223877);
   $48 = (($tempQuality) + 148|0);
   HEAPF32[$48>>2] = Math_fround(0.46666666865348815918);
   $49 = (($tempQuality) + 152|0);
   HEAP32[$49>>2] = 1;
   $50 = (($tempQuality) + 156|0);
   HEAP32[$50>>2] = 1;
   $51 = (($tempQuality) + 160|0);
   $52 = (($tempQuality) + 176|0);
   ;HEAP32[$51+0>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;HEAP32[$51+12>>2]=0|0;
   HEAPF32[$52>>2] = Math_fround(0.300000011920928955078);
   $53 = (($tempQuality) + 180|0);
   HEAP32[$53>>2] = 0;
   $54 = (($tempQuality) + 184|0);
   HEAP32[$54>>2] = 4;
   $55 = (($tempQuality) + 188|0);
   HEAPF32[$55>>2] = Math_fround(512.0);
   $56 = (($tempQuality) + 192|0);
   HEAP8[$56>>0] = 14;
   $57 = (($56) + 1|0);
   ;HEAP8[$57+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$57+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$57+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$57+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$57+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$57+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$57+6>>0]=HEAP8[604208+6>>0]|0;
   $58 = (($tempQuality) + 200|0);
   HEAP8[$58>>0] = 0;
   $59 = (($tempQuality) + 204|0);
   HEAP32[$59>>2] = 0;
   $60 = (($tempQuality) + 208|0);
   HEAP32[$60>>2] = 0;
   $61 = (($tempQuality) + 212|0);
   HEAP32[$61>>2] = 0;
   $62 = (($tempQuality) + 216|0);
   HEAP32[$62>>2] = 1;
   $63 = (($tempQuality) + 220|0);
   HEAP32[$63>>2] = 1;
   $64 = (($tempQuality) + 224|0);
   HEAP32[$64>>2] = 1;
   $65 = (($tempQuality) + 228|0);
   HEAPF32[$65>>2] = Math_fround(15.0);
   $66 = (($tempQuality) + 232|0);
   HEAPF32[$66>>2] = Math_fround(0.333333343267440795898);
   $67 = (($tempQuality) + 236|0);
   HEAPF32[$67>>2] = Math_fround(0.0666666701436042785645);
   $68 = (($tempQuality) + 240|0);
   HEAPF32[$68>>2] = Math_fround(0.20000000298023223877);
   $69 = (($tempQuality) + 244|0);
   HEAPF32[$69>>2] = Math_fround(0.46666666865348815918);
   $70 = (($tempQuality) + 248|0);
   HEAP32[$70>>2] = 1;
   $71 = (($tempQuality) + 252|0);
   HEAP32[$71>>2] = 1;
   $72 = (($tempQuality) + 256|0);
   $73 = (($tempQuality) + 272|0);
   ;HEAP32[$72+0>>2]=0|0;HEAP32[$72+4>>2]=0|0;HEAP32[$72+8>>2]=0|0;HEAP32[$72+12>>2]=0|0;
   HEAPF32[$73>>2] = Math_fround(0.300000011920928955078);
   $74 = (($tempQuality) + 276|0);
   HEAP32[$74>>2] = 0;
   $75 = (($tempQuality) + 280|0);
   HEAP32[$75>>2] = 4;
   $76 = (($tempQuality) + 284|0);
   HEAPF32[$76>>2] = Math_fround(512.0);
   $77 = (($tempQuality) + 288|0);
   HEAP8[$77>>0] = 14;
   $78 = (($77) + 1|0);
   ;HEAP8[$78+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$78+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$78+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$78+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$78+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$78+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$78+6>>0]=HEAP8[604208+6>>0]|0;
   $79 = (($tempQuality) + 296|0);
   HEAP8[$79>>0] = 0;
   $80 = (($tempQuality) + 300|0);
   HEAP32[$80>>2] = 0;
   $81 = (($tempQuality) + 304|0);
   HEAP32[$81>>2] = 0;
   $82 = (($tempQuality) + 308|0);
   HEAP32[$82>>2] = 0;
   $83 = (($tempQuality) + 312|0);
   HEAP32[$83>>2] = 1;
   $84 = (($tempQuality) + 316|0);
   HEAP32[$84>>2] = 1;
   $85 = (($tempQuality) + 320|0);
   HEAP32[$85>>2] = 1;
   $86 = (($tempQuality) + 324|0);
   HEAPF32[$86>>2] = Math_fround(15.0);
   $87 = (($tempQuality) + 328|0);
   HEAPF32[$87>>2] = Math_fround(0.333333343267440795898);
   $88 = (($tempQuality) + 332|0);
   HEAPF32[$88>>2] = Math_fround(0.0666666701436042785645);
   $89 = (($tempQuality) + 336|0);
   HEAPF32[$89>>2] = Math_fround(0.20000000298023223877);
   $90 = (($tempQuality) + 340|0);
   HEAPF32[$90>>2] = Math_fround(0.46666666865348815918);
   $91 = (($tempQuality) + 344|0);
   HEAP32[$91>>2] = 1;
   $92 = (($tempQuality) + 348|0);
   HEAP32[$92>>2] = 1;
   $93 = (($tempQuality) + 352|0);
   $94 = (($tempQuality) + 368|0);
   ;HEAP32[$93+0>>2]=0|0;HEAP32[$93+4>>2]=0|0;HEAP32[$93+8>>2]=0|0;HEAP32[$93+12>>2]=0|0;
   HEAPF32[$94>>2] = Math_fround(0.300000011920928955078);
   $95 = (($tempQuality) + 372|0);
   HEAP32[$95>>2] = 0;
   $96 = (($tempQuality) + 376|0);
   HEAP32[$96>>2] = 4;
   $97 = (($tempQuality) + 380|0);
   HEAPF32[$97>>2] = Math_fround(512.0);
   $98 = (($tempQuality) + 384|0);
   HEAP8[$98>>0] = 14;
   $99 = (($98) + 1|0);
   ;HEAP8[$99+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$99+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$99+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$99+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$99+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$99+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$99+6>>0]=HEAP8[604208+6>>0]|0;
   $100 = (($tempQuality) + 392|0);
   HEAP8[$100>>0] = 0;
   $101 = (($tempQuality) + 396|0);
   HEAP32[$101>>2] = 0;
   $102 = (($tempQuality) + 400|0);
   HEAP32[$102>>2] = 0;
   $103 = (($tempQuality) + 404|0);
   HEAP32[$103>>2] = 0;
   $104 = (($tempQuality) + 408|0);
   HEAP32[$104>>2] = 1;
   $105 = (($tempQuality) + 412|0);
   HEAP32[$105>>2] = 1;
   $106 = (($tempQuality) + 416|0);
   HEAP32[$106>>2] = 1;
   $107 = (($tempQuality) + 420|0);
   HEAPF32[$107>>2] = Math_fround(15.0);
   $108 = (($tempQuality) + 424|0);
   HEAPF32[$108>>2] = Math_fround(0.333333343267440795898);
   $109 = (($tempQuality) + 428|0);
   HEAPF32[$109>>2] = Math_fround(0.0666666701436042785645);
   $110 = (($tempQuality) + 432|0);
   HEAPF32[$110>>2] = Math_fround(0.20000000298023223877);
   $111 = (($tempQuality) + 436|0);
   HEAPF32[$111>>2] = Math_fround(0.46666666865348815918);
   $112 = (($tempQuality) + 440|0);
   HEAP32[$112>>2] = 1;
   $113 = (($tempQuality) + 444|0);
   HEAP32[$113>>2] = 1;
   $114 = (($tempQuality) + 448|0);
   $115 = (($tempQuality) + 464|0);
   ;HEAP32[$114+0>>2]=0|0;HEAP32[$114+4>>2]=0|0;HEAP32[$114+8>>2]=0|0;HEAP32[$114+12>>2]=0|0;
   HEAPF32[$115>>2] = Math_fround(0.300000011920928955078);
   $116 = (($tempQuality) + 468|0);
   HEAP32[$116>>2] = 0;
   $117 = (($tempQuality) + 472|0);
   HEAP32[$117>>2] = 4;
   $118 = (($tempQuality) + 476|0);
   HEAPF32[$118>>2] = Math_fround(512.0);
   $119 = (($tempQuality) + 480|0);
   HEAP8[$119>>0] = 14;
   $120 = (($119) + 1|0);
   ;HEAP8[$120+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$120+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$120+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$120+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$120+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$120+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$120+6>>0]=HEAP8[604208+6>>0]|0;
   $121 = (($tempQuality) + 488|0);
   HEAP8[$121>>0] = 0;
   $122 = (($tempQuality) + 492|0);
   HEAP32[$122>>2] = 0;
   $123 = (($tempQuality) + 496|0);
   HEAP32[$123>>2] = 0;
   $124 = (($tempQuality) + 500|0);
   HEAP32[$124>>2] = 0;
   $125 = (($tempQuality) + 504|0);
   HEAP32[$125>>2] = 1;
   $126 = (($tempQuality) + 508|0);
   HEAP32[$126>>2] = 1;
   $127 = (($tempQuality) + 512|0);
   HEAP32[$127>>2] = 1;
   $128 = (($tempQuality) + 516|0);
   HEAPF32[$128>>2] = Math_fround(15.0);
   $129 = (($tempQuality) + 520|0);
   HEAPF32[$129>>2] = Math_fround(0.333333343267440795898);
   $130 = (($tempQuality) + 524|0);
   HEAPF32[$130>>2] = Math_fround(0.0666666701436042785645);
   $131 = (($tempQuality) + 528|0);
   HEAPF32[$131>>2] = Math_fround(0.20000000298023223877);
   $132 = (($tempQuality) + 532|0);
   HEAPF32[$132>>2] = Math_fround(0.46666666865348815918);
   $133 = (($tempQuality) + 536|0);
   HEAP32[$133>>2] = 1;
   $134 = (($tempQuality) + 540|0);
   HEAP32[$134>>2] = 1;
   $135 = (($tempQuality) + 544|0);
   $136 = (($tempQuality) + 560|0);
   ;HEAP32[$135+0>>2]=0|0;HEAP32[$135+4>>2]=0|0;HEAP32[$135+8>>2]=0|0;HEAP32[$135+12>>2]=0|0;
   HEAPF32[$136>>2] = Math_fround(0.300000011920928955078);
   $137 = (($tempQuality) + 564|0);
   HEAP32[$137>>2] = 0;
   $138 = (($tempQuality) + 568|0);
   HEAP32[$138>>2] = 4;
   $139 = (($tempQuality) + 572|0);
   HEAPF32[$139>>2] = Math_fround(512.0);
   __THREW__ = 0;
   invoke_vi(3486,($tempQuality|0));
   $140 = __THREW__; __THREW__ = 0;
   $141 = $140&1;
   do {
    if (!($141)) {
     $142 = (($tempQuality) + 288|0);
     $143 = HEAP32[$4>>2]|0;
     $144 = (($this) + 32|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = ($143|0)==($145|0);
     if ($146) {
      __THREW__ = 0;
      invoke_vii(2715,($2|0),($142|0));
      $180 = __THREW__; __THREW__ = 0;
      $181 = $180&1;
      if ($181) {
       break;
      }
     } else {
      $147 = ($143|0)==(0|0);
      if ($147) {
       $179 = 0;
      } else {
       $148 = HEAP8[$142>>0]|0;
       $149 = $148 & 1;
       $150 = ($149<<24>>24)==(0);
       if ($150) {
        $155 = (($142) + 1|0);
        $156 = $148&255;
        $157 = $156 >>> 1;
        $159 = $157;$174 = $155;
       } else {
        $151 = (($tempQuality) + 296|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = (($tempQuality) + 292|0);
        $154 = HEAP32[$153>>2]|0;
        $159 = $154;$174 = $152;
       }
       $158 = ($159>>>0)>(2147483631);
       if ($158) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $160 = __THREW__; __THREW__ = 0;
        $161 = $160&1;
        if ($161) {
         break;
        }
        // unreachable;
       }
       $162 = ($159>>>0)<(11);
       if ($162) {
        $163 = $159 << 1;
        $164 = $163&255;
        HEAP8[$143>>0] = $164;
        $165 = (($143) + 1|0);
        $__p$0$i$i$i$i$i$i$i$i = $165;
       } else {
        $166 = (($159) + 16)|0;
        $167 = $166 & -16;
        HEAP32[$0>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
        $168 = (invoke_iiiiiii(102,($167|0),16,($$byval_copy2|0),0,(604264|0),79)|0);
        $169 = __THREW__; __THREW__ = 0;
        $170 = $169&1;
        if ($170) {
         break;
        }
        $171 = (($143) + 8|0);
        HEAP32[$171>>2] = $168;
        $172 = $167 | 1;
        HEAP32[$143>>2] = $172;
        $173 = (($143) + 4|0);
        HEAP32[$173>>2] = $159;
        $__p$0$i$i$i$i$i$i$i$i = $168;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($174|0),($159|0))|0;
       $175 = (($__p$0$i$i$i$i$i$i$i$i) + ($159)|0);
       HEAP8[$175>>0] = 0;
       $176 = (($143) + 12|0);
       $177 = (($tempQuality) + 300|0);
       dest=$176+0|0; src=$177+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $$pre$i = HEAP32[$4>>2]|0;
       $179 = $$pre$i;
      }
      $178 = (($179) + 96|0);
      HEAP32[$4>>2] = $178;
     }
     $183 = $14;
     while(1) {
      $182 = (($183) + -96|0);
      $184 = HEAP8[$182>>0]|0;
      $185 = $184 & 1;
      $186 = ($185<<24>>24)==(0);
      if (!($186)) {
       $187 = (($183) + -88|0);
       $188 = HEAP32[$187>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($188|0),($$byval_copy2|0));
       $189 = __THREW__; __THREW__ = 0;
       $190 = $189&1;
       if ($190) {
        label = 23;
        break;
       }
      }
      $193 = ($182|0)==($tempQuality|0);
      if ($193) {
       label = 2;
       break;
      } else {
       $183 = $182;
      }
     }
     if ((label|0) == 2) {
      $$pre = HEAP32[$4>>2]|0;
      $$pre25 = HEAP32[$2>>2]|0;
      $10 = $$pre25;$8 = $$pre;
      break L1;
     }
     else if ((label|0) == 23) {
      $191 = ___cxa_find_matching_catch()|0;
      $192 = tempRet0;
      ___cxa_call_unexpected(($191|0));
      // unreachable;
     }
    }
   } while(0);
   $194 = ___cxa_find_matching_catch()|0;
   $195 = tempRet0;
   $197 = $14;
   while(1) {
    $196 = (($197) + -96|0);
    $198 = HEAP8[$196>>0]|0;
    $199 = $198 & 1;
    $200 = ($199<<24>>24)==(0);
    if (!($200)) {
     $201 = (($197) + -88|0);
     $202 = HEAP32[$201>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($202|0),($$byval_copy2|0));
     $203 = __THREW__; __THREW__ = 0;
     $204 = $203&1;
     if ($204) {
      label = 28;
      break;
     }
    }
    $207 = ($196|0)==($tempQuality|0);
    if ($207) {
     label = 51;
     break;
    } else {
     $197 = $196;
    }
   }
   if ((label|0) == 28) {
    $205 = ___cxa_find_matching_catch()|0;
    $206 = tempRet0;
    ___cxa_call_unexpected(($205|0));
    // unreachable;
   }
   else if ((label|0) == 51) {
    ___resumeException($194|0);
    // unreachable;
   }
  } else {
   $10 = $3;$8 = $5;
  }
 } while(0);
 $7 = $8;
 $9 = $10;
 $11 = (($7) - ($9))|0;
 $12 = (($11|0) / 96)&-1;
 $13 = ($8|0)==($10|0);
 if (!($13)) {
  $i$024 = 0;
  while(1) {
   $208 = ((($10) + (($i$024*96)|0)|0) + 12|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = ($209|0)<(0);
   $211 = $210 ? 0 : $209;
   HEAP32[$208>>2] = $211;
   $212 = ((($10) + (($i$024*96)|0)|0) + 16|0);
   $213 = HEAP32[$212>>2]|0;
   $214 = ($213|0)<(0);
   if ($214) {
    $$0$i17 = 0;
   } else {
    $215 = ($213|0)>(2);
    $$$i16 = $215 ? 2 : $213;
    $$0$i17 = $$$i16;
   }
   HEAP32[$212>>2] = $$0$i17;
   $216 = ((($10) + (($i$024*96)|0)|0) + 20|0);
   $217 = HEAP32[$216>>2]|0;
   $218 = ($217|0)<(0);
   if ($218) {
    $$0$i14 = 0;
   } else {
    $219 = ($217|0)>(3);
    $$$i13 = $219 ? 3 : $217;
    $$0$i14 = $$$i13;
   }
   HEAP32[$216>>2] = $$0$i14;
   $220 = ((($10) + (($i$024*96)|0)|0) + 24|0);
   $221 = HEAP32[$220>>2]|0;
   $222 = ($221|0)<(0);
   if ($222) {
    $$0$i11 = 0;
   } else {
    $223 = ($221|0)>(1);
    $$$i10 = $223 ? 1 : $221;
    $$0$i11 = $$$i10;
   }
   HEAP32[$220>>2] = $$0$i11;
   $224 = ((($10) + (($i$024*96)|0)|0) + 28|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = ($225|0)<(1);
   if ($226) {
    $$0$i8 = 1;
   } else {
    $227 = ($225|0)>(4);
    $$$i7 = $227 ? 4 : $225;
    $$0$i8 = $$$i7;
   }
   $228 = ($$0$i8|0)==(3);
   $$ = $228 ? 2 : $$0$i8;
   HEAP32[$224>>2] = $$;
   $229 = ((($10) + (($i$024*96)|0)|0) + 68|0);
   $230 = HEAP32[$229>>2]|0;
   $231 = ($230|0)<(2);
   do {
    if ($231) {
     HEAP32[$229>>2] = 0;
    } else {
     $232 = ($230|0)<(4);
     if ($232) {
      HEAP32[$229>>2] = 2;
      break;
     }
     $233 = ($230|0)<(8);
     if ($233) {
      HEAP32[$229>>2] = 4;
      break;
     } else {
      HEAP32[$229>>2] = 8;
      break;
     }
    }
   } while(0);
   $234 = ((($10) + (($i$024*96)|0)|0) + 36|0);
   $235 = Math_fround(HEAPF32[$234>>2]);
   $236 = $235 < Math_fround(0.0);
   $237 = $236 ? Math_fround(0.0) : $235;
   HEAPF32[$234>>2] = $237;
   $238 = ((($10) + (($i$024*96)|0)|0) + 56|0);
   $239 = HEAP32[$238>>2]|0;
   $240 = ($239|0)<(1);
   $241 = $240 ? 1 : $239;
   $242 = ($241|0)>(4);
   $243 = $242 ? 4 : $241;
   $244 = ($243|0)==(3);
   $$3 = $244 ? 2 : $243;
   HEAP32[$238>>2] = $$3;
   $245 = ((($10) + (($i$024*96)|0)|0) + 60|0);
   $246 = HEAP32[$245>>2]|0;
   $247 = ($246|0)<(0);
   $248 = $247 ? 0 : $246;
   $249 = ($248|0)>(10);
   $250 = $249 ? 10 : $248;
   HEAP32[$245>>2] = $250;
   $251 = ((($10) + (($i$024*96)|0)|0) + 64|0);
   $252 = HEAP32[$251>>2]|0;
   $253 = ($252|0)<(0);
   $254 = $253 ? 0 : $252;
   $255 = ($254|0)>(3);
   $256 = $255 ? 3 : $254;
   HEAP32[$251>>2] = $256;
   $257 = ((($10) + (($i$024*96)|0)|0) + 72|0);
   $258 = HEAP32[$257>>2]|0;
   $259 = ($258|0)<(0);
   $260 = $259 ? 0 : $258;
   $261 = ($260|0)>(2);
   $262 = $261 ? 2 : $260;
   HEAP32[$257>>2] = $262;
   $263 = ((($10) + (($i$024*96)|0)|0) + 80|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = $264 > Math_fround(0.0);
   $266 = $265 ? $264 : Math_fround(0.0);
   HEAPF32[$263>>2] = $266;
   $267 = ((($10) + (($i$024*96)|0)|0) + 84|0);
   $268 = HEAP32[$267>>2]|0;
   $269 = ($268|0)<(0);
   if ($269) {
    $$0$i5 = 0;
   } else {
    $270 = ($268|0)>(7);
    $$$i4 = $270 ? 7 : $268;
    $$0$i5 = $$$i4;
   }
   HEAP32[$267>>2] = $$0$i5;
   $271 = (($i$024) + 1)|0;
   $272 = ($271>>>0)<($12>>>0);
   if ($272) {
    $i$024 = $271;
   } else {
    break;
   }
  }
 }
 $273 = (($this) + 40|0);
 $274 = (($12) + -1)|0;
 $275 = HEAP32[$273>>2]|0;
 $276 = ($275|0)<(0);
 if ($276) {
  $$0$i = 0;
  HEAP32[$273>>2] = $$0$i;
  STACKTOP = sp;return;
 }
 $277 = ($275|0)>($274|0);
 $$$i = $277 ? $274 : $275;
 $$0$i = $$$i;
 HEAP32[$273>>2] = $$0$i;
 STACKTOP = sp;return;
}
function __ZN15QualitySettings13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Znwj(32)|0);
 $2 = (($0) + 8|0);
 HEAP32[$2>>2] = $1;
 HEAP32[$0>>2] = 33;
 $3 = (($0) + 4|0);
 HEAP32[$3>>2] = 20;
 dest=$1+0|0; src=604240+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($1) + 20|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_iii(2398,($0|0),($6|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $27 = HEAP8[$0>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   ___resumeException($25|0);
   // unreachable;
  }
  $30 = HEAP32[$2>>2]|0;
  __ZdlPv($30);
  ___resumeException($25|0);
  // unreachable;
 }
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 96)&-1;
 $18 = (($17) + -1)|0;
 $19 = ($7|0)<(0);
 if ($19) {
  $$0$i = 0;
 } else {
  $20 = ($7|0)>($18|0);
  $$$i = $20 ? $18 : $7;
  $$0$i = $$$i;
 }
 HEAP32[$5>>2] = $$0$i;
 $21 = HEAP8[$0>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  __ZN15QualitySettings13ApplySettingsEib($this,-1,0);
  STACKTOP = sp;return;
 }
 $24 = HEAP32[$2>>2]|0;
 __ZdlPv($24);
 __ZN15QualitySettings13ApplySettingsEib($this,-1,0);
 STACKTOP = sp;return;
}
function __ZN15QualitySettings13ApplySettingsEib($this,$previousIndex,$applyExpensiveChanges) {
 $this = $this|0;
 $previousIndex = $previousIndex|0;
 $applyExpensiveChanges = $applyExpensiveChanges|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*96)|0)|0) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN7Texture13SetAnisoLimitEi($6);
 $7 = ((($4) + (($2*96)|0)|0) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN7Texture21SetMasterTextureLimitEib($8,1);
 $9 = (__Z21GetLODGroupManagerPtrv()|0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = (__Z18GetLODGroupManagerv()|0);
  $12 = ((($4) + (($2*96)|0)|0) + 80|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($11) + 20|0);
  HEAPF32[$14>>2] = $13;
 }
 $15 = ((($4) + (($2*96)|0)|0) + 84|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__Z14IsWorldPlayingv()|0);
 if ($17) {
  $18 = (($this) + 36|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)<($16|0);
  $21 = $20 ? $16 : $19;
  $26 = $21;
 } else {
  $26 = $16;
 }
 $22 = (__Z21GetLODGroupManagerPtrv()|0);
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = (__Z18GetLODGroupManagerv()|0);
  $25 = (($24) + 24|0);
  HEAP32[$25>>2] = $26;
 }
 if (!($applyExpensiveChanges)) {
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$3>>2]|0;
 $28 = ((($27) + (($previousIndex*96)|0)|0) + 68|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($4) + (($2*96)|0)|0) + 68|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($29|0)==($31|0);
 if ($32) {
  $33 = ((($27) + (($previousIndex*96)|0)|0) + 72|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ((($4) + (($2*96)|0)|0) + 72|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($34|0)==($36|0);
  if ($37) {
   STACKTOP = sp;return;
  }
 }
 $38 = (__Z16GetScreenManagerv()|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($38) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(-1);
 if ($44) {
  $45 = (($39) + 80|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (FUNCTION_TABLE_ii[$46 & 4095]($38)|0);
  $71 = $47;
 } else {
  $71 = $43;
 }
 $48 = (($38) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(-1);
 if ($50) {
  $51 = HEAP32[$38>>2]|0;
  $52 = (($51) + 84|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (FUNCTION_TABLE_ii[$53 & 4095]($38)|0);
  $72 = $54;
 } else {
  $72 = $49;
 }
 $55 = (($38) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(-1);
 if ($57) {
  $58 = HEAP32[$38>>2]|0;
  $59 = (($58) + 92|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (FUNCTION_TABLE_ii[$60 & 4095]($38)|0);
  $73 = $61;
 } else {
  $62 = ($56|0)==(1);
  $73 = $62;
 }
 $63 = (($38) + 16|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(-1);
 if ($65) {
  $66 = HEAP32[$38>>2]|0;
  $67 = (($66) + 28|0);
  $68 = HEAP32[$67>>2]|0;
  FUNCTION_TABLE_vii[$68 & 4095]($0,$38);
  $69 = (($0) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  $74 = $70;
 } else {
  $74 = $64;
 }
 FUNCTION_TABLE_viiiii[$41 & 255]($38,$71,$72,$73,$74);
 STACKTOP = sp;return;
}
function __ZN15QualitySettings28SetShadowDistanceTemporarilyEf($this,$shadowDistance) {
 $this = $this|0;
 $shadowDistance = Math_fround($shadowDistance);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $shadowDistance < Math_fround(0.0);
 $1 = $0 ? Math_fround(0.0) : $shadowDistance;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5) + (($3*96)|0)|0) + 36|0);
 HEAPF32[$6>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN15QualitySettings29GetShadowDistanceForRenderingEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(11)|0);
 $1 = (($0) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*96)|0)|0) + 36|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 STACKTOP = sp;return (Math_fround($6));
}
function __ZN15QualitySettingsD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((604096 + 8|0));
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN17GlobalGameManagerD2Ev($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($2|0);
 do {
  if ($6) {
   $20 = $2;
  } else {
   $8 = $5;
   while(1) {
    $7 = (($8) + -96|0);
    HEAP32[$4>>2] = $7;
    $9 = HEAP8[$7>>0]|0;
    $10 = $9 & 1;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $13 = $7;
    } else {
     $14 = (($8) + -88|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 8;
      break;
     }
     $$pre$i$i$i$i$i$i = HEAP32[$4>>2]|0;
     $13 = $$pre$i$i$i$i$i$i;
    }
    $12 = ($13|0)==($2|0);
    if ($12) {
     label = 9;
     break;
    } else {
     $8 = $13;
    }
   }
   if ((label|0) == 8) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 9) {
    $$pre$i$i$i$i = HEAP32[$1>>2]|0;
    $20 = $$pre$i$i$i$i;
    break;
   }
  }
 } while(0);
 __ZdlPv($20);
 __ZN17GlobalGameManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN15QualitySettingsD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((604096 + 8|0));
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  do {
   if ($6) {
    $20 = $2;
   } else {
    $8 = $5;
    while(1) {
     $7 = (($8) + -96|0);
     HEAP32[$4>>2] = $7;
     $9 = HEAP8[$7>>0]|0;
     $10 = $9 & 1;
     $11 = ($10<<24>>24)==(0);
     if ($11) {
      $13 = $7;
     } else {
      $14 = (($8) + -88|0);
      $15 = HEAP32[$14>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($15|0),($$byval_copy|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       label = 8;
       break;
      }
      $$pre$i$i$i$i$i$i$i = HEAP32[$4>>2]|0;
      $13 = $$pre$i$i$i$i$i$i$i;
     }
     $12 = ($13|0)==($2|0);
     if ($12) {
      label = 9;
      break;
     } else {
      $8 = $13;
     }
    }
    if ((label|0) == 8) {
     $18 = ___cxa_find_matching_catch()|0;
     $19 = tempRet0;
     ___cxa_call_unexpected(($18|0));
     // unreachable;
    }
    else if ((label|0) == 9) {
     $$pre$i$i$i$i$i = HEAP32[$1>>2]|0;
     $20 = $$pre$i$i$i$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($20);
 }
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if ($36) {
   $39 = ___cxa_find_matching_catch(0|0)|0;
   $40 = tempRet0;
   __THREW__ = 0;
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $43 = ___cxa_find_matching_catch(0|0)|0;
    $44 = tempRet0;
    ___clang_call_terminate($43);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $39;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if (!($38)) {
   $eh$lpad$body$index8Z2D = $34;$eh$lpad$body$indexZ2D = $33;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $45 = ___cxa_find_matching_catch(0|0)|0;
  $46 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $45;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   __THREW__ = 0;
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $29 = ___cxa_find_matching_catch(0|0)|0;
    $30 = tempRet0;
    ___clang_call_terminate($29);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $26;$eh$lpad$body$indexZ2D = $25;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if (!($32)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $47 = ___cxa_find_matching_catch()|0;
  $48 = tempRet0;
  $eh$lpad$body$index8Z2D = $48;$eh$lpad$body$indexZ2D = $47;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i8 = 0, $$0$i9 = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i$i = 0, $__v = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 96)&-1;
 $10 = (($9) + 1)|0;
 $11 = ($10>>>0)>(44739242);
 if ($11) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($7))|0;
 $16 = (($15|0) / 96)&-1;
 $17 = ($16>>>0)<(22369621);
 if ($17) {
  $20 = $16 << 1;
  $21 = ($20>>>0)<($10>>>0);
  $22 = $21 ? $10 : $20;
  $23 = (($__v) + 12|0);
  HEAP32[$23>>2] = 0;
  $24 = (($__v) + 16|0);
  HEAP32[$24>>2] = $2;
  $25 = ($22|0)==(0);
  if ($25) {
   $$0$i9 = 0;$28 = 0;$33 = $23;
  } else {
   $$0$i8 = $22;$105 = $23;
   label = 6;
  }
 } else {
  $18 = (($__v) + 12|0);
  HEAP32[$18>>2] = 0;
  $19 = (($__v) + 16|0);
  HEAP32[$19>>2] = $2;
  $$0$i8 = 44739242;$105 = $18;
  label = 6;
 }
 if ((label|0) == 6) {
  $26 = ($$0$i8*96)|0;
  $27 = (__Znwj($26)|0);
  $$0$i9 = $$0$i8;$28 = $27;$33 = $105;
 }
 HEAP32[$__v>>2] = $28;
 $29 = (($28) + (($9*96)|0)|0);
 $30 = (($__v) + 8|0);
 HEAP32[$30>>2] = $29;
 $31 = (($__v) + 4|0);
 HEAP32[$31>>2] = $29;
 $32 = (($28) + (($$0$i9*96)|0)|0);
 HEAP32[$33>>2] = $32;
 $34 = ($29|0)==(0|0);
 do {
  if ($34) {
   $66 = 0;
   label = 19;
  } else {
   $35 = HEAP8[$__x>>0]|0;
   $36 = $35 & 1;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    $42 = (($__x) + 1|0);
    $43 = $35&255;
    $44 = $43 >>> 1;
    $46 = $44;$61 = $42;
   } else {
    $38 = (($__x) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($__x) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $46 = $41;$61 = $39;
   }
   $45 = ($46>>>0)>(2147483631);
   if ($45) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    // unreachable;
   }
   $49 = ($46>>>0)<(11);
   if ($49) {
    $50 = $46 << 1;
    $51 = $50&255;
    HEAP8[$29>>0] = $51;
    $52 = (($29) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $52;
   } else {
    $53 = (($46) + 16)|0;
    $54 = $53 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $55 = (invoke_iiiiiii(102,($54|0),16,($$byval_copy2|0),0,(604264|0),79)|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = ((($28) + (($9*96)|0)|0) + 8|0);
    HEAP32[$58>>2] = $55;
    $59 = $54 | 1;
    HEAP32[$29>>2] = $59;
    $60 = ((($28) + (($9*96)|0)|0) + 4|0);
    HEAP32[$60>>2] = $46;
    $__p$0$i$i$i$i$i$i$i = $55;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($61|0),($46|0))|0;
   $62 = (($__p$0$i$i$i$i$i$i$i) + ($46)|0);
   HEAP8[$62>>0] = 0;
   $63 = ((($28) + (($9*96)|0)|0) + 12|0);
   $64 = (($__x) + 12|0);
   dest=$63+0|0; src=$64+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre = HEAP32[$30>>2]|0;
   $66 = $$pre;
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  $65 = (($66) + 96|0);
  HEAP32[$30>>2] = $65;
  __THREW__ = 0;
  invoke_vii(2716,($this|0),($__v|0));
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if (!($68)) {
   $69 = HEAP32[$31>>2]|0;
   $70 = HEAP32[$30>>2]|0;
   $71 = ($70|0)==($69|0);
   L28: do {
    if (!($71)) {
     $73 = $70;
     while(1) {
      $72 = (($73) + -96|0);
      HEAP32[$30>>2] = $72;
      $74 = HEAP8[$72>>0]|0;
      $75 = $74 & 1;
      $76 = ($75<<24>>24)==(0);
      if (!($76)) {
       $78 = (($73) + -88|0);
       $79 = HEAP32[$78>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($79|0),($$byval_copy2|0));
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
      }
      $77 = ($72|0)==($69|0);
      if ($77) {
       break L28;
      } else {
       $73 = $72;
      }
     }
     $82 = ___cxa_find_matching_catch()|0;
     $83 = tempRet0;
     ___cxa_call_unexpected(($82|0));
     // unreachable;
    }
   } while(0);
   $84 = HEAP32[$__v>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    STACKTOP = sp;return;
   }
   __ZdlPv($84);
   STACKTOP = sp;return;
  }
 }
 $86 = ___cxa_find_matching_catch()|0;
 $87 = tempRet0;
 $88 = HEAP32[$31>>2]|0;
 $89 = HEAP32[$30>>2]|0;
 $90 = ($89|0)==($88|0);
 L42: do {
  if (!($90)) {
   $92 = $89;
   while(1) {
    $91 = (($92) + -96|0);
    HEAP32[$30>>2] = $91;
    $93 = HEAP8[$91>>0]|0;
    $94 = $93 & 1;
    $95 = ($94<<24>>24)==(0);
    if (!($95)) {
     $97 = (($92) + -88|0);
     $98 = HEAP32[$97>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($98|0),($$byval_copy2|0));
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      break;
     }
    }
    $96 = ($91|0)==($88|0);
    if ($96) {
     break L42;
    } else {
     $92 = $91;
    }
   }
   $101 = ___cxa_find_matching_catch()|0;
   $102 = tempRet0;
   ___cxa_call_unexpected(($101|0));
   // unreachable;
  }
 } while(0);
 $103 = HEAP32[$__v>>2]|0;
 $104 = ($103|0)==(0|0);
 if ($104) {
  ___resumeException($86|0);
  // unreachable;
 }
 __ZdlPv($103);
 ___resumeException($86|0);
 // unreachable;
}
function __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__v) + 4|0);
 $5 = ($3|0)==($1|0);
 do {
  if ($5) {
   $$pre1 = HEAP32[$4>>2]|0;
   $38 = $$pre1;$39 = $1;
  } else {
   $$pre$i = HEAP32[$4>>2]|0;
   $$01$i = $3;$7 = $$pre$i;
   while(1) {
    $6 = (($7) + -96|0);
    $8 = (($$01$i) + -96|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9 & 1;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $16 = (($8) + 1|0);
     $17 = $9&255;
     $18 = $17 >>> 1;
     $20 = $18;$31 = $16;
    } else {
     $12 = (($$01$i) + -88|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($$01$i) + -92|0);
     $15 = HEAP32[$14>>2]|0;
     $20 = $15;$31 = $13;
    }
    $19 = ($20>>>0)>(2147483631);
    if ($19) {
     label = 8;
     break;
    }
    $21 = ($20>>>0)<(11);
    if ($21) {
     $22 = $20 << 1;
     $23 = $22&255;
     HEAP8[$6>>0] = $23;
     $24 = (($6) + 1|0);
     $__p$0$i$i$i$i$i$i$i$i = $24;
    } else {
     $25 = (($20) + 16)|0;
     $26 = $25 & -16;
     HEAP32[$0>>2] = 59;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $27 = (__Z15malloc_internaljj10MemLabelIdiPKci($26,16,$$byval_copy,0,604264,79)|0);
     $28 = (($7) + -88|0);
     HEAP32[$28>>2] = $27;
     $29 = $26 | 1;
     HEAP32[$6>>2] = $29;
     $30 = (($7) + -92|0);
     HEAP32[$30>>2] = $20;
     $__p$0$i$i$i$i$i$i$i$i = $27;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($31|0),($20|0))|0;
    $32 = (($__p$0$i$i$i$i$i$i$i$i) + ($20)|0);
    HEAP8[$32>>0] = 0;
    $33 = (($7) + -84|0);
    $34 = (($$01$i) + -84|0);
    dest=$33+0|0; src=$34+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $35 = HEAP32[$4>>2]|0;
    $36 = (($35) + -96|0);
    HEAP32[$4>>2] = $36;
    $37 = ($8|0)==($1|0);
    if ($37) {
     label = 13;
     break;
    } else {
     $$01$i = $8;$7 = $36;
    }
   }
   if ((label|0) == 8) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre = HEAP32[$this>>2]|0;
    $38 = $36;$39 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $38;
 HEAP32[$4>>2] = $39;
 $40 = (($__v) + 8|0);
 $41 = HEAP32[$2>>2]|0;
 $42 = HEAP32[$40>>2]|0;
 HEAP32[$2>>2] = $42;
 HEAP32[$40>>2] = $41;
 $43 = (($this) + 8|0);
 $44 = (($__v) + 12|0);
 $45 = HEAP32[$43>>2]|0;
 $46 = HEAP32[$44>>2]|0;
 HEAP32[$43>>2] = $46;
 HEAP32[$44>>2] = $45;
 $47 = HEAP32[$4>>2]|0;
 HEAP32[$__v>>2] = $47;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE18__construct_at_endIPS2_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$01 = 0, $$byval_copy = 0, $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__first|0)==($__last|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 $$pre = HEAP32[$2>>2]|0;
 $$01 = $__first;$4 = $$pre;
 while(1) {
  $3 = ($4|0)==(0|0);
  if ($3) {
   $32 = 0;
  } else {
   $5 = HEAP8[$$01>>0]|0;
   $6 = $5 & 1;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $12 = (($$01) + 1|0);
    $13 = $5&255;
    $14 = $13 >>> 1;
    $16 = $14;$27 = $12;
   } else {
    $8 = (($$01) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($$01) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $16 = $11;$27 = $9;
   }
   $15 = ($16>>>0)>(2147483631);
   if ($15) {
    label = 8;
    break;
   }
   $17 = ($16>>>0)<(11);
   if ($17) {
    $18 = $16 << 1;
    $19 = $18&255;
    HEAP8[$4>>0] = $19;
    $20 = (($4) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $20;
   } else {
    $21 = (($16) + 16)|0;
    $22 = $21 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,16,$$byval_copy,0,604264,79)|0);
    $24 = (($4) + 8|0);
    HEAP32[$24>>2] = $23;
    $25 = $22 | 1;
    HEAP32[$4>>2] = $25;
    $26 = (($4) + 4|0);
    HEAP32[$26>>2] = $16;
    $__p$0$i$i$i$i$i$i$i = $23;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($27|0),($16|0))|0;
   $28 = (($__p$0$i$i$i$i$i$i$i) + ($16)|0);
   HEAP8[$28>>0] = 0;
   $29 = (($4) + 12|0);
   $30 = (($$01) + 12|0);
   dest=$29+0|0; src=$30+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre3 = HEAP32[$2>>2]|0;
   $32 = $$pre3;
  }
  $31 = (($32) + 96|0);
  HEAP32[$2>>2] = $31;
  $33 = (($$01) + 96|0);
  $34 = ($33|0)==($__last|0);
  if ($34) {
   label = 14;
   break;
  } else {
   $$01 = $33;$4 = $31;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZN15QualitySettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $17 = $3;$19 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre3 = HEAP32[$4>>2]|0;
  $17 = $$pre;$19 = $$pre3;
 }
 $8 = (($this) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 96)&-1;
 HEAP32[$size$i$i$i>>2] = $15;
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)<($19>>>0);
 if ($18) {
  HEAP32[$17>>2] = $15;
  HEAP32[$1>>2] = $16;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i,4);
 }
 $20 = HEAP32[$8>>2]|0;
 $21 = HEAP32[$10>>2]|0;
 $22 = ($21|0)==($20|0);
 if (!($22)) {
  $23 = $21;
  while(1) {
   __ZN15QualitySettings14QualitySetting8TransferI19StreamedBinaryWriteILb0EEEEvRT_($23,$transfer);
   $24 = (($23) + 96|0);
   $25 = ($24|0)==($20|0);
   if ($25) {
    break;
   } else {
    $23 = $24;
   }
  }
 }
 $26 = (($this) + 36|0);
 $27 = HEAP32[$1>>2]|0;
 $28 = (($27) + 4|0);
 $29 = HEAP32[$4>>2]|0;
 $30 = ($28>>>0)<($29>>>0);
 if ($30) {
  $31 = HEAP32[$26>>2]|0;
  HEAP32[$27>>2] = $31;
  HEAP32[$1>>2] = $28;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,4);
  STACKTOP = sp;return;
 }
}
function __ZN15QualitySettings14QualitySetting8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre3$i$i$i = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0;
 var $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre4$i$i$i = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre5$i$i$i = 0, $$pre50 = 0, $$pre51 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre18;
 }
 $8 = (($this) + 16|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = HEAP32[$8>>2]|0;
  HEAP32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $16 = $$pre19;$18 = $$pre20;
 }
 $14 = (($this) + 20|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = HEAP32[$14>>2]|0;
  HEAP32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $22 = $$pre21;$24 = $$pre22;
 }
 $20 = (($this) + 24|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = HEAP32[$20>>2]|0;
  HEAP32[$22>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,4);
  $$pre23 = HEAP32[$1>>2]|0;
  $$pre24 = HEAP32[$4>>2]|0;
  $28 = $$pre23;$30 = $$pre24;
 }
 $26 = (($this) + 28|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)<($30>>>0);
 if ($29) {
  $31 = HEAP32[$26>>2]|0;
  HEAP32[$28>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,4);
  $$pre25 = HEAP32[$1>>2]|0;
  $$pre26 = HEAP32[$4>>2]|0;
  $34 = $$pre25;$36 = $$pre26;
 }
 $32 = (($this) + 32|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)<($36>>>0);
 if ($35) {
  $37 = HEAP32[$32>>2]|0;
  HEAP32[$34>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$32,4);
  $$pre27 = HEAP32[$1>>2]|0;
  $$pre28 = HEAP32[$4>>2]|0;
  $40 = $$pre27;$42 = $$pre28;
 }
 $38 = (($this) + 36|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)<($42>>>0);
 if ($41) {
  $43 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[$40>>2] = $43;
  HEAP32[$1>>2] = $39;
  $46 = $39;$48 = $42;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$38,4);
  $$pre29 = HEAP32[$1>>2]|0;
  $$pre30 = HEAP32[$4>>2]|0;
  $46 = $$pre29;$48 = $$pre30;
 }
 $44 = (($this) + 40|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)<($48>>>0);
 if ($47) {
  $49 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$46>>2] = $49;
  HEAP32[$1>>2] = $45;
  $52 = $45;$54 = $48;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$44,4);
  $$pre31 = HEAP32[$1>>2]|0;
  $$pre32 = HEAP32[$4>>2]|0;
  $52 = $$pre31;$54 = $$pre32;
 }
 $50 = (($this) + 44|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)<($54>>>0);
 if ($53) {
  $55 = Math_fround(HEAPF32[$50>>2]);
  HEAPF32[$52>>2] = $55;
  HEAP32[$1>>2] = $51;
  $58 = $51;$60 = $54;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$50,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre3$i$i$i = HEAP32[$4>>2]|0;
  $58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
 }
 $56 = (($this) + 48|0);
 $57 = (($58) + 4|0);
 $59 = ($57>>>0)<($60>>>0);
 if ($59) {
  $61 = Math_fround(HEAPF32[$56>>2]);
  HEAPF32[$58>>2] = $61;
  HEAP32[$1>>2] = $57;
  $64 = $57;$66 = $60;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$56,4);
  $$pre4$i$i$i = HEAP32[$1>>2]|0;
  $$pre5$i$i$i = HEAP32[$4>>2]|0;
  $64 = $$pre4$i$i$i;$66 = $$pre5$i$i$i;
 }
 $62 = (($this) + 52|0);
 $63 = (($64) + 4|0);
 $65 = ($63>>>0)<($66>>>0);
 if ($65) {
  $67 = Math_fround(HEAPF32[$62>>2]);
  HEAPF32[$64>>2] = $67;
  HEAP32[$1>>2] = $63;
  $70 = $63;$72 = $66;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$62,4);
  $$pre33 = HEAP32[$1>>2]|0;
  $$pre34 = HEAP32[$4>>2]|0;
  $70 = $$pre33;$72 = $$pre34;
 }
 $68 = (($this) + 56|0);
 $69 = (($70) + 4|0);
 $71 = ($69>>>0)<($72>>>0);
 if ($71) {
  $73 = HEAP32[$68>>2]|0;
  HEAP32[$70>>2] = $73;
  HEAP32[$1>>2] = $69;
  $76 = $69;$78 = $72;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$68,4);
  $$pre35 = HEAP32[$1>>2]|0;
  $$pre36 = HEAP32[$4>>2]|0;
  $76 = $$pre35;$78 = $$pre36;
 }
 $74 = (($this) + 60|0);
 $75 = (($76) + 4|0);
 $77 = ($75>>>0)<($78>>>0);
 if ($77) {
  $79 = HEAP32[$74>>2]|0;
  HEAP32[$76>>2] = $79;
  HEAP32[$1>>2] = $75;
  $82 = $75;$84 = $78;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$74,4);
  $$pre37 = HEAP32[$1>>2]|0;
  $$pre38 = HEAP32[$4>>2]|0;
  $82 = $$pre37;$84 = $$pre38;
 }
 $80 = (($this) + 64|0);
 $81 = (($82) + 4|0);
 $83 = ($81>>>0)<($84>>>0);
 if ($83) {
  $85 = HEAP32[$80>>2]|0;
  HEAP32[$82>>2] = $85;
  HEAP32[$1>>2] = $81;
  $88 = $81;$90 = $84;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$80,4);
  $$pre39 = HEAP32[$1>>2]|0;
  $$pre40 = HEAP32[$4>>2]|0;
  $88 = $$pre39;$90 = $$pre40;
 }
 $86 = (($this) + 68|0);
 $87 = (($88) + 4|0);
 $89 = ($87>>>0)<($90>>>0);
 if ($89) {
  $91 = HEAP32[$86>>2]|0;
  HEAP32[$88>>2] = $91;
  HEAP32[$1>>2] = $87;
  $94 = $87;$96 = $90;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$86,4);
  $$pre41 = HEAP32[$1>>2]|0;
  $$pre42 = HEAP32[$4>>2]|0;
  $94 = $$pre41;$96 = $$pre42;
 }
 $92 = (($this) + 76|0);
 $93 = (($94) + 1|0);
 $95 = ($93>>>0)<($96>>>0);
 if ($95) {
  $97 = HEAP8[$92>>0]|0;
  HEAP8[$94>>0] = $97;
  $98 = HEAP32[$1>>2]|0;
  $99 = (($98) + 1|0);
  HEAP32[$1>>2] = $99;
  $102 = $99;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$92,1);
  $$pre43 = HEAP32[$1>>2]|0;
  $102 = $$pre43;
 }
 $100 = (($this) + 77|0);
 $101 = (($102) + 1|0);
 $103 = HEAP32[$4>>2]|0;
 $104 = ($101>>>0)<($103>>>0);
 if ($104) {
  $105 = HEAP8[$100>>0]|0;
  HEAP8[$102>>0] = $105;
  $106 = HEAP32[$1>>2]|0;
  $107 = (($106) + 1|0);
  HEAP32[$1>>2] = $107;
  $110 = $107;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$100,1);
  $$pre44 = HEAP32[$1>>2]|0;
  $110 = $$pre44;
 }
 $108 = (($this) + 78|0);
 $109 = (($110) + 1|0);
 $111 = HEAP32[$4>>2]|0;
 $112 = ($109>>>0)<($111>>>0);
 if ($112) {
  $113 = HEAP8[$108>>0]|0;
  HEAP8[$110>>0] = $113;
  $114 = HEAP32[$1>>2]|0;
  $115 = (($114) + 1|0);
  HEAP32[$1>>2] = $115;
  $118 = $115;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$108,1);
  $$pre45 = HEAP32[$1>>2]|0;
  $118 = $$pre45;
 }
 $116 = (($this) + 79|0);
 $117 = (($118) + 1|0);
 $119 = HEAP32[$4>>2]|0;
 $120 = ($117>>>0)<($119>>>0);
 if ($120) {
  $121 = HEAP8[$116>>0]|0;
  HEAP8[$118>>0] = $121;
  $122 = HEAP32[$1>>2]|0;
  $123 = (($122) + 1|0);
  HEAP32[$1>>2] = $123;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$116,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $124 = (($this) + 72|0);
 $125 = HEAP32[$1>>2]|0;
 $126 = (($125) + 4|0);
 $127 = HEAP32[$4>>2]|0;
 $128 = ($126>>>0)<($127>>>0);
 if ($128) {
  $129 = HEAP32[$124>>2]|0;
  HEAP32[$125>>2] = $129;
  HEAP32[$1>>2] = $126;
  $132 = $126;$134 = $127;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$124,4);
  $$pre46 = HEAP32[$1>>2]|0;
  $$pre47 = HEAP32[$4>>2]|0;
  $132 = $$pre46;$134 = $$pre47;
 }
 $130 = (($this) + 80|0);
 $131 = (($132) + 4|0);
 $133 = ($131>>>0)<($134>>>0);
 if ($133) {
  $135 = Math_fround(HEAPF32[$130>>2]);
  HEAPF32[$132>>2] = $135;
  HEAP32[$1>>2] = $131;
  $138 = $131;$140 = $134;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$130,4);
  $$pre48 = HEAP32[$1>>2]|0;
  $$pre49 = HEAP32[$4>>2]|0;
  $138 = $$pre48;$140 = $$pre49;
 }
 $136 = (($this) + 84|0);
 $137 = (($138) + 4|0);
 $139 = ($137>>>0)<($140>>>0);
 if ($139) {
  $141 = HEAP32[$136>>2]|0;
  HEAP32[$138>>2] = $141;
  HEAP32[$1>>2] = $137;
  $144 = $137;$146 = $140;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$136,4);
  $$pre50 = HEAP32[$1>>2]|0;
  $$pre51 = HEAP32[$4>>2]|0;
  $144 = $$pre50;$146 = $$pre51;
 }
 $142 = (($this) + 88|0);
 $143 = (($144) + 4|0);
 $145 = ($143>>>0)<($146>>>0);
 if ($145) {
  $147 = HEAP32[$142>>2]|0;
  HEAP32[$144>>2] = $147;
  HEAP32[$1>>2] = $143;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$142,4);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN15QualitySettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i2 = HEAP32[$0>>2]|0;
  $8 = $$pre$i$i$i2;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN15QualitySettings14QualitySettingENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$10,0);
 $11 = (($this) + 36|0);
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$4>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $17 = $$pre$i$i$i;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$11>>2] = $18;
  STACKTOP = sp;return;
 } else {
  $16 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$1>>2] = $13;
  $17 = $16;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$11>>2] = $18;
  STACKTOP = sp;return;
 }
}
function __ZN15QualitySettings14QualitySetting8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i21 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i25 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i30 = 0, $$pre$i$i$i34 = 0, $$pre$i$i$i37 = 0, $$pre$i$i$i5 = 0, $$pre$i$i$i7 = 0, $$pre$i$i$i9 = 0, $$pre$phi$i$i$i17Z2D = 0, $$pre$phi$i$i$i35Z2D = 0, $$pre$phi$i$i$iZ2D = 0;
 var $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $$pre57 = 0, $$pre58 = 0;
 var $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre39 = HEAP32[$4>>2]|0;
  $12 = $$pre;$14 = $$pre39;$8 = $$pre$i$i$i1;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $12 = $3;$14 = $5;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 16|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,4);
  $$pre$i$i$i3 = HEAP32[$10>>2]|0;
  $$pre40 = HEAP32[$1>>2]|0;
  $$pre41 = HEAP32[$4>>2]|0;
  $16 = $$pre$i$i$i3;$20 = $$pre40;$22 = $$pre41;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$1>>2] = $11;
  $16 = $15;$20 = $11;$22 = $14;
 }
 $17 = (_llvm_bswap_i32(($16|0))|0);
 HEAP32[$10>>2] = $17;
 $18 = (($this) + 20|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)>($22>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$18,4);
  $$pre$i$i$i5 = HEAP32[$18>>2]|0;
  $$pre42 = HEAP32[$1>>2]|0;
  $$pre43 = HEAP32[$4>>2]|0;
  $24 = $$pre$i$i$i5;$28 = $$pre42;$30 = $$pre43;
 } else {
  $23 = HEAP32[$20>>2]|0;
  HEAP32[$18>>2] = $23;
  HEAP32[$1>>2] = $19;
  $24 = $23;$28 = $19;$30 = $22;
 }
 $25 = (_llvm_bswap_i32(($24|0))|0);
 HEAP32[$18>>2] = $25;
 $26 = (($this) + 24|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre$i$i$i7 = HEAP32[$26>>2]|0;
  $$pre44 = HEAP32[$1>>2]|0;
  $$pre45 = HEAP32[$4>>2]|0;
  $32 = $$pre$i$i$i7;$36 = $$pre44;$38 = $$pre45;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $32 = $31;$36 = $27;$38 = $30;
 }
 $33 = (_llvm_bswap_i32(($32|0))|0);
 HEAP32[$26>>2] = $33;
 $34 = (($this) + 28|0);
 $35 = (($36) + 4|0);
 $37 = ($35>>>0)>($38>>>0);
 if ($37) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
  $$pre$i$i$i9 = HEAP32[$34>>2]|0;
  $$pre46 = HEAP32[$1>>2]|0;
  $$pre47 = HEAP32[$4>>2]|0;
  $40 = $$pre$i$i$i9;$44 = $$pre46;$46 = $$pre47;
 } else {
  $39 = HEAP32[$36>>2]|0;
  HEAP32[$34>>2] = $39;
  HEAP32[$1>>2] = $35;
  $40 = $39;$44 = $35;$46 = $38;
 }
 $41 = (_llvm_bswap_i32(($40|0))|0);
 HEAP32[$34>>2] = $41;
 $42 = (($this) + 32|0);
 $43 = (($44) + 4|0);
 $45 = ($43>>>0)>($46>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$42,4);
  $$pre$i$i$i11 = HEAP32[$42>>2]|0;
  $$pre48 = HEAP32[$1>>2]|0;
  $$pre49 = HEAP32[$4>>2]|0;
  $48 = $$pre$i$i$i11;$52 = $$pre48;$54 = $$pre49;
 } else {
  $47 = HEAP32[$44>>2]|0;
  HEAP32[$42>>2] = $47;
  HEAP32[$1>>2] = $43;
  $48 = $47;$52 = $43;$54 = $46;
 }
 $49 = (_llvm_bswap_i32(($48|0))|0);
 HEAP32[$42>>2] = $49;
 $50 = (($this) + 36|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)>($54>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$50,4);
  $$pre$i$i$i13 = HEAP32[$50>>2]|0;
  $$pre50 = HEAP32[$1>>2]|0;
  $$pre51 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $50;$57 = $$pre$i$i$i13;$61 = $$pre50;$63 = $$pre51;
 } else {
  $55 = Math_fround(HEAPF32[$52>>2]);
  HEAPF32[$50>>2] = $55;
  HEAP32[$1>>2] = $51;
  $56 = (HEAPF32[tempDoublePtr>>2]=$55,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $50;$57 = $56;$61 = $51;$63 = $54;
 }
 $58 = (_llvm_bswap_i32(($57|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $58;
 $59 = (($this) + 40|0);
 $60 = (($61) + 4|0);
 $62 = ($60>>>0)>($63>>>0);
 if ($62) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$59,4);
  $$pre$i$i$i16 = HEAP32[$59>>2]|0;
  $$pre$phi$i$i$i17Z2D = $59;$66 = $$pre$i$i$i16;
 } else {
  $64 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$59>>2] = $64;
  HEAP32[$1>>2] = $60;
  $65 = (HEAPF32[tempDoublePtr>>2]=$64,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i17Z2D = $59;$66 = $65;
 }
 $67 = (_llvm_bswap_i32(($66|0))|0);
 HEAP32[$$pre$phi$i$i$i17Z2D>>2] = $67;
 $68 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$68,0,0);
 $69 = (($this) + 56|0);
 $70 = HEAP32[$1>>2]|0;
 $71 = (($70) + 4|0);
 $72 = HEAP32[$4>>2]|0;
 $73 = ($71>>>0)>($72>>>0);
 if ($73) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$69,4);
  $$pre$i$i$i19 = HEAP32[$69>>2]|0;
  $$pre52 = HEAP32[$1>>2]|0;
  $$pre53 = HEAP32[$4>>2]|0;
  $75 = $$pre$i$i$i19;$79 = $$pre52;$81 = $$pre53;
 } else {
  $74 = HEAP32[$70>>2]|0;
  HEAP32[$69>>2] = $74;
  HEAP32[$1>>2] = $71;
  $75 = $74;$79 = $71;$81 = $72;
 }
 $76 = (_llvm_bswap_i32(($75|0))|0);
 HEAP32[$69>>2] = $76;
 $77 = (($this) + 60|0);
 $78 = (($79) + 4|0);
 $80 = ($78>>>0)>($81>>>0);
 if ($80) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$77,4);
  $$pre$i$i$i21 = HEAP32[$77>>2]|0;
  $$pre54 = HEAP32[$1>>2]|0;
  $$pre55 = HEAP32[$4>>2]|0;
  $83 = $$pre$i$i$i21;$87 = $$pre54;$89 = $$pre55;
 } else {
  $82 = HEAP32[$79>>2]|0;
  HEAP32[$77>>2] = $82;
  HEAP32[$1>>2] = $78;
  $83 = $82;$87 = $78;$89 = $81;
 }
 $84 = (_llvm_bswap_i32(($83|0))|0);
 HEAP32[$77>>2] = $84;
 $85 = (($this) + 64|0);
 $86 = (($87) + 4|0);
 $88 = ($86>>>0)>($89>>>0);
 if ($88) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$85,4);
  $$pre$i$i$i23 = HEAP32[$85>>2]|0;
  $$pre56 = HEAP32[$1>>2]|0;
  $$pre57 = HEAP32[$4>>2]|0;
  $91 = $$pre$i$i$i23;$95 = $$pre56;$97 = $$pre57;
 } else {
  $90 = HEAP32[$87>>2]|0;
  HEAP32[$85>>2] = $90;
  HEAP32[$1>>2] = $86;
  $91 = $90;$95 = $86;$97 = $89;
 }
 $92 = (_llvm_bswap_i32(($91|0))|0);
 HEAP32[$85>>2] = $92;
 $93 = (($this) + 68|0);
 $94 = (($95) + 4|0);
 $96 = ($94>>>0)>($97>>>0);
 if ($96) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$93,4);
  $$pre$i$i$i25 = HEAP32[$93>>2]|0;
  $$pre58 = HEAP32[$1>>2]|0;
  $$pre59 = HEAP32[$4>>2]|0;
  $103 = $$pre58;$105 = $$pre59;$99 = $$pre$i$i$i25;
 } else {
  $98 = HEAP32[$95>>2]|0;
  HEAP32[$93>>2] = $98;
  HEAP32[$1>>2] = $94;
  $103 = $94;$105 = $97;$99 = $98;
 }
 $100 = (_llvm_bswap_i32(($99|0))|0);
 HEAP32[$93>>2] = $100;
 $101 = (($this) + 76|0);
 $102 = (($103) + 1|0);
 $104 = ($102>>>0)>($105>>>0);
 if ($104) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$101,1);
  $$pre60 = HEAP32[$1>>2]|0;
  $111 = $$pre60;
 } else {
  $106 = HEAP8[$103>>0]|0;
  HEAP8[$101>>0] = $106;
  $107 = HEAP32[$1>>2]|0;
  $108 = (($107) + 1|0);
  HEAP32[$1>>2] = $108;
  $111 = $108;
 }
 $109 = (($this) + 77|0);
 $110 = (($111) + 1|0);
 $112 = HEAP32[$4>>2]|0;
 $113 = ($110>>>0)>($112>>>0);
 if ($113) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$109,1);
  $$pre61 = HEAP32[$1>>2]|0;
  $119 = $$pre61;
 } else {
  $114 = HEAP8[$111>>0]|0;
  HEAP8[$109>>0] = $114;
  $115 = HEAP32[$1>>2]|0;
  $116 = (($115) + 1|0);
  HEAP32[$1>>2] = $116;
  $119 = $116;
 }
 $117 = (($this) + 78|0);
 $118 = (($119) + 1|0);
 $120 = HEAP32[$4>>2]|0;
 $121 = ($118>>>0)>($120>>>0);
 if ($121) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$117,1);
  $$pre62 = HEAP32[$1>>2]|0;
  $127 = $$pre62;
 } else {
  $122 = HEAP8[$119>>0]|0;
  HEAP8[$117>>0] = $122;
  $123 = HEAP32[$1>>2]|0;
  $124 = (($123) + 1|0);
  HEAP32[$1>>2] = $124;
  $127 = $124;
 }
 $125 = (($this) + 79|0);
 $126 = (($127) + 1|0);
 $128 = HEAP32[$4>>2]|0;
 $129 = ($126>>>0)>($128>>>0);
 if ($129) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$125,1);
 } else {
  $130 = HEAP8[$127>>0]|0;
  HEAP8[$125>>0] = $130;
  $131 = HEAP32[$1>>2]|0;
  $132 = (($131) + 1|0);
  HEAP32[$1>>2] = $132;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $133 = (($this) + 72|0);
 $134 = HEAP32[$1>>2]|0;
 $135 = (($134) + 4|0);
 $136 = HEAP32[$4>>2]|0;
 $137 = ($135>>>0)>($136>>>0);
 if ($137) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$133,4);
  $$pre$i$i$i30 = HEAP32[$133>>2]|0;
  $$pre63 = HEAP32[$1>>2]|0;
  $$pre64 = HEAP32[$4>>2]|0;
  $139 = $$pre$i$i$i30;$143 = $$pre63;$145 = $$pre64;
 } else {
  $138 = HEAP32[$134>>2]|0;
  HEAP32[$133>>2] = $138;
  HEAP32[$1>>2] = $135;
  $139 = $138;$143 = $135;$145 = $136;
 }
 $140 = (_llvm_bswap_i32(($139|0))|0);
 HEAP32[$133>>2] = $140;
 $141 = (($this) + 80|0);
 $142 = (($143) + 4|0);
 $144 = ($142>>>0)>($145>>>0);
 if ($144) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$141,4);
  $$pre$i$i$i34 = HEAP32[$141>>2]|0;
  $$pre65 = HEAP32[$1>>2]|0;
  $$pre66 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i35Z2D = $141;$148 = $$pre$i$i$i34;$152 = $$pre65;$154 = $$pre66;
 } else {
  $146 = Math_fround(HEAPF32[$143>>2]);
  HEAPF32[$141>>2] = $146;
  HEAP32[$1>>2] = $142;
  $147 = (HEAPF32[tempDoublePtr>>2]=$146,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i35Z2D = $141;$148 = $147;$152 = $142;$154 = $145;
 }
 $149 = (_llvm_bswap_i32(($148|0))|0);
 HEAP32[$$pre$phi$i$i$i35Z2D>>2] = $149;
 $150 = (($this) + 84|0);
 $151 = (($152) + 4|0);
 $153 = ($151>>>0)>($154>>>0);
 if ($153) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$150,4);
  $$pre$i$i$i37 = HEAP32[$150>>2]|0;
  $$pre67 = HEAP32[$1>>2]|0;
  $$pre68 = HEAP32[$4>>2]|0;
  $156 = $$pre$i$i$i37;$160 = $$pre67;$162 = $$pre68;
 } else {
  $155 = HEAP32[$152>>2]|0;
  HEAP32[$150>>2] = $155;
  HEAP32[$1>>2] = $151;
  $156 = $155;$160 = $151;$162 = $154;
 }
 $157 = (_llvm_bswap_i32(($156|0))|0);
 HEAP32[$150>>2] = $157;
 $158 = (($this) + 88|0);
 $159 = (($160) + 4|0);
 $161 = ($159>>>0)>($162>>>0);
 if ($161) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$158,4);
  $$pre$i$i$i = HEAP32[$158>>2]|0;
  $164 = $$pre$i$i$i;
  $165 = (_llvm_bswap_i32(($164|0))|0);
  HEAP32[$158>>2] = $165;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $163 = HEAP32[$160>>2]|0;
  HEAP32[$158>>2] = $163;
  HEAP32[$1>>2] = $159;
  $164 = $163;
  $165 = (_llvm_bswap_i32(($164|0))|0);
  HEAP32[$158>>2] = $165;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN15QualitySettings14QualitySettingENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorIN15QualitySettings14QualitySettingENS0_9allocatorIS3_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN15QualitySettings14QualitySetting8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 96|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*96)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIN15QualitySettings14QualitySettingENS0_9allocatorIS3_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy5 = 0, $$byval_copy8 = 0, $$idx = 0, $$pre = 0, $$pre$i$i$i$i$i16 = 0, $$pre$i$i$i$i$i8 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i5 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $temp = 0, $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 44|0;
 $$byval_copy5 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $temp = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $temp1 = sp + 32|0;
 $4 = (($v) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$v>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 96)&-1;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $95 = ($10>>>0)>($sz>>>0);
  if (!($95)) {
   STACKTOP = sp;return;
  }
  $96 = (($6) + (($sz*96)|0)|0);
  HEAP32[$temp1>>2] = 0;
  $97 = (($temp1) + 4|0);
  HEAP32[$97>>2] = 0;
  $98 = (($temp1) + 8|0);
  HEAP32[$98>>2] = 0;
  $$idx = ($sz*96)|0;
  $99 = (($$idx|0) / 96)&-1;
  $100 = ($sz|0)==(0);
  do {
   if ($100) {
    $128 = $6;$129 = 0;$130 = $5;$131 = 0;$134 = 0;
   } else {
    $101 = ($99>>>0)>(44739242);
    if ($101) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if (!($103)) {
      // unreachable;
     }
    } else {
     __THREW__ = 0;
     $104 = (invoke_ii(2988,($$idx|0))|0);
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if (!($106)) {
      HEAP32[$97>>2] = $104;
      HEAP32[$temp1>>2] = $104;
      $107 = (($104) + (($99*96)|0)|0);
      HEAP32[$98>>2] = $107;
      HEAP32[$0>>2] = $6;
      HEAP32[$1>>2] = $96;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_viii(1742,($temp1|0),($$byval_copy5|0),($$byval_copy8|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if (!($109)) {
       $$pre36 = HEAP32[$temp1>>2]|0;
       $$pre37 = HEAP32[$v>>2]|0;
       $$pre38 = HEAP32[$97>>2]|0;
       $$pre39 = HEAP32[$4>>2]|0;
       $$pre40 = HEAP32[$98>>2]|0;
       $128 = $$pre37;$129 = $$pre36;$130 = $$pre39;$131 = $$pre38;$134 = $$pre40;
       break;
      }
     }
    }
    $110 = ___cxa_find_matching_catch()|0;
    $111 = tempRet0;
    $112 = HEAP32[$temp1>>2]|0;
    $113 = ($112|0)==(0|0);
    if ($113) {
     ___resumeException($110|0);
     // unreachable;
    }
    $114 = HEAP32[$97>>2]|0;
    $115 = ($114|0)==($112|0);
    L18: do {
     if (!($115)) {
      $117 = $114;
      while(1) {
       $116 = (($117) + -96|0);
       HEAP32[$97>>2] = $116;
       $118 = HEAP8[$116>>0]|0;
       $119 = $118 & 1;
       $120 = ($119<<24>>24)==(0);
       if (!($120)) {
        $122 = (($117) + -88|0);
        $123 = HEAP32[$122>>2]|0;
        HEAP32[$$byval_copy5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
        invoke_vii(2591,($123|0),($$byval_copy8|0));
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break;
        }
       }
       $121 = ($116|0)==($112|0);
       if ($121) {
        break L18;
       } else {
        $117 = $116;
       }
      }
      $126 = ___cxa_find_matching_catch()|0;
      $127 = tempRet0;
      ___cxa_call_unexpected(($126|0));
      // unreachable;
     }
    } while(0);
    __ZdlPv($112);
    ___resumeException($110|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$temp1>>2] = $128;
  HEAP32[$v>>2] = $129;
  HEAP32[$97>>2] = $130;
  HEAP32[$4>>2] = $131;
  $132 = (($v) + 8|0);
  $133 = HEAP32[$132>>2]|0;
  HEAP32[$98>>2] = $133;
  HEAP32[$132>>2] = $134;
  $135 = ($128|0)==(0|0);
  if ($135) {
   STACKTOP = sp;return;
  }
  $136 = ($130|0)==($128|0);
  L32: do {
   if (!($136)) {
    $138 = $130;
    while(1) {
     $137 = (($138) + -96|0);
     HEAP32[$97>>2] = $137;
     $139 = HEAP8[$137>>0]|0;
     $140 = $139 & 1;
     $141 = ($140<<24>>24)==(0);
     if (!($141)) {
      $143 = (($138) + -88|0);
      $144 = HEAP32[$143>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($144|0),($$byval_copy8|0));
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       break;
      }
     }
     $142 = ($137|0)==($128|0);
     if ($142) {
      break L32;
     } else {
      $138 = $137;
     }
    }
    $147 = ___cxa_find_matching_catch()|0;
    $148 = tempRet0;
    ___cxa_call_unexpected(($147|0));
    // unreachable;
   }
  } while(0);
  __ZdlPv($128);
  STACKTOP = sp;return;
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 96)&-1;
 $17 = ($16|0)==($sz|0);
 if ($17) {
  $94 = (($sz) - ($10))|0;
  __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE8__appendEj($v,$94);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $18 = (($temp) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($temp) + 8|0);
 HEAP32[$19>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2717,($temp|0),($sz|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L47: do {
  if (!($21)) {
   $22 = HEAP32[$v>>2]|0;
   HEAP32[$2>>2] = $22;
   $23 = HEAP32[$4>>2]|0;
   HEAP32[$3>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viii(1741,($temp|0),($$byval_copy5|0),($$byval_copy8|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$18>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = (($30|0) / 96)&-1;
    $32 = ($31>>>0)<($sz>>>0);
    L50: do {
     if ($32) {
      $33 = (($sz) - ($31))|0;
      __THREW__ = 0;
      invoke_vii(2718,($temp|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L47;
      }
      $$pre = HEAP32[$18>>2]|0;
      $55 = $$pre;
     } else {
      $36 = ($31>>>0)>($sz>>>0);
      if ($36) {
       $37 = (($27) + (($sz*96)|0)|0);
       $38 = ($26|0)==($37|0);
       if ($38) {
        $55 = $26;
       } else {
        $40 = $26;
        while(1) {
         $39 = (($40) + -96|0);
         HEAP32[$18>>2] = $39;
         $41 = HEAP8[$39>>0]|0;
         $42 = $41 & 1;
         $43 = ($42<<24>>24)==(0);
         if ($43) {
          $45 = $39;
         } else {
          $46 = (($40) + -88|0);
          $47 = HEAP32[$46>>2]|0;
          HEAP32[$0>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($47|0),($$byval_copy8|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          $$pre$i$i$i5 = HEAP32[$18>>2]|0;
          $45 = $$pre$i$i$i5;
         }
         $44 = ($45|0)==($37|0);
         if ($44) {
          $55 = $37;
          break L50;
         } else {
          $40 = $45;
         }
        }
        $50 = ___cxa_find_matching_catch()|0;
        $51 = tempRet0;
        ___cxa_call_unexpected(($50|0));
        // unreachable;
       }
      } else {
       $55 = $26;
      }
     }
    } while(0);
    $52 = HEAP32[$temp>>2]|0;
    $53 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $53;
    HEAP32[$v>>2] = $52;
    $54 = HEAP32[$4>>2]|0;
    HEAP32[$18>>2] = $54;
    HEAP32[$4>>2] = $55;
    $56 = HEAP32[$19>>2]|0;
    $57 = HEAP32[$12>>2]|0;
    HEAP32[$19>>2] = $57;
    HEAP32[$12>>2] = $56;
    $58 = ($53|0)==(0|0);
    if ($58) {
     STACKTOP = sp;return;
    }
    $59 = ($54|0)==($53|0);
    do {
     if ($59) {
      $73 = $53;
     } else {
      $61 = $54;
      while(1) {
       $60 = (($61) + -96|0);
       HEAP32[$18>>2] = $60;
       $62 = HEAP8[$60>>0]|0;
       $63 = $62 & 1;
       $64 = ($63<<24>>24)==(0);
       if ($64) {
        $66 = $60;
       } else {
        $67 = (($61) + -88|0);
        $68 = HEAP32[$67>>2]|0;
        HEAP32[$$byval_copy5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
        invoke_vii(2591,($68|0),($$byval_copy8|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 23;
         break;
        }
        $$pre$i$i$i$i$i8 = HEAP32[$18>>2]|0;
        $66 = $$pre$i$i$i$i$i8;
       }
       $65 = ($66|0)==($53|0);
       if ($65) {
        label = 24;
        break;
       } else {
        $61 = $66;
       }
      }
      if ((label|0) == 23) {
       $71 = ___cxa_find_matching_catch()|0;
       $72 = tempRet0;
       ___cxa_call_unexpected(($71|0));
       // unreachable;
      }
      else if ((label|0) == 24) {
       $$pre$i$i$i10 = HEAP32[$temp>>2]|0;
       $73 = $$pre$i$i$i10;
       break;
      }
     }
    } while(0);
    __ZdlPv($73);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $74 = ___cxa_find_matching_catch()|0;
 $75 = tempRet0;
 $76 = HEAP32[$temp>>2]|0;
 $77 = ($76|0)==(0|0);
 if ($77) {
  ___resumeException($74|0);
  // unreachable;
 }
 $78 = HEAP32[$18>>2]|0;
 $79 = ($78|0)==($76|0);
 do {
  if ($79) {
   $93 = $76;
  } else {
   $81 = $78;
   while(1) {
    $80 = (($81) + -96|0);
    HEAP32[$18>>2] = $80;
    $82 = HEAP8[$80>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if ($84) {
     $86 = $80;
    } else {
     $87 = (($81) + -88|0);
     $88 = HEAP32[$87>>2]|0;
     HEAP32[$$byval_copy5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
     invoke_vii(2591,($88|0),($$byval_copy8|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 33;
      break;
     }
     $$pre$i$i$i$i$i16 = HEAP32[$18>>2]|0;
     $86 = $$pre$i$i$i$i$i16;
    }
    $85 = ($86|0)==($76|0);
    if ($85) {
     label = 34;
     break;
    } else {
     $81 = $86;
    }
   }
   if ((label|0) == 33) {
    $91 = ___cxa_find_matching_catch()|0;
    $92 = tempRet0;
    ___cxa_call_unexpected(($91|0));
    // unreachable;
   }
   else if ((label|0) == 34) {
    $$pre$i$i$i18 = HEAP32[$temp>>2]|0;
    $93 = $$pre$i$i$i18;
    break;
   }
  }
 } while(0);
 __ZdlPv($93);
 ___resumeException($74|0);
 // unreachable;
}
function __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 96)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 96)&-1;
 $15 = (($__v) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($__v) + 16|0);
 HEAP32[$16>>2] = $9;
 $17 = ($__n|0)==(0);
 if ($17) {
  $20 = 0;
 } else {
  $18 = ($__n*96)|0;
  $19 = (__Znwj($18)|0);
  $20 = $19;
 }
 HEAP32[$__v>>2] = $20;
 $21 = (($20) + (($14*96)|0)|0);
 $22 = (($__v) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($__v) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = (($20) + (($__n*96)|0)|0);
 HEAP32[$15>>2] = $24;
 __THREW__ = 0;
 invoke_vii(2716,($this|0),($__v|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $46 = HEAP32[$23>>2]|0;
  $47 = HEAP32[$22>>2]|0;
  $48 = ($47|0)==($46|0);
  L23: do {
   if (!($48)) {
    $50 = $47;
    while(1) {
     $49 = (($50) + -96|0);
     HEAP32[$22>>2] = $49;
     $51 = HEAP8[$49>>0]|0;
     $52 = $51 & 1;
     $53 = ($52<<24>>24)==(0);
     if (!($53)) {
      $55 = (($50) + -88|0);
      $56 = HEAP32[$55>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($56|0),($$byval_copy1|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
     }
     $54 = ($49|0)==($46|0);
     if ($54) {
      break L23;
     } else {
      $50 = $49;
     }
    }
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    ___cxa_call_unexpected(($59|0));
    // unreachable;
   }
  } while(0);
  $61 = HEAP32[$__v>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   ___resumeException($44|0);
   // unreachable;
  }
  __ZdlPv($61);
  ___resumeException($44|0);
  // unreachable;
 } else {
  $27 = HEAP32[$23>>2]|0;
  $28 = HEAP32[$22>>2]|0;
  $29 = ($28|0)==($27|0);
  L9: do {
   if (!($29)) {
    $31 = $28;
    while(1) {
     $30 = (($31) + -96|0);
     HEAP32[$22>>2] = $30;
     $32 = HEAP8[$30>>0]|0;
     $33 = $32 & 1;
     $34 = ($33<<24>>24)==(0);
     if (!($34)) {
      $36 = (($31) + -88|0);
      $37 = HEAP32[$36>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($37|0),($$byval_copy1|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
     }
     $35 = ($30|0)==($27|0);
     if ($35) {
      break L9;
     } else {
      $31 = $30;
     }
    }
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
  } while(0);
  $42 = HEAP32[$__v>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   STACKTOP = sp;return;
  }
  __ZdlPv($42);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i10 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 24|0;
 $$byval_copy4 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = HEAP32[$__first>>2]|0;
 $6 = HEAP32[$__last>>2]|0;
 $7 = $6;
 $8 = $5;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 96)&-1;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$this>>2]|0;
 $14 = $12;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 96)&-1;
 $18 = ($10>>>0)>($17>>>0);
 if ($18) {
  $52 = ($13|0)==(0|0);
  if ($52) {
   $72 = $12;
  } else {
   $53 = (($this) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==($13|0);
   do {
    if ($55) {
     $69 = $13;
    } else {
     $57 = $54;
     while(1) {
      $56 = (($57) + -96|0);
      HEAP32[$53>>2] = $56;
      $58 = HEAP8[$56>>0]|0;
      $59 = $58 & 1;
      $60 = ($59<<24>>24)==(0);
      if ($60) {
       $62 = $56;
      } else {
       $63 = (($57) + -88|0);
       $64 = HEAP32[$63>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($64|0),($$byval_copy5|0));
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$53>>2]|0;
       $62 = $$pre$i$i$i$i;
      }
      $61 = ($62|0)==($13|0);
      if ($61) {
       label = 25;
       break;
      } else {
       $57 = $62;
      }
     }
     if ((label|0) == 24) {
      $67 = ___cxa_find_matching_catch()|0;
      $68 = tempRet0;
      ___cxa_call_unexpected(($67|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $69 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($69);
   HEAP32[$11>>2] = 0;
   HEAP32[$53>>2] = 0;
   HEAP32[$this>>2] = 0;
   $72 = 0;
  }
  $70 = ($10>>>0)>(44739242);
  if ($70) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $71 = $72;
  $73 = (($71|0) / 96)&-1;
  $74 = ($73>>>0)<(22369621);
  if ($74) {
   $75 = $73 << 1;
   $76 = ($75>>>0)<($10>>>0);
   $77 = $76 ? $10 : $75;
   $78 = ($77>>>0)>(44739242);
   if ($78) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i10 = $77;
   }
  } else {
   $$0$i10 = 44739242;
  }
  $79 = ($$0$i10*96)|0;
  $80 = (__Znwj($79)|0);
  $81 = (($this) + 4|0);
  HEAP32[$81>>2] = $80;
  HEAP32[$this>>2] = $80;
  $82 = (($80) + (($$0$i10*96)|0)|0);
  HEAP32[$11>>2] = $82;
  HEAP32[$3>>2] = $5;
  HEAP32[$4>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
  __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE18__construct_at_endINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_($this,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 $22 = (($21) - ($15))|0;
 $23 = (($22|0) / 96)&-1;
 $24 = ($10>>>0)>($23>>>0);
 if ($24) {
  $25 = (($5) + (($23*96)|0)|0);
  $27 = $25;$__growing$0$off0 = 1;
 } else {
  $27 = $6;$__growing$0$off0 = 0;
 }
 $26 = ($5|0)==($27|0);
 if ($26) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i = (($27) + -96|0);
  $28 = (0 - ($8))|0;
  $uglygep$i = (($scevgep$i) + ($28)|0);
  $uglygep16$i = $uglygep$i;
  $29 = (($uglygep16$i>>>0) / 96)&-1;
  $$01$i$i = $13;$30 = $5;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($$01$i$i,$30)|0);
   $31 = (($$01$i$i) + 12|0);
   $32 = (($30) + 12|0);
   dest=$31+0|0; src=$32+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $33 = (($30) + 96|0);
   $34 = (($$01$i$i) + 96|0);
   $35 = ($33|0)==($27|0);
   if ($35) {
    break;
   } else {
    $$01$i$i = $34;$30 = $33;
   }
  }
  $36 = (($29) + 1)|0;
  $scevgep17$i = (($13) + (($36*96)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  HEAP32[$1>>2] = $27;
  HEAP32[$2>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE18__construct_at_endINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_($this,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$19>>2]|0;
 $38 = ($37|0)==($$0$lcssa$i$i|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $40 = $37;
 while(1) {
  $39 = (($40) + -96|0);
  HEAP32[$19>>2] = $39;
  $41 = HEAP8[$39>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   $45 = $39;
  } else {
   $46 = (($40) + -88|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$$byval_copy4>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy4+0>>2]|0;
   invoke_vii(2591,($47|0),($$byval_copy5|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    label = 16;
    break;
   }
   $$pre$i$i = HEAP32[$19>>2]|0;
   $45 = $$pre$i$i;
  }
  $44 = ($45|0)==($$0$lcssa$i$i|0);
  if ($44) {
   label = 33;
   break;
  } else {
   $40 = $45;
  }
 }
 if ((label|0) == 16) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  ___cxa_call_unexpected(($50|0));
  // unreachable;
 }
 else if ((label|0) == 33) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE18__construct_at_endINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$byval_copy = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 while(1) {
  $5 = ($6|0)==(0|0);
  if ($5) {
   $35 = 0;$37 = $8;
  } else {
   $7 = HEAP8[$8>>0]|0;
   $9 = $7 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $15 = (($8) + 1|0);
    $16 = $7&255;
    $17 = $16 >>> 1;
    $19 = $17;$30 = $15;
   } else {
    $11 = (($8) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($8) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $19 = $14;$30 = $12;
   }
   $18 = ($19>>>0)>(2147483631);
   if ($18) {
    label = 8;
    break;
   }
   $20 = ($19>>>0)<(11);
   if ($20) {
    $21 = $19 << 1;
    $22 = $21&255;
    HEAP8[$6>>0] = $22;
    $23 = (($6) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $23;
   } else {
    $24 = (($19) + 16)|0;
    $25 = $24 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy,0,604264,79)|0);
    $27 = (($6) + 8|0);
    HEAP32[$27>>2] = $26;
    $28 = $25 | 1;
    HEAP32[$6>>2] = $28;
    $29 = (($6) + 4|0);
    HEAP32[$29>>2] = $19;
    $__p$0$i$i$i$i$i$i$i = $26;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($30|0),($19|0))|0;
   $31 = (($__p$0$i$i$i$i$i$i$i) + ($19)|0);
   HEAP8[$31>>0] = 0;
   $32 = (($6) + 12|0);
   $33 = (($8) + 12|0);
   dest=$32+0|0; src=$33+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre1 = HEAP32[$4>>2]|0;
   $$pre2 = HEAP32[$__first>>2]|0;
   $35 = $$pre1;$37 = $$pre2;
  }
  $34 = (($35) + 96|0);
  HEAP32[$4>>2] = $34;
  $36 = (($37) + 96|0);
  HEAP32[$__first>>2] = $36;
  $38 = ($36|0)==($2|0);
  if ($38) {
   label = 14;
   break;
  } else {
   $6 = $34;$8 = $36;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i712 = 0, $$0$i713 = 0, $$0$i9 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$pre1$i10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 96)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $33 = 0;
   } else {
    HEAP8[$11>>0] = 14;
    $12 = (($11) + 1|0);
    ;HEAP8[$12+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$12+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$12+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$12+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$12+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$12+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$12+6>>0]=HEAP8[604208+6>>0]|0;
    $13 = (($11) + 8|0);
    HEAP8[$13>>0] = 0;
    $14 = (($11) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = (($11) + 16|0);
    HEAP32[$15>>2] = 0;
    $16 = (($11) + 20|0);
    HEAP32[$16>>2] = 0;
    $17 = (($11) + 24|0);
    HEAP32[$17>>2] = 1;
    $18 = (($11) + 28|0);
    HEAP32[$18>>2] = 1;
    $19 = (($11) + 32|0);
    HEAP32[$19>>2] = 1;
    $20 = (($11) + 36|0);
    HEAPF32[$20>>2] = Math_fround(15.0);
    $21 = (($11) + 40|0);
    HEAPF32[$21>>2] = Math_fround(0.333333343267440795898);
    $22 = (($11) + 44|0);
    HEAPF32[$22>>2] = Math_fround(0.0666666701436042785645);
    $23 = (($11) + 48|0);
    HEAPF32[$23>>2] = Math_fround(0.20000000298023223877);
    $24 = (($11) + 52|0);
    HEAPF32[$24>>2] = Math_fround(0.46666666865348815918);
    $25 = (($11) + 56|0);
    HEAP32[$25>>2] = 1;
    $26 = (($11) + 60|0);
    HEAP32[$26>>2] = 1;
    $27 = (($11) + 64|0);
    $28 = (($11) + 80|0);
    ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;
    HEAPF32[$28>>2] = Math_fround(0.300000011920928955078);
    $29 = (($11) + 84|0);
    HEAP32[$29>>2] = 0;
    $30 = (($11) + 88|0);
    HEAP32[$30>>2] = 4;
    $31 = (($11) + 92|0);
    HEAPF32[$31>>2] = Math_fround(512.0);
    $$pre1$i = HEAP32[$3>>2]|0;
    $33 = $$pre1$i;
   }
   $32 = (($33) + 96|0);
   HEAP32[$3>>2] = $32;
   $34 = (($$0$i) + -1)|0;
   $35 = ($34|0)==(0);
   if ($35) {
    break;
   } else {
    $$0$i = $34;$11 = $32;
   }
  }
  STACKTOP = sp;return;
 }
 $36 = (($this) + 8|0);
 $37 = HEAP32[$this>>2]|0;
 $38 = $37;
 $39 = (($6) - ($38))|0;
 $40 = (($39|0) / 96)&-1;
 $41 = (($40) + ($__n))|0;
 $42 = ($41>>>0)>(44739242);
 if ($42) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $43 = (($5) - ($38))|0;
 $44 = (($43|0) / 96)&-1;
 $45 = ($44>>>0)<(22369621);
 if ($45) {
  $48 = $44 << 1;
  $49 = ($48>>>0)<($41>>>0);
  $50 = $49 ? $41 : $48;
  $51 = (($__v) + 12|0);
  HEAP32[$51>>2] = 0;
  $52 = (($__v) + 16|0);
  HEAP32[$52>>2] = $36;
  $53 = ($50|0)==(0);
  if ($53) {
   $$0$i713 = 0;$56 = 0;$61 = $51;
  } else {
   $$0$i712 = $50;$126 = $51;
   label = 10;
  }
 } else {
  $46 = (($__v) + 12|0);
  HEAP32[$46>>2] = 0;
  $47 = (($__v) + 16|0);
  HEAP32[$47>>2] = $36;
  $$0$i712 = 44739242;$126 = $46;
  label = 10;
 }
 if ((label|0) == 10) {
  $54 = ($$0$i712*96)|0;
  $55 = (__Znwj($54)|0);
  $$0$i713 = $$0$i712;$56 = $55;$61 = $126;
 }
 HEAP32[$__v>>2] = $56;
 $57 = (($56) + (($40*96)|0)|0);
 $58 = (($__v) + 8|0);
 HEAP32[$58>>2] = $57;
 $59 = (($__v) + 4|0);
 HEAP32[$59>>2] = $57;
 $60 = (($56) + (($$0$i713*96)|0)|0);
 HEAP32[$61>>2] = $60;
 $$0$i9 = $__n;$63 = $57;
 while(1) {
  $62 = ($63|0)==(0|0);
  if ($62) {
   $85 = 0;
  } else {
   HEAP8[$63>>0] = 14;
   $64 = (($63) + 1|0);
   ;HEAP8[$64+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$64+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$64+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$64+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$64+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$64+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$64+6>>0]=HEAP8[604208+6>>0]|0;
   $65 = (($63) + 8|0);
   HEAP8[$65>>0] = 0;
   $66 = (($63) + 12|0);
   HEAP32[$66>>2] = 0;
   $67 = (($63) + 16|0);
   HEAP32[$67>>2] = 0;
   $68 = (($63) + 20|0);
   HEAP32[$68>>2] = 0;
   $69 = (($63) + 24|0);
   HEAP32[$69>>2] = 1;
   $70 = (($63) + 28|0);
   HEAP32[$70>>2] = 1;
   $71 = (($63) + 32|0);
   HEAP32[$71>>2] = 1;
   $72 = (($63) + 36|0);
   HEAPF32[$72>>2] = Math_fround(15.0);
   $73 = (($63) + 40|0);
   HEAPF32[$73>>2] = Math_fround(0.333333343267440795898);
   $74 = (($63) + 44|0);
   HEAPF32[$74>>2] = Math_fround(0.0666666701436042785645);
   $75 = (($63) + 48|0);
   HEAPF32[$75>>2] = Math_fround(0.20000000298023223877);
   $76 = (($63) + 52|0);
   HEAPF32[$76>>2] = Math_fround(0.46666666865348815918);
   $77 = (($63) + 56|0);
   HEAP32[$77>>2] = 1;
   $78 = (($63) + 60|0);
   HEAP32[$78>>2] = 1;
   $79 = (($63) + 64|0);
   $80 = (($63) + 80|0);
   ;HEAP32[$79+0>>2]=0|0;HEAP32[$79+4>>2]=0|0;HEAP32[$79+8>>2]=0|0;HEAP32[$79+12>>2]=0|0;
   HEAPF32[$80>>2] = Math_fround(0.300000011920928955078);
   $81 = (($63) + 84|0);
   HEAP32[$81>>2] = 0;
   $82 = (($63) + 88|0);
   HEAP32[$82>>2] = 4;
   $83 = (($63) + 92|0);
   HEAPF32[$83>>2] = Math_fround(512.0);
   $$pre1$i10 = HEAP32[$58>>2]|0;
   $85 = $$pre1$i10;
  }
  $84 = (($85) + 96|0);
  HEAP32[$58>>2] = $84;
  $86 = (($$0$i9) + -1)|0;
  $87 = ($86|0)==(0);
  if ($87) {
   break;
  } else {
   $$0$i9 = $86;$63 = $84;
  }
 }
 __THREW__ = 0;
 invoke_vii(2716,($this|0),($__v|0));
 $88 = __THREW__; __THREW__ = 0;
 $89 = $88&1;
 if ($89) {
  $107 = ___cxa_find_matching_catch()|0;
  $108 = tempRet0;
  $109 = HEAP32[$59>>2]|0;
  $110 = HEAP32[$58>>2]|0;
  $111 = ($110|0)==($109|0);
  L40: do {
   if (!($111)) {
    $113 = $110;
    while(1) {
     $112 = (($113) + -96|0);
     HEAP32[$58>>2] = $112;
     $114 = HEAP8[$112>>0]|0;
     $115 = $114 & 1;
     $116 = ($115<<24>>24)==(0);
     if (!($116)) {
      $118 = (($113) + -88|0);
      $119 = HEAP32[$118>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($119|0),($$byval_copy1|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       break;
      }
     }
     $117 = ($112|0)==($109|0);
     if ($117) {
      break L40;
     } else {
      $113 = $112;
     }
    }
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    ___cxa_call_unexpected(($122|0));
    // unreachable;
   }
  } while(0);
  $124 = HEAP32[$__v>>2]|0;
  $125 = ($124|0)==(0|0);
  if ($125) {
   ___resumeException($107|0);
   // unreachable;
  }
  __ZdlPv($124);
  ___resumeException($107|0);
  // unreachable;
 } else {
  $90 = HEAP32[$59>>2]|0;
  $91 = HEAP32[$58>>2]|0;
  $92 = ($91|0)==($90|0);
  L26: do {
   if (!($92)) {
    $94 = $91;
    while(1) {
     $93 = (($94) + -96|0);
     HEAP32[$58>>2] = $93;
     $95 = HEAP8[$93>>0]|0;
     $96 = $95 & 1;
     $97 = ($96<<24>>24)==(0);
     if (!($97)) {
      $99 = (($94) + -88|0);
      $100 = HEAP32[$99>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($100|0),($$byval_copy1|0));
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       break;
      }
     }
     $98 = ($93|0)==($90|0);
     if ($98) {
      break L26;
     } else {
      $94 = $93;
     }
    }
    $103 = ___cxa_find_matching_catch()|0;
    $104 = tempRet0;
    ___cxa_call_unexpected(($103|0));
    // unreachable;
   }
  } while(0);
  $105 = HEAP32[$__v>>2]|0;
  $106 = ($105|0)==(0|0);
  if ($106) {
   STACKTOP = sp;return;
  }
  __ZdlPv($105);
  STACKTOP = sp;return;
 }
}
function __ZN15QualitySettings14QualitySetting8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre3$i$i$i = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0;
 var $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre4$i$i$i = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre5$i$i$i = 0, $$pre50 = 0, $$pre51 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre18;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 16|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $16 = $$pre19;$18 = $$pre20;
 } else {
  $13 = HEAP32[$10>>2]|0;
  HEAP32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 20|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $22 = $$pre21;$24 = $$pre22;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 }
 $20 = (($this) + 24|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre23 = HEAP32[$1>>2]|0;
  $$pre24 = HEAP32[$4>>2]|0;
  $28 = $$pre23;$30 = $$pre24;
 } else {
  $25 = HEAP32[$22>>2]|0;
  HEAP32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 }
 $26 = (($this) + 28|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre25 = HEAP32[$1>>2]|0;
  $$pre26 = HEAP32[$4>>2]|0;
  $34 = $$pre25;$36 = $$pre26;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 }
 $32 = (($this) + 32|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$32,4);
  $$pre27 = HEAP32[$1>>2]|0;
  $$pre28 = HEAP32[$4>>2]|0;
  $40 = $$pre27;$42 = $$pre28;
 } else {
  $37 = HEAP32[$34>>2]|0;
  HEAP32[$32>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 }
 $38 = (($this) + 36|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)>($42>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
  $$pre29 = HEAP32[$1>>2]|0;
  $$pre30 = HEAP32[$4>>2]|0;
  $46 = $$pre29;$48 = $$pre30;
 } else {
  $43 = Math_fround(HEAPF32[$40>>2]);
  HEAPF32[$38>>2] = $43;
  HEAP32[$1>>2] = $39;
  $46 = $39;$48 = $42;
 }
 $44 = (($this) + 40|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)>($48>>>0);
 if ($47) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$44,4);
  $$pre31 = HEAP32[$1>>2]|0;
  $$pre32 = HEAP32[$4>>2]|0;
  $52 = $$pre31;$54 = $$pre32;
 } else {
  $49 = Math_fround(HEAPF32[$46>>2]);
  HEAPF32[$44>>2] = $49;
  HEAP32[$1>>2] = $45;
  $52 = $45;$54 = $48;
 }
 $50 = (($this) + 44|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)>($54>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$50,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre3$i$i$i = HEAP32[$4>>2]|0;
  $58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
 } else {
  $55 = Math_fround(HEAPF32[$52>>2]);
  HEAPF32[$50>>2] = $55;
  HEAP32[$1>>2] = $51;
  $58 = $51;$60 = $54;
 }
 $56 = (($this) + 48|0);
 $57 = (($58) + 4|0);
 $59 = ($57>>>0)>($60>>>0);
 if ($59) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$56,4);
  $$pre4$i$i$i = HEAP32[$1>>2]|0;
  $$pre5$i$i$i = HEAP32[$4>>2]|0;
  $64 = $$pre4$i$i$i;$66 = $$pre5$i$i$i;
 } else {
  $61 = Math_fround(HEAPF32[$58>>2]);
  HEAPF32[$56>>2] = $61;
  HEAP32[$1>>2] = $57;
  $64 = $57;$66 = $60;
 }
 $62 = (($this) + 52|0);
 $63 = (($64) + 4|0);
 $65 = ($63>>>0)>($66>>>0);
 if ($65) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$62,4);
  $$pre33 = HEAP32[$1>>2]|0;
  $$pre34 = HEAP32[$4>>2]|0;
  $70 = $$pre33;$72 = $$pre34;
 } else {
  $67 = Math_fround(HEAPF32[$64>>2]);
  HEAPF32[$62>>2] = $67;
  HEAP32[$1>>2] = $63;
  $70 = $63;$72 = $66;
 }
 $68 = (($this) + 56|0);
 $69 = (($70) + 4|0);
 $71 = ($69>>>0)>($72>>>0);
 if ($71) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$68,4);
  $$pre35 = HEAP32[$1>>2]|0;
  $$pre36 = HEAP32[$4>>2]|0;
  $76 = $$pre35;$78 = $$pre36;
 } else {
  $73 = HEAP32[$70>>2]|0;
  HEAP32[$68>>2] = $73;
  HEAP32[$1>>2] = $69;
  $76 = $69;$78 = $72;
 }
 $74 = (($this) + 60|0);
 $75 = (($76) + 4|0);
 $77 = ($75>>>0)>($78>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$74,4);
  $$pre37 = HEAP32[$1>>2]|0;
  $$pre38 = HEAP32[$4>>2]|0;
  $82 = $$pre37;$84 = $$pre38;
 } else {
  $79 = HEAP32[$76>>2]|0;
  HEAP32[$74>>2] = $79;
  HEAP32[$1>>2] = $75;
  $82 = $75;$84 = $78;
 }
 $80 = (($this) + 64|0);
 $81 = (($82) + 4|0);
 $83 = ($81>>>0)>($84>>>0);
 if ($83) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$80,4);
  $$pre39 = HEAP32[$1>>2]|0;
  $$pre40 = HEAP32[$4>>2]|0;
  $88 = $$pre39;$90 = $$pre40;
 } else {
  $85 = HEAP32[$82>>2]|0;
  HEAP32[$80>>2] = $85;
  HEAP32[$1>>2] = $81;
  $88 = $81;$90 = $84;
 }
 $86 = (($this) + 68|0);
 $87 = (($88) + 4|0);
 $89 = ($87>>>0)>($90>>>0);
 if ($89) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$86,4);
  $$pre41 = HEAP32[$1>>2]|0;
  $$pre42 = HEAP32[$4>>2]|0;
  $94 = $$pre41;$96 = $$pre42;
 } else {
  $91 = HEAP32[$88>>2]|0;
  HEAP32[$86>>2] = $91;
  HEAP32[$1>>2] = $87;
  $94 = $87;$96 = $90;
 }
 $92 = (($this) + 76|0);
 $93 = (($94) + 1|0);
 $95 = ($93>>>0)>($96>>>0);
 if ($95) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$92,1);
  $$pre43 = HEAP32[$1>>2]|0;
  $102 = $$pre43;
 } else {
  $97 = HEAP8[$94>>0]|0;
  HEAP8[$92>>0] = $97;
  $98 = HEAP32[$1>>2]|0;
  $99 = (($98) + 1|0);
  HEAP32[$1>>2] = $99;
  $102 = $99;
 }
 $100 = (($this) + 77|0);
 $101 = (($102) + 1|0);
 $103 = HEAP32[$4>>2]|0;
 $104 = ($101>>>0)>($103>>>0);
 if ($104) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$100,1);
  $$pre44 = HEAP32[$1>>2]|0;
  $110 = $$pre44;
 } else {
  $105 = HEAP8[$102>>0]|0;
  HEAP8[$100>>0] = $105;
  $106 = HEAP32[$1>>2]|0;
  $107 = (($106) + 1|0);
  HEAP32[$1>>2] = $107;
  $110 = $107;
 }
 $108 = (($this) + 78|0);
 $109 = (($110) + 1|0);
 $111 = HEAP32[$4>>2]|0;
 $112 = ($109>>>0)>($111>>>0);
 if ($112) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$108,1);
  $$pre45 = HEAP32[$1>>2]|0;
  $118 = $$pre45;
 } else {
  $113 = HEAP8[$110>>0]|0;
  HEAP8[$108>>0] = $113;
  $114 = HEAP32[$1>>2]|0;
  $115 = (($114) + 1|0);
  HEAP32[$1>>2] = $115;
  $118 = $115;
 }
 $116 = (($this) + 79|0);
 $117 = (($118) + 1|0);
 $119 = HEAP32[$4>>2]|0;
 $120 = ($117>>>0)>($119>>>0);
 if ($120) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$116,1);
 } else {
  $121 = HEAP8[$118>>0]|0;
  HEAP8[$116>>0] = $121;
  $122 = HEAP32[$1>>2]|0;
  $123 = (($122) + 1|0);
  HEAP32[$1>>2] = $123;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $124 = (($this) + 72|0);
 $125 = HEAP32[$1>>2]|0;
 $126 = (($125) + 4|0);
 $127 = HEAP32[$4>>2]|0;
 $128 = ($126>>>0)>($127>>>0);
 if ($128) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$124,4);
  $$pre46 = HEAP32[$1>>2]|0;
  $$pre47 = HEAP32[$4>>2]|0;
  $132 = $$pre46;$134 = $$pre47;
 } else {
  $129 = HEAP32[$125>>2]|0;
  HEAP32[$124>>2] = $129;
  HEAP32[$1>>2] = $126;
  $132 = $126;$134 = $127;
 }
 $130 = (($this) + 80|0);
 $131 = (($132) + 4|0);
 $133 = ($131>>>0)>($134>>>0);
 if ($133) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$130,4);
  $$pre48 = HEAP32[$1>>2]|0;
  $$pre49 = HEAP32[$4>>2]|0;
  $138 = $$pre48;$140 = $$pre49;
 } else {
  $135 = Math_fround(HEAPF32[$132>>2]);
  HEAPF32[$130>>2] = $135;
  HEAP32[$1>>2] = $131;
  $138 = $131;$140 = $134;
 }
 $136 = (($this) + 84|0);
 $137 = (($138) + 4|0);
 $139 = ($137>>>0)>($140>>>0);
 if ($139) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$136,4);
  $$pre50 = HEAP32[$1>>2]|0;
  $$pre51 = HEAP32[$4>>2]|0;
  $144 = $$pre50;$146 = $$pre51;
 } else {
  $141 = HEAP32[$138>>2]|0;
  HEAP32[$136>>2] = $141;
  HEAP32[$1>>2] = $137;
  $144 = $137;$146 = $140;
 }
 $142 = (($this) + 88|0);
 $143 = (($144) + 4|0);
 $145 = ($143>>>0)>($146>>>0);
 if ($145) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$142,4);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $147 = HEAP32[$144>>2]|0;
  HEAP32[$142>>2] = $147;
  HEAP32[$1>>2] = $143;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN15QualitySettings14QualitySettingENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIN15QualitySettings14QualitySettingENS0_9allocatorIS3_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN15QualitySettings14QualitySetting8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 96|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*96)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15QualitySettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$byval_copy13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $converter$i$i38 = 0, $converter$i$i42 = 0, $converter$i$i48 = 0, $converter$i$i54 = 0, $converter$i$i60 = 0, $converter$i$i66 = 0, $m_DefaultMobileQuality = 0, $m_DefaultStandaloneQuality = 0, $m_DefaultWebPlayerQuality = 0, $tempQuality = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 752|0;
 $$byval_copy13 = sp + 740|0;
 $0 = sp + 736|0;
 $converter$i$i66 = sp + 732|0;
 $converter$i$i60 = sp + 728|0;
 $converter$i$i54 = sp + 724|0;
 $converter$i$i48 = sp + 720|0;
 $converter$i$i42 = sp + 716|0;
 $converter$i$i38 = sp + 712|0;
 $1 = sp + 708|0;
 $2 = sp + 704|0;
 $3 = sp + 700|0;
 $4 = sp + 696|0;
 $5 = sp + 692|0;
 $6 = sp + 688|0;
 $7 = sp + 684|0;
 $8 = sp + 680|0;
 $9 = sp + 20|0;
 $10 = sp;
 $11 = sp + 4|0;
 $12 = sp + 8|0;
 $m_DefaultStandaloneQuality = sp + 12|0;
 $m_DefaultWebPlayerQuality = sp + 16|0;
 $m_DefaultMobileQuality = sp + 24|0;
 $13 = sp + 28|0;
 $14 = sp + 40|0;
 $15 = sp + 52|0;
 $16 = sp + 64|0;
 $17 = sp + 76|0;
 $18 = sp + 88|0;
 $tempQuality = sp + 104|0;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,5);
 $19 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$19,604272,0);
 $20 = (($this) + 24|0);
 $21 = HEAP32[580760>>2]|0;
 $22 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604296,$21,$$byval_copy13,1)|0);
 $23 = ($22|0)==(0);
 if (!($23)) {
  $24 = ($22|0)>(0);
  if ($24) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN15QualitySettings14QualitySettingENS1_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$20,0);
  } else {
   $25 = HEAP32[$$byval_copy13>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    (FUNCTION_TABLE_iii[$25 & 4095]($20,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $27 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,4)|0);
 do {
  if ($27) {
   HEAP32[$m_DefaultStandaloneQuality>>2] = 3;
   HEAP32[$m_DefaultWebPlayerQuality>>2] = 3;
   HEAP32[$m_DefaultMobileQuality>>2] = 2;
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$m_DefaultStandaloneQuality,604320,0);
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$m_DefaultWebPlayerQuality,604352,0);
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$m_DefaultMobileQuality,604384,0);
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$19,604408,0);
   $28 = HEAP32[$m_DefaultStandaloneQuality>>2]|0;
   HEAP32[$19>>2] = $28;
   $29 = (($this) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$20>>2]|0;
   $32 = $30;
   $33 = $31;
   $34 = (($32) - ($33))|0;
   $35 = ($34|0)==(576);
   if ($35) {
    HEAP8[$13>>0] = 14;
    $36 = (($13) + 1|0);
    ;HEAP8[$36+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$36+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$36+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$36+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$36+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$36+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$36+6>>0]=HEAP8[604208+6>>0]|0;
    $37 = (($13) + 8|0);
    HEAP8[$37>>0] = 0;
    __THREW__ = 0;
    (invoke_iii(2359,($31|0),($13|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     $123 = ___cxa_find_matching_catch()|0;
     $124 = tempRet0;
     $125 = HEAP8[$13>>0]|0;
     $126 = $125 & 1;
     $127 = ($126<<24>>24)==(0);
     if ($127) {
      $$0 = $124;$$01 = $123;
      ___resumeException($$01|0);
      // unreachable;
     }
     $128 = HEAP32[$37>>2]|0;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($128|0),($$byval_copy13|0));
     $129 = __THREW__; __THREW__ = 0;
     $130 = $129&1;
     if ($130) {
      $131 = ___cxa_find_matching_catch()|0;
      $132 = tempRet0;
      ___cxa_call_unexpected(($131|0));
      // unreachable;
     } else {
      $$0 = $124;$$01 = $123;
      ___resumeException($$01|0);
      // unreachable;
     }
    }
    $40 = HEAP8[$13>>0]|0;
    $41 = $40 & 1;
    $42 = ($41<<24>>24)==(0);
    if (!($42)) {
     $43 = HEAP32[$37>>2]|0;
     HEAP32[$12>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$12+0>>2]|0;
     invoke_vii(2591,($43|0),($$byval_copy13|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      $46 = ___cxa_find_matching_catch()|0;
      $47 = tempRet0;
      ___cxa_call_unexpected(($46|0));
      // unreachable;
     }
    }
    $48 = HEAP32[$20>>2]|0;
    HEAP8[$14>>0] = 8;
    $49 = (($14) + 1|0);
    HEAP8[$49>>0]=1953718598&255;HEAP8[$49+1>>0]=(1953718598>>8)&255;HEAP8[$49+2>>0]=(1953718598>>16)&255;HEAP8[$49+3>>0]=1953718598>>24;
    $50 = (($14) + 5|0);
    HEAP8[$50>>0] = 0;
    $51 = (($48) + 96|0);
    __THREW__ = 0;
    (invoke_iii(2359,($51|0),($14|0))|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $133 = ___cxa_find_matching_catch()|0;
     $134 = tempRet0;
     $135 = HEAP8[$14>>0]|0;
     $136 = $135 & 1;
     $137 = ($136<<24>>24)==(0);
     if ($137) {
      $$0 = $134;$$01 = $133;
      ___resumeException($$01|0);
      // unreachable;
     }
     $138 = (($14) + 8|0);
     $139 = HEAP32[$138>>2]|0;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($139|0),($$byval_copy13|0));
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if ($141) {
      $142 = ___cxa_find_matching_catch()|0;
      $143 = tempRet0;
      ___cxa_call_unexpected(($142|0));
      // unreachable;
     } else {
      $$0 = $134;$$01 = $133;
      ___resumeException($$01|0);
      // unreachable;
     }
    }
    $54 = HEAP8[$14>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if (!($56)) {
     $57 = (($14) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     HEAP32[$11>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$11+0>>2]|0;
     invoke_vii(2591,($58|0),($$byval_copy13|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      $61 = ___cxa_find_matching_catch()|0;
      $62 = tempRet0;
      ___cxa_call_unexpected(($61|0));
      // unreachable;
     }
    }
    $63 = HEAP32[$20>>2]|0;
    HEAP8[$15>>0] = 12;
    $64 = (($15) + 1|0);
    ;HEAP8[$64+0>>0]=HEAP8[604432+0>>0]|0;HEAP8[$64+1>>0]=HEAP8[604432+1>>0]|0;HEAP8[$64+2>>0]=HEAP8[604432+2>>0]|0;HEAP8[$64+3>>0]=HEAP8[604432+3>>0]|0;HEAP8[$64+4>>0]=HEAP8[604432+4>>0]|0;HEAP8[$64+5>>0]=HEAP8[604432+5>>0]|0;
    $65 = (($15) + 7|0);
    HEAP8[$65>>0] = 0;
    $66 = (($63) + 192|0);
    __THREW__ = 0;
    (invoke_iii(2359,($66|0),($15|0))|0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     $144 = ___cxa_find_matching_catch()|0;
     $145 = tempRet0;
     $146 = HEAP8[$15>>0]|0;
     $147 = $146 & 1;
     $148 = ($147<<24>>24)==(0);
     if ($148) {
      $$0 = $145;$$01 = $144;
      ___resumeException($$01|0);
      // unreachable;
     }
     $149 = (($15) + 8|0);
     $150 = HEAP32[$149>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($150|0),($$byval_copy13|0));
     $151 = __THREW__; __THREW__ = 0;
     $152 = $151&1;
     if ($152) {
      $153 = ___cxa_find_matching_catch()|0;
      $154 = tempRet0;
      ___cxa_call_unexpected(($153|0));
      // unreachable;
     } else {
      $$0 = $145;$$01 = $144;
      ___resumeException($$01|0);
      // unreachable;
     }
    }
    $69 = HEAP8[$15>>0]|0;
    $70 = $69 & 1;
    $71 = ($70<<24>>24)==(0);
    if (!($71)) {
     $72 = (($15) + 8|0);
     $73 = HEAP32[$72>>2]|0;
     HEAP32[$10>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$10+0>>2]|0;
     invoke_vii(2591,($73|0),($$byval_copy13|0));
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      $76 = ___cxa_find_matching_catch()|0;
      $77 = tempRet0;
      ___cxa_call_unexpected(($76|0));
      // unreachable;
     }
    }
    $78 = HEAP32[$20>>2]|0;
    HEAP8[$16>>0] = 8;
    $79 = (($16) + 1|0);
    HEAP8[$79>>0]=1685024583&255;HEAP8[$79+1>>0]=(1685024583>>8)&255;HEAP8[$79+2>>0]=(1685024583>>16)&255;HEAP8[$79+3>>0]=1685024583>>24;
    $80 = (($16) + 5|0);
    HEAP8[$80>>0] = 0;
    $81 = (($78) + 288|0);
    __THREW__ = 0;
    (invoke_iii(2359,($81|0),($16|0))|0);
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     $155 = ___cxa_find_matching_catch()|0;
     $156 = tempRet0;
     $157 = HEAP8[$16>>0]|0;
     $158 = $157 & 1;
     $159 = ($158<<24>>24)==(0);
     if ($159) {
      $$0 = $156;$$01 = $155;
      ___resumeException($$01|0);
      // unreachable;
     }
     $160 = (($16) + 8|0);
     $161 = HEAP32[$160>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($161|0),($$byval_copy13|0));
     $162 = __THREW__; __THREW__ = 0;
     $163 = $162&1;
     if ($163) {
      $164 = ___cxa_find_matching_catch()|0;
      $165 = tempRet0;
      ___cxa_call_unexpected(($164|0));
      // unreachable;
     } else {
      $$0 = $156;$$01 = $155;
      ___resumeException($$01|0);
      // unreachable;
     }
    }
    $84 = HEAP8[$16>>0]|0;
    $85 = $84 & 1;
    $86 = ($85<<24>>24)==(0);
    if (!($86)) {
     $87 = (($16) + 8|0);
     $88 = HEAP32[$87>>2]|0;
     HEAP32[$9>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$9+0>>2]|0;
     invoke_vii(2591,($88|0),($$byval_copy13|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      $91 = ___cxa_find_matching_catch()|0;
      $92 = tempRet0;
      ___cxa_call_unexpected(($91|0));
      // unreachable;
     }
    }
    $93 = HEAP32[$20>>2]|0;
    HEAP8[$17>>0] = 18;
    $94 = (($17) + 1|0);
    dest=$94+0|0; src=604448+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $95 = (($17) + 10|0);
    HEAP8[$95>>0] = 0;
    $96 = (($93) + 384|0);
    __THREW__ = 0;
    (invoke_iii(2359,($96|0),($17|0))|0);
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if ($98) {
     $166 = ___cxa_find_matching_catch()|0;
     $167 = tempRet0;
     $168 = HEAP8[$17>>0]|0;
     $169 = $168 & 1;
     $170 = ($169<<24>>24)==(0);
     if ($170) {
      $$0 = $167;$$01 = $166;
      ___resumeException($$01|0);
      // unreachable;
     }
     $171 = (($17) + 8|0);
     $172 = HEAP32[$171>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($172|0),($$byval_copy13|0));
     $173 = __THREW__; __THREW__ = 0;
     $174 = $173&1;
     if ($174) {
      $175 = ___cxa_find_matching_catch()|0;
      $176 = tempRet0;
      ___cxa_call_unexpected(($175|0));
      // unreachable;
     } else {
      $$0 = $167;$$01 = $166;
      ___resumeException($$01|0);
      // unreachable;
     }
    }
    $99 = HEAP8[$17>>0]|0;
    $100 = $99 & 1;
    $101 = ($100<<24>>24)==(0);
    if (!($101)) {
     $102 = (($17) + 8|0);
     $103 = HEAP32[$102>>2]|0;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$8+0>>2]|0;
     invoke_vii(2591,($103|0),($$byval_copy13|0));
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      $106 = ___cxa_find_matching_catch()|0;
      $107 = tempRet0;
      ___cxa_call_unexpected(($106|0));
      // unreachable;
     }
    }
    $108 = HEAP32[$20>>2]|0;
    HEAP8[$18>>0] = 18;
    $109 = (($18) + 1|0);
    dest=$109+0|0; src=604464+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $110 = (($18) + 10|0);
    HEAP8[$110>>0] = 0;
    $111 = (($108) + 480|0);
    __THREW__ = 0;
    (invoke_iii(2359,($111|0),($18|0))|0);
    $112 = __THREW__; __THREW__ = 0;
    $113 = $112&1;
    if (!($113)) {
     $114 = HEAP8[$18>>0]|0;
     $115 = $114 & 1;
     $116 = ($115<<24>>24)==(0);
     if ($116) {
      break;
     }
     $117 = (($18) + 8|0);
     $118 = HEAP32[$117>>2]|0;
     HEAP32[$7>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$7+0>>2]|0;
     invoke_vii(2591,($118|0),($$byval_copy13|0));
     $119 = __THREW__; __THREW__ = 0;
     $120 = $119&1;
     if (!($120)) {
      break;
     }
     $121 = ___cxa_find_matching_catch()|0;
     $122 = tempRet0;
     ___cxa_call_unexpected(($121|0));
     // unreachable;
    }
    $177 = ___cxa_find_matching_catch()|0;
    $178 = tempRet0;
    $179 = HEAP8[$18>>0]|0;
    $180 = $179 & 1;
    $181 = ($180<<24>>24)==(0);
    if ($181) {
     $$0 = $178;$$01 = $177;
     ___resumeException($$01|0);
     // unreachable;
    }
    $182 = (($18) + 8|0);
    $183 = HEAP32[$182>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($183|0),($$byval_copy13|0));
    $184 = __THREW__; __THREW__ = 0;
    $185 = $184&1;
    if ($185) {
     $186 = ___cxa_find_matching_catch()|0;
     $187 = tempRet0;
     ___cxa_call_unexpected(($186|0));
     // unreachable;
    } else {
     $$0 = $178;$$01 = $177;
     ___resumeException($$01|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $188 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,3)|0);
 if (!($188)) {
  $437 = (($this) + 36|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$437,604480,0);
  STACKTOP = sp;return;
 }
 $189 = (($tempQuality) + 576|0);
 HEAP8[$tempQuality>>0] = 14;
 $190 = (($tempQuality) + 1|0);
 ;HEAP8[$190+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$190+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$190+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$190+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$190+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$190+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$190+6>>0]=HEAP8[604208+6>>0]|0;
 $191 = (($tempQuality) + 8|0);
 HEAP8[$191>>0] = 0;
 $192 = (($tempQuality) + 12|0);
 HEAP32[$192>>2] = 0;
 $193 = (($tempQuality) + 16|0);
 HEAP32[$193>>2] = 0;
 $194 = (($tempQuality) + 20|0);
 HEAP32[$194>>2] = 0;
 $195 = (($tempQuality) + 24|0);
 HEAP32[$195>>2] = 1;
 $196 = (($tempQuality) + 28|0);
 HEAP32[$196>>2] = 1;
 $197 = (($tempQuality) + 32|0);
 HEAP32[$197>>2] = 1;
 $198 = (($tempQuality) + 36|0);
 HEAPF32[$198>>2] = Math_fround(15.0);
 $199 = (($tempQuality) + 40|0);
 HEAPF32[$199>>2] = Math_fround(0.333333343267440795898);
 $200 = (($tempQuality) + 44|0);
 HEAPF32[$200>>2] = Math_fround(0.0666666701436042785645);
 $201 = (($tempQuality) + 48|0);
 HEAPF32[$201>>2] = Math_fround(0.20000000298023223877);
 $202 = (($tempQuality) + 52|0);
 HEAPF32[$202>>2] = Math_fround(0.46666666865348815918);
 $203 = (($tempQuality) + 56|0);
 HEAP32[$203>>2] = 1;
 $204 = (($tempQuality) + 60|0);
 HEAP32[$204>>2] = 1;
 $205 = (($tempQuality) + 64|0);
 $206 = (($tempQuality) + 80|0);
 ;HEAP32[$205+0>>2]=0|0;HEAP32[$205+4>>2]=0|0;HEAP32[$205+8>>2]=0|0;HEAP32[$205+12>>2]=0|0;
 HEAPF32[$206>>2] = Math_fround(0.300000011920928955078);
 $207 = (($tempQuality) + 84|0);
 HEAP32[$207>>2] = 0;
 $208 = (($tempQuality) + 88|0);
 HEAP32[$208>>2] = 4;
 $209 = (($tempQuality) + 92|0);
 HEAPF32[$209>>2] = Math_fround(512.0);
 $210 = (($tempQuality) + 96|0);
 HEAP8[$210>>0] = 14;
 $211 = (($210) + 1|0);
 ;HEAP8[$211+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$211+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$211+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$211+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$211+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$211+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$211+6>>0]=HEAP8[604208+6>>0]|0;
 $212 = (($tempQuality) + 104|0);
 HEAP8[$212>>0] = 0;
 $213 = (($tempQuality) + 108|0);
 HEAP32[$213>>2] = 0;
 $214 = (($tempQuality) + 112|0);
 HEAP32[$214>>2] = 0;
 $215 = (($tempQuality) + 116|0);
 HEAP32[$215>>2] = 0;
 $216 = (($tempQuality) + 120|0);
 HEAP32[$216>>2] = 1;
 $217 = (($tempQuality) + 124|0);
 HEAP32[$217>>2] = 1;
 $218 = (($tempQuality) + 128|0);
 HEAP32[$218>>2] = 1;
 $219 = (($tempQuality) + 132|0);
 HEAPF32[$219>>2] = Math_fround(15.0);
 $220 = (($tempQuality) + 136|0);
 HEAPF32[$220>>2] = Math_fround(0.333333343267440795898);
 $221 = (($tempQuality) + 140|0);
 HEAPF32[$221>>2] = Math_fround(0.0666666701436042785645);
 $222 = (($tempQuality) + 144|0);
 HEAPF32[$222>>2] = Math_fround(0.20000000298023223877);
 $223 = (($tempQuality) + 148|0);
 HEAPF32[$223>>2] = Math_fround(0.46666666865348815918);
 $224 = (($tempQuality) + 152|0);
 HEAP32[$224>>2] = 1;
 $225 = (($tempQuality) + 156|0);
 HEAP32[$225>>2] = 1;
 $226 = (($tempQuality) + 160|0);
 $227 = (($tempQuality) + 176|0);
 ;HEAP32[$226+0>>2]=0|0;HEAP32[$226+4>>2]=0|0;HEAP32[$226+8>>2]=0|0;HEAP32[$226+12>>2]=0|0;
 HEAPF32[$227>>2] = Math_fround(0.300000011920928955078);
 $228 = (($tempQuality) + 180|0);
 HEAP32[$228>>2] = 0;
 $229 = (($tempQuality) + 184|0);
 HEAP32[$229>>2] = 4;
 $230 = (($tempQuality) + 188|0);
 HEAPF32[$230>>2] = Math_fround(512.0);
 $231 = (($tempQuality) + 192|0);
 HEAP8[$231>>0] = 14;
 $232 = (($231) + 1|0);
 ;HEAP8[$232+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$232+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$232+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$232+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$232+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$232+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$232+6>>0]=HEAP8[604208+6>>0]|0;
 $233 = (($tempQuality) + 200|0);
 HEAP8[$233>>0] = 0;
 $234 = (($tempQuality) + 204|0);
 HEAP32[$234>>2] = 0;
 $235 = (($tempQuality) + 208|0);
 HEAP32[$235>>2] = 0;
 $236 = (($tempQuality) + 212|0);
 HEAP32[$236>>2] = 0;
 $237 = (($tempQuality) + 216|0);
 HEAP32[$237>>2] = 1;
 $238 = (($tempQuality) + 220|0);
 HEAP32[$238>>2] = 1;
 $239 = (($tempQuality) + 224|0);
 HEAP32[$239>>2] = 1;
 $240 = (($tempQuality) + 228|0);
 HEAPF32[$240>>2] = Math_fround(15.0);
 $241 = (($tempQuality) + 232|0);
 HEAPF32[$241>>2] = Math_fround(0.333333343267440795898);
 $242 = (($tempQuality) + 236|0);
 HEAPF32[$242>>2] = Math_fround(0.0666666701436042785645);
 $243 = (($tempQuality) + 240|0);
 HEAPF32[$243>>2] = Math_fround(0.20000000298023223877);
 $244 = (($tempQuality) + 244|0);
 HEAPF32[$244>>2] = Math_fround(0.46666666865348815918);
 $245 = (($tempQuality) + 248|0);
 HEAP32[$245>>2] = 1;
 $246 = (($tempQuality) + 252|0);
 HEAP32[$246>>2] = 1;
 $247 = (($tempQuality) + 256|0);
 $248 = (($tempQuality) + 272|0);
 ;HEAP32[$247+0>>2]=0|0;HEAP32[$247+4>>2]=0|0;HEAP32[$247+8>>2]=0|0;HEAP32[$247+12>>2]=0|0;
 HEAPF32[$248>>2] = Math_fround(0.300000011920928955078);
 $249 = (($tempQuality) + 276|0);
 HEAP32[$249>>2] = 0;
 $250 = (($tempQuality) + 280|0);
 HEAP32[$250>>2] = 4;
 $251 = (($tempQuality) + 284|0);
 HEAPF32[$251>>2] = Math_fround(512.0);
 $252 = (($tempQuality) + 288|0);
 HEAP8[$252>>0] = 14;
 $253 = (($252) + 1|0);
 ;HEAP8[$253+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$253+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$253+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$253+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$253+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$253+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$253+6>>0]=HEAP8[604208+6>>0]|0;
 $254 = (($tempQuality) + 296|0);
 HEAP8[$254>>0] = 0;
 $255 = (($tempQuality) + 300|0);
 HEAP32[$255>>2] = 0;
 $256 = (($tempQuality) + 304|0);
 HEAP32[$256>>2] = 0;
 $257 = (($tempQuality) + 308|0);
 HEAP32[$257>>2] = 0;
 $258 = (($tempQuality) + 312|0);
 HEAP32[$258>>2] = 1;
 $259 = (($tempQuality) + 316|0);
 HEAP32[$259>>2] = 1;
 $260 = (($tempQuality) + 320|0);
 HEAP32[$260>>2] = 1;
 $261 = (($tempQuality) + 324|0);
 HEAPF32[$261>>2] = Math_fround(15.0);
 $262 = (($tempQuality) + 328|0);
 HEAPF32[$262>>2] = Math_fround(0.333333343267440795898);
 $263 = (($tempQuality) + 332|0);
 HEAPF32[$263>>2] = Math_fround(0.0666666701436042785645);
 $264 = (($tempQuality) + 336|0);
 HEAPF32[$264>>2] = Math_fround(0.20000000298023223877);
 $265 = (($tempQuality) + 340|0);
 HEAPF32[$265>>2] = Math_fround(0.46666666865348815918);
 $266 = (($tempQuality) + 344|0);
 HEAP32[$266>>2] = 1;
 $267 = (($tempQuality) + 348|0);
 HEAP32[$267>>2] = 1;
 $268 = (($tempQuality) + 352|0);
 $269 = (($tempQuality) + 368|0);
 ;HEAP32[$268+0>>2]=0|0;HEAP32[$268+4>>2]=0|0;HEAP32[$268+8>>2]=0|0;HEAP32[$268+12>>2]=0|0;
 HEAPF32[$269>>2] = Math_fround(0.300000011920928955078);
 $270 = (($tempQuality) + 372|0);
 HEAP32[$270>>2] = 0;
 $271 = (($tempQuality) + 376|0);
 HEAP32[$271>>2] = 4;
 $272 = (($tempQuality) + 380|0);
 HEAPF32[$272>>2] = Math_fround(512.0);
 $273 = (($tempQuality) + 384|0);
 HEAP8[$273>>0] = 14;
 $274 = (($273) + 1|0);
 ;HEAP8[$274+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$274+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$274+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$274+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$274+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$274+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$274+6>>0]=HEAP8[604208+6>>0]|0;
 $275 = (($tempQuality) + 392|0);
 HEAP8[$275>>0] = 0;
 $276 = (($tempQuality) + 396|0);
 HEAP32[$276>>2] = 0;
 $277 = (($tempQuality) + 400|0);
 HEAP32[$277>>2] = 0;
 $278 = (($tempQuality) + 404|0);
 HEAP32[$278>>2] = 0;
 $279 = (($tempQuality) + 408|0);
 HEAP32[$279>>2] = 1;
 $280 = (($tempQuality) + 412|0);
 HEAP32[$280>>2] = 1;
 $281 = (($tempQuality) + 416|0);
 HEAP32[$281>>2] = 1;
 $282 = (($tempQuality) + 420|0);
 HEAPF32[$282>>2] = Math_fround(15.0);
 $283 = (($tempQuality) + 424|0);
 HEAPF32[$283>>2] = Math_fround(0.333333343267440795898);
 $284 = (($tempQuality) + 428|0);
 HEAPF32[$284>>2] = Math_fround(0.0666666701436042785645);
 $285 = (($tempQuality) + 432|0);
 HEAPF32[$285>>2] = Math_fround(0.20000000298023223877);
 $286 = (($tempQuality) + 436|0);
 HEAPF32[$286>>2] = Math_fround(0.46666666865348815918);
 $287 = (($tempQuality) + 440|0);
 HEAP32[$287>>2] = 1;
 $288 = (($tempQuality) + 444|0);
 HEAP32[$288>>2] = 1;
 $289 = (($tempQuality) + 448|0);
 $290 = (($tempQuality) + 464|0);
 ;HEAP32[$289+0>>2]=0|0;HEAP32[$289+4>>2]=0|0;HEAP32[$289+8>>2]=0|0;HEAP32[$289+12>>2]=0|0;
 HEAPF32[$290>>2] = Math_fround(0.300000011920928955078);
 $291 = (($tempQuality) + 468|0);
 HEAP32[$291>>2] = 0;
 $292 = (($tempQuality) + 472|0);
 HEAP32[$292>>2] = 4;
 $293 = (($tempQuality) + 476|0);
 HEAPF32[$293>>2] = Math_fround(512.0);
 $294 = (($tempQuality) + 480|0);
 HEAP8[$294>>0] = 14;
 $295 = (($294) + 1|0);
 ;HEAP8[$295+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$295+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$295+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$295+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$295+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$295+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$295+6>>0]=HEAP8[604208+6>>0]|0;
 $296 = (($tempQuality) + 488|0);
 HEAP8[$296>>0] = 0;
 $297 = (($tempQuality) + 492|0);
 HEAP32[$297>>2] = 0;
 $298 = (($tempQuality) + 496|0);
 HEAP32[$298>>2] = 0;
 $299 = (($tempQuality) + 500|0);
 HEAP32[$299>>2] = 0;
 $300 = (($tempQuality) + 504|0);
 HEAP32[$300>>2] = 1;
 $301 = (($tempQuality) + 508|0);
 HEAP32[$301>>2] = 1;
 $302 = (($tempQuality) + 512|0);
 HEAP32[$302>>2] = 1;
 $303 = (($tempQuality) + 516|0);
 HEAPF32[$303>>2] = Math_fround(15.0);
 $304 = (($tempQuality) + 520|0);
 HEAPF32[$304>>2] = Math_fround(0.333333343267440795898);
 $305 = (($tempQuality) + 524|0);
 HEAPF32[$305>>2] = Math_fround(0.0666666701436042785645);
 $306 = (($tempQuality) + 528|0);
 HEAPF32[$306>>2] = Math_fround(0.20000000298023223877);
 $307 = (($tempQuality) + 532|0);
 HEAPF32[$307>>2] = Math_fround(0.46666666865348815918);
 $308 = (($tempQuality) + 536|0);
 HEAP32[$308>>2] = 1;
 $309 = (($tempQuality) + 540|0);
 HEAP32[$309>>2] = 1;
 $310 = (($tempQuality) + 544|0);
 $311 = (($tempQuality) + 560|0);
 ;HEAP32[$310+0>>2]=0|0;HEAP32[$310+4>>2]=0|0;HEAP32[$310+8>>2]=0|0;HEAP32[$310+12>>2]=0|0;
 HEAPF32[$311>>2] = Math_fround(0.300000011920928955078);
 $312 = (($tempQuality) + 564|0);
 HEAP32[$312>>2] = 0;
 $313 = (($tempQuality) + 568|0);
 HEAP32[$313>>2] = 4;
 $314 = (($tempQuality) + 572|0);
 HEAPF32[$314>>2] = Math_fround(512.0);
 __THREW__ = 0;
 invoke_vi(3486,($tempQuality|0));
 $315 = __THREW__; __THREW__ = 0;
 $316 = $315&1;
 L92: do {
  if (!($316)) {
   __THREW__ = 0;
   $317 = (invoke_iiiiii(192,($transfer|0),(604208|0),(604976|0),($converter$i$i38|0),1)|0);
   $318 = __THREW__; __THREW__ = 0;
   $319 = $318&1;
   if (!($319)) {
    $320 = ($317|0)==(0);
    if (!($320)) {
     $321 = ($317|0)>(0);
     if ($321) {
      __THREW__ = 0;
      invoke_vii(2719,($tempQuality|0),($transfer|0));
      $322 = __THREW__; __THREW__ = 0;
      $323 = $322&1;
      if ($323) {
       break;
      }
     } else {
      $324 = HEAP32[$converter$i$i38>>2]|0;
      $325 = ($324|0)==(0|0);
      if (!($325)) {
       __THREW__ = 0;
       (invoke_iii($324|0,($tempQuality|0),($transfer|0))|0);
       $326 = __THREW__; __THREW__ = 0;
       $327 = $326&1;
       if ($327) {
        break;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3389,($transfer|0));
     $328 = __THREW__; __THREW__ = 0;
     $329 = $328&1;
     if ($329) {
      break;
     }
    }
    $330 = (($tempQuality) + 96|0);
    __THREW__ = 0;
    $331 = (invoke_iiiiii(192,($transfer|0),(604424|0),(604976|0),($converter$i$i42|0),1)|0);
    $332 = __THREW__; __THREW__ = 0;
    $333 = $332&1;
    if (!($333)) {
     $334 = ($331|0)==(0);
     if (!($334)) {
      $335 = ($331|0)>(0);
      if ($335) {
       __THREW__ = 0;
       invoke_vii(2719,($330|0),($transfer|0));
       $336 = __THREW__; __THREW__ = 0;
       $337 = $336&1;
       if ($337) {
        break;
       }
      } else {
       $338 = HEAP32[$converter$i$i42>>2]|0;
       $339 = ($338|0)==(0|0);
       if (!($339)) {
        __THREW__ = 0;
        (invoke_iii($338|0,($330|0),($transfer|0))|0);
        $340 = __THREW__; __THREW__ = 0;
        $341 = $340&1;
        if ($341) {
         break;
        }
       }
      }
      __THREW__ = 0;
      invoke_vi(3389,($transfer|0));
      $342 = __THREW__; __THREW__ = 0;
      $343 = $342&1;
      if ($343) {
       break;
      }
     }
     $344 = (($tempQuality) + 192|0);
     __THREW__ = 0;
     $345 = (invoke_iiiiii(192,($transfer|0),(604432|0),(604976|0),($converter$i$i48|0),1)|0);
     $346 = __THREW__; __THREW__ = 0;
     $347 = $346&1;
     if (!($347)) {
      $348 = ($345|0)==(0);
      if (!($348)) {
       $349 = ($345|0)>(0);
       if ($349) {
        __THREW__ = 0;
        invoke_vii(2719,($344|0),($transfer|0));
        $350 = __THREW__; __THREW__ = 0;
        $351 = $350&1;
        if ($351) {
         break;
        }
       } else {
        $352 = HEAP32[$converter$i$i48>>2]|0;
        $353 = ($352|0)==(0|0);
        if (!($353)) {
         __THREW__ = 0;
         (invoke_iii($352|0,($344|0),($transfer|0))|0);
         $354 = __THREW__; __THREW__ = 0;
         $355 = $354&1;
         if ($355) {
          break;
         }
        }
       }
       __THREW__ = 0;
       invoke_vi(3389,($transfer|0));
       $356 = __THREW__; __THREW__ = 0;
       $357 = $356&1;
       if ($357) {
        break;
       }
      }
      $358 = (($tempQuality) + 288|0);
      __THREW__ = 0;
      $359 = (invoke_iiiiii(192,($transfer|0),(604440|0),(604976|0),($converter$i$i54|0),1)|0);
      $360 = __THREW__; __THREW__ = 0;
      $361 = $360&1;
      if (!($361)) {
       $362 = ($359|0)==(0);
       if (!($362)) {
        $363 = ($359|0)>(0);
        if ($363) {
         __THREW__ = 0;
         invoke_vii(2719,($358|0),($transfer|0));
         $364 = __THREW__; __THREW__ = 0;
         $365 = $364&1;
         if ($365) {
          break;
         }
        } else {
         $366 = HEAP32[$converter$i$i54>>2]|0;
         $367 = ($366|0)==(0|0);
         if (!($367)) {
          __THREW__ = 0;
          (invoke_iii($366|0,($358|0),($transfer|0))|0);
          $368 = __THREW__; __THREW__ = 0;
          $369 = $368&1;
          if ($369) {
           break;
          }
         }
        }
        __THREW__ = 0;
        invoke_vi(3389,($transfer|0));
        $370 = __THREW__; __THREW__ = 0;
        $371 = $370&1;
        if ($371) {
         break;
        }
       }
       $372 = (($tempQuality) + 384|0);
       __THREW__ = 0;
       $373 = (invoke_iiiiii(192,($transfer|0),(604448|0),(604976|0),($converter$i$i60|0),1)|0);
       $374 = __THREW__; __THREW__ = 0;
       $375 = $374&1;
       if (!($375)) {
        $376 = ($373|0)==(0);
        if (!($376)) {
         $377 = ($373|0)>(0);
         if ($377) {
          __THREW__ = 0;
          invoke_vii(2719,($372|0),($transfer|0));
          $378 = __THREW__; __THREW__ = 0;
          $379 = $378&1;
          if ($379) {
           break;
          }
         } else {
          $380 = HEAP32[$converter$i$i60>>2]|0;
          $381 = ($380|0)==(0|0);
          if (!($381)) {
           __THREW__ = 0;
           (invoke_iii($380|0,($372|0),($transfer|0))|0);
           $382 = __THREW__; __THREW__ = 0;
           $383 = $382&1;
           if ($383) {
            break;
           }
          }
         }
         __THREW__ = 0;
         invoke_vi(3389,($transfer|0));
         $384 = __THREW__; __THREW__ = 0;
         $385 = $384&1;
         if ($385) {
          break;
         }
        }
        $386 = (($tempQuality) + 480|0);
        __THREW__ = 0;
        $387 = (invoke_iiiiii(192,($transfer|0),(604464|0),(604976|0),($converter$i$i66|0),1)|0);
        $388 = __THREW__; __THREW__ = 0;
        $389 = $388&1;
        if (!($389)) {
         $390 = ($387|0)==(0);
         if (!($390)) {
          $391 = ($387|0)>(0);
          do {
           if ($391) {
            __THREW__ = 0;
            invoke_vii(2719,($386|0),($transfer|0));
            $392 = __THREW__; __THREW__ = 0;
            $393 = $392&1;
            if ($393) {
             break L92;
            }
           } else {
            $394 = HEAP32[$converter$i$i66>>2]|0;
            $395 = ($394|0)==(0|0);
            if ($395) {
             break;
            }
            __THREW__ = 0;
            (invoke_iii($394|0,($386|0),($transfer|0))|0);
            $396 = __THREW__; __THREW__ = 0;
            $397 = $396&1;
            if ($397) {
             break L92;
            }
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3389,($transfer|0));
          $398 = __THREW__; __THREW__ = 0;
          $399 = $398&1;
          if ($399) {
           break;
          }
         }
         __THREW__ = 0;
         $400 = (invoke_iii(2399,($transfer|0),2)|0);
         $401 = __THREW__; __THREW__ = 0;
         $402 = $401&1;
         if (!($402)) {
          if ($400) {
           $403 = (($tempQuality) + 24|0);
           HEAP32[$403>>2] = 0;
           $404 = (($tempQuality) + 120|0);
           HEAP32[$404>>2] = 0;
           $405 = (($tempQuality) + 216|0);
           HEAP32[$405>>2] = 0;
           $406 = (($tempQuality) + 312|0);
           HEAP32[$406>>2] = 0;
           $407 = (($tempQuality) + 408|0);
           HEAP32[$407>>2] = 0;
           $408 = (($tempQuality) + 504|0);
           HEAP32[$408>>2] = 0;
          }
          __THREW__ = 0;
          invoke_viii(1740,($20|0),($tempQuality|0),($189|0));
          $411 = __THREW__; __THREW__ = 0;
          $412 = $411&1;
          if (!($412)) {
           $414 = $189;
           while(1) {
            $413 = (($414) + -96|0);
            $415 = HEAP8[$413>>0]|0;
            $416 = $415 & 1;
            $417 = ($416<<24>>24)==(0);
            if (!($417)) {
             $418 = (($414) + -88|0);
             $419 = HEAP32[$418>>2]|0;
             HEAP32[$0>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
             invoke_vii(2591,($419|0),($$byval_copy13|0));
             $420 = __THREW__; __THREW__ = 0;
             $421 = $420&1;
             if ($421) {
              label = 103;
              break;
             }
            }
            $424 = ($413|0)==($tempQuality|0);
            if ($424) {
             label = 109;
             break;
            } else {
             $414 = $413;
            }
           }
           if ((label|0) == 103) {
            $422 = ___cxa_find_matching_catch()|0;
            $423 = tempRet0;
            ___cxa_call_unexpected(($422|0));
            // unreachable;
           }
           else if ((label|0) == 109) {
            $437 = (($this) + 36|0);
            __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$437,604480,0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $409 = ___cxa_find_matching_catch()|0;
 $410 = tempRet0;
 $426 = $189;
 while(1) {
  $425 = (($426) + -96|0);
  $427 = HEAP8[$425>>0]|0;
  $428 = $427 & 1;
  $429 = ($428<<24>>24)==(0);
  if (!($429)) {
   $430 = (($426) + -88|0);
   $431 = HEAP32[$430>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($431|0),($$byval_copy13|0));
   $432 = __THREW__; __THREW__ = 0;
   $433 = $432&1;
   if ($433) {
    label = 107;
    break;
   }
  }
  $436 = ($425|0)==($tempQuality|0);
  if ($436) {
   $$0 = $410;$$01 = $409;
   label = 110;
   break;
  } else {
   $426 = $425;
  }
 }
 if ((label|0) == 107) {
  $434 = ___cxa_find_matching_catch()|0;
  $435 = tempRet0;
  ___cxa_call_unexpected(($434|0));
  // unreachable;
 }
 else if ((label|0) == 110) {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN15QualitySettings14QualitySetting8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i14 = 0, $$sum$i$i$i$i$i19 = 0, $$sum$i$i$i$i$i4 = 0, $$sum$i$i$i$i$i9 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i10 = 0, $$sum1$i$i$i$i$i15 = 0, $$sum1$i$i$i$i$i20 = 0, $$sum1$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i18 = 0;
 var $syncToVBL = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i18 = sp;
 $syncToVBL = sp + 4|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = HEAP32[580712>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604512,$0,$converter$i$i18,0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i18>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$6,604520,0);
 $7 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$7,604536,0);
 $8 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$8,604544,0);
 $9 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$9,604568,0);
 $10 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$10,604592,0);
 $11 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$11,604608,0);
 $12 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,604632,0);
 $13 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,604648,0);
 $14 = (($this) + 44|0);
 $15 = HEAP32[580776>>2]|0;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604672,$15,$converter$i$i18,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  if ($18) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$14,604944,0);
   $19 = (($this) + 48|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$19,604952,0);
   $20 = (($this) + 52|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$20,604960,0);
  } else {
   $21 = HEAP32[$converter$i$i18>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    (FUNCTION_TABLE_iii[$21 & 4095]($14,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $23 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$23,604696,0);
 $24 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$24,604712,0);
 $25 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$25,604728,0);
 $26 = (($this) + 68|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$26,604752,0);
 $27 = (($this) + 76|0);
 $28 = HEAP32[580544>>2]|0;
 $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604768,$28,$converter$i$i18,0)|0);
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = ($29|0)>(0);
  do {
   if ($31) {
    $32 = (($transfer) + 12|0);
    $33 = (($transfer) + 80|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($transfer) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($transfer) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($transfer) + 32|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = Math_imul($42, $40)|0;
    $$sum$i$i$i$i$i = (($36) - ($43))|0;
    $44 = (($38) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$32>>2] = $44;
    $45 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($45)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $46 = (($38) + ($$sum1$i$i$i$i$i)|0);
     $47 = (($transfer) + 20|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($46>>>0)>($48>>>0);
     if (!($49)) {
      $50 = HEAP8[$44>>0]|0;
      HEAP8[$27>>0] = $50;
      $51 = HEAP32[$32>>2]|0;
      $52 = (($51) + 1|0);
      HEAP32[$32>>2] = $52;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($32,$27,1);
   } else {
    $53 = HEAP32[$converter$i$i18>>2]|0;
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     (FUNCTION_TABLE_iii[$53 & 4095]($27,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $55 = (($this) + 77|0);
 $56 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604784,$28,$converter$i$i18,0)|0);
 $57 = ($56|0)==(0);
 if (!($57)) {
  $58 = ($56|0)>(0);
  do {
   if ($58) {
    $59 = (($transfer) + 12|0);
    $60 = (($transfer) + 80|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61) + 12|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($transfer) + 16|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($transfer) + 28|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($transfer) + 32|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = Math_imul($69, $67)|0;
    $$sum$i$i$i$i$i4 = (($63) - ($70))|0;
    $71 = (($65) + ($$sum$i$i$i$i$i4)|0);
    HEAP32[$59>>2] = $71;
    $72 = ($$sum$i$i$i$i$i4|0)<(0);
    if (!($72)) {
     $$sum1$i$i$i$i$i5 = (($$sum$i$i$i$i$i4) + 1)|0;
     $73 = (($65) + ($$sum1$i$i$i$i$i5)|0);
     $74 = (($transfer) + 20|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = ($73>>>0)>($75>>>0);
     if (!($76)) {
      $77 = HEAP8[$71>>0]|0;
      HEAP8[$55>>0] = $77;
      $78 = HEAP32[$59>>2]|0;
      $79 = (($78) + 1|0);
      HEAP32[$59>>2] = $79;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($59,$55,1);
   } else {
    $80 = HEAP32[$converter$i$i18>>2]|0;
    $81 = ($80|0)==(0|0);
    if (!($81)) {
     (FUNCTION_TABLE_iii[$80 & 4095]($55,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $82 = (($this) + 78|0);
 $83 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604800,$28,$converter$i$i18,0)|0);
 $84 = ($83|0)==(0);
 if (!($84)) {
  $85 = ($83|0)>(0);
  do {
   if ($85) {
    $86 = (($transfer) + 12|0);
    $87 = (($transfer) + 80|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = (($88) + 12|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = (($transfer) + 16|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = (($transfer) + 28|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($transfer) + 32|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = Math_imul($96, $94)|0;
    $$sum$i$i$i$i$i9 = (($90) - ($97))|0;
    $98 = (($92) + ($$sum$i$i$i$i$i9)|0);
    HEAP32[$86>>2] = $98;
    $99 = ($$sum$i$i$i$i$i9|0)<(0);
    if (!($99)) {
     $$sum1$i$i$i$i$i10 = (($$sum$i$i$i$i$i9) + 1)|0;
     $100 = (($92) + ($$sum1$i$i$i$i$i10)|0);
     $101 = (($transfer) + 20|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = ($100>>>0)>($102>>>0);
     if (!($103)) {
      $104 = HEAP8[$98>>0]|0;
      HEAP8[$82>>0] = $104;
      $105 = HEAP32[$86>>2]|0;
      $106 = (($105) + 1|0);
      HEAP32[$86>>2] = $106;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($86,$82,1);
   } else {
    $107 = HEAP32[$converter$i$i18>>2]|0;
    $108 = ($107|0)==(0|0);
    if (!($108)) {
     (FUNCTION_TABLE_iii[$107 & 4095]($82,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $109 = (($this) + 79|0);
 $110 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604832,$28,$converter$i$i18,0)|0);
 $111 = ($110|0)==(0);
 if (!($111)) {
  $112 = ($110|0)>(0);
  do {
   if ($112) {
    $113 = (($transfer) + 12|0);
    $114 = (($transfer) + 80|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = (($115) + 12|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = (($transfer) + 16|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($transfer) + 28|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = (($transfer) + 32|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = Math_imul($123, $121)|0;
    $$sum$i$i$i$i$i14 = (($117) - ($124))|0;
    $125 = (($119) + ($$sum$i$i$i$i$i14)|0);
    HEAP32[$113>>2] = $125;
    $126 = ($$sum$i$i$i$i$i14|0)<(0);
    if (!($126)) {
     $$sum1$i$i$i$i$i15 = (($$sum$i$i$i$i$i14) + 1)|0;
     $127 = (($119) + ($$sum1$i$i$i$i$i15)|0);
     $128 = (($transfer) + 20|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = ($127>>>0)>($129>>>0);
     if (!($130)) {
      $131 = HEAP8[$125>>0]|0;
      HEAP8[$109>>0] = $131;
      $132 = HEAP32[$113>>2]|0;
      $133 = (($132) + 1|0);
      HEAP32[$113>>2] = $133;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($113,$109,1);
   } else {
    $134 = HEAP32[$converter$i$i18>>2]|0;
    $135 = ($134|0)==(0|0);
    if (!($135)) {
     (FUNCTION_TABLE_iii[$134 & 4095]($109,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $136 = (($this) + 72|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$136,604864,0);
 $137 = (($this) + 80|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$137,604880,0);
 $138 = (($this) + 84|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$138,604888,0);
 $139 = (($this) + 88|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$139,604904,0);
 $140 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 if (!($140)) {
  STACKTOP = sp;return;
 }
 $141 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,604928,$28,$converter$i$i18,0)|0);
 $142 = ($141|0)==(0);
 if (!($142)) {
  $143 = ($141|0)>(0);
  do {
   if ($143) {
    $144 = (($transfer) + 12|0);
    $145 = (($transfer) + 80|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = (($146) + 12|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = (($transfer) + 16|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = (($transfer) + 28|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = (($transfer) + 32|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = Math_imul($154, $152)|0;
    $$sum$i$i$i$i$i19 = (($148) - ($155))|0;
    $156 = (($150) + ($$sum$i$i$i$i$i19)|0);
    HEAP32[$144>>2] = $156;
    $157 = ($$sum$i$i$i$i$i19|0)<(0);
    if (!($157)) {
     $$sum1$i$i$i$i$i20 = (($$sum$i$i$i$i$i19) + 1)|0;
     $158 = (($150) + ($$sum1$i$i$i$i$i20)|0);
     $159 = (($transfer) + 20|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = ($158>>>0)>($160>>>0);
     if (!($161)) {
      $162 = HEAP8[$156>>0]|0;
      HEAP8[$syncToVBL>>0] = $162;
      $$sum = (($$sum$i$i$i$i$i19) + 1)|0;
      $163 = (($150) + ($$sum)|0);
      HEAP32[$144>>2] = $163;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($144,$syncToVBL,1);
   } else {
    $164 = HEAP32[$converter$i$i18>>2]|0;
    $165 = ($164|0)==(0|0);
    if (!($165)) {
     (FUNCTION_TABLE_iii[$164 & 4095]($syncToVBL,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $166 = HEAP8[$syncToVBL>>0]|0;
 $167 = $166&255;
 HEAP32[$136>>2] = $167;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN15QualitySettings14QualitySettingENS1_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 96)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,604992,604992,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIN15QualitySettings14QualitySettingENS0_9allocatorIS3_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,604968,604976,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN15QualitySettings14QualitySetting8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 96|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,604968,604976,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN15QualitySettings14QualitySetting8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 96|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorIN15QualitySettings14QualitySettingENS1_9allocatorIS4_EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp + 104|0;
 $0 = sp;
 $1 = sp + 4|0;
 $p$i$i = sp + 8|0;
 $2 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$2,$data,$metaFlag);
 HEAP8[$p$i$i>>0] = 14;
 $3 = (($p$i$i) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[604208+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[604208+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[604208+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[604208+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[604208+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[604208+5>>0]|0;HEAP8[$3+6>>0]=HEAP8[604208+6>>0]|0;
 $4 = (($p$i$i) + 8|0);
 HEAP8[$4>>0] = 0;
 $5 = (($p$i$i) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($p$i$i) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = (($p$i$i) + 20|0);
 HEAP32[$7>>2] = 0;
 $8 = (($p$i$i) + 24|0);
 HEAP32[$8>>2] = 1;
 $9 = (($p$i$i) + 28|0);
 HEAP32[$9>>2] = 1;
 $10 = (($p$i$i) + 32|0);
 HEAP32[$10>>2] = 1;
 $11 = (($p$i$i) + 36|0);
 HEAPF32[$11>>2] = Math_fround(15.0);
 $12 = (($p$i$i) + 40|0);
 HEAPF32[$12>>2] = Math_fround(0.333333343267440795898);
 $13 = (($p$i$i) + 44|0);
 HEAPF32[$13>>2] = Math_fround(0.0666666701436042785645);
 $14 = (($p$i$i) + 48|0);
 HEAPF32[$14>>2] = Math_fround(0.20000000298023223877);
 $15 = (($p$i$i) + 52|0);
 HEAPF32[$15>>2] = Math_fround(0.46666666865348815918);
 $16 = (($p$i$i) + 56|0);
 HEAP32[$16>>2] = 1;
 $17 = (($p$i$i) + 60|0);
 HEAP32[$17>>2] = 1;
 $18 = (($p$i$i) + 64|0);
 $19 = (($p$i$i) + 80|0);
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;
 HEAPF32[$19>>2] = Math_fround(0.300000011920928955078);
 $20 = (($p$i$i) + 84|0);
 HEAP32[$20>>2] = 0;
 $21 = (($p$i$i) + 88|0);
 HEAP32[$21>>2] = 4;
 $22 = (($p$i$i) + 92|0);
 HEAPF32[$22>>2] = Math_fround(512.0);
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(604992|0),(604992|0),($0|0),0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if (!($24)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(604968|0),(604976|0),($p$i$i|0),0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   __THREW__ = 0;
   invoke_vii(2720,($p$i$i|0),($this|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    __THREW__ = 0;
    invoke_vi(3390,($this|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __THREW__ = 0;
     invoke_vi(3391,($this|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $33 = HEAP8[$p$i$i>>0]|0;
      $34 = $33 & 1;
      $35 = ($34<<24>>24)==(0);
      if ($35) {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
      $36 = HEAP32[$4>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($36|0),($$byval_copy1|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       $39 = ___cxa_find_matching_catch()|0;
       $40 = tempRet0;
       ___cxa_call_unexpected(($39|0));
       // unreachable;
      } else {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 $43 = HEAP8[$p$i$i>>0]|0;
 $44 = $43 & 1;
 $45 = ($44<<24>>24)==(0);
 if ($45) {
  ___resumeException($41|0);
  // unreachable;
 }
 $46 = HEAP32[$4>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($46|0),($$byval_copy1|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 } else {
  ___resumeException($41|0);
  // unreachable;
 }
}
function __ZN15QualitySettings14QualitySetting8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $p$i$i$i = 0;
 var $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604512,$0,$this,2048);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,604992,604992,$size$i$i$i$i,1);
 $1 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604968,$1,$p$i$i$i,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 12|0);
 $9 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604520,$9,$8,2048);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604536,$9,$14,2048);
 $15 = HEAP32[$2>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$5>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604544,$9,$19,2048);
 $20 = HEAP32[$2>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$5>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604568,$9,$24,2048);
 $25 = HEAP32[$2>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$5>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604592,$9,$29,2048);
 $30 = HEAP32[$2>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$5>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $34 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604608,$9,$34,2048);
 $35 = HEAP32[$2>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$5>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $39 = (($this) + 36|0);
 $40 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604632,$40,$39,2048);
 $41 = HEAP32[$2>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$5>>2]|0;
 $44 = ((($42) + (($43*24)|0)|0) + 12|0);
 HEAP32[$44>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $45 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604648,$40,$45,2048);
 $46 = HEAP32[$2>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$5>>2]|0;
 $49 = ((($47) + (($48*24)|0)|0) + 12|0);
 HEAP32[$49>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $50 = (($this) + 44|0);
 $51 = HEAP32[580776>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604672,$51,$50,2048);
 $52 = (($transfer) + 16|0);
 $53 = (__ZNK16TypeTreeIterator7GetNodeEv($52)|0);
 $54 = (($53) + 20|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 | 2097152;
 $57 = HEAP32[$2>>2]|0;
 $58 = HEAP32[$57>>2]|0;
 $59 = HEAP32[$5>>2]|0;
 $60 = ((($58) + (($59*24)|0)|0) + 20|0);
 HEAP32[$60>>2] = $56;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604944,$40,$50,0);
 $61 = HEAP32[$2>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP32[$5>>2]|0;
 $64 = ((($62) + (($63*24)|0)|0) + 12|0);
 HEAP32[$64>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $65 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604952,$40,$65,0);
 $66 = HEAP32[$2>>2]|0;
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$5>>2]|0;
 $69 = ((($67) + (($68*24)|0)|0) + 12|0);
 HEAP32[$69>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $70 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604960,$40,$70,0);
 $71 = HEAP32[$2>>2]|0;
 $72 = HEAP32[$71>>2]|0;
 $73 = HEAP32[$5>>2]|0;
 $74 = ((($72) + (($73*24)|0)|0) + 12|0);
 HEAP32[$74>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $75 = (($this) + 56|0);
 $76 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604696,$76,$75,2048);
 $77 = HEAP32[$2>>2]|0;
 $78 = HEAP32[$77>>2]|0;
 $79 = HEAP32[$5>>2]|0;
 $80 = ((($78) + (($79*24)|0)|0) + 12|0);
 HEAP32[$80>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $81 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604712,$76,$81,2048);
 $82 = HEAP32[$2>>2]|0;
 $83 = HEAP32[$82>>2]|0;
 $84 = HEAP32[$5>>2]|0;
 $85 = ((($83) + (($84*24)|0)|0) + 12|0);
 HEAP32[$85>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $86 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604728,$76,$86,2048);
 $87 = HEAP32[$2>>2]|0;
 $88 = HEAP32[$87>>2]|0;
 $89 = HEAP32[$5>>2]|0;
 $90 = ((($88) + (($89*24)|0)|0) + 12|0);
 HEAP32[$90>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $91 = (($this) + 68|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604752,$76,$91,2048);
 $92 = HEAP32[$2>>2]|0;
 $93 = HEAP32[$92>>2]|0;
 $94 = HEAP32[$5>>2]|0;
 $95 = ((($93) + (($94*24)|0)|0) + 12|0);
 HEAP32[$95>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $96 = (($this) + 76|0);
 $97 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604768,$97,$96,2048);
 $98 = HEAP32[$2>>2]|0;
 $99 = HEAP32[$98>>2]|0;
 $100 = HEAP32[$5>>2]|0;
 $101 = ((($99) + (($100*24)|0)|0) + 12|0);
 HEAP32[$101>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $102 = (($this) + 77|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604784,$97,$102,2049);
 $103 = HEAP32[$2>>2]|0;
 $104 = HEAP32[$103>>2]|0;
 $105 = HEAP32[$5>>2]|0;
 $106 = ((($104) + (($105*24)|0)|0) + 12|0);
 HEAP32[$106>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $107 = (($this) + 78|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604800,$97,$107,2048);
 $108 = HEAP32[$2>>2]|0;
 $109 = HEAP32[$108>>2]|0;
 $110 = HEAP32[$5>>2]|0;
 $111 = ((($109) + (($110*24)|0)|0) + 12|0);
 HEAP32[$111>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $112 = (($this) + 79|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604832,$97,$112,2048);
 $113 = HEAP32[$2>>2]|0;
 $114 = HEAP32[$113>>2]|0;
 $115 = HEAP32[$5>>2]|0;
 $116 = ((($114) + (($115*24)|0)|0) + 12|0);
 HEAP32[$116>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $117 = (($this) + 72|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604864,$76,$117,2048);
 $118 = HEAP32[$2>>2]|0;
 $119 = HEAP32[$118>>2]|0;
 $120 = HEAP32[$5>>2]|0;
 $121 = ((($119) + (($120*24)|0)|0) + 12|0);
 HEAP32[$121>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $122 = (($this) + 80|0);
 $123 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604880,$123,$122,2048);
 $124 = HEAP32[$2>>2]|0;
 $125 = HEAP32[$124>>2]|0;
 $126 = HEAP32[$5>>2]|0;
 $127 = ((($125) + (($126*24)|0)|0) + 12|0);
 HEAP32[$127>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $128 = (($this) + 84|0);
 $129 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604888,$129,$128,2048);
 $130 = HEAP32[$2>>2]|0;
 $131 = HEAP32[$130>>2]|0;
 $132 = HEAP32[$5>>2]|0;
 $133 = ((($131) + (($132*24)|0)|0) + 12|0);
 HEAP32[$133>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $134 = (($this) + 88|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,604904,$129,$134,2048);
 $135 = HEAP32[$2>>2]|0;
 $136 = HEAP32[$135>>2]|0;
 $137 = HEAP32[$5>>2]|0;
 $138 = ((($136) + (($137*24)|0)|0) + 12|0);
 HEAP32[$138>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TransformD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i5$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy18 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((610384 + 8|0));
 __THREW__ = 0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if ($3) {
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   $39 = (($this) + 152|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)>(-1);
   if ($41) {
    $42 = (($this) + 140|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($this) + 144|0);
    $45 = HEAP32[$44>>2]|0;
    HEAP32[$0>>2] = $45;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($43|0),($$byval_copy18|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if (!($47)) {
     HEAP32[$42>>2] = 0;
     $$0 = $38;$$01 = $37;
     label = 22;
    }
   } else {
    $$0 = $38;$$01 = $37;
    label = 22;
   }
  } else {
   $4 = (($this) + 152|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)>(-1);
   do {
    if ($6) {
     $7 = (($this) + 140|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = (($this) + 144|0);
     $10 = HEAP32[$9>>2]|0;
     HEAP32[$1>>2] = $10;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($8|0),($$byval_copy18|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      $48 = ___cxa_find_matching_catch()|0;
      $49 = tempRet0;
      $$0 = $49;$$01 = $48;
      label = 22;
      break L1;
     } else {
      HEAP32[$7>>2] = 0;
      break;
     }
    }
   } while(0);
   HEAP32[$this>>2] = ((562072 + 8|0));
   __THREW__ = 0;
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$this>>2] = ((560936 + 8|0));
    __THREW__ = 0;
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     STACKTOP = sp;return;
    }
    $17 = ___cxa_find_matching_catch()|0;
    $18 = tempRet0;
    __THREW__ = 0;
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $21 = ___cxa_find_matching_catch(0|0)|0;
     $22 = tempRet0;
     ___clang_call_terminate($21);
     // unreachable;
    } else {
     ___resumeException($17|0);
     // unreachable;
    }
   }
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $29 = ___cxa_find_matching_catch(0|0)|0;
    $30 = tempRet0;
    __THREW__ = 0;
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch(0|0)|0;
     $34 = tempRet0;
     ___clang_call_terminate($33);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $29;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    ___resumeException($23|0);
    // unreachable;
   }
   $35 = ___cxa_find_matching_catch(0|0)|0;
   $36 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $35;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 do {
  if ((label|0) == 22) {
   HEAP32[$this>>2] = ((562072 + 8|0));
   __THREW__ = 0;
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if (!($51)) {
    HEAP32[$this>>2] = ((560936 + 8|0));
    __THREW__ = 0;
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if (!($53)) {
     __THREW__ = 0;
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     ___resumeException($$01|0);
     // unreachable;
    }
    $54 = ___cxa_find_matching_catch(0|0)|0;
    $55 = tempRet0;
    __THREW__ = 0;
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $58 = ___cxa_find_matching_catch(0|0)|0;
     $59 = tempRet0;
     ___clang_call_terminate($58);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $54;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $62 = ___cxa_find_matching_catch(0|0)|0;
   $63 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $68 = ___cxa_find_matching_catch(0|0)|0;
    $69 = tempRet0;
    __THREW__ = 0;
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $72 = ___cxa_find_matching_catch(0|0)|0;
     $73 = tempRet0;
     ___clang_call_terminate($72);
     // unreachable;
    } else {
     $eh$lpad$body$i5$indexZ2D = $68;
     ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if (!($67)) {
    $eh$lpad$body$indexZ2D = $62;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $74 = ___cxa_find_matching_catch(0|0)|0;
   $75 = tempRet0;
   $eh$lpad$body$i5$indexZ2D = $74;
   ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
   // unreachable;
  }
 } while(0);
 $76 = ___cxa_find_matching_catch(0|0)|0;
 $77 = tempRet0;
 $eh$lpad$body$indexZ2D = $76;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN2UI13RectTransform9DirtyRectEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 $0 = (__ZN2UI13RectTransform16UpdateCachedRectER9Transform($this,$this)|0);
 $1 = $0 & 2;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN2UI13RectTransform16DirtyRectRecurseER9Transform($this,$this);
 $3 = (($data) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($data) + 4|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$data>>2] = 0;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,566696,$data);
 STACKTOP = sp;return;
}
function __ZN2UI13RectTransform7GetRectEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == Math_fround(0.0);
 if ($2) {
  $3 = (($this) + 164|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4 == Math_fround(0.0);
  if ($5) {
   $6 = (($this) + 168|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 == Math_fround(0.0);
   if ($8) {
    $9 = (($this) + 172|0);
    $10 = Math_fround(HEAPF32[$9>>2]);
    $11 = $10 == Math_fround(0.0);
    if ($11) {
     (__ZN2UI13RectTransform16UpdateCachedRectER9Transform($this,$this)|0);
    }
   }
  }
 }
 STACKTOP = sp;return ($0|0);
}
function __ZN2UI13RectTransform16UpdateCachedRectER9Transform($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $5 = Math_fround(0);
 var $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $mask$0 = 0, $mask$1 = 0, $or$cond = 0, $or$cond1 = 0, $rect = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $rect = sp;
 __ZN2UI13RectTransform26CalculateRectInParentSpaceER9Transform($rect,$this,$transform);
 $0 = (($transform) + 44|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($transform) + 48|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($transform) + 52|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$rect>>2]);
 $7 = (($rect) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 208|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = Math_fround($6 + $11);
 $13 = (($rect) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($rect) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 212|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 + $19);
 $21 = $1 != $12;
 $22 = $3 != $20;
 $or$cond = $21 | $22;
 $23 = ($5 != $5) | (Math_fround(0.0) != Math_fround(0.0));
 $or$cond1 = $or$cond | $23;
 if ($or$cond1) {
  HEAPF32[$0>>2] = $12;
  HEAPF32[$2>>2] = $20;
  HEAPF32[$4>>2] = $5;
  $24 = (($transform) + 135|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25&255;
  $27 = $26 | 1;
  $28 = $27&255;
  HEAP8[$24>>0] = $28;
  __ZN9Transform20SendTransformChangedEi($transform,65);
  $mask$0 = 1;
 } else {
  $mask$0 = 0;
 }
 $29 = Math_fround($6 - $12);
 HEAPF32[$rect>>2] = $29;
 $30 = Math_fround($14 - $20);
 HEAPF32[$13>>2] = $30;
 $31 = (($this) + 160|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = $29 != $32;
 if (!($33)) {
  $34 = (($this) + 164|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = $30 != $35;
  if (!($36)) {
   $37 = (($this) + 168|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = $8 != $38;
   if (!($39)) {
    $40 = (($this) + 172|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = $16 != $41;
    if (!($42)) {
     $mask$1 = $mask$0;
     STACKTOP = sp;return ($mask$1|0);
    }
   }
  }
 }
 $43 = $mask$0 | 2;
 ;HEAP32[$31+0>>2]=HEAP32[$rect+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$rect+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$rect+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$rect+12>>2]|0;
 $mask$1 = $43;
 STACKTOP = sp;return ($mask$1|0);
}
function __ZN2UI13RectTransform16DirtyRectRecurseER9Transform($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 $0 = (($transform) + 148|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($transform) + 140|0);
 $4 = (($data) + 8|0);
 $5 = (($data) + 4|0);
 $i$01 = 0;
 while(1) {
  $6 = HEAP32[$3>>2]|0;
  $7 = (($6) + ($i$01<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = (($8) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $11 >>> 21;
   $13 = HEAP32[560640>>2]|0;
   $14 = Math_imul($13, $12)|0;
   $15 = (($14) + 224)|0;
   $16 = $15 >> 5;
   $17 = $16 << 5;
   $18 = (($15) - ($17))|0;
   $19 = HEAP32[560632>>2]|0;
   $20 = (($19) + ($16<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = 1 << $18;
   $23 = $22 & $21;
   $24 = ($23|0)==(0);
   if (!($24)) {
    $25 = (__ZN2UI13RectTransform16UpdateCachedRectER9Transform($8,$8)|0);
    $26 = $25 & 2;
    $27 = ($26|0)==(0);
    if (!($27)) {
     __ZN2UI13RectTransform16DirtyRectRecurseER9Transform($this,$8);
     HEAP32[$4>>2] = 0;
     HEAP32[$5>>2] = 0;
     HEAP32[$data>>2] = 0;
     __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($8,566696,$data);
    }
   }
  }
  $28 = (($i$01) + 1)|0;
  $exitcond = ($28|0)==($1|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $28;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI13RectTransform26CalculateRectInParentSpaceER9Transform($agg$result,$this,$transform) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $transform = $transform|0;
 var $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transform) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $38 = Math_fround(0.0);$40 = Math_fround(0.0);$44 = Math_fround(0.0);$46 = Math_fround(0.0);
 } else {
  $3 = (($1) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4 >>> 21;
  $6 = HEAP32[560640>>2]|0;
  $7 = Math_imul($6, $5)|0;
  $8 = (($7) + 224)|0;
  $9 = $8 >> 5;
  $10 = $9 << 5;
  $11 = (($8) - ($10))|0;
  $12 = HEAP32[560632>>2]|0;
  $13 = (($12) + ($9<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = 1 << $11;
  $16 = $15 & $14;
  $17 = ($16|0)==(0);
  if ($17) {
   $38 = Math_fround(0.0);$40 = Math_fround(0.0);$44 = Math_fround(0.0);$46 = Math_fround(0.0);
  } else {
   $18 = (($1) + 160|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = $19 == Math_fround(0.0);
   $21 = (($1) + 164|0);
   if ($20) {
    $22 = Math_fround(HEAPF32[$21>>2]);
    $23 = $22 == Math_fround(0.0);
    if ($23) {
     $24 = (($1) + 168|0);
     $25 = Math_fround(HEAPF32[$24>>2]);
     $26 = $25 == Math_fround(0.0);
     if ($26) {
      $27 = (($1) + 172|0);
      $28 = Math_fround(HEAPF32[$27>>2]);
      $29 = $28 == Math_fround(0.0);
      if ($29) {
       (__ZN2UI13RectTransform16UpdateCachedRectER9Transform($1,$1)|0);
       $$pre = Math_fround(HEAPF32[$18>>2]);
       $80 = $$pre;
      } else {
       $80 = $19;
      }
     } else {
      $80 = $19;
     }
    } else {
     $80 = $19;
    }
   } else {
    $80 = $19;
   }
   $30 = Math_fround(HEAPF32[$21>>2]);
   $31 = (($1) + 168|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = (($1) + 172|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $38 = $32;$40 = $80;$44 = $34;$46 = $30;
  }
 }
 $35 = (($this) + 176|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($38 * $36);
 $39 = Math_fround($40 + $37);
 $41 = (($this) + 180|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($44 * $42);
 $45 = Math_fround($46 + $43);
 $47 = (($this) + 184|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($38 * $48);
 $50 = Math_fround($40 + $49);
 $51 = (($this) + 188|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($44 * $52);
 $54 = Math_fround($46 + $53);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $55 = (($this) + 192|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($39 + $56);
 $58 = (($this) + 200|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($this) + 208|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($59 * $61);
 $63 = Math_fround($57 - $62);
 HEAPF32[$agg$result>>2] = $63;
 $64 = (($this) + 196|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($45 + $65);
 $67 = (($this) + 204|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($this) + 212|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($68 * $70);
 $72 = Math_fround($66 - $71);
 $73 = (($agg$result) + 4|0);
 HEAPF32[$73>>2] = $72;
 $74 = Math_fround($50 - $39);
 $75 = Math_fround($74 + $59);
 $76 = (($agg$result) + 8|0);
 HEAPF32[$76>>2] = $75;
 $77 = Math_fround($54 - $45);
 $78 = Math_fround($77 + $68);
 $79 = (($agg$result) + 12|0);
 HEAPF32[$79>>2] = $78;
 STACKTOP = sp;return;
}
function __ZN2UI13RectTransform17SetDrivenByObjectEPK6Object($this,$obj) {
 $this = $this|0;
 $obj = $obj|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK2UI13RectTransform17GetDrivenByObjectEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN2UI13RectTransform19SetDrivenPropertiesENS0_16DrivenPropertiesE($this,$properties) {
 $this = $this|0;
 $properties = $properties|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9TransformD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9TransformD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN9TransformD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3487,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN19RenderBufferManager23InitRenderBufferManagerEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(32)|0);
 HEAP32[$0>>2] = $0;
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = $0;
 $2 = (($0) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($0) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($0) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($0) + 12|0);
 HEAP32[$5>>2] = $3;
 $6 = (($0) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($0) + 28|0);
 HEAP32[$7>>2] = 0;
 HEAP32[605000>>2] = $0;
 STACKTOP = sp;return;
}
function __Z22GetRenderBufferManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[605000>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($this,$width,$height,$depthFormat,$colorFormat,$flags,$colorSpace,$antiAliasing) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $depthFormat = $depthFormat|0;
 $colorFormat = $colorFormat|0;
 $flags = $flags|0;
 $colorSpace = $colorSpace|0;
 $antiAliasing = $antiAliasing|0;
 var $$0 = 0, $$0$i1836 = 0, $$02 = 0, $$03 = 0, $$04 = 0, $$05 = 0, $$06 = 0, $$1 = 0, $$17 = 0, $$byval_copy12 = 0, $$in = 0, $$lobit = 0, $$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $antiAliasing$off = 0;
 var $eh$lpad$body$i$i$indexZ2D = 0, $neg = 0, $neg9 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond11 = 0, $or$cond47 = 0, $rect = 0, $temp$0$i$i$i41 = 0, $temp$0$i1745 = 0, $temp$0$i43 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy12 = sp;
 $0 = sp + 72|0;
 $1 = sp + 68|0;
 $2 = sp + 64|0;
 $3 = sp + 60|0;
 $4 = sp + 56|0;
 $5 = sp + 76|0;
 $rect = sp + 32|0;
 $6 = sp + 28|0;
 $7 = sp + 24|0;
 $8 = sp + 12|0;
 $9 = sp + 48|0;
 $10 = sp + 52|0;
 $11 = ($colorFormat|0)==(7);
 if ($11) {
  $12 = (__Z12GetGfxDevicev()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 672|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
  $$06 = $16;
 } else {
  $$06 = $colorFormat;
 }
 $17 = ($$06|0)==(9);
 if ($17) {
  $18 = (__Z12GetGfxDevicev()|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 676|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 4095]($18)|0);
  $$17 = $22;
 } else {
  $$17 = $$06;
 }
 $23 = $flags & 2;
 $24 = ($23|0)==(0);
 $25 = $flags >>> 2;
 $26 = $flags & 1;
 $27 = ($26|0)!=(0);
 $28 = $26 << 1;
 $29 = (($28) + 2)|0;
 if ((($colorSpace|0) == 2)) {
  label = 7;
 } else if ((($colorSpace|0) == 0)) {
  $30 = (__Z19GetActiveColorSpacev()|0);
  $31 = ($30|0)==(1);
  if ($31) {
   label = 7;
  } else {
   $$off0 = 0;
  }
 } else {
  $$off0 = 0;
 }
 if ((label|0) == 7) {
  $32 = (__Z12GetGfxDevicev()|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 676|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (FUNCTION_TABLE_ii[$35 & 4095]($32)|0);
  $37 = ($$17|0)!=($36|0);
  $$off0 = $37;
 }
 $38 = ($width|0)<(1);
 $39 = ($height|0)<(1);
 $or$cond = $38 | $39;
 if ($or$cond) {
  if ($27) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $40 = (__Z16GetRenderManagerv()|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0);
  if ($42) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$5>>2] = $41;
  $43 = HEAP32[560624>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   label = 19;
  } else {
   $45 = (($43) + 36|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($43) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46|0)==($48|0);
   do {
    if ($49) {
     $50 = (($43) + 28|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($43) + 32|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = (($51) + ($53<<3)|0);
     $70 = $54;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy12,$43,$5);
     $55 = HEAP32[$$byval_copy12>>2]|0;
     $56 = ($55|0)==(-1);
     $57 = (($43) + 28|0);
     $58 = HEAP32[$57>>2]|0;
     if ($56) {
      $59 = (($43) + 32|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = (($58) + ($60<<3)|0);
      $70 = $61;
      break;
     } else {
      $62 = (($58) + ($55<<3)|0);
      $70 = $62;
      break;
     }
    }
   } while(0);
   $63 = HEAP32[560624>>2]|0;
   $64 = (($63) + 28|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($63) + 32|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($65) + ($67<<3)|0);
   $69 = ($70|0)==($68|0);
   if ($69) {
    label = 19;
   } else {
    $71 = (($70) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==(0|0);
    if ($73) {
     label = 19;
    } else {
     $temp$0$i$i$i41 = $72;
    }
   }
  }
  if ((label|0) == 19) {
   $74 = HEAP32[$40>>2]|0;
   $75 = (__Z31ReadObjectFromPersistentManageri($74)|0);
   $76 = ($75|0)==(0|0);
   if ($76) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $temp$0$i$i$i41 = $75;
   }
  }
  __ZNK6Camera24GetScreenViewportRectIntEv($rect,$temp$0$i$i$i41);
  $77 = ($width|0)<(0);
  $78 = (($rect) + 8|0);
  $79 = HEAP32[$78>>2]|0;
  if ($77) {
   $neg9 = (0 - ($width))|0;
   $80 = (($79|0) / ($neg9|0))&-1;
   $$04 = $80;
  } else {
   $$04 = $79;
  }
  $81 = ($height|0)<(0);
  $82 = (($rect) + 12|0);
  $83 = HEAP32[$82>>2]|0;
  if ($81) {
   $neg = (0 - ($height))|0;
   $84 = (($83|0) / ($neg|0))&-1;
   $$05 = $84;$$1 = $$04;
  } else {
   $$05 = $83;$$1 = $$04;
  }
 } else {
  $$05 = $height;$$1 = $width;
 }
 if ($27) {
  $85 = (($$1) + -1)|0;
  $86 = $85 & $$1;
  $87 = ($86|0)==(0);
  $88 = ($$1|0)==($$05|0);
  $or$cond10 = $87 & $88;
  if (!($or$cond10)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $antiAliasing$off = (($antiAliasing) + -1)|0;
 $89 = ($antiAliasing$off>>>0)<(8);
 $90 = $antiAliasing$off & $antiAliasing;
 $91 = ($90|0)==(0);
 $or$cond47 = $89 & $91;
 if (!($or$cond47)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $92 = (($this) + 4|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==($this|0);
 L46: do {
  if (!($94)) {
   $95 = $25 & 1;
   $96 = ($95|0)!=(0);
   $98 = $93;
   L48: while(1) {
    $97 = (($98) + 12|0);
    $99 = HEAP32[$97>>2]|0;
    $100 = ($99|0)==(0);
    do {
     if (!($100)) {
      HEAP32[$2>>2] = $99;
      $101 = HEAP32[560624>>2]|0;
      $102 = ($101|0)==(0|0);
      if ($102) {
       label = 39;
      } else {
       $103 = (($101) + 36|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = (($101) + 4|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ($104|0)==($106|0);
       do {
        if ($107) {
         $108 = (($101) + 28|0);
         $109 = HEAP32[$108>>2]|0;
         $110 = (($101) + 32|0);
         $111 = HEAP32[$110>>2]|0;
         $112 = (($109) + ($111<<3)|0);
         $128 = $112;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy12,$101,$2);
         $113 = HEAP32[$$byval_copy12>>2]|0;
         $114 = ($113|0)==(-1);
         $115 = (($101) + 28|0);
         $116 = HEAP32[$115>>2]|0;
         if ($114) {
          $117 = (($101) + 32|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (($116) + ($118<<3)|0);
          $128 = $119;
          break;
         } else {
          $120 = (($116) + ($113<<3)|0);
          $128 = $120;
          break;
         }
        }
       } while(0);
       $121 = HEAP32[560624>>2]|0;
       $122 = (($121) + 28|0);
       $123 = HEAP32[$122>>2]|0;
       $124 = (($121) + 32|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = (($123) + ($125<<3)|0);
       $127 = ($128|0)==($126|0);
       if ($127) {
        label = 39;
       } else {
        $129 = (($128) + 4|0);
        $130 = HEAP32[$129>>2]|0;
        $131 = ($130|0)==(0|0);
        if ($131) {
         label = 39;
        } else {
         $$in = $130;$temp$0$i43 = $130;
        }
       }
      }
      if ((label|0) == 39) {
       label = 0;
       $132 = HEAP32[$97>>2]|0;
       $133 = (__Z31ReadObjectFromPersistentManageri($132)|0);
       $134 = ($133|0)==(0|0);
       if ($134) {
        break;
       } else {
        $$in = $133;$temp$0$i43 = $133;
       }
      }
      $135 = (($temp$0$i43) + 120|0);
      $136 = HEAP32[$135>>2]|0;
      $137 = ($136|0)==($depthFormat|0);
      if ($137) {
       $138 = (($temp$0$i43) + 116|0);
       $139 = HEAP32[$138>>2]|0;
       $140 = ($139|0)==($$17|0);
       if ($140) {
        $141 = HEAP32[$temp$0$i43>>2]|0;
        $142 = (($141) + 92|0);
        $143 = HEAP32[$142>>2]|0;
        $144 = (FUNCTION_TABLE_ii[$143 & 4095]($$in)|0);
        $145 = ($144|0)==($29|0);
        if ($145) {
         $146 = (($temp$0$i43) + 130|0);
         $147 = HEAP8[$146>>0]|0;
         $148 = ($147<<24>>24)!=(0);
         $149 = $148 ^ $$off0;
         if (!($149)) {
          $150 = (($temp$0$i43) + 108|0);
          $151 = HEAP32[$150>>2]|0;
          $152 = ($151|0)==($antiAliasing|0);
          if ($152) {
           $153 = (($$in) + 133|0);
           $154 = HEAP8[$153>>0]|0;
           $155 = ($154<<24>>24)!=(0);
           $156 = $155 ^ $96;
           if (!($156)) {
            $157 = (($temp$0$i43) + 100|0);
            $158 = HEAP32[$157>>2]|0;
            $159 = (($temp$0$i43) + 104|0);
            $160 = HEAP32[$159>>2]|0;
            $161 = ($158|0)==($$1|0);
            $162 = ($160|0)==($$05|0);
            $or$cond11 = $161 & $162;
            if ($or$cond11) {
             break L48;
            }
           }
          }
         }
        }
       }
      }
     }
    } while(0);
    $163 = (($98) + 4|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = ($164|0)==($this|0);
    if ($165) {
     break L46;
    } else {
     $98 = $164;
    }
   }
   $166 = ($98|0)==($this|0);
   if (!($166)) {
    $167 = HEAP32[$97>>2]|0;
    $168 = ($167|0)==(0);
    if (!($168)) {
     HEAP32[$0>>2] = $167;
     $169 = HEAP32[560624>>2]|0;
     $170 = ($169|0)==(0|0);
     if ($170) {
      label = 58;
     } else {
      $171 = (($169) + 36|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = (($169) + 4|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = ($172|0)==($174|0);
      do {
       if ($175) {
        $176 = (($169) + 28|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = (($169) + 32|0);
        $179 = HEAP32[$178>>2]|0;
        $180 = (($177) + ($179<<3)|0);
        $196 = $180;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy12,$169,$0);
        $181 = HEAP32[$$byval_copy12>>2]|0;
        $182 = ($181|0)==(-1);
        $183 = (($169) + 28|0);
        $184 = HEAP32[$183>>2]|0;
        if ($182) {
         $185 = (($169) + 32|0);
         $186 = HEAP32[$185>>2]|0;
         $187 = (($184) + ($186<<3)|0);
         $196 = $187;
         break;
        } else {
         $188 = (($184) + ($181<<3)|0);
         $196 = $188;
         break;
        }
       }
      } while(0);
      $189 = HEAP32[560624>>2]|0;
      $190 = (($189) + 28|0);
      $191 = HEAP32[$190>>2]|0;
      $192 = (($189) + 32|0);
      $193 = HEAP32[$192>>2]|0;
      $194 = (($191) + ($193<<3)|0);
      $195 = ($196|0)==($194|0);
      if ($195) {
       label = 58;
      } else {
       $197 = (($196) + 4|0);
       $198 = HEAP32[$197>>2]|0;
       $199 = ($198|0)==(0|0);
       if ($199) {
        label = 58;
       }
      }
     }
     if ((label|0) == 58) {
      $200 = HEAP32[$97>>2]|0;
      $201 = (__Z31ReadObjectFromPersistentManageri($200)|0);
      $202 = ($201|0)==(0|0);
      if ($202) {
       break;
      }
     }
     $257 = HEAP32[$97>>2]|0;
     $258 = ($257|0)==(0);
     do {
      if ($258) {
       $259 = (($this) + 12|0);
       $344 = $259;
       label = 85;
      } else {
       HEAP32[$1>>2] = $257;
       $260 = HEAP32[560624>>2]|0;
       $261 = ($260|0)==(0|0);
       if ($261) {
        label = 84;
       } else {
        $262 = (($260) + 36|0);
        $263 = HEAP32[$262>>2]|0;
        $264 = (($260) + 4|0);
        $265 = HEAP32[$264>>2]|0;
        $266 = ($263|0)==($265|0);
        do {
         if ($266) {
          $267 = (($260) + 28|0);
          $268 = HEAP32[$267>>2]|0;
          $269 = (($260) + 32|0);
          $270 = HEAP32[$269>>2]|0;
          $271 = (($268) + ($270<<3)|0);
          $287 = $271;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy12,$260,$1);
          $272 = HEAP32[$$byval_copy12>>2]|0;
          $273 = ($272|0)==(-1);
          $274 = (($260) + 28|0);
          $275 = HEAP32[$274>>2]|0;
          if ($273) {
           $276 = (($260) + 32|0);
           $277 = HEAP32[$276>>2]|0;
           $278 = (($275) + ($277<<3)|0);
           $287 = $278;
           break;
          } else {
           $279 = (($275) + ($272<<3)|0);
           $287 = $279;
           break;
          }
         }
        } while(0);
        $280 = HEAP32[560624>>2]|0;
        $281 = (($280) + 28|0);
        $282 = HEAP32[$281>>2]|0;
        $283 = (($280) + 32|0);
        $284 = HEAP32[$283>>2]|0;
        $285 = (($282) + ($284<<3)|0);
        $286 = ($287|0)==($285|0);
        if ($286) {
         label = 84;
        } else {
         $288 = (($287) + 4|0);
         $289 = HEAP32[$288>>2]|0;
         $290 = ($289|0)==(0|0);
         if ($290) {
          label = 84;
         } else {
          $291 = (($this) + 12|0);
          $345 = $291;$temp$0$i1745 = $289;
         }
        }
       }
       if ((label|0) == 84) {
        $292 = HEAP32[$97>>2]|0;
        $293 = (__Z31ReadObjectFromPersistentManageri($292)|0);
        $294 = (($this) + 12|0);
        $295 = ($293|0)==(0|0);
        if ($295) {
         $344 = $294;
         label = 85;
         break;
        } else {
         $345 = $294;$temp$0$i1745 = $293;
        }
       }
       $296 = (($temp$0$i1745) + 4|0);
       $297 = HEAP32[$296>>2]|0;
       HEAP32[$10>>2] = $297;
       $$0$i1836 = $temp$0$i1745;$298 = $345;
      }
     } while(0);
     if ((label|0) == 85) {
      HEAP32[$10>>2] = 0;
      $$0$i1836 = 0;$298 = $344;
     }
     __ZNSt3__16__treeI4PPtrI13RenderTextureENS_4lessIS3_EE11memory_poolIS3_EE15__insert_uniqueERKS3_($$byval_copy12,$298,$10);
     $299 = (($98) + 4|0);
     $300 = HEAP32[$299>>2]|0;
     $301 = HEAP32[$98>>2]|0;
     $302 = (($301) + 4|0);
     HEAP32[$302>>2] = $300;
     $303 = HEAP32[$98>>2]|0;
     $304 = HEAP32[$299>>2]|0;
     HEAP32[$304>>2] = $303;
     $305 = (($this) + 8|0);
     $306 = HEAP32[$305>>2]|0;
     $307 = (($306) + -1)|0;
     HEAP32[$305>>2] = $307;
     $308 = HEAP8[605128>>0]|0;
     $309 = ($308<<24>>24)==(0);
     do {
      if ($309) {
       $310 = HEAP32[628480>>2]|0;
       HEAP32[$3>>2] = $310;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
       $311 = (invoke_iiiiiii(103,40,($$byval_copy12|0),0,16,(605008|0),141)|0);
       $312 = __THREW__; __THREW__ = 0;
       $313 = $312&1;
       if (!($313)) {
        $314 = HEAP32[628480>>2]|0;
        HEAP32[$4>>2] = $314;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
        invoke_viiiiii(98,($311|0),1,(605136|0),16,32768,($$byval_copy12|0));
        $315 = __THREW__; __THREW__ = 0;
        $316 = $315&1;
        if (!($316)) {
         HEAP32[605120>>2] = $311;
         __THREW__ = 0;
         invoke_vi(3395,($311|0));
         $323 = __THREW__; __THREW__ = 0;
         $324 = $323&1;
         if ($324) {
          break;
         }
         $325 = 605128;
         $326 = $325;
         HEAP32[$326>>2] = 1;
         $327 = (($325) + 4)|0;
         $328 = $327;
         HEAP32[$328>>2] = 0;
         label = 94;
         break;
        }
        $317 = ___cxa_find_matching_catch()|0;
        $318 = tempRet0;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_viiiiii(97,($311|0),($$byval_copy12|0),0,16,(605008|0),141);
        $319 = __THREW__; __THREW__ = 0;
        $320 = $319&1;
        if ($320) {
         $321 = ___cxa_find_matching_catch(0|0)|0;
         $322 = tempRet0;
         ___clang_call_terminate($321);
         // unreachable;
        } else {
         $eh$lpad$body$i$i$indexZ2D = $317;
         ___cxa_call_unexpected(($eh$lpad$body$i$i$indexZ2D|0));
         // unreachable;
        }
       }
      } else {
       label = 94;
      }
     } while(0);
     if ((label|0) == 94) {
      $329 = HEAP32[605120>>2]|0;
      __THREW__ = 0;
      invoke_vii(2609,($329|0),($98|0));
      $330 = __THREW__; __THREW__ = 0;
      $331 = $330&1;
      if (!($331)) {
       $334 = (($$0$i1836) + 28|0);
       __ZN15TextureSettings5ResetEv($334);
       $335 = (($$0$i1836) + 40|0);
       HEAP32[$335>>2] = 1;
       $336 = (($$0$i1836) + 32|0);
       HEAP32[$336>>2] = 0;
       $337 = HEAP32[$$0$i1836>>2]|0;
       $338 = (($337) + 132|0);
       $339 = HEAP32[$338>>2]|0;
       FUNCTION_TABLE_vi[$339 & 4095]($$0$i1836);
       $340 = (($$0$i1836) + 132|0);
       $$lobit = $23 >>> 1;
       $341 = $$lobit&255;
       HEAP8[$340>>0] = $341;
       if ($24) {
        $$0 = $$0$i1836;
        STACKTOP = sp;return ($$0|0);
       }
       __ZN13RenderTexture15DiscardContentsEv($$0$i1836);
       $$0 = $$0$i1836;
       STACKTOP = sp;return ($$0|0);
      }
     }
     $332 = ___cxa_find_matching_catch()|0;
     $333 = tempRet0;
     $eh$lpad$body$i$i$indexZ2D = $332;
     ___cxa_call_unexpected(($eh$lpad$body$i$i$indexZ2D|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $203 = (($this) + 24|0);
 $204 = HEAP32[$203>>2]|0;
 $205 = (($204) + 1)|0;
 HEAP32[$203>>2] = $205;
 $206 = HEAP32[628384>>2]|0;
 HEAP32[$6>>2] = $206;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$6+0>>2]|0;
 $207 = (__Znwj10MemLabelIdbiPKci(172,$$byval_copy12,1,16,605008,152)|0);
 $208 = HEAP32[628384>>2]|0;
 HEAP32[$7>>2] = $208;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$7+0>>2]|0;
 invoke_viii(1743,($207|0),($$byval_copy12|0),0);
 $209 = __THREW__; __THREW__ = 0;
 $210 = $209&1;
 if ($210) {
  $246 = ___cxa_find_matching_catch()|0;
  $247 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$6+0>>2]|0;
  invoke_viiiiii(97,($207|0),($$byval_copy12|0),1,16,(605008|0),152);
  $248 = __THREW__; __THREW__ = 0;
  $249 = $248&1;
  if ($249) {
   $342 = ___cxa_find_matching_catch(0|0)|0;
   $343 = tempRet0;
   ___clang_call_terminate($342);
   // unreachable;
  } else {
   $$02 = $247;$$03 = $246;
   ___resumeException($$03|0);
   // unreachable;
  }
 }
 $211 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($207)|0);
 $212 = HEAP32[$211>>2]|0;
 $213 = (($212) + 24|0);
 $214 = HEAP32[$213>>2]|0;
 FUNCTION_TABLE_vi[$214 & 4095]($211);
 $215 = HEAP32[$211>>2]|0;
 $216 = (($215) + 44|0);
 $217 = HEAP32[$216>>2]|0;
 FUNCTION_TABLE_vii[$217 & 4095]($211,61);
 $218 = HEAP32[$211>>2]|0;
 $219 = (($218) + 36|0);
 $220 = HEAP32[$219>>2]|0;
 $221 = HEAP32[$203>>2]|0;
 HEAP32[$$byval_copy12>>2] = $221;
 $vararg_ptr6 = (($$byval_copy12) + 4|0);
 HEAP32[$vararg_ptr6>>2] = $$1;
 $vararg_ptr7 = (($$byval_copy12) + 8|0);
 HEAP32[$vararg_ptr7>>2] = $$05;
 __Z6FormatPKcz($8,605016,$$byval_copy12);
 $222 = HEAP8[$8>>0]|0;
 $223 = $222 & 1;
 $224 = ($223<<24>>24)==(0);
 if ($224) {
  $227 = (($8) + 1|0);
  $228 = $227;
 } else {
  $225 = (($8) + 8|0);
  $226 = HEAP32[$225>>2]|0;
  $228 = $226;
 }
 __THREW__ = 0;
 invoke_vii($220|0,($211|0),($228|0));
 $229 = __THREW__; __THREW__ = 0;
 $230 = $229&1;
 if ($230) {
  $250 = ___cxa_find_matching_catch()|0;
  $251 = tempRet0;
  $252 = HEAP8[$8>>0]|0;
  $253 = $252 & 1;
  $254 = ($253<<24>>24)==(0);
  if ($254) {
   $$02 = $251;$$03 = $250;
   ___resumeException($$03|0);
   // unreachable;
  }
  $255 = (($8) + 8|0);
  $256 = HEAP32[$255>>2]|0;
  __ZdlPv($256);
  $$02 = $251;$$03 = $250;
  ___resumeException($$03|0);
  // unreachable;
 }
 $231 = HEAP8[$8>>0]|0;
 $232 = $231 & 1;
 $233 = ($232<<24>>24)==(0);
 if (!($233)) {
  $234 = (($8) + 8|0);
  $235 = HEAP32[$234>>2]|0;
  __ZdlPv($235);
 }
 __ZN13RenderTexture8SetWidthEi($211,$$1);
 __ZN13RenderTexture9SetHeightEi($211,$$05);
 __ZN13RenderTexture14SetColorFormatE19RenderTextureFormat($211,$$17);
 __ZN13RenderTexture14SetDepthFormatE17DepthBufferFormat($211,$depthFormat);
 __ZN13RenderTexture12SetDimensionE16TextureDimension($211,$29);
 __ZN13RenderTexture16SetSRGBReadWriteEb($211,$$off0);
 __ZN13RenderTexture15SetAntiAliasingEi($211,$antiAliasing);
 $236 = $25 & 1;
 $237 = (($211) + 133|0);
 $238 = $236&255;
 HEAP8[$237>>0] = $238;
 $239 = HEAP32[$211>>2]|0;
 $240 = (($239) + 12|0);
 $241 = HEAP32[$240>>2]|0;
 FUNCTION_TABLE_vii[$241 & 4095]($211,4);
 $242 = ($211|0)==(0|0);
 if ($242) {
  HEAP32[$9>>2] = 0;
 } else {
  $243 = (($211) + 4|0);
  $244 = HEAP32[$243>>2]|0;
  HEAP32[$9>>2] = $244;
 }
 $245 = (($this) + 12|0);
 __ZNSt3__16__treeI4PPtrI13RenderTextureENS_4lessIS3_EE11memory_poolIS3_EE15__insert_uniqueERKS3_($$byval_copy12,$245,$9);
 $$0 = $211;
 STACKTOP = sp;return ($$0|0);
}
function __ZN19RenderBufferManager14GarbageCollectEi($this,$framesDelay) {
 $this = $this|0;
 $framesDelay = $framesDelay|0;
 var $$0$i = 0, $$byval_copy7 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $eh$lpad$body$i$i$indexZ2D = 0, $or$cond = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy7 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 HEAP32[$3>>2] = $5;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($this|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $11 = $7;$14 = $5;
 while(1) {
  $10 = (($11) + 8|0);
  $12 = HEAP32[$10>>2]|0;
  $13 = (($14) - ($12))|0;
  $15 = ($13|0)>($framesDelay|0);
  $16 = ($13|0)<(0);
  $or$cond = $15 | $16;
  $17 = (($11) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  if ($or$cond) {
   $19 = (($11) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    $$0$i = 0;
   } else {
    HEAP32[$0>>2] = $20;
    $22 = HEAP32[560624>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     label = 13;
    } else {
     $24 = (($22) + 36|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($22) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($25|0)==($27|0);
     do {
      if ($28) {
       $29 = (($22) + 28|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = (($22) + 32|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($30) + ($32<<3)|0);
       $49 = $33;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy7,$22,$0);
       $34 = HEAP32[$$byval_copy7>>2]|0;
       $35 = ($34|0)==(-1);
       $36 = (($22) + 28|0);
       $37 = HEAP32[$36>>2]|0;
       if ($35) {
        $38 = (($22) + 32|0);
        $39 = HEAP32[$38>>2]|0;
        $40 = (($37) + ($39<<3)|0);
        $49 = $40;
        break;
       } else {
        $41 = (($37) + ($34<<3)|0);
        $49 = $41;
        break;
       }
      }
     } while(0);
     $42 = HEAP32[560624>>2]|0;
     $43 = (($42) + 28|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + 32|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($44) + ($46<<3)|0);
     $48 = ($49|0)==($47|0);
     if ($48) {
      label = 13;
     } else {
      $50 = (($49) + 4|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==(0|0);
      if ($52) {
       label = 13;
      } else {
       $temp$0$i = $51;
      }
     }
    }
    if ((label|0) == 13) {
     label = 0;
     $53 = HEAP32[$19>>2]|0;
     $54 = (__Z31ReadObjectFromPersistentManageri($53)|0);
     $temp$0$i = $54;
    }
    $$0$i = $temp$0$i;
   }
   __Z19DestroySingleObjectP6Object($$0$i);
   $55 = HEAP32[$17>>2]|0;
   $56 = HEAP32[$11>>2]|0;
   $57 = (($56) + 4|0);
   HEAP32[$57>>2] = $55;
   $58 = HEAP32[$11>>2]|0;
   $59 = HEAP32[$17>>2]|0;
   HEAP32[$59>>2] = $58;
   $60 = HEAP32[$9>>2]|0;
   $61 = (($60) + -1)|0;
   HEAP32[$9>>2] = $61;
   $62 = HEAP8[605128>>0]|0;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    $64 = HEAP32[628480>>2]|0;
    HEAP32[$1>>2] = $64;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    $65 = (invoke_iiiiiii(103,40,($$byval_copy7|0),0,16,(605008|0),141)|0);
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     label = 25;
     break;
    }
    $68 = HEAP32[628480>>2]|0;
    HEAP32[$2>>2] = $68;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viiiiii(98,($65|0),1,(605136|0),16,32768,($$byval_copy7|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     label = 18;
     break;
    }
    HEAP32[605120>>2] = $65;
    __THREW__ = 0;
    invoke_vi(3395,($65|0));
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     label = 25;
     break;
    }
    $79 = 605128;
    $80 = $79;
    HEAP32[$80>>2] = 1;
    $81 = (($79) + 4)|0;
    $82 = $81;
    HEAP32[$82>>2] = 0;
   }
   $83 = HEAP32[605120>>2]|0;
   __THREW__ = 0;
   invoke_vii(2609,($83|0),($11|0));
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   if ($85) {
    label = 25;
    break;
   }
  }
  $86 = ($18|0)==($this|0);
  if ($86) {
   label = 27;
   break;
  }
  $$pre = HEAP32[$3>>2]|0;
  $11 = $18;$14 = $$pre;
 }
 if ((label|0) == 18) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viiiiii(97,($65|0),($$byval_copy7|0),0,16,(605008|0),141);
  $73 = __THREW__; __THREW__ = 0;
  $74 = $73&1;
  if ($74) {
   $75 = ___cxa_find_matching_catch(0|0)|0;
   $76 = tempRet0;
   ___clang_call_terminate($75);
   // unreachable;
  } else {
   $eh$lpad$body$i$i$indexZ2D = $71;
   ___cxa_call_unexpected(($eh$lpad$body$i$i$indexZ2D|0));
   // unreachable;
  }
 }
 else if ((label|0) == 25) {
  $87 = ___cxa_find_matching_catch()|0;
  $88 = tempRet0;
  $eh$lpad$body$i$i$indexZ2D = $87;
  ___cxa_call_unexpected(($eh$lpad$body$i$i$indexZ2D|0));
  // unreachable;
 }
 else if ((label|0) == 27) {
  STACKTOP = sp;return;
 }
}
function __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($this,$rTex) {
 $this = $this|0;
 $rTex = $rTex|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__rt$0$in$i$i = 0, $__rt$0$in$in$be$i$i = 0;
 var $__rt$0$in1$i$i = 0, $__rt$0$in2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = ($rTex|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($rTex) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 16|0);
 $__rt$0$in1$i$i = HEAP32[$6>>2]|0;
 $7 = ($__rt$0$in1$i$i|0)==(0|0);
 L4: do {
  if (!($7)) {
   $__rt$0$in2$i$i = $__rt$0$in1$i$i;
   while(1) {
    $8 = (($__rt$0$in2$i$i) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($5|0)<($9|0);
    if ($10) {
     $__rt$0$in$in$be$i$i = $__rt$0$in2$i$i;
    } else {
     $11 = ($9|0)<($5|0);
     if (!($11)) {
      break;
     }
     $12 = (($__rt$0$in2$i$i) + 4|0);
     $__rt$0$in$in$be$i$i = $12;
    }
    $__rt$0$in$i$i = HEAP32[$__rt$0$in$in$be$i$i>>2]|0;
    $13 = ($__rt$0$in$i$i|0)==(0|0);
    if ($13) {
     break L4;
    } else {
     $__rt$0$in2$i$i = $__rt$0$in$i$i;
    }
   }
   $14 = (($this) + 12|0);
   $15 = (($this) + 16|0);
   $$0$ph7$i$i$i$i = $15;$$01$ph6$i$in$i$i$i = $__rt$0$in1$i$i;
   L13: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $16 = (($$013$i$in$i$i$i) + 16|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)<($5|0);
     if (!($18)) {
      break;
     }
     $21 = (($$013$i$in$i$i$i) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L13;
     } else {
      $$013$i$in$i$i$i = $22;
     }
    }
    $19 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $19;
    }
   }
   $24 = ($$0$ph5$i$i$i$i|0)==($15|0);
   if ($24) {
    $31 = $5;
   } else {
    $25 = (($$0$ph5$i$i$i$i) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($5|0)<($26|0);
    if ($27) {
     $31 = $5;
    } else {
     HEAP32[$0>>2] = $$0$ph5$i$i$i$i;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     __ZNSt3__16__treeI4PPtrI13RenderTextureENS_4lessIS3_EE11memory_poolIS3_EE5eraseENS_21__tree_const_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEE($1,$14,$$byval_copy);
     $$pre = HEAP32[$4>>2]|0;
     $31 = $$pre;
    }
   }
   $28 = (($this) + 28|0);
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$2>>2] = $29;
   $30 = (($2) + 4|0);
   HEAP32[$30>>2] = $31;
   __ZNSt3__14listINS_4pairIi4PPtrI13RenderTextureEEE11memory_poolIS5_EE9push_backERKS5_($this,$2);
   STACKTOP = sp;return;
  }
 } while(0);
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(605040,0,605008,251,1,$5,0,0);
 STACKTOP = sp;return;
}
function __ZNSt3__14listINS_4pairIi4PPtrI13RenderTextureEEE11memory_poolIS5_EE9push_backERKS5_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP8[605128>>0]|0;
 $3 = ($2<<24>>24)==(0);
 do {
  if ($3) {
   $4 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $4;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $5 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,605008,141)|0);
   $6 = HEAP32[628480>>2]|0;
   HEAP32[$1>>2] = $6;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(98,($5|0),1,(605136|0),16,32768,($$byval_copy2|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    HEAP32[605120>>2] = $5;
    __ZN10MemoryPool24RegisterStaticMemoryPoolEPS_($5);
    $15 = 605128;
    $16 = $15;
    HEAP32[$16>>2] = 1;
    $17 = (($15) + 4)|0;
    $18 = $17;
    HEAP32[$18>>2] = 0;
    break;
   }
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viiiiii(97,($5|0),($$byval_copy2|0),0,16,(605008|0),141);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $13 = ___cxa_find_matching_catch(0|0)|0;
    $14 = tempRet0;
    ___clang_call_terminate($13);
    // unreachable;
   } else {
    ___resumeException($9|0);
    // unreachable;
   }
  }
 } while(0);
 $19 = HEAP32[605120>>2]|0;
 $20 = (__ZN10MemoryPool8AllocateEj($19,16)|0);
 $21 = (($20) + 8|0);
 $22 = HEAP32[$__x>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = (($__x) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($20) + 12|0);
 HEAP32[$25>>2] = $24;
 $26 = HEAP32[$__x>>2]|0;
 HEAP32[$21>>2] = $26;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + 4|0);
 HEAP32[$28>>2] = $20;
 $29 = HEAP32[$this>>2]|0;
 HEAP32[$20>>2] = $29;
 HEAP32[$this>>2] = $20;
 $30 = (($20) + 4|0);
 HEAP32[$30>>2] = $this;
 $31 = (($this) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 1)|0;
 HEAP32[$31>>2] = $33;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI4PPtrI13RenderTextureENS_4lessIS3_EE11memory_poolIS3_EE5eraseENS_21__tree_const_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEE($agg$result,$this,$__p) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__p = $__p|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$__p>>2]|0;
 HEAP32[$agg$result>>2] = $2;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$01$i$i = $2;
  while(1) {
   $8 = (($$01$i$i) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($$01$i$i|0);
   if ($11) {
    $$0$i$i = $9;
    break;
   } else {
    $$01$i$i = $9;
   }
  }
 } else {
  $$0$i$i$i = $4;
  while(1) {
   $6 = HEAP32[$$0$i$i$i>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $$0$i$i = $$0$i$i$i;
    break;
   } else {
    $$0$i$i$i = $6;
   }
  }
 }
 HEAP32[$agg$result>>2] = $$0$i$i;
 $12 = HEAP32[$this>>2]|0;
 $13 = ($12|0)==($2|0);
 if ($13) {
  HEAP32[$this>>2] = $$0$i$i;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($18,$2);
 $19 = HEAP8[567776>>0]|0;
 $20 = ($19<<24>>24)==(0);
 do {
  if ($20) {
   $21 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   $22 = (invoke_iiiiiii(103,40,($$byval_copy7|0),0,16,(605008|0),141)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[628480>>2]|0;
    HEAP32[$1>>2] = $25;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viiiiii(98,($22|0),1,(605136|0),20,32768,($$byval_copy7|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     HEAP32[567768>>2] = $22;
     __THREW__ = 0;
     invoke_vi(3395,($22|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $36 = 567776;
     $37 = $36;
     HEAP32[$37>>2] = 1;
     $38 = (($36) + 4)|0;
     $39 = $38;
     HEAP32[$39>>2] = 0;
     label = 14;
     break;
    }
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viiiiii(97,($22|0),($$byval_copy7|0),0,16,(605008|0),141);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     $32 = ___cxa_find_matching_catch(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $28;
     ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
     // unreachable;
    }
   }
  } else {
   label = 14;
  }
 } while(0);
 if ((label|0) == 14) {
  $40 = HEAP32[567768>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($40|0),($2|0));
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if (!($42)) {
   STACKTOP = sp;return;
  }
 }
 $43 = ___cxa_find_matching_catch()|0;
 $44 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $43;
 ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
 // unreachable;
}
function __ZNSt3__16__treeI4PPtrI13RenderTextureENS_4lessIS3_EE11memory_poolIS3_EE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp + 12|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$20 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)<($6|0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6|0)<($4|0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $30 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 __ZNSt3__16__treeI4PPtrI13RenderTextureENS_4lessIS3_EE11memory_poolIS3_EE16__construct_nodeERKS3_($0,$this,$__v);
 $17 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$17>>2] = 0;
 $18 = (($17) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $17;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $17;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $17;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI4PPtrI13RenderTextureENS_4lessIS3_EE11memory_poolIS3_EE16__construct_nodeERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP8[567776>>0]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   $5 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $5;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $6 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,605008,141)|0);
   $7 = HEAP32[628480>>2]|0;
   HEAP32[$1>>2] = $7;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(98,($6|0),1,(605136|0),20,32768,($$byval_copy2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    HEAP32[567768>>2] = $6;
    __ZN10MemoryPool24RegisterStaticMemoryPoolEPS_($6);
    $16 = 567776;
    $17 = $16;
    HEAP32[$17>>2] = 1;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP32[$19>>2] = 0;
    break;
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viiiiii(97,($6|0),($$byval_copy2|0),0,16,(605008|0),141);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch(0|0)|0;
    $15 = tempRet0;
    ___clang_call_terminate($14);
    // unreachable;
   } else {
    ___resumeException($10|0);
    // unreachable;
   }
  }
 } while(0);
 $20 = HEAP32[567768>>2]|0;
 $21 = (__ZN10MemoryPool8AllocateEj($20,20)|0);
 $22 = $2;
 $23 = (($21) + 16|0);
 $24 = HEAP32[$__v>>2]|0;
 HEAP32[$23>>2] = $24;
 HEAP32[$agg$result>>2] = $21;
 $25 = (($agg$result) + 4|0);
 $26 = $25;
 $27 = $26;
 HEAP32[$27>>2] = $22;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = 1;
 STACKTOP = sp;return;
}
function __Z22RegisterClass_Rendererv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(25,129,130,131,132);
 STACKTOP = sp;return;
}
function __ZN8Renderer13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(2)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity9Component13RegisterClassEv();
 }
 HEAP8[$0>>0] = 16;
 $3 = (($0) + 1|0);
 $4 = $3;
 $5 = $4;
 HEAP8[$5>>0]=1684956498&255;HEAP8[$5+1>>0]=(1684956498>>8)&255;HEAP8[$5+2>>0]=(1684956498>>16)&255;HEAP8[$5+3>>0]=1684956498>>24;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP8[$7>>0]=1919251045&255;HEAP8[$7+1>>0]=(1919251045>>8)&255;HEAP8[$7+2>>0]=(1919251045>>16)&255;HEAP8[$7+3>>0]=1919251045>>24;
 $8 = (($0) + 9|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,25,2,($0|0),284,(2400|0),1,0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return;
 }
}
function __ZN8Renderer15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(25,564104,1744,100000);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(25,564552,1745,0);
 __Z43InitializeRendererAnimationBindingInterfacev();
 STACKTOP = sp;return;
}
function __ZN8Renderer19PostInitializeClassEv() {
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(72,$$byval_copy5,1,16,605432,1111)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1629,($3|0),($$byval_copy5|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy5|0),1,16,(605432|0),1111);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch(0|0)|0;
   $11 = tempRet0;
   ___clang_call_terminate($10);
   // unreachable;
  } else {
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $12 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 4095]($12);
 $16 = HEAP32[$12>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($12,4);
 $19 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $19;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 $20 = (__Znwj10MemLabelIdbiPKci(160,$$byval_copy5,1,16,605432,1111)|0);
 HEAP32[$1>>2] = $19;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1746,($20|0),($$byval_copy5|0),0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  $29 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($20)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 24|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vi[$32 & 4095]($29);
  $33 = HEAP32[$29>>2]|0;
  $34 = (($33) + 12|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vii[$35 & 4095]($29,4);
  HEAP32[605184>>2] = $29;
  __ZN5Unity10GameObject20AddComponentInternalERS0_RNS_9ComponentE($12,$29);
  $36 = HEAP32[$12>>2]|0;
  $37 = (($36) + 44|0);
  $38 = HEAP32[$37>>2]|0;
  FUNCTION_TABLE_vii[$38 & 4095]($12,61);
  STACKTOP = sp;return;
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($20|0),($$byval_copy5|0),1,16,(605432|0),1111);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZN8Renderer12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[605184>>2] = 0;
 __Z40CleanupRendererAnimationBindingInterfacev();
 STACKTOP = sp;return;
}
function __ZN8Renderer7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK8Renderer25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 25;
}
function __ZN8Renderer23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605168,605152,$this,0);
 __ZN8Renderer8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Renderer23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605168,605152,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN8Renderer8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Renderer23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Renderer23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Renderer23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Renderer23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8RendererC2E12RendererType10MemLabelId18ObjectCreationMode($this,$type,$label,$mode) {
 $this = $this|0;
 $type = $type|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy13 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0;
 var $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy13 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy13,$mode);
 $3 = (($this) + 28|0);
 __THREW__ = 0;
 invoke_vii(2629,($3|0),($type|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   $$2 = $32;$$23 = $31;$$pre$phiZ2D = $this;
   label = 11;
  } else {
   HEAP32[$this>>2] = ((605192 + 8|0));
   $6 = (($this) + 28|0);
   HEAP32[$6>>2] = ((605192 + 172|0));
   $7 = (($this) + 216|0);
   HEAP32[$7>>2] = -1;
   __THREW__ = 0;
   $8 = (invoke_ii(3223,($this|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $33 = ___cxa_find_matching_catch()|0;
    $34 = tempRet0;
    $$1 = $34;$$12 = $33;
   } else {
    $11 = (($this) + 220|0);
    HEAP32[$11>>2] = 0;
    $12 = (($this) + 224|0);
    HEAP32[$12>>2] = $8;
    $13 = (($this) + 228|0);
    HEAP32[$13>>2] = 0;
    $14 = (($this) + 232|0);
    HEAP32[$14>>2] = 0;
    __THREW__ = 0;
    $15 = (invoke_ii(3223,($this|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = (($this) + 236|0);
     HEAP32[$18>>2] = 0;
     $19 = (($this) + 240|0);
     HEAP32[$19>>2] = $15;
     $20 = (($this) + 244|0);
     $21 = (($this) + 268|0);
     ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;HEAP32[$20+16>>2]=0|0;HEAP32[$20+20>>2]=0|0;
     HEAP32[$21>>2] = $this;
     $22 = (($this) + 272|0);
     HEAP8[$22>>0] = 1;
     $23 = (($this) + 273|0);
     HEAP8[$23>>0] = 1;
     $24 = (($this) + 276|0);
     $25 = (($this) + 204|0);
     $26 = $24;
     $27 = $26;
     HEAP32[$27>>2] = 0;
     $28 = (($26) + 4)|0;
     $29 = $28;
     HEAP32[$29>>2] = 0;
     HEAP32[$25>>2] = 1;
     $30 = (($this) + 72|0);
     HEAP32[$30>>2] = 1;
     STACKTOP = sp;return;
    }
    $35 = ___cxa_find_matching_catch()|0;
    $36 = tempRet0;
    $37 = HEAP32[$14>>2]|0;
    $38 = ($37|0)>(-1);
    if ($38) {
     $39 = HEAP32[$11>>2]|0;
     $40 = HEAP32[$12>>2]|0;
     HEAP32[$0>>2] = $40;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($39|0),($$byval_copy13|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     HEAP32[$11>>2] = 0;
     $$1 = $36;$$12 = $35;
    } else {
     $$1 = $36;$$12 = $35;
    }
   }
   __THREW__ = 0;
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    $$2 = $$1;$$23 = $$12;$$pre$phiZ2D = $this;
    label = 11;
   }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   HEAP32[$$pre$phiZ2D>>2] = ((562072 + 8|0));
   __THREW__ = 0;
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    HEAP32[$$pre$phiZ2D>>2] = ((560936 + 8|0));
    __THREW__ = 0;
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if (!($48)) {
     __THREW__ = 0;
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     ___resumeException($$23|0);
     // unreachable;
    }
    $49 = ___cxa_find_matching_catch(0|0)|0;
    $50 = tempRet0;
    __THREW__ = 0;
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     $53 = ___cxa_find_matching_catch(0|0)|0;
     $54 = tempRet0;
     ___clang_call_terminate($53);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $49;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $57 = ___cxa_find_matching_catch(0|0)|0;
   $58 = tempRet0;
   HEAP32[$$pre$phiZ2D>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $63 = ___cxa_find_matching_catch(0|0)|0;
    $64 = tempRet0;
    __THREW__ = 0;
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     $67 = ___cxa_find_matching_catch(0|0)|0;
     $68 = tempRet0;
     ___clang_call_terminate($67);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $63;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if (!($62)) {
    $eh$lpad$body$indexZ2D = $57;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $69 = ___cxa_find_matching_catch(0|0)|0;
   $70 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $69;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 $71 = ___cxa_find_matching_catch(0|0)|0;
 $72 = tempRet0;
 $eh$lpad$body$indexZ2D = $71;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN8Renderer10SmartResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 228|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(1);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 220|0);
 HEAP32[$0>>2] = 0;
 __ZN13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EE18resize_initializedEjRKS3_b($4,1,$0,0);
 __ZN8Renderer17HealSubsetIndicesEv($this);
 __ZN8Renderer13BoundsChangedEv($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Renderer18ClearPropertyBlockEv($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer18ClearPropertyBlockEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 196|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK6Object14GetMemoryLabelEv($this)|0);
 $6 = ($4|0)==(0|0);
 if (!($6)) {
  $7 = (($4) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)>(-1);
  do {
   if ($9) {
    $10 = (($4) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($4) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$1>>2] = $13;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($11|0),($$byval_copy3|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     HEAP32[$10>>2] = 0;
     break;
    }
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $24 = (($4) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)>(-1);
    if (!($26)) {
     ___resumeException($22|0);
     // unreachable;
    }
    $27 = HEAP32[$4>>2]|0;
    $28 = (($4) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$0>>2] = $29;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy3|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     $32 = ___cxa_find_matching_catch(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    }
    HEAP32[$4>>2] = 0;
    ___resumeException($22|0);
    // unreachable;
   }
  } while(0);
  $16 = (($4) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)>(-1);
  if ($18) {
   $19 = HEAP32[$4>>2]|0;
   $20 = (($4) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$0>>2] = $21;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy3);
   HEAP32[$4>>2] = 0;
  }
 }
 HEAP32[$2>>2] = $5;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($4,$$byval_copy3);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN8Renderer17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 264|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (($this) + 256|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 __ZN8LODGroup25RemoveFromCachedRenderersEP8Renderer($9,$this);
 STACKTOP = sp;return;
}
function __ZZN8Renderer15InitializeClassEvEN38FunctorImpl_Renderer_kTransformChanged4CallEPviR11MessageData($object,$messageID,$messageData) {
 $object = $object|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($object) + 76|0);
 HEAP8[$0>>0] = 1;
 __ZN8Renderer13BoundsChangedEv($object);
 STACKTOP = sp;return;
}
function __ZZN8Renderer15InitializeClassEvEN34FunctorImpl_Renderer_kLayerChanged4CallE_0PviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($object) + 216|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__ZN5Unity8GetSceneEv()|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = HEAP32[$object>>2]|0;
 $8 = (($7) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($object)|0);
 $11 = (($5) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12) + (($6*24)|0)|0) + 4|0);
 HEAP32[$13>>2] = $10;
 STACKTOP = sp;return;
}
function __ZNK8Renderer16IsVisibleInSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 71|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN8Renderer21RendererBecameVisibleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i = sp;
 $0 = (($this) + 71|0);
 HEAP8[$0>>0] = 1;
 __ZN6Object11InvokeEventEi($this,0);
 $1 = (($data$i) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($data$i) + 4|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$data$i>>2] = 0;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,564688,$data$i);
 STACKTOP = sp;return;
}
function __ZThn28_N8Renderer21RendererBecameVisibleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $data$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i = sp;
 $0 = (($this) + -28|0);
 $1 = (($0) + 71|0);
 HEAP8[$1>>0] = 1;
 __ZN6Object11InvokeEventEi($0,0);
 $2 = (($data$i$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($data$i$i) + 4|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$data$i$i>>2] = 0;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($0,564688,$data$i$i);
 STACKTOP = sp;return;
}
function __ZN8Renderer23RendererBecameInvisibleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i = sp;
 $0 = (($this) + 71|0);
 HEAP8[$0>>0] = 0;
 $1 = (($data$i) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($data$i) + 4|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$data$i>>2] = 0;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,564728,$data$i);
 __ZN6Object11InvokeEventEi($this,1);
 STACKTOP = sp;return;
}
function __ZThn28_N8Renderer23RendererBecameInvisibleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $data$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i$i = sp;
 $0 = (($this) + -28|0);
 $1 = (($0) + 71|0);
 HEAP8[$1>>0] = 0;
 $2 = (($data$i$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($data$i$i) + 4|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$data$i$i>>2] = 0;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($0,564728,$data$i$i);
 __ZN6Object11InvokeEventEi($0,1);
 STACKTOP = sp;return;
}
function __ZNK8Renderer8GetLayerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZThn28_NK8Renderer8GetLayerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN8Renderer10SetVisibleEb($this,$visible) {
 $this = $this|0;
 $visible = $visible|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $tmp = 0, $tmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 273|0);
 $1 = $visible&1;
 HEAP8[$0>>0] = $1;
 $2 = (($this) + 272|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $5 = $visible ^ 1;
 $or$cond = $4 | $5;
 if ($or$cond) {
  label = 3;
 } else {
  $6 = (($this) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   label = 3;
  } else {
   $12 = (__ZNK5Unity10GameObject8IsActiveEv($7)|0);
   $13 = (($this) + 216|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)!=(-1);
   $tmp = $12 ^ $15;
   if (!($tmp)) {
    STACKTOP = sp;return;
   }
   if ($12) {
    $27 = (($this) + 260|0);
    $28 = HEAP32[$27>>2]|0;
    $tmp$i = ($28|0)==(0|0);
    if (!($tmp$i)) {
     STACKTOP = sp;return;
    }
    $29 = HEAP32[((605176 + 4|0))>>2]|0;
    $30 = ($27|0)==($29|0);
    if ($30) {
     STACKTOP = sp;return;
    }
    $$pre$i$i$i = (($this) + 264|0);
    $31 = HEAP32[$29>>2]|0;
    HEAP32[$27>>2] = $31;
    HEAP32[$$pre$i$i$i>>2] = $29;
    $32 = (($31) + 4|0);
    HEAP32[$32>>2] = $27;
    $33 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$33>>2] = $27;
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 3) {
  $9 = (($this) + 216|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(-1);
  if ($11) {
   STACKTOP = sp;return;
  }
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = (($16) + 152|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($this);
 $19 = (($this) + 260|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = (($this) + 264|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($20) + 4|0);
  HEAP32[$24>>2] = $23;
  $25 = HEAP32[$19>>2]|0;
  $26 = HEAP32[$22>>2]|0;
  HEAP32[$26>>2] = $25;
  HEAP32[$19>>2] = 0;
  HEAP32[$22>>2] = 0;
 }
 __ZN6Object11InvokeEventEi($this,1);
 STACKTOP = sp;return;
}
function __ZN8Renderer13BoundsChangedEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 77|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 216|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__ZN5Unity8GetSceneEv()|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($5) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8) + (($6*24)|0)|0) + 21|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($5) + 96|0);
 $13 = (($5) + 104|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1)|0;
 HEAP32[$13>>2] = $15;
 $16 = (($5) + 108|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2147483647;
 $19 = ($15>>>0)>($18>>>0);
 if ($19) {
  $20 = $17 << 1;
  $21 = ($20|0)==(0);
  $22 = $21 ? 1 : $20;
  $23 = ($18>>>0)<($22>>>0);
  do {
   if ($23) {
    $24 = ($17|0)>(-1);
    if ($24) {
     HEAP32[$16>>2] = $22;
     $25 = HEAP32[$12>>2]|0;
     $26 = $22 << 2;
     $27 = (($5) + 100|0);
     $28 = HEAP32[$27>>2]|0;
     HEAP32[$0>>2] = $28;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $29 = (__Z16realloc_internalPvji10MemLabelIdiPKci($25,$26,4,$$byval_copy1,0,605432,370)|0);
     HEAP32[$12>>2] = $29;
     break;
    } else {
     $30 = $22 << 2;
     $31 = (($5) + 100|0);
     $32 = HEAP32[$31>>2]|0;
     HEAP32[$0>>2] = $32;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($30,4,$$byval_copy1,0,605432,352)|0);
     $34 = HEAP32[$12>>2]|0;
     $35 = HEAP32[$13>>2]|0;
     $36 = $35 << 2;
     _memcpy(($33|0),($34|0),($36|0))|0;
     HEAP32[$16>>2] = $22;
     HEAP32[$12>>2] = $33;
     break;
    }
   }
  } while(0);
  $$pre$i$i$i = HEAP32[$13>>2]|0;
  $38 = $$pre$i$i$i;
 } else {
  $38 = $15;
 }
 $37 = (($38) + -1)|0;
 $39 = HEAP32[$12>>2]|0;
 $40 = (($39) + ($37<<2)|0);
 HEAP32[$40>>2] = $6;
 HEAP8[$9>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN8Renderer26UpdateAllRenderersInternalEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((605176 + 4|0))>>2]|0;
 $1 = ($0|0)==(605176|0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $3 = $0;
 }
 while(1) {
  $2 = (($3) + 4|0);
  $4 = HEAP32[$2>>2]|0;
  $5 = (($3) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 260|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = (($6) + 264|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($8) + 4|0);
   HEAP32[$12>>2] = $11;
   $13 = HEAP32[$7>>2]|0;
   $14 = HEAP32[$10>>2]|0;
   HEAP32[$14>>2] = $13;
   HEAP32[$7>>2] = 0;
   HEAP32[$10>>2] = 0;
  }
  $15 = HEAP32[$6>>2]|0;
  $16 = (($15) + 144|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vi[$17 & 4095]($6);
  $18 = ($4|0)==(605176|0);
  if ($18) {
   break;
  } else {
   $3 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZN8Renderer23NotifySceneHandleChangeEi($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 216|0);
 HEAP32[$0>>2] = $handle;
 STACKTOP = sp;return;
}
function __ZN8Renderer17UpdateSceneHandleEv($this) {
 $this = $this|0;
 var $$lobit = 0, $$pre$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $lodGroup$i = 0, $lodIndexMask$i = 0, $phitmp$i = 0, $worldAABB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $lodGroup$i = sp + 32|0;
 $lodIndexMask$i = sp;
 $worldAABB = sp + 8|0;
 $0 = (($this) + 216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN5Unity8GetSceneEv()|0);
 ;HEAP32[$worldAABB+0>>2]=0|0;HEAP32[$worldAABB+4>>2]=0|0;HEAP32[$worldAABB+8>>2]=0|0;HEAP32[$worldAABB+12>>2]=0|0;HEAP32[$worldAABB+16>>2]=0|0;HEAP32[$worldAABB+20>>2]=0|0;
 $4 = (($this) + 28|0);
 __ZN12BaseRenderer12GetWorldAABBER4AABB($4,$worldAABB);
 $5 = HEAP32[$0>>2]|0;
 $6 = (($3) + 64|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + (($5*24)|0)|0);
 ;HEAP32[$8+0>>2]=HEAP32[$worldAABB+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$worldAABB+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$worldAABB+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$worldAABB+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$worldAABB+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$worldAABB+20>>2]|0;
 $9 = (($3) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10) + (($5*24)|0)|0) + 21|0);
 HEAP8[$11>>0] = 0;
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($10) + (($16*24)|0)|0) + 20|0);
 $18 = $15 >>> 4;
 $$lobit = $18 & 1;
 $19 = $$lobit&255;
 HEAP8[$17>>0] = $19;
 $20 = HEAP32[$this>>2]|0;
 $21 = (($20) + 116|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_ii[$22 & 4095]($this)|0);
 $24 = HEAP32[$9>>2]|0;
 $25 = ((($24) + (($16*24)|0)|0) + 4|0);
 HEAP32[$25>>2] = $23;
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==(-1);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (__ZN5Unity8GetSceneEv()|0);
 HEAP32[$lodGroup$i>>2] = 0;
 HEAP32[$lodIndexMask$i>>2] = 0;
 $29 = (($this) + 256|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $37 = 0;$39 = 0;
 } else {
  __ZN8LODGroup23GetLODGroupIndexAndMaskEP8RendererPjS2_($30,$this,$lodGroup$i,$lodIndexMask$i);
  $$pre$i = HEAP32[$lodGroup$i>>2]|0;
  $$pre1$i = HEAP32[$lodIndexMask$i>>2]|0;
  $phitmp$i = $$pre$i&65535;
  $37 = $phitmp$i;$39 = $$pre1$i;
 }
 $32 = HEAP32[$0>>2]|0;
 $33 = (($28) + 48|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ((($34) + (($32*24)|0)|0) + 12|0);
 HEAP16[$35>>1] = 0;
 $36 = ((($34) + (($32*24)|0)|0) + 14|0);
 HEAP16[$36>>1] = $37;
 $38 = ((($34) + (($32*24)|0)|0) + 16|0);
 HEAP32[$38>>2] = $39;
 STACKTOP = sp;return;
}
function __ZN8Renderer19UpdateTransformInfoEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN8Renderer12GetTransformEv($this)|0);
 $1 = (($this) + 76|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 80|0);
  $5 = (__ZNK9Transform24CalculateTransformMatrixER10Matrix4x4f($0,$4)|0);
  $6 = (($this) + 192|0);
  HEAP32[$6>>2] = $5;
 }
 $7 = (($this) + 77|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = HEAP32[$this>>2]|0;
  $11 = (($10) + 124|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($this);
 }
 $13 = (($this) + 168|0);
 $14 = (($this) + 80|0);
 $15 = (($this) + 144|0);
 __Z13TransformAABBRK4AABBRK10Matrix4x4fRS_($13,$14,$15);
 STACKTOP = sp;return;
}
function __ZN8Renderer12GetTransformEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0;
 var $9 = 0, $phitmp$i = 0, $pos$i$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 244|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($this) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($6)|0);
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 252|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 do {
  if (!($10)) {
   HEAP32[$0>>2] = $9;
   $11 = HEAP32[560624>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    label = 12;
   } else {
    $13 = (($11) + 36|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($11) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($14|0)==($16|0);
    do {
     if ($17) {
      $18 = (($11) + 28|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = (($11) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $38 = $22;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$11,$0);
      $23 = HEAP32[$pos$i$i$i$i$i>>2]|0;
      $24 = ($23|0)==(-1);
      $25 = (($11) + 28|0);
      $26 = HEAP32[$25>>2]|0;
      if ($24) {
       $27 = (($11) + 32|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = (($26) + ($28<<3)|0);
       $38 = $29;
       break;
      } else {
       $30 = (($26) + ($23<<3)|0);
       $38 = $30;
       break;
      }
     }
    } while(0);
    $31 = HEAP32[560624>>2]|0;
    $32 = (($31) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($31) + 32|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($33) + ($35<<3)|0);
    $37 = ($38|0)==($36|0);
    if ($37) {
     label = 12;
    } else {
     $39 = (($38) + 4|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      label = 12;
     } else {
      $46 = $31;
     }
    }
   }
   if ((label|0) == 12) {
    $42 = HEAP32[$8>>2]|0;
    $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
    $phitmp$i = ($43|0)==(0|0);
    if ($phitmp$i) {
     break;
    }
    $$pre = HEAP32[560624>>2]|0;
    $46 = $$pre;
   }
   $44 = HEAP32[$8>>2]|0;
   HEAP32[$1>>2] = $44;
   $45 = ($46|0)==(0|0);
   if ($45) {
    label = 22;
   } else {
    $47 = (($46) + 36|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($48|0)==($50|0);
    do {
     if ($51) {
      $52 = (($46) + 28|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (($46) + 32|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = (($53) + ($55<<3)|0);
      $72 = $56;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$46,$1);
      $57 = HEAP32[$pos$i$i$i$i$i>>2]|0;
      $58 = ($57|0)==(-1);
      $59 = (($46) + 28|0);
      $60 = HEAP32[$59>>2]|0;
      if ($58) {
       $61 = (($46) + 32|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($60) + ($62<<3)|0);
       $72 = $63;
       break;
      } else {
       $64 = (($60) + ($57<<3)|0);
       $72 = $64;
       break;
      }
     }
    } while(0);
    $65 = HEAP32[560624>>2]|0;
    $66 = (($65) + 28|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($65) + 32|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($67) + ($69<<3)|0);
    $71 = ($72|0)==($70|0);
    if ($71) {
     label = 22;
    } else {
     $73 = (($72) + 4|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==(0|0);
     if ($75) {
      label = 22;
     } else {
      $temp$0$i = $74;
     }
    }
   }
   if ((label|0) == 22) {
    $76 = HEAP32[$8>>2]|0;
    $77 = (__Z31ReadObjectFromPersistentManageri($76)|0);
    $temp$0$i = $77;
   }
   $$0 = $temp$0$i;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $78 = HEAP32[605184>>2]|0;
 $$0 = $78;
 STACKTOP = sp;return ($$0|0);
}
function __ZThn28_N8Renderer19UpdateTransformInfoEv($this) {
 $this = $this|0;
 var $$c = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -28|0);
 $1 = (__ZN8Renderer12GetTransformEv($0)|0);
 $2 = (($0) + 76|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = (($0) + 80|0);
  $6 = (__ZNK9Transform24CalculateTransformMatrixER10Matrix4x4f($1,$5)|0);
  $7 = (($0) + 192|0);
  $$c = $6;
  HEAP32[$7>>2] = $$c;
 }
 $8 = (($0) + 77|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = HEAP32[$0>>2]|0;
  $12 = (($11) + 124|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($0);
 }
 $14 = (($0) + 168|0);
 $15 = (($0) + 80|0);
 $16 = (($0) + 144|0);
 __Z13TransformAABBRK4AABBRK10Matrix4x4fRS_($14,$15,$16);
 STACKTOP = sp;return;
}
function __ZN8Renderer14UpdateRendererEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 272|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  label = 4;
 } else {
  $3 = (($this) + 273|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   label = 4;
  } else {
   $6 = (($this) + 24|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 4;
   } else {
    $10 = (__ZNK5Unity10GameObject8IsActiveEv($7)|0);
    $11 = HEAP32[$this>>2]|0;
    if ($10) {
     $12 = (($11) + 148|0);
     $13 = HEAP32[$12>>2]|0;
     FUNCTION_TABLE_vi[$13 & 4095]($this);
     __ZN8Renderer17UpdateSceneHandleEv($this);
     STACKTOP = sp;return;
    } else {
     $15 = $11;
    }
   }
  }
 }
 if ((label|0) == 4) {
  $9 = HEAP32[$this>>2]|0;
  $15 = $9;
 }
 $14 = (($15) + 152|0);
 $16 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$16 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer36GetPropertyBlockRememberToUpdateHashEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $15 = $2;
  STACKTOP = sp;return ($15|0);
 }
 $4 = (__ZNK6Object14GetMemoryLabelEv($this)|0);
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__Znwj10MemLabelIdbiPKci(36,$$byval_copy,0,16,605432,307)|0);
 HEAP32[$5>>2] = 0;
 $6 = (($5) + 4|0);
 HEAP32[$6>>2] = $4;
 $7 = (($5) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($5) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = (($5) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = (($5) + 20|0);
 HEAP32[$10>>2] = $4;
 $11 = (($5) + 24|0);
 HEAP32[$11>>2] = 0;
 $12 = (($5) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($5) + 32|0);
 $14 = HEAP32[641904>>2]|0;
 HEAP32[$13>>2] = $14;
 HEAP32[$1>>2] = $5;
 $15 = $5;
 STACKTOP = sp;return ($15|0);
}
function __ZN8Renderer10DeactivateEN5Unity19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 152|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 $3 = (($this) + 260|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 264|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$6>>2]|0;
 HEAP32[$10>>2] = $9;
 HEAP32[$3>>2] = 0;
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EE18resize_initializedEjRKS3_b($this,$size,$t,$double_on_resize) {
 $this = $this|0;
 $size = $size|0;
 $t = $t|0;
 $double_on_resize = $double_on_resize|0;
 var $$01$i = 0, $$byval_copy1 = 0, $$size = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $requested_size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)<($size>>>0);
 do {
  if ($4) {
   if ($double_on_resize) {
    $5 = $2 << 1;
    $6 = ($5>>>0)>($size>>>0);
    $$size = $6 ? $5 : $size;
    $requested_size$0 = $$size;
   } else {
    $requested_size$0 = $size;
   }
   $7 = ($3>>>0)<($requested_size$0>>>0);
   if ($7) {
    $8 = ($2|0)>(-1);
    if ($8) {
     HEAP32[$1>>2] = $requested_size$0;
     $9 = HEAP32[$this>>2]|0;
     $10 = $requested_size$0 << 2;
     $11 = (($this) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     HEAP32[$0>>2] = $12;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($9,$10,4,$$byval_copy1,0,605432,370)|0);
     HEAP32[$this>>2] = $13;
     break;
    } else {
     $14 = $requested_size$0 << 2;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,605432,352)|0);
     $18 = HEAP32[$this>>2]|0;
     $19 = (($this) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = $20 << 2;
     _memcpy(($17|0),($18|0),($21|0))|0;
     HEAP32[$1>>2] = $requested_size$0;
     HEAP32[$this>>2] = $17;
     break;
    }
   }
  }
 } while(0);
 $22 = (($this) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($size>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + ($size<<2)|0);
 $27 = ($23|0)==($size|0);
 if ($27) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $28 = (($25) + ($23<<2)|0);
 $$01$i = $28;
 while(1) {
  $29 = ($$01$i|0)==(0|0);
  if (!($29)) {
   $30 = HEAP32[$t>>2]|0;
   HEAP32[$$01$i>>2] = $30;
  }
  $31 = (($$01$i) + 4|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i = $31;
  }
 }
 HEAP32[$22>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN8Renderer17HealSubsetIndicesEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $q$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 236|0);
 $2 = (($this) + 244|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($3|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $6;
 $8 = (($this) + 248|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($10>>>0)<($6>>>0);
 do {
  if ($11) {
   $12 = ($9|0)>(-1);
   if ($12) {
    HEAP32[$8>>2] = $6;
    $13 = HEAP32[$1>>2]|0;
    $14 = $6 << 2;
    $15 = (($this) + 240|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,605432,370)|0);
    HEAP32[$1>>2] = $17;
    break;
   } else {
    $18 = $6 << 2;
    $19 = (($this) + 240|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,605432,352)|0);
    $22 = HEAP32[$1>>2]|0;
    $23 = HEAP32[$2>>2]|0;
    $24 = $23 << 2;
    _memcpy(($21|0),($22|0),($24|0))|0;
    HEAP32[$8>>2] = $6;
    HEAP32[$1>>2] = $21;
    break;
   }
  }
 } while(0);
 $25 = HEAP32[$2>>2]|0;
 $26 = ($3>>>0)<($25>>>0);
 if ($26) {
  $27 = HEAP32[$1>>2]|0;
  $q$01 = $3;
  while(1) {
   $28 = (($27) + ($q$01<<2)|0);
   HEAP32[$28>>2] = $q$01;
   $29 = (($q$01) + 1)|0;
   $30 = HEAP32[$2>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    $q$01 = $29;
   } else {
    break;
   }
  }
 }
 __ZN8Renderer13BoundsChangedEv($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer10AddToSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN5Unity8GetSceneEv()|0);
 $4 = (__ZN5Unity5Scene11AddRendererEP8Renderer($3,$this)|0);
 HEAP32[$0>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN8Renderer15RemoveFromSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 71|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = (__ZN5Unity8GetSceneEv()|0);
 $7 = HEAP32[$0>>2]|0;
 (__ZN5Unity5Scene14RemoveRendererEi($6,$7)|0);
 HEAP32[$0>>2] = -1;
 if ($5) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 112|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vi[$10 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer16CheckConsistencyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component16CheckConsistencyEv($this);
 __ZN8Renderer17HealSubsetIndicesEv($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer18ClearSubsetIndicesEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 248|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (($this) + 236|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 240|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy);
  HEAP32[$4>>2] = 0;
 }
 $8 = (($this) + 244|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$1>>2] = 0;
 __ZN8Renderer13BoundsChangedEv($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer14SetSubsetIndexEii($this,$index,$subsetIndex) {
 $this = $this|0;
 $index = $index|0;
 $subsetIndex = $subsetIndex|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $q$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 236|0);
 $2 = (($this) + 244|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($this) + 228|0);
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$2>>2] = $6;
  $7 = (($this) + 248|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 2147483647;
  $10 = ($9>>>0)<($6>>>0);
  do {
   if ($10) {
    $11 = ($8|0)>(-1);
    if ($11) {
     HEAP32[$7>>2] = $6;
     $12 = HEAP32[$1>>2]|0;
     $13 = $6 << 2;
     $14 = (($this) + 240|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$0>>2] = $15;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $16 = (__Z16realloc_internalPvji10MemLabelIdiPKci($12,$13,4,$$byval_copy1,0,605432,370)|0);
     HEAP32[$1>>2] = $16;
     break;
    } else {
     $17 = $6 << 2;
     $18 = (($this) + 240|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$0>>2] = $19;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($17,4,$$byval_copy1,0,605432,352)|0);
     $21 = HEAP32[$1>>2]|0;
     $22 = HEAP32[$2>>2]|0;
     $23 = $22 << 2;
     _memcpy(($20|0),($21|0),($23|0))|0;
     HEAP32[$7>>2] = $6;
     HEAP32[$1>>2] = $20;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[$5>>2]|0;
  $25 = ($24|0)==(0);
  if (!($25)) {
   $26 = HEAP32[$1>>2]|0;
   $q$01 = 0;
   while(1) {
    $27 = (($26) + ($q$01<<2)|0);
    HEAP32[$27>>2] = $q$01;
    $28 = (($q$01) + 1)|0;
    $29 = HEAP32[$5>>2]|0;
    $30 = ($28>>>0)<($29>>>0);
    if ($30) {
     $q$01 = $28;
    } else {
     break;
    }
   }
  }
 }
 $31 = ($index|0)>(-1);
 if (!($31)) {
  __ZN8Renderer13BoundsChangedEv($this);
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$2>>2]|0;
 $33 = ($32|0)>($index|0);
 if (!($33)) {
  __ZN8Renderer13BoundsChangedEv($this);
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$1>>2]|0;
 $35 = (($34) + ($index<<2)|0);
 HEAP32[$35>>2] = $subsetIndex;
 __ZN8Renderer13BoundsChangedEv($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer11SetMaterialE4PPtrIN5Unity8MaterialEEi($this,$material,$index) {
 $this = $this|0;
 $material = $material|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 220|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$material>>2]|0;
 $3 = (($1) + ($index<<2)|0);
 HEAP32[$3>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN8Renderer32GetAndAssignInstantiatedMaterialEib($this,$i,$allowFromEditMode) {
 $this = $this|0;
 $i = $i|0;
 $allowFromEditMode = $allowFromEditMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $material$0 = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($this)|0);
 $7 = ($6|0)>($i|0);
 if ($7) {
  $8 = HEAP32[$this>>2]|0;
  $9 = (($8) + 132|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_viii[$10 & 4095]($2,$this,$i);
  $11 = HEAP32[$2>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $material$0 = 0;
  } else {
   HEAP32[$1>>2] = $11;
   $13 = HEAP32[560624>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    label = 11;
   } else {
    $15 = (($13) + 36|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($13) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($16|0)==($18|0);
    do {
     if ($19) {
      $20 = (($13) + 28|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($13) + 32|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = (($21) + ($23<<3)|0);
      $40 = $24;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($0,$13,$1);
      $25 = HEAP32[$0>>2]|0;
      $26 = ($25|0)==(-1);
      $27 = (($13) + 28|0);
      $28 = HEAP32[$27>>2]|0;
      if ($26) {
       $29 = (($13) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = (($28) + ($30<<3)|0);
       $40 = $31;
       break;
      } else {
       $32 = (($28) + ($25<<3)|0);
       $40 = $32;
       break;
      }
     }
    } while(0);
    $33 = HEAP32[560624>>2]|0;
    $34 = (($33) + 28|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($33) + 32|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($35) + ($37<<3)|0);
    $39 = ($40|0)==($38|0);
    if ($39) {
     label = 11;
    } else {
     $41 = (($40) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0|0);
     if ($43) {
      label = 11;
     } else {
      $temp$0$i = $42;
     }
    }
   }
   if ((label|0) == 11) {
    $44 = HEAP32[$2>>2]|0;
    $45 = (__Z31ReadObjectFromPersistentManageri($44)|0);
    $temp$0$i = $45;
   }
   $material$0 = $temp$0$i;
  }
 } else {
  $material$0 = 0;
 }
 $46 = (__ZN5Unity8Material23GetInstantiatedMaterialEPS0_R6Objectb($material$0,$this,$allowFromEditMode)|0);
 $47 = ($material$0|0)==($46|0);
 if ($47) {
  STACKTOP = sp;return ($46|0);
 }
 $48 = HEAP32[$this>>2]|0;
 $49 = (($48) + 128|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (FUNCTION_TABLE_ii[$50 & 4095]($this)|0);
 $52 = (($i) + 1)|0;
 $53 = ($51|0)<($52|0);
 $54 = $53 ? $52 : $51;
 $55 = (($this) + 228|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==($54|0);
 if (!($57)) {
  $58 = (($this) + 220|0);
  HEAP32[$0>>2] = 0;
  __ZN13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EE18resize_initializedEjRKS3_b($58,$54,$0,0);
  __ZN8Renderer17HealSubsetIndicesEv($this);
  __ZN8Renderer13BoundsChangedEv($this);
 }
 $59 = ($46|0)==(0|0);
 if ($59) {
  $65 = 0;
 } else {
  $60 = (($46) + 4|0);
  $61 = HEAP32[$60>>2]|0;
  $65 = $61;
 }
 $62 = (($this) + 220|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + ($i<<2)|0);
 HEAP32[$64>>2] = $65;
 STACKTOP = sp;return ($46|0);
}
function __ZN8Renderer13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $awakeMode & 1;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($this) + 273|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)!=(0);
  __ZN8Renderer10SetVisibleEb($this,$4);
 }
 $5 = $awakeMode & 13;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (__Z13GetTagManagerv()|0);
  $8 = (($this) + 276|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__ZN10TagManager32GetSortingLayerValueFromUniqueIDEi($7,$9)|0);
  $11 = $10&65535;
  $12 = (($this) + 282|0);
  HEAP16[$12>>1] = $11;
 }
 $13 = (($this) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   $16 = (($this) + 260|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    $37 = $17;$39 = $16;
    label = 14;
   }
  } else {
   $19 = (__ZNK5Unity10GameObject8IsActiveEv($14)|0);
   $20 = (($this) + 260|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)!=(0|0);
   $tmp$i = $22 ^ $19;
   if ($tmp$i) {
    if (!($19)) {
     $33 = ($21|0)==(0|0);
     if ($33) {
      break;
     } else {
      $37 = $21;$39 = $20;
      label = 14;
      break;
     }
    }
    $23 = HEAP32[((605176 + 4|0))>>2]|0;
    $24 = ($20|0)==($23|0);
    if (!($24)) {
     $25 = ($21|0)==(0|0);
     $$pre$i$i$i = (($this) + 264|0);
     if (!($25)) {
      $26 = HEAP32[$$pre$i$i$i>>2]|0;
      $27 = (($21) + 4|0);
      HEAP32[$27>>2] = $26;
      $28 = HEAP32[$20>>2]|0;
      $29 = HEAP32[$$pre$i$i$i>>2]|0;
      HEAP32[$29>>2] = $28;
      HEAP32[$20>>2] = 0;
      HEAP32[$$pre$i$i$i>>2] = 0;
     }
     $30 = HEAP32[$23>>2]|0;
     HEAP32[$20>>2] = $30;
     HEAP32[$$pre$i$i$i>>2] = $23;
     $31 = (($30) + 4|0);
     HEAP32[$31>>2] = $20;
     $32 = HEAP32[$$pre$i$i$i>>2]|0;
     HEAP32[$32>>2] = $20;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $34 = (($this) + 264|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($37) + 4|0);
  HEAP32[$36>>2] = $35;
  $38 = HEAP32[$39>>2]|0;
  $40 = HEAP32[$34>>2]|0;
  HEAP32[$40>>2] = $38;
  HEAP32[$39>>2] = 0;
  HEAP32[$34>>2] = 0;
 }
 $41 = (($this) + 282|0);
 $42 = HEAP16[$41>>1]|0;
 $43 = (($this) + 280|0);
 $44 = HEAP16[$43>>1]|0;
 $45 = $42&65535;
 $46 = $45 << 16;
 $47 = $46 ^ -2147483648;
 $48 = $44 << 16 >> 16;
 $49 = (($48) + 32768)|0;
 $50 = $47 | $49;
 $51 = (($this) + 200|0);
 HEAP32[$51>>2] = $50;
 STACKTOP = sp;return;
}
function __ZN8Renderer26SupportedMessagesDidChangeEi($this,$mask) {
 $this = $this|0;
 $mask = $mask|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN5Unity8GetSceneEv()|0);
 $8 = HEAP32[$0>>2]|0;
 $9 = (($7) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10) + (($8*24)|0)|0) + 20|0);
 $12 = $6 >>> 4;
 $$lobit = $12 & 1;
 $13 = $$lobit&255;
 HEAP8[$11>>0] = $13;
 STACKTOP = sp;return;
}
function __ZN8Renderer19SetLightmapIndexIntEi12LightmapType($this,$index,$lightmapType) {
 $this = $this|0;
 $index = $index|0;
 $lightmapType = $lightmapType|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 64|0);
 $2 = (($1) + ($lightmapType<<1)|0);
 $3 = ($index|0)==(-1);
 if ($3) {
  HEAP16[$2>>1] = 255;
  STACKTOP = sp;return;
 }
 $4 = ($index>>>0)>(255);
 if (!($4)) {
  $26 = $index&65535;
  HEAP16[$2>>1] = $26;
  STACKTOP = sp;return;
 }
 HEAP16[$2>>1] = 255;
 HEAP32[$vararg_buffer>>2] = 255;
 __Z6FormatPKcz($0,605864,$vararg_buffer);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (($0) + 1|0);
  $11 = $10;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($11|0),0,(605432|0),60,1,0,0,(0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP8[$0>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   ___resumeException($19|0);
   // unreachable;
  }
  $24 = (($0) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  __ZdlPv($25);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   STACKTOP = sp;return;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  STACKTOP = sp;return;
 }
}
function __ZN8Renderer8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $localIdentifier$i$i$i1 = 0, $p$i$i = 0, $p$i$i$i = 0, $useLightProbes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i1 = sp;
 $p$i$i$i = sp + 20|0;
 $p$i$i = sp + 16|0;
 $useLightProbes = sp + 24|0;
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 272|0);
 $1 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605440,$1,$0,1);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 69|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605456,$1,$8,0);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 70|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605472,$1,$13,0);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $18 = (($this) + 64|0);
 $19 = HEAP32[580720>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605496,$19,$18,8388609);
 $20 = HEAP32[$2>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$5>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($18) + 2|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605512,$19,$24,8388609);
 $25 = HEAP32[$2>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$5>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 32|0);
 $30 = HEAP32[580784>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605536,$30,$29,8388609);
 __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($29,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $31 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605560,$30,$31,8388609);
 __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($31,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = (($this) + 220|0);
 $33 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605592,$33,$32,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,605840,605840,$p$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605784,605848,$p$i$i,0);
 $34 = (($localIdentifier$i$i$i1) + 8|0);
 $35 = $34;
 $36 = $35;
 HEAP32[$36>>2] = 0;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 $39 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605752,$39,$p$i$i,1);
 $40 = HEAP32[$2>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$5>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605768,$44,$34,1);
 $45 = HEAP32[$2>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$5>>2]|0;
 $48 = ((($46) + (($47*24)|0)|0) + 12|0);
 HEAP32[$48>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $49 = (($this) + 236|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605608,$33,$49,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,605840,605840,$localIdentifier$i$i$i1,0);
 $50 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605784,$50,$p$i$i$i,0);
 $51 = HEAP32[$2>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$5>>2]|0;
 $54 = ((($52) + (($53*24)|0)|0) + 12|0);
 HEAP32[$54>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $55 = (($this) + 252|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605624,605824,$55,1);
 $56 = (($localIdentifier$i$i$i1) + 8|0);
 $57 = $56;
 $58 = $57;
 HEAP32[$58>>2] = 0;
 $59 = (($57) + 4)|0;
 $60 = $59;
 HEAP32[$60>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605752,$39,$55,1);
 $61 = HEAP32[$2>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP32[$5>>2]|0;
 $64 = ((($62) + (($63*24)|0)|0) + 12|0);
 HEAP32[$64>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605768,$44,$56,1);
 $65 = HEAP32[$2>>2]|0;
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$5>>2]|0;
 $68 = ((($66) + (($67*24)|0)|0) + 12|0);
 HEAP32[$68>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $69 = (($this) + 204|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(1);
 $72 = $71&1;
 HEAP8[$useLightProbes>>0] = $72;
 $73 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605648,$73,$useLightProbes,0);
 $74 = HEAP32[$2>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 $76 = HEAP32[$5>>2]|0;
 $77 = ((($75) + (($76*24)|0)|0) + 12|0);
 HEAP32[$77>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $78 = HEAP8[$useLightProbes>>0]|0;
 $79 = $78&255;
 HEAP32[$69>>2] = $79;
 __ZN13ProxyTransfer5AlignEv($transfer);
 $80 = (($this) + 72|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605672,$39,$80,0);
 $81 = HEAP32[$2>>2]|0;
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$5>>2]|0;
 $84 = ((($82) + (($83*24)|0)|0) + 12|0);
 HEAP32[$84>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $85 = (($this) + 212|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605696,605824,$85,0);
 $86 = (($localIdentifier$i$i$i1) + 8|0);
 $87 = $86;
 $88 = $87;
 HEAP32[$88>>2] = 0;
 $89 = (($87) + 4)|0;
 $90 = $89;
 HEAP32[$90>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 $91 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605752,$91,$85,1);
 $92 = HEAP32[$2>>2]|0;
 $93 = HEAP32[$92>>2]|0;
 $94 = HEAP32[$5>>2]|0;
 $95 = ((($93) + (($94*24)|0)|0) + 12|0);
 HEAP32[$95>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $96 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605768,$96,$86,1);
 $97 = HEAP32[$2>>2]|0;
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$5>>2]|0;
 $100 = ((($98) + (($99*24)|0)|0) + 12|0);
 HEAP32[$100>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $101 = (($this) + 276|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605712,$91,$101,1);
 $102 = HEAP32[$2>>2]|0;
 $103 = HEAP32[$102>>2]|0;
 $104 = HEAP32[$5>>2]|0;
 $105 = ((($103) + (($104*24)|0)|0) + 12|0);
 HEAP32[$105>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $106 = (($this) + 280|0);
 $107 = HEAP32[580672>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,605736,$107,$106,1);
 $108 = HEAP32[$2>>2]|0;
 $109 = HEAP32[$108>>2]|0;
 $110 = HEAP32[$5>>2]|0;
 $111 = ((($109) + (($110*24)|0)|0) + 12|0);
 HEAP32[$111>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Renderer8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i16 = 0, $$sum$i$i$i$i$i2 = 0, $$sum$i$i$i$i$i7 = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i17 = 0, $$sum1$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i20 = 0, $useLightProbes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i20 = sp;
 $useLightProbes = sp + 4|0;
 __ZN5Unity9Component8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 272|0);
 $1 = HEAP32[580544>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605440,$1,$converter$i$i20,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  do {
   if ($4) {
    $5 = (($transfer) + 12|0);
    $6 = (($transfer) + 80|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($transfer) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($transfer) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($transfer) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = Math_imul($15, $13)|0;
    $$sum$i$i$i$i$i = (($9) - ($16))|0;
    $17 = (($11) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$5>>2] = $17;
    $18 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($18)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $19 = (($11) + ($$sum1$i$i$i$i$i)|0);
     $20 = (($transfer) + 20|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($19>>>0)>($21>>>0);
     if (!($22)) {
      $23 = HEAP8[$17>>0]|0;
      HEAP8[$0>>0] = $23;
      $24 = HEAP32[$5>>2]|0;
      $25 = (($24) + 1|0);
      HEAP32[$5>>2] = $25;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($5,$0,1);
   } else {
    $26 = HEAP32[$converter$i$i20>>2]|0;
    $27 = ($26|0)==(0|0);
    if (!($27)) {
     (FUNCTION_TABLE_iii[$26 & 4095]($0,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $28 = (($this) + 69|0);
 $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605456,$1,$converter$i$i20,0)|0);
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = ($29|0)>(0);
  do {
   if ($31) {
    $32 = (($transfer) + 12|0);
    $33 = (($transfer) + 80|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($transfer) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($transfer) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($transfer) + 32|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = Math_imul($42, $40)|0;
    $$sum$i$i$i$i$i2 = (($36) - ($43))|0;
    $44 = (($38) + ($$sum$i$i$i$i$i2)|0);
    HEAP32[$32>>2] = $44;
    $45 = ($$sum$i$i$i$i$i2|0)<(0);
    if (!($45)) {
     $$sum1$i$i$i$i$i3 = (($$sum$i$i$i$i$i2) + 1)|0;
     $46 = (($38) + ($$sum1$i$i$i$i$i3)|0);
     $47 = (($transfer) + 20|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($46>>>0)>($48>>>0);
     if (!($49)) {
      $50 = HEAP8[$44>>0]|0;
      HEAP8[$28>>0] = $50;
      $51 = HEAP32[$32>>2]|0;
      $52 = (($51) + 1|0);
      HEAP32[$32>>2] = $52;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($32,$28,1);
   } else {
    $53 = HEAP32[$converter$i$i20>>2]|0;
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     (FUNCTION_TABLE_iii[$53 & 4095]($28,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $55 = (($this) + 70|0);
 $56 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605472,$1,$converter$i$i20,0)|0);
 $57 = ($56|0)==(0);
 if (!($57)) {
  $58 = ($56|0)>(0);
  do {
   if ($58) {
    $59 = (($transfer) + 12|0);
    $60 = (($transfer) + 80|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61) + 12|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($transfer) + 16|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($transfer) + 28|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($transfer) + 32|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = Math_imul($69, $67)|0;
    $$sum$i$i$i$i$i7 = (($63) - ($70))|0;
    $71 = (($65) + ($$sum$i$i$i$i$i7)|0);
    HEAP32[$59>>2] = $71;
    $72 = ($$sum$i$i$i$i$i7|0)<(0);
    if (!($72)) {
     $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
     $73 = (($65) + ($$sum1$i$i$i$i$i8)|0);
     $74 = (($transfer) + 20|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = ($73>>>0)>($75>>>0);
     if (!($76)) {
      $77 = HEAP8[$71>>0]|0;
      HEAP8[$55>>0] = $77;
      $78 = HEAP32[$59>>2]|0;
      $79 = (($78) + 1|0);
      HEAP32[$59>>2] = $79;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($59,$55,1);
   } else {
    $80 = HEAP32[$converter$i$i20>>2]|0;
    $81 = ($80|0)==(0|0);
    if (!($81)) {
     (FUNCTION_TABLE_iii[$80 & 4095]($55,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $82 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$82,605496,0);
 $83 = (($82) + 2|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$83,605512,0);
 $84 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($transfer,$84,605536,0);
 $85 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($transfer,$85,605560,0);
 $86 = (($this) + 220|0);
 $87 = HEAP32[580760>>2]|0;
 $88 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605592,$87,$converter$i$i20,1)|0);
 $89 = ($88|0)==(0);
 if (!($89)) {
  $90 = ($88|0)>(0);
  if ($90) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EEEEvRT_17TransferMetaFlags($transfer,$86,0);
  } else {
   $91 = HEAP32[$converter$i$i20>>2]|0;
   $92 = ($91|0)==(0|0);
   if (!($92)) {
    (FUNCTION_TABLE_iii[$91 & 4095]($86,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $93 = (($this) + 236|0);
 $94 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605608,$87,$converter$i$i20,1)|0);
 $95 = ($94|0)==(0);
 if (!($95)) {
  $96 = ($94|0)>(0);
  if ($96) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$93,0);
  } else {
   $97 = HEAP32[$converter$i$i20>>2]|0;
   $98 = ($97|0)==(0|0);
   if (!($98)) {
    (FUNCTION_TABLE_iii[$97 & 4095]($93,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $99 = (($this) + 252|0);
 $100 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605624,605824,$converter$i$i20,1)|0);
 $101 = ($100|0)==(0);
 if (!($101)) {
  $102 = ($100|0)>(0);
  if ($102) {
   __ZN4PPtrI9TransformE8TransferI14SafeBinaryReadEEvRT_($99,$transfer);
  } else {
   $103 = HEAP32[$converter$i$i20>>2]|0;
   $104 = ($103|0)==(0|0);
   if (!($104)) {
    (FUNCTION_TABLE_iii[$103 & 4095]($99,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $105 = (($this) + 204|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($106|0)==(1);
 $108 = $107&1;
 HEAP8[$useLightProbes>>0] = $108;
 $109 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605648,$1,$converter$i$i20,0)|0);
 $110 = ($109|0)==(0);
 if (!($110)) {
  $111 = ($109|0)>(0);
  do {
   if ($111) {
    $112 = (($transfer) + 12|0);
    $113 = (($transfer) + 80|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = (($114) + 12|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (($transfer) + 16|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (($transfer) + 28|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = (($transfer) + 32|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = Math_imul($122, $120)|0;
    $$sum$i$i$i$i$i16 = (($116) - ($123))|0;
    $124 = (($118) + ($$sum$i$i$i$i$i16)|0);
    HEAP32[$112>>2] = $124;
    $125 = ($$sum$i$i$i$i$i16|0)<(0);
    if (!($125)) {
     $$sum1$i$i$i$i$i17 = (($$sum$i$i$i$i$i16) + 1)|0;
     $126 = (($118) + ($$sum1$i$i$i$i$i17)|0);
     $127 = (($transfer) + 20|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = ($126>>>0)>($128>>>0);
     if (!($129)) {
      $130 = HEAP8[$124>>0]|0;
      HEAP8[$useLightProbes>>0] = $130;
      $$sum = (($$sum$i$i$i$i$i16) + 1)|0;
      $131 = (($118) + ($$sum)|0);
      HEAP32[$112>>2] = $131;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($112,$useLightProbes,1);
   } else {
    $132 = HEAP32[$converter$i$i20>>2]|0;
    $133 = ($132|0)==(0|0);
    if (!($133)) {
     (FUNCTION_TABLE_iii[$132 & 4095]($useLightProbes,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $134 = HEAP8[$useLightProbes>>0]|0;
 $135 = $134&255;
 HEAP32[$105>>2] = $135;
 $136 = (($this) + 72|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$136,605672,0);
 $137 = (($this) + 212|0);
 $138 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605696,605824,$converter$i$i20,1)|0);
 $139 = ($138|0)==(0);
 if (!($139)) {
  $140 = ($138|0)>(0);
  if ($140) {
   __ZN4PPtrI9TransformE8TransferI14SafeBinaryReadEEvRT_($137,$transfer);
  } else {
   $141 = HEAP32[$converter$i$i20>>2]|0;
   $142 = ($141|0)==(0|0);
   if (!($142)) {
    (FUNCTION_TABLE_iii[$141 & 4095]($137,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $143 = (($this) + 276|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$143,605712,0);
 $144 = (($this) + 280|0);
 $145 = HEAP32[580672>>2]|0;
 $146 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,605736,$145,$converter$i$i20,0)|0);
 $147 = ($146|0)==(0);
 if ($147) {
  STACKTOP = sp;return;
 }
 $148 = ($146|0)>(0);
 if ($148) {
  $149 = (($transfer) + 12|0);
  $150 = (($transfer) + 80|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = (($151) + 12|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = (($transfer) + 16|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = (($transfer) + 28|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = (($transfer) + 32|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = Math_imul($159, $157)|0;
  $$sum$i$i$i = (($153) - ($160))|0;
  $161 = (($155) + ($$sum$i$i$i)|0);
  HEAP32[$149>>2] = $161;
  $162 = ($$sum$i$i$i|0)<(0);
  if ($162) {
   label = 66;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 2)|0;
   $163 = (($155) + ($$sum1$i$i$i)|0);
   $164 = (($transfer) + 20|0);
   $165 = HEAP32[$164>>2]|0;
   $166 = ($163>>>0)>($165>>>0);
   if ($166) {
    label = 66;
   } else {
    $167 = HEAP16[$161>>1]|0;
    HEAP16[$144>>1] = $167;
    HEAP32[$149>>2] = $163;
   }
  }
  if ((label|0) == 66) {
   __ZN12CachedReader15UpdateReadCacheEPvj($149,$144,2);
  }
  $168 = HEAP32[$transfer>>2]|0;
  $169 = $168 & 512;
  $170 = ($169|0)==(0);
  if (!($170)) {
   $171 = HEAP16[$144>>1]|0;
   $172 = $171&65535;
   $173 = $172 << 8;
   $174 = $172 >>> 8;
   $175 = $173 | $174;
   $176 = $175&65535;
   HEAP16[$144>>1] = $176;
  }
 } else {
  $177 = HEAP32[$converter$i$i20>>2]|0;
  $178 = ($177|0)==(0|0);
  if (!($178)) {
   (FUNCTION_TABLE_iii[$177 & 4095]($144,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580720>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  $5 = (($this) + 12|0);
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $13)|0;
  $$sum$i$i$i = (($9) - ($16))|0;
  $17 = (($11) + ($$sum$i$i$i)|0);
  HEAP32[$5>>2] = $17;
  $18 = ($$sum$i$i$i|0)<(0);
  if ($18) {
   label = 6;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 2)|0;
   $19 = (($11) + ($$sum1$i$i$i)|0);
   $20 = (($this) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19>>>0)>($21>>>0);
   if ($22) {
    label = 6;
   } else {
    $23 = HEAP16[$17>>1]|0;
    HEAP16[$data>>1] = $23;
    HEAP32[$5>>2] = $19;
   }
  }
  if ((label|0) == 6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,2);
  }
  $24 = HEAP32[$this>>2]|0;
  $25 = $24 & 512;
  $26 = ($25|0)==(0);
  if (!($26)) {
   $27 = HEAP16[$data>>1]|0;
   $28 = $27&65535;
   $29 = $28 << 8;
   $30 = $28 >>> 8;
   $31 = $29 | $30;
   $32 = $31&65535;
   HEAP16[$data>>1] = $32;
  }
 } else {
  $33 = HEAP32[$converter$i>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   (FUNCTION_TABLE_iii[$33 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580784>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$data,605792,0);
  $5 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$5,605800,0);
  $6 = (($data) + 8|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$6,605808,0);
  $7 = (($data) + 12|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$7,605816,0);
 } else {
  $8 = HEAP32[$converter$i>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   (FUNCTION_TABLE_iii[$8 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN8Renderer8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0;
 var $useLightProbes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $useLightProbes = sp;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 272|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
  $$pre = HEAP32[$1>>2]|0;
  $12 = $$pre;
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  $12 = $9;
 }
 $10 = (($this) + 69|0);
 $11 = (($12) + 1|0);
 $13 = HEAP32[$4>>2]|0;
 $14 = ($11>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,1);
  $$pre6 = HEAP32[$1>>2]|0;
  $20 = $$pre6;
 } else {
  $15 = HEAP8[$12>>0]|0;
  HEAP8[$10>>0] = $15;
  $16 = HEAP32[$1>>2]|0;
  $17 = (($16) + 1|0);
  HEAP32[$1>>2] = $17;
  $20 = $17;
 }
 $18 = (($this) + 70|0);
 $19 = (($20) + 1|0);
 $21 = HEAP32[$4>>2]|0;
 $22 = ($19>>>0)>($21>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$18,1);
 } else {
  $23 = HEAP8[$20>>0]|0;
  HEAP8[$18>>0] = $23;
  $24 = HEAP32[$1>>2]|0;
  $25 = (($24) + 1|0);
  HEAP32[$1>>2] = $25;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $26 = (($this) + 64|0);
 $27 = HEAP32[$1>>2]|0;
 $28 = (($27) + 2|0);
 $29 = HEAP32[$4>>2]|0;
 $30 = ($28>>>0)>($29>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,2);
  $$pre7 = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $34 = $$pre7;$36 = $$pre8;
 } else {
  $31 = HEAP16[$27>>1]|0;
  HEAP16[$26>>1] = $31;
  HEAP32[$1>>2] = $28;
  $34 = $28;$36 = $29;
 }
 $32 = (($26) + 2|0);
 $33 = (($34) + 2|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$32,2);
 } else {
  $37 = HEAP16[$34>>1]|0;
  HEAP16[$32>>1] = $37;
  HEAP32[$1>>2] = $33;
 }
 $38 = (($this) + 32|0);
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($38,$transfer);
 $39 = (($this) + 48|0);
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($39,$transfer);
 $40 = (($this) + 220|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EEEEvRT_17TransferMetaFlags($transfer,$40,0);
 $41 = (($this) + 236|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$41,0);
 $42 = (($this) + 252|0);
 __ZN4PPtrI9TransformE8TransferI18StreamedBinaryReadILb0EEEEvRT_($42,$transfer);
 $43 = (($this) + 204|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(1);
 $46 = $45&1;
 HEAP8[$useLightProbes>>0] = $46;
 $47 = HEAP32[$1>>2]|0;
 $48 = (($47) + 1|0);
 $49 = HEAP32[$4>>2]|0;
 $50 = ($48>>>0)>($49>>>0);
 if ($50) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$useLightProbes,1);
  $$pre9 = HEAP8[$useLightProbes>>0]|0;
  $53 = $$pre9;
 } else {
  $51 = HEAP8[$47>>0]|0;
  HEAP8[$useLightProbes>>0] = $51;
  HEAP32[$1>>2] = $48;
  $53 = $51;
 }
 $52 = $53&255;
 HEAP32[$43>>2] = $52;
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $54 = (($this) + 72|0);
 $55 = HEAP32[$1>>2]|0;
 $56 = (($55) + 4|0);
 $57 = HEAP32[$4>>2]|0;
 $58 = ($56>>>0)>($57>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$54,4);
 } else {
  $59 = HEAP32[$55>>2]|0;
  HEAP32[$54>>2] = $59;
  HEAP32[$1>>2] = $56;
 }
 $60 = (($this) + 212|0);
 __ZN4PPtrI9TransformE8TransferI18StreamedBinaryReadILb0EEEEvRT_($60,$transfer);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $61 = (($this) + 276|0);
 $62 = HEAP32[$1>>2]|0;
 $63 = (($62) + 4|0);
 $64 = HEAP32[$4>>2]|0;
 $65 = ($63>>>0)>($64>>>0);
 if ($65) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$61,4);
  $$pre10 = HEAP32[$1>>2]|0;
  $$pre11 = HEAP32[$4>>2]|0;
  $69 = $$pre10;$71 = $$pre11;
 } else {
  $66 = HEAP32[$62>>2]|0;
  HEAP32[$61>>2] = $66;
  HEAP32[$1>>2] = $63;
  $69 = $63;$71 = $64;
 }
 $67 = (($this) + 280|0);
 $68 = (($69) + 2|0);
 $70 = ($68>>>0)>($71>>>0);
 if ($70) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$67,2);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $72 = HEAP16[$69>>1]|0;
  HEAP16[$67>>1] = $72;
  HEAP32[$1>>2] = $68;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN8Renderer8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i7 = 0, $$pre$i$i$i8 = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $useLightProbes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $useLightProbes = sp;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 272|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
  $$pre = HEAP32[$1>>2]|0;
  $12 = $$pre;
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  $12 = $9;
 }
 $10 = (($this) + 69|0);
 $11 = (($12) + 1|0);
 $13 = HEAP32[$4>>2]|0;
 $14 = ($11>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,1);
  $$pre10 = HEAP32[$1>>2]|0;
  $20 = $$pre10;
 } else {
  $15 = HEAP8[$12>>0]|0;
  HEAP8[$10>>0] = $15;
  $16 = HEAP32[$1>>2]|0;
  $17 = (($16) + 1|0);
  HEAP32[$1>>2] = $17;
  $20 = $17;
 }
 $18 = (($this) + 70|0);
 $19 = (($20) + 1|0);
 $21 = HEAP32[$4>>2]|0;
 $22 = ($19>>>0)>($21>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$18,1);
 } else {
  $23 = HEAP8[$20>>0]|0;
  HEAP8[$18>>0] = $23;
  $24 = HEAP32[$1>>2]|0;
  $25 = (($24) + 1|0);
  HEAP32[$1>>2] = $25;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $26 = (($this) + 64|0);
 $27 = HEAP32[$1>>2]|0;
 $28 = (($27) + 2|0);
 $29 = HEAP32[$4>>2]|0;
 $30 = ($28>>>0)>($29>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,2);
  $$pre$i$i$i7 = HEAP16[$26>>1]|0;
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $33 = $$pre$i$i$i7;$40 = $$pre11;$42 = $$pre12;
 } else {
  $31 = HEAP16[$27>>1]|0;
  HEAP16[$26>>1] = $31;
  HEAP32[$1>>2] = $28;
  $33 = $31;$40 = $28;$42 = $29;
 }
 $32 = $33&65535;
 $34 = $32 << 8;
 $35 = $32 >>> 8;
 $36 = $34 | $35;
 $37 = $36&65535;
 HEAP16[$26>>1] = $37;
 $38 = (($26) + 2|0);
 $39 = (($40) + 2|0);
 $41 = ($39>>>0)>($42>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,2);
  $$pre$i$i$i8 = HEAP16[$38>>1]|0;
  $45 = $$pre$i$i$i8;
 } else {
  $43 = HEAP16[$40>>1]|0;
  HEAP16[$38>>1] = $43;
  HEAP32[$1>>2] = $39;
  $45 = $43;
 }
 $44 = $45&65535;
 $46 = $44 << 8;
 $47 = $44 >>> 8;
 $48 = $46 | $47;
 $49 = $48&65535;
 HEAP16[$38>>1] = $49;
 $50 = (($this) + 32|0);
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($50,$transfer);
 $51 = (($this) + 48|0);
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($51,$transfer);
 $52 = (($this) + 220|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EEEEvRT_17TransferMetaFlags($transfer,$52,0);
 $53 = (($this) + 236|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$53,0);
 $54 = (($this) + 252|0);
 __ZN4PPtrI9TransformE8TransferI18StreamedBinaryReadILb1EEEEvRT_($54,$transfer);
 $55 = (($this) + 204|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(1);
 $58 = $57&1;
 HEAP8[$useLightProbes>>0] = $58;
 $59 = HEAP32[$1>>2]|0;
 $60 = (($59) + 1|0);
 $61 = HEAP32[$4>>2]|0;
 $62 = ($60>>>0)>($61>>>0);
 if ($62) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$useLightProbes,1);
  $$pre13 = HEAP8[$useLightProbes>>0]|0;
  $65 = $$pre13;
 } else {
  $63 = HEAP8[$59>>0]|0;
  HEAP8[$useLightProbes>>0] = $63;
  HEAP32[$1>>2] = $60;
  $65 = $63;
 }
 $64 = $65&255;
 HEAP32[$55>>2] = $64;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $66 = (($this) + 72|0);
 $67 = HEAP32[$1>>2]|0;
 $68 = (($67) + 4|0);
 $69 = HEAP32[$4>>2]|0;
 $70 = ($68>>>0)>($69>>>0);
 if ($70) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$66,4);
  $$pre$i$i$i4 = HEAP32[$66>>2]|0;
  $72 = $$pre$i$i$i4;
 } else {
  $71 = HEAP32[$67>>2]|0;
  HEAP32[$66>>2] = $71;
  HEAP32[$1>>2] = $68;
  $72 = $71;
 }
 $73 = (_llvm_bswap_i32(($72|0))|0);
 HEAP32[$66>>2] = $73;
 $74 = (($this) + 212|0);
 __ZN4PPtrI9TransformE8TransferI18StreamedBinaryReadILb1EEEEvRT_($74,$transfer);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $75 = (($this) + 276|0);
 $76 = HEAP32[$1>>2]|0;
 $77 = (($76) + 4|0);
 $78 = HEAP32[$4>>2]|0;
 $79 = ($77>>>0)>($78>>>0);
 if ($79) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$75,4);
  $$pre$i$i$i3 = HEAP32[$75>>2]|0;
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $81 = $$pre$i$i$i3;$85 = $$pre14;$87 = $$pre15;
 } else {
  $80 = HEAP32[$76>>2]|0;
  HEAP32[$75>>2] = $80;
  HEAP32[$1>>2] = $77;
  $81 = $80;$85 = $77;$87 = $78;
 }
 $82 = (_llvm_bswap_i32(($81|0))|0);
 HEAP32[$75>>2] = $82;
 $83 = (($this) + 280|0);
 $84 = (($85) + 2|0);
 $86 = ($84>>>0)>($87>>>0);
 if ($86) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$83,2);
  $$pre$i$i$i = HEAP16[$83>>1]|0;
  $90 = $$pre$i$i$i;
  $89 = $90&65535;
  $91 = $89 << 8;
  $92 = $89 >>> 8;
  $93 = $91 | $92;
  $94 = $93&65535;
  HEAP16[$83>>1] = $94;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $88 = HEAP16[$85>>1]|0;
  HEAP16[$83>>1] = $88;
  HEAP32[$1>>2] = $84;
  $90 = $88;
  $89 = $90&65535;
  $91 = $89 << 8;
  $92 = $89 >>> 8;
  $93 = $91 | $92;
  $94 = $93&65535;
  HEAP16[$83>>1] = $94;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN8Renderer8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i$i$i = 0, $i$01$i$i$i8 = 0, $size$i$i$i6 = 0, $useLightProbes = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i6 = sp;
 $useLightProbes = sp + 4|0;
 __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 272|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP8[$0>>0]|0;
  HEAP8[$2>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
  $12 = $9;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,1);
  $$pre = HEAP32[$1>>2]|0;
  $12 = $$pre;
 }
 $10 = (($this) + 69|0);
 $11 = (($12) + 1|0);
 $13 = HEAP32[$4>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $15 = HEAP8[$10>>0]|0;
  HEAP8[$12>>0] = $15;
  $16 = HEAP32[$1>>2]|0;
  $17 = (($16) + 1|0);
  HEAP32[$1>>2] = $17;
  $20 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$10,1);
  $$pre10 = HEAP32[$1>>2]|0;
  $20 = $$pre10;
 }
 $18 = (($this) + 70|0);
 $19 = (($20) + 1|0);
 $21 = HEAP32[$4>>2]|0;
 $22 = ($19>>>0)<($21>>>0);
 if ($22) {
  $23 = HEAP8[$18>>0]|0;
  HEAP8[$20>>0] = $23;
  $24 = HEAP32[$1>>2]|0;
  $25 = (($24) + 1|0);
  HEAP32[$1>>2] = $25;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$18,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $26 = (($this) + 64|0);
 $27 = HEAP32[$1>>2]|0;
 $28 = (($27) + 2|0);
 $29 = HEAP32[$4>>2]|0;
 $30 = ($28>>>0)<($29>>>0);
 if ($30) {
  $31 = HEAP16[$26>>1]|0;
  HEAP16[$27>>1] = $31;
  HEAP32[$1>>2] = $28;
  $34 = $28;$36 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,2);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $34 = $$pre11;$36 = $$pre12;
 }
 $32 = (($26) + 2|0);
 $33 = (($34) + 2|0);
 $35 = ($33>>>0)<($36>>>0);
 if ($35) {
  $37 = HEAP16[$32>>1]|0;
  HEAP16[$34>>1] = $37;
  HEAP32[$1>>2] = $33;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$32,2);
 }
 $38 = (($this) + 32|0);
 __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($38,$transfer);
 $39 = (($this) + 48|0);
 __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($39,$transfer);
 $40 = (($this) + 228|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$size$i$i$i6>>2] = $41;
 $42 = HEAP32[$1>>2]|0;
 $43 = (($42) + 4|0);
 $44 = HEAP32[$4>>2]|0;
 $45 = ($43>>>0)<($44>>>0);
 if ($45) {
  HEAP32[$42>>2] = $41;
  HEAP32[$1>>2] = $43;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i6,4);
 }
 $46 = (($this) + 220|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$40>>2]|0;
 $49 = (($47) + ($48<<2)|0);
 $50 = ($48|0)==(0);
 if (!($50)) {
  $i$01$i$i$i8 = $47;
  while(1) {
   __ZN4PPtrIN5Unity8MaterialEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i8,$transfer);
   $51 = (($i$01$i$i$i8) + 4|0);
   $52 = ($51|0)==($49|0);
   if ($52) {
    break;
   } else {
    $i$01$i$i$i8 = $51;
   }
  }
 }
 $53 = (($this) + 244|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$size$i$i$i6>>2] = $54;
 $55 = HEAP32[$1>>2]|0;
 $56 = (($55) + 4|0);
 $57 = HEAP32[$4>>2]|0;
 $58 = ($56>>>0)<($57>>>0);
 if ($58) {
  HEAP32[$55>>2] = $54;
  HEAP32[$1>>2] = $56;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i6,4);
 }
 $59 = (($this) + 236|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$53>>2]|0;
 $62 = (($60) + ($61<<2)|0);
 $63 = ($61|0)==(0);
 if (!($63)) {
  $i$01$i$i$i = $60;
  while(1) {
   $64 = HEAP32[$1>>2]|0;
   $65 = (($64) + 4|0);
   $66 = HEAP32[$4>>2]|0;
   $67 = ($65>>>0)<($66>>>0);
   if ($67) {
    $68 = HEAP32[$i$01$i$i$i>>2]|0;
    HEAP32[$64>>2] = $68;
    HEAP32[$1>>2] = $65;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$i$01$i$i$i,4);
   }
   $69 = (($i$01$i$i$i) + 4|0);
   $70 = ($69|0)==($62|0);
   if ($70) {
    break;
   } else {
    $i$01$i$i$i = $69;
   }
  }
 }
 $71 = (($this) + 252|0);
 __ZN4PPtrI9TransformE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($71,$transfer);
 $72 = (($this) + 204|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(1);
 $75 = $74&1;
 HEAP8[$useLightProbes>>0] = $75;
 $76 = HEAP32[$1>>2]|0;
 $77 = (($76) + 1|0);
 $78 = HEAP32[$4>>2]|0;
 $79 = ($77>>>0)<($78>>>0);
 if ($79) {
  HEAP8[$76>>0] = $75;
  $80 = HEAP32[$1>>2]|0;
  $81 = (($80) + 1|0);
  HEAP32[$1>>2] = $81;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$useLightProbes,1);
 }
 $82 = HEAP8[$useLightProbes>>0]|0;
 $83 = $82&255;
 HEAP32[$72>>2] = $83;
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $84 = (($this) + 72|0);
 $85 = HEAP32[$1>>2]|0;
 $86 = (($85) + 4|0);
 $87 = HEAP32[$4>>2]|0;
 $88 = ($86>>>0)<($87>>>0);
 if ($88) {
  $89 = HEAP32[$84>>2]|0;
  HEAP32[$85>>2] = $89;
  HEAP32[$1>>2] = $86;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$84,4);
 }
 $90 = (($this) + 212|0);
 __ZN4PPtrI9TransformE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($90,$transfer);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $91 = (($this) + 276|0);
 $92 = HEAP32[$1>>2]|0;
 $93 = (($92) + 4|0);
 $94 = HEAP32[$4>>2]|0;
 $95 = ($93>>>0)<($94>>>0);
 if ($95) {
  $96 = HEAP32[$91>>2]|0;
  HEAP32[$92>>2] = $96;
  HEAP32[$1>>2] = $93;
  $101 = $94;$99 = $93;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$91,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $101 = $$pre14;$99 = $$pre13;
 }
 $97 = (($this) + 280|0);
 $98 = (($99) + 2|0);
 $100 = ($98>>>0)<($101>>>0);
 if ($100) {
  $102 = HEAP16[$97>>1]|0;
  HEAP16[$99>>1] = $102;
  HEAP32[$1>>2] = $98;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$97,2);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN8Renderer8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre2 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$01$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 220|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 228|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)==(0);
 $$pre = (($transfer) + 12|0);
 $$pre2 = (($transfer) + 28|0);
 $$pre4 = (($transfer) + 32|0);
 if (!($5)) {
  $i$01$i$i$i = $1;
  while(1) {
   $6 = HEAP32[$i$01$i$i$i>>2]|0;
   $7 = HEAP32[$$pre>>2]|0;
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$$pre2>>2]|0;
   $11 = (FUNCTION_TABLE_iiii[$9 & 2047]($7,$6,$10)|0);
   $12 = HEAP8[$$pre4>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if (!($13)) {
    HEAP32[$i$01$i$i$i>>2] = $11;
   }
   $14 = (($i$01$i$i$i) + 4|0);
   $15 = ($14|0)==($4|0);
   if ($15) {
    break;
   } else {
    $i$01$i$i$i = $14;
   }
  }
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
 $16 = (($this) + 252|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$$pre>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$$pre2>>2]|0;
 $22 = (FUNCTION_TABLE_iiii[$20 & 2047]($18,$17,$21)|0);
 $23 = HEAP8[$$pre4>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if (!($24)) {
  HEAP32[$16>>2] = $22;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 $25 = (($this) + 204|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(1);
 $28 = $27&1;
 HEAP32[$25>>2] = $28;
 $29 = (($this) + 212|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$$pre>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$$pre2>>2]|0;
 $35 = (FUNCTION_TABLE_iiii[$33 & 2047]($31,$30,$34)|0);
 $36 = HEAP8[$$pre4>>0]|0;
 $37 = ($36<<24>>24)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 HEAP32[$29>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($5) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $34 = $$pre$i$i$i4;
  } else {
   $33 = HEAP32[$6>>2]|0;
   HEAP32[$size1>>2] = $33;
   HEAP32[$2>>2] = $7;
   $34 = $33;
  }
  $35 = (_llvm_bswap_i32(($34|0))|0);
  HEAP32[$size1>>2] = $35;
  $36 = (($this) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$data>>2]|0;
  $39 = ($38|0)==(0|0);
  if ($39) {
   $40 = (($data) + 4|0);
   HEAP32[$40>>2] = $37;
  }
  HEAP32[$$byval_copy>>2] = 0;
  __ZN13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EE18resize_initializedEjRKS3_b($data,$35,$$byval_copy,0);
  $41 = HEAP32[$data>>2]|0;
  $42 = (($data) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + ($43<<2)|0);
  $45 = ($43|0)==(0);
  if ($45) {
   STACKTOP = sp;return;
  } else {
   $i$06 = $41;
  }
  while(1) {
   __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$06,$this);
   $46 = (($i$06) + 4|0);
   $47 = ($46|0)==($44|0);
   if ($47) {
    break;
   } else {
    $i$06 = $46;
   }
  }
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre7 = HEAP32[$8>>2]|0;
  $12 = $$pre$i$i$i;$15 = $$pre;$17 = $$pre7;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$size>>2] = $11;
  HEAP32[$2>>2] = $7;
  $12 = $11;$15 = $7;$17 = $9;
 }
 $13 = (_llvm_bswap_i32(($12|0))|0);
 HEAP32[$size>>2] = $13;
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $19 = $$pre$i$i$i1;$22 = $$pre8;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$offset>>2] = $18;
  HEAP32[$2>>2] = $14;
  $19 = $18;$22 = $13;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$offset>>2] = $20;
 $21 = $22 << 2;
 $23 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$20,$21)|0);
 $24 = (($data) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)>(-1);
 if ($26) {
  $27 = HEAP32[$data>>2]|0;
  $28 = (($data) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$1>>2] = $29;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy);
  HEAP32[$data>>2] = 0;
 }
 $30 = $21 >> 2;
 $31 = (($data) + 8|0);
 HEAP32[$31>>2] = $30;
 $32 = $30 | -2147483648;
 HEAP32[$24>>2] = $32;
 HEAP32[$data>>2] = $23;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($5) {
  if ($10) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $36 = $$pre;
  } else {
   $30 = HEAP32[$6>>2]|0;
   HEAP32[$size1>>2] = $30;
   HEAP32[$2>>2] = $7;
   $36 = $30;
  }
  $31 = (($this) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$data>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $35 = (($data) + 4|0);
   HEAP32[$35>>2] = $32;
  }
  HEAP32[$$byval_copy>>2] = 0;
  __ZN13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EE18resize_initializedEjRKS3_b($data,$36,$$byval_copy,0);
  $37 = HEAP32[$data>>2]|0;
  $38 = (($data) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + ($39<<2)|0);
  $41 = ($39|0)==(0);
  if ($41) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $37;
  }
  while(1) {
   __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$04,$this);
   $42 = (($i$04) + 4|0);
   $43 = ($42|0)==($40|0);
   if ($43) {
    break;
   } else {
    $i$04 = $42;
   }
  }
  STACKTOP = sp;return;
 }
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre5 = HEAP32[$2>>2]|0;
  $$pre6 = HEAP32[$8>>2]|0;
  $13 = $$pre5;$15 = $$pre6;
 } else {
  $11 = HEAP32[$6>>2]|0;
  HEAP32[$size>>2] = $11;
  HEAP32[$2>>2] = $7;
  $13 = $7;$15 = $9;
 }
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $19 = $$pre7;
 } else {
  $16 = HEAP32[$13>>2]|0;
  HEAP32[$offset>>2] = $16;
  HEAP32[$2>>2] = $12;
  $19 = $16;
 }
 $17 = HEAP32[$size>>2]|0;
 $18 = $17 << 2;
 $20 = (__ZN12CachedReader22FetchResourceImageDataEjj($2,$19,$18)|0);
 $21 = (($data) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)>(-1);
 if ($23) {
  $24 = HEAP32[$data>>2]|0;
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  HEAP32[$1>>2] = $26;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($24,$$byval_copy);
  HEAP32[$data>>2] = 0;
 }
 $27 = $18 >> 2;
 $28 = (($data) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = $27 | -2147483648;
 HEAP32[$21>>2] = $29;
 HEAP32[$data>>2] = $20;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $1 = sp + 12|0;
 $size = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,605840,605840,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$data>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = (($data) + 4|0);
  HEAP32[$11>>2] = $8;
 }
 HEAP32[$1>>2] = 0;
 __ZN13dynamic_arrayI4PPtrIN5Unity8MaterialEELj4EE18resize_initializedEjRKS3_b($data,$6,$1,0);
 $12 = HEAP32[$data>>2]|0;
 $13 = HEAP32[$3>>2]|0;
 $14 = (($12) + ($13<<2)|0);
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)==(0);
 do {
  if (!($16)) {
   $17 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,605784,605848,0,1)|0);
   $18 = (($this) + 80|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (__ZNK16TypeTreeIterator7GetNodeEv($19)|0);
   $21 = (($20) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($this) + 84|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$24>>2] = 0;
   $25 = ($17|0)==(2);
   if ($25) {
    $26 = HEAP32[$18>>2]|0;
    $27 = (($26) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$data>>2]|0;
    $30 = ($29|0)==($14|0);
    L11: do {
     if (!($30)) {
      $32 = 0;$35 = $26;$i$03 = $29;
      while(1) {
       $31 = Math_imul($32, $22)|0;
       $33 = (($31) + ($28))|0;
       $34 = (($35) + 20|0);
       HEAP32[$34>>2] = $33;
       $36 = (($35) + 12|0);
       HEAP32[$36>>2] = $33;
       $37 = (($35) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$35);
       $38 = $2;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = (($38) + 4)|0;
       $42 = $41;
       $43 = HEAP32[$42>>2]|0;
       $44 = $37;
       $45 = $44;
       HEAP32[$45>>2] = $40;
       $46 = (($44) + 4)|0;
       $47 = $46;
       HEAP32[$47>>2] = $43;
       $48 = HEAP32[$23>>2]|0;
       $49 = HEAP32[$48>>2]|0;
       $50 = (($49) + 1)|0;
       HEAP32[$48>>2] = $50;
       __ZN4PPtrIN5Unity8MaterialEE8TransferI14SafeBinaryReadEEvRT_($i$03,$this);
       $51 = (($i$03) + 4|0);
       $52 = ($51|0)==($14|0);
       if ($52) {
        break L11;
       }
       $$pre = HEAP32[$23>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$18>>2]|0;
       $32 = $$pre8;$35 = $$pre9;$i$03 = $51;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $53 = HEAP32[$data>>2]|0;
   $54 = ($53|0)==($14|0);
   if (!($54)) {
    $i$14 = $53;
    while(1) {
     $55 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,605784,605848,$1,1)|0);
     $56 = ($55|0)==(0);
     if (!($56)) {
      $57 = ($55|0)>(0);
      if ($57) {
       __ZN4PPtrIN5Unity8MaterialEE8TransferI14SafeBinaryReadEEvRT_($i$14,$this);
      } else {
       $58 = HEAP32[$1>>2]|0;
       $59 = ($58|0)==(0|0);
       if (!($59)) {
        (FUNCTION_TABLE_iii[$58 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $60 = (($i$14) + 4|0);
     $61 = ($60|0)==($14|0);
     if ($61) {
      break;
     } else {
      $i$14 = $60;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z43InitializeRendererAnimationBindingInterfacev() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (__Z13GetIAnimationv()|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy1,0,16,605944,389)|0);
 HEAP32[$5>>2] = ((606008 + 8|0));
 HEAP32[605952>>2] = $5;
 $6 = (__Z13GetIAnimationv()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[605952>>2]|0;
 FUNCTION_TABLE_viiii[$9 & 511]($6,25,21,$10);
 $11 = HEAP32[628296>>2]|0;
 HEAP32[$1>>2] = $11;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $12 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy1,0,16,605944,393)|0);
 HEAP32[$12>>2] = ((605968 + 8|0));
 HEAP32[605960>>2] = $12;
 $13 = (__Z13GetIAnimationv()|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[605960>>2]|0;
 FUNCTION_TABLE_viiii[$16 & 511]($13,25,22,$17);
 STACKTOP = sp;return;
}
function __Z40CleanupRendererAnimationBindingInterfacev() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[605952>>2]|0;
 $2 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy1);
 HEAP32[605952>>2] = 0;
 $3 = HEAP32[605960>>2]|0;
 $4 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy1);
 HEAP32[605960>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK32RendererMaterialAnimationBinding13GetFloatValueERKN11UnityEngine9Animation10BoundCurveE($this,$bind) {
 $this = $this|0;
 $bind = $bind|0;
 var $$0 = Math_fround(0), $$byval_copy4 = 0, $$in = 0, $$in13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0);
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $color = 0, $i$03 = 0, $i$03$us = 0, $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy4 = sp + 80|0;
 $0 = sp + 76|0;
 $name = sp + 72|0;
 $color = sp + 56|0;
 $1 = sp + 52|0;
 $2 = sp + 48|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $5 = sp + 8|0;
 $6 = sp;
 $7 = sp + 32|0;
 $8 = (($bind) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$bind>>2]|0;
 $11 = $10 & 268435455;
 HEAP32[$name>>2] = $11;
 $12 = (($9) + 28|0);
 $13 = (($12) + 168|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if (!($15)) {
   $16 = $10 >>> 30;
   if ((($16|0) == 1)) {
    $26 = (__ZNK21MaterialPropertyBlock8GetColorERKN9ShaderLab16FastPropertyNameER10ColorRGBAf($14,$name,$color)|0);
    if (!($26)) {
     break;
    }
    $81 = $10 >>> 28;
    $82 = $81 & 3;
    $83 = (($color) + ($82<<2)|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $$0 = $84;
    STACKTOP = sp;return (Math_fround($$0));
   } else if ((($16|0) == 2)) {
    $17 = (__ZNK21MaterialPropertyBlock9FindFloatERKN9ShaderLab16FastPropertyNameE($14,$name)|0);
    $18 = ($17|0)==(0|0);
    if ($18) {
     break;
    }
    $19 = Math_fround(HEAPF32[$17>>2]);
    $$0 = $19;
    STACKTOP = sp;return (Math_fround($$0));
   } else if ((($16|0) == 0)) {
    $20 = (__ZNK21MaterialPropertyBlock10FindVectorERKN9ShaderLab16FastPropertyNameE($14,$name)|0);
    $21 = ($20|0)==(0|0);
    if ($21) {
     break;
    }
    $22 = $10 >>> 28;
    $23 = $22 & 3;
    $24 = (($20) + ($23<<2)|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $$0 = $25;
    STACKTOP = sp;return (Math_fround($$0));
   } else {
    break;
   }
  }
 } while(0);
 $27 = HEAP32[$9>>2]|0;
 $28 = (($27) + 128|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (FUNCTION_TABLE_ii[$29 & 4095]($9)|0);
 $31 = ($30|0)>(0);
 if (!($31)) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $32 = $10 >>> 30;
 $33 = ($32|0)==(2);
 if ($33) {
  $i$03$us = 0;
  L18: while(1) {
   $34 = HEAP32[$9>>2]|0;
   $35 = (($34) + 132|0);
   $36 = HEAP32[$35>>2]|0;
   FUNCTION_TABLE_viii[$36 & 4095]($1,$9,0);
   $37 = HEAP32[$1>>2]|0;
   $38 = ($37|0)==(0);
   do {
    if (!($38)) {
     HEAP32[$0>>2] = $37;
     $39 = HEAP32[560624>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      label = 20;
     } else {
      $41 = (($39) + 36|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (($39) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($42|0)==($44|0);
      do {
       if ($45) {
        $54 = (($39) + 28|0);
        $55 = HEAP32[$54>>2]|0;
        $56 = (($39) + 32|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = (($55) + ($57<<3)|0);
        $66 = $58;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$39,$0);
        $46 = HEAP32[$$byval_copy4>>2]|0;
        $47 = ($46|0)==(-1);
        $48 = (($39) + 28|0);
        $49 = HEAP32[$48>>2]|0;
        if ($47) {
         $51 = (($39) + 32|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = (($49) + ($52<<3)|0);
         $66 = $53;
         break;
        } else {
         $50 = (($49) + ($46<<3)|0);
         $66 = $50;
         break;
        }
       }
      } while(0);
      $59 = HEAP32[560624>>2]|0;
      $60 = (($59) + 28|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = (($59) + 32|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($61) + ($63<<3)|0);
      $65 = ($66|0)==($64|0);
      if ($65) {
       label = 20;
      } else {
       $67 = (($66) + 4|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = ($68|0)==(0|0);
       if ($69) {
        label = 20;
       } else {
        $$in13 = $68;
       }
      }
     }
     if ((label|0) == 20) {
      label = 0;
      $70 = HEAP32[$1>>2]|0;
      $71 = (__Z31ReadObjectFromPersistentManageri($70)|0);
      $72 = ($71|0)==(0|0);
      if ($72) {
       break;
      } else {
       $$in13 = $71;
      }
     }
     $73 = HEAP32[$name>>2]|0;
     HEAP32[$2>>2] = $73;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
     $74 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($$in13,$$byval_copy4)|0);
     if ($74) {
      break L18;
     }
    }
   } while(0);
   $75 = (($i$03$us) + 1)|0;
   $76 = HEAP32[$9>>2]|0;
   $77 = (($76) + 128|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (FUNCTION_TABLE_ii[$78 & 4095]($9)|0);
   $80 = ($75|0)<($79|0);
   if ($80) {
    $i$03$us = $75;
   } else {
    $$0 = Math_fround(0.0);
    label = 41;
    break;
   }
  }
  if ((label|0) == 41) {
   STACKTOP = sp;return (Math_fround($$0));
  }
  $126 = HEAP32[$name>>2]|0;
  HEAP32[$3>>2] = $126;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
  $127 = (Math_fround(__ZN5Unity8Material8GetFloatEN9ShaderLab16FastPropertyNameE($$in13,$$byval_copy4)));
  $$0 = $127;
  STACKTOP = sp;return (Math_fround($$0));
 } else {
  $i$03 = 0;
 }
 L41: while(1) {
  $85 = HEAP32[$9>>2]|0;
  $86 = (($85) + 132|0);
  $87 = HEAP32[$86>>2]|0;
  FUNCTION_TABLE_viii[$87 & 4095]($1,$9,0);
  $88 = HEAP32[$1>>2]|0;
  $89 = ($88|0)==(0);
  do {
   if (!($89)) {
    HEAP32[$0>>2] = $88;
    $90 = HEAP32[560624>>2]|0;
    $91 = ($90|0)==(0|0);
    if ($91) {
     label = 34;
    } else {
     $92 = (($90) + 36|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = (($90) + 4|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = ($93|0)==($95|0);
     do {
      if ($96) {
       $97 = (($90) + 28|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = (($90) + 32|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = (($98) + ($100<<3)|0);
       $117 = $101;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$90,$0);
       $102 = HEAP32[$$byval_copy4>>2]|0;
       $103 = ($102|0)==(-1);
       $104 = (($90) + 28|0);
       $105 = HEAP32[$104>>2]|0;
       if ($103) {
        $106 = (($90) + 32|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = (($105) + ($107<<3)|0);
        $117 = $108;
        break;
       } else {
        $109 = (($105) + ($102<<3)|0);
        $117 = $109;
        break;
       }
      }
     } while(0);
     $110 = HEAP32[560624>>2]|0;
     $111 = (($110) + 28|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = (($110) + 32|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (($112) + ($114<<3)|0);
     $116 = ($117|0)==($115|0);
     if ($116) {
      label = 34;
     } else {
      $118 = (($117) + 4|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = ($119|0)==(0|0);
      if ($120) {
       label = 34;
      } else {
       $$in = $119;
      }
     }
    }
    if ((label|0) == 34) {
     label = 0;
     $121 = HEAP32[$1>>2]|0;
     $122 = (__Z31ReadObjectFromPersistentManageri($121)|0);
     $123 = ($122|0)==(0|0);
     if ($123) {
      break;
     } else {
      $$in = $122;
     }
    }
    $124 = HEAP32[$name>>2]|0;
    HEAP32[$2>>2] = $124;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
    $125 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($$in,$$byval_copy4)|0);
    if ($125) {
     if ((($32|0) == 0)) {
      label = 39;
      break L41;
     } else if ((($32|0) == 1)) {
      label = 38;
      break L41;
     }
    }
   }
  } while(0);
  $138 = (($i$03) + 1)|0;
  $139 = HEAP32[$9>>2]|0;
  $140 = (($139) + 128|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = (FUNCTION_TABLE_ii[$141 & 4095]($9)|0);
  $143 = ($138|0)<($142|0);
  if ($143) {
   $i$03 = $138;
  } else {
   $$0 = Math_fround(0.0);
   label = 41;
   break;
  }
 }
 if ((label|0) == 38) {
  $128 = $10 >>> 28;
  $129 = $128 & 3;
  $130 = HEAP32[$name>>2]|0;
  HEAP32[$4>>2] = $130;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
  __ZN5Unity8Material8GetColorEN9ShaderLab16FastPropertyNameE($5,$$in,$$byval_copy4);
  $131 = (($5) + ($129<<2)|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $$0 = $132;
  STACKTOP = sp;return (Math_fround($$0));
 }
 else if ((label|0) == 39) {
  $133 = $10 >>> 28;
  $134 = $133 & 3;
  $135 = HEAP32[$name>>2]|0;
  HEAP32[$6>>2] = $135;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$6+0>>2]|0;
  __ZN5Unity8Material8GetColorEN9ShaderLab16FastPropertyNameE($7,$$in,$$byval_copy4);
  $136 = (($7) + ($134<<2)|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $$0 = $137;
  STACKTOP = sp;return (Math_fround($$0));
 }
 else if ((label|0) == 41) {
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZNK32RendererMaterialAnimationBinding13SetFloatValueERKN11UnityEngine9Animation10BoundCurveEf($this,$bound,$value) {
 $this = $this|0;
 $bound = $bound|0;
 $value = Math_fround($value);
 var $$not$i = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $color$i = 0, $name = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $color$i = sp + 8|0;
 $name = sp;
 $0 = (($bound) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$bound>>2]|0;
 $3 = (__ZN8Renderer36GetPropertyBlockRememberToUpdateHashEv($1)|0);
 $4 = $2 & 268435455;
 HEAP32[$name>>2] = $4;
 $5 = $2 >>> 30;
 if ((($5|0) == 2)) {
  __ZN21MaterialPropertyBlock20ReplacePropertyFloatERKN9ShaderLab16FastPropertyNameEf($3,$name,$value);
 } else if ((($5|0) == 0)) {
  $6 = $2 >>> 28;
  $7 = $6 & 3;
  $8 = $7&255;
  __ZN21MaterialPropertyBlock27ReplacePartialFloatPropertyERKN9ShaderLab16FastPropertyNameEfhh($3,$name,$value,4,$8);
 } else if ((($5|0) == 1)) {
  $9 = $2 >>> 28;
  $10 = $9 & 3;
  $11 = $10&255;
  __ZN21MaterialPropertyBlock32ReplacePartialFloatColorPropertyERKN9ShaderLab16FastPropertyNameEfhh($3,$name,$value,4,$11);
 }
 __ZN21MaterialPropertyBlock11ComputeHashEv($3);
 $12 = HEAP32[$name>>2]|0;
 $13 = $2 & 805306368;
 $14 = ($13|0)==(536870912);
 $15 = HEAP32[605904>>2]|0;
 $16 = ($15|0)==($12|0);
 $or$cond = $14 & $16;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $17 = (($1) + 64|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 >>> 16;
 $20 = $19&65535;
 $$off$i$i = (($20) + -254)<<16>>16;
 $21 = ($$off$i$i&65535)>(1);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (__Z13GetIEnlightenv()|0);
 $23 = (__ZNK21MaterialPropertyBlock8GetColorERKN9ShaderLab16FastPropertyNameER10ColorRGBAf($3,605904,$color$i)|0);
 $$not$i = $23 ^ 1;
 $24 = ($22|0)==(0|0);
 $or$cond$i = $24 | $$not$i;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$22>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 (FUNCTION_TABLE_iiii[$26 & 2047]($22,$1,$color$i)|0);
 STACKTOP = sp;return;
}
function __ZNK32RendererMaterialAnimationBinding12SetPPtrValueERKN11UnityEngine9Animation10BoundCurveEi($this,$bound,$value) {
 $this = $this|0;
 $bound = $bound|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK32RendererMaterialAnimationBinding12GetPPtrValueERKN11UnityEngine9Animation10BoundCurveE($this,$bound) {
 $this = $this|0;
 $bound = $bound|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK32RendererMaterialAnimationBinding15GenerateBindingERK8UnityStrbRN11UnityEngine9Animation14GenericBindingE($this,$attributeStr,$pptrCurve,$outputBinding) {
 $this = $this|0;
 $attributeStr = $attributeStr|0;
 $pptrCurve = $pptrCurve|0;
 $outputBinding = $outputBinding|0;
 var $$0 = 0, $$02$i$i$i = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__p$0$lcssa$i$i$i = 0, $__p$0$ph$i$i$i = 0, $__p$01$i$i$i = 0, $a$0 = 0, $binding$sroa$0$0 = 0, $binding$sroa$0$1 = 0, $dotIndex$0 = 0, $dotIndex$1 = 0, $scevgep$i$i$i = 0, $scevgep3$i$i$i = 0, $scevgep4$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 if ($pptrCurve) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP8[$attributeStr>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($attributeStr) + 1|0);
  $7 = $6;
 } else {
  $4 = (($attributeStr) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 $8 = (__Z10BeginsWithPKcS0_($7,605928)|0);
 if (!($8)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = HEAP8[$attributeStr>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $14 = (($attributeStr) + 1|0);
  $17 = $14;
 } else {
  $12 = (($attributeStr) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $17 = $13;
 }
 $15 = (_strlen((605928|0))|0);
 $16 = (($17) + ($15)|0);
 $18 = $16;
 $a$0 = $16;$dotIndex$0 = -1;
 while(1) {
  $19 = HEAP8[$a$0>>0]|0;
  if ((($19<<24>>24) == 46)) {
   $20 = ($dotIndex$0|0)==(-1);
   if ($20) {
    $21 = $a$0;
    $22 = (($21) - ($18))|0;
    $dotIndex$1 = $22;
   } else {
    $dotIndex$1 = $dotIndex$0;
   }
  } else if ((($19<<24>>24) == 0)) {
   break;
  } else {
   $dotIndex$1 = $dotIndex$0;
  }
  $23 = (($a$0) + 1|0);
  $a$0 = $23;$dotIndex$0 = $dotIndex$1;
 }
 $24 = (($a$0) + -1|0);
 $25 = ($dotIndex$0|0)==(-1);
 L22: do {
  if ($25) {
   $26 = (__ZN9ShaderLab33GenerateFastPropertyName28BitHashEPKc($16)|0);
   $27 = $26 & 268435455;
   $28 = $27 | -2147483648;
   $binding$sroa$0$1 = $28;
  } else {
   $$sum = (($dotIndex$0) + ($15))|0;
   $29 = (($17) + ($$sum)|0);
   $30 = $29;
   $31 = (($30) - ($18))|0;
   $32 = ($31>>>0)>(4294967279);
   if ($32) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $33 = ($31>>>0)<(11);
   if ($33) {
    $34 = $31 << 1;
    $35 = $34&255;
    HEAP8[$0>>0] = $35;
    $36 = (($0) + 1|0);
    $__p$0$ph$i$i$i = $36;
   } else {
    $37 = (($31) + 16)|0;
    $38 = $37 & -16;
    $39 = (__Znwj($38)|0);
    $40 = (($0) + 8|0);
    HEAP32[$40>>2] = $39;
    $41 = $38 | 1;
    HEAP32[$0>>2] = $41;
    $42 = (($0) + 4|0);
    HEAP32[$42>>2] = $31;
    $__p$0$ph$i$i$i = $39;
   }
   $43 = ($dotIndex$0|0)==(0);
   if ($43) {
    $__p$0$lcssa$i$i$i = $__p$0$ph$i$i$i;
   } else {
    $$02$i$i$i = $16;$__p$01$i$i$i = $__p$0$ph$i$i$i;
    while(1) {
     $44 = HEAP8[$$02$i$i$i>>0]|0;
     HEAP8[$__p$01$i$i$i>>0] = $44;
     $45 = (($$02$i$i$i) + 1|0);
     $46 = (($__p$01$i$i$i) + 1|0);
     $47 = ($45|0)==($29|0);
     if ($47) {
      break;
     } else {
      $$02$i$i$i = $45;$__p$01$i$i$i = $46;
     }
    }
    $$sum2 = (($$sum) - ($18))|0;
    $scevgep$i$i$i = (($17) + ($$sum2)|0);
    $scevgep3$i$i$i = $scevgep$i$i$i;
    $scevgep4$i$i$i = (($__p$0$ph$i$i$i) + ($scevgep3$i$i$i)|0);
    $__p$0$lcssa$i$i$i = $scevgep4$i$i$i;
   }
   HEAP8[$__p$0$lcssa$i$i$i>>0] = 0;
   $48 = HEAP8[$0>>0]|0;
   $49 = $48 & 1;
   $50 = ($49<<24>>24)==(0);
   if ($50) {
    $53 = (($0) + 1|0);
    $54 = $53;
   } else {
    $51 = (($0) + 8|0);
    $52 = HEAP32[$51>>2]|0;
    $54 = $52;
   }
   __THREW__ = 0;
   $55 = (invoke_ii(3247,($54|0))|0);
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    $67 = ___cxa_find_matching_catch()|0;
    $68 = tempRet0;
    $69 = HEAP8[$0>>0]|0;
    $70 = $69 & 1;
    $71 = ($70<<24>>24)==(0);
    if ($71) {
     ___resumeException($67|0);
     // unreachable;
    }
    $72 = (($0) + 8|0);
    $73 = HEAP32[$72>>2]|0;
    __ZdlPv($73);
    ___resumeException($67|0);
    // unreachable;
   }
   $58 = $55 & 268435455;
   $59 = HEAP8[$0>>0]|0;
   $60 = $59 & 1;
   $61 = ($60<<24>>24)==(0);
   if (!($61)) {
    $62 = (($0) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    __ZdlPv($63);
   }
   $64 = (($dotIndex$0) + 2)|0;
   $65 = (_strlen(($16|0))|0);
   $66 = ($64|0)==($65|0);
   if (!($66)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $74 = HEAP8[$24>>0]|0;
   $75 = $74 << 24 >> 24;
   if ((($75|0) == 97) | (($75|0) == 98) | (($75|0) == 103) | (($75|0) == 114)) {
    $76 = $58 | 1073741824;
    $binding$sroa$0$0 = $76;
   } else {
    $binding$sroa$0$0 = $58;
   }
   switch ($75|0) {
   case 120: case 114:  {
    $77 = $binding$sroa$0$0 & -805306369;
    $binding$sroa$0$1 = $77;
    break L22;
    break;
   }
   case 122: case 98:  {
    $80 = $binding$sroa$0$0 & -805306369;
    $81 = $80 | 536870912;
    $binding$sroa$0$1 = $81;
    break L22;
    break;
   }
   case 121: case 103:  {
    $78 = $binding$sroa$0$0 & -805306369;
    $79 = $78 | 268435456;
    $binding$sroa$0$1 = $79;
    break L22;
    break;
   }
   case 119: case 97:  {
    $82 = $binding$sroa$0$0 | 805306368;
    $binding$sroa$0$1 = $82;
    break L22;
    break;
   }
   default: {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   }
  }
 } while(0);
 $83 = (($outputBinding) + 4|0);
 HEAP32[$83>>2] = $binding$sroa$0$1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK32RendererMaterialAnimationBinding9BindValueER6ObjectRKN11UnityEngine9Animation14GenericBindingERNS3_10BoundCurveE($this,$target,$outputBinding,$bound) {
 $this = $this|0;
 $target = $target|0;
 $outputBinding = $outputBinding|0;
 $bound = $bound|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $prop = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $prop = sp;
 $0 = (($outputBinding) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$prop>>2] = -1;
 $2 = $1 & 268435455;
 __ZN9ShaderLab16FastPropertyName15InitBy28BitHashEj($prop,$2);
 $3 = HEAP32[$prop>>2]|0;
 $4 = $3 & 268435455;
 $5 = $1 & -268435456;
 $6 = $4 | $5;
 $7 = $6;
 HEAP32[$bound>>2] = $7;
 STACKTOP = sp;return 100002;
}
function __ZNK24RendererAnimationBinding13GetFloatValueERKN11UnityEngine9Animation10BoundCurveE($this,$bind) {
 $this = $this|0;
 $bind = $bind|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return Math_fround(0.0);
}
function __ZNK24RendererAnimationBinding13SetFloatValueERKN11UnityEngine9Animation10BoundCurveEf($this,$bound,$value) {
 $this = $this|0;
 $bound = $bound|0;
 $value = Math_fround($value);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK24RendererAnimationBinding12SetPPtrValueERKN11UnityEngine9Animation10BoundCurveEi($this,$bound,$value) {
 $this = $this|0;
 $bound = $bound|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($bound) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$bound>>2]|0;
 $4 = $3;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($5) + 128|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($2)|0);
 $9 = ($4|0)<($8|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $value;
 __ZN8Renderer11SetMaterialE4PPtrIN5Unity8MaterialEEi($2,$0,$4);
 STACKTOP = sp;return;
}
function __ZNK24RendererAnimationBinding12GetPPtrValueERKN11UnityEngine9Animation10BoundCurveE($this,$bound) {
 $this = $this|0;
 $bound = $bound|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($bound) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$bound>>2]|0;
 $4 = $3;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($5) + 128|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($2)|0);
 $9 = ($4|0)<($8|0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[$2>>2]|0;
 $11 = (($10) + 132|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viii[$12 & 4095]($0,$2,$4);
 $13 = HEAP32[$0>>2]|0;
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK24RendererAnimationBinding15GenerateBindingERK8UnityStrbRN11UnityEngine9Animation14GenericBindingE($this,$attribute,$pptrCurve,$outputBinding) {
 $this = $this|0;
 $attribute = $attribute|0;
 $pptrCurve = $pptrCurve|0;
 $outputBinding = $outputBinding|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $brmerge = 0, $pptrCurve$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24ParseIndexAttributeIndexRK8UnityStrPKc($attribute,606048)|0);
 $1 = ($0|0)==(-1);
 $pptrCurve$not = $pptrCurve ^ 1;
 $brmerge = $1 | $pptrCurve$not;
 if ($brmerge) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($outputBinding) + 4|0);
 HEAP32[$2>>2] = $0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK24RendererAnimationBinding9BindValueER6ObjectRKN11UnityEngine9Animation14GenericBindingERNS3_10BoundCurveE($this,$target,$outputBinding,$bound) {
 $this = $this|0;
 $target = $target|0;
 $outputBinding = $outputBinding|0;
 $bound = $bound|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($outputBinding) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1;
 HEAP32[$bound>>2] = $2;
 STACKTOP = sp;return 21;
}
function __Z24ParseIndexAttributeIndexRK8UnityStrPKc($attribute,$preString) {
 $attribute = $attribute|0;
 $preString = $preString|0;
 var $$0 = 0, $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$attribute>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($attribute) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8|0)==(0);
 if ($7) {
  $$0$i$i = -1;
 } else {
  if ($2) {
   $11 = (($attribute) + 1|0);
   $12 = $11;
  } else {
   $9 = (($attribute) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $12 = $10;
  }
  $13 = (_memchr($12,91,$8)|0);
  $14 = ($13|0)==(0|0);
  if ($14) {
   $$0$i$i = -1;
  } else {
   $15 = $13;
   $16 = $12;
   $17 = (($15) - ($16))|0;
   $$0$i$i = $17;
  }
 }
 if ($2) {
  $20 = $0&255;
  $21 = $20 >>> 1;
  $23 = $21;
 } else {
  $18 = (($attribute) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $23 = $19;
 }
 $22 = ($23|0)==(0);
 if ($22) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($2) {
  $26 = (($attribute) + 1|0);
  $27 = $26;
 } else {
  $24 = (($attribute) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $27 = $25;
 }
 $28 = (_memchr($27,93,$23)|0);
 $29 = ($28|0)==(0|0);
 if ($29) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = $28;
 $31 = $27;
 $32 = (($30) - ($31))|0;
 $33 = ($$0$i$i|0)==(-1);
 $34 = ($32|0)==(-1);
 $or$cond = $33 | $34;
 if ($or$cond) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($2) {
  $37 = (($attribute) + 1|0);
  $38 = $37;
 } else {
  $35 = (($attribute) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $38 = $36;
 }
 $39 = (__Z10BeginsWithPKcS0_($38,$preString)|0);
 if (!($39)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = HEAP8[$attribute>>0]|0;
 $41 = $40 & 1;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  $45 = (($attribute) + 1|0);
  $47 = $45;
 } else {
  $43 = (($attribute) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $47 = $44;
 }
 $46 = (($47) + ($$0$i$i)|0);
 $48 = (__Z11StringToIntPKc($46)|0);
 $$0 = $48;
 STACKTOP = sp;return ($$0|0);
}
function __GLOBAL__I_a4778() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,605912);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[605904>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb($allow) {
 $allow = $allow|0;
 var $0 = 0, $storemerge = 0, $storemerge$v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[606080>>2]|0;
 $storemerge$v = $allow ? 1 : -1;
 $storemerge = (($0) + ($storemerge$v))|0;
 HEAP32[606080>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZN13RenderTexture19FindAndSetSRGBWriteEPS_($newActive) {
 $newActive = $newActive|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetActiveColorSpacev()|0);
 $1 = ($0|0)==(1);
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($newActive|0)==(0|0);
 if ($6) {
  $10 = $1;
  FUNCTION_TABLE_vii[$5 & 4095]($2,$10);
  STACKTOP = sp;return;
 }
 $7 = (($newActive) + 130|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 $$ = $9 & $1;
 $10 = $$;
 FUNCTION_TABLE_vii[$5 & 4095]($2,$10);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej($newActive,$mipLevel,$face,$flags) {
 $newActive = $newActive|0;
 $mipLevel = $mipLevel|0;
 $face = $face|0;
 $flags = $flags|0;
 var $$ = 0, $$0$i$i = 0, $$byval_copy = 0, $$in = 0, $$pn = 0, $$pr$pre$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newColorSurface = 0, $newDepthSurface$sroa$0$03 = 0, $or$cond$i$i = 0, $phitmp$i = 0, $phitmp2$i = 0, $phitmp4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $newColorSurface = sp;
 $0 = sp + 4|0;
 $1 = HEAP8[((640792 + 241|0))>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (1)==(0);
 $or$cond$i$i = $2 | $3;
 do {
  if (!($or$cond$i$i)) {
   $4 = (__Z16GetBuildSettingsv()|0);
   $5 = (($4) + 92|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $8 = HEAP32[606080>>2]|0;
    $9 = ($8|0)!=(0);
    $phitmp$i = $9 ? $newActive : 0;
    $$0$i$i = $phitmp$i;
   } else {
    $$0$i$i = $newActive;
   }
   $10 = ($$0$i$i|0)==(0|0);
   if (!($10)) {
    $11 = (($$0$i$i) + 140|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $14 = (($$0$i$i) + 148|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0|0);
     if ($16) {
      (__ZN13RenderTexture6CreateEv($$0$i$i)|0);
      $$pr$pre$i = HEAP32[$11>>2]|0;
      $phitmp4$i = ($$pr$pre$i|0)==(0|0);
      if ($phitmp4$i) {
       $$pre = HEAP32[$14>>2]|0;
       $18 = $$pre;
       label = 9;
      } else {
       $20 = $$0$i$i;
      }
     } else {
      $18 = $15;
      label = 9;
     }
     if ((label|0) == 9) {
      $17 = ($18|0)!=(0|0);
      $phitmp2$i = $17 ? $$0$i$i : 0;
      $20 = $phitmp2$i;
     }
     $19 = ($20|0)==(0|0);
     if ($19) {
      break;
     }
     $21 = (($20) + 140|0);
     $22 = HEAP32[$21>>2]|0;
     HEAP32[$newColorSurface>>2] = $22;
     $$pn = $20;
    } else {
     HEAP32[$newColorSurface>>2] = $12;
     $$pn = $$0$i$i;
    }
    $$in = (($$pn) + 148|0);
    $33 = HEAP32[$$in>>2]|0;
    $34 = HEAP32[$$pn>>2]|0;
    $35 = (($34) + 124|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (FUNCTION_TABLE_ii[$36 & 4095]($$pn)|0);
    $$ = $37 ? $mipLevel : 0;
    $38 = $$pn;$39 = $$;$newDepthSurface$sroa$0$03 = $33;
    HEAP32[$0>>2] = $newDepthSurface$sroa$0$03;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$newColorSurface,$$byval_copy,$38,$39,$face,$flags)|0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $23 = (__Z12GetGfxDevicev()|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 432|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (FUNCTION_TABLE_ii[$26 & 4095]($23)|0);
 HEAP32[$newColorSurface>>2] = $27;
 $28 = (__Z12GetGfxDevicev()|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 436|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_ii[$31 & 4095]($28)|0);
 $38 = 0;$39 = 0;$newDepthSurface$sroa$0$03 = $32;
 HEAP32[$0>>2] = $newDepthSurface$sroa$0$03;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 (__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej(1,$newColorSurface,$$byval_copy,$38,$39,$face,$flags)|0);
 STACKTOP = sp;return;
}
function __Z28EnsureRenderTextureIsCreatedP13RenderTexture($tex) {
 $tex = $tex|0;
 var $$0$i = 0, $$pr$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond$i = 0, $phitmp = 0, $phitmp2 = 0, $phitmp4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[((640792 + 241|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 $2 = (1)==(0);
 $or$cond$i = $1 | $2;
 if ($or$cond$i) {
  $18 = 0;
  STACKTOP = sp;return ($18|0);
 }
 $3 = (__Z16GetBuildSettingsv()|0);
 $4 = (($3) + 92|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = HEAP32[606080>>2]|0;
  $8 = ($7|0)!=(0);
  $phitmp = $8 ? $tex : 0;
  $$0$i = $phitmp;
 } else {
  $$0$i = $tex;
 }
 $9 = ($$0$i|0)==(0|0);
 if ($9) {
  $18 = 0;
  STACKTOP = sp;return ($18|0);
 }
 $10 = (($$0$i) + 140|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $18 = $$0$i;
  STACKTOP = sp;return ($18|0);
 }
 $13 = (($$0$i) + 148|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  (__ZN13RenderTexture6CreateEv($$0$i)|0);
  $$pr$pre = HEAP32[$10>>2]|0;
  $phitmp4 = ($$pr$pre|0)==(0|0);
  if (!($phitmp4)) {
   $18 = $$0$i;
   STACKTOP = sp;return ($18|0);
  }
 }
 $16 = HEAP32[$13>>2]|0;
 $17 = ($16|0)!=(0|0);
 $phitmp2 = $17 ? $$0$i : 0;
 $18 = $phitmp2;
 STACKTOP = sp;return ($18|0);
}
function __ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej($count,$newColorSurfaces,$newDepthSurface,$rt,$mipLevel,$face,$flags) {
 $count = $count|0;
 $newColorSurfaces = $newColorSurfaces|0;
 $newDepthSurface = $newDepthSurface|0;
 $rt = $rt|0;
 $mipLevel = $mipLevel|0;
 $face = $face|0;
 $flags = $flags|0;
 var $$$i = 0, $$0$i = 0, $$0$i3 = 0, $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond6 = 0, $exitcond7 = 0, $exitcond8 = 0, $i$04 = 0, $i$04$us = 0, $i$04$us$us = 0, $i$04$us5 = 0, $or$cond$i = 0, $phitmp = 0, $setup = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $setup = sp;
 dest=$setup+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = HEAP8[((640792 + 241|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 $2 = (1)==(0);
 $or$cond$i = $1 | $2;
 do {
  if ($or$cond$i) {
   $3 = (($setup) + 36|0);
   HEAP32[$3>>2] = 1;
   $4 = $flags & 4;
   $5 = ($4|0)==(0);
   if ($5) {
    $63 = 1;
    label = 12;
   } else {
    $80 = 1;
    label = 11;
   }
  } else {
   $6 = (__Z16GetBuildSettingsv()|0);
   $7 = (($6) + 92|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   if ($9) {
    $10 = HEAP32[606080>>2]|0;
    $11 = ($10|0)!=(0);
    $$0$i = $11;
   } else {
    $$0$i = 1;
   }
   $12 = $$0$i ? $count : 1;
   $13 = (($setup) + 36|0);
   HEAP32[$13>>2] = $12;
   $14 = ($12|0)>(0);
   if ($14) {
    $15 = $flags & 4;
    $16 = ($15|0)==(0);
    if (!($$0$i)) {
     if ($16) {
      $63 = $12;
      label = 12;
      break;
     } else {
      $80 = $12;
      label = 11;
      break;
     }
    }
    if ($16) {
     $i$04$us$us = 0;
     while(1) {
      $17 = (($newColorSurfaces) + ($i$04$us$us<<2)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($setup) + ($i$04$us$us<<2)|0);
      HEAP32[$19>>2] = $18;
      $20 = (($18) + 20|0);
      $21 = HEAP8[$20>>0]|0;
      $22 = ((($setup) + ($i$04$us$us)|0) + 52|0);
      HEAP8[$22>>0] = $21;
      $23 = HEAP32[$19>>2]|0;
      $24 = (($23) + 21|0);
      $25 = HEAP8[$24>>0]|0;
      $26 = ((($setup) + ($i$04$us$us)|0) + 60|0);
      HEAP8[$26>>0] = $25;
      $27 = HEAP32[$19>>2]|0;
      $28 = (($27) + 21|0);
      HEAP8[$28>>0] = 0;
      $29 = HEAP32[$19>>2]|0;
      $30 = (($29) + 20|0);
      HEAP8[$30>>0] = 0;
      $31 = (($i$04$us$us) + 1)|0;
      $exitcond8 = ($31|0)==($12|0);
      if ($exitcond8) {
       break;
      } else {
       $i$04$us$us = $31;
      }
     }
    } else {
     $i$04$us = 0;
     while(1) {
      $32 = (($newColorSurfaces) + ($i$04$us<<2)|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($setup) + ($i$04$us<<2)|0);
      HEAP32[$34>>2] = $33;
      $35 = ((($setup) + ($i$04$us)|0) + 52|0);
      HEAP8[$35>>0] = 2;
      $36 = HEAP32[$34>>2]|0;
      $37 = (($36) + 21|0);
      $38 = HEAP8[$37>>0]|0;
      $39 = ((($setup) + ($i$04$us)|0) + 60|0);
      HEAP8[$39>>0] = $38;
      $40 = HEAP32[$34>>2]|0;
      $41 = (($40) + 21|0);
      HEAP8[$41>>0] = 0;
      $42 = HEAP32[$34>>2]|0;
      $43 = (($42) + 20|0);
      HEAP8[$43>>0] = 0;
      $44 = (($i$04$us) + 1)|0;
      $exitcond6 = ($44|0)==($12|0);
      if ($exitcond6) {
       break;
      } else {
       $i$04$us = $44;
      }
     }
    }
   }
   if ($$0$i) {
    $81 = HEAP32[$newDepthSurface>>2]|0;
    $88 = $81;
   } else {
    label = 17;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $i$04 = 0;
  while(1) {
   $64 = (__Z12GetGfxDevicev()|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 432|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (FUNCTION_TABLE_ii[$67 & 4095]($64)|0);
   $69 = (($setup) + ($i$04<<2)|0);
   HEAP32[$69>>2] = $68;
   $70 = ((($setup) + ($i$04)|0) + 52|0);
   HEAP8[$70>>0] = 2;
   $71 = HEAP32[$69>>2]|0;
   $72 = (($71) + 21|0);
   $73 = HEAP8[$72>>0]|0;
   $74 = ((($setup) + ($i$04)|0) + 60|0);
   HEAP8[$74>>0] = $73;
   $75 = HEAP32[$69>>2]|0;
   $76 = (($75) + 21|0);
   HEAP8[$76>>0] = 0;
   $77 = HEAP32[$69>>2]|0;
   $78 = (($77) + 20|0);
   HEAP8[$78>>0] = 0;
   $79 = (($i$04) + 1)|0;
   $exitcond = ($79|0)==($80|0);
   if ($exitcond) {
    label = 17;
    break;
   } else {
    $i$04 = $79;
   }
  }
 }
 else if ((label|0) == 12) {
  $i$04$us5 = 0;
  while(1) {
   $45 = (__Z12GetGfxDevicev()|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($46) + 432|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (FUNCTION_TABLE_ii[$48 & 4095]($45)|0);
   $50 = (($setup) + ($i$04$us5<<2)|0);
   HEAP32[$50>>2] = $49;
   $51 = (($49) + 20|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = ((($setup) + ($i$04$us5)|0) + 52|0);
   HEAP8[$53>>0] = $52;
   $54 = HEAP32[$50>>2]|0;
   $55 = (($54) + 21|0);
   $56 = HEAP8[$55>>0]|0;
   $57 = ((($setup) + ($i$04$us5)|0) + 60|0);
   HEAP8[$57>>0] = $56;
   $58 = HEAP32[$50>>2]|0;
   $59 = (($58) + 21|0);
   HEAP8[$59>>0] = 0;
   $60 = HEAP32[$50>>2]|0;
   $61 = (($60) + 20|0);
   HEAP8[$61>>0] = 0;
   $62 = (($i$04$us5) + 1)|0;
   $exitcond7 = ($62|0)==($63|0);
   if ($exitcond7) {
    label = 17;
    break;
   } else {
    $i$04$us5 = $62;
   }
  }
 }
 if ((label|0) == 17) {
  $82 = (__Z12GetGfxDevicev()|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + 436|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (FUNCTION_TABLE_ii[$85 & 4095]($82)|0);
  $88 = $86;
 }
 $87 = (($setup) + 32|0);
 HEAP32[$87>>2] = $88;
 $89 = $flags & 8;
 $90 = ($89|0)==(0);
 if ($90) {
  $91 = (($88) + 20|0);
  $92 = HEAP8[$91>>0]|0;
  $94 = $92;
 } else {
  $94 = 2;
 }
 $93 = (($setup) + 68|0);
 HEAP8[$93>>0] = $94;
 $95 = (($88) + 21|0);
 $96 = HEAP8[$95>>0]|0;
 $97 = (($setup) + 69|0);
 HEAP8[$97>>0] = $96;
 HEAP8[$95>>0] = 0;
 $98 = HEAP32[$87>>2]|0;
 $99 = (($98) + 20|0);
 HEAP8[$99>>0] = 0;
 $100 = (($setup) + 44|0);
 HEAP32[$100>>2] = $face;
 $101 = HEAP32[$setup>>2]|0;
 $102 = (($101) + 23|0);
 $103 = HEAP8[$102>>0]|0;
 $104 = ($103<<24>>24)==(0);
 if ($104) {
  $105 = (($101) + 4|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($101) + 8|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (__Z22CalculateMipMapCount3Diii($106,$108,1)|0);
  $phitmp = (($109) + -1)|0;
  $112 = $phitmp;
 } else {
  $112 = 0;
 }
 $110 = ($mipLevel|0)<(0);
 if ($110) {
  $$0$i3 = 0;
  $113 = (($setup) + 40|0);
  HEAP32[$113>>2] = $$0$i3;
  $114 = $flags >>> 2;
  $$lobit = $114 & 1;
  $115 = $89 >>> 2;
  $116 = $$lobit | $115;
  $117 = $flags << 2;
  $118 = $117 & 8;
  $119 = $116 | $118;
  $120 = (($setup) + 48|0);
  HEAP32[$120>>2] = $119;
  $121 = (__ZN13RenderTexture9SetActiveEPS_RK20GfxRenderTargetSetupj($rt,$setup,$flags)|0);
  STACKTOP = sp;return ($121|0);
 }
 $111 = ($112|0)<($mipLevel|0);
 $$$i = $111 ? $112 : $mipLevel;
 $$0$i3 = $$$i;
 $113 = (($setup) + 40|0);
 HEAP32[$113>>2] = $$0$i3;
 $114 = $flags >>> 2;
 $$lobit = $114 & 1;
 $115 = $89 >>> 2;
 $116 = $$lobit | $115;
 $117 = $flags << 2;
 $118 = $117 & 8;
 $119 = $116 | $118;
 $120 = (($setup) + 48|0);
 HEAP32[$120>>2] = $119;
 $121 = (__ZN13RenderTexture9SetActiveEPS_RK20GfxRenderTargetSetupj($rt,$setup,$flags)|0);
 STACKTOP = sp;return ($121|0);
}
function __ZN13RenderTexture9IsEnabledEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[((640792 + 241|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 $2 = (1)==(0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  $$0 = 0;
 } else {
  $3 = (__Z16GetBuildSettingsv()|0);
  $4 = (($3) + 92|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $7 = HEAP32[606080>>2]|0;
   $8 = ($7|0)!=(0);
   $$0 = $8;
  } else {
   $$0 = 1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN13RenderTexture9SetActiveEPS_RK20GfxRenderTargetSetupj($texture,$setup,$flags) {
 $texture = $texture|0;
 $setup = $setup|0;
 $flags = $flags|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $cameraViewPort = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $cameraViewPort = sp + 16|0;
 $2 = sp + 32|0;
 $3 = HEAP32[$setup>>2]|0;
 $4 = (($3) + 23|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = (__Z12GetGfxDevicev()|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 420|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$9 & 4095]($6,0)|0);
 $11 = HEAP32[$6>>2]|0;
 $12 = (($11) + 424|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 4095]($6)|0);
 $15 = HEAP32[$setup>>2]|0;
 $16 = ($10|0)==($15|0);
 if ($16) {
  $17 = (($setup) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 2;
  $20 = ($19|0)==(0);
  if (!($20)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $21 = (__Z12GetGfxDevicev()|0);
  $22 = (($21) + 5788|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   $25 = (($23) + 108|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)>(1);
   if ($27) {
    $28 = (($23) + 144|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==(0|0);
    if (!($30)) {
     $31 = (__Z12GetGfxDevicev()|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($32) + 400|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($23) + 140|0);
     $36 = HEAP32[$35>>2]|0;
     HEAP32[$0>>2] = $36;
     $37 = HEAP32[$28>>2]|0;
     HEAP32[$1>>2] = $37;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
     FUNCTION_TABLE_viii[$34 & 4095]($31,$$byval_copy,$$byval_copy1);
    }
   }
  }
 }
 $38 = HEAP32[$6>>2]|0;
 $39 = (($38) + 396|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_vii[$40 & 4095]($6,$setup);
 $41 = HEAP32[$setup>>2]|0;
 $42 = ($10|0)==($41|0);
 if ($42) {
  $43 = (($setup) + 32|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($14|0)==($44|0);
  $46 = ($5<<24>>24)==(0);
  $or$cond = $45 & $46;
  if ($or$cond) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $47 = (__Z12GetGfxDevicev()|0);
 $48 = (($47) + 5788|0);
 HEAP32[$48>>2] = $texture;
 $49 = $flags & 1;
 $50 = ($49|0)==(0);
 do {
  if ($50) {
   $51 = ($5<<24>>24)==(0);
   if ($51) {
    $57 = HEAP32[$setup>>2]|0;
    $58 = (($57) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($setup) + 40|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = $59 >>> $61;
    $63 = (($57) + 8|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = $64 >>> $61;
    $66 = HEAP32[$6>>2]|0;
    $67 = (($66) + 172|0);
    $68 = HEAP32[$67>>2]|0;
    HEAP32[$2>>2] = 0;
    $69 = (($2) + 8|0);
    HEAP32[$69>>2] = $62;
    $70 = (($2) + 4|0);
    HEAP32[$70>>2] = 0;
    $71 = (($2) + 12|0);
    HEAP32[$71>>2] = $65;
    FUNCTION_TABLE_vii[$68 & 4095]($6,$2);
    $72 = HEAP32[$6>>2]|0;
    $73 = (($72) + 28|0);
    $74 = HEAP32[$73>>2]|0;
    $86 = $74;
    break;
   } else {
    $52 = (__Z16GetRenderManagerv()|0);
    $53 = (($52) + 72|0);
    ;HEAP32[$cameraViewPort+0>>2]=HEAP32[$53+0>>2]|0;HEAP32[$cameraViewPort+4>>2]=HEAP32[$53+4>>2]|0;HEAP32[$cameraViewPort+8>>2]=HEAP32[$53+8>>2]|0;HEAP32[$cameraViewPort+12>>2]=HEAP32[$53+12>>2]|0;
    __Z22FlipScreenRectIfNeededRK9GfxDeviceR5RectTIiE($6,$cameraViewPort);
    $54 = HEAP32[$6>>2]|0;
    $55 = (($54) + 172|0);
    $56 = HEAP32[$55>>2]|0;
    FUNCTION_TABLE_vii[$56 & 4095]($6,$cameraViewPort);
    label = 13;
    break;
   }
  } else {
   label = 13;
  }
 } while(0);
 if ((label|0) == 13) {
  $75 = ($5<<24>>24)==(0);
  $76 = HEAP32[$6>>2]|0;
  $77 = (($76) + 28|0);
  $78 = HEAP32[$77>>2]|0;
  if ($75) {
   $86 = $78;
  } else {
   FUNCTION_TABLE_vii[$78 & 4095]($6,0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $79 = ($texture|0)==(0|0);
 if ($79) {
  label = 17;
 } else {
  $80 = (($texture) + 134|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = ($81<<24>>24)==(0);
  if ($82) {
   $87 = 0;
  } else {
   label = 17;
  }
 }
 if ((label|0) == 17) {
  $83 = (($6) + 5932|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = ($84<<24>>24)==(0);
  $87 = $85;
 }
 FUNCTION_TABLE_vii[$86 & 4095]($6,$87);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13RenderTexture9GetActiveEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($0) + 5788|0);
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN13RenderTexture6CreateEv($this) {
 $this = $this|0;
 var $$ = 0, $$$ = 0, $$$0$i31 = 0, $$$i = 0, $$0 = 0, $$0$i31 = 0, $$0$off0$$i = 0, $$0$off0$i = 0, $$16 = 0, $$19 = 0, $$37 = 0, $$38 = 0, $$byval_copy4 = 0, $$depthFlags$1 = 0, $$pr = 0, $$pre42 = 0, $$pre43 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $colorFlags$1 = 0, $colorFlags$1$ = 0, $colorFlags$3 = 0, $depthFlags$1 = 0;
 var $depthFlags$2 = 0, $extract$t2$$i = 0, $extract$t3$i = 0, $not$ = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i29 = 0, $or$cond10 = 0, $or$cond12 = 0, $or$cond18 = 0, $or$cond21$not = 0, $or$cond23 = 0, $or$cond36 = 0, $or$cond44 = 0, $or$cond6 = 0, $or$cond8 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = HEAP8[((640792 + 241|0))>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $7 = (1)==(0);
 $or$cond$i = $6 | $7;
 if ($or$cond$i) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (__Z16GetBuildSettingsv()|0);
 $9 = (($8) + 92|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = HEAP32[606080>>2]|0;
 $13 = ($12|0)!=(0);
 $or$cond36 = $11 | $13;
 if (!($or$cond36)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($this) + 140|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $17 = (($this) + 148|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = (__Z12GetGfxDevicev()|0);
  $21 = (($this) + 152|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (0 - ($22))|0;
  $24 = ($23|0)<(0);
  $25 = $24 << 31 >> 31;
  $26 = (($20) + 5456|0);
  $27 = $26;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 4)|0;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = (_i64Add(($29|0),($32|0),($23|0),($25|0))|0);
  $34 = tempRet0;
  $35 = $26;
  $36 = $35;
  HEAP32[$36>>2] = $33;
  $37 = (($35) + 4)|0;
  $38 = $37;
  HEAP32[$38>>2] = $34;
  HEAP32[$21>>2] = 0;
  $39 = (($this) + 140|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = HEAP32[$20>>2]|0;
   $43 = (($42) + 392|0);
   $44 = HEAP32[$43>>2]|0;
   FUNCTION_TABLE_vii[$44 & 4095]($20,$39);
  }
  $45 = (($this) + 144|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if (!($47)) {
   $48 = HEAP32[$20>>2]|0;
   $49 = (($48) + 392|0);
   $50 = HEAP32[$49>>2]|0;
   FUNCTION_TABLE_vii[$50 & 4095]($20,$45);
  }
  $51 = (($this) + 148|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(0|0);
  if (!($53)) {
   $54 = HEAP32[$20>>2]|0;
   $55 = (($54) + 392|0);
   $56 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vii[$56 & 4095]($20,$51);
  }
 }
 $57 = (__Z12GetGfxDevicev()|0);
 $58 = (($this) + 100|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)<(1);
 if ($60) {
  $64 = ($this|0)==(0|0);
  if ($64) {
   $67 = 0;
  } else {
   label = 14;
  }
 } else {
  $61 = (($this) + 104|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)<(1);
  if ($63) {
   label = 14;
  } else {
   $68 = (($this) + 124|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(4);
   do {
    if ($70) {
     $71 = (($59) + -1)|0;
     $72 = $71 & $59;
     $73 = ($72|0)==(0);
     if ($73) {
      $74 = (($62) + -1)|0;
      $75 = $74 & $62;
      $76 = ($75|0)==(0);
      $77 = ($59|0)==($62|0);
      $or$cond44 = $76 & $77;
      if ($or$cond44) {
       break;
      }
     }
     $78 = ($this|0)==(0|0);
     if ($78) {
      $81 = 0;
     } else {
      $79 = (($this) + 4|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = $80;
     }
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606168,0,606160,238,1,$81,0,0);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $82 = HEAP32[$57>>2]|0;
   $83 = (($82) + 448|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($this) + 116|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($this) + 120|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (FUNCTION_TABLE_iiiiii[$84 & 255]($57,$59,$62,$86,$88)|0);
   L33: do {
    if (!($89)) {
     $90 = HEAP32[$58>>2]|0;
     $91 = (($90) + -1)|0;
     $92 = $91 & $90;
     $93 = ($92|0)==(0);
     if ($93) {
      $94 = HEAP32[$61>>2]|0;
      $95 = (($94) + -1)|0;
      $96 = $95 & $94;
      $97 = ($96|0)==(0);
      if ($97) {
       $98 = HEAP32[((640792 + 116|0))>>2]|0;
       $99 = ($98|0)<(4);
       if (!($99)) {
        $105 = $90;$109 = $94;
        while(1) {
         $104 = (($105|0) / 2)&-1;
         $106 = ($104|0)<(4);
         $107 = $106 ? 4 : $104;
         HEAP32[$58>>2] = $107;
         $108 = (($109|0) / 2)&-1;
         $110 = ($108|0)<(4);
         $111 = $110 ? 4 : $108;
         HEAP32[$61>>2] = $111;
         $112 = HEAP32[$57>>2]|0;
         $113 = (($112) + 448|0);
         $114 = HEAP32[$113>>2]|0;
         $115 = HEAP32[$85>>2]|0;
         $116 = HEAP32[$87>>2]|0;
         $117 = (FUNCTION_TABLE_iiiiii[$114 & 255]($57,$107,$111,$115,$116)|0);
         if ($117) {
          break L33;
         }
         $$pre42 = HEAP32[$58>>2]|0;
         $$pre43 = HEAP32[$61>>2]|0;
         $105 = $$pre42;$109 = $$pre43;
        }
       }
       $100 = ($this|0)==(0|0);
       if ($100) {
        $103 = 0;
       } else {
        $101 = (($this) + 4|0);
        $102 = HEAP32[$101>>2]|0;
        $103 = $102;
       }
       __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606256,0,606160,248,1,$103,0,0);
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
     $118 = ($this|0)==(0|0);
     if ($118) {
      $121 = 0;
     } else {
      $119 = (($this) + 4|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = $120;
     }
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606320,0,606160,262,1,$121,0,0);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $122 = HEAP32[$85>>2]|0;
   $123 = ((640792 + ($122)|0) + 201|0);
   $124 = HEAP8[$123>>0]|0;
   $125 = ($124<<24>>24)==(0);
   if ($125) {
    $126 = ($this|0)==(0|0);
    if ($126) {
     $129 = 0;
    } else {
     $127 = (($this) + 4|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = $128;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606384,0,606160,269,1,$129,0,0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $130 = HEAP32[$58>>2]|0;
   $131 = (($130) + -1)|0;
   $132 = $131 & $130;
   $133 = ($132|0)==(0);
   if ($133) {
    $134 = HEAP32[$61>>2]|0;
    $135 = (($134) + -1)|0;
    $136 = $135 & $134;
    $phitmp = ($136|0)!=(0);
    $139 = $phitmp;
   } else {
    $139 = 1;
   }
   $137 = HEAP32[((640792 + 232|0))>>2]|0;
   $138 = ($137|0)==(0);
   $or$cond = $138 & $139;
   if ($or$cond) {
    $140 = ($this|0)==(0|0);
    if ($140) {
     $143 = 0;
    } else {
     $141 = (($this) + 4|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = $142;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606440,0,606160,275,1,$143,0,0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $144 = HEAP32[$68>>2]|0;
   $145 = ($144|0)==(4);
   do {
    if ($145) {
     $146 = HEAP8[((640792 + 242|0))>>0]|0;
     $147 = ($146<<24>>24)==(0);
     if ($147) {
      $149 = ($this|0)==(0|0);
      if ($149) {
       $152 = 0;
      } else {
       label = 48;
      }
     } else {
      $148 = (__Z15IsDepthRTFormat19RenderTextureFormat($122)|0);
      if ($148) {
       label = 48;
      } else {
       $$pr = HEAP32[$68>>2]|0;
       $154 = $$pr;
       break;
      }
     }
     if ((label|0) == 48) {
      $150 = (($this) + 4|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = $151;
     }
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606512,0,606160,281,1,$152,0,0);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    } else {
     $154 = $144;
    }
   } while(0);
   $153 = ($154|0)==(3);
   if ($153) {
    $155 = HEAP8[((640792 + 225|0))>>0]|0;
    $156 = ($155<<24>>24)==(0);
    $157 = HEAP8[((640792 + 243|0))>>0]|0;
    $158 = ($157<<24>>24)==(0);
    $or$cond6 = $156 | $158;
    if ($or$cond6) {
     $159 = ($this|0)==(0|0);
     if ($159) {
      $162 = 0;
     } else {
      $160 = (($this) + 4|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = $161;
     }
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606568,0,606160,287,1,$162,0,0);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $163 = (($this) + 128|0);
   $164 = HEAP8[$163>>0]|0;
   $165 = ($164<<24>>24)!=(0);
   $166 = HEAP8[((640792 + 140|0))>>0]|0;
   $167 = ($166<<24>>24)!=(0);
   $168 = ($154|0)==(4);
   $extract$t3$i = $167 & $165;
   if ($168) {
    $169 = HEAP8[((640792 + 275|0))>>0]|0;
    $170 = ($169<<24>>24)==(0);
    $extract$t2$$i = $170 & $extract$t3$i;
    $$0$off0$i = $extract$t2$$i;
   } else {
    $$0$off0$i = $extract$t3$i;
   }
   $171 = ($154|0)!=(3);
   $172 = HEAP8[((640792 + 276|0))>>0]|0;
   $173 = ($172<<24>>24)==(0);
   $or$cond$i29 = $171 | $173;
   $$0$off0$$i = $or$cond$i29 & $$0$off0$i;
   $174 = HEAP32[$58>>2]|0;
   $175 = (($174) + -1)|0;
   $176 = $175 & $174;
   $177 = ($176|0)==(0);
   if ($177) {
    $178 = HEAP32[$61>>2]|0;
    $179 = (($178) + -1)|0;
    $180 = $179 & $178;
    $181 = ($180|0)==(0);
    $182 = $181;
   } else {
    $182 = 0;
   }
   $$ = $182 & $$0$off0$$i;
   $183 = (($this) + 108|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = ($184|0)<(1);
   if ($185) {
    $$0$i31 = 1;
   } else {
    $186 = ($184|0)>(8);
    $$$i = $186 ? 8 : $184;
    $$0$i31 = $$$i;
   }
   $187 = (($this) + 130|0);
   $188 = HEAP8[((640792 + 129|0))>>0]|0;
   $189 = ($188<<24>>24)==(0);
   $$$0$i31 = $189 ? 1 : $$0$i31;
   $190 = ($154|0)==(2);
   $191 = $190 ? $$$0$i31 : 1;
   $192 = ($191|0)>(1);
   $not$ = $192 ^ 1;
   $$$ = $$ & $not$;
   $193 = HEAP32[$85>>2]|0;
   $194 = ($193|0)!=(1);
   $195 = HEAP8[((640792 + 247|0))>>0]|0;
   $196 = ($195<<24>>24)==(0);
   $or$cond8 = $194 | $196;
   L98: do {
    if ($or$cond8) {
     $197 = ($193|0)!=(3);
     $198 = HEAP8[((640792 + 249|0))>>0]|0;
     $199 = ($198<<24>>24)==(0);
     $or$cond10 = $197 | $199;
     if ($or$cond10) {
      $203 = HEAP8[((640792 + 130|0))>>0]|0;
      $204 = ($203<<24>>24)==(0);
      $or$cond12 = $192 & $204;
      $205 = (($this) + 44|0);
      $206 = HEAP32[$205>>2]|0;
      $$37 = $or$cond12 ? 0 : $206;
      $$38 = $or$cond12 ? $206 : 0;
      do {
       if ($190) {
        $207 = HEAP32[$87>>2]|0;
        $208 = ($207|0)==(0);
        if ($208) {
         break;
        }
        $209 = HEAP8[((640792 + 248|0))>>0]|0;
        $notlhs = ($191|0)<(2);
        $notrhs = ($209<<24>>24)!=(0);
        $or$cond21$not = $notrhs & $notlhs;
        $210 = HEAP8[((640792 + 274|0))>>0]|0;
        $211 = ($210<<24>>24)==(0);
        $or$cond23 = $or$cond21$not & $211;
        if (!($or$cond23)) {
         break;
        }
        $212 = (($this) + 136|0);
        $213 = HEAP32[$212>>2]|0;
        $214 = (($this) + 168|0);
        HEAP8[$214>>0] = 1;
        $230 = $$37;$240 = $$38;$255 = $213;
        break L98;
       }
      } while(0);
      $215 = (($this) + 168|0);
      HEAP8[$215>>0] = 0;
      $230 = $$37;$240 = $$38;$255 = 0;
     } else {
      label = 64;
     }
    } else {
     label = 64;
    }
   } while(0);
   if ((label|0) == 64) {
    $200 = (($this) + 44|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = (($this) + 168|0);
    HEAP8[$202>>0] = 0;
    $230 = 0;$240 = 0;$255 = $201;
   }
   $$16 = $$$ ? 2 : 0;
   $216 = (($this) + 129|0);
   $217 = HEAP8[$216>>0]|0;
   $218 = ($217<<24>>24)==(0);
   $219 = $$16 | 128;
   $colorFlags$1 = $218 ? $$16 : $219;
   $220 = HEAP8[$187>>0]|0;
   $221 = ($220<<24>>24)==(0);
   $222 = $colorFlags$1 | 4;
   $colorFlags$1$ = $221 ? $colorFlags$1 : $222;
   $223 = (($this) + 131|0);
   $224 = HEAP8[$223>>0]|0;
   $225 = ($224<<24>>24)==(0);
   $226 = $colorFlags$1$ | 16;
   $colorFlags$3 = $225 ? $colorFlags$1$ : $226;
   $227 = HEAP32[$57>>2]|0;
   $228 = (($227) + 384|0);
   $229 = HEAP32[$228>>2]|0;
   HEAP32[$0>>2] = $230;
   $231 = HEAP32[$61>>2]|0;
   $232 = (($this) + 112|0);
   $233 = HEAP32[$232>>2]|0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   $234 = (FUNCTION_TABLE_iiiiiiiiii[$229 & 15]($57,$$byval_copy4,$174,$231,$191,$233,$154,$193,$colorFlags$3)|0);
   HEAP32[$14>>2] = $234;
   $235 = HEAP8[((640792 + 130|0))>>0]|0;
   $236 = ($235<<24>>24)==(0);
   $or$cond18 = $192 & $236;
   if ($or$cond18) {
    $237 = HEAP32[$57>>2]|0;
    $238 = (($237) + 384|0);
    $239 = HEAP32[$238>>2]|0;
    HEAP32[$1>>2] = $240;
    $241 = HEAP32[$58>>2]|0;
    $242 = HEAP32[$61>>2]|0;
    $243 = HEAP32[$232>>2]|0;
    $244 = HEAP32[$68>>2]|0;
    $245 = HEAP32[$85>>2]|0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    $246 = (FUNCTION_TABLE_iiiiiiiiii[$239 & 15]($57,$$byval_copy4,$241,$242,1,$243,$244,$245,$colorFlags$3)|0);
    $247 = (($this) + 144|0);
    HEAP32[$247>>2] = $246;
   }
   $248 = HEAP32[$85>>2]|0;
   $249 = ($248|0)==(3);
   $$19 = $249 ? 8 : 0;
   $250 = (($this) + 133|0);
   $251 = HEAP8[$250>>0]|0;
   $252 = ($251<<24>>24)==(0);
   $253 = $$19 | 32;
   $depthFlags$1 = $252 ? $$19 : $253;
   $254 = ($255|0)==(0);
   $256 = HEAP32[$87>>2]|0;
   if ($254) {
    $257 = ($256|0)==(0);
    $258 = $depthFlags$1 | 64;
    $$depthFlags$1 = $257 ? $258 : $depthFlags$1;
    $depthFlags$2 = $$depthFlags$1;
   } else {
    $depthFlags$2 = $depthFlags$1;
   }
   $259 = HEAP32[$57>>2]|0;
   $260 = (($259) + 388|0);
   $261 = HEAP32[$260>>2]|0;
   HEAP32[$2>>2] = $255;
   $262 = HEAP32[$58>>2]|0;
   $263 = HEAP32[$61>>2]|0;
   $264 = HEAP32[$68>>2]|0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
   $265 = (FUNCTION_TABLE_iiiiiiiii[$261 & 63]($57,$$byval_copy4,$262,$263,$191,$264,$256,$depthFlags$2)|0);
   $266 = (($this) + 148|0);
   HEAP32[$266>>2] = $265;
   $267 = (($this) + 140|0);
   $268 = HEAP32[$267>>2]|0;
   $269 = ($268|0)==(0|0);
   do {
    if ($269) {
     $271 = ($this|0)==(0|0);
     if ($271) {
      $274 = 0;
     } else {
      label = 77;
     }
    } else {
     $270 = ($265|0)==(0|0);
     if ($270) {
      label = 77;
      break;
     }
     $315 = HEAP32[$this>>2]|0;
     $316 = (($315) + 48|0);
     $317 = HEAP32[$316>>2]|0;
     $318 = (FUNCTION_TABLE_ii[$317 & 4095]($this)|0);
     $319 = (($this) + 152|0);
     HEAP32[$319>>2] = $318;
     $320 = ($318|0)<(0);
     $321 = $320 << 31 >> 31;
     $322 = (($57) + 5456|0);
     $323 = $322;
     $324 = $323;
     $325 = HEAP32[$324>>2]|0;
     $326 = (($323) + 4)|0;
     $327 = $326;
     $328 = HEAP32[$327>>2]|0;
     $329 = (_i64Add(($325|0),($328|0),($318|0),($321|0))|0);
     $330 = tempRet0;
     $331 = $322;
     $332 = $331;
     HEAP32[$332>>2] = $329;
     $333 = (($331) + 4)|0;
     $334 = $333;
     HEAP32[$334>>2] = $330;
     $335 = (($this) + 132|0);
     $336 = HEAP8[$335>>0]|0;
     $337 = ($336<<24>>24)==(0);
     if (!($337)) {
      $338 = HEAP32[$57>>2]|0;
      $339 = (($338) + 452|0);
      $340 = HEAP32[$339>>2]|0;
      $341 = HEAP32[$267>>2]|0;
      HEAP32[$3>>2] = $341;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
      FUNCTION_TABLE_viiii[$340 & 511]($57,$$byval_copy4,2,-4);
      $342 = HEAP32[$57>>2]|0;
      $343 = (($342) + 452|0);
      $344 = HEAP32[$343>>2]|0;
      $345 = HEAP32[$266>>2]|0;
      HEAP32[$4>>2] = $345;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
      FUNCTION_TABLE_viiii[$344 & 511]($57,$$byval_copy4,2,-4);
     }
     $346 = HEAP32[$57>>2]|0;
     $347 = (($346) + 652|0);
     $348 = HEAP32[$347>>2]|0;
     $349 = HEAP32[$267>>2]|0;
     $350 = HEAP32[$this>>2]|0;
     $351 = (($350) + 32|0);
     $352 = HEAP32[$351>>2]|0;
     $353 = (FUNCTION_TABLE_ii[$352 & 4095]($this)|0);
     FUNCTION_TABLE_viii[$348 & 4095]($57,$349,$353);
     $354 = HEAP32[$57>>2]|0;
     $355 = (($354) + 652|0);
     $356 = HEAP32[$355>>2]|0;
     $357 = HEAP32[$266>>2]|0;
     $358 = HEAP32[$this>>2]|0;
     $359 = (($358) + 32|0);
     $360 = HEAP32[$359>>2]|0;
     $361 = (FUNCTION_TABLE_ii[$360 & 4095]($this)|0);
     FUNCTION_TABLE_viii[$356 & 4095]($57,$357,$361);
     $362 = HEAP8[$187>>0]|0;
     $363 = $362&255;
     __ZN7Texture33SetStoredColorSpaceNoDirtyNoApplyE17TextureColorSpace($this,$363);
     $364 = HEAP32[$this>>2]|0;
     $365 = (($364) + 132|0);
     $366 = HEAP32[$365>>2]|0;
     FUNCTION_TABLE_vi[$366 & 4095]($this);
     $367 = (($this) + 64|0);
     HEAPF32[$367>>2] = Math_fround(1.0);
     $368 = (($this) + 68|0);
     HEAPF32[$368>>2] = Math_fround(1.0);
     __ZN7Texture20NotifyUVScaleChangedEv($this);
     $369 = HEAP32[$58>>2]|0;
     $370 = ($369|0)==(0);
     if ($370) {
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
     $371 = HEAP32[$61>>2]|0;
     $372 = ($371|0)==(0);
     if ($372) {
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
     $373 = (Math_fround(($369|0)));
     $374 = Math_fround(Math_fround(1.0) / $373);
     $375 = (Math_fround(($371|0)));
     $376 = Math_fround(Math_fround(1.0) / $375);
     $377 = (($this) + 72|0);
     HEAPF32[$377>>2] = $374;
     $378 = (($this) + 76|0);
     HEAPF32[$378>>2] = $376;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   if ((label|0) == 77) {
    $272 = (($this) + 4|0);
    $273 = HEAP32[$272>>2]|0;
    $274 = $273;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606632,0,606160,373,1,$274,0,0);
   $275 = HEAP32[$14>>2]|0;
   $276 = ($275|0)==(0|0);
   do {
    if ($276) {
     $277 = HEAP32[$266>>2]|0;
     $278 = ($277|0)==(0|0);
     if ($278) {
      $$0 = 0;
     } else {
      break;
     }
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $279 = (__Z12GetGfxDevicev()|0);
   $280 = (($this) + 152|0);
   $281 = HEAP32[$280>>2]|0;
   $282 = (0 - ($281))|0;
   $283 = ($282|0)<(0);
   $284 = $283 << 31 >> 31;
   $285 = (($279) + 5456|0);
   $286 = $285;
   $287 = $286;
   $288 = HEAP32[$287>>2]|0;
   $289 = (($286) + 4)|0;
   $290 = $289;
   $291 = HEAP32[$290>>2]|0;
   $292 = (_i64Add(($288|0),($291|0),($282|0),($284|0))|0);
   $293 = tempRet0;
   $294 = $285;
   $295 = $294;
   HEAP32[$295>>2] = $292;
   $296 = (($294) + 4)|0;
   $297 = $296;
   HEAP32[$297>>2] = $293;
   HEAP32[$280>>2] = 0;
   $298 = HEAP32[$267>>2]|0;
   $299 = ($298|0)==(0|0);
   if (!($299)) {
    $300 = HEAP32[$279>>2]|0;
    $301 = (($300) + 392|0);
    $302 = HEAP32[$301>>2]|0;
    FUNCTION_TABLE_vii[$302 & 4095]($279,$267);
   }
   $303 = (($this) + 144|0);
   $304 = HEAP32[$303>>2]|0;
   $305 = ($304|0)==(0|0);
   if (!($305)) {
    $306 = HEAP32[$279>>2]|0;
    $307 = (($306) + 392|0);
    $308 = HEAP32[$307>>2]|0;
    FUNCTION_TABLE_vii[$308 & 4095]($279,$303);
   }
   $309 = (($this) + 148|0);
   $310 = HEAP32[$309>>2]|0;
   $311 = ($310|0)==(0|0);
   if ($311) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $312 = HEAP32[$279>>2]|0;
   $313 = (($312) + 392|0);
   $314 = HEAP32[$313>>2]|0;
   FUNCTION_TABLE_vii[$314 & 4095]($279,$309);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 if ((label|0) == 14) {
  $65 = (($this) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = $66;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606088,0,606160,232,1,$67,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13RenderTexture13ApplySettingsEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 124|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($this)|0);
 $10 = (($this) + 116|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (__Z15IsDepthRTFormat19RenderTextureFormat($11)|0);
 if ($12) {
  label = 3;
 } else {
  $13 = (($this) + 168|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if (!($15)) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $16 = (($this) + 32|0);
  HEAP32[$16>>2] = 0;
 }
 $17 = (($this) + 28|0);
 $18 = (($this) + 44|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$0>>2] = $19;
 $20 = (__Z19GetActiveColorSpacev()|0);
 $21 = ($20|0)==(1);
 if ($21) {
  $22 = (($this) + 56|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23;
 } else {
  $24 = 0;
 }
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __ZNK15TextureSettings5ApplyE9TextureID16TextureDimensionb17TextureColorSpaceb($17,$$byval_copy1,$5,$9,$24,0);
 $25 = (($this) + 168|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  __ZN7Texture20NotifyMipBiasChangedEv($this);
  STACKTOP = sp;return;
 }
 $28 = (($this) + 136|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$1>>2] = $29;
 $30 = (__Z19GetActiveColorSpacev()|0);
 $31 = ($30|0)==(1);
 if ($31) {
  $32 = (($this) + 56|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33;
 } else {
  $34 = 0;
 }
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNK15TextureSettings5ApplyE9TextureID16TextureDimensionb17TextureColorSpaceb($17,$$byval_copy1,$5,$9,$34,0);
 __ZN7Texture20NotifyMipBiasChangedEv($this);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture7ReleaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($0) + 5788|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($this|0);
 if ($3) {
  $4 = ($this|0)==(0|0);
  if ($4) {
   $7 = 0;
  } else {
   $5 = (($this) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = $6;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606664,0,606160,442,1,$7,0,0);
  $8 = (__Z12GetGfxDevicev()|0);
  $9 = (($8) + 5788|0);
  HEAP32[$9>>2] = 0;
 }
 $10 = (($this) + 140|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = (($this) + 148|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   STACKTOP = sp;return;
  }
 }
 $16 = (__Z12GetGfxDevicev()|0);
 $17 = (($this) + 152|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (0 - ($18))|0;
 $20 = ($19|0)<(0);
 $21 = $20 << 31 >> 31;
 $22 = (($16) + 5456|0);
 $23 = $22;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (_i64Add(($25|0),($28|0),($19|0),($21|0))|0);
 $30 = tempRet0;
 $31 = $22;
 $32 = $31;
 HEAP32[$32>>2] = $29;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 HEAP32[$17>>2] = 0;
 $35 = (($this) + 140|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  $38 = HEAP32[$16>>2]|0;
  $39 = (($38) + 392|0);
  $40 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_vii[$40 & 4095]($16,$35);
 }
 $41 = (($this) + 144|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if (!($43)) {
  $44 = HEAP32[$16>>2]|0;
  $45 = (($44) + 392|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 4095]($16,$41);
 }
 $47 = (($this) + 148|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$16>>2]|0;
 $51 = (($50) + 392|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095]($16,$47);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture15DiscardContentsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 148|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   STACKTOP = sp;return;
  }
 }
 __Z28RenderTextureDiscardContentsP13RenderTexturebb($this,1,1);
 STACKTOP = sp;return;
}
function __Z28RenderTextureDiscardContentsP13RenderTexturebb($rt,$discardColor,$discardDepth) {
 $rt = $rt|0;
 $discardColor = $discardColor|0;
 $discardDepth = $discardDepth|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $color = 0, $depth = 0, $rcolor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $color = sp + 8|0;
 $rcolor = sp;
 $depth = sp + 4|0;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = ($rt|0)==(0|0);
 if ($1) {
  $8 = HEAP32[$0>>2]|0;
  $9 = (($8) + 432|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($0)|0);
  HEAP32[$color>>2] = $11;
  HEAP32[$rcolor>>2] = 0;
  $12 = HEAP32[$0>>2]|0;
  $13 = (($12) + 436|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (FUNCTION_TABLE_ii[$14 & 4095]($0)|0);
  HEAP32[$depth>>2] = $15;
 } else {
  $2 = (($rt) + 140|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$color>>2] = $3;
  $4 = (($rt) + 144|0);
  $5 = HEAP32[$4>>2]|0;
  HEAP32[$rcolor>>2] = $5;
  $6 = (($rt) + 148|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$depth>>2] = $7;
 }
 if ($discardColor) {
  $16 = HEAP32[$color>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = HEAP32[$0>>2]|0;
   $19 = (($18) + 404|0);
   $20 = HEAP32[$19>>2]|0;
   FUNCTION_TABLE_vii[$20 & 4095]($0,$color);
  }
  $21 = HEAP32[$rcolor>>2]|0;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   $23 = HEAP32[$0>>2]|0;
   $24 = (($23) + 404|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vii[$25 & 4095]($0,$rcolor);
  }
 }
 if (!($discardDepth)) {
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$depth>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = HEAP32[$0>>2]|0;
 $29 = (($28) + 404|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($0,$depth);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture10GrabPixelsEiiii($this,$left,$bottom,$width,$height) {
 $this = $this|0;
 $left = $left|0;
 $bottom = $bottom|0;
 $width = $width|0;
 $height = $height|0;
 var $$$width = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$left = 0, $$width = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = (($this) + 140|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (($this) + 148|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   (__ZN13RenderTexture6CreateEv($this)|0);
  }
 }
 $8 = (($this) + 108|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(1);
 $11 = (($this) + 144|0);
 $12 = (($this) + 140|0);
 $13 = $10 ? $11 : $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ($left|0)<(0);
 $17 = $16 ? $left : 0;
 $$width = (($17) + ($width))|0;
 $$left = $16 ? 0 : $left;
 $18 = ($bottom|0)<(0);
 $19 = $18 ? $bottom : 0;
 $$02 = (($19) + ($height))|0;
 $$01 = $18 ? 0 : $bottom;
 $20 = (($this) + 100|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($$width|0)>($21|0);
 $$$width = $22 ? $21 : $$width;
 $23 = (($this) + 104|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($$02|0)>($24|0);
 $$1 = $25 ? $24 : $$02;
 $26 = (__Z12GetGfxDevicev()|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 604|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$13>>2]|0;
 HEAP32[$0>>2] = $30;
 $31 = (($this) + 148|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP32[$1>>2] = $32;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_viiiiiii[$29 & 127]($26,$$byval_copy,$$byval_copy1,$$left,$$01,$$$width,$$1);
 $33 = (($26) + 5544|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (($26) + 5324|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 STACKTOP = sp;return;
}
function __ZN13RenderTexture24CorrectVerticalTexelSizeEb($this,$shouldBePositive) {
 $this = $this|0;
 $shouldBePositive = $shouldBePositive|0;
 var $$not = 0, $$not1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $brmerge = 0, $brmerge2 = 0, $shouldBePositive$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (($0) + 5932|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 76|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $$not = !($5 < Math_fround(0.0));
 $shouldBePositive$not = $shouldBePositive ^ 1;
 $brmerge = $$not | $shouldBePositive$not;
 if (!($brmerge)) {
  $6 = Math_fround(-$5);
  HEAPF32[$4>>2] = $6;
  STACKTOP = sp;return;
 }
 $$not1 = !($5 > Math_fround(0.0));
 $brmerge2 = $$not1 | $shouldBePositive;
 if ($brmerge2) {
  STACKTOP = sp;return;
 }
 $7 = Math_fround(-$5);
 HEAPF32[$4>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN13RenderTextureC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$01$i = 0, $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$label>>2]|0;
 HEAP32[$2>>2] = $3;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN7TextureC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy7,$mode);
 HEAP32[$this>>2] = ((606736 + 8|0));
 $4 = (($this) + 116|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 120|0);
 HEAP32[$5>>2] = 2;
 $6 = (($this) + 124|0);
 HEAP32[$6>>2] = 2;
 $7 = (($this) + 128|0);
 HEAP8[$7>>0] = 0;
 $8 = (($this) + 129|0);
 HEAP8[$8>>0] = 1;
 $9 = (($this) + 130|0);
 $10 = (($this) + 134|0);
 HEAP8[$9>>0]=0&255;HEAP8[$9+1>>0]=(0>>8)&255;HEAP8[$9+2>>0]=(0>>16)&255;HEAP8[$9+3>>0]=0>>24;
 HEAP8[$10>>0] = 1;
 $11 = (($this) + 136|0);
 $12 = (($this) + 164|0);
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;HEAP32[$11+24>>2]=0|0;
 HEAP32[$12>>2] = $this;
 $13 = (($this) + 100|0);
 HEAP32[$13>>2] = 256;
 $14 = (($this) + 104|0);
 HEAP32[$14>>2] = 256;
 $15 = (($this) + 112|0);
 HEAP32[$15>>2] = 1;
 $16 = (($this) + 108|0);
 HEAP32[$16>>2] = 1;
 $17 = (($this) + 40|0);
 HEAP32[$17>>2] = 1;
 __THREW__ = 0;
 $18 = (invoke_i(85)|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if (!($20)) {
  $21 = HEAP32[$18>>2]|0;
  $22 = (($21) + 456|0);
  $23 = HEAP32[$22>>2]|0;
  __THREW__ = 0;
  $24 = (invoke_ii($23|0,($18|0))|0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   HEAP32[$11>>2] = $24;
   $27 = (($this) + 168|0);
   HEAP8[$27>>0] = 0;
   STACKTOP = sp;return;
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 HEAP32[$this>>2] = ((608008 + 8|0));
 __THREW__ = 0;
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 L5: do {
  if ($31) {
   $43 = ___cxa_find_matching_catch(0|0)|0;
   $44 = tempRet0;
   $45 = (($this) + 92|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)>(-1);
   if ($47) {
    $48 = (($this) + 80|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($this) + 84|0);
    $51 = HEAP32[$50>>2]|0;
    HEAP32[$0>>2] = $51;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($49|0),($$byval_copy7|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $58 = ___cxa_find_matching_catch(0|0)|0;
     $59 = tempRet0;
     ___clang_call_terminate($58);
     // unreachable;
    } else {
     HEAP32[$48>>2] = 0;
     $$01$i = $43;
     break;
    }
   } else {
    $$01$i = $43;
   }
  } else {
   $32 = (($this) + 92|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)>(-1);
   do {
    if ($34) {
     $35 = (($this) + 80|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($this) + 84|0);
     $38 = HEAP32[$37>>2]|0;
     HEAP32[$1>>2] = $38;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($36|0),($$byval_copy7|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      $54 = ___cxa_find_matching_catch(0|0)|0;
      $55 = tempRet0;
      $$01$i = $54;
      break L5;
     } else {
      HEAP32[$35>>2] = 0;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if (!($42)) {
    ___resumeException($28|0);
    // unreachable;
   }
   $60 = ___cxa_find_matching_catch(0|0)|0;
   $61 = tempRet0;
   $eh$lpad$body$indexZ2D = $60;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $58 = ___cxa_find_matching_catch(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 }
 $eh$lpad$body$indexZ2D = $$01$i;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN7TextureD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((608008 + 8|0));
 __THREW__ = 0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if ($3) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   $15 = (($this) + 92|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(-1);
   if ($17) {
    $18 = (($this) + 80|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($this) + 84|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($19|0),($$byval_copy1|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $28 = ___cxa_find_matching_catch(0|0)|0;
     $29 = tempRet0;
     ___clang_call_terminate($28);
     // unreachable;
    } else {
     HEAP32[$18>>2] = 0;
     $$0 = $14;$$01 = $13;
     break;
    }
   } else {
    $$0 = $14;$$01 = $13;
   }
  } else {
   $4 = (($this) + 92|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)>(-1);
   if (!($6)) {
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
   $7 = (($this) + 80|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 84|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$1>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy1|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    $$0 = $25;$$01 = $24;
    break;
   }
   HEAP32[$7>>2] = 0;
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN13RenderTexture17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13RenderTexture7ReleaseEv($this);
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 160|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = HEAP32[((607992 + 4|0))>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  __ZN7Texture17MainThreadCleanupEv($this);
  STACKTOP = sp;return;
 }
 $10 = (($this) + 136|0);
 $11 = HEAP32[$10>>2]|0;
 $$0$ph7$i$i$i$i = ((607992 + 4|0));$$01$ph6$i$in$i$i$i = $8;
 L7: while(1) {
  $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
  while(1) {
   $12 = (($$013$i$in$i$i$i) + 16|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13>>>0)<($11>>>0);
   if (!($14)) {
    break;
   }
   $17 = (($$013$i$in$i$i$i) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
    break L7;
   } else {
    $$013$i$in$i$i$i = $18;
   }
  }
  $15 = HEAP32[$$013$i$in$i$i$i>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
   break;
  } else {
   $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $15;
  }
 }
 $20 = ($$0$ph5$i$i$i$i|0)==(((607992 + 4|0))|0);
 if ($20) {
  __ZN7Texture17MainThreadCleanupEv($this);
  STACKTOP = sp;return;
 }
 $21 = (($$0$ph5$i$i$i$i) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($11>>>0)<($22>>>0);
 if ($23) {
  __ZN7Texture17MainThreadCleanupEv($this);
  STACKTOP = sp;return;
 }
 $24 = (($$0$ph5$i$i$i$i) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $$01$i$i$i$i$i = $$0$ph5$i$i$i$i;
  while(1) {
   $29 = (($$01$i$i$i$i$i) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($$01$i$i$i$i$i|0);
   if ($32) {
    $$0$i$i$i$i$i = $30;
    break;
   } else {
    $$01$i$i$i$i$i = $30;
   }
  }
 } else {
  $$0$i$i$i$i$i$i = $25;
  while(1) {
   $27 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i$i = $27;
   }
  }
 }
 $33 = HEAP32[607992>>2]|0;
 $34 = ($33|0)==($$0$ph5$i$i$i$i|0);
 if ($34) {
  HEAP32[607992>>2] = $$0$i$i$i$i$i;
 }
 $35 = HEAP32[((607992 + 8|0))>>2]|0;
 $36 = (($35) + -1)|0;
 HEAP32[((607992 + 8|0))>>2] = $36;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($8,$$0$ph5$i$i$i$i);
 __ZdlPv($$0$ph5$i$i$i$i);
 __ZN7Texture17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture12SetDimensionE16TextureDimension($this,$dim) {
 $this = $this|0;
 $dim = $dim|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($dim|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($this) + 148|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   HEAP32[$0>>2] = $dim;
   STACKTOP = sp;return;
  } else {
   label = 6;
  }
 } else {
  $9 = ($this|0)==(0|0);
  if ($9) {
   $12 = 0;
  } else {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606888,0,606160,580,1,$12,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture15SetAntiAliasingEi($this,$aa) {
 $this = $this|0;
 $aa = $aa|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $aa$off = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($aa|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $aa$off = (($aa) + -1)|0;
 $3 = ($aa$off>>>0)<(8);
 $4 = $aa$off & $aa;
 $5 = ($4|0)==(0);
 $or$cond = $3 & $5;
 if (!($or$cond)) {
  $6 = ($this|0)==(0|0);
  if ($6) {
   $9 = 0;
  } else {
   $7 = (($this) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(606960,0,606160,601,1,$9,0,0);
  STACKTOP = sp;return;
 }
 $10 = (($this) + 140|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = (($this) + 148|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   HEAP32[$0>>2] = $aa;
   STACKTOP = sp;return;
  }
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607016,0,606160,608,1,$17,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture9SetMipMapEb($this,$mipMap) {
 $this = $this|0;
 $mipMap = $mipMap|0;
 var $$0$off0$$i = 0, $$0$off0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $extract$t2$$i = 0, $extract$t3$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[((640792 + 140|0))>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 $2 = (($this) + 124|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(4);
 $extract$t3$i = $1 & $mipMap;
 if ($4) {
  $5 = HEAP8[((640792 + 275|0))>>0]|0;
  $6 = ($5<<24>>24)==(0);
  $extract$t2$$i = $6 & $extract$t3$i;
  $$0$off0$i = $extract$t2$$i;
 } else {
  $$0$off0$i = $extract$t3$i;
 }
 $7 = ($3|0)!=(3);
 $8 = HEAP8[((640792 + 276|0))>>0]|0;
 $9 = ($8<<24>>24)==(0);
 $or$cond$i = $7 | $9;
 $$0$off0$$i = $or$cond$i & $$0$off0$i;
 $10 = $$0$off0$$i&1;
 $11 = (($this) + 128|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = ($10|0)==($13|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 140|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $18 = (($this) + 148|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   $21 = $$0$off0$$i&1;
   HEAP8[$11>>0] = $21;
   STACKTOP = sp;return;
  } else {
   label = 8;
  }
 } else {
  $22 = ($this|0)==(0|0);
  if ($22) {
   $25 = 0;
  } else {
   label = 8;
  }
 }
 if ((label|0) == 8) {
  $23 = (($this) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607096,0,606160,622,1,$25,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture16SetSRGBReadWriteEb($this,$sRGB) {
 $this = $this|0;
 $sRGB = $sRGB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 148|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   if ($sRGB) {
    $6 = (__Z19GetActiveColorSpacev()|0);
    $7 = ($6|0)==(1);
    if ($7) {
     $8 = (($this) + 116|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (__Z12GetGfxDevicev()|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($11) + 676|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
     $15 = ($9|0)!=($14|0);
     $phitmp = $15&1;
     $17 = $phitmp;
    } else {
     $17 = 0;
    }
   } else {
    $17 = 0;
   }
   $16 = (($this) + 130|0);
   HEAP8[$16>>0] = $17;
   STACKTOP = sp;return;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607160,0,606160,651,1,$19,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$$i = 0, $$0$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(1);
 $3 = $2 ? $1 : 1;
 HEAP32[$0>>2] = $3;
 $4 = (($this) + 104|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(1);
 $7 = $6 ? $5 : 1;
 HEAP32[$4>>2] = $7;
 $8 = (($this) + 112|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(1);
 $11 = $10 ? $9 : 1;
 HEAP32[$8>>2] = $11;
 $12 = (($this) + 108|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)<(1);
 if ($14) {
  $$0$i = 1;
 } else {
  $15 = ($13|0)>(8);
  $$$i = $15 ? 8 : $13;
  $$0$i = $$$i;
 }
 HEAP32[$12>>2] = $$0$i;
 $16 = (($this) + 116|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (__Z15IsDepthRTFormat19RenderTextureFormat($17)|0);
 if ($18) {
  $19 = (($this) + 128|0);
  HEAP8[$19>>0] = 0;
 }
 $20 = (($this) + 124|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(4);
 $23 = HEAP32[$0>>2]|0;
 if ($22) {
  HEAP32[$4>>2] = $23;
 }
 $24 = (($23) + -1)|0;
 $25 = $24 & $23;
 $26 = ($25|0)==(0);
 if ($26) {
  $27 = HEAP32[$4>>2]|0;
  $28 = (($27) + -1)|0;
  $29 = $28 & $27;
  $30 = ($29|0)==(0);
  if (!($30)) {
   label = 9;
  }
 } else {
  label = 9;
 }
 if ((label|0) == 9) {
  $31 = (($this) + 40|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(0);
  if ($33) {
   HEAP32[$31>>2] = 1;
  }
 }
 $34 = HEAP32[$16>>2]|0;
 $35 = (__Z15IsDepthRTFormat19RenderTextureFormat($34)|0);
 if ($35) {
  $36 = (($this) + 40|0);
  HEAP32[$36>>2] = 1;
 }
 $37 = (($this) + 156|0);
 $38 = ($37|0)==(606072|0);
 if (!($38)) {
  $39 = HEAP32[$37>>2]|0;
  $40 = ($39|0)==(0|0);
  $$pre$i$i = (($this) + 160|0);
  if (!($40)) {
   $41 = HEAP32[$$pre$i$i>>2]|0;
   $42 = (($39) + 4|0);
   HEAP32[$42>>2] = $41;
   $43 = HEAP32[$37>>2]|0;
   $44 = HEAP32[$$pre$i$i>>2]|0;
   HEAP32[$44>>2] = $43;
   HEAP32[$37>>2] = 0;
   HEAP32[$$pre$i$i>>2] = 0;
  }
  $45 = HEAP32[606072>>2]|0;
  HEAP32[$37>>2] = $45;
  HEAP32[$$pre$i$i>>2] = 606072;
  $46 = (($45) + 4|0);
  HEAP32[$46>>2] = $37;
  $47 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$47>>2] = $37;
 }
 $48 = (($this) + 64|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($this) + 68|0);
 HEAPF32[$49>>2] = Math_fround(1.0);
 __ZN7Texture20NotifyUVScaleChangedEv($this);
 $50 = HEAP32[$0>>2]|0;
 $51 = ($50|0)==(0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $52 = HEAP32[$4>>2]|0;
 $53 = ($52|0)==(0);
 if ($53) {
  STACKTOP = sp;return;
 }
 $54 = (Math_fround(($50|0)));
 $55 = Math_fround(Math_fround(1.0) / $54);
 $56 = (Math_fround(($52|0)));
 $57 = Math_fround(Math_fround(1.0) / $56);
 $58 = (($this) + 72|0);
 HEAPF32[$58>>2] = $55;
 $59 = (($this) + 76|0);
 HEAPF32[$59>>2] = $57;
 STACKTOP = sp;return;
}
function __ZN13RenderTexture8SetWidthEi($this,$width) {
 $this = $this|0;
 $width = $width|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 148|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $6 = (($this) + 100|0);
   HEAP32[$6>>2] = $width;
   $7 = (($this) + 64|0);
   HEAPF32[$7>>2] = Math_fround(1.0);
   $8 = (($this) + 68|0);
   HEAPF32[$8>>2] = Math_fround(1.0);
   __ZN7Texture20NotifyUVScaleChangedEv($this);
   $9 = HEAP32[$6>>2]|0;
   $10 = ($9|0)==(0);
   if ($10) {
    STACKTOP = sp;return;
   }
   $11 = (($this) + 104|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    STACKTOP = sp;return;
   }
   $14 = (Math_fround(($9|0)));
   $15 = Math_fround(Math_fround(1.0) / $14);
   $16 = (Math_fround(($12|0)));
   $17 = Math_fround(Math_fround(1.0) / $16);
   $18 = (($this) + 72|0);
   HEAPF32[$18>>2] = $15;
   $19 = (($this) + 76|0);
   HEAPF32[$19>>2] = $17;
   STACKTOP = sp;return;
  }
 }
 $20 = (($this) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607216,0,606160,703,1,$21,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture9SetHeightEi($this,$height) {
 $this = $this|0;
 $height = $height|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 148|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $6 = (($this) + 104|0);
   HEAP32[$6>>2] = $height;
   $7 = (($this) + 64|0);
   HEAPF32[$7>>2] = Math_fround(1.0);
   $8 = (($this) + 68|0);
   HEAPF32[$8>>2] = Math_fround(1.0);
   __ZN7Texture20NotifyUVScaleChangedEv($this);
   $9 = (($this) + 100|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    STACKTOP = sp;return;
   }
   $12 = HEAP32[$6>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    STACKTOP = sp;return;
   }
   $14 = (Math_fround(($10|0)));
   $15 = Math_fround(Math_fround(1.0) / $14);
   $16 = (Math_fround(($12|0)));
   $17 = Math_fround(Math_fround(1.0) / $16);
   $18 = (($this) + 72|0);
   HEAPF32[$18>>2] = $15;
   $19 = (($this) + 76|0);
   HEAPF32[$19>>2] = $17;
   STACKTOP = sp;return;
  }
 }
 $20 = (($this) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607216,0,606160,713,1,$21,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture14SetDepthFormatE17DepthBufferFormat($this,$depth) {
 $this = $this|0;
 $depth = $depth|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 148|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $6 = ($depth>>>0)>(2);
   if ($6) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607264,0,606160,722,1,0,0,0);
    STACKTOP = sp;return;
   } else {
    $7 = (($this) + 120|0);
    HEAP32[$7>>2] = $depth;
    STACKTOP = sp;return;
   }
  }
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607296,0,606160,728,1,$9,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture14SetColorFormatE19RenderTextureFormat($this,$format) {
 $this = $this|0;
 $format = $format|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 148|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $6 = ($format|0)==(7);
   if ($6) {
    $7 = (__Z12GetGfxDevicev()|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + 672|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
    $$0 = $11;
   } else {
    $$0 = $format;
   }
   $12 = ($$0>>>0)>(21);
   if ($12) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607360,0,606160,740,1,0,0,0);
    STACKTOP = sp;return;
   }
   $13 = (($this) + 116|0);
   HEAP32[$13>>2] = $$0;
   $14 = (__Z15IsDepthRTFormat19RenderTextureFormat($$0)|0);
   if (!($14)) {
    STACKTOP = sp;return;
   }
   $15 = (($this) + 32|0);
   HEAP32[$15>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(607392,0,606160,747,1,$17,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture17SetGlobalPropertyERKN9ShaderLab16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[652824>>2]|0;
 $1 = (($0) + 20|0);
 $2 = (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($1,$name,$this)|0);
 __ZN9ShaderLab6TexEnv15SetTextureScaleEff($2,Math_fround(1.0),Math_fround(1.0));
 __ZN9ShaderLab6TexEnv16SetTextureOffsetEff($2,Math_fround(0.0),Math_fround(0.0));
 STACKTOP = sp;return ($2|0);
}
function __ZN13RenderTexture10ReleaseAllEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13RenderTexture9SetActiveEPS_i11CubemapFacej(0,0,-1,0);
 $0 = HEAP32[((606072 + 4|0))>>2]|0;
 $1 = ($0|0)==(606072|0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $3 = $0;
 }
 while(1) {
  $2 = (($3) + 8|0);
  $4 = HEAP32[$2>>2]|0;
  __ZN13RenderTexture7ReleaseEv($4);
  $5 = (($3) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(606072|0);
  if ($7) {
   break;
  } else {
   $3 = $6;
  }
 }
 STACKTOP = sp;return;
}
function __Z25EstimateRenderTextureSizeiii19RenderTextureFormat17DepthBufferFormat16TextureDimensionb($width,$height,$depth,$format,$depthFormat,$dim,$mipMap) {
 $width = $width|0;
 $height = $height|0;
 $depth = $depth|0;
 $format = $format|0;
 $depthFormat = $depthFormat|0;
 $dim = $dim|0;
 $mipMap = $mipMap|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $colorBPP$0 = 0, $mipMap$not = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $size$0 = 0, $size$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($format|0)!=(1);
 $1 = HEAP8[((640792 + 247|0))>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $or$cond = $0 | $2;
 if ($or$cond) {
  $3 = ($format|0)!=(3);
  $4 = HEAP8[((640792 + 249|0))>>0]|0;
  $5 = ($4<<24>>24)==(0);
  $or$cond3 = $3 | $5;
  if ($or$cond3) {
   $6 = (607456 + ($format<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $colorBPP$0 = $7;
  } else {
   $colorBPP$0 = 0;
  }
 } else {
  $colorBPP$0 = 0;
 }
 $8 = Math_imul($height, $width)|0;
 $9 = Math_imul($colorBPP$0, $8)|0;
 if ((($dim|0) == 4)) {
  $11 = ($9*6)|0;
  $size$0 = $11;
 } else if ((($dim|0) == 3)) {
  $10 = Math_imul($9, $depth)|0;
  $size$0 = $10;
 } else {
  $size$0 = $9;
 }
 $mipMap$not = $mipMap ^ 1;
 $12 = HEAP8[((640792 + 140|0))>>0]|0;
 $13 = ($12<<24>>24)==(0);
 $or$cond5 = $13 | $mipMap$not;
 if ($or$cond5) {
  $size$1 = $size$0;
 } else {
  $14 = (($size$0|0) / 3)&-1;
  $15 = (($14) + ($size$0))|0;
  $size$1 = $15;
 }
 $16 = (607544 + ($depthFormat<<2)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = Math_imul($17, $8)|0;
 $19 = (($18) + ($size$1))|0;
 STACKTOP = sp;return ($19|0);
}
function __ZNK13RenderTexture20GetRuntimeMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $colorBPP$0$i = 0, $mipMap$not$i = 0, $or$cond$i = 0;
 var $or$cond3$i = 0, $or$cond5$i = 0, $size$0$i = 0, $size$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 120|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 128|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($7|0)!=(1);
 $15 = HEAP8[((640792 + 247|0))>>0]|0;
 $16 = ($15<<24>>24)==(0);
 $or$cond$i = $14 | $16;
 if ($or$cond$i) {
  $17 = ($7|0)!=(3);
  $18 = HEAP8[((640792 + 249|0))>>0]|0;
  $19 = ($18<<24>>24)==(0);
  $or$cond3$i = $17 | $19;
  if ($or$cond3$i) {
   $20 = (607456 + ($7<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $colorBPP$0$i = $21;
  } else {
   $colorBPP$0$i = 0;
  }
 } else {
  $colorBPP$0$i = 0;
 }
 $22 = Math_imul($3, $1)|0;
 $23 = Math_imul($colorBPP$0$i, $22)|0;
 if ((($11|0) == 3)) {
  $24 = Math_imul($23, $5)|0;
  $size$0$i = $24;
 } else if ((($11|0) == 4)) {
  $25 = ($23*6)|0;
  $size$0$i = $25;
 } else {
  $size$0$i = $23;
 }
 $mipMap$not$i = ($13<<24>>24)==(0);
 $26 = HEAP8[((640792 + 140|0))>>0]|0;
 $27 = ($26<<24>>24)==(0);
 $or$cond5$i = $27 | $mipMap$not$i;
 if ($or$cond5$i) {
  $size$1$i = $size$0$i;
  $30 = (607544 + ($9<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = Math_imul($31, $22)|0;
  $33 = (($32) + ($size$1$i))|0;
  $34 = (($this) + 108|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = Math_imul($33, $35)|0;
  STACKTOP = sp;return ($36|0);
 }
 $28 = (($size$0$i|0) / 3)&-1;
 $29 = (($28) + ($size$0$i))|0;
 $size$1$i = $29;
 $30 = (607544 + ($9<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = Math_imul($31, $22)|0;
 $33 = (($32) + ($size$1$i))|0;
 $34 = (($this) + 108|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = Math_imul($33, $35)|0;
 STACKTOP = sp;return ($36|0);
}
function __Z27RegisterClass_RenderTexturev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(84,133,0,0,0);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(27)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN7Texture13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 13;
 dest=$3+0|0; src=607560+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 13|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,84,27,($0|0),172,(2401|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN13RenderTexture7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(172,$$byval_copy2,1,16,606160,41)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1743,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(606160|0),41);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK13RenderTexture25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 84;
}
function __ZN13RenderTexture23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607576,607560,$this,0);
 __ZN13RenderTexture8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,607576,607560,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN13RenderTexture8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13RenderTexture8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13RenderTexture8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13RenderTexture8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Texture8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13RenderTextureD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((606736 + 8|0));
 __THREW__ = 0;
 $1 = (invoke_i(71)|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = HEAP32[$1>>2]|0;
  $5 = (($4) + 460|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($this) + 136|0);
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$0>>2] = $8;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii($6|0,($1|0),($$byval_copy|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN7TextureD2Ev($this);
   STACKTOP = sp;return;
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3488,($this|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZN13RenderTextureD0Ev($this) {
 $this = $this|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i6 = 0, $$byval_copy16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body2$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy16 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((606736 + 8|0));
 __THREW__ = 0;
 $3 = (invoke_i(71)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = HEAP32[$3>>2]|0;
  $7 = (($6) + 460|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 136|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$2>>2] = $10;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii($8|0,($3|0),($$byval_copy16|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   HEAP32[$this>>2] = ((608008 + 8|0));
   __THREW__ = 0;
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   L4: do {
    if ($48) {
     $60 = ___cxa_find_matching_catch()|0;
     $61 = tempRet0;
     $62 = (($this) + 92|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63|0)>(-1);
     if ($64) {
      $65 = (($this) + 80|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = (($this) + 84|0);
      $68 = HEAP32[$67>>2]|0;
      HEAP32[$0>>2] = $68;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($66|0),($$byval_copy16|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       $75 = ___cxa_find_matching_catch(0|0)|0;
       $76 = tempRet0;
       ___clang_call_terminate($75);
       // unreachable;
      } else {
       HEAP32[$65>>2] = 0;
       $$0$i7 = $61;$$01$i6 = $60;
       break;
      }
     } else {
      $$0$i7 = $61;$$01$i6 = $60;
     }
    } else {
     $49 = (($this) + 92|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)>(-1);
     do {
      if ($51) {
       $52 = (($this) + 80|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (($this) + 84|0);
       $55 = HEAP32[$54>>2]|0;
       HEAP32[$1>>2] = $55;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($53|0),($$byval_copy16|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        $71 = ___cxa_find_matching_catch()|0;
        $72 = tempRet0;
        $$0$i7 = $72;$$01$i6 = $71;
        break L4;
       } else {
        HEAP32[$52>>2] = 0;
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3423,($this|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      __ZdlPv($this);
      STACKTOP = sp;return;
     }
     $77 = ___cxa_find_matching_catch()|0;
     $78 = tempRet0;
     $eh$lpad$body$index8Z2D = $78;$eh$lpad$body$indexZ2D = $77;
     __ZdlPv($this);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch(0|0)|0;
    $76 = tempRet0;
    ___clang_call_terminate($75);
    // unreachable;
   }
   $eh$lpad$body$index8Z2D = $$0$i7;$eh$lpad$body$indexZ2D = $$01$i6;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 HEAP32[$this>>2] = ((608008 + 8|0));
 __THREW__ = 0;
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 L27: do {
  if ($16) {
   $28 = ___cxa_find_matching_catch(0|0)|0;
   $29 = tempRet0;
   $30 = (($this) + 92|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)>(-1);
   if ($32) {
    $33 = (($this) + 80|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($this) + 84|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$0>>2] = $36;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($34|0),($$byval_copy16|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $43 = ___cxa_find_matching_catch(0|0)|0;
     $44 = tempRet0;
     ___clang_call_terminate($43);
     // unreachable;
    } else {
     HEAP32[$33>>2] = 0;
     $$01$i = $28;
     break;
    }
   } else {
    $$01$i = $28;
   }
  } else {
   $17 = (($this) + 92|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)>(-1);
   do {
    if ($19) {
     $20 = (($this) + 80|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($this) + 84|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$1>>2] = $23;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($21|0),($$byval_copy16|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      $39 = ___cxa_find_matching_catch(0|0)|0;
      $40 = tempRet0;
      $$01$i = $39;
      break L27;
     } else {
      HEAP32[$20>>2] = 0;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $eh$lpad$body$index8Z2D = $14;$eh$lpad$body$indexZ2D = $13;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $45 = ___cxa_find_matching_catch(0|0)|0;
   $46 = tempRet0;
   $eh$lpad$body2$indexZ2D = $45;
   ___clang_call_terminate($eh$lpad$body2$indexZ2D);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 }
 $eh$lpad$body2$indexZ2D = $$01$i;
 ___clang_call_terminate($eh$lpad$body2$indexZ2D);
 // unreachable;
}
function __ZNK13RenderTexture12GetDimensionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13RenderTexture12ExtractImageEP14ImageReferencei($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK13RenderTexture12GetDataWidthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13RenderTexture13GetDataHeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13RenderTexture9HasMipMapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK13RenderTexture12CountMipmapsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN13RenderTexture19UnloadFromGfxDeviceEb($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13RenderTexture17UploadToGfxDeviceEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13RenderTexture8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Texture8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 100|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre7;
 }
 $8 = (($this) + 104|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = HEAP32[$8>>2]|0;
  HEAP32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre8 = HEAP32[$1>>2]|0;
  $$pre9 = HEAP32[$4>>2]|0;
  $16 = $$pre8;$18 = $$pre9;
 }
 $14 = (($this) + 108|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = HEAP32[$14>>2]|0;
  HEAP32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre10 = HEAP32[$1>>2]|0;
  $$pre11 = HEAP32[$4>>2]|0;
  $22 = $$pre10;$24 = $$pre11;
 }
 $20 = (($this) + 120|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = HEAP32[$20>>2]|0;
  HEAP32[$22>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,4);
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $28 = $$pre12;$30 = $$pre13;
 }
 $26 = (($this) + 116|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)<($30>>>0);
 if ($29) {
  $31 = HEAP32[$26>>2]|0;
  HEAP32[$28>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,4);
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $34 = $$pre14;$36 = $$pre15;
 }
 $32 = (($this) + 128|0);
 $33 = (($34) + 1|0);
 $35 = ($33>>>0)<($36>>>0);
 if ($35) {
  $37 = HEAP8[$32>>0]|0;
  HEAP8[$34>>0] = $37;
  $38 = HEAP32[$1>>2]|0;
  $39 = (($38) + 1|0);
  HEAP32[$1>>2] = $39;
  $42 = $39;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$32,1);
  $$pre16 = HEAP32[$1>>2]|0;
  $42 = $$pre16;
 }
 $40 = (($this) + 129|0);
 $41 = (($42) + 1|0);
 $43 = HEAP32[$4>>2]|0;
 $44 = ($41>>>0)<($43>>>0);
 if ($44) {
  $45 = HEAP8[$40>>0]|0;
  HEAP8[$42>>0] = $45;
  $46 = HEAP32[$1>>2]|0;
  $47 = (($46) + 1|0);
  HEAP32[$1>>2] = $47;
  $50 = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$40,1);
  $$pre17 = HEAP32[$1>>2]|0;
  $50 = $$pre17;
 }
 $48 = (($this) + 130|0);
 $49 = (($50) + 1|0);
 $51 = HEAP32[$4>>2]|0;
 $52 = ($49>>>0)<($51>>>0);
 if ($52) {
  $53 = HEAP8[$48>>0]|0;
  HEAP8[$50>>0] = $53;
  $54 = HEAP32[$1>>2]|0;
  $55 = (($54) + 1|0);
  HEAP32[$1>>2] = $55;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  $56 = (($this) + 28|0);
  __ZN15TextureSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($56,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$48,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  $56 = (($this) + 28|0);
  __ZN15TextureSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($56,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN15TextureSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $11 = $$pre3;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $15 = $$pre4;$17 = $$pre5;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $21 = $$pre6;$23 = $$pre7;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __ZN13RenderTexture8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre$i$i$i7 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Texture8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 100|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre11 = HEAP32[$4>>2]|0;
  $12 = $$pre;$14 = $$pre11;$8 = $$pre$i$i$i;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $12 = $3;$14 = $5;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 104|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,4);
  $$pre$i$i$i1 = HEAP32[$10>>2]|0;
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $16 = $$pre$i$i$i1;$20 = $$pre12;$22 = $$pre13;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$1>>2] = $11;
  $16 = $15;$20 = $11;$22 = $14;
 }
 $17 = (_llvm_bswap_i32(($16|0))|0);
 HEAP32[$10>>2] = $17;
 $18 = (($this) + 108|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)>($22>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$18,4);
  $$pre$i$i$i3 = HEAP32[$18>>2]|0;
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $24 = $$pre$i$i$i3;$28 = $$pre14;$30 = $$pre15;
 } else {
  $23 = HEAP32[$20>>2]|0;
  HEAP32[$18>>2] = $23;
  HEAP32[$1>>2] = $19;
  $24 = $23;$28 = $19;$30 = $22;
 }
 $25 = (_llvm_bswap_i32(($24|0))|0);
 HEAP32[$18>>2] = $25;
 $26 = (($this) + 120|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre$i$i$i5 = HEAP32[$26>>2]|0;
  $$pre16 = HEAP32[$1>>2]|0;
  $$pre17 = HEAP32[$4>>2]|0;
  $32 = $$pre$i$i$i5;$36 = $$pre16;$38 = $$pre17;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $32 = $31;$36 = $27;$38 = $30;
 }
 $33 = (_llvm_bswap_i32(($32|0))|0);
 HEAP32[$26>>2] = $33;
 $34 = (($this) + 116|0);
 $35 = (($36) + 4|0);
 $37 = ($35>>>0)>($38>>>0);
 if ($37) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
  $$pre$i$i$i7 = HEAP32[$34>>2]|0;
  $$pre18 = HEAP32[$1>>2]|0;
  $$pre19 = HEAP32[$4>>2]|0;
  $40 = $$pre$i$i$i7;$44 = $$pre18;$46 = $$pre19;
 } else {
  $39 = HEAP32[$36>>2]|0;
  HEAP32[$34>>2] = $39;
  HEAP32[$1>>2] = $35;
  $40 = $39;$44 = $35;$46 = $38;
 }
 $41 = (_llvm_bswap_i32(($40|0))|0);
 HEAP32[$34>>2] = $41;
 $42 = (($this) + 128|0);
 $43 = (($44) + 1|0);
 $45 = ($43>>>0)>($46>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$42,1);
  $$pre20 = HEAP32[$1>>2]|0;
  $52 = $$pre20;
 } else {
  $47 = HEAP8[$44>>0]|0;
  HEAP8[$42>>0] = $47;
  $48 = HEAP32[$1>>2]|0;
  $49 = (($48) + 1|0);
  HEAP32[$1>>2] = $49;
  $52 = $49;
 }
 $50 = (($this) + 129|0);
 $51 = (($52) + 1|0);
 $53 = HEAP32[$4>>2]|0;
 $54 = ($51>>>0)>($53>>>0);
 if ($54) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$50,1);
  $$pre21 = HEAP32[$1>>2]|0;
  $60 = $$pre21;
 } else {
  $55 = HEAP8[$52>>0]|0;
  HEAP8[$50>>0] = $55;
  $56 = HEAP32[$1>>2]|0;
  $57 = (($56) + 1|0);
  HEAP32[$1>>2] = $57;
  $60 = $57;
 }
 $58 = (($this) + 130|0);
 $59 = (($60) + 1|0);
 $61 = HEAP32[$4>>2]|0;
 $62 = ($59>>>0)>($61>>>0);
 if ($62) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$58,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  $66 = (($this) + 28|0);
  __ZN15TextureSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($66,$transfer);
  STACKTOP = sp;return;
 } else {
  $63 = HEAP8[$60>>0]|0;
  HEAP8[$58>>0] = $63;
  $64 = HEAP32[$1>>2]|0;
  $65 = (($64) + 1|0);
  HEAP32[$1>>2] = $65;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  $66 = (($this) + 28|0);
  __ZN15TextureSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($66,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN15TextureSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre10 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre6;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre7;$21 = $$pre8;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $17;$24 = $$pre$i$i$i3;$28 = $$pre9;$30 = $$pre10;
 } else {
  $22 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = (HEAPF32[tempDoublePtr>>2]=$22,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $17;$24 = $23;$28 = $18;$30 = $21;
 }
 $25 = (_llvm_bswap_i32(($24|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $25;
 $26 = (($this) + 12|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$26,4);
  $$pre$i$i$i4 = HEAP32[$26>>2]|0;
  $32 = $$pre$i$i$i4;
  $33 = (_llvm_bswap_i32(($32|0))|0);
  HEAP32[$26>>2] = $33;
  STACKTOP = sp;return;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$0>>2] = $27;
  $32 = $31;
  $33 = (_llvm_bswap_i32(($32|0))|0);
  HEAP32[$26>>2] = $33;
  STACKTOP = sp;return;
 }
}
function __ZN13RenderTexture8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Texture8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 100|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre7;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 104|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre8 = HEAP32[$1>>2]|0;
  $$pre9 = HEAP32[$4>>2]|0;
  $16 = $$pre8;$18 = $$pre9;
 } else {
  $13 = HEAP32[$10>>2]|0;
  HEAP32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 108|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  $$pre10 = HEAP32[$1>>2]|0;
  $$pre11 = HEAP32[$4>>2]|0;
  $22 = $$pre10;$24 = $$pre11;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 }
 $20 = (($this) + 120|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $28 = $$pre12;$30 = $$pre13;
 } else {
  $25 = HEAP32[$22>>2]|0;
  HEAP32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 }
 $26 = (($this) + 116|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $34 = $$pre14;$36 = $$pre15;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 }
 $32 = (($this) + 128|0);
 $33 = (($34) + 1|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$32,1);
  $$pre16 = HEAP32[$1>>2]|0;
  $42 = $$pre16;
 } else {
  $37 = HEAP8[$34>>0]|0;
  HEAP8[$32>>0] = $37;
  $38 = HEAP32[$1>>2]|0;
  $39 = (($38) + 1|0);
  HEAP32[$1>>2] = $39;
  $42 = $39;
 }
 $40 = (($this) + 129|0);
 $41 = (($42) + 1|0);
 $43 = HEAP32[$4>>2]|0;
 $44 = ($41>>>0)>($43>>>0);
 if ($44) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$40,1);
  $$pre17 = HEAP32[$1>>2]|0;
  $50 = $$pre17;
 } else {
  $45 = HEAP8[$42>>0]|0;
  HEAP8[$40>>0] = $45;
  $46 = HEAP32[$1>>2]|0;
  $47 = (($46) + 1|0);
  HEAP32[$1>>2] = $47;
  $50 = $47;
 }
 $48 = (($this) + 130|0);
 $49 = (($50) + 1|0);
 $51 = HEAP32[$4>>2]|0;
 $52 = ($49>>>0)>($51>>>0);
 if ($52) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$48,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  $56 = (($this) + 28|0);
  __ZN15TextureSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($56,$transfer);
  STACKTOP = sp;return;
 } else {
  $53 = HEAP8[$50>>0]|0;
  HEAP8[$48>>0] = $53;
  $54 = HEAP32[$1>>2]|0;
  $55 = (($54) + 1|0);
  HEAP32[$1>>2] = $55;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  $56 = (($this) + 28|0);
  __ZN15TextureSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($56,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN15TextureSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $11 = $$pre3;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $15 = $$pre4;$17 = $$pre5;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $21 = $$pre6;$23 = $$pre7;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN13RenderTexture8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i2 = 0, $$sum$i$i$i$i$i7 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $converter$i$i11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i11 = sp;
 __ZN7Texture8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 100|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$0,607584,0);
 $1 = (($this) + 104|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$1,607592,0);
 $2 = (($this) + 108|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$2,607608,0);
 $3 = (($this) + 120|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$3,607624,0);
 $4 = (($this) + 116|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$4,607640,0);
 $5 = (($this) + 128|0);
 $6 = HEAP32[580544>>2]|0;
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,607656,$6,$converter$i$i11,0)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  do {
   if ($9) {
    $10 = (($transfer) + 12|0);
    $11 = (($transfer) + 80|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($transfer) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($transfer) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($transfer) + 32|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = Math_imul($20, $18)|0;
    $$sum$i$i$i$i$i = (($14) - ($21))|0;
    $22 = (($16) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$10>>2] = $22;
    $23 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($23)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $24 = (($16) + ($$sum1$i$i$i$i$i)|0);
     $25 = (($transfer) + 20|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($24>>>0)>($26>>>0);
     if (!($27)) {
      $28 = HEAP8[$22>>0]|0;
      HEAP8[$5>>0] = $28;
      $29 = HEAP32[$10>>2]|0;
      $30 = (($29) + 1|0);
      HEAP32[$10>>2] = $30;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($10,$5,1);
   } else {
    $31 = HEAP32[$converter$i$i11>>2]|0;
    $32 = ($31|0)==(0|0);
    if (!($32)) {
     (FUNCTION_TABLE_iii[$31 & 4095]($5,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $33 = (($this) + 129|0);
 $34 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,607672,$6,$converter$i$i11,0)|0);
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = ($34|0)>(0);
  do {
   if ($36) {
    $37 = (($transfer) + 12|0);
    $38 = (($transfer) + 80|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($transfer) + 16|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($transfer) + 28|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($transfer) + 32|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = Math_imul($47, $45)|0;
    $$sum$i$i$i$i$i2 = (($41) - ($48))|0;
    $49 = (($43) + ($$sum$i$i$i$i$i2)|0);
    HEAP32[$37>>2] = $49;
    $50 = ($$sum$i$i$i$i$i2|0)<(0);
    if (!($50)) {
     $$sum1$i$i$i$i$i3 = (($$sum$i$i$i$i$i2) + 1)|0;
     $51 = (($43) + ($$sum1$i$i$i$i$i3)|0);
     $52 = (($transfer) + 20|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51>>>0)>($53>>>0);
     if (!($54)) {
      $55 = HEAP8[$49>>0]|0;
      HEAP8[$33>>0] = $55;
      $56 = HEAP32[$37>>2]|0;
      $57 = (($56) + 1|0);
      HEAP32[$37>>2] = $57;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($37,$33,1);
   } else {
    $58 = HEAP32[$converter$i$i11>>2]|0;
    $59 = ($58|0)==(0|0);
    if (!($59)) {
     (FUNCTION_TABLE_iii[$58 & 4095]($33,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $60 = (($this) + 130|0);
 $61 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,607688,$6,$converter$i$i11,0)|0);
 $62 = ($61|0)==(0);
 if (!($62)) {
  $63 = ($61|0)>(0);
  do {
   if ($63) {
    $64 = (($transfer) + 12|0);
    $65 = (($transfer) + 80|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($66) + 12|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($transfer) + 16|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($transfer) + 28|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($transfer) + 32|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = Math_imul($74, $72)|0;
    $$sum$i$i$i$i$i7 = (($68) - ($75))|0;
    $76 = (($70) + ($$sum$i$i$i$i$i7)|0);
    HEAP32[$64>>2] = $76;
    $77 = ($$sum$i$i$i$i$i7|0)<(0);
    if (!($77)) {
     $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
     $78 = (($70) + ($$sum1$i$i$i$i$i8)|0);
     $79 = (($transfer) + 20|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($78>>>0)>($80>>>0);
     if (!($81)) {
      $82 = HEAP8[$76>>0]|0;
      HEAP8[$60>>0] = $82;
      $83 = HEAP32[$64>>2]|0;
      $84 = (($83) + 1|0);
      HEAP32[$64>>2] = $84;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($64,$60,1);
   } else {
    $85 = HEAP32[$converter$i$i11>>2]|0;
    $86 = ($85|0)==(0|0);
    if (!($86)) {
     (FUNCTION_TABLE_iii[$85 & 4095]($60,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $87 = (($this) + 28|0);
 $88 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,607696,607776,$converter$i$i11,1)|0);
 $89 = ($88|0)==(0);
 if ($89) {
  STACKTOP = sp;return;
 }
 $90 = ($88|0)>(0);
 if ($90) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$87,607720,0);
  $91 = (($this) + 32|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$91,607736,0);
  $92 = (($this) + 36|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$92,607744,0);
  $93 = (($this) + 40|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$93,607760,0);
 } else {
  $94 = HEAP32[$converter$i$i11>>2]|0;
  $95 = ($94|0)==(0|0);
  if (!($95)) {
   (FUNCTION_TABLE_iii[$94 & 4095]($87,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13RenderTexture8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Texture8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 100|0);
 $1 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607584,$1,$0,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 104|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607592,$1,$8,0);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 108|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607608,$1,$13,0);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 120|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607624,$1,$18,0);
 $19 = HEAP32[$2>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 116|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607640,$1,$23,0);
 $24 = HEAP32[$2>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 128|0);
 $29 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607656,$29,$28,0);
 $30 = HEAP32[$2>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$5>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $34 = (($this) + 129|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607672,$29,$34,0);
 $35 = HEAP32[$2>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$5>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $39 = (($this) + 130|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607688,$29,$39,0);
 $40 = HEAP32[$2>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$5>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $44 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607696,607776,$44,0);
 __ZN15TextureSettings8TransferI13ProxyTransferEEvRT_($44,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15TextureSettings8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607720,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607736,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 $13 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607744,$13,$12,0);
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$4>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,607760,$0,$18,0);
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$4>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __Z19GetColorBlockColorsPK11DXTColBlockP9Color8888($block,$colors) {
 $block = $block|0;
 $colors = $colors|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$block>>1]|0;
 $1 = (($block) + 2|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($0&65535) >>> 11;
 $4 = $3&65535;
 $5 = $4 << 3;
 $6 = $4 >>> 2;
 $7 = $5 | $6;
 $8 = $7&255;
 HEAP8[$colors>>0] = $8;
 $9 = ($0&65535) >>> 5;
 $10 = $9 & 63;
 $11 = $10&65535;
 $12 = $11 << 2;
 $13 = $11 >>> 4;
 $14 = $12 | $13;
 $15 = $14&255;
 $16 = (($colors) + 1|0);
 HEAP8[$16>>0] = $15;
 $17 = $0 & 31;
 $18 = $17&65535;
 $19 = $18 << 3;
 $20 = $18 >>> 2;
 $21 = $19 | $20;
 $22 = $21&255;
 $23 = (($colors) + 2|0);
 HEAP8[$23>>0] = $22;
 $24 = (($colors) + 3|0);
 HEAP8[$24>>0] = -1;
 $25 = ($2&65535) >>> 11;
 $26 = $25&65535;
 $27 = $26 << 3;
 $28 = $26 >>> 2;
 $29 = $27 | $28;
 $30 = $29&255;
 $31 = (($colors) + 4|0);
 HEAP8[$31>>0] = $30;
 $32 = ($2&65535) >>> 5;
 $33 = $32 & 63;
 $34 = $33&65535;
 $35 = $34 << 2;
 $36 = $34 >>> 4;
 $37 = $35 | $36;
 $38 = $37&255;
 $39 = (($colors) + 5|0);
 HEAP8[$39>>0] = $38;
 $40 = $2 & 31;
 $41 = $40&65535;
 $42 = $41 << 3;
 $43 = $41 >>> 2;
 $44 = $42 | $43;
 $45 = $44&255;
 $46 = (($colors) + 6|0);
 HEAP8[$46>>0] = $45;
 $47 = (($colors) + 7|0);
 HEAP8[$47>>0] = -1;
 $48 = ($0&65535)>($2&65535);
 if ($48) {
  $49 = $7 << 1;
  $50 = (($29) + ($49))|0;
  $51 = (($50>>>0) / 3)&-1;
  $52 = $51&255;
  $53 = (($colors) + 8|0);
  HEAP8[$53>>0] = $52;
  $54 = $14 << 1;
  $55 = (($54) + ($37))|0;
  $56 = (($55>>>0) / 3)&-1;
  $57 = $56&255;
  $58 = (($colors) + 9|0);
  HEAP8[$58>>0] = $57;
  $59 = $21 << 1;
  $60 = (($59) + ($44))|0;
  $61 = (($60>>>0) / 3)&-1;
  $62 = $61&255;
  $63 = (($colors) + 10|0);
  HEAP8[$63>>0] = $62;
  $64 = (($colors) + 11|0);
  HEAP8[$64>>0] = -1;
  $65 = $29 << 1;
  $66 = (($65) + ($7))|0;
  $67 = (($66>>>0) / 3)&-1;
  $68 = $67&255;
  $69 = (($colors) + 12|0);
  HEAP8[$69>>0] = $68;
  $70 = $37 << 1;
  $71 = (($70) + ($14))|0;
  $72 = (($71>>>0) / 3)&-1;
  $73 = $72&255;
  $74 = (($colors) + 13|0);
  HEAP8[$74>>0] = $73;
  $75 = $44 << 1;
  $76 = (($75) + ($21))|0;
  $77 = (($76>>>0) / 3)&-1;
  $78 = $77&255;
  $79 = (($colors) + 14|0);
  HEAP8[$79>>0] = $78;
  $80 = (($colors) + 15|0);
  HEAP8[$80>>0] = -1;
  STACKTOP = sp;return;
 } else {
  $81 = (($29) + ($7))|0;
  $82 = $81 >>> 1;
  $83 = $82&255;
  $84 = (($colors) + 8|0);
  HEAP8[$84>>0] = $83;
  $85 = (($37) + ($14))|0;
  $86 = $85 >>> 1;
  $87 = $86&255;
  $88 = (($colors) + 9|0);
  HEAP8[$88>>0] = $87;
  $89 = (($44) + ($21))|0;
  $90 = $89 >>> 1;
  $91 = $90&255;
  $92 = (($colors) + 10|0);
  HEAP8[$92>>0] = $91;
  $93 = (($colors) + 11|0);
  HEAP8[$93>>0] = -1;
  $94 = (($colors) + 12|0);
  HEAP8[$94>>0]=0&255;HEAP8[$94+1>>0]=(0>>8)&255;HEAP8[$94+2>>0]=(0>>16)&255;HEAP8[$94+3>>0]=0>>24;
  STACKTOP = sp;return;
 }
}
function __Z16DecodeColorBlockPjRK11DXTColBlockiPKj($dest,$colorBlock,$width,$colors) {
 $dest = $dest|0;
 $colorBlock = $colorBlock|0;
 $width = $width|0;
 $colors = $colors|0;
 var $$sum11 = 0, $$sum12 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum910 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$1$sum = 0, $scevgep$2$sum = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($colorBlock) + 4|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 & 3;
 $4 = (($colors) + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$dest>>2] = $5;
 $6 = (($dest) + 4|0);
 $7 = HEAP8[$0>>0]|0;
 $8 = $7&255;
 $9 = $8 >>> 2;
 $10 = $9 & 3;
 $11 = (($colors) + ($10<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$6>>2] = $12;
 $13 = (($dest) + 8|0);
 $14 = HEAP8[$0>>0]|0;
 $15 = $14&255;
 $16 = $15 >>> 4;
 $17 = $16 & 3;
 $18 = (($colors) + ($17<<2)|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$13>>2] = $19;
 $20 = (($dest) + 12|0);
 $21 = HEAP8[$0>>0]|0;
 $22 = $21&255;
 $23 = $22 >>> 6;
 $24 = (($colors) + ($23<<2)|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$20>>2] = $25;
 $26 = (($dest) + ($width<<2)|0);
 $27 = (($colorBlock) + 5|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = $28&255;
 $30 = $29 & 3;
 $31 = (($colors) + ($30<<2)|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP32[$26>>2] = $32;
 $$sum5 = (($width) + 1)|0;
 $33 = (($dest) + ($$sum5<<2)|0);
 $34 = HEAP8[$27>>0]|0;
 $35 = $34&255;
 $36 = $35 >>> 2;
 $37 = $36 & 3;
 $38 = (($colors) + ($37<<2)|0);
 $39 = HEAP32[$38>>2]|0;
 HEAP32[$33>>2] = $39;
 $$sum6 = (($width) + 2)|0;
 $40 = (($dest) + ($$sum6<<2)|0);
 $41 = HEAP8[$27>>0]|0;
 $42 = $41&255;
 $43 = $42 >>> 4;
 $44 = $43 & 3;
 $45 = (($colors) + ($44<<2)|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$40>>2] = $46;
 $$sum7 = (($width) + 3)|0;
 $47 = (($dest) + ($$sum7<<2)|0);
 $48 = HEAP8[$27>>0]|0;
 $49 = $48&255;
 $50 = $49 >>> 6;
 $51 = (($colors) + ($50<<2)|0);
 $52 = HEAP32[$51>>2]|0;
 HEAP32[$47>>2] = $52;
 $scevgep$1$sum = $width << 1;
 $53 = (($dest) + ($scevgep$1$sum<<2)|0);
 $54 = (($colorBlock) + 6|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = $55&255;
 $57 = $56 & 3;
 $58 = (($colors) + ($57<<2)|0);
 $59 = HEAP32[$58>>2]|0;
 HEAP32[$53>>2] = $59;
 $$sum910 = $scevgep$1$sum | 1;
 $60 = (($dest) + ($$sum910<<2)|0);
 $61 = HEAP8[$54>>0]|0;
 $62 = $61&255;
 $63 = $62 >>> 2;
 $64 = $63 & 3;
 $65 = (($colors) + ($64<<2)|0);
 $66 = HEAP32[$65>>2]|0;
 HEAP32[$60>>2] = $66;
 $$sum11 = (($$sum910) + 1)|0;
 $67 = (($dest) + ($$sum11<<2)|0);
 $68 = HEAP8[$54>>0]|0;
 $69 = $68&255;
 $70 = $69 >>> 4;
 $71 = $70 & 3;
 $72 = (($colors) + ($71<<2)|0);
 $73 = HEAP32[$72>>2]|0;
 HEAP32[$67>>2] = $73;
 $$sum12 = (($$sum910) + 2)|0;
 $74 = (($dest) + ($$sum12<<2)|0);
 $75 = HEAP8[$54>>0]|0;
 $76 = $75&255;
 $77 = $76 >>> 6;
 $78 = (($colors) + ($77<<2)|0);
 $79 = HEAP32[$78>>2]|0;
 HEAP32[$74>>2] = $79;
 $scevgep$2$sum = (($scevgep$1$sum) + ($width))|0;
 $80 = (($dest) + ($scevgep$2$sum<<2)|0);
 $81 = (($colorBlock) + 7|0);
 $82 = HEAP8[$81>>0]|0;
 $83 = $82&255;
 $84 = $83 & 3;
 $85 = (($colors) + ($84<<2)|0);
 $86 = HEAP32[$85>>2]|0;
 HEAP32[$80>>2] = $86;
 $$sum14 = (($scevgep$2$sum) + 1)|0;
 $87 = (($dest) + ($$sum14<<2)|0);
 $88 = HEAP8[$81>>0]|0;
 $89 = $88&255;
 $90 = $89 >>> 2;
 $91 = $90 & 3;
 $92 = (($colors) + ($91<<2)|0);
 $93 = HEAP32[$92>>2]|0;
 HEAP32[$87>>2] = $93;
 $$sum15 = (($scevgep$2$sum) + 2)|0;
 $94 = (($dest) + ($$sum15<<2)|0);
 $95 = HEAP8[$81>>0]|0;
 $96 = $95&255;
 $97 = $96 >>> 4;
 $98 = $97 & 3;
 $99 = (($colors) + ($98<<2)|0);
 $100 = HEAP32[$99>>2]|0;
 HEAP32[$94>>2] = $100;
 $$sum16 = (($scevgep$2$sum) + 3)|0;
 $101 = (($dest) + ($$sum16<<2)|0);
 $102 = HEAP8[$81>>0]|0;
 $103 = $102&255;
 $104 = $103 >>> 6;
 $105 = (($colors) + ($104<<2)|0);
 $106 = HEAP32[$105>>2]|0;
 HEAP32[$101>>2] = $106;
 STACKTOP = sp;return;
}
function __Z14DecompressDXT3iiiPKjPj($xblocks,$yblocks,$destWidth,$m_pCompBytes,$decompBytes) {
 $xblocks = $xblocks|0;
 $yblocks = $yblocks|0;
 $destWidth = $destWidth|0;
 $m_pCompBytes = $m_pCompBytes|0;
 $decompBytes = $decompBytes|0;
 var $$04$i$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$03$us = 0, $exitcond = 0, $exitcond$i$us = 0;
 var $exitcond8 = 0, $i$02$us = 0, $j$04$us = 0, $row$05$i$us = 0, $tmp$us = 0, $tmp1$us = 0, $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $u = sp;
 $0 = (($u) + 3|0);
 HEAP8[$0>>0] = 0;
 $1 = (($u) + 2|0);
 HEAP8[$1>>0] = -1;
 $2 = (($u) + 1|0);
 HEAP8[$2>>0] = -1;
 HEAP8[$u>>0] = -1;
 $3 = HEAP32[$u>>2]|0;
 $4 = ($yblocks|0)>(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = $xblocks << 2;
 $6 = ($xblocks|0)>(0);
 if ($6) {
  $j$04$us = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $54 = Math_imul($5, $j$04$us)|0;
  $55 = (($m_pCompBytes) + ($54<<2)|0);
  $9 = Math_imul($j$04$us, $destWidth)|0;
  $block$03$us = $55;$i$02$us = 0;
  while(1) {
   $8 = (($block$03$us) + 8|0);
   __Z19GetColorBlockColorsPK11DXTColBlockP9Color8888($8,$u);
   $tmp$us = (($i$02$us) + ($9))|0;
   $tmp1$us = $tmp$us << 2;
   $10 = (($decompBytes) + ($tmp1$us<<2)|0);
   __Z16DecodeColorBlockPjRK11DXTColBlockiPKj($10,$8,$destWidth,$u);
   $$04$i$us = $10;$row$05$i$us = 0;
   while(1) {
    $11 = (($block$03$us) + ($row$05$i$us<<1)|0);
    $12 = HEAP16[$11>>1]|0;
    $13 = HEAP32[$$04$i$us>>2]|0;
    $14 = $13 & $3;
    $15 = $12&65535;
    $16 = $15 & 15;
    $17 = $15 << 4;
    $18 = $16 | $17;
    $19 = $18 << 24;
    $20 = $19 | $14;
    HEAP32[$$04$i$us>>2] = $20;
    $21 = ($12&65535) >>> 4;
    $22 = (($$04$i$us) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = $23 & $3;
    $25 = $21&65535;
    $26 = $25 & 15;
    $27 = $25 << 4;
    $28 = $26 | $27;
    $29 = $28 << 24;
    $30 = $29 | $24;
    HEAP32[$22>>2] = $30;
    $31 = ($12&65535) >>> 8;
    $32 = (($$04$i$us) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = $33 & $3;
    $35 = $31&65535;
    $36 = $35 & 15;
    $37 = $35 << 4;
    $38 = $36 | $37;
    $39 = $38 << 24;
    $40 = $39 | $34;
    HEAP32[$32>>2] = $40;
    $41 = ($12&65535) >>> 12;
    $42 = (($$04$i$us) + 12|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = $43 & $3;
    $45 = $41&65535;
    $46 = $45 << 4;
    $47 = $46 | $45;
    $48 = $47 << 24;
    $49 = $44 | $48;
    HEAP32[$42>>2] = $49;
    $50 = (($row$05$i$us) + 1)|0;
    $51 = (($$04$i$us) + ($destWidth<<2)|0);
    $exitcond$i$us = ($50|0)==(4);
    if ($exitcond$i$us) {
     break;
    } else {
     $$04$i$us = $51;$row$05$i$us = $50;
    }
   }
   $52 = (($i$02$us) + 1)|0;
   $53 = (($block$03$us) + 16|0);
   $exitcond = ($52|0)==($xblocks|0);
   if ($exitcond) {
    break;
   } else {
    $block$03$us = $53;$i$02$us = $52;
   }
  }
  $7 = (($j$04$us) + 1)|0;
  $exitcond8 = ($7|0)==($yblocks|0);
  if ($exitcond8) {
   break;
  } else {
   $j$04$us = $7;
  }
 }
 STACKTOP = sp;return;
}
function __Z21DecodeAlpha3BitLinearPjRK23DXTAlphaBlock3BitLinearij($dest,$alphaBlock,$width,$alphazero) {
 $dest = $dest|0;
 $alphaBlock = $alphaBlock|0;
 $width = $width|0;
 $alphazero = $alphazero|0;
 var $$04 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alphas = 0, $exitcond = 0, $row$15 = 0, $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $u = sp;
 $alphas = sp + 64|0;
 $0 = $alphazero ^ -1;
 $1 = HEAP8[$alphaBlock>>0]|0;
 $2 = $1&255;
 HEAP16[$alphas>>1] = $2;
 $3 = (($alphaBlock) + 1|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (($alphas) + 2|0);
 HEAP16[$6>>1] = $5;
 $7 = $1&255;
 $8 = $4&255;
 $9 = ($1&255)>($4&255);
 if ($9) {
  $10 = ($7*6)|0;
  $11 = (($8) + 3)|0;
  $12 = (($11) + ($10))|0;
  $13 = (($12>>>0) / 7)&-1;
  $14 = $13&65535;
  $15 = (($alphas) + 4|0);
  HEAP16[$15>>1] = $14;
  $16 = ($7*5)|0;
  $17 = $4&255;
  $18 = $17 << 1;
  $19 = (($16) + 3)|0;
  $20 = (($19) + ($18))|0;
  $21 = (($20>>>0) / 7)&-1;
  $22 = $21&65535;
  $23 = (($alphas) + 6|0);
  HEAP16[$23>>1] = $22;
  $24 = $7 << 2;
  $25 = ($17*3)|0;
  $26 = $24 | 3;
  $27 = (($26) + ($25))|0;
  $28 = (($27>>>0) / 7)&-1;
  $29 = $28&65535;
  $30 = (($alphas) + 8|0);
  HEAP16[$30>>1] = $29;
  $31 = ($7*3)|0;
  $32 = $17 << 2;
  $33 = (($31) + 3)|0;
  $34 = (($33) + ($32))|0;
  $35 = (($34>>>0) / 7)&-1;
  $36 = $35&65535;
  $37 = (($alphas) + 10|0);
  HEAP16[$37>>1] = $36;
  $38 = $7 << 1;
  $39 = ($17*5)|0;
  $40 = (($38) + 3)|0;
  $41 = (($40) + ($39))|0;
  $42 = (($41>>>0) / 7)&-1;
  $43 = $42&65535;
  $44 = (($alphas) + 12|0);
  HEAP16[$44>>1] = $43;
  $45 = ($17*6)|0;
  $46 = (($7) + 3)|0;
  $47 = (($46) + ($45))|0;
  $48 = (($47>>>0) / 7)&-1;
  $49 = $48&65535;
  $50 = (($alphas) + 14|0);
  HEAP16[$50>>1] = $49;
 } else {
  $51 = $7 << 2;
  $52 = (($8) + 2)|0;
  $53 = (($52) + ($51))|0;
  $54 = (($53>>>0) / 5)&-1;
  $55 = $54&65535;
  $56 = (($alphas) + 4|0);
  HEAP16[$56>>1] = $55;
  $57 = ($7*3)|0;
  $58 = $4&255;
  $59 = $58 << 1;
  $60 = (($57) + 2)|0;
  $61 = (($60) + ($59))|0;
  $62 = (($61>>>0) / 5)&-1;
  $63 = $62&65535;
  $64 = (($alphas) + 6|0);
  HEAP16[$64>>1] = $63;
  $65 = $7 << 1;
  $66 = ($58*3)|0;
  $67 = (($65) + 2)|0;
  $68 = (($67) + ($66))|0;
  $69 = (($68>>>0) / 5)&-1;
  $70 = $69&65535;
  $71 = (($alphas) + 8|0);
  HEAP16[$71>>1] = $70;
  $72 = $58 << 2;
  $73 = (($7) + 2)|0;
  $74 = (($73) + ($72))|0;
  $75 = (($74>>>0) / 5)&-1;
  $76 = $75&65535;
  $77 = (($alphas) + 10|0);
  HEAP16[$77>>1] = $76;
  $78 = (($alphas) + 12|0);
  HEAP16[$78>>1] = 0;
  $79 = (($alphas) + 14|0);
  HEAP16[$79>>1] = 255;
 }
 $80 = (($alphaBlock) + 2|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = $81 & 7;
 $83 = $81 >>> 3;
 $84 = $83 & 7;
 $85 = $81 >>> 6;
 $86 = $85 & 7;
 $87 = $81 >>> 9;
 $88 = $87 & 7;
 $89 = $81 >>> 12;
 $90 = $89 & 7;
 $91 = $81 >>> 15;
 $92 = $91 & 7;
 $93 = $81 >>> 18;
 $94 = $93 & 7;
 $95 = $81 >>> 21;
 $96 = $95 & 7;
 $97 = (($alphaBlock) + 5|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = $98 & 7;
 $100 = $98 >>> 3;
 $101 = $100 & 7;
 $102 = $98 >>> 6;
 $103 = $102 & 7;
 $104 = $98 >>> 9;
 $105 = $104 & 7;
 $106 = $98 >>> 12;
 $107 = $106 & 7;
 $108 = $98 >>> 15;
 $109 = $108 & 7;
 $110 = $98 >>> 18;
 $111 = $110 & 7;
 $112 = $98 >>> 21;
 $113 = $112 & 7;
 $114 = (($alphas) + ($82<<1)|0);
 $115 = HEAP16[$114>>1]|0;
 $116 = $115&255;
 $117 = (($u) + 3|0);
 HEAP8[$117>>0] = $116;
 $118 = (($alphas) + ($84<<1)|0);
 $119 = HEAP16[$118>>1]|0;
 $120 = $119&255;
 $121 = (($u) + 7|0);
 HEAP8[$121>>0] = $120;
 $122 = (($alphas) + ($86<<1)|0);
 $123 = HEAP16[$122>>1]|0;
 $124 = $123&255;
 $125 = (($u) + 11|0);
 HEAP8[$125>>0] = $124;
 $126 = (($alphas) + ($88<<1)|0);
 $127 = HEAP16[$126>>1]|0;
 $128 = $127&255;
 $129 = (($u) + 15|0);
 HEAP8[$129>>0] = $128;
 $130 = (($alphas) + ($90<<1)|0);
 $131 = HEAP16[$130>>1]|0;
 $132 = $131&255;
 $133 = (($u) + 19|0);
 HEAP8[$133>>0] = $132;
 $134 = (($alphas) + ($92<<1)|0);
 $135 = HEAP16[$134>>1]|0;
 $136 = $135&255;
 $137 = (($u) + 23|0);
 HEAP8[$137>>0] = $136;
 $138 = (($alphas) + ($94<<1)|0);
 $139 = HEAP16[$138>>1]|0;
 $140 = $139&255;
 $141 = (($u) + 27|0);
 HEAP8[$141>>0] = $140;
 $142 = (($alphas) + ($96<<1)|0);
 $143 = HEAP16[$142>>1]|0;
 $144 = $143&255;
 $145 = (($u) + 31|0);
 HEAP8[$145>>0] = $144;
 $146 = (($alphas) + ($99<<1)|0);
 $147 = HEAP16[$146>>1]|0;
 $148 = $147&255;
 $149 = (($u) + 35|0);
 HEAP8[$149>>0] = $148;
 $150 = (($alphas) + ($101<<1)|0);
 $151 = HEAP16[$150>>1]|0;
 $152 = $151&255;
 $153 = (($u) + 39|0);
 HEAP8[$153>>0] = $152;
 $154 = (($alphas) + ($103<<1)|0);
 $155 = HEAP16[$154>>1]|0;
 $156 = $155&255;
 $157 = (($u) + 43|0);
 HEAP8[$157>>0] = $156;
 $158 = (($alphas) + ($105<<1)|0);
 $159 = HEAP16[$158>>1]|0;
 $160 = $159&255;
 $161 = (($u) + 47|0);
 HEAP8[$161>>0] = $160;
 $162 = (($alphas) + ($107<<1)|0);
 $163 = HEAP16[$162>>1]|0;
 $164 = $163&255;
 $165 = (($u) + 51|0);
 HEAP8[$165>>0] = $164;
 $166 = (($alphas) + ($109<<1)|0);
 $167 = HEAP16[$166>>1]|0;
 $168 = $167&255;
 $169 = (($u) + 55|0);
 HEAP8[$169>>0] = $168;
 $170 = (($alphas) + ($111<<1)|0);
 $171 = HEAP16[$170>>1]|0;
 $172 = $171&255;
 $173 = (($u) + 59|0);
 HEAP8[$173>>0] = $172;
 $174 = (($alphas) + ($113<<1)|0);
 $175 = HEAP16[$174>>1]|0;
 $176 = $175&255;
 $177 = (($u) + 63|0);
 HEAP8[$177>>0] = $176;
 $$04 = $dest;$row$15 = 0;
 while(1) {
  $178 = HEAP32[$$04>>2]|0;
  $179 = $178 & $alphazero;
  HEAP32[$$04>>2] = $179;
  $180 = (($u) + ($row$15<<4)|0);
  $181 = HEAP32[$180>>2]|0;
  $182 = $181 & $0;
  $183 = $182 | $179;
  HEAP32[$$04>>2] = $183;
  $184 = (($$04) + 4|0);
  $185 = HEAP32[$184>>2]|0;
  $186 = $185 & $alphazero;
  HEAP32[$184>>2] = $186;
  $187 = ((($u) + ($row$15<<4)|0) + 4|0);
  $188 = HEAP32[$187>>2]|0;
  $189 = $188 & $0;
  $190 = $189 | $186;
  HEAP32[$184>>2] = $190;
  $191 = (($$04) + 8|0);
  $192 = HEAP32[$191>>2]|0;
  $193 = $192 & $alphazero;
  HEAP32[$191>>2] = $193;
  $194 = ((($u) + ($row$15<<4)|0) + 8|0);
  $195 = HEAP32[$194>>2]|0;
  $196 = $195 & $0;
  $197 = $196 | $193;
  HEAP32[$191>>2] = $197;
  $198 = (($$04) + 12|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = $199 & $alphazero;
  HEAP32[$198>>2] = $200;
  $201 = ((($u) + ($row$15<<4)|0) + 12|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = $202 & $0;
  $204 = $203 | $200;
  HEAP32[$198>>2] = $204;
  $205 = (($row$15) + 1)|0;
  $206 = (($$04) + ($width<<2)|0);
  $exitcond = ($205|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $$04 = $206;$row$15 = $205;
  }
 }
 STACKTOP = sp;return;
}
function __Z41DecompressNativeTextureFormatWithMipLevel13TextureFormatiiiPKjiiPj($srcFormat,$srcWidth,$srcHeight,$mipLevel,$sourceData,$destWidth,$destHeight,$destData) {
 $srcFormat = $srcFormat|0;
 $srcWidth = $srcWidth|0;
 $srcHeight = $srcHeight|0;
 $mipLevel = $mipLevel|0;
 $sourceData = $sourceData|0;
 $destWidth = $destWidth|0;
 $destHeight = $destHeight|0;
 $destData = $destData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z29DecompressNativeTextureFormat13TextureFormatiiPKjiiPj($srcFormat,$srcWidth,$srcHeight,$sourceData,$destWidth,$destHeight,$destData)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z29DecompressNativeTextureFormat13TextureFormatiiPKjiiPj($srcFormat,$srcWidth,$srcHeight,$sourceData,$destWidth,$destHeight,$destData) {
 $srcFormat = $srcFormat|0;
 $srcWidth = $srcWidth|0;
 $srcHeight = $srcHeight|0;
 $sourceData = $sourceData|0;
 $destWidth = $destWidth|0;
 $destHeight = $destHeight|0;
 $destData = $destData|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$02$us$i = 0, $block$03$us$i = 0, $exitcond$i = 0, $exitcond$i6 = 0, $exitcond8$i = 0, $exitcond8$i3 = 0, $i$02$us$i = 0, $i$03$us$i = 0, $j$04$us$i = 0, $j$04$us$i7 = 0;
 var $tmp$us$i = 0, $tmp$us$i4 = 0, $tmp1$us$i = 0, $tmp1$us$i5 = 0, $u$i = 0, $u$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $u$i1 = sp + 16|0;
 $u$i = sp;
 $0 = (($srcWidth) + 3)|0;
 $1 = (($0|0) / 4)&-1;
 $2 = (($srcHeight) + 3)|0;
 $3 = (($2|0) / 4)&-1;
 switch ($srcFormat|0) {
 case 12:  {
  $14 = (($u$i1) + 3|0);
  HEAP8[$14>>0] = 0;
  $15 = (($u$i1) + 2|0);
  HEAP8[$15>>0] = -1;
  $16 = (($u$i1) + 1|0);
  HEAP8[$16>>0] = -1;
  HEAP8[$u$i1>>0] = -1;
  $17 = HEAP32[$u$i1>>2]|0;
  $18 = ($srcHeight|0)>(0);
  if (!($18)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $19 = $1 << 2;
  $20 = ($srcWidth|0)>(0);
  if ($20) {
   $j$04$us$i7 = 0;
  } else {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  while(1) {
   $27 = Math_imul($19, $j$04$us$i7)|0;
   $28 = (($sourceData) + ($27<<2)|0);
   $23 = Math_imul($j$04$us$i7, $destWidth)|0;
   $block$03$us$i = $28;$i$02$us$i = 0;
   while(1) {
    $22 = (($block$03$us$i) + 8|0);
    __Z19GetColorBlockColorsPK11DXTColBlockP9Color8888($22,$u$i1);
    $tmp$us$i4 = (($i$02$us$i) + ($23))|0;
    $tmp1$us$i5 = $tmp$us$i4 << 2;
    $24 = (($destData) + ($tmp1$us$i5<<2)|0);
    __Z16DecodeColorBlockPjRK11DXTColBlockiPKj($24,$22,$destWidth,$u$i1);
    __Z21DecodeAlpha3BitLinearPjRK23DXTAlphaBlock3BitLinearij($24,$block$03$us$i,$destWidth,$17);
    $25 = (($i$02$us$i) + 1)|0;
    $26 = (($block$03$us$i) + 16|0);
    $exitcond$i6 = ($25|0)==($1|0);
    if ($exitcond$i6) {
     break;
    } else {
     $block$03$us$i = $26;$i$02$us$i = $25;
    }
   }
   $21 = (($j$04$us$i7) + 1)|0;
   $exitcond8$i3 = ($21|0)==($3|0);
   if ($exitcond8$i3) {
    $$0 = 1;
    break;
   } else {
    $j$04$us$i7 = $21;
   }
  }
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 11:  {
  __Z14DecompressDXT3iiiPKjPj($1,$3,$destWidth,$sourceData,$destData);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 46:  {
  __Z22DecompressETC2_RGB8_A1PhPKhiiii($destData,$sourceData,$srcWidth,$srcHeight,$destWidth,$destHeight);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 45:  {
  __Z19DecompressETC2_RGB8PhPKhiiii($destData,$sourceData,$srcWidth,$srcHeight,$destWidth,$destHeight);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 47:  {
  __Z20DecompressETC2_RGBA8PhPKhiiii($destData,$sourceData,$srcWidth,$srcHeight,$destWidth,$destHeight);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 10:  {
  $4 = ($srcHeight|0)>(0);
  if (!($4)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $5 = $1 << 1;
  $6 = ($srcWidth|0)>(0);
  if ($6) {
   $j$04$us$i = 0;
  } else {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  while(1) {
   $12 = Math_imul($5, $j$04$us$i)|0;
   $13 = (($sourceData) + ($12<<2)|0);
   $8 = Math_imul($j$04$us$i, $destWidth)|0;
   $block$02$us$i = $13;$i$03$us$i = 0;
   while(1) {
    __Z19GetColorBlockColorsPK11DXTColBlockP9Color8888($block$02$us$i,$u$i);
    $tmp$us$i = (($i$03$us$i) + ($8))|0;
    $tmp1$us$i = $tmp$us$i << 2;
    $9 = (($destData) + ($tmp1$us$i<<2)|0);
    __Z16DecodeColorBlockPjRK11DXTColBlockiPKj($9,$block$02$us$i,$destWidth,$u$i);
    $10 = (($i$03$us$i) + 1)|0;
    $11 = (($block$02$us$i) + 8|0);
    $exitcond$i = ($10|0)==($1|0);
    if ($exitcond$i) {
     break;
    } else {
     $block$02$us$i = $11;$i$03$us$i = $10;
    }
   }
   $7 = (($j$04$us$i) + 1)|0;
   $exitcond8$i = ($7|0)==($3|0);
   if ($exitcond8$i) {
    $$0 = 1;
    break;
   } else {
    $j$04$us$i = $7;
   }
  }
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __Z17InitScreenManagerv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(56)|0);
 __THREW__ = 0;
 invoke_vi(3489,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[607800>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __Z16GetScreenManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[607800>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z19GetScreenManagerPtrv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[607800>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN13ScreenManagerC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((607808 + 8|0));
 $0 = (($this) + 4|0);
 ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
 $1 = (($this) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 26|0);
 $3 = (($this) + 24|0);
 dest=$2+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 25|0);
 HEAP8[$4>>0] = 1;
 $5 = (($this) + 40|0);
 HEAP32[$5>>2] = 1;
 $6 = (($this) + 44|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13ScreenManager17RequestResolutionEiibi($this,$width,$height,$fullscreen,$preferredRefreshRate) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $fullscreen = $fullscreen|0;
 $preferredRefreshRate = $preferredRefreshRate|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $width;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $height;
 $2 = $fullscreen&1;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $2;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = $preferredRefreshRate;
 STACKTOP = sp;return;
}
function __ZN13ScreenManager21SetCursorInsideWindowEb($this,$insideWindow) {
 $this = $this|0;
 $insideWindow = $insideWindow|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 26|0);
 $1 = $insideWindow&1;
 HEAP8[$0>>0] = $1;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
 FUNCTION_TABLE_vii[$4 & 4095]($this,$7);
 STACKTOP = sp;return;
}
function __ZN13ScreenManager22SetRequestedResolutionEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $33 = 0;
 } else {
  $3 = (($this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(-1);
  if ($5) {
   $33 = 0;
  } else {
   $6 = HEAP32[$this>>2]|0;
   $7 = (($6) + 16|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(1);
   $12 = (($this) + 16|0);
   $13 = HEAP32[$12>>2]|0;
   (FUNCTION_TABLE_iiiiii[$8 & 255]($this,$1,$4,$11,$13)|0);
   ;HEAP32[$0+0>>2]=4294967295|0;HEAP32[$0+4>>2]=4294967295|0;HEAP32[$0+8>>2]=4294967295|0;HEAP32[$0+12>>2]=4294967295|0;
   $33 = 1;
  }
 }
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)!=(-1);
 if (!($16)) {
  $$ = $33 | $16;
  STACKTOP = sp;return ($$|0);
 }
 $17 = ($15|0)!=(0);
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 92|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_ii[$20 & 4095]($this)|0);
 $22 = $21 ^ $17;
 if ($22) {
  $23 = HEAP32[$this>>2]|0;
  $24 = (($23) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 80|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (FUNCTION_TABLE_ii[$27 & 4095]($this)|0);
  $29 = HEAP32[$this>>2]|0;
  $30 = (($29) + 84|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (FUNCTION_TABLE_ii[$31 & 4095]($this)|0);
  (FUNCTION_TABLE_iiiiii[$25 & 255]($this,$28,$32,$17,0)|0);
 }
 HEAP32[$14>>2] = -1;
 $$ = $33 | $16;
 STACKTOP = sp;return ($$|0);
}
function __ZN13ScreenManager24SetIsFullScreenImmediateEb($this,$fullscreen) {
 $this = $this|0;
 $fullscreen = $fullscreen|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = $3 ^ $fullscreen;
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($this)|0);
 $11 = HEAP32[$this>>2]|0;
 $12 = (($11) + 84|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 4095]($this)|0);
 (FUNCTION_TABLE_iiiiii[$7 & 255]($this,$10,$14,$fullscreen,0)|0);
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager19GetSystemResolutionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($agg$result,$this);
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager20GetCurrentResolutionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 4|0);
 $1 = (($agg$result) + 8|0);
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 HEAP32[$agg$result>>2] = $5;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($this)|0);
 HEAP32[$0>>2] = $9;
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13ScreenManager24SetupScreenManagerEditorEff($this,$w,$h) {
 $this = $this|0;
 $w = Math_fround($w);
 $h = Math_fround($h);
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($w + Math_fround(0.5));
 $1 = (~~(($0))>>>0);
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = $1;
 $3 = Math_fround($h + Math_fround(0.5));
 $4 = (~~(($3))>>>0);
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN13ScreenManager18SetAllowCursorLockEb($this,$allowLock) {
 $this = $this|0;
 $allowLock = $allowLock|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 25|0);
 $1 = $allowLock&1;
 HEAP8[$0>>0] = $1;
 if ($allowLock) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($this,0);
 STACKTOP = sp;return;
}
function __ZN13ScreenManager23SetIsOrientationEnabledE18EnabledOrientationb($this,$orientation,$enabled) {
 $this = $this|0;
 $orientation = $orientation|0;
 $enabled = $enabled|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($enabled) {
  $0 = (($this) + 36|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = $1 | $orientation;
  HEAP32[$0>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $3 = $orientation ^ -1;
  $4 = (($this) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 & $3;
  HEAP32[$4>>2] = $6;
  STACKTOP = sp;return;
 }
}
function __ZN13ScreenManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13ScreenManagerD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN13ScreenManager22SetResolutionImmediateEiibi($this,$0,$1,$2,$3) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN13ScreenManager14GetResolutionsEib($agg$result,$this,$0,$1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$agg$result>>2] = 0;
 $2 = (($agg$result) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($agg$result) + 8|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager13GetShowCursorEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN13ScreenManager13SetShowCursorEb($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager13GetLockCursorEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN13ScreenManager13SetLockCursorE14CursorLockMode($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager24GetAllowLayeredRenderingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN13ScreenManager24SetAllowLayeredRenderingEb($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager16GetScreenTimeoutEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __ZN13ScreenManager16SetScreenTimeoutEi($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager12GetIsFocusedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN13ScreenManager12SetIsFocusedEb($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager21GetCursorInsideWindowEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 26|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK13ScreenManager8GetWidthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13ScreenManager9GetHeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13ScreenManager6GetDPIEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return Math_fround(0.0);
}
function __ZNK13ScreenManager12IsFullScreenEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 27|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK13ScreenManager21IsMultiDisplayEnabledEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN13ScreenManager18RequestOrientationE17ScreenOrientation($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 HEAP32[$0>>2] = $value;
 STACKTOP = sp;return;
}
function __ZNK13ScreenManager20GetScreenOrientationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN13ScreenManager20SetScreenOrientationE17ScreenOrientation($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = $value;
 STACKTOP = sp;return;
}
function __ZN17SharedTextureDataC2E10MemLabelIdii13TextureFormatiibb($this,$label,$width,$height,$format,$imageSize,$imageCount,$mipmap,$initMemory) {
 $this = $this|0;
 $label = $label|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $imageSize = $imageSize|0;
 $imageCount = $imageCount|0;
 $mipmap = $mipmap|0;
 $initMemory = $initMemory|0;
 var $$01$i$i = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 HEAP32[$this>>2] = ((587472 + 8|0));
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = 1;
 HEAP32[$this>>2] = ((607936 + 8|0));
 $6 = HEAP32[$label>>2]|0;
 $7 = (($this) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 12|0);
 HEAP32[$8>>2] = $6;
 $9 = (($this) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 20|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 24|0);
 HEAP32[$11>>2] = $width;
 $12 = (($this) + 28|0);
 HEAP32[$12>>2] = $height;
 $13 = (($this) + 32|0);
 HEAP32[$13>>2] = $format;
 $14 = (($this) + 36|0);
 HEAP32[$14>>2] = $imageSize;
 $15 = (($this) + 40|0);
 HEAP32[$15>>2] = $imageCount;
 $16 = (($this) + 44|0);
 $17 = $mipmap&1;
 HEAP8[$16>>0] = $17;
 __THREW__ = 0;
 $18 = (invoke_ii(3248,($format|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 L1: do {
  if (!($20)) {
   $21 = Math_imul($imageCount, $imageSize)|0;
   $22 = (($18) + ($21))|0;
   if (!($initMemory)) {
    HEAP32[$9>>2] = $22;
    $55 = HEAP32[$10>>2]|0;
    $56 = $55 & 2147483647;
    $57 = ($56>>>0)<($22>>>0);
    if (!($57)) {
     STACKTOP = sp;return;
    }
    $58 = ($55|0)>(-1);
    if ($58) {
     HEAP32[$10>>2] = $22;
     $59 = HEAP32[$7>>2]|0;
     $60 = HEAP32[$8>>2]|0;
     HEAP32[$3>>2] = $60;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
     $61 = (invoke_iiiiiiii(108,($59|0),($22|0),1,($$byval_copy4|0),0,(607952|0),370)|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     HEAP32[$7>>2] = $61;
     STACKTOP = sp;return;
    } else {
     $64 = HEAP32[$8>>2]|0;
     HEAP32[$4>>2] = $64;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
     $65 = (invoke_iiiiiii(102,($22|0),1,($$byval_copy4|0),0,(607952|0),352)|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     $68 = HEAP32[$7>>2]|0;
     $69 = HEAP32[$9>>2]|0;
     _memcpy(($65|0),($68|0),($69|0))|0;
     HEAP32[$10>>2] = $22;
     HEAP32[$7>>2] = $65;
     STACKTOP = sp;return;
    }
   }
   $23 = HEAP32[$10>>2]|0;
   $24 = $23 & 2147483647;
   $25 = ($24>>>0)<($22>>>0);
   do {
    if ($25) {
     $26 = ($23|0)>(-1);
     if ($26) {
      HEAP32[$10>>2] = $22;
      $27 = HEAP32[$7>>2]|0;
      $28 = HEAP32[$8>>2]|0;
      HEAP32[$1>>2] = $28;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      $29 = (invoke_iiiiiiii(108,($27|0),($22|0),1,($$byval_copy4|0),0,(607952|0),370)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break L1;
      }
      HEAP32[$7>>2] = $29;
      break;
     } else {
      $32 = HEAP32[$8>>2]|0;
      HEAP32[$2>>2] = $32;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
      $33 = (invoke_iiiiiii(102,($22|0),1,($$byval_copy4|0),0,(607952|0),352)|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L1;
      }
      $36 = HEAP32[$7>>2]|0;
      $37 = HEAP32[$9>>2]|0;
      _memcpy(($33|0),($36|0),($37|0))|0;
      HEAP32[$10>>2] = $22;
      HEAP32[$7>>2] = $33;
      break;
     }
    }
   } while(0);
   $38 = HEAP32[$9>>2]|0;
   $39 = ($38>>>0)<($22>>>0);
   if ($39) {
    $40 = HEAP32[$7>>2]|0;
    $41 = (($40) + ($22)|0);
    $42 = ($38|0)==($22|0);
    if (!($42)) {
     $43 = (($40) + ($38)|0);
     $$01$i$i = $43;
     while(1) {
      $44 = ($$01$i$i|0)==(0|0);
      if (!($44)) {
       HEAP8[$$01$i$i>>0] = -51;
      }
      $45 = (($$01$i$i) + 1|0);
      $46 = ($45|0)==($41|0);
      if ($46) {
       break;
      } else {
       $$01$i$i = $45;
      }
     }
    }
   }
   HEAP32[$9>>2] = $22;
   STACKTOP = sp;return;
  }
 } while(0);
 $47 = ___cxa_find_matching_catch()|0;
 $48 = tempRet0;
 $49 = HEAP32[$10>>2]|0;
 $50 = ($49|0)>(-1);
 if (!($50)) {
  ___resumeException($47|0);
  // unreachable;
 }
 $51 = HEAP32[$7>>2]|0;
 $52 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $52;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($51|0),($$byval_copy4|0));
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 if ($54) {
  $70 = ___cxa_find_matching_catch(0|0)|0;
  $71 = tempRet0;
  ___clang_call_terminate($70);
  // unreachable;
 }
 HEAP32[$7>>2] = 0;
 ___resumeException($47|0);
 // unreachable;
}
function __ZN17SharedTextureData17GetImageReferenceEP14ImageReferenceii($this,$image,$frame,$mipLevel) {
 $this = $this|0;
 $image = $image|0;
 $frame = $frame|0;
 $mipLevel = $mipLevel|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0;
 var $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $format$off$i$i = (($5) + -10)|0;
 $6 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($5) + -30)|0;
 $7 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $6 | $7;
 $8 = ($5|0)==(34);
 $or$cond7$i = $or$cond$i | $8;
 $format$off$i4$i = (($5) + -35)|0;
 $9 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $9;
 $format$off$i3$i = (($5) + -41)|0;
 $10 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $10;
 $format$off$i2$i = (($5) + -45)|0;
 $11 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $11;
 $format$off$i1$i = (($5) + -48)|0;
 $12 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $12;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($this) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = Math_imul($14, $frame)|0;
 $16 = (($this) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__Z21CalculateMipMapOffsetii13TextureFormati($19,$21,$5,$mipLevel)|0);
 $$sum = (($22) + ($15))|0;
 $23 = (($17) + ($$sum)|0);
 $24 = HEAP32[$18>>2]|0;
 $25 = $24 >> $mipLevel;
 $26 = ($25|0)<(1);
 $27 = $26 ? 1 : $25;
 $28 = HEAP32[$20>>2]|0;
 $29 = $28 >> $mipLevel;
 $30 = ($29|0)<(1);
 $31 = $30 ? 1 : $29;
 $32 = HEAP32[$4>>2]|0;
 $33 = (__Z29GetRowBytesFromWidthAndFormati13TextureFormat($27,$32)|0);
 $34 = HEAP32[$4>>2]|0;
 __ZN14ImageReferenceC2Eiii13TextureFormatPv($0,$27,$31,$33,$34,$23);
 ;HEAP32[$image+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$image+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$image+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$image+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$image+16>>2]=HEAP32[$0+16>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17SharedTextureData15ExtractMipLevelEPS_iibb($this,$dst,$frame,$mipLevel,$checkCompression,$scaleToSize) {
 $this = $this|0;
 $dst = $dst|0;
 $frame = $frame|0;
 $mipLevel = $mipLevel|0;
 $checkCompression = $checkCompression|0;
 $scaleToSize = $scaleToSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0;
 var $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, $ref = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ref = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($dst) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = Math_imul($7, $frame)|0;
 $9 = (($dst) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($dst) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($dst) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (__Z21CalculateMipMapOffsetii13TextureFormati($10,$12,$14,$mipLevel)|0);
 $16 = (($15) + ($8))|0;
 $17 = (($dst) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + ($16)|0);
 $20 = HEAP32[$9>>2]|0;
 $21 = $20 >> $mipLevel;
 $22 = ($21|0)<(1);
 $23 = $22 ? 1 : $21;
 $24 = HEAP32[$11>>2]|0;
 $25 = $24 >> $mipLevel;
 $26 = ($25|0)<(1);
 $27 = $26 ? 1 : $25;
 if ($checkCompression) {
  $28 = HEAP32[$13>>2]|0;
  $format$off$i$i = (($28) + -10)|0;
  $29 = ($format$off$i$i>>>0)<(3);
  $format$off$i5$i = (($28) + -30)|0;
  $30 = ($format$off$i5$i>>>0)<(4);
  $or$cond$i = $29 | $30;
  $31 = ($28|0)==(34);
  $or$cond7$i = $or$cond$i | $31;
  $format$off$i4$i = (($28) + -35)|0;
  $32 = ($format$off$i4$i>>>0)<(2);
  $or$cond9$i = $or$cond7$i | $32;
  $format$off$i3$i = (($28) + -41)|0;
  $33 = ($format$off$i3$i>>>0)<(4);
  $or$cond11$i = $or$cond9$i | $33;
  $format$off$i2$i = (($28) + -45)|0;
  $34 = ($format$off$i2$i>>>0)<(3);
  $or$cond13$i = $or$cond11$i | $34;
  $format$off$i1$i = (($28) + -48)|0;
  $35 = ($format$off$i1$i>>>0)<(12);
  $or$cond = $or$cond13$i | $35;
  if ($or$cond) {
   __ZNK17SharedTextureData22ExtractCompressedImageEPhiii($this,$19,$23,$27,$frame);
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$ref+0>>2]=0|0;HEAP32[$ref+4>>2]=0|0;HEAP32[$ref+8>>2]=0|0;HEAP32[$ref+12>>2]=0|0;HEAP32[$ref+16>>2]=0|0;
 (__ZN17SharedTextureData17GetImageReferenceEP14ImageReferenceii($dst,$ref,$frame,$mipLevel)|0);
 (__ZNK17SharedTextureData12ExtractImageEP14ImageReferencebi($this,$ref,$scaleToSize,$frame)|0);
 STACKTOP = sp;return;
}
function __ZNK17SharedTextureData22ExtractCompressedImageEPhiii($this,$dst,$dstWidth,$dstHeight,$imageIndex) {
 $this = $this|0;
 $dst = $dst|0;
 $dstWidth = $dstWidth|0;
 $dstHeight = $dstHeight|0;
 $imageIndex = $imageIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z21SourceMipLevelForBlitiiii($1,$3,$dstWidth,$dstHeight)|0);
 $5 = (($this) + 44|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $12 = 0;
 } else {
  $8 = HEAP32[$0>>2]|0;
  $9 = HEAP32[$2>>2]|0;
  $10 = (__Z22CalculateMipMapCount3Diii($8,$9,1)|0);
  $phitmp = (($10) + -1)|0;
  $12 = $phitmp;
 }
 $11 = ($12|0)<($4|0);
 $13 = $11 ? $12 : $4;
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = (($this) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (__Z21CalculateMipMapOffsetii13TextureFormati($14,$15,$17,$13)|0);
 $19 = HEAP32[$0>>2]|0;
 $20 = $19 >> $13;
 $21 = ($20|0)<(1);
 $22 = $21 ? 1 : $20;
 $23 = HEAP32[$2>>2]|0;
 $24 = $23 >> $13;
 $25 = ($24|0)<(1);
 $26 = $25 ? 1 : $24;
 $27 = HEAP32[$16>>2]|0;
 $28 = (($this) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = Math_imul($29, $imageIndex)|0;
 $31 = (($30) + ($18))|0;
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + ($31)|0);
 __Z23BlitCopyCompressedImage13TextureFormatPKhiiPhiib($27,$34,$22,$26,$dst,$dstWidth,$dstHeight,1);
 STACKTOP = sp;return;
}
function __ZNK17SharedTextureData12ExtractImageEP14ImageReferencebi($this,$image,$scaleToSize,$imageIndex) {
 $this = $this|0;
 $image = $image|0;
 $scaleToSize = $scaleToSize|0;
 $imageIndex = $imageIndex|0;
 var $$0 = 0, $$1 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $clipped = 0, $decompressed = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0;
 var $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, $phitmp = 0, $source = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 64|0;
 $0 = sp;
 $decompressed = sp + 4|0;
 $clipped = sp + 24|0;
 $source = sp + 44|0;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($image) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($image) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__Z21SourceMipLevelForBlitiiii($2,$4,$6,$8)|0);
 $10 = (($this) + 44|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $17 = 0;
 } else {
  $13 = HEAP32[$1>>2]|0;
  $14 = HEAP32[$3>>2]|0;
  $15 = (__Z22CalculateMipMapCount3Diii($13,$14,1)|0);
  $phitmp = (($15) + -1)|0;
  $17 = $phitmp;
 }
 $16 = ($17|0)<($9|0);
 $18 = $16 ? $17 : $9;
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$3>>2]|0;
 $21 = (($this) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (__Z21CalculateMipMapOffsetii13TextureFormati($19,$20,$22,$18)|0);
 $24 = HEAP32[$1>>2]|0;
 $25 = $24 >> $18;
 $26 = ($25|0)<(1);
 $27 = $26 ? 1 : $25;
 $28 = HEAP32[$3>>2]|0;
 $29 = $28 >> $18;
 $30 = ($29|0)<(1);
 $31 = $30 ? 1 : $29;
 $32 = HEAP32[$21>>2]|0;
 $format$off$i$i = (($32) + -10)|0;
 $33 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($32) + -30)|0;
 $34 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $33 | $34;
 $35 = ($32|0)==(34);
 $or$cond7$i = $or$cond$i | $35;
 $format$off$i4$i = (($32) + -35)|0;
 $36 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $36;
 $format$off$i3$i = (($32) + -41)|0;
 $37 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $37;
 $format$off$i2$i = (($32) + -45)|0;
 $38 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $38;
 $format$off$i1$i = (($32) + -48)|0;
 $39 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $39;
 if (!($or$cond)) {
  $75 = (__Z25GetBytesFromTextureFormat13TextureFormat($32)|0);
  $76 = Math_imul($75, $27)|0;
  $77 = HEAP32[$21>>2]|0;
  $78 = (($this) + 36|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = Math_imul($79, $imageIndex)|0;
  $81 = (($80) + ($23))|0;
  $82 = (($this) + 8|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($83) + ($81)|0);
  __ZN14ImageReferenceC2Eiii13TextureFormatPv($source,$27,$31,$76,$77,$84);
  if ($scaleToSize) {
   __ZN14ImageReference9BlitImageERKS_NS_8BlitModeE($image,$source,2);
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  } else {
   __ZN14ImageReference9BlitImageERKS_NS_8BlitModeE($image,$source,0);
   __Z14PadImageBorderR14ImageReferenceii($image,$27,$31);
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $40 = (($27) + 3)|0;
 $41 = (($40|0) / 4)&-1;
 $42 = $41 << 2;
 $43 = (($31) + 3)|0;
 $44 = (($43|0) / 4)&-1;
 $45 = $44 << 2;
 __ZN5ImageC2Eii13TextureFormat($decompressed,$42,$45,4);
 $46 = (($this) + 36|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = Math_imul($47, $imageIndex)|0;
 $49 = (($48) + ($23))|0;
 $50 = (($this) + 8|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + ($49)|0);
 $53 = HEAP32[$21>>2]|0;
 $54 = (($decompressed) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 __THREW__ = 0;
 $56 = (invoke_iiiiiiiii(39,($53|0),($27|0),($31|0),($18|0),($52|0),($42|0),($45|0),($55|0))|0);
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 L12: do {
  if (!($58)) {
   do {
    if ($56) {
     __THREW__ = 0;
     invoke_viiiiii(108,($clipped|0),($decompressed|0),0,0,($27|0),($31|0));
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break L12;
     }
     if ($scaleToSize) {
      __THREW__ = 0;
      invoke_viii(1729,($image|0),($clipped|0),2);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break L12;
      } else {
       $$0 = 1;
       break;
      }
     }
     __THREW__ = 0;
     invoke_viii(1729,($image|0),($clipped|0),0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      break L12;
     }
     __THREW__ = 0;
     invoke_viii(1747,($image|0),($27|0),($31|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      break L12;
     } else {
      $$0 = 1;
     }
    } else {
     $$0 = 0;
    }
   } while(0);
   $73 = HEAP32[$54>>2]|0;
   $74 = HEAP32[628224>>2]|0;
   HEAP32[$0>>2] = $74;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($73,$$byval_copy1);
   $$1 = $$0;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 $59 = ___cxa_find_matching_catch()|0;
 $60 = tempRet0;
 $61 = HEAP32[$54>>2]|0;
 $62 = HEAP32[628224>>2]|0;
 HEAP32[$0>>2] = $62;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($61|0),($$byval_copy1|0));
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $85 = ___cxa_find_matching_catch(0|0)|0;
  $86 = tempRet0;
  ___clang_call_terminate($85);
  // unreachable;
 } else {
  ___resumeException($59|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN17SharedTextureDataD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((607936 + 8|0));
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17SharedTextureDataD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((607936 + 8|0));
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if (!($3)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($5|0),($$byval_copy|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZdlPv($this);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead8TransferI5RectTIfEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580648>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  __ZN14SafeBinaryRead10SetVersionEi($this,2);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$data,607960,0);
  $5 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$5,607968,0);
  $6 = (($data) + 8|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$6,607976,0);
  $7 = (($data) + 12|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$7,607984,0);
 } else {
  $8 = HEAP32[$converter$i>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   (FUNCTION_TABLE_iii[$8 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7TextureC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$0 = 0, $$01 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy1,$mode);
 HEAP32[$this>>2] = ((608008 + 8|0));
 $3 = (($this) + 28|0);
 __THREW__ = 0;
 invoke_vi(3490,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $29 = ___cxa_find_matching_catch()|0;
   $30 = tempRet0;
   $$0 = $29;$$01 = $30;
  } else {
   $6 = (($this) + 44|0);
   HEAP32[$6>>2] = 0;
   $7 = (($this) + 48|0);
   HEAP32[$7>>2] = 0;
   $8 = (($this) + 64|0);
   HEAPF32[$8>>2] = Math_fround(1.0);
   $9 = (($this) + 68|0);
   HEAPF32[$9>>2] = Math_fround(1.0);
   $10 = (($this) + 72|0);
   HEAPF32[$10>>2] = Math_fround(1.0);
   $11 = (($this) + 76|0);
   HEAPF32[$11>>2] = Math_fround(1.0);
   $12 = (($this) + 80|0);
   HEAP32[$12>>2] = 0;
   $13 = (($this) + 88|0);
   HEAP32[$13>>2] = 0;
   $14 = (($this) + 92|0);
   HEAP32[$14>>2] = 0;
   $15 = (($this) + 84|0);
   HEAP32[$15>>2] = 61;
   $16 = (($this) + 96|0);
   HEAP8[$16>>0] = 0;
   __THREW__ = 0;
   $17 = (invoke_i(85)|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP32[$17>>2]|0;
    $21 = (($20) + 456|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    $23 = (invoke_ii($22|0,($17|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     HEAP32[$6>>2] = $23;
     $26 = (($this) + 52|0);
     HEAP32[$26>>2] = 0;
     $27 = (($this) + 56|0);
     HEAP32[$27>>2] = 0;
     $28 = (($this) + 60|0);
     HEAP32[$28>>2] = 0;
     STACKTOP = sp;return;
    }
   }
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   $33 = HEAP32[$14>>2]|0;
   $34 = ($33|0)>(-1);
   if ($34) {
    $35 = HEAP32[$12>>2]|0;
    $36 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $36;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($35|0),($$byval_copy1|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $41 = ___cxa_find_matching_catch(0|0)|0;
     $42 = tempRet0;
     ___clang_call_terminate($41);
     // unreachable;
    } else {
     HEAP32[$12>>2] = 0;
     $$0 = $31;$$01 = $32;
     break;
    }
   } else {
    $$0 = $31;$$01 = $32;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN7Texture15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN7Texture17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[((607992 + 4|0))>>2]|0;
 $3 = ($2|0)==(0|0);
 $$pre = (($this) + 44|0);
 if (!($3)) {
  $4 = HEAP32[$$pre>>2]|0;
  $$0$ph7$i$i$i$i = ((607992 + 4|0));$$01$ph6$i$in$i$i$i = $2;
  L3: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $5 = (($$013$i$in$i$i$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6>>>0)<($4>>>0);
    if (!($7)) {
     break;
    }
    $10 = (($$013$i$in$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L3;
    } else {
     $$013$i$in$i$i$i = $11;
    }
   }
   $8 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $8;
   }
  }
  $13 = ($$0$ph5$i$i$i$i|0)==(((607992 + 4|0))|0);
  if (!($13)) {
   $14 = (($$0$ph5$i$i$i$i) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($4>>>0)<($15>>>0);
   if (!($16)) {
    $17 = (($$0$ph5$i$i$i$i) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $$01$i$i$i$i$i = $$0$ph5$i$i$i$i;
     while(1) {
      $22 = (($$01$i$i$i$i$i) + 8|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24|0)==($$01$i$i$i$i$i|0);
      if ($25) {
       $$0$i$i$i$i$i = $23;
       break;
      } else {
       $$01$i$i$i$i$i = $23;
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $18;
     while(1) {
      $20 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i$i = $20;
      }
     }
    }
    $26 = HEAP32[607992>>2]|0;
    $27 = ($26|0)==($$0$ph5$i$i$i$i|0);
    if ($27) {
     HEAP32[607992>>2] = $$0$i$i$i$i$i;
    }
    $28 = HEAP32[((607992 + 8|0))>>2]|0;
    $29 = (($28) + -1)|0;
    HEAP32[((607992 + 8|0))>>2] = $29;
    __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($2,$$0$ph5$i$i$i$i);
    __ZdlPv($$0$ph5$i$i$i$i);
   }
  }
 }
 $30 = (__Z25GetUncheckedRealGfxDevicev()|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 460|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$$pre>>2]|0;
 HEAP32[$1>>2] = $34;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_vii[$33 & 4095]($30,$$byval_copy1);
 HEAP32[$$pre>>2] = 0;
 $35 = (($this) + 80|0);
 $36 = (($this) + 88|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if (!($38)) {
  $i$02$i = 0;
  while(1) {
   $39 = HEAP32[$35>>2]|0;
   $40 = (($39) + ($i$02$i<<2)|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 16|0);
   HEAP32[$42>>2] = 0;
   $43 = (($41) + 20|0);
   HEAP32[$43>>2] = 0;
   $44 = (($i$02$i) + 1)|0;
   $45 = HEAP32[$36>>2]|0;
   $46 = ($44>>>0)<($45>>>0);
   if ($46) {
    $i$02$i = $44;
   } else {
    break;
   }
  }
 }
 $47 = (($this) + 92|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)>(-1);
 if (!($49)) {
  HEAP32[$36>>2] = 0;
  HEAP32[$47>>2] = 0;
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$35>>2]|0;
 $51 = (($this) + 84|0);
 $52 = HEAP32[$51>>2]|0;
 HEAP32[$0>>2] = $52;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($50,$$byval_copy1);
 HEAP32[$35>>2] = 0;
 HEAP32[$36>>2] = 0;
 HEAP32[$47>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7Texture16CheckConsistencyEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 __ZN15TextureSettings16CheckConsistencyEv($0);
 STACKTOP = sp;return;
}
function __ZN7Texture5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 56|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7Texture21SetMasterTextureLimitEib($i,$reloadTextures) {
 $i = $i|0;
 $reloadTextures = $reloadTextures|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $j$010 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $objects = 0, $pos$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $temp$0$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp;
 $objects = sp + 4|0;
 $1 = HEAP32[608160>>2]|0;
 $2 = ($1|0)==($i|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[608160>>2] = $i;
 if (!($reloadTextures)) {
  STACKTOP = sp;return;
 }
 HEAP32[$objects>>2] = 0;
 $3 = (($objects) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($objects) + 8|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1536,27,($objects|0),0)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L7: do {
  if ($6) {
   label = 19;
  } else {
   $7 = HEAP32[$3>>2]|0;
   $8 = HEAP32[$objects>>2]|0;
   $9 = ($7|0)==($8|0);
   L9: do {
    if (!($9)) {
     $11 = $8;$j$010 = 0;
     while(1) {
      $10 = (($11) + ($j$010<<2)|0);
      $12 = HEAP32[$10>>2]|0;
      HEAP32[$0>>2] = $12;
      $13 = HEAP32[560624>>2]|0;
      $14 = ($13|0)==(0|0);
      if ($14) {
       label = 14;
      } else {
       $15 = (($13) + 36|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = (($13) + 4|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = ($16|0)==($18|0);
       do {
        if ($19) {
         $20 = (($13) + 28|0);
         $21 = HEAP32[$20>>2]|0;
         $22 = (($13) + 32|0);
         $23 = HEAP32[$22>>2]|0;
         $24 = (($21) + ($23<<3)|0);
         $40 = $24;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$13,$0);
         $25 = HEAP32[$pos$i$i$i$i>>2]|0;
         $26 = ($25|0)==(-1);
         $27 = (($13) + 28|0);
         $28 = HEAP32[$27>>2]|0;
         if ($26) {
          $29 = (($13) + 32|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = (($28) + ($30<<3)|0);
          $40 = $31;
          break;
         } else {
          $32 = (($28) + ($25<<3)|0);
          $40 = $32;
          break;
         }
        }
       } while(0);
       $33 = HEAP32[560624>>2]|0;
       $34 = (($33) + 28|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = (($33) + 32|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + ($37<<3)|0);
       $39 = ($40|0)==($38|0);
       if ($39) {
        label = 14;
       } else {
        $41 = (($40) + 4|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = ($42|0)==(0|0);
        if ($43) {
         label = 14;
        } else {
         $temp$0$i = $42;
        }
       }
      }
      if ((label|0) == 14) {
       label = 0;
       __THREW__ = 0;
       $44 = (invoke_ii(3215,($12|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       } else {
        $temp$0$i = $44;
       }
      }
      $47 = HEAP32[$temp$0$i>>2]|0;
      $48 = (($47) + 136|0);
      $49 = HEAP32[$48>>2]|0;
      __THREW__ = 0;
      invoke_vii($49|0,($temp$0$i|0),0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
      $52 = HEAP32[$temp$0$i>>2]|0;
      $53 = (($52) + 140|0);
      $54 = HEAP32[$53>>2]|0;
      __THREW__ = 0;
      invoke_vi($54|0,($temp$0$i|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break;
      }
      $57 = (($j$010) + 1)|0;
      $58 = HEAP32[$3>>2]|0;
      $59 = HEAP32[$objects>>2]|0;
      $60 = $58;
      $61 = $59;
      $62 = (($60) - ($61))|0;
      $63 = $62 >> 2;
      $64 = ($57>>>0)<($63>>>0);
      if ($64) {
       $11 = $59;$j$010 = $57;
      } else {
       break L9;
      }
     }
     $65 = ___cxa_find_matching_catch()|0;
     $66 = tempRet0;
     $lpad$phi$index = $65;$lpad$phi$index2 = $66;
     break L7;
    }
   } while(0);
   __THREW__ = 0;
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 19;
   } else {
    $78 = HEAP32[$objects>>2]|0;
    $79 = ($78|0)==(0|0);
    if ($79) {
     STACKTOP = sp;return;
    }
    $80 = HEAP32[$3>>2]|0;
    $81 = ($80|0)==($78|0);
    if (!($81)) {
     $__new_last2$i$i$i$i$i = $78;
     $scevgep$i$i$i$i$i = (($80) + -4|0);
     $82 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($82)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $83 = $uglygep3$i$i$i$i$i >>> 2;
     $84 = $83 ^ -1;
     $scevgep4$i$i$i$i$i = (($80) + ($84<<2)|0);
     HEAP32[$3>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($78);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  $lpad$phi$index = $67;$lpad$phi$index2 = $68;
 }
 $69 = HEAP32[$objects>>2]|0;
 $70 = ($69|0)==(0|0);
 if ($70) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $71 = HEAP32[$3>>2]|0;
 $72 = ($71|0)==($69|0);
 if (!($72)) {
  $__new_last2$i$i$i$i$i1 = $69;
  $scevgep$i$i$i$i$i2 = (($71) + -4|0);
  $73 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($73)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $74 = $uglygep3$i$i$i$i$i5 >>> 2;
  $75 = $74 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($71) + ($75<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($69);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN7Texture9ReloadAllEbbb($unload,$load,$forceUnloadAll) {
 $unload = $unload|0;
 $load = $load|0;
 $forceUnloadAll = $forceUnloadAll|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $i$011 = 0, $i$02$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $objects = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $temp$0$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $objects = sp + 8|0;
 HEAP32[$objects>>2] = 0;
 $2 = (($objects) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($objects) + 8|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1536,27,($objects|0),1)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   label = 23;
  } else {
   $6 = HEAP32[$2>>2]|0;
   $7 = HEAP32[$objects>>2]|0;
   $8 = ($6|0)==($7|0);
   L3: do {
    if (!($8)) {
     $10 = $7;$i$011 = 0;
     while(1) {
      $9 = (($10) + ($i$011<<2)|0);
      $11 = HEAP32[$9>>2]|0;
      HEAP32[$0>>2] = $11;
      $12 = HEAP32[560624>>2]|0;
      $13 = ($12|0)==(0|0);
      if ($13) {
       label = 12;
      } else {
       $14 = (($12) + 36|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($12) + 4|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = ($15|0)==($17|0);
       do {
        if ($18) {
         $19 = (($12) + 28|0);
         $20 = HEAP32[$19>>2]|0;
         $21 = (($12) + 32|0);
         $22 = HEAP32[$21>>2]|0;
         $23 = (($20) + ($22<<3)|0);
         $39 = $23;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$12,$0);
         $24 = HEAP32[$$byval_copy>>2]|0;
         $25 = ($24|0)==(-1);
         $26 = (($12) + 28|0);
         $27 = HEAP32[$26>>2]|0;
         if ($25) {
          $28 = (($12) + 32|0);
          $29 = HEAP32[$28>>2]|0;
          $30 = (($27) + ($29<<3)|0);
          $39 = $30;
          break;
         } else {
          $31 = (($27) + ($24<<3)|0);
          $39 = $31;
          break;
         }
        }
       } while(0);
       $32 = HEAP32[560624>>2]|0;
       $33 = (($32) + 28|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 32|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = (($34) + ($36<<3)|0);
       $38 = ($39|0)==($37|0);
       if ($38) {
        label = 12;
       } else {
        $40 = (($39) + 4|0);
        $41 = HEAP32[$40>>2]|0;
        $42 = ($41|0)==(0|0);
        if ($42) {
         label = 12;
        } else {
         $temp$0$i = $41;
        }
       }
      }
      if ((label|0) == 12) {
       label = 0;
       __THREW__ = 0;
       $43 = (invoke_ii(3215,($11|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       } else {
        $temp$0$i = $43;
       }
      }
      if ($unload) {
       $46 = HEAP32[$temp$0$i>>2]|0;
       $47 = (($46) + 136|0);
       $48 = HEAP32[$47>>2]|0;
       __THREW__ = 0;
       invoke_vii($48|0,($temp$0$i|0),($forceUnloadAll|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
       $51 = (($temp$0$i) + 80|0);
       $52 = (($temp$0$i) + 88|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($53|0)==(0);
       if (!($54)) {
        $i$02$i = 0;
        while(1) {
         $55 = HEAP32[$51>>2]|0;
         $56 = (($55) + ($i$02$i<<2)|0);
         $57 = HEAP32[$56>>2]|0;
         $58 = (($57) + 16|0);
         HEAP32[$58>>2] = 0;
         $59 = (($57) + 20|0);
         HEAP32[$59>>2] = 0;
         $60 = (($i$02$i) + 1)|0;
         $61 = HEAP32[$52>>2]|0;
         $62 = ($60>>>0)<($61>>>0);
         if ($62) {
          $i$02$i = $60;
         } else {
          break;
         }
        }
       }
       $63 = (($temp$0$i) + 92|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = ($64|0)>(-1);
       if ($65) {
        $66 = HEAP32[$51>>2]|0;
        $67 = (($temp$0$i) + 84|0);
        $68 = HEAP32[$67>>2]|0;
        HEAP32[$1>>2] = $68;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($66|0),($$byval_copy|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
        HEAP32[$51>>2] = 0;
       }
       HEAP32[$52>>2] = 0;
       HEAP32[$63>>2] = 0;
      }
      if ($load) {
       $82 = HEAP32[$temp$0$i>>2]|0;
       $83 = (($82) + 140|0);
       $84 = HEAP32[$83>>2]|0;
       __THREW__ = 0;
       invoke_vi($84|0,($temp$0$i|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
      }
      $87 = (($i$011) + 1)|0;
      $88 = HEAP32[$2>>2]|0;
      $89 = HEAP32[$objects>>2]|0;
      $90 = $88;
      $91 = $89;
      $92 = (($90) - ($91))|0;
      $93 = $92 >> 2;
      $94 = ($87>>>0)<($93>>>0);
      if ($94) {
       $10 = $89;$i$011 = $87;
      } else {
       break L3;
      }
     }
     $71 = ___cxa_find_matching_catch()|0;
     $72 = tempRet0;
     $lpad$phi$index = $71;$lpad$phi$index2 = $72;
     break L1;
    }
   } while(0);
   __THREW__ = 0;
   $95 = __THREW__; __THREW__ = 0;
   $96 = $95&1;
   if ($96) {
    label = 23;
   } else {
    $97 = HEAP32[$objects>>2]|0;
    $98 = ($97|0)==(0|0);
    if ($98) {
     STACKTOP = sp;return;
    }
    $99 = HEAP32[$2>>2]|0;
    $100 = ($99|0)==($97|0);
    if (!($100)) {
     $__new_last2$i$i$i$i$i = $97;
     $scevgep$i$i$i$i$i = (($99) + -4|0);
     $101 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($101)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $102 = $uglygep3$i$i$i$i$i >>> 2;
     $103 = $102 ^ -1;
     $scevgep4$i$i$i$i$i = (($99) + ($103<<2)|0);
     HEAP32[$2>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($97);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $73 = ___cxa_find_matching_catch()|0;
  $74 = tempRet0;
  $lpad$phi$index = $73;$lpad$phi$index2 = $74;
 }
 $75 = HEAP32[$objects>>2]|0;
 $76 = ($75|0)==(0|0);
 if ($76) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $77 = HEAP32[$2>>2]|0;
 $78 = ($77|0)==($75|0);
 if (!($78)) {
  $__new_last2$i$i$i$i$i1 = $75;
  $scevgep$i$i$i$i$i2 = (($77) + -4|0);
  $79 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($79)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $80 = $uglygep3$i$i$i$i$i5 >>> 2;
  $81 = $80 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($77) + ($81<<2)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($75);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN7Texture13SetAnisoLimitEi($aniso) {
 $aniso = $aniso|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZL21SetAnisoLimitEnumImplib($aniso,0);
 STACKTOP = sp;return;
}
function __ZL21SetAnisoLimitEnumImplib($aniso,$forced) {
 $aniso = $aniso|0;
 $forced = $forced|0;
 var $$lcssa = 0, $$lcssa11 = 0, $$lcssa13 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i1 = 0, $brmerge = 0, $i$015 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $objects = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $objects = sp;
 $0 = HEAP32[608168>>2]|0;
 $$not = ($0|0)!=($aniso|0);
 $brmerge = $$not | $forced;
 if (!($brmerge)) {
  STACKTOP = sp;return;
 }
 HEAP32[608168>>2] = $aniso;
 if ((($aniso|0) == 2)) {
  __ZN15TextureSettings14SetAnisoLimitsEii(9,16);
 } else if ((($aniso|0) == 0)) {
  __ZN15TextureSettings14SetAnisoLimitsEii(1,1);
 } else {
  __ZN15TextureSettings14SetAnisoLimitsEii(1,16);
 }
 HEAP32[$objects>>2] = 0;
 $1 = (($objects) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($objects) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,27,($objects|0),0)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L9: do {
  if ($4) {
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   $lpad$phi$index = $27;$lpad$phi$index2 = $28;
  } else {
   $5 = HEAP32[$1>>2]|0;
   $6 = HEAP32[$objects>>2]|0;
   $7 = $6;
   $8 = ($5|0)==($6|0);
   L12: do {
    if ($8) {
     $$lcssa = $5;$$lcssa11 = $5;$$lcssa13 = $7;
    } else {
     $10 = $6;$i$015 = 0;
     while(1) {
      $9 = (($10) + ($i$015<<2)|0);
      $11 = HEAP32[$9>>2]|0;
      $12 = HEAP32[$11>>2]|0;
      $13 = (($12) + 132|0);
      $14 = HEAP32[$13>>2]|0;
      __THREW__ = 0;
      invoke_vi($14|0,($11|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      $17 = (($i$015) + 1)|0;
      $18 = HEAP32[$1>>2]|0;
      $19 = HEAP32[$objects>>2]|0;
      $20 = $18;
      $21 = $19;
      $22 = (($20) - ($21))|0;
      $23 = $22 >> 2;
      $24 = ($17>>>0)<($23>>>0);
      if ($24) {
       $10 = $19;$i$015 = $17;
      } else {
       $$lcssa = $18;$$lcssa11 = $19;$$lcssa13 = $21;
       break L12;
      }
     }
     $25 = ___cxa_find_matching_catch()|0;
     $26 = tempRet0;
     $lpad$phi$index = $25;$lpad$phi$index2 = $26;
     break L9;
    }
   } while(0);
   $36 = ($$lcssa11|0)==(0|0);
   if ($36) {
    STACKTOP = sp;return;
   }
   $37 = ($$lcssa|0)==($$lcssa11|0);
   if (!($37)) {
    $scevgep$i$i$i$i$i = (($$lcssa) + -4|0);
    $38 = (0 - ($$lcssa13))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($38)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $39 = $uglygep3$i$i$i$i$i >>> 2;
    $40 = $39 ^ -1;
    $scevgep4$i$i$i$i$i = (($$lcssa) + ($40<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($$lcssa11);
   STACKTOP = sp;return;
  }
 } while(0);
 $29 = HEAP32[$objects>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $31 = HEAP32[$1>>2]|0;
 $32 = ($31|0)==($29|0);
 if (!($32)) {
  $__new_last2$i$i$i$i$i1 = $29;
  $scevgep$i$i$i$i$i2 = (($31) + -4|0);
  $33 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($33)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $34 = $uglygep3$i$i$i$i$i5 >>> 2;
  $35 = $34 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($31) + ($35<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($29);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN7Texture13ApplySettingsEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 92|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 124|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
 $12 = (__Z19GetActiveColorSpacev()|0);
 $13 = ($12|0)==(1);
 if ($13) {
  $14 = (($this) + 56|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15;
 } else {
  $16 = 0;
 }
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZNK15TextureSettings5ApplyE9TextureID16TextureDimensionb17TextureColorSpaceb($1,$$byval_copy,$7,$11,$16,0);
 $17 = (($this) + 36|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 88|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 80|0);
 $i$01$i = 0;
 while(1) {
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + ($i$01$i<<2)|0);
  $25 = HEAP32[$24>>2]|0;
  __ZN9ShaderLab6TexEnv21TextureMipBiasChangedEf($25,$18);
  $26 = (($i$01$i) + 1)|0;
  $27 = HEAP32[$19>>2]|0;
  $28 = ($26>>>0)<($27>>>0);
  if ($28) {
   $i$01$i = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7Texture20NotifyMipBiasChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 80|0);
 $i$01 = 0;
 while(1) {
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($i$01<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  __ZN9ShaderLab6TexEnv21TextureMipBiasChangedEf($8,$1);
  $9 = (($i$01) + 1)|0;
  $10 = HEAP32[$2>>2]|0;
  $11 = ($9>>>0)<($10>>>0);
  if ($11) {
   $i$01 = $9;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7Texture13AddTexEnvUserEPN9ShaderLab6TexEnvE($this,$texenv) {
 $this = $this|0;
 $texenv = $texenv|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 80|0);
 $2 = (($this) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($texenv) + 16|0);
 HEAP32[$4>>2] = $this;
 $5 = (($texenv) + 20|0);
 HEAP32[$5>>2] = $3;
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 1)|0;
 HEAP32[$2>>2] = $7;
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($7>>>0)>($10>>>0);
 if (!($11)) {
  $30 = $7;
  $29 = (($30) + -1)|0;
  $31 = HEAP32[$1>>2]|0;
  $32 = (($31) + ($29<<2)|0);
  HEAP32[$32>>2] = $texenv;
  STACKTOP = sp;return;
 }
 $12 = $9 << 1;
 $13 = ($12|0)==(0);
 $14 = $13 ? 1 : $12;
 $15 = ($10>>>0)<($14>>>0);
 do {
  if ($15) {
   $16 = ($9|0)>(-1);
   if ($16) {
    HEAP32[$8>>2] = $14;
    $17 = HEAP32[$1>>2]|0;
    $18 = $14 << 2;
    $19 = (($this) + 84|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z16realloc_internalPvji10MemLabelIdiPKci($17,$18,4,$$byval_copy1,0,608200,370)|0);
    HEAP32[$1>>2] = $21;
    break;
   } else {
    $22 = $14 << 2;
    $23 = (($this) + 84|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = $24;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,4,$$byval_copy1,0,608200,352)|0);
    $26 = HEAP32[$1>>2]|0;
    $27 = HEAP32[$2>>2]|0;
    $28 = $27 << 2;
    _memcpy(($25|0),($26|0),($28|0))|0;
    HEAP32[$8>>2] = $14;
    HEAP32[$1>>2] = $25;
    break;
   }
  }
 } while(0);
 $$pre$i$i = HEAP32[$2>>2]|0;
 $30 = $$pre$i$i;
 $29 = (($30) + -1)|0;
 $31 = HEAP32[$1>>2]|0;
 $32 = (($31) + ($29<<2)|0);
 HEAP32[$32>>2] = $texenv;
 STACKTOP = sp;return;
}
function __ZN7Texture16RemoveTexEnvUserEPN9ShaderLab6TexEnvEj($this,$texenv,$index) {
 $this = $this|0;
 $texenv = $texenv|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = (($this) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($2<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($index<<2)|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + ($index<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 16|0);
 HEAP32[$11>>2] = $this;
 $12 = (($10) + 20|0);
 HEAP32[$12>>2] = $index;
 $13 = HEAP32[$0>>2]|0;
 $14 = (($13) + -1)|0;
 HEAP32[$0>>2] = $14;
 $15 = (($texenv) + 16|0);
 HEAP32[$15>>2] = 0;
 $16 = (($texenv) + 20|0);
 HEAP32[$16>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7Texture20NotifyUVScaleChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 68|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 80|0);
 $i$01 = 0;
 while(1) {
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + ($i$01<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  __ZN9ShaderLab6TexEnv21TextureUVScaleChangedEff($10,$1,$3);
  $11 = (($i$01) + 1)|0;
  $12 = HEAP32[$4>>2]|0;
  $13 = ($11>>>0)<($12>>>0);
  if ($13) {
   $i$01 = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7Texture13SetFilterModeEi($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($mode|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $mode;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 132|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN7Texture19SetStoredColorSpaceE17TextureColorSpace($this,$space) {
 $this = $this|0;
 $space = $space|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($space|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $space;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 132|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN7Texture33SetStoredColorSpaceNoDirtyNoApplyE17TextureColorSpace($this,$space) {
 $this = $this|0;
 $space = $space|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 HEAP32[$0>>2] = $space;
 STACKTOP = sp;return;
}
function __ZN7Texture11SetWrapModeEi($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($mode|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $mode;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 132|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN7Texture13SetMipMapBiasEf($this,$mipBias) {
 $this = $this|0;
 $mipBias = Math_fround($mipBias);
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 != $mipBias;
 if (!($2)) {
  STACKTOP = sp;return;
 }
 HEAPF32[$0>>2] = $mipBias;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 132|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN7Texture21GetMasterTextureLimitEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[608160>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN7Texture39ShouldIgnoreInGarbageDependencyTrackingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __Z21RegisterClass_Texturev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(27,134,0,0,0);
 STACKTOP = sp;return;
}
function __ZN7Texture13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 HEAP8[$0>>0] = 14;
 $3 = (($0) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[608176+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[608176+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[608176+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[608176+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[608176+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[608176+5>>0]|0;HEAP8[$3+6>>0]=HEAP8[608176+6>>0]|0;
 $4 = (($0) + 8|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,27,130,($0|0),100,(2402|0),1,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $13 = HEAP8[$0>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   ___resumeException($11|0);
   // unreachable;
  }
  $16 = HEAP32[$4>>2]|0;
  __ZdlPv($16);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = HEAP32[$4>>2]|0;
  __ZdlPv($10);
  STACKTOP = sp;return;
 }
}
function __ZN7Texture7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK7Texture25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 27;
}
function __ZN7Texture23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,608184,608176,$this,0);
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,608184,608176,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Texture8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z19UploadTexture2DData9TextureIDPhjiii13TextureFormatj16TextureUsageMode17TextureColorSpacei($tid,$data,$dataSize,$width,$height,$mipCount,$format,$uploadFlags,$usageMode,$colorSpace,$masterTextureLimit) {
 $tid = $tid|0;
 $data = $data|0;
 $dataSize = $dataSize|0;
 $width = $width|0;
 $height = $height|0;
 $mipCount = $mipCount|0;
 $format = $format|0;
 $uploadFlags = $uploadFlags|0;
 $usageMode = $usageMode|0;
 $colorSpace = $colorSpace|0;
 $masterTextureLimit = $masterTextureLimit|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$pre = 0, $$pre2 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $baseLevel = 0, $dataPtr = 0, $uploadHeight = 0, $uploadSize$0 = 0, $uploadWidth = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $dataPtr = sp;
 $uploadWidth = sp + 4|0;
 $uploadHeight = sp + 8|0;
 $baseLevel = sp + 12|0;
 $0 = sp + 16|0;
 HEAP32[$dataPtr>>2] = $data;
 $1 = (($mipCount) + -1)|0;
 $2 = ($1|0)>($masterTextureLimit|0);
 $3 = $2 ? $masterTextureLimit : $1;
 HEAP32[$uploadWidth>>2] = $width;
 HEAP32[$uploadHeight>>2] = $height;
 HEAP32[$baseLevel>>2] = 0;
 $4 = (__Z29SkipMipLevelsForTextureUploadi13TextureFormatiPPhPiS2_S2_($3,$format,$mipCount,$dataPtr,$uploadWidth,$uploadHeight,$baseLevel)|0);
 $5 = HEAP32[$dataPtr>>2]|0;
 if ($4) {
  $6 = $data;
  $7 = (($6) + ($dataSize))|0;
  $8 = $5;
  $9 = (($7) - ($8))|0;
  $$pre = HEAP32[$uploadWidth>>2]|0;
  $$pre2 = HEAP32[$uploadHeight>>2]|0;
  $$pre3 = HEAP32[$baseLevel>>2]|0;
  $$0 = $mipCount;$$01 = $format;$16 = $$pre3;$17 = $5;$18 = $$pre;$19 = $$pre2;$uploadSize$0 = $9;
 } else {
  HEAP32[$dataPtr>>2] = 608192;
  HEAP32[$uploadWidth>>2] = 1;
  HEAP32[$uploadHeight>>2] = 1;
  HEAP32[$baseLevel>>2] = 0;
  $$0 = 1;$$01 = 5;$16 = 0;$17 = 608192;$18 = 1;$19 = 1;$uploadSize$0 = 4;
 }
 $10 = (__Z21GetUncheckedGfxDevicev()|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 472|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$tid>>2]|0;
 HEAP32[$0>>2] = $14;
 $15 = (($$0) - ($16))|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiiiiiiiiiii[$13 & 3]($10,$$byval_copy,2,$17,$uploadSize$0,$18,$19,$$01,$15,$uploadFlags,$usageMode,$colorSpace);
 STACKTOP = sp;return;
}
function __Z29SkipMipLevelsForTextureUploadi13TextureFormatiPPhPiS2_S2_($masterTextureLimit,$dataFormat,$mipCount,$srcData,$width,$height,$baseLevel) {
 $masterTextureLimit = $masterTextureLimit|0;
 $dataFormat = $dataFormat|0;
 $mipCount = $mipCount|0;
 $srcData = $srcData|0;
 $width = $width|0;
 $height = $height|0;
 $baseLevel = $baseLevel|0;
 var $$pre = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $level$03 = 0;
 var $or$cond = 0, $storemerge$lcssa = 0, $storemerge5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($masterTextureLimit|0)>(0);
 L1: do {
  if ($0) {
   $1 = HEAP32[$width>>2]|0;
   $storemerge5 = $masterTextureLimit;
   while(1) {
    $2 = $1 >> $storemerge5;
    $3 = ($2|0)<(8);
    if (!($3)) {
     $4 = HEAP32[$height>>2]|0;
     $5 = $4 >> $storemerge5;
     $6 = ($5|0)<(8);
     if (!($6)) {
      $storemerge$lcssa = $storemerge5;
      break L1;
     }
    }
    $7 = (($storemerge5) + -1)|0;
    $8 = ($7|0)>(0);
    if ($8) {
     $storemerge5 = $7;
    } else {
     $storemerge$lcssa = $7;
     break;
    }
   }
  } else {
   $storemerge$lcssa = $masterTextureLimit;
  }
 } while(0);
 $9 = (($mipCount) + -1)|0;
 $10 = ($9|0)<($storemerge$lcssa|0);
 $11 = $10 ? $9 : $storemerge$lcssa;
 HEAP32[$baseLevel>>2] = $11;
 $12 = ($11|0)>(0);
 if ($12) {
  $$pre11 = HEAP32[$height>>2]|0;
  $17 = $$pre11;$level$03 = 0;
  while(1) {
   $16 = HEAP32[$width>>2]|0;
   $18 = (__Z18CalculateImageSizeii13TextureFormat($16,$17,$dataFormat)|0);
   $19 = HEAP32[$srcData>>2]|0;
   $20 = (($19) + ($18)|0);
   HEAP32[$srcData>>2] = $20;
   $21 = HEAP32[$width>>2]|0;
   $22 = (($21|0) / 2)&-1;
   $23 = ($22|0)<(1);
   $24 = $23 ? 1 : $22;
   HEAP32[$width>>2] = $24;
   $25 = HEAP32[$height>>2]|0;
   $26 = (($25|0) / 2)&-1;
   $27 = ($26|0)<(1);
   $28 = $27 ? 1 : $26;
   HEAP32[$height>>2] = $28;
   $29 = (($level$03) + 1)|0;
   $30 = HEAP32[$baseLevel>>2]|0;
   $31 = ($29|0)<($30|0);
   if ($31) {
    $17 = $28;$level$03 = $29;
   } else {
    $14 = $30;
    break;
   }
  }
 } else {
  $14 = $11;
 }
 $13 = ($14|0)<($9|0);
 $15 = HEAP32[$width>>2]|0;
 L14: do {
  if ($13) {
   $34 = $15;
   while(1) {
    $32 = HEAP32[((640792 + 108|0))>>2]|0;
    $33 = ($34|0)>($32|0);
    $$pre = HEAP32[$height>>2]|0;
    $35 = ($$pre|0)>($32|0);
    $or$cond = $33 | $35;
    if (!($or$cond)) {
     $53 = $34;
     break L14;
    }
    $36 = (__Z18CalculateImageSizeii13TextureFormat($34,$$pre,$dataFormat)|0);
    $37 = HEAP32[$srcData>>2]|0;
    $38 = (($37) + ($36)|0);
    HEAP32[$srcData>>2] = $38;
    $39 = HEAP32[$width>>2]|0;
    $40 = (($39|0) / 2)&-1;
    $41 = ($40|0)<(1);
    $42 = $41 ? 1 : $40;
    HEAP32[$width>>2] = $42;
    $43 = HEAP32[$height>>2]|0;
    $44 = (($43|0) / 2)&-1;
    $45 = ($44|0)<(1);
    $46 = $45 ? 1 : $44;
    HEAP32[$height>>2] = $46;
    $47 = HEAP32[$baseLevel>>2]|0;
    $48 = (($47) + 1)|0;
    HEAP32[$baseLevel>>2] = $48;
    $49 = ($48|0)<($9|0);
    $50 = HEAP32[$width>>2]|0;
    if ($49) {
     $34 = $50;
    } else {
     $53 = $50;
     break;
    }
   }
  } else {
   $53 = $15;
  }
 } while(0);
 $51 = HEAP32[((640792 + 108|0))>>2]|0;
 $52 = ($53|0)>($51|0);
 if ($52) {
  $56 = 0;
  STACKTOP = sp;return ($56|0);
 }
 $54 = HEAP32[$height>>2]|0;
 $55 = ($54|0)<=($51|0);
 $56 = $55;
 STACKTOP = sp;return ($56|0);
}
function __Z19GetBytesForOnePixel13TextureFormat($format) {
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0;
 var $or$cond9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $format$off$i$i = (($format) + -10)|0;
 $0 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($format) + -30)|0;
 $1 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $0 | $1;
 $2 = ($format|0)==(34);
 $or$cond7$i = $or$cond$i | $2;
 $format$off$i4$i = (($format) + -35)|0;
 $3 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $3;
 $format$off$i3$i = (($format) + -41)|0;
 $4 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $4;
 $format$off$i2$i = (($format) + -45)|0;
 $5 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $5;
 $format$off$i1$i = (($format) + -48)|0;
 $6 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $6;
 if ($or$cond) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $7 = (__Z25GetBytesFromTextureFormat13TextureFormat($format)|0);
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __Z21SourceMipLevelForBlitiiii($srcWidth,$srcHeight,$dstWidth,$dstHeight) {
 $srcWidth = $srcWidth|0;
 $srcHeight = $srcHeight|0;
 $dstWidth = $dstWidth|0;
 $dstHeight = $dstHeight|0;
 var $$$i = 0, $$$i16 = 0, $$$i2 = 0, $$$i9 = 0, $$1$i = 0, $$1$i10 = 0, $$1$i17 = 0, $$1$i3 = 0, $$2$i = 0, $$2$i12 = 0, $$2$i19 = 0, $$2$i5 = 0, $$mask$i = 0, $$mask$i1 = 0, $$mask$i15 = 0, $$mask$i8 = 0, $$neg22 = 0, $$neg24 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $base$1$i = 0, $base$1$i11 = 0, $base$1$i18 = 0, $base$1$i4 = 0, $base$2$i = 0, $base$2$i13 = 0, $base$2$i20 = 0, $base$2$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($srcWidth) + -1)|0;
 $1 = $0 >>> 16;
 $2 = $1 | $0;
 $3 = $2 >>> 8;
 $4 = $3 | $2;
 $5 = $4 >>> 4;
 $6 = $5 | $4;
 $7 = $6 >>> 2;
 $8 = $7 | $6;
 $9 = $8 >>> 1;
 $10 = $9 | $8;
 $11 = (($10) + 1)|0;
 $12 = ($11>>>0)>(65535);
 $13 = $11 >>> 16;
 $$mask$i15 = $12 ? $13 : $11;
 $$$i16 = $12 ? 16 : 0;
 $14 = $$mask$i15 & 65280;
 $15 = ($14|0)==(0);
 if ($15) {
  $$1$i17 = $$mask$i15;$base$1$i18 = $$$i16;
 } else {
  $16 = $$$i16 | 8;
  $17 = $$mask$i15 >>> 8;
  $$1$i17 = $17;$base$1$i18 = $16;
 }
 $18 = $$1$i17 & 240;
 $19 = ($18|0)==(0);
 if ($19) {
  $$2$i19 = $$1$i17;$base$2$i20 = $base$1$i18;
 } else {
  $20 = (($base$1$i18) + 4)|0;
  $21 = $$1$i17 >>> 4;
  $$2$i19 = $21;$base$2$i20 = $20;
 }
 $22 = (609472 + ($$2$i19)|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23 << 24 >> 24;
 $25 = (($dstWidth) + -1)|0;
 $26 = $25 >>> 16;
 $27 = $26 | $25;
 $28 = $27 >>> 8;
 $29 = $28 | $27;
 $30 = $29 >>> 4;
 $31 = $30 | $29;
 $32 = $31 >>> 2;
 $33 = $32 | $31;
 $34 = $33 >>> 1;
 $35 = $34 | $33;
 $36 = (($35) + 1)|0;
 $37 = ($36>>>0)>(65535);
 $38 = $36 >>> 16;
 $$mask$i8 = $37 ? $38 : $36;
 $$$i9 = $37 ? 16 : 0;
 $39 = $$mask$i8 & 65280;
 $40 = ($39|0)==(0);
 if ($40) {
  $$1$i10 = $$mask$i8;$base$1$i11 = $$$i9;
 } else {
  $41 = $$$i9 | 8;
  $42 = $$mask$i8 >>> 8;
  $$1$i10 = $42;$base$1$i11 = $41;
 }
 $43 = $$1$i10 & 240;
 $44 = ($43|0)==(0);
 if ($44) {
  $$2$i12 = $$1$i10;$base$2$i13 = $base$1$i11;
 } else {
  $45 = (($base$1$i11) + 4)|0;
  $46 = $$1$i10 >>> 4;
  $$2$i12 = $46;$base$2$i13 = $45;
 }
 $47 = (609472 + ($$2$i12)|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48 << 24 >> 24;
 $$neg22 = (($24) + ($base$2$i20))|0;
 $50 = (($$neg22) - ($base$2$i13))|0;
 $51 = (($50) - ($49))|0;
 $52 = (($srcHeight) + -1)|0;
 $53 = $52 >>> 16;
 $54 = $53 | $52;
 $55 = $54 >>> 8;
 $56 = $55 | $54;
 $57 = $56 >>> 4;
 $58 = $57 | $56;
 $59 = $58 >>> 2;
 $60 = $59 | $58;
 $61 = $60 >>> 1;
 $62 = $61 | $60;
 $63 = (($62) + 1)|0;
 $64 = ($63>>>0)>(65535);
 $65 = $63 >>> 16;
 $$mask$i1 = $64 ? $65 : $63;
 $$$i2 = $64 ? 16 : 0;
 $66 = $$mask$i1 & 65280;
 $67 = ($66|0)==(0);
 if ($67) {
  $$1$i3 = $$mask$i1;$base$1$i4 = $$$i2;
 } else {
  $68 = $$$i2 | 8;
  $69 = $$mask$i1 >>> 8;
  $$1$i3 = $69;$base$1$i4 = $68;
 }
 $70 = $$1$i3 & 240;
 $71 = ($70|0)==(0);
 if ($71) {
  $$2$i5 = $$1$i3;$base$2$i6 = $base$1$i4;
 } else {
  $72 = (($base$1$i4) + 4)|0;
  $73 = $$1$i3 >>> 4;
  $$2$i5 = $73;$base$2$i6 = $72;
 }
 $74 = (609472 + ($$2$i5)|0);
 $75 = HEAP8[$74>>0]|0;
 $76 = $75 << 24 >> 24;
 $77 = (($dstHeight) + -1)|0;
 $78 = $77 >>> 16;
 $79 = $78 | $77;
 $80 = $79 >>> 8;
 $81 = $80 | $79;
 $82 = $81 >>> 4;
 $83 = $82 | $81;
 $84 = $83 >>> 2;
 $85 = $84 | $83;
 $86 = $85 >>> 1;
 $87 = $86 | $85;
 $88 = (($87) + 1)|0;
 $89 = ($88>>>0)>(65535);
 $90 = $88 >>> 16;
 $$mask$i = $89 ? $90 : $88;
 $$$i = $89 ? 16 : 0;
 $91 = $$mask$i & 65280;
 $92 = ($91|0)==(0);
 if ($92) {
  $$1$i = $$mask$i;$base$1$i = $$$i;
 } else {
  $93 = $$$i | 8;
  $94 = $$mask$i >>> 8;
  $$1$i = $94;$base$1$i = $93;
 }
 $95 = $$1$i & 240;
 $96 = ($95|0)==(0);
 if ($96) {
  $$2$i = $$1$i;$base$2$i = $base$1$i;
  $99 = (609472 + ($$2$i)|0);
  $100 = HEAP8[$99>>0]|0;
  $101 = $100 << 24 >> 24;
  $$neg24 = (($76) + ($base$2$i6))|0;
  $102 = (($$neg24) - ($base$2$i))|0;
  $103 = (($102) - ($101))|0;
  $104 = ($51|0)<($103|0);
  $105 = $104 ? $103 : $51;
  $106 = ($105|0)>(0);
  $107 = $106 ? $105 : 0;
  STACKTOP = sp;return ($107|0);
 }
 $97 = (($base$1$i) + 4)|0;
 $98 = $$1$i >>> 4;
 $$2$i = $98;$base$2$i = $97;
 $99 = (609472 + ($$2$i)|0);
 $100 = HEAP8[$99>>0]|0;
 $101 = $100 << 24 >> 24;
 $$neg24 = (($76) + ($base$2$i6))|0;
 $102 = (($$neg24) - ($base$2$i))|0;
 $103 = (($102) - ($101))|0;
 $104 = ($51|0)<($103|0);
 $105 = $104 ? $103 : $51;
 $106 = ($105|0)>(0);
 $107 = $106 ? $105 : 0;
 STACKTOP = sp;return ($107|0);
}
function __ZNK9Texture2D13IsNPOTAllowedEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((640792 + 228|0))>>2]|0;
 if ((($0|0) == 1)) {
  label = 2;
 } else if ((($0|0) == 0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ((label|0) == 2) {
  $1 = HEAP8[((640792 + 236|0))>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if (!($2)) {
   $3 = (($this) + 48|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    $8 = 5;
   } else {
    $6 = (($4) + 32|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = $7;
   }
   $format$off$i$i = (($8) + -10)|0;
   $9 = ($format$off$i$i>>>0)<(3);
   $format$off$i5$i = (($8) + -30)|0;
   $10 = ($format$off$i5$i>>>0)<(4);
   $or$cond$i = $9 | $10;
   $11 = ($8|0)==(34);
   $or$cond7$i = $or$cond$i | $11;
   $format$off$i4$i = (($8) + -35)|0;
   $12 = ($format$off$i4$i>>>0)<(2);
   $or$cond9$i = $or$cond7$i | $12;
   $format$off$i3$i = (($8) + -41)|0;
   $13 = ($format$off$i3$i>>>0)<(4);
   $or$cond11$i = $or$cond9$i | $13;
   $format$off$i2$i = (($8) + -45)|0;
   $14 = ($format$off$i2$i>>>0)<(3);
   $or$cond13$i = $or$cond11$i | $14;
   $format$off$i1$i = (($8) + -48)|0;
   $15 = ($format$off$i1$i>>>0)<(12);
   $or$cond = $or$cond13$i | $15;
   if ($or$cond) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = (($16) + 124|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 4095]($this)|0);
 $20 = HEAP32[((640792 + 228|0))>>2]|0;
 $21 = ($20|0)==(2);
 $22 = ($20|0)>(0);
 $23 = $19 ? $21 : $22;
 $$0 = $23;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Texture2DC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$01$i = 0, $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$label>>2]|0;
 HEAP32[$2>>2] = $3;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN7TextureC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy7,$mode);
 HEAP32[$this>>2] = ((608208 + 8|0));
 $4 = (($this) + 132|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 100|0);
 $6 = (($this) + 124|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP8[$6>>0] = 1;
 $7 = (($this) + 127|0);
 HEAP8[$7>>0] = 1;
 $8 = (($this) + 129|0);
 HEAP8[$8>>0] = 0;
 $9 = (($this) + 128|0);
 HEAP8[$9>>0] = 1;
 $10 = (($this) + 125|0);
 HEAP8[$10>>0] = 0;
 $11 = (($this) + 126|0);
 HEAP8[$11>>0] = 0;
 __THREW__ = 0;
 $12 = (invoke_i(85)|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  $15 = HEAP32[$12>>2]|0;
  $16 = (($15) + 456|0);
  $17 = HEAP32[$16>>2]|0;
  __THREW__ = 0;
  $18 = (invoke_ii($17|0,($12|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   HEAP32[$4>>2] = $18;
   STACKTOP = sp;return;
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 HEAP32[$this>>2] = ((608008 + 8|0));
 __THREW__ = 0;
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 L5: do {
  if ($24) {
   $36 = ___cxa_find_matching_catch(0|0)|0;
   $37 = tempRet0;
   $38 = (($this) + 92|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)>(-1);
   if ($40) {
    $41 = (($this) + 80|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($this) + 84|0);
    $44 = HEAP32[$43>>2]|0;
    HEAP32[$0>>2] = $44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($42|0),($$byval_copy7|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     $51 = ___cxa_find_matching_catch(0|0)|0;
     $52 = tempRet0;
     ___clang_call_terminate($51);
     // unreachable;
    } else {
     HEAP32[$41>>2] = 0;
     $$01$i = $36;
     break;
    }
   } else {
    $$01$i = $36;
   }
  } else {
   $25 = (($this) + 92|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)>(-1);
   do {
    if ($27) {
     $28 = (($this) + 80|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($this) + 84|0);
     $31 = HEAP32[$30>>2]|0;
     HEAP32[$1>>2] = $31;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($29|0),($$byval_copy7|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      $47 = ___cxa_find_matching_catch(0|0)|0;
      $48 = tempRet0;
      $$01$i = $47;
      break L5;
     } else {
      HEAP32[$28>>2] = 0;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    ___resumeException($21|0);
    // unreachable;
   }
   $53 = ___cxa_find_matching_catch(0|0)|0;
   $54 = tempRet0;
   $eh$lpad$body$indexZ2D = $53;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch(0|0)|0;
  $52 = tempRet0;
  ___clang_call_terminate($51);
  // unreachable;
 }
 $eh$lpad$body$indexZ2D = $$01$i;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN9Texture2D5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Texture5ResetEv($this);
 $0 = (($this) + 28|0);
 __ZN15TextureSettings5ResetEv($0);
 STACKTOP = sp;return;
}
function __ZN9Texture2D21AwakeFromLoadThreadedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Texture2D26IntegrateLoadedImmediatelyEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Texture2D13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 144|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($this,0);
 STACKTOP = sp;return;
}
function __ZN9Texture2D15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture2D14DestroyTextureEv($this);
 STACKTOP = sp;return;
}
function __ZN9Texture2D14DestroyTextureEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[628264>>2]|0;
  $6 = (($3) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + -1)|0;
  HEAP32[$6>>2] = $8;
  $9 = HEAP32[$6>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = HEAP32[$3>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vi[$12 & 4095]($3);
   HEAP32[$0>>2] = $5;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy2);
  }
  HEAP32[$2>>2] = 0;
 }
 $13 = (($this) + 125|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  $16 = (__Z12GetGfxDevicev()|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 488|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($this) + 44|0);
  $21 = HEAP32[$20>>2]|0;
  HEAP32[$0>>2] = $21;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_vii[$19 & 4095]($16,$$byval_copy2);
  HEAP8[$13>>0] = 0;
 }
 $22 = (($this) + 126|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (__Z12GetGfxDevicev()|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 488|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$this>>2]|0;
 $30 = (($29) + 100|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_ii[$31 & 4095]($this)|0);
 HEAP32[$1>>2] = $32;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_vii[$28 & 4095]($25,$$byval_copy2);
 HEAP8[$22>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9Texture2D17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 125|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (__Z12GetGfxDevicev()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 488|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 44|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = $11;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_vii[$9 & 4095]($6,$$byval_copy2);
  HEAP8[$3>>0] = 0;
 }
 $12 = (($this) + 126|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  $15 = (__Z12GetGfxDevicev()|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 488|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$this>>2]|0;
  $20 = (($19) + 100|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 4095]($this)|0);
  HEAP32[$1>>2] = $22;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  FUNCTION_TABLE_vii[$18 & 4095]($15,$$byval_copy2);
  HEAP8[$12>>0] = 0;
 }
 $23 = HEAP32[((607992 + 4|0))>>2]|0;
 $24 = ($23|0)==(0|0);
 $$pre = (($this) + 132|0);
 if (!($24)) {
  $25 = HEAP32[$$pre>>2]|0;
  $$0$ph7$i$i$i$i = ((607992 + 4|0));$$01$ph6$i$in$i$i$i = $23;
  L9: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $26 = (($$013$i$in$i$i$i) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27>>>0)<($25>>>0);
    if (!($28)) {
     break;
    }
    $31 = (($$013$i$in$i$i$i) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L9;
    } else {
     $$013$i$in$i$i$i = $32;
    }
   }
   $29 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $29;
   }
  }
  $34 = ($$0$ph5$i$i$i$i|0)==(((607992 + 4|0))|0);
  if (!($34)) {
   $35 = (($$0$ph5$i$i$i$i) + 16|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($25>>>0)<($36>>>0);
   if (!($37)) {
    $38 = (($$0$ph5$i$i$i$i) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$01$i$i$i$i$i = $$0$ph5$i$i$i$i;
     while(1) {
      $43 = (($$01$i$i$i$i$i) + 8|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45|0)==($$01$i$i$i$i$i|0);
      if ($46) {
       $$0$i$i$i$i$i = $44;
       break;
      } else {
       $$01$i$i$i$i$i = $44;
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $39;
     while(1) {
      $41 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $42 = ($41|0)==(0|0);
      if ($42) {
       $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i$i = $41;
      }
     }
    }
    $47 = HEAP32[607992>>2]|0;
    $48 = ($47|0)==($$0$ph5$i$i$i$i|0);
    if ($48) {
     HEAP32[607992>>2] = $$0$i$i$i$i$i;
    }
    $49 = HEAP32[((607992 + 8|0))>>2]|0;
    $50 = (($49) + -1)|0;
    HEAP32[((607992 + 8|0))>>2] = $50;
    __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($23,$$0$ph5$i$i$i$i);
    __ZdlPv($$0$ph5$i$i$i$i);
   }
  }
 }
 $51 = (__Z25GetUncheckedRealGfxDevicev()|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 460|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$$pre>>2]|0;
 HEAP32[$2>>2] = $55;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 FUNCTION_TABLE_vii[$54 & 4095]($51,$$byval_copy2);
 HEAP32[$$pre>>2] = 0;
 __ZN7Texture17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZNK9Texture2D12ExtractImageEP14ImageReferencei($this,$image,$imageIndex) {
 $this = $this|0;
 $image = $image|0;
 $imageIndex = $imageIndex|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(608392,0,608384,313,1,$4,0,0);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $5 = (__ZNK17SharedTextureData12ExtractImageEP14ImageReferencebi($1,$image,1,$imageIndex)|0);
  $$0$i = $5;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZNK9Texture2D12CountMipmapsEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z22CalculateMipMapCount3Diii($5,$7,1)|0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK9Texture2D16CountDataMipmapsEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 104|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 108|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z22CalculateMipMapCount3Diii($5,$7,1)|0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Texture2D18UnshareTextureDataEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(1);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[628264>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 $9 = (__Znwj10MemLabelIdbiPKci(48,$$byval_copy3,0,16,608384,345)|0);
 $10 = HEAP32[$2>>2]|0;
 HEAP32[$9>>2] = ((587472 + 8|0));
 $11 = (($9) + 4|0);
 HEAP32[$11>>2] = 1;
 HEAP32[$9>>2] = ((607936 + 8|0));
 $12 = (($10) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($9) + 12|0);
 HEAP32[$14>>2] = $13;
 $15 = (($9) + 16|0);
 HEAP32[$15>>2] = 0;
 $16 = (($9) + 20|0);
 HEAP32[$16>>2] = 0;
 $17 = (($9) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = (($10) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($10) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$15>>2] = $21;
 $22 = ($21|0)==(0);
 do {
  if ($22) {
   $26 = 0;$27 = 0;
  } else {
   HEAP32[$16>>2] = $21;
   HEAP32[$0>>2] = $13;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   $23 = (invoke_iiiiiiii(108,(0|0),($21|0),1,($$byval_copy3|0),0,(608384|0),370)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    HEAP32[$17>>2] = $23;
    $$pre$i$i$i = HEAP32[$15>>2]|0;
    $26 = $23;$27 = $$pre$i$i$i;
    break;
   }
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(97,($9|0),($$byval_copy3|0),0,16,(608384|0),345);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $43 = ___cxa_find_matching_catch(0|0)|0;
    $44 = tempRet0;
    ___clang_call_terminate($43);
    // unreachable;
   } else {
    ___resumeException($39|0);
    // unreachable;
   }
  }
 } while(0);
 _memcpy(($26|0),($19|0),($27|0))|0;
 $28 = (($9) + 24|0);
 $29 = (($10) + 24|0);
 ;HEAP32[$28+0>>2]=HEAP32[$29+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$29+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$29+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$29+12>>2]|0;HEAP32[$28+16>>2]=HEAP32[$29+16>>2]|0;HEAP8[$28+20>>0]=HEAP8[$29+20>>0]|0;
 $30 = HEAP32[$2>>2]|0;
 $31 = HEAP32[628264>>2]|0;
 $32 = (($30) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + -1)|0;
 HEAP32[$32>>2] = $34;
 $35 = HEAP32[$32>>2]|0;
 $36 = ($35|0)==(0);
 if ($36) {
  $37 = HEAP32[$30>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  FUNCTION_TABLE_vi[$38 & 4095]($30);
  HEAP32[$0>>2] = $31;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($30,$$byval_copy3);
 }
 HEAP32[$2>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN9Texture2D19InitTextureInternalEii13TextureFormatiii($this,$width,$height,$format,$imageSize,$options,$imageCount) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $imageSize = $imageSize|0;
 $options = $options|0;
 $imageCount = $imageCount|0;
 var $$$i = 0, $$0$i = 0, $$0$i5 = 0, $$1$i = 0, $$1$i6 = 0, $$byval_copy3 = 0, $$not$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i1$i18 = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond$i = 0, $or$cond$i1 = 0, $or$cond$i2 = 0, $or$cond$i20 = 0, $or$cond$not$i = 0, $or$cond$not$i3 = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond3$i = 0, $or$cond3$i4 = 0, $or$cond7$i = 0, $or$cond9$i = 0;
 var $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = $options & 32;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN9Texture2D14DestroyTextureEv($this);
 } else {
  $5 = (($this) + 48|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = HEAP32[628264>>2]|0;
   $9 = (($6) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + -1)|0;
   HEAP32[$9>>2] = $11;
   $12 = HEAP32[$9>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    $14 = HEAP32[$6>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vi[$15 & 4095]($6);
    HEAP32[$0>>2] = $8;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy3);
   }
   HEAP32[$5>>2] = 0;
  }
 }
 $16 = $options & 1;
 $17 = ($16|0)!=(0);
 $18 = $options & 16;
 $19 = ($18|0)==(0);
 $20 = (__ZNK6Object14GetMemoryLabelEv($this)|0);
 $21 = ($20|0)==(15);
 $22 = (__ZNK6Object14GetMemoryLabelEv($this)|0);
 $$$i = $21 ? $22 : 13;
 $23 = HEAP32[628264>>2]|0;
 HEAP32[$1>>2] = $23;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 $24 = (__Znwj10MemLabelIdbiPKci(48,$$byval_copy3,0,16,608384,376)|0);
 HEAP32[$2>>2] = $$$i;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_viiiiiiiii(13,($24|0),($$byval_copy3|0),($width|0),($height|0),($format|0),($imageSize|0),($imageCount|0),($17|0),($19|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $148 = ___cxa_find_matching_catch()|0;
  $149 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viiiiii(97,($24|0),($$byval_copy3|0),0,16,(608384|0),376);
  $150 = __THREW__; __THREW__ = 0;
  $151 = $150&1;
  if ($151) {
   $152 = ___cxa_find_matching_catch(0|0)|0;
   $153 = tempRet0;
   ___clang_call_terminate($152);
   // unreachable;
  } else {
   ___resumeException($148|0);
   // unreachable;
  }
 }
 $27 = (($this) + 48|0);
 HEAP32[$27>>2] = $24;
 $28 = (($this) + 100|0);
 HEAP32[$28>>2] = 2;
 $29 = (($this) + 120|0);
 HEAP32[$29>>2] = $options;
 $30 = (($this) + 104|0);
 HEAP32[$30>>2] = $width;
 $31 = (($this) + 108|0);
 HEAP32[$31>>2] = $height;
 $32 = (($this) + 96|0);
 $33 = $16&255;
 HEAP8[$32>>0] = $33;
 $34 = (__Z29GetTextureSizeAllowedMultiple13TextureFormat($format)|0);
 $35 = (($width) + -1)|0;
 $36 = (($35) + ($34))|0;
 $37 = (0 - ($34))|0;
 $38 = $36 & $37;
 $format$off$i$i = (($format) + -10)|0;
 $39 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($format) + -30)|0;
 $40 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i1 = $39 | $40;
 $41 = ($format|0)==(34);
 $or$cond7$i = $or$cond$i1 | $41;
 $format$off$i4$i = (($format) + -35)|0;
 $42 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $42;
 $format$off$i3$i = (($format) + -41)|0;
 $43 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $43;
 $format$off$i2$i = (($format) + -45)|0;
 $44 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $44;
 if ($or$cond13$i) {
  $48 = 1;
 } else {
  $format$off$i1$i = (($format) + -48)|0;
  $45 = ($format$off$i1$i>>>0)<(12);
  $48 = $45;
 }
 $46 = HEAP32[((640792 + 228|0))>>2]|0;
 $47 = ($46|0)<(2);
 $or$cond$i = $48 & $47;
 $or$cond$not$i = $or$cond$i ^ 1;
 $49 = HEAP8[((640792 + 236|0))>>0]|0;
 $50 = ($49<<24>>24)==(0);
 $or$cond3$i = $50 | $or$cond$not$i;
 if ($or$cond3$i) {
  $$0$i = $38;
 } else {
  $51 = (($38) + -1)|0;
  $52 = $51 >>> 16;
  $53 = $52 | $51;
  $54 = $53 >>> 8;
  $55 = $54 | $53;
  $56 = $55 >>> 4;
  $57 = $56 | $55;
  $58 = $57 >>> 2;
  $59 = $58 | $57;
  $60 = $59 >>> 1;
  $61 = $60 | $59;
  $62 = (($61) + 1)|0;
  $$0$i = $62;
 }
 $63 = ($46|0)==(2);
 $64 = ($46|0)>(0);
 $65 = $17 ? $63 : $64;
 if ($65) {
  $$1$i = $$0$i;
 } else {
  $66 = (($$0$i) + -1)|0;
  $67 = $66 >>> 16;
  $68 = $67 | $66;
  $69 = $68 >>> 8;
  $70 = $69 | $68;
  $71 = $70 >>> 4;
  $72 = $71 | $70;
  $73 = $72 >>> 2;
  $74 = $73 | $72;
  $75 = $74 >>> 1;
  $76 = $75 | $74;
  $77 = (($76) + 1)|0;
  $$1$i = $77;
 }
 $78 = (($this) + 112|0);
 HEAP32[$78>>2] = $$1$i;
 $79 = (__Z29GetTextureSizeAllowedMultiple13TextureFormat($format)|0);
 $80 = (($height) + -1)|0;
 $81 = (($80) + ($79))|0;
 $82 = (0 - ($79))|0;
 $83 = $81 & $82;
 if ($or$cond13$i) {
  $87 = 1;
 } else {
  $format$off$i1$i18 = (($format) + -48)|0;
  $84 = ($format$off$i1$i18>>>0)<(12);
  $87 = $84;
 }
 $85 = HEAP32[((640792 + 228|0))>>2]|0;
 $86 = ($85|0)<(2);
 $or$cond$i2 = $87 & $86;
 $or$cond$not$i3 = $or$cond$i2 ^ 1;
 $88 = HEAP8[((640792 + 236|0))>>0]|0;
 $89 = ($88<<24>>24)==(0);
 $or$cond3$i4 = $89 | $or$cond$not$i3;
 if ($or$cond3$i4) {
  $$0$i5 = $83;
 } else {
  $90 = (($83) + -1)|0;
  $91 = $90 >>> 16;
  $92 = $91 | $90;
  $93 = $92 >>> 8;
  $94 = $93 | $92;
  $95 = $94 >>> 4;
  $96 = $95 | $94;
  $97 = $96 >>> 2;
  $98 = $97 | $96;
  $99 = $98 >>> 1;
  $100 = $99 | $98;
  $101 = (($100) + 1)|0;
  $$0$i5 = $101;
 }
 $102 = ($85|0)==(2);
 $103 = ($85|0)>(0);
 $104 = $17 ? $102 : $103;
 if ($104) {
  $$1$i6 = $$0$i5;
 } else {
  $105 = (($$0$i5) + -1)|0;
  $106 = $105 >>> 16;
  $107 = $106 | $105;
  $108 = $107 >>> 8;
  $109 = $108 | $107;
  $110 = $109 >>> 4;
  $111 = $110 | $109;
  $112 = $111 >>> 2;
  $113 = $112 | $111;
  $114 = $113 >>> 1;
  $115 = $114 | $113;
  $116 = (($115) + 1)|0;
  $$1$i6 = $116;
 }
 $117 = (($this) + 116|0);
 HEAP32[$117>>2] = $$1$i6;
 $118 = HEAP32[$78>>2]|0;
 $119 = (Math_fround(($118|0)));
 $120 = Math_fround(Math_fround(1.0) / $119);
 $121 = (Math_fround(($$1$i6|0)));
 $122 = Math_fround(Math_fround(1.0) / $121);
 $123 = (($this) + 72|0);
 HEAPF32[$123>>2] = $120;
 $124 = (($this) + 76|0);
 HEAPF32[$124>>2] = $122;
 $125 = HEAP32[$this>>2]|0;
 $126 = (($125) + 104|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = (FUNCTION_TABLE_ii[$127 & 4095]($this)|0);
 $129 = (($128) + -1)|0;
 $130 = $129 & $128;
 $131 = ($130|0)==(0);
 if ($131) {
  $133 = HEAP32[$this>>2]|0;
  $134 = (($133) + 108|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = (FUNCTION_TABLE_ii[$135 & 4095]($this)|0);
  $137 = (($136) + -1)|0;
  $138 = $137 & $136;
  $139 = ($138|0)==(0);
  $phitmp$i = $139&1;
  $140 = (($this) + 124|0);
  HEAP8[$140>>0] = $phitmp$i;
  if ($139) {
   STACKTOP = sp;return;
  }
 } else {
  $132 = (($this) + 124|0);
  HEAP8[$132>>0] = 0;
 }
 $141 = HEAP32[$this>>2]|0;
 $142 = (($141) + 124|0);
 $143 = HEAP32[$142>>2]|0;
 $144 = (FUNCTION_TABLE_ii[$143 & 4095]($this)|0);
 $$not$i = $144 ^ 1;
 $145 = HEAP32[((640792 + 228|0))>>2]|0;
 $146 = ($145|0)==(1);
 $or$cond$i20 = $146 & $$not$i;
 if (!($or$cond$i20)) {
  STACKTOP = sp;return;
 }
 $147 = (($this) + 40|0);
 HEAP32[$147>>2] = 1;
 STACKTOP = sp;return;
}
function __ZN9Texture2D11InitTextureEii13TextureFormatiii($this,$width,$height,$format,$options,$imageCount,$nativeTex) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $options = $options|0;
 $imageCount = $imageCount|0;
 $nativeTex = $nativeTex|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $format$off$i$i$i = 0, $format$off$i1$i$i = 0, $format$off$i2$i$i = 0, $format$off$i3$i$i = 0, $format$off$i4$i$i = 0, $format$off$i5$i$i = 0, $imageSize$0 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond11$i$i = 0, $or$cond13$i$i = 0, $or$cond7$i$i = 0, $or$cond9$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($width>>>0)>(16384);
 $2 = ($height>>>0)>(16384);
 $or$cond = $1 | $2;
 if ($or$cond) {
  $3 = ($this|0)==(0|0);
  if ($3) {
   $6 = 0;
  } else {
   $4 = (($this) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(608424,0,608384,394,1,$6,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__Z20IsValidTextureFormat13TextureFormat($format)|0);
 if (!($7)) {
  $8 = ($this|0)==(0|0);
  if ($8) {
   $11 = 0;
  } else {
   $9 = (($this) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $10;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(608464,0,608384,400,1,$11,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = $options & 1;
 $13 = ($12|0)==(0);
 if ($13) {
  $15 = (__Z18CalculateImageSizeii13TextureFormat($width,$height,$format)|0);
  $imageSize$0 = $15;
 } else {
  $14 = (__Z24CalculateImageMipMapSizeii13TextureFormat($width,$height,$format)|0);
  $imageSize$0 = $14;
 }
 $16 = Math_imul($imageSize$0, $imageCount)|0;
 $17 = ($imageSize$0|0)==(0);
 if (!($17)) {
  $18 = (($16>>>0) / ($imageSize$0>>>0))&-1;
  $19 = ($18|0)==($imageCount|0);
  if (!($19)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $format$off$i$i$i = (($format) + -10)|0;
 $20 = ($format$off$i$i$i>>>0)<(3);
 $format$off$i5$i$i = (($format) + -30)|0;
 $21 = ($format$off$i5$i$i>>>0)<(4);
 $or$cond$i$i = $20 | $21;
 $22 = ($format|0)==(34);
 $or$cond7$i$i = $or$cond$i$i | $22;
 $format$off$i4$i$i = (($format) + -35)|0;
 $23 = ($format$off$i4$i$i>>>0)<(2);
 $or$cond9$i$i = $or$cond7$i$i | $23;
 $format$off$i3$i$i = (($format) + -41)|0;
 $24 = ($format$off$i3$i$i>>>0)<(4);
 $or$cond11$i$i = $or$cond9$i$i | $24;
 $format$off$i2$i$i = (($format) + -45)|0;
 $25 = ($format$off$i2$i$i>>>0)<(3);
 $or$cond13$i$i = $or$cond11$i$i | $25;
 $format$off$i1$i$i = (($format) + -48)|0;
 $26 = ($format$off$i1$i$i>>>0)<(12);
 $or$cond$i = $or$cond13$i$i | $26;
 if ($or$cond$i) {
  $29 = 0;
 } else {
  $27 = (__Z25GetBytesFromTextureFormat13TextureFormat($format)|0);
  $29 = $27;
 }
 $28 = (($29) + ($16))|0;
 $30 = ($28>>>0)<($16>>>0);
 if ($30) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = ($nativeTex|0)==(0);
 if (!($31)) {
  $32 = (__Z12GetGfxDevicev()|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 464|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($this) + 44|0);
  $37 = HEAP32[$36>>2]|0;
  HEAP32[$0>>2] = $37;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_viii[$35 & 4095]($32,$$byval_copy,$nativeTex);
 }
 __ZN9Texture2D19InitTextureInternalEii13TextureFormatiii($this,$width,$height,$format,$imageSize$0,$options,$imageCount);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Texture2D13RebuildMipMapEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0;
 var $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $i$02 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $format$off$i$i = (($7) + -10)|0;
 $8 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($7) + -30)|0;
 $9 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $8 | $9;
 $10 = ($7|0)==(34);
 $or$cond7$i = $or$cond$i | $10;
 $format$off$i4$i = (($7) + -35)|0;
 $11 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $11;
 $format$off$i3$i = (($7) + -41)|0;
 $12 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $12;
 $format$off$i2$i = (($7) + -45)|0;
 $13 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $13;
 $format$off$i1$i = (($7) + -48)|0;
 $14 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $14;
 if ($or$cond) {
  $22 = ($this|0)==(0|0);
  if ($22) {
   $25 = 0;
  } else {
   $23 = (($this) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $24;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(608496,0,608384,437,1,$25,0,0);
  STACKTOP = sp;return;
 }
 $15 = (($5) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)>(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($5) + 36|0);
 $19 = (($5) + 8|0);
 $20 = (($5) + 24|0);
 $21 = (($5) + 28|0);
 $32 = $7;$i$02 = 0;
 while(1) {
  $26 = HEAP32[$18>>2]|0;
  $27 = Math_imul($26, $i$02)|0;
  $28 = HEAP32[$19>>2]|0;
  $29 = (($28) + ($27)|0);
  $30 = HEAP32[$20>>2]|0;
  $31 = HEAP32[$21>>2]|0;
  __Z12CreateMipMapPhiii13TextureFormat($29,$30,$31,1,$32);
  $33 = (($i$02) + 1)|0;
  $34 = HEAP32[$15>>2]|0;
  $35 = ($33|0)<($34|0);
  if (!($35)) {
   break;
  }
  $$pre = HEAP32[$6>>2]|0;
  $32 = $$pre;$i$02 = $33;
 }
 STACKTOP = sp;return;
}
function __ZN9Texture2D22GetWriteImageReferenceEP14ImageReferenceii($this,$image,$frame,$miplevel) {
 $this = $this|0;
 $image = $image|0;
 $frame = $frame|0;
 $miplevel = $miplevel|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN9Texture2D18UnshareTextureDataEv($this);
 $3 = HEAP32[$0>>2]|0;
 $4 = (__ZN17SharedTextureData17GetImageReferenceEP14ImageReferenceii($3,$image,$frame,$miplevel)|0);
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Texture2D13ApplySettingsEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 $6 = (($this) + 28|0);
 $7 = (($this) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$0>>2] = $8;
 $9 = HEAP32[$this>>2]|0;
 $10 = (($9) + 124|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($this)|0);
 $13 = (__Z19GetActiveColorSpacev()|0);
 $14 = ($13|0)==(1);
 if ($14) {
  $15 = (($this) + 56|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
 } else {
  $17 = 0;
 }
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __ZNK15TextureSettings5ApplyE9TextureID16TextureDimensionb17TextureColorSpaceb($6,$$byval_copy1,$5,$12,$17,0);
 $18 = (($this) + 126|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  __ZN7Texture20NotifyMipBiasChangedEv($this);
  STACKTOP = sp;return;
 }
 $21 = HEAP32[$this>>2]|0;
 $22 = (($21) + 100|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 4095]($this)|0);
 HEAP32[$1>>2] = $24;
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + 124|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (FUNCTION_TABLE_ii[$27 & 4095]($this)|0);
 $29 = (__Z19GetActiveColorSpacev()|0);
 $30 = ($29|0)==(1);
 if ($30) {
  $31 = (($this) + 56|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $32;
 } else {
  $33 = 0;
 }
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNK15TextureSettings5ApplyE9TextureID16TextureDimensionb17TextureColorSpaceb($6,$$byval_copy1,$5,$28,$33,0);
 __ZN7Texture20NotifyMipBiasChangedEv($this);
 STACKTOP = sp;return;
}
function __ZN9Texture2D13UploadTextureEb($this,$dontUseSubImage) {
 $this = $this|0;
 $dontUseSubImage = $dontUseSubImage|0;
 var $$byval_copy6 = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $padded = 0, $scaled = 0, $uploadFlags$0 = 0, $uploadFlags$2 = 0, $uploadFlags1$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp + 40|0;
 $0 = sp;
 $1 = sp + 36|0;
 $scaled = sp + 32|0;
 $padded = sp + 28|0;
 $2 = sp + 24|0;
 $3 = sp + 16|0;
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 20|0;
 $7 = (($this) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(608560,0,608384,510,1,$11,0,0);
  STACKTOP = sp;return;
 }
 $12 = (($8) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($8) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  STACKTOP = sp;return;
 }
 HEAP32[$scaled>>2] = 0;
 HEAP32[$padded>>2] = 0;
 __ZN9Texture2D25CreateScaledAndPaddedDataEPP17SharedTextureDataS2_($this,$scaled,$padded);
 $18 = HEAP32[$this>>2]|0;
 $19 = (($18) + 128|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_ii[$20 & 4095]($this)|0);
 $22 = (__ZN7Texture21GetMasterTextureLimitEv()|0);
 $23 = (($this) + 52|0);
 $24 = HEAP32[$23>>2]|0;
 if ($dontUseSubImage) {
  label = 7;
 } else {
  $25 = (($this) + 125|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   label = 7;
  } else {
   $uploadFlags$0 = 1;
  }
 }
 if ((label|0) == 7) {
  $uploadFlags$0 = 3;
 }
 $28 = (($this) + 120|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = $29 >>> 1;
 $31 = $30 & 4;
 $32 = $31 | $uploadFlags$0;
 $33 = (($this) + 127|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ($34<<24>>24)==(0);
 $36 = $32 | 16;
 $uploadFlags$2 = $35 ? $32 : $36;
 $37 = (($this) + 44|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$2>>2] = $38;
 $39 = HEAP32[$scaled>>2]|0;
 $40 = (($39) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + 36|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($39) + 24|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($39) + 28|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($39) + 32|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (__Z19GetActiveColorSpacev()|0);
 $51 = ($50|0)==(1);
 if ($51) {
  $52 = (($this) + 56|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = $53;
 } else {
  $54 = 0;
 }
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
 __Z19UploadTexture2DData9TextureIDPhjiii13TextureFormatj16TextureUsageMode17TextureColorSpacei($$byval_copy6,$41,$43,$45,$47,$21,$49,$uploadFlags$2,$24,$54,$22);
 $55 = HEAP32[$37>>2]|0;
 $56 = $this;
 $57 = $0;
 $58 = $57;
 HEAP32[$58>>2] = $55;
 $59 = (($57) + 4)|0;
 $60 = $59;
 HEAP32[$60>>2] = $56;
 __ZNSt3__16__treeINS_12__value_typeI9TextureIDP7TextureEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($$byval_copy6,607992,$0);
 $61 = HEAP32[$44>>2]|0;
 $62 = (($61) + -1)|0;
 $63 = $62 & $61;
 $64 = ($63|0)==(0);
 if ($64) {
  $65 = HEAP32[$46>>2]|0;
  $66 = (($65) + -1)|0;
  $67 = $66 & $65;
  $68 = ($67|0)!=(0);
  $83 = $68;
 } else {
  $83 = 1;
 }
 $69 = (($this) + 28|0);
 $70 = HEAP32[$37>>2]|0;
 HEAP32[$3>>2] = $70;
 $71 = HEAP32[$this>>2]|0;
 $72 = (($71) + 92|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (FUNCTION_TABLE_ii[$73 & 4095]($this)|0);
 $75 = (($39) + 44|0);
 $76 = HEAP8[$75>>0]|0;
 $77 = ($76<<24>>24)!=(0);
 $78 = (__Z19GetActiveColorSpacev()|0);
 $79 = ($78|0)==(1);
 if ($79) {
  $80 = (($this) + 56|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = $81;
 } else {
  $82 = 0;
 }
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
 __ZNK15TextureSettings5ApplyE9TextureID16TextureDimensionb17TextureColorSpaceb($69,$$byval_copy6,$74,$77,$82,$83);
 $84 = (($this) + 125|0);
 HEAP8[$84>>0] = 1;
 $85 = (__Z12GetGfxDevicev()|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + 364|0);
 $88 = HEAP32[$87>>2]|0;
 FUNCTION_TABLE_vii[$88 & 4095]($85,$39);
 $89 = HEAP32[$7>>2]|0;
 $90 = (($89) + 24|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (($this) + 112|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($91|0)==($93|0);
 if ($94) {
  $95 = (($89) + 28|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (($this) + 116|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ($96|0)==($98|0);
  if ($99) {
   $155 = HEAP32[$padded>>2]|0;
   $156 = HEAP32[628264>>2]|0;
   $157 = (($155) + 4|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($158) + -1)|0;
   HEAP32[$157>>2] = $159;
   $160 = HEAP32[$157>>2]|0;
   $161 = ($160|0)==(0);
   if ($161) {
    $162 = HEAP32[$155>>2]|0;
    $163 = HEAP32[$162>>2]|0;
    FUNCTION_TABLE_vi[$163 & 4095]($155);
    HEAP32[$0>>2] = $156;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($155,$$byval_copy6);
   }
  } else {
   label = 16;
  }
 } else {
  label = 16;
 }
 if ((label|0) == 16) {
  $$pre$pre = (($this) + 126|0);
  if ($dontUseSubImage) {
   label = 18;
  } else {
   $100 = HEAP8[$$pre$pre>>0]|0;
   $101 = ($100<<24>>24)==(0);
   if ($101) {
    label = 18;
   } else {
    $uploadFlags1$0 = 1;
   }
  }
  if ((label|0) == 18) {
   $uploadFlags1$0 = 3;
  }
  $102 = HEAP32[$28>>2]|0;
  $103 = $102 >>> 1;
  $104 = $103 & 4;
  $105 = $104 | $uploadFlags1$0;
  HEAP8[$$pre$pre>>0] = 1;
  $106 = HEAP32[$this>>2]|0;
  $107 = (($106) + 100|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (FUNCTION_TABLE_ii[$108 & 4095]($this)|0);
  HEAP32[$4>>2] = $109;
  $110 = HEAP32[$padded>>2]|0;
  $111 = (($110) + 8|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = (($110) + 36|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (($110) + 24|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($110) + 28|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($110) + 32|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = (__Z19GetActiveColorSpacev()|0);
  $122 = ($121|0)==(1);
  if ($122) {
   $123 = (($this) + 56|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = $124;
  } else {
   $125 = 0;
  }
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
  __Z19UploadTexture2DData9TextureIDPhjiii13TextureFormatj16TextureUsageMode17TextureColorSpacei($$byval_copy6,$112,$114,$116,$118,$21,$120,$105,$24,$125,$22);
  $126 = $0;
  $127 = $126;
  HEAP32[$127>>2] = $109;
  $128 = (($126) + 4)|0;
  $129 = $128;
  HEAP32[$129>>2] = $56;
  __ZNSt3__16__treeINS_12__value_typeI9TextureIDP7TextureEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($$byval_copy6,607992,$0);
  $130 = HEAP32[$115>>2]|0;
  $131 = (($130) + -1)|0;
  $132 = $131 & $130;
  $133 = ($132|0)==(0);
  if ($133) {
   $134 = HEAP32[$117>>2]|0;
   $135 = (($134) + -1)|0;
   $136 = $135 & $134;
   $137 = ($136|0)!=(0);
   $150 = $137;
  } else {
   $150 = 1;
  }
  HEAP32[$5>>2] = $109;
  $138 = HEAP32[$this>>2]|0;
  $139 = (($138) + 92|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = (FUNCTION_TABLE_ii[$140 & 4095]($this)|0);
  $142 = (($110) + 44|0);
  $143 = HEAP8[$142>>0]|0;
  $144 = ($143<<24>>24)!=(0);
  $145 = (__Z19GetActiveColorSpacev()|0);
  $146 = ($145|0)==(1);
  if ($146) {
   $147 = (($this) + 56|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = $148;
  } else {
   $149 = 0;
  }
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
  __ZNK15TextureSettings5ApplyE9TextureID16TextureDimensionb17TextureColorSpaceb($69,$$byval_copy6,$141,$144,$149,$150);
  $151 = (__Z12GetGfxDevicev()|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = (($152) + 364|0);
  $154 = HEAP32[$153>>2]|0;
  FUNCTION_TABLE_vii[$154 & 4095]($151,$110);
 }
 $164 = (__Z12GetGfxDevicev()|0);
 $165 = HEAP32[$164>>2]|0;
 $166 = (($165) + 648|0);
 $167 = HEAP32[$166>>2]|0;
 $168 = HEAP32[$37>>2]|0;
 HEAP32[$6>>2] = $168;
 $169 = HEAP32[$this>>2]|0;
 $170 = (($169) + 32|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = (FUNCTION_TABLE_ii[$171 & 4095]($this)|0);
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$6+0>>2]|0;
 FUNCTION_TABLE_viii[$167 & 4095]($164,$$byval_copy6,$172);
 $173 = HEAP8[$33>>0]|0;
 $174 = ($173<<24>>24)==(0);
 if (!($174)) {
  STACKTOP = sp;return;
 }
 $175 = HEAP32[$7>>2]|0;
 $176 = ($175|0)==(0|0);
 if ($176) {
  STACKTOP = sp;return;
 }
 $177 = HEAP32[628264>>2]|0;
 $178 = (($175) + 4|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = (($179) + -1)|0;
 HEAP32[$178>>2] = $180;
 $181 = HEAP32[$178>>2]|0;
 $182 = ($181|0)==(0);
 if ($182) {
  $183 = HEAP32[$175>>2]|0;
  $184 = HEAP32[$183>>2]|0;
  FUNCTION_TABLE_vi[$184 & 4095]($175);
  HEAP32[$1>>2] = $177;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($175,$$byval_copy6);
 }
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9Texture2D25CreateScaledAndPaddedDataEPP17SharedTextureDataS2_($this,$scaled,$padded) {
 $this = $this|0;
 $scaled = $scaled|0;
 $padded = $padded|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, $exitcond = 0, $exitcond4 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $frame$02$us = 0, $mip$01$us = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if ($2) {
  HEAP32[$0>>2] = 2;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $8 = 5;
 } else {
  $6 = (($4) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7;
 }
 $9 = (__Z29GetTextureSizeAllowedMultiple13TextureFormat($8)|0);
 $10 = (($9) + -1)|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = (($11) + 104|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 4095]($this)|0);
 $15 = $14 & $10;
 $16 = ($15|0)==(0);
 do {
  if ($16) {
   $17 = HEAP32[$this>>2]|0;
   $18 = (($17) + 108|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (FUNCTION_TABLE_ii[$19 & 4095]($this)|0);
   $21 = $20 & $10;
   $22 = ($21|0)==(0);
   if ($22) {
    $23 = (($this) + 124|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     $26 = HEAP32[$this>>2]|0;
     $27 = (($26) + 112|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (FUNCTION_TABLE_ii[$28 & 4095]($this)|0);
     if (!($29)) {
      break;
     }
    }
    $30 = HEAP32[$3>>2]|0;
    HEAP32[$padded>>2] = $30;
    HEAP32[$scaled>>2] = $30;
    $31 = HEAP32[$3>>2]|0;
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 1)|0;
    HEAP32[$32>>2] = $34;
    $35 = HEAP32[$32>>2]|0;
    $36 = HEAP32[$3>>2]|0;
    $37 = (($36) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 1)|0;
    HEAP32[$37>>2] = $39;
    $40 = HEAP32[$37>>2]|0;
    $41 = HEAP32[$this>>2]|0;
    $42 = (($41) + 104|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (FUNCTION_TABLE_ii[$43 & 4095]($this)|0);
    $45 = (Math_fround(($44|0)));
    $46 = Math_fround(Math_fround(1.0) / $45);
    $47 = HEAP32[$this>>2]|0;
    $48 = (($47) + 108|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (FUNCTION_TABLE_ii[$49 & 4095]($this)|0);
    $51 = (Math_fround(($50|0)));
    $52 = Math_fround(Math_fround(1.0) / $51);
    $53 = (($this) + 72|0);
    HEAPF32[$53>>2] = $46;
    $54 = (($this) + 76|0);
    HEAPF32[$54>>2] = $52;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $format$off$i$i = (($8) + -10)|0;
 $55 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($8) + -30)|0;
 $56 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $55 | $56;
 $57 = ($8|0)==(34);
 $or$cond7$i = $or$cond$i | $57;
 $format$off$i4$i = (($8) + -35)|0;
 $58 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $58;
 $format$off$i3$i = (($8) + -41)|0;
 $59 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $59;
 $format$off$i2$i = (($8) + -45)|0;
 $60 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $60;
 if ($or$cond13$i) {
  $62 = 4;
 } else {
  $format$off$i1$i = (($8) + -48)|0;
  $61 = ($format$off$i1$i>>>0)<(12);
  $phitmp = $61 ? 4 : $8;
  $62 = $phitmp;
 }
 $63 = (__ZN9Texture2D26AllocateScaledOrPaddedDataE13TextureFormat($this,$62)|0);
 HEAP32[$scaled>>2] = $63;
 $64 = (__ZN9Texture2D26AllocateScaledOrPaddedDataE13TextureFormat($this,$8)|0);
 HEAP32[$padded>>2] = $64;
 $65 = HEAP32[$3>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  $74 = 0;
 } else {
  $67 = (($65) + 40|0);
  $68 = HEAP32[$67>>2]|0;
  $74 = $68;
 }
 $69 = HEAP32[$this>>2]|0;
 $70 = (($69) + 128|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (FUNCTION_TABLE_ii[$71 & 4095]($this)|0);
 $73 = ($74|0)>(0);
 $75 = ($72|0)>(0);
 $or$cond = $73 & $75;
 if ($or$cond) {
  $frame$02$us = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $mip$01$us = 0;
  while(1) {
   $77 = HEAP32[$scaled>>2]|0;
   $78 = HEAP32[$3>>2]|0;
   __ZN17SharedTextureData15ExtractMipLevelEPS_iibb($78,$77,$frame$02$us,$mip$01$us,0,1);
   $79 = HEAP32[$padded>>2]|0;
   $80 = HEAP32[$3>>2]|0;
   __ZN17SharedTextureData15ExtractMipLevelEPS_iibb($80,$79,$frame$02$us,$mip$01$us,1,0);
   $81 = (($mip$01$us) + 1)|0;
   $exitcond = ($81|0)==($72|0);
   if ($exitcond) {
    break;
   } else {
    $mip$01$us = $81;
   }
  }
  $76 = (($frame$02$us) + 1)|0;
  $exitcond4 = ($76|0)==($74|0);
  if ($exitcond4) {
   break;
  } else {
   $frame$02$us = $76;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Texture2D19UnloadFromGfxDeviceEb($this,$forceUnloadAll) {
 $this = $this|0;
 $forceUnloadAll = $forceUnloadAll|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 129|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 $brmerge = $4 | $forceUnloadAll;
 if (!($brmerge)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 125|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (__Z12GetGfxDevicev()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 488|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$0>>2] = $13;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($8,$$byval_copy1);
  HEAP8[$5>>0] = 0;
 }
 $14 = (($this) + 126|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (__Z12GetGfxDevicev()|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 488|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$this>>2]|0;
 $22 = (($21) + 100|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 4095]($this)|0);
 HEAP32[$1>>2] = $24;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_vii[$20 & 4095]($17,$$byval_copy1);
 HEAP8[$14>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9Texture2D17UploadToGfxDeviceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $settings = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $settings = sp;
 $0 = (($this) + 129|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($this) + 127|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $9 = (($this) + 28|0);
   ;HEAP32[$settings+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$settings+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$settings+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$settings+12>>2]=HEAP32[$9+12>>2]|0;
   $10 = (__Z20GetPersistentManagerv()|0);
   (__ZN17PersistentManager14ReloadFromDiskER6Object($10,$this)|0);
   ;HEAP32[$9+0>>2]=HEAP32[$settings+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$settings+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$settings+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$settings+12>>2]|0;
   $11 = HEAP32[$this>>2]|0;
   $12 = (($11) + 132|0);
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vi[$13 & 4095]($this);
   STACKTOP = sp;return;
  }
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 144|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($this,1);
 STACKTOP = sp;return;
}
function __ZN9Texture2D15UpdateImageDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 160|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 144|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($this,0);
 STACKTOP = sp;return;
}
function __ZN9Texture2D30UpdateImageDataDontTouchMipmapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 144|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($this,0);
 STACKTOP = sp;return;
}
function __ZNK9Texture2D20GetUnscaledTextureIDEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 126|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($this) + 132|0);
 $4 = (($this) + 44|0);
 $5 = $2 ? $4 : $3;
 $6 = HEAP32[$5>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZNK9Texture2D12GetDataWidthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK9Texture2D13GetDataHeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9Texture2D26AllocateScaledOrPaddedDataE13TextureFormat($this,$format) {
 $this = $this|0;
 $format = $format|0;
 var $$0$i = 0, $$0$i5 = 0, $$1$i = 0, $$1$i6 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i1$i18 = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $imageSize$0 = 0, $or$cond$i = 0, $or$cond$i1 = 0, $or$cond$i2 = 0, $or$cond$not$i = 0, $or$cond$not$i3 = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond3$i = 0, $or$cond3$i4 = 0, $or$cond7$i = 0, $or$cond9$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 104|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($this)|0);
 $10 = (__Z29GetTextureSizeAllowedMultiple13TextureFormat($format)|0);
 $11 = (($9) + -1)|0;
 $12 = (($11) + ($10))|0;
 $13 = (0 - ($10))|0;
 $14 = $12 & $13;
 $format$off$i$i = (($format) + -10)|0;
 $15 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($format) + -30)|0;
 $16 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i1 = $15 | $16;
 $17 = ($format|0)==(34);
 $or$cond7$i = $or$cond$i1 | $17;
 $format$off$i4$i = (($format) + -35)|0;
 $18 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $18;
 $format$off$i3$i = (($format) + -41)|0;
 $19 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $19;
 $format$off$i2$i = (($format) + -45)|0;
 $20 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $20;
 if ($or$cond13$i) {
  $24 = 1;
 } else {
  $format$off$i1$i = (($format) + -48)|0;
  $21 = ($format$off$i1$i>>>0)<(12);
  $24 = $21;
 }
 $22 = HEAP32[((640792 + 228|0))>>2]|0;
 $23 = ($22|0)<(2);
 $or$cond$i = $24 & $23;
 $or$cond$not$i = $or$cond$i ^ 1;
 $25 = HEAP8[((640792 + 236|0))>>0]|0;
 $26 = ($25<<24>>24)==(0);
 $or$cond3$i = $26 | $or$cond$not$i;
 if ($or$cond3$i) {
  $$0$i = $14;
 } else {
  $27 = (($14) + -1)|0;
  $28 = $27 >>> 16;
  $29 = $28 | $27;
  $30 = $29 >>> 8;
  $31 = $30 | $29;
  $32 = $31 >>> 4;
  $33 = $32 | $31;
  $34 = $33 >>> 2;
  $35 = $34 | $33;
  $36 = $35 >>> 1;
  $37 = $36 | $35;
  $38 = (($37) + 1)|0;
  $$0$i = $38;
 }
 $39 = ($22|0)==(2);
 $40 = ($22|0)>(0);
 $41 = $5 ? $39 : $40;
 if ($41) {
  $$1$i = $$0$i;
 } else {
  $42 = (($$0$i) + -1)|0;
  $43 = $42 >>> 16;
  $44 = $43 | $42;
  $45 = $44 >>> 8;
  $46 = $45 | $44;
  $47 = $46 >>> 4;
  $48 = $47 | $46;
  $49 = $48 >>> 2;
  $50 = $49 | $48;
  $51 = $50 >>> 1;
  $52 = $51 | $50;
  $53 = (($52) + 1)|0;
  $$1$i = $53;
 }
 $54 = HEAP32[$this>>2]|0;
 $55 = (($54) + 108|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (FUNCTION_TABLE_ii[$56 & 4095]($this)|0);
 $58 = (__Z29GetTextureSizeAllowedMultiple13TextureFormat($format)|0);
 $59 = (($57) + -1)|0;
 $60 = (($59) + ($58))|0;
 $61 = (0 - ($58))|0;
 $62 = $60 & $61;
 if ($or$cond13$i) {
  $66 = 1;
 } else {
  $format$off$i1$i18 = (($format) + -48)|0;
  $63 = ($format$off$i1$i18>>>0)<(12);
  $66 = $63;
 }
 $64 = HEAP32[((640792 + 228|0))>>2]|0;
 $65 = ($64|0)<(2);
 $or$cond$i2 = $66 & $65;
 $or$cond$not$i3 = $or$cond$i2 ^ 1;
 $67 = HEAP8[((640792 + 236|0))>>0]|0;
 $68 = ($67<<24>>24)==(0);
 $or$cond3$i4 = $68 | $or$cond$not$i3;
 if ($or$cond3$i4) {
  $$0$i5 = $62;
 } else {
  $69 = (($62) + -1)|0;
  $70 = $69 >>> 16;
  $71 = $70 | $69;
  $72 = $71 >>> 8;
  $73 = $72 | $71;
  $74 = $73 >>> 4;
  $75 = $74 | $73;
  $76 = $75 >>> 2;
  $77 = $76 | $75;
  $78 = $77 >>> 1;
  $79 = $78 | $77;
  $80 = (($79) + 1)|0;
  $$0$i5 = $80;
 }
 $81 = ($64|0)==(2);
 $82 = ($64|0)>(0);
 $83 = $5 ? $81 : $82;
 if ($83) {
  $$1$i6 = $$0$i5;
 } else {
  $84 = (($$0$i5) + -1)|0;
  $85 = $84 >>> 16;
  $86 = $85 | $84;
  $87 = $86 >>> 8;
  $88 = $87 | $86;
  $89 = $88 >>> 4;
  $90 = $89 | $88;
  $91 = $90 >>> 2;
  $92 = $91 | $90;
  $93 = $92 >>> 1;
  $94 = $93 | $92;
  $95 = (($94) + 1)|0;
  $$1$i6 = $95;
 }
 if ($5) {
  $96 = (__Z24CalculateImageMipMapSizeii13TextureFormat($$1$i,$$1$i6,$format)|0);
  $imageSize$0 = $96;
 } else {
  $97 = (__Z18CalculateImageSizeii13TextureFormat($$1$i,$$1$i6,$format)|0);
  $imageSize$0 = $97;
 }
 $98 = HEAP32[628264>>2]|0;
 HEAP32[$0>>2] = $98;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $99 = (__Znwj10MemLabelIdbiPKci(48,$$byval_copy2,0,16,608384,918)|0);
 $100 = HEAP32[628264>>2]|0;
 HEAP32[$1>>2] = $100;
 $101 = (($this) + 48|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = ($102|0)==(0|0);
 if ($103) {
  $106 = 0;
 } else {
  $104 = (($102) + 40|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = $105;
 }
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiiiiii(13,($99|0),($$byval_copy2|0),($$1$i|0),($$1$i6|0),($format|0),($imageSize$0|0),($106|0),($5|0),1);
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if (!($108)) {
  STACKTOP = sp;return ($99|0);
 }
 $109 = ___cxa_find_matching_catch()|0;
 $110 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($99|0),($$byval_copy2|0),0,16,(608384|0),918);
 $111 = __THREW__; __THREW__ = 0;
 $112 = $111&1;
 if ($112) {
  $113 = ___cxa_find_matching_catch(0|0)|0;
  $114 = tempRet0;
  ___clang_call_terminate($113);
  // unreachable;
 } else {
  ___resumeException($109|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK9Texture2D20GetRuntimeMemorySizeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 136;
}
function __Z23RegisterClass_Texture2Dv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(28,135,136,0,137);
 STACKTOP = sp;return;
}
function __ZN9Texture2D13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(27)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN7Texture13RegisterClassEv();
 }
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=608600+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,28,27,($0|0),136,(2403|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN9Texture2D15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Texture2D12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Texture2D7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy2,1,16,608384,77)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1733,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(608384|0),77);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK9Texture2D25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 28;
}
function __ZN9Texture2D23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,608616,608600,$this,0);
 __ZN9Texture2D8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture2D23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,608616,608600,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9Texture2D8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture2D23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture2D8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture2D23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture2D8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture2D23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture2D8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture2D23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy = 0, $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 __ZN7Texture8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN9Texture2D18UnshareTextureDataEv($this);
 HEAP32[$0>>2] = 61;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN9Texture2D8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $format = 0, $height = 0, $imageCount = 0, $imageSize = 0, $imageSizeXImageCount = 0, $mipmap = 0, $width = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 28|0;
 $0 = sp + 24|0;
 $width = sp + 20|0;
 $height = sp + 16|0;
 $format = sp + 12|0;
 $imageSize = sp + 4|0;
 $imageCount = sp;
 $mipmap = sp + 32|0;
 $imageSizeXImageCount = sp + 8|0;
 __ZN7Texture8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN9Texture2D18UnshareTextureDataEv($this);
 HEAP32[$width>>2] = 0;
 HEAP32[$height>>2] = 0;
 HEAP32[$format>>2] = 0;
 HEAP32[$imageSize>>2] = 0;
 HEAP32[$imageCount>>2] = 0;
 HEAP8[$mipmap>>0] = 0;
 $1 = HEAP32[580592>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($transfer|0),(608624|0),($1|0),($width|0),16);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($transfer) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = HEAP32[$5>>2]|0;
   $7 = (($transfer) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($6) + (($8*24)|0)|0) + 12|0);
   HEAP32[$9>>2] = 4;
   __THREW__ = 0;
   invoke_vi(3390,($transfer|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    invoke_viiiii(86,($transfer|0),(608632|0),($1|0),($height|0),16);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[$4>>2]|0;
     $19 = HEAP32[$18>>2]|0;
     $20 = HEAP32[$7>>2]|0;
     $21 = ((($19) + (($20*24)|0)|0) + 12|0);
     HEAP32[$21>>2] = 4;
     __THREW__ = 0;
     invoke_vi(3390,($transfer|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      invoke_viiiii(86,($transfer|0),(608648|0),($1|0),($imageSize|0),16);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = HEAP32[$4>>2]|0;
       $27 = HEAP32[$26>>2]|0;
       $28 = HEAP32[$7>>2]|0;
       $29 = ((($27) + (($28*24)|0)|0) + 12|0);
       HEAP32[$29>>2] = 4;
       __THREW__ = 0;
       invoke_vi(3390,($transfer|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        __THREW__ = 0;
        invoke_viiiii(86,($transfer|0),(608672|0),($1|0),($format|0),1);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         $34 = HEAP32[$4>>2]|0;
         $35 = HEAP32[$34>>2]|0;
         $36 = HEAP32[$7>>2]|0;
         $37 = ((($35) + (($36*24)|0)|0) + 12|0);
         HEAP32[$37>>2] = 4;
         __THREW__ = 0;
         invoke_vi(3390,($transfer|0));
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if (!($39)) {
          $40 = HEAP32[580544>>2]|0;
          __THREW__ = 0;
          invoke_viiiii(86,($transfer|0),(608688|0),($40|0),($mipmap|0),16);
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if (!($42)) {
           $43 = HEAP32[$4>>2]|0;
           $44 = HEAP32[$43>>2]|0;
           $45 = HEAP32[$7>>2]|0;
           $46 = ((($44) + (($45*24)|0)|0) + 12|0);
           HEAP32[$46>>2] = 1;
           __THREW__ = 0;
           invoke_vi(3390,($transfer|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if (!($48)) {
            $49 = (($this) + 127|0);
            __THREW__ = 0;
            invoke_viiiii(86,($transfer|0),(608704|0),($40|0),($49|0),0);
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if (!($51)) {
             $52 = HEAP32[$4>>2]|0;
             $53 = HEAP32[$52>>2]|0;
             $54 = HEAP32[$7>>2]|0;
             $55 = ((($53) + (($54*24)|0)|0) + 12|0);
             HEAP32[$55>>2] = 1;
             __THREW__ = 0;
             invoke_vi(3390,($transfer|0));
             $56 = __THREW__; __THREW__ = 0;
             $57 = $56&1;
             if (!($57)) {
              $58 = (($this) + 128|0);
              __THREW__ = 0;
              invoke_viiiii(86,($transfer|0),(608720|0),($40|0),($58|0),16);
              $59 = __THREW__; __THREW__ = 0;
              $60 = $59&1;
              if (!($60)) {
               $61 = HEAP32[$4>>2]|0;
               $62 = HEAP32[$61>>2]|0;
               $63 = HEAP32[$7>>2]|0;
               $64 = ((($62) + (($63*24)|0)|0) + 12|0);
               HEAP32[$64>>2] = 1;
               __THREW__ = 0;
               invoke_vi(3390,($transfer|0));
               $65 = __THREW__; __THREW__ = 0;
               $66 = $65&1;
               if (!($66)) {
                __THREW__ = 0;
                invoke_vi(3392,($transfer|0));
                $67 = __THREW__; __THREW__ = 0;
                $68 = $67&1;
                if (!($68)) {
                 __THREW__ = 0;
                 invoke_viiiii(86,($transfer|0),(608736|0),($1|0),($imageCount|0),16);
                 $69 = __THREW__; __THREW__ = 0;
                 $70 = $69&1;
                 if (!($70)) {
                  $71 = HEAP32[$4>>2]|0;
                  $72 = HEAP32[$71>>2]|0;
                  $73 = HEAP32[$7>>2]|0;
                  $74 = ((($72) + (($73*24)|0)|0) + 12|0);
                  HEAP32[$74>>2] = 4;
                  __THREW__ = 0;
                  invoke_vi(3390,($transfer|0));
                  $75 = __THREW__; __THREW__ = 0;
                  $76 = $75&1;
                  if (!($76)) {
                   $77 = (($this) + 100|0);
                   __THREW__ = 0;
                   invoke_viiiii(86,($transfer|0),(608752|0),($1|0),($77|0),1);
                   $78 = __THREW__; __THREW__ = 0;
                   $79 = $78&1;
                   if (!($79)) {
                    $80 = HEAP32[$4>>2]|0;
                    $81 = HEAP32[$80>>2]|0;
                    $82 = HEAP32[$7>>2]|0;
                    $83 = ((($81) + (($82*24)|0)|0) + 12|0);
                    HEAP32[$83>>2] = 4;
                    __THREW__ = 0;
                    invoke_vi(3390,($transfer|0));
                    $84 = __THREW__; __THREW__ = 0;
                    $85 = $84&1;
                    if (!($85)) {
                     $86 = (($this) + 28|0);
                     __THREW__ = 0;
                     invoke_viiiii(86,($transfer|0),(608776|0),(609376|0),($86|0),0);
                     $87 = __THREW__; __THREW__ = 0;
                     $88 = $87&1;
                     if ($88) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(2721,($86|0),($transfer|0));
                     $89 = __THREW__; __THREW__ = 0;
                     $90 = $89&1;
                     if ($90) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3390,($transfer|0));
                     $91 = __THREW__; __THREW__ = 0;
                     $92 = $91&1;
                     if ($92) {
                      break;
                     }
                     $93 = (($this) + 52|0);
                     __THREW__ = 0;
                     invoke_viiiii(86,($transfer|0),(608800|0),($1|0),($93|0),0);
                     $94 = __THREW__; __THREW__ = 0;
                     $95 = $94&1;
                     if ($95) {
                      break;
                     }
                     $96 = HEAP32[$4>>2]|0;
                     $97 = HEAP32[$96>>2]|0;
                     $98 = HEAP32[$7>>2]|0;
                     $99 = ((($97) + (($98*24)|0)|0) + 12|0);
                     HEAP32[$99>>2] = 4;
                     __THREW__ = 0;
                     invoke_vi(3390,($transfer|0));
                     $100 = __THREW__; __THREW__ = 0;
                     $101 = $100&1;
                     if ($101) {
                      break;
                     }
                     $102 = (($this) + 56|0);
                     __THREW__ = 0;
                     invoke_viiiii(86,($transfer|0),(608824|0),($1|0),($102|0),0);
                     $103 = __THREW__; __THREW__ = 0;
                     $104 = $103&1;
                     if ($104) {
                      break;
                     }
                     $105 = HEAP32[$4>>2]|0;
                     $106 = HEAP32[$105>>2]|0;
                     $107 = HEAP32[$7>>2]|0;
                     $108 = ((($106) + (($107*24)|0)|0) + 12|0);
                     HEAP32[$108>>2] = 4;
                     __THREW__ = 0;
                     invoke_vi(3390,($transfer|0));
                     $109 = __THREW__; __THREW__ = 0;
                     $110 = $109&1;
                     if ($110) {
                      break;
                     }
                     $111 = HEAP32[$imageCount>>2]|0;
                     $112 = HEAP32[$imageSize>>2]|0;
                     $113 = Math_imul($112, $111)|0;
                     HEAP32[$imageSizeXImageCount>>2] = $113;
                     __THREW__ = 0;
                     invoke_viiii(353,($transfer|0),($imageSizeXImageCount|0),(608840|0),1);
                     $114 = __THREW__; __THREW__ = 0;
                     $115 = $114&1;
                     if ($115) {
                      break;
                     }
                     $116 = (($this) + 48|0);
                     $117 = HEAP32[$116>>2]|0;
                     $118 = ($117|0)==(0|0);
                     if ($118) {
                      $122 = 0;
                     } else {
                      $119 = (($117) + 8|0);
                      $120 = HEAP32[$119>>2]|0;
                      $122 = $120;
                     }
                     $121 = HEAP32[$imageSizeXImageCount>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(354,($transfer|0),($121|0),($122|0),0);
                     $123 = __THREW__; __THREW__ = 0;
                     $124 = $123&1;
                     if ($124) {
                      break;
                     }
                     HEAP32[$0>>2] = 61;
                     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
                     __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy1);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 HEAP32[$0>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $125 = ___cxa_find_matching_catch(0|0)|0;
  $126 = tempRet0;
  ___clang_call_terminate($125);
  // unreachable;
 } else {
  ___resumeException($12|0);
  // unreachable;
 }
}
function __ZN9Texture2D8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$$i = 0, $$0 = 0, $$0$i = 0, $$0$i42 = 0, $$01 = 0, $$1$i = 0, $$1$i43 = 0, $$byval_copy5 = 0, $$not$i = 0, $$sum = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i16 = 0, $$sum$i$i$i$i$i7 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i17 = 0, $$sum1$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $converter$i$i15 = 0, $converter$i$i24 = 0, $converter$i$i6 = 0, $exitcond$i$i = 0, $exitcond7$i$i = 0, $format = 0, $format$off$i$i = 0, $format$off$i$i46 = 0, $format$off$i1$i = 0, $format$off$i1$i56 = 0;
 var $format$off$i2$i = 0, $format$off$i2$i54 = 0, $format$off$i3$i = 0, $format$off$i3$i52 = 0, $format$off$i4$i = 0, $format$off$i4$i50 = 0, $format$off$i5$i = 0, $format$off$i5$i47 = 0, $height = 0, $i$02$i$i = 0, $i2$05$i$i = 0, $imageCount = 0, $imageSize = 0, $imageSizeXImageCount = 0, $mipmap = 0, $or$cond$i = 0, $or$cond$i38 = 0, $or$cond$i39 = 0, $or$cond$i48 = 0, $or$cond$i58 = 0;
 var $or$cond$not$i = 0, $or$cond$not$i40 = 0, $or$cond11$i = 0, $or$cond11$i53 = 0, $or$cond13$i = 0, $or$cond13$i55 = 0, $or$cond3$i = 0, $or$cond3$i41 = 0, $or$cond7$i = 0, $or$cond7$i49 = 0, $or$cond9$i = 0, $or$cond9$i51 = 0, $p$01$i$i = 0, $p1$04$i$i = 0, $phitmp$i = 0, $width = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy5 = sp + 56|0;
 $0 = sp + 52|0;
 $converter$i$i24 = sp + 48|0;
 $converter$i$i15 = sp + 44|0;
 $converter$i$i6 = sp + 40|0;
 $converter$i$i = sp + 36|0;
 $1 = sp + 32|0;
 $width = sp + 24|0;
 $height = sp + 20|0;
 $format = sp + 16|0;
 $imageSize = sp + 12|0;
 $imageCount = sp + 8|0;
 $mipmap = sp + 60|0;
 $imageSizeXImageCount = sp + 4|0;
 $2 = sp;
 $3 = sp + 28|0;
 __ZN7Texture8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN9Texture2D18UnshareTextureDataEv($this);
 HEAP32[$width>>2] = 0;
 HEAP32[$height>>2] = 0;
 HEAP32[$format>>2] = 0;
 HEAP32[$imageSize>>2] = 0;
 HEAP32[$imageCount>>2] = 0;
 HEAP8[$mipmap>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(369,($transfer|0),($width|0),(608624|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   label = 2;
  } else {
   __THREW__ = 0;
   invoke_viiii(369,($transfer|0),($height|0),(608632|0),0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 2;
   } else {
    __THREW__ = 0;
    invoke_viiii(369,($transfer|0),($imageSize|0),(608648|0),0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     label = 2;
    } else {
     __THREW__ = 0;
     invoke_viiii(369,($transfer|0),($format|0),(608672|0),0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      label = 2;
     } else {
      $14 = HEAP32[580544>>2]|0;
      __THREW__ = 0;
      $15 = (invoke_iiiiii(192,($transfer|0),(608688|0),($14|0),($converter$i$i|0),0)|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       label = 2;
      } else {
       $18 = ($15|0)==(0);
       if (!($18)) {
        $19 = ($15|0)>(0);
        do {
         if ($19) {
          $20 = (($transfer) + 12|0);
          $21 = (($transfer) + 80|0);
          $22 = HEAP32[$21>>2]|0;
          $23 = (($22) + 12|0);
          $24 = HEAP32[$23>>2]|0;
          $25 = (($transfer) + 16|0);
          $26 = HEAP32[$25>>2]|0;
          $27 = (($transfer) + 28|0);
          $28 = HEAP32[$27>>2]|0;
          $29 = (($transfer) + 32|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = Math_imul($30, $28)|0;
          $$sum$i$i$i$i$i = (($24) - ($31))|0;
          $32 = (($26) + ($$sum$i$i$i$i$i)|0);
          HEAP32[$20>>2] = $32;
          $33 = ($$sum$i$i$i$i$i|0)<(0);
          if (!($33)) {
           $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
           $34 = (($26) + ($$sum1$i$i$i$i$i)|0);
           $35 = (($transfer) + 20|0);
           $36 = HEAP32[$35>>2]|0;
           $37 = ($34>>>0)>($36>>>0);
           if (!($37)) {
            $38 = HEAP8[$32>>0]|0;
            HEAP8[$mipmap>>0] = $38;
            $$sum = (($$sum$i$i$i$i$i) + 1)|0;
            $39 = (($26) + ($$sum)|0);
            HEAP32[$20>>2] = $39;
            break;
           }
          }
          __THREW__ = 0;
          invoke_viii(1748,($20|0),($mipmap|0),1);
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           label = 2;
           break L1;
          }
         } else {
          $42 = HEAP32[$converter$i$i>>2]|0;
          $43 = ($42|0)==(0|0);
          if (!($43)) {
           __THREW__ = 0;
           (invoke_iii($42|0,($mipmap|0),($transfer|0))|0);
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            label = 2;
            break L1;
           }
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3389,($transfer|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         label = 2;
         break;
        }
       }
       $48 = (($this) + 127|0);
       __THREW__ = 0;
       $49 = (invoke_iiiiii(192,($transfer|0),(608704|0),($14|0),($converter$i$i6|0),0)|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        label = 2;
       } else {
        $52 = ($49|0)==(0);
        if (!($52)) {
         $53 = ($49|0)>(0);
         do {
          if ($53) {
           $54 = (($transfer) + 12|0);
           $55 = (($transfer) + 80|0);
           $56 = HEAP32[$55>>2]|0;
           $57 = (($56) + 12|0);
           $58 = HEAP32[$57>>2]|0;
           $59 = (($transfer) + 16|0);
           $60 = HEAP32[$59>>2]|0;
           $61 = (($transfer) + 28|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = (($transfer) + 32|0);
           $64 = HEAP32[$63>>2]|0;
           $65 = Math_imul($64, $62)|0;
           $$sum$i$i$i$i$i7 = (($58) - ($65))|0;
           $66 = (($60) + ($$sum$i$i$i$i$i7)|0);
           HEAP32[$54>>2] = $66;
           $67 = ($$sum$i$i$i$i$i7|0)<(0);
           if (!($67)) {
            $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
            $68 = (($60) + ($$sum1$i$i$i$i$i8)|0);
            $69 = (($transfer) + 20|0);
            $70 = HEAP32[$69>>2]|0;
            $71 = ($68>>>0)>($70>>>0);
            if (!($71)) {
             $72 = HEAP8[$66>>0]|0;
             HEAP8[$48>>0] = $72;
             $73 = HEAP32[$54>>2]|0;
             $74 = (($73) + 1|0);
             HEAP32[$54>>2] = $74;
             break;
            }
           }
           __THREW__ = 0;
           invoke_viii(1748,($54|0),($48|0),1);
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if ($76) {
            label = 2;
            break L1;
           }
          } else {
           $77 = HEAP32[$converter$i$i6>>2]|0;
           $78 = ($77|0)==(0|0);
           if (!($78)) {
            __THREW__ = 0;
            (invoke_iii($77|0,($48|0),($transfer|0))|0);
            $79 = __THREW__; __THREW__ = 0;
            $80 = $79&1;
            if ($80) {
             label = 2;
             break L1;
            }
           }
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3389,($transfer|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          label = 2;
          break;
         }
        }
        $83 = (($this) + 128|0);
        __THREW__ = 0;
        $84 = (invoke_iiiiii(192,($transfer|0),(608720|0),($14|0),($converter$i$i15|0),0)|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 2;
        } else {
         $87 = ($84|0)==(0);
         if (!($87)) {
          $88 = ($84|0)>(0);
          do {
           if ($88) {
            $89 = (($transfer) + 12|0);
            $90 = (($transfer) + 80|0);
            $91 = HEAP32[$90>>2]|0;
            $92 = (($91) + 12|0);
            $93 = HEAP32[$92>>2]|0;
            $94 = (($transfer) + 16|0);
            $95 = HEAP32[$94>>2]|0;
            $96 = (($transfer) + 28|0);
            $97 = HEAP32[$96>>2]|0;
            $98 = (($transfer) + 32|0);
            $99 = HEAP32[$98>>2]|0;
            $100 = Math_imul($99, $97)|0;
            $$sum$i$i$i$i$i16 = (($93) - ($100))|0;
            $101 = (($95) + ($$sum$i$i$i$i$i16)|0);
            HEAP32[$89>>2] = $101;
            $102 = ($$sum$i$i$i$i$i16|0)<(0);
            if (!($102)) {
             $$sum1$i$i$i$i$i17 = (($$sum$i$i$i$i$i16) + 1)|0;
             $103 = (($95) + ($$sum1$i$i$i$i$i17)|0);
             $104 = (($transfer) + 20|0);
             $105 = HEAP32[$104>>2]|0;
             $106 = ($103>>>0)>($105>>>0);
             if (!($106)) {
              $107 = HEAP8[$101>>0]|0;
              HEAP8[$83>>0] = $107;
              $108 = HEAP32[$89>>2]|0;
              $109 = (($108) + 1|0);
              HEAP32[$89>>2] = $109;
              break;
             }
            }
            __THREW__ = 0;
            invoke_viii(1748,($89|0),($83|0),1);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if ($111) {
             label = 2;
             break L1;
            }
           } else {
            $112 = HEAP32[$converter$i$i15>>2]|0;
            $113 = ($112|0)==(0|0);
            if (!($113)) {
             __THREW__ = 0;
             (invoke_iii($112|0,($83|0),($transfer|0))|0);
             $114 = __THREW__; __THREW__ = 0;
             $115 = $114&1;
             if ($115) {
              label = 2;
              break L1;
             }
            }
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3389,($transfer|0));
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           label = 2;
           break;
          }
         }
         __THREW__ = 0;
         invoke_viiii(369,($transfer|0),($imageCount|0),(608736|0),0);
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          label = 2;
         } else {
          $120 = (($this) + 100|0);
          __THREW__ = 0;
          invoke_viiii(369,($transfer|0),($120|0),(608752|0),0);
          $121 = __THREW__; __THREW__ = 0;
          $122 = $121&1;
          if ($122) {
           label = 2;
          } else {
           $123 = (($this) + 28|0);
           __THREW__ = 0;
           $124 = (invoke_iiiiii(192,($transfer|0),(608776|0),(609376|0),($converter$i$i24|0),1)|0);
           $125 = __THREW__; __THREW__ = 0;
           $126 = $125&1;
           if ($126) {
            label = 2;
           } else {
            $127 = ($124|0)==(0);
            if (!($127)) {
             $128 = ($124|0)>(0);
             if ($128) {
              __THREW__ = 0;
              invoke_viiii(369,($transfer|0),($123|0),(609320|0),0);
              $129 = __THREW__; __THREW__ = 0;
              $130 = $129&1;
              if ($130) {
               label = 2;
               break;
              }
              $131 = (($this) + 32|0);
              __THREW__ = 0;
              invoke_viiii(369,($transfer|0),($131|0),(609336|0),0);
              $132 = __THREW__; __THREW__ = 0;
              $133 = $132&1;
              if ($133) {
               label = 2;
               break;
              }
              $134 = (($this) + 36|0);
              __THREW__ = 0;
              invoke_viiii(370,($transfer|0),($134|0),(609344|0),0);
              $135 = __THREW__; __THREW__ = 0;
              $136 = $135&1;
              if ($136) {
               label = 2;
               break;
              }
              $137 = (($this) + 40|0);
              __THREW__ = 0;
              invoke_viiii(369,($transfer|0),($137|0),(609360|0),0);
              $138 = __THREW__; __THREW__ = 0;
              $139 = $138&1;
              if ($139) {
               label = 2;
               break;
              }
             } else {
              $140 = HEAP32[$converter$i$i24>>2]|0;
              $141 = ($140|0)==(0|0);
              if (!($141)) {
               __THREW__ = 0;
               (invoke_iii($140|0,($123|0),($transfer|0))|0);
               $142 = __THREW__; __THREW__ = 0;
               $143 = $142&1;
               if ($143) {
                label = 2;
                break;
               }
              }
             }
             __THREW__ = 0;
             invoke_vi(3389,($transfer|0));
             $144 = __THREW__; __THREW__ = 0;
             $145 = $144&1;
             if ($145) {
              label = 2;
              break;
             }
            }
            $146 = (($this) + 52|0);
            __THREW__ = 0;
            invoke_viiii(369,($transfer|0),($146|0),(608800|0),0);
            $147 = __THREW__; __THREW__ = 0;
            $148 = $147&1;
            if ($148) {
             label = 2;
            } else {
             $149 = (($this) + 56|0);
             __THREW__ = 0;
             invoke_viiii(369,($transfer|0),($149|0),(608824|0),0);
             $150 = __THREW__; __THREW__ = 0;
             $151 = $150&1;
             if ($151) {
              label = 2;
             } else {
              $152 = HEAP32[$imageCount>>2]|0;
              $153 = HEAP32[$imageSize>>2]|0;
              $154 = Math_imul($153, $152)|0;
              HEAP32[$imageSizeXImageCount>>2] = $154;
              __THREW__ = 0;
              invoke_viiii(355,($transfer|0),($imageSizeXImageCount|0),(608840|0),1);
              $155 = __THREW__; __THREW__ = 0;
              $156 = $155&1;
              if ($156) {
               label = 2;
              } else {
               __THREW__ = 0;
               invoke_vi(3491,($this|0));
               $157 = __THREW__; __THREW__ = 0;
               $158 = $157&1;
               if ($158) {
                label = 2;
               } else {
                __THREW__ = 0;
                $159 = (invoke_ii(3223,($this|0))|0);
                $160 = __THREW__; __THREW__ = 0;
                $161 = $160&1;
                if ($161) {
                 label = 2;
                } else {
                 __THREW__ = 0;
                 $162 = (invoke_ii(3223,($this|0))|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  label = 2;
                  break;
                 }
                 $165 = ($159|0)==(15);
                 $$$i = $165 ? $162 : 13;
                 $166 = (($this) + 48|0);
                 $167 = HEAP32[$166>>2]|0;
                 $168 = ($167|0)==(0|0);
                 if (!($168)) {
                  $169 = HEAP32[628264>>2]|0;
                  $170 = (($167) + 4|0);
                  $171 = HEAP32[$170>>2]|0;
                  $172 = (($171) + -1)|0;
                  HEAP32[$170>>2] = $172;
                  $173 = HEAP32[$170>>2]|0;
                  $174 = ($173|0)==(0);
                  if ($174) {
                   $175 = HEAP32[$167>>2]|0;
                   $176 = HEAP32[$175>>2]|0;
                   __THREW__ = 0;
                   invoke_vi($176|0,($167|0));
                   $177 = __THREW__; __THREW__ = 0;
                   $178 = $177&1;
                   if ($178) {
                    label = 2;
                    break;
                   }
                   HEAP32[$0>>2] = $169;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
                   invoke_vii(2591,($167|0),($$byval_copy5|0));
                   $179 = __THREW__; __THREW__ = 0;
                   $180 = $179&1;
                   if ($180) {
                    label = 2;
                    break;
                   }
                  }
                  HEAP32[$166>>2] = 0;
                 }
                 $181 = HEAP32[628264>>2]|0;
                 HEAP32[$2>>2] = $181;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
                 $182 = (invoke_iiiiiii(103,48,($$byval_copy5|0),0,16,(608384|0),779)|0);
                 $183 = __THREW__; __THREW__ = 0;
                 $184 = $183&1;
                 if ($184) {
                  label = 2;
                  break;
                 }
                 HEAP32[$3>>2] = $$$i;
                 $185 = HEAP32[$width>>2]|0;
                 $186 = HEAP32[$height>>2]|0;
                 $187 = HEAP32[$format>>2]|0;
                 $188 = HEAP32[$imageSize>>2]|0;
                 $189 = HEAP32[$imageCount>>2]|0;
                 $190 = HEAP8[$mipmap>>0]|0;
                 $191 = ($190<<24>>24)!=(0);
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
                 invoke_viiiiiiiii(13,($182|0),($$byval_copy5|0),($185|0),($186|0),($187|0),($188|0),($189|0),($191|0),1);
                 $192 = __THREW__; __THREW__ = 0;
                 $193 = $192&1;
                 if ($193) {
                  $336 = ___cxa_find_matching_catch()|0;
                  $337 = tempRet0;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
                  invoke_viiiiii(97,($182|0),($$byval_copy5|0),0,16,(608384|0),779);
                  $338 = __THREW__; __THREW__ = 0;
                  $339 = $338&1;
                  if (!($339)) {
                   $$0 = $336;$$01 = $337;
                   break;
                  }
                  $371 = ___cxa_find_matching_catch(0|0)|0;
                  $372 = tempRet0;
                  ___clang_call_terminate($371);
                  // unreachable;
                 }
                 HEAP32[$166>>2] = $182;
                 $194 = HEAP32[$width>>2]|0;
                 $195 = (($this) + 104|0);
                 HEAP32[$195>>2] = $194;
                 $196 = HEAP32[$height>>2]|0;
                 $197 = (($this) + 108|0);
                 HEAP32[$197>>2] = $196;
                 $198 = HEAP8[$mipmap>>0]|0;
                 $199 = (($this) + 96|0);
                 HEAP8[$199>>0] = $198;
                 $200 = ($198<<24>>24)!=(0);
                 $201 = HEAP32[$format>>2]|0;
                 __THREW__ = 0;
                 $202 = (invoke_ii(3249,($201|0))|0);
                 $203 = __THREW__; __THREW__ = 0;
                 $204 = $203&1;
                 if ($204) {
                  label = 2;
                  break;
                 }
                 $205 = (($194) + -1)|0;
                 $206 = (($205) + ($202))|0;
                 $207 = (0 - ($202))|0;
                 $208 = $206 & $207;
                 $format$off$i$i = (($201) + -10)|0;
                 $209 = ($format$off$i$i>>>0)<(3);
                 $format$off$i5$i = (($201) + -30)|0;
                 $210 = ($format$off$i5$i>>>0)<(4);
                 $or$cond$i38 = $209 | $210;
                 $211 = ($201|0)==(34);
                 $or$cond7$i = $or$cond$i38 | $211;
                 $format$off$i4$i = (($201) + -35)|0;
                 $212 = ($format$off$i4$i>>>0)<(2);
                 $or$cond9$i = $or$cond7$i | $212;
                 $format$off$i3$i = (($201) + -41)|0;
                 $213 = ($format$off$i3$i>>>0)<(4);
                 $or$cond11$i = $or$cond9$i | $213;
                 $format$off$i2$i = (($201) + -45)|0;
                 $214 = ($format$off$i2$i>>>0)<(3);
                 $or$cond13$i = $or$cond11$i | $214;
                 if ($or$cond13$i) {
                  $218 = 1;
                 } else {
                  $format$off$i1$i = (($201) + -48)|0;
                  $215 = ($format$off$i1$i>>>0)<(12);
                  $218 = $215;
                 }
                 $216 = HEAP32[((640792 + 228|0))>>2]|0;
                 $217 = ($216|0)<(2);
                 $or$cond$i = $218 & $217;
                 $or$cond$not$i = $or$cond$i ^ 1;
                 $219 = HEAP8[((640792 + 236|0))>>0]|0;
                 $220 = ($219<<24>>24)==(0);
                 $or$cond3$i = $220 | $or$cond$not$i;
                 if ($or$cond3$i) {
                  $$0$i = $208;
                 } else {
                  $221 = (($208) + -1)|0;
                  $222 = $221 >>> 16;
                  $223 = $222 | $221;
                  $224 = $223 >>> 8;
                  $225 = $224 | $223;
                  $226 = $225 >>> 4;
                  $227 = $226 | $225;
                  $228 = $227 >>> 2;
                  $229 = $228 | $227;
                  $230 = $229 >>> 1;
                  $231 = $230 | $229;
                  $232 = (($231) + 1)|0;
                  $$0$i = $232;
                 }
                 $233 = ($216|0)==(2);
                 $234 = ($216|0)>(0);
                 $235 = $200 ? $233 : $234;
                 if ($235) {
                  $$1$i = $$0$i;
                 } else {
                  $236 = (($$0$i) + -1)|0;
                  $237 = $236 >>> 16;
                  $238 = $237 | $236;
                  $239 = $238 >>> 8;
                  $240 = $239 | $238;
                  $241 = $240 >>> 4;
                  $242 = $241 | $240;
                  $243 = $242 >>> 2;
                  $244 = $243 | $242;
                  $245 = $244 >>> 1;
                  $246 = $245 | $244;
                  $247 = (($246) + 1)|0;
                  $$1$i = $247;
                 }
                 $248 = (($this) + 112|0);
                 HEAP32[$248>>2] = $$1$i;
                 $249 = HEAP32[$height>>2]|0;
                 $250 = HEAP8[$mipmap>>0]|0;
                 $251 = ($250<<24>>24)!=(0);
                 $252 = HEAP32[$format>>2]|0;
                 __THREW__ = 0;
                 $253 = (invoke_ii(3249,($252|0))|0);
                 $254 = __THREW__; __THREW__ = 0;
                 $255 = $254&1;
                 if ($255) {
                  label = 2;
                  break;
                 }
                 $256 = (($249) + -1)|0;
                 $257 = (($256) + ($253))|0;
                 $258 = (0 - ($253))|0;
                 $259 = $257 & $258;
                 $format$off$i$i46 = (($252) + -10)|0;
                 $260 = ($format$off$i$i46>>>0)<(3);
                 $format$off$i5$i47 = (($252) + -30)|0;
                 $261 = ($format$off$i5$i47>>>0)<(4);
                 $or$cond$i48 = $260 | $261;
                 $262 = ($252|0)==(34);
                 $or$cond7$i49 = $or$cond$i48 | $262;
                 $format$off$i4$i50 = (($252) + -35)|0;
                 $263 = ($format$off$i4$i50>>>0)<(2);
                 $or$cond9$i51 = $or$cond7$i49 | $263;
                 $format$off$i3$i52 = (($252) + -41)|0;
                 $264 = ($format$off$i3$i52>>>0)<(4);
                 $or$cond11$i53 = $or$cond9$i51 | $264;
                 $format$off$i2$i54 = (($252) + -45)|0;
                 $265 = ($format$off$i2$i54>>>0)<(3);
                 $or$cond13$i55 = $or$cond11$i53 | $265;
                 if ($or$cond13$i55) {
                  $269 = 1;
                 } else {
                  $format$off$i1$i56 = (($252) + -48)|0;
                  $266 = ($format$off$i1$i56>>>0)<(12);
                  $269 = $266;
                 }
                 $267 = HEAP32[((640792 + 228|0))>>2]|0;
                 $268 = ($267|0)<(2);
                 $or$cond$i39 = $269 & $268;
                 $or$cond$not$i40 = $or$cond$i39 ^ 1;
                 $270 = HEAP8[((640792 + 236|0))>>0]|0;
                 $271 = ($270<<24>>24)==(0);
                 $or$cond3$i41 = $271 | $or$cond$not$i40;
                 if ($or$cond3$i41) {
                  $$0$i42 = $259;
                 } else {
                  $272 = (($259) + -1)|0;
                  $273 = $272 >>> 16;
                  $274 = $273 | $272;
                  $275 = $274 >>> 8;
                  $276 = $275 | $274;
                  $277 = $276 >>> 4;
                  $278 = $277 | $276;
                  $279 = $278 >>> 2;
                  $280 = $279 | $278;
                  $281 = $280 >>> 1;
                  $282 = $281 | $280;
                  $283 = (($282) + 1)|0;
                  $$0$i42 = $283;
                 }
                 $284 = ($267|0)==(2);
                 $285 = ($267|0)>(0);
                 $286 = $251 ? $284 : $285;
                 if ($286) {
                  $$1$i43 = $$0$i42;
                 } else {
                  $287 = (($$0$i42) + -1)|0;
                  $288 = $287 >>> 16;
                  $289 = $288 | $287;
                  $290 = $289 >>> 8;
                  $291 = $290 | $289;
                  $292 = $291 >>> 4;
                  $293 = $292 | $291;
                  $294 = $293 >>> 2;
                  $295 = $294 | $293;
                  $296 = $295 >>> 1;
                  $297 = $296 | $295;
                  $298 = (($297) + 1)|0;
                  $$1$i43 = $298;
                 }
                 $299 = (($this) + 116|0);
                 HEAP32[$299>>2] = $$1$i43;
                 $300 = HEAP32[$248>>2]|0;
                 $301 = (Math_fround(($300|0)));
                 $302 = Math_fround(Math_fround(1.0) / $301);
                 $303 = (Math_fround(($$1$i43|0)));
                 $304 = Math_fround(Math_fround(1.0) / $303);
                 $305 = (($this) + 72|0);
                 HEAPF32[$305>>2] = $302;
                 $306 = (($this) + 76|0);
                 HEAPF32[$306>>2] = $304;
                 $307 = HEAP32[$this>>2]|0;
                 $308 = (($307) + 104|0);
                 $309 = HEAP32[$308>>2]|0;
                 __THREW__ = 0;
                 $310 = (invoke_ii($309|0,($this|0))|0);
                 $311 = __THREW__; __THREW__ = 0;
                 $312 = $311&1;
                 if ($312) {
                  label = 2;
                  break;
                 }
                 $313 = (($310) + -1)|0;
                 $314 = $313 & $310;
                 $315 = ($314|0)==(0);
                 if ($315) {
                  $317 = HEAP32[$this>>2]|0;
                  $318 = (($317) + 108|0);
                  $319 = HEAP32[$318>>2]|0;
                  __THREW__ = 0;
                  $320 = (invoke_ii($319|0,($this|0))|0);
                  $321 = __THREW__; __THREW__ = 0;
                  $322 = $321&1;
                  if ($322) {
                   label = 2;
                   break;
                  }
                  $323 = (($320) + -1)|0;
                  $324 = $323 & $320;
                  $325 = ($324|0)==(0);
                  $phitmp$i = $325&1;
                  $326 = (($this) + 124|0);
                  HEAP8[$326>>0] = $phitmp$i;
                  if (!($325)) {
                   label = 80;
                  }
                 } else {
                  $316 = (($this) + 124|0);
                  HEAP8[$316>>0] = 0;
                  label = 80;
                 }
                 do {
                  if ((label|0) == 80) {
                   $327 = HEAP32[$this>>2]|0;
                   $328 = (($327) + 124|0);
                   $329 = HEAP32[$328>>2]|0;
                   __THREW__ = 0;
                   $330 = (invoke_ii($329|0,($this|0))|0);
                   $331 = __THREW__; __THREW__ = 0;
                   $332 = $331&1;
                   if ($332) {
                    label = 2;
                    break L1;
                   }
                   $$not$i = $330 ^ 1;
                   $333 = HEAP32[((640792 + 228|0))>>2]|0;
                   $334 = ($333|0)==(1);
                   $or$cond$i58 = $334 & $$not$i;
                   if (!($or$cond$i58)) {
                    break;
                   }
                   $335 = (($this) + 40|0);
                   HEAP32[$335>>2] = 1;
                  }
                 } while(0);
                 $340 = HEAP32[$166>>2]|0;
                 $341 = ($340|0)==(0|0);
                 if ($341) {
                  $345 = 0;
                 } else {
                  $342 = (($340) + 8|0);
                  $343 = HEAP32[$342>>2]|0;
                  $345 = $343;
                 }
                 $344 = HEAP32[$imageSizeXImageCount>>2]|0;
                 __THREW__ = 0;
                 invoke_viiii(356,($transfer|0),($344|0),($345|0),0);
                 $346 = __THREW__; __THREW__ = 0;
                 $347 = $346&1;
                 if ($347) {
                  label = 2;
                  break;
                 }
                 $348 = HEAP32[$transfer>>2]|0;
                 $349 = $348 & 512;
                 $350 = ($349|0)==(0);
                 if ($350) {
                  HEAP32[$0>>2] = 61;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
                  __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
                  STACKTOP = sp;return;
                 }
                 $351 = HEAP32[$format>>2]|0;
                 $352 = HEAP32[$imageSizeXImageCount>>2]|0;
                 if ((($351|0) == 6)) {
                  $353 = (($352|0) / 4)&-1;
                  $354 = ($352|0)>(3);
                  if (!($354)) {
                   HEAP32[$0>>2] = 61;
                   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
                   __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
                   STACKTOP = sp;return;
                  }
                  $i2$05$i$i = 0;$p1$04$i$i = $345;
                  while(1) {
                   $355 = (($p1$04$i$i) + 4|0);
                   $356 = HEAP32[$p1$04$i$i>>2]|0;
                   $357 = (_llvm_bswap_i32(($356|0))|0);
                   HEAP32[$p1$04$i$i>>2] = $357;
                   $358 = (($i2$05$i$i) + 1)|0;
                   $exitcond7$i$i = ($358|0)==($353|0);
                   if ($exitcond7$i$i) {
                    break;
                   } else {
                    $i2$05$i$i = $358;$p1$04$i$i = $355;
                   }
                  }
                  HEAP32[$0>>2] = 61;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
                  __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
                  STACKTOP = sp;return;
                 } else if ((($351|0) == 2) | (($351|0) == 7) | (($351|0) == 13)) {
                  $359 = (($352|0) / 2)&-1;
                  $360 = ($352|0)>(1);
                  if (!($360)) {
                   HEAP32[$0>>2] = 61;
                   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
                   __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
                   STACKTOP = sp;return;
                  }
                  $i$02$i$i = 0;$p$01$i$i = $345;
                  while(1) {
                   $361 = (($p$01$i$i) + 2|0);
                   $362 = HEAP16[$p$01$i$i>>1]|0;
                   $363 = $362&65535;
                   $364 = $363 << 8;
                   $365 = $363 >>> 8;
                   $366 = $364 | $365;
                   $367 = $366&65535;
                   HEAP16[$p$01$i$i>>1] = $367;
                   $368 = (($i$02$i$i) + 1)|0;
                   $exitcond$i$i = ($368|0)==($359|0);
                   if ($exitcond$i$i) {
                    break;
                   } else {
                    $i$02$i$i = $368;$p$01$i$i = $361;
                   }
                  }
                  HEAP32[$0>>2] = 61;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
                  __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
                  STACKTOP = sp;return;
                 } else {
                  HEAP32[$0>>2] = 61;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
                  __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $$0 = $6;$$01 = $7;
 }
 HEAP32[$1>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy5|0));
 $369 = __THREW__; __THREW__ = 0;
 $370 = $369&1;
 if ($370) {
  $371 = ___cxa_find_matching_catch(0|0)|0;
  $372 = tempRet0;
  ___clang_call_terminate($371);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN9Texture2D8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$$i = 0, $$0 = 0, $$0$i = 0, $$0$i33 = 0, $$01 = 0, $$1$i = 0, $$1$i34 = 0, $$byval_copy5 = 0, $$not$i = 0, $$pre = 0, $$pre53 = 0, $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0;
 var $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $format = 0, $format$off$i$i = 0, $format$off$i$i37 = 0, $format$off$i1$i = 0, $format$off$i1$i47 = 0, $format$off$i2$i = 0, $format$off$i2$i45 = 0, $format$off$i3$i = 0, $format$off$i3$i43 = 0, $format$off$i4$i = 0, $format$off$i4$i41 = 0, $format$off$i5$i = 0, $format$off$i5$i38 = 0, $height = 0, $imageCount = 0, $imageSize = 0, $imageSizeXImageCount = 0;
 var $mipmap = 0, $or$cond$i = 0, $or$cond$i29 = 0, $or$cond$i30 = 0, $or$cond$i39 = 0, $or$cond$i49 = 0, $or$cond$not$i = 0, $or$cond$not$i31 = 0, $or$cond11$i = 0, $or$cond11$i44 = 0, $or$cond13$i = 0, $or$cond13$i46 = 0, $or$cond3$i = 0, $or$cond3$i32 = 0, $or$cond7$i = 0, $or$cond7$i40 = 0, $or$cond9$i = 0, $or$cond9$i42 = 0, $phitmp$i = 0, $width = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp + 40|0;
 $0 = sp + 36|0;
 $1 = sp + 32|0;
 $width = sp + 28|0;
 $height = sp + 24|0;
 $format = sp + 16|0;
 $imageSize = sp + 12|0;
 $imageCount = sp + 8|0;
 $mipmap = sp + 44|0;
 $imageSizeXImageCount = sp + 4|0;
 $2 = sp;
 $3 = sp + 20|0;
 __ZN7Texture8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 __ZN9Texture2D18UnshareTextureDataEv($this);
 HEAP32[$width>>2] = 0;
 HEAP32[$height>>2] = 0;
 HEAP32[$format>>2] = 0;
 HEAP32[$imageSize>>2] = 0;
 HEAP32[$imageCount>>2] = 0;
 HEAP8[$mipmap>>0] = 0;
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($9) {
  __THREW__ = 0;
  invoke_viii(1748,($4|0),($width|0),4);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   label = 5;
  } else {
   $$pre = HEAP32[$4>>2]|0;
   $$pre53 = HEAP32[$7>>2]|0;
   $16 = $$pre;$18 = $$pre53;
   label = 6;
  }
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$width>>2] = $10;
  HEAP32[$4>>2] = $6;
  $16 = $6;$18 = $8;
  label = 6;
 }
 L5: do {
  if ((label|0) == 6) {
   $15 = (($16) + 4|0);
   $17 = ($15>>>0)>($18>>>0);
   if ($17) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($height|0),4);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 5;
     break;
    }
    $$pre54 = HEAP32[$4>>2]|0;
    $$pre55 = HEAP32[$7>>2]|0;
    $23 = $$pre54;$25 = $$pre55;
   } else {
    $19 = HEAP32[$16>>2]|0;
    HEAP32[$height>>2] = $19;
    HEAP32[$4>>2] = $15;
    $23 = $15;$25 = $18;
   }
   $22 = (($23) + 4|0);
   $24 = ($22>>>0)>($25>>>0);
   if ($24) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($imageSize|0),4);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     label = 5;
     break;
    }
    $$pre56 = HEAP32[$4>>2]|0;
    $$pre57 = HEAP32[$7>>2]|0;
    $30 = $$pre56;$32 = $$pre57;
   } else {
    $26 = HEAP32[$23>>2]|0;
    HEAP32[$imageSize>>2] = $26;
    HEAP32[$4>>2] = $22;
    $30 = $22;$32 = $25;
   }
   $29 = (($30) + 4|0);
   $31 = ($29>>>0)>($32>>>0);
   if ($31) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($format|0),4);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 5;
     break;
    }
    $$pre58 = HEAP32[$4>>2]|0;
    $$pre59 = HEAP32[$7>>2]|0;
    $37 = $$pre58;$39 = $$pre59;
   } else {
    $33 = HEAP32[$30>>2]|0;
    HEAP32[$format>>2] = $33;
    HEAP32[$4>>2] = $29;
    $37 = $29;$39 = $32;
   }
   $36 = (($37) + 1|0);
   $38 = ($36>>>0)>($39>>>0);
   if ($38) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($mipmap|0),1);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 5;
     break;
    }
    $$pre60 = HEAP32[$4>>2]|0;
    $$pre61 = HEAP32[$7>>2]|0;
    $45 = $$pre60;$47 = $$pre61;
   } else {
    $40 = HEAP8[$37>>0]|0;
    HEAP8[$mipmap>>0] = $40;
    HEAP32[$4>>2] = $36;
    $45 = $36;$47 = $39;
   }
   $43 = (($this) + 127|0);
   $44 = (($45) + 1|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($43|0),1);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     label = 5;
     break;
    }
    $$pre62 = HEAP32[$4>>2]|0;
    $55 = $$pre62;
   } else {
    $48 = HEAP8[$45>>0]|0;
    HEAP8[$43>>0] = $48;
    $49 = HEAP32[$4>>2]|0;
    $50 = (($49) + 1|0);
    HEAP32[$4>>2] = $50;
    $55 = $50;
   }
   $53 = (($this) + 128|0);
   $54 = (($55) + 1|0);
   $56 = HEAP32[$7>>2]|0;
   $57 = ($54>>>0)>($56>>>0);
   if ($57) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($53|0),1);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     label = 5;
     break;
    }
   } else {
    $58 = HEAP8[$55>>0]|0;
    HEAP8[$53>>0] = $58;
    $59 = HEAP32[$4>>2]|0;
    $60 = (($59) + 1|0);
    HEAP32[$4>>2] = $60;
   }
   __THREW__ = 0;
   invoke_vi(3376,($transfer|0));
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    label = 5;
   } else {
    $65 = HEAP32[$4>>2]|0;
    $66 = (($65) + 4|0);
    $67 = HEAP32[$7>>2]|0;
    $68 = ($66>>>0)>($67>>>0);
    if ($68) {
     __THREW__ = 0;
     invoke_viii(1748,($4|0),($imageCount|0),4);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      label = 5;
      break;
     }
     $$pre63 = HEAP32[$4>>2]|0;
     $$pre64 = HEAP32[$7>>2]|0;
     $74 = $$pre63;$76 = $$pre64;
    } else {
     $69 = HEAP32[$65>>2]|0;
     HEAP32[$imageCount>>2] = $69;
     HEAP32[$4>>2] = $66;
     $74 = $66;$76 = $67;
    }
    $72 = (($this) + 100|0);
    $73 = (($74) + 4|0);
    $75 = ($73>>>0)>($76>>>0);
    if ($75) {
     __THREW__ = 0;
     invoke_viii(1748,($4|0),($72|0),4);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      label = 5;
      break;
     }
    } else {
     $77 = HEAP32[$74>>2]|0;
     HEAP32[$72>>2] = $77;
     HEAP32[$4>>2] = $73;
    }
    $80 = (($this) + 28|0);
    __THREW__ = 0;
    invoke_vii(2722,($80|0),($transfer|0));
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     label = 5;
    } else {
     $83 = (($this) + 52|0);
     $84 = HEAP32[$4>>2]|0;
     $85 = (($84) + 4|0);
     $86 = HEAP32[$7>>2]|0;
     $87 = ($85>>>0)>($86>>>0);
     if ($87) {
      __THREW__ = 0;
      invoke_viii(1748,($4|0),($83|0),4);
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      if ($90) {
       label = 5;
       break;
      }
      $$pre65 = HEAP32[$4>>2]|0;
      $$pre66 = HEAP32[$7>>2]|0;
      $93 = $$pre65;$95 = $$pre66;
     } else {
      $88 = HEAP32[$84>>2]|0;
      HEAP32[$83>>2] = $88;
      HEAP32[$4>>2] = $85;
      $93 = $85;$95 = $86;
     }
     $91 = (($this) + 56|0);
     $92 = (($93) + 4|0);
     $94 = ($92>>>0)>($95>>>0);
     if ($94) {
      __THREW__ = 0;
      invoke_viii(1748,($4|0),($91|0),4);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       label = 5;
       break;
      }
     } else {
      $96 = HEAP32[$93>>2]|0;
      HEAP32[$91>>2] = $96;
      HEAP32[$4>>2] = $92;
     }
     $99 = HEAP32[$imageCount>>2]|0;
     $100 = HEAP32[$imageSize>>2]|0;
     $101 = Math_imul($100, $99)|0;
     HEAP32[$imageSizeXImageCount>>2] = $101;
     __THREW__ = 0;
     invoke_viiii(357,($transfer|0),($imageSizeXImageCount|0),(608840|0),1);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 5;
     } else {
      __THREW__ = 0;
      invoke_vi(3491,($this|0));
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       label = 5;
      } else {
       __THREW__ = 0;
       $106 = (invoke_ii(3223,($this|0))|0);
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        label = 5;
       } else {
        __THREW__ = 0;
        $109 = (invoke_ii(3223,($this|0))|0);
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         label = 5;
        } else {
         $112 = ($106|0)==(15);
         $$$i = $112 ? $109 : 13;
         $113 = (($this) + 48|0);
         $114 = HEAP32[$113>>2]|0;
         $115 = ($114|0)==(0|0);
         if (!($115)) {
          $116 = HEAP32[628264>>2]|0;
          $117 = (($114) + 4|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (($118) + -1)|0;
          HEAP32[$117>>2] = $119;
          $120 = HEAP32[$117>>2]|0;
          $121 = ($120|0)==(0);
          if ($121) {
           $122 = HEAP32[$114>>2]|0;
           $123 = HEAP32[$122>>2]|0;
           __THREW__ = 0;
           invoke_vi($123|0,($114|0));
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            label = 5;
            break;
           }
           HEAP32[$0>>2] = $116;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($114|0),($$byval_copy5|0));
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            label = 5;
            break;
           }
          }
          HEAP32[$113>>2] = 0;
         }
         $128 = HEAP32[628264>>2]|0;
         HEAP32[$2>>2] = $128;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
         $129 = (invoke_iiiiiii(103,48,($$byval_copy5|0),0,16,(608384|0),779)|0);
         $130 = __THREW__; __THREW__ = 0;
         $131 = $130&1;
         if ($131) {
          label = 5;
         } else {
          HEAP32[$3>>2] = $$$i;
          $132 = HEAP32[$width>>2]|0;
          $133 = HEAP32[$height>>2]|0;
          $134 = HEAP32[$format>>2]|0;
          $135 = HEAP32[$imageSize>>2]|0;
          $136 = HEAP32[$imageCount>>2]|0;
          $137 = HEAP8[$mipmap>>0]|0;
          $138 = ($137<<24>>24)!=(0);
          __THREW__ = 0;
          ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
          invoke_viiiiiiiii(13,($129|0),($$byval_copy5|0),($132|0),($133|0),($134|0),($135|0),($136|0),($138|0),1);
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           $283 = ___cxa_find_matching_catch()|0;
           $284 = tempRet0;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
           invoke_viiiiii(97,($129|0),($$byval_copy5|0),0,16,(608384|0),779);
           $285 = __THREW__; __THREW__ = 0;
           $286 = $285&1;
           if (!($286)) {
            $$0 = $283;$$01 = $284;
            break;
           }
           $297 = ___cxa_find_matching_catch(0|0)|0;
           $298 = tempRet0;
           ___clang_call_terminate($297);
           // unreachable;
          }
          HEAP32[$113>>2] = $129;
          $141 = HEAP32[$width>>2]|0;
          $142 = (($this) + 104|0);
          HEAP32[$142>>2] = $141;
          $143 = HEAP32[$height>>2]|0;
          $144 = (($this) + 108|0);
          HEAP32[$144>>2] = $143;
          $145 = HEAP8[$mipmap>>0]|0;
          $146 = (($this) + 96|0);
          HEAP8[$146>>0] = $145;
          $147 = ($145<<24>>24)!=(0);
          $148 = HEAP32[$format>>2]|0;
          __THREW__ = 0;
          $149 = (invoke_ii(3249,($148|0))|0);
          $150 = __THREW__; __THREW__ = 0;
          $151 = $150&1;
          if ($151) {
           label = 5;
           break;
          }
          $152 = (($141) + -1)|0;
          $153 = (($152) + ($149))|0;
          $154 = (0 - ($149))|0;
          $155 = $153 & $154;
          $format$off$i$i = (($148) + -10)|0;
          $156 = ($format$off$i$i>>>0)<(3);
          $format$off$i5$i = (($148) + -30)|0;
          $157 = ($format$off$i5$i>>>0)<(4);
          $or$cond$i29 = $156 | $157;
          $158 = ($148|0)==(34);
          $or$cond7$i = $or$cond$i29 | $158;
          $format$off$i4$i = (($148) + -35)|0;
          $159 = ($format$off$i4$i>>>0)<(2);
          $or$cond9$i = $or$cond7$i | $159;
          $format$off$i3$i = (($148) + -41)|0;
          $160 = ($format$off$i3$i>>>0)<(4);
          $or$cond11$i = $or$cond9$i | $160;
          $format$off$i2$i = (($148) + -45)|0;
          $161 = ($format$off$i2$i>>>0)<(3);
          $or$cond13$i = $or$cond11$i | $161;
          if ($or$cond13$i) {
           $165 = 1;
          } else {
           $format$off$i1$i = (($148) + -48)|0;
           $162 = ($format$off$i1$i>>>0)<(12);
           $165 = $162;
          }
          $163 = HEAP32[((640792 + 228|0))>>2]|0;
          $164 = ($163|0)<(2);
          $or$cond$i = $165 & $164;
          $or$cond$not$i = $or$cond$i ^ 1;
          $166 = HEAP8[((640792 + 236|0))>>0]|0;
          $167 = ($166<<24>>24)==(0);
          $or$cond3$i = $167 | $or$cond$not$i;
          if ($or$cond3$i) {
           $$0$i = $155;
          } else {
           $168 = (($155) + -1)|0;
           $169 = $168 >>> 16;
           $170 = $169 | $168;
           $171 = $170 >>> 8;
           $172 = $171 | $170;
           $173 = $172 >>> 4;
           $174 = $173 | $172;
           $175 = $174 >>> 2;
           $176 = $175 | $174;
           $177 = $176 >>> 1;
           $178 = $177 | $176;
           $179 = (($178) + 1)|0;
           $$0$i = $179;
          }
          $180 = ($163|0)==(2);
          $181 = ($163|0)>(0);
          $182 = $147 ? $180 : $181;
          if ($182) {
           $$1$i = $$0$i;
          } else {
           $183 = (($$0$i) + -1)|0;
           $184 = $183 >>> 16;
           $185 = $184 | $183;
           $186 = $185 >>> 8;
           $187 = $186 | $185;
           $188 = $187 >>> 4;
           $189 = $188 | $187;
           $190 = $189 >>> 2;
           $191 = $190 | $189;
           $192 = $191 >>> 1;
           $193 = $192 | $191;
           $194 = (($193) + 1)|0;
           $$1$i = $194;
          }
          $195 = (($this) + 112|0);
          HEAP32[$195>>2] = $$1$i;
          $196 = HEAP32[$height>>2]|0;
          $197 = HEAP8[$mipmap>>0]|0;
          $198 = ($197<<24>>24)!=(0);
          $199 = HEAP32[$format>>2]|0;
          __THREW__ = 0;
          $200 = (invoke_ii(3249,($199|0))|0);
          $201 = __THREW__; __THREW__ = 0;
          $202 = $201&1;
          if ($202) {
           label = 5;
           break;
          }
          $203 = (($196) + -1)|0;
          $204 = (($203) + ($200))|0;
          $205 = (0 - ($200))|0;
          $206 = $204 & $205;
          $format$off$i$i37 = (($199) + -10)|0;
          $207 = ($format$off$i$i37>>>0)<(3);
          $format$off$i5$i38 = (($199) + -30)|0;
          $208 = ($format$off$i5$i38>>>0)<(4);
          $or$cond$i39 = $207 | $208;
          $209 = ($199|0)==(34);
          $or$cond7$i40 = $or$cond$i39 | $209;
          $format$off$i4$i41 = (($199) + -35)|0;
          $210 = ($format$off$i4$i41>>>0)<(2);
          $or$cond9$i42 = $or$cond7$i40 | $210;
          $format$off$i3$i43 = (($199) + -41)|0;
          $211 = ($format$off$i3$i43>>>0)<(4);
          $or$cond11$i44 = $or$cond9$i42 | $211;
          $format$off$i2$i45 = (($199) + -45)|0;
          $212 = ($format$off$i2$i45>>>0)<(3);
          $or$cond13$i46 = $or$cond11$i44 | $212;
          if ($or$cond13$i46) {
           $216 = 1;
          } else {
           $format$off$i1$i47 = (($199) + -48)|0;
           $213 = ($format$off$i1$i47>>>0)<(12);
           $216 = $213;
          }
          $214 = HEAP32[((640792 + 228|0))>>2]|0;
          $215 = ($214|0)<(2);
          $or$cond$i30 = $216 & $215;
          $or$cond$not$i31 = $or$cond$i30 ^ 1;
          $217 = HEAP8[((640792 + 236|0))>>0]|0;
          $218 = ($217<<24>>24)==(0);
          $or$cond3$i32 = $218 | $or$cond$not$i31;
          if ($or$cond3$i32) {
           $$0$i33 = $206;
          } else {
           $219 = (($206) + -1)|0;
           $220 = $219 >>> 16;
           $221 = $220 | $219;
           $222 = $221 >>> 8;
           $223 = $222 | $221;
           $224 = $223 >>> 4;
           $225 = $224 | $223;
           $226 = $225 >>> 2;
           $227 = $226 | $225;
           $228 = $227 >>> 1;
           $229 = $228 | $227;
           $230 = (($229) + 1)|0;
           $$0$i33 = $230;
          }
          $231 = ($214|0)==(2);
          $232 = ($214|0)>(0);
          $233 = $198 ? $231 : $232;
          if ($233) {
           $$1$i34 = $$0$i33;
          } else {
           $234 = (($$0$i33) + -1)|0;
           $235 = $234 >>> 16;
           $236 = $235 | $234;
           $237 = $236 >>> 8;
           $238 = $237 | $236;
           $239 = $238 >>> 4;
           $240 = $239 | $238;
           $241 = $240 >>> 2;
           $242 = $241 | $240;
           $243 = $242 >>> 1;
           $244 = $243 | $242;
           $245 = (($244) + 1)|0;
           $$1$i34 = $245;
          }
          $246 = (($this) + 116|0);
          HEAP32[$246>>2] = $$1$i34;
          $247 = HEAP32[$195>>2]|0;
          $248 = (Math_fround(($247|0)));
          $249 = Math_fround(Math_fround(1.0) / $248);
          $250 = (Math_fround(($$1$i34|0)));
          $251 = Math_fround(Math_fround(1.0) / $250);
          $252 = (($this) + 72|0);
          HEAPF32[$252>>2] = $249;
          $253 = (($this) + 76|0);
          HEAPF32[$253>>2] = $251;
          $254 = HEAP32[$this>>2]|0;
          $255 = (($254) + 104|0);
          $256 = HEAP32[$255>>2]|0;
          __THREW__ = 0;
          $257 = (invoke_ii($256|0,($this|0))|0);
          $258 = __THREW__; __THREW__ = 0;
          $259 = $258&1;
          if ($259) {
           label = 5;
           break;
          }
          $260 = (($257) + -1)|0;
          $261 = $260 & $257;
          $262 = ($261|0)==(0);
          if ($262) {
           $264 = HEAP32[$this>>2]|0;
           $265 = (($264) + 108|0);
           $266 = HEAP32[$265>>2]|0;
           __THREW__ = 0;
           $267 = (invoke_ii($266|0,($this|0))|0);
           $268 = __THREW__; __THREW__ = 0;
           $269 = $268&1;
           if ($269) {
            label = 5;
            break;
           }
           $270 = (($267) + -1)|0;
           $271 = $270 & $267;
           $272 = ($271|0)==(0);
           $phitmp$i = $272&1;
           $273 = (($this) + 124|0);
           HEAP8[$273>>0] = $phitmp$i;
           if (!($272)) {
            label = 75;
           }
          } else {
           $263 = (($this) + 124|0);
           HEAP8[$263>>0] = 0;
           label = 75;
          }
          do {
           if ((label|0) == 75) {
            $274 = HEAP32[$this>>2]|0;
            $275 = (($274) + 124|0);
            $276 = HEAP32[$275>>2]|0;
            __THREW__ = 0;
            $277 = (invoke_ii($276|0,($this|0))|0);
            $278 = __THREW__; __THREW__ = 0;
            $279 = $278&1;
            if ($279) {
             label = 5;
             break L5;
            }
            $$not$i = $277 ^ 1;
            $280 = HEAP32[((640792 + 228|0))>>2]|0;
            $281 = ($280|0)==(1);
            $or$cond$i49 = $281 & $$not$i;
            if (!($or$cond$i49)) {
             break;
            }
            $282 = (($this) + 40|0);
            HEAP32[$282>>2] = 1;
           }
          } while(0);
          $287 = HEAP32[$113>>2]|0;
          $288 = ($287|0)==(0|0);
          if ($288) {
           $292 = 0;
          } else {
           $289 = (($287) + 8|0);
           $290 = HEAP32[$289>>2]|0;
           $292 = $290;
          }
          $291 = HEAP32[$imageSizeXImageCount>>2]|0;
          __THREW__ = 0;
          invoke_viiii(358,($transfer|0),($291|0),($292|0),0);
          $293 = __THREW__; __THREW__ = 0;
          $294 = $293&1;
          if ($294) {
           label = 5;
           break;
          }
          HEAP32[$0>>2] = 61;
          ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
          __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $$0 = $13;$$01 = $14;
 }
 HEAP32[$1>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy5|0));
 $295 = __THREW__; __THREW__ = 0;
 $296 = $295&1;
 if ($296) {
  $297 = ___cxa_find_matching_catch(0|0)|0;
  $298 = tempRet0;
  ___clang_call_terminate($297);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN9Texture2D8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$$i = 0, $$0 = 0, $$0$i = 0, $$0$i40 = 0, $$01 = 0, $$1$i = 0, $$1$i41 = 0, $$byval_copy5 = 0, $$not$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i17 = 0, $$pre$i$i$i20 = 0, $$pre$i$i$i24 = 0, $$pre$i$i$i27 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $$pre$i$i$i9 = 0, $$pre61 = 0, $$pre62 = 0;
 var $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i = 0, $exitcond7$i$i = 0, $format = 0, $format$off$i$i = 0, $format$off$i$i44 = 0, $format$off$i1$i = 0, $format$off$i1$i54 = 0, $format$off$i2$i = 0, $format$off$i2$i52 = 0, $format$off$i3$i = 0, $format$off$i3$i50 = 0, $format$off$i4$i = 0, $format$off$i4$i48 = 0, $format$off$i5$i = 0, $format$off$i5$i45 = 0;
 var $height = 0, $i$02$i$i = 0, $i2$05$i$i = 0, $imageCount = 0, $imageSize = 0, $imageSizeXImageCount = 0, $mipmap = 0, $or$cond$i = 0, $or$cond$i36 = 0, $or$cond$i37 = 0, $or$cond$i46 = 0, $or$cond$i56 = 0, $or$cond$not$i = 0, $or$cond$not$i38 = 0, $or$cond11$i = 0, $or$cond11$i51 = 0, $or$cond13$i = 0, $or$cond13$i53 = 0, $or$cond3$i = 0, $or$cond3$i39 = 0;
 var $or$cond7$i = 0, $or$cond7$i47 = 0, $or$cond9$i = 0, $or$cond9$i49 = 0, $p$01$i$i = 0, $p1$04$i$i = 0, $phitmp$i = 0, $width = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp + 40|0;
 $0 = sp + 36|0;
 $1 = sp + 32|0;
 $width = sp + 28|0;
 $height = sp + 24|0;
 $format = sp + 16|0;
 $imageSize = sp + 12|0;
 $imageCount = sp + 8|0;
 $mipmap = sp + 44|0;
 $imageSizeXImageCount = sp + 4|0;
 $2 = sp;
 $3 = sp + 20|0;
 __ZN7Texture8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 __ZN9Texture2D18UnshareTextureDataEv($this);
 HEAP32[$width>>2] = 0;
 HEAP32[$height>>2] = 0;
 HEAP32[$format>>2] = 0;
 HEAP32[$imageSize>>2] = 0;
 HEAP32[$imageCount>>2] = 0;
 HEAP8[$mipmap>>0] = 0;
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($9) {
  __THREW__ = 0;
  invoke_viii(1748,($4|0),($width|0),4);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   label = 5;
  } else {
   $$pre$i$i$i = HEAP32[$width>>2]|0;
   $$pre = HEAP32[$4>>2]|0;
   $$pre61 = HEAP32[$7>>2]|0;
   $15 = $$pre$i$i$i;$18 = $$pre;$20 = $$pre61;
   label = 6;
  }
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$width>>2] = $10;
  HEAP32[$4>>2] = $6;
  $15 = $10;$18 = $6;$20 = $8;
  label = 6;
 }
 L5: do {
  if ((label|0) == 6) {
   $16 = (_llvm_bswap_i32(($15|0))|0);
   HEAP32[$width>>2] = $16;
   $17 = (($18) + 4|0);
   $19 = ($17>>>0)>($20>>>0);
   if ($19) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($height|0),4);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 5;
     break;
    }
    $$pre$i$i$i3 = HEAP32[$height>>2]|0;
    $$pre62 = HEAP32[$4>>2]|0;
    $$pre63 = HEAP32[$7>>2]|0;
    $24 = $$pre$i$i$i3;$27 = $$pre62;$29 = $$pre63;
   } else {
    $21 = HEAP32[$18>>2]|0;
    HEAP32[$height>>2] = $21;
    HEAP32[$4>>2] = $17;
    $24 = $21;$27 = $17;$29 = $20;
   }
   $25 = (_llvm_bswap_i32(($24|0))|0);
   HEAP32[$height>>2] = $25;
   $26 = (($27) + 4|0);
   $28 = ($26>>>0)>($29>>>0);
   if ($28) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($imageSize|0),4);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     label = 5;
     break;
    }
    $$pre$i$i$i6 = HEAP32[$imageSize>>2]|0;
    $$pre64 = HEAP32[$4>>2]|0;
    $$pre65 = HEAP32[$7>>2]|0;
    $33 = $$pre$i$i$i6;$36 = $$pre64;$38 = $$pre65;
   } else {
    $30 = HEAP32[$27>>2]|0;
    HEAP32[$imageSize>>2] = $30;
    HEAP32[$4>>2] = $26;
    $33 = $30;$36 = $26;$38 = $29;
   }
   $34 = (_llvm_bswap_i32(($33|0))|0);
   HEAP32[$imageSize>>2] = $34;
   $35 = (($36) + 4|0);
   $37 = ($35>>>0)>($38>>>0);
   if ($37) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($format|0),4);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 5;
     break;
    }
    $$pre$i$i$i9 = HEAP32[$format>>2]|0;
    $$pre66 = HEAP32[$4>>2]|0;
    $$pre67 = HEAP32[$7>>2]|0;
    $42 = $$pre$i$i$i9;$45 = $$pre66;$47 = $$pre67;
   } else {
    $39 = HEAP32[$36>>2]|0;
    HEAP32[$format>>2] = $39;
    HEAP32[$4>>2] = $35;
    $42 = $39;$45 = $35;$47 = $38;
   }
   $43 = (_llvm_bswap_i32(($42|0))|0);
   HEAP32[$format>>2] = $43;
   $44 = (($45) + 1|0);
   $46 = ($44>>>0)>($47>>>0);
   if ($46) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($mipmap|0),1);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 5;
     break;
    }
    $$pre72 = HEAP32[$4>>2]|0;
    $$pre73 = HEAP32[$7>>2]|0;
    $53 = $$pre72;$55 = $$pre73;
   } else {
    $48 = HEAP8[$45>>0]|0;
    HEAP8[$mipmap>>0] = $48;
    HEAP32[$4>>2] = $44;
    $53 = $44;$55 = $47;
   }
   $51 = (($this) + 127|0);
   $52 = (($53) + 1|0);
   $54 = ($52>>>0)>($55>>>0);
   if ($54) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($51|0),1);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 5;
     break;
    }
    $$pre74 = HEAP32[$4>>2]|0;
    $63 = $$pre74;
   } else {
    $56 = HEAP8[$53>>0]|0;
    HEAP8[$51>>0] = $56;
    $57 = HEAP32[$4>>2]|0;
    $58 = (($57) + 1|0);
    HEAP32[$4>>2] = $58;
    $63 = $58;
   }
   $61 = (($this) + 128|0);
   $62 = (($63) + 1|0);
   $64 = HEAP32[$7>>2]|0;
   $65 = ($62>>>0)>($64>>>0);
   if ($65) {
    __THREW__ = 0;
    invoke_viii(1748,($4|0),($61|0),1);
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     label = 5;
     break;
    }
   } else {
    $66 = HEAP8[$63>>0]|0;
    HEAP8[$61>>0] = $66;
    $67 = HEAP32[$4>>2]|0;
    $68 = (($67) + 1|0);
    HEAP32[$4>>2] = $68;
   }
   __THREW__ = 0;
   invoke_vi(3377,($transfer|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    label = 5;
   } else {
    $73 = HEAP32[$4>>2]|0;
    $74 = (($73) + 4|0);
    $75 = HEAP32[$7>>2]|0;
    $76 = ($74>>>0)>($75>>>0);
    if ($76) {
     __THREW__ = 0;
     invoke_viii(1748,($4|0),($imageCount|0),4);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      label = 5;
      break;
     }
     $$pre$i$i$i17 = HEAP32[$imageCount>>2]|0;
     $$pre68 = HEAP32[$4>>2]|0;
     $$pre69 = HEAP32[$7>>2]|0;
     $80 = $$pre$i$i$i17;$84 = $$pre68;$86 = $$pre69;
    } else {
     $77 = HEAP32[$73>>2]|0;
     HEAP32[$imageCount>>2] = $77;
     HEAP32[$4>>2] = $74;
     $80 = $77;$84 = $74;$86 = $75;
    }
    $81 = (_llvm_bswap_i32(($80|0))|0);
    HEAP32[$imageCount>>2] = $81;
    $82 = (($this) + 100|0);
    $83 = (($84) + 4|0);
    $85 = ($83>>>0)>($86>>>0);
    if ($85) {
     __THREW__ = 0;
     invoke_viii(1748,($4|0),($82|0),4);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      label = 5;
      break;
     }
     $$pre$i$i$i20 = HEAP32[$82>>2]|0;
     $90 = $$pre$i$i$i20;
    } else {
     $87 = HEAP32[$84>>2]|0;
     HEAP32[$82>>2] = $87;
     HEAP32[$4>>2] = $83;
     $90 = $87;
    }
    $91 = (_llvm_bswap_i32(($90|0))|0);
    HEAP32[$82>>2] = $91;
    $92 = (($this) + 28|0);
    __THREW__ = 0;
    invoke_vii(2723,($92|0),($transfer|0));
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     label = 5;
    } else {
     $95 = (($this) + 52|0);
     $96 = HEAP32[$4>>2]|0;
     $97 = (($96) + 4|0);
     $98 = HEAP32[$7>>2]|0;
     $99 = ($97>>>0)>($98>>>0);
     if ($99) {
      __THREW__ = 0;
      invoke_viii(1748,($4|0),($95|0),4);
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       label = 5;
       break;
      }
      $$pre$i$i$i24 = HEAP32[$95>>2]|0;
      $$pre70 = HEAP32[$4>>2]|0;
      $$pre71 = HEAP32[$7>>2]|0;
      $103 = $$pre$i$i$i24;$107 = $$pre70;$109 = $$pre71;
     } else {
      $100 = HEAP32[$96>>2]|0;
      HEAP32[$95>>2] = $100;
      HEAP32[$4>>2] = $97;
      $103 = $100;$107 = $97;$109 = $98;
     }
     $104 = (_llvm_bswap_i32(($103|0))|0);
     HEAP32[$95>>2] = $104;
     $105 = (($this) + 56|0);
     $106 = (($107) + 4|0);
     $108 = ($106>>>0)>($109>>>0);
     if ($108) {
      __THREW__ = 0;
      invoke_viii(1748,($4|0),($105|0),4);
      $111 = __THREW__; __THREW__ = 0;
      $112 = $111&1;
      if ($112) {
       label = 5;
       break;
      }
      $$pre$i$i$i27 = HEAP32[$105>>2]|0;
      $113 = $$pre$i$i$i27;
     } else {
      $110 = HEAP32[$107>>2]|0;
      HEAP32[$105>>2] = $110;
      HEAP32[$4>>2] = $106;
      $113 = $110;
     }
     $114 = (_llvm_bswap_i32(($113|0))|0);
     HEAP32[$105>>2] = $114;
     $115 = HEAP32[$imageCount>>2]|0;
     $116 = HEAP32[$imageSize>>2]|0;
     $117 = Math_imul($116, $115)|0;
     HEAP32[$imageSizeXImageCount>>2] = $117;
     __THREW__ = 0;
     invoke_viiii(359,($transfer|0),($imageSizeXImageCount|0),(608840|0),1);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      label = 5;
     } else {
      __THREW__ = 0;
      invoke_vi(3491,($this|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       label = 5;
      } else {
       __THREW__ = 0;
       $122 = (invoke_ii(3223,($this|0))|0);
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        label = 5;
       } else {
        __THREW__ = 0;
        $125 = (invoke_ii(3223,($this|0))|0);
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if ($127) {
         label = 5;
        } else {
         $128 = ($122|0)==(15);
         $$$i = $128 ? $125 : 13;
         $129 = (($this) + 48|0);
         $130 = HEAP32[$129>>2]|0;
         $131 = ($130|0)==(0|0);
         if (!($131)) {
          $132 = HEAP32[628264>>2]|0;
          $133 = (($130) + 4|0);
          $134 = HEAP32[$133>>2]|0;
          $135 = (($134) + -1)|0;
          HEAP32[$133>>2] = $135;
          $136 = HEAP32[$133>>2]|0;
          $137 = ($136|0)==(0);
          if ($137) {
           $138 = HEAP32[$130>>2]|0;
           $139 = HEAP32[$138>>2]|0;
           __THREW__ = 0;
           invoke_vi($139|0,($130|0));
           $140 = __THREW__; __THREW__ = 0;
           $141 = $140&1;
           if ($141) {
            label = 5;
            break;
           }
           HEAP32[$0>>2] = $132;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($130|0),($$byval_copy5|0));
           $142 = __THREW__; __THREW__ = 0;
           $143 = $142&1;
           if ($143) {
            label = 5;
            break;
           }
          }
          HEAP32[$129>>2] = 0;
         }
         $144 = HEAP32[628264>>2]|0;
         HEAP32[$2>>2] = $144;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
         $145 = (invoke_iiiiiii(103,48,($$byval_copy5|0),0,16,(608384|0),779)|0);
         $146 = __THREW__; __THREW__ = 0;
         $147 = $146&1;
         if ($147) {
          label = 5;
         } else {
          HEAP32[$3>>2] = $$$i;
          $148 = HEAP32[$width>>2]|0;
          $149 = HEAP32[$height>>2]|0;
          $150 = HEAP32[$format>>2]|0;
          $151 = HEAP32[$imageSize>>2]|0;
          $152 = HEAP32[$imageCount>>2]|0;
          $153 = HEAP8[$mipmap>>0]|0;
          $154 = ($153<<24>>24)!=(0);
          __THREW__ = 0;
          ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
          invoke_viiiiiiiii(13,($145|0),($$byval_copy5|0),($148|0),($149|0),($150|0),($151|0),($152|0),($154|0),1);
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           $299 = ___cxa_find_matching_catch()|0;
           $300 = tempRet0;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
           invoke_viiiiii(97,($145|0),($$byval_copy5|0),0,16,(608384|0),779);
           $301 = __THREW__; __THREW__ = 0;
           $302 = $301&1;
           if (!($302)) {
            $$0 = $299;$$01 = $300;
            break;
           }
           $331 = ___cxa_find_matching_catch(0|0)|0;
           $332 = tempRet0;
           ___clang_call_terminate($331);
           // unreachable;
          }
          HEAP32[$129>>2] = $145;
          $157 = HEAP32[$width>>2]|0;
          $158 = (($this) + 104|0);
          HEAP32[$158>>2] = $157;
          $159 = HEAP32[$height>>2]|0;
          $160 = (($this) + 108|0);
          HEAP32[$160>>2] = $159;
          $161 = HEAP8[$mipmap>>0]|0;
          $162 = (($this) + 96|0);
          HEAP8[$162>>0] = $161;
          $163 = ($161<<24>>24)!=(0);
          $164 = HEAP32[$format>>2]|0;
          __THREW__ = 0;
          $165 = (invoke_ii(3249,($164|0))|0);
          $166 = __THREW__; __THREW__ = 0;
          $167 = $166&1;
          if ($167) {
           label = 5;
           break;
          }
          $168 = (($157) + -1)|0;
          $169 = (($168) + ($165))|0;
          $170 = (0 - ($165))|0;
          $171 = $169 & $170;
          $format$off$i$i = (($164) + -10)|0;
          $172 = ($format$off$i$i>>>0)<(3);
          $format$off$i5$i = (($164) + -30)|0;
          $173 = ($format$off$i5$i>>>0)<(4);
          $or$cond$i36 = $172 | $173;
          $174 = ($164|0)==(34);
          $or$cond7$i = $or$cond$i36 | $174;
          $format$off$i4$i = (($164) + -35)|0;
          $175 = ($format$off$i4$i>>>0)<(2);
          $or$cond9$i = $or$cond7$i | $175;
          $format$off$i3$i = (($164) + -41)|0;
          $176 = ($format$off$i3$i>>>0)<(4);
          $or$cond11$i = $or$cond9$i | $176;
          $format$off$i2$i = (($164) + -45)|0;
          $177 = ($format$off$i2$i>>>0)<(3);
          $or$cond13$i = $or$cond11$i | $177;
          if ($or$cond13$i) {
           $181 = 1;
          } else {
           $format$off$i1$i = (($164) + -48)|0;
           $178 = ($format$off$i1$i>>>0)<(12);
           $181 = $178;
          }
          $179 = HEAP32[((640792 + 228|0))>>2]|0;
          $180 = ($179|0)<(2);
          $or$cond$i = $181 & $180;
          $or$cond$not$i = $or$cond$i ^ 1;
          $182 = HEAP8[((640792 + 236|0))>>0]|0;
          $183 = ($182<<24>>24)==(0);
          $or$cond3$i = $183 | $or$cond$not$i;
          if ($or$cond3$i) {
           $$0$i = $171;
          } else {
           $184 = (($171) + -1)|0;
           $185 = $184 >>> 16;
           $186 = $185 | $184;
           $187 = $186 >>> 8;
           $188 = $187 | $186;
           $189 = $188 >>> 4;
           $190 = $189 | $188;
           $191 = $190 >>> 2;
           $192 = $191 | $190;
           $193 = $192 >>> 1;
           $194 = $193 | $192;
           $195 = (($194) + 1)|0;
           $$0$i = $195;
          }
          $196 = ($179|0)==(2);
          $197 = ($179|0)>(0);
          $198 = $163 ? $196 : $197;
          if ($198) {
           $$1$i = $$0$i;
          } else {
           $199 = (($$0$i) + -1)|0;
           $200 = $199 >>> 16;
           $201 = $200 | $199;
           $202 = $201 >>> 8;
           $203 = $202 | $201;
           $204 = $203 >>> 4;
           $205 = $204 | $203;
           $206 = $205 >>> 2;
           $207 = $206 | $205;
           $208 = $207 >>> 1;
           $209 = $208 | $207;
           $210 = (($209) + 1)|0;
           $$1$i = $210;
          }
          $211 = (($this) + 112|0);
          HEAP32[$211>>2] = $$1$i;
          $212 = HEAP32[$height>>2]|0;
          $213 = HEAP8[$mipmap>>0]|0;
          $214 = ($213<<24>>24)!=(0);
          $215 = HEAP32[$format>>2]|0;
          __THREW__ = 0;
          $216 = (invoke_ii(3249,($215|0))|0);
          $217 = __THREW__; __THREW__ = 0;
          $218 = $217&1;
          if ($218) {
           label = 5;
           break;
          }
          $219 = (($212) + -1)|0;
          $220 = (($219) + ($216))|0;
          $221 = (0 - ($216))|0;
          $222 = $220 & $221;
          $format$off$i$i44 = (($215) + -10)|0;
          $223 = ($format$off$i$i44>>>0)<(3);
          $format$off$i5$i45 = (($215) + -30)|0;
          $224 = ($format$off$i5$i45>>>0)<(4);
          $or$cond$i46 = $223 | $224;
          $225 = ($215|0)==(34);
          $or$cond7$i47 = $or$cond$i46 | $225;
          $format$off$i4$i48 = (($215) + -35)|0;
          $226 = ($format$off$i4$i48>>>0)<(2);
          $or$cond9$i49 = $or$cond7$i47 | $226;
          $format$off$i3$i50 = (($215) + -41)|0;
          $227 = ($format$off$i3$i50>>>0)<(4);
          $or$cond11$i51 = $or$cond9$i49 | $227;
          $format$off$i2$i52 = (($215) + -45)|0;
          $228 = ($format$off$i2$i52>>>0)<(3);
          $or$cond13$i53 = $or$cond11$i51 | $228;
          if ($or$cond13$i53) {
           $232 = 1;
          } else {
           $format$off$i1$i54 = (($215) + -48)|0;
           $229 = ($format$off$i1$i54>>>0)<(12);
           $232 = $229;
          }
          $230 = HEAP32[((640792 + 228|0))>>2]|0;
          $231 = ($230|0)<(2);
          $or$cond$i37 = $232 & $231;
          $or$cond$not$i38 = $or$cond$i37 ^ 1;
          $233 = HEAP8[((640792 + 236|0))>>0]|0;
          $234 = ($233<<24>>24)==(0);
          $or$cond3$i39 = $234 | $or$cond$not$i38;
          if ($or$cond3$i39) {
           $$0$i40 = $222;
          } else {
           $235 = (($222) + -1)|0;
           $236 = $235 >>> 16;
           $237 = $236 | $235;
           $238 = $237 >>> 8;
           $239 = $238 | $237;
           $240 = $239 >>> 4;
           $241 = $240 | $239;
           $242 = $241 >>> 2;
           $243 = $242 | $241;
           $244 = $243 >>> 1;
           $245 = $244 | $243;
           $246 = (($245) + 1)|0;
           $$0$i40 = $246;
          }
          $247 = ($230|0)==(2);
          $248 = ($230|0)>(0);
          $249 = $214 ? $247 : $248;
          if ($249) {
           $$1$i41 = $$0$i40;
          } else {
           $250 = (($$0$i40) + -1)|0;
           $251 = $250 >>> 16;
           $252 = $251 | $250;
           $253 = $252 >>> 8;
           $254 = $253 | $252;
           $255 = $254 >>> 4;
           $256 = $255 | $254;
           $257 = $256 >>> 2;
           $258 = $257 | $256;
           $259 = $258 >>> 1;
           $260 = $259 | $258;
           $261 = (($260) + 1)|0;
           $$1$i41 = $261;
          }
          $262 = (($this) + 116|0);
          HEAP32[$262>>2] = $$1$i41;
          $263 = HEAP32[$211>>2]|0;
          $264 = (Math_fround(($263|0)));
          $265 = Math_fround(Math_fround(1.0) / $264);
          $266 = (Math_fround(($$1$i41|0)));
          $267 = Math_fround(Math_fround(1.0) / $266);
          $268 = (($this) + 72|0);
          HEAPF32[$268>>2] = $265;
          $269 = (($this) + 76|0);
          HEAPF32[$269>>2] = $267;
          $270 = HEAP32[$this>>2]|0;
          $271 = (($270) + 104|0);
          $272 = HEAP32[$271>>2]|0;
          __THREW__ = 0;
          $273 = (invoke_ii($272|0,($this|0))|0);
          $274 = __THREW__; __THREW__ = 0;
          $275 = $274&1;
          if ($275) {
           label = 5;
           break;
          }
          $276 = (($273) + -1)|0;
          $277 = $276 & $273;
          $278 = ($277|0)==(0);
          if ($278) {
           $280 = HEAP32[$this>>2]|0;
           $281 = (($280) + 108|0);
           $282 = HEAP32[$281>>2]|0;
           __THREW__ = 0;
           $283 = (invoke_ii($282|0,($this|0))|0);
           $284 = __THREW__; __THREW__ = 0;
           $285 = $284&1;
           if ($285) {
            label = 5;
            break;
           }
           $286 = (($283) + -1)|0;
           $287 = $286 & $283;
           $288 = ($287|0)==(0);
           $phitmp$i = $288&1;
           $289 = (($this) + 124|0);
           HEAP8[$289>>0] = $phitmp$i;
           if (!($288)) {
            label = 77;
           }
          } else {
           $279 = (($this) + 124|0);
           HEAP8[$279>>0] = 0;
           label = 77;
          }
          do {
           if ((label|0) == 77) {
            $290 = HEAP32[$this>>2]|0;
            $291 = (($290) + 124|0);
            $292 = HEAP32[$291>>2]|0;
            __THREW__ = 0;
            $293 = (invoke_ii($292|0,($this|0))|0);
            $294 = __THREW__; __THREW__ = 0;
            $295 = $294&1;
            if ($295) {
             label = 5;
             break L5;
            }
            $$not$i = $293 ^ 1;
            $296 = HEAP32[((640792 + 228|0))>>2]|0;
            $297 = ($296|0)==(1);
            $or$cond$i56 = $297 & $$not$i;
            if (!($or$cond$i56)) {
             break;
            }
            $298 = (($this) + 40|0);
            HEAP32[$298>>2] = 1;
           }
          } while(0);
          $303 = HEAP32[$129>>2]|0;
          $304 = ($303|0)==(0|0);
          if ($304) {
           $308 = 0;
          } else {
           $305 = (($303) + 8|0);
           $306 = HEAP32[$305>>2]|0;
           $308 = $306;
          }
          $307 = HEAP32[$imageSizeXImageCount>>2]|0;
          __THREW__ = 0;
          invoke_viiii(360,($transfer|0),($307|0),($308|0),0);
          $309 = __THREW__; __THREW__ = 0;
          $310 = $309&1;
          if ($310) {
           label = 5;
           break;
          }
          $311 = HEAP32[$format>>2]|0;
          $312 = HEAP32[$imageSizeXImageCount>>2]|0;
          if ((($311|0) == 2) | (($311|0) == 7) | (($311|0) == 13)) {
           $319 = (($312|0) / 2)&-1;
           $320 = ($312|0)>(1);
           if (!($320)) {
            HEAP32[$0>>2] = 61;
            ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
            __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
            STACKTOP = sp;return;
           }
           $i$02$i$i = 0;$p$01$i$i = $308;
           while(1) {
            $321 = (($p$01$i$i) + 2|0);
            $322 = HEAP16[$p$01$i$i>>1]|0;
            $323 = $322&65535;
            $324 = $323 << 8;
            $325 = $323 >>> 8;
            $326 = $324 | $325;
            $327 = $326&65535;
            HEAP16[$p$01$i$i>>1] = $327;
            $328 = (($i$02$i$i) + 1)|0;
            $exitcond$i$i = ($328|0)==($319|0);
            if ($exitcond$i$i) {
             break;
            } else {
             $i$02$i$i = $328;$p$01$i$i = $321;
            }
           }
           HEAP32[$0>>2] = 61;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
           __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
           STACKTOP = sp;return;
          } else if ((($311|0) == 6)) {
           $313 = (($312|0) / 4)&-1;
           $314 = ($312|0)>(3);
           if (!($314)) {
            HEAP32[$0>>2] = 61;
            ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
            __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
            STACKTOP = sp;return;
           }
           $i2$05$i$i = 0;$p1$04$i$i = $308;
           while(1) {
            $315 = (($p1$04$i$i) + 4|0);
            $316 = HEAP32[$p1$04$i$i>>2]|0;
            $317 = (_llvm_bswap_i32(($316|0))|0);
            HEAP32[$p1$04$i$i>>2] = $317;
            $318 = (($i2$05$i$i) + 1)|0;
            $exitcond7$i$i = ($318|0)==($313|0);
            if ($exitcond7$i$i) {
             break;
            } else {
             $i2$05$i$i = $318;$p1$04$i$i = $315;
            }
           }
           HEAP32[$0>>2] = 61;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
           __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
           STACKTOP = sp;return;
          } else {
           HEAP32[$0>>2] = 61;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
           __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy5);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $$0 = $13;$$01 = $14;
 }
 HEAP32[$1>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy5|0));
 $329 = __THREW__; __THREW__ = 0;
 $330 = $329&1;
 if ($330) {
  $331 = ___cxa_find_matching_catch(0|0)|0;
  $332 = tempRet0;
  ___clang_call_terminate($331);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN9Texture2D8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $format = 0, $height = 0, $imageCount = 0, $imageSize = 0, $imageSizeXImageCount = 0, $mipmap = 0, $width = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 28|0;
 $0 = sp + 24|0;
 $width = sp + 20|0;
 $height = sp + 16|0;
 $format = sp + 12|0;
 $imageSize = sp + 4|0;
 $imageCount = sp;
 $mipmap = sp + 32|0;
 $imageSizeXImageCount = sp + 8|0;
 __ZN7Texture8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 __ZN9Texture2D18UnshareTextureDataEv($this);
 HEAP32[$width>>2] = 0;
 HEAP32[$height>>2] = 0;
 HEAP32[$format>>2] = 0;
 HEAP32[$imageSize>>2] = 0;
 HEAP32[$imageCount>>2] = 0;
 HEAP8[$mipmap>>0] = 0;
 $1 = (($this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $26 = 0;
 } else {
  $4 = (($2) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  HEAP32[$width>>2] = $5;
  $6 = (($2) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$height>>2] = $7;
  $8 = (($2) + 32|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$format>>2] = $9;
  $10 = (($2) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$imageSize>>2] = $11;
  $12 = (($2) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$imageCount>>2] = $13;
  $14 = (($2) + 44|0);
  $15 = HEAP8[$14>>0]|0;
  HEAP8[$mipmap>>0] = $15;
  $26 = $5;
 }
 $20 = (($transfer) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 4|0);
 $23 = (($transfer) + 20|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22>>>0)<($24>>>0);
 if ($25) {
  HEAP32[$21>>2] = $26;
  HEAP32[$20>>2] = $22;
  $30 = $22;$32 = $24;
  label = 8;
 } else {
  __THREW__ = 0;
  invoke_viii(1640,($20|0),($width|0),4);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if (!($28)) {
   $$pre = HEAP32[$20>>2]|0;
   $$pre24 = HEAP32[$23>>2]|0;
   $30 = $$pre;$32 = $$pre24;
   label = 8;
  }
 }
 do {
  if ((label|0) == 8) {
   $29 = (($30) + 4|0);
   $31 = ($29>>>0)<($32>>>0);
   if ($31) {
    $33 = HEAP32[$height>>2]|0;
    HEAP32[$30>>2] = $33;
    HEAP32[$20>>2] = $29;
    $37 = $29;$39 = $32;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($20|0),($height|0),4);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $$pre25 = HEAP32[$20>>2]|0;
    $$pre26 = HEAP32[$23>>2]|0;
    $37 = $$pre25;$39 = $$pre26;
   }
   $36 = (($37) + 4|0);
   $38 = ($36>>>0)<($39>>>0);
   if ($38) {
    $40 = HEAP32[$imageSize>>2]|0;
    HEAP32[$37>>2] = $40;
    HEAP32[$20>>2] = $36;
    $44 = $36;$46 = $39;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($20|0),($imageSize|0),4);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $$pre27 = HEAP32[$20>>2]|0;
    $$pre28 = HEAP32[$23>>2]|0;
    $44 = $$pre27;$46 = $$pre28;
   }
   $43 = (($44) + 4|0);
   $45 = ($43>>>0)<($46>>>0);
   if ($45) {
    $47 = HEAP32[$format>>2]|0;
    HEAP32[$44>>2] = $47;
    HEAP32[$20>>2] = $43;
    $51 = $43;$53 = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($20|0),($format|0),4);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    $$pre29 = HEAP32[$20>>2]|0;
    $$pre30 = HEAP32[$23>>2]|0;
    $51 = $$pre29;$53 = $$pre30;
   }
   $50 = (($51) + 1|0);
   $52 = ($50>>>0)<($53>>>0);
   if ($52) {
    $54 = HEAP8[$mipmap>>0]|0;
    HEAP8[$51>>0] = $54;
    $55 = HEAP32[$20>>2]|0;
    $56 = (($55) + 1|0);
    HEAP32[$20>>2] = $56;
    $61 = $56;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($20|0),($mipmap|0),1);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     break;
    }
    $$pre31 = HEAP32[$20>>2]|0;
    $61 = $$pre31;
   }
   $59 = (($this) + 127|0);
   $60 = (($61) + 1|0);
   $62 = HEAP32[$23>>2]|0;
   $63 = ($60>>>0)<($62>>>0);
   if ($63) {
    $64 = HEAP8[$59>>0]|0;
    HEAP8[$61>>0] = $64;
    $65 = HEAP32[$20>>2]|0;
    $66 = (($65) + 1|0);
    HEAP32[$20>>2] = $66;
    $71 = $66;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($20|0),($59|0),1);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     break;
    }
    $$pre32 = HEAP32[$20>>2]|0;
    $71 = $$pre32;
   }
   $69 = (($this) + 128|0);
   $70 = (($71) + 1|0);
   $72 = HEAP32[$23>>2]|0;
   $73 = ($70>>>0)<($72>>>0);
   if ($73) {
    $74 = HEAP8[$69>>0]|0;
    HEAP8[$71>>0] = $74;
    $75 = HEAP32[$20>>2]|0;
    $76 = (($75) + 1|0);
    HEAP32[$20>>2] = $76;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($20|0),($69|0),1);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_vi(3378,($transfer|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if (!($80)) {
    $81 = HEAP32[$20>>2]|0;
    $82 = (($81) + 4|0);
    $83 = HEAP32[$23>>2]|0;
    $84 = ($82>>>0)<($83>>>0);
    if ($84) {
     $85 = HEAP32[$imageCount>>2]|0;
     HEAP32[$81>>2] = $85;
     HEAP32[$20>>2] = $82;
     $90 = $82;$92 = $83;
    } else {
     __THREW__ = 0;
     invoke_viii(1640,($20|0),($imageCount|0),4);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      break;
     }
     $$pre33 = HEAP32[$20>>2]|0;
     $$pre34 = HEAP32[$23>>2]|0;
     $90 = $$pre33;$92 = $$pre34;
    }
    $88 = (($this) + 100|0);
    $89 = (($90) + 4|0);
    $91 = ($89>>>0)<($92>>>0);
    if ($91) {
     $93 = HEAP32[$88>>2]|0;
     HEAP32[$90>>2] = $93;
     HEAP32[$20>>2] = $89;
    } else {
     __THREW__ = 0;
     invoke_viii(1640,($20|0),($88|0),4);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      break;
     }
    }
    $96 = (($this) + 28|0);
    __THREW__ = 0;
    invoke_vii(2724,($96|0),($transfer|0));
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if (!($98)) {
     $99 = (($this) + 52|0);
     $100 = HEAP32[$20>>2]|0;
     $101 = (($100) + 4|0);
     $102 = HEAP32[$23>>2]|0;
     $103 = ($101>>>0)<($102>>>0);
     if ($103) {
      $104 = HEAP32[$99>>2]|0;
      HEAP32[$100>>2] = $104;
      HEAP32[$20>>2] = $101;
      $109 = $101;$111 = $102;
     } else {
      __THREW__ = 0;
      invoke_viii(1640,($20|0),($99|0),4);
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       break;
      }
      $$pre35 = HEAP32[$20>>2]|0;
      $$pre36 = HEAP32[$23>>2]|0;
      $109 = $$pre35;$111 = $$pre36;
     }
     $107 = (($this) + 56|0);
     $108 = (($109) + 4|0);
     $110 = ($108>>>0)<($111>>>0);
     if ($110) {
      $112 = HEAP32[$107>>2]|0;
      HEAP32[$109>>2] = $112;
      HEAP32[$20>>2] = $108;
     } else {
      __THREW__ = 0;
      invoke_viii(1640,($20|0),($107|0),4);
      $113 = __THREW__; __THREW__ = 0;
      $114 = $113&1;
      if ($114) {
       break;
      }
     }
     $115 = HEAP32[$imageCount>>2]|0;
     $116 = HEAP32[$imageSize>>2]|0;
     $117 = Math_imul($116, $115)|0;
     HEAP32[$imageSizeXImageCount>>2] = $117;
     __THREW__ = 0;
     invoke_viiii(361,($transfer|0),($imageSizeXImageCount|0),(608840|0),1);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if (!($119)) {
      $120 = HEAP32[$1>>2]|0;
      $121 = ($120|0)==(0|0);
      if ($121) {
       $125 = 0;
      } else {
       $122 = (($120) + 8|0);
       $123 = HEAP32[$122>>2]|0;
       $125 = $123;
      }
      $124 = HEAP32[$imageSizeXImageCount>>2]|0;
      __THREW__ = 0;
      invoke_viiii(362,($transfer|0),($124|0),($125|0),0);
      $126 = __THREW__; __THREW__ = 0;
      $127 = $126&1;
      if (!($127)) {
       HEAP32[$0>>2] = 61;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy1);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 HEAP32[$0>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy1|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $128 = ___cxa_find_matching_catch(0|0)|0;
  $129 = tempRet0;
  ___clang_call_terminate($128);
  // unreachable;
 } else {
  ___resumeException($16|0);
  // unreachable;
 }
}
function __ZN9Texture2D8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy = 0, $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 __ZN7Texture8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN9Texture2D18UnshareTextureDataEv($this);
 HEAP32[$0>>2] = 61;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZNK9Texture2D11GetPixels32EiP11ColorRGBA32i($this,$miplevel,$colors,$pixelCount) {
 $this = $this|0;
 $miplevel = $miplevel|0;
 $colors = $colors|0;
 $pixelCount = $pixelCount|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy13 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $clipped = 0;
 var $decompressed = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, $resultImage = 0, $resultImage1 = 0, $texImage = 0, $vararg_ptr1 = 0, $vararg_ptr11 = 0, $vararg_ptr12 = 0, $vararg_ptr2 = 0;
 var $vararg_ptr6 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy13 = sp;
 $0 = sp + 128|0;
 $texImage = sp + 108|0;
 $1 = sp + 96|0;
 $2 = sp + 84|0;
 $decompressed = sp + 132|0;
 $clipped = sp + 32|0;
 $resultImage = sp + 12|0;
 $3 = sp + 52|0;
 $resultImage1 = sp + 64|0;
 ;HEAP32[$texImage+0>>2]=0|0;HEAP32[$texImage+4>>2]=0|0;HEAP32[$texImage+8>>2]=0|0;HEAP32[$texImage+12>>2]=0|0;HEAP32[$texImage+16>>2]=0|0;
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__ZN17SharedTextureData17GetImageReferenceEP14ImageReferenceii($5,$texImage,0,$miplevel)|0);
 if ($7) {
  $124 = (($texImage) + 4|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (($texImage) + 8|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = Math_imul($127, $125)|0;
  $129 = ($128|0)>($pixelCount|0);
  if (!($129)) {
   $151 = (__Z29GetRowBytesFromWidthAndFormati13TextureFormat($125,4)|0);
   __ZN14ImageReferenceC2Eiii13TextureFormatPv($resultImage1,$125,$127,$151,4,$colors);
   __ZN14ImageReference9BlitImageERKS_NS_8BlitModeE($resultImage1,$texImage,0);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$$byval_copy13>>2] = $pixelCount;
  $vararg_ptr11 = (($$byval_copy13) + 4|0);
  HEAP32[$vararg_ptr11>>2] = $125;
  $vararg_ptr12 = (($$byval_copy13) + 8|0);
  HEAP32[$vararg_ptr12>>2] = $127;
  __Z6FormatPKcz($3,608896,$$byval_copy13);
  $130 = HEAP8[$3>>0]|0;
  $131 = $130 & 1;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $135 = (($3) + 1|0);
   $136 = $135;
  } else {
   $133 = (($3) + 8|0);
   $134 = HEAP32[$133>>2]|0;
   $136 = $134;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($136|0),0,(608384|0),1197,1,0,0,(0|0));
  $137 = __THREW__; __THREW__ = 0;
  $138 = $137&1;
  if ($138) {
   $144 = ___cxa_find_matching_catch()|0;
   $145 = tempRet0;
   $146 = HEAP8[$3>>0]|0;
   $147 = $146 & 1;
   $148 = ($147<<24>>24)==(0);
   if ($148) {
    $$01 = $144;$$02 = $145;
    ___resumeException($$01|0);
    // unreachable;
   }
   $149 = (($3) + 8|0);
   $150 = HEAP32[$149>>2]|0;
   __ZdlPv($150);
   $$01 = $144;$$02 = $145;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $139 = HEAP8[$3>>0]|0;
   $140 = $139 & 1;
   $141 = ($140<<24>>24)==(0);
   if ($141) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $142 = (($3) + 8|0);
   $143 = HEAP32[$142>>2]|0;
   __ZdlPv($143);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$pr = HEAP32[$4>>2]|0;
 $8 = ($$pr|0)==(0|0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($$pr) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $format$off$i$i = (($10) + -10)|0;
 $11 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($10) + -30)|0;
 $12 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $11 | $12;
 $13 = ($10|0)==(34);
 $or$cond7$i = $or$cond$i | $13;
 $format$off$i4$i = (($10) + -35)|0;
 $14 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $14;
 $format$off$i3$i = (($10) + -41)|0;
 $15 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $15;
 $format$off$i2$i = (($10) + -45)|0;
 $16 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $16;
 $format$off$i1$i = (($10) + -48)|0;
 $17 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $17;
 if (!($or$cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($$pr) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($$pr) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__Z21CalculateMipMapOffsetii13TextureFormati($19,$21,$10,$miplevel)|0);
 $23 = (($$pr) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + ($22)|0);
 $26 = HEAP32[$4>>2]|0;
 $27 = (($26) + 32|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (__Z33GetMinimumTextureMipSizeForFormat13TextureFormat($28)|0);
 $30 = HEAP32[$4>>2]|0;
 $31 = (($30) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 >> $miplevel;
 $34 = ($33|0)<($29|0);
 $35 = $34 ? $29 : $33;
 $36 = (($30) + 28|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 >> $miplevel;
 $39 = ($38|0)<($29|0);
 $40 = $39 ? $29 : $38;
 $41 = (($35|0) % ($29|0))&-1;
 $42 = ($41|0)==(0);
 if ($42) {
  $43 = (($40|0) % ($29|0))&-1;
  $44 = ($43|0)==(0);
  if ($44) {
   $45 = Math_imul($40, $35)|0;
   $46 = ($45|0)>($pixelCount|0);
   if (!($46)) {
    $68 = (($30) + 32|0);
    $69 = HEAP32[$68>>2]|0;
    (__Z41DecompressNativeTextureFormatWithMipLevel13TextureFormatiiiPKjiiPj($69,$35,$40,$miplevel,$25,$35,$40,$colors)|0);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$$byval_copy13>>2] = $pixelCount;
   $vararg_ptr1 = (($$byval_copy13) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $35;
   $vararg_ptr2 = (($$byval_copy13) + 8|0);
   HEAP32[$vararg_ptr2>>2] = $40;
   __Z6FormatPKcz($1,608896,$$byval_copy13);
   $47 = HEAP8[$1>>0]|0;
   $48 = $47 & 1;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    $52 = (($1) + 1|0);
    $53 = $52;
   } else {
    $50 = (($1) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $53 = $51;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($53|0),0,(608384|0),1162,1,0,0,(0|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    $61 = ___cxa_find_matching_catch()|0;
    $62 = tempRet0;
    $63 = HEAP8[$1>>0]|0;
    $64 = $63 & 1;
    $65 = ($64<<24>>24)==(0);
    if ($65) {
     $$01 = $61;$$02 = $62;
     ___resumeException($$01|0);
     // unreachable;
    }
    $66 = (($1) + 8|0);
    $67 = HEAP32[$66>>2]|0;
    __ZdlPv($67);
    $$01 = $61;$$02 = $62;
    ___resumeException($$01|0);
    // unreachable;
   } else {
    $56 = HEAP8[$1>>0]|0;
    $57 = $56 & 1;
    $58 = ($57<<24>>24)==(0);
    if ($58) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $59 = (($1) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    __ZdlPv($60);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $70 = (($29) + -1)|0;
 $71 = (($70) + ($35))|0;
 $72 = (($71|0) % ($29|0))&-1;
 $73 = (($71) - ($72))|0;
 $74 = (($70) + ($40))|0;
 $75 = (($74|0) % ($29|0))&-1;
 $76 = (($74) - ($75))|0;
 $77 = Math_imul($76, $73)|0;
 $78 = ($77|0)>($pixelCount|0);
 if (!($78)) {
  __ZN5ImageC2Eii13TextureFormat($decompressed,$73,$76,4);
  $100 = HEAP32[$4>>2]|0;
  $101 = (($100) + 32|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($decompressed) + 16|0);
  $104 = HEAP32[$103>>2]|0;
  __THREW__ = 0;
  (invoke_iiiiiiiii(39,($102|0),($35|0),($40|0),($miplevel|0),($25|0),($73|0),($76|0),($104|0))|0);
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if (!($106)) {
   __THREW__ = 0;
   invoke_viiiiii(108,($clipped|0),($decompressed|0),0,0,($35|0),($40|0));
   $107 = __THREW__; __THREW__ = 0;
   $108 = $107&1;
   if (!($108)) {
    __THREW__ = 0;
    $109 = (invoke_iii(2404,($35|0),4)|0);
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if (!($111)) {
     __THREW__ = 0;
     invoke_viiiiii(125,($resultImage|0),($35|0),($40|0),($109|0),4,($colors|0));
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if (!($113)) {
      __THREW__ = 0;
      invoke_viii(1729,($resultImage|0),($clipped|0),0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if (!($115)) {
       $116 = HEAP32[$103>>2]|0;
       $117 = HEAP32[628224>>2]|0;
       HEAP32[$0>>2] = $117;
       ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId($116,$$byval_copy13);
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
  $118 = ___cxa_find_matching_catch()|0;
  $119 = tempRet0;
  $120 = HEAP32[$103>>2]|0;
  $121 = HEAP32[628224>>2]|0;
  HEAP32[$0>>2] = $121;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($120|0),($$byval_copy13|0));
  $122 = __THREW__; __THREW__ = 0;
  $123 = $122&1;
  if ($123) {
   $152 = ___cxa_find_matching_catch(0|0)|0;
   $153 = tempRet0;
   ___clang_call_terminate($152);
   // unreachable;
  } else {
   $$01 = $118;$$02 = $119;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 HEAP32[$$byval_copy13>>2] = $pixelCount;
 $vararg_ptr6 = (($$byval_copy13) + 4|0);
 HEAP32[$vararg_ptr6>>2] = $73;
 $vararg_ptr7 = (($$byval_copy13) + 8|0);
 HEAP32[$vararg_ptr7>>2] = $76;
 __Z6FormatPKcz($2,608896,$$byval_copy13);
 $79 = HEAP8[$2>>0]|0;
 $80 = $79 & 1;
 $81 = ($80<<24>>24)==(0);
 if ($81) {
  $84 = (($2) + 1|0);
  $85 = $84;
 } else {
  $82 = (($2) + 8|0);
  $83 = HEAP32[$82>>2]|0;
  $85 = $83;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($85|0),0,(608384|0),1175,1,0,0,(0|0));
 $86 = __THREW__; __THREW__ = 0;
 $87 = $86&1;
 if ($87) {
  $93 = ___cxa_find_matching_catch()|0;
  $94 = tempRet0;
  $95 = HEAP8[$2>>0]|0;
  $96 = $95 & 1;
  $97 = ($96<<24>>24)==(0);
  if ($97) {
   $$01 = $93;$$02 = $94;
   ___resumeException($$01|0);
   // unreachable;
  }
  $98 = (($2) + 8|0);
  $99 = HEAP32[$98>>2]|0;
  __ZdlPv($99);
  $$01 = $93;$$02 = $94;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $88 = HEAP8[$2>>0]|0;
  $89 = $88 & 1;
  $90 = ($89<<24>>24)==(0);
  if ($90) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $91 = (($2) + 8|0);
  $92 = HEAP32[$91>>2]|0;
  __ZdlPv($92);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9Texture2D10ReadPixelsEiiiiiiibb($this,$frame,$left,$bottom,$width,$height,$destX,$destY,$flipped,$computeMipMap) {
 $this = $this|0;
 $frame = $frame|0;
 $left = $left|0;
 $bottom = $bottom|0;
 $width = $width|0;
 $height = $height|0;
 $destX = $destX|0;
 $destY = $destY|0;
 $flipped = $flipped|0;
 $computeMipMap = $computeMipMap|0;
 var $$$0 = 0, $$0 = 0, $$04 = 0, $$08 = 0, $$15 = 0, $$17 = 0, $$19 = 0, $$phi$trans$insert = 0, $$pre = 0, $$width = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0;
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $image = 0, $phitmp = 0, $subImage = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer = sp;
 $0 = sp + 48|0;
 $image = sp + 8|0;
 $subImage = sp + 28|0;
 $1 = $destY | $destX;
 $2 = ($1|0)<(0);
 if (!($2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 104|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 4095]($this)|0);
  $7 = ($6|0)>($destX|0);
  if ($7) {
   $8 = HEAP32[$this>>2]|0;
   $9 = (($8) + 108|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
   $12 = ($11|0)>($destY|0);
   if ($12) {
    $17 = $height | $width;
    $18 = ($17|0)<(0);
    if ($18) {
     $19 = ($this|0)==(0|0);
     if ($19) {
      $22 = 0;
     } else {
      $20 = (($this) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = $21;
     }
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609024,0,608384,1257,1,$22,0,0);
     STACKTOP = sp;return;
    }
    $23 = (__Z12GetGfxDevicev()|0);
    $24 = (($23) + 5784|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = ($25<<24>>24)==(0);
    if ($26) {
     $27 = (__ZN13RenderTexture9GetActiveEv()|0);
     $28 = ($27|0)==(0|0);
     if ($28) {
      $29 = ($this|0)==(0|0);
      if ($29) {
       $32 = 0;
      } else {
       $30 = (($this) + 4|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = $31;
      }
      __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609072,0,608384,1263,1,$32,0,0);
     }
    }
    $33 = ($frame|0)<(0);
    $$phi$trans$insert = (($this) + 48|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    if (!($33)) {
     $34 = ($$pre|0)==(0|0);
     if ($34) {
      $38 = 0;
     } else {
      $35 = (($$pre) + 40|0);
      $36 = HEAP32[$35>>2]|0;
      $38 = $36;
     }
     $37 = ($38|0)>($frame|0);
     if ($37) {
      $68 = (__Z12GetGfxDevicev()|0);
      $69 = (($68) + 5928|0);
      $70 = HEAP32[$69>>2]|0;
      if ((($70|0) == 16) | (($70|0) == 8) | (($70|0) == 11)) {
       $76 = 1;
      } else {
       $76 = 0;
      }
      $71 = HEAP32[$$phi$trans$insert>>2]|0;
      $72 = ($71|0)==(0|0);
      if ($72) {
       ;HEAP32[$image+0>>2]=0|0;HEAP32[$image+4>>2]=0|0;HEAP32[$image+8>>2]=0|0;HEAP32[$image+12>>2]=0|0;HEAP32[$image+16>>2]=0|0;
       $83 = ($this|0)==(0|0);
       if ($83) {
        $86 = 0;
       } else {
        label = 42;
       }
      } else {
       $73 = (($71) + 32|0);
       $74 = HEAP32[$73>>2]|0;
       if (!((($74|0) == 3) | (($74|0) == 5))) {
        $75 = ($74|0)==($76|0);
        if (!($75)) {
         $77 = ($this|0)==(0|0);
         if ($77) {
          $80 = 0;
         } else {
          $78 = (($this) + 4|0);
          $79 = HEAP32[$78>>2]|0;
          $80 = $79;
         }
         __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609400,0,608384,1282,1,$80,0,0);
         STACKTOP = sp;return;
        }
       }
       ;HEAP32[$image+0>>2]=0|0;HEAP32[$image+4>>2]=0|0;HEAP32[$image+8>>2]=0|0;HEAP32[$image+12>>2]=0|0;HEAP32[$image+16>>2]=0|0;
       __ZN9Texture2D18UnshareTextureDataEv($this);
       $81 = HEAP32[$$phi$trans$insert>>2]|0;
       $82 = (__ZN17SharedTextureData17GetImageReferenceEP14ImageReferenceii($81,$image,$frame,0)|0);
       if ($82) {
        $87 = (__ZN13RenderTexture9GetActiveEv()|0);
        $88 = ($87|0)==(0|0);
        if ($88) {
         $89 = (__Z16GetRenderManagerv()|0);
         $90 = (($89) + 56|0);
         $91 = Math_fround(HEAPF32[$90>>2]);
         $92 = (($89) + 60|0);
         $93 = Math_fround(HEAPF32[$92>>2]);
         $94 = (Math_fround(($left|0)));
         $95 = Math_fround($94 + $91);
         $96 = (~~(($95)));
         $97 = (Math_fround(($bottom|0)));
         $98 = Math_fround($97 + $93);
         $99 = (~~(($98)));
         $$0 = $96;$$04 = $99;
        } else {
         $$0 = $left;$$04 = $bottom;
        }
        $100 = ($$0|0)<(0);
        $101 = $100 ? $$0 : 0;
        $$width = (($101) + ($width))|0;
        $$$0 = $100 ? 0 : $$0;
        $102 = ($$04|0)<(0);
        $103 = $102 ? $$04 : 0;
        $$08 = (($103) + ($height))|0;
        $$15 = $102 ? 0 : $$04;
        $104 = (($$width) + ($destX))|0;
        $105 = HEAP32[$this>>2]|0;
        $106 = (($105) + 104|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = (FUNCTION_TABLE_ii[$107 & 4095]($this)|0);
        $109 = ($104|0)>($108|0);
        if ($109) {
         $110 = HEAP32[$this>>2]|0;
         $111 = (($110) + 104|0);
         $112 = HEAP32[$111>>2]|0;
         $113 = (FUNCTION_TABLE_ii[$112 & 4095]($this)|0);
         $114 = (($113) - ($destX))|0;
         $$17 = $114;
        } else {
         $$17 = $$width;
        }
        $115 = (($$08) + ($destY))|0;
        $116 = HEAP32[$this>>2]|0;
        $117 = (($116) + 108|0);
        $118 = HEAP32[$117>>2]|0;
        $119 = (FUNCTION_TABLE_ii[$118 & 4095]($this)|0);
        $120 = ($115|0)>($119|0);
        if ($120) {
         $121 = HEAP32[$this>>2]|0;
         $122 = (($121) + 108|0);
         $123 = HEAP32[$122>>2]|0;
         $124 = (FUNCTION_TABLE_ii[$123 & 4095]($this)|0);
         $125 = (($124) - ($destY))|0;
         $$19 = $125;
        } else {
         $$19 = $$08;
        }
        $126 = (__Z12GetGfxDevicev()|0);
        $127 = HEAP32[$126>>2]|0;
        $128 = (($127) + 600|0);
        $129 = HEAP32[$128>>2]|0;
        (FUNCTION_TABLE_iiiiiiiii[$129 & 63]($126,$image,$$$0,$$15,$$17,$$19,$destX,$destY)|0);
        if ($flipped) {
         __ZNK14ImageReference9ClipImageEiiii($subImage,$image,$destX,$destY,$$17,$$19);
         __ZN14ImageReference10FlipImageYEv($subImage);
        }
        if (!($computeMipMap)) {
         STACKTOP = sp;return;
        }
        $130 = HEAP32[$this>>2]|0;
        $131 = (($130) + 124|0);
        $132 = HEAP32[$131>>2]|0;
        $133 = (FUNCTION_TABLE_ii[$132 & 4095]($this)|0);
        if (!($133)) {
         STACKTOP = sp;return;
        }
        $134 = HEAP32[$this>>2]|0;
        $135 = (($134) + 160|0);
        $136 = HEAP32[$135>>2]|0;
        FUNCTION_TABLE_vi[$136 & 4095]($this);
        STACKTOP = sp;return;
       } else {
        label = 42;
       }
      }
      if ((label|0) == 42) {
       $84 = (($this) + 4|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = $85;
      }
      __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(608856,0,608384,1289,1,$86,0,0);
      STACKTOP = sp;return;
     }
    }
    $39 = ($$pre|0)==(0|0);
    if ($39) {
     $42 = -1;
    } else {
     $40 = (($$pre) + 40|0);
     $41 = HEAP32[$40>>2]|0;
     $phitmp = (($41) + -1)|0;
     $42 = $phitmp;
    }
    HEAP32[$vararg_buffer>>2] = $frame;
    $vararg_ptr1 = (($vararg_buffer) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $42;
    __Z6FormatPKcz($0,609168,$vararg_buffer);
    $43 = ($this|0)==(0|0);
    if ($43) {
     $53 = 0;
    } else {
     $44 = (($this) + 4|0);
     $45 = HEAP32[$44>>2]|0;
     $53 = $45;
    }
    $46 = HEAP8[$0>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if ($48) {
     $51 = (($0) + 1|0);
     $52 = $51;
    } else {
     $49 = (($0) + 8|0);
     $50 = HEAP32[$49>>2]|0;
     $52 = $50;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($52|0),0,(608384|0),1269,1,($53|0),0,(0|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     $61 = ___cxa_find_matching_catch()|0;
     $62 = tempRet0;
     $63 = HEAP8[$0>>0]|0;
     $64 = $63 & 1;
     $65 = ($64<<24>>24)==(0);
     if ($65) {
      ___resumeException($61|0);
      // unreachable;
     }
     $66 = (($0) + 8|0);
     $67 = HEAP32[$66>>2]|0;
     __ZdlPv($67);
     ___resumeException($61|0);
     // unreachable;
    } else {
     $56 = HEAP8[$0>>0]|0;
     $57 = $56 & 1;
     $58 = ($57<<24>>24)==(0);
     if ($58) {
      STACKTOP = sp;return;
     }
     $59 = (($0) + 8|0);
     $60 = HEAP32[$59>>2]|0;
     __ZdlPv($60);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $13 = ($this|0)==(0|0);
 if ($13) {
  $16 = 0;
 } else {
  $14 = (($this) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(608984,0,608384,1252,1,$16,0,0);
 STACKTOP = sp;return;
}
function __ZN9Texture2D16ResizeWithFormatEii13TextureFormati($this,$width,$height,$format,$flags) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $flags = $flags|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0;
 var $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 127|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609240,0,608384,1368,1,$4,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $format$off$i$i = (($format) + -10)|0;
 $5 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($format) + -30)|0;
 $6 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $5 | $6;
 $7 = ($format|0)==(34);
 $or$cond7$i = $or$cond$i | $7;
 $format$off$i4$i = (($format) + -35)|0;
 $8 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $8;
 $format$off$i3$i = (($format) + -41)|0;
 $9 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $9;
 $format$off$i2$i = (($format) + -45)|0;
 $10 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $10;
 $format$off$i1$i = (($format) + -48)|0;
 $11 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $11;
 if ($or$cond) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609272,0,608384,1374,1,$13,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $14 = HEAP32[$this>>2]|0;
  $15 = (($14) + 148|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_iiiiiiii[$16 & 127]($this,$width,$height,$format,$flags,1,0)|0);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9Texture3DC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN7TextureC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((609488 + 8|0));
 $2 = (($this) + 100|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 104|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 108|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 112|0);
 HEAP32[$5>>2] = 5;
 $6 = (($this) + 116|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP16[$6+8>>1]=0|0;
 STACKTOP = sp;return;
}
function __ZN9Texture3D17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 125|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  __ZN7Texture17MainThreadCleanupEv($this);
  STACKTOP = sp;return;
 }
 $4 = (__Z12GetGfxDevicev()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 488|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $9;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($4,$$byval_copy);
 HEAP8[$1>>0] = 0;
 __ZN7Texture17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN9Texture3D13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $awakeMode & -5;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($this) + 116|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   STACKTOP = sp;return;
  }
 }
 __ZN9Texture3D13UploadTextureEb($this,0);
 STACKTOP = sp;return;
}
function __ZN9Texture3D13UploadTextureEb($this,$dontUseSubImage) {
 $this = $this|0;
 $dontUseSubImage = $dontUseSubImage|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = HEAP8[((640792 + 225|0))>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__Z19GetBuildSettingsPtrv()|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($5) + 93|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
 }
 $$pre = (($this) + 125|0);
 if ($dontUseSubImage) {
  $34 = 2;
 } else {
  $10 = HEAP8[$$pre>>0]|0;
  $11 = ($10<<24>>24)==(0);
  $phitmp = $11 ? 2 : 0;
  $34 = $phitmp;
 }
 $12 = (__Z12GetGfxDevicev()|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 484|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$1>>2] = $17;
 $18 = (($this) + 116|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 120|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 100|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 104|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 108|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($this) + 112|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$this>>2]|0;
 $31 = (($30) + 128|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (FUNCTION_TABLE_ii[$32 & 4095]($this)|0);
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_viiiiiiiiii[$15 & 15]($12,$$byval_copy1,$19,$21,$23,$25,$27,$29,$33,$34);
 $35 = HEAP32[$16>>2]|0;
 $36 = $this;
 $37 = $0;
 $38 = $37;
 HEAP32[$38>>2] = $35;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 __ZNSt3__16__treeINS_12__value_typeI9TextureIDP7TextureEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($$byval_copy1,607992,$0);
 $41 = HEAP32[$this>>2]|0;
 $42 = (($41) + 132|0);
 $43 = HEAP32[$42>>2]|0;
 FUNCTION_TABLE_vi[$43 & 4095]($this);
 $44 = (__Z12GetGfxDevicev()|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 648|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$16>>2]|0;
 HEAP32[$2>>2] = $48;
 $49 = HEAP32[$this>>2]|0;
 $50 = (($49) + 32|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (FUNCTION_TABLE_ii[$51 & 4095]($this)|0);
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 FUNCTION_TABLE_viii[$47 & 4095]($44,$$byval_copy1,$52);
 HEAP8[$$pre>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9Texture3D5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Texture5ResetEv($this);
 $0 = (($this) + 28|0);
 __ZN15TextureSettings5ResetEv($0);
 STACKTOP = sp;return;
}
function __ZN9Texture3D11InitTextureEiii13TextureFormatb($this,$width,$height,$depth,$format,$mipMaps) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $depth = $depth|0;
 $format = $format|0;
 $mipMaps = $mipMaps|0;
 var $$0 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0;
 var $8 = 0, $80 = 0, $9 = 0, $exitcond$i = 0, $imageSize$0$lcssa$i = 0, $imageSize$02$i = 0, $mip$01$i = 0, $or$cond = 0, $or$cond6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($width) + -1)|0;
 $3 = $2 & $width;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($height) + -1)|0;
  $6 = $5 & $height;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($depth) + -1)|0;
   $9 = $8 & $depth;
   $10 = ($9|0)==(0);
   if ($10) {
    $15 = ($format|0)>(9);
    if (!($15)) {
     $16 = (__Z20IsValidTextureFormat13TextureFormat($format)|0);
     if ($16) {
      $21 = ($width>>>0)>(1024);
      $22 = ($height>>>0)>(1024);
      $or$cond = $21 | $22;
      $23 = ($depth>>>0)>(1024);
      $or$cond6 = $or$cond | $23;
      if ($or$cond6) {
       $24 = ($this|0)==(0|0);
       if ($24) {
        $27 = 0;
       } else {
        $25 = (($this) + 4|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = $26;
       }
       __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609728,0,609680,82,1,$27,0,0);
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      $28 = (($this) + 100|0);
      HEAP32[$28>>2] = $width;
      $29 = (($this) + 104|0);
      HEAP32[$29>>2] = $height;
      $30 = (($this) + 108|0);
      HEAP32[$30>>2] = $depth;
      $31 = (($this) + 112|0);
      HEAP32[$31>>2] = $format;
      $32 = (($this) + 124|0);
      $33 = $mipMaps&1;
      HEAP8[$32>>0] = $33;
      $34 = HEAP32[$this>>2]|0;
      $35 = (($34) + 128|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (FUNCTION_TABLE_ii[$36 & 4095]($this)|0);
      $38 = (__Z25GetBytesFromTextureFormat13TextureFormat($format)|0);
      $39 = ($37|0)>(0);
      if ($39) {
       $imageSize$02$i = 0;$mip$01$i = 0;
       while(1) {
        $40 = $width >> $mip$01$i;
        $41 = ($40|0)<(1);
        $42 = $41 ? 1 : $40;
        $43 = $height >> $mip$01$i;
        $44 = ($43|0)<(1);
        $45 = $44 ? 1 : $43;
        $46 = $depth >> $mip$01$i;
        $47 = ($46|0)<(1);
        $48 = $47 ? 1 : $46;
        $49 = Math_imul($42, $38)|0;
        $50 = Math_imul($49, $45)|0;
        $51 = Math_imul($50, $48)|0;
        $52 = (($51) + ($imageSize$02$i))|0;
        $53 = (($mip$01$i) + 1)|0;
        $exitcond$i = ($53|0)==($37|0);
        if ($exitcond$i) {
         $imageSize$0$lcssa$i = $52;
         break;
        } else {
         $imageSize$02$i = $52;$mip$01$i = $53;
        }
       }
      } else {
       $imageSize$0$lcssa$i = 0;
      }
      $54 = HEAP32[$31>>2]|0;
      $55 = (__Z25GetBytesFromTextureFormat13TextureFormat($54)|0);
      $56 = (($55) + ($imageSize$0$lcssa$i))|0;
      $57 = HEAP32[628264>>2]|0;
      HEAP32[$0>>2] = $57;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
      $58 = (__Z15malloc_internaljj10MemLabelIdiPKci($56,32,$$byval_copy2,0,609680,115)|0);
      $59 = ($58|0)==(0|0);
      if ($59) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      _memset(($58|0),-51,($56|0))|0;
      $60 = (($this) + 116|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = HEAP32[628264>>2]|0;
      HEAP32[$1>>2] = $62;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($61,$$byval_copy2);
      HEAP32[$60>>2] = 0;
      $63 = (($this) + 120|0);
      HEAP32[$63>>2] = 0;
      $64 = (($this) + 125|0);
      $65 = HEAP8[$64>>0]|0;
      $66 = ($65<<24>>24)==(0);
      if (!($66)) {
       $67 = (__Z12GetGfxDevicev()|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = (($68) + 488|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = (($this) + 44|0);
       $72 = HEAP32[$71>>2]|0;
       HEAP32[$0>>2] = $72;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       FUNCTION_TABLE_vii[$70 & 4095]($67,$$byval_copy2);
       HEAP8[$64>>0] = 0;
      }
      HEAP32[$60>>2] = $58;
      HEAP32[$63>>2] = $imageSize$0$lcssa$i;
      $73 = HEAP32[$28>>2]|0;
      $74 = (Math_fround(($73|0)));
      $75 = Math_fround(Math_fround(1.0) / $74);
      $76 = HEAP32[$29>>2]|0;
      $77 = (Math_fround(($76|0)));
      $78 = Math_fround(Math_fround(1.0) / $77);
      $79 = (($this) + 72|0);
      HEAPF32[$79>>2] = $75;
      $80 = (($this) + 76|0);
      HEAPF32[$80>>2] = $78;
      $$0 = 1;
      STACKTOP = sp;return ($$0|0);
     }
    }
    $17 = ($this|0)==(0|0);
    if ($17) {
     $20 = 0;
    } else {
     $18 = (($this) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = $19;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609688,0,609680,75,1,$20,0,0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = ($this|0)==(0|0);
 if ($11) {
  $14 = 0;
 } else {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609640,0,609680,70,1,$14,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Texture3D15UpdateImageDataEb($this,$rebuildMipMaps) {
 $this = $this|0;
 $rebuildMipMaps = $rebuildMipMaps|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 if ($rebuildMipMaps) {
  __ZN9Texture3D13RebuildMipMapEv($this);
 }
 __ZN9Texture3D13UploadTextureEb($this,0);
 STACKTOP = sp;return;
}
function __ZN9Texture3D13RebuildMipMapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0, $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 112|0);
 $7 = HEAP32[$6>>2]|0;
 $format$off$i$i = (($7) + -10)|0;
 $8 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($7) + -30)|0;
 $9 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $8 | $9;
 $10 = ($7|0)==(34);
 $or$cond7$i = $or$cond$i | $10;
 $format$off$i4$i = (($7) + -35)|0;
 $11 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $11;
 $format$off$i3$i = (($7) + -41)|0;
 $12 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $12;
 $format$off$i2$i = (($7) + -45)|0;
 $13 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $13;
 $format$off$i1$i = (($7) + -48)|0;
 $14 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $14;
 if (!($or$cond)) {
  $19 = (($this) + 100|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($this) + 104|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($this) + 108|0);
  $24 = HEAP32[$23>>2]|0;
  __Z12CreateMipMapPhiii13TextureFormat($4,$20,$22,$24,$7);
  STACKTOP = sp;return;
 }
 $15 = ($this|0)==(0|0);
 if ($15) {
  $18 = 0;
 } else {
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(609784,0,609680,181,1,$18,0,0);
 STACKTOP = sp;return;
}
function __ZNK9Texture3D12ExtractImageEP14ImageReferencei($this,$image,$imageIndex) {
 $this = $this|0;
 $image = $image|0;
 $imageIndex = $imageIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $source = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $source = sp;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 104|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 112|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__Z25GetBytesFromTextureFormat13TextureFormat($8)|0);
 $10 = Math_imul($9, $4)|0;
 $11 = HEAP32[$7>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 __ZN14ImageReferenceC2Eiii13TextureFormatPv($source,$4,$6,$10,$11,$12);
 __ZN14ImageReference9BlitImageERKS_NS_8BlitModeE($image,$source,2);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK9Texture3D12CountMipmapsEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 104|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 108|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__Z22CalculateMipMapCount3Diii($4,$6,$8)|0);
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Texture3D19UnloadFromGfxDeviceEb($this,$forceUnloadAll) {
 $this = $this|0;
 $forceUnloadAll = $forceUnloadAll|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 125|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__Z12GetGfxDevicev()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 488|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $9;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($4,$$byval_copy);
 HEAP8[$1>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9Texture3D17UploadToGfxDeviceEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture3D13UploadTextureEb($this,1);
 STACKTOP = sp;return;
}
function __Z23RegisterClass_Texture3Dv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(117,138,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9Texture3D13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(27)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN7Texture13RegisterClassEv();
 }
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=609848+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,117,27,($0|0),128,(2405|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN9Texture3D7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(128,$$byval_copy2,1,16,609680,9)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1749,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((609488 + 8|0));
  $6 = (($3) + 100|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 104|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 108|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 112|0);
  HEAP32[$9>>2] = 5;
  $10 = (($3) + 116|0);
  ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP16[$10+8>>1]=0|0;
  STACKTOP = sp;return ($3|0);
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(609680|0),9);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK9Texture3D25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 117;
}
function __ZN9Texture3D23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,609864,609848,$this,0);
 __ZN9Texture3D8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture3D23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,609864,609848,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9Texture3D8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture3D23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture3D8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture3D23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture3D8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture3D23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Texture3D8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture3D23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Texture8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Texture3DD1Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((609488 + 8|0));
 $2 = (($this) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[628264>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($3|0),($$byval_copy1|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[$2>>2] = 0;
  $7 = (($this) + 120|0);
  HEAP32[$7>>2] = 0;
  $8 = (($this) + 125|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if ($10) {
   __ZN7TextureD2Ev($this);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  $11 = (invoke_i(59)|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[$11>>2]|0;
   $15 = (($14) + 488|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($this) + 44|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$0>>2] = $18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii($16|0,($11|0),($$byval_copy1|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    HEAP8[$8>>0] = 0;
    __ZN7TextureD2Ev($this);
    STACKTOP = sp;return;
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3488,($this|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($21|0);
  // unreachable;
 }
}
function __ZN9Texture3DD0Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$01$i = 0, $$01$i6 = 0, $$byval_copy17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body10$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy17 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 HEAP32[$this>>2] = ((609488 + 8|0));
 $4 = (($this) + 116|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[628264>>2]|0;
 HEAP32[$3>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($5|0),($$byval_copy17|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   HEAP32[$4>>2] = 0;
   $9 = (($this) + 120|0);
   HEAP32[$9>>2] = 0;
   $10 = (($this) + 125|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)==(0);
   if (!($12)) {
    __THREW__ = 0;
    $13 = (invoke_i(59)|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[$13>>2]|0;
    $17 = (($16) + 488|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($this) + 44|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$2>>2] = $20;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii($18|0,($13|0),($$byval_copy17|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    HEAP8[$10>>0] = 0;
   }
   HEAP32[$this>>2] = ((608008 + 8|0));
   __THREW__ = 0;
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   L8: do {
    if ($58) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     $72 = (($this) + 92|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ($73|0)>(-1);
     if ($74) {
      $75 = (($this) + 80|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = (($this) + 84|0);
      $78 = HEAP32[$77>>2]|0;
      HEAP32[$0>>2] = $78;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($76|0),($$byval_copy17|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       $85 = ___cxa_find_matching_catch(0|0)|0;
       $86 = tempRet0;
       ___clang_call_terminate($85);
       // unreachable;
      } else {
       HEAP32[$75>>2] = 0;
       $$0$i = $71;$$01$i = $70;
       break;
      }
     } else {
      $$0$i = $71;$$01$i = $70;
     }
    } else {
     $59 = (($this) + 92|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)>(-1);
     do {
      if ($61) {
       $62 = (($this) + 80|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = (($this) + 84|0);
       $65 = HEAP32[$64>>2]|0;
       HEAP32[$1>>2] = $65;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($63|0),($$byval_copy17|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        $81 = ___cxa_find_matching_catch()|0;
        $82 = tempRet0;
        $$0$i = $82;$$01$i = $81;
        break L8;
       } else {
        HEAP32[$62>>2] = 0;
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3423,($this|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if (!($69)) {
      __ZdlPv($this);
      STACKTOP = sp;return;
     }
     $87 = ___cxa_find_matching_catch()|0;
     $88 = tempRet0;
     $eh$lpad$body$index8Z2D = $88;$eh$lpad$body$indexZ2D = $87;
     __ZdlPv($this);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $85 = ___cxa_find_matching_catch(0|0)|0;
    $86 = tempRet0;
    ___clang_call_terminate($85);
    // unreachable;
   }
   $eh$lpad$body$index8Z2D = $$0$i;$eh$lpad$body$indexZ2D = $$01$i;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 HEAP32[$this>>2] = ((608008 + 8|0));
 __THREW__ = 0;
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 L31: do {
  if ($26) {
   $38 = ___cxa_find_matching_catch(0|0)|0;
   $39 = tempRet0;
   $40 = (($this) + 92|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)>(-1);
   if ($42) {
    $43 = (($this) + 80|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($this) + 84|0);
    $46 = HEAP32[$45>>2]|0;
    HEAP32[$0>>2] = $46;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($44|0),($$byval_copy17|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     $53 = ___cxa_find_matching_catch(0|0)|0;
     $54 = tempRet0;
     ___clang_call_terminate($53);
     // unreachable;
    } else {
     HEAP32[$43>>2] = 0;
     $$01$i6 = $38;
     break;
    }
   } else {
    $$01$i6 = $38;
   }
  } else {
   $27 = (($this) + 92|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)>(-1);
   do {
    if ($29) {
     $30 = (($this) + 80|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($this) + 84|0);
     $33 = HEAP32[$32>>2]|0;
     HEAP32[$1>>2] = $33;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($31|0),($$byval_copy17|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      $49 = ___cxa_find_matching_catch(0|0)|0;
      $50 = tempRet0;
      $$01$i6 = $49;
      break L31;
     } else {
      HEAP32[$30>>2] = 0;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if (!($37)) {
    $eh$lpad$body$index8Z2D = $24;$eh$lpad$body$indexZ2D = $23;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $55 = ___cxa_find_matching_catch(0|0)|0;
   $56 = tempRet0;
   $eh$lpad$body10$indexZ2D = $55;
   ___clang_call_terminate($eh$lpad$body10$indexZ2D);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch(0|0)|0;
  $54 = tempRet0;
  ___clang_call_terminate($53);
  // unreachable;
 }
 $eh$lpad$body10$indexZ2D = $$01$i6;
 ___clang_call_terminate($eh$lpad$body10$indexZ2D);
 // unreachable;
}
function __ZNK9Texture3D20GetRuntimeMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK9Texture3D12GetDimensionEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 3;
}
function __ZNK9Texture3D12GetDataWidthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK9Texture3D13GetDataHeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK9Texture3D9HasMipMapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN9Texture3D8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dataSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dataSize = sp;
 __ZN7Texture8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 100|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre4 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre4;
 }
 $8 = (($this) + 104|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = HEAP32[$8>>2]|0;
  HEAP32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$4>>2]|0;
  $16 = $$pre5;$18 = $$pre6;
 }
 $14 = (($this) + 108|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = HEAP32[$14>>2]|0;
  HEAP32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre7 = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $22 = $$pre7;$24 = $$pre8;
 }
 $20 = (($this) + 112|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = HEAP32[$20>>2]|0;
  HEAP32[$22>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,4);
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $28 = $$pre9;$30 = $$pre10;
 }
 $26 = (($this) + 124|0);
 $27 = (($28) + 1|0);
 $29 = ($27>>>0)<($30>>>0);
 if ($29) {
  $31 = HEAP8[$26>>0]|0;
  HEAP8[$28>>0] = $31;
  $32 = HEAP32[$1>>2]|0;
  $33 = (($32) + 1|0);
  HEAP32[$1>>2] = $33;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $34 = (($this) + 120|0);
 $35 = HEAP32[$1>>2]|0;
 $36 = (($35) + 4|0);
 $37 = HEAP32[$4>>2]|0;
 $38 = ($36>>>0)<($37>>>0);
 if ($38) {
  $39 = HEAP32[$34>>2]|0;
  HEAP32[$35>>2] = $39;
  HEAP32[$1>>2] = $36;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$34,4);
 }
 $40 = (($this) + 28|0);
 __ZN15TextureSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($40,$transfer);
 $41 = HEAP32[$34>>2]|0;
 HEAP32[$dataSize>>2] = $41;
 __ZN19StreamedBinaryWriteILb0EE16TransferTypelessEPjPKc17TransferMetaFlags($transfer,$dataSize,609976,1);
 $42 = HEAP32[$dataSize>>2]|0;
 $43 = (($this) + 116|0);
 $44 = HEAP32[$43>>2]|0;
 __ZN19StreamedBinaryWriteILb0EE20TransferTypelessDataEjPvi($transfer,$42,$44,0);
 STACKTOP = sp;return;
}
function __ZN9Texture3D8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre$i$i$i7 = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $dataSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $dataSize = sp + 8|0;
 __ZN7Texture8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $2 = (($this) + 100|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre8 = HEAP32[$6>>2]|0;
  $10 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;$14 = $5;$16 = $7;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$2>>2] = $11;
 $12 = (($this) + 104|0);
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$12,4);
  $$pre$i$i$i1 = HEAP32[$12>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $$pre10 = HEAP32[$6>>2]|0;
  $18 = $$pre$i$i$i1;$22 = $$pre9;$24 = $$pre10;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$3>>2] = $13;
  $18 = $17;$22 = $13;$24 = $16;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$12>>2] = $19;
 $20 = (($this) + 108|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$20,4);
  $$pre$i$i$i3 = HEAP32[$20>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $$pre12 = HEAP32[$6>>2]|0;
  $26 = $$pre$i$i$i3;$30 = $$pre11;$32 = $$pre12;
 } else {
  $25 = HEAP32[$22>>2]|0;
  HEAP32[$20>>2] = $25;
  HEAP32[$3>>2] = $21;
  $26 = $25;$30 = $21;$32 = $24;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$20>>2] = $27;
 $28 = (($this) + 112|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$28,4);
  $$pre$i$i$i5 = HEAP32[$28>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $$pre14 = HEAP32[$6>>2]|0;
  $34 = $$pre$i$i$i5;$38 = $$pre13;$40 = $$pre14;
 } else {
  $33 = HEAP32[$30>>2]|0;
  HEAP32[$28>>2] = $33;
  HEAP32[$3>>2] = $29;
  $34 = $33;$38 = $29;$40 = $32;
 }
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$28>>2] = $35;
 $36 = (($this) + 124|0);
 $37 = (($38) + 1|0);
 $39 = ($37>>>0)>($40>>>0);
 if ($39) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$36,1);
 } else {
  $41 = HEAP8[$38>>0]|0;
  HEAP8[$36>>0] = $41;
  $42 = HEAP32[$3>>2]|0;
  $43 = (($42) + 1|0);
  HEAP32[$3>>2] = $43;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $44 = (($this) + 120|0);
 $45 = HEAP32[$3>>2]|0;
 $46 = (($45) + 4|0);
 $47 = HEAP32[$6>>2]|0;
 $48 = ($46>>>0)>($47>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$44,4);
  $$pre$i$i$i7 = HEAP32[$44>>2]|0;
  $50 = $$pre$i$i$i7;
 } else {
  $49 = HEAP32[$45>>2]|0;
  HEAP32[$44>>2] = $49;
  HEAP32[$3>>2] = $46;
  $50 = $49;
 }
 $51 = (_llvm_bswap_i32(($50|0))|0);
 HEAP32[$44>>2] = $51;
 $52 = (($this) + 28|0);
 __ZN15TextureSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($52,$transfer);
 $53 = HEAP32[$44>>2]|0;
 HEAP32[$dataSize>>2] = $53;
 __ZN18StreamedBinaryReadILb1EE16TransferTypelessEPjPKc17TransferMetaFlags($transfer,$dataSize,609976,1);
 $54 = (($this) + 116|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[628264>>2]|0;
 HEAP32[$1>>2] = $56;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($55,$$byval_copy2);
 HEAP32[$54>>2] = 0;
 HEAP32[$44>>2] = 0;
 $57 = (($this) + 125|0);
 $58 = HEAP8[$57>>0]|0;
 $59 = ($58<<24>>24)==(0);
 if (!($59)) {
  $60 = (__Z12GetGfxDevicev()|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 488|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($this) + 44|0);
  $65 = HEAP32[$64>>2]|0;
  HEAP32[$0>>2] = $65;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_vii[$63 & 4095]($60,$$byval_copy2);
  HEAP8[$57>>0] = 0;
 }
 $66 = HEAP32[$dataSize>>2]|0;
 HEAP32[$44>>2] = $66;
 $67 = HEAP32[$28>>2]|0;
 $68 = (__Z25GetBytesFromTextureFormat13TextureFormat($67)|0);
 $69 = (($68) + ($66))|0;
 $70 = HEAP32[628264>>2]|0;
 HEAP32[$0>>2] = $70;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $71 = (__Z15malloc_internaljj10MemLabelIdiPKci($69,32,$$byval_copy2,0,609680,115)|0);
 HEAP32[$54>>2] = $71;
 $72 = HEAP32[$2>>2]|0;
 $73 = (Math_fround(($72|0)));
 $74 = Math_fround(Math_fround(1.0) / $73);
 $75 = HEAP32[$12>>2]|0;
 $76 = (Math_fround(($75|0)));
 $77 = Math_fround(Math_fround(1.0) / $76);
 $78 = (($this) + 72|0);
 HEAPF32[$78>>2] = $74;
 $79 = (($this) + 76|0);
 HEAPF32[$79>>2] = $77;
 $80 = HEAP32[$dataSize>>2]|0;
 __ZN18StreamedBinaryReadILb1EE20TransferTypelessDataEjPvi($transfer,$80,$71,0);
 STACKTOP = sp;return;
}
function __ZN9Texture3D8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre10 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0;
 var $dataSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $dataSize = sp + 8|0;
 __ZN7Texture8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $2 = (($this) + 100|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre4;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($this) + 104|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,4);
  $$pre5 = HEAP32[$3>>2]|0;
  $$pre6 = HEAP32[$6>>2]|0;
  $18 = $$pre5;$20 = $$pre6;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$3>>2] = $11;
  $18 = $11;$20 = $14;
 }
 $16 = (($this) + 108|0);
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)>($20>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$16,4);
  $$pre7 = HEAP32[$3>>2]|0;
  $$pre8 = HEAP32[$6>>2]|0;
  $24 = $$pre7;$26 = $$pre8;
 } else {
  $21 = HEAP32[$18>>2]|0;
  HEAP32[$16>>2] = $21;
  HEAP32[$3>>2] = $17;
  $24 = $17;$26 = $20;
 }
 $22 = (($this) + 112|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)>($26>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$22,4);
  $$pre9 = HEAP32[$3>>2]|0;
  $$pre10 = HEAP32[$6>>2]|0;
  $30 = $$pre9;$32 = $$pre10;
 } else {
  $27 = HEAP32[$24>>2]|0;
  HEAP32[$22>>2] = $27;
  HEAP32[$3>>2] = $23;
  $30 = $23;$32 = $26;
 }
 $28 = (($this) + 124|0);
 $29 = (($30) + 1|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$28,1);
 } else {
  $33 = HEAP8[$30>>0]|0;
  HEAP8[$28>>0] = $33;
  $34 = HEAP32[$3>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$3>>2] = $35;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $36 = (($this) + 120|0);
 $37 = HEAP32[$3>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$6>>2]|0;
 $40 = ($38>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$36,4);
 } else {
  $41 = HEAP32[$37>>2]|0;
  HEAP32[$36>>2] = $41;
  HEAP32[$3>>2] = $38;
 }
 $42 = (($this) + 28|0);
 __ZN15TextureSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($42,$transfer);
 $43 = HEAP32[$36>>2]|0;
 HEAP32[$dataSize>>2] = $43;
 __ZN18StreamedBinaryReadILb0EE16TransferTypelessEPjPKc17TransferMetaFlags($transfer,$dataSize,609976,1);
 $44 = (($this) + 116|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[628264>>2]|0;
 HEAP32[$1>>2] = $46;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($45,$$byval_copy2);
 HEAP32[$44>>2] = 0;
 HEAP32[$36>>2] = 0;
 $47 = (($this) + 125|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = ($48<<24>>24)==(0);
 if (!($49)) {
  $50 = (__Z12GetGfxDevicev()|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + 488|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($this) + 44|0);
  $55 = HEAP32[$54>>2]|0;
  HEAP32[$0>>2] = $55;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_vii[$53 & 4095]($50,$$byval_copy2);
  HEAP8[$47>>0] = 0;
 }
 $56 = HEAP32[$dataSize>>2]|0;
 HEAP32[$36>>2] = $56;
 $57 = HEAP32[$22>>2]|0;
 $58 = (__Z25GetBytesFromTextureFormat13TextureFormat($57)|0);
 $59 = (($58) + ($56))|0;
 $60 = HEAP32[628264>>2]|0;
 HEAP32[$0>>2] = $60;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $61 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,32,$$byval_copy2,0,609680,115)|0);
 HEAP32[$44>>2] = $61;
 $62 = HEAP32[$2>>2]|0;
 $63 = (Math_fround(($62|0)));
 $64 = Math_fround(Math_fround(1.0) / $63);
 $65 = HEAP32[$10>>2]|0;
 $66 = (Math_fround(($65|0)));
 $67 = Math_fround(Math_fround(1.0) / $66);
 $68 = (($this) + 72|0);
 HEAPF32[$68>>2] = $64;
 $69 = (($this) + 76|0);
 HEAPF32[$69>>2] = $67;
 $70 = HEAP32[$dataSize>>2]|0;
 __ZN18StreamedBinaryReadILb0EE20TransferTypelessDataEjPvi($transfer,$70,$61,0);
 STACKTOP = sp;return;
}
function __ZN9Texture3D8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $dataSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $dataSize = sp + 8|0;
 __ZN7Texture8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $2 = (($this) + 100|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$2,609872,0);
 $3 = (($this) + 104|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$3,609880,0);
 $4 = (($this) + 108|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$4,609896,0);
 $5 = (($this) + 112|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$5,609904,0);
 $6 = (($this) + 124|0);
 $7 = HEAP32[580544>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,609920,$7,$$byval_copy2,0)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($8|0)>(0);
  do {
   if ($10) {
    $11 = (($transfer) + 12|0);
    $12 = (($transfer) + 80|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($transfer) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($transfer) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($transfer) + 32|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = Math_imul($21, $19)|0;
    $$sum$i$i$i$i$i = (($15) - ($22))|0;
    $23 = (($17) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$11>>2] = $23;
    $24 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($24)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $25 = (($17) + ($$sum1$i$i$i$i$i)|0);
     $26 = (($transfer) + 20|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($25>>>0)>($27>>>0);
     if (!($28)) {
      $29 = HEAP8[$23>>0]|0;
      HEAP8[$6>>0] = $29;
      $30 = HEAP32[$11>>2]|0;
      $31 = (($30) + 1|0);
      HEAP32[$11>>2] = $31;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($11,$6,1);
   } else {
    $32 = HEAP32[$$byval_copy2>>2]|0;
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     (FUNCTION_TABLE_iii[$32 & 4095]($6,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $34 = (($this) + 120|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$34,609936,0);
 $35 = (($this) + 28|0);
 $36 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,609952,610048,$$byval_copy2,1)|0);
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = ($36|0)>(0);
  if ($38) {
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$35,609992,0);
   $39 = (($this) + 32|0);
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$39,610008,0);
   $40 = (($this) + 36|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$40,610016,0);
   $41 = (($this) + 40|0);
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$41,610032,0);
  } else {
   $42 = HEAP32[$$byval_copy2>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    (FUNCTION_TABLE_iii[$42 & 4095]($35,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $44 = HEAP32[$34>>2]|0;
 HEAP32[$dataSize>>2] = $44;
 __ZN14SafeBinaryRead16TransferTypelessEPjPKc17TransferMetaFlags($transfer,$dataSize,609976,1);
 $45 = (($this) + 116|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[628264>>2]|0;
 HEAP32[$1>>2] = $47;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($46,$$byval_copy2);
 HEAP32[$45>>2] = 0;
 HEAP32[$34>>2] = 0;
 $48 = (($this) + 125|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = ($49<<24>>24)==(0);
 if ($50) {
  $57 = HEAP32[$dataSize>>2]|0;
  HEAP32[$34>>2] = $57;
  $58 = HEAP32[$5>>2]|0;
  $59 = (__Z25GetBytesFromTextureFormat13TextureFormat($58)|0);
  $60 = (($59) + ($57))|0;
  $61 = HEAP32[628264>>2]|0;
  HEAP32[$0>>2] = $61;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $62 = (__Z15malloc_internaljj10MemLabelIdiPKci($60,32,$$byval_copy2,0,609680,115)|0);
  HEAP32[$45>>2] = $62;
  $63 = HEAP32[$2>>2]|0;
  $64 = (Math_fround(($63|0)));
  $65 = Math_fround(Math_fround(1.0) / $64);
  $66 = HEAP32[$3>>2]|0;
  $67 = (Math_fround(($66|0)));
  $68 = Math_fround(Math_fround(1.0) / $67);
  $69 = (($this) + 72|0);
  HEAPF32[$69>>2] = $65;
  $70 = (($this) + 76|0);
  HEAPF32[$70>>2] = $68;
  $71 = HEAP32[$dataSize>>2]|0;
  __ZN14SafeBinaryRead20TransferTypelessDataEjPvi($transfer,$71,$62,0);
  STACKTOP = sp;return;
 }
 $51 = (__Z12GetGfxDevicev()|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 488|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($this) + 44|0);
 $56 = HEAP32[$55>>2]|0;
 HEAP32[$0>>2] = $56;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_vii[$54 & 4095]($51,$$byval_copy2);
 HEAP8[$48>>0] = 0;
 $57 = HEAP32[$dataSize>>2]|0;
 HEAP32[$34>>2] = $57;
 $58 = HEAP32[$5>>2]|0;
 $59 = (__Z25GetBytesFromTextureFormat13TextureFormat($58)|0);
 $60 = (($59) + ($57))|0;
 $61 = HEAP32[628264>>2]|0;
 HEAP32[$0>>2] = $61;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $62 = (__Z15malloc_internaljj10MemLabelIdiPKci($60,32,$$byval_copy2,0,609680,115)|0);
 HEAP32[$45>>2] = $62;
 $63 = HEAP32[$2>>2]|0;
 $64 = (Math_fround(($63|0)));
 $65 = Math_fround(Math_fround(1.0) / $64);
 $66 = HEAP32[$3>>2]|0;
 $67 = (Math_fround(($66|0)));
 $68 = Math_fround(Math_fround(1.0) / $67);
 $69 = (($this) + 72|0);
 HEAPF32[$69>>2] = $65;
 $70 = (($this) + 76|0);
 HEAPF32[$70>>2] = $68;
 $71 = HEAP32[$dataSize>>2]|0;
 __ZN14SafeBinaryRead20TransferTypelessDataEjPvi($transfer,$71,$62,0);
 STACKTOP = sp;return;
}
function __ZN9Texture3D8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $dataSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dataSize = sp;
 __ZN7Texture8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 100|0);
 $1 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,609872,$1,$0,16);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 104|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,609880,$1,$8,16);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 108|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,609896,$1,$13,16);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 112|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,609904,$1,$18,0);
 $19 = HEAP32[$2>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 124|0);
 $24 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,609920,$24,$23,16);
 $25 = HEAP32[$2>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$5>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $29 = (($this) + 120|0);
 $30 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,609936,$30,$29,16);
 $31 = HEAP32[$2>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$5>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $35 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,609952,610048,$35,0);
 __ZN15TextureSettings8TransferI13ProxyTransferEEvRT_($35,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $36 = HEAP32[$29>>2]|0;
 HEAP32[$dataSize>>2] = $36;
 __ZN13ProxyTransfer16TransferTypelessEPjPKc17TransferMetaFlags($transfer,$dataSize,609976,1);
 $37 = HEAP32[$dataSize>>2]|0;
 $38 = (($this) + 116|0);
 $39 = HEAP32[$38>>2]|0;
 __ZN13ProxyTransfer20TransferTypelessDataEjPvi($transfer,$37,$39,0);
 STACKTOP = sp;return;
}
function __Z25GetBytesFromTextureFormat13TextureFormat($inFormat) {
 $inFormat = $inFormat|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($inFormat|0)==(14);
 if ($0) {
  $3 = 4;
 } else {
  $1 = (610072 + ($inFormat<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = $2;
 }
 STACKTOP = sp;return ($3|0);
}
function __Z19GetMaxBytesPerPixel13TextureFormat($inFormat) {
 $inFormat = $inFormat|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 16;
}
function __Z29GetRowBytesFromWidthAndFormati13TextureFormat($width,$inFormat) {
 $width = $width|0;
 $inFormat = $inFormat|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($inFormat|0)==(14);
 if ($0) {
  $4 = 4;
 } else {
  $1 = (610072 + ($inFormat<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $4 = $2;
 }
 $3 = Math_imul($4, $width)|0;
 STACKTOP = sp;return ($3|0);
}
function __Z20IsValidTextureFormat13TextureFormat($format) {
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $format$off = 0, $format$off$i = 0, $format$off$i2 = 0, $format$off$i3 = 0, $format$off$i4 = 0, $format$off$i5 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond7 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $format$off = (($format) + -1)|0;
 $0 = ($format$off>>>0)<(22);
 $format$off$i = (($format) + -30)|0;
 $1 = ($format$off$i>>>0)<(4);
 $or$cond = $0 | $1;
 $2 = ($format|0)==(34);
 $or$cond7 = $or$cond | $2;
 $format$off$i5 = (($format) + -35)|0;
 $3 = ($format$off$i5>>>0)<(2);
 $or$cond9 = $or$cond7 | $3;
 $format$off$i4 = (($format) + -45)|0;
 $4 = ($format$off$i4>>>0)<(3);
 $or$cond11 = $or$cond9 | $4;
 $format$off$i3 = (($format) + -48)|0;
 $5 = ($format$off$i3>>>0)<(12);
 $or$cond13 = $or$cond11 | $5;
 if ($or$cond13) {
  STACKTOP = sp;return 1;
 } else {
  $format$off$i2 = (($format) + -41)|0;
  $6 = ($format$off$i2>>>0)<(4);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z29GetTextureSizeAllowedMultiple13TextureFormat($format) {
 $format = $format|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $format$off$i = 0, $format$off$i1 = 0, $format$off$i2 = 0, $format$off$i3 = 0, $or$cond = 0, $or$cond5 = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $format$off$i = (($format) + -10)|0;
 $0 = ($format$off$i>>>0)<(3);
 $format$off$i3 = (($format) + -35)|0;
 $1 = ($format$off$i3>>>0)<(2);
 $or$cond = $0 | $1;
 $2 = ($format|0)==(34);
 $or$cond5 = $or$cond | $2;
 $format$off$i2 = (($format) + -45)|0;
 $3 = ($format$off$i2>>>0)<(3);
 $or$cond7 = $or$cond5 | $3;
 if ($or$cond7) {
  STACKTOP = sp;return 4;
 } else {
  $format$off$i1 = (($format) + -41)|0;
  $4 = ($format$off$i1>>>0)<(4);
  $$ = $4 ? 4 : 1;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function __Z33GetMinimumTextureMipSizeForFormat13TextureFormat($format) {
 $format = $format|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $format$off$i = 0, $format$off$i4 = 0, $format$off$i5 = 0, $format$off$i6 = 0, $format$off$i7 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond12 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = $format & -2;
 $1 = ($0|0)==(30);
 if ($1) {
  $$0 = 16;
 } else {
  $2 = ($0|0)==(32);
  if ($2) {
   $$0 = 8;
  } else {
   $3 = ($format|0)==(34);
   $format$off$i7 = (($format) + -45)|0;
   $4 = ($format$off$i7>>>0)<(3);
   $or$cond = $3 | $4;
   $format$off$i6 = (($format) + -41)|0;
   $5 = ($format$off$i6>>>0)<(4);
   $or$cond10 = $or$cond | $5;
   $format$off$i5 = (($format) + -35)|0;
   $6 = ($format$off$i5>>>0)<(2);
   $or$cond12 = $or$cond10 | $6;
   if ($or$cond12) {
    $$0 = 4;
   } else {
    $format$off$i4 = (($format) + -48)|0;
    $7 = ($format$off$i4>>>0)<(12);
    if ($7) {
     $$0 = 1;
    } else {
     $format$off$i = (($format) + -10)|0;
     $8 = ($format$off$i>>>0)<(3);
     $$ = $8 ? 4 : 1;
     $$0 = $$;
    }
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z21HasAlphaTextureFormat13TextureFormat($format) {
 $format = $format|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off = 0, $format$off32 = 0, $or$cond11 = 0;
 var $or$cond13 = 0, $or$cond15 = 0, $or$cond17 = 0, $or$cond19 = 0, $or$cond21 = 0, $or$cond23 = 0, $or$cond25 = 0, $or$cond27 = 0, $or$cond29 = 0, $or$cond3 = 0, $or$cond31 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $format$off = (($format) + -1)|0;
 $0 = ($format$off>>>0)<(2);
 $1 = ($format|0)==(13);
 $or$cond3 = $0 | $1;
 $2 = ($format|0)==(4);
 $or$cond5 = $or$cond3 | $2;
 $3 = ($format|0)==(5);
 $or$cond7 = $or$cond5 | $3;
 $4 = ($format|0)==(6);
 $or$cond9 = $or$cond7 | $4;
 $5 = ($format|0)==(9);
 $or$cond11 = $or$cond9 | $5;
 $6 = ($format|0)==(12);
 $or$cond13 = $or$cond11 | $6;
 $7 = ($format|0)==(11);
 $or$cond15 = $or$cond13 | $7;
 $8 = ($format|0)==(17);
 $or$cond17 = $or$cond15 | $8;
 $9 = ($format|0)==(20);
 $or$cond19 = $or$cond17 | $9;
 $10 = ($format|0)==(31);
 $or$cond21 = $or$cond19 | $10;
 $11 = ($format|0)==(33);
 $or$cond23 = $or$cond21 | $11;
 $12 = ($format|0)==(36);
 $or$cond25 = $or$cond23 | $12;
 $13 = ($format|0)==(14);
 $or$cond27 = $or$cond25 | $13;
 $14 = ($format|0)==(46);
 $or$cond29 = $or$cond27 | $14;
 $15 = ($format|0)==(47);
 $or$cond31 = $or$cond29 | $15;
 if ($or$cond31) {
  STACKTOP = sp;return 1;
 } else {
  $format$off32 = (($format) + -54)|0;
  $16 = ($format$off32>>>0)<(6);
  STACKTOP = sp;return ($16|0);
 }
 return 0|0;
}
function __Z15IsDepthRTFormat19RenderTextureFormat($format) {
 $format = $format|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $format & -3;
 $1 = ($0|0)==(1);
 STACKTOP = sp;return ($1|0);
}
function __ZN15TextureSettings14SetAnisoLimitsEii($minAniso,$maxAniso) {
 $minAniso = $minAniso|0;
 $maxAniso = $maxAniso|0;
 var $$pr = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[610312>>2] = $minAniso;
 HEAP32[610320>>2] = $maxAniso;
 $0 = ($minAniso|0)<(1);
 if ($0) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(610328,0,610352,14,1,0,0,0);
  $$pr = HEAP32[610320>>2]|0;
  $2 = $$pr;
 } else {
  $2 = $maxAniso;
 }
 $1 = ($2|0)>(16);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(610360,0,610352,15,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN15TextureSettings14GetAnisoLimitsERiS0_($minAniso,$maxAniso) {
 $minAniso = $minAniso|0;
 $maxAniso = $maxAniso|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[610312>>2]|0;
 HEAP32[$minAniso>>2] = $0;
 $1 = HEAP32[610320>>2]|0;
 HEAP32[$maxAniso>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN15TextureSettings5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 1;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 1;
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15TextureSettings16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$$i = 0, $$$i1 = 0, $$0$i = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)<(0);
 if ($1) {
  $$0$i = 0;
 } else {
  $2 = ($0|0)>(2);
  $$$i = $2 ? 2 : $0;
  $$0$i = $$$i;
 }
 HEAP32[$this>>2] = $$0$i;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)<(0);
 if ($5) {
  $$0$i2 = 0;
  HEAP32[$3>>2] = $$0$i2;
  STACKTOP = sp;return;
 }
 $6 = ($4|0)>(1);
 $$$i1 = $6 ? 1 : $4;
 $$0$i2 = $$$i1;
 HEAP32[$3>>2] = $$0$i2;
 STACKTOP = sp;return;
}
function __ZNK15TextureSettings5ApplyE9TextureID16TextureDimensionb17TextureColorSpaceb($this,$texture,$texDim,$hasMipMap,$colorSpace,$isNPOT) {
 $this = $this|0;
 $texture = $texture|0;
 $texDim = $texDim|0;
 $hasMipMap = $hasMipMap|0;
 $colorSpace = $colorSpace|0;
 $isNPOT = $isNPOT|0;
 var $$$i$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $aniso$0$i$i = 0;
 var $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z21GetUncheckedGfxDevicev()|0);
 $2 = HEAP32[$texture>>2]|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 212|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $2;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 $12 = ($8|0)==(0);
 $or$cond$i = $11 | $12;
 if ($or$cond$i) {
  $aniso$0$i$i = 1;
 } else {
  $13 = HEAP32[610312>>2]|0;
  $14 = ($10|0)<($13|0);
  if ($14) {
   $aniso$0$i$i = $13;
  } else {
   $15 = HEAP32[610320>>2]|0;
   $16 = ($10|0)>($15|0);
   $$$i$i$i = $16 ? $15 : $10;
   $aniso$0$i$i = $$$i$i$i;
  }
 }
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$7 & 63]($1,$$byval_copy,$texDim,$8,$4,$aniso$0$i$i,$hasMipMap,$colorSpace);
 STACKTOP = sp;return;
}
function __ZN9TransformC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((610384 + 8|0));
 $2 = (($this) + 44|0);
 $3 = (($this) + 132|0);
 HEAP8[$3>>0] = 0;
 $4 = (($this) + 133|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 134|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 HEAP8[$5>>0] = 1;
 $6 = (($this) + 135|0);
 HEAP8[$6>>0] = 11;
 $7 = (($this) + 140|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 144|0);
 HEAP32[$8>>2] = $1;
 $9 = (($this) + 148|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 152|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 156|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 136|0);
 HEAP8[$12>>0] = 0;
 $13 = (($this) + 137|0);
 HEAP8[$13>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9Transform5ResetEv($this) {
 $this = $this|0;
 var $$phi$trans$insert$i = 0, $$pre$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0);
 var $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 32|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 36|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 40|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 44|0);
 ;HEAP32[$4+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[616680+8>>2]|0;
 $5 = (($this) + 56|0);
 ;HEAP32[$5+0>>2]=HEAP32[616696+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[616696+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[616696+8>>2]|0;
 $6 = (($this) + 56|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 60|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 - $9);
 $11 = $10 < Math_fround(0.0);
 if ($11) {
  $12 = Math_fround(-$10);
  $14 = $12;
 } else {
  $14 = $10;
 }
 $13 = !($14 <= Math_fround(9.99999974737875163555E-5));
 $$phi$trans$insert$i = (($this) + 64|0);
 $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
 do {
  if ($13) {
   label = 13;
  } else {
   $15 = Math_fround($9 - $$pre$i);
   $16 = $15 < Math_fround(0.0);
   if ($16) {
    $17 = Math_fround(-$15);
    $19 = $17;
   } else {
    $19 = $15;
   }
   $18 = !($19 <= Math_fround(9.99999974737875163555E-5));
   if ($18) {
    label = 13;
   } else {
    $20 = Math_fround($7 + Math_fround(-1.0));
    $21 = $20 < Math_fround(0.0);
    if ($21) {
     $22 = Math_fround(-$20);
     $24 = $22;
    } else {
     $24 = $20;
    }
    $23 = !($24 <= Math_fround(9.99999974737875163555E-5));
    $25 = (($this) + 136|0);
    if (!($23)) {
     HEAP8[$25>>0] = 0;
     break;
    }
    HEAP8[$25>>0] = 1;
    $26 = $7 < Math_fround(0.0);
    if ($26) {
     HEAP8[$25>>0] = 6;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $27 = (($this) + 136|0);
  $28 = Math_fround($7 * $9);
  $29 = Math_fround($28 * $$pre$i);
  $30 = $29 < Math_fround(0.0);
  $31 = $30&1;
  $32 = $31 << 2;
  $33 = $32 | 2;
  $34 = $33&255;
  HEAP8[$27>>0] = $34;
 }
 $35 = (($this) + 133|0);
 HEAP8[$35>>0] = 0;
 $36 = (($this) + 134|0);
 HEAP8[$36>>0] = 1;
 $37 = (($this) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 __ZN9Transform20SendTransformChangedEi($this,11);
 STACKTOP = sp;return;
}
function __ZN9Transform24RecalculateTransformTypeEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$pre = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 60|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = $4 < Math_fround(0.0);
 if ($5) {
  $6 = Math_fround(-$4);
  $8 = $6;
 } else {
  $8 = $4;
 }
 $7 = !($8 <= Math_fround(9.99999974737875163555E-5));
 $$phi$trans$insert = (($this) + 64|0);
 $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
 if (!($7)) {
  $9 = Math_fround($3 - $$pre);
  $10 = $9 < Math_fround(0.0);
  if ($10) {
   $11 = Math_fround(-$9);
   $13 = $11;
  } else {
   $13 = $9;
  }
  $12 = !($13 <= Math_fround(9.99999974737875163555E-5));
  if (!($12)) {
   $14 = Math_fround($1 + Math_fround(-1.0));
   $15 = $14 < Math_fround(0.0);
   if ($15) {
    $16 = Math_fround(-$14);
    $18 = $16;
   } else {
    $18 = $14;
   }
   $17 = !($18 <= Math_fround(9.99999974737875163555E-5));
   $19 = (($this) + 136|0);
   if (!($17)) {
    HEAP8[$19>>0] = 0;
    STACKTOP = sp;return;
   }
   HEAP8[$19>>0] = 1;
   $20 = $1 < Math_fround(0.0);
   if (!($20)) {
    STACKTOP = sp;return;
   }
   HEAP8[$19>>0] = 6;
   STACKTOP = sp;return;
  }
 }
 $21 = (($this) + 136|0);
 $22 = Math_fround($1 * $3);
 $23 = Math_fround($22 * $$pre);
 $24 = $23 < Math_fround(0.0);
 $25 = $24&1;
 $26 = $25 << 2;
 $27 = $26 | 2;
 $28 = $27&255;
 HEAP8[$21>>0] = $28;
 STACKTOP = sp;return;
}
function __ZN9Transform20SendTransformChangedEi($this,$changeMask) {
 $this = $this|0;
 $changeMask = $changeMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $data1 = 0, $i$01 = 0, $i2$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $data = sp + 12|0;
 $data1 = sp;
 $0 = (($this) + 135|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 | $changeMask;
 HEAP8[$0>>0] = 0;
 $4 = $3 >>> 5;
 $5 = (($this) + 137|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 do {
  if ($7) {
   $8 = $4 & 1;
   $9 = ($8|0)==(0);
   $10 = (($this) + 133|0);
   HEAP8[$10>>0] = 0;
   $11 = (($this) + 134|0);
   HEAP8[$11>>0] = 1;
   if (!($9)) {
    $12 = (($this) + 24|0);
    $13 = HEAP32[$12>>2]|0;
    $32 = $13;
    break;
   }
   $14 = (($this) + 140|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($this) + 148|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($15) + ($17<<2)|0);
   $19 = ($17|0)==(0);
   if ($19) {
    STACKTOP = sp;return;
   }
   $20 = $3 | 1;
   $i$01 = $15;
   while(1) {
    $21 = HEAP32[$i$01>>2]|0;
    __ZN9Transform20SendTransformChangedEi($21,$20);
    $22 = (($i$01) + 4|0);
    $23 = ($22|0)==($18|0);
    if ($23) {
     break;
    } else {
     $i$01 = $22;
    }
   }
   STACKTOP = sp;return;
  } else {
   $24 = (($this) + 133|0);
   HEAP8[$24>>0] = 0;
   $25 = (($this) + 134|0);
   HEAP8[$25>>0] = 1;
   $26 = (($this) + 24|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($data) + 8|0);
   HEAP32[$28>>2] = 0;
   $29 = (($data) + 4|0);
   HEAP32[$29>>2] = $3;
   HEAP32[$data>>2] = 100000;
   __ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData($27,564104,$data);
   $32 = $27;
  }
 } while(0);
 $30 = $4 & 1;
 $31 = ($30|0)==(0);
 if (!($31)) {
  __ZN5Unity10GameObject25TransformParentHasChangedEv($32);
  $33 = (($data1) + 8|0);
  HEAP32[$33>>2] = 0;
  $34 = (($data1) + 4|0);
  HEAP32[$34>>2] = 0;
  HEAP32[$data1>>2] = 0;
  __ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData($32,564208,$data1);
 }
 $35 = (($this) + 140|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 148|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + ($38<<2)|0);
 $40 = ($38|0)==(0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = $3 | 1;
 $i2$03 = $36;
 while(1) {
  $42 = HEAP32[$i2$03>>2]|0;
  __ZN9Transform20SendTransformChangedEi($42,$41);
  $43 = (($i2$03) + 4|0);
  $44 = ($43|0)==($39|0);
  if ($44) {
   break;
  } else {
   $i2$03 = $43;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Transform15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Transform4FindEPKS_($this,$child) {
 $this = $this|0;
 $child = $child|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $it$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 148|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)==(0);
 L1: do {
  if ($5) {
   $$0 = $4;
  } else {
   $it$01 = $1;
   while(1) {
    $8 = HEAP32[$it$01>>2]|0;
    $9 = ($8|0)==($child|0);
    $7 = (($it$01) + 4|0);
    if ($9) {
     $$0 = $it$01;
     break L1;
    }
    $6 = ($7|0)==($4|0);
    if ($6) {
     $$0 = $4;
     break;
    } else {
     $it$01 = $7;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Transform16RemoveFromParentEb($this,$sendParentingChanged) {
 $this = $this|0;
 $sendParentingChanged = $sendParentingChanged|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $it$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 if ($sendParentingChanged) {
  $3 = (($this) + 24|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   __ZN9Transform26SendBeforeParentingChangedEv($this);
  }
 }
 $6 = (($1) + 148|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 L8: do {
  if (!($8)) {
   $9 = (($7) + -1)|0;
   $10 = (($1) + 140|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + ($9<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==($this|0);
   if ($14) {
    HEAP32[$6>>2] = $9;
    break;
   }
   $15 = (($11) + ($7<<2)|0);
   $it$01$i = $11;
   while(1) {
    $18 = HEAP32[$it$01$i>>2]|0;
    $19 = ($18|0)==($this|0);
    $17 = (($it$01$i) + 4|0);
    if ($19) {
     break;
    }
    $16 = ($17|0)==($15|0);
    if ($16) {
     break L8;
    } else {
     $it$01$i = $17;
    }
   }
   $20 = ($it$01$i|0)==($15|0);
   if (!($20)) {
    $21 = (($it$01$i) + 4|0);
    $22 = $15;
    $23 = $21;
    $24 = (($22) - ($23))|0;
    _memmove(($it$01$i|0),($21|0),($24|0))|0;
    $25 = HEAP32[$6>>2]|0;
    $26 = (($25) + -1)|0;
    HEAP32[$6>>2] = $26;
   }
  }
 } while(0);
 if (!($sendParentingChanged)) {
  STACKTOP = sp;return;
 }
 $27 = (($this) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 __ZN9Transform20SendTransformChangedEi($this,32);
 $30 = (($data) + 8|0);
 HEAP32[$30>>2] = 0;
 $31 = (($data) + 4|0);
 HEAP32[$31>>2] = 0;
 HEAP32[$data>>2] = 0;
 $32 = (($1) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 __ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData($33,564264,$data);
 STACKTOP = sp;return;
}
function __ZN9Transform26SendBeforeParentingChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 $0 = (($data) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($data) + 4|0);
 HEAP32[$1>>2] = 0;
 HEAP32[$data>>2] = 0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData($3,564152,$data);
 }
 $5 = (($this) + 140|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 148|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + ($8<<2)|0);
 $10 = ($8|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $6;
 }
 while(1) {
  $11 = HEAP32[$i$01>>2]|0;
  __ZN9Transform26SendBeforeParentingChangedEv($11);
  $12 = (($i$01) + 4|0);
  $13 = ($12|0)==($9|0);
  if ($13) {
   break;
  } else {
   $i$01 = $12;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI12ImmediatePtrI9TransformELj4EE9push_backERKS2_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if (!($7)) {
  $26 = $3;
  $25 = (($26) + -1)|0;
  $27 = HEAP32[$this>>2]|0;
  $28 = HEAP32[$t>>2]|0;
  $29 = (($27) + ($25<<2)|0);
  HEAP32[$29>>2] = $28;
  STACKTOP = sp;return;
 }
 $8 = $5 << 1;
 $9 = ($8|0)==(0);
 $10 = $9 ? 1 : $8;
 $11 = ($6>>>0)<($10>>>0);
 do {
  if ($11) {
   $12 = ($5|0)>(-1);
   if ($12) {
    HEAP32[$4>>2] = $10;
    $13 = HEAP32[$this>>2]|0;
    $14 = $10 << 2;
    $15 = (($this) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,610504,370)|0);
    HEAP32[$this>>2] = $17;
    break;
   } else {
    $18 = $10 << 2;
    $19 = (($this) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,610504,352)|0);
    $22 = HEAP32[$this>>2]|0;
    $23 = HEAP32[$1>>2]|0;
    $24 = $23 << 2;
    _memcpy(($21|0),($22|0),($24|0))|0;
    HEAP32[$4>>2] = $10;
    HEAP32[$this>>2] = $21;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$1>>2]|0;
 $26 = $$pre$i;
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$t>>2]|0;
 $29 = (($27) + ($25<<2)|0);
 HEAP32[$29>>2] = $28;
 STACKTOP = sp;return;
}
function __ZN9Transform10ClearChildEPS_($this,$child) {
 $this = $this|0;
 $child = $child|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $it$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 148|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $it$01$i = $1;
 }
 while(1) {
  $8 = HEAP32[$it$01$i>>2]|0;
  $9 = ($8|0)==($child|0);
  $7 = (($it$01$i) + 4|0);
  if ($9) {
   break;
  }
  $6 = ($7|0)==($4|0);
  if ($6) {
   label = 6;
   break;
  } else {
   $it$01$i = $7;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
 $10 = ($it$01$i|0)==($4|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($it$01$i) + 4|0);
 $12 = $4;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 _memmove(($it$01$i|0),($11|0),($14|0))|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$2>>2] = $16;
 STACKTOP = sp;return;
}
function __ZNK9Transform13GetWorldScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $7 = 0, $8 = Math_fround(0);
 var $9 = 0, $cur$0$i = 0, $cur$0$in$i = 0, $cur$0$in1$i = 0, $cur$02$i = 0, $cur$03$i = 0, $invRotation = 0, $scaleAndRotation = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $invRotation = sp + 52|0;
 $0 = sp;
 $scaleAndRotation = sp + 16|0;
 $1 = (($this) + 28|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 32|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 36|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 40|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $cur$0$in1$i = (($this) + 156|0);
 $cur$02$i = HEAP32[$cur$0$in1$i>>2]|0;
 $9 = ($cur$02$i|0)==(0|0);
 if ($9) {
  $52 = $2;$54 = $4;$56 = $6;$60 = $8;
 } else {
  $13 = $2;$17 = $8;$22 = $6;$27 = $4;$cur$03$i = $cur$02$i;
  while(1) {
   $10 = (($cur$03$i) + 40|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = Math_fround($13 * $11);
   $14 = (($cur$03$i) + 28|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($17 * $15);
   $18 = Math_fround($12 + $16);
   $19 = (($cur$03$i) + 32|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround($22 * $20);
   $23 = Math_fround($18 + $21);
   $24 = (($cur$03$i) + 36|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = Math_fround($27 * $25);
   $28 = Math_fround($23 - $26);
   $29 = Math_fround($27 * $11);
   $30 = Math_fround($17 * $20);
   $31 = Math_fround($29 + $30);
   $32 = Math_fround($13 * $25);
   $33 = Math_fround($32 + $31);
   $34 = Math_fround($22 * $15);
   $35 = Math_fround($33 - $34);
   $36 = Math_fround($22 * $11);
   $37 = Math_fround($17 * $25);
   $38 = Math_fround($36 + $37);
   $39 = Math_fround($27 * $15);
   $40 = Math_fround($39 + $38);
   $41 = Math_fround($13 * $20);
   $42 = Math_fround($40 - $41);
   $43 = Math_fround($17 * $11);
   $44 = Math_fround($13 * $15);
   $45 = Math_fround($43 - $44);
   $46 = Math_fround($27 * $20);
   $47 = Math_fround($45 - $46);
   $48 = Math_fround($22 * $25);
   $49 = Math_fround($47 - $48);
   $cur$0$in$i = (($cur$03$i) + 156|0);
   $cur$0$i = HEAP32[$cur$0$in$i>>2]|0;
   $50 = ($cur$0$i|0)==(0|0);
   if ($50) {
    $52 = $28;$54 = $35;$56 = $42;$60 = $49;
    break;
   } else {
    $13 = $28;$17 = $49;$22 = $42;$27 = $35;$cur$03$i = $cur$0$i;
   }
  }
 }
 $51 = Math_fround(-$52);
 $53 = Math_fround(-$54);
 $55 = Math_fround(-$56);
 HEAPF32[$0>>2] = $51;
 $57 = (($0) + 4|0);
 HEAPF32[$57>>2] = $53;
 $58 = (($0) + 8|0);
 HEAPF32[$58>>2] = $55;
 $59 = (($0) + 12|0);
 HEAPF32[$59>>2] = $60;
 __Z18QuaternionToMatrixRK11QuaternionfR10Matrix3x3f($0,$invRotation);
 __ZNK9Transform24GetWorldRotationAndScaleEv($scaleAndRotation,$this);
 dest=$agg$result+0|0; src=$invRotation+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 (__ZN10Matrix3x3fmLERKS_($agg$result,$scaleAndRotation)|0);
 STACKTOP = sp;return;
}
function __ZNK9Transform11GetRotationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$promoted = Math_fround(0), $$promoted4 = Math_fround(0), $$promoted5 = Math_fround(0), $$promoted6 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $cur$0 = 0, $cur$0$in = 0, $cur$0$in1 = 0, $cur$02 = 0, $cur$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 $cur$0$in1 = (($this) + 156|0);
 $cur$02 = HEAP32[$cur$0$in1>>2]|0;
 $1 = ($cur$02|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($agg$result) + 12|0);
 $3 = (($agg$result) + 8|0);
 $4 = (($agg$result) + 4|0);
 $$promoted = Math_fround(HEAPF32[$agg$result>>2]);
 $$promoted4 = Math_fround(HEAPF32[$2>>2]);
 $$promoted5 = Math_fround(HEAPF32[$3>>2]);
 $$promoted6 = Math_fround(HEAPF32[$4>>2]);
 $12 = $$promoted4;$17 = $$promoted5;$22 = $$promoted6;$8 = $$promoted;$cur$03 = $cur$02;
 while(1) {
  $5 = (($cur$03) + 40|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($6 * $8);
  $9 = (($cur$03) + 28|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround($10 * $12);
  $13 = Math_fround($7 + $11);
  $14 = (($cur$03) + 32|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = Math_fround($15 * $17);
  $18 = Math_fround($13 + $16);
  $19 = (($cur$03) + 36|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($20 * $22);
  $23 = Math_fround($18 - $21);
  $24 = Math_fround($6 * $22);
  $25 = Math_fround($12 * $15);
  $26 = Math_fround($25 + $24);
  $27 = Math_fround($8 * $20);
  $28 = Math_fround($27 + $26);
  $29 = Math_fround($10 * $17);
  $30 = Math_fround($28 - $29);
  $31 = Math_fround($6 * $17);
  $32 = Math_fround($12 * $20);
  $33 = Math_fround($31 + $32);
  $34 = Math_fround($10 * $22);
  $35 = Math_fround($33 + $34);
  $36 = Math_fround($8 * $15);
  $37 = Math_fround($35 - $36);
  $38 = Math_fround($6 * $12);
  $39 = Math_fround($8 * $10);
  $40 = Math_fround($38 - $39);
  $41 = Math_fround($15 * $22);
  $42 = Math_fround($40 - $41);
  $43 = Math_fround($17 * $20);
  $44 = Math_fround($42 - $43);
  $cur$0$in = (($cur$03) + 156|0);
  $cur$0 = HEAP32[$cur$0$in>>2]|0;
  $45 = ($cur$0|0)==(0|0);
  if ($45) {
   break;
  } else {
   $12 = $44;$17 = $37;$22 = $30;$8 = $23;$cur$03 = $cur$0;
  }
 }
 HEAPF32[$agg$result>>2] = $23;
 HEAPF32[$2>>2] = $44;
 HEAPF32[$3>>2] = $37;
 HEAPF32[$4>>2] = $30;
 STACKTOP = sp;return;
}
function __ZNK9Transform24GetWorldRotationAndScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $parentTransform = 0, $rotation = 0, $scale = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $scale = sp + 108|0;
 $rotation = sp;
 $parentTransform = sp + 36|0;
 $0 = sp + 72|0;
 $1 = (($this) + 56|0);
 (__ZN10Matrix3x3f8SetScaleERK8Vector3f($scale,$1)|0);
 $2 = (($this) + 28|0);
 __Z18QuaternionToMatrixRK11QuaternionfR10Matrix3x3f($2,$rotation);
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  dest=$agg$result+0|0; src=$rotation+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  (__ZN10Matrix3x3fmLERKS_($agg$result,$scale)|0);
  STACKTOP = sp;return;
 } else {
  __ZNK9Transform24GetWorldRotationAndScaleEv($parentTransform,$4);
  dest=$0+0|0; src=$parentTransform+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  (__ZN10Matrix3x3fmLERKS_($0,$rotation)|0);
  dest=$agg$result+0|0; src=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  (__ZN10Matrix3x3fmLERKS_($agg$result,$scale)|0);
  STACKTOP = sp;return;
 }
}
function __ZNK9Transform18GetWorldScaleLossyEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = Math_fround(0), $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $rot = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $rot = sp;
 __ZNK9Transform13GetWorldScaleEv($rot,$this);
 $0 = Math_fround(HEAPF32[$rot>>2]);
 $1 = (($rot) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($rot) + 32|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$agg$result>>2] = $0;
 $5 = (($agg$result) + 4|0);
 HEAPF32[$5>>2] = $2;
 $6 = (($agg$result) + 8|0);
 HEAPF32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNK9Transform11GetPositionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$promoted = Math_fround(0), $$promoted4 = Math_fround(0), $$promoted5 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $8 = 0, $9 = Math_fround(0), $cur$0 = 0, $cur$0$in = 0, $cur$0$in1 = 0, $cur$02 = 0;
 var $cur$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 $cur$0$in1 = (($this) + 156|0);
 $cur$02 = HEAP32[$cur$0$in1>>2]|0;
 $1 = ($cur$02|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($agg$result) + 4|0);
 $3 = (($agg$result) + 8|0);
 $$promoted = Math_fround(HEAPF32[$agg$result>>2]);
 $$promoted4 = Math_fround(HEAPF32[$2>>2]);
 $$promoted5 = Math_fround(HEAPF32[$3>>2]);
 $11 = $$promoted4;$15 = $$promoted5;$7 = $$promoted;$cur$03 = $cur$02;
 while(1) {
  $4 = (($cur$03) + 56|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = Math_fround($5 * $7);
  $8 = (($cur$03) + 60|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($9 * $11);
  $12 = (($cur$03) + 64|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($13 * $15);
  $16 = (($cur$03) + 28|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($17 * Math_fround(2.0));
  $19 = (($cur$03) + 32|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($20 * Math_fround(2.0));
  $22 = (($cur$03) + 36|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($23 * Math_fround(2.0));
  $25 = Math_fround($17 * $18);
  $26 = Math_fround($20 * $21);
  $27 = Math_fround($23 * $24);
  $28 = Math_fround($17 * $21);
  $29 = Math_fround($17 * $24);
  $30 = Math_fround($20 * $24);
  $31 = (($cur$03) + 40|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($18 * $32);
  $34 = Math_fround($21 * $32);
  $35 = Math_fround($32 * $24);
  $36 = Math_fround($26 + $27);
  $37 = Math_fround(Math_fround(1.0) - $36);
  $38 = Math_fround($6 * $37);
  $39 = Math_fround($28 - $35);
  $40 = Math_fround($39 * $10);
  $41 = Math_fround($40 + $38);
  $42 = Math_fround($29 + $34);
  $43 = Math_fround($14 * $42);
  $44 = Math_fround($43 + $41);
  $45 = Math_fround($28 + $35);
  $46 = Math_fround($6 * $45);
  $47 = Math_fround($25 + $27);
  $48 = Math_fround(Math_fround(1.0) - $47);
  $49 = Math_fround($10 * $48);
  $50 = Math_fround($46 + $49);
  $51 = Math_fround($30 - $33);
  $52 = Math_fround($14 * $51);
  $53 = Math_fround($52 + $50);
  $54 = Math_fround($29 - $34);
  $55 = Math_fround($6 * $54);
  $56 = Math_fround($30 + $33);
  $57 = Math_fround($56 * $10);
  $58 = Math_fround($55 + $57);
  $59 = Math_fround($25 + $26);
  $60 = Math_fround(Math_fround(1.0) - $59);
  $61 = Math_fround($14 * $60);
  $62 = Math_fround($61 + $58);
  $63 = (($cur$03) + 44|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = Math_fround($64 + $44);
  $66 = (($cur$03) + 48|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($67 + $53);
  $69 = (($cur$03) + 52|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($70 + $62);
  $cur$0$in = (($cur$03) + 156|0);
  $cur$0 = HEAP32[$cur$0$in>>2]|0;
  $72 = ($cur$0|0)==(0|0);
  if ($72) {
   break;
  } else {
   $11 = $68;$15 = $71;$7 = $65;$cur$03 = $cur$0;
  }
 }
 HEAPF32[$agg$result>>2] = $65;
 HEAPF32[$2>>2] = $68;
 HEAPF32[$3>>2] = $71;
 STACKTOP = sp;return;
}
function __ZN9Transform45SetPositionAndRotationSafeWithoutNotificationERK8Vector3fRK11Quaternionf($this,$p,$q) {
 $this = $this|0;
 $p = $p|0;
 $q = $q|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Transform30SetPositionAndRotationInternalILb1ELb0EEEvRK8Vector3fRK11Quaternionf($this,$p,$q);
 STACKTOP = sp;return;
}
function __ZN9Transform13SetCacheDirtyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 133|0);
 HEAP8[$0>>0] = 0;
 $1 = (($this) + 134|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 140|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5<<2)|0);
 $7 = ($5|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $3;
 }
 while(1) {
  $8 = HEAP32[$i$01>>2]|0;
  __ZN9Transform13SetCacheDirtyEv($8);
  $9 = (($i$01) + 4|0);
  $10 = ($9|0)==($6|0);
  if ($10) {
   break;
  } else {
   $i$01 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Transform19SetLocalEulerAnglesERK8Vector3f($this,$eulerAngles) {
 $this = $this|0;
 $eulerAngles = $eulerAngles|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = Math_fround(HEAPF32[$eulerAngles>>2]);
 $3 = Math_fround($2 * Math_fround(0.0174532942473888397217));
 $4 = (($eulerAngles) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(0.0174532942473888397217));
 $7 = (($eulerAngles) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * Math_fround(0.0174532942473888397217));
 HEAPF32[$1>>2] = $3;
 $10 = (($1) + 4|0);
 HEAPF32[$10>>2] = $6;
 $11 = (($1) + 8|0);
 HEAPF32[$11>>2] = $9;
 __Z17EulerToQuaternionRK8Vector3f($0,$1);
 $12 = Math_fround(HEAPF32[$0>>2]);
 $13 = Math_fround($12 * $12);
 $14 = (($0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $15);
 $17 = Math_fround($13 + $16);
 $18 = (($0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $19);
 $21 = Math_fround($17 + $20);
 $22 = (($0) + 12|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $23);
 $25 = Math_fround($21 + $24);
 $26 = (Math_fround(Math_sqrt((Math_fround($25)))));
 $27 = Math_fround(HEAPF32[616648>>2]);
 $28 = $26 < $27;
 if ($28) {
  $36 = Math_fround(0.0);$39 = Math_fround(0.0);$43 = Math_fround(0.0);$47 = Math_fround(1.0);
 } else {
  $29 = Math_fround($12 / $26);
  $30 = Math_fround($15 / $26);
  $31 = Math_fround($19 / $26);
  $32 = Math_fround($23 / $26);
  $36 = $29;$39 = $30;$43 = $31;$47 = $32;
 }
 $33 = (($this) + 28|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = $34 != $36;
 $$pre$i = (($this) + 32|0);
 if (!($35)) {
  $37 = Math_fround(HEAPF32[$$pre$i>>2]);
  $38 = $37 != $39;
  if (!($38)) {
   $40 = (($this) + 36|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = $41 != $43;
   if (!($42)) {
    $44 = (($this) + 40|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = $45 != $47;
    if (!($46)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 HEAPF32[$33>>2] = $36;
 HEAPF32[$$pre$i>>2] = $39;
 $48 = (($this) + 36|0);
 HEAPF32[$48>>2] = $43;
 $49 = (($this) + 40|0);
 HEAPF32[$49>>2] = $47;
 __ZN9Transform20SendTransformChangedEi($this,2);
 STACKTOP = sp;return;
}
function __ZN9Transform20SetLocalRotationSafeERK11Quaternionf($this,$q) {
 $this = $this|0;
 $q = $q|0;
 var $$pre = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$q>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($q) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($q) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (($q) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (Math_fround(Math_sqrt((Math_fround($13)))));
 $15 = Math_fround(HEAPF32[616648>>2]);
 $16 = $14 < $15;
 if ($16) {
  $24 = Math_fround(0.0);$27 = Math_fround(0.0);$31 = Math_fround(0.0);$35 = Math_fround(1.0);
 } else {
  $17 = Math_fround($0 / $14);
  $18 = Math_fround($3 / $14);
  $19 = Math_fround($7 / $14);
  $20 = Math_fround($11 / $14);
  $24 = $17;$27 = $18;$31 = $19;$35 = $20;
 }
 $21 = (($this) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = $22 != $24;
 $$pre = (($this) + 32|0);
 if (!($23)) {
  $25 = Math_fround(HEAPF32[$$pre>>2]);
  $26 = $25 != $27;
  if (!($26)) {
   $28 = (($this) + 36|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = $29 != $31;
   if (!($30)) {
    $32 = (($this) + 40|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = $33 != $35;
    if (!($34)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 HEAPF32[$21>>2] = $24;
 HEAPF32[$$pre>>2] = $27;
 $36 = (($this) + 36|0);
 HEAPF32[$36>>2] = $31;
 $37 = (($this) + 40|0);
 HEAPF32[$37>>2] = $35;
 __ZN9Transform20SendTransformChangedEi($this,2);
 STACKTOP = sp;return;
}
function __ZN9Transform19GetLocalEulerAnglesEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $rotation = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $rotation = sp + 16|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($2 * $2);
 $4 = (($this) + 32|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $5);
 $7 = Math_fround($3 + $6);
 $8 = (($this) + 36|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (($this) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * $13);
 $15 = Math_fround($11 + $14);
 $16 = (Math_fround(Math_sqrt((Math_fround($15)))));
 $17 = Math_fround(HEAPF32[616648>>2]);
 $18 = $16 < $17;
 if ($18) {
  HEAPF32[$rotation>>2] = Math_fround(0.0);
  $19 = (($rotation) + 4|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = (($rotation) + 8|0);
  HEAPF32[$20>>2] = Math_fround(0.0);
  $21 = (($rotation) + 12|0);
  HEAPF32[$21>>2] = Math_fround(1.0);
 } else {
  $22 = Math_fround($2 / $16);
  $23 = Math_fround($5 / $16);
  $24 = Math_fround($9 / $16);
  $25 = Math_fround($13 / $16);
  HEAPF32[$rotation>>2] = $22;
  $26 = (($rotation) + 4|0);
  HEAPF32[$26>>2] = $23;
  $27 = (($rotation) + 8|0);
  HEAPF32[$27>>2] = $24;
  $28 = (($rotation) + 12|0);
  HEAPF32[$28>>2] = $25;
 }
 __Z17QuaternionToEulerRK11Quaternionf($0,$rotation);
 $29 = Math_fround(HEAPF32[$0>>2]);
 $30 = Math_fround($29 * Math_fround(57.2957763671875));
 $31 = (($0) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(57.2957763671875));
 $34 = (($0) + 8|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * Math_fround(57.2957763671875));
 HEAPF32[$agg$result>>2] = $30;
 $37 = (($agg$result) + 4|0);
 HEAPF32[$37>>2] = $33;
 $38 = (($agg$result) + 8|0);
 HEAPF32[$38>>2] = $36;
 STACKTOP = sp;return;
}
function __ZN9Transform11SetRotationERK11Quaternionf($this,$q) {
 $this = $this|0;
 $q = $q|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0);
 var $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $cur$0$i = 0, $cur$0$in$i = 0, $cur$0$in1$i = 0, $cur$02$i = 0, $cur$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $108 = (($this) + 28|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = Math_fround(HEAPF32[$q>>2]);
  $111 = $109 != $110;
  if (!($111)) {
   $112 = (($this) + 32|0);
   $113 = Math_fround(HEAPF32[$112>>2]);
   $114 = (($q) + 4|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = $113 != $115;
   if (!($116)) {
    $117 = (($this) + 36|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = (($q) + 8|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = $118 != $120;
    if (!($121)) {
     $122 = (($this) + 40|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     $124 = (($q) + 12|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     $126 = $123 != $125;
     if (!($126)) {
      STACKTOP = sp;return;
     }
    }
   }
  }
  ;HEAP32[$108+0>>2]=HEAP32[$q+0>>2]|0;HEAP32[$108+4>>2]=HEAP32[$q+4>>2]|0;HEAP32[$108+8>>2]=HEAP32[$q+8>>2]|0;HEAP32[$108+12>>2]=HEAP32[$q+12>>2]|0;
  __ZN9Transform20SendTransformChangedEi($this,2);
  STACKTOP = sp;return;
 }
 $3 = (($1) + 28|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 32|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 36|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($1) + 40|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $cur$0$in1$i = (($1) + 156|0);
 $cur$02$i = HEAP32[$cur$0$in1$i>>2]|0;
 $11 = ($cur$02$i|0)==(0|0);
 if ($11) {
  $54 = $4;$56 = $6;$58 = $8;$61 = $10;
 } else {
  $15 = $4;$19 = $10;$24 = $8;$29 = $6;$cur$03$i = $cur$02$i;
  while(1) {
   $12 = (($cur$03$i) + 40|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = Math_fround($15 * $13);
   $16 = (($cur$03$i) + 28|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround($19 * $17);
   $20 = Math_fround($14 + $18);
   $21 = (($cur$03$i) + 32|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = Math_fround($24 * $22);
   $25 = Math_fround($20 + $23);
   $26 = (($cur$03$i) + 36|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($29 * $27);
   $30 = Math_fround($25 - $28);
   $31 = Math_fround($29 * $13);
   $32 = Math_fround($19 * $22);
   $33 = Math_fround($31 + $32);
   $34 = Math_fround($15 * $27);
   $35 = Math_fround($34 + $33);
   $36 = Math_fround($24 * $17);
   $37 = Math_fround($35 - $36);
   $38 = Math_fround($24 * $13);
   $39 = Math_fround($19 * $27);
   $40 = Math_fround($38 + $39);
   $41 = Math_fround($29 * $17);
   $42 = Math_fround($41 + $40);
   $43 = Math_fround($15 * $22);
   $44 = Math_fround($42 - $43);
   $45 = Math_fround($19 * $13);
   $46 = Math_fround($15 * $17);
   $47 = Math_fround($45 - $46);
   $48 = Math_fround($29 * $22);
   $49 = Math_fround($47 - $48);
   $50 = Math_fround($24 * $27);
   $51 = Math_fround($49 - $50);
   $cur$0$in$i = (($cur$03$i) + 156|0);
   $cur$0$i = HEAP32[$cur$0$in$i>>2]|0;
   $52 = ($cur$0$i|0)==(0|0);
   if ($52) {
    $54 = $30;$56 = $37;$58 = $44;$61 = $51;
    break;
   } else {
    $15 = $30;$19 = $51;$24 = $44;$29 = $37;$cur$03$i = $cur$0$i;
   }
  }
 }
 $53 = Math_fround(-$54);
 $55 = Math_fround(-$56);
 $57 = Math_fround(-$58);
 $59 = Math_fround(HEAPF32[$q>>2]);
 $60 = Math_fround($61 * $59);
 $62 = (($q) + 12|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $53);
 $65 = Math_fround($60 + $64);
 $66 = (($q) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 * $55);
 $69 = Math_fround($65 + $68);
 $70 = (($q) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $57);
 $73 = Math_fround($69 - $72);
 $74 = Math_fround($61 * $71);
 $75 = Math_fround($63 * $55);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($59 * $57);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($67 * $53);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($61 * $67);
 $82 = Math_fround($63 * $57);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($71 * $53);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($59 * $55);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($61 * $63);
 $89 = Math_fround($59 * $53);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($71 * $55);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($67 * $57);
 $94 = Math_fround($92 - $93);
 $95 = (($this) + 28|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = $96 != $73;
 $$pre = (($this) + 32|0);
 if (!($97)) {
  $98 = Math_fround(HEAPF32[$$pre>>2]);
  $99 = $98 != $80;
  if (!($99)) {
   $100 = (($this) + 36|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = $101 != $87;
   if (!($102)) {
    $103 = (($this) + 40|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = $104 != $94;
    if (!($105)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 HEAPF32[$95>>2] = $73;
 HEAPF32[$$pre>>2] = $80;
 $106 = (($this) + 36|0);
 HEAPF32[$106>>2] = $87;
 $107 = (($this) + 40|0);
 HEAPF32[$107>>2] = $94;
 __ZN9Transform20SendTransformChangedEi($this,2);
 STACKTOP = sp;return;
}
function __ZN9Transform15SetRotationSafeERK11Quaternionf($this,$q) {
 $this = $this|0;
 $q = $q|0;
 var $$pre = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $cur$0$i = 0, $cur$0$in$i = 0, $cur$0$in1$i = 0, $cur$02$i = 0, $cur$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $126 = Math_fround(HEAPF32[$q>>2]);
  $127 = Math_fround($126 * $126);
  $128 = (($q) + 4|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = Math_fround($129 * $129);
  $131 = Math_fround($127 + $130);
  $132 = (($q) + 8|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = Math_fround($133 * $133);
  $135 = Math_fround($131 + $134);
  $136 = (($q) + 12|0);
  $137 = Math_fround(HEAPF32[$136>>2]);
  $138 = Math_fround($137 * $137);
  $139 = Math_fround($135 + $138);
  $140 = (Math_fround(Math_sqrt((Math_fround($139)))));
  $141 = Math_fround(HEAPF32[616648>>2]);
  $142 = $140 < $141;
  if ($142) {
   $150 = Math_fround(0.0);$153 = Math_fround(0.0);$157 = Math_fround(0.0);$161 = Math_fround(1.0);
  } else {
   $143 = Math_fround($126 / $140);
   $144 = Math_fround($129 / $140);
   $145 = Math_fround($133 / $140);
   $146 = Math_fround($137 / $140);
   $150 = $143;$153 = $144;$157 = $145;$161 = $146;
  }
  $147 = (($this) + 28|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = $148 != $150;
  $$pre = (($this) + 32|0);
  if (!($149)) {
   $151 = Math_fround(HEAPF32[$$pre>>2]);
   $152 = $151 != $153;
   if (!($152)) {
    $154 = (($this) + 36|0);
    $155 = Math_fround(HEAPF32[$154>>2]);
    $156 = $155 != $157;
    if (!($156)) {
     $158 = (($this) + 40|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = $159 != $161;
     if (!($160)) {
      STACKTOP = sp;return;
     }
    }
   }
  }
  HEAPF32[$147>>2] = $150;
  HEAPF32[$$pre>>2] = $153;
  $162 = (($this) + 36|0);
  HEAPF32[$162>>2] = $157;
  $163 = (($this) + 40|0);
  HEAPF32[$163>>2] = $161;
  __ZN9Transform20SendTransformChangedEi($this,2);
  STACKTOP = sp;return;
 }
 $3 = (($1) + 28|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 32|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 36|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($1) + 40|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $cur$0$in1$i = (($1) + 156|0);
 $cur$02$i = HEAP32[$cur$0$in1$i>>2]|0;
 $11 = ($cur$02$i|0)==(0|0);
 if ($11) {
  $54 = $4;$56 = $6;$58 = $8;$61 = $10;
 } else {
  $15 = $4;$19 = $10;$24 = $8;$29 = $6;$cur$03$i = $cur$02$i;
  while(1) {
   $12 = (($cur$03$i) + 40|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = Math_fround($15 * $13);
   $16 = (($cur$03$i) + 28|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround($19 * $17);
   $20 = Math_fround($14 + $18);
   $21 = (($cur$03$i) + 32|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = Math_fround($24 * $22);
   $25 = Math_fround($20 + $23);
   $26 = (($cur$03$i) + 36|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($29 * $27);
   $30 = Math_fround($25 - $28);
   $31 = Math_fround($29 * $13);
   $32 = Math_fround($19 * $22);
   $33 = Math_fround($31 + $32);
   $34 = Math_fround($15 * $27);
   $35 = Math_fround($34 + $33);
   $36 = Math_fround($24 * $17);
   $37 = Math_fround($35 - $36);
   $38 = Math_fround($24 * $13);
   $39 = Math_fround($19 * $27);
   $40 = Math_fround($38 + $39);
   $41 = Math_fround($29 * $17);
   $42 = Math_fround($41 + $40);
   $43 = Math_fround($15 * $22);
   $44 = Math_fround($42 - $43);
   $45 = Math_fround($19 * $13);
   $46 = Math_fround($15 * $17);
   $47 = Math_fround($45 - $46);
   $48 = Math_fround($29 * $22);
   $49 = Math_fround($47 - $48);
   $50 = Math_fround($24 * $27);
   $51 = Math_fround($49 - $50);
   $cur$0$in$i = (($cur$03$i) + 156|0);
   $cur$0$i = HEAP32[$cur$0$in$i>>2]|0;
   $52 = ($cur$0$i|0)==(0|0);
   if ($52) {
    $54 = $30;$56 = $37;$58 = $44;$61 = $51;
    break;
   } else {
    $15 = $30;$19 = $51;$24 = $44;$29 = $37;$cur$03$i = $cur$0$i;
   }
  }
 }
 $53 = Math_fround(-$54);
 $55 = Math_fround(-$56);
 $57 = Math_fround(-$58);
 $59 = Math_fround(HEAPF32[$q>>2]);
 $60 = Math_fround($61 * $59);
 $62 = (($q) + 12|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $53);
 $65 = Math_fround($60 + $64);
 $66 = (($q) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 * $55);
 $69 = Math_fround($65 + $68);
 $70 = (($q) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $57);
 $73 = Math_fround($69 - $72);
 $74 = Math_fround($61 * $71);
 $75 = Math_fround($63 * $55);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($59 * $57);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($67 * $53);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($61 * $67);
 $82 = Math_fround($63 * $57);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($71 * $53);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($59 * $55);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($61 * $63);
 $89 = Math_fround($59 * $53);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($71 * $55);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($67 * $57);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($73 * $73);
 $96 = Math_fround($80 * $80);
 $97 = Math_fround($95 + $96);
 $98 = Math_fround($87 * $87);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($94 * $94);
 $101 = Math_fround($100 + $99);
 $102 = (Math_fround(Math_sqrt((Math_fround($101)))));
 $103 = Math_fround(HEAPF32[616648>>2]);
 $104 = $102 < $103;
 if ($104) {
  $112 = Math_fround(0.0);$115 = Math_fround(0.0);$119 = Math_fround(0.0);$123 = Math_fround(1.0);
 } else {
  $105 = Math_fround($73 / $102);
  $106 = Math_fround($80 / $102);
  $107 = Math_fround($87 / $102);
  $108 = Math_fround($94 / $102);
  $112 = $105;$115 = $106;$119 = $107;$123 = $108;
 }
 $109 = (($this) + 28|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = $110 != $112;
 $$pre27 = (($this) + 32|0);
 if (!($111)) {
  $113 = Math_fround(HEAPF32[$$pre27>>2]);
  $114 = $113 != $115;
  if (!($114)) {
   $116 = (($this) + 36|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = $117 != $119;
   if (!($118)) {
    $120 = (($this) + 40|0);
    $121 = Math_fround(HEAPF32[$120>>2]);
    $122 = $121 != $123;
    if (!($122)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 HEAPF32[$109>>2] = $112;
 HEAPF32[$$pre27>>2] = $115;
 $124 = (($this) + 36|0);
 HEAPF32[$124>>2] = $119;
 $125 = (($this) + 40|0);
 HEAPF32[$125>>2] = $123;
 __ZN9Transform20SendTransformChangedEi($this,2);
 STACKTOP = sp;return;
}
function __ZN9Transform11SetPositionERK8Vector3f($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $newPosition = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $newPosition = sp + 12|0;
 $0 = sp;
 ;HEAP32[$newPosition+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$newPosition+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$newPosition+8>>2]=HEAP32[$p+8>>2]|0;
 $1 = (($this) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZNK9Transform21InverseTransformPointERK8Vector3f($0,$2,$newPosition);
  ;HEAP32[$newPosition+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$newPosition+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$newPosition+8>>2]=HEAP32[$0+8>>2]|0;
 }
 $4 = (($this) + 44|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$newPosition>>2]);
 $7 = $5 != $6;
 if (!($7)) {
  $8 = (($this) + 48|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($newPosition) + 4|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = $9 != $11;
  if (!($12)) {
   $13 = (($this) + 52|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = (($newPosition) + 8|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = $14 != $16;
   if (!($17)) {
    STACKTOP = sp;return;
   }
  }
 }
 ;HEAP32[$4+0>>2]=HEAP32[$newPosition+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$newPosition+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$newPosition+8>>2]|0;
 __ZN9Transform20SendTransformChangedEi($this,1);
 STACKTOP = sp;return;
}
function __ZNK9Transform21InverseTransformPointERK8Vector3f($agg$result,$this,$inPosition) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inPosition = $inPosition|0;
 var $$0$i$i = Math_fround(0), $$0$i2$i = Math_fround(0), $$0$i5$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0);
 var $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0);
 var $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $1 = (($agg$result) + 4|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($agg$result) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $11 = Math_fround(HEAPF32[$inPosition>>2]);
  $12 = (($inPosition) + 4|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($inPosition) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $19 = $11;$23 = $13;$27 = $15;
 } else {
  __ZNK9Transform21InverseTransformPointERK8Vector3f($0,$4,$inPosition);
  $6 = Math_fround(HEAPF32[$0>>2]);
  $7 = (($0) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($0) + 8|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $19 = $6;$23 = $8;$27 = $10;
 }
 $16 = (($this) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($19 - $17);
 $20 = (($this) + 48|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($23 - $21);
 $24 = (($this) + 52|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($27 - $25);
 $28 = (($this) + 28|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround(-$29);
 $31 = (($this) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround(-$32);
 $34 = (($this) + 36|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($this) + 40|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($29 * Math_fround(-2.0));
 $39 = Math_fround($32 * Math_fround(-2.0));
 $40 = Math_fround($35 * Math_fround(-2.0));
 $41 = Math_fround($38 * $30);
 $42 = Math_fround($39 * $33);
 $43 = Math_fround($35 * $40);
 $44 = Math_fround($39 * $30);
 $45 = Math_fround($40 * $30);
 $46 = Math_fround($40 * $33);
 $47 = Math_fround($38 * $37);
 $48 = Math_fround($39 * $37);
 $49 = Math_fround($37 * $40);
 $50 = Math_fround($42 - $43);
 $51 = Math_fround(Math_fround(1.0) - $50);
 $52 = Math_fround($18 * $51);
 $53 = Math_fround($44 - $49);
 $54 = Math_fround($22 * $53);
 $55 = Math_fround($54 + $52);
 $56 = Math_fround($45 + $48);
 $57 = Math_fround($26 * $56);
 $58 = Math_fround($57 + $55);
 $59 = Math_fround($44 + $49);
 $60 = Math_fround($18 * $59);
 $61 = Math_fround($41 - $43);
 $62 = Math_fround(Math_fround(1.0) - $61);
 $63 = Math_fround($22 * $62);
 $64 = Math_fround($60 + $63);
 $65 = Math_fround($46 - $47);
 $66 = Math_fround($26 * $65);
 $67 = Math_fround($66 + $64);
 $68 = Math_fround($45 - $48);
 $69 = Math_fround($18 * $68);
 $70 = Math_fround($46 + $47);
 $71 = Math_fround($22 * $70);
 $72 = Math_fround($69 + $71);
 $73 = Math_fround($41 + $42);
 $74 = Math_fround(Math_fround(1.0) - $73);
 $75 = Math_fround($26 * $74);
 $76 = Math_fround($75 + $72);
 HEAPF32[$agg$result>>2] = $58;
 HEAPF32[$1>>2] = $67;
 HEAPF32[$2>>2] = $76;
 $77 = (($this) + 136|0);
 $78 = HEAP8[$77>>0]|0;
 $79 = ($78<<24>>24)==(0);
 if ($79) {
  STACKTOP = sp;return;
 }
 $80 = (($this) + 56|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = $81 < Math_fround(0.0);
 if ($82) {
  $83 = Math_fround(-$81);
  $86 = $83;
 } else {
  $86 = $81;
 }
 $84 = Math_fround(HEAPF32[616648>>2]);
 $85 = $86 > $84;
 if ($85) {
  $87 = Math_fround(Math_fround(1.0) / $81);
  $$0$i$i = $87;
 } else {
  $$0$i$i = Math_fround(0.0);
 }
 $88 = (($this) + 60|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = $89 < Math_fround(0.0);
 if ($90) {
  $91 = Math_fround(-$89);
  $93 = $91;
 } else {
  $93 = $89;
 }
 $92 = $93 > $84;
 if ($92) {
  $94 = Math_fround(Math_fround(1.0) / $89);
  $$0$i5$i = $94;
 } else {
  $$0$i5$i = Math_fround(0.0);
 }
 $95 = (($this) + 64|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = $96 < Math_fround(0.0);
 if ($97) {
  $98 = Math_fround(-$96);
  $100 = $98;
 } else {
  $100 = $96;
 }
 $99 = $100 > $84;
 if ($99) {
  $101 = Math_fround(Math_fround(1.0) / $96);
  $$0$i2$i = $101;
 } else {
  $$0$i2$i = Math_fround(0.0);
 }
 $102 = Math_fround($$0$i$i * $58);
 HEAPF32[$agg$result>>2] = $102;
 $103 = Math_fround($$0$i5$i * $67);
 HEAPF32[$1>>2] = $103;
 $104 = Math_fround($$0$i2$i * $76);
 HEAPF32[$2>>2] = $104;
 STACKTOP = sp;return;
}
function __ZN9Transform26SetPositionWithLocalOffsetERK8Vector3fS2_($this,$p,$localOffset) {
 $this = $this|0;
 $p = $p|0;
 $localOffset = $localOffset|0;
 var $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0);
 var $8 = 0, $9 = Math_fround(0), $newPosition$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $newPosition$i = sp + 36|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = sp + 24|0;
 __ZNK9Transform14TransformPointERK8Vector3f($1,$this,$localOffset);
 $3 = Math_fround(HEAPF32[$p>>2]);
 $4 = Math_fround(HEAPF32[$1>>2]);
 $5 = Math_fround($3 - $4);
 $6 = (($p) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($1) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 - $9);
 $11 = (($p) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($1) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 - $14);
 __ZNK9Transform11GetPositionEv($2,$this);
 $16 = Math_fround(HEAPF32[$2>>2]);
 $17 = Math_fround($5 + $16);
 $18 = (($2) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($10 + $19);
 $21 = (($2) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($15 + $22);
 HEAPF32[$newPosition$i>>2] = $17;
 $24 = (($newPosition$i) + 4|0);
 HEAPF32[$24>>2] = $20;
 $25 = (($newPosition$i) + 8|0);
 HEAPF32[$25>>2] = $23;
 $26 = (($this) + 156|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $32 = $17;
 } else {
  __ZNK9Transform21InverseTransformPointERK8Vector3f($0,$27,$newPosition$i);
  ;HEAP32[$newPosition$i+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$newPosition$i+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$newPosition$i+8>>2]=HEAP32[$0+8>>2]|0;
  $$pre = Math_fround(HEAPF32[$newPosition$i>>2]);
  $32 = $$pre;
 }
 $29 = (($this) + 44|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = $30 != $32;
 if (!($31)) {
  $33 = (($this) + 48|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround(HEAPF32[$24>>2]);
  $36 = $34 != $35;
  if (!($36)) {
   $37 = (($this) + 52|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround(HEAPF32[$25>>2]);
   $40 = $38 != $39;
   if (!($40)) {
    STACKTOP = sp;return;
   }
  }
 }
 ;HEAP32[$29+0>>2]=HEAP32[$newPosition$i+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[$newPosition$i+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$newPosition$i+8>>2]|0;
 __ZN9Transform20SendTransformChangedEi($this,1);
 STACKTOP = sp;return;
}
function __ZNK9Transform14TransformPointERK8Vector3f($agg$result,$this,$inPoint) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inPoint = $inPoint|0;
 var $$promoted = Math_fround(0), $$promoted2 = Math_fround(0), $$promoted3 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $cur$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=HEAP32[$inPoint+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$inPoint+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$inPoint+8>>2]|0;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($agg$result) + 4|0);
 $2 = (($agg$result) + 8|0);
 $$promoted = Math_fround(HEAPF32[$agg$result>>2]);
 $$promoted2 = Math_fround(HEAPF32[$1>>2]);
 $$promoted3 = Math_fround(HEAPF32[$2>>2]);
 $10 = $$promoted2;$14 = $$promoted3;$6 = $$promoted;$cur$01 = $this;
 while(1) {
  $3 = (($cur$01) + 56|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = Math_fround($4 * $6);
  $7 = (($cur$01) + 60|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround($8 * $10);
  $11 = (($cur$01) + 64|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($12 * $14);
  $15 = (($cur$01) + 28|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($16 * Math_fround(2.0));
  $18 = (($cur$01) + 32|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($19 * Math_fround(2.0));
  $21 = (($cur$01) + 36|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($22 * Math_fround(2.0));
  $24 = Math_fround($16 * $17);
  $25 = Math_fround($19 * $20);
  $26 = Math_fround($22 * $23);
  $27 = Math_fround($16 * $20);
  $28 = Math_fround($16 * $23);
  $29 = Math_fround($19 * $23);
  $30 = (($cur$01) + 40|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($17 * $31);
  $33 = Math_fround($20 * $31);
  $34 = Math_fround($31 * $23);
  $35 = Math_fround($25 + $26);
  $36 = Math_fround(Math_fround(1.0) - $35);
  $37 = Math_fround($5 * $36);
  $38 = Math_fround($27 - $34);
  $39 = Math_fround($38 * $9);
  $40 = Math_fround($39 + $37);
  $41 = Math_fround($28 + $33);
  $42 = Math_fround($13 * $41);
  $43 = Math_fround($42 + $40);
  $44 = Math_fround($27 + $34);
  $45 = Math_fround($5 * $44);
  $46 = Math_fround($24 + $26);
  $47 = Math_fround(Math_fround(1.0) - $46);
  $48 = Math_fround($9 * $47);
  $49 = Math_fround($45 + $48);
  $50 = Math_fround($29 - $32);
  $51 = Math_fround($13 * $50);
  $52 = Math_fround($51 + $49);
  $53 = Math_fround($28 - $33);
  $54 = Math_fround($5 * $53);
  $55 = Math_fround($29 + $32);
  $56 = Math_fround($55 * $9);
  $57 = Math_fround($54 + $56);
  $58 = Math_fround($24 + $25);
  $59 = Math_fround(Math_fround(1.0) - $58);
  $60 = Math_fround($13 * $59);
  $61 = Math_fround($60 + $57);
  $62 = (($cur$01) + 44|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($63 + $43);
  $65 = (($cur$01) + 48|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = Math_fround($66 + $52);
  $68 = (($cur$01) + 52|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($69 + $61);
  $71 = (($cur$01) + 156|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  if ($73) {
   break;
  } else {
   $10 = $67;$14 = $70;$6 = $64;$cur$01 = $72;
  }
 }
 HEAPF32[$agg$result>>2] = $64;
 HEAPF32[$1>>2] = $67;
 HEAPF32[$2>>2] = $70;
 STACKTOP = sp;return;
}
function __ZN9Transform13SetLocalScaleERK8Vector3f($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $5 = 0;
 var $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$scale>>2]);
 $3 = $1 != $2;
 $$pre = (($this) + 60|0);
 if (!($3)) {
  $4 = Math_fround(HEAPF32[$$pre>>2]);
  $5 = (($scale) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = $4 != $6;
  if (!($7)) {
   $8 = (($this) + 64|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = (($scale) + 8|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = $9 != $11;
   if (!($12)) {
    STACKTOP = sp;return;
   }
  }
 }
 ;HEAP32[$0+0>>2]=HEAP32[$scale+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$scale+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$scale+8>>2]|0;
 $13 = (($this) + 56|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround(HEAPF32[$$pre>>2]);
 $16 = Math_fround($14 - $15);
 $17 = $16 < Math_fround(0.0);
 if ($17) {
  $18 = Math_fround(-$16);
  $20 = $18;
 } else {
  $20 = $16;
 }
 $19 = !($20 <= Math_fround(9.99999974737875163555E-5));
 $$phi$trans$insert$i = (($this) + 64|0);
 $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
 do {
  if ($19) {
   label = 16;
  } else {
   $21 = Math_fround($15 - $$pre$i);
   $22 = $21 < Math_fround(0.0);
   if ($22) {
    $23 = Math_fround(-$21);
    $25 = $23;
   } else {
    $25 = $21;
   }
   $24 = !($25 <= Math_fround(9.99999974737875163555E-5));
   if ($24) {
    label = 16;
   } else {
    $26 = Math_fround($14 + Math_fround(-1.0));
    $27 = $26 < Math_fround(0.0);
    if ($27) {
     $28 = Math_fround(-$26);
     $30 = $28;
    } else {
     $30 = $26;
    }
    $29 = !($30 <= Math_fround(9.99999974737875163555E-5));
    $31 = (($this) + 136|0);
    if (!($29)) {
     HEAP8[$31>>0] = 0;
     break;
    }
    HEAP8[$31>>0] = 1;
    $32 = $14 < Math_fround(0.0);
    if ($32) {
     HEAP8[$31>>0] = 6;
    }
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $33 = (($this) + 136|0);
  $34 = Math_fround($14 * $15);
  $35 = Math_fround($34 * $$pre$i);
  $36 = $35 < Math_fround(0.0);
  $37 = $36&1;
  $38 = $37 << 2;
  $39 = $38 | 2;
  $40 = $39&255;
  HEAP8[$33>>0] = $40;
 }
 __ZN9Transform20SendTransformChangedEi($this,11);
 STACKTOP = sp;return;
}
function __ZN9Transform30SetPositionAndRotationInternalILb1ELb0EEEvRK8Vector3fRK11Quaternionf($this,$p,$q) {
 $this = $this|0;
 $p = $p|0;
 $q = $q|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0);
 var $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $cur$0$i = 0, $cur$0$in$i = 0, $cur$0$in1$i = 0, $cur$02$i = 0, $cur$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = (($this) + 44|0);
 if ($3) {
  ;HEAP32[$4+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$p+8>>2]|0;
  $119 = Math_fround(HEAPF32[$q>>2]);
  $120 = Math_fround($119 * $119);
  $121 = (($q) + 4|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround($122 * $122);
  $124 = Math_fround($120 + $123);
  $125 = (($q) + 8|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = Math_fround($126 * $126);
  $128 = Math_fround($124 + $127);
  $129 = (($q) + 12|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($130 * $130);
  $132 = Math_fround($128 + $131);
  $133 = (Math_fround(Math_sqrt((Math_fround($132)))));
  $134 = Math_fround(HEAPF32[616648>>2]);
  $135 = $133 < $134;
  if ($135) {
   $141 = Math_fround(0.0);$143 = Math_fround(0.0);$145 = Math_fround(0.0);$147 = Math_fround(1.0);
  } else {
   $136 = Math_fround($119 / $133);
   $137 = Math_fround($122 / $133);
   $138 = Math_fround($126 / $133);
   $139 = Math_fround($130 / $133);
   $141 = $136;$143 = $137;$145 = $138;$147 = $139;
  }
  $140 = (($this) + 28|0);
  HEAPF32[$140>>2] = $141;
  $142 = (($this) + 32|0);
  HEAPF32[$142>>2] = $143;
  $144 = (($this) + 36|0);
  HEAPF32[$144>>2] = $145;
  $146 = (($this) + 40|0);
  HEAPF32[$146>>2] = $147;
  STACKTOP = sp;return;
 }
 __ZNK9Transform21InverseTransformPointERK8Vector3f($0,$2,$p);
 ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;
 $5 = (($2) + 28|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($2) + 32|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($2) + 36|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($2) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $cur$0$in1$i = (($2) + 156|0);
 $cur$02$i = HEAP32[$cur$0$in1$i>>2]|0;
 $13 = ($cur$02$i|0)==(0|0);
 if ($13) {
  $56 = $6;$58 = $8;$60 = $10;$63 = $12;
 } else {
  $17 = $6;$21 = $12;$26 = $10;$31 = $8;$cur$03$i = $cur$02$i;
  while(1) {
   $14 = (($cur$03$i) + 40|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($17 * $15);
   $18 = (($cur$03$i) + 28|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround($21 * $19);
   $22 = Math_fround($16 + $20);
   $23 = (($cur$03$i) + 32|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($26 * $24);
   $27 = Math_fround($22 + $25);
   $28 = (($cur$03$i) + 36|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($31 * $29);
   $32 = Math_fround($27 - $30);
   $33 = Math_fround($31 * $15);
   $34 = Math_fround($21 * $24);
   $35 = Math_fround($33 + $34);
   $36 = Math_fround($17 * $29);
   $37 = Math_fround($36 + $35);
   $38 = Math_fround($26 * $19);
   $39 = Math_fround($37 - $38);
   $40 = Math_fround($26 * $15);
   $41 = Math_fround($21 * $29);
   $42 = Math_fround($40 + $41);
   $43 = Math_fround($31 * $19);
   $44 = Math_fround($43 + $42);
   $45 = Math_fround($17 * $24);
   $46 = Math_fround($44 - $45);
   $47 = Math_fround($21 * $15);
   $48 = Math_fround($17 * $19);
   $49 = Math_fround($47 - $48);
   $50 = Math_fround($31 * $24);
   $51 = Math_fround($49 - $50);
   $52 = Math_fround($26 * $29);
   $53 = Math_fround($51 - $52);
   $cur$0$in$i = (($cur$03$i) + 156|0);
   $cur$0$i = HEAP32[$cur$0$in$i>>2]|0;
   $54 = ($cur$0$i|0)==(0|0);
   if ($54) {
    $56 = $32;$58 = $39;$60 = $46;$63 = $53;
    break;
   } else {
    $17 = $32;$21 = $53;$26 = $46;$31 = $39;$cur$03$i = $cur$0$i;
   }
  }
 }
 $55 = Math_fround(-$56);
 $57 = Math_fround(-$58);
 $59 = Math_fround(-$60);
 $61 = Math_fround(HEAPF32[$q>>2]);
 $62 = Math_fround($63 * $61);
 $64 = (($q) + 12|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 * $55);
 $67 = Math_fround($62 + $66);
 $68 = (($q) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 * $57);
 $71 = Math_fround($67 + $70);
 $72 = (($q) + 4|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 * $59);
 $75 = Math_fround($71 - $74);
 $76 = Math_fround($63 * $73);
 $77 = Math_fround($65 * $57);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($61 * $59);
 $80 = Math_fround($79 + $78);
 $81 = Math_fround($69 * $55);
 $82 = Math_fround($80 - $81);
 $83 = Math_fround($63 * $69);
 $84 = Math_fround($65 * $59);
 $85 = Math_fround($84 + $83);
 $86 = Math_fround($73 * $55);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($61 * $57);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($63 * $65);
 $91 = Math_fround($61 * $55);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($73 * $57);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($69 * $59);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($75 * $75);
 $98 = Math_fround($82 * $82);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($89 * $89);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($96 * $96);
 $103 = Math_fround($102 + $101);
 $104 = (Math_fround(Math_sqrt((Math_fround($103)))));
 $105 = Math_fround(HEAPF32[616648>>2]);
 $106 = $104 < $105;
 if ($106) {
  $112 = Math_fround(0.0);$114 = Math_fround(0.0);$116 = Math_fround(0.0);$118 = Math_fround(1.0);
 } else {
  $107 = Math_fround($75 / $104);
  $108 = Math_fround($82 / $104);
  $109 = Math_fround($89 / $104);
  $110 = Math_fround($96 / $104);
  $112 = $107;$114 = $108;$116 = $109;$118 = $110;
 }
 $111 = (($this) + 28|0);
 HEAPF32[$111>>2] = $112;
 $113 = (($this) + 32|0);
 HEAPF32[$113>>2] = $114;
 $115 = (($this) + 36|0);
 HEAPF32[$115>>2] = $116;
 $117 = (($this) + 40|0);
 HEAPF32[$117>>2] = $118;
 STACKTOP = sp;return;
}
function __ZN9Transform26SetPositionAndRotationSafeERK8Vector3fRK11Quaternionf($this,$p,$q) {
 $this = $this|0;
 $p = $p|0;
 $q = $q|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Transform30SetPositionAndRotationInternalILb1ELb1EEEvRK8Vector3fRK11Quaternionf($this,$p,$q);
 STACKTOP = sp;return;
}
function __ZN9Transform30SetPositionAndRotationInternalILb1ELb1EEEvRK8Vector3fRK11Quaternionf($this,$p,$q) {
 $this = $this|0;
 $p = $p|0;
 $q = $q|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0);
 var $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $cur$0$i = 0, $cur$0$in$i = 0, $cur$0$in1$i = 0, $cur$02$i = 0, $cur$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = (($this) + 44|0);
 if ($3) {
  ;HEAP32[$4+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$p+8>>2]|0;
  $119 = Math_fround(HEAPF32[$q>>2]);
  $120 = Math_fround($119 * $119);
  $121 = (($q) + 4|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = Math_fround($122 * $122);
  $124 = Math_fround($120 + $123);
  $125 = (($q) + 8|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = Math_fround($126 * $126);
  $128 = Math_fround($124 + $127);
  $129 = (($q) + 12|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = Math_fround($130 * $130);
  $132 = Math_fround($128 + $131);
  $133 = (Math_fround(Math_sqrt((Math_fround($132)))));
  $134 = Math_fround(HEAPF32[616648>>2]);
  $135 = $133 < $134;
  if ($135) {
   $141 = Math_fround(0.0);$143 = Math_fround(0.0);$145 = Math_fround(0.0);$147 = Math_fround(1.0);
  } else {
   $136 = Math_fround($119 / $133);
   $137 = Math_fround($122 / $133);
   $138 = Math_fround($126 / $133);
   $139 = Math_fround($130 / $133);
   $141 = $136;$143 = $137;$145 = $138;$147 = $139;
  }
  $140 = (($this) + 28|0);
  HEAPF32[$140>>2] = $141;
  $142 = (($this) + 32|0);
  HEAPF32[$142>>2] = $143;
  $144 = (($this) + 36|0);
  HEAPF32[$144>>2] = $145;
  $146 = (($this) + 40|0);
  HEAPF32[$146>>2] = $147;
  __ZN9Transform20SendTransformChangedEi($this,3);
  STACKTOP = sp;return;
 }
 __ZNK9Transform21InverseTransformPointERK8Vector3f($0,$2,$p);
 ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;
 $5 = (($2) + 28|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($2) + 32|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($2) + 36|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($2) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $cur$0$in1$i = (($2) + 156|0);
 $cur$02$i = HEAP32[$cur$0$in1$i>>2]|0;
 $13 = ($cur$02$i|0)==(0|0);
 if ($13) {
  $56 = $6;$58 = $8;$60 = $10;$63 = $12;
 } else {
  $17 = $6;$21 = $12;$26 = $10;$31 = $8;$cur$03$i = $cur$02$i;
  while(1) {
   $14 = (($cur$03$i) + 40|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($17 * $15);
   $18 = (($cur$03$i) + 28|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround($21 * $19);
   $22 = Math_fround($16 + $20);
   $23 = (($cur$03$i) + 32|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($26 * $24);
   $27 = Math_fround($22 + $25);
   $28 = (($cur$03$i) + 36|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($31 * $29);
   $32 = Math_fround($27 - $30);
   $33 = Math_fround($31 * $15);
   $34 = Math_fround($21 * $24);
   $35 = Math_fround($33 + $34);
   $36 = Math_fround($17 * $29);
   $37 = Math_fround($36 + $35);
   $38 = Math_fround($26 * $19);
   $39 = Math_fround($37 - $38);
   $40 = Math_fround($26 * $15);
   $41 = Math_fround($21 * $29);
   $42 = Math_fround($40 + $41);
   $43 = Math_fround($31 * $19);
   $44 = Math_fround($43 + $42);
   $45 = Math_fround($17 * $24);
   $46 = Math_fround($44 - $45);
   $47 = Math_fround($21 * $15);
   $48 = Math_fround($17 * $19);
   $49 = Math_fround($47 - $48);
   $50 = Math_fround($31 * $24);
   $51 = Math_fround($49 - $50);
   $52 = Math_fround($26 * $29);
   $53 = Math_fround($51 - $52);
   $cur$0$in$i = (($cur$03$i) + 156|0);
   $cur$0$i = HEAP32[$cur$0$in$i>>2]|0;
   $54 = ($cur$0$i|0)==(0|0);
   if ($54) {
    $56 = $32;$58 = $39;$60 = $46;$63 = $53;
    break;
   } else {
    $17 = $32;$21 = $53;$26 = $46;$31 = $39;$cur$03$i = $cur$0$i;
   }
  }
 }
 $55 = Math_fround(-$56);
 $57 = Math_fround(-$58);
 $59 = Math_fround(-$60);
 $61 = Math_fround(HEAPF32[$q>>2]);
 $62 = Math_fround($63 * $61);
 $64 = (($q) + 12|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 * $55);
 $67 = Math_fround($62 + $66);
 $68 = (($q) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 * $57);
 $71 = Math_fround($67 + $70);
 $72 = (($q) + 4|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 * $59);
 $75 = Math_fround($71 - $74);
 $76 = Math_fround($63 * $73);
 $77 = Math_fround($65 * $57);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($61 * $59);
 $80 = Math_fround($79 + $78);
 $81 = Math_fround($69 * $55);
 $82 = Math_fround($80 - $81);
 $83 = Math_fround($63 * $69);
 $84 = Math_fround($65 * $59);
 $85 = Math_fround($84 + $83);
 $86 = Math_fround($73 * $55);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($61 * $57);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($63 * $65);
 $91 = Math_fround($61 * $55);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($73 * $57);
 $94 = Math_fround($92 - $93);
 $95 = Math_fround($69 * $59);
 $96 = Math_fround($94 - $95);
 $97 = Math_fround($75 * $75);
 $98 = Math_fround($82 * $82);
 $99 = Math_fround($97 + $98);
 $100 = Math_fround($89 * $89);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($96 * $96);
 $103 = Math_fround($102 + $101);
 $104 = (Math_fround(Math_sqrt((Math_fround($103)))));
 $105 = Math_fround(HEAPF32[616648>>2]);
 $106 = $104 < $105;
 if ($106) {
  $112 = Math_fround(0.0);$114 = Math_fround(0.0);$116 = Math_fround(0.0);$118 = Math_fround(1.0);
 } else {
  $107 = Math_fround($75 / $104);
  $108 = Math_fround($82 / $104);
  $109 = Math_fround($89 / $104);
  $110 = Math_fround($96 / $104);
  $112 = $107;$114 = $108;$116 = $109;$118 = $110;
 }
 $111 = (($this) + 28|0);
 HEAPF32[$111>>2] = $112;
 $113 = (($this) + 32|0);
 HEAPF32[$113>>2] = $114;
 $115 = (($this) + 36|0);
 HEAPF32[$115>>2] = $116;
 $117 = (($this) + 40|0);
 HEAPF32[$117>>2] = $118;
 __ZN9Transform20SendTransformChangedEi($this,3);
 STACKTOP = sp;return;
}
function __ZN9Transform30SetPositionWithoutNotificationERK8Vector3f($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = (($this) + 44|0);
 if ($3) {
  ;HEAP32[$4+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$p+8>>2]|0;
  STACKTOP = sp;return;
 } else {
  __ZNK9Transform21InverseTransformPointERK8Vector3f($0,$2,$p);
  ;HEAP32[$4+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$0+8>>2]|0;
  STACKTOP = sp;return;
 }
}
function __ZN9Transform30SetRotationWithoutNotificationERK11Quaternionf($this,$q) {
 $this = $this|0;
 $q = $q|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $cur$0$i = 0, $cur$0$in$i = 0, $cur$0$in1$i = 0, $cur$02$i = 0, $cur$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $99 = (($this) + 28|0);
  ;HEAP32[$99+0>>2]=HEAP32[$q+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$q+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$q+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$q+12>>2]|0;
  STACKTOP = sp;return;
 }
 $3 = (($1) + 28|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 32|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 36|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($1) + 40|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $cur$0$in1$i = (($1) + 156|0);
 $cur$02$i = HEAP32[$cur$0$in1$i>>2]|0;
 $11 = ($cur$02$i|0)==(0|0);
 if ($11) {
  $54 = $4;$56 = $6;$58 = $8;$61 = $10;
 } else {
  $15 = $4;$19 = $10;$24 = $8;$29 = $6;$cur$03$i = $cur$02$i;
  while(1) {
   $12 = (($cur$03$i) + 40|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = Math_fround($15 * $13);
   $16 = (($cur$03$i) + 28|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround($19 * $17);
   $20 = Math_fround($14 + $18);
   $21 = (($cur$03$i) + 32|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = Math_fround($24 * $22);
   $25 = Math_fround($20 + $23);
   $26 = (($cur$03$i) + 36|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($29 * $27);
   $30 = Math_fround($25 - $28);
   $31 = Math_fround($29 * $13);
   $32 = Math_fround($19 * $22);
   $33 = Math_fround($31 + $32);
   $34 = Math_fround($15 * $27);
   $35 = Math_fround($34 + $33);
   $36 = Math_fround($24 * $17);
   $37 = Math_fround($35 - $36);
   $38 = Math_fround($24 * $13);
   $39 = Math_fround($19 * $27);
   $40 = Math_fround($38 + $39);
   $41 = Math_fround($29 * $17);
   $42 = Math_fround($41 + $40);
   $43 = Math_fround($15 * $22);
   $44 = Math_fround($42 - $43);
   $45 = Math_fround($19 * $13);
   $46 = Math_fround($15 * $17);
   $47 = Math_fround($45 - $46);
   $48 = Math_fround($29 * $22);
   $49 = Math_fround($47 - $48);
   $50 = Math_fround($24 * $27);
   $51 = Math_fround($49 - $50);
   $cur$0$in$i = (($cur$03$i) + 156|0);
   $cur$0$i = HEAP32[$cur$0$in$i>>2]|0;
   $52 = ($cur$0$i|0)==(0|0);
   if ($52) {
    $54 = $30;$56 = $37;$58 = $44;$61 = $51;
    break;
   } else {
    $15 = $30;$19 = $51;$24 = $44;$29 = $37;$cur$03$i = $cur$0$i;
   }
  }
 }
 $53 = Math_fround(-$54);
 $55 = Math_fround(-$56);
 $57 = Math_fround(-$58);
 $59 = Math_fround(HEAPF32[$q>>2]);
 $60 = Math_fround($61 * $59);
 $62 = (($q) + 12|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 * $53);
 $65 = Math_fround($60 + $64);
 $66 = (($q) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 * $55);
 $69 = Math_fround($65 + $68);
 $70 = (($q) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $57);
 $73 = Math_fround($69 - $72);
 $74 = Math_fround($61 * $71);
 $75 = Math_fround($63 * $55);
 $76 = Math_fround($75 + $74);
 $77 = Math_fround($59 * $57);
 $78 = Math_fround($77 + $76);
 $79 = Math_fround($67 * $53);
 $80 = Math_fround($78 - $79);
 $81 = Math_fround($61 * $67);
 $82 = Math_fround($63 * $57);
 $83 = Math_fround($82 + $81);
 $84 = Math_fround($71 * $53);
 $85 = Math_fround($83 + $84);
 $86 = Math_fround($59 * $55);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($61 * $63);
 $89 = Math_fround($59 * $53);
 $90 = Math_fround($88 - $89);
 $91 = Math_fround($71 * $55);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($67 * $57);
 $94 = Math_fround($92 - $93);
 $95 = (($this) + 28|0);
 HEAPF32[$95>>2] = $73;
 $96 = (($this) + 32|0);
 HEAPF32[$96>>2] = $80;
 $97 = (($this) + 36|0);
 HEAPF32[$97>>2] = $87;
 $98 = (($this) + 40|0);
 HEAPF32[$98>>2] = $94;
 STACKTOP = sp;return;
}
function __ZN9Transform44SetLocalPositionOnCompareWithoutNotificationERK8Vector3f($this,$position) {
 $this = $this|0;
 $position = $position|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = Math_fround(HEAPF32[616648>>2]);
 $2 = Math_fround(HEAPF32[$position>>2]);
 $3 = Math_fround(HEAPF32[$0>>2]);
 $4 = Math_fround($2 - $3);
 $5 = (($position) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 48|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($position) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 52|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * $4);
 $16 = Math_fround($9 * $9);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($14 * $14);
 $19 = Math_fround($17 + $18);
 $20 = Math_fround($1 * $1);
 $21 = !($19 <= $20);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$0+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$position+8>>2]|0;
 $22 = (($this) + 135|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 | 1;
 $26 = $25&255;
 HEAP8[$22>>0] = $26;
 STACKTOP = sp;return;
}
function __ZN9Transform44SetLocalRotationOnCompareWithoutNotificationERK11Quaternionf($this,$rotation) {
 $this = $this|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = Math_fround(HEAPF32[616648>>2]);
 $2 = Math_fround(HEAPF32[$0>>2]);
 $3 = (($this) + 32|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($this) + 36|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 40|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(HEAPF32[$rotation>>2]);
 $10 = Math_fround($2 - $9);
 $11 = (($rotation) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($4 - $12);
 $14 = (($rotation) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($6 - $15);
 $17 = (($rotation) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($8 - $18);
 $20 = Math_fround($10 * $10);
 $21 = Math_fround($13 * $13);
 $22 = Math_fround($20 + $21);
 $23 = Math_fround($16 * $16);
 $24 = Math_fround($22 + $23);
 $25 = Math_fround($19 * $19);
 $26 = Math_fround($24 + $25);
 $27 = Math_fround($1 * $1);
 $28 = !($26 <= $27);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $29 = Math_fround($2 + $9);
 $30 = Math_fround($4 + $12);
 $31 = Math_fround($6 + $15);
 $32 = Math_fround($8 + $18);
 $33 = Math_fround($29 * $29);
 $34 = Math_fround($30 * $30);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($31 * $31);
 $37 = Math_fround($35 + $36);
 $38 = Math_fround($32 * $32);
 $39 = Math_fround($37 + $38);
 $40 = !($39 <= $27);
 if (!($40)) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$0+0>>2]=HEAP32[$rotation+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$rotation+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$rotation+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$rotation+12>>2]|0;
 $41 = (($this) + 135|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = $42&255;
 $44 = $43 | 2;
 $45 = $44&255;
 HEAP8[$41>>0] = $45;
 STACKTOP = sp;return;
}
function __ZN9Transform41SetLocalScaleOnCompareWithoutNotificationERK8Vector3f($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $$pre$i$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[616648>>2]);
 $2 = Math_fround(HEAPF32[$scale>>2]);
 $3 = Math_fround(HEAPF32[$0>>2]);
 $4 = Math_fround($2 - $3);
 $5 = (($scale) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 60|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($scale) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 64|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * $4);
 $16 = Math_fround($9 * $9);
 $17 = Math_fround($15 + $16);
 $18 = Math_fround($14 * $14);
 $19 = Math_fround($17 + $18);
 $20 = Math_fround($1 * $1);
 $21 = !($19 <= $20);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$0+0>>2]=HEAP32[$scale+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$scale+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$scale+8>>2]|0;
 $22 = (($this) + 135|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 | 8;
 $26 = $25&255;
 HEAP8[$22>>0] = $26;
 $27 = (($this) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$7>>2]);
 $30 = Math_fround($28 - $29);
 $31 = $30 < Math_fround(0.0);
 if ($31) {
  $32 = Math_fround(-$30);
  $34 = $32;
 } else {
  $34 = $30;
 }
 $33 = !($34 <= Math_fround(9.99999974737875163555E-5));
 $$pre$i$i = Math_fround(HEAPF32[$12>>2]);
 if (!($33)) {
  $35 = Math_fround($29 - $$pre$i$i);
  $36 = $35 < Math_fround(0.0);
  if ($36) {
   $37 = Math_fround(-$35);
   $39 = $37;
  } else {
   $39 = $35;
  }
  $38 = !($39 <= Math_fround(9.99999974737875163555E-5));
  if (!($38)) {
   $40 = Math_fround($28 + Math_fround(-1.0));
   $41 = $40 < Math_fround(0.0);
   if ($41) {
    $42 = Math_fround(-$40);
    $44 = $42;
   } else {
    $44 = $40;
   }
   $43 = !($44 <= Math_fround(9.99999974737875163555E-5));
   $45 = (($this) + 136|0);
   if (!($43)) {
    HEAP8[$45>>0] = 0;
    STACKTOP = sp;return;
   }
   HEAP8[$45>>0] = 1;
   $46 = $28 < Math_fround(0.0);
   if (!($46)) {
    STACKTOP = sp;return;
   }
   HEAP8[$45>>0] = 6;
   STACKTOP = sp;return;
  }
 }
 $47 = (($this) + 136|0);
 $48 = Math_fround($28 * $29);
 $49 = Math_fround($48 * $$pre$i$i);
 $50 = $49 < Math_fround(0.0);
 $51 = $50&1;
 $52 = $51 << 2;
 $53 = $52 | 2;
 $54 = $53&255;
 HEAP8[$47>>0] = $54;
 STACKTOP = sp;return;
}
function __ZN9Transform26CalculateSupportedMessagesEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN5Unity10GameObject17WillHandleMessageERK17MessageIdentifier($1,564104)|0);
 $$ = $2 ? 8 : 0;
 STACKTOP = sp;return ($$|0);
}
function __ZN9Transform26SupportedMessagesDidChangeEi($this,$mask) {
 $this = $this|0;
 $mask = $mask|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $mask & 8;
 $1 = $0&255;
 $2 = (($this) + 137|0);
 HEAP8[$2>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN9Transform40SendTransformChangedToModifiedTransformsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 135|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $12 = $1&255;
  __ZN9Transform20SendTransformChangedEi($this,$12);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $4;
 }
 while(1) {
  $9 = HEAP32[$i$01>>2]|0;
  __ZN9Transform40SendTransformChangedToModifiedTransformsEv($9);
  $10 = (($i$01) + 4|0);
  $11 = ($10|0)==($7|0);
  if ($11) {
   break;
  } else {
   $i$01 = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Transform19BroadcastMessageAnyERK17MessageIdentifierR11MessageData($this,$messageID,$data) {
 $this = $this|0;
 $messageID = $messageID|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData($1,$messageID,$data);
 }
 $3 = (($this) + 140|0);
 $4 = (($this) + 148|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$3>>2]|0;
 $i$01 = $7;
 while(1) {
  $8 = HEAP32[$i$01>>2]|0;
  __ZN9Transform19BroadcastMessageAnyERK17MessageIdentifierR11MessageData($8,$messageID,$data);
  $9 = (($i$01) + 4|0);
  $10 = HEAP32[$3>>2]|0;
  $11 = HEAP32[$4>>2]|0;
  $12 = (($10) + ($11<<2)|0);
  $13 = ($9|0)==($12|0);
  if ($13) {
   break;
  } else {
   $i$01 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK9Transform25InverseTransformDirectionERK8Vector3f($agg$result,$this,$inDirection) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inDirection = $inDirection|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $cur$0$i = 0, $cur$0$in$i = 0, $cur$0$in1$i = 0, $cur$02$i = 0, $cur$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 32|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 36|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 40|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $cur$0$in1$i = (($this) + 156|0);
 $cur$02$i = HEAP32[$cur$0$in1$i>>2]|0;
 $8 = ($cur$02$i|0)==(0|0);
 if ($8) {
  $51 = $1;$53 = $3;$57 = $5;$65 = $7;
 } else {
  $12 = $1;$16 = $7;$21 = $5;$26 = $3;$cur$03$i = $cur$02$i;
  while(1) {
   $9 = (($cur$03$i) + 40|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = Math_fround($12 * $10);
   $13 = (($cur$03$i) + 28|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = Math_fround($16 * $14);
   $17 = Math_fround($11 + $15);
   $18 = (($cur$03$i) + 32|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround($21 * $19);
   $22 = Math_fround($17 + $20);
   $23 = (($cur$03$i) + 36|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($26 * $24);
   $27 = Math_fround($22 - $25);
   $28 = Math_fround($26 * $10);
   $29 = Math_fround($16 * $19);
   $30 = Math_fround($28 + $29);
   $31 = Math_fround($12 * $24);
   $32 = Math_fround($31 + $30);
   $33 = Math_fround($21 * $14);
   $34 = Math_fround($32 - $33);
   $35 = Math_fround($21 * $10);
   $36 = Math_fround($16 * $24);
   $37 = Math_fround($35 + $36);
   $38 = Math_fround($26 * $14);
   $39 = Math_fround($38 + $37);
   $40 = Math_fround($12 * $19);
   $41 = Math_fround($39 - $40);
   $42 = Math_fround($16 * $10);
   $43 = Math_fround($12 * $14);
   $44 = Math_fround($42 - $43);
   $45 = Math_fround($26 * $19);
   $46 = Math_fround($44 - $45);
   $47 = Math_fround($21 * $24);
   $48 = Math_fround($46 - $47);
   $cur$0$in$i = (($cur$03$i) + 156|0);
   $cur$0$i = HEAP32[$cur$0$in$i>>2]|0;
   $49 = ($cur$0$i|0)==(0|0);
   if ($49) {
    $51 = $27;$53 = $34;$57 = $41;$65 = $48;
    break;
   } else {
    $12 = $27;$16 = $48;$21 = $41;$26 = $34;$cur$03$i = $cur$0$i;
   }
  }
 }
 $50 = Math_fround(-$51);
 $52 = Math_fround(-$53);
 $54 = Math_fround($51 * Math_fround(-2.0));
 $55 = Math_fround($53 * Math_fround(-2.0));
 $56 = Math_fround($57 * Math_fround(-2.0));
 $58 = Math_fround($54 * $50);
 $59 = Math_fround($55 * $52);
 $60 = Math_fround($57 * $56);
 $61 = Math_fround($55 * $50);
 $62 = Math_fround($56 * $50);
 $63 = Math_fround($56 * $52);
 $64 = Math_fround($65 * $54);
 $66 = Math_fround($65 * $55);
 $67 = Math_fround($65 * $56);
 $68 = (($agg$result) + 4|0);
 $69 = (($agg$result) + 8|0);
 $70 = Math_fround($59 - $60);
 $71 = Math_fround(Math_fround(1.0) - $70);
 $72 = Math_fround(HEAPF32[$inDirection>>2]);
 $73 = Math_fround($72 * $71);
 $74 = Math_fround($61 - $67);
 $75 = (($inDirection) + 4|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($76 * $74);
 $78 = Math_fround($77 + $73);
 $79 = Math_fround($66 + $62);
 $80 = (($inDirection) + 8|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($79 * $81);
 $83 = Math_fround($82 + $78);
 HEAPF32[$agg$result>>2] = $83;
 $84 = Math_fround($67 + $61);
 $85 = Math_fround($72 * $84);
 $86 = Math_fround($58 - $60);
 $87 = Math_fround(Math_fround(1.0) - $86);
 $88 = Math_fround($76 * $87);
 $89 = Math_fround($85 + $88);
 $90 = Math_fround($63 - $64);
 $91 = Math_fround($90 * $81);
 $92 = Math_fround($91 + $89);
 HEAPF32[$68>>2] = $92;
 $93 = Math_fround($62 - $66);
 $94 = Math_fround($72 * $93);
 $95 = Math_fround($63 + $64);
 $96 = Math_fround($76 * $95);
 $97 = Math_fround($94 + $96);
 $98 = Math_fround($59 + $58);
 $99 = Math_fround(Math_fround(1.0) - $98);
 $100 = Math_fround($81 * $99);
 $101 = Math_fround($97 + $100);
 HEAPF32[$69>>2] = $101;
 STACKTOP = sp;return;
}
function __ZNK9Transform22GetPositionAndRotationER8Vector3fR11Quaternionf($this,$pos,$q) {
 $this = $this|0;
 $pos = $pos|0;
 $q = $q|0;
 var $$lcssa = Math_fround(0), $$lcssa4 = Math_fround(0), $$lcssa5 = Math_fround(0), $$lcssa6 = Math_fround(0), $$lcssa7 = Math_fround(0), $$lcssa8 = Math_fround(0), $$lcssa9 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0;
 var $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $cur$0 = 0, $cur$0$in = 0, $cur$0$in10 = 0, $cur$011 = 0, $cur$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 48|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 52|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 28|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 32|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 36|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $cur$0$in10 = (($this) + 156|0);
 $cur$011 = HEAP32[$cur$0$in10>>2]|0;
 $14 = ($cur$011|0)==(0|0);
 if ($14) {
  $$lcssa = $5;$$lcssa4 = $3;$$lcssa5 = $1;$$lcssa6 = $13;$$lcssa7 = $11;$$lcssa8 = $9;$$lcssa9 = $7;
  HEAPF32[$pos>>2] = $$lcssa5;
  $116 = (($pos) + 4|0);
  HEAPF32[$116>>2] = $$lcssa4;
  $117 = (($pos) + 8|0);
  HEAPF32[$117>>2] = $$lcssa;
  HEAPF32[$q>>2] = $$lcssa9;
  $118 = (($q) + 4|0);
  HEAPF32[$118>>2] = $$lcssa8;
  $119 = (($q) + 8|0);
  HEAPF32[$119>>2] = $$lcssa7;
  $120 = (($q) + 12|0);
  HEAPF32[$120>>2] = $$lcssa6;
  STACKTOP = sp;return;
 } else {
  $18 = $1;$22 = $3;$26 = $5;$84 = $7;$86 = $13;$89 = $11;$92 = $9;$cur$012 = $cur$011;
 }
 while(1) {
  $15 = (($cur$012) + 56|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($18 * $16);
  $19 = (($cur$012) + 60|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($22 * $20);
  $23 = (($cur$012) + 64|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($26 * $24);
  $27 = (($cur$012) + 28|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround($28 * Math_fround(2.0));
  $30 = (($cur$012) + 32|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($31 * Math_fround(2.0));
  $33 = (($cur$012) + 36|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($34 * Math_fround(2.0));
  $36 = Math_fround($28 * $29);
  $37 = Math_fround($31 * $32);
  $38 = Math_fround($34 * $35);
  $39 = Math_fround($28 * $32);
  $40 = Math_fround($28 * $35);
  $41 = Math_fround($31 * $35);
  $42 = (($cur$012) + 40|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($29 * $43);
  $45 = Math_fround($32 * $43);
  $46 = Math_fround($43 * $35);
  $47 = Math_fround($37 + $38);
  $48 = Math_fround(Math_fround(1.0) - $47);
  $49 = Math_fround($17 * $48);
  $50 = Math_fround($39 - $46);
  $51 = Math_fround($21 * $50);
  $52 = Math_fround($51 + $49);
  $53 = Math_fround($40 + $45);
  $54 = Math_fround($25 * $53);
  $55 = Math_fround($54 + $52);
  $56 = Math_fround($39 + $46);
  $57 = Math_fround($17 * $56);
  $58 = Math_fround($36 + $38);
  $59 = Math_fround(Math_fround(1.0) - $58);
  $60 = Math_fround($21 * $59);
  $61 = Math_fround($57 + $60);
  $62 = Math_fround($41 - $44);
  $63 = Math_fround($25 * $62);
  $64 = Math_fround($63 + $61);
  $65 = Math_fround($40 - $45);
  $66 = Math_fround($17 * $65);
  $67 = Math_fround($41 + $44);
  $68 = Math_fround($21 * $67);
  $69 = Math_fround($66 + $68);
  $70 = Math_fround($36 + $37);
  $71 = Math_fround(Math_fround(1.0) - $70);
  $72 = Math_fround($25 * $71);
  $73 = Math_fround($72 + $69);
  $74 = (($cur$012) + 44|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($75 + $55);
  $77 = (($cur$012) + 48|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = Math_fround($78 + $64);
  $80 = (($cur$012) + 52|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround($81 + $73);
  $83 = Math_fround($84 * $43);
  $85 = Math_fround($86 * $28);
  $87 = Math_fround($85 + $83);
  $88 = Math_fround($89 * $31);
  $90 = Math_fround($88 + $87);
  $91 = Math_fround($92 * $34);
  $93 = Math_fround($90 - $91);
  $94 = Math_fround($92 * $43);
  $95 = Math_fround($86 * $31);
  $96 = Math_fround($95 + $94);
  $97 = Math_fround($84 * $34);
  $98 = Math_fround($97 + $96);
  $99 = Math_fround($89 * $28);
  $100 = Math_fround($98 - $99);
  $101 = Math_fround($89 * $43);
  $102 = Math_fround($86 * $34);
  $103 = Math_fround($102 + $101);
  $104 = Math_fround($92 * $28);
  $105 = Math_fround($104 + $103);
  $106 = Math_fround($84 * $31);
  $107 = Math_fround($105 - $106);
  $108 = Math_fround($86 * $43);
  $109 = Math_fround($84 * $28);
  $110 = Math_fround($108 - $109);
  $111 = Math_fround($92 * $31);
  $112 = Math_fround($110 - $111);
  $113 = Math_fround($89 * $34);
  $114 = Math_fround($112 - $113);
  $cur$0$in = (($cur$012) + 156|0);
  $cur$0 = HEAP32[$cur$0$in>>2]|0;
  $115 = ($cur$0|0)==(0|0);
  if ($115) {
   $$lcssa = $82;$$lcssa4 = $79;$$lcssa5 = $76;$$lcssa6 = $114;$$lcssa7 = $107;$$lcssa8 = $100;$$lcssa9 = $93;
   break;
  } else {
   $18 = $76;$22 = $79;$26 = $82;$84 = $93;$86 = $114;$89 = $107;$92 = $100;$cur$012 = $cur$0;
  }
 }
 HEAPF32[$pos>>2] = $$lcssa5;
 $116 = (($pos) + 4|0);
 HEAPF32[$116>>2] = $$lcssa4;
 $117 = (($pos) + 8|0);
 HEAPF32[$117>>2] = $$lcssa;
 HEAPF32[$q>>2] = $$lcssa9;
 $118 = (($q) + 4|0);
 HEAPF32[$118>>2] = $$lcssa8;
 $119 = (($q) + 8|0);
 HEAPF32[$119>>2] = $$lcssa7;
 $120 = (($q) + 12|0);
 HEAPF32[$120>>2] = $$lcssa6;
 STACKTOP = sp;return;
}
function __ZNK9Transform24CalculateTransformMatrixER10Matrix4x4f($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $$$i = 0, $$0 = 0, $$02$i$i = 0, $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $8 = 0, $9 = 0, $cur$01$i$i = 0, $i$04 = 0, $i$04$in = 0, $parent$0 = 0, $parent$1 = 0, $parent$1$ph = 0, $temp = 0, $transformCount$0 = 0, $transforms = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $transforms = sp + 64|0;
 $temp = sp;
 $0 = (($this) + 68|0);
 $1 = (($this) + 133|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  __Z13CopyMatrixREFPKfPf($0,$transform);
  $4 = (($this) + 132|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$transforms>>2] = $this;
 $7 = (($this) + 156|0);
 $8 = HEAP32[$7>>2]|0;
 $parent$0 = $8;$transformCount$0 = 1;
 while(1) {
  $9 = ($parent$0|0)==(0|0);
  if ($9) {
   $parent$1 = 0;
   label = 10;
   break;
  }
  $10 = (($parent$0) + 133|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if (!($12)) {
   $parent$1 = $parent$0;
   label = 10;
   break;
  }
  $13 = (($transformCount$0) + 1)|0;
  $14 = (($transforms) + ($transformCount$0<<2)|0);
  HEAP32[$14>>2] = $parent$0;
  $15 = ($13|0)==(31);
  $16 = (($parent$0) + 156|0);
  $17 = HEAP32[$16>>2]|0;
  if ($15) {
   label = 7;
   break;
  } else {
   $parent$0 = $17;$transformCount$0 = $13;
  }
 }
 if ((label|0) == 7) {
  $18 = ($17|0)==(0|0);
  if ($18) {
   $$ph = 0;$parent$1$ph = 0;
  } else {
   $19 = (__ZNK9Transform33CalculateTransformMatrixIterativeER10Matrix4x4f($17,$temp)|0);
   $$ph = $19;$parent$1$ph = $17;
  }
  $20 = (($transforms) + 124|0);
  HEAP32[$20>>2] = $parent$1$ph;
  $26 = $parent$1$ph;$35 = $$ph;$i$04$in = 31;
  label = 11;
 }
 else if ((label|0) == 10) {
  $21 = (($transforms) + ($transformCount$0<<2)|0);
  HEAP32[$21>>2] = $parent$1;
  $22 = ($transformCount$0|0)>(0);
  if ($22) {
   $26 = $parent$1;$35 = 0;$i$04$in = $transformCount$0;
   label = 11;
  }
 }
 if ((label|0) == 11) {
  while(1) {
   label = 0;
   $i$04 = (($i$04$in) + -1)|0;
   $23 = (($transforms) + ($i$04<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($26|0)==(0|0);
   if ($25) {
    $42 = (($24) + 68|0);
    $43 = (($24) + 136|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = $44&255;
    $46 = ($44<<24>>24)==(0);
    $47 = (($24) + 44|0);
    $48 = (($24) + 28|0);
    if ($46) {
     __ZN10Matrix4x4f5SetTRERK8Vector3fRK11Quaternionf($42,$47,$48);
    } else {
     $49 = (($24) + 56|0);
     __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($42,$47,$48,$49);
    }
    $50 = $45 | $35;
    $52 = $50;
   } else {
    $27 = (($24) + 136|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28&255;
    $30 = ($28<<24>>24)==(0);
    $31 = (($24) + 44|0);
    $32 = (($24) + 28|0);
    if ($30) {
     __ZN10Matrix4x4f5SetTRERK8Vector3fRK11Quaternionf($temp,$31,$32);
    } else {
     $33 = (($24) + 56|0);
     __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($temp,$31,$32,$33);
    }
    $34 = $29 | $35;
    $36 = (($26) + 132|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = $37&255;
    $39 = $34 | $38;
    $40 = (($26) + 68|0);
    $41 = (($24) + 68|0);
    __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($40,$temp,$41);
    $52 = $39;
   }
   $51 = $52 & 4;
   $53 = ($51|0)==(0);
   if ($53) {
    $68 = $52;
   } else {
    $54 = $52 & -5;
    $55 = ($24|0)==(0|0);
    if ($55) {
     $68 = $54;
    } else {
     $$02$i$i = $54;$cur$01$i$i = $24;
     while(1) {
      $56 = (($cur$01$i$i) + 136|0);
      $57 = HEAP8[$56>>0]|0;
      $58 = $57&255;
      $59 = $58 | $$02$i$i;
      $60 = $59 & -5;
      $61 = $58 ^ $$02$i$i;
      $62 = $61 & 4;
      $63 = $60 | $62;
      $64 = (($cur$01$i$i) + 156|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = ($65|0)==(0|0);
      if ($66) {
       $68 = $63;
       break;
      } else {
       $$02$i$i = $63;$cur$01$i$i = $65;
      }
     }
    }
   }
   $67 = $68 & 2;
   $69 = ($67|0)==(0);
   $70 = $68 & 254;
   $$$i = $69 ? $68 : $70;
   $71 = $$$i&255;
   $72 = (($24) + 132|0);
   HEAP8[$72>>0] = $71;
   $73 = (($24) + 133|0);
   HEAP8[$73>>0] = 1;
   $74 = ($i$04|0)>(0);
   if ($74) {
    $26 = $24;$35 = $52;$i$04$in = $i$04;
    label = 11;
   } else {
    break;
   }
  }
 }
 __Z13CopyMatrixREFPKfPf($0,$transform);
 $75 = (($this) + 132|0);
 $76 = HEAP8[$75>>0]|0;
 $77 = $76&255;
 $$0 = $77;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK9Transform33CalculateTransformMatrixIterativeER10Matrix4x4f($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $$$i = 0, $$0 = 0, $$02$i$i = 0, $$lcssa2 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cur$01$i$i = 0, $parent$03 = 0, $parentTransform = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $temp = sp + 64|0;
 $parentTransform = sp;
 $0 = (($this) + 133|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 68|0);
  __Z13CopyMatrixREFPKfPf($3,$transform);
  $4 = (($this) + 132|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 136|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = ($8<<24>>24)==(0);
 $11 = (($this) + 44|0);
 $12 = (($this) + 28|0);
 if ($10) {
  __ZN10Matrix4x4f5SetTRERK8Vector3fRK11Quaternionf($transform,$11,$12);
 } else {
  $13 = (($this) + 56|0);
  __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($transform,$11,$12,$13);
 }
 $14 = (($this) + 156|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 L9: do {
  if ($16) {
   $$lcssa2 = $9;$$pre$phiZ2D = $transform;
  } else {
   $25 = $9;$parent$03 = $15;
   while(1) {
    $17 = (($parent$03) + 133|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)==(0);
    if (!($19)) {
     break;
    }
    $26 = (($parent$03) + 136|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = $27&255;
    $29 = ($27<<24>>24)==(0);
    $30 = (($parent$03) + 44|0);
    $31 = (($parent$03) + 28|0);
    if ($29) {
     __ZN10Matrix4x4f5SetTRERK8Vector3fRK11Quaternionf($parentTransform,$30,$31);
    } else {
     $32 = (($parent$03) + 56|0);
     __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($parentTransform,$30,$31,$32);
    }
    __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($parentTransform,$transform,$temp);
    $33 = (($parent$03) + 156|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = $28 | $25;
    __Z13CopyMatrixREFPKfPf($temp,$transform);
    $36 = ($34|0)==(0|0);
    if ($36) {
     $$lcssa2 = $35;$$pre$phiZ2D = $transform;
     break L9;
    } else {
     $25 = $35;$parent$03 = $34;
    }
   }
   $20 = (($parent$03) + 132|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21&255;
   $23 = (($parent$03) + 68|0);
   __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($23,$transform,$temp);
   $24 = $22 | $25;
   __Z13CopyMatrixREFPKfPf($temp,$transform);
   $$lcssa2 = $24;$$pre$phiZ2D = $transform;
  }
 } while(0);
 $37 = (($this) + 68|0);
 __Z13CopyMatrixREFPKfPf($$pre$phiZ2D,$37);
 $38 = $$lcssa2 & 4;
 $39 = ($38|0)==(0);
 if ($39) {
  $54 = $$lcssa2;
 } else {
  $40 = $$lcssa2 & -5;
  $41 = ($this|0)==(0|0);
  if ($41) {
   $54 = $40;
  } else {
   $$02$i$i = $40;$cur$01$i$i = $this;
   while(1) {
    $42 = (($cur$01$i$i) + 136|0);
    $43 = HEAP8[$42>>0]|0;
    $44 = $43&255;
    $45 = $44 | $$02$i$i;
    $46 = $45 & -5;
    $47 = $44 ^ $$02$i$i;
    $48 = $47 & 4;
    $49 = $46 | $48;
    $50 = (($cur$01$i$i) + 156|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)==(0|0);
    if ($52) {
     $54 = $49;
     break;
    } else {
     $$02$i$i = $49;$cur$01$i$i = $51;
    }
   }
  }
 }
 $53 = $54 & 2;
 $55 = ($53|0)==(0);
 $56 = $54 & 254;
 $$$i = $55 ? $54 : $56;
 $57 = $$$i&255;
 $58 = (($this) + 132|0);
 HEAP8[$58>>0] = $57;
 HEAP8[$0>>0] = 1;
 $$0 = $$lcssa2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK9Transform34CalculateTransformMatrixScaleDeltaER10Matrix4x4f($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $pos$i = 0, $rot$i = 0, $scaledMatrix = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $pos$i = sp + 144|0;
 $rot$i = sp;
 $scaledMatrix = sp + 16|0;
 $tmp = sp + 80|0;
 $0 = (__ZNK9Transform24CalculateTransformMatrixER10Matrix4x4f($this,$scaledMatrix)|0);
 $1 = $0 & 3;
 $2 = ($1|0)==(0);
 if ($2) {
  (__ZN10Matrix4x4f11SetIdentityEv($m)|0);
  STACKTOP = sp;return ($0|0);
 } else {
  HEAPF32[$pos$i>>2] = Math_fround(0.0);
  $3 = (($pos$i) + 4|0);
  HEAPF32[$3>>2] = Math_fround(0.0);
  $4 = (($pos$i) + 8|0);
  HEAPF32[$4>>2] = Math_fround(0.0);
  __ZNK9Transform22GetPositionAndRotationER8Vector3fR11Quaternionf($this,$pos$i,$rot$i);
  __ZN10Matrix4x4f12SetTRInverseERK8Vector3fRK11Quaternionf($tmp,$pos$i,$rot$i);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($tmp,$scaledMatrix,$m);
  $5 = (($m) + 48|0);
  HEAPF32[$5>>2] = Math_fround(0.0);
  $6 = (($m) + 52|0);
  HEAPF32[$6>>2] = Math_fround(0.0);
  $7 = (($m) + 56|0);
  HEAPF32[$7>>2] = Math_fround(0.0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $pos$i = 0, $rot$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i = sp + 16|0;
 $rot$i = sp;
 HEAPF32[$pos$i>>2] = Math_fround(0.0);
 $0 = (($pos$i) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($pos$i) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 __ZNK9Transform22GetPositionAndRotationER8Vector3fR11Quaternionf($this,$pos$i,$rot$i);
 __ZN10Matrix4x4f12SetTRInverseERK8Vector3fRK11Quaternionf($agg$result,$pos$i,$rot$i);
 STACKTOP = sp;return;
}
function __ZNK9Transform28GetLocalToWorldMatrixNoScaleEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $pos$i = 0, $rot$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $rot$i = sp + 16|0;
 $pos$i = sp;
 HEAPF32[$pos$i>>2] = Math_fround(0.0);
 $0 = (($pos$i) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($pos$i) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 __ZNK9Transform22GetPositionAndRotationER8Vector3fR11Quaternionf($this,$pos$i,$rot$i);
 __ZN10Matrix4x4f5SetTRERK8Vector3fRK11Quaternionf($agg$result,$pos$i,$rot$i);
 STACKTOP = sp;return;
}
function __ZNK9Transform21GetWorldToLocalMatrixEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $$0$i2$i = Math_fround(0), $$0$i5$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $scale = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $temp = sp + 80|0;
 $scale = sp;
 $0 = sp + 64|0;
 $1 = (($this) + 44|0);
 $2 = (($this) + 28|0);
 __ZN10Matrix4x4f12SetTRInverseERK8Vector3fRK11Quaternionf($agg$result,$1,$2);
 $3 = (($this) + 136|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($this) + 56|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = $7 < Math_fround(0.0);
  if ($8) {
   $9 = Math_fround(-$7);
   $12 = $9;
  } else {
   $12 = $7;
  }
  $10 = Math_fround(HEAPF32[616648>>2]);
  $11 = $12 > $10;
  if ($11) {
   $13 = Math_fround(Math_fround(1.0) / $7);
   $$0$i$i = $13;
  } else {
   $$0$i$i = Math_fround(0.0);
  }
  $14 = (($this) + 60|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = $15 < Math_fround(0.0);
  if ($16) {
   $17 = Math_fround(-$15);
   $19 = $17;
  } else {
   $19 = $15;
  }
  $18 = $19 > $10;
  if ($18) {
   $20 = Math_fround(Math_fround(1.0) / $15);
   $$0$i5$i = $20;
  } else {
   $$0$i5$i = Math_fround(0.0);
  }
  $21 = (($this) + 64|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = $22 < Math_fround(0.0);
  if ($23) {
   $24 = Math_fround(-$22);
   $26 = $24;
  } else {
   $26 = $22;
  }
  $25 = $26 > $10;
  if ($25) {
   $27 = Math_fround(Math_fround(1.0) / $22);
   $$0$i2$i = $27;
  } else {
   $$0$i2$i = Math_fround(0.0);
  }
  HEAPF32[$0>>2] = $$0$i$i;
  $28 = (($0) + 4|0);
  HEAPF32[$28>>2] = $$0$i5$i;
  $29 = (($0) + 8|0);
  HEAPF32[$29>>2] = $$0$i2$i;
  (__ZN10Matrix4x4f8SetScaleERK8Vector3f($scale,$0)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($scale,$agg$result,$temp);
  __Z13CopyMatrixREFPKfPf($temp,$agg$result);
 }
 $30 = (($this) + 156|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 __ZNK9Transform21GetWorldToLocalMatrixEv($scale,$31);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($agg$result,$scale,$temp);
 __Z13CopyMatrixREFPKfPf($temp,$agg$result);
 STACKTOP = sp;return;
}
function __ZNK9Transform21GetLocalToWorldMatrixEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZNK9Transform24CalculateTransformMatrixER10Matrix4x4f($this,$agg$result)|0);
 STACKTOP = sp;return;
}
function __ZNK9Transform18TransformDirectionERK8Vector3f($agg$result,$this,$inDirection) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inDirection = $inDirection|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0);
 var $cur$0$i = 0, $cur$0$in$i = 0, $cur$0$in1$i = 0, $cur$02$i = 0, $cur$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 32|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 36|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 40|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $cur$0$in1$i = (($this) + 156|0);
 $cur$02$i = HEAP32[$cur$0$in1$i>>2]|0;
 $8 = ($cur$02$i|0)==(0|0);
 if ($8) {
  $51 = $1;$53 = $3;$55 = $5;$63 = $7;
 } else {
  $12 = $1;$16 = $7;$21 = $5;$26 = $3;$cur$03$i = $cur$02$i;
  while(1) {
   $9 = (($cur$03$i) + 40|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = Math_fround($12 * $10);
   $13 = (($cur$03$i) + 28|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = Math_fround($16 * $14);
   $17 = Math_fround($11 + $15);
   $18 = (($cur$03$i) + 32|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround($21 * $19);
   $22 = Math_fround($17 + $20);
   $23 = (($cur$03$i) + 36|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($26 * $24);
   $27 = Math_fround($22 - $25);
   $28 = Math_fround($26 * $10);
   $29 = Math_fround($16 * $19);
   $30 = Math_fround($28 + $29);
   $31 = Math_fround($12 * $24);
   $32 = Math_fround($31 + $30);
   $33 = Math_fround($21 * $14);
   $34 = Math_fround($32 - $33);
   $35 = Math_fround($21 * $10);
   $36 = Math_fround($16 * $24);
   $37 = Math_fround($35 + $36);
   $38 = Math_fround($26 * $14);
   $39 = Math_fround($38 + $37);
   $40 = Math_fround($12 * $19);
   $41 = Math_fround($39 - $40);
   $42 = Math_fround($16 * $10);
   $43 = Math_fround($12 * $14);
   $44 = Math_fround($42 - $43);
   $45 = Math_fround($26 * $19);
   $46 = Math_fround($44 - $45);
   $47 = Math_fround($21 * $24);
   $48 = Math_fround($46 - $47);
   $cur$0$in$i = (($cur$03$i) + 156|0);
   $cur$0$i = HEAP32[$cur$0$in$i>>2]|0;
   $49 = ($cur$0$i|0)==(0|0);
   if ($49) {
    $51 = $27;$53 = $34;$55 = $41;$63 = $48;
    break;
   } else {
    $12 = $27;$16 = $48;$21 = $41;$26 = $34;$cur$03$i = $cur$0$i;
   }
  }
 }
 $50 = Math_fround($51 * Math_fround(2.0));
 $52 = Math_fround($53 * Math_fround(2.0));
 $54 = Math_fround($55 * Math_fround(2.0));
 $56 = Math_fround($51 * $50);
 $57 = Math_fround($53 * $52);
 $58 = Math_fround($55 * $54);
 $59 = Math_fround($51 * $52);
 $60 = Math_fround($54 * $51);
 $61 = Math_fround($53 * $54);
 $62 = Math_fround($63 * $50);
 $64 = Math_fround($63 * $52);
 $65 = Math_fround($63 * $54);
 $66 = (($agg$result) + 4|0);
 $67 = (($agg$result) + 8|0);
 $68 = Math_fround($58 + $57);
 $69 = Math_fround(Math_fround(1.0) - $68);
 $70 = Math_fround(HEAPF32[$inDirection>>2]);
 $71 = Math_fround($70 * $69);
 $72 = Math_fround($59 - $65);
 $73 = (($inDirection) + 4|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($72 * $74);
 $76 = Math_fround($75 + $71);
 $77 = Math_fround($60 + $64);
 $78 = (($inDirection) + 8|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($77 * $79);
 $81 = Math_fround($80 + $76);
 HEAPF32[$agg$result>>2] = $81;
 $82 = Math_fround($65 + $59);
 $83 = Math_fround($70 * $82);
 $84 = Math_fround($58 + $56);
 $85 = Math_fround(Math_fround(1.0) - $84);
 $86 = Math_fround($74 * $85);
 $87 = Math_fround($83 + $86);
 $88 = Math_fround($61 - $62);
 $89 = Math_fround($88 * $79);
 $90 = Math_fround($89 + $87);
 HEAPF32[$66>>2] = $90;
 $91 = Math_fround($60 - $64);
 $92 = Math_fround($70 * $91);
 $93 = Math_fround($61 + $62);
 $94 = Math_fround($74 * $93);
 $95 = Math_fround($92 + $94);
 $96 = Math_fround($57 + $56);
 $97 = Math_fround(Math_fround(1.0) - $96);
 $98 = Math_fround($79 * $97);
 $99 = Math_fround($95 + $98);
 HEAPF32[$67>>2] = $99;
 STACKTOP = sp;return;
}
function __ZN9Transform13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$phi$trans$insert$i = 0, $$pre$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($awakeMode|0)==(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 __ZN9Transform13SetCacheDirtyEv($this);
 $1 = (($this) + 56|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 60|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 - $4);
 $6 = $5 < Math_fround(0.0);
 if ($6) {
  $7 = Math_fround(-$5);
  $9 = $7;
 } else {
  $9 = $5;
 }
 $8 = !($9 <= Math_fround(9.99999974737875163555E-5));
 $$phi$trans$insert$i = (($this) + 64|0);
 $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
 do {
  if ($8) {
   label = 14;
  } else {
   $10 = Math_fround($4 - $$pre$i);
   $11 = $10 < Math_fround(0.0);
   if ($11) {
    $12 = Math_fround(-$10);
    $14 = $12;
   } else {
    $14 = $10;
   }
   $13 = !($14 <= Math_fround(9.99999974737875163555E-5));
   if ($13) {
    label = 14;
   } else {
    $15 = Math_fround($2 + Math_fround(-1.0));
    $16 = $15 < Math_fround(0.0);
    if ($16) {
     $17 = Math_fround(-$15);
     $19 = $17;
    } else {
     $19 = $15;
    }
    $18 = !($19 <= Math_fround(9.99999974737875163555E-5));
    $20 = (($this) + 136|0);
    if (!($18)) {
     HEAP8[$20>>0] = 0;
     break;
    }
    HEAP8[$20>>0] = 1;
    $21 = $2 < Math_fround(0.0);
    if ($21) {
     HEAP8[$20>>0] = 6;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $22 = (($this) + 136|0);
  $23 = Math_fround($2 * $4);
  $24 = Math_fround($23 * $$pre$i);
  $25 = $24 < Math_fround(0.0);
  $26 = $25&1;
  $27 = $26 << 2;
  $28 = $27 | 2;
  $29 = $28&255;
  HEAP8[$22>>0] = $29;
 }
 __ZN9Transform20SendTransformChangedEi($this,75);
 STACKTOP = sp;return;
}
function __ZN9Transform16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$sum12 = 0, $$sum12$us = 0, $$sum15 = 0, $$sum15$us = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$029 = 0, $i$029$us = 0, $i$1 = 0, $i$1$us = 0, $it$01$i = 0, $j$0 = 0, $j$0$ph = 0, $j$0$ph$us = 0, $j$0$us = 0, $neg = 0, $neg$us = 0, $neg19 = 0, $neg19$us = 0, $neg22 = 0;
 var $neg22$us = 0, $occursMultipleTimes$0$off0$ph = 0, $occursMultipleTimes$0$off0$ph$us = 0, $tmp = 0, $tmp$us = 0, $tmp18 = 0, $tmp18$us = 0, $tmp20 = 0, $tmp20$us = 0, $tmp21 = 0, $tmp21$us = 0, $tmp23 = 0, $tmp23$us = 0, $tmp24 = 0, $tmp24$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN5Unity9Component16CheckConsistencyEv($this);
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2139095040;
 $4 = ($3|0)==(2139095040);
 $5 = (HEAP32[tempDoublePtr>>2]=$2,Math_fround(HEAPF32[tempDoublePtr>>2]));
 if ($4) {
  HEAPF32[$1>>2] = Math_fround(0.0);
  $46 = Math_fround(0.0);
 } else {
  $46 = $5;
 }
 $6 = (($this) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2139095040;
 $9 = ($8|0)==(2139095040);
 $10 = (HEAP32[tempDoublePtr>>2]=$7,Math_fround(HEAPF32[tempDoublePtr>>2]));
 if ($9) {
  HEAPF32[$6>>2] = Math_fround(0.0);
  $48 = Math_fround(0.0);
 } else {
  $48 = $10;
 }
 $11 = (($this) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2139095040;
 $14 = ($13|0)==(2139095040);
 $15 = (HEAP32[tempDoublePtr>>2]=$12,Math_fround(HEAPF32[tempDoublePtr>>2]));
 if ($14) {
  HEAPF32[$11>>2] = Math_fround(0.0);
  $51 = Math_fround(0.0);
 } else {
  $51 = $15;
 }
 $16 = (($this) + 40|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2139095040;
 $19 = ($18|0)==(2139095040);
 $20 = (HEAP32[tempDoublePtr>>2]=$17,Math_fround(HEAPF32[tempDoublePtr>>2]));
 if ($19) {
  HEAPF32[$16>>2] = Math_fround(0.0);
  $54 = Math_fround(0.0);
 } else {
  $54 = $20;
 }
 $21 = (($this) + 44|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 & 2139095040;
 $24 = ($23|0)==(2139095040);
 if ($24) {
  HEAPF32[$21>>2] = Math_fround(0.0);
 }
 $25 = (($this) + 48|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26 & 2139095040;
 $28 = ($27|0)==(2139095040);
 if ($28) {
  HEAPF32[$25>>2] = Math_fround(0.0);
 }
 $29 = (($this) + 52|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 2139095040;
 $32 = ($31|0)==(2139095040);
 if ($32) {
  HEAPF32[$29>>2] = Math_fround(0.0);
 }
 $33 = (($this) + 56|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 2139095040;
 $36 = ($35|0)==(2139095040);
 if ($36) {
  HEAPF32[$33>>2] = Math_fround(0.0);
 }
 $37 = (($this) + 60|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 2139095040;
 $40 = ($39|0)==(2139095040);
 if ($40) {
  HEAPF32[$37>>2] = Math_fround(0.0);
 }
 $41 = (($this) + 64|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 & 2139095040;
 $44 = ($43|0)==(2139095040);
 if ($44) {
  HEAPF32[$41>>2] = Math_fround(0.0);
 }
 $45 = Math_fround($46 * $46);
 $47 = Math_fround($48 * $48);
 $49 = Math_fround($45 + $47);
 $50 = Math_fround($51 * $51);
 $52 = Math_fround($49 + $50);
 $53 = Math_fround($54 * $54);
 $55 = Math_fround($52 + $53);
 $56 = (Math_fround(Math_sqrt((Math_fround($55)))));
 $57 = Math_fround(HEAPF32[616648>>2]);
 $58 = $56 < $57;
 if ($58) {
  $64 = Math_fround(0.0);$65 = Math_fround(0.0);$66 = Math_fround(0.0);$67 = Math_fround(1.0);
 } else {
  $59 = Math_fround($46 / $56);
  $60 = Math_fround($48 / $56);
  $61 = Math_fround($51 / $56);
  $62 = Math_fround($54 / $56);
  $64 = $59;$65 = $60;$66 = $61;$67 = $62;
 }
 $63 = (($this) + 28|0);
 HEAPF32[$63>>2] = $64;
 HEAPF32[$6>>2] = $65;
 HEAPF32[$11>>2] = $66;
 HEAPF32[$16>>2] = $67;
 $68 = (($this) + 156|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0|0);
 L34: do {
  if (!($70)) {
   $71 = (($69) + 140|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($69) + 148|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($72) + ($74<<2)|0);
   $76 = ($74|0)==(0);
   L36: do {
    if (!($76)) {
     $it$01$i = $72;
     while(1) {
      $79 = HEAP32[$it$01$i>>2]|0;
      $80 = ($79|0)==($this|0);
      $78 = (($it$01$i) + 4|0);
      if ($80) {
       break;
      }
      $77 = ($78|0)==($75|0);
      if ($77) {
       break L36;
      } else {
       $it$01$i = $78;
      }
     }
     $81 = ($it$01$i|0)==($75|0);
     if (!($81)) {
      break L34;
     }
    }
   } while(0);
   $82 = (($69) + 140|0);
   HEAP32[$0>>2] = $this;
   __ZN13dynamic_arrayI12ImmediatePtrI9TransformELj4EE9push_backERKS2_($82,$0);
  }
 } while(0);
 $83 = (($this) + 148|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)>(0);
 if (!($85)) {
  STACKTOP = sp;return;
 }
 $86 = (($this) + 140|0);
 $87 = ($this|0)==(0|0);
 $88 = (($this) + 4|0);
 if ($87) {
  $98 = $84;$i$029$us = 0;
  while(1) {
   $89 = HEAP32[$86>>2]|0;
   $90 = (($89) + ($i$029$us<<2)|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(0|0);
   do {
    if ($92) {
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(610512,0,610504,1848,1,0,0,0);
     $115 = HEAP32[$86>>2]|0;
     $116 = (($115) + ($i$029$us<<2)|0);
     $$sum15$us = (($i$029$us) + 1)|0;
     $117 = (($115) + ($$sum15$us<<2)|0);
     $118 = HEAP32[$83>>2]|0;
     $neg$us = $i$029$us ^ 1073741823;
     $tmp$us = (($118) + ($neg$us))|0;
     $tmp18$us = $tmp$us << 2;
     _memmove(($116|0),($117|0),($tmp18$us|0))|0;
     $119 = HEAP32[$83>>2]|0;
     $120 = (($119) + -1)|0;
     HEAP32[$83>>2] = $120;
     $121 = (($i$029$us) + -1)|0;
     $i$1$us = $121;
    } else {
     $93 = (($91) + 156|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ($94|0)==(0|0);
     $96 = (($i$029$us) + 1)|0;
     if ($95) {
      $105 = $98;$j$0$ph$us = $96;$occursMultipleTimes$0$off0$ph$us = 0;
     } else {
      $97 = (($89) + ($96<<2)|0);
      $neg19$us = $i$029$us ^ 1073741823;
      $tmp20$us = (($98) + ($neg19$us))|0;
      $tmp21$us = $tmp20$us << 2;
      _memmove(($90|0),($97|0),($tmp21$us|0))|0;
      $99 = HEAP32[$83>>2]|0;
      $100 = (($99) + -1)|0;
      HEAP32[$83>>2] = $100;
      $101 = (($i$029$us) + -1)|0;
      $102 = (($91) + 4|0);
      $103 = HEAP32[$102>>2]|0;
      __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(610568,0,610504,1872,1,$103,0,0);
      $i$1$us = $101;
      break;
     }
     L53: while(1) {
      $j$0$us = $j$0$ph$us;
      while(1) {
       $104 = ($j$0$us|0)<($105|0);
       if (!($104)) {
        break L53;
       }
       $108 = HEAP32[$86>>2]|0;
       $109 = (($108) + ($j$0$us<<2)|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = ($110|0)==($91|0);
       $$sum12$us = (($j$0$us) + 1)|0;
       if ($111) {
        break;
       } else {
        $j$0$us = $$sum12$us;
       }
      }
      $112 = (($108) + ($$sum12$us<<2)|0);
      $neg22$us = $j$0$us ^ 1073741823;
      $tmp23$us = (($105) + ($neg22$us))|0;
      $tmp24$us = $tmp23$us << 2;
      _memmove(($109|0),($112|0),($tmp24$us|0))|0;
      $113 = HEAP32[$83>>2]|0;
      $114 = (($113) + -1)|0;
      HEAP32[$83>>2] = $114;
      $105 = $114;$j$0$ph$us = $j$0$us;$occursMultipleTimes$0$off0$ph$us = 1;
     }
     if ($occursMultipleTimes$0$off0$ph$us) {
      $106 = (($91) + 4|0);
      $107 = HEAP32[$106>>2]|0;
      __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(610624,0,610504,1891,1,$107,0,0);
      $i$1$us = $i$029$us;
     } else {
      $i$1$us = $i$029$us;
     }
    }
   } while(0);
   $122 = (($i$1$us) + 1)|0;
   $123 = HEAP32[$83>>2]|0;
   $124 = ($122|0)<($123|0);
   if ($124) {
    $98 = $123;$i$029$us = $122;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else {
  $142 = $84;$i$029 = 0;
  while(1) {
   $125 = HEAP32[$86>>2]|0;
   $126 = (($125) + ($i$029<<2)|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)==(0|0);
   do {
    if ($128) {
     $129 = HEAP32[$88>>2]|0;
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(610512,0,610504,1848,1,$129,0,0);
     $130 = HEAP32[$86>>2]|0;
     $131 = (($130) + ($i$029<<2)|0);
     $$sum15 = (($i$029) + 1)|0;
     $132 = (($130) + ($$sum15<<2)|0);
     $133 = HEAP32[$83>>2]|0;
     $neg = $i$029 ^ 1073741823;
     $tmp = (($133) + ($neg))|0;
     $tmp18 = $tmp << 2;
     _memmove(($131|0),($132|0),($tmp18|0))|0;
     $134 = HEAP32[$83>>2]|0;
     $135 = (($134) + -1)|0;
     HEAP32[$83>>2] = $135;
     $136 = (($i$029) + -1)|0;
     $i$1 = $136;
    } else {
     $137 = (($127) + 156|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = ($138|0)==($this|0);
     $140 = (($i$029) + 1)|0;
     if ($139) {
      $149 = $142;$j$0$ph = $140;$occursMultipleTimes$0$off0$ph = 0;
     } else {
      $141 = (($125) + ($140<<2)|0);
      $neg19 = $i$029 ^ 1073741823;
      $tmp20 = (($142) + ($neg19))|0;
      $tmp21 = $tmp20 << 2;
      _memmove(($126|0),($141|0),($tmp21|0))|0;
      $143 = HEAP32[$83>>2]|0;
      $144 = (($143) + -1)|0;
      HEAP32[$83>>2] = $144;
      $145 = (($i$029) + -1)|0;
      $146 = (($127) + 4|0);
      $147 = HEAP32[$146>>2]|0;
      __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(610568,0,610504,1872,1,$147,0,0);
      $i$1 = $145;
      break;
     }
     L70: while(1) {
      $j$0 = $j$0$ph;
      while(1) {
       $148 = ($j$0|0)<($149|0);
       if (!($148)) {
        break L70;
       }
       $150 = HEAP32[$86>>2]|0;
       $151 = (($150) + ($j$0<<2)|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = ($152|0)==($127|0);
       $$sum12 = (($j$0) + 1)|0;
       if ($153) {
        break;
       } else {
        $j$0 = $$sum12;
       }
      }
      $154 = (($150) + ($$sum12<<2)|0);
      $neg22 = $j$0 ^ 1073741823;
      $tmp23 = (($149) + ($neg22))|0;
      $tmp24 = $tmp23 << 2;
      _memmove(($151|0),($154|0),($tmp24|0))|0;
      $155 = HEAP32[$83>>2]|0;
      $156 = (($155) + -1)|0;
      HEAP32[$83>>2] = $156;
      $149 = $156;$j$0$ph = $j$0;$occursMultipleTimes$0$off0$ph = 1;
     }
     if ($occursMultipleTimes$0$off0$ph) {
      $157 = (($127) + 4|0);
      $158 = HEAP32[$157>>2]|0;
      __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(610624,0,610504,1891,1,$158,0,0);
      $i$1 = $i$029;
     } else {
      $i$1 = $i$029;
     }
    }
   } while(0);
   $159 = (($i$1) + 1)|0;
   $160 = HEAP32[$83>>2]|0;
   $161 = ($159|0)<($160|0);
   if ($161) {
    $142 = $160;$i$029 = $159;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN9Transform23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610736,610744,$this,0);
 __ZN9Transform8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,610736,610744,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9Transform8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Transform8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN11Quaternionf8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$1,0,0);
 $2 = (($this) + 56|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$2,0,0);
 __ZN9Transform25CompleteTransformTransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Transform8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN9Transform25CompleteTransformTransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z23RegisterClass_Transformv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(4,139,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9Transform13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(2)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity9Component13RegisterClassEv();
 }
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=610744+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,4,2,($0|0),160,(2406|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN9Transform7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(160,$$byval_copy2,1,16,610504,77)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((610384 + 8|0));
  $6 = (($3) + 44|0);
  $7 = (($3) + 132|0);
  HEAP8[$7>>0] = 0;
  $8 = (($3) + 133|0);
  HEAP8[$8>>0] = 0;
  $9 = (($3) + 134|0);
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  HEAP8[$9>>0] = 1;
  $10 = (($3) + 135|0);
  HEAP8[$10>>0] = 11;
  $11 = (($3) + 140|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 144|0);
  HEAP32[$12>>2] = $2;
  $13 = (($3) + 148|0);
  HEAP32[$13>>2] = 0;
  $14 = (($3) + 152|0);
  HEAP32[$14>>2] = 0;
  $15 = (($3) + 156|0);
  HEAP32[$15>>2] = 0;
  $16 = (($3) + 136|0);
  HEAP8[$16>>0] = 0;
  $17 = (($3) + 137|0);
  HEAP8[$17>>0] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(610504|0),77);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 } else {
  ___resumeException($18|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK9Transform25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 4;
}
function __ZN9Transform8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580640>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610760,$1,$0,2048);
 __ZN11Quaternionf8TransferI13ProxyTransferEEvRT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($this) + 44|0);
 $3 = HEAP32[580776>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610776,$3,$2,2048);
 $4 = (($transfer) + 16|0);
 $5 = (__ZNK16TypeTreeIterator7GetNodeEv($4)|0);
 $6 = (($5) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 | 2097152;
 $9 = (($transfer) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($transfer) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($11) + (($13*24)|0)|0) + 20|0);
 HEAP32[$14>>2] = $8;
 $15 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610912,$15,$2,0);
 $16 = HEAP32[$9>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$12>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610920,$15,$20,0);
 $21 = HEAP32[$9>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$12>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $25 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610928,$15,$25,0);
 $26 = HEAP32[$9>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$12>>2]|0;
 $29 = ((($27) + (($28*24)|0)|0) + 12|0);
 HEAP32[$29>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $30 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610792,$3,$30,2048);
 $31 = (__ZNK16TypeTreeIterator7GetNodeEv($4)|0);
 $32 = (($31) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 | 2097152;
 $35 = HEAP32[$9>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$12>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 20|0);
 HEAP32[$38>>2] = $34;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610912,$15,$30,0);
 $39 = HEAP32[$9>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$12>>2]|0;
 $42 = ((($40) + (($41*24)|0)|0) + 12|0);
 HEAP32[$42>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $43 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610920,$15,$43,0);
 $44 = HEAP32[$9>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$12>>2]|0;
 $47 = ((($45) + (($46*24)|0)|0) + 12|0);
 HEAP32[$47>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $48 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610928,$15,$48,0);
 $49 = HEAP32[$9>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$12>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN9Transform25CompleteTransformTransferI13ProxyTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform25CompleteTransformTransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i$i = 0, $p$i$i = 0, $size$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 $size$i$i$i = sp + 20|0;
 $p$i$i = sp + 16|0;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 140|0);
 $4 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610808,$4,$3,65601);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,610904,610904,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610880,610888,$p$i$i,0);
 $5 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $6 = $5;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $10 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610848,$10,$localIdentifier$i$i$i$i$i$i,1);
 $11 = (($transfer) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($transfer) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($13) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610864,$17,$5,1);
 $18 = HEAP32[$11>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$14>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 156|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610824,610888,$22,65537);
 $23 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $24 = $23;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610848,$10,$localIdentifier$i$i$i$i$i$i,1);
 $28 = HEAP32[$11>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$14>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610864,$17,$23,1);
 $32 = HEAP32[$11>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$14>>2]|0;
 $35 = ((($33) + (($34*24)|0)|0) + 12|0);
 HEAP32[$35>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i2 = sp;
 __ZN5Unity9Component8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580640>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,610760,$1,$converter$i$i2,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,610912,0);
   $5 = (($this) + 32|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,610920,0);
   $6 = (($this) + 36|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,610928,0);
   $7 = (($this) + 40|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$7,610936,0);
  } else {
   $8 = HEAP32[$converter$i$i2>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    (FUNCTION_TABLE_iii[$8 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[580776>>2]|0;
 $12 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,610776,$11,$converter$i$i2,1)|0);
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = ($12|0)>(0);
  if ($14) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$10,610912,0);
   $15 = (($this) + 48|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$15,610920,0);
   $16 = (($this) + 52|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,610928,0);
  } else {
   $17 = HEAP32[$converter$i$i2>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    (FUNCTION_TABLE_iii[$17 & 4095]($10,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $19 = (($this) + 56|0);
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,610792,$11,$converter$i$i2,1)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  __ZN9Transform25CompleteTransformTransferI14SafeBinaryReadEEvRT_($this,$transfer);
  STACKTOP = sp;return;
 }
 $22 = ($20|0)>(0);
 if ($22) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$19,610912,0);
  $23 = (($this) + 60|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$23,610920,0);
  $24 = (($this) + 64|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$24,610928,0);
 } else {
  $25 = HEAP32[$converter$i$i2>>2]|0;
  $26 = ($25|0)==(0|0);
  if (!($26)) {
   (FUNCTION_TABLE_iii[$25 & 4095]($19,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 __ZN9Transform25CompleteTransformTransferI14SafeBinaryReadEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform25CompleteTransformTransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert$i = 0, $$pre$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 60|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = $4 < Math_fround(0.0);
 if ($5) {
  $6 = Math_fround(-$4);
  $8 = $6;
 } else {
  $8 = $4;
 }
 $7 = !($8 <= Math_fround(9.99999974737875163555E-5));
 $$phi$trans$insert$i = (($this) + 64|0);
 $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
 do {
  if ($7) {
   label = 13;
  } else {
   $9 = Math_fround($3 - $$pre$i);
   $10 = $9 < Math_fround(0.0);
   if ($10) {
    $11 = Math_fround(-$9);
    $13 = $11;
   } else {
    $13 = $9;
   }
   $12 = !($13 <= Math_fround(9.99999974737875163555E-5));
   if ($12) {
    label = 13;
   } else {
    $14 = Math_fround($1 + Math_fround(-1.0));
    $15 = $14 < Math_fround(0.0);
    if ($15) {
     $16 = Math_fround(-$14);
     $18 = $16;
    } else {
     $18 = $14;
    }
    $17 = !($18 <= Math_fround(9.99999974737875163555E-5));
    $19 = (($this) + 136|0);
    if (!($17)) {
     HEAP8[$19>>0] = 0;
     break;
    }
    HEAP8[$19>>0] = 1;
    $20 = $1 < Math_fround(0.0);
    if ($20) {
     HEAP8[$19>>0] = 6;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $21 = (($this) + 136|0);
  $22 = Math_fround($1 * $3);
  $23 = Math_fround($22 * $$pre$i);
  $24 = $23 < Math_fround(0.0);
  $25 = $24&1;
  $26 = $25 << 2;
  $27 = $26 | 2;
  $28 = $27&255;
  HEAP8[$21>>0] = $28;
 }
 $29 = HEAP32[$transfer>>2]|0;
 $30 = $29 & 16384;
 $31 = ($30|0)==(0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = (($this) + 140|0);
 $33 = HEAP32[580760>>2]|0;
 $34 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,610808,$33,$converter$i$i1,1)|0);
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = ($34|0)>(0);
  if ($36) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEEEvRT_17TransferMetaFlags($transfer,$32,0);
  } else {
   $37 = HEAP32[$converter$i$i1>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    (FUNCTION_TABLE_iii[$37 & 4095]($32,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $39 = (($this) + 156|0);
 $40 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,610824,610888,$converter$i$i1,1)|0);
 $41 = ($40|0)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = ($40|0)>(0);
 if ($42) {
  __ZN12ImmediatePtrI9TransformE8TransferI14SafeBinaryReadEEvRT_($39,$transfer);
 } else {
  $43 = HEAP32[$converter$i$i1>>2]|0;
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   (FUNCTION_TABLE_iii[$43 & 4095]($39,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i2 = 0, $$pre4$i$i$i = 0, $$pre4$i$i$i4 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i5 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN11Quaternionf8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 44|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $$pre3$i$i$i = HEAP32[$5>>2]|0;
  $11 = $$pre$i$i$i;$13 = $$pre3$i$i$i;
 } else {
  $8 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $11 = $4;$13 = $6;
 }
 $9 = (($this) + 48|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$9,4);
  $$pre4$i$i$i = HEAP32[$2>>2]|0;
  $$pre5$i$i$i = HEAP32[$5>>2]|0;
  $17 = $$pre4$i$i$i;$19 = $$pre5$i$i$i;
 } else {
  $14 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$9>>2] = $14;
  HEAP32[$2>>2] = $10;
  $17 = $10;$19 = $13;
 }
 $15 = (($this) + 52|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$15,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre8 = HEAP32[$5>>2]|0;
  $23 = $$pre;$25 = $$pre8;
 } else {
  $20 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$15>>2] = $20;
  HEAP32[$2>>2] = $16;
  $23 = $16;$25 = $19;
 }
 $21 = (($this) + 56|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$21,4);
  $$pre$i$i$i1 = HEAP32[$2>>2]|0;
  $$pre3$i$i$i2 = HEAP32[$5>>2]|0;
  $29 = $$pre$i$i$i1;$31 = $$pre3$i$i$i2;
 } else {
  $26 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$21>>2] = $26;
  HEAP32[$2>>2] = $22;
  $29 = $22;$31 = $25;
 }
 $27 = (($this) + 60|0);
 $28 = (($29) + 4|0);
 $30 = ($28>>>0)>($31>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$27,4);
  $$pre4$i$i$i4 = HEAP32[$2>>2]|0;
  $$pre5$i$i$i5 = HEAP32[$5>>2]|0;
  $35 = $$pre4$i$i$i4;$37 = $$pre5$i$i$i5;
 } else {
  $32 = Math_fround(HEAPF32[$29>>2]);
  HEAPF32[$27>>2] = $32;
  HEAP32[$2>>2] = $28;
  $35 = $28;$37 = $31;
 }
 $33 = (($this) + 64|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$33,4);
  __ZN9Transform25CompleteTransformTransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
  STACKTOP = sp;return;
 } else {
  $38 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$33>>2] = $38;
  HEAP32[$2>>2] = $34;
  __ZN9Transform25CompleteTransformTransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9Transform25CompleteTransformTransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert$i = 0, $$pre$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 60|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = $4 < Math_fround(0.0);
 if ($5) {
  $6 = Math_fround(-$4);
  $8 = $6;
 } else {
  $8 = $4;
 }
 $7 = !($8 <= Math_fround(9.99999974737875163555E-5));
 $$phi$trans$insert$i = (($this) + 64|0);
 $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
 do {
  if ($7) {
   label = 13;
  } else {
   $9 = Math_fround($3 - $$pre$i);
   $10 = $9 < Math_fround(0.0);
   if ($10) {
    $11 = Math_fround(-$9);
    $13 = $11;
   } else {
    $13 = $9;
   }
   $12 = !($13 <= Math_fround(9.99999974737875163555E-5));
   if ($12) {
    label = 13;
   } else {
    $14 = Math_fround($1 + Math_fround(-1.0));
    $15 = $14 < Math_fround(0.0);
    if ($15) {
     $16 = Math_fround(-$14);
     $18 = $16;
    } else {
     $18 = $14;
    }
    $17 = !($18 <= Math_fround(9.99999974737875163555E-5));
    $19 = (($this) + 136|0);
    if (!($17)) {
     HEAP8[$19>>0] = 0;
     break;
    }
    HEAP8[$19>>0] = 1;
    $20 = $1 < Math_fround(0.0);
    if ($20) {
     HEAP8[$19>>0] = 6;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $21 = (($this) + 136|0);
  $22 = Math_fround($1 * $3);
  $23 = Math_fround($22 * $$pre$i);
  $24 = $23 < Math_fround(0.0);
  $25 = $24&1;
  $26 = $25 << 2;
  $27 = $26 | 2;
  $28 = $27&255;
  HEAP8[$21>>0] = $28;
 }
 $29 = HEAP32[$transfer>>2]|0;
 $30 = $29 & 16384;
 $31 = ($30|0)==(0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = (($this) + 140|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEEEvRT_17TransferMetaFlags($transfer,$32,0);
 $33 = (($this) + 156|0);
 __ZN12ImmediatePtrI9TransformE8TransferI18StreamedBinaryReadILb0EEEEvRT_($33,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform25CompleteTransformTransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert$i = 0, $$pre$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 60|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = $4 < Math_fround(0.0);
 if ($5) {
  $6 = Math_fround(-$4);
  $8 = $6;
 } else {
  $8 = $4;
 }
 $7 = !($8 <= Math_fround(9.99999974737875163555E-5));
 $$phi$trans$insert$i = (($this) + 64|0);
 $$pre$i = Math_fround(HEAPF32[$$phi$trans$insert$i>>2]);
 do {
  if ($7) {
   label = 13;
  } else {
   $9 = Math_fround($3 - $$pre$i);
   $10 = $9 < Math_fround(0.0);
   if ($10) {
    $11 = Math_fround(-$9);
    $13 = $11;
   } else {
    $13 = $9;
   }
   $12 = !($13 <= Math_fround(9.99999974737875163555E-5));
   if ($12) {
    label = 13;
   } else {
    $14 = Math_fround($1 + Math_fround(-1.0));
    $15 = $14 < Math_fround(0.0);
    if ($15) {
     $16 = Math_fround(-$14);
     $18 = $16;
    } else {
     $18 = $14;
    }
    $17 = !($18 <= Math_fround(9.99999974737875163555E-5));
    $19 = (($this) + 136|0);
    if (!($17)) {
     HEAP8[$19>>0] = 0;
     break;
    }
    HEAP8[$19>>0] = 1;
    $20 = $1 < Math_fround(0.0);
    if ($20) {
     HEAP8[$19>>0] = 6;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $21 = (($this) + 136|0);
  $22 = Math_fround($1 * $3);
  $23 = Math_fround($22 * $$pre$i);
  $24 = $23 < Math_fround(0.0);
  $25 = $24&1;
  $26 = $25 << 2;
  $27 = $26 | 2;
  $28 = $27&255;
  HEAP8[$21>>0] = $28;
 }
 $29 = HEAP32[$transfer>>2]|0;
 $30 = $29 & 16384;
 $31 = ($30|0)==(0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = (($this) + 140|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEEEvRT_17TransferMetaFlags($transfer,$32,0);
 $33 = (($this) + 156|0);
 __ZN12ImmediatePtrI9TransformE8TransferI18StreamedBinaryReadILb1EEEEvRT_($33,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i2 = 0, $$pre4$i$i$i = 0, $$pre4$i$i$i4 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i5 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $i$01$i$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN11Quaternionf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 44|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  $8 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$3>>2] = $8;
  HEAP32[$2>>2] = $4;
  $11 = $4;$13 = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$1,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $$pre3$i$i$i = HEAP32[$5>>2]|0;
  $11 = $$pre$i$i$i;$13 = $$pre3$i$i$i;
 }
 $9 = (($this) + 48|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)<($13>>>0);
 if ($12) {
  $14 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$11>>2] = $14;
  HEAP32[$2>>2] = $10;
  $17 = $10;$19 = $13;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$9,4);
  $$pre4$i$i$i = HEAP32[$2>>2]|0;
  $$pre5$i$i$i = HEAP32[$5>>2]|0;
  $17 = $$pre4$i$i$i;$19 = $$pre5$i$i$i;
 }
 $15 = (($this) + 52|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)<($19>>>0);
 if ($18) {
  $20 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$17>>2] = $20;
  HEAP32[$2>>2] = $16;
  $23 = $16;$25 = $19;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$15,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre8 = HEAP32[$5>>2]|0;
  $23 = $$pre;$25 = $$pre8;
 }
 $21 = (($this) + 56|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)<($25>>>0);
 if ($24) {
  $26 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$23>>2] = $26;
  HEAP32[$2>>2] = $22;
  $29 = $22;$31 = $25;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$21,4);
  $$pre$i$i$i1 = HEAP32[$2>>2]|0;
  $$pre3$i$i$i2 = HEAP32[$5>>2]|0;
  $29 = $$pre$i$i$i1;$31 = $$pre3$i$i$i2;
 }
 $27 = (($this) + 60|0);
 $28 = (($29) + 4|0);
 $30 = ($28>>>0)<($31>>>0);
 if ($30) {
  $32 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$29>>2] = $32;
  HEAP32[$2>>2] = $28;
  $35 = $28;$37 = $31;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$27,4);
  $$pre4$i$i$i4 = HEAP32[$2>>2]|0;
  $$pre5$i$i$i5 = HEAP32[$5>>2]|0;
  $35 = $$pre4$i$i$i4;$37 = $$pre5$i$i$i5;
 }
 $33 = (($this) + 64|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)<($37>>>0);
 if ($36) {
  $38 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$35>>2] = $38;
  HEAP32[$2>>2] = $34;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$33,4);
 }
 $39 = HEAP32[$transfer>>2]|0;
 $40 = $39 & 16384;
 $41 = ($40|0)==(0);
 if (!($41)) {
  STACKTOP = sp;return;
 }
 $42 = (($this) + 148|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$size$i$i$i$i>>2] = $43;
 $44 = HEAP32[$2>>2]|0;
 $45 = (($44) + 4|0);
 $46 = HEAP32[$5>>2]|0;
 $47 = ($45>>>0)<($46>>>0);
 if ($47) {
  HEAP32[$44>>2] = $43;
  HEAP32[$2>>2] = $45;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i,4);
 }
 $48 = (($this) + 140|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$42>>2]|0;
 $51 = (($49) + ($50<<2)|0);
 $52 = ($50|0)==(0);
 if (!($52)) {
  $i$01$i$i$i$i = $49;
  while(1) {
   __ZN12ImmediatePtrI9TransformE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i$i,$transfer);
   $53 = (($i$01$i$i$i$i) + 4|0);
   $54 = ($53|0)==($51|0);
   if ($54) {
    break;
   } else {
    $i$01$i$i$i$i = $53;
   }
  }
 }
 $55 = (($this) + 156|0);
 __ZN12ImmediatePtrI9TransformE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($55,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Transform25CompleteTransformTransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i$i3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 16384;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,65601);
 $3 = (($this) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $9 = (($transfer) + 12|0);
  $10 = (($transfer) + 28|0);
  $11 = (($transfer) + 32|0);
  $i$01$i$i2$i = $4;
  while(1) {
   $12 = HEAP32[$i$01$i$i2$i>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$i$i$i$i$i3$i = 0;
   } else {
    $14 = (($12) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $$0$i$i$i$i$i3$i = $15;
   }
   $16 = HEAP32[$9>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$10>>2]|0;
   $20 = (FUNCTION_TABLE_iiii[$18 & 2047]($16,$$0$i$i$i$i$i3$i,$19)|0);
   $21 = HEAP8[$11>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if (!($22)) {
    $23 = (__Z38PreallocateObjectFromPersistentManagerib($20,0)|0);
    HEAP32[$i$01$i$i2$i>>2] = $23;
   }
   $24 = (($i$01$i$i2$i) + 4|0);
   $25 = ($24|0)==($7|0);
   if ($25) {
    break;
   } else {
    $i$01$i$i2$i = $24;
   }
  }
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,65537);
 $26 = (($this) + 156|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $$0$i$i$i = 0;
 } else {
  $29 = (($27) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $$0$i$i$i = $30;
 }
 $31 = (($transfer) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($transfer) + 28|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (FUNCTION_TABLE_iiii[$34 & 2047]($32,$$0$i$i$i,$36)|0);
 $38 = (($transfer) + 32|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if (!($40)) {
  $41 = (__Z38PreallocateObjectFromPersistentManagerib($37,0)|0);
  HEAP32[$26>>2] = $41;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __Z29FindRelativeTransformWithPathR9TransformPKcb($transform,$path,$isActiveOnly) {
 $transform = $transform|0;
 $path = $path|0;
 $isActiveOnly = $isActiveOnly|0;
 var $$0 = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $c$0$i = 0, $i$05 = 0;
 var $j$0$lcssa = 0, $j$02 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $n$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[610840>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[610840>>2] = $1;
 $2 = ($1>>>0)>(2000);
 L1: do {
  if ($2) {
   $$0 = 0;
  } else {
   $3 = HEAP8[$path>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    $$0 = $transform;
   } else {
    $74 = $3;$c$0$i = $path;
    while(1) {
     if ((($74<<24>>24) == 0) | (($74<<24>>24) == 47)) {
      break;
     }
     $5 = (($c$0$i) + 1|0);
     $$pre = HEAP8[$5>>0]|0;
     $74 = $$pre;$c$0$i = $5;
    }
    $6 = $c$0$i;
    $7 = $path;
    $8 = (($6) - ($7))|0;
    do {
     if ((($3<<24>>24) == 47)) {
      __THREW__ = 0;
      $9 = (invoke_ii(3250,($path|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       label = 29;
      } else {
       $$0 = $9;
       break L1;
      }
     } else if ((($3<<24>>24) == 46)) {
      $12 = (($path) + 1|0);
      $13 = HEAP8[$12>>0]|0;
      $14 = ($13<<24>>24)==(46);
      if ($14) {
       $15 = (($transform) + 156|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = (($path) + 2|0);
       $18 = HEAP8[$17>>0]|0;
       if ((($18<<24>>24) == 0)) {
        $$0 = $16;
        break L1;
       } else if (!((($18<<24>>24) == 47))) {
        break;
       }
       $19 = ($16|0)==(0|0);
       if ($19) {
        $$0 = 0;
        break L1;
       }
       $20 = (($path) + 3|0);
       __THREW__ = 0;
       $21 = (invoke_iiii(1546,($16|0),($20|0),0)|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        label = 29;
       } else {
        $$0 = $21;
        break L1;
       }
      }
     }
    } while(0);
    if ((label|0) == 29) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     $lpad$phi$index = $70;$lpad$phi$index2 = $71;
     $72 = HEAP32[610840>>2]|0;
     $73 = (($72) + -1)|0;
     HEAP32[610840>>2] = $73;
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    $24 = (($transform) + 140|0);
    $25 = (($transform) + 148|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0);
    if ($27) {
     $$0 = 0;
    } else {
     $28 = HEAP32[$24>>2]|0;
     $29 = ($8|0)>(0);
     $30 = (($path) + ($8)|0);
     $$sum = (($8) + 1)|0;
     $31 = (($path) + ($$sum)|0);
     $i$05 = $28;
     while(1) {
      $32 = HEAP32[$i$05>>2]|0;
      if ($isActiveOnly) {
       $33 = (($32) + 24|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ($34|0)==(0|0);
       if (!($35)) {
        __THREW__ = 0;
        $36 = (invoke_ii(3251,($34|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        }
        if ($36) {
         label = 17;
        }
       }
      } else {
       label = 17;
      }
      if ((label|0) == 17) {
       label = 0;
       $39 = HEAP32[$32>>2]|0;
       $40 = (($39) + 32|0);
       $41 = HEAP32[$40>>2]|0;
       __THREW__ = 0;
       $42 = (invoke_ii($41|0,($32|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $45 = (_strlen(($42|0))|0);
       $46 = ($45|0)==($8|0);
       if ($46) {
        L28: do {
         if ($29) {
          $j$02 = 0;$n$01 = $42;
          while(1) {
           $47 = (($path) + ($j$02)|0);
           $48 = HEAP8[$47>>0]|0;
           $49 = HEAP8[$n$01>>0]|0;
           $50 = ($48<<24>>24)==($49<<24>>24);
           if (!($50)) {
            $j$0$lcssa = $j$02;
            break L28;
           }
           $51 = (($j$02) + 1)|0;
           $52 = (($n$01) + 1|0);
           $53 = ($51|0)<($8|0);
           if ($53) {
            $j$02 = $51;$n$01 = $52;
           } else {
            $j$0$lcssa = $51;
            break;
           }
          }
         } else {
          $j$0$lcssa = 0;
         }
        } while(0);
        $54 = ($j$0$lcssa|0)==($8|0);
        if ($54) {
         $55 = HEAP8[$30>>0]|0;
         $56 = ($55<<24>>24)==(0);
         if ($56) {
          $$0 = $32;
          break L1;
         }
         __THREW__ = 0;
         $57 = (invoke_iiii(1546,($32|0),($31|0),0)|0);
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          break;
         }
         $60 = ($57|0)==(0|0);
         if (!($60)) {
          $$0 = $57;
          break L1;
         }
        }
       }
      }
      $61 = (($i$05) + 4|0);
      $62 = HEAP32[$24>>2]|0;
      $63 = HEAP32[$25>>2]|0;
      $64 = (($62) + ($63<<2)|0);
      $65 = ($61|0)==($64|0);
      if ($65) {
       $$0 = 0;
       break L1;
      } else {
       $i$05 = $61;
      }
     }
     $68 = ___cxa_find_matching_catch()|0;
     $69 = tempRet0;
     $lpad$phi$index = $68;$lpad$phi$index2 = $69;
     $72 = HEAP32[610840>>2]|0;
     $73 = (($72) + -1)|0;
     HEAP32[610840>>2] = $73;
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $66 = HEAP32[610840>>2]|0;
 $67 = (($66) + -1)|0;
 HEAP32[610840>>2] = $67;
 STACKTOP = sp;return ($$0|0);
}
function __Z27FindActiveTransformWithPathPKc($path) {
 $path = $path|0;
 var $$0 = 0, $$path = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$path>>0]|0;
 $1 = ($0<<24>>24)==(47);
 $2 = (($path) + 1|0);
 $$path = $1 ? $2 : $path;
 $3 = HEAP8[$$path>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__ZN5Unity20GetGameObjectManagerEv()|0);
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($5|0);
 L4: do {
  if (!($8)) {
   $10 = $7;
   while(1) {
    $13 = (($10) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (__ZL31FindActiveTransformWithPathImplPKcRN5Unity10GameObjectEb($$path,$14,$1)|0);
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     $$0 = $15;
     break;
    }
    $9 = (($10) + 4|0);
    $11 = HEAP32[$9>>2]|0;
    $12 = ($11|0)==($5|0);
    if ($12) {
     break L4;
    } else {
     $10 = $11;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $17 = (__ZN5Unity20GetGameObjectManagerEv()|0);
 $18 = (($17) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 8|0);
 $21 = ($19|0)==($20|0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $23 = $19;
 }
 while(1) {
  $26 = (($23) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (__ZL31FindActiveTransformWithPathImplPKcRN5Unity10GameObjectEb($$path,$27,$1)|0);
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $$0 = $28;
   label = 8;
   break;
  }
  $22 = (($23) + 4|0);
  $24 = HEAP32[$22>>2]|0;
  $25 = ($24|0)==($20|0);
  if ($25) {
   $$0 = 0;
   label = 8;
   break;
  } else {
   $23 = $24;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z22CalculateTransformPathRK9TransformPS0_($agg$result,$transform,$to) {
 $agg$result = $agg$result|0;
 $transform = $transform|0;
 $to = $to|0;
 var $$ = 0, $$0 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i9 = 0, $cur$034 = 0, $eh$lpad$body$index13Z2D = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi22$index = 0;
 var $lpad$phi22$index7 = 0, $or$cond = 0, $or$cond33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $2 = ($transform|0)!=($to|0);
 $3 = ($transform|0)!=(0|0);
 $or$cond33 = $2 & $3;
 if (!($or$cond33)) {
  STACKTOP = sp;return;
 }
 $4 = (($1) + 1|0);
 $5 = (($agg$result) + 1|0);
 $6 = (($0) + 1|0);
 $7 = (($1) + 8|0);
 $8 = (($0) + 8|0);
 $9 = (($0) + 4|0);
 $10 = (($1) + 4|0);
 $11 = (($agg$result) + 8|0);
 $12 = (($agg$result) + 4|0);
 $14 = 0;$cur$034 = $transform;
 while(1) {
  $13 = $14 & 1;
  $15 = ($13<<24>>24)==(0);
  if ($15) {
   $17 = $14&255;
   $18 = $17 >>> 1;
   $20 = $18;
  } else {
   $16 = HEAP32[$12>>2]|0;
   $20 = $16;
  }
  $19 = ($20|0)==(0);
  $21 = HEAP32[$cur$034>>2]|0;
  $22 = (($21) + 32|0);
  $23 = HEAP32[$22>>2]|0;
  if ($19) {
   __THREW__ = 0;
   $113 = (invoke_ii($23|0,($cur$034|0))|0);
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if ($115) {
    label = 45;
    break;
   }
   __THREW__ = 0;
   (invoke_iii(2392,($agg$result|0),($113|0))|0);
   $116 = __THREW__; __THREW__ = 0;
   $117 = $116&1;
   if ($117) {
    label = 45;
    break;
   }
  } else {
   __THREW__ = 0;
   $24 = (invoke_ii($23|0,($cur$034|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 45;
    break;
   }
   ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
   $27 = HEAP8[$agg$result>>0]|0;
   $28 = $27 & 1;
   $29 = ($28<<24>>24)==(0);
   if ($29) {
    $31 = $27&255;
    $32 = $31 >>> 1;
    $34 = $32;
   } else {
    $30 = HEAP32[$12>>2]|0;
    $34 = $30;
   }
   $33 = (($34) + 1)|0;
   $35 = ($33>>>0)>(4294967279);
   if ($35) {
    label = 12;
    break;
   }
   $38 = ($33>>>0)<(11);
   if ($38) {
    HEAP8[$1>>0] = 2;
    $__p$0$i$i = $4;
   } else {
    $39 = (($34) + 17)|0;
    $40 = $39 & -16;
    __THREW__ = 0;
    $41 = (invoke_ii(2988,($40|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 21;
     break;
    }
    HEAP32[$7>>2] = $41;
    $44 = $40 | 1;
    HEAP32[$1>>2] = $44;
    HEAP32[$10>>2] = 1;
    $__p$0$i$i = $41;
   }
   HEAP8[$__p$0$i$i>>0] = 47;
   $45 = (($__p$0$i$i) + 1|0);
   HEAP8[$45>>0] = 0;
   if ($29) {
    $47 = $5;
   } else {
    $46 = HEAP32[$11>>2]|0;
    $47 = $46;
   }
   __THREW__ = 0;
   (invoke_iiii(1480,($1|0),($47|0),($34|0))|0);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    label = 21;
    break;
   }
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
   $58 = (_strlen(($24|0))|0);
   $59 = HEAP8[$1>>0]|0;
   $60 = $59 & 1;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    $63 = $59&255;
    $64 = $63 >>> 1;
    $66 = $64;
   } else {
    $62 = HEAP32[$10>>2]|0;
    $66 = $62;
   }
   $65 = (($66) + ($58))|0;
   $67 = ($65>>>0)>(4294967279);
   if ($67) {
    label = 29;
    break;
   }
   $70 = ($65>>>0)<(11);
   if ($70) {
    $71 = $58 << 1;
    $72 = $71&255;
    HEAP8[$0>>0] = $72;
    $__p$0$i$i9 = $6;
   } else {
    $73 = (($65) + 16)|0;
    $74 = $73 & -16;
    __THREW__ = 0;
    $75 = (invoke_ii(2988,($74|0))|0);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     label = 36;
     break;
    }
    HEAP32[$8>>2] = $75;
    $78 = $74 | 1;
    HEAP32[$0>>2] = $78;
    HEAP32[$9>>2] = $58;
    $__p$0$i$i9 = $75;
   }
   _memcpy(($__p$0$i$i9|0),($24|0),($58|0))|0;
   $79 = (($__p$0$i$i9) + ($58)|0);
   HEAP8[$79>>0] = 0;
   $80 = HEAP32[$7>>2]|0;
   $$ = $61 ? $4 : $80;
   __THREW__ = 0;
   (invoke_iiii(1480,($0|0),($$|0),($66|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 36;
    break;
   }
   __THREW__ = 0;
   (invoke_iii(2233,($agg$result|0),($0|0))|0);
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   if ($92) {
    label = 48;
    break;
   }
   $93 = HEAP8[$0>>0]|0;
   $94 = $93 & 1;
   $95 = ($94<<24>>24)==(0);
   if (!($95)) {
    $96 = HEAP32[$8>>2]|0;
    __ZdlPv($96);
   }
   $97 = HEAP8[$1>>0]|0;
   $98 = $97 & 1;
   $99 = ($98<<24>>24)==(0);
   if (!($99)) {
    $100 = HEAP32[$7>>2]|0;
    __ZdlPv($100);
   }
  }
  $118 = (($cur$034) + 156|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = ($119|0)!=($to|0);
  $121 = ($119|0)!=(0|0);
  $or$cond = $120 & $121;
  if (!($or$cond)) {
   label = 56;
   break;
  }
  $$pre = HEAP8[$agg$result>>0]|0;
  $14 = $$pre;$cur$034 = $119;
 }
 do {
  if ((label|0) == 12) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    $lpad$phi$index = $52;$lpad$phi$index2 = $53;
    label = 23;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 21) {
   $50 = ___cxa_find_matching_catch()|0;
   $51 = tempRet0;
   $lpad$phi$index = $50;$lpad$phi$index2 = $51;
   label = 23;
  }
  else if ((label|0) == 29) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    $85 = ___cxa_find_matching_catch()|0;
    $86 = tempRet0;
    $lpad$phi22$index = $85;$lpad$phi22$index7 = $86;
    label = 38;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 36) {
   $83 = ___cxa_find_matching_catch()|0;
   $84 = tempRet0;
   $lpad$phi22$index = $83;$lpad$phi22$index7 = $84;
   label = 38;
  }
  else if ((label|0) == 45) {
   $101 = ___cxa_find_matching_catch()|0;
   $102 = tempRet0;
   $eh$lpad$body$index13Z2D = $102;$eh$lpad$body$indexZ2D = $101;
   label = 46;
  }
  else if ((label|0) == 48) {
   $103 = ___cxa_find_matching_catch()|0;
   $104 = tempRet0;
   $105 = HEAP8[$0>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $$0 = $104;$$02 = $103;
    label = 50;
   } else {
    $108 = HEAP32[$8>>2]|0;
    __ZdlPv($108);
    $$0 = $104;$$02 = $103;
    label = 50;
   }
  }
  else if ((label|0) == 56) {
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 23) {
  $54 = HEAP8[$1>>0]|0;
  $55 = $54 & 1;
  $56 = ($55<<24>>24)==(0);
  if ($56) {
   $eh$lpad$body$index13Z2D = $lpad$phi$index2;$eh$lpad$body$indexZ2D = $lpad$phi$index;
   label = 46;
  } else {
   $57 = HEAP32[$7>>2]|0;
   __ZdlPv($57);
   $eh$lpad$body$index13Z2D = $lpad$phi$index2;$eh$lpad$body$indexZ2D = $lpad$phi$index;
   label = 46;
  }
 }
 else if ((label|0) == 38) {
  $87 = HEAP8[$0>>0]|0;
  $88 = $87 & 1;
  $89 = ($88<<24>>24)==(0);
  if (!($89)) {
   $90 = HEAP32[$8>>2]|0;
   __ZdlPv($90);
  }
  $$0 = $lpad$phi22$index7;$$02 = $lpad$phi22$index;
  label = 50;
 }
 if ((label|0) == 46) {
  $$1 = $eh$lpad$body$index13Z2D;$$13 = $eh$lpad$body$indexZ2D;
 }
 else if ((label|0) == 50) {
  $109 = HEAP8[$1>>0]|0;
  $110 = $109 & 1;
  $111 = ($110<<24>>24)==(0);
  if ($111) {
   $$1 = $$0;$$13 = $$02;
  } else {
   $112 = HEAP32[$7>>2]|0;
   __ZdlPv($112);
   $$1 = $$0;$$13 = $$02;
  }
 }
 $122 = HEAP8[$agg$result>>0]|0;
 $123 = $122 & 1;
 $124 = ($123<<24>>24)==(0);
 if ($124) {
  ___resumeException($$13|0);
  // unreachable;
 }
 $125 = HEAP32[$11>>2]|0;
 __ZdlPv($125);
 ___resumeException($$13|0);
 // unreachable;
}
function __ZL31FindActiveTransformWithPathImplPKcRN5Unity10GameObjectEb($path,$go,$needsToBeRoot) {
 $path = $path|0;
 $go = $go|0;
 $needsToBeRoot = $needsToBeRoot|0;
 var $$0 = 0, $$01 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$go>>2]|0;
 $1 = (($0) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($go)|0);
 $4 = (_strlen(($3|0))|0);
 $5 = (_strncmp($3,$path,$4)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($path) + ($4)|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(47);
 if ($9) {
  $$sum = (($4) + 1)|0;
  $10 = (($path) + ($$sum)|0);
  $$01 = $10;
 } else {
  $$01 = $7;
 }
 $11 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ($needsToBeRoot) {
  $13 = (($11) + 156|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $16 = HEAP8[$$01>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $18 = (($11) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if (!($20)) {
   $21 = (__ZNK5Unity10GameObject8IsActiveEv($19)|0);
   if ($21) {
    $$0 = $11;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $22 = (__Z29FindRelativeTransformWithPathR9TransformPKcb($11,$$01,1)|0);
 $$0 = $22;
 STACKTOP = sp;return ($$0|0);
}
function __Z22IsChildOrSameTransformR9TransformS0_($transform,$inParent) {
 $transform = $transform|0;
 $inParent = $inParent|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $child$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($transform|0)==(0|0);
 L1: do {
  if ($0) {
   $$0 = 0;
  } else {
   $child$01 = $transform;
   while(1) {
    $1 = ($child$01|0)==($inParent|0);
    if ($1) {
     $$0 = 1;
     break L1;
    }
    $2 = (($child$01) + 156|0);
    $3 = HEAP32[$2>>2]|0;
    $4 = ($3|0)==(0|0);
    if ($4) {
     $$0 = 0;
     break;
    } else {
     $child$01 = $3;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z17GetTransformDepthR9Transform($transform) {
 $transform = $transform|0;
 var $0 = 0, $1 = 0, $depth$0 = 0, $parent$0 = 0, $parent$0$in = 0, $transform$pn = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $depth$0 = 0;$transform$pn = $transform;
 while(1) {
  $parent$0$in = (($transform$pn) + 156|0);
  $parent$0 = HEAP32[$parent$0$in>>2]|0;
  $0 = ($parent$0|0)==(0|0);
  $1 = (($depth$0) + 1)|0;
  if ($0) {
   break;
  } else {
   $depth$0 = $1;$transform$pn = $parent$0;
  }
 }
 STACKTOP = sp;return ($depth$0|0);
}
function __ZN9Transform21CopyTRSNoNotificationERKS_($this,$src) {
 $this = $this|0;
 $src = $src|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = (($src) + 28|0);
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($this) + 44|0);
 $3 = (($src) + 44|0);
 ;HEAP32[$2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$3+8>>2]|0;
 $4 = (($this) + 56|0);
 $5 = (($src) + 56|0);
 ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;
 $6 = (($src) + 136|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = (($this) + 136|0);
 HEAP8[$8>>0] = $7;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6appendEPKcj($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $14 = 10;$7 = $0;
 } else {
  $3 = HEAP32[$this>>2]|0;
  $4 = $3 & -2;
  $phitmp$i = (($4) + -1)|0;
  $5 = $3&255;
  $14 = $phitmp$i;$7 = $5;
 }
 $6 = $7 & 1;
 $8 = ($6<<24>>24)==(0);
 if ($8) {
  $11 = $7&255;
  $12 = $11 >>> 1;
  $15 = $12;
 } else {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $15 = $10;
 }
 $13 = (($14) - ($15))|0;
 $16 = ($13>>>0)<($__n>>>0);
 if ($16) {
  $33 = (($__n) - ($14))|0;
  $34 = (($33) + ($15))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$14,$34,$15,$15,0,$__n,$__s);
  STACKTOP = sp;return ($this|0);
 }
 $17 = ($__n|0)==(0);
 if ($17) {
  STACKTOP = sp;return ($this|0);
 }
 $18 = $7 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $22 = (($this) + 1|0);
  $24 = $22;
 } else {
  $20 = (($this) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $24 = $21;
 }
 $23 = (($24) + ($15)|0);
 _memcpy(($23|0),($__s|0),($__n|0))|0;
 $25 = (($15) + ($__n))|0;
 $26 = HEAP8[$this>>0]|0;
 $27 = $26 & 1;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  $30 = $25 << 1;
  $31 = $30&255;
  HEAP8[$this>>0] = $31;
 } else {
  $29 = (($this) + 4|0);
  HEAP32[$29>>2] = $25;
 }
 $32 = (($24) + ($25)|0);
 HEAP8[$32>>0] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZN12ImmediatePtrI9TransformE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i3 = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = HEAP32[$this>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($7) {
  if ($9) {
   $35 = 0;
  } else {
   $33 = (($8) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = $34;
  }
  HEAP32[$localIdentifier>>2] = $35;
  $36 = $0;
  $37 = $36;
  HEAP32[$37>>2] = 0;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = 0;
  $40 = (($transfer) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 4|0);
  $43 = (($transfer) + 20|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42>>>0)<($44>>>0);
  if ($45) {
   HEAP32[$41>>2] = $35;
   HEAP32[$40>>2] = $42;
   $47 = $42;$49 = $44;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($40,$localIdentifier,4);
   $$pre = HEAP32[$40>>2]|0;
   $$pre5 = HEAP32[$43>>2]|0;
   $47 = $$pre;$49 = $$pre5;
  }
  $46 = (($47) + 8|0);
  $48 = ($46>>>0)<($49>>>0);
  if ($48) {
   $50 = $0;
   $51 = $50;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($50) + 4)|0;
   $54 = $53;
   $55 = HEAP32[$54>>2]|0;
   $56 = $47;
   $57 = $56;
   HEAP32[$57>>2] = $52;
   $58 = (($56) + 4)|0;
   $59 = $58;
   HEAP32[$59>>2] = $55;
   HEAP32[$40>>2] = $46;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($40,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  if ($9) {
   $$0$i3 = 0;
  } else {
   $10 = (($8) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $$0$i3 = $11;
  }
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($$0$i3,$localIdentifier);
  $12 = (($transfer) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 4|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)<($16>>>0);
  if ($17) {
   $18 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$13>>2] = $18;
   HEAP32[$12>>2] = $14;
   $20 = $14;$22 = $16;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($12,$localIdentifier,4);
   $$pre6 = HEAP32[$12>>2]|0;
   $$pre7 = HEAP32[$15>>2]|0;
   $20 = $$pre6;$22 = $$pre7;
  }
  $19 = (($20) + 8|0);
  $21 = ($19>>>0)<($22>>>0);
  if ($21) {
   $23 = $0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + 4)|0;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = $20;
   $30 = $29;
   HEAP32[$30>>2] = $25;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = $28;
   HEAP32[$12>>2] = $19;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($12,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN12ImmediatePtrI9TransformE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $39 = (($transfer) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 4|0);
  $42 = (($transfer) + 20|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($41>>>0)>($43>>>0);
  if ($44) {
   __ZN12CachedReader15UpdateReadCacheEPvj($39,$localIdentifier,4);
   $$pre$i$i$i1 = HEAP32[$localIdentifier>>2]|0;
   $$pre = HEAP32[$39>>2]|0;
   $$pre13 = HEAP32[$42>>2]|0;
   $46 = $$pre$i$i$i1;$49 = $$pre;$51 = $$pre13;
  } else {
   $45 = HEAP32[$40>>2]|0;
   HEAP32[$localIdentifier>>2] = $45;
   HEAP32[$39>>2] = $41;
   $46 = $45;$49 = $41;$51 = $43;
  }
  $47 = (_llvm_bswap_i32(($46|0))|0);
  HEAP32[$localIdentifier>>2] = $47;
  $48 = (($49) + 8|0);
  $50 = ($48>>>0)>($51>>>0);
  if ($50) {
   __ZN12CachedReader15UpdateReadCacheEPvj($39,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre14 = HEAP32[$localIdentifier>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$62 = $$pre$i$i$i;$64 = $$pre3$i$i$i;$66 = $$pre14;
  } else {
   $52 = $49;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = $0;
   $59 = $58;
   HEAP32[$59>>2] = $54;
   $60 = (($58) + 4)|0;
   $61 = $60;
   HEAP32[$61>>2] = $57;
   HEAP32[$39>>2] = $48;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$62 = $54;$64 = $57;$66 = $47;
  }
  $63 = (_llvm_bswap_i32(($62|0))|0);
  $65 = (_llvm_bswap_i32(($64|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $65;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $63;
  $67 = (__Z38PreallocateObjectFromPersistentManagerib($66,0)|0);
  HEAP32[$this>>2] = $67;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  $10 = (($transfer) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 4|0);
  $13 = (($transfer) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12>>>0)>($14>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre15 = HEAP32[$10>>2]|0;
   $$pre16 = HEAP32[$13>>2]|0;
   $17 = $$pre$i$i$i11;$20 = $$pre15;$22 = $$pre16;
  } else {
   $16 = HEAP32[$11>>2]|0;
   HEAP32[$localIdentifier>>2] = $16;
   HEAP32[$10>>2] = $12;
   $17 = $16;$20 = $12;$22 = $14;
  }
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$localIdentifier>>2] = $18;
  $19 = (($20) + 8|0);
  $21 = ($19>>>0)>($22>>>0);
  if ($21) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$33 = $$pre$i$i$i5;$35 = $$pre3$i$i$i7;
  } else {
   $23 = $20;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + 4)|0;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = $0;
   $30 = $29;
   HEAP32[$30>>2] = $25;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = $28;
   HEAP32[$10>>2] = $19;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$33 = $25;$35 = $28;
  }
  $34 = (_llvm_bswap_i32(($33|0))|0);
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $36;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $34;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $37 = HEAP32[$instanceID>>2]|0;
  $38 = (__Z38PreallocateObjectFromPersistentManagerib($37,$9)|0);
  HEAP32[$this>>2] = $38;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<2)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN12ImmediatePtrI9TransformE8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 4|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = $23 << 2;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = $22 >> 2;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 2;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,610504,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 2;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,610504,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 2;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<2)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<2)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   HEAP32[$$01$i$i>>2] = 0;
  }
  $30 = (($$01$i$i) + 4|0);
  $31 = ($30|0)==($25|0);
  if ($31) {
   break;
  } else {
   $$01$i$i = $30;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN12ImmediatePtrI9TransformE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $33 = (($transfer) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + 4|0);
  $36 = (($transfer) + 20|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($35>>>0)>($37>>>0);
  if ($38) {
   __ZN12CachedReader15UpdateReadCacheEPvj($33,$localIdentifier,4);
   $$pre = HEAP32[$33>>2]|0;
   $$pre3 = HEAP32[$36>>2]|0;
   $41 = $$pre;$43 = $$pre3;
  } else {
   $39 = HEAP32[$34>>2]|0;
   HEAP32[$localIdentifier>>2] = $39;
   HEAP32[$33>>2] = $35;
   $41 = $35;$43 = $37;
  }
  $40 = (($41) + 8|0);
  $42 = ($40>>>0)>($43>>>0);
  if ($42) {
   __ZN12CachedReader15UpdateReadCacheEPvj($33,$0,8);
  } else {
   $44 = $41;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 4)|0;
   $48 = $47;
   $49 = HEAP32[$48>>2]|0;
   $50 = $0;
   $51 = $50;
   HEAP32[$51>>2] = $46;
   $52 = (($50) + 4)|0;
   $53 = $52;
   HEAP32[$53>>2] = $49;
   HEAP32[$33>>2] = $40;
  }
  $54 = HEAP32[$localIdentifier>>2]|0;
  $55 = (__Z38PreallocateObjectFromPersistentManagerib($54,0)|0);
  HEAP32[$this>>2] = $55;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  $10 = (($transfer) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 4|0);
  $13 = (($transfer) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12>>>0)>($14>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$localIdentifier,4);
   $$pre4 = HEAP32[$10>>2]|0;
   $$pre5 = HEAP32[$13>>2]|0;
   $18 = $$pre4;$20 = $$pre5;
  } else {
   $16 = HEAP32[$11>>2]|0;
   HEAP32[$localIdentifier>>2] = $16;
   HEAP32[$10>>2] = $12;
   $18 = $12;$20 = $14;
  }
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($10,$0,8);
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$10>>2] = $17;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $31 = HEAP32[$instanceID>>2]|0;
  $32 = (__Z38PreallocateObjectFromPersistentManagerib($31,$9)|0);
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<2)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN12ImmediatePtrI9TransformE8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 4|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 2;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 2;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12ImmediatePtrI9TransformE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $instanceID = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier = sp;
 $instanceID = sp + 16|0;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,610848,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,610864,0);
  $12 = HEAP32[$localIdentifier>>2]|0;
  $13 = (__Z38PreallocateObjectFromPersistentManagerib($12,0)|0);
  HEAP32[$this>>2] = $13;
  STACKTOP = sp;return;
 } else {
  $8 = $5 & 8388608;
  $9 = ($8|0)!=(0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,610848,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,610864,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$instanceID);
  $10 = HEAP32[$instanceID>>2]|0;
  $11 = (__Z38PreallocateObjectFromPersistentManagerib($10,$9)|0);
  HEAP32[$this>>2] = $11;
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,610904,610904,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI12ImmediatePtrI9TransformELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<2)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,610880,610888,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN12ImmediatePtrI9TransformE8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 4|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,610880,610888,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN12ImmediatePtrI9TransformE8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 4|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11Quaternionf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __ZN11Quaternionf8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i3 = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $this;$12 = $$pre;$14 = $$pre16;$8 = $$pre$i$i$i3;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i8 = HEAP32[$10>>2]|0;
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $10;$17 = $$pre$i$i$i8;$21 = $$pre17;$23 = $$pre18;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i13 = HEAP32[$19>>2]|0;
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $19;$26 = $$pre$i$i$i13;$30 = $$pre19;$32 = $$pre20;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i = HEAP32[$28>>2]|0;
  $$pre$phi$i$i$iZ2D = $28;$35 = $$pre$i$i$i;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $36;
  STACKTOP = sp;return;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $28;$35 = $34;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $36;
  STACKTOP = sp;return;
 }
}
function __ZN11Quaternionf8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN11Quaternionf8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = (__ZNK16TypeTreeIterator7GetNodeEv($0)|0);
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 | 2097152;
 $5 = (($transfer) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($transfer) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($7) + (($9*24)|0)|0) + 20|0);
 HEAP32[$10>>2] = $4;
 $11 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610912,$11,$this,0);
 $12 = HEAP32[$5>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$8>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610920,$11,$16,0);
 $17 = HEAP32[$5>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$8>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $21 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610928,$11,$21,0);
 $22 = HEAP32[$5>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$8>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $26 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610936,$11,$26,0);
 $27 = HEAP32[$5>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$8>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __Z8StripifyPKjiRNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEE($faces,$count,$strip) {
 $faces = $faces|0;
 $count = $count|0;
 $strip = $strip|0;
 var $$0 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0;
 var $striper = 0, $stripinput = 0, $stripresult = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $stripinput = sp + 40|0;
 $stripresult = sp;
 $striper = sp + 12|0;
 $0 = HEAP32[$strip>>2]|0;
 $1 = (($strip) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if (!($3)) {
  $__new_last2$i$i$i = $0;
  $scevgep$i$i$i = (($2) + -4|0);
  $4 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($4)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $5 = $uglygep3$i$i$i >>> 2;
  $6 = $5 ^ -1;
  $scevgep4$i$i$i = (($2) + ($6<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i;
 }
 $7 = ($count|0)==(0);
 if ($7) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $8 = (($stripinput) + 4|0);
 $9 = (($stripinput) + 8|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$8>>2] = $faces;
 $10 = (($count|0) / 3)&-1;
 HEAP32[$stripinput>>2] = $10;
 __ZN7StriperC2Ev($striper);
 __THREW__ = 0;
 $11 = (invoke_iii(2407,($striper|0),($stripinput|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 do {
  if (!($13)) {
   if ($11) {
    __THREW__ = 0;
    $14 = (invoke_iii(2408,($striper|0),($stripresult|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    if ($14) {
     $17 = HEAP32[$stripresult>>2]|0;
     $18 = ($17|0)==(1);
     if ($18) {
      $19 = (($stripresult) + 4|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = HEAP32[$20>>2]|0;
      $22 = (($stripresult) + 8|0);
      $23 = HEAP32[$22>>2]|0;
      __THREW__ = 0;
      invoke_vii(2725,($strip|0),($21|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = (($23) + ($21<<2)|0);
      __THREW__ = 0;
      invoke_viii(1750,($strip|0),($23|0),($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      } else {
       $$0 = 1;
      }
     } else {
      $$0 = 0;
     }
    } else {
     $$0 = 0;
    }
   } else {
    $$0 = 0;
   }
   __ZN7StriperD2Ev($striper);
   $$1 = $$0;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3492,($striper|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch(0|0)|0;
  $34 = tempRet0;
  ___clang_call_terminate($33);
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
 return 0|0;
}
function __Z15reserve_trimmedINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy1 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0;
 var $temp = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 28|0;
 $$byval_copy1 = sp;
 $0 = sp + 4|0;
 $temp = sp + 8|0;
 $1 = sp + 20|0;
 $2 = sp + 24|0;
 $3 = (($v) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$v>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9|0)==($sz|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $11 = (($temp) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($temp) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = ($sz|0)==(0);
 if ($13) {
  label = 5;
 } else {
  $14 = $sz << 2;
  HEAP32[$$byval_copy1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$$byval_copy1+0>>2]|0;
  $15 = (invoke_iiiiiii(102,($14|0),16,($$byval_copy4|0),0,(610944|0),79)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $18 = (($15) + ($sz<<2)|0);
   HEAP32[$temp>>2] = $15;
   HEAP32[$11>>2] = $15;
   HEAP32[$12>>2] = $18;
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $19 = HEAP32[$v>>2]|0;
  HEAP32[$1>>2] = $19;
  $20 = (($v) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  HEAP32[$2>>2] = $21;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_viii(1751,($temp|0),($$byval_copy1|0),($$byval_copy4|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if (!($23)) {
   $24 = HEAP32[$temp>>2]|0;
   $25 = HEAP32[$v>>2]|0;
   HEAP32[$temp>>2] = $25;
   HEAP32[$v>>2] = $24;
   $26 = HEAP32[$11>>2]|0;
   $27 = HEAP32[$20>>2]|0;
   HEAP32[$11>>2] = $27;
   HEAP32[$20>>2] = $26;
   $28 = HEAP32[$12>>2]|0;
   $29 = HEAP32[$3>>2]|0;
   HEAP32[$12>>2] = $29;
   HEAP32[$3>>2] = $28;
   $30 = ($25|0)==(0|0);
   if ($30) {
    STACKTOP = sp;return;
   }
   $31 = ($27|0)==($25|0);
   if (!($31)) {
    $__new_last2$i$i$i$i$i1 = $25;
    $scevgep$i$i$i$i$i2 = (($27) + -4|0);
    $32 = (0 - ($__new_last2$i$i$i$i$i1))|0;
    $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($32)|0);
    $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
    $33 = $uglygep3$i$i$i$i$i5 >>> 2;
    $34 = $33 ^ -1;
    $scevgep4$i$i$i$i$i6 = (($27) + ($34<<2)|0);
    HEAP32[$11>>2] = $scevgep4$i$i$i$i$i6;
   }
   HEAP32[$$byval_copy1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$$byval_copy1+0>>2]|0;
   invoke_vii(2591,($25|0),($$byval_copy4|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $37 = ___cxa_find_matching_catch()|0;
    $38 = tempRet0;
    ___cxa_call_unexpected(($37|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 $39 = ___cxa_find_matching_catch()|0;
 $40 = tempRet0;
 $41 = HEAP32[$temp>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  ___resumeException($39|0);
  // unreachable;
 }
 $43 = HEAP32[$11>>2]|0;
 $44 = ($43|0)==($41|0);
 if (!($44)) {
  $__new_last2$i$i$i$i$i = $41;
  $scevgep$i$i$i$i$i = (($43) + -4|0);
  $45 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($45)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $46 = $uglygep3$i$i$i$i$i >>> 2;
  $47 = $46 ^ -1;
  $scevgep4$i$i$i$i$i = (($43) + ($47<<2)|0);
  HEAP32[$11>>2] = $scevgep4$i$i$i$i$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy4|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  ___cxa_call_unexpected(($50|0));
  // unreachable;
 } else {
  ___resumeException($39|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i13 = 0, $$01$i = 0, $$01$i8 = 0, $$byval_copy1 = 0, $$promoted$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0;
 var $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i3 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep5$i = 0, $scevgep5$i10 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i5 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep4$i = 0, $uglygep4$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = $__last;
 $2 = $__first;
 $3 = (($1) - ($2))|0;
 $4 = $3 >> 2;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$this>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($4>>>0)>($11>>>0);
 if (!($12)) {
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14;
  $16 = (($15) - ($9))|0;
  $17 = $16 >> 2;
  $18 = ($4>>>0)>($17>>>0);
  if (!($18)) {
   $31 = $__last;
   $32 = (($31) - ($2))|0;
   $33 = $32 >> 2;
   _memmove(($7|0),($__first|0),($32|0))|0;
   $34 = (($7) + ($33<<2)|0);
   $35 = HEAP32[$13>>2]|0;
   $36 = ($35|0)==($34|0);
   if ($36) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $34;
   $scevgep$i$i = (($35) + -4|0);
   $37 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($37)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $38 = $uglygep3$i$i >>> 2;
   $39 = $38 ^ -1;
   $scevgep4$i$i = (($35) + ($39<<2)|0);
   HEAP32[$13>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $19 = (($__first) + ($17<<2)|0);
  _memmove(($7|0),($__first|0),($16|0))|0;
  $20 = ($19|0)==($__last|0);
  if ($20) {
   STACKTOP = sp;return;
  }
  $21 = $19;
  $$promoted$i2 = HEAP32[$13>>2]|0;
  $scevgep$i3 = (($__last) + -4|0);
  $22 = (0 - ($21))|0;
  $uglygep$i5 = (($scevgep$i3) + ($22)|0);
  $uglygep4$i6 = $uglygep$i5;
  $23 = $uglygep4$i6 >>> 2;
  $$01$i8 = $19;$25 = $$promoted$i2;
  while(1) {
   $24 = ($25|0)==(0|0);
   if (!($24)) {
    $26 = HEAP32[$$01$i8>>2]|0;
    HEAP32[$25>>2] = $26;
   }
   $27 = (($25) + 4|0);
   $28 = (($$01$i8) + 4|0);
   $29 = ($28|0)==($__last|0);
   if ($29) {
    break;
   } else {
    $$01$i8 = $28;$25 = $27;
   }
  }
  $30 = (($23) + 1)|0;
  $scevgep5$i10 = (($$promoted$i2) + ($30<<2)|0);
  HEAP32[$13>>2] = $scevgep5$i10;
  STACKTOP = sp;return;
 }
 $40 = ($7|0)==(0|0);
 do {
  if ($40) {
   $53 = $6;
  } else {
   $41 = (($this) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==($7|0);
   if (!($43)) {
    $scevgep$i$i$i$i = (($42) + -4|0);
    $44 = (0 - ($9))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($44)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $45 = $uglygep3$i$i$i$i >>> 2;
    $46 = $45 ^ -1;
    $scevgep4$i$i$i$i = (($42) + ($46<<2)|0);
    HEAP32[$41>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($7|0),($$byval_copy1|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $49 = ___cxa_find_matching_catch()|0;
    $50 = tempRet0;
    ___cxa_call_unexpected(($49|0));
    // unreachable;
   } else {
    HEAP32[$5>>2] = 0;
    HEAP32[$41>>2] = 0;
    HEAP32[$this>>2] = 0;
    $53 = 0;
    break;
   }
  }
 } while(0);
 $51 = ($3|0)<(0);
 if ($51) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $52 = $53;
 $54 = $52 >> 2;
 $55 = ($54>>>0)<(1073741823);
 if ($55) {
  $56 = $52 >> 1;
  $57 = ($56>>>0)<($4>>>0);
  $58 = $57 ? $4 : $56;
  $59 = ($58|0)<(0);
  if ($59) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i13 = $58;
  }
 } else {
  $$0$i13 = 2147483647;
 }
 $60 = $$0$i13 << 2;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $61 = (__Z15malloc_internaljj10MemLabelIdiPKci($60,16,$$byval_copy1,0,610944,79)|0);
 $62 = (($this) + 4|0);
 HEAP32[$62>>2] = $61;
 HEAP32[$this>>2] = $61;
 $63 = (($61) + ($$0$i13<<2)|0);
 HEAP32[$5>>2] = $63;
 $64 = ($__first|0)==($__last|0);
 if ($64) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($__last) + -4|0);
 $65 = (0 - ($2))|0;
 $uglygep$i = (($scevgep$i) + ($65)|0);
 $uglygep4$i = $uglygep$i;
 $66 = $uglygep4$i >>> 2;
 $$01$i = $__first;$68 = $61;
 while(1) {
  $67 = ($68|0)==(0|0);
  if (!($67)) {
   $69 = HEAP32[$$01$i>>2]|0;
   HEAP32[$68>>2] = $69;
  }
  $70 = (($68) + 4|0);
  $71 = (($$01$i) + 4|0);
  $72 = ($71|0)==($__last|0);
  if ($72) {
   break;
  } else {
   $$01$i = $71;$68 = $70;
  }
 }
 $73 = (($66) + 1)|0;
 $scevgep5$i = (($61) + ($73<<2)|0);
 HEAP32[$62>>2] = $scevgep5$i;
 STACKTOP = sp;return;
}
function __Z21CountTrianglesInStripItEiPKT_i($strip,$length) {
 $strip = $strip|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0$ = 0, $count$0$ph = 0, $i$0 = 0, $i$0$ph = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($length) + -2)|0;
 $count$0$ph = 0;$i$0$ph = 0;
 L1: while(1) {
  $i$0 = $i$0$ph;
  while(1) {
   $1 = ($i$0|0)<($0|0);
   if (!($1)) {
    break L1;
   }
   $2 = (($strip) + ($i$0<<1)|0);
   $3 = HEAP16[$2>>1]|0;
   $4 = (($i$0) + 1)|0;
   $5 = (($strip) + ($4<<1)|0);
   $6 = HEAP16[$5>>1]|0;
   $7 = ($3<<16>>16)==($6<<16>>16);
   if ($7) {
    $i$0 = $4;
   } else {
    break;
   }
  }
  $8 = (($i$0) + 2)|0;
  $9 = (($strip) + ($8<<1)|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = ($3<<16>>16)==($10<<16>>16);
  $12 = ($6<<16>>16)==($10<<16>>16);
  $or$cond = $11 | $12;
  $13 = $or$cond&1;
  $14 = $13 ^ 1;
  $count$0$ = (($14) + ($count$0$ph))|0;
  $count$0$ph = $count$0$;$i$0$ph = $4;
 }
 STACKTOP = sp;return ($count$0$ph|0);
}
function __Z10DestripifyIttEvPKT_iPT0_i($strip,$length,$trilist,$capacity) {
 $strip = $strip|0;
 $length = $length|0;
 $trilist = $trilist|0;
 $capacity = $capacity|0;
 var $$ = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$0$ph = 0, $or$cond = 0, $or$cond1 = 0, $triIndex$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($length) + -2)|0;
 $i$0$ph = 0;$triIndex$0$ph = 0;
 L1: while(1) {
  $i$0 = $i$0$ph;
  while(1) {
   $1 = ($i$0|0)<($0|0);
   if (!($1)) {
    break L1;
   }
   $2 = (($strip) + ($i$0<<1)|0);
   $3 = HEAP16[$2>>1]|0;
   $4 = (($i$0) + 1)|0;
   $5 = (($strip) + ($4<<1)|0);
   $6 = HEAP16[$5>>1]|0;
   $7 = (($i$0) + 2)|0;
   $8 = (($strip) + ($7<<1)|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = ($3<<16>>16)==($6<<16>>16);
   $11 = ($3<<16>>16)==($9<<16>>16);
   $or$cond = $10 | $11;
   $12 = ($6<<16>>16)==($9<<16>>16);
   $or$cond1 = $or$cond | $12;
   if ($or$cond1) {
    $i$0 = $4;
   } else {
    break;
   }
  }
  $13 = $i$0 & 1;
  $14 = ($13|0)==(0);
  $$ = $14 ? $3 : $6;
  $$2 = $14 ? $6 : $3;
  $15 = (($triIndex$0$ph) + 1)|0;
  $16 = (($trilist) + ($triIndex$0$ph<<1)|0);
  HEAP16[$16>>1] = $$;
  $17 = (($triIndex$0$ph) + 2)|0;
  $18 = (($trilist) + ($15<<1)|0);
  HEAP16[$18>>1] = $$2;
  $19 = (($triIndex$0$ph) + 3)|0;
  $20 = (($trilist) + ($17<<1)|0);
  HEAP16[$20>>1] = $9;
  $i$0$ph = $4;$triIndex$0$ph = $19;
 }
 STACKTOP = sp;return;
}
function __Z10DestripifyPKtiRNSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEE($strip,$length,$trilist) {
 $strip = $strip|0;
 $length = $length|0;
 $trilist = $trilist|0;
 var $$$i = 0, $$2$i = 0, $$pre = 0, $$sum = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $count$0$$i = 0;
 var $count$0$ph$i = 0, $i$0$i = 0, $i$0$i3 = 0, $i$0$ph$i = 0, $i$0$ph$i1 = 0, $or$cond$i = 0, $or$cond$i4 = 0, $or$cond1$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $triIndex$0$ph$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($trilist) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$trilist>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($length) + -2)|0;
 $count$0$ph$i = 0;$i$0$ph$i1 = 0;
 L1: while(1) {
  $i$0$i3 = $i$0$ph$i1;
  while(1) {
   $7 = ($i$0$i3|0)<($6|0);
   if (!($7)) {
    break L1;
   }
   $8 = (($strip) + ($i$0$i3<<1)|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = (($i$0$i3) + 1)|0;
   $11 = (($strip) + ($10<<1)|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = ($9<<16>>16)==($12<<16>>16);
   if ($13) {
    $i$0$i3 = $10;
   } else {
    break;
   }
  }
  $14 = (($i$0$i3) + 2)|0;
  $15 = (($strip) + ($14<<1)|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = ($9<<16>>16)==($16<<16>>16);
  $18 = ($12<<16>>16)==($16<<16>>16);
  $or$cond$i4 = $17 | $18;
  $19 = $or$cond$i4&1;
  $20 = $19 ^ 1;
  $count$0$$i = (($20) + ($count$0$ph$i))|0;
  $count$0$ph$i = $count$0$$i;$i$0$ph$i1 = $10;
 }
 $21 = $5 >> 1;
 $22 = ($count$0$ph$i*3)|0;
 $23 = (($22) + ($21))|0;
 $24 = ($21>>>0)<($23>>>0);
 if ($24) {
  __ZNSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEE8__appendEj($trilist,$22);
  $$pre = HEAP32[$trilist>>2]|0;
  $48 = $$pre;
 } else {
  $25 = ($21>>>0)>($23>>>0);
  if ($25) {
   $26 = (($2) + ($23<<1)|0);
   $27 = ($1|0)==($26|0);
   if ($27) {
    $48 = $2;
   } else {
    $__new_last2$i$i$i = $26;
    $scevgep$i$i$i = (($1) + -2|0);
    $28 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($28)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $29 = $uglygep3$i$i$i >>> 1;
    $30 = $29 ^ -1;
    $scevgep4$i$i$i = (($1) + ($30<<1)|0);
    HEAP32[$0>>2] = $scevgep4$i$i$i;
    $48 = $2;
   }
  } else {
   $48 = $2;
  }
 }
 $31 = (($21) + 1)|0;
 $32 = (($21) + 2)|0;
 $i$0$ph$i = 0;$triIndex$0$ph$i = 0;
 L14: while(1) {
  $i$0$i = $i$0$ph$i;
  while(1) {
   $33 = ($i$0$i|0)<($6|0);
   if (!($33)) {
    break L14;
   }
   $34 = (($strip) + ($i$0$i<<1)|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = (($i$0$i) + 1)|0;
   $37 = (($strip) + ($36<<1)|0);
   $38 = HEAP16[$37>>1]|0;
   $39 = (($i$0$i) + 2)|0;
   $40 = (($strip) + ($39<<1)|0);
   $41 = HEAP16[$40>>1]|0;
   $42 = ($35<<16>>16)==($38<<16>>16);
   $43 = ($35<<16>>16)==($41<<16>>16);
   $or$cond$i = $42 | $43;
   $44 = ($38<<16>>16)==($41<<16>>16);
   $or$cond1$i = $or$cond$i | $44;
   if ($or$cond1$i) {
    $i$0$i = $36;
   } else {
    break;
   }
  }
  $45 = $i$0$i & 1;
  $46 = ($45|0)==(0);
  $$$i = $46 ? $35 : $38;
  $$2$i = $46 ? $38 : $35;
  $$sum = (($triIndex$0$ph$i) + ($21))|0;
  $47 = (($48) + ($$sum<<1)|0);
  HEAP16[$47>>1] = $$$i;
  $$sum5 = (($31) + ($triIndex$0$ph$i))|0;
  $49 = (($48) + ($$sum5<<1)|0);
  HEAP16[$49>>1] = $$2$i;
  $50 = (($triIndex$0$ph$i) + 3)|0;
  $$sum6 = (($32) + ($triIndex$0$ph$i))|0;
  $51 = (($48) + ($$sum6<<1)|0);
  HEAP16[$51>>1] = $41;
  $i$0$ph$i = $36;$triIndex$0$ph$i = $50;
 }
 STACKTOP = sp;return;
}
function __Z10DestripifyPKtiRNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEE($strip,$length,$trilist) {
 $strip = $strip|0;
 $length = $length|0;
 $trilist = $trilist|0;
 var $$$i = 0, $$1$i = 0, $$pre = 0, $$pre$i = 0, $$pre$pre$i = 0, $$sum = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $count$0$$i = 0, $count$0$ph$i = 0, $i$0$i = 0, $i$0$ph$i = 0, $i$0$ph7$i = 0, $i$06$i = 0, $or$cond$i = 0, $or$cond$i2 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $triIndex$0$ph8$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($trilist) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$trilist>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($length) + -2)|0;
 $count$0$ph$i = 0;$i$0$ph$i = 0;
 L1: while(1) {
  $i$0$i = $i$0$ph$i;
  while(1) {
   $7 = ($i$0$i|0)<($6|0);
   if (!($7)) {
    break L1;
   }
   $8 = (($strip) + ($i$0$i<<1)|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = (($i$0$i) + 1)|0;
   $11 = (($strip) + ($10<<1)|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = ($9<<16>>16)==($12<<16>>16);
   if ($13) {
    $i$0$i = $10;
   } else {
    break;
   }
  }
  $14 = (($i$0$i) + 2)|0;
  $15 = (($strip) + ($14<<1)|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = ($9<<16>>16)==($16<<16>>16);
  $18 = ($12<<16>>16)==($16<<16>>16);
  $or$cond$i2 = $17 | $18;
  $19 = $or$cond$i2&1;
  $20 = $19 ^ 1;
  $count$0$$i = (($20) + ($count$0$ph$i))|0;
  $count$0$ph$i = $count$0$$i;$i$0$ph$i = $10;
 }
 $21 = $5 >> 2;
 $22 = ($count$0$ph$i*3)|0;
 $23 = (($22) + ($21))|0;
 $24 = ($21>>>0)<($23>>>0);
 if ($24) {
  __ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE8__appendEj($trilist,$22);
  $$pre = HEAP32[$trilist>>2]|0;
  $50 = $$pre;
 } else {
  $25 = ($21>>>0)>($23>>>0);
  if ($25) {
   $26 = (($2) + ($23<<2)|0);
   $27 = ($1|0)==($26|0);
   if ($27) {
    $50 = $2;
   } else {
    $__new_last2$i$i$i = $26;
    $scevgep$i$i$i = (($1) + -4|0);
    $28 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($28)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $29 = $uglygep3$i$i$i >>> 2;
    $30 = $29 ^ -1;
    $scevgep4$i$i$i = (($1) + ($30<<2)|0);
    HEAP32[$0>>2] = $scevgep4$i$i$i;
    $50 = $2;
   }
  } else {
   $50 = $2;
  }
 }
 $31 = ($6|0)>(0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $$pre$pre$i = HEAP16[$strip>>1]|0;
 $32 = (($21) + 1)|0;
 $33 = (($21) + 2)|0;
 $$pre$i = $$pre$pre$i;$i$0$ph7$i = 0;$triIndex$0$ph8$i = 0;
 L17: while(1) {
  $38 = $$pre$i;$i$06$i = $i$0$ph7$i;
  while(1) {
   $34 = (($i$06$i) + 1)|0;
   $35 = (($strip) + ($34<<1)|0);
   $36 = HEAP16[$35>>1]|0;
   $37 = ($38<<16>>16)==($36<<16>>16);
   if (!($37)) {
    $40 = (($i$06$i) + 2)|0;
    $41 = (($strip) + ($40<<1)|0);
    $42 = HEAP16[$41>>1]|0;
    $43 = ($38<<16>>16)==($42<<16>>16);
    $44 = ($36<<16>>16)==($42<<16>>16);
    $or$cond$i = $43 | $44;
    if (!($or$cond$i)) {
     break;
    }
   }
   $39 = ($34|0)<($6|0);
   if ($39) {
    $38 = $36;$i$06$i = $34;
   } else {
    label = 18;
    break L17;
   }
  }
  $45 = $42&65535;
  $46 = $i$06$i & 1;
  $47 = ($46|0)==(0);
  $$$i = $47 ? $38 : $36;
  $$1$i = $47 ? $36 : $38;
  $48 = $$$i&65535;
  $$sum = (($triIndex$0$ph8$i) + ($21))|0;
  $49 = (($50) + ($$sum<<2)|0);
  HEAP32[$49>>2] = $48;
  $51 = $$1$i&65535;
  $$sum3 = (($32) + ($triIndex$0$ph8$i))|0;
  $52 = (($50) + ($$sum3<<2)|0);
  HEAP32[$52>>2] = $51;
  $53 = (($triIndex$0$ph8$i) + 3)|0;
  $$sum4 = (($33) + ($triIndex$0$ph8$i))|0;
  $54 = (($50) + ($$sum4<<2)|0);
  HEAP32[$54>>2] = $45;
  $55 = ($34|0)<($6|0);
  if ($55) {
   $$pre$i = $36;$i$0$ph7$i = $34;$triIndex$0$ph8$i = $53;
  } else {
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP16[$11>>1] = 0;
   }
   $12 = (($11) + 2|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<1)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 1;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 1;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = ($21>>>0)<($19>>>0);
  $25 = $24 ? $19 : $21;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 1;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($27,16,$$byval_copy1,0,610944,79)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($18<<1)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP16[$32>>1] = 0;
  }
  $33 = (($32) + 2|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<1)|0);
 $scevgep$i4 = (($30) + ($19<<1)|0);
 $37 = HEAP32[$this>>2]|0;
 $38 = HEAP32[$3>>2]|0;
 $39 = $38;
 $40 = $37;
 $41 = (($39) - ($40))|0;
 $42 = $41 >> 1;
 $$sum6 = (($18) - ($42))|0;
 $43 = (($30) + ($$sum6<<1)|0);
 _memcpy(($43|0),($37|0),($41|0))|0;
 $44 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $43;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $36;
 $45 = ($44|0)==(0|0);
 if ($45) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($44|0),($$byval_copy1|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPjEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $34 = $2;
   $35 = (($34) - ($4))|0;
   $36 = $35 >> 2;
   _memmove(($9|0),($1|0),($35|0))|0;
   $37 = (($9) + ($36<<2)|0);
   $38 = HEAP32[$15>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $37;
   $scevgep$i$i = (($38) + -4|0);
   $40 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($40)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $41 = $uglygep3$i$i >>> 2;
   $42 = $41 ^ -1;
   $scevgep4$i$i = (($38) + ($42<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<2)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -4|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 2;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = HEAP32[$29>>2]|0;
    HEAP32[$27>>2] = $28;
   }
   $30 = (($27) + 4|0);
   $31 = (($29) + 4|0);
   $32 = ($31|0)==($2|0);
   if ($32) {
    break;
   } else {
    $27 = $30;$29 = $31;
   }
  }
  $33 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($33<<2)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $43 = ($9|0)==(0|0);
 do {
  if ($43) {
   $56 = $8;
  } else {
   $44 = (($this) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==($9|0);
   if (!($46)) {
    $scevgep$i$i$i$i = (($45) + -4|0);
    $47 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($47)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $48 = $uglygep3$i$i$i$i >>> 2;
    $49 = $48 ^ -1;
    $scevgep4$i$i$i$i = (($45) + ($49<<2)|0);
    HEAP32[$44>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    ___cxa_call_unexpected(($52|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$44>>2] = 0;
    HEAP32[$this>>2] = 0;
    $56 = 0;
    break;
   }
  }
 } while(0);
 $54 = ($5|0)<(0);
 if ($54) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $55 = $56;
 $57 = $55 >> 2;
 $58 = ($57>>>0)<(1073741823);
 if ($58) {
  $59 = $55 >> 1;
  $60 = ($59>>>0)<($6>>>0);
  $61 = $60 ? $6 : $59;
  $62 = ($61|0)<(0);
  if ($62) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $61;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $63 = $$0$i37 << 2;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $64 = (__Z15malloc_internaljj10MemLabelIdiPKci($63,16,$$byval_copy1,0,610944,79)|0);
 $65 = (($this) + 4|0);
 HEAP32[$65>>2] = $64;
 HEAP32[$this>>2] = $64;
 $66 = (($64) + ($$0$i37<<2)|0);
 HEAP32[$7>>2] = $66;
 $67 = ($1|0)==($2|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -4|0);
 $68 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($68)|0);
 $uglygep6$i = $uglygep$i;
 $69 = $uglygep6$i >>> 2;
 $71 = $64;$73 = $1;
 while(1) {
  $70 = ($71|0)==(0|0);
  if (!($70)) {
   $72 = HEAP32[$73>>2]|0;
   HEAP32[$71>>2] = $72;
  }
  $74 = (($71) + 4|0);
  $75 = (($73) + 4|0);
  $76 = ($75|0)==($2|0);
  if ($76) {
   break;
  } else {
   $71 = $74;$73 = $75;
  }
 }
 $77 = (($69) + 1)|0;
 $scevgep8$i = (($64) + ($77<<2)|0);
 HEAP32[$65>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZN17ProceduralTexture8SetOwnerEP18ProceduralMaterial($this,$material) {
 $this = $this|0;
 $material = $material|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $material;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferIyEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580736>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  $5 = (($this) + 12|0);
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $13)|0;
  $$sum$i$i$i = (($9) - ($16))|0;
  $17 = (($11) + ($$sum$i$i$i)|0);
  HEAP32[$5>>2] = $17;
  $18 = ($$sum$i$i$i|0)<(0);
  if ($18) {
   label = 6;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 8)|0;
   $19 = (($11) + ($$sum1$i$i$i)|0);
   $20 = (($this) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19>>>0)>($21>>>0);
   if ($22) {
    label = 6;
   } else {
    $23 = $17;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 4)|0;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = $data;
    $30 = $29;
    HEAP32[$30>>2] = $25;
    $31 = (($29) + 4)|0;
    $32 = $31;
    HEAP32[$32>>2] = $28;
    HEAP32[$5>>2] = $19;
   }
  }
  if ((label|0) == 6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,8);
  }
  $33 = HEAP32[$this>>2]|0;
  $34 = $33 & 512;
  $35 = ($34|0)==(0);
  if (!($35)) {
   $36 = HEAP32[$data>>2]|0;
   $37 = (_llvm_bswap_i32(($36|0))|0);
   $38 = (($data) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (_llvm_bswap_i32(($39|0))|0);
   HEAP32[$data>>2] = $40;
   HEAP32[$38>>2] = $37;
  }
 } else {
  $41 = HEAP32[$converter$i>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   (FUNCTION_TABLE_iii[$41 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZNK18ProceduralMaterial25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 185;
}
function __ZN18ProceduralMaterial23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,610976,610952,$this,0);
 __ZN18ProceduralMaterial8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,610976,610952,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN18ProceduralMaterial8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18ProceduralMaterial8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18ProceduralMaterial8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18ProceduralMaterial8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18ProceduralMaterial8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity8MaterialD2Ev($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i8 = 0, $$pre$i$i$i10 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((641176 + 8|0));
 __THREW__ = 0;
 invoke_vi(3493,($this|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($this) + 108|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   $8 = (($this) + 116|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy3|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $12 = ___cxa_find_matching_catch()|0;
    $13 = tempRet0;
    ___cxa_call_unexpected(($12|0));
    // unreachable;
   }
  }
  $14 = (($this) + 96|0);
  $15 = (($this) + 100|0);
  $16 = HEAP32[$15>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($14,$16);
  $17 = (($this) + 84|0);
  $18 = (($this) + 88|0);
  $19 = HEAP32[$18>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($17,$19);
  $20 = (($this) + 72|0);
  $21 = (($this) + 76|0);
  $22 = HEAP32[$21>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($20,$22);
  $23 = (($this) + 40|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
  $26 = (($this) + 44|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($24|0);
  do {
   if ($28) {
    $43 = $24;
   } else {
    $30 = $27;
    while(1) {
     $29 = (($30) + -44|0);
     HEAP32[$26>>2] = $29;
     $31 = (($30) + -32|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)>(-1);
     if ($33) {
      $36 = HEAP32[$29>>2]|0;
      $37 = (($30) + -40|0);
      $38 = HEAP32[$37>>2]|0;
      HEAP32[$0>>2] = $38;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($36|0),($$byval_copy3|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 12;
       break;
      }
      HEAP32[$29>>2] = 0;
      $$pre$i$i$i$i$i = HEAP32[$26>>2]|0;
      $35 = $$pre$i$i$i$i$i;
     } else {
      $35 = $29;
     }
     $34 = ($35|0)==($24|0);
     if ($34) {
      label = 13;
      break;
     } else {
      $30 = $35;
     }
    }
    if ((label|0) == 12) {
     $41 = ___cxa_find_matching_catch()|0;
     $42 = tempRet0;
     ___cxa_call_unexpected(($41|0));
     // unreachable;
    }
    else if ((label|0) == 13) {
     $$pre$i$i$i = HEAP32[$23>>2]|0;
     $43 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($43);
  __ZN11NamedObjectD2Ev($this);
  STACKTOP = sp;return;
 }
 $44 = ___cxa_find_matching_catch()|0;
 $45 = tempRet0;
 $46 = (($this) + 108|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = $47 & 1;
 $49 = ($48<<24>>24)==(0);
 if (!($49)) {
  $50 = (($this) + 116|0);
  $51 = HEAP32[$50>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($51|0),($$byval_copy3|0));
  $52 = __THREW__; __THREW__ = 0;
  $53 = $52&1;
  if ($53) {
   $54 = ___cxa_find_matching_catch()|0;
   $55 = tempRet0;
   ___cxa_call_unexpected(($54|0));
   // unreachable;
  }
 }
 $56 = (($this) + 96|0);
 $57 = (($this) + 100|0);
 $58 = HEAP32[$57>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($56,$58);
 $59 = (($this) + 84|0);
 $60 = (($this) + 88|0);
 $61 = HEAP32[$60>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($59,$61);
 $62 = (($this) + 72|0);
 $63 = (($this) + 76|0);
 $64 = HEAP32[$63>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($62,$64);
 $65 = (($this) + 40|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = (($this) + 44|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)==($66|0);
  do {
   if ($70) {
    $85 = $66;
   } else {
    $72 = $69;
    while(1) {
     $71 = (($72) + -44|0);
     HEAP32[$68>>2] = $71;
     $73 = (($72) + -32|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)>(-1);
     if ($75) {
      $78 = HEAP32[$71>>2]|0;
      $79 = (($72) + -40|0);
      $80 = HEAP32[$79>>2]|0;
      HEAP32[$0>>2] = $80;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($78|0),($$byval_copy3|0));
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       label = 26;
       break;
      }
      HEAP32[$71>>2] = 0;
      $$pre$i$i$i$i$i8 = HEAP32[$68>>2]|0;
      $77 = $$pre$i$i$i$i$i8;
     } else {
      $77 = $71;
     }
     $76 = ($77|0)==($66|0);
     if ($76) {
      label = 27;
      break;
     } else {
      $72 = $77;
     }
    }
    if ((label|0) == 26) {
     $83 = ___cxa_find_matching_catch()|0;
     $84 = tempRet0;
     ___cxa_call_unexpected(($83|0));
     // unreachable;
    }
    else if ((label|0) == 27) {
     $$pre$i$i$i10 = HEAP32[$65>>2]|0;
     $85 = $$pre$i$i$i10;
     break;
    }
   }
  } while(0);
  __ZdlPv($85);
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $86 = __THREW__; __THREW__ = 0;
 $87 = $86&1;
 if ($87) {
  $88 = ___cxa_find_matching_catch(0|0)|0;
  $89 = tempRet0;
  ___clang_call_terminate($88);
  // unreachable;
 } else {
  ___resumeException($44|0);
  // unreachable;
 }
}
function __ZN18ProceduralMaterial5CloneEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre = 0, $$pre$phi10Z2D = 0, $$pre$phiZ2D = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $idx$07 = 0, $temp$0$i = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[628384>>2]|0;
 HEAP32[$2>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
 $4 = (__Z20CreateObjectFromCodeI18ProceduralMaterialEPT_17AwakeFromLoadMode10MemLabelId(4,$$byval_copy)|0);
 $5 = (($this) + 152|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 152|0);
 HEAP32[$7>>2] = $6;
 $8 = (($4) + 164|0);
 $9 = (($this) + 164|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($8,$9)|0);
 $10 = (($this) + 176|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($4) + 176|0);
 HEAP32[$12>>2] = $11;
 $13 = (($this) + 180|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($4) + 180|0);
 HEAP32[$15>>2] = $14;
 $16 = (($4) + 188|0);
 $17 = (($this) + 188|0);
 $18 = ($4|0)==($this|0);
 if ($18) {
  $$pre8 = (($this) + 192|0);
  $$pre$phi10Z2D = $17;$$pre$phiZ2D = $$pre8;
 } else {
  $19 = HEAP32[$17>>2]|0;
  $20 = (($this) + 192|0);
  $21 = HEAP32[$20>>2]|0;
  __ZNSt3__16vectorI4PPtrI17ProceduralTextureENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($16,$19,$21);
  $$pre$phi10Z2D = $17;$$pre$phiZ2D = $20;
 }
 $22 = HEAP32[$$pre$phiZ2D>>2]|0;
 $23 = HEAP32[$$pre$phi10Z2D>>2]|0;
 $24 = ($22|0)==($23|0);
 if (!($24)) {
  $idx$07 = 0;
  while(1) {
   $25 = HEAP32[$16>>2]|0;
   $26 = (($25) + ($idx$07<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
   $28 = HEAP32[560624>>2]|0;
   $29 = ($28|0)==(0|0);
   if ($29) {
    label = 14;
   } else {
    $30 = (($28) + 36|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($28) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($31|0)==($33|0);
    do {
     if ($34) {
      $35 = (($28) + 28|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($28) + 32|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + ($38<<3)|0);
      $55 = $39;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$28,$1);
      $40 = HEAP32[$$byval_copy>>2]|0;
      $41 = ($40|0)==(-1);
      $42 = (($28) + 28|0);
      $43 = HEAP32[$42>>2]|0;
      if ($41) {
       $44 = (($28) + 32|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = (($43) + ($45<<3)|0);
       $55 = $46;
       break;
      } else {
       $47 = (($43) + ($40<<3)|0);
       $55 = $47;
       break;
      }
     }
    } while(0);
    $48 = HEAP32[560624>>2]|0;
    $49 = (($48) + 28|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($48) + 32|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($50) + ($52<<3)|0);
    $54 = ($55|0)==($53|0);
    if ($54) {
     label = 14;
    } else {
     $56 = (($55) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      label = 14;
     } else {
      $68 = $48;$temp$0$i = $57;
     }
    }
   }
   if ((label|0) == 14) {
    label = 0;
    $59 = HEAP32[$26>>2]|0;
    $60 = (__Z31ReadObjectFromPersistentManageri($59)|0);
    $$pre = HEAP32[560624>>2]|0;
    $68 = $$pre;$temp$0$i = $60;
   }
   $61 = HEAP32[$temp$0$i>>2]|0;
   $62 = (($61) + 36|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$$pre$phi10Z2D>>2]|0;
   $65 = (($64) + ($idx$07<<2)|0);
   $66 = HEAP32[$65>>2]|0;
   HEAP32[$0>>2] = $66;
   $67 = ($68|0)==(0|0);
   if ($67) {
    label = 23;
   } else {
    $69 = (($68) + 36|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($68) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($70|0)==($72|0);
    do {
     if ($73) {
      $74 = (($68) + 28|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($68) + 32|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($75) + ($77<<3)|0);
      $94 = $78;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$68,$0);
      $79 = HEAP32[$$byval_copy>>2]|0;
      $80 = ($79|0)==(-1);
      $81 = (($68) + 28|0);
      $82 = HEAP32[$81>>2]|0;
      if ($80) {
       $83 = (($68) + 32|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = (($82) + ($84<<3)|0);
       $94 = $85;
       break;
      } else {
       $86 = (($82) + ($79<<3)|0);
       $94 = $86;
       break;
      }
     }
    } while(0);
    $87 = HEAP32[560624>>2]|0;
    $88 = (($87) + 28|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($87) + 32|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($89) + ($91<<3)|0);
    $93 = ($94|0)==($92|0);
    if ($93) {
     label = 23;
    } else {
     $95 = (($94) + 4|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = ($96|0)==(0|0);
     if ($97) {
      label = 23;
     } else {
      $temp$0$i5 = $96;
     }
    }
   }
   if ((label|0) == 23) {
    label = 0;
    $98 = HEAP32[$65>>2]|0;
    $99 = (__Z31ReadObjectFromPersistentManageri($98)|0);
    $temp$0$i5 = $99;
   }
   $100 = HEAP32[$temp$0$i5>>2]|0;
   $101 = (($100) + 32|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (FUNCTION_TABLE_ii[$102 & 4095]($temp$0$i5)|0);
   FUNCTION_TABLE_vii[$63 & 4095]($temp$0$i,$103);
   $104 = (($idx$07) + 1)|0;
   $105 = HEAP32[$$pre$phiZ2D>>2]|0;
   $106 = HEAP32[$$pre$phi10Z2D>>2]|0;
   $107 = $105;
   $108 = $106;
   $109 = (($107) - ($108))|0;
   $110 = $109 >> 2;
   $111 = ($104>>>0)<($110>>>0);
   if ($111) {
    $idx$07 = $104;
   } else {
    break;
   }
  }
 }
 $112 = (($this) + 252|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($4) + 252|0);
 HEAP32[$114>>2] = $113;
 if ($18) {
  $120 = (($this) + 260|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = $121 & -169;
  $123 = $122 | 136;
  $124 = (($4) + 260|0);
  HEAP32[$124>>2] = $123;
  $125 = (($this) + 264|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (($4) + 264|0);
  HEAP32[$127>>2] = $126;
  __ZN18ProceduralMaterial17AwakeDependenciesEb($4,0);
  STACKTOP = sp;return ($4|0);
 }
 $115 = (($4) + 212|0);
 $116 = (($this) + 212|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = (($this) + 216|0);
 $119 = HEAP32[$118>>2]|0;
 __ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($115,$117,$119);
 $120 = (($this) + 260|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = $121 & -169;
 $123 = $122 | 136;
 $124 = (($4) + 260|0);
 HEAP32[$124>>2] = $123;
 $125 = (($this) + 264|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (($4) + 264|0);
 HEAP32[$127>>2] = $126;
 __ZN18ProceduralMaterial17AwakeDependenciesEb($4,0);
 STACKTOP = sp;return ($4|0);
}
function __Z20CreateObjectFromCodeI18ProceduralMaterialEPT_17AwakeFromLoadMode10MemLabelId($awakeMode,$label) {
 $awakeMode = $awakeMode|0;
 $label = $label|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(272,$$byval_copy2,1,16,611088,1111)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1726,($3|0),($$byval_copy2|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((610984 + 8|0));
  $6 = (($3) + 144|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 148|0);
  HEAP32[$7>>2] = 4;
  $8 = (($3) + 152|0);
  $9 = (($3) + 176|0);
  ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP16[$8+12>>1]=0|0;
  HEAP32[$9>>2] = 9;
  $10 = (($3) + 180|0);
  HEAP32[$10>>2] = 9;
  $11 = (($3) + 184|0);
  HEAP8[$11>>0] = 1;
  $12 = (($3) + 188|0);
  $13 = (($3) + 252|0);
  dest=$12+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$13>>2] = 42;
  $14 = (($3) + 256|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
  $15 = (($3) + 260|0);
  HEAP32[$15>>2] = 0;
  $16 = (($3) + 264|0);
  HEAP32[$16>>2] = 1;
  $17 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_vi[$20 & 4095]($17);
  $21 = HEAP32[$17>>2]|0;
  $22 = (($21) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  FUNCTION_TABLE_vii[$23 & 4095]($17,$awakeMode);
  STACKTOP = sp;return ($17|0);
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(611088|0),1111);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($24|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN18ProceduralMaterial17AwakeDependenciesEb($this,$awakeThreaded) {
 $this = $this|0;
 $awakeThreaded = $awakeThreaded|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $__new_last2$i$i$i = 0, $pos$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $texture_index$02 = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 192|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 188|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = (($this) + 260|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 | 2048;
  HEAP32[$10>>2] = $12;
  STACKTOP = sp;return;
 }
 $13 = (($this) + 200|0);
 $14 = (($this) + 204|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$13>>2]|0;
 $17 = $15;
 $18 = $16;
 $19 = (($17) - ($18))|0;
 $20 = $19 >> 2;
 $21 = ($20|0)==($8|0);
 if (!($21)) {
  $22 = ($20>>>0)<($8>>>0);
  if ($22) {
   $23 = (($8) - ($20))|0;
   __ZNSt3__16vectorIP17ProceduralTextureNS_9allocatorIS2_EEE8__appendEj($13,$23);
   $$pre = HEAP32[$14>>2]|0;
   $$pre3 = HEAP32[$13>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $24 = ($20>>>0)>($8>>>0);
   if ($24) {
    $25 = (($16) + ($8<<2)|0);
    $26 = ($15|0)==($25|0);
    if ($26) {
     $31 = $15;$33 = $16;
    } else {
     $__new_last2$i$i$i = $25;
     $scevgep$i$i$i = (($15) + -4|0);
     $27 = (0 - ($__new_last2$i$i$i))|0;
     $uglygep$i$i$i = (($scevgep$i$i$i) + ($27)|0);
     $uglygep3$i$i$i = $uglygep$i$i$i;
     $28 = $uglygep3$i$i$i >>> 2;
     $29 = $28 ^ -1;
     $scevgep4$i$i$i = (($15) + ($29<<2)|0);
     HEAP32[$14>>2] = $scevgep4$i$i$i;
     $31 = $scevgep4$i$i$i;$33 = $16;
    }
   } else {
    $31 = $15;$33 = $16;
   }
  }
  $30 = $31;
  $32 = $33;
  $34 = (($30) - ($32))|0;
  $35 = $34 >> 2;
  $36 = ($20>>>0)<($35>>>0);
  if ($36) {
   $37 = (($33) + ($20<<2)|0);
   $38 = HEAP32[$1>>2]|0;
   $39 = HEAP32[$3>>2]|0;
   $40 = $38;
   $41 = $39;
   $42 = (($40) - ($19))|0;
   $43 = (($42) - ($41))|0;
   $44 = $43 & -4;
   _memset(($37|0),0,($44|0))|0;
  }
 }
 $45 = HEAP32[$3>>2]|0;
 $46 = HEAP32[$1>>2]|0;
 $47 = ($45|0)==($46|0);
 if ($47) {
  STACKTOP = sp;return;
 }
 $51 = $45;$texture_index$02 = 0;
 while(1) {
  $48 = HEAP32[$13>>2]|0;
  $49 = (($48) + ($texture_index$02<<2)|0);
  $50 = HEAP32[$51>>2]|0;
  $52 = ($50|0)==(0);
  do {
   if ($52) {
    HEAP32[$49>>2] = 0;
    label = 25;
   } else {
    HEAP32[$0>>2] = $50;
    $53 = HEAP32[560624>>2]|0;
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     $55 = (($53) + 36|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($53) + 4|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($56|0)==($58|0);
     do {
      if ($59) {
       $60 = (($53) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($53) + 32|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = (($61) + ($63<<3)|0);
       $80 = $64;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$53,$0);
       $65 = HEAP32[$pos$i$i$i>>2]|0;
       $66 = ($65|0)==(-1);
       $67 = (($53) + 28|0);
       $68 = HEAP32[$67>>2]|0;
       if ($66) {
        $69 = (($53) + 32|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = (($68) + ($70<<3)|0);
        $80 = $71;
        break;
       } else {
        $72 = (($68) + ($65<<3)|0);
        $80 = $72;
        break;
       }
      }
     } while(0);
     $73 = HEAP32[560624>>2]|0;
     $74 = (($73) + 28|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($73) + 32|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($75) + ($77<<3)|0);
     $79 = ($80|0)==($78|0);
     if (!($79)) {
      $81 = (($80) + 4|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ($82|0)==(0|0);
      if (!($83)) {
       HEAP32[$49>>2] = $82;
       break;
      }
     }
    }
    $84 = HEAP32[$51>>2]|0;
    $85 = (__Z31ReadObjectFromPersistentManageri($84)|0);
    HEAP32[$49>>2] = $85;
    $86 = ($85|0)==(0|0);
    if ($86) {
     label = 25;
    }
   }
  } while(0);
  if ((label|0) == 25) {
   label = 0;
   HEAP32[$51>>2] = 0;
  }
  $87 = HEAP32[$13>>2]|0;
  $88 = (($87) + ($texture_index$02<<2)|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==(0|0);
  if ($90) {
   break;
  }
  __ZN17ProceduralTexture8SetOwnerEP18ProceduralMaterial($89,$this);
  $94 = (($51) + 4|0);
  $95 = HEAP32[$1>>2]|0;
  $96 = ($94|0)==($95|0);
  if ($96) {
   label = 30;
   break;
  }
  $97 = (($texture_index$02) + 1)|0;
  $51 = $94;$texture_index$02 = $97;
 }
 if ((label|0) == 30) {
  STACKTOP = sp;return;
 }
 $91 = (($this) + 260|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = $92 | 2048;
 HEAP32[$91>>2] = $93;
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial21AwakeFromLoadThreadedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity8Material13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 __ZN18ProceduralMaterial17AwakeDependenciesEb($this,0);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial9ReloadAllEbb($unload,$load) {
 $unload = $unload|0;
 $load = $load|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial17MainThreadCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity8Material17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterialD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18ProceduralMaterialD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterialD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3494,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIP17ProceduralTextureNS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    HEAP32[$10>>2] = 0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 4|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i57 = 0;$31 = 0;
  } else {
   $$0$i56 = $26;
   label = 9;
  }
 } else {
  $$0$i56 = 1073741823;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = $$0$i56 << 2;
  $29 = (__Znwj($28)|0);
  $$0$i57 = $$0$i56;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if ($32) {
   $35 = 0;
  } else {
   HEAP32[$33>>2] = 0;
   $35 = $33;
  }
  $34 = (($35) + 4|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $34;
  }
 }
 $38 = (($31) + ($$0$i57<<2)|0);
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = $40;
 $42 = $39;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 2;
 $$sum = (($18) - ($44))|0;
 $45 = (($31) + ($$sum<<2)|0);
 _memcpy(($45|0),($39|0),($43|0))|0;
 HEAP32[$this>>2] = $45;
 HEAP32[$2>>2] = $34;
 HEAP32[$0>>2] = $38;
 $46 = ($39|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZdlPv($39);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i3 = 0, $$012$i$i = 0, $$03$i$i = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0;
 var $__growing$0$off0 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 7;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 7;
 $11 = ($3>>>0)>($10>>>0);
 if ($11) {
  $41 = ($6|0)==(0|0);
  do {
   if ($41) {
    $53 = $5;
   } else {
    $42 = (($this) + 4|0);
    while(1) {
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==($6|0);
     if ($44) {
      label = 22;
      break;
     }
     $45 = (($43) + -128|0);
     HEAP32[$42>>2] = $45;
     __THREW__ = 0;
     invoke_vi(3495,($45|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 21;
      break;
     }
    }
    if ((label|0) == 21) {
     $48 = ___cxa_find_matching_catch()|0;
     $49 = tempRet0;
     ___cxa_call_unexpected(($48|0));
     // unreachable;
    }
    else if ((label|0) == 22) {
     $50 = HEAP32[$this>>2]|0;
     __ZdlPv($50);
     HEAP32[$4>>2] = 0;
     HEAP32[$42>>2] = 0;
     HEAP32[$this>>2] = 0;
     $53 = 0;
     break;
    }
   }
  } while(0);
  $51 = ($3>>>0)>(33554431);
  if ($51) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $52 = $53;
  $54 = $52 >> 7;
  $55 = ($54>>>0)<(16777215);
  if ($55) {
   $56 = $52 >> 6;
   $57 = ($56>>>0)<($3>>>0);
   $58 = $57 ? $3 : $56;
   $59 = ($58>>>0)>(33554431);
   if ($59) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i7 = $58;
   }
  } else {
   $$0$i7 = 33554431;
  }
  $60 = $$0$i7 << 7;
  $61 = (__Znwj($60)|0);
  $62 = (($this) + 4|0);
  HEAP32[$62>>2] = $61;
  HEAP32[$this>>2] = $61;
  $63 = (($61) + ($$0$i7<<7)|0);
  HEAP32[$4>>2] = $63;
  $64 = ($__first|0)==($__last|0);
  if ($64) {
   STACKTOP = sp;return;
  } else {
   $$01$i = $__first;$66 = $61;
  }
  while(1) {
   $65 = ($66|0)==(0|0);
   if ($65) {
    $68 = 0;
   } else {
    __ZN14SubstanceInputC2ERKS_($66,$$01$i);
    $$pre2$i = HEAP32[$62>>2]|0;
    $68 = $$pre2$i;
   }
   $67 = (($68) + 128|0);
   HEAP32[$62>>2] = $67;
   $69 = (($$01$i) + 128|0);
   $70 = ($69|0)==($__last|0);
   if ($70) {
    break;
   } else {
    $$01$i = $69;$66 = $67;
   }
  }
  STACKTOP = sp;return;
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = $15 >> 7;
 $17 = ($3>>>0)>($16>>>0);
 if ($17) {
  $18 = (($__first) + ($16<<7)|0);
  $20 = $18;$__growing$0$off0 = 1;
 } else {
  $20 = $__last;$__growing$0$off0 = 0;
 }
 $19 = ($20|0)==($__first|0);
 if ($19) {
  $$0$lcssa$i$i = $6;
 } else {
  $scevgep$i$i = (($20) + -128|0);
  $21 = (0 - ($1))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($21)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $6;
  while(1) {
   (__ZN14SubstanceInputaSERKS_($$03$i$i,$$012$i$i)|0);
   $22 = (($$012$i$i) + 128|0);
   $23 = (($$03$i$i) + 128|0);
   $24 = ($22|0)==($20|0);
   if ($24) {
    break;
   } else {
    $$012$i$i = $22;$$03$i$i = $23;
   }
  }
  $25 = $uglygep6$i$i >>> 7;
  $26 = (($25) + 1)|0;
  $scevgep7$i$i = (($6) + ($26<<7)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if (!($__growing$0$off0)) {
  while(1) {
   $34 = HEAP32[$12>>2]|0;
   $35 = ($34|0)==($$0$lcssa$i$i|0);
   if ($35) {
    label = 32;
    break;
   }
   $36 = (($34) + -128|0);
   HEAP32[$12>>2] = $36;
   __THREW__ = 0;
   invoke_vi(3495,($36|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 16;
    break;
   }
  }
  if ((label|0) == 16) {
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   ___cxa_call_unexpected(($39|0));
   // unreachable;
  }
  else if ((label|0) == 32) {
   STACKTOP = sp;return;
  }
 }
 $27 = ($20|0)==($__last|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $$pre$i1 = HEAP32[$12>>2]|0;
 $$01$i3 = $20;$29 = $$pre$i1;
 while(1) {
  $28 = ($29|0)==(0|0);
  if ($28) {
   $31 = 0;
  } else {
   __ZN14SubstanceInputC2ERKS_($29,$$01$i3);
   $$pre2$i4 = HEAP32[$12>>2]|0;
   $31 = $$pre2$i4;
  }
  $30 = (($31) + 128|0);
  HEAP32[$12>>2] = $30;
  $32 = (($$01$i3) + 128|0);
  $33 = ($32|0)==($__last|0);
  if ($33) {
   break;
  } else {
   $$01$i3 = $32;$29 = $30;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14SubstanceInputD2Ev($this) {
 $this = $this|0;
 var $$byval_copy4 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i6 = 0, $$pre$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = (($this) + 116|0);
 $6 = (($this) + 120|0);
 $7 = HEAP32[$6>>2]|0;
 __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($5,$7);
 $8 = (($this) + 100|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = (($this) + 104|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($9|0);
  do {
   if ($13) {
    $28 = $9;
   } else {
    $15 = $12;
    while(1) {
     $14 = (($15) + -16|0);
     HEAP32[$11>>2] = $14;
     $16 = (($15) + -12|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = $17 & 1;
     $19 = ($18<<24>>24)==(0);
     if ($19) {
      $21 = $14;
     } else {
      $22 = (($15) + -4|0);
      $23 = HEAP32[$22>>2]|0;
      HEAP32[$4>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($23|0),($$byval_copy4|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       label = 8;
       break;
      }
      $$pre$i$i$i$i$i = HEAP32[$11>>2]|0;
      $21 = $$pre$i$i$i$i$i;
     }
     $20 = ($21|0)==($9|0);
     if ($20) {
      label = 9;
      break;
     } else {
      $15 = $21;
     }
    }
    if ((label|0) == 8) {
     $26 = ___cxa_find_matching_catch()|0;
     $27 = tempRet0;
     ___cxa_call_unexpected(($26|0));
     // unreachable;
    }
    else if ((label|0) == 9) {
     $$pre$i$i$i = HEAP32[$8>>2]|0;
     $28 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($28);
 }
 $29 = (($this) + 76|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = (($this) + 80|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==($30|0);
  do {
   if ($34) {
    $48 = $30;
   } else {
    $36 = $33;
    while(1) {
     $35 = (($36) + -12|0);
     HEAP32[$32>>2] = $35;
     $37 = HEAP8[$35>>0]|0;
     $38 = $37 & 1;
     $39 = ($38<<24>>24)==(0);
     if ($39) {
      $41 = $35;
     } else {
      $42 = (($36) + -4|0);
      $43 = HEAP32[$42>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($43|0),($$byval_copy4|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 18;
       break;
      }
      $$pre$i$i$i$i$i6 = HEAP32[$32>>2]|0;
      $41 = $$pre$i$i$i$i$i6;
     }
     $40 = ($41|0)==($30|0);
     if ($40) {
      label = 19;
      break;
     } else {
      $36 = $41;
     }
    }
    if ((label|0) == 18) {
     $46 = ___cxa_find_matching_catch()|0;
     $47 = tempRet0;
     ___cxa_call_unexpected(($46|0));
     // unreachable;
    }
    else if ((label|0) == 19) {
     $$pre$i$i$i7 = HEAP32[$29>>2]|0;
     $48 = $$pre$i$i$i7;
     break;
    }
   }
  } while(0);
  __ZdlPv($48);
 }
 $49 = (($this) + 24|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = $50 & 1;
 $52 = ($51<<24>>24)==(0);
 if (!($52)) {
  $53 = (($this) + 32|0);
  $54 = HEAP32[$53>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($54|0),($$byval_copy4|0));
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if ($56) {
   $57 = ___cxa_find_matching_catch()|0;
   $58 = tempRet0;
   ___cxa_call_unexpected(($57|0));
   // unreachable;
  }
 }
 $59 = (($this) + 12|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = $60 & 1;
 $62 = ($61<<24>>24)==(0);
 if (!($62)) {
  $63 = (($this) + 20|0);
  $64 = HEAP32[$63>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($64|0),($$byval_copy4|0));
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if ($66) {
   $67 = ___cxa_find_matching_catch()|0;
   $68 = tempRet0;
   ___cxa_call_unexpected(($67|0));
   // unreachable;
  }
 }
 $69 = HEAP8[$this>>0]|0;
 $70 = $69 & 1;
 $71 = ($70<<24>>24)==(0);
 if ($71) {
  STACKTOP = sp;return;
 }
 $72 = (($this) + 8|0);
 $73 = HEAP32[$72>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($73|0),($$byval_copy4|0));
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if ($75) {
  $76 = ___cxa_find_matching_catch()|0;
  $77 = tempRet0;
  ___cxa_call_unexpected(($76|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN14SubstanceInputC2ERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01 = 0, $$01$i$i$i$i$i = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$byval_copy10 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i24 = 0, $$pre$i$i$i$i$i26 = 0, $$pre$i$i$i27 = 0, $$pre$i$i$i31 = 0, $$pre$i$i$i33 = 0;
 var $$pre$i34 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i14 = 0, $__p$0$i$i$i$i8 = 0, $__parent$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy10 = sp + 44|0;
 $1 = sp + 40|0;
 $2 = sp + 36|0;
 $3 = sp + 32|0;
 $4 = sp + 28|0;
 $5 = sp + 24|0;
 $6 = sp + 20|0;
 $7 = sp + 12|0;
 $__parent$i$i$i$i = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = sp + 16|0;
 $11 = HEAP8[$0>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $18 = (($0) + 1|0);
  $19 = $11&255;
  $20 = $19 >>> 1;
  $22 = $20;$33 = $18;
 } else {
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($0) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $22 = $17;$33 = $15;
 }
 $21 = ($22>>>0)>(2147483631);
 if ($21) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = ($22>>>0)<(11);
 if ($23) {
  $24 = $22 << 1;
  $25 = $24&255;
  HEAP8[$this>>0] = $25;
  $26 = (($this) + 1|0);
  $__p$0$i$i$i$i = $26;
 } else {
  $27 = (($22) + 16)|0;
  $28 = $27 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy10,0,611088,79)|0);
  $30 = (($this) + 8|0);
  HEAP32[$30>>2] = $29;
  $31 = $28 | 1;
  HEAP32[$this>>2] = $31;
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $22;
  $__p$0$i$i$i$i = $29;
 }
 _memcpy(($__p$0$i$i$i$i|0),($33|0),($22|0))|0;
 $34 = (($__p$0$i$i$i$i) + ($22)|0);
 HEAP8[$34>>0] = 0;
 $35 = (($this) + 12|0);
 $36 = (($0) + 12|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37 & 1;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  $44 = (($36) + 1|0);
  $45 = $37&255;
  $46 = $45 >>> 1;
  $48 = $46;$63 = $44;
 } else {
  $40 = (($0) + 20|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($0) + 16|0);
  $43 = HEAP32[$42>>2]|0;
  $48 = $43;$63 = $41;
 }
 $47 = ($48>>>0)>(2147483631);
 do {
  if ($47) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    label = 74;
   } else {
    // unreachable;
   }
  } else {
   $51 = ($48>>>0)<(11);
   if ($51) {
    $52 = $48 << 1;
    $53 = $52&255;
    HEAP8[$35>>0] = $53;
    $54 = (($35) + 1|0);
    $__p$0$i$i$i$i8 = $54;
   } else {
    $55 = (($48) + 16)|0;
    $56 = $55 & -16;
    HEAP32[$10>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$10+0>>2]|0;
    $57 = (invoke_iiiiiii(102,($56|0),16,($$byval_copy10|0),0,(611088|0),79)|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 74;
     break;
    }
    $60 = (($this) + 20|0);
    HEAP32[$60>>2] = $57;
    $61 = $56 | 1;
    HEAP32[$35>>2] = $61;
    $62 = (($this) + 16|0);
    HEAP32[$62>>2] = $48;
    $__p$0$i$i$i$i8 = $57;
   }
   _memcpy(($__p$0$i$i$i$i8|0),($63|0),($48|0))|0;
   $64 = (($__p$0$i$i$i$i8) + ($48)|0);
   HEAP8[$64>>0] = 0;
   $65 = (($this) + 24|0);
   $66 = (($0) + 24|0);
   $67 = HEAP8[$66>>0]|0;
   $68 = $67 & 1;
   $69 = ($68<<24>>24)==(0);
   if ($69) {
    $74 = (($66) + 1|0);
    $75 = $67&255;
    $76 = $75 >>> 1;
    $78 = $76;$93 = $74;
   } else {
    $70 = (($0) + 32|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($0) + 28|0);
    $73 = HEAP32[$72>>2]|0;
    $78 = $73;$93 = $71;
   }
   $77 = ($78>>>0)>(2147483631);
   do {
    if ($77) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if ($80) {
      label = 75;
     } else {
      // unreachable;
     }
    } else {
     $81 = ($78>>>0)<(11);
     if ($81) {
      $82 = $78 << 1;
      $83 = $82&255;
      HEAP8[$65>>0] = $83;
      $84 = (($65) + 1|0);
      $__p$0$i$i$i$i14 = $84;
     } else {
      $85 = (($78) + 16)|0;
      $86 = $85 & -16;
      HEAP32[$9>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$9+0>>2]|0;
      $87 = (invoke_iiiiiii(102,($86|0),16,($$byval_copy10|0),0,(611088|0),79)|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       label = 75;
       break;
      }
      $90 = (($this) + 32|0);
      HEAP32[$90>>2] = $87;
      $91 = $86 | 1;
      HEAP32[$65>>2] = $91;
      $92 = (($this) + 28|0);
      HEAP32[$92>>2] = $78;
      $__p$0$i$i$i$i14 = $87;
     }
     _memcpy(($__p$0$i$i$i$i14|0),($93|0),($78|0))|0;
     $94 = (($__p$0$i$i$i$i14) + ($78)|0);
     HEAP8[$94>>0] = 0;
     $95 = (($this) + 36|0);
     $96 = (($0) + 36|0);
     $97 = HEAP32[$96>>2]|0;
     HEAP32[$95>>2] = $97;
     $98 = (($this) + 40|0);
     $99 = (($0) + 40|0);
     ;HEAP32[$98+0>>2]=HEAP32[$99+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$99+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$99+8>>2]|0;HEAP32[$98+12>>2]=HEAP32[$99+12>>2]|0;
     $100 = (($0) + 56|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (($this) + 56|0);
     HEAP32[$102>>2] = $101;
     ;HEAP32[$98+0>>2]=HEAP32[$99+0>>2]|0;HEAP32[$98+4>>2]=HEAP32[$99+4>>2]|0;HEAP32[$98+8>>2]=HEAP32[$99+8>>2]|0;HEAP32[$98+12>>2]=HEAP32[$99+12>>2]|0;
     $103 = (($this) + 60|0);
     $104 = (($0) + 60|0);
     ;HEAP32[$103+0>>2]=HEAP32[$104+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$104+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$104+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$104+12>>2]|0;
     $105 = (($this) + 76|0);
     HEAP32[$105>>2] = 0;
     $106 = (($this) + 80|0);
     HEAP32[$106>>2] = 0;
     $107 = (($this) + 84|0);
     HEAP32[$107>>2] = 0;
     $108 = (($0) + 80|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = (($0) + 76|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = $109;
     $113 = $111;
     $114 = (($112) - ($113))|0;
     $115 = (($114|0) / 12)&-1;
     $116 = ($109|0)==($111|0);
     do {
      if ($116) {
       label = 45;
      } else {
       $117 = ($115>>>0)>(357913941);
       if ($117) {
        __THREW__ = 0;
        invoke_vi(3308,0);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if (!($119)) {
         // unreachable;
        }
       } else {
        __THREW__ = 0;
        $120 = (invoke_ii(2988,($114|0))|0);
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if (!($122)) {
         HEAP32[$106>>2] = $120;
         HEAP32[$105>>2] = $120;
         $123 = (($120) + (($115*12)|0)|0);
         HEAP32[$107>>2] = $123;
         $124 = HEAP32[$110>>2]|0;
         $125 = HEAP32[$108>>2]|0;
         __THREW__ = 0;
         invoke_viii(1752,($105|0),($124|0),($125|0));
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if (!($127)) {
          label = 45;
          break;
         }
        }
       }
       $128 = ___cxa_find_matching_catch()|0;
       $129 = tempRet0;
       $130 = HEAP32[$105>>2]|0;
       $131 = ($130|0)==(0|0);
       if (!($131)) {
        $132 = HEAP32[$106>>2]|0;
        $133 = ($132|0)==($130|0);
        do {
         if ($133) {
          $147 = $130;
         } else {
          $135 = $132;
          while(1) {
           $134 = (($135) + -12|0);
           HEAP32[$106>>2] = $134;
           $136 = HEAP8[$134>>0]|0;
           $137 = $136 & 1;
           $138 = ($137<<24>>24)==(0);
           if ($138) {
            $140 = $134;
           } else {
            $141 = (($135) + -4|0);
            $142 = HEAP32[$141>>2]|0;
            HEAP32[$2>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
            invoke_vii(2591,($142|0),($$byval_copy10|0));
            $143 = __THREW__; __THREW__ = 0;
            $144 = $143&1;
            if ($144) {
             label = 42;
             break;
            }
            $$pre$i$i$i31 = HEAP32[$106>>2]|0;
            $140 = $$pre$i$i$i31;
           }
           $139 = ($140|0)==($130|0);
           if ($139) {
            label = 43;
            break;
           } else {
            $135 = $140;
           }
          }
          if ((label|0) == 42) {
           $145 = ___cxa_find_matching_catch()|0;
           $146 = tempRet0;
           ___cxa_call_unexpected(($145|0));
           // unreachable;
          }
          else if ((label|0) == 43) {
           $$pre$i = HEAP32[$105>>2]|0;
           $147 = $$pre$i;
           break;
          }
         }
        } while(0);
        __ZdlPv($147);
       }
       $$1 = $129;$$12 = $128;
      }
     } while(0);
     if ((label|0) == 45) {
      $148 = (($this) + 88|0);
      $149 = (($0) + 88|0);
      ;HEAP32[$148+0>>2]=HEAP32[$149+0>>2]|0;HEAP32[$148+4>>2]=HEAP32[$149+4>>2]|0;HEAP32[$148+8>>2]=HEAP32[$149+8>>2]|0;
      $150 = (($this) + 100|0);
      HEAP32[$150>>2] = 0;
      $151 = (($this) + 104|0);
      HEAP32[$151>>2] = 0;
      $152 = (($this) + 108|0);
      HEAP32[$152>>2] = 0;
      $153 = (($0) + 104|0);
      $154 = HEAP32[$153>>2]|0;
      $155 = (($0) + 100|0);
      $156 = HEAP32[$155>>2]|0;
      $157 = $154;
      $158 = $156;
      $159 = (($157) - ($158))|0;
      $160 = $159 >> 4;
      $161 = ($160|0)==(0);
      do {
       if ($161) {
        label = 61;
       } else {
        $162 = ($160>>>0)>(268435455);
        if ($162) {
         __THREW__ = 0;
         invoke_vi(3308,0);
         $163 = __THREW__; __THREW__ = 0;
         $164 = $163&1;
         if (!($164)) {
          // unreachable;
         }
        } else {
         __THREW__ = 0;
         $165 = (invoke_ii(2988,($159|0))|0);
         $166 = __THREW__; __THREW__ = 0;
         $167 = $166&1;
         if (!($167)) {
          HEAP32[$151>>2] = $165;
          HEAP32[$150>>2] = $165;
          $168 = (($165) + ($160<<4)|0);
          HEAP32[$152>>2] = $168;
          $169 = HEAP32[$155>>2]|0;
          $170 = HEAP32[$153>>2]|0;
          __THREW__ = 0;
          invoke_viii(1753,($150|0),($169|0),($170|0));
          $171 = __THREW__; __THREW__ = 0;
          $172 = $171&1;
          if (!($172)) {
           label = 61;
           break;
          }
         }
        }
        $173 = ___cxa_find_matching_catch()|0;
        $174 = tempRet0;
        $175 = HEAP32[$150>>2]|0;
        $176 = ($175|0)==(0|0);
        if (!($176)) {
         $177 = HEAP32[$151>>2]|0;
         $178 = ($177|0)==($175|0);
         do {
          if ($178) {
           $193 = $175;
          } else {
           $180 = $177;
           while(1) {
            $179 = (($180) + -16|0);
            HEAP32[$151>>2] = $179;
            $181 = (($180) + -12|0);
            $182 = HEAP8[$181>>0]|0;
            $183 = $182 & 1;
            $184 = ($183<<24>>24)==(0);
            if ($184) {
             $186 = $179;
            } else {
             $187 = (($180) + -4|0);
             $188 = HEAP32[$187>>2]|0;
             HEAP32[$1>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
             invoke_vii(2591,($188|0),($$byval_copy10|0));
             $189 = __THREW__; __THREW__ = 0;
             $190 = $189&1;
             if ($190) {
              label = 58;
              break;
             }
             $$pre$i$i$i33 = HEAP32[$151>>2]|0;
             $186 = $$pre$i$i$i33;
            }
            $185 = ($186|0)==($175|0);
            if ($185) {
             label = 59;
             break;
            } else {
             $180 = $186;
            }
           }
           if ((label|0) == 58) {
            $191 = ___cxa_find_matching_catch()|0;
            $192 = tempRet0;
            ___cxa_call_unexpected(($191|0));
            // unreachable;
           }
           else if ((label|0) == 59) {
            $$pre$i34 = HEAP32[$150>>2]|0;
            $193 = $$pre$i34;
            break;
           }
          }
         } while(0);
         __ZdlPv($193);
        }
        $$0 = $174;$$01 = $173;
       }
      } while(0);
      if ((label|0) == 61) {
       $194 = (($this) + 112|0);
       $195 = (($0) + 112|0);
       $196 = HEAP32[$195>>2]|0;
       HEAP32[$194>>2] = $196;
       $197 = (($this) + 116|0);
       $198 = (($this) + 120|0);
       HEAP32[$198>>2] = 0;
       $199 = (($this) + 124|0);
       HEAP32[$199>>2] = 0;
       $200 = (($this) + 120|0);
       HEAP32[$197>>2] = $200;
       $201 = (($0) + 116|0);
       $202 = HEAP32[$201>>2]|0;
       $203 = (($0) + 120|0);
       $204 = ($202|0)==($203|0);
       if ($204) {
        $235 = HEAP32[$195>>2]|0;
        HEAP32[$194>>2] = $235;
        STACKTOP = sp;return;
       }
       $206 = $202;
       while(1) {
        $205 = (($206) + 16|0);
        HEAP32[$8>>2] = $200;
        ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$8+0>>2]|0;
        $207 = (__ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIjPNS_11__tree_nodeIjS8_EEiEESB_RKT_($197,$$byval_copy10,$__parent$i$i$i$i,$205)|0);
        $208 = HEAP32[$207>>2]|0;
        $209 = ($208|0)==(0|0);
        if ($209) {
         __THREW__ = 0;
         $210 = (invoke_ii(2988,20)|0);
         $211 = __THREW__; __THREW__ = 0;
         $212 = $211&1;
         if ($212) {
          break;
         }
         $213 = (($210) + 16|0);
         $214 = HEAP32[$205>>2]|0;
         HEAP32[$213>>2] = $214;
         $215 = HEAP32[$__parent$i$i$i$i>>2]|0;
         HEAP32[$210>>2] = 0;
         $216 = (($210) + 4|0);
         HEAP32[$216>>2] = 0;
         $217 = (($210) + 8|0);
         HEAP32[$217>>2] = $215;
         HEAP32[$207>>2] = $210;
         $218 = HEAP32[$197>>2]|0;
         $219 = HEAP32[$218>>2]|0;
         $220 = ($219|0)==(0|0);
         if ($220) {
          $222 = $210;
         } else {
          HEAP32[$197>>2] = $219;
          $$pre$i$i$i$i$i = HEAP32[$207>>2]|0;
          $222 = $$pre$i$i$i$i$i;
         }
         $221 = HEAP32[$198>>2]|0;
         __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($221,$222);
         $223 = HEAP32[$199>>2]|0;
         $224 = (($223) + 1)|0;
         HEAP32[$199>>2] = $224;
        }
        $225 = (($206) + 4|0);
        $226 = HEAP32[$225>>2]|0;
        $227 = ($226|0)==(0|0);
        if ($227) {
         $$01$i$i$i$i$i = $206;
         while(1) {
          $230 = (($$01$i$i$i$i$i) + 8|0);
          $231 = HEAP32[$230>>2]|0;
          $232 = HEAP32[$231>>2]|0;
          $233 = ($232|0)==($$01$i$i$i$i$i|0);
          if ($233) {
           $$0$i$i$i$i$i = $231;
           break;
          } else {
           $$01$i$i$i$i$i = $231;
          }
         }
        } else {
         $$0$i$i$i$i$i$i = $226;
         while(1) {
          $228 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
          $229 = ($228|0)==(0|0);
          if ($229) {
           $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
           break;
          } else {
           $$0$i$i$i$i$i$i = $228;
          }
         }
        }
        $234 = ($$0$i$i$i$i$i|0)==($203|0);
        if ($234) {
         label = 73;
         break;
        } else {
         $206 = $$0$i$i$i$i$i;
        }
       }
       if ((label|0) == 73) {
        $235 = HEAP32[$195>>2]|0;
        HEAP32[$194>>2] = $235;
        STACKTOP = sp;return;
       }
       $240 = ___cxa_find_matching_catch()|0;
       $241 = tempRet0;
       $242 = HEAP32[$198>>2]|0;
       __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($197,$242);
       $243 = HEAP32[$150>>2]|0;
       $244 = ($243|0)==(0|0);
       if ($244) {
        $$0 = $241;$$01 = $240;
       } else {
        $245 = HEAP32[$151>>2]|0;
        $246 = ($245|0)==($243|0);
        do {
         if ($246) {
          $261 = $243;
         } else {
          $248 = $245;
          while(1) {
           $247 = (($248) + -16|0);
           HEAP32[$151>>2] = $247;
           $249 = (($248) + -12|0);
           $250 = HEAP8[$249>>0]|0;
           $251 = $250 & 1;
           $252 = ($251<<24>>24)==(0);
           if ($252) {
            $254 = $247;
           } else {
            $255 = (($248) + -4|0);
            $256 = HEAP32[$255>>2]|0;
            HEAP32[$7>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$7+0>>2]|0;
            invoke_vii(2591,($256|0),($$byval_copy10|0));
            $257 = __THREW__; __THREW__ = 0;
            $258 = $257&1;
            if ($258) {
             label = 85;
             break;
            }
            $$pre$i$i$i$i$i24 = HEAP32[$151>>2]|0;
            $254 = $$pre$i$i$i$i$i24;
           }
           $253 = ($254|0)==($243|0);
           if ($253) {
            label = 86;
            break;
           } else {
            $248 = $254;
           }
          }
          if ((label|0) == 85) {
           $259 = ___cxa_find_matching_catch()|0;
           $260 = tempRet0;
           ___cxa_call_unexpected(($259|0));
           // unreachable;
          }
          else if ((label|0) == 86) {
           $$pre$i$i$i = HEAP32[$150>>2]|0;
           $261 = $$pre$i$i$i;
           break;
          }
         }
        } while(0);
        __ZdlPv($261);
        $$0 = $241;$$01 = $240;
       }
      }
      $262 = HEAP32[$105>>2]|0;
      $263 = ($262|0)==(0|0);
      if ($263) {
       $$1 = $$0;$$12 = $$01;
      } else {
       $264 = HEAP32[$106>>2]|0;
       $265 = ($264|0)==($262|0);
       do {
        if ($265) {
         $279 = $262;
        } else {
         $267 = $264;
         while(1) {
          $266 = (($267) + -12|0);
          HEAP32[$106>>2] = $266;
          $268 = HEAP8[$266>>0]|0;
          $269 = $268 & 1;
          $270 = ($269<<24>>24)==(0);
          if ($270) {
           $272 = $266;
          } else {
           $273 = (($267) + -4|0);
           $274 = HEAP32[$273>>2]|0;
           HEAP32[$6>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$6+0>>2]|0;
           invoke_vii(2591,($274|0),($$byval_copy10|0));
           $275 = __THREW__; __THREW__ = 0;
           $276 = $275&1;
           if ($276) {
            label = 95;
            break;
           }
           $$pre$i$i$i$i$i26 = HEAP32[$106>>2]|0;
           $272 = $$pre$i$i$i$i$i26;
          }
          $271 = ($272|0)==($262|0);
          if ($271) {
           label = 96;
           break;
          } else {
           $267 = $272;
          }
         }
         if ((label|0) == 95) {
          $277 = ___cxa_find_matching_catch()|0;
          $278 = tempRet0;
          ___cxa_call_unexpected(($277|0));
          // unreachable;
         }
         else if ((label|0) == 96) {
          $$pre$i$i$i27 = HEAP32[$105>>2]|0;
          $279 = $$pre$i$i$i27;
          break;
         }
        }
       } while(0);
       __ZdlPv($279);
       $$1 = $$0;$$12 = $$01;
      }
     }
     $280 = HEAP8[$65>>0]|0;
     $281 = $280 & 1;
     $282 = ($281<<24>>24)==(0);
     if ($282) {
      $$2 = $$1;$$23 = $$12;
     } else {
      $283 = (($this) + 32|0);
      $284 = HEAP32[$283>>2]|0;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_vii(2591,($284|0),($$byval_copy10|0));
      $285 = __THREW__; __THREW__ = 0;
      $286 = $285&1;
      if ($286) {
       $287 = ___cxa_find_matching_catch()|0;
       $288 = tempRet0;
       ___cxa_call_unexpected(($287|0));
       // unreachable;
      } else {
       $$2 = $$1;$$23 = $$12;
      }
     }
    }
   } while(0);
   if ((label|0) == 75) {
    $238 = ___cxa_find_matching_catch()|0;
    $239 = tempRet0;
    $$2 = $239;$$23 = $238;
   }
   $289 = HEAP8[$35>>0]|0;
   $290 = $289 & 1;
   $291 = ($290<<24>>24)==(0);
   if ($291) {
    $$3 = $$2;$$34 = $$23;
   } else {
    $292 = (($this) + 20|0);
    $293 = HEAP32[$292>>2]|0;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($293|0),($$byval_copy10|0));
    $294 = __THREW__; __THREW__ = 0;
    $295 = $294&1;
    if ($295) {
     $296 = ___cxa_find_matching_catch()|0;
     $297 = tempRet0;
     ___cxa_call_unexpected(($296|0));
     // unreachable;
    } else {
     $$3 = $$2;$$34 = $$23;
    }
   }
  }
 } while(0);
 if ((label|0) == 74) {
  $236 = ___cxa_find_matching_catch()|0;
  $237 = tempRet0;
  $$3 = $237;$$34 = $236;
 }
 $298 = HEAP8[$this>>0]|0;
 $299 = $298 & 1;
 $300 = ($299<<24>>24)==(0);
 if ($300) {
  ___resumeException($$34|0);
  // unreachable;
 }
 $301 = (($this) + 8|0);
 $302 = HEAP32[$301>>2]|0;
 HEAP32[$3>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($302|0),($$byval_copy10|0));
 $303 = __THREW__; __THREW__ = 0;
 $304 = $303&1;
 if ($304) {
  $305 = ___cxa_find_matching_catch()|0;
  $306 = tempRet0;
  ___cxa_call_unexpected(($305|0));
  // unreachable;
 } else {
  ___resumeException($$34|0);
  // unreachable;
 }
}
function __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE12__find_equalIjEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIjPNS_11__tree_nodeIjS8_EEiEESB_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = (($1) + 16|0);
  $4 = HEAP32[$__v>>2]|0;
  $5 = HEAP32[$3>>2]|0;
  $6 = ($4>>>0)<($5>>>0);
  if (!($6)) {
   $36 = ($5>>>0)<($4>>>0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($4>>>0)<($48>>>0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($4>>>0)<($54>>>0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54>>>0)<($4>>>0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18>>>0)<($19>>>0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19>>>0)<($28>>>0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28>>>0)<($19>>>0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$01 = 0, $$byval_copy = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__first|0)==($__last|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 $$pre = HEAP32[$2>>2]|0;
 $$01 = $__first;$4 = $$pre;
 while(1) {
  $3 = ($4|0)==(0|0);
  if ($3) {
   $34 = 0;
  } else {
   $5 = HEAP32[$$01>>2]|0;
   HEAP32[$4>>2] = $5;
   $6 = (($4) + 4|0);
   $7 = (($$01) + 4|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $15 = (($7) + 1|0);
    $16 = $8&255;
    $17 = $16 >>> 1;
    $19 = $17;$30 = $15;
   } else {
    $11 = (($$01) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($$01) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $19 = $14;$30 = $12;
   }
   $18 = ($19>>>0)>(2147483631);
   if ($18) {
    label = 8;
    break;
   }
   $20 = ($19>>>0)<(11);
   if ($20) {
    $21 = $19 << 1;
    $22 = $21&255;
    HEAP8[$6>>0] = $22;
    $23 = (($6) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $23;
   } else {
    $24 = (($19) + 16)|0;
    $25 = $24 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy,0,611088,79)|0);
    $27 = (($4) + 12|0);
    HEAP32[$27>>2] = $26;
    $28 = $25 | 1;
    HEAP32[$6>>2] = $28;
    $29 = (($4) + 8|0);
    HEAP32[$29>>2] = $19;
    $__p$0$i$i$i$i$i$i$i = $26;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($30|0),($19|0))|0;
   $31 = (($__p$0$i$i$i$i$i$i$i) + ($19)|0);
   HEAP8[$31>>0] = 0;
   $32 = HEAP32[$$01>>2]|0;
   HEAP32[$4>>2] = $32;
   $$pre2 = HEAP32[$2>>2]|0;
   $34 = $$pre2;
  }
  $33 = (($34) + 16|0);
  HEAP32[$2>>2] = $33;
  $35 = (($$01) + 16|0);
  $36 = ($35|0)==($__last|0);
  if ($36) {
   label = 14;
   break;
  } else {
   $$01 = $35;$4 = $33;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$01 = 0, $$byval_copy = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__first|0)==($__last|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 $$pre = HEAP32[$2>>2]|0;
 $$01 = $__first;$4 = $$pre;
 while(1) {
  $3 = ($4|0)==(0|0);
  if ($3) {
   $30 = 0;
  } else {
   $5 = HEAP8[$$01>>0]|0;
   $6 = $5 & 1;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $12 = (($$01) + 1|0);
    $13 = $5&255;
    $14 = $13 >>> 1;
    $16 = $14;$27 = $12;
   } else {
    $8 = (($$01) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($$01) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $16 = $11;$27 = $9;
   }
   $15 = ($16>>>0)>(2147483631);
   if ($15) {
    label = 8;
    break;
   }
   $17 = ($16>>>0)<(11);
   if ($17) {
    $18 = $16 << 1;
    $19 = $18&255;
    HEAP8[$4>>0] = $19;
    $20 = (($4) + 1|0);
    $__p$0$i$i$i$i$i = $20;
   } else {
    $21 = (($16) + 16)|0;
    $22 = $21 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,16,$$byval_copy,0,611088,79)|0);
    $24 = (($4) + 8|0);
    HEAP32[$24>>2] = $23;
    $25 = $22 | 1;
    HEAP32[$4>>2] = $25;
    $26 = (($4) + 4|0);
    HEAP32[$26>>2] = $16;
    $__p$0$i$i$i$i$i = $23;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($27|0),($16|0))|0;
   $28 = (($__p$0$i$i$i$i$i) + ($16)|0);
   HEAP8[$28>>0] = 0;
   $$pre2 = HEAP32[$2>>2]|0;
   $30 = $$pre2;
  }
  $29 = (($30) + 12|0);
  HEAP32[$2>>2] = $29;
  $31 = (($$01) + 12|0);
  $32 = ($31|0)==($__last|0);
  if ($32) {
   label = 14;
   break;
  } else {
   $$01 = $31;$4 = $29;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZN14SubstanceInputaSERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($this,$0)|0);
 $3 = (($this) + 12|0);
 $4 = (($0) + 12|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($3,$4)|0);
 $5 = (($this) + 24|0);
 $6 = (($0) + 24|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($5,$6)|0);
 $7 = (($0) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 36|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 40|0);
 $11 = (($0) + 40|0);
 ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;
 $12 = (($0) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 56|0);
 HEAP32[$14>>2] = $13;
 $15 = (($this) + 60|0);
 $16 = (($0) + 60|0);
 ;HEAP32[$15+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$16+12>>2]|0;
 $17 = ($this|0)==($0|0);
 if ($17) {
  $18 = (($this) + 88|0);
  $19 = (($0) + 88|0);
  ;HEAP32[$18+0>>2]=HEAP32[$19+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$19+8>>2]|0;
 } else {
  $20 = (($this) + 76|0);
  $21 = (($0) + 76|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($0) + 80|0);
  $24 = HEAP32[$23>>2]|0;
  __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($20,$22,$24);
  $25 = (($this) + 88|0);
  $26 = (($0) + 88|0);
  ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;
  $27 = (($this) + 100|0);
  $28 = (($0) + 100|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($0) + 104|0);
  $31 = HEAP32[$30>>2]|0;
  __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($27,$29,$31);
 }
 $32 = (($0) + 112|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 112|0);
 HEAP32[$34>>2] = $33;
 if ($17) {
  STACKTOP = sp;return ($this|0);
 }
 $35 = (($this) + 116|0);
 $36 = (($0) + 116|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$1>>2] = $37;
 $38 = (($0) + 120|0);
 HEAP32[$2>>2] = $38;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_($35,$$byval_copy,$$byval_copy1);
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE14__assign_multiINS_21__tree_const_iteratorIjPNS_11__tree_nodeIjPvEEiEEEEvT_SD_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i4 = 0, $$0$i$i13 = 0, $$0$i$i15 = 0, $$0$i$i2 = 0, $$0$i$i8 = 0, $$0$i1$i = 0, $$01$i$i = 0, $$01$i$i6 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__cache$0$ph = 0, $__cache$023 = 0, $__cache$2$lcssa = 0, $__nd$0$in$i$i = 0, $__nd$0$in$i$i11 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = HEAP32[$this>>2]|0;
   $4 = (($this) + 4|0);
   HEAP32[$this>>2] = $4;
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + 8|0);
   HEAP32[$6>>2] = 0;
   HEAP32[$4>>2] = 0;
   HEAP32[$0>>2] = 0;
   $7 = (($3) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $__cache$0$ph = $3;
   } else {
    $__cache$0$ph = $8;
   }
   $10 = ($__cache$0$ph|0)==(0|0);
   if (!($10)) {
    $11 = (($this) + 4|0);
    $$pre = HEAP32[$__first>>2]|0;
    $14 = $$pre;$__cache$023 = $__cache$0$ph;
    while(1) {
     $12 = HEAP32[$__last>>2]|0;
     $13 = ($14|0)==($12|0);
     if ($13) {
      break;
     }
     $18 = (($14) + 16|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($__cache$023) + 16|0);
     HEAP32[$20>>2] = $19;
     $21 = (($__cache$023) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     do {
      if ($23) {
       $$0$i = 0;
      } else {
       $24 = HEAP32[$22>>2]|0;
       $25 = ($24|0)==($__cache$023|0);
       if ($25) {
        HEAP32[$22>>2] = 0;
        $26 = HEAP32[$21>>2]|0;
        $27 = (($26) + 4|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = ($28|0)==(0|0);
        if ($29) {
         $$0$i = $26;
         break;
        } else {
         $$0$i1$i = $28;
        }
        while(1) {
         $30 = HEAP32[$$0$i1$i>>2]|0;
         $31 = ($30|0)==(0|0);
         if (!($31)) {
          $$0$i1$i = $30;
          continue;
         }
         $32 = (($$0$i1$i) + 4|0);
         $33 = HEAP32[$32>>2]|0;
         $34 = ($33|0)==(0|0);
         if ($34) {
          break;
         } else {
          $$0$i1$i = $33;
         }
        }
        $$0$i = $$0$i1$i;
        break;
       } else {
        $35 = (($22) + 4|0);
        HEAP32[$35>>2] = 0;
        $36 = HEAP32[$21>>2]|0;
        $37 = HEAP32[$36>>2]|0;
        $38 = ($37|0)==(0|0);
        if ($38) {
         $$0$i = $36;
         break;
        } else {
         $$0$i$i15 = $37;
        }
        while(1) {
         $39 = HEAP32[$$0$i$i15>>2]|0;
         $40 = ($39|0)==(0|0);
         if (!($40)) {
          $$0$i$i15 = $39;
          continue;
         }
         $41 = (($$0$i$i15) + 4|0);
         $42 = HEAP32[$41>>2]|0;
         $43 = ($42|0)==(0|0);
         if ($43) {
          break;
         } else {
          $$0$i$i15 = $42;
         }
        }
        $$0$i = $$0$i$i15;
        break;
       }
      }
     } while(0);
     $44 = HEAP32[$11>>2]|0;
     $45 = ($44|0)==(0|0);
     if ($45) {
      $$0$i$i13 = $4;$55 = $4;
     } else {
      $__nd$0$in$i$i11 = $44;
      while(1) {
       $46 = (($__nd$0$in$i$i11) + 16|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($19>>>0)<($47>>>0);
       if ($48) {
        $49 = HEAP32[$__nd$0$in$i$i11>>2]|0;
        $50 = ($49|0)==(0|0);
        if ($50) {
         $$0$i$i13 = $__nd$0$in$i$i11;$55 = $__nd$0$in$i$i11;
         break;
        } else {
         $__nd$0$in$i$i11 = $49;
         continue;
        }
       } else {
        $51 = (($__nd$0$in$i$i11) + 4|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = ($52|0)==(0|0);
        if ($53) {
         $$0$i$i13 = $51;$55 = $__nd$0$in$i$i11;
         break;
        } else {
         $__nd$0$in$i$i11 = $52;
         continue;
        }
       }
      }
     }
     HEAP32[$__cache$023>>2] = 0;
     $54 = (($__cache$023) + 4|0);
     HEAP32[$54>>2] = 0;
     HEAP32[$21>>2] = $55;
     HEAP32[$$0$i$i13>>2] = $__cache$023;
     $56 = HEAP32[$this>>2]|0;
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $60 = $__cache$023;
     } else {
      HEAP32[$this>>2] = $57;
      $$pre$i$i14 = HEAP32[$$0$i$i13>>2]|0;
      $60 = $$pre$i$i14;
     }
     $59 = HEAP32[$11>>2]|0;
     __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($59,$60);
     $61 = HEAP32[$0>>2]|0;
     $62 = (($61) + 1)|0;
     HEAP32[$0>>2] = $62;
     $63 = HEAP32[$__first>>2]|0;
     $64 = (($63) + 4|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = ($65|0)==(0|0);
     if ($66) {
      $$01$i$i6 = $63;
      while(1) {
       $69 = (($$01$i$i6) + 8|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = HEAP32[$70>>2]|0;
       $72 = ($71|0)==($$01$i$i6|0);
       if ($72) {
        $$0$i$i8 = $70;
        break;
       } else {
        $$01$i$i6 = $70;
       }
      }
     } else {
      $$0$i$i$i4 = $65;
      while(1) {
       $67 = HEAP32[$$0$i$i$i4>>2]|0;
       $68 = ($67|0)==(0|0);
       if ($68) {
        $$0$i$i8 = $$0$i$i$i4;
        break;
       } else {
        $$0$i$i$i4 = $67;
       }
      }
     }
     HEAP32[$__first>>2] = $$0$i$i8;
     $73 = ($$0$i|0)==(0|0);
     if ($73) {
      break L1;
     } else {
      $14 = $$0$i$i8;$__cache$023 = $$0$i;
     }
    }
    $15 = (($__cache$023) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $__cache$2$lcssa = $__cache$023;
    } else {
     $75 = $16;
     while(1) {
      $74 = (($75) + 8|0);
      $76 = HEAP32[$74>>2]|0;
      $77 = ($76|0)==(0|0);
      if ($77) {
       break;
      } else {
       $75 = $76;
      }
     }
     $__cache$2$lcssa = $75;
    }
    __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($this,$__cache$2$lcssa);
   }
  }
 } while(0);
 $78 = HEAP32[$__first>>2]|0;
 $79 = HEAP32[$__last>>2]|0;
 $80 = ($78|0)==($79|0);
 if ($80) {
  STACKTOP = sp;return;
 }
 $81 = (($this) + 4|0);
 $82 = (($this) + 4|0);
 $84 = $78;
 while(1) {
  $83 = (($84) + 16|0);
  $85 = HEAP32[$81>>2]|0;
  $86 = ($85|0)==(0|0);
  $$pre$i = HEAP32[$83>>2]|0;
  if ($86) {
   $$0$i$i2 = $82;$99 = $82;
  } else {
   $__nd$0$in$i$i = $85;
   while(1) {
    $87 = (($__nd$0$in$i$i) + 16|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ($$pre$i>>>0)<($88>>>0);
    if ($89) {
     $90 = HEAP32[$__nd$0$in$i$i>>2]|0;
     $91 = ($90|0)==(0|0);
     if ($91) {
      $$0$i$i2 = $__nd$0$in$i$i;$99 = $__nd$0$in$i$i;
      break;
     } else {
      $__nd$0$in$i$i = $90;
      continue;
     }
    } else {
     $92 = (($__nd$0$in$i$i) + 4|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ($93|0)==(0|0);
     if ($94) {
      $$0$i$i2 = $92;$99 = $__nd$0$in$i$i;
      break;
     } else {
      $__nd$0$in$i$i = $93;
      continue;
     }
    }
   }
  }
  $95 = (__Znwj(20)|0);
  $96 = (($95) + 16|0);
  HEAP32[$96>>2] = $$pre$i;
  HEAP32[$95>>2] = 0;
  $97 = (($95) + 4|0);
  HEAP32[$97>>2] = 0;
  $98 = (($95) + 8|0);
  HEAP32[$98>>2] = $99;
  HEAP32[$$0$i$i2>>2] = $95;
  $100 = HEAP32[$this>>2]|0;
  $101 = HEAP32[$100>>2]|0;
  $102 = ($101|0)==(0|0);
  if ($102) {
   $104 = $95;
  } else {
   HEAP32[$this>>2] = $101;
   $$pre$i$i = HEAP32[$$0$i$i2>>2]|0;
   $104 = $$pre$i$i;
  }
  $103 = HEAP32[$81>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($103,$104);
  $105 = HEAP32[$0>>2]|0;
  $106 = (($105) + 1)|0;
  HEAP32[$0>>2] = $106;
  $107 = HEAP32[$__first>>2]|0;
  $108 = (($107) + 4|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)==(0|0);
  if ($110) {
   $$01$i$i = $107;
   while(1) {
    $113 = (($$01$i$i) + 8|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = HEAP32[$114>>2]|0;
    $116 = ($115|0)==($$01$i$i|0);
    if ($116) {
     $$0$i$i = $114;
     break;
    } else {
     $$01$i$i = $114;
    }
   }
  } else {
   $$0$i$i$i = $109;
   while(1) {
    $111 = HEAP32[$$0$i$i$i>>2]|0;
    $112 = ($111|0)==(0|0);
    if ($112) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $111;
    }
   }
  }
  HEAP32[$__first>>2] = $$0$i$i;
  $117 = HEAP32[$__last>>2]|0;
  $118 = ($$0$i$i|0)==($117|0);
  if ($118) {
   break;
  } else {
   $84 = $$0$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i2 = 0, $$0$lcssa$i$i = 0, $$012$i$i = 0, $$03$i$i = 0, $$byval_copy1 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = $__last;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 4;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 4;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $48 = ($8|0)==(0|0);
  if ($48) {
   $69 = $7;
  } else {
   $49 = (($this) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==($8|0);
   do {
    if ($51) {
     $66 = $8;
    } else {
     $53 = $50;
     while(1) {
      $52 = (($53) + -16|0);
      HEAP32[$49>>2] = $52;
      $54 = (($53) + -12|0);
      $55 = HEAP8[$54>>0]|0;
      $56 = $55 & 1;
      $57 = ($56<<24>>24)==(0);
      if ($57) {
       $59 = $52;
      } else {
       $60 = (($53) + -4|0);
       $61 = HEAP32[$60>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($61|0),($$byval_copy1|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$49>>2]|0;
       $59 = $$pre$i$i$i$i;
      }
      $58 = ($59|0)==($8|0);
      if ($58) {
       label = 25;
       break;
      } else {
       $53 = $59;
      }
     }
     if ((label|0) == 24) {
      $64 = ___cxa_find_matching_catch()|0;
      $65 = tempRet0;
      ___cxa_call_unexpected(($64|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $66 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($66);
   HEAP32[$6>>2] = 0;
   HEAP32[$49>>2] = 0;
   HEAP32[$this>>2] = 0;
   $69 = 0;
  }
  $67 = ($5>>>0)>(268435455);
  if ($67) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $68 = $69;
  $70 = $68 >> 4;
  $71 = ($70>>>0)<(134217727);
  if ($71) {
   $72 = $68 >> 3;
   $73 = ($72>>>0)<($5>>>0);
   $74 = $73 ? $5 : $72;
   $75 = ($74>>>0)>(268435455);
   if ($75) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i2 = $74;
   }
  } else {
   $$0$i2 = 268435455;
  }
  $76 = $$0$i2 << 4;
  $77 = (__Znwj($76)|0);
  $78 = (($this) + 4|0);
  HEAP32[$78>>2] = $77;
  HEAP32[$this>>2] = $77;
  $79 = (($77) + ($$0$i2<<4)|0);
  HEAP32[$6>>2] = $79;
  __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_($this,$__first,$__last);
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 4;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($__first) + ($18<<4)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $__last;$__growing$0$off0 = 0;
 }
 $21 = ($22|0)==($__first|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i = (($22) + -16|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($23)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $8;
  while(1) {
   $24 = HEAP32[$$012$i$i>>2]|0;
   HEAP32[$$03$i$i>>2] = $24;
   $25 = (($$03$i$i) + 4|0);
   $26 = (($$012$i$i) + 4|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($25,$26)|0);
   $27 = (($$012$i$i) + 16|0);
   $28 = (($$03$i$i) + 16|0);
   $29 = ($27|0)==($22|0);
   if ($29) {
    break;
   } else {
    $$012$i$i = $27;$$03$i$i = $28;
   }
  }
  $30 = $uglygep6$i$i >>> 4;
  $31 = (($30) + 1)|0;
  $scevgep7$i$i = (($8) + ($31<<4)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if ($__growing$0$off0) {
  __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_($this,$22,$__last);
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$14>>2]|0;
 $33 = ($32|0)==($$0$lcssa$i$i|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $35 = $32;
 while(1) {
  $34 = (($35) + -16|0);
  HEAP32[$14>>2] = $34;
  $36 = (($35) + -12|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = $37 & 1;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $41 = $34;
  } else {
   $42 = (($35) + -4|0);
   $43 = HEAP32[$42>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($43|0),($$byval_copy1|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    label = 16;
    break;
   }
   $$pre$i$i = HEAP32[$14>>2]|0;
   $41 = $$pre$i$i;
  }
  $40 = ($41|0)==($$0$lcssa$i$i|0);
  if ($40) {
   label = 33;
   break;
  } else {
   $35 = $41;
  }
 }
 if ((label|0) == 16) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 }
 else if ((label|0) == 33) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i2 = 0, $$0$lcssa$i$i = 0, $$012$i$i = 0, $$03$i$i = 0, $$byval_copy1 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $8 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = $__last;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = (($4|0) / 12)&-1;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = (($11|0) / 12)&-1;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $44 = ($8|0)==(0|0);
  if ($44) {
   $64 = $7;
  } else {
   $45 = (($this) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($8|0);
   do {
    if ($47) {
     $61 = $8;
    } else {
     $49 = $46;
     while(1) {
      $48 = (($49) + -12|0);
      HEAP32[$45>>2] = $48;
      $50 = HEAP8[$48>>0]|0;
      $51 = $50 & 1;
      $52 = ($51<<24>>24)==(0);
      if ($52) {
       $54 = $48;
      } else {
       $55 = (($49) + -4|0);
       $56 = HEAP32[$55>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($56|0),($$byval_copy1|0));
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$45>>2]|0;
       $54 = $$pre$i$i$i$i;
      }
      $53 = ($54|0)==($8|0);
      if ($53) {
       label = 25;
       break;
      } else {
       $49 = $54;
      }
     }
     if ((label|0) == 24) {
      $59 = ___cxa_find_matching_catch()|0;
      $60 = tempRet0;
      ___cxa_call_unexpected(($59|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $61 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($61);
   HEAP32[$6>>2] = 0;
   HEAP32[$45>>2] = 0;
   HEAP32[$this>>2] = 0;
   $64 = 0;
  }
  $62 = ($5>>>0)>(357913941);
  if ($62) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $63 = $64;
  $65 = (($63|0) / 12)&-1;
  $66 = ($65>>>0)<(178956970);
  if ($66) {
   $67 = $65 << 1;
   $68 = ($67>>>0)<($5>>>0);
   $69 = $68 ? $5 : $67;
   $70 = ($69>>>0)>(357913941);
   if ($70) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i2 = $69;
   }
  } else {
   $$0$i2 = 357913941;
  }
  $71 = ($$0$i2*12)|0;
  $72 = (__Znwj($71)|0);
  $73 = (($this) + 4|0);
  HEAP32[$73>>2] = $72;
  HEAP32[$this>>2] = $72;
  $74 = (($72) + (($$0$i2*12)|0)|0);
  HEAP32[$6>>2] = $74;
  __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_($this,$__first,$__last);
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = (($17|0) / 12)&-1;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($__first) + (($18*12)|0)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $__last;$__growing$0$off0 = 0;
 }
 $21 = ($22|0)==($__first|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i = (($22) + -12|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($23)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $8;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($$03$i$i,$$012$i$i)|0);
   $24 = (($$012$i$i) + 12|0);
   $25 = (($$03$i$i) + 12|0);
   $26 = ($24|0)==($22|0);
   if ($26) {
    break;
   } else {
    $$012$i$i = $24;$$03$i$i = $25;
   }
  }
  $27 = (($uglygep6$i$i>>>0) / 12)&-1;
  $28 = (($27) + 1)|0;
  $scevgep7$i$i = (($8) + (($28*12)|0)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if ($__growing$0$off0) {
  __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_($this,$22,$__last);
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$14>>2]|0;
 $30 = ($29|0)==($$0$lcssa$i$i|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $32 = $29;
 while(1) {
  $31 = (($32) + -12|0);
  HEAP32[$14>>2] = $31;
  $33 = HEAP8[$31>>0]|0;
  $34 = $33 & 1;
  $35 = ($34<<24>>24)==(0);
  if ($35) {
   $37 = $31;
  } else {
   $38 = (($32) + -4|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($39|0),($$byval_copy1|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    label = 16;
    break;
   }
   $$pre$i$i = HEAP32[$14>>2]|0;
   $37 = $$pre$i$i;
  }
  $36 = ($37|0)==($$0$lcssa$i$i|0);
  if ($36) {
   label = 33;
   break;
  } else {
   $32 = $37;
  }
 }
 if ((label|0) == 16) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  ___cxa_call_unexpected(($42|0));
  // unreachable;
 }
 else if ((label|0) == 33) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrI17ProceduralTextureENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i17 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i8 = 0, $$012$i$i = 0, $$03$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $__first3$i1 = 0, $__growing$0$off0 = 0;
 var $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i13 = 0, $scevgep$i3 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep5$i = 0, $scevgep5$i10 = 0, $scevgep7$i$i = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i15 = 0, $uglygep$i5 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep4$i = 0, $uglygep4$i6 = 0;
 var $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($3>>>0)>($10>>>0);
 if ($11) {
  $42 = ($6|0)==(0|0);
  if ($42) {
   $51 = $5;
  } else {
   $43 = (($this) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==($6|0);
   if (!($45)) {
    $scevgep$i$i$i$i = (($44) + -4|0);
    $46 = (0 - ($8))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($46)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $47 = $uglygep3$i$i$i$i >>> 2;
    $48 = $47 ^ -1;
    $scevgep4$i$i$i$i = (($44) + ($48<<2)|0);
    HEAP32[$43>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($6);
   HEAP32[$4>>2] = 0;
   HEAP32[$43>>2] = 0;
   HEAP32[$this>>2] = 0;
   $51 = 0;
  }
  $49 = ($3>>>0)>(1073741823);
  if ($49) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $50 = $51;
  $52 = $50 >> 2;
  $53 = ($52>>>0)<(536870911);
  if ($53) {
   $54 = $50 >> 1;
   $55 = ($54>>>0)<($3>>>0);
   $56 = $55 ? $3 : $54;
   $57 = ($56>>>0)>(1073741823);
   if ($57) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i17 = $56;
   }
  } else {
   $$0$i17 = 1073741823;
  }
  $58 = $$0$i17 << 2;
  $59 = (__Znwj($58)|0);
  $60 = (($this) + 4|0);
  HEAP32[$60>>2] = $59;
  HEAP32[$this>>2] = $59;
  $61 = (($59) + ($$0$i17<<2)|0);
  HEAP32[$4>>2] = $61;
  $62 = ($__first|0)==($__last|0);
  if ($62) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($__last) + -4|0);
  $63 = (0 - ($1))|0;
  $uglygep$i = (($scevgep$i) + ($63)|0);
  $uglygep4$i = $uglygep$i;
  $64 = $uglygep4$i >>> 2;
  $$01$i = $__first;$66 = $59;
  while(1) {
   $65 = ($66|0)==(0|0);
   if (!($65)) {
    $67 = HEAP32[$$01$i>>2]|0;
    HEAP32[$66>>2] = $67;
   }
   $68 = (($66) + 4|0);
   $69 = (($$01$i) + 4|0);
   $70 = ($69|0)==($__last|0);
   if ($70) {
    break;
   } else {
    $$01$i = $69;$66 = $68;
   }
  }
  $71 = (($64) + 1)|0;
  $scevgep5$i = (($59) + ($71<<2)|0);
  HEAP32[$60>>2] = $scevgep5$i;
  STACKTOP = sp;return;
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = $15 >> 2;
 $17 = ($3>>>0)>($16>>>0);
 if ($17) {
  $18 = (($__first) + ($16<<2)|0);
  $20 = $18;$__growing$0$off0 = 1;
 } else {
  $20 = $__last;$__growing$0$off0 = 0;
 }
 $19 = ($20|0)==($__first|0);
 if ($19) {
  $$0$lcssa$i$i = $6;
 } else {
  $scevgep$i$i13 = (($20) + -4|0);
  $21 = (0 - ($1))|0;
  $uglygep$i$i15 = (($scevgep$i$i13) + ($21)|0);
  $uglygep6$i$i = $uglygep$i$i15;
  $$012$i$i = $__first;$$03$i$i = $6;
  while(1) {
   $22 = HEAP32[$$012$i$i>>2]|0;
   HEAP32[$$03$i$i>>2] = $22;
   $23 = (($$012$i$i) + 4|0);
   $24 = (($$03$i$i) + 4|0);
   $25 = ($23|0)==($20|0);
   if ($25) {
    break;
   } else {
    $$012$i$i = $23;$$03$i$i = $24;
   }
  }
  $26 = $uglygep6$i$i >>> 2;
  $27 = (($26) + 1)|0;
  $scevgep7$i$i = (($6) + ($27<<2)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if (!($__growing$0$off0)) {
  $38 = ($13|0)==($$0$lcssa$i$i|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($13) + -4|0);
  $39 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($39)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $40 = $uglygep3$i$i >>> 2;
  $41 = $40 ^ -1;
  $scevgep4$i$i = (($13) + ($41<<2)|0);
  HEAP32[$12>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $28 = ($20|0)==($__last|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $__first3$i1 = $20;
 $scevgep$i3 = (($__last) + -4|0);
 $29 = (0 - ($__first3$i1))|0;
 $uglygep$i5 = (($scevgep$i3) + ($29)|0);
 $uglygep4$i6 = $uglygep$i5;
 $30 = $uglygep4$i6 >>> 2;
 $$01$i8 = $20;$32 = $13;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   $33 = HEAP32[$$01$i8>>2]|0;
   HEAP32[$32>>2] = $33;
  }
  $34 = (($32) + 4|0);
  $35 = (($$01$i8) + 4|0);
  $36 = ($35|0)==($__last|0);
  if ($36) {
   break;
  } else {
   $$01$i8 = $35;$32 = $34;
  }
 }
 $37 = (($30) + 1)|0;
 $scevgep5$i10 = (($13) + ($37<<2)|0);
 HEAP32[$12>>2] = $scevgep5$i10;
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre3 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZN5Unity8Material8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $2 = (($this) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 192|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 $$pre = (($transfer) + 12|0);
 $$pre3 = (($transfer) + 28|0);
 $$pre5 = (($transfer) + 32|0);
 if (!($6)) {
  $8 = $3;
  while(1) {
   $7 = HEAP32[$8>>2]|0;
   $9 = HEAP32[$$pre>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$$pre3>>2]|0;
   $13 = (FUNCTION_TABLE_iiii[$11 & 2047]($9,$7,$12)|0);
   $14 = HEAP8[$$pre5>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if (!($15)) {
    HEAP32[$8>>2] = $13;
   }
   $16 = (($8) + 4|0);
   $17 = ($16|0)==($5|0);
   if ($17) {
    break;
   } else {
    $8 = $16;
   }
  }
 }
 $18 = (($this) + 260|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & -65537;
 HEAP32[$18>>2] = $20;
 $21 = (($this) + 152|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$$pre>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$$pre3>>2]|0;
 $27 = (FUNCTION_TABLE_iiii[$25 & 2047]($23,$22,$26)|0);
 $28 = HEAP8[$$pre5>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  HEAP32[$21>>2] = $27;
 }
 $30 = (($this) + 212|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 216|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($31|0)==($33|0);
 if (!($34)) {
  $36 = $31;
  while(1) {
   $35 = (($36) + 56|0);
   $37 = HEAP32[$35>>2]|0;
   $38 = HEAP32[$$pre>>2]|0;
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$$pre3>>2]|0;
   $42 = (FUNCTION_TABLE_iiii[$40 & 2047]($38,$37,$41)|0);
   $43 = HEAP8[$$pre5>>0]|0;
   $44 = ($43<<24>>24)==(0);
   if (!($44)) {
    HEAP32[$35>>2] = $42;
   }
   $45 = (($36) + 128|0);
   $46 = ($45|0)==($33|0);
   if ($46) {
    break;
   } else {
    $36 = $45;
   }
  }
 }
 $47 = (($this) + 164|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48 & 1;
 $50 = ($49<<24>>24)==(0);
 if ($50) {
  $53 = $48&255;
  $54 = $53 >>> 1;
  $56 = $54;
 } else {
  $51 = (($this) + 168|0);
  $52 = HEAP32[$51>>2]|0;
  $56 = $52;
 }
 $55 = ($56|0)==(0);
 if (!($55)) {
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$this>>2]|0;
 $58 = (($57) + 32|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (FUNCTION_TABLE_ii[$59 & 4095]($this)|0);
 $61 = (_strlen(($60|0))|0);
 $62 = ($61>>>0)>(2147483631);
 if ($62) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $63 = ($61>>>0)<(11);
 if ($63) {
  $64 = $61 << 1;
  $65 = $64&255;
  HEAP8[$1>>0] = $65;
  $66 = (($1) + 1|0);
  $__p$0$i$i$i$i = $66;
 } else {
  $67 = (($61) + 16)|0;
  $68 = $67 & -16;
  HEAP32[$0>>2] = 59;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $69 = (__Z15malloc_internaljj10MemLabelIdiPKci($68,16,$$byval_copy2,0,611088,79)|0);
  $70 = (($1) + 8|0);
  HEAP32[$70>>2] = $69;
  $71 = $68 | 1;
  HEAP32[$1>>2] = $71;
  $72 = (($1) + 4|0);
  HEAP32[$72>>2] = $61;
  $__p$0$i$i$i$i = $69;
 }
 _memcpy(($__p$0$i$i$i$i|0),($60|0),($61|0))|0;
 $73 = (($__p$0$i$i$i$i) + ($61)|0);
 HEAP8[$73>>0] = 0;
 __THREW__ = 0;
 (invoke_iii(2359,($47|0),($1|0))|0);
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if ($75) {
  $85 = ___cxa_find_matching_catch()|0;
  $86 = tempRet0;
  $87 = HEAP8[$1>>0]|0;
  $88 = $87 & 1;
  $89 = ($88<<24>>24)==(0);
  if ($89) {
   ___resumeException($85|0);
   // unreachable;
  }
  $90 = (($1) + 8|0);
  $91 = HEAP32[$90>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($91|0),($$byval_copy2|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   $94 = ___cxa_find_matching_catch()|0;
   $95 = tempRet0;
   ___cxa_call_unexpected(($94|0));
   // unreachable;
  } else {
   ___resumeException($85|0);
   // unreachable;
  }
 } else {
  $76 = HEAP8[$1>>0]|0;
  $77 = $76 & 1;
  $78 = ($77<<24>>24)==(0);
  if ($78) {
   STACKTOP = sp;return;
  }
  $79 = (($1) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($80|0),($$byval_copy2|0));
  $81 = __THREW__; __THREW__ = 0;
  $82 = $81&1;
  if ($82) {
   $83 = ___cxa_find_matching_catch()|0;
   $84 = tempRet0;
   ___cxa_call_unexpected(($83|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZN18ProceduralMaterial8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZN5Unity8Material8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $2 = (($this) + 176|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = HEAP32[$2>>2]|0;
  HEAP32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre8 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre8;
 }
 $10 = (($this) + 180|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)<($14>>>0);
 if ($13) {
  $15 = HEAP32[$10>>2]|0;
  HEAP32[$12>>2] = $15;
  HEAP32[$3>>2] = $11;
  $18 = $11;$20 = $14;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$10,4);
  $$pre9 = HEAP32[$3>>2]|0;
  $$pre10 = HEAP32[$6>>2]|0;
  $18 = $$pre9;$20 = $$pre10;
 }
 $16 = (($this) + 184|0);
 $17 = (($18) + 1|0);
 $19 = ($17>>>0)<($20>>>0);
 if ($19) {
  $21 = HEAP8[$16>>0]|0;
  HEAP8[$18>>0] = $21;
  $22 = HEAP32[$3>>2]|0;
  $23 = (($22) + 1|0);
  HEAP32[$3>>2] = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$16,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $24 = (($this) + 192|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 188|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $25;
 $29 = $27;
 $30 = (($28) - ($29))|0;
 $31 = $30 >> 2;
 HEAP32[$$byval_copy2>>2] = $31;
 $32 = HEAP32[$3>>2]|0;
 $33 = (($32) + 4|0);
 $34 = HEAP32[$6>>2]|0;
 $35 = ($33>>>0)<($34>>>0);
 if ($35) {
  HEAP32[$32>>2] = $31;
  HEAP32[$3>>2] = $33;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy2,4);
 }
 $36 = HEAP32[$24>>2]|0;
 $37 = HEAP32[$26>>2]|0;
 $38 = ($37|0)==($36|0);
 if (!($38)) {
  $39 = $37;
  while(1) {
   __ZN4PPtrI17ProceduralTextureE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($39,$transfer);
   $40 = (($39) + 4|0);
   $41 = ($40|0)==($36|0);
   if ($41) {
    break;
   } else {
    $39 = $40;
   }
  }
 }
 $42 = (($this) + 260|0);
 $43 = HEAP32[$3>>2]|0;
 $44 = (($43) + 4|0);
 $45 = HEAP32[$6>>2]|0;
 $46 = ($44>>>0)<($45>>>0);
 if ($46) {
  $47 = HEAP32[$42>>2]|0;
  HEAP32[$43>>2] = $47;
  HEAP32[$3>>2] = $44;
  $52 = $44;$54 = $45;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$42,4);
  $$pre11 = HEAP32[$3>>2]|0;
  $$pre12 = HEAP32[$6>>2]|0;
  $52 = $$pre11;$54 = $$pre12;
 }
 $48 = HEAP32[$42>>2]|0;
 $49 = $48 & -65537;
 HEAP32[$42>>2] = $49;
 $50 = (($this) + 264|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)<($54>>>0);
 if ($53) {
  $55 = HEAP32[$50>>2]|0;
  HEAP32[$52>>2] = $55;
  HEAP32[$3>>2] = $51;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$50,4);
 }
 $56 = (($this) + 152|0);
 __ZN4PPtrI16SubstanceArchiveE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($56,$transfer);
 $57 = (($this) + 216|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 212|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $58;
 $62 = $60;
 $63 = (($61) - ($62))|0;
 $64 = $63 >> 7;
 HEAP32[$$byval_copy2>>2] = $64;
 $65 = HEAP32[$3>>2]|0;
 $66 = (($65) + 4|0);
 $67 = HEAP32[$6>>2]|0;
 $68 = ($66>>>0)<($67>>>0);
 if ($68) {
  HEAP32[$65>>2] = $64;
  HEAP32[$3>>2] = $66;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy2,4);
 }
 $69 = HEAP32[$57>>2]|0;
 $70 = HEAP32[$59>>2]|0;
 $71 = ($70|0)==($69|0);
 if (!($71)) {
  $72 = $70;
  while(1) {
   __ZN14SubstanceInput8TransferI19StreamedBinaryWriteILb0EEEEvRT_($72,$transfer);
   $73 = (($72) + 128|0);
   $74 = ($73|0)==($69|0);
   if ($74) {
    break;
   } else {
    $72 = $73;
   }
  }
 }
 $75 = (($this) + 164|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$75,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $76 = HEAP8[$75>>0]|0;
 $77 = $76 & 1;
 $78 = ($77<<24>>24)==(0);
 if ($78) {
  $81 = $76&255;
  $82 = $81 >>> 1;
  $84 = $82;
 } else {
  $79 = (($this) + 168|0);
  $80 = HEAP32[$79>>2]|0;
  $84 = $80;
 }
 $83 = ($84|0)==(0);
 do {
  if ($83) {
   $85 = HEAP32[$this>>2]|0;
   $86 = (($85) + 32|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (FUNCTION_TABLE_ii[$87 & 4095]($this)|0);
   $89 = (_strlen(($88|0))|0);
   $90 = ($89>>>0)>(2147483631);
   if ($90) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $91 = ($89>>>0)<(11);
   if ($91) {
    $92 = $89 << 1;
    $93 = $92&255;
    HEAP8[$1>>0] = $93;
    $94 = (($1) + 1|0);
    $__p$0$i$i$i$i = $94;
   } else {
    $95 = (($89) + 16)|0;
    $96 = $95 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $97 = (__Z15malloc_internaljj10MemLabelIdiPKci($96,16,$$byval_copy2,0,611088,79)|0);
    $98 = (($1) + 8|0);
    HEAP32[$98>>2] = $97;
    $99 = $96 | 1;
    HEAP32[$1>>2] = $99;
    $100 = (($1) + 4|0);
    HEAP32[$100>>2] = $89;
    $__p$0$i$i$i$i = $97;
   }
   _memcpy(($__p$0$i$i$i$i|0),($88|0),($89|0))|0;
   $101 = (($__p$0$i$i$i$i) + ($89)|0);
   HEAP8[$101>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($75|0),($1|0))|0);
   $102 = __THREW__; __THREW__ = 0;
   $103 = $102&1;
   if (!($103)) {
    $104 = HEAP8[$1>>0]|0;
    $105 = $104 & 1;
    $106 = ($105<<24>>24)==(0);
    if ($106) {
     break;
    }
    $107 = (($1) + 8|0);
    $108 = HEAP32[$107>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($108|0),($$byval_copy2|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if (!($110)) {
     break;
    }
    $111 = ___cxa_find_matching_catch()|0;
    $112 = tempRet0;
    ___cxa_call_unexpected(($111|0));
    // unreachable;
   }
   $113 = ___cxa_find_matching_catch()|0;
   $114 = tempRet0;
   $115 = HEAP8[$1>>0]|0;
   $116 = $115 & 1;
   $117 = ($116<<24>>24)==(0);
   if ($117) {
    ___resumeException($113|0);
    // unreachable;
   }
   $118 = (($1) + 8|0);
   $119 = HEAP32[$118>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($119|0),($$byval_copy2|0));
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    ___cxa_call_unexpected(($122|0));
    // unreachable;
   } else {
    ___resumeException($113|0);
    // unreachable;
   }
  }
 } while(0);
 $124 = (($this) + 252|0);
 $125 = HEAP32[$3>>2]|0;
 $126 = (($125) + 4|0);
 $127 = HEAP32[$6>>2]|0;
 $128 = ($126>>>0)<($127>>>0);
 if ($128) {
  $129 = HEAP32[$124>>2]|0;
  HEAP32[$125>>2] = $129;
  HEAP32[$3>>2] = $126;
  $130 = (($this) + 224|0);
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($130,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$124,4);
  $130 = (($this) + 224|0);
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($130,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN14SubstanceInput8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $size$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i6 = sp;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $1 = (($this) + 24|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $2 = (($this) + 36|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = HEAP32[$2>>2]|0;
  HEAP32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
 }
 $10 = (($this) + 40|0);
 __ZN14SubstanceValue8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 60|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$6>>2]|0;
 $15 = ($13>>>0)<($14>>>0);
 if ($15) {
  $16 = HEAP32[$11>>2]|0;
  HEAP32[$12>>2] = $16;
  HEAP32[$3>>2] = $13;
  $19 = $13;$21 = $14;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$11,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre10 = HEAP32[$6>>2]|0;
  $19 = $$pre;$21 = $$pre10;
 }
 $17 = (($this) + 64|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)<($21>>>0);
 if ($20) {
  $22 = HEAP32[$17>>2]|0;
  HEAP32[$19>>2] = $22;
  HEAP32[$3>>2] = $18;
  $25 = $18;$27 = $21;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$17,4);
  $$pre11 = HEAP32[$3>>2]|0;
  $$pre12 = HEAP32[$6>>2]|0;
  $25 = $$pre11;$27 = $$pre12;
 }
 $23 = (($this) + 68|0);
 $24 = (($25) + 4|0);
 $26 = ($24>>>0)<($27>>>0);
 if ($26) {
  $28 = HEAP32[$23>>2]|0;
  HEAP32[$25>>2] = $28;
  HEAP32[$3>>2] = $24;
  $38 = $24;$40 = $27;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$23,4);
  $$pre13 = HEAP32[$3>>2]|0;
  $$pre14 = HEAP32[$6>>2]|0;
  $38 = $$pre13;$40 = $$pre14;
 }
 $29 = (($this) + 80|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 76|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $30;
 $34 = $32;
 $35 = (($33) - ($34))|0;
 $36 = (($35|0) / 12)&-1;
 HEAP32[$size$i$i$i6>>2] = $36;
 $37 = (($38) + 4|0);
 $39 = ($37>>>0)<($40>>>0);
 if ($39) {
  HEAP32[$38>>2] = $36;
  HEAP32[$3>>2] = $37;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size$i$i$i6,4);
 }
 $41 = HEAP32[$29>>2]|0;
 $42 = HEAP32[$31>>2]|0;
 $43 = ($42|0)==($41|0);
 if (!($43)) {
  $44 = $42;
  while(1) {
   __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$44,0);
   __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
   $45 = (($44) + 12|0);
   $46 = ($45|0)==($41|0);
   if ($46) {
    break;
   } else {
    $44 = $45;
   }
  }
 }
 $47 = (($this) + 88|0);
 $48 = HEAP32[$3>>2]|0;
 $49 = (($48) + 4|0);
 $50 = HEAP32[$6>>2]|0;
 $51 = ($49>>>0)<($50>>>0);
 if ($51) {
  $52 = Math_fround(HEAPF32[$47>>2]);
  HEAPF32[$48>>2] = $52;
  HEAP32[$3>>2] = $49;
  $55 = $49;$57 = $50;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$47,4);
  $$pre15 = HEAP32[$3>>2]|0;
  $$pre16 = HEAP32[$6>>2]|0;
  $55 = $$pre15;$57 = $$pre16;
 }
 $53 = (($this) + 92|0);
 $54 = (($55) + 4|0);
 $56 = ($54>>>0)<($57>>>0);
 if ($56) {
  $58 = Math_fround(HEAPF32[$53>>2]);
  HEAPF32[$55>>2] = $58;
  HEAP32[$3>>2] = $54;
  $61 = $54;$63 = $57;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$53,4);
  $$pre17 = HEAP32[$3>>2]|0;
  $$pre18 = HEAP32[$6>>2]|0;
  $61 = $$pre17;$63 = $$pre18;
 }
 $59 = (($this) + 96|0);
 $60 = (($61) + 4|0);
 $62 = ($60>>>0)<($63>>>0);
 if ($62) {
  $64 = Math_fround(HEAPF32[$59>>2]);
  HEAPF32[$61>>2] = $64;
  HEAP32[$3>>2] = $60;
  $67 = $60;$69 = $63;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$59,4);
  $$pre19 = HEAP32[$3>>2]|0;
  $$pre20 = HEAP32[$6>>2]|0;
  $67 = $$pre19;$69 = $$pre20;
 }
 $65 = (($this) + 112|0);
 $66 = (($67) + 4|0);
 $68 = ($66>>>0)<($69>>>0);
 if ($68) {
  $70 = HEAP32[$65>>2]|0;
  HEAP32[$67>>2] = $70;
  HEAP32[$3>>2] = $66;
  $74 = $66;$76 = $69;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$65,4);
  $$pre21 = HEAP32[$3>>2]|0;
  $$pre22 = HEAP32[$6>>2]|0;
  $74 = $$pre21;$76 = $$pre22;
 }
 $71 = (($this) + 124|0);
 $72 = HEAP32[$71>>2]|0;
 HEAP32[$size$i$i$i6>>2] = $72;
 $73 = (($74) + 4|0);
 $75 = ($73>>>0)<($76>>>0);
 if ($75) {
  HEAP32[$74>>2] = $72;
  HEAP32[$3>>2] = $73;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size$i$i$i6,4);
 }
 $77 = (($this) + 120|0);
 $78 = (($this) + 116|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($79|0)==($77|0);
 if ($80) {
  $98 = (($this) + 100|0);
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$98,0);
  STACKTOP = sp;return;
 }
 $82 = $79;
 while(1) {
  $81 = (($82) + 16|0);
  $83 = HEAP32[$3>>2]|0;
  $84 = (($83) + 4|0);
  $85 = HEAP32[$6>>2]|0;
  $86 = ($84>>>0)<($85>>>0);
  if ($86) {
   $87 = HEAP32[$81>>2]|0;
   HEAP32[$83>>2] = $87;
   HEAP32[$3>>2] = $84;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$81,4);
  }
  $88 = (($82) + 4|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==(0|0);
  if ($90) {
   $$01$i$i$i$i$i = $82;
   while(1) {
    $93 = (($$01$i$i$i$i$i) + 8|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==($$01$i$i$i$i$i|0);
    if ($96) {
     $$0$i$i$i$i$i = $94;
     break;
    } else {
     $$01$i$i$i$i$i = $94;
    }
   }
  } else {
   $$0$i$i$i$i$i$i = $89;
   while(1) {
    $91 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
    $92 = ($91|0)==(0|0);
    if ($92) {
     $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i$i = $91;
    }
   }
  }
  $97 = ($$0$i$i$i$i$i|0)==($77|0);
  if ($97) {
   break;
  }
  $82 = $$0$i$i$i$i$i;
 }
 $98 = (($this) + 100|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$98,0);
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$data>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 HEAP32[$size>>2] = $7;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size,4);
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$data>>2]|0;
 $16 = ($15|0)==($14|0);
 if ($16) {
  STACKTOP = sp;return;
 } else {
  $22 = $15;
 }
 while(1) {
  $17 = HEAP32[$8>>2]|0;
  $18 = (($17) + 4|0);
  $19 = HEAP32[$11>>2]|0;
  $20 = ($18>>>0)<($19>>>0);
  if ($20) {
   $21 = HEAP32[$22>>2]|0;
   HEAP32[$17>>2] = $21;
   HEAP32[$8>>2] = $18;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$22,4);
  }
  $23 = (($22) + 4|0);
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$23,0);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($this);
  $24 = (($22) + 16|0);
  $25 = ($24|0)==($14|0);
  if ($25) {
   break;
  } else {
   $22 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14SubstanceValue8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (($this) + 16|0);
  __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($25,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $25 = (($this) + 16|0);
  __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($25,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI16SubstanceArchiveE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI17ProceduralTextureE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN18ProceduralMaterial8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre$i$i$i7 = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZN5Unity8Material8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $2 = (($this) + 176|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre9 = HEAP32[$6>>2]|0;
  $10 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre9;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;$14 = $5;$16 = $7;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$2>>2] = $11;
 $12 = (($this) + 180|0);
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$12,4);
  $$pre$i$i$i1 = HEAP32[$12>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $$pre11 = HEAP32[$6>>2]|0;
  $18 = $$pre$i$i$i1;$22 = $$pre10;$24 = $$pre11;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$3>>2] = $13;
  $18 = $17;$22 = $13;$24 = $16;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$12>>2] = $19;
 $20 = (($this) + 184|0);
 $21 = (($22) + 1|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$20,1);
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$3>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$3>>2] = $27;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $28 = (($this) + 188|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI17ProceduralTextureENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($transfer,$28,0);
 $29 = (($this) + 260|0);
 $30 = HEAP32[$3>>2]|0;
 $31 = (($30) + 4|0);
 $32 = HEAP32[$6>>2]|0;
 $33 = ($31>>>0)>($32>>>0);
 if ($33) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$29,4);
  $$pre$i$i$i5 = HEAP32[$29>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $$pre13 = HEAP32[$6>>2]|0;
  $35 = $$pre$i$i$i5;$41 = $$pre12;$43 = $$pre13;
 } else {
  $34 = HEAP32[$30>>2]|0;
  HEAP32[$29>>2] = $34;
  HEAP32[$3>>2] = $31;
  $35 = $34;$41 = $31;$43 = $32;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 $37 = $36 & 1;
 $38 = (($this) + 264|0);
 HEAP32[$38>>2] = $37;
 $39 = $36 & -65538;
 HEAP32[$29>>2] = $39;
 $40 = (($41) + 4|0);
 $42 = ($40>>>0)>($43>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$38,4);
  $$pre$i$i$i7 = HEAP32[$38>>2]|0;
  $45 = $$pre$i$i$i7;
 } else {
  $44 = HEAP32[$41>>2]|0;
  HEAP32[$38>>2] = $44;
  HEAP32[$3>>2] = $40;
  $45 = $44;
 }
 $46 = (_llvm_bswap_i32(($45|0))|0);
 HEAP32[$38>>2] = $46;
 $47 = (($this) + 152|0);
 __ZN4PPtrI16SubstanceArchiveE8TransferI18StreamedBinaryReadILb1EEEEvRT_($47,$transfer);
 $48 = (($this) + 212|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14SubstanceInputNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$48,0);
 $49 = (($this) + 164|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$49,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $50 = HEAP8[$49>>0]|0;
 $51 = $50 & 1;
 $52 = ($51<<24>>24)==(0);
 if ($52) {
  $55 = $50&255;
  $56 = $55 >>> 1;
  $58 = $56;
 } else {
  $53 = (($this) + 168|0);
  $54 = HEAP32[$53>>2]|0;
  $58 = $54;
 }
 $57 = ($58|0)==(0);
 do {
  if ($57) {
   $59 = HEAP32[$this>>2]|0;
   $60 = (($59) + 32|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (FUNCTION_TABLE_ii[$61 & 4095]($this)|0);
   $63 = (_strlen(($62|0))|0);
   $64 = ($63>>>0)>(2147483631);
   if ($64) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $65 = ($63>>>0)<(11);
   if ($65) {
    $66 = $63 << 1;
    $67 = $66&255;
    HEAP8[$1>>0] = $67;
    $68 = (($1) + 1|0);
    $__p$0$i$i$i$i = $68;
   } else {
    $69 = (($63) + 16)|0;
    $70 = $69 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $71 = (__Z15malloc_internaljj10MemLabelIdiPKci($70,16,$$byval_copy2,0,611088,79)|0);
    $72 = (($1) + 8|0);
    HEAP32[$72>>2] = $71;
    $73 = $70 | 1;
    HEAP32[$1>>2] = $73;
    $74 = (($1) + 4|0);
    HEAP32[$74>>2] = $63;
    $__p$0$i$i$i$i = $71;
   }
   _memcpy(($__p$0$i$i$i$i|0),($62|0),($63|0))|0;
   $75 = (($__p$0$i$i$i$i) + ($63)|0);
   HEAP8[$75>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($49|0),($1|0))|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    $78 = HEAP8[$1>>0]|0;
    $79 = $78 & 1;
    $80 = ($79<<24>>24)==(0);
    if ($80) {
     break;
    }
    $81 = (($1) + 8|0);
    $82 = HEAP32[$81>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($82|0),($$byval_copy2|0));
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if (!($84)) {
     break;
    }
    $85 = ___cxa_find_matching_catch()|0;
    $86 = tempRet0;
    ___cxa_call_unexpected(($85|0));
    // unreachable;
   }
   $87 = ___cxa_find_matching_catch()|0;
   $88 = tempRet0;
   $89 = HEAP8[$1>>0]|0;
   $90 = $89 & 1;
   $91 = ($90<<24>>24)==(0);
   if ($91) {
    ___resumeException($87|0);
    // unreachable;
   }
   $92 = (($1) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($93|0),($$byval_copy2|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    $96 = ___cxa_find_matching_catch()|0;
    $97 = tempRet0;
    ___cxa_call_unexpected(($96|0));
    // unreachable;
   } else {
    ___resumeException($87|0);
    // unreachable;
   }
  }
 } while(0);
 $98 = (($this) + 252|0);
 $99 = HEAP32[$3>>2]|0;
 $100 = (($99) + 4|0);
 $101 = HEAP32[$6>>2]|0;
 $102 = ($100>>>0)>($101>>>0);
 if ($102) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$98,4);
  $$pre$i$i$i3 = HEAP32[$98>>2]|0;
  $104 = $$pre$i$i$i3;
  $105 = (_llvm_bswap_i32(($104|0))|0);
  HEAP32[$98>>2] = $105;
  $106 = (($this) + 224|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($106,$transfer);
  STACKTOP = sp;return;
 } else {
  $103 = HEAP32[$99>>2]|0;
  HEAP32[$98>>2] = $103;
  HEAP32[$3>>2] = $100;
  $104 = $103;
  $105 = (_llvm_bswap_i32(($104|0))|0);
  HEAP32[$98>>2] = $105;
  $106 = (($this) + 224|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($106,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14SubstanceInputNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI14SubstanceInputNS0_9allocatorIS2_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN14SubstanceInput8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 128|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 7;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14SubstanceInput8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i17 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i6 = 0, $$pre$i$i$i9 = 0, $$pre$phi$i$i$i10Z2D = 0, $$pre$phi$i$i$i15Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0;
 var $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $1 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $2 = (($this) + 36|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $10 = $$pre$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$2>>2] = $11;
 $12 = (($this) + 40|0);
 __ZN14SubstanceValue8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$transfer);
 $13 = (($this) + 60|0);
 $14 = HEAP32[$3>>2]|0;
 $15 = (($14) + 4|0);
 $16 = HEAP32[$6>>2]|0;
 $17 = ($15>>>0)>($16>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$13,4);
  $$pre$i$i$i1 = HEAP32[$13>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre19 = HEAP32[$6>>2]|0;
  $19 = $$pre$i$i$i1;$23 = $$pre;$25 = $$pre19;
 } else {
  $18 = HEAP32[$14>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$3>>2] = $15;
  $19 = $18;$23 = $15;$25 = $16;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$13>>2] = $20;
 $21 = (($this) + 64|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$21,4);
  $$pre$i$i$i3 = HEAP32[$21>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $$pre21 = HEAP32[$6>>2]|0;
  $27 = $$pre$i$i$i3;$31 = $$pre20;$33 = $$pre21;
 } else {
  $26 = HEAP32[$23>>2]|0;
  HEAP32[$21>>2] = $26;
  HEAP32[$3>>2] = $22;
  $27 = $26;$31 = $22;$33 = $25;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$21>>2] = $28;
 $29 = (($this) + 68|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$29,4);
  $$pre$i$i$i4 = HEAP32[$29>>2]|0;
  $35 = $$pre$i$i$i4;
 } else {
  $34 = HEAP32[$31>>2]|0;
  HEAP32[$29>>2] = $34;
  HEAP32[$3>>2] = $30;
  $35 = $34;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$29>>2] = $36;
 $37 = (($this) + 76|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$37,0);
 $38 = (($this) + 88|0);
 $39 = HEAP32[$3>>2]|0;
 $40 = (($39) + 4|0);
 $41 = HEAP32[$6>>2]|0;
 $42 = ($40>>>0)>($41>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$38,4);
  $$pre$i$i$i6 = HEAP32[$38>>2]|0;
  $$pre22 = HEAP32[$3>>2]|0;
  $$pre23 = HEAP32[$6>>2]|0;
  $$pre$phi$i$i$iZ2D = $38;$45 = $$pre$i$i$i6;$49 = $$pre22;$51 = $$pre23;
 } else {
  $43 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$38>>2] = $43;
  HEAP32[$3>>2] = $40;
  $44 = (HEAPF32[tempDoublePtr>>2]=$43,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $38;$45 = $44;$49 = $40;$51 = $41;
 }
 $46 = (_llvm_bswap_i32(($45|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $46;
 $47 = (($this) + 92|0);
 $48 = (($49) + 4|0);
 $50 = ($48>>>0)>($51>>>0);
 if ($50) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$47,4);
  $$pre$i$i$i9 = HEAP32[$47>>2]|0;
  $$pre24 = HEAP32[$3>>2]|0;
  $$pre25 = HEAP32[$6>>2]|0;
  $$pre$phi$i$i$i10Z2D = $47;$54 = $$pre$i$i$i9;$58 = $$pre24;$60 = $$pre25;
 } else {
  $52 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$47>>2] = $52;
  HEAP32[$3>>2] = $48;
  $53 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i10Z2D = $47;$54 = $53;$58 = $48;$60 = $51;
 }
 $55 = (_llvm_bswap_i32(($54|0))|0);
 HEAP32[$$pre$phi$i$i$i10Z2D>>2] = $55;
 $56 = (($this) + 96|0);
 $57 = (($58) + 4|0);
 $59 = ($57>>>0)>($60>>>0);
 if ($59) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$56,4);
  $$pre$i$i$i14 = HEAP32[$56>>2]|0;
  $$pre26 = HEAP32[$3>>2]|0;
  $$pre27 = HEAP32[$6>>2]|0;
  $$pre$phi$i$i$i15Z2D = $56;$63 = $$pre$i$i$i14;$67 = $$pre26;$69 = $$pre27;
 } else {
  $61 = Math_fround(HEAPF32[$58>>2]);
  HEAPF32[$56>>2] = $61;
  HEAP32[$3>>2] = $57;
  $62 = (HEAPF32[tempDoublePtr>>2]=$61,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i15Z2D = $56;$63 = $62;$67 = $57;$69 = $60;
 }
 $64 = (_llvm_bswap_i32(($63|0))|0);
 HEAP32[$$pre$phi$i$i$i15Z2D>>2] = $64;
 $65 = (($this) + 112|0);
 $66 = (($67) + 4|0);
 $68 = ($66>>>0)>($69>>>0);
 if ($68) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$65,4);
  $$pre$i$i$i17 = HEAP32[$65>>2]|0;
  $71 = $$pre$i$i$i17;
  $72 = (_llvm_bswap_i32(($71|0))|0);
  HEAP32[$65>>2] = $72;
  $73 = (($this) + 116|0);
  __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13setIjNS2_4lessIjEENS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$73,0);
  $74 = (($this) + 100|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$74,0);
  $75 = HEAP32[$65>>2]|0;
  $76 = $75 & -13;
  $77 = $76 | 8;
  HEAP32[$65>>2] = $77;
  STACKTOP = sp;return;
 } else {
  $70 = HEAP32[$67>>2]|0;
  HEAP32[$65>>2] = $70;
  HEAP32[$3>>2] = $66;
  $71 = $70;
  $72 = (_llvm_bswap_i32(($71|0))|0);
  HEAP32[$65>>2] = $72;
  $73 = (($this) + 116|0);
  __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13setIjNS2_4lessIjEENS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$73,0);
  $74 = (($this) + 100|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$74,0);
  $75 = HEAP32[$65>>2]|0;
  $76 = $75 & -13;
  $77 = $76 | 8;
  HEAP32[$65>>2] = $77;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i3;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorI17SubstanceEnumItemNS0_9allocatorIS2_EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
   $$pre$i$i$i$i$i$i = HEAP32[$34>>2]|0;
   $35 = $$pre$i$i$i$i$i$i;
  } else {
   $33 = HEAP32[$29>>2]|0;
   HEAP32[$34>>2] = $33;
   HEAP32[$1>>2] = $30;
   $35 = $33;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$34>>2] = $36;
  $37 = (($34) + 4|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$37,0);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
  $38 = (($34) + 16|0);
  $39 = ($38|0)==($26|0);
  if ($39) {
   break;
  } else {
   $34 = $38;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI17SubstanceEnumItemNS0_9allocatorIS2_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy5 = 0, $$byval_copy8 = 0, $$idx = 0, $$pre = 0, $$pre$i$i$i$i$i16 = 0, $$pre$i$i$i$i$i8 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i5 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $temp = 0, $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 44|0;
 $$byval_copy5 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $temp = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $temp1 = sp + 32|0;
 $4 = (($v) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$v>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $98 = ($10>>>0)>($sz>>>0);
  if (!($98)) {
   STACKTOP = sp;return;
  }
  $99 = (($6) + ($sz<<4)|0);
  HEAP32[$temp1>>2] = 0;
  $100 = (($temp1) + 4|0);
  HEAP32[$100>>2] = 0;
  $101 = (($temp1) + 8|0);
  HEAP32[$101>>2] = 0;
  $$idx = $sz << 4;
  $102 = $$idx >> 4;
  $103 = ($102|0)==(0);
  do {
   if ($103) {
    $132 = $6;$133 = 0;$134 = $5;$135 = 0;$138 = 0;
   } else {
    $104 = ($102>>>0)>(268435455);
    if ($104) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if (!($106)) {
      // unreachable;
     }
    } else {
     __THREW__ = 0;
     $107 = (invoke_ii(2988,($$idx|0))|0);
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if (!($109)) {
      HEAP32[$100>>2] = $107;
      HEAP32[$temp1>>2] = $107;
      $110 = (($107) + ($102<<4)|0);
      HEAP32[$101>>2] = $110;
      HEAP32[$0>>2] = $6;
      HEAP32[$1>>2] = $99;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_viii(1755,($temp1|0),($$byval_copy5|0),($$byval_copy8|0));
      $111 = __THREW__; __THREW__ = 0;
      $112 = $111&1;
      if (!($112)) {
       $$pre36 = HEAP32[$temp1>>2]|0;
       $$pre37 = HEAP32[$v>>2]|0;
       $$pre38 = HEAP32[$100>>2]|0;
       $$pre39 = HEAP32[$4>>2]|0;
       $$pre40 = HEAP32[$101>>2]|0;
       $132 = $$pre37;$133 = $$pre36;$134 = $$pre39;$135 = $$pre38;$138 = $$pre40;
       break;
      }
     }
    }
    $113 = ___cxa_find_matching_catch()|0;
    $114 = tempRet0;
    $115 = HEAP32[$temp1>>2]|0;
    $116 = ($115|0)==(0|0);
    if ($116) {
     ___resumeException($113|0);
     // unreachable;
    }
    $117 = HEAP32[$100>>2]|0;
    $118 = ($117|0)==($115|0);
    L18: do {
     if (!($118)) {
      $120 = $117;
      while(1) {
       $119 = (($120) + -16|0);
       HEAP32[$100>>2] = $119;
       $121 = (($120) + -12|0);
       $122 = HEAP8[$121>>0]|0;
       $123 = $122 & 1;
       $124 = ($123<<24>>24)==(0);
       if (!($124)) {
        $126 = (($120) + -4|0);
        $127 = HEAP32[$126>>2]|0;
        HEAP32[$$byval_copy5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
        invoke_vii(2591,($127|0),($$byval_copy8|0));
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if ($129) {
         break;
        }
       }
       $125 = ($119|0)==($115|0);
       if ($125) {
        break L18;
       } else {
        $120 = $119;
       }
      }
      $130 = ___cxa_find_matching_catch()|0;
      $131 = tempRet0;
      ___cxa_call_unexpected(($130|0));
      // unreachable;
     }
    } while(0);
    __ZdlPv($115);
    ___resumeException($113|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$temp1>>2] = $132;
  HEAP32[$v>>2] = $133;
  HEAP32[$100>>2] = $134;
  HEAP32[$4>>2] = $135;
  $136 = (($v) + 8|0);
  $137 = HEAP32[$136>>2]|0;
  HEAP32[$101>>2] = $137;
  HEAP32[$136>>2] = $138;
  $139 = ($132|0)==(0|0);
  if ($139) {
   STACKTOP = sp;return;
  }
  $140 = ($134|0)==($132|0);
  L32: do {
   if (!($140)) {
    $142 = $134;
    while(1) {
     $141 = (($142) + -16|0);
     HEAP32[$100>>2] = $141;
     $143 = (($142) + -12|0);
     $144 = HEAP8[$143>>0]|0;
     $145 = $144 & 1;
     $146 = ($145<<24>>24)==(0);
     if (!($146)) {
      $148 = (($142) + -4|0);
      $149 = HEAP32[$148>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($149|0),($$byval_copy8|0));
      $150 = __THREW__; __THREW__ = 0;
      $151 = $150&1;
      if ($151) {
       break;
      }
     }
     $147 = ($141|0)==($132|0);
     if ($147) {
      break L32;
     } else {
      $142 = $141;
     }
    }
    $152 = ___cxa_find_matching_catch()|0;
    $153 = tempRet0;
    ___cxa_call_unexpected(($152|0));
    // unreachable;
   }
  } while(0);
  __ZdlPv($132);
  STACKTOP = sp;return;
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = $15 >> 4;
 $17 = ($16|0)==($sz|0);
 if ($17) {
  $97 = (($sz) - ($10))|0;
  __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE8__appendEj($v,$97);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $18 = (($temp) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($temp) + 8|0);
 HEAP32[$19>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2726,($temp|0),($sz|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L47: do {
  if (!($21)) {
   $22 = HEAP32[$v>>2]|0;
   HEAP32[$2>>2] = $22;
   $23 = HEAP32[$4>>2]|0;
   HEAP32[$3>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viii(1754,($temp|0),($$byval_copy5|0),($$byval_copy8|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$18>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = $30 >> 4;
    $32 = ($31>>>0)<($sz>>>0);
    L50: do {
     if ($32) {
      $33 = (($sz) - ($31))|0;
      __THREW__ = 0;
      invoke_vii(2727,($temp|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L47;
      }
      $$pre = HEAP32[$18>>2]|0;
      $56 = $$pre;
     } else {
      $36 = ($31>>>0)>($sz>>>0);
      if ($36) {
       $37 = (($27) + ($sz<<4)|0);
       $38 = ($26|0)==($37|0);
       if ($38) {
        $56 = $26;
       } else {
        $40 = $26;
        while(1) {
         $39 = (($40) + -16|0);
         HEAP32[$18>>2] = $39;
         $41 = (($40) + -12|0);
         $42 = HEAP8[$41>>0]|0;
         $43 = $42 & 1;
         $44 = ($43<<24>>24)==(0);
         if ($44) {
          $46 = $39;
         } else {
          $47 = (($40) + -4|0);
          $48 = HEAP32[$47>>2]|0;
          HEAP32[$0>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($48|0),($$byval_copy8|0));
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
          $$pre$i$i$i5 = HEAP32[$18>>2]|0;
          $46 = $$pre$i$i$i5;
         }
         $45 = ($46|0)==($37|0);
         if ($45) {
          $56 = $37;
          break L50;
         } else {
          $40 = $46;
         }
        }
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       }
      } else {
       $56 = $26;
      }
     }
    } while(0);
    $53 = HEAP32[$temp>>2]|0;
    $54 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $54;
    HEAP32[$v>>2] = $53;
    $55 = HEAP32[$4>>2]|0;
    HEAP32[$18>>2] = $55;
    HEAP32[$4>>2] = $56;
    $57 = HEAP32[$19>>2]|0;
    $58 = HEAP32[$12>>2]|0;
    HEAP32[$19>>2] = $58;
    HEAP32[$12>>2] = $57;
    $59 = ($54|0)==(0|0);
    if ($59) {
     STACKTOP = sp;return;
    }
    $60 = ($55|0)==($54|0);
    do {
     if ($60) {
      $75 = $54;
     } else {
      $62 = $55;
      while(1) {
       $61 = (($62) + -16|0);
       HEAP32[$18>>2] = $61;
       $63 = (($62) + -12|0);
       $64 = HEAP8[$63>>0]|0;
       $65 = $64 & 1;
       $66 = ($65<<24>>24)==(0);
       if ($66) {
        $68 = $61;
       } else {
        $69 = (($62) + -4|0);
        $70 = HEAP32[$69>>2]|0;
        HEAP32[$$byval_copy5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
        invoke_vii(2591,($70|0),($$byval_copy8|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 23;
         break;
        }
        $$pre$i$i$i$i$i8 = HEAP32[$18>>2]|0;
        $68 = $$pre$i$i$i$i$i8;
       }
       $67 = ($68|0)==($54|0);
       if ($67) {
        label = 24;
        break;
       } else {
        $62 = $68;
       }
      }
      if ((label|0) == 23) {
       $73 = ___cxa_find_matching_catch()|0;
       $74 = tempRet0;
       ___cxa_call_unexpected(($73|0));
       // unreachable;
      }
      else if ((label|0) == 24) {
       $$pre$i$i$i10 = HEAP32[$temp>>2]|0;
       $75 = $$pre$i$i$i10;
       break;
      }
     }
    } while(0);
    __ZdlPv($75);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $76 = ___cxa_find_matching_catch()|0;
 $77 = tempRet0;
 $78 = HEAP32[$temp>>2]|0;
 $79 = ($78|0)==(0|0);
 if ($79) {
  ___resumeException($76|0);
  // unreachable;
 }
 $80 = HEAP32[$18>>2]|0;
 $81 = ($80|0)==($78|0);
 do {
  if ($81) {
   $96 = $78;
  } else {
   $83 = $80;
   while(1) {
    $82 = (($83) + -16|0);
    HEAP32[$18>>2] = $82;
    $84 = (($83) + -12|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85 & 1;
    $87 = ($86<<24>>24)==(0);
    if ($87) {
     $89 = $82;
    } else {
     $90 = (($83) + -4|0);
     $91 = HEAP32[$90>>2]|0;
     HEAP32[$$byval_copy5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy5+0>>2]|0;
     invoke_vii(2591,($91|0),($$byval_copy8|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      label = 33;
      break;
     }
     $$pre$i$i$i$i$i16 = HEAP32[$18>>2]|0;
     $89 = $$pre$i$i$i$i$i16;
    }
    $88 = ($89|0)==($78|0);
    if ($88) {
     label = 34;
     break;
    } else {
     $83 = $89;
    }
   }
   if ((label|0) == 33) {
    $94 = ___cxa_find_matching_catch()|0;
    $95 = tempRet0;
    ___cxa_call_unexpected(($94|0));
    // unreachable;
   }
   else if ((label|0) == 34) {
    $$pre$i$i$i18 = HEAP32[$temp>>2]|0;
    $96 = $$pre$i$i$i18;
    break;
   }
  }
 } while(0);
 __ZdlPv($96);
 ___resumeException($76|0);
 // unreachable;
}
function __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 4;
 $15 = (($__v) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($__v) + 16|0);
 HEAP32[$16>>2] = $9;
 $17 = ($__n|0)==(0);
 if ($17) {
  $20 = 0;
 } else {
  $18 = $__n << 4;
  $19 = (__Znwj($18)|0);
  $20 = $19;
 }
 HEAP32[$__v>>2] = $20;
 $21 = (($20) + ($14<<4)|0);
 $22 = (($__v) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($__v) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = (($20) + ($__n<<4)|0);
 HEAP32[$15>>2] = $24;
 __THREW__ = 0;
 invoke_vii(2728,($this|0),($__v|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  $47 = HEAP32[$23>>2]|0;
  $48 = HEAP32[$22>>2]|0;
  $49 = ($48|0)==($47|0);
  L9: do {
   if (!($49)) {
    $51 = $48;
    while(1) {
     $50 = (($51) + -16|0);
     HEAP32[$22>>2] = $50;
     $52 = (($51) + -12|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = $53 & 1;
     $55 = ($54<<24>>24)==(0);
     if (!($55)) {
      $57 = (($51) + -4|0);
      $58 = HEAP32[$57>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($58|0),($$byval_copy1|0));
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
     }
     $56 = ($50|0)==($47|0);
     if ($56) {
      break L9;
     } else {
      $51 = $50;
     }
    }
    $61 = ___cxa_find_matching_catch()|0;
    $62 = tempRet0;
    ___cxa_call_unexpected(($61|0));
    // unreachable;
   }
  } while(0);
  $63 = HEAP32[$__v>>2]|0;
  $64 = ($63|0)==(0|0);
  if ($64) {
   ___resumeException($45|0);
   // unreachable;
  }
  __ZdlPv($63);
  ___resumeException($45|0);
  // unreachable;
 } else {
  $27 = HEAP32[$23>>2]|0;
  $28 = HEAP32[$22>>2]|0;
  $29 = ($28|0)==($27|0);
  L23: do {
   if (!($29)) {
    $31 = $28;
    while(1) {
     $30 = (($31) + -16|0);
     HEAP32[$22>>2] = $30;
     $32 = (($31) + -12|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if (!($35)) {
      $37 = (($31) + -4|0);
      $38 = HEAP32[$37>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($38|0),($$byval_copy1|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
     }
     $36 = ($30|0)==($27|0);
     if ($36) {
      break L23;
     } else {
      $31 = $30;
     }
    }
    $41 = ___cxa_find_matching_catch()|0;
    $42 = tempRet0;
    ___cxa_call_unexpected(($41|0));
    // unreachable;
   }
  } while(0);
  $43 = HEAP32[$__v>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   STACKTOP = sp;return;
  }
  __ZdlPv($43);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i10 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 24|0;
 $$byval_copy4 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = HEAP32[$__first>>2]|0;
 $6 = HEAP32[$__last>>2]|0;
 $7 = $6;
 $8 = $5;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$this>>2]|0;
 $14 = $12;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = $16 >> 4;
 $18 = ($10>>>0)>($17>>>0);
 if ($18) {
  $54 = ($13|0)==(0|0);
  if ($54) {
   $75 = $12;
  } else {
   $55 = (($this) + 4|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==($13|0);
   do {
    if ($57) {
     $72 = $13;
    } else {
     $59 = $56;
     while(1) {
      $58 = (($59) + -16|0);
      HEAP32[$55>>2] = $58;
      $60 = (($59) + -12|0);
      $61 = HEAP8[$60>>0]|0;
      $62 = $61 & 1;
      $63 = ($62<<24>>24)==(0);
      if ($63) {
       $65 = $58;
      } else {
       $66 = (($59) + -4|0);
       $67 = HEAP32[$66>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($67|0),($$byval_copy5|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$55>>2]|0;
       $65 = $$pre$i$i$i$i;
      }
      $64 = ($65|0)==($13|0);
      if ($64) {
       label = 25;
       break;
      } else {
       $59 = $65;
      }
     }
     if ((label|0) == 24) {
      $70 = ___cxa_find_matching_catch()|0;
      $71 = tempRet0;
      ___cxa_call_unexpected(($70|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $72 = $$pre$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($72);
   HEAP32[$11>>2] = 0;
   HEAP32[$55>>2] = 0;
   HEAP32[$this>>2] = 0;
   $75 = 0;
  }
  $73 = ($10>>>0)>(268435455);
  if ($73) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $74 = $75;
  $76 = $74 >> 4;
  $77 = ($76>>>0)<(134217727);
  if ($77) {
   $78 = $74 >> 3;
   $79 = ($78>>>0)<($10>>>0);
   $80 = $79 ? $10 : $78;
   $81 = ($80>>>0)>(268435455);
   if ($81) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i10 = $80;
   }
  } else {
   $$0$i10 = 268435455;
  }
  $82 = $$0$i10 << 4;
  $83 = (__Znwj($82)|0);
  $84 = (($this) + 4|0);
  HEAP32[$84>>2] = $83;
  HEAP32[$this>>2] = $83;
  $85 = (($83) + ($$0$i10<<4)|0);
  HEAP32[$11>>2] = $85;
  HEAP32[$3>>2] = $5;
  HEAP32[$4>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
  __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 $22 = (($21) - ($15))|0;
 $23 = $22 >> 4;
 $24 = ($10>>>0)>($23>>>0);
 if ($24) {
  $25 = (($5) + ($23<<4)|0);
  $27 = $25;$__growing$0$off0 = 1;
 } else {
  $27 = $6;$__growing$0$off0 = 0;
 }
 $26 = ($5|0)==($27|0);
 if ($26) {
  $$0$lcssa$i$i = $13;
 } else {
  $scevgep$i = (($27) + -16|0);
  $28 = (0 - ($8))|0;
  $uglygep$i = (($scevgep$i) + ($28)|0);
  $uglygep16$i = $uglygep$i;
  $29 = $uglygep16$i >>> 4;
  $$01$i$i = $13;$31 = $5;
  while(1) {
   $30 = HEAP32[$31>>2]|0;
   HEAP32[$$01$i$i>>2] = $30;
   $32 = (($$01$i$i) + 4|0);
   $33 = (($31) + 4|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($32,$33)|0);
   $34 = (($31) + 16|0);
   $35 = (($$01$i$i) + 16|0);
   $36 = ($34|0)==($27|0);
   if ($36) {
    break;
   } else {
    $$01$i$i = $35;$31 = $34;
   }
  }
  $37 = (($29) + 1)|0;
  $scevgep17$i = (($13) + ($37<<4)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  HEAP32[$1>>2] = $27;
  HEAP32[$2>>2] = $6;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$19>>2]|0;
 $39 = ($38|0)==($$0$lcssa$i$i|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $41 = $38;
 while(1) {
  $40 = (($41) + -16|0);
  HEAP32[$19>>2] = $40;
  $42 = (($41) + -12|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = $43 & 1;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   $47 = $40;
  } else {
   $48 = (($41) + -4|0);
   $49 = HEAP32[$48>>2]|0;
   HEAP32[$$byval_copy4>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy4+0>>2]|0;
   invoke_vii(2591,($49|0),($$byval_copy5|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    label = 16;
    break;
   }
   $$pre$i$i = HEAP32[$19>>2]|0;
   $47 = $$pre$i$i;
  }
  $46 = ($47|0)==($$0$lcssa$i$i|0);
  if ($46) {
   label = 33;
   break;
  } else {
   $41 = $47;
  }
 }
 if ((label|0) == 16) {
  $52 = ___cxa_find_matching_catch()|0;
  $53 = tempRet0;
  ___cxa_call_unexpected(($52|0));
  // unreachable;
 }
 else if ((label|0) == 33) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$byval_copy = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 while(1) {
  $5 = ($6|0)==(0|0);
  if ($5) {
   $37 = 0;$39 = $8;
  } else {
   $7 = HEAP32[$8>>2]|0;
   HEAP32[$6>>2] = $7;
   $9 = (($6) + 4|0);
   $10 = (($8) + 4|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = $11 & 1;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    $18 = (($10) + 1|0);
    $19 = $11&255;
    $20 = $19 >>> 1;
    $22 = $20;$33 = $18;
   } else {
    $14 = (($8) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($8) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $22 = $17;$33 = $15;
   }
   $21 = ($22>>>0)>(2147483631);
   if ($21) {
    label = 8;
    break;
   }
   $23 = ($22>>>0)<(11);
   if ($23) {
    $24 = $22 << 1;
    $25 = $24&255;
    HEAP8[$9>>0] = $25;
    $26 = (($9) + 1|0);
    $__p$0$i$i$i$i$i$i$i = $26;
   } else {
    $27 = (($22) + 16)|0;
    $28 = $27 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy,0,611088,79)|0);
    $30 = (($6) + 12|0);
    HEAP32[$30>>2] = $29;
    $31 = $28 | 1;
    HEAP32[$9>>2] = $31;
    $32 = (($6) + 8|0);
    HEAP32[$32>>2] = $22;
    $__p$0$i$i$i$i$i$i$i = $29;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i|0),($33|0),($22|0))|0;
   $34 = (($__p$0$i$i$i$i$i$i$i) + ($22)|0);
   HEAP8[$34>>0] = 0;
   $35 = HEAP32[$8>>2]|0;
   HEAP32[$6>>2] = $35;
   $$pre1 = HEAP32[$4>>2]|0;
   $$pre2 = HEAP32[$__first>>2]|0;
   $37 = $$pre1;$39 = $$pre2;
  }
  $36 = (($37) + 16|0);
  HEAP32[$4>>2] = $36;
  $38 = (($39) + 16|0);
  HEAP32[$__first>>2] = $38;
  $40 = ($38|0)==($2|0);
  if ($40) {
   label = 14;
   break;
  } else {
   $6 = $36;$8 = $38;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i713 = 0, $$0$i714 = 0, $$0$i9 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$pre1$i1012 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 16|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = (($this) + 8|0);
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($6) - ($18))|0;
 $20 = $19 >> 4;
 $21 = (($20) + ($__n))|0;
 $22 = ($21>>>0)>(268435455);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($5) - ($18))|0;
 $24 = $23 >> 4;
 $25 = ($24>>>0)<(134217727);
 if ($25) {
  $28 = $23 >> 3;
  $29 = ($28>>>0)<($21>>>0);
  $30 = $29 ? $21 : $28;
  $31 = (($__v) + 12|0);
  HEAP32[$31>>2] = 0;
  $32 = (($__v) + 16|0);
  HEAP32[$32>>2] = $16;
  $33 = ($30|0)==(0);
  if ($33) {
   $$0$i714 = 0;$36 = 0;$41 = $31;
  } else {
   $$0$i713 = $30;$87 = $31;
   label = 10;
  }
 } else {
  $26 = (($__v) + 12|0);
  HEAP32[$26>>2] = 0;
  $27 = (($__v) + 16|0);
  HEAP32[$27>>2] = $16;
  $$0$i713 = 268435455;$87 = $26;
  label = 10;
 }
 if ((label|0) == 10) {
  $34 = $$0$i713 << 4;
  $35 = (__Znwj($34)|0);
  $$0$i714 = $$0$i713;$36 = $35;$41 = $87;
 }
 HEAP32[$__v>>2] = $36;
 $37 = (($36) + ($20<<4)|0);
 $38 = (($__v) + 8|0);
 HEAP32[$38>>2] = $37;
 $39 = (($__v) + 4|0);
 HEAP32[$39>>2] = $37;
 $40 = (($36) + ($$0$i714<<4)|0);
 HEAP32[$41>>2] = $40;
 $$0$i9 = $__n;$$pre1$i1012 = $37;
 while(1) {
  $42 = ($$pre1$i1012|0)==(0|0);
  if ($42) {
   $44 = 0;
  } else {
   ;HEAP32[$$pre1$i1012+0>>2]=0|0;HEAP32[$$pre1$i1012+4>>2]=0|0;HEAP32[$$pre1$i1012+8>>2]=0|0;HEAP32[$$pre1$i1012+12>>2]=0|0;
   $44 = $$pre1$i1012;
  }
  $43 = (($44) + 16|0);
  $45 = (($$0$i9) + -1)|0;
  $46 = ($45|0)==(0);
  if ($46) {
   break;
  } else {
   $$0$i9 = $45;$$pre1$i1012 = $43;
  }
 }
 HEAP32[$38>>2] = $43;
 __THREW__ = 0;
 invoke_vii(2728,($this|0),($__v|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  $69 = HEAP32[$39>>2]|0;
  $70 = HEAP32[$38>>2]|0;
  $71 = ($70|0)==($69|0);
  L26: do {
   if (!($71)) {
    $73 = $70;
    while(1) {
     $72 = (($73) + -16|0);
     HEAP32[$38>>2] = $72;
     $74 = (($73) + -12|0);
     $75 = HEAP8[$74>>0]|0;
     $76 = $75 & 1;
     $77 = ($76<<24>>24)==(0);
     if (!($77)) {
      $79 = (($73) + -4|0);
      $80 = HEAP32[$79>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($80|0),($$byval_copy1|0));
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       break;
      }
     }
     $78 = ($72|0)==($69|0);
     if ($78) {
      break L26;
     } else {
      $73 = $72;
     }
    }
    $83 = ___cxa_find_matching_catch()|0;
    $84 = tempRet0;
    ___cxa_call_unexpected(($83|0));
    // unreachable;
   }
  } while(0);
  $85 = HEAP32[$__v>>2]|0;
  $86 = ($85|0)==(0|0);
  if ($86) {
   ___resumeException($67|0);
   // unreachable;
  }
  __ZdlPv($85);
  ___resumeException($67|0);
  // unreachable;
 } else {
  $49 = HEAP32[$39>>2]|0;
  $50 = HEAP32[$38>>2]|0;
  $51 = ($50|0)==($49|0);
  L40: do {
   if (!($51)) {
    $53 = $50;
    while(1) {
     $52 = (($53) + -16|0);
     HEAP32[$38>>2] = $52;
     $54 = (($53) + -12|0);
     $55 = HEAP8[$54>>0]|0;
     $56 = $55 & 1;
     $57 = ($56<<24>>24)==(0);
     if (!($57)) {
      $59 = (($53) + -4|0);
      $60 = HEAP32[$59>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($60|0),($$byval_copy1|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
     }
     $58 = ($52|0)==($49|0);
     if ($58) {
      break L40;
     } else {
      $53 = $52;
     }
    }
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    ___cxa_call_unexpected(($63|0));
    // unreachable;
   }
  } while(0);
  $65 = HEAP32[$__v>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  __ZdlPv($65);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__v) + 4|0);
 $5 = ($3|0)==($1|0);
 do {
  if ($5) {
   $$pre1 = HEAP32[$4>>2]|0;
   $40 = $$pre1;$41 = $1;
  } else {
   $$pre$i = HEAP32[$4>>2]|0;
   $$01$i = $3;$8 = $$pre$i;
   while(1) {
    $6 = (($$01$i) + -16|0);
    $7 = (($8) + -16|0);
    $9 = HEAP32[$6>>2]|0;
    HEAP32[$7>>2] = $9;
    $10 = (($8) + -12|0);
    $11 = (($$01$i) + -12|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = $12 & 1;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     $19 = (($11) + 1|0);
     $20 = $12&255;
     $21 = $20 >>> 1;
     $23 = $21;$34 = $19;
    } else {
     $15 = (($$01$i) + -4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($$01$i) + -8|0);
     $18 = HEAP32[$17>>2]|0;
     $23 = $18;$34 = $16;
    }
    $22 = ($23>>>0)>(2147483631);
    if ($22) {
     label = 8;
     break;
    }
    $24 = ($23>>>0)<(11);
    if ($24) {
     $25 = $23 << 1;
     $26 = $25&255;
     HEAP8[$10>>0] = $26;
     $27 = (($10) + 1|0);
     $__p$0$i$i$i$i$i$i$i$i = $27;
    } else {
     $28 = (($23) + 16)|0;
     $29 = $28 & -16;
     HEAP32[$0>>2] = 59;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy,0,611088,79)|0);
     $31 = (($8) + -4|0);
     HEAP32[$31>>2] = $30;
     $32 = $29 | 1;
     HEAP32[$10>>2] = $32;
     $33 = (($8) + -8|0);
     HEAP32[$33>>2] = $23;
     $__p$0$i$i$i$i$i$i$i$i = $30;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($34|0),($23|0))|0;
    $35 = (($__p$0$i$i$i$i$i$i$i$i) + ($23)|0);
    HEAP8[$35>>0] = 0;
    $36 = HEAP32[$6>>2]|0;
    HEAP32[$7>>2] = $36;
    $37 = HEAP32[$4>>2]|0;
    $38 = (($37) + -16|0);
    HEAP32[$4>>2] = $38;
    $39 = ($6|0)==($1|0);
    if ($39) {
     label = 13;
     break;
    } else {
     $$01$i = $6;$8 = $38;
    }
   }
   if ((label|0) == 8) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre = HEAP32[$this>>2]|0;
    $40 = $38;$41 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $40;
 HEAP32[$4>>2] = $41;
 $42 = (($__v) + 8|0);
 $43 = HEAP32[$2>>2]|0;
 $44 = HEAP32[$42>>2]|0;
 HEAP32[$2>>2] = $44;
 HEAP32[$42>>2] = $43;
 $45 = (($this) + 8|0);
 $46 = (($__v) + 12|0);
 $47 = HEAP32[$45>>2]|0;
 $48 = HEAP32[$46>>2]|0;
 HEAP32[$45>>2] = $48;
 HEAP32[$46>>2] = $47;
 $49 = HEAP32[$4>>2]|0;
 HEAP32[$__v>>2] = $49;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13setIjNS2_4lessIjEENS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $1 = sp + 8|0;
 $size = sp;
 $p = sp + 4|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $9 = $$pre$i$i$i;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$size>>2] = $8;
  HEAP32[$2>>2] = $4;
  $9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$size>>2] = $10;
 $11 = (($data) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($data,$12);
 $13 = (($data) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($data) + 4|0);
 HEAP32[$data>>2] = $14;
 HEAP32[$14>>2] = 0;
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)>(0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $i$02 = 0;
 while(1) {
  $17 = HEAP32[$2>>2]|0;
  $18 = (($17) + 4|0);
  $19 = HEAP32[$5>>2]|0;
  $20 = ($18>>>0)>($19>>>0);
  if ($20) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$p,4);
   $$pre$i$i$i1 = HEAP32[$p>>2]|0;
   $22 = $$pre$i$i$i1;
  } else {
   $21 = HEAP32[$17>>2]|0;
   HEAP32[$p>>2] = $21;
   HEAP32[$2>>2] = $18;
   $22 = $21;
  }
  $23 = (_llvm_bswap_i32(($22|0))|0);
  HEAP32[$p>>2] = $23;
  __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE15__insert_uniqueERKj($1,$data,$p);
  $24 = (($i$02) + 1)|0;
  $25 = HEAP32[$size>>2]|0;
  $26 = ($24|0)<($25|0);
  if ($26) {
   $i$02 = $24;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE15__insert_uniqueERKj($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3>>>0)<($5>>>0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5>>>0)<($3>>>0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $31 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $30 = (($agg$result) + 4|0);
  HEAP8[$30>>0] = $31;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(20)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__v>>2]|0;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $31 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $30 = (($agg$result) + 4|0);
 HEAP8[$30>>0] = $31;
 STACKTOP = sp;return;
}
function __ZN14SubstanceValue8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $this;$12 = $$pre;$14 = $$pre16;$8 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i3 = HEAP32[$10>>2]|0;
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $10;$17 = $$pre$i$i$i3;$21 = $$pre17;$23 = $$pre18;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i8 = HEAP32[$19>>2]|0;
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $19;$26 = $$pre$i$i$i8;$30 = $$pre19;$32 = $$pre20;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i13 = HEAP32[$28>>2]|0;
  $$pre$phi$i$i$i14Z2D = $28;$35 = $$pre$i$i$i13;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $36;
  $37 = (($this) + 16|0);
  __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($37,$transfer);
  STACKTOP = sp;return;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $28;$35 = $34;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $36;
  $37 = (($this) + 16|0);
  __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($37,$transfer);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI14SubstanceInputNS0_9allocatorIS2_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy8 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lpad$phi$i$i21$index = 0, $lpad$phi$i$i21$index3 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 7;
 $9 = ($8>>>0)<($sz>>>0);
 if ($9) {
  $10 = (($v) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($6))|0;
  $14 = $13 >> 7;
  $15 = ($14|0)==($sz|0);
  if ($15) {
   $71 = (($sz) - ($8))|0;
   __ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE8__appendEj($v,$71);
   STACKTOP = sp;return;
  }
  HEAP32[$temp>>2] = 0;
  $16 = (($temp) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($temp) + 8|0);
  HEAP32[$17>>2] = 0;
  __THREW__ = 0;
  invoke_vii(2729,($temp|0),($sz|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  L47: do {
   if (!($19)) {
    $20 = HEAP32[$v>>2]|0;
    HEAP32[$0>>2] = $20;
    $21 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viii(1756,($temp|0),($$byval_copy|0),($$byval_copy8|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[$16>>2]|0;
     $25 = HEAP32[$temp>>2]|0;
     $26 = $24;
     $27 = $25;
     $28 = (($26) - ($27))|0;
     $29 = $28 >> 7;
     $30 = ($29>>>0)<($sz>>>0);
     L50: do {
      if ($30) {
       $31 = (($sz) - ($29))|0;
       __THREW__ = 0;
       invoke_vii(2730,($temp|0),($31|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break L47;
       }
       $$pre28 = HEAP32[$16>>2]|0;
       $47 = $$pre28;
      } else {
       $34 = ($29>>>0)>($sz>>>0);
       if ($34) {
        $35 = (($25) + ($sz<<7)|0);
        $36 = ($24|0)==($35|0);
        if ($36) {
         $47 = $24;
        } else {
         $38 = $24;
         while(1) {
          $37 = (($38) + -128|0);
          HEAP32[$16>>2] = $37;
          __THREW__ = 0;
          invoke_vi(3495,($37|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          $$pre$i = HEAP32[$16>>2]|0;
          $41 = ($$pre$i|0)==($35|0);
          if ($41) {
           $47 = $35;
           break L50;
          } else {
           $38 = $$pre$i;
          }
         }
         $42 = ___cxa_find_matching_catch()|0;
         $43 = tempRet0;
         ___cxa_call_unexpected(($42|0));
         // unreachable;
        }
       } else {
        $47 = $24;
       }
      }
     } while(0);
     $44 = HEAP32[$temp>>2]|0;
     $45 = HEAP32[$v>>2]|0;
     HEAP32[$temp>>2] = $45;
     HEAP32[$v>>2] = $44;
     $46 = HEAP32[$2>>2]|0;
     HEAP32[$16>>2] = $46;
     HEAP32[$2>>2] = $47;
     $48 = HEAP32[$17>>2]|0;
     $49 = HEAP32[$10>>2]|0;
     HEAP32[$17>>2] = $49;
     HEAP32[$10>>2] = $48;
     $50 = ($45|0)==(0|0);
     if ($50) {
      STACKTOP = sp;return;
     } else {
      $52 = $46;
     }
     while(1) {
      $51 = ($52|0)==($45|0);
      if ($51) {
       break;
      }
      $53 = (($52) + -128|0);
      HEAP32[$16>>2] = $53;
      __THREW__ = 0;
      invoke_vi(3495,($53|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 17;
       break;
      }
      $$pre29 = HEAP32[$16>>2]|0;
      $52 = $$pre29;
     }
     if ((label|0) == 17) {
      $56 = ___cxa_find_matching_catch()|0;
      $57 = tempRet0;
      ___cxa_call_unexpected(($56|0));
      // unreachable;
     }
     $58 = HEAP32[$temp>>2]|0;
     __ZdlPv($58);
     STACKTOP = sp;return;
    }
   }
  } while(0);
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $61 = HEAP32[$temp>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   ___resumeException($59|0);
   // unreachable;
  }
  while(1) {
   $63 = HEAP32[$16>>2]|0;
   $64 = ($63|0)==($61|0);
   if ($64) {
    break;
   }
   $65 = (($63) + -128|0);
   HEAP32[$16>>2] = $65;
   __THREW__ = 0;
   invoke_vi(3495,($65|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 22;
    break;
   }
  }
  if ((label|0) == 22) {
   $68 = ___cxa_find_matching_catch()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
  $70 = HEAP32[$temp>>2]|0;
  __ZdlPv($70);
  ___resumeException($59|0);
  // unreachable;
 } else {
  $72 = ($8>>>0)>($sz>>>0);
  if (!($72)) {
   STACKTOP = sp;return;
  }
  $73 = (($4) + ($sz<<7)|0);
  $$idx = $sz << 7;
  $74 = $$idx >> 7;
  $75 = ($74|0)==(0);
  do {
   if ($75) {
    $105 = 0;$106 = 0;$108 = 0;$110 = $4;$118 = $3;
   } else {
    $76 = ($74>>>0)>(33554431);
    if ($76) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if (!($78)) {
      // unreachable;
     }
    } else {
     __THREW__ = 0;
     $79 = (invoke_ii(2988,($$idx|0))|0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if (!($81)) {
      $82 = (($79) + ($74<<7)|0);
      $83 = ($sz|0)==(0);
      if ($83) {
       $105 = $79;$106 = $79;$108 = $82;$110 = $4;$118 = $3;
       break;
      } else {
       $85 = $79;$86 = $4;
      }
      while(1) {
       $84 = ($85|0)==(0|0);
       if ($84) {
        $90 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(2731,($85|0),($86|0));
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         break;
        } else {
         $90 = $85;
        }
       }
       $89 = (($90) + 128|0);
       $91 = (($86) + 128|0);
       $92 = ($91|0)==($73|0);
       if ($92) {
        label = 42;
        break;
       } else {
        $85 = $89;$86 = $91;
       }
      }
      if ((label|0) == 42) {
       $$pre = HEAP32[$v>>2]|0;
       $$pre27 = HEAP32[$2>>2]|0;
       $105 = $79;$106 = $89;$108 = $82;$110 = $$pre;$118 = $$pre27;
       break;
      }
      $95 = ___cxa_find_matching_catch()|0;
      $96 = tempRet0;
      $97 = ($79|0)==(0|0);
      if ($97) {
       $lpad$phi$i$i21$index = $95;$lpad$phi$i$i21$index3 = $96;
       ___resumeException($lpad$phi$i$i21$index|0);
       // unreachable;
      } else {
       $99 = $85;
      }
      while(1) {
       $98 = ($99|0)==($79|0);
       if ($98) {
        break;
       }
       $100 = (($99) + -128|0);
       __THREW__ = 0;
       invoke_vi(3495,($100|0));
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        label = 39;
        break;
       } else {
        $99 = $100;
       }
      }
      if ((label|0) == 39) {
       $103 = ___cxa_find_matching_catch()|0;
       $104 = tempRet0;
       ___cxa_call_unexpected(($103|0));
       // unreachable;
      }
      __ZdlPv($79);
      $lpad$phi$i$i21$index = $95;$lpad$phi$i$i21$index3 = $96;
      ___resumeException($lpad$phi$i$i21$index|0);
      // unreachable;
     }
    }
    $93 = ___cxa_find_matching_catch()|0;
    $94 = tempRet0;
    $lpad$phi$i$i21$index = $93;$lpad$phi$i$i21$index3 = $94;
    ___resumeException($lpad$phi$i$i21$index|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $105;
  HEAP32[$2>>2] = $106;
  $107 = (($v) + 8|0);
  HEAP32[$107>>2] = $108;
  $109 = ($110|0)==(0|0);
  if ($109) {
   STACKTOP = sp;return;
  } else {
   $112 = $118;
  }
  while(1) {
   $111 = ($112|0)==($110|0);
   if ($111) {
    break;
   }
   $113 = (($112) + -128|0);
   __THREW__ = 0;
   invoke_vi(3495,($113|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if ($115) {
    label = 46;
    break;
   } else {
    $112 = $113;
   }
  }
  if ((label|0) == 46) {
   $116 = ___cxa_find_matching_catch()|0;
   $117 = tempRet0;
   ___cxa_call_unexpected(($116|0));
   // unreachable;
  }
  __ZdlPv($110);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 7;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 7;
 $13 = ($__n|0)==(0);
 if ($13) {
  $17 = 0;
 } else {
  $14 = $__n << 7;
  $15 = (__Znwj($14)|0);
  $17 = $15;
 }
 $16 = (($17) + ($12<<7)|0);
 $18 = (($17) + ($__n<<7)|0);
 $19 = ($9|0)==($2|0);
 do {
  if ($19) {
   $26 = $16;$29 = $2;$46 = $2;
  } else {
   $$01$i$i = $9;$21 = $16;
   while(1) {
    $20 = (($21) + -128|0);
    $22 = (($$01$i$i) + -128|0);
    __THREW__ = 0;
    invoke_vii(2731,($20|0),($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = ($22|0)==($2|0);
    if ($25) {
     label = 7;
     break;
    } else {
     $$01$i$i = $22;$21 = $20;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$8>>2]|0;
    $26 = $20;$29 = $$pre$i;$46 = $$pre;
    break;
   }
   $36 = ___cxa_find_matching_catch()|0;
   $37 = tempRet0;
   $39 = $16;
   while(1) {
    $38 = ($39|0)==($21|0);
    if ($38) {
     break;
    }
    $40 = (($39) + -128|0);
    __THREW__ = 0;
    invoke_vi(3495,($40|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 17;
     break;
    } else {
     $39 = $40;
    }
   }
   if ((label|0) == 17) {
    $43 = ___cxa_find_matching_catch()|0;
    $44 = tempRet0;
    ___cxa_call_unexpected(($43|0));
    // unreachable;
   }
   $45 = ($17|0)==(0|0);
   if ($45) {
    ___resumeException($36|0);
    // unreachable;
   }
   __ZdlPv($17);
   ___resumeException($36|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$this>>2] = $26;
 HEAP32[$8>>2] = $16;
 HEAP32[$0>>2] = $18;
 $28 = $46;
 while(1) {
  $27 = ($28|0)==($29|0);
  if ($27) {
   break;
  }
  $30 = (($28) + -128|0);
  __THREW__ = 0;
  invoke_vi(3495,($30|0));
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if ($32) {
   label = 11;
   break;
  } else {
   $28 = $30;
  }
 }
 if ((label|0) == 11) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  ___cxa_call_unexpected(($33|0));
  // unreachable;
 }
 $35 = ($29|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 __ZdlPv($29);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i30 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $8 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 7;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 7;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $45 = ($8|0)==(0|0);
  do {
   if ($45) {
    $57 = $7;
   } else {
    $46 = (($this) + 4|0);
    while(1) {
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==($8|0);
     if ($48) {
      label = 22;
      break;
     }
     $49 = (($47) + -128|0);
     HEAP32[$46>>2] = $49;
     __THREW__ = 0;
     invoke_vi(3495,($49|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 21;
      break;
     }
    }
    if ((label|0) == 21) {
     $52 = ___cxa_find_matching_catch()|0;
     $53 = tempRet0;
     ___cxa_call_unexpected(($52|0));
     // unreachable;
    }
    else if ((label|0) == 22) {
     $54 = HEAP32[$this>>2]|0;
     __ZdlPv($54);
     HEAP32[$6>>2] = 0;
     HEAP32[$46>>2] = 0;
     HEAP32[$this>>2] = 0;
     $57 = 0;
     break;
    }
   }
  } while(0);
  $55 = ($5>>>0)>(33554431);
  if ($55) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $56 = $57;
  $58 = $56 >> 7;
  $59 = ($58>>>0)<(16777215);
  if ($59) {
   $60 = $56 >> 6;
   $61 = ($60>>>0)<($5>>>0);
   $62 = $61 ? $5 : $60;
   $63 = ($62>>>0)>(33554431);
   if ($63) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i30 = $62;
   }
  } else {
   $$0$i30 = 33554431;
  }
  $64 = $$0$i30 << 7;
  $65 = (__Znwj($64)|0);
  $66 = (($this) + 4|0);
  HEAP32[$66>>2] = $65;
  HEAP32[$this>>2] = $65;
  $67 = (($65) + ($$0$i30<<7)|0);
  HEAP32[$6>>2] = $67;
  $68 = ($0|0)==($1|0);
  if ($68) {
   STACKTOP = sp;return;
  } else {
   $70 = $65;$71 = $0;
  }
  while(1) {
   $69 = ($70|0)==(0|0);
   if ($69) {
    $73 = 0;
   } else {
    __ZN14SubstanceInputC2ERKS_($70,$71);
    $$pre1$i = HEAP32[$66>>2]|0;
    $73 = $$pre1$i;
   }
   $72 = (($73) + 128|0);
   HEAP32[$66>>2] = $72;
   $74 = (($71) + 128|0);
   $75 = ($74|0)==($1|0);
   if ($75) {
    break;
   } else {
    $70 = $72;$71 = $74;
   }
  }
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 7;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<7)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i = (($22) + -128|0);
  $23 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($23)|0);
  $uglygep16$i = $uglygep$i;
  $24 = $uglygep16$i >>> 7;
  $$01$i$i = $8;$25 = $0;
  while(1) {
   (__ZN14SubstanceInputaSERKS_($$01$i$i,$25)|0);
   $26 = (($25) + 128|0);
   $27 = (($$01$i$i) + 128|0);
   $28 = ($26|0)==($22|0);
   if ($28) {
    break;
   } else {
    $$01$i$i = $27;$25 = $26;
   }
  }
  $29 = (($24) + 1)|0;
  $scevgep17$i = (($8) + ($29<<7)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if (!($__growing$0$off0)) {
  while(1) {
   $38 = HEAP32[$14>>2]|0;
   $39 = ($38|0)==($$0$lcssa$i$i|0);
   if ($39) {
    label = 32;
    break;
   }
   $40 = (($38) + -128|0);
   HEAP32[$14>>2] = $40;
   __THREW__ = 0;
   invoke_vi(3495,($40|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    label = 16;
    break;
   }
  }
  if ((label|0) == 16) {
   $43 = ___cxa_find_matching_catch()|0;
   $44 = tempRet0;
   ___cxa_call_unexpected(($43|0));
   // unreachable;
  }
  else if ((label|0) == 32) {
   STACKTOP = sp;return;
  }
 }
 $30 = ($22|0)==($1|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $$pre$i12 = HEAP32[$14>>2]|0;
 $32 = $$pre$i12;$33 = $22;
 while(1) {
  $31 = ($32|0)==(0|0);
  if ($31) {
   $35 = 0;
  } else {
   __ZN14SubstanceInputC2ERKS_($32,$33);
   $$pre1$i14 = HEAP32[$14>>2]|0;
   $35 = $$pre1$i14;
  }
  $34 = (($35) + 128|0);
  HEAP32[$14>>2] = $34;
  $36 = (($33) + 128|0);
  $37 = ($36|0)==($1|0);
  if ($37) {
   break;
  } else {
   $32 = $34;$33 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i417 = 0, $$0$i418 = 0, $$0$i6 = 0, $$01$i$i = 0, $$pre = 0, $$pre$i10 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 7;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $30 = 0;
   } else {
    $11 = (($10) + 40|0);
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;
    $12 = (($10) + 76|0);
    HEAP32[$12>>2] = 0;
    $13 = (($10) + 80|0);
    HEAP32[$13>>2] = 0;
    $14 = (($10) + 84|0);
    HEAP32[$14>>2] = 0;
    $15 = (($10) + 100|0);
    HEAP32[$15>>2] = 0;
    $16 = (($10) + 104|0);
    HEAP32[$16>>2] = 0;
    $17 = (($10) + 108|0);
    HEAP32[$17>>2] = 0;
    $18 = (($10) + 120|0);
    HEAP32[$18>>2] = 0;
    $19 = (($10) + 124|0);
    HEAP32[$19>>2] = 0;
    $20 = (($10) + 120|0);
    $21 = (($10) + 116|0);
    dest=$10+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$21>>2] = $20;
    $22 = (($10) + 36|0);
    HEAP32[$22>>2] = 1;
    $23 = (($10) + 112|0);
    HEAP32[$23>>2] = 8;
    $24 = (($10) + 60|0);
    HEAP32[$24>>2] = 0;
    $25 = (($10) + 64|0);
    HEAP32[$25>>2] = 0;
    $26 = (($10) + 68|0);
    HEAP32[$26>>2] = 0;
    $27 = (($10) + 88|0);
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
    HEAPF32[$27>>2] = Math_fround(-3.40282346638528859812E+38);
    $28 = (($10) + 92|0);
    HEAPF32[$28>>2] = Math_fround(3.40282346638528859812E+38);
    $$pre1$i = HEAP32[$2>>2]|0;
    $30 = $$pre1$i;
   }
   $29 = (($30) + 128|0);
   HEAP32[$2>>2] = $29;
   $31 = (($$0$i) + -1)|0;
   $32 = ($31|0)==(0);
   if ($32) {
    break;
   } else {
    $$0$i = $31;$10 = $29;
   }
  }
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$this>>2]|0;
 $34 = $33;
 $35 = (($5) - ($34))|0;
 $36 = $35 >> 7;
 $37 = (($36) + ($__n))|0;
 $38 = ($37>>>0)>(33554431);
 if ($38) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $39 = (($4) - ($34))|0;
 $40 = $39 >> 7;
 $41 = ($40>>>0)<(16777215);
 if ($41) {
  $42 = $39 >> 6;
  $43 = ($42>>>0)<($37>>>0);
  $44 = $43 ? $37 : $42;
  $45 = ($44|0)==(0);
  if ($45) {
   $$0$i418 = 0;$49 = 0;
  } else {
   $$0$i417 = $44;
   label = 9;
  }
 } else {
  $$0$i417 = 33554431;
  label = 9;
 }
 if ((label|0) == 9) {
  $46 = $$0$i417 << 7;
  $47 = (__Znwj($46)|0);
  $$0$i418 = $$0$i417;$49 = $47;
 }
 $48 = (($49) + ($36<<7)|0);
 $$0$i6 = $__n;$51 = $48;
 while(1) {
  $50 = ($51|0)==(0|0);
  if ($50) {
   $71 = 0;
  } else {
   $52 = (($51) + 40|0);
   ;HEAP32[$52+0>>2]=0|0;HEAP32[$52+4>>2]=0|0;HEAP32[$52+8>>2]=0|0;HEAP32[$52+12>>2]=0|0;HEAP32[$52+16>>2]=0|0;
   $53 = (($51) + 76|0);
   HEAP32[$53>>2] = 0;
   $54 = (($51) + 80|0);
   HEAP32[$54>>2] = 0;
   $55 = (($51) + 84|0);
   HEAP32[$55>>2] = 0;
   $56 = (($51) + 100|0);
   HEAP32[$56>>2] = 0;
   $57 = (($51) + 104|0);
   HEAP32[$57>>2] = 0;
   $58 = (($51) + 108|0);
   HEAP32[$58>>2] = 0;
   $59 = (($51) + 120|0);
   HEAP32[$59>>2] = 0;
   $60 = (($51) + 124|0);
   HEAP32[$60>>2] = 0;
   $61 = (($51) + 120|0);
   $62 = (($51) + 116|0);
   dest=$51+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$62>>2] = $61;
   $63 = (($51) + 36|0);
   HEAP32[$63>>2] = 1;
   $64 = (($51) + 112|0);
   HEAP32[$64>>2] = 8;
   $65 = (($51) + 60|0);
   HEAP32[$65>>2] = 0;
   $66 = (($51) + 64|0);
   HEAP32[$66>>2] = 0;
   $67 = (($51) + 68|0);
   HEAP32[$67>>2] = 0;
   $68 = (($51) + 88|0);
   ;HEAP32[$52+0>>2]=0|0;HEAP32[$52+4>>2]=0|0;HEAP32[$52+8>>2]=0|0;HEAP32[$52+12>>2]=0|0;
   HEAPF32[$68>>2] = Math_fround(-3.40282346638528859812E+38);
   $69 = (($51) + 92|0);
   HEAPF32[$69>>2] = Math_fround(3.40282346638528859812E+38);
   $71 = $51;
  }
  $70 = (($71) + 128|0);
  $72 = (($$0$i6) + -1)|0;
  $73 = ($72|0)==(0);
  if ($73) {
   break;
  } else {
   $$0$i6 = $72;$51 = $70;
  }
 }
 $74 = (($49) + ($$0$i418<<7)|0);
 $75 = HEAP32[$this>>2]|0;
 $76 = HEAP32[$2>>2]|0;
 $77 = ($76|0)==($75|0);
 do {
  if ($77) {
   $104 = $75;$84 = $48;$87 = $75;
  } else {
   $$01$i$i = $76;$79 = $48;
   while(1) {
    $78 = (($79) + -128|0);
    $80 = (($$01$i$i) + -128|0);
    __THREW__ = 0;
    invoke_vii(2731,($78|0),($80|0));
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = ($80|0)==($75|0);
    if ($83) {
     label = 17;
     break;
    } else {
     $$01$i$i = $80;$79 = $78;
    }
   }
   if ((label|0) == 17) {
    $$pre$i10 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $104 = $$pre;$84 = $78;$87 = $$pre$i10;
    break;
   }
   $94 = ___cxa_find_matching_catch()|0;
   $95 = tempRet0;
   $97 = $70;
   while(1) {
    $96 = ($97|0)==($79|0);
    if ($96) {
     break;
    }
    $98 = (($97) + -128|0);
    __THREW__ = 0;
    invoke_vi(3495,($98|0));
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     label = 27;
     break;
    } else {
     $97 = $98;
    }
   }
   if ((label|0) == 27) {
    $101 = ___cxa_find_matching_catch()|0;
    $102 = tempRet0;
    ___cxa_call_unexpected(($101|0));
    // unreachable;
   }
   $103 = ($49|0)==(0|0);
   if ($103) {
    ___resumeException($94|0);
    // unreachable;
   }
   __ZdlPv($49);
   ___resumeException($94|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$this>>2] = $84;
 HEAP32[$2>>2] = $70;
 HEAP32[$0>>2] = $74;
 $86 = $104;
 while(1) {
  $85 = ($86|0)==($87|0);
  if ($85) {
   break;
  }
  $88 = (($86) + -128|0);
  __THREW__ = 0;
  invoke_vi(3495,($88|0));
  $89 = __THREW__; __THREW__ = 0;
  $90 = $89&1;
  if ($90) {
   label = 21;
   break;
  } else {
   $86 = $88;
  }
 }
 if ((label|0) == 21) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  ___cxa_call_unexpected(($91|0));
  // unreachable;
 }
 $93 = ($87|0)==(0|0);
 if ($93) {
  STACKTOP = sp;return;
 }
 __ZdlPv($87);
 STACKTOP = sp;return;
}
function __ZN4PPtrI16SubstanceArchiveE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI17ProceduralTextureENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4PPtrI17ProceduralTextureENS0_9allocatorIS4_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI17ProceduralTextureE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI17ProceduralTextureE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI4PPtrI17ProceduralTextureENS0_9allocatorIS4_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$idx = 0, $$pre54 = 0, $$pre55 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i30 = 0, $__new_last2$i$i$i$i$i39 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i31 = 0, $scevgep$i$i$i$i$i40 = 0, $scevgep$i$i$i17 = 0, $scevgep4$i$i$i$i$i35 = 0, $scevgep4$i$i$i$i$i44 = 0;
 var $scevgep4$i$i$i19 = 0, $scevgep8$i$i$i = 0, $scevgep8$i$i$i52 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i42 = 0, $uglygep$i$i$i18 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i34 = 0, $uglygep3$i$i$i$i$i43 = 0, $uglygep6$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($sz>>>0);
 if (!($9)) {
  $63 = ($8>>>0)>($sz>>>0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  $64 = (($4) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $65 = $$idx >> 2;
  $66 = ($65|0)==(0);
  if ($66) {
   $81 = 0;$83 = 0;$scevgep8$i$i$i52 = 0;
  } else {
   $67 = ($65>>>0)>(1073741823);
   if ($67) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $68 = (__Znwj($$idx)|0);
   $69 = (($68) + ($65<<2)|0);
   $70 = ($sz|0)==(0);
   if ($70) {
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $68;
   } else {
    $$sum = (($sz) + -1)|0;
    $scevgep$i$i$i = (($4) + ($$sum<<2)|0);
    $71 = (0 - ($6))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($71)|0);
    $73 = $68;$75 = $4;
    while(1) {
     $72 = ($73|0)==(0|0);
     if (!($72)) {
      $74 = HEAP32[$75>>2]|0;
      HEAP32[$73>>2] = $74;
     }
     $76 = (($73) + 4|0);
     $77 = (($75) + 4|0);
     $78 = ($77|0)==($64|0);
     if ($78) {
      break;
     } else {
      $73 = $76;$75 = $77;
     }
    }
    $uglygep6$i$i$i = $uglygep$i$i$i;
    $79 = $uglygep6$i$i$i >>> 2;
    $80 = (($79) + 1)|0;
    $scevgep8$i$i$i = (($68) + ($80<<2)|0);
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $scevgep8$i$i$i;
   }
  }
  HEAP32[$v>>2] = $81;
  HEAP32[$2>>2] = $scevgep8$i$i$i52;
  $82 = (($v) + 8|0);
  HEAP32[$82>>2] = $83;
  $84 = ($4|0)==(0|0);
  if ($84) {
   STACKTOP = sp;return;
  }
  __ZdlPv($4);
  STACKTOP = sp;return;
 }
 $10 = (($v) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($6))|0;
 $14 = $13 >> 2;
 $15 = ($14|0)==($sz|0);
 if ($15) {
  $62 = (($sz) - ($8))|0;
  __ZNSt3__16vectorI4PPtrI17ProceduralTextureENS_9allocatorIS3_EEE8__appendEj($v,$62);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $16 = (($temp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($temp) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = ($sz|0)==(0);
 if ($18) {
  label = 6;
 } else {
  $19 = $sz << 2;
  __THREW__ = 0;
  $20 = (invoke_ii(2988,($19|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $23 = (($20) + ($sz<<2)|0);
   HEAP32[$temp>>2] = $20;
   HEAP32[$16>>2] = $20;
   HEAP32[$17>>2] = $23;
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$0>>2] = $4;
   HEAP32[$1>>2] = $3;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1757,($temp|0),($$byval_copy|0),($$byval_copy1|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$16>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = $30 >> 2;
    $32 = ($31>>>0)<($sz>>>0);
    if ($32) {
     $33 = (($sz) - ($31))|0;
     __THREW__ = 0;
     invoke_vii(2732,($temp|0),($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $$pre54 = HEAP32[$temp>>2]|0;
     $$pre55 = HEAP32[$16>>2]|0;
     $43 = $$pre54;$45 = $$pre55;
    } else {
     $36 = ($31>>>0)>($sz>>>0);
     if ($36) {
      $37 = (($27) + ($sz<<2)|0);
      $38 = ($26|0)==($37|0);
      if ($38) {
       $43 = $27;$45 = $26;
      } else {
       $__new_last2$i$i$i = $37;
       $scevgep$i$i$i17 = (($26) + -4|0);
       $39 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i18 = (($scevgep$i$i$i17) + ($39)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i18;
       $40 = $uglygep3$i$i$i >>> 2;
       $41 = $40 ^ -1;
       $scevgep4$i$i$i19 = (($26) + ($41<<2)|0);
       HEAP32[$16>>2] = $scevgep4$i$i$i19;
       $43 = $27;$45 = $scevgep4$i$i$i19;
      }
     } else {
      $43 = $27;$45 = $26;
     }
    }
    $42 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $42;
    HEAP32[$v>>2] = $43;
    $44 = HEAP32[$2>>2]|0;
    HEAP32[$16>>2] = $44;
    HEAP32[$2>>2] = $45;
    $46 = HEAP32[$17>>2]|0;
    $47 = HEAP32[$10>>2]|0;
    HEAP32[$17>>2] = $47;
    HEAP32[$10>>2] = $46;
    $48 = ($42|0)==(0|0);
    if ($48) {
     STACKTOP = sp;return;
    }
    $49 = ($44|0)==($42|0);
    if (!($49)) {
     $__new_last2$i$i$i$i$i30 = $42;
     $scevgep$i$i$i$i$i31 = (($44) + -4|0);
     $50 = (0 - ($__new_last2$i$i$i$i$i30))|0;
     $uglygep$i$i$i$i$i33 = (($scevgep$i$i$i$i$i31) + ($50)|0);
     $uglygep3$i$i$i$i$i34 = $uglygep$i$i$i$i$i33;
     $51 = $uglygep3$i$i$i$i$i34 >>> 2;
     $52 = $51 ^ -1;
     $scevgep4$i$i$i$i$i35 = (($44) + ($52<<2)|0);
     HEAP32[$16>>2] = $scevgep4$i$i$i$i$i35;
    }
    __ZdlPv($42);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $53 = ___cxa_find_matching_catch()|0;
 $54 = tempRet0;
 $55 = HEAP32[$temp>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($53|0);
  // unreachable;
 }
 $57 = HEAP32[$16>>2]|0;
 $58 = ($57|0)==($55|0);
 if (!($58)) {
  $__new_last2$i$i$i$i$i39 = $55;
  $scevgep$i$i$i$i$i40 = (($57) + -4|0);
  $59 = (0 - ($__new_last2$i$i$i$i$i39))|0;
  $uglygep$i$i$i$i$i42 = (($scevgep$i$i$i$i$i40) + ($59)|0);
  $uglygep3$i$i$i$i$i43 = $uglygep$i$i$i$i$i42;
  $60 = $uglygep3$i$i$i$i$i43 >>> 2;
  $61 = $60 ^ -1;
  $scevgep4$i$i$i$i$i44 = (($57) + ($61<<2)|0);
  HEAP32[$16>>2] = $scevgep4$i$i$i$i$i44;
 }
 __ZdlPv($55);
 ___resumeException($53|0);
 // unreachable;
}
function __ZNSt3__16vectorI4PPtrI17ProceduralTextureENS_9allocatorIS3_EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$promoted15$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0;
 var $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i24 = 0, $scevgep$i10 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i17 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i25 = 0, $uglygep$i12 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0;
 var $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $46 = ($8|0)==(0|0);
  if ($46) {
   $55 = $7;
  } else {
   $47 = (($this) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($8|0);
   if (!($49)) {
    $scevgep$i$i$i$i = (($48) + -4|0);
    $50 = (0 - ($10))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($50)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $51 = $uglygep3$i$i$i$i >>> 2;
    $52 = $51 ^ -1;
    $scevgep4$i$i$i$i = (($48) + ($52<<2)|0);
    HEAP32[$47>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($8);
   HEAP32[$6>>2] = 0;
   HEAP32[$47>>2] = 0;
   HEAP32[$this>>2] = 0;
   $55 = 0;
  }
  $53 = ($5>>>0)>(1073741823);
  if ($53) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $54 = $55;
  $56 = $54 >> 2;
  $57 = ($56>>>0)<(536870911);
  if ($57) {
   $58 = $54 >> 1;
   $59 = ($58>>>0)<($5>>>0);
   $60 = $59 ? $5 : $58;
   $61 = ($60>>>0)>(1073741823);
   if ($61) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $60;
   }
  } else {
   $$0$i40 = 1073741823;
  }
  $62 = $$0$i40 << 2;
  $63 = (__Znwj($62)|0);
  $64 = (($this) + 4|0);
  HEAP32[$64>>2] = $63;
  HEAP32[$this>>2] = $63;
  $65 = (($63) + ($$0$i40<<2)|0);
  HEAP32[$6>>2] = $65;
  $66 = ($0|0)==($1|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($1) + -4|0);
  $67 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($67)|0);
  $uglygep6$i = $uglygep$i;
  $68 = $uglygep6$i >>> 2;
  $70 = $63;$72 = $0;
  while(1) {
   $69 = ($70|0)==(0|0);
   if (!($69)) {
    $71 = HEAP32[$72>>2]|0;
    HEAP32[$70>>2] = $71;
   }
   $73 = (($70) + 4|0);
   $74 = (($72) + 4|0);
   $75 = ($74|0)==($1|0);
   if ($75) {
    break;
   } else {
    $70 = $73;$72 = $74;
   }
  }
  $76 = (($68) + 1)|0;
  $scevgep8$i = (($63) + ($76<<2)|0);
  HEAP32[$64>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 2;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<2)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i24 = (($22) + -4|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i25 = (($scevgep$i$i24) + ($23)|0);
  $uglygep5$i$i = $uglygep$i$i25;
  $24 = $uglygep5$i$i >>> 2;
  $$01$i$i = $8;$26 = $0;
  while(1) {
   $25 = HEAP32[$26>>2]|0;
   HEAP32[$$01$i$i>>2] = $25;
   $27 = (($26) + 4|0);
   $28 = (($$01$i$i) + 4|0);
   $29 = ($27|0)==($22|0);
   if ($29) {
    break;
   } else {
    $$01$i$i = $28;$26 = $27;
   }
  }
  $30 = (($24) + 1)|0;
  $scevgep6$i$i = (($8) + ($30<<2)|0);
  $$0$lcssa$i$i = $scevgep6$i$i;
 }
 if (!($__growing$0$off0)) {
  $42 = ($15|0)==($$0$lcssa$i$i|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($15) + -4|0);
  $43 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($43)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $44 = $uglygep3$i$i >>> 2;
  $45 = $44 ^ -1;
  $scevgep4$i$i = (($15) + ($45<<2)|0);
  HEAP32[$14>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $31 = ($22|0)==($1|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $$promoted15$i9 = $22;
 $scevgep$i10 = (($1) + -4|0);
 $32 = (0 - ($$promoted15$i9))|0;
 $uglygep$i12 = (($scevgep$i10) + ($32)|0);
 $uglygep6$i13 = $uglygep$i12;
 $33 = $uglygep6$i13 >>> 2;
 $35 = $15;$37 = $22;
 while(1) {
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   $36 = HEAP32[$37>>2]|0;
   HEAP32[$35>>2] = $36;
  }
  $38 = (($35) + 4|0);
  $39 = (($37) + 4|0);
  $40 = ($39|0)==($1|0);
  if ($40) {
   break;
  } else {
   $35 = $38;$37 = $39;
  }
 }
 $41 = (($33) + 1)|0;
 $scevgep8$i17 = (($15) + ($41<<2)|0);
 HEAP32[$14>>2] = $scevgep8$i17;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI4PPtrI17ProceduralTextureENS_9allocatorIS3_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0;
 var $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
   }
   $11 = (($10) + 4|0);
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$10 = $11;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($__n))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 if ($22) {
  $23 = $20 >> 1;
  $24 = ($23>>>0)<($18>>>0);
  $25 = $24 ? $18 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 2;
  $28 = (__Znwj($27)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($17<<2)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP32[$32>>2] = 0;
  }
  $33 = (($32) + 4|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($30) + ($18<<2)|0);
 $37 = ($3|0)==($14|0);
 if ($37) {
  $47 = $29;$49 = $3;
 } else {
  $scevgep$i$i = (($3) + -4|0);
  $38 = (0 - ($15))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($38)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $3;$42 = $29;
  while(1) {
   $39 = (($$01$i$i) + -4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($42) + -4|0);
   HEAP32[$41>>2] = $40;
   $43 = (($42) + -4|0);
   $44 = ($39|0)==($14|0);
   if ($44) {
    break;
   } else {
    $$01$i$i = $39;$42 = $43;
   }
  }
  $45 = $uglygep4$i$i >>> 2;
  $46 = $45 ^ -1;
  $$sum6 = (($17) + ($46))|0;
  $scevgep5$i$i = (($30) + ($$sum6<<2)|0);
  $47 = $scevgep5$i$i;$49 = $14;
 }
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $36;
 $48 = ($49|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($49);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterial8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre10 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZN5Unity8Material8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $2 = (($this) + 176|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre5;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($this) + 180|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,4);
  $$pre6 = HEAP32[$3>>2]|0;
  $$pre7 = HEAP32[$6>>2]|0;
  $18 = $$pre6;$20 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$3>>2] = $11;
  $18 = $11;$20 = $14;
 }
 $16 = (($this) + 184|0);
 $17 = (($18) + 1|0);
 $19 = ($17>>>0)>($20>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$16,1);
 } else {
  $21 = HEAP8[$18>>0]|0;
  HEAP8[$16>>0] = $21;
  $22 = HEAP32[$3>>2]|0;
  $23 = (($22) + 1|0);
  HEAP32[$3>>2] = $23;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $24 = (($this) + 188|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI17ProceduralTextureENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($transfer,$24,0);
 $25 = (($this) + 260|0);
 $26 = HEAP32[$3>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$6>>2]|0;
 $29 = ($27>>>0)>($28>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$25,4);
  $$pre8 = HEAP32[$25>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $$pre10 = HEAP32[$6>>2]|0;
  $32 = $$pre8;$36 = $$pre9;$38 = $$pre10;
 } else {
  $30 = HEAP32[$26>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$3>>2] = $27;
  $32 = $30;$36 = $27;$38 = $28;
 }
 $31 = $32 & 1;
 $33 = (($this) + 264|0);
 HEAP32[$33>>2] = $31;
 $34 = $32 & -65538;
 HEAP32[$25>>2] = $34;
 $35 = (($36) + 4|0);
 $37 = ($35>>>0)>($38>>>0);
 if ($37) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$33,4);
 } else {
  $39 = HEAP32[$36>>2]|0;
  HEAP32[$33>>2] = $39;
  HEAP32[$3>>2] = $35;
 }
 $40 = (($this) + 152|0);
 __ZN4PPtrI16SubstanceArchiveE8TransferI18StreamedBinaryReadILb0EEEEvRT_($40,$transfer);
 $41 = (($this) + 212|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14SubstanceInputNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$41,0);
 $42 = (($this) + 164|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$42,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43 & 1;
 $45 = ($44<<24>>24)==(0);
 if ($45) {
  $48 = $43&255;
  $49 = $48 >>> 1;
  $51 = $49;
 } else {
  $46 = (($this) + 168|0);
  $47 = HEAP32[$46>>2]|0;
  $51 = $47;
 }
 $50 = ($51|0)==(0);
 do {
  if ($50) {
   $52 = HEAP32[$this>>2]|0;
   $53 = (($52) + 32|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (FUNCTION_TABLE_ii[$54 & 4095]($this)|0);
   $56 = (_strlen(($55|0))|0);
   $57 = ($56>>>0)>(2147483631);
   if ($57) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $58 = ($56>>>0)<(11);
   if ($58) {
    $59 = $56 << 1;
    $60 = $59&255;
    HEAP8[$1>>0] = $60;
    $61 = (($1) + 1|0);
    $__p$0$i$i$i$i = $61;
   } else {
    $62 = (($56) + 16)|0;
    $63 = $62 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $64 = (__Z15malloc_internaljj10MemLabelIdiPKci($63,16,$$byval_copy2,0,611088,79)|0);
    $65 = (($1) + 8|0);
    HEAP32[$65>>2] = $64;
    $66 = $63 | 1;
    HEAP32[$1>>2] = $66;
    $67 = (($1) + 4|0);
    HEAP32[$67>>2] = $56;
    $__p$0$i$i$i$i = $64;
   }
   _memcpy(($__p$0$i$i$i$i|0),($55|0),($56|0))|0;
   $68 = (($__p$0$i$i$i$i) + ($56)|0);
   HEAP8[$68>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($42|0),($1|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    $71 = HEAP8[$1>>0]|0;
    $72 = $71 & 1;
    $73 = ($72<<24>>24)==(0);
    if ($73) {
     break;
    }
    $74 = (($1) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($75|0),($$byval_copy2|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if (!($77)) {
     break;
    }
    $78 = ___cxa_find_matching_catch()|0;
    $79 = tempRet0;
    ___cxa_call_unexpected(($78|0));
    // unreachable;
   }
   $80 = ___cxa_find_matching_catch()|0;
   $81 = tempRet0;
   $82 = HEAP8[$1>>0]|0;
   $83 = $82 & 1;
   $84 = ($83<<24>>24)==(0);
   if ($84) {
    ___resumeException($80|0);
    // unreachable;
   }
   $85 = (($1) + 8|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($86|0),($$byval_copy2|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    ___resumeException($80|0);
    // unreachable;
   }
  }
 } while(0);
 $91 = (($this) + 252|0);
 $92 = HEAP32[$3>>2]|0;
 $93 = (($92) + 4|0);
 $94 = HEAP32[$6>>2]|0;
 $95 = ($93>>>0)>($94>>>0);
 if ($95) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$91,4);
  $97 = (($this) + 224|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($97,$transfer);
  STACKTOP = sp;return;
 } else {
  $96 = HEAP32[$92>>2]|0;
  HEAP32[$91>>2] = $96;
  HEAP32[$3>>2] = $93;
  $97 = (($this) + 224|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($97,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14SubstanceInputNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI14SubstanceInputNS0_9allocatorIS2_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN14SubstanceInput8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 128|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 7;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14SubstanceInput8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0);
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $1 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $2 = (($this) + 36|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
 }
 $10 = (($this) + 40|0);
 __ZN14SubstanceValue8TransferI18StreamedBinaryReadILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 60|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$6>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$11,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre6 = HEAP32[$6>>2]|0;
  $19 = $$pre;$21 = $$pre6;
 } else {
  $16 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$3>>2] = $13;
  $19 = $13;$21 = $14;
 }
 $17 = (($this) + 64|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$17,4);
  $$pre7 = HEAP32[$3>>2]|0;
  $$pre8 = HEAP32[$6>>2]|0;
  $25 = $$pre7;$27 = $$pre8;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$3>>2] = $18;
  $25 = $18;$27 = $21;
 }
 $23 = (($this) + 68|0);
 $24 = (($25) + 4|0);
 $26 = ($24>>>0)>($27>>>0);
 if ($26) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$23,4);
 } else {
  $28 = HEAP32[$25>>2]|0;
  HEAP32[$23>>2] = $28;
  HEAP32[$3>>2] = $24;
 }
 $29 = (($this) + 76|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$29,0);
 $30 = (($this) + 88|0);
 $31 = HEAP32[$3>>2]|0;
 $32 = (($31) + 4|0);
 $33 = HEAP32[$6>>2]|0;
 $34 = ($32>>>0)>($33>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$30,4);
  $$pre9 = HEAP32[$3>>2]|0;
  $$pre10 = HEAP32[$6>>2]|0;
  $38 = $$pre9;$40 = $$pre10;
 } else {
  $35 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$30>>2] = $35;
  HEAP32[$3>>2] = $32;
  $38 = $32;$40 = $33;
 }
 $36 = (($this) + 92|0);
 $37 = (($38) + 4|0);
 $39 = ($37>>>0)>($40>>>0);
 if ($39) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$36,4);
  $$pre11 = HEAP32[$3>>2]|0;
  $$pre12 = HEAP32[$6>>2]|0;
  $44 = $$pre11;$46 = $$pre12;
 } else {
  $41 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[$36>>2] = $41;
  HEAP32[$3>>2] = $37;
  $44 = $37;$46 = $40;
 }
 $42 = (($this) + 96|0);
 $43 = (($44) + 4|0);
 $45 = ($43>>>0)>($46>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$42,4);
  $$pre13 = HEAP32[$3>>2]|0;
  $$pre14 = HEAP32[$6>>2]|0;
  $50 = $$pre13;$52 = $$pre14;
 } else {
  $47 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$42>>2] = $47;
  HEAP32[$3>>2] = $43;
  $50 = $43;$52 = $46;
 }
 $48 = (($this) + 112|0);
 $49 = (($50) + 4|0);
 $51 = ($49>>>0)>($52>>>0);
 if ($51) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$48,4);
  $54 = (($this) + 116|0);
  __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13setIjNS2_4lessIjEENS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$54,0);
  $55 = (($this) + 100|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$55,0);
  $56 = HEAP32[$48>>2]|0;
  $57 = $56 & -13;
  $58 = $57 | 8;
  HEAP32[$48>>2] = $58;
  STACKTOP = sp;return;
 } else {
  $53 = HEAP32[$50>>2]|0;
  HEAP32[$48>>2] = $53;
  HEAP32[$3>>2] = $49;
  $54 = (($this) + 116|0);
  __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13setIjNS2_4lessIjEENS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$54,0);
  $55 = (($this) + 100|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$55,0);
  $56 = HEAP32[$48>>2]|0;
  $57 = $56 & -13;
  $58 = $57 | 8;
  HEAP32[$48>>2] = $58;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $20 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $20 = $19;
 }
 __Z14resize_trimmedINSt3__16vectorI17SubstanceEnumItemNS0_9allocatorIS2_EEEEEvRT_j($data,$20);
 $21 = (($data) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$data>>2]|0;
 $24 = ($23|0)==($22|0);
 if ($24) {
  STACKTOP = sp;return;
 } else {
  $30 = $23;
 }
 while(1) {
  $25 = HEAP32[$1>>2]|0;
  $26 = (($25) + 4|0);
  $27 = HEAP32[$7>>2]|0;
  $28 = ($26>>>0)>($27>>>0);
  if ($28) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$30,4);
  } else {
   $29 = HEAP32[$25>>2]|0;
   HEAP32[$30>>2] = $29;
   HEAP32[$1>>2] = $26;
  }
  $31 = (($30) + 4|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$31,0);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
  $32 = (($30) + 16|0);
  $33 = ($32|0)==($22|0);
  if ($33) {
   break;
  } else {
   $30 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13setIjNS2_4lessIjEENS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $1 = sp + 8|0;
 $size = sp;
 $p = sp + 4|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$size>>2] = $8;
  HEAP32[$2>>2] = $4;
 }
 $9 = (($data) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($data,$10);
 $11 = (($data) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (($data) + 4|0);
 HEAP32[$data>>2] = $12;
 HEAP32[$12>>2] = 0;
 $13 = HEAP32[$size>>2]|0;
 $14 = ($13|0)>(0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $i$01 = 0;
 while(1) {
  $15 = HEAP32[$2>>2]|0;
  $16 = (($15) + 4|0);
  $17 = HEAP32[$5>>2]|0;
  $18 = ($16>>>0)>($17>>>0);
  if ($18) {
   __ZN12CachedReader15UpdateReadCacheEPvj($2,$p,4);
  } else {
   $19 = HEAP32[$15>>2]|0;
   HEAP32[$p>>2] = $19;
   HEAP32[$2>>2] = $16;
  }
  __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE15__insert_uniqueERKj($1,$data,$p);
  $20 = (($i$01) + 1)|0;
  $21 = HEAP32[$size>>2]|0;
  $22 = ($20|0)<($21|0);
  if ($22) {
   $i$01 = $20;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14SubstanceValue8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $25 = (($this) + 16|0);
  __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$transfer);
  STACKTOP = sp;return;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (($this) + 16|0);
  __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI16SubstanceArchiveE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI17ProceduralTextureENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4PPtrI17ProceduralTextureENS0_9allocatorIS4_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI17ProceduralTextureE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI17ProceduralTextureE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18ProceduralMaterial8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $m_MaximumSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $m_MaximumSize = sp + 4|0;
 $1 = sp + 8|0;
 __ZN5Unity8Material8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $2 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,2)|0);
 if ($2) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$m_MaximumSize,611096,0);
  $3 = HEAP32[$m_MaximumSize>>2]|0;
  $4 = (($this) + 176|0);
  HEAP32[$4>>2] = $3;
  $5 = (($this) + 180|0);
  HEAP32[$5>>2] = $3;
 } else {
  $6 = (($this) + 176|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$6,611112,0);
  $7 = (($this) + 180|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$7,611120,0);
 }
 $8 = (($this) + 184|0);
 $9 = HEAP32[580544>>2]|0;
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611136,$9,$$byval_copy2,0)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ($10|0)>(0);
  do {
   if ($12) {
    $13 = (($transfer) + 12|0);
    $14 = (($transfer) + 80|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($15) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($transfer) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($transfer) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($transfer) + 32|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $21)|0;
    $$sum$i$i$i$i$i = (($17) - ($24))|0;
    $25 = (($19) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$13>>2] = $25;
    $26 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($26)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $27 = (($19) + ($$sum1$i$i$i$i$i)|0);
     $28 = (($transfer) + 20|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27>>>0)>($29>>>0);
     if (!($30)) {
      $31 = HEAP8[$25>>0]|0;
      HEAP8[$8>>0] = $31;
      $32 = HEAP32[$13>>2]|0;
      $33 = (($32) + 1|0);
      HEAP32[$13>>2] = $33;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($13,$8,1);
   } else {
    $34 = HEAP32[$$byval_copy2>>2]|0;
    $35 = ($34|0)==(0|0);
    if (!($35)) {
     (FUNCTION_TABLE_iii[$34 & 4095]($8,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $36 = (($transfer) + 136|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  HEAP8[$8>>0] = 1;
 }
 $39 = (($this) + 188|0);
 $40 = HEAP32[580760>>2]|0;
 $41 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611160,$40,$$byval_copy2,1)|0);
 $42 = ($41|0)==(0);
 if (!($42)) {
  $43 = ($41|0)>(0);
  if ($43) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI17ProceduralTextureENS1_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$39,0);
  } else {
   $44 = HEAP32[$$byval_copy2>>2]|0;
   $45 = ($44|0)==(0|0);
   if (!($45)) {
    (FUNCTION_TABLE_iii[$44 & 4095]($39,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $46 = (($this) + 260|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$46,611176,0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 & 1;
 $49 = (($this) + 264|0);
 HEAP32[$49>>2] = $48;
 $50 = $47 & -65538;
 HEAP32[$46>>2] = $50;
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$49,611184,0);
 $51 = (($this) + 152|0);
 $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611208,611688,$$byval_copy2,1)|0);
 $53 = ($52|0)==(0);
 if (!($53)) {
  $54 = ($52|0)>(0);
  if ($54) {
   __ZN4PPtrI16SubstanceArchiveE8TransferI14SafeBinaryReadEEvRT_($51,$transfer);
  } else {
   $55 = HEAP32[$$byval_copy2>>2]|0;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    (FUNCTION_TABLE_iii[$55 & 4095]($51,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $57 = (($this) + 212|0);
 $58 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611232,$40,$$byval_copy2,1)|0);
 $59 = ($58|0)==(0);
 if (!($59)) {
  $60 = ($58|0)>(0);
  if ($60) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI14SubstanceInputNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$57,0);
  } else {
   $61 = HEAP32[$$byval_copy2>>2]|0;
   $62 = ($61|0)==(0|0);
   if (!($62)) {
    (FUNCTION_TABLE_iii[$61 & 4095]($57,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $63 = (($this) + 164|0);
 $64 = HEAP32[580712>>2]|0;
 $65 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611248,$64,$$byval_copy2,0)|0);
 $66 = ($65|0)==(0);
 if (!($66)) {
  $67 = ($65|0)>(0);
  if ($67) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$63,0);
  } else {
   $68 = HEAP32[$$byval_copy2>>2]|0;
   $69 = ($68|0)==(0|0);
   if (!($69)) {
    (FUNCTION_TABLE_iii[$68 & 4095]($63,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $70 = HEAP8[$63>>0]|0;
 $71 = $70 & 1;
 $72 = ($71<<24>>24)==(0);
 if ($72) {
  $75 = $70&255;
  $76 = $75 >>> 1;
  $78 = $76;
 } else {
  $73 = (($this) + 168|0);
  $74 = HEAP32[$73>>2]|0;
  $78 = $74;
 }
 $77 = ($78|0)==(0);
 do {
  if ($77) {
   $79 = HEAP32[$this>>2]|0;
   $80 = (($79) + 32|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (FUNCTION_TABLE_ii[$81 & 4095]($this)|0);
   $83 = (_strlen(($82|0))|0);
   $84 = ($83>>>0)>(2147483631);
   if ($84) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $85 = ($83>>>0)<(11);
   if ($85) {
    $86 = $83 << 1;
    $87 = $86&255;
    HEAP8[$1>>0] = $87;
    $88 = (($1) + 1|0);
    $__p$0$i$i$i$i = $88;
   } else {
    $89 = (($83) + 16)|0;
    $90 = $89 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $91 = (__Z15malloc_internaljj10MemLabelIdiPKci($90,16,$$byval_copy2,0,611088,79)|0);
    $92 = (($1) + 8|0);
    HEAP32[$92>>2] = $91;
    $93 = $90 | 1;
    HEAP32[$1>>2] = $93;
    $94 = (($1) + 4|0);
    HEAP32[$94>>2] = $83;
    $__p$0$i$i$i$i = $91;
   }
   _memcpy(($__p$0$i$i$i$i|0),($82|0),($83|0))|0;
   $95 = (($__p$0$i$i$i$i) + ($83)|0);
   HEAP8[$95>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($63|0),($1|0))|0);
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if (!($97)) {
    $98 = HEAP8[$1>>0]|0;
    $99 = $98 & 1;
    $100 = ($99<<24>>24)==(0);
    if ($100) {
     break;
    }
    $101 = (($1) + 8|0);
    $102 = HEAP32[$101>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($102|0),($$byval_copy2|0));
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if (!($104)) {
     break;
    }
    $105 = ___cxa_find_matching_catch()|0;
    $106 = tempRet0;
    ___cxa_call_unexpected(($105|0));
    // unreachable;
   }
   $107 = ___cxa_find_matching_catch()|0;
   $108 = tempRet0;
   $109 = HEAP8[$1>>0]|0;
   $110 = $109 & 1;
   $111 = ($110<<24>>24)==(0);
   if ($111) {
    ___resumeException($107|0);
    // unreachable;
   }
   $112 = (($1) + 8|0);
   $113 = HEAP32[$112>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($113|0),($$byval_copy2|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if ($115) {
    $116 = ___cxa_find_matching_catch()|0;
    $117 = tempRet0;
    ___cxa_call_unexpected(($116|0));
    // unreachable;
   } else {
    ___resumeException($107|0);
    // unreachable;
   }
  }
 } while(0);
 $118 = (($this) + 252|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$118,611264,0);
 $119 = (($this) + 224|0);
 $120 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611288,611600,$$byval_copy2,1)|0);
 $121 = ($120|0)==(0);
 if ($121) {
  STACKTOP = sp;return;
 }
 $122 = ($120|0)>(0);
 if ($122) {
  __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($119,$transfer);
 } else {
  $123 = HEAP32[$$byval_copy2>>2]|0;
  $124 = ($123|0)==(0|0);
  if (!($124)) {
   (FUNCTION_TABLE_iii[$123 & 4095]($119,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI14SubstanceInputNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 7;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,611608,611608,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI14SubstanceInputNS0_9allocatorIS2_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,611296,611672,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN14SubstanceInput8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 128|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,611296,611672,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN14SubstanceInput8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 128|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SubstanceInput8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i7 = 0, $converter$i$i8 = 0, $i$01$i$i = 0, $p$i$i = 0, $size$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i8 = sp + 16|0;
 $size$i$i = sp;
 $p$i$i = sp + 4|0;
 $converter$i$i7 = sp + 8|0;
 $0 = HEAP32[580712>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611304,$0,$converter$i$i8,0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i8>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 12|0);
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611312,$0,$converter$i$i8,0)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  if ($9) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$6,0);
  } else {
   $10 = HEAP32[$converter$i$i8>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    (FUNCTION_TABLE_iii[$10 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $12 = (($this) + 24|0);
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611320,$0,$converter$i$i8,0)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$12,0);
  } else {
   $16 = HEAP32[$converter$i$i8>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    (FUNCTION_TABLE_iii[$16 & 4095]($12,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $18 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$18,611328,0);
 $19 = (($this) + 40|0);
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611336,611640,$converter$i$i8,1)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = ($20|0)>(0);
  if ($22) {
   __ZN14SubstanceValue8TransferI14SafeBinaryReadEEvRT_($19,$transfer);
  } else {
   $23 = HEAP32[$converter$i$i8>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    (FUNCTION_TABLE_iii[$23 & 4095]($19,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $25 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$25,611344,0);
 $26 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$26,611360,0);
 $27 = (($this) + 68|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$27,611376,0);
 $28 = (($this) + 76|0);
 $29 = HEAP32[580760>>2]|0;
 $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611400,$29,$converter$i$i8,1)|0);
 $31 = ($30|0)==(0);
 if (!($31)) {
  $32 = ($30|0)>(0);
  if ($32) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$28,0);
  } else {
   $33 = HEAP32[$converter$i$i8>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    (FUNCTION_TABLE_iii[$33 & 4095]($28,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $35 = (($this) + 88|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$35,611416,0);
 $36 = (($this) + 92|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$36,611424,0);
 $37 = (($this) + 96|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$37,611432,0);
 $38 = (($this) + 112|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$38,611440,0);
 $39 = (($this) + 116|0);
 $40 = HEAP32[580664>>2]|0;
 $41 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611448,$40,$converter$i$i7,1)|0);
 $42 = ($41|0)==(0);
 if (!($42)) {
  $43 = ($41|0)>(0);
  if ($43) {
   $44 = (($this) + 124|0);
   $45 = HEAP32[$44>>2]|0;
   HEAP32[$size$i$i>>2] = $45;
   $46 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($transfer,611608,611608,$size$i$i)|0);
   if ($46) {
    $47 = (($this) + 120|0);
    $48 = HEAP32[$47>>2]|0;
    __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE7destroyEPNS_11__tree_nodeIjPvEE($39,$48);
    HEAP32[$44>>2] = 0;
    $49 = (($this) + 120|0);
    HEAP32[$39>>2] = $49;
    HEAP32[$49>>2] = 0;
    $50 = HEAP32[$size$i$i>>2]|0;
    $51 = ($50|0)>(0);
    if ($51) {
     $i$01$i$i = 0;
     while(1) {
      __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$p$i$i,611296,0);
      __ZNSt3__16__treeIjNS_4lessIjEENS_9allocatorIjEEE15__insert_uniqueERKj($converter$i$i8,$39,$p$i$i);
      $52 = (($i$01$i$i) + 1)|0;
      $53 = HEAP32[$size$i$i>>2]|0;
      $54 = ($52|0)<($53|0);
      if ($54) {
       $i$01$i$i = $52;
      } else {
       break;
      }
     }
    }
    __ZN14SafeBinaryRead16EndArrayTransferEv($transfer);
   }
  } else {
   $55 = HEAP32[$converter$i$i7>>2]|0;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    (FUNCTION_TABLE_iii[$55 & 4095]($39,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $57 = (($this) + 100|0);
 $58 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611472,$29,$converter$i$i8,1)|0);
 $59 = ($58|0)==(0);
 if ($59) {
  $63 = HEAP32[$38>>2]|0;
  $64 = $63 & -13;
  $65 = $64 | 8;
  HEAP32[$38>>2] = $65;
  STACKTOP = sp;return;
 }
 $60 = ($58|0)>(0);
 if ($60) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$57,0);
 } else {
  $61 = HEAP32[$converter$i$i8>>2]|0;
  $62 = ($61|0)==(0|0);
  if (!($62)) {
   (FUNCTION_TABLE_iii[$61 & 4095]($57,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $63 = HEAP32[$38>>2]|0;
 $64 = $63 & -13;
 $65 = $64 | 8;
 HEAP32[$38>>2] = $65;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI17SubstanceEnumItemNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i$i$i2 = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,611608,611608,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI17SubstanceEnumItemNS0_9allocatorIS2_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,611296,611616,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $28 = HEAP32[580712>>2]|0;
      $30 = 0;$33 = $23;$49 = $26;
      while(1) {
       $29 = Math_imul($30, $19)|0;
       $31 = (($29) + ($25))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$20>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$49,611336,0);
       $50 = (($49) + 4|0);
       $51 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,611488,$28,$converter$i$i$i$i2,0)|0);
       $52 = ($51|0)==(0);
       if (!($52)) {
        $53 = ($51|0)>(0);
        if ($53) {
         __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$50,0);
        } else {
         $54 = HEAP32[$converter$i$i$i$i2>>2]|0;
         $55 = ($54|0)==(0|0);
         if (!($55)) {
          (FUNCTION_TABLE_iii[$54 & 4095]($50,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $56 = (($49) + 16|0);
       $57 = ($56|0)==($11|0);
       if ($57) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre10 = HEAP32[$$pre>>2]|0;
       $$pre11 = HEAP32[$15>>2]|0;
       $30 = $$pre10;$33 = $$pre11;$49 = $56;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $58 = HEAP32[$data>>2]|0;
   $59 = ($58|0)==($11|0);
   if (!($59)) {
    $60 = HEAP32[580712>>2]|0;
    $64 = $58;
    while(1) {
     $61 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,611296,611616,$converter$i$i,1)|0);
     $62 = ($61|0)==(0);
     if (!($62)) {
      $63 = ($61|0)>(0);
      if ($63) {
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$64,611336,0);
       $65 = (($64) + 4|0);
       $66 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,611488,$60,$converter$i$i$i$i2,0)|0);
       $67 = ($66|0)==(0);
       if (!($67)) {
        $68 = ($66|0)>(0);
        if ($68) {
         __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$65,0);
        } else {
         $69 = HEAP32[$converter$i$i$i$i2>>2]|0;
         $70 = ($69|0)==(0|0);
         if (!($70)) {
          (FUNCTION_TABLE_iii[$69 & 4095]($65,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $71 = HEAP32[$converter$i$i>>2]|0;
       $72 = ($71|0)==(0|0);
       if (!($72)) {
        (FUNCTION_TABLE_iii[$71 & 4095]($64,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $73 = (($64) + 16|0);
     $74 = ($73|0)==($11|0);
     if ($74) {
      break;
     } else {
      $64 = $73;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SubstanceValue8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$this,611496,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,611512,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,611528,0);
 $2 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$2,611544,0);
 $3 = (($this) + 16|0);
 $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,611560,611656,$converter$i$i,1)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ($4|0)>(0);
 if ($6) {
  __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($3,$transfer);
 } else {
  $7 = HEAP32[$converter$i$i>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   (FUNCTION_TABLE_iii[$7 & 4095]($3,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN4PPtrI16SubstanceArchiveE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,611568,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,611584,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,611568,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,611584,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI17ProceduralTextureENS1_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,611608,611608,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4PPtrI17ProceduralTextureENS0_9allocatorIS4_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,611296,611712,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4PPtrI17ProceduralTextureE8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 4|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,611296,611712,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4PPtrI17ProceduralTextureE8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 4|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI17ProceduralTextureE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,611568,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,611584,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,611568,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,611584,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18ProceduralMaterial8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $p$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy2 = sp;
 $0 = sp + 32|0;
 $p$i$i = sp + 16|0;
 $1 = sp + 20|0;
 __ZN5Unity8Material8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $2 = (($this) + 176|0);
 $3 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611112,$3,$2,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 180|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611120,$3,$10,0);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$7>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 184|0);
 $16 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611136,$16,$15,0);
 $17 = HEAP32[$4>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$7>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $21 = (($this) + 188|0);
 $22 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611160,$22,$21,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,611608,611608,$0,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611296,611712,$p$i$i,0);
 $23 = (($$byval_copy2) + 8|0);
 $24 = $23;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 HEAP32[$$byval_copy2>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611568,$3,$p$i$i,1);
 $28 = HEAP32[$4>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$7>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611584,$32,$23,1);
 $33 = HEAP32[$4>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$7>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $37 = (($this) + 260|0);
 $38 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611176,$38,$37,0);
 $39 = HEAP32[$4>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$7>>2]|0;
 $42 = ((($40) + (($41*24)|0)|0) + 12|0);
 HEAP32[$42>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $43 = HEAP32[$37>>2]|0;
 $44 = $43 & -65537;
 HEAP32[$37>>2] = $44;
 $45 = (($this) + 264|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611184,$3,$45,0);
 $46 = HEAP32[$4>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$7>>2]|0;
 $49 = ((($47) + (($48*24)|0)|0) + 12|0);
 HEAP32[$49>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $50 = (($this) + 152|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611208,611688,$50,0);
 $51 = (($$byval_copy2) + 8|0);
 $52 = $51;
 $53 = $52;
 HEAP32[$53>>2] = 0;
 $54 = (($52) + 4)|0;
 $55 = $54;
 HEAP32[$55>>2] = 0;
 HEAP32[$$byval_copy2>>2] = 0;
 $56 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611568,$56,$50,1);
 $57 = HEAP32[$4>>2]|0;
 $58 = HEAP32[$57>>2]|0;
 $59 = HEAP32[$7>>2]|0;
 $60 = ((($58) + (($59*24)|0)|0) + 12|0);
 HEAP32[$60>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611584,$32,$51,1);
 $61 = HEAP32[$4>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP32[$7>>2]|0;
 $64 = ((($62) + (($63*24)|0)|0) + 12|0);
 HEAP32[$64>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $65 = (($this) + 212|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611232,$22,$65,0);
 $66 = (($0) + 40|0);
 ;HEAP32[$66+0>>2]=0|0;HEAP32[$66+4>>2]=0|0;HEAP32[$66+8>>2]=0|0;HEAP32[$66+12>>2]=0|0;HEAP32[$66+16>>2]=0|0;
 $67 = (($0) + 76|0);
 HEAP32[$67>>2] = 0;
 $68 = (($0) + 80|0);
 HEAP32[$68>>2] = 0;
 $69 = (($0) + 84|0);
 HEAP32[$69>>2] = 0;
 $70 = (($0) + 100|0);
 HEAP32[$70>>2] = 0;
 $71 = (($0) + 104|0);
 HEAP32[$71>>2] = 0;
 $72 = (($0) + 108|0);
 HEAP32[$72>>2] = 0;
 $73 = (($0) + 120|0);
 HEAP32[$73>>2] = 0;
 $74 = (($0) + 124|0);
 HEAP32[$74>>2] = 0;
 $75 = (($0) + 120|0);
 $76 = (($0) + 116|0);
 dest=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$76>>2] = $75;
 $77 = (($0) + 36|0);
 HEAP32[$77>>2] = 1;
 $78 = (($0) + 112|0);
 HEAP32[$78>>2] = 8;
 $79 = (($0) + 60|0);
 HEAP32[$79>>2] = 0;
 $80 = (($0) + 64|0);
 HEAP32[$80>>2] = 0;
 $81 = (($0) + 68|0);
 HEAP32[$81>>2] = 0;
 $82 = (($0) + 88|0);
 ;HEAP32[$66+0>>2]=0|0;HEAP32[$66+4>>2]=0|0;HEAP32[$66+8>>2]=0|0;HEAP32[$66+12>>2]=0|0;
 HEAPF32[$82>>2] = Math_fround(-3.40282346638528859812E+38);
 $83 = (($0) + 92|0);
 HEAPF32[$83>>2] = Math_fround(3.40282346638528859812E+38);
 __THREW__ = 0;
 invoke_viiiii(87,($transfer|0),(611608|0),(611608|0),($$byval_copy2|0),0);
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if (!($85)) {
  __THREW__ = 0;
  invoke_viiiii(86,($transfer|0),(611296|0),(611672|0),($0|0),0);
  $86 = __THREW__; __THREW__ = 0;
  $87 = $86&1;
  if (!($87)) {
   __THREW__ = 0;
   invoke_vii(2733,($0|0),($transfer|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if (!($89)) {
    __THREW__ = 0;
    invoke_vi(3390,($transfer|0));
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if (!($91)) {
     __THREW__ = 0;
     invoke_vi(3391,($transfer|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if (!($93)) {
      __ZN14SubstanceInputD2Ev($0);
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      $100 = (($this) + 164|0);
      $101 = HEAP32[580712>>2]|0;
      __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611248,$101,$100,0);
      __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,611608,611608,$$byval_copy2,1);
      $102 = HEAP32[580552>>2]|0;
      __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611296,$102,$0,0);
      $103 = HEAP32[$4>>2]|0;
      $104 = HEAP32[$103>>2]|0;
      $105 = HEAP32[$7>>2]|0;
      $106 = ((($104) + (($105*24)|0)|0) + 12|0);
      HEAP32[$106>>2] = 1;
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
      __ZN13ProxyTransfer5AlignEv($transfer);
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      $107 = HEAP8[$100>>0]|0;
      $108 = $107 & 1;
      $109 = ($108<<24>>24)==(0);
      if ($109) {
       $112 = $107&255;
       $113 = $112 >>> 1;
       $115 = $113;
      } else {
       $110 = (($this) + 168|0);
       $111 = HEAP32[$110>>2]|0;
       $115 = $111;
      }
      $114 = ($115|0)==(0);
      if (!($114)) {
       $155 = (($this) + 252|0);
       __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611264,$56,$155,0);
       $156 = HEAP32[$4>>2]|0;
       $157 = HEAP32[$156>>2]|0;
       $158 = HEAP32[$7>>2]|0;
       $159 = ((($157) + (($158*24)|0)|0) + 12|0);
       HEAP32[$159>>2] = 4;
       __ZN13ProxyTransfer11EndTransferEv($transfer);
       $160 = (($this) + 224|0);
       __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611288,611600,$160,0);
       __ZN7Hash1288TransferI13ProxyTransferEEvRT_($160,$transfer);
       __ZN13ProxyTransfer11EndTransferEv($transfer);
       STACKTOP = sp;return;
      }
      $116 = HEAP32[$this>>2]|0;
      $117 = (($116) + 32|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = (FUNCTION_TABLE_ii[$118 & 4095]($this)|0);
      $120 = (_strlen(($119|0))|0);
      $121 = ($120>>>0)>(2147483631);
      if ($121) {
       __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
       // unreachable;
      }
      $122 = ($120>>>0)<(11);
      if ($122) {
       $123 = $120 << 1;
       $124 = $123&255;
       HEAP8[$1>>0] = $124;
       $125 = (($1) + 1|0);
       $__p$0$i$i$i$i = $125;
      } else {
       $126 = (($120) + 16)|0;
       $127 = $126 & -16;
       HEAP32[$0>>2] = 59;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       $128 = (__Z15malloc_internaljj10MemLabelIdiPKci($127,16,$$byval_copy2,0,611088,79)|0);
       $129 = (($1) + 8|0);
       HEAP32[$129>>2] = $128;
       $130 = $127 | 1;
       HEAP32[$1>>2] = $130;
       $131 = (($1) + 4|0);
       HEAP32[$131>>2] = $120;
       $__p$0$i$i$i$i = $128;
      }
      _memcpy(($__p$0$i$i$i$i|0),($119|0),($120|0))|0;
      $132 = (($__p$0$i$i$i$i) + ($120)|0);
      HEAP8[$132>>0] = 0;
      __THREW__ = 0;
      (invoke_iii(2359,($100|0),($1|0))|0);
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       $144 = ___cxa_find_matching_catch()|0;
       $145 = tempRet0;
       $146 = HEAP8[$1>>0]|0;
       $147 = $146 & 1;
       $148 = ($147<<24>>24)==(0);
       if ($148) {
        ___resumeException($144|0);
        // unreachable;
       }
       $149 = (($1) + 8|0);
       $150 = HEAP32[$149>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($150|0),($$byval_copy2|0));
       $151 = __THREW__; __THREW__ = 0;
       $152 = $151&1;
       if ($152) {
        $153 = ___cxa_find_matching_catch()|0;
        $154 = tempRet0;
        ___cxa_call_unexpected(($153|0));
        // unreachable;
       } else {
        ___resumeException($144|0);
        // unreachable;
       }
      } else {
       $135 = HEAP8[$1>>0]|0;
       $136 = $135 & 1;
       $137 = ($136<<24>>24)==(0);
       if ($137) {
        $155 = (($this) + 252|0);
        __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611264,$56,$155,0);
        $156 = HEAP32[$4>>2]|0;
        $157 = HEAP32[$156>>2]|0;
        $158 = HEAP32[$7>>2]|0;
        $159 = ((($157) + (($158*24)|0)|0) + 12|0);
        HEAP32[$159>>2] = 4;
        __ZN13ProxyTransfer11EndTransferEv($transfer);
        $160 = (($this) + 224|0);
        __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611288,611600,$160,0);
        __ZN7Hash1288TransferI13ProxyTransferEEvRT_($160,$transfer);
        __ZN13ProxyTransfer11EndTransferEv($transfer);
        STACKTOP = sp;return;
       }
       $138 = (($1) + 8|0);
       $139 = HEAP32[$138>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($139|0),($$byval_copy2|0));
       $140 = __THREW__; __THREW__ = 0;
       $141 = $140&1;
       if ($141) {
        $142 = ___cxa_find_matching_catch()|0;
        $143 = tempRet0;
        ___cxa_call_unexpected(($142|0));
        // unreachable;
       } else {
        $155 = (($this) + 252|0);
        __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611264,$56,$155,0);
        $156 = HEAP32[$4>>2]|0;
        $157 = HEAP32[$156>>2]|0;
        $158 = HEAP32[$7>>2]|0;
        $159 = ((($157) + (($158*24)|0)|0) + 12|0);
        HEAP32[$159>>2] = 4;
        __ZN13ProxyTransfer11EndTransferEv($transfer);
        $160 = (($this) + 224|0);
        __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611288,611600,$160,0);
        __ZN7Hash1288TransferI13ProxyTransferEEvRT_($160,$transfer);
        __ZN13ProxyTransfer11EndTransferEv($transfer);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $94 = ___cxa_find_matching_catch()|0;
 $95 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3495,($0|0));
 $96 = __THREW__; __THREW__ = 0;
 $97 = $96&1;
 if ($97) {
  $98 = ___cxa_find_matching_catch(0|0)|0;
  $99 = tempRet0;
  ___clang_call_terminate($98);
  // unreachable;
 } else {
  ___resumeException($94|0);
  // unreachable;
 }
}
function __ZN14SubstanceInput8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $p$i$i$i$i18 = 0, $p$i$i$i8 = 0, $size$i = 0, $size$i$i$i$i$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy3 = sp + 32|0;
 $size$i$i$i$i$i17 = sp;
 $p$i$i$i$i18 = sp + 36|0;
 $size$i = sp + 8|0;
 $0 = sp + 12|0;
 $p$i$i$i8 = sp + 16|0;
 $1 = sp + 4|0;
 $2 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611304,$2,$this,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,611608,611608,$$byval_copy3,1);
 $3 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611296,$3,$size$i$i$i$i$i17,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611312,$2,$10,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,611608,611608,$$byval_copy3,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611296,$3,$size$i$i$i$i$i17,0);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$7>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611320,$2,$15,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,611608,611608,$$byval_copy3,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611296,$3,$size$i$i$i$i$i17,0);
 $16 = HEAP32[$4>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$7>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 36|0);
 $21 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611328,$21,$20,0);
 $22 = HEAP32[$4>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$7>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $26 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611336,611640,$26,0);
 __ZN14SubstanceValue8TransferI13ProxyTransferEEvRT_($26,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $27 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611344,$21,$27,0);
 $28 = HEAP32[$4>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$7>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = (($this) + 64|0);
 $33 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611360,$33,$32,0);
 $34 = HEAP32[$4>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$7>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($this) + 68|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611376,$33,$38,0);
 $39 = HEAP32[$4>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$7>>2]|0;
 $42 = ((($40) + (($41*24)|0)|0) + 12|0);
 HEAP32[$42>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $43 = (($this) + 76|0);
 $44 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611400,$44,$43,0);
 ;HEAP32[$p$i$i$i8+0>>2]=0|0;HEAP32[$p$i$i$i8+4>>2]=0|0;HEAP32[$p$i$i$i8+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiii(87,($transfer|0),(611608|0),(611608|0),($size$i|0),0);
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if (!($46)) {
  $47 = HEAP32[580712>>2]|0;
  __THREW__ = 0;
  invoke_viiiii(86,($transfer|0),(611296|0),($47|0),($p$i$i$i8|0),0);
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  if (!($49)) {
   __THREW__ = 0;
   invoke_viiiii(87,($transfer|0),(611608|0),(611608|0),($size$i$i$i$i$i17|0),1);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if (!($51)) {
    $52 = HEAP32[580552>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($transfer|0),(611296|0),($52|0),($p$i$i$i$i18|0),0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     $55 = HEAP32[$4>>2]|0;
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$7>>2]|0;
     $58 = ((($56) + (($57*24)|0)|0) + 12|0);
     HEAP32[$58>>2] = 1;
     __THREW__ = 0;
     invoke_vi(3390,($transfer|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if (!($60)) {
      __THREW__ = 0;
      invoke_vi(3391,($transfer|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if (!($62)) {
       __THREW__ = 0;
       invoke_vi(3392,($transfer|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if (!($64)) {
        __THREW__ = 0;
        invoke_vi(3390,($transfer|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if (!($66)) {
         __THREW__ = 0;
         invoke_vi(3391,($transfer|0));
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if (!($68)) {
          $69 = HEAP8[$p$i$i$i8>>0]|0;
          $70 = $69 & 1;
          $71 = ($70<<24>>24)==(0);
          if (!($71)) {
           $72 = (($p$i$i$i8) + 8|0);
           $73 = HEAP32[$72>>2]|0;
           HEAP32[$1>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
           invoke_vii(2591,($73|0),($$byval_copy3|0));
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if ($75) {
            $76 = ___cxa_find_matching_catch()|0;
            $77 = tempRet0;
            ___cxa_call_unexpected(($76|0));
            // unreachable;
           }
          }
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          $89 = (($this) + 88|0);
          $90 = HEAP32[580584>>2]|0;
          __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611416,$90,$89,0);
          $91 = HEAP32[$4>>2]|0;
          $92 = HEAP32[$91>>2]|0;
          $93 = HEAP32[$7>>2]|0;
          $94 = ((($92) + (($93*24)|0)|0) + 12|0);
          HEAP32[$94>>2] = 4;
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          $95 = (($this) + 92|0);
          __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611424,$90,$95,0);
          $96 = HEAP32[$4>>2]|0;
          $97 = HEAP32[$96>>2]|0;
          $98 = HEAP32[$7>>2]|0;
          $99 = ((($97) + (($98*24)|0)|0) + 12|0);
          HEAP32[$99>>2] = 4;
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          $100 = (($this) + 96|0);
          __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611432,$90,$100,0);
          $101 = HEAP32[$4>>2]|0;
          $102 = HEAP32[$101>>2]|0;
          $103 = HEAP32[$7>>2]|0;
          $104 = ((($102) + (($103*24)|0)|0) + 12|0);
          HEAP32[$104>>2] = 4;
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          $105 = (($this) + 112|0);
          __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611440,$33,$105,0);
          $106 = HEAP32[$4>>2]|0;
          $107 = HEAP32[$106>>2]|0;
          $108 = HEAP32[$7>>2]|0;
          $109 = ((($107) + (($108*24)|0)|0) + 12|0);
          HEAP32[$109>>2] = 4;
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          $110 = (($this) + 116|0);
          $111 = HEAP32[580664>>2]|0;
          __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611448,$111,$110,0);
          __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,611608,611608,$$byval_copy3,0);
          __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611296,$33,$size$i$i$i$i$i17,0);
          $112 = HEAP32[$4>>2]|0;
          $113 = HEAP32[$112>>2]|0;
          $114 = HEAP32[$7>>2]|0;
          $115 = ((($113) + (($114*24)|0)|0) + 12|0);
          HEAP32[$115>>2] = 4;
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          $116 = (($this) + 100|0);
          __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611472,$44,$116,0);
          $117 = (($p$i$i$i8) + 4|0);
          ;HEAP32[$117+0>>2]=0|0;HEAP32[$117+4>>2]=0|0;HEAP32[$117+8>>2]=0|0;
          __THREW__ = 0;
          invoke_viiiii(87,($transfer|0),(611608|0),(611608|0),($size$i|0),0);
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          do {
           if (!($119)) {
            __THREW__ = 0;
            invoke_viiiii(86,($transfer|0),(611296|0),(611616|0),($p$i$i$i8|0),0);
            $120 = __THREW__; __THREW__ = 0;
            $121 = $120&1;
            if (!($121)) {
             __THREW__ = 0;
             invoke_viiiii(86,($transfer|0),(611336|0),($21|0),($p$i$i$i8|0),0);
             $122 = __THREW__; __THREW__ = 0;
             $123 = $122&1;
             if (!($123)) {
              $124 = HEAP32[$4>>2]|0;
              $125 = HEAP32[$124>>2]|0;
              $126 = HEAP32[$7>>2]|0;
              $127 = ((($125) + (($126*24)|0)|0) + 12|0);
              HEAP32[$127>>2] = 4;
              __THREW__ = 0;
              invoke_vi(3390,($transfer|0));
              $128 = __THREW__; __THREW__ = 0;
              $129 = $128&1;
              if (!($129)) {
               __THREW__ = 0;
               invoke_viiiii(86,($transfer|0),(611488|0),($47|0),($117|0),0);
               $130 = __THREW__; __THREW__ = 0;
               $131 = $130&1;
               if (!($131)) {
                __THREW__ = 0;
                invoke_viiiii(87,($transfer|0),(611608|0),(611608|0),($size$i$i$i$i$i17|0),1);
                $132 = __THREW__; __THREW__ = 0;
                $133 = $132&1;
                if (!($133)) {
                 __THREW__ = 0;
                 invoke_viiiii(86,($transfer|0),(611296|0),($52|0),($p$i$i$i$i18|0),0);
                 $134 = __THREW__; __THREW__ = 0;
                 $135 = $134&1;
                 if (!($135)) {
                  $136 = HEAP32[$4>>2]|0;
                  $137 = HEAP32[$136>>2]|0;
                  $138 = HEAP32[$7>>2]|0;
                  $139 = ((($137) + (($138*24)|0)|0) + 12|0);
                  HEAP32[$139>>2] = 1;
                  __THREW__ = 0;
                  invoke_vi(3390,($transfer|0));
                  $140 = __THREW__; __THREW__ = 0;
                  $141 = $140&1;
                  if (!($141)) {
                   __THREW__ = 0;
                   invoke_vi(3391,($transfer|0));
                   $142 = __THREW__; __THREW__ = 0;
                   $143 = $142&1;
                   if ($143) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3392,($transfer|0));
                   $144 = __THREW__; __THREW__ = 0;
                   $145 = $144&1;
                   if ($145) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3390,($transfer|0));
                   $146 = __THREW__; __THREW__ = 0;
                   $147 = $146&1;
                   if ($147) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3390,($transfer|0));
                   $148 = __THREW__; __THREW__ = 0;
                   $149 = $148&1;
                   if ($149) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3391,($transfer|0));
                   $150 = __THREW__; __THREW__ = 0;
                   $151 = $150&1;
                   if ($151) {
                    break;
                   }
                   $152 = HEAP8[$117>>0]|0;
                   $153 = $152 & 1;
                   $154 = ($153<<24>>24)==(0);
                   if ($154) {
                    __ZN13ProxyTransfer11EndTransferEv($transfer);
                    STACKTOP = sp;return;
                   }
                   $155 = (($p$i$i$i8) + 12|0);
                   $156 = HEAP32[$155>>2]|0;
                   HEAP32[$size$i$i$i$i$i17>>2] = 59;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$size$i$i$i$i$i17+0>>2]|0;
                   invoke_vii(2591,($156|0),($$byval_copy3|0));
                   $157 = __THREW__; __THREW__ = 0;
                   $158 = $157&1;
                   if ($158) {
                    $159 = ___cxa_find_matching_catch()|0;
                    $160 = tempRet0;
                    ___cxa_call_unexpected(($159|0));
                    // unreachable;
                   } else {
                    __ZN13ProxyTransfer11EndTransferEv($transfer);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          } while(0);
          $161 = ___cxa_find_matching_catch()|0;
          $162 = tempRet0;
          $163 = HEAP8[$117>>0]|0;
          $164 = $163 & 1;
          $165 = ($164<<24>>24)==(0);
          if ($165) {
           ___resumeException($161|0);
           // unreachable;
          }
          $166 = (($p$i$i$i8) + 12|0);
          $167 = HEAP32[$166>>2]|0;
          HEAP32[$0>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($167|0),($$byval_copy3|0));
          $168 = __THREW__; __THREW__ = 0;
          $169 = $168&1;
          if ($169) {
           $170 = ___cxa_find_matching_catch()|0;
           $171 = tempRet0;
           ___cxa_call_unexpected(($170|0));
           // unreachable;
          } else {
           ___resumeException($161|0);
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $78 = ___cxa_find_matching_catch()|0;
 $79 = tempRet0;
 $80 = HEAP8[$p$i$i$i8>>0]|0;
 $81 = $80 & 1;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  ___resumeException($78|0);
  // unreachable;
 }
 $83 = (($p$i$i$i8) + 8|0);
 $84 = HEAP32[$83>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($84|0),($$byval_copy3|0));
 $85 = __THREW__; __THREW__ = 0;
 $86 = $85&1;
 if ($86) {
  $87 = ___cxa_find_matching_catch()|0;
  $88 = tempRet0;
  ___cxa_call_unexpected(($87|0));
  // unreachable;
 } else {
  ___resumeException($78|0);
  // unreachable;
 }
}
function __ZN14SubstanceValue8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611496,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611512,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611528,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611544,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611560,611656,$22,0);
 $23 = (($localIdentifier$i$i$i) + 8|0);
 $24 = $23;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $28 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611568,$28,$22,1);
 $29 = HEAP32[$1>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$4>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,611584,$33,$23,1);
 $34 = HEAP32[$1>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$4>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18ProceduralMaterialD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i12 = 0, $__new_last2$i$i$i$i$i5 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i13 = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $scevgep4$i$i$i$i$i17 = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i15 = 0, $uglygep$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i16 = 0, $uglygep3$i$i$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((610984 + 8|0));
 $1 = (($this) + 240|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 244|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($2|0);
  if (!($6)) {
   $__new_last2$i$i$i$i$i = $2;
   $scevgep$i$i$i$i$i = (($5) + -16|0);
   $7 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($7)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $8 = $uglygep3$i$i$i$i$i >>> 4;
   $9 = $8 ^ -1;
   $scevgep4$i$i$i$i$i = (($5) + ($9<<4)|0);
   HEAP32[$4>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($2);
 }
 $10 = (($this) + 212|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 do {
  if (!($12)) {
   $13 = (($this) + 216|0);
   while(1) {
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($11|0);
    if ($15) {
     label = 10;
     break;
    }
    $16 = (($14) + -128|0);
    HEAP32[$13>>2] = $16;
    __THREW__ = 0;
    invoke_vi(3495,($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 9;
     break;
    }
   }
   if ((label|0) == 9) {
    $19 = ___cxa_find_matching_catch()|0;
    $20 = tempRet0;
    ___cxa_call_unexpected(($19|0));
    // unreachable;
   }
   else if ((label|0) == 10) {
    $21 = HEAP32[$10>>2]|0;
    __ZdlPv($21);
    break;
   }
  }
 } while(0);
 $22 = (($this) + 200|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (($this) + 204|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==($23|0);
  if (!($27)) {
   $__new_last2$i$i$i$i$i5 = $23;
   $scevgep$i$i$i$i$i6 = (($26) + -4|0);
   $28 = (0 - ($__new_last2$i$i$i$i$i5))|0;
   $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($28)|0);
   $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
   $29 = $uglygep3$i$i$i$i$i9 >>> 2;
   $30 = $29 ^ -1;
   $scevgep4$i$i$i$i$i10 = (($26) + ($30<<2)|0);
   HEAP32[$25>>2] = $scevgep4$i$i$i$i$i10;
  }
  __ZdlPv($23);
 }
 $31 = (($this) + 188|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = (($this) + 192|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==($32|0);
  if (!($36)) {
   $__new_last2$i$i$i$i$i12 = $32;
   $scevgep$i$i$i$i$i13 = (($35) + -4|0);
   $37 = (0 - ($__new_last2$i$i$i$i$i12))|0;
   $uglygep$i$i$i$i$i15 = (($scevgep$i$i$i$i$i13) + ($37)|0);
   $uglygep3$i$i$i$i$i16 = $uglygep$i$i$i$i$i15;
   $38 = $uglygep3$i$i$i$i$i16 >>> 2;
   $39 = $38 ^ -1;
   $scevgep4$i$i$i$i$i17 = (($35) + ($39<<2)|0);
   HEAP32[$34>>2] = $scevgep4$i$i$i$i$i17;
  }
  __ZdlPv($32);
 }
 $40 = (($this) + 164|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41 & 1;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  __ZN5Unity8MaterialD2Ev($this);
  STACKTOP = sp;return;
 }
 $44 = (($this) + 172|0);
 $45 = HEAP32[$44>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($45|0),($$byval_copy|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 } else {
  __ZN5Unity8MaterialD2Ev($this);
  STACKTOP = sp;return;
 }
}
function __ZN5Unity8MaterialD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity8MaterialD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN5Unity8MaterialD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3496,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __Z14InitGUIManagerv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(100)|0);
 $1 = (($0) + 4|0);
 HEAP32[$0>>2] = $0;
 HEAP32[$1>>2] = $0;
 $2 = (($0) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($0) + 16|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($0) + 20|0);
 HEAP32[$4>>2] = $4;
 $5 = (($0) + 24|0);
 HEAP32[$5>>2] = $4;
 $6 = (($0) + 28|0);
 HEAP32[$6>>2] = 0;
 $7 = (($0) + 40|0);
 $8 = (($0) + 76|0);
 HEAP32[$8>>2] = 0;
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
 $9 = (($0) + 80|0);
 __THREW__ = 0;
 invoke_vi(3497,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $19 = (($0) + 32|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = (($0) + 9|0);
  HEAP8[$20>>0] = 0;
  $21 = (($0) + 8|0);
  HEAP8[$21>>0] = 0;
  HEAP32[611736>>2] = $0;
  __Z12InitGUIStatev();
  STACKTOP = sp;return;
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $14 = (($0) + 36|0);
 __THREW__ = 0;
 invoke_vi(3498,($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  __ZNSt3__110__list_impIN10GUIManager12SortedScriptE11memory_poolIS2_EE5clearEv($4);
  __ZdlPv($0);
  ___resumeException($12|0);
  // unreachable;
 }
}
function __Z13GetGUIManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[611736>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN10GUIManager12AddGUIScriptER8ListNodeI13MonoBehaviourE($this,$beh) {
 $this = $this|0;
 $beh = $beh|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($beh|0)==($this|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$beh>>2]|0;
 $2 = ($1|0)==(0|0);
 $$pre$i$i = (($beh) + 4|0);
 if (!($2)) {
  $3 = HEAP32[$$pre$i$i>>2]|0;
  $4 = (($1) + 4|0);
  HEAP32[$4>>2] = $3;
  $5 = HEAP32[$beh>>2]|0;
  $6 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$6>>2] = $5;
  HEAP32[$beh>>2] = 0;
  HEAP32[$$pre$i$i>>2] = 0;
 }
 $7 = HEAP32[$this>>2]|0;
 HEAP32[$beh>>2] = $7;
 HEAP32[$$pre$i$i>>2] = $this;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $beh;
 $9 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$9>>2] = $beh;
 STACKTOP = sp;return;
}
function __ZN10GUIManager7RepaintEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ie = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $ie = sp;
 $0 = (__Z15GetInputManagerv()|0);
 $1 = (($0) + 156|0);
 HEAP8[$1>>0] = 0;
 $2 = (($ie) + 4|0);
 $3 = (($ie) + 40|0);
 HEAP32[$3>>2] = 0;
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 $4 = (($this) + 36|0);
 __THREW__ = 0;
 invoke_vii(2734,($ie|0),($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[$ie>>2] = 7;
  __THREW__ = 0;
  invoke_viii(1758,($this|0),($ie|0),0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __ZN10InputEventD2Ev($ie);
   STACKTOP = sp;return;
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3498,($ie|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 } else {
  ___resumeException($9|0);
  // unreachable;
 }
}
function __ZN10GUIManager10DoGUIEventER10InputEventb($this,$eventToSend,$frontToBack) {
 $this = $this|0;
 $eventToSend = $eventToSend|0;
 $frontToBack = $frontToBack|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i2$i$i58 = 0, $$0$i3$i$i = 0, $$0$i3$i$i60 = 0, $$02 = 0, $$byval_copy = 0, $$byval_copy22 = 0, $$not = 0, $$not$us = 0, $$not14 = 0, $$not16 = 0, $$not94 = 0, $$off0 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i39 = 0, $$pre$i42 = 0, $$pre$i55 = 0;
 var $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i19 = 0, $__new_last2$i$i$i$i$i28 = 0, $__new_last2$i$i$i$i$i46 = 0, $brmerge = 0, $brmerge$us = 0, $brmerge15 = 0, $brmerge17 = 0, $brmerge18 = 0, $brmerge95 = 0, $current$296 = 0, $current$3103 = 0;
 var $endWindows$0$off0 = 0, $endWindows$0$off0$us = 0, $endWindows5$0$off0 = 0, $eventUsed$0$off0$ph$be = 0, $eventUsed$0$off0$ph127 = 0, $eventUsed$0$off0$ph128 = 0, $eventUsed$0$off0$ph129 = 0, $eventUsed$1$off0 = 0, $eventUsed$2$off0$lcssa = 0, $eventUsed$2$off093 = 0, $eventUsed$3$off0 = 0, $guiScriptIterator = 0, $handleTab$0 = 0, $hasSentEndWindows$0$off097 = 0, $hasSentEndWindows$0$off097$us = 0, $hasSentEndWindows$1$off0 = 0, $hasSentEndWindows$2$off0104 = 0, $hasSentEndWindows$3$off0 = 0, $keyIDLists = 0, $layoutedScripts = 0;
 var $lpad$phi$index = 0, $lpad$phi$index18 = 0, $lpad$phi120$index = 0, $lpad$phi120$index13 = 0, $lpad$phi90$index = 0, $lpad$phi90$index5 = 0, $node$0$i = 0, $node$01$i = 0, $node$03$i = 0, $or$cond = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep$i$i$i$i$i29 = 0, $scevgep$i$i$i$i$i47 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i24 = 0, $scevgep4$i$i$i$i$i33 = 0, $scevgep4$i$i$i$i$i51 = 0, $size$02$i = 0, $uglygep$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i22 = 0, $uglygep$i$i$i$i$i31 = 0, $uglygep$i$i$i$i$i49 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep3$i$i$i$i$i32 = 0, $uglygep3$i$i$i$i$i50 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy22 = sp + 104|0;
 $$byval_copy = sp + 100|0;
 $0 = sp + 96|0;
 $1 = sp + 92|0;
 $2 = sp + 88|0;
 $3 = sp;
 $layoutedScripts = sp + 76|0;
 $4 = sp + 32|0;
 $guiScriptIterator = sp + 16|0;
 $5 = sp + 4|0;
 $6 = sp + 48|0;
 $keyIDLists = sp + 64|0;
 $7 = (__Z11GetGUIStatev()|0);
 __ZN8GUIState8SetEventERK10InputEvent($7,$eventToSend);
 $8 = (($7) + 280|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 80|0);
 __ZN16GUIKeyboardState16LoadIntoGUIStateER8GUIState($10,$7);
 $11 = (__Z27GetUserAuthorizationManagerv()|0);
 $12 = (__ZN24UserAuthorizationManager22GetAuthorizationDialogEv($11)|0);
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==($this|0);
 $16 = ($12|0)==(0|0);
 $or$cond = $15 & $16;
 if ($or$cond) {
  $17 = (($this) + 8|0);
  HEAP8[$17>>0] = 0;
  STACKTOP = sp;return;
 }
 $18 = (__Z16GetScreenManagerv()|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 40|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 4095]($18)|0);
 $23 = ($22|0)==(1);
 if ($23) {
  $24 = (($9) + 4|0);
  $25 = $24;
  $26 = $25;
  HEAP32[$26>>2] = -971227136;
  $27 = (($25) + 4)|0;
  $28 = $27;
  HEAP32[$28>>2] = -971227136;
 }
 $29 = HEAP32[$9>>2]|0;
 $30 = ($29|0)==(4);
 if ($30) {
  $31 = (($9) + 36|0);
  $32 = HEAP16[$31>>1]|0;
  if ((($32<<16>>16) == 25) | (($32<<16>>16) == 9)) {
   $33 = (($9) + 24|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = $34 << 1;
   $36 = $35 & 2;
   $37 = $36 ^ 2;
   $38 = (($37) + -1)|0;
   $handleTab$0 = $38;
  } else {
   $handleTab$0 = 0;
  }
 } else {
  $handleTab$0 = 0;
 }
 HEAP32[$layoutedScripts>>2] = 0;
 $39 = (($layoutedScripts) + 4|0);
 HEAP32[$39>>2] = 0;
 $40 = (($layoutedScripts) + 8|0);
 HEAP32[$40>>2] = 0;
 L12: do {
  if ($16) {
   $node$01$i = HEAP32[$13>>2]|0;
   $53 = ($node$01$i|0)==($this|0);
   if (!($53)) {
    $node$03$i = $node$01$i;$size$02$i = 0;
    while(1) {
     $54 = (($node$03$i) + 4|0);
     $55 = (($size$02$i) + 1)|0;
     $node$0$i = HEAP32[$54>>2]|0;
     $56 = ($node$0$i|0)==($this|0);
     if ($56) {
      break;
     } else {
      $node$03$i = $node$0$i;$size$02$i = $55;
     }
    }
    $57 = ($55|0)==(0);
    if (!($57)) {
     $58 = ($55*12)|0;
     __THREW__ = 0;
     $59 = (invoke_ii(2988,($58|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 13;
      break;
     }
     $62 = (($59) + (($55*12)|0)|0);
     HEAP32[$layoutedScripts>>2] = $59;
     HEAP32[$39>>2] = $59;
     HEAP32[$40>>2] = $62;
    }
   }
   $63 = (($guiScriptIterator) + 4|0);
   $64 = (($guiScriptIterator) + 8|0);
   HEAP32[$64>>2] = $this;
   $65 = (($guiScriptIterator) + 12|0);
   HEAP32[$65>>2] = 0;
   $66 = HEAP32[$this>>2]|0;
   HEAP32[$guiScriptIterator>>2] = $66;
   $67 = HEAP32[$13>>2]|0;
   HEAP32[$13>>2] = $guiScriptIterator;
   HEAP32[$63>>2] = $67;
   HEAP32[$this>>2] = $this;
   $68 = ($66|0)==($this|0);
   if ($68) {
    HEAP32[$guiScriptIterator>>2] = $guiScriptIterator;
   }
   HEAP32[$13>>2] = $this;
   $69 = ($67|0)==($this|0);
   if ($69) {
    HEAP32[$63>>2] = $guiScriptIterator;
   }
   $70 = (($this) + 4|0);
   HEAP32[$70>>2] = $this;
   HEAP32[$this>>2] = $this;
   $71 = HEAP32[$guiScriptIterator>>2]|0;
   $72 = (($71) + 4|0);
   HEAP32[$72>>2] = $guiScriptIterator;
   $73 = HEAP32[$63>>2]|0;
   HEAP32[$73>>2] = $guiScriptIterator;
   $74 = HEAP32[$63>>2]|0;
   $75 = ($74|0)==($guiScriptIterator|0);
   L27: do {
    if ($75) {
     $eventUsed$0$off0$ph128 = 0;
     label = 33;
    } else {
     $76 = (($5) + 4|0);
     $77 = (($5) + 8|0);
     $425 = $74;$eventUsed$0$off0$ph129 = 0;
     L29: while(1) {
      $78 = $425;
      while(1) {
       HEAP32[$65>>2] = $78;
       $79 = HEAP32[$78>>2]|0;
       $80 = ($79|0)==(0|0);
       if ($80) {
        $88 = $78;
       } else {
        $81 = (($78) + 4|0);
        $82 = HEAP32[$81>>2]|0;
        $83 = (($79) + 4|0);
        HEAP32[$83>>2] = $82;
        $84 = HEAP32[$78>>2]|0;
        $85 = HEAP32[$81>>2]|0;
        HEAP32[$85>>2] = $84;
        HEAP32[$78>>2] = 0;
        HEAP32[$81>>2] = 0;
        $$pre3$i = HEAP32[$65>>2]|0;
        $88 = $$pre3$i;
       }
       $86 = HEAP32[$64>>2]|0;
       $87 = ($88|0)==($86|0);
       if ($87) {
        $99 = $88;
       } else {
        $89 = HEAP32[$88>>2]|0;
        $90 = ($89|0)==(0|0);
        $$pre$i$i$i = (($88) + 4|0);
        if (!($90)) {
         $91 = HEAP32[$$pre$i$i$i>>2]|0;
         $92 = (($89) + 4|0);
         HEAP32[$92>>2] = $91;
         $93 = HEAP32[$88>>2]|0;
         $94 = HEAP32[$$pre$i$i$i>>2]|0;
         HEAP32[$94>>2] = $93;
         HEAP32[$88>>2] = 0;
         HEAP32[$$pre$i$i$i>>2] = 0;
        }
        $95 = HEAP32[$86>>2]|0;
        HEAP32[$88>>2] = $95;
        HEAP32[$$pre$i$i$i>>2] = $86;
        $96 = (($95) + 4|0);
        HEAP32[$96>>2] = $88;
        $97 = HEAP32[$$pre$i$i$i>>2]|0;
        HEAP32[$97>>2] = $88;
        $$pre$i39 = HEAP32[$65>>2]|0;
        $99 = $$pre$i39;
       }
       $98 = ($99|0)==(0|0);
       if ($98) {
        $eventUsed$0$off0$ph127 = $eventUsed$0$off0$ph129;
        break L27;
       }
       $100 = (($99) + 8|0);
       $101 = HEAP32[$100>>2]|0;
       __THREW__ = 0;
       $102 = (invoke_ii(3253,($101|0))|0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        label = 43;
        break L29;
       }
       if (!($102)) {
        break;
       }
       HEAP32[$5>>2] = $101;
       HEAP32[$76>>2] = 1547;
       HEAP32[$77>>2] = 3252;
       $105 = HEAP32[$39>>2]|0;
       $106 = HEAP32[$40>>2]|0;
       $107 = ($105|0)==($106|0);
       if ($107) {
        __THREW__ = 0;
        invoke_vii(2735,($layoutedScripts|0),($5|0));
        $113 = __THREW__; __THREW__ = 0;
        $114 = $113&1;
        if ($114) {
         label = 43;
         break L29;
        }
       } else {
        $108 = ($105|0)==(0|0);
        if ($108) {
         $112 = 0;
        } else {
         HEAP32[$105>>2] = $101;
         $109 = (($105) + 4|0);
         HEAP32[$109>>2] = 1547;
         $110 = (($105) + 8|0);
         HEAP32[$110>>2] = 3252;
         $$pre$i42 = HEAP32[$39>>2]|0;
         $112 = $$pre$i42;
        }
        $111 = (($112) + 12|0);
        HEAP32[$39>>2] = $111;
       }
       $115 = HEAP32[$63>>2]|0;
       $116 = ($115|0)==($guiScriptIterator|0);
       if ($116) {
        $eventUsed$0$off0$ph128 = $eventUsed$0$off0$ph129;
        label = 33;
        break L27;
       } else {
        $78 = $115;
       }
      }
      if ($eventUsed$0$off0$ph129) {
       $eventUsed$0$off0$ph$be = 1;
      } else {
       $123 = HEAP32[$101>>2]|0;
       $124 = (($123) + 132|0);
       $125 = HEAP32[$124>>2]|0;
       __THREW__ = 0;
       $126 = (invoke_iiii($125|0,($101|0),0,0)|0);
       $127 = __THREW__; __THREW__ = 0;
       $128 = $127&1;
       if ($128) {
        label = 44;
        break;
       } else {
        $eventUsed$0$off0$ph$be = $126;
       }
      }
      $121 = HEAP32[$63>>2]|0;
      $122 = ($121|0)==($guiScriptIterator|0);
      if ($122) {
       $eventUsed$0$off0$ph128 = $eventUsed$0$off0$ph$be;
       label = 33;
       break L27;
      } else {
       $425 = $121;$eventUsed$0$off0$ph129 = $eventUsed$0$off0$ph$be;
      }
     }
     if ((label|0) == 43) {
      $117 = ___cxa_find_matching_catch()|0;
      $118 = tempRet0;
      $lpad$phi120$index = $117;$lpad$phi120$index13 = $118;
     }
     else if ((label|0) == 44) {
      $119 = ___cxa_find_matching_catch()|0;
      $120 = tempRet0;
      $lpad$phi120$index = $119;$lpad$phi120$index13 = $120;
     }
     HEAP32[$63>>2] = 0;
     HEAP32[$guiScriptIterator>>2] = 0;
     $$0 = $lpad$phi120$index;$$02 = $lpad$phi120$index13;
     break L12;
    }
   } while(0);
   if ((label|0) == 33) {
    HEAP32[$65>>2] = 0;
    $eventUsed$0$off0$ph127 = $eventUsed$0$off0$ph128;
   }
   HEAP32[$63>>2] = 0;
   HEAP32[$guiScriptIterator>>2] = 0;
   $eventUsed$1$off0 = $eventUsed$0$off0$ph127;
   label = 50;
  } else {
   HEAP32[$4>>2] = $12;
   $41 = (($4) + 4|0);
   HEAP32[$41>>2] = 1547;
   $42 = (($4) + 8|0);
   HEAP32[$42>>2] = 3252;
   __THREW__ = 0;
   invoke_vii(2735,($layoutedScripts|0),($4|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    label = 13;
   } else {
    $eventUsed$1$off0 = 0;
    label = 50;
   }
  }
 } while(0);
 L64: do {
  if ((label|0) == 50) {
   $129 = (($7) + 8|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    $$off0 = 0;
   } else {
    $132 = (($130) + 24|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = ($133|0)!=(0|0);
    $$off0 = $134;
   }
   $135 = (($this) + 20|0);
   __ZNSt3__110__list_impIN10GUIManager12SortedScriptE11memory_poolIS2_EE5clearEv($135);
   $136 = HEAP32[$layoutedScripts>>2]|0;
   $137 = HEAP32[$39>>2]|0;
   $138 = ($136|0)==($137|0);
   if (!($138)) {
    HEAP32[$9>>2] = 8;
    $139 = $$off0 ^ 1;
    __THREW__ = 0;
    invoke_viii(1759,($7|0),1,($139|0));
    $140 = __THREW__; __THREW__ = 0;
    $141 = $140&1;
    if ($141) {
     label = 13;
     break;
    }
    $142 = HEAP32[$layoutedScripts>>2]|0;
    $143 = HEAP32[$39>>2]|0;
    $144 = ($142|0)==($143|0);
    L72: do {
     if (!($144)) {
      $145 = (($6) + 4|0);
      $146 = (($6) + 8|0);
      $147 = (($6) + 12|0);
      $149 = $142;$426 = $143;
      while(1) {
       $148 = HEAP32[$149>>2]|0;
       $150 = (($149) + 4|0);
       $151 = HEAP32[$150>>2]|0;
       $152 = (($149) + 8|0);
       $153 = HEAP32[$152>>2]|0;
       $154 = ($148|0)==(0|0);
       if ($154) {
        $166 = $426;
       } else {
        __THREW__ = 0;
        (invoke_iiii($151|0,($148|0),1,0)|0);
        $155 = __THREW__; __THREW__ = 0;
        $156 = $155&1;
        if ($156) {
         break;
        }
        __THREW__ = 0;
        $157 = (invoke_i(86)|0);
        $158 = __THREW__; __THREW__ = 0;
        $159 = $158&1;
        if ($159) {
         break;
        }
        $160 = (($157) + 68|0);
        $161 = HEAP32[$160>>2]|0;
        HEAP32[$6>>2] = $161;
        HEAP32[$145>>2] = $148;
        HEAP32[$146>>2] = $151;
        HEAP32[$147>>2] = $153;
        __THREW__ = 0;
        invoke_vii(2736,($135|0),($6|0));
        $162 = __THREW__; __THREW__ = 0;
        $163 = $162&1;
        if ($163) {
         break;
        }
        $$pre = HEAP32[$39>>2]|0;
        $166 = $$pre;
       }
       $164 = (($149) + 12|0);
       $165 = ($164|0)==($166|0);
       if ($165) {
        break L72;
       } else {
        $149 = $164;$426 = $166;
       }
      }
      $49 = ___cxa_find_matching_catch()|0;
      $50 = tempRet0;
      $lpad$phi90$index = $49;$lpad$phi90$index5 = $50;
      label = 14;
      break L64;
     }
    } while(0);
    $167 = (($7) + 96|0);
    $168 = HEAP32[$8>>2]|0;
    __THREW__ = 0;
    invoke_vii(2737,($167|0),($168|0));
    $169 = __THREW__; __THREW__ = 0;
    $170 = $169&1;
    if ($170) {
     label = 13;
     break;
    }
    __THREW__ = 0;
    invoke_vii(2738,($7|0),($139|0));
    $171 = __THREW__; __THREW__ = 0;
    $172 = $171&1;
    if ($172) {
     label = 13;
     break;
    }
    $173 = HEAP32[$8>>2]|0;
    __THREW__ = 0;
    invoke_vii(2739,($167|0),($173|0));
    $174 = __THREW__; __THREW__ = 0;
    $175 = $174&1;
    if ($175) {
     label = 13;
     break;
    }
    $176 = (($this) + 24|0);
    $177 = HEAP32[$176>>2]|0;
    HEAP32[$0>>2] = $177;
    HEAP32[$1>>2] = $135;
    $178 = (($this) + 28|0);
    $179 = HEAP32[$178>>2]|0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
    __ZNSt3__14listIN10GUIManager12SortedScriptE11memory_poolIS2_EE6__sortI13OldSortScriptEENS_15__list_iteratorIS2_PvEESA_SA_jRT_($2,$$byval_copy,$$byval_copy22,$179,$3);
    HEAP32[$9>>2] = $29;
   }
   if ($frontToBack) {
    $180 = (($this) + 8|0);
    $181 = HEAP8[$180>>0]|0;
    $182 = $181&255;
    $183 = (($7) + 272|0);
    HEAP32[$183>>2] = $182;
    $184 = (($this) + 24|0);
    $185 = HEAP32[$184>>2]|0;
    $$not94 = ($185|0)==($135|0);
    $brmerge95 = $$not94 | $eventUsed$1$off0;
    L90: do {
     if ($brmerge95) {
      $eventUsed$2$off0$lcssa = $eventUsed$1$off0;
     } else {
      $186 = $$off0 ^ 1;
      $187 = (($this) + 28|0);
      if ($$off0) {
       $191 = $185;$hasSentEndWindows$0$off097$us = 0;
       while(1) {
        if ($hasSentEndWindows$0$off097$us) {
         $endWindows$0$off0$us = 0;
        } else {
         __THREW__ = 0;
         invoke_viii(1759,($7|0),1,($186|0));
         $188 = __THREW__; __THREW__ = 0;
         $189 = $188&1;
         if ($189) {
          break;
         } else {
          $endWindows$0$off0$us = 1;
         }
        }
        $190 = (($191) + 16|0);
        $192 = HEAP32[$190>>2]|0;
        $193 = (($191) + 12|0);
        $194 = HEAP32[$193>>2]|0;
        __THREW__ = 0;
        $195 = (invoke_iiii($192|0,($194|0),1,0)|0);
        $196 = __THREW__; __THREW__ = 0;
        $197 = $196&1;
        if ($197) {
         break;
        }
        if ($endWindows$0$off0$us) {
         __THREW__ = 0;
         invoke_vii(2738,($7|0),($186|0));
         $198 = __THREW__; __THREW__ = 0;
         $199 = $198&1;
         if ($199) {
          break;
         }
        }
        $200 = (($191) + 4|0);
        $201 = HEAP32[$200>>2]|0;
        $$not$us = ($201|0)==($135|0);
        $brmerge$us = $$not$us | $195;
        if ($brmerge$us) {
         $eventUsed$2$off0$lcssa = $195;
         break L90;
        } else {
         $191 = $201;$hasSentEndWindows$0$off097$us = 1;
        }
       }
       $202 = ___cxa_find_matching_catch()|0;
       $203 = tempRet0;
       $lpad$phi90$index = $202;$lpad$phi90$index5 = $203;
       label = 14;
       break L64;
      } else {
       $207 = $185;$current$296 = 1;$hasSentEndWindows$0$off097 = 0;
      }
      while(1) {
       $204 = HEAP32[$187>>2]|0;
       $205 = ($current$296|0)==($204|0);
       if ($205) {
        if ($hasSentEndWindows$0$off097) {
         $endWindows$0$off0 = 0;$hasSentEndWindows$1$off0 = 1;
        } else {
         label = 79;
        }
       } else {
        $206 = (($207) + 8|0);
        $208 = HEAP32[$206>>2]|0;
        $$not14 = ($208|0)<(1);
        $brmerge15 = $$not14 | $hasSentEndWindows$0$off097;
        if ($brmerge15) {
         $endWindows$0$off0 = 0;$hasSentEndWindows$1$off0 = $hasSentEndWindows$0$off097;
        } else {
         label = 79;
        }
       }
       if ((label|0) == 79) {
        label = 0;
        __THREW__ = 0;
        invoke_viii(1759,($7|0),1,($186|0));
        $209 = __THREW__; __THREW__ = 0;
        $210 = $209&1;
        if ($210) {
         break;
        } else {
         $endWindows$0$off0 = 1;$hasSentEndWindows$1$off0 = 1;
        }
       }
       $211 = (($current$296) + 1)|0;
       $212 = (($207) + 16|0);
       $213 = HEAP32[$212>>2]|0;
       $214 = (($207) + 12|0);
       $215 = HEAP32[$214>>2]|0;
       __THREW__ = 0;
       $216 = (invoke_iiii($213|0,($215|0),1,0)|0);
       $217 = __THREW__; __THREW__ = 0;
       $218 = $217&1;
       if ($218) {
        break;
       }
       if ($endWindows$0$off0) {
        __THREW__ = 0;
        invoke_vii(2738,($7|0),($186|0));
        $219 = __THREW__; __THREW__ = 0;
        $220 = $219&1;
        if ($220) {
         break;
        }
       }
       $221 = (($207) + 4|0);
       $222 = HEAP32[$221>>2]|0;
       $$not = ($222|0)==($135|0);
       $brmerge = $$not | $216;
       if ($brmerge) {
        $eventUsed$2$off0$lcssa = $216;
        break L90;
       } else {
        $207 = $222;$current$296 = $211;$hasSentEndWindows$0$off097 = $hasSentEndWindows$1$off0;
       }
      }
      $45 = ___cxa_find_matching_catch()|0;
      $46 = tempRet0;
      $lpad$phi90$index = $45;$lpad$phi90$index5 = $46;
      label = 14;
      break L64;
     }
    } while(0);
    $$not16 = ($29|0)!=(0);
    $brmerge17 = $$not16 | $eventUsed$2$off0$lcssa;
    if ($brmerge17) {
     $eventUsed$2$off093 = $eventUsed$2$off0$lcssa;
    } else {
     __THREW__ = 0;
     $223 = (invoke_i(86)|0);
     $224 = __THREW__; __THREW__ = 0;
     $225 = $224&1;
     if ($225) {
      label = 13;
      break;
     }
     HEAP32[$223>>2] = 0;
     $eventUsed$2$off093 = 0;
    }
    $226 = ($29>>>0)<(2);
    if ($226) {
     $227 = HEAP32[$183>>2]|0;
     $228 = ($227|0)!=(0);
     $229 = $228 | $eventUsed$2$off093;
     $230 = $229&1;
     HEAP32[$183>>2] = $230;
     $eventUsed$3$off0 = $eventUsed$2$off093;
    } else {
     $eventUsed$3$off0 = $eventUsed$2$off093;
    }
   } else {
    $231 = (($7) + 96|0);
    $232 = (($7) + 272|0);
    HEAP32[$232>>2] = 0;
    $233 = (($this) + 8|0);
    HEAP8[$233>>0] = 0;
    $234 = $$off0 ^ 1;
    __THREW__ = 0;
    invoke_viii(1759,($7|0),1,($234|0));
    $235 = __THREW__; __THREW__ = 0;
    $236 = $235&1;
    if ($236) {
     label = 13;
     break;
    }
    $237 = (($this) + 24|0);
    $238 = HEAP32[$237>>2]|0;
    $239 = ($135|0)==($238|0);
    L124: do {
     if (!($239)) {
      $240 = (($this) + 28|0);
      $242 = $135;$current$3103 = 1;$hasSentEndWindows$2$off0104 = 0;
      while(1) {
       $241 = HEAP32[$242>>2]|0;
       if ($hasSentEndWindows$2$off0104) {
        $endWindows5$0$off0 = 0;$hasSentEndWindows$3$off0 = 1;
       } else {
        $243 = HEAP32[$240>>2]|0;
        $244 = ($current$3103|0)==($243|0);
        if ($244) {
         $endWindows5$0$off0 = 1;$hasSentEndWindows$3$off0 = 1;
        } else {
         $245 = HEAP32[$241>>2]|0;
         $246 = (($245) + 8|0);
         $247 = HEAP32[$246>>2]|0;
         $248 = ($247|0)<(1);
         $endWindows5$0$off0 = $248;$hasSentEndWindows$3$off0 = $248;
        }
       }
       $249 = (($241) + 16|0);
       $250 = HEAP32[$249>>2]|0;
       $251 = (($241) + 12|0);
       $252 = HEAP32[$251>>2]|0;
       __THREW__ = 0;
       (invoke_iiii($250|0,($252|0),1,0)|0);
       $253 = __THREW__; __THREW__ = 0;
       $254 = $253&1;
       if ($254) {
        break;
       }
       if ($endWindows5$0$off0) {
        $255 = HEAP32[$8>>2]|0;
        __THREW__ = 0;
        invoke_vii(2737,($231|0),($255|0));
        $256 = __THREW__; __THREW__ = 0;
        $257 = $256&1;
        if ($257) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(2738,($7|0),($234|0));
        $258 = __THREW__; __THREW__ = 0;
        $259 = $258&1;
        if ($259) {
         break;
        }
        $260 = HEAP32[$8>>2]|0;
        __THREW__ = 0;
        invoke_vii(2739,($231|0),($260|0));
        $261 = __THREW__; __THREW__ = 0;
        $262 = $261&1;
        if ($262) {
         break;
        }
       }
       $263 = (($current$3103) + 1)|0;
       $264 = HEAP32[$237>>2]|0;
       $265 = ($241|0)==($264|0);
       if ($265) {
        break L124;
       } else {
        $242 = $241;$current$3103 = $263;$hasSentEndWindows$2$off0104 = $hasSentEndWindows$3$off0;
       }
      }
      $47 = ___cxa_find_matching_catch()|0;
      $48 = tempRet0;
      $lpad$phi90$index = $47;$lpad$phi90$index5 = $48;
      label = 14;
      break L64;
     }
    } while(0);
    if ($$off0) {
     $266 = HEAP32[$8>>2]|0;
     __THREW__ = 0;
     invoke_vii(2737,($231|0),($266|0));
     $267 = __THREW__; __THREW__ = 0;
     $268 = $267&1;
     if ($268) {
      label = 13;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3499,($7|0));
     $269 = __THREW__; __THREW__ = 0;
     $270 = $269&1;
     if ($270) {
      label = 13;
      break;
     }
     $271 = HEAP32[$8>>2]|0;
     __THREW__ = 0;
     invoke_vii(2739,($231|0),($271|0));
     $272 = __THREW__; __THREW__ = 0;
     $273 = $272&1;
     if ($273) {
      label = 13;
      break;
     } else {
      $eventUsed$3$off0 = $eventUsed$1$off0;
     }
    } else {
     $eventUsed$3$off0 = $eventUsed$1$off0;
    }
   }
   $274 = ($handleTab$0|0)==(0);
   $brmerge18 = $274 | $eventUsed$3$off0;
   L144: do {
    if (!($brmerge18)) {
     $275 = (($this) + 28|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = ($276|0)==(0);
     if (!($277)) {
      HEAP32[$keyIDLists>>2] = 0;
      $278 = (($keyIDLists) + 4|0);
      HEAP32[$278>>2] = 0;
      $279 = (($keyIDLists) + 8|0);
      HEAP32[$279>>2] = 0;
      __THREW__ = 0;
      $280 = (invoke_ii(3254,($7|0))|0);
      $281 = __THREW__; __THREW__ = 0;
      $282 = $281&1;
      L147: do {
       if ($282) {
        label = 125;
       } else {
        $283 = ($280|0)==(0|0);
        L149: do {
         if ($283) {
          $326 = HEAP32[$275>>2]|0;
          $327 = HEAP32[$279>>2]|0;
          $328 = HEAP32[$keyIDLists>>2]|0;
          $329 = $327;
          $330 = $328;
          $331 = (($329) - ($330))|0;
          $332 = $331 >> 2;
          $333 = ($332>>>0)<($326>>>0);
          if ($333) {
           $334 = HEAP32[$278>>2]|0;
           $335 = $334;
           $336 = (($335) - ($330))|0;
           $337 = $336 >> 2;
           $338 = ($326|0)==(0);
           if ($338) {
            $344 = 0;
           } else {
            $339 = $326 << 2;
            __THREW__ = 0;
            $340 = (invoke_ii(2988,($339|0))|0);
            $341 = __THREW__; __THREW__ = 0;
            $342 = $341&1;
            if ($342) {
             label = 125;
             break L147;
            }
            $344 = $340;
           }
           $343 = (($344) + ($337<<2)|0);
           $345 = (($344) + ($326<<2)|0);
           _memcpy(($344|0),($328|0),($336|0))|0;
           HEAP32[$keyIDLists>>2] = $344;
           HEAP32[$278>>2] = $343;
           HEAP32[$279>>2] = $345;
           $346 = ($328|0)==(0|0);
           if (!($346)) {
            __ZdlPv($328);
           }
          }
          $347 = (($this) + 24|0);
          $348 = HEAP32[$347>>2]|0;
          $349 = ($348|0)==($135|0);
          if (!($349)) {
           $351 = $348;
           L159: while(1) {
            $350 = (($351) + 20|0);
            $352 = HEAP32[$350>>2]|0;
            $353 = (($351) + 12|0);
            $354 = HEAP32[$353>>2]|0;
            __THREW__ = 0;
            $355 = (invoke_ii($352|0,($354|0))|0);
            $356 = __THREW__; __THREW__ = 0;
            $357 = $356&1;
            if ($357) {
             label = 124;
             break;
            }
            $358 = HEAP32[$278>>2]|0;
            $359 = HEAP32[$279>>2]|0;
            $360 = ($358|0)==($359|0);
            do {
             if ($360) {
              $364 = HEAP32[$keyIDLists>>2]|0;
              $365 = $358;
              $366 = $364;
              $367 = (($365) - ($366))|0;
              $368 = $367 >> 2;
              $369 = (($368) + 1)|0;
              $370 = ($369>>>0)>(1073741823);
              if ($370) {
               break L159;
              }
              $373 = ($368>>>0)<(536870911);
              if ($373) {
               $374 = $367 >> 1;
               $375 = ($374>>>0)<($369>>>0);
               $376 = $375 ? $369 : $374;
               $377 = ($376|0)==(0);
               if ($377) {
                $$0$i3$i$i = 0;$383 = 0;
               } else {
                $$0$i2$i$i = $376;
                label = 147;
               }
              } else {
               $$0$i2$i$i = 1073741823;
               label = 147;
              }
              if ((label|0) == 147) {
               label = 0;
               $378 = $$0$i2$i$i << 2;
               __THREW__ = 0;
               $379 = (invoke_ii(2988,($378|0))|0);
               $380 = __THREW__; __THREW__ = 0;
               $381 = $380&1;
               if ($381) {
                label = 124;
                break L159;
               }
               $$0$i3$i$i = $$0$i2$i$i;$383 = $379;
              }
              $382 = (($383) + ($368<<2)|0);
              $384 = (($383) + ($$0$i3$i$i<<2)|0);
              $385 = ($382|0)==(0|0);
              if (!($385)) {
               HEAP32[$382>>2] = $355;
              }
              $386 = (($383) + ($369<<2)|0);
              _memcpy(($383|0),($364|0),($367|0))|0;
              HEAP32[$keyIDLists>>2] = $383;
              HEAP32[$278>>2] = $386;
              HEAP32[$279>>2] = $384;
              $387 = ($364|0)==(0|0);
              if ($387) {
               break;
              }
              __ZdlPv($364);
             } else {
              $361 = ($358|0)==(0|0);
              if ($361) {
               $363 = 0;
              } else {
               HEAP32[$358>>2] = $355;
               $$pre$i = HEAP32[$278>>2]|0;
               $363 = $$pre$i;
              }
              $362 = (($363) + 4|0);
              HEAP32[$278>>2] = $362;
             }
            } while(0);
            $388 = (($351) + 4|0);
            $389 = HEAP32[$388>>2]|0;
            $390 = ($389|0)==($135|0);
            if ($390) {
             break L149;
            } else {
             $351 = $389;
            }
           }
           if ((label|0) == 124) {
            $315 = ___cxa_find_matching_catch()|0;
            $316 = tempRet0;
            $lpad$phi$index = $315;$lpad$phi$index18 = $316;
            break L147;
           }
           __THREW__ = 0;
           invoke_vi(3308,0);
           $371 = __THREW__; __THREW__ = 0;
           $372 = $371&1;
           if ($372) {
            label = 125;
            break L147;
           }
           // unreachable;
          }
         } else {
          $284 = (($280) + 4|0);
          $285 = HEAP32[$278>>2]|0;
          $286 = HEAP32[$279>>2]|0;
          $287 = ($285|0)==($286|0);
          if (!($287)) {
           $288 = ($285|0)==(0|0);
           if ($288) {
            $290 = 0;
           } else {
            HEAP32[$285>>2] = $284;
            $$pre$i55 = HEAP32[$278>>2]|0;
            $290 = $$pre$i55;
           }
           $289 = (($290) + 4|0);
           HEAP32[$278>>2] = $289;
           break;
          }
          $291 = HEAP32[$keyIDLists>>2]|0;
          $292 = $285;
          $293 = $291;
          $294 = (($292) - ($293))|0;
          $295 = $294 >> 2;
          $296 = (($295) + 1)|0;
          $297 = ($296>>>0)>(1073741823);
          if ($297) {
           __THREW__ = 0;
           invoke_vi(3308,0);
           $298 = __THREW__; __THREW__ = 0;
           $299 = $298&1;
           if ($299) {
            label = 125;
            break L147;
           }
           // unreachable;
          }
          $300 = ($295>>>0)<(536870911);
          if ($300) {
           $301 = $294 >> 1;
           $302 = ($301>>>0)<($296>>>0);
           $303 = $302 ? $296 : $301;
           $304 = ($303|0)==(0);
           if ($304) {
            $$0$i3$i$i60 = 0;$310 = 0;
           } else {
            $$0$i2$i$i58 = $303;
            label = 118;
           }
          } else {
           $$0$i2$i$i58 = 1073741823;
           label = 118;
          }
          if ((label|0) == 118) {
           $305 = $$0$i2$i$i58 << 2;
           __THREW__ = 0;
           $306 = (invoke_ii(2988,($305|0))|0);
           $307 = __THREW__; __THREW__ = 0;
           $308 = $307&1;
           if ($308) {
            label = 125;
            break L147;
           }
           $$0$i3$i$i60 = $$0$i2$i$i58;$310 = $306;
          }
          $309 = (($310) + ($295<<2)|0);
          $311 = (($310) + ($$0$i3$i$i60<<2)|0);
          $312 = ($309|0)==(0|0);
          if (!($312)) {
           HEAP32[$309>>2] = $284;
          }
          $313 = (($310) + ($296<<2)|0);
          _memcpy(($310|0),($291|0),($294|0))|0;
          HEAP32[$keyIDLists>>2] = $310;
          HEAP32[$278>>2] = $313;
          HEAP32[$279>>2] = $311;
          $314 = ($291|0)==(0|0);
          if (!($314)) {
           __ZdlPv($291);
          }
         }
        } while(0);
        $391 = ($handleTab$0|0)==(1);
        __THREW__ = 0;
        invoke_viii(1760,($7|0),($keyIDLists|0),($391|0));
        $392 = __THREW__; __THREW__ = 0;
        $393 = $392&1;
        if ($393) {
         label = 125;
        } else {
         $394 = HEAP32[$keyIDLists>>2]|0;
         $395 = ($394|0)==(0|0);
         if ($395) {
          break L144;
         }
         $396 = HEAP32[$278>>2]|0;
         $397 = ($396|0)==($394|0);
         if (!($397)) {
          $__new_last2$i$i$i$i$i28 = $394;
          $scevgep$i$i$i$i$i29 = (($396) + -4|0);
          $398 = (0 - ($__new_last2$i$i$i$i$i28))|0;
          $uglygep$i$i$i$i$i31 = (($scevgep$i$i$i$i$i29) + ($398)|0);
          $uglygep3$i$i$i$i$i32 = $uglygep$i$i$i$i$i31;
          $399 = $uglygep3$i$i$i$i$i32 >>> 2;
          $400 = $399 ^ -1;
          $scevgep4$i$i$i$i$i33 = (($396) + ($400<<2)|0);
          HEAP32[$278>>2] = $scevgep4$i$i$i$i$i33;
         }
         __ZdlPv($394);
         break L144;
        }
       }
      } while(0);
      if ((label|0) == 125) {
       $317 = ___cxa_find_matching_catch()|0;
       $318 = tempRet0;
       $lpad$phi$index = $317;$lpad$phi$index18 = $318;
      }
      $319 = HEAP32[$keyIDLists>>2]|0;
      $320 = ($319|0)==(0|0);
      if ($320) {
       $$0 = $lpad$phi$index;$$02 = $lpad$phi$index18;
       break L64;
      }
      $321 = HEAP32[$278>>2]|0;
      $322 = ($321|0)==($319|0);
      if (!($322)) {
       $__new_last2$i$i$i$i$i46 = $319;
       $scevgep$i$i$i$i$i47 = (($321) + -4|0);
       $323 = (0 - ($__new_last2$i$i$i$i$i46))|0;
       $uglygep$i$i$i$i$i49 = (($scevgep$i$i$i$i$i47) + ($323)|0);
       $uglygep3$i$i$i$i$i50 = $uglygep$i$i$i$i$i49;
       $324 = $uglygep3$i$i$i$i$i50 >>> 2;
       $325 = $324 ^ -1;
       $scevgep4$i$i$i$i$i51 = (($321) + ($325<<2)|0);
       HEAP32[$278>>2] = $scevgep4$i$i$i$i$i51;
      }
      __ZdlPv($319);
      $$0 = $lpad$phi$index;$$02 = $lpad$phi$index18;
      break L64;
     }
    }
   } while(0);
   __THREW__ = 0;
   invoke_vii(2740,($10|0),($7|0));
   $401 = __THREW__; __THREW__ = 0;
   $402 = $401&1;
   if ($402) {
    label = 13;
   } else {
    __THREW__ = 0;
    invoke_vi(3500,($10|0));
    $403 = __THREW__; __THREW__ = 0;
    $404 = $403&1;
    if ($404) {
     label = 13;
    } else {
     $405 = (($7) + 272|0);
     $406 = HEAP32[$405>>2]|0;
     $407 = ($406|0)!=(0);
     $408 = (($this) + 8|0);
     $409 = $407&1;
     HEAP8[$408>>0] = $409;
     $410 = HEAP32[$9>>2]|0;
     HEAP32[$eventToSend>>2] = $410;
     $411 = HEAP32[$layoutedScripts>>2]|0;
     $412 = ($411|0)==(0|0);
     if ($412) {
      STACKTOP = sp;return;
     }
     $413 = HEAP32[$39>>2]|0;
     $414 = ($413|0)==($411|0);
     if (!($414)) {
      $__new_last2$i$i$i$i$i19 = $411;
      $scevgep$i$i$i$i$i20 = (($413) + -12|0);
      $415 = (0 - ($__new_last2$i$i$i$i$i19))|0;
      $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($415)|0);
      $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
      $416 = (($uglygep3$i$i$i$i$i23>>>0) / 12)&-1;
      $417 = $416 ^ -1;
      $scevgep4$i$i$i$i$i24 = (($413) + (($417*12)|0)|0);
      HEAP32[$39>>2] = $scevgep4$i$i$i$i$i24;
     }
     __ZdlPv($411);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $lpad$phi90$index = $51;$lpad$phi90$index5 = $52;
  label = 14;
 }
 if ((label|0) == 14) {
  $$0 = $lpad$phi90$index;$$02 = $lpad$phi90$index5;
 }
 $418 = HEAP32[$layoutedScripts>>2]|0;
 $419 = ($418|0)==(0|0);
 if ($419) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $420 = HEAP32[$39>>2]|0;
 $421 = ($420|0)==($418|0);
 if (!($421)) {
  $__new_last2$i$i$i$i$i = $418;
  $scevgep$i$i$i$i$i = (($420) + -12|0);
  $422 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($422)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $423 = (($uglygep3$i$i$i$i$i>>>0) / 12)&-1;
  $424 = $423 ^ -1;
  $scevgep4$i$i$i$i$i = (($420) + (($424*12)|0)|0);
  HEAP32[$39>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($418);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN10GUIManager16SendQueuedEventsEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy8 = 0, $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0);
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $event = 0, $i1$0 = 0, $i1$0$in = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy8 = sp + 60|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $event = sp + 16|0;
 $4 = (__Z18GetGUIEventManagerv()|0);
 $5 = (__ZNK15GUIEventManager13GetEventCountEv($4)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($this) + 36|0);
  $8 = (__ZNK15GUIEventManager13GetEventCountEv($4)|0);
  $9 = (($8) + -1)|0;
  $10 = (__ZNK15GUIEventManager15GetEventAtIndexEi($4,$9)|0);
  __ZN10InputEventaSERKS_($7,$10);
 }
 $11 = (($event) + 4|0);
 $12 = (($event) + 40|0);
 HEAP32[$12>>2] = 0;
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
 $31 = 0;$48 = 0;$50 = 0;$storemerge = 0;
 L4: while(1) {
  __THREW__ = 0;
  $13 = (invoke_ii(3255,($4|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   $$ph = $50;
   label = 11;
   break;
  }
  $16 = ($storemerge|0)<($13|0);
  if (!($16)) {
   label = 28;
   break;
  }
  __THREW__ = 0;
  $17 = (invoke_iii(2409,($4|0),($storemerge|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $$ph = $50;
   label = 11;
   break;
  }
  __THREW__ = 0;
  invoke_vii(2734,($event|0),($17|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $$ph = $50;
   label = 11;
   break;
  }
  $22 = HEAP32[$event>>2]|0;
  if ((($22|0) == 2)) {
   $80 = $50;$81 = $48;$82 = $31;
  } else if ((($22|0) == 4) | (($22|0) == 1) | (($22|0) == 0)) {
   __THREW__ = 0;
   $34 = (invoke_i(87)|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $$ph = $50;
    label = 11;
    break;
   }
   __THREW__ = 0;
   $37 = (+invoke_di(8,($34|0)));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    $$ph = $50;
    label = 11;
    break;
   }
   $40 = Math_fround($37);
   $41 = HEAP32[611736>>2]|0;
   $42 = (($41) + 32|0);
   HEAPF32[$42>>2] = $40;
   label = 17;
  } else {
   label = 17;
  }
  if ((label|0) == 17) {
   label = 0;
   __THREW__ = 0;
   invoke_viii(1758,($this|0),($event|0),1);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $$ph = $50;
    label = 11;
    break;
   }
   $45 = HEAP32[$event>>2]|0;
   $46 = ($45|0)==(12);
   if ($46) {
    $47 = (($48) + 1)|0;
    $49 = $50 & 2147483647;
    $51 = ($47>>>0)>($49>>>0);
    do {
     if ($51) {
      $52 = $50 << 1;
      $53 = ($52|0)==(0);
      $54 = $53 ? 1 : $52;
      $55 = ($49>>>0)<($54>>>0);
      if ($55) {
       $56 = ($50|0)>(-1);
       if ($56) {
        $57 = $54 << 2;
        HEAP32[$0>>2] = 61;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
        $58 = (invoke_iiiiiiii(108,($31|0),($57|0),4,($$byval_copy8|0),0,(611760|0),370)|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         $$ph = $54;
         label = 11;
         break L4;
        }
        $67 = $58;$83 = $54;
        break;
       } else {
        $61 = $54 << 2;
        HEAP32[$1>>2] = 61;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
        $62 = (invoke_iiiiiii(102,($61|0),4,($$byval_copy8|0),0,(611760|0),352)|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $$ph = $50;
         label = 11;
         break L4;
        }
        $65 = $47 << 2;
        _memcpy(($62|0),($31|0),($65|0))|0;
        $67 = $62;$83 = $54;
        break;
       }
      } else {
       $67 = $31;$83 = $50;
      }
     } else {
      $67 = $31;$83 = $50;
     }
    } while(0);
    $66 = (($67) + ($48<<2)|0);
    HEAP32[$66>>2] = $storemerge;
    $80 = $83;$81 = $47;$82 = $67;
   } else {
    $80 = $50;$81 = $48;$82 = $31;
   }
  }
  $68 = (($storemerge) + 1)|0;
  $31 = $82;$48 = $81;$50 = $80;$storemerge = $68;
 }
 L28: do {
  if ((label|0) == 11) {
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   $30 = $$ph;$lpad$phi$index = $27;$lpad$phi$index2 = $28;
   label = 12;
  }
  else if ((label|0) == 28) {
   $69 = ($48|0)==(0);
   L30: do {
    if (!($69)) {
     $i1$0$in = $48;
     while(1) {
      $i1$0 = (($i1$0$in) + -1)|0;
      $70 = ($i1$0|0)>(-1);
      if (!($70)) {
       break L30;
      }
      __THREW__ = 0;
      invoke_vii(2741,($4|0),($i1$0|0));
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       break;
      } else {
       $i1$0$in = $i1$0;
      }
     }
     $25 = ___cxa_find_matching_catch()|0;
     $26 = tempRet0;
     $30 = $50;$lpad$phi$index = $25;$lpad$phi$index2 = $26;
     label = 12;
     break L28;
    }
   } while(0);
   $73 = ($50|0)>(-1);
   if (!($73)) {
    __ZN10InputEventD2Ev($event);
    STACKTOP = sp;return;
   }
   HEAP32[$3>>2] = 61;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($31|0),($$byval_copy8|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $$0 = $24;$$01 = $23;
    break;
   } else {
    __ZN10InputEventD2Ev($event);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $29 = ($30|0)>(-1);
  if ($29) {
   HEAP32[$2>>2] = 61;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($31|0),($$byval_copy8|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $78 = ___cxa_find_matching_catch(0|0)|0;
    $79 = tempRet0;
    ___clang_call_terminate($78);
    // unreachable;
   } else {
    $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
   }
  } else {
   $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
  }
 }
 __THREW__ = 0;
 invoke_vi(3498,($event|0));
 $76 = __THREW__; __THREW__ = 0;
 $77 = $76&1;
 if ($77) {
  $78 = ___cxa_find_matching_catch(0|0)|0;
  $79 = tempRet0;
  ___clang_call_terminate($78);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZL18MonoBehaviourDoGUIPvN13MonoBehaviour13GUILayoutTypeEi($beh,$layoutType,$skin) {
 $beh = $beh|0;
 $layoutType = $layoutType|0;
 $skin = $skin|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$beh>>2]|0;
 $1 = (($0) + 132|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 2047]($beh,$layoutType,$skin)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL30MonoBehaviourGetObjectGUIStatePv($beh) {
 $beh = $beh|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13MonoBehaviour17GetObjectGUIStateEv($beh)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__14listIN10GUIManager12SortedScriptE11memory_poolIS2_EE9push_backERKS2_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP8[611752>>0]|0;
 $3 = ($2<<24>>24)==(0);
 do {
  if ($3) {
   $4 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $4;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $5 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,611760,141)|0);
   $6 = HEAP32[628480>>2]|0;
   HEAP32[$1>>2] = $6;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(98,($5|0),1,(611768|0),24,32768,($$byval_copy2|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    HEAP32[611744>>2] = $5;
    __ZN10MemoryPool24RegisterStaticMemoryPoolEPS_($5);
    $15 = 611752;
    $16 = $15;
    HEAP32[$16>>2] = 1;
    $17 = (($15) + 4)|0;
    $18 = $17;
    HEAP32[$18>>2] = 0;
    break;
   }
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viiiiii(97,($5|0),($$byval_copy2|0),0,16,(611760|0),141);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $13 = ___cxa_find_matching_catch(0|0)|0;
    $14 = tempRet0;
    ___clang_call_terminate($13);
    // unreachable;
   } else {
    ___resumeException($9|0);
    // unreachable;
   }
  }
 } while(0);
 $19 = HEAP32[611744>>2]|0;
 $20 = (__ZN10MemoryPool8AllocateEj($19,24)|0);
 $21 = (($20) + 8|0);
 $22 = HEAP32[$__x>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = (($20) + 12|0);
 $24 = (($__x) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = (($20) + 16|0);
 $27 = (($__x) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $28;
 $29 = (($20) + 20|0);
 $30 = (($__x) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 HEAP32[$29>>2] = $31;
 $32 = HEAP32[$__x>>2]|0;
 HEAP32[$21>>2] = $32;
 $33 = HEAP32[$this>>2]|0;
 $34 = (($33) + 4|0);
 HEAP32[$34>>2] = $20;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$20>>2] = $35;
 HEAP32[$this>>2] = $20;
 $36 = (($20) + 4|0);
 HEAP32[$36>>2] = $this;
 $37 = (($this) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$37>>2] = $39;
 STACKTOP = sp;return;
}
function __ZNSt3__14listIN10GUIManager12SortedScriptE11memory_poolIS2_EE6__sortI13OldSortScriptEENS_15__list_iteratorIS2_PvEESA_SA_jRT_($agg$result,$__f1,$__e2,$__n,$__comp) {
 $agg$result = $agg$result|0;
 $__f1 = $__f1|0;
 $__e2 = $__e2|0;
 $__n = $__n|0;
 $__comp = $__comp|0;
 var $$ = 0, $$01$i$i$i25 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$lcssa39 = 0, $$lcssa48 = 0, $$ph = 0, $$ph4253 = 0, $$ph4354 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$sroa$0$0$ph = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 28|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = sp + 24|0;
 if ((($__n|0) == 2)) {
  $7 = HEAP32[$__e2>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$__e2>>2] = $8;
  $9 = HEAP32[$__f1>>2]|0;
  $10 = (($8) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($9) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)<($13|0);
  if ($14) {
   $15 = (($8) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$8>>2]|0;
   $18 = (($17) + 4|0);
   HEAP32[$18>>2] = $16;
   $19 = HEAP32[$8>>2]|0;
   $20 = HEAP32[$15>>2]|0;
   HEAP32[$20>>2] = $19;
   $21 = HEAP32[$9>>2]|0;
   $22 = (($21) + 4|0);
   HEAP32[$22>>2] = $8;
   $23 = HEAP32[$9>>2]|0;
   HEAP32[$8>>2] = $23;
   HEAP32[$9>>2] = $8;
   HEAP32[$15>>2] = $9;
   HEAP32[$agg$result>>2] = $8;
   STACKTOP = sp;return;
  } else {
   HEAP32[$agg$result>>2] = $9;
   STACKTOP = sp;return;
  }
 } else if ((($__n|0) == 1) | (($__n|0) == 0)) {
  $6 = HEAP32[$__f1>>2]|0;
  HEAP32[$agg$result>>2] = $6;
  STACKTOP = sp;return;
 } else {
  $24 = $__n >>> 1;
  $25 = HEAP32[$__f1>>2]|0;
  $26 = ($24|0)==(0);
  if ($26) {
   $32 = $25;
  } else {
   $$01$i$i$i25 = $24;$28 = $25;
   while(1) {
    $27 = (($28) + 4|0);
    $29 = HEAP32[$27>>2]|0;
    $30 = (($$01$i$i$i25) + -1)|0;
    $31 = ($30|0)>(0);
    if ($31) {
     $$01$i$i$i25 = $30;$28 = $29;
    } else {
     $32 = $29;
     break;
    }
   }
  }
  HEAP32[$1>>2] = $25;
  HEAP32[$2>>2] = $32;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
  __ZNSt3__14listIN10GUIManager12SortedScriptE11memory_poolIS2_EE6__sortI13OldSortScriptEENS_15__list_iteratorIS2_PvEESA_SA_jRT_($0,$$byval_copy2,$$byval_copy3,$24,$__comp);
  $33 = HEAP32[$0>>2]|0;
  HEAP32[$__f1>>2] = $33;
  HEAP32[$4>>2] = $32;
  $34 = HEAP32[$__e2>>2]|0;
  HEAP32[$5>>2] = $34;
  $35 = (($__n) - ($24))|0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$4+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$5+0>>2]|0;
  __ZNSt3__14listIN10GUIManager12SortedScriptE11memory_poolIS2_EE6__sortI13OldSortScriptEENS_15__list_iteratorIS2_PvEESA_SA_jRT_($3,$$byval_copy2,$$byval_copy3,$35,$__comp);
  $36 = HEAP32[$3>>2]|0;
  $37 = (($36) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($33) + 8|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($38|0)<($40|0);
  if ($41) {
   $42 = (($36) + 4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==($34|0);
   L9: do {
    if ($44) {
     $$lcssa48 = $34;
    } else {
     $46 = $43;
     while(1) {
      $45 = (($46) + 8|0);
      $47 = HEAP32[$45>>2]|0;
      $48 = ($47|0)<($40|0);
      if (!($48)) {
       $$lcssa48 = $46;
       break L9;
      }
      $49 = (($46) + 4|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50|0)==($34|0);
      if ($51) {
       $$lcssa48 = $34;
       break;
      } else {
       $46 = $50;
      }
     }
    }
   } while(0);
   $52 = HEAP32[$$lcssa48>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = HEAP32[$36>>2]|0;
   $56 = (($55) + 4|0);
   HEAP32[$56>>2] = $54;
   $57 = HEAP32[$36>>2]|0;
   $58 = HEAP32[$53>>2]|0;
   HEAP32[$58>>2] = $57;
   $59 = (($33) + 4|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = HEAP32[$33>>2]|0;
   $62 = (($61) + 4|0);
   HEAP32[$62>>2] = $36;
   $63 = HEAP32[$33>>2]|0;
   HEAP32[$36>>2] = $63;
   HEAP32[$33>>2] = $52;
   HEAP32[$53>>2] = $33;
   $$ph = $$lcssa48;$__r$sroa$0$0$ph = $36;$storemerge = $60;
  } else {
   $64 = (($33) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $$ph = $36;$__r$sroa$0$0$ph = $33;$storemerge = $65;
  }
  HEAP32[$__f1>>2] = $storemerge;
  $66 = ($storemerge|0)==($$ph|0);
  L16: do {
   if (!($66)) {
    $$ph4253 = $$ph;$$ph4354 = $$ph;$102 = $storemerge;$68 = $34;
    while(1) {
     $67 = ($$ph4354|0)==($68|0);
     $69 = (($$ph4354) + 8|0);
     if ($67) {
      break L16;
     } else {
      $72 = $102;
     }
     while(1) {
      $70 = HEAP32[$69>>2]|0;
      $71 = (($72) + 8|0);
      $73 = HEAP32[$71>>2]|0;
      $74 = ($70|0)<($73|0);
      if ($74) {
       break;
      }
      $99 = (($72) + 4|0);
      $100 = HEAP32[$99>>2]|0;
      HEAP32[$__f1>>2] = $100;
      $101 = ($100|0)==($$ph4253|0);
      if ($101) {
       break L16;
      } else {
       $72 = $100;
      }
     }
     $75 = (($$ph4354) + 4|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==($68|0);
     L23: do {
      if ($77) {
       $$lcssa39 = $68;
      } else {
       $79 = $76;
       while(1) {
        $78 = (($79) + 8|0);
        $80 = HEAP32[$78>>2]|0;
        $81 = ($80|0)<($73|0);
        if (!($81)) {
         $$lcssa39 = $79;
         break L23;
        }
        $82 = (($79) + 4|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = ($83|0)==($68|0);
        if ($84) {
         $$lcssa39 = $68;
         break;
        } else {
         $79 = $83;
        }
       }
      }
     } while(0);
     $85 = HEAP32[$$lcssa39>>2]|0;
     $86 = ($$ph4253|0)==($$ph4354|0);
     $87 = (($85) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = HEAP32[$$ph4354>>2]|0;
     $90 = (($89) + 4|0);
     HEAP32[$90>>2] = $88;
     $91 = HEAP32[$$ph4354>>2]|0;
     $92 = HEAP32[$87>>2]|0;
     HEAP32[$92>>2] = $91;
     $93 = (($72) + 4|0);
     $94 = HEAP32[$93>>2]|0;
     $$ = $86 ? $$lcssa39 : $$ph4253;
     $95 = HEAP32[$72>>2]|0;
     $96 = (($95) + 4|0);
     HEAP32[$96>>2] = $$ph4354;
     $97 = HEAP32[$72>>2]|0;
     HEAP32[$$ph4354>>2] = $97;
     HEAP32[$72>>2] = $85;
     HEAP32[$87>>2] = $72;
     HEAP32[$__f1>>2] = $94;
     $98 = ($94|0)==($$|0);
     if ($98) {
      break L16;
     }
     $$pre = HEAP32[$__e2>>2]|0;
     $$ph4253 = $$;$$ph4354 = $$lcssa39;$102 = $94;$68 = $$pre;
    }
   }
  } while(0);
  HEAP32[$agg$result>>2] = $__r$sroa$0$0$ph;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__110__list_impIN10GUIManager12SortedScriptE11memory_poolIS2_EE5clearEv($this) {
 $this = $this|0;
 var $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__f$0 = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $9;
 $12 = HEAP32[$6>>2]|0;
 $13 = HEAP32[$8>>2]|0;
 HEAP32[$13>>2] = $12;
 HEAP32[$2>>2] = 0;
 $__f$0 = $6;
 while(1) {
  $14 = ($__f$0|0)==($this|0);
  if ($14) {
   label = 14;
   break;
  }
  $15 = (($__f$0) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP8[611752>>0]|0;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $19 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $19;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   $20 = (invoke_iiiiiii(103,40,($$byval_copy7|0),0,16,(611760|0),141)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 12;
    break;
   }
   $23 = HEAP32[628480>>2]|0;
   HEAP32[$1>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(98,($20|0),1,(611768|0),24,32768,($$byval_copy7|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 7;
    break;
   }
   HEAP32[611744>>2] = $20;
   __THREW__ = 0;
   invoke_vi(3395,($20|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    label = 12;
    break;
   }
   $34 = 611752;
   $35 = $34;
   HEAP32[$35>>2] = 1;
   $36 = (($34) + 4)|0;
   $37 = $36;
   HEAP32[$37>>2] = 0;
  }
  $38 = HEAP32[611744>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($38|0),($__f$0|0));
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if ($40) {
   label = 12;
   break;
  } else {
   $__f$0 = $16;
  }
 }
 if ((label|0) == 7) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($20|0),($$byval_copy7|0),0,16,(611760|0),141);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $30 = ___cxa_find_matching_catch(0|0)|0;
   $31 = tempRet0;
   ___clang_call_terminate($30);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $26;
   ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
   // unreachable;
  }
 }
 else if ((label|0) == 12) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $41;
  ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN10GUIManager16GUIObjectWrapperENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i4 = 0, $$0$i5 = 0, $$01$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $scevgep3 = 0, $uglygep = 0;
 var $uglygep2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($13>>>0)<(178956970);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i5 = 0;$22 = 0;
  } else {
   $$0$i4 = $17;
   label = 5;
  }
 } else {
  $$0$i4 = 357913941;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i4*12)|0;
  $20 = (__Znwj($19)|0);
  $$0$i5 = $$0$i4;$22 = $20;
 }
 $21 = (($22) + (($6*12)|0)|0);
 $23 = (($22) + (($$0$i5*12)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  $25 = HEAP32[$__x>>2]|0;
  HEAP32[$21>>2] = $25;
  $26 = ((($22) + (($6*12)|0)|0) + 4|0);
  $27 = (($__x) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$26>>2] = $28;
  $29 = ((($22) + (($6*12)|0)|0) + 8|0);
  $30 = (($__x) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$29>>2] = $31;
 }
 $32 = (($22) + (($7*12)|0)|0);
 $33 = ($1|0)==($2|0);
 if ($33) {
  $50 = $21;$52 = $1;
 } else {
  $34 = (($6) + -1)|0;
  $scevgep = (($1) + -12|0);
  $35 = (0 - ($4))|0;
  $uglygep = (($scevgep) + ($35)|0);
  $uglygep2 = $uglygep;
  $36 = (($uglygep2>>>0) / 12)&-1;
  $37 = (($34) - ($36))|0;
  $$01$i$i = $1;$40 = $21;
  while(1) {
   $38 = (($$01$i$i) + -12|0);
   $39 = (($40) + -12|0);
   $41 = HEAP32[$38>>2]|0;
   HEAP32[$39>>2] = $41;
   $42 = (($40) + -8|0);
   $43 = (($$01$i$i) + -8|0);
   $44 = HEAP32[$43>>2]|0;
   HEAP32[$42>>2] = $44;
   $45 = (($40) + -4|0);
   $46 = (($$01$i$i) + -4|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$45>>2] = $47;
   $48 = (($40) + -12|0);
   $49 = ($38|0)==($2|0);
   if ($49) {
    break;
   } else {
    $$01$i$i = $38;$40 = $48;
   }
  }
  $scevgep3 = (($22) + (($37*12)|0)|0);
  $$pre$i = HEAP32[$this>>2]|0;
  $50 = $scevgep3;$52 = $$pre$i;
 }
 HEAP32[$this>>2] = $50;
 HEAP32[$0>>2] = $32;
 HEAP32[$9>>2] = $23;
 $51 = ($52|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 __ZdlPv($52);
 STACKTOP = sp;return;
}
function __ZN12GUIClipStateC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 140|0);
 dest=$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN12GUIClipState4PushER10InputEventRK5RectTIfE8Vector2fRKS6_b($this,$event,$screenRect,$scrollOffset,$renderOffset,$resetOffset) {
 $this = $this|0;
 $event = $event|0;
 $screenRect = $screenRect|0;
 $scrollOffset = $scrollOffset|0;
 $renderOffset = $renderOffset|0;
 $resetOffset = $resetOffset|0;
 var $$byval_copy = 0, $$pre$i = 0, $$pre$i1 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $physicalxMax$0 = Math_fround(0), $physicalxMax$1 = Math_fround(0), $physicalxMin$0 = Math_fround(0), $physicalyMax$0 = Math_fround(0), $physicalyMax$1 = Math_fround(0), $physicalyMin$0 = Math_fround(0), dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp + 120|0;
 $0 = sp;
 $1 = sp + 56|0;
 $2 = sp + 112|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(611784,0,611832,32,1,0,0,0);
  STACKTOP = sp;return;
 }
 $7 = Math_fround(HEAPF32[$screenRect>>2]);
 $8 = (($5) + -56|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 + $9);
 $11 = (($5) + -24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 $14 = (($screenRect) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($7 + $15);
 $17 = Math_fround($9 + $16);
 $18 = Math_fround($12 + $17);
 $19 = (($screenRect) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($5) + -52|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 + $22);
 $24 = (($5) + -20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 + $25);
 $27 = (($screenRect) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($20 + $28);
 $30 = Math_fround($22 + $29);
 $31 = Math_fround($25 + $30);
 $32 = $13 < $9;
 if ($32) {
  $33 = Math_fround($13 - $9);
  $34 = Math_fround(HEAPF32[$scrollOffset>>2]);
  $35 = Math_fround($33 + $34);
  HEAPF32[$scrollOffset>>2] = $35;
  $physicalxMin$0 = $9;
 } else {
  $physicalxMin$0 = $13;
 }
 $36 = $26 < $22;
 if ($36) {
  $37 = Math_fround($26 - $22);
  $38 = (($scrollOffset) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($37 + $39);
  HEAPF32[$38>>2] = $40;
  $physicalyMin$0 = $22;
 } else {
  $physicalyMin$0 = $26;
 }
 $41 = (($5) + -48|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($9 + $42);
 $44 = $18 > $43;
 $physicalxMax$0 = $44 ? $43 : $18;
 $45 = (($5) + -44|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($22 + $46);
 $48 = $31 > $47;
 $physicalyMax$0 = $48 ? $47 : $31;
 $49 = !($physicalxMax$0 <= $physicalxMin$0);
 $physicalxMax$1 = $49 ? $physicalxMax$0 : $physicalxMin$0;
 $50 = !($physicalyMax$0 <= $physicalyMin$0);
 $physicalyMax$1 = $50 ? $physicalyMax$0 : $physicalyMin$0;
 $51 = Math_fround($physicalxMax$1 - $physicalxMin$0);
 $52 = Math_fround($physicalyMax$1 - $physicalyMin$0);
 do {
  if ($resetOffset) {
   $106 = Math_fround(HEAPF32[$scrollOffset>>2]);
   $107 = Math_fround($physicalxMin$0 + $106);
   $108 = Math_fround(HEAPF32[$renderOffset>>2]);
   $109 = Math_fround($107 + $108);
   $110 = (($scrollOffset) + 4|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = Math_fround($physicalyMin$0 + $111);
   $113 = (($renderOffset) + 4|0);
   $114 = Math_fround(HEAPF32[$113>>2]);
   $115 = Math_fround($112 + $114);
   $116 = (($5) + -16|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = Math_fround($106 + $117);
   $119 = (($5) + -12|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = Math_fround($111 + $120);
   $122 = (($1) + 16|0);
   $123 = (($1) + 32|0);
   $124 = (($1) + 40|0);
   $125 = (($1) + 48|0);
   dest=$1+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   ;HEAP32[$122+0>>2]=HEAP32[$screenRect+0>>2]|0;HEAP32[$122+4>>2]=HEAP32[$screenRect+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$screenRect+8>>2]|0;HEAP32[$122+12>>2]=HEAP32[$screenRect+12>>2]|0;
   HEAPF32[$1>>2] = $physicalxMin$0;
   $126 = (($1) + 4|0);
   HEAPF32[$126>>2] = $physicalyMin$0;
   $127 = (($1) + 8|0);
   HEAPF32[$127>>2] = $51;
   $128 = (($1) + 12|0);
   HEAPF32[$128>>2] = $52;
   $129 = $scrollOffset;
   $130 = $129;
   $131 = HEAP32[$130>>2]|0;
   $132 = (($129) + 4)|0;
   $133 = $132;
   $134 = HEAP32[$133>>2]|0;
   $135 = $123;
   $136 = $135;
   HEAP32[$136>>2] = $131;
   $137 = (($135) + 4)|0;
   $138 = $137;
   HEAP32[$138>>2] = $134;
   $139 = (HEAPF32[tempDoublePtr>>2]=$109,HEAP32[tempDoublePtr>>2]|0);
   $140 = (HEAPF32[tempDoublePtr>>2]=$115,HEAP32[tempDoublePtr>>2]|0);
   $141 = $125;
   $142 = $141;
   HEAP32[$142>>2] = $139;
   $143 = (($141) + 4)|0;
   $144 = $143;
   HEAP32[$144>>2] = $140;
   $145 = (HEAPF32[tempDoublePtr>>2]=$118,HEAP32[tempDoublePtr>>2]|0);
   $146 = (HEAPF32[tempDoublePtr>>2]=$121,HEAP32[tempDoublePtr>>2]|0);
   $147 = $124;
   $148 = $147;
   HEAP32[$148>>2] = $145;
   $149 = (($147) + 4)|0;
   $150 = $149;
   HEAP32[$150>>2] = $146;
   $151 = (($this) + 8|0);
   $152 = HEAP32[$151>>2]|0;
   $153 = ($5|0)==($152|0);
   if ($153) {
    __ZNSt3__16vectorI7GUIClipNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$1);
    break;
   } else {
    dest=$5+0|0; src=$1+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre$i = HEAP32[$4>>2]|0;
    $154 = (($$pre$i) + 56|0);
    HEAP32[$4>>2] = $154;
    break;
   }
  } else {
   $53 = (($5) + -8|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = Math_fround(HEAPF32[$renderOffset>>2]);
   $56 = Math_fround($54 + $55);
   $57 = (($5) + -4|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = (($renderOffset) + 4|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround($58 + $60);
   $62 = (($5) + -16|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = Math_fround(HEAPF32[$scrollOffset>>2]);
   $65 = Math_fround($63 + $64);
   $66 = (($5) + -12|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = (($scrollOffset) + 4|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($67 + $69);
   $71 = (($0) + 16|0);
   $72 = (($0) + 32|0);
   $73 = (($0) + 40|0);
   $74 = (($0) + 48|0);
   dest=$0+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   ;HEAP32[$71+0>>2]=HEAP32[$screenRect+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$screenRect+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$screenRect+8>>2]|0;HEAP32[$71+12>>2]=HEAP32[$screenRect+12>>2]|0;
   HEAPF32[$0>>2] = $physicalxMin$0;
   $75 = (($0) + 4|0);
   HEAPF32[$75>>2] = $physicalyMin$0;
   $76 = (($0) + 8|0);
   HEAPF32[$76>>2] = $51;
   $77 = (($0) + 12|0);
   HEAPF32[$77>>2] = $52;
   $78 = $scrollOffset;
   $79 = $78;
   $80 = HEAP32[$79>>2]|0;
   $81 = (($78) + 4)|0;
   $82 = $81;
   $83 = HEAP32[$82>>2]|0;
   $84 = $72;
   $85 = $84;
   HEAP32[$85>>2] = $80;
   $86 = (($84) + 4)|0;
   $87 = $86;
   HEAP32[$87>>2] = $83;
   $88 = (HEAPF32[tempDoublePtr>>2]=$56,HEAP32[tempDoublePtr>>2]|0);
   $89 = (HEAPF32[tempDoublePtr>>2]=$61,HEAP32[tempDoublePtr>>2]|0);
   $90 = $74;
   $91 = $90;
   HEAP32[$91>>2] = $88;
   $92 = (($90) + 4)|0;
   $93 = $92;
   HEAP32[$93>>2] = $89;
   $94 = (HEAPF32[tempDoublePtr>>2]=$65,HEAP32[tempDoublePtr>>2]|0);
   $95 = (HEAPF32[tempDoublePtr>>2]=$70,HEAP32[tempDoublePtr>>2]|0);
   $96 = $73;
   $97 = $96;
   HEAP32[$97>>2] = $94;
   $98 = (($96) + 4)|0;
   $99 = $98;
   HEAP32[$99>>2] = $95;
   $100 = (($this) + 8|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($5|0)==($101|0);
   if ($102) {
    __ZNSt3__16vectorI7GUIClipNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$0);
    break;
   }
   $103 = ($5|0)==(0|0);
   if ($103) {
    $105 = 0;
   } else {
    dest=$5+0|0; src=$0+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre$i1 = HEAP32[$4>>2]|0;
    $105 = $$pre$i1;
   }
   $104 = (($105) + 56|0);
   HEAP32[$4>>2] = $104;
  }
 } while(0);
 $155 = HEAP32[$4>>2]|0;
 $156 = (($155) + -56|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $157 = (($2) + 4|0);
 HEAPF32[$157>>2] = Math_fround(1.0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 __ZN12GUIClipState5ApplyER10InputEventR7GUIClip8Vector2f($this,$event,$156,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN12GUIClipState5ApplyER10InputEventR7GUIClip8Vector2f($this,$event,$topmost,$renderScaleFactor) {
 $this = $this|0;
 $event = $event|0;
 $topmost = $topmost|0;
 $renderScaleFactor = $renderScaleFactor|0;
 var $$sink$i$i = Math_fround(0), $$sink$i$i1 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0;
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = 0, $floorf$i$i = Math_fround(0), $floorf$i$i3 = Math_fround(0), $height$0 = Math_fround(0), $height$0$in = 0, $matrix$i = 0, $pixelMatrix = 0, $r$sroa$2$0 = Math_fround(0), $r$sroa$3$0 = Math_fround(0), $rect$i = 0, $scaleFac = 0, $viewportMatrix = 0, $width$0 = Math_fround(0), $width$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $rect$i = sp + 248|0;
 $matrix$i = sp;
 $viewportMatrix = sp + 64|0;
 $scaleFac = sp + 128|0;
 $0 = sp + 140|0;
 $1 = sp + 152|0;
 $2 = sp + 168|0;
 $pixelMatrix = sp + 184|0;
 __ZN12GUIClipState20CalculateMouseValuesER10InputEvent($this,$event);
 $3 = (($this) + 156|0);
 $4 = (($topmost) + 32|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(-$5);
 $7 = (($topmost) + 36|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround(-$8);
 $10 = (($topmost) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($topmost) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 156|0);
 HEAPF32[$14>>2] = $6;
 $15 = (($this) + 160|0);
 HEAPF32[$15>>2] = $9;
 $16 = (($this) + 164|0);
 HEAPF32[$16>>2] = $11;
 $17 = (($this) + 168|0);
 HEAPF32[$17>>2] = $13;
 $18 = HEAP32[$event>>2]|0;
 $19 = ($18|0)==(7);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = Math_fround(HEAPF32[$topmost>>2]);
 $21 = (($topmost) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround(HEAPF32[$10>>2]);
 $24 = Math_fround(HEAPF32[$12>>2]);
 $25 = $23 < Math_fround(0.0);
 $r$sroa$2$0 = $25 ? Math_fround(0.0) : $23;
 $26 = $24 < Math_fround(0.0);
 $r$sroa$3$0 = $26 ? Math_fround(0.0) : $24;
 $27 = (($topmost) + 48|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($20 - $28);
 $30 = (($topmost) + 52|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($22 - $31);
 $33 = Math_fround($29 + Math_fround(0.5));
 $34 = !($33 >= Math_fround(0.0));
 if ($34) {
  $35 = Math_fround($33 + Math_fround(-0.999999940395355224609));
  $$sink$i$i = $35;
 } else {
  $$sink$i$i = $33;
 }
 $36 = (~~(($$sink$i$i)));
 $37 = (Math_fround(($36|0)));
 $38 = Math_fround($32 + Math_fround(0.5));
 $39 = !($38 >= Math_fround(0.0));
 if ($39) {
  $40 = Math_fround($38 + Math_fround(-0.999999940395355224609));
  $$sink$i$i1 = $40;
 } else {
  $$sink$i$i1 = $38;
 }
 $41 = (~~(($$sink$i$i1)));
 $42 = (Math_fround(($41|0)));
 $43 = Math_fround($r$sroa$2$0 + Math_fround(0.5));
 $44 = (~~(($43))>>>0);
 $45 = (Math_fround(($44>>>0)));
 $46 = Math_fround($r$sroa$3$0 + Math_fround(0.5));
 $47 = (~~(($46))>>>0);
 $48 = (Math_fround(($47>>>0)));
 (__ZN10Matrix4x4f11SetIdentityEv($viewportMatrix)|0);
 $49 = (__ZN13RenderTexture9GetActiveEv()|0);
 $50 = ($49|0)==(0|0);
 if ($50) {
  $55 = (__Z16GetScreenManagerv()|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($56) + 80|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (FUNCTION_TABLE_ii[$58 & 4095]($55)|0);
  $60 = (__Z16GetScreenManagerv()|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 84|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $height$0$in = $64;$width$0$in = $59;
 } else {
  $51 = (($49) + 100|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($49) + 104|0);
  $54 = HEAP32[$53>>2]|0;
  $height$0$in = $54;$width$0$in = $52;
 }
 $height$0 = (Math_fround(($height$0$in|0)));
 $width$0 = (Math_fround(($width$0$in|0)));
 $65 = Math_fround($45 / $width$0);
 $66 = Math_fround($48 / $height$0);
 $67 = (($scaleFac) + 4|0);
 $68 = (($scaleFac) + 8|0);
 HEAPF32[$68>>2] = Math_fround(1.0);
 $69 = Math_fround(HEAPF32[$renderScaleFactor>>2]);
 $70 = Math_fround($69 * $65);
 HEAPF32[$scaleFac>>2] = $70;
 $71 = (($renderScaleFactor) + 4|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 * $66);
 HEAPF32[$67>>2] = $73;
 $74 = (($this) + 12|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($37 * $75);
 $77 = (($this) + 28|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($42 * $78);
 $80 = Math_fround($76 + $79);
 $81 = (($this) + 44|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($82 * Math_fround(0.0));
 $84 = Math_fround($80 + $83);
 $85 = (($this) + 60|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($86 + $84);
 $88 = (($this) + 16|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($37 * $89);
 $91 = (($this) + 32|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($42 * $92);
 $94 = Math_fround($90 + $93);
 $95 = (($this) + 48|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($96 * Math_fround(0.0));
 $98 = Math_fround($94 + $97);
 $99 = (($this) + 64|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($100 + $98);
 $102 = (($this) + 24|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($37 * $103);
 $105 = (($this) + 40|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = Math_fround($42 * $106);
 $108 = Math_fround($104 + $107);
 $109 = (($this) + 56|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($110 * Math_fround(0.0));
 $112 = Math_fround($108 + $111);
 $113 = (($this) + 72|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($114 + $112);
 $116 = $115 < Math_fround(0.0);
 if ($116) {
  $117 = Math_fround(-$115);
  $119 = $117;
 } else {
  $119 = $115;
 }
 $118 = $119 > Math_fround(1.00000001168609742308E-7);
 if ($118) {
  $120 = Math_fround(Math_fround(1.0) / $115);
  $121 = Math_fround($87 * $120);
  $122 = Math_fround($101 * $120);
  $124 = $121;$126 = $122;
 } else {
  $124 = Math_fround(0.0);$126 = Math_fround(0.0);
 }
 $123 = Math_fround($124 * $70);
 $125 = Math_fround($126 * $73);
 HEAPF32[$0>>2] = $123;
 $127 = (($0) + 4|0);
 HEAPF32[$127>>2] = $125;
 $128 = (($0) + 8|0);
 HEAPF32[$128>>2] = Math_fround(0.0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $129 = (($1) + 4|0);
 HEAPF32[$129>>2] = Math_fround(0.0);
 $130 = (($1) + 8|0);
 HEAPF32[$130>>2] = Math_fround(0.0);
 $131 = (($1) + 12|0);
 HEAPF32[$131>>2] = Math_fround(1.0);
 __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($viewportMatrix,$0,$1,$scaleFac);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $132 = (($2) + 8|0);
 HEAPF32[$132>>2] = $width$0;
 $133 = (($2) + 4|0);
 HEAPF32[$133>>2] = Math_fround(0.0);
 $134 = (($2) + 12|0);
 HEAPF32[$134>>2] = $height$0;
 __Z13SetGLViewportRK5RectTIfE($2);
 $135 = Math_fround(HEAPF32[$4>>2]);
 $136 = Math_fround(-$135);
 $137 = Math_fround(HEAPF32[$7>>2]);
 $138 = Math_fround(-$137);
 $139 = Math_fround(HEAPF32[$74>>2]);
 $140 = Math_fround($139 * $136);
 $141 = Math_fround(HEAPF32[$77>>2]);
 $142 = Math_fround($141 * $138);
 $143 = Math_fround($140 + $142);
 $144 = Math_fround(HEAPF32[$81>>2]);
 $145 = Math_fround($144 * Math_fround(0.0));
 $146 = Math_fround($143 + $145);
 $147 = Math_fround(HEAPF32[$85>>2]);
 $148 = Math_fround($147 + $146);
 $149 = Math_fround(HEAPF32[$88>>2]);
 $150 = Math_fround($149 * $136);
 $151 = Math_fround(HEAPF32[$91>>2]);
 $152 = Math_fround($151 * $138);
 $153 = Math_fround($150 + $152);
 $154 = Math_fround(HEAPF32[$95>>2]);
 $155 = Math_fround($154 * Math_fround(0.0));
 $156 = Math_fround($153 + $155);
 $157 = Math_fround(HEAPF32[$99>>2]);
 $158 = Math_fround($157 + $156);
 $159 = Math_fround(HEAPF32[$102>>2]);
 $160 = Math_fround($159 * $136);
 $161 = Math_fround(HEAPF32[$105>>2]);
 $162 = Math_fround($161 * $138);
 $163 = Math_fround($160 + $162);
 $164 = Math_fround(HEAPF32[$109>>2]);
 $165 = Math_fround($164 * Math_fround(0.0));
 $166 = Math_fround($163 + $165);
 $167 = Math_fround(HEAPF32[$113>>2]);
 $168 = Math_fround($167 + $166);
 $169 = $168 < Math_fround(0.0);
 if ($169) {
  $170 = Math_fround(-$168);
  $172 = $170;
 } else {
  $172 = $168;
 }
 $171 = $172 > Math_fround(1.00000001168609742308E-7);
 if ($171) {
  $173 = Math_fround(Math_fround(1.0) / $168);
  $174 = Math_fround($148 * $173);
  $175 = Math_fround($158 * $173);
  $178 = $174;$181 = $175;
 } else {
  $178 = Math_fround(0.0);$181 = Math_fround(0.0);
 }
 $176 = Math_fround(HEAPF32[$scaleFac>>2]);
 $177 = Math_fround($178 * $176);
 $179 = Math_fround(HEAPF32[$67>>2]);
 $180 = Math_fround($181 * $179);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($viewportMatrix,$74,$pixelMatrix);
 $182 = Math_fround(HEAPF32[$10>>2]);
 $183 = Math_fround($182 + Math_fround(0.5));
 $floorf$i$i3 = (Math_fround(Math_floor((Math_fround($183)))));
 $184 = Math_fround($177 + $floorf$i$i3);
 $185 = Math_fround(HEAPF32[$12>>2]);
 $186 = Math_fround($185 + Math_fround(0.5));
 $floorf$i$i = (Math_fround(Math_floor((Math_fround($186)))));
 $187 = Math_fround($180 + $floorf$i$i);
 $188 = Math_fround($184 - $177);
 $189 = Math_fround($180 - $187);
 HEAPF32[$rect$i>>2] = $177;
 $190 = (($rect$i) + 8|0);
 HEAPF32[$190>>2] = $188;
 $191 = (($rect$i) + 4|0);
 HEAPF32[$191>>2] = $187;
 $192 = (($rect$i) + 12|0);
 HEAPF32[$192>>2] = $189;
 __Z15CalcPixelMatrixRK5RectTIfER10Matrix4x4f($rect$i,$matrix$i);
 (__ZN10Matrix4x4fmLERKS_($matrix$i,$pixelMatrix)|0);
 __Z30ApplyTexelOffsetsToPixelMatrixbR10Matrix4x4f(1,$matrix$i);
 $193 = (__Z12GetGfxDevicev()|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = (($194) + 104|0);
 $196 = HEAP32[$195>>2]|0;
 FUNCTION_TABLE_vii[$196 & 4095]($193,$matrix$i);
 $197 = HEAP32[$193>>2]|0;
 $198 = (($197) + 100|0);
 $199 = HEAP32[$198>>2]|0;
 FUNCTION_TABLE_vii[$199 & 4095]($193,616552);
 __ZN8GUIStyle14SetGUIClipRectERK5RectTIfE($3);
 STACKTOP = sp;return;
}
function __ZN12GUIClipState3PopER10InputEvent($this,$event) {
 $this = $this|0;
 $event = $event|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$sum = 0;
 var $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 56)&-1;
 $8 = ($7>>>0)<(2);
 if ($8) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(611840,0,611832,101,1,0,0,0);
  STACKTOP = sp;return;
 } else {
  $9 = (($2) + -56|0);
  $__new_last2$i$i$i = $9;
  $scevgep$i$i$i = (($2) + -56|0);
  $10 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($10)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $11 = (($uglygep3$i$i$i>>>0) / 56)&-1;
  $12 = $11 ^ -1;
  $scevgep4$i$i$i = (($2) + (($12*56)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i;
  $scevgep4$i$i$i$sum = (-2 - ($11))|0;
  $13 = (($2) + (($scevgep4$i$i$i$sum*56)|0)|0);
  HEAPF32[$0>>2] = Math_fround(1.0);
  $14 = (($0) + 4|0);
  HEAPF32[$14>>2] = Math_fround(1.0);
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  __ZN12GUIClipState5ApplyER10InputEventR7GUIClip8Vector2f($this,$event,$13,$$byval_copy);
  STACKTOP = sp;return;
 }
}
function __ZN12GUIClipState4ClipERK8Vector2f($agg$result,$this,$absolutePos) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $absolutePos = $absolutePos|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if ($3) {
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $71 = (($agg$result) + 4|0);
  HEAPF32[$71>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $4 = Math_fround(HEAPF32[$absolutePos>>2]);
 $5 = (($absolutePos) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 76|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($4 * $8);
 $10 = (($this) + 92|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($6 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (($this) + 108|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * Math_fround(0.0));
 $17 = Math_fround($13 + $16);
 $18 = (($this) + 124|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 + $17);
 $21 = (($this) + 80|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($4 * $22);
 $24 = (($this) + 96|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($6 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($this) + 112|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * Math_fround(0.0));
 $31 = Math_fround($27 + $30);
 $32 = (($this) + 128|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 + $31);
 $35 = (($this) + 88|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($4 * $36);
 $38 = (($this) + 104|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($6 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($this) + 120|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * Math_fround(0.0));
 $45 = Math_fround($41 + $44);
 $46 = (($this) + 136|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 + $45);
 $49 = $48 < Math_fround(0.0);
 if ($49) {
  $50 = Math_fround(-$48);
  $52 = $50;
 } else {
  $52 = $48;
 }
 $51 = $52 > Math_fround(1.00000001168609742308E-7);
 if ($51) {
  $53 = Math_fround(Math_fround(1.0) / $48);
  $54 = Math_fround($20 * $53);
  $55 = Math_fround($34 * $53);
  $59 = $54;$63 = $55;
 } else {
  $59 = Math_fround(0.0);$63 = Math_fround(0.0);
 }
 $56 = (($2) + -24|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($59 - $57);
 $60 = (($2) + -20|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($63 - $61);
 $64 = (($2) + -56|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($2) + -52|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($58 - $65);
 $69 = Math_fround($62 - $67);
 HEAPF32[$agg$result>>2] = $68;
 $70 = (($agg$result) + 4|0);
 HEAPF32[$70>>2] = $69;
 STACKTOP = sp;return;
}
function __ZN12GUIClipState9SetMatrixER10InputEventRK10Matrix4x4f($this,$event,$m) {
 $this = $this|0;
 $event = $event|0;
 $m = $m|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $inverse = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy = sp + 72|0;
 $0 = sp;
 $inverse = sp + 8|0;
 $1 = (($this) + 12|0);
 dest=$1+0|0; src=$m+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (__Z20InvertMatrix4x4_FullPKfPf($m,$inverse)|0);
 if (!($2)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(611872,0,611832,223,1,0,0,0);
  STACKTOP = sp;return;
 }
 dest=$1+0|0; src=$m+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $3 = (($this) + 76|0);
 dest=$3+0|0; src=$inverse+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($6) + -56|0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $9 = (($0) + 4|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN12GUIClipState5ApplyER10InputEventR7GUIClip8Vector2f($this,$event,$8,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN12GUIClipState20CalculateMouseValuesER10InputEvent($this,$event) {
 $this = $this|0;
 $event = $event|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0;
 var $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0;
 var $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($event) + 4|0);
 $7 = (($this) + 140|0);
 __ZN12GUIClipState4ClipERK8Vector2f($0,$this,$7);
 $8 = $0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $6;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 $18 = Math_fround(HEAPF32[$7>>2]);
 $19 = (($this) + 144|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 76|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($18 * $22);
 $24 = (($this) + 92|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($20 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($this) + 108|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * Math_fround(0.0));
 $31 = Math_fround($27 + $30);
 $32 = (($this) + 124|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 + $31);
 $35 = (($this) + 80|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($18 * $36);
 $38 = (($this) + 96|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($20 * $39);
 $41 = Math_fround($37 + $40);
 $42 = (($this) + 112|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * Math_fround(0.0));
 $45 = Math_fround($41 + $44);
 $46 = (($this) + 128|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 + $45);
 $49 = (($this) + 88|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($18 * $50);
 $52 = (($this) + 104|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($20 * $53);
 $55 = Math_fround($51 + $54);
 $56 = (($this) + 120|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 * Math_fround(0.0));
 $59 = Math_fround($55 + $58);
 $60 = (($this) + 136|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 + $59);
 $63 = $62 < Math_fround(0.0);
 if ($63) {
  $64 = Math_fround(-$62);
  $66 = $64;
 } else {
  $66 = $62;
 }
 $65 = $66 > Math_fround(1.00000001168609742308E-7);
 if ($65) {
  $67 = Math_fround(Math_fround(1.0) / $62);
  $68 = Math_fround($34 * $67);
  $69 = Math_fround($48 * $67);
  $74 = $68;$82 = $69;
 } else {
  $74 = Math_fround(0.0);$82 = Math_fround(0.0);
 }
 $70 = HEAP32[$3>>2]|0;
 $71 = (($70) + -56|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = !($72 <= $74);
 if ($73) {
  $88 = 0;
 } else {
  $75 = (($70) + -48|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = Math_fround($72 + $76);
  $78 = $77 > $74;
  if ($78) {
   $79 = (($70) + -52|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = !($80 <= $82);
   if ($81) {
    $88 = 0;
   } else {
    $83 = (($70) + -44|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = Math_fround($80 + $84);
    $86 = $85 > $82;
    $88 = $86;
   }
  } else {
   $88 = 0;
  }
 }
 $87 = $88 << 31 >> 31;
 $89 = (($this) + 172|0);
 HEAP32[$89>>2] = $87;
 $90 = HEAP32[$event>>2]|0;
 $91 = ($90|0)==(6);
 if ($91) {
  STACKTOP = sp;return;
 }
 $92 = (($event) + 12|0);
 $93 = (($this) + 148|0);
 __ZN12GUIClipState4ClipERK8Vector2f($1,$this,$93);
 $94 = Math_fround(HEAPF32[$6>>2]);
 $95 = Math_fround(HEAPF32[$1>>2]);
 $96 = Math_fround($94 - $95);
 $97 = (($event) + 8|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($1) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($98 - $100);
 $102 = (HEAPF32[tempDoublePtr>>2]=$96,HEAP32[tempDoublePtr>>2]|0);
 $103 = (HEAPF32[tempDoublePtr>>2]=$101,HEAP32[tempDoublePtr>>2]|0);
 $104 = $92;
 $105 = $104;
 HEAP32[$105>>2] = $102;
 $106 = (($104) + 4)|0;
 $107 = $106;
 HEAP32[$107>>2] = $103;
 STACKTOP = sp;return;
}
function __ZN12GUIClipState10BeginOnGUIER10InputEvent($this,$event) {
 $this = $this|0;
 $event = $event|0;
 var $$ = Math_fround(0), $$pr = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $bitcast = Math_fround(0), $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $tmpcast1$byval_copy = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast1$byval_copy = sp + 64|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 140|0);
 $3 = (($event) + 4|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $2;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (($this) + 148|0);
 $bitcast = (HEAP32[tempDoublePtr>>2]=$6,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $15 = (($event) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($bitcast - $16);
 $18 = (HEAP32[tempDoublePtr>>2]=$9,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $19 = (($event) + 16|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 - $20);
 $22 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
 $23 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
 $24 = $14;
 $25 = $24;
 HEAP32[$25>>2] = $22;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = (($this) + 12|0);
 (__ZN10Matrix4x4f11SetIdentityEv($28)|0);
 $29 = (($this) + 76|0);
 (__ZN10Matrix4x4f11SetIdentityEv($29)|0);
 $30 = (($this) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$this>>2]|0;
 $33 = ($31|0)==($32|0);
 if ($33) {
  $54 = $31;
 } else {
  $34 = $32;
  $scevgep$i$i$i = (($31) + -56|0);
  $35 = (0 - ($34))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($35)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $36 = (($uglygep3$i$i$i>>>0) / 56)&-1;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i = (($31) + (($37*56)|0)|0);
  HEAP32[$30>>2] = $scevgep4$i$i$i;
  $54 = $scevgep4$i$i$i;
 }
 $38 = (($0) + 32|0);
 $39 = (($0) + 40|0);
 dest=$0+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $40 = (($0) + 16|0);
 HEAPF32[$40>>2] = Math_fround(-1.0E+4);
 $41 = (($0) + 20|0);
 HEAPF32[$41>>2] = Math_fround(-1.0E+4);
 $42 = (($0) + 24|0);
 HEAPF32[$42>>2] = Math_fround(4.0E+4);
 $43 = (($0) + 28|0);
 HEAPF32[$43>>2] = Math_fround(4.0E+4);
 HEAPF32[$0>>2] = Math_fround(-1.0E+4);
 $44 = (($0) + 4|0);
 HEAPF32[$44>>2] = Math_fround(-1.0E+4);
 $45 = (($0) + 8|0);
 HEAPF32[$45>>2] = Math_fround(4.0E+4);
 $46 = (($0) + 12|0);
 HEAPF32[$46>>2] = Math_fround(4.0E+4);
 $47 = $38;
 $48 = $47;
 HEAP32[$48>>2] = 1176256512;
 $49 = (($47) + 4)|0;
 $50 = $49;
 HEAP32[$50>>2] = 1176256512;
 $51 = (($this) + 8|0);
 ;HEAP32[$39+0>>2]=0|0;HEAP32[$39+4>>2]=0|0;HEAP32[$39+8>>2]=0|0;HEAP32[$39+12>>2]=0|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = ($54|0)==($52|0);
 if ($53) {
  __ZNSt3__16vectorI7GUIClipNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$0);
 } else {
  $55 = ($54|0)==(0|0);
  if ($55) {
   $57 = 0;
  } else {
   dest=$54+0|0; src=$0+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre$i = HEAP32[$30>>2]|0;
   $57 = $$pre$i;
  }
  $56 = (($57) + 56|0);
  HEAP32[$30>>2] = $56;
 }
 $58 = HEAP32[$event>>2]|0;
 $59 = ($58|0)==(7);
 if ($59) {
  $60 = (__Z12GetGfxDevicev()|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 780|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($60)|0);
  $65 = ($64|0)==(2);
  $$ = $65 ? Math_fround(0.5) : Math_fround(1.0);
  $$pr = HEAP32[$event>>2]|0;
  $66 = ($$pr|0)==(7);
  if ($66) {
   $67 = (__Z12GetGfxDevicev()|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + 780|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
   $72 = ($71|0)==(4);
   $73 = $72 ? 0 : 0;
   $74 = $72 ? 1056964608 : 1065353216;
   $78 = $$;$80 = $73;$85 = $74;
  } else {
   $78 = $$;$80 = 0;$85 = 1065353216;
  }
 } else {
  $78 = Math_fround(1.0);$80 = 0;$85 = 1065353216;
 }
 $75 = HEAP32[$30>>2]|0;
 $76 = (($75) + -56|0);
 $77 = (HEAPF32[tempDoublePtr>>2]=$78,HEAP32[tempDoublePtr>>2]|0);
 $79 = $77 | $80;
 $81 = $1;
 $82 = $81;
 HEAP32[$82>>2] = $79;
 $83 = (($81) + 4)|0;
 $84 = $83;
 HEAP32[$84>>2] = $85;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 __ZN12GUIClipState5ApplyER10InputEventR7GUIClip8Vector2f($this,$event,$76,$tmpcast1$byval_copy);
 STACKTOP = sp;return;
}
function __ZN12GUIClipState8EndOnGUIER10InputEvent($this,$event) {
 $this = $this|0;
 $event = $event|0;
 var $$off = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 56)&-1;
 $7 = ($5|0)==(56);
 do {
  if ($7) {
   $12 = $1;
  } else {
   $8 = HEAP32[$event>>2]|0;
   $$off = (($8) + -11)|0;
   $9 = ($$off>>>0)>(1);
   if ($9) {
    $10 = ($6>>>0)>(1);
    if ($10) {
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(611992,0,611832,416,1,0,0,0);
     $$pre = HEAP32[$0>>2]|0;
     $12 = $$pre;
     break;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(612088,0,611832,420,1,0,0,0);
    STACKTOP = sp;return;
   } else {
    $12 = $1;
   }
  }
 } while(0);
 $11 = (($12) + -56|0);
 $__new_last2$i$i$i = $11;
 $scevgep$i$i$i = (($12) + -56|0);
 $13 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($13)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $14 = (($uglygep3$i$i$i>>>0) / 56)&-1;
 $15 = $14 ^ -1;
 $scevgep4$i$i$i = (($12) + (($15*56)|0)|0);
 HEAP32[$0>>2] = $scevgep4$i$i$i;
 $16 = (($event) + 12|0);
 $17 = (($this) + 140|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 148|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($18 - $20);
 $22 = (($this) + 144|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 152|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 - $25);
 $27 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
 $28 = (HEAPF32[tempDoublePtr>>2]=$26,HEAP32[tempDoublePtr>>2]|0);
 $29 = $16;
 $30 = $29;
 HEAP32[$30>>2] = $27;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $28;
 $33 = (($event) + 4|0);
 $34 = $17;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = $33;
 $41 = $40;
 HEAP32[$41>>2] = $36;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $39;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI7GUIClipNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 56)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(76695844);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 56)&-1;
 $14 = ($13>>>0)<(38347922);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 76695844;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*56)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*56)|0)|0);
 $23 = (($22) + (($$0$i3*56)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  dest=$21+0|0; src=$__x+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $25 = (($22) + (($7*56)|0)|0);
 $26 = (($5|0) / -56)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*56)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __Z11GetGUIStatev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[612184>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN14ObjectGUIStateC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6IDListC2Ev($this);
 STACKTOP = sp;return;
}
function __ZN14ObjectGUIStateD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10OnGUIStateD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP8[$1>>0]|0;
  $4 = $3 & 1;
  $5 = ($4<<24>>24)==(0);
  if (!($5)) {
   $6 = (($1) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   __ZdlPv($7);
  }
  __ZdlPv($1);
 }
 $8 = (($this) + 72|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if (!($10)) {
   __THREW__ = 0;
   invoke_vi(3501,($9|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZdlPv($9);
    break;
   }
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   __ZdlPv($9);
   $$0 = $19;$$01 = $18;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $13 = (($this) + 76|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3501,($14|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  __ZdlPv($14);
  $$0 = $21;$$01 = $20;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  __ZdlPv($14);
  STACKTOP = sp;return;
 }
}
function __ZN10OnGUIState8EndOnGUIEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP8[$1>>0]|0;
  $4 = $3 & 1;
  $5 = ($4<<24>>24)==(0);
  if (!($5)) {
   $6 = (($1) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   __ZdlPv($7);
  }
  __ZdlPv($1);
 }
 HEAP32[$0>>2] = 0;
 $8 = (($this) + 72|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if (!($10)) {
   __THREW__ = 0;
   invoke_vi(3501,($9|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZdlPv($9);
    break;
   }
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   __ZdlPv($9);
   $$0 = $19;$$01 = $18;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$8>>2] = 0;
 $13 = (($this) + 76|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  HEAP32[$13>>2] = 0;
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3501,($14|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  __ZdlPv($14);
  $$0 = $21;$$01 = $20;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  __ZdlPv($14);
  HEAP32[$13>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN8GUIStateC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 $3 = (($this) + 76|0);
 $4 = (($this) + 44|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 48|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 52|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($this) + 56|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($this) + 28|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 32|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 36|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($this) + 40|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $12 = (($this) + 16|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($this) + 20|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($this) + 24|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($this) + 60|0);
 HEAP32[$15>>2] = 1;
 $16 = (($this) + 64|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 68|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 72|0);
 HEAP32[$18>>2] = 1;
 $19 = (($this) + 96|0);
 __THREW__ = 0;
 invoke_vi(3502,($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  $22 = (($this) + 288|0);
  $23 = (($this) + 324|0);
  HEAP32[$23>>2] = 0;
  ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;
  $24 = (($this) + 280|0);
  HEAP32[$24>>2] = 0;
  $25 = (($this) + 92|0);
  HEAP32[$25>>2] = 0;
  $26 = (($this) + 328|0);
  HEAP32[$26>>2] = 0;
  STACKTOP = sp;return;
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3503,($2|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  $eh$lpad$body$indexZ2D = $41;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)==(0|0);
 if (!($32)) {
  $33 = (($31) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5IMGUI12NamedControlEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($31,$34);
  __ZdlPv($31);
 }
 $35 = HEAP32[$1>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  ___resumeException($27|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3504,($35|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch(0|0)|0;
  $40 = tempRet0;
  __ZdlPv($35);
  $eh$lpad$body$indexZ2D = $39;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 } else {
  __ZdlPv($35);
  ___resumeException($27|0);
  // unreachable;
 }
}
function __ZN8GUIState10BeginFrameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN8GUIState10BeginOnGUIER14ObjectGUIState($this,$objectGUIState) {
 $this = $this|0;
 $objectGUIState = $objectGUIState|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 HEAP32[$0>>2] = $objectGUIState;
 $1 = (($this) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 48|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 52|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 56|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 28|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 32|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($this) + 36|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($this) + 40|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 12|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 16|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($this) + 20|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($this) + 24|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($this) + 60|0);
 HEAP32[$13>>2] = 1;
 $14 = (($this) + 64|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 68|0);
 HEAP32[$15>>2] = 1;
 __ZN6IDList10BeginOnGUIEv($objectGUIState);
 $16 = (($this) + 328|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1)|0;
 HEAP32[$16>>2] = $18;
 STACKTOP = sp;return;
}
function __ZN8GUIState8EndOnGUIEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN10OnGUIState8EndOnGUIEv($0);
 $1 = (($this) + 92|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 328|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$2>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN8GUIState8SetEventERK10InputEvent($this,$event) {
 $this = $this|0;
 $event = $event|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $invocation = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $invocation = sp;
 __ZN25ScriptingInvocationNoArgsC2Ev($invocation);
 $0 = (($invocation) + 4|0);
 $1 = (__Z19GetScriptingManagerv()|0);
 $2 = (($1) + 504|0);
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP8[$0+4>>0]=HEAP8[$2+4>>0]|0;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation)|0);
 $3 = (($this) + 280|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN10InputEventaSERKS_($4,$event);
 STACKTOP = sp;return;
}
function __ZN8GUIState24Internal_SetManagedEventEPv($this,$event) {
 $this = $this|0;
 $event = $event|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 HEAP32[$0>>2] = $event;
 STACKTOP = sp;return;
}
function __ZN8GUIState18CycleKeyboardFocusERNSt3__16vectorIP6IDListNS0_9allocatorIS3_EEEEb($this,$idListsToSearch,$searchForward) {
 $this = $this|0;
 $idListsToSearch = $idListsToSearch|0;
 $searchForward = $searchForward|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN8GUIState24GetNextKeyboardControlIDERNSt3__16vectorIP6IDListNS0_9allocatorIS3_EEEEb(0,$idListsToSearch,$searchForward)|0);
 HEAP32[$this>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN8GUIState24GetNextKeyboardControlIDERNSt3__16vectorIP6IDListNS0_9allocatorIS3_EEEEb($this,$idListsToSearch,$searchForward) {
 $this = $this|0;
 $idListsToSearch = $idListsToSearch|0;
 $searchForward = $searchForward|0;
 var $$0 = 0, $$0$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i3$05 = 0, $listIdx$0 = 0, $listIdx$0$ph = 0, $listIdx2$0 = 0, $listIdx2$0$ph = 0, $listIdx2$1 = 0, $listIdx2$1$in = 0, $startIdx1$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$idListsToSearch>>2]|0;
 $1 = (($idListsToSearch) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 L1: do {
  if ($3) {
   $$0$i = 0;
  } else {
   $7 = $0;
   while(1) {
    $6 = HEAP32[$7>>2]|0;
    $8 = (($6) + 20|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(0);
    $5 = (($7) + 4|0);
    if (!($10)) {
     $$0$i = $6;
     break L1;
    }
    $4 = ($5|0)==($2|0);
    if ($4) {
     $$0$i = 0;
     break;
    } else {
     $7 = $5;
    }
   }
  }
 } while(0);
 $11 = ($$0$i|0)!=(0|0);
 if ($searchForward) {
  L8: do {
   if ($11) {
    $12 = (($$0$i) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(-1);
    if (!($14)) {
     $$0 = $13;
     STACKTOP = sp;return ($$0|0);
    }
    $15 = $2;
    $16 = $0;
    $17 = (($15) - ($16))|0;
    $18 = $17 >> 2;
    $i$0 = 0;
    while(1) {
     $19 = ($i$0>>>0)<($18>>>0);
     if (!($19)) {
      $$pre$phiZ2D = $16;$listIdx$0$ph = -1;
      break L8;
     }
     $20 = (($0) + ($i$0<<2)|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==($$0$i|0);
     $23 = (($i$0) + 1)|0;
     if ($22) {
      break;
     } else {
      $i$0 = $23;
     }
    }
    $24 = (($23>>>0) % ($18>>>0))&-1;
    $$pre$phiZ2D = $16;$listIdx$0$ph = $24;
   } else {
    $$pre = $0;
    $$pre$phiZ2D = $$pre;$listIdx$0$ph = 0;
   }
  } while(0);
  $listIdx$0 = $listIdx$0$ph;
  while(1) {
   $25 = (($0) + ($listIdx$0<<2)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + 4|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==(-1);
   if (!($29)) {
    $$0 = $28;
    label = 26;
    break;
   }
   $30 = (($listIdx$0) + 1)|0;
   $31 = $2;
   $32 = (($31) - ($$pre$phiZ2D))|0;
   $33 = $32 >> 2;
   $34 = (($30>>>0) % ($33>>>0))&-1;
   $35 = ($34|0)==($listIdx$0$ph|0);
   if ($35) {
    $$0 = 0;
    label = 26;
    break;
   } else {
    $listIdx$0 = $34;
   }
  }
  if ((label|0) == 26) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 L26: do {
  if ($11) {
   $36 = (($$0$i) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(-1);
   if (!($38)) {
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   }
   $39 = $2;
   $40 = $0;
   $41 = (($39) - ($40))|0;
   $42 = $41 >> 2;
   if ($3) {
    $listIdx2$0$ph = $42;$startIdx1$0$ph = 0;
   } else {
    $i3$05 = 0;
    while(1) {
     $49 = (($0) + ($i3$05<<2)|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50|0)==($$0$i|0);
     $48 = (($i3$05) + 1)|0;
     if ($51) {
      $listIdx2$0$ph = $i3$05;$startIdx1$0$ph = $i3$05;
      break L26;
     }
     $47 = ($48>>>0)<($42>>>0);
     if ($47) {
      $i3$05 = $48;
     } else {
      $listIdx2$0$ph = $42;$startIdx1$0$ph = 0;
      break;
     }
    }
   }
  } else {
   $43 = $2;
   $44 = $0;
   $45 = (($43) - ($44))|0;
   $46 = $45 >> 2;
   $listIdx2$0$ph = $46;$startIdx1$0$ph = 0;
  }
 } while(0);
 $listIdx2$0 = $listIdx2$0$ph;
 while(1) {
  $52 = ($listIdx2$0|0)==(0);
  if ($52) {
   $53 = $2;
   $54 = $0;
   $55 = (($53) - ($54))|0;
   $56 = $55 >> 2;
   $listIdx2$1$in = $56;
  } else {
   $listIdx2$1$in = $listIdx2$0;
  }
  $listIdx2$1 = (($listIdx2$1$in) + -1)|0;
  $57 = (($0) + ($listIdx2$1<<2)|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + 8|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(-1);
  if (!($61)) {
   $$0 = $60;
   label = 26;
   break;
  }
  $62 = ($listIdx2$1|0)==($startIdx1$0$ph|0);
  if ($62) {
   $$0 = 0;
   label = 26;
   break;
  } else {
   $listIdx2$0 = $listIdx2$1;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN16GUIKeyboardStateC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = -1;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 1;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16GUIKeyboardState16LoadIntoGUIStateER8GUIState($this,$dest) {
 $this = $this|0;
 $dest = $dest|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 HEAP32[$dest>>2] = $0;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($dest) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($dest) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($dest) + 72|0);
 HEAP32[$9>>2] = $8;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16GUIKeyboardState16SaveFromGUIStateER8GUIState($this,$src) {
 $this = $this|0;
 $src = $src|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$src>>2]|0;
 HEAP32[$this>>2] = $0;
 $1 = (($src) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $2;
 HEAP32[$1>>2] = 0;
 $4 = (($src) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = (($src) + 72|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 4|0);
 HEAP32[$9>>2] = $8;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16GUIKeyboardState8EndFrameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN5IMGUI14GUIWindowState23ReleaseScriptingObjectsEv($1);
 STACKTOP = sp;return;
}
function __Z12InitGUIStatev() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(332)|0);
 __THREW__ = 0;
 invoke_vi(3505,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZdlPv($0);
  ___resumeException($14|0);
  // unreachable;
 }
 HEAP32[612184>>2] = $0;
 $3 = HEAP32[612192>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (__Znwj(12)|0);
  HEAP32[$5>>2] = 1;
  $6 = (($5) + 4|0);
  HEAP32[$6>>2] = 0;
  $7 = (($5) + 8|0);
  HEAP8[$7>>0] = 1;
  HEAP32[612192>>2] = $5;
  $9 = $5;
 } else {
  $9 = $3;
 }
 $8 = (($0) + 276|0);
 HEAP32[$8>>2] = $9;
 $10 = (__Znwj(44)|0);
 $11 = (($10) + 4|0);
 $12 = (($10) + 40|0);
 HEAP32[$12>>2] = 0;
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
 $13 = (($0) + 280|0);
 HEAP32[$13>>2] = $10;
 __ZN10InputEvent4InitEv($10);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5IMGUI12NamedControlEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5IMGUI12NamedControlEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEN5IMGUI12NamedControlEEENS_19__map_value_compareIS7_SA_NS_4lessIS7_EELb1EEENS5_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($__nd) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __Z24InitializeGUIClipTexturev() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = HEAP32[612216>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 126;
 $5 = (__Z12BuildTextureIhPFvP9Texture2DPhiiiiEES1_PKcii13TextureFormatRKT0_b(612224,16,16,1,$1,0)|0);
 HEAP32[612216>>2] = $5;
 __ZN7Texture13SetFilterModeEi($5,0);
 $6 = HEAP32[612216>>2]|0;
 __ZN7Texture11SetWrapModeEi($6,1);
 $7 = HEAP32[652824>>2]|0;
 $8 = (($7) + 20|0);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,612240);
 $9 = HEAP32[$0>>2]|0;
 HEAP32[$2>>2] = $9;
 $10 = HEAP32[612216>>2]|0;
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($8,$2,$10)|0);
 STACKTOP = sp;return;
}
function __Z14GUIClipTextureP9Texture2DPhiiii($tex,$data,$x,$y,$maxX,$maxY) {
 $tex = $tex|0;
 $data = $data|0;
 $x = $x|0;
 $y = $y|0;
 $maxX = $maxX|0;
 $maxY = $maxY|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $not$ = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($x|0)==(0);
 $1 = ($y|0)==(0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $storemerge = 0;
 } else {
  $2 = (($maxX) + -1)|0;
  $3 = ($2|0)==($x|0);
  if ($3) {
   $storemerge = 0;
  } else {
   $4 = (($maxY) + -1)|0;
   $not$ = ($4|0)!=($y|0);
   $$ = $not$ << 31 >> 31;
   $storemerge = $$;
  }
 }
 HEAP8[$data>>0] = $storemerge;
 STACKTOP = sp;return;
}
function __Z19GetGUIBlendMaterialv() {
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[612256>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $24 = $1;
  STACKTOP = sp;return ($24|0);
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 30;
 dest=$3+0|0; src=612264+0|0; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 30|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 $7 = (invoke_i(58)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  $10 = (invoke_iiii(1532,($7|0),48,($0|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP8[$0>>0]|0;
   $14 = $13 & 1;
   $15 = ($14<<24>>24)==(0);
   if (!($15)) {
    $16 = HEAP32[$4>>2]|0;
    __ZdlPv($16);
   }
   $17 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($10,61,0)|0);
   HEAP32[612256>>2] = $17;
   __Z24InitializeGUIClipTexturev();
   $$pre = HEAP32[612256>>2]|0;
   $24 = $$pre;
   STACKTOP = sp;return ($24|0);
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $20 = HEAP8[$0>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  ___resumeException($18|0);
  // unreachable;
 }
 $23 = HEAP32[$4>>2]|0;
 __ZdlPv($23);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __ZN8GUIStyleC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($this) + 32|0);
 $2 = (($this) + 48|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 52|0);
 $4 = (($this) + 68|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 72|0);
 $6 = (($this) + 88|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($this) + 92|0);
 $8 = (($this) + 108|0);
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 112|0);
 $10 = (($this) + 128|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($this) + 132|0);
 $12 = (($this) + 148|0);
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($this) + 152|0);
 $14 = (($this) + 168|0);
 ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($this) + 172|0);
 $16 = (($this) + 245|0);
 dest=$15+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP8[$16>>0] = 1;
 $17 = (($this) + 244|0);
 HEAP8[$17>>0] = 0;
 $18 = (($this) + 248|0);
 $19 = (($this) + 288|0);
 dest=$18+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP8[$19>>0] = 1;
 $20 = (($this) + 289|0);
 HEAP8[$20>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN8GUIStyleC2ERKS_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0);
 var $97 = 0, $98 = Math_fround(0), $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 32|0);
 $3 = (($this) + 48|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 52|0);
 $5 = (($this) + 68|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 72|0);
 $7 = (($this) + 88|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($this) + 92|0);
 $9 = (($this) + 108|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 112|0);
 $11 = (($this) + 128|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($this) + 132|0);
 $13 = (($this) + 148|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($this) + 152|0);
 $15 = (($this) + 168|0);
 ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($this) + 172|0);
 $17 = (($this) + 256|0);
 dest=$16+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;
 __THREW__ = 0;
 (invoke_iii(2359,($this|0),($other|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  $20 = (($this) + 220|0);
  $21 = (($this) + 204|0);
  $22 = (($this) + 188|0);
  $23 = (($this) + 264|0);
  $24 = (($this) + 236|0);
  $25 = (($other) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($this) + 12|0);
  HEAP32[$27>>2] = $26;
  $28 = (($other) + 16|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($other) + 20|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($other) + 24|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($other) + 28|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = (($this) + 16|0);
  HEAPF32[$36>>2] = $29;
  $37 = (($this) + 20|0);
  HEAPF32[$37>>2] = $31;
  $38 = (($this) + 24|0);
  HEAPF32[$38>>2] = $33;
  HEAPF32[$1>>2] = $35;
  $39 = (($other) + 32|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$2>>2] = $40;
  $41 = (($other) + 36|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($other) + 40|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($other) + 44|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($other) + 48|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($this) + 36|0);
  HEAPF32[$49>>2] = $42;
  $50 = (($this) + 40|0);
  HEAPF32[$50>>2] = $44;
  $51 = (($this) + 44|0);
  HEAPF32[$51>>2] = $46;
  HEAPF32[$3>>2] = $48;
  $52 = (($other) + 52|0);
  $53 = HEAP32[$52>>2]|0;
  HEAP32[$4>>2] = $53;
  $54 = (($other) + 56|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($other) + 60|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($other) + 64|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($other) + 68|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($this) + 56|0);
  HEAPF32[$62>>2] = $55;
  $63 = (($this) + 60|0);
  HEAPF32[$63>>2] = $57;
  $64 = (($this) + 64|0);
  HEAPF32[$64>>2] = $59;
  HEAPF32[$5>>2] = $61;
  $65 = (($other) + 72|0);
  $66 = HEAP32[$65>>2]|0;
  HEAP32[$6>>2] = $66;
  $67 = (($other) + 76|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($other) + 80|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = (($other) + 84|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = (($other) + 88|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($this) + 76|0);
  HEAPF32[$75>>2] = $68;
  $76 = (($this) + 80|0);
  HEAPF32[$76>>2] = $70;
  $77 = (($this) + 84|0);
  HEAPF32[$77>>2] = $72;
  HEAPF32[$7>>2] = $74;
  $78 = (($other) + 92|0);
  $79 = HEAP32[$78>>2]|0;
  HEAP32[$8>>2] = $79;
  $80 = (($other) + 96|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($other) + 100|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($other) + 104|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = (($other) + 108|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = (($this) + 96|0);
  HEAPF32[$88>>2] = $81;
  $89 = (($this) + 100|0);
  HEAPF32[$89>>2] = $83;
  $90 = (($this) + 104|0);
  HEAPF32[$90>>2] = $85;
  HEAPF32[$9>>2] = $87;
  $91 = (($other) + 112|0);
  $92 = HEAP32[$91>>2]|0;
  HEAP32[$10>>2] = $92;
  $93 = (($other) + 116|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = (($other) + 120|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = (($other) + 124|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($other) + 128|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($this) + 116|0);
  HEAPF32[$101>>2] = $94;
  $102 = (($this) + 120|0);
  HEAPF32[$102>>2] = $96;
  $103 = (($this) + 124|0);
  HEAPF32[$103>>2] = $98;
  HEAPF32[$11>>2] = $100;
  $104 = (($other) + 132|0);
  $105 = HEAP32[$104>>2]|0;
  HEAP32[$12>>2] = $105;
  $106 = (($other) + 136|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = (($other) + 140|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($other) + 144|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = (($other) + 148|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = (($this) + 136|0);
  HEAPF32[$114>>2] = $107;
  $115 = (($this) + 140|0);
  HEAPF32[$115>>2] = $109;
  $116 = (($this) + 144|0);
  HEAPF32[$116>>2] = $111;
  HEAPF32[$13>>2] = $113;
  $117 = (($other) + 152|0);
  $118 = HEAP32[$117>>2]|0;
  HEAP32[$14>>2] = $118;
  $119 = (($other) + 156|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $121 = (($other) + 160|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = (($other) + 164|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = (($other) + 168|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = (($this) + 156|0);
  HEAPF32[$127>>2] = $120;
  $128 = (($this) + 160|0);
  HEAPF32[$128>>2] = $122;
  $129 = (($this) + 164|0);
  HEAPF32[$129>>2] = $124;
  HEAPF32[$15>>2] = $126;
  $130 = (($other) + 172|0);
  ;HEAP32[$16+0>>2]=HEAP32[$130+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$130+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$130+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$130+12>>2]|0;
  $131 = (($other) + 188|0);
  ;HEAP32[$22+0>>2]=HEAP32[$131+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$131+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$131+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$131+12>>2]|0;
  $132 = (($other) + 204|0);
  ;HEAP32[$21+0>>2]=HEAP32[$132+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$132+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$132+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$132+12>>2]|0;
  $133 = (($other) + 220|0);
  ;HEAP32[$20+0>>2]=HEAP32[$133+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$133+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$133+12>>2]|0;
  $134 = (($other) + 236|0);
  $135 = HEAP32[$134>>2]|0;
  HEAP32[$24>>2] = $135;
  $136 = (($other) + 240|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = (($this) + 240|0);
  HEAP32[$138>>2] = $137;
  $139 = (($other) + 245|0);
  $140 = HEAP8[$139>>0]|0;
  $141 = (($this) + 245|0);
  HEAP8[$141>>0] = $140;
  $142 = (($other) + 244|0);
  $143 = HEAP8[$142>>0]|0;
  $144 = (($this) + 244|0);
  HEAP8[$144>>0] = $143;
  $145 = (($other) + 248|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = (($this) + 248|0);
  HEAP32[$147>>2] = $146;
  $148 = (($other) + 252|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = (($this) + 252|0);
  HEAP32[$150>>2] = $149;
  $151 = (($other) + 256|0);
  $152 = $151;
  $153 = $152;
  $154 = HEAP32[$153>>2]|0;
  $155 = (($152) + 4)|0;
  $156 = $155;
  $157 = HEAP32[$156>>2]|0;
  $158 = $17;
  $159 = $158;
  HEAP32[$159>>2] = $154;
  $160 = (($158) + 4)|0;
  $161 = $160;
  HEAP32[$161>>2] = $157;
  $162 = (($other) + 264|0);
  $163 = $162;
  $164 = $163;
  $165 = HEAP32[$164>>2]|0;
  $166 = (($163) + 4)|0;
  $167 = $166;
  $168 = HEAP32[$167>>2]|0;
  $169 = $23;
  $170 = $169;
  HEAP32[$170>>2] = $165;
  $171 = (($169) + 4)|0;
  $172 = $171;
  HEAP32[$172>>2] = $168;
  $173 = (($other) + 272|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = (($this) + 272|0);
  HEAPF32[$175>>2] = $174;
  $176 = (($other) + 276|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = (($this) + 276|0);
  HEAPF32[$178>>2] = $177;
  $179 = (($other) + 280|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = (($this) + 280|0);
  HEAP32[$181>>2] = $180;
  $182 = (($other) + 284|0);
  $183 = HEAP32[$182>>2]|0;
  $184 = (($this) + 284|0);
  HEAP32[$184>>2] = $183;
  $185 = (($other) + 288|0);
  $186 = HEAP8[$185>>0]|0;
  $187 = (($this) + 288|0);
  HEAP8[$187>>0] = $186;
  $188 = (($other) + 289|0);
  $189 = HEAP8[$188>>0]|0;
  $190 = (($this) + 289|0);
  HEAP8[$190>>0] = $189;
  STACKTOP = sp;return;
 }
 $191 = ___cxa_find_matching_catch()|0;
 $192 = tempRet0;
 $193 = HEAP8[$this>>0]|0;
 $194 = $193 & 1;
 $195 = ($194<<24>>24)==(0);
 if ($195) {
  ___resumeException($191|0);
  // unreachable;
 }
 $196 = (($this) + 8|0);
 $197 = HEAP32[$196>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($197|0),($$byval_copy|0));
 $198 = __THREW__; __THREW__ = 0;
 $199 = $198&1;
 if ($199) {
  $200 = ___cxa_find_matching_catch()|0;
  $201 = tempRet0;
  ___cxa_call_unexpected(($200|0));
  // unreachable;
 } else {
  ___resumeException($191|0);
  // unreachable;
 }
}
function __ZN8GUIStyle14SetDefaultFontEPN13TextRendering4FontE($font) {
 $font = $font|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($font|0)==(0|0);
 if (!($1)) {
  $2 = (($font) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[612200>>2] = $3;
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 18;
 $4 = (($0) + 1|0);
 dest=$4+0|0; src=612296+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $5 = (($0) + 10|0);
 HEAP8[$5>>0] = 0;
 __THREW__ = 0;
 $6 = (invoke_i(58)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __THREW__ = 0;
  $9 = (invoke_iiii(1532,($6|0),128,($0|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = ($9|0)==(0|0);
   if ($12) {
    $storemerge = 0;
   } else {
    $13 = (($9) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $storemerge = $14;
   }
   HEAP32[612200>>2] = $storemerge;
   $15 = HEAP8[$0>>0]|0;
   $16 = $15 & 1;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    STACKTOP = sp;return;
   }
   $18 = (($0) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   __ZdlPv($19);
   STACKTOP = sp;return;
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $22 = HEAP8[$0>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  ___resumeException($20|0);
  // unreachable;
 }
 $25 = (($0) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 __ZdlPv($26);
 ___resumeException($20|0);
 // unreachable;
}
function __ZNK8GUIStyle4DrawER8GUIStateRK5RectTIfER10GUIContentbbbb($this,$state,$screenRect,$content,$isHover,$isActive,$on,$hasKeyboardFocus) {
 $this = $this|0;
 $state = $state|0;
 $screenRect = $screenRect|0;
 $content = $content|0;
 $isHover = $isHover|0;
 $isActive = $isActive|0;
 $on = $on|0;
 $hasKeyboardFocus = $hasKeyboardFocus|0;
 var $$isHover = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $floorf$i$i = Math_fround(0);
 var $floorf$i$i1 = Math_fround(0), $floorf$i$i2 = Math_fround(0), $floorf$i$i3 = Math_fround(0), $not$ = 0, $rounded = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $rounded = sp;
 $0 = Math_fround(HEAPF32[$screenRect>>2]);
 $1 = (($screenRect) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 272|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = $4 != Math_fround(0.0);
 if ($5) {
  $17 = $4;
 } else {
  $6 = (($screenRect) + 8|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $17 = $7;
 }
 $8 = (($this) + 276|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = $9 != Math_fround(0.0);
 if ($10) {
  $20 = $9;
 } else {
  $11 = (($screenRect) + 12|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $20 = $12;
 }
 $13 = (($rounded) + 8|0);
 $14 = (($rounded) + 4|0);
 $15 = (($rounded) + 12|0);
 $16 = Math_fround($0 + $17);
 $18 = Math_fround($16 + Math_fround(0.5));
 $floorf$i$i = (Math_fround(Math_floor((Math_fround($18)))));
 $19 = Math_fround($20 + $2);
 $21 = Math_fround($19 + Math_fround(0.5));
 $floorf$i$i1 = (Math_fround(Math_floor((Math_fround($21)))));
 $22 = Math_fround($0 + Math_fround(0.5));
 $floorf$i$i2 = (Math_fround(Math_floor((Math_fround($22)))));
 HEAPF32[$rounded>>2] = $floorf$i$i2;
 $23 = Math_fround($2 + Math_fround(0.5));
 $floorf$i$i3 = (Math_fround(Math_floor((Math_fround($23)))));
 HEAPF32[$14>>2] = $floorf$i$i3;
 $24 = Math_fround($floorf$i$i - $floorf$i$i2);
 HEAPF32[$13>>2] = $24;
 $25 = Math_fround($floorf$i$i1 - $floorf$i$i3);
 HEAPF32[$15>>2] = $25;
 $26 = (($state) + 256|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = $floorf$i$i1 < $27;
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($state) + 264|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($27 + $30);
 $32 = $floorf$i$i3 > $31;
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($state) + 276|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 8|0);
 $36 = HEAP8[$35>>0]|0;
 $not$ = ($36<<24>>24)!=(0);
 $$isHover = $not$ & $isHover;
 $37 = (__ZNK8GUIStyle16GetGUIStyleStateER8GUIStatebbbb($this,$state,$$isHover,$isActive,$on,$hasKeyboardFocus)|0);
 __ZNK8GUIStyle14DrawBackgroundER8GUIStateRK5RectTIfEPK13GUIStyleState($this,$state,$rounded,$37);
 __ZNK8GUIStyle11DrawContentER8GUIStateRK5RectTIfER10GUIContentPK13GUIStyleState($this,$state,$rounded,$content,$37);
 STACKTOP = sp;return;
}
function __ZNK8GUIStyle16GetGUIStyleStateER8GUIStatebbbb($this,$state,$isHover,$isActive,$on,$hasKeyboardFocus) {
 $this = $this|0;
 $state = $state|0;
 $isHover = $isHover|0;
 $isActive = $isActive|0;
 $on = $on|0;
 $hasKeyboardFocus = $hasKeyboardFocus|0;
 var $$t$2 = 0, $$t$5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$demorgan = 0, $brmerge3$demorgan = 0, $phitmp = 0, $phitmp68 = 0, $phitmp69 = 0, $phitmp70 = 0, $phitmp71 = 0, $phitmp72 = 0, $phitmp73 = 0, $phitmp74 = 0, $phitmp75 = 0, $phitmp76 = 0;
 var $phitmp77 = 0, $phitmp78 = 0, $pos$i$i$i$i60 = 0, $t$0 = 0, $t$1 = 0, $t$2 = 0, $t$3 = 0, $t$4 = 0, $t$5 = 0, $t$7 = 0, $t$767 = 0, $t$8 = 0, $temp$0$i = 0, $temp$0$i15 = 0, $temp$0$i22 = 0, $temp$0$i29 = 0, $temp$0$i43 = 0, $temp$0$i50 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i60 = sp + 40|0;
 $0 = sp + 36|0;
 $1 = sp + 32|0;
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = sp + 20|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 $9 = sp + 16|0;
 L1: do {
  if ($on) {
   if ($isHover) {
    $159 = (($this) + 112|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = ($160|0)==(0);
    if ($161) {
     $t$3 = 0;
    } else {
     HEAP32[$5>>2] = $160;
     $162 = HEAP32[560624>>2]|0;
     $163 = ($162|0)==(0|0);
     if ($163) {
      label = 59;
     } else {
      $164 = (($162) + 36|0);
      $165 = HEAP32[$164>>2]|0;
      $166 = (($162) + 4|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = ($165|0)==($167|0);
      do {
       if ($168) {
        $169 = (($162) + 28|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = (($162) + 32|0);
        $172 = HEAP32[$171>>2]|0;
        $173 = (($170) + ($172<<3)|0);
        $189 = $173;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$162,$5);
        $174 = HEAP32[$pos$i$i$i$i60>>2]|0;
        $175 = ($174|0)==(-1);
        $176 = (($162) + 28|0);
        $177 = HEAP32[$176>>2]|0;
        if ($175) {
         $178 = (($162) + 32|0);
         $179 = HEAP32[$178>>2]|0;
         $180 = (($177) + ($179<<3)|0);
         $189 = $180;
         break;
        } else {
         $181 = (($177) + ($174<<3)|0);
         $189 = $181;
         break;
        }
       }
      } while(0);
      $182 = HEAP32[560624>>2]|0;
      $183 = (($182) + 28|0);
      $184 = HEAP32[$183>>2]|0;
      $185 = (($182) + 32|0);
      $186 = HEAP32[$185>>2]|0;
      $187 = (($184) + ($186<<3)|0);
      $188 = ($189|0)==($187|0);
      if ($188) {
       label = 59;
      } else {
       $190 = (($189) + 4|0);
       $191 = HEAP32[$190>>2]|0;
       $192 = ($191|0)==(0|0);
       if ($192) {
        label = 59;
       } else {
        $temp$0$i29 = $191;
       }
      }
     }
     if ((label|0) == 59) {
      $193 = HEAP32[$159>>2]|0;
      $194 = (__Z31ReadObjectFromPersistentManageri($193)|0);
      $temp$0$i29 = $194;
     }
     $phitmp77 = ($temp$0$i29|0)!=(0|0);
     $phitmp78 = $phitmp77 ? $159 : 0;
     $t$3 = $phitmp78;
    }
   } else {
    $t$3 = 0;
   }
   do {
    if ($hasKeyboardFocus) {
     $195 = (($this) + 152|0);
     $196 = HEAP32[$195>>2]|0;
     $197 = ($196|0)==(0);
     if (!($197)) {
      HEAP32[$4>>2] = $196;
      $198 = HEAP32[560624>>2]|0;
      $199 = ($198|0)==(0|0);
      if (!($199)) {
       $200 = (($198) + 36|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = (($198) + 4|0);
       $203 = HEAP32[$202>>2]|0;
       $204 = ($201|0)==($203|0);
       do {
        if ($204) {
         $205 = (($198) + 28|0);
         $206 = HEAP32[$205>>2]|0;
         $207 = (($198) + 32|0);
         $208 = HEAP32[$207>>2]|0;
         $209 = (($206) + ($208<<3)|0);
         $225 = $209;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$198,$4);
         $210 = HEAP32[$pos$i$i$i$i60>>2]|0;
         $211 = ($210|0)==(-1);
         $212 = (($198) + 28|0);
         $213 = HEAP32[$212>>2]|0;
         if ($211) {
          $214 = (($198) + 32|0);
          $215 = HEAP32[$214>>2]|0;
          $216 = (($213) + ($215<<3)|0);
          $225 = $216;
          break;
         } else {
          $217 = (($213) + ($210<<3)|0);
          $225 = $217;
          break;
         }
        }
       } while(0);
       $218 = HEAP32[560624>>2]|0;
       $219 = (($218) + 28|0);
       $220 = HEAP32[$219>>2]|0;
       $221 = (($218) + 32|0);
       $222 = HEAP32[$221>>2]|0;
       $223 = (($220) + ($222<<3)|0);
       $224 = ($225|0)==($223|0);
       if (!($224)) {
        $226 = (($225) + 4|0);
        $227 = HEAP32[$226>>2]|0;
        $228 = ($227|0)==(0|0);
        if (!($228)) {
         $t$4 = $195;
         break;
        }
       }
      }
      $229 = HEAP32[$195>>2]|0;
      $230 = (__Z31ReadObjectFromPersistentManageri($229)|0);
      $231 = ($230|0)==(0|0);
      if (!($231)) {
       $t$4 = $195;
       break;
      }
     }
     $232 = (($this) + 112|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = ($233|0)==(0);
     if ($234) {
      $t$4 = $t$3;
     } else {
      HEAP32[$3>>2] = $233;
      $235 = HEAP32[560624>>2]|0;
      $236 = ($235|0)==(0|0);
      if ($236) {
       label = 81;
      } else {
       $237 = (($235) + 36|0);
       $238 = HEAP32[$237>>2]|0;
       $239 = (($235) + 4|0);
       $240 = HEAP32[$239>>2]|0;
       $241 = ($238|0)==($240|0);
       do {
        if ($241) {
         $242 = (($235) + 28|0);
         $243 = HEAP32[$242>>2]|0;
         $244 = (($235) + 32|0);
         $245 = HEAP32[$244>>2]|0;
         $246 = (($243) + ($245<<3)|0);
         $262 = $246;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$235,$3);
         $247 = HEAP32[$pos$i$i$i$i60>>2]|0;
         $248 = ($247|0)==(-1);
         $249 = (($235) + 28|0);
         $250 = HEAP32[$249>>2]|0;
         if ($248) {
          $251 = (($235) + 32|0);
          $252 = HEAP32[$251>>2]|0;
          $253 = (($250) + ($252<<3)|0);
          $262 = $253;
          break;
         } else {
          $254 = (($250) + ($247<<3)|0);
          $262 = $254;
          break;
         }
        }
       } while(0);
       $255 = HEAP32[560624>>2]|0;
       $256 = (($255) + 28|0);
       $257 = HEAP32[$256>>2]|0;
       $258 = (($255) + 32|0);
       $259 = HEAP32[$258>>2]|0;
       $260 = (($257) + ($259<<3)|0);
       $261 = ($262|0)==($260|0);
       if ($261) {
        label = 81;
       } else {
        $263 = (($262) + 4|0);
        $264 = HEAP32[$263>>2]|0;
        $265 = ($264|0)==(0|0);
        if ($265) {
         label = 81;
        } else {
         $temp$0$i43 = $264;
        }
       }
      }
      if ((label|0) == 81) {
       $266 = HEAP32[$232>>2]|0;
       $267 = (__Z31ReadObjectFromPersistentManageri($266)|0);
       $temp$0$i43 = $267;
      }
      $phitmp75 = ($temp$0$i43|0)!=(0|0);
      $phitmp76 = $phitmp75 ? $232 : $t$3;
      $t$4 = $phitmp76;
     }
    } else {
     $t$4 = $t$3;
    }
   } while(0);
   $brmerge3$demorgan = $isActive & $isHover;
   if ($brmerge3$demorgan) {
    $268 = (($this) + 132|0);
    $269 = HEAP32[$268>>2]|0;
    $270 = ($269|0)==(0);
    if ($270) {
     $t$5 = $t$4;
    } else {
     HEAP32[$2>>2] = $269;
     $271 = HEAP32[560624>>2]|0;
     $272 = ($271|0)==(0|0);
     if ($272) {
      label = 93;
     } else {
      $273 = (($271) + 36|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = (($271) + 4|0);
      $276 = HEAP32[$275>>2]|0;
      $277 = ($274|0)==($276|0);
      do {
       if ($277) {
        $278 = (($271) + 28|0);
        $279 = HEAP32[$278>>2]|0;
        $280 = (($271) + 32|0);
        $281 = HEAP32[$280>>2]|0;
        $282 = (($279) + ($281<<3)|0);
        $298 = $282;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$271,$2);
        $283 = HEAP32[$pos$i$i$i$i60>>2]|0;
        $284 = ($283|0)==(-1);
        $285 = (($271) + 28|0);
        $286 = HEAP32[$285>>2]|0;
        if ($284) {
         $287 = (($271) + 32|0);
         $288 = HEAP32[$287>>2]|0;
         $289 = (($286) + ($288<<3)|0);
         $298 = $289;
         break;
        } else {
         $290 = (($286) + ($283<<3)|0);
         $298 = $290;
         break;
        }
       }
      } while(0);
      $291 = HEAP32[560624>>2]|0;
      $292 = (($291) + 28|0);
      $293 = HEAP32[$292>>2]|0;
      $294 = (($291) + 32|0);
      $295 = HEAP32[$294>>2]|0;
      $296 = (($293) + ($295<<3)|0);
      $297 = ($298|0)==($296|0);
      if ($297) {
       label = 93;
      } else {
       $299 = (($298) + 4|0);
       $300 = HEAP32[$299>>2]|0;
       $301 = ($300|0)==(0|0);
       if ($301) {
        label = 93;
       } else {
        $temp$0$i50 = $300;
       }
      }
     }
     if ((label|0) == 93) {
      $302 = HEAP32[$268>>2]|0;
      $303 = (__Z31ReadObjectFromPersistentManageri($302)|0);
      $temp$0$i50 = $303;
     }
     $phitmp73 = ($temp$0$i50|0)!=(0|0);
     $phitmp74 = $phitmp73 ? $268 : $t$4;
     $t$5 = $phitmp74;
    }
   } else {
    $t$5 = $t$4;
   }
   $304 = (($state) + 60|0);
   $305 = HEAP32[$304>>2]|0;
   $306 = ($305|0)==(0);
   $307 = (($this) + 12|0);
   $$t$5 = $306 ? $307 : $t$5;
   $308 = ($$t$5|0)==(0|0);
   do {
    if (!($308)) {
     $309 = HEAP32[$$t$5>>2]|0;
     $310 = ($309|0)==(0);
     if (!($310)) {
      HEAP32[$1>>2] = $309;
      $311 = HEAP32[560624>>2]|0;
      $312 = ($311|0)==(0|0);
      if ($312) {
       label = 105;
      } else {
       $313 = (($311) + 36|0);
       $314 = HEAP32[$313>>2]|0;
       $315 = (($311) + 4|0);
       $316 = HEAP32[$315>>2]|0;
       $317 = ($314|0)==($316|0);
       do {
        if ($317) {
         $318 = (($311) + 28|0);
         $319 = HEAP32[$318>>2]|0;
         $320 = (($311) + 32|0);
         $321 = HEAP32[$320>>2]|0;
         $322 = (($319) + ($321<<3)|0);
         $338 = $322;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$311,$1);
         $323 = HEAP32[$pos$i$i$i$i60>>2]|0;
         $324 = ($323|0)==(-1);
         $325 = (($311) + 28|0);
         $326 = HEAP32[$325>>2]|0;
         if ($324) {
          $327 = (($311) + 32|0);
          $328 = HEAP32[$327>>2]|0;
          $329 = (($326) + ($328<<3)|0);
          $338 = $329;
          break;
         } else {
          $330 = (($326) + ($323<<3)|0);
          $338 = $330;
          break;
         }
        }
       } while(0);
       $331 = HEAP32[560624>>2]|0;
       $332 = (($331) + 28|0);
       $333 = HEAP32[$332>>2]|0;
       $334 = (($331) + 32|0);
       $335 = HEAP32[$334>>2]|0;
       $336 = (($333) + ($335<<3)|0);
       $337 = ($338|0)==($336|0);
       if ($337) {
        label = 105;
       } else {
        $339 = (($338) + 4|0);
        $340 = HEAP32[$339>>2]|0;
        $341 = ($340|0)==(0|0);
        if ($341) {
         label = 105;
        }
       }
      }
      if ((label|0) == 105) {
       $342 = HEAP32[$$t$5>>2]|0;
       $343 = (__Z31ReadObjectFromPersistentManageri($342)|0);
       $344 = ($343|0)==(0|0);
       if ($344) {
        break;
       }
      }
      $345 = HEAP32[$304>>2]|0;
      $346 = ($345|0)==(0);
      if (!($346)) {
       $t$7 = $$t$5;
       label = 108;
       break L1;
      }
     }
    }
   } while(0);
   $347 = (($this) + 92|0);
   $t$767 = $347;
   label = 109;
  } else {
   if ($isHover) {
    $10 = (($this) + 32|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0);
    if ($12) {
     $t$0 = 0;
    } else {
     HEAP32[$9>>2] = $11;
     $13 = HEAP32[560624>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 12;
     } else {
      $15 = (($13) + 36|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($13) + 4|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($16|0)==($18|0);
      do {
       if ($19) {
        $20 = (($13) + 28|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = (($13) + 32|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = (($21) + ($23<<3)|0);
        $40 = $24;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$13,$9);
        $25 = HEAP32[$pos$i$i$i$i60>>2]|0;
        $26 = ($25|0)==(-1);
        $27 = (($13) + 28|0);
        $28 = HEAP32[$27>>2]|0;
        if ($26) {
         $29 = (($13) + 32|0);
         $30 = HEAP32[$29>>2]|0;
         $31 = (($28) + ($30<<3)|0);
         $40 = $31;
         break;
        } else {
         $32 = (($28) + ($25<<3)|0);
         $40 = $32;
         break;
        }
       }
      } while(0);
      $33 = HEAP32[560624>>2]|0;
      $34 = (($33) + 28|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = (($33) + 32|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($35) + ($37<<3)|0);
      $39 = ($40|0)==($38|0);
      if ($39) {
       label = 12;
      } else {
       $41 = (($40) + 4|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        label = 12;
       } else {
        $temp$0$i = $42;
       }
      }
     }
     if ((label|0) == 12) {
      $44 = HEAP32[$10>>2]|0;
      $45 = (__Z31ReadObjectFromPersistentManageri($44)|0);
      $temp$0$i = $45;
     }
     $phitmp71 = ($temp$0$i|0)!=(0|0);
     $phitmp72 = $phitmp71 ? $10 : 0;
     $t$0 = $phitmp72;
    }
   } else {
    $t$0 = 0;
   }
   do {
    if ($hasKeyboardFocus) {
     $46 = (($this) + 72|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==(0);
     if (!($48)) {
      HEAP32[$8>>2] = $47;
      $49 = HEAP32[560624>>2]|0;
      $50 = ($49|0)==(0|0);
      if (!($50)) {
       $51 = (($49) + 36|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($49) + 4|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = ($52|0)==($54|0);
       do {
        if ($55) {
         $56 = (($49) + 28|0);
         $57 = HEAP32[$56>>2]|0;
         $58 = (($49) + 32|0);
         $59 = HEAP32[$58>>2]|0;
         $60 = (($57) + ($59<<3)|0);
         $76 = $60;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$49,$8);
         $61 = HEAP32[$pos$i$i$i$i60>>2]|0;
         $62 = ($61|0)==(-1);
         $63 = (($49) + 28|0);
         $64 = HEAP32[$63>>2]|0;
         if ($62) {
          $65 = (($49) + 32|0);
          $66 = HEAP32[$65>>2]|0;
          $67 = (($64) + ($66<<3)|0);
          $76 = $67;
          break;
         } else {
          $68 = (($64) + ($61<<3)|0);
          $76 = $68;
          break;
         }
        }
       } while(0);
       $69 = HEAP32[560624>>2]|0;
       $70 = (($69) + 28|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = (($69) + 32|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = (($71) + ($73<<3)|0);
       $75 = ($76|0)==($74|0);
       if (!($75)) {
        $77 = (($76) + 4|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = ($78|0)==(0|0);
        if (!($79)) {
         $t$1 = $46;
         break;
        }
       }
      }
      $80 = HEAP32[$46>>2]|0;
      $81 = (__Z31ReadObjectFromPersistentManageri($80)|0);
      $82 = ($81|0)==(0|0);
      if (!($82)) {
       $t$1 = $46;
       break;
      }
     }
     $83 = (($this) + 32|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ($84|0)==(0);
     if ($85) {
      $t$1 = $t$0;
     } else {
      HEAP32[$7>>2] = $84;
      $86 = HEAP32[560624>>2]|0;
      $87 = ($86|0)==(0|0);
      if ($87) {
       label = 34;
      } else {
       $88 = (($86) + 36|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = (($86) + 4|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($89|0)==($91|0);
       do {
        if ($92) {
         $93 = (($86) + 28|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = (($86) + 32|0);
         $96 = HEAP32[$95>>2]|0;
         $97 = (($94) + ($96<<3)|0);
         $113 = $97;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$86,$7);
         $98 = HEAP32[$pos$i$i$i$i60>>2]|0;
         $99 = ($98|0)==(-1);
         $100 = (($86) + 28|0);
         $101 = HEAP32[$100>>2]|0;
         if ($99) {
          $102 = (($86) + 32|0);
          $103 = HEAP32[$102>>2]|0;
          $104 = (($101) + ($103<<3)|0);
          $113 = $104;
          break;
         } else {
          $105 = (($101) + ($98<<3)|0);
          $113 = $105;
          break;
         }
        }
       } while(0);
       $106 = HEAP32[560624>>2]|0;
       $107 = (($106) + 28|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = (($106) + 32|0);
       $110 = HEAP32[$109>>2]|0;
       $111 = (($108) + ($110<<3)|0);
       $112 = ($113|0)==($111|0);
       if ($112) {
        label = 34;
       } else {
        $114 = (($113) + 4|0);
        $115 = HEAP32[$114>>2]|0;
        $116 = ($115|0)==(0|0);
        if ($116) {
         label = 34;
        } else {
         $temp$0$i15 = $115;
        }
       }
      }
      if ((label|0) == 34) {
       $117 = HEAP32[$83>>2]|0;
       $118 = (__Z31ReadObjectFromPersistentManageri($117)|0);
       $temp$0$i15 = $118;
      }
      $phitmp69 = ($temp$0$i15|0)!=(0|0);
      $phitmp70 = $phitmp69 ? $83 : $t$0;
      $t$1 = $phitmp70;
     }
    } else {
     $t$1 = $t$0;
    }
   } while(0);
   $brmerge$demorgan = $isActive & $isHover;
   if ($brmerge$demorgan) {
    $119 = (($this) + 52|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = ($120|0)==(0);
    if ($121) {
     $t$2 = $t$1;
    } else {
     HEAP32[$6>>2] = $120;
     $122 = HEAP32[560624>>2]|0;
     $123 = ($122|0)==(0|0);
     if ($123) {
      label = 46;
     } else {
      $124 = (($122) + 36|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = (($122) + 4|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ($125|0)==($127|0);
      do {
       if ($128) {
        $129 = (($122) + 28|0);
        $130 = HEAP32[$129>>2]|0;
        $131 = (($122) + 32|0);
        $132 = HEAP32[$131>>2]|0;
        $133 = (($130) + ($132<<3)|0);
        $149 = $133;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$122,$6);
        $134 = HEAP32[$pos$i$i$i$i60>>2]|0;
        $135 = ($134|0)==(-1);
        $136 = (($122) + 28|0);
        $137 = HEAP32[$136>>2]|0;
        if ($135) {
         $138 = (($122) + 32|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = (($137) + ($139<<3)|0);
         $149 = $140;
         break;
        } else {
         $141 = (($137) + ($134<<3)|0);
         $149 = $141;
         break;
        }
       }
      } while(0);
      $142 = HEAP32[560624>>2]|0;
      $143 = (($142) + 28|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($142) + 32|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = (($144) + ($146<<3)|0);
      $148 = ($149|0)==($147|0);
      if ($148) {
       label = 46;
      } else {
       $150 = (($149) + 4|0);
       $151 = HEAP32[$150>>2]|0;
       $152 = ($151|0)==(0|0);
       if ($152) {
        label = 46;
       } else {
        $temp$0$i22 = $151;
       }
      }
     }
     if ((label|0) == 46) {
      $153 = HEAP32[$119>>2]|0;
      $154 = (__Z31ReadObjectFromPersistentManageri($153)|0);
      $temp$0$i22 = $154;
     }
     $phitmp = ($temp$0$i22|0)!=(0|0);
     $phitmp68 = $phitmp ? $119 : $t$1;
     $t$2 = $phitmp68;
    }
   } else {
    $t$2 = $t$1;
   }
   $155 = (($state) + 60|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = ($156|0)==(0);
   $158 = (($this) + 12|0);
   $$t$2 = $157 ? $158 : $t$2;
   $t$7 = $$t$2;
   label = 108;
  }
 } while(0);
 if ((label|0) == 108) {
  $348 = ($t$7|0)==(0|0);
  if (!($348)) {
   $t$767 = $t$7;
   label = 109;
  }
 }
 if ((label|0) == 109) {
  $349 = HEAP32[$t$767>>2]|0;
  $350 = ($349|0)==(0);
  if (!($350)) {
   HEAP32[$0>>2] = $349;
   $351 = HEAP32[560624>>2]|0;
   $352 = ($351|0)==(0|0);
   if (!($352)) {
    $353 = (($351) + 36|0);
    $354 = HEAP32[$353>>2]|0;
    $355 = (($351) + 4|0);
    $356 = HEAP32[$355>>2]|0;
    $357 = ($354|0)==($356|0);
    do {
     if ($357) {
      $358 = (($351) + 28|0);
      $359 = HEAP32[$358>>2]|0;
      $360 = (($351) + 32|0);
      $361 = HEAP32[$360>>2]|0;
      $362 = (($359) + ($361<<3)|0);
      $378 = $362;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i60,$351,$0);
      $363 = HEAP32[$pos$i$i$i$i60>>2]|0;
      $364 = ($363|0)==(-1);
      $365 = (($351) + 28|0);
      $366 = HEAP32[$365>>2]|0;
      if ($364) {
       $367 = (($351) + 32|0);
       $368 = HEAP32[$367>>2]|0;
       $369 = (($366) + ($368<<3)|0);
       $378 = $369;
       break;
      } else {
       $370 = (($366) + ($363<<3)|0);
       $378 = $370;
       break;
      }
     }
    } while(0);
    $371 = HEAP32[560624>>2]|0;
    $372 = (($371) + 28|0);
    $373 = HEAP32[$372>>2]|0;
    $374 = (($371) + 32|0);
    $375 = HEAP32[$374>>2]|0;
    $376 = (($373) + ($375<<3)|0);
    $377 = ($378|0)==($376|0);
    if (!($377)) {
     $379 = (($378) + 4|0);
     $380 = HEAP32[$379>>2]|0;
     $381 = ($380|0)==(0|0);
     if (!($381)) {
      $t$8 = $t$767;
      STACKTOP = sp;return ($t$8|0);
     }
    }
   }
   $382 = HEAP32[$t$767>>2]|0;
   $383 = (__Z31ReadObjectFromPersistentManageri($382)|0);
   $384 = ($383|0)==(0|0);
   if (!($384)) {
    $t$8 = $t$767;
    STACKTOP = sp;return ($t$8|0);
   }
  }
 }
 $385 = (($this) + 12|0);
 $t$8 = $385;
 STACKTOP = sp;return ($t$8|0);
}
function __ZNK8GUIStyle14DrawBackgroundER8GUIStateRK5RectTIfEPK13GUIStyleState($this,$state,$screenRect,$gss) {
 $this = $this|0;
 $state = $state|0;
 $screenRect = $screenRect|0;
 $gss = $gss|0;
 var $$0$i6 = 0, $$byval_copy = 0, $$op$i$i$i$i$i = Math_fround(0), $$op$i1$i$i$i$i = Math_fround(0), $$op$i2$i$i$i$i = Math_fround(0), $$op$i3$i$i$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0);
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0);
 var $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0;
 var $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $temp$0$i5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 16|0;
 $4 = (($state) + 252|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($state) + 256|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($state) + 260|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($state) + 264|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 (__ZN10Matrix4x4f11SetIdentityEv($$byval_copy)|0);
 $12 = $9 > Math_fround(0.0);
 if ($12) {
  $13 = Math_fround(Math_fround(0.875) / $9);
  HEAPF32[$$byval_copy>>2] = $13;
  $19 = $13;
 } else {
  HEAPF32[$$byval_copy>>2] = Math_fround(inf);
  $19 = Math_fround(inf);
 }
 $14 = $11 > Math_fround(0.0);
 if ($14) {
  $15 = Math_fround(Math_fround(0.875) / $11);
  $16 = (($$byval_copy) + 20|0);
  HEAPF32[$16>>2] = $15;
  $23 = $15;
 } else {
  $17 = (($$byval_copy) + 20|0);
  HEAPF32[$17>>2] = Math_fround(inf);
  $23 = Math_fround(inf);
 }
 $18 = Math_fround($5 * $19);
 $20 = Math_fround(Math_fround(0.0625) - $18);
 $21 = (($$byval_copy) + 48|0);
 HEAPF32[$21>>2] = $20;
 $22 = Math_fround($7 * $23);
 $24 = Math_fround(Math_fround(0.0625) - $22);
 $25 = (($$byval_copy) + 52|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($$byval_copy) + 60|0);
 $27 = (($$byval_copy) + 40|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $28 = (($$byval_copy) + 56|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (__Z12GetGfxDevicev()|0);
 $30 = (($29) + 3492|0);
 dest=$30+0|0; src=$$byval_copy+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $31 = HEAP32[$gss>>2]|0;
 $32 = ($31|0)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $31;
 $33 = HEAP32[560624>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  label = 16;
 } else {
  $35 = (($33) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($33) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($36|0)==($38|0);
  do {
   if ($39) {
    $40 = (($33) + 28|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($33) + 32|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($41) + ($43<<3)|0);
    $60 = $44;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$33,$1);
    $45 = HEAP32[$$byval_copy>>2]|0;
    $46 = ($45|0)==(-1);
    $47 = (($33) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    if ($46) {
     $49 = (($33) + 32|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (($48) + ($50<<3)|0);
     $60 = $51;
     break;
    } else {
     $52 = (($48) + ($45<<3)|0);
     $60 = $52;
     break;
    }
   }
  } while(0);
  $53 = HEAP32[560624>>2]|0;
  $54 = (($53) + 28|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($53) + 32|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($55) + ($57<<3)|0);
  $59 = ($60|0)==($58|0);
  if ($59) {
   label = 16;
  } else {
   $61 = (($60) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==(0|0);
   if ($63) {
    label = 16;
   }
  }
 }
 if ((label|0) == 16) {
  $64 = HEAP32[$gss>>2]|0;
  $65 = (__Z31ReadObjectFromPersistentManageri($64)|0);
  $66 = ($65|0)==(0|0);
  if ($66) {
   STACKTOP = sp;return;
  }
 }
 $67 = (($state) + 12|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($state) + 28|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($68 * $70);
 $72 = (($state) + 16|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($state) + 32|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($73 * $75);
 $77 = (($state) + 20|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($state) + 36|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($78 * $80);
 $82 = (($state) + 24|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($state) + 40|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($83 * $85);
 $87 = (($state) + 60|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0);
 if ($89) {
  $90 = Math_fround($86 * Math_fround(0.5));
  $196 = $90;
 } else {
  $196 = $86;
 }
 $91 = Math_fround(HEAPF32[$screenRect>>2]);
 $92 = (($this) + 220|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (Math_fround(($93|0)));
 $95 = Math_fround($91 - $94);
 $96 = (($screenRect) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($this) + 228|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = (Math_fround(($99|0)));
 $101 = Math_fround($97 - $100);
 $102 = (($screenRect) + 8|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = Math_fround($91 + $103);
 $105 = (($this) + 224|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = (Math_fround(($106|0)));
 $108 = Math_fround($104 + $107);
 $109 = (($screenRect) + 12|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround($97 + $110);
 $112 = (($this) + 232|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (Math_fround(($113|0)));
 $115 = Math_fround($111 + $114);
 $116 = Math_fround($108 - $95);
 $117 = Math_fround($115 - $101);
 HEAPF32[$3>>2] = $95;
 $118 = (($3) + 8|0);
 HEAPF32[$118>>2] = $116;
 $119 = (($3) + 4|0);
 HEAPF32[$119>>2] = $101;
 $120 = (($3) + 12|0);
 HEAPF32[$120>>2] = $117;
 $121 = HEAP32[$gss>>2]|0;
 $122 = ($121|0)==(0);
 if ($122) {
  $$0$i6 = 0;
 } else {
  HEAP32[$0>>2] = $121;
  $123 = HEAP32[560624>>2]|0;
  $124 = ($123|0)==(0|0);
  if ($124) {
   label = 28;
  } else {
   $125 = (($123) + 36|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = (($123) + 4|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = ($126|0)==($128|0);
   do {
    if ($129) {
     $130 = (($123) + 28|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = (($123) + 32|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = (($131) + ($133<<3)|0);
     $150 = $134;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$123,$0);
     $135 = HEAP32[$$byval_copy>>2]|0;
     $136 = ($135|0)==(-1);
     $137 = (($123) + 28|0);
     $138 = HEAP32[$137>>2]|0;
     if ($136) {
      $139 = (($123) + 32|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = (($138) + ($140<<3)|0);
      $150 = $141;
      break;
     } else {
      $142 = (($138) + ($135<<3)|0);
      $150 = $142;
      break;
     }
    }
   } while(0);
   $143 = HEAP32[560624>>2]|0;
   $144 = (($143) + 28|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = (($143) + 32|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = (($145) + ($147<<3)|0);
   $149 = ($150|0)==($148|0);
   if ($149) {
    label = 28;
   } else {
    $151 = (($150) + 4|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152|0)==(0|0);
    if ($153) {
     label = 28;
    } else {
     $temp$0$i5 = $152;
    }
   }
  }
  if ((label|0) == 28) {
   $154 = HEAP32[$gss>>2]|0;
   $155 = (__Z31ReadObjectFromPersistentManageri($154)|0);
   $temp$0$i5 = $155;
  }
  $$0$i6 = $temp$0$i5;
 }
 $156 = (($this) + 172|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = (Math_fround(($157|0)));
 $159 = (($this) + 176|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = (Math_fround(($160|0)));
 $162 = (($this) + 180|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = (Math_fround(($163|0)));
 $165 = (($this) + 184|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = (Math_fround(($166|0)));
 $168 = (~~(($158)));
 $169 = (~~(($161)));
 $170 = (~~(($164)));
 $171 = (~~(($167)));
 $172 = $71 < Math_fround(0.0);
 $173 = $172 ? Math_fround(0.0) : $71;
 $174 = $173 > Math_fround(1.0);
 $$op$i$i$i$i$i = Math_fround($173 * Math_fround(255.0));
 $175 = $174 ? Math_fround(255.0) : $$op$i$i$i$i$i;
 $176 = Math_fround($175 + Math_fround(0.5));
 $177 = (~~(($176))>>>0);
 $178 = $177&255;
 HEAP8[$2>>0] = $178;
 $179 = $76 < Math_fround(0.0);
 $180 = $179 ? Math_fround(0.0) : $76;
 $181 = $180 > Math_fround(1.0);
 $$op$i3$i$i$i$i = Math_fround($180 * Math_fround(255.0));
 $182 = $181 ? Math_fround(255.0) : $$op$i3$i$i$i$i;
 $183 = Math_fround($182 + Math_fround(0.5));
 $184 = (~~(($183))>>>0);
 $185 = $184&255;
 $186 = (($2) + 1|0);
 HEAP8[$186>>0] = $185;
 $187 = $81 < Math_fround(0.0);
 $188 = $187 ? Math_fround(0.0) : $81;
 $189 = $188 > Math_fround(1.0);
 $$op$i2$i$i$i$i = Math_fround($188 * Math_fround(255.0));
 $190 = $189 ? Math_fround(255.0) : $$op$i2$i$i$i$i;
 $191 = Math_fround($190 + Math_fround(0.5));
 $192 = (~~(($191))>>>0);
 $193 = $192&255;
 $194 = (($2) + 2|0);
 HEAP8[$194>>0] = $193;
 $195 = $196 < Math_fround(0.0);
 $197 = $195 ? Math_fround(0.0) : $196;
 $198 = $197 > Math_fround(1.0);
 $$op$i1$i$i$i$i = Math_fround($197 * Math_fround(255.0));
 $199 = $198 ? Math_fround(255.0) : $$op$i1$i$i$i$i;
 $200 = Math_fround($199 + Math_fround(0.5));
 $201 = (~~(($200))>>>0);
 $202 = $201&255;
 $203 = (($2) + 3|0);
 HEAP8[$203>>0] = $202;
 $204 = (__Z19GetGUIBlendMaterialv()|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
 __Z14DrawGUITextureRK5RectTIfEP7Textureiiii11ColorRGBA32PN5Unity8MaterialE($3,$$0$i6,$168,$169,$170,$171,$$byval_copy,$204);
 STACKTOP = sp;return;
}
function __ZNK8GUIStyle11DrawContentER8GUIStateRK5RectTIfER10GUIContentPK13GUIStyleState($this,$state,$screenRect,$content,$gss) {
 $this = $this|0;
 $state = $state|0;
 $screenRect = $screenRect|0;
 $content = $content|0;
 $gss = $gss|0;
 var $$0$i20 = 0, $$byval_copy1 = 0, $$in = 0, $$op$i$i$i$i = Math_fround(0), $$op$i$i$i$i$i = Math_fround(0), $$op$i1$i$i$i = Math_fround(0), $$op$i1$i$i$i$i = Math_fround(0), $$op$i2$i$i$i = Math_fround(0), $$op$i2$i$i$i$i = Math_fround(0), $$op$i3$i$i$i = Math_fround(0), $$op$i3$i$i$i$i = Math_fround(0), $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0);
 var $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = 0;
 var $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0;
 var $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0;
 var $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0);
 var $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = Math_fround(0), $339 = 0;
 var $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = 0;
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = 0;
 var $376 = Math_fround(0), $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0;
 var $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0;
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $contentRect = 0, $height = 0, $imageRect = 0, $needClipping$0$off0 = 0, $or$cond = 0, $or$cond21 = 0, $phitmp = 0, $phitmp22 = 0, $phitmp26 = 0, $phitmp27 = 0, $storemerge$i = Math_fround(0), $storemerge1$i = Math_fround(0), $temp$0$i32 = 0, $textRect = 0, $tmgen$0 = 0, $tmpcast$byval_copy = 0;
 var $tmpcast2$byval_copy = 0, $width = 0, $x2$0$i = Math_fround(0), $y2$0$i = Math_fround(0), dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy1 = sp + 136|0;
 $tmpcast2$byval_copy = sp + 120|0;
 $tmpcast$byval_copy = sp + 112|0;
 $0 = sp + 104|0;
 $imageRect = sp + 88|0;
 $textRect = sp + 72|0;
 $width = sp + 64|0;
 $height = sp + 40|0;
 $contentRect = sp + 24|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = sp + 48|0;
 $5 = (($state) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($state) + 44|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = (($state) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($state) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 * $13);
 $15 = (($state) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($state) + 52|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = (($state) + 24|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($state) + 56|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 * $23);
 $25 = (($gss) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($9 * $26);
 $28 = (($gss) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($14 * $29);
 $31 = (($gss) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($19 * $32);
 $34 = (($gss) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($24 * $35);
 $37 = (($state) + 60|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  $40 = Math_fround($36 * Math_fround(0.5));
  $41 = Math_fround($24 * Math_fround(0.5));
  $364 = $41;$67 = $40;
 } else {
  $364 = $24;$67 = $36;
 }
 $42 = (($this) + 252|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(2);
 if ($44) {
  $224 = 0;$225 = 0;$227 = 0;$228 = 0;$tmgen$0 = 0;
 } else {
  $45 = (($content) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0);
  if ($47) {
   $224 = 0;$225 = 0;$227 = 0;$228 = 0;$tmgen$0 = 0;
  } else {
   $48 = $27 < Math_fround(0.0);
   $49 = $48 ? Math_fround(0.0) : $27;
   $50 = $49 > Math_fround(1.0);
   $$op$i$i$i$i = Math_fround($49 * Math_fround(255.0));
   $51 = $50 ? Math_fround(255.0) : $$op$i$i$i$i;
   $52 = Math_fround($51 + Math_fround(0.5));
   $53 = (~~(($52))>>>0);
   $54 = $30 < Math_fround(0.0);
   $55 = $54 ? Math_fround(0.0) : $30;
   $56 = $55 > Math_fround(1.0);
   $$op$i3$i$i$i = Math_fround($55 * Math_fround(255.0));
   $57 = $56 ? Math_fround(255.0) : $$op$i3$i$i$i;
   $58 = Math_fround($57 + Math_fround(0.5));
   $59 = (~~(($58))>>>0);
   $60 = $33 < Math_fround(0.0);
   $61 = $60 ? Math_fround(0.0) : $33;
   $62 = $61 > Math_fround(1.0);
   $$op$i2$i$i$i = Math_fround($61 * Math_fround(255.0));
   $63 = $62 ? Math_fround(255.0) : $$op$i2$i$i$i;
   $64 = Math_fround($63 + Math_fround(0.5));
   $65 = (~~(($64))>>>0);
   $66 = $67 < Math_fround(0.0);
   $68 = $66 ? Math_fround(0.0) : $67;
   $69 = $68 > Math_fround(1.0);
   $$op$i1$i$i$i = Math_fround($68 * Math_fround(255.0));
   $70 = $69 ? Math_fround(255.0) : $$op$i1$i$i$i;
   $71 = Math_fround($70 + Math_fround(0.5));
   $72 = (~~(($71))>>>0);
   $73 = Math_fround(HEAPF32[$screenRect>>2]);
   $74 = (($this) + 204|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (Math_fround(($75|0)));
   $77 = Math_fround($73 + $76);
   $78 = (($screenRect) + 4|0);
   $79 = Math_fround(HEAPF32[$78>>2]);
   $80 = (($this) + 212|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (Math_fround(($81|0)));
   $83 = Math_fround($79 + $82);
   $84 = (($screenRect) + 8|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = Math_fround($73 + $85);
   $87 = (($this) + 208|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (Math_fround(($88|0)));
   $90 = Math_fround($86 - $89);
   $91 = (($screenRect) + 12|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = Math_fround($79 + $92);
   $94 = (($this) + 216|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (Math_fround(($95|0)));
   $97 = Math_fround($93 - $96);
   $98 = Math_fround($90 - $77);
   $99 = Math_fround($97 - $83);
   HEAPF32[$tmpcast2$byval_copy>>2] = $77;
   $100 = (($tmpcast2$byval_copy) + 8|0);
   HEAPF32[$100>>2] = $98;
   $101 = (($tmpcast2$byval_copy) + 4|0);
   HEAPF32[$101>>2] = $83;
   $102 = (($tmpcast2$byval_copy) + 12|0);
   HEAPF32[$102>>2] = $99;
   $103 = (__ZNK8GUIStyle14GetCurrentFontEv($this)|0);
   $104 = (($this) + 240|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($this) + 244|0);
   $107 = HEAP8[$106>>0]|0;
   $108 = ($107<<24>>24)!=(0);
   $109 = (($this) + 245|0);
   $110 = HEAP8[$109>>0]|0;
   $111 = ($110<<24>>24)!=(0);
   $112 = $72 << 24;
   $113 = $65 << 16;
   $114 = $113 & 16711680;
   $115 = $59 << 8;
   $116 = $115 & 65280;
   $117 = $53 & 255;
   $118 = $116 | $117;
   $119 = $118 | $114;
   $120 = $119 | $112;
   HEAP32[$tmpcast$byval_copy>>2] = $120;
   $121 = (($this) + 280|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = (($this) + 284|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = HEAP32[$42>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$tmpcast$byval_copy+0>>2]|0;
   $126 = (__ZN5IMGUI12GetGeneratorERK5RectTIfERK10GUIContentPN13TextRendering4FontE10TextAnchorbb11ColorRGBA32ii13ImagePosition($tmpcast2$byval_copy,$content,$103,$105,$108,$111,$$byval_copy1,$122,$124,$125)|0);
   $127 = ($126|0)==(0|0);
   if ($127) {
    $224 = 0;$225 = 0;$227 = 0;$228 = 0;$tmgen$0 = 0;
   } else {
    $128 = (($126) + 16|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = (($126) + 20|0);
    $131 = Math_fround(HEAPF32[$130>>2]);
    $phitmp26 = (HEAPF32[tempDoublePtr>>2]=$129,HEAP32[tempDoublePtr>>2]|0);
    $phitmp27 = (HEAPF32[tempDoublePtr>>2]=$131,HEAP32[tempDoublePtr>>2]|0);
    $224 = $phitmp26;$225 = 0;$227 = 0;$228 = $phitmp27;$tmgen$0 = $126;
   }
  }
 }
 $132 = (($content) + 24|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = ($133|0)==(0);
 do {
  if ($134) {
   $$0$i20 = 0;$214 = 0;$215 = 0;$217 = 0;$218 = 0;
  } else {
   HEAP32[$0>>2] = $133;
   $135 = HEAP32[560624>>2]|0;
   $136 = ($135|0)==(0|0);
   if ($136) {
    label = 17;
   } else {
    $137 = (($135) + 36|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = (($135) + 4|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = ($138|0)==($140|0);
    do {
     if ($141) {
      $142 = (($135) + 28|0);
      $143 = HEAP32[$142>>2]|0;
      $144 = (($135) + 32|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = (($143) + ($145<<3)|0);
      $162 = $146;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$135,$0);
      $147 = HEAP32[$$byval_copy1>>2]|0;
      $148 = ($147|0)==(-1);
      $149 = (($135) + 28|0);
      $150 = HEAP32[$149>>2]|0;
      if ($148) {
       $151 = (($135) + 32|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = (($150) + ($152<<3)|0);
       $162 = $153;
       break;
      } else {
       $154 = (($150) + ($147<<3)|0);
       $162 = $154;
       break;
      }
     }
    } while(0);
    $155 = HEAP32[560624>>2]|0;
    $156 = (($155) + 28|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = (($155) + 32|0);
    $159 = HEAP32[$158>>2]|0;
    $160 = (($157) + ($159<<3)|0);
    $161 = ($162|0)==($160|0);
    if ($161) {
     label = 17;
    } else {
     $163 = (($162) + 4|0);
     $164 = HEAP32[$163>>2]|0;
     $165 = ($164|0)==(0|0);
     if ($165) {
      label = 17;
     } else {
      $$in = $164;$temp$0$i32 = $164;
     }
    }
   }
   if ((label|0) == 17) {
    $166 = HEAP32[$132>>2]|0;
    $167 = (__Z31ReadObjectFromPersistentManageri($166)|0);
    $168 = ($167|0)==(0|0);
    if ($168) {
     $$0$i20 = 0;$214 = 0;$215 = 0;$217 = 0;$218 = 0;
     break;
    } else {
     $$in = $167;$temp$0$i32 = $167;
    }
   }
   $169 = HEAP32[$42>>2]|0;
   $170 = ($169|0)==(3);
   if ($170) {
    $$0$i20 = $$in;$214 = 0;$215 = 0;$217 = 0;$218 = 0;
   } else {
    $171 = HEAP32[$temp$0$i32>>2]|0;
    $172 = (($171) + 104|0);
    $173 = HEAP32[$172>>2]|0;
    $174 = (FUNCTION_TABLE_ii[$173 & 4095]($$in)|0);
    $175 = (Math_fround(($174|0)));
    $176 = HEAP32[$temp$0$i32>>2]|0;
    $177 = (($176) + 108|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = (FUNCTION_TABLE_ii[$178 & 4095]($$in)|0);
    $180 = (Math_fround(($179|0)));
    $phitmp = (HEAPF32[tempDoublePtr>>2]=$175,HEAP32[tempDoublePtr>>2]|0);
    $phitmp22 = (HEAPF32[tempDoublePtr>>2]=$180,HEAP32[tempDoublePtr>>2]|0);
    $$0$i20 = $$in;$214 = $phitmp;$215 = 0;$217 = 0;$218 = $phitmp22;
   }
  }
 } while(0);
 $181 = (($imageRect) + 8|0);
 ;HEAP32[$imageRect+0>>2]=0|0;HEAP32[$imageRect+4>>2]=0|0;HEAP32[$imageRect+8>>2]=0|0;HEAP32[$imageRect+12>>2]=0|0;
 $182 = (($textRect) + 8|0);
 ;HEAP32[$textRect+0>>2]=0|0;HEAP32[$textRect+4>>2]=0|0;HEAP32[$textRect+8>>2]=0|0;HEAP32[$textRect+12>>2]=0|0;
 $183 = Math_fround(HEAPF32[$screenRect>>2]);
 $184 = (($this) + 204|0);
 $185 = HEAP32[$184>>2]|0;
 $186 = (Math_fround(($185|0)));
 $187 = Math_fround($183 + $186);
 $188 = (($screenRect) + 4|0);
 $189 = Math_fround(HEAPF32[$188>>2]);
 $190 = (($this) + 212|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = (Math_fround(($191|0)));
 $193 = Math_fround($189 + $192);
 $194 = (($screenRect) + 8|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = Math_fround($183 + $195);
 $197 = (($this) + 208|0);
 $198 = HEAP32[$197>>2]|0;
 $199 = (Math_fround(($198|0)));
 $200 = Math_fround($196 - $199);
 $201 = (($screenRect) + 12|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = Math_fround($189 + $202);
 $204 = (($this) + 216|0);
 $205 = HEAP32[$204>>2]|0;
 $206 = (Math_fround(($205|0)));
 $207 = Math_fround($203 - $206);
 $208 = Math_fround($200 - $187);
 $209 = Math_fround($207 - $193);
 HEAPF32[$contentRect>>2] = $187;
 $210 = (($contentRect) + 8|0);
 HEAPF32[$210>>2] = $208;
 $211 = (($contentRect) + 4|0);
 HEAPF32[$211>>2] = $193;
 $212 = (($contentRect) + 12|0);
 HEAPF32[$212>>2] = $209;
 $213 = $214 | $215;
 $216 = $217 | $218;
 $219 = $1;
 $220 = $219;
 HEAP32[$220>>2] = $213;
 $221 = (($219) + 4)|0;
 $222 = $221;
 HEAP32[$222>>2] = $216;
 $223 = $224 | $225;
 $226 = $227 | $228;
 $229 = $2;
 $230 = $229;
 HEAP32[$230>>2] = $223;
 $231 = (($229) + 4)|0;
 $232 = $231;
 HEAP32[$232>>2] = $226;
 $233 = HEAP32[$42>>2]|0;
 $234 = (($this) + 240|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = (($this) + 256|0);
 $237 = $236;
 $238 = $237;
 $239 = HEAP32[$238>>2]|0;
 $240 = (($237) + 4)|0;
 $241 = $240;
 $242 = HEAP32[$241>>2]|0;
 $243 = $3;
 $244 = $243;
 HEAP32[$244>>2] = $239;
 $245 = (($243) + 4)|0;
 $246 = $245;
 HEAP32[$246>>2] = $242;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$3+4>>2]|0;
 __ZN8GUIStyle16CalcContentRectsERK5RectTIfE8Vector2fS4_RS1_S5_RfS6_iiS4_($contentRect,$tmpcast$byval_copy,$tmpcast2$byval_copy,$imageRect,$textRect,$width,$height,$233,$235,$$byval_copy1);
 $247 = (($state) + 252|0);
 $248 = Math_fround(HEAPF32[$247>>2]);
 $249 = (($state) + 256|0);
 $250 = Math_fround(HEAPF32[$249>>2]);
 $251 = (($state) + 260|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 $253 = (($state) + 264|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = (($this) + 248|0);
 $256 = HEAP32[$255>>2]|0;
 $257 = ($256|0)==(0);
 do {
  if ($257) {
   label = 32;
  } else {
   $258 = Math_fround(HEAPF32[$width>>2]);
   $259 = Math_fround(HEAPF32[$210>>2]);
   $260 = $258 > $259;
   if ($260) {
    $$pre = Math_fround(HEAPF32[$212>>2]);
    $279 = $$pre;
   } else {
    $261 = Math_fround(HEAPF32[$height>>2]);
    $262 = Math_fround(HEAPF32[$212>>2]);
    $263 = $261 > $262;
    if ($263) {
     $279 = $262;
    } else {
     label = 32;
     break;
    }
   }
   $264 = Math_fround(HEAPF32[$contentRect>>2]);
   $265 = Math_fround(HEAPF32[$211>>2]);
   $266 = Math_fround(HEAPF32[$236>>2]);
   $267 = (($this) + 264|0);
   $268 = Math_fround(HEAPF32[$267>>2]);
   $269 = Math_fround($266 + $268);
   $270 = Math_fround($264 + $269);
   $271 = (($this) + 260|0);
   $272 = Math_fround(HEAPF32[$271>>2]);
   $273 = (($this) + 268|0);
   $274 = Math_fround(HEAPF32[$273>>2]);
   $275 = Math_fround($272 + $274);
   $276 = Math_fround($265 + $275);
   $277 = Math_fround($259 + $270);
   $278 = Math_fround($279 + $276);
   $280 = Math_fround($248 + $252);
   $281 = Math_fround($250 + $254);
   $282 = $270 < $248;
   $283 = $282 ? $248 : $270;
   $284 = $277 > $280;
   $x2$0$i = $284 ? $280 : $277;
   $285 = $276 < $250;
   $286 = $285 ? $250 : $276;
   $287 = $278 > $281;
   $y2$0$i = $287 ? $281 : $278;
   $288 = Math_fround($x2$0$i - $283);
   $289 = $288 < Math_fround(0.0);
   $storemerge1$i = $289 ? Math_fround(0.0) : $288;
   $290 = Math_fround($y2$0$i - $286);
   $291 = $290 < Math_fround(0.0);
   $storemerge$i = $291 ? Math_fround(0.0) : $290;
   $292 = $storemerge1$i == Math_fround(0.0);
   $293 = $storemerge$i == Math_fround(0.0);
   $or$cond21 = $292 | $293;
   if ($or$cond21) {
    STACKTOP = sp;return;
   }
   (__ZN10Matrix4x4f11SetIdentityEv($$byval_copy1)|0);
   $294 = $storemerge1$i > Math_fround(0.0);
   if ($294) {
    $295 = Math_fround(Math_fround(0.875) / $storemerge1$i);
    HEAPF32[$$byval_copy1>>2] = $295;
    $301 = $295;
   } else {
    HEAPF32[$$byval_copy1>>2] = Math_fround(inf);
    $301 = Math_fround(inf);
   }
   $296 = $storemerge$i > Math_fround(0.0);
   if ($296) {
    $297 = Math_fround(Math_fround(0.875) / $storemerge$i);
    $298 = (($$byval_copy1) + 20|0);
    HEAPF32[$298>>2] = $297;
    $305 = $297;
   } else {
    $299 = (($$byval_copy1) + 20|0);
    HEAPF32[$299>>2] = Math_fround(inf);
    $305 = Math_fround(inf);
   }
   $300 = Math_fround($283 * $301);
   $302 = Math_fround(Math_fround(0.0625) - $300);
   $303 = (($$byval_copy1) + 48|0);
   HEAPF32[$303>>2] = $302;
   $304 = Math_fround($286 * $305);
   $306 = Math_fround(Math_fround(0.0625) - $304);
   $307 = (($$byval_copy1) + 52|0);
   HEAPF32[$307>>2] = $306;
   $308 = (($$byval_copy1) + 60|0);
   $309 = (($$byval_copy1) + 40|0);
   HEAPF32[$309>>2] = Math_fround(0.0);
   HEAPF32[$308>>2] = Math_fround(1.0);
   $310 = (($$byval_copy1) + 56|0);
   HEAPF32[$310>>2] = Math_fround(1.0);
   $311 = (__Z12GetGfxDevicev()|0);
   $312 = (($311) + 3492|0);
   dest=$312+0|0; src=$$byval_copy1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $needClipping$0$off0 = 1;
  }
 } while(0);
 if ((label|0) == 32) {
  (__ZN10Matrix4x4f11SetIdentityEv($$byval_copy1)|0);
  $313 = $252 > Math_fround(0.0);
  if ($313) {
   $314 = Math_fround(Math_fround(0.875) / $252);
   HEAPF32[$$byval_copy1>>2] = $314;
   $320 = $314;
  } else {
   HEAPF32[$$byval_copy1>>2] = Math_fround(inf);
   $320 = Math_fround(inf);
  }
  $315 = $254 > Math_fround(0.0);
  if ($315) {
   $316 = Math_fround(Math_fround(0.875) / $254);
   $317 = (($$byval_copy1) + 20|0);
   HEAPF32[$317>>2] = $316;
   $324 = $316;
  } else {
   $318 = (($$byval_copy1) + 20|0);
   HEAPF32[$318>>2] = Math_fround(inf);
   $324 = Math_fround(inf);
  }
  $319 = Math_fround($248 * $320);
  $321 = Math_fround(Math_fround(0.0625) - $319);
  $322 = (($$byval_copy1) + 48|0);
  HEAPF32[$322>>2] = $321;
  $323 = Math_fround($250 * $324);
  $325 = Math_fround(Math_fround(0.0625) - $323);
  $326 = (($$byval_copy1) + 52|0);
  HEAPF32[$326>>2] = $325;
  $327 = (($$byval_copy1) + 60|0);
  $328 = (($$byval_copy1) + 40|0);
  HEAPF32[$328>>2] = Math_fround(0.0);
  HEAPF32[$327>>2] = Math_fround(1.0);
  $329 = (($$byval_copy1) + 56|0);
  HEAPF32[$329>>2] = Math_fround(1.0);
  $330 = (__Z12GetGfxDevicev()|0);
  $331 = (($330) + 3492|0);
  dest=$331+0|0; src=$$byval_copy1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $needClipping$0$off0 = 0;
 }
 $332 = Math_fround(HEAPF32[$182>>2]);
 $333 = $332 == Math_fround(0.0);
 $334 = ($tmgen$0|0)==(0|0);
 $or$cond = $333 | $334;
 if (!($or$cond)) {
  HEAPF32[$4>>2] = $27;
  $335 = (($4) + 4|0);
  HEAPF32[$335>>2] = $30;
  $336 = (($4) + 8|0);
  HEAPF32[$336>>2] = $33;
  $337 = (($4) + 12|0);
  HEAPF32[$337>>2] = $67;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$4+12>>2]|0;
  __ZNK8GUIStyle10RenderTextERK5RectTIfERN13TextRendering17TextMeshGeneratorE10ColorRGBAf($this,$textRect,$tmgen$0,$$byval_copy1);
 }
 $338 = Math_fround(HEAPF32[$181>>2]);
 $339 = $338 != Math_fround(0.0);
 if ($339) {
  $340 = $9 < Math_fround(0.0);
  $341 = $340 ? Math_fround(0.0) : $9;
  $342 = $341 > Math_fround(1.0);
  $$op$i$i$i$i$i = Math_fround($341 * Math_fround(255.0));
  $343 = $342 ? Math_fround(255.0) : $$op$i$i$i$i$i;
  $344 = Math_fround($343 + Math_fround(0.5));
  $345 = (~~(($344))>>>0);
  $346 = $345&255;
  HEAP8[$tmpcast2$byval_copy>>0] = $346;
  $347 = $14 < Math_fround(0.0);
  $348 = $347 ? Math_fround(0.0) : $14;
  $349 = $348 > Math_fround(1.0);
  $$op$i3$i$i$i$i = Math_fround($348 * Math_fround(255.0));
  $350 = $349 ? Math_fround(255.0) : $$op$i3$i$i$i$i;
  $351 = Math_fround($350 + Math_fround(0.5));
  $352 = (~~(($351))>>>0);
  $353 = $352&255;
  $354 = (($tmpcast2$byval_copy) + 1|0);
  HEAP8[$354>>0] = $353;
  $355 = $19 < Math_fround(0.0);
  $356 = $355 ? Math_fround(0.0) : $19;
  $357 = $356 > Math_fround(1.0);
  $$op$i2$i$i$i$i = Math_fround($356 * Math_fround(255.0));
  $358 = $357 ? Math_fround(255.0) : $$op$i2$i$i$i$i;
  $359 = Math_fround($358 + Math_fround(0.5));
  $360 = (~~(($359))>>>0);
  $361 = $360&255;
  $362 = (($tmpcast2$byval_copy) + 2|0);
  HEAP8[$362>>0] = $361;
  $363 = $364 < Math_fround(0.0);
  $365 = $363 ? Math_fround(0.0) : $364;
  $366 = $365 > Math_fround(1.0);
  $$op$i1$i$i$i$i = Math_fround($365 * Math_fround(255.0));
  $367 = $366 ? Math_fround(255.0) : $$op$i1$i$i$i$i;
  $368 = Math_fround($367 + Math_fround(0.5));
  $369 = (~~(($368))>>>0);
  $370 = $369&255;
  $371 = (($tmpcast2$byval_copy) + 3|0);
  HEAP8[$371>>0] = $370;
  $372 = (__Z19GetGUIBlendMaterialv()|0);
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$tmpcast2$byval_copy+0>>2]|0;
  __Z14DrawGUITextureRK5RectTIfEP7Textureiiii11ColorRGBA32PN5Unity8MaterialE($imageRect,$$0$i20,0,0,0,0,$$byval_copy1,$372);
 }
 if (!($needClipping$0$off0)) {
  STACKTOP = sp;return;
 }
 (__ZN10Matrix4x4f11SetIdentityEv($$byval_copy1)|0);
 $373 = $252 > Math_fround(0.0);
 if ($373) {
  $374 = Math_fround(Math_fround(0.875) / $252);
  HEAPF32[$$byval_copy1>>2] = $374;
  $380 = $374;
 } else {
  HEAPF32[$$byval_copy1>>2] = Math_fround(inf);
  $380 = Math_fround(inf);
 }
 $375 = $254 > Math_fround(0.0);
 if ($375) {
  $376 = Math_fround(Math_fround(0.875) / $254);
  $377 = (($$byval_copy1) + 20|0);
  HEAPF32[$377>>2] = $376;
  $384 = $376;
 } else {
  $378 = (($$byval_copy1) + 20|0);
  HEAPF32[$378>>2] = Math_fround(inf);
  $384 = Math_fround(inf);
 }
 $379 = Math_fround($248 * $380);
 $381 = Math_fround(Math_fround(0.0625) - $379);
 $382 = (($$byval_copy1) + 48|0);
 HEAPF32[$382>>2] = $381;
 $383 = Math_fround($250 * $384);
 $385 = Math_fround(Math_fround(0.0625) - $383);
 $386 = (($$byval_copy1) + 52|0);
 HEAPF32[$386>>2] = $385;
 $387 = (($$byval_copy1) + 60|0);
 $388 = (($$byval_copy1) + 40|0);
 HEAPF32[$388>>2] = Math_fround(0.0);
 HEAPF32[$387>>2] = Math_fround(1.0);
 $389 = (($$byval_copy1) + 56|0);
 HEAPF32[$389>>2] = Math_fround(1.0);
 $390 = (__Z12GetGfxDevicev()|0);
 $391 = (($390) + 3492|0);
 dest=$391+0|0; src=$$byval_copy1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZNK8GUIStyle14GetCurrentFontEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 236|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  HEAP32[$1>>2] = $3;
  $5 = HEAP32[560624>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = (($5) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   do {
    if ($11) {
     $12 = (($5) + 28|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($5) + 32|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($13) + ($15<<3)|0);
     $32 = $16;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$5,$1);
     $17 = HEAP32[$pos$i$i$i$i1>>2]|0;
     $18 = ($17|0)==(-1);
     $19 = (($5) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     if ($18) {
      $21 = (($5) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $32 = $23;
      break;
     } else {
      $24 = (($20) + ($17<<3)|0);
      $32 = $24;
      break;
     }
    }
   } while(0);
   $25 = HEAP32[560624>>2]|0;
   $26 = (($25) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 32|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + ($29<<3)|0);
   $31 = ($32|0)==($30|0);
   if (!($31)) {
    $33 = (($32) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if (!($35)) {
     $$0 = $34;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $36 = HEAP32[$2>>2]|0;
  $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   $$0 = $37;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $39 = HEAP32[612200>>2]|0;
 $40 = ($39|0)==(0);
 if (!($40)) {
  HEAP32[$0>>2] = $39;
  $41 = HEAP32[560624>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = (($41) + 36|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($41) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($44|0)==($46|0);
   do {
    if ($47) {
     $48 = (($41) + 28|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = (($41) + 32|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($49) + ($51<<3)|0);
     $68 = $52;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$41,$0);
     $53 = HEAP32[$pos$i$i$i$i1>>2]|0;
     $54 = ($53|0)==(-1);
     $55 = (($41) + 28|0);
     $56 = HEAP32[$55>>2]|0;
     if ($54) {
      $57 = (($41) + 32|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (($56) + ($58<<3)|0);
      $68 = $59;
      break;
     } else {
      $60 = (($56) + ($53<<3)|0);
      $68 = $60;
      break;
     }
    }
   } while(0);
   $61 = HEAP32[560624>>2]|0;
   $62 = (($61) + 28|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($61) + 32|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($63) + ($65<<3)|0);
   $67 = ($68|0)==($66|0);
   if (!($67)) {
    $69 = (($68) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==(0|0);
    if (!($71)) {
     $$0 = $70;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $72 = HEAP32[612200>>2]|0;
  $73 = (__Z31ReadObjectFromPersistentManageri($72)|0);
  $74 = ($73|0)==(0|0);
  if (!($74)) {
   $$0 = $73;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $75 = (__ZN8GUIStyle14GetBuiltinFontEv()|0);
 $$0 = $75;
 STACKTOP = sp;return ($$0|0);
}
function __ZN8GUIStyle14GetBuiltinFontEv() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $storemerge = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[612208>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
     $16 = HEAP32[$pos$i$i$i$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if (!($30)) {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     $$0 = $33;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $35 = HEAP32[612208>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $$0 = $36;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP8[$1>>0] = 18;
 $38 = (($1) + 1|0);
 dest=$38+0|0; src=612296+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $39 = (($1) + 10|0);
 HEAP8[$39>>0] = 0;
 __THREW__ = 0;
 $40 = (invoke_i(58)|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if (!($42)) {
  __THREW__ = 0;
  $43 = (invoke_iiii(1532,($40|0),128,($1|0))|0);
  $44 = __THREW__; __THREW__ = 0;
  $45 = $44&1;
  if (!($45)) {
   $46 = ($43|0)==(0|0);
   if ($46) {
    $storemerge = 0;
   } else {
    $47 = (($43) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $storemerge = $48;
   }
   HEAP32[612208>>2] = $storemerge;
   $49 = HEAP8[$1>>0]|0;
   $50 = $49 & 1;
   $51 = ($50<<24>>24)==(0);
   if (!($51)) {
    $52 = (($1) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    __ZdlPv($53);
   }
   if (!($46)) {
    $$0 = $43;
    STACKTOP = sp;return ($$0|0);
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(612312,0,612360,364,4,0,0,0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $54 = ___cxa_find_matching_catch()|0;
 $55 = tempRet0;
 $56 = HEAP8[$1>>0]|0;
 $57 = $56 & 1;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  ___resumeException($54|0);
  // unreachable;
 }
 $59 = (($1) + 8|0);
 $60 = HEAP32[$59>>2]|0;
 __ZdlPv($60);
 ___resumeException($54|0);
 // unreachable;
 return 0|0;
}
function __ZN8GUIStyle14SetGUIClipRectERK5RectTIfE($screenRect) {
 $screenRect = $screenRect|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = Math_fround(0);
 var $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $clipMatrix = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $clipMatrix = sp;
 (__ZN10Matrix4x4f11SetIdentityEv($clipMatrix)|0);
 $0 = (($screenRect) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 > Math_fround(0.0);
 if ($2) {
  $3 = Math_fround(Math_fround(0.875) / $1);
  HEAPF32[$clipMatrix>>2] = $3;
  $12 = $3;
 } else {
  HEAPF32[$clipMatrix>>2] = Math_fround(inf);
  $12 = Math_fround(inf);
 }
 $4 = (($screenRect) + 12|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 > Math_fround(0.0);
 if ($6) {
  $7 = Math_fround(Math_fround(0.875) / $5);
  $8 = (($clipMatrix) + 20|0);
  HEAPF32[$8>>2] = $7;
  $18 = $7;
 } else {
  $9 = (($clipMatrix) + 20|0);
  HEAPF32[$9>>2] = Math_fround(inf);
  $18 = Math_fround(inf);
 }
 $10 = Math_fround(HEAPF32[$screenRect>>2]);
 $11 = Math_fround($10 * $12);
 $13 = Math_fround(Math_fround(0.0625) - $11);
 $14 = (($clipMatrix) + 48|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($screenRect) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $18);
 $19 = Math_fround(Math_fround(0.0625) - $17);
 $20 = (($clipMatrix) + 52|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($clipMatrix) + 60|0);
 $22 = (($clipMatrix) + 40|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $23 = (($clipMatrix) + 56|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (__Z12GetGfxDevicev()|0);
 $25 = (($24) + 3492|0);
 dest=$25+0|0; src=$clipMatrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZNK8GUIStyle10RenderTextERK5RectTIfERN13TextRendering17TextMeshGeneratorE10ColorRGBAf($this,$screenRect,$tmgen,$color) {
 $this = $this|0;
 $screenRect = $screenRect|0;
 $tmgen = $tmgen|0;
 $color = $color|0;
 var $$0$i = 0, $$pre$i = 0, $$pre$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$06 = 0, $matWorld = 0, $offset = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, $textMatrix = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $pos$i$i$i$i = sp + 160|0;
 $0 = sp;
 $1 = sp + 4|0;
 $matWorld = sp + 8|0;
 $textMatrix = sp + 72|0;
 $offset = sp + 136|0;
 $2 = sp + 144|0;
 $3 = HEAP32[612480>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $5 = (__Znwj(48)|0);
   $6 = (($pos$i$i$i$i) + 8|0);
   HEAP32[$6>>2] = $5;
   HEAP32[$pos$i$i$i$i>>2] = 49;
   $7 = (($pos$i$i$i$i) + 4|0);
   HEAP32[$7>>2] = 34;
   dest=$5+0|0; src=612488+0|0; stop=dest+34|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $8 = (($5) + 34|0);
   HEAP8[$8>>0] = 0;
   __THREW__ = 0;
   $9 = (invoke_i(58)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iiii(1532,($9|0),48,($pos$i$i$i$i|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP8[$pos$i$i$i$i>>0]|0;
     $16 = $15 & 1;
     $17 = ($16<<24>>24)==(0);
     if (!($17)) {
      $18 = HEAP32[$6>>2]|0;
      __ZdlPv($18);
     }
     $19 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($12,61,0)|0);
     HEAP32[612480>>2] = $19;
     __Z24InitializeGUIClipTexturev();
     $$pre$i = HEAP32[612480>>2]|0;
     $36 = $$pre$i;
     break;
    }
   }
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   $22 = HEAP8[$pos$i$i$i$i>>0]|0;
   $23 = $22 & 1;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    ___resumeException($20|0);
    // unreachable;
   }
   $25 = HEAP32[$6>>2]|0;
   __ZdlPv($25);
   ___resumeException($20|0);
   // unreachable;
  } else {
   $36 = $3;
  }
 } while(0);
 HEAPF32[$color>>2] = Math_fround(1.0);
 $26 = (($color) + 4|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($color) + 8|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($color) + 12|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = HEAP8[612376>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if ($30) {
  HEAP32[$pos$i$i$i$i>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($pos$i$i$i$i,612384);
  $31 = HEAP32[$pos$i$i$i$i>>2]|0;
  HEAP32[612368>>2] = $31;
  HEAP8[612376>>0] = 1;
 }
 $32 = HEAP8[612400>>0]|0;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  HEAP32[$pos$i$i$i$i>>2] = -1;
  __ZN9ShaderLab16FastPropertyName4InitEPKc($pos$i$i$i$i,612408);
  $34 = HEAP32[$pos$i$i$i$i>>2]|0;
  HEAP32[612392>>2] = $34;
  HEAP8[612400>>0] = 1;
 }
 $35 = (($36) + 32|0);
 $37 = HEAP32[$35>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  __ZN5Unity8Material15BuildPropertiesEv($36);
  $$pre$i1 = HEAP32[$35>>2]|0;
  $40 = $$pre$i1;
 } else {
  $40 = $37;
 }
 $39 = (($36) + 36|0);
 HEAP8[$39>>0] = 1;
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($40,612368,$color);
 $41 = (__ZNK8GUIStyle14GetCurrentFontEv($this)|0);
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  __ZNK13TextRendering4Font10GetTextureEv($1,$41);
  $43 = HEAP32[$1>>2]|0;
  $44 = ($43|0)==(0);
  if ($44) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $43;
   $45 = HEAP32[560624>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    label = 26;
   } else {
    $47 = (($45) + 36|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($45) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($48|0)==($50|0);
    do {
     if ($51) {
      $52 = (($45) + 28|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (($45) + 32|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = (($53) + ($55<<3)|0);
      $72 = $56;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$45,$0);
      $57 = HEAP32[$pos$i$i$i$i>>2]|0;
      $58 = ($57|0)==(-1);
      $59 = (($45) + 28|0);
      $60 = HEAP32[$59>>2]|0;
      if ($58) {
       $61 = (($45) + 32|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($60) + ($62<<3)|0);
       $72 = $63;
       break;
      } else {
       $64 = (($60) + ($57<<3)|0);
       $72 = $64;
       break;
      }
     }
    } while(0);
    $65 = HEAP32[560624>>2]|0;
    $66 = (($65) + 28|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($65) + 32|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($67) + ($69<<3)|0);
    $71 = ($72|0)==($70|0);
    if ($71) {
     label = 26;
    } else {
     $73 = (($72) + 4|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==(0|0);
     if ($75) {
      label = 26;
     } else {
      $temp$0$i = $74;
     }
    }
   }
   if ((label|0) == 26) {
    $76 = (__Z31ReadObjectFromPersistentManageri($43)|0);
    $temp$0$i = $76;
   }
   $$0$i = $temp$0$i;
  }
  (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($40,612392,$$0$i)|0);
 }
 $77 = (__Z12GetGfxDevicev()|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 116|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (FUNCTION_TABLE_ii[$80 & 4095]($77)|0);
 dest=$pos$i$i$i$i+0|0; src=$81+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $82 = HEAP32[$77>>2]|0;
 $83 = (($82) + 112|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (FUNCTION_TABLE_ii[$84 & 4095]($77)|0);
 dest=$matWorld+0|0; src=$85+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __ZN13TextRendering17TextMeshGenerator13GetTextOffsetERK5RectTIfE($offset,$tmgen,$screenRect);
 $86 = Math_fround(HEAPF32[$offset>>2]);
 $87 = (($offset) + 4|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 HEAPF32[$2>>2] = $86;
 $89 = (($2) + 4|0);
 HEAPF32[$89>>2] = $88;
 $90 = (($2) + 8|0);
 HEAPF32[$90>>2] = Math_fround(0.0);
 (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($textMatrix,$2)|0);
 $91 = HEAP32[$77>>2]|0;
 $92 = (($91) + 100|0);
 $93 = HEAP32[$92>>2]|0;
 FUNCTION_TABLE_vii[$93 & 4095]($77,$textMatrix);
 $94 = (__ZN5Unity8Material12GetPassCountEv($36)|0);
 $95 = HEAP32[652824>>2]|0;
 $96 = ($94|0)>(0);
 if (!($96)) {
  $100 = HEAP32[$77>>2]|0;
  $101 = (($100) + 100|0);
  $102 = HEAP32[$101>>2]|0;
  FUNCTION_TABLE_vii[$102 & 4095]($77,$pos$i$i$i$i);
  $103 = HEAP32[$77>>2]|0;
  $104 = (($103) + 96|0);
  $105 = HEAP32[$104>>2]|0;
  FUNCTION_TABLE_vii[$105 & 4095]($77,$matWorld);
  STACKTOP = sp;return;
 }
 $i$06 = 0;
 while(1) {
  $97 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($36,$i$06,$95,0,1)|0);
  $98 = HEAP32[$tmgen>>2]|0;
  __ZN8DrawUtil15DrawTextMeshRawERK14ChannelAssignsR4Meshj($97,$98,13);
  $99 = (($i$06) + 1)|0;
  $exitcond = ($99|0)==($94|0);
  if ($exitcond) {
   break;
  } else {
   $i$06 = $99;
  }
 }
 $100 = HEAP32[$77>>2]|0;
 $101 = (($100) + 100|0);
 $102 = HEAP32[$101>>2]|0;
 FUNCTION_TABLE_vii[$102 & 4095]($77,$pos$i$i$i$i);
 $103 = HEAP32[$77>>2]|0;
 $104 = (($103) + 96|0);
 $105 = HEAP32[$104>>2]|0;
 FUNCTION_TABLE_vii[$105 & 4095]($77,$matWorld);
 STACKTOP = sp;return;
}
function __ZNK13TextRendering4Font10GetTextureEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $phitmp$i2 = 0;
 var $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if (!($6)) {
   HEAP32[$2>>2] = $5;
   $7 = HEAP32[560624>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 10;
   } else {
    $9 = (($7) + 36|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    do {
     if ($13) {
      $14 = (($7) + 28|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($7) + 32|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($15) + ($17<<3)|0);
      $34 = $18;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$7,$2);
      $19 = HEAP32[$$byval_copy>>2]|0;
      $20 = ($19|0)==(-1);
      $21 = (($7) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      if ($20) {
       $23 = (($7) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $34 = $25;
       break;
      } else {
       $26 = (($22) + ($19<<3)|0);
       $34 = $26;
       break;
      }
     }
    } while(0);
    $27 = HEAP32[560624>>2]|0;
    $28 = (($27) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + ($31<<3)|0);
    $33 = ($34|0)==($32|0);
    if ($33) {
     label = 10;
    } else {
     $35 = (($34) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      label = 10;
     }
    }
   }
   if ((label|0) == 10) {
    $38 = HEAP32[$4>>2]|0;
    $39 = (__Z31ReadObjectFromPersistentManageri($38)|0);
    $phitmp$i = ($39|0)==(0|0);
    if ($phitmp$i) {
     break;
    }
   }
   $40 = HEAP32[$4>>2]|0;
   HEAP32[$agg$result>>2] = $40;
   STACKTOP = sp;return;
  }
 } while(0);
 $41 = (($this) + 36|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 do {
  if (!($43)) {
   HEAP32[$0>>2] = $42;
   $44 = HEAP32[560624>>2]|0;
   $45 = ($44|0)==(0|0);
   if ($45) {
    label = 21;
   } else {
    $46 = (($44) + 36|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($44) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($47|0)==($49|0);
    do {
     if ($50) {
      $51 = (($44) + 28|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (($44) + 32|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = (($52) + ($54<<3)|0);
      $71 = $55;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$44,$0);
      $56 = HEAP32[$$byval_copy>>2]|0;
      $57 = ($56|0)==(-1);
      $58 = (($44) + 28|0);
      $59 = HEAP32[$58>>2]|0;
      if ($57) {
       $60 = (($44) + 32|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($59) + ($61<<3)|0);
       $71 = $62;
       break;
      } else {
       $63 = (($59) + ($56<<3)|0);
       $71 = $63;
       break;
      }
     }
    } while(0);
    $64 = HEAP32[560624>>2]|0;
    $65 = (($64) + 28|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($64) + 32|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + ($68<<3)|0);
    $70 = ($71|0)==($69|0);
    if ($70) {
     label = 21;
    } else {
     $72 = (($71) + 4|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ($73|0)==(0|0);
     if ($74) {
      label = 21;
     } else {
      $79 = $64;
     }
    }
   }
   if ((label|0) == 21) {
    $75 = HEAP32[$41>>2]|0;
    $76 = (__Z31ReadObjectFromPersistentManageri($75)|0);
    $phitmp$i2 = ($76|0)==(0|0);
    if ($phitmp$i2) {
     break;
    }
    $$pre = HEAP32[560624>>2]|0;
    $79 = $$pre;
   }
   $77 = HEAP32[$41>>2]|0;
   HEAP32[$1>>2] = $77;
   $78 = ($79|0)==(0|0);
   if ($78) {
    label = 31;
   } else {
    $80 = (($79) + 36|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($79) + 4|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($81|0)==($83|0);
    do {
     if ($84) {
      $85 = (($79) + 28|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = (($79) + 32|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (($86) + ($88<<3)|0);
      $105 = $89;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$79,$1);
      $90 = HEAP32[$$byval_copy>>2]|0;
      $91 = ($90|0)==(-1);
      $92 = (($79) + 28|0);
      $93 = HEAP32[$92>>2]|0;
      if ($91) {
       $94 = (($79) + 32|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = (($93) + ($95<<3)|0);
       $105 = $96;
       break;
      } else {
       $97 = (($93) + ($90<<3)|0);
       $105 = $97;
       break;
      }
     }
    } while(0);
    $98 = HEAP32[560624>>2]|0;
    $99 = (($98) + 28|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($98) + 32|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (($100) + ($102<<3)|0);
    $104 = ($105|0)==($103|0);
    if ($104) {
     label = 31;
    } else {
     $106 = (($105) + 4|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ($107|0)==(0|0);
     if ($108) {
      label = 31;
     } else {
      $temp$0$i = $107;
     }
    }
   }
   if ((label|0) == 31) {
    $109 = HEAP32[$41>>2]|0;
    $110 = (__Z31ReadObjectFromPersistentManageri($109)|0);
    $temp$0$i = $110;
   }
   HEAP32[$$byval_copy>>2] = -1;
   __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy,612408);
   $111 = HEAP32[$$byval_copy>>2]|0;
   HEAP32[$3>>2] = $111;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
   $112 = (__ZN5Unity8Material10GetTextureEN9ShaderLab16FastPropertyNameE($temp$0$i,$$byval_copy)|0);
   $113 = ($112|0)==(0|0);
   if ($113) {
    HEAP32[$agg$result>>2] = 0;
    STACKTOP = sp;return;
   } else {
    $114 = (($112) + 4|0);
    $115 = HEAP32[$114>>2]|0;
    HEAP32[$agg$result>>2] = $115;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 HEAP32[$agg$result>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13TextRendering17TextMeshGenerator13GetTextOffsetERK5RectTIfE($agg$result,$this,$rect) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $rect = $rect|0;
 var $$0$i = Math_fround(0), $$0$i11 = Math_fround(0), $$0$i14 = Math_fround(0), $$0$i20 = Math_fround(0), $$0$i23 = Math_fround(0), $$0$i26 = Math_fround(0), $$0$i29 = Math_fround(0), $$0$i32 = Math_fround(0), $$0$i35 = Math_fround(0), $$0$i38 = Math_fround(0), $$0$i41 = Math_fround(0), $$0$i44 = Math_fround(0), $$0$i47 = Math_fround(0), $$0$i5 = Math_fround(0), $$0$i50 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0);
 var $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0);
 var $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0;
 var $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0;
 var $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0);
 var $floorf$i$i$i = Math_fround(0), $floorf$i$i$i1 = Math_fround(0), $floorf$i$i$i10 = Math_fround(0), $floorf$i$i$i13 = Math_fround(0), $floorf$i$i$i16 = Math_fround(0), $floorf$i$i$i19 = Math_fround(0), $floorf$i$i$i22 = Math_fround(0), $floorf$i$i$i25 = Math_fround(0), $floorf$i$i$i28 = Math_fround(0), $floorf$i$i$i31 = Math_fround(0), $floorf$i$i$i34 = Math_fround(0), $floorf$i$i$i37 = Math_fround(0), $floorf$i$i$i4 = Math_fround(0), $floorf$i$i$i40 = Math_fround(0), $floorf$i$i$i43 = Math_fround(0), $floorf$i$i$i46 = Math_fround(0), $floorf$i$i$i49 = Math_fround(0), $floorf$i$i$i7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $0 = (($agg$result) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 do {
  switch ($2|0) {
  case 0:  {
   $3 = Math_fround(HEAPF32[$rect>>2]);
   $4 = (($this) + 28|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    HEAPF32[$agg$result>>2] = $3;
    $7 = (($rect) + 4|0);
    $8 = Math_fround(HEAPF32[$7>>2]);
    $$0$i5 = $8;
   } else {
    $9 = Math_fround($3 + Math_fround(0.5));
    $floorf$i$i$i1 = (Math_fround(Math_floor((Math_fround($9)))));
    HEAPF32[$agg$result>>2] = $floorf$i$i$i1;
    $10 = (($rect) + 4|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    $12 = Math_fround($11 + Math_fround(0.5));
    $floorf$i$i$i4 = (Math_fround(Math_floor((Math_fround($12)))));
    $$0$i5 = $floorf$i$i$i4;
   }
   HEAPF32[$0>>2] = $$0$i5;
   STACKTOP = sp;return;
   break;
  }
  case 8:  {
   $128 = Math_fround(HEAPF32[$rect>>2]);
   $129 = (($rect) + 8|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = Math_fround($128 + $130);
   $132 = (($this) + 28|0);
   $133 = HEAP8[$132>>0]|0;
   $134 = ($133<<24>>24)==(0);
   if ($134) {
    $$0$i14 = $131;
   } else {
    $135 = Math_fround($131 + Math_fround(0.5));
    $floorf$i$i$i13 = (Math_fround(Math_floor((Math_fround($135)))));
    $$0$i14 = $floorf$i$i$i13;
   }
   HEAPF32[$agg$result>>2] = $$0$i14;
   $136 = (($rect) + 4|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = (($rect) + 12|0);
   $139 = Math_fround(HEAPF32[$138>>2]);
   $140 = Math_fround($137 + $139);
   $141 = (($this) + 20|0);
   $142 = Math_fround(HEAPF32[$141>>2]);
   $143 = Math_fround($140 - $142);
   if ($134) {
    $$0$i = $143;
   } else {
    $144 = Math_fround($143 + Math_fround(0.5));
    $floorf$i$i$i = (Math_fround(Math_floor((Math_fround($144)))));
    $$0$i = $floorf$i$i$i;
   }
   HEAPF32[$0>>2] = $$0$i;
   STACKTOP = sp;return;
   break;
  }
  case 2:  {
   $27 = Math_fround(HEAPF32[$rect>>2]);
   $28 = (($rect) + 8|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($27 + $29);
   $31 = (($this) + 28|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)==(0);
   if ($33) {
    HEAPF32[$agg$result>>2] = $30;
    $34 = (($rect) + 4|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $$0$i20 = $35;
   } else {
    $36 = Math_fround($30 + Math_fround(0.5));
    $floorf$i$i$i16 = (Math_fround(Math_floor((Math_fround($36)))));
    HEAPF32[$agg$result>>2] = $floorf$i$i$i16;
    $37 = (($rect) + 4|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = Math_fround($38 + Math_fround(0.5));
    $floorf$i$i$i19 = (Math_fround(Math_floor((Math_fround($39)))));
    $$0$i20 = $floorf$i$i$i19;
   }
   HEAPF32[$0>>2] = $$0$i20;
   STACKTOP = sp;return;
   break;
  }
  case 3:  {
   $40 = Math_fround(HEAPF32[$rect>>2]);
   $41 = (($this) + 28|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $$0$i23 = $40;
   } else {
    $44 = Math_fround($40 + Math_fround(0.5));
    $floorf$i$i$i22 = (Math_fround(Math_floor((Math_fround($44)))));
    $$0$i23 = $floorf$i$i$i22;
   }
   HEAPF32[$agg$result>>2] = $$0$i23;
   $45 = (($rect) + 4|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($rect) + 12|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = Math_fround($46 + $48);
   $50 = Math_fround($46 + $49);
   $51 = (($this) + 20|0);
   $52 = Math_fround(HEAPF32[$51>>2]);
   $53 = Math_fround($50 - $52);
   $54 = Math_fround($53 * Math_fround(0.5));
   if ($43) {
    $$0$i32 = $54;
   } else {
    $55 = Math_fround($54 + Math_fround(0.5));
    $floorf$i$i$i31 = (Math_fround(Math_floor((Math_fround($55)))));
    $$0$i32 = $floorf$i$i$i31;
   }
   HEAPF32[$0>>2] = $$0$i32;
   STACKTOP = sp;return;
   break;
  }
  case 5:  {
   $76 = Math_fround(HEAPF32[$rect>>2]);
   $77 = (($rect) + 8|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = Math_fround($76 + $78);
   $80 = (($this) + 28|0);
   $81 = HEAP8[$80>>0]|0;
   $82 = ($81<<24>>24)==(0);
   if ($82) {
    $$0$i50 = $79;
   } else {
    $83 = Math_fround($79 + Math_fround(0.5));
    $floorf$i$i$i49 = (Math_fround(Math_floor((Math_fround($83)))));
    $$0$i50 = $floorf$i$i$i49;
   }
   HEAPF32[$agg$result>>2] = $$0$i50;
   $84 = (($rect) + 4|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = (($rect) + 12|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = Math_fround($85 + $87);
   $89 = Math_fround($85 + $88);
   $90 = (($this) + 20|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = Math_fround($89 - $91);
   $93 = Math_fround($92 * Math_fround(0.5));
   if ($82) {
    $$0$i47 = $93;
   } else {
    $94 = Math_fround($93 + Math_fround(0.5));
    $floorf$i$i$i46 = (Math_fround(Math_floor((Math_fround($94)))));
    $$0$i47 = $floorf$i$i$i46;
   }
   HEAPF32[$0>>2] = $$0$i47;
   STACKTOP = sp;return;
   break;
  }
  case 7:  {
   $109 = Math_fround(HEAPF32[$rect>>2]);
   $110 = (($rect) + 8|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = Math_fround($109 + $111);
   $113 = Math_fround($109 + $112);
   $114 = Math_fround($113 * Math_fround(0.5));
   $115 = (($this) + 28|0);
   $116 = HEAP8[$115>>0]|0;
   $117 = ($116<<24>>24)==(0);
   if ($117) {
    $$0$i29 = $114;
   } else {
    $118 = Math_fround($114 + Math_fround(0.5));
    $floorf$i$i$i28 = (Math_fround(Math_floor((Math_fround($118)))));
    $$0$i29 = $floorf$i$i$i28;
   }
   HEAPF32[$agg$result>>2] = $$0$i29;
   $119 = (($rect) + 4|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = (($rect) + 12|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = Math_fround($120 + $122);
   $124 = (($this) + 20|0);
   $125 = Math_fround(HEAPF32[$124>>2]);
   $126 = Math_fround($123 - $125);
   if ($117) {
    $$0$i26 = $126;
   } else {
    $127 = Math_fround($126 + Math_fround(0.5));
    $floorf$i$i$i25 = (Math_fround(Math_floor((Math_fround($127)))));
    $$0$i26 = $floorf$i$i$i25;
   }
   HEAPF32[$0>>2] = $$0$i26;
   STACKTOP = sp;return;
   break;
  }
  case 1:  {
   $13 = Math_fround(HEAPF32[$rect>>2]);
   $14 = (($rect) + 8|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($15 * Math_fround(0.5));
   $17 = Math_fround($13 + $16);
   $18 = (($this) + 28|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    HEAPF32[$agg$result>>2] = $17;
    $21 = (($rect) + 4|0);
    $22 = Math_fround(HEAPF32[$21>>2]);
    $$0$i11 = $22;
   } else {
    $23 = Math_fround($17 + Math_fround(0.5));
    $floorf$i$i$i7 = (Math_fround(Math_floor((Math_fround($23)))));
    HEAPF32[$agg$result>>2] = $floorf$i$i$i7;
    $24 = (($rect) + 4|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = Math_fround($25 + Math_fround(0.5));
    $floorf$i$i$i10 = (Math_fround(Math_floor((Math_fround($26)))));
    $$0$i11 = $floorf$i$i$i10;
   }
   HEAPF32[$0>>2] = $$0$i11;
   STACKTOP = sp;return;
   break;
  }
  case 6:  {
   $95 = Math_fround(HEAPF32[$rect>>2]);
   $96 = (($this) + 28|0);
   $97 = HEAP8[$96>>0]|0;
   $98 = ($97<<24>>24)==(0);
   if ($98) {
    $$0$i41 = $95;
   } else {
    $99 = Math_fround($95 + Math_fround(0.5));
    $floorf$i$i$i40 = (Math_fround(Math_floor((Math_fround($99)))));
    $$0$i41 = $floorf$i$i$i40;
   }
   HEAPF32[$agg$result>>2] = $$0$i41;
   $100 = (($rect) + 4|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = (($rect) + 12|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = Math_fround($101 + $103);
   $105 = (($this) + 20|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = Math_fround($104 - $106);
   if ($98) {
    $$0$i38 = $107;
   } else {
    $108 = Math_fround($107 + Math_fround(0.5));
    $floorf$i$i$i37 = (Math_fround(Math_floor((Math_fround($108)))));
    $$0$i38 = $floorf$i$i$i37;
   }
   HEAPF32[$0>>2] = $$0$i38;
   STACKTOP = sp;return;
   break;
  }
  case 4:  {
   $56 = Math_fround(HEAPF32[$rect>>2]);
   $57 = (($rect) + 8|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = Math_fround($58 * Math_fround(0.5));
   $60 = Math_fround($56 + $59);
   $61 = (($this) + 28|0);
   $62 = HEAP8[$61>>0]|0;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    $$0$i35 = $60;
   } else {
    $64 = Math_fround($60 + Math_fround(0.5));
    $floorf$i$i$i34 = (Math_fround(Math_floor((Math_fround($64)))));
    $$0$i35 = $floorf$i$i$i34;
   }
   HEAPF32[$agg$result>>2] = $$0$i35;
   $65 = (($rect) + 4|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = (($rect) + 12|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = Math_fround($66 + $68);
   $70 = Math_fround($66 + $69);
   $71 = (($this) + 20|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = Math_fround($70 - $72);
   $74 = Math_fround($73 * Math_fround(0.5));
   if ($63) {
    $$0$i44 = $74;
   } else {
    $75 = Math_fround($74 + Math_fround(0.5));
    $floorf$i$i$i43 = (Math_fround(Math_floor((Math_fround($75)))));
    $$0$i44 = $floorf$i$i$i43;
   }
   HEAPF32[$0>>2] = $$0$i44;
   STACKTOP = sp;return;
   break;
  }
  default: {
   HEAPF32[$0>>2] = Math_fround(0.0);
   HEAPF32[$agg$result>>2] = Math_fround(0.0);
   STACKTOP = sp;return;
  }
  }
 } while(0);
}
function __ZN8GUIStyle16CalcContentRectsERK5RectTIfE8Vector2fS4_RS1_S5_RfS6_iiS4_($contentRect,$imageSize,$textSize,$imageRect,$textRect,$width,$height,$imagePosition,$alignment,$contentOffset) {
 $contentRect = $contentRect|0;
 $imageSize = $imageSize|0;
 $textSize = $textSize|0;
 $imageRect = $imageRect|0;
 $textRect = $textRect|0;
 $width = $width|0;
 $height = $height|0;
 $imagePosition = $imagePosition|0;
 $alignment = $alignment|0;
 $contentOffset = $contentOffset|0;
 var $$$i = Math_fround(0), $$$i15 = Math_fround(0), $$0$i = Math_fround(0), $$0$i16 = Math_fround(0), $$phi$trans$insert = 0, $$phi$trans$insert49 = 0, $$phi$trans$insert51 = 0, $$pre = Math_fround(0), $$pre50 = Math_fround(0), $$pre52 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0);
 var $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0;
 var $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0);
 var $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0;
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $floorf$i$i = Math_fround(0), $floorf$i$i10 = Math_fround(0), $floorf$i$i11 = Math_fround(0);
 var $floorf$i$i12 = Math_fround(0), $floorf$i$i13 = Math_fround(0), $floorf$i$i14 = Math_fround(0), $floorf$i$i18 = Math_fround(0), $floorf$i$i6 = Math_fround(0), $floorf$i$i7 = Math_fround(0), $floorf$i$i8 = Math_fround(0), $floorf$i$i9 = Math_fround(0), $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $xAlign$0 = Math_fround(0), $yAlign$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$width>>2] = Math_fround(0.0);
 HEAPF32[$height>>2] = Math_fround(0.0);
 if ((($imagePosition|0) == 0)) {
  $0 = Math_fround(HEAPF32[$imageSize>>2]);
  $1 = $0 > Math_fround(0.0);
  do {
   if ($1) {
    $2 = Math_fround(0.0) == Math_fround(0.0);
    $3 = Math_fround(0.0) == Math_fround(0.0);
    $or$cond = $2 | $3;
    if (!($or$cond)) {
     HEAPF32[$imageSize>>2] = Math_fround(0.0);
     $22 = (($imageSize) + 4|0);
     HEAPF32[$22>>2] = Math_fround(0.0);
     $25 = Math_fround(0.0);$29 = Math_fround(0.0);
     break;
    }
    $4 = (($contentRect) + 8|0);
    $5 = Math_fround(HEAPF32[$4>>2]);
    $6 = Math_fround(HEAPF32[$textSize>>2]);
    $7 = Math_fround($5 - $6);
    $8 = Math_fround($7 / $0);
    $9 = (($contentRect) + 12|0);
    $10 = Math_fround(HEAPF32[$9>>2]);
    $11 = (($imageSize) + 4|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    $13 = Math_fround($10 / $12);
    $14 = $13 < $8;
    $15 = $14 ? $13 : $8;
    $16 = $15 < Math_fround(0.0);
    if ($16) {
     $$0$i = Math_fround(0.0);
    } else {
     $17 = $15 > Math_fround(1.0);
     $$$i = $17 ? Math_fround(1.0) : $15;
     $$0$i = $$$i;
    }
    $18 = Math_fround($$0$i * $0);
    $19 = Math_fround($18 + Math_fround(0.5));
    $floorf$i$i9 = (Math_fround(Math_floor((Math_fround($19)))));
    HEAPF32[$imageSize>>2] = $floorf$i$i9;
    $20 = Math_fround($$0$i * $12);
    $21 = Math_fround($20 + Math_fround(0.5));
    $floorf$i$i10 = (Math_fround(Math_floor((Math_fround($21)))));
    HEAPF32[$11>>2] = $floorf$i$i10;
    $25 = $floorf$i$i9;$29 = $floorf$i$i10;
   } else {
    $$phi$trans$insert = (($imageSize) + 4|0);
    $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
    $25 = $0;$29 = $$pre;
   }
  } while(0);
  $23 = Math_fround(HEAPF32[$textSize>>2]);
  $24 = Math_fround($25 + $23);
  HEAPF32[$width>>2] = $24;
  $26 = (($textSize) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = $29 < $27;
  $30 = $28 ? $27 : $29;
  HEAPF32[$height>>2] = $30;
  $104 = $30;
 } else if ((($imagePosition|0) == 3)) {
  $86 = Math_fround(HEAPF32[$textSize>>2]);
  HEAPF32[$width>>2] = $86;
  $87 = (($textSize) + 4|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  HEAPF32[$height>>2] = $88;
  $104 = $88;
 } else if ((($imagePosition|0) == 1)) {
  $31 = Math_fround(HEAPF32[$imageSize>>2]);
  $32 = $31 > Math_fround(0.0);
  do {
   if ($32) {
    $33 = Math_fround(0.0) == Math_fround(0.0);
    $34 = Math_fround(0.0) == Math_fround(0.0);
    $or$cond3 = $33 | $34;
    if (!($or$cond3)) {
     HEAPF32[$imageSize>>2] = Math_fround(0.0);
     $54 = (($imageSize) + 4|0);
     HEAPF32[$54>>2] = Math_fround(0.0);
     $57 = Math_fround(0.0);$62 = Math_fround(0.0);
     break;
    }
    $35 = (($contentRect) + 12|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = (($textSize) + 4|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = Math_fround($36 - $38);
    $40 = (($imageSize) + 4|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = Math_fround($39 / $41);
    $43 = (($contentRect) + 8|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = Math_fround($44 / $31);
    $46 = $45 < $42;
    $47 = $46 ? $45 : $42;
    $48 = $47 < Math_fround(0.0);
    if ($48) {
     $$0$i16 = Math_fround(0.0);
    } else {
     $49 = $47 > Math_fround(1.0);
     $$$i15 = $49 ? Math_fround(1.0) : $47;
     $$0$i16 = $$$i15;
    }
    $50 = Math_fround($$0$i16 * $31);
    $51 = Math_fround($50 + Math_fround(0.5));
    $floorf$i$i18 = (Math_fround(Math_floor((Math_fround($51)))));
    HEAPF32[$imageSize>>2] = $floorf$i$i18;
    $52 = Math_fround($$0$i16 * $41);
    $53 = Math_fround($52 + Math_fround(0.5));
    $floorf$i$i14 = (Math_fround(Math_floor((Math_fround($53)))));
    HEAPF32[$40>>2] = $floorf$i$i14;
    $57 = $floorf$i$i18;$62 = $floorf$i$i14;
   } else {
    $$phi$trans$insert49 = (($imageSize) + 4|0);
    $$pre50 = Math_fround(HEAPF32[$$phi$trans$insert49>>2]);
    $57 = $31;$62 = $$pre50;
   }
  } while(0);
  $55 = Math_fround(HEAPF32[$textSize>>2]);
  $56 = $57 < $55;
  $58 = $56 ? $55 : $57;
  HEAPF32[$width>>2] = $58;
  $59 = (($textSize) + 4|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround($62 + $60);
  HEAPF32[$height>>2] = $61;
  $104 = $61;
 } else if ((($imagePosition|0) == 2)) {
  $63 = Math_fround(HEAPF32[$imageSize>>2]);
  $64 = $63 > Math_fround(0.0);
  do {
   if ($64) {
    $65 = Math_fround(0.0) == Math_fround(0.0);
    $66 = Math_fround(0.0) == Math_fround(0.0);
    $or$cond5 = $65 | $66;
    if ($or$cond5) {
     $67 = (($contentRect) + 8|0);
     $68 = Math_fround(HEAPF32[$67>>2]);
     $69 = Math_fround($68 / $63);
     $70 = (($contentRect) + 12|0);
     $71 = Math_fround(HEAPF32[$70>>2]);
     $72 = (($imageSize) + 4|0);
     $73 = Math_fround(HEAPF32[$72>>2]);
     $74 = Math_fround($71 / $73);
     $75 = $74 < $69;
     $76 = $75 ? $74 : $69;
     $77 = $76 > Math_fround(1.0);
     $78 = $77 ? Math_fround(1.0) : $76;
     $79 = Math_fround($63 * $78);
     $80 = Math_fround($79 + Math_fround(0.5));
     $floorf$i$i13 = (Math_fround(Math_floor((Math_fround($80)))));
     HEAPF32[$imageSize>>2] = $floorf$i$i13;
     $81 = Math_fround($73 * $78);
     $82 = Math_fround($81 + Math_fround(0.5));
     $floorf$i$i12 = (Math_fround(Math_floor((Math_fround($82)))));
     HEAPF32[$72>>2] = $floorf$i$i12;
     $84 = $floorf$i$i13;$85 = $floorf$i$i12;
     break;
    } else {
     HEAPF32[$imageSize>>2] = Math_fround(0.0);
     $83 = (($imageSize) + 4|0);
     HEAPF32[$83>>2] = Math_fround(0.0);
     $84 = Math_fround(0.0);$85 = Math_fround(0.0);
     break;
    }
   } else {
    $$phi$trans$insert51 = (($imageSize) + 4|0);
    $$pre52 = Math_fround(HEAPF32[$$phi$trans$insert51>>2]);
    $84 = $63;$85 = $$pre52;
   }
  } while(0);
  HEAPF32[$width>>2] = $84;
  HEAPF32[$height>>2] = $85;
  $104 = $85;
 } else {
  $104 = Math_fround(0.0);
 }
 switch ($alignment|0) {
 case 1:  {
  $xAlign$0 = Math_fround(0.5);$yAlign$0 = Math_fround(0.0);
  break;
 }
 case 6:  {
  $xAlign$0 = Math_fround(0.0);$yAlign$0 = Math_fround(1.0);
  break;
 }
 case 4:  {
  $xAlign$0 = Math_fround(0.5);$yAlign$0 = Math_fround(0.5);
  break;
 }
 case 3:  {
  $xAlign$0 = Math_fround(0.0);$yAlign$0 = Math_fround(0.5);
  break;
 }
 case 7:  {
  $xAlign$0 = Math_fround(0.5);$yAlign$0 = Math_fround(1.0);
  break;
 }
 case 2:  {
  $xAlign$0 = Math_fround(1.0);$yAlign$0 = Math_fround(0.0);
  break;
 }
 case 8:  {
  $xAlign$0 = Math_fround(1.0);$yAlign$0 = Math_fround(1.0);
  break;
 }
 case 5:  {
  $xAlign$0 = Math_fround(1.0);$yAlign$0 = Math_fround(0.5);
  break;
 }
 default: {
  $xAlign$0 = Math_fround(0.0);$yAlign$0 = Math_fround(0.0);
 }
 }
 $89 = Math_fround(HEAPF32[$contentRect>>2]);
 $90 = (($contentRect) + 8|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround(HEAPF32[$width>>2]);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($xAlign$0 * $93);
 $95 = Math_fround($89 + $94);
 $96 = Math_fround(HEAPF32[$contentOffset>>2]);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($97 + Math_fround(0.5));
 $floorf$i$i11 = (Math_fround(Math_floor((Math_fround($98)))));
 $99 = (($contentRect) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($contentRect) + 12|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($102 - $104);
 $105 = Math_fround($yAlign$0 * $103);
 $106 = Math_fround($100 + $105);
 $107 = (($contentOffset) + 4|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($108 + $106);
 $110 = Math_fround($109 + Math_fround(0.5));
 $floorf$i$i8 = (Math_fround(Math_floor((Math_fround($110)))));
 if ((($imagePosition|0) == 1)) {
  $143 = Math_fround(HEAPF32[$imageSize>>2]);
  $144 = $143 > Math_fround(0.0);
  if ($144) {
   $145 = Math_fround($92 - $143);
   $146 = Math_fround($145 * Math_fround(0.5));
   $147 = Math_fround($floorf$i$i11 + $146);
   $148 = Math_fround($147 + Math_fround(0.5));
   $floorf$i$i7 = (Math_fround(Math_floor((Math_fround($148)))));
   $149 = (($imageSize) + 4|0);
   $150 = Math_fround(HEAPF32[$149>>2]);
   HEAPF32[$imageRect>>2] = $floorf$i$i7;
   $151 = (($imageRect) + 4|0);
   HEAPF32[$151>>2] = $floorf$i$i8;
   $152 = (($imageRect) + 8|0);
   HEAPF32[$152>>2] = $143;
   $153 = (($imageRect) + 12|0);
   HEAPF32[$153>>2] = $150;
  }
  $154 = Math_fround(HEAPF32[$textSize>>2]);
  $155 = $154 > Math_fround(0.0);
  if (!($155)) {
   STACKTOP = sp;return;
  }
  $156 = Math_fround(HEAPF32[$width>>2]);
  $157 = Math_fround($156 - $154);
  $158 = Math_fround($157 * Math_fround(0.5));
  $159 = Math_fround($floorf$i$i11 + $158);
  $160 = Math_fround($159 + Math_fround(0.5));
  $floorf$i$i6 = (Math_fround(Math_floor((Math_fround($160)))));
  $161 = (($imageSize) + 4|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($floorf$i$i8 + $162);
  $164 = (($textSize) + 4|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  HEAPF32[$textRect>>2] = $floorf$i$i6;
  $166 = (($textRect) + 4|0);
  HEAPF32[$166>>2] = $163;
  $167 = (($textRect) + 8|0);
  HEAPF32[$167>>2] = $154;
  $168 = (($textRect) + 12|0);
  HEAPF32[$168>>2] = $165;
  STACKTOP = sp;return;
 } else if ((($imagePosition|0) == 2)) {
  $169 = Math_fround(HEAPF32[$imageSize>>2]);
  $170 = $169 > Math_fround(0.0);
  if (!($170)) {
   STACKTOP = sp;return;
  }
  $171 = Math_fround($92 - $169);
  $172 = Math_fround($171 * Math_fround(0.5));
  $173 = Math_fround($floorf$i$i11 + $172);
  $174 = Math_fround($173 + Math_fround(0.5));
  $floorf$i$i = (Math_fround(Math_floor((Math_fround($174)))));
  $175 = (($imageSize) + 4|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  HEAPF32[$imageRect>>2] = $floorf$i$i;
  $177 = (($imageRect) + 4|0);
  HEAPF32[$177>>2] = $floorf$i$i8;
  $178 = (($imageRect) + 8|0);
  HEAPF32[$178>>2] = $169;
  $179 = (($imageRect) + 12|0);
  HEAPF32[$179>>2] = $176;
  STACKTOP = sp;return;
 } else if ((($imagePosition|0) == 3)) {
  $180 = Math_fround(HEAPF32[$textSize>>2]);
  $181 = $180 > Math_fround(0.0);
  if (!($181)) {
   STACKTOP = sp;return;
  }
  $182 = (($textSize) + 4|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  HEAPF32[$textRect>>2] = $floorf$i$i11;
  $184 = (($textRect) + 4|0);
  HEAPF32[$184>>2] = $floorf$i$i8;
  $185 = (($textRect) + 8|0);
  HEAPF32[$185>>2] = $180;
  $186 = (($textRect) + 12|0);
  HEAPF32[$186>>2] = $183;
  STACKTOP = sp;return;
 } else if ((($imagePosition|0) == 0)) {
  $111 = Math_fround(HEAPF32[$imageSize>>2]);
  $112 = $111 > Math_fround(0.0);
  if ($112) {
   $113 = (($imageSize) + 4|0);
   $114 = Math_fround(HEAPF32[$113>>2]);
   $115 = Math_fround($104 - $114);
   $116 = Math_fround($115 * Math_fround(0.5));
   $117 = Math_fround($floorf$i$i8 + $116);
   HEAPF32[$imageRect>>2] = $floorf$i$i11;
   $118 = (($imageRect) + 4|0);
   HEAPF32[$118>>2] = $117;
   $119 = (($imageRect) + 8|0);
   HEAPF32[$119>>2] = $111;
   $120 = (($imageRect) + 12|0);
   HEAPF32[$120>>2] = $114;
  }
  $121 = Math_fround(HEAPF32[$textSize>>2]);
  $122 = $121 > Math_fround(0.0);
  if (!($122)) {
   STACKTOP = sp;return;
  }
  if ($112) {
   $123 = Math_fround($floorf$i$i11 + $111);
   $124 = Math_fround($123 + Math_fround(1.0));
   $125 = Math_fround(HEAPF32[$height>>2]);
   $126 = (($textSize) + 4|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = Math_fround($125 - $127);
   $129 = Math_fround($128 * Math_fround(0.5));
   $130 = Math_fround($floorf$i$i8 + $129);
   HEAPF32[$textRect>>2] = $124;
   $131 = (($textRect) + 4|0);
   HEAPF32[$131>>2] = $130;
   $132 = (($textRect) + 8|0);
   HEAPF32[$132>>2] = $121;
   $133 = (($textRect) + 12|0);
   HEAPF32[$133>>2] = $127;
   STACKTOP = sp;return;
  } else {
   $134 = Math_fround(HEAPF32[$height>>2]);
   $135 = (($textSize) + 4|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = Math_fround($134 - $136);
   $138 = Math_fround($137 * Math_fround(0.5));
   $139 = Math_fround($floorf$i$i8 + $138);
   HEAPF32[$textRect>>2] = $floorf$i$i11;
   $140 = (($textRect) + 4|0);
   HEAPF32[$140>>2] = $139;
   $141 = (($textRect) + 8|0);
   HEAPF32[$141>>2] = $121;
   $142 = (($textRect) + 12|0);
   HEAPF32[$142>>2] = $136;
   STACKTOP = sp;return;
  }
 } else {
  STACKTOP = sp;return;
 }
}
function __Z14GetBuiltinSkini($skin) {
 $skin = $skin|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $pos$i$i$i$i1 = 0;
 var $temp$0$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i1 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP8[612440>>0]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   HEAP32[612424>>2] = 0;
   HEAP32[((612424 + 4|0))>>2] = 0;
   HEAP32[((612424 + 8|0))>>2] = 0;
   HEAP8[612440>>0] = 1;
   label = 13;
  } else {
   $$pre = HEAP32[612424>>2]|0;
   $5 = ($$pre|0)==(0);
   if ($5) {
    label = 13;
   } else {
    HEAP32[$0>>2] = $$pre;
    $6 = HEAP32[560624>>2]|0;
    $7 = ($6|0)==(0|0);
    if (!($7)) {
     $8 = (($6) + 36|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($6) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($9|0)==($11|0);
     do {
      if ($12) {
       $13 = (($6) + 28|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = (($6) + 32|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = (($14) + ($16<<3)|0);
       $33 = $17;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$6,$0);
       $18 = HEAP32[$pos$i$i$i$i1>>2]|0;
       $19 = ($18|0)==(-1);
       $20 = (($6) + 28|0);
       $21 = HEAP32[$20>>2]|0;
       if ($19) {
        $22 = (($6) + 32|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = (($21) + ($23<<3)|0);
        $33 = $24;
        break;
       } else {
        $25 = (($21) + ($18<<3)|0);
        $33 = $25;
        break;
       }
      }
     } while(0);
     $26 = HEAP32[560624>>2]|0;
     $27 = (($26) + 28|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($26) + 32|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + ($30<<3)|0);
     $32 = ($33|0)==($31|0);
     if (!($32)) {
      $34 = (($33) + 4|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==(0|0);
      if (!($36)) {
       break;
      }
     }
    }
    $37 = HEAP32[612424>>2]|0;
    $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
    $39 = ($38|0)==(0|0);
    if ($39) {
     label = 13;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 13) {
   $40 = (__Z25GetBuiltinResourceManagerv()|0);
   $41 = (__Znwj(32)|0);
   $42 = (($2) + 8|0);
   HEAP32[$42>>2] = $41;
   HEAP32[$2>>2] = 33;
   $43 = (($2) + 4|0);
   HEAP32[$43>>2] = 25;
   dest=$41+0|0; src=612448+0|0; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $44 = (($41) + 25|0);
   HEAP8[$44>>0] = 0;
   __THREW__ = 0;
   $45 = (invoke_iiii(1532,($40|0),114,($2|0))|0);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    $57 = HEAP8[$2>>0]|0;
    $58 = $57 & 1;
    $59 = ($58<<24>>24)==(0);
    if ($59) {
     ___resumeException($55|0);
     // unreachable;
    }
    $60 = HEAP32[$42>>2]|0;
    __ZdlPv($60);
    ___resumeException($55|0);
    // unreachable;
   }
   $48 = HEAP8[$2>>0]|0;
   $49 = $48 & 1;
   $50 = ($49<<24>>24)==(0);
   if (!($50)) {
    $51 = HEAP32[$42>>2]|0;
    __ZdlPv($51);
   }
   $52 = ($45|0)==(0|0);
   if ($52) {
    HEAP32[612424>>2] = 0;
    break;
   } else {
    $53 = (($45) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    HEAP32[612424>>2] = $54;
    break;
   }
  }
 } while(0);
 $61 = (612424 + ($skin<<2)|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$1>>2] = $62;
 $64 = HEAP32[560624>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  label = 30;
 } else {
  $66 = (($64) + 36|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($64) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($67|0)==($69|0);
  do {
   if ($70) {
    $71 = (($64) + 28|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($64) + 32|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($72) + ($74<<3)|0);
    $91 = $75;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$64,$1);
    $76 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $77 = ($76|0)==(-1);
    $78 = (($64) + 28|0);
    $79 = HEAP32[$78>>2]|0;
    if ($77) {
     $80 = (($64) + 32|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($79) + ($81<<3)|0);
     $91 = $82;
     break;
    } else {
     $83 = (($79) + ($76<<3)|0);
     $91 = $83;
     break;
    }
   }
  } while(0);
  $84 = HEAP32[560624>>2]|0;
  $85 = (($84) + 28|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (($84) + 32|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($86) + ($88<<3)|0);
  $90 = ($91|0)==($89|0);
  if ($90) {
   label = 30;
  } else {
   $92 = (($91) + 4|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0|0);
   if ($94) {
    label = 30;
   } else {
    $temp$0$i = $93;
   }
  }
 }
 if ((label|0) == 30) {
  $95 = HEAP32[$61>>2]|0;
  $96 = (__Z31ReadObjectFromPersistentManageri($95)|0);
  $temp$0$i = $96;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __Z14GetDefaultSkini($skinMode) {
 $skinMode = $skinMode|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14GetBuiltinSkini(0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN5IMGUI9GUIWindowD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body7$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3506,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   label = 15;
  } else {
   HEAP32[$0>>2] = 0;
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   $5 = (($this) + 104|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0);
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3506,($6|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 15;
     break;
    }
    HEAP32[$5>>2] = 0;
   }
   $10 = (($this) + 108|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0);
   if (!($12)) {
    __THREW__ = 0;
    invoke_vi(3506,($11|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 15;
     break;
    }
    HEAP32[$10>>2] = 0;
   }
   $15 = (($this) + 68|0);
   $16 = (($this) + 80|0);
   __THREW__ = 0;
   invoke_vi(3501,($16|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   do {
    if ($18) {
     $19 = ___cxa_find_matching_catch()|0;
     $20 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3501,($15|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      $23 = ___cxa_find_matching_catch(0|0)|0;
      $24 = tempRet0;
      ___clang_call_terminate($23);
      // unreachable;
     } else {
      $eh$lpad$body$index2Z2D = $20;$eh$lpad$body$indexZ2D = $19;
     }
    } else {
     __THREW__ = 0;
     invoke_vi(3501,($15|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      $42 = ___cxa_find_matching_catch()|0;
      $43 = tempRet0;
      $eh$lpad$body$index2Z2D = $43;$eh$lpad$body$indexZ2D = $42;
      break;
     } else {
      $27 = (($this) + 4|0);
      __ZN14ObjectGUIStateD2Ev($27);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   $$0 = $eh$lpad$body$index2Z2D;$$01 = $eh$lpad$body$indexZ2D;
   label = 21;
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = (($this) + 68|0);
   $31 = (($this) + 80|0);
   __THREW__ = 0;
   invoke_vi(3501,($31|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    __THREW__ = 0;
    invoke_vi(3501,($30|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    } else {
     $$0 = $29;$$01 = $28;
     label = 21;
     break;
    }
   }
   $34 = ___cxa_find_matching_catch(0|0)|0;
   $35 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3501,($30|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $38 = ___cxa_find_matching_catch(0|0)|0;
    $39 = tempRet0;
    ___clang_call_terminate($38);
    // unreachable;
   } else {
    $eh$lpad$body7$indexZ2D = $34;
    ___clang_call_terminate($eh$lpad$body7$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $44 = (($this) + 4|0);
  __THREW__ = 0;
  invoke_vi(3507,($44|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if (!($46)) {
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $47 = ___cxa_find_matching_catch(0|0)|0;
 $48 = tempRet0;
 $eh$lpad$body7$indexZ2D = $47;
 ___clang_call_terminate($eh$lpad$body7$indexZ2D);
 // unreachable;
}
function __ZN5IMGUI9GUIWindow5OnGUIER8GUIState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0;
 var $99 = 0, $exception = 0, $invocation = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $tmpcast1$byval_copy = sp + 224|0;
 $0 = sp;
 $invocation = sp + 8|0;
 $1 = sp + 208|0;
 $exception = sp + 216|0;
 $2 = (($state) + 280|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 112|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 116|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 120|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 124|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($state) + 12|0);
 HEAPF32[$12>>2] = $5;
 $13 = (($state) + 16|0);
 HEAPF32[$13>>2] = $7;
 $14 = (($state) + 20|0);
 HEAPF32[$14>>2] = $9;
 $15 = (($state) + 24|0);
 HEAPF32[$15>>2] = $11;
 $16 = (($this) + 128|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 132|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 136|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($this) + 140|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($state) + 28|0);
 HEAPF32[$24>>2] = $17;
 $25 = (($state) + 32|0);
 HEAPF32[$25>>2] = $19;
 $26 = (($state) + 36|0);
 HEAPF32[$26>>2] = $21;
 $27 = (($state) + 40|0);
 HEAPF32[$27>>2] = $23;
 $28 = (($this) + 144|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($this) + 148|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($this) + 152|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 156|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($state) + 44|0);
 HEAPF32[$36>>2] = $29;
 $37 = (($state) + 48|0);
 HEAPF32[$37>>2] = $31;
 $38 = (($state) + 52|0);
 HEAPF32[$38>>2] = $33;
 $39 = (($state) + 56|0);
 HEAPF32[$39>>2] = $35;
 $40 = (($this) + 224|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41&255;
 $43 = (($state) + 60|0);
 HEAP32[$43>>2] = $42;
 $44 = (($state) + 96|0);
 $45 = (($this) + 160|0);
 __ZN12GUIClipState9SetMatrixER10InputEventRK10Matrix4x4f($44,$3,$45);
 $46 = (($state) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 20|0);
 HEAP32[$48>>2] = $this;
 $49 = HEAP32[$3>>2]|0;
 $50 = ($49|0)==(7);
 if ($50) {
  $51 = (($3) + 4|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (($3) + 8|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($this) + 48|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = !($56 <= $52);
  if (!($57)) {
   $58 = (($this) + 56|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = Math_fround($56 + $59);
   $61 = $60 > $52;
   if ($61) {
    $62 = (($this) + 52|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    $64 = !($63 <= $54);
    if (!($64)) {
     $65 = (($this) + 60|0);
     $66 = Math_fround(HEAPF32[$65>>2]);
     $67 = Math_fround($63 + $66);
     $68 = $67 > $54;
     if ($68) {
      $69 = (($state) + 272|0);
      HEAP32[$69>>2] = 1;
     }
    }
   }
  }
 }
 $70 = (($state) + 72|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$46>>2]|0;
 $73 = (($72) + 12|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$this>>2]|0;
 $76 = ($74|0)==($75|0);
 $77 = $76&1;
 $78 = $77 & $71;
 HEAP32[$70>>2] = $78;
 $79 = (($this) + 108|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (__Z29scripting_gchandle_get_targeti($80)|0);
 $82 = ($81|0)==(0|0);
 if (!($82)) {
  $83 = HEAP32[$3>>2]|0;
  $84 = ($83|0)==(7);
  if ($84) {
   $85 = (($81) + 8|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($this) + 48|0);
   $88 = (($this) + 68|0);
   $89 = (($3) + 4|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = (($3) + 8|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = Math_fround(HEAPF32[$87>>2]);
   $94 = !($93 <= $90);
   if ($94) {
    $111 = 0;
   } else {
    $95 = (($this) + 56|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $97 = Math_fround($93 + $96);
    $98 = $97 > $90;
    if ($98) {
     $99 = (($this) + 52|0);
     $100 = Math_fround(HEAPF32[$99>>2]);
     $101 = !($100 <= $92);
     if ($101) {
      $111 = 0;
     } else {
      $102 = (($this) + 60|0);
      $103 = Math_fround(HEAPF32[$102>>2]);
      $104 = Math_fround($100 + $103);
      $105 = $104 > $92;
      $111 = $105;
     }
    } else {
     $111 = 0;
    }
   }
   $106 = HEAP32[$46>>2]|0;
   $107 = (($106) + 12|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = HEAP32[$this>>2]|0;
   $110 = ($108|0)==($109|0);
   __ZNK8GUIStyle4DrawER8GUIStateRK5RectTIfER10GUIContentbbbb($86,$state,$87,$88,$111,0,$110,0);
  }
 }
 $112 = HEAP32[$2>>2]|0;
 $113 = (($this) + 48|0);
 $114 = 616640;
 $115 = $114;
 $116 = HEAP32[$115>>2]|0;
 $117 = (($114) + 4)|0;
 $118 = $117;
 $119 = HEAP32[$118>>2]|0;
 $120 = $0;
 $121 = $120;
 HEAP32[$121>>2] = $116;
 $122 = (($120) + 4)|0;
 $123 = $122;
 HEAP32[$123>>2] = $119;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN12GUIClipState4PushER10InputEventRK5RectTIfE8Vector2fRKS6_b($44,$112,$113,$tmpcast1$byval_copy,616640,0);
 $124 = (($state) + 92|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = (($this) + 4|0);
 __ZN8GUIState10BeginOnGUIER14ObjectGUIState($state,$126);
 $127 = (__Z19GetScriptingManagerv()|0);
 $128 = (($127) + 440|0);
 $129 = $128;
 $130 = $129;
 $131 = HEAP32[$130>>2]|0;
 $132 = (($129) + 4)|0;
 $133 = $132;
 $134 = HEAP32[$133>>2]|0;
 $135 = $1;
 $136 = $135;
 HEAP32[$136>>2] = $131;
 $137 = (($135) + 4)|0;
 $138 = $137;
 HEAP32[$138>>2] = $134;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast1$byval_copy);
 $139 = (($this) + 100|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = (__Z29scripting_gchandle_get_targeti($140)|0);
 $142 = (($invocation) + 32|0);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($142,$141);
 $143 = HEAP32[$this>>2]|0;
 __ZN18ScriptingArguments6AddIntEi($142,$143);
 $144 = (($this) + 104|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = (__Z29scripting_gchandle_get_targeti($145)|0);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($142,$146);
 $147 = (($this) + 98|0);
 $148 = HEAP8[$147>>0]|0;
 $149 = $148&255;
 __ZN18ScriptingArguments6AddIntEi($142,$149);
 $150 = (($this) + 56|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 __ZN18ScriptingArguments8AddFloatEf($142,$151);
 $152 = (($this) + 60|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 __ZN18ScriptingArguments8AddFloatEf($142,$153);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($142,$81);
 $154 = HEAP32[$73>>2]|0;
 $155 = HEAP32[$this>>2]|0;
 $156 = ($154|0)==($155|0);
 $157 = $156&1;
 HEAP32[$70>>2] = $157;
 HEAP32[$exception>>2] = 0;
 $158 = (($invocation) + 25|0);
 HEAP8[$158>>0] = 0;
 (__ZN19ScriptingInvocation6InvokeEPP18ScriptingException($invocation,$exception)|0);
 __ZN8GUIState8EndOnGUIEv($state);
 HEAP32[$124>>2] = $125;
 __ZN12GUIClipState3PopER10InputEvent($44,$3);
 $159 = HEAP32[$46>>2]|0;
 $160 = (($159) + 20|0);
 HEAP32[$160>>2] = 0;
 HEAP32[$70>>2] = $71;
 STACKTOP = sp;return;
}
function __ZN5IMGUI12BeginWindowsER8GUIStatebb($state,$setupClipping,$ignoreModalWindow) {
 $state = $state|0;
 $setupClipping = $setupClipping|0;
 $ignoreModalWindow = $ignoreModalWindow|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$07$i = 0, $i$07$i3 = 0, $oldProperties = 0, $phitmp = 0;
 var $win$011 = 0, $win$1 = 0, $win$114 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 116|0;
 $oldProperties = sp;
 $1 = (($state) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($state) + 280|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($state) + 108|0);
 dest=$oldProperties+0|0; src=$6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $7 = (($state) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($state) + 16|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($state) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($state) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($oldProperties) + 64|0);
 HEAPF32[$15>>2] = $8;
 $16 = (($oldProperties) + 68|0);
 HEAPF32[$16>>2] = $10;
 $17 = (($oldProperties) + 72|0);
 HEAPF32[$17>>2] = $12;
 $18 = (($oldProperties) + 76|0);
 HEAPF32[$18>>2] = $14;
 $19 = (($state) + 44|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($state) + 48|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($state) + 52|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($state) + 56|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($oldProperties) + 80|0);
 HEAPF32[$27>>2] = $20;
 $28 = (($oldProperties) + 84|0);
 HEAPF32[$28>>2] = $22;
 $29 = (($oldProperties) + 88|0);
 HEAPF32[$29>>2] = $24;
 $30 = (($oldProperties) + 92|0);
 HEAPF32[$30>>2] = $26;
 $31 = (($state) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($state) + 32|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($state) + 36|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($state) + 40|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($oldProperties) + 96|0);
 HEAPF32[$39>>2] = $32;
 $40 = (($oldProperties) + 100|0);
 HEAPF32[$40>>2] = $34;
 $41 = (($oldProperties) + 104|0);
 HEAPF32[$41>>2] = $36;
 $42 = (($oldProperties) + 108|0);
 HEAPF32[$42>>2] = $38;
 $43 = (($state) + 60|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)!=(0);
 $46 = (($oldProperties) + 112|0);
 $47 = $45&1;
 HEAP8[$46>>0] = $47;
 if ($setupClipping) {
  $48 = (($state) + 96|0);
  __ZN12GUIClipState10BeginOnGUIER10InputEvent($48,$4);
 }
 $49 = (($2) + 16|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = ($50<<24>>24)==(0);
 if (!($51)) {
  $52 = HEAP32[$2>>2]|0;
  $53 = (($2) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  HEAP32[$0>>2] = 2410;
  __ZNSt3__16__sortIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEvT0_SA_T_($52,$54,$0);
  $55 = HEAP32[$53>>2]|0;
  $56 = HEAP32[$2>>2]|0;
  $57 = ($55|0)==($56|0);
  if (!($57)) {
   $58 = $55;
   $59 = $56;
   $60 = (($58) - ($59))|0;
   $61 = $60 >> 2;
   $i$07$i = 0;
   while(1) {
    $62 = (($56) + ($i$07$i<<2)|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($63) + 64|0);
    HEAP32[$64>>2] = $i$07$i;
    $65 = (($i$07$i) + 1)|0;
    $66 = ($65>>>0)<($61>>>0);
    if ($66) {
     $i$07$i = $65;
    } else {
     break;
    }
   }
  }
 }
 $67 = HEAP32[$4>>2]|0;
 L13: do {
  switch ($67|0) {
  case 0:  {
   $115 = (($2) + 12|0);
   HEAP32[$115>>2] = -1;
   if ($ignoreModalWindow) {
    label = 31;
   } else {
    $116 = (($2) + 24|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ($117|0)==(0|0);
    if ($118) {
     label = 31;
    } else {
     $win$011 = $117;
    }
   }
   if ((label|0) == 31) {
    $119 = (__ZN5IMGUI14GUIWindowState20FindWindowUnderMouseER8GUIState($2,$state)|0);
    $120 = ($119|0)==(0|0);
    if ($120) {
     break L13;
    } else {
     $win$011 = $119;
    }
   }
   $121 = (($win$011) + 64|0);
   HEAP32[$121>>2] = -1;
   $122 = HEAP32[$win$011>>2]|0;
   HEAP32[$115>>2] = $122;
   $123 = HEAP32[$2>>2]|0;
   $124 = (($2) + 4|0);
   $125 = HEAP32[$124>>2]|0;
   HEAP32[$0>>2] = 2410;
   __ZNSt3__16__sortIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEvT0_SA_T_($123,$125,$0);
   $126 = HEAP32[$124>>2]|0;
   $127 = HEAP32[$2>>2]|0;
   $128 = ($126|0)==($127|0);
   if ($128) {
    $win$114 = $win$011;
    label = 47;
   } else {
    $129 = $126;
    $130 = $127;
    $131 = (($129) - ($130))|0;
    $132 = $131 >> 2;
    $i$07$i3 = 0;
    while(1) {
     $133 = (($127) + ($i$07$i3<<2)|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($134) + 64|0);
     HEAP32[$135>>2] = $i$07$i3;
     $136 = (($i$07$i3) + 1)|0;
     $137 = ($136>>>0)<($132>>>0);
     if ($137) {
      $i$07$i3 = $136;
     } else {
      $win$1 = $win$011;
      label = 46;
      break;
     }
    }
   }
   break;
  }
  case 15: case 10: case 9:  {
   if (!($ignoreModalWindow)) {
    $81 = (($2) + 24|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ($82|0)==(0|0);
    if (!($83)) {
     $win$114 = $82;
     label = 47;
     break L13;
    }
   }
   $84 = (__ZN5IMGUI14GUIWindowState20FindWindowUnderMouseER8GUIState($2,$state)|0);
   $win$1 = $84;
   label = 46;
   break;
  }
  case 8:  {
   $68 = HEAP32[$2>>2]|0;
   $69 = (($2) + 4|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($68|0)==($70|0);
   if (!($71)) {
    $73 = $68;
    while(1) {
     $72 = HEAP32[$73>>2]|0;
     $74 = (($72) + 96|0);
     HEAP8[$74>>0] = 0;
     $75 = (($73) + 4|0);
     $76 = ($75|0)==($70|0);
     if ($76) {
      break;
     } else {
      $73 = $75;
     }
    }
   }
   if (!($ignoreModalWindow)) {
    $77 = (($2) + 24|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ($78|0)==(0|0);
    if (!($79)) {
     $80 = (($78) + 96|0);
     HEAP8[$80>>0] = 0;
    }
   }
   break;
  }
  case 2: case 3: case 1:  {
   if (!($ignoreModalWindow)) {
    $85 = (($2) + 24|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==(0|0);
    if (!($87)) {
     $win$114 = $86;
     label = 47;
     break L13;
    }
   }
   $88 = (($state) + 276|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($89) + 4|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(0);
   if ($92) {
    $93 = (__ZN5IMGUI14GUIWindowState20FindWindowUnderMouseER8GUIState($2,$state)|0);
    $win$1 = $93;
    label = 46;
    break L13;
   }
   $94 = (($2) + 12|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = HEAP32[$2>>2]|0;
   $97 = (($2) + 4|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($96|0)==($98|0);
   if (!($99)) {
    $103 = $96;
    while(1) {
     $102 = HEAP32[$103>>2]|0;
     $104 = HEAP32[$102>>2]|0;
     $105 = ($104|0)==($95|0);
     $101 = (($103) + 4|0);
     if ($105) {
      $win$1 = $102;
      label = 46;
      break L13;
     }
     $100 = ($101|0)==($98|0);
     if ($100) {
      break;
     } else {
      $103 = $101;
     }
    }
   }
   $106 = (($2) + 24|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($107|0)==(0|0);
   if (!($108)) {
    $109 = HEAP32[$107>>2]|0;
    $110 = ($109|0)==($95|0);
    if ($110) {
     $win$114 = $107;
     label = 47;
    }
   }
   break;
  }
  case 6:  {
   if (!($ignoreModalWindow)) {
    $111 = (($2) + 24|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($112|0)==(0|0);
    if (!($113)) {
     $win$114 = $112;
     label = 47;
     break L13;
    }
   }
   $114 = (__ZN5IMGUI14GUIWindowState20FindWindowUnderMouseER8GUIState($2,$state)|0);
   $win$1 = $114;
   label = 46;
   break;
  }
  case 7:  {
   if ($ignoreModalWindow) {
    label = 37;
   } else {
    $138 = (($2) + 24|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = ($139|0)==(0|0);
    if ($140) {
     label = 37;
    } else {
     $146 = 0;
    }
   }
   if ((label|0) == 37) {
    $141 = (__ZN5IMGUI14GUIWindowState20FindWindowUnderMouseER8GUIState($2,$state)|0);
    $142 = ($141|0)==(0|0);
    $phitmp = $142&1;
    $146 = $phitmp;
   }
   $143 = (($state) + 276|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = (($144) + 8|0);
   HEAP8[$145>>0] = $146;
   STACKTOP = sp;return;
   break;
  }
  default: {
   if (!($ignoreModalWindow)) {
    $147 = (($2) + 24|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ($148|0)==(0|0);
    if (!($149)) {
     $win$114 = $148;
     label = 47;
     break L13;
    }
   }
   $150 = (($2) + 12|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = HEAP32[$2>>2]|0;
   $153 = (($2) + 4|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ($152|0)==($154|0);
   if (!($155)) {
    $159 = $152;
    while(1) {
     $158 = HEAP32[$159>>2]|0;
     $160 = HEAP32[$158>>2]|0;
     $161 = ($160|0)==($151|0);
     $157 = (($159) + 4|0);
     if ($161) {
      $win$1 = $158;
      label = 46;
      break L13;
     }
     $156 = ($157|0)==($154|0);
     if ($156) {
      break;
     } else {
      $159 = $157;
     }
    }
   }
   $162 = (($2) + 24|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ($163|0)==(0|0);
   if (!($164)) {
    $165 = HEAP32[$163>>2]|0;
    $166 = ($165|0)==($151|0);
    if ($166) {
     $win$114 = $163;
     label = 47;
    }
   }
  }
  }
 } while(0);
 if ((label|0) == 46) {
  $167 = ($win$1|0)==(0|0);
  if (!($167)) {
   $win$114 = $win$1;
   label = 47;
  }
 }
 L70: do {
  if ((label|0) == 47) {
   $168 = (($win$114) + 100|0);
   $169 = HEAP32[$168>>2]|0;
   $170 = ($169|0)==(0);
   if (!($170)) {
    __ZN5IMGUI9GUIWindow5OnGUIER8GUIState($win$114,$state);
    if (!($ignoreModalWindow)) {
     $171 = (($2) + 24|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = ($172|0)==(0|0);
     if (!($173)) {
      $174 = HEAP32[$4>>2]|0;
      switch ($174|0) {
      case 1: case 3: case 2:  {
       break;
      }
      case 0: case 6:  {
       HEAP32[$4>>2] = 11;
       break L70;
       break;
      }
      default: {
       break L70;
      }
      }
      $175 = (($state) + 276|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = (($176) + 4|0);
      $178 = HEAP32[$177>>2]|0;
      $179 = ($178|0)==(0);
      if ($179) {
       HEAP32[$4>>2] = 11;
      }
     }
    }
   }
  }
 } while(0);
 $180 = (($state) + 96|0);
 __ZN12GUIClipState9SetMatrixER10InputEventRK10Matrix4x4f($180,$4,$oldProperties);
 $181 = Math_fround(HEAPF32[$15>>2]);
 $182 = Math_fround(HEAPF32[$16>>2]);
 $183 = Math_fround(HEAPF32[$17>>2]);
 $184 = Math_fround(HEAPF32[$18>>2]);
 HEAPF32[$7>>2] = $181;
 HEAPF32[$9>>2] = $182;
 HEAPF32[$11>>2] = $183;
 HEAPF32[$13>>2] = $184;
 $185 = Math_fround(HEAPF32[$27>>2]);
 $186 = Math_fround(HEAPF32[$28>>2]);
 $187 = Math_fround(HEAPF32[$29>>2]);
 $188 = Math_fround(HEAPF32[$30>>2]);
 HEAPF32[$19>>2] = $185;
 HEAPF32[$21>>2] = $186;
 HEAPF32[$23>>2] = $187;
 HEAPF32[$25>>2] = $188;
 $189 = Math_fround(HEAPF32[$39>>2]);
 $190 = Math_fround(HEAPF32[$40>>2]);
 $191 = Math_fround(HEAPF32[$41>>2]);
 $192 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$31>>2] = $189;
 HEAPF32[$33>>2] = $190;
 HEAPF32[$35>>2] = $191;
 HEAPF32[$37>>2] = $192;
 $193 = HEAP8[$46>>0]|0;
 $194 = $193&255;
 HEAP32[$43>>2] = $194;
 if (!($setupClipping)) {
  STACKTOP = sp;return;
 }
 $195 = HEAP32[$3>>2]|0;
 __ZN12GUIClipState8EndOnGUIER10InputEvent($180,$195);
 STACKTOP = sp;return;
}
function __ZN5IMGUI14GUIWindowState20FindWindowUnderMouseER8GUIState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $7 = 0;
 var $8 = Math_fround(0), $9 = 0, $evt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $evt = sp;
 $0 = (($state) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN10InputEventC2ERKS_($evt,$1);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($evt) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($evt) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($3) + 48|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = !($10 <= $6);
  if (!($11)) {
   $12 = (($3) + 56|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = Math_fround($10 + $13);
   $15 = $14 > $6;
   if ($15) {
    $16 = (($3) + 52|0);
    $17 = Math_fround(HEAPF32[$16>>2]);
    $18 = !($17 <= $8);
    if (!($18)) {
     $19 = (($3) + 60|0);
     $20 = Math_fround(HEAPF32[$19>>2]);
     $21 = Math_fround($17 + $20);
     $22 = $21 > $8;
     if ($22) {
      $$0 = $3;
      __ZN10InputEventD2Ev($evt);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = (($this) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27|0)==($29|0);
 if ($30) {
  $$0 = 0;
  __ZN10InputEventD2Ev($evt);
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (($state) + 96|0);
 $32 = (($evt) + 4|0);
 $33 = (($evt) + 8|0);
 $35 = $27;
 while(1) {
  $34 = HEAP32[$35>>2]|0;
  $36 = (($34) + 160|0);
  __THREW__ = 0;
  invoke_viii(1761,($31|0),($evt|0),($36|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   label = 6;
   break;
  }
  $39 = HEAP32[$35>>2]|0;
  $40 = Math_fround(HEAPF32[$32>>2]);
  $41 = Math_fround(HEAPF32[$33>>2]);
  $42 = (($39) + 48|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = !($43 <= $40);
  if (!($44)) {
   $45 = (($39) + 56|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = Math_fround($43 + $46);
   $48 = $47 > $40;
   if ($48) {
    $49 = (($39) + 52|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = !($50 <= $41);
    if (!($51)) {
     $52 = (($39) + 60|0);
     $53 = Math_fround(HEAPF32[$52>>2]);
     $54 = Math_fround($50 + $53);
     $55 = $54 > $41;
     if ($55) {
      $$0 = $39;
      label = 15;
      break;
     }
    }
   }
  }
  $56 = (($35) + 4|0);
  $57 = HEAP32[$28>>2]|0;
  $58 = ($56|0)==($57|0);
  if ($58) {
   $$0 = 0;
   label = 15;
   break;
  } else {
   $35 = $56;
  }
 }
 if ((label|0) == 6) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3498,($evt|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $59 = ___cxa_find_matching_catch(0|0)|0;
   $60 = tempRet0;
   ___clang_call_terminate($59);
   // unreachable;
  } else {
   ___resumeException($23|0);
   // unreachable;
  }
 }
 else if ((label|0) == 15) {
  __ZN10InputEventD2Ev($evt);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5IMGUI10EndWindowsER8GUIStateb($state,$ignoreModalWindow) {
 $state = $state|0;
 $ignoreModalWindow = $ignoreModalWindow|0;
 var $$0 = 0, $$01 = 0, $$clearFocus$0$off0 = 0, $$idx = 0, $$in = 0, $$in21 = 0, $$in22 = 0, $$pre = 0, $$pre30 = 0, $$pre34 = 0, $$pre35 = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $clearFocus$0$off0$ph19 = 0;
 var $clearFocus$0$off0$ph20 = 0, $i$07$i = 0, $not$ = 0, $oldProperties = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, $windowUnderMouse$0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 116|0;
 $oldProperties = sp;
 $1 = (($state) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($state) + 108|0);
 dest=$oldProperties+0|0; src=$4+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = (($state) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($state) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($state) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($state) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($oldProperties) + 64|0);
 HEAPF32[$13>>2] = $6;
 $14 = (($oldProperties) + 68|0);
 HEAPF32[$14>>2] = $8;
 $15 = (($oldProperties) + 72|0);
 HEAPF32[$15>>2] = $10;
 $16 = (($oldProperties) + 76|0);
 HEAPF32[$16>>2] = $12;
 $17 = (($state) + 44|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($state) + 48|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($state) + 52|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($state) + 56|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($oldProperties) + 80|0);
 HEAPF32[$25>>2] = $18;
 $26 = (($oldProperties) + 84|0);
 HEAPF32[$26>>2] = $20;
 $27 = (($oldProperties) + 88|0);
 HEAPF32[$27>>2] = $22;
 $28 = (($oldProperties) + 92|0);
 HEAPF32[$28>>2] = $24;
 $29 = (($state) + 28|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($state) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($state) + 36|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($state) + 40|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($oldProperties) + 96|0);
 HEAPF32[$37>>2] = $30;
 $38 = (($oldProperties) + 100|0);
 HEAPF32[$38>>2] = $32;
 $39 = (($oldProperties) + 104|0);
 HEAPF32[$39>>2] = $34;
 $40 = (($oldProperties) + 108|0);
 HEAPF32[$40>>2] = $36;
 $41 = (($state) + 60|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)!=(0);
 $44 = (($oldProperties) + 112|0);
 $45 = $43&1;
 HEAP8[$44>>0] = $45;
 $46 = (($state) + 280|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 do {
  if ((($48|0) == 8)) {
   $49 = (($2) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = HEAP32[$2>>2]|0;
   $52 = $50;
   $53 = $51;
   $54 = (($52) - ($53))|0;
   $55 = $54 >> 2;
   $56 = ($55|0)==(0);
   L6: do {
    if ($56) {
     $clearFocus$0$off0$ph19 = 1;
    } else {
     $57 = (($2) + 16|0);
     $58 = (($2) + 12|0);
     $$in21 = $55;$181 = $51;$182 = $50;$clearFocus$0$off0$ph20 = 1;
     L8: while(1) {
      $$in22 = $$in21;$183 = $182;$61 = $181;
      while(1) {
       $59 = (($$in22) + -1)|0;
       $60 = (($61) + ($59<<2)|0);
       $62 = HEAP32[$60>>2]|0;
       $63 = (($62) + 96|0);
       $64 = HEAP8[$63>>0]|0;
       $65 = ($64<<24>>24)==(0);
       if (!($65)) {
        break;
       }
       $66 = ($62|0)==(0|0);
       if ($66) {
        $71 = $61;$74 = $183;
       } else {
        __THREW__ = 0;
        invoke_vi(3508,($62|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break L8;
        }
        __ZdlPv($62);
        $$pre = HEAP32[$2>>2]|0;
        $$pre30 = HEAP32[$49>>2]|0;
        $71 = $$pre;$74 = $$pre30;
       }
       $$idx = $59 << 2;
       $69 = $$idx >> 2;
       $70 = (($71) + ($69<<2)|0);
       $$sum$i = (($69) + 1)|0;
       $72 = (($71) + ($$sum$i<<2)|0);
       $73 = $74;
       $75 = $72;
       $76 = (($73) - ($75))|0;
       $77 = $76 >> 2;
       _memmove(($70|0),($72|0),($76|0))|0;
       $$sum1$i = (($77) + ($69))|0;
       $78 = (($71) + ($$sum1$i<<2)|0);
       $79 = HEAP32[$49>>2]|0;
       $80 = ($79|0)==($78|0);
       if ($80) {
        $184 = $78;
       } else {
        $__new_last2$i$i$i = $78;
        $scevgep$i$i$i = (($79) + -4|0);
        $81 = (0 - ($__new_last2$i$i$i))|0;
        $uglygep$i$i$i = (($scevgep$i$i$i) + ($81)|0);
        $uglygep3$i$i$i = $uglygep$i$i$i;
        $82 = $uglygep3$i$i$i >>> 2;
        $83 = $82 ^ -1;
        $scevgep4$i$i$i = (($79) + ($83<<2)|0);
        HEAP32[$49>>2] = $scevgep4$i$i$i;
        $184 = $scevgep4$i$i$i;
       }
       HEAP8[$57>>0] = 1;
       $84 = ($59|0)==(0);
       if ($84) {
        $clearFocus$0$off0$ph19 = $clearFocus$0$off0$ph20;
        break L6;
       }
       $$pre34 = HEAP32[$2>>2]|0;
       $$in22 = $59;$183 = $184;$61 = $$pre34;
      }
      $87 = HEAP32[$62>>2]|0;
      $88 = HEAP32[$58>>2]|0;
      $not$ = ($87|0)!=($88|0);
      $$clearFocus$0$off0 = $clearFocus$0$off0$ph20 & $not$;
      $89 = ($59|0)==(0);
      if ($89) {
       $clearFocus$0$off0$ph19 = $$clearFocus$0$off0;
       break L6;
      } else {
       $$in21 = $59;$181 = $61;$182 = $183;$clearFocus$0$off0$ph20 = $$clearFocus$0$off0;
      }
     }
     $85 = ___cxa_find_matching_catch()|0;
     $86 = tempRet0;
     __ZdlPv($62);
     $$0 = $86;$$01 = $85;
     ___resumeException($$01|0);
     // unreachable;
    }
   } while(0);
   do {
    if (!($ignoreModalWindow)) {
     $90 = (($2) + 24|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($91|0)==(0|0);
     if (!($92)) {
      $93 = (($91) + 96|0);
      $94 = HEAP8[$93>>0]|0;
      $95 = ($94<<24>>24)==(0);
      if ($95) {
       __THREW__ = 0;
       invoke_vi(3508,($91|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        __ZdlPv($91);
        HEAP32[$90>>2] = 0;
        break;
       }
       $98 = ___cxa_find_matching_catch()|0;
       $99 = tempRet0;
       __ZdlPv($91);
       $$0 = $99;$$01 = $98;
       ___resumeException($$01|0);
       // unreachable;
      }
     }
    }
   } while(0);
   if ($clearFocus$0$off0$ph19) {
    $100 = (($2) + 12|0);
    HEAP32[$100>>2] = -1;
   }
   $101 = (($2) + 16|0);
   $102 = HEAP8[$101>>0]|0;
   $103 = ($102<<24>>24)==(0);
   if (!($103)) {
    $104 = HEAP32[$2>>2]|0;
    $105 = HEAP32[$49>>2]|0;
    HEAP32[$0>>2] = 2410;
    __ZNSt3__16__sortIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEvT0_SA_T_($104,$105,$0);
    $106 = HEAP32[$49>>2]|0;
    $107 = HEAP32[$2>>2]|0;
    $108 = ($106|0)==($107|0);
    if (!($108)) {
     $109 = $106;
     $110 = $107;
     $111 = (($109) - ($110))|0;
     $112 = $111 >> 2;
     $i$07$i = 0;
     while(1) {
      $113 = (($107) + ($i$07$i<<2)|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = (($114) + 64|0);
      HEAP32[$115>>2] = $i$07$i;
      $116 = (($i$07$i) + 1)|0;
      $117 = ($116>>>0)<($112>>>0);
      if ($117) {
       $i$07$i = $116;
      } else {
       break;
      }
     }
    }
   }
   if (!($ignoreModalWindow)) {
    $118 = (($2) + 24|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($119|0)==(0|0);
    if (!($120)) {
     __ZN5IMGUI9GUIWindow5OnGUIER8GUIState($119,$state);
    }
   }
   $121 = HEAP32[$2>>2]|0;
   $122 = HEAP32[$49>>2]|0;
   $123 = ($121|0)==($122|0);
   if (!($123)) {
    $125 = $121;
    while(1) {
     $124 = HEAP32[$125>>2]|0;
     __ZN5IMGUI9GUIWindow5OnGUIER8GUIState($124,$state);
     $126 = (($125) + 4|0);
     $127 = HEAP32[$49>>2]|0;
     $128 = ($126|0)==($127|0);
     if ($128) {
      break;
     } else {
      $125 = $126;
     }
    }
   }
  } else if ((($48|0) == 7)) {
   $129 = (($2) + 24|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    $132 = (__ZN5IMGUI14GUIWindowState20FindWindowUnderMouseER8GUIState($2,$state)|0);
    $windowUnderMouse$0 = $132;
   } else {
    $windowUnderMouse$0 = $130;
   }
   $133 = (($2) + 4|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = HEAP32[$2>>2]|0;
   $136 = $134;
   $137 = $135;
   $138 = (($136) - ($137))|0;
   $139 = $138 >> 2;
   $140 = ($139|0)==(0);
   L53: do {
    if (!($140)) {
     $141 = (($state) + 276|0);
     $$in = $139;$144 = $135;
     while(1) {
      $142 = (($$in) + -1)|0;
      $143 = (($144) + ($142<<2)|0);
      $145 = HEAP32[$143>>2]|0;
      $146 = ($145|0)==($windowUnderMouse$0|0);
      if ($146) {
       $147 = HEAP32[$129>>2]|0;
       $148 = ($147|0)==(0|0);
       $phitmp = $148&1;
       $151 = $phitmp;
      } else {
       $151 = 0;
      }
      $149 = HEAP32[$141>>2]|0;
      $150 = (($149) + 8|0);
      HEAP8[$150>>0] = $151;
      __ZN5IMGUI9GUIWindow5OnGUIER8GUIState($145,$state);
      $152 = ($142|0)==(0);
      if ($152) {
       break L53;
      }
      $$pre35 = HEAP32[$2>>2]|0;
      $$in = $142;$144 = $$pre35;
     }
    }
   } while(0);
   if (!($ignoreModalWindow)) {
    $153 = HEAP32[$129>>2]|0;
    $154 = ($153|0)==(0|0);
    if (!($154)) {
     $158 = (($state) + 276|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = (($159) + 8|0);
     HEAP8[$160>>0] = 0;
     break;
    }
   }
   $155 = (($state) + 276|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = (($156) + 8|0);
   HEAP8[$157>>0] = 1;
  }
 } while(0);
 $161 = (($state) + 96|0);
 __ZN12GUIClipState9SetMatrixER10InputEventRK10Matrix4x4f($161,$47,$oldProperties);
 $162 = Math_fround(HEAPF32[$13>>2]);
 $163 = Math_fround(HEAPF32[$14>>2]);
 $164 = Math_fround(HEAPF32[$15>>2]);
 $165 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$5>>2] = $162;
 HEAPF32[$7>>2] = $163;
 HEAPF32[$9>>2] = $164;
 HEAPF32[$11>>2] = $165;
 $166 = Math_fround(HEAPF32[$25>>2]);
 $167 = Math_fround(HEAPF32[$26>>2]);
 $168 = Math_fround(HEAPF32[$27>>2]);
 $169 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$17>>2] = $166;
 HEAPF32[$19>>2] = $167;
 HEAPF32[$21>>2] = $168;
 HEAPF32[$23>>2] = $169;
 $170 = Math_fround(HEAPF32[$37>>2]);
 $171 = Math_fround(HEAPF32[$38>>2]);
 $172 = Math_fround(HEAPF32[$39>>2]);
 $173 = Math_fround(HEAPF32[$40>>2]);
 HEAPF32[$29>>2] = $170;
 HEAPF32[$31>>2] = $171;
 HEAPF32[$33>>2] = $172;
 HEAPF32[$35>>2] = $173;
 $174 = HEAP8[$44>>0]|0;
 $175 = $174&255;
 HEAP32[$41>>2] = $175;
 $176 = HEAP32[$47>>2]|0;
 $177 = ($176|0)==(8);
 if ($177) {
  STACKTOP = sp;return;
 }
 if (!($ignoreModalWindow)) {
  $178 = (($2) + 24|0);
  $179 = HEAP32[$178>>2]|0;
  $180 = ($179|0)==(0|0);
  if (!($180)) {
   STACKTOP = sp;return;
  }
 }
 __ZN5IMGUI14GUIWindowState23ReleaseScriptingObjectsEv($2);
 STACKTOP = sp;return;
}
function __ZN5IMGUI14GUIWindowState23ReleaseScriptingObjectsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if (!($3)) {
  $5 = $0;
  while(1) {
   $4 = HEAP32[$5>>2]|0;
   $6 = (($4) + 100|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if (!($8)) {
    __Z23scripting_gchandle_freei($7);
    HEAP32[$6>>2] = 0;
   }
   $9 = (($4) + 104|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   if (!($11)) {
    __Z23scripting_gchandle_freei($10);
    HEAP32[$9>>2] = 0;
   }
   $12 = (($4) + 108|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0);
   if (!($14)) {
    __Z23scripting_gchandle_freei($13);
    HEAP32[$12>>2] = 0;
   }
   $15 = (($5) + 4|0);
   $16 = HEAP32[$1>>2]|0;
   $17 = ($15|0)==($16|0);
   if ($17) {
    break;
   } else {
    $5 = $15;
   }
  }
 }
 $18 = (($this) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = (($19) + 100|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if (!($23)) {
  __Z23scripting_gchandle_freei($22);
  HEAP32[$21>>2] = 0;
 }
 $24 = (($19) + 104|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if (!($26)) {
  __Z23scripting_gchandle_freei($25);
  HEAP32[$24>>2] = 0;
 }
 $27 = (($19) + 108|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0);
 if ($29) {
  STACKTOP = sp;return;
 }
 __Z23scripting_gchandle_freei($28);
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5IMGUI18RepaintModalWindowER8GUIState($state) {
 $state = $state|0;
 var $$pr$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($state) + 280|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(7);
 if ($6) {
  $7 = (($state) + 276|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 8|0);
  HEAP8[$9>>0] = 1;
  $10 = (($1) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   __ZN5IMGUI9GUIWindow5OnGUIER8GUIState($11,$state);
   $$pr$pre = HEAP32[$4>>2]|0;
   $14 = $$pr$pre;
   label = 5;
  }
 } else {
  $14 = $5;
  label = 5;
 }
 if ((label|0) == 5) {
  $13 = ($14|0)==(8);
  if ($13) {
   STACKTOP = sp;return;
  }
 }
 __ZN5IMGUI14GUIWindowState23ReleaseScriptingObjectsEv($1);
 STACKTOP = sp;return;
}
function __ZN5IMGUI16GetFocusedWindowER8GUIState($state) {
 $state = $state|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (($1) + 12|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = HEAP32[$1>>2]|0;
   $6 = (($1) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5|0)==($7|0);
   if (!($8)) {
    $12 = $5;
    while(1) {
     $11 = HEAP32[$12>>2]|0;
     $13 = HEAP32[$11>>2]|0;
     $14 = ($13|0)==($4|0);
     $10 = (($12) + 4|0);
     if ($14) {
      $$0 = $11;
      break L1;
     }
     $9 = ($10|0)==($7|0);
     if ($9) {
      break;
     } else {
      $12 = $10;
     }
    }
   }
   $15 = (($1) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $18 = HEAP32[$16>>2]|0;
    $19 = ($18|0)==($4|0);
    if ($19) {
     $$0 = $16;
     break;
    }
   }
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5IMGUI14GUIWindowStateD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 L1: do {
  if ($3) {
   label = 7;
  } else {
   $35 = $2;$5 = $0;
   while(1) {
    $4 = HEAP32[$5>>2]|0;
    $6 = ($4|0)==(0|0);
    if ($6) {
     $11 = $35;
    } else {
     __THREW__ = 0;
     invoke_vi(3508,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __ZdlPv($4);
     $$pre = HEAP32[$1>>2]|0;
     $11 = $$pre;
    }
    $9 = (($5) + 4|0);
    $10 = ($9|0)==($11|0);
    if ($10) {
     label = 7;
     break L1;
    } else {
     $35 = $11;$5 = $9;
    }
   }
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   __ZdlPv($4);
   $$0 = $13;$$01 = $12;
  }
 } while(0);
 L9: do {
  if ((label|0) == 7) {
   $14 = (($this) + 24|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   do {
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(3508,($15|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      $19 = ___cxa_find_matching_catch()|0;
      $20 = tempRet0;
      __ZdlPv($15);
      $$0 = $20;$$01 = $19;
      break L9;
     } else {
      __ZdlPv($15);
      HEAP32[$14>>2] = 0;
      break;
     }
    }
   } while(0);
   $21 = HEAP32[$this>>2]|0;
   $22 = ($21|0)==(0|0);
   if ($22) {
    STACKTOP = sp;return;
   }
   $23 = HEAP32[$1>>2]|0;
   $24 = ($23|0)==($21|0);
   if (!($24)) {
    $__new_last2$i$i$i$i$i2 = $21;
    $scevgep$i$i$i$i$i3 = (($23) + -4|0);
    $25 = (0 - ($__new_last2$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($25)|0);
    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
    $26 = $uglygep3$i$i$i$i$i6 >>> 2;
    $27 = $26 ^ -1;
    $scevgep4$i$i$i$i$i7 = (($23) + ($27<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i7;
   }
   __ZdlPv($21);
   STACKTOP = sp;return;
  }
 } while(0);
 $28 = HEAP32[$this>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $30 = HEAP32[$1>>2]|0;
 $31 = ($30|0)==($28|0);
 if (!($31)) {
  $__new_last2$i$i$i$i$i = $28;
  $scevgep$i$i$i$i$i = (($30) + -4|0);
  $32 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($32)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $33 = $uglygep3$i$i$i$i$i >>> 2;
  $34 = $33 ^ -1;
  $scevgep4$i$i$i$i$i = (($30) + ($34<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($28);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN5IMGUIL14SortTwoWindowsEPKNS_9GUIWindowES2_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($b) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5IMGUI20MoveWindowFromLayoutER8GUIStateiRK5RectTIfE($state,$windowID,$rect) {
 $state = $state|0;
 $windowID = $windowID|0;
 $rect = $rect|0;
 var $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($1) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 L1: do {
  if ($5) {
   label = 4;
  } else {
   $9 = $2;
   while(1) {
    $8 = HEAP32[$9>>2]|0;
    $10 = HEAP32[$8>>2]|0;
    $11 = ($10|0)==($windowID|0);
    $7 = (($9) + 4|0);
    if ($11) {
     break;
    }
    $6 = ($7|0)==($4|0);
    if ($6) {
     label = 4;
     break L1;
    } else {
     $9 = $7;
    }
   }
   $17 = ($8|0)==(0|0);
   if ($17) {
    STACKTOP = sp;return;
   } else {
    $$0$i2 = $8;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $12 = (($1) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   STACKTOP = sp;return;
  }
  $15 = HEAP32[$13>>2]|0;
  $16 = ($15|0)==($windowID|0);
  if ($16) {
   $$0$i2 = $13;
  } else {
   STACKTOP = sp;return;
  }
 }
 $18 = (($$0$i2) + 48|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$rect>>2]);
 $21 = $19 != $20;
 if (!($21)) {
  $22 = (($$0$i2) + 52|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($rect) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = $23 != $25;
  if (!($26)) {
   $27 = (($$0$i2) + 56|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = (($rect) + 8|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = $28 != $30;
   if (!($31)) {
    $32 = (($$0$i2) + 60|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = (($rect) + 12|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = $33 != $35;
    if (!($36)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 ;HEAP32[$18+0>>2]=HEAP32[$rect+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$rect+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$rect+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$rect+12>>2]|0;
 $37 = (($$0$i2) + 97|0);
 HEAP8[$37>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5IMGUI13GetWindowRectER8GUIStatei($agg$result,$state,$windowID) {
 $agg$result = $agg$result|0;
 $state = $state|0;
 $windowID = $windowID|0;
 var $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($1) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 L1: do {
  if ($5) {
   label = 4;
  } else {
   $9 = $2;
   while(1) {
    $8 = HEAP32[$9>>2]|0;
    $10 = HEAP32[$8>>2]|0;
    $11 = ($10|0)==($windowID|0);
    $7 = (($9) + 4|0);
    if ($11) {
     break;
    }
    $6 = ($7|0)==($4|0);
    if ($6) {
     label = 4;
     break L1;
    } else {
     $9 = $7;
    }
   }
   $17 = ($8|0)==(0|0);
   if ($17) {
    label = 8;
   } else {
    $$0$i2 = $8;
    label = 7;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $12 = (($1) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   label = 8;
  } else {
   $15 = HEAP32[$13>>2]|0;
   $16 = ($15|0)==($windowID|0);
   if ($16) {
    $$0$i2 = $13;
    label = 7;
   } else {
    label = 8;
   }
  }
 }
 if ((label|0) == 7) {
  $18 = (($$0$i2) + 48|0);
  ;HEAP32[$agg$result+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$18+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__sortIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEvT0_SA_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$09 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0;
 var $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 2;
   switch ($4|0) {
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 70;
    break L1;
    break;
   }
   default: {
   }
   }
   $63 = ($3|0)<(124);
   if ($63) {
    label = 21;
    break L1;
   }
   $64 = ($3|0)>(3996);
   $65 = (($4|0) / 2)&-1;
   $66 = (($$0) + ($65<<2)|0);
   do {
    if ($64) {
     $67 = (($4|0) / 4)&-1;
     $68 = (($$0) + ($67<<2)|0);
     $$sum = (($67) + ($65))|0;
     $69 = (($$0) + ($$sum<<2)|0);
     $70 = (__ZNSt3__17__sort4IRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEjT0_SA_SA_SA_T_($$0,$68,$66,$69,$__comp)|0);
     $71 = HEAP32[$__comp>>2]|0;
     $72 = HEAP32[$1>>2]|0;
     $73 = HEAP32[$69>>2]|0;
     $74 = (FUNCTION_TABLE_iii[$71 & 4095]($72,$73)|0);
     if ($74) {
      $75 = HEAP32[$69>>2]|0;
      $76 = HEAP32[$1>>2]|0;
      HEAP32[$69>>2] = $76;
      HEAP32[$1>>2] = $75;
      $77 = HEAP32[$__comp>>2]|0;
      $78 = HEAP32[$69>>2]|0;
      $79 = HEAP32[$66>>2]|0;
      $80 = (FUNCTION_TABLE_iii[$77 & 4095]($78,$79)|0);
      if (!($80)) {
       $81 = (($70) + 1)|0;
       $__n_swaps$0 = $81;
       break;
      }
      $82 = HEAP32[$66>>2]|0;
      $83 = HEAP32[$69>>2]|0;
      HEAP32[$66>>2] = $83;
      HEAP32[$69>>2] = $82;
      $84 = HEAP32[$__comp>>2]|0;
      $85 = HEAP32[$66>>2]|0;
      $86 = HEAP32[$68>>2]|0;
      $87 = (FUNCTION_TABLE_iii[$84 & 4095]($85,$86)|0);
      if (!($87)) {
       $88 = (($70) + 2)|0;
       $__n_swaps$0 = $88;
       break;
      }
      $89 = HEAP32[$68>>2]|0;
      $90 = HEAP32[$66>>2]|0;
      HEAP32[$68>>2] = $90;
      HEAP32[$66>>2] = $89;
      $91 = HEAP32[$__comp>>2]|0;
      $92 = HEAP32[$68>>2]|0;
      $93 = HEAP32[$$0>>2]|0;
      $94 = (FUNCTION_TABLE_iii[$91 & 4095]($92,$93)|0);
      if ($94) {
       $96 = HEAP32[$$0>>2]|0;
       $97 = HEAP32[$68>>2]|0;
       HEAP32[$$0>>2] = $97;
       HEAP32[$68>>2] = $96;
       $98 = (($70) + 4)|0;
       $__n_swaps$0 = $98;
       break;
      } else {
       $95 = (($70) + 3)|0;
       $__n_swaps$0 = $95;
       break;
      }
     } else {
      $__n_swaps$0 = $70;
     }
    } else {
     $99 = HEAP32[$__comp>>2]|0;
     $100 = HEAP32[$66>>2]|0;
     $101 = HEAP32[$$0>>2]|0;
     $102 = (FUNCTION_TABLE_iii[$99 & 4095]($100,$101)|0);
     $103 = HEAP32[$__comp>>2]|0;
     $104 = HEAP32[$1>>2]|0;
     $105 = HEAP32[$66>>2]|0;
     $106 = (FUNCTION_TABLE_iii[$103 & 4095]($104,$105)|0);
     if (!($102)) {
      if (!($106)) {
       $__n_swaps$0 = 0;
       break;
      }
      $107 = HEAP32[$66>>2]|0;
      $108 = HEAP32[$1>>2]|0;
      HEAP32[$66>>2] = $108;
      HEAP32[$1>>2] = $107;
      $109 = HEAP32[$__comp>>2]|0;
      $110 = HEAP32[$66>>2]|0;
      $111 = HEAP32[$$0>>2]|0;
      $112 = (FUNCTION_TABLE_iii[$109 & 4095]($110,$111)|0);
      if (!($112)) {
       $__n_swaps$0 = 1;
       break;
      }
      $113 = HEAP32[$$0>>2]|0;
      $114 = HEAP32[$66>>2]|0;
      HEAP32[$$0>>2] = $114;
      HEAP32[$66>>2] = $113;
      $__n_swaps$0 = 2;
      break;
     }
     $115 = HEAP32[$$0>>2]|0;
     if ($106) {
      $116 = HEAP32[$1>>2]|0;
      HEAP32[$$0>>2] = $116;
      HEAP32[$1>>2] = $115;
      $__n_swaps$0 = 1;
      break;
     }
     $117 = HEAP32[$66>>2]|0;
     HEAP32[$$0>>2] = $117;
     HEAP32[$66>>2] = $115;
     $118 = HEAP32[$__comp>>2]|0;
     $119 = HEAP32[$1>>2]|0;
     $120 = (FUNCTION_TABLE_iii[$118 & 4095]($119,$115)|0);
     if ($120) {
      $121 = HEAP32[$66>>2]|0;
      $122 = HEAP32[$1>>2]|0;
      HEAP32[$66>>2] = $122;
      HEAP32[$1>>2] = $121;
      $__n_swaps$0 = 2;
     } else {
      $__n_swaps$0 = 1;
     }
    }
   } while(0);
   $123 = HEAP32[$__comp>>2]|0;
   $124 = HEAP32[$$0>>2]|0;
   $125 = HEAP32[$66>>2]|0;
   $126 = (FUNCTION_TABLE_iii[$123 & 4095]($124,$125)|0);
   do {
    if ($126) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $127 = (($__j$0) + -4|0);
      $128 = ($$0|0)==($127|0);
      if ($128) {
       break;
      }
      $157 = HEAP32[$__comp>>2]|0;
      $158 = HEAP32[$127>>2]|0;
      $159 = HEAP32[$66>>2]|0;
      $160 = (FUNCTION_TABLE_iii[$157 & 4095]($158,$159)|0);
      if ($160) {
       label = 53;
       break;
      } else {
       $__j$0 = $127;
      }
     }
     if ((label|0) == 53) {
      label = 0;
      $161 = HEAP32[$$0>>2]|0;
      $162 = HEAP32[$127>>2]|0;
      HEAP32[$$0>>2] = $162;
      HEAP32[$127>>2] = $161;
      $163 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $127;$__n_swaps$3 = $163;
      break;
     }
     $129 = (($$0) + 4|0);
     $130 = HEAP32[$__comp>>2]|0;
     $131 = HEAP32[$$0>>2]|0;
     $132 = HEAP32[$1>>2]|0;
     $133 = (FUNCTION_TABLE_iii[$130 & 4095]($131,$132)|0);
     if ($133) {
      $__i$1 = $129;
     } else {
      $134 = ($129|0)==($1|0);
      if ($134) {
       label = 70;
       break L1;
      } else {
       $__i$09 = $129;
      }
      while(1) {
       $137 = HEAP32[$__comp>>2]|0;
       $138 = HEAP32[$$0>>2]|0;
       $139 = HEAP32[$__i$09>>2]|0;
       $140 = (FUNCTION_TABLE_iii[$137 & 4095]($138,$139)|0);
       $136 = (($__i$09) + 4|0);
       if ($140) {
        break;
       }
       $135 = ($136|0)==($1|0);
       if ($135) {
        label = 70;
        break L1;
       } else {
        $__i$09 = $136;
       }
      }
      $141 = HEAP32[$__i$09>>2]|0;
      $142 = HEAP32[$1>>2]|0;
      HEAP32[$__i$09>>2] = $142;
      HEAP32[$1>>2] = $141;
      $__i$1 = $136;
     }
     $143 = ($__i$1|0)==($1|0);
     if ($143) {
      label = 70;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $144 = HEAP32[$__comp>>2]|0;
       $145 = HEAP32[$$0>>2]|0;
       $146 = HEAP32[$__i$2>>2]|0;
       $147 = (FUNCTION_TABLE_iii[$144 & 4095]($145,$146)|0);
       $148 = (($__i$2) + 4|0);
       if ($147) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $148;
       }
      }
      while(1) {
       $149 = HEAP32[$__comp>>2]|0;
       $150 = HEAP32[$$0>>2]|0;
       $151 = (($__j$2) + -4|0);
       $152 = HEAP32[$151>>2]|0;
       $153 = (FUNCTION_TABLE_iii[$149 & 4095]($150,$152)|0);
       if ($153) {
        $__j$2 = $151;
       } else {
        break;
       }
      }
      $154 = ($__i$2>>>0)<($151>>>0);
      if (!($154)) {
       $$0 = $__i$2;
       continue L3;
      }
      $155 = HEAP32[$__i$2>>2]|0;
      $156 = HEAP32[$151>>2]|0;
      HEAP32[$__i$2>>2] = $156;
      HEAP32[$151>>2] = $155;
      $__i$2$ph = $148;$__j$1$ph = $151;
     }
    }
   } while(0);
   $164 = (($$0) + 4|0);
   $165 = ($164>>>0)<($__j$3>>>0);
   L53: do {
    if ($165) {
     $__i$3$ph = $164;$__j$4$ph = $__j$3;$__m$0$ph = $66;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $166 = HEAP32[$__comp>>2]|0;
       $167 = HEAP32[$__i$3>>2]|0;
       $168 = HEAP32[$__m$0$ph>>2]|0;
       $169 = (FUNCTION_TABLE_iii[$166 & 4095]($167,$168)|0);
       $170 = (($__i$3) + 4|0);
       if ($169) {
        $__i$3 = $170;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $171 = HEAP32[$__comp>>2]|0;
       $172 = (($__j$5) + -4|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = HEAP32[$__m$0$ph>>2]|0;
       $175 = (FUNCTION_TABLE_iii[$171 & 4095]($173,$174)|0);
       if ($175) {
        break;
       } else {
        $__j$5 = $172;
       }
      }
      $176 = ($__i$3>>>0)>($172>>>0);
      if ($176) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L53;
      }
      $177 = HEAP32[$__i$3>>2]|0;
      $178 = HEAP32[$172>>2]|0;
      HEAP32[$__i$3>>2] = $178;
      HEAP32[$172>>2] = $177;
      $179 = (($__n_swaps$4$ph) + 1)|0;
      $180 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $180 ? $172 : $__m$0$ph;
      $__i$3$ph = $170;$__j$4$ph = $172;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $179;
     }
    } else {
     $__i$4 = $164;$__m$2 = $66;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $181 = ($__i$4|0)==($__m$2|0);
   if ($181) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $182 = HEAP32[$__comp>>2]|0;
    $183 = HEAP32[$__m$2>>2]|0;
    $184 = HEAP32[$__i$4>>2]|0;
    $185 = (FUNCTION_TABLE_iii[$182 & 4095]($183,$184)|0);
    if ($185) {
     $186 = HEAP32[$__i$4>>2]|0;
     $187 = HEAP32[$__m$2>>2]|0;
     HEAP32[$__i$4>>2] = $187;
     HEAP32[$__m$2>>2] = $186;
     $188 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $188;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $189 = ($__n_swaps$6|0)==(0);
   if ($189) {
    $190 = (__ZNSt3__127__insertion_sort_incompleteIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEbT0_SA_T_($$0,$__i$4,$__comp)|0);
    $191 = (($__i$4) + 4|0);
    $192 = (__ZNSt3__127__insertion_sort_incompleteIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEbT0_SA_T_($191,$$01$ph,$__comp)|0);
    if ($192) {
     label = 65;
     break;
    }
    if ($190) {
     $$0 = $191;
     continue;
    }
   }
   $193 = $__i$4;
   $194 = (($193) - ($2))|0;
   $195 = (($0) - ($193))|0;
   $196 = ($194|0)<($195|0);
   if (!($196)) {
    label = 69;
    break;
   }
   __ZNSt3__16__sortIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEvT0_SA_T_($$0,$__i$4,$__comp);
   $197 = (($__i$4) + 4|0);
   $$0 = $197;
  }
  if ((label|0) == 65) {
   label = 0;
   if ($190) {
    label = 70;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 69) {
   label = 0;
   $198 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEvT0_SA_T_($198,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$__comp>>2]|0;
  $6 = HEAP32[$1>>2]|0;
  $7 = HEAP32[$$0>>2]|0;
  $8 = (FUNCTION_TABLE_iii[$5 & 4095]($6,$7)|0);
  if (!($8)) {
   STACKTOP = sp;return;
  }
  $9 = HEAP32[$$0>>2]|0;
  $10 = HEAP32[$1>>2]|0;
  HEAP32[$$0>>2] = $10;
  HEAP32[$1>>2] = $9;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $11 = (($$0) + 4|0);
  $12 = HEAP32[$__comp>>2]|0;
  $13 = HEAP32[$11>>2]|0;
  $14 = HEAP32[$$0>>2]|0;
  $15 = (FUNCTION_TABLE_iii[$12 & 4095]($13,$14)|0);
  $16 = HEAP32[$__comp>>2]|0;
  $17 = HEAP32[$1>>2]|0;
  $18 = HEAP32[$11>>2]|0;
  $19 = (FUNCTION_TABLE_iii[$16 & 4095]($17,$18)|0);
  if (!($15)) {
   if (!($19)) {
    STACKTOP = sp;return;
   }
   $20 = HEAP32[$11>>2]|0;
   $21 = HEAP32[$1>>2]|0;
   HEAP32[$11>>2] = $21;
   HEAP32[$1>>2] = $20;
   $22 = HEAP32[$__comp>>2]|0;
   $23 = HEAP32[$11>>2]|0;
   $24 = HEAP32[$$0>>2]|0;
   $25 = (FUNCTION_TABLE_iii[$22 & 4095]($23,$24)|0);
   if (!($25)) {
    STACKTOP = sp;return;
   }
   $26 = HEAP32[$$0>>2]|0;
   $27 = HEAP32[$11>>2]|0;
   HEAP32[$$0>>2] = $27;
   HEAP32[$11>>2] = $26;
   STACKTOP = sp;return;
  }
  $28 = HEAP32[$$0>>2]|0;
  if ($19) {
   $29 = HEAP32[$1>>2]|0;
   HEAP32[$$0>>2] = $29;
   HEAP32[$1>>2] = $28;
   STACKTOP = sp;return;
  }
  $30 = HEAP32[$11>>2]|0;
  HEAP32[$$0>>2] = $30;
  HEAP32[$11>>2] = $28;
  $31 = HEAP32[$__comp>>2]|0;
  $32 = HEAP32[$1>>2]|0;
  $33 = (FUNCTION_TABLE_iii[$31 & 4095]($32,$28)|0);
  if (!($33)) {
   STACKTOP = sp;return;
  }
  $34 = HEAP32[$11>>2]|0;
  $35 = HEAP32[$1>>2]|0;
  HEAP32[$11>>2] = $35;
  HEAP32[$1>>2] = $34;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $36 = (($$0) + 4|0);
  $37 = (($$0) + 8|0);
  (__ZNSt3__17__sort4IRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEjT0_SA_SA_SA_T_($$0,$36,$37,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $38 = (($$0) + 4|0);
  $39 = (($$0) + 8|0);
  $40 = (($$0) + 12|0);
  (__ZNSt3__17__sort4IRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEjT0_SA_SA_SA_T_($$0,$38,$39,$40,$__comp)|0);
  $41 = HEAP32[$__comp>>2]|0;
  $42 = HEAP32[$1>>2]|0;
  $43 = HEAP32[$40>>2]|0;
  $44 = (FUNCTION_TABLE_iii[$41 & 4095]($42,$43)|0);
  if (!($44)) {
   STACKTOP = sp;return;
  }
  $45 = HEAP32[$40>>2]|0;
  $46 = HEAP32[$1>>2]|0;
  HEAP32[$40>>2] = $46;
  HEAP32[$1>>2] = $45;
  $47 = HEAP32[$__comp>>2]|0;
  $48 = HEAP32[$40>>2]|0;
  $49 = HEAP32[$39>>2]|0;
  $50 = (FUNCTION_TABLE_iii[$47 & 4095]($48,$49)|0);
  if (!($50)) {
   STACKTOP = sp;return;
  }
  $51 = HEAP32[$39>>2]|0;
  $52 = HEAP32[$40>>2]|0;
  HEAP32[$39>>2] = $52;
  HEAP32[$40>>2] = $51;
  $53 = HEAP32[$__comp>>2]|0;
  $54 = HEAP32[$38>>2]|0;
  $55 = (FUNCTION_TABLE_iii[$53 & 4095]($52,$54)|0);
  if (!($55)) {
   STACKTOP = sp;return;
  }
  $56 = HEAP32[$38>>2]|0;
  $57 = HEAP32[$39>>2]|0;
  HEAP32[$38>>2] = $57;
  HEAP32[$39>>2] = $56;
  $58 = HEAP32[$__comp>>2]|0;
  $59 = HEAP32[$$0>>2]|0;
  $60 = (FUNCTION_TABLE_iii[$58 & 4095]($57,$59)|0);
  if (!($60)) {
   STACKTOP = sp;return;
  }
  $61 = HEAP32[$$0>>2]|0;
  $62 = HEAP32[$38>>2]|0;
  HEAP32[$$0>>2] = $62;
  HEAP32[$38>>2] = $61;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEvT0_SA_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 70) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEjT0_SA_SA_SA_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__c>>2]|0;
 $1 = HEAP32[$__x2>>2]|0;
 $2 = HEAP32[$__x1>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$0 & 4095]($1,$2)|0);
 $4 = HEAP32[$__c>>2]|0;
 $5 = HEAP32[$__x3>>2]|0;
 $6 = HEAP32[$__x2>>2]|0;
 $7 = (FUNCTION_TABLE_iii[$4 & 4095]($5,$6)|0);
 do {
  if ($3) {
   $16 = HEAP32[$__x1>>2]|0;
   if ($7) {
    $17 = HEAP32[$__x3>>2]|0;
    HEAP32[$__x1>>2] = $17;
    HEAP32[$__x3>>2] = $16;
    $$0$i = 1;
    break;
   }
   $18 = HEAP32[$__x2>>2]|0;
   HEAP32[$__x1>>2] = $18;
   HEAP32[$__x2>>2] = $16;
   $19 = HEAP32[$__c>>2]|0;
   $20 = HEAP32[$__x3>>2]|0;
   $21 = (FUNCTION_TABLE_iii[$19 & 4095]($20,$16)|0);
   if ($21) {
    $22 = HEAP32[$__x2>>2]|0;
    $23 = HEAP32[$__x3>>2]|0;
    HEAP32[$__x2>>2] = $23;
    HEAP32[$__x3>>2] = $22;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($7) {
    $8 = HEAP32[$__x2>>2]|0;
    $9 = HEAP32[$__x3>>2]|0;
    HEAP32[$__x2>>2] = $9;
    HEAP32[$__x3>>2] = $8;
    $10 = HEAP32[$__c>>2]|0;
    $11 = HEAP32[$__x2>>2]|0;
    $12 = HEAP32[$__x1>>2]|0;
    $13 = (FUNCTION_TABLE_iii[$10 & 4095]($11,$12)|0);
    if ($13) {
     $14 = HEAP32[$__x1>>2]|0;
     $15 = HEAP32[$__x2>>2]|0;
     HEAP32[$__x1>>2] = $15;
     HEAP32[$__x2>>2] = $14;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $24 = HEAP32[$__c>>2]|0;
 $25 = HEAP32[$__x4>>2]|0;
 $26 = HEAP32[$__x3>>2]|0;
 $27 = (FUNCTION_TABLE_iii[$24 & 4095]($25,$26)|0);
 if (!($27)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $28 = HEAP32[$__x3>>2]|0;
 $29 = HEAP32[$__x4>>2]|0;
 HEAP32[$__x3>>2] = $29;
 HEAP32[$__x4>>2] = $28;
 $30 = (($$0$i) + 1)|0;
 $31 = HEAP32[$__c>>2]|0;
 $32 = HEAP32[$__x3>>2]|0;
 $33 = HEAP32[$__x2>>2]|0;
 $34 = (FUNCTION_TABLE_iii[$31 & 4095]($32,$33)|0);
 if (!($34)) {
  $__r$0 = $30;
  STACKTOP = sp;return ($__r$0|0);
 }
 $35 = HEAP32[$__x2>>2]|0;
 $36 = HEAP32[$__x3>>2]|0;
 HEAP32[$__x2>>2] = $36;
 HEAP32[$__x3>>2] = $35;
 $37 = (($$0$i) + 2)|0;
 $38 = HEAP32[$__c>>2]|0;
 $39 = HEAP32[$__x2>>2]|0;
 $40 = HEAP32[$__x1>>2]|0;
 $41 = (FUNCTION_TABLE_iii[$38 & 4095]($39,$40)|0);
 if (!($41)) {
  $__r$0 = $37;
  STACKTOP = sp;return ($__r$0|0);
 }
 $42 = HEAP32[$__x1>>2]|0;
 $43 = HEAP32[$__x2>>2]|0;
 HEAP32[$__x1>>2] = $43;
 HEAP32[$__x2>>2] = $42;
 $44 = (($$0$i) + 3)|0;
 $__r$0 = $44;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEvT0_SA_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 8|0);
 $1 = (($__first) + 4|0);
 $2 = HEAP32[$__comp>>2]|0;
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$__first>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$2 & 4095]($3,$4)|0);
 $6 = HEAP32[$__comp>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$1>>2]|0;
 $9 = (FUNCTION_TABLE_iii[$6 & 4095]($7,$8)|0);
 do {
  if ($5) {
   $17 = HEAP32[$__first>>2]|0;
   if ($9) {
    $18 = HEAP32[$0>>2]|0;
    HEAP32[$__first>>2] = $18;
    HEAP32[$0>>2] = $17;
    break;
   }
   $19 = HEAP32[$1>>2]|0;
   HEAP32[$__first>>2] = $19;
   HEAP32[$1>>2] = $17;
   $20 = HEAP32[$__comp>>2]|0;
   $21 = HEAP32[$0>>2]|0;
   $22 = (FUNCTION_TABLE_iii[$20 & 4095]($21,$17)|0);
   if ($22) {
    $23 = HEAP32[$1>>2]|0;
    $24 = HEAP32[$0>>2]|0;
    HEAP32[$1>>2] = $24;
    HEAP32[$0>>2] = $23;
   }
  } else {
   if ($9) {
    $10 = HEAP32[$1>>2]|0;
    $11 = HEAP32[$0>>2]|0;
    HEAP32[$1>>2] = $11;
    HEAP32[$0>>2] = $10;
    $12 = HEAP32[$__comp>>2]|0;
    $13 = HEAP32[$__first>>2]|0;
    $14 = (FUNCTION_TABLE_iii[$12 & 4095]($11,$13)|0);
    if ($14) {
     $15 = HEAP32[$__first>>2]|0;
     $16 = HEAP32[$1>>2]|0;
     HEAP32[$__first>>2] = $16;
     HEAP32[$1>>2] = $15;
    }
   }
  }
 } while(0);
 $25 = (($__first) + 12|0);
 $26 = ($25|0)==($__last|0);
 if ($26) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $25;$__j$01 = $0;
 }
 while(1) {
  $27 = HEAP32[$__comp>>2]|0;
  $28 = HEAP32[$__i$02>>2]|0;
  $29 = HEAP32[$__j$01>>2]|0;
  $30 = (FUNCTION_TABLE_iii[$27 & 4095]($28,$29)|0);
  if ($30) {
   $31 = HEAP32[$__i$02>>2]|0;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    $32 = HEAP32[$__k$0>>2]|0;
    HEAP32[$__j$1>>2] = $32;
    $33 = ($__k$0|0)==($__first|0);
    if ($33) {
     $__k$0$lcssa = $__first;
     break;
    }
    $34 = HEAP32[$__comp>>2]|0;
    $35 = (($__k$0) + -4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (FUNCTION_TABLE_iii[$34 & 4095]($31,$36)|0);
    if ($37) {
     $__j$1$phi = $__k$0;$__k$0 = $35;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAP32[$__k$0$lcssa>>2] = $31;
  }
  $38 = (($__i$02) + 4|0);
  $39 = ($38|0)==($__last|0);
  if ($39) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $38;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEbT0_SA_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$05 = 0, $__count$1 = 0, $__i$06 = 0, $__j$04 = 0, $__j$04$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (($__last) + -4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$__first>>2]|0;
  $8 = (FUNCTION_TABLE_iii[$4 & 4095]($6,$7)|0);
  if (!($8)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $9 = HEAP32[$__first>>2]|0;
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$__first>>2] = $10;
  HEAP32[$5>>2] = $9;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $40 = (($__first) + 4|0);
  $41 = (($__first) + 8|0);
  $42 = (($__first) + 12|0);
  $43 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEjT0_SA_SA_SA_T_($__first,$40,$41,$42,$__comp)|0);
  $44 = HEAP32[$__comp>>2]|0;
  $45 = HEAP32[$43>>2]|0;
  $46 = HEAP32[$42>>2]|0;
  $47 = (FUNCTION_TABLE_iii[$44 & 4095]($45,$46)|0);
  if (!($47)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $48 = HEAP32[$42>>2]|0;
  $49 = HEAP32[$43>>2]|0;
  HEAP32[$42>>2] = $49;
  HEAP32[$43>>2] = $48;
  $50 = HEAP32[$__comp>>2]|0;
  $51 = HEAP32[$42>>2]|0;
  $52 = HEAP32[$41>>2]|0;
  $53 = (FUNCTION_TABLE_iii[$50 & 4095]($51,$52)|0);
  if (!($53)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $54 = HEAP32[$41>>2]|0;
  $55 = HEAP32[$42>>2]|0;
  HEAP32[$41>>2] = $55;
  HEAP32[$42>>2] = $54;
  $56 = HEAP32[$__comp>>2]|0;
  $57 = HEAP32[$40>>2]|0;
  $58 = (FUNCTION_TABLE_iii[$56 & 4095]($55,$57)|0);
  if (!($58)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $59 = HEAP32[$40>>2]|0;
  $60 = HEAP32[$41>>2]|0;
  HEAP32[$40>>2] = $60;
  HEAP32[$41>>2] = $59;
  $61 = HEAP32[$__comp>>2]|0;
  $62 = HEAP32[$__first>>2]|0;
  $63 = (FUNCTION_TABLE_iii[$61 & 4095]($60,$62)|0);
  if (!($63)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $64 = HEAP32[$__first>>2]|0;
  $65 = HEAP32[$40>>2]|0;
  HEAP32[$__first>>2] = $65;
  HEAP32[$40>>2] = $64;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $37 = (($__first) + 4|0);
  $38 = (($__first) + 8|0);
  $39 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IRPFbPKN5IMGUI9GUIWindowES4_EPPS2_EEjT0_SA_SA_SA_T_($__first,$37,$38,$39,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $11 = (($__first) + 4|0);
  $12 = (($__last) + -4|0);
  $13 = HEAP32[$__comp>>2]|0;
  $14 = HEAP32[$11>>2]|0;
  $15 = HEAP32[$__first>>2]|0;
  $16 = (FUNCTION_TABLE_iii[$13 & 4095]($14,$15)|0);
  $17 = HEAP32[$__comp>>2]|0;
  $18 = HEAP32[$12>>2]|0;
  $19 = HEAP32[$11>>2]|0;
  $20 = (FUNCTION_TABLE_iii[$17 & 4095]($18,$19)|0);
  if (!($16)) {
   if (!($20)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $21 = HEAP32[$11>>2]|0;
   $22 = HEAP32[$12>>2]|0;
   HEAP32[$11>>2] = $22;
   HEAP32[$12>>2] = $21;
   $23 = HEAP32[$__comp>>2]|0;
   $24 = HEAP32[$11>>2]|0;
   $25 = HEAP32[$__first>>2]|0;
   $26 = (FUNCTION_TABLE_iii[$23 & 4095]($24,$25)|0);
   if (!($26)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $27 = HEAP32[$__first>>2]|0;
   $28 = HEAP32[$11>>2]|0;
   HEAP32[$__first>>2] = $28;
   HEAP32[$11>>2] = $27;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $29 = HEAP32[$__first>>2]|0;
  if ($20) {
   $30 = HEAP32[$12>>2]|0;
   HEAP32[$__first>>2] = $30;
   HEAP32[$12>>2] = $29;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $31 = HEAP32[$11>>2]|0;
  HEAP32[$__first>>2] = $31;
  HEAP32[$11>>2] = $29;
  $32 = HEAP32[$__comp>>2]|0;
  $33 = HEAP32[$12>>2]|0;
  $34 = (FUNCTION_TABLE_iii[$32 & 4095]($33,$29)|0);
  if (!($34)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $35 = HEAP32[$11>>2]|0;
  $36 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $36;
  HEAP32[$12>>2] = $35;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $66 = (($__first) + 8|0);
  $67 = (($__first) + 4|0);
  $68 = HEAP32[$__comp>>2]|0;
  $69 = HEAP32[$67>>2]|0;
  $70 = HEAP32[$__first>>2]|0;
  $71 = (FUNCTION_TABLE_iii[$68 & 4095]($69,$70)|0);
  $72 = HEAP32[$__comp>>2]|0;
  $73 = HEAP32[$66>>2]|0;
  $74 = HEAP32[$67>>2]|0;
  $75 = (FUNCTION_TABLE_iii[$72 & 4095]($73,$74)|0);
  do {
   if ($71) {
    $83 = HEAP32[$__first>>2]|0;
    if ($75) {
     $84 = HEAP32[$66>>2]|0;
     HEAP32[$__first>>2] = $84;
     HEAP32[$66>>2] = $83;
     break;
    }
    $85 = HEAP32[$67>>2]|0;
    HEAP32[$__first>>2] = $85;
    HEAP32[$67>>2] = $83;
    $86 = HEAP32[$__comp>>2]|0;
    $87 = HEAP32[$66>>2]|0;
    $88 = (FUNCTION_TABLE_iii[$86 & 4095]($87,$83)|0);
    if ($88) {
     $89 = HEAP32[$67>>2]|0;
     $90 = HEAP32[$66>>2]|0;
     HEAP32[$67>>2] = $90;
     HEAP32[$66>>2] = $89;
    }
   } else {
    if ($75) {
     $76 = HEAP32[$67>>2]|0;
     $77 = HEAP32[$66>>2]|0;
     HEAP32[$67>>2] = $77;
     HEAP32[$66>>2] = $76;
     $78 = HEAP32[$__comp>>2]|0;
     $79 = HEAP32[$__first>>2]|0;
     $80 = (FUNCTION_TABLE_iii[$78 & 4095]($77,$79)|0);
     if ($80) {
      $81 = HEAP32[$__first>>2]|0;
      $82 = HEAP32[$67>>2]|0;
      HEAP32[$__first>>2] = $82;
      HEAP32[$67>>2] = $81;
     }
    }
   }
  } while(0);
  $91 = (($__first) + 12|0);
  $92 = ($91|0)==($__last|0);
  if ($92) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$05 = 0;$__i$06 = $91;$__j$04 = $66;
  }
  while(1) {
   $93 = HEAP32[$__comp>>2]|0;
   $94 = HEAP32[$__i$06>>2]|0;
   $95 = HEAP32[$__j$04>>2]|0;
   $96 = (FUNCTION_TABLE_iii[$93 & 4095]($94,$95)|0);
   if ($96) {
    $97 = HEAP32[$__i$06>>2]|0;
    $__j$1 = $__i$06;$__k$0 = $__j$04;
    while(1) {
     $98 = HEAP32[$__k$0>>2]|0;
     HEAP32[$__j$1>>2] = $98;
     $99 = ($__k$0|0)==($__first|0);
     if ($99) {
      $__k$0$lcssa = $__first;
      break;
     }
     $100 = HEAP32[$__comp>>2]|0;
     $101 = (($__k$0) + -4|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = (FUNCTION_TABLE_iii[$100 & 4095]($97,$102)|0);
     if ($103) {
      $__j$1$phi = $__k$0;$__k$0 = $101;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $97;
    $104 = (($__count$05) + 1)|0;
    $105 = ($104|0)==(8);
    if ($105) {
     break;
    } else {
     $__count$1 = $104;
    }
   } else {
    $__count$1 = $__count$05;
   }
   $108 = (($__i$06) + 4|0);
   $109 = ($108|0)==($__last|0);
   if ($109) {
    $$0 = 1;
    label = 34;
    break;
   } else {
    $__j$04$phi = $__i$06;$__count$05 = $__count$1;$__i$06 = $108;$__j$04 = $__j$04$phi;
   }
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  $106 = (($__i$06) + 4|0);
  $107 = ($106|0)==($__last|0);
  $$0 = $107;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN6IDListC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 32|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 36|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 28|0);
 HEAP32[$3>>2] = 61;
 $4 = (($this) + 40|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6IDList10BeginOnGUIEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 4|0);
 $2 = (($this) + 20|0);
 ;HEAP32[$1+0>>2]=4294967295|0;HEAP32[$1+4>>2]=4294967295|0;HEAP32[$1+8>>2]=4294967295|0;HEAP32[$1+12>>2]=4294967295|0;
 HEAP8[$2>>0] = 0;
 HEAP32[$this>>2] = 1;
 STACKTOP = sp;return;
}
function __ZN5IMGUI12GetEventTypeERK8GUIStateRK10InputEvent($state,$event) {
 $state = $state|0;
 $event = $event|0;
 var $$ = 0, $$0 = 0, $$off = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$event>>2]|0;
 $1 = (($state) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $$off = (($0) + -7)|0;
   $4 = ($$off>>>0)<(2);
   $5 = ($0|0)==(12);
   $or$cond3 = $4 | $5;
   $$ = $or$cond3 ? $0 : 11;
   $$0 = $$;
  } else {
   $6 = (($state) + 268|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if ($8) {
    switch ($0|0) {
    case 0: case 1: case 9: case 10: case 16:  {
     $$0 = 11;
     break L1;
     break;
    }
    default: {
    }
    }
    $$0 = $0;
   } else {
    $$0 = $0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5IMGUI12GetGeneratorERK5RectTIfERK10GUIContentPN13TextRendering4FontE10TextAnchorbb11ColorRGBA32ii13ImagePosition($contentRect,$content,$font,$alignment,$wordWrap,$richText,$color,$fontSize,$fontStyle,$imagePosition) {
 $contentRect = $contentRect|0;
 $content = $content|0;
 $font = $font|0;
 $alignment = $alignment|0;
 $wordWrap = $wordWrap|0;
 $richText = $richText|0;
 $color = $color|0;
 $fontSize = $fontSize|0;
 $fontStyle = $fontStyle|0;
 $imagePosition = $imagePosition|0;
 var $$$i = Math_fround(0), $$0 = 0, $$0$i = 0, $$0$i3 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var $floorf$i$i = Math_fround(0), $temp$0$i = 0, $textWidth$0 = Math_fround(0), $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast1$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (__ZN13TextRendering17GetITextRenderingEv()|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($wordWrap)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$color>>2]|0;
  HEAP32[$1>>2] = $7;
  ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  $8 = (FUNCTION_TABLE_iiiiiifffiiiii[$6 & 1]($3,$content,$font,$alignment,3,Math_fround(0.0),Math_fround(16.0),Math_fround(1.0),$richText,1,$tmpcast1$byval_copy,$fontSize,$fontStyle)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($content) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $10;
  $12 = HEAP32[560624>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 13;
  } else {
   $14 = (($12) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($12) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($15|0)==($17|0);
   do {
    if ($18) {
     $19 = (($12) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($12) + 32|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + ($22<<3)|0);
     $39 = $23;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast1$byval_copy,$12,$0);
     $24 = HEAP32[$tmpcast1$byval_copy>>2]|0;
     $25 = ($24|0)==(-1);
     $26 = (($12) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     if ($25) {
      $28 = (($12) + 32|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($27) + ($29<<3)|0);
      $39 = $30;
      break;
     } else {
      $31 = (($27) + ($24<<3)|0);
      $39 = $31;
      break;
     }
    }
   } while(0);
   $32 = HEAP32[560624>>2]|0;
   $33 = (($32) + 28|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + 32|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + ($36<<3)|0);
   $38 = ($39|0)==($37|0);
   if ($38) {
    label = 13;
   } else {
    $40 = (($39) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     label = 13;
    } else {
     $temp$0$i = $41;
    }
   }
  }
  if ((label|0) == 13) {
   $43 = HEAP32[$9>>2]|0;
   $44 = (__Z31ReadObjectFromPersistentManageri($43)|0);
   $temp$0$i = $44;
  }
  $$0$i = $temp$0$i;
 }
 $45 = (($contentRect) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 if ((($imagePosition|0) == 2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($imagePosition|0) == 0)) {
  label = 16;
 } else {
  $textWidth$0 = $46;
 }
 do {
  if ((label|0) == 16) {
   $47 = ($$0$i|0)==(0|0);
   if ($47) {
    $textWidth$0 = $46;
   } else {
    $48 = HEAP32[$$0$i>>2]|0;
    $49 = (($48) + 104|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (FUNCTION_TABLE_ii[$50 & 4095]($$0$i)|0);
    $52 = (Math_fround(($51|0)));
    $53 = HEAP32[$$0$i>>2]|0;
    $54 = (($53) + 108|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (FUNCTION_TABLE_ii[$55 & 4095]($$0$i)|0);
    $57 = Math_fround(0.0) == Math_fround(0.0);
    if (!($57)) {
     $71 = Math_fround($46 - Math_fround(0.0));
     $textWidth$0 = $71;
     break;
    }
    $58 = (Math_fround(($56|0)));
    $59 = Math_fround(HEAPF32[$45>>2]);
    $60 = Math_fround($59 / $52);
    $61 = (($contentRect) + 12|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = Math_fround($62 / $58);
    $64 = $63 < $60;
    $65 = $64 ? $63 : $60;
    $66 = $65 < Math_fround(0.0);
    if ($66) {
     $$0$i3 = Math_fround(0.0);
    } else {
     $67 = $65 > Math_fround(1.0);
     $$$i = $67 ? Math_fround(1.0) : $65;
     $$0$i3 = $$$i;
    }
    $68 = Math_fround($52 * $$0$i3);
    $69 = Math_fround($68 + Math_fround(0.5));
    $floorf$i$i = (Math_fround(Math_floor((Math_fround($69)))));
    $70 = Math_fround($46 - $floorf$i$i);
    $textWidth$0 = $70;
   }
  }
 } while(0);
 $72 = HEAP32[$3>>2]|0;
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$color>>2]|0;
 HEAP32[$2>>2] = $74;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
 $75 = (FUNCTION_TABLE_iiiiiifffiiiii[$73 & 1]($3,$content,$font,$alignment,3,$textWidth$0,Math_fround(16.0),Math_fround(1.0),$richText,1,$tmpcast1$byval_copy,$fontSize,$fontStyle)|0);
 $$0 = $75;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11UTF16StringC2EPKc($this,$str) {
 $this = $this|0;
 $str = $str|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (_strlen(($str|0))|0);
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$this>>2] = 0;
  $8 = (($this) + 4|0);
  HEAP32[$8>>2] = 0;
  $9 = (($this) + 8|0);
  HEAP8[$9>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $3 = $1 << 1;
  $4 = HEAP32[628464>>2]|0;
  HEAP32[$0>>2] = $4;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $5 = (__Z15malloc_internaljj10MemLabelIdiPKci($3,16,$$byval_copy,0,612528,26)|0);
  HEAP32[$this>>2] = $5;
  $6 = (($this) + 4|0);
  (__Z18ConvertUTF8toUTF16PKciPtRi($str,$1,$5,$6)|0);
  $7 = (($this) + 8|0);
  HEAP8[$7>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN11UTF16StringD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = HEAP32[628464>>2]|0;
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($4,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN11UTF16StringC2ERKS_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($other) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 $4 = (($this) + 4|0);
 if ($3) {
  HEAP32[$4>>2] = 0;
  HEAP32[$this>>2] = 0;
  $12 = (($this) + 8|0);
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 } else {
  HEAP32[$4>>2] = $2;
  $5 = $2 << 1;
  $6 = HEAP32[628464>>2]|0;
  HEAP32[$0>>2] = $6;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $7 = (__Z15malloc_internaljj10MemLabelIdiPKci($5,16,$$byval_copy,0,612528,128)|0);
  HEAP32[$this>>2] = $7;
  $8 = HEAP32[$other>>2]|0;
  $9 = HEAP32[$4>>2]|0;
  $10 = $9 << 1;
  _memcpy(($7|0),($8|0),($10|0))|0;
  $11 = (($this) + 8|0);
  HEAP8[$11>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIcNS_9allocatorIcEEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  $$0$i = $__n;$9 = $3;
  while(1) {
   $8 = ($9|0)==(0|0);
   if ($8) {
    $11 = 0;
   } else {
    HEAP8[$9>>0] = 0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $11 = $$pre1$i;
   }
   $10 = (($11) + 1|0);
   HEAP32[$2>>2] = $10;
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$9 = $10;
   }
  }
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = (($16) + ($__n))|0;
 $18 = ($17|0)<(0);
 if ($18) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $19 = (($4) - ($15))|0;
 $20 = ($19>>>0)<(1073741823);
 if ($20) {
  $21 = $19 << 1;
  $22 = ($21>>>0)<($17>>>0);
  $23 = $22 ? $17 : $21;
  $24 = ($23|0)==(0);
  if ($24) {
   $$0$i57 = 0;$27 = 0;
  } else {
   $$0$i56 = $23;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $25 = (__Znwj($$0$i56)|0);
  $$0$i57 = $$0$i56;$27 = $25;
 }
 $26 = (($27) + ($16)|0);
 $$0$i2 = $__n;$29 = $26;
 while(1) {
  $28 = ($29|0)==(0|0);
  if ($28) {
   $31 = 0;
  } else {
   HEAP8[$29>>0] = 0;
   $31 = $29;
  }
  $30 = (($31) + 1|0);
  $32 = (($$0$i2) + -1)|0;
  $33 = ($32|0)==(0);
  if ($33) {
   break;
  } else {
   $$0$i2 = $32;$29 = $30;
  }
 }
 $34 = (($27) + ($$0$i57)|0);
 $35 = HEAP32[$this>>2]|0;
 $36 = HEAP32[$2>>2]|0;
 $37 = $36;
 $38 = $35;
 $39 = (($37) - ($38))|0;
 $$sum = (($16) - ($39))|0;
 $40 = (($27) + ($$sum)|0);
 _memcpy(($40|0),($35|0),($39|0))|0;
 HEAP32[$this>>2] = $40;
 HEAP32[$2>>2] = $30;
 HEAP32[$0>>2] = $34;
 $41 = ($35|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 __ZdlPv($35);
 STACKTOP = sp;return;
}
function __ZN15GUIEventManager10QueueEventERK10InputEvent($this,$event) {
 $this = $this|0;
 $event = $event|0;
 var $$neg2$i$i = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2$i = 0, $$pre3$i = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$event>>2]|0;
 if ((($0|0) == 16) | (($0|0) == 11)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $16 = 0;
 } else {
  $10 = ($8*93)|0;
  $11 = (($10) + -1)|0;
  $16 = $11;
 }
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $$neg2$i$i = (($16) - ($13))|0;
 $17 = ($$neg2$i$i|0)==($15|0);
 if ($17) {
  __ZNSt3__15dequeI10InputEventNS_9allocatorIS1_EEE19__add_back_capacityEv($this);
  $$pre$i = HEAP32[$14>>2]|0;
  $$pre1$i = HEAP32[$12>>2]|0;
  $$pre2$i = HEAP32[$3>>2]|0;
  $$pre3$i = HEAP32[$1>>2]|0;
  $19 = $$pre$i;$20 = $$pre1$i;$22 = $$pre3$i;$23 = $$pre2$i;
 } else {
  $19 = $15;$20 = $13;$22 = $2;$23 = $4;
 }
 $18 = (($19) + ($20))|0;
 $21 = ($22|0)==($23|0);
 if ($21) {
  $31 = $19;
 } else {
  $24 = (($18>>>0) / 93)&-1;
  $25 = (($23) + ($24<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($18>>>0) % 93)&-1;
  $28 = (($26) + (($27*44)|0)|0);
  $29 = ($28|0)==(0|0);
  if ($29) {
   $31 = $19;
  } else {
   __ZN10InputEventC2ERKS_($28,$event);
   $$pre4$i = HEAP32[$14>>2]|0;
   $31 = $$pre4$i;
  }
 }
 $30 = (($31) + 1)|0;
 HEAP32[$14>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN15GUIEventManager11ClearEventsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112__deque_baseI10InputEventNS_9allocatorIS1_EEE5clearEv($this);
 STACKTOP = sp;return;
}
function __ZNK15GUIEventManager13GetEventCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK15GUIEventManager15GetEventAtIndexEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index))|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2>>>0) / 93)&-1;
 $6 = (($4) + ($5<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($2>>>0) % 93)&-1;
 $9 = (($7) + (($8*44)|0)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN15GUIEventManager18RemoveEventAtIndexEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$byval_copy = 0, $$off32 = 0, $$sum = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5>>>0) / 93)&-1;
 $7 = (($3) + ($6<<2)|0);
 $8 = (($this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($3|0);
 if ($10) {
  $$off32 = 0;
 } else {
  $11 = HEAP32[$7>>2]|0;
  $12 = (($5>>>0) % 93)&-1;
  $13 = (($11) + (($12*44)|0)|0);
  $phitmp = $13;
  $$off32 = $phitmp;
 }
 $14 = $$off32;
 $15 = ($index|0)==(0);
 do {
  if ($15) {
   $34 = $7;$36 = $14;
  } else {
   $16 = HEAP32[$7>>2]|0;
   $17 = $16;
   $18 = (($$off32) - ($17))|0;
   $19 = (($18|0) / 44)&-1;
   $20 = (($19) + ($index))|0;
   $21 = ($20|0)>(0);
   if ($21) {
    $22 = (($20|0) / 93)&-1;
    $$sum3 = (($22) + ($6))|0;
    $23 = (($3) + ($$sum3<<2)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($20|0) % 93)&-1;
    $26 = (($24) + (($25*44)|0)|0);
    $34 = $23;$36 = $26;
    break;
   } else {
    $27 = (92 - ($20))|0;
    $28 = (($27|0) / -93)&-1;
    $$sum = (($28) + ($6))|0;
    $29 = (($3) + ($$sum<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($27|0) % 93)&-1;
    $32 = (92 - ($31))|0;
    $33 = (($30) + (($32*44)|0)|0);
    $34 = $29;$36 = $33;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = $34;
 $35 = (($0) + 4|0);
 HEAP32[$35>>2] = $36;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZNSt3__15dequeI10InputEventNS_9allocatorIS1_EEE5eraseENS_16__deque_iteratorIS1_PKS1_RS6_PKS7_iLi93EEE($1,$this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZNSt3__15dequeI10InputEventNS_9allocatorIS1_EEE5eraseENS_16__deque_iteratorIS1_PKS1_RS6_PKS7_iLi93EEE($agg$result,$this,$__f) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__f = $__f|0;
 var $$0$i27 = 0, $$byval_copy = 0, $$neg$i = 0, $$neg2$i = 0, $$pre = 0, $$pre24 = 0, $$pre25 = 0, $$sum = 0, $$sum19 = 0, $$sum20 = 0, $$sum22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i = 0, $__new_last2$i$i$i = 0, $phitmp = 0, $scevgep4$i$i$i = 0, $tmpcast$byval_copy = 0, $tmpcast2$byval_copy = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmpcast2$byval_copy = sp + 72|0;
 $$byval_copy = sp + 56|0;
 $tmpcast$byval_copy = sp + 80|0;
 $0 = sp + 16|0;
 $1 = sp + 24|0;
 $2 = sp + 8|0;
 $3 = sp + 40|0;
 $__i = sp + 48|0;
 $4 = sp;
 $5 = sp + 64|0;
 $6 = sp + 32|0;
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10>>>0) / 93)&-1;
 $12 = (($8) + ($11<<2)|0);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==($8|0);
 if ($15) {
  $22 = 0;
 } else {
  $16 = HEAP32[$12>>2]|0;
  $17 = (($10>>>0) % 93)&-1;
  $18 = (($16) + (($17*44)|0)|0);
  $22 = $18;
 }
 $19 = (($__f) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==($22|0);
 do {
  if ($21) {
   $$pre24 = $12;
   $$pre25 = $22;
   $$0$i27 = 0;$215 = 1;$66 = $$pre24;$69 = $$pre25;$71 = $12;$73 = $22;
  } else {
   $23 = HEAP32[$__f>>2]|0;
   $24 = $23;
   $25 = $12;
   $26 = (($24) - ($25))|0;
   $27 = $26 >> 2;
   $28 = ($27*93)|0;
   $29 = HEAP32[$23>>2]|0;
   $30 = $20;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = (($32|0) / 44)&-1;
   $34 = (($28) + ($33))|0;
   $35 = HEAP32[$12>>2]|0;
   $36 = $22;
   $37 = $35;
   $38 = (($36) - ($37))|0;
   $$neg$i = (($38|0) / -44)&-1;
   $39 = (($34) + ($$neg$i))|0;
   $40 = ($39|0)==(0);
   if ($40) {
    $$0$i27 = 0;$215 = 1;$66 = $25;$69 = $36;$71 = $12;$73 = $22;
   } else {
    $41 = HEAP32[$12>>2]|0;
    $42 = $41;
    $43 = (($36) - ($42))|0;
    $44 = (($43|0) / 44)&-1;
    $45 = (($44) + ($39))|0;
    $46 = ($45|0)>(0);
    if ($46) {
     $47 = (($45|0) / 93)&-1;
     $$sum22 = (($47) + ($11))|0;
     $48 = (($8) + ($$sum22<<2)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = (($45|0) % 93)&-1;
     $51 = (($49) + (($50*44)|0)|0);
     $$0$i27 = $39;$215 = 0;$66 = $25;$69 = $36;$71 = $48;$73 = $51;
     break;
    } else {
     $52 = (92 - ($45))|0;
     $53 = (($52|0) / -93)&-1;
     $$sum = (($53) + ($11))|0;
     $54 = (($8) + ($$sum<<2)|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($52|0) % 93)&-1;
     $57 = (92 - ($56))|0;
     $58 = (($55) + (($57*44)|0)|0);
     $$0$i27 = $39;$215 = $40;$66 = $25;$69 = $36;$71 = $54;$73 = $58;
     break;
    }
   }
  }
 } while(0);
 $59 = (($this) + 20|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + -1)|0;
 $62 = $61 >>> 1;
 $63 = ($$0$i27>>>0)<($62>>>0);
 if ($63) {
  $64 = $0;
  $65 = $64;
  HEAP32[$65>>2] = $66;
  $67 = (($64) + 4)|0;
  $68 = $67;
  HEAP32[$68>>2] = $69;
  $70 = $71;
  $72 = $73;
  $74 = $1;
  $75 = $74;
  HEAP32[$75>>2] = $70;
  $76 = (($74) + 4)|0;
  $77 = $76;
  HEAP32[$77>>2] = $72;
  $78 = HEAP32[$71>>2]|0;
  $79 = $78;
  $80 = (($72) - ($79))|0;
  $81 = (($80|0) / 44)&-1;
  $82 = (($81) + 1)|0;
  $83 = ($80|0)>(-44);
  if ($83) {
   $84 = (($82|0) / 93)&-1;
   $85 = (($71) + ($84<<2)|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($82|0) % 93)&-1;
   $88 = (($86) + (($87*44)|0)|0);
   $97 = $85;$99 = $88;
  } else {
   $89 = (91 - ($81))|0;
   $90 = (($89|0) / -93)&-1;
   $91 = (($71) + ($90<<2)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($89|0) % 93)&-1;
   $94 = (92 - ($93))|0;
   $95 = (($92) + (($94*44)|0)|0);
   $97 = $91;$99 = $95;
  }
  $96 = $97;
  $98 = $99;
  $100 = $2;
  $101 = $100;
  HEAP32[$101>>2] = $96;
  $102 = (($100) + 4)|0;
  $103 = $102;
  HEAP32[$103>>2] = $98;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
  ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
  __ZNSt3__113move_backwardI10InputEventPS1_RS1_PS2_iLi93ES1_S2_S3_S4_iLi93EEENS_16__deque_iteratorIT5_T6_T7_T8_T9_XT10_EEENS5_IT_T0_T1_T2_T3_XT4_EEESH_SB_($3,$tmpcast$byval_copy,$$byval_copy,$tmpcast2$byval_copy);
  __ZN10InputEventD2Ev($22);
  $104 = HEAP32[$59>>2]|0;
  $105 = (($104) + -1)|0;
  HEAP32[$59>>2] = $105;
  $106 = HEAP32[$9>>2]|0;
  $107 = (($106) + 1)|0;
  HEAP32[$9>>2] = $107;
  $108 = ($107>>>0)>(185);
  if ($108) {
   $109 = HEAP32[$7>>2]|0;
   $110 = HEAP32[$109>>2]|0;
   __ZdlPv($110);
   $111 = HEAP32[$7>>2]|0;
   $112 = (($111) + 4|0);
   HEAP32[$7>>2] = $112;
   $113 = HEAP32[$9>>2]|0;
   $114 = (($113) + -93)|0;
   HEAP32[$9>>2] = $114;
   $181 = $114;
  } else {
   $181 = $107;
  }
 } else {
  $115 = $71;
  $116 = $73;
  $117 = HEAP32[$71>>2]|0;
  $118 = $117;
  $119 = (($116) - ($118))|0;
  $120 = (($119|0) / 44)&-1;
  $121 = (($120) + 1)|0;
  $122 = ($119|0)>(-44);
  if ($122) {
   $123 = (($121|0) / 93)&-1;
   $124 = (($71) + ($123<<2)|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = (($121|0) % 93)&-1;
   $127 = (($125) + (($126*44)|0)|0);
   $136 = $124;$138 = $127;
  } else {
   $128 = (91 - ($120))|0;
   $129 = (($128|0) / -93)&-1;
   $130 = (($71) + ($129<<2)|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = (($128|0) % 93)&-1;
   $133 = (92 - ($132))|0;
   $134 = (($131) + (($133*44)|0)|0);
   $136 = $130;$138 = $134;
  }
  $135 = $136;
  $137 = $138;
  $139 = $4;
  $140 = $139;
  HEAP32[$140>>2] = $135;
  $141 = (($139) + 4)|0;
  $142 = $141;
  HEAP32[$142>>2] = $137;
  $143 = (($10) + ($60))|0;
  $144 = (($143>>>0) / 93)&-1;
  $145 = (($8) + ($144<<2)|0);
  if ($15) {
   $150 = 0;
  } else {
   $146 = HEAP32[$145>>2]|0;
   $147 = (($143>>>0) % 93)&-1;
   $148 = (($146) + (($147*44)|0)|0);
   $150 = $148;
  }
  HEAP32[$5>>2] = $145;
  $149 = (($5) + 4|0);
  HEAP32[$149>>2] = $150;
  $151 = $6;
  $152 = $151;
  HEAP32[$152>>2] = $115;
  $153 = (($151) + 4)|0;
  $154 = $153;
  HEAP32[$154>>2] = $116;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
  ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
  __ZNSt3__14moveI10InputEventPS1_RS1_PS2_iLi93ES1_S2_S3_S4_iLi93EEENS_16__deque_iteratorIT5_T6_T7_T8_T9_XT10_EEENS5_IT_T0_T1_T2_T3_XT4_EEESH_SB_($__i,$tmpcast$byval_copy,$$byval_copy,$tmpcast2$byval_copy);
  $155 = (($__i) + 4|0);
  $156 = HEAP32[$155>>2]|0;
  __ZN10InputEventD2Ev($156);
  $157 = HEAP32[$59>>2]|0;
  $158 = (($157) + -1)|0;
  HEAP32[$59>>2] = $158;
  $159 = HEAP32[$13>>2]|0;
  $160 = HEAP32[$7>>2]|0;
  $161 = $159;
  $162 = $160;
  $163 = (($161) - ($162))|0;
  $164 = $163 >> 2;
  $165 = ($164|0)==(0);
  if ($165) {
   $169 = 0;
  } else {
   $166 = ($164*93)|0;
   $167 = (($166) + -1)|0;
   $169 = $167;
  }
  $168 = HEAP32[$9>>2]|0;
  $$neg2$i = (($169) - ($168))|0;
  $170 = (($$neg2$i) - ($158))|0;
  $171 = ($170>>>0)>(185);
  if ($171) {
   $172 = (($159) + -4|0);
   $173 = HEAP32[$172>>2]|0;
   __ZdlPv($173);
   $174 = HEAP32[$13>>2]|0;
   $175 = (($174) + -4|0);
   $__new_last2$i$i$i = $175;
   $176 = (0 - ($__new_last2$i$i$i))|0;
   $uglygep$i$i$i = (($175) + ($176)|0);
   $uglygep3$i$i$i = $uglygep$i$i$i;
   $177 = $uglygep3$i$i$i >>> 2;
   $178 = $177 ^ -1;
   $scevgep4$i$i$i = (($174) + ($178<<2)|0);
   HEAP32[$13>>2] = $scevgep4$i$i$i;
   $$pre = HEAP32[$9>>2]|0;
   $181 = $$pre;
  } else {
   $181 = $168;
  }
 }
 $179 = HEAP32[$7>>2]|0;
 $180 = (($181>>>0) / 93)&-1;
 $182 = (($179) + ($180<<2)|0);
 $183 = HEAP32[$13>>2]|0;
 $184 = ($183|0)==($179|0);
 if ($184) {
  $190 = 0;$195 = 0;
 } else {
  $185 = HEAP32[$182>>2]|0;
  $186 = (($181>>>0) % 93)&-1;
  $187 = (($185) + (($186*44)|0)|0);
  $phitmp = $187;
  $190 = 0;$195 = $phitmp;
 }
 $188 = $182;
 $189 = $190 | $188;
 $191 = $agg$result;
 $192 = $191;
 HEAP32[$192>>2] = $189;
 $193 = (($191) + 4)|0;
 $194 = $193;
 HEAP32[$194>>2] = $195;
 if ($215) {
  STACKTOP = sp;return;
 }
 $196 = (($agg$result) + 4|0);
 $197 = HEAP32[$182>>2]|0;
 $198 = $197;
 $199 = (($195) - ($198))|0;
 $200 = (($199|0) / 44)&-1;
 $201 = (($200) + ($$0$i27))|0;
 $202 = ($201|0)>(0);
 if ($202) {
  $203 = (($201|0) / 93)&-1;
  $$sum20 = (($203) + ($180))|0;
  $204 = (($179) + ($$sum20<<2)|0);
  HEAP32[$agg$result>>2] = $204;
  $205 = HEAP32[$204>>2]|0;
  $206 = (($201|0) % 93)&-1;
  $207 = (($205) + (($206*44)|0)|0);
  HEAP32[$196>>2] = $207;
  STACKTOP = sp;return;
 } else {
  $208 = (92 - ($201))|0;
  $209 = (($208|0) / -93)&-1;
  $$sum19 = (($209) + ($180))|0;
  $210 = (($179) + ($$sum19<<2)|0);
  HEAP32[$agg$result>>2] = $210;
  $211 = HEAP32[$210>>2]|0;
  $212 = (($208|0) % 93)&-1;
  $213 = (92 - ($212))|0;
  $214 = (($211) + (($213*44)|0)|0);
  HEAP32[$196>>2] = $214;
  STACKTOP = sp;return;
 }
}
function __Z18GetGUIEventManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[612536>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZL19InitGUIEventManagerv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628368>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(24,$$byval_copy,1,16,612544,52)|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 HEAP32[612536>>2] = $2;
 STACKTOP = sp;return;
}
function __ZL22CleanupGUIEventManagerv() {
 var $$byval_copy = 0, $$pre$i$i$i$i$i$i = 0, $$pre2$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__i$01$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[612536>>2]|0;
 $2 = HEAP32[628368>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZNSt3__112__deque_baseI10InputEventNS_9allocatorIS1_EEE5clearEv($1);
  $4 = (($1) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($1) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  if (!($8)) {
   $__i$01$i$i$i$i$i$i = $5;
   while(1) {
    $9 = HEAP32[$__i$01$i$i$i$i$i$i>>2]|0;
    __ZdlPv($9);
    $10 = (($__i$01$i$i$i$i$i$i) + 4|0);
    $11 = ($10|0)==($7|0);
    if ($11) {
     break;
    } else {
     $__i$01$i$i$i$i$i$i = $10;
    }
   }
   $$pre$i$i$i$i$i$i = HEAP32[$4>>2]|0;
   $$pre2$i$i$i$i$i$i = HEAP32[$6>>2]|0;
   $12 = ($$pre2$i$i$i$i$i$i|0)==($$pre$i$i$i$i$i$i|0);
   if (!($12)) {
    $__new_last2$i$i$i$i$i$i$i$i$i$i$i = $$pre$i$i$i$i$i$i;
    $scevgep$i$i$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i$i$i) + -4|0);
    $13 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i) + ($13)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i;
    $14 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i >>> 2;
    $15 = $14 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i$i$i) + ($15<<2)|0);
    HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i;
   }
  }
  $16 = HEAP32[$1>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   __ZdlPv($16);
  }
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[612536>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__113move_backwardI10InputEventPS1_RS1_PS2_iLi93ES1_S2_S3_S4_iLi93EEENS_16__deque_iteratorIT5_T6_T7_T8_T9_XT10_EEENS5_IT_T0_T1_T2_T3_XT4_EEESH_SB_($agg$result,$__f,$__l,$__r) {
 $agg$result = $agg$result|0;
 $__f = $__f|0;
 $__l = $__l|0;
 $__r = $__r|0;
 var $$neg$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__bs$0 = 0, $__lb$0 = 0, $__n$0$neg = 0, $__n$03 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($__l) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__f) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = HEAP32[$__l>>2]|0;
  $8 = HEAP32[$__f>>2]|0;
  $9 = $7;
  $10 = $8;
  $11 = (($9) - ($10))|0;
  $12 = $11 >> 2;
  $13 = ($12*93)|0;
  $14 = HEAP32[$7>>2]|0;
  $15 = $3;
  $16 = $14;
  $17 = (($15) - ($16))|0;
  $18 = (($17|0) / 44)&-1;
  $19 = (($13) + ($18))|0;
  $20 = HEAP32[$8>>2]|0;
  $21 = $5;
  $22 = $20;
  $23 = (($21) - ($22))|0;
  $$neg$i = (($23|0) / -44)&-1;
  $24 = (($19) + ($$neg$i))|0;
  $25 = ($24|0)>(0);
  if ($25) {
   $$pre = HEAP32[$__l>>2]|0;
   $33 = $$pre;$35 = $3;$__n$03 = $24;
   while(1) {
    $32 = HEAP32[$33>>2]|0;
    $34 = ($35|0)==($32|0);
    if ($34) {
     $36 = (($33) + -4|0);
     HEAP32[$__l>>2] = $36;
     $37 = HEAP32[$36>>2]|0;
     $38 = (($37) + 4092|0);
     HEAP32[$2>>2] = $38;
     $40 = $38;$42 = $36;
    } else {
     $40 = $35;$42 = $33;
    }
    $39 = (($40) + -44|0);
    HEAP32[$2>>2] = $39;
    $41 = HEAP32[$42>>2]|0;
    $43 = $40;
    $44 = $41;
    $45 = (($43) - ($44))|0;
    $46 = (($45|0) / 44)&-1;
    $47 = ($46|0)>($__n$03|0);
    if ($47) {
     $__n$0$neg = (0 - ($__n$03))|0;
     $48 = (($40) + (($__n$0$neg*44)|0)|0);
     $__bs$0 = $__n$03;$__lb$0 = $48;
    } else {
     $__bs$0 = $46;$__lb$0 = $41;
    }
    $49 = $__r;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = (($49) + 4)|0;
    $53 = $52;
    $54 = HEAP32[$53>>2]|0;
    $55 = $1;
    $56 = $55;
    HEAP32[$56>>2] = $51;
    $57 = (($55) + 4)|0;
    $58 = $57;
    HEAP32[$58>>2] = $54;
    ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
    __ZNSt3__113move_backwardIP10InputEventS1_S2_RS1_PS2_iLi93EEENS_16__deque_iteratorIT0_T1_T2_T3_T4_XT5_EEET_SC_SB_PNS_9enable_ifIXsr27__is_random_access_iteratorISC_EE5valueEvE4typeE($0,$__lb$0,$40,$tmpcast$byval_copy,0);
    $59 = $0;
    $60 = $59;
    $61 = HEAP32[$60>>2]|0;
    $62 = (($59) + 4)|0;
    $63 = $62;
    $64 = HEAP32[$63>>2]|0;
    $65 = $__r;
    $66 = $65;
    HEAP32[$66>>2] = $61;
    $67 = (($65) + 4)|0;
    $68 = $67;
    HEAP32[$68>>2] = $64;
    $69 = (($__n$03) - ($__bs$0))|0;
    $70 = (($__bs$0) + -1)|0;
    $71 = ($70|0)==(0);
    do {
     if ($71) {
      $98 = $42;$99 = $39;
     } else {
      $73 = HEAP32[$42>>2]|0;
      $74 = $39;
      $75 = $73;
      $76 = (($74) - ($75))|0;
      $77 = (($76|0) / 44)&-1;
      $78 = (($77) - ($70))|0;
      $79 = ($78|0)>(0);
      if ($79) {
       $80 = (($78|0) / 93)&-1;
       $81 = (($42) + ($80<<2)|0);
       HEAP32[$__l>>2] = $81;
       $82 = HEAP32[$81>>2]|0;
       $83 = (($78|0) % 93)&-1;
       $84 = (($82) + (($83*44)|0)|0);
       HEAP32[$2>>2] = $84;
       $98 = $81;$99 = $84;
       break;
      } else {
       $85 = (92 - ($78))|0;
       $86 = (($85|0) / -93)&-1;
       $87 = (($42) + ($86<<2)|0);
       HEAP32[$__l>>2] = $87;
       $88 = HEAP32[$87>>2]|0;
       $89 = (($85|0) % 93)&-1;
       $90 = (92 - ($89))|0;
       $91 = (($88) + (($90*44)|0)|0);
       HEAP32[$2>>2] = $91;
       $98 = $87;$99 = $91;
       break;
      }
     }
    } while(0);
    $72 = ($69|0)>(0);
    if ($72) {
     $33 = $98;$35 = $99;$__n$03 = $69;
    } else {
     $94 = $61;$97 = $64;
     break;
    }
   }
   $92 = $agg$result;
   $93 = $92;
   HEAP32[$93>>2] = $94;
   $95 = (($92) + 4)|0;
   $96 = $95;
   HEAP32[$96>>2] = $97;
   STACKTOP = sp;return;
  }
 }
 $26 = $__r;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $94 = $28;$97 = $31;
 $92 = $agg$result;
 $93 = $92;
 HEAP32[$93>>2] = $94;
 $95 = (($92) + 4)|0;
 $96 = $95;
 HEAP32[$96>>2] = $97;
 STACKTOP = sp;return;
}
function __ZNSt3__14moveI10InputEventPS1_RS1_PS2_iLi93ES1_S2_S3_S4_iLi93EEENS_16__deque_iteratorIT5_T6_T7_T8_T9_XT10_EEENS5_IT_T0_T1_T2_T3_XT4_EEESH_SB_($agg$result,$__f,$__l,$__r) {
 $agg$result = $agg$result|0;
 $__f = $__f|0;
 $__l = $__l|0;
 $__r = $__r|0;
 var $$01$i = 0, $$012$i$i$i = 0, $$03$i$i$i = 0, $$neg$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__bs$0 = 0, $__fe$0 = 0, $__m$0$i = 0, $__n$0$i = 0, $__n$05 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__l) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__f) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  $5 = HEAP32[$__l>>2]|0;
  $6 = HEAP32[$__f>>2]|0;
  $7 = $5;
  $8 = $6;
  $9 = (($7) - ($8))|0;
  $10 = $9 >> 2;
  $11 = ($10*93)|0;
  $12 = HEAP32[$5>>2]|0;
  $13 = $1;
  $14 = $12;
  $15 = (($13) - ($14))|0;
  $16 = (($15|0) / 44)&-1;
  $17 = (($11) + ($16))|0;
  $18 = HEAP32[$6>>2]|0;
  $19 = $3;
  $20 = $18;
  $21 = (($19) - ($20))|0;
  $$neg$i = (($21|0) / -44)&-1;
  $22 = (($17) + ($$neg$i))|0;
  $23 = ($22|0)>(0);
  if ($23) {
   $$pre = HEAP32[$__f>>2]|0;
   $31 = $$pre;$35 = $3;$__n$05 = $22;
   while(1) {
    $30 = HEAP32[$31>>2]|0;
    $32 = (($30) + 4092|0);
    $33 = $32;
    $34 = $35;
    $36 = (($33) - ($34))|0;
    $37 = (($36|0) / 44)&-1;
    $38 = ($37|0)>($__n$05|0);
    if ($38) {
     $39 = (($35) + (($__n$05*44)|0)|0);
     $__bs$0 = $__n$05;$__fe$0 = $39;
    } else {
     $__bs$0 = $37;$__fe$0 = $32;
    }
    $40 = $__r;
    $41 = $40;
    $42 = HEAP32[$41>>2]|0;
    $43 = (($40) + 4)|0;
    $44 = $43;
    $45 = HEAP32[$44>>2]|0;
    $46 = $42;
    $47 = $45;
    $48 = ($35|0)==($__fe$0|0);
    if ($48) {
     $88 = $46;$90 = $47;
    } else {
     $49 = $__fe$0;
     $$01$i = $35;$122 = $47;$123 = $46;$51 = $46;$55 = $47;
     while(1) {
      $50 = HEAP32[$51>>2]|0;
      $52 = (($50) + 4092|0);
      $53 = $52;
      $54 = $55;
      $56 = (($53) - ($54))|0;
      $57 = (($56|0) / 44)&-1;
      $58 = $$01$i;
      $59 = (($49) - ($58))|0;
      $60 = (($59|0) / 44)&-1;
      $61 = ($60|0)>($57|0);
      if ($61) {
       $62 = (($$01$i) + (($57*44)|0)|0);
       $__m$0$i = $62;$__n$0$i = $57;
      } else {
       $__m$0$i = $__fe$0;$__n$0$i = $60;
      }
      $63 = ($$01$i|0)==($__m$0$i|0);
      if (!($63)) {
       $$012$i$i$i = $$01$i;$$03$i$i$i = $55;
       while(1) {
        __ZN10InputEventaSERKS_($$03$i$i$i,$$012$i$i$i);
        $64 = (($$012$i$i$i) + 44|0);
        $65 = (($$03$i$i$i) + 44|0);
        $66 = ($64|0)==($__m$0$i|0);
        if ($66) {
         break;
        } else {
         $$012$i$i$i = $64;$$03$i$i$i = $65;
        }
       }
      }
      $67 = ($__n$0$i|0)==(0);
      do {
       if ($67) {
        $124 = $122;$125 = $123;$126 = $51;$127 = $55;
       } else {
        $69 = HEAP32[$51>>2]|0;
        $70 = $69;
        $71 = (($54) - ($70))|0;
        $72 = (($71|0) / 44)&-1;
        $73 = (($72) + ($__n$0$i))|0;
        $74 = ($73|0)>(0);
        if ($74) {
         $75 = (($73|0) / 93)&-1;
         $76 = (($51) + ($75<<2)|0);
         $77 = HEAP32[$76>>2]|0;
         $78 = (($73|0) % 93)&-1;
         $79 = (($77) + (($78*44)|0)|0);
         $124 = $79;$125 = $76;$126 = $76;$127 = $79;
         break;
        } else {
         $80 = (92 - ($73))|0;
         $81 = (($80|0) / -93)&-1;
         $82 = (($51) + ($81<<2)|0);
         $83 = HEAP32[$82>>2]|0;
         $84 = (($80|0) % 93)&-1;
         $85 = (92 - ($84))|0;
         $86 = (($83) + (($85*44)|0)|0);
         $124 = $86;$125 = $82;$126 = $82;$127 = $86;
         break;
        }
       }
      } while(0);
      $68 = ($__m$0$i|0)==($__fe$0|0);
      if ($68) {
       $88 = $125;$90 = $124;
       break;
      } else {
       $$01$i = $__m$0$i;$122 = $124;$123 = $125;$51 = $126;$55 = $127;
      }
     }
    }
    $87 = $88;
    $89 = $90;
    $91 = $__r;
    $92 = $91;
    HEAP32[$92>>2] = $87;
    $93 = (($91) + 4)|0;
    $94 = $93;
    HEAP32[$94>>2] = $89;
    $95 = (($__n$05) - ($__bs$0))|0;
    $96 = ($__bs$0|0)==(0);
    do {
     if ($96) {
      $128 = $31;$129 = $35;
     } else {
      $98 = HEAP32[$31>>2]|0;
      $99 = $98;
      $100 = (($34) - ($99))|0;
      $101 = (($100|0) / 44)&-1;
      $102 = (($101) + ($__bs$0))|0;
      $103 = ($102|0)>(0);
      if ($103) {
       $104 = (($102|0) / 93)&-1;
       $105 = (($31) + ($104<<2)|0);
       HEAP32[$__f>>2] = $105;
       $106 = HEAP32[$105>>2]|0;
       $107 = (($102|0) % 93)&-1;
       $108 = (($106) + (($107*44)|0)|0);
       HEAP32[$2>>2] = $108;
       $128 = $105;$129 = $108;
       break;
      } else {
       $109 = (92 - ($102))|0;
       $110 = (($109|0) / -93)&-1;
       $111 = (($31) + ($110<<2)|0);
       HEAP32[$__f>>2] = $111;
       $112 = HEAP32[$111>>2]|0;
       $113 = (($109|0) % 93)&-1;
       $114 = (92 - ($113))|0;
       $115 = (($112) + (($114*44)|0)|0);
       HEAP32[$2>>2] = $115;
       $128 = $111;$129 = $115;
       break;
      }
     }
    } while(0);
    $97 = ($95|0)>(0);
    if ($97) {
     $31 = $128;$35 = $129;$__n$05 = $95;
    } else {
     $118 = $87;$121 = $89;
     break;
    }
   }
   $116 = $agg$result;
   $117 = $116;
   HEAP32[$117>>2] = $118;
   $119 = (($116) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $121;
   STACKTOP = sp;return;
  }
 }
 $24 = $__r;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $118 = $26;$121 = $29;
 $116 = $agg$result;
 $117 = $116;
 HEAP32[$117>>2] = $118;
 $119 = (($116) + 4)|0;
 $120 = $119;
 HEAP32[$120>>2] = $121;
 STACKTOP = sp;return;
}
function __ZNSt3__113move_backwardIP10InputEventS1_S2_RS1_PS2_iLi93EEENS_16__deque_iteratorIT0_T1_T2_T3_T4_XT5_EEET_SC_SB_PNS_9enable_ifIXsr27__is_random_access_iteratorISC_EE5valueEvE4typeE($agg$result,$__f,$__l,$__r,$0) {
 $agg$result = $agg$result|0;
 $__f = $__f|0;
 $__l = $__l|0;
 $__r = $__r|0;
 $0 = $0|0;
 var $$012$i$i = 0, $$03 = 0, $$03$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0;
 var $__m$0 = 0, $__n$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($__l|0)==($__f|0);
 if ($1) {
  $68 = $__r;
  $69 = $68;
  $70 = HEAP32[$69>>2]|0;
  $71 = (($68) + 4)|0;
  $72 = $71;
  $73 = HEAP32[$72>>2]|0;
  $74 = $agg$result;
  $75 = $74;
  HEAP32[$75>>2] = $70;
  $76 = (($74) + 4)|0;
  $77 = $76;
  HEAP32[$77>>2] = $73;
  STACKTOP = sp;return;
 }
 $2 = $__f;
 $3 = (($__r) + 4|0);
 $$03 = $__l;
 while(1) {
  $4 = $__r;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $6;
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($9) - ($12))|0;
  $14 = (($13|0) / 44)&-1;
  $15 = (($14) + -1)|0;
  $16 = ($15|0)>(0);
  if ($16) {
   $17 = (($15|0) / 93)&-1;
   $18 = (($10) + ($17<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($15|0) % 93)&-1;
   $21 = (($19) + (($20*44)|0)|0);
   $30 = $21;$33 = $19;
  } else {
   $22 = (93 - ($14))|0;
   $23 = (($22|0) / -93)&-1;
   $24 = (($10) + ($23<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($22|0) % 93)&-1;
   $27 = (92 - ($26))|0;
   $28 = (($25) + (($27*44)|0)|0);
   $30 = $28;$33 = $25;
  }
  $29 = (($30) + 44|0);
  $31 = $29;
  $32 = $33;
  $34 = (($31) - ($32))|0;
  $35 = (($34|0) / 44)&-1;
  $36 = $$03;
  $37 = (($36) - ($2))|0;
  $38 = (($37|0) / 44)&-1;
  $39 = ($38|0)>($35|0);
  if ($39) {
   $40 = (0 - ($35))|0;
   $41 = (($$03) + (($40*44)|0)|0);
   $__m$0 = $41;$__n$0 = $35;
  } else {
   $__m$0 = $__f;$__n$0 = $38;
  }
  $42 = ($$03|0)==($__m$0|0);
  if (!($42)) {
   $$012$i$i = $$03;$$03$i$i = $29;
   while(1) {
    $43 = (($$03$i$i) + -44|0);
    $44 = (($$012$i$i) + -44|0);
    __ZN10InputEventaSERKS_($43,$44);
    $45 = ($44|0)==($__m$0|0);
    if ($45) {
     break;
    } else {
     $$012$i$i = $44;$$03$i$i = $43;
    }
   }
  }
  $46 = ($__n$0|0)==(0);
  do {
   if (!($46)) {
    $48 = HEAP32[$3>>2]|0;
    $49 = HEAP32[$10>>2]|0;
    $50 = $48;
    $51 = $49;
    $52 = (($50) - ($51))|0;
    $53 = (($52|0) / 44)&-1;
    $54 = (($53) - ($__n$0))|0;
    $55 = ($54|0)>(0);
    if ($55) {
     $56 = (($54|0) / 93)&-1;
     $57 = (($10) + ($56<<2)|0);
     HEAP32[$__r>>2] = $57;
     $58 = HEAP32[$57>>2]|0;
     $59 = (($54|0) % 93)&-1;
     $60 = (($58) + (($59*44)|0)|0);
     HEAP32[$3>>2] = $60;
     break;
    } else {
     $61 = (92 - ($54))|0;
     $62 = (($61|0) / -93)&-1;
     $63 = (($10) + ($62<<2)|0);
     HEAP32[$__r>>2] = $63;
     $64 = HEAP32[$63>>2]|0;
     $65 = (($61|0) % 93)&-1;
     $66 = (92 - ($65))|0;
     $67 = (($64) + (($66*44)|0)|0);
     HEAP32[$3>>2] = $67;
     break;
    }
   }
  } while(0);
  $47 = ($__m$0|0)==($__f|0);
  if ($47) {
   break;
  } else {
   $$03 = $__m$0;
  }
 }
 $68 = $__r;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = $agg$result;
 $75 = $74;
 HEAP32[$75>>2] = $70;
 $76 = (($74) + 4)|0;
 $77 = $76;
 HEAP32[$77>>2] = $73;
 STACKTOP = sp;return;
}
function __ZNSt3__112__deque_baseI10InputEventNS_9allocatorIS1_EEE5clearEv($this) {
 $this = $this|0;
 var $$lcssa = 0, $$ph = 0, $$ph1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3>>>0) / 93)&-1;
 $5 = (($1) + ($4<<2)|0);
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if ($8) {
  $9 = (($this) + 20|0);
  $23 = 0;$36 = $9;$54 = 0;
 } else {
  $10 = HEAP32[$5>>2]|0;
  $11 = (($3>>>0) % 93)&-1;
  $12 = (($10) + (($11*44)|0)|0);
  $13 = (($this) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($3) + ($14))|0;
  $16 = (($15>>>0) / 93)&-1;
  $17 = (($1) + ($16<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($15>>>0) % 93)&-1;
  $20 = (($18) + (($19*44)|0)|0);
  $23 = $20;$36 = $13;$54 = $12;
 }
 $$ph = $54;$$ph1 = $5;
 L5: while(1) {
  $22 = $$ph;
  while(1) {
   $21 = ($22|0)==($23|0);
   if ($21) {
    break L5;
   }
   __THREW__ = 0;
   invoke_vi(3498,($22|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 10;
    break L5;
   }
   $26 = (($22) + 44|0);
   $27 = HEAP32[$$ph1>>2]|0;
   $28 = $26;
   $29 = $27;
   $30 = (($28) - ($29))|0;
   $31 = ($30|0)==(4092);
   if ($31) {
    break;
   } else {
    $22 = $26;
   }
  }
  $32 = (($$ph1) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $$ph = $33;$$ph1 = $32;
 }
 if ((label|0) == 10) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 }
 HEAP32[$36>>2] = 0;
 $37 = HEAP32[$6>>2]|0;
 $38 = HEAP32[$0>>2]|0;
 $39 = $37;
 $40 = $38;
 $41 = (($39) - ($40))|0;
 $42 = $41 >> 2;
 $43 = ($42>>>0)>(2);
 if ($43) {
  $45 = $38;
  while(1) {
   $44 = HEAP32[$45>>2]|0;
   __ZdlPv($44);
   $46 = HEAP32[$0>>2]|0;
   $47 = (($46) + 4|0);
   HEAP32[$0>>2] = $47;
   $48 = HEAP32[$6>>2]|0;
   $49 = $48;
   $50 = $47;
   $51 = (($49) - ($50))|0;
   $52 = $51 >> 2;
   $53 = ($52>>>0)>(2);
   if ($53) {
    $45 = $47;
   } else {
    $$lcssa = $52;
    break;
   }
  }
 } else {
  $$lcssa = $42;
 }
 if ((($$lcssa|0) == 1)) {
  HEAP32[$2>>2] = 46;
  STACKTOP = sp;return;
 } else if ((($$lcssa|0) == 2)) {
  HEAP32[$2>>2] = 93;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__15dequeI10InputEventNS_9allocatorIS1_EEE19__add_back_capacityEv($this) {
 $this = $this|0;
 var $$0153 = 0, $$055 = 0, $$pr$pre$i = 0, $$pr$pre$i36 = 0, $$pre = 0, $$pre$i = 0, $$pre$i33 = 0, $$pre50 = 0, $$pre8$i = 0, $$pre8$i19 = 0, $$pre8$i28 = 0, $$pre8$i38 = 0, $$sum = 0, $$sum$i = 0, $$sum$i30 = 0, $$sum41 = 0, $$sum42 = 0, $$sum43 = 0, $$sum51 = 0, $$sum52 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__buf = 0, $__i$0 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $__buf = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>(92);
 if ($3) {
  $4 = (($2) + -93)|0;
  HEAP32[$1>>2] = $4;
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($6) + 4|0);
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  do {
   if ($13) {
    $14 = HEAP32[$this>>2]|0;
    $15 = ($8>>>0)>($14>>>0);
    if ($15) {
     $16 = $8;
     $17 = $14;
     $18 = (($16) - ($17))|0;
     $19 = $18 >> 2;
     $20 = (($19) + 1)|0;
     $21 = (($20|0) / -2)&-1;
     $$sum42 = (($21) + 1)|0;
     $22 = (($6) + ($$sum42<<2)|0);
     $23 = $10;
     $24 = (($23) - ($16))|0;
     $25 = $24 >> 2;
     _memmove(($22|0),($8|0),($24|0))|0;
     $$sum$i = (($25) + 1)|0;
     $$sum43 = (($$sum$i) + ($21))|0;
     $26 = (($6) + ($$sum43<<2)|0);
     HEAP32[$9>>2] = $26;
     $27 = HEAP32[$5>>2]|0;
     $28 = (($27) + ($21<<2)|0);
     HEAP32[$5>>2] = $28;
     $54 = $26;
     label = 13;
     break;
    }
    $29 = $10;
    $30 = $14;
    $31 = (($29) - ($30))|0;
    $32 = $31 >> 1;
    $33 = ($32|0)==(0);
    $34 = $33 ? 1 : $32;
    $35 = $34 >>> 2;
    $36 = $34 << 2;
    $37 = (__Znwj($36)|0);
    $38 = (($37) + ($35<<2)|0);
    $39 = (($37) + ($34<<2)|0);
    $40 = ($8|0)==($10|0);
    if ($40) {
     $49 = $38;$51 = $14;
    } else {
     $42 = $38;$44 = $8;
     while(1) {
      $41 = ($42|0)==(0|0);
      if ($41) {
       $46 = 0;
      } else {
       $43 = HEAP32[$44>>2]|0;
       HEAP32[$42>>2] = $43;
       $46 = $42;
      }
      $45 = (($46) + 4|0);
      $47 = (($44) + 4|0);
      $48 = ($47|0)==($10|0);
      if ($48) {
       break;
      } else {
       $42 = $45;$44 = $47;
      }
     }
     $$pre$i = HEAP32[$this>>2]|0;
     $49 = $45;$51 = $$pre$i;
    }
    HEAP32[$this>>2] = $37;
    HEAP32[$5>>2] = $38;
    HEAP32[$9>>2] = $49;
    HEAP32[$11>>2] = $39;
    $50 = ($51|0)==(0|0);
    if ($50) {
     $53 = $49;
     label = 12;
    } else {
     __ZdlPv($51);
     $$pr$pre$i = HEAP32[$9>>2]|0;
     $53 = $$pr$pre$i;
     label = 12;
    }
   } else {
    $53 = $10;
    label = 12;
   }
  } while(0);
  if ((label|0) == 12) {
   $52 = ($53|0)==(0|0);
   if ($52) {
    $56 = 0;
   } else {
    $54 = $53;
    label = 13;
   }
  }
  if ((label|0) == 13) {
   HEAP32[$54>>2] = $7;
   $$pre8$i = HEAP32[$9>>2]|0;
   $56 = $$pre8$i;
  }
  $55 = (($56) + 4|0);
  HEAP32[$9>>2] = $55;
  STACKTOP = sp;return;
 }
 $57 = (($this) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $58;
 $62 = $60;
 $63 = (($61) - ($62))|0;
 $64 = $63 >> 2;
 $65 = (($this) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$this>>2]|0;
 $68 = $66;
 $69 = $67;
 $70 = (($68) - ($69))|0;
 $71 = $70 >> 2;
 $72 = ($64>>>0)<($71>>>0);
 if ($72) {
  $73 = ($66|0)==($58|0);
  $74 = (__Znwj(4092)|0);
  if (!($73)) {
   $75 = ($58|0)==(0|0);
   if ($75) {
    $77 = 0;
   } else {
    HEAP32[$58>>2] = $74;
    $$pre8$i28 = HEAP32[$57>>2]|0;
    $77 = $$pre8$i28;
   }
   $76 = (($77) + 4|0);
   HEAP32[$57>>2] = $76;
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $74;
  __ZNSt3__114__split_bufferIP10InputEventNS_9allocatorIS2_EEE10push_frontERKS2_($this,$0);
  $78 = HEAP32[$59>>2]|0;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($78) + 4|0);
  HEAP32[$59>>2] = $80;
  $81 = HEAP32[$57>>2]|0;
  $82 = HEAP32[$65>>2]|0;
  $83 = ($81|0)==($82|0);
  do {
   if ($83) {
    $84 = HEAP32[$this>>2]|0;
    $85 = ($80>>>0)>($84>>>0);
    if ($85) {
     $86 = $80;
     $87 = $84;
     $88 = (($86) - ($87))|0;
     $89 = $88 >> 2;
     $90 = (($89) + 1)|0;
     $91 = (($90|0) / -2)&-1;
     $$sum = (($91) + 1)|0;
     $92 = (($78) + ($$sum<<2)|0);
     $93 = $81;
     $94 = (($93) - ($86))|0;
     $95 = $94 >> 2;
     _memmove(($92|0),($80|0),($94|0))|0;
     $$sum$i30 = (($95) + 1)|0;
     $$sum41 = (($$sum$i30) + ($91))|0;
     $96 = (($78) + ($$sum41<<2)|0);
     HEAP32[$57>>2] = $96;
     $97 = HEAP32[$59>>2]|0;
     $98 = (($97) + ($91<<2)|0);
     HEAP32[$59>>2] = $98;
     $124 = $96;
     label = 31;
     break;
    }
    $99 = $81;
    $100 = $84;
    $101 = (($99) - ($100))|0;
    $102 = $101 >> 1;
    $103 = ($102|0)==(0);
    $104 = $103 ? 1 : $102;
    $105 = $104 >>> 2;
    $106 = $104 << 2;
    $107 = (__Znwj($106)|0);
    $108 = (($107) + ($105<<2)|0);
    $109 = (($107) + ($104<<2)|0);
    $110 = ($80|0)==($81|0);
    if ($110) {
     $119 = $108;$121 = $84;
    } else {
     $112 = $108;$114 = $80;
     while(1) {
      $111 = ($112|0)==(0|0);
      if ($111) {
       $116 = 0;
      } else {
       $113 = HEAP32[$114>>2]|0;
       HEAP32[$112>>2] = $113;
       $116 = $112;
      }
      $115 = (($116) + 4|0);
      $117 = (($114) + 4|0);
      $118 = ($117|0)==($81|0);
      if ($118) {
       break;
      } else {
       $112 = $115;$114 = $117;
      }
     }
     $$pre$i33 = HEAP32[$this>>2]|0;
     $119 = $115;$121 = $$pre$i33;
    }
    HEAP32[$this>>2] = $107;
    HEAP32[$59>>2] = $108;
    HEAP32[$57>>2] = $119;
    HEAP32[$65>>2] = $109;
    $120 = ($121|0)==(0|0);
    if ($120) {
     $123 = $119;
     label = 30;
    } else {
     __ZdlPv($121);
     $$pr$pre$i36 = HEAP32[$57>>2]|0;
     $123 = $$pr$pre$i36;
     label = 30;
    }
   } else {
    $123 = $81;
    label = 30;
   }
  } while(0);
  if ((label|0) == 30) {
   $122 = ($123|0)==(0|0);
   if ($122) {
    $126 = 0;
   } else {
    $124 = $123;
    label = 31;
   }
  }
  if ((label|0) == 31) {
   HEAP32[$124>>2] = $79;
   $$pre8$i38 = HEAP32[$57>>2]|0;
   $126 = $$pre8$i38;
  }
  $125 = (($126) + 4|0);
  HEAP32[$57>>2] = $125;
  STACKTOP = sp;return;
 }
 $127 = $70 >> 1;
 $128 = ($127|0)==(0);
 $129 = $128 ? 1 : $127;
 $130 = (($this) + 12|0);
 $131 = (($__buf) + 12|0);
 $132 = (($__buf) + 16|0);
 HEAP32[$132>>2] = $130;
 $133 = $129 << 2;
 $134 = (__Znwj($133)|0);
 HEAP32[$__buf>>2] = $134;
 $135 = (($134) + ($64<<2)|0);
 $136 = (($__buf) + 8|0);
 HEAP32[$136>>2] = $135;
 $137 = (($__buf) + 4|0);
 HEAP32[$137>>2] = $135;
 $138 = (($134) + ($129<<2)|0);
 HEAP32[$131>>2] = $138;
 __THREW__ = 0;
 $139 = (invoke_ii(2988,4092)|0);
 $140 = __THREW__; __THREW__ = 0;
 $141 = $140&1;
 L54: do {
  if ($141) {
   label = 42;
  } else {
   $142 = ($64|0)==($129|0);
   do {
    if ($142) {
     $143 = ($135>>>0)>($134>>>0);
     $144 = $135;
     $145 = $134;
     $146 = (($144) - ($145))|0;
     if ($143) {
      $147 = $146 >> 2;
      $148 = (($147) + 1)|0;
      $149 = (($148|0) / -2)&-1;
      $$sum52 = (($64) + ($149))|0;
      $150 = (($134) + ($$sum52<<2)|0);
      HEAP32[$136>>2] = $150;
      HEAP32[$137>>2] = $150;
      $163 = $150;
      break;
     }
     $151 = $146 >> 1;
     $152 = ($151|0)==(0);
     $153 = $152 ? 1 : $151;
     $154 = $153 << 2;
     __THREW__ = 0;
     $155 = (invoke_ii(2988,($154|0))|0);
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if ($157) {
      label = 42;
      break L54;
     }
     $158 = $153 >>> 2;
     $159 = (($155) + ($158<<2)|0);
     $160 = (($155) + ($153<<2)|0);
     HEAP32[$__buf>>2] = $155;
     HEAP32[$137>>2] = $159;
     HEAP32[$136>>2] = $159;
     HEAP32[$131>>2] = $160;
     $161 = ($134|0)==(0|0);
     if ($161) {
      $163 = $159;
     } else {
      __ZdlPv($134);
      $163 = $159;
     }
    } else {
     $163 = $135;
    }
   } while(0);
   $162 = ($163|0)==(0|0);
   if ($162) {
    $175 = 0;
   } else {
    HEAP32[$163>>2] = $139;
    $$pre8$i19 = HEAP32[$136>>2]|0;
    $175 = $$pre8$i19;
   }
   $174 = (($175) + 4|0);
   HEAP32[$136>>2] = $174;
   $176 = HEAP32[$57>>2]|0;
   $__i$0 = $176;
   while(1) {
    $177 = HEAP32[$59>>2]|0;
    $178 = ($__i$0|0)==($177|0);
    if ($178) {
     break;
    }
    $179 = (($__i$0) + -4|0);
    __THREW__ = 0;
    invoke_vii(2742,($__buf|0),($179|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if ($181) {
     label = 51;
     break;
    } else {
     $__i$0 = $179;
    }
   }
   if ((label|0) == 51) {
    $194 = ___cxa_find_matching_catch()|0;
    $195 = tempRet0;
    $$pre = HEAP32[$137>>2]|0;
    $$pre50 = HEAP32[$136>>2]|0;
    $196 = ($$pre50|0)==($$pre|0);
    if ($196) {
     $$0153 = $194;$$055 = $195;
     break;
    }
    $__new_last2$i$i$i$i$i = $$pre;
    $scevgep$i$i$i$i$i = (($$pre50) + -4|0);
    $197 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($197)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $198 = $uglygep3$i$i$i$i$i >>> 2;
    $199 = $198 ^ -1;
    $scevgep4$i$i$i$i$i = (($$pre50) + ($199<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i;
    $$0153 = $194;$$055 = $195;
    break;
   }
   $182 = HEAP32[$this>>2]|0;
   $183 = HEAP32[$__buf>>2]|0;
   HEAP32[$this>>2] = $183;
   HEAP32[$__buf>>2] = $182;
   $184 = HEAP32[$137>>2]|0;
   HEAP32[$59>>2] = $184;
   HEAP32[$137>>2] = $__i$0;
   $185 = HEAP32[$57>>2]|0;
   $186 = HEAP32[$136>>2]|0;
   HEAP32[$57>>2] = $186;
   HEAP32[$136>>2] = $185;
   $187 = HEAP32[$65>>2]|0;
   $188 = HEAP32[$131>>2]|0;
   HEAP32[$65>>2] = $188;
   HEAP32[$131>>2] = $187;
   $189 = ($185|0)==($__i$0|0);
   if (!($189)) {
    $__new_last2$i$i$i$i$i2 = $__i$0;
    $scevgep$i$i$i$i$i3 = (($185) + -4|0);
    $190 = (0 - ($__new_last2$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($190)|0);
    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
    $191 = $uglygep3$i$i$i$i$i6 >>> 2;
    $192 = $191 ^ -1;
    $scevgep4$i$i$i$i$i7 = (($185) + ($192<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i7;
   }
   $193 = ($182|0)==(0|0);
   if ($193) {
    STACKTOP = sp;return;
   }
   __ZdlPv($182);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 42) {
  $164 = ___cxa_find_matching_catch(0|0)|0;
  $165 = tempRet0;
  (___cxa_begin_catch(($164|0))|0);
  $$sum51 = (($64) + -1)|0;
  $166 = (($134) + ($$sum51<<2)|0);
  $167 = HEAP32[$166>>2]|0;
  __ZdlPv($167);
  __THREW__ = 0;
  invoke_v(140);
  $168 = __THREW__; __THREW__ = 0;
  $169 = $168&1;
  if (!($169)) {
   // unreachable;
  }
  $170 = ___cxa_find_matching_catch()|0;
  $171 = tempRet0;
  __THREW__ = 0;
  invoke_v(66);
  $172 = __THREW__; __THREW__ = 0;
  $173 = $172&1;
  if ($173) {
   $202 = ___cxa_find_matching_catch(0|0)|0;
   $203 = tempRet0;
   ___clang_call_terminate($202);
   // unreachable;
  } else {
   $$0153 = $170;$$055 = $171;
  }
 }
 $200 = HEAP32[$__buf>>2]|0;
 $201 = ($200|0)==(0|0);
 if ($201) {
  ___resumeException($$0153|0);
  // unreachable;
 }
 __ZdlPv($200);
 ___resumeException($$0153|0);
 // unreachable;
}
function __ZNSt3__114__split_bufferIP10InputEventNS_9allocatorIS2_EEE10push_frontERKS2_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIP10InputEventRNS_9allocatorIS2_EEE10push_frontERKS2_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZN9InputAxisC2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy6 = sp + 48|0;
 $0 = sp + 44|0;
 $1 = sp + 40|0;
 $2 = sp + 36|0;
 $3 = sp + 32|0;
 $4 = sp + 16|0;
 $5 = sp + 12|0;
 $6 = sp;
 $7 = sp + 20|0;
 HEAP32[$this>>2] = ((612552 + 8|0));
 $8 = (($this) + 4|0);
 $9 = (($this) + 16|0);
 $10 = (($this) + 28|0);
 $11 = (($this) + 80|0);
 dest=$8+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$11>>2] = Math_fround(0.00100000004749745130539);
 $12 = (($this) + 76|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 84|0);
 HEAPF32[$13>>2] = Math_fround(0.100000001490116119385);
 $14 = (($this) + 89|0);
 HEAP8[$14>>0] = 0;
 $15 = (($this) + 88|0);
 HEAP8[$15>>0] = 0;
 $16 = (($this) + 64|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 0;
 HEAP8[$6>>0] = 0;
 $18 = (($6) + 1|0);
 HEAP8[$18>>0] = 0;
 __THREW__ = 0;
 (invoke_iii(2359,($9|0),($6|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if ($20) {
   $42 = ___cxa_find_matching_catch()|0;
   $43 = tempRet0;
   $44 = HEAP8[$6>>0]|0;
   $45 = $44 & 1;
   $46 = ($45<<24>>24)==(0);
   if ($46) {
    $$0 = $43;$$01 = $42;
   } else {
    $47 = (($6) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($48|0),($$byval_copy6|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     $51 = ___cxa_find_matching_catch()|0;
     $52 = tempRet0;
     ___cxa_call_unexpected(($51|0));
     // unreachable;
    } else {
     $$0 = $43;$$01 = $42;
    }
   }
  } else {
   $21 = HEAP8[$6>>0]|0;
   $22 = $21 & 1;
   $23 = ($22<<24>>24)==(0);
   if (!($23)) {
    $24 = (($6) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($25|0),($$byval_copy6|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     $28 = ___cxa_find_matching_catch()|0;
     $29 = tempRet0;
     ___cxa_call_unexpected(($28|0));
     // unreachable;
    }
   }
   HEAP8[$7>>0] = 0;
   $30 = (($7) + 1|0);
   HEAP8[$30>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($10|0),($7|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $53 = ___cxa_find_matching_catch()|0;
    $54 = tempRet0;
    $55 = HEAP8[$7>>0]|0;
    $56 = $55 & 1;
    $57 = ($56<<24>>24)==(0);
    if ($57) {
     $$0 = $54;$$01 = $53;
     break;
    }
    $58 = (($7) + 8|0);
    $59 = HEAP32[$58>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($59|0),($$byval_copy6|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if (!($61)) {
     $$0 = $54;$$01 = $53;
     break;
    }
    $62 = ___cxa_find_matching_catch()|0;
    $63 = tempRet0;
    ___cxa_call_unexpected(($62|0));
    // unreachable;
   }
   $33 = HEAP8[$7>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $36 = (($7) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($37|0),($$byval_copy6|0));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $64 = HEAP8[$10>>0]|0;
 $65 = $64 & 1;
 $66 = ($65<<24>>24)==(0);
 if (!($66)) {
  $67 = (($this) + 36|0);
  $68 = HEAP32[$67>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($68|0),($$byval_copy6|0));
  $69 = __THREW__; __THREW__ = 0;
  $70 = $69&1;
  if ($70) {
   $71 = ___cxa_find_matching_catch()|0;
   $72 = tempRet0;
   ___cxa_call_unexpected(($71|0));
   // unreachable;
  }
 }
 $73 = HEAP8[$9>>0]|0;
 $74 = $73 & 1;
 $75 = ($74<<24>>24)==(0);
 if (!($75)) {
  $76 = (($this) + 24|0);
  $77 = HEAP32[$76>>2]|0;
  HEAP32[$4>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($77|0),($$byval_copy6|0));
  $78 = __THREW__; __THREW__ = 0;
  $79 = $78&1;
  if ($79) {
   $80 = ___cxa_find_matching_catch()|0;
   $81 = tempRet0;
   ___cxa_call_unexpected(($80|0));
   // unreachable;
  }
 }
 $82 = HEAP8[$8>>0]|0;
 $83 = $82 & 1;
 $84 = ($83<<24>>24)==(0);
 if ($84) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $85 = (($this) + 12|0);
 $86 = HEAP32[$85>>2]|0;
 HEAP32[$5>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
 invoke_vii(2591,($86|0),($$byval_copy6|0));
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if ($88) {
  $89 = ___cxa_find_matching_catch()|0;
  $90 = tempRet0;
  ___cxa_call_unexpected(($89|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN9InputAxisC2ERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = 0, $$01 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy6 = sp + 48|0;
 $0 = sp + 44|0;
 $1 = sp + 40|0;
 $2 = sp + 36|0;
 $3 = sp + 32|0;
 $4 = sp + 16|0;
 $5 = sp + 12|0;
 $6 = sp;
 $7 = sp + 20|0;
 HEAP32[$this>>2] = ((612552 + 8|0));
 $8 = (($this) + 4|0);
 $9 = (($this) + 16|0);
 $10 = (($this) + 28|0);
 $11 = (($this) + 80|0);
 dest=$8+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$11>>2] = Math_fround(0.00100000004749745130539);
 $12 = (($this) + 76|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 84|0);
 HEAPF32[$13>>2] = Math_fround(0.100000001490116119385);
 $14 = (($this) + 89|0);
 HEAP8[$14>>0] = 0;
 $15 = (($this) + 88|0);
 HEAP8[$15>>0] = 0;
 $16 = (($this) + 64|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 0;
 $18 = HEAP8[$name>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  $25 = (($name) + 1|0);
  $26 = $18&255;
  $27 = $26 >>> 1;
  $29 = $27;$31 = $25;
 } else {
  $21 = (($name) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($name) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $29 = $24;$31 = $22;
 }
 $28 = ($29>>>0)>(10);
 do {
  if ($28) {
   $39 = (($29) + -10)|0;
   __THREW__ = 0;
   invoke_viiiiiiii(22,($8|0),10,($39|0),0,0,0,($29|0),($31|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    $66 = ___cxa_find_matching_catch()|0;
    $67 = tempRet0;
    $$0 = $67;$$01 = $66;
   } else {
    label = 9;
   }
  } else {
   $30 = (($8) + 1|0);
   _memmove(($30|0),($31|0),($29|0))|0;
   $32 = ((($8) + ($29)|0) + 1|0);
   HEAP8[$32>>0] = 0;
   $33 = HEAP8[$8>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    $37 = $29 << 1;
    $38 = $37&255;
    HEAP8[$8>>0] = $38;
    label = 9;
    break;
   } else {
    $36 = (($this) + 8|0);
    HEAP32[$36>>2] = $29;
    label = 9;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 9) {
   HEAP8[$6>>0] = 0;
   $42 = (($6) + 1|0);
   HEAP8[$42>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($9|0),($6|0))|0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    $70 = HEAP8[$6>>0]|0;
    $71 = $70 & 1;
    $72 = ($71<<24>>24)==(0);
    if ($72) {
     $$0 = $69;$$01 = $68;
     break;
    }
    $73 = (($6) + 8|0);
    $74 = HEAP32[$73>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($74|0),($$byval_copy6|0));
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if (!($76)) {
     $$0 = $69;$$01 = $68;
     break;
    }
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    ___cxa_call_unexpected(($77|0));
    // unreachable;
   }
   $45 = HEAP8[$6>>0]|0;
   $46 = $45 & 1;
   $47 = ($46<<24>>24)==(0);
   if (!($47)) {
    $48 = (($6) + 8|0);
    $49 = HEAP32[$48>>2]|0;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($49|0),($$byval_copy6|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     $52 = ___cxa_find_matching_catch()|0;
     $53 = tempRet0;
     ___cxa_call_unexpected(($52|0));
     // unreachable;
    }
   }
   HEAP8[$7>>0] = 0;
   $54 = (($7) + 1|0);
   HEAP8[$54>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($10|0),($7|0))|0);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if ($56) {
    $79 = ___cxa_find_matching_catch()|0;
    $80 = tempRet0;
    $81 = HEAP8[$7>>0]|0;
    $82 = $81 & 1;
    $83 = ($82<<24>>24)==(0);
    if ($83) {
     $$0 = $80;$$01 = $79;
     break;
    }
    $84 = (($7) + 8|0);
    $85 = HEAP32[$84>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($85|0),($$byval_copy6|0));
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if (!($87)) {
     $$0 = $80;$$01 = $79;
     break;
    }
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    ___cxa_call_unexpected(($88|0));
    // unreachable;
   }
   $57 = HEAP8[$7>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    STACKTOP = sp;return;
   }
   $60 = (($7) + 8|0);
   $61 = HEAP32[$60>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($61|0),($$byval_copy6|0));
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if ($63) {
    $64 = ___cxa_find_matching_catch()|0;
    $65 = tempRet0;
    ___cxa_call_unexpected(($64|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $90 = HEAP8[$10>>0]|0;
 $91 = $90 & 1;
 $92 = ($91<<24>>24)==(0);
 if (!($92)) {
  $93 = (($this) + 36|0);
  $94 = HEAP32[$93>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($94|0),($$byval_copy6|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   $97 = ___cxa_find_matching_catch()|0;
   $98 = tempRet0;
   ___cxa_call_unexpected(($97|0));
   // unreachable;
  }
 }
 $99 = HEAP8[$9>>0]|0;
 $100 = $99 & 1;
 $101 = ($100<<24>>24)==(0);
 if (!($101)) {
  $102 = (($this) + 24|0);
  $103 = HEAP32[$102>>2]|0;
  HEAP32[$4>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($103|0),($$byval_copy6|0));
  $104 = __THREW__; __THREW__ = 0;
  $105 = $104&1;
  if ($105) {
   $106 = ___cxa_find_matching_catch()|0;
   $107 = tempRet0;
   ___cxa_call_unexpected(($106|0));
   // unreachable;
  }
 }
 $108 = HEAP8[$8>>0]|0;
 $109 = $108 & 1;
 $110 = ($109<<24>>24)==(0);
 if ($110) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $111 = (($this) + 12|0);
 $112 = HEAP32[$111>>2]|0;
 HEAP32[$5>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
 invoke_vii(2591,($112|0),($$byval_copy6|0));
 $113 = __THREW__; __THREW__ = 0;
 $114 = $113&1;
 if ($114) {
  $115 = ___cxa_find_matching_catch()|0;
  $116 = tempRet0;
  ___cxa_call_unexpected(($115|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN9InputAxis6UpdateEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert8 = 0, $$pre = Math_fround(0), $$pre9 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0);
 var $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0);
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0);
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0;
 var $99 = Math_fround(0), $brmerge$demorgan = 0, $or$cond = 0, $or$cond11 = 0, $or$cond12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14GetTimeManagerv()|0);
 $1 = (($0) + 104|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 89|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($this) + 64|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround(-$7);
  HEAPF32[$6>>2] = $8;
 }
 $9 = (($this) + 60|0);
 $10 = HEAP32[$9>>2]|0;
 do {
  if ((($10|0) == 2)) {
   $156 = (__Z15GetInputManagerv()|0);
   $157 = (($this) + 56|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($this) + 72|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = (Math_fround(__ZNK12InputManager19GetJoystickPositionEii($156,$158,$160)));
   $162 = (($this) + 64|0);
   $163 = (($this) + 68|0);
   HEAPF32[$163>>2] = $161;
   $164 = (($this) + 84|0);
   $165 = Math_fround(HEAPF32[$164>>2]);
   $166 = Math_fround($165 * $161);
   HEAPF32[$162>>2] = $166;
   $167 = $166 > Math_fround(1.0);
   if ($167) {
    HEAPF32[$162>>2] = Math_fround(1.0);
    break;
   }
   $168 = $166 < Math_fround(-1.0);
   if ($168) {
    HEAPF32[$162>>2] = Math_fround(-1.0);
    break;
   }
   $169 = (($this) + 80|0);
   $170 = Math_fround(HEAPF32[$169>>2]);
   $171 = $166 < $170;
   $172 = Math_fround(-$170);
   $173 = $166 > $172;
   $or$cond = $171 & $173;
   if ($or$cond) {
    HEAPF32[$162>>2] = Math_fround(0.0);
    break;
   }
   $174 = $166 > Math_fround(0.0);
   if ($174) {
    $175 = Math_fround($166 - $170);
    $176 = Math_fround(Math_fround(1.0) - $170);
    $177 = Math_fround($175 / $176);
    $178 = Math_fround(Math_fround(1.0) - $177);
    $179 = Math_fround($178 * Math_fround(0.0));
    $180 = Math_fround($177 + $179);
    HEAPF32[$162>>2] = $180;
    break;
   } else {
    $181 = Math_fround(-$166);
    $182 = Math_fround($181 - $170);
    $183 = Math_fround(Math_fround(1.0) - $170);
    $184 = Math_fround($182 / $183);
    $185 = Math_fround($184 * Math_fround(-1.0));
    $186 = Math_fround(Math_fround(1.0) - $184);
    $187 = Math_fround($186 * Math_fround(0.0));
    $188 = Math_fround($185 + $187);
    HEAPF32[$162>>2] = $188;
    break;
   }
  } else if ((($10|0) == 0)) {
   $11 = (__Z15GetInputManagerv()|0);
   $12 = (($this) + 40|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 >>> 5;
   $15 = (($11) + 56|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($14<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = $13 & 31;
   $20 = 1 << $19;
   $21 = (($11) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + ($14<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $24 | $18;
   $26 = $25 & $20;
   $27 = ($26|0)==(0);
   if ($27) {
    $28 = (__Z15GetInputManagerv()|0);
    $29 = (($this) + 48|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = $30 >>> 5;
    $32 = (($28) + 56|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + ($31<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $30 & 31;
    $37 = 1 << $36;
    $38 = (($28) + 40|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + ($31<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $41 | $35;
    $43 = $42 & $37;
    $44 = ($43|0)!=(0);
    $80 = $44;
   } else {
    $80 = 1;
   }
   $45 = (__Z15GetInputManagerv()|0);
   $46 = (($this) + 44|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 >>> 5;
   $49 = (($45) + 56|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($50) + ($48<<2)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = $47 & 31;
   $54 = 1 << $53;
   $55 = (($45) + 40|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + ($48<<2)|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = $58 | $52;
   $60 = $59 & $54;
   $61 = ($60|0)==(0);
   if ($61) {
    $62 = (__Z15GetInputManagerv()|0);
    $63 = (($this) + 52|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = $64 >>> 5;
    $66 = (($62) + 56|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($67) + ($65<<2)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = $64 & 31;
    $71 = 1 << $70;
    $72 = (($62) + 40|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($73) + ($65<<2)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $75 | $69;
    $77 = $76 & $71;
    $78 = ($77|0)!=(0);
    $81 = $78;
   } else {
    $81 = 1;
   }
   $79 = (($this) + 68|0);
   HEAPF32[$79>>2] = Math_fround(0.0);
   $brmerge$demorgan = $80 & $81;
   if (!($brmerge$demorgan)) {
    if ($80) {
     $82 = (($this) + 88|0);
     $83 = HEAP8[$82>>0]|0;
     $84 = ($83<<24>>24)!=(0);
     $$phi$trans$insert = (($this) + 64|0);
     $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
     $85 = $$pre < Math_fround(0.0);
     $or$cond11 = $84 & $85;
     if ($or$cond11) {
      HEAPF32[$$phi$trans$insert>>2] = Math_fround(0.0);
      $86 = (($this) + 64|0);
      $101 = $86;$99 = Math_fround(0.0);
     } else {
      $87 = (($this) + 84|0);
      $88 = Math_fround(HEAPF32[$87>>2]);
      $89 = Math_fround($2 * $88);
      $90 = (($this) + 64|0);
      $91 = Math_fround($$pre + $89);
      HEAPF32[$90>>2] = $91;
      $92 = (($this) + 64|0);
      $93 = $91 < Math_fround(0.0);
      if ($93) {
       $94 = (($this) + 76|0);
       $95 = Math_fround(HEAPF32[$94>>2]);
       $96 = Math_fround($2 * $95);
       $97 = Math_fround($91 + $96);
       HEAPF32[$92>>2] = $97;
       $101 = $92;$99 = $97;
      } else {
       $101 = $92;$99 = $91;
      }
     }
     $98 = $99 < Math_fround(1.0);
     $100 = $98 ? $99 : Math_fround(1.0);
     HEAPF32[$101>>2] = $100;
     HEAPF32[$79>>2] = Math_fround(1.0);
     break;
    }
    if ($81) {
     $102 = (($this) + 88|0);
     $103 = HEAP8[$102>>0]|0;
     $104 = ($103<<24>>24)!=(0);
     $$phi$trans$insert8 = (($this) + 64|0);
     $$pre9 = Math_fround(HEAPF32[$$phi$trans$insert8>>2]);
     $105 = $$pre9 > Math_fround(0.0);
     $or$cond12 = $104 & $105;
     if ($or$cond12) {
      HEAPF32[$$phi$trans$insert8>>2] = Math_fround(0.0);
      $106 = (($this) + 64|0);
      $119 = Math_fround(0.0);$121 = $106;
     } else {
      $107 = (($this) + 84|0);
      $108 = Math_fround(HEAPF32[$107>>2]);
      $109 = Math_fround($2 * $108);
      $110 = (($this) + 64|0);
      $111 = Math_fround($$pre9 - $109);
      HEAPF32[$110>>2] = $111;
      $112 = (($this) + 64|0);
      $113 = $111 > Math_fround(0.0);
      if ($113) {
       $114 = (($this) + 76|0);
       $115 = Math_fround(HEAPF32[$114>>2]);
       $116 = Math_fround($2 * $115);
       $117 = Math_fround($111 - $116);
       HEAPF32[$112>>2] = $117;
       $119 = $117;$121 = $112;
      } else {
       $119 = $111;$121 = $112;
      }
     }
     $118 = $119 > Math_fround(-1.0);
     $120 = $118 ? $119 : Math_fround(-1.0);
     HEAPF32[$121>>2] = $120;
     HEAPF32[$79>>2] = Math_fround(-1.0);
     break;
    }
    $122 = (($this) + 76|0);
    $123 = Math_fround(HEAPF32[$122>>2]);
    $124 = $123 != Math_fround(0.0);
    if ($124) {
     $125 = (($this) + 64|0);
     $126 = Math_fround(HEAPF32[$125>>2]);
     $127 = $126 > Math_fround(0.0);
     if ($127) {
      $128 = Math_fround($2 * $123);
      $129 = Math_fround($126 - $128);
      HEAPF32[$125>>2] = $129;
      $130 = $129 < Math_fround(0.0);
      if (!($130)) {
       break;
      }
      HEAPF32[$125>>2] = Math_fround(0.0);
      break;
     }
     $131 = $126 < Math_fround(0.0);
     if ($131) {
      $132 = Math_fround($2 * $123);
      $133 = Math_fround($132 + $126);
      HEAPF32[$125>>2] = $133;
      $134 = $133 > Math_fround(0.0);
      if ($134) {
       HEAPF32[$125>>2] = Math_fround(0.0);
      }
     }
    }
   }
  } else if ((($10|0) == 1)) {
   $135 = (__Z15GetInputManagerv()|0);
   $136 = (($this) + 72|0);
   $137 = HEAP32[$136>>2]|0;
   if ((($137|0) == 0)) {
    $138 = (($135) + 84|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = (($this) + 64|0);
    HEAPF32[$140>>2] = $139;
    $152 = $139;
   } else if ((($137|0) == 1)) {
    $141 = (($135) + 88|0);
    $142 = Math_fround(HEAPF32[$141>>2]);
    $143 = (($this) + 64|0);
    HEAPF32[$143>>2] = $142;
    $152 = $142;
   } else if ((($137|0) == 3)) {
    $144 = (($135) + 92|0);
    $145 = Math_fround(HEAPF32[$144>>2]);
    $146 = (($this) + 64|0);
    HEAPF32[$146>>2] = $145;
    $152 = $145;
   } else {
    $147 = (($135) + 96|0);
    $148 = Math_fround(HEAPF32[$147>>2]);
    $149 = (($this) + 64|0);
    HEAPF32[$149>>2] = $148;
    $152 = $148;
   }
   $150 = (($this) + 64|0);
   $151 = (($this) + 68|0);
   HEAPF32[$151>>2] = $152;
   $153 = (($this) + 84|0);
   $154 = Math_fround(HEAPF32[$153>>2]);
   $155 = Math_fround($154 * $152);
   HEAPF32[$150>>2] = $155;
  }
 } while(0);
 $189 = HEAP8[$3>>0]|0;
 $190 = ($189<<24>>24)==(0);
 if ($190) {
  STACKTOP = sp;return;
 }
 $191 = (($this) + 64|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = Math_fround(-$192);
 HEAPF32[$191>>2] = $193;
 $194 = (($this) + 68|0);
 $195 = Math_fround(HEAPF32[$194>>2]);
 $196 = Math_fround(-$195);
 HEAPF32[$194>>2] = $196;
 STACKTOP = sp;return;
}
function __ZN9InputAxis13MakeAnalogKeyEiiii($this,$pos,$neg,$altpos,$altnegpos) {
 $this = $this|0;
 $pos = $pos|0;
 $neg = $neg|0;
 $altpos = $altpos|0;
 $altnegpos = $altnegpos|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = $pos;
 $1 = (($this) + 44|0);
 HEAP32[$1>>2] = $neg;
 $2 = (($this) + 48|0);
 HEAP32[$2>>2] = $altpos;
 $3 = (($this) + 52|0);
 HEAP32[$3>>2] = $altnegpos;
 $4 = (($this) + 60|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 84|0);
 HEAPF32[$5>>2] = Math_fround(3.0);
 $6 = (($this) + 76|0);
 HEAPF32[$6>>2] = Math_fround(3.0);
 $7 = (($this) + 88|0);
 HEAP8[$7>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9InputAxis10MakeButtonEii($this,$button,$altbutton) {
 $this = $this|0;
 $button = $button|0;
 $altbutton = $altbutton|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = $button;
 $1 = (($this) + 44|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 48|0);
 HEAP32[$2>>2] = $altbutton;
 $3 = (($this) + 52|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 60|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 84|0);
 HEAPF32[$5>>2] = Math_fround(1000.0);
 $6 = (($this) + 76|0);
 HEAPF32[$6>>2] = Math_fround(1000.0);
 $7 = (($this) + 88|0);
 HEAP8[$7>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9InputAxis9MakeMouseEi($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 HEAP32[$0>>2] = 1;
 $1 = (($this) + 72|0);
 HEAP32[$1>>2] = $a;
 $2 = (($this) + 80|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 84|0);
 HEAPF32[$3>>2] = Math_fround(0.100000001490116119385);
 STACKTOP = sp;return;
}
function __ZN9InputAxis12MakeJoystickEi($this,$a) {
 $this = $this|0;
 $a = $a|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 HEAP32[$0>>2] = 2;
 $1 = (($this) + 72|0);
 HEAP32[$1>>2] = $a;
 $2 = (($this) + 84|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 80|0);
 HEAPF32[$3>>2] = Math_fround(0.189999997615814208984);
 $4 = (($this) + 76|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 88|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 89|0);
 HEAP8[$6>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__1plIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEENS_12basic_stringIT_T0_T1_EERKSA_PKS7_($agg$result,$__lhs,$__rhs) {
 $agg$result = $agg$result|0;
 $__lhs = $__lhs|0;
 $__rhs = $__rhs|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $2 = HEAP8[$__lhs>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $10 = $2&255;
  $11 = $10 >>> 1;
  $12 = (_strlen(($__rhs|0))|0);
  $13 = (($__lhs) + 1|0);
  $15 = $12;$16 = $11;$32 = $13;
 } else {
  $5 = (($__lhs) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (_strlen(($__rhs|0))|0);
  $8 = (($__lhs) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $15 = $7;$16 = $6;$32 = $9;
 }
 $14 = (($15) + ($16))|0;
 $17 = ($14>>>0)>(2147483631);
 do {
  if ($17) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    // unreachable;
   }
  } else {
   $20 = ($14>>>0)<(11);
   if ($20) {
    $21 = $16 << 1;
    $22 = $21&255;
    HEAP8[$agg$result>>0] = $22;
    $23 = (($agg$result) + 1|0);
    $__p$0$i = $23;
   } else {
    $24 = (($14) + 16)|0;
    $25 = $24 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (invoke_iiiiiii(102,($25|0),16,($$byval_copy1|0),0,(612568|0),79)|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = (($agg$result) + 8|0);
    HEAP32[$29>>2] = $26;
    $30 = $25 | 1;
    HEAP32[$agg$result>>2] = $30;
    $31 = (($agg$result) + 4|0);
    HEAP32[$31>>2] = $16;
    $__p$0$i = $26;
   }
   _memcpy(($__p$0$i|0),($32|0),($16|0))|0;
   $33 = (($__p$0$i) + ($16)|0);
   HEAP8[$33>>0] = 0;
   __THREW__ = 0;
   (invoke_iiii(1548,($agg$result|0),($__rhs|0),($15|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = HEAP8[$agg$result>>0]|0;
 $39 = $38 & 1;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  ___resumeException($36|0);
  // unreachable;
 }
 $41 = (($agg$result) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($42|0),($$byval_copy1|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  ___cxa_call_unexpected(($45|0));
  // unreachable;
 } else {
  ___resumeException($36|0);
  // unreachable;
 }
}
function __ZNK9InputAxis11GetValueRawEv($this) {
 $this = $this|0;
 var $$0 = Math_fround(0), $$0$in = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 68|0);
 $4 = (($this) + 64|0);
 $$0$in = $2 ? $3 : $4;
 $$0 = Math_fround(HEAPF32[$$0$in>>2]);
 STACKTOP = sp;return (Math_fround($$0));
}
function __Z26RegisterClass_InputManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(13,141,142,0,143);
 STACKTOP = sp;return;
}
function __ZN12InputManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 12;
 dest=$3+0|0; src=612576+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 12|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,13,6,($0|0),180,(2411|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN12InputManager15InitializeClassEv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628392>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy1,0,16,613072,317)|0);
 $4 = (($3) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 8|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$3>>2] = $4;
 HEAP32[613080>>2] = $3;
 $6 = HEAP32[628392>>2]|0;
 HEAP32[$1>>2] = $6;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $7 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy1,0,16,613072,318)|0);
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($7) + 8|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$7>>2] = $8;
 HEAP32[613088>>2] = $7;
 __Z19SetupKeyNameMappingv();
 STACKTOP = sp;return;
}
function __ZN12InputManager12CleanupClassEv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[613080>>2]|0;
 $2 = HEAP32[628392>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIiS8_NS_4lessIiEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($1,$5);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy1);
 HEAP32[613080>>2] = 0;
 $6 = HEAP32[613088>>2]|0;
 $7 = HEAP32[628392>>2]|0;
 $8 = ($6|0)==(0|0);
 if ($8) {
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy1);
  HEAP32[613088>>2] = 0;
  STACKTOP = sp;return;
 }
 $9 = (($6) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($6,$10);
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy1);
 HEAP32[613088>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12InputManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(180,$$byval_copy2,1,16,613072,42)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1762,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(613072|0),42);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK12InputManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 13;
}
function __ZN12InputManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,612592,612576,$this,0);
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 24|0);
 __ZN13ProxyTransfer8TransferINSt3__16vectorI9InputAxisNS1_9allocatorIS3_EEEEEEvRT_PKc17TransferMetaFlags($transfer,$0,615696,2048);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12InputManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,612592,612576,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN12InputManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12InputManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI9InputAxisNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 STACKTOP = sp;return;
}
function __ZN12InputManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI9InputAxisNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 STACKTOP = sp;return;
}
function __ZN12InputManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $size$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i = sp;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 92)&-1;
 HEAP32[$size$i$i$i$i$i$i>>2] = $7;
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i$i$i$i,4);
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==($14|0);
 if ($16) {
  STACKTOP = sp;return;
 } else {
  $17 = $15;
 }
 while(1) {
  __ZN9InputAxis8TransferI19StreamedBinaryWriteILb0EEEEvRT_($17,$transfer);
  $18 = (($17) + 92|0);
  $19 = ($18|0)==($14|0);
  if ($19) {
   break;
  } else {
   $17 = $18;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12InputManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __Z15GetInputManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(1)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12InputManagerC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$01 = 0, $$01$i$i = 0, $$byval_copy31 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$pre$pre = 0, $$pre58 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $axes = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body14$index5Z2D = 0, $eh$lpad$body14$indexZ2D = 0, $i$054 = 0, $j$032 = 0, $lpad$phi37$index = 0, $lpad$phi37$index13 = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep4$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0, $uglygep3$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep4$i$i = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy31 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $axes = sp + 16|0;
 $4 = HEAP32[$label>>2]|0;
 HEAP32[$3>>2] = $4;
 ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$3+0>>2]|0;
 __ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy31,$mode);
 HEAP32[$this>>2] = ((612600 + 8|0));
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 44|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 48|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 40|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 60|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 64|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 56|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 76|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 80|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 72|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 100|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($this) + 104|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($this) + 112|0);
 $23 = (($this) + 116|0);
 $24 = (($this) + 120|0);
 $25 = (($this) + 124|0);
 $26 = (($this) + 136|0);
 dest=$22+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vi(3509,($this|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  label = 23;
 } else {
  __THREW__ = 0;
  invoke_viii(1763,($8|0),570,0);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 23;
  } else {
   __THREW__ = 0;
   invoke_viii(1763,($12|0),570,0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 23;
   } else {
    __THREW__ = 0;
    invoke_viii(1763,($16|0),570,0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     label = 23;
    } else {
     $35 = (($this) + 84|0);
     $36 = (($this) + 108|0);
     ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;HEAP32[$35+20>>2]=0|0;
     HEAP8[$36>>0] = 1;
     $37 = (($this) + 176|0);
     HEAP8[$37>>0] = 0;
     $38 = (($this) + 156|0);
     HEAP8[$38>>0] = 0;
     $39 = (($this) + 164|0);
     HEAP8[$39>>0] = 0;
     $40 = (($this) + 177|0);
     HEAP8[$40>>0] = 1;
     $41 = (($axes) + 4|0);
     $42 = (($axes) + 8|0);
     $i$054 = 0;
     L6: while(1) {
      HEAP32[$axes>>2] = 0;
      HEAP32[$41>>2] = 0;
      HEAP32[$42>>2] = 0;
      $44 = 0;$45 = 0;$50 = 0;$j$032 = 0;
      while(1) {
       $43 = ($44|0)==($45|0);
       if ($43) {
        $48 = $45;
        $49 = $50;
        $51 = (($48) - ($49))|0;
        $52 = $51 >> 2;
        $53 = (($52) + 1)|0;
        $54 = ($53>>>0)>(1073741823);
        if ($54) {
         label = 12;
         break L6;
        }
        $57 = ($52>>>0)<(536870911);
        if ($57) {
         $58 = $51 >> 1;
         $59 = ($58>>>0)<($53>>>0);
         $60 = $59 ? $53 : $58;
         $61 = ($60|0)==(0);
         if ($61) {
          $$0$i3$i$i = 0;$67 = 0;
         } else {
          $$0$i2$i$i = $60;
          label = 16;
         }
        } else {
         $$0$i2$i$i = 1073741823;
         label = 16;
        }
        if ((label|0) == 16) {
         label = 0;
         $62 = $$0$i2$i$i << 2;
         __THREW__ = 0;
         $63 = (invoke_ii(2988,($62|0))|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          label = 24;
          break L6;
         }
         $$0$i3$i$i = $$0$i2$i$i;$67 = $63;
        }
        $66 = (($67) + ($52<<2)|0);
        $68 = (($67) + ($$0$i3$i$i<<2)|0);
        $69 = ($66|0)==(0|0);
        if (!($69)) {
         HEAPF32[$66>>2] = Math_fround(0.0);
        }
        $70 = (($67) + ($53<<2)|0);
        _memcpy(($67|0),($50|0),($51|0))|0;
        HEAP32[$axes>>2] = $67;
        HEAP32[$41>>2] = $70;
        HEAP32[$42>>2] = $68;
        $71 = ($50|0)==(0|0);
        if ($71) {
         $212 = $68;$96 = $70;$98 = $67;
        } else {
         __ZdlPv($50);
         $212 = $68;$96 = $70;$98 = $67;
        }
       } else {
        $46 = ($44|0)==(0|0);
        if (!($46)) {
         HEAPF32[$44>>2] = Math_fround(0.0);
        }
        $47 = (($44) + 4|0);
        HEAP32[$41>>2] = $47;
        $212 = $45;$96 = $47;$98 = $50;
       }
       $72 = (($j$032) + 1)|0;
       $73 = ($72|0)<(20);
       if ($73) {
        $44 = $96;$45 = $212;$50 = $98;$j$032 = $72;
       } else {
        break;
       }
      }
      $89 = HEAP32[$23>>2]|0;
      $90 = HEAP32[$24>>2]|0;
      $91 = ($89|0)==($90|0);
      if ($91) {
       __THREW__ = 0;
       invoke_vii(2743,($22|0),($axes|0));
       $132 = __THREW__; __THREW__ = 0;
       $133 = $132&1;
       if ($133) {
        label = 25;
        break;
       }
       $$pre58 = HEAP32[$axes>>2]|0;
       $135 = $$pre58;
      } else {
       $92 = ($89|0)==(0|0);
       if ($92) {
        $131 = 0;
       } else {
        HEAP32[$89>>2] = 0;
        $93 = (($89) + 4|0);
        HEAP32[$93>>2] = 0;
        $94 = (($89) + 8|0);
        HEAP32[$94>>2] = 0;
        $95 = $96;
        $97 = $98;
        $99 = (($95) - ($97))|0;
        $100 = $99 >> 2;
        $101 = ($100|0)==(0);
        if (!($101)) {
         $102 = ($100>>>0)>(1073741823);
         if ($102) {
          label = 35;
          break;
         }
         __THREW__ = 0;
         $105 = (invoke_ii(2988,($99|0))|0);
         $106 = __THREW__; __THREW__ = 0;
         $107 = $106&1;
         if ($107) {
          label = 44;
          break;
         }
         HEAP32[$93>>2] = $105;
         HEAP32[$89>>2] = $105;
         $108 = (($105) + ($100<<2)|0);
         HEAP32[$94>>2] = $108;
         $109 = ($98|0)==($96|0);
         if (!($109)) {
          $scevgep$i$i = (($96) + -4|0);
          $110 = (0 - ($97))|0;
          $uglygep$i$i = (($scevgep$i$i) + ($110)|0);
          $uglygep4$i$i = $uglygep$i$i;
          $$01$i$i = $98;$112 = $105;
          while(1) {
           $111 = ($112|0)==(0|0);
           if (!($111)) {
            $113 = Math_fround(HEAPF32[$$01$i$i>>2]);
            HEAPF32[$112>>2] = $113;
           }
           $114 = (($112) + 4|0);
           $115 = (($$01$i$i) + 4|0);
           $116 = ($115|0)==($96|0);
           if ($116) {
            break;
           } else {
            $$01$i$i = $115;$112 = $114;
           }
          }
          $117 = $uglygep4$i$i >>> 2;
          $118 = (($117) + 1)|0;
          $scevgep5$i$i = (($105) + ($118<<2)|0);
          HEAP32[$93>>2] = $scevgep5$i$i;
         }
        }
        $$pre$i = HEAP32[$23>>2]|0;
        $131 = $$pre$i;
       }
       $130 = (($131) + 12|0);
       HEAP32[$23>>2] = $130;
       $135 = $98;
      }
      $134 = ($135|0)==(0|0);
      if (!($134)) {
       $136 = HEAP32[$41>>2]|0;
       $137 = ($136|0)==($135|0);
       if (!($137)) {
        $__new_last2$i$i$i$i$i15 = $135;
        $scevgep$i$i$i$i$i16 = (($136) + -4|0);
        $138 = (0 - ($__new_last2$i$i$i$i$i15))|0;
        $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($138)|0);
        $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
        $139 = $uglygep3$i$i$i$i$i19 >>> 2;
        $140 = $139 ^ -1;
        $scevgep4$i$i$i$i$i20 = (($136) + ($140<<2)|0);
        HEAP32[$41>>2] = $scevgep4$i$i$i$i$i20;
       }
       __ZdlPv($135);
      }
      $141 = (($i$054) + 1)|0;
      $142 = ($141|0)<(12);
      if ($142) {
       $i$054 = $141;
      } else {
       label = 59;
       break;
      }
     }
     do {
      if ((label|0) == 12) {
       __THREW__ = 0;
       invoke_vi(3308,0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        $80 = ___cxa_find_matching_catch()|0;
        $81 = tempRet0;
        $83 = $50;$eh$lpad$body14$index5Z2D = $81;$eh$lpad$body14$indexZ2D = $80;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 24) {
       $76 = ___cxa_find_matching_catch()|0;
       $77 = tempRet0;
       $83 = $50;$eh$lpad$body14$index5Z2D = $77;$eh$lpad$body14$indexZ2D = $76;
      }
      else if ((label|0) == 25) {
       $78 = ___cxa_find_matching_catch()|0;
       $79 = tempRet0;
       $$pre$pre$pre = HEAP32[$axes>>2]|0;
       $83 = $$pre$pre$pre;$eh$lpad$body14$index5Z2D = $79;$eh$lpad$body14$indexZ2D = $78;
      }
      else if ((label|0) == 35) {
       __THREW__ = 0;
       invoke_vi(3308,0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        $121 = ___cxa_find_matching_catch()|0;
        $122 = tempRet0;
        $lpad$phi37$index = $121;$lpad$phi37$index13 = $122;
        label = 46;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 44) {
       $119 = ___cxa_find_matching_catch()|0;
       $120 = tempRet0;
       $lpad$phi37$index = $119;$lpad$phi37$index13 = $120;
       label = 46;
      }
      else if ((label|0) == 59) {
       $143 = (($this) + 157|0);
       HEAP8[$143>>0] = 1;
       $144 = (($this) + 160|0);
       HEAP32[$144>>2] = 0;
       STACKTOP = sp;return;
      }
     } while(0);
     if ((label|0) == 46) {
      $123 = HEAP32[$89>>2]|0;
      $124 = ($123|0)==(0|0);
      if ($124) {
       $83 = $98;$eh$lpad$body14$index5Z2D = $lpad$phi37$index13;$eh$lpad$body14$indexZ2D = $lpad$phi37$index;
      } else {
       $125 = HEAP32[$93>>2]|0;
       $126 = ($125|0)==($123|0);
       if (!($126)) {
        $__new_last2$i$i$i$i = $123;
        $scevgep$i$i$i$i = (($125) + -4|0);
        $127 = (0 - ($__new_last2$i$i$i$i))|0;
        $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($127)|0);
        $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
        $128 = $uglygep3$i$i$i$i >>> 2;
        $129 = $128 ^ -1;
        $scevgep4$i$i$i$i = (($125) + ($129<<2)|0);
        HEAP32[$93>>2] = $scevgep4$i$i$i$i;
       }
       __ZdlPv($123);
       $83 = $98;$eh$lpad$body14$index5Z2D = $lpad$phi37$index13;$eh$lpad$body14$indexZ2D = $lpad$phi37$index;
      }
     }
     $82 = ($83|0)==(0|0);
     if ($82) {
      $$0 = $eh$lpad$body14$index5Z2D;$$01 = $eh$lpad$body14$indexZ2D;
     } else {
      $84 = HEAP32[$41>>2]|0;
      $85 = ($84|0)==($83|0);
      if (!($85)) {
       $__new_last2$i$i$i$i$i = $83;
       $scevgep$i$i$i$i$i = (($84) + -4|0);
       $86 = (0 - ($__new_last2$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($86)|0);
       $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
       $87 = $uglygep3$i$i$i$i$i >>> 2;
       $88 = $87 ^ -1;
       $scevgep4$i$i$i$i$i = (($84) + ($88<<2)|0);
       HEAP32[$41>>2] = $scevgep4$i$i$i$i$i;
      }
      __ZdlPv($83);
      $$0 = $eh$lpad$body14$index5Z2D;$$01 = $eh$lpad$body14$indexZ2D;
     }
    }
   }
  }
 }
 if ((label|0) == 23) {
  $74 = ___cxa_find_matching_catch()|0;
  $75 = tempRet0;
  $$0 = $75;$$01 = $74;
 }
 $145 = HEAP8[$26>>0]|0;
 $146 = $145 & 1;
 $147 = ($146<<24>>24)==(0);
 if (!($147)) {
  $148 = (($this) + 144|0);
  $149 = HEAP32[$148>>2]|0;
  __ZdlPv($149);
 }
 $150 = HEAP8[$25>>0]|0;
 $151 = $150 & 1;
 $152 = ($151<<24>>24)==(0);
 if (!($152)) {
  $153 = (($this) + 132|0);
  $154 = HEAP32[$153>>2]|0;
  __ZdlPv($154);
 }
 $155 = HEAP32[$22>>2]|0;
 $156 = ($155|0)==(0|0);
 if (!($156)) {
  $157 = HEAP32[$23>>2]|0;
  $158 = ($157|0)==($155|0);
  if ($158) {
   $171 = $155;
  } else {
   $160 = $157;
   while(1) {
    $159 = (($160) + -12|0);
    HEAP32[$23>>2] = $159;
    $161 = HEAP32[$159>>2]|0;
    $162 = ($161|0)==(0|0);
    if ($162) {
     $164 = $159;
    } else {
     $165 = (($160) + -8|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = ($166|0)==($161|0);
     if (!($167)) {
      $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = $161;
      $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = (($166) + -4|0);
      $168 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i) + ($168)|0);
      $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i;
      $169 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
      $170 = $169 ^ -1;
      $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = (($166) + ($170<<2)|0);
      HEAP32[$165>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i;
     }
     __ZdlPv($161);
     $$pre$i$i$i$i$i = HEAP32[$23>>2]|0;
     $164 = $$pre$i$i$i$i$i;
    }
    $163 = ($164|0)==($155|0);
    if ($163) {
     break;
    } else {
     $160 = $164;
    }
   }
   $$pre$i$i$i = HEAP32[$22>>2]|0;
   $171 = $$pre$i$i$i;
  }
  __ZdlPv($171);
 }
 $172 = HEAP32[$19>>2]|0;
 $173 = HEAP32[$16>>2]|0;
 HEAP32[$1>>2] = $173;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($172|0),($$byval_copy31|0));
 $174 = __THREW__; __THREW__ = 0;
 $175 = $174&1;
 do {
  if (!($175)) {
   $176 = HEAP32[$15>>2]|0;
   $177 = HEAP32[$12>>2]|0;
   HEAP32[$0>>2] = $177;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($176|0),($$byval_copy31|0));
   $178 = __THREW__; __THREW__ = 0;
   $179 = $178&1;
   if (!($179)) {
    $180 = HEAP32[$11>>2]|0;
    $181 = HEAP32[$8>>2]|0;
    HEAP32[$2>>2] = $181;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($180|0),($$byval_copy31|0));
    $182 = __THREW__; __THREW__ = 0;
    $183 = $182&1;
    if (!($183)) {
     __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($5);
     HEAP32[$this>>2] = ((561192 + 8|0));
     __THREW__ = 0;
     $184 = __THREW__; __THREW__ = 0;
     $185 = $184&1;
     if (!($185)) {
      HEAP32[$this>>2] = ((561376 + 8|0));
      __THREW__ = 0;
      $186 = __THREW__; __THREW__ = 0;
      $187 = $186&1;
      if (!($187)) {
       __THREW__ = 0;
       $194 = __THREW__; __THREW__ = 0;
       $195 = $194&1;
       if ($195) {
        break;
       }
       ___resumeException($$01|0);
       // unreachable;
      }
      $188 = ___cxa_find_matching_catch(0|0)|0;
      $189 = tempRet0;
      __THREW__ = 0;
      $190 = __THREW__; __THREW__ = 0;
      $191 = $190&1;
      if ($191) {
       $192 = ___cxa_find_matching_catch(0|0)|0;
       $193 = tempRet0;
       ___clang_call_terminate($192);
       // unreachable;
      } else {
       $eh$lpad$body$indexZ2D = $188;
       ___clang_call_terminate($eh$lpad$body$indexZ2D);
       // unreachable;
      }
     }
     $196 = ___cxa_find_matching_catch(0|0)|0;
     $197 = tempRet0;
     HEAP32[$this>>2] = ((561376 + 8|0));
     __THREW__ = 0;
     $198 = __THREW__; __THREW__ = 0;
     $199 = $198&1;
     if ($199) {
      $202 = ___cxa_find_matching_catch(0|0)|0;
      $203 = tempRet0;
      __THREW__ = 0;
      $204 = __THREW__; __THREW__ = 0;
      $205 = $204&1;
      if ($205) {
       $206 = ___cxa_find_matching_catch(0|0)|0;
       $207 = tempRet0;
       ___clang_call_terminate($206);
       // unreachable;
      } else {
       $eh$lpad$body$i$indexZ2D = $202;
       ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
       // unreachable;
      }
     }
     __THREW__ = 0;
     $200 = __THREW__; __THREW__ = 0;
     $201 = $200&1;
     if (!($201)) {
      $eh$lpad$body$indexZ2D = $196;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
     $208 = ___cxa_find_matching_catch(0|0)|0;
     $209 = tempRet0;
     $eh$lpad$body$i$indexZ2D = $208;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
  }
 } while(0);
 $210 = ___cxa_find_matching_catch(0|0)|0;
 $211 = tempRet0;
 $eh$lpad$body$indexZ2D = $210;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN12InputManager11MakeDefaultEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i = 0, $$0$i104 = 0, $$0$i113 = 0, $$0$i172 = 0, $$0$i181 = 0, $$0$i190 = 0, $$0$i199 = 0, $$0$i208 = 0, $$0$i217 = 0, $$0$i226 = 0, $$0$i342 = 0, $$0$i350 = 0, $$0$i358 = 0, $$0$i366 = 0, $$0$i57 = 0, $$0$i66 = 0, $$0$i75 = 0, $$0$i86 = 0, $$0$i95 = 0;
 var $$01 = 0, $$1 = 0, $$10 = 0, $$1019 = 0, $$11 = 0, $$110 = 0, $$1120 = 0, $$15 = 0, $$1524 = 0, $$16 = 0, $$1625 = 0, $$17 = 0, $$1726 = 0, $$18 = 0, $$1827 = 0, $$19 = 0, $$1928 = 0, $$20 = 0, $$2029 = 0, $$21 = 0;
 var $$2130 = 0, $$22 = 0, $$2231 = 0, $$23 = 0, $$2332 = 0, $$24 = 0, $$2433 = 0, $$8 = 0, $$817 = 0, $$9 = 0, $$918 = 0, $$byval_copy89 = 0, $$pre$i = 0, $$pre$i122 = 0, $$pre$i134 = 0, $$pre$i146 = 0, $$pre$i158 = 0, $$pre$i232 = 0, $$pre$i244 = 0, $$pre$i256 = 0;
 var $$pre$i268 = 0, $$pre$i280 = 0, $$pre$i292 = 0, $$pre$i304 = 0, $$pre$i316 = 0, $$pre$i328 = 0, $$pre$i38 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0;
 var $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0;
 var $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0;
 var $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0;
 var $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0;
 var $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0;
 var $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0;
 var $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0;
 var $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0;
 var $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0;
 var $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0;
 var $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0;
 var $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0;
 var $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0;
 var $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0;
 var $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0;
 var $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0;
 var $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0;
 var $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0;
 var $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0;
 var $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0;
 var $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0;
 var $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0;
 var $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0;
 var $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0;
 var $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0;
 var $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0;
 var $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0;
 var $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0;
 var $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0;
 var $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0;
 var $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0;
 var $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0;
 var $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0;
 var $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0;
 var $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0;
 var $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0;
 var $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0;
 var $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0;
 var $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0;
 var $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0;
 var $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0;
 var $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0;
 var $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0;
 var $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0;
 var $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0;
 var $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0;
 var $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0;
 var $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0;
 var $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0;
 var $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0;
 var $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0;
 var $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0;
 var $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0;
 var $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0;
 var $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0;
 var $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0;
 var $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0;
 var $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0;
 var $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0;
 var $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0;
 var $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0;
 var $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0;
 var $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0;
 var $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0;
 var $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0;
 var $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0;
 var $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0;
 var $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0;
 var $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0;
 var $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0;
 var $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2160|0;
 $$byval_copy89 = sp + 2148|0;
 $0 = sp + 2144|0;
 $1 = sp + 2140|0;
 $2 = sp + 2136|0;
 $3 = sp + 2132|0;
 $4 = sp + 2128|0;
 $5 = sp + 2124|0;
 $6 = sp + 2120|0;
 $7 = sp + 2116|0;
 $8 = sp + 2112|0;
 $9 = sp + 2108|0;
 $10 = sp + 2104|0;
 $11 = sp + 2100|0;
 $12 = sp + 2096|0;
 $13 = sp + 2092|0;
 $14 = sp + 2088|0;
 $15 = sp + 2084|0;
 $16 = sp + 2080|0;
 $17 = sp + 2076|0;
 $18 = sp + 2072|0;
 $19 = sp + 2068|0;
 $20 = sp + 2064|0;
 $21 = sp + 2060|0;
 $22 = sp + 2056|0;
 $23 = sp + 2052|0;
 $24 = sp + 2048|0;
 $25 = sp + 2044|0;
 $26 = sp + 2040|0;
 $27 = sp + 2036|0;
 $28 = sp + 2032|0;
 $29 = sp + 2028|0;
 $30 = sp + 2024|0;
 $31 = sp + 2020|0;
 $32 = sp + 2016|0;
 $33 = sp + 2012|0;
 $34 = sp + 2008|0;
 $35 = sp + 2004|0;
 $36 = sp + 2000|0;
 $37 = sp + 1996|0;
 $38 = sp + 1992|0;
 $39 = sp + 1988|0;
 $40 = sp + 1984|0;
 $41 = sp + 1980|0;
 $42 = sp + 1976|0;
 $43 = sp + 1972|0;
 $44 = sp + 1968|0;
 $45 = sp + 1964|0;
 $46 = sp + 1960|0;
 $47 = sp + 1956|0;
 $48 = sp + 1952|0;
 $49 = sp + 1948|0;
 $50 = sp + 1944|0;
 $51 = sp + 1940|0;
 $52 = sp + 1936|0;
 $53 = sp + 1932|0;
 $54 = sp + 1928|0;
 $55 = sp + 1924|0;
 $56 = sp + 1920|0;
 $57 = sp + 1916|0;
 $58 = sp + 1912|0;
 $59 = sp + 1908|0;
 $60 = sp + 1904|0;
 $61 = sp + 1900|0;
 $62 = sp + 1896|0;
 $63 = sp + 1892|0;
 $64 = sp + 1888|0;
 $65 = sp + 1884|0;
 $66 = sp + 1880|0;
 $67 = sp + 1876|0;
 $68 = sp + 1872|0;
 $69 = sp + 1868|0;
 $70 = sp + 484|0;
 $71 = sp + 480|0;
 $72 = sp + 476|0;
 $73 = sp + 472|0;
 $74 = sp + 468|0;
 $75 = sp + 464|0;
 $76 = sp + 460|0;
 $77 = sp + 456|0;
 $78 = sp + 452|0;
 $79 = sp + 448|0;
 $80 = sp + 444|0;
 $81 = sp + 440|0;
 $82 = sp + 436|0;
 $83 = sp + 432|0;
 $84 = sp + 428|0;
 $85 = sp + 424|0;
 $86 = sp + 420|0;
 $87 = sp + 416|0;
 $88 = sp + 224|0;
 $89 = sp;
 $90 = sp + 4|0;
 $91 = sp + 96|0;
 $92 = sp + 108|0;
 $93 = sp + 200|0;
 $94 = sp + 212|0;
 $95 = sp + 228|0;
 $96 = sp + 240|0;
 $97 = sp + 252|0;
 $98 = sp + 264|0;
 $99 = sp + 276|0;
 $100 = sp + 288|0;
 $101 = sp + 300|0;
 $102 = sp + 312|0;
 $103 = sp + 404|0;
 $104 = sp + 488|0;
 $105 = sp + 580|0;
 $106 = sp + 592|0;
 $107 = sp + 684|0;
 $108 = sp + 696|0;
 $109 = sp + 788|0;
 $110 = sp + 800|0;
 $111 = sp + 812|0;
 $112 = sp + 824|0;
 $113 = sp + 836|0;
 $114 = sp + 848|0;
 $115 = sp + 860|0;
 $116 = sp + 872|0;
 $117 = sp + 884|0;
 $118 = sp + 976|0;
 $119 = sp + 988|0;
 $120 = sp + 1080|0;
 $121 = sp + 1092|0;
 $122 = sp + 1184|0;
 $123 = sp + 1196|0;
 $124 = sp + 1288|0;
 $125 = sp + 1300|0;
 $126 = sp + 1392|0;
 $127 = sp + 1404|0;
 $128 = sp + 1496|0;
 $129 = sp + 1508|0;
 $130 = sp + 1600|0;
 $131 = sp + 1612|0;
 $132 = sp + 1704|0;
 $133 = sp + 1716|0;
 $134 = sp + 1808|0;
 $135 = sp + 1820|0;
 $136 = sp + 1832|0;
 $137 = sp + 1844|0;
 $138 = sp + 1856|0;
 $139 = (($this) + 24|0);
 HEAP8[$91>>0] = 20;
 $140 = (($91) + 1|0);
 dest=$140+0|0; src=612808+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $141 = (($91) + 11|0);
 HEAP8[$141>>0] = 0;
 __THREW__ = 0;
 invoke_vii(2744,($90|0),($91|0));
 $142 = __THREW__; __THREW__ = 0;
 $143 = $142&1;
 do {
  if ($143) {
   $1201 = ___cxa_find_matching_catch()|0;
   $1202 = tempRet0;
   $$0 = $1202;$$01 = $1201;
  } else {
   $144 = (($this) + 28|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = (($this) + 32|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ($145|0)==($147|0);
   do {
    if ($148) {
     __THREW__ = 0;
     invoke_vii(2746,($139|0),($90|0));
     $154 = __THREW__; __THREW__ = 0;
     $155 = $154&1;
     if ($155) {
      label = 359;
     }
    } else {
     $149 = ($145|0)==(0|0);
     if ($149) {
      $153 = 0;
     } else {
      __THREW__ = 0;
      invoke_vii(2745,($145|0),($90|0));
      $150 = __THREW__; __THREW__ = 0;
      $151 = $150&1;
      if ($151) {
       label = 359;
       break;
      }
      $$pre$i = HEAP32[$144>>2]|0;
      $153 = $$pre$i;
     }
     $152 = (($153) + 92|0);
     HEAP32[$144>>2] = $152;
    }
   } while(0);
   if ((label|0) == 359) {
    $1203 = ___cxa_find_matching_catch()|0;
    $1204 = tempRet0;
    HEAP32[$90>>2] = ((612552 + 8|0));
    $1205 = (($90) + 28|0);
    $1206 = HEAP8[$1205>>0]|0;
    $1207 = $1206 & 1;
    $1208 = ($1207<<24>>24)==(0);
    if (!($1208)) {
     $1209 = (($90) + 36|0);
     $1210 = HEAP32[$1209>>2]|0;
     HEAP32[$44>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$44+0>>2]|0;
     invoke_vii(2591,($1210|0),($$byval_copy89|0));
     $1211 = __THREW__; __THREW__ = 0;
     $1212 = $1211&1;
     if ($1212) {
      $1213 = ___cxa_find_matching_catch()|0;
      $1214 = tempRet0;
      ___cxa_call_unexpected(($1213|0));
      // unreachable;
     }
    }
    $1215 = (($90) + 16|0);
    $1216 = HEAP8[$1215>>0]|0;
    $1217 = $1216 & 1;
    $1218 = ($1217<<24>>24)==(0);
    if (!($1218)) {
     $1219 = (($90) + 24|0);
     $1220 = HEAP32[$1219>>2]|0;
     HEAP32[$43>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$43+0>>2]|0;
     invoke_vii(2591,($1220|0),($$byval_copy89|0));
     $1221 = __THREW__; __THREW__ = 0;
     $1222 = $1221&1;
     if ($1222) {
      $1223 = ___cxa_find_matching_catch()|0;
      $1224 = tempRet0;
      ___cxa_call_unexpected(($1223|0));
      // unreachable;
     }
    }
    $1225 = (($90) + 4|0);
    $1226 = HEAP8[$1225>>0]|0;
    $1227 = $1226 & 1;
    $1228 = ($1227<<24>>24)==(0);
    if ($1228) {
     $$0 = $1204;$$01 = $1203;
     break;
    }
    $1229 = (($90) + 12|0);
    $1230 = HEAP32[$1229>>2]|0;
    HEAP32[$42>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$42+0>>2]|0;
    invoke_vii(2591,($1230|0),($$byval_copy89|0));
    $1231 = __THREW__; __THREW__ = 0;
    $1232 = $1231&1;
    if (!($1232)) {
     $$0 = $1204;$$01 = $1203;
     break;
    }
    $1233 = ___cxa_find_matching_catch()|0;
    $1234 = tempRet0;
    ___cxa_call_unexpected(($1233|0));
    // unreachable;
   }
   HEAP32[$90>>2] = ((612552 + 8|0));
   $156 = (($90) + 28|0);
   $157 = HEAP8[$156>>0]|0;
   $158 = $157 & 1;
   $159 = ($158<<24>>24)==(0);
   if (!($159)) {
    $160 = (($90) + 36|0);
    $161 = HEAP32[$160>>2]|0;
    HEAP32[$89>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$89+0>>2]|0;
    invoke_vii(2591,($161|0),($$byval_copy89|0));
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if ($163) {
     $164 = ___cxa_find_matching_catch()|0;
     $165 = tempRet0;
     ___cxa_call_unexpected(($164|0));
     // unreachable;
    }
   }
   $166 = (($90) + 16|0);
   $167 = HEAP8[$166>>0]|0;
   $168 = $167 & 1;
   $169 = ($168<<24>>24)==(0);
   if (!($169)) {
    $170 = (($90) + 24|0);
    $171 = HEAP32[$170>>2]|0;
    HEAP32[$88>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$88+0>>2]|0;
    invoke_vii(2591,($171|0),($$byval_copy89|0));
    $172 = __THREW__; __THREW__ = 0;
    $173 = $172&1;
    if ($173) {
     $174 = ___cxa_find_matching_catch()|0;
     $175 = tempRet0;
     ___cxa_call_unexpected(($174|0));
     // unreachable;
    }
   }
   $176 = (($90) + 4|0);
   $177 = HEAP8[$176>>0]|0;
   $178 = $177 & 1;
   $179 = ($178<<24>>24)==(0);
   if (!($179)) {
    $180 = (($90) + 12|0);
    $181 = HEAP32[$180>>2]|0;
    HEAP32[$87>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$87+0>>2]|0;
    invoke_vii(2591,($181|0),($$byval_copy89|0));
    $182 = __THREW__; __THREW__ = 0;
    $183 = $182&1;
    if ($183) {
     $184 = ___cxa_find_matching_catch()|0;
     $185 = tempRet0;
     ___cxa_call_unexpected(($184|0));
     // unreachable;
    }
   }
   $186 = HEAP8[$91>>0]|0;
   $187 = $186 & 1;
   $188 = ($187<<24>>24)==(0);
   if (!($188)) {
    $189 = (($91) + 8|0);
    $190 = HEAP32[$189>>2]|0;
    __ZdlPv($190);
   }
   HEAP8[$93>>0] = 16;
   $191 = (($93) + 1|0);
   $192 = $191;
   $193 = $192;
   HEAP8[$193>>0]=1953654102&255;HEAP8[$193+1>>0]=(1953654102>>8)&255;HEAP8[$193+2>>0]=(1953654102>>16)&255;HEAP8[$193+3>>0]=1953654102>>24;
   $194 = (($192) + 4)|0;
   $195 = $194;
   HEAP8[$195>>0]=1818321769&255;HEAP8[$195+1>>0]=(1818321769>>8)&255;HEAP8[$195+2>>0]=(1818321769>>16)&255;HEAP8[$195+3>>0]=1818321769>>24;
   $196 = (($93) + 9|0);
   HEAP8[$196>>0] = 0;
   __THREW__ = 0;
   invoke_vii(2744,($92|0),($93|0));
   $197 = __THREW__; __THREW__ = 0;
   $198 = $197&1;
   do {
    if ($198) {
     $1240 = ___cxa_find_matching_catch()|0;
     $1241 = tempRet0;
     $$1 = $1241;$$110 = $1240;
    } else {
     $199 = HEAP32[$144>>2]|0;
     $200 = HEAP32[$146>>2]|0;
     $201 = ($199|0)==($200|0);
     do {
      if ($201) {
       __THREW__ = 0;
       invoke_vii(2746,($139|0),($92|0));
       $207 = __THREW__; __THREW__ = 0;
       $208 = $207&1;
       if ($208) {
        label = 371;
       }
      } else {
       $202 = ($199|0)==(0|0);
       if ($202) {
        $206 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(2745,($199|0),($92|0));
        $203 = __THREW__; __THREW__ = 0;
        $204 = $203&1;
        if ($204) {
         label = 371;
         break;
        }
        $$pre$i38 = HEAP32[$144>>2]|0;
        $206 = $$pre$i38;
       }
       $205 = (($206) + 92|0);
       HEAP32[$144>>2] = $205;
      }
     } while(0);
     if ((label|0) == 371) {
      $1242 = ___cxa_find_matching_catch()|0;
      $1243 = tempRet0;
      HEAP32[$92>>2] = ((612552 + 8|0));
      $1244 = (($92) + 28|0);
      $1245 = HEAP8[$1244>>0]|0;
      $1246 = $1245 & 1;
      $1247 = ($1246<<24>>24)==(0);
      if (!($1247)) {
       $1248 = (($92) + 36|0);
       $1249 = HEAP32[$1248>>2]|0;
       HEAP32[$41>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$41+0>>2]|0;
       invoke_vii(2591,($1249|0),($$byval_copy89|0));
       $1250 = __THREW__; __THREW__ = 0;
       $1251 = $1250&1;
       if ($1251) {
        $1252 = ___cxa_find_matching_catch()|0;
        $1253 = tempRet0;
        ___cxa_call_unexpected(($1252|0));
        // unreachable;
       }
      }
      $1254 = (($92) + 16|0);
      $1255 = HEAP8[$1254>>0]|0;
      $1256 = $1255 & 1;
      $1257 = ($1256<<24>>24)==(0);
      if (!($1257)) {
       $1258 = (($92) + 24|0);
       $1259 = HEAP32[$1258>>2]|0;
       HEAP32[$40>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$40+0>>2]|0;
       invoke_vii(2591,($1259|0),($$byval_copy89|0));
       $1260 = __THREW__; __THREW__ = 0;
       $1261 = $1260&1;
       if ($1261) {
        $1262 = ___cxa_find_matching_catch()|0;
        $1263 = tempRet0;
        ___cxa_call_unexpected(($1262|0));
        // unreachable;
       }
      }
      $1264 = (($92) + 4|0);
      $1265 = HEAP8[$1264>>0]|0;
      $1266 = $1265 & 1;
      $1267 = ($1266<<24>>24)==(0);
      if ($1267) {
       $$1 = $1243;$$110 = $1242;
       break;
      }
      $1268 = (($92) + 12|0);
      $1269 = HEAP32[$1268>>2]|0;
      HEAP32[$39>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$39+0>>2]|0;
      invoke_vii(2591,($1269|0),($$byval_copy89|0));
      $1270 = __THREW__; __THREW__ = 0;
      $1271 = $1270&1;
      if (!($1271)) {
       $$1 = $1243;$$110 = $1242;
       break;
      }
      $1272 = ___cxa_find_matching_catch()|0;
      $1273 = tempRet0;
      ___cxa_call_unexpected(($1272|0));
      // unreachable;
     }
     HEAP32[$92>>2] = ((612552 + 8|0));
     $209 = (($92) + 28|0);
     $210 = HEAP8[$209>>0]|0;
     $211 = $210 & 1;
     $212 = ($211<<24>>24)==(0);
     if (!($212)) {
      $213 = (($92) + 36|0);
      $214 = HEAP32[$213>>2]|0;
      HEAP32[$86>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$86+0>>2]|0;
      invoke_vii(2591,($214|0),($$byval_copy89|0));
      $215 = __THREW__; __THREW__ = 0;
      $216 = $215&1;
      if ($216) {
       $217 = ___cxa_find_matching_catch()|0;
       $218 = tempRet0;
       ___cxa_call_unexpected(($217|0));
       // unreachable;
      }
     }
     $219 = (($92) + 16|0);
     $220 = HEAP8[$219>>0]|0;
     $221 = $220 & 1;
     $222 = ($221<<24>>24)==(0);
     if (!($222)) {
      $223 = (($92) + 24|0);
      $224 = HEAP32[$223>>2]|0;
      HEAP32[$85>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$85+0>>2]|0;
      invoke_vii(2591,($224|0),($$byval_copy89|0));
      $225 = __THREW__; __THREW__ = 0;
      $226 = $225&1;
      if ($226) {
       $227 = ___cxa_find_matching_catch()|0;
       $228 = tempRet0;
       ___cxa_call_unexpected(($227|0));
       // unreachable;
      }
     }
     $229 = (($92) + 4|0);
     $230 = HEAP8[$229>>0]|0;
     $231 = $230 & 1;
     $232 = ($231<<24>>24)==(0);
     if (!($232)) {
      $233 = (($92) + 12|0);
      $234 = HEAP32[$233>>2]|0;
      HEAP32[$84>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$84+0>>2]|0;
      invoke_vii(2591,($234|0),($$byval_copy89|0));
      $235 = __THREW__; __THREW__ = 0;
      $236 = $235&1;
      if ($236) {
       $237 = ___cxa_find_matching_catch()|0;
       $238 = tempRet0;
       ___cxa_call_unexpected(($237|0));
       // unreachable;
      }
     }
     $239 = HEAP8[$93>>0]|0;
     $240 = $239 & 1;
     $241 = ($240<<24>>24)==(0);
     if (!($241)) {
      $242 = (($93) + 8|0);
      $243 = HEAP32[$242>>2]|0;
      __ZdlPv($243);
     }
     $244 = HEAP32[$139>>2]|0;
     HEAP8[$94>>0] = 10;
     $245 = (($94) + 1|0);
     ;HEAP8[$245+0>>0]=HEAP8[612824+0>>0]|0;HEAP8[$245+1>>0]=HEAP8[612824+1>>0]|0;HEAP8[$245+2>>0]=HEAP8[612824+2>>0]|0;HEAP8[$245+3>>0]=HEAP8[612824+3>>0]|0;HEAP8[$245+4>>0]=HEAP8[612824+4>>0]|0;
     $246 = (($94) + 6|0);
     HEAP8[$246>>0] = 0;
     $247 = HEAP32[613088>>2]|0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$247,$94);
     $248 = HEAP32[613088>>2]|0;
     $249 = (($248) + 4|0);
     $250 = HEAP32[$$byval_copy89>>2]|0;
     $251 = ($250|0)==($249|0);
     if ($251) {
      $$0$i = 0;
     } else {
      $252 = (($250) + 28|0);
      $253 = HEAP32[$252>>2]|0;
      $$0$i = $253;
     }
     HEAP8[$95>>0] = 8;
     $254 = (($95) + 1|0);
     HEAP8[$254>>0]=1952867692&255;HEAP8[$254+1>>0]=(1952867692>>8)&255;HEAP8[$254+2>>0]=(1952867692>>16)&255;HEAP8[$254+3>>0]=1952867692>>24;
     $255 = (($95) + 5|0);
     HEAP8[$255>>0] = 0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$248,$95);
     $256 = HEAP32[613088>>2]|0;
     $257 = (($256) + 4|0);
     $258 = HEAP32[$$byval_copy89>>2]|0;
     $259 = ($258|0)==($257|0);
     if ($259) {
      $$0$i57 = 0;
     } else {
      $260 = (($258) + 28|0);
      $261 = HEAP32[$260>>2]|0;
      $$0$i57 = $261;
     }
     HEAP8[$96>>0] = 2;
     $262 = (($96) + 1|0);
     HEAP8[$262>>0] = 100;
     $263 = (($96) + 2|0);
     HEAP8[$263>>0] = 0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$256,$96);
     $264 = HEAP32[613088>>2]|0;
     $265 = (($264) + 4|0);
     $266 = HEAP32[$$byval_copy89>>2]|0;
     $267 = ($266|0)==($265|0);
     if ($267) {
      $$0$i66 = 0;
     } else {
      $268 = (($266) + 28|0);
      $269 = HEAP32[$268>>2]|0;
      $$0$i66 = $269;
     }
     HEAP8[$97>>0] = 2;
     $270 = (($97) + 1|0);
     HEAP8[$270>>0] = 97;
     $271 = (($97) + 2|0);
     HEAP8[$271>>0] = 0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$264,$97);
     $272 = HEAP32[613088>>2]|0;
     $273 = (($272) + 4|0);
     $274 = HEAP32[$$byval_copy89>>2]|0;
     $275 = ($274|0)==($273|0);
     if ($275) {
      $$0$i75 = 0;
     } else {
      $276 = (($274) + 28|0);
      $277 = HEAP32[$276>>2]|0;
      $$0$i75 = $277;
     }
     __THREW__ = 0;
     invoke_viiiii(98,($244|0),($$0$i|0),($$0$i57|0),($$0$i66|0),($$0$i75|0));
     $278 = __THREW__; __THREW__ = 0;
     $279 = $278&1;
     if ($279) {
      $1279 = ___cxa_find_matching_catch()|0;
      $1280 = tempRet0;
      $1281 = HEAP8[$97>>0]|0;
      $1282 = $1281 & 1;
      $1283 = ($1282<<24>>24)==(0);
      if (!($1283)) {
       $1284 = (($97) + 8|0);
       $1285 = HEAP32[$1284>>2]|0;
       __ZdlPv($1285);
      }
      $1286 = HEAP8[$96>>0]|0;
      $1287 = $1286 & 1;
      $1288 = ($1287<<24>>24)==(0);
      if (!($1288)) {
       $1289 = (($96) + 8|0);
       $1290 = HEAP32[$1289>>2]|0;
       __ZdlPv($1290);
      }
      $1291 = HEAP8[$95>>0]|0;
      $1292 = $1291 & 1;
      $1293 = ($1292<<24>>24)==(0);
      if (!($1293)) {
       $1294 = (($95) + 8|0);
       $1295 = HEAP32[$1294>>2]|0;
       __ZdlPv($1295);
      }
      $1296 = HEAP8[$94>>0]|0;
      $1297 = $1296 & 1;
      $1298 = ($1297<<24>>24)==(0);
      if ($1298) {
       $$24 = $1280;$$2433 = $1279;
       ___resumeException($$2433|0);
       // unreachable;
      }
      $1299 = (($94) + 8|0);
      $1300 = HEAP32[$1299>>2]|0;
      __ZdlPv($1300);
      $$24 = $1280;$$2433 = $1279;
      ___resumeException($$2433|0);
      // unreachable;
     }
     $280 = HEAP8[$97>>0]|0;
     $281 = $280 & 1;
     $282 = ($281<<24>>24)==(0);
     if (!($282)) {
      $283 = (($97) + 8|0);
      $284 = HEAP32[$283>>2]|0;
      __ZdlPv($284);
     }
     $285 = HEAP8[$96>>0]|0;
     $286 = $285 & 1;
     $287 = ($286<<24>>24)==(0);
     if (!($287)) {
      $288 = (($96) + 8|0);
      $289 = HEAP32[$288>>2]|0;
      __ZdlPv($289);
     }
     $290 = HEAP8[$95>>0]|0;
     $291 = $290 & 1;
     $292 = ($291<<24>>24)==(0);
     if (!($292)) {
      $293 = (($95) + 8|0);
      $294 = HEAP32[$293>>2]|0;
      __ZdlPv($294);
     }
     $295 = HEAP8[$94>>0]|0;
     $296 = $295 & 1;
     $297 = ($296<<24>>24)==(0);
     if (!($297)) {
      $298 = (($94) + 8|0);
      $299 = HEAP32[$298>>2]|0;
      __ZdlPv($299);
     }
     $300 = HEAP32[$139>>2]|0;
     $301 = (($300) + 92|0);
     HEAP8[$98>>0] = 4;
     $302 = (($98) + 1|0);
     HEAP8[$302>>0]=28789&255;HEAP8[$302+1>>0]=28789>>8;
     $303 = (($98) + 3|0);
     HEAP8[$303>>0] = 0;
     $304 = HEAP32[613088>>2]|0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$304,$98);
     $305 = HEAP32[613088>>2]|0;
     $306 = (($305) + 4|0);
     $307 = HEAP32[$$byval_copy89>>2]|0;
     $308 = ($307|0)==($306|0);
     if ($308) {
      $$0$i86 = 0;
     } else {
      $309 = (($307) + 28|0);
      $310 = HEAP32[$309>>2]|0;
      $$0$i86 = $310;
     }
     HEAP8[$99>>0] = 8;
     $311 = (($99) + 1|0);
     HEAP8[$311>>0]=1853321060&255;HEAP8[$311+1>>0]=(1853321060>>8)&255;HEAP8[$311+2>>0]=(1853321060>>16)&255;HEAP8[$311+3>>0]=1853321060>>24;
     $312 = (($99) + 5|0);
     HEAP8[$312>>0] = 0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$305,$99);
     $313 = HEAP32[613088>>2]|0;
     $314 = (($313) + 4|0);
     $315 = HEAP32[$$byval_copy89>>2]|0;
     $316 = ($315|0)==($314|0);
     if ($316) {
      $$0$i95 = 0;
     } else {
      $317 = (($315) + 28|0);
      $318 = HEAP32[$317>>2]|0;
      $$0$i95 = $318;
     }
     HEAP8[$100>>0] = 2;
     $319 = (($100) + 1|0);
     HEAP8[$319>>0] = 119;
     $320 = (($100) + 2|0);
     HEAP8[$320>>0] = 0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$313,$100);
     $321 = HEAP32[613088>>2]|0;
     $322 = (($321) + 4|0);
     $323 = HEAP32[$$byval_copy89>>2]|0;
     $324 = ($323|0)==($322|0);
     if ($324) {
      $$0$i104 = 0;
     } else {
      $325 = (($323) + 28|0);
      $326 = HEAP32[$325>>2]|0;
      $$0$i104 = $326;
     }
     HEAP8[$101>>0] = 2;
     $327 = (($101) + 1|0);
     HEAP8[$327>>0] = 115;
     $328 = (($101) + 2|0);
     HEAP8[$328>>0] = 0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$321,$101);
     $329 = HEAP32[613088>>2]|0;
     $330 = (($329) + 4|0);
     $331 = HEAP32[$$byval_copy89>>2]|0;
     $332 = ($331|0)==($330|0);
     if ($332) {
      $$0$i113 = 0;
     } else {
      $333 = (($331) + 28|0);
      $334 = HEAP32[$333>>2]|0;
      $$0$i113 = $334;
     }
     __THREW__ = 0;
     invoke_viiiii(98,($301|0),($$0$i86|0),($$0$i95|0),($$0$i104|0),($$0$i113|0));
     $335 = __THREW__; __THREW__ = 0;
     $336 = $335&1;
     if ($336) {
      $1301 = ___cxa_find_matching_catch()|0;
      $1302 = tempRet0;
      $1303 = HEAP8[$101>>0]|0;
      $1304 = $1303 & 1;
      $1305 = ($1304<<24>>24)==(0);
      if (!($1305)) {
       $1306 = (($101) + 8|0);
       $1307 = HEAP32[$1306>>2]|0;
       __ZdlPv($1307);
      }
      $1308 = HEAP8[$100>>0]|0;
      $1309 = $1308 & 1;
      $1310 = ($1309<<24>>24)==(0);
      if (!($1310)) {
       $1311 = (($100) + 8|0);
       $1312 = HEAP32[$1311>>2]|0;
       __ZdlPv($1312);
      }
      $1313 = HEAP8[$99>>0]|0;
      $1314 = $1313 & 1;
      $1315 = ($1314<<24>>24)==(0);
      if (!($1315)) {
       $1316 = (($99) + 8|0);
       $1317 = HEAP32[$1316>>2]|0;
       __ZdlPv($1317);
      }
      $1318 = HEAP8[$98>>0]|0;
      $1319 = $1318 & 1;
      $1320 = ($1319<<24>>24)==(0);
      if ($1320) {
       $$24 = $1302;$$2433 = $1301;
       ___resumeException($$2433|0);
       // unreachable;
      }
      $1321 = (($98) + 8|0);
      $1322 = HEAP32[$1321>>2]|0;
      __ZdlPv($1322);
      $$24 = $1302;$$2433 = $1301;
      ___resumeException($$2433|0);
      // unreachable;
     }
     $337 = HEAP8[$101>>0]|0;
     $338 = $337 & 1;
     $339 = ($338<<24>>24)==(0);
     if (!($339)) {
      $340 = (($101) + 8|0);
      $341 = HEAP32[$340>>2]|0;
      __ZdlPv($341);
     }
     $342 = HEAP8[$100>>0]|0;
     $343 = $342 & 1;
     $344 = ($343<<24>>24)==(0);
     if (!($344)) {
      $345 = (($100) + 8|0);
      $346 = HEAP32[$345>>2]|0;
      __ZdlPv($346);
     }
     $347 = HEAP8[$99>>0]|0;
     $348 = $347 & 1;
     $349 = ($348<<24>>24)==(0);
     if (!($349)) {
      $350 = (($99) + 8|0);
      $351 = HEAP32[$350>>2]|0;
      __ZdlPv($351);
     }
     $352 = HEAP8[$98>>0]|0;
     $353 = $352 & 1;
     $354 = ($353<<24>>24)==(0);
     if (!($354)) {
      $355 = (($98) + 8|0);
      $356 = HEAP32[$355>>2]|0;
      __ZdlPv($356);
     }
     HEAP8[$103>>0] = 10;
     $357 = (($103) + 1|0);
     ;HEAP8[$357+0>>0]=HEAP8[612888+0>>0]|0;HEAP8[$357+1>>0]=HEAP8[612888+1>>0]|0;HEAP8[$357+2>>0]=HEAP8[612888+2>>0]|0;HEAP8[$357+3>>0]=HEAP8[612888+3>>0]|0;HEAP8[$357+4>>0]=HEAP8[612888+4>>0]|0;
     $358 = (($103) + 6|0);
     HEAP8[$358>>0] = 0;
     __THREW__ = 0;
     invoke_vii(2744,($102|0),($103|0));
     $359 = __THREW__; __THREW__ = 0;
     $360 = $359&1;
     do {
      if ($360) {
       $1323 = ___cxa_find_matching_catch()|0;
       $1324 = tempRet0;
       $$8 = $1324;$$817 = $1323;
      } else {
       $361 = HEAP32[$144>>2]|0;
       $362 = HEAP32[$146>>2]|0;
       $363 = ($361|0)==($362|0);
       do {
        if ($363) {
         __THREW__ = 0;
         invoke_vii(2746,($139|0),($102|0));
         $369 = __THREW__; __THREW__ = 0;
         $370 = $369&1;
         if ($370) {
          label = 399;
         }
        } else {
         $364 = ($361|0)==(0|0);
         if ($364) {
          $368 = 0;
         } else {
          __THREW__ = 0;
          invoke_vii(2745,($361|0),($102|0));
          $365 = __THREW__; __THREW__ = 0;
          $366 = $365&1;
          if ($366) {
           label = 399;
           break;
          }
          $$pre$i122 = HEAP32[$144>>2]|0;
          $368 = $$pre$i122;
         }
         $367 = (($368) + 92|0);
         HEAP32[$144>>2] = $367;
        }
       } while(0);
       if ((label|0) == 399) {
        $1325 = ___cxa_find_matching_catch()|0;
        $1326 = tempRet0;
        HEAP32[$102>>2] = ((612552 + 8|0));
        $1327 = (($102) + 28|0);
        $1328 = HEAP8[$1327>>0]|0;
        $1329 = $1328 & 1;
        $1330 = ($1329<<24>>24)==(0);
        do {
         if (!($1330)) {
          $1331 = (($102) + 36|0);
          $1332 = HEAP32[$1331>>2]|0;
          HEAP32[$38>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$38+0>>2]|0;
          invoke_vii(2591,($1332|0),($$byval_copy89|0));
          $1333 = __THREW__; __THREW__ = 0;
          $1334 = $1333&1;
          if (!($1334)) {
           break;
          }
          $1335 = ___cxa_find_matching_catch()|0;
          $1336 = tempRet0;
          ___cxa_call_unexpected(($1335|0));
          // unreachable;
         }
        } while(0);
        $1337 = (($102) + 16|0);
        $1338 = HEAP8[$1337>>0]|0;
        $1339 = $1338 & 1;
        $1340 = ($1339<<24>>24)==(0);
        do {
         if (!($1340)) {
          $1341 = (($102) + 24|0);
          $1342 = HEAP32[$1341>>2]|0;
          HEAP32[$37>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$37+0>>2]|0;
          invoke_vii(2591,($1342|0),($$byval_copy89|0));
          $1343 = __THREW__; __THREW__ = 0;
          $1344 = $1343&1;
          if (!($1344)) {
           break;
          }
          $1345 = ___cxa_find_matching_catch()|0;
          $1346 = tempRet0;
          ___cxa_call_unexpected(($1345|0));
          // unreachable;
         }
        } while(0);
        $1347 = (($102) + 4|0);
        $1348 = HEAP8[$1347>>0]|0;
        $1349 = $1348 & 1;
        $1350 = ($1349<<24>>24)==(0);
        if ($1350) {
         $$8 = $1326;$$817 = $1325;
         break;
        }
        $1351 = (($102) + 12|0);
        $1352 = HEAP32[$1351>>2]|0;
        HEAP32[$36>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$36+0>>2]|0;
        invoke_vii(2591,($1352|0),($$byval_copy89|0));
        $1353 = __THREW__; __THREW__ = 0;
        $1354 = $1353&1;
        if (!($1354)) {
         $$8 = $1326;$$817 = $1325;
         break;
        }
        $1355 = ___cxa_find_matching_catch()|0;
        $1356 = tempRet0;
        ___cxa_call_unexpected(($1355|0));
        // unreachable;
       }
       HEAP32[$102>>2] = ((612552 + 8|0));
       $371 = (($102) + 28|0);
       $372 = HEAP8[$371>>0]|0;
       $373 = $372 & 1;
       $374 = ($373<<24>>24)==(0);
       do {
        if (!($374)) {
         $375 = (($102) + 36|0);
         $376 = HEAP32[$375>>2]|0;
         HEAP32[$83>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$83+0>>2]|0;
         invoke_vii(2591,($376|0),($$byval_copy89|0));
         $377 = __THREW__; __THREW__ = 0;
         $378 = $377&1;
         if (!($378)) {
          break;
         }
         $379 = ___cxa_find_matching_catch()|0;
         $380 = tempRet0;
         ___cxa_call_unexpected(($379|0));
         // unreachable;
        }
       } while(0);
       $381 = (($102) + 16|0);
       $382 = HEAP8[$381>>0]|0;
       $383 = $382 & 1;
       $384 = ($383<<24>>24)==(0);
       do {
        if (!($384)) {
         $385 = (($102) + 24|0);
         $386 = HEAP32[$385>>2]|0;
         HEAP32[$82>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$82+0>>2]|0;
         invoke_vii(2591,($386|0),($$byval_copy89|0));
         $387 = __THREW__; __THREW__ = 0;
         $388 = $387&1;
         if (!($388)) {
          break;
         }
         $389 = ___cxa_find_matching_catch()|0;
         $390 = tempRet0;
         ___cxa_call_unexpected(($389|0));
         // unreachable;
        }
       } while(0);
       $391 = (($102) + 4|0);
       $392 = HEAP8[$391>>0]|0;
       $393 = $392 & 1;
       $394 = ($393<<24>>24)==(0);
       do {
        if (!($394)) {
         $395 = (($102) + 12|0);
         $396 = HEAP32[$395>>2]|0;
         HEAP32[$81>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$81+0>>2]|0;
         invoke_vii(2591,($396|0),($$byval_copy89|0));
         $397 = __THREW__; __THREW__ = 0;
         $398 = $397&1;
         if (!($398)) {
          break;
         }
         $399 = ___cxa_find_matching_catch()|0;
         $400 = tempRet0;
         ___cxa_call_unexpected(($399|0));
         // unreachable;
        }
       } while(0);
       $401 = HEAP8[$103>>0]|0;
       $402 = $401 & 1;
       $403 = ($402<<24>>24)==(0);
       if (!($403)) {
        $404 = (($103) + 8|0);
        $405 = HEAP32[$404>>2]|0;
        __ZdlPv($405);
       }
       HEAP8[$105>>0] = 10;
       $406 = (($105) + 1|0);
       ;HEAP8[$406+0>>0]=HEAP8[612896+0>>0]|0;HEAP8[$406+1>>0]=HEAP8[612896+1>>0]|0;HEAP8[$406+2>>0]=HEAP8[612896+2>>0]|0;HEAP8[$406+3>>0]=HEAP8[612896+3>>0]|0;HEAP8[$406+4>>0]=HEAP8[612896+4>>0]|0;
       $407 = (($105) + 6|0);
       HEAP8[$407>>0] = 0;
       __THREW__ = 0;
       invoke_vii(2744,($104|0),($105|0));
       $408 = __THREW__; __THREW__ = 0;
       $409 = $408&1;
       do {
        if ($409) {
         $1362 = ___cxa_find_matching_catch()|0;
         $1363 = tempRet0;
         $$9 = $1363;$$918 = $1362;
        } else {
         $410 = HEAP32[$144>>2]|0;
         $411 = HEAP32[$146>>2]|0;
         $412 = ($410|0)==($411|0);
         do {
          if ($412) {
           __THREW__ = 0;
           invoke_vii(2746,($139|0),($104|0));
           $418 = __THREW__; __THREW__ = 0;
           $419 = $418&1;
           if ($419) {
            label = 411;
           }
          } else {
           $413 = ($410|0)==(0|0);
           if ($413) {
            $417 = 0;
           } else {
            __THREW__ = 0;
            invoke_vii(2745,($410|0),($104|0));
            $414 = __THREW__; __THREW__ = 0;
            $415 = $414&1;
            if ($415) {
             label = 411;
             break;
            }
            $$pre$i134 = HEAP32[$144>>2]|0;
            $417 = $$pre$i134;
           }
           $416 = (($417) + 92|0);
           HEAP32[$144>>2] = $416;
          }
         } while(0);
         if ((label|0) == 411) {
          $1364 = ___cxa_find_matching_catch()|0;
          $1365 = tempRet0;
          HEAP32[$104>>2] = ((612552 + 8|0));
          $1366 = (($104) + 28|0);
          $1367 = HEAP8[$1366>>0]|0;
          $1368 = $1367 & 1;
          $1369 = ($1368<<24>>24)==(0);
          do {
           if (!($1369)) {
            $1370 = (($104) + 36|0);
            $1371 = HEAP32[$1370>>2]|0;
            HEAP32[$35>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$35+0>>2]|0;
            invoke_vii(2591,($1371|0),($$byval_copy89|0));
            $1372 = __THREW__; __THREW__ = 0;
            $1373 = $1372&1;
            if (!($1373)) {
             break;
            }
            $1374 = ___cxa_find_matching_catch()|0;
            $1375 = tempRet0;
            ___cxa_call_unexpected(($1374|0));
            // unreachable;
           }
          } while(0);
          $1376 = (($104) + 16|0);
          $1377 = HEAP8[$1376>>0]|0;
          $1378 = $1377 & 1;
          $1379 = ($1378<<24>>24)==(0);
          do {
           if (!($1379)) {
            $1380 = (($104) + 24|0);
            $1381 = HEAP32[$1380>>2]|0;
            HEAP32[$34>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$34+0>>2]|0;
            invoke_vii(2591,($1381|0),($$byval_copy89|0));
            $1382 = __THREW__; __THREW__ = 0;
            $1383 = $1382&1;
            if (!($1383)) {
             break;
            }
            $1384 = ___cxa_find_matching_catch()|0;
            $1385 = tempRet0;
            ___cxa_call_unexpected(($1384|0));
            // unreachable;
           }
          } while(0);
          $1386 = (($104) + 4|0);
          $1387 = HEAP8[$1386>>0]|0;
          $1388 = $1387 & 1;
          $1389 = ($1388<<24>>24)==(0);
          if ($1389) {
           $$9 = $1365;$$918 = $1364;
           break;
          }
          $1390 = (($104) + 12|0);
          $1391 = HEAP32[$1390>>2]|0;
          HEAP32[$33>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$33+0>>2]|0;
          invoke_vii(2591,($1391|0),($$byval_copy89|0));
          $1392 = __THREW__; __THREW__ = 0;
          $1393 = $1392&1;
          if (!($1393)) {
           $$9 = $1365;$$918 = $1364;
           break;
          }
          $1394 = ___cxa_find_matching_catch()|0;
          $1395 = tempRet0;
          ___cxa_call_unexpected(($1394|0));
          // unreachable;
         }
         HEAP32[$104>>2] = ((612552 + 8|0));
         $420 = (($104) + 28|0);
         $421 = HEAP8[$420>>0]|0;
         $422 = $421 & 1;
         $423 = ($422<<24>>24)==(0);
         do {
          if (!($423)) {
           $424 = (($104) + 36|0);
           $425 = HEAP32[$424>>2]|0;
           HEAP32[$80>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$80+0>>2]|0;
           invoke_vii(2591,($425|0),($$byval_copy89|0));
           $426 = __THREW__; __THREW__ = 0;
           $427 = $426&1;
           if (!($427)) {
            break;
           }
           $428 = ___cxa_find_matching_catch()|0;
           $429 = tempRet0;
           ___cxa_call_unexpected(($428|0));
           // unreachable;
          }
         } while(0);
         $430 = (($104) + 16|0);
         $431 = HEAP8[$430>>0]|0;
         $432 = $431 & 1;
         $433 = ($432<<24>>24)==(0);
         do {
          if (!($433)) {
           $434 = (($104) + 24|0);
           $435 = HEAP32[$434>>2]|0;
           HEAP32[$79>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$79+0>>2]|0;
           invoke_vii(2591,($435|0),($$byval_copy89|0));
           $436 = __THREW__; __THREW__ = 0;
           $437 = $436&1;
           if (!($437)) {
            break;
           }
           $438 = ___cxa_find_matching_catch()|0;
           $439 = tempRet0;
           ___cxa_call_unexpected(($438|0));
           // unreachable;
          }
         } while(0);
         $440 = (($104) + 4|0);
         $441 = HEAP8[$440>>0]|0;
         $442 = $441 & 1;
         $443 = ($442<<24>>24)==(0);
         do {
          if (!($443)) {
           $444 = (($104) + 12|0);
           $445 = HEAP32[$444>>2]|0;
           HEAP32[$78>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$78+0>>2]|0;
           invoke_vii(2591,($445|0),($$byval_copy89|0));
           $446 = __THREW__; __THREW__ = 0;
           $447 = $446&1;
           if (!($447)) {
            break;
           }
           $448 = ___cxa_find_matching_catch()|0;
           $449 = tempRet0;
           ___cxa_call_unexpected(($448|0));
           // unreachable;
          }
         } while(0);
         $450 = HEAP8[$105>>0]|0;
         $451 = $450 & 1;
         $452 = ($451<<24>>24)==(0);
         if (!($452)) {
          $453 = (($105) + 8|0);
          $454 = HEAP32[$453>>2]|0;
          __ZdlPv($454);
         }
         HEAP8[$107>>0] = 10;
         $455 = (($107) + 1|0);
         ;HEAP8[$455+0>>0]=HEAP8[612904+0>>0]|0;HEAP8[$455+1>>0]=HEAP8[612904+1>>0]|0;HEAP8[$455+2>>0]=HEAP8[612904+2>>0]|0;HEAP8[$455+3>>0]=HEAP8[612904+3>>0]|0;HEAP8[$455+4>>0]=HEAP8[612904+4>>0]|0;
         $456 = (($107) + 6|0);
         HEAP8[$456>>0] = 0;
         __THREW__ = 0;
         invoke_vii(2744,($106|0),($107|0));
         $457 = __THREW__; __THREW__ = 0;
         $458 = $457&1;
         do {
          if ($458) {
           $1401 = ___cxa_find_matching_catch()|0;
           $1402 = tempRet0;
           $$10 = $1402;$$1019 = $1401;
          } else {
           $459 = HEAP32[$144>>2]|0;
           $460 = HEAP32[$146>>2]|0;
           $461 = ($459|0)==($460|0);
           do {
            if ($461) {
             __THREW__ = 0;
             invoke_vii(2746,($139|0),($106|0));
             $467 = __THREW__; __THREW__ = 0;
             $468 = $467&1;
             if ($468) {
              label = 423;
             }
            } else {
             $462 = ($459|0)==(0|0);
             if ($462) {
              $466 = 0;
             } else {
              __THREW__ = 0;
              invoke_vii(2745,($459|0),($106|0));
              $463 = __THREW__; __THREW__ = 0;
              $464 = $463&1;
              if ($464) {
               label = 423;
               break;
              }
              $$pre$i146 = HEAP32[$144>>2]|0;
              $466 = $$pre$i146;
             }
             $465 = (($466) + 92|0);
             HEAP32[$144>>2] = $465;
            }
           } while(0);
           if ((label|0) == 423) {
            $1403 = ___cxa_find_matching_catch()|0;
            $1404 = tempRet0;
            HEAP32[$106>>2] = ((612552 + 8|0));
            $1405 = (($106) + 28|0);
            $1406 = HEAP8[$1405>>0]|0;
            $1407 = $1406 & 1;
            $1408 = ($1407<<24>>24)==(0);
            do {
             if (!($1408)) {
              $1409 = (($106) + 36|0);
              $1410 = HEAP32[$1409>>2]|0;
              HEAP32[$32>>2] = 59;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$32+0>>2]|0;
              invoke_vii(2591,($1410|0),($$byval_copy89|0));
              $1411 = __THREW__; __THREW__ = 0;
              $1412 = $1411&1;
              if (!($1412)) {
               break;
              }
              $1413 = ___cxa_find_matching_catch()|0;
              $1414 = tempRet0;
              ___cxa_call_unexpected(($1413|0));
              // unreachable;
             }
            } while(0);
            $1415 = (($106) + 16|0);
            $1416 = HEAP8[$1415>>0]|0;
            $1417 = $1416 & 1;
            $1418 = ($1417<<24>>24)==(0);
            do {
             if (!($1418)) {
              $1419 = (($106) + 24|0);
              $1420 = HEAP32[$1419>>2]|0;
              HEAP32[$31>>2] = 59;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$31+0>>2]|0;
              invoke_vii(2591,($1420|0),($$byval_copy89|0));
              $1421 = __THREW__; __THREW__ = 0;
              $1422 = $1421&1;
              if (!($1422)) {
               break;
              }
              $1423 = ___cxa_find_matching_catch()|0;
              $1424 = tempRet0;
              ___cxa_call_unexpected(($1423|0));
              // unreachable;
             }
            } while(0);
            $1425 = (($106) + 4|0);
            $1426 = HEAP8[$1425>>0]|0;
            $1427 = $1426 & 1;
            $1428 = ($1427<<24>>24)==(0);
            if ($1428) {
             $$10 = $1404;$$1019 = $1403;
             break;
            }
            $1429 = (($106) + 12|0);
            $1430 = HEAP32[$1429>>2]|0;
            HEAP32[$30>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$30+0>>2]|0;
            invoke_vii(2591,($1430|0),($$byval_copy89|0));
            $1431 = __THREW__; __THREW__ = 0;
            $1432 = $1431&1;
            if (!($1432)) {
             $$10 = $1404;$$1019 = $1403;
             break;
            }
            $1433 = ___cxa_find_matching_catch()|0;
            $1434 = tempRet0;
            ___cxa_call_unexpected(($1433|0));
            // unreachable;
           }
           HEAP32[$106>>2] = ((612552 + 8|0));
           $469 = (($106) + 28|0);
           $470 = HEAP8[$469>>0]|0;
           $471 = $470 & 1;
           $472 = ($471<<24>>24)==(0);
           do {
            if (!($472)) {
             $473 = (($106) + 36|0);
             $474 = HEAP32[$473>>2]|0;
             HEAP32[$77>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$77+0>>2]|0;
             invoke_vii(2591,($474|0),($$byval_copy89|0));
             $475 = __THREW__; __THREW__ = 0;
             $476 = $475&1;
             if (!($476)) {
              break;
             }
             $477 = ___cxa_find_matching_catch()|0;
             $478 = tempRet0;
             ___cxa_call_unexpected(($477|0));
             // unreachable;
            }
           } while(0);
           $479 = (($106) + 16|0);
           $480 = HEAP8[$479>>0]|0;
           $481 = $480 & 1;
           $482 = ($481<<24>>24)==(0);
           do {
            if (!($482)) {
             $483 = (($106) + 24|0);
             $484 = HEAP32[$483>>2]|0;
             HEAP32[$76>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$76+0>>2]|0;
             invoke_vii(2591,($484|0),($$byval_copy89|0));
             $485 = __THREW__; __THREW__ = 0;
             $486 = $485&1;
             if (!($486)) {
              break;
             }
             $487 = ___cxa_find_matching_catch()|0;
             $488 = tempRet0;
             ___cxa_call_unexpected(($487|0));
             // unreachable;
            }
           } while(0);
           $489 = (($106) + 4|0);
           $490 = HEAP8[$489>>0]|0;
           $491 = $490 & 1;
           $492 = ($491<<24>>24)==(0);
           do {
            if (!($492)) {
             $493 = (($106) + 12|0);
             $494 = HEAP32[$493>>2]|0;
             HEAP32[$75>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$75+0>>2]|0;
             invoke_vii(2591,($494|0),($$byval_copy89|0));
             $495 = __THREW__; __THREW__ = 0;
             $496 = $495&1;
             if (!($496)) {
              break;
             }
             $497 = ___cxa_find_matching_catch()|0;
             $498 = tempRet0;
             ___cxa_call_unexpected(($497|0));
             // unreachable;
            }
           } while(0);
           $499 = HEAP8[$107>>0]|0;
           $500 = $499 & 1;
           $501 = ($500<<24>>24)==(0);
           if (!($501)) {
            $502 = (($107) + 8|0);
            $503 = HEAP32[$502>>2]|0;
            __ZdlPv($503);
           }
           HEAP8[$109>>0] = 8;
           $504 = (($109) + 1|0);
           HEAP8[$504>>0]=1886221642&255;HEAP8[$504+1>>0]=(1886221642>>8)&255;HEAP8[$504+2>>0]=(1886221642>>16)&255;HEAP8[$504+3>>0]=1886221642>>24;
           $505 = (($109) + 5|0);
           HEAP8[$505>>0] = 0;
           __THREW__ = 0;
           invoke_vii(2744,($108|0),($109|0));
           $506 = __THREW__; __THREW__ = 0;
           $507 = $506&1;
           do {
            if ($507) {
             $1440 = ___cxa_find_matching_catch()|0;
             $1441 = tempRet0;
             $$11 = $1441;$$1120 = $1440;
            } else {
             $508 = HEAP32[$144>>2]|0;
             $509 = HEAP32[$146>>2]|0;
             $510 = ($508|0)==($509|0);
             do {
              if ($510) {
               __THREW__ = 0;
               invoke_vii(2746,($139|0),($108|0));
               $516 = __THREW__; __THREW__ = 0;
               $517 = $516&1;
               if ($517) {
                label = 435;
               }
              } else {
               $511 = ($508|0)==(0|0);
               if ($511) {
                $515 = 0;
               } else {
                __THREW__ = 0;
                invoke_vii(2745,($508|0),($108|0));
                $512 = __THREW__; __THREW__ = 0;
                $513 = $512&1;
                if ($513) {
                 label = 435;
                 break;
                }
                $$pre$i158 = HEAP32[$144>>2]|0;
                $515 = $$pre$i158;
               }
               $514 = (($515) + 92|0);
               HEAP32[$144>>2] = $514;
              }
             } while(0);
             if ((label|0) == 435) {
              $1442 = ___cxa_find_matching_catch()|0;
              $1443 = tempRet0;
              HEAP32[$108>>2] = ((612552 + 8|0));
              $1444 = (($108) + 28|0);
              $1445 = HEAP8[$1444>>0]|0;
              $1446 = $1445 & 1;
              $1447 = ($1446<<24>>24)==(0);
              do {
               if (!($1447)) {
                $1448 = (($108) + 36|0);
                $1449 = HEAP32[$1448>>2]|0;
                HEAP32[$29>>2] = 59;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$29+0>>2]|0;
                invoke_vii(2591,($1449|0),($$byval_copy89|0));
                $1450 = __THREW__; __THREW__ = 0;
                $1451 = $1450&1;
                if (!($1451)) {
                 break;
                }
                $1452 = ___cxa_find_matching_catch()|0;
                $1453 = tempRet0;
                ___cxa_call_unexpected(($1452|0));
                // unreachable;
               }
              } while(0);
              $1454 = (($108) + 16|0);
              $1455 = HEAP8[$1454>>0]|0;
              $1456 = $1455 & 1;
              $1457 = ($1456<<24>>24)==(0);
              do {
               if (!($1457)) {
                $1458 = (($108) + 24|0);
                $1459 = HEAP32[$1458>>2]|0;
                HEAP32[$28>>2] = 59;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$28+0>>2]|0;
                invoke_vii(2591,($1459|0),($$byval_copy89|0));
                $1460 = __THREW__; __THREW__ = 0;
                $1461 = $1460&1;
                if (!($1461)) {
                 break;
                }
                $1462 = ___cxa_find_matching_catch()|0;
                $1463 = tempRet0;
                ___cxa_call_unexpected(($1462|0));
                // unreachable;
               }
              } while(0);
              $1464 = (($108) + 4|0);
              $1465 = HEAP8[$1464>>0]|0;
              $1466 = $1465 & 1;
              $1467 = ($1466<<24>>24)==(0);
              if ($1467) {
               $$11 = $1443;$$1120 = $1442;
               break;
              }
              $1468 = (($108) + 12|0);
              $1469 = HEAP32[$1468>>2]|0;
              HEAP32[$27>>2] = 59;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$27+0>>2]|0;
              invoke_vii(2591,($1469|0),($$byval_copy89|0));
              $1470 = __THREW__; __THREW__ = 0;
              $1471 = $1470&1;
              if (!($1471)) {
               $$11 = $1443;$$1120 = $1442;
               break;
              }
              $1472 = ___cxa_find_matching_catch()|0;
              $1473 = tempRet0;
              ___cxa_call_unexpected(($1472|0));
              // unreachable;
             }
             HEAP32[$108>>2] = ((612552 + 8|0));
             $518 = (($108) + 28|0);
             $519 = HEAP8[$518>>0]|0;
             $520 = $519 & 1;
             $521 = ($520<<24>>24)==(0);
             do {
              if (!($521)) {
               $522 = (($108) + 36|0);
               $523 = HEAP32[$522>>2]|0;
               HEAP32[$74>>2] = 59;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$74+0>>2]|0;
               invoke_vii(2591,($523|0),($$byval_copy89|0));
               $524 = __THREW__; __THREW__ = 0;
               $525 = $524&1;
               if (!($525)) {
                break;
               }
               $526 = ___cxa_find_matching_catch()|0;
               $527 = tempRet0;
               ___cxa_call_unexpected(($526|0));
               // unreachable;
              }
             } while(0);
             $528 = (($108) + 16|0);
             $529 = HEAP8[$528>>0]|0;
             $530 = $529 & 1;
             $531 = ($530<<24>>24)==(0);
             do {
              if (!($531)) {
               $532 = (($108) + 24|0);
               $533 = HEAP32[$532>>2]|0;
               HEAP32[$73>>2] = 59;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$73+0>>2]|0;
               invoke_vii(2591,($533|0),($$byval_copy89|0));
               $534 = __THREW__; __THREW__ = 0;
               $535 = $534&1;
               if (!($535)) {
                break;
               }
               $536 = ___cxa_find_matching_catch()|0;
               $537 = tempRet0;
               ___cxa_call_unexpected(($536|0));
               // unreachable;
              }
             } while(0);
             $538 = (($108) + 4|0);
             $539 = HEAP8[$538>>0]|0;
             $540 = $539 & 1;
             $541 = ($540<<24>>24)==(0);
             do {
              if (!($541)) {
               $542 = (($108) + 12|0);
               $543 = HEAP32[$542>>2]|0;
               HEAP32[$72>>2] = 59;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$72+0>>2]|0;
               invoke_vii(2591,($543|0),($$byval_copy89|0));
               $544 = __THREW__; __THREW__ = 0;
               $545 = $544&1;
               if (!($545)) {
                break;
               }
               $546 = ___cxa_find_matching_catch()|0;
               $547 = tempRet0;
               ___cxa_call_unexpected(($546|0));
               // unreachable;
              }
             } while(0);
             $548 = HEAP8[$109>>0]|0;
             $549 = $548 & 1;
             $550 = ($549<<24>>24)==(0);
             if (!($550)) {
              $551 = (($109) + 8|0);
              $552 = HEAP32[$551>>2]|0;
              __ZdlPv($552);
             }
             $553 = HEAP32[$139>>2]|0;
             $554 = (($553) + 184|0);
             HEAP8[$110>>0] = 18;
             $555 = (($110) + 1|0);
             dest=$555+0|0; src=612912+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
             $556 = (($110) + 10|0);
             HEAP8[$556>>0] = 0;
             $557 = HEAP32[613088>>2]|0;
             __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$557,$110);
             $558 = HEAP32[613088>>2]|0;
             $559 = (($558) + 4|0);
             $560 = HEAP32[$$byval_copy89>>2]|0;
             $561 = ($560|0)==($559|0);
             if ($561) {
              $$0$i172 = 0;
             } else {
              $562 = (($560) + 28|0);
              $563 = HEAP32[$562>>2]|0;
              $$0$i172 = $563;
             }
             HEAP8[$111>>0] = 14;
             $564 = (($111) + 1|0);
             ;HEAP8[$564+0>>0]=HEAP8[612928+0>>0]|0;HEAP8[$564+1>>0]=HEAP8[612928+1>>0]|0;HEAP8[$564+2>>0]=HEAP8[612928+2>>0]|0;HEAP8[$564+3>>0]=HEAP8[612928+3>>0]|0;HEAP8[$564+4>>0]=HEAP8[612928+4>>0]|0;HEAP8[$564+5>>0]=HEAP8[612928+5>>0]|0;HEAP8[$564+6>>0]=HEAP8[612928+6>>0]|0;
             $565 = (($111) + 8|0);
             HEAP8[$565>>0] = 0;
             __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$558,$111);
             $566 = HEAP32[613088>>2]|0;
             $567 = (($566) + 4|0);
             $568 = HEAP32[$$byval_copy89>>2]|0;
             $569 = ($568|0)==($567|0);
             if ($569) {
              $$0$i181 = 0;
             } else {
              $570 = (($568) + 28|0);
              $571 = HEAP32[$570>>2]|0;
              $$0$i181 = $571;
             }
             __THREW__ = 0;
             invoke_viii(1764,($554|0),($$0$i172|0),($$0$i181|0));
             $572 = __THREW__; __THREW__ = 0;
             $573 = $572&1;
             if ($573) {
              $1479 = ___cxa_find_matching_catch()|0;
              $1480 = tempRet0;
              $1481 = HEAP8[$111>>0]|0;
              $1482 = $1481 & 1;
              $1483 = ($1482<<24>>24)==(0);
              if (!($1483)) {
               $1484 = HEAP32[$565>>2]|0;
               __ZdlPv($1484);
              }
              $1485 = HEAP8[$110>>0]|0;
              $1486 = $1485 & 1;
              $1487 = ($1486<<24>>24)==(0);
              if ($1487) {
               $$24 = $1480;$$2433 = $1479;
               ___resumeException($$2433|0);
               // unreachable;
              }
              $1488 = (($110) + 8|0);
              $1489 = HEAP32[$1488>>2]|0;
              __ZdlPv($1489);
              $$24 = $1480;$$2433 = $1479;
              ___resumeException($$2433|0);
              // unreachable;
             }
             $574 = HEAP8[$111>>0]|0;
             $575 = $574 & 1;
             $576 = ($575<<24>>24)==(0);
             if (!($576)) {
              $577 = HEAP32[$565>>2]|0;
              __ZdlPv($577);
             }
             $578 = HEAP8[$110>>0]|0;
             $579 = $578 & 1;
             $580 = ($579<<24>>24)==(0);
             if (!($580)) {
              $581 = (($110) + 8|0);
              $582 = HEAP32[$581>>2]|0;
              __ZdlPv($582);
             }
             $583 = HEAP32[$139>>2]|0;
             $584 = (($583) + 276|0);
             HEAP8[$112>>0] = 16;
             $585 = (($112) + 1|0);
             $586 = $585;
             $587 = $586;
             HEAP8[$587>>0]=1952867692&255;HEAP8[$587+1>>0]=(1952867692>>8)&255;HEAP8[$587+2>>0]=(1952867692>>16)&255;HEAP8[$587+3>>0]=1952867692>>24;
             $588 = (($586) + 4)|0;
             $589 = $588;
             HEAP8[$589>>0]=1953259808&255;HEAP8[$589+1>>0]=(1953259808>>8)&255;HEAP8[$589+2>>0]=(1953259808>>16)&255;HEAP8[$589+3>>0]=1953259808>>24;
             $590 = (($112) + 9|0);
             HEAP8[$590>>0] = 0;
             $591 = HEAP32[613088>>2]|0;
             __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$591,$112);
             $592 = HEAP32[613088>>2]|0;
             $593 = (($592) + 4|0);
             $594 = HEAP32[$$byval_copy89>>2]|0;
             $595 = ($594|0)==($593|0);
             if ($595) {
              $$0$i190 = 0;
             } else {
              $596 = (($594) + 28|0);
              $597 = HEAP32[$596>>2]|0;
              $$0$i190 = $597;
             }
             HEAP8[$113>>0] = 14;
             $598 = (($113) + 1|0);
             ;HEAP8[$598+0>>0]=HEAP8[612952+0>>0]|0;HEAP8[$598+1>>0]=HEAP8[612952+1>>0]|0;HEAP8[$598+2>>0]=HEAP8[612952+2>>0]|0;HEAP8[$598+3>>0]=HEAP8[612952+3>>0]|0;HEAP8[$598+4>>0]=HEAP8[612952+4>>0]|0;HEAP8[$598+5>>0]=HEAP8[612952+5>>0]|0;HEAP8[$598+6>>0]=HEAP8[612952+6>>0]|0;
             $599 = (($113) + 8|0);
             HEAP8[$599>>0] = 0;
             __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$592,$113);
             $600 = HEAP32[613088>>2]|0;
             $601 = (($600) + 4|0);
             $602 = HEAP32[$$byval_copy89>>2]|0;
             $603 = ($602|0)==($601|0);
             if ($603) {
              $$0$i199 = 0;
             } else {
              $604 = (($602) + 28|0);
              $605 = HEAP32[$604>>2]|0;
              $$0$i199 = $605;
             }
             __THREW__ = 0;
             invoke_viii(1764,($584|0),($$0$i190|0),($$0$i199|0));
             $606 = __THREW__; __THREW__ = 0;
             $607 = $606&1;
             if ($607) {
              $1490 = ___cxa_find_matching_catch()|0;
              $1491 = tempRet0;
              $1492 = HEAP8[$113>>0]|0;
              $1493 = $1492 & 1;
              $1494 = ($1493<<24>>24)==(0);
              if (!($1494)) {
               $1495 = HEAP32[$599>>2]|0;
               __ZdlPv($1495);
              }
              $1496 = HEAP8[$112>>0]|0;
              $1497 = $1496 & 1;
              $1498 = ($1497<<24>>24)==(0);
              if ($1498) {
               $$24 = $1491;$$2433 = $1490;
               ___resumeException($$2433|0);
               // unreachable;
              }
              $1499 = (($112) + 8|0);
              $1500 = HEAP32[$1499>>2]|0;
              __ZdlPv($1500);
              $$24 = $1491;$$2433 = $1490;
              ___resumeException($$2433|0);
              // unreachable;
             }
             $608 = HEAP8[$113>>0]|0;
             $609 = $608 & 1;
             $610 = ($609<<24>>24)==(0);
             if (!($610)) {
              $611 = HEAP32[$599>>2]|0;
              __ZdlPv($611);
             }
             $612 = HEAP8[$112>>0]|0;
             $613 = $612 & 1;
             $614 = ($613<<24>>24)==(0);
             if (!($614)) {
              $615 = (($112) + 8|0);
              $616 = HEAP32[$615>>2]|0;
              __ZdlPv($616);
             }
             $617 = HEAP32[$139>>2]|0;
             $618 = (($617) + 368|0);
             HEAP8[$114>>0] = 16;
             $619 = (($114) + 1|0);
             $620 = $619;
             $621 = $620;
             HEAP8[$621>>0]=1952867692&255;HEAP8[$621+1>>0]=(1952867692>>8)&255;HEAP8[$621+2>>0]=(1952867692>>16)&255;HEAP8[$621+3>>0]=1952867692>>24;
             $622 = (($620) + 4)|0;
             $623 = $622;
             HEAP8[$623>>0]=1684890400&255;HEAP8[$623+1>>0]=(1684890400>>8)&255;HEAP8[$623+2>>0]=(1684890400>>16)&255;HEAP8[$623+3>>0]=1684890400>>24;
             $624 = (($114) + 9|0);
             HEAP8[$624>>0] = 0;
             $625 = HEAP32[613088>>2]|0;
             __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$625,$114);
             $626 = HEAP32[613088>>2]|0;
             $627 = (($626) + 4|0);
             $628 = HEAP32[$$byval_copy89>>2]|0;
             $629 = ($628|0)==($627|0);
             if ($629) {
              $$0$i208 = 0;
             } else {
              $630 = (($628) + 28|0);
              $631 = HEAP32[$630>>2]|0;
              $$0$i208 = $631;
             }
             HEAP8[$115>>0] = 14;
             $632 = (($115) + 1|0);
             ;HEAP8[$632+0>>0]=HEAP8[612976+0>>0]|0;HEAP8[$632+1>>0]=HEAP8[612976+1>>0]|0;HEAP8[$632+2>>0]=HEAP8[612976+2>>0]|0;HEAP8[$632+3>>0]=HEAP8[612976+3>>0]|0;HEAP8[$632+4>>0]=HEAP8[612976+4>>0]|0;HEAP8[$632+5>>0]=HEAP8[612976+5>>0]|0;HEAP8[$632+6>>0]=HEAP8[612976+6>>0]|0;
             $633 = (($115) + 8|0);
             HEAP8[$633>>0] = 0;
             __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$626,$115);
             $634 = HEAP32[613088>>2]|0;
             $635 = (($634) + 4|0);
             $636 = HEAP32[$$byval_copy89>>2]|0;
             $637 = ($636|0)==($635|0);
             if ($637) {
              $$0$i217 = 0;
             } else {
              $638 = (($636) + 28|0);
              $639 = HEAP32[$638>>2]|0;
              $$0$i217 = $639;
             }
             __THREW__ = 0;
             invoke_viii(1764,($618|0),($$0$i208|0),($$0$i217|0));
             $640 = __THREW__; __THREW__ = 0;
             $641 = $640&1;
             if ($641) {
              $1501 = ___cxa_find_matching_catch()|0;
              $1502 = tempRet0;
              $1503 = HEAP8[$115>>0]|0;
              $1504 = $1503 & 1;
              $1505 = ($1504<<24>>24)==(0);
              if (!($1505)) {
               $1506 = HEAP32[$633>>2]|0;
               __ZdlPv($1506);
              }
              $1507 = HEAP8[$114>>0]|0;
              $1508 = $1507 & 1;
              $1509 = ($1508<<24>>24)==(0);
              if ($1509) {
               $$24 = $1502;$$2433 = $1501;
               ___resumeException($$2433|0);
               // unreachable;
              }
              $1510 = (($114) + 8|0);
              $1511 = HEAP32[$1510>>2]|0;
              __ZdlPv($1511);
              $$24 = $1502;$$2433 = $1501;
              ___resumeException($$2433|0);
              // unreachable;
             }
             $642 = HEAP8[$115>>0]|0;
             $643 = $642 & 1;
             $644 = ($643<<24>>24)==(0);
             if (!($644)) {
              $645 = HEAP32[$633>>2]|0;
              __ZdlPv($645);
             }
             $646 = HEAP8[$114>>0]|0;
             $647 = $646 & 1;
             $648 = ($647<<24>>24)==(0);
             if (!($648)) {
              $649 = (($114) + 8|0);
              $650 = HEAP32[$649>>2]|0;
              __ZdlPv($650);
             }
             $651 = HEAP32[$139>>2]|0;
             $652 = (($651) + 460|0);
             HEAP8[$116>>0] = 10;
             $653 = (($116) + 1|0);
             ;HEAP8[$653+0>>0]=HEAP8[612760+0>>0]|0;HEAP8[$653+1>>0]=HEAP8[612760+1>>0]|0;HEAP8[$653+2>>0]=HEAP8[612760+2>>0]|0;HEAP8[$653+3>>0]=HEAP8[612760+3>>0]|0;HEAP8[$653+4>>0]=HEAP8[612760+4>>0]|0;
             $654 = (($116) + 6|0);
             HEAP8[$654>>0] = 0;
             $655 = HEAP32[613088>>2]|0;
             __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$655,$116);
             $656 = HEAP32[613088>>2]|0;
             $657 = (($656) + 4|0);
             $658 = HEAP32[$$byval_copy89>>2]|0;
             $659 = ($658|0)==($657|0);
             if ($659) {
              $$0$i226 = 0;
             } else {
              $660 = (($658) + 28|0);
              $661 = HEAP32[$660>>2]|0;
              $$0$i226 = $661;
             }
             __THREW__ = 0;
             invoke_viii(1764,($652|0),($$0$i226|0),0);
             $662 = __THREW__; __THREW__ = 0;
             $663 = $662&1;
             if ($663) {
              $1512 = ___cxa_find_matching_catch()|0;
              $1513 = tempRet0;
              $1514 = HEAP8[$116>>0]|0;
              $1515 = $1514 & 1;
              $1516 = ($1515<<24>>24)==(0);
              if ($1516) {
               $$24 = $1513;$$2433 = $1512;
               ___resumeException($$2433|0);
               // unreachable;
              }
              $1517 = (($116) + 8|0);
              $1518 = HEAP32[$1517>>2]|0;
              __ZdlPv($1518);
              $$24 = $1513;$$2433 = $1512;
              ___resumeException($$2433|0);
              // unreachable;
             }
             $664 = HEAP8[$116>>0]|0;
             $665 = $664 & 1;
             $666 = ($665<<24>>24)==(0);
             if (!($666)) {
              $667 = (($116) + 8|0);
              $668 = HEAP32[$667>>2]|0;
              __ZdlPv($668);
             }
             HEAP8[$118>>0] = 14;
             $669 = (($118) + 1|0);
             ;HEAP8[$669+0>>0]=HEAP8[612984+0>>0]|0;HEAP8[$669+1>>0]=HEAP8[612984+1>>0]|0;HEAP8[$669+2>>0]=HEAP8[612984+2>>0]|0;HEAP8[$669+3>>0]=HEAP8[612984+3>>0]|0;HEAP8[$669+4>>0]=HEAP8[612984+4>>0]|0;HEAP8[$669+5>>0]=HEAP8[612984+5>>0]|0;HEAP8[$669+6>>0]=HEAP8[612984+6>>0]|0;
             $670 = (($118) + 8|0);
             HEAP8[$670>>0] = 0;
             __THREW__ = 0;
             invoke_vii(2744,($117|0),($118|0));
             $671 = __THREW__; __THREW__ = 0;
             $672 = $671&1;
             do {
              if ($672) {
               $1519 = ___cxa_find_matching_catch()|0;
               $1520 = tempRet0;
               $$15 = $1520;$$1524 = $1519;
              } else {
               $673 = HEAP32[$144>>2]|0;
               $674 = HEAP32[$146>>2]|0;
               $675 = ($673|0)==($674|0);
               do {
                if ($675) {
                 __THREW__ = 0;
                 invoke_vii(2746,($139|0),($117|0));
                 $681 = __THREW__; __THREW__ = 0;
                 $682 = $681&1;
                 if ($682) {
                  label = 461;
                 }
                } else {
                 $676 = ($673|0)==(0|0);
                 if ($676) {
                  $680 = 0;
                 } else {
                  __THREW__ = 0;
                  invoke_vii(2745,($673|0),($117|0));
                  $677 = __THREW__; __THREW__ = 0;
                  $678 = $677&1;
                  if ($678) {
                   label = 461;
                   break;
                  }
                  $$pre$i232 = HEAP32[$144>>2]|0;
                  $680 = $$pre$i232;
                 }
                 $679 = (($680) + 92|0);
                 HEAP32[$144>>2] = $679;
                }
               } while(0);
               if ((label|0) == 461) {
                $1521 = ___cxa_find_matching_catch()|0;
                $1522 = tempRet0;
                HEAP32[$117>>2] = ((612552 + 8|0));
                $1523 = (($117) + 28|0);
                $1524 = HEAP8[$1523>>0]|0;
                $1525 = $1524 & 1;
                $1526 = ($1525<<24>>24)==(0);
                do {
                 if (!($1526)) {
                  $1527 = (($117) + 36|0);
                  $1528 = HEAP32[$1527>>2]|0;
                  HEAP32[$26>>2] = 59;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$26+0>>2]|0;
                  invoke_vii(2591,($1528|0),($$byval_copy89|0));
                  $1529 = __THREW__; __THREW__ = 0;
                  $1530 = $1529&1;
                  if (!($1530)) {
                   break;
                  }
                  $1531 = ___cxa_find_matching_catch()|0;
                  $1532 = tempRet0;
                  ___cxa_call_unexpected(($1531|0));
                  // unreachable;
                 }
                } while(0);
                $1533 = (($117) + 16|0);
                $1534 = HEAP8[$1533>>0]|0;
                $1535 = $1534 & 1;
                $1536 = ($1535<<24>>24)==(0);
                do {
                 if (!($1536)) {
                  $1537 = (($117) + 24|0);
                  $1538 = HEAP32[$1537>>2]|0;
                  HEAP32[$25>>2] = 59;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$25+0>>2]|0;
                  invoke_vii(2591,($1538|0),($$byval_copy89|0));
                  $1539 = __THREW__; __THREW__ = 0;
                  $1540 = $1539&1;
                  if (!($1540)) {
                   break;
                  }
                  $1541 = ___cxa_find_matching_catch()|0;
                  $1542 = tempRet0;
                  ___cxa_call_unexpected(($1541|0));
                  // unreachable;
                 }
                } while(0);
                $1543 = (($117) + 4|0);
                $1544 = HEAP8[$1543>>0]|0;
                $1545 = $1544 & 1;
                $1546 = ($1545<<24>>24)==(0);
                if ($1546) {
                 $$15 = $1522;$$1524 = $1521;
                 break;
                }
                $1547 = (($117) + 12|0);
                $1548 = HEAP32[$1547>>2]|0;
                HEAP32[$24>>2] = 59;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$24+0>>2]|0;
                invoke_vii(2591,($1548|0),($$byval_copy89|0));
                $1549 = __THREW__; __THREW__ = 0;
                $1550 = $1549&1;
                if (!($1550)) {
                 $$15 = $1522;$$1524 = $1521;
                 break;
                }
                $1551 = ___cxa_find_matching_catch()|0;
                $1552 = tempRet0;
                ___cxa_call_unexpected(($1551|0));
                // unreachable;
               }
               HEAP32[$117>>2] = ((612552 + 8|0));
               $683 = (($117) + 28|0);
               $684 = HEAP8[$683>>0]|0;
               $685 = $684 & 1;
               $686 = ($685<<24>>24)==(0);
               do {
                if (!($686)) {
                 $687 = (($117) + 36|0);
                 $688 = HEAP32[$687>>2]|0;
                 HEAP32[$71>>2] = 59;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$71+0>>2]|0;
                 invoke_vii(2591,($688|0),($$byval_copy89|0));
                 $689 = __THREW__; __THREW__ = 0;
                 $690 = $689&1;
                 if (!($690)) {
                  break;
                 }
                 $691 = ___cxa_find_matching_catch()|0;
                 $692 = tempRet0;
                 ___cxa_call_unexpected(($691|0));
                 // unreachable;
                }
               } while(0);
               $693 = (($117) + 16|0);
               $694 = HEAP8[$693>>0]|0;
               $695 = $694 & 1;
               $696 = ($695<<24>>24)==(0);
               do {
                if (!($696)) {
                 $697 = (($117) + 24|0);
                 $698 = HEAP32[$697>>2]|0;
                 HEAP32[$70>>2] = 59;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$70+0>>2]|0;
                 invoke_vii(2591,($698|0),($$byval_copy89|0));
                 $699 = __THREW__; __THREW__ = 0;
                 $700 = $699&1;
                 if (!($700)) {
                  break;
                 }
                 $701 = ___cxa_find_matching_catch()|0;
                 $702 = tempRet0;
                 ___cxa_call_unexpected(($701|0));
                 // unreachable;
                }
               } while(0);
               $703 = (($117) + 4|0);
               $704 = HEAP8[$703>>0]|0;
               $705 = $704 & 1;
               $706 = ($705<<24>>24)==(0);
               do {
                if (!($706)) {
                 $707 = (($117) + 12|0);
                 $708 = HEAP32[$707>>2]|0;
                 HEAP32[$69>>2] = 59;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$69+0>>2]|0;
                 invoke_vii(2591,($708|0),($$byval_copy89|0));
                 $709 = __THREW__; __THREW__ = 0;
                 $710 = $709&1;
                 if (!($710)) {
                  break;
                 }
                 $711 = ___cxa_find_matching_catch()|0;
                 $712 = tempRet0;
                 ___cxa_call_unexpected(($711|0));
                 // unreachable;
                }
               } while(0);
               $713 = HEAP8[$118>>0]|0;
               $714 = $713 & 1;
               $715 = ($714<<24>>24)==(0);
               if (!($715)) {
                $716 = HEAP32[$670>>2]|0;
                __ZdlPv($716);
               }
               HEAP8[$120>>0] = 14;
               $717 = (($120) + 1|0);
               ;HEAP8[$717+0>>0]=HEAP8[612992+0>>0]|0;HEAP8[$717+1>>0]=HEAP8[612992+1>>0]|0;HEAP8[$717+2>>0]=HEAP8[612992+2>>0]|0;HEAP8[$717+3>>0]=HEAP8[612992+3>>0]|0;HEAP8[$717+4>>0]=HEAP8[612992+4>>0]|0;HEAP8[$717+5>>0]=HEAP8[612992+5>>0]|0;HEAP8[$717+6>>0]=HEAP8[612992+6>>0]|0;
               $718 = (($120) + 8|0);
               HEAP8[$718>>0] = 0;
               __THREW__ = 0;
               invoke_vii(2744,($119|0),($120|0));
               $719 = __THREW__; __THREW__ = 0;
               $720 = $719&1;
               do {
                if ($720) {
                 $1557 = ___cxa_find_matching_catch()|0;
                 $1558 = tempRet0;
                 $$16 = $1558;$$1625 = $1557;
                } else {
                 $721 = HEAP32[$144>>2]|0;
                 $722 = HEAP32[$146>>2]|0;
                 $723 = ($721|0)==($722|0);
                 do {
                  if ($723) {
                   __THREW__ = 0;
                   invoke_vii(2746,($139|0),($119|0));
                   $729 = __THREW__; __THREW__ = 0;
                   $730 = $729&1;
                   if ($730) {
                    label = 473;
                   }
                  } else {
                   $724 = ($721|0)==(0|0);
                   if ($724) {
                    $728 = 0;
                   } else {
                    __THREW__ = 0;
                    invoke_vii(2745,($721|0),($119|0));
                    $725 = __THREW__; __THREW__ = 0;
                    $726 = $725&1;
                    if ($726) {
                     label = 473;
                     break;
                    }
                    $$pre$i244 = HEAP32[$144>>2]|0;
                    $728 = $$pre$i244;
                   }
                   $727 = (($728) + 92|0);
                   HEAP32[$144>>2] = $727;
                  }
                 } while(0);
                 if ((label|0) == 473) {
                  $1559 = ___cxa_find_matching_catch()|0;
                  $1560 = tempRet0;
                  HEAP32[$119>>2] = ((612552 + 8|0));
                  $1561 = (($119) + 28|0);
                  $1562 = HEAP8[$1561>>0]|0;
                  $1563 = $1562 & 1;
                  $1564 = ($1563<<24>>24)==(0);
                  do {
                   if (!($1564)) {
                    $1565 = (($119) + 36|0);
                    $1566 = HEAP32[$1565>>2]|0;
                    HEAP32[$23>>2] = 59;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$23+0>>2]|0;
                    invoke_vii(2591,($1566|0),($$byval_copy89|0));
                    $1567 = __THREW__; __THREW__ = 0;
                    $1568 = $1567&1;
                    if (!($1568)) {
                     break;
                    }
                    $1569 = ___cxa_find_matching_catch()|0;
                    $1570 = tempRet0;
                    ___cxa_call_unexpected(($1569|0));
                    // unreachable;
                   }
                  } while(0);
                  $1571 = (($119) + 16|0);
                  $1572 = HEAP8[$1571>>0]|0;
                  $1573 = $1572 & 1;
                  $1574 = ($1573<<24>>24)==(0);
                  do {
                   if (!($1574)) {
                    $1575 = (($119) + 24|0);
                    $1576 = HEAP32[$1575>>2]|0;
                    HEAP32[$22>>2] = 59;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$22+0>>2]|0;
                    invoke_vii(2591,($1576|0),($$byval_copy89|0));
                    $1577 = __THREW__; __THREW__ = 0;
                    $1578 = $1577&1;
                    if (!($1578)) {
                     break;
                    }
                    $1579 = ___cxa_find_matching_catch()|0;
                    $1580 = tempRet0;
                    ___cxa_call_unexpected(($1579|0));
                    // unreachable;
                   }
                  } while(0);
                  $1581 = (($119) + 4|0);
                  $1582 = HEAP8[$1581>>0]|0;
                  $1583 = $1582 & 1;
                  $1584 = ($1583<<24>>24)==(0);
                  if ($1584) {
                   $$16 = $1560;$$1625 = $1559;
                   break;
                  }
                  $1585 = (($119) + 12|0);
                  $1586 = HEAP32[$1585>>2]|0;
                  HEAP32[$21>>2] = 59;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$21+0>>2]|0;
                  invoke_vii(2591,($1586|0),($$byval_copy89|0));
                  $1587 = __THREW__; __THREW__ = 0;
                  $1588 = $1587&1;
                  if (!($1588)) {
                   $$16 = $1560;$$1625 = $1559;
                   break;
                  }
                  $1589 = ___cxa_find_matching_catch()|0;
                  $1590 = tempRet0;
                  ___cxa_call_unexpected(($1589|0));
                  // unreachable;
                 }
                 HEAP32[$119>>2] = ((612552 + 8|0));
                 $731 = (($119) + 28|0);
                 $732 = HEAP8[$731>>0]|0;
                 $733 = $732 & 1;
                 $734 = ($733<<24>>24)==(0);
                 do {
                  if (!($734)) {
                   $735 = (($119) + 36|0);
                   $736 = HEAP32[$735>>2]|0;
                   HEAP32[$68>>2] = 59;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$68+0>>2]|0;
                   invoke_vii(2591,($736|0),($$byval_copy89|0));
                   $737 = __THREW__; __THREW__ = 0;
                   $738 = $737&1;
                   if (!($738)) {
                    break;
                   }
                   $739 = ___cxa_find_matching_catch()|0;
                   $740 = tempRet0;
                   ___cxa_call_unexpected(($739|0));
                   // unreachable;
                  }
                 } while(0);
                 $741 = (($119) + 16|0);
                 $742 = HEAP8[$741>>0]|0;
                 $743 = $742 & 1;
                 $744 = ($743<<24>>24)==(0);
                 do {
                  if (!($744)) {
                   $745 = (($119) + 24|0);
                   $746 = HEAP32[$745>>2]|0;
                   HEAP32[$67>>2] = 59;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$67+0>>2]|0;
                   invoke_vii(2591,($746|0),($$byval_copy89|0));
                   $747 = __THREW__; __THREW__ = 0;
                   $748 = $747&1;
                   if (!($748)) {
                    break;
                   }
                   $749 = ___cxa_find_matching_catch()|0;
                   $750 = tempRet0;
                   ___cxa_call_unexpected(($749|0));
                   // unreachable;
                  }
                 } while(0);
                 $751 = (($119) + 4|0);
                 $752 = HEAP8[$751>>0]|0;
                 $753 = $752 & 1;
                 $754 = ($753<<24>>24)==(0);
                 do {
                  if (!($754)) {
                   $755 = (($119) + 12|0);
                   $756 = HEAP32[$755>>2]|0;
                   HEAP32[$66>>2] = 59;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$66+0>>2]|0;
                   invoke_vii(2591,($756|0),($$byval_copy89|0));
                   $757 = __THREW__; __THREW__ = 0;
                   $758 = $757&1;
                   if (!($758)) {
                    break;
                   }
                   $759 = ___cxa_find_matching_catch()|0;
                   $760 = tempRet0;
                   ___cxa_call_unexpected(($759|0));
                   // unreachable;
                  }
                 } while(0);
                 $761 = HEAP8[$120>>0]|0;
                 $762 = $761 & 1;
                 $763 = ($762<<24>>24)==(0);
                 if (!($763)) {
                  $764 = HEAP32[$718>>2]|0;
                  __ZdlPv($764);
                 }
                 $765 = (__Znwj(32)|0);
                 $766 = (($122) + 8|0);
                 HEAP32[$766>>2] = $765;
                 HEAP32[$122>>2] = 33;
                 $767 = (($122) + 4|0);
                 HEAP32[$767>>2] = 17;
                 dest=$765+0|0; src=613000+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                 $768 = (($765) + 17|0);
                 HEAP8[$768>>0] = 0;
                 __THREW__ = 0;
                 invoke_vii(2744,($121|0),($122|0));
                 $769 = __THREW__; __THREW__ = 0;
                 $770 = $769&1;
                 do {
                  if ($770) {
                   $1595 = ___cxa_find_matching_catch()|0;
                   $1596 = tempRet0;
                   $$17 = $1596;$$1726 = $1595;
                  } else {
                   $771 = HEAP32[$144>>2]|0;
                   $772 = HEAP32[$146>>2]|0;
                   $773 = ($771|0)==($772|0);
                   do {
                    if ($773) {
                     __THREW__ = 0;
                     invoke_vii(2746,($139|0),($121|0));
                     $779 = __THREW__; __THREW__ = 0;
                     $780 = $779&1;
                     if ($780) {
                      label = 485;
                     }
                    } else {
                     $774 = ($771|0)==(0|0);
                     if ($774) {
                      $778 = 0;
                     } else {
                      __THREW__ = 0;
                      invoke_vii(2745,($771|0),($121|0));
                      $775 = __THREW__; __THREW__ = 0;
                      $776 = $775&1;
                      if ($776) {
                       label = 485;
                       break;
                      }
                      $$pre$i256 = HEAP32[$144>>2]|0;
                      $778 = $$pre$i256;
                     }
                     $777 = (($778) + 92|0);
                     HEAP32[$144>>2] = $777;
                    }
                   } while(0);
                   if ((label|0) == 485) {
                    $1597 = ___cxa_find_matching_catch()|0;
                    $1598 = tempRet0;
                    HEAP32[$121>>2] = ((612552 + 8|0));
                    $1599 = (($121) + 28|0);
                    $1600 = HEAP8[$1599>>0]|0;
                    $1601 = $1600 & 1;
                    $1602 = ($1601<<24>>24)==(0);
                    do {
                     if (!($1602)) {
                      $1603 = (($121) + 36|0);
                      $1604 = HEAP32[$1603>>2]|0;
                      HEAP32[$20>>2] = 59;
                      __THREW__ = 0;
                      ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$20+0>>2]|0;
                      invoke_vii(2591,($1604|0),($$byval_copy89|0));
                      $1605 = __THREW__; __THREW__ = 0;
                      $1606 = $1605&1;
                      if (!($1606)) {
                       break;
                      }
                      $1607 = ___cxa_find_matching_catch()|0;
                      $1608 = tempRet0;
                      ___cxa_call_unexpected(($1607|0));
                      // unreachable;
                     }
                    } while(0);
                    $1609 = (($121) + 16|0);
                    $1610 = HEAP8[$1609>>0]|0;
                    $1611 = $1610 & 1;
                    $1612 = ($1611<<24>>24)==(0);
                    do {
                     if (!($1612)) {
                      $1613 = (($121) + 24|0);
                      $1614 = HEAP32[$1613>>2]|0;
                      HEAP32[$19>>2] = 59;
                      __THREW__ = 0;
                      ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$19+0>>2]|0;
                      invoke_vii(2591,($1614|0),($$byval_copy89|0));
                      $1615 = __THREW__; __THREW__ = 0;
                      $1616 = $1615&1;
                      if (!($1616)) {
                       break;
                      }
                      $1617 = ___cxa_find_matching_catch()|0;
                      $1618 = tempRet0;
                      ___cxa_call_unexpected(($1617|0));
                      // unreachable;
                     }
                    } while(0);
                    $1619 = (($121) + 4|0);
                    $1620 = HEAP8[$1619>>0]|0;
                    $1621 = $1620 & 1;
                    $1622 = ($1621<<24>>24)==(0);
                    if ($1622) {
                     $$17 = $1598;$$1726 = $1597;
                     break;
                    }
                    $1623 = (($121) + 12|0);
                    $1624 = HEAP32[$1623>>2]|0;
                    HEAP32[$18>>2] = 59;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$18+0>>2]|0;
                    invoke_vii(2591,($1624|0),($$byval_copy89|0));
                    $1625 = __THREW__; __THREW__ = 0;
                    $1626 = $1625&1;
                    if (!($1626)) {
                     $$17 = $1598;$$1726 = $1597;
                     break;
                    }
                    $1627 = ___cxa_find_matching_catch()|0;
                    $1628 = tempRet0;
                    ___cxa_call_unexpected(($1627|0));
                    // unreachable;
                   }
                   HEAP32[$121>>2] = ((612552 + 8|0));
                   $781 = (($121) + 28|0);
                   $782 = HEAP8[$781>>0]|0;
                   $783 = $782 & 1;
                   $784 = ($783<<24>>24)==(0);
                   do {
                    if (!($784)) {
                     $785 = (($121) + 36|0);
                     $786 = HEAP32[$785>>2]|0;
                     HEAP32[$65>>2] = 59;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$65+0>>2]|0;
                     invoke_vii(2591,($786|0),($$byval_copy89|0));
                     $787 = __THREW__; __THREW__ = 0;
                     $788 = $787&1;
                     if (!($788)) {
                      break;
                     }
                     $789 = ___cxa_find_matching_catch()|0;
                     $790 = tempRet0;
                     ___cxa_call_unexpected(($789|0));
                     // unreachable;
                    }
                   } while(0);
                   $791 = (($121) + 16|0);
                   $792 = HEAP8[$791>>0]|0;
                   $793 = $792 & 1;
                   $794 = ($793<<24>>24)==(0);
                   do {
                    if (!($794)) {
                     $795 = (($121) + 24|0);
                     $796 = HEAP32[$795>>2]|0;
                     HEAP32[$64>>2] = 59;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$64+0>>2]|0;
                     invoke_vii(2591,($796|0),($$byval_copy89|0));
                     $797 = __THREW__; __THREW__ = 0;
                     $798 = $797&1;
                     if (!($798)) {
                      break;
                     }
                     $799 = ___cxa_find_matching_catch()|0;
                     $800 = tempRet0;
                     ___cxa_call_unexpected(($799|0));
                     // unreachable;
                    }
                   } while(0);
                   $801 = (($121) + 4|0);
                   $802 = HEAP8[$801>>0]|0;
                   $803 = $802 & 1;
                   $804 = ($803<<24>>24)==(0);
                   do {
                    if (!($804)) {
                     $805 = (($121) + 12|0);
                     $806 = HEAP32[$805>>2]|0;
                     HEAP32[$63>>2] = 59;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$63+0>>2]|0;
                     invoke_vii(2591,($806|0),($$byval_copy89|0));
                     $807 = __THREW__; __THREW__ = 0;
                     $808 = $807&1;
                     if (!($808)) {
                      break;
                     }
                     $809 = ___cxa_find_matching_catch()|0;
                     $810 = tempRet0;
                     ___cxa_call_unexpected(($809|0));
                     // unreachable;
                    }
                   } while(0);
                   $811 = HEAP8[$122>>0]|0;
                   $812 = $811 & 1;
                   $813 = ($812<<24>>24)==(0);
                   if (!($813)) {
                    $814 = HEAP32[$766>>2]|0;
                    __ZdlPv($814);
                   }
                   $815 = HEAP32[$139>>2]|0;
                   $816 = (($815) + 552|0);
                   __ZN9InputAxis9MakeMouseEi($816,0);
                   $817 = HEAP32[$139>>2]|0;
                   $818 = (($817) + 644|0);
                   __ZN9InputAxis9MakeMouseEi($818,1);
                   $819 = HEAP32[$139>>2]|0;
                   $820 = (($819) + 736|0);
                   __ZN9InputAxis9MakeMouseEi($820,2);
                   HEAP8[$124>>0] = 20;
                   $821 = (($124) + 1|0);
                   dest=$821+0|0; src=612808+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $822 = (($124) + 11|0);
                   HEAP8[$822>>0] = 0;
                   __THREW__ = 0;
                   invoke_vii(2744,($123|0),($124|0));
                   $823 = __THREW__; __THREW__ = 0;
                   $824 = $823&1;
                   do {
                    if ($824) {
                     $1633 = ___cxa_find_matching_catch()|0;
                     $1634 = tempRet0;
                     $$18 = $1634;$$1827 = $1633;
                    } else {
                     $825 = HEAP32[$144>>2]|0;
                     $826 = HEAP32[$146>>2]|0;
                     $827 = ($825|0)==($826|0);
                     do {
                      if ($827) {
                       __THREW__ = 0;
                       invoke_vii(2746,($139|0),($123|0));
                       $833 = __THREW__; __THREW__ = 0;
                       $834 = $833&1;
                       if ($834) {
                        label = 497;
                       }
                      } else {
                       $828 = ($825|0)==(0|0);
                       if ($828) {
                        $832 = 0;
                       } else {
                        __THREW__ = 0;
                        invoke_vii(2745,($825|0),($123|0));
                        $829 = __THREW__; __THREW__ = 0;
                        $830 = $829&1;
                        if ($830) {
                         label = 497;
                         break;
                        }
                        $$pre$i268 = HEAP32[$144>>2]|0;
                        $832 = $$pre$i268;
                       }
                       $831 = (($832) + 92|0);
                       HEAP32[$144>>2] = $831;
                      }
                     } while(0);
                     if ((label|0) == 497) {
                      $1635 = ___cxa_find_matching_catch()|0;
                      $1636 = tempRet0;
                      HEAP32[$123>>2] = ((612552 + 8|0));
                      $1637 = (($123) + 28|0);
                      $1638 = HEAP8[$1637>>0]|0;
                      $1639 = $1638 & 1;
                      $1640 = ($1639<<24>>24)==(0);
                      do {
                       if (!($1640)) {
                        $1641 = (($123) + 36|0);
                        $1642 = HEAP32[$1641>>2]|0;
                        HEAP32[$17>>2] = 59;
                        __THREW__ = 0;
                        ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$17+0>>2]|0;
                        invoke_vii(2591,($1642|0),($$byval_copy89|0));
                        $1643 = __THREW__; __THREW__ = 0;
                        $1644 = $1643&1;
                        if (!($1644)) {
                         break;
                        }
                        $1645 = ___cxa_find_matching_catch()|0;
                        $1646 = tempRet0;
                        ___cxa_call_unexpected(($1645|0));
                        // unreachable;
                       }
                      } while(0);
                      $1647 = (($123) + 16|0);
                      $1648 = HEAP8[$1647>>0]|0;
                      $1649 = $1648 & 1;
                      $1650 = ($1649<<24>>24)==(0);
                      do {
                       if (!($1650)) {
                        $1651 = (($123) + 24|0);
                        $1652 = HEAP32[$1651>>2]|0;
                        HEAP32[$16>>2] = 59;
                        __THREW__ = 0;
                        ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$16+0>>2]|0;
                        invoke_vii(2591,($1652|0),($$byval_copy89|0));
                        $1653 = __THREW__; __THREW__ = 0;
                        $1654 = $1653&1;
                        if (!($1654)) {
                         break;
                        }
                        $1655 = ___cxa_find_matching_catch()|0;
                        $1656 = tempRet0;
                        ___cxa_call_unexpected(($1655|0));
                        // unreachable;
                       }
                      } while(0);
                      $1657 = (($123) + 4|0);
                      $1658 = HEAP8[$1657>>0]|0;
                      $1659 = $1658 & 1;
                      $1660 = ($1659<<24>>24)==(0);
                      if ($1660) {
                       $$18 = $1636;$$1827 = $1635;
                       break;
                      }
                      $1661 = (($123) + 12|0);
                      $1662 = HEAP32[$1661>>2]|0;
                      HEAP32[$15>>2] = 59;
                      __THREW__ = 0;
                      ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$15+0>>2]|0;
                      invoke_vii(2591,($1662|0),($$byval_copy89|0));
                      $1663 = __THREW__; __THREW__ = 0;
                      $1664 = $1663&1;
                      if (!($1664)) {
                       $$18 = $1636;$$1827 = $1635;
                       break;
                      }
                      $1665 = ___cxa_find_matching_catch()|0;
                      $1666 = tempRet0;
                      ___cxa_call_unexpected(($1665|0));
                      // unreachable;
                     }
                     HEAP32[$123>>2] = ((612552 + 8|0));
                     $835 = (($123) + 28|0);
                     $836 = HEAP8[$835>>0]|0;
                     $837 = $836 & 1;
                     $838 = ($837<<24>>24)==(0);
                     do {
                      if (!($838)) {
                       $839 = (($123) + 36|0);
                       $840 = HEAP32[$839>>2]|0;
                       HEAP32[$62>>2] = 59;
                       __THREW__ = 0;
                       ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$62+0>>2]|0;
                       invoke_vii(2591,($840|0),($$byval_copy89|0));
                       $841 = __THREW__; __THREW__ = 0;
                       $842 = $841&1;
                       if (!($842)) {
                        break;
                       }
                       $843 = ___cxa_find_matching_catch()|0;
                       $844 = tempRet0;
                       ___cxa_call_unexpected(($843|0));
                       // unreachable;
                      }
                     } while(0);
                     $845 = (($123) + 16|0);
                     $846 = HEAP8[$845>>0]|0;
                     $847 = $846 & 1;
                     $848 = ($847<<24>>24)==(0);
                     do {
                      if (!($848)) {
                       $849 = (($123) + 24|0);
                       $850 = HEAP32[$849>>2]|0;
                       HEAP32[$61>>2] = 59;
                       __THREW__ = 0;
                       ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$61+0>>2]|0;
                       invoke_vii(2591,($850|0),($$byval_copy89|0));
                       $851 = __THREW__; __THREW__ = 0;
                       $852 = $851&1;
                       if (!($852)) {
                        break;
                       }
                       $853 = ___cxa_find_matching_catch()|0;
                       $854 = tempRet0;
                       ___cxa_call_unexpected(($853|0));
                       // unreachable;
                      }
                     } while(0);
                     $855 = (($123) + 4|0);
                     $856 = HEAP8[$855>>0]|0;
                     $857 = $856 & 1;
                     $858 = ($857<<24>>24)==(0);
                     do {
                      if (!($858)) {
                       $859 = (($123) + 12|0);
                       $860 = HEAP32[$859>>2]|0;
                       HEAP32[$60>>2] = 59;
                       __THREW__ = 0;
                       ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$60+0>>2]|0;
                       invoke_vii(2591,($860|0),($$byval_copy89|0));
                       $861 = __THREW__; __THREW__ = 0;
                       $862 = $861&1;
                       if (!($862)) {
                        break;
                       }
                       $863 = ___cxa_find_matching_catch()|0;
                       $864 = tempRet0;
                       ___cxa_call_unexpected(($863|0));
                       // unreachable;
                      }
                     } while(0);
                     $865 = HEAP8[$124>>0]|0;
                     $866 = $865 & 1;
                     $867 = ($866<<24>>24)==(0);
                     if (!($867)) {
                      $868 = (($124) + 8|0);
                      $869 = HEAP32[$868>>2]|0;
                      __ZdlPv($869);
                     }
                     HEAP8[$126>>0] = 16;
                     $870 = (($126) + 1|0);
                     $871 = $870;
                     $872 = $871;
                     HEAP8[$872>>0]=1953654102&255;HEAP8[$872+1>>0]=(1953654102>>8)&255;HEAP8[$872+2>>0]=(1953654102>>16)&255;HEAP8[$872+3>>0]=1953654102>>24;
                     $873 = (($871) + 4)|0;
                     $874 = $873;
                     HEAP8[$874>>0]=1818321769&255;HEAP8[$874+1>>0]=(1818321769>>8)&255;HEAP8[$874+2>>0]=(1818321769>>16)&255;HEAP8[$874+3>>0]=1818321769>>24;
                     $875 = (($126) + 9|0);
                     HEAP8[$875>>0] = 0;
                     __THREW__ = 0;
                     invoke_vii(2744,($125|0),($126|0));
                     $876 = __THREW__; __THREW__ = 0;
                     $877 = $876&1;
                     do {
                      if ($877) {
                       $1672 = ___cxa_find_matching_catch()|0;
                       $1673 = tempRet0;
                       $$19 = $1673;$$1928 = $1672;
                      } else {
                       $878 = HEAP32[$144>>2]|0;
                       $879 = HEAP32[$146>>2]|0;
                       $880 = ($878|0)==($879|0);
                       do {
                        if ($880) {
                         __THREW__ = 0;
                         invoke_vii(2746,($139|0),($125|0));
                         $886 = __THREW__; __THREW__ = 0;
                         $887 = $886&1;
                         if ($887) {
                          label = 509;
                         }
                        } else {
                         $881 = ($878|0)==(0|0);
                         if ($881) {
                          $885 = 0;
                         } else {
                          __THREW__ = 0;
                          invoke_vii(2745,($878|0),($125|0));
                          $882 = __THREW__; __THREW__ = 0;
                          $883 = $882&1;
                          if ($883) {
                           label = 509;
                           break;
                          }
                          $$pre$i280 = HEAP32[$144>>2]|0;
                          $885 = $$pre$i280;
                         }
                         $884 = (($885) + 92|0);
                         HEAP32[$144>>2] = $884;
                        }
                       } while(0);
                       if ((label|0) == 509) {
                        $1674 = ___cxa_find_matching_catch()|0;
                        $1675 = tempRet0;
                        HEAP32[$125>>2] = ((612552 + 8|0));
                        $1676 = (($125) + 28|0);
                        $1677 = HEAP8[$1676>>0]|0;
                        $1678 = $1677 & 1;
                        $1679 = ($1678<<24>>24)==(0);
                        do {
                         if (!($1679)) {
                          $1680 = (($125) + 36|0);
                          $1681 = HEAP32[$1680>>2]|0;
                          HEAP32[$14>>2] = 59;
                          __THREW__ = 0;
                          ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$14+0>>2]|0;
                          invoke_vii(2591,($1681|0),($$byval_copy89|0));
                          $1682 = __THREW__; __THREW__ = 0;
                          $1683 = $1682&1;
                          if (!($1683)) {
                           break;
                          }
                          $1684 = ___cxa_find_matching_catch()|0;
                          $1685 = tempRet0;
                          ___cxa_call_unexpected(($1684|0));
                          // unreachable;
                         }
                        } while(0);
                        $1686 = (($125) + 16|0);
                        $1687 = HEAP8[$1686>>0]|0;
                        $1688 = $1687 & 1;
                        $1689 = ($1688<<24>>24)==(0);
                        do {
                         if (!($1689)) {
                          $1690 = (($125) + 24|0);
                          $1691 = HEAP32[$1690>>2]|0;
                          HEAP32[$13>>2] = 59;
                          __THREW__ = 0;
                          ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$13+0>>2]|0;
                          invoke_vii(2591,($1691|0),($$byval_copy89|0));
                          $1692 = __THREW__; __THREW__ = 0;
                          $1693 = $1692&1;
                          if (!($1693)) {
                           break;
                          }
                          $1694 = ___cxa_find_matching_catch()|0;
                          $1695 = tempRet0;
                          ___cxa_call_unexpected(($1694|0));
                          // unreachable;
                         }
                        } while(0);
                        $1696 = (($125) + 4|0);
                        $1697 = HEAP8[$1696>>0]|0;
                        $1698 = $1697 & 1;
                        $1699 = ($1698<<24>>24)==(0);
                        if ($1699) {
                         $$19 = $1675;$$1928 = $1674;
                         break;
                        }
                        $1700 = (($125) + 12|0);
                        $1701 = HEAP32[$1700>>2]|0;
                        HEAP32[$12>>2] = 59;
                        __THREW__ = 0;
                        ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$12+0>>2]|0;
                        invoke_vii(2591,($1701|0),($$byval_copy89|0));
                        $1702 = __THREW__; __THREW__ = 0;
                        $1703 = $1702&1;
                        if (!($1703)) {
                         $$19 = $1675;$$1928 = $1674;
                         break;
                        }
                        $1704 = ___cxa_find_matching_catch()|0;
                        $1705 = tempRet0;
                        ___cxa_call_unexpected(($1704|0));
                        // unreachable;
                       }
                       HEAP32[$125>>2] = ((612552 + 8|0));
                       $888 = (($125) + 28|0);
                       $889 = HEAP8[$888>>0]|0;
                       $890 = $889 & 1;
                       $891 = ($890<<24>>24)==(0);
                       do {
                        if (!($891)) {
                         $892 = (($125) + 36|0);
                         $893 = HEAP32[$892>>2]|0;
                         HEAP32[$59>>2] = 59;
                         __THREW__ = 0;
                         ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$59+0>>2]|0;
                         invoke_vii(2591,($893|0),($$byval_copy89|0));
                         $894 = __THREW__; __THREW__ = 0;
                         $895 = $894&1;
                         if (!($895)) {
                          break;
                         }
                         $896 = ___cxa_find_matching_catch()|0;
                         $897 = tempRet0;
                         ___cxa_call_unexpected(($896|0));
                         // unreachable;
                        }
                       } while(0);
                       $898 = (($125) + 16|0);
                       $899 = HEAP8[$898>>0]|0;
                       $900 = $899 & 1;
                       $901 = ($900<<24>>24)==(0);
                       do {
                        if (!($901)) {
                         $902 = (($125) + 24|0);
                         $903 = HEAP32[$902>>2]|0;
                         HEAP32[$58>>2] = 59;
                         __THREW__ = 0;
                         ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$58+0>>2]|0;
                         invoke_vii(2591,($903|0),($$byval_copy89|0));
                         $904 = __THREW__; __THREW__ = 0;
                         $905 = $904&1;
                         if (!($905)) {
                          break;
                         }
                         $906 = ___cxa_find_matching_catch()|0;
                         $907 = tempRet0;
                         ___cxa_call_unexpected(($906|0));
                         // unreachable;
                        }
                       } while(0);
                       $908 = (($125) + 4|0);
                       $909 = HEAP8[$908>>0]|0;
                       $910 = $909 & 1;
                       $911 = ($910<<24>>24)==(0);
                       do {
                        if (!($911)) {
                         $912 = (($125) + 12|0);
                         $913 = HEAP32[$912>>2]|0;
                         HEAP32[$57>>2] = 59;
                         __THREW__ = 0;
                         ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$57+0>>2]|0;
                         invoke_vii(2591,($913|0),($$byval_copy89|0));
                         $914 = __THREW__; __THREW__ = 0;
                         $915 = $914&1;
                         if (!($915)) {
                          break;
                         }
                         $916 = ___cxa_find_matching_catch()|0;
                         $917 = tempRet0;
                         ___cxa_call_unexpected(($916|0));
                         // unreachable;
                        }
                       } while(0);
                       $918 = HEAP8[$126>>0]|0;
                       $919 = $918 & 1;
                       $920 = ($919<<24>>24)==(0);
                       if (!($920)) {
                        $921 = (($126) + 8|0);
                        $922 = HEAP32[$921>>2]|0;
                        __ZdlPv($922);
                       }
                       $923 = HEAP32[$139>>2]|0;
                       $924 = (($923) + 828|0);
                       __ZN9InputAxis12MakeJoystickEi($924,0);
                       $925 = HEAP32[$139>>2]|0;
                       $926 = (($925) + 920|0);
                       __ZN9InputAxis12MakeJoystickEi($926,1);
                       $927 = HEAP32[$139>>2]|0;
                       $928 = (($927) + 1009|0);
                       HEAP8[$928>>0] = 1;
                       HEAP8[$128>>0] = 10;
                       $929 = (($128) + 1|0);
                       ;HEAP8[$929+0>>0]=HEAP8[612888+0>>0]|0;HEAP8[$929+1>>0]=HEAP8[612888+1>>0]|0;HEAP8[$929+2>>0]=HEAP8[612888+2>>0]|0;HEAP8[$929+3>>0]=HEAP8[612888+3>>0]|0;HEAP8[$929+4>>0]=HEAP8[612888+4>>0]|0;
                       $930 = (($128) + 6|0);
                       HEAP8[$930>>0] = 0;
                       __THREW__ = 0;
                       invoke_vii(2744,($127|0),($128|0));
                       $931 = __THREW__; __THREW__ = 0;
                       $932 = $931&1;
                       do {
                        if ($932) {
                         $1711 = ___cxa_find_matching_catch()|0;
                         $1712 = tempRet0;
                         $$20 = $1712;$$2029 = $1711;
                        } else {
                         $933 = HEAP32[$144>>2]|0;
                         $934 = HEAP32[$146>>2]|0;
                         $935 = ($933|0)==($934|0);
                         do {
                          if ($935) {
                           __THREW__ = 0;
                           invoke_vii(2746,($139|0),($127|0));
                           $941 = __THREW__; __THREW__ = 0;
                           $942 = $941&1;
                           if ($942) {
                            label = 521;
                           }
                          } else {
                           $936 = ($933|0)==(0|0);
                           if ($936) {
                            $940 = 0;
                           } else {
                            __THREW__ = 0;
                            invoke_vii(2745,($933|0),($127|0));
                            $937 = __THREW__; __THREW__ = 0;
                            $938 = $937&1;
                            if ($938) {
                             label = 521;
                             break;
                            }
                            $$pre$i292 = HEAP32[$144>>2]|0;
                            $940 = $$pre$i292;
                           }
                           $939 = (($940) + 92|0);
                           HEAP32[$144>>2] = $939;
                          }
                         } while(0);
                         if ((label|0) == 521) {
                          $1713 = ___cxa_find_matching_catch()|0;
                          $1714 = tempRet0;
                          HEAP32[$127>>2] = ((612552 + 8|0));
                          $1715 = (($127) + 28|0);
                          $1716 = HEAP8[$1715>>0]|0;
                          $1717 = $1716 & 1;
                          $1718 = ($1717<<24>>24)==(0);
                          do {
                           if (!($1718)) {
                            $1719 = (($127) + 36|0);
                            $1720 = HEAP32[$1719>>2]|0;
                            HEAP32[$11>>2] = 59;
                            __THREW__ = 0;
                            ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$11+0>>2]|0;
                            invoke_vii(2591,($1720|0),($$byval_copy89|0));
                            $1721 = __THREW__; __THREW__ = 0;
                            $1722 = $1721&1;
                            if (!($1722)) {
                             break;
                            }
                            $1723 = ___cxa_find_matching_catch()|0;
                            $1724 = tempRet0;
                            ___cxa_call_unexpected(($1723|0));
                            // unreachable;
                           }
                          } while(0);
                          $1725 = (($127) + 16|0);
                          $1726 = HEAP8[$1725>>0]|0;
                          $1727 = $1726 & 1;
                          $1728 = ($1727<<24>>24)==(0);
                          do {
                           if (!($1728)) {
                            $1729 = (($127) + 24|0);
                            $1730 = HEAP32[$1729>>2]|0;
                            HEAP32[$10>>2] = 59;
                            __THREW__ = 0;
                            ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$10+0>>2]|0;
                            invoke_vii(2591,($1730|0),($$byval_copy89|0));
                            $1731 = __THREW__; __THREW__ = 0;
                            $1732 = $1731&1;
                            if (!($1732)) {
                             break;
                            }
                            $1733 = ___cxa_find_matching_catch()|0;
                            $1734 = tempRet0;
                            ___cxa_call_unexpected(($1733|0));
                            // unreachable;
                           }
                          } while(0);
                          $1735 = (($127) + 4|0);
                          $1736 = HEAP8[$1735>>0]|0;
                          $1737 = $1736 & 1;
                          $1738 = ($1737<<24>>24)==(0);
                          if ($1738) {
                           $$20 = $1714;$$2029 = $1713;
                           break;
                          }
                          $1739 = (($127) + 12|0);
                          $1740 = HEAP32[$1739>>2]|0;
                          HEAP32[$9>>2] = 59;
                          __THREW__ = 0;
                          ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$9+0>>2]|0;
                          invoke_vii(2591,($1740|0),($$byval_copy89|0));
                          $1741 = __THREW__; __THREW__ = 0;
                          $1742 = $1741&1;
                          if (!($1742)) {
                           $$20 = $1714;$$2029 = $1713;
                           break;
                          }
                          $1743 = ___cxa_find_matching_catch()|0;
                          $1744 = tempRet0;
                          ___cxa_call_unexpected(($1743|0));
                          // unreachable;
                         }
                         HEAP32[$127>>2] = ((612552 + 8|0));
                         $943 = (($127) + 28|0);
                         $944 = HEAP8[$943>>0]|0;
                         $945 = $944 & 1;
                         $946 = ($945<<24>>24)==(0);
                         do {
                          if (!($946)) {
                           $947 = (($127) + 36|0);
                           $948 = HEAP32[$947>>2]|0;
                           HEAP32[$56>>2] = 59;
                           __THREW__ = 0;
                           ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$56+0>>2]|0;
                           invoke_vii(2591,($948|0),($$byval_copy89|0));
                           $949 = __THREW__; __THREW__ = 0;
                           $950 = $949&1;
                           if (!($950)) {
                            break;
                           }
                           $951 = ___cxa_find_matching_catch()|0;
                           $952 = tempRet0;
                           ___cxa_call_unexpected(($951|0));
                           // unreachable;
                          }
                         } while(0);
                         $953 = (($127) + 16|0);
                         $954 = HEAP8[$953>>0]|0;
                         $955 = $954 & 1;
                         $956 = ($955<<24>>24)==(0);
                         do {
                          if (!($956)) {
                           $957 = (($127) + 24|0);
                           $958 = HEAP32[$957>>2]|0;
                           HEAP32[$55>>2] = 59;
                           __THREW__ = 0;
                           ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$55+0>>2]|0;
                           invoke_vii(2591,($958|0),($$byval_copy89|0));
                           $959 = __THREW__; __THREW__ = 0;
                           $960 = $959&1;
                           if (!($960)) {
                            break;
                           }
                           $961 = ___cxa_find_matching_catch()|0;
                           $962 = tempRet0;
                           ___cxa_call_unexpected(($961|0));
                           // unreachable;
                          }
                         } while(0);
                         $963 = (($127) + 4|0);
                         $964 = HEAP8[$963>>0]|0;
                         $965 = $964 & 1;
                         $966 = ($965<<24>>24)==(0);
                         do {
                          if (!($966)) {
                           $967 = (($127) + 12|0);
                           $968 = HEAP32[$967>>2]|0;
                           HEAP32[$54>>2] = 59;
                           __THREW__ = 0;
                           ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$54+0>>2]|0;
                           invoke_vii(2591,($968|0),($$byval_copy89|0));
                           $969 = __THREW__; __THREW__ = 0;
                           $970 = $969&1;
                           if (!($970)) {
                            break;
                           }
                           $971 = ___cxa_find_matching_catch()|0;
                           $972 = tempRet0;
                           ___cxa_call_unexpected(($971|0));
                           // unreachable;
                          }
                         } while(0);
                         $973 = HEAP8[$128>>0]|0;
                         $974 = $973 & 1;
                         $975 = ($974<<24>>24)==(0);
                         if (!($975)) {
                          $976 = (($128) + 8|0);
                          $977 = HEAP32[$976>>2]|0;
                          __ZdlPv($977);
                         }
                         HEAP8[$130>>0] = 10;
                         $978 = (($130) + 1|0);
                         ;HEAP8[$978+0>>0]=HEAP8[612896+0>>0]|0;HEAP8[$978+1>>0]=HEAP8[612896+1>>0]|0;HEAP8[$978+2>>0]=HEAP8[612896+2>>0]|0;HEAP8[$978+3>>0]=HEAP8[612896+3>>0]|0;HEAP8[$978+4>>0]=HEAP8[612896+4>>0]|0;
                         $979 = (($130) + 6|0);
                         HEAP8[$979>>0] = 0;
                         __THREW__ = 0;
                         invoke_vii(2744,($129|0),($130|0));
                         $980 = __THREW__; __THREW__ = 0;
                         $981 = $980&1;
                         do {
                          if ($981) {
                           $1750 = ___cxa_find_matching_catch()|0;
                           $1751 = tempRet0;
                           $$21 = $1751;$$2130 = $1750;
                          } else {
                           $982 = HEAP32[$144>>2]|0;
                           $983 = HEAP32[$146>>2]|0;
                           $984 = ($982|0)==($983|0);
                           do {
                            if ($984) {
                             __THREW__ = 0;
                             invoke_vii(2746,($139|0),($129|0));
                             $990 = __THREW__; __THREW__ = 0;
                             $991 = $990&1;
                             if ($991) {
                              label = 533;
                             }
                            } else {
                             $985 = ($982|0)==(0|0);
                             if ($985) {
                              $989 = 0;
                             } else {
                              __THREW__ = 0;
                              invoke_vii(2745,($982|0),($129|0));
                              $986 = __THREW__; __THREW__ = 0;
                              $987 = $986&1;
                              if ($987) {
                               label = 533;
                               break;
                              }
                              $$pre$i304 = HEAP32[$144>>2]|0;
                              $989 = $$pre$i304;
                             }
                             $988 = (($989) + 92|0);
                             HEAP32[$144>>2] = $988;
                            }
                           } while(0);
                           if ((label|0) == 533) {
                            $1752 = ___cxa_find_matching_catch()|0;
                            $1753 = tempRet0;
                            HEAP32[$129>>2] = ((612552 + 8|0));
                            $1754 = (($129) + 28|0);
                            $1755 = HEAP8[$1754>>0]|0;
                            $1756 = $1755 & 1;
                            $1757 = ($1756<<24>>24)==(0);
                            do {
                             if (!($1757)) {
                              $1758 = (($129) + 36|0);
                              $1759 = HEAP32[$1758>>2]|0;
                              HEAP32[$8>>2] = 59;
                              __THREW__ = 0;
                              ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$8+0>>2]|0;
                              invoke_vii(2591,($1759|0),($$byval_copy89|0));
                              $1760 = __THREW__; __THREW__ = 0;
                              $1761 = $1760&1;
                              if (!($1761)) {
                               break;
                              }
                              $1762 = ___cxa_find_matching_catch()|0;
                              $1763 = tempRet0;
                              ___cxa_call_unexpected(($1762|0));
                              // unreachable;
                             }
                            } while(0);
                            $1764 = (($129) + 16|0);
                            $1765 = HEAP8[$1764>>0]|0;
                            $1766 = $1765 & 1;
                            $1767 = ($1766<<24>>24)==(0);
                            do {
                             if (!($1767)) {
                              $1768 = (($129) + 24|0);
                              $1769 = HEAP32[$1768>>2]|0;
                              HEAP32[$7>>2] = 59;
                              __THREW__ = 0;
                              ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$7+0>>2]|0;
                              invoke_vii(2591,($1769|0),($$byval_copy89|0));
                              $1770 = __THREW__; __THREW__ = 0;
                              $1771 = $1770&1;
                              if (!($1771)) {
                               break;
                              }
                              $1772 = ___cxa_find_matching_catch()|0;
                              $1773 = tempRet0;
                              ___cxa_call_unexpected(($1772|0));
                              // unreachable;
                             }
                            } while(0);
                            $1774 = (($129) + 4|0);
                            $1775 = HEAP8[$1774>>0]|0;
                            $1776 = $1775 & 1;
                            $1777 = ($1776<<24>>24)==(0);
                            if ($1777) {
                             $$21 = $1753;$$2130 = $1752;
                             break;
                            }
                            $1778 = (($129) + 12|0);
                            $1779 = HEAP32[$1778>>2]|0;
                            HEAP32[$6>>2] = 59;
                            __THREW__ = 0;
                            ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$6+0>>2]|0;
                            invoke_vii(2591,($1779|0),($$byval_copy89|0));
                            $1780 = __THREW__; __THREW__ = 0;
                            $1781 = $1780&1;
                            if (!($1781)) {
                             $$21 = $1753;$$2130 = $1752;
                             break;
                            }
                            $1782 = ___cxa_find_matching_catch()|0;
                            $1783 = tempRet0;
                            ___cxa_call_unexpected(($1782|0));
                            // unreachable;
                           }
                           HEAP32[$129>>2] = ((612552 + 8|0));
                           $992 = (($129) + 28|0);
                           $993 = HEAP8[$992>>0]|0;
                           $994 = $993 & 1;
                           $995 = ($994<<24>>24)==(0);
                           do {
                            if (!($995)) {
                             $996 = (($129) + 36|0);
                             $997 = HEAP32[$996>>2]|0;
                             HEAP32[$53>>2] = 59;
                             __THREW__ = 0;
                             ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$53+0>>2]|0;
                             invoke_vii(2591,($997|0),($$byval_copy89|0));
                             $998 = __THREW__; __THREW__ = 0;
                             $999 = $998&1;
                             if (!($999)) {
                              break;
                             }
                             $1000 = ___cxa_find_matching_catch()|0;
                             $1001 = tempRet0;
                             ___cxa_call_unexpected(($1000|0));
                             // unreachable;
                            }
                           } while(0);
                           $1002 = (($129) + 16|0);
                           $1003 = HEAP8[$1002>>0]|0;
                           $1004 = $1003 & 1;
                           $1005 = ($1004<<24>>24)==(0);
                           do {
                            if (!($1005)) {
                             $1006 = (($129) + 24|0);
                             $1007 = HEAP32[$1006>>2]|0;
                             HEAP32[$52>>2] = 59;
                             __THREW__ = 0;
                             ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$52+0>>2]|0;
                             invoke_vii(2591,($1007|0),($$byval_copy89|0));
                             $1008 = __THREW__; __THREW__ = 0;
                             $1009 = $1008&1;
                             if (!($1009)) {
                              break;
                             }
                             $1010 = ___cxa_find_matching_catch()|0;
                             $1011 = tempRet0;
                             ___cxa_call_unexpected(($1010|0));
                             // unreachable;
                            }
                           } while(0);
                           $1012 = (($129) + 4|0);
                           $1013 = HEAP8[$1012>>0]|0;
                           $1014 = $1013 & 1;
                           $1015 = ($1014<<24>>24)==(0);
                           do {
                            if (!($1015)) {
                             $1016 = (($129) + 12|0);
                             $1017 = HEAP32[$1016>>2]|0;
                             HEAP32[$51>>2] = 59;
                             __THREW__ = 0;
                             ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$51+0>>2]|0;
                             invoke_vii(2591,($1017|0),($$byval_copy89|0));
                             $1018 = __THREW__; __THREW__ = 0;
                             $1019 = $1018&1;
                             if (!($1019)) {
                              break;
                             }
                             $1020 = ___cxa_find_matching_catch()|0;
                             $1021 = tempRet0;
                             ___cxa_call_unexpected(($1020|0));
                             // unreachable;
                            }
                           } while(0);
                           $1022 = HEAP8[$130>>0]|0;
                           $1023 = $1022 & 1;
                           $1024 = ($1023<<24>>24)==(0);
                           if (!($1024)) {
                            $1025 = (($130) + 8|0);
                            $1026 = HEAP32[$1025>>2]|0;
                            __ZdlPv($1026);
                           }
                           HEAP8[$132>>0] = 10;
                           $1027 = (($132) + 1|0);
                           ;HEAP8[$1027+0>>0]=HEAP8[612904+0>>0]|0;HEAP8[$1027+1>>0]=HEAP8[612904+1>>0]|0;HEAP8[$1027+2>>0]=HEAP8[612904+2>>0]|0;HEAP8[$1027+3>>0]=HEAP8[612904+3>>0]|0;HEAP8[$1027+4>>0]=HEAP8[612904+4>>0]|0;
                           $1028 = (($132) + 6|0);
                           HEAP8[$1028>>0] = 0;
                           __THREW__ = 0;
                           invoke_vii(2744,($131|0),($132|0));
                           $1029 = __THREW__; __THREW__ = 0;
                           $1030 = $1029&1;
                           do {
                            if ($1030) {
                             $1789 = ___cxa_find_matching_catch()|0;
                             $1790 = tempRet0;
                             $$22 = $1790;$$2231 = $1789;
                            } else {
                             $1031 = HEAP32[$144>>2]|0;
                             $1032 = HEAP32[$146>>2]|0;
                             $1033 = ($1031|0)==($1032|0);
                             do {
                              if ($1033) {
                               __THREW__ = 0;
                               invoke_vii(2746,($139|0),($131|0));
                               $1039 = __THREW__; __THREW__ = 0;
                               $1040 = $1039&1;
                               if ($1040) {
                                label = 545;
                               }
                              } else {
                               $1034 = ($1031|0)==(0|0);
                               if ($1034) {
                                $1038 = 0;
                               } else {
                                __THREW__ = 0;
                                invoke_vii(2745,($1031|0),($131|0));
                                $1035 = __THREW__; __THREW__ = 0;
                                $1036 = $1035&1;
                                if ($1036) {
                                 label = 545;
                                 break;
                                }
                                $$pre$i316 = HEAP32[$144>>2]|0;
                                $1038 = $$pre$i316;
                               }
                               $1037 = (($1038) + 92|0);
                               HEAP32[$144>>2] = $1037;
                              }
                             } while(0);
                             if ((label|0) == 545) {
                              $1791 = ___cxa_find_matching_catch()|0;
                              $1792 = tempRet0;
                              HEAP32[$131>>2] = ((612552 + 8|0));
                              $1793 = (($131) + 28|0);
                              $1794 = HEAP8[$1793>>0]|0;
                              $1795 = $1794 & 1;
                              $1796 = ($1795<<24>>24)==(0);
                              do {
                               if (!($1796)) {
                                $1797 = (($131) + 36|0);
                                $1798 = HEAP32[$1797>>2]|0;
                                HEAP32[$5>>2] = 59;
                                __THREW__ = 0;
                                ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$5+0>>2]|0;
                                invoke_vii(2591,($1798|0),($$byval_copy89|0));
                                $1799 = __THREW__; __THREW__ = 0;
                                $1800 = $1799&1;
                                if (!($1800)) {
                                 break;
                                }
                                $1801 = ___cxa_find_matching_catch()|0;
                                $1802 = tempRet0;
                                ___cxa_call_unexpected(($1801|0));
                                // unreachable;
                               }
                              } while(0);
                              $1803 = (($131) + 16|0);
                              $1804 = HEAP8[$1803>>0]|0;
                              $1805 = $1804 & 1;
                              $1806 = ($1805<<24>>24)==(0);
                              do {
                               if (!($1806)) {
                                $1807 = (($131) + 24|0);
                                $1808 = HEAP32[$1807>>2]|0;
                                HEAP32[$4>>2] = 59;
                                __THREW__ = 0;
                                ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$4+0>>2]|0;
                                invoke_vii(2591,($1808|0),($$byval_copy89|0));
                                $1809 = __THREW__; __THREW__ = 0;
                                $1810 = $1809&1;
                                if (!($1810)) {
                                 break;
                                }
                                $1811 = ___cxa_find_matching_catch()|0;
                                $1812 = tempRet0;
                                ___cxa_call_unexpected(($1811|0));
                                // unreachable;
                               }
                              } while(0);
                              $1813 = (($131) + 4|0);
                              $1814 = HEAP8[$1813>>0]|0;
                              $1815 = $1814 & 1;
                              $1816 = ($1815<<24>>24)==(0);
                              if ($1816) {
                               $$22 = $1792;$$2231 = $1791;
                               break;
                              }
                              $1817 = (($131) + 12|0);
                              $1818 = HEAP32[$1817>>2]|0;
                              HEAP32[$3>>2] = 59;
                              __THREW__ = 0;
                              ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$3+0>>2]|0;
                              invoke_vii(2591,($1818|0),($$byval_copy89|0));
                              $1819 = __THREW__; __THREW__ = 0;
                              $1820 = $1819&1;
                              if (!($1820)) {
                               $$22 = $1792;$$2231 = $1791;
                               break;
                              }
                              $1821 = ___cxa_find_matching_catch()|0;
                              $1822 = tempRet0;
                              ___cxa_call_unexpected(($1821|0));
                              // unreachable;
                             }
                             HEAP32[$131>>2] = ((612552 + 8|0));
                             $1041 = (($131) + 28|0);
                             $1042 = HEAP8[$1041>>0]|0;
                             $1043 = $1042 & 1;
                             $1044 = ($1043<<24>>24)==(0);
                             do {
                              if (!($1044)) {
                               $1045 = (($131) + 36|0);
                               $1046 = HEAP32[$1045>>2]|0;
                               HEAP32[$50>>2] = 59;
                               __THREW__ = 0;
                               ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$50+0>>2]|0;
                               invoke_vii(2591,($1046|0),($$byval_copy89|0));
                               $1047 = __THREW__; __THREW__ = 0;
                               $1048 = $1047&1;
                               if (!($1048)) {
                                break;
                               }
                               $1049 = ___cxa_find_matching_catch()|0;
                               $1050 = tempRet0;
                               ___cxa_call_unexpected(($1049|0));
                               // unreachable;
                              }
                             } while(0);
                             $1051 = (($131) + 16|0);
                             $1052 = HEAP8[$1051>>0]|0;
                             $1053 = $1052 & 1;
                             $1054 = ($1053<<24>>24)==(0);
                             do {
                              if (!($1054)) {
                               $1055 = (($131) + 24|0);
                               $1056 = HEAP32[$1055>>2]|0;
                               HEAP32[$49>>2] = 59;
                               __THREW__ = 0;
                               ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$49+0>>2]|0;
                               invoke_vii(2591,($1056|0),($$byval_copy89|0));
                               $1057 = __THREW__; __THREW__ = 0;
                               $1058 = $1057&1;
                               if (!($1058)) {
                                break;
                               }
                               $1059 = ___cxa_find_matching_catch()|0;
                               $1060 = tempRet0;
                               ___cxa_call_unexpected(($1059|0));
                               // unreachable;
                              }
                             } while(0);
                             $1061 = (($131) + 4|0);
                             $1062 = HEAP8[$1061>>0]|0;
                             $1063 = $1062 & 1;
                             $1064 = ($1063<<24>>24)==(0);
                             do {
                              if (!($1064)) {
                               $1065 = (($131) + 12|0);
                               $1066 = HEAP32[$1065>>2]|0;
                               HEAP32[$48>>2] = 59;
                               __THREW__ = 0;
                               ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$48+0>>2]|0;
                               invoke_vii(2591,($1066|0),($$byval_copy89|0));
                               $1067 = __THREW__; __THREW__ = 0;
                               $1068 = $1067&1;
                               if (!($1068)) {
                                break;
                               }
                               $1069 = ___cxa_find_matching_catch()|0;
                               $1070 = tempRet0;
                               ___cxa_call_unexpected(($1069|0));
                               // unreachable;
                              }
                             } while(0);
                             $1071 = HEAP8[$132>>0]|0;
                             $1072 = $1071 & 1;
                             $1073 = ($1072<<24>>24)==(0);
                             if (!($1073)) {
                              $1074 = (($132) + 8|0);
                              $1075 = HEAP32[$1074>>2]|0;
                              __ZdlPv($1075);
                             }
                             HEAP8[$134>>0] = 8;
                             $1076 = (($134) + 1|0);
                             HEAP8[$1076>>0]=1886221642&255;HEAP8[$1076+1>>0]=(1886221642>>8)&255;HEAP8[$1076+2>>0]=(1886221642>>16)&255;HEAP8[$1076+3>>0]=1886221642>>24;
                             $1077 = (($134) + 5|0);
                             HEAP8[$1077>>0] = 0;
                             __THREW__ = 0;
                             invoke_vii(2744,($133|0),($134|0));
                             $1078 = __THREW__; __THREW__ = 0;
                             $1079 = $1078&1;
                             do {
                              if ($1079) {
                               $1828 = ___cxa_find_matching_catch()|0;
                               $1829 = tempRet0;
                               $$23 = $1829;$$2332 = $1828;
                              } else {
                               $1080 = HEAP32[$144>>2]|0;
                               $1081 = HEAP32[$146>>2]|0;
                               $1082 = ($1080|0)==($1081|0);
                               do {
                                if ($1082) {
                                 __THREW__ = 0;
                                 invoke_vii(2746,($139|0),($133|0));
                                 $1088 = __THREW__; __THREW__ = 0;
                                 $1089 = $1088&1;
                                 if ($1089) {
                                  label = 557;
                                 }
                                } else {
                                 $1083 = ($1080|0)==(0|0);
                                 if ($1083) {
                                  $1087 = 0;
                                 } else {
                                  __THREW__ = 0;
                                  invoke_vii(2745,($1080|0),($133|0));
                                  $1084 = __THREW__; __THREW__ = 0;
                                  $1085 = $1084&1;
                                  if ($1085) {
                                   label = 557;
                                   break;
                                  }
                                  $$pre$i328 = HEAP32[$144>>2]|0;
                                  $1087 = $$pre$i328;
                                 }
                                 $1086 = (($1087) + 92|0);
                                 HEAP32[$144>>2] = $1086;
                                }
                               } while(0);
                               if ((label|0) == 557) {
                                $1830 = ___cxa_find_matching_catch()|0;
                                $1831 = tempRet0;
                                HEAP32[$133>>2] = ((612552 + 8|0));
                                $1832 = (($133) + 28|0);
                                $1833 = HEAP8[$1832>>0]|0;
                                $1834 = $1833 & 1;
                                $1835 = ($1834<<24>>24)==(0);
                                do {
                                 if (!($1835)) {
                                  $1836 = (($133) + 36|0);
                                  $1837 = HEAP32[$1836>>2]|0;
                                  HEAP32[$2>>2] = 59;
                                  __THREW__ = 0;
                                  ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$2+0>>2]|0;
                                  invoke_vii(2591,($1837|0),($$byval_copy89|0));
                                  $1838 = __THREW__; __THREW__ = 0;
                                  $1839 = $1838&1;
                                  if (!($1839)) {
                                   break;
                                  }
                                  $1840 = ___cxa_find_matching_catch()|0;
                                  $1841 = tempRet0;
                                  ___cxa_call_unexpected(($1840|0));
                                  // unreachable;
                                 }
                                } while(0);
                                $1842 = (($133) + 16|0);
                                $1843 = HEAP8[$1842>>0]|0;
                                $1844 = $1843 & 1;
                                $1845 = ($1844<<24>>24)==(0);
                                do {
                                 if (!($1845)) {
                                  $1846 = (($133) + 24|0);
                                  $1847 = HEAP32[$1846>>2]|0;
                                  HEAP32[$1>>2] = 59;
                                  __THREW__ = 0;
                                  ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$1+0>>2]|0;
                                  invoke_vii(2591,($1847|0),($$byval_copy89|0));
                                  $1848 = __THREW__; __THREW__ = 0;
                                  $1849 = $1848&1;
                                  if (!($1849)) {
                                   break;
                                  }
                                  $1850 = ___cxa_find_matching_catch()|0;
                                  $1851 = tempRet0;
                                  ___cxa_call_unexpected(($1850|0));
                                  // unreachable;
                                 }
                                } while(0);
                                $1852 = (($133) + 4|0);
                                $1853 = HEAP8[$1852>>0]|0;
                                $1854 = $1853 & 1;
                                $1855 = ($1854<<24>>24)==(0);
                                if ($1855) {
                                 $$23 = $1831;$$2332 = $1830;
                                 break;
                                }
                                $1856 = (($133) + 12|0);
                                $1857 = HEAP32[$1856>>2]|0;
                                HEAP32[$0>>2] = 59;
                                __THREW__ = 0;
                                ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$0+0>>2]|0;
                                invoke_vii(2591,($1857|0),($$byval_copy89|0));
                                $1858 = __THREW__; __THREW__ = 0;
                                $1859 = $1858&1;
                                if (!($1859)) {
                                 $$23 = $1831;$$2332 = $1830;
                                 break;
                                }
                                $1860 = ___cxa_find_matching_catch()|0;
                                $1861 = tempRet0;
                                ___cxa_call_unexpected(($1860|0));
                                // unreachable;
                               }
                               HEAP32[$133>>2] = ((612552 + 8|0));
                               $1090 = (($133) + 28|0);
                               $1091 = HEAP8[$1090>>0]|0;
                               $1092 = $1091 & 1;
                               $1093 = ($1092<<24>>24)==(0);
                               do {
                                if (!($1093)) {
                                 $1094 = (($133) + 36|0);
                                 $1095 = HEAP32[$1094>>2]|0;
                                 HEAP32[$47>>2] = 59;
                                 __THREW__ = 0;
                                 ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$47+0>>2]|0;
                                 invoke_vii(2591,($1095|0),($$byval_copy89|0));
                                 $1096 = __THREW__; __THREW__ = 0;
                                 $1097 = $1096&1;
                                 if (!($1097)) {
                                  break;
                                 }
                                 $1098 = ___cxa_find_matching_catch()|0;
                                 $1099 = tempRet0;
                                 ___cxa_call_unexpected(($1098|0));
                                 // unreachable;
                                }
                               } while(0);
                               $1100 = (($133) + 16|0);
                               $1101 = HEAP8[$1100>>0]|0;
                               $1102 = $1101 & 1;
                               $1103 = ($1102<<24>>24)==(0);
                               do {
                                if (!($1103)) {
                                 $1104 = (($133) + 24|0);
                                 $1105 = HEAP32[$1104>>2]|0;
                                 HEAP32[$46>>2] = 59;
                                 __THREW__ = 0;
                                 ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$46+0>>2]|0;
                                 invoke_vii(2591,($1105|0),($$byval_copy89|0));
                                 $1106 = __THREW__; __THREW__ = 0;
                                 $1107 = $1106&1;
                                 if (!($1107)) {
                                  break;
                                 }
                                 $1108 = ___cxa_find_matching_catch()|0;
                                 $1109 = tempRet0;
                                 ___cxa_call_unexpected(($1108|0));
                                 // unreachable;
                                }
                               } while(0);
                               $1110 = (($133) + 4|0);
                               $1111 = HEAP8[$1110>>0]|0;
                               $1112 = $1111 & 1;
                               $1113 = ($1112<<24>>24)==(0);
                               do {
                                if (!($1113)) {
                                 $1114 = (($133) + 12|0);
                                 $1115 = HEAP32[$1114>>2]|0;
                                 HEAP32[$45>>2] = 59;
                                 __THREW__ = 0;
                                 ;HEAP32[$$byval_copy89+0>>2]=HEAP32[$45+0>>2]|0;
                                 invoke_vii(2591,($1115|0),($$byval_copy89|0));
                                 $1116 = __THREW__; __THREW__ = 0;
                                 $1117 = $1116&1;
                                 if (!($1117)) {
                                  break;
                                 }
                                 $1118 = ___cxa_find_matching_catch()|0;
                                 $1119 = tempRet0;
                                 ___cxa_call_unexpected(($1118|0));
                                 // unreachable;
                                }
                               } while(0);
                               $1120 = HEAP8[$134>>0]|0;
                               $1121 = $1120 & 1;
                               $1122 = ($1121<<24>>24)==(0);
                               if (!($1122)) {
                                $1123 = (($134) + 8|0);
                                $1124 = HEAP32[$1123>>2]|0;
                                __ZdlPv($1124);
                               }
                               $1125 = HEAP32[$139>>2]|0;
                               $1126 = (($1125) + 1012|0);
                               $1127 = (__Znwj(32)|0);
                               $1128 = (($135) + 8|0);
                               HEAP32[$1128>>2] = $1127;
                               HEAP32[$135>>2] = 33;
                               $1129 = (($135) + 4|0);
                               HEAP32[$1129>>2] = 17;
                               dest=$1127+0|0; src=612728+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                               $1130 = (($1127) + 17|0);
                               HEAP8[$1130>>0] = 0;
                               $1131 = HEAP32[613088>>2]|0;
                               __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$1131,$135);
                               $1132 = HEAP32[613088>>2]|0;
                               $1133 = (($1132) + 4|0);
                               $1134 = HEAP32[$$byval_copy89>>2]|0;
                               $1135 = ($1134|0)==($1133|0);
                               if ($1135) {
                                $$0$i342 = 0;
                               } else {
                                $1136 = (($1134) + 28|0);
                                $1137 = HEAP32[$1136>>2]|0;
                                $$0$i342 = $1137;
                               }
                               __THREW__ = 0;
                               invoke_viii(1764,($1126|0),($$0$i342|0),0);
                               $1138 = __THREW__; __THREW__ = 0;
                               $1139 = $1138&1;
                               if ($1139) {
                                $1867 = ___cxa_find_matching_catch()|0;
                                $1868 = tempRet0;
                                $1869 = HEAP8[$135>>0]|0;
                                $1870 = $1869 & 1;
                                $1871 = ($1870<<24>>24)==(0);
                                if ($1871) {
                                 $$24 = $1868;$$2433 = $1867;
                                 ___resumeException($$2433|0);
                                 // unreachable;
                                }
                                $1872 = HEAP32[$1128>>2]|0;
                                __ZdlPv($1872);
                                $$24 = $1868;$$2433 = $1867;
                                ___resumeException($$2433|0);
                                // unreachable;
                               }
                               $1140 = HEAP8[$135>>0]|0;
                               $1141 = $1140 & 1;
                               $1142 = ($1141<<24>>24)==(0);
                               if (!($1142)) {
                                $1143 = HEAP32[$1128>>2]|0;
                                __ZdlPv($1143);
                               }
                               $1144 = HEAP32[$139>>2]|0;
                               $1145 = (($1144) + 1104|0);
                               $1146 = (__Znwj(32)|0);
                               $1147 = (($136) + 8|0);
                               HEAP32[$1147>>2] = $1146;
                               HEAP32[$136>>2] = 33;
                               $1148 = (($136) + 4|0);
                               HEAP32[$1148>>2] = 17;
                               dest=$1146+0|0; src=612784+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                               $1149 = (($1146) + 17|0);
                               HEAP8[$1149>>0] = 0;
                               $1150 = HEAP32[613088>>2]|0;
                               __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$1150,$136);
                               $1151 = HEAP32[613088>>2]|0;
                               $1152 = (($1151) + 4|0);
                               $1153 = HEAP32[$$byval_copy89>>2]|0;
                               $1154 = ($1153|0)==($1152|0);
                               if ($1154) {
                                $$0$i350 = 0;
                               } else {
                                $1155 = (($1153) + 28|0);
                                $1156 = HEAP32[$1155>>2]|0;
                                $$0$i350 = $1156;
                               }
                               __THREW__ = 0;
                               invoke_viii(1764,($1145|0),($$0$i350|0),0);
                               $1157 = __THREW__; __THREW__ = 0;
                               $1158 = $1157&1;
                               if ($1158) {
                                $1873 = ___cxa_find_matching_catch()|0;
                                $1874 = tempRet0;
                                $1875 = HEAP8[$136>>0]|0;
                                $1876 = $1875 & 1;
                                $1877 = ($1876<<24>>24)==(0);
                                if ($1877) {
                                 $$24 = $1874;$$2433 = $1873;
                                 ___resumeException($$2433|0);
                                 // unreachable;
                                }
                                $1878 = HEAP32[$1147>>2]|0;
                                __ZdlPv($1878);
                                $$24 = $1874;$$2433 = $1873;
                                ___resumeException($$2433|0);
                                // unreachable;
                               }
                               $1159 = HEAP8[$136>>0]|0;
                               $1160 = $1159 & 1;
                               $1161 = ($1160<<24>>24)==(0);
                               if (!($1161)) {
                                $1162 = HEAP32[$1147>>2]|0;
                                __ZdlPv($1162);
                               }
                               $1163 = HEAP32[$139>>2]|0;
                               $1164 = (($1163) + 1196|0);
                               $1165 = (__Znwj(32)|0);
                               $1166 = (($137) + 8|0);
                               HEAP32[$1166>>2] = $1165;
                               HEAP32[$137>>2] = 33;
                               $1167 = (($137) + 4|0);
                               HEAP32[$1167>>2] = 17;
                               dest=$1165+0|0; src=613024+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                               $1168 = (($1165) + 17|0);
                               HEAP8[$1168>>0] = 0;
                               $1169 = HEAP32[613088>>2]|0;
                               __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$1169,$137);
                               $1170 = HEAP32[613088>>2]|0;
                               $1171 = (($1170) + 4|0);
                               $1172 = HEAP32[$$byval_copy89>>2]|0;
                               $1173 = ($1172|0)==($1171|0);
                               if ($1173) {
                                $$0$i358 = 0;
                               } else {
                                $1174 = (($1172) + 28|0);
                                $1175 = HEAP32[$1174>>2]|0;
                                $$0$i358 = $1175;
                               }
                               __THREW__ = 0;
                               invoke_viii(1764,($1164|0),($$0$i358|0),0);
                               $1176 = __THREW__; __THREW__ = 0;
                               $1177 = $1176&1;
                               if ($1177) {
                                $1879 = ___cxa_find_matching_catch()|0;
                                $1880 = tempRet0;
                                $1881 = HEAP8[$137>>0]|0;
                                $1882 = $1881 & 1;
                                $1883 = ($1882<<24>>24)==(0);
                                if ($1883) {
                                 $$24 = $1880;$$2433 = $1879;
                                 ___resumeException($$2433|0);
                                 // unreachable;
                                }
                                $1884 = HEAP32[$1166>>2]|0;
                                __ZdlPv($1884);
                                $$24 = $1880;$$2433 = $1879;
                                ___resumeException($$2433|0);
                                // unreachable;
                               }
                               $1178 = HEAP8[$137>>0]|0;
                               $1179 = $1178 & 1;
                               $1180 = ($1179<<24>>24)==(0);
                               if (!($1180)) {
                                $1181 = HEAP32[$1166>>2]|0;
                                __ZdlPv($1181);
                               }
                               $1182 = HEAP32[$139>>2]|0;
                               $1183 = (($1182) + 1288|0);
                               $1184 = (__Znwj(32)|0);
                               $1185 = (($138) + 8|0);
                               HEAP32[$1185>>2] = $1184;
                               HEAP32[$138>>2] = 33;
                               $1186 = (($138) + 4|0);
                               HEAP32[$1186>>2] = 17;
                               dest=$1184+0|0; src=613048+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                               $1187 = (($1184) + 17|0);
                               HEAP8[$1187>>0] = 0;
                               $1188 = HEAP32[613088>>2]|0;
                               __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy89,$1188,$138);
                               $1189 = HEAP32[613088>>2]|0;
                               $1190 = (($1189) + 4|0);
                               $1191 = HEAP32[$$byval_copy89>>2]|0;
                               $1192 = ($1191|0)==($1190|0);
                               if ($1192) {
                                $$0$i366 = 0;
                               } else {
                                $1193 = (($1191) + 28|0);
                                $1194 = HEAP32[$1193>>2]|0;
                                $$0$i366 = $1194;
                               }
                               __THREW__ = 0;
                               invoke_viii(1764,($1183|0),($$0$i366|0),0);
                               $1195 = __THREW__; __THREW__ = 0;
                               $1196 = $1195&1;
                               if ($1196) {
                                $1885 = ___cxa_find_matching_catch()|0;
                                $1886 = tempRet0;
                                $1887 = HEAP8[$138>>0]|0;
                                $1888 = $1887 & 1;
                                $1889 = ($1888<<24>>24)==(0);
                                if ($1889) {
                                 $$24 = $1886;$$2433 = $1885;
                                 ___resumeException($$2433|0);
                                 // unreachable;
                                }
                                $1890 = HEAP32[$1185>>2]|0;
                                __ZdlPv($1890);
                                $$24 = $1886;$$2433 = $1885;
                                ___resumeException($$2433|0);
                                // unreachable;
                               } else {
                                $1197 = HEAP8[$138>>0]|0;
                                $1198 = $1197 & 1;
                                $1199 = ($1198<<24>>24)==(0);
                                if ($1199) {
                                 __Z10AddGUIAxesRNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEEE($139);
                                 STACKTOP = sp;return;
                                }
                                $1200 = HEAP32[$1185>>2]|0;
                                __ZdlPv($1200);
                                __Z10AddGUIAxesRNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEEE($139);
                                STACKTOP = sp;return;
                               }
                              }
                             } while(0);
                             $1862 = HEAP8[$134>>0]|0;
                             $1863 = $1862 & 1;
                             $1864 = ($1863<<24>>24)==(0);
                             if ($1864) {
                              $$24 = $$23;$$2433 = $$2332;
                              ___resumeException($$2433|0);
                              // unreachable;
                             }
                             $1865 = (($134) + 8|0);
                             $1866 = HEAP32[$1865>>2]|0;
                             __ZdlPv($1866);
                             $$24 = $$23;$$2433 = $$2332;
                             ___resumeException($$2433|0);
                             // unreachable;
                            }
                           } while(0);
                           $1823 = HEAP8[$132>>0]|0;
                           $1824 = $1823 & 1;
                           $1825 = ($1824<<24>>24)==(0);
                           if ($1825) {
                            $$24 = $$22;$$2433 = $$2231;
                            ___resumeException($$2433|0);
                            // unreachable;
                           }
                           $1826 = (($132) + 8|0);
                           $1827 = HEAP32[$1826>>2]|0;
                           __ZdlPv($1827);
                           $$24 = $$22;$$2433 = $$2231;
                           ___resumeException($$2433|0);
                           // unreachable;
                          }
                         } while(0);
                         $1784 = HEAP8[$130>>0]|0;
                         $1785 = $1784 & 1;
                         $1786 = ($1785<<24>>24)==(0);
                         if ($1786) {
                          $$24 = $$21;$$2433 = $$2130;
                          ___resumeException($$2433|0);
                          // unreachable;
                         }
                         $1787 = (($130) + 8|0);
                         $1788 = HEAP32[$1787>>2]|0;
                         __ZdlPv($1788);
                         $$24 = $$21;$$2433 = $$2130;
                         ___resumeException($$2433|0);
                         // unreachable;
                        }
                       } while(0);
                       $1745 = HEAP8[$128>>0]|0;
                       $1746 = $1745 & 1;
                       $1747 = ($1746<<24>>24)==(0);
                       if ($1747) {
                        $$24 = $$20;$$2433 = $$2029;
                        ___resumeException($$2433|0);
                        // unreachable;
                       }
                       $1748 = (($128) + 8|0);
                       $1749 = HEAP32[$1748>>2]|0;
                       __ZdlPv($1749);
                       $$24 = $$20;$$2433 = $$2029;
                       ___resumeException($$2433|0);
                       // unreachable;
                      }
                     } while(0);
                     $1706 = HEAP8[$126>>0]|0;
                     $1707 = $1706 & 1;
                     $1708 = ($1707<<24>>24)==(0);
                     if ($1708) {
                      $$24 = $$19;$$2433 = $$1928;
                      ___resumeException($$2433|0);
                      // unreachable;
                     }
                     $1709 = (($126) + 8|0);
                     $1710 = HEAP32[$1709>>2]|0;
                     __ZdlPv($1710);
                     $$24 = $$19;$$2433 = $$1928;
                     ___resumeException($$2433|0);
                     // unreachable;
                    }
                   } while(0);
                   $1667 = HEAP8[$124>>0]|0;
                   $1668 = $1667 & 1;
                   $1669 = ($1668<<24>>24)==(0);
                   if ($1669) {
                    $$24 = $$18;$$2433 = $$1827;
                    ___resumeException($$2433|0);
                    // unreachable;
                   }
                   $1670 = (($124) + 8|0);
                   $1671 = HEAP32[$1670>>2]|0;
                   __ZdlPv($1671);
                   $$24 = $$18;$$2433 = $$1827;
                   ___resumeException($$2433|0);
                   // unreachable;
                  }
                 } while(0);
                 $1629 = HEAP8[$122>>0]|0;
                 $1630 = $1629 & 1;
                 $1631 = ($1630<<24>>24)==(0);
                 if ($1631) {
                  $$24 = $$17;$$2433 = $$1726;
                  ___resumeException($$2433|0);
                  // unreachable;
                 }
                 $1632 = HEAP32[$766>>2]|0;
                 __ZdlPv($1632);
                 $$24 = $$17;$$2433 = $$1726;
                 ___resumeException($$2433|0);
                 // unreachable;
                }
               } while(0);
               $1591 = HEAP8[$120>>0]|0;
               $1592 = $1591 & 1;
               $1593 = ($1592<<24>>24)==(0);
               if ($1593) {
                $$24 = $$16;$$2433 = $$1625;
                ___resumeException($$2433|0);
                // unreachable;
               }
               $1594 = HEAP32[$718>>2]|0;
               __ZdlPv($1594);
               $$24 = $$16;$$2433 = $$1625;
               ___resumeException($$2433|0);
               // unreachable;
              }
             } while(0);
             $1553 = HEAP8[$118>>0]|0;
             $1554 = $1553 & 1;
             $1555 = ($1554<<24>>24)==(0);
             if ($1555) {
              $$24 = $$15;$$2433 = $$1524;
              ___resumeException($$2433|0);
              // unreachable;
             }
             $1556 = HEAP32[$670>>2]|0;
             __ZdlPv($1556);
             $$24 = $$15;$$2433 = $$1524;
             ___resumeException($$2433|0);
             // unreachable;
            }
           } while(0);
           $1474 = HEAP8[$109>>0]|0;
           $1475 = $1474 & 1;
           $1476 = ($1475<<24>>24)==(0);
           if ($1476) {
            $$24 = $$11;$$2433 = $$1120;
            ___resumeException($$2433|0);
            // unreachable;
           }
           $1477 = (($109) + 8|0);
           $1478 = HEAP32[$1477>>2]|0;
           __ZdlPv($1478);
           $$24 = $$11;$$2433 = $$1120;
           ___resumeException($$2433|0);
           // unreachable;
          }
         } while(0);
         $1435 = HEAP8[$107>>0]|0;
         $1436 = $1435 & 1;
         $1437 = ($1436<<24>>24)==(0);
         if ($1437) {
          $$24 = $$10;$$2433 = $$1019;
          ___resumeException($$2433|0);
          // unreachable;
         }
         $1438 = (($107) + 8|0);
         $1439 = HEAP32[$1438>>2]|0;
         __ZdlPv($1439);
         $$24 = $$10;$$2433 = $$1019;
         ___resumeException($$2433|0);
         // unreachable;
        }
       } while(0);
       $1396 = HEAP8[$105>>0]|0;
       $1397 = $1396 & 1;
       $1398 = ($1397<<24>>24)==(0);
       if ($1398) {
        $$24 = $$9;$$2433 = $$918;
        ___resumeException($$2433|0);
        // unreachable;
       }
       $1399 = (($105) + 8|0);
       $1400 = HEAP32[$1399>>2]|0;
       __ZdlPv($1400);
       $$24 = $$9;$$2433 = $$918;
       ___resumeException($$2433|0);
       // unreachable;
      }
     } while(0);
     $1357 = HEAP8[$103>>0]|0;
     $1358 = $1357 & 1;
     $1359 = ($1358<<24>>24)==(0);
     if ($1359) {
      $$24 = $$8;$$2433 = $$817;
      ___resumeException($$2433|0);
      // unreachable;
     }
     $1360 = (($103) + 8|0);
     $1361 = HEAP32[$1360>>2]|0;
     __ZdlPv($1361);
     $$24 = $$8;$$2433 = $$817;
     ___resumeException($$2433|0);
     // unreachable;
    }
   } while(0);
   $1274 = HEAP8[$93>>0]|0;
   $1275 = $1274 & 1;
   $1276 = ($1275<<24>>24)==(0);
   if ($1276) {
    $$24 = $$1;$$2433 = $$110;
    ___resumeException($$2433|0);
    // unreachable;
   }
   $1277 = (($93) + 8|0);
   $1278 = HEAP32[$1277>>2]|0;
   __ZdlPv($1278);
   $$24 = $$1;$$2433 = $$110;
   ___resumeException($$2433|0);
   // unreachable;
  }
 } while(0);
 $1235 = HEAP8[$91>>0]|0;
 $1236 = $1235 & 1;
 $1237 = ($1236<<24>>24)==(0);
 if ($1237) {
  $$24 = $$0;$$2433 = $$01;
  ___resumeException($$2433|0);
  // unreachable;
 }
 $1238 = (($91) + 8|0);
 $1239 = HEAP32[$1238>>2]|0;
 __ZdlPv($1239);
 $$24 = $$0;$$2433 = $$01;
 ___resumeException($$2433|0);
 // unreachable;
}
function __ZN12InputManager5ResetEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 L1: do {
  if (!($7)) {
   $9 = $6;
   while(1) {
    $8 = (($9) + -92|0);
    HEAP32[$5>>2] = $8;
    HEAP32[$8>>2] = ((612552 + 8|0));
    $10 = (($9) + -64|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = (($9) + -56|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy2|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 5;
      break;
     }
    }
    $20 = (($9) + -76|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if (!($23)) {
     $24 = (($9) + -68|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy2|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 8;
      break;
     }
    }
    $30 = (($9) + -88|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if (!($33)) {
     $36 = (($9) + -80|0);
     $37 = HEAP32[$36>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($37|0),($$byval_copy2|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 12;
      break;
     }
    }
    $34 = HEAP32[$5>>2]|0;
    $35 = ($34|0)==($4|0);
    if ($35) {
     break L1;
    } else {
     $9 = $34;
    }
   }
   if ((label|0) == 5) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 8) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   else if ((label|0) == 12) {
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
  }
 } while(0);
 $42 = (($this) + 136|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43 & 1;
 $45 = ($44<<24>>24)==(0);
 if ($45) {
  $49 = (($42) + 1|0);
  HEAP8[$49>>0] = 0;
  HEAP8[$42>>0] = 0;
  __ZN12InputManager11MakeDefaultEv($this);
  STACKTOP = sp;return;
 } else {
  $46 = (($this) + 144|0);
  $47 = HEAP32[$46>>2]|0;
  HEAP8[$47>>0] = 0;
  $48 = (($this) + 140|0);
  HEAP32[$48>>2] = 0;
  __ZN12InputManager11MakeDefaultEv($this);
  STACKTOP = sp;return;
 }
}
function __Z10AddGUIAxesRNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEEE($axes) {
 $axes = $axes|0;
 var $$0 = 0, $$0$i = 0, $$0$i19 = 0, $$0$i40 = 0, $$0$i49 = 0, $$0$i70 = 0, $$0$i79 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$4 = 0, $$45 = 0, $$5 = 0, $$56 = 0, $$6 = 0, $$67 = 0, $$byval_copy17 = 0, $$pre$i = 0;
 var $$pre$i26 = 0, $$pre$i56 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0;
 $$byval_copy17 = sp + 456|0;
 $0 = sp + 452|0;
 $1 = sp + 448|0;
 $2 = sp + 444|0;
 $3 = sp + 440|0;
 $4 = sp + 436|0;
 $5 = sp + 432|0;
 $6 = sp + 428|0;
 $7 = sp + 424|0;
 $8 = sp + 420|0;
 $9 = sp + 416|0;
 $10 = sp + 412|0;
 $11 = sp + 408|0;
 $12 = sp + 404|0;
 $13 = sp + 400|0;
 $14 = sp + 396|0;
 $15 = sp + 136|0;
 $16 = sp;
 $17 = sp + 4|0;
 $18 = sp + 8|0;
 $19 = sp + 100|0;
 $20 = sp + 112|0;
 $21 = sp + 124|0;
 $22 = sp + 140|0;
 $23 = sp + 232|0;
 $24 = sp + 244|0;
 $25 = sp + 256|0;
 $26 = sp + 268|0;
 $27 = sp + 360|0;
 $28 = sp + 372|0;
 $29 = sp + 384|0;
 $30 = (($axes) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$axes>>2]|0;
 $33 = $31;
 $34 = $32;
 $35 = (($33) - ($34))|0;
 $36 = (($35|0) / 92)&-1;
 HEAP8[$19>>0] = 12;
 $37 = (($19) + 1|0);
 ;HEAP8[$37+0>>0]=HEAP8[612712+0>>0]|0;HEAP8[$37+1>>0]=HEAP8[612712+1>>0]|0;HEAP8[$37+2>>0]=HEAP8[612712+2>>0]|0;HEAP8[$37+3>>0]=HEAP8[612712+3>>0]|0;HEAP8[$37+4>>0]=HEAP8[612712+4>>0]|0;HEAP8[$37+5>>0]=HEAP8[612712+5>>0]|0;
 $38 = (($19) + 7|0);
 HEAP8[$38>>0] = 0;
 __THREW__ = 0;
 invoke_vii(2744,($18|0),($19|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 do {
  if ($40) {
   $286 = ___cxa_find_matching_catch()|0;
   $287 = tempRet0;
   $$0 = $287;$$01 = $286;
  } else {
   $41 = HEAP32[$30>>2]|0;
   $42 = (($axes) + 8|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($41|0)==($43|0);
   do {
    if ($44) {
     __THREW__ = 0;
     invoke_vii(2746,($axes|0),($18|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 86;
     }
    } else {
     $45 = ($41|0)==(0|0);
     if ($45) {
      $49 = 0;
     } else {
      __THREW__ = 0;
      invoke_vii(2745,($41|0),($18|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 86;
       break;
      }
      $$pre$i = HEAP32[$30>>2]|0;
      $49 = $$pre$i;
     }
     $48 = (($49) + 92|0);
     HEAP32[$30>>2] = $48;
    }
   } while(0);
   if ((label|0) == 86) {
    $288 = ___cxa_find_matching_catch()|0;
    $289 = tempRet0;
    HEAP32[$18>>2] = ((612552 + 8|0));
    $290 = (($18) + 28|0);
    $291 = HEAP8[$290>>0]|0;
    $292 = $291 & 1;
    $293 = ($292<<24>>24)==(0);
    if (!($293)) {
     $294 = (($18) + 36|0);
     $295 = HEAP32[$294>>2]|0;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$8+0>>2]|0;
     invoke_vii(2591,($295|0),($$byval_copy17|0));
     $296 = __THREW__; __THREW__ = 0;
     $297 = $296&1;
     if ($297) {
      $298 = ___cxa_find_matching_catch()|0;
      $299 = tempRet0;
      ___cxa_call_unexpected(($298|0));
      // unreachable;
     }
    }
    $300 = (($18) + 16|0);
    $301 = HEAP8[$300>>0]|0;
    $302 = $301 & 1;
    $303 = ($302<<24>>24)==(0);
    if (!($303)) {
     $304 = (($18) + 24|0);
     $305 = HEAP32[$304>>2]|0;
     HEAP32[$7>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$7+0>>2]|0;
     invoke_vii(2591,($305|0),($$byval_copy17|0));
     $306 = __THREW__; __THREW__ = 0;
     $307 = $306&1;
     if ($307) {
      $308 = ___cxa_find_matching_catch()|0;
      $309 = tempRet0;
      ___cxa_call_unexpected(($308|0));
      // unreachable;
     }
    }
    $310 = (($18) + 4|0);
    $311 = HEAP8[$310>>0]|0;
    $312 = $311 & 1;
    $313 = ($312<<24>>24)==(0);
    if ($313) {
     $$0 = $289;$$01 = $288;
     break;
    }
    $314 = (($18) + 12|0);
    $315 = HEAP32[$314>>2]|0;
    HEAP32[$6>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_vii(2591,($315|0),($$byval_copy17|0));
    $316 = __THREW__; __THREW__ = 0;
    $317 = $316&1;
    if (!($317)) {
     $$0 = $289;$$01 = $288;
     break;
    }
    $318 = ___cxa_find_matching_catch()|0;
    $319 = tempRet0;
    ___cxa_call_unexpected(($318|0));
    // unreachable;
   }
   HEAP32[$18>>2] = ((612552 + 8|0));
   $52 = (($18) + 28|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = $53 & 1;
   $55 = ($54<<24>>24)==(0);
   if (!($55)) {
    $56 = (($18) + 36|0);
    $57 = HEAP32[$56>>2]|0;
    HEAP32[$17>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$17+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy17|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     $60 = ___cxa_find_matching_catch()|0;
     $61 = tempRet0;
     ___cxa_call_unexpected(($60|0));
     // unreachable;
    }
   }
   $62 = (($18) + 16|0);
   $63 = HEAP8[$62>>0]|0;
   $64 = $63 & 1;
   $65 = ($64<<24>>24)==(0);
   if (!($65)) {
    $66 = (($18) + 24|0);
    $67 = HEAP32[$66>>2]|0;
    HEAP32[$16>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$16+0>>2]|0;
    invoke_vii(2591,($67|0),($$byval_copy17|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    }
   }
   $72 = (($18) + 4|0);
   $73 = HEAP8[$72>>0]|0;
   $74 = $73 & 1;
   $75 = ($74<<24>>24)==(0);
   if (!($75)) {
    $76 = (($18) + 12|0);
    $77 = HEAP32[$76>>2]|0;
    HEAP32[$15>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$15+0>>2]|0;
    invoke_vii(2591,($77|0),($$byval_copy17|0));
    $78 = __THREW__; __THREW__ = 0;
    $79 = $78&1;
    if ($79) {
     $80 = ___cxa_find_matching_catch()|0;
     $81 = tempRet0;
     ___cxa_call_unexpected(($80|0));
     // unreachable;
    }
   }
   $82 = HEAP8[$19>>0]|0;
   $83 = $82 & 1;
   $84 = ($83<<24>>24)==(0);
   if (!($84)) {
    $85 = (($19) + 8|0);
    $86 = HEAP32[$85>>2]|0;
    __ZdlPv($86);
   }
   $87 = (($36) + 1)|0;
   $88 = HEAP32[$axes>>2]|0;
   $89 = (($88) + (($36*92)|0)|0);
   HEAP8[$20>>0] = 12;
   $90 = (($20) + 1|0);
   ;HEAP8[$90+0>>0]=HEAP8[612720+0>>0]|0;HEAP8[$90+1>>0]=HEAP8[612720+1>>0]|0;HEAP8[$90+2>>0]=HEAP8[612720+2>>0]|0;HEAP8[$90+3>>0]=HEAP8[612720+3>>0]|0;HEAP8[$90+4>>0]=HEAP8[612720+4>>0]|0;HEAP8[$90+5>>0]=HEAP8[612720+5>>0]|0;
   $91 = (($20) + 7|0);
   HEAP8[$91>>0] = 0;
   $92 = HEAP32[613088>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy17,$92,$20);
   $93 = HEAP32[613088>>2]|0;
   $94 = (($93) + 4|0);
   $95 = HEAP32[$$byval_copy17>>2]|0;
   $96 = ($95|0)==($94|0);
   if ($96) {
    $$0$i = 0;
   } else {
    $97 = (($95) + 28|0);
    $98 = HEAP32[$97>>2]|0;
    $$0$i = $98;
   }
   __THREW__ = 0;
   $99 = (invoke_ii(2988,32)|0);
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   do {
    if ($101) {
     $325 = ___cxa_find_matching_catch()|0;
     $326 = tempRet0;
     $$1 = $326;$$12 = $325;
    } else {
     $102 = (($21) + 8|0);
     HEAP32[$102>>2] = $99;
     HEAP32[$21>>2] = 33;
     $103 = (($21) + 4|0);
     HEAP32[$103>>2] = 17;
     dest=$99+0|0; src=612728+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $104 = (($99) + 17|0);
     HEAP8[$104>>0] = 0;
     __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy17,$93,$21);
     $105 = HEAP32[613088>>2]|0;
     $106 = (($105) + 4|0);
     $107 = HEAP32[$$byval_copy17>>2]|0;
     $108 = ($107|0)==($106|0);
     if ($108) {
      $$0$i19 = 0;
     } else {
      $109 = (($107) + 28|0);
      $110 = HEAP32[$109>>2]|0;
      $$0$i19 = $110;
     }
     __THREW__ = 0;
     invoke_viii(1764,($89|0),($$0$i|0),($$0$i19|0));
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      $327 = ___cxa_find_matching_catch()|0;
      $328 = tempRet0;
      $329 = HEAP8[$21>>0]|0;
      $330 = $329 & 1;
      $331 = ($330<<24>>24)==(0);
      if ($331) {
       $$1 = $328;$$12 = $327;
       break;
      }
      $332 = HEAP32[$102>>2]|0;
      __ZdlPv($332);
      $$1 = $328;$$12 = $327;
      break;
     }
     $113 = HEAP8[$21>>0]|0;
     $114 = $113 & 1;
     $115 = ($114<<24>>24)==(0);
     if (!($115)) {
      $116 = HEAP32[$102>>2]|0;
      __ZdlPv($116);
     }
     $117 = HEAP8[$20>>0]|0;
     $118 = $117 & 1;
     $119 = ($118<<24>>24)==(0);
     if (!($119)) {
      $120 = (($20) + 8|0);
      $121 = HEAP32[$120>>2]|0;
      __ZdlPv($121);
     }
     HEAP8[$23>>0] = 12;
     $122 = (($23) + 1|0);
     ;HEAP8[$122+0>>0]=HEAP8[612712+0>>0]|0;HEAP8[$122+1>>0]=HEAP8[612712+1>>0]|0;HEAP8[$122+2>>0]=HEAP8[612712+2>>0]|0;HEAP8[$122+3>>0]=HEAP8[612712+3>>0]|0;HEAP8[$122+4>>0]=HEAP8[612712+4>>0]|0;HEAP8[$122+5>>0]=HEAP8[612712+5>>0]|0;
     $123 = (($23) + 7|0);
     HEAP8[$123>>0] = 0;
     __THREW__ = 0;
     invoke_vii(2744,($22|0),($23|0));
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     do {
      if ($125) {
       $338 = ___cxa_find_matching_catch()|0;
       $339 = tempRet0;
       $$2 = $339;$$23 = $338;
      } else {
       $126 = HEAP32[$30>>2]|0;
       $127 = HEAP32[$42>>2]|0;
       $128 = ($126|0)==($127|0);
       do {
        if ($128) {
         __THREW__ = 0;
         invoke_vii(2746,($axes|0),($22|0));
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          label = 103;
         }
        } else {
         $129 = ($126|0)==(0|0);
         if ($129) {
          $133 = 0;
         } else {
          __THREW__ = 0;
          invoke_vii(2745,($126|0),($22|0));
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           label = 103;
           break;
          }
          $$pre$i26 = HEAP32[$30>>2]|0;
          $133 = $$pre$i26;
         }
         $132 = (($133) + 92|0);
         HEAP32[$30>>2] = $132;
        }
       } while(0);
       if ((label|0) == 103) {
        $340 = ___cxa_find_matching_catch()|0;
        $341 = tempRet0;
        HEAP32[$22>>2] = ((612552 + 8|0));
        $342 = (($22) + 28|0);
        $343 = HEAP8[$342>>0]|0;
        $344 = $343 & 1;
        $345 = ($344<<24>>24)==(0);
        do {
         if (!($345)) {
          $346 = (($22) + 36|0);
          $347 = HEAP32[$346>>2]|0;
          HEAP32[$5>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$5+0>>2]|0;
          invoke_vii(2591,($347|0),($$byval_copy17|0));
          $348 = __THREW__; __THREW__ = 0;
          $349 = $348&1;
          if (!($349)) {
           break;
          }
          $350 = ___cxa_find_matching_catch()|0;
          $351 = tempRet0;
          ___cxa_call_unexpected(($350|0));
          // unreachable;
         }
        } while(0);
        $352 = (($22) + 16|0);
        $353 = HEAP8[$352>>0]|0;
        $354 = $353 & 1;
        $355 = ($354<<24>>24)==(0);
        do {
         if (!($355)) {
          $356 = (($22) + 24|0);
          $357 = HEAP32[$356>>2]|0;
          HEAP32[$4>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$4+0>>2]|0;
          invoke_vii(2591,($357|0),($$byval_copy17|0));
          $358 = __THREW__; __THREW__ = 0;
          $359 = $358&1;
          if (!($359)) {
           break;
          }
          $360 = ___cxa_find_matching_catch()|0;
          $361 = tempRet0;
          ___cxa_call_unexpected(($360|0));
          // unreachable;
         }
        } while(0);
        $362 = (($22) + 4|0);
        $363 = HEAP8[$362>>0]|0;
        $364 = $363 & 1;
        $365 = ($364<<24>>24)==(0);
        if ($365) {
         $$2 = $341;$$23 = $340;
         break;
        }
        $366 = (($22) + 12|0);
        $367 = HEAP32[$366>>2]|0;
        HEAP32[$3>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($367|0),($$byval_copy17|0));
        $368 = __THREW__; __THREW__ = 0;
        $369 = $368&1;
        if (!($369)) {
         $$2 = $341;$$23 = $340;
         break;
        }
        $370 = ___cxa_find_matching_catch()|0;
        $371 = tempRet0;
        ___cxa_call_unexpected(($370|0));
        // unreachable;
       }
       HEAP32[$22>>2] = ((612552 + 8|0));
       $136 = (($22) + 28|0);
       $137 = HEAP8[$136>>0]|0;
       $138 = $137 & 1;
       $139 = ($138<<24>>24)==(0);
       if (!($139)) {
        $140 = (($22) + 36|0);
        $141 = HEAP32[$140>>2]|0;
        HEAP32[$14>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$14+0>>2]|0;
        invoke_vii(2591,($141|0),($$byval_copy17|0));
        $142 = __THREW__; __THREW__ = 0;
        $143 = $142&1;
        if ($143) {
         $144 = ___cxa_find_matching_catch()|0;
         $145 = tempRet0;
         ___cxa_call_unexpected(($144|0));
         // unreachable;
        }
       }
       $146 = (($22) + 16|0);
       $147 = HEAP8[$146>>0]|0;
       $148 = $147 & 1;
       $149 = ($148<<24>>24)==(0);
       do {
        if (!($149)) {
         $150 = (($22) + 24|0);
         $151 = HEAP32[$150>>2]|0;
         HEAP32[$13>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$13+0>>2]|0;
         invoke_vii(2591,($151|0),($$byval_copy17|0));
         $152 = __THREW__; __THREW__ = 0;
         $153 = $152&1;
         if (!($153)) {
          break;
         }
         $154 = ___cxa_find_matching_catch()|0;
         $155 = tempRet0;
         ___cxa_call_unexpected(($154|0));
         // unreachable;
        }
       } while(0);
       $156 = (($22) + 4|0);
       $157 = HEAP8[$156>>0]|0;
       $158 = $157 & 1;
       $159 = ($158<<24>>24)==(0);
       do {
        if (!($159)) {
         $160 = (($22) + 12|0);
         $161 = HEAP32[$160>>2]|0;
         HEAP32[$12>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$12+0>>2]|0;
         invoke_vii(2591,($161|0),($$byval_copy17|0));
         $162 = __THREW__; __THREW__ = 0;
         $163 = $162&1;
         if (!($163)) {
          break;
         }
         $164 = ___cxa_find_matching_catch()|0;
         $165 = tempRet0;
         ___cxa_call_unexpected(($164|0));
         // unreachable;
        }
       } while(0);
       $166 = HEAP8[$23>>0]|0;
       $167 = $166 & 1;
       $168 = ($167<<24>>24)==(0);
       if (!($168)) {
        $169 = (($23) + 8|0);
        $170 = HEAP32[$169>>2]|0;
        __ZdlPv($170);
       }
       $171 = (($36) + 2)|0;
       $172 = HEAP32[$axes>>2]|0;
       $173 = (($172) + (($87*92)|0)|0);
       HEAP8[$24>>0] = 10;
       $174 = (($24) + 1|0);
       ;HEAP8[$174+0>>0]=HEAP8[612752+0>>0]|0;HEAP8[$174+1>>0]=HEAP8[612752+1>>0]|0;HEAP8[$174+2>>0]=HEAP8[612752+2>>0]|0;HEAP8[$174+3>>0]=HEAP8[612752+3>>0]|0;HEAP8[$174+4>>0]=HEAP8[612752+4>>0]|0;
       $175 = (($24) + 6|0);
       HEAP8[$175>>0] = 0;
       $176 = HEAP32[613088>>2]|0;
       __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy17,$176,$24);
       $177 = HEAP32[613088>>2]|0;
       $178 = (($177) + 4|0);
       $179 = HEAP32[$$byval_copy17>>2]|0;
       $180 = ($179|0)==($178|0);
       if ($180) {
        $$0$i40 = 0;
       } else {
        $181 = (($179) + 28|0);
        $182 = HEAP32[$181>>2]|0;
        $$0$i40 = $182;
       }
       HEAP8[$25>>0] = 10;
       $183 = (($25) + 1|0);
       ;HEAP8[$183+0>>0]=HEAP8[612760+0>>0]|0;HEAP8[$183+1>>0]=HEAP8[612760+1>>0]|0;HEAP8[$183+2>>0]=HEAP8[612760+2>>0]|0;HEAP8[$183+3>>0]=HEAP8[612760+3>>0]|0;HEAP8[$183+4>>0]=HEAP8[612760+4>>0]|0;
       $184 = (($25) + 6|0);
       HEAP8[$184>>0] = 0;
       __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy17,$177,$25);
       $185 = HEAP32[613088>>2]|0;
       $186 = (($185) + 4|0);
       $187 = HEAP32[$$byval_copy17>>2]|0;
       $188 = ($187|0)==($186|0);
       if ($188) {
        $$0$i49 = 0;
       } else {
        $189 = (($187) + 28|0);
        $190 = HEAP32[$189>>2]|0;
        $$0$i49 = $190;
       }
       __THREW__ = 0;
       invoke_viii(1764,($173|0),($$0$i40|0),($$0$i49|0));
       $191 = __THREW__; __THREW__ = 0;
       $192 = $191&1;
       if ($192) {
        $377 = ___cxa_find_matching_catch()|0;
        $378 = tempRet0;
        $379 = HEAP8[$25>>0]|0;
        $380 = $379 & 1;
        $381 = ($380<<24>>24)==(0);
        if (!($381)) {
         $382 = (($25) + 8|0);
         $383 = HEAP32[$382>>2]|0;
         __ZdlPv($383);
        }
        $384 = HEAP8[$24>>0]|0;
        $385 = $384 & 1;
        $386 = ($385<<24>>24)==(0);
        if ($386) {
         $$6 = $378;$$67 = $377;
         ___resumeException($$67|0);
         // unreachable;
        }
        $387 = (($24) + 8|0);
        $388 = HEAP32[$387>>2]|0;
        __ZdlPv($388);
        $$6 = $378;$$67 = $377;
        ___resumeException($$67|0);
        // unreachable;
       }
       $193 = HEAP8[$25>>0]|0;
       $194 = $193 & 1;
       $195 = ($194<<24>>24)==(0);
       if (!($195)) {
        $196 = (($25) + 8|0);
        $197 = HEAP32[$196>>2]|0;
        __ZdlPv($197);
       }
       $198 = HEAP8[$24>>0]|0;
       $199 = $198 & 1;
       $200 = ($199<<24>>24)==(0);
       if (!($200)) {
        $201 = (($24) + 8|0);
        $202 = HEAP32[$201>>2]|0;
        __ZdlPv($202);
       }
       HEAP8[$27>>0] = 12;
       $203 = (($27) + 1|0);
       ;HEAP8[$203+0>>0]=HEAP8[612768+0>>0]|0;HEAP8[$203+1>>0]=HEAP8[612768+1>>0]|0;HEAP8[$203+2>>0]=HEAP8[612768+2>>0]|0;HEAP8[$203+3>>0]=HEAP8[612768+3>>0]|0;HEAP8[$203+4>>0]=HEAP8[612768+4>>0]|0;HEAP8[$203+5>>0]=HEAP8[612768+5>>0]|0;
       $204 = (($27) + 7|0);
       HEAP8[$204>>0] = 0;
       __THREW__ = 0;
       invoke_vii(2744,($26|0),($27|0));
       $205 = __THREW__; __THREW__ = 0;
       $206 = $205&1;
       do {
        if ($206) {
         $389 = ___cxa_find_matching_catch()|0;
         $390 = tempRet0;
         $$4 = $390;$$45 = $389;
        } else {
         $207 = HEAP32[$30>>2]|0;
         $208 = HEAP32[$42>>2]|0;
         $209 = ($207|0)==($208|0);
         do {
          if ($209) {
           __THREW__ = 0;
           invoke_vii(2746,($axes|0),($26|0));
           $215 = __THREW__; __THREW__ = 0;
           $216 = $215&1;
           if ($216) {
            label = 119;
           }
          } else {
           $210 = ($207|0)==(0|0);
           if ($210) {
            $214 = 0;
           } else {
            __THREW__ = 0;
            invoke_vii(2745,($207|0),($26|0));
            $211 = __THREW__; __THREW__ = 0;
            $212 = $211&1;
            if ($212) {
             label = 119;
             break;
            }
            $$pre$i56 = HEAP32[$30>>2]|0;
            $214 = $$pre$i56;
           }
           $213 = (($214) + 92|0);
           HEAP32[$30>>2] = $213;
          }
         } while(0);
         if ((label|0) == 119) {
          $391 = ___cxa_find_matching_catch()|0;
          $392 = tempRet0;
          HEAP32[$26>>2] = ((612552 + 8|0));
          $393 = (($26) + 28|0);
          $394 = HEAP8[$393>>0]|0;
          $395 = $394 & 1;
          $396 = ($395<<24>>24)==(0);
          do {
           if (!($396)) {
            $397 = (($26) + 36|0);
            $398 = HEAP32[$397>>2]|0;
            HEAP32[$2>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$2+0>>2]|0;
            invoke_vii(2591,($398|0),($$byval_copy17|0));
            $399 = __THREW__; __THREW__ = 0;
            $400 = $399&1;
            if (!($400)) {
             break;
            }
            $401 = ___cxa_find_matching_catch()|0;
            $402 = tempRet0;
            ___cxa_call_unexpected(($401|0));
            // unreachable;
           }
          } while(0);
          $403 = (($26) + 16|0);
          $404 = HEAP8[$403>>0]|0;
          $405 = $404 & 1;
          $406 = ($405<<24>>24)==(0);
          do {
           if (!($406)) {
            $407 = (($26) + 24|0);
            $408 = HEAP32[$407>>2]|0;
            HEAP32[$1>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$1+0>>2]|0;
            invoke_vii(2591,($408|0),($$byval_copy17|0));
            $409 = __THREW__; __THREW__ = 0;
            $410 = $409&1;
            if (!($410)) {
             break;
            }
            $411 = ___cxa_find_matching_catch()|0;
            $412 = tempRet0;
            ___cxa_call_unexpected(($411|0));
            // unreachable;
           }
          } while(0);
          $413 = (($26) + 4|0);
          $414 = HEAP8[$413>>0]|0;
          $415 = $414 & 1;
          $416 = ($415<<24>>24)==(0);
          if ($416) {
           $$4 = $392;$$45 = $391;
           break;
          }
          $417 = (($26) + 12|0);
          $418 = HEAP32[$417>>2]|0;
          HEAP32[$0>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($418|0),($$byval_copy17|0));
          $419 = __THREW__; __THREW__ = 0;
          $420 = $419&1;
          if (!($420)) {
           $$4 = $392;$$45 = $391;
           break;
          }
          $421 = ___cxa_find_matching_catch()|0;
          $422 = tempRet0;
          ___cxa_call_unexpected(($421|0));
          // unreachable;
         }
         HEAP32[$26>>2] = ((612552 + 8|0));
         $217 = (($26) + 28|0);
         $218 = HEAP8[$217>>0]|0;
         $219 = $218 & 1;
         $220 = ($219<<24>>24)==(0);
         do {
          if (!($220)) {
           $221 = (($26) + 36|0);
           $222 = HEAP32[$221>>2]|0;
           HEAP32[$11>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$11+0>>2]|0;
           invoke_vii(2591,($222|0),($$byval_copy17|0));
           $223 = __THREW__; __THREW__ = 0;
           $224 = $223&1;
           if (!($224)) {
            break;
           }
           $225 = ___cxa_find_matching_catch()|0;
           $226 = tempRet0;
           ___cxa_call_unexpected(($225|0));
           // unreachable;
          }
         } while(0);
         $227 = (($26) + 16|0);
         $228 = HEAP8[$227>>0]|0;
         $229 = $228 & 1;
         $230 = ($229<<24>>24)==(0);
         do {
          if (!($230)) {
           $231 = (($26) + 24|0);
           $232 = HEAP32[$231>>2]|0;
           HEAP32[$10>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$10+0>>2]|0;
           invoke_vii(2591,($232|0),($$byval_copy17|0));
           $233 = __THREW__; __THREW__ = 0;
           $234 = $233&1;
           if (!($234)) {
            break;
           }
           $235 = ___cxa_find_matching_catch()|0;
           $236 = tempRet0;
           ___cxa_call_unexpected(($235|0));
           // unreachable;
          }
         } while(0);
         $237 = (($26) + 4|0);
         $238 = HEAP8[$237>>0]|0;
         $239 = $238 & 1;
         $240 = ($239<<24>>24)==(0);
         do {
          if (!($240)) {
           $241 = (($26) + 12|0);
           $242 = HEAP32[$241>>2]|0;
           HEAP32[$9>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$9+0>>2]|0;
           invoke_vii(2591,($242|0),($$byval_copy17|0));
           $243 = __THREW__; __THREW__ = 0;
           $244 = $243&1;
           if (!($244)) {
            break;
           }
           $245 = ___cxa_find_matching_catch()|0;
           $246 = tempRet0;
           ___cxa_call_unexpected(($245|0));
           // unreachable;
          }
         } while(0);
         $247 = HEAP8[$27>>0]|0;
         $248 = $247 & 1;
         $249 = ($248<<24>>24)==(0);
         if (!($249)) {
          $250 = (($27) + 8|0);
          $251 = HEAP32[$250>>2]|0;
          __ZdlPv($251);
         }
         $252 = HEAP32[$axes>>2]|0;
         $253 = (($252) + (($171*92)|0)|0);
         HEAP8[$28>>0] = 12;
         $254 = (($28) + 1|0);
         ;HEAP8[$254+0>>0]=HEAP8[612776+0>>0]|0;HEAP8[$254+1>>0]=HEAP8[612776+1>>0]|0;HEAP8[$254+2>>0]=HEAP8[612776+2>>0]|0;HEAP8[$254+3>>0]=HEAP8[612776+3>>0]|0;HEAP8[$254+4>>0]=HEAP8[612776+4>>0]|0;HEAP8[$254+5>>0]=HEAP8[612776+5>>0]|0;
         $255 = (($28) + 7|0);
         HEAP8[$255>>0] = 0;
         $256 = HEAP32[613088>>2]|0;
         __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy17,$256,$28);
         $257 = HEAP32[613088>>2]|0;
         $258 = (($257) + 4|0);
         $259 = HEAP32[$$byval_copy17>>2]|0;
         $260 = ($259|0)==($258|0);
         if ($260) {
          $$0$i70 = 0;
         } else {
          $261 = (($259) + 28|0);
          $262 = HEAP32[$261>>2]|0;
          $$0$i70 = $262;
         }
         __THREW__ = 0;
         $263 = (invoke_ii(2988,32)|0);
         $264 = __THREW__; __THREW__ = 0;
         $265 = $264&1;
         do {
          if ($265) {
           $428 = ___cxa_find_matching_catch()|0;
           $429 = tempRet0;
           $$5 = $429;$$56 = $428;
          } else {
           $266 = (($29) + 8|0);
           HEAP32[$266>>2] = $263;
           HEAP32[$29>>2] = 33;
           $267 = (($29) + 4|0);
           HEAP32[$267>>2] = 17;
           dest=$263+0|0; src=612784+0|0; stop=dest+17|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $268 = (($263) + 17|0);
           HEAP8[$268>>0] = 0;
           __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy17,$257,$29);
           $269 = HEAP32[613088>>2]|0;
           $270 = (($269) + 4|0);
           $271 = HEAP32[$$byval_copy17>>2]|0;
           $272 = ($271|0)==($270|0);
           if ($272) {
            $$0$i79 = 0;
           } else {
            $273 = (($271) + 28|0);
            $274 = HEAP32[$273>>2]|0;
            $$0$i79 = $274;
           }
           __THREW__ = 0;
           invoke_viii(1764,($253|0),($$0$i70|0),($$0$i79|0));
           $275 = __THREW__; __THREW__ = 0;
           $276 = $275&1;
           if ($276) {
            $430 = ___cxa_find_matching_catch()|0;
            $431 = tempRet0;
            $432 = HEAP8[$29>>0]|0;
            $433 = $432 & 1;
            $434 = ($433<<24>>24)==(0);
            if ($434) {
             $$5 = $431;$$56 = $430;
             break;
            }
            $435 = HEAP32[$266>>2]|0;
            __ZdlPv($435);
            $$5 = $431;$$56 = $430;
            break;
           }
           $277 = HEAP8[$29>>0]|0;
           $278 = $277 & 1;
           $279 = ($278<<24>>24)==(0);
           if (!($279)) {
            $280 = HEAP32[$266>>2]|0;
            __ZdlPv($280);
           }
           $281 = HEAP8[$28>>0]|0;
           $282 = $281 & 1;
           $283 = ($282<<24>>24)==(0);
           if ($283) {
            STACKTOP = sp;return;
           }
           $284 = (($28) + 8|0);
           $285 = HEAP32[$284>>2]|0;
           __ZdlPv($285);
           STACKTOP = sp;return;
          }
         } while(0);
         $436 = HEAP8[$28>>0]|0;
         $437 = $436 & 1;
         $438 = ($437<<24>>24)==(0);
         if ($438) {
          $$6 = $$5;$$67 = $$56;
          ___resumeException($$67|0);
          // unreachable;
         }
         $439 = (($28) + 8|0);
         $440 = HEAP32[$439>>2]|0;
         __ZdlPv($440);
         $$6 = $$5;$$67 = $$56;
         ___resumeException($$67|0);
         // unreachable;
        }
       } while(0);
       $423 = HEAP8[$27>>0]|0;
       $424 = $423 & 1;
       $425 = ($424<<24>>24)==(0);
       if ($425) {
        $$6 = $$4;$$67 = $$45;
        ___resumeException($$67|0);
        // unreachable;
       }
       $426 = (($27) + 8|0);
       $427 = HEAP32[$426>>2]|0;
       __ZdlPv($427);
       $$6 = $$4;$$67 = $$45;
       ___resumeException($$67|0);
       // unreachable;
      }
     } while(0);
     $372 = HEAP8[$23>>0]|0;
     $373 = $372 & 1;
     $374 = ($373<<24>>24)==(0);
     if ($374) {
      $$6 = $$2;$$67 = $$23;
      ___resumeException($$67|0);
      // unreachable;
     }
     $375 = (($23) + 8|0);
     $376 = HEAP32[$375>>2]|0;
     __ZdlPv($376);
     $$6 = $$2;$$67 = $$23;
     ___resumeException($$67|0);
     // unreachable;
    }
   } while(0);
   $333 = HEAP8[$20>>0]|0;
   $334 = $333 & 1;
   $335 = ($334<<24>>24)==(0);
   if ($335) {
    $$6 = $$1;$$67 = $$12;
    ___resumeException($$67|0);
    // unreachable;
   }
   $336 = (($20) + 8|0);
   $337 = HEAP32[$336>>2]|0;
   __ZdlPv($337);
   $$6 = $$1;$$67 = $$12;
   ___resumeException($$67|0);
   // unreachable;
  }
 } while(0);
 $320 = HEAP8[$19>>0]|0;
 $321 = $320 & 1;
 $322 = ($321<<24>>24)==(0);
 if ($322) {
  $$6 = $$0;$$67 = $$01;
  ___resumeException($$67|0);
  // unreachable;
 }
 $323 = (($19) + 8|0);
 $324 = HEAP32[$323>>2]|0;
 __ZdlPv($324);
 $$6 = $$0;$$67 = $$01;
 ___resumeException($$67|0);
 // unreachable;
}
function __Z11StringToKeyRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($name) {
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $found = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $found = sp;
 $0 = HEAP32[613088>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($found,$0,$name);
 $1 = HEAP32[613088>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$found>>2]|0;
 $4 = ($3|0)==($2|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($3) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12InputManager9GetButtonERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $finalButton$0$off0$lcssa = 0, $finalButton$0$off04 = 0, $finalButton$1$off0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $finalButton$0$off0$lcssa = 0;
  STACKTOP = sp;return ($finalButton$0$off0$lcssa|0);
 }
 $5 = HEAP8[$name>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 $8 = $5&255;
 $9 = $8 >>> 1;
 $10 = (($name) + 1|0);
 $11 = (($this) + 56|0);
 $12 = (($this) + 40|0);
 $13 = (($name) + 8|0);
 $14 = (($name) + 4|0);
 $16 = $1;$finalButton$0$off04 = 0;
 while(1) {
  $15 = (($16) + 4|0);
  $17 = HEAP8[$15>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $22 = $17&255;
   $23 = $22 >>> 1;
   $26 = $23;
  } else {
   $20 = (($16) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $26 = $21;
  }
  if ($7) {
   $27 = $9;
  } else {
   $24 = HEAP32[$14>>2]|0;
   $27 = $24;
  }
  $25 = ($26|0)==($27|0);
  if ($25) {
   if ($19) {
    $30 = (($15) + 1|0);
    $36 = $30;
   } else {
    $28 = (($16) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    $36 = $29;
   }
   if ($7) {
    $37 = $10;
   } else {
    $31 = HEAP32[$13>>2]|0;
    $37 = $31;
   }
   if ($19) {
    $34 = $17&255;
    $35 = $34 >>> 1;
    $38 = $35;
   } else {
    $32 = (($16) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $38 = $33;
   }
   $39 = (_strncmp($36,$37,$38)|0);
   $40 = ($39|0)==(0);
   if ($40) {
    $41 = (($16) + 40|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42 >>> 5;
    $44 = HEAP32[$11>>2]|0;
    $45 = (($44) + ($43<<2)|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = $42 & 31;
    $48 = 1 << $47;
    $49 = HEAP32[$12>>2]|0;
    $50 = (($49) + ($43<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = $51 | $46;
    $53 = $52 & $48;
    $54 = ($53|0)!=(0);
    $55 = $finalButton$0$off04 | $54;
    $56 = (($16) + 44|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = $57 >>> 5;
    $59 = (($44) + ($58<<2)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = $57 & 31;
    $62 = 1 << $61;
    $63 = (($49) + ($58<<2)|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = $64 | $60;
    $66 = $65 & $62;
    $67 = ($66|0)!=(0);
    $68 = $55 | $67;
    $69 = (($16) + 48|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = $70 >>> 5;
    $72 = (($44) + ($71<<2)|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = $70 & 31;
    $75 = 1 << $74;
    $76 = (($49) + ($71<<2)|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = $77 | $73;
    $79 = $78 & $75;
    $80 = ($79|0)!=(0);
    $81 = $68 | $80;
    $82 = (($16) + 52|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = $83 >>> 5;
    $85 = (($44) + ($84<<2)|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = $83 & 31;
    $88 = 1 << $87;
    $89 = (($49) + ($84<<2)|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = $90 | $86;
    $92 = $91 & $88;
    $93 = ($92|0)!=(0);
    $94 = $81 | $93;
    $finalButton$1$off0 = $94;
   } else {
    $finalButton$1$off0 = $finalButton$0$off04;
   }
  } else {
   $finalButton$1$off0 = $finalButton$0$off04;
  }
  $95 = (($16) + 92|0);
  $96 = ($95|0)==($3|0);
  if ($96) {
   $finalButton$0$off0$lcssa = $finalButton$1$off0;
   break;
  } else {
   $16 = $95;$finalButton$0$off04 = $finalButton$1$off0;
  }
 }
 STACKTOP = sp;return ($finalButton$0$off0$lcssa|0);
}
function __ZN12InputManager13GetButtonDownERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $finalButton$0$off0$lcssa = 0, $finalButton$0$off012 = 0, $finalButton$1$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $finalButton$0$off0$lcssa = 0;
  STACKTOP = sp;return ($finalButton$0$off0$lcssa|0);
 }
 $5 = HEAP8[$name>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 $8 = $5&255;
 $9 = $8 >>> 1;
 $10 = (($name) + 1|0);
 $11 = (($this) + 56|0);
 $12 = (($name) + 8|0);
 $13 = (($name) + 4|0);
 $15 = $1;$finalButton$0$off012 = 0;
 while(1) {
  $14 = (($15) + 4|0);
  $16 = HEAP8[$14>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $21 = $16&255;
   $22 = $21 >>> 1;
   $25 = $22;
  } else {
   $19 = (($15) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $25 = $20;
  }
  if ($7) {
   $26 = $9;
  } else {
   $23 = HEAP32[$13>>2]|0;
   $26 = $23;
  }
  $24 = ($25|0)==($26|0);
  if ($24) {
   if ($18) {
    $29 = (($14) + 1|0);
    $35 = $29;
   } else {
    $27 = (($15) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $35 = $28;
   }
   if ($7) {
    $36 = $10;
   } else {
    $30 = HEAP32[$12>>2]|0;
    $36 = $30;
   }
   if ($18) {
    $33 = $16&255;
    $34 = $33 >>> 1;
    $37 = $34;
   } else {
    $31 = (($15) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $37 = $32;
   }
   $38 = (_strncmp($35,$36,$37)|0);
   $39 = ($38|0)==(0);
   if ($39) {
    $40 = (($15) + 60|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==(0);
    if ($42) {
     $43 = (($15) + 40|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = $44 >>> 5;
     $46 = HEAP32[$11>>2]|0;
     $47 = (($46) + ($45<<2)|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = $44 & 31;
     $50 = 1 << $49;
     $51 = $48 & $50;
     $52 = ($51|0)!=(0);
     $53 = $finalButton$0$off012 | $52;
     $54 = (($15) + 44|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = $55 >>> 5;
     $57 = (($46) + ($56<<2)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = $55 & 31;
     $60 = 1 << $59;
     $61 = $60 & $58;
     $62 = ($61|0)!=(0);
     $63 = $53 | $62;
     $64 = (($15) + 48|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = $65 >>> 5;
     $67 = (($46) + ($66<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = $65 & 31;
     $70 = 1 << $69;
     $71 = $70 & $68;
     $72 = ($71|0)!=(0);
     $73 = $63 | $72;
     $74 = (($15) + 52|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = $75 >>> 5;
     $77 = (($46) + ($76<<2)|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = $75 & 31;
     $80 = 1 << $79;
     $81 = $80 & $78;
     $82 = ($81|0)!=(0);
     $83 = $73 | $82;
     $finalButton$1$off0 = $83;
    } else {
     $finalButton$1$off0 = $finalButton$0$off012;
    }
   } else {
    $finalButton$1$off0 = $finalButton$0$off012;
   }
  } else {
   $finalButton$1$off0 = $finalButton$0$off012;
  }
  $84 = (($15) + 92|0);
  $85 = ($84|0)==($3|0);
  if ($85) {
   $finalButton$0$off0$lcssa = $finalButton$1$off0;
   break;
  } else {
   $15 = $84;$finalButton$0$off012 = $finalButton$1$off0;
  }
 }
 STACKTOP = sp;return ($finalButton$0$off0$lcssa|0);
}
function __ZN12InputManager7GetAxisERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $finalValue$0$lcssa = Math_fround(0), $finalValue$03 = Math_fround(0), $finalValue$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $finalValue$0$lcssa = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($finalValue$0$lcssa));
 }
 $5 = HEAP8[$name>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 $8 = $5&255;
 $9 = $8 >>> 1;
 $10 = (($name) + 1|0);
 $11 = (($name) + 8|0);
 $12 = (($name) + 4|0);
 $14 = $1;$finalValue$03 = Math_fround(0.0);
 while(1) {
  $13 = (($14) + 4|0);
  $15 = HEAP8[$13>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $20 = $15&255;
   $21 = $20 >>> 1;
   $24 = $21;
  } else {
   $18 = (($14) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $24 = $19;
  }
  if ($7) {
   $25 = $9;
  } else {
   $22 = HEAP32[$12>>2]|0;
   $25 = $22;
  }
  $23 = ($24|0)==($25|0);
  if ($23) {
   if ($17) {
    $28 = (($13) + 1|0);
    $34 = $28;
   } else {
    $26 = (($14) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $34 = $27;
   }
   if ($7) {
    $35 = $10;
   } else {
    $29 = HEAP32[$11>>2]|0;
    $35 = $29;
   }
   if ($17) {
    $32 = $15&255;
    $33 = $32 >>> 1;
    $36 = $33;
   } else {
    $30 = (($14) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $36 = $31;
   }
   $37 = (_strncmp($34,$35,$36)|0);
   $38 = ($37|0)==(0);
   if ($38) {
    $39 = (($14) + 64|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = $40 < Math_fround(0.0);
    if ($41) {
     $42 = Math_fround(-$40);
     $46 = $42;
    } else {
     $46 = $40;
    }
    $43 = $finalValue$03 < Math_fround(0.0);
    if ($43) {
     $44 = Math_fround(-$finalValue$03);
     $47 = $44;
    } else {
     $47 = $finalValue$03;
    }
    $45 = $46 > $47;
    if ($45) {
     $finalValue$1 = $40;
    } else {
     $finalValue$1 = $finalValue$03;
    }
   } else {
    $finalValue$1 = $finalValue$03;
   }
  } else {
   $finalValue$1 = $finalValue$03;
  }
  $48 = (($14) + 92|0);
  $49 = ($48|0)==($3|0);
  if ($49) {
   $finalValue$0$lcssa = $finalValue$1;
   break;
  } else {
   $14 = $48;$finalValue$03 = $finalValue$1;
  }
 }
 STACKTOP = sp;return (Math_fround($finalValue$0$lcssa));
}
function __ZN12InputManager10GetAxisRawERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $finalValue$0$lcssa = Math_fround(0), $finalValue$03 = Math_fround(0), $finalValue$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $finalValue$0$lcssa = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($finalValue$0$lcssa));
 }
 $5 = (($name) + 1|0);
 $6 = (($name) + 8|0);
 $7 = (($name) + 4|0);
 $9 = $1;$finalValue$03 = Math_fround(0.0);
 while(1) {
  $8 = (($9) + 4|0);
  $10 = HEAP8[$8>>0]|0;
  $11 = $10 & 1;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $15 = $10&255;
   $16 = $15 >>> 1;
   $24 = $16;
  } else {
   $13 = (($9) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $24 = $14;
  }
  $17 = HEAP8[$name>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $21 = $17&255;
   $22 = $21 >>> 1;
   $25 = $22;
  } else {
   $20 = HEAP32[$7>>2]|0;
   $25 = $20;
  }
  $23 = ($24|0)==($25|0);
  if ($23) {
   if ($12) {
    $28 = (($8) + 1|0);
    $34 = $28;
   } else {
    $26 = (($9) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $34 = $27;
   }
   if ($19) {
    $35 = $5;
   } else {
    $29 = HEAP32[$6>>2]|0;
    $35 = $29;
   }
   if ($12) {
    $32 = $10&255;
    $33 = $32 >>> 1;
    $36 = $33;
   } else {
    $30 = (($9) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    $36 = $31;
   }
   $37 = (_strncmp($34,$35,$36)|0);
   $38 = ($37|0)==(0);
   if ($38) {
    $39 = (Math_fround(__ZNK9InputAxis11GetValueRawEv($9)));
    $40 = $39 < Math_fround(0.0);
    if ($40) {
     $41 = Math_fround(-$39);
     $45 = $41;
    } else {
     $45 = $39;
    }
    $42 = $finalValue$03 < Math_fround(0.0);
    if ($42) {
     $43 = Math_fround(-$finalValue$03);
     $46 = $43;
    } else {
     $46 = $finalValue$03;
    }
    $44 = $45 > $46;
    if ($44) {
     $47 = (Math_fround(__ZNK9InputAxis11GetValueRawEv($9)));
     $finalValue$1 = $47;
    } else {
     $finalValue$1 = $finalValue$03;
    }
   } else {
    $finalValue$1 = $finalValue$03;
   }
  } else {
   $finalValue$1 = $finalValue$03;
  }
  $48 = (($9) + 92|0);
  $49 = HEAP32[$2>>2]|0;
  $50 = ($48|0)==($49|0);
  if ($50) {
   $finalValue$0$lcssa = $finalValue$1;
   break;
  } else {
   $9 = $48;$finalValue$03 = $finalValue$1;
  }
 }
 STACKTOP = sp;return (Math_fround($finalValue$0$lcssa));
}
function __ZN12InputManager16CheckConsistencyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12InputManager14ResetInputAxesEv($this);
 STACKTOP = sp;return;
}
function __ZN12InputManager14ResetInputAxesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i1$06 = 0, $j$05 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  $6 = $1;
  while(1) {
   $5 = (($6) + 64|0);
   HEAPF32[$5>>2] = Math_fround(0.0);
   $7 = (($6) + 68|0);
   HEAPF32[$7>>2] = Math_fround(0.0);
   $8 = (($6) + 92|0);
   $9 = ($8|0)==($3|0);
   if ($9) {
    break;
   } else {
    $6 = $8;
   }
  }
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $13 = (($this) + 40|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($this) + 48|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16 << 2;
  _memset(($14|0),0,($17|0))|0;
 }
 $18 = (($this) + 60|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = (($this) + 56|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($this) + 64|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 << 2;
  _memset(($22|0),0,($25|0))|0;
 }
 $26 = (($this) + 76|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if (!($28)) {
  $29 = (($this) + 72|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($this) + 80|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $32 << 2;
  _memset(($30|0),0,($33|0))|0;
 }
 $34 = (($this) + 116|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 112|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($35|0)==($37|0);
 if ($38) {
  $57 = (($this) + 84|0);
  ;HEAP32[$57+0>>2]=0|0;HEAP32[$57+4>>2]=0|0;HEAP32[$57+8>>2]=0|0;HEAP32[$57+12>>2]=0|0;
  STACKTOP = sp;return;
 }
 $39 = $35;
 $40 = $37;
 $41 = (($39) - ($40))|0;
 $42 = (($41|0) / 12)&-1;
 $i1$06 = 0;
 while(1) {
  $43 = ((($37) + (($i1$06*12)|0)|0) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($37) + (($i1$06*12)|0)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($44|0)==($46|0);
  if (!($47)) {
   $48 = $44;
   $49 = $46;
   $50 = (($48) - ($49))|0;
   $51 = $50 >> 2;
   $j$05 = 0;
   while(1) {
    $52 = (($46) + ($j$05<<2)|0);
    HEAPF32[$52>>2] = Math_fround(0.0);
    $53 = (($j$05) + 1)|0;
    $54 = ($53>>>0)<($51>>>0);
    if ($54) {
     $j$05 = $53;
    } else {
     break;
    }
   }
  }
  $55 = (($i1$06) + 1)|0;
  $56 = ($55>>>0)<($42>>>0);
  if ($56) {
   $i1$06 = $55;
  } else {
   break;
  }
 }
 $57 = (($this) + 84|0);
 ;HEAP32[$57+0>>2]=0|0;HEAP32[$57+4>>2]=0|0;HEAP32[$57+8>>2]=0|0;HEAP32[$57+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNK12InputManager19GetJoystickPositionEii($this,$joyNum,$axis) {
 $this = $this|0;
 $joyNum = $joyNum|0;
 $axis = $axis|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($7|0)>($joyNum|0);
 if (!($8)) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $9 = ((($3) + (($joyNum*12)|0)|0) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($3) + (($joyNum*12)|0)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $10;
 $14 = $12;
 $15 = (($13) - ($14))|0;
 $16 = $15 >> 2;
 $17 = ($16|0)>($axis|0);
 if (!($17)) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $18 = (($12) + ($axis<<2)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $$0 = $19;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN12InputManager19SetJoystickPositionEiif($this,$joyNum,$axis,$pos) {
 $this = $this|0;
 $joyNum = $joyNum|0;
 $axis = $axis|0;
 $pos = Math_fround($pos);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($7|0)>($joyNum|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = ((($3) + (($joyNum*12)|0)|0) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($3) + (($joyNum*12)|0)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $10;
 $14 = $12;
 $15 = (($13) - ($14))|0;
 $16 = $15 >> 2;
 $17 = ($16|0)>($axis|0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($12) + ($axis<<2)|0);
 HEAPF32[$18>>2] = $pos;
 STACKTOP = sp;return;
}
function __Z19SetupKeyNameMappingv() {
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0;
 var $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $buffy = 0, $button$03 = 0, $button$03$us = 0, $exitcond = 0, $exitcond6 = 0, $exitcond7 = 0, $joystick$04 = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1072|0;
 $vararg_buffer1 = sp;
 $0 = sp + 960|0;
 $1 = sp + 956|0;
 $2 = sp + 952|0;
 $3 = sp + 948|0;
 $4 = sp + 944|0;
 $5 = sp + 940|0;
 $6 = sp + 936|0;
 $7 = sp + 932|0;
 $8 = sp + 928|0;
 $9 = sp + 924|0;
 $10 = sp + 920|0;
 $11 = sp + 916|0;
 $12 = sp + 912|0;
 $13 = sp + 908|0;
 $14 = sp + 904|0;
 $15 = sp + 900|0;
 $16 = sp + 896|0;
 $17 = sp + 892|0;
 $18 = sp + 888|0;
 $19 = sp + 884|0;
 $20 = sp + 880|0;
 $21 = sp + 876|0;
 $22 = sp + 872|0;
 $23 = sp + 868|0;
 $24 = sp + 864|0;
 $25 = sp + 860|0;
 $26 = sp + 856|0;
 $27 = sp + 852|0;
 $28 = sp + 848|0;
 $29 = sp + 844|0;
 $30 = sp + 840|0;
 $31 = sp + 836|0;
 $32 = sp + 832|0;
 $33 = sp + 828|0;
 $34 = sp + 824|0;
 $35 = sp + 820|0;
 $36 = sp + 816|0;
 $37 = sp + 812|0;
 $38 = sp + 808|0;
 $39 = sp + 804|0;
 $40 = sp + 800|0;
 $41 = sp + 796|0;
 $42 = sp + 792|0;
 $43 = sp + 788|0;
 $44 = sp + 784|0;
 $45 = sp + 780|0;
 $46 = sp + 776|0;
 $47 = sp + 772|0;
 $48 = sp + 768|0;
 $49 = sp + 764|0;
 $50 = sp + 760|0;
 $51 = sp + 756|0;
 $52 = sp + 752|0;
 $53 = sp + 748|0;
 $54 = sp + 744|0;
 $55 = sp + 740|0;
 $56 = sp + 736|0;
 $57 = sp + 732|0;
 $58 = sp + 728|0;
 $59 = sp + 724|0;
 $60 = sp + 720|0;
 $61 = sp + 716|0;
 $62 = sp + 712|0;
 $63 = sp + 708|0;
 $64 = sp + 704|0;
 $65 = sp + 700|0;
 $66 = sp + 696|0;
 $67 = sp + 692|0;
 $68 = sp + 688|0;
 $69 = sp + 684|0;
 $70 = sp + 680|0;
 $71 = sp + 676|0;
 $72 = sp + 672|0;
 $73 = sp + 668|0;
 $74 = sp + 664|0;
 $75 = sp + 660|0;
 $76 = sp + 656|0;
 $77 = sp + 652|0;
 $78 = sp + 648|0;
 $79 = sp + 644|0;
 $80 = sp + 640|0;
 $81 = sp + 636|0;
 $82 = sp + 632|0;
 $83 = sp + 628|0;
 $84 = sp + 624|0;
 $85 = sp + 620|0;
 $86 = sp + 616|0;
 $87 = sp + 612|0;
 $88 = sp + 608|0;
 $89 = sp + 604|0;
 $90 = sp + 600|0;
 $91 = sp + 596|0;
 $92 = sp + 592|0;
 $93 = sp + 588|0;
 $94 = sp + 584|0;
 $95 = sp + 580|0;
 $96 = sp + 576|0;
 $97 = sp + 572|0;
 $98 = sp + 568|0;
 $99 = sp + 564|0;
 $100 = sp + 560|0;
 $101 = sp + 556|0;
 $102 = sp + 552|0;
 $103 = sp + 548|0;
 $104 = sp + 544|0;
 $105 = sp + 540|0;
 $106 = sp + 536|0;
 $107 = sp + 532|0;
 $108 = sp + 528|0;
 $109 = sp + 524|0;
 $110 = sp + 520|0;
 $111 = sp + 516|0;
 $112 = sp + 512|0;
 $113 = sp + 508|0;
 $114 = sp + 504|0;
 $115 = sp + 500|0;
 $116 = sp + 496|0;
 $117 = sp + 492|0;
 $118 = sp + 488|0;
 $119 = sp + 244|0;
 $120 = sp + 964|0;
 $121 = sp + 232|0;
 $122 = sp + 228|0;
 $123 = sp + 224|0;
 $124 = sp + 220|0;
 $125 = sp + 216|0;
 $126 = sp + 212|0;
 $127 = sp + 208|0;
 $128 = sp + 204|0;
 $129 = sp + 200|0;
 $130 = sp + 196|0;
 $131 = sp + 192|0;
 $132 = sp + 188|0;
 $133 = sp + 184|0;
 $134 = sp + 180|0;
 $135 = sp + 176|0;
 $136 = sp + 172|0;
 $137 = sp + 168|0;
 $138 = sp + 164|0;
 $139 = sp + 160|0;
 $140 = sp + 156|0;
 $141 = sp + 152|0;
 $142 = sp + 148|0;
 $143 = sp + 144|0;
 $144 = sp + 140|0;
 $145 = sp + 136|0;
 $146 = sp + 132|0;
 $147 = sp + 128|0;
 $148 = sp + 124|0;
 $149 = sp + 240|0;
 $150 = sp + 60|0;
 $151 = sp + 52|0;
 $152 = sp + 48|0;
 $153 = sp + 44|0;
 $154 = sp + 40|0;
 $155 = sp + 36|0;
 $156 = sp + 32|0;
 $157 = sp + 56|0;
 $158 = sp + 20|0;
 $159 = sp + 16|0;
 $160 = sp + 12|0;
 $161 = sp + 8|0;
 $162 = sp + 24|0;
 $163 = sp + 28|0;
 $164 = sp + 116|0;
 $165 = sp + 64|0;
 $166 = sp + 68|0;
 $167 = sp + 72|0;
 $168 = sp + 76|0;
 $169 = sp + 80|0;
 $170 = sp + 84|0;
 $171 = sp + 88|0;
 $172 = sp + 92|0;
 $173 = sp + 96|0;
 $174 = sp + 100|0;
 $175 = sp + 104|0;
 $176 = sp + 108|0;
 $177 = sp + 112|0;
 $178 = sp + 120|0;
 $179 = sp + 484|0;
 $180 = sp + 248|0;
 $181 = sp + 252|0;
 $182 = sp + 256|0;
 $183 = sp + 260|0;
 $184 = sp + 264|0;
 $185 = sp + 268|0;
 $186 = sp + 272|0;
 $187 = sp + 276|0;
 $188 = sp + 280|0;
 $189 = sp + 284|0;
 $190 = sp + 288|0;
 $191 = sp + 292|0;
 $192 = sp + 296|0;
 $193 = sp + 300|0;
 $194 = sp + 304|0;
 $195 = sp + 308|0;
 $196 = sp + 312|0;
 $197 = sp + 316|0;
 $198 = sp + 320|0;
 $199 = sp + 324|0;
 $200 = sp + 328|0;
 $201 = sp + 332|0;
 $202 = sp + 336|0;
 $203 = sp + 340|0;
 $204 = sp + 344|0;
 $205 = sp + 348|0;
 $206 = sp + 352|0;
 $207 = sp + 356|0;
 $208 = sp + 360|0;
 $209 = sp + 364|0;
 $210 = sp + 368|0;
 $211 = sp + 372|0;
 $212 = sp + 376|0;
 $213 = sp + 380|0;
 $214 = sp + 384|0;
 $215 = sp + 388|0;
 $216 = sp + 392|0;
 $217 = sp + 396|0;
 $218 = sp + 400|0;
 $219 = sp + 404|0;
 $220 = sp + 408|0;
 $221 = sp + 412|0;
 $222 = sp + 416|0;
 $223 = sp + 420|0;
 $224 = sp + 424|0;
 $225 = sp + 428|0;
 $226 = sp + 432|0;
 $227 = sp + 436|0;
 $228 = sp + 440|0;
 $229 = sp + 444|0;
 $230 = sp + 448|0;
 $231 = sp + 452|0;
 $232 = sp + 456|0;
 $233 = sp + 460|0;
 $234 = sp + 464|0;
 $235 = sp + 468|0;
 $236 = sp + 472|0;
 $237 = sp + 476|0;
 $238 = sp + 480|0;
 $buffy = sp + 968|0;
 $239 = sp + 236|0;
 $240 = HEAP8[613096>>0]|0;
 $241 = ($240<<24>>24)==(0);
 if (!($241)) {
  STACKTOP = sp;return;
 }
 HEAP8[613096>>0] = 1;
 $242 = HEAP32[613080>>2]|0;
 HEAP32[$0>>2] = 8;
 $243 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($242,$0)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($243,613104)|0);
 $244 = HEAP32[613080>>2]|0;
 HEAP32[$1>>2] = 9;
 $245 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($244,$1)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($245,613120)|0);
 $246 = HEAP32[613080>>2]|0;
 HEAP32[$2>>2] = 12;
 $247 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($246,$2)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($247,613128)|0);
 $248 = HEAP32[613080>>2]|0;
 HEAP32[$3>>2] = 13;
 $249 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($248,$3)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($249,612720)|0);
 $250 = HEAP32[613080>>2]|0;
 HEAP32[$4>>2] = 19;
 $251 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($250,$4)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($251,613136)|0);
 $252 = HEAP32[613080>>2]|0;
 HEAP32[$5>>2] = 27;
 $253 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($252,$5)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($253,612776)|0);
 $254 = HEAP32[613080>>2]|0;
 HEAP32[$6>>2] = 32;
 $255 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($254,$6)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($255,612760)|0);
 $256 = HEAP32[613080>>2]|0;
 HEAP32[$7>>2] = 33;
 $257 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($256,$7)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($257,613144)|0);
 $258 = HEAP32[613080>>2]|0;
 HEAP32[$8>>2] = 34;
 $259 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($258,$8)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($259,613152)|0);
 $260 = HEAP32[613080>>2]|0;
 HEAP32[$9>>2] = 35;
 $261 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($260,$9)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($261,613160)|0);
 $262 = HEAP32[613080>>2]|0;
 HEAP32[$10>>2] = 36;
 $263 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($262,$10)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($263,613168)|0);
 $264 = HEAP32[613080>>2]|0;
 HEAP32[$11>>2] = 38;
 $265 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($264,$11)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($265,613176)|0);
 $266 = HEAP32[613080>>2]|0;
 HEAP32[$12>>2] = 39;
 $267 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($266,$12)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($267,613184)|0);
 $268 = HEAP32[613080>>2]|0;
 HEAP32[$13>>2] = 40;
 $269 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($268,$13)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($269,613192)|0);
 $270 = HEAP32[613080>>2]|0;
 HEAP32[$14>>2] = 41;
 $271 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($270,$14)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($271,613200)|0);
 $272 = HEAP32[613080>>2]|0;
 HEAP32[$15>>2] = 42;
 $273 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($272,$15)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($273,613208)|0);
 $274 = HEAP32[613080>>2]|0;
 HEAP32[$16>>2] = 43;
 $275 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($274,$16)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($275,613216)|0);
 $276 = HEAP32[613080>>2]|0;
 HEAP32[$17>>2] = 44;
 $277 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($276,$17)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($277,613224)|0);
 $278 = HEAP32[613080>>2]|0;
 HEAP32[$18>>2] = 45;
 $279 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($278,$18)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($279,613232)|0);
 $280 = HEAP32[613080>>2]|0;
 HEAP32[$19>>2] = 46;
 $281 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($280,$19)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($281,613240)|0);
 $282 = HEAP32[613080>>2]|0;
 HEAP32[$20>>2] = 47;
 $283 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($282,$20)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($283,613248)|0);
 $284 = HEAP32[613080>>2]|0;
 HEAP32[$21>>2] = 48;
 $285 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($284,$21)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($285,613256)|0);
 $286 = HEAP32[613080>>2]|0;
 HEAP32[$22>>2] = 49;
 $287 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($286,$22)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($287,613264)|0);
 $288 = HEAP32[613080>>2]|0;
 HEAP32[$23>>2] = 50;
 $289 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($288,$23)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($289,613272)|0);
 $290 = HEAP32[613080>>2]|0;
 HEAP32[$24>>2] = 51;
 $291 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($290,$24)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($291,613280)|0);
 $292 = HEAP32[613080>>2]|0;
 HEAP32[$25>>2] = 52;
 $293 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($292,$25)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($293,613288)|0);
 $294 = HEAP32[613080>>2]|0;
 HEAP32[$26>>2] = 53;
 $295 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($294,$26)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($295,613296)|0);
 $296 = HEAP32[613080>>2]|0;
 HEAP32[$27>>2] = 54;
 $297 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($296,$27)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($297,613304)|0);
 $298 = HEAP32[613080>>2]|0;
 HEAP32[$28>>2] = 55;
 $299 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($298,$28)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($299,613312)|0);
 $300 = HEAP32[613080>>2]|0;
 HEAP32[$29>>2] = 56;
 $301 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($300,$29)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($301,613320)|0);
 $302 = HEAP32[613080>>2]|0;
 HEAP32[$30>>2] = 57;
 $303 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($302,$30)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($303,613328)|0);
 $304 = HEAP32[613080>>2]|0;
 HEAP32[$31>>2] = 58;
 $305 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($304,$31)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($305,613336)|0);
 $306 = HEAP32[613080>>2]|0;
 HEAP32[$32>>2] = 59;
 $307 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($306,$32)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($307,613344)|0);
 $308 = HEAP32[613080>>2]|0;
 HEAP32[$33>>2] = 60;
 $309 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($308,$33)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($309,613352)|0);
 $310 = HEAP32[613080>>2]|0;
 HEAP32[$34>>2] = 61;
 $311 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($310,$34)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($311,613360)|0);
 $312 = HEAP32[613080>>2]|0;
 HEAP32[$35>>2] = 62;
 $313 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($312,$35)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($313,613368)|0);
 $314 = HEAP32[613080>>2]|0;
 HEAP32[$36>>2] = 63;
 $315 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($314,$36)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($315,613376)|0);
 $316 = HEAP32[613080>>2]|0;
 HEAP32[$37>>2] = 64;
 $317 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($316,$37)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($317,613384)|0);
 $318 = HEAP32[613080>>2]|0;
 HEAP32[$38>>2] = 91;
 $319 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($318,$38)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($319,613392)|0);
 $320 = HEAP32[613080>>2]|0;
 HEAP32[$39>>2] = 92;
 $321 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($320,$39)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($321,613400)|0);
 $322 = HEAP32[613080>>2]|0;
 HEAP32[$40>>2] = 93;
 $323 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($322,$40)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($323,613408)|0);
 $324 = HEAP32[613080>>2]|0;
 HEAP32[$41>>2] = 94;
 $325 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($324,$41)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($325,613416)|0);
 $326 = HEAP32[613080>>2]|0;
 HEAP32[$42>>2] = 95;
 $327 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($326,$42)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($327,613424)|0);
 $328 = HEAP32[613080>>2]|0;
 HEAP32[$43>>2] = 96;
 $329 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($328,$43)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($329,613432)|0);
 $330 = HEAP32[613080>>2]|0;
 HEAP32[$44>>2] = 97;
 $331 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($330,$44)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($331,612848)|0);
 $332 = HEAP32[613080>>2]|0;
 HEAP32[$45>>2] = 98;
 $333 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($332,$45)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($333,613440)|0);
 $334 = HEAP32[613080>>2]|0;
 HEAP32[$46>>2] = 99;
 $335 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($334,$46)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($335,613448)|0);
 $336 = HEAP32[613080>>2]|0;
 HEAP32[$47>>2] = 100;
 $337 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($336,$47)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($337,612840)|0);
 $338 = HEAP32[613080>>2]|0;
 HEAP32[$48>>2] = 101;
 $339 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($338,$48)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($339,613456)|0);
 $340 = HEAP32[613080>>2]|0;
 HEAP32[$49>>2] = 102;
 $341 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($340,$49)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($341,613464)|0);
 $342 = HEAP32[613080>>2]|0;
 HEAP32[$50>>2] = 103;
 $343 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($342,$50)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($343,613472)|0);
 $344 = HEAP32[613080>>2]|0;
 HEAP32[$51>>2] = 104;
 $345 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($344,$51)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($345,613480)|0);
 $346 = HEAP32[613080>>2]|0;
 HEAP32[$52>>2] = 105;
 $347 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($346,$52)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($347,613488)|0);
 $348 = HEAP32[613080>>2]|0;
 HEAP32[$53>>2] = 106;
 $349 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($348,$53)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($349,613496)|0);
 $350 = HEAP32[613080>>2]|0;
 HEAP32[$54>>2] = 107;
 $351 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($350,$54)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($351,613504)|0);
 $352 = HEAP32[613080>>2]|0;
 HEAP32[$55>>2] = 108;
 $353 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($352,$55)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($353,613512)|0);
 $354 = HEAP32[613080>>2]|0;
 HEAP32[$56>>2] = 109;
 $355 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($354,$56)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($355,613520)|0);
 $356 = HEAP32[613080>>2]|0;
 HEAP32[$57>>2] = 110;
 $357 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($356,$57)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($357,613528)|0);
 $358 = HEAP32[613080>>2]|0;
 HEAP32[$58>>2] = 111;
 $359 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($358,$58)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($359,613536)|0);
 $360 = HEAP32[613080>>2]|0;
 HEAP32[$59>>2] = 112;
 $361 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($360,$59)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($361,613544)|0);
 $362 = HEAP32[613080>>2]|0;
 HEAP32[$60>>2] = 113;
 $363 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($362,$60)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($363,613552)|0);
 $364 = HEAP32[613080>>2]|0;
 HEAP32[$61>>2] = 114;
 $365 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($364,$61)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($365,613560)|0);
 $366 = HEAP32[613080>>2]|0;
 HEAP32[$62>>2] = 115;
 $367 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($366,$62)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($367,612880)|0);
 $368 = HEAP32[613080>>2]|0;
 HEAP32[$63>>2] = 116;
 $369 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($368,$63)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($369,613568)|0);
 $370 = HEAP32[613080>>2]|0;
 HEAP32[$64>>2] = 117;
 $371 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($370,$64)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($371,613576)|0);
 $372 = HEAP32[613080>>2]|0;
 HEAP32[$65>>2] = 118;
 $373 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($372,$65)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($373,613584)|0);
 $374 = HEAP32[613080>>2]|0;
 HEAP32[$66>>2] = 119;
 $375 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($374,$66)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($375,612872)|0);
 $376 = HEAP32[613080>>2]|0;
 HEAP32[$67>>2] = 120;
 $377 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($376,$67)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($377,613592)|0);
 $378 = HEAP32[613080>>2]|0;
 HEAP32[$68>>2] = 121;
 $379 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($378,$68)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($379,613600)|0);
 $380 = HEAP32[613080>>2]|0;
 HEAP32[$69>>2] = 122;
 $381 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($380,$69)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($381,613608)|0);
 $382 = HEAP32[613080>>2]|0;
 HEAP32[$70>>2] = 127;
 $383 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($382,$70)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($383,613616)|0);
 $384 = HEAP32[613080>>2]|0;
 HEAP32[$71>>2] = 160;
 $385 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($384,$71)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($385,613624)|0);
 $386 = HEAP32[613080>>2]|0;
 HEAP32[$72>>2] = 161;
 $387 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($386,$72)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($387,613632)|0);
 $388 = HEAP32[613080>>2]|0;
 HEAP32[$73>>2] = 162;
 $389 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($388,$73)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($389,613640)|0);
 $390 = HEAP32[613080>>2]|0;
 HEAP32[$74>>2] = 163;
 $391 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($390,$74)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($391,613648)|0);
 $392 = HEAP32[613080>>2]|0;
 HEAP32[$75>>2] = 164;
 $393 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($392,$75)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($393,613656)|0);
 $394 = HEAP32[613080>>2]|0;
 HEAP32[$76>>2] = 165;
 $395 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($394,$76)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($395,613664)|0);
 $396 = HEAP32[613080>>2]|0;
 HEAP32[$77>>2] = 166;
 $397 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($396,$77)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($397,613672)|0);
 $398 = HEAP32[613080>>2]|0;
 HEAP32[$78>>2] = 167;
 $399 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($398,$78)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($399,613680)|0);
 $400 = HEAP32[613080>>2]|0;
 HEAP32[$79>>2] = 168;
 $401 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($400,$79)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($401,613688)|0);
 $402 = HEAP32[613080>>2]|0;
 HEAP32[$80>>2] = 169;
 $403 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($402,$80)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($403,613696)|0);
 $404 = HEAP32[613080>>2]|0;
 HEAP32[$81>>2] = 170;
 $405 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($404,$81)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($405,613704)|0);
 $406 = HEAP32[613080>>2]|0;
 HEAP32[$82>>2] = 171;
 $407 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($406,$82)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($407,613720)|0);
 $408 = HEAP32[613080>>2]|0;
 HEAP32[$83>>2] = 172;
 $409 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($408,$83)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($409,613736)|0);
 $410 = HEAP32[613080>>2]|0;
 HEAP32[$84>>2] = 173;
 $411 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($410,$84)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($411,613752)|0);
 $412 = HEAP32[613080>>2]|0;
 HEAP32[$85>>2] = 174;
 $413 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($412,$85)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($413,613768)|0);
 $414 = HEAP32[613080>>2]|0;
 HEAP32[$86>>2] = 175;
 $415 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($414,$86)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($415,613784)|0);
 $416 = HEAP32[613080>>2]|0;
 HEAP32[$87>>2] = 176;
 $417 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($416,$87)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($417,613800)|0);
 $418 = HEAP32[613080>>2]|0;
 HEAP32[$88>>2] = 177;
 $419 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($418,$88)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($419,613816)|0);
 $420 = HEAP32[613080>>2]|0;
 HEAP32[$89>>2] = 178;
 $421 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($420,$89)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($421,613832)|0);
 $422 = HEAP32[613080>>2]|0;
 HEAP32[$90>>2] = 179;
 $423 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($422,$90)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($423,613848)|0);
 $424 = HEAP32[613080>>2]|0;
 HEAP32[$91>>2] = 180;
 $425 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($424,$91)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($425,613864)|0);
 $426 = HEAP32[613080>>2]|0;
 HEAP32[$92>>2] = 181;
 $427 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($426,$92)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($427,613880)|0);
 $428 = HEAP32[613080>>2]|0;
 HEAP32[$93>>2] = 182;
 $429 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($428,$93)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($429,613896)|0);
 $430 = HEAP32[613080>>2]|0;
 HEAP32[$94>>2] = 183;
 $431 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($430,$94)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($431,613912)|0);
 $432 = HEAP32[613080>>2]|0;
 HEAP32[$95>>2] = 184;
 $433 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($432,$95)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($433,613928)|0);
 $434 = HEAP32[613080>>2]|0;
 HEAP32[$96>>2] = 185;
 $435 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($434,$96)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($435,613944)|0);
 $436 = HEAP32[613080>>2]|0;
 HEAP32[$97>>2] = 186;
 $437 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($436,$97)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($437,613960)|0);
 $438 = HEAP32[613080>>2]|0;
 HEAP32[$98>>2] = 187;
 $439 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($438,$98)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($439,613976)|0);
 $440 = HEAP32[613080>>2]|0;
 HEAP32[$99>>2] = 188;
 $441 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($440,$99)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($441,613992)|0);
 $442 = HEAP32[613080>>2]|0;
 HEAP32[$100>>2] = 189;
 $443 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($442,$100)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($443,614008)|0);
 $444 = HEAP32[613080>>2]|0;
 HEAP32[$101>>2] = 190;
 $445 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($444,$101)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($445,614024)|0);
 $446 = HEAP32[613080>>2]|0;
 HEAP32[$102>>2] = 191;
 $447 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($446,$102)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($447,614040)|0);
 $448 = HEAP32[613080>>2]|0;
 HEAP32[$103>>2] = 192;
 $449 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($448,$103)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($449,614056)|0);
 $450 = HEAP32[613080>>2]|0;
 HEAP32[$104>>2] = 193;
 $451 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($450,$104)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($451,614072)|0);
 $452 = HEAP32[613080>>2]|0;
 HEAP32[$105>>2] = 194;
 $453 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($452,$105)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($453,614088)|0);
 $454 = HEAP32[613080>>2]|0;
 HEAP32[$106>>2] = 195;
 $455 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($454,$106)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($455,614104)|0);
 $456 = HEAP32[613080>>2]|0;
 HEAP32[$107>>2] = 196;
 $457 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($456,$107)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($457,614120)|0);
 $458 = HEAP32[613080>>2]|0;
 HEAP32[$108>>2] = 197;
 $459 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($458,$108)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($459,614136)|0);
 $460 = HEAP32[613080>>2]|0;
 HEAP32[$109>>2] = 198;
 $461 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($460,$109)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($461,614152)|0);
 $462 = HEAP32[613080>>2]|0;
 HEAP32[$110>>2] = 199;
 $463 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($462,$110)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($463,614168)|0);
 $464 = HEAP32[613080>>2]|0;
 HEAP32[$111>>2] = 200;
 $465 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($464,$111)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($465,614184)|0);
 $466 = HEAP32[613080>>2]|0;
 HEAP32[$112>>2] = 201;
 $467 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($466,$112)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($467,614200)|0);
 $468 = HEAP32[613080>>2]|0;
 HEAP32[$113>>2] = 202;
 $469 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($468,$113)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($469,614216)|0);
 $470 = HEAP32[613080>>2]|0;
 HEAP32[$114>>2] = 203;
 $471 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($470,$114)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($471,614232)|0);
 $472 = HEAP32[613080>>2]|0;
 HEAP32[$115>>2] = 204;
 $473 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($472,$115)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($473,614248)|0);
 $474 = HEAP32[613080>>2]|0;
 HEAP32[$116>>2] = 205;
 $475 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($474,$116)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($475,614264)|0);
 $476 = HEAP32[613080>>2]|0;
 HEAP32[$117>>2] = 206;
 $477 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($476,$117)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($477,614280)|0);
 $478 = HEAP32[613080>>2]|0;
 HEAP32[$118>>2] = 207;
 $479 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($478,$118)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($479,614296)|0);
 $480 = HEAP32[613080>>2]|0;
 HEAP32[$119>>2] = 208;
 $481 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($480,$119)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($481,614312)|0);
 $482 = HEAP32[613080>>2]|0;
 HEAP32[$120>>2] = 209;
 $483 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($482,$120)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($483,614328)|0);
 $484 = HEAP32[613080>>2]|0;
 HEAP32[$121>>2] = 210;
 $485 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($484,$121)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($485,614344)|0);
 $486 = HEAP32[613080>>2]|0;
 HEAP32[$122>>2] = 211;
 $487 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($486,$122)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($487,614360)|0);
 $488 = HEAP32[613080>>2]|0;
 HEAP32[$123>>2] = 212;
 $489 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($488,$123)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($489,614376)|0);
 $490 = HEAP32[613080>>2]|0;
 HEAP32[$124>>2] = 213;
 $491 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($490,$124)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($491,614392)|0);
 $492 = HEAP32[613080>>2]|0;
 HEAP32[$125>>2] = 214;
 $493 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($492,$125)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($493,614408)|0);
 $494 = HEAP32[613080>>2]|0;
 HEAP32[$126>>2] = 215;
 $495 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($494,$126)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($495,614424)|0);
 $496 = HEAP32[613080>>2]|0;
 HEAP32[$127>>2] = 216;
 $497 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($496,$127)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($497,614440)|0);
 $498 = HEAP32[613080>>2]|0;
 HEAP32[$128>>2] = 217;
 $499 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($498,$128)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($499,614456)|0);
 $500 = HEAP32[613080>>2]|0;
 HEAP32[$129>>2] = 218;
 $501 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($500,$129)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($501,614472)|0);
 $502 = HEAP32[613080>>2]|0;
 HEAP32[$130>>2] = 219;
 $503 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($502,$130)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($503,614488)|0);
 $504 = HEAP32[613080>>2]|0;
 HEAP32[$131>>2] = 220;
 $505 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($504,$131)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($505,614504)|0);
 $506 = HEAP32[613080>>2]|0;
 HEAP32[$132>>2] = 221;
 $507 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($506,$132)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($507,614520)|0);
 $508 = HEAP32[613080>>2]|0;
 HEAP32[$133>>2] = 222;
 $509 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($508,$133)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($509,614536)|0);
 $510 = HEAP32[613080>>2]|0;
 HEAP32[$134>>2] = 223;
 $511 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($510,$134)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($511,614552)|0);
 $512 = HEAP32[613080>>2]|0;
 HEAP32[$135>>2] = 224;
 $513 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($512,$135)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($513,614568)|0);
 $514 = HEAP32[613080>>2]|0;
 HEAP32[$136>>2] = 225;
 $515 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($514,$136)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($515,614584)|0);
 $516 = HEAP32[613080>>2]|0;
 HEAP32[$137>>2] = 226;
 $517 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($516,$137)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($517,614600)|0);
 $518 = HEAP32[613080>>2]|0;
 HEAP32[$138>>2] = 227;
 $519 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($518,$138)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($519,614616)|0);
 $520 = HEAP32[613080>>2]|0;
 HEAP32[$139>>2] = 228;
 $521 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($520,$139)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($521,614632)|0);
 $522 = HEAP32[613080>>2]|0;
 HEAP32[$140>>2] = 229;
 $523 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($522,$140)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($523,614648)|0);
 $524 = HEAP32[613080>>2]|0;
 HEAP32[$141>>2] = 230;
 $525 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($524,$141)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($525,614664)|0);
 $526 = HEAP32[613080>>2]|0;
 HEAP32[$142>>2] = 231;
 $527 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($526,$142)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($527,614680)|0);
 $528 = HEAP32[613080>>2]|0;
 HEAP32[$143>>2] = 232;
 $529 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($528,$143)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($529,614696)|0);
 $530 = HEAP32[613080>>2]|0;
 HEAP32[$144>>2] = 233;
 $531 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($530,$144)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($531,614712)|0);
 $532 = HEAP32[613080>>2]|0;
 HEAP32[$145>>2] = 234;
 $533 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($532,$145)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($533,614728)|0);
 $534 = HEAP32[613080>>2]|0;
 HEAP32[$146>>2] = 235;
 $535 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($534,$146)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($535,614744)|0);
 $536 = HEAP32[613080>>2]|0;
 HEAP32[$147>>2] = 236;
 $537 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($536,$147)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($537,614760)|0);
 $538 = HEAP32[613080>>2]|0;
 HEAP32[$148>>2] = 237;
 $539 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($538,$148)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($539,614776)|0);
 $540 = HEAP32[613080>>2]|0;
 HEAP32[$149>>2] = 238;
 $541 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($540,$149)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($541,614792)|0);
 $542 = HEAP32[613080>>2]|0;
 HEAP32[$150>>2] = 239;
 $543 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($542,$150)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($543,614808)|0);
 $544 = HEAP32[613080>>2]|0;
 HEAP32[$151>>2] = 240;
 $545 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($544,$151)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($545,614824)|0);
 $546 = HEAP32[613080>>2]|0;
 HEAP32[$152>>2] = 241;
 $547 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($546,$152)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($547,614840)|0);
 $548 = HEAP32[613080>>2]|0;
 HEAP32[$153>>2] = 242;
 $549 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($548,$153)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($549,614856)|0);
 $550 = HEAP32[613080>>2]|0;
 HEAP32[$154>>2] = 243;
 $551 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($550,$154)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($551,614872)|0);
 $552 = HEAP32[613080>>2]|0;
 HEAP32[$155>>2] = 244;
 $553 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($552,$155)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($553,614888)|0);
 $554 = HEAP32[613080>>2]|0;
 HEAP32[$156>>2] = 245;
 $555 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($554,$156)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($555,614904)|0);
 $556 = HEAP32[613080>>2]|0;
 HEAP32[$157>>2] = 246;
 $557 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($556,$157)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($557,614920)|0);
 $558 = HEAP32[613080>>2]|0;
 HEAP32[$158>>2] = 247;
 $559 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($558,$158)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($559,614936)|0);
 $560 = HEAP32[613080>>2]|0;
 HEAP32[$159>>2] = 248;
 $561 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($560,$159)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($561,614952)|0);
 $562 = HEAP32[613080>>2]|0;
 HEAP32[$160>>2] = 249;
 $563 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($562,$160)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($563,614968)|0);
 $564 = HEAP32[613080>>2]|0;
 HEAP32[$161>>2] = 250;
 $565 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($564,$161)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($565,614984)|0);
 $566 = HEAP32[613080>>2]|0;
 HEAP32[$162>>2] = 251;
 $567 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($566,$162)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($567,615000)|0);
 $568 = HEAP32[613080>>2]|0;
 HEAP32[$163>>2] = 252;
 $569 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($568,$163)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($569,615016)|0);
 $570 = HEAP32[613080>>2]|0;
 HEAP32[$164>>2] = 253;
 $571 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($570,$164)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($571,615032)|0);
 $572 = HEAP32[613080>>2]|0;
 HEAP32[$165>>2] = 254;
 $573 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($572,$165)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($573,615048)|0);
 $574 = HEAP32[613080>>2]|0;
 HEAP32[$166>>2] = 255;
 $575 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($574,$166)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($575,615064)|0);
 $576 = HEAP32[613080>>2]|0;
 HEAP32[$167>>2] = 256;
 $577 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($576,$167)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($577,615080)|0);
 $578 = HEAP32[613080>>2]|0;
 HEAP32[$168>>2] = 257;
 $579 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($578,$168)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($579,615088)|0);
 $580 = HEAP32[613080>>2]|0;
 HEAP32[$169>>2] = 258;
 $581 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($580,$169)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($581,615096)|0);
 $582 = HEAP32[613080>>2]|0;
 HEAP32[$170>>2] = 259;
 $583 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($582,$170)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($583,615104)|0);
 $584 = HEAP32[613080>>2]|0;
 HEAP32[$171>>2] = 260;
 $585 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($584,$171)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($585,615112)|0);
 $586 = HEAP32[613080>>2]|0;
 HEAP32[$172>>2] = 261;
 $587 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($586,$172)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($587,615120)|0);
 $588 = HEAP32[613080>>2]|0;
 HEAP32[$173>>2] = 262;
 $589 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($588,$173)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($589,615128)|0);
 $590 = HEAP32[613080>>2]|0;
 HEAP32[$174>>2] = 263;
 $591 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($590,$174)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($591,615136)|0);
 $592 = HEAP32[613080>>2]|0;
 HEAP32[$175>>2] = 264;
 $593 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($592,$175)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($593,615144)|0);
 $594 = HEAP32[613080>>2]|0;
 HEAP32[$176>>2] = 265;
 $595 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($594,$176)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($595,615152)|0);
 $596 = HEAP32[613080>>2]|0;
 HEAP32[$177>>2] = 266;
 $597 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($596,$177)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($597,615160)|0);
 $598 = HEAP32[613080>>2]|0;
 HEAP32[$178>>2] = 267;
 $599 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($598,$178)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($599,615168)|0);
 $600 = HEAP32[613080>>2]|0;
 HEAP32[$179>>2] = 268;
 $601 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($600,$179)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($601,615176)|0);
 $602 = HEAP32[613080>>2]|0;
 HEAP32[$180>>2] = 269;
 $603 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($602,$180)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($603,615184)|0);
 $604 = HEAP32[613080>>2]|0;
 HEAP32[$181>>2] = 270;
 $605 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($604,$181)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($605,615192)|0);
 $606 = HEAP32[613080>>2]|0;
 HEAP32[$182>>2] = 271;
 $607 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($606,$182)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($607,612752)|0);
 $608 = HEAP32[613080>>2]|0;
 HEAP32[$183>>2] = 272;
 $609 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($608,$183)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($609,615200)|0);
 $610 = HEAP32[613080>>2]|0;
 HEAP32[$184>>2] = 273;
 $611 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($610,$184)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($611,612856)|0);
 $612 = HEAP32[613080>>2]|0;
 HEAP32[$185>>2] = 274;
 $613 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($612,$185)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($613,612864)|0);
 $614 = HEAP32[613080>>2]|0;
 HEAP32[$186>>2] = 275;
 $615 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($614,$186)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($615,612824)|0);
 $616 = HEAP32[613080>>2]|0;
 HEAP32[$187>>2] = 276;
 $617 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($616,$187)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($617,612832)|0);
 $618 = HEAP32[613080>>2]|0;
 HEAP32[$188>>2] = 274;
 $619 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($618,$188)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($619,612864)|0);
 $620 = HEAP32[613080>>2]|0;
 HEAP32[$189>>2] = 277;
 $621 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($620,$189)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($621,615208)|0);
 $622 = HEAP32[613080>>2]|0;
 HEAP32[$190>>2] = 278;
 $623 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($622,$190)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($623,615216)|0);
 $624 = HEAP32[613080>>2]|0;
 HEAP32[$191>>2] = 279;
 $625 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($624,$191)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($625,615224)|0);
 $626 = HEAP32[613080>>2]|0;
 HEAP32[$192>>2] = 280;
 $627 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($626,$192)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($627,615232)|0);
 $628 = HEAP32[613080>>2]|0;
 HEAP32[$193>>2] = 281;
 $629 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($628,$193)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($629,615240)|0);
 $630 = HEAP32[613080>>2]|0;
 HEAP32[$194>>2] = 282;
 $631 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($630,$194)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($631,615256)|0);
 $632 = HEAP32[613080>>2]|0;
 HEAP32[$195>>2] = 283;
 $633 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($632,$195)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($633,615264)|0);
 $634 = HEAP32[613080>>2]|0;
 HEAP32[$196>>2] = 284;
 $635 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($634,$196)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($635,615272)|0);
 $636 = HEAP32[613080>>2]|0;
 HEAP32[$197>>2] = 285;
 $637 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($636,$197)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($637,615280)|0);
 $638 = HEAP32[613080>>2]|0;
 HEAP32[$198>>2] = 286;
 $639 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($638,$198)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($639,615288)|0);
 $640 = HEAP32[613080>>2]|0;
 HEAP32[$199>>2] = 287;
 $641 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($640,$199)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($641,615296)|0);
 $642 = HEAP32[613080>>2]|0;
 HEAP32[$200>>2] = 288;
 $643 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($642,$200)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($643,615304)|0);
 $644 = HEAP32[613080>>2]|0;
 HEAP32[$201>>2] = 289;
 $645 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($644,$201)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($645,615312)|0);
 $646 = HEAP32[613080>>2]|0;
 HEAP32[$202>>2] = 290;
 $647 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($646,$202)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($647,615320)|0);
 $648 = HEAP32[613080>>2]|0;
 HEAP32[$203>>2] = 291;
 $649 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($648,$203)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($649,615328)|0);
 $650 = HEAP32[613080>>2]|0;
 HEAP32[$204>>2] = 292;
 $651 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($650,$204)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($651,615336)|0);
 $652 = HEAP32[613080>>2]|0;
 HEAP32[$205>>2] = 293;
 $653 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($652,$205)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($653,615344)|0);
 $654 = HEAP32[613080>>2]|0;
 HEAP32[$206>>2] = 294;
 $655 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($654,$206)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($655,615352)|0);
 $656 = HEAP32[613080>>2]|0;
 HEAP32[$207>>2] = 295;
 $657 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($656,$207)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($657,615360)|0);
 $658 = HEAP32[613080>>2]|0;
 HEAP32[$208>>2] = 296;
 $659 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($658,$208)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($659,615368)|0);
 $660 = HEAP32[613080>>2]|0;
 HEAP32[$209>>2] = 300;
 $661 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($660,$209)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($661,615376)|0);
 $662 = HEAP32[613080>>2]|0;
 HEAP32[$210>>2] = 301;
 $663 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($662,$210)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($663,615384)|0);
 $664 = HEAP32[613080>>2]|0;
 HEAP32[$211>>2] = 302;
 $665 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($664,$211)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($665,615400)|0);
 $666 = HEAP32[613080>>2]|0;
 HEAP32[$212>>2] = 303;
 $667 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($666,$212)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($667,615416)|0);
 $668 = HEAP32[613080>>2]|0;
 HEAP32[$213>>2] = 304;
 $669 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($668,$213)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($669,615432)|0);
 $670 = HEAP32[613080>>2]|0;
 HEAP32[$214>>2] = 305;
 $671 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($670,$214)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($671,615448)|0);
 $672 = HEAP32[613080>>2]|0;
 HEAP32[$215>>2] = 306;
 $673 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($672,$215)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($673,612912)|0);
 $674 = HEAP32[613080>>2]|0;
 HEAP32[$216>>2] = 307;
 $675 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($674,$216)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($675,615464)|0);
 $676 = HEAP32[613080>>2]|0;
 HEAP32[$217>>2] = 308;
 $677 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($676,$217)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($677,612936)|0);
 $678 = HEAP32[613080>>2]|0;
 HEAP32[$218>>2] = 309;
 $679 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($678,$218)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($679,615480)|0);
 $680 = HEAP32[613080>>2]|0;
 HEAP32[$219>>2] = 310;
 $681 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($680,$219)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($681,612960)|0);
 $682 = HEAP32[613080>>2]|0;
 HEAP32[$220>>2] = 311;
 $683 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($682,$220)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($683,615496)|0);
 $684 = HEAP32[613080>>2]|0;
 HEAP32[$221>>2] = 312;
 $685 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($684,$221)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($685,615512)|0);
 $686 = HEAP32[613080>>2]|0;
 HEAP32[$222>>2] = 313;
 $687 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($686,$222)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($687,615528)|0);
 $688 = HEAP32[613080>>2]|0;
 HEAP32[$223>>2] = 314;
 $689 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($688,$223)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($689,615536)|0);
 $690 = HEAP32[613080>>2]|0;
 HEAP32[$224>>2] = 315;
 $691 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($690,$224)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($691,615544)|0);
 $692 = HEAP32[613080>>2]|0;
 HEAP32[$225>>2] = 316;
 $693 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($692,$225)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($693,615552)|0);
 $694 = HEAP32[613080>>2]|0;
 HEAP32[$226>>2] = 317;
 $695 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($694,$226)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($695,615568)|0);
 $696 = HEAP32[613080>>2]|0;
 HEAP32[$227>>2] = 318;
 $697 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($696,$227)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($697,615576)|0);
 $698 = HEAP32[613080>>2]|0;
 HEAP32[$228>>2] = 319;
 $699 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($698,$228)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($699,615584)|0);
 $700 = HEAP32[613080>>2]|0;
 HEAP32[$229>>2] = 320;
 $701 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($700,$229)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($701,615592)|0);
 $702 = HEAP32[613080>>2]|0;
 HEAP32[$230>>2] = 321;
 $703 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($702,$230)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($703,615600)|0);
 $704 = HEAP32[613080>>2]|0;
 HEAP32[$231>>2] = 322;
 $705 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($704,$231)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($705,615608)|0);
 $706 = HEAP32[613080>>2]|0;
 HEAP32[$232>>2] = 323;
 $707 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($706,$232)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($707,612928)|0);
 $708 = HEAP32[613080>>2]|0;
 HEAP32[$233>>2] = 324;
 $709 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($708,$233)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($709,612952)|0);
 $710 = HEAP32[613080>>2]|0;
 HEAP32[$234>>2] = 325;
 $711 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($710,$234)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($711,612976)|0);
 $712 = HEAP32[613080>>2]|0;
 HEAP32[$235>>2] = 326;
 $713 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($712,$235)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($713,615616)|0);
 $714 = HEAP32[613080>>2]|0;
 HEAP32[$236>>2] = 327;
 $715 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($714,$236)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($715,615624)|0);
 $716 = HEAP32[613080>>2]|0;
 HEAP32[$237>>2] = 328;
 $717 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($716,$237)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($717,615632)|0);
 $718 = HEAP32[613080>>2]|0;
 HEAP32[$238>>2] = 329;
 $719 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($718,$238)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($719,615640)|0);
 $joystick$04 = 0;
 while(1) {
  $720 = ($joystick$04|0)==(0);
  $721 = ($joystick$04*20)|0;
  $722 = (($721) + 330)|0;
  if ($720) {
   $button$03$us = 0;
   while(1) {
    HEAP32[$vararg_buffer1>>2] = $button$03$us;
    (_snprintf($buffy,100,615672,$vararg_buffer1)|0);
    $723 = HEAP32[613080>>2]|0;
    $724 = (($722) + ($button$03$us))|0;
    HEAP32[$239>>2] = $724;
    $725 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($723,$239)|0);
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($725,$buffy)|0);
    $726 = (($button$03$us) + 1)|0;
    $exitcond6 = ($726|0)==(20);
    if ($exitcond6) {
     break;
    } else {
     $button$03$us = $726;
    }
   }
  } else {
   $button$03 = 0;
   while(1) {
    HEAP32[$vararg_buffer1>>2] = $joystick$04;
    $vararg_ptr4 = (($vararg_buffer1) + 4|0);
    HEAP32[$vararg_ptr4>>2] = $button$03;
    (_snprintf($buffy,100,615648,$vararg_buffer1)|0);
    $727 = HEAP32[613080>>2]|0;
    $728 = (($722) + ($button$03))|0;
    HEAP32[$239>>2] = $728;
    $729 = (__ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($727,$239)|0);
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($729,$buffy)|0);
    $730 = (($button$03) + 1)|0;
    $exitcond = ($730|0)==(20);
    if ($exitcond) {
     break;
    } else {
     $button$03 = $730;
    }
   }
  }
  $731 = (($joystick$04) + 1)|0;
  $exitcond7 = ($731|0)==(12);
  if ($exitcond7) {
   break;
  } else {
   $joystick$04 = $731;
  }
 }
 $732 = HEAP32[613088>>2]|0;
 $733 = (($732) + 4|0);
 $734 = HEAP32[$733>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($732,$734);
 $735 = (($732) + 8|0);
 HEAP32[$735>>2] = 0;
 $736 = (($732) + 4|0);
 HEAP32[$732>>2] = $736;
 HEAP32[$736>>2] = 0;
 $737 = HEAP32[613080>>2]|0;
 $738 = HEAP32[$737>>2]|0;
 $739 = (($737) + 4|0);
 $740 = ($738|0)==($739|0);
 if ($740) {
  STACKTOP = sp;return;
 } else {
  $742 = $738;
 }
 while(1) {
  $741 = (($742) + 16|0);
  $743 = HEAP32[$741>>2]|0;
  $744 = HEAP32[613088>>2]|0;
  $745 = (($742) + 20|0);
  $746 = (__ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiNS_4lessIS6_EENS4_INS_4pairIKS6_iEEEEEixERSA_($744,$745)|0);
  HEAP32[$746>>2] = $743;
  $747 = (($742) + 4|0);
  $748 = HEAP32[$747>>2]|0;
  $749 = ($748|0)==(0|0);
  if ($749) {
   $$01$i$i$i$i = $742;
   while(1) {
    $752 = (($$01$i$i$i$i) + 8|0);
    $753 = HEAP32[$752>>2]|0;
    $754 = HEAP32[$753>>2]|0;
    $755 = ($754|0)==($$01$i$i$i$i|0);
    if ($755) {
     $$0$i$i$i$i = $753;
     break;
    } else {
     $$01$i$i$i$i = $753;
    }
   }
  } else {
   $$0$i$i$i$i$i = $748;
   while(1) {
    $750 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $751 = ($750|0)==(0|0);
    if ($751) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $750;
    }
   }
  }
  $756 = HEAP32[613080>>2]|0;
  $757 = (($756) + 4|0);
  $758 = ($$0$i$i$i$i|0)==($757|0);
  if ($758) {
   break;
  } else {
   $742 = $$0$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIiEENS4_INS_4pairIKiS6_EEEEEixERSA_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$22 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $31 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($31|0);
 }
 $16 = (__Znwj(32)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;
 HEAP32[$16>>2] = 0;
 $20 = (($16) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $16;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $16;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $__r$0 = $16;
 $31 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($31|0);
}
function __Z11KeyToStringi($agg$result,$key) {
 $agg$result = $agg$result|0;
 $key = $key|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[613080>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $5 = (($$013$i$in$i$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<($key|0);
    if (!($7)) {
     break;
    }
    $10 = (($$013$i$in$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $11;
    }
   }
   $8 = HEAP32[$$013$i$in$i$i>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $8;
   }
  }
  $13 = ($$0$ph5$i$i$i|0)==($3|0);
  if (!($13)) {
   $14 = (($$0$ph5$i$i$i) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>($key|0);
   $17 = ($$0$ph5$i$i$i|0)==($3|0);
   $or$cond = $16 | $17;
   if (!($or$cond)) {
    $18 = (($$0$ph5$i$i$i) + 20|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     ;HEAP32[$agg$result+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$18+8>>2]|0;
     STACKTOP = sp;return;
    }
    $22 = (($$0$ph5$i$i$i) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($$0$ph5$i$i$i) + 24|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25>>>0)>(4294967279);
    if ($26) {
     __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
     // unreachable;
    }
    $27 = ($25>>>0)<(11);
    if ($27) {
     $28 = $25 << 1;
     $29 = $28&255;
     HEAP8[$agg$result>>0] = $29;
     $30 = (($agg$result) + 1|0);
     $__p$0$i$i$i = $30;
    } else {
     $31 = (($25) + 16)|0;
     $32 = $31 & -16;
     $33 = (__Znwj($32)|0);
     $34 = (($agg$result) + 8|0);
     HEAP32[$34>>2] = $33;
     $35 = $32 | 1;
     HEAP32[$agg$result>>2] = $35;
     $36 = (($agg$result) + 4|0);
     HEAP32[$36>>2] = $25;
     $__p$0$i$i$i = $33;
    }
    _memcpy(($__p$0$i$i$i|0),($23|0),($25|0))|0;
    $37 = (($__p$0$i$i$i) + ($25)|0);
    HEAP8[$37>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN12InputManager13InputEndFrameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($this) + 64|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 << 2;
  _memset(($4|0),0,($7|0))|0;
 }
 $8 = (($this) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (($this) + 72|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($this) + 80|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 << 2;
  _memset(($12|0),0,($15|0))|0;
 }
 $16 = (($this) + 84|0);
 $17 = (($this) + 124|0);
 ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
 $18 = HEAP8[$17>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  $24 = (($17) + 1|0);
  HEAP8[$24>>0] = 0;
  HEAP8[$17>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $21 = (($this) + 132|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP8[$22>>0] = 0;
  $23 = (($this) + 128|0);
  HEAP32[$23>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN12InputManager12ProcessInputEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre18 = 0, $$sink10 = 0, $$sink10$phi = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$06 = 0, $scevgep = 0, $uglygep = 0, $uglygep17 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($3) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  if ($8) {
   $14 = $3;$16 = $1;
  } else {
   $9 = $5;
   $scevgep = (($7) + -4|0);
   $10 = (0 - ($9))|0;
   $uglygep = (($scevgep) + ($10)|0);
   $uglygep17 = $uglygep;
   $11 = (($uglygep17) + 4)|0;
   $12 = $11 & -4;
   _memset(($5|0),0,($12|0))|0;
   $$pre = HEAP32[$2>>2]|0;
   $$pre18 = HEAP32[$0>>2]|0;
   $14 = $$pre;$16 = $$pre18;
  }
  $13 = (($14) + 12|0);
  $15 = ($13|0)==($16|0);
  if (!($15)) {
   $17 = HEAP32[$6>>2]|0;
   $18 = HEAP32[$3>>2]|0;
   $19 = $17;
   $20 = $18;
   $21 = (($19) - ($20))|0;
   $22 = $21 >> 2;
   $23 = $22 ^ -1;
   $$sink10 = $14;$25 = $13;
   while(1) {
    $27 = (($$sink10) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$25>>2]|0;
    $30 = $28;
    $31 = $29;
    $32 = (($30) - ($31))|0;
    $33 = $32 >> 2;
    $34 = ($33>>>0)<($22>>>0);
    $35 = $34 ? $33 : $22;
    $36 = ($35|0)==(0);
    if (!($36)) {
     $37 = $33 ^ -1;
     $38 = ($37>>>0)>($23>>>0);
     $umax = $38 ? $37 : $23;
     $39 = $umax ^ -1;
     $i$06 = 0;
     while(1) {
      $40 = (($29) + ($i$06<<2)|0);
      $41 = Math_fround(HEAPF32[$40>>2]);
      $42 = (Math_fround(Math_abs((Math_fround($41)))));
      $43 = (($18) + ($i$06<<2)|0);
      $44 = Math_fround(HEAPF32[$43>>2]);
      $45 = (Math_fround(Math_abs((Math_fround($44)))));
      $46 = $42 > $45;
      if ($46) {
       HEAPF32[$43>>2] = $41;
      }
      $47 = (($i$06) + 1)|0;
      $exitcond = ($47|0)==($39|0);
      if ($exitcond) {
       break;
      } else {
       $i$06 = $47;
      }
     }
    }
    $24 = (($25) + 12|0);
    $26 = ($24|0)==($16|0);
    if ($26) {
     break;
    } else {
     $$sink10$phi = $25;$25 = $24;$$sink10 = $$sink10$phi;
    }
   }
  }
 }
 $48 = (($this) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($this) + 28|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($49|0)==($51|0);
 if ($52) {
  STACKTOP = sp;return;
 } else {
  $54 = $49;
 }
 while(1) {
  $53 = HEAP32[$54>>2]|0;
  $55 = HEAP32[$53>>2]|0;
  FUNCTION_TABLE_vi[$55 & 4095]($54);
  $56 = (($54) + 92|0);
  $57 = HEAP32[$50>>2]|0;
  $58 = ($56|0)==($57|0);
  if ($58) {
   break;
  } else {
   $54 = $56;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12InputManager11SetKeyStateEib($this,$key,$state) {
 $this = $this|0;
 $key = $key|0;
 $state = $state|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre11 = 0, $$pre12 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  if ($state) {
   $0 = $key >>> 5;
   $1 = (($this) + 40|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = (($2) + ($0<<2)|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = $key & 31;
   $6 = 1 << $5;
   $7 = $4 & $6;
   $8 = ($7|0)==(0);
   if ($8) {
    $9 = (($this) + 56|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($0<<2)|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = $12 | $6;
    HEAP32[$11>>2] = $13;
   }
   $19 = (($this) + 36|0);
   $28 = $19;$33 = $6;
  } else {
   $$phi$trans$insert = (($this) + 40|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $$pre11 = $key >>> 5;
   $$pre12 = $key & 31;
   $$pre14 = 1 << $$pre12;
   $14 = (($$pre) + ($$pre11<<2)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = $15 & $$pre14;
   $17 = ($16|0)==(0);
   if ($17) {
    $18 = (($this) + 36|0);
    $36 = $18;
   } else {
    $20 = (($this) + 72|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + ($$pre11<<2)|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = $23 | $$pre14;
    HEAP32[$22>>2] = $24;
    $25 = (($this) + 36|0);
    if ($state) {
     $28 = $25;$33 = $$pre14;
     break;
    } else {
     $36 = $25;
    }
   }
   $34 = $$pre14 ^ -1;
   $35 = (($36) + 4|0);
   $37 = HEAP32[$35>>2]|0;
   $38 = (($37) + ($$pre11<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = $39 & $34;
   HEAP32[$38>>2] = $40;
   STACKTOP = sp;return;
  }
 } while(0);
 $26 = $key >>> 5;
 $27 = (($28) + 4|0);
 $29 = HEAP32[$27>>2]|0;
 $30 = (($29) + ($26<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 | $33;
 HEAP32[$30>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN12InputManager17GetTextFieldInputEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12InputManager30GetEatKeyPressOnTextFieldFocusEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 157|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $13 = 1;
  STACKTOP = sp;return ($13|0);
 }
 $3 = (__Z11GetGUIStatev()|0);
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $13 = 0;
  STACKTOP = sp;return ($13|0);
 }
 $7 = (__Z11GetGUIStatev()|0);
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)!=(0|0);
 $13 = $12;
 STACKTOP = sp;return ($13|0);
}
function __ZN12InputManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12InputManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN12InputManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3510,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIiS8_NS_4lessIiEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIiS8_NS_4lessIiEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIiS8_NS_4lessIiEELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$3);
 $4 = (($__nd) + 20|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($__nd) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i7 = 0, $$0$i8 = 0, $$01$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre1$i$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 92)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(46684427);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 92)&-1;
 $15 = ($14>>>0)<(23342213);
 if ($15) {
  $18 = $14 << 1;
  $19 = ($18>>>0)<($8>>>0);
  $20 = $19 ? $8 : $18;
  $21 = (($__v) + 12|0);
  HEAP32[$21>>2] = 0;
  $22 = (($__v) + 16|0);
  HEAP32[$22>>2] = $0;
  $23 = ($20|0)==(0);
  if ($23) {
   $$0$i8 = 0;$26 = 0;$31 = $21;
  } else {
   $$0$i7 = $20;$58 = $21;
   label = 6;
  }
 } else {
  $16 = (($__v) + 12|0);
  HEAP32[$16>>2] = 0;
  $17 = (($__v) + 16|0);
  HEAP32[$17>>2] = $0;
  $$0$i7 = 46684427;$58 = $16;
  label = 6;
 }
 if ((label|0) == 6) {
  $24 = ($$0$i7*92)|0;
  $25 = (__Znwj($24)|0);
  $$0$i8 = $$0$i7;$26 = $25;$31 = $58;
 }
 HEAP32[$__v>>2] = $26;
 $27 = (($26) + (($7*92)|0)|0);
 $28 = (($__v) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = (($__v) + 4|0);
 HEAP32[$29>>2] = $27;
 $30 = (($26) + (($$0$i8*92)|0)|0);
 HEAP32[$31>>2] = $30;
 $32 = ($27|0)==(0|0);
 do {
  if ($32) {
   $$pre1$i = 0;$36 = 0;$38 = $2;$39 = $3;
  } else {
   __THREW__ = 0;
   invoke_vii(2745,($27|0),($__x|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    $$pre3 = HEAP32[$28>>2]|0;
    $$pre4 = HEAP32[$this>>2]|0;
    $$pre5 = HEAP32[$1>>2]|0;
    $$pre1$i$pre = HEAP32[$29>>2]|0;
    $$pre1$i = $$pre1$i$pre;$36 = $$pre3;$38 = $$pre5;$39 = $$pre4;
    break;
   }
   $56 = ___cxa_find_matching_catch()|0;
   $57 = tempRet0;
   $lpad$phi$index = $56;$lpad$phi$index2 = $57;
   __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $35 = (($36) + 92|0);
 HEAP32[$28>>2] = $35;
 $37 = ($38|0)==($39|0);
 if ($37) {
  $48 = $$pre1$i;$49 = $38;$50 = $35;$51 = $38;
  HEAP32[$this>>2] = $48;
  HEAP32[$29>>2] = $49;
  HEAP32[$1>>2] = $50;
  HEAP32[$28>>2] = $51;
  $52 = HEAP32[$10>>2]|0;
  $53 = HEAP32[$31>>2]|0;
  HEAP32[$10>>2] = $53;
  HEAP32[$31>>2] = $52;
  HEAP32[$__v>>2] = $49;
  __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
  STACKTOP = sp;return;
 } else {
  $$01$i$i = $38;$41 = $$pre1$i;
 }
 while(1) {
  $40 = (($41) + -92|0);
  $42 = (($$01$i$i) + -92|0);
  __THREW__ = 0;
  invoke_vii(2745,($40|0),($42|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   label = 15;
   break;
  }
  $45 = HEAP32[$29>>2]|0;
  $46 = (($45) + -92|0);
  HEAP32[$29>>2] = $46;
  $47 = ($42|0)==($39|0);
  if ($47) {
   label = 13;
   break;
  } else {
   $$01$i$i = $42;$41 = $46;
  }
 }
 if ((label|0) == 13) {
  $$pre$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre2 = HEAP32[$28>>2]|0;
  $48 = $46;$49 = $$pre$i;$50 = $$pre2;$51 = $$pre;
  HEAP32[$this>>2] = $48;
  HEAP32[$29>>2] = $49;
  HEAP32[$1>>2] = $50;
  HEAP32[$28>>2] = $51;
  $52 = HEAP32[$10>>2]|0;
  $53 = HEAP32[$31>>2]|0;
  HEAP32[$10>>2] = $53;
  HEAP32[$31>>2] = $52;
  HEAP32[$__v>>2] = $49;
  __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  $lpad$phi$index = $54;$lpad$phi$index2 = $55;
  __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 L1: do {
  if (!($7)) {
   $9 = $6;
   while(1) {
    $8 = (($9) + -92|0);
    HEAP32[$5>>2] = $8;
    HEAP32[$8>>2] = ((612552 + 8|0));
    $10 = (($9) + -64|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = (($9) + -56|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy2|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 5;
      break;
     }
    }
    $20 = (($9) + -76|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if (!($23)) {
     $24 = (($9) + -68|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy2|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 8;
      break;
     }
    }
    $30 = (($9) + -88|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if (!($33)) {
     $36 = (($9) + -80|0);
     $37 = HEAP32[$36>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($37|0),($$byval_copy2|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 12;
      break;
     }
    }
    $34 = HEAP32[$5>>2]|0;
    $35 = ($34|0)==($4|0);
    if ($35) {
     break L1;
    } else {
     $9 = $34;
    }
   }
   if ((label|0) == 5) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 8) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   else if ((label|0) == 12) {
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
  }
 } while(0);
 $42 = HEAP32[$this>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 __ZdlPv($42);
 STACKTOP = sp;return;
}
function __ZN9InputAxisC2ERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i12 = 0, $__p$0$i$i$i$i6 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = sp + 8|0;
 $4 = sp + 12|0;
 HEAP32[$this>>2] = ((612552 + 8|0));
 $5 = (($this) + 4|0);
 $6 = (($0) + 4|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $14 = (($6) + 1|0);
  $15 = $7&255;
  $16 = $15 >>> 1;
  $18 = $16;$29 = $14;
 } else {
  $10 = (($0) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($0) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $18 = $13;$29 = $11;
 }
 $17 = ($18>>>0)>(2147483631);
 if ($17) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $19 = ($18>>>0)<(11);
 if ($19) {
  $20 = $18 << 1;
  $21 = $20&255;
  HEAP8[$5>>0] = $21;
  $22 = (($5) + 1|0);
  $__p$0$i$i$i$i = $22;
 } else {
  $23 = (($18) + 16)|0;
  $24 = $23 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($24,16,$$byval_copy4,0,613072,79)|0);
  $26 = (($this) + 12|0);
  HEAP32[$26>>2] = $25;
  $27 = $24 | 1;
  HEAP32[$5>>2] = $27;
  $28 = (($this) + 8|0);
  HEAP32[$28>>2] = $18;
  $__p$0$i$i$i$i = $25;
 }
 _memcpy(($__p$0$i$i$i$i|0),($29|0),($18|0))|0;
 $30 = (($__p$0$i$i$i$i) + ($18)|0);
 HEAP8[$30>>0] = 0;
 $31 = (($this) + 16|0);
 $32 = (($0) + 16|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $40 = (($32) + 1|0);
  $41 = $33&255;
  $42 = $41 >>> 1;
  $44 = $42;$59 = $40;
 } else {
  $36 = (($0) + 24|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($0) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $44 = $39;$59 = $37;
 }
 $43 = ($44>>>0)>(2147483631);
 do {
  if ($43) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    label = 30;
   } else {
    // unreachable;
   }
  } else {
   $47 = ($44>>>0)<(11);
   if ($47) {
    $48 = $44 << 1;
    $49 = $48&255;
    HEAP8[$31>>0] = $49;
    $50 = (($31) + 1|0);
    $__p$0$i$i$i$i6 = $50;
   } else {
    $51 = (($44) + 16)|0;
    $52 = $51 & -16;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
    $53 = (invoke_iiiiiii(102,($52|0),16,($$byval_copy4|0),0,(613072|0),79)|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 30;
     break;
    }
    $56 = (($this) + 24|0);
    HEAP32[$56>>2] = $53;
    $57 = $52 | 1;
    HEAP32[$31>>2] = $57;
    $58 = (($this) + 20|0);
    HEAP32[$58>>2] = $44;
    $__p$0$i$i$i$i6 = $53;
   }
   _memcpy(($__p$0$i$i$i$i6|0),($59|0),($44|0))|0;
   $60 = (($__p$0$i$i$i$i6) + ($44)|0);
   HEAP8[$60>>0] = 0;
   $61 = (($this) + 28|0);
   $62 = (($0) + 28|0);
   $63 = HEAP8[$62>>0]|0;
   $64 = $63 & 1;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    $70 = (($62) + 1|0);
    $71 = $63&255;
    $72 = $71 >>> 1;
    $74 = $72;$89 = $70;
   } else {
    $66 = (($0) + 36|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($0) + 32|0);
    $69 = HEAP32[$68>>2]|0;
    $74 = $69;$89 = $67;
   }
   $73 = ($74>>>0)>(2147483631);
   if ($73) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if (!($76)) {
     // unreachable;
    }
   } else {
    $77 = ($74>>>0)<(11);
    if ($77) {
     $78 = $74 << 1;
     $79 = $78&255;
     HEAP8[$61>>0] = $79;
     $80 = (($61) + 1|0);
     $__p$0$i$i$i$i12 = $80;
     _memcpy(($__p$0$i$i$i$i12|0),($89|0),($74|0))|0;
     $90 = (($__p$0$i$i$i$i12) + ($74)|0);
     HEAP8[$90>>0] = 0;
     $91 = (($this) + 40|0);
     $92 = (($0) + 40|0);
     dest=$91+0|0; src=$92+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[$91+48>>1]=HEAP16[$92+48>>1]|0;
     STACKTOP = sp;return;
    }
    $81 = (($74) + 16)|0;
    $82 = $81 & -16;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    $83 = (invoke_iiiiiii(102,($82|0),16,($$byval_copy4|0),0,(613072|0),79)|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = (($this) + 36|0);
     HEAP32[$86>>2] = $83;
     $87 = $82 | 1;
     HEAP32[$61>>2] = $87;
     $88 = (($this) + 32|0);
     HEAP32[$88>>2] = $74;
     $__p$0$i$i$i$i12 = $83;
     _memcpy(($__p$0$i$i$i$i12|0),($89|0),($74|0))|0;
     $90 = (($__p$0$i$i$i$i12) + ($74)|0);
     HEAP8[$90>>0] = 0;
     $91 = (($this) + 40|0);
     $92 = (($0) + 40|0);
     dest=$91+0|0; src=$92+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[$91+48>>1]=HEAP16[$92+48>>1]|0;
     STACKTOP = sp;return;
    }
   }
   $95 = ___cxa_find_matching_catch()|0;
   $96 = tempRet0;
   $97 = HEAP8[$31>>0]|0;
   $98 = $97 & 1;
   $99 = ($98<<24>>24)==(0);
   if ($99) {
    $$0 = $96;$$01 = $95;
   } else {
    $100 = (($this) + 24|0);
    $101 = HEAP32[$100>>2]|0;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($101|0),($$byval_copy4|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     $104 = ___cxa_find_matching_catch()|0;
     $105 = tempRet0;
     ___cxa_call_unexpected(($104|0));
     // unreachable;
    } else {
     $$0 = $96;$$01 = $95;
    }
   }
  }
 } while(0);
 if ((label|0) == 30) {
  $93 = ___cxa_find_matching_catch()|0;
  $94 = tempRet0;
  $$0 = $94;$$01 = $93;
 }
 $106 = HEAP8[$5>>0]|0;
 $107 = $106 & 1;
 $108 = ($107<<24>>24)==(0);
 if ($108) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $109 = (($this) + 12|0);
 $110 = HEAP32[$109>>2]|0;
 HEAP32[$3>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($110|0),($$byval_copy4|0));
 $111 = __THREW__; __THREW__ = 0;
 $112 = $111&1;
 if ($112) {
  $113 = ___cxa_find_matching_catch()|0;
  $114 = tempRet0;
  ___cxa_call_unexpected(($113|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorINS0_IfNS_9allocatorIfEEEENS1_IS3_EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i21 = 0, $$0$i22 = 0, $$01$i$i = 0, $$index = 0, $$index3 = 0, $$pre = 0, $$pre$i = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i3 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($13>>>0)<(178956970);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i22 = 0;$22 = 0;
  } else {
   $$0$i21 = $17;
   label = 5;
  }
 } else {
  $$0$i21 = 357913941;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i21*12)|0;
  $20 = (__Znwj($19)|0);
  $$0$i22 = $$0$i21;$22 = $20;
 }
 $21 = (($22) + (($6*12)|0)|0);
 $23 = (($22) + (($$0$i22*12)|0)|0);
 $24 = ($21|0)==(0|0);
 do {
  if ($24) {
   $31 = $1;$32 = $2;
   label = 10;
  } else {
   __THREW__ = 0;
   invoke_vii(2747,($21|0),($__x|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch()|0;
    $28 = tempRet0;
    $$index = $27;$$index3 = $28;
    break;
   } else {
    $$pre19 = HEAP32[$this>>2]|0;
    $$pre20 = HEAP32[$0>>2]|0;
    $31 = $$pre20;$32 = $$pre19;
    label = 10;
    break;
   }
  }
 } while(0);
 L14: do {
  if ((label|0) == 10) {
   $29 = (($22) + (($7*12)|0)|0);
   $30 = ($31|0)==($32|0);
   do {
    if ($30) {
     HEAP32[$this>>2] = $21;
     HEAP32[$0>>2] = $29;
     HEAP32[$9>>2] = $23;
     $52 = $31;
    } else {
     $$01$i$i = $31;$34 = $21;
     while(1) {
      $33 = (($34) + -12|0);
      $35 = (($$01$i$i) + -12|0);
      __THREW__ = 0;
      invoke_vii(2747,($33|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 23;
       break;
      }
      $38 = ($35|0)==($32|0);
      if ($38) {
       label = 14;
       break;
      } else {
       $$01$i$i = $35;$34 = $33;
      }
     }
     if ((label|0) == 14) {
      $$pre$i = HEAP32[$this>>2]|0;
      $$pre = HEAP32[$0>>2]|0;
      HEAP32[$this>>2] = $33;
      HEAP32[$0>>2] = $29;
      HEAP32[$9>>2] = $23;
      $39 = ($$pre|0)==($$pre$i|0);
      if ($39) {
       $52 = $$pre$i;
       break;
      } else {
       $41 = $$pre;
      }
      while(1) {
       $40 = (($41) + -12|0);
       $42 = HEAP32[$40>>2]|0;
       $43 = ($42|0)==(0|0);
       if (!($43)) {
        $45 = (($41) + -8|0);
        $46 = HEAP32[$45>>2]|0;
        $47 = ($46|0)==($42|0);
        if (!($47)) {
         $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i3 = $42;
         $scevgep$i$i$i$i$i$i$i$i$i$i$i$i4 = (($46) + -4|0);
         $48 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i3))|0;
         $uglygep$i$i$i$i$i$i$i$i$i$i$i$i6 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i4) + ($48)|0);
         $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i7 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i6;
         $49 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i7 >>> 2;
         $50 = $49 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i8 = (($46) + ($50<<2)|0);
         HEAP32[$45>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i8;
        }
        __ZdlPv($42);
       }
       $44 = ($40|0)==($$pre$i|0);
       if ($44) {
        $52 = $$pre$i;
        break;
       } else {
        $41 = $40;
       }
      }
     }
     else if ((label|0) == 23) {
      $53 = ___cxa_find_matching_catch()|0;
      $54 = tempRet0;
      $55 = ($29|0)==($34|0);
      if ($55) {
       $$index = $53;$$index3 = $54;
       break L14;
      } else {
       $57 = $29;
      }
      while(1) {
       $56 = (($57) + -12|0);
       $58 = HEAP32[$56>>2]|0;
       $59 = ($58|0)==(0|0);
       if (!($59)) {
        $61 = (($57) + -8|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = ($62|0)==($58|0);
        if (!($63)) {
         $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = $58;
         $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = (($62) + -4|0);
         $64 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i) + ($64)|0);
         $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i;
         $65 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
         $66 = $65 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = (($62) + ($66<<2)|0);
         HEAP32[$61>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i;
        }
        __ZdlPv($58);
       }
       $60 = ($56|0)==($34|0);
       if ($60) {
        $$index = $53;$$index3 = $54;
        break L14;
       } else {
        $57 = $56;
       }
      }
     }
    }
   } while(0);
   $51 = ($52|0)==(0|0);
   if ($51) {
    STACKTOP = sp;return;
   }
   __ZdlPv($52);
   STACKTOP = sp;return;
  }
 } while(0);
 $67 = ($22|0)==(0|0);
 if ($67) {
  ___resumeException($$index|0);
  // unreachable;
 }
 __ZdlPv($22);
 ___resumeException($$index|0);
 // unreachable;
}
function __ZNSt3__16vectorIfNS_9allocatorIfEEEC2ERKS3_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__first3$i = 0;
 var $__new_last2$i$i$i = 0, $scevgep$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep5$i = 0, $uglygep$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, $uglygep4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($__x) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$__x>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3308,0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   // unreachable;
  }
 } else {
  __THREW__ = 0;
  $13 = (invoke_ii(2988,($7|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   HEAP32[$0>>2] = $13;
   HEAP32[$this>>2] = $13;
   $16 = (($13) + ($8<<2)|0);
   HEAP32[$1>>2] = $16;
   $17 = HEAP32[$__x>>2]|0;
   $18 = HEAP32[$2>>2]|0;
   $19 = ($17|0)==($18|0);
   if ($19) {
    STACKTOP = sp;return;
   }
   $__first3$i = $17;
   $scevgep$i = (($18) + -4|0);
   $20 = (0 - ($__first3$i))|0;
   $uglygep$i = (($scevgep$i) + ($20)|0);
   $uglygep4$i = $uglygep$i;
   $21 = $uglygep4$i >>> 2;
   $$01$i = $17;$23 = $13;
   while(1) {
    $22 = ($23|0)==(0|0);
    if (!($22)) {
     $24 = Math_fround(HEAPF32[$$01$i>>2]);
     HEAPF32[$23>>2] = $24;
    }
    $25 = (($23) + 4|0);
    $26 = (($$01$i) + 4|0);
    $27 = ($26|0)==($18|0);
    if ($27) {
     break;
    } else {
     $$01$i = $26;$23 = $25;
    }
   }
   $28 = (($21) + 1)|0;
   $scevgep5$i = (($13) + ($28<<2)|0);
   HEAP32[$0>>2] = $scevgep5$i;
   STACKTOP = sp;return;
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$this>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$0>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i = $31;
  $scevgep$i$i$i = (($33) + -4|0);
  $35 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($35)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $36 = $uglygep3$i$i$i >>> 2;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i = (($33) + ($37<<2)|0);
  HEAP32[$0>>2] = $scevgep4$i$i$i;
 }
 __ZdlPv($31);
 ___resumeException($29|0);
 // unreachable;
}
function __ZN8UnityStraSINSt3__19allocatorIcEEEERS_RKNS1_12basic_stringIcNS1_11char_traitsIcEET_EE($this,$rhs) {
 $this = $this|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$rhs>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = (($rhs) + 1|0);
  $8 = $0&255;
  $9 = $8 >>> 1;
  $18 = $9;$26 = $7;
 } else {
  $3 = (($rhs) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($rhs) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $18 = $6;$26 = $4;
 }
 $10 = HEAP8[$this>>0]|0;
 $11 = $10 & 1;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $17 = 10;$20 = $10;
 } else {
  $13 = HEAP32[$this>>2]|0;
  $14 = $13 & -2;
  $phitmp$i$i = (($14) + -1)|0;
  $15 = $13&255;
  $17 = $phitmp$i$i;$20 = $15;
 }
 $16 = ($17>>>0)<($18>>>0);
 $19 = $20 & 1;
 $21 = ($19<<24>>24)==(0);
 if ($16) {
  if ($21) {
   $36 = $20&255;
   $37 = $36 >>> 1;
   $39 = $37;
  } else {
   $34 = (($this) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $39 = $35;
  }
  $38 = (($18) - ($17))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$17,$38,$39,0,$39,$18,$26);
  STACKTOP = sp;return ($this|0);
 }
 if ($21) {
  $24 = (($this) + 1|0);
  $25 = $24;
 } else {
  $22 = (($this) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $25 = $23;
 }
 _memmove(($25|0),($26|0),($18|0))|0;
 $27 = (($25) + ($18)|0);
 HEAP8[$27>>0] = 0;
 $28 = HEAP8[$this>>0]|0;
 $29 = $28 & 1;
 $30 = ($29<<24>>24)==(0);
 if ($30) {
  $32 = $18 << 1;
  $33 = $32&255;
  HEAP8[$this>>0] = $33;
  STACKTOP = sp;return ($this|0);
 } else {
  $31 = (($this) + 4|0);
  HEAP32[$31>>2] = $18;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZN9InputAxis8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0;
 var $$pre46 = 0, $$pre47 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0);
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $value = 0, $value1 = 0;
 var $value2 = 0, $value3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy7 = sp + 124|0;
 $0 = sp + 120|0;
 $1 = sp + 116|0;
 $2 = sp + 112|0;
 $3 = sp + 108|0;
 $4 = sp + 104|0;
 $5 = sp + 100|0;
 $6 = sp + 96|0;
 $value = sp + 84|0;
 $7 = sp + 60|0;
 $value1 = sp + 48|0;
 $8 = sp + 36|0;
 $value2 = sp + 24|0;
 $9 = sp + 12|0;
 $value3 = sp;
 $10 = sp + 72|0;
 $11 = (($this) + 4|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$11,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $12 = (($this) + 16|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$12,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $13 = (($this) + 28|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$13,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 ;HEAP32[$value+0>>2]=0|0;HEAP32[$value+4>>2]=0|0;HEAP32[$value+8>>2]=0|0;
 $14 = (($this) + 44|0);
 $15 = HEAP32[$14>>2]|0;
 __THREW__ = 0;
 invoke_vii(2748,($7|0),($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if ($17) {
   label = 5;
  } else {
   __THREW__ = 0;
   (invoke_iii(2412,($value|0),($7|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $27 = ___cxa_find_matching_catch()|0;
    $28 = tempRet0;
    $29 = HEAP8[$7>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if ($31) {
     $$0 = $28;$$01 = $27;
     break;
    }
    $32 = (($7) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    __ZdlPv($33);
    $$0 = $28;$$01 = $27;
    break;
   }
   $20 = HEAP8[$7>>0]|0;
   $21 = $20 & 1;
   $22 = ($21<<24>>24)==(0);
   if (!($22)) {
    $23 = (($7) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZdlPv($24);
   }
   __THREW__ = 0;
   invoke_viii(1641,($transfer|0),($value|0),0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_vi(3378,($transfer|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 5;
    } else {
     $38 = HEAP8[$value>>0]|0;
     $39 = $38 & 1;
     $40 = ($39<<24>>24)==(0);
     if (!($40)) {
      $41 = (($value) + 8|0);
      $42 = HEAP32[$41>>2]|0;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_vii(2591,($42|0),($$byval_copy7|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       $45 = ___cxa_find_matching_catch()|0;
       $46 = tempRet0;
       ___cxa_call_unexpected(($45|0));
       // unreachable;
      }
     }
     ;HEAP32[$value1+0>>2]=0|0;HEAP32[$value1+4>>2]=0|0;HEAP32[$value1+8>>2]=0|0;
     $47 = (($this) + 40|0);
     $48 = HEAP32[$47>>2]|0;
     __THREW__ = 0;
     invoke_vii(2748,($8|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     do {
      if ($50) {
       label = 20;
      } else {
       __THREW__ = 0;
       (invoke_iii(2412,($value1|0),($8|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        $69 = ___cxa_find_matching_catch()|0;
        $70 = tempRet0;
        $71 = HEAP8[$8>>0]|0;
        $72 = $71 & 1;
        $73 = ($72<<24>>24)==(0);
        if ($73) {
         $$1 = $70;$$12 = $69;
         break;
        }
        $74 = (($8) + 8|0);
        $75 = HEAP32[$74>>2]|0;
        __ZdlPv($75);
        $$1 = $70;$$12 = $69;
        break;
       }
       $53 = HEAP8[$8>>0]|0;
       $54 = $53 & 1;
       $55 = ($54<<24>>24)==(0);
       if (!($55)) {
        $56 = (($8) + 8|0);
        $57 = HEAP32[$56>>2]|0;
        __ZdlPv($57);
       }
       __THREW__ = 0;
       invoke_viii(1641,($transfer|0),($value1|0),0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        label = 20;
       } else {
        __THREW__ = 0;
        invoke_vi(3378,($transfer|0));
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 20;
        } else {
         $80 = HEAP8[$value1>>0]|0;
         $81 = $80 & 1;
         $82 = ($81<<24>>24)==(0);
         if (!($82)) {
          $83 = (($value1) + 8|0);
          $84 = HEAP32[$83>>2]|0;
          HEAP32[$3>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
          invoke_vii(2591,($84|0),($$byval_copy7|0));
          $85 = __THREW__; __THREW__ = 0;
          $86 = $85&1;
          if ($86) {
           $87 = ___cxa_find_matching_catch()|0;
           $88 = tempRet0;
           ___cxa_call_unexpected(($87|0));
           // unreachable;
          }
         }
         ;HEAP32[$value2+0>>2]=0|0;HEAP32[$value2+4>>2]=0|0;HEAP32[$value2+8>>2]=0|0;
         $89 = (($this) + 52|0);
         $90 = HEAP32[$89>>2]|0;
         __THREW__ = 0;
         invoke_vii(2748,($9|0),($90|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         do {
          if ($92) {
           label = 35;
          } else {
           __THREW__ = 0;
           (invoke_iii(2412,($value2|0),($9|0))|0);
           $93 = __THREW__; __THREW__ = 0;
           $94 = $93&1;
           if ($94) {
            $111 = ___cxa_find_matching_catch()|0;
            $112 = tempRet0;
            $113 = HEAP8[$9>>0]|0;
            $114 = $113 & 1;
            $115 = ($114<<24>>24)==(0);
            if ($115) {
             $$2 = $112;$$23 = $111;
             break;
            }
            $116 = (($9) + 8|0);
            $117 = HEAP32[$116>>2]|0;
            __ZdlPv($117);
            $$2 = $112;$$23 = $111;
            break;
           }
           $95 = HEAP8[$9>>0]|0;
           $96 = $95 & 1;
           $97 = ($96<<24>>24)==(0);
           if (!($97)) {
            $98 = (($9) + 8|0);
            $99 = HEAP32[$98>>2]|0;
            __ZdlPv($99);
           }
           __THREW__ = 0;
           invoke_viii(1641,($transfer|0),($value2|0),0);
           $118 = __THREW__; __THREW__ = 0;
           $119 = $118&1;
           if ($119) {
            label = 35;
           } else {
            __THREW__ = 0;
            invoke_vi(3378,($transfer|0));
            $120 = __THREW__; __THREW__ = 0;
            $121 = $120&1;
            if ($121) {
             label = 35;
            } else {
             $122 = HEAP8[$value2>>0]|0;
             $123 = $122 & 1;
             $124 = ($123<<24>>24)==(0);
             do {
              if (!($124)) {
               $125 = (($value2) + 8|0);
               $126 = HEAP32[$125>>2]|0;
               HEAP32[$1>>2] = 59;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
               invoke_vii(2591,($126|0),($$byval_copy7|0));
               $127 = __THREW__; __THREW__ = 0;
               $128 = $127&1;
               if (!($128)) {
                break;
               }
               $129 = ___cxa_find_matching_catch()|0;
               $130 = tempRet0;
               ___cxa_call_unexpected(($129|0));
               // unreachable;
              }
             } while(0);
             ;HEAP32[$value3+0>>2]=0|0;HEAP32[$value3+4>>2]=0|0;HEAP32[$value3+8>>2]=0|0;
             $131 = (($this) + 48|0);
             $132 = HEAP32[$131>>2]|0;
             __THREW__ = 0;
             invoke_vii(2748,($10|0),($132|0));
             $133 = __THREW__; __THREW__ = 0;
             $134 = $133&1;
             do {
              if ($134) {
               label = 50;
              } else {
               __THREW__ = 0;
               (invoke_iii(2412,($value3|0),($10|0))|0);
               $135 = __THREW__; __THREW__ = 0;
               $136 = $135&1;
               if ($136) {
                $153 = ___cxa_find_matching_catch()|0;
                $154 = tempRet0;
                $155 = HEAP8[$10>>0]|0;
                $156 = $155 & 1;
                $157 = ($156<<24>>24)==(0);
                if ($157) {
                 $$3 = $154;$$34 = $153;
                 break;
                }
                $158 = (($10) + 8|0);
                $159 = HEAP32[$158>>2]|0;
                __ZdlPv($159);
                $$3 = $154;$$34 = $153;
                break;
               }
               $137 = HEAP8[$10>>0]|0;
               $138 = $137 & 1;
               $139 = ($138<<24>>24)==(0);
               if (!($139)) {
                $140 = (($10) + 8|0);
                $141 = HEAP32[$140>>2]|0;
                __ZdlPv($141);
               }
               __THREW__ = 0;
               invoke_viii(1641,($transfer|0),($value3|0),0);
               $160 = __THREW__; __THREW__ = 0;
               $161 = $160&1;
               if ($161) {
                label = 50;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3378,($transfer|0));
               $162 = __THREW__; __THREW__ = 0;
               $163 = $162&1;
               if ($163) {
                label = 50;
                break;
               }
               $164 = HEAP8[$value3>>0]|0;
               $165 = $164 & 1;
               $166 = ($165<<24>>24)==(0);
               do {
                if (!($166)) {
                 $167 = (($value3) + 8|0);
                 $168 = HEAP32[$167>>2]|0;
                 HEAP32[$0>>2] = 59;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
                 invoke_vii(2591,($168|0),($$byval_copy7|0));
                 $169 = __THREW__; __THREW__ = 0;
                 $170 = $169&1;
                 if (!($170)) {
                  break;
                 }
                 $171 = ___cxa_find_matching_catch()|0;
                 $172 = tempRet0;
                 ___cxa_call_unexpected(($171|0));
                 // unreachable;
                }
               } while(0);
               $173 = (($this) + 76|0);
               $174 = (($transfer) + 12|0);
               $175 = HEAP32[$174>>2]|0;
               $176 = (($175) + 4|0);
               $177 = (($transfer) + 20|0);
               $178 = HEAP32[$177>>2]|0;
               $179 = ($176>>>0)<($178>>>0);
               if ($179) {
                $180 = Math_fround(HEAPF32[$173>>2]);
                HEAPF32[$175>>2] = $180;
                HEAP32[$174>>2] = $176;
                $183 = $176;$185 = $178;
               } else {
                __ZN12CachedWriter16UpdateWriteCacheEPKvj($174,$173,4);
                $$pre = HEAP32[$174>>2]|0;
                $$pre38 = HEAP32[$177>>2]|0;
                $183 = $$pre;$185 = $$pre38;
               }
               $181 = (($this) + 80|0);
               $182 = (($183) + 4|0);
               $184 = ($182>>>0)<($185>>>0);
               if ($184) {
                $186 = Math_fround(HEAPF32[$181>>2]);
                HEAPF32[$183>>2] = $186;
                HEAP32[$174>>2] = $182;
                $189 = $182;$191 = $185;
               } else {
                __ZN12CachedWriter16UpdateWriteCacheEPKvj($174,$181,4);
                $$pre39 = HEAP32[$174>>2]|0;
                $$pre40 = HEAP32[$177>>2]|0;
                $189 = $$pre39;$191 = $$pre40;
               }
               $187 = (($this) + 84|0);
               $188 = (($189) + 4|0);
               $190 = ($188>>>0)<($191>>>0);
               if ($190) {
                $192 = Math_fround(HEAPF32[$187>>2]);
                HEAPF32[$189>>2] = $192;
                HEAP32[$174>>2] = $188;
                $195 = $188;$197 = $191;
               } else {
                __ZN12CachedWriter16UpdateWriteCacheEPKvj($174,$187,4);
                $$pre41 = HEAP32[$174>>2]|0;
                $$pre42 = HEAP32[$177>>2]|0;
                $195 = $$pre41;$197 = $$pre42;
               }
               $193 = (($this) + 88|0);
               $194 = (($195) + 1|0);
               $196 = ($194>>>0)<($197>>>0);
               if ($196) {
                $198 = HEAP8[$193>>0]|0;
                HEAP8[$195>>0] = $198;
                $199 = HEAP32[$174>>2]|0;
                $200 = (($199) + 1|0);
                HEAP32[$174>>2] = $200;
                $203 = $200;
               } else {
                __ZN12CachedWriter16UpdateWriteCacheEPKvj($174,$193,1);
                $$pre43 = HEAP32[$174>>2]|0;
                $203 = $$pre43;
               }
               $201 = (($this) + 89|0);
               $202 = (($203) + 1|0);
               $204 = HEAP32[$177>>2]|0;
               $205 = ($202>>>0)<($204>>>0);
               if ($205) {
                $206 = HEAP8[$201>>0]|0;
                HEAP8[$203>>0] = $206;
                $207 = HEAP32[$174>>2]|0;
                $208 = (($207) + 1|0);
                HEAP32[$174>>2] = $208;
               } else {
                __ZN12CachedWriter16UpdateWriteCacheEPKvj($174,$201,1);
               }
               __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
               $209 = (($this) + 60|0);
               $210 = HEAP32[$174>>2]|0;
               $211 = (($210) + 4|0);
               $212 = HEAP32[$177>>2]|0;
               $213 = ($211>>>0)<($212>>>0);
               if ($213) {
                $214 = HEAP32[$209>>2]|0;
                HEAP32[$210>>2] = $214;
                HEAP32[$174>>2] = $211;
                $217 = $211;$219 = $212;
               } else {
                __ZN12CachedWriter16UpdateWriteCacheEPKvj($174,$209,4);
                $$pre44 = HEAP32[$174>>2]|0;
                $$pre45 = HEAP32[$177>>2]|0;
                $217 = $$pre44;$219 = $$pre45;
               }
               $215 = (($this) + 72|0);
               $216 = (($217) + 4|0);
               $218 = ($216>>>0)<($219>>>0);
               if ($218) {
                $220 = HEAP32[$215>>2]|0;
                HEAP32[$217>>2] = $220;
                HEAP32[$174>>2] = $216;
                $223 = $216;$225 = $219;
               } else {
                __ZN12CachedWriter16UpdateWriteCacheEPKvj($174,$215,4);
                $$pre46 = HEAP32[$174>>2]|0;
                $$pre47 = HEAP32[$177>>2]|0;
                $223 = $$pre46;$225 = $$pre47;
               }
               $221 = (($this) + 56|0);
               $222 = (($223) + 4|0);
               $224 = ($222>>>0)<($225>>>0);
               if ($224) {
                $226 = HEAP32[$221>>2]|0;
                HEAP32[$223>>2] = $226;
                HEAP32[$174>>2] = $222;
                STACKTOP = sp;return;
               } else {
                __ZN12CachedWriter16UpdateWriteCacheEPKvj($174,$221,4);
                STACKTOP = sp;return;
               }
              }
             } while(0);
             if ((label|0) == 50) {
              $151 = ___cxa_find_matching_catch()|0;
              $152 = tempRet0;
              $$3 = $152;$$34 = $151;
             }
             $227 = HEAP8[$value3>>0]|0;
             $228 = $227 & 1;
             $229 = ($228<<24>>24)==(0);
             if ($229) {
              $$4 = $$3;$$45 = $$34;
              ___resumeException($$45|0);
              // unreachable;
             }
             $230 = (($value3) + 8|0);
             $231 = HEAP32[$230>>2]|0;
             HEAP32[$6>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
             invoke_vii(2591,($231|0),($$byval_copy7|0));
             $232 = __THREW__; __THREW__ = 0;
             $233 = $232&1;
             if ($233) {
              $234 = ___cxa_find_matching_catch()|0;
              $235 = tempRet0;
              ___cxa_call_unexpected(($234|0));
              // unreachable;
             } else {
              $$4 = $$3;$$45 = $$34;
              ___resumeException($$45|0);
              // unreachable;
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 35) {
          $109 = ___cxa_find_matching_catch()|0;
          $110 = tempRet0;
          $$2 = $110;$$23 = $109;
         }
         $142 = HEAP8[$value2>>0]|0;
         $143 = $142 & 1;
         $144 = ($143<<24>>24)==(0);
         if ($144) {
          $$4 = $$2;$$45 = $$23;
          ___resumeException($$45|0);
          // unreachable;
         }
         $145 = (($value2) + 8|0);
         $146 = HEAP32[$145>>2]|0;
         HEAP32[$0>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($146|0),($$byval_copy7|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          $149 = ___cxa_find_matching_catch()|0;
          $150 = tempRet0;
          ___cxa_call_unexpected(($149|0));
          // unreachable;
         } else {
          $$4 = $$2;$$45 = $$23;
          ___resumeException($$45|0);
          // unreachable;
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 20) {
      $67 = ___cxa_find_matching_catch()|0;
      $68 = tempRet0;
      $$1 = $68;$$12 = $67;
     }
     $100 = HEAP8[$value1>>0]|0;
     $101 = $100 & 1;
     $102 = ($101<<24>>24)==(0);
     if ($102) {
      $$4 = $$1;$$45 = $$12;
      ___resumeException($$45|0);
      // unreachable;
     }
     $103 = (($value1) + 8|0);
     $104 = HEAP32[$103>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($104|0),($$byval_copy7|0));
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      $107 = ___cxa_find_matching_catch()|0;
      $108 = tempRet0;
      ___cxa_call_unexpected(($107|0));
      // unreachable;
     } else {
      $$4 = $$1;$$45 = $$12;
      ___resumeException($$45|0);
      // unreachable;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $$0 = $26;$$01 = $25;
 }
 $58 = HEAP8[$value>>0]|0;
 $59 = $58 & 1;
 $60 = ($59<<24>>24)==(0);
 if ($60) {
  $$4 = $$0;$$45 = $$01;
  ___resumeException($$45|0);
  // unreachable;
 }
 $61 = (($value) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 HEAP32[$4>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
 invoke_vii(2591,($62|0),($$byval_copy7|0));
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $65 = ___cxa_find_matching_catch()|0;
  $66 = tempRet0;
  ___cxa_call_unexpected(($65|0));
  // unreachable;
 } else {
  $$4 = $$0;$$45 = $$01;
  ___resumeException($$45|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI9InputAxisNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI9InputAxisNS0_9allocatorIS2_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN9InputAxis8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 92|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*92)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9InputAxis8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i = 0, $$0$i24 = 0, $$0$i42 = 0, $$0$i60 = 0, $$4 = 0, $$45 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i66 = 0, $$pre$i$i$i71 = 0, $$pre$i$i$i75 = 0, $$pre$i$i$i76 = 0, $$pre$i$i$i78 = 0, $$pre$phi$i$i$i67Z2D = 0, $$pre$phi$i$i$i72Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre80 = 0, $$pre81 = 0, $$pre82 = 0;
 var $$pre83 = 0, $$pre84 = 0, $$pre85 = 0, $$pre86 = 0, $$pre87 = 0, $$pre88 = 0, $$pre89 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i18 = 0, $__p$0$i$i$i$i36 = 0, $__p$0$i$i$i$i54 = 0, $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy7 = sp + 124|0;
 $0 = sp + 120|0;
 $1 = sp + 116|0;
 $2 = sp + 112|0;
 $3 = sp + 108|0;
 $4 = sp + 104|0;
 $5 = sp + 100|0;
 $6 = sp + 96|0;
 $value = sp + 84|0;
 $7 = sp + 60|0;
 $value1 = sp + 48|0;
 $8 = sp + 36|0;
 $value2 = sp + 24|0;
 $9 = sp + 12|0;
 $value3 = sp;
 $10 = sp + 72|0;
 $11 = (($this) + 4|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$11,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $12 = (($this) + 16|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$12,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $13 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$13,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 ;HEAP32[$value+0>>2]=0|0;HEAP32[$value+4>>2]=0|0;HEAP32[$value+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1765,($transfer|0),($value|0),0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 do {
  if (!($15)) {
   __THREW__ = 0;
   invoke_vi(3377,($transfer|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP8[$value>>0]|0;
    $19 = $18 & 1;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     $21 = (($value) + 1|0);
     $22 = $18&255;
     $23 = $22 >>> 1;
     $32 = $23;$44 = $21;
    } else {
     $24 = (($value) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($value) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27>>>0)>(4294967279);
     if ($28) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     } else {
      $32 = $27;$44 = $25;
     }
    }
    $31 = ($32>>>0)<(11);
    if ($31) {
     $33 = $32 << 1;
     $34 = $33&255;
     HEAP8[$7>>0] = $34;
     $35 = (($7) + 1|0);
     $__p$0$i$i$i$i = $35;
    } else {
     $36 = (($32) + 16)|0;
     $37 = $36 & -16;
     __THREW__ = 0;
     $38 = (invoke_ii(2988,($37|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     $41 = (($7) + 8|0);
     HEAP32[$41>>2] = $38;
     $42 = $37 | 1;
     HEAP32[$7>>2] = $42;
     $43 = (($7) + 4|0);
     HEAP32[$43>>2] = $32;
     $__p$0$i$i$i$i = $38;
    }
    _memcpy(($__p$0$i$i$i$i|0),($44|0),($32|0))|0;
    $45 = (($__p$0$i$i$i$i) + ($32)|0);
    HEAP8[$45>>0] = 0;
    $46 = HEAP32[613088>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$46,$7);
    $47 = HEAP32[613088>>2]|0;
    $48 = (($47) + 4|0);
    $49 = HEAP32[$$byval_copy7>>2]|0;
    $50 = ($49|0)==($48|0);
    if ($50) {
     $$0$i = 0;
    } else {
     $51 = (($49) + 28|0);
     $52 = HEAP32[$51>>2]|0;
     $$0$i = $52;
    }
    $53 = (($this) + 44|0);
    HEAP32[$53>>2] = $$0$i;
    $54 = HEAP8[$7>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if (!($56)) {
     $57 = (($7) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     __ZdlPv($58);
    }
    $59 = HEAP8[$value>>0]|0;
    $60 = $59 & 1;
    $61 = ($60<<24>>24)==(0);
    if (!($61)) {
     $62 = (($value) + 8|0);
     $63 = HEAP32[$62>>2]|0;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($63|0),($$byval_copy7|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      $66 = ___cxa_find_matching_catch()|0;
      $67 = tempRet0;
      ___cxa_call_unexpected(($66|0));
      // unreachable;
     }
    }
    ;HEAP32[$value1+0>>2]=0|0;HEAP32[$value1+4>>2]=0|0;HEAP32[$value1+8>>2]=0|0;
    __THREW__ = 0;
    invoke_viii(1765,($transfer|0),($value1|0),0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    do {
     if (!($69)) {
      __THREW__ = 0;
      invoke_vi(3377,($transfer|0));
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if (!($71)) {
       $83 = HEAP8[$value1>>0]|0;
       $84 = $83 & 1;
       $85 = ($84<<24>>24)==(0);
       if ($85) {
        $86 = (($value1) + 1|0);
        $87 = $83&255;
        $88 = $87 >>> 1;
        $109 = $86;$97 = $88;
       } else {
        $89 = (($value1) + 8|0);
        $90 = HEAP32[$89>>2]|0;
        $91 = (($value1) + 4|0);
        $92 = HEAP32[$91>>2]|0;
        $93 = ($92>>>0)>(4294967279);
        if ($93) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         // unreachable;
        } else {
         $109 = $90;$97 = $92;
        }
       }
       $96 = ($97>>>0)<(11);
       if ($96) {
        $98 = $97 << 1;
        $99 = $98&255;
        HEAP8[$8>>0] = $99;
        $100 = (($8) + 1|0);
        $__p$0$i$i$i$i18 = $100;
       } else {
        $101 = (($97) + 16)|0;
        $102 = $101 & -16;
        __THREW__ = 0;
        $103 = (invoke_ii(2988,($102|0))|0);
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if ($105) {
         break;
        }
        $106 = (($8) + 8|0);
        HEAP32[$106>>2] = $103;
        $107 = $102 | 1;
        HEAP32[$8>>2] = $107;
        $108 = (($8) + 4|0);
        HEAP32[$108>>2] = $97;
        $__p$0$i$i$i$i18 = $103;
       }
       _memcpy(($__p$0$i$i$i$i18|0),($109|0),($97|0))|0;
       $110 = (($__p$0$i$i$i$i18) + ($97)|0);
       HEAP8[$110>>0] = 0;
       $111 = HEAP32[613088>>2]|0;
       __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$111,$8);
       $112 = HEAP32[613088>>2]|0;
       $113 = (($112) + 4|0);
       $114 = HEAP32[$$byval_copy7>>2]|0;
       $115 = ($114|0)==($113|0);
       if ($115) {
        $$0$i24 = 0;
       } else {
        $116 = (($114) + 28|0);
        $117 = HEAP32[$116>>2]|0;
        $$0$i24 = $117;
       }
       $118 = (($this) + 40|0);
       HEAP32[$118>>2] = $$0$i24;
       $119 = HEAP8[$8>>0]|0;
       $120 = $119 & 1;
       $121 = ($120<<24>>24)==(0);
       if (!($121)) {
        $122 = (($8) + 8|0);
        $123 = HEAP32[$122>>2]|0;
        __ZdlPv($123);
       }
       $124 = HEAP8[$value1>>0]|0;
       $125 = $124 & 1;
       $126 = ($125<<24>>24)==(0);
       if (!($126)) {
        $127 = (($value1) + 8|0);
        $128 = HEAP32[$127>>2]|0;
        HEAP32[$3>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($128|0),($$byval_copy7|0));
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         $131 = ___cxa_find_matching_catch()|0;
         $132 = tempRet0;
         ___cxa_call_unexpected(($131|0));
         // unreachable;
        }
       }
       ;HEAP32[$value2+0>>2]=0|0;HEAP32[$value2+4>>2]=0|0;HEAP32[$value2+8>>2]=0|0;
       __THREW__ = 0;
       invoke_viii(1765,($transfer|0),($value2|0),0);
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       L49: do {
        if (!($134)) {
         __THREW__ = 0;
         invoke_vi(3377,($transfer|0));
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if (!($136)) {
          $148 = HEAP8[$value2>>0]|0;
          $149 = $148 & 1;
          $150 = ($149<<24>>24)==(0);
          do {
           if ($150) {
            $151 = (($value2) + 1|0);
            $152 = $148&255;
            $153 = $152 >>> 1;
            $162 = $153;$174 = $151;
           } else {
            $154 = (($value2) + 8|0);
            $155 = HEAP32[$154>>2]|0;
            $156 = (($value2) + 4|0);
            $157 = HEAP32[$156>>2]|0;
            $158 = ($157>>>0)>(4294967279);
            if (!($158)) {
             $162 = $157;$174 = $155;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3309,0);
            $159 = __THREW__; __THREW__ = 0;
            $160 = $159&1;
            if ($160) {
             break L49;
            }
            // unreachable;
           }
          } while(0);
          $161 = ($162>>>0)<(11);
          if ($161) {
           $163 = $162 << 1;
           $164 = $163&255;
           HEAP8[$9>>0] = $164;
           $165 = (($9) + 1|0);
           $__p$0$i$i$i$i36 = $165;
          } else {
           $166 = (($162) + 16)|0;
           $167 = $166 & -16;
           __THREW__ = 0;
           $168 = (invoke_ii(2988,($167|0))|0);
           $169 = __THREW__; __THREW__ = 0;
           $170 = $169&1;
           if ($170) {
            break;
           }
           $171 = (($9) + 8|0);
           HEAP32[$171>>2] = $168;
           $172 = $167 | 1;
           HEAP32[$9>>2] = $172;
           $173 = (($9) + 4|0);
           HEAP32[$173>>2] = $162;
           $__p$0$i$i$i$i36 = $168;
          }
          _memcpy(($__p$0$i$i$i$i36|0),($174|0),($162|0))|0;
          $175 = (($__p$0$i$i$i$i36) + ($162)|0);
          HEAP8[$175>>0] = 0;
          $176 = HEAP32[613088>>2]|0;
          __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$176,$9);
          $177 = HEAP32[613088>>2]|0;
          $178 = (($177) + 4|0);
          $179 = HEAP32[$$byval_copy7>>2]|0;
          $180 = ($179|0)==($178|0);
          if ($180) {
           $$0$i42 = 0;
          } else {
           $181 = (($179) + 28|0);
           $182 = HEAP32[$181>>2]|0;
           $$0$i42 = $182;
          }
          $183 = (($this) + 52|0);
          HEAP32[$183>>2] = $$0$i42;
          $184 = HEAP8[$9>>0]|0;
          $185 = $184 & 1;
          $186 = ($185<<24>>24)==(0);
          if (!($186)) {
           $187 = (($9) + 8|0);
           $188 = HEAP32[$187>>2]|0;
           __ZdlPv($188);
          }
          $189 = HEAP8[$value2>>0]|0;
          $190 = $189 & 1;
          $191 = ($190<<24>>24)==(0);
          do {
           if (!($191)) {
            $192 = (($value2) + 8|0);
            $193 = HEAP32[$192>>2]|0;
            HEAP32[$1>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
            invoke_vii(2591,($193|0),($$byval_copy7|0));
            $194 = __THREW__; __THREW__ = 0;
            $195 = $194&1;
            if (!($195)) {
             break;
            }
            $196 = ___cxa_find_matching_catch()|0;
            $197 = tempRet0;
            ___cxa_call_unexpected(($196|0));
            // unreachable;
           }
          } while(0);
          ;HEAP32[$value3+0>>2]=0|0;HEAP32[$value3+4>>2]=0|0;HEAP32[$value3+8>>2]=0|0;
          __THREW__ = 0;
          invoke_viii(1765,($transfer|0),($value3|0),0);
          $198 = __THREW__; __THREW__ = 0;
          $199 = $198&1;
          L73: do {
           if (!($199)) {
            __THREW__ = 0;
            invoke_vi(3377,($transfer|0));
            $200 = __THREW__; __THREW__ = 0;
            $201 = $200&1;
            if ($201) {
             break;
            }
            $213 = HEAP8[$value3>>0]|0;
            $214 = $213 & 1;
            $215 = ($214<<24>>24)==(0);
            do {
             if ($215) {
              $216 = (($value3) + 1|0);
              $217 = $213&255;
              $218 = $217 >>> 1;
              $227 = $218;$239 = $216;
             } else {
              $219 = (($value3) + 8|0);
              $220 = HEAP32[$219>>2]|0;
              $221 = (($value3) + 4|0);
              $222 = HEAP32[$221>>2]|0;
              $223 = ($222>>>0)>(4294967279);
              if (!($223)) {
               $227 = $222;$239 = $220;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3309,0);
              $224 = __THREW__; __THREW__ = 0;
              $225 = $224&1;
              if ($225) {
               break L73;
              }
              // unreachable;
             }
            } while(0);
            $226 = ($227>>>0)<(11);
            if ($226) {
             $228 = $227 << 1;
             $229 = $228&255;
             HEAP8[$10>>0] = $229;
             $230 = (($10) + 1|0);
             $__p$0$i$i$i$i54 = $230;
            } else {
             $231 = (($227) + 16)|0;
             $232 = $231 & -16;
             __THREW__ = 0;
             $233 = (invoke_ii(2988,($232|0))|0);
             $234 = __THREW__; __THREW__ = 0;
             $235 = $234&1;
             if ($235) {
              break;
             }
             $236 = (($10) + 8|0);
             HEAP32[$236>>2] = $233;
             $237 = $232 | 1;
             HEAP32[$10>>2] = $237;
             $238 = (($10) + 4|0);
             HEAP32[$238>>2] = $227;
             $__p$0$i$i$i$i54 = $233;
            }
            _memcpy(($__p$0$i$i$i$i54|0),($239|0),($227|0))|0;
            $240 = (($__p$0$i$i$i$i54) + ($227)|0);
            HEAP8[$240>>0] = 0;
            $241 = HEAP32[613088>>2]|0;
            __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$241,$10);
            $242 = HEAP32[613088>>2]|0;
            $243 = (($242) + 4|0);
            $244 = HEAP32[$$byval_copy7>>2]|0;
            $245 = ($244|0)==($243|0);
            if ($245) {
             $$0$i60 = 0;
            } else {
             $246 = (($244) + 28|0);
             $247 = HEAP32[$246>>2]|0;
             $$0$i60 = $247;
            }
            $248 = (($this) + 48|0);
            HEAP32[$248>>2] = $$0$i60;
            $249 = HEAP8[$10>>0]|0;
            $250 = $249 & 1;
            $251 = ($250<<24>>24)==(0);
            if (!($251)) {
             $252 = (($10) + 8|0);
             $253 = HEAP32[$252>>2]|0;
             __ZdlPv($253);
            }
            $254 = HEAP8[$value3>>0]|0;
            $255 = $254 & 1;
            $256 = ($255<<24>>24)==(0);
            do {
             if (!($256)) {
              $257 = (($value3) + 8|0);
              $258 = HEAP32[$257>>2]|0;
              HEAP32[$0>>2] = 59;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
              invoke_vii(2591,($258|0),($$byval_copy7|0));
              $259 = __THREW__; __THREW__ = 0;
              $260 = $259&1;
              if (!($260)) {
               break;
              }
              $261 = ___cxa_find_matching_catch()|0;
              $262 = tempRet0;
              ___cxa_call_unexpected(($261|0));
              // unreachable;
             }
            } while(0);
            $263 = (($this) + 76|0);
            $264 = (($transfer) + 12|0);
            $265 = HEAP32[$264>>2]|0;
            $266 = (($265) + 4|0);
            $267 = (($transfer) + 20|0);
            $268 = HEAP32[$267>>2]|0;
            $269 = ($266>>>0)>($268>>>0);
            if ($269) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$263,4);
             $$pre$i$i$i = HEAP32[$263>>2]|0;
             $$pre = HEAP32[$264>>2]|0;
             $$pre80 = HEAP32[$267>>2]|0;
             $$pre$phi$i$i$iZ2D = $263;$272 = $$pre$i$i$i;$276 = $$pre;$278 = $$pre80;
            } else {
             $270 = Math_fround(HEAPF32[$265>>2]);
             HEAPF32[$263>>2] = $270;
             HEAP32[$264>>2] = $266;
             $271 = (HEAPF32[tempDoublePtr>>2]=$270,HEAP32[tempDoublePtr>>2]|0);
             $$pre$phi$i$i$iZ2D = $263;$272 = $271;$276 = $266;$278 = $268;
            }
            $273 = (_llvm_bswap_i32(($272|0))|0);
            HEAP32[$$pre$phi$i$i$iZ2D>>2] = $273;
            $274 = (($this) + 80|0);
            $275 = (($276) + 4|0);
            $277 = ($275>>>0)>($278>>>0);
            if ($277) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$274,4);
             $$pre$i$i$i66 = HEAP32[$274>>2]|0;
             $$pre81 = HEAP32[$264>>2]|0;
             $$pre82 = HEAP32[$267>>2]|0;
             $$pre$phi$i$i$i67Z2D = $274;$281 = $$pre$i$i$i66;$285 = $$pre81;$287 = $$pre82;
            } else {
             $279 = Math_fround(HEAPF32[$276>>2]);
             HEAPF32[$274>>2] = $279;
             HEAP32[$264>>2] = $275;
             $280 = (HEAPF32[tempDoublePtr>>2]=$279,HEAP32[tempDoublePtr>>2]|0);
             $$pre$phi$i$i$i67Z2D = $274;$281 = $280;$285 = $275;$287 = $278;
            }
            $282 = (_llvm_bswap_i32(($281|0))|0);
            HEAP32[$$pre$phi$i$i$i67Z2D>>2] = $282;
            $283 = (($this) + 84|0);
            $284 = (($285) + 4|0);
            $286 = ($284>>>0)>($287>>>0);
            if ($286) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$283,4);
             $$pre$i$i$i71 = HEAP32[$283>>2]|0;
             $$pre83 = HEAP32[$264>>2]|0;
             $$pre84 = HEAP32[$267>>2]|0;
             $$pre$phi$i$i$i72Z2D = $283;$290 = $$pre$i$i$i71;$294 = $$pre83;$296 = $$pre84;
            } else {
             $288 = Math_fround(HEAPF32[$285>>2]);
             HEAPF32[$283>>2] = $288;
             HEAP32[$264>>2] = $284;
             $289 = (HEAPF32[tempDoublePtr>>2]=$288,HEAP32[tempDoublePtr>>2]|0);
             $$pre$phi$i$i$i72Z2D = $283;$290 = $289;$294 = $284;$296 = $287;
            }
            $291 = (_llvm_bswap_i32(($290|0))|0);
            HEAP32[$$pre$phi$i$i$i72Z2D>>2] = $291;
            $292 = (($this) + 88|0);
            $293 = (($294) + 1|0);
            $295 = ($293>>>0)>($296>>>0);
            if ($295) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$292,1);
             $$pre85 = HEAP32[$264>>2]|0;
             $302 = $$pre85;
            } else {
             $297 = HEAP8[$294>>0]|0;
             HEAP8[$292>>0] = $297;
             $298 = HEAP32[$264>>2]|0;
             $299 = (($298) + 1|0);
             HEAP32[$264>>2] = $299;
             $302 = $299;
            }
            $300 = (($this) + 89|0);
            $301 = (($302) + 1|0);
            $303 = HEAP32[$267>>2]|0;
            $304 = ($301>>>0)>($303>>>0);
            if ($304) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$300,1);
            } else {
             $305 = HEAP8[$302>>0]|0;
             HEAP8[$300>>0] = $305;
             $306 = HEAP32[$264>>2]|0;
             $307 = (($306) + 1|0);
             HEAP32[$264>>2] = $307;
            }
            __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
            $308 = (($this) + 60|0);
            $309 = HEAP32[$264>>2]|0;
            $310 = (($309) + 4|0);
            $311 = HEAP32[$267>>2]|0;
            $312 = ($310>>>0)>($311>>>0);
            if ($312) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$308,4);
             $$pre$i$i$i75 = HEAP32[$308>>2]|0;
             $$pre86 = HEAP32[$264>>2]|0;
             $$pre87 = HEAP32[$267>>2]|0;
             $314 = $$pre$i$i$i75;$318 = $$pre86;$320 = $$pre87;
            } else {
             $313 = HEAP32[$309>>2]|0;
             HEAP32[$308>>2] = $313;
             HEAP32[$264>>2] = $310;
             $314 = $313;$318 = $310;$320 = $311;
            }
            $315 = (_llvm_bswap_i32(($314|0))|0);
            HEAP32[$308>>2] = $315;
            $316 = (($this) + 72|0);
            $317 = (($318) + 4|0);
            $319 = ($317>>>0)>($320>>>0);
            if ($319) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$316,4);
             $$pre$i$i$i76 = HEAP32[$316>>2]|0;
             $$pre88 = HEAP32[$264>>2]|0;
             $$pre89 = HEAP32[$267>>2]|0;
             $322 = $$pre$i$i$i76;$326 = $$pre88;$328 = $$pre89;
            } else {
             $321 = HEAP32[$318>>2]|0;
             HEAP32[$316>>2] = $321;
             HEAP32[$264>>2] = $317;
             $322 = $321;$326 = $317;$328 = $320;
            }
            $323 = (_llvm_bswap_i32(($322|0))|0);
            HEAP32[$316>>2] = $323;
            $324 = (($this) + 56|0);
            $325 = (($326) + 4|0);
            $327 = ($325>>>0)>($328>>>0);
            if ($327) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$324,4);
             $$pre$i$i$i78 = HEAP32[$324>>2]|0;
             $330 = $$pre$i$i$i78;
             $331 = (_llvm_bswap_i32(($330|0))|0);
             HEAP32[$324>>2] = $331;
             STACKTOP = sp;return;
            } else {
             $329 = HEAP32[$326>>2]|0;
             HEAP32[$324>>2] = $329;
             HEAP32[$264>>2] = $325;
             $330 = $329;
             $331 = (_llvm_bswap_i32(($330|0))|0);
             HEAP32[$324>>2] = $331;
             STACKTOP = sp;return;
            }
           }
          } while(0);
          $332 = ___cxa_find_matching_catch()|0;
          $333 = tempRet0;
          $334 = HEAP8[$value3>>0]|0;
          $335 = $334 & 1;
          $336 = ($335<<24>>24)==(0);
          if ($336) {
           $$4 = $333;$$45 = $332;
           ___resumeException($$45|0);
           // unreachable;
          }
          $337 = (($value3) + 8|0);
          $338 = HEAP32[$337>>2]|0;
          HEAP32[$6>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
          invoke_vii(2591,($338|0),($$byval_copy7|0));
          $339 = __THREW__; __THREW__ = 0;
          $340 = $339&1;
          if ($340) {
           $341 = ___cxa_find_matching_catch()|0;
           $342 = tempRet0;
           ___cxa_call_unexpected(($341|0));
           // unreachable;
          } else {
           $$4 = $333;$$45 = $332;
           ___resumeException($$45|0);
           // unreachable;
          }
         }
        }
       } while(0);
       $202 = ___cxa_find_matching_catch()|0;
       $203 = tempRet0;
       $204 = HEAP8[$value2>>0]|0;
       $205 = $204 & 1;
       $206 = ($205<<24>>24)==(0);
       if ($206) {
        $$4 = $203;$$45 = $202;
        ___resumeException($$45|0);
        // unreachable;
       }
       $207 = (($value2) + 8|0);
       $208 = HEAP32[$207>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($208|0),($$byval_copy7|0));
       $209 = __THREW__; __THREW__ = 0;
       $210 = $209&1;
       if ($210) {
        $211 = ___cxa_find_matching_catch()|0;
        $212 = tempRet0;
        ___cxa_call_unexpected(($211|0));
        // unreachable;
       } else {
        $$4 = $203;$$45 = $202;
        ___resumeException($$45|0);
        // unreachable;
       }
      }
     }
    } while(0);
    $137 = ___cxa_find_matching_catch()|0;
    $138 = tempRet0;
    $139 = HEAP8[$value1>>0]|0;
    $140 = $139 & 1;
    $141 = ($140<<24>>24)==(0);
    if ($141) {
     $$4 = $138;$$45 = $137;
     ___resumeException($$45|0);
     // unreachable;
    }
    $142 = (($value1) + 8|0);
    $143 = HEAP32[$142>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($143|0),($$byval_copy7|0));
    $144 = __THREW__; __THREW__ = 0;
    $145 = $144&1;
    if ($145) {
     $146 = ___cxa_find_matching_catch()|0;
     $147 = tempRet0;
     ___cxa_call_unexpected(($146|0));
     // unreachable;
    } else {
     $$4 = $138;$$45 = $137;
     ___resumeException($$45|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP8[$value>>0]|0;
 $75 = $74 & 1;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  $$4 = $73;$$45 = $72;
  ___resumeException($$45|0);
  // unreachable;
 }
 $77 = (($value) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 HEAP32[$4>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
 invoke_vii(2591,($78|0),($$byval_copy7|0));
 $79 = __THREW__; __THREW__ = 0;
 $80 = $79&1;
 if ($80) {
  $81 = ___cxa_find_matching_catch()|0;
  $82 = tempRet0;
  ___cxa_call_unexpected(($81|0));
  // unreachable;
 } else {
  $$4 = $73;$$45 = $72;
  ___resumeException($$45|0);
  // unreachable;
 }
}
function __Z14resize_trimmedINSt3__16vectorI9InputAxisNS0_9allocatorIS2_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy6 = 0, $$idx = 0, $$pre = 0, $$pre1$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$i$i$index = 0, $lpad$phi$i$i$index2 = 0, $temp = 0, $temp1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp + 36|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $temp1 = sp + 24|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 92)&-1;
 $9 = ($8>>>0)<($sz>>>0);
 if ($9) {
  $10 = (($v) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($6))|0;
  $14 = (($13|0) / 92)&-1;
  $15 = ($14|0)==($sz|0);
  if ($15) {
   __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE6resizeEj($v,$sz);
   STACKTOP = sp;return;
  }
  HEAP32[$temp>>2] = 0;
  $16 = (($temp) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($temp) + 8|0);
  HEAP32[$17>>2] = 0;
  __THREW__ = 0;
  invoke_vii(2749,($temp|0),($sz|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $65 = ___cxa_find_matching_catch()|0;
   $66 = tempRet0;
   __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($temp);
   ___resumeException($65|0);
   // unreachable;
  }
  $20 = HEAP32[$v>>2]|0;
  HEAP32[$0>>2] = $20;
  $21 = HEAP32[$2>>2]|0;
  HEAP32[$1>>2] = $21;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viii(1766,($temp|0),($$byval_copy|0),($$byval_copy6|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   $65 = ___cxa_find_matching_catch()|0;
   $66 = tempRet0;
   __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($temp);
   ___resumeException($65|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_vii(2750,($temp|0),($sz|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $65 = ___cxa_find_matching_catch()|0;
   $66 = tempRet0;
   __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($temp);
   ___resumeException($65|0);
   // unreachable;
  }
  $26 = HEAP32[$temp>>2]|0;
  $27 = HEAP32[$v>>2]|0;
  HEAP32[$temp>>2] = $27;
  HEAP32[$v>>2] = $26;
  $28 = HEAP32[$16>>2]|0;
  $29 = HEAP32[$2>>2]|0;
  HEAP32[$16>>2] = $29;
  HEAP32[$2>>2] = $28;
  $30 = HEAP32[$17>>2]|0;
  $31 = HEAP32[$10>>2]|0;
  HEAP32[$17>>2] = $31;
  HEAP32[$10>>2] = $30;
  __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($temp);
  STACKTOP = sp;return;
 }
 $32 = ($8>>>0)>($sz>>>0);
 if (!($32)) {
  STACKTOP = sp;return;
 }
 $33 = (($4) + (($sz*92)|0)|0);
 HEAP32[$temp1>>2] = 0;
 $34 = (($temp1) + 4|0);
 HEAP32[$34>>2] = 0;
 $35 = (($temp1) + 8|0);
 HEAP32[$35>>2] = 0;
 $$idx = ($sz*92)|0;
 $36 = (($$idx|0) / 92)&-1;
 $37 = ($sz|0)==(0);
 do {
  if ($37) {
   $58 = $4;$59 = 0;$60 = $3;$61 = 0;$64 = 0;
  } else {
   $38 = ($36>>>0)>(46684427);
   if ($38) {
    __THREW__ = 0;
    invoke_vi(3308,0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     // unreachable;
    }
   } else {
    __THREW__ = 0;
    $41 = (invoke_ii(2988,($$idx|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     HEAP32[$34>>2] = $41;
     HEAP32[$temp1>>2] = $41;
     $44 = (($41) + (($36*92)|0)|0);
     HEAP32[$35>>2] = $44;
     $46 = $41;$47 = $4;
     while(1) {
      $45 = ($46|0)==(0|0);
      if ($45) {
       $51 = 0;
      } else {
       __THREW__ = 0;
       invoke_vii(2745,($46|0),($47|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
       $$pre1$i$i$i = HEAP32[$34>>2]|0;
       $51 = $$pre1$i$i$i;
      }
      $50 = (($51) + 92|0);
      HEAP32[$34>>2] = $50;
      $52 = (($47) + 92|0);
      $53 = ($52|0)==($33|0);
      if ($53) {
       label = 22;
       break;
      } else {
       $46 = $50;$47 = $52;
      }
     }
     if ((label|0) == 22) {
      $$pre = HEAP32[$temp1>>2]|0;
      $$pre9 = HEAP32[$v>>2]|0;
      $$pre10 = HEAP32[$2>>2]|0;
      $$pre11 = HEAP32[$35>>2]|0;
      $58 = $$pre9;$59 = $$pre;$60 = $$pre10;$61 = $50;$64 = $$pre11;
      break;
     }
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     $lpad$phi$i$i$index = $54;$lpad$phi$i$i$index2 = $55;
     __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($temp1);
     ___resumeException($lpad$phi$i$i$index|0);
     // unreachable;
    }
   }
   $56 = ___cxa_find_matching_catch()|0;
   $57 = tempRet0;
   $lpad$phi$i$i$index = $56;$lpad$phi$i$i$index2 = $57;
   __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($temp1);
   ___resumeException($lpad$phi$i$i$index|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$temp1>>2] = $58;
 HEAP32[$v>>2] = $59;
 HEAP32[$34>>2] = $60;
 HEAP32[$2>>2] = $61;
 $62 = (($v) + 8|0);
 $63 = HEAP32[$62>>2]|0;
 HEAP32[$35>>2] = $63;
 HEAP32[$62>>2] = $64;
 __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($temp1);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 92)&-1;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 8|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 92)&-1;
 $14 = (($__v) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($__v) + 16|0);
 HEAP32[$15>>2] = $8;
 $16 = ($__n|0)==(0);
 if ($16) {
  $19 = 0;
 } else {
  $17 = ($__n*92)|0;
  $18 = (__Znwj($17)|0);
  $19 = $18;
 }
 HEAP32[$__v>>2] = $19;
 $20 = (($19) + (($13*92)|0)|0);
 $21 = (($__v) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = (($__v) + 4|0);
 HEAP32[$22>>2] = $20;
 $23 = (($19) + (($__n*92)|0)|0);
 HEAP32[$14>>2] = $23;
 $24 = ($10|0)==($2|0);
 do {
  if ($24) {
   $33 = $20;$34 = $2;$35 = $20;$36 = $2;$37 = $23;$38 = $1;
  } else {
   $$01$i$i = $10;$26 = $20;
   while(1) {
    $25 = (($26) + -92|0);
    $27 = (($$01$i$i) + -92|0);
    __THREW__ = 0;
    invoke_vii(2745,($25|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 10;
     break;
    }
    $30 = HEAP32[$22>>2]|0;
    $31 = (($30) + -92|0);
    HEAP32[$22>>2] = $31;
    $32 = ($27|0)==($2|0);
    if ($32) {
     label = 7;
     break;
    } else {
     $$01$i$i = $27;$26 = $31;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$9>>2]|0;
    $$pre1 = HEAP32[$21>>2]|0;
    $$pre2 = HEAP32[$0>>2]|0;
    $$pre3 = HEAP32[$14>>2]|0;
    $33 = $31;$34 = $$pre$i;$35 = $$pre1;$36 = $$pre;$37 = $$pre3;$38 = $$pre2;
    break;
   }
   else if ((label|0) == 10) {
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
    ___resumeException($39|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $33;
 HEAP32[$22>>2] = $34;
 HEAP32[$9>>2] = $35;
 HEAP32[$21>>2] = $36;
 HEAP32[$0>>2] = $37;
 HEAP32[$14>>2] = $38;
 HEAP32[$__v>>2] = $34;
 __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i32 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy2 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0;
 var $uglygep16$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = HEAP32[$__last>>2]|0;
 $5 = $4;
 $6 = $3;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 92)&-1;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 92)&-1;
 $16 = ($8>>>0)>($15>>>0);
 if ($16) {
  __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE10deallocateEv($this);
  $85 = ($8>>>0)>(46684427);
  if ($85) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $86 = HEAP32[$9>>2]|0;
  $87 = HEAP32[$this>>2]|0;
  $88 = $86;
  $89 = $87;
  $90 = (($88) - ($89))|0;
  $91 = (($90|0) / 92)&-1;
  $92 = ($91>>>0)<(23342213);
  if ($92) {
   $93 = $91 << 1;
   $94 = ($93>>>0)<($8>>>0);
   $95 = $94 ? $8 : $93;
   $96 = ($95>>>0)>(46684427);
   if ($96) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i32 = $95;
   }
  } else {
   $$0$i32 = 46684427;
  }
  $97 = ($$0$i32*92)|0;
  $98 = (__Znwj($97)|0);
  $99 = (($this) + 4|0);
  HEAP32[$99>>2] = $98;
  HEAP32[$this>>2] = $98;
  $100 = (($98) + (($$0$i32*92)|0)|0);
  HEAP32[$9>>2] = $100;
  $101 = ($3|0)==($4|0);
  if ($101) {
   STACKTOP = sp;return;
  } else {
   $103 = $98;$104 = $3;
  }
  while(1) {
   $102 = ($103|0)==(0|0);
   if ($102) {
    $106 = 0;
   } else {
    __ZN9InputAxisC2ERKS_($103,$104);
    $$pre1$i = HEAP32[$99>>2]|0;
    $106 = $$pre1$i;
   }
   $105 = (($106) + 92|0);
   HEAP32[$99>>2] = $105;
   $107 = (($104) + 92|0);
   $108 = ($107|0)==($4|0);
   if ($108) {
    break;
   } else {
    $103 = $105;$104 = $107;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18;
 $20 = (($19) - ($13))|0;
 $21 = (($20|0) / 92)&-1;
 $22 = ($8>>>0)>($21>>>0);
 if ($22) {
  $23 = (($3) + (($21*92)|0)|0);
  $25 = $23;$__growing$0$off0 = 1;
 } else {
  $25 = $4;$__growing$0$off0 = 0;
 }
 $24 = ($3|0)==($25|0);
 if ($24) {
  $$0$lcssa$i$i = $11;
 } else {
  $scevgep$i = (($25) + -92|0);
  $26 = (0 - ($6))|0;
  $uglygep$i = (($scevgep$i) + ($26)|0);
  $uglygep16$i = $uglygep$i;
  $27 = (($uglygep16$i>>>0) / 92)&-1;
  $$01$i$i = $11;$30 = $3;
  while(1) {
   $28 = (($$01$i$i) + 4|0);
   $29 = (($30) + 4|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($28,$29)|0);
   $31 = (($$01$i$i) + 16|0);
   $32 = (($30) + 16|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($31,$32)|0);
   $33 = (($$01$i$i) + 28|0);
   $34 = (($30) + 28|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($33,$34)|0);
   $35 = (($$01$i$i) + 40|0);
   $36 = (($30) + 40|0);
   dest=$35+0|0; src=$36+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[$35+48>>1]=HEAP16[$36+48>>1]|0;
   $37 = (($30) + 92|0);
   $38 = (($$01$i$i) + 92|0);
   $39 = ($37|0)==($25|0);
   if ($39) {
    break;
   } else {
    $$01$i$i = $38;$30 = $37;
   }
  }
  $40 = (($27) + 1)|0;
  $scevgep17$i = (($11) + (($40*92)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  $41 = ($25|0)==($4|0);
  if ($41) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$17>>2]|0;
  $43 = $$pre$i12;$44 = $25;
  while(1) {
   $42 = ($43|0)==(0|0);
   if ($42) {
    $46 = 0;
   } else {
    __ZN9InputAxisC2ERKS_($43,$44);
    $$pre1$i14 = HEAP32[$17>>2]|0;
    $46 = $$pre1$i14;
   }
   $45 = (($46) + 92|0);
   HEAP32[$17>>2] = $45;
   $47 = (($44) + 92|0);
   $48 = ($47|0)==($4|0);
   if ($48) {
    break;
   } else {
    $43 = $45;$44 = $47;
   }
  }
  STACKTOP = sp;return;
 }
 $49 = HEAP32[$17>>2]|0;
 $50 = ($49|0)==($$0$lcssa$i$i|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 $52 = $49;
 while(1) {
  $51 = (($52) + -92|0);
  HEAP32[$17>>2] = $51;
  HEAP32[$51>>2] = ((612552 + 8|0));
  $53 = (($52) + -64|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = $54 & 1;
  $56 = ($55<<24>>24)==(0);
  if (!($56)) {
   $57 = (($52) + -56|0);
   $58 = HEAP32[$57>>2]|0;
   HEAP32[$2>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($58|0),($$byval_copy2|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    label = 18;
    break;
   }
  }
  $63 = (($52) + -76|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = $64 & 1;
  $66 = ($65<<24>>24)==(0);
  if (!($66)) {
   $67 = (($52) + -68|0);
   $68 = HEAP32[$67>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($68|0),($$byval_copy2|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 21;
    break;
   }
  }
  $73 = (($52) + -88|0);
  $74 = HEAP8[$73>>0]|0;
  $75 = $74 & 1;
  $76 = ($75<<24>>24)==(0);
  if (!($76)) {
   $79 = (($52) + -80|0);
   $80 = HEAP32[$79>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy2|0));
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 25;
    break;
   }
  }
  $77 = HEAP32[$17>>2]|0;
  $78 = ($77|0)==($$0$lcssa$i$i|0);
  if ($78) {
   label = 35;
   break;
  } else {
   $52 = $77;
  }
 }
 if ((label|0) == 18) {
  $61 = ___cxa_find_matching_catch()|0;
  $62 = tempRet0;
  ___cxa_call_unexpected(($61|0));
  // unreachable;
 }
 else if ((label|0) == 21) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  ___cxa_call_unexpected(($71|0));
  // unreachable;
 }
 else if ((label|0) == 25) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 }
 else if ((label|0) == 35) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE6resizeEj($this,$__sz) {
 $this = $this|0;
 $__sz = $__sz|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 92)&-1;
 $10 = ($9>>>0)<($__sz>>>0);
 if ($10) {
  $11 = (($__sz) - ($9))|0;
  __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE8__appendEj($this,$11);
  STACKTOP = sp;return;
 }
 $12 = ($9>>>0)>($__sz>>>0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($5) + (($__sz*92)|0)|0);
 $14 = ($4|0)==($13|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $16 = $4;
 while(1) {
  $15 = (($16) + -92|0);
  HEAP32[$3>>2] = $15;
  HEAP32[$15>>2] = ((612552 + 8|0));
  $17 = (($16) + -64|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if (!($20)) {
   $21 = (($16) + -56|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$2>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($22|0),($$byval_copy2|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 8;
    break;
   }
  }
  $27 = (($16) + -76|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if (!($30)) {
   $31 = (($16) + -68|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($32|0),($$byval_copy2|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 11;
    break;
   }
  }
  $37 = (($16) + -88|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if (!($40)) {
   $43 = (($16) + -80|0);
   $44 = HEAP32[$43>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($44|0),($$byval_copy2|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    label = 15;
    break;
   }
  }
  $41 = HEAP32[$3>>2]|0;
  $42 = ($41|0)==($13|0);
  if ($42) {
   label = 16;
   break;
  } else {
   $16 = $41;
  }
 }
 if ((label|0) == 8) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  ___cxa_call_unexpected(($25|0));
  // unreachable;
 }
 else if ((label|0) == 11) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 }
 else if ((label|0) == 15) {
  $47 = ___cxa_find_matching_catch()|0;
  $48 = tempRet0;
  ___cxa_call_unexpected(($47|0));
  // unreachable;
 }
 else if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 do {
  if ($7) {
   $42 = $3;
  } else {
   $9 = $6;
   while(1) {
    $8 = (($9) + -92|0);
    HEAP32[$5>>2] = $8;
    HEAP32[$8>>2] = ((612552 + 8|0));
    $10 = (($9) + -64|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = (($9) + -56|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy2|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 6;
      break;
     }
    }
    $20 = (($9) + -76|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if (!($23)) {
     $24 = (($9) + -68|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy2|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 9;
      break;
     }
    }
    $30 = (($9) + -88|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if (!($33)) {
     $36 = (($9) + -80|0);
     $37 = HEAP32[$36>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($37|0),($$byval_copy2|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 13;
      break;
     }
    }
    $34 = HEAP32[$5>>2]|0;
    $35 = ($34|0)==($3|0);
    if ($35) {
     label = 14;
     break;
    } else {
     $9 = $34;
    }
   }
   if ((label|0) == 6) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 9) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
   else if ((label|0) == 14) {
    $$pre = HEAP32[$this>>2]|0;
    $42 = $$pre;
    break;
   }
  }
 } while(0);
 __ZdlPv($42);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i311 = 0, $$0$i312 = 0, $$0$i5 = 0, $$01$i$i = 0, $$pre = 0, $$pre$i2 = 0, $$pre1$i = 0, $$pre1$i6 = 0, $$pre10 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__v = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 92)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    __ZN9InputAxisC2Ev($10);
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 92|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = (($this) + 8|0);
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($5) - ($17))|0;
 $19 = (($18|0) / 92)&-1;
 $20 = (($19) + ($__n))|0;
 $21 = ($20>>>0)>(46684427);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($4) - ($17))|0;
 $23 = (($22|0) / 92)&-1;
 $24 = ($23>>>0)<(23342213);
 if ($24) {
  $27 = $23 << 1;
  $28 = ($27>>>0)<($20>>>0);
  $29 = $28 ? $20 : $27;
  $30 = (($__v) + 12|0);
  HEAP32[$30>>2] = 0;
  $31 = (($__v) + 16|0);
  HEAP32[$31>>2] = $15;
  $32 = ($29|0)==(0);
  if ($32) {
   $$0$i312 = 0;$35 = 0;$40 = $30;
  } else {
   $$0$i311 = $29;$69 = $30;
   label = 10;
  }
 } else {
  $25 = (($__v) + 12|0);
  HEAP32[$25>>2] = 0;
  $26 = (($__v) + 16|0);
  HEAP32[$26>>2] = $15;
  $$0$i311 = 46684427;$69 = $25;
  label = 10;
 }
 if ((label|0) == 10) {
  $33 = ($$0$i311*92)|0;
  $34 = (__Znwj($33)|0);
  $$0$i312 = $$0$i311;$35 = $34;$40 = $69;
 }
 HEAP32[$__v>>2] = $35;
 $36 = (($35) + (($19*92)|0)|0);
 $37 = (($__v) + 8|0);
 HEAP32[$37>>2] = $36;
 $38 = (($__v) + 4|0);
 HEAP32[$38>>2] = $36;
 $39 = (($35) + (($$0$i312*92)|0)|0);
 HEAP32[$40>>2] = $39;
 $$0$i5 = $__n;$$pre1$i6 = $36;
 while(1) {
  $41 = ($$pre1$i6|0)==(0|0);
  if ($41) {
   $45 = 0;
  } else {
   __THREW__ = 0;
   invoke_vi(3511,($$pre1$i6|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    label = 22;
    break;
   } else {
    $45 = $$pre1$i6;
   }
  }
  $44 = (($45) + 92|0);
  HEAP32[$37>>2] = $44;
  $46 = (($$0$i5) + -1)|0;
  $47 = ($46|0)==(0);
  if ($47) {
   break;
  } else {
   $$0$i5 = $46;$$pre1$i6 = $44;
  }
 }
 if ((label|0) == 22) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  $lpad$phi$index = $67;$lpad$phi$index2 = $68;
  __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $48 = HEAP32[$this>>2]|0;
 $49 = HEAP32[$2>>2]|0;
 $50 = ($49|0)==($48|0);
 do {
  if ($50) {
   $59 = $36;$60 = $48;$61 = $44;$62 = $48;$64 = $39;
  } else {
   $$01$i$i = $49;$52 = $36;
   while(1) {
    $51 = (($52) + -92|0);
    $53 = (($$01$i$i) + -92|0);
    __THREW__ = 0;
    invoke_vii(2745,($51|0),($53|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     break;
    }
    $56 = HEAP32[$38>>2]|0;
    $57 = (($56) + -92|0);
    HEAP32[$38>>2] = $57;
    $58 = ($53|0)==($48|0);
    if ($58) {
     label = 18;
     break;
    } else {
     $$01$i$i = $53;$52 = $57;
    }
   }
   if ((label|0) == 18) {
    $$pre$i2 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    $$pre9 = HEAP32[$37>>2]|0;
    $$pre10 = HEAP32[$40>>2]|0;
    $59 = $57;$60 = $$pre$i2;$61 = $$pre9;$62 = $$pre;$64 = $$pre10;
    break;
   }
   $65 = ___cxa_find_matching_catch()|0;
   $66 = tempRet0;
   $lpad$phi$index = $65;$lpad$phi$index2 = $66;
   __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$this>>2] = $59;
 HEAP32[$38>>2] = $60;
 HEAP32[$2>>2] = $61;
 HEAP32[$37>>2] = $62;
 $63 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = $64;
 HEAP32[$40>>2] = $63;
 HEAP32[$__v>>2] = $60;
 __ZNSt3__114__split_bufferI9InputAxisRNS_9allocatorIS1_EEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE10deallocateEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 do {
  if ($7) {
   $42 = $3;
  } else {
   $9 = $6;
   while(1) {
    $8 = (($9) + -92|0);
    HEAP32[$5>>2] = $8;
    HEAP32[$8>>2] = ((612552 + 8|0));
    $10 = (($9) + -64|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = (($9) + -56|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy2|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 6;
      break;
     }
    }
    $20 = (($9) + -76|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if (!($23)) {
     $24 = (($9) + -68|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy2|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 9;
      break;
     }
    }
    $30 = (($9) + -88|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if (!($33)) {
     $36 = (($9) + -80|0);
     $37 = HEAP32[$36>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($37|0),($$byval_copy2|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 13;
      break;
     }
    }
    $34 = HEAP32[$5>>2]|0;
    $35 = ($34|0)==($3|0);
    if ($35) {
     label = 14;
     break;
    } else {
     $9 = $34;
    }
   }
   if ((label|0) == 6) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 9) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    ___cxa_call_unexpected(($40|0));
    // unreachable;
   }
   else if ((label|0) == 14) {
    $$pre = HEAP32[$this>>2]|0;
    $42 = $$pre;
    break;
   }
  }
 } while(0);
 __ZdlPv($42);
 $43 = (($this) + 8|0);
 HEAP32[$43>>2] = 0;
 HEAP32[$5>>2] = 0;
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI9InputAxisNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI9InputAxisNS0_9allocatorIS2_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN9InputAxis8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 92|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*92)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9InputAxis8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i = 0, $$0$i24 = 0, $$0$i42 = 0, $$0$i60 = 0, $$4 = 0, $$45 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre69 = 0, $$pre70 = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $$pre75 = 0, $$pre76 = 0, $$pre77 = 0, $$pre78 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i18 = 0, $__p$0$i$i$i$i36 = 0, $__p$0$i$i$i$i54 = 0, $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy7 = sp + 124|0;
 $0 = sp + 120|0;
 $1 = sp + 116|0;
 $2 = sp + 112|0;
 $3 = sp + 108|0;
 $4 = sp + 104|0;
 $5 = sp + 100|0;
 $6 = sp + 96|0;
 $value = sp + 84|0;
 $7 = sp + 60|0;
 $value1 = sp + 48|0;
 $8 = sp + 36|0;
 $value2 = sp + 24|0;
 $9 = sp + 12|0;
 $value3 = sp;
 $10 = sp + 72|0;
 $11 = (($this) + 4|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$11,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $12 = (($this) + 16|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$12,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $13 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$13,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 ;HEAP32[$value+0>>2]=0|0;HEAP32[$value+4>>2]=0|0;HEAP32[$value+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1767,($transfer|0),($value|0),0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 do {
  if (!($15)) {
   __THREW__ = 0;
   invoke_vi(3376,($transfer|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP8[$value>>0]|0;
    $19 = $18 & 1;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     $21 = (($value) + 1|0);
     $22 = $18&255;
     $23 = $22 >>> 1;
     $32 = $23;$44 = $21;
    } else {
     $24 = (($value) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($value) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27>>>0)>(4294967279);
     if ($28) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     } else {
      $32 = $27;$44 = $25;
     }
    }
    $31 = ($32>>>0)<(11);
    if ($31) {
     $33 = $32 << 1;
     $34 = $33&255;
     HEAP8[$7>>0] = $34;
     $35 = (($7) + 1|0);
     $__p$0$i$i$i$i = $35;
    } else {
     $36 = (($32) + 16)|0;
     $37 = $36 & -16;
     __THREW__ = 0;
     $38 = (invoke_ii(2988,($37|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     $41 = (($7) + 8|0);
     HEAP32[$41>>2] = $38;
     $42 = $37 | 1;
     HEAP32[$7>>2] = $42;
     $43 = (($7) + 4|0);
     HEAP32[$43>>2] = $32;
     $__p$0$i$i$i$i = $38;
    }
    _memcpy(($__p$0$i$i$i$i|0),($44|0),($32|0))|0;
    $45 = (($__p$0$i$i$i$i) + ($32)|0);
    HEAP8[$45>>0] = 0;
    $46 = HEAP32[613088>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$46,$7);
    $47 = HEAP32[613088>>2]|0;
    $48 = (($47) + 4|0);
    $49 = HEAP32[$$byval_copy7>>2]|0;
    $50 = ($49|0)==($48|0);
    if ($50) {
     $$0$i = 0;
    } else {
     $51 = (($49) + 28|0);
     $52 = HEAP32[$51>>2]|0;
     $$0$i = $52;
    }
    $53 = (($this) + 44|0);
    HEAP32[$53>>2] = $$0$i;
    $54 = HEAP8[$7>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if (!($56)) {
     $57 = (($7) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     __ZdlPv($58);
    }
    $59 = HEAP8[$value>>0]|0;
    $60 = $59 & 1;
    $61 = ($60<<24>>24)==(0);
    if (!($61)) {
     $62 = (($value) + 8|0);
     $63 = HEAP32[$62>>2]|0;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($63|0),($$byval_copy7|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      $66 = ___cxa_find_matching_catch()|0;
      $67 = tempRet0;
      ___cxa_call_unexpected(($66|0));
      // unreachable;
     }
    }
    ;HEAP32[$value1+0>>2]=0|0;HEAP32[$value1+4>>2]=0|0;HEAP32[$value1+8>>2]=0|0;
    __THREW__ = 0;
    invoke_viii(1767,($transfer|0),($value1|0),0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    do {
     if (!($69)) {
      __THREW__ = 0;
      invoke_vi(3376,($transfer|0));
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if (!($71)) {
       $83 = HEAP8[$value1>>0]|0;
       $84 = $83 & 1;
       $85 = ($84<<24>>24)==(0);
       if ($85) {
        $86 = (($value1) + 1|0);
        $87 = $83&255;
        $88 = $87 >>> 1;
        $109 = $86;$97 = $88;
       } else {
        $89 = (($value1) + 8|0);
        $90 = HEAP32[$89>>2]|0;
        $91 = (($value1) + 4|0);
        $92 = HEAP32[$91>>2]|0;
        $93 = ($92>>>0)>(4294967279);
        if ($93) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         // unreachable;
        } else {
         $109 = $90;$97 = $92;
        }
       }
       $96 = ($97>>>0)<(11);
       if ($96) {
        $98 = $97 << 1;
        $99 = $98&255;
        HEAP8[$8>>0] = $99;
        $100 = (($8) + 1|0);
        $__p$0$i$i$i$i18 = $100;
       } else {
        $101 = (($97) + 16)|0;
        $102 = $101 & -16;
        __THREW__ = 0;
        $103 = (invoke_ii(2988,($102|0))|0);
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if ($105) {
         break;
        }
        $106 = (($8) + 8|0);
        HEAP32[$106>>2] = $103;
        $107 = $102 | 1;
        HEAP32[$8>>2] = $107;
        $108 = (($8) + 4|0);
        HEAP32[$108>>2] = $97;
        $__p$0$i$i$i$i18 = $103;
       }
       _memcpy(($__p$0$i$i$i$i18|0),($109|0),($97|0))|0;
       $110 = (($__p$0$i$i$i$i18) + ($97)|0);
       HEAP8[$110>>0] = 0;
       $111 = HEAP32[613088>>2]|0;
       __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$111,$8);
       $112 = HEAP32[613088>>2]|0;
       $113 = (($112) + 4|0);
       $114 = HEAP32[$$byval_copy7>>2]|0;
       $115 = ($114|0)==($113|0);
       if ($115) {
        $$0$i24 = 0;
       } else {
        $116 = (($114) + 28|0);
        $117 = HEAP32[$116>>2]|0;
        $$0$i24 = $117;
       }
       $118 = (($this) + 40|0);
       HEAP32[$118>>2] = $$0$i24;
       $119 = HEAP8[$8>>0]|0;
       $120 = $119 & 1;
       $121 = ($120<<24>>24)==(0);
       if (!($121)) {
        $122 = (($8) + 8|0);
        $123 = HEAP32[$122>>2]|0;
        __ZdlPv($123);
       }
       $124 = HEAP8[$value1>>0]|0;
       $125 = $124 & 1;
       $126 = ($125<<24>>24)==(0);
       if (!($126)) {
        $127 = (($value1) + 8|0);
        $128 = HEAP32[$127>>2]|0;
        HEAP32[$3>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($128|0),($$byval_copy7|0));
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         $131 = ___cxa_find_matching_catch()|0;
         $132 = tempRet0;
         ___cxa_call_unexpected(($131|0));
         // unreachable;
        }
       }
       ;HEAP32[$value2+0>>2]=0|0;HEAP32[$value2+4>>2]=0|0;HEAP32[$value2+8>>2]=0|0;
       __THREW__ = 0;
       invoke_viii(1767,($transfer|0),($value2|0),0);
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       L49: do {
        if (!($134)) {
         __THREW__ = 0;
         invoke_vi(3376,($transfer|0));
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if (!($136)) {
          $148 = HEAP8[$value2>>0]|0;
          $149 = $148 & 1;
          $150 = ($149<<24>>24)==(0);
          do {
           if ($150) {
            $151 = (($value2) + 1|0);
            $152 = $148&255;
            $153 = $152 >>> 1;
            $162 = $153;$174 = $151;
           } else {
            $154 = (($value2) + 8|0);
            $155 = HEAP32[$154>>2]|0;
            $156 = (($value2) + 4|0);
            $157 = HEAP32[$156>>2]|0;
            $158 = ($157>>>0)>(4294967279);
            if (!($158)) {
             $162 = $157;$174 = $155;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3309,0);
            $159 = __THREW__; __THREW__ = 0;
            $160 = $159&1;
            if ($160) {
             break L49;
            }
            // unreachable;
           }
          } while(0);
          $161 = ($162>>>0)<(11);
          if ($161) {
           $163 = $162 << 1;
           $164 = $163&255;
           HEAP8[$9>>0] = $164;
           $165 = (($9) + 1|0);
           $__p$0$i$i$i$i36 = $165;
          } else {
           $166 = (($162) + 16)|0;
           $167 = $166 & -16;
           __THREW__ = 0;
           $168 = (invoke_ii(2988,($167|0))|0);
           $169 = __THREW__; __THREW__ = 0;
           $170 = $169&1;
           if ($170) {
            break;
           }
           $171 = (($9) + 8|0);
           HEAP32[$171>>2] = $168;
           $172 = $167 | 1;
           HEAP32[$9>>2] = $172;
           $173 = (($9) + 4|0);
           HEAP32[$173>>2] = $162;
           $__p$0$i$i$i$i36 = $168;
          }
          _memcpy(($__p$0$i$i$i$i36|0),($174|0),($162|0))|0;
          $175 = (($__p$0$i$i$i$i36) + ($162)|0);
          HEAP8[$175>>0] = 0;
          $176 = HEAP32[613088>>2]|0;
          __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$176,$9);
          $177 = HEAP32[613088>>2]|0;
          $178 = (($177) + 4|0);
          $179 = HEAP32[$$byval_copy7>>2]|0;
          $180 = ($179|0)==($178|0);
          if ($180) {
           $$0$i42 = 0;
          } else {
           $181 = (($179) + 28|0);
           $182 = HEAP32[$181>>2]|0;
           $$0$i42 = $182;
          }
          $183 = (($this) + 52|0);
          HEAP32[$183>>2] = $$0$i42;
          $184 = HEAP8[$9>>0]|0;
          $185 = $184 & 1;
          $186 = ($185<<24>>24)==(0);
          if (!($186)) {
           $187 = (($9) + 8|0);
           $188 = HEAP32[$187>>2]|0;
           __ZdlPv($188);
          }
          $189 = HEAP8[$value2>>0]|0;
          $190 = $189 & 1;
          $191 = ($190<<24>>24)==(0);
          do {
           if (!($191)) {
            $192 = (($value2) + 8|0);
            $193 = HEAP32[$192>>2]|0;
            HEAP32[$1>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
            invoke_vii(2591,($193|0),($$byval_copy7|0));
            $194 = __THREW__; __THREW__ = 0;
            $195 = $194&1;
            if (!($195)) {
             break;
            }
            $196 = ___cxa_find_matching_catch()|0;
            $197 = tempRet0;
            ___cxa_call_unexpected(($196|0));
            // unreachable;
           }
          } while(0);
          ;HEAP32[$value3+0>>2]=0|0;HEAP32[$value3+4>>2]=0|0;HEAP32[$value3+8>>2]=0|0;
          __THREW__ = 0;
          invoke_viii(1767,($transfer|0),($value3|0),0);
          $198 = __THREW__; __THREW__ = 0;
          $199 = $198&1;
          L73: do {
           if (!($199)) {
            __THREW__ = 0;
            invoke_vi(3376,($transfer|0));
            $200 = __THREW__; __THREW__ = 0;
            $201 = $200&1;
            if ($201) {
             break;
            }
            $213 = HEAP8[$value3>>0]|0;
            $214 = $213 & 1;
            $215 = ($214<<24>>24)==(0);
            do {
             if ($215) {
              $216 = (($value3) + 1|0);
              $217 = $213&255;
              $218 = $217 >>> 1;
              $227 = $218;$239 = $216;
             } else {
              $219 = (($value3) + 8|0);
              $220 = HEAP32[$219>>2]|0;
              $221 = (($value3) + 4|0);
              $222 = HEAP32[$221>>2]|0;
              $223 = ($222>>>0)>(4294967279);
              if (!($223)) {
               $227 = $222;$239 = $220;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3309,0);
              $224 = __THREW__; __THREW__ = 0;
              $225 = $224&1;
              if ($225) {
               break L73;
              }
              // unreachable;
             }
            } while(0);
            $226 = ($227>>>0)<(11);
            if ($226) {
             $228 = $227 << 1;
             $229 = $228&255;
             HEAP8[$10>>0] = $229;
             $230 = (($10) + 1|0);
             $__p$0$i$i$i$i54 = $230;
            } else {
             $231 = (($227) + 16)|0;
             $232 = $231 & -16;
             __THREW__ = 0;
             $233 = (invoke_ii(2988,($232|0))|0);
             $234 = __THREW__; __THREW__ = 0;
             $235 = $234&1;
             if ($235) {
              break;
             }
             $236 = (($10) + 8|0);
             HEAP32[$236>>2] = $233;
             $237 = $232 | 1;
             HEAP32[$10>>2] = $237;
             $238 = (($10) + 4|0);
             HEAP32[$238>>2] = $227;
             $__p$0$i$i$i$i54 = $233;
            }
            _memcpy(($__p$0$i$i$i$i54|0),($239|0),($227|0))|0;
            $240 = (($__p$0$i$i$i$i54) + ($227)|0);
            HEAP8[$240>>0] = 0;
            $241 = HEAP32[613088>>2]|0;
            __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$241,$10);
            $242 = HEAP32[613088>>2]|0;
            $243 = (($242) + 4|0);
            $244 = HEAP32[$$byval_copy7>>2]|0;
            $245 = ($244|0)==($243|0);
            if ($245) {
             $$0$i60 = 0;
            } else {
             $246 = (($244) + 28|0);
             $247 = HEAP32[$246>>2]|0;
             $$0$i60 = $247;
            }
            $248 = (($this) + 48|0);
            HEAP32[$248>>2] = $$0$i60;
            $249 = HEAP8[$10>>0]|0;
            $250 = $249 & 1;
            $251 = ($250<<24>>24)==(0);
            if (!($251)) {
             $252 = (($10) + 8|0);
             $253 = HEAP32[$252>>2]|0;
             __ZdlPv($253);
            }
            $254 = HEAP8[$value3>>0]|0;
            $255 = $254 & 1;
            $256 = ($255<<24>>24)==(0);
            do {
             if (!($256)) {
              $257 = (($value3) + 8|0);
              $258 = HEAP32[$257>>2]|0;
              HEAP32[$0>>2] = 59;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
              invoke_vii(2591,($258|0),($$byval_copy7|0));
              $259 = __THREW__; __THREW__ = 0;
              $260 = $259&1;
              if (!($260)) {
               break;
              }
              $261 = ___cxa_find_matching_catch()|0;
              $262 = tempRet0;
              ___cxa_call_unexpected(($261|0));
              // unreachable;
             }
            } while(0);
            $263 = (($this) + 76|0);
            $264 = (($transfer) + 12|0);
            $265 = HEAP32[$264>>2]|0;
            $266 = (($265) + 4|0);
            $267 = (($transfer) + 20|0);
            $268 = HEAP32[$267>>2]|0;
            $269 = ($266>>>0)>($268>>>0);
            if ($269) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$263,4);
             $$pre = HEAP32[$264>>2]|0;
             $$pre69 = HEAP32[$267>>2]|0;
             $273 = $$pre;$275 = $$pre69;
            } else {
             $270 = Math_fround(HEAPF32[$265>>2]);
             HEAPF32[$263>>2] = $270;
             HEAP32[$264>>2] = $266;
             $273 = $266;$275 = $268;
            }
            $271 = (($this) + 80|0);
            $272 = (($273) + 4|0);
            $274 = ($272>>>0)>($275>>>0);
            if ($274) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$271,4);
             $$pre70 = HEAP32[$264>>2]|0;
             $$pre71 = HEAP32[$267>>2]|0;
             $279 = $$pre70;$281 = $$pre71;
            } else {
             $276 = Math_fround(HEAPF32[$273>>2]);
             HEAPF32[$271>>2] = $276;
             HEAP32[$264>>2] = $272;
             $279 = $272;$281 = $275;
            }
            $277 = (($this) + 84|0);
            $278 = (($279) + 4|0);
            $280 = ($278>>>0)>($281>>>0);
            if ($280) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$277,4);
             $$pre72 = HEAP32[$264>>2]|0;
             $$pre73 = HEAP32[$267>>2]|0;
             $285 = $$pre72;$287 = $$pre73;
            } else {
             $282 = Math_fround(HEAPF32[$279>>2]);
             HEAPF32[$277>>2] = $282;
             HEAP32[$264>>2] = $278;
             $285 = $278;$287 = $281;
            }
            $283 = (($this) + 88|0);
            $284 = (($285) + 1|0);
            $286 = ($284>>>0)>($287>>>0);
            if ($286) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$283,1);
             $$pre74 = HEAP32[$264>>2]|0;
             $293 = $$pre74;
            } else {
             $288 = HEAP8[$285>>0]|0;
             HEAP8[$283>>0] = $288;
             $289 = HEAP32[$264>>2]|0;
             $290 = (($289) + 1|0);
             HEAP32[$264>>2] = $290;
             $293 = $290;
            }
            $291 = (($this) + 89|0);
            $292 = (($293) + 1|0);
            $294 = HEAP32[$267>>2]|0;
            $295 = ($292>>>0)>($294>>>0);
            if ($295) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$291,1);
            } else {
             $296 = HEAP8[$293>>0]|0;
             HEAP8[$291>>0] = $296;
             $297 = HEAP32[$264>>2]|0;
             $298 = (($297) + 1|0);
             HEAP32[$264>>2] = $298;
            }
            __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
            $299 = (($this) + 60|0);
            $300 = HEAP32[$264>>2]|0;
            $301 = (($300) + 4|0);
            $302 = HEAP32[$267>>2]|0;
            $303 = ($301>>>0)>($302>>>0);
            if ($303) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$299,4);
             $$pre75 = HEAP32[$264>>2]|0;
             $$pre76 = HEAP32[$267>>2]|0;
             $307 = $$pre75;$309 = $$pre76;
            } else {
             $304 = HEAP32[$300>>2]|0;
             HEAP32[$299>>2] = $304;
             HEAP32[$264>>2] = $301;
             $307 = $301;$309 = $302;
            }
            $305 = (($this) + 72|0);
            $306 = (($307) + 4|0);
            $308 = ($306>>>0)>($309>>>0);
            if ($308) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$305,4);
             $$pre77 = HEAP32[$264>>2]|0;
             $$pre78 = HEAP32[$267>>2]|0;
             $313 = $$pre77;$315 = $$pre78;
            } else {
             $310 = HEAP32[$307>>2]|0;
             HEAP32[$305>>2] = $310;
             HEAP32[$264>>2] = $306;
             $313 = $306;$315 = $309;
            }
            $311 = (($this) + 56|0);
            $312 = (($313) + 4|0);
            $314 = ($312>>>0)>($315>>>0);
            if ($314) {
             __ZN12CachedReader15UpdateReadCacheEPvj($264,$311,4);
             STACKTOP = sp;return;
            } else {
             $316 = HEAP32[$313>>2]|0;
             HEAP32[$311>>2] = $316;
             HEAP32[$264>>2] = $312;
             STACKTOP = sp;return;
            }
           }
          } while(0);
          $317 = ___cxa_find_matching_catch()|0;
          $318 = tempRet0;
          $319 = HEAP8[$value3>>0]|0;
          $320 = $319 & 1;
          $321 = ($320<<24>>24)==(0);
          if ($321) {
           $$4 = $318;$$45 = $317;
           ___resumeException($$45|0);
           // unreachable;
          }
          $322 = (($value3) + 8|0);
          $323 = HEAP32[$322>>2]|0;
          HEAP32[$6>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
          invoke_vii(2591,($323|0),($$byval_copy7|0));
          $324 = __THREW__; __THREW__ = 0;
          $325 = $324&1;
          if ($325) {
           $326 = ___cxa_find_matching_catch()|0;
           $327 = tempRet0;
           ___cxa_call_unexpected(($326|0));
           // unreachable;
          } else {
           $$4 = $318;$$45 = $317;
           ___resumeException($$45|0);
           // unreachable;
          }
         }
        }
       } while(0);
       $202 = ___cxa_find_matching_catch()|0;
       $203 = tempRet0;
       $204 = HEAP8[$value2>>0]|0;
       $205 = $204 & 1;
       $206 = ($205<<24>>24)==(0);
       if ($206) {
        $$4 = $203;$$45 = $202;
        ___resumeException($$45|0);
        // unreachable;
       }
       $207 = (($value2) + 8|0);
       $208 = HEAP32[$207>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($208|0),($$byval_copy7|0));
       $209 = __THREW__; __THREW__ = 0;
       $210 = $209&1;
       if ($210) {
        $211 = ___cxa_find_matching_catch()|0;
        $212 = tempRet0;
        ___cxa_call_unexpected(($211|0));
        // unreachable;
       } else {
        $$4 = $203;$$45 = $202;
        ___resumeException($$45|0);
        // unreachable;
       }
      }
     }
    } while(0);
    $137 = ___cxa_find_matching_catch()|0;
    $138 = tempRet0;
    $139 = HEAP8[$value1>>0]|0;
    $140 = $139 & 1;
    $141 = ($140<<24>>24)==(0);
    if ($141) {
     $$4 = $138;$$45 = $137;
     ___resumeException($$45|0);
     // unreachable;
    }
    $142 = (($value1) + 8|0);
    $143 = HEAP32[$142>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($143|0),($$byval_copy7|0));
    $144 = __THREW__; __THREW__ = 0;
    $145 = $144&1;
    if ($145) {
     $146 = ___cxa_find_matching_catch()|0;
     $147 = tempRet0;
     ___cxa_call_unexpected(($146|0));
     // unreachable;
    } else {
     $$4 = $138;$$45 = $137;
     ___resumeException($$45|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP8[$value>>0]|0;
 $75 = $74 & 1;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  $$4 = $73;$$45 = $72;
  ___resumeException($$45|0);
  // unreachable;
 }
 $77 = (($value) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 HEAP32[$4>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
 invoke_vii(2591,($78|0),($$byval_copy7|0));
 $79 = __THREW__; __THREW__ = 0;
 $80 = $79&1;
 if ($80) {
  $81 = ___cxa_find_matching_catch()|0;
  $82 = tempRet0;
  ___cxa_call_unexpected(($81|0));
  // unreachable;
 } else {
  $$4 = $73;$$45 = $72;
  ___resumeException($$45|0);
  // unreachable;
 }
}
function __ZN12InputManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 24|0);
 $1 = HEAP32[580760>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,615696,$1,$converter$i$i,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI9InputAxisNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 __Z10AddGUIAxesRNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEEE($0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI9InputAxisNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 92)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,615912,615912,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI9InputAxisNS0_9allocatorIS2_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,615704,615920,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN9InputAxis8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 92|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,615704,615920,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN9InputAxis8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 92|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN9InputAxis8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i = 0, $$0$i34 = 0, $$0$i55 = 0, $$0$i76 = 0, $$4 = 0, $$45 = 0, $$byval_copy7 = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i82 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i83 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i28 = 0, $__p$0$i$i$i$i49 = 0, $__p$0$i$i$i$i70 = 0, $converter$i$i10 = 0, $converter$i$i18 = 0, $converter$i$i39 = 0, $converter$i$i60 = 0, $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy7 = sp + 140|0;
 $0 = sp + 136|0;
 $1 = sp + 132|0;
 $converter$i$i60 = sp + 128|0;
 $2 = sp + 124|0;
 $3 = sp + 120|0;
 $converter$i$i39 = sp + 116|0;
 $4 = sp + 112|0;
 $5 = sp + 108|0;
 $converter$i$i18 = sp + 104|0;
 $6 = sp + 100|0;
 $converter$i$i10 = sp + 36|0;
 $value = sp;
 $7 = sp + 12|0;
 $value1 = sp + 24|0;
 $8 = sp + 40|0;
 $value2 = sp + 52|0;
 $9 = sp + 64|0;
 $value3 = sp + 76|0;
 $10 = sp + 88|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,3);
 $11 = (($this) + 4|0);
 $12 = HEAP32[580712>>2]|0;
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,615712,$12,$$byval_copy7,0)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$11,0);
  } else {
   $16 = HEAP32[$$byval_copy7>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    (FUNCTION_TABLE_iii[$16 & 4095]($11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $18 = (($this) + 16|0);
 $19 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,615720,$12,$$byval_copy7,0)|0);
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = ($19|0)>(0);
  if ($21) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$18,0);
  } else {
   $22 = HEAP32[$$byval_copy7>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    (FUNCTION_TABLE_iii[$22 & 4095]($18,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $24 = (($this) + 28|0);
 $25 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,615736,$12,$$byval_copy7,0)|0);
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = ($25|0)>(0);
  if ($27) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$24,0);
  } else {
   $28 = HEAP32[$$byval_copy7>>2]|0;
   $29 = ($28|0)==(0|0);
   if (!($29)) {
    (FUNCTION_TABLE_iii[$28 & 4095]($24,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 ;HEAP32[$value+0>>2]=0|0;HEAP32[$value+4>>2]=0|0;HEAP32[$value+8>>2]=0|0;
 __THREW__ = 0;
 $30 = (invoke_iiiiii(192,($transfer|0),(615760|0),($12|0),($converter$i$i10|0),0)|0);
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 do {
  if (!($32)) {
   $33 = ($30|0)==(0);
   if (!($33)) {
    $34 = ($30|0)>(0);
    if ($34) {
     __THREW__ = 0;
     invoke_viii(1652,($transfer|0),($value|0),0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
    } else {
     $37 = HEAP32[$converter$i$i10>>2]|0;
     $38 = ($37|0)==(0|0);
     if (!($38)) {
      __THREW__ = 0;
      (invoke_iii($37|0,($value|0),($transfer|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($transfer|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
   }
   $43 = (($transfer) + 136|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($44<<24>>24)==(0);
   if (!($45)) {
    $46 = HEAP8[$value>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if ($48) {
     $49 = (($value) + 1|0);
     $50 = $46&255;
     $51 = $50 >>> 1;
     $60 = $51;$72 = $49;
    } else {
     $52 = (($value) + 8|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = (($value) + 4|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55>>>0)>(4294967279);
     if ($56) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      // unreachable;
     } else {
      $60 = $55;$72 = $53;
     }
    }
    $59 = ($60>>>0)<(11);
    if ($59) {
     $61 = $60 << 1;
     $62 = $61&255;
     HEAP8[$7>>0] = $62;
     $63 = (($7) + 1|0);
     $__p$0$i$i$i$i = $63;
    } else {
     $64 = (($60) + 16)|0;
     $65 = $64 & -16;
     __THREW__ = 0;
     $66 = (invoke_ii(2988,($65|0))|0);
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     $69 = (($7) + 8|0);
     HEAP32[$69>>2] = $66;
     $70 = $65 | 1;
     HEAP32[$7>>2] = $70;
     $71 = (($7) + 4|0);
     HEAP32[$71>>2] = $60;
     $__p$0$i$i$i$i = $66;
    }
    _memcpy(($__p$0$i$i$i$i|0),($72|0),($60|0))|0;
    $73 = (($__p$0$i$i$i$i) + ($60)|0);
    HEAP8[$73>>0] = 0;
    $74 = HEAP32[613088>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$74,$7);
    $75 = HEAP32[613088>>2]|0;
    $76 = (($75) + 4|0);
    $77 = HEAP32[$$byval_copy7>>2]|0;
    $78 = ($77|0)==($76|0);
    if ($78) {
     $$0$i = 0;
    } else {
     $79 = (($77) + 28|0);
     $80 = HEAP32[$79>>2]|0;
     $$0$i = $80;
    }
    $81 = (($this) + 44|0);
    HEAP32[$81>>2] = $$0$i;
    $82 = HEAP8[$7>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if (!($84)) {
     $85 = (($7) + 8|0);
     $86 = HEAP32[$85>>2]|0;
     __ZdlPv($86);
    }
   }
   $87 = HEAP8[$value>>0]|0;
   $88 = $87 & 1;
   $89 = ($88<<24>>24)==(0);
   if (!($89)) {
    $90 = (($value) + 8|0);
    $91 = HEAP32[$90>>2]|0;
    HEAP32[$6>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_vii(2591,($91|0),($$byval_copy7|0));
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     $94 = ___cxa_find_matching_catch()|0;
     $95 = tempRet0;
     ___cxa_call_unexpected(($94|0));
     // unreachable;
    }
   }
   ;HEAP32[$value1+0>>2]=0|0;HEAP32[$value1+4>>2]=0|0;HEAP32[$value1+8>>2]=0|0;
   __THREW__ = 0;
   $96 = (invoke_iiiiii(192,($transfer|0),(615776|0),($12|0),($converter$i$i18|0),0)|0);
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   do {
    if (!($98)) {
     $99 = ($96|0)==(0);
     if (!($99)) {
      $100 = ($96|0)>(0);
      if ($100) {
       __THREW__ = 0;
       invoke_viii(1652,($transfer|0),($value1|0),0);
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        break;
       }
      } else {
       $103 = HEAP32[$converter$i$i18>>2]|0;
       $104 = ($103|0)==(0|0);
       if (!($104)) {
        __THREW__ = 0;
        (invoke_iii($103|0,($value1|0),($transfer|0))|0);
        $105 = __THREW__; __THREW__ = 0;
        $106 = $105&1;
        if ($106) {
         break;
        }
       }
      }
      __THREW__ = 0;
      invoke_vi(3389,($transfer|0));
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       break;
      }
     }
     $120 = HEAP8[$43>>0]|0;
     $121 = ($120<<24>>24)==(0);
     if (!($121)) {
      $122 = HEAP8[$value1>>0]|0;
      $123 = $122 & 1;
      $124 = ($123<<24>>24)==(0);
      if ($124) {
       $125 = (($value1) + 1|0);
       $126 = $122&255;
       $127 = $126 >>> 1;
       $136 = $127;$148 = $125;
      } else {
       $128 = (($value1) + 8|0);
       $129 = HEAP32[$128>>2]|0;
       $130 = (($value1) + 4|0);
       $131 = HEAP32[$130>>2]|0;
       $132 = ($131>>>0)>(4294967279);
       if ($132) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         break;
        }
        // unreachable;
       } else {
        $136 = $131;$148 = $129;
       }
      }
      $135 = ($136>>>0)<(11);
      if ($135) {
       $137 = $136 << 1;
       $138 = $137&255;
       HEAP8[$8>>0] = $138;
       $139 = (($8) + 1|0);
       $__p$0$i$i$i$i28 = $139;
      } else {
       $140 = (($136) + 16)|0;
       $141 = $140 & -16;
       __THREW__ = 0;
       $142 = (invoke_ii(2988,($141|0))|0);
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        break;
       }
       $145 = (($8) + 8|0);
       HEAP32[$145>>2] = $142;
       $146 = $141 | 1;
       HEAP32[$8>>2] = $146;
       $147 = (($8) + 4|0);
       HEAP32[$147>>2] = $136;
       $__p$0$i$i$i$i28 = $142;
      }
      _memcpy(($__p$0$i$i$i$i28|0),($148|0),($136|0))|0;
      $149 = (($__p$0$i$i$i$i28) + ($136)|0);
      HEAP8[$149>>0] = 0;
      $150 = HEAP32[613088>>2]|0;
      __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$150,$8);
      $151 = HEAP32[613088>>2]|0;
      $152 = (($151) + 4|0);
      $153 = HEAP32[$$byval_copy7>>2]|0;
      $154 = ($153|0)==($152|0);
      if ($154) {
       $$0$i34 = 0;
      } else {
       $155 = (($153) + 28|0);
       $156 = HEAP32[$155>>2]|0;
       $$0$i34 = $156;
      }
      $157 = (($this) + 40|0);
      HEAP32[$157>>2] = $$0$i34;
      $158 = HEAP8[$8>>0]|0;
      $159 = $158 & 1;
      $160 = ($159<<24>>24)==(0);
      if (!($160)) {
       $161 = (($8) + 8|0);
       $162 = HEAP32[$161>>2]|0;
       __ZdlPv($162);
      }
     }
     $163 = HEAP8[$value1>>0]|0;
     $164 = $163 & 1;
     $165 = ($164<<24>>24)==(0);
     if (!($165)) {
      $166 = (($value1) + 8|0);
      $167 = HEAP32[$166>>2]|0;
      HEAP32[$4>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($167|0),($$byval_copy7|0));
      $168 = __THREW__; __THREW__ = 0;
      $169 = $168&1;
      if ($169) {
       $170 = ___cxa_find_matching_catch()|0;
       $171 = tempRet0;
       ___cxa_call_unexpected(($170|0));
       // unreachable;
      }
     }
     ;HEAP32[$value2+0>>2]=0|0;HEAP32[$value2+4>>2]=0|0;HEAP32[$value2+8>>2]=0|0;
     __THREW__ = 0;
     $172 = (invoke_iiiiii(192,($transfer|0),(615792|0),($12|0),($converter$i$i39|0),0)|0);
     $173 = __THREW__; __THREW__ = 0;
     $174 = $173&1;
     L89: do {
      if (!($174)) {
       $175 = ($172|0)==(0);
       if (!($175)) {
        $176 = ($172|0)>(0);
        if ($176) {
         __THREW__ = 0;
         invoke_viii(1652,($transfer|0),($value2|0),0);
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          break;
         }
        } else {
         $179 = HEAP32[$converter$i$i39>>2]|0;
         $180 = ($179|0)==(0|0);
         if (!($180)) {
          __THREW__ = 0;
          (invoke_iii($179|0,($value2|0),($transfer|0))|0);
          $181 = __THREW__; __THREW__ = 0;
          $182 = $181&1;
          if ($182) {
           break;
          }
         }
        }
        __THREW__ = 0;
        invoke_vi(3389,($transfer|0));
        $183 = __THREW__; __THREW__ = 0;
        $184 = $183&1;
        if ($184) {
         break;
        }
       }
       $196 = HEAP8[$43>>0]|0;
       $197 = ($196<<24>>24)==(0);
       do {
        if (!($197)) {
         $198 = HEAP8[$value2>>0]|0;
         $199 = $198 & 1;
         $200 = ($199<<24>>24)==(0);
         do {
          if ($200) {
           $201 = (($value2) + 1|0);
           $202 = $198&255;
           $203 = $202 >>> 1;
           $212 = $203;$224 = $201;
          } else {
           $204 = (($value2) + 8|0);
           $205 = HEAP32[$204>>2]|0;
           $206 = (($value2) + 4|0);
           $207 = HEAP32[$206>>2]|0;
           $208 = ($207>>>0)>(4294967279);
           if (!($208)) {
            $212 = $207;$224 = $205;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3309,0);
           $209 = __THREW__; __THREW__ = 0;
           $210 = $209&1;
           if ($210) {
            break L89;
           }
           // unreachable;
          }
         } while(0);
         $211 = ($212>>>0)<(11);
         if ($211) {
          $213 = $212 << 1;
          $214 = $213&255;
          HEAP8[$9>>0] = $214;
          $215 = (($9) + 1|0);
          $__p$0$i$i$i$i49 = $215;
         } else {
          $216 = (($212) + 16)|0;
          $217 = $216 & -16;
          __THREW__ = 0;
          $218 = (invoke_ii(2988,($217|0))|0);
          $219 = __THREW__; __THREW__ = 0;
          $220 = $219&1;
          if ($220) {
           break L89;
          }
          $221 = (($9) + 8|0);
          HEAP32[$221>>2] = $218;
          $222 = $217 | 1;
          HEAP32[$9>>2] = $222;
          $223 = (($9) + 4|0);
          HEAP32[$223>>2] = $212;
          $__p$0$i$i$i$i49 = $218;
         }
         _memcpy(($__p$0$i$i$i$i49|0),($224|0),($212|0))|0;
         $225 = (($__p$0$i$i$i$i49) + ($212)|0);
         HEAP8[$225>>0] = 0;
         $226 = HEAP32[613088>>2]|0;
         __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$226,$9);
         $227 = HEAP32[613088>>2]|0;
         $228 = (($227) + 4|0);
         $229 = HEAP32[$$byval_copy7>>2]|0;
         $230 = ($229|0)==($228|0);
         if ($230) {
          $$0$i55 = 0;
         } else {
          $231 = (($229) + 28|0);
          $232 = HEAP32[$231>>2]|0;
          $$0$i55 = $232;
         }
         $233 = (($this) + 52|0);
         HEAP32[$233>>2] = $$0$i55;
         $234 = HEAP8[$9>>0]|0;
         $235 = $234 & 1;
         $236 = ($235<<24>>24)==(0);
         if ($236) {
          break;
         }
         $237 = (($9) + 8|0);
         $238 = HEAP32[$237>>2]|0;
         __ZdlPv($238);
        }
       } while(0);
       $239 = HEAP8[$value2>>0]|0;
       $240 = $239 & 1;
       $241 = ($240<<24>>24)==(0);
       if (!($241)) {
        $242 = (($value2) + 8|0);
        $243 = HEAP32[$242>>2]|0;
        HEAP32[$2>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($243|0),($$byval_copy7|0));
        $244 = __THREW__; __THREW__ = 0;
        $245 = $244&1;
        if ($245) {
         $246 = ___cxa_find_matching_catch()|0;
         $247 = tempRet0;
         ___cxa_call_unexpected(($246|0));
         // unreachable;
        }
       }
       ;HEAP32[$value3+0>>2]=0|0;HEAP32[$value3+4>>2]=0|0;HEAP32[$value3+8>>2]=0|0;
       __THREW__ = 0;
       $248 = (invoke_iiiiii(192,($transfer|0),(615816|0),($12|0),($converter$i$i60|0),0)|0);
       $249 = __THREW__; __THREW__ = 0;
       $250 = $249&1;
       L121: do {
        if (!($250)) {
         $251 = ($248|0)==(0);
         if (!($251)) {
          $252 = ($248|0)>(0);
          do {
           if ($252) {
            __THREW__ = 0;
            invoke_viii(1652,($transfer|0),($value3|0),0);
            $253 = __THREW__; __THREW__ = 0;
            $254 = $253&1;
            if ($254) {
             break L121;
            }
           } else {
            $255 = HEAP32[$converter$i$i60>>2]|0;
            $256 = ($255|0)==(0|0);
            if ($256) {
             break;
            }
            __THREW__ = 0;
            (invoke_iii($255|0,($value3|0),($transfer|0))|0);
            $257 = __THREW__; __THREW__ = 0;
            $258 = $257&1;
            if ($258) {
             break L121;
            }
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3389,($transfer|0));
          $259 = __THREW__; __THREW__ = 0;
          $260 = $259&1;
          if ($260) {
           break;
          }
         }
         $272 = HEAP8[$43>>0]|0;
         $273 = ($272<<24>>24)==(0);
         do {
          if (!($273)) {
           $274 = HEAP8[$value3>>0]|0;
           $275 = $274 & 1;
           $276 = ($275<<24>>24)==(0);
           do {
            if ($276) {
             $277 = (($value3) + 1|0);
             $278 = $274&255;
             $279 = $278 >>> 1;
             $288 = $279;$300 = $277;
            } else {
             $280 = (($value3) + 8|0);
             $281 = HEAP32[$280>>2]|0;
             $282 = (($value3) + 4|0);
             $283 = HEAP32[$282>>2]|0;
             $284 = ($283>>>0)>(4294967279);
             if (!($284)) {
              $288 = $283;$300 = $281;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3309,0);
             $285 = __THREW__; __THREW__ = 0;
             $286 = $285&1;
             if ($286) {
              break L121;
             }
             // unreachable;
            }
           } while(0);
           $287 = ($288>>>0)<(11);
           if ($287) {
            $289 = $288 << 1;
            $290 = $289&255;
            HEAP8[$10>>0] = $290;
            $291 = (($10) + 1|0);
            $__p$0$i$i$i$i70 = $291;
           } else {
            $292 = (($288) + 16)|0;
            $293 = $292 & -16;
            __THREW__ = 0;
            $294 = (invoke_ii(2988,($293|0))|0);
            $295 = __THREW__; __THREW__ = 0;
            $296 = $295&1;
            if ($296) {
             break L121;
            }
            $297 = (($10) + 8|0);
            HEAP32[$297>>2] = $294;
            $298 = $293 | 1;
            HEAP32[$10>>2] = $298;
            $299 = (($10) + 4|0);
            HEAP32[$299>>2] = $288;
            $__p$0$i$i$i$i70 = $294;
           }
           _memcpy(($__p$0$i$i$i$i70|0),($300|0),($288|0))|0;
           $301 = (($__p$0$i$i$i$i70) + ($288)|0);
           HEAP8[$301>>0] = 0;
           $302 = HEAP32[613088>>2]|0;
           __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($$byval_copy7,$302,$10);
           $303 = HEAP32[613088>>2]|0;
           $304 = (($303) + 4|0);
           $305 = HEAP32[$$byval_copy7>>2]|0;
           $306 = ($305|0)==($304|0);
           if ($306) {
            $$0$i76 = 0;
           } else {
            $307 = (($305) + 28|0);
            $308 = HEAP32[$307>>2]|0;
            $$0$i76 = $308;
           }
           $309 = (($this) + 48|0);
           HEAP32[$309>>2] = $$0$i76;
           $310 = HEAP8[$10>>0]|0;
           $311 = $310 & 1;
           $312 = ($311<<24>>24)==(0);
           if ($312) {
            break;
           }
           $313 = (($10) + 8|0);
           $314 = HEAP32[$313>>2]|0;
           __ZdlPv($314);
          }
         } while(0);
         $315 = HEAP8[$value3>>0]|0;
         $316 = $315 & 1;
         $317 = ($316<<24>>24)==(0);
         do {
          if (!($317)) {
           $318 = (($value3) + 8|0);
           $319 = HEAP32[$318>>2]|0;
           HEAP32[$0>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($319|0),($$byval_copy7|0));
           $320 = __THREW__; __THREW__ = 0;
           $321 = $320&1;
           if (!($321)) {
            break;
           }
           $322 = ___cxa_find_matching_catch()|0;
           $323 = tempRet0;
           ___cxa_call_unexpected(($322|0));
           // unreachable;
          }
         } while(0);
         $324 = (($this) + 76|0);
         __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$324,615840,0);
         $325 = (($this) + 80|0);
         __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$325,615848,0);
         $326 = (($this) + 84|0);
         __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$326,615856,0);
         $327 = (($this) + 88|0);
         $328 = HEAP32[580544>>2]|0;
         $329 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,615872,$328,$$byval_copy7,0)|0);
         $330 = ($329|0)==(0);
         if (!($330)) {
          $331 = ($329|0)>(0);
          L155: do {
           if ($331) {
            $332 = (($transfer) + 12|0);
            $333 = (($transfer) + 80|0);
            $334 = HEAP32[$333>>2]|0;
            $335 = (($334) + 12|0);
            $336 = HEAP32[$335>>2]|0;
            $337 = (($transfer) + 16|0);
            $338 = HEAP32[$337>>2]|0;
            $339 = (($transfer) + 28|0);
            $340 = HEAP32[$339>>2]|0;
            $341 = (($transfer) + 32|0);
            $342 = HEAP32[$341>>2]|0;
            $343 = Math_imul($342, $340)|0;
            $$sum$i$i$i$i$i = (($336) - ($343))|0;
            $344 = (($338) + ($$sum$i$i$i$i$i)|0);
            HEAP32[$332>>2] = $344;
            $345 = ($$sum$i$i$i$i$i|0)<(0);
            do {
             if (!($345)) {
              $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
              $346 = (($338) + ($$sum1$i$i$i$i$i)|0);
              $347 = (($transfer) + 20|0);
              $348 = HEAP32[$347>>2]|0;
              $349 = ($346>>>0)>($348>>>0);
              if ($349) {
               break;
              }
              $350 = HEAP8[$344>>0]|0;
              HEAP8[$327>>0] = $350;
              $351 = HEAP32[$332>>2]|0;
              $352 = (($351) + 1|0);
              HEAP32[$332>>2] = $352;
              break L155;
             }
            } while(0);
            __ZN12CachedReader15UpdateReadCacheEPvj($332,$327,1);
           } else {
            $353 = HEAP32[$$byval_copy7>>2]|0;
            $354 = ($353|0)==(0|0);
            if ($354) {
             break;
            }
            (FUNCTION_TABLE_iii[$353 & 4095]($327,$transfer)|0);
           }
          } while(0);
          __ZN14SafeBinaryRead11EndTransferEv($transfer);
         }
         $355 = (($this) + 89|0);
         $356 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,615880,$328,$$byval_copy7,0)|0);
         $357 = ($356|0)==(0);
         if ($357) {
          $382 = (($this) + 60|0);
          __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$382,615888,0);
          $383 = (($this) + 72|0);
          __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$383,615896,0);
          $384 = (($this) + 56|0);
          __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$384,615904,0);
          STACKTOP = sp;return;
         }
         $358 = ($356|0)>(0);
         L168: do {
          if ($358) {
           $359 = (($transfer) + 12|0);
           $360 = (($transfer) + 80|0);
           $361 = HEAP32[$360>>2]|0;
           $362 = (($361) + 12|0);
           $363 = HEAP32[$362>>2]|0;
           $364 = (($transfer) + 16|0);
           $365 = HEAP32[$364>>2]|0;
           $366 = (($transfer) + 28|0);
           $367 = HEAP32[$366>>2]|0;
           $368 = (($transfer) + 32|0);
           $369 = HEAP32[$368>>2]|0;
           $370 = Math_imul($369, $367)|0;
           $$sum$i$i$i$i$i82 = (($363) - ($370))|0;
           $371 = (($365) + ($$sum$i$i$i$i$i82)|0);
           HEAP32[$359>>2] = $371;
           $372 = ($$sum$i$i$i$i$i82|0)<(0);
           do {
            if (!($372)) {
             $$sum1$i$i$i$i$i83 = (($$sum$i$i$i$i$i82) + 1)|0;
             $373 = (($365) + ($$sum1$i$i$i$i$i83)|0);
             $374 = (($transfer) + 20|0);
             $375 = HEAP32[$374>>2]|0;
             $376 = ($373>>>0)>($375>>>0);
             if ($376) {
              break;
             }
             $377 = HEAP8[$371>>0]|0;
             HEAP8[$355>>0] = $377;
             $378 = HEAP32[$359>>2]|0;
             $379 = (($378) + 1|0);
             HEAP32[$359>>2] = $379;
             break L168;
            }
           } while(0);
           __ZN12CachedReader15UpdateReadCacheEPvj($359,$355,1);
          } else {
           $380 = HEAP32[$$byval_copy7>>2]|0;
           $381 = ($380|0)==(0|0);
           if ($381) {
            break;
           }
           (FUNCTION_TABLE_iii[$380 & 4095]($355,$transfer)|0);
          }
         } while(0);
         __ZN14SafeBinaryRead11EndTransferEv($transfer);
         $382 = (($this) + 60|0);
         __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$382,615888,0);
         $383 = (($this) + 72|0);
         __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$383,615896,0);
         $384 = (($this) + 56|0);
         __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$384,615904,0);
         STACKTOP = sp;return;
        }
       } while(0);
       $385 = ___cxa_find_matching_catch()|0;
       $386 = tempRet0;
       $387 = HEAP8[$value3>>0]|0;
       $388 = $387 & 1;
       $389 = ($388<<24>>24)==(0);
       if ($389) {
        $$4 = $386;$$45 = $385;
        ___resumeException($$45|0);
        // unreachable;
       }
       $390 = (($value3) + 8|0);
       $391 = HEAP32[$390>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($391|0),($$byval_copy7|0));
       $392 = __THREW__; __THREW__ = 0;
       $393 = $392&1;
       if ($393) {
        $394 = ___cxa_find_matching_catch()|0;
        $395 = tempRet0;
        ___cxa_call_unexpected(($394|0));
        // unreachable;
       } else {
        $$4 = $386;$$45 = $385;
        ___resumeException($$45|0);
        // unreachable;
       }
      }
     } while(0);
     $261 = ___cxa_find_matching_catch()|0;
     $262 = tempRet0;
     $263 = HEAP8[$value2>>0]|0;
     $264 = $263 & 1;
     $265 = ($264<<24>>24)==(0);
     if ($265) {
      $$4 = $262;$$45 = $261;
      ___resumeException($$45|0);
      // unreachable;
     }
     $266 = (($value2) + 8|0);
     $267 = HEAP32[$266>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($267|0),($$byval_copy7|0));
     $268 = __THREW__; __THREW__ = 0;
     $269 = $268&1;
     if ($269) {
      $270 = ___cxa_find_matching_catch()|0;
      $271 = tempRet0;
      ___cxa_call_unexpected(($270|0));
      // unreachable;
     } else {
      $$4 = $262;$$45 = $261;
      ___resumeException($$45|0);
      // unreachable;
     }
    }
   } while(0);
   $185 = ___cxa_find_matching_catch()|0;
   $186 = tempRet0;
   $187 = HEAP8[$value1>>0]|0;
   $188 = $187 & 1;
   $189 = ($188<<24>>24)==(0);
   if ($189) {
    $$4 = $186;$$45 = $185;
    ___resumeException($$45|0);
    // unreachable;
   }
   $190 = (($value1) + 8|0);
   $191 = HEAP32[$190>>2]|0;
   HEAP32[$3>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($191|0),($$byval_copy7|0));
   $192 = __THREW__; __THREW__ = 0;
   $193 = $192&1;
   if ($193) {
    $194 = ___cxa_find_matching_catch()|0;
    $195 = tempRet0;
    ___cxa_call_unexpected(($194|0));
    // unreachable;
   } else {
    $$4 = $186;$$45 = $185;
    ___resumeException($$45|0);
    // unreachable;
   }
  }
 } while(0);
 $109 = ___cxa_find_matching_catch()|0;
 $110 = tempRet0;
 $111 = HEAP8[$value>>0]|0;
 $112 = $111 & 1;
 $113 = ($112<<24>>24)==(0);
 if ($113) {
  $$4 = $110;$$45 = $109;
  ___resumeException($$45|0);
  // unreachable;
 }
 $114 = (($value) + 8|0);
 $115 = HEAP32[$114>>2]|0;
 HEAP32[$5>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
 invoke_vii(2591,($115|0),($$byval_copy7|0));
 $116 = __THREW__; __THREW__ = 0;
 $117 = $116&1;
 if ($117) {
  $118 = ___cxa_find_matching_catch()|0;
  $119 = tempRet0;
  ___cxa_call_unexpected(($118|0));
  // unreachable;
 } else {
  $$4 = $110;$$45 = $109;
  ___resumeException($$45|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorI9InputAxisNS1_9allocatorIS3_EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $size$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy5 = sp + 108|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $size$i$i$i = sp + 12|0;
 $p$i$i = sp + 16|0;
 $3 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$3,$data,$metaFlag);
 __ZN9InputAxisC2Ev($p$i$i);
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(615912|0),(615912|0),($size$i$i$i|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(615704|0),(615920|0),($p$i$i|0),0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vii(2751,($p$i$i|0),($this|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(3390,($this|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3391,($this|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      HEAP32[$p$i$i>>2] = ((612552 + 8|0));
      $46 = (($p$i$i) + 28|0);
      $47 = HEAP8[$46>>0]|0;
      $48 = $47 & 1;
      $49 = ($48<<24>>24)==(0);
      if (!($49)) {
       $50 = (($p$i$i) + 36|0);
       $51 = HEAP32[$50>>2]|0;
       HEAP32[$2>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
       invoke_vii(2591,($51|0),($$byval_copy5|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        $54 = ___cxa_find_matching_catch()|0;
        $55 = tempRet0;
        ___cxa_call_unexpected(($54|0));
        // unreachable;
       }
      }
      $56 = (($p$i$i) + 16|0);
      $57 = HEAP8[$56>>0]|0;
      $58 = $57 & 1;
      $59 = ($58<<24>>24)==(0);
      if (!($59)) {
       $60 = (($p$i$i) + 24|0);
       $61 = HEAP32[$60>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($61|0),($$byval_copy5|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        $64 = ___cxa_find_matching_catch()|0;
        $65 = tempRet0;
        ___cxa_call_unexpected(($64|0));
        // unreachable;
       }
      }
      $66 = (($p$i$i) + 4|0);
      $67 = HEAP8[$66>>0]|0;
      $68 = $67 & 1;
      $69 = ($68<<24>>24)==(0);
      if ($69) {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
      $70 = (($p$i$i) + 12|0);
      $71 = HEAP32[$70>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($71|0),($$byval_copy5|0));
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       $74 = ___cxa_find_matching_catch()|0;
       $75 = tempRet0;
       ___cxa_call_unexpected(($74|0));
       // unreachable;
      } else {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 HEAP32[$p$i$i>>2] = ((612552 + 8|0));
 $16 = (($p$i$i) + 28|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if (!($19)) {
  $20 = (($p$i$i) + 36|0);
  $21 = HEAP32[$20>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($21|0),($$byval_copy5|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   ___cxa_call_unexpected(($24|0));
   // unreachable;
  }
 }
 $26 = (($p$i$i) + 16|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27 & 1;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  $30 = (($p$i$i) + 24|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($31|0),($$byval_copy5|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $34 = ___cxa_find_matching_catch()|0;
   $35 = tempRet0;
   ___cxa_call_unexpected(($34|0));
   // unreachable;
  }
 }
 $36 = (($p$i$i) + 4|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37 & 1;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  ___resumeException($14|0);
  // unreachable;
 }
 $40 = (($p$i$i) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy5|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZN9InputAxis8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$4 = 0, $$45 = 0, $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $p$i$i$i11 = 0, $p$i$i$i21 = 0, $p$i$i$i34 = 0, $p$i$i$i47 = 0, $size$i$i$i$i10 = 0, $size$i$i$i$i20 = 0, $size$i$i$i$i33 = 0, $size$i$i$i$i46 = 0, $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy7 = sp + 92|0;
 $0 = sp + 72|0;
 $size$i$i$i$i46 = sp + 88|0;
 $p$i$i$i47 = sp + 96|0;
 $1 = sp + 84|0;
 $2 = sp + 80|0;
 $size$i$i$i$i33 = sp + 76|0;
 $p$i$i$i34 = sp + 99|0;
 $3 = sp;
 $4 = sp + 12|0;
 $size$i$i$i$i20 = sp + 4|0;
 $p$i$i$i21 = sp + 98|0;
 $5 = sp + 8|0;
 $6 = sp + 16|0;
 $size$i$i$i$i10 = sp + 20|0;
 $p$i$i$i11 = sp + 97|0;
 $value = sp + 24|0;
 $value1 = sp + 36|0;
 $value2 = sp + 48|0;
 $value3 = sp + 60|0;
 __ZN13ProxyTransfer10SetVersionEi($transfer,3);
 $7 = (($this) + 4|0);
 $8 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615712,$8,$7,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,615912,615912,$$byval_copy7,1);
 $9 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615704,$9,$0,0);
 $10 = (($transfer) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($transfer) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($12) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615720,$8,$16,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,615912,615912,$$byval_copy7,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615704,$9,$0,0);
 $17 = HEAP32[$10>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$13>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $21 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615736,$8,$21,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,615912,615912,$$byval_copy7,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615704,$9,$0,0);
 $22 = HEAP32[$10>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$13>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 ;HEAP32[$value+0>>2]=0|0;HEAP32[$value+4>>2]=0|0;HEAP32[$value+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiii(86,($transfer|0),(615760|0),($8|0),($value|0),2048);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if (!($27)) {
  __THREW__ = 0;
  invoke_viiiii(87,($transfer|0),(615912|0),(615912|0),($size$i$i$i$i10|0),1);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   __THREW__ = 0;
   invoke_viiiii(86,($transfer|0),(615704|0),($9|0),($p$i$i$i11|0),0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    $32 = HEAP32[$10>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$13>>2]|0;
    $35 = ((($33) + (($34*24)|0)|0) + 12|0);
    HEAP32[$35>>2] = 1;
    __THREW__ = 0;
    invoke_vi(3390,($transfer|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     invoke_vi(3391,($transfer|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      __THREW__ = 0;
      invoke_vi(3392,($transfer|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       __THREW__ = 0;
       invoke_vi(3390,($transfer|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if (!($43)) {
        $55 = HEAP8[$value>>0]|0;
        $56 = $55 & 1;
        $57 = ($56<<24>>24)==(0);
        if (!($57)) {
         $58 = (($value) + 8|0);
         $59 = HEAP32[$58>>2]|0;
         HEAP32[$5>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
         invoke_vii(2591,($59|0),($$byval_copy7|0));
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          $62 = ___cxa_find_matching_catch()|0;
          $63 = tempRet0;
          ___cxa_call_unexpected(($62|0));
          // unreachable;
         }
        }
        ;HEAP32[$value1+0>>2]=0|0;HEAP32[$value1+4>>2]=0|0;HEAP32[$value1+8>>2]=0|0;
        __THREW__ = 0;
        invoke_viiiii(86,($transfer|0),(615776|0),($8|0),($value1|0),2048);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if (!($65)) {
         __THREW__ = 0;
         invoke_viiiii(87,($transfer|0),(615912|0),(615912|0),($size$i$i$i$i20|0),1);
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if (!($67)) {
          __THREW__ = 0;
          invoke_viiiii(86,($transfer|0),(615704|0),($9|0),($p$i$i$i21|0),0);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if (!($69)) {
           $70 = HEAP32[$10>>2]|0;
           $71 = HEAP32[$70>>2]|0;
           $72 = HEAP32[$13>>2]|0;
           $73 = ((($71) + (($72*24)|0)|0) + 12|0);
           HEAP32[$73>>2] = 1;
           __THREW__ = 0;
           invoke_vi(3390,($transfer|0));
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if (!($75)) {
            __THREW__ = 0;
            invoke_vi(3391,($transfer|0));
            $76 = __THREW__; __THREW__ = 0;
            $77 = $76&1;
            if (!($77)) {
             __THREW__ = 0;
             invoke_vi(3392,($transfer|0));
             $78 = __THREW__; __THREW__ = 0;
             $79 = $78&1;
             if (!($79)) {
              __THREW__ = 0;
              invoke_vi(3390,($transfer|0));
              $80 = __THREW__; __THREW__ = 0;
              $81 = $80&1;
              if (!($81)) {
               $93 = HEAP8[$value1>>0]|0;
               $94 = $93 & 1;
               $95 = ($94<<24>>24)==(0);
               if (!($95)) {
                $96 = (($value1) + 8|0);
                $97 = HEAP32[$96>>2]|0;
                HEAP32[$3>>2] = 59;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
                invoke_vii(2591,($97|0),($$byval_copy7|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 $100 = ___cxa_find_matching_catch()|0;
                 $101 = tempRet0;
                 ___cxa_call_unexpected(($100|0));
                 // unreachable;
                }
               }
               ;HEAP32[$value2+0>>2]=0|0;HEAP32[$value2+4>>2]=0|0;HEAP32[$value2+8>>2]=0|0;
               __THREW__ = 0;
               invoke_viiiii(86,($transfer|0),(615792|0),($8|0),($value2|0),2048);
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               do {
                if (!($103)) {
                 __THREW__ = 0;
                 invoke_viiiii(87,($transfer|0),(615912|0),(615912|0),($size$i$i$i$i33|0),1);
                 $104 = __THREW__; __THREW__ = 0;
                 $105 = $104&1;
                 if ($105) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiiii(86,($transfer|0),(615704|0),($9|0),($p$i$i$i34|0),0);
                 $106 = __THREW__; __THREW__ = 0;
                 $107 = $106&1;
                 if ($107) {
                  break;
                 }
                 $108 = HEAP32[$10>>2]|0;
                 $109 = HEAP32[$108>>2]|0;
                 $110 = HEAP32[$13>>2]|0;
                 $111 = ((($109) + (($110*24)|0)|0) + 12|0);
                 HEAP32[$111>>2] = 1;
                 __THREW__ = 0;
                 invoke_vi(3390,($transfer|0));
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3391,($transfer|0));
                 $114 = __THREW__; __THREW__ = 0;
                 $115 = $114&1;
                 if ($115) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3392,($transfer|0));
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3390,($transfer|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                 $131 = HEAP8[$value2>>0]|0;
                 $132 = $131 & 1;
                 $133 = ($132<<24>>24)==(0);
                 do {
                  if (!($133)) {
                   $134 = (($value2) + 8|0);
                   $135 = HEAP32[$134>>2]|0;
                   HEAP32[$1>>2] = 59;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
                   invoke_vii(2591,($135|0),($$byval_copy7|0));
                   $136 = __THREW__; __THREW__ = 0;
                   $137 = $136&1;
                   if (!($137)) {
                    break;
                   }
                   $138 = ___cxa_find_matching_catch()|0;
                   $139 = tempRet0;
                   ___cxa_call_unexpected(($138|0));
                   // unreachable;
                  }
                 } while(0);
                 ;HEAP32[$value3+0>>2]=0|0;HEAP32[$value3+4>>2]=0|0;HEAP32[$value3+8>>2]=0|0;
                 __THREW__ = 0;
                 invoke_viiiii(86,($transfer|0),(615816|0),($8|0),($value3|0),2048);
                 $140 = __THREW__; __THREW__ = 0;
                 $141 = $140&1;
                 do {
                  if (!($141)) {
                   __THREW__ = 0;
                   invoke_viiiii(87,($transfer|0),(615912|0),(615912|0),($size$i$i$i$i46|0),1);
                   $142 = __THREW__; __THREW__ = 0;
                   $143 = $142&1;
                   if ($143) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viiiii(86,($transfer|0),(615704|0),($9|0),($p$i$i$i47|0),0);
                   $144 = __THREW__; __THREW__ = 0;
                   $145 = $144&1;
                   if ($145) {
                    break;
                   }
                   $146 = HEAP32[$10>>2]|0;
                   $147 = HEAP32[$146>>2]|0;
                   $148 = HEAP32[$13>>2]|0;
                   $149 = ((($147) + (($148*24)|0)|0) + 12|0);
                   HEAP32[$149>>2] = 1;
                   __THREW__ = 0;
                   invoke_vi(3390,($transfer|0));
                   $150 = __THREW__; __THREW__ = 0;
                   $151 = $150&1;
                   if ($151) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3391,($transfer|0));
                   $152 = __THREW__; __THREW__ = 0;
                   $153 = $152&1;
                   if ($153) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3392,($transfer|0));
                   $154 = __THREW__; __THREW__ = 0;
                   $155 = $154&1;
                   if ($155) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3390,($transfer|0));
                   $156 = __THREW__; __THREW__ = 0;
                   $157 = $156&1;
                   if ($157) {
                    break;
                   }
                   $169 = HEAP8[$value3>>0]|0;
                   $170 = $169 & 1;
                   $171 = ($170<<24>>24)==(0);
                   do {
                    if (!($171)) {
                     $172 = (($value3) + 8|0);
                     $173 = HEAP32[$172>>2]|0;
                     HEAP32[$0>>2] = 59;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
                     invoke_vii(2591,($173|0),($$byval_copy7|0));
                     $174 = __THREW__; __THREW__ = 0;
                     $175 = $174&1;
                     if (!($175)) {
                      break;
                     }
                     $176 = ___cxa_find_matching_catch()|0;
                     $177 = tempRet0;
                     ___cxa_call_unexpected(($176|0));
                     // unreachable;
                    }
                   } while(0);
                   $178 = (($this) + 76|0);
                   $179 = HEAP32[580584>>2]|0;
                   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615840,$179,$178,0);
                   $180 = HEAP32[$10>>2]|0;
                   $181 = HEAP32[$180>>2]|0;
                   $182 = HEAP32[$13>>2]|0;
                   $183 = ((($181) + (($182*24)|0)|0) + 12|0);
                   HEAP32[$183>>2] = 4;
                   __ZN13ProxyTransfer11EndTransferEv($transfer);
                   $184 = (($this) + 80|0);
                   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615848,$179,$184,0);
                   $185 = HEAP32[$10>>2]|0;
                   $186 = HEAP32[$185>>2]|0;
                   $187 = HEAP32[$13>>2]|0;
                   $188 = ((($186) + (($187*24)|0)|0) + 12|0);
                   HEAP32[$188>>2] = 4;
                   __ZN13ProxyTransfer11EndTransferEv($transfer);
                   $189 = (($this) + 84|0);
                   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615856,$179,$189,2048);
                   $190 = HEAP32[$10>>2]|0;
                   $191 = HEAP32[$190>>2]|0;
                   $192 = HEAP32[$13>>2]|0;
                   $193 = ((($191) + (($192*24)|0)|0) + 12|0);
                   HEAP32[$193>>2] = 4;
                   __ZN13ProxyTransfer11EndTransferEv($transfer);
                   $194 = (($this) + 88|0);
                   $195 = HEAP32[580544>>2]|0;
                   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615872,$195,$194,0);
                   $196 = HEAP32[$10>>2]|0;
                   $197 = HEAP32[$196>>2]|0;
                   $198 = HEAP32[$13>>2]|0;
                   $199 = ((($197) + (($198*24)|0)|0) + 12|0);
                   HEAP32[$199>>2] = 1;
                   __ZN13ProxyTransfer11EndTransferEv($transfer);
                   $200 = (($this) + 89|0);
                   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615880,$195,$200,0);
                   $201 = HEAP32[$10>>2]|0;
                   $202 = HEAP32[$201>>2]|0;
                   $203 = HEAP32[$13>>2]|0;
                   $204 = ((($202) + (($203*24)|0)|0) + 12|0);
                   HEAP32[$204>>2] = 1;
                   __ZN13ProxyTransfer11EndTransferEv($transfer);
                   __ZN13ProxyTransfer5AlignEv($transfer);
                   $205 = (($this) + 60|0);
                   $206 = HEAP32[580592>>2]|0;
                   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615888,$206,$205,2048);
                   $207 = HEAP32[$10>>2]|0;
                   $208 = HEAP32[$207>>2]|0;
                   $209 = HEAP32[$13>>2]|0;
                   $210 = ((($208) + (($209*24)|0)|0) + 12|0);
                   HEAP32[$210>>2] = 4;
                   __ZN13ProxyTransfer11EndTransferEv($transfer);
                   $211 = (($this) + 72|0);
                   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615896,$206,$211,0);
                   $212 = HEAP32[$10>>2]|0;
                   $213 = HEAP32[$212>>2]|0;
                   $214 = HEAP32[$13>>2]|0;
                   $215 = ((($213) + (($214*24)|0)|0) + 12|0);
                   HEAP32[$215>>2] = 4;
                   __ZN13ProxyTransfer11EndTransferEv($transfer);
                   $216 = (($this) + 56|0);
                   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,615904,$206,$216,0);
                   $217 = HEAP32[$10>>2]|0;
                   $218 = HEAP32[$217>>2]|0;
                   $219 = HEAP32[$13>>2]|0;
                   $220 = ((($218) + (($219*24)|0)|0) + 12|0);
                   HEAP32[$220>>2] = 4;
                   __ZN13ProxyTransfer11EndTransferEv($transfer);
                   STACKTOP = sp;return;
                  }
                 } while(0);
                 $158 = ___cxa_find_matching_catch()|0;
                 $159 = tempRet0;
                 $160 = HEAP8[$value3>>0]|0;
                 $161 = $160 & 1;
                 $162 = ($161<<24>>24)==(0);
                 if ($162) {
                  $$4 = $159;$$45 = $158;
                  ___resumeException($$45|0);
                  // unreachable;
                 }
                 $163 = (($value3) + 8|0);
                 $164 = HEAP32[$163>>2]|0;
                 HEAP32[$0>>2] = 59;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
                 invoke_vii(2591,($164|0),($$byval_copy7|0));
                 $165 = __THREW__; __THREW__ = 0;
                 $166 = $165&1;
                 if ($166) {
                  $167 = ___cxa_find_matching_catch()|0;
                  $168 = tempRet0;
                  ___cxa_call_unexpected(($167|0));
                  // unreachable;
                 } else {
                  $$4 = $159;$$45 = $158;
                  ___resumeException($$45|0);
                  // unreachable;
                 }
                }
               } while(0);
               $120 = ___cxa_find_matching_catch()|0;
               $121 = tempRet0;
               $122 = HEAP8[$value2>>0]|0;
               $123 = $122 & 1;
               $124 = ($123<<24>>24)==(0);
               if ($124) {
                $$4 = $121;$$45 = $120;
                ___resumeException($$45|0);
                // unreachable;
               }
               $125 = (($value2) + 8|0);
               $126 = HEAP32[$125>>2]|0;
               HEAP32[$2>>2] = 59;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
               invoke_vii(2591,($126|0),($$byval_copy7|0));
               $127 = __THREW__; __THREW__ = 0;
               $128 = $127&1;
               if ($128) {
                $129 = ___cxa_find_matching_catch()|0;
                $130 = tempRet0;
                ___cxa_call_unexpected(($129|0));
                // unreachable;
               } else {
                $$4 = $121;$$45 = $120;
                ___resumeException($$45|0);
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
        $82 = ___cxa_find_matching_catch()|0;
        $83 = tempRet0;
        $84 = HEAP8[$value1>>0]|0;
        $85 = $84 & 1;
        $86 = ($85<<24>>24)==(0);
        if ($86) {
         $$4 = $83;$$45 = $82;
         ___resumeException($$45|0);
         // unreachable;
        }
        $87 = (($value1) + 8|0);
        $88 = HEAP32[$87>>2]|0;
        HEAP32[$4>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
        invoke_vii(2591,($88|0),($$byval_copy7|0));
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         $91 = ___cxa_find_matching_catch()|0;
         $92 = tempRet0;
         ___cxa_call_unexpected(($91|0));
         // unreachable;
        } else {
         $$4 = $83;$$45 = $82;
         ___resumeException($$45|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 }
 $44 = ___cxa_find_matching_catch()|0;
 $45 = tempRet0;
 $46 = HEAP8[$value>>0]|0;
 $47 = $46 & 1;
 $48 = ($47<<24>>24)==(0);
 if ($48) {
  $$4 = $45;$$45 = $44;
  ___resumeException($$45|0);
  // unreachable;
 }
 $49 = (($value) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 HEAP32[$6>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_vii(2591,($50|0),($$byval_copy7|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  ___cxa_call_unexpected(($53|0));
  // unreachable;
 } else {
  $$4 = $45;$$45 = $44;
  ___resumeException($$45|0);
  // unreachable;
 }
}
function __ZN12InputManagerD2Ev($this) {
 $this = $this|0;
 var $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$byval_copy21 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i29$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy21 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 HEAP32[$this>>2] = ((612600 + 8|0));
 $5 = (($this) + 136|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($this) + 144|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 $11 = (($this) + 124|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12 & 1;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  $15 = (($this) + 132|0);
  $16 = HEAP32[$15>>2]|0;
  __ZdlPv($16);
 }
 $17 = (($this) + 112|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = (($this) + 116|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==($18|0);
  if ($22) {
   $35 = $18;
  } else {
   $24 = $21;
   while(1) {
    $23 = (($24) + -12|0);
    HEAP32[$20>>2] = $23;
    $25 = HEAP32[$23>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     $28 = $23;
    } else {
     $29 = (($24) + -8|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($25|0);
     if (!($31)) {
      $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = $25;
      $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = (($30) + -4|0);
      $32 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i) + ($32)|0);
      $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i;
      $33 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
      $34 = $33 ^ -1;
      $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = (($30) + ($34<<2)|0);
      HEAP32[$29>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i;
     }
     __ZdlPv($25);
     $$pre$i$i$i$i$i = HEAP32[$20>>2]|0;
     $28 = $$pre$i$i$i$i$i;
    }
    $27 = ($28|0)==($18|0);
    if ($27) {
     break;
    } else {
     $24 = $28;
    }
   }
   $$pre$i$i$i = HEAP32[$17>>2]|0;
   $35 = $$pre$i$i$i;
  }
  __ZdlPv($35);
 }
 $36 = (($this) + 72|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + 68|0);
 $39 = HEAP32[$38>>2]|0;
 HEAP32[$4>>2] = $39;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
 invoke_vii(2591,($37|0),($$byval_copy21|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 do {
  if ($41) {
   $81 = ___cxa_find_matching_catch()|0;
   $82 = tempRet0;
   $83 = (($this) + 56|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($this) + 52|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$1>>2] = $86;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($84|0),($$byval_copy21|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if (!($88)) {
    $$3 = $82;$$34 = $81;
    label = 33;
   }
  } else {
   $42 = (($this) + 56|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($this) + 52|0);
   $45 = HEAP32[$44>>2]|0;
   HEAP32[$3>>2] = $45;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($43|0),($$byval_copy21|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $79 = ___cxa_find_matching_catch()|0;
    $80 = tempRet0;
    $$3 = $80;$$34 = $79;
    label = 33;
    break;
   }
   $48 = (($this) + 40|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($this) + 36|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$2>>2] = $51;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($49|0),($$byval_copy21|0));
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    $$4 = $90;$$45 = $89;
    label = 34;
    break;
   }
   $54 = (($this) + 24|0);
   __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($54);
   HEAP32[$this>>2] = ((561192 + 8|0));
   __THREW__ = 0;
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if (!($56)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if (!($58)) {
     STACKTOP = sp;return;
    }
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    __THREW__ = 0;
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $63 = ___cxa_find_matching_catch(0|0)|0;
     $64 = tempRet0;
     ___clang_call_terminate($63);
     // unreachable;
    } else {
     ___resumeException($59|0);
     // unreachable;
    }
   }
   $65 = ___cxa_find_matching_catch()|0;
   $66 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $71 = ___cxa_find_matching_catch(0|0)|0;
    $72 = tempRet0;
    __THREW__ = 0;
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if ($74) {
     $75 = ___cxa_find_matching_catch(0|0)|0;
     $76 = tempRet0;
     ___clang_call_terminate($75);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $71;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    ___resumeException($65|0);
    // unreachable;
   }
   $77 = ___cxa_find_matching_catch(0|0)|0;
   $78 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $77;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 33) {
  $91 = (($this) + 40|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (($this) + 36|0);
  $94 = HEAP32[$93>>2]|0;
  HEAP32[$0>>2] = $94;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($92|0),($$byval_copy21|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if (!($96)) {
   $$4 = $$3;$$45 = $$34;
   label = 34;
  }
 }
 do {
  if ((label|0) == 34) {
   $97 = (($this) + 24|0);
   __ZNSt3__113__vector_baseI9InputAxisNS_9allocatorIS1_EEED2Ev($97);
   HEAP32[$this>>2] = ((561192 + 8|0));
   __THREW__ = 0;
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if (!($99)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if (!($101)) {
     __THREW__ = 0;
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if ($109) {
      break;
     }
     ___resumeException($$45|0);
     // unreachable;
    }
    $102 = ___cxa_find_matching_catch(0|0)|0;
    $103 = tempRet0;
    __THREW__ = 0;
    $104 = __THREW__; __THREW__ = 0;
    $105 = $104&1;
    if ($105) {
     $106 = ___cxa_find_matching_catch(0|0)|0;
     $107 = tempRet0;
     ___clang_call_terminate($106);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $102;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $110 = ___cxa_find_matching_catch(0|0)|0;
   $111 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    $116 = ___cxa_find_matching_catch(0|0)|0;
    $117 = tempRet0;
    __THREW__ = 0;
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     $120 = ___cxa_find_matching_catch(0|0)|0;
     $121 = tempRet0;
     ___clang_call_terminate($120);
     // unreachable;
    } else {
     $eh$lpad$body$i29$indexZ2D = $116;
     ___clang_call_terminate($eh$lpad$body$i29$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if (!($115)) {
    $eh$lpad$body$indexZ2D = $110;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $122 = ___cxa_find_matching_catch(0|0)|0;
   $123 = tempRet0;
   $eh$lpad$body$i29$indexZ2D = $122;
   ___clang_call_terminate($eh$lpad$body$i29$indexZ2D);
   // unreachable;
  }
 } while(0);
 $124 = ___cxa_find_matching_catch(0|0)|0;
 $125 = tempRet0;
 $eh$lpad$body$indexZ2D = $124;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN11TimeManagerC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((615936 + 8|0));
 $2 = (($this) + 24|0);
 $3 = (($this) + 56|0);
 $4 = (($this) + 88|0);
 $5 = (($this) + 132|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 184|0);
 HEAP8[$6>>0] = 0;
 $7 = (($this) + 185|0);
 HEAP8[$7>>0] = 0;
 $8 = (($this) + 40|0);
 $9 = (($this) + 188|0);
 dest=$2+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$9>>2] = Math_fround(1.0);
 HEAPF32[$8>>2] = Math_fround(0.0199999995529651641846);
 $10 = (($this) + 192|0);
 HEAPF32[$10>>2] = Math_fround(0.333333343267440795898);
 $11 = (($this) + 200|0);
 HEAPF64[$11>>3] = 0.0;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 __THREW__ = 0;
 $12 = (invoke_i(88)|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  $15 = (($this) + 72|0);
  if ($12) {
   HEAPF32[$15>>2] = Math_fround(0.0199999995529651641846);
   $16 = (($this) + 84|0);
   HEAPF32[$16>>2] = Math_fround(50.0);
  } else {
   HEAPF32[$15>>2] = Math_fround(0.0);
   $17 = (($this) + 84|0);
   HEAPF32[$17>>2] = Math_fround(0.0);
  }
  $18 = (($this) + 76|0);
  HEAPF32[$18>>2] = Math_fround(0.0);
  $19 = (($this) + 80|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = (($this) + 24|0);
  ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;
  $21 = Math_fround(HEAPF32[$8>>2]);
  $22 = Math_fround(Math_fround(1.0) / $21);
  $23 = (($this) + 52|0);
  HEAPF32[$23>>2] = $22;
  ;HEAP32[$4+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$3+20>>2]|0;HEAP32[$4+24>>2]=HEAP32[$3+24>>2]|0;HEAP32[$4+28>>2]=HEAP32[$3+28>>2]|0;
  $24 = (($this) + 120|0);
  HEAP8[$24>>0] = 1;
  $25 = (($this) + 121|0);
  HEAP8[$25>>0] = 1;
  $26 = (($this) + 122|0);
  HEAP8[$26>>0] = 1;
  $27 = (($this) + 124|0);
  HEAP32[$27>>2] = 0;
  $28 = (($this) + 128|0);
  HEAP32[$28>>2] = 0;
  __THREW__ = 0;
  $29 = (+invoke_d(1));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if (!($31)) {
   $32 = (($this) + 144|0);
   HEAPF64[$32>>3] = $29;
   $33 = (($this) + 152|0);
   HEAPF64[$33>>3] = $29;
   $34 = (($this) + 160|0);
   $35 = (($this) + 136|0);
   HEAP32[$35>>2] = 0;
   ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;
   STACKTOP = sp;return;
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $50 = ___cxa_find_matching_catch(0|0)|0;
  $51 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $52 = __THREW__; __THREW__ = 0;
  $53 = $52&1;
  if ($53) {
   $56 = ___cxa_find_matching_catch(0|0)|0;
   $57 = tempRet0;
   __THREW__ = 0;
   $58 = __THREW__; __THREW__ = 0;
   $59 = $58&1;
   if ($59) {
    $60 = ___cxa_find_matching_catch(0|0)|0;
    $61 = tempRet0;
    ___clang_call_terminate($60);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $56;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if (!($55)) {
   $eh$lpad$body$indexZ2D = $50;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $62;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   $42 = ___cxa_find_matching_catch(0|0)|0;
   $43 = tempRet0;
   __THREW__ = 0;
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $46 = ___cxa_find_matching_catch(0|0)|0;
    $47 = tempRet0;
    ___clang_call_terminate($46);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $42;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  if (!($49)) {
   ___resumeException($36|0);
   // unreachable;
  }
  $64 = ___cxa_find_matching_catch(0|0)|0;
  $65 = tempRet0;
  $eh$lpad$body$indexZ2D = $64;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __ZN11TimeManager8SetPauseEb($this,$pause) {
 $this = $this|0;
 $pause = $pause|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 121|0);
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN11TimeManager6UpdateEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $$0$i$i = Math_fround(0), $$0$i$i1 = Math_fround(0), $$0$i$i3 = Math_fround(0), $$0$i$i5 = Math_fround(0), $$0$i$i7 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0.0, $105 = 0.0, $106 = 0, $107 = 0.0, $108 = Math_fround(0), $109 = 0, $11 = 0;
 var $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0;
 var $129 = 0, $13 = 0.0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0.0, $133 = 0.0, $134 = 0, $135 = 0.0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0;
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0.0, $164 = 0.0;
 var $165 = 0, $166 = 0.0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = 0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0.0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0.0;
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0;
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0;
 var $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0.0;
 var $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0.0, $97 = 0, $98 = Math_fround(0), $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 $3 = (($this) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 HEAP32[$3>>2] = $5;
 $6 = (($this) + 184|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 136|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)>(0);
 if ($11) {
  $12 = (($this) + 56|0);
  $13 = +HEAPF64[$12>>3];
  $14 = (Math_fround(($10|0)));
  $15 = Math_fround(Math_fround(1.0) / $14);
  $16 = (($this) + 188|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($15 * $17);
  $19 = +$18;
  $20 = $13 + $19;
  $21 = (($this) + 56|0);
  $22 = (($this) + 64|0);
  HEAPF64[$22>>3] = $13;
  HEAPF64[$21>>3] = $20;
  $23 = $20 - $13;
  $24 = Math_fround($23);
  $25 = (($this) + 72|0);
  HEAPF32[$25>>2] = $24;
  $26 = $24 > Math_fround(9.99999974737875163555E-6);
  if ($26) {
   $27 = Math_fround(Math_fround(1.0) / $24);
   $$0$i$i = $27;
  } else {
   $$0$i$i = Math_fround(1.0);
  }
  $28 = (($this) + 84|0);
  HEAPF32[$28>>2] = $$0$i$i;
  $29 = (($this) + 80|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = Math_fround($30 * Math_fround(0.800000011920928955078));
  $32 = Math_fround($31 + Math_fround(0.20000000298023223877));
  HEAPF32[$29>>2] = $32;
  $33 = Math_fround(Math_fround(0.20000000298023223877) / $32);
  $34 = (($this) + 76|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($24 * $33);
  $37 = Math_fround(Math_fround(1.0) - $33);
  $38 = Math_fround($37 * $35);
  $39 = Math_fround($36 + $38);
  HEAPF32[$34>>2] = $39;
  $40 = (($this) + 88|0);
  ;HEAP32[$40+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$21+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$21+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$21+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$21+24>>2]|0;HEAP32[$40+28>>2]=HEAP32[$21+28>>2]|0;
  $41 = (+__Z19GetTimeSinceStartupv());
  $42 = +HEAPF64[$21>>3];
  $43 = $41 - $42;
  $44 = (($this) + 144|0);
  HEAPF64[$44>>3] = $43;
  STACKTOP = sp;return;
 }
 $45 = (($this) + 120|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if (!($47)) {
  HEAP8[$45>>0] = 0;
  STACKTOP = sp;return;
 }
 $48 = (($this) + 121|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = ($49<<24>>24)==(0);
 if (!($50)) {
  HEAP8[$48>>0] = 0;
  $51 = (($this) + 56|0);
  $52 = +HEAPF64[$51>>3];
  $53 = (($this) + 188|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($54 * Math_fround(0.0199999995529651641846));
  $56 = +$55;
  $57 = $52 + $56;
  $58 = (($this) + 56|0);
  $59 = (($this) + 64|0);
  HEAPF64[$59>>3] = $52;
  HEAPF64[$58>>3] = $57;
  $60 = $57 - $52;
  $61 = Math_fround($60);
  $62 = (($this) + 72|0);
  HEAPF32[$62>>2] = $61;
  $63 = $61 > Math_fround(9.99999974737875163555E-6);
  if ($63) {
   $64 = Math_fround(Math_fround(1.0) / $61);
   $$0$i$i1 = $64;
  } else {
   $$0$i$i1 = Math_fround(1.0);
  }
  $65 = (($this) + 84|0);
  HEAPF32[$65>>2] = $$0$i$i1;
  $66 = (($this) + 80|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = Math_fround($67 * Math_fround(0.800000011920928955078));
  $69 = Math_fround($68 + Math_fround(0.20000000298023223877));
  HEAPF32[$66>>2] = $69;
  $70 = Math_fround(Math_fround(0.20000000298023223877) / $69);
  $71 = (($this) + 76|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($61 * $70);
  $74 = Math_fround(Math_fround(1.0) - $70);
  $75 = Math_fround($74 * $72);
  $76 = Math_fround($73 + $75);
  HEAPF32[$71>>2] = $76;
  $77 = (($this) + 88|0);
  ;HEAP32[$77+0>>2]=HEAP32[$58+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$58+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$58+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$58+12>>2]|0;HEAP32[$77+16>>2]=HEAP32[$58+16>>2]|0;HEAP32[$77+20>>2]=HEAP32[$58+20>>2]|0;HEAP32[$77+24>>2]=HEAP32[$58+24>>2]|0;HEAP32[$77+28>>2]=HEAP32[$58+28>>2]|0;
  $78 = (+__Z19GetTimeSinceStartupv());
  $79 = +HEAPF64[$58>>3];
  $80 = $78 - $79;
  $81 = (($this) + 144|0);
  HEAPF64[$81>>3] = $80;
  $82 = (($this) + 112|0);
  HEAPF32[$82>>2] = Math_fround(0.0);
  HEAPF32[$66>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $83 = (+__Z19GetTimeSinceStartupv());
 $84 = (($this) + 144|0);
 $85 = +HEAPF64[$84>>3];
 $86 = $83 - $85;
 $87 = (($this) + 152|0);
 $88 = +HEAPF64[$87>>3];
 $89 = $83 - $88;
 $90 = (($this) + 168|0);
 $91 = +HEAPF64[$90>>3];
 $92 = $89 - $91;
 $93 = (($this) + 176|0);
 HEAPF64[$93>>3] = $92;
 HEAPF64[$90>>3] = $89;
 $94 = (($this) + 56|0);
 $95 = +HEAPF64[$94>>3];
 $96 = $86 - $95;
 $97 = (($this) + 192|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = +$98;
 $100 = $96 > $99;
 if ($100) {
  $101 = (($this) + 188|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = Math_fround($98 * $102);
  $104 = +$103;
  $105 = $95 + $104;
  $106 = (($this) + 64|0);
  HEAPF64[$106>>3] = $95;
  HEAPF64[$94>>3] = $105;
  $107 = $105 - $95;
  $108 = Math_fround($107);
  $109 = (($this) + 72|0);
  HEAPF32[$109>>2] = $108;
  $110 = $108 > Math_fround(9.99999974737875163555E-6);
  if ($110) {
   $111 = Math_fround(Math_fround(1.0) / $108);
   $$0$i$i3 = $111;
  } else {
   $$0$i$i3 = Math_fround(1.0);
  }
  $112 = (($this) + 84|0);
  HEAPF32[$112>>2] = $$0$i$i3;
  $113 = (($this) + 80|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = Math_fround($114 * Math_fround(0.800000011920928955078));
  $116 = Math_fround($115 + Math_fround(0.20000000298023223877));
  HEAPF32[$113>>2] = $116;
  $117 = Math_fround(Math_fround(0.20000000298023223877) / $116);
  $118 = (($this) + 76|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround($108 * $117);
  $121 = Math_fround(Math_fround(1.0) - $117);
  $122 = Math_fround($121 * $119);
  $123 = Math_fround($120 + $122);
  HEAPF32[$118>>2] = $123;
  $124 = (($this) + 88|0);
  ;HEAP32[$124+0>>2]=HEAP32[$94+0>>2]|0;HEAP32[$124+4>>2]=HEAP32[$94+4>>2]|0;HEAP32[$124+8>>2]=HEAP32[$94+8>>2]|0;HEAP32[$124+12>>2]=HEAP32[$94+12>>2]|0;HEAP32[$124+16>>2]=HEAP32[$94+16>>2]|0;HEAP32[$124+20>>2]=HEAP32[$94+20>>2]|0;HEAP32[$124+24>>2]=HEAP32[$94+24>>2]|0;HEAP32[$124+28>>2]=HEAP32[$94+28>>2]|0;
  $125 = (+__Z19GetTimeSinceStartupv());
  $126 = +HEAPF64[$94>>3];
  $127 = $125 - $126;
  HEAPF64[$84>>3] = $127;
  STACKTOP = sp;return;
 }
 $128 = $96 < 9.99999974737875163555E-6;
 $129 = (($this) + 188|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 if ($128) {
  $131 = Math_fround($130 * Math_fround(9.99999974737875163555E-6));
  $132 = +$131;
  $133 = $95 + $132;
  $134 = (($this) + 64|0);
  HEAPF64[$134>>3] = $95;
  HEAPF64[$94>>3] = $133;
  $135 = $133 - $95;
  $136 = Math_fround($135);
  $137 = (($this) + 72|0);
  HEAPF32[$137>>2] = $136;
  $138 = $136 > Math_fround(9.99999974737875163555E-6);
  if ($138) {
   $139 = Math_fround(Math_fround(1.0) / $136);
   $$0$i$i5 = $139;
  } else {
   $$0$i$i5 = Math_fround(1.0);
  }
  $140 = (($this) + 84|0);
  HEAPF32[$140>>2] = $$0$i$i5;
  $141 = (($this) + 80|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = Math_fround($142 * Math_fround(0.800000011920928955078));
  $144 = Math_fround($143 + Math_fround(0.20000000298023223877));
  HEAPF32[$141>>2] = $144;
  $145 = Math_fround(Math_fround(0.20000000298023223877) / $144);
  $146 = (($this) + 76|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  $148 = Math_fround($136 * $145);
  $149 = Math_fround(Math_fround(1.0) - $145);
  $150 = Math_fround($149 * $147);
  $151 = Math_fround($148 + $150);
  HEAPF32[$146>>2] = $151;
  $152 = (($this) + 88|0);
  ;HEAP32[$152+0>>2]=HEAP32[$94+0>>2]|0;HEAP32[$152+4>>2]=HEAP32[$94+4>>2]|0;HEAP32[$152+8>>2]=HEAP32[$94+8>>2]|0;HEAP32[$152+12>>2]=HEAP32[$94+12>>2]|0;HEAP32[$152+16>>2]=HEAP32[$94+16>>2]|0;HEAP32[$152+20>>2]=HEAP32[$94+20>>2]|0;HEAP32[$152+24>>2]=HEAP32[$94+24>>2]|0;HEAP32[$152+28>>2]=HEAP32[$94+28>>2]|0;
  $153 = (+__Z19GetTimeSinceStartupv());
  $154 = +HEAPF64[$94>>3];
  $155 = $153 - $154;
  HEAPF64[$84>>3] = $155;
  STACKTOP = sp;return;
 }
 $156 = Math_fround($130 + Math_fround(-1.0));
 $157 = $156 < Math_fround(0.0);
 if ($157) {
  $158 = Math_fround(-$156);
  $160 = $158;
 } else {
  $160 = $156;
 }
 $159 = !($160 <= Math_fround(9.99999997475242707878E-7));
 if ($159) {
  $161 = Math_fround($96);
  $162 = Math_fround($161 * $130);
  $163 = +$162;
  $164 = $95 + $163;
  $165 = (($this) + 64|0);
  HEAPF64[$165>>3] = $95;
  HEAPF64[$94>>3] = $164;
  $166 = $164 - $95;
  $167 = Math_fround($166);
  $168 = (($this) + 72|0);
  HEAPF32[$168>>2] = $167;
  $169 = $167 > Math_fround(9.99999974737875163555E-6);
  if ($169) {
   $170 = Math_fround(Math_fround(1.0) / $167);
   $$0$i$i7 = $170;
  } else {
   $$0$i$i7 = Math_fround(1.0);
  }
  $171 = (($this) + 84|0);
  HEAPF32[$171>>2] = $$0$i$i7;
  $172 = (($this) + 80|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($173 * Math_fround(0.800000011920928955078));
  $175 = Math_fround($174 + Math_fround(0.20000000298023223877));
  HEAPF32[$172>>2] = $175;
  $176 = Math_fround(Math_fround(0.20000000298023223877) / $175);
  $177 = (($this) + 76|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = Math_fround($167 * $176);
  $180 = Math_fround(Math_fround(1.0) - $176);
  $181 = Math_fround($180 * $178);
  $182 = Math_fround($179 + $181);
  HEAPF32[$177>>2] = $182;
  $183 = (($this) + 88|0);
  ;HEAP32[$183+0>>2]=HEAP32[$94+0>>2]|0;HEAP32[$183+4>>2]=HEAP32[$94+4>>2]|0;HEAP32[$183+8>>2]=HEAP32[$94+8>>2]|0;HEAP32[$183+12>>2]=HEAP32[$94+12>>2]|0;HEAP32[$183+16>>2]=HEAP32[$94+16>>2]|0;HEAP32[$183+20>>2]=HEAP32[$94+20>>2]|0;HEAP32[$183+24>>2]=HEAP32[$94+24>>2]|0;HEAP32[$183+28>>2]=HEAP32[$94+28>>2]|0;
  $184 = (+__Z19GetTimeSinceStartupv());
  $185 = +HEAPF64[$94>>3];
  $186 = $184 - $185;
  HEAPF64[$84>>3] = $186;
  STACKTOP = sp;return;
 } else {
  $187 = (($this) + 64|0);
  HEAPF64[$187>>3] = $95;
  HEAPF64[$94>>3] = $86;
  $188 = Math_fround($96);
  $189 = (($this) + 72|0);
  HEAPF32[$189>>2] = $188;
  $190 = $188 > Math_fround(9.99999974737875163555E-6);
  if ($190) {
   $191 = Math_fround(Math_fround(1.0) / $188);
   $$0$i = $191;
  } else {
   $$0$i = Math_fround(1.0);
  }
  $192 = (($this) + 84|0);
  HEAPF32[$192>>2] = $$0$i;
  $193 = (($this) + 80|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = Math_fround($194 * Math_fround(0.800000011920928955078));
  $196 = Math_fround($195 + Math_fround(0.20000000298023223877));
  HEAPF32[$193>>2] = $196;
  $197 = Math_fround(Math_fround(0.20000000298023223877) / $196);
  $198 = (($this) + 76|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = Math_fround($197 * $188);
  $201 = Math_fround(Math_fround(1.0) - $197);
  $202 = Math_fround($201 * $199);
  $203 = Math_fround($202 + $200);
  HEAPF32[$198>>2] = $203;
  $204 = (($this) + 88|0);
  ;HEAP32[$204+0>>2]=HEAP32[$94+0>>2]|0;HEAP32[$204+4>>2]=HEAP32[$94+4>>2]|0;HEAP32[$204+8>>2]=HEAP32[$94+8>>2]|0;HEAP32[$204+12>>2]=HEAP32[$94+12>>2]|0;HEAP32[$204+16>>2]=HEAP32[$94+16>>2]|0;HEAP32[$204+20>>2]=HEAP32[$94+20>>2]|0;HEAP32[$204+24>>2]=HEAP32[$94+24>>2]|0;HEAP32[$204+28>>2]=HEAP32[$94+28>>2]|0;
  STACKTOP = sp;return;
 }
}
function __ZN11TimeManager13StepFixedTimeEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = Math_fround(0), $4 = 0.0, $5 = 0.0, $6 = 0;
 var $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = +HEAPF64[$0>>3];
 $2 = (($this) + 40|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = +$3;
 $5 = $1 + $4;
 $6 = (($this) + 56|0);
 $7 = +HEAPF64[$6>>3];
 $8 = $5 > $7;
 $9 = (($this) + 122|0);
 $10 = HEAP8[$9>>0]|0;
 do {
  if ($8) {
   $11 = ($10<<24>>24)==(0);
   if (!($11)) {
    $12 = (($this) + 32|0);
    HEAPF64[$12>>3] = $1;
    $13 = (($this) + 122|0);
    $21 = $13;
    break;
   }
   $14 = (($this) + 88|0);
   ;HEAP32[$14+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$14+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$14+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$14+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$14+28>>2]=HEAP32[$6+28>>2]|0;
   $15 = (($this) + 185|0);
   HEAP8[$15>>0] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $16 = (($this) + 32|0);
   HEAPF64[$16>>3] = $1;
   $17 = (($this) + 122|0);
   $18 = ($10<<24>>24)==(0);
   if ($18) {
    HEAPF64[$0>>3] = $5;
    $21 = $17;
   } else {
    $21 = $17;
   }
  }
 } while(0);
 $19 = (($this) + 88|0);
 ;HEAP32[$19+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$19+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$19+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$19+24>>2]=HEAP32[$0+24>>2]|0;HEAP32[$19+28>>2]=HEAP32[$0+28>>2]|0;
 $20 = (($this) + 185|0);
 HEAP8[$20>>0] = 1;
 HEAP8[$21>>0] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11TimeManager13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = Math_fround(0), $2 = Math_fround(0), $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(Math_fround(1.0) / $1);
 $3 = (($this) + 52|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($this) + 44|0);
 HEAPF32[$4>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN11TimeManager16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$$i = Math_fround(0), $$0$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 < Math_fround(9.99999974737875163555E-5);
 if ($2) {
  $$0$i = Math_fround(9.99999974737875163555E-5);
 } else {
  $3 = $1 > Math_fround(10.0);
  $$$i = $3 ? Math_fround(10.0) : $1;
  $$0$i = $$$i;
 }
 HEAPF32[$0>>2] = $$0$i;
 $4 = (($this) + 192|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 < $$0$i;
 $7 = $6 ? $$0$i : $5;
 HEAPF32[$4>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN11TimeManager21DidFinishLoadingLevelEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = +HEAPF64[$0>>3];
 $2 = -$1;
 $3 = (($this) + 160|0);
 HEAPF64[$3>>3] = $2;
 $4 = (($this) + 120|0);
 HEAP8[$4>>0] = 1;
 $5 = (($this) + 121|0);
 HEAP8[$5>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN11TimeManager11GetRealtimeEv($this) {
 $this = $this|0;
 var $0 = 0.0, $1 = 0, $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__Z19GetTimeSinceStartupv());
 $1 = (($this) + 152|0);
 $2 = +HEAPF64[$1>>3];
 $3 = $0 - $2;
 STACKTOP = sp;return (+$3);
}
function __Z25RegisterClass_TimeManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(5,144,0,0,0);
 STACKTOP = sp;return;
}
function __ZN11TimeManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 11;
 dest=$3+0|0; src=616056+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 11|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,5,6,($0|0),208,(2413|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN11TimeManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(208,$$byval_copy2,1,16,616048,49)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1768,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(616048|0),49);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK11TimeManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 5;
}
function __ZN11TimeManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616072,616056,$this,0);
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616080,$1,$0,2048);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 192|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616096,$1,$8,2048);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 188|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616128,$1,$13,2048);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11TimeManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14SafeBinaryRead8TransferI11TimeManagerEEvRT_PKc17TransferMetaFlags($transfer,$this,616072,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI11TimeManagerEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,616056,$converter$i,1)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ($1|0)>(0);
 if ($3) {
  __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($data,$this);
  $4 = (($data) + 40|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$4,616080,0);
  $5 = (($data) + 192|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$5,616096,0);
  $6 = (($data) + 188|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$6,616128,0);
 } else {
  $7 = HEAP32[$converter$i>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   (FUNCTION_TABLE_iii[$7 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11TimeManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11TimeManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11TimeManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11TimeManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11TimeManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11TimeManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11TimeManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z14GetTimeManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(7)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN11TimeManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   STACKTOP = sp;return;
  }
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __THREW__ = 0;
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   ___resumeException($4|0);
   // unreachable;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$i$i$indexZ2D = $16;
   ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  ___resumeException($10|0);
  // unreachable;
 }
 $22 = ___cxa_find_matching_catch(0|0)|0;
 $23 = tempRet0;
 $eh$lpad$body$i$i$indexZ2D = $22;
 ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
 // unreachable;
}
function __ZN11TimeManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $16 = ___cxa_find_matching_catch(0|0)|0;
   $17 = tempRet0;
   __THREW__ = 0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $20 = ___cxa_find_matching_catch(0|0)|0;
    $21 = tempRet0;
    ___clang_call_terminate($20);
    // unreachable;
   } else {
    $eh$lpad$body$i$i$i$indexZ2D = $16;
    ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $eh$lpad$body$index8Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  $eh$lpad$body$i$i$i$indexZ2D = $22;
  ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   $4 = ___cxa_find_matching_catch()|0;
   $5 = tempRet0;
   __THREW__ = 0;
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $8 = ___cxa_find_matching_catch(0|0)|0;
    $9 = tempRet0;
    ___clang_call_terminate($8);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $5;$eh$lpad$body$indexZ2D = $4;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $eh$lpad$body$index8Z2D = $27;$eh$lpad$body$indexZ2D = $26;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN11TimeManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$0>>2]);
  HEAPF32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre3 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre3;
 }
 $8 = (($this) + 192|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre4 = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$4>>2]|0;
  $16 = $$pre4;$18 = $$pre5;
 }
 $14 = (($this) + 188|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  STACKTOP = sp;return;
 }
}
function __ZN11TimeManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre11 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $0;$13 = $$pre;$15 = $$pre11;$9 = $$pre$i$i$i;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $0;$13 = $3;$15 = $5;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $10;
 $11 = (($this) + 192|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i3 = HEAP32[$11>>2]|0;
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i4Z2D = $11;$18 = $$pre$i$i$i3;$22 = $$pre12;$24 = $$pre13;
 } else {
  $16 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$1>>2] = $12;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $11;$18 = $17;$22 = $12;$24 = $15;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $19;
 $20 = (($this) + 188|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre$i$i$i8 = HEAP32[$20>>2]|0;
  $$pre$phi$i$i$i9Z2D = $20;$27 = $$pre$i$i$i8;
  $28 = (_llvm_bswap_i32(($27|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $28;
  STACKTOP = sp;return;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $26 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $20;$27 = $26;
  $28 = (_llvm_bswap_i32(($27|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $28;
  STACKTOP = sp;return;
 }
}
function __ZN11TimeManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre3 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre3;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 192|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre4 = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$4>>2]|0;
  $16 = $$pre4;$18 = $$pre5;
 } else {
  $13 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 188|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  STACKTOP = sp;return;
 } else {
  $19 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  STACKTOP = sp;return;
 }
}
function __Z33GetIAnimationStateNetworkProviderv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[616144>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z33SetIAnimationStateNetworkProviderP30IAnimationStateNetworkProvider($manager) {
 $manager = $manager|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[616144>>2] = $manager;
 STACKTOP = sp;return;
}
function __Z13GetIAnimationv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[616160>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z13SetIAnimationP10IAnimation($animation) {
 $animation = $animation|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[616160>>2] = $animation;
 STACKTOP = sp;return;
}
function __Z13GetIEnlightenv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __Z13GetIPhysics2Dv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __Z11GetIPhysicsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[616168>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z11SetIPhysicsP8IPhysics($phys) {
 $phys = $phys|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[616168>>2] = $phys;
 STACKTOP = sp;return;
}
function __ZN13TextRendering17GetITextRenderingEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[616176>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN13TextRendering17SetITextRenderingEPNS_14ITextRenderingE($textRendering) {
 $textRendering = $textRendering|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[616176>>2] = $textRendering;
 STACKTOP = sp;return;
}
function __ZN8IRaycast12IntersectAnyERK14BatchedRaycastP4AABBj($ray,$shapeBounds,$shapeCount) {
 $ray = $ray|0;
 $shapeBounds = $shapeBounds|0;
 $shapeCount = $shapeCount|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0);
 var $9 = Math_fround(0), $rayBounds = 0, $s$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $rayBounds = sp;
 $0 = (($ray) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($ray) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($ray) + 20|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($ray) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($ray) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($ray) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = Math_fround($4 * Math_fround(0.5));
 $16 = Math_fround($9 * Math_fround(0.5));
 $17 = Math_fround($14 * Math_fround(0.5));
 $18 = Math_fround($3 + $15);
 $19 = Math_fround($8 + $16);
 $20 = Math_fround($13 + $17);
 $21 = $15 < Math_fround(0.0);
 if ($21) {
  $22 = Math_fround(-$15);
  $30 = $22;
 } else {
  $30 = $15;
 }
 $23 = $16 < Math_fround(0.0);
 if ($23) {
  $24 = Math_fround(-$16);
  $32 = $24;
 } else {
  $32 = $16;
 }
 $25 = $17 < Math_fround(0.0);
 if ($25) {
  $26 = Math_fround(-$17);
  $34 = $26;
 } else {
  $34 = $17;
 }
 ;HEAP32[$rayBounds+0>>2]=0|0;HEAP32[$rayBounds+4>>2]=0|0;HEAP32[$rayBounds+8>>2]=0|0;HEAP32[$rayBounds+12>>2]=0|0;HEAP32[$rayBounds+16>>2]=0|0;
 HEAPF32[$rayBounds>>2] = $18;
 $27 = (($rayBounds) + 4|0);
 HEAPF32[$27>>2] = $19;
 $28 = (($rayBounds) + 8|0);
 HEAPF32[$28>>2] = $20;
 $29 = (($rayBounds) + 12|0);
 HEAPF32[$29>>2] = $30;
 $31 = (($rayBounds) + 16|0);
 HEAPF32[$31>>2] = $32;
 $33 = (($rayBounds) + 20|0);
 HEAPF32[$33>>2] = $34;
 $35 = ($shapeCount|0)==(0);
 if ($35) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $s$07 = 0;
 }
 while(1) {
  $38 = (($shapeBounds) + (($s$07*24)|0)|0);
  $39 = (__Z26IntersectAABBAABBInclusiveRK4AABBS1_($rayBounds,$38)|0);
  $37 = (($s$07) + 1)|0;
  if ($39) {
   $$0 = 1;
   label = 10;
   break;
  }
  $36 = ($37>>>0)<($shapeCount>>>0);
  if ($36) {
   $s$07 = $37;
  } else {
   $$0 = 0;
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN8IRaycast16ComputeBatchAABBERK13dynamic_arrayI14BatchedRaycastLj4EE($agg$result,$raycasts) {
 $agg$result = $agg$result|0;
 $raycasts = $raycasts|0;
 var $$promoted = Math_fround(0), $$promoted2 = Math_fround(0), $$promoted3 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $6 = Math_fround(0), $7 = Math_fround(0);
 var $8 = Math_fround(0), $9 = 0, $q$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 12|0);
 $1 = (($agg$result) + 16|0);
 $2 = (($agg$result) + 20|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 ;HEAP32[$agg$result+0>>2]=HEAP32[616664+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[616664+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[616664+8>>2]|0;
 $3 = Math_fround(HEAPF32[616664>>2]);
 $4 = Math_fround(-$3);
 $5 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $6 = Math_fround(-$5);
 $7 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $8 = Math_fround(-$7);
 HEAPF32[$0>>2] = $4;
 HEAPF32[$1>>2] = $6;
 HEAPF32[$2>>2] = $8;
 $9 = (($raycasts) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$raycasts>>2]|0;
 $13 = (($agg$result) + 4|0);
 $14 = (($agg$result) + 8|0);
 $$promoted = Math_fround(HEAPF32[$agg$result>>2]);
 $$promoted2 = Math_fround(HEAPF32[$13>>2]);
 $$promoted3 = Math_fround(HEAPF32[$14>>2]);
 $18 = $$promoted;$23 = $$promoted2;$28 = $$promoted3;$31 = $4;$34 = $6;$37 = $8;$q$01 = 0;
 while(1) {
  $15 = ((($12) + (($q$01*28)|0)|0) + 4|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = $16 < $18;
  $19 = $17 ? $16 : $18;
  $20 = ((($12) + (($q$01*28)|0)|0) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = $21 < $23;
  $24 = $22 ? $21 : $23;
  $25 = ((($12) + (($q$01*28)|0)|0) + 12|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = $26 < $28;
  $29 = $27 ? $26 : $28;
  $30 = $31 < $16;
  $32 = $30 ? $16 : $31;
  $33 = $34 < $21;
  $35 = $33 ? $21 : $34;
  $36 = $37 < $26;
  $38 = $36 ? $26 : $37;
  $39 = ((($12) + (($q$01*28)|0)|0) + 16|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = $40 < $19;
  $42 = $41 ? $40 : $19;
  $43 = ((($12) + (($q$01*28)|0)|0) + 20|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = $44 < $24;
  $46 = $45 ? $44 : $24;
  $47 = ((($12) + (($q$01*28)|0)|0) + 24|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = $48 < $29;
  $50 = $49 ? $48 : $29;
  $51 = $32 < $40;
  $52 = $51 ? $40 : $32;
  $53 = $35 < $44;
  $54 = $53 ? $44 : $35;
  $55 = $38 < $48;
  $56 = $55 ? $48 : $38;
  $57 = (($q$01) + 1)|0;
  $58 = ($57>>>0)<($10>>>0);
  if ($58) {
   $18 = $42;$23 = $46;$28 = $50;$31 = $52;$34 = $54;$37 = $56;$q$01 = $57;
  } else {
   break;
  }
 }
 HEAPF32[$agg$result>>2] = $42;
 HEAPF32[$13>>2] = $46;
 HEAPF32[$14>>2] = $50;
 HEAPF32[$0>>2] = $52;
 HEAPF32[$1>>2] = $54;
 HEAPF32[$2>>2] = $56;
 STACKTOP = sp;return;
}
function __Z19GetRaycastInterfacev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[616184>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z19SetRaycastInterfaceP8IRaycast($theInterface) {
 $theInterface = $theInterface|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[616184>>2] = $theInterface;
 STACKTOP = sp;return;
}
function __Z18GetITerrainManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[616192>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z18SetITerrainManagerP15ITerrainManager($manager) {
 $manager = $manager|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[616192>>2] = $manager;
 STACKTOP = sp;return;
}
function __Z18GetITerrainPhysicsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __Z9GetIAudiov() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[616200>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z9SetIAudioP6IAudio($audio) {
 $audio = $audio|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[616200>>2] = $audio;
 STACKTOP = sp;return;
}
function __Z9GetIUmbrav() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __Z19GetIClusterRendererv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __Z18GetIParticleSystemv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __Z16GetScriptingRandv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (616208|0);
}
function __GLOBAL__I_a6056() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_time((0|0))|0);
 HEAP32[616208>>2] = $0;
 $1 = Math_imul($0, 1812433253)|0;
 $2 = (($1) + 1)|0;
 HEAP32[((616208 + 4|0))>>2] = $2;
 $3 = Math_imul($2, 1812433253)|0;
 $4 = (($3) + 1)|0;
 HEAP32[((616208 + 8|0))>>2] = $4;
 $5 = Math_imul($4, 1812433253)|0;
 $6 = (($5) + 1)|0;
 HEAP32[((616208 + 12|0))>>2] = $6;
 STACKTOP = sp;return;
}
function __Z19GetActiveColorSpacev() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20GetPlayerSettingsPtrv()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__Z17GetPlayerSettingsv()|0);
 $3 = (__ZNK14PlayerSettings22GetValidatedColorSpaceEv($2)|0);
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __Z19InitFloatExceptionsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11GradientNEWC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 HEAP8[$0>>0] = 2;
 $1 = (($this) + 65|0);
 HEAP8[$1>>0] = 2;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = -1;
 HEAP32[$this>>2] = -1;
 $3 = (($this) + 48|0);
 HEAP16[$3>>1] = 0;
 $4 = (($this) + 32|0);
 HEAP16[$4>>1] = 0;
 $5 = (($this) + 50|0);
 HEAP16[$5>>1] = -1;
 $6 = (($this) + 34|0);
 HEAP16[$6>>1] = -1;
 $7 = (($this) + 36|0);
 $8 = (($this) + 52|0);
 $9 = (($this) + 8|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;
 ;HEAP16[$7+0>>1]=0|0;HEAP16[$7+2>>1]=0|0;HEAP16[$7+4>>1]=0|0;HEAP16[$7+6>>1]=0|0;HEAP16[$7+8>>1]=0|0;HEAP16[$7+10>>1]=0|0;
 ;HEAP16[$8+0>>1]=0|0;HEAP16[$8+2>>1]=0|0;HEAP16[$8+4>>1]=0|0;HEAP16[$8+6>>1]=0|0;HEAP16[$8+8>>1]=0|0;HEAP16[$8+10>>1]=0|0;
 STACKTOP = sp;return;
}
function __ZN11GradientNEWD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11GradientNEW8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $exitcond5 = 0, $exitcond6 = 0, $i$04 = 0, $i1$03 = 0, $i2$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580560>>2]|0;
 $1 = HEAP32[580752>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = (($transfer) + 20|0);
 $i$04 = 0;
 while(1) {
  $5 = (616512 + ($i$04<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($this) + ($i$04<<2)|0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$6,$0,$7,1);
  __ZN13ProxyTransfer10SetVersionEi($transfer,2);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616544,$1,$7,1);
  $8 = HEAP32[$2>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$3>>2]|0;
  $11 = ((($9) + (($10*24)|0)|0) + 12|0);
  HEAP32[$11>>2] = 4;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $12 = (($i$04) + 1)|0;
  $exitcond6 = ($12|0)==(8);
  if ($exitcond6) {
   break;
  } else {
   $i$04 = $12;
  }
 }
 $4 = HEAP32[580720>>2]|0;
 $i1$03 = 0;
 while(1) {
  $13 = ((($this) + ($i1$03<<1)|0) + 32|0);
  $14 = (616352 + ($i1$03<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$15,$4,$13,1);
  $16 = HEAP32[$2>>2]|0;
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$3>>2]|0;
  $19 = ((($17) + (($18*24)|0)|0) + 12|0);
  HEAP32[$19>>2] = 2;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $20 = (($i1$03) + 1)|0;
  $exitcond5 = ($20|0)==(8);
  if ($exitcond5) {
   $i2$01 = 0;
   break;
  } else {
   $i1$03 = $20;
  }
 }
 while(1) {
  $21 = ((($this) + ($i2$01<<1)|0) + 48|0);
  $22 = (616448 + ($i2$01<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$23,$4,$21,1);
  $24 = HEAP32[$2>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$3>>2]|0;
  $27 = ((($25) + (($26*24)|0)|0) + 12|0);
  HEAP32[$27>>2] = 2;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $28 = (($i2$01) + 1)|0;
  $exitcond = ($28|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i2$01 = $28;
  }
 }
 $29 = (($this) + 64|0);
 $30 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616480,$30,$29,1);
 $31 = HEAP32[$2>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$3>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $35 = (($this) + 65|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616496,$30,$35,1);
 $36 = HEAP32[$2>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$3>>2]|0;
 $39 = ((($37) + (($38*24)|0)|0) + 12|0);
 HEAP32[$39>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11GradientNEW8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i2 = 0, $exitcond = 0, $i$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i2 = sp;
 $0 = HEAP32[580560>>2]|0;
 $i$010 = 0;
 while(1) {
  $21 = (($this) + ($i$010<<2)|0);
  $22 = (616512 + ($i$010<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$23,$0,$converter$i$i2,1)|0);
  $25 = ($24|0)==(0);
  if (!($25)) {
   $26 = ($24|0)>(0);
   if ($26) {
    __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
    $27 = HEAP32[$transfer>>2]|0;
    $28 = $27 & 512;
    $29 = ($28|0)==(0);
    __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$21,616544,0);
    if (!($29)) {
     $30 = HEAP32[$21>>2]|0;
     $31 = (_llvm_bswap_i32(($30|0))|0);
     HEAP32[$21>>2] = $31;
    }
   } else {
    $32 = HEAP32[$converter$i$i2>>2]|0;
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     (FUNCTION_TABLE_iii[$32 & 4095]($21,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
  $34 = (($i$010) + 1)|0;
  $exitcond = ($34|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i$010 = $34;
  }
 }
 $1 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$1,616288,0);
 $2 = (($this) + 34|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$2,616296,0);
 $3 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$3,616304,0);
 $4 = (($this) + 38|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$4,616312,0);
 $5 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$5,616320,0);
 $6 = (($this) + 42|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$6,616328,0);
 $7 = (($this) + 44|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$7,616336,0);
 $8 = (($this) + 46|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$8,616344,0);
 $9 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$9,616384,0);
 $10 = (($this) + 50|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$10,616392,0);
 $11 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$11,616400,0);
 $12 = (($this) + 54|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$12,616408,0);
 $13 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$13,616416,0);
 $14 = (($this) + 58|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$14,616424,0);
 $15 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$15,616432,0);
 $16 = (($this) + 62|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$16,616440,0);
 $17 = (($this) + 64|0);
 $18 = HEAP32[580744>>2]|0;
 $19 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,616480,$18,$converter$i$i2,0)|0);
 $20 = ($19|0)==(0);
 if (!($20)) {
  $35 = ($19|0)>(0);
  do {
   if ($35) {
    $36 = (($transfer) + 12|0);
    $37 = (($transfer) + 80|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 12|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($transfer) + 16|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($transfer) + 28|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($transfer) + 32|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = Math_imul($46, $44)|0;
    $$sum$i$i$i$i$i = (($40) - ($47))|0;
    $48 = (($42) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$36>>2] = $48;
    $49 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($49)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $50 = (($42) + ($$sum1$i$i$i$i$i)|0);
     $51 = (($transfer) + 20|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($50>>>0)>($52>>>0);
     if (!($53)) {
      $54 = HEAP8[$48>>0]|0;
      HEAP8[$17>>0] = $54;
      $55 = HEAP32[$36>>2]|0;
      $56 = (($55) + 1|0);
      HEAP32[$36>>2] = $56;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($36,$17,1);
   } else {
    $57 = HEAP32[$converter$i$i2>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     (FUNCTION_TABLE_iii[$57 & 4095]($17,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $59 = (($this) + 65|0);
 $60 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,616496,$18,$converter$i$i2,0)|0);
 $61 = ($60|0)==(0);
 if (!($61)) {
  $62 = ($60|0)>(0);
  do {
   if ($62) {
    $63 = (($transfer) + 12|0);
    $64 = (($transfer) + 80|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($65) + 12|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($transfer) + 16|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($transfer) + 28|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($transfer) + 32|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = Math_imul($73, $71)|0;
    $$sum$i$i$i$i$i3 = (($67) - ($74))|0;
    $75 = (($69) + ($$sum$i$i$i$i$i3)|0);
    HEAP32[$63>>2] = $75;
    $76 = ($$sum$i$i$i$i$i3|0)<(0);
    if (!($76)) {
     $$sum1$i$i$i$i$i4 = (($$sum$i$i$i$i$i3) + 1)|0;
     $77 = (($69) + ($$sum1$i$i$i$i$i4)|0);
     $78 = (($transfer) + 20|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($77>>>0)>($79>>>0);
     if (!($80)) {
      $81 = HEAP8[$75>>0]|0;
      HEAP8[$59>>0] = $81;
      $82 = HEAP32[$63>>2]|0;
      $83 = (($82) + 1|0);
      HEAP32[$63>>2] = $83;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($63,$59,1);
   } else {
    $84 = HEAP32[$converter$i$i2>>2]|0;
    $85 = ($84|0)==(0|0);
    if (!($85)) {
     (FUNCTION_TABLE_iii[$84 & 4095]($59,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $86 = HEAP8[$17>>0]|0;
 $87 = ($86&255)<(2);
 if ($87) {
  HEAP8[$17>>0] = 2;
  $88 = (($this) + 4|0);
  $89 = HEAP8[$this>>0]|0;
  HEAP8[$88>>0] = $89;
  $90 = (($this) + 1|0);
  $91 = HEAP8[$90>>0]|0;
  $92 = (($88) + 1|0);
  HEAP8[$92>>0] = $91;
  $93 = (($this) + 2|0);
  $94 = HEAP8[$93>>0]|0;
  $95 = (($88) + 2|0);
  HEAP8[$95>>0] = $94;
  HEAP16[$1>>1] = 0;
  HEAP16[$2>>1] = -1;
 }
 $96 = HEAP8[$59>>0]|0;
 $97 = ($96&255)<(2);
 if (!($97)) {
  STACKTOP = sp;return;
 }
 HEAP8[$59>>0] = 2;
 $98 = (($this) + 3|0);
 $99 = HEAP8[$98>>0]|0;
 $100 = (($this) + 7|0);
 HEAP8[$100>>0] = $99;
 HEAP16[$9>>1] = 0;
 HEAP16[$10>>1] = -1;
 STACKTOP = sp;return;
}
function __ZN11GradientNEW8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0;
 var $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0;
 var $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $$pre54 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 20|0);
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$1>>2]|0;
  $11 = $$pre7;$9 = $$pre;
 } else {
  $6 = HEAP32[$2>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $3;
  $11 = $4;$9 = $3;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$1>>2]|0;
  $140 = $$pre8;$142 = $$pre9;
 } else {
  $137 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $137;
  HEAP32[$0>>2] = $8;
  $140 = $8;$142 = $11;
 }
 $138 = (($this) + 8|0);
 $139 = (($140) + 4|0);
 $141 = ($139>>>0)>($142>>>0);
 if ($141) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$138,4);
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$1>>2]|0;
  $146 = $$pre10;$148 = $$pre11;
 } else {
  $143 = HEAP32[$140>>2]|0;
  HEAP32[$138>>2] = $143;
  HEAP32[$0>>2] = $139;
  $146 = $139;$148 = $142;
 }
 $144 = (($this) + 12|0);
 $145 = (($146) + 4|0);
 $147 = ($145>>>0)>($148>>>0);
 if ($147) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$144,4);
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$1>>2]|0;
  $152 = $$pre12;$154 = $$pre13;
 } else {
  $149 = HEAP32[$146>>2]|0;
  HEAP32[$144>>2] = $149;
  HEAP32[$0>>2] = $145;
  $152 = $145;$154 = $148;
 }
 $150 = (($this) + 16|0);
 $151 = (($152) + 4|0);
 $153 = ($151>>>0)>($154>>>0);
 if ($153) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$150,4);
  $$pre14 = HEAP32[$0>>2]|0;
  $$pre15 = HEAP32[$1>>2]|0;
  $158 = $$pre14;$160 = $$pre15;
 } else {
  $155 = HEAP32[$152>>2]|0;
  HEAP32[$150>>2] = $155;
  HEAP32[$0>>2] = $151;
  $158 = $151;$160 = $154;
 }
 $156 = (($this) + 20|0);
 $157 = (($158) + 4|0);
 $159 = ($157>>>0)>($160>>>0);
 if ($159) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$156,4);
  $$pre16 = HEAP32[$0>>2]|0;
  $$pre17 = HEAP32[$1>>2]|0;
  $164 = $$pre16;$166 = $$pre17;
 } else {
  $161 = HEAP32[$158>>2]|0;
  HEAP32[$156>>2] = $161;
  HEAP32[$0>>2] = $157;
  $164 = $157;$166 = $160;
 }
 $162 = (($this) + 24|0);
 $163 = (($164) + 4|0);
 $165 = ($163>>>0)>($166>>>0);
 if ($165) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$162,4);
  $$pre18 = HEAP32[$0>>2]|0;
  $$pre19 = HEAP32[$1>>2]|0;
  $170 = $$pre18;$172 = $$pre19;
 } else {
  $167 = HEAP32[$164>>2]|0;
  HEAP32[$162>>2] = $167;
  HEAP32[$0>>2] = $163;
  $170 = $163;$172 = $166;
 }
 $168 = (($this) + 28|0);
 $169 = (($170) + 4|0);
 $171 = ($169>>>0)>($172>>>0);
 if ($171) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$168,4);
  $$pre20 = HEAP32[$0>>2]|0;
  $$pre21 = HEAP32[$1>>2]|0;
  $13 = $$pre20;$175 = $$pre21;
 } else {
  $173 = HEAP32[$170>>2]|0;
  HEAP32[$168>>2] = $173;
  HEAP32[$0>>2] = $169;
  $13 = $169;$175 = $172;
 }
 $14 = (($this) + 32|0);
 $15 = (($13) + 2|0);
 $174 = ($15>>>0)>($175>>>0);
 if ($174) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$14,2);
  $$pre22 = HEAP32[$0>>2]|0;
  $$pre23 = HEAP32[$1>>2]|0;
  $18 = $$pre22;$20 = $$pre23;
 } else {
  $12 = HEAP16[$13>>1]|0;
  HEAP16[$14>>1] = $12;
  HEAP32[$0>>2] = $15;
  $18 = $15;$20 = $175;
 }
 $16 = (($this) + 34|0);
 $17 = (($18) + 2|0);
 $19 = ($17>>>0)>($20>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$16,2);
  $$pre24 = HEAP32[$0>>2]|0;
  $$pre25 = HEAP32[$1>>2]|0;
  $101 = $$pre24;$103 = $$pre25;
 } else {
  $98 = HEAP16[$18>>1]|0;
  HEAP16[$16>>1] = $98;
  HEAP32[$0>>2] = $17;
  $101 = $17;$103 = $20;
 }
 $99 = (($this) + 36|0);
 $100 = (($101) + 2|0);
 $102 = ($100>>>0)>($103>>>0);
 if ($102) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$99,2);
  $$pre26 = HEAP32[$0>>2]|0;
  $$pre27 = HEAP32[$1>>2]|0;
  $107 = $$pre26;$109 = $$pre27;
 } else {
  $104 = HEAP16[$101>>1]|0;
  HEAP16[$99>>1] = $104;
  HEAP32[$0>>2] = $100;
  $107 = $100;$109 = $103;
 }
 $105 = (($this) + 38|0);
 $106 = (($107) + 2|0);
 $108 = ($106>>>0)>($109>>>0);
 if ($108) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$105,2);
  $$pre28 = HEAP32[$0>>2]|0;
  $$pre29 = HEAP32[$1>>2]|0;
  $113 = $$pre28;$115 = $$pre29;
 } else {
  $110 = HEAP16[$107>>1]|0;
  HEAP16[$105>>1] = $110;
  HEAP32[$0>>2] = $106;
  $113 = $106;$115 = $109;
 }
 $111 = (($this) + 40|0);
 $112 = (($113) + 2|0);
 $114 = ($112>>>0)>($115>>>0);
 if ($114) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$111,2);
  $$pre30 = HEAP32[$0>>2]|0;
  $$pre31 = HEAP32[$1>>2]|0;
  $119 = $$pre30;$121 = $$pre31;
 } else {
  $116 = HEAP16[$113>>1]|0;
  HEAP16[$111>>1] = $116;
  HEAP32[$0>>2] = $112;
  $119 = $112;$121 = $115;
 }
 $117 = (($this) + 42|0);
 $118 = (($119) + 2|0);
 $120 = ($118>>>0)>($121>>>0);
 if ($120) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$117,2);
  $$pre32 = HEAP32[$0>>2]|0;
  $$pre33 = HEAP32[$1>>2]|0;
  $125 = $$pre32;$127 = $$pre33;
 } else {
  $122 = HEAP16[$119>>1]|0;
  HEAP16[$117>>1] = $122;
  HEAP32[$0>>2] = $118;
  $125 = $118;$127 = $121;
 }
 $123 = (($this) + 44|0);
 $124 = (($125) + 2|0);
 $126 = ($124>>>0)>($127>>>0);
 if ($126) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$123,2);
  $$pre34 = HEAP32[$0>>2]|0;
  $$pre35 = HEAP32[$1>>2]|0;
  $131 = $$pre34;$133 = $$pre35;
 } else {
  $128 = HEAP16[$125>>1]|0;
  HEAP16[$123>>1] = $128;
  HEAP32[$0>>2] = $124;
  $131 = $124;$133 = $127;
 }
 $129 = (($this) + 46|0);
 $130 = (($131) + 2|0);
 $132 = ($130>>>0)>($133>>>0);
 if ($132) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$129,2);
  $$pre36 = HEAP32[$0>>2]|0;
  $$pre37 = HEAP32[$1>>2]|0;
  $136 = $$pre37;$22 = $$pre36;
 } else {
  $134 = HEAP16[$131>>1]|0;
  HEAP16[$129>>1] = $134;
  HEAP32[$0>>2] = $130;
  $136 = $133;$22 = $130;
 }
 $23 = (($this) + 48|0);
 $24 = (($22) + 2|0);
 $135 = ($24>>>0)>($136>>>0);
 if ($135) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$23,2);
  $$pre38 = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$1>>2]|0;
  $27 = $$pre38;$29 = $$pre39;
 } else {
  $21 = HEAP16[$22>>1]|0;
  HEAP16[$23>>1] = $21;
  HEAP32[$0>>2] = $24;
  $27 = $24;$29 = $136;
 }
 $25 = (($this) + 50|0);
 $26 = (($27) + 2|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,2);
  $$pre40 = HEAP32[$0>>2]|0;
  $$pre41 = HEAP32[$1>>2]|0;
  $61 = $$pre40;$63 = $$pre41;
 } else {
  $58 = HEAP16[$27>>1]|0;
  HEAP16[$25>>1] = $58;
  HEAP32[$0>>2] = $26;
  $61 = $26;$63 = $29;
 }
 $59 = (($this) + 52|0);
 $60 = (($61) + 2|0);
 $62 = ($60>>>0)>($63>>>0);
 if ($62) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$59,2);
  $$pre42 = HEAP32[$0>>2]|0;
  $$pre43 = HEAP32[$1>>2]|0;
  $67 = $$pre42;$69 = $$pre43;
 } else {
  $64 = HEAP16[$61>>1]|0;
  HEAP16[$59>>1] = $64;
  HEAP32[$0>>2] = $60;
  $67 = $60;$69 = $63;
 }
 $65 = (($this) + 54|0);
 $66 = (($67) + 2|0);
 $68 = ($66>>>0)>($69>>>0);
 if ($68) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$65,2);
  $$pre44 = HEAP32[$0>>2]|0;
  $$pre45 = HEAP32[$1>>2]|0;
  $73 = $$pre44;$75 = $$pre45;
 } else {
  $70 = HEAP16[$67>>1]|0;
  HEAP16[$65>>1] = $70;
  HEAP32[$0>>2] = $66;
  $73 = $66;$75 = $69;
 }
 $71 = (($this) + 56|0);
 $72 = (($73) + 2|0);
 $74 = ($72>>>0)>($75>>>0);
 if ($74) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$71,2);
  $$pre46 = HEAP32[$0>>2]|0;
  $$pre47 = HEAP32[$1>>2]|0;
  $79 = $$pre46;$81 = $$pre47;
 } else {
  $76 = HEAP16[$73>>1]|0;
  HEAP16[$71>>1] = $76;
  HEAP32[$0>>2] = $72;
  $79 = $72;$81 = $75;
 }
 $77 = (($this) + 58|0);
 $78 = (($79) + 2|0);
 $80 = ($78>>>0)>($81>>>0);
 if ($80) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$77,2);
  $$pre48 = HEAP32[$0>>2]|0;
  $$pre49 = HEAP32[$1>>2]|0;
  $85 = $$pre48;$87 = $$pre49;
 } else {
  $82 = HEAP16[$79>>1]|0;
  HEAP16[$77>>1] = $82;
  HEAP32[$0>>2] = $78;
  $85 = $78;$87 = $81;
 }
 $83 = (($this) + 60|0);
 $84 = (($85) + 2|0);
 $86 = ($84>>>0)>($87>>>0);
 if ($86) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$83,2);
  $$pre50 = HEAP32[$0>>2]|0;
  $$pre51 = HEAP32[$1>>2]|0;
  $91 = $$pre50;$93 = $$pre51;
 } else {
  $88 = HEAP16[$85>>1]|0;
  HEAP16[$83>>1] = $88;
  HEAP32[$0>>2] = $84;
  $91 = $84;$93 = $87;
 }
 $89 = (($this) + 62|0);
 $90 = (($91) + 2|0);
 $92 = ($90>>>0)>($93>>>0);
 if ($92) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$89,2);
  $$pre52 = HEAP32[$0>>2]|0;
  $$pre53 = HEAP32[$1>>2]|0;
  $31 = $$pre52;$97 = $$pre53;
 } else {
  $94 = HEAP16[$91>>1]|0;
  HEAP16[$89>>1] = $94;
  HEAP32[$0>>2] = $90;
  $31 = $90;$97 = $93;
 }
 $32 = (($this) + 64|0);
 $95 = (($31) + 1|0);
 $96 = ($95>>>0)>($97>>>0);
 if ($96) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$32,1);
  $$pre54 = HEAP32[$0>>2]|0;
  $37 = $$pre54;
 } else {
  $30 = HEAP8[$31>>0]|0;
  HEAP8[$32>>0] = $30;
  $33 = HEAP32[$0>>2]|0;
  $34 = (($33) + 1|0);
  HEAP32[$0>>2] = $34;
  $37 = $34;
 }
 $35 = (($this) + 65|0);
 $36 = (($37) + 1|0);
 $38 = HEAP32[$1>>2]|0;
 $39 = ($36>>>0)>($38>>>0);
 if ($39) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$35,1);
 } else {
  $40 = HEAP8[$37>>0]|0;
  HEAP8[$35>>0] = $40;
  $41 = HEAP32[$0>>2]|0;
  $42 = (($41) + 1|0);
  HEAP32[$0>>2] = $42;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $43 = HEAP8[$32>>0]|0;
 $44 = ($43&255)<(2);
 if ($44) {
  HEAP8[$32>>0] = 2;
  $45 = (($this) + 4|0);
  $46 = HEAP8[$this>>0]|0;
  HEAP8[$45>>0] = $46;
  $47 = (($this) + 1|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = (($45) + 1|0);
  HEAP8[$49>>0] = $48;
  $50 = (($this) + 2|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = (($45) + 2|0);
  HEAP8[$52>>0] = $51;
  HEAP16[$14>>1] = 0;
  HEAP16[$16>>1] = -1;
 }
 $53 = HEAP8[$35>>0]|0;
 $54 = ($53&255)<(2);
 if (!($54)) {
  STACKTOP = sp;return;
 }
 HEAP8[$35>>0] = 2;
 $55 = (($this) + 3|0);
 $56 = HEAP8[$55>>0]|0;
 $57 = (($this) + 7|0);
 HEAP8[$57>>0] = $56;
 HEAP16[$23>>1] = 0;
 HEAP16[$25>>1] = -1;
 STACKTOP = sp;return;
}
function __ZN11GradientNEW8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond8 = 0, $exitcond9 = 0, $i$07 = 0, $i1$06 = 0;
 var $i2$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 20|0);
 $i$07 = 0;
 while(1) {
  $2 = (($this) + ($i$07<<2)|0);
  $3 = HEAP32[$0>>2]|0;
  $4 = (($3) + 4|0);
  $5 = HEAP32[$1>>2]|0;
  $6 = ($4>>>0)>($5>>>0);
  if ($6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($0,$2,4);
   $$pre$i$i$i$i$i$i = HEAP32[$2>>2]|0;
   $8 = $$pre$i$i$i$i$i$i;
  } else {
   $7 = HEAP32[$3>>2]|0;
   HEAP32[$2>>2] = $7;
   HEAP32[$0>>2] = $4;
   $8 = $7;
  }
  HEAP32[$2>>2] = $8;
  $9 = (($i$07) + 1)|0;
  $exitcond9 = ($9|0)==(8);
  if ($exitcond9) {
   $i1$06 = 0;
   break;
  } else {
   $i$07 = $9;
  }
 }
 while(1) {
  $10 = ((($this) + ($i1$06<<1)|0) + 32|0);
  $11 = HEAP32[$0>>2]|0;
  $12 = (($11) + 2|0);
  $13 = HEAP32[$1>>2]|0;
  $14 = ($12>>>0)>($13>>>0);
  if ($14) {
   __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,2);
   $$pre$i$i$i = HEAP16[$10>>1]|0;
   $17 = $$pre$i$i$i;
  } else {
   $15 = HEAP16[$11>>1]|0;
   HEAP16[$10>>1] = $15;
   HEAP32[$0>>2] = $12;
   $17 = $15;
  }
  $16 = $17&65535;
  $18 = $16 << 8;
  $19 = $16 >>> 8;
  $20 = $18 | $19;
  $21 = $20&65535;
  HEAP16[$10>>1] = $21;
  $22 = (($i1$06) + 1)|0;
  $exitcond8 = ($22|0)==(8);
  if ($exitcond8) {
   $i2$04 = 0;
   break;
  } else {
   $i1$06 = $22;
  }
 }
 while(1) {
  $23 = ((($this) + ($i2$04<<1)|0) + 48|0);
  $24 = HEAP32[$0>>2]|0;
  $25 = (($24) + 2|0);
  $26 = HEAP32[$1>>2]|0;
  $27 = ($25>>>0)>($26>>>0);
  if ($27) {
   __ZN12CachedReader15UpdateReadCacheEPvj($0,$23,2);
   $$pre$i$i$i1 = HEAP16[$23>>1]|0;
   $30 = $$pre$i$i$i1;
  } else {
   $28 = HEAP16[$24>>1]|0;
   HEAP16[$23>>1] = $28;
   HEAP32[$0>>2] = $25;
   $30 = $28;
  }
  $29 = $30&65535;
  $31 = $29 << 8;
  $32 = $29 >>> 8;
  $33 = $31 | $32;
  $34 = $33&65535;
  HEAP16[$23>>1] = $34;
  $35 = (($i2$04) + 1)|0;
  $exitcond = ($35|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i2$04 = $35;
  }
 }
 $36 = (($this) + 64|0);
 $37 = HEAP32[$0>>2]|0;
 $38 = (($37) + 1|0);
 $39 = HEAP32[$1>>2]|0;
 $40 = ($38>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$36,1);
  $$pre = HEAP32[$0>>2]|0;
  $46 = $$pre;
 } else {
  $41 = HEAP8[$37>>0]|0;
  HEAP8[$36>>0] = $41;
  $42 = HEAP32[$0>>2]|0;
  $43 = (($42) + 1|0);
  HEAP32[$0>>2] = $43;
  $46 = $43;
 }
 $44 = (($this) + 65|0);
 $45 = (($46) + 1|0);
 $47 = HEAP32[$1>>2]|0;
 $48 = ($45>>>0)>($47>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$44,1);
 } else {
  $49 = HEAP8[$46>>0]|0;
  HEAP8[$44>>0] = $49;
  $50 = HEAP32[$0>>2]|0;
  $51 = (($50) + 1|0);
  HEAP32[$0>>2] = $51;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $52 = HEAP8[$36>>0]|0;
 $53 = ($52&255)<(2);
 if ($53) {
  HEAP8[$36>>0] = 2;
  $54 = (($this) + 4|0);
  $55 = HEAP8[$this>>0]|0;
  HEAP8[$54>>0] = $55;
  $56 = (($this) + 1|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = (($54) + 1|0);
  HEAP8[$58>>0] = $57;
  $59 = (($this) + 2|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = (($54) + 2|0);
  HEAP8[$61>>0] = $60;
  $62 = (($this) + 32|0);
  HEAP16[$62>>1] = 0;
  $63 = (($this) + 34|0);
  HEAP16[$63>>1] = -1;
 }
 $64 = HEAP8[$44>>0]|0;
 $65 = ($64&255)<(2);
 if (!($65)) {
  STACKTOP = sp;return;
 }
 HEAP8[$44>>0] = 2;
 $66 = (($this) + 3|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = (($this) + 7|0);
 HEAP8[$68>>0] = $67;
 $69 = (($this) + 48|0);
 HEAP16[$69>>1] = 0;
 $70 = (($this) + 50|0);
 HEAP16[$70>>1] = -1;
 STACKTOP = sp;return;
}
function __ZN11GradientNEW8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0;
 var $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0;
 var $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $$pre54 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 20|0);
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$2>>2] = $6;
  HEAP32[$0>>2] = $3;
  $11 = $4;$9 = $3;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$1>>2]|0;
  $11 = $$pre7;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $122 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $122;
  HEAP32[$0>>2] = $8;
  $125 = $8;$127 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$1>>2]|0;
  $125 = $$pre8;$127 = $$pre9;
 }
 $123 = (($this) + 8|0);
 $124 = (($125) + 4|0);
 $126 = ($124>>>0)<($127>>>0);
 if ($126) {
  $128 = HEAP32[$123>>2]|0;
  HEAP32[$125>>2] = $128;
  HEAP32[$0>>2] = $124;
  $131 = $124;$133 = $127;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$123,4);
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$1>>2]|0;
  $131 = $$pre10;$133 = $$pre11;
 }
 $129 = (($this) + 12|0);
 $130 = (($131) + 4|0);
 $132 = ($130>>>0)<($133>>>0);
 if ($132) {
  $134 = HEAP32[$129>>2]|0;
  HEAP32[$131>>2] = $134;
  HEAP32[$0>>2] = $130;
  $137 = $130;$139 = $133;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$129,4);
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$1>>2]|0;
  $137 = $$pre12;$139 = $$pre13;
 }
 $135 = (($this) + 16|0);
 $136 = (($137) + 4|0);
 $138 = ($136>>>0)<($139>>>0);
 if ($138) {
  $140 = HEAP32[$135>>2]|0;
  HEAP32[$137>>2] = $140;
  HEAP32[$0>>2] = $136;
  $143 = $136;$145 = $139;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$135,4);
  $$pre14 = HEAP32[$0>>2]|0;
  $$pre15 = HEAP32[$1>>2]|0;
  $143 = $$pre14;$145 = $$pre15;
 }
 $141 = (($this) + 20|0);
 $142 = (($143) + 4|0);
 $144 = ($142>>>0)<($145>>>0);
 if ($144) {
  $146 = HEAP32[$141>>2]|0;
  HEAP32[$143>>2] = $146;
  HEAP32[$0>>2] = $142;
  $149 = $142;$151 = $145;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$141,4);
  $$pre16 = HEAP32[$0>>2]|0;
  $$pre17 = HEAP32[$1>>2]|0;
  $149 = $$pre16;$151 = $$pre17;
 }
 $147 = (($this) + 24|0);
 $148 = (($149) + 4|0);
 $150 = ($148>>>0)<($151>>>0);
 if ($150) {
  $152 = HEAP32[$147>>2]|0;
  HEAP32[$149>>2] = $152;
  HEAP32[$0>>2] = $148;
  $155 = $148;$157 = $151;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$147,4);
  $$pre18 = HEAP32[$0>>2]|0;
  $$pre19 = HEAP32[$1>>2]|0;
  $155 = $$pre18;$157 = $$pre19;
 }
 $153 = (($this) + 28|0);
 $154 = (($155) + 4|0);
 $156 = ($154>>>0)<($157>>>0);
 if ($156) {
  $158 = HEAP32[$153>>2]|0;
  HEAP32[$155>>2] = $158;
  HEAP32[$0>>2] = $154;
  $14 = $154;$160 = $157;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$153,4);
  $$pre20 = HEAP32[$0>>2]|0;
  $$pre21 = HEAP32[$1>>2]|0;
  $14 = $$pre20;$160 = $$pre21;
 }
 $13 = (($this) + 32|0);
 $15 = (($14) + 2|0);
 $159 = ($15>>>0)<($160>>>0);
 if ($159) {
  $12 = HEAP16[$13>>1]|0;
  HEAP16[$14>>1] = $12;
  HEAP32[$0>>2] = $15;
  $18 = $15;$20 = $160;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,2);
  $$pre22 = HEAP32[$0>>2]|0;
  $$pre23 = HEAP32[$1>>2]|0;
  $18 = $$pre22;$20 = $$pre23;
 }
 $16 = (($this) + 34|0);
 $17 = (($18) + 2|0);
 $19 = ($17>>>0)<($20>>>0);
 if ($19) {
  $83 = HEAP16[$16>>1]|0;
  HEAP16[$18>>1] = $83;
  HEAP32[$0>>2] = $17;
  $86 = $17;$88 = $20;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$16,2);
  $$pre24 = HEAP32[$0>>2]|0;
  $$pre25 = HEAP32[$1>>2]|0;
  $86 = $$pre24;$88 = $$pre25;
 }
 $84 = (($this) + 36|0);
 $85 = (($86) + 2|0);
 $87 = ($85>>>0)<($88>>>0);
 if ($87) {
  $89 = HEAP16[$84>>1]|0;
  HEAP16[$86>>1] = $89;
  HEAP32[$0>>2] = $85;
  $92 = $85;$94 = $88;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$84,2);
  $$pre26 = HEAP32[$0>>2]|0;
  $$pre27 = HEAP32[$1>>2]|0;
  $92 = $$pre26;$94 = $$pre27;
 }
 $90 = (($this) + 38|0);
 $91 = (($92) + 2|0);
 $93 = ($91>>>0)<($94>>>0);
 if ($93) {
  $95 = HEAP16[$90>>1]|0;
  HEAP16[$92>>1] = $95;
  HEAP32[$0>>2] = $91;
  $100 = $94;$98 = $91;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$90,2);
  $$pre28 = HEAP32[$0>>2]|0;
  $$pre29 = HEAP32[$1>>2]|0;
  $100 = $$pre29;$98 = $$pre28;
 }
 $96 = (($this) + 40|0);
 $97 = (($98) + 2|0);
 $99 = ($97>>>0)<($100>>>0);
 if ($99) {
  $101 = HEAP16[$96>>1]|0;
  HEAP16[$98>>1] = $101;
  HEAP32[$0>>2] = $97;
  $104 = $97;$106 = $100;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$96,2);
  $$pre30 = HEAP32[$0>>2]|0;
  $$pre31 = HEAP32[$1>>2]|0;
  $104 = $$pre30;$106 = $$pre31;
 }
 $102 = (($this) + 42|0);
 $103 = (($104) + 2|0);
 $105 = ($103>>>0)<($106>>>0);
 if ($105) {
  $107 = HEAP16[$102>>1]|0;
  HEAP16[$104>>1] = $107;
  HEAP32[$0>>2] = $103;
  $110 = $103;$112 = $106;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$102,2);
  $$pre32 = HEAP32[$0>>2]|0;
  $$pre33 = HEAP32[$1>>2]|0;
  $110 = $$pre32;$112 = $$pre33;
 }
 $108 = (($this) + 44|0);
 $109 = (($110) + 2|0);
 $111 = ($109>>>0)<($112>>>0);
 if ($111) {
  $113 = HEAP16[$108>>1]|0;
  HEAP16[$110>>1] = $113;
  HEAP32[$0>>2] = $109;
  $116 = $109;$118 = $112;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$108,2);
  $$pre34 = HEAP32[$0>>2]|0;
  $$pre35 = HEAP32[$1>>2]|0;
  $116 = $$pre34;$118 = $$pre35;
 }
 $114 = (($this) + 46|0);
 $115 = (($116) + 2|0);
 $117 = ($115>>>0)<($118>>>0);
 if ($117) {
  $119 = HEAP16[$114>>1]|0;
  HEAP16[$116>>1] = $119;
  HEAP32[$0>>2] = $115;
  $121 = $118;$23 = $115;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$114,2);
  $$pre36 = HEAP32[$0>>2]|0;
  $$pre37 = HEAP32[$1>>2]|0;
  $121 = $$pre37;$23 = $$pre36;
 }
 $22 = (($this) + 48|0);
 $24 = (($23) + 2|0);
 $120 = ($24>>>0)<($121>>>0);
 if ($120) {
  $21 = HEAP16[$22>>1]|0;
  HEAP16[$23>>1] = $21;
  HEAP32[$0>>2] = $24;
  $27 = $24;$29 = $121;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$22,2);
  $$pre38 = HEAP32[$0>>2]|0;
  $$pre39 = HEAP32[$1>>2]|0;
  $27 = $$pre38;$29 = $$pre39;
 }
 $25 = (($this) + 50|0);
 $26 = (($27) + 2|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $43 = HEAP16[$25>>1]|0;
  HEAP16[$27>>1] = $43;
  HEAP32[$0>>2] = $26;
  $46 = $26;$48 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$25,2);
  $$pre40 = HEAP32[$0>>2]|0;
  $$pre41 = HEAP32[$1>>2]|0;
  $46 = $$pre40;$48 = $$pre41;
 }
 $44 = (($this) + 52|0);
 $45 = (($46) + 2|0);
 $47 = ($45>>>0)<($48>>>0);
 if ($47) {
  $49 = HEAP16[$44>>1]|0;
  HEAP16[$46>>1] = $49;
  HEAP32[$0>>2] = $45;
  $52 = $45;$54 = $48;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$44,2);
  $$pre42 = HEAP32[$0>>2]|0;
  $$pre43 = HEAP32[$1>>2]|0;
  $52 = $$pre42;$54 = $$pre43;
 }
 $50 = (($this) + 54|0);
 $51 = (($52) + 2|0);
 $53 = ($51>>>0)<($54>>>0);
 if ($53) {
  $55 = HEAP16[$50>>1]|0;
  HEAP16[$52>>1] = $55;
  HEAP32[$0>>2] = $51;
  $58 = $51;$60 = $54;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$50,2);
  $$pre44 = HEAP32[$0>>2]|0;
  $$pre45 = HEAP32[$1>>2]|0;
  $58 = $$pre44;$60 = $$pre45;
 }
 $56 = (($this) + 56|0);
 $57 = (($58) + 2|0);
 $59 = ($57>>>0)<($60>>>0);
 if ($59) {
  $61 = HEAP16[$56>>1]|0;
  HEAP16[$58>>1] = $61;
  HEAP32[$0>>2] = $57;
  $64 = $57;$66 = $60;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$56,2);
  $$pre46 = HEAP32[$0>>2]|0;
  $$pre47 = HEAP32[$1>>2]|0;
  $64 = $$pre46;$66 = $$pre47;
 }
 $62 = (($this) + 58|0);
 $63 = (($64) + 2|0);
 $65 = ($63>>>0)<($66>>>0);
 if ($65) {
  $67 = HEAP16[$62>>1]|0;
  HEAP16[$64>>1] = $67;
  HEAP32[$0>>2] = $63;
  $70 = $63;$72 = $66;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$62,2);
  $$pre48 = HEAP32[$0>>2]|0;
  $$pre49 = HEAP32[$1>>2]|0;
  $70 = $$pre48;$72 = $$pre49;
 }
 $68 = (($this) + 60|0);
 $69 = (($70) + 2|0);
 $71 = ($69>>>0)<($72>>>0);
 if ($71) {
  $73 = HEAP16[$68>>1]|0;
  HEAP16[$70>>1] = $73;
  HEAP32[$0>>2] = $69;
  $76 = $69;$78 = $72;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$68,2);
  $$pre50 = HEAP32[$0>>2]|0;
  $$pre51 = HEAP32[$1>>2]|0;
  $76 = $$pre50;$78 = $$pre51;
 }
 $74 = (($this) + 62|0);
 $75 = (($76) + 2|0);
 $77 = ($75>>>0)<($78>>>0);
 if ($77) {
  $79 = HEAP16[$74>>1]|0;
  HEAP16[$76>>1] = $79;
  HEAP32[$0>>2] = $75;
  $32 = $75;$82 = $78;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$74,2);
  $$pre52 = HEAP32[$0>>2]|0;
  $$pre53 = HEAP32[$1>>2]|0;
  $32 = $$pre52;$82 = $$pre53;
 }
 $31 = (($this) + 64|0);
 $80 = (($32) + 1|0);
 $81 = ($80>>>0)<($82>>>0);
 if ($81) {
  $30 = HEAP8[$31>>0]|0;
  HEAP8[$32>>0] = $30;
  $33 = HEAP32[$0>>2]|0;
  $34 = (($33) + 1|0);
  HEAP32[$0>>2] = $34;
  $37 = $34;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$31,1);
  $$pre54 = HEAP32[$0>>2]|0;
  $37 = $$pre54;
 }
 $35 = (($this) + 65|0);
 $36 = (($37) + 1|0);
 $38 = HEAP32[$1>>2]|0;
 $39 = ($36>>>0)<($38>>>0);
 if ($39) {
  $40 = HEAP8[$35>>0]|0;
  HEAP8[$37>>0] = $40;
  $41 = HEAP32[$0>>2]|0;
  $42 = (($41) + 1|0);
  HEAP32[$0>>2] = $42;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$35,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN10Matrix3x3fC2ERK10Matrix4x4f($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $3 = 0, $4 = 0;
 var $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$other>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = (($other) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 4|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($other) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 8|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($other) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 12|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($other) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 16|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($other) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 20|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($other) + 32|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 24|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($other) + 36|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 28|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($other) + 40|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 32|0);
 HEAPF32[$24>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN10Matrix3x3f8SetScaleERK8Vector3f($this,$inScale) {
 $this = $this|0;
 $inScale = $inScale|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inScale>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = (($this) + 12|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 24|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($inScale) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 16|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 28|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 20|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($inScale) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 32|0);
 HEAPF32[$12>>2] = $11;
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix3x3f15InvertTransposeEv($this) {
 $this = $this|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $3 = 0, $4 = 0;
 var $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $m$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $m$i = sp;
 __ZN10Matrix4x4fC2ERK10Matrix3x3f($m$i,$this);
 (__Z20InvertMatrix4x4_FullPKfPf($m$i,$m$i)|0);
 $0 = Math_fround(HEAPF32[$m$i>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = (($m$i) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 4|0);
 $4 = (($m$i) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 8|0);
 $7 = (($m$i) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 12|0);
 $10 = (($m$i) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 16|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($m$i) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 20|0);
 $16 = (($m$i) + 32|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 24|0);
 $19 = (($m$i) + 36|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 28|0);
 $22 = (($m$i) + 40|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 32|0);
 HEAPF32[$24>>2] = $23;
 HEAPF32[$9>>2] = $2;
 HEAPF32[$3>>2] = $8;
 HEAPF32[$18>>2] = $5;
 HEAPF32[$6>>2] = $17;
 HEAPF32[$15>>2] = $20;
 HEAPF32[$21>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN10Matrix3x3fmLERKS_($this,$inM) {
 $this = $this|0;
 $inM = $inM|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inM) + 4|0);
 $1 = (($inM) + 8|0);
 $2 = (($inM) + 12|0);
 $3 = (($inM) + 16|0);
 $4 = (($inM) + 20|0);
 $5 = (($inM) + 24|0);
 $6 = (($inM) + 28|0);
 $7 = (($inM) + 32|0);
 $8 = Math_fround(HEAPF32[$this>>2]);
 $9 = (($this) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(HEAPF32[$inM>>2]);
 $14 = Math_fround($8 * $13);
 $15 = Math_fround(HEAPF32[$0>>2]);
 $16 = Math_fround($10 * $15);
 $17 = Math_fround($14 + $16);
 $18 = Math_fround(HEAPF32[$1>>2]);
 $19 = Math_fround($12 * $18);
 $20 = Math_fround($17 + $19);
 HEAPF32[$this>>2] = $20;
 $21 = Math_fround(HEAPF32[$2>>2]);
 $22 = Math_fround($8 * $21);
 $23 = Math_fround(HEAPF32[$3>>2]);
 $24 = Math_fround($10 * $23);
 $25 = Math_fround($22 + $24);
 $26 = Math_fround(HEAPF32[$4>>2]);
 $27 = Math_fround($12 * $26);
 $28 = Math_fround($25 + $27);
 HEAPF32[$9>>2] = $28;
 $29 = Math_fround(HEAPF32[$5>>2]);
 $30 = Math_fround($8 * $29);
 $31 = Math_fround(HEAPF32[$6>>2]);
 $32 = Math_fround($10 * $31);
 $33 = Math_fround($30 + $32);
 $34 = Math_fround(HEAPF32[$7>>2]);
 $35 = Math_fround($12 * $34);
 $36 = Math_fround($33 + $35);
 HEAPF32[$11>>2] = $36;
 $37 = (($this) + 4|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($this) + 16|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 28|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround(HEAPF32[$inM>>2]);
 $44 = Math_fround($38 * $43);
 $45 = Math_fround(HEAPF32[$0>>2]);
 $46 = Math_fround($40 * $45);
 $47 = Math_fround($44 + $46);
 $48 = Math_fround(HEAPF32[$1>>2]);
 $49 = Math_fround($42 * $48);
 $50 = Math_fround($47 + $49);
 HEAPF32[$37>>2] = $50;
 $51 = Math_fround(HEAPF32[$2>>2]);
 $52 = Math_fround($38 * $51);
 $53 = Math_fround(HEAPF32[$3>>2]);
 $54 = Math_fround($40 * $53);
 $55 = Math_fround($52 + $54);
 $56 = Math_fround(HEAPF32[$4>>2]);
 $57 = Math_fround($42 * $56);
 $58 = Math_fround($55 + $57);
 HEAPF32[$39>>2] = $58;
 $59 = Math_fround(HEAPF32[$5>>2]);
 $60 = Math_fround($38 * $59);
 $61 = Math_fround(HEAPF32[$6>>2]);
 $62 = Math_fround($40 * $61);
 $63 = Math_fround($60 + $62);
 $64 = Math_fround(HEAPF32[$7>>2]);
 $65 = Math_fround($42 * $64);
 $66 = Math_fround($63 + $65);
 HEAPF32[$41>>2] = $66;
 $67 = (($this) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($this) + 20|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($this) + 32|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround(HEAPF32[$inM>>2]);
 $74 = Math_fround($68 * $73);
 $75 = Math_fround(HEAPF32[$0>>2]);
 $76 = Math_fround($70 * $75);
 $77 = Math_fround($74 + $76);
 $78 = Math_fround(HEAPF32[$1>>2]);
 $79 = Math_fround($72 * $78);
 $80 = Math_fround($77 + $79);
 HEAPF32[$67>>2] = $80;
 $81 = Math_fround(HEAPF32[$2>>2]);
 $82 = Math_fround($68 * $81);
 $83 = Math_fround(HEAPF32[$3>>2]);
 $84 = Math_fround($70 * $83);
 $85 = Math_fround($82 + $84);
 $86 = Math_fround(HEAPF32[$4>>2]);
 $87 = Math_fround($72 * $86);
 $88 = Math_fround($85 + $87);
 HEAPF32[$69>>2] = $88;
 $89 = Math_fround(HEAPF32[$5>>2]);
 $90 = Math_fround($68 * $89);
 $91 = Math_fround(HEAPF32[$6>>2]);
 $92 = Math_fround($70 * $91);
 $93 = Math_fround($90 + $92);
 $94 = Math_fround(HEAPF32[$7>>2]);
 $95 = Math_fround($72 * $94);
 $96 = Math_fround($93 + $95);
 HEAPF32[$71>>2] = $96;
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix3x3f12SetAxisAngleERK8Vector3ff($this,$rotationAxis,$radians) {
 $this = $this|0;
 $rotationAxis = $rotationAxis|0;
 $radians = Math_fround($radians);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(+(Math_sin((+$radians)))));
 $1 = (Math_fround(+(Math_cos((+$radians)))));
 $2 = Math_fround(HEAPF32[$rotationAxis>>2]);
 $3 = (($rotationAxis) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($rotationAxis) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($2 * $2);
 $8 = Math_fround($4 * $4);
 $9 = Math_fround($6 * $6);
 $10 = Math_fround($2 * $4);
 $11 = Math_fround($4 * $6);
 $12 = Math_fround($2 * $6);
 $13 = Math_fround($0 * $2);
 $14 = Math_fround($0 * $4);
 $15 = Math_fround($0 * $6);
 $16 = Math_fround(Math_fround(1.0) - $1);
 $17 = Math_fround($16 * $7);
 $18 = Math_fround($1 + $17);
 HEAPF32[$this>>2] = $18;
 $19 = Math_fround($16 * $10);
 $20 = Math_fround($19 - $15);
 $21 = (($this) + 12|0);
 HEAPF32[$21>>2] = $20;
 $22 = Math_fround($16 * $12);
 $23 = Math_fround($14 + $22);
 $24 = (($this) + 24|0);
 HEAPF32[$24>>2] = $23;
 $25 = Math_fround($19 + $15);
 $26 = (($this) + 4|0);
 HEAPF32[$26>>2] = $25;
 $27 = Math_fround($16 * $8);
 $28 = Math_fround($1 + $27);
 $29 = (($this) + 16|0);
 HEAPF32[$29>>2] = $28;
 $30 = Math_fround($16 * $11);
 $31 = Math_fround($30 - $13);
 $32 = (($this) + 28|0);
 HEAPF32[$32>>2] = $31;
 $33 = Math_fround($22 - $14);
 $34 = (($this) + 8|0);
 HEAPF32[$34>>2] = $33;
 $35 = Math_fround($13 + $30);
 $36 = (($this) + 20|0);
 HEAPF32[$36>>2] = $35;
 $37 = Math_fround($16 * $9);
 $38 = Math_fround($1 + $37);
 $39 = (($this) + 32|0);
 HEAPF32[$39>>2] = $38;
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix3x3f17SetFromToRotationERK8Vector3fS2_($this,$from,$to) {
 $this = $this|0;
 $from = $from|0;
 $to = $to|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $3 = 0, $4 = 0;
 var $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $mtx = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $mtx = sp;
 __Z14fromToRotationPKfS0_PA3_f($from,$to,$mtx);
 $0 = Math_fround(HEAPF32[$mtx>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = (($mtx) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 12|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($mtx) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 24|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($mtx) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 4|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($mtx) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 16|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($mtx) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 28|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($mtx) + 24|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 8|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($mtx) + 28|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 20|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($mtx) + 32|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 32|0);
 HEAPF32[$24>>2] = $23;
 STACKTOP = sp;return ($this|0);
}
function __Z14fromToRotationPKfS0_PA3_f($from,$to,$mtx) {
 $from = $from|0;
 $to = $to|0;
 $mtx = $mtx|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0.0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $left$sroa$0$0 = Math_fround(0), $left$sroa$1$0 = Math_fround(0), $left$sroa$2$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($from) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($to) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 * $3);
 $5 = (($from) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($to) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = Math_fround($4 - $9);
 $11 = Math_fround(HEAPF32[$to>>2]);
 $12 = Math_fround($6 * $11);
 $13 = Math_fround(HEAPF32[$from>>2]);
 $14 = Math_fround($3 * $13);
 $15 = Math_fround($12 - $14);
 $16 = Math_fround($8 * $13);
 $17 = Math_fround($1 * $11);
 $18 = Math_fround($16 - $17);
 $19 = Math_fround($11 * $13);
 $20 = Math_fround($1 * $8);
 $21 = Math_fround($20 + $19);
 $22 = Math_fround($3 * $6);
 $23 = Math_fround($22 + $21);
 $24 = +$23;
 $25 = $24 > 0.999998999999999971244;
 if ($25) {
  HEAPF32[$mtx>>2] = Math_fround(1.0);
  $26 = (($mtx) + 4|0);
  HEAPF32[$26>>2] = Math_fround(0.0);
  $27 = (($mtx) + 8|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  $28 = (($mtx) + 12|0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  $29 = (($mtx) + 16|0);
  HEAPF32[$29>>2] = Math_fround(1.0);
  $30 = (($mtx) + 20|0);
  HEAPF32[$30>>2] = Math_fround(0.0);
  $31 = (($mtx) + 24|0);
  HEAPF32[$31>>2] = Math_fround(0.0);
  $32 = (($mtx) + 28|0);
  HEAPF32[$32>>2] = Math_fround(0.0);
  $33 = (($mtx) + 32|0);
  HEAPF32[$33>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
 $34 = $24 < -0.999998999999999971244;
 if (!($34)) {
  $102 = Math_fround(Math_fround(1.0) - $23);
  $103 = Math_fround($10 * $10);
  $104 = Math_fround($15 * $15);
  $105 = Math_fround($103 + $104);
  $106 = Math_fround($18 * $18);
  $107 = Math_fround($106 + $105);
  $108 = Math_fround($102 / $107);
  $109 = Math_fround($10 * $108);
  $110 = Math_fround($18 * $108);
  $111 = Math_fround($15 * $109);
  $112 = Math_fround($18 * $109);
  $113 = Math_fround($15 * $110);
  $114 = Math_fround($10 * $109);
  $115 = Math_fround($23 + $114);
  HEAPF32[$mtx>>2] = $115;
  $116 = Math_fround($111 - $18);
  $117 = (($mtx) + 4|0);
  HEAPF32[$117>>2] = $116;
  $118 = Math_fround($15 + $112);
  $119 = (($mtx) + 8|0);
  HEAPF32[$119>>2] = $118;
  $120 = Math_fround($18 + $111);
  $121 = (($mtx) + 12|0);
  HEAPF32[$121>>2] = $120;
  $122 = Math_fround($15 * $108);
  $123 = Math_fround($15 * $122);
  $124 = Math_fround($23 + $123);
  $125 = (($mtx) + 16|0);
  HEAPF32[$125>>2] = $124;
  $126 = Math_fround($113 - $10);
  $127 = (($mtx) + 20|0);
  HEAPF32[$127>>2] = $126;
  $128 = Math_fround($112 - $15);
  $129 = (($mtx) + 24|0);
  HEAPF32[$129>>2] = $128;
  $130 = Math_fround($10 + $113);
  $131 = (($mtx) + 28|0);
  HEAPF32[$131>>2] = $130;
  $132 = Math_fround($18 * $110);
  $133 = Math_fround($23 + $132);
  $134 = (($mtx) + 32|0);
  HEAPF32[$134>>2] = $133;
  STACKTOP = sp;return;
 }
 $35 = Math_fround(-$1);
 $36 = Math_fround($6 * $6);
 $37 = Math_fround($36 + Math_fround(0.0));
 $38 = Math_fround($1 * $1);
 $39 = Math_fround($38 + $37);
 $40 = +$39;
 $41 = $40 < 9.99999999999999954748E-7;
 if ($41) {
  $42 = Math_fround(-$6);
  $left$sroa$0$0 = $42;$left$sroa$1$0 = Math_fround(0.0);$left$sroa$2$0 = $13;
 } else {
  $left$sroa$0$0 = Math_fround(0.0);$left$sroa$1$0 = $6;$left$sroa$2$0 = $35;
 }
 $43 = Math_fround($left$sroa$0$0 * $left$sroa$0$0);
 $44 = Math_fround($left$sroa$1$0 * $left$sroa$1$0);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($left$sroa$2$0 * $left$sroa$2$0);
 $47 = Math_fround($45 + $46);
 $48 = (Math_fround(Math_sqrt((Math_fround($47)))));
 $49 = Math_fround(Math_fround(1.0) / $48);
 $50 = Math_fround($left$sroa$0$0 * $49);
 $51 = Math_fround($left$sroa$1$0 * $49);
 $52 = Math_fround($left$sroa$2$0 * $49);
 $53 = Math_fround($51 * $6);
 $54 = Math_fround($52 * $1);
 $55 = Math_fround($53 - $54);
 $56 = Math_fround($52 * $13);
 $57 = Math_fround($50 * $6);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($50 * $1);
 $60 = Math_fround($51 * $13);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround(-$13);
 $63 = Math_fround($13 * $62);
 $64 = Math_fround($1 * $35);
 $65 = Math_fround($1 * $62);
 $66 = Math_fround($6 * $62);
 $67 = Math_fround($6 * $35);
 $68 = Math_fround($55 * $55);
 $69 = Math_fround($58 * $58);
 $70 = Math_fround($61 * $61);
 $71 = Math_fround($55 * $58);
 $72 = Math_fround($55 * $61);
 $73 = Math_fround($58 * $61);
 $74 = Math_fround(-$50);
 $75 = Math_fround($50 * $74);
 $76 = Math_fround(-$51);
 $77 = Math_fround($51 * $76);
 $78 = Math_fround($52 * $52);
 $79 = Math_fround($51 * $74);
 $80 = Math_fround($52 * $74);
 $81 = Math_fround($52 * $76);
 $82 = Math_fround($63 + $68);
 $83 = Math_fround($75 + $82);
 HEAPF32[$mtx>>2] = $83;
 $84 = Math_fround($65 + $71);
 $85 = Math_fround($79 + $84);
 $86 = (($mtx) + 4|0);
 HEAPF32[$86>>2] = $85;
 $87 = Math_fround($66 + $72);
 $88 = Math_fround($80 + $87);
 $89 = (($mtx) + 8|0);
 HEAPF32[$89>>2] = $88;
 $90 = (($mtx) + 12|0);
 HEAPF32[$90>>2] = $85;
 $91 = Math_fround($64 + $69);
 $92 = Math_fround($77 + $91);
 $93 = (($mtx) + 16|0);
 HEAPF32[$93>>2] = $92;
 $94 = Math_fround($67 + $73);
 $95 = Math_fround($81 + $94);
 $96 = (($mtx) + 20|0);
 HEAPF32[$96>>2] = $95;
 $97 = (($mtx) + 24|0);
 HEAPF32[$97>>2] = $88;
 $98 = (($mtx) + 28|0);
 HEAPF32[$98>>2] = $95;
 $99 = Math_fround($70 - $36);
 $100 = Math_fround($99 - $78);
 $101 = (($mtx) + 32|0);
 HEAPF32[$101>>2] = $100;
 STACKTOP = sp;return;
}
function __Z13MatrixToEulerRK10Matrix3x3fR8Vector3f($matrix,$v) {
 $matrix = $matrix|0;
 $v = $v|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($matrix) + 28|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 < Math_fround(0.999000012874603271484);
 if (!($2)) {
  HEAPF32[$v>>2] = Math_fround(-1.57079637050628662109);
  $40 = (($matrix) + 12|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround(-$41);
  $43 = Math_fround(HEAPF32[$matrix>>2]);
  $44 = (Math_fround(+(Math_atan2((+$42),(+$43)))));
  $45 = (($v) + 4|0);
  HEAPF32[$45>>2] = $44;
  $46 = (($v) + 8|0);
  HEAPF32[$46>>2] = Math_fround(0.0);
  HEAPF32[$v>>2] = Math_fround(4.7123889923095703125);
  $47 = $44 < Math_fround(-9.99999974737875163555E-5);
  if ($47) {
   $48 = Math_fround($44 + Math_fround(6.28318548202514648438));
   HEAPF32[$45>>2] = $48;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $49 = $44 > Math_fround(6.28308534622192382813);
  if (!($49)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $50 = Math_fround($44 + Math_fround(-6.28318548202514648438));
  HEAPF32[$45>>2] = $50;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = $1 > Math_fround(-0.999000012874603271484);
 if (!($3)) {
  HEAPF32[$v>>2] = Math_fround(1.57079637050628662109);
  $30 = (($matrix) + 12|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround(HEAPF32[$matrix>>2]);
  $33 = (Math_fround(+(Math_atan2((+$31),(+$32)))));
  $34 = (($v) + 4|0);
  HEAPF32[$34>>2] = $33;
  $35 = (($v) + 8|0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  $36 = $33 < Math_fround(-9.99999974737875163555E-5);
  if ($36) {
   $37 = Math_fround($33 + Math_fround(6.28318548202514648438));
   HEAPF32[$34>>2] = $37;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $38 = $33 > Math_fround(6.28308534622192382813);
  if (!($38)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $39 = Math_fround($33 + Math_fround(-6.28318548202514648438));
  HEAPF32[$34>>2] = $39;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = Math_fround(-$1);
 $5 = (Math_fround(+(Math_asin((+$4)))));
 HEAPF32[$v>>2] = $5;
 $6 = (($matrix) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($matrix) + 32|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (Math_fround(+(Math_atan2((+$7),(+$9)))));
 $11 = (($v) + 4|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($matrix) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($matrix) + 16|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (Math_fround(+(Math_atan2((+$13),(+$15)))));
 $17 = (($v) + 8|0);
 HEAPF32[$17>>2] = $16;
 $18 = $5 < Math_fround(-9.99999974737875163555E-5);
 if ($18) {
  $19 = Math_fround($5 + Math_fround(6.28318548202514648438));
  HEAPF32[$v>>2] = $19;
 } else {
  $20 = $5 > Math_fround(6.28308534622192382813);
  if ($20) {
   $21 = Math_fround($5 + Math_fround(-6.28318548202514648438));
   HEAPF32[$v>>2] = $21;
  }
 }
 $22 = $10 < Math_fround(-9.99999974737875163555E-5);
 if ($22) {
  $23 = Math_fround($10 + Math_fround(6.28318548202514648438));
  HEAPF32[$11>>2] = $23;
 } else {
  $24 = $10 > Math_fround(6.28308534622192382813);
  if ($24) {
   $25 = Math_fround($10 + Math_fround(-6.28318548202514648438));
   HEAPF32[$11>>2] = $25;
  }
 }
 $26 = $16 < Math_fround(-9.99999974737875163555E-5);
 if ($26) {
  $27 = Math_fround($16 + Math_fround(6.28318548202514648438));
  HEAPF32[$17>>2] = $27;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = $16 > Math_fround(6.28308534622192382813);
 if (!($28)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = Math_fround($16 + Math_fround(-6.28318548202514648438));
 HEAPF32[$17>>2] = $29;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z20LookRotationToMatrixRK8Vector3fS1_P10Matrix3x3f($viewVec,$upVec,$m) {
 $viewVec = $viewVec|0;
 $upVec = $upVec|0;
 $m = $m|0;
 var $$0 = 0, $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0);
 var $80 = 0, $81 = 0, $82 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$viewVec>>2]);
 $1 = (($viewVec) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($viewVec) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($0 * $0);
 $6 = Math_fround($2 * $2);
 $7 = Math_fround($5 + $6);
 $8 = Math_fround($4 * $4);
 $9 = Math_fround($7 + $8);
 $10 = (Math_fround(Math_sqrt((Math_fround($9)))));
 $11 = Math_fround(HEAPF32[616648>>2]);
 $12 = $10 < $11;
 if ($12) {
  HEAPF32[$m>>2] = Math_fround(1.0);
  $13 = (($m) + 12|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = (($m) + 24|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
  $15 = (($m) + 4|0);
  HEAPF32[$15>>2] = Math_fround(0.0);
  $16 = (($m) + 16|0);
  HEAPF32[$16>>2] = Math_fround(1.0);
  $17 = (($m) + 28|0);
  HEAPF32[$17>>2] = Math_fround(0.0);
  $18 = (($m) + 8|0);
  HEAPF32[$18>>2] = Math_fround(0.0);
  $19 = (($m) + 20|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = (($m) + 32|0);
  HEAPF32[$20>>2] = Math_fround(1.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = Math_fround($0 / $10);
 $22 = Math_fround($2 / $10);
 $23 = Math_fround($4 / $10);
 $24 = (($upVec) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 * $25);
 $27 = (($upVec) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($22 * $28);
 $30 = Math_fround($26 - $29);
 $31 = Math_fround($21 * $28);
 $32 = Math_fround(HEAPF32[$upVec>>2]);
 $33 = Math_fround($23 * $32);
 $34 = Math_fround($31 - $33);
 $35 = Math_fround($22 * $32);
 $36 = Math_fround($21 * $25);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($30 * $30);
 $39 = Math_fround($34 * $34);
 $40 = Math_fround($38 + $39);
 $41 = Math_fround($37 * $37);
 $42 = Math_fround($41 + $40);
 $43 = (Math_fround(Math_sqrt((Math_fround($42)))));
 $44 = $43 < $11;
 if ($44) {
  HEAPF32[$m>>2] = Math_fround(1.0);
  $45 = (($m) + 12|0);
  HEAPF32[$45>>2] = Math_fround(0.0);
  $46 = (($m) + 24|0);
  HEAPF32[$46>>2] = Math_fround(0.0);
  $47 = (($m) + 4|0);
  HEAPF32[$47>>2] = Math_fround(0.0);
  $48 = (($m) + 16|0);
  HEAPF32[$48>>2] = Math_fround(1.0);
  $49 = (($m) + 28|0);
  HEAPF32[$49>>2] = Math_fround(0.0);
  $50 = (($m) + 8|0);
  HEAPF32[$50>>2] = Math_fround(0.0);
  $51 = (($m) + 20|0);
  HEAPF32[$51>>2] = Math_fround(0.0);
  $52 = (($m) + 32|0);
  HEAPF32[$52>>2] = Math_fround(1.0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $53 = Math_fround($30 / $43);
 $54 = Math_fround($34 / $43);
 $55 = Math_fround($37 / $43);
 $56 = Math_fround($22 * $55);
 $57 = Math_fround($23 * $54);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($23 * $53);
 $60 = Math_fround($21 * $55);
 $61 = Math_fround($59 - $60);
 $62 = Math_fround($21 * $54);
 $63 = Math_fround($22 * $53);
 $64 = Math_fround($62 - $63);
 $65 = Math_fround($58 * $58);
 $66 = Math_fround($61 * $61);
 $67 = Math_fround($65 + $66);
 $68 = Math_fround($64 * $64);
 $69 = Math_fround($68 + $67);
 $70 = Math_fround($69 + Math_fround(-1.0));
 $71 = $70 < Math_fround(0.0);
 if ($71) {
  $72 = Math_fround(-$70);
  $74 = $72;
 } else {
  $74 = $70;
 }
 $73 = !($74 <= Math_fround(9.99999997475242707878E-7));
 if ($73) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$m>>2] = $53;
 $75 = (($m) + 12|0);
 HEAPF32[$75>>2] = $58;
 $76 = (($m) + 24|0);
 HEAPF32[$76>>2] = $21;
 $77 = (($m) + 4|0);
 HEAPF32[$77>>2] = $54;
 $78 = (($m) + 16|0);
 HEAPF32[$78>>2] = $61;
 $79 = (($m) + 28|0);
 HEAPF32[$79>>2] = $22;
 $80 = (($m) + 8|0);
 HEAPF32[$80>>2] = $55;
 $81 = (($m) + 20|0);
 HEAPF32[$81>>2] = $64;
 $82 = (($m) + 32|0);
 HEAPF32[$82>>2] = $23;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10Matrix4x4f11SetIdentityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = Math_fround(1.0);
 $0 = (($this) + 16|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 32|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 48|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($this) + 20|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 36|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 52|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 8|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 24|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 40|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 56|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 12|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 28|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 44|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($this) + 60|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4fC2ERK10Matrix3x3f($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$other>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = (($other) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 4|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($other) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 8|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 12|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($other) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 16|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($other) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 20|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($other) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 24|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($this) + 28|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($other) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 32|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($other) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 36|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($other) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 40|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($this) + 44|0);
 $28 = (($this) + 60|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;
 HEAPF32[$28>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4faSERK10Matrix3x3f($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$other>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = (($other) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 4|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($other) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 8|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 12|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($other) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 16|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($other) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 20|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($other) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 24|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($this) + 28|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($other) + 24|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 32|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($other) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 36|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($other) + 32|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 40|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($this) + 44|0);
 $28 = (($this) + 60|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;
 HEAPF32[$28>>2] = Math_fround(1.0);
 STACKTOP = sp;return ($this|0);
}
function __ZNK10Matrix4x4f10IsIdentityEf($this,$threshold) {
 $this = $this|0;
 $threshold = Math_fround($threshold);
 var $$0 = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0;
 var $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$this>>2]);
 $1 = Math_fround($0 + Math_fround(-1.0));
 $2 = $1 < Math_fround(0.0);
 if ($2) {
  $3 = Math_fround(-$1);
  $5 = $3;
 } else {
  $5 = $1;
 }
 $4 = !($5 <= $threshold);
 do {
  if (!($4)) {
   $6 = (($this) + 16|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 < Math_fround(0.0);
   if ($8) {
    $9 = Math_fround(-$7);
    $11 = $9;
   } else {
    $11 = $7;
   }
   $10 = !($11 <= $threshold);
   if (!($10)) {
    $12 = (($this) + 32|0);
    $13 = Math_fround(HEAPF32[$12>>2]);
    $14 = $13 < Math_fround(0.0);
    if ($14) {
     $15 = Math_fround(-$13);
     $17 = $15;
    } else {
     $17 = $13;
    }
    $16 = !($17 <= $threshold);
    if (!($16)) {
     $18 = (($this) + 48|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = $19 < Math_fround(0.0);
     if ($20) {
      $21 = Math_fround(-$19);
      $23 = $21;
     } else {
      $23 = $19;
     }
     $22 = !($23 <= $threshold);
     if (!($22)) {
      $24 = (($this) + 4|0);
      $25 = Math_fround(HEAPF32[$24>>2]);
      $26 = $25 < Math_fround(0.0);
      if ($26) {
       $27 = Math_fround(-$25);
       $29 = $27;
      } else {
       $29 = $25;
      }
      $28 = !($29 <= $threshold);
      if (!($28)) {
       $30 = (($this) + 20|0);
       $31 = Math_fround(HEAPF32[$30>>2]);
       $32 = Math_fround($31 + Math_fround(-1.0));
       $33 = $32 < Math_fround(0.0);
       if ($33) {
        $34 = Math_fround(-$32);
        $36 = $34;
       } else {
        $36 = $32;
       }
       $35 = !($36 <= $threshold);
       if (!($35)) {
        $37 = (($this) + 36|0);
        $38 = Math_fround(HEAPF32[$37>>2]);
        $39 = $38 < Math_fround(0.0);
        if ($39) {
         $40 = Math_fround(-$38);
         $42 = $40;
        } else {
         $42 = $38;
        }
        $41 = !($42 <= $threshold);
        if (!($41)) {
         $43 = (($this) + 52|0);
         $44 = Math_fround(HEAPF32[$43>>2]);
         $45 = $44 < Math_fround(0.0);
         if ($45) {
          $46 = Math_fround(-$44);
          $48 = $46;
         } else {
          $48 = $44;
         }
         $47 = !($48 <= $threshold);
         if (!($47)) {
          $49 = (($this) + 8|0);
          $50 = Math_fround(HEAPF32[$49>>2]);
          $51 = $50 < Math_fround(0.0);
          if ($51) {
           $52 = Math_fround(-$50);
           $54 = $52;
          } else {
           $54 = $50;
          }
          $53 = !($54 <= $threshold);
          if (!($53)) {
           $55 = (($this) + 24|0);
           $56 = Math_fround(HEAPF32[$55>>2]);
           $57 = $56 < Math_fround(0.0);
           if ($57) {
            $58 = Math_fround(-$56);
            $60 = $58;
           } else {
            $60 = $56;
           }
           $59 = !($60 <= $threshold);
           if ($59) {
            break;
           }
           $61 = (($this) + 40|0);
           $62 = Math_fround(HEAPF32[$61>>2]);
           $63 = Math_fround($62 + Math_fround(-1.0));
           $64 = $63 < Math_fround(0.0);
           if ($64) {
            $65 = Math_fround(-$63);
            $67 = $65;
           } else {
            $67 = $63;
           }
           $66 = !($67 <= $threshold);
           if ($66) {
            break;
           }
           $68 = (($this) + 56|0);
           $69 = Math_fround(HEAPF32[$68>>2]);
           $70 = $69 < Math_fround(0.0);
           if ($70) {
            $71 = Math_fround(-$69);
            $73 = $71;
           } else {
            $73 = $69;
           }
           $72 = !($73 <= $threshold);
           if ($72) {
            break;
           }
           $74 = (($this) + 12|0);
           $75 = Math_fround(HEAPF32[$74>>2]);
           $76 = $75 < Math_fround(0.0);
           if ($76) {
            $77 = Math_fround(-$75);
            $79 = $77;
           } else {
            $79 = $75;
           }
           $78 = !($79 <= $threshold);
           if ($78) {
            break;
           }
           $80 = (($this) + 28|0);
           $81 = Math_fround(HEAPF32[$80>>2]);
           $82 = $81 < Math_fround(0.0);
           if ($82) {
            $83 = Math_fround(-$81);
            $85 = $83;
           } else {
            $85 = $81;
           }
           $84 = !($85 <= $threshold);
           if ($84) {
            break;
           }
           $86 = (($this) + 44|0);
           $87 = Math_fround(HEAPF32[$86>>2]);
           $88 = $87 < Math_fround(0.0);
           if ($88) {
            $89 = Math_fround(-$87);
            $91 = $89;
           } else {
            $91 = $87;
           }
           $90 = !($91 <= $threshold);
           if ($90) {
            break;
           }
           $92 = (($this) + 60|0);
           $93 = Math_fround(HEAPF32[$92>>2]);
           $94 = Math_fround($93 + Math_fround(-1.0));
           $95 = $94 < Math_fround(0.0);
           if ($95) {
            $96 = Math_fround(-$94);
            $98 = $96;
           } else {
            $98 = $94;
           }
           $97 = !($98 <= $threshold);
           if ($97) {
            break;
           } else {
            $$0 = 1;
           }
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK10Matrix4x4f14GetDeterminantEv($this) {
 $this = $this|0;
 var $0 = Math_fround(0), $1 = 0.0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = Math_fround(0), $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0.0, $14 = 0, $15 = Math_fround(0), $16 = 0.0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0.0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0.0, $23 = 0, $24 = Math_fround(0), $25 = 0.0, $26 = 0, $27 = Math_fround(0), $28 = 0.0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0.0, $32 = 0, $33 = Math_fround(0), $34 = 0.0, $35 = 0;
 var $36 = Math_fround(0), $37 = 0.0, $38 = 0, $39 = Math_fround(0), $4 = 0.0, $40 = 0.0, $41 = 0, $42 = Math_fround(0), $43 = 0.0, $44 = 0, $45 = Math_fround(0), $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0;
 var $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = Math_fround(0), $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0;
 var $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = Math_fround(0);
 var $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$this>>2]);
 $1 = +$0;
 $2 = (($this) + 16|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = +$3;
 $5 = (($this) + 32|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = +$6;
 $8 = (($this) + 48|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = +$9;
 $11 = (($this) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = +$12;
 $14 = (($this) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = +$15;
 $17 = (($this) + 36|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = +$18;
 $20 = (($this) + 52|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = +$21;
 $23 = (($this) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = +$24;
 $26 = (($this) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = +$27;
 $29 = (($this) + 40|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = +$30;
 $32 = (($this) + 56|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = +$33;
 $35 = (($this) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = +$36;
 $38 = (($this) + 28|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = +$39;
 $41 = (($this) + 44|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = +$42;
 $44 = (($this) + 60|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = +$45;
 $47 = $10 * $19;
 $48 = $47 * $28;
 $49 = $48 * $37;
 $50 = $7 * $22;
 $51 = $50 * $28;
 $52 = $51 * $37;
 $53 = $49 - $52;
 $54 = $10 * $16;
 $55 = $54 * $31;
 $56 = $55 * $37;
 $57 = $53 - $56;
 $58 = $4 * $22;
 $59 = $58 * $31;
 $60 = $59 * $37;
 $61 = $60 + $57;
 $62 = $7 * $16;
 $63 = $62 * $34;
 $64 = $63 * $37;
 $65 = $64 + $61;
 $66 = $4 * $19;
 $67 = $66 * $34;
 $68 = $67 * $37;
 $69 = $65 - $68;
 $70 = $47 * $25;
 $71 = $70 * $40;
 $72 = $69 - $71;
 $73 = $50 * $25;
 $74 = $73 * $40;
 $75 = $74 + $72;
 $76 = $10 * $13;
 $77 = $76 * $31;
 $78 = $77 * $40;
 $79 = $78 + $75;
 $80 = $1 * $22;
 $81 = $80 * $31;
 $82 = $81 * $40;
 $83 = $79 - $82;
 $84 = $7 * $13;
 $85 = $84 * $34;
 $86 = $85 * $40;
 $87 = $83 - $86;
 $88 = $1 * $19;
 $89 = $88 * $34;
 $90 = $89 * $40;
 $91 = $90 + $87;
 $92 = $54 * $25;
 $93 = $92 * $43;
 $94 = $93 + $91;
 $95 = $58 * $25;
 $96 = $95 * $43;
 $97 = $94 - $96;
 $98 = $76 * $28;
 $99 = $98 * $43;
 $100 = $97 - $99;
 $101 = $80 * $28;
 $102 = $101 * $43;
 $103 = $102 + $100;
 $104 = $4 * $13;
 $105 = $104 * $34;
 $106 = $105 * $43;
 $107 = $106 + $103;
 $108 = $1 * $16;
 $109 = $108 * $34;
 $110 = $109 * $43;
 $111 = $107 - $110;
 $112 = $62 * $25;
 $113 = $112 * $46;
 $114 = $111 - $113;
 $115 = $66 * $25;
 $116 = $115 * $46;
 $117 = $116 + $114;
 $118 = $84 * $28;
 $119 = $118 * $46;
 $120 = $119 + $117;
 $121 = $88 * $28;
 $122 = $121 * $46;
 $123 = $120 - $122;
 $124 = $104 * $31;
 $125 = $124 * $46;
 $126 = $123 - $125;
 $127 = $108 * $31;
 $128 = $127 * $46;
 $129 = $128 + $126;
 STACKTOP = sp;return (+$129);
}
function __ZN10Matrix4x4fmLERKS_($this,$inM1) {
 $this = $this|0;
 $inM1 = $inM1|0;
 var $tmp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmp = sp;
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($this,$inM1,$tmp);
 dest=$this+0|0; src=$tmp+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return ($this|0);
}
function __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($lhs,$rhs,$res) {
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 $res = $res|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $8 = Math_fround(0), $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$rhs>>2]);
 $1 = (($rhs) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($rhs) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($rhs) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($rhs) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($rhs) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($rhs) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($rhs) + 28|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($rhs) + 32|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($rhs) + 36|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($rhs) + 40|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($rhs) + 44|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($rhs) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($rhs) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($rhs) + 56|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($rhs) + 60|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $i$01 = 0;
 while(1) {
  $31 = (($lhs) + ($i$01<<2)|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($32 * $0);
  $34 = (($i$01) + 4)|0;
  $35 = (($lhs) + ($34<<2)|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($36 * $2);
  $38 = Math_fround($33 + $37);
  $39 = (($i$01) + 8)|0;
  $40 = (($lhs) + ($39<<2)|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($41 * $4);
  $43 = Math_fround($38 + $42);
  $44 = (($i$01) + 12)|0;
  $45 = (($lhs) + ($44<<2)|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($46 * $6);
  $48 = Math_fround($43 + $47);
  $49 = (($res) + ($i$01<<2)|0);
  HEAPF32[$49>>2] = $48;
  $50 = Math_fround($32 * $8);
  $51 = Math_fround($36 * $10);
  $52 = Math_fround($50 + $51);
  $53 = Math_fround($41 * $12);
  $54 = Math_fround($52 + $53);
  $55 = Math_fround($46 * $14);
  $56 = Math_fround($54 + $55);
  $57 = (($res) + ($34<<2)|0);
  HEAPF32[$57>>2] = $56;
  $58 = Math_fround($32 * $16);
  $59 = Math_fround($36 * $18);
  $60 = Math_fround($58 + $59);
  $61 = Math_fround($41 * $20);
  $62 = Math_fround($60 + $61);
  $63 = Math_fround($46 * $22);
  $64 = Math_fround($62 + $63);
  $65 = (($res) + ($39<<2)|0);
  HEAPF32[$65>>2] = $64;
  $66 = Math_fround($32 * $24);
  $67 = Math_fround($36 * $26);
  $68 = Math_fround($66 + $67);
  $69 = Math_fround($41 * $28);
  $70 = Math_fround($68 + $69);
  $71 = Math_fround($46 * $30);
  $72 = Math_fround($70 + $71);
  $73 = (($res) + ($44<<2)|0);
  HEAPF32[$73>>2] = $72;
  $74 = (($i$01) + 1)|0;
  $exitcond = ($74|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $74;
  }
 }
 STACKTOP = sp;return;
}
function __Z19MultiplyMatrices3x4RK10Matrix4x4fS1_RS_($lhs,$rhs,$res) {
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 $res = $res|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($rhs) + 4|0);
 $1 = (($rhs) + 8|0);
 $2 = (($rhs) + 16|0);
 $3 = (($rhs) + 20|0);
 $4 = (($rhs) + 24|0);
 $5 = (($rhs) + 32|0);
 $6 = (($rhs) + 36|0);
 $7 = (($rhs) + 40|0);
 $8 = (($rhs) + 48|0);
 $9 = (($rhs) + 52|0);
 $10 = (($rhs) + 56|0);
 $i$01 = 0;
 while(1) {
  $11 = (($lhs) + ($i$01<<2)|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround(HEAPF32[$rhs>>2]);
  $14 = Math_fround($12 * $13);
  $15 = (($i$01) + 4)|0;
  $16 = (($lhs) + ($15<<2)|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround(HEAPF32[$0>>2]);
  $19 = Math_fround($17 * $18);
  $20 = Math_fround($14 + $19);
  $21 = (($i$01) + 8)|0;
  $22 = (($lhs) + ($21<<2)|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround(HEAPF32[$1>>2]);
  $25 = Math_fround($23 * $24);
  $26 = Math_fround($20 + $25);
  $27 = (($res) + ($i$01<<2)|0);
  HEAPF32[$27>>2] = $26;
  $28 = Math_fround(HEAPF32[$11>>2]);
  $29 = Math_fround(HEAPF32[$2>>2]);
  $30 = Math_fround($28 * $29);
  $31 = Math_fround(HEAPF32[$16>>2]);
  $32 = Math_fround(HEAPF32[$3>>2]);
  $33 = Math_fround($31 * $32);
  $34 = Math_fround($30 + $33);
  $35 = Math_fround(HEAPF32[$22>>2]);
  $36 = Math_fround(HEAPF32[$4>>2]);
  $37 = Math_fround($35 * $36);
  $38 = Math_fround($34 + $37);
  $39 = (($res) + ($15<<2)|0);
  HEAPF32[$39>>2] = $38;
  $40 = Math_fround(HEAPF32[$11>>2]);
  $41 = Math_fround(HEAPF32[$5>>2]);
  $42 = Math_fround($40 * $41);
  $43 = Math_fround(HEAPF32[$16>>2]);
  $44 = Math_fround(HEAPF32[$6>>2]);
  $45 = Math_fround($43 * $44);
  $46 = Math_fround($42 + $45);
  $47 = Math_fround(HEAPF32[$22>>2]);
  $48 = Math_fround(HEAPF32[$7>>2]);
  $49 = Math_fround($47 * $48);
  $50 = Math_fround($46 + $49);
  $51 = (($res) + ($21<<2)|0);
  HEAPF32[$51>>2] = $50;
  $52 = Math_fround(HEAPF32[$11>>2]);
  $53 = Math_fround(HEAPF32[$8>>2]);
  $54 = Math_fround($52 * $53);
  $55 = Math_fround(HEAPF32[$16>>2]);
  $56 = Math_fround(HEAPF32[$9>>2]);
  $57 = Math_fround($55 * $56);
  $58 = Math_fround($54 + $57);
  $59 = Math_fround(HEAPF32[$22>>2]);
  $60 = Math_fround(HEAPF32[$10>>2]);
  $61 = Math_fround($59 * $60);
  $62 = Math_fround($58 + $61);
  $63 = (($i$01) + 12)|0;
  $64 = (($lhs) + ($63<<2)|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = Math_fround($65 + $62);
  $67 = (($res) + ($63<<2)|0);
  HEAPF32[$67>>2] = $66;
  $68 = (($i$01) + 1)|0;
  $exitcond = ($68|0)==(3);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $68;
  }
 }
 $69 = (($res) + 12|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 $70 = (($res) + 28|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($res) + 44|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($res) + 60|0);
 HEAPF32[$72>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4f8SetBasisERK8Vector3fS2_S2_($this,$inX,$inY,$inZ) {
 $this = $this|0;
 $inX = $inX|0;
 $inY = $inY|0;
 $inZ = $inZ|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inX>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = Math_fround(HEAPF32[$inY>>2]);
 $2 = (($this) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = Math_fround(HEAPF32[$inZ>>2]);
 $4 = (($this) + 32|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($this) + 48|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($inX) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 4|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($inY) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 20|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($inZ) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 36|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($this) + 52|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($inX) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 8|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($inY) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 24|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($inZ) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 40|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($this) + 56|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($this) + 12|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 28|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 44|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($this) + 60|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f18SetBasisTransposedERK8Vector3fS2_S2_($this,$inX,$inY,$inZ) {
 $this = $this|0;
 $inX = $inX|0;
 $inY = $inY|0;
 $inZ = $inZ|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inX>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = Math_fround(HEAPF32[$inY>>2]);
 $2 = (($this) + 4|0);
 HEAPF32[$2>>2] = $1;
 $3 = Math_fround(HEAPF32[$inZ>>2]);
 $4 = (($this) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($this) + 12|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($inX) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 16|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($inY) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 20|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($inZ) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 24|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($this) + 28|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($inX) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 32|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($inY) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 36|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($inZ) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 40|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($this) + 44|0);
 $26 = (($this) + 60|0);
 ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;
 HEAPF32[$26>>2] = Math_fround(1.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f30SetPositionAndOrthoNormalBasisERK8Vector3fS2_S2_S2_($this,$inPosition,$inX,$inY,$inZ) {
 $this = $this|0;
 $inPosition = $inPosition|0;
 $inX = $inX|0;
 $inY = $inY|0;
 $inZ = $inZ|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inX>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = Math_fround(HEAPF32[$inY>>2]);
 $2 = (($this) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = Math_fround(HEAPF32[$inZ>>2]);
 $4 = (($this) + 32|0);
 HEAPF32[$4>>2] = $3;
 $5 = Math_fround(HEAPF32[$inPosition>>2]);
 $6 = (($this) + 48|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($inX) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 4|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($inY) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($this) + 20|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($inZ) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 36|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($inPosition) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 52|0);
 HEAPF32[$18>>2] = $17;
 $19 = (($inX) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 8|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($inY) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 24|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($inZ) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($this) + 40|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($inPosition) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($this) + 56|0);
 HEAPF32[$30>>2] = $29;
 $31 = (($this) + 12|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($this) + 28|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($this) + 44|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($this) + 60|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f8SetScaleERK8Vector3f($this,$inScale) {
 $this = $this|0;
 $inScale = $inScale|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inScale>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = (($this) + 16|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 32|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 48|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($this) + 4|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($inScale) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 20|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($this) + 36|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 52|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 8|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 24|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($inScale) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 40|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($this) + 56|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 12|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 28|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($this) + 44|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 60|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f5ScaleERK8Vector3f($this,$inScale) {
 $this = $this|0;
 $inScale = $inScale|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$inScale>>2]);
 $1 = Math_fround(HEAPF32[$this>>2]);
 $2 = Math_fround($0 * $1);
 HEAPF32[$this>>2] = $2;
 $3 = Math_fround(HEAPF32[$inScale>>2]);
 $4 = (($this) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($3 * $5);
 HEAPF32[$4>>2] = $6;
 $7 = Math_fround(HEAPF32[$inScale>>2]);
 $8 = (($this) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 * $9);
 HEAPF32[$8>>2] = $10;
 $11 = Math_fround(HEAPF32[$inScale>>2]);
 $12 = (($this) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 * $13);
 HEAPF32[$12>>2] = $14;
 $15 = (($inScale) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 HEAPF32[$17>>2] = $19;
 $20 = Math_fround(HEAPF32[$15>>2]);
 $21 = (($this) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 HEAPF32[$21>>2] = $23;
 $24 = Math_fround(HEAPF32[$15>>2]);
 $25 = (($this) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($24 * $26);
 HEAPF32[$25>>2] = $27;
 $28 = Math_fround(HEAPF32[$15>>2]);
 $29 = (($this) + 28|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 * $30);
 HEAPF32[$29>>2] = $31;
 $32 = (($inScale) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 * $35);
 HEAPF32[$34>>2] = $36;
 $37 = Math_fround(HEAPF32[$32>>2]);
 $38 = (($this) + 36|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($37 * $39);
 HEAPF32[$38>>2] = $40;
 $41 = Math_fround(HEAPF32[$32>>2]);
 $42 = (($this) + 40|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($41 * $43);
 HEAPF32[$42>>2] = $44;
 $45 = Math_fround(HEAPF32[$32>>2]);
 $46 = (($this) + 44|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 * $47);
 HEAPF32[$46>>2] = $48;
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f9TranslateERK8Vector3f($this,$inTrans) {
 $this = $this|0;
 $inTrans = $inTrans|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$this>>2]);
 $1 = Math_fround(HEAPF32[$inTrans>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($this) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($inTrans) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($this) + 32|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($inTrans) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($this) + 48|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + $14);
 HEAPF32[$15>>2] = $17;
 $18 = (($this) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround(HEAPF32[$inTrans>>2]);
 $21 = Math_fround($19 * $20);
 $22 = (($this) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(HEAPF32[$5>>2]);
 $25 = Math_fround($23 * $24);
 $26 = Math_fround($21 + $25);
 $27 = (($this) + 36|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround(HEAPF32[$11>>2]);
 $30 = Math_fround($28 * $29);
 $31 = Math_fround($26 + $30);
 $32 = (($this) + 52|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 + $31);
 HEAPF32[$32>>2] = $34;
 $35 = (($this) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround(HEAPF32[$inTrans>>2]);
 $38 = Math_fround($36 * $37);
 $39 = (($this) + 24|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround(HEAPF32[$5>>2]);
 $42 = Math_fround($40 * $41);
 $43 = Math_fround($38 + $42);
 $44 = (($this) + 40|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround(HEAPF32[$11>>2]);
 $47 = Math_fround($45 * $46);
 $48 = Math_fround($43 + $47);
 $49 = (($this) + 56|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($50 + $48);
 HEAPF32[$49>>2] = $51;
 $52 = (($this) + 12|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround(HEAPF32[$inTrans>>2]);
 $55 = Math_fround($53 * $54);
 $56 = (($this) + 28|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround(HEAPF32[$5>>2]);
 $59 = Math_fround($57 * $58);
 $60 = Math_fround($55 + $59);
 $61 = (($this) + 44|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = Math_fround(HEAPF32[$11>>2]);
 $64 = Math_fround($62 * $63);
 $65 = Math_fround($60 + $64);
 $66 = (($this) + 60|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 + $65);
 HEAPF32[$66>>2] = $68;
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f12SetTranslateERK8Vector3f($this,$inTrans) {
 $this = $this|0;
 $inTrans = $inTrans|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = Math_fround(1.0);
 $0 = (($this) + 16|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 32|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = Math_fround(HEAPF32[$inTrans>>2]);
 $3 = (($this) + 48|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($this) + 4|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 20|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($this) + 36|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($inTrans) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 52|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($this) + 8|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 24|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 40|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($inTrans) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 56|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($this) + 12|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 28|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($this) + 44|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 60|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f14SetPerspectiveEffffff($this,$l,$r,$t,$b,$zNear,$zFar) {
 $this = $this|0;
 $l = Math_fround($l);
 $r = Math_fround($r);
 $t = Math_fround($t);
 $b = Math_fround($b);
 $zNear = Math_fround($zNear);
 $zFar = Math_fround($zFar);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($zNear * Math_fround(2.0));
 $1 = Math_fround($r - $l);
 $2 = Math_fround($0 / $1);
 HEAPF32[$this>>2] = $2;
 $3 = (($this) + 16|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = Math_fround($l + $r);
 $5 = Math_fround($4 / $1);
 $6 = (($this) + 32|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 48|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 4|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = Math_fround($t - $b);
 $10 = Math_fround($0 / $9);
 $11 = (($this) + 20|0);
 HEAPF32[$11>>2] = $10;
 $12 = Math_fround($t + $b);
 $13 = Math_fround($12 / $9);
 $14 = (($this) + 36|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($this) + 52|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 8|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 24|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = Math_fround($zNear + $zFar);
 $19 = Math_fround(-$18);
 $20 = Math_fround($zFar - $zNear);
 $21 = Math_fround($19 / $20);
 $22 = (($this) + 40|0);
 HEAPF32[$22>>2] = $21;
 $23 = Math_fround($zFar * Math_fround(2.0));
 $24 = Math_fround($23 * $zNear);
 $25 = Math_fround(-$24);
 $26 = Math_fround($25 / $20);
 $27 = (($this) + 56|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($this) + 12|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($this) + 28|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($this) + 44|0);
 HEAPF32[$30>>2] = Math_fround(-1.0);
 $31 = (($this) + 60|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f14SetPerspectiveEffff($this,$fovy,$aspect,$zNear,$zFar) {
 $this = $this|0;
 $fovy = Math_fround($fovy);
 $aspect = Math_fround($aspect);
 $zNear = Math_fround($zNear);
 $zFar = Math_fround($zFar);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($fovy * Math_fround(0.5));
 $1 = Math_fround($0 / Math_fround(360.0));
 $2 = Math_fround($1 * Math_fround(2.0));
 $3 = Math_fround($2 * Math_fround(3.14159274101257324219));
 $4 = (Math_fround(+(Math_cos((+$3)))));
 $5 = (Math_fround(+(Math_sin((+$3)))));
 $6 = Math_fround($4 / $5);
 $7 = Math_fround($zNear - $zFar);
 $8 = Math_fround($6 / $aspect);
 HEAPF32[$this>>2] = $8;
 $9 = (($this) + 16|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 32|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 48|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 4|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 20|0);
 HEAPF32[$13>>2] = $6;
 $14 = (($this) + 36|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($this) + 52|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 8|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 24|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = Math_fround($zNear + $zFar);
 $19 = Math_fround($18 / $7);
 $20 = (($this) + 40|0);
 HEAPF32[$20>>2] = $19;
 $21 = Math_fround($zNear * Math_fround(2.0));
 $22 = Math_fround($21 * $zFar);
 $23 = Math_fround($22 / $7);
 $24 = (($this) + 56|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($this) + 12|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($this) + 28|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 44|0);
 HEAPF32[$27>>2] = Math_fround(-1.0);
 $28 = (($this) + 60|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f19SetPerspectiveCotanEfff($this,$cotangent,$zNear,$zFar) {
 $this = $this|0;
 $cotangent = Math_fround($cotangent);
 $zNear = Math_fround($zNear);
 $zFar = Math_fround($zFar);
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($zNear - $zFar);
 HEAPF32[$this>>2] = $cotangent;
 $1 = (($this) + 16|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 32|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 48|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($this) + 4|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 20|0);
 HEAPF32[$5>>2] = $cotangent;
 $6 = (($this) + 36|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 52|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 24|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = Math_fround($zNear + $zFar);
 $11 = Math_fround($10 / $0);
 $12 = (($this) + 40|0);
 HEAPF32[$12>>2] = $11;
 $13 = Math_fround($zNear * Math_fround(2.0));
 $14 = Math_fround($13 * $zFar);
 $15 = Math_fround($14 / $0);
 $16 = (($this) + 56|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($this) + 12|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($this) + 28|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 44|0);
 HEAPF32[$19>>2] = Math_fround(-1.0);
 $20 = (($this) + 60|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 STACKTOP = sp;return ($this|0);
}
function __ZN10Matrix4x4f8SetOrthoEffffff($this,$left,$right,$bottom,$top,$zNear,$zFar) {
 $this = $this|0;
 $left = Math_fround($left);
 $right = Math_fround($right);
 $bottom = Math_fround($bottom);
 $top = Math_fround($top);
 $zNear = Math_fround($zNear);
 $zFar = Math_fround($zFar);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 32|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 48|0);
 $3 = (($this) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($this) + 20|0);
 $5 = (($this) + 36|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 52|0);
 $7 = (($this) + 8|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 24|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 40|0);
 $10 = (($this) + 56|0);
 $11 = (($this) + 12|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 28|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 44|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($this) + 60|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = Math_fround($right - $left);
 $16 = Math_fround($top - $bottom);
 $17 = Math_fround($zFar - $zNear);
 $18 = Math_fround(Math_fround(2.0) / $15);
 HEAPF32[$this>>2] = $18;
 $19 = Math_fround($left + $right);
 $20 = Math_fround(-$19);
 $21 = Math_fround($20 / $15);
 HEAPF32[$2>>2] = $21;
 $22 = Math_fround(Math_fround(2.0) / $16);
 HEAPF32[$4>>2] = $22;
 $23 = Math_fround($bottom + $top);
 $24 = Math_fround(-$23);
 $25 = Math_fround($24 / $16);
 HEAPF32[$6>>2] = $25;
 $26 = Math_fround(Math_fround(-2.0) / $17);
 HEAPF32[$9>>2] = $26;
 $27 = Math_fround($zNear + $zFar);
 $28 = Math_fround(-$27);
 $29 = Math_fround($28 / $17);
 HEAPF32[$10>>2] = $29;
 STACKTOP = sp;return ($this|0);
}
function __Z20ComputeTransformTypeRK10Matrix4x4ff($matrix,$epsilon) {
 $matrix = $matrix|0;
 $epsilon = Math_fround($epsilon);
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = 0.0, $53 = 0.0, $54 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $transType$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$matrix>>2]);
 $1 = (($matrix) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($matrix) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($0 * $0);
 $6 = Math_fround($2 * $2);
 $7 = Math_fround($5 + $6);
 $8 = Math_fround($4 * $4);
 $9 = Math_fround($7 + $8);
 $10 = (Math_fround(Math_sqrt((Math_fround($9)))));
 $11 = (($matrix) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($matrix) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($matrix) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($12 * $12);
 $18 = Math_fround($14 * $14);
 $19 = Math_fround($17 + $18);
 $20 = Math_fround($16 * $16);
 $21 = Math_fround($19 + $20);
 $22 = (Math_fround(Math_sqrt((Math_fround($21)))));
 $23 = (($matrix) + 32|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($matrix) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($matrix) + 40|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($24 * $24);
 $30 = Math_fround($26 * $26);
 $31 = Math_fround($29 + $30);
 $32 = Math_fround($28 * $28);
 $33 = Math_fround($31 + $32);
 $34 = (Math_fround(Math_sqrt((Math_fround($33)))));
 $35 = $22 < $10;
 $36 = $35 ? $22 : $10;
 $37 = $34 < $36;
 $38 = $37 ? $34 : $36;
 $39 = $10 < $22;
 $40 = $39 ? $22 : $10;
 $41 = $40 < $34;
 $42 = $41 ? $34 : $40;
 $43 = +$38;
 $44 = +$epsilon;
 $45 = 1.0 - $44;
 $46 = $43 < $45;
 if (!($46)) {
  $47 = +$42;
  $48 = $44 + 1.0;
  $49 = $47 > $48;
  if (!($49)) {
   $transType$0 = 0;
   STACKTOP = sp;return ($transType$0|0);
  }
 }
 $50 = $38 != Math_fround(0.0);
 if ($50) {
  $51 = Math_fround($42 / $38);
  $52 = +$51;
  $53 = $44 + 1.0;
  $54 = $52 < $53;
  if ($54) {
   $transType$0 = 1;
   STACKTOP = sp;return ($transType$0|0);
  }
 }
 $transType$0 = 2;
 STACKTOP = sp;return ($transType$0|0);
}
function __Z20InvertMatrix4x4_FullPKfPf($m,$out) {
 $m = $m|0;
 $out = $out|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = 0;
 var $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0;
 var $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0);
 var $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = 0, $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0;
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = 0, $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0);
 var $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0);
 var $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0);
 var $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0);
 var $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0);
 var $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = Math_fround(0), $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0);
 var $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0);
 var $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = 0, $456 = 0, $457 = 0;
 var $458 = Math_fround(0), $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = 0, $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = Math_fround(0), $473 = 0, $474 = Math_fround(0), $475 = 0;
 var $476 = Math_fround(0), $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0;
 var $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0;
 var $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $r0$0 = 0, $r1$0 = 0, $r1$1 = 0, $r1$2 = 0, $r2$0 = 0, $r2$1 = 0, $r2$2 = 0, $r2$3 = 0, $r2$4 = 0, $r3$0 = 0, $r3$1 = 0, $r3$2 = 0, $wtmp = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $wtmp = sp;
 $0 = (($wtmp) + 32|0);
 $1 = (($wtmp) + 64|0);
 $2 = (($wtmp) + 96|0);
 $3 = Math_fround(HEAPF32[$m>>2]);
 HEAPF32[$wtmp>>2] = $3;
 $4 = (($m) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($wtmp) + 4|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($m) + 32|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($wtmp) + 8|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($m) + 48|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($wtmp) + 12|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($wtmp) + 16|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($wtmp) + 28|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($wtmp) + 24|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($wtmp) + 20|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($m) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$0>>2] = $18;
 $19 = (($m) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($wtmp) + 36|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($m) + 36|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($wtmp) + 40|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($m) + 52|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($wtmp) + 44|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($wtmp) + 52|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($wtmp) + 60|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($wtmp) + 56|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($wtmp) + 48|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($m) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$1>>2] = $33;
 $34 = (($m) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($wtmp) + 68|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($m) + 40|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($wtmp) + 72|0);
 HEAPF32[$39>>2] = $38;
 $40 = (($m) + 56|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($wtmp) + 76|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($wtmp) + 88|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 $44 = (($wtmp) + 92|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($wtmp) + 84|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($wtmp) + 80|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($m) + 12|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$2>>2] = $48;
 $49 = (($m) + 28|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($wtmp) + 100|0);
 HEAPF32[$51>>2] = $50;
 $52 = (($m) + 44|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($wtmp) + 104|0);
 HEAPF32[$54>>2] = $53;
 $55 = (($m) + 60|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($wtmp) + 108|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($wtmp) + 124|0);
 HEAPF32[$58>>2] = Math_fround(1.0);
 $59 = (($wtmp) + 120|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($wtmp) + 116|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($wtmp) + 112|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = $48 < Math_fround(0.0);
 if ($62) {
  $63 = Math_fround(-$48);
  $67 = $63;
 } else {
  $67 = $48;
 }
 $64 = $33 < Math_fround(0.0);
 if ($64) {
  $65 = Math_fround(-$33);
  $68 = $65;
 } else {
  $68 = $33;
 }
 $66 = $67 > $68;
 $r2$0 = $66 ? $2 : $1;
 $r3$0 = $66 ? $1 : $2;
 $69 = Math_fround(HEAPF32[$r2$0>>2]);
 $70 = $69 < Math_fround(0.0);
 if ($70) {
  $71 = Math_fround(-$69);
  $75 = $71;
 } else {
  $75 = $69;
 }
 $72 = $18 < Math_fround(0.0);
 if ($72) {
  $73 = Math_fround(-$18);
  $76 = $73;
 } else {
  $76 = $18;
 }
 $74 = $75 > $76;
 $r1$0 = $74 ? $r2$0 : $0;
 $r2$1 = $74 ? $0 : $r2$0;
 $77 = Math_fround(HEAPF32[$r1$0>>2]);
 $78 = $77 < Math_fround(0.0);
 if ($78) {
  $79 = Math_fround(-$77);
  $83 = $79;
 } else {
  $83 = $77;
 }
 $80 = $3 < Math_fround(0.0);
 if ($80) {
  $81 = Math_fround(-$3);
  $84 = $81;
 } else {
  $84 = $3;
 }
 $82 = $83 > $84;
 $r1$1 = $82 ? $wtmp : $r1$0;
 $r0$0 = $82 ? $r1$0 : $wtmp;
 $85 = Math_fround(HEAPF32[$r0$0>>2]);
 $86 = $85 == Math_fround(0.0);
 if ($86) {
  dest=$out+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $87 = Math_fround(HEAPF32[$r1$1>>2]);
 $88 = Math_fround($87 / $85);
 $89 = Math_fround(HEAPF32[$r2$1>>2]);
 $90 = Math_fround($89 / $85);
 $91 = Math_fround(HEAPF32[$r3$0>>2]);
 $92 = Math_fround($91 / $85);
 $93 = (($r0$0) + 4|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($88 * $94);
 $96 = (($r1$1) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($97 - $95);
 HEAPF32[$96>>2] = $98;
 $99 = Math_fround($90 * $94);
 $100 = (($r2$1) + 4|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($101 - $99);
 HEAPF32[$100>>2] = $102;
 $103 = Math_fround($92 * $94);
 $104 = (($r3$0) + 4|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($105 - $103);
 HEAPF32[$104>>2] = $106;
 $107 = (($r0$0) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($88 * $108);
 $110 = (($r1$1) + 8|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($111 - $109);
 HEAPF32[$110>>2] = $112;
 $113 = Math_fround($90 * $108);
 $114 = (($r2$1) + 8|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($115 - $113);
 HEAPF32[$114>>2] = $116;
 $117 = Math_fround($92 * $108);
 $118 = (($r3$0) + 8|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($119 - $117);
 HEAPF32[$118>>2] = $120;
 $121 = (($r0$0) + 12|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround($88 * $122);
 $124 = (($r1$1) + 12|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = Math_fround($125 - $123);
 HEAPF32[$124>>2] = $126;
 $127 = Math_fround($90 * $122);
 $128 = (($r2$1) + 12|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($129 - $127);
 HEAPF32[$128>>2] = $130;
 $131 = Math_fround($92 * $122);
 $132 = (($r3$0) + 12|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($133 - $131);
 HEAPF32[$132>>2] = $134;
 $135 = (($r0$0) + 16|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = $136 != Math_fround(0.0);
 if ($137) {
  $138 = Math_fround($88 * $136);
  $139 = (($r1$1) + 16|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = Math_fround($140 - $138);
  HEAPF32[$139>>2] = $141;
  $142 = Math_fround($90 * $136);
  $143 = (($r2$1) + 16|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = Math_fround($144 - $142);
  HEAPF32[$143>>2] = $145;
  $146 = Math_fround($92 * $136);
  $147 = (($r3$0) + 16|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = Math_fround($148 - $146);
  HEAPF32[$147>>2] = $149;
 }
 $150 = (($r0$0) + 20|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = $151 != Math_fround(0.0);
 if ($152) {
  $153 = Math_fround($88 * $151);
  $154 = (($r1$1) + 20|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = Math_fround($155 - $153);
  HEAPF32[$154>>2] = $156;
  $157 = Math_fround($90 * $151);
  $158 = (($r2$1) + 20|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = Math_fround($159 - $157);
  HEAPF32[$158>>2] = $160;
  $161 = Math_fround($92 * $151);
  $162 = (($r3$0) + 20|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = Math_fround($163 - $161);
  HEAPF32[$162>>2] = $164;
 }
 $165 = (($r0$0) + 24|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = $166 != Math_fround(0.0);
 if ($167) {
  $168 = Math_fround($88 * $166);
  $169 = (($r1$1) + 24|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround($170 - $168);
  HEAPF32[$169>>2] = $171;
  $172 = Math_fround($90 * $166);
  $173 = (($r2$1) + 24|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = Math_fround($174 - $172);
  HEAPF32[$173>>2] = $175;
  $176 = Math_fround($92 * $166);
  $177 = (($r3$0) + 24|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = Math_fround($178 - $176);
  HEAPF32[$177>>2] = $179;
 }
 $180 = (($r0$0) + 28|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = $181 != Math_fround(0.0);
 if ($182) {
  $183 = Math_fround($88 * $181);
  $184 = (($r1$1) + 28|0);
  $185 = Math_fround(HEAPF32[$184>>2]);
  $186 = Math_fround($185 - $183);
  HEAPF32[$184>>2] = $186;
  $187 = Math_fround($90 * $181);
  $188 = (($r2$1) + 28|0);
  $189 = Math_fround(HEAPF32[$188>>2]);
  $190 = Math_fround($189 - $187);
  HEAPF32[$188>>2] = $190;
  $191 = Math_fround($92 * $181);
  $192 = (($r3$0) + 28|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = Math_fround($193 - $191);
  HEAPF32[$192>>2] = $194;
 }
 $195 = Math_fround(HEAPF32[$104>>2]);
 $196 = $195 < Math_fround(0.0);
 if ($196) {
  $197 = Math_fround(-$195);
  $202 = $197;
 } else {
  $202 = $195;
 }
 $198 = Math_fround(HEAPF32[$100>>2]);
 $199 = $198 < Math_fround(0.0);
 if ($199) {
  $200 = Math_fround(-$198);
  $203 = $200;
 } else {
  $203 = $198;
 }
 $201 = $202 > $203;
 $r2$2 = $201 ? $r3$0 : $r2$1;
 $r3$1 = $201 ? $r2$1 : $r3$0;
 $204 = (($r2$2) + 4|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = $205 < Math_fround(0.0);
 if ($206) {
  $207 = Math_fround(-$205);
  $212 = $207;
 } else {
  $212 = $205;
 }
 $208 = Math_fround(HEAPF32[$96>>2]);
 $209 = $208 < Math_fround(0.0);
 if ($209) {
  $210 = Math_fround(-$208);
  $213 = $210;
 } else {
  $213 = $208;
 }
 $211 = $212 > $213;
 $r1$2 = $211 ? $r2$2 : $r1$1;
 $r2$3 = $211 ? $r1$1 : $r2$2;
 $214 = (($r1$2) + 4|0);
 $215 = Math_fround(HEAPF32[$214>>2]);
 $216 = $215 == Math_fround(0.0);
 if ($216) {
  dest=$out+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $217 = (($r2$3) + 4|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 $219 = Math_fround($218 / $215);
 $220 = (($r3$1) + 4|0);
 $221 = Math_fround(HEAPF32[$220>>2]);
 $222 = Math_fround($221 / $215);
 $223 = (($r1$2) + 8|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = Math_fround($219 * $224);
 $226 = (($r2$3) + 8|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 $228 = Math_fround($227 - $225);
 HEAPF32[$226>>2] = $228;
 $229 = Math_fround(HEAPF32[$223>>2]);
 $230 = Math_fround($222 * $229);
 $231 = (($r3$1) + 8|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = Math_fround($232 - $230);
 HEAPF32[$231>>2] = $233;
 $234 = (($r1$2) + 12|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = Math_fround($219 * $235);
 $237 = (($r2$3) + 12|0);
 $238 = Math_fround(HEAPF32[$237>>2]);
 $239 = Math_fround($238 - $236);
 HEAPF32[$237>>2] = $239;
 $240 = Math_fround(HEAPF32[$234>>2]);
 $241 = Math_fround($222 * $240);
 $242 = (($r3$1) + 12|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = Math_fround($243 - $241);
 HEAPF32[$242>>2] = $244;
 $245 = (($r1$2) + 16|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = $246 != Math_fround(0.0);
 if ($247) {
  $248 = Math_fround($219 * $246);
  $249 = (($r2$3) + 16|0);
  $250 = Math_fround(HEAPF32[$249>>2]);
  $251 = Math_fround($250 - $248);
  HEAPF32[$249>>2] = $251;
  $252 = Math_fround($222 * $246);
  $253 = (($r3$1) + 16|0);
  $254 = Math_fround(HEAPF32[$253>>2]);
  $255 = Math_fround($254 - $252);
  HEAPF32[$253>>2] = $255;
 }
 $256 = (($r1$2) + 20|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = $257 != Math_fround(0.0);
 if ($258) {
  $259 = Math_fround($219 * $257);
  $260 = (($r2$3) + 20|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = Math_fround($261 - $259);
  HEAPF32[$260>>2] = $262;
  $263 = Math_fround($222 * $257);
  $264 = (($r3$1) + 20|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = Math_fround($265 - $263);
  HEAPF32[$264>>2] = $266;
 }
 $267 = (($r1$2) + 24|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = $268 != Math_fround(0.0);
 if ($269) {
  $270 = Math_fround($219 * $268);
  $271 = (($r2$3) + 24|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = Math_fround($272 - $270);
  HEAPF32[$271>>2] = $273;
  $274 = Math_fround($222 * $268);
  $275 = (($r3$1) + 24|0);
  $276 = Math_fround(HEAPF32[$275>>2]);
  $277 = Math_fround($276 - $274);
  HEAPF32[$275>>2] = $277;
 }
 $278 = (($r1$2) + 28|0);
 $279 = Math_fround(HEAPF32[$278>>2]);
 $280 = $279 != Math_fround(0.0);
 if ($280) {
  $281 = Math_fround($219 * $279);
  $282 = (($r2$3) + 28|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = Math_fround($283 - $281);
  HEAPF32[$282>>2] = $284;
  $285 = Math_fround($222 * $279);
  $286 = (($r3$1) + 28|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $288 = Math_fround($287 - $285);
  HEAPF32[$286>>2] = $288;
 }
 $289 = Math_fround(HEAPF32[$231>>2]);
 $290 = $289 < Math_fround(0.0);
 if ($290) {
  $291 = Math_fround(-$289);
  $296 = $291;
 } else {
  $296 = $289;
 }
 $292 = Math_fround(HEAPF32[$226>>2]);
 $293 = $292 < Math_fround(0.0);
 if ($293) {
  $294 = Math_fround(-$292);
  $297 = $294;
 } else {
  $297 = $292;
 }
 $295 = $296 > $297;
 $r2$4 = $295 ? $r3$1 : $r2$3;
 $r3$2 = $295 ? $r2$3 : $r3$1;
 $298 = (($r2$4) + 8|0);
 $299 = Math_fround(HEAPF32[$298>>2]);
 $300 = $299 == Math_fround(0.0);
 if ($300) {
  dest=$out+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $301 = (($r3$2) + 8|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = Math_fround($302 / $299);
 $304 = (($r2$4) + 12|0);
 $305 = Math_fround(HEAPF32[$304>>2]);
 $306 = Math_fround($303 * $305);
 $307 = (($r3$2) + 12|0);
 $308 = Math_fround(HEAPF32[$307>>2]);
 $309 = Math_fround($308 - $306);
 HEAPF32[$307>>2] = $309;
 $310 = (($r2$4) + 16|0);
 $311 = Math_fround(HEAPF32[$310>>2]);
 $312 = Math_fround($303 * $311);
 $313 = (($r3$2) + 16|0);
 $314 = Math_fround(HEAPF32[$313>>2]);
 $315 = Math_fround($314 - $312);
 HEAPF32[$313>>2] = $315;
 $316 = (($r2$4) + 20|0);
 $317 = Math_fround(HEAPF32[$316>>2]);
 $318 = Math_fround($303 * $317);
 $319 = (($r3$2) + 20|0);
 $320 = Math_fround(HEAPF32[$319>>2]);
 $321 = Math_fround($320 - $318);
 HEAPF32[$319>>2] = $321;
 $322 = (($r2$4) + 24|0);
 $323 = Math_fround(HEAPF32[$322>>2]);
 $324 = Math_fround($303 * $323);
 $325 = (($r3$2) + 24|0);
 $326 = Math_fround(HEAPF32[$325>>2]);
 $327 = Math_fround($326 - $324);
 HEAPF32[$325>>2] = $327;
 $328 = (($r2$4) + 28|0);
 $329 = Math_fround(HEAPF32[$328>>2]);
 $330 = Math_fround($303 * $329);
 $331 = (($r3$2) + 28|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = Math_fround($332 - $330);
 HEAPF32[$331>>2] = $333;
 $334 = $309 == Math_fround(0.0);
 if ($334) {
  dest=$out+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $335 = Math_fround(Math_fround(1.0) / $309);
  $336 = Math_fround($335 * $315);
  HEAPF32[$313>>2] = $336;
  $337 = Math_fround($335 * $321);
  HEAPF32[$319>>2] = $337;
  $338 = Math_fround($335 * $327);
  HEAPF32[$325>>2] = $338;
  $339 = Math_fround($335 * $333);
  HEAPF32[$331>>2] = $339;
  $340 = Math_fround(HEAPF32[$304>>2]);
  $341 = Math_fround(HEAPF32[$298>>2]);
  $342 = Math_fround(Math_fround(1.0) / $341);
  $343 = Math_fround(HEAPF32[$310>>2]);
  $344 = Math_fround($340 * $336);
  $345 = Math_fround($343 - $344);
  $346 = Math_fround($342 * $345);
  HEAPF32[$310>>2] = $346;
  $347 = Math_fround(HEAPF32[$316>>2]);
  $348 = Math_fround(HEAPF32[$319>>2]);
  $349 = Math_fround($340 * $348);
  $350 = Math_fround($347 - $349);
  $351 = Math_fround($342 * $350);
  HEAPF32[$316>>2] = $351;
  $352 = Math_fround(HEAPF32[$322>>2]);
  $353 = Math_fround(HEAPF32[$325>>2]);
  $354 = Math_fround($340 * $353);
  $355 = Math_fround($352 - $354);
  $356 = Math_fround($342 * $355);
  HEAPF32[$322>>2] = $356;
  $357 = Math_fround(HEAPF32[$328>>2]);
  $358 = Math_fround(HEAPF32[$331>>2]);
  $359 = Math_fround($340 * $358);
  $360 = Math_fround($357 - $359);
  $361 = Math_fround($342 * $360);
  HEAPF32[$328>>2] = $361;
  $362 = Math_fround(HEAPF32[$234>>2]);
  $363 = Math_fround(HEAPF32[$313>>2]);
  $364 = Math_fround($362 * $363);
  $365 = Math_fround(HEAPF32[$245>>2]);
  $366 = Math_fround($365 - $364);
  HEAPF32[$245>>2] = $366;
  $367 = Math_fround(HEAPF32[$319>>2]);
  $368 = Math_fround($362 * $367);
  $369 = Math_fround(HEAPF32[$256>>2]);
  $370 = Math_fround($369 - $368);
  HEAPF32[$256>>2] = $370;
  $371 = Math_fround(HEAPF32[$325>>2]);
  $372 = Math_fround($362 * $371);
  $373 = Math_fround(HEAPF32[$267>>2]);
  $374 = Math_fround($373 - $372);
  HEAPF32[$267>>2] = $374;
  $375 = Math_fround(HEAPF32[$331>>2]);
  $376 = Math_fround($362 * $375);
  $377 = Math_fround(HEAPF32[$278>>2]);
  $378 = Math_fround($377 - $376);
  HEAPF32[$278>>2] = $378;
  $379 = Math_fround(HEAPF32[$121>>2]);
  $380 = Math_fround(HEAPF32[$313>>2]);
  $381 = Math_fround($379 * $380);
  $382 = Math_fround(HEAPF32[$135>>2]);
  $383 = Math_fround($382 - $381);
  HEAPF32[$135>>2] = $383;
  $384 = Math_fround(HEAPF32[$319>>2]);
  $385 = Math_fround($379 * $384);
  $386 = Math_fround(HEAPF32[$150>>2]);
  $387 = Math_fround($386 - $385);
  HEAPF32[$150>>2] = $387;
  $388 = Math_fround(HEAPF32[$325>>2]);
  $389 = Math_fround($379 * $388);
  $390 = Math_fround(HEAPF32[$165>>2]);
  $391 = Math_fround($390 - $389);
  HEAPF32[$165>>2] = $391;
  $392 = Math_fround(HEAPF32[$331>>2]);
  $393 = Math_fround($379 * $392);
  $394 = Math_fround(HEAPF32[$180>>2]);
  $395 = Math_fround($394 - $393);
  HEAPF32[$180>>2] = $395;
  $396 = Math_fround(HEAPF32[$223>>2]);
  $397 = Math_fround(HEAPF32[$214>>2]);
  $398 = Math_fround(Math_fround(1.0) / $397);
  $399 = Math_fround(HEAPF32[$245>>2]);
  $400 = Math_fround(HEAPF32[$310>>2]);
  $401 = Math_fround($396 * $400);
  $402 = Math_fround($399 - $401);
  $403 = Math_fround($398 * $402);
  HEAPF32[$245>>2] = $403;
  $404 = Math_fround(HEAPF32[$256>>2]);
  $405 = Math_fround(HEAPF32[$316>>2]);
  $406 = Math_fround($396 * $405);
  $407 = Math_fround($404 - $406);
  $408 = Math_fround($398 * $407);
  HEAPF32[$256>>2] = $408;
  $409 = Math_fround(HEAPF32[$267>>2]);
  $410 = Math_fround(HEAPF32[$322>>2]);
  $411 = Math_fround($396 * $410);
  $412 = Math_fround($409 - $411);
  $413 = Math_fround($398 * $412);
  HEAPF32[$267>>2] = $413;
  $414 = Math_fround(HEAPF32[$278>>2]);
  $415 = Math_fround(HEAPF32[$328>>2]);
  $416 = Math_fround($396 * $415);
  $417 = Math_fround($414 - $416);
  $418 = Math_fround($398 * $417);
  HEAPF32[$278>>2] = $418;
  $419 = Math_fround(HEAPF32[$107>>2]);
  $420 = Math_fround(HEAPF32[$310>>2]);
  $421 = Math_fround($419 * $420);
  $422 = Math_fround(HEAPF32[$135>>2]);
  $423 = Math_fround($422 - $421);
  HEAPF32[$135>>2] = $423;
  $424 = Math_fround(HEAPF32[$316>>2]);
  $425 = Math_fround($419 * $424);
  $426 = Math_fround(HEAPF32[$150>>2]);
  $427 = Math_fround($426 - $425);
  HEAPF32[$150>>2] = $427;
  $428 = Math_fround(HEAPF32[$322>>2]);
  $429 = Math_fround($419 * $428);
  $430 = Math_fround(HEAPF32[$165>>2]);
  $431 = Math_fround($430 - $429);
  HEAPF32[$165>>2] = $431;
  $432 = Math_fround(HEAPF32[$328>>2]);
  $433 = Math_fround($419 * $432);
  $434 = Math_fround(HEAPF32[$180>>2]);
  $435 = Math_fround($434 - $433);
  HEAPF32[$180>>2] = $435;
  $436 = Math_fround(HEAPF32[$93>>2]);
  $437 = Math_fround(HEAPF32[$r0$0>>2]);
  $438 = Math_fround(Math_fround(1.0) / $437);
  $439 = Math_fround(HEAPF32[$245>>2]);
  $440 = Math_fround($436 * $439);
  $441 = Math_fround($423 - $440);
  $442 = Math_fround($438 * $441);
  HEAPF32[$135>>2] = $442;
  $443 = Math_fround(HEAPF32[$256>>2]);
  $444 = Math_fround($436 * $443);
  $445 = Math_fround($427 - $444);
  $446 = Math_fround($438 * $445);
  HEAPF32[$150>>2] = $446;
  $447 = Math_fround(HEAPF32[$267>>2]);
  $448 = Math_fround($436 * $447);
  $449 = Math_fround($431 - $448);
  $450 = Math_fround($438 * $449);
  HEAPF32[$165>>2] = $450;
  $451 = Math_fround(HEAPF32[$278>>2]);
  $452 = Math_fround($436 * $451);
  $453 = Math_fround($435 - $452);
  $454 = Math_fround($438 * $453);
  HEAPF32[$180>>2] = $454;
  HEAPF32[$out>>2] = $442;
  $455 = (($out) + 16|0);
  HEAPF32[$455>>2] = $446;
  $456 = (($out) + 32|0);
  HEAPF32[$456>>2] = $450;
  $457 = (($out) + 48|0);
  HEAPF32[$457>>2] = $454;
  $458 = Math_fround(HEAPF32[$245>>2]);
  $459 = (($out) + 4|0);
  HEAPF32[$459>>2] = $458;
  $460 = Math_fround(HEAPF32[$256>>2]);
  $461 = (($out) + 20|0);
  HEAPF32[$461>>2] = $460;
  $462 = Math_fround(HEAPF32[$267>>2]);
  $463 = (($out) + 36|0);
  HEAPF32[$463>>2] = $462;
  $464 = Math_fround(HEAPF32[$278>>2]);
  $465 = (($out) + 52|0);
  HEAPF32[$465>>2] = $464;
  $466 = Math_fround(HEAPF32[$310>>2]);
  $467 = (($out) + 8|0);
  HEAPF32[$467>>2] = $466;
  $468 = Math_fround(HEAPF32[$316>>2]);
  $469 = (($out) + 24|0);
  HEAPF32[$469>>2] = $468;
  $470 = Math_fround(HEAPF32[$322>>2]);
  $471 = (($out) + 40|0);
  HEAPF32[$471>>2] = $470;
  $472 = Math_fround(HEAPF32[$328>>2]);
  $473 = (($out) + 56|0);
  HEAPF32[$473>>2] = $472;
  $474 = Math_fround(HEAPF32[$313>>2]);
  $475 = (($out) + 12|0);
  HEAPF32[$475>>2] = $474;
  $476 = Math_fround(HEAPF32[$319>>2]);
  $477 = (($out) + 28|0);
  HEAPF32[$477>>2] = $476;
  $478 = Math_fround(HEAPF32[$325>>2]);
  $479 = (($out) + 44|0);
  HEAPF32[$479>>2] = $478;
  $480 = Math_fround(HEAPF32[$331>>2]);
  $481 = (($out) + 60|0);
  HEAPF32[$481>>2] = $480;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z25InvertMatrix4x4_General3DPKfPf($in,$out) {
 $in = $in|0;
 $out = $out|0;
 var $$ = Math_fround(0), $$0 = 0, $$1 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0;
 var $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0);
 var $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0.0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0);
 var $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $neg$1 = Math_fround(0), $neg$2 = Math_fround(0), $neg$3 = Math_fround(0), $neg$4 = Math_fround(0), $neg$5 = Math_fround(0), $pos$1 = Math_fround(0), $pos$2 = Math_fround(0), $pos$3 = Math_fround(0), $pos$4 = Math_fround(0);
 var $pos$5 = Math_fround(0), dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$in>>2]);
 $1 = (($in) + 20|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($in) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($3 * $5);
 $7 = !($6 >= Math_fround(0.0));
 $8 = Math_fround($6 + Math_fround(0.0));
 $$ = $7 ? Math_fround(0.0) : $8;
 $$1 = $7 ? $8 : Math_fround(0.0);
 $9 = (($in) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($in) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = (($in) + 32|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 * $15);
 $17 = !($16 >= Math_fround(0.0));
 if ($17) {
  $19 = Math_fround($$1 + $16);
  $neg$1 = $19;$pos$1 = $$;
 } else {
  $18 = Math_fround($$ + $16);
  $neg$1 = $$1;$pos$1 = $18;
 }
 $20 = (($in) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($in) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 * $23);
 $25 = (($in) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($24 * $26);
 $28 = !($27 >= Math_fround(0.0));
 if ($28) {
  $30 = Math_fround($neg$1 + $27);
  $neg$2 = $30;$pos$2 = $pos$1;
 } else {
  $29 = Math_fround($pos$1 + $27);
  $neg$2 = $neg$1;$pos$2 = $29;
 }
 $31 = Math_fround($21 * $2);
 $32 = Math_fround($31 * $15);
 $33 = !($32 <= Math_fround(-0.0));
 if ($33) {
  $35 = Math_fround($neg$2 - $32);
  $neg$3 = $35;$pos$3 = $pos$2;
 } else {
  $34 = Math_fround($pos$2 - $32);
  $neg$3 = $neg$2;$pos$3 = $34;
 }
 $36 = Math_fround($10 * $23);
 $37 = Math_fround($36 * $5);
 $38 = !($37 <= Math_fround(-0.0));
 if ($38) {
  $40 = Math_fround($neg$3 - $37);
  $neg$4 = $40;$pos$4 = $pos$3;
 } else {
  $39 = Math_fround($pos$3 - $37);
  $neg$4 = $neg$3;$pos$4 = $39;
 }
 $41 = Math_fround($0 * $12);
 $42 = Math_fround($41 * $26);
 $43 = !($42 <= Math_fround(-0.0));
 if ($43) {
  $45 = Math_fround($neg$4 - $42);
  $neg$5 = $45;$pos$5 = $pos$4;
 } else {
  $44 = Math_fround($pos$4 - $42);
  $neg$5 = $neg$4;$pos$5 = $44;
 }
 $46 = Math_fround($pos$5 + $neg$5);
 $47 = Math_fround($46 * $46);
 $48 = +$47;
 $49 = $48 < 1.00000000000000003849E-25;
 if ($49) {
  dest=$out+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $50 = Math_fround(Math_fround(1.0) / $46);
  $51 = Math_fround($2 * $5);
  $52 = Math_fround($12 * $26);
  $53 = Math_fround($51 - $52);
  $54 = Math_fround($50 * $53);
  HEAPF32[$out>>2] = $54;
  $55 = Math_fround(HEAPF32[$22>>2]);
  $56 = Math_fround(HEAPF32[$4>>2]);
  $57 = Math_fround($55 * $56);
  $58 = Math_fround(HEAPF32[$11>>2]);
  $59 = Math_fround(HEAPF32[$14>>2]);
  $60 = Math_fround($58 * $59);
  $61 = Math_fround($57 - $60);
  $62 = Math_fround($50 * $61);
  $63 = Math_fround(-$62);
  $64 = (($out) + 16|0);
  HEAPF32[$64>>2] = $63;
  $65 = Math_fround(HEAPF32[$22>>2]);
  $66 = Math_fround(HEAPF32[$25>>2]);
  $67 = Math_fround($65 * $66);
  $68 = Math_fround(HEAPF32[$1>>2]);
  $69 = Math_fround(HEAPF32[$14>>2]);
  $70 = Math_fround($68 * $69);
  $71 = Math_fround($67 - $70);
  $72 = Math_fround($50 * $71);
  $73 = (($out) + 32|0);
  HEAPF32[$73>>2] = $72;
  $74 = Math_fround(HEAPF32[$9>>2]);
  $75 = Math_fround(HEAPF32[$4>>2]);
  $76 = Math_fround($74 * $75);
  $77 = Math_fround(HEAPF32[$20>>2]);
  $78 = Math_fround(HEAPF32[$25>>2]);
  $79 = Math_fround($77 * $78);
  $80 = Math_fround($76 - $79);
  $81 = Math_fround($50 * $80);
  $82 = Math_fround(-$81);
  $83 = (($out) + 4|0);
  HEAPF32[$83>>2] = $82;
  $84 = Math_fround(HEAPF32[$in>>2]);
  $85 = Math_fround(HEAPF32[$4>>2]);
  $86 = Math_fround($84 * $85);
  $87 = Math_fround(HEAPF32[$20>>2]);
  $88 = Math_fround(HEAPF32[$14>>2]);
  $89 = Math_fround($87 * $88);
  $90 = Math_fround($86 - $89);
  $91 = Math_fround($50 * $90);
  $92 = (($out) + 20|0);
  HEAPF32[$92>>2] = $91;
  $93 = Math_fround(HEAPF32[$in>>2]);
  $94 = Math_fround(HEAPF32[$25>>2]);
  $95 = Math_fround($93 * $94);
  $96 = Math_fround(HEAPF32[$9>>2]);
  $97 = Math_fround(HEAPF32[$14>>2]);
  $98 = Math_fround($96 * $97);
  $99 = Math_fround($95 - $98);
  $100 = Math_fround($50 * $99);
  $101 = Math_fround(-$100);
  $102 = (($out) + 36|0);
  HEAPF32[$102>>2] = $101;
  $103 = Math_fround(HEAPF32[$9>>2]);
  $104 = Math_fround(HEAPF32[$11>>2]);
  $105 = Math_fround($103 * $104);
  $106 = Math_fround(HEAPF32[$20>>2]);
  $107 = Math_fround(HEAPF32[$1>>2]);
  $108 = Math_fround($106 * $107);
  $109 = Math_fround($105 - $108);
  $110 = Math_fround($50 * $109);
  $111 = (($out) + 8|0);
  HEAPF32[$111>>2] = $110;
  $112 = Math_fround(HEAPF32[$in>>2]);
  $113 = Math_fround(HEAPF32[$11>>2]);
  $114 = Math_fround($112 * $113);
  $115 = Math_fround(HEAPF32[$20>>2]);
  $116 = Math_fround(HEAPF32[$22>>2]);
  $117 = Math_fround($115 * $116);
  $118 = Math_fround($114 - $117);
  $119 = Math_fround($50 * $118);
  $120 = Math_fround(-$119);
  $121 = (($out) + 24|0);
  HEAPF32[$121>>2] = $120;
  $122 = Math_fround(HEAPF32[$in>>2]);
  $123 = Math_fround(HEAPF32[$1>>2]);
  $124 = Math_fround($122 * $123);
  $125 = Math_fround(HEAPF32[$9>>2]);
  $126 = Math_fround(HEAPF32[$22>>2]);
  $127 = Math_fround($125 * $126);
  $128 = Math_fround($124 - $127);
  $129 = Math_fround($50 * $128);
  $130 = (($out) + 40|0);
  HEAPF32[$130>>2] = $129;
  $131 = (($in) + 48|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = Math_fround($132 * $54);
  $134 = (($in) + 52|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = Math_fround($135 * $63);
  $137 = Math_fround($133 + $136);
  $138 = (($in) + 56|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($139 * $72);
  $141 = Math_fround($137 + $140);
  $142 = Math_fround(-$141);
  $143 = (($out) + 48|0);
  HEAPF32[$143>>2] = $142;
  $144 = Math_fround(HEAPF32[$131>>2]);
  $145 = Math_fround($144 * $82);
  $146 = Math_fround(HEAPF32[$134>>2]);
  $147 = Math_fround($146 * $91);
  $148 = Math_fround($145 + $147);
  $149 = Math_fround(HEAPF32[$138>>2]);
  $150 = Math_fround($149 * $101);
  $151 = Math_fround($148 + $150);
  $152 = Math_fround(-$151);
  $153 = (($out) + 52|0);
  HEAPF32[$153>>2] = $152;
  $154 = Math_fround(HEAPF32[$131>>2]);
  $155 = Math_fround($154 * $110);
  $156 = Math_fround(HEAPF32[$134>>2]);
  $157 = Math_fround($156 * $120);
  $158 = Math_fround($155 + $157);
  $159 = Math_fround(HEAPF32[$138>>2]);
  $160 = Math_fround($159 * $129);
  $161 = Math_fround($158 + $160);
  $162 = Math_fround(-$161);
  $163 = (($out) + 56|0);
  HEAPF32[$163>>2] = $162;
  $164 = (($out) + 12|0);
  HEAPF32[$164>>2] = Math_fround(0.0);
  $165 = (($out) + 28|0);
  HEAPF32[$165>>2] = Math_fround(0.0);
  $166 = (($out) + 44|0);
  HEAPF32[$166>>2] = Math_fround(0.0);
  $167 = (($out) + 60|0);
  HEAPF32[$167>>2] = Math_fround(1.0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10Matrix4x4f9TransposeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = 0;
 var $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 4|0);
 $2 = Math_fround(HEAPF32[$0>>2]);
 $3 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$0>>2] = $3;
 HEAPF32[$1>>2] = $2;
 $4 = (($this) + 32|0);
 $5 = (($this) + 8|0);
 $6 = Math_fround(HEAPF32[$4>>2]);
 $7 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $7;
 HEAPF32[$5>>2] = $6;
 $8 = (($this) + 48|0);
 $9 = (($this) + 12|0);
 $10 = Math_fround(HEAPF32[$8>>2]);
 $11 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $11;
 HEAPF32[$9>>2] = $10;
 $12 = (($this) + 36|0);
 $13 = (($this) + 24|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $15 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$12>>2] = $15;
 HEAPF32[$13>>2] = $14;
 $16 = (($this) + 52|0);
 $17 = (($this) + 28|0);
 $18 = Math_fround(HEAPF32[$16>>2]);
 $19 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $19;
 HEAPF32[$17>>2] = $18;
 $20 = (($this) + 56|0);
 $21 = (($this) + 44|0);
 $22 = Math_fround(HEAPF32[$20>>2]);
 $23 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $23;
 HEAPF32[$21>>2] = $22;
 STACKTOP = sp;return ($this|0);
}
function __Z13CopyMatrixREFPKfPf($lhs,$res) {
 $lhs = $lhs|0;
 $res = $res|0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 dest=$res+0|0; src=$lhs+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4f5SetTRERK8Vector3fRK11Quaternionf($this,$pos,$q) {
 $this = $this|0;
 $pos = $pos|0;
 $q = $q|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __Z18QuaternionToMatrixRK11QuaternionfR10Matrix4x4f($q,$this);
 $0 = Math_fround(HEAPF32[$pos>>2]);
 $1 = (($this) + 48|0);
 HEAPF32[$1>>2] = $0;
 $2 = (($pos) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 52|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($pos) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 56|0);
 HEAPF32[$7>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($this,$pos,$q,$s) {
 $this = $this|0;
 $pos = $pos|0;
 $q = $q|0;
 $s = $s|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 __Z18QuaternionToMatrixRK11QuaternionfR10Matrix4x4f($q,$this);
 $0 = Math_fround(HEAPF32[$s>>2]);
 $1 = Math_fround(HEAPF32[$this>>2]);
 $2 = Math_fround($0 * $1);
 HEAPF32[$this>>2] = $2;
 $3 = Math_fround(HEAPF32[$s>>2]);
 $4 = (($this) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($3 * $5);
 HEAPF32[$4>>2] = $6;
 $7 = Math_fround(HEAPF32[$s>>2]);
 $8 = (($this) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 * $9);
 HEAPF32[$8>>2] = $10;
 $11 = (($s) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 * $14);
 HEAPF32[$13>>2] = $15;
 $16 = Math_fround(HEAPF32[$11>>2]);
 $17 = (($this) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 HEAPF32[$17>>2] = $19;
 $20 = Math_fround(HEAPF32[$11>>2]);
 $21 = (($this) + 24|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 * $22);
 HEAPF32[$21>>2] = $23;
 $24 = (($s) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 32|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 * $27);
 HEAPF32[$26>>2] = $28;
 $29 = Math_fround(HEAPF32[$24>>2]);
 $30 = (($this) + 36|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($29 * $31);
 HEAPF32[$30>>2] = $32;
 $33 = Math_fround(HEAPF32[$24>>2]);
 $34 = (($this) + 40|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 * $35);
 HEAPF32[$34>>2] = $36;
 $37 = Math_fround(HEAPF32[$pos>>2]);
 $38 = (($this) + 48|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($pos) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 52|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($pos) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($this) + 56|0);
 HEAPF32[$44>>2] = $43;
 STACKTOP = sp;return;
}
function __ZN10Matrix4x4f12SetTRInverseERK8Vector3fRK11Quaternionf($this,$pos,$q) {
 $this = $this|0;
 $pos = $pos|0;
 $q = $q|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = Math_fround(HEAPF32[$q>>2]);
 $2 = Math_fround(-$1);
 $3 = (($q) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround(-$4);
 $6 = (($q) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(-$7);
 $9 = (($q) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$0>>2] = $2;
 $11 = (($0) + 4|0);
 HEAPF32[$11>>2] = $5;
 $12 = (($0) + 8|0);
 HEAPF32[$12>>2] = $8;
 $13 = (($0) + 12|0);
 HEAPF32[$13>>2] = $10;
 __Z18QuaternionToMatrixRK11QuaternionfR10Matrix4x4f($0,$this);
 $14 = Math_fround(HEAPF32[$pos>>2]);
 $15 = Math_fround(-$14);
 $16 = (($pos) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(-$17);
 $19 = (($pos) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround(-$20);
 $22 = Math_fround(HEAPF32[$this>>2]);
 $23 = Math_fround($22 * $15);
 $24 = (($this) + 16|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $18);
 $27 = Math_fround($23 + $26);
 $28 = (($this) + 32|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $21);
 $31 = Math_fround($27 + $30);
 $32 = (($this) + 48|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 + $31);
 HEAPF32[$32>>2] = $34;
 $35 = (($this) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 * $15);
 $38 = (($this) + 20|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $18);
 $41 = Math_fround($37 + $40);
 $42 = (($this) + 36|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 * $21);
 $45 = Math_fround($41 + $44);
 $46 = (($this) + 52|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 + $45);
 HEAPF32[$46>>2] = $48;
 $49 = (($this) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($50 * $15);
 $52 = (($this) + 24|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 * $18);
 $55 = Math_fround($51 + $54);
 $56 = (($this) + 40|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 * $21);
 $59 = Math_fround($55 + $58);
 $60 = (($this) + 56|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 + $59);
 HEAPF32[$60>>2] = $62;
 $63 = (($this) + 12|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 * $15);
 $66 = (($this) + 28|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 * $18);
 $69 = Math_fround($65 + $68);
 $70 = (($this) + 44|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $21);
 $73 = Math_fround($69 + $72);
 $74 = (($this) + 60|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 + $73);
 HEAPF32[$74>>2] = $76;
 STACKTOP = sp;return;
}
function __Z18TransformPoints3x3RK10Matrix4x4fPK8Vector3fPS2_i($matrix,$in,$out,$count) {
 $matrix = $matrix|0;
 $in = $in|0;
 $out = $out|0;
 $count = $count|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = Math_fround(0), $6 = 0;
 var $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $exitcond = 0, $i$01 = 0, $m = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $m = sp;
 __ZN10Matrix3x3fC2ERK10Matrix4x4f($m,$matrix);
 $0 = ($count|0)>(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = Math_fround(HEAPF32[$m>>2]);
 $2 = (($m) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($m) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($m) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($m) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($m) + 28|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($m) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($m) + 20|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($m) + 32|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $i$01 = 0;
 while(1) {
  $18 = (($in) + (($i$01*12)|0)|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($1 * $19);
  $21 = ((($in) + (($i$01*12)|0)|0) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($3 * $22);
  $24 = Math_fround($20 + $23);
  $25 = ((($in) + (($i$01*12)|0)|0) + 8|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround($5 * $26);
  $28 = Math_fround($24 + $27);
  $29 = Math_fround($19 * $7);
  $30 = Math_fround($22 * $9);
  $31 = Math_fround($29 + $30);
  $32 = Math_fround($26 * $11);
  $33 = Math_fround($31 + $32);
  $34 = Math_fround($19 * $13);
  $35 = Math_fround($22 * $15);
  $36 = Math_fround($34 + $35);
  $37 = Math_fround($26 * $17);
  $38 = Math_fround($36 + $37);
  $39 = (($out) + (($i$01*12)|0)|0);
  HEAPF32[$39>>2] = $28;
  $40 = ((($out) + (($i$01*12)|0)|0) + 4|0);
  HEAPF32[$40>>2] = $33;
  $41 = ((($out) + (($i$01*12)|0)|0) + 8|0);
  HEAPF32[$41>>2] = $38;
  $42 = (($i$01) + 1)|0;
  $exitcond = ($42|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $42;
  }
 }
 STACKTOP = sp;return;
}
function __Z18TransformPoints3x3RK10Matrix4x4fPK8Vector3fjPS2_ji($matrix,$in,$inStride,$out,$outStride,$count) {
 $matrix = $matrix|0;
 $in = $in|0;
 $inStride = $inStride|0;
 $out = $out|0;
 $outStride = $outStride|0;
 $count = $count|0;
 var $$012 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $exitcond = 0, $i$04 = 0, $m = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $m = sp;
 __ZN10Matrix3x3fC2ERK10Matrix4x4f($m,$matrix);
 $0 = ($count|0)>(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($m) + 12|0);
 $2 = (($m) + 24|0);
 $3 = (($m) + 4|0);
 $4 = (($m) + 16|0);
 $5 = (($m) + 28|0);
 $6 = (($m) + 8|0);
 $7 = (($m) + 20|0);
 $8 = (($m) + 32|0);
 $$012 = $out;$$03 = $in;$i$04 = 0;
 while(1) {
  $9 = Math_fround(HEAPF32[$m>>2]);
  $10 = Math_fround(HEAPF32[$$03>>2]);
  $11 = Math_fround($9 * $10);
  $12 = Math_fround(HEAPF32[$1>>2]);
  $13 = (($$03) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($12 * $14);
  $16 = Math_fround($11 + $15);
  $17 = Math_fround(HEAPF32[$2>>2]);
  $18 = (($$03) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($17 * $19);
  $21 = Math_fround($16 + $20);
  $22 = Math_fround(HEAPF32[$3>>2]);
  $23 = Math_fround($10 * $22);
  $24 = Math_fround(HEAPF32[$4>>2]);
  $25 = Math_fround($14 * $24);
  $26 = Math_fround($23 + $25);
  $27 = Math_fround(HEAPF32[$5>>2]);
  $28 = Math_fround($19 * $27);
  $29 = Math_fround($26 + $28);
  $30 = Math_fround(HEAPF32[$6>>2]);
  $31 = Math_fround($10 * $30);
  $32 = Math_fround(HEAPF32[$7>>2]);
  $33 = Math_fround($14 * $32);
  $34 = Math_fround($31 + $33);
  $35 = Math_fround(HEAPF32[$8>>2]);
  $36 = Math_fround($19 * $35);
  $37 = Math_fround($34 + $36);
  HEAPF32[$$012>>2] = $21;
  $38 = (($$012) + 4|0);
  HEAPF32[$38>>2] = $29;
  $39 = (($$012) + 8|0);
  HEAPF32[$39>>2] = $37;
  $40 = (($i$04) + 1)|0;
  $41 = (($$03) + ($inStride)|0);
  $42 = (($$012) + ($outStride)|0);
  $exitcond = ($40|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $$012 = $42;$$03 = $41;$i$04 = $40;
  }
 }
 STACKTOP = sp;return;
}
function __Z18TransformPoints3x4RK10Matrix4x4fPK8Vector3fjPS2_ji($matrix,$in,$inStride,$out,$outStride,$count) {
 $matrix = $matrix|0;
 $in = $in|0;
 $inStride = $inStride|0;
 $out = $out|0;
 $outStride = $outStride|0;
 $count = $count|0;
 var $$012 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)>(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($matrix) + 16|0);
 $2 = (($matrix) + 32|0);
 $3 = (($matrix) + 48|0);
 $4 = (($matrix) + 4|0);
 $5 = (($matrix) + 20|0);
 $6 = (($matrix) + 36|0);
 $7 = (($matrix) + 52|0);
 $8 = (($matrix) + 8|0);
 $9 = (($matrix) + 24|0);
 $10 = (($matrix) + 40|0);
 $11 = (($matrix) + 56|0);
 $$012 = $out;$$03 = $in;$i$04 = 0;
 while(1) {
  $12 = Math_fround(HEAPF32[$matrix>>2]);
  $13 = Math_fround(HEAPF32[$$03>>2]);
  $14 = Math_fround($12 * $13);
  $15 = Math_fround(HEAPF32[$1>>2]);
  $16 = (($$03) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($15 * $17);
  $19 = Math_fround($14 + $18);
  $20 = Math_fround(HEAPF32[$2>>2]);
  $21 = (($$03) + 8|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($20 * $22);
  $24 = Math_fround($19 + $23);
  $25 = Math_fround(HEAPF32[$3>>2]);
  $26 = Math_fround($25 + $24);
  $27 = Math_fround(HEAPF32[$4>>2]);
  $28 = Math_fround($13 * $27);
  $29 = Math_fround(HEAPF32[$5>>2]);
  $30 = Math_fround($17 * $29);
  $31 = Math_fround($28 + $30);
  $32 = Math_fround(HEAPF32[$6>>2]);
  $33 = Math_fround($22 * $32);
  $34 = Math_fround($31 + $33);
  $35 = Math_fround(HEAPF32[$7>>2]);
  $36 = Math_fround($35 + $34);
  $37 = Math_fround(HEAPF32[$8>>2]);
  $38 = Math_fround($13 * $37);
  $39 = Math_fround(HEAPF32[$9>>2]);
  $40 = Math_fround($17 * $39);
  $41 = Math_fround($38 + $40);
  $42 = Math_fround(HEAPF32[$10>>2]);
  $43 = Math_fround($22 * $42);
  $44 = Math_fround($41 + $43);
  $45 = Math_fround(HEAPF32[$11>>2]);
  $46 = Math_fround($45 + $44);
  HEAPF32[$$012>>2] = $26;
  $47 = (($$012) + 4|0);
  HEAPF32[$47>>2] = $36;
  $48 = (($$012) + 8|0);
  HEAPF32[$48>>2] = $46;
  $49 = (($i$04) + 1)|0;
  $50 = (($$03) + ($inStride)|0);
  $51 = (($$012) + ($outStride)|0);
  $exitcond = ($49|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $$012 = $51;$$03 = $50;$i$04 = $49;
  }
 }
 STACKTOP = sp;return;
}
function __Z21TransposeMatrix4x4REFPK10Matrix4x4fPS_($lhs,$res) {
 $lhs = $lhs|0;
 $res = $res|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = 0;
 var $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 dest=$res+0|0; src=$lhs+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $0 = (($res) + 16|0);
 $1 = (($res) + 4|0);
 $2 = Math_fround(HEAPF32[$0>>2]);
 $3 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$0>>2] = $3;
 HEAPF32[$1>>2] = $2;
 $4 = (($res) + 32|0);
 $5 = (($res) + 8|0);
 $6 = Math_fround(HEAPF32[$4>>2]);
 $7 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $7;
 HEAPF32[$5>>2] = $6;
 $8 = (($res) + 48|0);
 $9 = (($res) + 12|0);
 $10 = Math_fround(HEAPF32[$8>>2]);
 $11 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$8>>2] = $11;
 HEAPF32[$9>>2] = $10;
 $12 = (($res) + 36|0);
 $13 = (($res) + 24|0);
 $14 = Math_fround(HEAPF32[$12>>2]);
 $15 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$12>>2] = $15;
 HEAPF32[$13>>2] = $14;
 $16 = (($res) + 52|0);
 $17 = (($res) + 28|0);
 $18 = Math_fround(HEAPF32[$16>>2]);
 $19 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$16>>2] = $19;
 HEAPF32[$17>>2] = $18;
 $20 = (($res) + 56|0);
 $21 = (($res) + 44|0);
 $22 = Math_fround(HEAPF32[$20>>2]);
 $23 = Math_fround(HEAPF32[$21>>2]);
 HEAPF32[$20>>2] = $23;
 HEAPF32[$21>>2] = $22;
 STACKTOP = sp;return;
}
function __Z33MultiplyMatrixArrayWithBase4x4REFPK10Matrix4x4fS1_S1_PS_j($base,$a,$b,$res,$count) {
 $base = $base|0;
 $a = $a|0;
 $b = $b|0;
 $res = $res|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $exitcond = 0, $i$01 = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmp = sp;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $1 = (($a) + ($i$01<<6)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($base,$1,$tmp);
  $2 = (($b) + ($i$01<<6)|0);
  $3 = (($res) + ($i$01<<6)|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($tmp,$2,$3);
  $4 = (($i$01) + 1)|0;
  $exitcond = ($4|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __Z5SlerpRK11QuaternionfS1_f($agg$result,$q1,$q2,$t) {
 $agg$result = $agg$result|0;
 $q1 = $q1|0;
 $q2 = $q2|0;
 $t = Math_fround($t);
 var $$pn$i = Math_fround(0), $$pn2$i = Math_fround(0), $$pn3$i = Math_fround(0), $$pn4$i = Math_fround(0), $$pn5$i = Math_fround(0), $$pn6$i = Math_fround(0), $$pn7$i = Math_fround(0), $$pn8$i = Math_fround(0), $$pn9$i = Math_fround(0), $$sink$i = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0;
 var $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0);
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $dot$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$q1>>2]);
 $1 = Math_fround(HEAPF32[$q2>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($q1) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($q2) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($q1) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($q2) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($q1) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($q2) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 + $19);
 $21 = $20 < Math_fround(0.0);
 if ($21) {
  $22 = Math_fround(-$20);
  $23 = Math_fround(-$1);
  $24 = Math_fround(-$6);
  $25 = Math_fround(-$12);
  $26 = Math_fround(-$18);
  $38 = $23;$43 = $24;$48 = $25;$53 = $26;$dot$0 = $22;
 } else {
  $38 = $1;$43 = $6;$48 = $12;$53 = $18;$dot$0 = $20;
 }
 $27 = $dot$0 < Math_fround(0.949999988079071044921);
 if ($27) {
  $28 = (Math_fround(+(Math_acos((+$dot$0)))));
  $29 = (Math_fround(+(Math_sin((+$28)))));
  $30 = Math_fround(Math_fround(1.0) / $29);
  $31 = Math_fround($28 * $t);
  $32 = (Math_fround(+(Math_sin((+$31)))));
  $33 = Math_fround(Math_fround(1.0) - $t);
  $34 = Math_fround($33 * $28);
  $35 = (Math_fround(+(Math_sin((+$34)))));
  $36 = Math_fround($35 * $0);
  $37 = Math_fround($38 * $32);
  $39 = Math_fround($37 + $36);
  $40 = Math_fround($30 * $39);
  $41 = Math_fround($35 * $4);
  $42 = Math_fround($43 * $32);
  $44 = Math_fround($42 + $41);
  $45 = Math_fround($30 * $44);
  $46 = Math_fround($35 * $10);
  $47 = Math_fround($48 * $32);
  $49 = Math_fround($47 + $46);
  $50 = Math_fround($30 * $49);
  $51 = Math_fround($35 * $16);
  $52 = Math_fround($53 * $32);
  $54 = Math_fround($52 + $51);
  $55 = Math_fround($30 * $54);
  HEAPF32[$agg$result>>2] = $40;
  $56 = (($agg$result) + 4|0);
  HEAPF32[$56>>2] = $45;
  $57 = (($agg$result) + 8|0);
  HEAPF32[$57>>2] = $50;
  $58 = (($agg$result) + 12|0);
  HEAPF32[$58>>2] = $55;
  STACKTOP = sp;return;
 }
 $59 = Math_fround($38 * $0);
 $60 = Math_fround($43 * $4);
 $61 = Math_fround($59 + $60);
 $62 = Math_fround($48 * $10);
 $63 = Math_fround($61 + $62);
 $64 = Math_fround($53 * $16);
 $65 = Math_fround($63 + $64);
 $66 = $65 < Math_fround(0.0);
 if ($66) {
  $67 = Math_fround(-$38);
  $68 = Math_fround(-$43);
  $69 = Math_fround(-$48);
  $70 = Math_fround(-$53);
  $$pn7$i = $69;$$pn8$i = $68;$$pn9$i = $67;$$sink$i = $70;
 } else {
  $$pn7$i = $48;$$pn8$i = $43;$$pn9$i = $38;$$sink$i = $53;
 }
 $$pn6$i = Math_fround($$pn9$i - $0);
 $$pn5$i = Math_fround($$pn8$i - $4);
 $$pn4$i = Math_fround($$pn7$i - $10);
 $$pn3$i = Math_fround($$pn6$i * $t);
 $$pn2$i = Math_fround($$pn5$i * $t);
 $$pn$i = Math_fround($$pn4$i * $t);
 $71 = Math_fround($0 + $$pn3$i);
 $72 = Math_fround($4 + $$pn2$i);
 $73 = Math_fround($10 + $$pn$i);
 $74 = Math_fround($$sink$i - $16);
 $75 = Math_fround($74 * $t);
 $76 = Math_fround($16 + $75);
 $77 = Math_fround($71 * $71);
 $78 = Math_fround($72 * $72);
 $79 = Math_fround($78 + $77);
 $80 = Math_fround($73 * $73);
 $81 = Math_fround($80 + $79);
 $82 = Math_fround($76 * $76);
 $83 = Math_fround($82 + $81);
 $84 = (Math_fround(Math_sqrt((Math_fround($83)))));
 $85 = Math_fround($71 / $84);
 $86 = Math_fround($72 / $84);
 $87 = Math_fround($73 / $84);
 $88 = Math_fround($76 / $84);
 HEAPF32[$agg$result>>2] = $85;
 $89 = (($agg$result) + 4|0);
 HEAPF32[$89>>2] = $86;
 $90 = (($agg$result) + 8|0);
 HEAPF32[$90>>2] = $87;
 $91 = (($agg$result) + 12|0);
 HEAPF32[$91>>2] = $88;
 STACKTOP = sp;return;
}
function __Z17EulerToQuaternionRK8Vector3f($agg$result,$someEulerAngles) {
 $agg$result = $agg$result|0;
 $someEulerAngles = $someEulerAngles|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$someEulerAngles>>2]);
 $1 = Math_fround($0 * Math_fround(0.5));
 $2 = (Math_fround(+(Math_cos((+$1)))));
 $3 = (Math_fround(+(Math_sin((+$1)))));
 $4 = (($someEulerAngles) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(0.5));
 $7 = (Math_fround(+(Math_cos((+$6)))));
 $8 = (Math_fround(+(Math_sin((+$6)))));
 $9 = (($someEulerAngles) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * Math_fround(0.5));
 $12 = (Math_fround(+(Math_cos((+$11)))));
 $13 = (Math_fround(+(Math_sin((+$11)))));
 $14 = Math_fround($3 * $7);
 $15 = Math_fround($2 * Math_fround(0.0));
 $16 = Math_fround($15 + $14);
 $17 = Math_fround($8 * Math_fround(0.0));
 $18 = Math_fround($16 + $17);
 $19 = Math_fround($7 * Math_fround(0.0));
 $20 = Math_fround($2 * $8);
 $21 = Math_fround($19 + $20);
 $22 = Math_fround($3 * Math_fround(0.0));
 $23 = Math_fround($22 + $21);
 $24 = Math_fround($15 + $19);
 $25 = Math_fround($24 + Math_fround(0.0));
 $26 = Math_fround($3 * $8);
 $27 = Math_fround($25 - $26);
 $28 = Math_fround($2 * $7);
 $29 = Math_fround($28 - $22);
 $30 = Math_fround($29 - $17);
 $31 = Math_fround($30 * Math_fround(0.0));
 $32 = Math_fround($18 * $12);
 $33 = Math_fround($31 + $32);
 $34 = Math_fround($23 * $13);
 $35 = Math_fround($33 + $34);
 $36 = Math_fround($27 * Math_fround(0.0));
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($12 * $23);
 $39 = Math_fround($31 + $38);
 $40 = Math_fround($36 + $39);
 $41 = Math_fround($18 * $13);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($30 * $13);
 $44 = Math_fround($12 * $27);
 $45 = Math_fround($43 + $44);
 $46 = Math_fround($18 * Math_fround(0.0));
 $47 = Math_fround($46 + $45);
 $48 = Math_fround($23 * Math_fround(0.0));
 $49 = Math_fround($47 - $48);
 $50 = Math_fround($30 * $12);
 $51 = Math_fround($50 - $46);
 $52 = Math_fround($51 - $48);
 $53 = Math_fround($13 * $27);
 $54 = Math_fround($52 - $53);
 HEAPF32[$agg$result>>2] = $37;
 $55 = (($agg$result) + 4|0);
 HEAPF32[$55>>2] = $42;
 $56 = (($agg$result) + 8|0);
 HEAPF32[$56>>2] = $49;
 $57 = (($agg$result) + 12|0);
 HEAPF32[$57>>2] = $54;
 STACKTOP = sp;return;
}
function __Z17QuaternionToEulerRK11Quaternionf($agg$result,$quat) {
 $agg$result = $agg$result|0;
 $quat = $quat|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0);
 var $9 = Math_fround(0), $m = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $m = sp;
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $0 = (($agg$result) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($agg$result) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = Math_fround(HEAPF32[$quat>>2]);
 $3 = Math_fround($2 * Math_fround(2.0));
 $4 = (($quat) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * Math_fround(2.0));
 $7 = (($quat) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * Math_fround(2.0));
 $10 = Math_fround($2 * $3);
 $11 = Math_fround($5 * $6);
 $12 = Math_fround($8 * $9);
 $13 = Math_fround($2 * $6);
 $14 = Math_fround($2 * $9);
 $15 = Math_fround($5 * $9);
 $16 = (($quat) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($3 * $17);
 $19 = Math_fround($6 * $17);
 $20 = Math_fround($17 * $9);
 $21 = Math_fround($11 + $12);
 $22 = Math_fround(Math_fround(1.0) - $21);
 HEAPF32[$m>>2] = $22;
 $23 = Math_fround($13 + $20);
 $24 = (($m) + 4|0);
 HEAPF32[$24>>2] = $23;
 $25 = Math_fround($14 - $19);
 $26 = (($m) + 8|0);
 HEAPF32[$26>>2] = $25;
 $27 = Math_fround($13 - $20);
 $28 = (($m) + 12|0);
 HEAPF32[$28>>2] = $27;
 $29 = Math_fround($10 + $12);
 $30 = Math_fround(Math_fround(1.0) - $29);
 $31 = (($m) + 16|0);
 HEAPF32[$31>>2] = $30;
 $32 = Math_fround($15 + $18);
 $33 = (($m) + 20|0);
 HEAPF32[$33>>2] = $32;
 $34 = Math_fround($14 + $19);
 $35 = (($m) + 24|0);
 HEAPF32[$35>>2] = $34;
 $36 = Math_fround($15 - $18);
 $37 = (($m) + 28|0);
 HEAPF32[$37>>2] = $36;
 $38 = Math_fround($10 + $11);
 $39 = Math_fround(Math_fround(1.0) - $38);
 $40 = (($m) + 32|0);
 HEAPF32[$40>>2] = $39;
 (__Z13MatrixToEulerRK10Matrix3x3fR8Vector3f($m,$agg$result)|0);
 STACKTOP = sp;return;
}
function __Z18QuaternionToMatrixRK11QuaternionfR10Matrix3x3f($q,$m) {
 $q = $q|0;
 $m = $m|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$q>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($q) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = (($q) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * Math_fround(2.0));
 $8 = Math_fround($0 * $1);
 $9 = Math_fround($3 * $4);
 $10 = Math_fround($6 * $7);
 $11 = Math_fround($0 * $4);
 $12 = Math_fround($0 * $7);
 $13 = Math_fround($3 * $7);
 $14 = (($q) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($1 * $15);
 $17 = Math_fround($4 * $15);
 $18 = Math_fround($15 * $7);
 $19 = Math_fround($9 + $10);
 $20 = Math_fround(Math_fround(1.0) - $19);
 HEAPF32[$m>>2] = $20;
 $21 = Math_fround($11 + $18);
 $22 = (($m) + 4|0);
 HEAPF32[$22>>2] = $21;
 $23 = Math_fround($12 - $17);
 $24 = (($m) + 8|0);
 HEAPF32[$24>>2] = $23;
 $25 = Math_fround($11 - $18);
 $26 = (($m) + 12|0);
 HEAPF32[$26>>2] = $25;
 $27 = Math_fround($8 + $10);
 $28 = Math_fround(Math_fround(1.0) - $27);
 $29 = (($m) + 16|0);
 HEAPF32[$29>>2] = $28;
 $30 = Math_fround($13 + $16);
 $31 = (($m) + 20|0);
 HEAPF32[$31>>2] = $30;
 $32 = Math_fround($12 + $17);
 $33 = (($m) + 24|0);
 HEAPF32[$33>>2] = $32;
 $34 = Math_fround($13 - $16);
 $35 = (($m) + 28|0);
 HEAPF32[$35>>2] = $34;
 $36 = Math_fround($8 + $9);
 $37 = Math_fround(Math_fround(1.0) - $36);
 $38 = (($m) + 32|0);
 HEAPF32[$38>>2] = $37;
 STACKTOP = sp;return;
}
function __Z18QuaternionToMatrixRK11QuaternionfR10Matrix4x4f($q,$m) {
 $q = $q|0;
 $m = $m|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = Math_fround(0);
 var $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$q>>2]);
 $1 = Math_fround($0 * Math_fround(2.0));
 $2 = (($q) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * Math_fround(2.0));
 $5 = (($q) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * Math_fround(2.0));
 $8 = Math_fround($0 * $1);
 $9 = Math_fround($3 * $4);
 $10 = Math_fround($6 * $7);
 $11 = Math_fround($0 * $4);
 $12 = Math_fround($0 * $7);
 $13 = Math_fround($3 * $7);
 $14 = (($q) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($1 * $15);
 $17 = Math_fround($4 * $15);
 $18 = Math_fround($15 * $7);
 $19 = Math_fround($9 + $10);
 $20 = Math_fround(Math_fround(1.0) - $19);
 HEAPF32[$m>>2] = $20;
 $21 = Math_fround($11 + $18);
 $22 = (($m) + 4|0);
 HEAPF32[$22>>2] = $21;
 $23 = Math_fround($12 - $17);
 $24 = (($m) + 8|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($m) + 12|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = Math_fround($11 - $18);
 $27 = (($m) + 16|0);
 HEAPF32[$27>>2] = $26;
 $28 = Math_fround($8 + $10);
 $29 = Math_fround(Math_fround(1.0) - $28);
 $30 = (($m) + 20|0);
 HEAPF32[$30>>2] = $29;
 $31 = Math_fround($13 + $16);
 $32 = (($m) + 24|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($m) + 28|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = Math_fround($12 + $17);
 $35 = (($m) + 32|0);
 HEAPF32[$35>>2] = $34;
 $36 = Math_fround($13 - $16);
 $37 = (($m) + 36|0);
 HEAPF32[$37>>2] = $36;
 $38 = Math_fround($8 + $9);
 $39 = Math_fround(Math_fround(1.0) - $38);
 $40 = (($m) + 40|0);
 HEAPF32[$40>>2] = $39;
 $41 = (($m) + 44|0);
 $42 = (($m) + 60|0);
 ;HEAP32[$41+0>>2]=0|0;HEAP32[$41+4>>2]=0|0;HEAP32[$41+8>>2]=0|0;HEAP32[$41+12>>2]=0|0;
 HEAPF32[$42>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __Z18MatrixToQuaternionRK10Matrix4x4fR11Quaternionf($m,$q) {
 $m = $m|0;
 $q = $q|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = Math_fround(0);
 var $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $mat = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $mat = sp;
 $0 = Math_fround(HEAPF32[$m>>2]);
 $1 = (($m) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($m) + 32|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($m) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($m) + 20|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($m) + 36|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($m) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($m) + 24|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($m) + 40|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$mat>>2] = $0;
 $17 = (($mat) + 4|0);
 HEAPF32[$17>>2] = $6;
 $18 = (($mat) + 8|0);
 HEAPF32[$18>>2] = $12;
 $19 = (($mat) + 12|0);
 HEAPF32[$19>>2] = $2;
 $20 = (($mat) + 16|0);
 HEAPF32[$20>>2] = $8;
 $21 = (($mat) + 20|0);
 HEAPF32[$21>>2] = $14;
 $22 = (($mat) + 24|0);
 HEAPF32[$22>>2] = $4;
 $23 = (($mat) + 28|0);
 HEAPF32[$23>>2] = $10;
 $24 = (($mat) + 32|0);
 HEAPF32[$24>>2] = $16;
 __Z18MatrixToQuaternionRK10Matrix3x3fR11Quaternionf($mat,$q);
 STACKTOP = sp;return;
}
function __Z18MatrixToQuaternionRK10Matrix3x3fR11Quaternionf($kRot,$q) {
 $kRot = $kRot|0;
 $q = $q|0;
 var $$pre = Math_fround(0), $$pre2 = Math_fround(0), $$pre4 = Math_fround(0), $$pre6 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0);
 var $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $apkQuat = 0;
 var $i$0 = 0, $i$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $apkQuat = sp;
 $0 = Math_fround(HEAPF32[$kRot>>2]);
 $1 = (($kRot) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 + $2);
 $4 = (($kRot) + 32|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($3 + $5);
 $7 = $6 > Math_fround(0.0);
 if ($7) {
  $8 = Math_fround($6 + Math_fround(1.0));
  $9 = (Math_fround(Math_sqrt((Math_fround($8)))));
  $10 = Math_fround($9 * Math_fround(0.5));
  $11 = (($q) + 12|0);
  HEAPF32[$11>>2] = $10;
  $12 = Math_fround(Math_fround(0.5) / $9);
  $13 = (($kRot) + 20|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($kRot) + 28|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($14 - $16);
  $18 = Math_fround($12 * $17);
  HEAPF32[$q>>2] = $18;
  $19 = (($kRot) + 24|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($kRot) + 8|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($20 - $22);
  $24 = Math_fround($12 * $23);
  $25 = (($q) + 4|0);
  HEAPF32[$25>>2] = $24;
  $26 = (($kRot) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($kRot) + 12|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($27 - $29);
  $31 = Math_fround($12 * $30);
  $32 = (($q) + 8|0);
  HEAPF32[$32>>2] = $31;
  $100 = $24;$104 = $31;$108 = $10;$97 = $18;
  $96 = Math_fround($97 * $97);
  $98 = (($q) + 4|0);
  $99 = Math_fround($100 * $100);
  $101 = Math_fround($96 + $99);
  $102 = (($q) + 8|0);
  $103 = Math_fround($104 * $104);
  $105 = Math_fround($101 + $103);
  $106 = (($q) + 12|0);
  $107 = Math_fround($108 * $108);
  $109 = Math_fround($105 + $107);
  $110 = (Math_fround(Math_sqrt((Math_fround($109)))));
  $111 = Math_fround($97 / $110);
  $112 = Math_fround($100 / $110);
  $113 = Math_fround($104 / $110);
  $114 = Math_fround($108 / $110);
  HEAPF32[$q>>2] = $111;
  HEAPF32[$98>>2] = $112;
  HEAPF32[$102>>2] = $113;
  HEAPF32[$106>>2] = $114;
  STACKTOP = sp;return;
 } else {
  $33 = $2 > $0;
  $i$0 = $33&1;
  $34 = $33 ? 3 : 0;
  $35 = (($34) + ($i$0))|0;
  $36 = (($kRot) + ($35<<2)|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = $5 > $37;
  $i$1 = $38 ? 2 : $i$0;
  $39 = (616616 + ($i$1<<2)|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (616616 + ($40<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($i$1*3)|0;
  $44 = (($43) + ($i$1))|0;
  $45 = (($kRot) + ($44<<2)|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = ($40*3)|0;
  $48 = (($47) + ($40))|0;
  $49 = (($kRot) + ($48<<2)|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($46 - $50);
  $52 = ($42*3)|0;
  $53 = (($52) + ($42))|0;
  $54 = (($kRot) + ($53<<2)|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($51 - $55);
  $57 = Math_fround($56 + Math_fround(1.0));
  $58 = (Math_fround(Math_sqrt((Math_fround($57)))));
  HEAP32[$apkQuat>>2] = $q;
  $59 = (($apkQuat) + 4|0);
  $60 = (($q) + 4|0);
  HEAP32[$59>>2] = $60;
  $61 = (($apkQuat) + 8|0);
  $62 = (($q) + 8|0);
  HEAP32[$61>>2] = $62;
  $63 = Math_fround($58 * Math_fround(0.5));
  $64 = (($apkQuat) + ($i$1<<2)|0);
  $65 = HEAP32[$64>>2]|0;
  HEAPF32[$65>>2] = $63;
  $66 = Math_fround(Math_fround(0.5) / $58);
  $67 = (($47) + ($42))|0;
  $68 = (($kRot) + ($67<<2)|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($52) + ($40))|0;
  $71 = (($kRot) + ($70<<2)|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($69 - $72);
  $74 = Math_fround($66 * $73);
  $75 = (($q) + 12|0);
  HEAPF32[$75>>2] = $74;
  $76 = (($43) + ($40))|0;
  $77 = (($kRot) + ($76<<2)|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($47) + ($i$1))|0;
  $80 = (($kRot) + ($79<<2)|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = Math_fround($78 + $81);
  $83 = Math_fround($66 * $82);
  $84 = (($apkQuat) + ($40<<2)|0);
  $85 = HEAP32[$84>>2]|0;
  HEAPF32[$85>>2] = $83;
  $86 = (($43) + ($42))|0;
  $87 = (($kRot) + ($86<<2)|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (($52) + ($i$1))|0;
  $90 = (($kRot) + ($89<<2)|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($88 + $91);
  $93 = Math_fround($66 * $92);
  $94 = (($apkQuat) + ($42<<2)|0);
  $95 = HEAP32[$94>>2]|0;
  HEAPF32[$95>>2] = $93;
  $$pre = Math_fround(HEAPF32[$q>>2]);
  $$pre2 = Math_fround(HEAPF32[$60>>2]);
  $$pre4 = Math_fround(HEAPF32[$62>>2]);
  $$pre6 = Math_fround(HEAPF32[$75>>2]);
  $100 = $$pre2;$104 = $$pre4;$108 = $$pre6;$97 = $$pre;
  $96 = Math_fround($97 * $97);
  $98 = (($q) + 4|0);
  $99 = Math_fround($100 * $100);
  $101 = Math_fround($96 + $99);
  $102 = (($q) + 8|0);
  $103 = Math_fround($104 * $104);
  $105 = Math_fround($101 + $103);
  $106 = (($q) + 12|0);
  $107 = Math_fround($108 * $108);
  $109 = Math_fround($105 + $107);
  $110 = (Math_fround(Math_sqrt((Math_fround($109)))));
  $111 = Math_fround($97 / $110);
  $112 = Math_fround($100 / $110);
  $113 = Math_fround($104 / $110);
  $114 = Math_fround($108 / $110);
  HEAPF32[$q>>2] = $111;
  HEAPF32[$98>>2] = $112;
  HEAPF32[$102>>2] = $113;
  HEAPF32[$106>>2] = $114;
  STACKTOP = sp;return;
 }
}
function __Z24LookRotationToQuaternionRK8Vector3fS1_P11Quaternionf($viewVec,$upVec,$res) {
 $viewVec = $viewVec|0;
 $upVec = $upVec|0;
 $res = $res|0;
 var $$0 = 0, $0 = 0, $m = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $m = sp;
 $0 = (__Z20LookRotationToMatrixRK8Vector3fS1_P10Matrix3x3f($viewVec,$upVec,$m)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __Z18MatrixToQuaternionRK10Matrix3x3fR11Quaternionf($m,$res);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z20FromToQuaternionSafeRK8Vector3fS1_($agg$result,$lhs,$rhs) {
 $agg$result = $agg$result|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $m$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $m$i = sp + 24|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = Math_fround(HEAPF32[$lhs>>2]);
 $3 = Math_fround($2 * $2);
 $4 = (($lhs) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $5);
 $7 = Math_fround($3 + $6);
 $8 = (($lhs) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $9);
 $11 = Math_fround($7 + $10);
 $12 = (Math_fround(Math_sqrt((Math_fround($11)))));
 $13 = Math_fround(HEAPF32[$rhs>>2]);
 $14 = Math_fround($13 * $13);
 $15 = (($rhs) + 4|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * $16);
 $18 = Math_fround($14 + $17);
 $19 = (($rhs) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $20);
 $22 = Math_fround($18 + $21);
 $23 = (Math_fround(Math_sqrt((Math_fround($22)))));
 $24 = Math_fround(HEAPF32[616648>>2]);
 $25 = $12 < $24;
 $26 = $23 < $24;
 $or$cond = $25 | $26;
 if ($or$cond) {
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $27 = (($agg$result) + 4|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  $28 = (($agg$result) + 8|0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  $29 = (($agg$result) + 12|0);
  HEAPF32[$29>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 } else {
  ;HEAP32[$0+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$lhs+8>>2]|0;
  $30 = Math_fround(HEAPF32[$0>>2]);
  $31 = Math_fround($30 / $12);
  HEAPF32[$0>>2] = $31;
  $32 = (($0) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($33 / $12);
  HEAPF32[$32>>2] = $34;
  $35 = (($0) + 8|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($36 / $12);
  HEAPF32[$35>>2] = $37;
  ;HEAP32[$1+0>>2]=HEAP32[$rhs+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$rhs+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$rhs+8>>2]|0;
  $38 = Math_fround(HEAPF32[$1>>2]);
  $39 = Math_fround($38 / $23);
  HEAPF32[$1>>2] = $39;
  $40 = (($1) + 4|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($41 / $23);
  HEAPF32[$40>>2] = $42;
  $43 = (($1) + 8|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($44 / $23);
  HEAPF32[$43>>2] = $45;
  (__ZN10Matrix3x3f17SetFromToRotationERK8Vector3fS2_($m$i,$0,$1)|0);
  __Z18MatrixToQuaternionRK10Matrix3x3fR11Quaternionf($m$i,$agg$result);
  STACKTOP = sp;return;
 }
}
function __Z13RotateTowardsRK8Vector3fS1_ff($agg$result,$lhs,$rhs,$angleMove,$magnitudeMove) {
 $agg$result = $agg$result|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 $angleMove = Math_fround($angleMove);
 $magnitudeMove = Math_fround($magnitudeMove);
 var $$0$i = Math_fround(0), $$0$i2 = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0;
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0);
 var $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = 0, $axis = 0, $axis1 = 0, $m = 0, $or$cond = 0, $storemerge$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $axis = sp + 48|0;
 $m = sp;
 $axis1 = sp + 36|0;
 $0 = Math_fround(HEAPF32[$lhs>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($lhs) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($lhs) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (Math_fround(Math_sqrt((Math_fround($9)))));
 $11 = Math_fround(HEAPF32[$rhs>>2]);
 $12 = Math_fround($11 * $11);
 $13 = (($rhs) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($rhs) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * $18);
 $20 = Math_fround($16 + $19);
 $21 = (Math_fround(Math_sqrt((Math_fround($20)))));
 $22 = $10 > Math_fround(9.99999974737875163555E-6);
 $23 = $21 > Math_fround(9.99999974737875163555E-6);
 $or$cond = $22 & $23;
 if (!($or$cond)) {
  $197 = Math_fround($11 - $0);
  $198 = Math_fround($14 - $3);
  $199 = Math_fround($18 - $7);
  $200 = Math_fround($197 * $197);
  $201 = Math_fround($198 * $198);
  $202 = Math_fround($200 + $201);
  $203 = Math_fround($199 * $199);
  $204 = Math_fround($202 + $203);
  $205 = Math_fround($magnitudeMove * $magnitudeMove);
  $206 = $204 > $205;
  if (!($206)) {
   ;HEAP32[$agg$result+0>>2]=HEAP32[$rhs+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$rhs+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$rhs+8>>2]|0;
   STACKTOP = sp;return;
  }
  $207 = (Math_fround(Math_sqrt((Math_fround($204)))));
  $208 = $207 > Math_fround(9.99999974737875163555E-6);
  if ($208) {
   $209 = Math_fround($197 / $207);
   $210 = Math_fround($198 / $207);
   $211 = Math_fround($199 / $207);
   $212 = Math_fround($209 * $magnitudeMove);
   $213 = Math_fround($210 * $magnitudeMove);
   $214 = Math_fround($211 * $magnitudeMove);
   $215 = Math_fround($0 + $212);
   $216 = Math_fround($3 + $213);
   $217 = Math_fround($7 + $214);
   HEAPF32[$agg$result>>2] = $215;
   $218 = (($agg$result) + 4|0);
   HEAPF32[$218>>2] = $216;
   $219 = (($agg$result) + 8|0);
   HEAPF32[$219>>2] = $217;
   STACKTOP = sp;return;
  } else {
   ;HEAP32[$agg$result+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$lhs+8>>2]|0;
   STACKTOP = sp;return;
  }
 }
 $24 = Math_fround($0 / $10);
 $25 = Math_fround($3 / $10);
 $26 = Math_fround($7 / $10);
 $27 = Math_fround($11 / $21);
 $28 = Math_fround($14 / $21);
 $29 = Math_fround($18 / $21);
 $30 = Math_fround($24 * $27);
 $31 = Math_fround($25 * $28);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($26 * $29);
 $34 = Math_fround($32 + $33);
 $35 = $34 > Math_fround(0.999989986419677734375);
 if ($35) {
  $36 = Math_fround($11 - $0);
  $37 = Math_fround($14 - $3);
  $38 = Math_fround($18 - $7);
  $39 = Math_fround($36 * $36);
  $40 = Math_fround($37 * $37);
  $41 = Math_fround($39 + $40);
  $42 = Math_fround($38 * $38);
  $43 = Math_fround($41 + $42);
  $44 = Math_fround($magnitudeMove * $magnitudeMove);
  $45 = $43 > $44;
  if (!($45)) {
   ;HEAP32[$agg$result+0>>2]=HEAP32[$rhs+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$rhs+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$rhs+8>>2]|0;
   STACKTOP = sp;return;
  }
  $46 = (Math_fround(Math_sqrt((Math_fround($43)))));
  $47 = $46 > Math_fround(9.99999974737875163555E-6);
  if ($47) {
   $48 = Math_fround($36 / $46);
   $49 = Math_fround($37 / $46);
   $50 = Math_fround($38 / $46);
   $51 = Math_fround($48 * $magnitudeMove);
   $52 = Math_fround($49 * $magnitudeMove);
   $53 = Math_fround($50 * $magnitudeMove);
   $54 = Math_fround($0 + $51);
   $55 = Math_fround($3 + $52);
   $56 = Math_fround($7 + $53);
   HEAPF32[$agg$result>>2] = $54;
   $57 = (($agg$result) + 4|0);
   HEAPF32[$57>>2] = $55;
   $58 = (($agg$result) + 8|0);
   HEAPF32[$58>>2] = $56;
   STACKTOP = sp;return;
  } else {
   ;HEAP32[$agg$result+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$lhs+8>>2]|0;
   STACKTOP = sp;return;
  }
 }
 $59 = $34 < Math_fround(-0.999989986419677734375);
 if (!($59)) {
  $128 = (Math_fround(+(Math_acos((+$34)))));
  $129 = Math_fround($25 * $29);
  $130 = Math_fround($26 * $28);
  $131 = Math_fround($129 - $130);
  $132 = Math_fround($26 * $27);
  $133 = Math_fround($24 * $29);
  $134 = Math_fround($132 - $133);
  $135 = Math_fround($24 * $28);
  $136 = Math_fround($25 * $27);
  $137 = Math_fround($135 - $136);
  $138 = Math_fround($131 * $131);
  $139 = Math_fround($134 * $134);
  $140 = Math_fround($138 + $139);
  $141 = Math_fround($137 * $137);
  $142 = Math_fround($141 + $140);
  $143 = (Math_fround(Math_sqrt((Math_fround($142)))));
  $144 = (($axis1) + 4|0);
  $145 = (($axis1) + 8|0);
  $146 = Math_fround($131 / $143);
  HEAPF32[$axis1>>2] = $146;
  $147 = Math_fround($134 / $143);
  HEAPF32[$144>>2] = $147;
  $148 = Math_fround($137 / $143);
  HEAPF32[$145>>2] = $148;
  $149 = $128 < $angleMove;
  $150 = $149 ? $128 : $angleMove;
  (__ZN10Matrix3x3f12SetAxisAngleERK8Vector3ff($m,$axis1,$150)|0);
  $151 = Math_fround(HEAPF32[$m>>2]);
  $152 = Math_fround($24 * $151);
  $153 = (($m) + 12|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = Math_fround($25 * $154);
  $156 = Math_fround($152 + $155);
  $157 = (($m) + 24|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = Math_fround($26 * $158);
  $160 = Math_fround($156 + $159);
  $161 = (($m) + 4|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($24 * $162);
  $164 = (($m) + 16|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  $166 = Math_fround($25 * $165);
  $167 = Math_fround($163 + $166);
  $168 = (($m) + 28|0);
  $169 = Math_fround(HEAPF32[$168>>2]);
  $170 = Math_fround($26 * $169);
  $171 = Math_fround($167 + $170);
  $172 = (($m) + 8|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($24 * $173);
  $175 = (($m) + 20|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = Math_fround($25 * $176);
  $178 = Math_fround($174 + $177);
  $179 = (($m) + 32|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = Math_fround($26 * $180);
  $182 = Math_fround($178 + $181);
  $183 = Math_fround($21 - $10);
  $184 = $183 > Math_fround(0.0);
  if ($184) {
   $185 = $183 > $magnitudeMove;
   $186 = $185 ? $magnitudeMove : $183;
   $187 = Math_fround($10 + $186);
   $$0$i = $187;
  } else {
   $188 = Math_fround(-$183);
   $189 = $magnitudeMove < $188;
   $190 = $189 ? $magnitudeMove : $188;
   $191 = Math_fround($10 - $190);
   $$0$i = $191;
  }
  $192 = Math_fround($160 * $$0$i);
  $193 = Math_fround($171 * $$0$i);
  $194 = Math_fround($182 * $$0$i);
  HEAPF32[$agg$result>>2] = $192;
  $195 = (($agg$result) + 4|0);
  HEAPF32[$195>>2] = $193;
  $196 = (($agg$result) + 8|0);
  HEAPF32[$196>>2] = $194;
  STACKTOP = sp;return;
 }
 HEAPF32[$axis>>2] = Math_fround(0.0);
 $60 = (($axis) + 4|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($axis) + 8|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = $26 < Math_fround(0.0);
 if ($62) {
  $63 = Math_fround(-$26);
  $65 = $63;
 } else {
  $65 = $26;
 }
 $64 = $65 > Math_fround(0.707106769084930419921);
 if ($64) {
  $66 = Math_fround($25 * $25);
  $67 = Math_fround($26 * $26);
  $68 = Math_fround($66 + $67);
  $69 = (Math_fround(Math_sqrt((Math_fround($68)))));
  $70 = Math_fround(Math_fround(1.0) / $69);
  HEAPF32[$axis>>2] = Math_fround(0.0);
  $71 = Math_fround($26 * $70);
  $72 = Math_fround(-$71);
  HEAPF32[$60>>2] = $72;
  $73 = Math_fround($25 * $70);
  $storemerge$i = $73;
 } else {
  $74 = Math_fround($24 * $24);
  $75 = Math_fround($25 * $25);
  $76 = Math_fround($74 + $75);
  $77 = (Math_fround(Math_sqrt((Math_fround($76)))));
  $78 = Math_fround(Math_fround(1.0) / $77);
  $79 = Math_fround($25 * $78);
  $80 = Math_fround(-$79);
  HEAPF32[$axis>>2] = $80;
  $81 = Math_fround($24 * $78);
  HEAPF32[$60>>2] = $81;
  $storemerge$i = Math_fround(0.0);
 }
 HEAPF32[$61>>2] = $storemerge$i;
 (__ZN10Matrix3x3f12SetAxisAngleERK8Vector3ff($m,$axis,$angleMove)|0);
 $82 = Math_fround(HEAPF32[$m>>2]);
 $83 = Math_fround($24 * $82);
 $84 = (($m) + 12|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($25 * $85);
 $87 = Math_fround($83 + $86);
 $88 = (($m) + 24|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($26 * $89);
 $91 = Math_fround($87 + $90);
 $92 = (($m) + 4|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($24 * $93);
 $95 = (($m) + 16|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($25 * $96);
 $98 = Math_fround($94 + $97);
 $99 = (($m) + 28|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($26 * $100);
 $102 = Math_fround($98 + $101);
 $103 = (($m) + 8|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($24 * $104);
 $106 = (($m) + 20|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($25 * $107);
 $109 = Math_fround($105 + $108);
 $110 = (($m) + 32|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($26 * $111);
 $113 = Math_fround($109 + $112);
 $114 = Math_fround($21 - $10);
 $115 = $114 > Math_fround(0.0);
 if ($115) {
  $116 = $114 > $magnitudeMove;
  $117 = $116 ? $magnitudeMove : $114;
  $118 = Math_fround($10 + $117);
  $$0$i2 = $118;
 } else {
  $119 = Math_fround(-$114);
  $120 = $magnitudeMove < $119;
  $121 = $120 ? $magnitudeMove : $119;
  $122 = Math_fround($10 - $121);
  $$0$i2 = $122;
 }
 $123 = Math_fround($91 * $$0$i2);
 $124 = Math_fround($102 * $$0$i2);
 $125 = Math_fround($113 * $$0$i2);
 HEAPF32[$agg$result>>2] = $123;
 $126 = (($agg$result) + 4|0);
 HEAPF32[$126>>2] = $124;
 $127 = (($agg$result) + 8|0);
 HEAPF32[$127>>2] = $125;
 STACKTOP = sp;return;
}
function __Z5SlerpRK8Vector3fS1_f($agg$result,$lhs,$rhs,$t) {
 $agg$result = $agg$result|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 $t = Math_fround($t);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0);
 var $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $axis = 0, $axis1 = 0, $m = 0, $or$cond = 0, $storemerge$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $axis = sp + 48|0;
 $m = sp;
 $axis1 = sp + 36|0;
 $0 = Math_fround(HEAPF32[$lhs>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($lhs) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($lhs) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (Math_fround(Math_sqrt((Math_fround($9)))));
 $11 = Math_fround(HEAPF32[$rhs>>2]);
 $12 = Math_fround($11 * $11);
 $13 = (($rhs) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($14 * $14);
 $16 = Math_fround($12 + $15);
 $17 = (($rhs) + 8|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * $18);
 $20 = Math_fround($16 + $19);
 $21 = (Math_fround(Math_sqrt((Math_fround($20)))));
 $22 = $10 < Math_fround(9.99999974737875163555E-6);
 $23 = $21 < Math_fround(9.99999974737875163555E-6);
 $or$cond = $22 | $23;
 if ($or$cond) {
  $24 = Math_fround($11 * $t);
  $25 = Math_fround($14 * $t);
  $26 = Math_fround($18 * $t);
  $27 = Math_fround(Math_fround(1.0) - $t);
  $28 = Math_fround($27 * $0);
  $29 = Math_fround($27 * $3);
  $30 = Math_fround($27 * $7);
  $31 = Math_fround($28 + $24);
  $32 = Math_fround($29 + $25);
  $33 = Math_fround($30 + $26);
  HEAPF32[$agg$result>>2] = $31;
  $34 = (($agg$result) + 4|0);
  HEAPF32[$34>>2] = $32;
  $35 = (($agg$result) + 8|0);
  HEAPF32[$35>>2] = $33;
  STACKTOP = sp;return;
 }
 $36 = Math_fround($21 * $t);
 $37 = Math_fround(Math_fround(1.0) - $t);
 $38 = Math_fround($37 * $10);
 $39 = Math_fround($38 + $36);
 $40 = Math_fround($0 * $11);
 $41 = Math_fround($3 * $14);
 $42 = Math_fround($40 + $41);
 $43 = Math_fround($7 * $18);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($10 * $21);
 $46 = Math_fround($44 / $45);
 $47 = $46 > Math_fround(0.999989986419677734375);
 if ($47) {
  $48 = Math_fround($11 * $t);
  $49 = Math_fround($14 * $t);
  $50 = Math_fround($18 * $t);
  $51 = Math_fround($37 * $0);
  $52 = Math_fround($37 * $3);
  $53 = Math_fround($37 * $7);
  $54 = Math_fround($51 + $48);
  $55 = Math_fround($52 + $49);
  $56 = Math_fround($53 + $50);
  HEAPF32[$agg$result>>2] = $54;
  $57 = (($agg$result) + 4|0);
  HEAPF32[$57>>2] = $55;
  $58 = (($agg$result) + 8|0);
  HEAPF32[$58>>2] = $56;
  STACKTOP = sp;return;
 }
 $59 = $46 < Math_fround(-0.999989986419677734375);
 if (!($59)) {
  $123 = Math_fround($3 * $18);
  $124 = Math_fround($7 * $14);
  $125 = Math_fround($123 - $124);
  $126 = Math_fround($7 * $11);
  $127 = Math_fround($0 * $18);
  $128 = Math_fround($126 - $127);
  $129 = Math_fround($0 * $14);
  $130 = Math_fround($3 * $11);
  $131 = Math_fround($129 - $130);
  $132 = (($axis1) + 4|0);
  $133 = (($axis1) + 8|0);
  $134 = Math_fround($0 / $10);
  $135 = Math_fround($3 / $10);
  $136 = Math_fround($7 / $10);
  $137 = Math_fround($125 * $125);
  $138 = Math_fround($128 * $128);
  $139 = Math_fround($137 + $138);
  $140 = Math_fround($131 * $131);
  $141 = Math_fround($140 + $139);
  $142 = (Math_fround(Math_sqrt((Math_fround($141)))));
  $143 = Math_fround($125 / $142);
  $144 = Math_fround($128 / $142);
  $145 = Math_fround($131 / $142);
  HEAPF32[$axis1>>2] = $143;
  HEAPF32[$132>>2] = $144;
  HEAPF32[$133>>2] = $145;
  $146 = (Math_fround(+(Math_acos((+$46)))));
  $147 = Math_fround($146 * $t);
  (__ZN10Matrix3x3f12SetAxisAngleERK8Vector3ff($m,$axis1,$147)|0);
  $148 = Math_fround(HEAPF32[$m>>2]);
  $149 = Math_fround($134 * $148);
  $150 = (($m) + 12|0);
  $151 = Math_fround(HEAPF32[$150>>2]);
  $152 = Math_fround($135 * $151);
  $153 = Math_fround($149 + $152);
  $154 = (($m) + 24|0);
  $155 = Math_fround(HEAPF32[$154>>2]);
  $156 = Math_fround($136 * $155);
  $157 = Math_fround($153 + $156);
  $158 = (($m) + 4|0);
  $159 = Math_fround(HEAPF32[$158>>2]);
  $160 = Math_fround($134 * $159);
  $161 = (($m) + 16|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = Math_fround($135 * $162);
  $164 = Math_fround($160 + $163);
  $165 = (($m) + 28|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = Math_fround($136 * $166);
  $168 = Math_fround($164 + $167);
  $169 = (($m) + 8|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround($134 * $170);
  $172 = (($m) + 20|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = Math_fround($135 * $173);
  $175 = Math_fround($171 + $174);
  $176 = (($m) + 32|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = Math_fround($136 * $177);
  $179 = Math_fround($175 + $178);
  $180 = Math_fround($39 * $157);
  $181 = Math_fround($39 * $168);
  $182 = Math_fround($39 * $179);
  HEAPF32[$agg$result>>2] = $180;
  $183 = (($agg$result) + 4|0);
  HEAPF32[$183>>2] = $181;
  $184 = (($agg$result) + 8|0);
  HEAPF32[$184>>2] = $182;
  STACKTOP = sp;return;
 }
 $60 = Math_fround($0 / $10);
 $61 = Math_fround($3 / $10);
 $62 = Math_fround($7 / $10);
 HEAPF32[$axis>>2] = Math_fround(0.0);
 $63 = (($axis) + 4|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($axis) + 8|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = $62 < Math_fround(0.0);
 if ($65) {
  $66 = Math_fround(-$62);
  $68 = $66;
 } else {
  $68 = $62;
 }
 $67 = $68 > Math_fround(0.707106769084930419921);
 if ($67) {
  $69 = Math_fround($61 * $61);
  $70 = Math_fround($62 * $62);
  $71 = Math_fround($69 + $70);
  $72 = (Math_fround(Math_sqrt((Math_fround($71)))));
  $73 = Math_fround(Math_fround(1.0) / $72);
  HEAPF32[$axis>>2] = Math_fround(0.0);
  $74 = Math_fround($62 * $73);
  $75 = Math_fround(-$74);
  HEAPF32[$63>>2] = $75;
  $76 = Math_fround($61 * $73);
  $storemerge$i = $76;
 } else {
  $77 = Math_fround($60 * $60);
  $78 = Math_fround($61 * $61);
  $79 = Math_fround($77 + $78);
  $80 = (Math_fround(Math_sqrt((Math_fround($79)))));
  $81 = Math_fround(Math_fround(1.0) / $80);
  $82 = Math_fround($61 * $81);
  $83 = Math_fround(-$82);
  HEAPF32[$axis>>2] = $83;
  $84 = Math_fround($60 * $81);
  HEAPF32[$63>>2] = $84;
  $storemerge$i = Math_fround(0.0);
 }
 HEAPF32[$64>>2] = $storemerge$i;
 $85 = Math_fround($t * Math_fround(3.14159274101257324219));
 (__ZN10Matrix3x3f12SetAxisAngleERK8Vector3ff($m,$axis,$85)|0);
 $86 = Math_fround(HEAPF32[$m>>2]);
 $87 = Math_fround($60 * $86);
 $88 = (($m) + 12|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($61 * $89);
 $91 = Math_fround($87 + $90);
 $92 = (($m) + 24|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($62 * $93);
 $95 = Math_fround($91 + $94);
 $96 = (($m) + 4|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($60 * $97);
 $99 = (($m) + 16|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = Math_fround($61 * $100);
 $102 = Math_fround($98 + $101);
 $103 = (($m) + 28|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($62 * $104);
 $106 = Math_fround($102 + $105);
 $107 = (($m) + 8|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($60 * $108);
 $110 = (($m) + 20|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($61 * $111);
 $113 = Math_fround($109 + $112);
 $114 = (($m) + 32|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($62 * $115);
 $117 = Math_fround($113 + $116);
 $118 = Math_fround($39 * $95);
 $119 = Math_fround($39 * $106);
 $120 = Math_fround($39 * $117);
 HEAPF32[$agg$result>>2] = $118;
 $121 = (($agg$result) + 4|0);
 HEAPF32[$121>>2] = $119;
 $122 = (($agg$result) + 8|0);
 HEAPF32[$122>>2] = $120;
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplIfE15InvalidateCacheEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = Math_fround(inf);
 HEAP32[$this>>2] = 0;
 $1 = (($this) + 32|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplIfE8GetRangeEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAPF32[$agg$result>>2] = Math_fround(inf);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(-inf);
  STACKTOP = sp;return;
 } else {
  $3 = (($this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($1) + -1)|0;
  $7 = (($4) + ($6<<4)|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$agg$result>>2] = $5;
  $9 = (($agg$result) + 4|0);
  HEAPF32[$9>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNK17AnimationCurveTplIfE8EvaluateEf($this,$curveT) {
 $this = $this|0;
 $curveT = Math_fround($curveT);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0;
 var $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0);
 var $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0);
 var $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0);
 var $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $floorf$i$i$i = Math_fround(0), $floorf$i$i$i3 = Math_fround(0), $lhs = 0, $output = 0, $rhs = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $lhs = sp + 8|0;
 $rhs = sp;
 $output = sp + 4|0;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if ($2) {
  $3 = (($this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $$0 = $6;
  STACKTOP = sp;return (Math_fround($$0));
 }
 $7 = (($this) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 <= $curveT);
 if (!($9)) {
  $10 = (($this) + 8|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = $11 > $curveT;
  if ($12) {
   $13 = Math_fround($curveT - $8);
   $14 = (($this) + 12|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($13 * $15);
   $17 = (($this) + 16|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = Math_fround($16 + $18);
   $20 = Math_fround($13 * $19);
   $21 = (($this) + 20|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = Math_fround($22 + $20);
   $24 = Math_fround($13 * $23);
   $25 = (($this) + 24|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = Math_fround($26 + $24);
   HEAPF32[$output>>2] = $27;
   $$0 = $27;
   STACKTOP = sp;return (Math_fround($$0));
  }
 }
 $28 = ($1|0)==(0);
 if ($28) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $29 = (($this) + 56|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($1) + -1)|0;
 $33 = (($30) + ($32<<4)|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = !($34 <= $curveT);
 do {
  if ($35) {
   $104 = $31 > $curveT;
   if (!($104)) {
    __ZNK17AnimationCurveTplIfE20FindIndexForSamplingERKNS0_5CacheEfRiS4_($this,$this,$curveT,$lhs,$rhs);
    $172 = HEAP32[$lhs>>2]|0;
    $173 = HEAP32[$rhs>>2]|0;
    $174 = HEAP32[$29>>2]|0;
    $175 = (($174) + ($172<<4)|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = Math_fround($176 + Math_fround(0.0));
    HEAPF32[$7>>2] = $177;
    $178 = (($174) + ($173<<4)|0);
    $179 = Math_fround(HEAPF32[$178>>2]);
    $180 = Math_fround($179 + Math_fround(0.0));
    $181 = (($this) + 8|0);
    HEAPF32[$181>>2] = $180;
    HEAP32[$this>>2] = $172;
    $182 = Math_fround(HEAPF32[$178>>2]);
    $183 = Math_fround(HEAPF32[$175>>2]);
    $184 = Math_fround($182 - $183);
    $185 = $184 < Math_fround(9.99999974737875163555E-5);
    $186 = $185 ? Math_fround(9.99999974737875163555E-5) : $184;
    $187 = ((($174) + ($173<<4)|0) + 4|0);
    $188 = Math_fround(HEAPF32[$187>>2]);
    $189 = ((($174) + ($172<<4)|0) + 4|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = Math_fround($188 - $190);
    $192 = Math_fround($186 * $186);
    $193 = Math_fround(Math_fround(1.0) / $192);
    $194 = ((($174) + ($172<<4)|0) + 12|0);
    $195 = Math_fround(HEAPF32[$194>>2]);
    $196 = ((($174) + ($173<<4)|0) + 8|0);
    $197 = Math_fround(HEAPF32[$196>>2]);
    $198 = Math_fround($186 * $195);
    $199 = Math_fround($186 * $197);
    $200 = Math_fround($198 + $199);
    $201 = Math_fround($200 - $191);
    $202 = Math_fround($201 - $191);
    $203 = Math_fround($193 * $202);
    $204 = Math_fround($203 / $186);
    $205 = (($this) + 12|0);
    HEAPF32[$205>>2] = $204;
    $206 = Math_fround($191 + $191);
    $207 = Math_fround($191 + $206);
    $208 = Math_fround($207 - $198);
    $209 = Math_fround($208 - $198);
    $210 = Math_fround($209 - $199);
    $211 = Math_fround($193 * $210);
    $212 = (($this) + 16|0);
    HEAPF32[$212>>2] = $211;
    $213 = (($this) + 20|0);
    HEAPF32[$213>>2] = $195;
    $214 = Math_fround(HEAPF32[$189>>2]);
    $215 = (($this) + 24|0);
    HEAPF32[$215>>2] = $214;
    $216 = Math_fround(HEAPF32[$194>>2]);
    $217 = $216 == Math_fround(inf);
    if (!($217)) {
     $218 = Math_fround(HEAPF32[$196>>2]);
     $219 = $218 == Math_fround(inf);
     if (!($219)) {
      $222 = $177;$224 = $204;$226 = $211;$229 = $195;$232 = $214;
      break;
     }
    }
    HEAPF32[$205>>2] = Math_fround(0.0);
    HEAPF32[$212>>2] = Math_fround(0.0);
    HEAPF32[$213>>2] = Math_fround(0.0);
    $220 = Math_fround(HEAPF32[$189>>2]);
    HEAPF32[$215>>2] = $220;
    $222 = $177;$224 = Math_fround(0.0);$226 = Math_fround(0.0);$229 = Math_fround(0.0);$232 = $220;
    break;
   }
   $105 = (($this) + 72|0);
   $106 = HEAP32[$105>>2]|0;
   if ((($106|0) == 1)) {
    $115 = Math_fround($curveT - $31);
    $116 = Math_fround($34 - $31);
    $117 = Math_fround($115 / $116);
    $floorf$i$i$i = (Math_fround(Math_floor((Math_fround($117)))));
    $118 = Math_fround($116 * $floorf$i$i$i);
    $119 = Math_fround($115 - $118);
    $120 = Math_fround($31 + $119);
    __ZNK17AnimationCurveTplIfE20FindIndexForSamplingERKNS0_5CacheEfRiS4_($this,$this,$120,$lhs,$rhs);
    $121 = HEAP32[$lhs>>2]|0;
    $122 = HEAP32[$rhs>>2]|0;
    $123 = Math_fround($curveT - $120);
    $124 = HEAP32[$29>>2]|0;
    $125 = (($124) + ($121<<4)|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = Math_fround($123 + $126);
    HEAPF32[$7>>2] = $127;
    $128 = (($124) + ($122<<4)|0);
    $129 = Math_fround(HEAPF32[$128>>2]);
    $130 = Math_fround($123 + $129);
    $131 = (($this) + 8|0);
    HEAPF32[$131>>2] = $130;
    HEAP32[$this>>2] = $121;
    $132 = Math_fround(HEAPF32[$128>>2]);
    $133 = Math_fround(HEAPF32[$125>>2]);
    $134 = Math_fround($132 - $133);
    $135 = $134 < Math_fround(9.99999974737875163555E-5);
    $136 = $135 ? Math_fround(9.99999974737875163555E-5) : $134;
    $137 = ((($124) + ($122<<4)|0) + 4|0);
    $138 = Math_fround(HEAPF32[$137>>2]);
    $139 = ((($124) + ($121<<4)|0) + 4|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = Math_fround($138 - $140);
    $142 = Math_fround($136 * $136);
    $143 = Math_fround(Math_fround(1.0) / $142);
    $144 = ((($124) + ($121<<4)|0) + 12|0);
    $145 = Math_fround(HEAPF32[$144>>2]);
    $146 = ((($124) + ($122<<4)|0) + 8|0);
    $147 = Math_fround(HEAPF32[$146>>2]);
    $148 = Math_fround($136 * $145);
    $149 = Math_fround($136 * $147);
    $150 = Math_fround($148 + $149);
    $151 = Math_fround($150 - $141);
    $152 = Math_fround($151 - $141);
    $153 = Math_fround($143 * $152);
    $154 = Math_fround($153 / $136);
    $155 = (($this) + 12|0);
    HEAPF32[$155>>2] = $154;
    $156 = Math_fround($141 + $141);
    $157 = Math_fround($141 + $156);
    $158 = Math_fround($157 - $148);
    $159 = Math_fround($158 - $148);
    $160 = Math_fround($159 - $149);
    $161 = Math_fround($143 * $160);
    $162 = (($this) + 16|0);
    HEAPF32[$162>>2] = $161;
    $163 = (($this) + 20|0);
    HEAPF32[$163>>2] = $145;
    $164 = Math_fround(HEAPF32[$139>>2]);
    $165 = (($this) + 24|0);
    HEAPF32[$165>>2] = $164;
    $166 = Math_fround(HEAPF32[$144>>2]);
    $167 = $166 == Math_fround(inf);
    if (!($167)) {
     $168 = Math_fround(HEAPF32[$146>>2]);
     $169 = $168 == Math_fround(inf);
     if (!($169)) {
      $222 = $127;$224 = $154;$226 = $161;$229 = $145;$232 = $164;
      break;
     }
    }
    HEAPF32[$155>>2] = Math_fround(0.0);
    HEAPF32[$162>>2] = Math_fround(0.0);
    HEAPF32[$163>>2] = Math_fround(0.0);
    $170 = Math_fround(HEAPF32[$139>>2]);
    HEAPF32[$165>>2] = $170;
    $222 = $127;$224 = Math_fround(0.0);$226 = Math_fround(0.0);$229 = Math_fround(0.0);$232 = $170;
    break;
   } else if ((($106|0) == 2)) {
    $107 = Math_fround($curveT + Math_fround(-1000.0));
    HEAPF32[$7>>2] = $107;
    $108 = (($this) + 8|0);
    HEAPF32[$108>>2] = $31;
    $109 = (($this) + 20|0);
    HEAPF32[$109>>2] = Math_fround(0.0);
    $110 = (($this) + 16|0);
    HEAPF32[$110>>2] = Math_fround(0.0);
    $111 = (($this) + 12|0);
    HEAPF32[$111>>2] = Math_fround(0.0);
    $112 = (($30) + 4|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = (($this) + 24|0);
    HEAPF32[$114>>2] = $113;
    $222 = $107;$224 = Math_fround(0.0);$226 = Math_fround(0.0);$229 = Math_fround(0.0);$232 = $113;
    break;
   } else {
    __ZNK17AnimationCurveTplIfE20EvaluateWithoutCacheEfRf($this,$curveT,$output);
    $171 = Math_fround(HEAPF32[$output>>2]);
    $$0 = $171;
    STACKTOP = sp;return (Math_fround($$0));
   }
  } else {
   $36 = (($this) + 76|0);
   $37 = HEAP32[$36>>2]|0;
   if ((($37|0) == 1)) {
    $45 = Math_fround($curveT - $31);
    $46 = Math_fround($34 - $31);
    $47 = Math_fround($45 / $46);
    $floorf$i$i$i3 = (Math_fround(Math_floor((Math_fround($47)))));
    $48 = Math_fround($46 * $floorf$i$i$i3);
    $49 = Math_fround($45 - $48);
    $50 = Math_fround($31 + $49);
    $51 = (Math_fround(+(_fmaxf((+$50),(+$31)))));
    $52 = (Math_fround(+(_fminf((+$51),(+$34)))));
    __ZNK17AnimationCurveTplIfE20FindIndexForSamplingERKNS0_5CacheEfRiS4_($this,$this,$52,$lhs,$rhs);
    $53 = HEAP32[$lhs>>2]|0;
    $54 = HEAP32[$rhs>>2]|0;
    $55 = Math_fround($curveT - $52);
    $56 = HEAP32[$29>>2]|0;
    $57 = (($56) + ($53<<4)|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($55 + $58);
    HEAPF32[$7>>2] = $59;
    $60 = (($56) + ($54<<4)|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = Math_fround($55 + $61);
    $63 = (($this) + 8|0);
    HEAPF32[$63>>2] = $62;
    HEAP32[$this>>2] = $53;
    $64 = Math_fround(HEAPF32[$60>>2]);
    $65 = Math_fround(HEAPF32[$57>>2]);
    $66 = Math_fround($64 - $65);
    $67 = $66 < Math_fround(9.99999974737875163555E-5);
    $68 = $67 ? Math_fround(9.99999974737875163555E-5) : $66;
    $69 = ((($56) + ($54<<4)|0) + 4|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = ((($56) + ($53<<4)|0) + 4|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = Math_fround($70 - $72);
    $74 = Math_fround($68 * $68);
    $75 = Math_fround(Math_fround(1.0) / $74);
    $76 = ((($56) + ($53<<4)|0) + 12|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = ((($56) + ($54<<4)|0) + 8|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = Math_fround($68 * $77);
    $81 = Math_fround($68 * $79);
    $82 = Math_fround($80 + $81);
    $83 = Math_fround($82 - $73);
    $84 = Math_fround($83 - $73);
    $85 = Math_fround($75 * $84);
    $86 = Math_fround($85 / $68);
    $87 = (($this) + 12|0);
    HEAPF32[$87>>2] = $86;
    $88 = Math_fround($73 + $73);
    $89 = Math_fround($73 + $88);
    $90 = Math_fround($89 - $80);
    $91 = Math_fround($90 - $80);
    $92 = Math_fround($91 - $81);
    $93 = Math_fround($75 * $92);
    $94 = (($this) + 16|0);
    HEAPF32[$94>>2] = $93;
    $95 = (($this) + 20|0);
    HEAPF32[$95>>2] = $77;
    $96 = Math_fround(HEAPF32[$71>>2]);
    $97 = (($this) + 24|0);
    HEAPF32[$97>>2] = $96;
    $98 = Math_fround(HEAPF32[$76>>2]);
    $99 = $98 == Math_fround(inf);
    if (!($99)) {
     $100 = Math_fround(HEAPF32[$78>>2]);
     $101 = $100 == Math_fround(inf);
     if (!($101)) {
      $222 = $59;$224 = $86;$226 = $93;$229 = $77;$232 = $96;
      break;
     }
    }
    HEAPF32[$87>>2] = Math_fround(0.0);
    HEAPF32[$94>>2] = Math_fround(0.0);
    HEAPF32[$95>>2] = Math_fround(0.0);
    $102 = Math_fround(HEAPF32[$71>>2]);
    HEAPF32[$97>>2] = $102;
    $222 = $59;$224 = Math_fround(0.0);$226 = Math_fround(0.0);$229 = Math_fround(0.0);$232 = $102;
    break;
   } else if ((($37|0) == 2)) {
    HEAPF32[$7>>2] = $34;
    $38 = (($this) + 8|0);
    HEAPF32[$38>>2] = Math_fround(inf);
    $39 = (($this) + 20|0);
    HEAPF32[$39>>2] = Math_fround(0.0);
    $40 = (($this) + 16|0);
    HEAPF32[$40>>2] = Math_fround(0.0);
    $41 = (($this) + 12|0);
    HEAPF32[$41>>2] = Math_fround(0.0);
    $42 = ((($30) + ($32<<4)|0) + 4|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = (($this) + 24|0);
    HEAPF32[$44>>2] = $43;
    $222 = $34;$224 = Math_fround(0.0);$226 = Math_fround(0.0);$229 = Math_fround(0.0);$232 = $43;
    break;
   } else {
    __ZNK17AnimationCurveTplIfE20EvaluateWithoutCacheEfRf($this,$curveT,$output);
    $103 = Math_fround(HEAPF32[$output>>2]);
    $$0 = $103;
    STACKTOP = sp;return (Math_fround($$0));
   }
  }
 } while(0);
 $221 = Math_fround($curveT - $222);
 $223 = Math_fround($221 * $224);
 $225 = Math_fround($223 + $226);
 $227 = Math_fround($221 * $225);
 $228 = Math_fround($229 + $227);
 $230 = Math_fround($221 * $228);
 $231 = Math_fround($232 + $230);
 HEAPF32[$output>>2] = $231;
 $$0 = $231;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZNK17AnimationCurveTplIfE20FindIndexForSamplingERKNS0_5CacheEfRiS4_($this,$cache,$curveT,$lhs,$rhs) {
 $this = $this|0;
 $cache = $cache|0;
 $curveT = Math_fround($curveT);
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, $i$06 = 0, $i1$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$cache>>2]|0;
 $5 = ($4|0)==(-1);
 L1: do {
  if ($5) {
   $$ph = 0;$__len$0$ph = $1;
  } else {
   $6 = (($3) + ($4<<4)|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 < $curveT;
   if ($8) {
    $i$06 = 0;
    while(1) {
     $9 = (($i$06) + ($4))|0;
     $10 = (($9) + 1)|0;
     $11 = ($10|0)<($1|0);
     if ($11) {
      $12 = (($3) + ($10<<4)|0);
      $13 = Math_fround(HEAPF32[$12>>2]);
      $14 = $13 > $curveT;
      if ($14) {
       break;
      }
     }
     $18 = (($i$06) + 1)|0;
     $19 = ($18|0)<(3);
     if ($19) {
      $i$06 = $18;
     } else {
      $$ph = 0;$__len$0$ph = $1;
      break L1;
     }
    }
    HEAP32[$lhs>>2] = $9;
    $15 = (($1) + -1)|0;
    $16 = ($15|0)<($10|0);
    $17 = $16 ? $15 : $10;
    HEAP32[$rhs>>2] = $17;
    STACKTOP = sp;return;
   } else {
    $i1$010 = 0;
    while(1) {
     $20 = (($4) - ($i1$010))|0;
     $21 = ($20|0)>(-1);
     if ($21) {
      $22 = (($3) + ($20<<4)|0);
      $23 = Math_fround(HEAPF32[$22>>2]);
      $24 = !($23 <= $curveT);
      if (!($24)) {
       break;
      }
     }
     $29 = (($i1$010) + 1)|0;
     $30 = ($29|0)<(3);
     if ($30) {
      $i1$010 = $29;
     } else {
      $$ph = 0;$__len$0$ph = $1;
      break L1;
     }
    }
    HEAP32[$lhs>>2] = $20;
    $25 = (($20) + 1)|0;
    $26 = (($1) + -1)|0;
    $27 = ($26|0)<($25|0);
    $28 = $27 ? $26 : $25;
    HEAP32[$rhs>>2] = $28;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 L18: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $31 = ($__len$0|0)>(0);
   if (!($31)) {
    break L18;
   }
   $32 = $__len$0 >> 1;
   $33 = (($32) + ($$ph))|0;
   $34 = (($3) + ($33<<4)|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = $35 > $curveT;
   if ($36) {
    $__len$0 = $32;
   } else {
    break;
   }
  }
  $37 = (($33) + 1)|0;
  $38 = (($__len$0) + -1)|0;
  $39 = (($38) - ($32))|0;
  $$ph = $37;$__len$0$ph = $39;
 }
 $40 = (($$ph) + -1)|0;
 HEAP32[$lhs>>2] = $40;
 $41 = (($1) + -1)|0;
 $42 = ($$ph|0)<($41|0);
 $43 = $42 ? $$ph : $41;
 HEAP32[$rhs>>2] = $43;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplIfE20EvaluateWithoutCacheEfRf($this,$curveT,$output) {
 $this = $this|0;
 $curveT = Math_fround($curveT);
 $output = $output|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $lhsIndex = 0, $m1$0 = Math_fround(0), $m2$0 = Math_fround(0);
 var $rhsIndex = 0, $t$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $lhsIndex = sp + 4|0;
 $rhsIndex = sp;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if ($2) {
  $3 = (($this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  HEAPF32[$output>>2] = $6;
  STACKTOP = sp;return;
 }
 $7 = (Math_fround(__ZNK17AnimationCurveTplIfE8WrapTimeEf($this,$curveT)));
 __ZNK17AnimationCurveTplIfE20FindIndexForSamplingERKNS0_5CacheEfRiS4_($this,$this,$7,$lhsIndex,$rhsIndex);
 $8 = HEAP32[$lhsIndex>>2]|0;
 $9 = (($this) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$rhsIndex>>2]|0;
 $12 = (($10) + ($11<<4)|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($10) + ($8<<4)|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 - $15);
 $17 = $16 != Math_fround(0.0);
 if ($17) {
  $18 = Math_fround($7 - $15);
  $19 = Math_fround($18 / $16);
  $20 = ((($10) + ($8<<4)|0) + 12|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($16 * $21);
  $23 = ((($10) + ($11<<4)|0) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($16 * $24);
  $$pre$phiZ2D = $20;$m1$0 = $22;$m2$0 = $25;$t$0 = $19;
 } else {
  $$pre = ((($10) + ($8<<4)|0) + 12|0);
  $$pre$phiZ2D = $$pre;$m1$0 = Math_fround(0.0);$m2$0 = Math_fround(0.0);$t$0 = Math_fround(0.0);
 }
 $26 = ((($10) + ($8<<4)|0) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = ((($10) + ($11<<4)|0) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($t$0 * $t$0);
 $31 = Math_fround($t$0 * $30);
 $32 = Math_fround($31 * Math_fround(2.0));
 $33 = Math_fround($30 * Math_fround(3.0));
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($34 + Math_fround(1.0));
 $36 = Math_fround($30 * Math_fround(2.0));
 $37 = Math_fround($31 - $36);
 $38 = Math_fround($t$0 + $37);
 $39 = Math_fround($31 - $30);
 $40 = Math_fround($31 * Math_fround(-2.0));
 $41 = Math_fround($33 + $40);
 $42 = Math_fround($27 * $35);
 $43 = Math_fround($m1$0 * $38);
 $44 = Math_fround($43 + $42);
 $45 = Math_fround($m2$0 * $39);
 $46 = Math_fround($45 + $44);
 $47 = Math_fround($29 * $41);
 $48 = Math_fround($47 + $46);
 HEAPF32[$output>>2] = $48;
 $49 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $50 = $49 == Math_fround(inf);
 if (!($50)) {
  $51 = ((($10) + ($11<<4)|0) + 8|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = $52 == Math_fround(inf);
  if (!($53)) {
   STACKTOP = sp;return;
  }
 }
 $54 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$output>>2] = $54;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplI8Vector3fE8GetRangeEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAPF32[$agg$result>>2] = Math_fround(inf);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(-inf);
  STACKTOP = sp;return;
 } else {
  $3 = (($this) + 120|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($1) + -1)|0;
  $7 = (($4) + (($6*40)|0)|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$agg$result>>2] = $5;
  $9 = (($agg$result) + 4|0);
  HEAPF32[$9>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNK17AnimationCurveTplI8Vector3fE20FindIndexForSamplingERKNS1_5CacheEfRiS5_($this,$cache,$curveT,$lhs,$rhs) {
 $this = $this|0;
 $cache = $cache|0;
 $curveT = Math_fround($curveT);
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, $i$06 = 0, $i1$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$cache>>2]|0;
 $5 = ($4|0)==(-1);
 L1: do {
  if ($5) {
   $$ph = 0;$__len$0$ph = $1;
  } else {
   $6 = (($3) + (($4*40)|0)|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 < $curveT;
   if ($8) {
    $i$06 = 0;
    while(1) {
     $9 = (($i$06) + ($4))|0;
     $10 = (($9) + 1)|0;
     $11 = ($10|0)<($1|0);
     if ($11) {
      $12 = (($3) + (($10*40)|0)|0);
      $13 = Math_fround(HEAPF32[$12>>2]);
      $14 = $13 > $curveT;
      if ($14) {
       break;
      }
     }
     $18 = (($i$06) + 1)|0;
     $19 = ($18|0)<(3);
     if ($19) {
      $i$06 = $18;
     } else {
      $$ph = 0;$__len$0$ph = $1;
      break L1;
     }
    }
    HEAP32[$lhs>>2] = $9;
    $15 = (($1) + -1)|0;
    $16 = ($15|0)<($10|0);
    $17 = $16 ? $15 : $10;
    HEAP32[$rhs>>2] = $17;
    STACKTOP = sp;return;
   } else {
    $i1$010 = 0;
    while(1) {
     $20 = (($4) - ($i1$010))|0;
     $21 = ($20|0)>(-1);
     if ($21) {
      $22 = (($3) + (($20*40)|0)|0);
      $23 = Math_fround(HEAPF32[$22>>2]);
      $24 = !($23 <= $curveT);
      if (!($24)) {
       break;
      }
     }
     $29 = (($i1$010) + 1)|0;
     $30 = ($29|0)<(3);
     if ($30) {
      $i1$010 = $29;
     } else {
      $$ph = 0;$__len$0$ph = $1;
      break L1;
     }
    }
    HEAP32[$lhs>>2] = $20;
    $25 = (($20) + 1)|0;
    $26 = (($1) + -1)|0;
    $27 = ($26|0)<($25|0);
    $28 = $27 ? $26 : $25;
    HEAP32[$rhs>>2] = $28;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 L18: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $31 = ($__len$0|0)>(0);
   if (!($31)) {
    break L18;
   }
   $32 = $__len$0 >> 1;
   $33 = (($32) + ($$ph))|0;
   $34 = (($3) + (($33*40)|0)|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = $35 > $curveT;
   if ($36) {
    $__len$0 = $32;
   } else {
    break;
   }
  }
  $37 = (($33) + 1)|0;
  $38 = (($__len$0) + -1)|0;
  $39 = (($38) - ($32))|0;
  $$ph = $37;$__len$0$ph = $39;
 }
 $40 = (($$ph) + -1)|0;
 HEAP32[$lhs>>2] = $40;
 $41 = (($1) + -1)|0;
 $42 = ($$ph|0)<($41|0);
 $43 = $42 ? $$ph : $41;
 HEAP32[$rhs>>2] = $43;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplI8Vector3fE18CalculateCacheDataERNS1_5CacheEiif($this,$cache,$lhsIndex,$rhsIndex,$timeOffset) {
 $this = $this|0;
 $cache = $cache|0;
 $lhsIndex = $lhsIndex|0;
 $rhsIndex = $rhsIndex|0;
 $timeOffset = Math_fround($timeOffset);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0;
 var $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0);
 var $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($lhsIndex*40)|0)|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 + $timeOffset);
 $5 = (($cache) + 4|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($1) + (($rhsIndex*40)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 + $timeOffset);
 $9 = (($cache) + 8|0);
 HEAPF32[$9>>2] = $8;
 HEAP32[$cache>>2] = $lhsIndex;
 $10 = Math_fround(HEAPF32[$6>>2]);
 $11 = Math_fround(HEAPF32[$2>>2]);
 $12 = Math_fround($10 - $11);
 $13 = $12 < Math_fround(9.99999974737875163555E-5);
 $14 = $13 ? Math_fround(9.99999974737875163555E-5) : $12;
 $15 = ((($1) + (($lhsIndex*40)|0)|0) + 4|0);
 $16 = ((($1) + (($rhsIndex*40)|0)|0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround(HEAPF32[$15>>2]);
 $19 = Math_fround($17 - $18);
 $20 = ((($1) + (($rhsIndex*40)|0)|0) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = ((($1) + (($lhsIndex*40)|0)|0) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 - $23);
 $25 = ((($1) + (($rhsIndex*40)|0)|0) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = ((($1) + (($lhsIndex*40)|0)|0) + 12|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($26 - $28);
 $30 = Math_fround($14 * $14);
 $31 = Math_fround(Math_fround(1.0) / $30);
 $32 = ((($1) + (($lhsIndex*40)|0)|0) + 28|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = ((($1) + (($lhsIndex*40)|0)|0) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = ((($1) + (($lhsIndex*40)|0)|0) + 36|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = ((($1) + (($rhsIndex*40)|0)|0) + 16|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = ((($1) + (($rhsIndex*40)|0)|0) + 20|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = ((($1) + (($rhsIndex*40)|0)|0) + 24|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($14 * $33);
 $45 = Math_fround($14 * $35);
 $46 = Math_fround($14 * $37);
 $47 = Math_fround($14 * $39);
 $48 = Math_fround($14 * $41);
 $49 = Math_fround($14 * $43);
 $50 = Math_fround($44 + $47);
 $51 = Math_fround($45 + $48);
 $52 = Math_fround($46 + $49);
 $53 = Math_fround($50 - $19);
 $54 = Math_fround($51 - $24);
 $55 = Math_fround($52 - $29);
 $56 = Math_fround($53 - $19);
 $57 = Math_fround($54 - $24);
 $58 = Math_fround($55 - $29);
 $59 = Math_fround($31 * $56);
 $60 = Math_fround($31 * $57);
 $61 = Math_fround($31 * $58);
 $62 = Math_fround($59 / $14);
 $63 = Math_fround($60 / $14);
 $64 = Math_fround($61 / $14);
 $65 = (($cache) + 12|0);
 HEAPF32[$65>>2] = $62;
 $66 = (($cache) + 16|0);
 HEAPF32[$66>>2] = $63;
 $67 = (($cache) + 20|0);
 HEAPF32[$67>>2] = $64;
 $68 = Math_fround($19 + $19);
 $69 = Math_fround($24 + $24);
 $70 = Math_fround($29 + $29);
 $71 = Math_fround($19 + $68);
 $72 = Math_fround($24 + $69);
 $73 = Math_fround($29 + $70);
 $74 = Math_fround($71 - $44);
 $75 = Math_fround($72 - $45);
 $76 = Math_fround($73 - $46);
 $77 = Math_fround($74 - $44);
 $78 = Math_fround($75 - $45);
 $79 = Math_fround($76 - $46);
 $80 = Math_fround($77 - $47);
 $81 = Math_fround($78 - $48);
 $82 = Math_fround($79 - $49);
 $83 = Math_fround($31 * $80);
 $84 = Math_fround($31 * $81);
 $85 = Math_fround($31 * $82);
 $86 = (($cache) + 24|0);
 HEAPF32[$86>>2] = $83;
 $87 = (($cache) + 28|0);
 HEAPF32[$87>>2] = $84;
 $88 = (($cache) + 32|0);
 HEAPF32[$88>>2] = $85;
 $89 = (($cache) + 36|0);
 HEAPF32[$89>>2] = $33;
 $90 = (($cache) + 40|0);
 HEAPF32[$90>>2] = $35;
 $91 = (($cache) + 44|0);
 HEAPF32[$91>>2] = $37;
 $92 = (($cache) + 48|0);
 ;HEAP32[$92+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$15+8>>2]|0;
 $93 = ((($1) + (($lhsIndex*40)|0)|0) + 4|0);
 $94 = (($cache) + 48|0);
 $95 = Math_fround(HEAPF32[$32>>2]);
 $96 = $95 == Math_fround(inf);
 if ($96) {
  label = 3;
 } else {
  $97 = Math_fround(HEAPF32[$38>>2]);
  $98 = $97 == Math_fround(inf);
  if ($98) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  HEAPF32[$65>>2] = Math_fround(0.0);
  HEAPF32[$86>>2] = Math_fround(0.0);
  HEAPF32[$89>>2] = Math_fround(0.0);
  $99 = Math_fround(HEAPF32[$93>>2]);
  HEAPF32[$94>>2] = $99;
 }
 $100 = (($32) + 4|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = $101 == Math_fround(inf);
 if ($102) {
  label = 6;
 } else {
  $103 = (($38) + 4|0);
  $104 = Math_fround(HEAPF32[$103>>2]);
  $105 = $104 == Math_fround(inf);
  if ($105) {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $106 = (($65) + 4|0);
  HEAPF32[$106>>2] = Math_fround(0.0);
  $107 = (($86) + 4|0);
  HEAPF32[$107>>2] = Math_fround(0.0);
  $108 = (($89) + 4|0);
  HEAPF32[$108>>2] = Math_fround(0.0);
  $109 = (($93) + 4|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = (($94) + 4|0);
  HEAPF32[$111>>2] = $110;
 }
 $112 = (($32) + 8|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = $113 == Math_fround(inf);
 if (!($114)) {
  $115 = (($38) + 8|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = $116 == Math_fround(inf);
  if (!($117)) {
   STACKTOP = sp;return;
  }
 }
 $118 = (($65) + 8|0);
 HEAPF32[$118>>2] = Math_fround(0.0);
 $119 = (($86) + 8|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($89) + 8|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($93) + 8|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($94) + 8|0);
 HEAPF32[$123>>2] = $122;
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplI8Vector3fE15InvalidateCacheEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = Math_fround(inf);
 HEAP32[$this>>2] = 0;
 $1 = (($this) + 64|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 $2 = (($this) + 60|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplI11QuaternionfE8GetRangeEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAPF32[$agg$result>>2] = Math_fround(inf);
  $10 = (($agg$result) + 4|0);
  HEAPF32[$10>>2] = Math_fround(-inf);
  STACKTOP = sp;return;
 } else {
  $3 = (($this) + 152|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($1) + -1)|0;
  $7 = (($4) + (($6*52)|0)|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$agg$result>>2] = $5;
  $9 = (($agg$result) + 4|0);
  HEAPF32[$9>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNK17AnimationCurveTplI11QuaternionfE20FindIndexForSamplingERKNS1_5CacheEfRiS5_($this,$cache,$curveT,$lhs,$rhs) {
 $this = $this|0;
 $cache = $cache|0;
 $curveT = Math_fround($curveT);
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, $i$06 = 0, $i1$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$cache>>2]|0;
 $5 = ($4|0)==(-1);
 L1: do {
  if ($5) {
   $$ph = 0;$__len$0$ph = $1;
  } else {
   $6 = (($3) + (($4*52)|0)|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 < $curveT;
   if ($8) {
    $i$06 = 0;
    while(1) {
     $9 = (($i$06) + ($4))|0;
     $10 = (($9) + 1)|0;
     $11 = ($10|0)<($1|0);
     if ($11) {
      $12 = (($3) + (($10*52)|0)|0);
      $13 = Math_fround(HEAPF32[$12>>2]);
      $14 = $13 > $curveT;
      if ($14) {
       break;
      }
     }
     $18 = (($i$06) + 1)|0;
     $19 = ($18|0)<(3);
     if ($19) {
      $i$06 = $18;
     } else {
      $$ph = 0;$__len$0$ph = $1;
      break L1;
     }
    }
    HEAP32[$lhs>>2] = $9;
    $15 = (($1) + -1)|0;
    $16 = ($15|0)<($10|0);
    $17 = $16 ? $15 : $10;
    HEAP32[$rhs>>2] = $17;
    STACKTOP = sp;return;
   } else {
    $i1$010 = 0;
    while(1) {
     $20 = (($4) - ($i1$010))|0;
     $21 = ($20|0)>(-1);
     if ($21) {
      $22 = (($3) + (($20*52)|0)|0);
      $23 = Math_fround(HEAPF32[$22>>2]);
      $24 = !($23 <= $curveT);
      if (!($24)) {
       break;
      }
     }
     $29 = (($i1$010) + 1)|0;
     $30 = ($29|0)<(3);
     if ($30) {
      $i1$010 = $29;
     } else {
      $$ph = 0;$__len$0$ph = $1;
      break L1;
     }
    }
    HEAP32[$lhs>>2] = $20;
    $25 = (($20) + 1)|0;
    $26 = (($1) + -1)|0;
    $27 = ($26|0)<($25|0);
    $28 = $27 ? $26 : $25;
    HEAP32[$rhs>>2] = $28;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 L18: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $31 = ($__len$0|0)>(0);
   if (!($31)) {
    break L18;
   }
   $32 = $__len$0 >> 1;
   $33 = (($32) + ($$ph))|0;
   $34 = (($3) + (($33*52)|0)|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = $35 > $curveT;
   if ($36) {
    $__len$0 = $32;
   } else {
    break;
   }
  }
  $37 = (($33) + 1)|0;
  $38 = (($__len$0) + -1)|0;
  $39 = (($38) - ($32))|0;
  $$ph = $37;$__len$0$ph = $39;
 }
 $40 = (($$ph) + -1)|0;
 HEAP32[$lhs>>2] = $40;
 $41 = (($1) + -1)|0;
 $42 = ($$ph|0)<($41|0);
 $43 = $42 ? $$ph : $41;
 HEAP32[$rhs>>2] = $43;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplI11QuaternionfE18CalculateCacheDataERNS1_5CacheEiif($this,$cache,$lhsIndex,$rhsIndex,$timeOffset) {
 $this = $this|0;
 $cache = $cache|0;
 $lhsIndex = $lhsIndex|0;
 $rhsIndex = $rhsIndex|0;
 $timeOffset = Math_fround($timeOffset);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0);
 var $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($lhsIndex*52)|0)|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 + $timeOffset);
 $5 = (($cache) + 4|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($1) + (($rhsIndex*52)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 + $timeOffset);
 $9 = (($cache) + 8|0);
 HEAPF32[$9>>2] = $8;
 HEAP32[$cache>>2] = $lhsIndex;
 $10 = Math_fround(HEAPF32[$6>>2]);
 $11 = Math_fround(HEAPF32[$2>>2]);
 $12 = Math_fround($10 - $11);
 $13 = $12 < Math_fround(9.99999974737875163555E-5);
 $14 = $13 ? Math_fround(9.99999974737875163555E-5) : $12;
 $15 = ((($1) + (($lhsIndex*52)|0)|0) + 4|0);
 $16 = ((($1) + (($rhsIndex*52)|0)|0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = ((($1) + (($rhsIndex*52)|0)|0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($1) + (($rhsIndex*52)|0)|0) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = ((($1) + (($rhsIndex*52)|0)|0) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround(HEAPF32[$15>>2]);
 $25 = Math_fround($17 - $24);
 $26 = ((($1) + (($lhsIndex*52)|0)|0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($19 - $27);
 $29 = ((($1) + (($lhsIndex*52)|0)|0) + 12|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($21 - $30);
 $32 = ((($1) + (($lhsIndex*52)|0)|0) + 16|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($23 - $33);
 $35 = Math_fround($14 * $14);
 $36 = Math_fround(Math_fround(1.0) / $35);
 $37 = ((($1) + (($lhsIndex*52)|0)|0) + 36|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = ((($1) + (($lhsIndex*52)|0)|0) + 40|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = ((($1) + (($lhsIndex*52)|0)|0) + 44|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = ((($1) + (($lhsIndex*52)|0)|0) + 48|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = ((($1) + (($rhsIndex*52)|0)|0) + 20|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = ((($1) + (($rhsIndex*52)|0)|0) + 24|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = ((($1) + (($rhsIndex*52)|0)|0) + 28|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = ((($1) + (($rhsIndex*52)|0)|0) + 32|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($14 * $38);
 $54 = Math_fround($14 * $40);
 $55 = Math_fround($14 * $42);
 $56 = Math_fround($14 * $44);
 $57 = Math_fround($14 * $46);
 $58 = Math_fround($14 * $48);
 $59 = Math_fround($14 * $50);
 $60 = Math_fround($14 * $52);
 $61 = Math_fround($53 + $57);
 $62 = Math_fround($54 + $58);
 $63 = Math_fround($55 + $59);
 $64 = Math_fround($56 + $60);
 $65 = Math_fround($61 - $25);
 $66 = Math_fround($62 - $28);
 $67 = Math_fround($63 - $31);
 $68 = Math_fround($64 - $34);
 $69 = Math_fround($65 - $25);
 $70 = Math_fround($66 - $28);
 $71 = Math_fround($67 - $31);
 $72 = Math_fround($68 - $34);
 $73 = Math_fround($36 * $69);
 $74 = Math_fround($36 * $70);
 $75 = Math_fround($36 * $71);
 $76 = Math_fround($36 * $72);
 $77 = Math_fround($73 / $14);
 $78 = Math_fround($74 / $14);
 $79 = Math_fround($75 / $14);
 $80 = Math_fround($76 / $14);
 $81 = (($cache) + 12|0);
 HEAPF32[$81>>2] = $77;
 $82 = (($cache) + 16|0);
 HEAPF32[$82>>2] = $78;
 $83 = (($cache) + 20|0);
 HEAPF32[$83>>2] = $79;
 $84 = (($cache) + 24|0);
 HEAPF32[$84>>2] = $80;
 $85 = Math_fround($25 + $25);
 $86 = Math_fround($28 + $28);
 $87 = Math_fround($31 + $31);
 $88 = Math_fround($34 + $34);
 $89 = Math_fround($25 + $85);
 $90 = Math_fround($28 + $86);
 $91 = Math_fround($31 + $87);
 $92 = Math_fround($34 + $88);
 $93 = Math_fround($89 - $53);
 $94 = Math_fround($90 - $54);
 $95 = Math_fround($91 - $55);
 $96 = Math_fround($92 - $56);
 $97 = Math_fround($93 - $53);
 $98 = Math_fround($94 - $54);
 $99 = Math_fround($95 - $55);
 $100 = Math_fround($96 - $56);
 $101 = Math_fround($97 - $57);
 $102 = Math_fround($98 - $58);
 $103 = Math_fround($99 - $59);
 $104 = Math_fround($100 - $60);
 $105 = Math_fround($36 * $101);
 $106 = Math_fround($36 * $102);
 $107 = Math_fround($36 * $103);
 $108 = Math_fround($36 * $104);
 $109 = (($cache) + 28|0);
 HEAPF32[$109>>2] = $105;
 $110 = (($cache) + 32|0);
 HEAPF32[$110>>2] = $106;
 $111 = (($cache) + 36|0);
 HEAPF32[$111>>2] = $107;
 $112 = (($cache) + 40|0);
 HEAPF32[$112>>2] = $108;
 $113 = (($cache) + 44|0);
 HEAPF32[$113>>2] = $38;
 $114 = (($cache) + 48|0);
 HEAPF32[$114>>2] = $40;
 $115 = (($cache) + 52|0);
 HEAPF32[$115>>2] = $42;
 $116 = (($cache) + 56|0);
 HEAPF32[$116>>2] = $44;
 $117 = (($cache) + 60|0);
 ;HEAP32[$117+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$117+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$117+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$117+12>>2]=HEAP32[$15+12>>2]|0;
 $118 = Math_fround(HEAPF32[$37>>2]);
 $119 = $118 == Math_fround(inf);
 if (!($119)) {
  $120 = Math_fround(HEAPF32[$45>>2]);
  $121 = $120 == Math_fround(inf);
  if (!($121)) {
   $122 = (($37) + 4|0);
   $123 = Math_fround(HEAPF32[$122>>2]);
   $124 = $123 == Math_fround(inf);
   if (!($124)) {
    $125 = (($45) + 4|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = $126 == Math_fround(inf);
    if (!($127)) {
     $128 = (($37) + 8|0);
     $129 = Math_fround(HEAPF32[$128>>2]);
     $130 = $129 == Math_fround(inf);
     if (!($130)) {
      $131 = (($45) + 8|0);
      $132 = Math_fround(HEAPF32[$131>>2]);
      $133 = $132 == Math_fround(inf);
      if (!($133)) {
       $134 = (($37) + 12|0);
       $135 = Math_fround(HEAPF32[$134>>2]);
       $136 = $135 == Math_fround(inf);
       if (!($136)) {
        $137 = (($45) + 12|0);
        $138 = Math_fround(HEAPF32[$137>>2]);
        $139 = $138 == Math_fround(inf);
        if (!($139)) {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $140 = ((($1) + (($lhsIndex*52)|0)|0) + 4|0);
 $141 = (($cache) + 60|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 HEAPF32[$109>>2] = Math_fround(0.0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $142 = Math_fround(HEAPF32[$140>>2]);
 HEAPF32[$141>>2] = $142;
 $143 = (($81) + 4|0);
 HEAPF32[$143>>2] = Math_fround(0.0);
 $144 = (($109) + 4|0);
 HEAPF32[$144>>2] = Math_fround(0.0);
 $145 = (($113) + 4|0);
 HEAPF32[$145>>2] = Math_fround(0.0);
 $146 = (($140) + 4|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = (($141) + 4|0);
 HEAPF32[$148>>2] = $147;
 $149 = (($81) + 8|0);
 HEAPF32[$149>>2] = Math_fround(0.0);
 $150 = (($109) + 8|0);
 HEAPF32[$150>>2] = Math_fround(0.0);
 $151 = (($113) + 8|0);
 HEAPF32[$151>>2] = Math_fround(0.0);
 $152 = (($140) + 8|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = (($141) + 8|0);
 HEAPF32[$154>>2] = $153;
 $155 = (($81) + 12|0);
 HEAPF32[$155>>2] = Math_fround(0.0);
 $156 = (($109) + 12|0);
 HEAPF32[$156>>2] = Math_fround(0.0);
 $157 = (($113) + 12|0);
 HEAPF32[$157>>2] = Math_fround(0.0);
 $158 = (($140) + 12|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($141) + 12|0);
 HEAPF32[$160>>2] = $159;
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplI11QuaternionfE15InvalidateCacheEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = Math_fround(inf);
 HEAP32[$this>>2] = 0;
 $1 = (($this) + 80|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 $2 = (($this) + 76|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplIfE13EvaluateClampEf($this,$curveT) {
 $this = $this|0;
 $curveT = Math_fround($curveT);
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $12 = Math_fround(0), $13 = 0;
 var $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0);
 var $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0);
 var $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0);
 var $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $lhs = 0, $rhs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $lhs = sp + 4|0;
 $rhs = sp;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if ($2) {
  $3 = (($this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $113 = $6;
  STACKTOP = sp;return (Math_fround($113));
 }
 $7 = (($this) + 28|0);
 $8 = (($this) + 32|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = !($9 <= $curveT);
 if (!($10)) {
  $11 = (($this) + 36|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = $12 > $curveT;
  if ($13) {
   $14 = Math_fround($curveT - $9);
   $15 = (($this) + 40|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($14 * $16);
   $18 = (($this) + 44|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround($17 + $19);
   $21 = Math_fround($14 * $20);
   $22 = (($this) + 48|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($23 + $21);
   $25 = Math_fround($14 * $24);
   $26 = (($this) + 52|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($27 + $25);
   $113 = $28;
   STACKTOP = sp;return (Math_fround($113));
  }
 }
 $29 = (($this) + 56|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($1) + -1)|0;
 $33 = (($30) + ($32<<4)|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = $34 < $curveT;
 do {
  if ($35) {
   HEAPF32[$8>>2] = $34;
   $36 = (($this) + 36|0);
   HEAPF32[$36>>2] = Math_fround(inf);
   $37 = (($this) + 48|0);
   HEAPF32[$37>>2] = Math_fround(0.0);
   $38 = (($this) + 44|0);
   HEAPF32[$38>>2] = Math_fround(0.0);
   $39 = (($this) + 40|0);
   HEAPF32[$39>>2] = Math_fround(0.0);
   $40 = ((($30) + ($32<<4)|0) + 4|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = (($this) + 52|0);
   HEAPF32[$42>>2] = $41;
   $102 = $34;$104 = Math_fround(0.0);$106 = Math_fround(0.0);$109 = Math_fround(0.0);$112 = $41;
  } else {
   $43 = $31 > $curveT;
   if ($43) {
    $44 = Math_fround($curveT + Math_fround(-1000.0));
    HEAPF32[$8>>2] = $44;
    $45 = (($this) + 36|0);
    HEAPF32[$45>>2] = $31;
    $46 = (($this) + 48|0);
    HEAPF32[$46>>2] = Math_fround(0.0);
    $47 = (($this) + 44|0);
    HEAPF32[$47>>2] = Math_fround(0.0);
    $48 = (($this) + 40|0);
    HEAPF32[$48>>2] = Math_fround(0.0);
    $49 = (($30) + 4|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = (($this) + 52|0);
    HEAPF32[$51>>2] = $50;
    $102 = $44;$104 = Math_fround(0.0);$106 = Math_fround(0.0);$109 = Math_fround(0.0);$112 = $50;
    break;
   }
   __ZNK17AnimationCurveTplIfE20FindIndexForSamplingERKNS0_5CacheEfRiS4_($this,$7,$curveT,$lhs,$rhs);
   $52 = HEAP32[$lhs>>2]|0;
   $53 = HEAP32[$rhs>>2]|0;
   $54 = HEAP32[$29>>2]|0;
   $55 = (($54) + ($52<<4)|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   $57 = Math_fround($56 + Math_fround(0.0));
   HEAPF32[$8>>2] = $57;
   $58 = (($54) + ($53<<4)|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = Math_fround($59 + Math_fround(0.0));
   $61 = (($this) + 36|0);
   HEAPF32[$61>>2] = $60;
   HEAP32[$7>>2] = $52;
   $62 = Math_fround(HEAPF32[$58>>2]);
   $63 = Math_fround(HEAPF32[$55>>2]);
   $64 = Math_fround($62 - $63);
   $65 = $64 < Math_fround(9.99999974737875163555E-5);
   $66 = $65 ? Math_fround(9.99999974737875163555E-5) : $64;
   $67 = ((($54) + ($53<<4)|0) + 4|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = ((($54) + ($52<<4)|0) + 4|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = Math_fround($68 - $70);
   $72 = Math_fround($66 * $66);
   $73 = Math_fround(Math_fround(1.0) / $72);
   $74 = ((($54) + ($52<<4)|0) + 12|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $76 = ((($54) + ($53<<4)|0) + 8|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = Math_fround($66 * $75);
   $79 = Math_fround($66 * $77);
   $80 = Math_fround($78 + $79);
   $81 = Math_fround($80 - $71);
   $82 = Math_fround($81 - $71);
   $83 = Math_fround($73 * $82);
   $84 = Math_fround($83 / $66);
   $85 = (($this) + 40|0);
   HEAPF32[$85>>2] = $84;
   $86 = Math_fround($71 + $71);
   $87 = Math_fround($71 + $86);
   $88 = Math_fround($87 - $78);
   $89 = Math_fround($88 - $78);
   $90 = Math_fround($89 - $79);
   $91 = Math_fround($73 * $90);
   $92 = (($this) + 44|0);
   HEAPF32[$92>>2] = $91;
   $93 = (($this) + 48|0);
   HEAPF32[$93>>2] = $75;
   $94 = Math_fround(HEAPF32[$69>>2]);
   $95 = (($this) + 52|0);
   HEAPF32[$95>>2] = $94;
   $96 = Math_fround(HEAPF32[$74>>2]);
   $97 = $96 == Math_fround(inf);
   if (!($97)) {
    $98 = Math_fround(HEAPF32[$76>>2]);
    $99 = $98 == Math_fround(inf);
    if (!($99)) {
     $102 = $57;$104 = $84;$106 = $91;$109 = $75;$112 = $94;
     break;
    }
   }
   HEAPF32[$85>>2] = Math_fround(0.0);
   HEAPF32[$92>>2] = Math_fround(0.0);
   HEAPF32[$93>>2] = Math_fround(0.0);
   $100 = Math_fround(HEAPF32[$69>>2]);
   HEAPF32[$95>>2] = $100;
   $102 = $57;$104 = Math_fround(0.0);$106 = Math_fround(0.0);$109 = Math_fround(0.0);$112 = $100;
  }
 } while(0);
 $101 = Math_fround($curveT - $102);
 $103 = Math_fround($101 * $104);
 $105 = Math_fround($103 + $106);
 $107 = Math_fround($101 * $105);
 $108 = Math_fround($109 + $107);
 $110 = Math_fround($101 * $108);
 $111 = Math_fround($112 + $110);
 $113 = $111;
 STACKTOP = sp;return (Math_fround($113));
}
function __ZNK17AnimationCurveTplI11QuaternionfE13EvaluateClampEf($agg$result,$this,$curveT) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $curveT = Math_fround($curveT);
 var $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0;
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0);
 var $lhs = 0, $rhs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $lhs = sp + 16|0;
 $rhs = sp + 20|0;
 $2 = (($this) + 160|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1);
 if ($4) {
  $5 = (($this) + 152|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 4|0);
  ;HEAP32[$agg$result+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$7+12>>2]|0;
  STACKTOP = sp;return;
 }
 $8 = (($this) + 76|0);
 $9 = (($this) + 80|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = !($10 <= $curveT);
 if (!($11)) {
  $12 = (($this) + 84|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = $13 > $curveT;
  if ($14) {
   $15 = Math_fround($curveT - $10);
   $16 = (($this) + 88|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = (($this) + 92|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = (($this) + 96|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = (($this) + 100|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($17 * $15);
   $25 = Math_fround($15 * $19);
   $26 = Math_fround($15 * $21);
   $27 = Math_fround($15 * $23);
   $28 = (($this) + 104|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($24 + $29);
   $31 = (($this) + 108|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = Math_fround($25 + $32);
   $34 = (($this) + 112|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = Math_fround($26 + $35);
   $37 = (($this) + 116|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($27 + $38);
   $40 = Math_fround($15 * $30);
   $41 = Math_fround($15 * $33);
   $42 = Math_fround($15 * $36);
   $43 = Math_fround($15 * $39);
   $44 = (($this) + 120|0);
   $45 = Math_fround(HEAPF32[$44>>2]);
   $46 = Math_fround($40 + $45);
   $47 = (($this) + 124|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = Math_fround($41 + $48);
   $50 = (($this) + 128|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = Math_fround($42 + $51);
   $53 = (($this) + 132|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = Math_fround($43 + $54);
   $56 = Math_fround($15 * $46);
   $57 = Math_fround($15 * $49);
   $58 = Math_fround($15 * $52);
   $59 = Math_fround($15 * $55);
   $60 = (($this) + 136|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = Math_fround($56 + $61);
   $63 = (($this) + 140|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = Math_fround($57 + $64);
   $66 = (($this) + 144|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = Math_fround($58 + $67);
   $69 = (($this) + 148|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = Math_fround($59 + $70);
   HEAPF32[$agg$result>>2] = $62;
   $72 = (($agg$result) + 4|0);
   HEAPF32[$72>>2] = $65;
   $73 = (($agg$result) + 8|0);
   HEAPF32[$73>>2] = $68;
   $74 = (($agg$result) + 12|0);
   HEAPF32[$74>>2] = $71;
   STACKTOP = sp;return;
  }
 }
 $75 = (($this) + 152|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($3) + -1)|0;
 $79 = (($76) + (($78*52)|0)|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = $80 < $curveT;
 do {
  if ($81) {
   HEAPF32[$9>>2] = $80;
   $82 = (($this) + 84|0);
   HEAPF32[$82>>2] = Math_fround(inf);
   $83 = (($this) + 88|0);
   $84 = (($this) + 104|0);
   $85 = (($this) + 120|0);
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   ;HEAP32[$85+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$85+12>>2]=HEAP32[$0+12>>2]|0;
   ;HEAP32[$84+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$84+12>>2]=HEAP32[$0+12>>2]|0;
   ;HEAP32[$83+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$83+12>>2]=HEAP32[$0+12>>2]|0;
   $86 = (($this) + 136|0);
   $87 = ((($76) + (($78*52)|0)|0) + 4|0);
   ;HEAP32[$86+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$86+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$86+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$86+12>>2]=HEAP32[$87+12>>2]|0;
   $99 = $80;
  } else {
   $88 = $77 > $curveT;
   if ($88) {
    $89 = Math_fround($curveT + Math_fround(-1000.0));
    HEAPF32[$9>>2] = $89;
    $90 = (($this) + 84|0);
    HEAPF32[$90>>2] = $77;
    $91 = (($this) + 88|0);
    $92 = (($this) + 104|0);
    $93 = (($this) + 120|0);
    ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
    ;HEAP32[$93+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$93+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$92+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$92+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$91+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$91+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$91+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$91+12>>2]=HEAP32[$1+12>>2]|0;
    $94 = (($this) + 136|0);
    $95 = (($76) + 4|0);
    ;HEAP32[$94+0>>2]=HEAP32[$95+0>>2]|0;HEAP32[$94+4>>2]=HEAP32[$95+4>>2]|0;HEAP32[$94+8>>2]=HEAP32[$95+8>>2]|0;HEAP32[$94+12>>2]=HEAP32[$95+12>>2]|0;
    $99 = $89;
    break;
   } else {
    __ZNK17AnimationCurveTplI11QuaternionfE20FindIndexForSamplingERKNS1_5CacheEfRiS5_($this,$8,$curveT,$lhs,$rhs);
    $96 = HEAP32[$lhs>>2]|0;
    $97 = HEAP32[$rhs>>2]|0;
    __ZNK17AnimationCurveTplI11QuaternionfE18CalculateCacheDataERNS1_5CacheEiif($this,$8,$96,$97,Math_fround(0.0));
    $$pre = Math_fround(HEAPF32[$9>>2]);
    $99 = $$pre;
    break;
   }
  }
 } while(0);
 $98 = Math_fround($curveT - $99);
 $100 = (($this) + 88|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($this) + 92|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($this) + 96|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($this) + 100|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($101 * $98);
 $109 = Math_fround($98 * $103);
 $110 = Math_fround($98 * $105);
 $111 = Math_fround($98 * $107);
 $112 = (($this) + 104|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = Math_fround($108 + $113);
 $115 = (($this) + 108|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($109 + $116);
 $118 = (($this) + 112|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround($110 + $119);
 $121 = (($this) + 116|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = Math_fround($111 + $122);
 $124 = Math_fround($98 * $114);
 $125 = Math_fround($98 * $117);
 $126 = Math_fround($98 * $120);
 $127 = Math_fround($98 * $123);
 $128 = (($this) + 120|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($124 + $129);
 $131 = (($this) + 124|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($125 + $132);
 $134 = (($this) + 128|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($126 + $135);
 $137 = (($this) + 132|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($127 + $138);
 $140 = Math_fround($98 * $130);
 $141 = Math_fround($98 * $133);
 $142 = Math_fround($98 * $136);
 $143 = Math_fround($98 * $139);
 $144 = (($this) + 136|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround($140 + $145);
 $147 = (($this) + 140|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = Math_fround($141 + $148);
 $150 = (($this) + 144|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = Math_fround($142 + $151);
 $153 = (($this) + 148|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = Math_fround($143 + $154);
 HEAPF32[$agg$result>>2] = $146;
 $156 = (($agg$result) + 4|0);
 HEAPF32[$156>>2] = $149;
 $157 = (($agg$result) + 8|0);
 HEAPF32[$157>>2] = $152;
 $158 = (($agg$result) + 12|0);
 HEAPF32[$158>>2] = $155;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplI8Vector3fE13EvaluateClampEf($agg$result,$this,$curveT) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $curveT = Math_fround($curveT);
 var $$phi$trans$insert = 0, $$phi$trans$insert5 = 0, $$phi$trans$insert7 = 0, $$pre = Math_fround(0), $$pre4 = Math_fround(0), $$pre6 = Math_fround(0), $$pre8 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0);
 var $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0);
 var $128 = 0, $129 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0;
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $lhs = 0, $rhs = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $lhs = sp + 4|0;
 $rhs = sp;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 if ($2) {
  $3 = (($this) + 120|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 4|0);
  ;HEAP32[$agg$result+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$5+8>>2]|0;
  STACKTOP = sp;return;
 }
 $6 = (($this) + 60|0);
 $7 = (($this) + 64|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = !($8 <= $curveT);
 if (!($9)) {
  $10 = (($this) + 68|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = $11 > $curveT;
  if ($12) {
   $13 = Math_fround($curveT - $8);
   $14 = (($this) + 72|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($15 * $13);
   $17 = (($this) + 76|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = Math_fround($13 * $18);
   $20 = (($this) + 80|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = Math_fround($13 * $21);
   $23 = (($this) + 84|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($16 + $24);
   $26 = (($this) + 88|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($19 + $27);
   $29 = (($this) + 92|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = Math_fround($22 + $30);
   $32 = Math_fround($13 * $25);
   $33 = Math_fround($13 * $28);
   $34 = Math_fround($13 * $31);
   $35 = (($this) + 96|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = Math_fround($32 + $36);
   $38 = (($this) + 100|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = Math_fround($33 + $39);
   $41 = (($this) + 104|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = Math_fround($34 + $42);
   $44 = Math_fround($13 * $37);
   $45 = Math_fround($13 * $40);
   $46 = Math_fround($13 * $43);
   $47 = (($this) + 108|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = Math_fround($44 + $48);
   $50 = (($this) + 112|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = Math_fround($45 + $51);
   $53 = (($this) + 116|0);
   $54 = Math_fround(HEAPF32[$53>>2]);
   $55 = Math_fround($46 + $54);
   HEAPF32[$agg$result>>2] = $49;
   $56 = (($agg$result) + 4|0);
   HEAPF32[$56>>2] = $52;
   $57 = (($agg$result) + 8|0);
   HEAPF32[$57>>2] = $55;
   STACKTOP = sp;return;
  }
 }
 $58 = (($this) + 120|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($1) + -1)|0;
 $62 = (($59) + (($61*40)|0)|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = $63 < $curveT;
 do {
  if ($64) {
   HEAPF32[$7>>2] = $63;
   $65 = (($this) + 68|0);
   HEAPF32[$65>>2] = Math_fround(inf);
   $66 = (($this) + 72|0);
   $67 = (($this) + 84|0);
   $68 = (($this) + 96|0);
   $69 = (($this) + 96|0);
   HEAPF32[$69>>2] = Math_fround(0.0);
   $70 = (($this) + 100|0);
   HEAPF32[$70>>2] = Math_fround(0.0);
   $71 = (($this) + 104|0);
   HEAPF32[$71>>2] = Math_fround(0.0);
   ;HEAP32[$67+0>>2]=HEAP32[$68+0>>2]|0;HEAP32[$67+4>>2]=HEAP32[$68+4>>2]|0;HEAP32[$67+8>>2]=HEAP32[$68+8>>2]|0;
   ;HEAP32[$66+0>>2]=HEAP32[$68+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$68+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$68+8>>2]|0;
   $72 = (($this) + 108|0);
   $73 = ((($59) + (($61*40)|0)|0) + 4|0);
   ;HEAP32[$72+0>>2]=HEAP32[$73+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$73+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$73+8>>2]|0;
   $111 = Math_fround(0.0);$113 = Math_fround(0.0);$115 = Math_fround(0.0);$88 = $63;
  } else {
   $74 = $60 > $curveT;
   if ($74) {
    $75 = Math_fround($curveT + Math_fround(-1000.0));
    HEAPF32[$7>>2] = $75;
    $76 = (($this) + 68|0);
    HEAPF32[$76>>2] = $60;
    $77 = (($this) + 72|0);
    $78 = (($this) + 84|0);
    $79 = (($this) + 96|0);
    $80 = (($this) + 96|0);
    HEAPF32[$80>>2] = Math_fround(0.0);
    $81 = (($this) + 100|0);
    HEAPF32[$81>>2] = Math_fround(0.0);
    $82 = (($this) + 104|0);
    HEAPF32[$82>>2] = Math_fround(0.0);
    ;HEAP32[$78+0>>2]=HEAP32[$79+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$79+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$79+8>>2]|0;
    ;HEAP32[$77+0>>2]=HEAP32[$79+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$79+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$79+8>>2]|0;
    $83 = (($this) + 108|0);
    $84 = (($59) + 4|0);
    ;HEAP32[$83+0>>2]=HEAP32[$84+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$84+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$84+8>>2]|0;
    $111 = Math_fround(0.0);$113 = Math_fround(0.0);$115 = Math_fround(0.0);$88 = $75;
    break;
   } else {
    __ZNK17AnimationCurveTplI8Vector3fE20FindIndexForSamplingERKNS1_5CacheEfRiS5_($this,$6,$curveT,$lhs,$rhs);
    $85 = HEAP32[$lhs>>2]|0;
    $86 = HEAP32[$rhs>>2]|0;
    __ZNK17AnimationCurveTplI8Vector3fE18CalculateCacheDataERNS1_5CacheEiif($this,$6,$85,$86,Math_fround(0.0));
    $$pre = Math_fround(HEAPF32[$7>>2]);
    $$phi$trans$insert = (($this) + 96|0);
    $$pre4 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
    $$phi$trans$insert5 = (($this) + 100|0);
    $$pre6 = Math_fround(HEAPF32[$$phi$trans$insert5>>2]);
    $$phi$trans$insert7 = (($this) + 104|0);
    $$pre8 = Math_fround(HEAPF32[$$phi$trans$insert7>>2]);
    $111 = $$pre4;$113 = $$pre6;$115 = $$pre8;$88 = $$pre;
    break;
   }
  }
 } while(0);
 $87 = Math_fround($curveT - $88);
 $89 = (($this) + 72|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($90 * $87);
 $92 = (($this) + 76|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($87 * $93);
 $95 = (($this) + 80|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($87 * $96);
 $98 = (($this) + 84|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($91 + $99);
 $101 = (($this) + 88|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($94 + $102);
 $104 = (($this) + 92|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($97 + $105);
 $107 = Math_fround($87 * $100);
 $108 = Math_fround($87 * $103);
 $109 = Math_fround($87 * $106);
 $110 = Math_fround($107 + $111);
 $112 = Math_fround($108 + $113);
 $114 = Math_fround($109 + $115);
 $116 = Math_fround($87 * $110);
 $117 = Math_fround($87 * $112);
 $118 = Math_fround($87 * $114);
 $119 = (($this) + 108|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($116 + $120);
 $122 = (($this) + 112|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($117 + $123);
 $125 = (($this) + 116|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($118 + $126);
 HEAPF32[$agg$result>>2] = $121;
 $128 = (($agg$result) + 4|0);
 HEAPF32[$128>>2] = $124;
 $129 = (($agg$result) + 8|0);
 HEAPF32[$129>>2] = $127;
 STACKTOP = sp;return;
}
function __ZNK17AnimationCurveTplIfE8WrapTimeEf($this,$curveT) {
 $this = $this|0;
 $curveT = Math_fround($curveT);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $floorf$i$i$i = Math_fround(0), $floorf$i$i$i$i = Math_fround(0), $floorf$i$i$i$i1 = Math_fround(0), $floorf$i$i$i3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 $6 = (($1) + ($5<<4)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $2 > $curveT;
 if ($8) {
  $9 = (($this) + 72|0);
  $10 = HEAP32[$9>>2]|0;
  if ((($10|0) == 0)) {
   $11 = Math_fround($curveT - $2);
   $12 = Math_fround($7 - $2);
   $13 = Math_fround($12 * Math_fround(2.0));
   $14 = Math_fround($11 / $13);
   $floorf$i$i$i$i1 = (Math_fround(Math_floor((Math_fround($14)))));
   $15 = Math_fround($13 * $floorf$i$i$i$i1);
   $16 = Math_fround($11 - $15);
   $17 = Math_fround($16 - $12);
   $18 = $17 < Math_fround(0.0);
   if ($18) {
    $19 = Math_fround(-$17);
    $21 = $19;
   } else {
    $21 = $17;
   }
   $20 = Math_fround($12 - $21);
   $22 = Math_fround($2 + $20);
   $$0 = $22;
   STACKTOP = sp;return (Math_fround($$0));
  } else if ((($10|0) == 2)) {
   $$0 = $2;
   STACKTOP = sp;return (Math_fround($$0));
  } else {
   $23 = Math_fround($curveT - $2);
   $24 = Math_fround($7 - $2);
   $25 = Math_fround($23 / $24);
   $floorf$i$i$i3 = (Math_fround(Math_floor((Math_fround($25)))));
   $26 = Math_fround($24 * $floorf$i$i$i3);
   $27 = Math_fround($23 - $26);
   $28 = Math_fround($2 + $27);
   $$0 = $28;
   STACKTOP = sp;return (Math_fround($$0));
  }
 }
 $29 = $7 < $curveT;
 if (!($29)) {
  $$0 = $curveT;
  STACKTOP = sp;return (Math_fround($$0));
 }
 $30 = (($this) + 76|0);
 $31 = HEAP32[$30>>2]|0;
 if ((($31|0) == 0)) {
  $32 = Math_fround($curveT - $2);
  $33 = Math_fround($7 - $2);
  $34 = Math_fround($33 * Math_fround(2.0));
  $35 = Math_fround($32 / $34);
  $floorf$i$i$i$i = (Math_fround(Math_floor((Math_fround($35)))));
  $36 = Math_fround($34 * $floorf$i$i$i$i);
  $37 = Math_fround($32 - $36);
  $38 = Math_fround($37 - $33);
  $39 = $38 < Math_fround(0.0);
  if ($39) {
   $40 = Math_fround(-$38);
   $42 = $40;
  } else {
   $42 = $38;
  }
  $41 = Math_fround($33 - $42);
  $43 = Math_fround($2 + $41);
  $$0 = $43;
  STACKTOP = sp;return (Math_fround($$0));
 } else if ((($31|0) == 2)) {
  $$0 = $7;
  STACKTOP = sp;return (Math_fround($$0));
 } else {
  $44 = Math_fround($curveT - $2);
  $45 = Math_fround($7 - $2);
  $46 = Math_fround($44 / $45);
  $floorf$i$i$i = (Math_fround(Math_floor((Math_fround($46)))));
  $47 = Math_fround($45 * $floorf$i$i$i);
  $48 = Math_fround($44 - $47);
  $49 = Math_fround($2 + $48);
  $$0 = $49;
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __Z25RegisterClass_AssetBundlev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(142,145,0,0,0);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 11;
 dest=$3+0|0; src=616760+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 11|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,142,130,($0|0),100,(2414|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN11AssetBundle7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(100,$$byval_copy2,1,16,616888,53)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1769,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(616888|0),53);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK11AssetBundle25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 142;
}
function __ZN11AssetBundle23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616776,616760,$this,0);
 __ZN11AssetBundle8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,616776,616760,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN11AssetBundle8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11AssetBundle8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11AssetBundle8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11AssetBundle8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11AssetBundle8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN11AssetBundleC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$1 = 0, $$12 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy1,$mode);
 HEAP32[$this>>2] = ((616784 + 8|0));
 $3 = (($this) + 28|0);
 HEAP32[$3>>2] = 1;
 $4 = (($this) + 32|0);
 $5 = (($this) + 44|0);
 $6 = (($this) + 52|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 56|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 48|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 HEAP32[$8>>2] = 61;
 $9 = (($this) + 60|0);
 $10 = (($this) + 64|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 68|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 64|0);
 HEAP32[$9>>2] = $12;
 $13 = (($this) + 72|0);
 $14 = (($this) + 84|0);
 ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(3379,($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $$1 = $26;$$12 = $25;
 } else {
  $17 = (($this) + 88|0);
  HEAP32[$17>>2] = 0;
  $18 = (($this) + 92|0);
  HEAP32[$18>>2] = 0;
  $19 = (($this) + 96|0);
  HEAP32[$19>>2] = 0;
  $20 = HEAP32[$this>>2]|0;
  $21 = (($20) + 44|0);
  $22 = HEAP32[$21>>2]|0;
  __THREW__ = 0;
  invoke_vii($22|0,($this|0),61);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   STACKTOP = sp;return;
  }
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  $29 = HEAP32[$17>>2]|0;
  $30 = ($29|0)==(0|0);
  do {
   if (!($30)) {
    while(1) {
     $31 = HEAP32[$18>>2]|0;
     $32 = ($31|0)==($29|0);
     if ($32) {
      label = 9;
      break;
     }
     $33 = (($31) + -4|0);
     HEAP32[$18>>2] = $33;
     __THREW__ = 0;
     invoke_vi(3382,($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 8;
      break;
     }
    }
    if ((label|0) == 8) {
     $36 = ___cxa_find_matching_catch()|0;
     $37 = tempRet0;
     ___cxa_call_unexpected(($36|0));
     // unreachable;
    }
    else if ((label|0) == 9) {
     $38 = HEAP32[$17>>2]|0;
     __ZdlPv($38);
     break;
    }
   }
  } while(0);
  __THREW__ = 0;
  invoke_vi(3382,($14|0));
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if ($40) {
   $50 = ___cxa_find_matching_catch(0|0)|0;
   $51 = tempRet0;
   ___clang_call_terminate($50);
   // unreachable;
  } else {
   $$1 = $28;$$12 = $27;
  }
 }
 $41 = HEAP32[$10>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($9,$41);
 $42 = HEAP32[$7>>2]|0;
 $43 = ($42|0)>(-1);
 do {
  if ($43) {
   $44 = HEAP32[$5>>2]|0;
   $45 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $45;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($44|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $50 = ___cxa_find_matching_catch(0|0)|0;
    $51 = tempRet0;
    ___clang_call_terminate($50);
    // unreachable;
   } else {
    HEAP32[$5>>2] = 0;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch(0|0)|0;
  $51 = tempRet0;
  ___clang_call_terminate($50);
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZN11AssetBundle12GetPathRangeERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($agg$result,$this,$path) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $path = $path|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01 = 0, $$01$i$i$i = 0, $$02 = 0, $$14 = 0, $$17 = 0, $$25 = 0, $$28 = 0, $$byval_copy11 = 0, $$in = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre45 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__lhs_sz$05$i = 0, $__lp$03$i = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i16 = 0, $__rp$04$i = 0, $cond = 0, $lowerPath = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi40$index = 0, $lpad$phi40$index7 = 0, $tempPath = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy11 = sp + 80|0;
 $0 = sp;
 $lowerPath = sp + 4|0;
 $1 = sp + 16|0;
 $tempPath = sp + 28|0;
 $2 = sp + 40|0;
 $3 = sp + 52|0;
 $4 = sp + 64|0;
 __Z7ToLowerINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_($lowerPath,$path);
 $5 = HEAP8[$lowerPath>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $12 = (($lowerPath) + 1|0);
  $13 = $5&255;
  $14 = $13 >>> 1;
  $16 = $12;$17 = $14;
 } else {
  $8 = (($lowerPath) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($lowerPath) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $16 = $9;$17 = $11;
 }
 $15 = (($16) + ($17)|0);
 $18 = ($17|0)==(0);
 if ($18) {
  $25 = $5;
 } else {
  $20 = $16;
  while(1) {
   $19 = HEAP8[$20>>0]|0;
   $21 = ($19<<24>>24)==(92);
   if ($21) {
    HEAP8[$20>>0] = 47;
   }
   $22 = (($20) + 1|0);
   $23 = ($22|0)==($15|0);
   if ($23) {
    break;
   } else {
    $20 = $22;
   }
  }
  $$pre = HEAP8[$lowerPath>>0]|0;
  $25 = $$pre;
 }
 $24 = $25 & 1;
 $26 = ($24<<24>>24)==(0);
 if ($26) {
  $29 = $25&255;
  $30 = $29 >>> 1;
  $32 = $30;
 } else {
  $27 = (($lowerPath) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $32 = $28;
 }
 $31 = ($32|0)==(0);
 if ($31) {
  label = 18;
 } else {
  if ($26) {
   $35 = (($lowerPath) + 1|0);
   $36 = $35;
  } else {
   $33 = (($lowerPath) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $36 = $34;
  }
  $37 = (_memchr($36,47,$32)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   label = 18;
  } else {
   $39 = $37;
   $40 = $36;
   $41 = (($39) - ($40))|0;
   $42 = ($41|0)==(-1);
   if ($42) {
    label = 18;
   } else {
    $199 = $25;
    label = 92;
   }
  }
 }
 L24: do {
  if ((label|0) == 18) {
   __THREW__ = 0;
   invoke_vii(2752,($1|0),($lowerPath|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    label = 69;
   } else {
    $45 = HEAP8[$1>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $48 = $45&255;
     $49 = $48 >>> 1;
     $$in = $49;
    } else {
     $50 = (($1) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($1) + 8|0);
     $53 = HEAP32[$52>>2]|0;
     __ZdlPv($53);
     $$in = $51;
    }
    $54 = ($$in|0)==(0);
    $55 = (($this) + 60|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($this) + 64|0);
    $58 = ($56|0)==($57|0);
    L31: do {
     if (!($58)) {
      $59 = (($tempPath) + 1|0);
      $60 = (($lowerPath) + 1|0);
      $61 = (($2) + 1|0);
      $62 = (($2) + 8|0);
      $63 = (($lowerPath) + 8|0);
      $64 = (($3) + 8|0);
      $65 = (($tempPath) + 8|0);
      $66 = (($2) + 4|0);
      $67 = (($lowerPath) + 4|0);
      $68 = (($tempPath) + 4|0);
      $69 = (($3) + 1|0);
      $70 = (($3) + 4|0);
      $72 = $56;
      L33: while(1) {
       $71 = (($72) + 16|0);
       $73 = HEAP8[$71>>0]|0;
       $74 = $73 & 1;
       $75 = ($74<<24>>24)==(0);
       if ($75) {
        $76 = (($71) + 1|0);
        $77 = $73&255;
        $78 = $77 >>> 1;
        $87 = $78;$97 = $76;
       } else {
        $79 = (($72) + 24|0);
        $80 = HEAP32[$79>>2]|0;
        $81 = (($72) + 20|0);
        $82 = HEAP32[$81>>2]|0;
        $83 = ($82>>>0)>(4294967279);
        if ($83) {
         label = 27;
         break;
        } else {
         $87 = $82;$97 = $80;
        }
       }
       $86 = ($87>>>0)<(11);
       if ($86) {
        $88 = $87 << 1;
        $89 = $88&255;
        HEAP8[$tempPath>>0] = $89;
        $100 = $89;$__p$0$i$i$i$i16 = $59;
       } else {
        $90 = (($87) + 16)|0;
        $91 = $90 & -16;
        __THREW__ = 0;
        $92 = (invoke_ii(2988,($91|0))|0);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         label = 68;
         break;
        }
        HEAP32[$65>>2] = $92;
        $95 = $91 | 1;
        HEAP32[$tempPath>>2] = $95;
        HEAP32[$68>>2] = $87;
        $96 = $95&255;
        $100 = $96;$__p$0$i$i$i$i16 = $92;
       }
       _memcpy(($__p$0$i$i$i$i16|0),($97|0),($87|0))|0;
       $98 = (($__p$0$i$i$i$i16) + ($87)|0);
       HEAP8[$98>>0] = 0;
       do {
        if ($54) {
         __THREW__ = 0;
         invoke_vii(2753,($3|0),($tempPath|0));
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          label = 74;
          break L33;
         } else {
          $$01 = 1;$$02 = 0;
         }
        } else {
         $99 = $100 & 1;
         $101 = ($99<<24>>24)==(0);
         if ($101) {
          ;HEAP32[$3+0>>2]=HEAP32[$tempPath+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$tempPath+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$tempPath+8>>2]|0;
          $$01 = 0;$$02 = 1;
          break;
         }
         $102 = HEAP32[$65>>2]|0;
         $103 = HEAP32[$68>>2]|0;
         $104 = ($103>>>0)>(4294967279);
         if ($104) {
          label = 37;
          break L33;
         }
         $107 = ($103>>>0)<(11);
         if ($107) {
          $108 = $103 << 1;
          $109 = $108&255;
          HEAP8[$3>>0] = $109;
          $__p$0$i$i$i = $69;
         } else {
          $110 = (($103) + 16)|0;
          $111 = $110 & -16;
          __THREW__ = 0;
          $112 = (invoke_ii(2988,($111|0))|0);
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           label = 71;
           break L33;
          }
          HEAP32[$64>>2] = $112;
          $115 = $111 | 1;
          HEAP32[$3>>2] = $115;
          HEAP32[$70>>2] = $103;
          $__p$0$i$i$i = $112;
         }
         _memcpy(($__p$0$i$i$i|0),($102|0),($103|0))|0;
         $116 = (($__p$0$i$i$i) + ($103)|0);
         HEAP8[$116>>0] = 0;
         $$01 = 0;$$02 = 1;
        }
       } while(0);
       __THREW__ = 0;
       invoke_vii(2754,($2|0),($3|0));
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        label = 75;
        break;
       }
       $121 = HEAP8[$lowerPath>>0]|0;
       $122 = $121 & 1;
       $123 = ($122<<24>>24)==(0);
       if ($123) {
        $125 = $121&255;
        $126 = $125 >>> 1;
        $134 = $126;
       } else {
        $124 = HEAP32[$67>>2]|0;
        $134 = $124;
       }
       $127 = HEAP8[$2>>0]|0;
       $128 = $127 & 1;
       $129 = ($128<<24>>24)==(0);
       if ($129) {
        $131 = $127&255;
        $132 = $131 >>> 1;
        $135 = $132;
       } else {
        $130 = HEAP32[$66>>2]|0;
        $135 = $130;
       }
       $133 = ($134|0)==($135|0);
       L66: do {
        if ($133) {
         $136 = HEAP32[$63>>2]|0;
         $$ = $123 ? $60 : $136;
         $137 = HEAP32[$62>>2]|0;
         $138 = $129 ? $61 : $137;
         if (!($123)) {
          $140 = (_memcmp($$,$138,$134)|0);
          $141 = ($140|0)==(0);
          $$0$i = $141;
          break;
         }
         $139 = ($134|0)==(0);
         if ($139) {
          $$0$i = 1;
         } else {
          $__lhs_sz$05$i = $134;$__lp$03$i = $$;$__rp$04$i = $138;
          while(1) {
           $142 = HEAP8[$__lp$03$i>>0]|0;
           $143 = HEAP8[$__rp$04$i>>0]|0;
           $144 = ($142<<24>>24)==($143<<24>>24);
           if (!($144)) {
            $$0$i = 0;
            break L66;
           }
           $145 = (($__lhs_sz$05$i) + -1)|0;
           $146 = (($__lp$03$i) + 1|0);
           $147 = (($__rp$04$i) + 1|0);
           $148 = ($145|0)==(0);
           if ($148) {
            $$0$i = 1;
            break;
           } else {
            $__lhs_sz$05$i = $145;$__lp$03$i = $146;$__rp$04$i = $147;
           }
          }
         }
        } else {
         $$0$i = 0;
        }
       } while(0);
       if (!($129)) {
        $149 = HEAP32[$62>>2]|0;
        __ZdlPv($149);
       }
       do {
        if ($$01) {
         $150 = HEAP8[$3>>0]|0;
         $151 = $150 & 1;
         $152 = ($151<<24>>24)==(0);
         if ($152) {
          break;
         }
         $153 = HEAP32[$64>>2]|0;
         __ZdlPv($153);
        }
       } while(0);
       do {
        if ($$02) {
         $154 = HEAP8[$3>>0]|0;
         $155 = $154 & 1;
         $156 = ($155<<24>>24)==(0);
         if ($156) {
          break;
         }
         $157 = HEAP32[$64>>2]|0;
         __ZdlPv($157);
        }
       } while(0);
       if ($$0$i) {
        __THREW__ = 0;
        (invoke_iii(2233,($lowerPath|0),($tempPath|0))|0);
        $158 = __THREW__; __THREW__ = 0;
        $159 = $158&1;
        if ($159) {
         label = 71;
         break;
        } else {
         $$0 = 2;
        }
       } else {
        $$0 = 0;
       }
       $180 = HEAP8[$tempPath>>0]|0;
       $181 = $180 & 1;
       $182 = ($181<<24>>24)==(0);
       if (!($182)) {
        $183 = HEAP32[$65>>2]|0;
        __ZdlPv($183);
       }
       $cond = ($$0|0)==(2);
       if ($cond) {
        break L31;
       }
       $184 = (($72) + 4|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = ($185|0)==(0|0);
       if ($186) {
        $$01$i$i$i = $72;
        while(1) {
         $189 = (($$01$i$i$i) + 8|0);
         $190 = HEAP32[$189>>2]|0;
         $191 = HEAP32[$190>>2]|0;
         $192 = ($191|0)==($$01$i$i$i|0);
         if ($192) {
          $$0$i$i$i = $190;
          break;
         } else {
          $$01$i$i$i = $190;
         }
        }
       } else {
        $$0$i$i$i$i = $185;
        while(1) {
         $187 = HEAP32[$$0$i$i$i$i>>2]|0;
         $188 = ($187|0)==(0|0);
         if ($188) {
          $$0$i$i$i = $$0$i$i$i$i;
          break;
         } else {
          $$0$i$i$i$i = $187;
         }
        }
       }
       $193 = ($$0$i$i$i|0)==($57|0);
       if ($193) {
        break L31;
       } else {
        $72 = $$0$i$i$i;
       }
      }
      do {
       if ((label|0) == 27) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         label = 69;
         break L24;
        }
        // unreachable;
       }
       else if ((label|0) == 37) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $105 = __THREW__; __THREW__ = 0;
        $106 = $105&1;
        if ($106) {
         $166 = ___cxa_find_matching_catch()|0;
         $167 = tempRet0;
         $lpad$phi40$index = $166;$lpad$phi40$index7 = $167;
         label = 73;
         break;
        } else {
         // unreachable;
        }
       }
       else if ((label|0) == 68) {
        $160 = ___cxa_find_matching_catch()|0;
        $161 = tempRet0;
        $lpad$phi$index = $160;$lpad$phi$index2 = $161;
        label = 70;
        break L24;
       }
       else if ((label|0) == 71) {
        $164 = ___cxa_find_matching_catch()|0;
        $165 = tempRet0;
        $lpad$phi40$index = $164;$lpad$phi40$index7 = $165;
        label = 73;
       }
       else if ((label|0) == 74) {
        $168 = ___cxa_find_matching_catch()|0;
        $169 = tempRet0;
        $$14 = $168;$$17 = $169;
       }
       else if ((label|0) == 75) {
        $170 = ___cxa_find_matching_catch()|0;
        $171 = tempRet0;
        if ($$01) {
         $172 = HEAP8[$3>>0]|0;
         $173 = $172 & 1;
         $174 = ($173<<24>>24)==(0);
         if ($174) {
          label = 78;
         } else {
          $175 = HEAP32[$64>>2]|0;
          __ZdlPv($175);
          if (!($$02)) {
           $$14 = $170;$$17 = $171;
           break;
          }
         }
        } else {
         label = 78;
        }
        if ((label|0) == 78) {
         if (!($$02)) {
          $$14 = $170;$$17 = $171;
          break;
         }
        }
        $176 = HEAP8[$3>>0]|0;
        $177 = $176 & 1;
        $178 = ($177<<24>>24)==(0);
        if ($178) {
         $$14 = $170;$$17 = $171;
        } else {
         $179 = HEAP32[$64>>2]|0;
         __ZdlPv($179);
         $$14 = $170;$$17 = $171;
        }
       }
      } while(0);
      if ((label|0) == 73) {
       $$14 = $lpad$phi40$index;$$17 = $lpad$phi40$index7;
      }
      $194 = HEAP8[$tempPath>>0]|0;
      $195 = $194 & 1;
      $196 = ($195<<24>>24)==(0);
      if ($196) {
       $$25 = $$14;$$28 = $$17;
       break L24;
      }
      $197 = HEAP32[$65>>2]|0;
      __ZdlPv($197);
      $$25 = $$14;$$28 = $$17;
      break L24;
     }
    } while(0);
    $$pre45 = HEAP8[$lowerPath>>0]|0;
    $199 = $$pre45;
    label = 92;
   }
  }
 } while(0);
 do {
  if ((label|0) == 92) {
   $198 = $199 & 1;
   $200 = ($198<<24>>24)==(0);
   if ($200) {
    $205 = (($lowerPath) + 1|0);
    $206 = $199&255;
    $207 = $206 >>> 1;
    $209 = $207;$224 = $205;
   } else {
    $201 = (($lowerPath) + 8|0);
    $202 = HEAP32[$201>>2]|0;
    $203 = (($lowerPath) + 4|0);
    $204 = HEAP32[$203>>2]|0;
    $209 = $204;$224 = $202;
   }
   $208 = ($209>>>0)>(2147483631);
   if ($208) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $210 = __THREW__; __THREW__ = 0;
    $211 = $210&1;
    if ($211) {
     label = 69;
     break;
    }
    // unreachable;
   }
   $212 = ($209>>>0)<(11);
   if ($212) {
    $213 = $209 << 1;
    $214 = $213&255;
    HEAP8[$4>>0] = $214;
    $215 = (($4) + 1|0);
    $$pre$phiZ2D = $4;$__p$0$i$i$i$i = $215;
   } else {
    $216 = (($209) + 16)|0;
    $217 = $216 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    $218 = (invoke_iiiiiii(102,($217|0),16,($$byval_copy11|0),0,(616888|0),79)|0);
    $219 = __THREW__; __THREW__ = 0;
    $220 = $219&1;
    if ($220) {
     label = 69;
     break;
    }
    $221 = (($4) + 8|0);
    HEAP32[$221>>2] = $218;
    $222 = $217 | 1;
    HEAP32[$4>>2] = $222;
    $223 = (($4) + 4|0);
    HEAP32[$223>>2] = $209;
    $$pre$phiZ2D = $4;$__p$0$i$i$i$i = $218;
   }
   _memcpy(($__p$0$i$i$i$i|0),($224|0),($209|0))|0;
   $225 = (($__p$0$i$i$i$i) + ($209)|0);
   HEAP8[$225>>0] = 0;
   $226 = (($this) + 60|0);
   __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE19__equal_range_multiIS2_EENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEESK_EERKT_($$byval_copy11,$226,$4);
   $227 = HEAP32[$$byval_copy11>>2]|0;
   HEAP32[$agg$result>>2] = $227;
   $228 = (($$byval_copy11) + 4|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = (($agg$result) + 4|0);
   HEAP32[$230>>2] = $229;
   $231 = HEAP8[$$pre$phiZ2D>>0]|0;
   $232 = $231 & 1;
   $233 = ($232<<24>>24)==(0);
   if (!($233)) {
    $234 = (($4) + 8|0);
    $235 = HEAP32[$234>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($235|0),($$byval_copy11|0));
    $236 = __THREW__; __THREW__ = 0;
    $237 = $236&1;
    if ($237) {
     $238 = ___cxa_find_matching_catch()|0;
     $239 = tempRet0;
     ___cxa_call_unexpected(($238|0));
     // unreachable;
    }
   }
   $240 = HEAP8[$lowerPath>>0]|0;
   $241 = $240 & 1;
   $242 = ($241<<24>>24)==(0);
   if ($242) {
    STACKTOP = sp;return;
   }
   $243 = (($lowerPath) + 8|0);
   $244 = HEAP32[$243>>2]|0;
   __ZdlPv($244);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 69) {
  $162 = ___cxa_find_matching_catch()|0;
  $163 = tempRet0;
  $lpad$phi$index = $162;$lpad$phi$index2 = $163;
  label = 70;
 }
 if ((label|0) == 70) {
  $$25 = $lpad$phi$index;$$28 = $lpad$phi$index2;
 }
 $245 = HEAP8[$lowerPath>>0]|0;
 $246 = $245 & 1;
 $247 = ($246<<24>>24)==(0);
 if ($247) {
  ___resumeException($$25|0);
  // unreachable;
 }
 $248 = (($lowerPath) + 8|0);
 $249 = HEAP32[$248>>2]|0;
 __ZdlPv($249);
 ___resumeException($$25|0);
 // unreachable;
}
function __ZN11AssetBundle6GetAllEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 64|0);
 HEAP32[$agg$result>>2] = $1;
 $3 = (($agg$result) + 4|0);
 HEAP32[$3>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN11AssetBundle14GetPreloadDataEiR13dynamic_arrayIiLj4EE($this,$instanceID,$preloadObjects) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 $preloadObjects = $preloadObjects|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $found$0$off0$lcssa = 0, $found$0$off011 = 0, $found$1$off0 = 0, $i$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 64|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  $found$0$off0$lcssa = 0;
  STACKTOP = sp;return ($found$0$off0$lcssa|0);
 }
 $5 = (($this) + 44|0);
 $6 = (($preloadObjects) + 8|0);
 $7 = (($preloadObjects) + 12|0);
 $8 = (($preloadObjects) + 4|0);
 $10 = $2;$found$0$off011 = 0;
 while(1) {
  $9 = (($10) + 36|0);
  $11 = HEAP32[$9>>2]|0;
  $12 = ($11|0)==($instanceID|0);
  if ($12) {
   $13 = (($10) + 32|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)>(0);
   if ($15) {
    $16 = (($10) + 28|0);
    $i$09 = 0;
    while(1) {
     $17 = HEAP32[$16>>2]|0;
     $18 = (($17) + ($i$09))|0;
     $19 = HEAP32[$5>>2]|0;
     $20 = (($19) + ($18<<2)|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$6>>2]|0;
     $23 = (($22) + 1)|0;
     HEAP32[$6>>2] = $23;
     $24 = HEAP32[$7>>2]|0;
     $25 = $24 & 2147483647;
     $26 = ($23>>>0)>($25>>>0);
     if ($26) {
      $27 = $24 << 1;
      $28 = ($27|0)==(0);
      $29 = $28 ? 1 : $27;
      $30 = ($25>>>0)<($29>>>0);
      do {
       if ($30) {
        $31 = ($24|0)>(-1);
        if ($31) {
         HEAP32[$7>>2] = $29;
         $32 = HEAP32[$preloadObjects>>2]|0;
         $33 = $29 << 2;
         $34 = HEAP32[$8>>2]|0;
         HEAP32[$0>>2] = $34;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         $35 = (__Z16realloc_internalPvji10MemLabelIdiPKci($32,$33,4,$$byval_copy1,0,616888,370)|0);
         HEAP32[$preloadObjects>>2] = $35;
         break;
        } else {
         $36 = $29 << 2;
         $37 = HEAP32[$8>>2]|0;
         HEAP32[$0>>2] = $37;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         $38 = (__Z15malloc_internaljj10MemLabelIdiPKci($36,4,$$byval_copy1,0,616888,352)|0);
         $39 = HEAP32[$preloadObjects>>2]|0;
         $40 = HEAP32[$6>>2]|0;
         $41 = $40 << 2;
         _memcpy(($38|0),($39|0),($41|0))|0;
         HEAP32[$7>>2] = $29;
         HEAP32[$preloadObjects>>2] = $38;
         break;
        }
       }
      } while(0);
      $$pre$i$i = HEAP32[$6>>2]|0;
      $43 = $$pre$i$i;
     } else {
      $43 = $23;
     }
     $42 = (($43) + -1)|0;
     $44 = HEAP32[$preloadObjects>>2]|0;
     $45 = (($44) + ($42<<2)|0);
     HEAP32[$45>>2] = $21;
     $46 = (($i$09) + 1)|0;
     $47 = HEAP32[$13>>2]|0;
     $48 = ($46|0)<($47|0);
     if ($48) {
      $i$09 = $46;
     } else {
      $found$1$off0 = 1;
      break;
     }
    }
   } else {
    $found$1$off0 = 1;
   }
  } else {
   $found$1$off0 = $found$0$off011;
  }
  $49 = (($10) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==(0|0);
  if ($51) {
   $$01$i$i$i = $10;
   while(1) {
    $54 = (($$01$i$i$i) + 8|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$55>>2]|0;
    $57 = ($56|0)==($$01$i$i$i|0);
    if ($57) {
     $$0$i$i$i = $55;
     break;
    } else {
     $$01$i$i$i = $55;
    }
   }
  } else {
   $$0$i$i$i$i = $50;
   while(1) {
    $52 = HEAP32[$$0$i$i$i$i>>2]|0;
    $53 = ($52|0)==(0|0);
    if ($53) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $52;
    }
   }
  }
  $58 = ($$0$i$i$i|0)==($3|0);
  if ($58) {
   $found$0$off0$lcssa = $found$1$off0;
   break;
  } else {
   $10 = $$0$i$i$i;$found$0$off011 = $found$1$off0;
  }
 }
 STACKTOP = sp;return ($found$0$off0$lcssa|0);
}
function __ZN11AssetBundle39ShouldIgnoreInGarbageDependencyTrackingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN11AssetBundleD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11AssetBundleD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN11AssetBundleD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3512,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE19__equal_range_multiIS2_EENS_4pairINS_15__tree_iteratorIS5_PNS_11__tree_nodeIS5_PvEEiEESK_EERKT_($agg$result,$this,$__k) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__k = $__k|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$i = 0, $$$$i$i$i$i$i11 = 0, $$$$i$i$i$i18 = 0, $$$i$i$i$i = 0, $$$i$i$i$i$i = 0, $$$i$i$i$i$i10 = 0, $$$i$i$i$i17 = 0, $$0$ph5$i = 0, $$0$ph5$i13 = 0, $$0$ph7$i = 0, $$0$ph7$i3 = 0, $$01$ph6$i$in = 0, $$01$ph6$i4$in = 0, $$013$i$in = 0, $$013$i6$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__result$0$ph41 = 0;
 var $__result$0$ph44 = 0, $__rt$0$in = 0, $__rt$0$in35 = 0, $__rt$0$in3542 = 0, $__rt$03646$in = 0, $__rt$038$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 4|0);
 $__rt$0$in3542 = HEAP32[$1>>2]|0;
 $2 = ($__rt$0$in3542|0)==(0|0);
 L1: do {
  if ($2) {
   $__result$0$ph41 = $0;
  } else {
   $3 = HEAP8[$__k>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   $6 = $3&255;
   $7 = $6 >>> 1;
   $8 = (($__k) + 1|0);
   $9 = (($__k) + 8|0);
   $10 = (($__k) + 4|0);
   $__result$0$ph44 = $0;$__rt$03646$in = $__rt$0$in3542;
   L3: while(1) {
    $__rt$038$in = $__rt$03646$in;
    while(1) {
     $13 = (($__rt$038$in) + 16|0);
     if ($5) {
      $28 = $7;
     } else {
      $14 = HEAP32[$10>>2]|0;
      $28 = $14;
     }
     $15 = HEAP8[$13>>0]|0;
     $16 = $15 & 1;
     $17 = ($16<<24>>24)==(0);
     if ($17) {
      $20 = $15&255;
      $21 = $20 >>> 1;
      $27 = $21;
     } else {
      $18 = (($__rt$038$in) + 20|0);
      $19 = HEAP32[$18>>2]|0;
      $27 = $19;
     }
     if ($5) {
      $30 = $8;
     } else {
      $22 = HEAP32[$9>>2]|0;
      $30 = $22;
     }
     if ($17) {
      $25 = (($13) + 1|0);
      $31 = $25;
     } else {
      $23 = (($__rt$038$in) + 24|0);
      $24 = HEAP32[$23>>2]|0;
      $31 = $24;
     }
     $26 = ($27>>>0)<($28>>>0);
     $29 = $26 ? $27 : $28;
     $32 = (_memcmp($30,$31,$29)|0);
     $33 = ($32|0)==(0);
     if ($33) {
      $34 = ($28>>>0)<($27>>>0);
      $$$i$i$i$i17 = $26&1;
      $$$$i$i$i$i18 = $34 ? -1 : $$$i$i$i$i17;
      $36 = $$$$i$i$i$i18;
     } else {
      $36 = $32;
     }
     $35 = ($36|0)<(0);
     if ($35) {
      break;
     }
     if ($17) {
      $40 = $15&255;
      $41 = $40 >>> 1;
      $49 = $41;
     } else {
      $38 = (($__rt$038$in) + 20|0);
      $39 = HEAP32[$38>>2]|0;
      $49 = $39;
     }
     if ($5) {
      $48 = $7;
     } else {
      $42 = HEAP32[$10>>2]|0;
      $48 = $42;
     }
     if ($17) {
      $45 = (($13) + 1|0);
      $51 = $45;
     } else {
      $43 = (($__rt$038$in) + 24|0);
      $44 = HEAP32[$43>>2]|0;
      $51 = $44;
     }
     if ($5) {
      $52 = $8;
     } else {
      $46 = HEAP32[$9>>2]|0;
      $52 = $46;
     }
     $47 = ($48>>>0)<($49>>>0);
     $50 = $47 ? $48 : $49;
     $53 = (_memcmp($51,$52,$50)|0);
     $54 = ($53|0)==(0);
     if ($54) {
      $55 = ($49>>>0)<($48>>>0);
      $$$i$i$i$i = $47&1;
      $$$$i$i$i$i = $55 ? -1 : $$$i$i$i$i;
      $57 = $$$$i$i$i$i;
     } else {
      $57 = $53;
     }
     $56 = ($57|0)<(0);
     if (!($56)) {
      break L3;
     }
     $11 = (($__rt$038$in) + 4|0);
     $__rt$0$in = HEAP32[$11>>2]|0;
     $12 = ($__rt$0$in|0)==(0|0);
     if ($12) {
      $__result$0$ph41 = $__result$0$ph44;
      break L1;
     } else {
      $__rt$038$in = $__rt$0$in;
     }
    }
    $__rt$0$in35 = HEAP32[$__rt$038$in>>2]|0;
    $37 = ($__rt$0$in35|0)==(0|0);
    if ($37) {
     $__result$0$ph41 = $__rt$038$in;
     break L1;
    } else {
     $__result$0$ph44 = $__rt$038$in;$__rt$03646$in = $__rt$0$in35;
    }
   }
   $58 = HEAP32[$__rt$038$in>>2]|0;
   $59 = ($58|0)==(0|0);
   L45: do {
    if ($59) {
     $$0$ph5$i13 = $__rt$038$in;
    } else {
     $$0$ph7$i3 = $__rt$038$in;$$01$ph6$i4$in = $58;
     while(1) {
      $$013$i6$in = $$01$ph6$i4$in;
      while(1) {
       $60 = (($$013$i6$in) + 16|0);
       $61 = HEAP8[$60>>0]|0;
       $62 = $61 & 1;
       $63 = ($62<<24>>24)==(0);
       if ($63) {
        $66 = $61&255;
        $67 = $66 >>> 1;
        $75 = $67;
       } else {
        $64 = (($$013$i6$in) + 20|0);
        $65 = HEAP32[$64>>2]|0;
        $75 = $65;
       }
       if ($5) {
        $74 = $7;
       } else {
        $68 = HEAP32[$10>>2]|0;
        $74 = $68;
       }
       if ($63) {
        $71 = (($60) + 1|0);
        $77 = $71;
       } else {
        $69 = (($$013$i6$in) + 24|0);
        $70 = HEAP32[$69>>2]|0;
        $77 = $70;
       }
       if ($5) {
        $78 = $8;
       } else {
        $72 = HEAP32[$9>>2]|0;
        $78 = $72;
       }
       $73 = ($74>>>0)<($75>>>0);
       $76 = $73 ? $74 : $75;
       $79 = (_memcmp($77,$78,$76)|0);
       $80 = ($79|0)==(0);
       if ($80) {
        $81 = ($75>>>0)<($74>>>0);
        $$$i$i$i$i$i10 = $73&1;
        $$$$i$i$i$i$i11 = $81 ? -1 : $$$i$i$i$i$i10;
        $83 = $$$$i$i$i$i$i11;
       } else {
        $83 = $79;
       }
       $82 = ($83|0)<(0);
       if (!($82)) {
        break;
       }
       $86 = (($$013$i6$in) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($87|0)==(0|0);
       if ($88) {
        $$0$ph5$i13 = $$0$ph7$i3;
        break L45;
       } else {
        $$013$i6$in = $87;
       }
      }
      $84 = HEAP32[$$013$i6$in>>2]|0;
      $85 = ($84|0)==(0|0);
      if ($85) {
       $$0$ph5$i13 = $$013$i6$in;
       break;
      } else {
       $$0$ph7$i3 = $$013$i6$in;$$01$ph6$i4$in = $84;
      }
     }
    }
   } while(0);
   $89 = (($__rt$038$in) + 4|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==(0|0);
   L70: do {
    if ($91) {
     $$0$ph5$i = $__result$0$ph44;
    } else {
     $$0$ph7$i = $__result$0$ph44;$$01$ph6$i$in = $90;
     while(1) {
      $$013$i$in = $$01$ph6$i$in;
      while(1) {
       $92 = (($$013$i$in) + 16|0);
       if ($5) {
        $107 = $7;
       } else {
        $93 = HEAP32[$10>>2]|0;
        $107 = $93;
       }
       $94 = HEAP8[$92>>0]|0;
       $95 = $94 & 1;
       $96 = ($95<<24>>24)==(0);
       if ($96) {
        $99 = $94&255;
        $100 = $99 >>> 1;
        $106 = $100;
       } else {
        $97 = (($$013$i$in) + 20|0);
        $98 = HEAP32[$97>>2]|0;
        $106 = $98;
       }
       if ($5) {
        $109 = $8;
       } else {
        $101 = HEAP32[$9>>2]|0;
        $109 = $101;
       }
       if ($96) {
        $104 = (($92) + 1|0);
        $110 = $104;
       } else {
        $102 = (($$013$i$in) + 24|0);
        $103 = HEAP32[$102>>2]|0;
        $110 = $103;
       }
       $105 = ($106>>>0)<($107>>>0);
       $108 = $105 ? $106 : $107;
       $111 = (_memcmp($109,$110,$108)|0);
       $112 = ($111|0)==(0);
       if ($112) {
        $113 = ($107>>>0)<($106>>>0);
        $$$i$i$i$i$i = $105&1;
        $$$$i$i$i$i$i = $113 ? -1 : $$$i$i$i$i$i;
        $115 = $$$$i$i$i$i$i;
       } else {
        $115 = $111;
       }
       $114 = ($115|0)<(0);
       if ($114) {
        break;
       }
       $118 = (($$013$i$in) + 4|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = ($119|0)==(0|0);
       if ($120) {
        $$0$ph5$i = $$0$ph7$i;
        break L70;
       } else {
        $$013$i$in = $119;
       }
      }
      $116 = HEAP32[$$013$i$in>>2]|0;
      $117 = ($116|0)==(0|0);
      if ($117) {
       $$0$ph5$i = $$013$i$in;
       break;
      } else {
       $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $116;
      }
     }
    }
   } while(0);
   HEAP32[$agg$result>>2] = $$0$ph5$i13;
   $121 = (($agg$result) + 4|0);
   HEAP32[$121>>2] = $$0$ph5$i;
   STACKTOP = sp;return;
  }
 } while(0);
 HEAP32[$agg$result>>2] = $__result$0$ph41;
 $122 = (($agg$result) + 4|0);
 HEAP32[$122>>2] = $__result$0$ph41;
 STACKTOP = sp;return;
}
function __ZN11AssetBundle8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$01$i$i$i$i$i$i$i = 0, $$pre = 0, $$pre6 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)==(0);
 if (!($5)) {
  $6 = (($transfer) + 12|0);
  $7 = (($transfer) + 28|0);
  $8 = (($transfer) + 32|0);
  $i$01$i$i$i = $1;
  while(1) {
   $9 = HEAP32[$i$01$i$i$i>>2]|0;
   $10 = HEAP32[$6>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$7>>2]|0;
   $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($10,$9,$13)|0);
   $15 = HEAP8[$8>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    HEAP32[$i$01$i$i$i>>2] = $14;
   }
   $17 = (($i$01$i$i$i) + 4|0);
   $18 = ($17|0)==($4|0);
   if ($18) {
    break;
   } else {
    $i$01$i$i$i = $17;
   }
  }
 }
 $19 = (($this) + 60|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 64|0);
 $22 = ($20|0)==($21|0);
 $$pre = (($transfer) + 12|0);
 $$pre6 = (($transfer) + 28|0);
 $$pre8 = (($transfer) + 32|0);
 if (!($22)) {
  $24 = $20;
  while(1) {
   $23 = (($24) + 36|0);
   $25 = HEAP32[$23>>2]|0;
   $26 = HEAP32[$$pre>>2]|0;
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$$pre6>>2]|0;
   $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$25,$29)|0);
   $31 = HEAP8[$$pre8>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if (!($32)) {
    HEAP32[$23>>2] = $30;
   }
   $33 = (($24) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    $$01$i$i$i$i$i$i$i = $24;
    while(1) {
     $38 = (($$01$i$i$i$i$i$i$i) + 8|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($$01$i$i$i$i$i$i$i|0);
     if ($41) {
      $$0$i$i$i$i$i$i$i = $39;
      break;
     } else {
      $$01$i$i$i$i$i$i$i = $39;
     }
    }
   } else {
    $$0$i$i$i$i$i$i$i$i = $34;
    while(1) {
     $36 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i$i$i = $36;
     }
    }
   }
   $42 = ($$0$i$i$i$i$i$i$i|0)==($21|0);
   if ($42) {
    break;
   } else {
    $24 = $$0$i$i$i$i$i$i$i;
   }
  }
 }
 $43 = (($this) + 40|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$$pre>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$$pre6>>2]|0;
 $49 = (FUNCTION_TABLE_iiii[$47 & 2047]($45,$44,$48)|0);
 $50 = HEAP8[$$pre8>>0]|0;
 $51 = ($50<<24>>24)==(0);
 if ($51) {
  STACKTOP = sp;return;
 }
 HEAP32[$43>>2] = $49;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$4);
 $5 = (($__nd) + 16|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($10|0),($$byval_copy|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS5_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0 = 0, $$lcssa = 0, $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, $__nd$0$in$lcssa = 0, $__nd$0$in$lcssa1 = 0, $__nd$0$in$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $63 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $63;
  $$0 = $63;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 if ($5) {
  $__nd$0$in$us = $1;
  while(1) {
   $11 = (($__nd$0$in$us) + 16|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = $12 & 1;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $19 = $12&255;
    $20 = $19 >>> 1;
    $21 = (($11) + 1|0);
    $23 = $20;$25 = $21;
   } else {
    $15 = (($__nd$0$in$us) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($__nd$0$in$us) + 24|0);
    $18 = HEAP32[$17>>2]|0;
    $23 = $16;$25 = $18;
   }
   $22 = ($23>>>0)<($7>>>0);
   $24 = $22 ? $23 : $7;
   $26 = (_memcmp($8,$25,$24)|0);
   $27 = ($26|0)==(0);
   if ($27) {
    $28 = ($7>>>0)<($23>>>0);
    $$$i$i$i$i$us = $22&1;
    $$$$i$i$i$i$us = $28 ? -1 : $$$i$i$i$i$us;
    $30 = $$$$i$i$i$i$us;
   } else {
    $30 = $26;
   }
   $29 = ($30|0)<(0);
   if ($29) {
    $34 = HEAP32[$__nd$0$in$us>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     $$lcssa2 = $__nd$0$in$us;$__nd$0$in$lcssa1 = $__nd$0$in$us;
     label = 18;
     break;
    } else {
     $__nd$0$in$us = $34;
     continue;
    }
   } else {
    $31 = (($__nd$0$in$us) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     $$lcssa = $31;$__nd$0$in$lcssa = $__nd$0$in$us;
     label = 20;
     break;
    } else {
     $__nd$0$in$us = $32;
     continue;
    }
   }
  }
 } else {
  $__nd$0$in = $1;
  while(1) {
   $36 = (($__nd$0$in) + 16|0);
   $37 = HEAP32[$10>>2]|0;
   $38 = HEAP8[$36>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    $45 = $38&255;
    $46 = $45 >>> 1;
    $47 = (($36) + 1|0);
    $50 = $46;$52 = $47;
   } else {
    $41 = (($__nd$0$in) + 20|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($__nd$0$in) + 24|0);
    $44 = HEAP32[$43>>2]|0;
    $50 = $42;$52 = $44;
   }
   $48 = HEAP32[$9>>2]|0;
   $49 = ($50>>>0)<($37>>>0);
   $51 = $49 ? $50 : $37;
   $53 = (_memcmp($48,$52,$51)|0);
   $54 = ($53|0)==(0);
   if ($54) {
    $55 = ($37>>>0)<($50>>>0);
    $$$i$i$i$i = $49&1;
    $$$$i$i$i$i = $55 ? -1 : $$$i$i$i$i;
    $57 = $$$$i$i$i$i;
   } else {
    $57 = $53;
   }
   $56 = ($57|0)<(0);
   if ($56) {
    $58 = HEAP32[$__nd$0$in>>2]|0;
    $59 = ($58|0)==(0|0);
    if ($59) {
     $$lcssa2 = $__nd$0$in;$__nd$0$in$lcssa1 = $__nd$0$in;
     label = 18;
     break;
    } else {
     $__nd$0$in = $58;
     continue;
    }
   } else {
    $60 = (($__nd$0$in) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)==(0|0);
    if ($62) {
     $$lcssa = $60;$__nd$0$in$lcssa = $__nd$0$in;
     label = 20;
     break;
    } else {
     $__nd$0$in = $61;
     continue;
    }
   }
  }
 }
 if ((label|0) == 18) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa1;
  $$0 = $$lcssa2;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 20) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa;
  $$0 = $$lcssa;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$4);
 $5 = (($__nd) + 16|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($10|0),($$byval_copy|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$01$i$i$i$i$i$i = 0, $$byval_copy1 = 0, $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $i$01$i$i$i = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$$byval_copy1>>2] = $2;
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy1,4);
 }
 $9 = (($this) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$1>>2]|0;
 $12 = (($10) + ($11<<2)|0);
 $13 = ($11|0)==(0);
 if (!($13)) {
  $i$01$i$i$i = $10;
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $14 = (($i$01$i$i$i) + 4|0);
   $15 = ($14|0)==($12|0);
   if ($15) {
    break;
   } else {
    $i$01$i$i$i = $14;
   }
  }
 }
 $16 = (($this) + 68|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$$byval_copy1>>2] = $17;
 $18 = HEAP32[$3>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$6>>2]|0;
 $21 = ($19>>>0)<($20>>>0);
 if ($21) {
  HEAP32[$18>>2] = $17;
  HEAP32[$3>>2] = $19;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy1,4);
 }
 $22 = (($this) + 64|0);
 $23 = (($this) + 60|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($22|0);
 if (!($25)) {
  $27 = $24;
  while(1) {
   $26 = (($27) + 16|0);
   __ZN19StreamedBinaryWriteILb0EE8TransferINSt3__14pairI8UnityStrN11AssetBundle9AssetInfoEEEEEvRT_PKc17TransferMetaFlags($transfer,$26,0,0);
   $28 = (($27) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $$01$i$i$i$i$i$i = $27;
    while(1) {
     $33 = (($$01$i$i$i$i$i$i) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)==($$01$i$i$i$i$i$i|0);
     if ($36) {
      $$0$i$i$i$i$i$i = $34;
      break;
     } else {
      $$01$i$i$i$i$i$i = $34;
     }
    }
   } else {
    $$0$i$i$i$i$i$i$i = $29;
    while(1) {
     $31 = HEAP32[$$0$i$i$i$i$i$i$i>>2]|0;
     $32 = ($31|0)==(0|0);
     if ($32) {
      $$0$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i$i = $31;
     }
    }
   }
   $37 = ($$0$i$i$i$i$i$i|0)==($22|0);
   if ($37) {
    break;
   } else {
    $27 = $$0$i$i$i$i$i$i;
   }
  }
 }
 $38 = (($this) + 32|0);
 $39 = HEAP32[$3>>2]|0;
 $40 = (($39) + 4|0);
 $41 = HEAP32[$6>>2]|0;
 $42 = ($40>>>0)<($41>>>0);
 if ($42) {
  $43 = HEAP32[$38>>2]|0;
  HEAP32[$39>>2] = $43;
  HEAP32[$3>>2] = $40;
  $46 = $40;$48 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$38,4);
  $$pre$i$i$i = HEAP32[$3>>2]|0;
  $$pre2$i$i$i = HEAP32[$6>>2]|0;
  $46 = $$pre$i$i$i;$48 = $$pre2$i$i$i;
 }
 $44 = (($this) + 36|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)<($48>>>0);
 if ($47) {
  $49 = HEAP32[$44>>2]|0;
  HEAP32[$46>>2] = $49;
  HEAP32[$3>>2] = $45;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$44,4);
 }
 $50 = (($this) + 40|0);
 __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($50,$transfer);
 $51 = (($this) + 28|0);
 $52 = HEAP32[$3>>2]|0;
 $53 = (($52) + 4|0);
 $54 = HEAP32[$6>>2]|0;
 $55 = ($53>>>0)<($54>>>0);
 if ($55) {
  $56 = HEAP32[$51>>2]|0;
  HEAP32[$52>>2] = $56;
  HEAP32[$3>>2] = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$51,4);
 }
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 $57 = (($this) + 84|0);
 $58 = HEAP32[$57>>2]|0;
 __THREW__ = 0;
 (invoke_iii(2353,($tempStr$i$i|0),($58|0))|0);
 $59 = __THREW__; __THREW__ = 0;
 $60 = $59&1;
 if (!($60)) {
  __THREW__ = 0;
  invoke_viii(1624,($transfer|0),($tempStr$i$i|0),0);
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if (!($73)) {
   __THREW__ = 0;
   invoke_vi(3378,($transfer|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if (!($75)) {
    $76 = HEAP8[$tempStr$i$i>>0]|0;
    $77 = $76 & 1;
    $78 = ($77<<24>>24)==(0);
    if ($78) {
     $85 = (($this) + 88|0);
     __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$85,0);
     STACKTOP = sp;return;
    }
    $79 = (($tempStr$i$i) + 8|0);
    $80 = HEAP32[$79>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($80|0),($$byval_copy1|0));
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     $83 = ___cxa_find_matching_catch()|0;
     $84 = tempRet0;
     ___cxa_call_unexpected(($83|0));
     // unreachable;
    } else {
     $85 = (($this) + 88|0);
     __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$85,0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $61 = ___cxa_find_matching_catch()|0;
 $62 = tempRet0;
 $63 = HEAP8[$tempStr$i$i>>0]|0;
 $64 = $63 & 1;
 $65 = ($64<<24>>24)==(0);
 if ($65) {
  ___resumeException($61|0);
  // unreachable;
 }
 $66 = (($tempStr$i$i) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($67|0),($$byval_copy1|0));
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $70 = ___cxa_find_matching_catch()|0;
  $71 = tempRet0;
  ___cxa_call_unexpected(($70|0));
  // unreachable;
 } else {
  ___resumeException($61|0);
  // unreachable;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $1 = sp;
 $2 = sp + 4|0;
 $tempStr$i$i = sp + 8|0;
 $size = sp + 20|0;
 $3 = (($data) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$data>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 HEAP32[$size>>2] = $9;
 $10 = (($this) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = (($this) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)<($14>>>0);
 if ($15) {
  HEAP32[$11>>2] = $9;
  HEAP32[$10>>2] = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($10,$size,4);
 }
 $16 = HEAP32[$3>>2]|0;
 $17 = HEAP32[$data>>2]|0;
 $18 = ($17|0)==($16|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($tempStr$i$i) + 8|0);
 $21 = $17;
 while(1) {
  ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
  $20 = HEAP32[$21>>2]|0;
  __THREW__ = 0;
  (invoke_iii(2353,($tempStr$i$i|0),($20|0))|0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  invoke_viii(1624,($this|0),($tempStr$i$i|0),0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3378,($this|0));
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   label = 7;
   break;
  }
  $38 = HEAP8[$tempStr$i$i>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if (!($40)) {
   $41 = HEAP32[$19>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($41|0),($$byval_copy1|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    label = 14;
    break;
   }
  }
  $46 = (($21) + 4|0);
  $47 = ($46|0)==($16|0);
  if ($47) {
   label = 17;
   break;
  } else {
   $21 = $46;
  }
 }
 if ((label|0) == 7) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  $26 = HEAP8[$tempStr$i$i>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   ___resumeException($24|0);
   // unreachable;
  }
  $29 = HEAP32[$19>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($29|0),($$byval_copy1|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   ___cxa_call_unexpected(($32|0));
   // unreachable;
  } else {
   ___resumeException($24|0);
   // unreachable;
  }
 }
 else if ((label|0) == 14) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE8TransferINSt3__14pairI8UnityStrN11AssetBundle9AssetInfoEEEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i$i$i = 0, $$pre2$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$data,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($this);
 $2 = (($data) + 12|0);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = HEAP32[$2>>2]|0;
  HEAP32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
  $$pre$i$i$i$i = HEAP32[$3>>2]|0;
  $$pre2$i$i$i$i = HEAP32[$6>>2]|0;
  $12 = $$pre$i$i$i$i;$14 = $$pre2$i$i$i$i;
 }
 $10 = (($data) + 16|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)<($14>>>0);
 if ($13) {
  $15 = HEAP32[$10>>2]|0;
  HEAP32[$12>>2] = $15;
  HEAP32[$3>>2] = $11;
  $16 = (($data) + 20|0);
  __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($16,$this);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$10,4);
  $16 = (($data) + 20|0);
  __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($16,$this);
  STACKTOP = sp;return;
 }
}
function __ZN11AssetBundle8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1$i$i$i = 0, $$pre$i$i$i4 = 0, $$pre3$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $1 = sp + 16|0;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$3,0);
 $4 = (($this) + 60|0);
 __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__18multimapI8UnityStrN11AssetBundle9AssetInfoENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S6_EEEEEEEEvRT_17TransferMetaFlags($transfer,$4,0);
 $5 = (($this) + 32|0);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$5,4);
  $$pre$i$i$i$i$i$i = HEAP32[$5>>2]|0;
  $$pre$i$i$i = HEAP32[$6>>2]|0;
  $$pre3$i$i$i = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i$i$i$i;$17 = $$pre$i$i$i;$19 = $$pre3$i$i$i;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$5>>2] = $12;
  HEAP32[$6>>2] = $8;
  $13 = $12;$17 = $8;$19 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$5>>2] = $14;
 $15 = (($this) + 36|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$15,4);
  $$pre$i$i$i1$i$i$i = HEAP32[$15>>2]|0;
  $21 = $$pre$i$i$i1$i$i$i;
 } else {
  $20 = HEAP32[$17>>2]|0;
  HEAP32[$15>>2] = $20;
  HEAP32[$6>>2] = $16;
  $21 = $20;
 }
 $22 = (_llvm_bswap_i32(($21|0))|0);
 HEAP32[$15>>2] = $22;
 $23 = (($this) + 40|0);
 __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($23,$transfer);
 $24 = HEAP32[$6>>2]|0;
 $25 = (($24) + 4|0);
 $26 = HEAP32[$9>>2]|0;
 $27 = ($25>>>0)>($26>>>0);
 if ($27) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$2,4);
  $$pre$i$i$i4 = HEAP32[$2>>2]|0;
  $29 = $$pre$i$i$i4;
 } else {
  $28 = HEAP32[$24>>2]|0;
  HEAP32[$2>>2] = $28;
  HEAP32[$6>>2] = $25;
  $29 = $28;
 }
 $30 = (_llvm_bswap_i32(($29|0))|0);
 HEAP32[$2>>2] = $30;
 $31 = (($this) + 84|0);
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1623,($transfer|0),($tempStr$i$i|0),0);
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if (!($33)) {
  __THREW__ = 0;
  invoke_vi(3377,($transfer|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if (!($46)) {
   $47 = HEAP8[$tempStr$i$i>>0]|0;
   $48 = $47 & 1;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    $52 = (($tempStr$i$i) + 1|0);
    $54 = $52;
   } else {
    $50 = (($tempStr$i$i) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $54 = $51;
   }
   $53 = HEAP32[628448>>2]|0;
   HEAP32[$1>>2] = $53;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1621,($31|0),($54|0),($$byval_copy2|0));
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if (!($56)) {
    $57 = HEAP8[$tempStr$i$i>>0]|0;
    $58 = $57 & 1;
    $59 = ($58<<24>>24)==(0);
    if ($59) {
     $66 = (($this) + 88|0);
     __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$66,0);
     STACKTOP = sp;return;
    }
    $60 = (($tempStr$i$i) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($61|0),($$byval_copy2|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $64 = ___cxa_find_matching_catch()|0;
     $65 = tempRet0;
     ___cxa_call_unexpected(($64|0));
     // unreachable;
    } else {
     $66 = (($this) + 88|0);
     __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$66,0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 $36 = HEAP8[$tempStr$i$i>>0]|0;
 $37 = $36 & 1;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  ___resumeException($34|0);
  // unreachable;
 }
 $39 = (($tempStr$i$i) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($40|0),($$byval_copy2|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  ___cxa_call_unexpected(($43|0));
  // unreachable;
 } else {
  ___resumeException($34|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy2 = sp + 36|0;
 $1 = sp;
 $2 = sp + 4|0;
 $tempStr$i$i = sp + 8|0;
 $3 = sp + 20|0;
 $offset = sp + 24|0;
 $size = sp + 28|0;
 $size1 = sp + 32|0;
 $4 = (($this) + 12|0);
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 $8 = HEAP32[$4>>2]|0;
 $9 = (($8) + 4|0);
 $10 = (($this) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if (!($7)) {
  if ($12) {
   __ZN12CachedReader15UpdateReadCacheEPvj($4,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$4>>2]|0;
   $$pre8 = HEAP32[$10>>2]|0;
   $14 = $$pre$i$i$i;$17 = $$pre;$19 = $$pre8;
  } else {
   $13 = HEAP32[$8>>2]|0;
   HEAP32[$size>>2] = $13;
   HEAP32[$4>>2] = $9;
   $14 = $13;$17 = $9;$19 = $11;
  }
  $15 = (_llvm_bswap_i32(($14|0))|0);
  HEAP32[$size>>2] = $15;
  $16 = (($17) + 4|0);
  $18 = ($16>>>0)>($19>>>0);
  if ($18) {
   __ZN12CachedReader15UpdateReadCacheEPvj($4,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $21 = $$pre$i$i$i1;$24 = $$pre9;
  } else {
   $20 = HEAP32[$17>>2]|0;
   HEAP32[$offset>>2] = $20;
   HEAP32[$4>>2] = $16;
   $21 = $20;$24 = $15;
  }
  $22 = (_llvm_bswap_i32(($21|0))|0);
  HEAP32[$offset>>2] = $22;
  $23 = $24 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($4,$22,$23)|0);
  HEAP32[$5>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$size1,4);
  $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
  $26 = $$pre$i$i$i3;
 } else {
  $25 = HEAP32[$8>>2]|0;
  HEAP32[$size1>>2] = $25;
  HEAP32[$4>>2] = $9;
  $26 = $25;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$size1>>2] = $27;
 __Z14resize_trimmedINSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEEEvRT_j($data,$27);
 $28 = (($data) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$data>>2]|0;
 $31 = ($30|0)==($29|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = (($tempStr$i$i) + 1|0);
 $33 = (($tempStr$i$i) + 8|0);
 $53 = $30;
 while(1) {
  ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
  __THREW__ = 0;
  invoke_viii(1623,($this|0),($tempStr$i$i|0),0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 15;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3377,($this|0));
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if ($47) {
   label = 15;
   break;
  }
  $48 = HEAP8[$tempStr$i$i>>0]|0;
  $49 = $48 & 1;
  $50 = ($49<<24>>24)==(0);
  $51 = HEAP32[$33>>2]|0;
  $$ = $50 ? $32 : $51;
  $52 = HEAP32[628448>>2]|0;
  HEAP32[$3>>2] = $52;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_viii(1621,($53|0),($$|0),($$byval_copy2|0));
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if ($55) {
   label = 15;
   break;
  }
  $56 = HEAP8[$tempStr$i$i>>0]|0;
  $57 = $56 & 1;
  $58 = ($57<<24>>24)==(0);
  if (!($58)) {
   $59 = HEAP32[$33>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($59|0),($$byval_copy2|0));
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    label = 22;
    break;
   }
  }
  $64 = (($53) + 4|0);
  $65 = ($64|0)==($29|0);
  if ($65) {
   label = 25;
   break;
  } else {
   $53 = $64;
  }
 }
 if ((label|0) == 15) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  $38 = HEAP8[$tempStr$i$i>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if ($40) {
   ___resumeException($36|0);
   // unreachable;
  }
  $41 = HEAP32[$33>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($41|0),($$byval_copy2|0));
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   ___cxa_call_unexpected(($44|0));
   // unreachable;
  } else {
   ___resumeException($36|0);
   // unreachable;
  }
 }
 else if ((label|0) == 22) {
  $62 = ___cxa_find_matching_catch()|0;
  $63 = tempRet0;
  ___cxa_call_unexpected(($62|0));
  // unreachable;
 }
 else if ((label|0) == 25) {
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy8 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lpad$phi$i$i21$index = 0, $lpad$phi$i$i21$index3 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($sz>>>0);
 if ($9) {
  $10 = (($v) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($6))|0;
  $14 = $13 >> 2;
  $15 = ($14|0)==($sz|0);
  if ($15) {
   $71 = (($sz) - ($8))|0;
   __ZNSt3__16vectorI14ConstantStringNS_9allocatorIS1_EEE8__appendEj($v,$71);
   STACKTOP = sp;return;
  }
  HEAP32[$temp>>2] = 0;
  $16 = (($temp) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($temp) + 8|0);
  HEAP32[$17>>2] = 0;
  __THREW__ = 0;
  invoke_vii(2755,($temp|0),($sz|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  L7: do {
   if (!($19)) {
    $20 = HEAP32[$v>>2]|0;
    HEAP32[$0>>2] = $20;
    $21 = HEAP32[$2>>2]|0;
    HEAP32[$1>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viii(1770,($temp|0),($$byval_copy|0),($$byval_copy8|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[$16>>2]|0;
     $25 = HEAP32[$temp>>2]|0;
     $26 = $24;
     $27 = $25;
     $28 = (($26) - ($27))|0;
     $29 = $28 >> 2;
     $30 = ($29>>>0)<($sz>>>0);
     L10: do {
      if ($30) {
       $31 = (($sz) - ($29))|0;
       __THREW__ = 0;
       invoke_vii(2756,($temp|0),($31|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break L7;
       }
       $$pre28 = HEAP32[$16>>2]|0;
       $47 = $$pre28;
      } else {
       $34 = ($29>>>0)>($sz>>>0);
       if ($34) {
        $35 = (($25) + ($sz<<2)|0);
        $36 = ($24|0)==($35|0);
        if ($36) {
         $47 = $24;
        } else {
         $38 = $24;
         while(1) {
          $37 = (($38) + -4|0);
          HEAP32[$16>>2] = $37;
          __THREW__ = 0;
          invoke_vi(3382,($37|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          $$pre$i = HEAP32[$16>>2]|0;
          $41 = ($$pre$i|0)==($35|0);
          if ($41) {
           $47 = $35;
           break L10;
          } else {
           $38 = $$pre$i;
          }
         }
         $42 = ___cxa_find_matching_catch()|0;
         $43 = tempRet0;
         ___cxa_call_unexpected(($42|0));
         // unreachable;
        }
       } else {
        $47 = $24;
       }
      }
     } while(0);
     $44 = HEAP32[$temp>>2]|0;
     $45 = HEAP32[$v>>2]|0;
     HEAP32[$temp>>2] = $45;
     HEAP32[$v>>2] = $44;
     $46 = HEAP32[$2>>2]|0;
     HEAP32[$16>>2] = $46;
     HEAP32[$2>>2] = $47;
     $48 = HEAP32[$17>>2]|0;
     $49 = HEAP32[$10>>2]|0;
     HEAP32[$17>>2] = $49;
     HEAP32[$10>>2] = $48;
     $50 = ($45|0)==(0|0);
     if ($50) {
      STACKTOP = sp;return;
     } else {
      $52 = $46;
     }
     while(1) {
      $51 = ($52|0)==($45|0);
      if ($51) {
       break;
      }
      $53 = (($52) + -4|0);
      HEAP32[$16>>2] = $53;
      __THREW__ = 0;
      invoke_vi(3382,($53|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 17;
       break;
      }
      $$pre29 = HEAP32[$16>>2]|0;
      $52 = $$pre29;
     }
     if ((label|0) == 17) {
      $56 = ___cxa_find_matching_catch()|0;
      $57 = tempRet0;
      ___cxa_call_unexpected(($56|0));
      // unreachable;
     }
     $58 = HEAP32[$temp>>2]|0;
     __ZdlPv($58);
     STACKTOP = sp;return;
    }
   }
  } while(0);
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $61 = HEAP32[$temp>>2]|0;
  $62 = ($61|0)==(0|0);
  if ($62) {
   ___resumeException($59|0);
   // unreachable;
  }
  while(1) {
   $63 = HEAP32[$16>>2]|0;
   $64 = ($63|0)==($61|0);
   if ($64) {
    break;
   }
   $65 = (($63) + -4|0);
   HEAP32[$16>>2] = $65;
   __THREW__ = 0;
   invoke_vi(3382,($65|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 22;
    break;
   }
  }
  if ((label|0) == 22) {
   $68 = ___cxa_find_matching_catch()|0;
   $69 = tempRet0;
   ___cxa_call_unexpected(($68|0));
   // unreachable;
  }
  $70 = HEAP32[$temp>>2]|0;
  __ZdlPv($70);
  ___resumeException($59|0);
  // unreachable;
 } else {
  $72 = ($8>>>0)>($sz>>>0);
  if (!($72)) {
   STACKTOP = sp;return;
  }
  $73 = (($4) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $74 = $$idx >> 2;
  $75 = ($74|0)==(0);
  do {
   if ($75) {
    $105 = 0;$106 = 0;$108 = 0;$110 = $4;$118 = $3;
   } else {
    $76 = ($74>>>0)>(1073741823);
    if ($76) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if (!($78)) {
      // unreachable;
     }
    } else {
     __THREW__ = 0;
     $79 = (invoke_ii(2988,($$idx|0))|0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if (!($81)) {
      $82 = (($79) + ($74<<2)|0);
      $83 = ($sz|0)==(0);
      if ($83) {
       $105 = $79;$106 = $79;$108 = $82;$110 = $4;$118 = $3;
       break;
      } else {
       $85 = $79;$86 = $4;
      }
      while(1) {
       $84 = ($85|0)==(0|0);
       if ($84) {
        $90 = 0;
       } else {
        HEAP32[$85>>2] = 0;
        __THREW__ = 0;
        invoke_vii(2680,($85|0),($86|0));
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         break;
        } else {
         $90 = $85;
        }
       }
       $89 = (($90) + 4|0);
       $91 = (($86) + 4|0);
       $92 = ($91|0)==($73|0);
       if ($92) {
        label = 42;
        break;
       } else {
        $85 = $89;$86 = $91;
       }
      }
      if ((label|0) == 42) {
       $$pre = HEAP32[$v>>2]|0;
       $$pre27 = HEAP32[$2>>2]|0;
       $105 = $79;$106 = $89;$108 = $82;$110 = $$pre;$118 = $$pre27;
       break;
      }
      $95 = ___cxa_find_matching_catch()|0;
      $96 = tempRet0;
      $97 = ($79|0)==(0|0);
      if ($97) {
       $lpad$phi$i$i21$index = $95;$lpad$phi$i$i21$index3 = $96;
       ___resumeException($lpad$phi$i$i21$index|0);
       // unreachable;
      } else {
       $99 = $85;
      }
      while(1) {
       $98 = ($99|0)==($79|0);
       if ($98) {
        break;
       }
       $100 = (($99) + -4|0);
       __THREW__ = 0;
       invoke_vi(3382,($100|0));
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        label = 39;
        break;
       } else {
        $99 = $100;
       }
      }
      if ((label|0) == 39) {
       $103 = ___cxa_find_matching_catch()|0;
       $104 = tempRet0;
       ___cxa_call_unexpected(($103|0));
       // unreachable;
      }
      __ZdlPv($79);
      $lpad$phi$i$i21$index = $95;$lpad$phi$i$i21$index3 = $96;
      ___resumeException($lpad$phi$i$i21$index|0);
      // unreachable;
     }
    }
    $93 = ___cxa_find_matching_catch()|0;
    $94 = tempRet0;
    $lpad$phi$i$i21$index = $93;$lpad$phi$i$i21$index3 = $94;
    ___resumeException($lpad$phi$i$i21$index|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $105;
  HEAP32[$2>>2] = $106;
  $107 = (($v) + 8|0);
  HEAP32[$107>>2] = $108;
  $109 = ($110|0)==(0|0);
  if ($109) {
   STACKTOP = sp;return;
  } else {
   $112 = $118;
  }
  while(1) {
   $111 = ($112|0)==($110|0);
   if ($111) {
    break;
   }
   $113 = (($112) + -4|0);
   __THREW__ = 0;
   invoke_vi(3382,($113|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if ($115) {
    label = 46;
    break;
   } else {
    $112 = $113;
   }
  }
  if ((label|0) == 46) {
   $116 = ___cxa_find_matching_catch()|0;
   $117 = tempRet0;
   ___cxa_call_unexpected(($116|0));
   // unreachable;
  }
  __ZdlPv($110);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI14ConstantStringNS_9allocatorIS1_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 2;
 $13 = ($__n|0)==(0);
 if ($13) {
  $17 = 0;
 } else {
  $14 = $__n << 2;
  $15 = (__Znwj($14)|0);
  $17 = $15;
 }
 $16 = (($17) + ($12<<2)|0);
 $18 = (($17) + ($__n<<2)|0);
 $19 = ($9|0)==($2|0);
 do {
  if ($19) {
   $26 = $16;$29 = $2;$46 = $2;
  } else {
   $$01$i$i = $9;$21 = $16;
   while(1) {
    $20 = (($21) + -4|0);
    $22 = (($$01$i$i) + -4|0);
    HEAP32[$20>>2] = 0;
    __THREW__ = 0;
    invoke_vii(2680,($20|0),($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = ($22|0)==($2|0);
    if ($25) {
     label = 7;
     break;
    } else {
     $$01$i$i = $22;$21 = $20;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$8>>2]|0;
    $26 = $20;$29 = $$pre$i;$46 = $$pre;
    break;
   }
   $36 = ___cxa_find_matching_catch()|0;
   $37 = tempRet0;
   $39 = $16;
   while(1) {
    $38 = ($39|0)==($21|0);
    if ($38) {
     break;
    }
    $40 = (($39) + -4|0);
    __THREW__ = 0;
    invoke_vi(3382,($40|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 17;
     break;
    } else {
     $39 = $40;
    }
   }
   if ((label|0) == 17) {
    $43 = ___cxa_find_matching_catch()|0;
    $44 = tempRet0;
    ___cxa_call_unexpected(($43|0));
    // unreachable;
   }
   $45 = ($17|0)==(0|0);
   if ($45) {
    ___resumeException($36|0);
    // unreachable;
   }
   __ZdlPv($17);
   ___resumeException($36|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$this>>2] = $26;
 HEAP32[$8>>2] = $16;
 HEAP32[$0>>2] = $18;
 $28 = $46;
 while(1) {
  $27 = ($28|0)==($29|0);
  if ($27) {
   break;
  }
  $30 = (($28) + -4|0);
  __THREW__ = 0;
  invoke_vi(3382,($30|0));
  $31 = __THREW__; __THREW__ = 0;
  $32 = $31&1;
  if ($32) {
   label = 11;
   break;
  } else {
   $28 = $30;
  }
 }
 if ((label|0) == 11) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  ___cxa_call_unexpected(($33|0));
  // unreachable;
 }
 $35 = ($29|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 __ZdlPv($29);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI14ConstantStringNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $8 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $45 = ($8|0)==(0|0);
  do {
   if ($45) {
    $57 = $7;
   } else {
    $46 = (($this) + 4|0);
    while(1) {
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==($8|0);
     if ($48) {
      label = 22;
      break;
     }
     $49 = (($47) + -4|0);
     HEAP32[$46>>2] = $49;
     __THREW__ = 0;
     invoke_vi(3382,($49|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 21;
      break;
     }
    }
    if ((label|0) == 21) {
     $52 = ___cxa_find_matching_catch()|0;
     $53 = tempRet0;
     ___cxa_call_unexpected(($52|0));
     // unreachable;
    }
    else if ((label|0) == 22) {
     $54 = HEAP32[$this>>2]|0;
     __ZdlPv($54);
     HEAP32[$6>>2] = 0;
     HEAP32[$46>>2] = 0;
     HEAP32[$this>>2] = 0;
     $57 = 0;
     break;
    }
   }
  } while(0);
  $55 = ($5>>>0)>(1073741823);
  if ($55) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $56 = $57;
  $58 = $56 >> 2;
  $59 = ($58>>>0)<(536870911);
  if ($59) {
   $60 = $56 >> 1;
   $61 = ($60>>>0)<($5>>>0);
   $62 = $61 ? $5 : $60;
   $63 = ($62>>>0)>(1073741823);
   if ($63) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i31 = $62;
   }
  } else {
   $$0$i31 = 1073741823;
  }
  $64 = $$0$i31 << 2;
  $65 = (__Znwj($64)|0);
  $66 = (($this) + 4|0);
  HEAP32[$66>>2] = $65;
  HEAP32[$this>>2] = $65;
  $67 = (($65) + ($$0$i31<<2)|0);
  HEAP32[$6>>2] = $67;
  $68 = ($0|0)==($1|0);
  if ($68) {
   STACKTOP = sp;return;
  } else {
   $70 = $65;$71 = $0;
  }
  while(1) {
   $69 = ($70|0)==(0|0);
   if ($69) {
    $73 = 0;
   } else {
    HEAP32[$70>>2] = 0;
    __ZN14ConstantString6assignERKS_($70,$71);
    $$pre1$i = HEAP32[$66>>2]|0;
    $73 = $$pre1$i;
   }
   $72 = (($73) + 4|0);
   HEAP32[$66>>2] = $72;
   $74 = (($71) + 4|0);
   $75 = ($74|0)==($1|0);
   if ($75) {
    break;
   } else {
    $70 = $72;$71 = $74;
   }
  }
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 2;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<2)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i = (($22) + -4|0);
  $23 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($23)|0);
  $uglygep16$i = $uglygep$i;
  $24 = $uglygep16$i >>> 2;
  $$01$i$i = $8;$25 = $0;
  while(1) {
   __ZN14ConstantStringaSERKS_($$01$i$i,$25);
   $26 = (($25) + 4|0);
   $27 = (($$01$i$i) + 4|0);
   $28 = ($26|0)==($22|0);
   if ($28) {
    break;
   } else {
    $$01$i$i = $27;$25 = $26;
   }
  }
  $29 = (($24) + 1)|0;
  $scevgep17$i = (($8) + ($29<<2)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if (!($__growing$0$off0)) {
  while(1) {
   $38 = HEAP32[$14>>2]|0;
   $39 = ($38|0)==($$0$lcssa$i$i|0);
   if ($39) {
    label = 32;
    break;
   }
   $40 = (($38) + -4|0);
   HEAP32[$14>>2] = $40;
   __THREW__ = 0;
   invoke_vi(3382,($40|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    label = 16;
    break;
   }
  }
  if ((label|0) == 16) {
   $43 = ___cxa_find_matching_catch()|0;
   $44 = tempRet0;
   ___cxa_call_unexpected(($43|0));
   // unreachable;
  }
  else if ((label|0) == 32) {
   STACKTOP = sp;return;
  }
 }
 $30 = ($22|0)==($1|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $$pre$i12 = HEAP32[$14>>2]|0;
 $32 = $$pre$i12;$33 = $22;
 while(1) {
  $31 = ($32|0)==(0|0);
  if ($31) {
   $35 = 0;
  } else {
   HEAP32[$32>>2] = 0;
   __ZN14ConstantString6assignERKS_($32,$33);
   $$pre1$i14 = HEAP32[$14>>2]|0;
   $35 = $$pre1$i14;
  }
  $34 = (($35) + 4|0);
  HEAP32[$14>>2] = $34;
  $36 = (($33) + 4|0);
  $37 = ($36|0)==($1|0);
  if ($37) {
   break;
  } else {
   $32 = $34;$33 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI14ConstantStringNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i122 = 0, $$0$i123 = 0, $$0$i6 = 0, $$01$i$i = 0, $$pre = 0, $$pre$i10 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    HEAP32[$10>>2] = 0;
    __ZN14ConstantString12create_emptyEv($10);
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 4|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i123 = 0;$31 = 0;
  } else {
   $$0$i122 = $26;
   label = 9;
  }
 } else {
  $$0$i122 = 1073741823;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = $$0$i122 << 2;
  $29 = (__Znwj($28)|0);
  $$0$i123 = $$0$i122;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $32 = (($31) + ($$0$i123<<2)|0);
 $$0$i6 = $__n;$34 = $30;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $38 = 0;
  } else {
   HEAP32[$34>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3379,($34|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    label = 25;
    break;
   } else {
    $38 = $34;
   }
  }
  $37 = (($38) + 4|0);
  $39 = (($$0$i6) + -1)|0;
  $40 = ($39|0)==(0);
  if ($40) {
   label = 14;
   break;
  } else {
   $$0$i6 = $39;$34 = $37;
  }
 }
 L22: do {
  if ((label|0) == 14) {
   $41 = HEAP32[$this>>2]|0;
   $42 = HEAP32[$2>>2]|0;
   $43 = ($42|0)==($41|0);
   do {
    if ($43) {
     $50 = $30;$53 = $41;$73 = $41;
    } else {
     $$01$i$i = $42;$45 = $30;
     while(1) {
      $44 = (($45) + -4|0);
      $46 = (($$01$i$i) + -4|0);
      HEAP32[$44>>2] = 0;
      __THREW__ = 0;
      invoke_vii(2680,($44|0),($46|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 24;
       break;
      }
      $49 = ($46|0)==($41|0);
      if ($49) {
       label = 17;
       break;
      } else {
       $$01$i$i = $46;$45 = $44;
      }
     }
     if ((label|0) == 17) {
      $$pre$i10 = HEAP32[$this>>2]|0;
      $$pre = HEAP32[$2>>2]|0;
      $50 = $44;$53 = $$pre$i10;$73 = $$pre;
      break;
     }
     else if ((label|0) == 24) {
      $60 = ___cxa_find_matching_catch()|0;
      $61 = tempRet0;
      $66 = $45;$74 = $37;$lpad$phi$index = $60;$lpad$phi$index2 = $61;
      break L22;
     }
    }
   } while(0);
   HEAP32[$this>>2] = $50;
   HEAP32[$2>>2] = $37;
   HEAP32[$0>>2] = $32;
   $52 = $73;
   while(1) {
    $51 = ($52|0)==($53|0);
    if ($51) {
     break;
    }
    $54 = (($52) + -4|0);
    __THREW__ = 0;
    invoke_vi(3382,($54|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 21;
     break;
    } else {
     $52 = $54;
    }
   }
   if ((label|0) == 21) {
    $57 = ___cxa_find_matching_catch()|0;
    $58 = tempRet0;
    ___cxa_call_unexpected(($57|0));
    // unreachable;
   }
   $59 = ($53|0)==(0|0);
   if ($59) {
    STACKTOP = sp;return;
   }
   __ZdlPv($53);
   STACKTOP = sp;return;
  }
  else if ((label|0) == 25) {
   $62 = ___cxa_find_matching_catch()|0;
   $63 = tempRet0;
   $66 = $30;$74 = $34;$lpad$phi$index = $62;$lpad$phi$index2 = $63;
  }
 } while(0);
 $65 = $74;
 while(1) {
  $64 = ($65|0)==($66|0);
  if ($64) {
   break;
  }
  $67 = (($65) + -4|0);
  __THREW__ = 0;
  invoke_vi(3382,($67|0));
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   label = 29;
   break;
  } else {
   $65 = $67;
  }
 }
 if ((label|0) == 29) {
  $70 = ___cxa_find_matching_catch()|0;
  $71 = tempRet0;
  ___cxa_call_unexpected(($70|0));
  // unreachable;
 }
 $72 = ($31|0)==(0|0);
 if ($72) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __ZdlPv($31);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__18multimapI8UnityStrN11AssetBundle9AssetInfoENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy34 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i$i$i = 0, $__parent$i$i = 0, $eh$lpad$body$i$index8Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$038 = 0, $lpad$phi$index = 0, $lpad$phi$index14 = 0, $lpad$phi17$index = 0, $lpad$phi17$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy34 = sp + 116|0;
 $1 = sp + 112|0;
 $2 = sp + 108|0;
 $3 = sp + 104|0;
 $4 = sp + 100|0;
 $5 = sp + 96|0;
 $__parent$i$i = sp + 92|0;
 $6 = sp + 88|0;
 $7 = sp + 40|0;
 $8 = sp + 32|0;
 $9 = sp + 28|0;
 $size = sp + 24|0;
 $p = sp;
 $10 = sp + 64|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$size>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = $17;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$size>>2] = $19;
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;HEAP32[$p+16>>2]=0|0;HEAP32[$p+20>>2]=0|0;
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($data,$21);
 $22 = (($data) + 8|0);
 HEAP32[$22>>2] = 0;
 $23 = (($data) + 4|0);
 HEAP32[$data>>2] = $23;
 HEAP32[$23>>2] = 0;
 $24 = HEAP32[$size>>2]|0;
 $25 = ($24|0)>(0);
 L5: do {
  if ($25) {
   $26 = (($p) + 1|0);
   $27 = (($10) + 1|0);
   $28 = (($10) + 12|0);
   $29 = (($p) + 12|0);
   $30 = (($p) + 20|0);
   $31 = (($10) + 20|0);
   $32 = (($7) + 1|0);
   $33 = (($7) + 12|0);
   $34 = (($7) + 20|0);
   $35 = (($10) + 8|0);
   $36 = (($7) + 8|0);
   $37 = (($7) + 4|0);
   $38 = (($10) + 4|0);
   $39 = (($p) + 8|0);
   $40 = (($p) + 4|0);
   $i$038 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_viiii(371,($this|0),($p|0),0,0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 55;
     break;
    }
    $43 = HEAP8[$p>>0]|0;
    $44 = $43 & 1;
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     $48 = $43&255;
     $49 = $48 >>> 1;
     $51 = $49;$64 = $26;
    } else {
     $46 = HEAP32[$39>>2]|0;
     $47 = HEAP32[$40>>2]|0;
     $51 = $47;$64 = $46;
    }
    $50 = ($51>>>0)>(2147483631);
    if ($50) {
     label = 11;
     break;
    }
    $54 = ($51>>>0)<(11);
    if ($54) {
     $55 = $51 << 1;
     $56 = $55&255;
     HEAP8[$10>>0] = $56;
     $78 = $56;$__p$0$i$i$i$i$i$i = $27;
    } else {
     $57 = (($51) + 16)|0;
     $58 = $57 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$8+0>>2]|0;
     $59 = (invoke_iiiiiii(102,($58|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 55;
      break;
     }
     HEAP32[$35>>2] = $59;
     $62 = $58 | 1;
     HEAP32[$10>>2] = $62;
     HEAP32[$38>>2] = $51;
     $63 = $62&255;
     $78 = $63;$__p$0$i$i$i$i$i$i = $59;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($64|0),($51|0))|0;
    $65 = (($__p$0$i$i$i$i$i$i) + ($51)|0);
    HEAP8[$65>>0] = 0;
    $66 = $29;
    $67 = $66;
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + 4)|0;
    $70 = $69;
    $71 = HEAP32[$70>>2]|0;
    $72 = $28;
    $73 = $72;
    HEAP32[$73>>2] = $68;
    $74 = (($72) + 4)|0;
    $75 = $74;
    HEAP32[$75>>2] = $71;
    $76 = HEAP32[$30>>2]|0;
    HEAP32[$31>>2] = $76;
    $77 = $78 & 1;
    $79 = ($77<<24>>24)==(0);
    if ($79) {
     $82 = $78&255;
     $83 = $82 >>> 1;
     $85 = $83;$97 = $27;
    } else {
     $80 = HEAP32[$35>>2]|0;
     $81 = HEAP32[$38>>2]|0;
     $85 = $81;$97 = $80;
    }
    $84 = ($85>>>0)>(2147483631);
    if ($84) {
     label = 21;
     break;
    }
    $88 = ($85>>>0)<(11);
    if ($88) {
     $89 = $85 << 1;
     $90 = $89&255;
     HEAP8[$7>>0] = $90;
     $__p$0$i$i$i$i$i$i$i$i$i = $32;
    } else {
     $91 = (($85) + 16)|0;
     $92 = $91 & -16;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$6+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($92|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      label = 58;
      break;
     }
     HEAP32[$36>>2] = $93;
     $96 = $92 | 1;
     HEAP32[$7>>2] = $96;
     HEAP32[$37>>2] = $85;
     $__p$0$i$i$i$i$i$i$i$i$i = $93;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($97|0),($85|0))|0;
    $98 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($85)|0);
    HEAP8[$98>>0] = 0;
    $99 = $33;
    $100 = $99;
    HEAP32[$100>>2] = $68;
    $101 = (($99) + 4)|0;
    $102 = $101;
    HEAP32[$102>>2] = $71;
    HEAP32[$34>>2] = $76;
    $103 = (__ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS5_($data,$__parent$i$i,$7)|0);
    __THREW__ = 0;
    $104 = (invoke_ii(2988,40)|0);
    $105 = __THREW__; __THREW__ = 0;
    $106 = $105&1;
    if ($106) {
     label = 47;
     break;
    }
    $107 = (($104) + 16|0);
    $108 = HEAP8[$7>>0]|0;
    $109 = $108 & 1;
    $110 = ($109<<24>>24)==(0);
    if ($110) {
     $113 = $108&255;
     $114 = $113 >>> 1;
     $116 = $114;$136 = $32;
    } else {
     $111 = HEAP32[$36>>2]|0;
     $112 = HEAP32[$37>>2]|0;
     $116 = $112;$136 = $111;
    }
    $115 = ($116>>>0)>(2147483631);
    if ($115) {
     label = 32;
     break;
    }
    $119 = ($116>>>0)<(11);
    if ($119) {
     $120 = $116 << 1;
     $121 = $120&255;
     HEAP8[$107>>0] = $121;
     $122 = (($104) + 17|0);
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $122;
    } else {
     $123 = (($116) + 16)|0;
     $124 = $123 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$5+0>>2]|0;
     $125 = (invoke_iiiiiii(102,($124|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $126 = __THREW__; __THREW__ = 0;
     $127 = $126&1;
     if ($127) {
      label = 38;
      break;
     }
     $128 = (($104) + 24|0);
     HEAP32[$128>>2] = $125;
     $129 = $124 | 1;
     HEAP32[$107>>2] = $129;
     $130 = (($104) + 20|0);
     HEAP32[$130>>2] = $116;
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $125;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i$i$i|0),($136|0),($116|0))|0;
    $137 = (($__p$0$i$i$i$i$i$i$i$i$i$i$i) + ($116)|0);
    HEAP8[$137>>0] = 0;
    $138 = (($104) + 28|0);
    $139 = $33;
    $140 = $139;
    $141 = HEAP32[$140>>2]|0;
    $142 = (($139) + 4)|0;
    $143 = $142;
    $144 = HEAP32[$143>>2]|0;
    $145 = $138;
    $146 = $145;
    HEAP32[$146>>2] = $141;
    $147 = (($145) + 4)|0;
    $148 = $147;
    HEAP32[$148>>2] = $144;
    $149 = HEAP32[$34>>2]|0;
    $150 = (($104) + 36|0);
    HEAP32[$150>>2] = $149;
    $151 = HEAP32[$__parent$i$i>>2]|0;
    HEAP32[$104>>2] = 0;
    $152 = (($104) + 4|0);
    HEAP32[$152>>2] = 0;
    $153 = (($104) + 8|0);
    HEAP32[$153>>2] = $151;
    HEAP32[$103>>2] = $104;
    $154 = HEAP32[$data>>2]|0;
    $155 = HEAP32[$154>>2]|0;
    $156 = ($155|0)==(0|0);
    if ($156) {
     $158 = $104;
    } else {
     HEAP32[$data>>2] = $155;
     $$pre$i$i$i3 = HEAP32[$103>>2]|0;
     $158 = $$pre$i$i$i3;
    }
    $157 = HEAP32[$20>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($157,$158);
    $159 = HEAP32[$22>>2]|0;
    $160 = (($159) + 1)|0;
    HEAP32[$22>>2] = $160;
    if (!($110)) {
     $161 = HEAP32[$36>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($161|0),($$byval_copy34|0));
     $162 = __THREW__; __THREW__ = 0;
     $163 = $162&1;
     if ($163) {
      label = 46;
      break;
     }
    }
    $176 = $78 & 1;
    $177 = ($176<<24>>24)==(0);
    if (!($177)) {
     $178 = HEAP32[$35>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($178|0),($$byval_copy34|0));
     $179 = __THREW__; __THREW__ = 0;
     $180 = $179&1;
     if ($180) {
      label = 53;
      break;
     }
    }
    $183 = (($i$038) + 1)|0;
    $184 = HEAP32[$size>>2]|0;
    $185 = ($183|0)<($184|0);
    if ($185) {
     $i$038 = $183;
    } else {
     break L5;
    }
   }
   do {
    if ((label|0) == 11) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $188 = ___cxa_find_matching_catch()|0;
      $189 = tempRet0;
      $lpad$phi$index = $188;$lpad$phi$index14 = $189;
      label = 57;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 21) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      $192 = ___cxa_find_matching_catch()|0;
      $193 = tempRet0;
      $eh$lpad$body$index21Z2D = $193;$eh$lpad$body$indexZ2D = $192;
      label = 60;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 32) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      $133 = ___cxa_find_matching_catch()|0;
      $134 = tempRet0;
      $lpad$phi17$index = $133;$lpad$phi17$index2 = $134;
      label = 40;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 38) {
     $131 = ___cxa_find_matching_catch()|0;
     $132 = tempRet0;
     $lpad$phi17$index = $131;$lpad$phi17$index2 = $132;
     label = 40;
    }
    else if ((label|0) == 46) {
     $164 = ___cxa_find_matching_catch()|0;
     $165 = tempRet0;
     ___cxa_call_unexpected(($164|0));
     // unreachable;
    }
    else if ((label|0) == 47) {
     $166 = ___cxa_find_matching_catch()|0;
     $167 = tempRet0;
     $$pre$i = HEAP8[$7>>0]|0;
     $169 = $$pre$i;$eh$lpad$body$i$index8Z2D = $167;$eh$lpad$body$i$indexZ2D = $166;
     label = 48;
    }
    else if ((label|0) == 53) {
     $181 = ___cxa_find_matching_catch()|0;
     $182 = tempRet0;
     ___cxa_call_unexpected(($181|0));
     // unreachable;
    }
    else if ((label|0) == 55) {
     $186 = ___cxa_find_matching_catch()|0;
     $187 = tempRet0;
     $lpad$phi$index = $186;$lpad$phi$index14 = $187;
     label = 57;
    }
    else if ((label|0) == 58) {
     $190 = ___cxa_find_matching_catch()|0;
     $191 = tempRet0;
     $eh$lpad$body$index21Z2D = $191;$eh$lpad$body$indexZ2D = $190;
     label = 60;
    }
   } while(0);
   if ((label|0) == 40) {
    $135 = ($104|0)==(0|0);
    if ($135) {
     $169 = $108;$eh$lpad$body$i$index8Z2D = $lpad$phi17$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi17$index;
     label = 48;
    } else {
     __ZdlPv($104);
     $169 = $108;$eh$lpad$body$i$index8Z2D = $lpad$phi17$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi17$index;
     label = 48;
    }
   }
   else if ((label|0) == 57) {
    $$0 = $lpad$phi$index14;$$01 = $lpad$phi$index;
   }
   if ((label|0) == 48) {
    $168 = $169 & 1;
    $170 = ($168<<24>>24)==(0);
    if ($170) {
     $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
     label = 60;
    } else {
     $171 = HEAP32[$36>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($171|0),($$byval_copy34|0));
     $172 = __THREW__; __THREW__ = 0;
     $173 = $172&1;
     if ($173) {
      $174 = ___cxa_find_matching_catch()|0;
      $175 = tempRet0;
      ___cxa_call_unexpected(($174|0));
      // unreachable;
     } else {
      $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
      label = 60;
     }
    }
   }
   if ((label|0) == 60) {
    $194 = $78 & 1;
    $195 = ($194<<24>>24)==(0);
    if ($195) {
     $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
    } else {
     $196 = HEAP32[$35>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($196|0),($$byval_copy34|0));
     $197 = __THREW__; __THREW__ = 0;
     $198 = $197&1;
     if ($198) {
      $199 = ___cxa_find_matching_catch()|0;
      $200 = tempRet0;
      ___cxa_call_unexpected(($199|0));
      // unreachable;
     } else {
      $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
    }
   }
   $210 = HEAP8[$p>>0]|0;
   $211 = $210 & 1;
   $212 = ($211<<24>>24)==(0);
   if ($212) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $213 = HEAP32[$39>>2]|0;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($213|0),($$byval_copy34|0));
   $214 = __THREW__; __THREW__ = 0;
   $215 = $214&1;
   if ($215) {
    $216 = ___cxa_find_matching_catch()|0;
    $217 = tempRet0;
    ___cxa_call_unexpected(($216|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $201 = HEAP8[$p>>0]|0;
 $202 = $201 & 1;
 $203 = ($202<<24>>24)==(0);
 if ($203) {
  STACKTOP = sp;return;
 }
 $204 = (($p) + 8|0);
 $205 = HEAP32[$204>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($205|0),($$byval_copy34|0));
 $206 = __THREW__; __THREW__ = 0;
 $207 = $206&1;
 if ($207) {
  $208 = ___cxa_find_matching_catch()|0;
  $209 = tempRet0;
  ___cxa_call_unexpected(($208|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE8TransferINSt3__14pairI8UnityStrN11AssetBundle9AssetInfoEEEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i1$i$i$i$i = 0, $$pre3$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$data,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
 $2 = (($data) + 12|0);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i$i$i$i$i = HEAP32[$2>>2]|0;
  $$pre$i$i$i$i = HEAP32[$3>>2]|0;
  $$pre3$i$i$i$i = HEAP32[$6>>2]|0;
  $10 = $$pre$i$i$i$i$i$i$i;$14 = $$pre$i$i$i$i;$16 = $$pre3$i$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;$14 = $5;$16 = $7;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$2>>2] = $11;
 $12 = (($data) + 16|0);
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$12,4);
  $$pre$i$i$i1$i$i$i$i = HEAP32[$12>>2]|0;
  $18 = $$pre$i$i$i1$i$i$i$i;
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$12>>2] = $19;
  $20 = (($data) + 20|0);
  __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($20,$this);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$3>>2] = $13;
  $18 = $17;
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$12>>2] = $19;
  $20 = (($data) + 20|0);
  __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($20,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI4PPtrI6ObjectELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<2)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 4|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = $23 << 2;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = $22 >> 2;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI4PPtrI6ObjectELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 2;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,616888,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 2;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,616888,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 2;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<2)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<2)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   HEAP32[$$01$i$i>>2] = 0;
  }
  $30 = (($$01$i$i) + 4|0);
  $31 = ($30|0)==($25|0);
  if ($31) {
   break;
  } else {
   $$01$i$i = $30;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS6_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0 = 0, $$lcssa = 0, $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, $__nd$0$in$lcssa = 0, $__nd$0$in$lcssa1 = 0, $__nd$0$in$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $63 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $63;
  $$0 = $63;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 if ($5) {
  $__nd$0$in$us = $1;
  while(1) {
   $11 = (($__nd$0$in$us) + 16|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = $12 & 1;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $19 = $12&255;
    $20 = $19 >>> 1;
    $21 = (($11) + 1|0);
    $23 = $20;$25 = $21;
   } else {
    $15 = (($__nd$0$in$us) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($__nd$0$in$us) + 24|0);
    $18 = HEAP32[$17>>2]|0;
    $23 = $16;$25 = $18;
   }
   $22 = ($23>>>0)<($7>>>0);
   $24 = $22 ? $23 : $7;
   $26 = (_memcmp($8,$25,$24)|0);
   $27 = ($26|0)==(0);
   if ($27) {
    $28 = ($7>>>0)<($23>>>0);
    $$$i$i$i$i$us = $22&1;
    $$$$i$i$i$i$us = $28 ? -1 : $$$i$i$i$i$us;
    $30 = $$$$i$i$i$i$us;
   } else {
    $30 = $26;
   }
   $29 = ($30|0)<(0);
   if ($29) {
    $34 = HEAP32[$__nd$0$in$us>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     $$lcssa2 = $__nd$0$in$us;$__nd$0$in$lcssa1 = $__nd$0$in$us;
     label = 18;
     break;
    } else {
     $__nd$0$in$us = $34;
     continue;
    }
   } else {
    $31 = (($__nd$0$in$us) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     $$lcssa = $31;$__nd$0$in$lcssa = $__nd$0$in$us;
     label = 20;
     break;
    } else {
     $__nd$0$in$us = $32;
     continue;
    }
   }
  }
 } else {
  $__nd$0$in = $1;
  while(1) {
   $36 = (($__nd$0$in) + 16|0);
   $37 = HEAP32[$10>>2]|0;
   $38 = HEAP8[$36>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    $45 = $38&255;
    $46 = $45 >>> 1;
    $47 = (($36) + 1|0);
    $50 = $46;$52 = $47;
   } else {
    $41 = (($__nd$0$in) + 20|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($__nd$0$in) + 24|0);
    $44 = HEAP32[$43>>2]|0;
    $50 = $42;$52 = $44;
   }
   $48 = HEAP32[$9>>2]|0;
   $49 = ($50>>>0)<($37>>>0);
   $51 = $49 ? $50 : $37;
   $53 = (_memcmp($48,$52,$51)|0);
   $54 = ($53|0)==(0);
   if ($54) {
    $55 = ($37>>>0)<($50>>>0);
    $$$i$i$i$i = $49&1;
    $$$$i$i$i$i = $55 ? -1 : $$$i$i$i$i;
    $57 = $$$$i$i$i$i;
   } else {
    $57 = $53;
   }
   $56 = ($57|0)<(0);
   if ($56) {
    $58 = HEAP32[$__nd$0$in>>2]|0;
    $59 = ($58|0)==(0|0);
    if ($59) {
     $$lcssa2 = $__nd$0$in;$__nd$0$in$lcssa1 = $__nd$0$in;
     label = 18;
     break;
    } else {
     $__nd$0$in = $58;
     continue;
    }
   } else {
    $60 = (($__nd$0$in) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)==(0|0);
    if ($62) {
     $$lcssa = $60;$__nd$0$in$lcssa = $__nd$0$in;
     label = 20;
     break;
    } else {
     $__nd$0$in = $61;
     continue;
    }
   }
  }
 }
 if ((label|0) == 18) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa1;
  $$0 = $$lcssa2;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 20) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa;
  $$0 = $$lcssa;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN11AssetBundle8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy2 = 0, $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp;
 $tempStr$i$i = sp + 4|0;
 $1 = sp + 16|0;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$3,0);
 $4 = (($this) + 60|0);
 __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__18multimapI8UnityStrN11AssetBundle9AssetInfoENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S6_EEEEEEEEvRT_17TransferMetaFlags($transfer,$4,0);
 $5 = (($this) + 32|0);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$5,4);
  $$pre$i$i$i = HEAP32[$6>>2]|0;
  $$pre2$i$i$i = HEAP32[$9>>2]|0;
  $15 = $$pre$i$i$i;$17 = $$pre2$i$i$i;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$5>>2] = $12;
  HEAP32[$6>>2] = $8;
  $15 = $8;$17 = $10;
 }
 $13 = (($this) + 36|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$13,4);
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$6>>2] = $14;
 }
 $19 = (($this) + 40|0);
 __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($19,$transfer);
 $20 = HEAP32[$6>>2]|0;
 $21 = (($20) + 4|0);
 $22 = HEAP32[$9>>2]|0;
 $23 = ($21>>>0)>($22>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$2,4);
 } else {
  $24 = HEAP32[$20>>2]|0;
  HEAP32[$2>>2] = $24;
  HEAP32[$6>>2] = $21;
 }
 $25 = (($this) + 84|0);
 ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1622,($transfer|0),($tempStr$i$i|0),0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if (!($27)) {
  __THREW__ = 0;
  invoke_vi(3376,($transfer|0));
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if (!($40)) {
   $41 = HEAP8[$tempStr$i$i>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $46 = (($tempStr$i$i) + 1|0);
    $48 = $46;
   } else {
    $44 = (($tempStr$i$i) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $48 = $45;
   }
   $47 = HEAP32[628448>>2]|0;
   HEAP32[$1>>2] = $47;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1621,($25|0),($48|0),($$byval_copy2|0));
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    $51 = HEAP8[$tempStr$i$i>>0]|0;
    $52 = $51 & 1;
    $53 = ($52<<24>>24)==(0);
    if ($53) {
     $60 = (($this) + 88|0);
     __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$60,0);
     STACKTOP = sp;return;
    }
    $54 = (($tempStr$i$i) + 8|0);
    $55 = HEAP32[$54>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($55|0),($$byval_copy2|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     ___cxa_call_unexpected(($58|0));
     // unreachable;
    } else {
     $60 = (($this) + 88|0);
     __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$60,0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 $30 = HEAP8[$tempStr$i$i>>0]|0;
 $31 = $30 & 1;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  ___resumeException($28|0);
  // unreachable;
 }
 $33 = (($tempStr$i$i) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy2|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($28|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ = 0, $$byval_copy2 = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, $tempStr$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy2 = sp + 36|0;
 $1 = sp;
 $2 = sp + 4|0;
 $tempStr$i$i = sp + 8|0;
 $3 = sp + 20|0;
 $offset = sp + 24|0;
 $size = sp + 28|0;
 $size1 = sp + 32|0;
 $4 = (($this) + 12|0);
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 $8 = HEAP32[$4>>2]|0;
 $9 = (($8) + 4|0);
 $10 = (($this) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 if (!($7)) {
  if ($12) {
   __ZN12CachedReader15UpdateReadCacheEPvj($4,$size,4);
   $$pre6 = HEAP32[$4>>2]|0;
   $$pre7 = HEAP32[$10>>2]|0;
   $15 = $$pre6;$17 = $$pre7;
  } else {
   $13 = HEAP32[$8>>2]|0;
   HEAP32[$size>>2] = $13;
   HEAP32[$4>>2] = $9;
   $15 = $9;$17 = $11;
  }
  $14 = (($15) + 4|0);
  $16 = ($14>>>0)>($17>>>0);
  if ($16) {
   __ZN12CachedReader15UpdateReadCacheEPvj($4,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $21 = $$pre8;
  } else {
   $18 = HEAP32[$15>>2]|0;
   HEAP32[$offset>>2] = $18;
   HEAP32[$4>>2] = $14;
   $21 = $18;
  }
  $19 = HEAP32[$size>>2]|0;
  $20 = $19 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($4,$21,$20)|0);
  HEAP32[$5>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $23 = $$pre;
 } else {
  $22 = HEAP32[$8>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$4>>2] = $9;
  $23 = $22;
 }
 __Z14resize_trimmedINSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEEEvRT_j($data,$23);
 $24 = (($data) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$data>>2]|0;
 $27 = ($26|0)==($25|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (($tempStr$i$i) + 1|0);
 $29 = (($tempStr$i$i) + 8|0);
 $49 = $26;
 while(1) {
  ;HEAP32[$tempStr$i$i+0>>2]=0|0;HEAP32[$tempStr$i$i+4>>2]=0|0;HEAP32[$tempStr$i$i+8>>2]=0|0;
  __THREW__ = 0;
  invoke_viii(1622,($this|0),($tempStr$i$i|0),0);
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   label = 15;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3376,($this|0));
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   label = 15;
   break;
  }
  $44 = HEAP8[$tempStr$i$i>>0]|0;
  $45 = $44 & 1;
  $46 = ($45<<24>>24)==(0);
  $47 = HEAP32[$29>>2]|0;
  $$ = $46 ? $28 : $47;
  $48 = HEAP32[628448>>2]|0;
  HEAP32[$3>>2] = $48;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_viii(1621,($49|0),($$|0),($$byval_copy2|0));
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   label = 15;
   break;
  }
  $52 = HEAP8[$tempStr$i$i>>0]|0;
  $53 = $52 & 1;
  $54 = ($53<<24>>24)==(0);
  if (!($54)) {
   $55 = HEAP32[$29>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($55|0),($$byval_copy2|0));
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    label = 22;
    break;
   }
  }
  $60 = (($49) + 4|0);
  $61 = ($60|0)==($25|0);
  if ($61) {
   label = 25;
   break;
  } else {
   $49 = $60;
  }
 }
 if ((label|0) == 15) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  $34 = HEAP8[$tempStr$i$i>>0]|0;
  $35 = $34 & 1;
  $36 = ($35<<24>>24)==(0);
  if ($36) {
   ___resumeException($32|0);
   // unreachable;
  }
  $37 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($37|0),($$byval_copy2|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   ___cxa_call_unexpected(($40|0));
   // unreachable;
  } else {
   ___resumeException($32|0);
   // unreachable;
  }
 }
 else if ((label|0) == 22) {
  $58 = ___cxa_find_matching_catch()|0;
  $59 = tempRet0;
  ___cxa_call_unexpected(($58|0));
  // unreachable;
 }
 else if ((label|0) == 25) {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__18multimapI8UnityStrN11AssetBundle9AssetInfoENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy34 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i$i$i = 0, $__parent$i$i = 0, $eh$lpad$body$i$index8Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$037 = 0, $lpad$phi$index = 0, $lpad$phi$index14 = 0, $lpad$phi16$index = 0, $lpad$phi16$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy34 = sp + 116|0;
 $1 = sp + 112|0;
 $2 = sp + 108|0;
 $3 = sp + 104|0;
 $4 = sp + 100|0;
 $5 = sp + 96|0;
 $__parent$i$i = sp + 92|0;
 $6 = sp + 88|0;
 $7 = sp + 40|0;
 $8 = sp + 32|0;
 $9 = sp + 28|0;
 $size = sp + 24|0;
 $p = sp;
 $10 = sp + 64|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$size,4);
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$size>>2] = $17;
  HEAP32[$11>>2] = $13;
 }
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;HEAP32[$p+16>>2]=0|0;HEAP32[$p+20>>2]=0|0;
 $18 = (($data) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($data,$19);
 $20 = (($data) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = (($data) + 4|0);
 HEAP32[$data>>2] = $21;
 HEAP32[$21>>2] = 0;
 $22 = HEAP32[$size>>2]|0;
 $23 = ($22|0)>(0);
 L5: do {
  if ($23) {
   $24 = (($p) + 1|0);
   $25 = (($10) + 1|0);
   $26 = (($10) + 12|0);
   $27 = (($p) + 12|0);
   $28 = (($p) + 20|0);
   $29 = (($10) + 20|0);
   $30 = (($7) + 1|0);
   $31 = (($7) + 12|0);
   $32 = (($7) + 20|0);
   $33 = (($10) + 8|0);
   $34 = (($7) + 8|0);
   $35 = (($7) + 4|0);
   $36 = (($10) + 4|0);
   $37 = (($p) + 8|0);
   $38 = (($p) + 4|0);
   $i$037 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_viiii(372,($this|0),($p|0),0,0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 55;
     break;
    }
    $41 = HEAP8[$p>>0]|0;
    $42 = $41 & 1;
    $43 = ($42<<24>>24)==(0);
    if ($43) {
     $46 = $41&255;
     $47 = $46 >>> 1;
     $49 = $47;$62 = $24;
    } else {
     $44 = HEAP32[$37>>2]|0;
     $45 = HEAP32[$38>>2]|0;
     $49 = $45;$62 = $44;
    }
    $48 = ($49>>>0)>(2147483631);
    if ($48) {
     label = 11;
     break;
    }
    $52 = ($49>>>0)<(11);
    if ($52) {
     $53 = $49 << 1;
     $54 = $53&255;
     HEAP8[$10>>0] = $54;
     $76 = $54;$__p$0$i$i$i$i$i$i = $25;
    } else {
     $55 = (($49) + 16)|0;
     $56 = $55 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$8+0>>2]|0;
     $57 = (invoke_iiiiiii(102,($56|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      label = 55;
      break;
     }
     HEAP32[$33>>2] = $57;
     $60 = $56 | 1;
     HEAP32[$10>>2] = $60;
     HEAP32[$36>>2] = $49;
     $61 = $60&255;
     $76 = $61;$__p$0$i$i$i$i$i$i = $57;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($62|0),($49|0))|0;
    $63 = (($__p$0$i$i$i$i$i$i) + ($49)|0);
    HEAP8[$63>>0] = 0;
    $64 = $27;
    $65 = $64;
    $66 = HEAP32[$65>>2]|0;
    $67 = (($64) + 4)|0;
    $68 = $67;
    $69 = HEAP32[$68>>2]|0;
    $70 = $26;
    $71 = $70;
    HEAP32[$71>>2] = $66;
    $72 = (($70) + 4)|0;
    $73 = $72;
    HEAP32[$73>>2] = $69;
    $74 = HEAP32[$28>>2]|0;
    HEAP32[$29>>2] = $74;
    $75 = $76 & 1;
    $77 = ($75<<24>>24)==(0);
    if ($77) {
     $80 = $76&255;
     $81 = $80 >>> 1;
     $83 = $81;$95 = $25;
    } else {
     $78 = HEAP32[$33>>2]|0;
     $79 = HEAP32[$36>>2]|0;
     $83 = $79;$95 = $78;
    }
    $82 = ($83>>>0)>(2147483631);
    if ($82) {
     label = 21;
     break;
    }
    $86 = ($83>>>0)<(11);
    if ($86) {
     $87 = $83 << 1;
     $88 = $87&255;
     HEAP8[$7>>0] = $88;
     $__p$0$i$i$i$i$i$i$i$i$i = $30;
    } else {
     $89 = (($83) + 16)|0;
     $90 = $89 & -16;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$6+0>>2]|0;
     $91 = (invoke_iiiiiii(102,($90|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      label = 58;
      break;
     }
     HEAP32[$34>>2] = $91;
     $94 = $90 | 1;
     HEAP32[$7>>2] = $94;
     HEAP32[$35>>2] = $83;
     $__p$0$i$i$i$i$i$i$i$i$i = $91;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($95|0),($83|0))|0;
    $96 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($83)|0);
    HEAP8[$96>>0] = 0;
    $97 = $31;
    $98 = $97;
    HEAP32[$98>>2] = $66;
    $99 = (($97) + 4)|0;
    $100 = $99;
    HEAP32[$100>>2] = $69;
    HEAP32[$32>>2] = $74;
    $101 = (__ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS5_($data,$__parent$i$i,$7)|0);
    __THREW__ = 0;
    $102 = (invoke_ii(2988,40)|0);
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if ($104) {
     label = 47;
     break;
    }
    $105 = (($102) + 16|0);
    $106 = HEAP8[$7>>0]|0;
    $107 = $106 & 1;
    $108 = ($107<<24>>24)==(0);
    if ($108) {
     $111 = $106&255;
     $112 = $111 >>> 1;
     $114 = $112;$134 = $30;
    } else {
     $109 = HEAP32[$34>>2]|0;
     $110 = HEAP32[$35>>2]|0;
     $114 = $110;$134 = $109;
    }
    $113 = ($114>>>0)>(2147483631);
    if ($113) {
     label = 32;
     break;
    }
    $117 = ($114>>>0)<(11);
    if ($117) {
     $118 = $114 << 1;
     $119 = $118&255;
     HEAP8[$105>>0] = $119;
     $120 = (($102) + 17|0);
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $120;
    } else {
     $121 = (($114) + 16)|0;
     $122 = $121 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$5+0>>2]|0;
     $123 = (invoke_iiiiiii(102,($122|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     if ($125) {
      label = 38;
      break;
     }
     $126 = (($102) + 24|0);
     HEAP32[$126>>2] = $123;
     $127 = $122 | 1;
     HEAP32[$105>>2] = $127;
     $128 = (($102) + 20|0);
     HEAP32[$128>>2] = $114;
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $123;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i$i$i|0),($134|0),($114|0))|0;
    $135 = (($__p$0$i$i$i$i$i$i$i$i$i$i$i) + ($114)|0);
    HEAP8[$135>>0] = 0;
    $136 = (($102) + 28|0);
    $137 = $31;
    $138 = $137;
    $139 = HEAP32[$138>>2]|0;
    $140 = (($137) + 4)|0;
    $141 = $140;
    $142 = HEAP32[$141>>2]|0;
    $143 = $136;
    $144 = $143;
    HEAP32[$144>>2] = $139;
    $145 = (($143) + 4)|0;
    $146 = $145;
    HEAP32[$146>>2] = $142;
    $147 = HEAP32[$32>>2]|0;
    $148 = (($102) + 36|0);
    HEAP32[$148>>2] = $147;
    $149 = HEAP32[$__parent$i$i>>2]|0;
    HEAP32[$102>>2] = 0;
    $150 = (($102) + 4|0);
    HEAP32[$150>>2] = 0;
    $151 = (($102) + 8|0);
    HEAP32[$151>>2] = $149;
    HEAP32[$101>>2] = $102;
    $152 = HEAP32[$data>>2]|0;
    $153 = HEAP32[$152>>2]|0;
    $154 = ($153|0)==(0|0);
    if ($154) {
     $156 = $102;
    } else {
     HEAP32[$data>>2] = $153;
     $$pre$i$i$i = HEAP32[$101>>2]|0;
     $156 = $$pre$i$i$i;
    }
    $155 = HEAP32[$18>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($155,$156);
    $157 = HEAP32[$20>>2]|0;
    $158 = (($157) + 1)|0;
    HEAP32[$20>>2] = $158;
    if (!($108)) {
     $159 = HEAP32[$34>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($159|0),($$byval_copy34|0));
     $160 = __THREW__; __THREW__ = 0;
     $161 = $160&1;
     if ($161) {
      label = 46;
      break;
     }
    }
    $174 = $76 & 1;
    $175 = ($174<<24>>24)==(0);
    if (!($175)) {
     $176 = HEAP32[$33>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($176|0),($$byval_copy34|0));
     $177 = __THREW__; __THREW__ = 0;
     $178 = $177&1;
     if ($178) {
      label = 53;
      break;
     }
    }
    $181 = (($i$037) + 1)|0;
    $182 = HEAP32[$size>>2]|0;
    $183 = ($181|0)<($182|0);
    if ($183) {
     $i$037 = $181;
    } else {
     break L5;
    }
   }
   do {
    if ((label|0) == 11) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      $186 = ___cxa_find_matching_catch()|0;
      $187 = tempRet0;
      $lpad$phi$index = $186;$lpad$phi$index14 = $187;
      label = 57;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 21) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if ($85) {
      $190 = ___cxa_find_matching_catch()|0;
      $191 = tempRet0;
      $eh$lpad$body$index21Z2D = $191;$eh$lpad$body$indexZ2D = $190;
      label = 60;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 32) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     if ($116) {
      $131 = ___cxa_find_matching_catch()|0;
      $132 = tempRet0;
      $lpad$phi16$index = $131;$lpad$phi16$index2 = $132;
      label = 40;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 38) {
     $129 = ___cxa_find_matching_catch()|0;
     $130 = tempRet0;
     $lpad$phi16$index = $129;$lpad$phi16$index2 = $130;
     label = 40;
    }
    else if ((label|0) == 46) {
     $162 = ___cxa_find_matching_catch()|0;
     $163 = tempRet0;
     ___cxa_call_unexpected(($162|0));
     // unreachable;
    }
    else if ((label|0) == 47) {
     $164 = ___cxa_find_matching_catch()|0;
     $165 = tempRet0;
     $$pre$i = HEAP8[$7>>0]|0;
     $167 = $$pre$i;$eh$lpad$body$i$index8Z2D = $165;$eh$lpad$body$i$indexZ2D = $164;
     label = 48;
    }
    else if ((label|0) == 53) {
     $179 = ___cxa_find_matching_catch()|0;
     $180 = tempRet0;
     ___cxa_call_unexpected(($179|0));
     // unreachable;
    }
    else if ((label|0) == 55) {
     $184 = ___cxa_find_matching_catch()|0;
     $185 = tempRet0;
     $lpad$phi$index = $184;$lpad$phi$index14 = $185;
     label = 57;
    }
    else if ((label|0) == 58) {
     $188 = ___cxa_find_matching_catch()|0;
     $189 = tempRet0;
     $eh$lpad$body$index21Z2D = $189;$eh$lpad$body$indexZ2D = $188;
     label = 60;
    }
   } while(0);
   if ((label|0) == 40) {
    $133 = ($102|0)==(0|0);
    if ($133) {
     $167 = $106;$eh$lpad$body$i$index8Z2D = $lpad$phi16$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi16$index;
     label = 48;
    } else {
     __ZdlPv($102);
     $167 = $106;$eh$lpad$body$i$index8Z2D = $lpad$phi16$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi16$index;
     label = 48;
    }
   }
   else if ((label|0) == 57) {
    $$0 = $lpad$phi$index14;$$01 = $lpad$phi$index;
   }
   if ((label|0) == 48) {
    $166 = $167 & 1;
    $168 = ($166<<24>>24)==(0);
    if ($168) {
     $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
     label = 60;
    } else {
     $169 = HEAP32[$34>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($169|0),($$byval_copy34|0));
     $170 = __THREW__; __THREW__ = 0;
     $171 = $170&1;
     if ($171) {
      $172 = ___cxa_find_matching_catch()|0;
      $173 = tempRet0;
      ___cxa_call_unexpected(($172|0));
      // unreachable;
     } else {
      $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
      label = 60;
     }
    }
   }
   if ((label|0) == 60) {
    $192 = $76 & 1;
    $193 = ($192<<24>>24)==(0);
    if ($193) {
     $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
    } else {
     $194 = HEAP32[$33>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($194|0),($$byval_copy34|0));
     $195 = __THREW__; __THREW__ = 0;
     $196 = $195&1;
     if ($196) {
      $197 = ___cxa_find_matching_catch()|0;
      $198 = tempRet0;
      ___cxa_call_unexpected(($197|0));
      // unreachable;
     } else {
      $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
    }
   }
   $208 = HEAP8[$p>>0]|0;
   $209 = $208 & 1;
   $210 = ($209<<24>>24)==(0);
   if ($210) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $211 = HEAP32[$37>>2]|0;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($211|0),($$byval_copy34|0));
   $212 = __THREW__; __THREW__ = 0;
   $213 = $212&1;
   if ($213) {
    $214 = ___cxa_find_matching_catch()|0;
    $215 = tempRet0;
    ___cxa_call_unexpected(($214|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $199 = HEAP8[$p>>0]|0;
 $200 = $199 & 1;
 $201 = ($200<<24>>24)==(0);
 if ($201) {
  STACKTOP = sp;return;
 }
 $202 = (($p) + 8|0);
 $203 = HEAP32[$202>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($203|0),($$byval_copy34|0));
 $204 = __THREW__; __THREW__ = 0;
 $205 = $204&1;
 if ($205) {
  $206 = ___cxa_find_matching_catch()|0;
  $207 = tempRet0;
  ___cxa_call_unexpected(($206|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE8TransferINSt3__14pairI8UnityStrN11AssetBundle9AssetInfoEEEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i$i$i = 0, $$pre2$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$data,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
 $2 = (($data) + 12|0);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i$i = HEAP32[$3>>2]|0;
  $$pre2$i$i$i$i = HEAP32[$6>>2]|0;
  $12 = $$pre$i$i$i$i;$14 = $$pre2$i$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($data) + 16|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,4);
  $16 = (($data) + 20|0);
  __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($16,$this);
  STACKTOP = sp;return;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$3>>2] = $11;
  $16 = (($data) + 20|0);
  __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($16,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI4PPtrI6ObjectELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<2)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 4|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 2;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 2;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11AssetBundle8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01 = 0, $$01$i$i$i$i = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy48 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i$i$i = 0, $__parent$i$i = 0, $converter$i$i4 = 0, $eh$lpad$body$i$index8Z2D = 0;
 var $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index31Z2D = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$index = 0, $lpad$phi$index14 = 0, $lpad$phi35$index = 0, $lpad$phi35$index19 = 0, $lpad$phi40$index = 0, $lpad$phi40$index24 = 0, $lpad$phi50$index = 0, $lpad$phi50$index2 = 0, $mainAsset = 0, $oldContainer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy48 = sp + 168|0;
 $0 = sp + 164|0;
 $1 = sp + 160|0;
 $2 = sp + 156|0;
 $3 = sp + 152|0;
 $4 = sp + 148|0;
 $5 = sp + 144|0;
 $6 = sp + 140|0;
 $7 = sp + 136|0;
 $8 = sp + 132|0;
 $__parent$i$i = sp + 128|0;
 $9 = sp + 124|0;
 $10 = sp + 16|0;
 $11 = sp;
 $12 = sp + 4|0;
 $13 = sp + 8|0;
 $converter$i$i4 = sp + 40|0;
 $oldContainer = sp + 44|0;
 $mainAsset = sp + 56|0;
 $14 = sp + 64|0;
 $15 = sp + 88|0;
 $16 = sp + 112|0;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,3);
 $17 = (($this) + 28|0);
 HEAP32[$17>>2] = 0;
 $18 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,1)|0);
 if (!($18)) {
  $331 = (($this) + 44|0);
  $332 = HEAP32[580760>>2]|0;
  $333 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,616928,$332,$$byval_copy48,1)|0);
  $334 = ($333|0)==(0);
  if (!($334)) {
   $335 = ($333|0)>(0);
   if ($335) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$331,0);
   } else {
    $336 = HEAP32[$$byval_copy48>>2]|0;
    $337 = ($336|0)==(0|0);
    if (!($337)) {
     (FUNCTION_TABLE_iii[$336 & 4095]($331,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
  $338 = (($this) + 60|0);
  $339 = HEAP32[580600>>2]|0;
  $340 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,616896,$339,$$byval_copy48,1)|0);
  $341 = ($340|0)==(0);
  if (!($341)) {
   $342 = ($340|0)>(0);
   if ($342) {
    __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__18multimapI8UnityStrN11AssetBundle9AssetInfoENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S5_EEEEEEEEvRT_17TransferMetaFlags($transfer,$338,0);
   } else {
    $343 = HEAP32[$$byval_copy48>>2]|0;
    $344 = ($343|0)==(0|0);
    if (!($344)) {
     (FUNCTION_TABLE_iii[$343 & 4095]($338,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
  $345 = (($this) + 32|0);
  $346 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,616912,617096,$$byval_copy48,1)|0);
  $347 = ($346|0)==(0);
  if (!($347)) {
   $348 = ($346|0)>(0);
   if ($348) {
    __ZN11AssetBundle9AssetInfo8TransferI14SafeBinaryReadEEvRT_($345,$transfer);
   } else {
    $349 = HEAP32[$$byval_copy48>>2]|0;
    $350 = ($349|0)==(0|0);
    if (!($350)) {
     (FUNCTION_TABLE_iii[$349 & 4095]($345,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
  $351 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,2)|0);
  if (!($351)) {
   __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$17,616944,0);
  }
  $352 = (($this) + 84|0);
  __ZN14SafeBinaryRead8TransferI14ConstantStringEEvRT_PKc17TransferMetaFlags($transfer,$352,616968,0);
  $353 = (($this) + 88|0);
  $354 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,616992,$332,$$byval_copy48,1)|0);
  $355 = ($354|0)==(0);
  if ($355) {
   STACKTOP = sp;return;
  }
  $356 = ($354|0)>(0);
  if ($356) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$353,0);
  } else {
   $357 = HEAP32[$$byval_copy48>>2]|0;
   $358 = ($357|0)==(0|0);
   if (!($358)) {
    (FUNCTION_TABLE_iii[$357 & 4095]($353,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
  STACKTOP = sp;return;
 }
 $19 = (($oldContainer) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($oldContainer) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = (($oldContainer) + 4|0);
 HEAP32[$oldContainer>>2] = $21;
 $22 = HEAP32[580600>>2]|0;
 __THREW__ = 0;
 $23 = (invoke_iiiiii(192,($transfer|0),(616896|0),($22|0),($converter$i$i4|0),1)|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 L40: do {
  if ($25) {
   label = 97;
  } else {
   $26 = ($23|0)==(0);
   if (!($26)) {
    $27 = ($23|0)>(0);
    if ($27) {
     __THREW__ = 0;
     invoke_viii(1771,($transfer|0),($oldContainer|0),0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 97;
      break;
     }
    } else {
     $30 = HEAP32[$converter$i$i4>>2]|0;
     $31 = ($30|0)==(0|0);
     if (!($31)) {
      __THREW__ = 0;
      (invoke_iii($30|0,($oldContainer|0),($transfer|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 97;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($transfer|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 97;
     break;
    }
   }
   HEAP32[$mainAsset>>2] = 0;
   $36 = HEAP32[580624>>2]|0;
   __THREW__ = 0;
   $37 = (invoke_iiiiii(192,($transfer|0),(616912|0),($36|0),($$byval_copy48|0),1)|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    label = 97;
   } else {
    $40 = ($37|0)==(0);
    if (!($40)) {
     $41 = ($37|0)>(0);
     if ($41) {
      __THREW__ = 0;
      invoke_vii(2757,($mainAsset|0),($transfer|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       label = 97;
       break;
      }
     } else {
      $44 = HEAP32[$$byval_copy48>>2]|0;
      $45 = ($44|0)==(0|0);
      if (!($45)) {
       __THREW__ = 0;
       (invoke_iii($44|0,($mainAsset|0),($transfer|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        label = 97;
        break;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3389,($transfer|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      label = 97;
      break;
     }
    }
    $50 = (($this) + 60|0);
    $51 = (($this) + 64|0);
    $52 = HEAP32[$51>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($50,$52);
    $53 = (($this) + 68|0);
    HEAP32[$53>>2] = 0;
    $54 = (($this) + 64|0);
    HEAP32[$50>>2] = $54;
    HEAP32[$54>>2] = 0;
    $55 = HEAP32[$oldContainer>>2]|0;
    $56 = ($55|0)==($21|0);
    L59: do {
     if (!($56)) {
      $57 = (($16) + 1|0);
      $58 = (($15) + 1|0);
      $59 = (($15) + 12|0);
      $60 = (($15) + 20|0);
      $61 = (($14) + 1|0);
      $62 = (($14) + 12|0);
      $63 = (($14) + 20|0);
      $64 = (($10) + 1|0);
      $65 = (($10) + 12|0);
      $66 = (($10) + 20|0);
      $67 = (($16) + 8|0);
      $68 = (($15) + 8|0);
      $69 = (($14) + 8|0);
      $70 = (($10) + 8|0);
      $71 = (($10) + 4|0);
      $72 = (($14) + 4|0);
      $73 = (($15) + 4|0);
      $74 = (($16) + 4|0);
      $76 = $55;
      while(1) {
       $75 = (($76) + 28|0);
       $77 = HEAP32[$75>>2]|0;
       $78 = (($76) + 16|0);
       $79 = HEAP8[$78>>0]|0;
       $80 = $79 & 1;
       $81 = ($80<<24>>24)==(0);
       if ($81) {
        $86 = (($78) + 1|0);
        $87 = $79&255;
        $88 = $87 >>> 1;
        $103 = $86;$90 = $88;
       } else {
        $82 = (($76) + 24|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = (($76) + 20|0);
        $85 = HEAP32[$84>>2]|0;
        $103 = $83;$90 = $85;
       }
       $89 = ($90>>>0)>(2147483631);
       if ($89) {
        label = 22;
        break;
       }
       $93 = ($90>>>0)<(11);
       if ($93) {
        $94 = $90 << 1;
        $95 = $94&255;
        HEAP8[$16>>0] = $95;
        $106 = $95;$__p$0$i$i$i$i = $57;
       } else {
        $96 = (($90) + 16)|0;
        $97 = $96 & -16;
        HEAP32[$13>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$13+0>>2]|0;
        $98 = (invoke_iiiiiii(102,($97|0),16,($$byval_copy48|0),0,(616888|0),79)|0);
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 96;
         break;
        }
        HEAP32[$67>>2] = $98;
        $101 = $97 | 1;
        HEAP32[$16>>2] = $101;
        HEAP32[$74>>2] = $90;
        $102 = $101&255;
        $106 = $102;$__p$0$i$i$i$i = $98;
       }
       _memcpy(($__p$0$i$i$i$i|0),($103|0),($90|0))|0;
       $104 = (($__p$0$i$i$i$i) + ($90)|0);
       HEAP8[$104>>0] = 0;
       $105 = $106 & 1;
       $107 = ($105<<24>>24)==(0);
       if ($107) {
        $110 = $106&255;
        $111 = $110 >>> 1;
        $113 = $111;$126 = $57;
       } else {
        $108 = HEAP32[$67>>2]|0;
        $109 = HEAP32[$74>>2]|0;
        $113 = $109;$126 = $108;
       }
       $112 = ($113>>>0)>(2147483631);
       if ($112) {
        label = 32;
        break;
       }
       $116 = ($113>>>0)<(11);
       if ($116) {
        $117 = $113 << 1;
        $118 = $117&255;
        HEAP8[$15>>0] = $118;
        $133 = $118;$__p$0$i$i$i$i$i$i$i = $58;
       } else {
        $119 = (($113) + 16)|0;
        $120 = $119 & -16;
        HEAP32[$12>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$12+0>>2]|0;
        $121 = (invoke_iiiiiii(102,($120|0),16,($$byval_copy48|0),0,(616888|0),79)|0);
        $122 = __THREW__; __THREW__ = 0;
        $123 = $122&1;
        if ($123) {
         label = 99;
         break;
        }
        HEAP32[$68>>2] = $121;
        $124 = $120 | 1;
        HEAP32[$15>>2] = $124;
        HEAP32[$73>>2] = $113;
        $125 = $124&255;
        $133 = $125;$__p$0$i$i$i$i$i$i$i = $121;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i|0),($126|0),($113|0))|0;
       $127 = (($__p$0$i$i$i$i$i$i$i) + ($113)|0);
       HEAP8[$127>>0] = 0;
       $128 = $59;
       $129 = $128;
       HEAP32[$129>>2] = 0;
       $130 = (($128) + 4)|0;
       $131 = $130;
       HEAP32[$131>>2] = 0;
       HEAP32[$60>>2] = $77;
       $132 = $133 & 1;
       $134 = ($132<<24>>24)==(0);
       if ($134) {
        $137 = $133&255;
        $138 = $137 >>> 1;
        $140 = $138;$153 = $58;
       } else {
        $135 = HEAP32[$68>>2]|0;
        $136 = HEAP32[$73>>2]|0;
        $140 = $136;$153 = $135;
       }
       $139 = ($140>>>0)>(2147483631);
       if ($139) {
        label = 42;
        break;
       }
       $143 = ($140>>>0)<(11);
       if ($143) {
        $144 = $140 << 1;
        $145 = $144&255;
        HEAP8[$14>>0] = $145;
        $160 = $145;$__p$0$i$i$i$i$i$i = $61;
       } else {
        $146 = (($140) + 16)|0;
        $147 = $146 & -16;
        HEAP32[$11>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$11+0>>2]|0;
        $148 = (invoke_iiiiiii(102,($147|0),16,($$byval_copy48|0),0,(616888|0),79)|0);
        $149 = __THREW__; __THREW__ = 0;
        $150 = $149&1;
        if ($150) {
         label = 102;
         break;
        }
        HEAP32[$69>>2] = $148;
        $151 = $147 | 1;
        HEAP32[$14>>2] = $151;
        HEAP32[$72>>2] = $140;
        $152 = $151&255;
        $160 = $152;$__p$0$i$i$i$i$i$i = $148;
       }
       _memcpy(($__p$0$i$i$i$i$i$i|0),($153|0),($140|0))|0;
       $154 = (($__p$0$i$i$i$i$i$i) + ($140)|0);
       HEAP8[$154>>0] = 0;
       $155 = $62;
       $156 = $155;
       HEAP32[$156>>2] = 0;
       $157 = (($155) + 4)|0;
       $158 = $157;
       HEAP32[$158>>2] = 0;
       HEAP32[$63>>2] = $77;
       $159 = $160 & 1;
       $161 = ($159<<24>>24)==(0);
       if ($161) {
        $164 = $160&255;
        $165 = $164 >>> 1;
        $167 = $165;$179 = $61;
       } else {
        $162 = HEAP32[$69>>2]|0;
        $163 = HEAP32[$72>>2]|0;
        $167 = $163;$179 = $162;
       }
       $166 = ($167>>>0)>(2147483631);
       if ($166) {
        label = 52;
        break;
       }
       $170 = ($167>>>0)<(11);
       if ($170) {
        $171 = $167 << 1;
        $172 = $171&255;
        HEAP8[$10>>0] = $172;
        $__p$0$i$i$i$i$i$i$i$i$i = $64;
       } else {
        $173 = (($167) + 16)|0;
        $174 = $173 & -16;
        HEAP32[$9>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$9+0>>2]|0;
        $175 = (invoke_iiiiiii(102,($174|0),16,($$byval_copy48|0),0,(616888|0),79)|0);
        $176 = __THREW__; __THREW__ = 0;
        $177 = $176&1;
        if ($177) {
         label = 105;
         break;
        }
        HEAP32[$70>>2] = $175;
        $178 = $174 | 1;
        HEAP32[$10>>2] = $178;
        HEAP32[$71>>2] = $167;
        $__p$0$i$i$i$i$i$i$i$i$i = $175;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($179|0),($167|0))|0;
       $180 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($167)|0);
       HEAP8[$180>>0] = 0;
       $181 = $65;
       $182 = $181;
       HEAP32[$182>>2] = 0;
       $183 = (($181) + 4)|0;
       $184 = $183;
       HEAP32[$184>>2] = 0;
       HEAP32[$66>>2] = $77;
       $185 = (__ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS5_($50,$__parent$i$i,$10)|0);
       __THREW__ = 0;
       $186 = (invoke_ii(2988,40)|0);
       $187 = __THREW__; __THREW__ = 0;
       $188 = $187&1;
       if ($188) {
        label = 78;
        break;
       }
       $189 = (($186) + 16|0);
       $190 = HEAP8[$10>>0]|0;
       $191 = $190 & 1;
       $192 = ($191<<24>>24)==(0);
       if ($192) {
        $195 = $190&255;
        $196 = $195 >>> 1;
        $198 = $196;$218 = $64;
       } else {
        $193 = HEAP32[$70>>2]|0;
        $194 = HEAP32[$71>>2]|0;
        $198 = $194;$218 = $193;
       }
       $197 = ($198>>>0)>(2147483631);
       if ($197) {
        label = 63;
        break;
       }
       $201 = ($198>>>0)<(11);
       if ($201) {
        $202 = $198 << 1;
        $203 = $202&255;
        HEAP8[$189>>0] = $203;
        $204 = (($186) + 17|0);
        $__p$0$i$i$i$i$i$i$i$i$i$i$i = $204;
       } else {
        $205 = (($198) + 16)|0;
        $206 = $205 & -16;
        HEAP32[$8>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$8+0>>2]|0;
        $207 = (invoke_iiiiiii(102,($206|0),16,($$byval_copy48|0),0,(616888|0),79)|0);
        $208 = __THREW__; __THREW__ = 0;
        $209 = $208&1;
        if ($209) {
         label = 69;
         break;
        }
        $210 = (($186) + 24|0);
        HEAP32[$210>>2] = $207;
        $211 = $206 | 1;
        HEAP32[$189>>2] = $211;
        $212 = (($186) + 20|0);
        HEAP32[$212>>2] = $198;
        $__p$0$i$i$i$i$i$i$i$i$i$i$i = $207;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i$i$i$i$i|0),($218|0),($198|0))|0;
       $219 = (($__p$0$i$i$i$i$i$i$i$i$i$i$i) + ($198)|0);
       HEAP8[$219>>0] = 0;
       $220 = (($186) + 28|0);
       $221 = $65;
       $222 = $221;
       $223 = HEAP32[$222>>2]|0;
       $224 = (($221) + 4)|0;
       $225 = $224;
       $226 = HEAP32[$225>>2]|0;
       $227 = $220;
       $228 = $227;
       HEAP32[$228>>2] = $223;
       $229 = (($227) + 4)|0;
       $230 = $229;
       HEAP32[$230>>2] = $226;
       $231 = HEAP32[$66>>2]|0;
       $232 = (($186) + 36|0);
       HEAP32[$232>>2] = $231;
       $233 = HEAP32[$__parent$i$i>>2]|0;
       HEAP32[$186>>2] = 0;
       $234 = (($186) + 4|0);
       HEAP32[$234>>2] = 0;
       $235 = (($186) + 8|0);
       HEAP32[$235>>2] = $233;
       HEAP32[$185>>2] = $186;
       $236 = HEAP32[$50>>2]|0;
       $237 = HEAP32[$236>>2]|0;
       $238 = ($237|0)==(0|0);
       if ($238) {
        $240 = $186;
       } else {
        HEAP32[$50>>2] = $237;
        $$pre$i$i$i = HEAP32[$185>>2]|0;
        $240 = $$pre$i$i$i;
       }
       $239 = HEAP32[$51>>2]|0;
       __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($239,$240);
       $241 = HEAP32[$53>>2]|0;
       $242 = (($241) + 1)|0;
       HEAP32[$53>>2] = $242;
       if (!($192)) {
        $243 = HEAP32[$70>>2]|0;
        HEAP32[$7>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$7+0>>2]|0;
        invoke_vii(2591,($243|0),($$byval_copy48|0));
        $244 = __THREW__; __THREW__ = 0;
        $245 = $244&1;
        if ($245) {
         label = 77;
         break;
        }
       }
       $258 = $160 & 1;
       $259 = ($258<<24>>24)==(0);
       if (!($259)) {
        $260 = HEAP32[$69>>2]|0;
        HEAP32[$5>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$5+0>>2]|0;
        invoke_vii(2591,($260|0),($$byval_copy48|0));
        $261 = __THREW__; __THREW__ = 0;
        $262 = $261&1;
        if ($262) {
         label = 84;
         break;
        }
       }
       $265 = $133 & 1;
       $266 = ($265<<24>>24)==(0);
       if (!($266)) {
        $267 = HEAP32[$68>>2]|0;
        HEAP32[$4>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$4+0>>2]|0;
        invoke_vii(2591,($267|0),($$byval_copy48|0));
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         label = 87;
         break;
        }
       }
       $272 = $106 & 1;
       $273 = ($272<<24>>24)==(0);
       if (!($273)) {
        $274 = HEAP32[$67>>2]|0;
        HEAP32[$3>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($274|0),($$byval_copy48|0));
        $275 = __THREW__; __THREW__ = 0;
        $276 = $275&1;
        if ($276) {
         label = 90;
         break;
        }
       }
       $279 = (($76) + 4|0);
       $280 = HEAP32[$279>>2]|0;
       $281 = ($280|0)==(0|0);
       if ($281) {
        $$01$i$i$i$i = $76;
        while(1) {
         $284 = (($$01$i$i$i$i) + 8|0);
         $285 = HEAP32[$284>>2]|0;
         $286 = HEAP32[$285>>2]|0;
         $287 = ($286|0)==($$01$i$i$i$i|0);
         if ($287) {
          $$0$i$i$i$i = $285;
          break;
         } else {
          $$01$i$i$i$i = $285;
         }
        }
       } else {
        $$0$i$i$i$i$i = $280;
        while(1) {
         $282 = HEAP32[$$0$i$i$i$i$i>>2]|0;
         $283 = ($282|0)==(0|0);
         if ($283) {
          $$0$i$i$i$i = $$0$i$i$i$i$i;
          break;
         } else {
          $$0$i$i$i$i$i = $282;
         }
        }
       }
       $288 = ($$0$i$i$i$i|0)==($21|0);
       if ($288) {
        break L59;
       } else {
        $76 = $$0$i$i$i$i;
       }
      }
      switch (label|0) {
       case 22: {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         label = 97;
         break L40;
        }
        // unreachable;
        break;
       }
       case 32: {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if ($115) {
         $295 = ___cxa_find_matching_catch()|0;
         $296 = tempRet0;
         $lpad$phi35$index = $295;$lpad$phi35$index19 = $296;
         label = 101;
         break;
        } else {
         // unreachable;
        }
        break;
       }
       case 42: {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $141 = __THREW__; __THREW__ = 0;
        $142 = $141&1;
        if ($142) {
         $299 = ___cxa_find_matching_catch()|0;
         $300 = tempRet0;
         $lpad$phi40$index = $299;$lpad$phi40$index24 = $300;
         label = 104;
         break;
        } else {
         // unreachable;
        }
        break;
       }
       case 52: {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         $303 = ___cxa_find_matching_catch()|0;
         $304 = tempRet0;
         $eh$lpad$body$index31Z2D = $304;$eh$lpad$body$indexZ2D = $303;
         label = 107;
         break;
        } else {
         // unreachable;
        }
        break;
       }
       case 63: {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $199 = __THREW__; __THREW__ = 0;
        $200 = $199&1;
        if ($200) {
         $215 = ___cxa_find_matching_catch()|0;
         $216 = tempRet0;
         $lpad$phi50$index = $215;$lpad$phi50$index2 = $216;
         label = 71;
         break;
        } else {
         // unreachable;
        }
        break;
       }
       case 69: {
        $213 = ___cxa_find_matching_catch()|0;
        $214 = tempRet0;
        $lpad$phi50$index = $213;$lpad$phi50$index2 = $214;
        label = 71;
        break;
       }
       case 77: {
        $246 = ___cxa_find_matching_catch()|0;
        $247 = tempRet0;
        ___cxa_call_unexpected(($246|0));
        // unreachable;
        break;
       }
       case 78: {
        $248 = ___cxa_find_matching_catch()|0;
        $249 = tempRet0;
        $$pre$i = HEAP8[$10>>0]|0;
        $251 = $$pre$i;$eh$lpad$body$i$index8Z2D = $249;$eh$lpad$body$i$indexZ2D = $248;
        label = 79;
        break;
       }
       case 84: {
        $263 = ___cxa_find_matching_catch()|0;
        $264 = tempRet0;
        ___cxa_call_unexpected(($263|0));
        // unreachable;
        break;
       }
       case 87: {
        $270 = ___cxa_find_matching_catch()|0;
        $271 = tempRet0;
        ___cxa_call_unexpected(($270|0));
        // unreachable;
        break;
       }
       case 90: {
        $277 = ___cxa_find_matching_catch()|0;
        $278 = tempRet0;
        ___cxa_call_unexpected(($277|0));
        // unreachable;
        break;
       }
       case 96: {
        $289 = ___cxa_find_matching_catch()|0;
        $290 = tempRet0;
        $lpad$phi$index = $289;$lpad$phi$index14 = $290;
        break L40;
        break;
       }
       case 99: {
        $293 = ___cxa_find_matching_catch()|0;
        $294 = tempRet0;
        $lpad$phi35$index = $293;$lpad$phi35$index19 = $294;
        label = 101;
        break;
       }
       case 102: {
        $297 = ___cxa_find_matching_catch()|0;
        $298 = tempRet0;
        $lpad$phi40$index = $297;$lpad$phi40$index24 = $298;
        label = 104;
        break;
       }
       case 105: {
        $301 = ___cxa_find_matching_catch()|0;
        $302 = tempRet0;
        $eh$lpad$body$index31Z2D = $302;$eh$lpad$body$indexZ2D = $301;
        label = 107;
        break;
       }
      }
      if ((label|0) == 71) {
       $217 = ($186|0)==(0|0);
       if ($217) {
        $251 = $190;$eh$lpad$body$i$index8Z2D = $lpad$phi50$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi50$index;
        label = 79;
       } else {
        __ZdlPv($186);
        $251 = $190;$eh$lpad$body$i$index8Z2D = $lpad$phi50$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi50$index;
        label = 79;
       }
      }
      else if ((label|0) == 101) {
       $$1 = $lpad$phi35$index19;$$12 = $lpad$phi35$index;
      }
      else if ((label|0) == 104) {
       $$0 = $lpad$phi40$index24;$$01 = $lpad$phi40$index;
       label = 110;
      }
      if ((label|0) == 79) {
       $250 = $251 & 1;
       $252 = ($250<<24>>24)==(0);
       if ($252) {
        $eh$lpad$body$index31Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
        label = 107;
       } else {
        $253 = HEAP32[$70>>2]|0;
        HEAP32[$6>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$6+0>>2]|0;
        invoke_vii(2591,($253|0),($$byval_copy48|0));
        $254 = __THREW__; __THREW__ = 0;
        $255 = $254&1;
        if ($255) {
         $256 = ___cxa_find_matching_catch()|0;
         $257 = tempRet0;
         ___cxa_call_unexpected(($256|0));
         // unreachable;
        } else {
         $eh$lpad$body$index31Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
         label = 107;
        }
       }
      }
      if ((label|0) == 107) {
       $305 = $160 & 1;
       $306 = ($305<<24>>24)==(0);
       if ($306) {
        $$0 = $eh$lpad$body$index31Z2D;$$01 = $eh$lpad$body$indexZ2D;
        label = 110;
       } else {
        $307 = HEAP32[$69>>2]|0;
        HEAP32[$2>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($307|0),($$byval_copy48|0));
        $308 = __THREW__; __THREW__ = 0;
        $309 = $308&1;
        if ($309) {
         $310 = ___cxa_find_matching_catch()|0;
         $311 = tempRet0;
         ___cxa_call_unexpected(($310|0));
         // unreachable;
        } else {
         $$0 = $eh$lpad$body$index31Z2D;$$01 = $eh$lpad$body$indexZ2D;
         label = 110;
        }
       }
      }
      if ((label|0) == 110) {
       $312 = $133 & 1;
       $313 = ($312<<24>>24)==(0);
       if ($313) {
        $$1 = $$0;$$12 = $$01;
       } else {
        $314 = HEAP32[$68>>2]|0;
        HEAP32[$1>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($314|0),($$byval_copy48|0));
        $315 = __THREW__; __THREW__ = 0;
        $316 = $315&1;
        if ($316) {
         $317 = ___cxa_find_matching_catch()|0;
         $318 = tempRet0;
         ___cxa_call_unexpected(($317|0));
         // unreachable;
        } else {
         $$1 = $$0;$$12 = $$01;
        }
       }
      }
      $319 = $106 & 1;
      $320 = ($319<<24>>24)==(0);
      if ($320) {
       $$2 = $$1;$$23 = $$12;
       $359 = HEAP32[$19>>2]|0;
       __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($oldContainer,$359);
       ___resumeException($$23|0);
       // unreachable;
      }
      $321 = HEAP32[$67>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($321|0),($$byval_copy48|0));
      $322 = __THREW__; __THREW__ = 0;
      $323 = $322&1;
      if ($323) {
       $324 = ___cxa_find_matching_catch()|0;
       $325 = tempRet0;
       ___cxa_call_unexpected(($324|0));
       // unreachable;
      } else {
       $$2 = $$1;$$23 = $$12;
       $359 = HEAP32[$19>>2]|0;
       __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($oldContainer,$359);
       ___resumeException($$23|0);
       // unreachable;
      }
     }
    } while(0);
    $326 = (($this) + 32|0);
    HEAP32[$326>>2] = 0;
    $327 = (($this) + 36|0);
    HEAP32[$327>>2] = 0;
    $328 = HEAP32[$mainAsset>>2]|0;
    $329 = (($this) + 40|0);
    HEAP32[$329>>2] = $328;
    $330 = HEAP32[$19>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($oldContainer,$330);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 97) {
  $291 = ___cxa_find_matching_catch()|0;
  $292 = tempRet0;
  $lpad$phi$index = $291;$lpad$phi$index14 = $292;
 }
 $$2 = $lpad$phi$index14;$$23 = $lpad$phi$index;
 $359 = HEAP32[$19>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($oldContainer,$359);
 ___resumeException($$23|0);
 // unreachable;
}
function __ZN14SafeBinaryRead8TransferI14ConstantStringEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$byval_copy2 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $converter$i = 0, $tempStr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 24|0;
 $1 = sp;
 $tempStr$i = sp + 4|0;
 $2 = sp + 16|0;
 $converter$i = sp + 20|0;
 $3 = HEAP32[580712>>2]|0;
 $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$3,$converter$i,1)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ($4|0)>(0);
 do {
  if ($6) {
   ;HEAP32[$tempStr$i+0>>2]=0|0;HEAP32[$tempStr$i+4>>2]=0|0;HEAP32[$tempStr$i+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viii(1620,($this|0),($tempStr$i|0),0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $20 = HEAP8[$tempStr$i>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $25 = (($tempStr$i) + 1|0);
     $27 = $25;
    } else {
     $23 = (($tempStr$i) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $27 = $24;
    }
    $26 = HEAP32[628448>>2]|0;
    HEAP32[$2>>2] = $26;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viii(1621,($data|0),($27|0),($$byval_copy2|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = HEAP8[$tempStr$i>>0]|0;
     $31 = $30 & 1;
     $32 = ($31<<24>>24)==(0);
     if ($32) {
      break;
     }
     $33 = (($tempStr$i) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     HEAP32[$1>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($34|0),($$byval_copy2|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      break;
     }
     $37 = ___cxa_find_matching_catch()|0;
     $38 = tempRet0;
     ___cxa_call_unexpected(($37|0));
     // unreachable;
    }
   }
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   $11 = HEAP8[$tempStr$i>>0]|0;
   $12 = $11 & 1;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    ___resumeException($9|0);
    // unreachable;
   }
   $14 = (($tempStr$i) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($15|0),($$byval_copy2|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   } else {
    ___resumeException($9|0);
    // unreachable;
   }
  } else {
   $39 = HEAP32[$converter$i>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    (FUNCTION_TABLE_iii[$39 & 4095]($data,$this)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ = 0, $$byval_copy2 = 0, $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $size = 0, $tempStr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy2 = sp + 36|0;
 $1 = sp + 32|0;
 $2 = sp + 8|0;
 $tempStr$i = sp + 12|0;
 $3 = sp + 24|0;
 $size = sp + 28|0;
 $4 = sp;
 $5 = (($data) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$data>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 HEAP32[$size>>2] = $11;
 $12 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,617088,617088,$size)|0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEEEvRT_j($data,$13);
 $14 = HEAP32[$5>>2]|0;
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)==(0);
 L4: do {
  if (!($16)) {
   $17 = HEAP32[580712>>2]|0;
   $18 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,617008,$17,0,1)|0);
   $19 = (($this) + 80|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (__ZNK16TypeTreeIterator7GetNodeEv($20)|0);
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($this) + 84|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$25>>2] = 0;
   $26 = ($18|0)==(2);
   if (!($26)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $84 = HEAP32[$data>>2]|0;
    $85 = ($84|0)==($14|0);
    if ($85) {
     break;
    } else {
     $86 = $84;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI14ConstantStringEEvRT_PKc17TransferMetaFlags($this,$86,617008,0);
     $87 = (($86) + 4|0);
     $88 = ($87|0)==($14|0);
     if ($88) {
      break L4;
     } else {
      $86 = $87;
     }
    }
   }
   $27 = HEAP32[$19>>2]|0;
   $28 = (($27) + 12|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$data>>2]|0;
   $31 = ($30|0)==($14|0);
   L11: do {
    if (!($31)) {
     $32 = (($tempStr$i) + 1|0);
     $33 = (($tempStr$i) + 8|0);
     $35 = 0;$38 = $27;$71 = $30;
     while(1) {
      $34 = Math_imul($35, $23)|0;
      $36 = (($34) + ($29))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($4,$38);
      $41 = $4;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$24>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      ;HEAP32[$tempStr$i+0>>2]=0|0;HEAP32[$tempStr$i+4>>2]=0|0;HEAP32[$tempStr$i+8>>2]=0|0;
      __THREW__ = 0;
      invoke_viii(1620,($this|0),($tempStr$i|0),0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      $66 = HEAP8[$tempStr$i>>0]|0;
      $67 = $66 & 1;
      $68 = ($67<<24>>24)==(0);
      $69 = HEAP32[$33>>2]|0;
      $$ = $68 ? $32 : $69;
      $70 = HEAP32[628448>>2]|0;
      HEAP32[$3>>2] = $70;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_viii(1621,($71|0),($$|0),($$byval_copy2|0));
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       break;
      }
      $74 = HEAP8[$tempStr$i>>0]|0;
      $75 = $74 & 1;
      $76 = ($75<<24>>24)==(0);
      if (!($76)) {
       $77 = HEAP32[$33>>2]|0;
       HEAP32[$2>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
       invoke_vii(2591,($77|0),($$byval_copy2|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 13;
        break;
       }
      }
      $82 = (($71) + 4|0);
      $83 = ($82|0)==($14|0);
      if ($83) {
       break L11;
      }
      $$pre = HEAP32[$24>>2]|0;
      $$pre9 = HEAP32[$$pre>>2]|0;
      $$pre10 = HEAP32[$19>>2]|0;
      $35 = $$pre9;$38 = $$pre10;$71 = $82;
     }
     if ((label|0) == 13) {
      $80 = ___cxa_find_matching_catch()|0;
      $81 = tempRet0;
      ___cxa_call_unexpected(($80|0));
      // unreachable;
     }
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     $58 = HEAP8[$tempStr$i>>0]|0;
     $59 = $58 & 1;
     $60 = ($59<<24>>24)==(0);
     if ($60) {
      ___resumeException($56|0);
      // unreachable;
     }
     $61 = HEAP32[$33>>2]|0;
     HEAP32[$1>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($61|0),($$byval_copy2|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      $64 = ___cxa_find_matching_catch()|0;
      $65 = tempRet0;
      ___cxa_call_unexpected(($64|0));
      // unreachable;
     } else {
      ___resumeException($56|0);
      // unreachable;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle9AssetInfo8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,617016,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$0,617032,0);
 $1 = (($this) + 8|0);
 $2 = HEAP32[580624>>2]|0;
 $3 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617048,$2,$converter$i$i,1)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = ($3|0)>(0);
 if ($5) {
  __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($1,$transfer);
 } else {
  $6 = HEAP32[$converter$i$i>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   (FUNCTION_TABLE_iii[$6 & 4095]($1,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__18multimapI8UnityStrN11AssetBundle9AssetInfoENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S5_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy34 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i$i$i = 0, $__parent$i$i = 0, $converter$i$i = 0, $eh$lpad$body$i$index8Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$041 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index14 = 0, $lpad$phi20$index = 0, $lpad$phi20$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy34 = sp + 116|0;
 $1 = sp + 112|0;
 $2 = sp + 108|0;
 $3 = sp + 104|0;
 $4 = sp + 100|0;
 $5 = sp + 96|0;
 $__parent$i$i = sp + 92|0;
 $6 = sp + 88|0;
 $7 = sp + 40|0;
 $8 = sp + 36|0;
 $converter$i$i = sp + 32|0;
 $9 = sp + 28|0;
 $size = sp + 24|0;
 $p = sp;
 $10 = sp + 64|0;
 $11 = (($data) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$size>>2] = $12;
 $13 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,617088,617088,$size)|0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;HEAP32[$p+16>>2]=0|0;HEAP32[$p+20>>2]=0|0;
 $14 = (($data) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($data,$15);
 HEAP32[$11>>2] = 0;
 $16 = (($data) + 4|0);
 HEAP32[$data>>2] = $16;
 HEAP32[$16>>2] = 0;
 $17 = HEAP32[$size>>2]|0;
 $18 = ($17|0)>(0);
 L4: do {
  if ($18) {
   $19 = HEAP32[580608>>2]|0;
   $20 = (($p) + 1|0);
   $21 = (($10) + 1|0);
   $22 = (($10) + 12|0);
   $23 = (($p) + 12|0);
   $24 = (($p) + 20|0);
   $25 = (($10) + 20|0);
   $26 = (($7) + 1|0);
   $27 = (($7) + 12|0);
   $28 = (($7) + 20|0);
   $29 = (($10) + 8|0);
   $30 = (($7) + 8|0);
   $31 = (($7) + 4|0);
   $32 = (($10) + 4|0);
   $33 = (($p) + 8|0);
   $34 = (($p) + 4|0);
   $i$041 = 0;
   while(1) {
    __THREW__ = 0;
    $35 = (invoke_iiiiii(192,($this|0),(617008|0),($19|0),($converter$i$i|0),1)|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 59;
     break;
    }
    $38 = ($35|0)==(0);
    if (!($38)) {
     $39 = ($35|0)>(0);
     if ($39) {
      __THREW__ = 0;
      invoke_vii(2758,($p|0),($this|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 59;
       break;
      }
     } else {
      $42 = HEAP32[$converter$i$i>>2]|0;
      $43 = ($42|0)==(0|0);
      if (!($43)) {
       __THREW__ = 0;
       (invoke_iii($42|0,($p|0),($this|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 59;
        break;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3389,($this|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 59;
      break;
     }
    }
    $48 = HEAP8[$p>>0]|0;
    $49 = $48 & 1;
    $50 = ($49<<24>>24)==(0);
    if ($50) {
     $53 = $48&255;
     $54 = $53 >>> 1;
     $56 = $54;$69 = $20;
    } else {
     $51 = HEAP32[$33>>2]|0;
     $52 = HEAP32[$34>>2]|0;
     $56 = $52;$69 = $51;
    }
    $55 = ($56>>>0)>(2147483631);
    if ($55) {
     label = 15;
     break;
    }
    $59 = ($56>>>0)<(11);
    if ($59) {
     $60 = $56 << 1;
     $61 = $60&255;
     HEAP8[$10>>0] = $61;
     $83 = $61;$__p$0$i$i$i$i$i$i = $21;
    } else {
     $62 = (($56) + 16)|0;
     $63 = $62 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$8+0>>2]|0;
     $64 = (invoke_iiiiiii(102,($63|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      label = 59;
      break;
     }
     HEAP32[$29>>2] = $64;
     $67 = $63 | 1;
     HEAP32[$10>>2] = $67;
     HEAP32[$32>>2] = $56;
     $68 = $67&255;
     $83 = $68;$__p$0$i$i$i$i$i$i = $64;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($69|0),($56|0))|0;
    $70 = (($__p$0$i$i$i$i$i$i) + ($56)|0);
    HEAP8[$70>>0] = 0;
    $71 = $23;
    $72 = $71;
    $73 = HEAP32[$72>>2]|0;
    $74 = (($71) + 4)|0;
    $75 = $74;
    $76 = HEAP32[$75>>2]|0;
    $77 = $22;
    $78 = $77;
    HEAP32[$78>>2] = $73;
    $79 = (($77) + 4)|0;
    $80 = $79;
    HEAP32[$80>>2] = $76;
    $81 = HEAP32[$24>>2]|0;
    HEAP32[$25>>2] = $81;
    $82 = $83 & 1;
    $84 = ($82<<24>>24)==(0);
    if ($84) {
     $87 = $83&255;
     $88 = $87 >>> 1;
     $102 = $21;$90 = $88;
    } else {
     $85 = HEAP32[$29>>2]|0;
     $86 = HEAP32[$32>>2]|0;
     $102 = $85;$90 = $86;
    }
    $89 = ($90>>>0)>(2147483631);
    if ($89) {
     label = 25;
     break;
    }
    $93 = ($90>>>0)<(11);
    if ($93) {
     $94 = $90 << 1;
     $95 = $94&255;
     HEAP8[$7>>0] = $95;
     $__p$0$i$i$i$i$i$i$i$i$i = $26;
    } else {
     $96 = (($90) + 16)|0;
     $97 = $96 & -16;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$6+0>>2]|0;
     $98 = (invoke_iiiiiii(102,($97|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      label = 62;
      break;
     }
     HEAP32[$30>>2] = $98;
     $101 = $97 | 1;
     HEAP32[$7>>2] = $101;
     HEAP32[$31>>2] = $90;
     $__p$0$i$i$i$i$i$i$i$i$i = $98;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($102|0),($90|0))|0;
    $103 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($90)|0);
    HEAP8[$103>>0] = 0;
    $104 = $27;
    $105 = $104;
    HEAP32[$105>>2] = $73;
    $106 = (($104) + 4)|0;
    $107 = $106;
    HEAP32[$107>>2] = $76;
    HEAP32[$28>>2] = $81;
    $108 = (__ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS5_($data,$__parent$i$i,$7)|0);
    __THREW__ = 0;
    $109 = (invoke_ii(2988,40)|0);
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if ($111) {
     label = 51;
     break;
    }
    $112 = (($109) + 16|0);
    $113 = HEAP8[$7>>0]|0;
    $114 = $113 & 1;
    $115 = ($114<<24>>24)==(0);
    if ($115) {
     $118 = $113&255;
     $119 = $118 >>> 1;
     $121 = $119;$141 = $26;
    } else {
     $116 = HEAP32[$30>>2]|0;
     $117 = HEAP32[$31>>2]|0;
     $121 = $117;$141 = $116;
    }
    $120 = ($121>>>0)>(2147483631);
    if ($120) {
     label = 36;
     break;
    }
    $124 = ($121>>>0)<(11);
    if ($124) {
     $125 = $121 << 1;
     $126 = $125&255;
     HEAP8[$112>>0] = $126;
     $127 = (($109) + 17|0);
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $127;
    } else {
     $128 = (($121) + 16)|0;
     $129 = $128 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$5+0>>2]|0;
     $130 = (invoke_iiiiiii(102,($129|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $131 = __THREW__; __THREW__ = 0;
     $132 = $131&1;
     if ($132) {
      label = 42;
      break;
     }
     $133 = (($109) + 24|0);
     HEAP32[$133>>2] = $130;
     $134 = $129 | 1;
     HEAP32[$112>>2] = $134;
     $135 = (($109) + 20|0);
     HEAP32[$135>>2] = $121;
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $130;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i$i$i|0),($141|0),($121|0))|0;
    $142 = (($__p$0$i$i$i$i$i$i$i$i$i$i$i) + ($121)|0);
    HEAP8[$142>>0] = 0;
    $143 = (($109) + 28|0);
    $144 = $27;
    $145 = $144;
    $146 = HEAP32[$145>>2]|0;
    $147 = (($144) + 4)|0;
    $148 = $147;
    $149 = HEAP32[$148>>2]|0;
    $150 = $143;
    $151 = $150;
    HEAP32[$151>>2] = $146;
    $152 = (($150) + 4)|0;
    $153 = $152;
    HEAP32[$153>>2] = $149;
    $154 = HEAP32[$28>>2]|0;
    $155 = (($109) + 36|0);
    HEAP32[$155>>2] = $154;
    $156 = HEAP32[$__parent$i$i>>2]|0;
    HEAP32[$109>>2] = 0;
    $157 = (($109) + 4|0);
    HEAP32[$157>>2] = 0;
    $158 = (($109) + 8|0);
    HEAP32[$158>>2] = $156;
    HEAP32[$108>>2] = $109;
    $159 = HEAP32[$data>>2]|0;
    $160 = HEAP32[$159>>2]|0;
    $161 = ($160|0)==(0|0);
    if ($161) {
     $163 = $109;
    } else {
     HEAP32[$data>>2] = $160;
     $$pre$i$i$i = HEAP32[$108>>2]|0;
     $163 = $$pre$i$i$i;
    }
    $162 = HEAP32[$14>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($162,$163);
    $164 = HEAP32[$11>>2]|0;
    $165 = (($164) + 1)|0;
    HEAP32[$11>>2] = $165;
    if (!($115)) {
     $166 = HEAP32[$30>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($166|0),($$byval_copy34|0));
     $167 = __THREW__; __THREW__ = 0;
     $168 = $167&1;
     if ($168) {
      label = 50;
      break;
     }
    }
    $181 = $83 & 1;
    $182 = ($181<<24>>24)==(0);
    if (!($182)) {
     $183 = HEAP32[$29>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($183|0),($$byval_copy34|0));
     $184 = __THREW__; __THREW__ = 0;
     $185 = $184&1;
     if ($185) {
      label = 57;
      break;
     }
    }
    $188 = (($i$041) + 1)|0;
    $189 = HEAP32[$size>>2]|0;
    $190 = ($188|0)<($189|0);
    if ($190) {
     $i$041 = $188;
    } else {
     label = 67;
     break L4;
    }
   }
   do {
    if ((label|0) == 15) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      label = 60;
      break L4;
     }
     // unreachable;
    }
    else if ((label|0) == 25) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      $197 = ___cxa_find_matching_catch()|0;
      $198 = tempRet0;
      $eh$lpad$body$index21Z2D = $198;$eh$lpad$body$indexZ2D = $197;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 36) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $122 = __THREW__; __THREW__ = 0;
     $123 = $122&1;
     if ($123) {
      $138 = ___cxa_find_matching_catch()|0;
      $139 = tempRet0;
      $lpad$phi20$index = $138;$lpad$phi20$index2 = $139;
      label = 44;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 42) {
     $136 = ___cxa_find_matching_catch()|0;
     $137 = tempRet0;
     $lpad$phi20$index = $136;$lpad$phi20$index2 = $137;
     label = 44;
    }
    else if ((label|0) == 50) {
     $169 = ___cxa_find_matching_catch()|0;
     $170 = tempRet0;
     ___cxa_call_unexpected(($169|0));
     // unreachable;
    }
    else if ((label|0) == 51) {
     $171 = ___cxa_find_matching_catch()|0;
     $172 = tempRet0;
     $$pre$i = HEAP8[$7>>0]|0;
     $174 = $$pre$i;$eh$lpad$body$i$index8Z2D = $172;$eh$lpad$body$i$indexZ2D = $171;
     label = 52;
    }
    else if ((label|0) == 57) {
     $186 = ___cxa_find_matching_catch()|0;
     $187 = tempRet0;
     ___cxa_call_unexpected(($186|0));
     // unreachable;
    }
    else if ((label|0) == 59) {
     $191 = ___cxa_find_matching_catch()|0;
     $192 = tempRet0;
     $lpad$phi$index = $191;$lpad$phi$index14 = $192;
     label = 61;
     break L4;
    }
    else if ((label|0) == 62) {
     $195 = ___cxa_find_matching_catch()|0;
     $196 = tempRet0;
     $eh$lpad$body$index21Z2D = $196;$eh$lpad$body$indexZ2D = $195;
    }
   } while(0);
   if ((label|0) == 44) {
    $140 = ($109|0)==(0|0);
    if ($140) {
     $174 = $113;$eh$lpad$body$i$index8Z2D = $lpad$phi20$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi20$index;
     label = 52;
    } else {
     __ZdlPv($109);
     $174 = $113;$eh$lpad$body$i$index8Z2D = $lpad$phi20$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi20$index;
     label = 52;
    }
   }
   if ((label|0) == 52) {
    $173 = $174 & 1;
    $175 = ($173<<24>>24)==(0);
    if ($175) {
     $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
    } else {
     $176 = HEAP32[$30>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($176|0),($$byval_copy34|0));
     $177 = __THREW__; __THREW__ = 0;
     $178 = $177&1;
     if ($178) {
      $179 = ___cxa_find_matching_catch()|0;
      $180 = tempRet0;
      ___cxa_call_unexpected(($179|0));
      // unreachable;
     } else {
      $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
     }
    }
   }
   $199 = $83 & 1;
   $200 = ($199<<24>>24)==(0);
   if ($200) {
    $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
   } else {
    $201 = HEAP32[$29>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($201|0),($$byval_copy34|0));
    $202 = __THREW__; __THREW__ = 0;
    $203 = $202&1;
    if ($203) {
     $204 = ___cxa_find_matching_catch()|0;
     $205 = tempRet0;
     ___cxa_call_unexpected(($204|0));
     // unreachable;
    } else {
     $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
    }
   }
  } else {
   label = 67;
  }
 } while(0);
 if ((label|0) == 67) {
  __THREW__ = 0;
  invoke_vi(3513,($this|0));
  $206 = __THREW__; __THREW__ = 0;
  $207 = $206&1;
  if ($207) {
   label = 60;
  } else {
   $208 = HEAP8[$p>>0]|0;
   $209 = $208 & 1;
   $210 = ($209<<24>>24)==(0);
   if ($210) {
    STACKTOP = sp;return;
   }
   $211 = (($p) + 8|0);
   $212 = HEAP32[$211>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($212|0),($$byval_copy34|0));
   $213 = __THREW__; __THREW__ = 0;
   $214 = $213&1;
   if ($214) {
    $215 = ___cxa_find_matching_catch()|0;
    $216 = tempRet0;
    ___cxa_call_unexpected(($215|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 60) {
  $193 = ___cxa_find_matching_catch()|0;
  $194 = tempRet0;
  $lpad$phi$index = $193;$lpad$phi$index14 = $194;
  label = 61;
 }
 if ((label|0) == 61) {
  $$0 = $lpad$phi$index14;$$01 = $lpad$phi$index;
 }
 $217 = HEAP8[$p>>0]|0;
 $218 = $217 & 1;
 $219 = ($218<<24>>24)==(0);
 if ($219) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $220 = (($p) + 8|0);
 $221 = HEAP32[$220>>2]|0;
 HEAP32[$9>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$9+0>>2]|0;
 invoke_vii(2591,($221|0),($$byval_copy34|0));
 $222 = __THREW__; __THREW__ = 0;
 $223 = $222&1;
 if ($223) {
  $224 = ___cxa_find_matching_catch()|0;
  $225 = tempRet0;
  ___cxa_call_unexpected(($224|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN15SerializeTraitsINSt3__14pairI8UnityStrN11AssetBundle9AssetInfoEEEE8TransferI14SafeBinaryReadEEvRS5_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580576>>2]|0;
 $1 = HEAP32[580712>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$0,$1,$converter$i$i1,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$data,0);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($data) + 12|0);
 $8 = HEAP32[580656>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$8,617096,$converter$i$i1,1)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 if ($11) {
  __ZN11AssetBundle9AssetInfo8TransferI14SafeBinaryReadEEvRT_($7,$transfer);
 } else {
  $12 = HEAP32[$converter$i$i1>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   (FUNCTION_TABLE_iii[$12 & 4095]($7,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,617088,617088,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI4PPtrI6ObjectELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<2)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580624>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,617008,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$i$01 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$33);
       $36 = $2;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $49 = (($i$01) + 4|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$16>>2]|0;
       $30 = $$pre6;$33 = $$pre7;$i$01 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $i$12 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,617008,$14,$$byval_copy,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $56 = HEAP32[$$byval_copy>>2]|0;
       $57 = ($56|0)==(0|0);
       if (!($57)) {
        (FUNCTION_TABLE_iii[$56 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $58 = (($i$12) + 4|0);
     $59 = ($58|0)==($11|0);
     if ($59) {
      break;
     } else {
      $i$12 = $58;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy34 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i$i$i = 0, $__parent$i$i = 0, $converter$i$i = 0, $eh$lpad$body$i$index8Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$041 = 0, $lpad$phi$index = 0, $lpad$phi$index14 = 0, $lpad$phi20$index = 0, $lpad$phi20$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy34 = sp + 92|0;
 $1 = sp + 88|0;
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 72|0;
 $__parent$i$i = sp + 68|0;
 $6 = sp + 64|0;
 $7 = sp + 32|0;
 $8 = sp + 28|0;
 $converter$i$i = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 48|0;
 $11 = (($data) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$size>>2] = $12;
 $13 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,617088,617088,$size)|0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $14 = (($data) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$15);
 HEAP32[$11>>2] = 0;
 $16 = (($data) + 4|0);
 HEAP32[$data>>2] = $16;
 HEAP32[$16>>2] = 0;
 $17 = HEAP32[$size>>2]|0;
 $18 = ($17|0)>(0);
 L4: do {
  if ($18) {
   $19 = HEAP32[580608>>2]|0;
   $20 = (($p) + 1|0);
   $21 = (($10) + 1|0);
   $22 = (($p) + 12|0);
   $23 = (($10) + 12|0);
   $24 = (($7) + 1|0);
   $25 = (($7) + 12|0);
   $26 = (($10) + 8|0);
   $27 = (($7) + 8|0);
   $28 = (($7) + 4|0);
   $29 = (($10) + 4|0);
   $30 = (($p) + 8|0);
   $31 = (($p) + 4|0);
   $i$041 = 0;
   while(1) {
    __THREW__ = 0;
    $32 = (invoke_iiiiii(192,($this|0),(617008|0),($19|0),($converter$i$i|0),1)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     label = 59;
     break;
    }
    $35 = ($32|0)==(0);
    if (!($35)) {
     $36 = ($32|0)>(0);
     if ($36) {
      __THREW__ = 0;
      invoke_vii(2759,($p|0),($this|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 59;
       break;
      }
     } else {
      $39 = HEAP32[$converter$i$i>>2]|0;
      $40 = ($39|0)==(0|0);
      if (!($40)) {
       __THREW__ = 0;
       (invoke_iii($39|0,($p|0),($this|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 59;
        break;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3389,($this|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 59;
      break;
     }
    }
    $45 = HEAP8[$p>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $50 = $45&255;
     $51 = $50 >>> 1;
     $53 = $51;$66 = $20;
    } else {
     $48 = HEAP32[$30>>2]|0;
     $49 = HEAP32[$31>>2]|0;
     $53 = $49;$66 = $48;
    }
    $52 = ($53>>>0)>(2147483631);
    if ($52) {
     label = 15;
     break;
    }
    $56 = ($53>>>0)<(11);
    if ($56) {
     $57 = $53 << 1;
     $58 = $57&255;
     HEAP8[$10>>0] = $58;
     $70 = $58;$__p$0$i$i$i$i$i$i = $21;
    } else {
     $59 = (($53) + 16)|0;
     $60 = $59 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$8+0>>2]|0;
     $61 = (invoke_iiiiiii(102,($60|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      label = 59;
      break;
     }
     HEAP32[$26>>2] = $61;
     $64 = $60 | 1;
     HEAP32[$10>>2] = $64;
     HEAP32[$29>>2] = $53;
     $65 = $64&255;
     $70 = $65;$__p$0$i$i$i$i$i$i = $61;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($66|0),($53|0))|0;
    $67 = (($__p$0$i$i$i$i$i$i) + ($53)|0);
    HEAP8[$67>>0] = 0;
    $68 = HEAP32[$22>>2]|0;
    HEAP32[$23>>2] = $68;
    $69 = $70 & 1;
    $71 = ($69<<24>>24)==(0);
    if ($71) {
     $74 = $70&255;
     $75 = $74 >>> 1;
     $77 = $75;$89 = $21;
    } else {
     $72 = HEAP32[$26>>2]|0;
     $73 = HEAP32[$29>>2]|0;
     $77 = $73;$89 = $72;
    }
    $76 = ($77>>>0)>(2147483631);
    if ($76) {
     label = 25;
     break;
    }
    $80 = ($77>>>0)<(11);
    if ($80) {
     $81 = $77 << 1;
     $82 = $81&255;
     HEAP8[$7>>0] = $82;
     $__p$0$i$i$i$i$i$i$i$i$i = $24;
    } else {
     $83 = (($77) + 16)|0;
     $84 = $83 & -16;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$6+0>>2]|0;
     $85 = (invoke_iiiiiii(102,($84|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      label = 62;
      break;
     }
     HEAP32[$27>>2] = $85;
     $88 = $84 | 1;
     HEAP32[$7>>2] = $88;
     HEAP32[$28>>2] = $77;
     $__p$0$i$i$i$i$i$i$i$i$i = $85;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($89|0),($77|0))|0;
    $90 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($77)|0);
    HEAP8[$90>>0] = 0;
    HEAP32[$25>>2] = $68;
    $91 = (__ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS6_($data,$__parent$i$i,$7)|0);
    __THREW__ = 0;
    $92 = (invoke_ii(2988,32)|0);
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     label = 51;
     break;
    }
    $95 = (($92) + 16|0);
    $96 = HEAP8[$7>>0]|0;
    $97 = $96 & 1;
    $98 = ($97<<24>>24)==(0);
    if ($98) {
     $101 = $96&255;
     $102 = $101 >>> 1;
     $104 = $102;$124 = $24;
    } else {
     $99 = HEAP32[$27>>2]|0;
     $100 = HEAP32[$28>>2]|0;
     $104 = $100;$124 = $99;
    }
    $103 = ($104>>>0)>(2147483631);
    if ($103) {
     label = 36;
     break;
    }
    $107 = ($104>>>0)<(11);
    if ($107) {
     $108 = $104 << 1;
     $109 = $108&255;
     HEAP8[$95>>0] = $109;
     $110 = (($92) + 17|0);
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $110;
    } else {
     $111 = (($104) + 16)|0;
     $112 = $111 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$5+0>>2]|0;
     $113 = (invoke_iiiiiii(102,($112|0),16,($$byval_copy34|0),0,(616888|0),79)|0);
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if ($115) {
      label = 42;
      break;
     }
     $116 = (($92) + 24|0);
     HEAP32[$116>>2] = $113;
     $117 = $112 | 1;
     HEAP32[$95>>2] = $117;
     $118 = (($92) + 20|0);
     HEAP32[$118>>2] = $104;
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $113;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i$i$i|0),($124|0),($104|0))|0;
    $125 = (($__p$0$i$i$i$i$i$i$i$i$i$i$i) + ($104)|0);
    HEAP8[$125>>0] = 0;
    $126 = HEAP32[$25>>2]|0;
    $127 = (($92) + 28|0);
    HEAP32[$127>>2] = $126;
    $128 = HEAP32[$__parent$i$i>>2]|0;
    HEAP32[$92>>2] = 0;
    $129 = (($92) + 4|0);
    HEAP32[$129>>2] = 0;
    $130 = (($92) + 8|0);
    HEAP32[$130>>2] = $128;
    HEAP32[$91>>2] = $92;
    $131 = HEAP32[$data>>2]|0;
    $132 = HEAP32[$131>>2]|0;
    $133 = ($132|0)==(0|0);
    if ($133) {
     $135 = $92;
    } else {
     HEAP32[$data>>2] = $132;
     $$pre$i$i$i = HEAP32[$91>>2]|0;
     $135 = $$pre$i$i$i;
    }
    $134 = HEAP32[$14>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($134,$135);
    $136 = HEAP32[$11>>2]|0;
    $137 = (($136) + 1)|0;
    HEAP32[$11>>2] = $137;
    if (!($98)) {
     $138 = HEAP32[$27>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($138|0),($$byval_copy34|0));
     $139 = __THREW__; __THREW__ = 0;
     $140 = $139&1;
     if ($140) {
      label = 50;
      break;
     }
    }
    $153 = $70 & 1;
    $154 = ($153<<24>>24)==(0);
    if (!($154)) {
     $155 = HEAP32[$26>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($155|0),($$byval_copy34|0));
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if ($157) {
      label = 57;
      break;
     }
    }
    $160 = (($i$041) + 1)|0;
    $161 = HEAP32[$size>>2]|0;
    $162 = ($160|0)<($161|0);
    if ($162) {
     $i$041 = $160;
    } else {
     label = 67;
     break L4;
    }
   }
   do {
    if ((label|0) == 15) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      label = 60;
      break L4;
     }
     // unreachable;
    }
    else if ((label|0) == 25) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      $169 = ___cxa_find_matching_catch()|0;
      $170 = tempRet0;
      $eh$lpad$body$index21Z2D = $170;$eh$lpad$body$indexZ2D = $169;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 36) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      $121 = ___cxa_find_matching_catch()|0;
      $122 = tempRet0;
      $lpad$phi20$index = $121;$lpad$phi20$index2 = $122;
      label = 44;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 42) {
     $119 = ___cxa_find_matching_catch()|0;
     $120 = tempRet0;
     $lpad$phi20$index = $119;$lpad$phi20$index2 = $120;
     label = 44;
    }
    else if ((label|0) == 50) {
     $141 = ___cxa_find_matching_catch()|0;
     $142 = tempRet0;
     ___cxa_call_unexpected(($141|0));
     // unreachable;
    }
    else if ((label|0) == 51) {
     $143 = ___cxa_find_matching_catch()|0;
     $144 = tempRet0;
     $$pre$i = HEAP8[$7>>0]|0;
     $146 = $$pre$i;$eh$lpad$body$i$index8Z2D = $144;$eh$lpad$body$i$indexZ2D = $143;
     label = 52;
    }
    else if ((label|0) == 57) {
     $158 = ___cxa_find_matching_catch()|0;
     $159 = tempRet0;
     ___cxa_call_unexpected(($158|0));
     // unreachable;
    }
    else if ((label|0) == 59) {
     $163 = ___cxa_find_matching_catch()|0;
     $164 = tempRet0;
     $lpad$phi$index = $163;$lpad$phi$index14 = $164;
     label = 61;
     break L4;
    }
    else if ((label|0) == 62) {
     $167 = ___cxa_find_matching_catch()|0;
     $168 = tempRet0;
     $eh$lpad$body$index21Z2D = $168;$eh$lpad$body$indexZ2D = $167;
    }
   } while(0);
   if ((label|0) == 44) {
    $123 = ($92|0)==(0|0);
    if ($123) {
     $146 = $96;$eh$lpad$body$i$index8Z2D = $lpad$phi20$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi20$index;
     label = 52;
    } else {
     __ZdlPv($92);
     $146 = $96;$eh$lpad$body$i$index8Z2D = $lpad$phi20$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi20$index;
     label = 52;
    }
   }
   if ((label|0) == 52) {
    $145 = $146 & 1;
    $147 = ($145<<24>>24)==(0);
    if ($147) {
     $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
    } else {
     $148 = HEAP32[$27>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($148|0),($$byval_copy34|0));
     $149 = __THREW__; __THREW__ = 0;
     $150 = $149&1;
     if ($150) {
      $151 = ___cxa_find_matching_catch()|0;
      $152 = tempRet0;
      ___cxa_call_unexpected(($151|0));
      // unreachable;
     } else {
      $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
     }
    }
   }
   $171 = $70 & 1;
   $172 = ($171<<24>>24)==(0);
   if ($172) {
    $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
   } else {
    $173 = HEAP32[$26>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($173|0),($$byval_copy34|0));
    $174 = __THREW__; __THREW__ = 0;
    $175 = $174&1;
    if ($175) {
     $176 = ___cxa_find_matching_catch()|0;
     $177 = tempRet0;
     ___cxa_call_unexpected(($176|0));
     // unreachable;
    } else {
     $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
    }
   }
  } else {
   label = 67;
  }
 } while(0);
 if ((label|0) == 67) {
  __THREW__ = 0;
  invoke_vi(3513,($this|0));
  $178 = __THREW__; __THREW__ = 0;
  $179 = $178&1;
  if ($179) {
   label = 60;
  } else {
   $180 = HEAP8[$p>>0]|0;
   $181 = $180 & 1;
   $182 = ($181<<24>>24)==(0);
   if ($182) {
    STACKTOP = sp;return;
   }
   $183 = (($p) + 8|0);
   $184 = HEAP32[$183>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($184|0),($$byval_copy34|0));
   $185 = __THREW__; __THREW__ = 0;
   $186 = $185&1;
   if ($186) {
    $187 = ___cxa_find_matching_catch()|0;
    $188 = tempRet0;
    ___cxa_call_unexpected(($187|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 60) {
  $165 = ___cxa_find_matching_catch()|0;
  $166 = tempRet0;
  $lpad$phi$index = $165;$lpad$phi$index14 = $166;
  label = 61;
 }
 if ((label|0) == 61) {
  $$0 = $lpad$phi$index14;$$01 = $lpad$phi$index;
 }
 $189 = HEAP8[$p>>0]|0;
 $190 = $189 & 1;
 $191 = ($190<<24>>24)==(0);
 if ($191) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $192 = (($p) + 8|0);
 $193 = HEAP32[$192>>2]|0;
 HEAP32[$9>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$9+0>>2]|0;
 invoke_vii(2591,($193|0),($$byval_copy34|0));
 $194 = __THREW__; __THREW__ = 0;
 $195 = $194&1;
 if ($195) {
  $196 = ___cxa_find_matching_catch()|0;
  $197 = tempRet0;
  ___cxa_call_unexpected(($196|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN15SerializeTraitsINSt3__14pairI8UnityStr4PPtrI6ObjectEEEE8TransferI14SafeBinaryReadEEvRS6_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580576>>2]|0;
 $1 = HEAP32[580712>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$0,$1,$converter$i$i1,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$data,0);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($data) + 12|0);
 $8 = HEAP32[580656>>2]|0;
 $9 = HEAP32[580624>>2]|0;
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$8,$9,$converter$i$i1,1)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($10|0)>(0);
 if ($12) {
  __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($7,$transfer);
 } else {
  $13 = HEAP32[$converter$i$i1>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   (FUNCTION_TABLE_iii[$13 & 4095]($7,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11AssetBundle8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $p$i$i$i = 0, $p$i$i$i12 = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i12 = sp + 24|0;
 $p$i$i = sp + 16|0;
 $p$i$i$i = sp + 20|0;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,3);
 $0 = (($this) + 44|0);
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616928,$1,$0,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,617088,617088,$p$i$i$i12,0);
 $2 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617008,$2,$p$i$i,0);
 $3 = (($size$i$i$i$i) + 8|0);
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 HEAP32[$size$i$i$i$i>>2] = 0;
 $8 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617056,$8,$p$i$i,1);
 $9 = (($transfer) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($transfer) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($11) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617072,$15,$3,1);
 $16 = HEAP32[$9>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$12>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 60|0);
 __ZN13ProxyTransfer8TransferINSt3__18multimapI8UnityStrN11AssetBundle9AssetInfoENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S5_EEEEEEEEvRT_PKc17TransferMetaFlags($transfer,$20,616896,0);
 $21 = (($this) + 32|0);
 __ZN13ProxyTransfer8TransferIN11AssetBundle9AssetInfoEEEvRT_PKc17TransferMetaFlags($transfer,$21,616912,0);
 $22 = (($this) + 28|0);
 $23 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616944,$23,$22,0);
 $24 = HEAP32[$9>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$12>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 84|0);
 $29 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616968,$29,$28,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,617088,617088,$size$i$i$i$i,1);
 $30 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617008,$30,$p$i$i$i12,0);
 $31 = HEAP32[$9>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$12>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $35 = (($this) + 88|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,616992,$1,$35,0);
 HEAP32[$p$i$i$i>>2] = 0;
 __ZN14ConstantString12create_emptyEv($p$i$i$i);
 __THREW__ = 0;
 invoke_viiiii(87,($transfer|0),(617088|0),(617088|0),($p$i$i|0),0);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if (!($37)) {
  __THREW__ = 0;
  invoke_viiiii(86,($transfer|0),(617008|0),($29|0),($p$i$i$i|0),0);
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if (!($39)) {
   __THREW__ = 0;
   invoke_viiiii(87,($transfer|0),(617088|0),(617088|0),($size$i$i$i$i|0),1);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    __THREW__ = 0;
    invoke_viiiii(86,($transfer|0),(617008|0),($30|0),($p$i$i$i12|0),0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     $44 = HEAP32[$9>>2]|0;
     $45 = HEAP32[$44>>2]|0;
     $46 = HEAP32[$12>>2]|0;
     $47 = ((($45) + (($46*24)|0)|0) + 12|0);
     HEAP32[$47>>2] = 1;
     __THREW__ = 0;
     invoke_vi(3390,($transfer|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if (!($49)) {
      __THREW__ = 0;
      invoke_vi(3391,($transfer|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if (!($51)) {
       __THREW__ = 0;
       invoke_vi(3392,($transfer|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if (!($53)) {
        __THREW__ = 0;
        invoke_vi(3390,($transfer|0));
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if (!($55)) {
         __THREW__ = 0;
         invoke_vi(3391,($transfer|0));
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if (!($57)) {
          __ZN14ConstantStringD2Ev($p$i$i$i);
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $58 = ___cxa_find_matching_catch()|0;
 $59 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3382,($p$i$i$i|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 if ($61) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 } else {
  ___resumeException($58|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer8TransferINSt3__18multimapI8UnityStrN11AssetBundle9AssetInfoENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S5_EEEEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $p$i$i$i$i = 0, $size$i$i = 0;
 var $size$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 40|0;
 $size$i$i$i$i$i = sp;
 $p$i$i$i$i = sp + 44|0;
 $0 = sp + 32|0;
 $size$i$i = sp + 36|0;
 $p$i$i = sp + 8|0;
 $1 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$1,$data,$metaFlag);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,617088,617088,$size$i$i,0);
 ;HEAP32[$p$i$i+0>>2]=0|0;HEAP32[$p$i$i+4>>2]=0|0;HEAP32[$p$i$i+8>>2]=0|0;HEAP32[$p$i$i+12>>2]=0|0;HEAP32[$p$i$i+16>>2]=0|0;HEAP32[$p$i$i+20>>2]=0|0;
 $2 = HEAP32[580608>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($this|0),(617008|0),($2|0),($p$i$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = HEAP32[580576>>2]|0;
  $6 = HEAP32[580712>>2]|0;
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),($5|0),($6|0),($p$i$i|0),0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_viiiii(87,($this|0),(617088|0),(617088|0),($size$i$i$i$i$i|0),1);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP32[580552>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($this|0),(617008|0),($11|0),($p$i$i$i$i|0),0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = (($this) + 12|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = HEAP32[$15>>2]|0;
     $17 = (($this) + 20|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ((($16) + (($18*24)|0)|0) + 12|0);
     HEAP32[$19>>2] = 1;
     __THREW__ = 0;
     invoke_vi(3390,($this|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3391,($this|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vi(3392,($this|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        invoke_vi(3390,($this|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $28 = (($p$i$i) + 12|0);
         $29 = HEAP32[580656>>2]|0;
         __THREW__ = 0;
         invoke_viiii(373,($this|0),($28|0),($29|0),0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          invoke_vi(3390,($this|0));
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           __THREW__ = 0;
           invoke_vi(3391,($this|0));
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $36 = HEAP8[$p$i$i>>0]|0;
            $37 = $36 & 1;
            $38 = ($37<<24>>24)==(0);
            if ($38) {
             __ZN13ProxyTransfer11EndTransferEv($this);
             STACKTOP = sp;return;
            }
            $39 = (($p$i$i) + 8|0);
            $40 = HEAP32[$39>>2]|0;
            HEAP32[$size$i$i$i$i$i>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i$i+0>>2]|0;
            invoke_vii(2591,($40|0),($$byval_copy1|0));
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             $43 = ___cxa_find_matching_catch()|0;
             $44 = tempRet0;
             ___cxa_call_unexpected(($43|0));
             // unreachable;
            } else {
             __ZN13ProxyTransfer11EndTransferEv($this);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $45 = ___cxa_find_matching_catch()|0;
 $46 = tempRet0;
 $47 = HEAP8[$p$i$i>>0]|0;
 $48 = $47 & 1;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  ___resumeException($45|0);
  // unreachable;
 }
 $50 = (($p$i$i) + 8|0);
 $51 = HEAP32[$50>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($51|0),($$byval_copy1|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  ___cxa_call_unexpected(($54|0));
  // unreachable;
 } else {
  ___resumeException($45|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer8TransferIN11AssetBundle9AssetInfoEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,617096,$data,$metaFlag);
 $0 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,617016,$0,$data,0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $7 = (($data) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,617032,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $12 = (($data) + 8|0);
 $13 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,617048,$13,$12,0);
 $14 = (($localIdentifier$i$i$i) + 8|0);
 $15 = $14;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,617056,$0,$12,1);
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$4>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $23 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,617072,$23,$14,1);
 $24 = HEAP32[$1>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$4>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11AssetBundleD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$3 = 0, $$34 = 0, $$byval_copy2 = 0, $$pr$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((616784 + 8|0));
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 3;
 } else {
  __THREW__ = 0;
  invoke_vi(3514,($4|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 22;
  } else {
   label = 3;
  }
 }
 do {
  if ((label|0) == 3) {
   $8 = (($this) + 76|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $11 = HEAP32[628408>>2]|0;
    $23 = $11;$24 = 0;$91 = $2;
   } else {
    __THREW__ = 0;
    $12 = (invoke_i(89)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 22;
     break;
    }
    $15 = HEAP32[$8>>2]|0;
    $16 = (($15) + 28|0);
    __THREW__ = 0;
    invoke_vii(2760,($12|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 22;
     break;
    }
    $$pr$i = HEAP32[$8>>2]|0;
    $19 = HEAP32[628408>>2]|0;
    $20 = ($$pr$i|0)==(0|0);
    if ($20) {
     $23 = $19;$24 = 0;$91 = $2;
    } else {
     __THREW__ = 0;
     invoke_vi(3515,($$pr$i|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 22;
      break;
     }
     $23 = $19;$24 = $$pr$i;$91 = $2;
    }
   }
   HEAP32[$2>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($24|0),($$byval_copy2|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 22;
   } else {
    HEAP32[$8>>2] = 0;
    $27 = (($this) + 88|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    do {
     if (!($29)) {
      $30 = (($this) + 92|0);
      while(1) {
       $31 = HEAP32[$30>>2]|0;
       $32 = ($31|0)==($28|0);
       if ($32) {
        label = 16;
        break;
       }
       $33 = (($31) + -4|0);
       HEAP32[$30>>2] = $33;
       __THREW__ = 0;
       invoke_vi(3382,($33|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 15;
        break;
       }
      }
      if ((label|0) == 15) {
       $36 = ___cxa_find_matching_catch()|0;
       $37 = tempRet0;
       ___cxa_call_unexpected(($36|0));
       // unreachable;
      }
      else if ((label|0) == 16) {
       $38 = HEAP32[$27>>2]|0;
       __ZdlPv($38);
       break;
      }
     }
    } while(0);
    $39 = (($this) + 84|0);
    __THREW__ = 0;
    invoke_vi(3382,($39|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     $68 = ___cxa_find_matching_catch()|0;
     $69 = tempRet0;
     $$1 = $69;$$12 = $68;
     label = 31;
     break;
    }
    $42 = (($this) + 60|0);
    $43 = (($this) + 64|0);
    $44 = HEAP32[$43>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($42,$44);
    $45 = (($this) + 56|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)>(-1);
    if (!($47)) {
     __ZN11NamedObjectD2Ev($this);
     STACKTOP = sp;return;
    }
    $48 = (($this) + 44|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($this) + 48|0);
    $51 = HEAP32[$50>>2]|0;
    HEAP32[$1>>2] = $51;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($49|0),($$byval_copy2|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $73 = ___cxa_find_matching_catch()|0;
     $74 = tempRet0;
     $$3 = $74;$$34 = $73;
     break;
    }
    HEAP32[$48>>2] = 0;
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  $56 = (($this) + 88|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  do {
   if (!($58)) {
    $59 = (($this) + 92|0);
    while(1) {
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==($57|0);
     if ($61) {
      label = 27;
      break;
     }
     $62 = (($60) + -4|0);
     HEAP32[$59>>2] = $62;
     __THREW__ = 0;
     invoke_vi(3382,($62|0));
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      label = 26;
      break;
     }
    }
    if ((label|0) == 26) {
     $65 = ___cxa_find_matching_catch()|0;
     $66 = tempRet0;
     ___cxa_call_unexpected(($65|0));
     // unreachable;
    }
    else if ((label|0) == 27) {
     $67 = HEAP32[$56>>2]|0;
     __ZdlPv($67);
     break;
    }
   }
  } while(0);
  $70 = (($this) + 84|0);
  __THREW__ = 0;
  invoke_vi(3382,($70|0));
  $71 = __THREW__; __THREW__ = 0;
  $72 = $71&1;
  if ($72) {
   $89 = ___cxa_find_matching_catch(0|0)|0;
   $90 = tempRet0;
   ___clang_call_terminate($89);
   // unreachable;
  } else {
   $$1 = $55;$$12 = $54;
   label = 31;
  }
 }
 do {
  if ((label|0) == 31) {
   $75 = (($this) + 60|0);
   $76 = (($this) + 64|0);
   $77 = HEAP32[$76>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeI8UnityStrN11AssetBundle9AssetInfoEEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($75,$77);
   $78 = (($this) + 56|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)>(-1);
   if ($80) {
    $81 = (($this) + 44|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($this) + 48|0);
    $84 = HEAP32[$83>>2]|0;
    HEAP32[$0>>2] = $84;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($82|0),($$byval_copy2|0));
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     $89 = ___cxa_find_matching_catch(0|0)|0;
     $90 = tempRet0;
     ___clang_call_terminate($89);
     // unreachable;
    } else {
     HEAP32[$81>>2] = 0;
     $$3 = $$1;$$34 = $$12;
     break;
    }
   } else {
    $$3 = $$1;$$34 = $$12;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if ($88) {
  $89 = ___cxa_find_matching_catch(0|0)|0;
  $90 = tempRet0;
  ___clang_call_terminate($89);
  // unreachable;
 } else {
  ___resumeException($$34|0);
  // unreachable;
 }
}
function __ZN27TimeSliceAwakeFromLoadQueue19IntegrateTimeSlicedEi($this,$timeoutMS) {
 $this = $this|0;
 $timeoutMS = $timeoutMS|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, $instanceID = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $instanceID = sp;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__Z20GetPersistentManagerv()|0);
 $4 = (+_emscripten_get_now());
 $5 = $4 * 1.0E+6;
 $6 = (~~$5)>>>0;
 $7 = +Math_abs($5) >= 1.0 ? $5 > 0.0 ? (Math_min(+Math_floor($5 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($5 - +(~~$5 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $8 = (+_emscripten_get_now());
 $9 = $8 * 1.0E+6;
 $10 = (~~$9)>>>0;
 $11 = +Math_abs($9) >= 1.0 ? $9 > 0.0 ? (Math_min(+Math_floor($9 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($9 - +(~~$9 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $12 = (_i64Subtract(($10|0),($11|0),($6|0),($7|0))|0);
 $13 = tempRet0;
 $14 = (__Z14GetProfileTimey($12,$13)|0);
 $15 = tempRet0;
 $16 = (___udivdi3(($14|0),($15|0),1000000,0)|0);
 $17 = tempRet0;
 $18 = Math_fround((+($16>>>0)) + (4294967296.0*(+($17>>>0))));
 $19 = (~~(($18)));
 $20 = ($19|0)<($timeoutMS|0);
 if (!($20)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $21 = (__ZN19RingbufferTemplates18ReadFromRingBufferIi17GrowingRingbufferEEbRT0_RT_($this,$instanceID)|0);
  if (!($21)) {
   $$0 = 0;
   label = 5;
   break;
  }
  $22 = HEAP32[$instanceID>>2]|0;
  (__ZN17PersistentManager48IntegrateObjectAndUnlockIntegrationMutexInternalEi($3,$22)|0);
  $23 = (+_emscripten_get_now());
  $24 = $23 * 1.0E+6;
  $25 = (~~$24)>>>0;
  $26 = +Math_abs($24) >= 1.0 ? $24 > 0.0 ? (Math_min(+Math_floor($24 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($24 - +(~~$24 >>> 0)) / 4294967296.0) >>> 0 : 0;
  $27 = (_i64Subtract(($25|0),($26|0),($6|0),($7|0))|0);
  $28 = tempRet0;
  $29 = (__Z14GetProfileTimey($27,$28)|0);
  $30 = tempRet0;
  $31 = (___udivdi3(($29|0),($30|0),1000000,0)|0);
  $32 = tempRet0;
  $33 = Math_fround((+($31>>>0)) + (4294967296.0*(+($32>>>0))));
  $34 = (~~(($33)));
  $35 = ($34|0)<($timeoutMS|0);
  if (!($35)) {
   $$0 = 0;
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN23PreloadManagerOperation11GetPriorityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN23PreloadManagerOperation11SetPriorityEi($this,$priority) {
 $this = $this|0;
 $priority = $priority|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 HEAP32[$0>>2] = $priority;
 STACKTOP = sp;return;
}
function __ZN14AsyncOperation23GetAllowSceneActivationEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN14AsyncOperation23SetAllowSceneActivationEb($this,$allow) {
 $this = $this|0;
 $allow = $allow|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN23PreloadManagerOperation21MustCompleteNextFrameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK23PreloadManagerOperation25GetAllowParallelExecutionEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN19RingbufferTemplates18ReadFromRingBufferIi17GrowingRingbufferEEbRT0_RT_($ringbuffer,$data) {
 $ringbuffer = $ringbuffer|0;
 $data = $data|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($ringbuffer) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$3>>2]|0;
 $8 = (($6) - ($7))|0;
 $9 = (($2) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + -1)|0;
 $12 = $11 & $4;
 $13 = (($10) - ($12))|0;
 $14 = ($13>>>0)<($8>>>0);
 $15 = $14 ? $13 : $8;
 $16 = ($15>>>0)>(3);
 if (!($16)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = HEAP32[$2>>2]|0;
 $18 = (($17) + ($12)|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$data>>2] = $19;
 $20 = HEAP32[$1>>2]|0;
 $21 = (($20) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 4)|0;
 HEAP32[$21>>2] = $23;
 $24 = HEAP32[$21>>2]|0;
 $25 = (($ringbuffer) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + -4)|0;
 HEAP32[$25>>2] = $27;
 $28 = HEAP32[$25>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = (($29) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = (($33) + 20|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($33) + 16|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($35|0)==($37|0);
 if (!($38)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = (($ringbuffer) + 12|0);
 $40 = HEAP32[$1>>2]|0;
 $41 = (($40) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$39>>2]|0;
 $44 = (($43) - ($42))|0;
 HEAP32[$39>>2] = $44;
 $45 = HEAP32[$39>>2]|0;
 $46 = HEAP32[$1>>2]|0;
 $47 = HEAP32[$1>>2]|0;
 $48 = (($47) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 HEAP32[$1>>2] = $49;
 $50 = ($46|0)==(0|0);
 if ($50) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $51 = (($46) + 4|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = ($52<<24>>24)==(0);
 if (!($53)) {
  $54 = HEAP32[$46>>2]|0;
  $55 = (($46) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  HEAP32[$0>>2] = $56;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($54|0),($$byval_copy|0));
  $57 = __THREW__; __THREW__ = 0;
  $58 = $57&1;
  if ($58) {
   $59 = ___cxa_find_matching_catch()|0;
   $60 = tempRet0;
   __ZdlPv($46);
   ___resumeException($59|0);
   // unreachable;
  }
 }
 __ZdlPv($46);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN18AssetBundleManager16StaticInitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628240>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy,1,16,617112,30)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($2) + 12|0);
 HEAP32[$5>>2] = 0;
 HEAP32[617120>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN18AssetBundleManager13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[617120>>2]|0;
 $2 = HEAP32[628240>>2]|0;
 $3 = ($1|0)==(0|0);
 do {
  if (!($3)) {
   $4 = (($1) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = (($1) + 8|0);
    while(1) {
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==($5|0);
     if ($9) {
      label = 7;
      break;
     }
     $10 = (($8) + -8|0);
     HEAP32[$7>>2] = $10;
     __THREW__ = 0;
     invoke_vi(3382,($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 6;
      break;
     }
    }
    if ((label|0) == 6) {
     $13 = ___cxa_find_matching_catch()|0;
     $14 = tempRet0;
     ___cxa_call_unexpected(($13|0));
     // unreachable;
    }
    else if ((label|0) == 7) {
     $15 = HEAP32[$4>>2]|0;
     __ZdlPv($15);
     break;
    }
   }
  }
 } while(0);
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[617120>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18AssetBundleManager18CollectPreloadDataERKNSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEER13dynamic_arrayIiLj4EEbb($this,$dependencies,$preloadObjects,$scriptOnly,$forceSorting) {
 $this = $this|0;
 $dependencies = $dependencies|0;
 $preloadObjects = $preloadObjects|0;
 $scriptOnly = $scriptOnly|0;
 $forceSorting = $forceSorting|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$01 = 0, $$01$i$i = 0, $$1 = 0, $$12 = 0, $$byval_copy24 = 0, $$idx$i$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $it$027 = 0, $it1$021 = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0, $lpad$phi26$index = 0, $lpad$phi26$index2 = 0, $lpad$phi36$index = 0, $lpad$phi36$index12 = 0, $objects = 0;
 var $preloadDataArray = 0, $preloadDataArray2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy24 = sp + 76|0;
 $0 = sp + 72|0;
 $1 = sp + 68|0;
 $2 = sp + 64|0;
 $3 = sp + 60|0;
 $4 = sp + 56|0;
 $5 = sp + 32|0;
 $preloadDataArray = sp + 16|0;
 $objects = sp;
 $preloadDataArray2 = sp + 40|0;
 $6 = (($preloadObjects) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (__Z20GetPersistentManagerv()|0);
 $10 = HEAP32[$dependencies>>2]|0;
 $11 = (($dependencies) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 if (!($13)) {
  $108 = (($objects) + 4|0);
  HEAP32[$108>>2] = 0;
  $109 = (($objects) + 8|0);
  HEAP32[$109>>2] = 0;
  $110 = (($objects) + 4|0);
  HEAP32[$objects>>2] = $110;
  __THREW__ = 0;
  invoke_viiii(375,($this|0),($dependencies|0),($preloadObjects|0),($objects|0));
  $111 = __THREW__; __THREW__ = 0;
  $112 = $111&1;
  L6: do {
   if ($112) {
    label = 44;
   } else {
    $113 = HEAP32[$109>>2]|0;
    $114 = HEAP32[$6>>2]|0;
    $115 = ($113>>>0)>($114>>>0);
    L8: do {
     if ($115) {
      $118 = HEAP32[628512>>2]|0;
      HEAP32[$preloadDataArray2>>2] = 0;
      $119 = (($preloadDataArray2) + 4|0);
      HEAP32[$119>>2] = $118;
      $120 = (($preloadDataArray2) + 8|0);
      HEAP32[$120>>2] = 0;
      $121 = (($preloadDataArray2) + 12|0);
      HEAP32[$121>>2] = 0;
      $122 = HEAP32[$objects>>2]|0;
      $123 = ($122|0)==($110|0);
      L10: do {
       if ($123) {
        label = 57;
       } else {
        $125 = $122;
        while(1) {
         $124 = (($125) + 16|0);
         $126 = HEAP32[$124>>2]|0;
         __THREW__ = 0;
         invoke_viiii(374,0,($126|0),($preloadDataArray2|0),($scriptOnly|0));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          break;
         }
         $129 = (($125) + 4|0);
         $130 = HEAP32[$129>>2]|0;
         $131 = ($130|0)==(0|0);
         if ($131) {
          $$01$i$i = $125;
          while(1) {
           $134 = (($$01$i$i) + 8|0);
           $135 = HEAP32[$134>>2]|0;
           $136 = HEAP32[$135>>2]|0;
           $137 = ($136|0)==($$01$i$i|0);
           if ($137) {
            $$0$i$i = $135;
            break;
           } else {
            $$01$i$i = $135;
           }
          }
         } else {
          $$0$i$i$i = $130;
          while(1) {
           $132 = HEAP32[$$0$i$i$i>>2]|0;
           $133 = ($132|0)==(0|0);
           if ($133) {
            $$0$i$i = $$0$i$i$i;
            break;
           } else {
            $$0$i$i$i = $132;
           }
          }
         }
         $138 = ($$0$i$i|0)==($110|0);
         if ($138) {
          label = 57;
          break L10;
         } else {
          $125 = $$0$i$i;
         }
        }
        $139 = ___cxa_find_matching_catch()|0;
        $140 = tempRet0;
        $lpad$phi36$index = $139;$lpad$phi36$index12 = $140;
       }
      } while(0);
      do {
       if ((label|0) == 57) {
        __THREW__ = 0;
        invoke_viii(1772,0,($preloadDataArray2|0),($preloadObjects|0));
        $149 = __THREW__; __THREW__ = 0;
        $150 = $149&1;
        if ($150) {
         $141 = ___cxa_find_matching_catch()|0;
         $142 = tempRet0;
         $lpad$phi36$index = $141;$lpad$phi36$index12 = $142;
         break;
        }
        $151 = HEAP32[$121>>2]|0;
        $152 = ($151|0)>(-1);
        if (!($152)) {
         break L8;
        }
        $153 = HEAP32[$preloadDataArray2>>2]|0;
        $154 = HEAP32[$119>>2]|0;
        HEAP32[$0>>2] = $154;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($153|0),($$byval_copy24|0));
        $155 = __THREW__; __THREW__ = 0;
        $156 = $155&1;
        if ($156) {
         label = 44;
         break L6;
        }
        HEAP32[$preloadDataArray2>>2] = 0;
        break L8;
       }
      } while(0);
      $143 = HEAP32[$121>>2]|0;
      $144 = ($143|0)>(-1);
      if (!($144)) {
       $$0 = $lpad$phi36$index12;$$01 = $lpad$phi36$index;
       break L6;
      }
      $145 = HEAP32[$preloadDataArray2>>2]|0;
      $146 = HEAP32[$119>>2]|0;
      HEAP32[$1>>2] = $146;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($145|0),($$byval_copy24|0));
      $147 = __THREW__; __THREW__ = 0;
      $148 = $147&1;
      if ($148) {
       $159 = ___cxa_find_matching_catch(0|0)|0;
       $160 = tempRet0;
       ___clang_call_terminate($159);
       // unreachable;
      } else {
       HEAP32[$preloadDataArray2>>2] = 0;
       $$0 = $lpad$phi36$index12;$$01 = $lpad$phi36$index;
       break L6;
      }
     }
    } while(0);
    $157 = HEAP32[$108>>2]|0;
    __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($objects,$157);
    STACKTOP = sp;return;
   }
  } while(0);
  if ((label|0) == 44) {
   $116 = ___cxa_find_matching_catch()|0;
   $117 = tempRet0;
   $$0 = $117;$$01 = $116;
  }
  $158 = HEAP32[$108>>2]|0;
  __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($objects,$158);
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$12|0);
  // unreachable;
 }
 L41: do {
  if ($scriptOnly) {
   $14 = (($preloadObjects) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$preloadObjects>>2]|0;
   $17 = HEAP32[$6>>2]|0;
   $$idx$i$i = $17 << 2;
   $18 = $$idx$i$i >> 2;
   $19 = ($18|0)==(0);
   if ($19) {
    $21 = 0;$22 = 0;$31 = 0;$71 = 0;
   } else {
    HEAP32[$0>>2] = $15;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
    $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i,4,$$byval_copy24,0,617112,370)|0);
    $21 = $20;$22 = $$idx$i$i;$31 = $20;$71 = $18;
   }
   _memcpy(($21|0),($16|0),($22|0))|0;
   $23 = (($preloadObjects) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)>(-1);
   do {
    if ($25) {
     $26 = HEAP32[$preloadObjects>>2]|0;
     $27 = HEAP32[$14>>2]|0;
     HEAP32[$5>>2] = $27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($26|0),($$byval_copy24|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      $68 = ___cxa_find_matching_catch()|0;
      $69 = tempRet0;
      $lpad$phi26$index = $68;$lpad$phi26$index2 = $69;
      break;
     } else {
      HEAP32[$preloadObjects>>2] = 0;
      label = 9;
      break;
     }
    } else {
     label = 9;
    }
   } while(0);
   L51: do {
    if ((label|0) == 9) {
     HEAP32[$6>>2] = 0;
     HEAP32[$23>>2] = 0;
     $30 = (($31) + ($18<<2)|0);
     L53: do {
      if (!($19)) {
       $it$027 = $31;
       L55: while(1) {
        $32 = HEAP32[$it$027>>2]|0;
        __THREW__ = 0;
        $33 = (invoke_iii(2415,($9|0),($32|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
        $36 = ($33|0)==(115);
        if ($36) {
         $37 = HEAP32[$it$027>>2]|0;
         $38 = HEAP32[$6>>2]|0;
         $39 = (($38) + 1)|0;
         HEAP32[$6>>2] = $39;
         $40 = HEAP32[$23>>2]|0;
         $41 = $40 & 2147483647;
         $42 = ($39>>>0)>($41>>>0);
         if ($42) {
          $43 = $40 << 1;
          $44 = ($43|0)==(0);
          $45 = $44 ? 1 : $43;
          $46 = ($41>>>0)<($45>>>0);
          do {
           if ($46) {
            $47 = ($40|0)>(-1);
            if ($47) {
             HEAP32[$23>>2] = $45;
             $48 = HEAP32[$preloadObjects>>2]|0;
             $49 = $45 << 2;
             $50 = HEAP32[$14>>2]|0;
             HEAP32[$3>>2] = $50;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$3+0>>2]|0;
             $51 = (invoke_iiiiiiii(108,($48|0),($49|0),4,($$byval_copy24|0),0,(617112|0),370)|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break L55;
             }
             HEAP32[$preloadObjects>>2] = $51;
             break;
            } else {
             $54 = $45 << 2;
             $55 = HEAP32[$14>>2]|0;
             HEAP32[$4>>2] = $55;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$4+0>>2]|0;
             $56 = (invoke_iiiiiii(102,($54|0),4,($$byval_copy24|0),0,(617112|0),352)|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              break L55;
             }
             $59 = HEAP32[$preloadObjects>>2]|0;
             $60 = HEAP32[$6>>2]|0;
             $61 = $60 << 2;
             _memcpy(($56|0),($59|0),($61|0))|0;
             HEAP32[$23>>2] = $45;
             HEAP32[$preloadObjects>>2] = $56;
             break;
            }
           }
          } while(0);
          $$pre$i$i = HEAP32[$6>>2]|0;
          $63 = $$pre$i$i;
         } else {
          $63 = $39;
         }
         $62 = (($63) + -1)|0;
         $64 = HEAP32[$preloadObjects>>2]|0;
         $65 = (($64) + ($62<<2)|0);
         HEAP32[$65>>2] = $37;
        }
        $74 = (($it$027) + 4|0);
        $75 = ($74|0)==($30|0);
        if ($75) {
         break L53;
        } else {
         $it$027 = $74;
        }
       }
       $66 = ___cxa_find_matching_catch()|0;
       $67 = tempRet0;
       $lpad$phi26$index = $66;$lpad$phi26$index2 = $67;
       break L51;
      }
     } while(0);
     $76 = ($71|0)>(-1);
     if (!($76)) {
      break L41;
     }
     HEAP32[$0>>2] = $15;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy24);
     break L41;
    }
   } while(0);
   $70 = ($71|0)>(-1);
   if (!($70)) {
    $$1 = $lpad$phi26$index2;$$12 = $lpad$phi26$index;
    ___resumeException($$12|0);
    // unreachable;
   }
   HEAP32[$2>>2] = $15;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($31|0),($$byval_copy24|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $159 = ___cxa_find_matching_catch(0|0)|0;
    $160 = tempRet0;
    ___clang_call_terminate($159);
    // unreachable;
   } else {
    $$1 = $lpad$phi26$index2;$$12 = $lpad$phi26$index;
    ___resumeException($$12|0);
    // unreachable;
   }
  }
 } while(0);
 if (!($forceSorting)) {
  STACKTOP = sp;return;
 }
 $77 = HEAP32[628512>>2]|0;
 HEAP32[$preloadDataArray>>2] = 0;
 $78 = (($preloadDataArray) + 4|0);
 HEAP32[$78>>2] = $77;
 $79 = (($preloadDataArray) + 8|0);
 HEAP32[$79>>2] = 0;
 $80 = (($preloadDataArray) + 12|0);
 HEAP32[$80>>2] = 0;
 $81 = HEAP32[$6>>2]|0;
 $82 = ($81|0)==(0);
 L86: do {
  if ($82) {
   label = 39;
  } else {
   $83 = HEAP32[$preloadObjects>>2]|0;
   $it1$021 = $83;
   while(1) {
    $84 = HEAP32[$it1$021>>2]|0;
    __THREW__ = 0;
    invoke_viiii(374,0,($84|0),($preloadDataArray|0),($scriptOnly|0));
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     break;
    }
    $87 = (($it1$021) + 4|0);
    $88 = HEAP32[$preloadObjects>>2]|0;
    $89 = HEAP32[$6>>2]|0;
    $90 = (($88) + ($89<<2)|0);
    $91 = ($87|0)==($90|0);
    if ($91) {
     label = 39;
     break L86;
    } else {
     $it1$021 = $87;
    }
   }
   $92 = ___cxa_find_matching_catch()|0;
   $93 = tempRet0;
   $lpad$phi$index = $92;$lpad$phi$index7 = $93;
  }
 } while(0);
 do {
  if ((label|0) == 39) {
   __THREW__ = 0;
   invoke_viii(1772,0,($preloadDataArray|0),($preloadObjects|0));
   $102 = __THREW__; __THREW__ = 0;
   $103 = $102&1;
   if ($103) {
    $94 = ___cxa_find_matching_catch()|0;
    $95 = tempRet0;
    $lpad$phi$index = $94;$lpad$phi$index7 = $95;
    break;
   }
   $104 = HEAP32[$80>>2]|0;
   $105 = ($104|0)>(-1);
   if (!($105)) {
    STACKTOP = sp;return;
   }
   $106 = HEAP32[$preloadDataArray>>2]|0;
   $107 = HEAP32[$78>>2]|0;
   HEAP32[$0>>2] = $107;
   ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($106,$$byval_copy24);
   HEAP32[$preloadDataArray>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $96 = HEAP32[$80>>2]|0;
 $97 = ($96|0)>(-1);
 if (!($97)) {
  $$1 = $lpad$phi$index7;$$12 = $lpad$phi$index;
  ___resumeException($$12|0);
  // unreachable;
 }
 $98 = HEAP32[$preloadDataArray>>2]|0;
 $99 = HEAP32[$78>>2]|0;
 HEAP32[$0>>2] = $99;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($98|0),($$byval_copy24|0));
 $100 = __THREW__; __THREW__ = 0;
 $101 = $100&1;
 if ($101) {
  $159 = ___cxa_find_matching_catch(0|0)|0;
  $160 = tempRet0;
  ___clang_call_terminate($159);
  // unreachable;
 }
 HEAP32[$preloadDataArray>>2] = 0;
 $$1 = $lpad$phi$index7;$$12 = $lpad$phi$index;
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN18AssetBundleManager14AddPreloadDataEiR13dynamic_arrayINS_11PreloadDataELj8EEb($this,$instanceID,$preloadDataArray,$scriptOnly) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 $preloadDataArray = $preloadDataArray|0;
 $scriptOnly = $scriptOnly|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $preloadData = 0, $scriptOnly$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 36|0;
 $0 = sp + 32|0;
 $preloadData = sp;
 $1 = (__Z20GetPersistentManagerv()|0);
 $2 = (__ZN17PersistentManager20GetSerializedClassIDEi($1,$instanceID)|0);
 $scriptOnly$not = $scriptOnly ^ 1;
 $3 = ($2|0)==(115);
 $or$cond = $3 | $scriptOnly$not;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $4 = $3 << 31 >> 31;
 HEAP32[$preloadData>>2] = $instanceID;
 $5 = (($preloadData) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($preloadData) + 16|0);
 $7 = $6;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 $11 = (($preloadData) + 24|0);
 HEAP32[$11>>2] = $4;
 $12 = (($preloadData) + 8|0);
 (__ZN17PersistentManager38InstanceIDToSerializedObjectIdentifierEiR26SerializedObjectIdentifier($1,$instanceID,$12)|0);
 $13 = (($preloadDataArray) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 1)|0;
 HEAP32[$13>>2] = $15;
 $16 = (($preloadDataArray) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2147483647;
 $19 = ($15>>>0)>($18>>>0);
 if ($19) {
  $20 = $17 << 1;
  $21 = ($20|0)==(0);
  $22 = $21 ? 1 : $20;
  $23 = ($18>>>0)<($22>>>0);
  do {
   if ($23) {
    $24 = ($17|0)>(-1);
    if ($24) {
     HEAP32[$16>>2] = $22;
     $25 = HEAP32[$preloadDataArray>>2]|0;
     $26 = $22 << 5;
     $27 = (($preloadDataArray) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     HEAP32[$0>>2] = $28;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $29 = (__Z16realloc_internalPvji10MemLabelIdiPKci($25,$26,8,$$byval_copy1,0,617112,370)|0);
     HEAP32[$preloadDataArray>>2] = $29;
     break;
    } else {
     $30 = $22 << 5;
     $31 = (($preloadDataArray) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     HEAP32[$0>>2] = $32;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($30,8,$$byval_copy1,0,617112,352)|0);
     $34 = HEAP32[$preloadDataArray>>2]|0;
     $35 = HEAP32[$13>>2]|0;
     $36 = $35 << 5;
     _memcpy(($33|0),($34|0),($36|0))|0;
     HEAP32[$16>>2] = $22;
     HEAP32[$preloadDataArray>>2] = $33;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$13>>2]|0;
  $38 = $$pre$i$i;
 } else {
  $38 = $15;
 }
 $37 = (($38) + -1)|0;
 $39 = HEAP32[$preloadDataArray>>2]|0;
 $40 = (($39) + ($37<<5)|0);
 ;HEAP32[$40+0>>2]=HEAP32[$preloadData+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$preloadData+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$preloadData+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$preloadData+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$preloadData+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$preloadData+20>>2]|0;HEAP32[$40+24>>2]=HEAP32[$preloadData+24>>2]|0;
 STACKTOP = sp;return;
}
function __ZN18AssetBundleManager20SortPreloadDataArrayER13dynamic_arrayINS_11PreloadDataELj8EERS0_IiLj4EE($this,$preloadDataArray,$preloadObjects) {
 $this = $this|0;
 $preloadDataArray = $preloadDataArray|0;
 $preloadObjects = $preloadObjects|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $it$03 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$preloadDataArray>>2]|0;
 $3 = (($preloadDataArray) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + ($4<<5)|0);
 __ZNSt3__16__sortIRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEvT0_S6_T_($2,$5,$0);
 $6 = HEAP32[$3>>2]|0;
 $7 = (($preloadObjects) + 8|0);
 HEAP32[$7>>2] = $6;
 $8 = (($preloadObjects) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($10>>>0)<($6>>>0);
 do {
  if ($11) {
   $12 = ($9|0)>(-1);
   if ($12) {
    HEAP32[$8>>2] = $6;
    $13 = HEAP32[$preloadObjects>>2]|0;
    $14 = $6 << 2;
    $15 = (($preloadObjects) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$1>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,617112,370)|0);
    HEAP32[$preloadObjects>>2] = $17;
    break;
   } else {
    $18 = $6 << 2;
    $19 = (($preloadObjects) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$1>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,617112,352)|0);
    $22 = HEAP32[$preloadObjects>>2]|0;
    $23 = HEAP32[$7>>2]|0;
    $24 = $23 << 2;
    _memcpy(($21|0),($22|0),($24|0))|0;
    HEAP32[$8>>2] = $6;
    HEAP32[$preloadObjects>>2] = $21;
    break;
   }
  }
 } while(0);
 $25 = HEAP32[$3>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$preloadDataArray>>2]|0;
 $28 = HEAP32[$preloadObjects>>2]|0;
 $i$02 = 0;$it$03 = $27;
 while(1) {
  $29 = HEAP32[$it$03>>2]|0;
  $30 = (($28) + ($i$02<<2)|0);
  HEAP32[$30>>2] = $29;
  $31 = (($it$03) + 32|0);
  $32 = (($i$02) + 1)|0;
  $33 = HEAP32[$3>>2]|0;
  $34 = (($27) + ($33<<5)|0);
  $35 = ($31|0)==($34|0);
  if ($35) {
   break;
  } else {
   $i$02 = $32;$it$03 = $31;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AssetBundleManager29CollectPreloadDataRecursivelyERKNSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEERK13dynamic_arrayIiLj4EERNS0_3setIiNS0_4lessIiEENS3_IiEEEE($this,$dependencies,$preloadObjects,$objects) {
 $this = $this|0;
 $dependencies = $dependencies|0;
 $preloadObjects = $preloadObjects|0;
 $objects = $objects|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $it$05 = 0, $phitmp = 0, $tempPreloadObjects = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $0 = sp;
 $1 = sp + 8|0;
 $tempPreloadObjects = sp + 16|0;
 $2 = HEAP32[628512>>2]|0;
 HEAP32[$tempPreloadObjects>>2] = 0;
 $3 = (($tempPreloadObjects) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (($tempPreloadObjects) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($tempPreloadObjects) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($preloadObjects) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 do {
  if (!($8)) {
   $9 = HEAP32[$preloadObjects>>2]|0;
   $10 = (($1) + 4|0);
   $it$05 = $9;
   while(1) {
    __THREW__ = 0;
    invoke_viii(1773,($1|0),($objects|0),($it$05|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP8[$10>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if (!($14)) {
     $23 = HEAP32[$it$05>>2]|0;
     __THREW__ = 0;
     $24 = (invoke_iiiii(240,($this|0),($23|0),($dependencies|0),($tempPreloadObjects|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = ($24|0)==(0|0);
     if (!($27)) {
      $28 = (($24) + 88|0);
      __THREW__ = 0;
      invoke_viiii(375,($this|0),($28|0),($tempPreloadObjects|0),($objects|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      HEAP32[$4>>2] = 0;
     }
    }
    $31 = (($it$05) + 4|0);
    $32 = HEAP32[$preloadObjects>>2]|0;
    $33 = HEAP32[$6>>2]|0;
    $34 = (($32) + ($33<<2)|0);
    $35 = ($31|0)==($34|0);
    if ($35) {
     label = 13;
     break;
    } else {
     $it$05 = $31;
    }
   }
   if ((label|0) == 13) {
    $$pre = HEAP32[$5>>2]|0;
    $phitmp = ($$pre|0)>(-1);
    if ($phitmp) {
     break;
    }
    STACKTOP = sp;return;
   }
   $15 = ___cxa_find_matching_catch()|0;
   $16 = tempRet0;
   $17 = HEAP32[$5>>2]|0;
   $18 = ($17|0)>(-1);
   if (!($18)) {
    ___resumeException($15|0);
    // unreachable;
   }
   $19 = HEAP32[$tempPreloadObjects>>2]|0;
   $20 = HEAP32[$3>>2]|0;
   HEAP32[$0>>2] = $20;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($19|0),($$byval_copy1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $38 = ___cxa_find_matching_catch(0|0)|0;
    $39 = tempRet0;
    ___clang_call_terminate($38);
    // unreachable;
   }
   HEAP32[$tempPreloadObjects>>2] = 0;
   ___resumeException($15|0);
   // unreachable;
  }
 } while(0);
 $36 = HEAP32[$tempPreloadObjects>>2]|0;
 $37 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $37;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($36,$$byval_copy1);
 HEAP32[$tempPreloadObjects>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18AssetBundleManager18CollectPreloadDataEiRKNSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEER13dynamic_arrayIiLj4EE($this,$instanceID,$dependencies,$preloadObjects) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 $dependencies = $dependencies|0;
 $preloadObjects = $preloadObjects|0;
 var $$ = 0, $$0 = 0, $$neg2$i$i$i$i$i = 0, $$pre = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$dependencies>>2]|0;
 $1 = (($dependencies) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 4|0);
 $5 = (($this) + 8|0);
 $14 = $0;$37 = $2;
 while(1) {
  $6 = HEAP32[$4>>2]|0;
  $7 = HEAP32[$5>>2]|0;
  $8 = $7;
  $9 = $6;
  $10 = (($8) - ($9))|0;
  $11 = $10 >> 3;
  $12 = ($11|0)==(0);
  if ($12) {
   $25 = $6;
  } else {
   $13 = HEAP32[$14>>2]|0;
   $17 = $6;$__len$03$i$i$i$i$i = $11;
   while(1) {
    $15 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
    $16 = (($17) + ($15<<3)|0);
    $18 = HEAP32[$16>>2]|0;
    $19 = (_strcmp($18,$13)|0);
    $20 = ($19|0)<(0);
    if ($20) {
     $$sum$i$i$i$i$i = (($15) + 1)|0;
     $21 = (($17) + ($$sum$i$i$i$i$i<<3)|0);
     $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
     $22 = (($$neg2$i$i$i$i$i) - ($15))|0;
     $38 = $21;$__len$0$be$i$i$i$i$i = $22;
    } else {
     $38 = $17;$__len$0$be$i$i$i$i$i = $15;
    }
    $23 = ($__len$0$be$i$i$i$i$i|0)==(0);
    if ($23) {
     $25 = $38;
     break;
    } else {
     $17 = $38;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
    }
   }
  }
  $24 = ($25|0)==($7|0);
  if ($24) {
   $36 = $37;
  } else {
   $26 = HEAP32[$14>>2]|0;
   $27 = HEAP32[$25>>2]|0;
   $28 = (_strcmp($26,$27)|0);
   $29 = ($28|0)<(0);
   $$ = $29 ? $7 : $25;
   $30 = ($$|0)==($7|0);
   if ($30) {
    $36 = $37;
   } else {
    $31 = (($$) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (__ZN11AssetBundle14GetPreloadDataEiR13dynamic_arrayIiLj4EE($32,$instanceID,$preloadObjects)|0);
    if ($33) {
     $$0 = $32;
     label = 13;
     break;
    }
    $$pre = HEAP32[$1>>2]|0;
    $36 = $$pre;
   }
  }
  $34 = (($14) + 4|0);
  $35 = ($34|0)==($36|0);
  if ($35) {
   $$0 = 0;
   label = 13;
   break;
  } else {
   $14 = $34;$37 = $36;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z21GetAssetBundleManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[617120>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE15__insert_uniqueERKi($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $31 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $30 = (($agg$result) + 4|0);
  HEAP8[$30>>0] = $31;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(20)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__v>>2]|0;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $31 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $30 = (($agg$result) + 4|0);
 HEAP8[$30>>0] = $31;
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$038 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0;
 var $__j$036 = 0, $__j$036$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i24 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -32|0);
  $2 = (($$01$ph) + -64|0);
  $3 = (($$01$ph) + -8|0);
  $4 = (($$01$ph) + -24|0);
  $5 = (($$01$ph) + -16|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $6 = $$0;
   $7 = (($0) - ($6))|0;
   $8 = $7 >> 5;
   switch ($8|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 10;
    break L1;
    break;
   }
   case 5:  {
    label = 12;
    break L1;
    break;
   }
   case 4:  {
    label = 11;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 91;
    break L1;
    break;
   }
   default: {
   }
   }
   $43 = ($7|0)<(992);
   if ($43) {
    label = 14;
    break L1;
   }
   $44 = ($7|0)>(31968);
   $45 = (($8|0) / 2)&-1;
   $46 = (($$0) + ($45<<5)|0);
   if ($44) {
    $47 = (($8|0) / 4)&-1;
    $48 = (($$0) + ($47<<5)|0);
    $$sum = (($47) + ($45))|0;
    $49 = (($$0) + ($$sum<<5)|0);
    $50 = (__ZNSt3__17__sort5IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_S6_S6_T_($$0,$48,$46,$49,$1,0)|0);
    $__n_swaps$0 = $50;
   } else {
    $51 = (__ZNSt3__17__sort3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_T_($$0,$46,$1,0)|0);
    $__n_swaps$0 = $51;
   }
   $52 = (($$0) + 24|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ((($$0) + ($45<<5)|0) + 24|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($53|0)==($55|0);
   if ($56) {
    $58 = (($$0) + 8|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ((($$0) + ($45<<5)|0) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($59|0)<($61|0);
    if ($62) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $63 = ($59|0)>($61|0);
     if ($63) {
      label = 23;
     } else {
      $64 = (($$0) + 16|0);
      $65 = $64;
      $66 = $65;
      $67 = HEAP32[$66>>2]|0;
      $68 = (($65) + 4)|0;
      $69 = $68;
      $70 = HEAP32[$69>>2]|0;
      $71 = ((($$0) + ($45<<5)|0) + 16|0);
      $72 = $71;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 4)|0;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = ($70|0)<($77|0);
      $79 = ($70|0)==($77|0);
      $80 = ($67>>>0)<($74>>>0);
      $81 = $79 & $80;
      $82 = $78 | $81;
      if ($82) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
      } else {
       label = 23;
      }
     }
    }
   } else {
    $57 = ($53|0)<($55|0);
    if ($57) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     label = 23;
    }
   }
   L16: do {
    if ((label|0) == 23) {
     label = 0;
     $83 = ($$0|0)==($2|0);
     L18: do {
      if (!($83)) {
       $84 = ((($$0) + ($45<<5)|0) + 8|0);
       $85 = ((($$0) + ($45<<5)|0) + 16|0);
       $236 = $2;$__j$036 = $1;
       while(1) {
        $208 = (($__j$036) + -8|0);
        $209 = HEAP32[$208>>2]|0;
        $210 = ($209|0)==($55|0);
        if ($210) {
         $212 = (($__j$036) + -24|0);
         $213 = HEAP32[$212>>2]|0;
         $214 = HEAP32[$84>>2]|0;
         $215 = ($213|0)<($214|0);
         if ($215) {
          break;
         }
         $216 = ($213|0)>($214|0);
         if (!($216)) {
          $217 = (($__j$036) + -16|0);
          $218 = $217;
          $219 = $218;
          $220 = HEAP32[$219>>2]|0;
          $221 = (($218) + 4)|0;
          $222 = $221;
          $223 = HEAP32[$222>>2]|0;
          $224 = $85;
          $225 = $224;
          $226 = HEAP32[$225>>2]|0;
          $227 = (($224) + 4)|0;
          $228 = $227;
          $229 = HEAP32[$228>>2]|0;
          $230 = ($223|0)<($229|0);
          $231 = ($223|0)==($229|0);
          $232 = ($220>>>0)<($226>>>0);
          $233 = $231 & $232;
          $234 = $230 | $233;
          if ($234) {
           break;
          }
         }
        } else {
         $211 = ($209|0)<($55|0);
         if ($211) {
          break;
         }
        }
        $235 = (($236) + -32|0);
        $237 = ($$0|0)==($235|0);
        if ($237) {
         break L18;
        } else {
         $__j$036$phi = $236;$236 = $235;$__j$036 = $__j$036$phi;
        }
       }
       ;HEAP32[$__t$i24+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i24+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i24+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i24+28>>2]=HEAP32[$$0+28>>2]|0;
       ;HEAP32[$$0+0>>2]=HEAP32[$236+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$236+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$236+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$236+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$236+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$236+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$236+24>>2]|0;
       ;HEAP32[$236+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$236+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$236+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$236+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$236+16>>2]=HEAP32[$__t$i24+16>>2]|0;HEAP32[$236+20>>2]=HEAP32[$__t$i24+20>>2]|0;HEAP32[$236+24>>2]=HEAP32[$__t$i24+24>>2]|0;
       $238 = (($__n_swaps$0) + 1)|0;
       $__j$3 = $236;$__n_swaps$3 = $238;
       break L16;
      }
     } while(0);
     $86 = (($$0) + 32|0);
     $87 = HEAP32[$3>>2]|0;
     $88 = ($53|0)==($87|0);
     if ($88) {
      $90 = (($$0) + 8|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = HEAP32[$4>>2]|0;
      $93 = ($91|0)<($92|0);
      if ($93) {
       $__i$1 = $86;
      } else {
       $94 = ($91|0)>($92|0);
       if ($94) {
        label = 30;
       } else {
        $95 = (($$0) + 16|0);
        $96 = $95;
        $97 = $96;
        $98 = HEAP32[$97>>2]|0;
        $99 = (($96) + 4)|0;
        $100 = $99;
        $101 = HEAP32[$100>>2]|0;
        $102 = $5;
        $103 = $102;
        $104 = HEAP32[$103>>2]|0;
        $105 = (($102) + 4)|0;
        $106 = $105;
        $107 = HEAP32[$106>>2]|0;
        $108 = ($101|0)<($107|0);
        $109 = ($101|0)==($107|0);
        $110 = ($98>>>0)<($104>>>0);
        $111 = $109 & $110;
        $112 = $108 | $111;
        if ($112) {
         $__i$1 = $86;
        } else {
         label = 30;
        }
       }
      }
     } else {
      $89 = ($53|0)<($87|0);
      if ($89) {
       $__i$1 = $86;
      } else {
       label = 30;
      }
     }
     if ((label|0) == 30) {
      label = 0;
      $113 = ($86|0)==($1|0);
      if ($113) {
       label = 91;
       break L1;
      }
      $114 = (($$0) + 8|0);
      $115 = (($$0) + 16|0);
      $__i$038 = $86;
      while(1) {
       $116 = (($__i$038) + 24|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ($53|0)==($117|0);
       if ($118) {
        $120 = HEAP32[$114>>2]|0;
        $121 = (($__i$038) + 8|0);
        $122 = HEAP32[$121>>2]|0;
        $123 = ($120|0)<($122|0);
        if ($123) {
         break;
        }
        $124 = ($120|0)>($122|0);
        if (!($124)) {
         $125 = $115;
         $126 = $125;
         $127 = HEAP32[$126>>2]|0;
         $128 = (($125) + 4)|0;
         $129 = $128;
         $130 = HEAP32[$129>>2]|0;
         $131 = (($__i$038) + 16|0);
         $132 = $131;
         $133 = $132;
         $134 = HEAP32[$133>>2]|0;
         $135 = (($132) + 4)|0;
         $136 = $135;
         $137 = HEAP32[$136>>2]|0;
         $138 = ($130|0)<($137|0);
         $139 = ($130|0)==($137|0);
         $140 = ($127>>>0)<($134>>>0);
         $141 = $139 & $140;
         $142 = $138 | $141;
         if ($142) {
          break;
         }
        }
       } else {
        $119 = ($53|0)<($117|0);
        if ($119) {
         break;
        }
       }
       $144 = (($__i$038) + 32|0);
       $145 = ($144|0)==($1|0);
       if ($145) {
        label = 91;
        break L1;
       } else {
        $__i$038 = $144;
       }
      }
      ;HEAP32[$__t$i24+0>>2]=HEAP32[$__i$038+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$__i$038+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$__i$038+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$__i$038+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$__i$038+16>>2]|0;HEAP32[$__t$i24+20>>2]=HEAP32[$__i$038+20>>2]|0;HEAP32[$__t$i24+24>>2]=HEAP32[$__i$038+24>>2]|0;HEAP32[$__t$i24+28>>2]=HEAP32[$__i$038+28>>2]|0;
      ;HEAP32[$__i$038+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$038+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$038+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$038+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__i$038+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__i$038+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$__i$038+24>>2]=HEAP32[$1+24>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i24+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i24+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i24+24>>2]|0;
      $143 = (($__i$038) + 32|0);
      $__i$1 = $143;
     }
     $146 = ($__i$1|0)==($1|0);
     if ($146) {
      label = 91;
      break L1;
     }
     $147 = (($$0) + 8|0);
     $148 = (($$0) + 16|0);
     $__i$2$ph = $__i$1;$__j$1$ph = $1;
     while(1) {
      $149 = HEAP32[$52>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $150 = (($__i$2) + 24|0);
       $151 = HEAP32[$150>>2]|0;
       $152 = ($149|0)==($151|0);
       if ($152) {
        $154 = HEAP32[$147>>2]|0;
        $155 = (($__i$2) + 8|0);
        $156 = HEAP32[$155>>2]|0;
        $157 = ($154|0)<($156|0);
        if ($157) {
         $__j$2 = $__j$1$ph;
         break;
        }
        $158 = ($154|0)>($156|0);
        if (!($158)) {
         $159 = $148;
         $160 = $159;
         $161 = HEAP32[$160>>2]|0;
         $162 = (($159) + 4)|0;
         $163 = $162;
         $164 = HEAP32[$163>>2]|0;
         $165 = (($__i$2) + 16|0);
         $166 = $165;
         $167 = $166;
         $168 = HEAP32[$167>>2]|0;
         $169 = (($166) + 4)|0;
         $170 = $169;
         $171 = HEAP32[$170>>2]|0;
         $172 = ($164|0)<($171|0);
         $173 = ($164|0)==($171|0);
         $174 = ($161>>>0)<($168>>>0);
         $175 = $173 & $174;
         $176 = $172 | $175;
         if ($176) {
          $__j$2 = $__j$1$ph;
          break;
         }
        }
       } else {
        $153 = ($149|0)<($151|0);
        if ($153) {
         $__j$2 = $__j$1$ph;
         break;
        }
       }
       $177 = (($__i$2) + 32|0);
       $__i$2 = $177;
      }
      while(1) {
       $178 = (($__j$2) + -32|0);
       $179 = (($__j$2) + -8|0);
       $180 = HEAP32[$179>>2]|0;
       $181 = ($149|0)==($180|0);
       if (!($181)) {
        $182 = ($149|0)<($180|0);
        if ($182) {
         $__j$2 = $178;
         continue;
        } else {
         break;
        }
       }
       $183 = HEAP32[$147>>2]|0;
       $184 = (($__j$2) + -24|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = ($183|0)<($185|0);
       if ($186) {
        $__j$2 = $178;
        continue;
       }
       $187 = ($183|0)>($185|0);
       if ($187) {
        break;
       }
       $188 = $148;
       $189 = $188;
       $190 = HEAP32[$189>>2]|0;
       $191 = (($188) + 4)|0;
       $192 = $191;
       $193 = HEAP32[$192>>2]|0;
       $194 = (($__j$2) + -16|0);
       $195 = $194;
       $196 = $195;
       $197 = HEAP32[$196>>2]|0;
       $198 = (($195) + 4)|0;
       $199 = $198;
       $200 = HEAP32[$199>>2]|0;
       $201 = ($193|0)<($200|0);
       $202 = ($193|0)==($200|0);
       $203 = ($190>>>0)<($197>>>0);
       $204 = $202 & $203;
       $205 = $201 | $204;
       if ($205) {
        $__j$2 = $178;
       } else {
        break;
       }
      }
      $206 = ($__i$2>>>0)<($178>>>0);
      if (!($206)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i24+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$__i$2+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$__i$2+16>>2]|0;HEAP32[$__t$i24+20>>2]=HEAP32[$__i$2+20>>2]|0;HEAP32[$__t$i24+24>>2]=HEAP32[$__i$2+24>>2]|0;HEAP32[$__t$i24+28>>2]=HEAP32[$__i$2+28>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$178+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$178+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$178+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$178+12>>2]|0;HEAP32[$__i$2+16>>2]=HEAP32[$178+16>>2]|0;HEAP32[$__i$2+20>>2]=HEAP32[$178+20>>2]|0;HEAP32[$__i$2+24>>2]=HEAP32[$178+24>>2]|0;
      ;HEAP32[$178+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$178+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$178+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$178+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$178+16>>2]=HEAP32[$__t$i24+16>>2]|0;HEAP32[$178+20>>2]=HEAP32[$__t$i24+20>>2]|0;HEAP32[$178+24>>2]=HEAP32[$__t$i24+24>>2]|0;
      $207 = (($__i$2) + 32|0);
      $__i$2$ph = $207;$__j$1$ph = $178;
     }
    }
   } while(0);
   $239 = (($$0) + 32|0);
   $240 = ($239>>>0)<($__j$3>>>0);
   L69: do {
    if ($240) {
     $__i$3$ph = $239;$__j$4$ph = $__j$3;$__m$0$ph = $46;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $241 = (($__m$0$ph) + 24|0);
      $242 = HEAP32[$241>>2]|0;
      $243 = (($__m$0$ph) + 8|0);
      $244 = (($__m$0$ph) + 16|0);
      $__i$3 = $__i$3$ph;
      while(1) {
       $245 = (($__i$3) + 24|0);
       $246 = HEAP32[$245>>2]|0;
       $247 = ($246|0)==($242|0);
       if ($247) {
        $249 = (($__i$3) + 8|0);
        $250 = HEAP32[$249>>2]|0;
        $251 = HEAP32[$243>>2]|0;
        $252 = ($250|0)<($251|0);
        if (!($252)) {
         $253 = ($250|0)>($251|0);
         if ($253) {
          $__j$5 = $__j$4$ph;
          break;
         }
         $254 = (($__i$3) + 16|0);
         $255 = $254;
         $256 = $255;
         $257 = HEAP32[$256>>2]|0;
         $258 = (($255) + 4)|0;
         $259 = $258;
         $260 = HEAP32[$259>>2]|0;
         $261 = $244;
         $262 = $261;
         $263 = HEAP32[$262>>2]|0;
         $264 = (($261) + 4)|0;
         $265 = $264;
         $266 = HEAP32[$265>>2]|0;
         $267 = ($260|0)<($266|0);
         $268 = ($260|0)==($266|0);
         $269 = ($257>>>0)<($263>>>0);
         $270 = $268 & $269;
         $271 = $267 | $270;
         if (!($271)) {
          $__j$5 = $__j$4$ph;
          break;
         }
        }
       } else {
        $248 = ($246|0)<($242|0);
        if (!($248)) {
         $__j$5 = $__j$4$ph;
         break;
        }
       }
       $272 = (($__i$3) + 32|0);
       $__i$3 = $272;
      }
      while(1) {
       $273 = (($__j$5) + -32|0);
       $274 = (($__j$5) + -8|0);
       $275 = HEAP32[$274>>2]|0;
       $276 = ($275|0)==($242|0);
       if (!($276)) {
        $277 = ($275|0)<($242|0);
        if ($277) {
         break;
        } else {
         $__j$5 = $273;
         continue;
        }
       }
       $278 = (($__j$5) + -24|0);
       $279 = HEAP32[$278>>2]|0;
       $280 = HEAP32[$243>>2]|0;
       $281 = ($279|0)<($280|0);
       if ($281) {
        break;
       }
       $282 = ($279|0)>($280|0);
       if ($282) {
        $__j$5 = $273;
        continue;
       }
       $283 = (($__j$5) + -16|0);
       $284 = $283;
       $285 = $284;
       $286 = HEAP32[$285>>2]|0;
       $287 = (($284) + 4)|0;
       $288 = $287;
       $289 = HEAP32[$288>>2]|0;
       $290 = $244;
       $291 = $290;
       $292 = HEAP32[$291>>2]|0;
       $293 = (($290) + 4)|0;
       $294 = $293;
       $295 = HEAP32[$294>>2]|0;
       $296 = ($289|0)<($295|0);
       $297 = ($289|0)==($295|0);
       $298 = ($286>>>0)<($292>>>0);
       $299 = $297 & $298;
       $300 = $296 | $299;
       if ($300) {
        break;
       } else {
        $__j$5 = $273;
       }
      }
      $301 = ($__i$3>>>0)>($273>>>0);
      if ($301) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L69;
      }
      ;HEAP32[$__t$i24+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$__i$3+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$__i$3+16>>2]|0;HEAP32[$__t$i24+20>>2]=HEAP32[$__i$3+20>>2]|0;HEAP32[$__t$i24+24>>2]=HEAP32[$__i$3+24>>2]|0;HEAP32[$__t$i24+28>>2]=HEAP32[$__i$3+28>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$273+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$273+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$273+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$273+12>>2]|0;HEAP32[$__i$3+16>>2]=HEAP32[$273+16>>2]|0;HEAP32[$__i$3+20>>2]=HEAP32[$273+20>>2]|0;HEAP32[$__i$3+24>>2]=HEAP32[$273+24>>2]|0;
      ;HEAP32[$273+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$273+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$273+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$273+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$273+16>>2]=HEAP32[$__t$i24+16>>2]|0;HEAP32[$273+20>>2]=HEAP32[$__t$i24+20>>2]|0;HEAP32[$273+24>>2]=HEAP32[$__t$i24+24>>2]|0;
      $302 = (($__n_swaps$4$ph) + 1)|0;
      $303 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $303 ? $273 : $__m$0$ph;
      $304 = (($__i$3) + 32|0);
      $__i$3$ph = $304;$__j$4$ph = $273;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $302;
     }
    } else {
     $__i$4 = $239;$__m$2 = $46;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $305 = ($__i$4|0)==($__m$2|0);
   do {
    if ($305) {
     $__n_swaps$6 = $__n_swaps$5;
    } else {
     $306 = (($__m$2) + 24|0);
     $307 = HEAP32[$306>>2]|0;
     $308 = (($__i$4) + 24|0);
     $309 = HEAP32[$308>>2]|0;
     $310 = ($307|0)==($309|0);
     if ($310) {
      $312 = (($__m$2) + 8|0);
      $313 = HEAP32[$312>>2]|0;
      $314 = (($__i$4) + 8|0);
      $315 = HEAP32[$314>>2]|0;
      $316 = ($313|0)<($315|0);
      if (!($316)) {
       $317 = ($313|0)>($315|0);
       if ($317) {
        $__n_swaps$6 = $__n_swaps$5;
        break;
       }
       $318 = (($__m$2) + 16|0);
       $319 = $318;
       $320 = $319;
       $321 = HEAP32[$320>>2]|0;
       $322 = (($319) + 4)|0;
       $323 = $322;
       $324 = HEAP32[$323>>2]|0;
       $325 = (($__i$4) + 16|0);
       $326 = $325;
       $327 = $326;
       $328 = HEAP32[$327>>2]|0;
       $329 = (($326) + 4)|0;
       $330 = $329;
       $331 = HEAP32[$330>>2]|0;
       $332 = ($324|0)<($331|0);
       $333 = ($324|0)==($331|0);
       $334 = ($321>>>0)<($328>>>0);
       $335 = $333 & $334;
       $336 = $332 | $335;
       if (!($336)) {
        $__n_swaps$6 = $__n_swaps$5;
        break;
       }
      }
     } else {
      $311 = ($307|0)<($309|0);
      if (!($311)) {
       $__n_swaps$6 = $__n_swaps$5;
       break;
      }
     }
     ;HEAP32[$__t$i24+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$__i$4+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$__i$4+16>>2]|0;HEAP32[$__t$i24+20>>2]=HEAP32[$__i$4+20>>2]|0;HEAP32[$__t$i24+24>>2]=HEAP32[$__i$4+24>>2]|0;HEAP32[$__t$i24+28>>2]=HEAP32[$__i$4+28>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;HEAP32[$__i$4+16>>2]=HEAP32[$__m$2+16>>2]|0;HEAP32[$__i$4+20>>2]=HEAP32[$__m$2+20>>2]|0;HEAP32[$__i$4+24>>2]=HEAP32[$__m$2+24>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$__m$2+16>>2]=HEAP32[$__t$i24+16>>2]|0;HEAP32[$__m$2+20>>2]=HEAP32[$__t$i24+20>>2]|0;HEAP32[$__m$2+24>>2]=HEAP32[$__t$i24+24>>2]|0;
     $337 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $337;
    }
   } while(0);
   $338 = ($__n_swaps$6|0)==(0);
   if ($338) {
    $339 = (__ZNSt3__127__insertion_sort_incompleteIRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEbT0_S6_T_($$0,$__i$4,0)|0);
    $340 = (($__i$4) + 32|0);
    $341 = (__ZNSt3__127__insertion_sort_incompleteIRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEbT0_S6_T_($340,$$01$ph,0)|0);
    if ($341) {
     label = 86;
     break;
    }
    if ($339) {
     $$0 = $340;
     continue;
    }
   }
   $342 = $__i$4;
   $343 = (($342) - ($6))|0;
   $344 = (($0) - ($342))|0;
   $345 = ($343|0)<($344|0);
   if (!($345)) {
    label = 90;
    break;
   }
   __ZNSt3__16__sortIRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEvT0_S6_T_($$0,$__i$4,$__comp);
   $346 = (($__i$4) + 32|0);
   $$0 = $346;
  }
  if ((label|0) == 86) {
   label = 0;
   if ($339) {
    label = 91;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 90) {
   label = 0;
   $347 = (($__i$4) + 32|0);
   __ZNSt3__16__sortIRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEvT0_S6_T_($347,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $9 = HEAP32[$3>>2]|0;
  $10 = (($$0) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if ($12) {
   $14 = HEAP32[$4>>2]|0;
   $15 = (($$0) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14|0)<($16|0);
   if (!($17)) {
    $18 = ($14|0)>($16|0);
    if ($18) {
     STACKTOP = sp;return;
    }
    $19 = $5;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    $22 = (($19) + 4)|0;
    $23 = $22;
    $24 = HEAP32[$23>>2]|0;
    $25 = (($$0) + 16|0);
    $26 = $25;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + 4)|0;
    $30 = $29;
    $31 = HEAP32[$30>>2]|0;
    $32 = ($24|0)<($31|0);
    $33 = ($24|0)==($31|0);
    $34 = ($21>>>0)<($28>>>0);
    $35 = $33 & $34;
    $36 = $32 | $35;
    if (!($36)) {
     STACKTOP = sp;return;
    }
   }
  } else {
   $13 = ($9|0)<($11|0);
   if (!($13)) {
    STACKTOP = sp;return;
   }
  }
  ;HEAP32[$__t$i24+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i24+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i24+24>>2]=HEAP32[$$0+24>>2]|0;HEAP32[$__t$i24+28>>2]=HEAP32[$$0+28>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$1+24>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i24+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i24+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i24+24>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  $37 = (($$0) + 32|0);
  (__ZNSt3__17__sort3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_T_($$0,$37,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  $38 = (($$0) + 32|0);
  $39 = (($$0) + 64|0);
  (__ZNSt3__17__sort4IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_S6_T_($$0,$38,$39,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  $40 = (($$0) + 32|0);
  $41 = (($$0) + 64|0);
  $42 = (($$0) + 96|0);
  (__ZNSt3__17__sort5IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_S6_S6_T_($$0,$40,$41,$42,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  __ZNSt3__118__insertion_sort_3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEvT0_S6_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 91) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $$0$i = 0, $$0$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__t$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i8 = sp;
 $0 = (($__y) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__x) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $6 = (($__y) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($__x) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)<($9|0);
  if ($10) {
   $$0$i = 1;
  } else {
   $11 = ($7|0)>($9|0);
   if ($11) {
    $$0$i = 0;
   } else {
    $12 = (($__y) + 16|0);
    $13 = $12;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + 4)|0;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__x) + 16|0);
    $20 = $19;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + 4)|0;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = ($18|0)<($25|0);
    $27 = ($18|0)==($25|0);
    $28 = ($15>>>0)<($22>>>0);
    $29 = $27 & $28;
    $30 = $26 | $29;
    $$0$i = $30;
   }
  }
 } else {
  $5 = ($1|0)<($3|0);
  $$0$i = $5;
 }
 $31 = (($__z) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==($1|0);
 if ($33) {
  $35 = (($__z) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($__y) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($36|0)<($38|0);
  if ($39) {
   $$0$i9 = 1;
  } else {
   $40 = ($36|0)>($38|0);
   if ($40) {
    $$0$i9 = 0;
   } else {
    $41 = (($__z) + 16|0);
    $42 = $41;
    $43 = $42;
    $44 = HEAP32[$43>>2]|0;
    $45 = (($42) + 4)|0;
    $46 = $45;
    $47 = HEAP32[$46>>2]|0;
    $48 = (($__y) + 16|0);
    $49 = $48;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = (($49) + 4)|0;
    $53 = $52;
    $54 = HEAP32[$53>>2]|0;
    $55 = ($47|0)<($54|0);
    $56 = ($47|0)==($54|0);
    $57 = ($44>>>0)<($51>>>0);
    $58 = $56 & $57;
    $59 = $55 | $58;
    $$0$i9 = $59;
   }
  }
 } else {
  $34 = ($32|0)<($1|0);
  $$0$i9 = $34;
 }
 if (!($$0$i)) {
  if (!($$0$i9)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i8+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__t$i8+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__t$i8+24>>2]=HEAP32[$__y+24>>2]|0;HEAP32[$__t$i8+28>>2]=HEAP32[$__y+28>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__z+24>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i8+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i8+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i8+24>>2]|0;
  $60 = HEAP32[$0>>2]|0;
  $61 = HEAP32[$2>>2]|0;
  $62 = ($60|0)==($61|0);
  if ($62) {
   $64 = (($__y) + 8|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($__x) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($65|0)<($67|0);
   if (!($68)) {
    $69 = ($65|0)>($67|0);
    if ($69) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $70 = (($__y) + 16|0);
    $71 = $70;
    $72 = $71;
    $73 = HEAP32[$72>>2]|0;
    $74 = (($71) + 4)|0;
    $75 = $74;
    $76 = HEAP32[$75>>2]|0;
    $77 = (($__x) + 16|0);
    $78 = $77;
    $79 = $78;
    $80 = HEAP32[$79>>2]|0;
    $81 = (($78) + 4)|0;
    $82 = $81;
    $83 = HEAP32[$82>>2]|0;
    $84 = ($76|0)<($83|0);
    $85 = ($76|0)==($83|0);
    $86 = ($73>>>0)<($80>>>0);
    $87 = $85 & $86;
    $88 = $84 | $87;
    if (!($88)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   $63 = ($60|0)<($61|0);
   if (!($63)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i8+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i8+24>>2]=HEAP32[$__x+24>>2]|0;HEAP32[$__t$i8+28>>2]=HEAP32[$__x+28>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__y+24>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i8+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__t$i8+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__t$i8+24>>2]|0;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($$0$i9) {
  ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i8+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i8+24>>2]=HEAP32[$__x+24>>2]|0;HEAP32[$__t$i8+28>>2]=HEAP32[$__x+28>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__z+24>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i8+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i8+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i8+24>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i8+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i8+24>>2]=HEAP32[$__x+24>>2]|0;HEAP32[$__t$i8+28>>2]=HEAP32[$__x+28>>2]|0;
 ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__y+24>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i8+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__t$i8+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__t$i8+24>>2]|0;
 $89 = HEAP32[$31>>2]|0;
 $90 = HEAP32[$0>>2]|0;
 $91 = ($89|0)==($90|0);
 if ($91) {
  $93 = (($__z) + 8|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (($__y) + 8|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ($94|0)<($96|0);
  if (!($97)) {
   $98 = ($94|0)>($96|0);
   if ($98) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $99 = (($__z) + 16|0);
   $100 = $99;
   $101 = $100;
   $102 = HEAP32[$101>>2]|0;
   $103 = (($100) + 4)|0;
   $104 = $103;
   $105 = HEAP32[$104>>2]|0;
   $106 = (($__y) + 16|0);
   $107 = $106;
   $108 = $107;
   $109 = HEAP32[$108>>2]|0;
   $110 = (($107) + 4)|0;
   $111 = $110;
   $112 = HEAP32[$111>>2]|0;
   $113 = ($105|0)<($112|0);
   $114 = ($105|0)==($112|0);
   $115 = ($102>>>0)<($109>>>0);
   $116 = $114 & $115;
   $117 = $113 | $116;
   if (!($117)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } else {
  $92 = ($89|0)<($90|0);
  if (!($92)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 ;HEAP32[$__t$i8+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__t$i8+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__t$i8+24>>2]=HEAP32[$__y+24>>2]|0;HEAP32[$__t$i8+28>>2]=HEAP32[$__y+28>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__z+24>>2]|0;
 ;HEAP32[$__z+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i8+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i8+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i8+24>>2]|0;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $__r$0 = 0, $__t$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i6 = sp;
 $0 = (__ZNSt3__17__sort3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_T_($__x1,$__x2,$__x3,0)|0);
 $1 = (($__x4) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__x3) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $7 = (($__x4) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__x3) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)<($10|0);
  if (!($11)) {
   $12 = ($8|0)>($10|0);
   if ($12) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
   $13 = (($__x4) + 16|0);
   $14 = $13;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__x3) + 16|0);
   $21 = $20;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = ($19|0)<($26|0);
   $28 = ($19|0)==($26|0);
   $29 = ($16>>>0)<($23>>>0);
   $30 = $28 & $29;
   $31 = $27 | $30;
   if (!($31)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } else {
  $6 = ($2|0)<($4|0);
  if (!($6)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP32[$__t$i6+28>>2]=HEAP32[$__x3+28>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__x4+24>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__t$i6+24>>2]|0;
 $32 = (($0) + 1)|0;
 $33 = HEAP32[$3>>2]|0;
 $34 = (($__x2) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)==($35|0);
 if ($36) {
  $38 = (($__x3) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($__x2) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($39|0)<($41|0);
  if (!($42)) {
   $43 = ($39|0)>($41|0);
   if ($43) {
    $__r$0 = $32;
    STACKTOP = sp;return ($__r$0|0);
   }
   $44 = (($__x3) + 16|0);
   $45 = $44;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = (($45) + 4)|0;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($__x2) + 16|0);
   $52 = $51;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = ($50|0)<($57|0);
   $59 = ($50|0)==($57|0);
   $60 = ($47>>>0)<($54>>>0);
   $61 = $59 & $60;
   $62 = $58 | $61;
   if (!($62)) {
    $__r$0 = $32;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } else {
  $37 = ($33|0)<($35|0);
  if (!($37)) {
   $__r$0 = $32;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP32[$__t$i6+28>>2]=HEAP32[$__x2+28>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i6+24>>2]|0;
 $63 = (($0) + 2)|0;
 $64 = HEAP32[$34>>2]|0;
 $65 = (($__x1) + 24|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($64|0)==($66|0);
 if ($67) {
  $69 = (($__x2) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($__x1) + 8|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($70|0)<($72|0);
  if (!($73)) {
   $74 = ($70|0)>($72|0);
   if ($74) {
    $__r$0 = $63;
    STACKTOP = sp;return ($__r$0|0);
   }
   $75 = (($__x2) + 16|0);
   $76 = $75;
   $77 = $76;
   $78 = HEAP32[$77>>2]|0;
   $79 = (($76) + 4)|0;
   $80 = $79;
   $81 = HEAP32[$80>>2]|0;
   $82 = (($__x1) + 16|0);
   $83 = $82;
   $84 = $83;
   $85 = HEAP32[$84>>2]|0;
   $86 = (($83) + 4)|0;
   $87 = $86;
   $88 = HEAP32[$87>>2]|0;
   $89 = ($81|0)<($88|0);
   $90 = ($81|0)==($88|0);
   $91 = ($78>>>0)<($85>>>0);
   $92 = $90 & $91;
   $93 = $89 | $92;
   if (!($93)) {
    $__r$0 = $63;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } else {
  $68 = ($64|0)<($66|0);
  if (!($68)) {
   $__r$0 = $63;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$__x1+24>>2]|0;HEAP32[$__t$i6+28>>2]=HEAP32[$__x1+28>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i6+24>>2]|0;
 $94 = (($0) + 3)|0;
 $__r$0 = $94;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__t$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i9 = sp;
 $0 = (__ZNSt3__17__sort4IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = (($__x5) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__x4) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $7 = (($__x5) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__x4) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)<($10|0);
  if (!($11)) {
   $12 = ($8|0)>($10|0);
   if ($12) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
   $13 = (($__x5) + 16|0);
   $14 = $13;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__x4) + 16|0);
   $21 = $20;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = ($19|0)<($26|0);
   $28 = ($19|0)==($26|0);
   $29 = ($16>>>0)<($23>>>0);
   $30 = $28 & $29;
   $31 = $27 | $30;
   if (!($31)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } else {
  $6 = ($2|0)<($4|0);
  if (!($6)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i9+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__t$i9+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__t$i9+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__t$i9+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__t$i9+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__t$i9+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__t$i9+24>>2]=HEAP32[$__x4+24>>2]|0;HEAP32[$__t$i9+28>>2]=HEAP32[$__x4+28>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__x5+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__x5+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__x5+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__x5+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__x5+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__x5+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__x5+24>>2]|0;
 ;HEAP32[$__x5+0>>2]=HEAP32[$__t$i9+0>>2]|0;HEAP32[$__x5+4>>2]=HEAP32[$__t$i9+4>>2]|0;HEAP32[$__x5+8>>2]=HEAP32[$__t$i9+8>>2]|0;HEAP32[$__x5+12>>2]=HEAP32[$__t$i9+12>>2]|0;HEAP32[$__x5+16>>2]=HEAP32[$__t$i9+16>>2]|0;HEAP32[$__x5+20>>2]=HEAP32[$__t$i9+20>>2]|0;HEAP32[$__x5+24>>2]=HEAP32[$__t$i9+24>>2]|0;
 $32 = (($0) + 1)|0;
 $33 = HEAP32[$3>>2]|0;
 $34 = (($__x3) + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($33|0)==($35|0);
 if ($36) {
  $38 = (($__x4) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($__x3) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($39|0)<($41|0);
  if (!($42)) {
   $43 = ($39|0)>($41|0);
   if ($43) {
    $__r$0 = $32;
    STACKTOP = sp;return ($__r$0|0);
   }
   $44 = (($__x4) + 16|0);
   $45 = $44;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = (($45) + 4)|0;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($__x3) + 16|0);
   $52 = $51;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = ($50|0)<($57|0);
   $59 = ($50|0)==($57|0);
   $60 = ($47>>>0)<($54>>>0);
   $61 = $59 & $60;
   $62 = $58 | $61;
   if (!($62)) {
    $__r$0 = $32;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } else {
  $37 = ($33|0)<($35|0);
  if (!($37)) {
   $__r$0 = $32;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i9+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i9+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i9+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i9+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i9+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i9+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__t$i9+24>>2]=HEAP32[$__x3+24>>2]|0;HEAP32[$__t$i9+28>>2]=HEAP32[$__x3+28>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__x4+24>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i9+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i9+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i9+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i9+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i9+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i9+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__t$i9+24>>2]|0;
 $63 = (($0) + 2)|0;
 $64 = HEAP32[$34>>2]|0;
 $65 = (($__x2) + 24|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($64|0)==($66|0);
 if ($67) {
  $69 = (($__x3) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($__x2) + 8|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($70|0)<($72|0);
  if (!($73)) {
   $74 = ($70|0)>($72|0);
   if ($74) {
    $__r$0 = $63;
    STACKTOP = sp;return ($__r$0|0);
   }
   $75 = (($__x3) + 16|0);
   $76 = $75;
   $77 = $76;
   $78 = HEAP32[$77>>2]|0;
   $79 = (($76) + 4)|0;
   $80 = $79;
   $81 = HEAP32[$80>>2]|0;
   $82 = (($__x2) + 16|0);
   $83 = $82;
   $84 = $83;
   $85 = HEAP32[$84>>2]|0;
   $86 = (($83) + 4)|0;
   $87 = $86;
   $88 = HEAP32[$87>>2]|0;
   $89 = ($81|0)<($88|0);
   $90 = ($81|0)==($88|0);
   $91 = ($78>>>0)<($85>>>0);
   $92 = $90 & $91;
   $93 = $89 | $92;
   if (!($93)) {
    $__r$0 = $63;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } else {
  $68 = ($64|0)<($66|0);
  if (!($68)) {
   $__r$0 = $63;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i9+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i9+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i9+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i9+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i9+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i9+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i9+24>>2]=HEAP32[$__x2+24>>2]|0;HEAP32[$__t$i9+28>>2]=HEAP32[$__x2+28>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i9+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i9+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i9+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i9+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i9+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i9+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i9+24>>2]|0;
 $94 = (($0) + 3)|0;
 $95 = HEAP32[$65>>2]|0;
 $96 = (($__x1) + 24|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = ($95|0)==($97|0);
 if ($98) {
  $100 = (($__x2) + 8|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (($__x1) + 8|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = ($101|0)<($103|0);
  if (!($104)) {
   $105 = ($101|0)>($103|0);
   if ($105) {
    $__r$0 = $94;
    STACKTOP = sp;return ($__r$0|0);
   }
   $106 = (($__x2) + 16|0);
   $107 = $106;
   $108 = $107;
   $109 = HEAP32[$108>>2]|0;
   $110 = (($107) + 4)|0;
   $111 = $110;
   $112 = HEAP32[$111>>2]|0;
   $113 = (($__x1) + 16|0);
   $114 = $113;
   $115 = $114;
   $116 = HEAP32[$115>>2]|0;
   $117 = (($114) + 4)|0;
   $118 = $117;
   $119 = HEAP32[$118>>2]|0;
   $120 = ($112|0)<($119|0);
   $121 = ($112|0)==($119|0);
   $122 = ($109>>>0)<($116>>>0);
   $123 = $121 & $122;
   $124 = $120 | $123;
   if (!($124)) {
    $__r$0 = $94;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } else {
  $99 = ($95|0)<($97|0);
  if (!($99)) {
   $__r$0 = $94;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i9+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i9+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i9+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i9+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i9+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i9+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i9+24>>2]=HEAP32[$__x1+24>>2]|0;HEAP32[$__t$i9+28>>2]=HEAP32[$__x1+28>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i9+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i9+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i9+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i9+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i9+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i9+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i9+24>>2]|0;
 $125 = (($0) + 4)|0;
 $__r$0 = $125;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$lcssa = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__i$08 = 0, $__j$07 = 0, $__j$07$phi = 0, $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 64|0);
 $1 = (($__first) + 32|0);
 (__ZNSt3__17__sort3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 96|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$08 = $2;$__j$07 = $0;
 }
 while(1) {
  $4 = (($__i$08) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($__j$07) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  if ($8) {
   $10 = (($__i$08) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($__j$07) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11|0)<($13|0);
   if ($14) {
    $$pre$phiZ2D = $10;
    label = 8;
   } else {
    $15 = ($11|0)>($13|0);
    if (!($15)) {
     $16 = (($__i$08) + 16|0);
     $17 = $16;
     $18 = $17;
     $19 = HEAP32[$18>>2]|0;
     $20 = (($17) + 4)|0;
     $21 = $20;
     $22 = HEAP32[$21>>2]|0;
     $23 = (($__j$07) + 16|0);
     $24 = $23;
     $25 = $24;
     $26 = HEAP32[$25>>2]|0;
     $27 = (($24) + 4)|0;
     $28 = $27;
     $29 = HEAP32[$28>>2]|0;
     $30 = ($22|0)<($29|0);
     $31 = ($22|0)==($29|0);
     $32 = ($19>>>0)<($26>>>0);
     $33 = $31 & $32;
     $34 = $30 | $33;
     if ($34) {
      $$pre$phiZ2D = $10;
      label = 8;
     }
    }
   }
  } else {
   $9 = ($5|0)<($7|0);
   if ($9) {
    $$pre = (($__i$08) + 8|0);
    $$pre$phiZ2D = $$pre;
    label = 8;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $35 = $__i$08;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $38 = (($35) + 4)|0;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$$pre$phiZ2D>>2]|0;
   $42 = (($__i$08) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($__i$08) + 16|0);
   $45 = $44;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = (($45) + 4)|0;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = HEAP32[$4>>2]|0;
   ;HEAP32[$__i$08+0>>2]=HEAP32[$__j$07+0>>2]|0;HEAP32[$__i$08+4>>2]=HEAP32[$__j$07+4>>2]|0;HEAP32[$__i$08+8>>2]=HEAP32[$__j$07+8>>2]|0;HEAP32[$__i$08+12>>2]=HEAP32[$__j$07+12>>2]|0;HEAP32[$__i$08+16>>2]=HEAP32[$__j$07+16>>2]|0;HEAP32[$__i$08+20>>2]=HEAP32[$__j$07+20>>2]|0;HEAP32[$__i$08+24>>2]=HEAP32[$__j$07+24>>2]|0;
   $52 = ($__j$07|0)==($__first|0);
   L13: do {
    if ($52) {
     $$lcssa = $__j$07;$__k$0$lcssa = $__first;
    } else {
     $54 = $__j$07;
     while(1) {
      $53 = (($54) + -32|0);
      $55 = (($54) + -8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($51|0)==($56|0);
      if ($57) {
       $59 = (($54) + -24|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ($41|0)<($60|0);
       if (!($61)) {
        $62 = ($41|0)>($60|0);
        if ($62) {
         $$lcssa = $54;$__k$0$lcssa = $54;
         break L13;
        }
        $63 = (($54) + -16|0);
        $64 = $63;
        $65 = $64;
        $66 = HEAP32[$65>>2]|0;
        $67 = (($64) + 4)|0;
        $68 = $67;
        $69 = HEAP32[$68>>2]|0;
        $70 = ($50|0)<($69|0);
        $71 = ($50|0)==($69|0);
        $72 = ($47>>>0)<($66>>>0);
        $73 = $71 & $72;
        $74 = $70 | $73;
        if (!($74)) {
         $$lcssa = $54;$__k$0$lcssa = $54;
         break L13;
        }
       }
      } else {
       $58 = ($51|0)<($56|0);
       if (!($58)) {
        $$lcssa = $54;$__k$0$lcssa = $54;
        break L13;
       }
      }
      ;HEAP32[$54+0>>2]=HEAP32[$53+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$53+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$53+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$53+12>>2]|0;HEAP32[$54+16>>2]=HEAP32[$53+16>>2]|0;HEAP32[$54+20>>2]=HEAP32[$53+20>>2]|0;HEAP32[$54+24>>2]=HEAP32[$53+24>>2]|0;
      $75 = ($53|0)==($__first|0);
      if ($75) {
       $$lcssa = $53;$__k$0$lcssa = $__first;
       break;
      } else {
       $54 = $53;
      }
     }
    }
   } while(0);
   $76 = $__k$0$lcssa;
   $77 = $76;
   HEAP32[$77>>2] = $37;
   $78 = (($76) + 4)|0;
   $79 = $78;
   HEAP32[$79>>2] = $40;
   $80 = (($__k$0$lcssa) + 8|0);
   HEAP32[$80>>2] = $41;
   $81 = (($$lcssa) + 12|0);
   HEAP32[$81>>2] = $43;
   $82 = (($__k$0$lcssa) + 16|0);
   $83 = $82;
   $84 = $83;
   HEAP32[$84>>2] = $47;
   $85 = (($83) + 4)|0;
   $86 = $85;
   HEAP32[$86>>2] = $50;
   $87 = (($__k$0$lcssa) + 24|0);
   HEAP32[$87>>2] = $51;
  }
  $88 = (($__i$08) + 32|0);
  $89 = ($88|0)==($__last|0);
  if ($89) {
   break;
  } else {
   $__j$07$phi = $__i$08;$__i$08 = $88;$__j$07 = $__j$07$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEbT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$lcssa = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__count$012 = 0, $__count$1 = 0, $__i$013 = 0, $__j$011 = 0, $__j$011$phi = 0, $__k$0$lcssa = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 5;
 switch ($3|0) {
 case 3:  {
  $36 = (($__first) + 32|0);
  $37 = (($__last) + -32|0);
  (__ZNSt3__17__sort3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_T_($__first,$36,$37,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -32|0);
  $5 = (($__last) + -8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($__first) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  if ($9) {
   $11 = (($__last) + -24|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($__first) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12|0)<($14|0);
   if (!($15)) {
    $16 = ($12|0)>($14|0);
    if ($16) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $17 = (($__last) + -16|0);
    $18 = $17;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($18) + 4)|0;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = (($__first) + 16|0);
    $25 = $24;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = ($23|0)<($30|0);
    $32 = ($23|0)==($30|0);
    $33 = ($20>>>0)<($27>>>0);
    $34 = $32 & $33;
    $35 = $31 | $34;
    if (!($35)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   $10 = ($6|0)<($8|0);
   if (!($10)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  ;HEAP32[$__t$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i+24>>2]=HEAP32[$__first+24>>2]|0;HEAP32[$__t$i+28>>2]=HEAP32[$__first+28>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$4+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$4+24>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$__t$i+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$__t$i+20>>2]|0;HEAP32[$4+24>>2]=HEAP32[$__t$i+24>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $38 = (($__first) + 32|0);
  $39 = (($__first) + 64|0);
  $40 = (($__last) + -32|0);
  (__ZNSt3__17__sort4IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_S6_T_($__first,$38,$39,$40,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $41 = (($__first) + 32|0);
  $42 = (($__first) + 64|0);
  $43 = (($__first) + 96|0);
  $44 = (($__last) + -32|0);
  (__ZNSt3__17__sort5IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_S6_S6_T_($__first,$41,$42,$43,$44,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $45 = (($__first) + 64|0);
  $46 = (($__first) + 32|0);
  (__ZNSt3__17__sort3IRN18AssetBundleManager27SortPreloadDataByIdentifierEPNS1_11PreloadDataEEEjT0_S6_S6_T_($__first,$46,$45,0)|0);
  $47 = (($__first) + 96|0);
  $48 = ($47|0)==($__last|0);
  if ($48) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$012 = 0;$__i$013 = $47;$__j$011 = $45;
  }
  while(1) {
   $49 = (($__i$013) + 24|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($__j$011) + 24|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($50|0)==($52|0);
   if ($53) {
    $55 = (($__i$013) + 8|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($__j$011) + 8|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($56|0)<($58|0);
    if ($59) {
     $$pre$phiZ2D = $55;
     label = 18;
    } else {
     $60 = ($56|0)>($58|0);
     if ($60) {
      $__count$1 = $__count$012;
     } else {
      $61 = (($__i$013) + 16|0);
      $62 = $61;
      $63 = $62;
      $64 = HEAP32[$63>>2]|0;
      $65 = (($62) + 4)|0;
      $66 = $65;
      $67 = HEAP32[$66>>2]|0;
      $68 = (($__j$011) + 16|0);
      $69 = $68;
      $70 = $69;
      $71 = HEAP32[$70>>2]|0;
      $72 = (($69) + 4)|0;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = ($67|0)<($74|0);
      $76 = ($67|0)==($74|0);
      $77 = ($64>>>0)<($71>>>0);
      $78 = $76 & $77;
      $79 = $75 | $78;
      if ($79) {
       $$pre$phiZ2D = $55;
       label = 18;
      } else {
       $__count$1 = $__count$012;
      }
     }
    }
   } else {
    $54 = ($50|0)<($52|0);
    if ($54) {
     $$pre = (($__i$013) + 8|0);
     $$pre$phiZ2D = $$pre;
     label = 18;
    } else {
     $__count$1 = $__count$012;
    }
   }
   if ((label|0) == 18) {
    label = 0;
    $80 = $__i$013;
    $81 = $80;
    $82 = HEAP32[$81>>2]|0;
    $83 = (($80) + 4)|0;
    $84 = $83;
    $85 = HEAP32[$84>>2]|0;
    $86 = HEAP32[$$pre$phiZ2D>>2]|0;
    $87 = (($__i$013) + 12|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = (($__i$013) + 16|0);
    $90 = $89;
    $91 = $90;
    $92 = HEAP32[$91>>2]|0;
    $93 = (($90) + 4)|0;
    $94 = $93;
    $95 = HEAP32[$94>>2]|0;
    $96 = HEAP32[$49>>2]|0;
    ;HEAP32[$__i$013+0>>2]=HEAP32[$__j$011+0>>2]|0;HEAP32[$__i$013+4>>2]=HEAP32[$__j$011+4>>2]|0;HEAP32[$__i$013+8>>2]=HEAP32[$__j$011+8>>2]|0;HEAP32[$__i$013+12>>2]=HEAP32[$__j$011+12>>2]|0;HEAP32[$__i$013+16>>2]=HEAP32[$__j$011+16>>2]|0;HEAP32[$__i$013+20>>2]=HEAP32[$__j$011+20>>2]|0;HEAP32[$__i$013+24>>2]=HEAP32[$__j$011+24>>2]|0;
    $97 = ($__j$011|0)==($__first|0);
    L29: do {
     if ($97) {
      $$lcssa = $__j$011;$__k$0$lcssa = $__first;
     } else {
      $99 = $__j$011;
      while(1) {
       $98 = (($99) + -32|0);
       $100 = (($99) + -8|0);
       $101 = HEAP32[$100>>2]|0;
       $102 = ($96|0)==($101|0);
       if ($102) {
        $104 = (($99) + -24|0);
        $105 = HEAP32[$104>>2]|0;
        $106 = ($86|0)<($105|0);
        if (!($106)) {
         $107 = ($86|0)>($105|0);
         if ($107) {
          $$lcssa = $99;$__k$0$lcssa = $99;
          break L29;
         }
         $108 = (($99) + -16|0);
         $109 = $108;
         $110 = $109;
         $111 = HEAP32[$110>>2]|0;
         $112 = (($109) + 4)|0;
         $113 = $112;
         $114 = HEAP32[$113>>2]|0;
         $115 = ($95|0)<($114|0);
         $116 = ($95|0)==($114|0);
         $117 = ($92>>>0)<($111>>>0);
         $118 = $116 & $117;
         $119 = $115 | $118;
         if (!($119)) {
          $$lcssa = $99;$__k$0$lcssa = $99;
          break L29;
         }
        }
       } else {
        $103 = ($96|0)<($101|0);
        if (!($103)) {
         $$lcssa = $99;$__k$0$lcssa = $99;
         break L29;
        }
       }
       ;HEAP32[$99+0>>2]=HEAP32[$98+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$98+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$98+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$98+12>>2]|0;HEAP32[$99+16>>2]=HEAP32[$98+16>>2]|0;HEAP32[$99+20>>2]=HEAP32[$98+20>>2]|0;HEAP32[$99+24>>2]=HEAP32[$98+24>>2]|0;
       $120 = ($98|0)==($__first|0);
       if ($120) {
        $$lcssa = $98;$__k$0$lcssa = $__first;
        break;
       } else {
        $99 = $98;
       }
      }
     }
    } while(0);
    $121 = $__k$0$lcssa;
    $122 = $121;
    HEAP32[$122>>2] = $82;
    $123 = (($121) + 4)|0;
    $124 = $123;
    HEAP32[$124>>2] = $85;
    $125 = (($__k$0$lcssa) + 8|0);
    HEAP32[$125>>2] = $86;
    $126 = (($$lcssa) + 12|0);
    HEAP32[$126>>2] = $88;
    $127 = (($__k$0$lcssa) + 16|0);
    $128 = $127;
    $129 = $128;
    HEAP32[$129>>2] = $92;
    $130 = (($128) + 4)|0;
    $131 = $130;
    HEAP32[$131>>2] = $95;
    $132 = (($__k$0$lcssa) + 24|0);
    HEAP32[$132>>2] = $96;
    $133 = (($__count$012) + 1)|0;
    $134 = ($133|0)==(8);
    if ($134) {
     break;
    } else {
     $__count$1 = $133;
    }
   }
   $137 = (($__i$013) + 32|0);
   $138 = ($137|0)==($__last|0);
   if ($138) {
    $$0 = 1;
    label = 28;
    break;
   } else {
    $__j$011$phi = $__i$013;$__count$012 = $__count$1;$__i$013 = $137;$__j$011 = $__j$011$phi;
   }
  }
  if ((label|0) == 28) {
   STACKTOP = sp;return ($$0|0);
  }
  $135 = (($__i$013) + 32|0);
  $136 = ($135|0)==($__last|0);
  $$0 = $136;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __Z28GetAbsoluteAssetBundlePrefixRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$mainAssetFileName) {
 $agg$result = $agg$result|0;
 $mainAssetFileName = $mainAssetFileName|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 HEAP8[$0>>0] = 18;
 $2 = (($0) + 1|0);
 dest=$2+0|0; src=617128+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $3 = (($0) + 10|0);
 HEAP8[$3>>0] = 0;
 __THREW__ = 0;
 invoke_vii(2761,($1|0),($mainAssetFileName|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   $$0 = $19;$$01 = $18;
  } else {
   __THREW__ = 0;
   invoke_viii(1774,($agg$result|0),($0|0),($1|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $20 = ___cxa_find_matching_catch()|0;
    $21 = tempRet0;
    $22 = HEAP8[$1>>0]|0;
    $23 = $22 & 1;
    $24 = ($23<<24>>24)==(0);
    if ($24) {
     $$0 = $21;$$01 = $20;
     break;
    }
    $25 = (($1) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    __ZdlPv($26);
    $$0 = $21;$$01 = $20;
    break;
   }
   $8 = HEAP8[$1>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if (!($10)) {
    $11 = (($1) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    __ZdlPv($12);
   }
   $13 = HEAP8[$0>>0]|0;
   $14 = $13 & 1;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    STACKTOP = sp;return;
   }
   $16 = (($0) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   __ZdlPv($17);
   STACKTOP = sp;return;
  }
 } while(0);
 $27 = HEAP8[$0>>0]|0;
 $28 = $27 & 1;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $30 = (($0) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 __ZdlPv($31);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZL20GetAssetBundlePrefixRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$mainAssetFileName) {
 $agg$result = $agg$result|0;
 $mainAssetFileName = $mainAssetFileName|0;
 var $$01$be$i$i$i$i = 0, $$01$be$i$i$i$i17 = 0, $$01$be$i$i$i$i5 = 0, $$014$i$i$i$i = 0, $$014$i$i$i$i16 = 0, $$014$i$i$i$i4 = 0, $$sum$i$i = 0, $$sum$i$i14 = 0, $$sum$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__m1$0$i$i$i$i = 0, $__m1$0$i$i$i$i19 = 0, $__m1$0$i$i$i$i7 = 0;
 var $__m2$0$i$i$i$i = 0, $__m2$0$i$i$i$i20 = 0, $__m2$0$i$i$i$i8 = 0, $or$cond = 0, $or$cond29 = 0, $or$cond30 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP8[$mainAssetFileName>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = $2&255;
  $8 = $7 >>> 1;
  $10 = $8;
 } else {
  $5 = (($mainAssetFileName) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $10 = $6;
 }
 $9 = ($10>>>0)<(17);
 L5: do {
  if ($9) {
   label = 15;
  } else {
   if ($4) {
    $13 = (($mainAssetFileName) + 1|0);
    $15 = $13;
   } else {
    $11 = (($mainAssetFileName) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $15 = $12;
   }
   $14 = (($15) + ($10)|0);
   $16 = ($10|0)<(17);
   if ($16) {
    label = 15;
   } else {
    $$sum$i$i = (($10) + -16)|0;
    $17 = (($15) + ($$sum$i$i)|0);
    $18 = ($$sum$i$i|0)==(0);
    if ($18) {
     label = 15;
    } else {
     $$014$i$i$i$i = $15;
     L12: while(1) {
      $19 = HEAP8[$$014$i$i$i$i>>0]|0;
      $20 = ($19<<24>>24)==(67);
      if ($20) {
       $__m1$0$i$i$i$i = $$014$i$i$i$i;$__m2$0$i$i$i$i = 617160;
       while(1) {
        $22 = (($__m2$0$i$i$i$i) + 1|0);
        $23 = ($22|0)==(((617160 + 17|0))|0);
        if ($23) {
         break L12;
        }
        $24 = (($__m1$0$i$i$i$i) + 1|0);
        $25 = HEAP8[$24>>0]|0;
        $26 = HEAP8[$22>>0]|0;
        $27 = ($25<<24>>24)==($26<<24>>24);
        if ($27) {
         $__m1$0$i$i$i$i = $24;$__m2$0$i$i$i$i = $22;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i = (($$014$i$i$i$i) + 1|0);
      $21 = ($$01$be$i$i$i$i|0)==($17|0);
      if ($21) {
       label = 15;
       break L5;
      } else {
       $$014$i$i$i$i = $$01$be$i$i$i$i;
      }
     }
     $28 = ($$014$i$i$i$i|0)!=($14|0);
     $29 = ($$014$i$i$i$i|0)==($15|0);
     $or$cond = $28 & $29;
     if (!($or$cond)) {
      label = 15;
     }
    }
   }
  }
 } while(0);
 L20: do {
  if ((label|0) == 15) {
   if ($4) {
    $32 = $2&255;
    $33 = $32 >>> 1;
    $35 = $33;
   } else {
    $30 = (($mainAssetFileName) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $35 = $31;
   }
   $34 = ($35>>>0)<(3);
   L26: do {
    if (!($34)) {
     if ($4) {
      $38 = (($mainAssetFileName) + 1|0);
      $40 = $38;
     } else {
      $36 = (($mainAssetFileName) + 8|0);
      $37 = HEAP32[$36>>2]|0;
      $40 = $37;
     }
     $39 = (($40) + ($35)|0);
     $41 = ($35|0)<(3);
     if (!($41)) {
      $$sum$i$i2 = (($35) + -2)|0;
      $42 = (($40) + ($$sum$i$i2)|0);
      $43 = ($$sum$i$i2|0)==(0);
      if (!($43)) {
       $$014$i$i$i$i4 = $40;
       L33: while(1) {
        $44 = HEAP8[$$014$i$i$i$i4>>0]|0;
        $45 = ($44<<24>>24)==(67);
        if ($45) {
         $__m1$0$i$i$i$i7 = $$014$i$i$i$i4;$__m2$0$i$i$i$i8 = 617184;
         while(1) {
          $47 = (($__m2$0$i$i$i$i8) + 1|0);
          $48 = ($47|0)==(((617184 + 3|0))|0);
          if ($48) {
           break L33;
          }
          $49 = (($__m1$0$i$i$i$i7) + 1|0);
          $50 = HEAP8[$49>>0]|0;
          $51 = HEAP8[$47>>0]|0;
          $52 = ($50<<24>>24)==($51<<24>>24);
          if ($52) {
           $__m1$0$i$i$i$i7 = $49;$__m2$0$i$i$i$i8 = $47;
          } else {
           break;
          }
         }
        }
        $$01$be$i$i$i$i5 = (($$014$i$i$i$i4) + 1|0);
        $46 = ($$01$be$i$i$i$i5|0)==($42|0);
        if ($46) {
         break L26;
        } else {
         $$014$i$i$i$i4 = $$01$be$i$i$i$i5;
        }
       }
       $53 = ($$014$i$i$i$i4|0)!=($39|0);
       $54 = ($$014$i$i$i$i4|0)==($40|0);
       $or$cond29 = $53 & $54;
       if ($or$cond29) {
        break L20;
       }
      }
     }
    }
   } while(0);
   if ($4) {
    $57 = $2&255;
    $58 = $57 >>> 1;
    $60 = $58;
   } else {
    $55 = (($mainAssetFileName) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $60 = $56;
   }
   $59 = ($60>>>0)<(11);
   L46: do {
    if (!($59)) {
     if ($4) {
      $63 = (($mainAssetFileName) + 1|0);
      $65 = $63;
     } else {
      $61 = (($mainAssetFileName) + 8|0);
      $62 = HEAP32[$61>>2]|0;
      $65 = $62;
     }
     $64 = (($65) + ($60)|0);
     $66 = ($60|0)<(11);
     if (!($66)) {
      $$sum$i$i14 = (($60) + -10)|0;
      $67 = (($65) + ($$sum$i$i14)|0);
      $68 = ($$sum$i$i14|0)==(0);
      if (!($68)) {
       $$014$i$i$i$i16 = $65;
       L53: while(1) {
        $69 = HEAP8[$$014$i$i$i$i16>>0]|0;
        $70 = ($69<<24>>24)==(66);
        if ($70) {
         $__m1$0$i$i$i$i19 = $$014$i$i$i$i16;$__m2$0$i$i$i$i20 = 617208;
         while(1) {
          $72 = (($__m2$0$i$i$i$i20) + 1|0);
          $73 = ($72|0)==(((617208 + 11|0))|0);
          if ($73) {
           break L53;
          }
          $74 = (($__m1$0$i$i$i$i19) + 1|0);
          $75 = HEAP8[$74>>0]|0;
          $76 = HEAP8[$72>>0]|0;
          $77 = ($75<<24>>24)==($76<<24>>24);
          if ($77) {
           $__m1$0$i$i$i$i19 = $74;$__m2$0$i$i$i$i20 = $72;
          } else {
           break;
          }
         }
        }
        $$01$be$i$i$i$i17 = (($$014$i$i$i$i16) + 1|0);
        $71 = ($$01$be$i$i$i$i17|0)==($67|0);
        if ($71) {
         break L46;
        } else {
         $$014$i$i$i$i16 = $$01$be$i$i$i$i17;
        }
       }
       $78 = ($$014$i$i$i$i16|0)!=($64|0);
       $79 = ($$014$i$i$i$i16|0)==($65|0);
       $or$cond30 = $78 & $79;
       if ($or$cond30) {
        __Z24GetLastPathNameComponentRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0,$mainAssetFileName);
        __THREW__ = 0;
        invoke_vii(2753,($1|0),($0|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         $87 = ___cxa_find_matching_catch()|0;
         $88 = tempRet0;
         $89 = HEAP8[$0>>0]|0;
         $90 = $89 & 1;
         $91 = ($90<<24>>24)==(0);
         if ($91) {
          ___resumeException($87|0);
          // unreachable;
         }
         $92 = (($0) + 8|0);
         $93 = HEAP32[$92>>2]|0;
         __ZdlPv($93);
         ___resumeException($87|0);
         // unreachable;
        }
        $82 = HEAP8[$0>>0]|0;
        $83 = $82 & 1;
        $84 = ($83<<24>>24)==(0);
        if (!($84)) {
         $85 = (($0) + 8|0);
         $86 = HEAP32[$85>>2]|0;
         __ZdlPv($86);
        }
        __THREW__ = 0;
        invoke_viii(1627,($agg$result|0),($1|0),(617200|0));
        $94 = __THREW__; __THREW__ = 0;
        $95 = $94&1;
        if ($95) {
         $101 = ___cxa_find_matching_catch()|0;
         $102 = tempRet0;
         $103 = HEAP8[$1>>0]|0;
         $104 = $103 & 1;
         $105 = ($104<<24>>24)==(0);
         if ($105) {
          ___resumeException($101|0);
          // unreachable;
         }
         $106 = (($1) + 8|0);
         $107 = HEAP32[$106>>2]|0;
         __ZdlPv($107);
         ___resumeException($101|0);
         // unreachable;
        } else {
         $96 = HEAP8[$1>>0]|0;
         $97 = $96 & 1;
         $98 = ($97<<24>>24)==(0);
         if ($98) {
          STACKTOP = sp;return;
         }
         $99 = (($1) + 8|0);
         $100 = HEAP32[$99>>2]|0;
         __ZdlPv($100);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   } while(0);
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
   STACKTOP = sp;return;
  }
 } while(0);
 __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_($agg$result,$mainAssetFileName,617200);
 STACKTOP = sp;return;
}
function __Z28IsBinaryBlobResourceFilePathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($filePath) {
 $filePath = $filePath|0;
 var $$$$i$i$i = 0, $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __Z20GetPathNameExtensionRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0,$filePath);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $8 = $1&255;
  $9 = $8 >>> 1;
  $10 = (($0) + 1|0);
  $12 = $9;$14 = $10;
 } else {
  $4 = (($0) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($0) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $12 = $5;$14 = $7;
 }
 $11 = ($12>>>0)>(8);
 $13 = $11 ? 8 : $12;
 $15 = (_memcmp($14,617144,$13)|0);
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = ($12>>>0)<(8);
  $$$i$i$i = $11&1;
  $$$$i$i$i = $17 ? -1 : $$$i$i$i;
  $19 = $$$$i$i$i;
 } else {
  $19 = $15;
 }
 $18 = ($19|0)==(0);
 if ($3) {
  STACKTOP = sp;return ($18|0);
 }
 $20 = (($0) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 __ZdlPv($21);
 STACKTOP = sp;return ($18|0);
}
function __Z30LoadNamedObjectFromAssetBundleR11AssetBundleRKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP15ScriptingObject($bundle,$name,$type) {
 $bundle = $bundle|0;
 $name = $name|0;
 $type = $type|0;
 var $$01114 = 0, $$012 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $result = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $tmpcast$byval_copy = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 24|0;
 $result = sp + 8|0;
 $0 = sp;
 __ZN11AssetBundle12GetPathRangeERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$bundle,$name);
 HEAP32[$result>>2] = 0;
 $1 = (($result) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($result) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 invoke_viiiii(99,($bundle|0),($tmpcast$byval_copy|0),($type|0),($result|0),1);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $10 = HEAP32[$result>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   ___resumeException($8|0);
   // unreachable;
  }
  $12 = HEAP32[$1>>2]|0;
  $13 = ($12|0)==($10|0);
  if (!($13)) {
   $__new_last2$i$i$i$i$i2 = $10;
   $scevgep$i$i$i$i$i3 = (($12) + -4|0);
   $14 = (0 - ($__new_last2$i$i$i$i$i2))|0;
   $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($14)|0);
   $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
   $15 = $uglygep3$i$i$i$i$i6 >>> 2;
   $16 = $15 ^ -1;
   $scevgep4$i$i$i$i$i7 = (($12) + ($16<<2)|0);
   HEAP32[$1>>2] = $scevgep4$i$i$i$i$i7;
  }
  __ZdlPv($10);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $5 = HEAP32[$result>>2]|0;
  $6 = HEAP32[$1>>2]|0;
  $7 = ($5|0)==($6|0);
  if ($7) {
   $17 = ($5|0)==(0|0);
   if ($17) {
    $$012 = 0;
    STACKTOP = sp;return ($$012|0);
   } else {
    $$01114 = 0;
   }
  } else {
   $18 = HEAP32[$5>>2]|0;
   $__new_last2$i$i$i$i$i = $5;
   $scevgep$i$i$i$i$i = (($6) + -4|0);
   $19 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($19)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $20 = $uglygep3$i$i$i$i$i >>> 2;
   $21 = $20 ^ -1;
   $scevgep4$i$i$i$i$i = (($6) + ($21<<2)|0);
   HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
   $$01114 = $18;
  }
  __ZdlPv($5);
  $$012 = $$01114;
  STACKTOP = sp;return ($$012|0);
 }
 return 0|0;
}
function __ZL25ProcessAssetBundleEntriesR11AssetBundleNSt3__14pairINS1_14__map_iteratorINS1_15__tree_iteratorINS1_12__value_typeI8UnityStrNS_9AssetInfoEEEPNS1_11__tree_nodeIS8_PvEEiEEEESE_EEP15ScriptingObjectRNS1_6vectorIP6ObjectNS1_9allocatorISK_EEEEb($bundle,$entries,$systemTypeInstance,$output,$stopAfterOne) {
 $bundle = $bundle|0;
 $entries = $entries|0;
 $systemTypeInstance = $systemTypeInstance|0;
 $output = $output|0;
 $stopAfterOne = $stopAfterOne|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i2 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$01$i$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (__Z39scripting_class_from_systemtypeinstanceP15ScriptingObject($systemTypeInstance)|0);
 $2 = HEAP32[$entries>>2]|0;
 $3 = (($entries) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($output) + 4|0);
 $7 = (($output) + 8|0);
 $9 = $2;
 L4: while(1) {
  $8 = (($9) + 28|0);
  __ZL12ForcePreloadR11AssetBundleRKNS_9AssetInfoEb($bundle,$8,1);
  $10 = (($9) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0);
  do {
   if (!($12)) {
    HEAP32[$0>>2] = $11;
    $13 = HEAP32[560624>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     label = 12;
    } else {
     $15 = (($13) + 36|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($13) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($16|0)==($18|0);
     do {
      if ($19) {
       $20 = (($13) + 28|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($13) + 32|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = (($21) + ($23<<3)|0);
       $40 = $24;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$13,$0);
       $25 = HEAP32[$pos$i$i$i$i>>2]|0;
       $26 = ($25|0)==(-1);
       $27 = (($13) + 28|0);
       $28 = HEAP32[$27>>2]|0;
       if ($26) {
        $29 = (($13) + 32|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = (($28) + ($30<<3)|0);
        $40 = $31;
        break;
       } else {
        $32 = (($28) + ($25<<3)|0);
        $40 = $32;
        break;
       }
      }
     } while(0);
     $33 = HEAP32[560624>>2]|0;
     $34 = (($33) + 28|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($33) + 32|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($35) + ($37<<3)|0);
     $39 = ($40|0)==($38|0);
     if ($39) {
      label = 12;
     } else {
      $41 = (($40) + 4|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0|0);
      if ($43) {
       label = 12;
      } else {
       $$0$i2 = $42;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $44 = HEAP32[$10>>2]|0;
     $45 = (__Z31ReadObjectFromPersistentManageri($44)|0);
     $46 = ($45|0)==(0|0);
     if ($46) {
      break;
     } else {
      $$0$i2 = $45;
     }
    }
    $47 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i2)|0);
    $48 = ($47|0)==(0|0);
    if (!($48)) {
     $49 = (__Z26scripting_object_get_classP15ScriptingObject($47)|0);
     $50 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($49,$1)|0);
     if ($50) {
      __ZL12ForcePreloadR11AssetBundleRKNS_9AssetInfoEb($bundle,$8,0);
      $51 = HEAP32[$6>>2]|0;
      $52 = HEAP32[$7>>2]|0;
      $53 = ($51|0)==($52|0);
      if ($53) {
       $57 = HEAP32[$output>>2]|0;
       $58 = $51;
       $59 = $57;
       $60 = (($58) - ($59))|0;
       $61 = $60 >> 2;
       $62 = (($61) + 1)|0;
       $63 = ($62>>>0)>(1073741823);
       if ($63) {
        label = 20;
        break L4;
       }
       $64 = ($61>>>0)<(536870911);
       if ($64) {
        $65 = $60 >> 1;
        $66 = ($65>>>0)<($62>>>0);
        $67 = $66 ? $62 : $65;
        $68 = ($67|0)==(0);
        if ($68) {
         $$0$i3$i$i = 0;$72 = 0;
        } else {
         $$0$i2$i$i = $67;
         label = 23;
        }
       } else {
        $$0$i2$i$i = 1073741823;
        label = 23;
       }
       if ((label|0) == 23) {
        label = 0;
        $69 = $$0$i2$i$i << 2;
        $70 = (__Znwj($69)|0);
        $$0$i3$i$i = $$0$i2$i$i;$72 = $70;
       }
       $71 = (($72) + ($61<<2)|0);
       $73 = (($72) + ($$0$i3$i$i<<2)|0);
       $74 = ($71|0)==(0|0);
       if (!($74)) {
        HEAP32[$71>>2] = $$0$i2;
       }
       $75 = (($72) + ($62<<2)|0);
       _memcpy(($72|0),($57|0),($60|0))|0;
       HEAP32[$output>>2] = $72;
       HEAP32[$6>>2] = $75;
       HEAP32[$7>>2] = $73;
       $76 = ($57|0)==(0|0);
       if (!($76)) {
        __ZdlPv($57);
       }
      } else {
       $54 = ($51|0)==(0|0);
       if ($54) {
        $56 = 0;
       } else {
        HEAP32[$51>>2] = $$0$i2;
        $$pre$i = HEAP32[$6>>2]|0;
        $56 = $$pre$i;
       }
       $55 = (($56) + 4|0);
       HEAP32[$6>>2] = $55;
      }
      if ($stopAfterOne) {
       label = 34;
       break L4;
      }
     }
    }
   }
  } while(0);
  $77 = (($9) + 4|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   $$01$i$i$i = $9;
   while(1) {
    $82 = (($$01$i$i$i) + 8|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = ($84|0)==($$01$i$i$i|0);
    if ($85) {
     $$0$i$i$i = $83;
     break;
    } else {
     $$01$i$i$i = $83;
    }
   }
  } else {
   $$0$i$i$i$i = $78;
   while(1) {
    $80 = HEAP32[$$0$i$i$i$i>>2]|0;
    $81 = ($80|0)==(0|0);
    if ($81) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $80;
    }
   }
  }
  $86 = HEAP32[$3>>2]|0;
  $87 = ($$0$i$i$i|0)==($86|0);
  if ($87) {
   label = 34;
   break;
  } else {
   $9 = $$0$i$i$i;
  }
 }
 if ((label|0) == 20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 34) {
  STACKTOP = sp;return;
 }
}
function __Z36LoadAssetWithSubAssetFromAssetBundleR11AssetBundleRKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP15ScriptingObjectRNS1_6vectorIP6ObjectNS5_ISE_EEEE($bundle,$name,$type,$output) {
 $bundle = $bundle|0;
 $name = $name|0;
 $type = $type|0;
 $output = $output|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $found = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $found = sp;
 $0 = sp + 8|0;
 $1 = HEAP8[$name>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $9 = $7;
 } else {
  $4 = (($name) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $9 = $5;
 }
 $8 = ($9|0)==(0);
 if ($8) {
  __ZN11AssetBundle6GetAllEv($found,$bundle);
 } else {
  __ZN11AssetBundle12GetPathRangeERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($found,$bundle,$name);
 }
 $10 = $found;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $0;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZL25ProcessAssetBundleEntriesR11AssetBundleNSt3__14pairINS1_14__map_iteratorINS1_15__tree_iteratorINS1_12__value_typeI8UnityStrNS_9AssetInfoEEEPNS1_11__tree_nodeIS8_PvEEiEEEESE_EEP15ScriptingObjectRNS1_6vectorIP6ObjectNS1_9allocatorISK_EEEEb($bundle,$tmpcast$byval_copy,$type,$output,0);
 STACKTOP = sp;return;
}
function __ZL12ForcePreloadR11AssetBundleRKNS_9AssetInfoEb($bundle,$info,$scriptOnly) {
 $bundle = $bundle|0;
 $info = $info|0;
 $scriptOnly = $scriptOnly|0;
 var $$byval_copy10 = 0, $$pre = 0, $$pre$i$i = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$012 = 0, $i1$08 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $phitmp = 0, $preloadObjects = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy10 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $preloadObjects = sp + 16|0;
 $4 = HEAP32[628512>>2]|0;
 HEAP32[$preloadObjects>>2] = 0;
 $5 = (($preloadObjects) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($preloadObjects) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($preloadObjects) + 12|0);
 HEAP32[$7>>2] = 0;
 $8 = (($info) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(0);
 L1: do {
  if ($10) {
   $11 = (($bundle) + 44|0);
   $17 = 1;$19 = 0;$28 = 0;$i$012 = 0;
   L3: while(1) {
    $12 = HEAP32[$info>>2]|0;
    $13 = (($12) + ($i$012))|0;
    $14 = HEAP32[$11>>2]|0;
    $15 = (($14) + ($13<<2)|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$6>>2] = $17;
    $18 = $19 & 2147483647;
    $20 = ($17>>>0)>($18>>>0);
    if ($20) {
     $21 = $19 << 1;
     $22 = ($21|0)==(0);
     $23 = $22 ? 1 : $21;
     $24 = ($18>>>0)<($23>>>0);
     do {
      if ($24) {
       $25 = ($19|0)>(-1);
       if ($25) {
        HEAP32[$7>>2] = $23;
        $26 = $23 << 2;
        $27 = HEAP32[$5>>2]|0;
        HEAP32[$1>>2] = $27;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
        $29 = (invoke_iiiiiiii(108,($28|0),($26|0),4,($$byval_copy10|0),0,(617192|0),370)|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         break L3;
        }
        HEAP32[$preloadObjects>>2] = $29;
        $113 = $29;
        break;
       } else {
        $32 = $23 << 2;
        $33 = HEAP32[$5>>2]|0;
        HEAP32[$2>>2] = $33;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
        $34 = (invoke_iiiiiii(102,($32|0),4,($$byval_copy10|0),0,(617192|0),352)|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break L3;
        }
        $37 = HEAP32[$preloadObjects>>2]|0;
        $38 = HEAP32[$6>>2]|0;
        $39 = $38 << 2;
        _memcpy(($34|0),($37|0),($39|0))|0;
        HEAP32[$7>>2] = $23;
        HEAP32[$preloadObjects>>2] = $34;
        $113 = $34;
        break;
       }
      } else {
       $113 = $28;
      }
     } while(0);
     $$pre$i$i = HEAP32[$6>>2]|0;
     $41 = $$pre$i$i;$43 = $113;
    } else {
     $41 = $17;$43 = $28;
    }
    $40 = (($41) + -1)|0;
    $42 = (($43) + ($40<<2)|0);
    HEAP32[$42>>2] = $16;
    $44 = (($i$012) + 1)|0;
    $45 = HEAP32[$8>>2]|0;
    $46 = ($44|0)<($45|0);
    if (!($46)) {
     label = 19;
     break L1;
    }
    $$pre = HEAP32[$6>>2]|0;
    $$pre17 = HEAP32[$7>>2]|0;
    $phitmp = (($$pre) + 1)|0;
    $17 = $phitmp;$19 = $$pre17;$28 = $43;$i$012 = $44;
   }
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $lpad$phi$index = $49;$lpad$phi$index3 = $50;
  } else {
   label = 19;
  }
 } while(0);
 L18: do {
  if ((label|0) == 19) {
   __THREW__ = 0;
   $59 = (invoke_i(90)|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if (!($61)) {
    $62 = (($bundle) + 88|0);
    __THREW__ = 0;
    invoke_viiiii(100,($59|0),($62|0),($preloadObjects|0),($scriptOnly|0),0);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if (!($64)) {
     $65 = HEAP32[$6>>2]|0;
     $66 = ($65|0)==(0);
     L23: do {
      if (!($66)) {
       $i1$08 = 0;
       L25: while(1) {
        $67 = HEAP32[$preloadObjects>>2]|0;
        $68 = (($67) + ($i1$08<<2)|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = ($69|0)==(0);
        do {
         if (!($70)) {
          HEAP32[$3>>2] = $69;
          $71 = HEAP32[560624>>2]|0;
          $72 = ($71|0)==(0|0);
          if (!($72)) {
           $73 = (($71) + 36|0);
           $74 = HEAP32[$73>>2]|0;
           $75 = (($71) + 4|0);
           $76 = HEAP32[$75>>2]|0;
           $77 = ($74|0)==($76|0);
           do {
            if ($77) {
             $78 = (($71) + 28|0);
             $79 = HEAP32[$78>>2]|0;
             $80 = (($71) + 32|0);
             $81 = HEAP32[$80>>2]|0;
             $82 = (($79) + ($81<<3)|0);
             $98 = $82;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy10,$71,$3);
             $83 = HEAP32[$$byval_copy10>>2]|0;
             $84 = ($83|0)==(-1);
             $85 = (($71) + 28|0);
             $86 = HEAP32[$85>>2]|0;
             if ($84) {
              $87 = (($71) + 32|0);
              $88 = HEAP32[$87>>2]|0;
              $89 = (($86) + ($88<<3)|0);
              $98 = $89;
              break;
             } else {
              $90 = (($86) + ($83<<3)|0);
              $98 = $90;
              break;
             }
            }
           } while(0);
           $91 = HEAP32[560624>>2]|0;
           $92 = (($91) + 28|0);
           $93 = HEAP32[$92>>2]|0;
           $94 = (($91) + 32|0);
           $95 = HEAP32[$94>>2]|0;
           $96 = (($93) + ($95<<3)|0);
           $97 = ($98|0)==($96|0);
           if (!($97)) {
            $99 = (($98) + 4|0);
            $100 = HEAP32[$99>>2]|0;
            $101 = ($100|0)==(0|0);
            if (!($101)) {
             break;
            }
           }
          }
          __THREW__ = 0;
          (invoke_ii(3215,($69|0))|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           break L25;
          }
         }
        } while(0);
        $104 = (($i1$08) + 1)|0;
        $105 = HEAP32[$6>>2]|0;
        $106 = ($104>>>0)<($105>>>0);
        if ($106) {
         $i1$08 = $104;
        } else {
         break L23;
        }
       }
       $47 = ___cxa_find_matching_catch()|0;
       $48 = tempRet0;
       $lpad$phi$index = $47;$lpad$phi$index3 = $48;
       break L18;
      }
     } while(0);
     $107 = HEAP32[$7>>2]|0;
     $108 = ($107|0)>(-1);
     if (!($108)) {
      STACKTOP = sp;return;
     }
     $109 = HEAP32[$preloadObjects>>2]|0;
     $110 = HEAP32[$5>>2]|0;
     HEAP32[$0>>2] = $110;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($109,$$byval_copy10);
     HEAP32[$preloadObjects>>2] = 0;
     STACKTOP = sp;return;
    }
   }
   $51 = ___cxa_find_matching_catch()|0;
   $52 = tempRet0;
   $lpad$phi$index = $51;$lpad$phi$index3 = $52;
  }
 } while(0);
 $53 = HEAP32[$7>>2]|0;
 $54 = ($53|0)>(-1);
 if (!($54)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $55 = HEAP32[$preloadObjects>>2]|0;
 $56 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $56;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($55|0),($$byval_copy10|0));
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if ($58) {
  $111 = ___cxa_find_matching_catch(0|0)|0;
  $112 = tempRet0;
  ___clang_call_terminate($111);
  // unreachable;
 }
 HEAP32[$preloadObjects>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN23PreloadManagerOperation19IntegrateTimeSlicedEi($this,$timeSliceMS) {
 $this = $this|0;
 $timeSliceMS = $timeSliceMS|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE6assignEPKc($this,$__s) {
 $this = $this|0;
 $__s = $__s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($__s|0))|0);
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $10 = $1;$8 = 10;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 & -2;
  $phitmp$i$i = (($5) + -1)|0;
  $6 = $4&255;
  $10 = $6;$8 = $phitmp$i$i;
 }
 $7 = ($8>>>0)<($0>>>0);
 $9 = $10 & 1;
 $11 = ($9<<24>>24)==(0);
 if ($7) {
  if ($11) {
   $25 = $10&255;
   $26 = $25 >>> 1;
   $28 = $26;
  } else {
   $23 = (($this) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $28 = $24;
  }
  $27 = (($0) - ($8))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$8,$27,$28,0,$28,$0,$__s);
  STACKTOP = sp;return ($this|0);
 }
 if ($11) {
  $14 = (($this) + 1|0);
  $15 = $14;
 } else {
  $12 = (($this) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $15 = $13;
 }
 _memmove(($15|0),($__s|0),($0|0))|0;
 $16 = (($15) + ($0)|0);
 HEAP8[$16>>0] = 0;
 $17 = HEAP8[$this>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $21 = $0 << 1;
  $22 = $21&255;
  HEAP8[$this>>0] = $22;
  STACKTOP = sp;return ($this|0);
 } else {
  $20 = (($this) + 4|0);
  HEAP32[$20>>2] = $0;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add,$__p_new_stuff) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 $__p_new_stuff = $__p_new_stuff|0;
 var $$byval_copy1 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (2147483630 - ($__old_cap))|0;
 $2 = ($1>>>0)<($__delta_cap>>>0);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($this) + 1|0);
  $20 = $8;
 } else {
  $6 = (($this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $20 = $7;
 }
 $9 = ($__old_cap>>>0)<(1073741799);
 if ($9) {
  $10 = (($__delta_cap) + ($__old_cap))|0;
  $11 = $__old_cap << 1;
  $12 = ($10>>>0)<($11>>>0);
  $13 = $12 ? $11 : $10;
  $14 = ($13>>>0)<(11);
  if ($14) {
   $17 = 11;
  } else {
   $15 = (($13) + 16)|0;
   $16 = $15 & -16;
   $17 = $16;
  }
 } else {
  $17 = 2147483631;
 }
 HEAP32[$0>>2] = 46;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($17,16,$$byval_copy1,0,617192,79)|0);
 $19 = ($__n_copy|0)==(0);
 if (!($19)) {
  _memcpy(($18|0),($20|0),($__n_copy|0))|0;
 }
 $21 = ($__n_add|0)==(0);
 if (!($21)) {
  $22 = (($18) + ($__n_copy)|0);
  _memcpy(($22|0),($__p_new_stuff|0),($__n_add|0))|0;
 }
 $23 = (($__old_sz) - ($__n_del))|0;
 $24 = ($23|0)==($__n_copy|0);
 if (!($24)) {
  $25 = (($23) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $26 = (($18) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $27 = (($20) + ($$sum1)|0);
  _memcpy(($26|0),($27|0),($25|0))|0;
 }
 $28 = ($__old_cap|0)==(10);
 if ($28) {
  $33 = (($this) + 8|0);
  HEAP32[$33>>2] = $18;
  $34 = $17 | 1;
  HEAP32[$this>>2] = $34;
  $35 = (($23) + ($__n_add))|0;
  $36 = (($this) + 4|0);
  HEAP32[$36>>2] = $35;
  $37 = (($18) + ($35)|0);
  HEAP8[$37>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($20|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  ___cxa_call_unexpected(($31|0));
  // unreachable;
 } else {
  $33 = (($this) + 8|0);
  HEAP32[$33>>2] = $18;
  $34 = $17 | 1;
  HEAP32[$this>>2] = $34;
  $35 = (($23) + ($__n_add))|0;
  $36 = (($this) + 4|0);
  HEAP32[$36>>2] = $35;
  $37 = (($18) + ($35)|0);
  HEAP8[$37>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN14AsyncOperation20SetCoroutineCallbackEPFvP6ObjectPvES1_S2_PFvS2_E($this,$func,$coroutineBehaviour,$userData,$cleanup) {
 $this = $this|0;
 $func = $func|0;
 $coroutineBehaviour = $coroutineBehaviour|0;
 $userData = $userData|0;
 $cleanup = $cleanup|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = ($coroutineBehaviour|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 0;
 } else {
  $2 = (($coroutineBehaviour) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $3;
 }
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = $func;
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = $cleanup;
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = $userData;
 STACKTOP = sp;return;
}
function __ZN14AsyncOperation15InvokeCoroutineEv($this) {
 $this = $this|0;
 var $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if (!($6)) {
   HEAP32[$0>>2] = $5;
   $7 = HEAP32[560624>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 11;
   } else {
    $9 = (($7) + 36|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    do {
     if ($13) {
      $14 = (($7) + 28|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($7) + 32|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($15) + ($17<<3)|0);
      $34 = $18;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$7,$0);
      $19 = HEAP32[$pos$i$i$i$i>>2]|0;
      $20 = ($19|0)==(-1);
      $21 = (($7) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      if ($20) {
       $23 = (($7) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $34 = $25;
       break;
      } else {
       $26 = (($22) + ($19<<3)|0);
       $34 = $26;
       break;
      }
     }
    } while(0);
    $27 = HEAP32[560624>>2]|0;
    $28 = (($27) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + ($31<<3)|0);
    $33 = ($34|0)==($32|0);
    if ($33) {
     label = 11;
    } else {
     $35 = (($34) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      label = 11;
     } else {
      $$0$i2 = $36;
     }
    }
   }
   if ((label|0) == 11) {
    $38 = HEAP32[$4>>2]|0;
    $39 = (__Z31ReadObjectFromPersistentManageri($38)|0);
    $40 = ($39|0)==(0|0);
    if ($40) {
     break;
    } else {
     $$0$i2 = $39;
    }
   }
   $41 = HEAP32[$1>>2]|0;
   $42 = (($this) + 16|0);
   $43 = HEAP32[$42>>2]|0;
   FUNCTION_TABLE_vii[$41 & 4095]($$0$i2,$43);
  }
 } while(0);
 $44 = (($this) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = (($this) + 16|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vi[$45 & 4095]($48);
 }
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14AsyncOperationD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN14AsyncOperationD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((617224 + 8|0));
 STACKTOP = sp;return;
}
function __ZN14AsyncOperation6RetainEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return;
}
function __ZN14AsyncOperation7ReleaseEv($this) {
 $this = $this|0;
 var $$not = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$0>>2]|0;
 $$not = ($3|0)!=(0);
 $4 = ($this|0)==(0|0);
 $or$cond = $4 | $$not;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vi[$7 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN14AsyncOperation11GetPriorityEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN14AsyncOperation11SetPriorityEi($this,$priority) {
 $this = $this|0;
 $priority = $priority|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13BuildSettingsC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$0 = 0, $$01 = 0, $$byval_copy19 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i29 = 0, $$pre$i$i$i$i$i37 = 0, $$pre$i$i$i31 = 0, $$pre$i$i$i39 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i20 = 0, $__p$0$i$i$i$i12 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, $i$01$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i21 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i25 = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i23 = 0;
 var $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i24 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy19 = sp + 56|0;
 $0 = sp + 52|0;
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = sp + 36|0;
 $5 = sp + 20|0;
 $6 = sp + 16|0;
 $7 = sp + 12|0;
 $8 = sp;
 $9 = sp + 24|0;
 $10 = HEAP32[$label>>2]|0;
 HEAP32[$7>>2] = $10;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$7+0>>2]|0;
 __ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy19,$mode);
 HEAP32[$this>>2] = ((617264 + 8|0));
 $11 = (($this) + 24|0);
 $12 = (($this) + 28|0);
 $13 = (($this) + 36|0);
 $14 = (($this) + 40|0);
 $15 = (($this) + 48|0);
 $16 = (($this) + 52|0);
 $17 = (($this) + 64|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 68|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 72|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 80|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 84|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 88|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 108|0);
 ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;
 $24 = (($this) + 124|0);
 ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;
 $25 = (($this) + 92|0);
 dest=$11+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP8[$25>>0] = 1;
 $26 = (($this) + 93|0);
 HEAP8[$26>>0] = 1;
 $27 = (($this) + 94|0);
 HEAP8[$27>>0] = 1;
 $28 = (($this) + 101|0);
 HEAP8[$28>>0] = 1;
 $29 = (($this) + 102|0);
 HEAP8[$29>>0] = 1;
 $30 = (($this) + 103|0);
 HEAP8[$30>>0] = 1;
 $31 = (($this) + 96|0);
 $32 = (($this) + 100|0);
 HEAP8[$31>>0]=0&255;HEAP8[$31+1>>0]=(0>>8)&255;HEAP8[$31+2>>0]=(0>>16)&255;HEAP8[$31+3>>0]=0>>24;
 HEAP8[$32>>0] = 1;
 $33 = (($this) + 104|0);
 HEAP8[$33>>0] = 1;
 $34 = (($this) + 105|0);
 HEAP8[$34>>0] = 1;
 $35 = (($this) + 95|0);
 HEAP8[$35>>0] = 1;
 $36 = (($this) + 107|0);
 HEAP8[$36>>0] = 0;
 $37 = (($this) + 106|0);
 HEAP8[$37>>0] = 1;
 HEAP8[$8>>0] = 10;
 $38 = (($8) + 1|0);
 ;HEAP8[$38+0>>0]=HEAP8[617376+0>>0]|0;HEAP8[$38+1>>0]=HEAP8[617376+1>>0]|0;HEAP8[$38+2>>0]=HEAP8[617376+2>>0]|0;HEAP8[$38+3>>0]=HEAP8[617376+3>>0]|0;HEAP8[$38+4>>0]=HEAP8[617376+4>>0]|0;
 $39 = (($8) + 6|0);
 HEAP8[$39>>0] = 0;
 __THREW__ = 0;
 (invoke_iii(2359,($24|0),($8|0))|0);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 L1: do {
  if ($41) {
   $106 = ___cxa_find_matching_catch()|0;
   $107 = tempRet0;
   $108 = HEAP8[$8>>0]|0;
   $109 = $108 & 1;
   $110 = ($109<<24>>24)==(0);
   if ($110) {
    $$0 = $107;$$01 = $106;
   } else {
    $111 = (($8) + 8|0);
    $112 = HEAP32[$111>>2]|0;
    HEAP32[$5>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($112|0),($$byval_copy19|0));
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    if ($114) {
     $115 = ___cxa_find_matching_catch()|0;
     $116 = tempRet0;
     ___cxa_call_unexpected(($115|0));
     // unreachable;
    } else {
     $$0 = $107;$$01 = $106;
    }
   }
  } else {
   $42 = HEAP8[$8>>0]|0;
   $43 = $42 & 1;
   $44 = ($43<<24>>24)==(0);
   if (!($44)) {
    $45 = (($8) + 8|0);
    $46 = HEAP32[$45>>2]|0;
    HEAP32[$6>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_vii(2591,($46|0),($$byval_copy19|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     $49 = ___cxa_find_matching_catch()|0;
     $50 = tempRet0;
     ___cxa_call_unexpected(($49|0));
     // unreachable;
    }
   }
   $51 = HEAP8[$24>>0]|0;
   $52 = $51 & 1;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    $54 = (($24) + 1|0);
    $55 = $51&255;
    $56 = $55 >>> 1;
    $65 = $56;$78 = $54;
    label = 10;
   } else {
    $57 = (($this) + 132|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($this) + 128|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60>>>0)>(4294967279);
    if ($61) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if (!($63)) {
      // unreachable;
     }
    } else {
     $65 = $60;$78 = $58;
     label = 10;
    }
   }
   do {
    if ((label|0) == 10) {
     $64 = ($65>>>0)<(11);
     if ($64) {
      $66 = $65 << 1;
      $67 = $66&255;
      HEAP8[$9>>0] = $67;
      $68 = (($9) + 1|0);
      $$pre$phiZ2D = $9;$81 = $67;$__p$0$i$i$i$i12 = $68;
     } else {
      $69 = (($65) + 16)|0;
      $70 = $69 & -16;
      __THREW__ = 0;
      $71 = (invoke_ii(2988,($70|0))|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       break;
      }
      $74 = (($9) + 8|0);
      HEAP32[$74>>2] = $71;
      $75 = $70 | 1;
      HEAP32[$9>>2] = $75;
      $76 = (($9) + 4|0);
      HEAP32[$76>>2] = $65;
      $77 = $75&255;
      $$pre$phiZ2D = $9;$81 = $77;$__p$0$i$i$i$i12 = $71;
     }
     _memcpy(($__p$0$i$i$i$i12|0),($78|0),($65|0))|0;
     $79 = (($__p$0$i$i$i$i12) + ($65)|0);
     HEAP8[$79>>0] = 0;
     $80 = $81 & 1;
     $82 = ($80<<24>>24)==(0);
     if ($82) {
      $85 = (($9) + 1|0);
      $86 = $85;
     } else {
      $83 = (($9) + 8|0);
      $84 = HEAP32[$83>>2]|0;
      $86 = $84;
     }
     __THREW__ = 0;
     $87 = (invoke_ii(3256,($86|0))|0);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      $117 = ___cxa_find_matching_catch()|0;
      $118 = tempRet0;
      $119 = HEAP8[$$pre$phiZ2D>>0]|0;
      $120 = $119 & 1;
      $121 = ($120<<24>>24)==(0);
      if ($121) {
       $$0 = $118;$$01 = $117;
       break L1;
      }
      $122 = (($9) + 8|0);
      $123 = HEAP32[$122>>2]|0;
      __ZdlPv($123);
      $$0 = $118;$$01 = $117;
      break L1;
     }
     $90 = (($this) + 120|0);
     HEAP32[$90>>2] = $87;
     $91 = HEAP8[$$pre$phiZ2D>>0]|0;
     $92 = $91 & 1;
     $93 = ($92<<24>>24)==(0);
     if (!($93)) {
      $94 = (($9) + 8|0);
      $95 = HEAP32[$94>>2]|0;
      __ZdlPv($95);
     }
     __THREW__ = 0;
     $96 = (invoke_i(78)|0);
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if (!($98)) {
      $i$01$i = 0;
      while(1) {
       $101 = ((($96) + ($i$01$i<<2)|0) + 448|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ($102|0)==(0|0);
       $100 = (($i$01$i) + 1)|0;
       if ($103) {
        break;
       }
       $99 = ($100|0)<(16);
       if ($99) {
        $i$01$i = $100;
       } else {
        label = 24;
        break;
       }
      }
      if ((label|0) == 24) {
       STACKTOP = sp;return;
      }
      HEAP32[$101>>2] = 146;
      STACKTOP = sp;return;
     }
    }
   } while(0);
   $104 = ___cxa_find_matching_catch()|0;
   $105 = tempRet0;
   $$0 = $105;$$01 = $104;
  }
 } while(0);
 $124 = HEAP8[$24>>0]|0;
 $125 = $124 & 1;
 $126 = ($125<<24>>24)==(0);
 if (!($126)) {
  $127 = (($this) + 132|0);
  $128 = HEAP32[$127>>2]|0;
  HEAP32[$4>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($128|0),($$byval_copy19|0));
  $129 = __THREW__; __THREW__ = 0;
  $130 = $129&1;
  if ($130) {
   $131 = ___cxa_find_matching_catch()|0;
   $132 = tempRet0;
   ___cxa_call_unexpected(($131|0));
   // unreachable;
  }
 }
 $133 = HEAP8[$23>>0]|0;
 $134 = $133 & 1;
 $135 = ($134<<24>>24)==(0);
 if (!($135)) {
  $136 = (($this) + 116|0);
  $137 = HEAP32[$136>>2]|0;
  HEAP32[$3>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($137|0),($$byval_copy19|0));
  $138 = __THREW__; __THREW__ = 0;
  $139 = $138&1;
  if ($139) {
   $140 = ___cxa_find_matching_catch()|0;
   $141 = tempRet0;
   ___cxa_call_unexpected(($140|0));
   // unreachable;
  }
 }
 $142 = HEAP32[$20>>2]|0;
 $143 = ($142|0)==(0|0);
 if (!($143)) {
  $144 = HEAP32[$21>>2]|0;
  $145 = ($144|0)==($142|0);
  if (!($145)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $142;
   $scevgep$i$i$i$i$i$i$i$i$i = (($144) + -32|0);
   $146 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($146)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $147 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 5;
   $148 = $147 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($144) + ($148<<5)|0);
   HEAP32[$21>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($142);
 }
 $149 = HEAP32[$17>>2]|0;
 $150 = ($149|0)==(0|0);
 if (!($150)) {
  $151 = HEAP32[$18>>2]|0;
  $152 = ($151|0)==($149|0);
  if (!($152)) {
   $__new_last2$i$i$i$i$i$i$i$i$i20 = $149;
   $scevgep$i$i$i$i$i$i$i$i$i21 = (($151) + -24|0);
   $153 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i20))|0;
   $uglygep$i$i$i$i$i$i$i$i$i23 = (($scevgep$i$i$i$i$i$i$i$i$i21) + ($153)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i24 = $uglygep$i$i$i$i$i$i$i$i$i23;
   $154 = (($uglygep3$i$i$i$i$i$i$i$i$i24>>>0) / 24)&-1;
   $155 = $154 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i25 = (($151) + (($155*24)|0)|0);
   HEAP32[$18>>2] = $scevgep4$i$i$i$i$i$i$i$i$i25;
  }
  __ZdlPv($149);
 }
 $156 = HEAP32[$15>>2]|0;
 $157 = ($156|0)==(0|0);
 if (!($157)) {
  $158 = HEAP32[$16>>2]|0;
  $159 = ($158|0)==($156|0);
  do {
   if ($159) {
    $173 = $156;
   } else {
    $161 = $158;
    while(1) {
     $160 = (($161) + -12|0);
     HEAP32[$16>>2] = $160;
     $162 = HEAP8[$160>>0]|0;
     $163 = $162 & 1;
     $164 = ($163<<24>>24)==(0);
     if ($164) {
      $166 = $160;
     } else {
      $167 = (($161) + -4|0);
      $168 = HEAP32[$167>>2]|0;
      HEAP32[$2>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($168|0),($$byval_copy19|0));
      $169 = __THREW__; __THREW__ = 0;
      $170 = $169&1;
      if ($170) {
       label = 52;
       break;
      }
      $$pre$i$i$i$i$i = HEAP32[$16>>2]|0;
      $166 = $$pre$i$i$i$i$i;
     }
     $165 = ($166|0)==($156|0);
     if ($165) {
      label = 53;
      break;
     } else {
      $161 = $166;
     }
    }
    if ((label|0) == 52) {
     $171 = ___cxa_find_matching_catch()|0;
     $172 = tempRet0;
     ___cxa_call_unexpected(($171|0));
     // unreachable;
    }
    else if ((label|0) == 53) {
     $$pre$i$i$i = HEAP32[$15>>2]|0;
     $173 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($173);
 }
 $174 = HEAP32[$13>>2]|0;
 $175 = ($174|0)==(0|0);
 if (!($175)) {
  $176 = HEAP32[$14>>2]|0;
  $177 = ($176|0)==($174|0);
  do {
   if ($177) {
    $191 = $174;
   } else {
    $179 = $176;
    while(1) {
     $178 = (($179) + -12|0);
     HEAP32[$14>>2] = $178;
     $180 = HEAP8[$178>>0]|0;
     $181 = $180 & 1;
     $182 = ($181<<24>>24)==(0);
     if ($182) {
      $184 = $178;
     } else {
      $185 = (($179) + -4|0);
      $186 = HEAP32[$185>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($186|0),($$byval_copy19|0));
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if ($188) {
       label = 62;
       break;
      }
      $$pre$i$i$i$i$i29 = HEAP32[$14>>2]|0;
      $184 = $$pre$i$i$i$i$i29;
     }
     $183 = ($184|0)==($174|0);
     if ($183) {
      label = 63;
      break;
     } else {
      $179 = $184;
     }
    }
    if ((label|0) == 62) {
     $189 = ___cxa_find_matching_catch()|0;
     $190 = tempRet0;
     ___cxa_call_unexpected(($189|0));
     // unreachable;
    }
    else if ((label|0) == 63) {
     $$pre$i$i$i31 = HEAP32[$13>>2]|0;
     $191 = $$pre$i$i$i31;
     break;
    }
   }
  } while(0);
  __ZdlPv($191);
 }
 $192 = HEAP32[$11>>2]|0;
 $193 = ($192|0)==(0|0);
 if (!($193)) {
  $194 = HEAP32[$12>>2]|0;
  $195 = ($194|0)==($192|0);
  do {
   if ($195) {
    $209 = $192;
   } else {
    $197 = $194;
    while(1) {
     $196 = (($197) + -12|0);
     HEAP32[$12>>2] = $196;
     $198 = HEAP8[$196>>0]|0;
     $199 = $198 & 1;
     $200 = ($199<<24>>24)==(0);
     if ($200) {
      $202 = $196;
     } else {
      $203 = (($197) + -4|0);
      $204 = HEAP32[$203>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($204|0),($$byval_copy19|0));
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if ($206) {
       label = 72;
       break;
      }
      $$pre$i$i$i$i$i37 = HEAP32[$12>>2]|0;
      $202 = $$pre$i$i$i$i$i37;
     }
     $201 = ($202|0)==($192|0);
     if ($201) {
      label = 73;
      break;
     } else {
      $197 = $202;
     }
    }
    if ((label|0) == 72) {
     $207 = ___cxa_find_matching_catch()|0;
     $208 = tempRet0;
     ___cxa_call_unexpected(($207|0));
     // unreachable;
    }
    else if ((label|0) == 73) {
     $$pre$i$i$i39 = HEAP32[$11>>2]|0;
     $209 = $$pre$i$i$i39;
     break;
    }
   }
  } while(0);
  __ZdlPv($209);
 }
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $210 = __THREW__; __THREW__ = 0;
 $211 = $210&1;
 if ($211) {
  $222 = ___cxa_find_matching_catch(0|0)|0;
  $223 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $224 = __THREW__; __THREW__ = 0;
  $225 = $224&1;
  if ($225) {
   $228 = ___cxa_find_matching_catch(0|0)|0;
   $229 = tempRet0;
   __THREW__ = 0;
   $230 = __THREW__; __THREW__ = 0;
   $231 = $230&1;
   if ($231) {
    $232 = ___cxa_find_matching_catch(0|0)|0;
    $233 = tempRet0;
    ___clang_call_terminate($232);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $228;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $226 = __THREW__; __THREW__ = 0;
  $227 = $226&1;
  if (!($227)) {
   $eh$lpad$body$indexZ2D = $222;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
  $234 = ___cxa_find_matching_catch(0|0)|0;
  $235 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $234;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $212 = __THREW__; __THREW__ = 0;
  $213 = $212&1;
  if ($213) {
   $214 = ___cxa_find_matching_catch(0|0)|0;
   $215 = tempRet0;
   __THREW__ = 0;
   $216 = __THREW__; __THREW__ = 0;
   $217 = $216&1;
   if ($217) {
    $218 = ___cxa_find_matching_catch(0|0)|0;
    $219 = tempRet0;
    ___clang_call_terminate($218);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $214;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $220 = __THREW__; __THREW__ = 0;
  $221 = $220&1;
  if (!($221)) {
   ___resumeException($$01|0);
   // unreachable;
  }
  $236 = ___cxa_find_matching_catch(0|0)|0;
  $237 = tempRet0;
  $eh$lpad$body$indexZ2D = $236;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __ZZN13BuildSettingsC1E10MemLabelId18ObjectCreationModeEN27initializedPreloadedPlugins7ForwardEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13BuildSettings13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$0 = 0, $$01 = 0, $$byval_copy5 = 0, $$pre = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$phiZ2D = 0, $$pre38 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i34 = 0, $i$036 = 0, $phitmp$i$i = 0, $phitmp40 = 0, $phitmp41 = 0, $phitmp42 = 0, $phitmp43 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy5 = sp;
 $0 = sp + 80|0;
 $1 = sp + 76|0;
 $2 = sp + 72|0;
 $3 = sp + 68|0;
 $4 = sp + 64|0;
 $5 = sp + 84|0;
 $6 = sp + 28|0;
 $7 = sp + 16|0;
 $8 = sp + 4|0;
 $9 = sp + 40|0;
 $10 = sp + 52|0;
 $11 = (($this) + 36|0);
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($11,$13,$15);
 $16 = HEAP32[$11>>2]|0;
 $17 = (($this) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16|0)==($18|0);
 L1: do {
  if ($19) {
   HEAP8[$6>>0] = 16;
   $20 = (($6) + 1|0);
   $21 = $20;
   $22 = $21;
   HEAP8[$22>>0]=1852399981&255;HEAP8[$22+1>>0]=(1852399981>>8)&255;HEAP8[$22+2>>0]=(1852399981>>16)&255;HEAP8[$22+3>>0]=1852399981>>24;
   $23 = (($21) + 4)|0;
   $24 = $23;
   HEAP8[$24>>0]=1635017028&255;HEAP8[$24+1>>0]=(1635017028>>8)&255;HEAP8[$24+2>>0]=(1635017028>>16)&255;HEAP8[$24+3>>0]=1635017028>>24;
   $25 = (($6) + 9|0);
   HEAP8[$25>>0] = 0;
   $26 = (($this) + 44|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($16|0)==($27|0);
   do {
    if ($28) {
     __THREW__ = 0;
     invoke_vii(2602,($11|0),($6|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      $$pre = HEAP8[$6>>0]|0;
      $phitmp40 = $$pre & 1;
      $phitmp41 = ($phitmp40<<24>>24)==(0);
      if ($phitmp41) {
       break;
      }
      $46 = (($6) + 8|0);
      $47 = HEAP32[$46>>2]|0;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_vii(2591,($47|0),($$byval_copy5|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if (!($49)) {
       break;
      }
      $50 = ___cxa_find_matching_catch()|0;
      $51 = tempRet0;
      ___cxa_call_unexpected(($50|0));
      // unreachable;
     }
     $69 = ___cxa_find_matching_catch()|0;
     $70 = tempRet0;
     $71 = HEAP8[$6>>0]|0;
     $72 = $71 & 1;
     $73 = ($72<<24>>24)==(0);
     if ($73) {
      $$0 = $70;$$01 = $69;
      ___resumeException($$01|0);
      // unreachable;
     }
     $74 = (($6) + 8|0);
     $75 = HEAP32[$74>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($75|0),($$byval_copy5|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      $78 = ___cxa_find_matching_catch()|0;
      $79 = tempRet0;
      ___cxa_call_unexpected(($78|0));
      // unreachable;
     } else {
      $$0 = $70;$$01 = $69;
      ___resumeException($$01|0);
      // unreachable;
     }
    } else {
     $29 = ($16|0)==(0|0);
     if ($29) {
      $43 = 0;
     } else {
      HEAP8[$16>>0] = 16;
      $30 = (($16) + 1|0);
      $31 = $20;
      $32 = $31;
      $33 = HEAPU8[$32>>0]|(HEAPU8[$32+1>>0]<<8)|(HEAPU8[$32+2>>0]<<16)|(HEAPU8[$32+3>>0]<<24);
      $34 = (($31) + 4)|0;
      $35 = $34;
      $36 = HEAPU8[$35>>0]|(HEAPU8[$35+1>>0]<<8)|(HEAPU8[$35+2>>0]<<16)|(HEAPU8[$35+3>>0]<<24);
      $37 = $30;
      $38 = $37;
      HEAP8[$38>>0]=$33&255;HEAP8[$38+1>>0]=($33>>8)&255;HEAP8[$38+2>>0]=($33>>16)&255;HEAP8[$38+3>>0]=$33>>24;
      $39 = (($37) + 4)|0;
      $40 = $39;
      HEAP8[$40>>0]=$36&255;HEAP8[$40+1>>0]=($36>>8)&255;HEAP8[$40+2>>0]=($36>>16)&255;HEAP8[$40+3>>0]=$36>>24;
      $41 = (($16) + 9|0);
      HEAP8[$41>>0] = 0;
      $$pre$i = HEAP32[$17>>2]|0;
      $43 = $$pre$i;
     }
     $42 = (($43) + 12|0);
     HEAP32[$17>>2] = $42;
    }
   } while(0);
   HEAP8[$7>>0] = 0;
   $52 = (($7) + 1|0);
   HEAP8[$52>>0] = 0;
   $53 = HEAP32[$14>>2]|0;
   $54 = (($this) + 32|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($53|0)==($55|0);
   if (!($56)) {
    $57 = ($53|0)==(0|0);
    if ($57) {
     $60 = 0;
    } else {
     HEAP8[$53>>0] = 0;
     $58 = (($53) + 1|0);
     HEAP8[$58>>0] = 0;
     $$pre$i13 = HEAP32[$14>>2]|0;
     $60 = $$pre$i13;
    }
    $59 = (($60) + 12|0);
    HEAP32[$14>>2] = $59;
    break;
   }
   __THREW__ = 0;
   invoke_vii(2602,($12|0),($7|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if (!($62)) {
    $$pre38 = HEAP8[$7>>0]|0;
    $phitmp42 = $$pre38 & 1;
    $phitmp43 = ($phitmp42<<24>>24)==(0);
    if ($phitmp43) {
     break;
    }
    $63 = (($7) + 8|0);
    $64 = HEAP32[$63>>2]|0;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($64|0),($$byval_copy5|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if (!($66)) {
     break;
    }
    $67 = ___cxa_find_matching_catch()|0;
    $68 = tempRet0;
    ___cxa_call_unexpected(($67|0));
    // unreachable;
   }
   $80 = ___cxa_find_matching_catch()|0;
   $81 = tempRet0;
   $82 = HEAP8[$7>>0]|0;
   $83 = $82 & 1;
   $84 = ($83<<24>>24)==(0);
   if ($84) {
    $$0 = $81;$$01 = $80;
    ___resumeException($$01|0);
    // unreachable;
   }
   $85 = (($7) + 8|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$2>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($86|0),($$byval_copy5|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    $$0 = $81;$$01 = $80;
    ___resumeException($$01|0);
    // unreachable;
   }
  } else {
   HEAP8[$8>>0] = 16;
   $91 = (($8) + 1|0);
   $92 = $91;
   $93 = $92;
   HEAP8[$93>>0]=1852399981&255;HEAP8[$93+1>>0]=(1852399981>>8)&255;HEAP8[$93+2>>0]=(1852399981>>16)&255;HEAP8[$93+3>>0]=1852399981>>24;
   $94 = (($92) + 4)|0;
   $95 = $94;
   HEAP8[$95>>0]=1635017028&255;HEAP8[$95+1>>0]=(1635017028>>8)&255;HEAP8[$95+2>>0]=(1635017028>>16)&255;HEAP8[$95+3>>0]=1635017028>>24;
   $96 = (($8) + 9|0);
   HEAP8[$96>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($16|0),($8|0))|0);
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   if ($98) {
    $172 = ___cxa_find_matching_catch()|0;
    $173 = tempRet0;
    $174 = HEAP8[$8>>0]|0;
    $175 = $174 & 1;
    $176 = ($175<<24>>24)==(0);
    if ($176) {
     $$0 = $173;$$01 = $172;
     ___resumeException($$01|0);
     // unreachable;
    }
    $177 = (($8) + 8|0);
    $178 = HEAP32[$177>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($178|0),($$byval_copy5|0));
    $179 = __THREW__; __THREW__ = 0;
    $180 = $179&1;
    if ($180) {
     $181 = ___cxa_find_matching_catch()|0;
     $182 = tempRet0;
     ___cxa_call_unexpected(($181|0));
     // unreachable;
    } else {
     $$0 = $173;$$01 = $172;
     ___resumeException($$01|0);
     // unreachable;
    }
   }
   $99 = HEAP8[$8>>0]|0;
   $100 = $99 & 1;
   $101 = ($100<<24>>24)==(0);
   if (!($101)) {
    $102 = (($8) + 8|0);
    $103 = HEAP32[$102>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($103|0),($$byval_copy5|0));
    $104 = __THREW__; __THREW__ = 0;
    $105 = $104&1;
    if ($105) {
     $116 = ___cxa_find_matching_catch()|0;
     $117 = tempRet0;
     ___cxa_call_unexpected(($116|0));
     // unreachable;
    }
   }
   $106 = HEAP32[$17>>2]|0;
   $107 = HEAP32[$11>>2]|0;
   $108 = $106;
   $109 = $107;
   $110 = (($108) - ($109))|0;
   $111 = (($110|0) / 12)&-1;
   $112 = ($111>>>0)>(1);
   if ($112) {
    $113 = (($9) + 1|0);
    $114 = (($9) + 8|0);
    $115 = (($9) + 4|0);
    $120 = $107;$i$036 = 1;
    L53: while(1) {
     $118 = (($i$036) + -1)|0;
     HEAP32[$$byval_copy5>>2] = $118;
     __Z6FormatPKcz($9,617392,$$byval_copy5);
     $119 = (($120) + (($i$036*12)|0)|0);
     $121 = HEAP8[$9>>0]|0;
     $122 = $121 & 1;
     $123 = ($122<<24>>24)==(0);
     if ($123) {
      $126 = $121&255;
      $127 = $126 >>> 1;
      $136 = $127;$144 = $113;
     } else {
      $124 = HEAP32[$114>>2]|0;
      $125 = HEAP32[$115>>2]|0;
      $136 = $125;$144 = $124;
     }
     $128 = HEAP8[$119>>0]|0;
     $129 = $128 & 1;
     $130 = ($129<<24>>24)==(0);
     if ($130) {
      $135 = 10;$138 = $128;
     } else {
      $131 = HEAP32[$119>>2]|0;
      $132 = $131 & -2;
      $phitmp$i$i = (($132) + -1)|0;
      $133 = $131&255;
      $135 = $phitmp$i$i;$138 = $133;
     }
     $134 = ($135>>>0)<($136>>>0);
     $137 = $138 & 1;
     $139 = ($137<<24>>24)==(0);
     do {
      if ($134) {
       if ($139) {
        $154 = $138&255;
        $155 = $154 >>> 1;
        $157 = $155;
       } else {
        $152 = ((($120) + (($i$036*12)|0)|0) + 4|0);
        $153 = HEAP32[$152>>2]|0;
        $157 = $153;
       }
       $156 = (($136) - ($135))|0;
       __THREW__ = 0;
       invoke_viiiiiiii(22,($119|0),($135|0),($156|0),($157|0),0,($157|0),($136|0),($144|0));
       $158 = __THREW__; __THREW__ = 0;
       $159 = $158&1;
       if ($159) {
        break L53;
       }
      } else {
       if ($139) {
        $142 = (($119) + 1|0);
        $143 = $142;
       } else {
        $140 = ((($120) + (($i$036*12)|0)|0) + 8|0);
        $141 = HEAP32[$140>>2]|0;
        $143 = $141;
       }
       _memmove(($143|0),($144|0),($136|0))|0;
       $145 = (($143) + ($136)|0);
       HEAP8[$145>>0] = 0;
       $146 = HEAP8[$119>>0]|0;
       $147 = $146 & 1;
       $148 = ($147<<24>>24)==(0);
       if ($148) {
        $150 = $136 << 1;
        $151 = $150&255;
        HEAP8[$119>>0] = $151;
        break;
       } else {
        $149 = ((($120) + (($i$036*12)|0)|0) + 4|0);
        HEAP32[$149>>2] = $136;
        break;
       }
      }
     } while(0);
     $160 = HEAP8[$9>>0]|0;
     $161 = $160 & 1;
     $162 = ($161<<24>>24)==(0);
     if (!($162)) {
      $163 = HEAP32[$114>>2]|0;
      __ZdlPv($163);
     }
     $164 = (($i$036) + 1)|0;
     $165 = HEAP32[$17>>2]|0;
     $166 = HEAP32[$11>>2]|0;
     $167 = $165;
     $168 = $166;
     $169 = (($167) - ($168))|0;
     $170 = (($169|0) / 12)&-1;
     $171 = ($164>>>0)<($170>>>0);
     if ($171) {
      $120 = $166;$i$036 = $164;
     } else {
      break L1;
     }
    }
    $183 = ___cxa_find_matching_catch()|0;
    $184 = tempRet0;
    $185 = HEAP8[$9>>0]|0;
    $186 = $185 & 1;
    $187 = ($186<<24>>24)==(0);
    if ($187) {
     $$0 = $184;$$01 = $183;
     ___resumeException($$01|0);
     // unreachable;
    }
    $188 = HEAP32[$114>>2]|0;
    __ZdlPv($188);
    $$0 = $184;$$01 = $183;
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $189 = (($this) + 124|0);
 $190 = HEAP8[$189>>0]|0;
 $191 = $190 & 1;
 $192 = ($191<<24>>24)==(0);
 if ($192) {
  $193 = (($189) + 1|0);
  $194 = $190&255;
  $195 = $194 >>> 1;
  $202 = $195;$213 = $193;
 } else {
  $196 = (($this) + 132|0);
  $197 = HEAP32[$196>>2]|0;
  $198 = (($this) + 128|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = ($199>>>0)>(4294967279);
  if ($200) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $202 = $199;$213 = $197;
  }
 }
 $201 = ($202>>>0)<(11);
 if ($201) {
  $203 = $202 << 1;
  $204 = $203&255;
  HEAP8[$10>>0] = $204;
  $205 = (($10) + 1|0);
  $$pre$phiZ2D = $10;$216 = $204;$__p$0$i$i$i$i34 = $205;
 } else {
  $206 = (($202) + 16)|0;
  $207 = $206 & -16;
  $208 = (__Znwj($207)|0);
  $209 = (($10) + 8|0);
  HEAP32[$209>>2] = $208;
  $210 = $207 | 1;
  HEAP32[$10>>2] = $210;
  $211 = (($10) + 4|0);
  HEAP32[$211>>2] = $202;
  $212 = $210&255;
  $$pre$phiZ2D = $10;$216 = $212;$__p$0$i$i$i$i34 = $208;
 }
 _memcpy(($__p$0$i$i$i$i34|0),($213|0),($202|0))|0;
 $214 = (($__p$0$i$i$i$i34) + ($202)|0);
 HEAP8[$214>>0] = 0;
 $215 = $216 & 1;
 $217 = ($215<<24>>24)==(0);
 if ($217) {
  $220 = (($10) + 1|0);
  $221 = $220;
 } else {
  $218 = (($10) + 8|0);
  $219 = HEAP32[$218>>2]|0;
  $221 = $219;
 }
 __THREW__ = 0;
 $222 = (invoke_ii(3256,($221|0))|0);
 $223 = __THREW__; __THREW__ = 0;
 $224 = $223&1;
 if ($224) {
  $231 = ___cxa_find_matching_catch()|0;
  $232 = tempRet0;
  $233 = HEAP8[$$pre$phiZ2D>>0]|0;
  $234 = $233 & 1;
  $235 = ($234<<24>>24)==(0);
  if ($235) {
   $$0 = $232;$$01 = $231;
   ___resumeException($$01|0);
   // unreachable;
  }
  $236 = (($10) + 8|0);
  $237 = HEAP32[$236>>2]|0;
  __ZdlPv($237);
  $$0 = $232;$$01 = $231;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $225 = (($this) + 120|0);
  HEAP32[$225>>2] = $222;
  $226 = HEAP8[$$pre$phiZ2D>>0]|0;
  $227 = $226 & 1;
  $228 = ($227<<24>>24)==(0);
  if ($228) {
   STACKTOP = sp;return;
  }
  $229 = (($10) + 8|0);
  $230 = HEAP32[$229>>2]|0;
  __ZdlPv($230);
  STACKTOP = sp;return;
 }
}
function __Z16GetBuildSettingsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(10)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z19GetBuildSettingsPtrv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24GetManagerPtrFromContexti(10)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z27RegisterClass_BuildSettingsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(141,147,0,0,0);
 STACKTOP = sp;return;
}
function __ZN13BuildSettings13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 13;
 dest=$3+0|0; src=617400+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 13|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,141,6,($0|0),136,(2416|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN13BuildSettings7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy2,1,16,617384,11)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1775,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(617384|0),11);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK13BuildSettings25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 141;
}
function __ZN13BuildSettings23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617416,617400,$this,0);
 __ZN13BuildSettings8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13BuildSettings23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617416,617400,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN13BuildSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13BuildSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13BuildSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13BuildSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13BuildSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13BuildSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13BuildSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13BuildSettings23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13BuildSettingsD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13BuildSettingsD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN13BuildSettingsD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3516,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN13BuildSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $size$i$i$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i23 = sp;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 HEAP32[$size$i$i$i23>>2] = $7;
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i23,4);
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==($14|0);
 if (!($16)) {
  $17 = $15;
  while(1) {
   __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$17,0);
   __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
   $18 = (($17) + 12|0);
   $19 = ($18|0)==($14|0);
   if ($19) {
    break;
   } else {
    $17 = $18;
   }
  }
 }
 $20 = (($this) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 48|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $21;
 $25 = $23;
 $26 = (($24) - ($25))|0;
 $27 = (($26|0) / 12)&-1;
 HEAP32[$size$i$i$i23>>2] = $27;
 $28 = HEAP32[$8>>2]|0;
 $29 = (($28) + 4|0);
 $30 = HEAP32[$11>>2]|0;
 $31 = ($29>>>0)<($30>>>0);
 if ($31) {
  HEAP32[$28>>2] = $27;
  HEAP32[$8>>2] = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i23,4);
 }
 $32 = HEAP32[$20>>2]|0;
 $33 = HEAP32[$22>>2]|0;
 $34 = ($33|0)==($32|0);
 if (!($34)) {
  $35 = $33;
  while(1) {
   __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$35,0);
   __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
   $36 = (($35) + 12|0);
   $37 = ($36|0)==($32|0);
   if ($37) {
    break;
   } else {
    $35 = $36;
   }
  }
 }
 $38 = (($this) + 92|0);
 $39 = HEAP32[$8>>2]|0;
 $40 = (($39) + 1|0);
 $41 = HEAP32[$11>>2]|0;
 $42 = ($40>>>0)<($41>>>0);
 if ($42) {
  $43 = HEAP8[$38>>0]|0;
  HEAP8[$39>>0] = $43;
  $44 = HEAP32[$8>>2]|0;
  $45 = (($44) + 1|0);
  HEAP32[$8>>2] = $45;
  $48 = $45;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$38,1);
  $$pre = HEAP32[$8>>2]|0;
  $48 = $$pre;
 }
 $46 = (($this) + 93|0);
 $47 = (($48) + 1|0);
 $49 = HEAP32[$11>>2]|0;
 $50 = ($47>>>0)<($49>>>0);
 if ($50) {
  $51 = HEAP8[$46>>0]|0;
  HEAP8[$48>>0] = $51;
  $52 = HEAP32[$8>>2]|0;
  $53 = (($52) + 1|0);
  HEAP32[$8>>2] = $53;
  $56 = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$46,1);
  $$pre26 = HEAP32[$8>>2]|0;
  $56 = $$pre26;
 }
 $54 = (($this) + 96|0);
 $55 = (($56) + 1|0);
 $57 = HEAP32[$11>>2]|0;
 $58 = ($55>>>0)<($57>>>0);
 if ($58) {
  $59 = HEAP8[$54>>0]|0;
  HEAP8[$56>>0] = $59;
  $60 = HEAP32[$8>>2]|0;
  $61 = (($60) + 1|0);
  HEAP32[$8>>2] = $61;
  $64 = $61;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$54,1);
  $$pre27 = HEAP32[$8>>2]|0;
  $64 = $$pre27;
 }
 $62 = (($this) + 97|0);
 $63 = (($64) + 1|0);
 $65 = HEAP32[$11>>2]|0;
 $66 = ($63>>>0)<($65>>>0);
 if ($66) {
  $67 = HEAP8[$62>>0]|0;
  HEAP8[$64>>0] = $67;
  $68 = HEAP32[$8>>2]|0;
  $69 = (($68) + 1|0);
  HEAP32[$8>>2] = $69;
  $72 = $69;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$62,1);
  $$pre28 = HEAP32[$8>>2]|0;
  $72 = $$pre28;
 }
 $70 = (($this) + 98|0);
 $71 = (($72) + 1|0);
 $73 = HEAP32[$11>>2]|0;
 $74 = ($71>>>0)<($73>>>0);
 if ($74) {
  $75 = HEAP8[$70>>0]|0;
  HEAP8[$72>>0] = $75;
  $76 = HEAP32[$8>>2]|0;
  $77 = (($76) + 1|0);
  HEAP32[$8>>2] = $77;
  $80 = $77;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$70,1);
  $$pre29 = HEAP32[$8>>2]|0;
  $80 = $$pre29;
 }
 $78 = (($this) + 99|0);
 $79 = (($80) + 1|0);
 $81 = HEAP32[$11>>2]|0;
 $82 = ($79>>>0)<($81>>>0);
 if ($82) {
  $83 = HEAP8[$78>>0]|0;
  HEAP8[$80>>0] = $83;
  $84 = HEAP32[$8>>2]|0;
  $85 = (($84) + 1|0);
  HEAP32[$8>>2] = $85;
  $88 = $85;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$78,1);
  $$pre30 = HEAP32[$8>>2]|0;
  $88 = $$pre30;
 }
 $86 = (($this) + 100|0);
 $87 = (($88) + 1|0);
 $89 = HEAP32[$11>>2]|0;
 $90 = ($87>>>0)<($89>>>0);
 if ($90) {
  $91 = HEAP8[$86>>0]|0;
  HEAP8[$88>>0] = $91;
  $92 = HEAP32[$8>>2]|0;
  $93 = (($92) + 1|0);
  HEAP32[$8>>2] = $93;
  $96 = $93;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$86,1);
  $$pre31 = HEAP32[$8>>2]|0;
  $96 = $$pre31;
 }
 $94 = (($this) + 101|0);
 $95 = (($96) + 1|0);
 $97 = HEAP32[$11>>2]|0;
 $98 = ($95>>>0)<($97>>>0);
 if ($98) {
  $99 = HEAP8[$94>>0]|0;
  HEAP8[$96>>0] = $99;
  $100 = HEAP32[$8>>2]|0;
  $101 = (($100) + 1|0);
  HEAP32[$8>>2] = $101;
  $104 = $101;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$94,1);
  $$pre32 = HEAP32[$8>>2]|0;
  $104 = $$pre32;
 }
 $102 = (($this) + 102|0);
 $103 = (($104) + 1|0);
 $105 = HEAP32[$11>>2]|0;
 $106 = ($103>>>0)<($105>>>0);
 if ($106) {
  $107 = HEAP8[$102>>0]|0;
  HEAP8[$104>>0] = $107;
  $108 = HEAP32[$8>>2]|0;
  $109 = (($108) + 1|0);
  HEAP32[$8>>2] = $109;
  $112 = $109;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$102,1);
  $$pre33 = HEAP32[$8>>2]|0;
  $112 = $$pre33;
 }
 $110 = (($this) + 103|0);
 $111 = (($112) + 1|0);
 $113 = HEAP32[$11>>2]|0;
 $114 = ($111>>>0)<($113>>>0);
 if ($114) {
  $115 = HEAP8[$110>>0]|0;
  HEAP8[$112>>0] = $115;
  $116 = HEAP32[$8>>2]|0;
  $117 = (($116) + 1|0);
  HEAP32[$8>>2] = $117;
  $120 = $117;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$110,1);
  $$pre34 = HEAP32[$8>>2]|0;
  $120 = $$pre34;
 }
 $118 = (($this) + 94|0);
 $119 = (($120) + 1|0);
 $121 = HEAP32[$11>>2]|0;
 $122 = ($119>>>0)<($121>>>0);
 if ($122) {
  $123 = HEAP8[$118>>0]|0;
  HEAP8[$120>>0] = $123;
  $124 = HEAP32[$8>>2]|0;
  $125 = (($124) + 1|0);
  HEAP32[$8>>2] = $125;
  $128 = $125;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$118,1);
  $$pre35 = HEAP32[$8>>2]|0;
  $128 = $$pre35;
 }
 $126 = (($this) + 95|0);
 $127 = (($128) + 1|0);
 $129 = HEAP32[$11>>2]|0;
 $130 = ($127>>>0)<($129>>>0);
 if ($130) {
  $131 = HEAP8[$126>>0]|0;
  HEAP8[$128>>0] = $131;
  $132 = HEAP32[$8>>2]|0;
  $133 = (($132) + 1|0);
  HEAP32[$8>>2] = $133;
  $136 = $133;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$126,1);
  $$pre36 = HEAP32[$8>>2]|0;
  $136 = $$pre36;
 }
 $134 = (($this) + 104|0);
 $135 = (($136) + 1|0);
 $137 = HEAP32[$11>>2]|0;
 $138 = ($135>>>0)<($137>>>0);
 if ($138) {
  $139 = HEAP8[$134>>0]|0;
  HEAP8[$136>>0] = $139;
  $140 = HEAP32[$8>>2]|0;
  $141 = (($140) + 1|0);
  HEAP32[$8>>2] = $141;
  $144 = $141;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$134,1);
  $$pre37 = HEAP32[$8>>2]|0;
  $144 = $$pre37;
 }
 $142 = (($this) + 105|0);
 $143 = (($144) + 1|0);
 $145 = HEAP32[$11>>2]|0;
 $146 = ($143>>>0)<($145>>>0);
 if ($146) {
  $147 = HEAP8[$142>>0]|0;
  HEAP8[$144>>0] = $147;
  $148 = HEAP32[$8>>2]|0;
  $149 = (($148) + 1|0);
  HEAP32[$8>>2] = $149;
  $152 = $149;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$142,1);
  $$pre38 = HEAP32[$8>>2]|0;
  $152 = $$pre38;
 }
 $150 = (($this) + 106|0);
 $151 = (($152) + 1|0);
 $153 = HEAP32[$11>>2]|0;
 $154 = ($151>>>0)<($153>>>0);
 if ($154) {
  $155 = HEAP8[$150>>0]|0;
  HEAP8[$152>>0] = $155;
  $156 = HEAP32[$8>>2]|0;
  $157 = (($156) + 1|0);
  HEAP32[$8>>2] = $157;
  $160 = $157;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$150,1);
  $$pre39 = HEAP32[$8>>2]|0;
  $160 = $$pre39;
 }
 $158 = (($this) + 107|0);
 $159 = (($160) + 1|0);
 $161 = HEAP32[$11>>2]|0;
 $162 = ($159>>>0)<($161>>>0);
 if ($162) {
  $163 = HEAP8[$158>>0]|0;
  HEAP8[$160>>0] = $163;
  $164 = HEAP32[$8>>2]|0;
  $165 = (($164) + 1|0);
  HEAP32[$8>>2] = $165;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$158,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $166 = (($this) + 124|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$166,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $167 = (($this) + 108|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$167,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $168 = (($this) + 68|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = (($this) + 64|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = $169;
 $173 = $171;
 $174 = (($172) - ($173))|0;
 $175 = (($174|0) / 24)&-1;
 HEAP32[$size$i$i$i23>>2] = $175;
 $176 = HEAP32[$8>>2]|0;
 $177 = (($176) + 4|0);
 $178 = HEAP32[$11>>2]|0;
 $179 = ($177>>>0)<($178>>>0);
 if ($179) {
  HEAP32[$176>>2] = $175;
  HEAP32[$8>>2] = $177;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i23,4);
 }
 $180 = HEAP32[$168>>2]|0;
 $181 = HEAP32[$170>>2]|0;
 $182 = ($181|0)==($180|0);
 if (!($182)) {
  $188 = $181;
  while(1) {
   $183 = HEAP32[$8>>2]|0;
   $184 = (($183) + 4|0);
   $185 = HEAP32[$11>>2]|0;
   $186 = ($184>>>0)<($185>>>0);
   if ($186) {
    $187 = HEAP32[$188>>2]|0;
    HEAP32[$183>>2] = $187;
    HEAP32[$8>>2] = $184;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$188,4);
   }
   $189 = (($188) + 8|0);
   __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($189,$transfer);
   $190 = (($188) + 24|0);
   $191 = ($190|0)==($180|0);
   if ($191) {
    break;
   } else {
    $188 = $190;
   }
  }
 }
 $192 = (($this) + 84|0);
 $193 = HEAP32[$192>>2]|0;
 $194 = (($this) + 80|0);
 $195 = HEAP32[$194>>2]|0;
 $196 = $193;
 $197 = $195;
 $198 = (($196) - ($197))|0;
 $199 = $198 >> 5;
 HEAP32[$size$i$i$i23>>2] = $199;
 $200 = HEAP32[$8>>2]|0;
 $201 = (($200) + 4|0);
 $202 = HEAP32[$11>>2]|0;
 $203 = ($201>>>0)<($202>>>0);
 if ($203) {
  HEAP32[$200>>2] = $199;
  HEAP32[$8>>2] = $201;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i23,4);
 }
 $204 = HEAP32[$192>>2]|0;
 $205 = HEAP32[$194>>2]|0;
 $206 = ($205|0)==($204|0);
 if ($206) {
  STACKTOP = sp;return;
 } else {
  $207 = $205;
 }
 while(1) {
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($207,$transfer);
  $208 = (($207) + 16|0);
  __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($208,$transfer);
  $209 = (($207) + 32|0);
  $210 = ($209|0)==($204|0);
  if ($210) {
   break;
  } else {
   $207 = $209;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13BuildSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $1 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 48|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$2,0);
 $3 = (($this) + 92|0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 1|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$3,1);
  $$pre = HEAP32[$4>>2]|0;
  $15 = $$pre;
 } else {
  $10 = HEAP8[$5>>0]|0;
  HEAP8[$3>>0] = $10;
  $11 = HEAP32[$4>>2]|0;
  $12 = (($11) + 1|0);
  HEAP32[$4>>2] = $12;
  $15 = $12;
 }
 $13 = (($this) + 93|0);
 $14 = (($15) + 1|0);
 $16 = HEAP32[$7>>2]|0;
 $17 = ($14>>>0)>($16>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$13,1);
  $$pre17 = HEAP32[$4>>2]|0;
  $23 = $$pre17;
 } else {
  $18 = HEAP8[$15>>0]|0;
  HEAP8[$13>>0] = $18;
  $19 = HEAP32[$4>>2]|0;
  $20 = (($19) + 1|0);
  HEAP32[$4>>2] = $20;
  $23 = $20;
 }
 $21 = (($this) + 96|0);
 $22 = (($23) + 1|0);
 $24 = HEAP32[$7>>2]|0;
 $25 = ($22>>>0)>($24>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$21,1);
  $$pre18 = HEAP32[$4>>2]|0;
  $31 = $$pre18;
 } else {
  $26 = HEAP8[$23>>0]|0;
  HEAP8[$21>>0] = $26;
  $27 = HEAP32[$4>>2]|0;
  $28 = (($27) + 1|0);
  HEAP32[$4>>2] = $28;
  $31 = $28;
 }
 $29 = (($this) + 97|0);
 $30 = (($31) + 1|0);
 $32 = HEAP32[$7>>2]|0;
 $33 = ($30>>>0)>($32>>>0);
 if ($33) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$29,1);
  $$pre19 = HEAP32[$4>>2]|0;
  $39 = $$pre19;
 } else {
  $34 = HEAP8[$31>>0]|0;
  HEAP8[$29>>0] = $34;
  $35 = HEAP32[$4>>2]|0;
  $36 = (($35) + 1|0);
  HEAP32[$4>>2] = $36;
  $39 = $36;
 }
 $37 = (($this) + 98|0);
 $38 = (($39) + 1|0);
 $40 = HEAP32[$7>>2]|0;
 $41 = ($38>>>0)>($40>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$37,1);
  $$pre20 = HEAP32[$4>>2]|0;
  $47 = $$pre20;
 } else {
  $42 = HEAP8[$39>>0]|0;
  HEAP8[$37>>0] = $42;
  $43 = HEAP32[$4>>2]|0;
  $44 = (($43) + 1|0);
  HEAP32[$4>>2] = $44;
  $47 = $44;
 }
 $45 = (($this) + 99|0);
 $46 = (($47) + 1|0);
 $48 = HEAP32[$7>>2]|0;
 $49 = ($46>>>0)>($48>>>0);
 if ($49) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$45,1);
  $$pre21 = HEAP32[$4>>2]|0;
  $55 = $$pre21;
 } else {
  $50 = HEAP8[$47>>0]|0;
  HEAP8[$45>>0] = $50;
  $51 = HEAP32[$4>>2]|0;
  $52 = (($51) + 1|0);
  HEAP32[$4>>2] = $52;
  $55 = $52;
 }
 $53 = (($this) + 100|0);
 $54 = (($55) + 1|0);
 $56 = HEAP32[$7>>2]|0;
 $57 = ($54>>>0)>($56>>>0);
 if ($57) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$53,1);
  $$pre22 = HEAP32[$4>>2]|0;
  $63 = $$pre22;
 } else {
  $58 = HEAP8[$55>>0]|0;
  HEAP8[$53>>0] = $58;
  $59 = HEAP32[$4>>2]|0;
  $60 = (($59) + 1|0);
  HEAP32[$4>>2] = $60;
  $63 = $60;
 }
 $61 = (($this) + 101|0);
 $62 = (($63) + 1|0);
 $64 = HEAP32[$7>>2]|0;
 $65 = ($62>>>0)>($64>>>0);
 if ($65) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$61,1);
  $$pre23 = HEAP32[$4>>2]|0;
  $71 = $$pre23;
 } else {
  $66 = HEAP8[$63>>0]|0;
  HEAP8[$61>>0] = $66;
  $67 = HEAP32[$4>>2]|0;
  $68 = (($67) + 1|0);
  HEAP32[$4>>2] = $68;
  $71 = $68;
 }
 $69 = (($this) + 102|0);
 $70 = (($71) + 1|0);
 $72 = HEAP32[$7>>2]|0;
 $73 = ($70>>>0)>($72>>>0);
 if ($73) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$69,1);
  $$pre24 = HEAP32[$4>>2]|0;
  $79 = $$pre24;
 } else {
  $74 = HEAP8[$71>>0]|0;
  HEAP8[$69>>0] = $74;
  $75 = HEAP32[$4>>2]|0;
  $76 = (($75) + 1|0);
  HEAP32[$4>>2] = $76;
  $79 = $76;
 }
 $77 = (($this) + 103|0);
 $78 = (($79) + 1|0);
 $80 = HEAP32[$7>>2]|0;
 $81 = ($78>>>0)>($80>>>0);
 if ($81) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$77,1);
  $$pre25 = HEAP32[$4>>2]|0;
  $87 = $$pre25;
 } else {
  $82 = HEAP8[$79>>0]|0;
  HEAP8[$77>>0] = $82;
  $83 = HEAP32[$4>>2]|0;
  $84 = (($83) + 1|0);
  HEAP32[$4>>2] = $84;
  $87 = $84;
 }
 $85 = (($this) + 94|0);
 $86 = (($87) + 1|0);
 $88 = HEAP32[$7>>2]|0;
 $89 = ($86>>>0)>($88>>>0);
 if ($89) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$85,1);
  $$pre26 = HEAP32[$4>>2]|0;
  $95 = $$pre26;
 } else {
  $90 = HEAP8[$87>>0]|0;
  HEAP8[$85>>0] = $90;
  $91 = HEAP32[$4>>2]|0;
  $92 = (($91) + 1|0);
  HEAP32[$4>>2] = $92;
  $95 = $92;
 }
 $93 = (($this) + 95|0);
 $94 = (($95) + 1|0);
 $96 = HEAP32[$7>>2]|0;
 $97 = ($94>>>0)>($96>>>0);
 if ($97) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$93,1);
  $$pre27 = HEAP32[$4>>2]|0;
  $103 = $$pre27;
 } else {
  $98 = HEAP8[$95>>0]|0;
  HEAP8[$93>>0] = $98;
  $99 = HEAP32[$4>>2]|0;
  $100 = (($99) + 1|0);
  HEAP32[$4>>2] = $100;
  $103 = $100;
 }
 $101 = (($this) + 104|0);
 $102 = (($103) + 1|0);
 $104 = HEAP32[$7>>2]|0;
 $105 = ($102>>>0)>($104>>>0);
 if ($105) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$101,1);
  $$pre28 = HEAP32[$4>>2]|0;
  $111 = $$pre28;
 } else {
  $106 = HEAP8[$103>>0]|0;
  HEAP8[$101>>0] = $106;
  $107 = HEAP32[$4>>2]|0;
  $108 = (($107) + 1|0);
  HEAP32[$4>>2] = $108;
  $111 = $108;
 }
 $109 = (($this) + 105|0);
 $110 = (($111) + 1|0);
 $112 = HEAP32[$7>>2]|0;
 $113 = ($110>>>0)>($112>>>0);
 if ($113) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$109,1);
  $$pre29 = HEAP32[$4>>2]|0;
  $119 = $$pre29;
 } else {
  $114 = HEAP8[$111>>0]|0;
  HEAP8[$109>>0] = $114;
  $115 = HEAP32[$4>>2]|0;
  $116 = (($115) + 1|0);
  HEAP32[$4>>2] = $116;
  $119 = $116;
 }
 $117 = (($this) + 106|0);
 $118 = (($119) + 1|0);
 $120 = HEAP32[$7>>2]|0;
 $121 = ($118>>>0)>($120>>>0);
 if ($121) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$117,1);
  $$pre30 = HEAP32[$4>>2]|0;
  $127 = $$pre30;
 } else {
  $122 = HEAP8[$119>>0]|0;
  HEAP8[$117>>0] = $122;
  $123 = HEAP32[$4>>2]|0;
  $124 = (($123) + 1|0);
  HEAP32[$4>>2] = $124;
  $127 = $124;
 }
 $125 = (($this) + 107|0);
 $126 = (($127) + 1|0);
 $128 = HEAP32[$7>>2]|0;
 $129 = ($126>>>0)>($128>>>0);
 if ($129) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$125,1);
 } else {
  $130 = HEAP8[$127>>0]|0;
  HEAP8[$125>>0] = $130;
  $131 = HEAP32[$4>>2]|0;
  $132 = (($131) + 1|0);
  HEAP32[$4>>2] = $132;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $133 = (($this) + 124|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$133,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $134 = (($this) + 108|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$134,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $135 = HEAP8[$133>>0]|0;
 $136 = $135 & 1;
 $137 = ($136<<24>>24)==(0);
 if ($137) {
  $138 = (($133) + 1|0);
  $139 = $135&255;
  $140 = $139 >>> 1;
  $147 = $140;$158 = $138;
 } else {
  $141 = (($this) + 132|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = (($this) + 128|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = ($144>>>0)>(4294967279);
  if ($145) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $147 = $144;$158 = $142;
  }
 }
 $146 = ($147>>>0)<(11);
 if ($146) {
  $148 = $147 << 1;
  $149 = $148&255;
  HEAP8[$0>>0] = $149;
  $150 = (($0) + 1|0);
  $$pre$phiZ2D = $0;$161 = $149;$__p$0$i$i$i$i = $150;
 } else {
  $151 = (($147) + 16)|0;
  $152 = $151 & -16;
  $153 = (__Znwj($152)|0);
  $154 = (($0) + 8|0);
  HEAP32[$154>>2] = $153;
  $155 = $152 | 1;
  HEAP32[$0>>2] = $155;
  $156 = (($0) + 4|0);
  HEAP32[$156>>2] = $147;
  $157 = $155&255;
  $$pre$phiZ2D = $0;$161 = $157;$__p$0$i$i$i$i = $153;
 }
 _memcpy(($__p$0$i$i$i$i|0),($158|0),($147|0))|0;
 $159 = (($__p$0$i$i$i$i) + ($147)|0);
 HEAP8[$159>>0] = 0;
 $160 = $161 & 1;
 $162 = ($160<<24>>24)==(0);
 if ($162) {
 } else {
 }
 __THREW__ = 0;
 $163 = __THREW__; __THREW__ = 0;
 $164 = $163&1;
 if ($164) {
  $172 = ___cxa_find_matching_catch()|0;
  $173 = tempRet0;
  $174 = HEAP8[$$pre$phiZ2D>>0]|0;
  $175 = $174 & 1;
  $176 = ($175<<24>>24)==(0);
  if ($176) {
   ___resumeException($172|0);
   // unreachable;
  }
  $177 = (($0) + 8|0);
  $178 = HEAP32[$177>>2]|0;
  __ZdlPv($178);
  ___resumeException($172|0);
  // unreachable;
 } else {
  $165 = HEAP8[$$pre$phiZ2D>>0]|0;
  $166 = $165 & 1;
  $167 = ($166<<24>>24)==(0);
  if ($167) {
   $170 = (($this) + 60|0);
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapIi7Hash128NSt3__14lessIiEENS4_9allocatorINS4_4pairIiS3_EEEEEEEvRT_17TransferMetaFlags($transfer,$170,0);
   $171 = (($this) + 76|0);
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapI7Hash128S3_NSt3__14lessIS3_EENS4_9allocatorINS4_4pairIS3_S3_EEEEEEEvRT_17TransferMetaFlags($transfer,$171,0);
   STACKTOP = sp;return;
  }
  $168 = (($0) + 8|0);
  $169 = HEAP32[$168>>2]|0;
  __ZdlPv($169);
  $170 = (($this) + 60|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapIi7Hash128NSt3__14lessIiEENS4_9allocatorINS4_4pairIiS3_EEEEEEEvRT_17TransferMetaFlags($transfer,$170,0);
  $171 = (($this) + 76|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapI7Hash128S3_NSt3__14lessIS3_EENS4_9allocatorINS4_4pairIS3_S3_EEEEEEEvRT_17TransferMetaFlags($transfer,$171,0);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapI7Hash128S3_NSt3__14lessIS3_EENS4_9allocatorINS4_4pairIS3_S3_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre10 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0;
 var $size = 0, $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre8 = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre8;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 5;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = (($data) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$25>>2]|0;
 $29 = $27;
 $30 = $28;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 5;
 $33 = ($32>>>0)<($24>>>0);
 if ($33) {
  $34 = (($24) - ($32))|0;
  __ZNSt3__16vectorINS_4pairI7Hash128S2_EENS_9allocatorIS3_EEE8__appendEj($25,$34);
  $$pre = HEAP32[$26>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre7 = HEAP32[$$phi$trans$insert>>2]|0;
  $42 = $$pre7;$43 = $$pre;
 } else {
  $35 = ($32>>>0)>($24>>>0);
  if ($35) {
   $36 = (($28) + ($24<<5)|0);
   $37 = ($27|0)==($36|0);
   if ($37) {
    $42 = $28;$43 = $27;
   } else {
    $__new_last2$i$i$i$i = $36;
    $scevgep$i$i$i$i = (($27) + -32|0);
    $38 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($38)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $39 = $uglygep3$i$i$i$i >>> 5;
    $40 = $39 ^ -1;
    $scevgep4$i$i$i$i = (($27) + ($40<<5)|0);
    HEAP32[$26>>2] = $scevgep4$i$i$i$i;
    $42 = $28;$43 = $scevgep4$i$i$i$i;
   }
  } else {
   $42 = $28;$43 = $27;
  }
 }
 $41 = ($42|0)==($43|0);
 if ($41) {
  STACKTOP = sp;return;
 } else {
  $44 = $42;
 }
 while(1) {
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($44,$this);
  $45 = (($44) + 16|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($45,$this);
  $46 = (($44) + 32|0);
  $47 = ($46|0)==($43|0);
  if ($47) {
   break;
  } else {
   $44 = $46;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_4pairI7Hash128S2_EENS_9allocatorIS3_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 5;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;HEAP32[$10+24>>2]=0|0;HEAP32[$10+28>>2]=0|0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 32|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 5;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(134217727);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 5;
 $23 = ($22>>>0)<(67108863);
 if ($23) {
  $24 = $21 >> 4;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i57 = 0;$31 = 0;
  } else {
   $$0$i56 = $26;
   label = 9;
  }
 } else {
  $$0$i56 = 134217727;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = $$0$i56 << 5;
  $29 = (__Znwj($28)|0);
  $$0$i57 = $$0$i56;$31 = $29;
 }
 $30 = (($31) + ($18<<5)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if ($32) {
   $35 = 0;
  } else {
   ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;HEAP32[$33+16>>2]=0|0;HEAP32[$33+20>>2]=0|0;HEAP32[$33+24>>2]=0|0;HEAP32[$33+28>>2]=0|0;
   $35 = $33;
  }
  $34 = (($35) + 32|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $34;
  }
 }
 $38 = (($31) + ($$0$i57<<5)|0);
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = $40;
 $42 = $39;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 5;
 $$sum = (($18) - ($44))|0;
 $45 = (($31) + ($$sum<<5)|0);
 _memcpy(($45|0),($39|0),($43|0))|0;
 HEAP32[$this>>2] = $45;
 HEAP32[$2>>2] = $34;
 HEAP32[$0>>2] = $38;
 $46 = ($39|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZdlPv($39);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapIi7Hash128NSt3__14lessIiEENS4_9allocatorINS4_4pairIiS3_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre10 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre8 = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre8;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = ($21*24)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = (($data) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$25>>2]|0;
 $29 = $27;
 $30 = $28;
 $31 = (($29) - ($30))|0;
 $32 = (($31|0) / 24)&-1;
 $33 = ($32>>>0)<($24>>>0);
 if ($33) {
  $34 = (($24) - ($32))|0;
  __ZNSt3__16vectorINS_4pairIi7Hash128EENS_9allocatorIS3_EEE8__appendEj($25,$34);
  $$pre = HEAP32[$26>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre7 = HEAP32[$$phi$trans$insert>>2]|0;
  $42 = $$pre7;$43 = $$pre;
 } else {
  $35 = ($32>>>0)>($24>>>0);
  if ($35) {
   $36 = (($28) + (($24*24)|0)|0);
   $37 = ($27|0)==($36|0);
   if ($37) {
    $42 = $28;$43 = $27;
   } else {
    $__new_last2$i$i$i$i = $36;
    $scevgep$i$i$i$i = (($27) + -24|0);
    $38 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($38)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $39 = (($uglygep3$i$i$i$i>>>0) / 24)&-1;
    $40 = $39 ^ -1;
    $scevgep4$i$i$i$i = (($27) + (($40*24)|0)|0);
    HEAP32[$26>>2] = $scevgep4$i$i$i$i;
    $42 = $28;$43 = $scevgep4$i$i$i$i;
   }
  } else {
   $42 = $28;$43 = $27;
  }
 }
 $41 = ($42|0)==($43|0);
 if ($41) {
  STACKTOP = sp;return;
 } else {
  $49 = $42;
 }
 while(1) {
  $44 = HEAP32[$1>>2]|0;
  $45 = (($44) + 4|0);
  $46 = HEAP32[$7>>2]|0;
  $47 = ($45>>>0)>($46>>>0);
  if ($47) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$49,4);
   $$pre$i$i$i$i$i = HEAP32[$49>>2]|0;
   $50 = $$pre$i$i$i$i$i;
  } else {
   $48 = HEAP32[$44>>2]|0;
   HEAP32[$49>>2] = $48;
   HEAP32[$1>>2] = $45;
   $50 = $48;
  }
  $51 = (_llvm_bswap_i32(($50|0))|0);
  HEAP32[$49>>2] = $51;
  $52 = (($49) + 8|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($52,$this);
  $53 = (($49) + 24|0);
  $54 = ($53|0)==($43|0);
  if ($54) {
   break;
  } else {
   $49 = $53;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_4pairIi7Hash128EENS_9allocatorIS3_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 24)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $13 = 0;
   } else {
    HEAP32[$10>>2] = 0;
    $11 = (($10) + 8|0);
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 24|0);
   HEAP32[$2>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$10 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($5) - ($17))|0;
 $19 = (($18|0) / 24)&-1;
 $20 = (($19) + ($__n))|0;
 $21 = ($20>>>0)>(178956970);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($4) - ($17))|0;
 $23 = (($22|0) / 24)&-1;
 $24 = ($23>>>0)<(89478485);
 if ($24) {
  $25 = $23 << 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 178956970;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = ($$0$i56*24)|0;
  $30 = (__Znwj($29)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + (($19*24)|0)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $37 = 0;
  } else {
   HEAP32[$34>>2] = 0;
   $35 = (($34) + 8|0);
   ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;
   $37 = $34;
  }
  $36 = (($37) + 24|0);
  $38 = (($$0$i2) + -1)|0;
  $39 = ($38|0)==(0);
  if ($39) {
   break;
  } else {
   $$0$i2 = $38;$34 = $36;
  }
 }
 $40 = (($32) + (($$0$i57*24)|0)|0);
 $41 = HEAP32[$this>>2]|0;
 $42 = HEAP32[$2>>2]|0;
 $43 = $42;
 $44 = $41;
 $45 = (($43) - ($44))|0;
 $46 = (($45|0) / -24)&-1;
 $$sum = (($46) + ($19))|0;
 $47 = (($32) + (($$sum*24)|0)|0);
 _memcpy(($47|0),($41|0),($45|0))|0;
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $36;
 HEAP32[$0>>2] = $40;
 $48 = ($41|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($41);
 STACKTOP = sp;return;
}
function __ZN13BuildSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $1 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 48|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$2,0);
 $3 = (($this) + 92|0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 1|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$3,1);
  $$pre = HEAP32[$4>>2]|0;
  $15 = $$pre;
 } else {
  $10 = HEAP8[$5>>0]|0;
  HEAP8[$3>>0] = $10;
  $11 = HEAP32[$4>>2]|0;
  $12 = (($11) + 1|0);
  HEAP32[$4>>2] = $12;
  $15 = $12;
 }
 $13 = (($this) + 93|0);
 $14 = (($15) + 1|0);
 $16 = HEAP32[$7>>2]|0;
 $17 = ($14>>>0)>($16>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$13,1);
  $$pre17 = HEAP32[$4>>2]|0;
  $23 = $$pre17;
 } else {
  $18 = HEAP8[$15>>0]|0;
  HEAP8[$13>>0] = $18;
  $19 = HEAP32[$4>>2]|0;
  $20 = (($19) + 1|0);
  HEAP32[$4>>2] = $20;
  $23 = $20;
 }
 $21 = (($this) + 96|0);
 $22 = (($23) + 1|0);
 $24 = HEAP32[$7>>2]|0;
 $25 = ($22>>>0)>($24>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$21,1);
  $$pre18 = HEAP32[$4>>2]|0;
  $31 = $$pre18;
 } else {
  $26 = HEAP8[$23>>0]|0;
  HEAP8[$21>>0] = $26;
  $27 = HEAP32[$4>>2]|0;
  $28 = (($27) + 1|0);
  HEAP32[$4>>2] = $28;
  $31 = $28;
 }
 $29 = (($this) + 97|0);
 $30 = (($31) + 1|0);
 $32 = HEAP32[$7>>2]|0;
 $33 = ($30>>>0)>($32>>>0);
 if ($33) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$29,1);
  $$pre19 = HEAP32[$4>>2]|0;
  $39 = $$pre19;
 } else {
  $34 = HEAP8[$31>>0]|0;
  HEAP8[$29>>0] = $34;
  $35 = HEAP32[$4>>2]|0;
  $36 = (($35) + 1|0);
  HEAP32[$4>>2] = $36;
  $39 = $36;
 }
 $37 = (($this) + 98|0);
 $38 = (($39) + 1|0);
 $40 = HEAP32[$7>>2]|0;
 $41 = ($38>>>0)>($40>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$37,1);
  $$pre20 = HEAP32[$4>>2]|0;
  $47 = $$pre20;
 } else {
  $42 = HEAP8[$39>>0]|0;
  HEAP8[$37>>0] = $42;
  $43 = HEAP32[$4>>2]|0;
  $44 = (($43) + 1|0);
  HEAP32[$4>>2] = $44;
  $47 = $44;
 }
 $45 = (($this) + 99|0);
 $46 = (($47) + 1|0);
 $48 = HEAP32[$7>>2]|0;
 $49 = ($46>>>0)>($48>>>0);
 if ($49) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$45,1);
  $$pre21 = HEAP32[$4>>2]|0;
  $55 = $$pre21;
 } else {
  $50 = HEAP8[$47>>0]|0;
  HEAP8[$45>>0] = $50;
  $51 = HEAP32[$4>>2]|0;
  $52 = (($51) + 1|0);
  HEAP32[$4>>2] = $52;
  $55 = $52;
 }
 $53 = (($this) + 100|0);
 $54 = (($55) + 1|0);
 $56 = HEAP32[$7>>2]|0;
 $57 = ($54>>>0)>($56>>>0);
 if ($57) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$53,1);
  $$pre22 = HEAP32[$4>>2]|0;
  $63 = $$pre22;
 } else {
  $58 = HEAP8[$55>>0]|0;
  HEAP8[$53>>0] = $58;
  $59 = HEAP32[$4>>2]|0;
  $60 = (($59) + 1|0);
  HEAP32[$4>>2] = $60;
  $63 = $60;
 }
 $61 = (($this) + 101|0);
 $62 = (($63) + 1|0);
 $64 = HEAP32[$7>>2]|0;
 $65 = ($62>>>0)>($64>>>0);
 if ($65) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$61,1);
  $$pre23 = HEAP32[$4>>2]|0;
  $71 = $$pre23;
 } else {
  $66 = HEAP8[$63>>0]|0;
  HEAP8[$61>>0] = $66;
  $67 = HEAP32[$4>>2]|0;
  $68 = (($67) + 1|0);
  HEAP32[$4>>2] = $68;
  $71 = $68;
 }
 $69 = (($this) + 102|0);
 $70 = (($71) + 1|0);
 $72 = HEAP32[$7>>2]|0;
 $73 = ($70>>>0)>($72>>>0);
 if ($73) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$69,1);
  $$pre24 = HEAP32[$4>>2]|0;
  $79 = $$pre24;
 } else {
  $74 = HEAP8[$71>>0]|0;
  HEAP8[$69>>0] = $74;
  $75 = HEAP32[$4>>2]|0;
  $76 = (($75) + 1|0);
  HEAP32[$4>>2] = $76;
  $79 = $76;
 }
 $77 = (($this) + 103|0);
 $78 = (($79) + 1|0);
 $80 = HEAP32[$7>>2]|0;
 $81 = ($78>>>0)>($80>>>0);
 if ($81) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$77,1);
  $$pre25 = HEAP32[$4>>2]|0;
  $87 = $$pre25;
 } else {
  $82 = HEAP8[$79>>0]|0;
  HEAP8[$77>>0] = $82;
  $83 = HEAP32[$4>>2]|0;
  $84 = (($83) + 1|0);
  HEAP32[$4>>2] = $84;
  $87 = $84;
 }
 $85 = (($this) + 94|0);
 $86 = (($87) + 1|0);
 $88 = HEAP32[$7>>2]|0;
 $89 = ($86>>>0)>($88>>>0);
 if ($89) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$85,1);
  $$pre26 = HEAP32[$4>>2]|0;
  $95 = $$pre26;
 } else {
  $90 = HEAP8[$87>>0]|0;
  HEAP8[$85>>0] = $90;
  $91 = HEAP32[$4>>2]|0;
  $92 = (($91) + 1|0);
  HEAP32[$4>>2] = $92;
  $95 = $92;
 }
 $93 = (($this) + 95|0);
 $94 = (($95) + 1|0);
 $96 = HEAP32[$7>>2]|0;
 $97 = ($94>>>0)>($96>>>0);
 if ($97) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$93,1);
  $$pre27 = HEAP32[$4>>2]|0;
  $103 = $$pre27;
 } else {
  $98 = HEAP8[$95>>0]|0;
  HEAP8[$93>>0] = $98;
  $99 = HEAP32[$4>>2]|0;
  $100 = (($99) + 1|0);
  HEAP32[$4>>2] = $100;
  $103 = $100;
 }
 $101 = (($this) + 104|0);
 $102 = (($103) + 1|0);
 $104 = HEAP32[$7>>2]|0;
 $105 = ($102>>>0)>($104>>>0);
 if ($105) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$101,1);
  $$pre28 = HEAP32[$4>>2]|0;
  $111 = $$pre28;
 } else {
  $106 = HEAP8[$103>>0]|0;
  HEAP8[$101>>0] = $106;
  $107 = HEAP32[$4>>2]|0;
  $108 = (($107) + 1|0);
  HEAP32[$4>>2] = $108;
  $111 = $108;
 }
 $109 = (($this) + 105|0);
 $110 = (($111) + 1|0);
 $112 = HEAP32[$7>>2]|0;
 $113 = ($110>>>0)>($112>>>0);
 if ($113) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$109,1);
  $$pre29 = HEAP32[$4>>2]|0;
  $119 = $$pre29;
 } else {
  $114 = HEAP8[$111>>0]|0;
  HEAP8[$109>>0] = $114;
  $115 = HEAP32[$4>>2]|0;
  $116 = (($115) + 1|0);
  HEAP32[$4>>2] = $116;
  $119 = $116;
 }
 $117 = (($this) + 106|0);
 $118 = (($119) + 1|0);
 $120 = HEAP32[$7>>2]|0;
 $121 = ($118>>>0)>($120>>>0);
 if ($121) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$117,1);
  $$pre30 = HEAP32[$4>>2]|0;
  $127 = $$pre30;
 } else {
  $122 = HEAP8[$119>>0]|0;
  HEAP8[$117>>0] = $122;
  $123 = HEAP32[$4>>2]|0;
  $124 = (($123) + 1|0);
  HEAP32[$4>>2] = $124;
  $127 = $124;
 }
 $125 = (($this) + 107|0);
 $126 = (($127) + 1|0);
 $128 = HEAP32[$7>>2]|0;
 $129 = ($126>>>0)>($128>>>0);
 if ($129) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$125,1);
 } else {
  $130 = HEAP8[$127>>0]|0;
  HEAP8[$125>>0] = $130;
  $131 = HEAP32[$4>>2]|0;
  $132 = (($131) + 1|0);
  HEAP32[$4>>2] = $132;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $133 = (($this) + 124|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$133,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $134 = (($this) + 108|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$134,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $135 = HEAP8[$133>>0]|0;
 $136 = $135 & 1;
 $137 = ($136<<24>>24)==(0);
 if ($137) {
  $138 = (($133) + 1|0);
  $139 = $135&255;
  $140 = $139 >>> 1;
  $147 = $140;$158 = $138;
 } else {
  $141 = (($this) + 132|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = (($this) + 128|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = ($144>>>0)>(4294967279);
  if ($145) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $147 = $144;$158 = $142;
  }
 }
 $146 = ($147>>>0)<(11);
 if ($146) {
  $148 = $147 << 1;
  $149 = $148&255;
  HEAP8[$0>>0] = $149;
  $150 = (($0) + 1|0);
  $$pre$phiZ2D = $0;$161 = $149;$__p$0$i$i$i$i = $150;
 } else {
  $151 = (($147) + 16)|0;
  $152 = $151 & -16;
  $153 = (__Znwj($152)|0);
  $154 = (($0) + 8|0);
  HEAP32[$154>>2] = $153;
  $155 = $152 | 1;
  HEAP32[$0>>2] = $155;
  $156 = (($0) + 4|0);
  HEAP32[$156>>2] = $147;
  $157 = $155&255;
  $$pre$phiZ2D = $0;$161 = $157;$__p$0$i$i$i$i = $153;
 }
 _memcpy(($__p$0$i$i$i$i|0),($158|0),($147|0))|0;
 $159 = (($__p$0$i$i$i$i) + ($147)|0);
 HEAP8[$159>>0] = 0;
 $160 = $161 & 1;
 $162 = ($160<<24>>24)==(0);
 if ($162) {
 } else {
 }
 __THREW__ = 0;
 $163 = __THREW__; __THREW__ = 0;
 $164 = $163&1;
 if ($164) {
  $172 = ___cxa_find_matching_catch()|0;
  $173 = tempRet0;
  $174 = HEAP8[$$pre$phiZ2D>>0]|0;
  $175 = $174 & 1;
  $176 = ($175<<24>>24)==(0);
  if ($176) {
   ___resumeException($172|0);
   // unreachable;
  }
  $177 = (($0) + 8|0);
  $178 = HEAP32[$177>>2]|0;
  __ZdlPv($178);
  ___resumeException($172|0);
  // unreachable;
 } else {
  $165 = HEAP8[$$pre$phiZ2D>>0]|0;
  $166 = $165 & 1;
  $167 = ($166<<24>>24)==(0);
  if ($167) {
   $170 = (($this) + 60|0);
   __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapIi7Hash128NSt3__14lessIiEENS4_9allocatorINS4_4pairIiS3_EEEEEEEvRT_17TransferMetaFlags($transfer,$170,0);
   $171 = (($this) + 76|0);
   __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapI7Hash128S3_NSt3__14lessIS3_EENS4_9allocatorINS4_4pairIS3_S3_EEEEEEEvRT_17TransferMetaFlags($transfer,$171,0);
   STACKTOP = sp;return;
  }
  $168 = (($0) + 8|0);
  $169 = HEAP32[$168>>2]|0;
  __ZdlPv($169);
  $170 = (($this) + 60|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapIi7Hash128NSt3__14lessIiEENS4_9allocatorINS4_4pairIiS3_EEEEEEEvRT_17TransferMetaFlags($transfer,$170,0);
  $171 = (($this) + 76|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapI7Hash128S3_NSt3__14lessIS3_EENS4_9allocatorINS4_4pairIS3_S3_EEEEEEEvRT_17TransferMetaFlags($transfer,$171,0);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapI7Hash128S3_NSt3__14lessIS3_EENS4_9allocatorINS4_4pairIS3_S3_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre7 = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $12 = $$pre7;$14 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre9 = HEAP32[$offset>>2]|0;
   $18 = $$pre9;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 5;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $29 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $29 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = (($data) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$20>>2]|0;
 $24 = $22;
 $25 = $23;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 5;
 $28 = ($27>>>0)<($29>>>0);
 if ($28) {
  $30 = (($29) - ($27))|0;
  __ZNSt3__16vectorINS_4pairI7Hash128S2_EENS_9allocatorIS3_EEE8__appendEj($20,$30);
  $$pre5 = HEAP32[$21>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre6 = HEAP32[$$phi$trans$insert>>2]|0;
  $38 = $$pre6;$39 = $$pre5;
 } else {
  $31 = ($27>>>0)>($29>>>0);
  if ($31) {
   $32 = (($23) + ($29<<5)|0);
   $33 = ($22|0)==($32|0);
   if ($33) {
    $38 = $23;$39 = $22;
   } else {
    $__new_last2$i$i$i$i = $32;
    $scevgep$i$i$i$i = (($22) + -32|0);
    $34 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($34)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $35 = $uglygep3$i$i$i$i >>> 5;
    $36 = $35 ^ -1;
    $scevgep4$i$i$i$i = (($22) + ($36<<5)|0);
    HEAP32[$21>>2] = $scevgep4$i$i$i$i;
    $38 = $23;$39 = $scevgep4$i$i$i$i;
   }
  } else {
   $38 = $23;$39 = $22;
  }
 }
 $37 = ($38|0)==($39|0);
 if ($37) {
  STACKTOP = sp;return;
 } else {
  $40 = $38;
 }
 while(1) {
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($40,$this);
  $41 = (($40) + 16|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($41,$this);
  $42 = (($40) + 32|0);
  $43 = ($42|0)==($39|0);
  if ($43) {
   break;
  } else {
   $40 = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapIi7Hash128NSt3__14lessIiEENS4_9allocatorINS4_4pairIiS3_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0;
 var $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre7 = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $12 = $$pre7;$14 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre9 = HEAP32[$offset>>2]|0;
   $18 = $$pre9;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = ($16*24)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $29 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $29 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = (($data) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$20>>2]|0;
 $24 = $22;
 $25 = $23;
 $26 = (($24) - ($25))|0;
 $27 = (($26|0) / 24)&-1;
 $28 = ($27>>>0)<($29>>>0);
 if ($28) {
  $30 = (($29) - ($27))|0;
  __ZNSt3__16vectorINS_4pairIi7Hash128EENS_9allocatorIS3_EEE8__appendEj($20,$30);
  $$pre5 = HEAP32[$21>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre6 = HEAP32[$$phi$trans$insert>>2]|0;
  $38 = $$pre6;$39 = $$pre5;
 } else {
  $31 = ($27>>>0)>($29>>>0);
  if ($31) {
   $32 = (($23) + (($29*24)|0)|0);
   $33 = ($22|0)==($32|0);
   if ($33) {
    $38 = $23;$39 = $22;
   } else {
    $__new_last2$i$i$i$i = $32;
    $scevgep$i$i$i$i = (($22) + -24|0);
    $34 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($34)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $35 = (($uglygep3$i$i$i$i>>>0) / 24)&-1;
    $36 = $35 ^ -1;
    $scevgep4$i$i$i$i = (($22) + (($36*24)|0)|0);
    HEAP32[$21>>2] = $scevgep4$i$i$i$i;
    $38 = $23;$39 = $scevgep4$i$i$i$i;
   }
  } else {
   $38 = $23;$39 = $22;
  }
 }
 $37 = ($38|0)==($39|0);
 if ($37) {
  STACKTOP = sp;return;
 } else {
  $45 = $38;
 }
 while(1) {
  $40 = HEAP32[$1>>2]|0;
  $41 = (($40) + 4|0);
  $42 = HEAP32[$7>>2]|0;
  $43 = ($41>>>0)>($42>>>0);
  if ($43) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$45,4);
  } else {
   $44 = HEAP32[$40>>2]|0;
   HEAP32[$45>>2] = $44;
   HEAP32[$1>>2] = $41;
  }
  $46 = (($45) + 8|0);
  __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($46,$this);
  $47 = (($45) + 24|0);
  $48 = ($47|0)==($39|0);
  if ($48) {
   break;
  } else {
   $45 = $47;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13BuildSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$phiZ2D = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i10 = 0, $$sum$i$i$i$i$i15 = 0, $$sum$i$i$i$i$i20 = 0, $$sum$i$i$i$i$i25 = 0, $$sum$i$i$i$i$i30 = 0, $$sum$i$i$i$i$i35 = 0, $$sum$i$i$i$i$i40 = 0, $$sum$i$i$i$i$i45 = 0, $$sum$i$i$i$i$i5 = 0, $$sum$i$i$i$i$i50 = 0, $$sum$i$i$i$i$i55 = 0, $$sum$i$i$i$i$i60 = 0, $$sum$i$i$i$i$i65 = 0, $$sum$i$i$i$i$i70 = 0, $$sum$i$i$i$i$i75 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i11 = 0, $$sum1$i$i$i$i$i16 = 0;
 var $$sum1$i$i$i$i$i21 = 0, $$sum1$i$i$i$i$i26 = 0, $$sum1$i$i$i$i$i31 = 0, $$sum1$i$i$i$i$i36 = 0, $$sum1$i$i$i$i$i41 = 0, $$sum1$i$i$i$i$i46 = 0, $$sum1$i$i$i$i$i51 = 0, $$sum1$i$i$i$i$i56 = 0, $$sum1$i$i$i$i$i6 = 0, $$sum1$i$i$i$i$i61 = 0, $$sum1$i$i$i$i$i66 = 0, $$sum1$i$i$i$i$i71 = 0, $$sum1$i$i$i$i$i76 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $converter$i$i83 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i83 = sp + 12|0;
 $0 = sp;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $1 = (($this) + 24|0);
 $2 = HEAP32[580760>>2]|0;
 $3 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617424,$2,$converter$i$i83,1)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ($3|0)>(0);
  if ($5) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
  } else {
   $6 = HEAP32[$converter$i$i83>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    (FUNCTION_TABLE_iii[$6 & 4095]($1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $8 = (($this) + 48|0);
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617432,$2,$converter$i$i83,1)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = ($9|0)>(0);
  if ($11) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$8,0);
  } else {
   $12 = HEAP32[$converter$i$i83>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    (FUNCTION_TABLE_iii[$12 & 4095]($8,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $14 = (($this) + 92|0);
 $15 = HEAP32[580544>>2]|0;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617456,$15,$converter$i$i83,0)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  do {
   if ($18) {
    $19 = (($transfer) + 12|0);
    $20 = (($transfer) + 80|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($transfer) + 16|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($transfer) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($transfer) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = Math_imul($29, $27)|0;
    $$sum$i$i$i$i$i = (($23) - ($30))|0;
    $31 = (($25) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$19>>2] = $31;
    $32 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($32)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $33 = (($25) + ($$sum1$i$i$i$i$i)|0);
     $34 = (($transfer) + 20|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($33>>>0)>($35>>>0);
     if (!($36)) {
      $37 = HEAP8[$31>>0]|0;
      HEAP8[$14>>0] = $37;
      $38 = HEAP32[$19>>2]|0;
      $39 = (($38) + 1|0);
      HEAP32[$19>>2] = $39;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($19,$14,1);
   } else {
    $40 = HEAP32[$converter$i$i83>>2]|0;
    $41 = ($40|0)==(0|0);
    if (!($41)) {
     (FUNCTION_TABLE_iii[$40 & 4095]($14,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $42 = (($this) + 93|0);
 $43 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617480,$15,$converter$i$i83,0)|0);
 $44 = ($43|0)==(0);
 if (!($44)) {
  $45 = ($43|0)>(0);
  do {
   if ($45) {
    $46 = (($transfer) + 12|0);
    $47 = (($transfer) + 80|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($transfer) + 16|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($transfer) + 28|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($transfer) + 32|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = Math_imul($56, $54)|0;
    $$sum$i$i$i$i$i5 = (($50) - ($57))|0;
    $58 = (($52) + ($$sum$i$i$i$i$i5)|0);
    HEAP32[$46>>2] = $58;
    $59 = ($$sum$i$i$i$i$i5|0)<(0);
    if (!($59)) {
     $$sum1$i$i$i$i$i6 = (($$sum$i$i$i$i$i5) + 1)|0;
     $60 = (($52) + ($$sum1$i$i$i$i$i6)|0);
     $61 = (($transfer) + 20|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($60>>>0)>($62>>>0);
     if (!($63)) {
      $64 = HEAP8[$58>>0]|0;
      HEAP8[$42>>0] = $64;
      $65 = HEAP32[$46>>2]|0;
      $66 = (($65) + 1|0);
      HEAP32[$46>>2] = $66;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($46,$42,1);
   } else {
    $67 = HEAP32[$converter$i$i83>>2]|0;
    $68 = ($67|0)==(0|0);
    if (!($68)) {
     (FUNCTION_TABLE_iii[$67 & 4095]($42,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $69 = (($this) + 96|0);
 $70 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617496,$15,$converter$i$i83,0)|0);
 $71 = ($70|0)==(0);
 if (!($71)) {
  $72 = ($70|0)>(0);
  do {
   if ($72) {
    $73 = (($transfer) + 12|0);
    $74 = (($transfer) + 80|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($75) + 12|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($transfer) + 16|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($transfer) + 28|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($transfer) + 32|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = Math_imul($83, $81)|0;
    $$sum$i$i$i$i$i10 = (($77) - ($84))|0;
    $85 = (($79) + ($$sum$i$i$i$i$i10)|0);
    HEAP32[$73>>2] = $85;
    $86 = ($$sum$i$i$i$i$i10|0)<(0);
    if (!($86)) {
     $$sum1$i$i$i$i$i11 = (($$sum$i$i$i$i$i10) + 1)|0;
     $87 = (($79) + ($$sum1$i$i$i$i$i11)|0);
     $88 = (($transfer) + 20|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = ($87>>>0)>($89>>>0);
     if (!($90)) {
      $91 = HEAP8[$85>>0]|0;
      HEAP8[$69>>0] = $91;
      $92 = HEAP32[$73>>2]|0;
      $93 = (($92) + 1|0);
      HEAP32[$73>>2] = $93;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($73,$69,1);
   } else {
    $94 = HEAP32[$converter$i$i83>>2]|0;
    $95 = ($94|0)==(0|0);
    if (!($95)) {
     (FUNCTION_TABLE_iii[$94 & 4095]($69,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $96 = (($this) + 97|0);
 $97 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617520,$15,$converter$i$i83,0)|0);
 $98 = ($97|0)==(0);
 if (!($98)) {
  $99 = ($97|0)>(0);
  do {
   if ($99) {
    $100 = (($transfer) + 12|0);
    $101 = (($transfer) + 80|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (($102) + 12|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($transfer) + 16|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = (($transfer) + 28|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = (($transfer) + 32|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = Math_imul($110, $108)|0;
    $$sum$i$i$i$i$i15 = (($104) - ($111))|0;
    $112 = (($106) + ($$sum$i$i$i$i$i15)|0);
    HEAP32[$100>>2] = $112;
    $113 = ($$sum$i$i$i$i$i15|0)<(0);
    if (!($113)) {
     $$sum1$i$i$i$i$i16 = (($$sum$i$i$i$i$i15) + 1)|0;
     $114 = (($106) + ($$sum1$i$i$i$i$i16)|0);
     $115 = (($transfer) + 20|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ($114>>>0)>($116>>>0);
     if (!($117)) {
      $118 = HEAP8[$112>>0]|0;
      HEAP8[$96>>0] = $118;
      $119 = HEAP32[$100>>2]|0;
      $120 = (($119) + 1|0);
      HEAP32[$100>>2] = $120;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($100,$96,1);
   } else {
    $121 = HEAP32[$converter$i$i83>>2]|0;
    $122 = ($121|0)==(0|0);
    if (!($122)) {
     (FUNCTION_TABLE_iii[$121 & 4095]($96,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $123 = (($this) + 98|0);
 $124 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617544,$15,$converter$i$i83,0)|0);
 $125 = ($124|0)==(0);
 if (!($125)) {
  $126 = ($124|0)>(0);
  do {
   if ($126) {
    $127 = (($transfer) + 12|0);
    $128 = (($transfer) + 80|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = (($129) + 12|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($transfer) + 16|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = (($transfer) + 28|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($transfer) + 32|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = Math_imul($137, $135)|0;
    $$sum$i$i$i$i$i20 = (($131) - ($138))|0;
    $139 = (($133) + ($$sum$i$i$i$i$i20)|0);
    HEAP32[$127>>2] = $139;
    $140 = ($$sum$i$i$i$i$i20|0)<(0);
    if (!($140)) {
     $$sum1$i$i$i$i$i21 = (($$sum$i$i$i$i$i20) + 1)|0;
     $141 = (($133) + ($$sum1$i$i$i$i$i21)|0);
     $142 = (($transfer) + 20|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = ($141>>>0)>($143>>>0);
     if (!($144)) {
      $145 = HEAP8[$139>>0]|0;
      HEAP8[$123>>0] = $145;
      $146 = HEAP32[$127>>2]|0;
      $147 = (($146) + 1|0);
      HEAP32[$127>>2] = $147;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($127,$123,1);
   } else {
    $148 = HEAP32[$converter$i$i83>>2]|0;
    $149 = ($148|0)==(0|0);
    if (!($149)) {
     (FUNCTION_TABLE_iii[$148 & 4095]($123,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $150 = (($this) + 99|0);
 $151 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617568,$15,$converter$i$i83,0)|0);
 $152 = ($151|0)==(0);
 if (!($152)) {
  $153 = ($151|0)>(0);
  do {
   if ($153) {
    $154 = (($transfer) + 12|0);
    $155 = (($transfer) + 80|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = (($156) + 12|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($transfer) + 16|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = (($transfer) + 28|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = (($transfer) + 32|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = Math_imul($164, $162)|0;
    $$sum$i$i$i$i$i25 = (($158) - ($165))|0;
    $166 = (($160) + ($$sum$i$i$i$i$i25)|0);
    HEAP32[$154>>2] = $166;
    $167 = ($$sum$i$i$i$i$i25|0)<(0);
    if (!($167)) {
     $$sum1$i$i$i$i$i26 = (($$sum$i$i$i$i$i25) + 1)|0;
     $168 = (($160) + ($$sum1$i$i$i$i$i26)|0);
     $169 = (($transfer) + 20|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = ($168>>>0)>($170>>>0);
     if (!($171)) {
      $172 = HEAP8[$166>>0]|0;
      HEAP8[$150>>0] = $172;
      $173 = HEAP32[$154>>2]|0;
      $174 = (($173) + 1|0);
      HEAP32[$154>>2] = $174;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($154,$150,1);
   } else {
    $175 = HEAP32[$converter$i$i83>>2]|0;
    $176 = ($175|0)==(0|0);
    if (!($176)) {
     (FUNCTION_TABLE_iii[$175 & 4095]($150,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $177 = (($this) + 100|0);
 $178 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617584,$15,$converter$i$i83,0)|0);
 $179 = ($178|0)==(0);
 if (!($179)) {
  $180 = ($178|0)>(0);
  do {
   if ($180) {
    $181 = (($transfer) + 12|0);
    $182 = (($transfer) + 80|0);
    $183 = HEAP32[$182>>2]|0;
    $184 = (($183) + 12|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = (($transfer) + 16|0);
    $187 = HEAP32[$186>>2]|0;
    $188 = (($transfer) + 28|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = (($transfer) + 32|0);
    $191 = HEAP32[$190>>2]|0;
    $192 = Math_imul($191, $189)|0;
    $$sum$i$i$i$i$i30 = (($185) - ($192))|0;
    $193 = (($187) + ($$sum$i$i$i$i$i30)|0);
    HEAP32[$181>>2] = $193;
    $194 = ($$sum$i$i$i$i$i30|0)<(0);
    if (!($194)) {
     $$sum1$i$i$i$i$i31 = (($$sum$i$i$i$i$i30) + 1)|0;
     $195 = (($187) + ($$sum1$i$i$i$i$i31)|0);
     $196 = (($transfer) + 20|0);
     $197 = HEAP32[$196>>2]|0;
     $198 = ($195>>>0)>($197>>>0);
     if (!($198)) {
      $199 = HEAP8[$193>>0]|0;
      HEAP8[$177>>0] = $199;
      $200 = HEAP32[$181>>2]|0;
      $201 = (($200) + 1|0);
      HEAP32[$181>>2] = $201;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($181,$177,1);
   } else {
    $202 = HEAP32[$converter$i$i83>>2]|0;
    $203 = ($202|0)==(0|0);
    if (!($203)) {
     (FUNCTION_TABLE_iii[$202 & 4095]($177,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $204 = (($this) + 101|0);
 $205 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617608,$15,$converter$i$i83,0)|0);
 $206 = ($205|0)==(0);
 if (!($206)) {
  $207 = ($205|0)>(0);
  do {
   if ($207) {
    $208 = (($transfer) + 12|0);
    $209 = (($transfer) + 80|0);
    $210 = HEAP32[$209>>2]|0;
    $211 = (($210) + 12|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = (($transfer) + 16|0);
    $214 = HEAP32[$213>>2]|0;
    $215 = (($transfer) + 28|0);
    $216 = HEAP32[$215>>2]|0;
    $217 = (($transfer) + 32|0);
    $218 = HEAP32[$217>>2]|0;
    $219 = Math_imul($218, $216)|0;
    $$sum$i$i$i$i$i35 = (($212) - ($219))|0;
    $220 = (($214) + ($$sum$i$i$i$i$i35)|0);
    HEAP32[$208>>2] = $220;
    $221 = ($$sum$i$i$i$i$i35|0)<(0);
    if (!($221)) {
     $$sum1$i$i$i$i$i36 = (($$sum$i$i$i$i$i35) + 1)|0;
     $222 = (($214) + ($$sum1$i$i$i$i$i36)|0);
     $223 = (($transfer) + 20|0);
     $224 = HEAP32[$223>>2]|0;
     $225 = ($222>>>0)>($224>>>0);
     if (!($225)) {
      $226 = HEAP8[$220>>0]|0;
      HEAP8[$204>>0] = $226;
      $227 = HEAP32[$208>>2]|0;
      $228 = (($227) + 1|0);
      HEAP32[$208>>2] = $228;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($208,$204,1);
   } else {
    $229 = HEAP32[$converter$i$i83>>2]|0;
    $230 = ($229|0)==(0|0);
    if (!($230)) {
     (FUNCTION_TABLE_iii[$229 & 4095]($204,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $231 = (($this) + 102|0);
 $232 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617624,$15,$converter$i$i83,0)|0);
 $233 = ($232|0)==(0);
 if (!($233)) {
  $234 = ($232|0)>(0);
  do {
   if ($234) {
    $235 = (($transfer) + 12|0);
    $236 = (($transfer) + 80|0);
    $237 = HEAP32[$236>>2]|0;
    $238 = (($237) + 12|0);
    $239 = HEAP32[$238>>2]|0;
    $240 = (($transfer) + 16|0);
    $241 = HEAP32[$240>>2]|0;
    $242 = (($transfer) + 28|0);
    $243 = HEAP32[$242>>2]|0;
    $244 = (($transfer) + 32|0);
    $245 = HEAP32[$244>>2]|0;
    $246 = Math_imul($245, $243)|0;
    $$sum$i$i$i$i$i40 = (($239) - ($246))|0;
    $247 = (($241) + ($$sum$i$i$i$i$i40)|0);
    HEAP32[$235>>2] = $247;
    $248 = ($$sum$i$i$i$i$i40|0)<(0);
    if (!($248)) {
     $$sum1$i$i$i$i$i41 = (($$sum$i$i$i$i$i40) + 1)|0;
     $249 = (($241) + ($$sum1$i$i$i$i$i41)|0);
     $250 = (($transfer) + 20|0);
     $251 = HEAP32[$250>>2]|0;
     $252 = ($249>>>0)>($251>>>0);
     if (!($252)) {
      $253 = HEAP8[$247>>0]|0;
      HEAP8[$231>>0] = $253;
      $254 = HEAP32[$235>>2]|0;
      $255 = (($254) + 1|0);
      HEAP32[$235>>2] = $255;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($235,$231,1);
   } else {
    $256 = HEAP32[$converter$i$i83>>2]|0;
    $257 = ($256|0)==(0|0);
    if (!($257)) {
     (FUNCTION_TABLE_iii[$256 & 4095]($231,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $258 = (($this) + 103|0);
 $259 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617640,$15,$converter$i$i83,0)|0);
 $260 = ($259|0)==(0);
 if (!($260)) {
  $261 = ($259|0)>(0);
  do {
   if ($261) {
    $262 = (($transfer) + 12|0);
    $263 = (($transfer) + 80|0);
    $264 = HEAP32[$263>>2]|0;
    $265 = (($264) + 12|0);
    $266 = HEAP32[$265>>2]|0;
    $267 = (($transfer) + 16|0);
    $268 = HEAP32[$267>>2]|0;
    $269 = (($transfer) + 28|0);
    $270 = HEAP32[$269>>2]|0;
    $271 = (($transfer) + 32|0);
    $272 = HEAP32[$271>>2]|0;
    $273 = Math_imul($272, $270)|0;
    $$sum$i$i$i$i$i45 = (($266) - ($273))|0;
    $274 = (($268) + ($$sum$i$i$i$i$i45)|0);
    HEAP32[$262>>2] = $274;
    $275 = ($$sum$i$i$i$i$i45|0)<(0);
    if (!($275)) {
     $$sum1$i$i$i$i$i46 = (($$sum$i$i$i$i$i45) + 1)|0;
     $276 = (($268) + ($$sum1$i$i$i$i$i46)|0);
     $277 = (($transfer) + 20|0);
     $278 = HEAP32[$277>>2]|0;
     $279 = ($276>>>0)>($278>>>0);
     if (!($279)) {
      $280 = HEAP8[$274>>0]|0;
      HEAP8[$258>>0] = $280;
      $281 = HEAP32[$262>>2]|0;
      $282 = (($281) + 1|0);
      HEAP32[$262>>2] = $282;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($262,$258,1);
   } else {
    $283 = HEAP32[$converter$i$i83>>2]|0;
    $284 = ($283|0)==(0|0);
    if (!($284)) {
     (FUNCTION_TABLE_iii[$283 & 4095]($258,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $285 = (($this) + 94|0);
 $286 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617664,$15,$converter$i$i83,0)|0);
 $287 = ($286|0)==(0);
 if (!($287)) {
  $288 = ($286|0)>(0);
  do {
   if ($288) {
    $289 = (($transfer) + 12|0);
    $290 = (($transfer) + 80|0);
    $291 = HEAP32[$290>>2]|0;
    $292 = (($291) + 12|0);
    $293 = HEAP32[$292>>2]|0;
    $294 = (($transfer) + 16|0);
    $295 = HEAP32[$294>>2]|0;
    $296 = (($transfer) + 28|0);
    $297 = HEAP32[$296>>2]|0;
    $298 = (($transfer) + 32|0);
    $299 = HEAP32[$298>>2]|0;
    $300 = Math_imul($299, $297)|0;
    $$sum$i$i$i$i$i50 = (($293) - ($300))|0;
    $301 = (($295) + ($$sum$i$i$i$i$i50)|0);
    HEAP32[$289>>2] = $301;
    $302 = ($$sum$i$i$i$i$i50|0)<(0);
    if (!($302)) {
     $$sum1$i$i$i$i$i51 = (($$sum$i$i$i$i$i50) + 1)|0;
     $303 = (($295) + ($$sum1$i$i$i$i$i51)|0);
     $304 = (($transfer) + 20|0);
     $305 = HEAP32[$304>>2]|0;
     $306 = ($303>>>0)>($305>>>0);
     if (!($306)) {
      $307 = HEAP8[$301>>0]|0;
      HEAP8[$285>>0] = $307;
      $308 = HEAP32[$289>>2]|0;
      $309 = (($308) + 1|0);
      HEAP32[$289>>2] = $309;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($289,$285,1);
   } else {
    $310 = HEAP32[$converter$i$i83>>2]|0;
    $311 = ($310|0)==(0|0);
    if (!($311)) {
     (FUNCTION_TABLE_iii[$310 & 4095]($285,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $312 = (($this) + 95|0);
 $313 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617688,$15,$converter$i$i83,0)|0);
 $314 = ($313|0)==(0);
 if (!($314)) {
  $315 = ($313|0)>(0);
  do {
   if ($315) {
    $316 = (($transfer) + 12|0);
    $317 = (($transfer) + 80|0);
    $318 = HEAP32[$317>>2]|0;
    $319 = (($318) + 12|0);
    $320 = HEAP32[$319>>2]|0;
    $321 = (($transfer) + 16|0);
    $322 = HEAP32[$321>>2]|0;
    $323 = (($transfer) + 28|0);
    $324 = HEAP32[$323>>2]|0;
    $325 = (($transfer) + 32|0);
    $326 = HEAP32[$325>>2]|0;
    $327 = Math_imul($326, $324)|0;
    $$sum$i$i$i$i$i55 = (($320) - ($327))|0;
    $328 = (($322) + ($$sum$i$i$i$i$i55)|0);
    HEAP32[$316>>2] = $328;
    $329 = ($$sum$i$i$i$i$i55|0)<(0);
    if (!($329)) {
     $$sum1$i$i$i$i$i56 = (($$sum$i$i$i$i$i55) + 1)|0;
     $330 = (($322) + ($$sum1$i$i$i$i$i56)|0);
     $331 = (($transfer) + 20|0);
     $332 = HEAP32[$331>>2]|0;
     $333 = ($330>>>0)>($332>>>0);
     if (!($333)) {
      $334 = HEAP8[$328>>0]|0;
      HEAP8[$312>>0] = $334;
      $335 = HEAP32[$316>>2]|0;
      $336 = (($335) + 1|0);
      HEAP32[$316>>2] = $336;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($316,$312,1);
   } else {
    $337 = HEAP32[$converter$i$i83>>2]|0;
    $338 = ($337|0)==(0|0);
    if (!($338)) {
     (FUNCTION_TABLE_iii[$337 & 4095]($312,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $339 = (($this) + 104|0);
 $340 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617712,$15,$converter$i$i83,0)|0);
 $341 = ($340|0)==(0);
 if (!($341)) {
  $342 = ($340|0)>(0);
  L163: do {
   if ($342) {
    $343 = (($transfer) + 12|0);
    $344 = (($transfer) + 80|0);
    $345 = HEAP32[$344>>2]|0;
    $346 = (($345) + 12|0);
    $347 = HEAP32[$346>>2]|0;
    $348 = (($transfer) + 16|0);
    $349 = HEAP32[$348>>2]|0;
    $350 = (($transfer) + 28|0);
    $351 = HEAP32[$350>>2]|0;
    $352 = (($transfer) + 32|0);
    $353 = HEAP32[$352>>2]|0;
    $354 = Math_imul($353, $351)|0;
    $$sum$i$i$i$i$i60 = (($347) - ($354))|0;
    $355 = (($349) + ($$sum$i$i$i$i$i60)|0);
    HEAP32[$343>>2] = $355;
    $356 = ($$sum$i$i$i$i$i60|0)<(0);
    do {
     if (!($356)) {
      $$sum1$i$i$i$i$i61 = (($$sum$i$i$i$i$i60) + 1)|0;
      $357 = (($349) + ($$sum1$i$i$i$i$i61)|0);
      $358 = (($transfer) + 20|0);
      $359 = HEAP32[$358>>2]|0;
      $360 = ($357>>>0)>($359>>>0);
      if ($360) {
       break;
      }
      $361 = HEAP8[$355>>0]|0;
      HEAP8[$339>>0] = $361;
      $362 = HEAP32[$343>>2]|0;
      $363 = (($362) + 1|0);
      HEAP32[$343>>2] = $363;
      break L163;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($343,$339,1);
   } else {
    $364 = HEAP32[$converter$i$i83>>2]|0;
    $365 = ($364|0)==(0|0);
    if (!($365)) {
     (FUNCTION_TABLE_iii[$364 & 4095]($339,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $366 = (($this) + 105|0);
 $367 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617728,$15,$converter$i$i83,0)|0);
 $368 = ($367|0)==(0);
 if (!($368)) {
  $369 = ($367|0)>(0);
  L175: do {
   if ($369) {
    $370 = (($transfer) + 12|0);
    $371 = (($transfer) + 80|0);
    $372 = HEAP32[$371>>2]|0;
    $373 = (($372) + 12|0);
    $374 = HEAP32[$373>>2]|0;
    $375 = (($transfer) + 16|0);
    $376 = HEAP32[$375>>2]|0;
    $377 = (($transfer) + 28|0);
    $378 = HEAP32[$377>>2]|0;
    $379 = (($transfer) + 32|0);
    $380 = HEAP32[$379>>2]|0;
    $381 = Math_imul($380, $378)|0;
    $$sum$i$i$i$i$i65 = (($374) - ($381))|0;
    $382 = (($376) + ($$sum$i$i$i$i$i65)|0);
    HEAP32[$370>>2] = $382;
    $383 = ($$sum$i$i$i$i$i65|0)<(0);
    do {
     if (!($383)) {
      $$sum1$i$i$i$i$i66 = (($$sum$i$i$i$i$i65) + 1)|0;
      $384 = (($376) + ($$sum1$i$i$i$i$i66)|0);
      $385 = (($transfer) + 20|0);
      $386 = HEAP32[$385>>2]|0;
      $387 = ($384>>>0)>($386>>>0);
      if ($387) {
       break;
      }
      $388 = HEAP8[$382>>0]|0;
      HEAP8[$366>>0] = $388;
      $389 = HEAP32[$370>>2]|0;
      $390 = (($389) + 1|0);
      HEAP32[$370>>2] = $390;
      break L175;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($370,$366,1);
   } else {
    $391 = HEAP32[$converter$i$i83>>2]|0;
    $392 = ($391|0)==(0|0);
    if (!($392)) {
     (FUNCTION_TABLE_iii[$391 & 4095]($366,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $393 = (($this) + 106|0);
 $394 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617752,$15,$converter$i$i83,0)|0);
 $395 = ($394|0)==(0);
 if (!($395)) {
  $396 = ($394|0)>(0);
  L187: do {
   if ($396) {
    $397 = (($transfer) + 12|0);
    $398 = (($transfer) + 80|0);
    $399 = HEAP32[$398>>2]|0;
    $400 = (($399) + 12|0);
    $401 = HEAP32[$400>>2]|0;
    $402 = (($transfer) + 16|0);
    $403 = HEAP32[$402>>2]|0;
    $404 = (($transfer) + 28|0);
    $405 = HEAP32[$404>>2]|0;
    $406 = (($transfer) + 32|0);
    $407 = HEAP32[$406>>2]|0;
    $408 = Math_imul($407, $405)|0;
    $$sum$i$i$i$i$i70 = (($401) - ($408))|0;
    $409 = (($403) + ($$sum$i$i$i$i$i70)|0);
    HEAP32[$397>>2] = $409;
    $410 = ($$sum$i$i$i$i$i70|0)<(0);
    do {
     if (!($410)) {
      $$sum1$i$i$i$i$i71 = (($$sum$i$i$i$i$i70) + 1)|0;
      $411 = (($403) + ($$sum1$i$i$i$i$i71)|0);
      $412 = (($transfer) + 20|0);
      $413 = HEAP32[$412>>2]|0;
      $414 = ($411>>>0)>($413>>>0);
      if ($414) {
       break;
      }
      $415 = HEAP8[$409>>0]|0;
      HEAP8[$393>>0] = $415;
      $416 = HEAP32[$397>>2]|0;
      $417 = (($416) + 1|0);
      HEAP32[$397>>2] = $417;
      break L187;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($397,$393,1);
   } else {
    $418 = HEAP32[$converter$i$i83>>2]|0;
    $419 = ($418|0)==(0|0);
    if ($419) {
     break;
    }
    (FUNCTION_TABLE_iii[$418 & 4095]($393,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $420 = (($this) + 107|0);
 $421 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617776,$15,$converter$i$i83,0)|0);
 $422 = ($421|0)==(0);
 if (!($422)) {
  $423 = ($421|0)>(0);
  L199: do {
   if ($423) {
    $424 = (($transfer) + 12|0);
    $425 = (($transfer) + 80|0);
    $426 = HEAP32[$425>>2]|0;
    $427 = (($426) + 12|0);
    $428 = HEAP32[$427>>2]|0;
    $429 = (($transfer) + 16|0);
    $430 = HEAP32[$429>>2]|0;
    $431 = (($transfer) + 28|0);
    $432 = HEAP32[$431>>2]|0;
    $433 = (($transfer) + 32|0);
    $434 = HEAP32[$433>>2]|0;
    $435 = Math_imul($434, $432)|0;
    $$sum$i$i$i$i$i75 = (($428) - ($435))|0;
    $436 = (($430) + ($$sum$i$i$i$i$i75)|0);
    HEAP32[$424>>2] = $436;
    $437 = ($$sum$i$i$i$i$i75|0)<(0);
    do {
     if (!($437)) {
      $$sum1$i$i$i$i$i76 = (($$sum$i$i$i$i$i75) + 1)|0;
      $438 = (($430) + ($$sum1$i$i$i$i$i76)|0);
      $439 = (($transfer) + 20|0);
      $440 = HEAP32[$439>>2]|0;
      $441 = ($438>>>0)>($440>>>0);
      if ($441) {
       break;
      }
      $442 = HEAP8[$436>>0]|0;
      HEAP8[$420>>0] = $442;
      $443 = HEAP32[$424>>2]|0;
      $444 = (($443) + 1|0);
      HEAP32[$424>>2] = $444;
      break L199;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($424,$420,1);
   } else {
    $445 = HEAP32[$converter$i$i83>>2]|0;
    $446 = ($445|0)==(0|0);
    if ($446) {
     break;
    }
    (FUNCTION_TABLE_iii[$445 & 4095]($420,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $447 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,1)|0);
 if ($447) {
  $448 = HEAP8[$14>>0]|0;
  HEAP8[$42>>0] = $448;
 }
 $449 = (($this) + 124|0);
 $450 = HEAP32[580712>>2]|0;
 $451 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617800,$450,$converter$i$i83,0)|0);
 $452 = ($451|0)==(0);
 if (!($452)) {
  $453 = ($451|0)>(0);
  do {
   if ($453) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$449,0);
   } else {
    $454 = HEAP32[$converter$i$i83>>2]|0;
    $455 = ($454|0)==(0|0);
    if ($455) {
     break;
    }
    (FUNCTION_TABLE_iii[$454 & 4095]($449,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $456 = (($this) + 108|0);
 $457 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617816,$450,$converter$i$i83,0)|0);
 $458 = ($457|0)==(0);
 if (!($458)) {
  $459 = ($457|0)>(0);
  do {
   if ($459) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$456,0);
   } else {
    $460 = HEAP32[$converter$i$i83>>2]|0;
    $461 = ($460|0)==(0|0);
    if ($461) {
     break;
    }
    (FUNCTION_TABLE_iii[$460 & 4095]($456,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $462 = HEAP8[$449>>0]|0;
 $463 = $462 & 1;
 $464 = ($463<<24>>24)==(0);
 do {
  if ($464) {
   $465 = (($449) + 1|0);
   $466 = $462&255;
   $467 = $466 >>> 1;
   $474 = $467;$485 = $465;
  } else {
   $468 = (($this) + 132|0);
   $469 = HEAP32[$468>>2]|0;
   $470 = (($this) + 128|0);
   $471 = HEAP32[$470>>2]|0;
   $472 = ($471>>>0)>(4294967279);
   if (!($472)) {
    $474 = $471;$485 = $469;
    break;
   }
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
 } while(0);
 $473 = ($474>>>0)<(11);
 if ($473) {
  $475 = $474 << 1;
  $476 = $475&255;
  HEAP8[$0>>0] = $476;
  $477 = (($0) + 1|0);
  $$pre$phiZ2D = $0;$488 = $476;$__p$0$i$i$i$i = $477;
 } else {
  $478 = (($474) + 16)|0;
  $479 = $478 & -16;
  $480 = (__Znwj($479)|0);
  $481 = (($0) + 8|0);
  HEAP32[$481>>2] = $480;
  $482 = $479 | 1;
  HEAP32[$0>>2] = $482;
  $483 = (($0) + 4|0);
  HEAP32[$483>>2] = $474;
  $484 = $482&255;
  $$pre$phiZ2D = $0;$488 = $484;$__p$0$i$i$i$i = $480;
 }
 _memcpy(($__p$0$i$i$i$i|0),($485|0),($474|0))|0;
 $486 = (($__p$0$i$i$i$i) + ($474)|0);
 HEAP8[$486>>0] = 0;
 $487 = $488 & 1;
 $489 = ($487<<24>>24)==(0);
 if ($489) {
 } else {
 }
 __THREW__ = 0;
 $490 = __THREW__; __THREW__ = 0;
 $491 = $490&1;
 if ($491) {
  $510 = ___cxa_find_matching_catch()|0;
  $511 = tempRet0;
  $512 = HEAP8[$$pre$phiZ2D>>0]|0;
  $513 = $512 & 1;
  $514 = ($513<<24>>24)==(0);
  if ($514) {
   ___resumeException($510|0);
   // unreachable;
  }
  $515 = (($0) + 8|0);
  $516 = HEAP32[$515>>2]|0;
  __ZdlPv($516);
  ___resumeException($510|0);
  // unreachable;
 }
 $492 = HEAP8[$$pre$phiZ2D>>0]|0;
 $493 = $492 & 1;
 $494 = ($493<<24>>24)==(0);
 if (!($494)) {
  $495 = (($0) + 8|0);
  $496 = HEAP32[$495>>2]|0;
  __ZdlPv($496);
 }
 $497 = (($this) + 60|0);
 $498 = HEAP32[580600>>2]|0;
 $499 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617832,$498,$converter$i$i83,1)|0);
 $500 = ($499|0)==(0);
 if (!($500)) {
  $501 = ($499|0)>(0);
  do {
   if ($501) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapIi7Hash128NSt3__14lessIiEENS3_9allocatorINS3_4pairIiS2_EEEEEEEvRT_17TransferMetaFlags($transfer,$497,0);
   } else {
    $502 = HEAP32[$converter$i$i83>>2]|0;
    $503 = ($502|0)==(0|0);
    if ($503) {
     break;
    }
    (FUNCTION_TABLE_iii[$502 & 4095]($497,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $504 = (($this) + 76|0);
 $505 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,617856,$498,$converter$i$i83,1)|0);
 $506 = ($505|0)==(0);
 if ($506) {
  STACKTOP = sp;return;
 }
 $507 = ($505|0)>(0);
 do {
  if ($507) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapI7Hash128S2_NSt3__14lessIS2_EENS3_9allocatorINS3_4pairIS2_S2_EEEEEEEvRT_17TransferMetaFlags($transfer,$504,0);
  } else {
   $508 = HEAP32[$converter$i$i83>>2]|0;
   $509 = ($508|0)==(0|0);
   if ($509) {
    break;
   }
   (FUNCTION_TABLE_iii[$508 & 4095]($504,$transfer)|0);
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapI7Hash128S2_NSt3__14lessIS2_EENS3_9allocatorINS3_4pairIS2_S2_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $converter$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($data) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 5;
 HEAP32[$size>>2] = $9;
 $10 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,617880,617880,$size)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$size>>2]|0;
 $12 = (($data) + 4|0);
 $13 = HEAP32[$2>>2]|0;
 $14 = HEAP32[$12>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = $17 >> 5;
 $19 = ($18>>>0)<($11>>>0);
 if ($19) {
  $20 = (($11) - ($18))|0;
  __ZNSt3__16vectorINS_4pairI7Hash128S2_EENS_9allocatorIS3_EEE8__appendEj($12,$20);
  $$pre = HEAP32[$2>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $28 = $$pre8;$44 = $$pre;
 } else {
  $21 = ($18>>>0)>($11>>>0);
  if ($21) {
   $22 = (($14) + ($11<<5)|0);
   $23 = ($13|0)==($22|0);
   if ($23) {
    $28 = $11;$44 = $13;
   } else {
    $__new_last2$i$i$i$i = $22;
    $scevgep$i$i$i$i = (($13) + -32|0);
    $24 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($24)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $25 = $uglygep3$i$i$i$i >>> 5;
    $26 = $25 ^ -1;
    $scevgep4$i$i$i$i = (($13) + ($26<<5)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i;
    $28 = $11;$44 = $scevgep4$i$i$i$i;
   }
  } else {
   $28 = $11;$44 = $13;
  }
 }
 $27 = ($28|0)==(0);
 do {
  if (!($27)) {
   $29 = HEAP32[580608>>2]|0;
   $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,617872,$29,0,1)|0);
   $31 = (($this) + 80|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (__ZNK16TypeTreeIterator7GetNodeEv($32)|0);
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($this) + 84|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$37>>2] = 0;
   $38 = ($30|0)==(2);
   if ($38) {
    $39 = HEAP32[$31>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$4>>2]|0;
    $43 = ($42|0)==($44|0);
    L14: do {
     if (!($43)) {
      $46 = 0;$49 = $39;$65 = $42;
      while(1) {
       $45 = Math_imul($46, $35)|0;
       $47 = (($45) + ($41))|0;
       $48 = (($49) + 20|0);
       HEAP32[$48>>2] = $47;
       $50 = (($49) + 12|0);
       HEAP32[$50>>2] = $47;
       $51 = (($49) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$49);
       $52 = $1;
       $53 = $52;
       $54 = HEAP32[$53>>2]|0;
       $55 = (($52) + 4)|0;
       $56 = $55;
       $57 = HEAP32[$56>>2]|0;
       $58 = $51;
       $59 = $58;
       HEAP32[$59>>2] = $54;
       $60 = (($58) + 4)|0;
       $61 = $60;
       HEAP32[$61>>2] = $57;
       $62 = HEAP32[$36>>2]|0;
       $63 = HEAP32[$62>>2]|0;
       $64 = (($63) + 1)|0;
       HEAP32[$62>>2] = $64;
       __ZN15SerializeTraitsINSt3__14pairI7Hash128S2_EEE8TransferI14SafeBinaryReadEEvRS3_RT_($65,$this);
       $66 = (($65) + 32|0);
       $67 = ($66|0)==($44|0);
       if ($67) {
        break L14;
       }
       $$pre10 = HEAP32[$36>>2]|0;
       $$pre11 = HEAP32[$$pre10>>2]|0;
       $$pre12 = HEAP32[$31>>2]|0;
       $46 = $$pre11;$49 = $$pre12;$65 = $66;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $68 = HEAP32[$4>>2]|0;
   $69 = ($68|0)==($44|0);
   if (!($69)) {
    $73 = $68;
    while(1) {
     $70 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,617872,$29,$converter$i$i,1)|0);
     $71 = ($70|0)==(0);
     if (!($71)) {
      $72 = ($70|0)>(0);
      if ($72) {
       __ZN15SerializeTraitsINSt3__14pairI7Hash128S2_EEE8TransferI14SafeBinaryReadEEvRS3_RT_($73,$this);
      } else {
       $74 = HEAP32[$converter$i$i>>2]|0;
       $75 = ($74|0)==(0|0);
       if (!($75)) {
        (FUNCTION_TABLE_iii[$74 & 4095]($73,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $76 = (($73) + 32|0);
     $77 = ($76|0)==($44|0);
     if ($77) {
      break;
     } else {
      $73 = $76;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairI7Hash128S2_EEE8TransferI14SafeBinaryReadEEvRS3_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580576>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$0,617888,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($data,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($data) + 16|0);
 $7 = HEAP32[580656>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$7,617888,$converter$i$i1,1)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($6,$transfer);
 } else {
  $11 = HEAP32[$converter$i$i1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (FUNCTION_TABLE_iii[$11 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapIi7Hash128NSt3__14lessIiEENS3_9allocatorINS3_4pairIiS2_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $__new_last2$i$i$i$i = 0, $converter$i$i = 0;
 var $converter$i$i$i2 = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($data) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 24)&-1;
 HEAP32[$size>>2] = $9;
 $10 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,617880,617880,$size)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$size>>2]|0;
 $12 = (($data) + 4|0);
 $13 = HEAP32[$2>>2]|0;
 $14 = HEAP32[$12>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = (($17|0) / 24)&-1;
 $19 = ($18>>>0)<($11>>>0);
 if ($19) {
  $20 = (($11) - ($18))|0;
  __ZNSt3__16vectorINS_4pairIi7Hash128EENS_9allocatorIS3_EEE8__appendEj($12,$20);
  $$pre = HEAP32[$2>>2]|0;
  $$pre10 = HEAP32[$size>>2]|0;
  $28 = $$pre10;$44 = $$pre;
 } else {
  $21 = ($18>>>0)>($11>>>0);
  if ($21) {
   $22 = (($14) + (($11*24)|0)|0);
   $23 = ($13|0)==($22|0);
   if ($23) {
    $28 = $11;$44 = $13;
   } else {
    $__new_last2$i$i$i$i = $22;
    $scevgep$i$i$i$i = (($13) + -24|0);
    $24 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($24)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $25 = (($uglygep3$i$i$i$i>>>0) / 24)&-1;
    $26 = $25 ^ -1;
    $scevgep4$i$i$i$i = (($13) + (($26*24)|0)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i;
    $28 = $11;$44 = $scevgep4$i$i$i$i;
   }
  } else {
   $28 = $11;$44 = $13;
  }
 }
 $27 = ($28|0)==(0);
 do {
  if (!($27)) {
   $29 = HEAP32[580608>>2]|0;
   $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,617872,$29,0,1)|0);
   $31 = (($this) + 80|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (__ZNK16TypeTreeIterator7GetNodeEv($32)|0);
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($this) + 84|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$37>>2] = 0;
   $38 = ($30|0)==(2);
   if ($38) {
    $39 = HEAP32[$31>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$4>>2]|0;
    $43 = ($42|0)==($44|0);
    L14: do {
     if (!($43)) {
      $45 = HEAP32[580576>>2]|0;
      $46 = HEAP32[580656>>2]|0;
      $48 = 0;$51 = $39;$67 = $42;
      while(1) {
       $47 = Math_imul($48, $35)|0;
       $49 = (($47) + ($41))|0;
       $50 = (($51) + 20|0);
       HEAP32[$50>>2] = $49;
       $52 = (($51) + 12|0);
       HEAP32[$52>>2] = $49;
       $53 = (($51) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$51);
       $54 = $1;
       $55 = $54;
       $56 = HEAP32[$55>>2]|0;
       $57 = (($54) + 4)|0;
       $58 = $57;
       $59 = HEAP32[$58>>2]|0;
       $60 = $53;
       $61 = $60;
       HEAP32[$61>>2] = $56;
       $62 = (($60) + 4)|0;
       $63 = $62;
       HEAP32[$63>>2] = $59;
       $64 = HEAP32[$36>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = (($65) + 1)|0;
       HEAP32[$64>>2] = $66;
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$67,$45,0);
       $68 = (($67) + 8|0);
       $69 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$46,617888,$converter$i$i$i2,1)|0);
       $70 = ($69|0)==(0);
       if (!($70)) {
        $71 = ($69|0)>(0);
        if ($71) {
         __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($68,$this);
        } else {
         $72 = HEAP32[$converter$i$i$i2>>2]|0;
         $73 = ($72|0)==(0|0);
         if (!($73)) {
          (FUNCTION_TABLE_iii[$72 & 4095]($68,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $74 = (($67) + 24|0);
       $75 = ($74|0)==($44|0);
       if ($75) {
        break L14;
       }
       $$pre11 = HEAP32[$36>>2]|0;
       $$pre12 = HEAP32[$$pre11>>2]|0;
       $$pre13 = HEAP32[$31>>2]|0;
       $48 = $$pre12;$51 = $$pre13;$67 = $74;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $76 = HEAP32[$4>>2]|0;
   $77 = ($76|0)==($44|0);
   if (!($77)) {
    $78 = HEAP32[580576>>2]|0;
    $79 = HEAP32[580656>>2]|0;
    $83 = $76;
    while(1) {
     $80 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,617872,$29,$converter$i$i,1)|0);
     $81 = ($80|0)==(0);
     if (!($81)) {
      $82 = ($80|0)>(0);
      if ($82) {
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$83,$78,0);
       $84 = (($83) + 8|0);
       $85 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$79,617888,$converter$i$i$i2,1)|0);
       $86 = ($85|0)==(0);
       if (!($86)) {
        $87 = ($85|0)>(0);
        if ($87) {
         __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($84,$this);
        } else {
         $88 = HEAP32[$converter$i$i$i2>>2]|0;
         $89 = ($88|0)==(0|0);
         if (!($89)) {
          (FUNCTION_TABLE_iii[$88 & 4095]($84,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $90 = HEAP32[$converter$i$i>>2]|0;
       $91 = ($90|0)==(0|0);
       if (!($91)) {
        (FUNCTION_TABLE_iii[$90 & 4095]($83,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $92 = (($83) + 24|0);
     $93 = ($92|0)==($44|0);
     if ($93) {
      break;
     } else {
      $83 = $92;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13BuildSettings8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $p$i$i4 = 0, $size$i$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $size$i$i$i3 = sp + 32|0;
 $p$i$i4 = sp;
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 24|0);
 __ZN13ProxyTransfer8TransferINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_PKc17TransferMetaFlags($transfer,$0,617424,0);
 $1 = (($this) + 48|0);
 __ZN13ProxyTransfer8TransferINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_PKc17TransferMetaFlags($transfer,$1,617432,0);
 $2 = (($this) + 92|0);
 $3 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617456,$3,$2,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 93|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617480,$3,$10,0);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$7>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 96|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617496,$3,$15,0);
 $16 = HEAP32[$4>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$7>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 97|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617520,$3,$20,0);
 $21 = HEAP32[$4>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$7>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $25 = (($this) + 98|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617544,$3,$25,0);
 $26 = HEAP32[$4>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$7>>2]|0;
 $29 = ((($27) + (($28*24)|0)|0) + 12|0);
 HEAP32[$29>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $30 = (($this) + 99|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617568,$3,$30,0);
 $31 = HEAP32[$4>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$7>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $35 = (($this) + 100|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617584,$3,$35,0);
 $36 = HEAP32[$4>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$7>>2]|0;
 $39 = ((($37) + (($38*24)|0)|0) + 12|0);
 HEAP32[$39>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $40 = (($this) + 101|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617608,$3,$40,0);
 $41 = HEAP32[$4>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$7>>2]|0;
 $44 = ((($42) + (($43*24)|0)|0) + 12|0);
 HEAP32[$44>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $45 = (($this) + 102|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617624,$3,$45,0);
 $46 = HEAP32[$4>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$7>>2]|0;
 $49 = ((($47) + (($48*24)|0)|0) + 12|0);
 HEAP32[$49>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $50 = (($this) + 103|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617640,$3,$50,0);
 $51 = HEAP32[$4>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$7>>2]|0;
 $54 = ((($52) + (($53*24)|0)|0) + 12|0);
 HEAP32[$54>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $55 = (($this) + 94|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617664,$3,$55,0);
 $56 = HEAP32[$4>>2]|0;
 $57 = HEAP32[$56>>2]|0;
 $58 = HEAP32[$7>>2]|0;
 $59 = ((($57) + (($58*24)|0)|0) + 12|0);
 HEAP32[$59>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $60 = (($this) + 95|0);
 $61 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617688,$61,$60,0);
 $62 = HEAP32[$4>>2]|0;
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$7>>2]|0;
 $65 = ((($63) + (($64*24)|0)|0) + 12|0);
 HEAP32[$65>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $66 = (($this) + 104|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617712,$61,$66,0);
 $67 = HEAP32[$4>>2]|0;
 $68 = HEAP32[$67>>2]|0;
 $69 = HEAP32[$7>>2]|0;
 $70 = ((($68) + (($69*24)|0)|0) + 12|0);
 HEAP32[$70>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $71 = (($this) + 105|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617728,$61,$71,0);
 $72 = HEAP32[$4>>2]|0;
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$7>>2]|0;
 $75 = ((($73) + (($74*24)|0)|0) + 12|0);
 HEAP32[$75>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $76 = (($this) + 106|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617752,$61,$76,0);
 $77 = HEAP32[$4>>2]|0;
 $78 = HEAP32[$77>>2]|0;
 $79 = HEAP32[$7>>2]|0;
 $80 = ((($78) + (($79*24)|0)|0) + 12|0);
 HEAP32[$80>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $81 = (($this) + 107|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617776,$61,$81,0);
 $82 = HEAP32[$4>>2]|0;
 $83 = HEAP32[$82>>2]|0;
 $84 = HEAP32[$7>>2]|0;
 $85 = ((($83) + (($84*24)|0)|0) + 12|0);
 HEAP32[$85>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $86 = (($this) + 124|0);
 $87 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617800,$87,$86,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,617880,617880,$size$i$i$i3,1);
 $88 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617872,$88,$p$i$i4,0);
 $89 = HEAP32[$4>>2]|0;
 $90 = HEAP32[$89>>2]|0;
 $91 = HEAP32[$7>>2]|0;
 $92 = ((($90) + (($91*24)|0)|0) + 12|0);
 HEAP32[$92>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $93 = (($this) + 108|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617816,$87,$93,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,617880,617880,$size$i$i$i3,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617872,$88,$p$i$i4,0);
 $94 = HEAP32[$4>>2]|0;
 $95 = HEAP32[$94>>2]|0;
 $96 = HEAP32[$7>>2]|0;
 $97 = ((($95) + (($96*24)|0)|0) + 12|0);
 HEAP32[$97>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $98 = (($this) + 60|0);
 $99 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617832,$99,$98,0);
 HEAP32[$p$i$i4>>2] = 0;
 $100 = (($p$i$i4) + 8|0);
 ;HEAP32[$100+0>>2]=0|0;HEAP32[$100+4>>2]=0|0;HEAP32[$100+8>>2]=0|0;HEAP32[$100+12>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,617880,617880,$size$i$i$i3,0);
 $101 = HEAP32[580608>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617872,$101,$p$i$i4,0);
 $102 = HEAP32[580576>>2]|0;
 $103 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$102,$103,$p$i$i4,0);
 $104 = HEAP32[$4>>2]|0;
 $105 = HEAP32[$104>>2]|0;
 $106 = HEAP32[$7>>2]|0;
 $107 = ((($105) + (($106*24)|0)|0) + 12|0);
 HEAP32[$107>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $108 = HEAP32[580656>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$108,617888,$100,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($100,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $109 = (($this) + 76|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617856,$99,$109,0);
 ;HEAP32[$p$i$i4+0>>2]=0|0;HEAP32[$p$i$i4+4>>2]=0|0;HEAP32[$p$i$i4+8>>2]=0|0;HEAP32[$p$i$i4+12>>2]=0|0;HEAP32[$p$i$i4+16>>2]=0|0;HEAP32[$p$i$i4+20>>2]=0|0;HEAP32[$p$i$i4+24>>2]=0|0;HEAP32[$p$i$i4+28>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,617880,617880,$size$i$i$i3,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,617872,$101,$p$i$i4,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$102,617888,$p$i$i4,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($p$i$i4,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $110 = (($p$i$i4) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$108,617888,$110,0);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($110,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13BuildSettingsD2Ev($this) {
 $this = $this|0;
 var $$byval_copy9 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i17 = 0, $$pre$i$i$i$i$i25 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i8 = 0, $eh$lpad$body$i$indexZ2D = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i9 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep4$i$i$i$i$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i11 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy9 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 HEAP32[$this>>2] = ((617264 + 8|0));
 $5 = (($this) + 124|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($this) + 132|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$4>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($10|0),($$byval_copy9|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 $15 = (($this) + 108|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 if (!($18)) {
  $19 = (($this) + 116|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$3>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($20|0),($$byval_copy9|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   ___cxa_call_unexpected(($23|0));
   // unreachable;
  }
 }
 $25 = (($this) + 80|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = (($this) + 84|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==($26|0);
  if (!($30)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $26;
   $scevgep$i$i$i$i$i$i$i$i$i = (($29) + -32|0);
   $31 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($31)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $32 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 5;
   $33 = $32 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($29) + ($33<<5)|0);
   HEAP32[$28>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($26);
 }
 $34 = (($this) + 64|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  $37 = (($this) + 68|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==($35|0);
  if (!($39)) {
   $__new_last2$i$i$i$i$i$i$i$i$i8 = $35;
   $scevgep$i$i$i$i$i$i$i$i$i9 = (($38) + -24|0);
   $40 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i8))|0;
   $uglygep$i$i$i$i$i$i$i$i$i11 = (($scevgep$i$i$i$i$i$i$i$i$i9) + ($40)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i12 = $uglygep$i$i$i$i$i$i$i$i$i11;
   $41 = (($uglygep3$i$i$i$i$i$i$i$i$i12>>>0) / 24)&-1;
   $42 = $41 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i13 = (($38) + (($42*24)|0)|0);
   HEAP32[$37>>2] = $scevgep4$i$i$i$i$i$i$i$i$i13;
  }
  __ZdlPv($35);
 }
 $43 = (($this) + 48|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = (($this) + 52|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==($44|0);
  do {
   if ($48) {
    $62 = $44;
   } else {
    $50 = $47;
    while(1) {
     $49 = (($50) + -12|0);
     HEAP32[$46>>2] = $49;
     $51 = HEAP8[$49>>0]|0;
     $52 = $51 & 1;
     $53 = ($52<<24>>24)==(0);
     if ($53) {
      $55 = $49;
     } else {
      $56 = (($50) + -4|0);
      $57 = HEAP32[$56>>2]|0;
      HEAP32[$2>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($57|0),($$byval_copy9|0));
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 22;
       break;
      }
      $$pre$i$i$i$i$i = HEAP32[$46>>2]|0;
      $55 = $$pre$i$i$i$i$i;
     }
     $54 = ($55|0)==($44|0);
     if ($54) {
      label = 23;
      break;
     } else {
      $50 = $55;
     }
    }
    if ((label|0) == 22) {
     $60 = ___cxa_find_matching_catch()|0;
     $61 = tempRet0;
     ___cxa_call_unexpected(($60|0));
     // unreachable;
    }
    else if ((label|0) == 23) {
     $$pre$i$i$i = HEAP32[$43>>2]|0;
     $62 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  __ZdlPv($62);
 }
 $63 = (($this) + 36|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 if (!($65)) {
  $66 = (($this) + 40|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==($64|0);
  do {
   if ($68) {
    $82 = $64;
   } else {
    $70 = $67;
    while(1) {
     $69 = (($70) + -12|0);
     HEAP32[$66>>2] = $69;
     $71 = HEAP8[$69>>0]|0;
     $72 = $71 & 1;
     $73 = ($72<<24>>24)==(0);
     if ($73) {
      $75 = $69;
     } else {
      $76 = (($70) + -4|0);
      $77 = HEAP32[$76>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($77|0),($$byval_copy9|0));
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       label = 32;
       break;
      }
      $$pre$i$i$i$i$i17 = HEAP32[$66>>2]|0;
      $75 = $$pre$i$i$i$i$i17;
     }
     $74 = ($75|0)==($64|0);
     if ($74) {
      label = 33;
      break;
     } else {
      $70 = $75;
     }
    }
    if ((label|0) == 32) {
     $80 = ___cxa_find_matching_catch()|0;
     $81 = tempRet0;
     ___cxa_call_unexpected(($80|0));
     // unreachable;
    }
    else if ((label|0) == 33) {
     $$pre$i$i$i19 = HEAP32[$63>>2]|0;
     $82 = $$pre$i$i$i19;
     break;
    }
   }
  } while(0);
  __ZdlPv($82);
 }
 $83 = (($this) + 24|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(0|0);
 if (!($85)) {
  $86 = (($this) + 28|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==($84|0);
  do {
   if ($88) {
    $102 = $84;
   } else {
    $90 = $87;
    while(1) {
     $89 = (($90) + -12|0);
     HEAP32[$86>>2] = $89;
     $91 = HEAP8[$89>>0]|0;
     $92 = $91 & 1;
     $93 = ($92<<24>>24)==(0);
     if ($93) {
      $95 = $89;
     } else {
      $96 = (($90) + -4|0);
      $97 = HEAP32[$96>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($97|0),($$byval_copy9|0));
      $98 = __THREW__; __THREW__ = 0;
      $99 = $98&1;
      if ($99) {
       label = 42;
       break;
      }
      $$pre$i$i$i$i$i25 = HEAP32[$86>>2]|0;
      $95 = $$pre$i$i$i$i$i25;
     }
     $94 = ($95|0)==($84|0);
     if ($94) {
      label = 43;
      break;
     } else {
      $90 = $95;
     }
    }
    if ((label|0) == 42) {
     $100 = ___cxa_find_matching_catch()|0;
     $101 = tempRet0;
     ___cxa_call_unexpected(($100|0));
     // unreachable;
    }
    else if ((label|0) == 43) {
     $$pre$i$i$i27 = HEAP32[$83>>2]|0;
     $102 = $$pre$i$i$i27;
     break;
    }
   }
  } while(0);
  __ZdlPv($102);
 }
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $103 = __THREW__; __THREW__ = 0;
 $104 = $103&1;
 if (!($104)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if (!($106)) {
   STACKTOP = sp;return;
  }
  $107 = ___cxa_find_matching_catch()|0;
  $108 = tempRet0;
  __THREW__ = 0;
  $109 = __THREW__; __THREW__ = 0;
  $110 = $109&1;
  if ($110) {
   $111 = ___cxa_find_matching_catch(0|0)|0;
   $112 = tempRet0;
   ___clang_call_terminate($111);
   // unreachable;
  } else {
   ___resumeException($107|0);
   // unreachable;
  }
 }
 $113 = ___cxa_find_matching_catch()|0;
 $114 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $115 = __THREW__; __THREW__ = 0;
 $116 = $115&1;
 if ($116) {
  $119 = ___cxa_find_matching_catch(0|0)|0;
  $120 = tempRet0;
  __THREW__ = 0;
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   $123 = ___cxa_find_matching_catch(0|0)|0;
   $124 = tempRet0;
   ___clang_call_terminate($123);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $119;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $117 = __THREW__; __THREW__ = 0;
 $118 = $117&1;
 if (!($118)) {
  ___resumeException($113|0);
  // unreachable;
 }
 $125 = ___cxa_find_matching_catch(0|0)|0;
 $126 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $125;
 ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
 // unreachable;
}
function __Z22GetFolderSizeRecursiveRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($path) {
 $path = $path|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$1 = 0, $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $paths = 0, $size$05 = 0, $size$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $paths = sp;
 $0 = (__Z18IsDirectoryCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($path)|0);
 if (!($0)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $1 = (($paths) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($paths) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($paths) + 4|0);
 HEAP32[$paths>>2] = $3;
 __THREW__ = 0;
 $4 = (invoke_iii(2417,($path|0),($paths|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $lpad$phi$index = $33;$lpad$phi$index2 = $34;
  $35 = HEAP32[$1>>2]|0;
  __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($paths,$35);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 L8: do {
  if ($4) {
   $7 = HEAP32[$paths>>2]|0;
   $8 = ($7|0)==($3|0);
   if ($8) {
    $$0 = 0;
   } else {
    $10 = $7;$size$05 = 0;
    while(1) {
     $9 = (($10) + 16|0);
     __THREW__ = 0;
     $11 = (invoke_ii(3257,($9|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     if ($11) {
      __THREW__ = 0;
      $14 = (invoke_ii(3258,($9|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      } else {
       $$pn = $14;
      }
     } else {
      __THREW__ = 0;
      $17 = (invoke_ii(3259,($9|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      } else {
       $$pn = $17;
      }
     }
     $size$1 = (($$pn) + ($size$05))|0;
     $20 = (($10) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      $$01$i$i$i = $10;
      while(1) {
       $25 = (($$01$i$i$i) + 8|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = HEAP32[$26>>2]|0;
       $28 = ($27|0)==($$01$i$i$i|0);
       if ($28) {
        $$0$i$i$i = $26;
        break;
       } else {
        $$01$i$i$i = $26;
       }
      }
     } else {
      $$0$i$i$i$i = $21;
      while(1) {
       $23 = HEAP32[$$0$i$i$i$i>>2]|0;
       $24 = ($23|0)==(0|0);
       if ($24) {
        $$0$i$i$i = $$0$i$i$i$i;
        break;
       } else {
        $$0$i$i$i$i = $23;
       }
      }
     }
     $29 = ($$0$i$i$i|0)==($3|0);
     if ($29) {
      $$0 = $size$1;
      break L8;
     } else {
      $10 = $$0$i$i$i;$size$05 = $size$1;
     }
    }
    $31 = ___cxa_find_matching_catch()|0;
    $32 = tempRet0;
    $lpad$phi$index = $31;$lpad$phi$index2 = $32;
    $35 = HEAP32[$1>>2]|0;
    __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($paths,$35);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
  } else {
   $$0 = 0;
  }
 } while(0);
 $30 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($paths,$30);
 $$1 = $$0;
 STACKTOP = sp;return ($$1|0);
}
function __Z20GetPlatformCachePathv($agg$result) {
 $agg$result = $agg$result|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p$0$i$i$i = 0, $result = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $result = sp + 12|0;
 $0 = sp;
 __ZN10systeminfo21GetPersistentDataPathEv($result);
 $1 = HEAP8[$result>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $9 = $7;
 } else {
  $4 = (($result) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $9 = $5;
 }
 $8 = ($9|0)==(0);
 L5: do {
  if ($8) {
   if ($3) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$result+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$result+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$result+8>>2]|0;
    label = 21;
    break;
   }
   $10 = (($result) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($result) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13>>>0)>(4294967279);
   do {
    if ($14) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      // unreachable;
     }
    } else {
     $17 = ($13>>>0)<(11);
     if ($17) {
      $18 = $13 << 1;
      $19 = $18&255;
      HEAP8[$agg$result>>0] = $19;
      $20 = (($agg$result) + 1|0);
      $__p$0$i$i$i = $20;
     } else {
      $21 = (($13) + 16)|0;
      $22 = $21 & -16;
      __THREW__ = 0;
      $23 = (invoke_ii(2988,($22|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = (($agg$result) + 8|0);
      HEAP32[$26>>2] = $23;
      $27 = $22 | 1;
      HEAP32[$agg$result>>2] = $27;
      $28 = (($agg$result) + 4|0);
      HEAP32[$28>>2] = $13;
      $__p$0$i$i$i = $23;
     }
     _memcpy(($__p$0$i$i$i|0),($11|0),($13|0))|0;
     $29 = (($__p$0$i$i$i) + ($13)|0);
     HEAP8[$29>>0] = 0;
     label = 21;
     break L5;
    }
   } while(0);
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   $$0 = $31;$$01 = $30;
   label = 24;
  } else {
   HEAP8[$0>>0] = 20;
   $32 = (($0) + 1|0);
   dest=$32+0|0; src=617896+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $33 = (($0) + 11|0);
   HEAP8[$33>>0] = 0;
   __THREW__ = 0;
   invoke_viii(1776,($agg$result|0),($result|0),($0|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $41 = ___cxa_find_matching_catch()|0;
    $42 = tempRet0;
    $43 = HEAP8[$0>>0]|0;
    $44 = $43 & 1;
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     $$0 = $42;$$01 = $41;
     label = 24;
     break;
    }
    $46 = (($0) + 8|0);
    $47 = HEAP32[$46>>2]|0;
    __ZdlPv($47);
    $$0 = $42;$$01 = $41;
    label = 24;
    break;
   } else {
    $36 = HEAP8[$0>>0]|0;
    $37 = $36 & 1;
    $38 = ($37<<24>>24)==(0);
    if ($38) {
     label = 21;
     break;
    }
    $39 = (($0) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    __ZdlPv($40);
    label = 21;
    break;
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $48 = HEAP8[$result>>0]|0;
  $49 = $48 & 1;
  $50 = ($49<<24>>24)==(0);
  if ($50) {
   STACKTOP = sp;return;
  }
  $51 = (($result) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  __ZdlPv($52);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 24) {
  $53 = HEAP8[$result>>0]|0;
  $54 = $53 & 1;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   ___resumeException($$01|0);
   // unreachable;
  }
  $56 = (($result) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  __ZdlPv($57);
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __Z21GetCachingManagerPathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEb($agg$result,$path,$createPath) {
 $agg$result = $agg$result|0;
 $path = $path|0;
 $createPath = $createPath|0;
 var $$0 = 0, $$01 = 0, $$not = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i11 = 0, $__p$0$i$i$i4 = 0, $brmerge = 0, $cachePath = 0, $fullPath = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $cachePath = sp + 12|0;
 $fullPath = sp;
 __Z20GetPlatformCachePathv($cachePath);
 $0 = HEAP8[$path>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $7 = $6;
 } else {
  $3 = (($path) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $7 = $4;
 }
 $$not = ($7|0)!=(0);
 $brmerge = $$not | $createPath;
 do {
  if ($brmerge) {
   __THREW__ = 0;
   invoke_viii(1776,($fullPath|0),($cachePath|0),($path|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 15;
   } else {
    do {
     if ($createPath) {
      __THREW__ = 0;
      $65 = (invoke_ii(3260,($fullPath|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 28;
      } else {
       if (!($65)) {
        ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
        $$pre = HEAP8[$fullPath>>0]|0;
        $92 = $$pre;
        label = 43;
        break;
       }
       $68 = HEAP8[$fullPath>>0]|0;
       $69 = $68 & 1;
       $70 = ($69<<24>>24)==(0);
       if ($70) {
        ;HEAP32[$agg$result+0>>2]=HEAP32[$fullPath+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$fullPath+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$fullPath+8>>2]|0;
        $92 = $68;
        label = 43;
        break;
       }
       $71 = (($fullPath) + 8|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = (($fullPath) + 4|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($74>>>0)>(4294967279);
       if ($75) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 28;
         break;
        }
        // unreachable;
       }
       $78 = ($74>>>0)<(11);
       if ($78) {
        $79 = $74 << 1;
        $80 = $79&255;
        HEAP8[$agg$result>>0] = $80;
        $81 = (($agg$result) + 1|0);
        $__p$0$i$i$i11 = $81;
       } else {
        $82 = (($74) + 16)|0;
        $83 = $82 & -16;
        __THREW__ = 0;
        $84 = (invoke_ii(2988,($83|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 28;
         break;
        }
        $87 = (($agg$result) + 8|0);
        HEAP32[$87>>2] = $84;
        $88 = $83 | 1;
        HEAP32[$agg$result>>2] = $88;
        $89 = (($agg$result) + 4|0);
        HEAP32[$89>>2] = $74;
        $__p$0$i$i$i11 = $84;
       }
       _memcpy(($__p$0$i$i$i11|0),($72|0),($74|0))|0;
       $90 = (($__p$0$i$i$i11) + ($74)|0);
       HEAP8[$90>>0] = 0;
       $92 = $68;
       label = 43;
      }
     } else {
      $35 = HEAP8[$fullPath>>0]|0;
      $36 = $35 & 1;
      $37 = ($36<<24>>24)==(0);
      if ($37) {
       ;HEAP32[$agg$result+0>>2]=HEAP32[$fullPath+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$fullPath+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$fullPath+8>>2]|0;
       $92 = $35;
       label = 43;
       break;
      }
      $38 = (($fullPath) + 8|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = (($fullPath) + 4|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41>>>0)>(4294967279);
      if ($42) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 28;
        break;
       }
       // unreachable;
      }
      $45 = ($41>>>0)<(11);
      if ($45) {
       $46 = $41 << 1;
       $47 = $46&255;
       HEAP8[$agg$result>>0] = $47;
       $48 = (($agg$result) + 1|0);
       $__p$0$i$i$i4 = $48;
      } else {
       $49 = (($41) + 16)|0;
       $50 = $49 & -16;
       __THREW__ = 0;
       $51 = (invoke_ii(2988,($50|0))|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        label = 28;
        break;
       }
       $54 = (($agg$result) + 8|0);
       HEAP32[$54>>2] = $51;
       $55 = $50 | 1;
       HEAP32[$agg$result>>2] = $55;
       $56 = (($agg$result) + 4|0);
       HEAP32[$56>>2] = $41;
       $__p$0$i$i$i4 = $51;
      }
      _memcpy(($__p$0$i$i$i4|0),($39|0),($41|0))|0;
      $57 = (($__p$0$i$i$i4) + ($41)|0);
      HEAP8[$57>>0] = 0;
      $92 = $35;
      label = 43;
     }
    } while(0);
    if ((label|0) == 28) {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     $60 = HEAP8[$fullPath>>0]|0;
     $61 = $60 & 1;
     $62 = ($61<<24>>24)==(0);
     if ($62) {
      $$0 = $59;$$01 = $58;
      break;
     }
     $63 = (($fullPath) + 8|0);
     $64 = HEAP32[$63>>2]|0;
     __ZdlPv($64);
     $$0 = $59;$$01 = $58;
     break;
    }
    else if ((label|0) == 43) {
     $91 = $92 & 1;
     $93 = ($91<<24>>24)==(0);
     if ($93) {
      label = 45;
      break;
     }
     $94 = (($fullPath) + 8|0);
     $95 = HEAP32[$94>>2]|0;
     __ZdlPv($95);
     label = 45;
     break;
    }
   }
  } else {
   $8 = HEAP8[$cachePath>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$cachePath+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$cachePath+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$cachePath+8>>2]|0;
    label = 45;
    break;
   }
   $11 = (($cachePath) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($cachePath) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14>>>0)>(4294967279);
   if ($15) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 15;
     break;
    }
    // unreachable;
   }
   $18 = ($14>>>0)<(11);
   if ($18) {
    $19 = $14 << 1;
    $20 = $19&255;
    HEAP8[$agg$result>>0] = $20;
    $21 = (($agg$result) + 1|0);
    $__p$0$i$i$i = $21;
   } else {
    $22 = (($14) + 16)|0;
    $23 = $22 & -16;
    __THREW__ = 0;
    $24 = (invoke_ii(2988,($23|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     label = 15;
     break;
    }
    $27 = (($agg$result) + 8|0);
    HEAP32[$27>>2] = $24;
    $28 = $23 | 1;
    HEAP32[$agg$result>>2] = $28;
    $29 = (($agg$result) + 4|0);
    HEAP32[$29>>2] = $14;
    $__p$0$i$i$i = $24;
   }
   _memcpy(($__p$0$i$i$i|0),($12|0),($14|0))|0;
   $30 = (($__p$0$i$i$i) + ($14)|0);
   HEAP8[$30>>0] = 0;
   label = 45;
  }
 } while(0);
 if ((label|0) == 15) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $$0 = $32;$$01 = $31;
 }
 else if ((label|0) == 45) {
  $96 = HEAP8[$cachePath>>0]|0;
  $97 = $96 & 1;
  $98 = ($97<<24>>24)==(0);
  if ($98) {
   STACKTOP = sp;return;
  }
  $99 = (($cachePath) + 8|0);
  $100 = HEAP32[$99>>2]|0;
  __ZdlPv($100);
  STACKTOP = sp;return;
 }
 $101 = HEAP8[$cachePath>>0]|0;
 $102 = $101 & 1;
 $103 = ($102<<24>>24)==(0);
 if ($103) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $104 = (($cachePath) + 8|0);
 $105 = HEAP32[$104>>2]|0;
 __ZdlPv($105);
 ___resumeException($$01|0);
 // unreachable;
}
function __Z24CreateDirectoryRecursiveRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName) {
 $pathName = $pathName|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__ps$0$i = 0, $superPath = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 36|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $superPath = sp + 16|0;
 $1 = sp + 28|0;
 $2 = sp + 32|0;
 __Z27DeleteLastPathNameComponentRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0,$pathName);
 __THREW__ = 0;
 $3 = (invoke_ii(3257,($0|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $$01 = $13;$$02 = $12;
   ___resumeException($$02|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  $$01 = $13;$$02 = $12;
  ___resumeException($$02|0);
  // unreachable;
 }
 $6 = HEAP8[$0>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 if ($3) {
  $11 = (__Z18IsDirectoryCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName)|0);
  if ($11) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
  $19 = (__Z13IsFileCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName)|0);
  if ($19) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  $20 = (__Z15CreateDirectoryRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName)|0);
  $$1 = $20;
  STACKTOP = sp;return ($$1|0);
 }
 $21 = HEAP8[$pathName>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $26 = $21&255;
  $27 = $26 >>> 1;
  $29 = $27;
 } else {
  $24 = (($pathName) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $29 = $25;
 }
 $28 = ($29|0)==(0);
 if ($28) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 if ($23) {
  $32 = (($pathName) + 1|0);
  $34 = $32;
 } else {
  $30 = (($pathName) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $34 = $31;
 }
 $33 = (($34) + ($29)|0);
 $__ps$0$i = $33;
 while(1) {
  $35 = ($__ps$0$i|0)==($34|0);
  if ($35) {
   $$1 = 1;
   label = 32;
   break;
  }
  $36 = (($__ps$0$i) + -1|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($37<<24>>24)==(47);
  if ($38) {
   break;
  } else {
   $__ps$0$i = $36;
  }
 }
 if ((label|0) == 32) {
  STACKTOP = sp;return ($$1|0);
 }
 $39 = $36;
 $40 = $34;
 $41 = (($39) - ($40))|0;
 $42 = ($41|0)==(-1);
 if ($42) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 ;HEAP32[$superPath+0>>2]=0|0;HEAP32[$superPath+4>>2]=0|0;HEAP32[$superPath+8>>2]=0|0;
 if ($23) {
  $47 = (($pathName) + 1|0);
  HEAP32[$1>>2] = $47;
  $48 = (($pathName) + 1|0);
  $50 = $48;
 } else {
  $43 = (($pathName) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  HEAP32[$1>>2] = $44;
  $45 = (($pathName) + 8|0);
  $46 = HEAP32[$45>>2]|0;
  $50 = $46;
 }
 $49 = (($50) + ($41)|0);
 HEAP32[$2>>2] = $49;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 (invoke_iiii(1549,($superPath|0),($$byval_copy|0),($$byval_copy1|0))|0);
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 do {
  if (!($52)) {
   __THREW__ = 0;
   $53 = (invoke_ii(3260,($superPath|0))|0);
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if (!($55)) {
    if ($53) {
     __THREW__ = 0;
     $63 = (invoke_ii(3260,($pathName|0))|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     } else {
      $$0 = $63;
     }
    } else {
     $$0 = 0;
    }
    $66 = HEAP8[$superPath>>0]|0;
    $67 = $66 & 1;
    $68 = ($67<<24>>24)==(0);
    if ($68) {
     $$1 = $$0;
     STACKTOP = sp;return ($$1|0);
    }
    $69 = (($superPath) + 8|0);
    $70 = HEAP32[$69>>2]|0;
    __ZdlPv($70);
    $$1 = $$0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 $58 = HEAP8[$superPath>>0]|0;
 $59 = $58 & 1;
 $60 = ($59<<24>>24)==(0);
 if ($60) {
  $$01 = $57;$$02 = $56;
  ___resumeException($$02|0);
  // unreachable;
 }
 $61 = (($superPath) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 __ZdlPv($62);
 $$01 = $57;$$02 = $56;
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN14CachingManager20DidUnloadAssetBundleERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN5Cache20DidUnloadAssetBundleERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($1,$path);
 STACKTOP = sp;return;
}
function __ZN5Cache20DidUnloadAssetBundleERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__i$i$i = sp;
 $0 = (($this) + 68|0);
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE4findIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_($__i$i$i,$0,$path);
 $1 = (($this) + 72|0);
 $2 = HEAP32[$__i$i$i>>2]|0;
 $3 = ($2|0)==($1|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$01$i$i$i$i = $2;
  while(1) {
   $9 = (($$01$i$i$i$i) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==($$01$i$i$i$i|0);
   if ($12) {
    $$0$i$i$i$i = $10;
    break;
   } else {
    $$01$i$i$i$i = $10;
   }
  }
 } else {
  $$0$i$i$i$i$i = $5;
  while(1) {
   $7 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $$0$i$i$i$i = $$0$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i = $7;
   }
  }
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($13|0)==($2|0);
 if ($14) {
  HEAP32[$0>>2] = $$0$i$i$i$i;
 }
 $15 = (($this) + 76|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = (($2) + 16|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  $22 = (($2) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  __ZdlPv($23);
 }
 $24 = (($this) + 72|0);
 $25 = HEAP32[$24>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$2);
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN20CachedUnityWebStreamD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i13 = 0, $$pre$i$i$i14 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (($this) + 40|0);
 __THREW__ = 0;
 (invoke_ii(3261,($2|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $45 = ___cxa_find_matching_catch()|0;
   $46 = tempRet0;
   $$1 = $46;$$12 = $45;
   label = 26;
  } else {
   $5 = (($this) + 28|0);
   HEAP8[$1>>0] = 12;
   $6 = (($1) + 1|0);
   ;HEAP8[$6+0>>0]=HEAP8[617920+0>>0]|0;HEAP8[$6+1>>0]=HEAP8[617920+1>>0]|0;HEAP8[$6+2>>0]=HEAP8[617920+2>>0]|0;HEAP8[$6+3>>0]=HEAP8[617920+3>>0]|0;HEAP8[$6+4>>0]=HEAP8[617920+4>>0]|0;HEAP8[$6+5>>0]=HEAP8[617920+5>>0]|0;
   $7 = (($1) + 7|0);
   HEAP8[$7>>0] = 0;
   __THREW__ = 0;
   invoke_viii(1776,($0|0),($5|0),($1|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   do {
    if ($9) {
     $47 = ___cxa_find_matching_catch()|0;
     $48 = tempRet0;
     $$0 = $48;$$01 = $47;
    } else {
     __THREW__ = 0;
     (invoke_ii(3262,($0|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      $49 = ___cxa_find_matching_catch()|0;
      $50 = tempRet0;
      $51 = HEAP8[$0>>0]|0;
      $52 = $51 & 1;
      $53 = ($52<<24>>24)==(0);
      if ($53) {
       $$0 = $50;$$01 = $49;
       break;
      }
      $54 = (($0) + 8|0);
      $55 = HEAP32[$54>>2]|0;
      __ZdlPv($55);
      $$0 = $50;$$01 = $49;
      break;
     }
     $12 = HEAP8[$0>>0]|0;
     $13 = $12 & 1;
     $14 = ($13<<24>>24)==(0);
     if (!($14)) {
      $15 = (($0) + 8|0);
      $16 = HEAP32[$15>>2]|0;
      __ZdlPv($16);
     }
     $17 = HEAP8[$1>>0]|0;
     $18 = $17 & 1;
     $19 = ($18<<24>>24)==(0);
     if (!($19)) {
      $20 = (($1) + 8|0);
      $21 = HEAP32[$20>>2]|0;
      __ZdlPv($21);
     }
     __THREW__ = 0;
     invoke_vi(3517,($2|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      $61 = ___cxa_find_matching_catch()|0;
      $62 = tempRet0;
      $$2 = $62;$$23 = $61;$$pre$phiZ2D = $5;
      break L1;
     }
     $24 = HEAP8[$5>>0]|0;
     $25 = $24 & 1;
     $26 = ($25<<24>>24)==(0);
     if (!($26)) {
      $27 = (($this) + 36|0);
      $28 = HEAP32[$27>>2]|0;
      __ZdlPv($28);
     }
     $29 = (($this) + 16|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      STACKTOP = sp;return;
     }
     $32 = (($this) + 20|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==($30|0);
     if ($34) {
      $44 = $30;
     } else {
      $36 = $33;
      while(1) {
       $35 = (($36) + -12|0);
       HEAP32[$32>>2] = $35;
       $37 = HEAP8[$35>>0]|0;
       $38 = $37 & 1;
       $39 = ($38<<24>>24)==(0);
       if ($39) {
        $41 = $35;
       } else {
        $42 = (($36) + -4|0);
        $43 = HEAP32[$42>>2]|0;
        __ZdlPv($43);
        $$pre$i$i$i$i$i = HEAP32[$32>>2]|0;
        $41 = $$pre$i$i$i$i$i;
       }
       $40 = ($41|0)==($30|0);
       if ($40) {
        break;
       } else {
        $36 = $41;
       }
      }
      $$pre$i$i$i = HEAP32[$29>>2]|0;
      $44 = $$pre$i$i$i;
     }
     __ZdlPv($44);
     STACKTOP = sp;return;
    }
   } while(0);
   $56 = HEAP8[$1>>0]|0;
   $57 = $56 & 1;
   $58 = ($57<<24>>24)==(0);
   if ($58) {
    $$1 = $$0;$$12 = $$01;
    label = 26;
   } else {
    $59 = (($1) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    __ZdlPv($60);
    $$1 = $$0;$$12 = $$01;
    label = 26;
   }
  }
 } while(0);
 do {
  if ((label|0) == 26) {
   __THREW__ = 0;
   invoke_vi(3517,($2|0));
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    $86 = ___cxa_find_matching_catch(0|0)|0;
    $87 = tempRet0;
    ___clang_call_terminate($86);
    // unreachable;
   } else {
    $$pre = (($this) + 28|0);
    $$2 = $$1;$$23 = $$12;$$pre$phiZ2D = $$pre;
    break;
   }
  }
 } while(0);
 $65 = HEAP8[$$pre$phiZ2D>>0]|0;
 $66 = $65 & 1;
 $67 = ($66<<24>>24)==(0);
 if (!($67)) {
  $68 = (($this) + 36|0);
  $69 = HEAP32[$68>>2]|0;
  __ZdlPv($69);
 }
 $70 = (($this) + 16|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  ___resumeException($$23|0);
  // unreachable;
 }
 $73 = (($this) + 20|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==($71|0);
 if ($75) {
  $85 = $71;
 } else {
  $77 = $74;
  while(1) {
   $76 = (($77) + -12|0);
   HEAP32[$73>>2] = $76;
   $78 = HEAP8[$76>>0]|0;
   $79 = $78 & 1;
   $80 = ($79<<24>>24)==(0);
   if ($80) {
    $82 = $76;
   } else {
    $83 = (($77) + -4|0);
    $84 = HEAP32[$83>>2]|0;
    __ZdlPv($84);
    $$pre$i$i$i$i$i13 = HEAP32[$73>>2]|0;
    $82 = $$pre$i$i$i$i$i13;
   }
   $81 = ($82|0)==($71|0);
   if ($81) {
    break;
   } else {
    $77 = $82;
   }
  }
  $$pre$i$i$i14 = HEAP32[$70>>2]|0;
  $85 = $$pre$i$i$i14;
 }
 __ZdlPv($85);
 ___resumeException($$23|0);
 // unreachable;
}
function __Z17GetCachingManagerv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[617944>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $9 = $0;
  STACKTOP = sp;return ($9|0);
 }
 $2 = (__Znwj(12)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$2>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_vi(3518,($2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZdlPv($2);
  ___resumeException($7|0);
  // unreachable;
 }
 HEAP32[617944>>2] = $2;
 $9 = $2;
 STACKTOP = sp;return ($9|0);
}
function __ZN14CachingManager12ReadInfoFileERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPlPNS0_6vectorIS6_NS4_IS6_EEEE($path,$lastUsedTime,$fileNames) {
 $path = $path|0;
 $lastUsedTime = $lastUsedTime|0;
 $fileNames = $fileNames|0;
 var $$0 = 0, $$0$ph = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $$byval_copy6 = 0, $$pr = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i13 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $headerData = 0, $i$036 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $seperatedHeader = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy6 = sp + 52|0;
 $0 = sp;
 $headerData = sp + 4|0;
 $1 = sp + 16|0;
 $2 = sp + 28|0;
 $seperatedHeader = sp + 40|0;
 ;HEAP32[$headerData+0>>2]=0|0;HEAP32[$headerData+4>>2]=0|0;HEAP32[$headerData+8>>2]=0|0;
 HEAP8[$2>>0] = 12;
 $3 = (($2) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[617960+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[617960+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[617960+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[617960+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[617960+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[617960+5>>0]|0;
 $4 = (($2) + 7|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1776,($1|0),($path|0),($2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   $22 = ___cxa_find_matching_catch()|0;
   $23 = tempRet0;
   $$01 = $22;$$03 = $23;
   label = 12;
  } else {
   __THREW__ = 0;
   $7 = (invoke_iii(2418,($headerData|0),($1|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    $26 = HEAP8[$1>>0]|0;
    $27 = $26 & 1;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $$01 = $24;$$03 = $25;
     label = 12;
     break;
    }
    $29 = (($1) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    __ZdlPv($30);
    $$01 = $24;$$03 = $25;
    label = 12;
    break;
   }
   $10 = HEAP8[$1>>0]|0;
   $11 = $10 & 1;
   $12 = ($11<<24>>24)==(0);
   if (!($12)) {
    $13 = (($1) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    __ZdlPv($14);
   }
   $15 = HEAP8[$2>>0]|0;
   $16 = $15 & 1;
   $17 = ($16<<24>>24)==(0);
   if (!($17)) {
    $18 = (($2) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($19);
   }
   if ($7) {
    $36 = HEAP8[$headerData>>0]|0;
    $37 = $36 & 1;
    $38 = ($37<<24>>24)==(0);
    if ($38) {
     $43 = (($headerData) + 1|0);
     $44 = $36&255;
     $45 = $44 >>> 1;
     $46 = $43;$47 = $45;
    } else {
     $39 = (($headerData) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($headerData) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $46 = $40;$47 = $42;
    }
    __THREW__ = 0;
    invoke_viiii(376,($seperatedHeader|0),($46|0),($47|0),10);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $20 = ___cxa_find_matching_catch()|0;
     $21 = tempRet0;
     $$12 = $20;$$14 = $21;
     break;
    }
    $50 = HEAP32[$seperatedHeader>>2]|0;
    $51 = (($seperatedHeader) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($50|0)==($52|0);
    L23: do {
     if ($53) {
      $$0 = 0;$151 = $50;
     } else {
      $54 = HEAP8[$50>>0]|0;
      $55 = $54 & 1;
      $56 = ($55<<24>>24)==(0);
      if ($56) {
       $59 = (($50) + 1|0);
       $60 = $59;
      } else {
       $57 = (($50) + 8|0);
       $58 = HEAP32[$57>>2]|0;
       $60 = $58;
      }
      __THREW__ = 0;
      $61 = (invoke_ii(3263,($60|0))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      L29: do {
       if ($63) {
        label = 25;
       } else {
        $64 = ($61|0)>(-1);
        L31: do {
         if ($64) {
          $$0$ph = 0;
         } else {
          $83 = (($50) + 12|0);
          $84 = HEAP32[$51>>2]|0;
          $85 = ($83|0)==($84|0);
          if ($85) {
           $$0$ph = 0;
          } else {
           $86 = ($lastUsedTime|0)==(0|0);
           if ($86) {
            $99 = $84;
           } else {
            $87 = HEAP8[$83>>0]|0;
            $88 = $87 & 1;
            $89 = ($88<<24>>24)==(0);
            if ($89) {
             $92 = (($83) + 1|0);
             $93 = $92;
            } else {
             $90 = (($50) + 20|0);
             $91 = HEAP32[$90>>2]|0;
             $93 = $91;
            }
            __THREW__ = 0;
            $94 = (invoke_ii(3263,($93|0))|0);
            $95 = __THREW__; __THREW__ = 0;
            $96 = $95&1;
            if ($96) {
             label = 25;
             break L29;
            }
            HEAP32[$lastUsedTime>>2] = $94;
            $$pre = HEAP32[$51>>2]|0;
            $99 = $$pre;
           }
           $97 = (($50) + 24|0);
           $98 = ($97|0)==($99|0);
           if ($98) {
            $$0$ph = 0;
           } else {
            $100 = ($fileNames|0)==(0|0);
            if ($100) {
             $$0$ph = 1;
            } else {
             $101 = HEAP8[$97>>0]|0;
             $102 = $101 & 1;
             $103 = ($102<<24>>24)==(0);
             if ($103) {
              $106 = (($97) + 1|0);
              $107 = $106;
             } else {
              $104 = (($50) + 32|0);
              $105 = HEAP32[$104>>2]|0;
              $107 = $105;
             }
             __THREW__ = 0;
             $108 = (invoke_ii(3263,($107|0))|0);
             $109 = __THREW__; __THREW__ = 0;
             $110 = $109&1;
             if ($110) {
              label = 25;
              break L29;
             }
             $111 = (($fileNames) + 4|0);
             $112 = HEAP32[$111>>2]|0;
             $113 = HEAP32[$fileNames>>2]|0;
             $114 = $112;
             $115 = $113;
             $116 = (($114) - ($115))|0;
             $117 = (($116|0) / 12)&-1;
             $118 = ($117>>>0)<($108>>>0);
             do {
              if ($118) {
               $119 = (($108) - ($117))|0;
               __THREW__ = 0;
               invoke_vii(2762,($fileNames|0),($119|0));
               $120 = __THREW__; __THREW__ = 0;
               $121 = $120&1;
               if ($121) {
                label = 25;
                break L29;
               }
              } else {
               $122 = ($117>>>0)>($108>>>0);
               if (!($122)) {
                break;
               }
               $123 = (($113) + (($108*12)|0)|0);
               $124 = ($112|0)==($123|0);
               if ($124) {
                break;
               } else {
                $126 = $112;
               }
               while(1) {
                $125 = (($126) + -12|0);
                HEAP32[$111>>2] = $125;
                $127 = HEAP8[$125>>0]|0;
                $128 = $127 & 1;
                $129 = ($128<<24>>24)==(0);
                if ($129) {
                 $131 = $125;
                } else {
                 $132 = (($126) + -4|0);
                 $133 = HEAP32[$132>>2]|0;
                 __ZdlPv($133);
                 $$pre$i$i$i18 = HEAP32[$111>>2]|0;
                 $131 = $$pre$i$i$i18;
                }
                $130 = ($131|0)==($123|0);
                if ($130) {
                 break;
                } else {
                 $126 = $131;
                }
               }
              }
             } while(0);
             $134 = (($50) + 36|0);
             $135 = HEAP32[$51>>2]|0;
             $136 = ($134|0)==($135|0);
             if ($136) {
              $$0$ph = 0;
              break;
             }
             $137 = ($108|0)>(0);
             if ($137) {
              $142 = $134;$i$036 = 0;
             } else {
              $$0$ph = 1;
              break;
             }
             while(1) {
              $140 = HEAP32[$fileNames>>2]|0;
              $141 = (($140) + (($i$036*12)|0)|0);
              __THREW__ = 0;
              (invoke_iii(2233,($141|0),($142|0))|0);
              $143 = __THREW__; __THREW__ = 0;
              $144 = $143&1;
              if ($144) {
               label = 24;
               break;
              }
              $145 = (($142) + 12|0);
              $146 = HEAP32[$51>>2]|0;
              $147 = ($145|0)==($146|0);
              $139 = (($i$036) + 1)|0;
              if ($147) {
               label = 58;
               break;
              }
              $138 = ($139|0)<($108|0);
              if ($138) {
               $142 = $145;$i$036 = $139;
              } else {
               $$0$ph = 1;
               break L31;
              }
             }
             if ((label|0) == 24) {
              $65 = ___cxa_find_matching_catch()|0;
              $66 = tempRet0;
              $lpad$phi$index = $65;$lpad$phi$index2 = $66;
              break L29;
             }
             else if ((label|0) == 58) {
              $148 = (($108) + -1)|0;
              $149 = ($i$036|0)==($148|0);
              $$0$ph = $149;
              break;
             }
            }
           }
          }
         }
        } while(0);
        $$pr = HEAP32[$seperatedHeader>>2]|0;
        $$0 = $$0$ph;$151 = $$pr;
        break L23;
       }
      } while(0);
      if ((label|0) == 25) {
       $67 = ___cxa_find_matching_catch()|0;
       $68 = tempRet0;
       $lpad$phi$index = $67;$lpad$phi$index2 = $68;
      }
      $69 = HEAP32[$seperatedHeader>>2]|0;
      $70 = ($69|0)==(0|0);
      if ($70) {
       $$12 = $lpad$phi$index;$$14 = $lpad$phi$index2;
       break L1;
      }
      $71 = HEAP32[$51>>2]|0;
      $72 = ($71|0)==($69|0);
      if ($72) {
       $82 = $69;
      } else {
       $74 = $71;
       while(1) {
        $73 = (($74) + -12|0);
        HEAP32[$51>>2] = $73;
        $75 = HEAP8[$73>>0]|0;
        $76 = $75 & 1;
        $77 = ($76<<24>>24)==(0);
        if ($77) {
         $79 = $73;
        } else {
         $80 = (($74) + -4|0);
         $81 = HEAP32[$80>>2]|0;
         __ZdlPv($81);
         $$pre$i$i$i$i$i13 = HEAP32[$51>>2]|0;
         $79 = $$pre$i$i$i$i$i13;
        }
        $78 = ($79|0)==($69|0);
        if ($78) {
         break;
        } else {
         $74 = $79;
        }
       }
       $$pre$i$i$i14 = HEAP32[$seperatedHeader>>2]|0;
       $82 = $$pre$i$i$i14;
      }
      __ZdlPv($82);
      $$12 = $lpad$phi$index;$$14 = $lpad$phi$index2;
      break L1;
     }
    } while(0);
    $150 = ($151|0)==(0|0);
    if ($150) {
     $$1 = $$0;
    } else {
     $152 = HEAP32[$51>>2]|0;
     $153 = ($152|0)==($151|0);
     if ($153) {
      $163 = $151;
     } else {
      $155 = $152;
      while(1) {
       $154 = (($155) + -12|0);
       HEAP32[$51>>2] = $154;
       $156 = HEAP8[$154>>0]|0;
       $157 = $156 & 1;
       $158 = ($157<<24>>24)==(0);
       if ($158) {
        $160 = $154;
       } else {
        $161 = (($155) + -4|0);
        $162 = HEAP32[$161>>2]|0;
        __ZdlPv($162);
        $$pre$i$i$i$i$i = HEAP32[$51>>2]|0;
        $160 = $$pre$i$i$i$i$i;
       }
       $159 = ($160|0)==($151|0);
       if ($159) {
        break;
       } else {
        $155 = $160;
       }
      }
      $$pre$i$i$i = HEAP32[$seperatedHeader>>2]|0;
      $163 = $$pre$i$i$i;
     }
     __ZdlPv($163);
     $$1 = $$0;
    }
   } else {
    $$1 = 0;
   }
   $164 = HEAP8[$headerData>>0]|0;
   $165 = $164 & 1;
   $166 = ($165<<24>>24)==(0);
   if ($166) {
    STACKTOP = sp;return ($$1|0);
   }
   $167 = (($headerData) + 8|0);
   $168 = HEAP32[$167>>2]|0;
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($168|0),($$byval_copy6|0));
   $169 = __THREW__; __THREW__ = 0;
   $170 = $169&1;
   if ($170) {
    $171 = ___cxa_find_matching_catch()|0;
    $172 = tempRet0;
    ___cxa_call_unexpected(($171|0));
    // unreachable;
   } else {
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $31 = HEAP8[$2>>0]|0;
  $32 = $31 & 1;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   $$12 = $$01;$$14 = $$03;
  } else {
   $34 = (($2) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   __ZdlPv($35);
   $$12 = $$01;$$14 = $$03;
  }
 }
 $173 = HEAP8[$headerData>>0]|0;
 $174 = $173 & 1;
 $175 = ($174<<24>>24)==(0);
 if ($175) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $176 = (($headerData) + 8|0);
 $177 = HEAP32[$176>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($177|0),($$byval_copy6|0));
 $178 = __THREW__; __THREW__ = 0;
 $179 = $178&1;
 if ($179) {
  $180 = ___cxa_find_matching_catch()|0;
  $181 = tempRet0;
  ___cxa_call_unexpected(($180|0));
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN5Cache18WriteCacheInfoFileEb($this,$updateExpiration) {
 $this = $this|0;
 $updateExpiration = $updateExpiration|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $f = 0, $folderPath = 0, $indexFile = 0;
 var $path = 0, $vararg_buffer = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $vararg_buffer = sp;
 $folderPath = sp + 96|0;
 $0 = sp + 20|0;
 $indexFile = sp + 32|0;
 $path = sp + 44|0;
 $1 = sp + 56|0;
 $f = sp + 68|0;
 HEAP8[$0>>0] = 0;
 $2 = (($0) + 1|0);
 HEAP8[$2>>0] = 0;
 $3 = (($this) + 4|0);
 __THREW__ = 0;
 invoke_viii(1776,($vararg_buffer|0),($3|0),($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $eh$lpad$body$index3Z2D = $29;$eh$lpad$body$indexZ2D = $28;
  } else {
   __THREW__ = 0;
   invoke_viii(1777,($folderPath|0),($vararg_buffer|0),0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $13 = ___cxa_find_matching_catch()|0;
    $14 = tempRet0;
    $15 = HEAP8[$vararg_buffer>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     $eh$lpad$body$index3Z2D = $14;$eh$lpad$body$indexZ2D = $13;
     break;
    }
    $18 = (($vararg_buffer) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($19);
    $eh$lpad$body$index3Z2D = $14;$eh$lpad$body$indexZ2D = $13;
    break;
   }
   $8 = HEAP8[$vararg_buffer>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if (!($10)) {
    $11 = (($vararg_buffer) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    __ZdlPv($12);
   }
   $20 = HEAP8[$0>>0]|0;
   $21 = $20 & 1;
   $22 = ($21<<24>>24)==(0);
   if (!($22)) {
    $23 = (($0) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZdlPv($24);
   }
   __THREW__ = 0;
   $25 = (invoke_ii(3257,($folderPath|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   L14: do {
    if ($27) {
     label = 14;
    } else {
     L16: do {
      if ($25) {
       if ($updateExpiration) {
        __THREW__ = 0;
        $37 = (invoke_ii(3264,(0|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         label = 14;
         break L14;
        }
        $40 = (($this) + 48|0);
        $41 = HEAP32[$40>>2]|0;
        $42 = (($41) + ($37))|0;
        $43 = (($this) + 16|0);
        HEAP32[$43>>2] = $42;
       }
       $44 = (($this) + 56|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = (($this) + 60|0);
       $47 = ($45|0)==($46|0);
       if ($47) {
        $62 = 0;$65 = 0;
       } else {
        $48 = (($45) + 36|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = ($49|0)<(0);
        $51 = $50 << 31 >> 31;
        $62 = $49;$65 = $51;
       }
       $52 = (($this) + 16|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($53|0)<(0);
       $55 = $54 << 31 >> 31;
       __THREW__ = 0;
       $56 = $vararg_buffer;
       $57 = $56;
       HEAP32[$57>>2] = $53;
       $58 = (($56) + 4)|0;
       $59 = $58;
       HEAP32[$59>>2] = $55;
       $vararg_ptr8 = (($vararg_buffer) + 8|0);
       HEAP32[$vararg_ptr8>>2] = 1;
       $vararg_ptr9 = (($vararg_buffer) + 12|0);
       $60 = $vararg_ptr9;
       $61 = $60;
       HEAP32[$61>>2] = $62;
       $63 = (($60) + 4)|0;
       $64 = $63;
       HEAP32[$64>>2] = $65;
       invoke_viii(1617,($indexFile|0),(617928|0),($vararg_buffer|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        label = 14;
        break L14;
       }
       HEAP8[$1>>0] = 12;
       $68 = (($1) + 1|0);
       ;HEAP8[$68+0>>0]=HEAP8[617960+0>>0]|0;HEAP8[$68+1>>0]=HEAP8[617960+1>>0]|0;HEAP8[$68+2>>0]=HEAP8[617960+2>>0]|0;HEAP8[$68+3>>0]=HEAP8[617960+3>>0]|0;HEAP8[$68+4>>0]=HEAP8[617960+4>>0]|0;HEAP8[$68+5>>0]=HEAP8[617960+5>>0]|0;
       $69 = (($1) + 7|0);
       HEAP8[$69>>0] = 0;
       __THREW__ = 0;
       invoke_viii(1776,($path|0),($folderPath|0),($1|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        $82 = ___cxa_find_matching_catch()|0;
        $83 = tempRet0;
        $84 = HEAP8[$1>>0]|0;
        $85 = $84 & 1;
        $86 = ($85<<24>>24)==(0);
        if ($86) {
         $$1 = $83;$$12 = $82;
        } else {
         $87 = (($1) + 8|0);
         $88 = HEAP32[$87>>2]|0;
         __ZdlPv($88);
         $$1 = $83;$$12 = $82;
        }
       } else {
        $72 = HEAP8[$1>>0]|0;
        $73 = $72 & 1;
        $74 = ($73<<24>>24)==(0);
        if (!($74)) {
         $75 = (($1) + 8|0);
         $76 = HEAP32[$75>>2]|0;
         __ZdlPv($76);
        }
        __THREW__ = 0;
        invoke_vi(3519,($f|0));
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        L33: do {
         if ($78) {
          label = 29;
         } else {
          __THREW__ = 0;
          $79 = (invoke_iiiii(241,($f|0),($path|0),1,3)|0);
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          do {
           if (!($81)) {
            if ($79) {
             __THREW__ = 0;
             (invoke_iiii(1550,($path|0),2,2)|0);
             $95 = __THREW__; __THREW__ = 0;
             $96 = $95&1;
             if ($96) {
              break;
             }
             $97 = HEAP8[$indexFile>>0]|0;
             $98 = $97 & 1;
             $99 = ($98<<24>>24)==(0);
             if ($99) {
              $104 = (($indexFile) + 1|0);
              $105 = $97&255;
              $106 = $105 >>> 1;
              $107 = $104;$108 = $106;
             } else {
              $100 = (($indexFile) + 8|0);
              $101 = HEAP32[$100>>2]|0;
              $102 = (($indexFile) + 4|0);
              $103 = HEAP32[$102>>2]|0;
              $107 = $101;$108 = $103;
             }
             __THREW__ = 0;
             (invoke_iiii(1551,($f|0),($107|0),($108|0))|0);
             $109 = __THREW__; __THREW__ = 0;
             $110 = $109&1;
             if ($110) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(3261,($f|0))|0);
             $111 = __THREW__; __THREW__ = 0;
             $112 = $111&1;
             if ($112) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vi(3517,($f|0));
            $113 = __THREW__; __THREW__ = 0;
            $114 = $113&1;
            if ($114) {
             label = 29;
             break L33;
            }
            $115 = HEAP8[$path>>0]|0;
            $116 = $115 & 1;
            $117 = ($116<<24>>24)==(0);
            if (!($117)) {
             $118 = (($path) + 8|0);
             $119 = HEAP32[$118>>2]|0;
             __ZdlPv($119);
            }
            $120 = HEAP8[$indexFile>>0]|0;
            $121 = $120 & 1;
            $122 = ($121<<24>>24)==(0);
            if ($122) {
             break L16;
            }
            $123 = (($indexFile) + 8|0);
            $124 = HEAP32[$123>>2]|0;
            __ZdlPv($124);
            break L16;
           }
          } while(0);
          $91 = ___cxa_find_matching_catch()|0;
          $92 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3517,($f|0));
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           $145 = ___cxa_find_matching_catch(0|0)|0;
           $146 = tempRet0;
           ___clang_call_terminate($145);
           // unreachable;
          } else {
           $$0 = $92;$$01 = $91;
          }
         }
        } while(0);
        if ((label|0) == 29) {
         $89 = ___cxa_find_matching_catch()|0;
         $90 = tempRet0;
         $$0 = $90;$$01 = $89;
        }
        $130 = HEAP8[$path>>0]|0;
        $131 = $130 & 1;
        $132 = ($131<<24>>24)==(0);
        if ($132) {
         $$1 = $$0;$$12 = $$01;
        } else {
         $133 = (($path) + 8|0);
         $134 = HEAP32[$133>>2]|0;
         __ZdlPv($134);
         $$1 = $$0;$$12 = $$01;
        }
       }
       $135 = HEAP8[$indexFile>>0]|0;
       $136 = $135 & 1;
       $137 = ($136<<24>>24)==(0);
       if ($137) {
        $$2 = $$1;$$23 = $$12;
        break L14;
       }
       $138 = (($indexFile) + 8|0);
       $139 = HEAP32[$138>>2]|0;
       __ZdlPv($139);
       $$2 = $$1;$$23 = $$12;
       break L14;
      }
     } while(0);
     $125 = HEAP8[$folderPath>>0]|0;
     $126 = $125 & 1;
     $127 = ($126<<24>>24)==(0);
     if ($127) {
      STACKTOP = sp;return;
     }
     $128 = (($folderPath) + 8|0);
     $129 = HEAP32[$128>>2]|0;
     __ZdlPv($129);
     STACKTOP = sp;return;
    }
   } while(0);
   if ((label|0) == 14) {
    $35 = ___cxa_find_matching_catch()|0;
    $36 = tempRet0;
    $$2 = $36;$$23 = $35;
   }
   $140 = HEAP8[$folderPath>>0]|0;
   $141 = $140 & 1;
   $142 = ($141<<24>>24)==(0);
   if ($142) {
    $$3 = $$2;$$34 = $$23;
    ___resumeException($$34|0);
    // unreachable;
   }
   $143 = (($folderPath) + 8|0);
   $144 = HEAP32[$143>>2]|0;
   __ZdlPv($144);
   $$3 = $$2;$$34 = $$23;
   ___resumeException($$34|0);
   // unreachable;
  }
 } while(0);
 $30 = HEAP8[$0>>0]|0;
 $31 = $30 & 1;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  $$3 = $eh$lpad$body$index3Z2D;$$34 = $eh$lpad$body$indexZ2D;
  ___resumeException($$34|0);
  // unreachable;
 }
 $33 = (($0) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 __ZdlPv($34);
 $$3 = $eh$lpad$body$index3Z2D;$$34 = $eh$lpad$body$indexZ2D;
 ___resumeException($$34|0);
 // unreachable;
}
function __ZN5Cache10AddToCacheERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEi($this,$path,$bytes) {
 $this = $this|0;
 $path = $path|0;
 $bytes = $bytes|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i$i = 0, $__p$0$i$i12 = 0, $__ps$0$i$i = 0, $lastUsedTime = 0, $name = 0, $version$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $lastUsedTime = sp + 80|0;
 $name = sp;
 $0 = sp + 12|0;
 $1 = sp + 24|0;
 $2 = sp + 40|0;
 $3 = sp + 64|0;
 $4 = sp + 76|0;
 HEAP32[$lastUsedTime>>2] = 0;
 (__ZN14CachingManager12ReadInfoFileERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPlPNS0_6vectorIS6_NS4_IS6_EEEE($path,$lastUsedTime,0)|0);
 $5 = HEAP32[$lastUsedTime>>2]|0;
 $6 = ($5|0)>(0);
 if ($6) {
  $7 = (_time((0|0))|0);
  $8 = (($this) + 48|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) - ($9))|0;
  $11 = ($5|0)<($10|0);
  if ($11) {
   (__Z21DeleteFileOrDirectoryRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($path)|0);
   STACKTOP = sp;return;
  }
 }
 $12 = ($bytes|0)<(0);
 $13 = $12 << 31 >> 31;
 $14 = (($this) + 24|0);
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (_i64Add(($17|0),($20|0),($bytes|0),($13|0))|0);
 $22 = tempRet0;
 $23 = $14;
 $24 = $23;
 HEAP32[$24>>2] = $21;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 __Z24GetLastPathNameComponentRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($name,$path);
 $27 = HEAP8[$name>>0]|0;
 $28 = $27 & 1;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  $32 = $27&255;
  $33 = $32 >>> 1;
  $35 = $33;
 } else {
  $30 = (($name) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $35 = $31;
 }
 $34 = ($35|0)==(0);
 L10: do {
  if ($34) {
   $version$0 = 0;
   label = 55;
  } else {
   if ($29) {
    $38 = (($name) + 1|0);
    $40 = $38;
   } else {
    $36 = (($name) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $40 = $37;
   }
   $39 = (($40) + ($35)|0);
   $__ps$0$i$i = $39;
   while(1) {
    $41 = ($__ps$0$i$i|0)==($40|0);
    if ($41) {
     $version$0 = 0;
     label = 55;
     break L10;
    }
    $42 = (($__ps$0$i$i) + -1|0);
    $43 = HEAP8[$42>>0]|0;
    $44 = ($43<<24>>24)==(64);
    if ($44) {
     break;
    } else {
     $__ps$0$i$i = $42;
    }
   }
   $45 = $42;
   $46 = $40;
   $47 = (($45) - ($46))|0;
   $48 = ($47|0)==(-1);
   if ($48) {
    $version$0 = 0;
    label = 55;
   } else {
    $49 = (($47) + 1)|0;
    if ($29) {
     $52 = $27&255;
     $53 = $52 >>> 1;
     $55 = $53;
    } else {
     $50 = (($name) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $55 = $51;
    }
    $54 = ($55>>>0)<($49>>>0);
    if ($54) {
     __THREW__ = 0;
     invoke_vi(3304,0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 50;
      break;
     }
     // unreachable;
    }
    if ($29) {
     $60 = (($name) + 1|0);
     $62 = $60;
    } else {
     $58 = (($name) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     $62 = $59;
    }
    $61 = (($62) + ($49)|0);
    $63 = (($55) - ($49))|0;
    $64 = ($63>>>0)>(4294967279);
    if ($64) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      label = 50;
      break;
     }
     // unreachable;
    }
    $67 = ($63>>>0)<(11);
    if ($67) {
     $68 = $63 << 1;
     $69 = $68&255;
     HEAP8[$0>>0] = $69;
     $70 = (($0) + 1|0);
     $$pre$phiZ2D = $0;$82 = $69;$__p$0$i$i = $70;
    } else {
     $71 = (($63) + 16)|0;
     $72 = $71 & -16;
     __THREW__ = 0;
     $73 = (invoke_ii(2988,($72|0))|0);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      label = 50;
      break;
     }
     $76 = (($0) + 8|0);
     HEAP32[$76>>2] = $73;
     $77 = $72 | 1;
     HEAP32[$0>>2] = $77;
     $78 = (($0) + 4|0);
     HEAP32[$78>>2] = $63;
     $79 = $77&255;
     $$pre$phiZ2D = $0;$82 = $79;$__p$0$i$i = $73;
    }
    _memcpy(($__p$0$i$i|0),($61|0),($63|0))|0;
    $80 = (($__p$0$i$i) + ($63)|0);
    HEAP8[$80>>0] = 0;
    $81 = $82 & 1;
    $83 = ($81<<24>>24)==(0);
    if ($83) {
     $86 = (($0) + 1|0);
     $87 = $86;
    } else {
     $84 = (($0) + 8|0);
     $85 = HEAP32[$84>>2]|0;
     $87 = $85;
    }
    __THREW__ = 0;
    $88 = (invoke_ii(3263,($87|0))|0);
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     $135 = ___cxa_find_matching_catch()|0;
     $136 = tempRet0;
     $137 = HEAP8[$$pre$phiZ2D>>0]|0;
     $138 = $137 & 1;
     $139 = ($138<<24>>24)==(0);
     if ($139) {
      $$1 = $136;$$12 = $135;
      break;
     }
     $140 = (($0) + 8|0);
     $141 = HEAP32[$140>>2]|0;
     __ZdlPv($141);
     $$1 = $136;$$12 = $135;
     break;
    }
    $91 = HEAP8[$$pre$phiZ2D>>0]|0;
    $92 = $91 & 1;
    $93 = ($92<<24>>24)==(0);
    if (!($93)) {
     $94 = (($0) + 8|0);
     $95 = HEAP32[$94>>2]|0;
     __ZdlPv($95);
    }
    $96 = HEAP8[$name>>0]|0;
    $97 = $96 & 1;
    $98 = ($97<<24>>24)==(0);
    if ($98) {
     $103 = $96&255;
     $104 = $103 >>> 1;
     $105 = (($name) + 1|0);
     $107 = $104;$124 = $105;
    } else {
     $99 = (($name) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = (($name) + 8|0);
     $102 = HEAP32[$101>>2]|0;
     $107 = $100;$124 = $102;
    }
    $106 = ($107>>>0)<($47>>>0);
    $108 = $106 ? $107 : $47;
    $109 = ($108>>>0)>(4294967279);
    if ($109) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if ($111) {
      label = 50;
      break;
     }
     // unreachable;
    }
    $112 = ($108>>>0)<(11);
    if ($112) {
     $113 = $108 << 1;
     $114 = $113&255;
     HEAP8[$1>>0] = $114;
     $115 = (($1) + 1|0);
     $__p$0$i$i12 = $115;
    } else {
     $116 = (($108) + 16)|0;
     $117 = $116 & -16;
     __THREW__ = 0;
     $118 = (invoke_ii(2988,($117|0))|0);
     $119 = __THREW__; __THREW__ = 0;
     $120 = $119&1;
     if ($120) {
      label = 50;
      break;
     }
     $121 = (($1) + 8|0);
     HEAP32[$121>>2] = $118;
     $122 = $117 | 1;
     HEAP32[$1>>2] = $122;
     $123 = (($1) + 4|0);
     HEAP32[$123>>2] = $108;
     $__p$0$i$i12 = $118;
    }
    _memcpy(($__p$0$i$i12|0),($124|0),($108|0))|0;
    $125 = (($__p$0$i$i12) + ($108)|0);
    HEAP8[$125>>0] = 0;
    __THREW__ = 0;
    (invoke_iii(2233,($name|0),($1|0))|0);
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if ($127) {
     $142 = ___cxa_find_matching_catch()|0;
     $143 = tempRet0;
     $144 = HEAP8[$1>>0]|0;
     $145 = $144 & 1;
     $146 = ($145<<24>>24)==(0);
     if ($146) {
      $$1 = $143;$$12 = $142;
      break;
     }
     $147 = (($1) + 8|0);
     $148 = HEAP32[$147>>2]|0;
     __ZdlPv($148);
     $$1 = $143;$$12 = $142;
     break;
    } else {
     $128 = HEAP8[$1>>0]|0;
     $129 = $128 & 1;
     $130 = ($129<<24>>24)==(0);
     if ($130) {
      $version$0 = $88;
      label = 55;
      break;
     }
     $131 = (($1) + 8|0);
     $132 = HEAP32[$131>>2]|0;
     __ZdlPv($132);
     $version$0 = $88;
     label = 55;
     break;
    }
   }
  }
 } while(0);
 L71: do {
  if ((label|0) == 55) {
   $149 = HEAP8[$path>>0]|0;
   $150 = $149 & 1;
   $151 = ($150<<24>>24)==(0);
   if ($151) {
    ;HEAP32[$3+0>>2]=HEAP32[$path+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$path+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$path+8>>2]|0;
   } else {
    $152 = (($path) + 8|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = (($path) + 4|0);
    $155 = HEAP32[$154>>2]|0;
    $156 = ($155>>>0)>(4294967279);
    if ($156) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $157 = __THREW__; __THREW__ = 0;
     $158 = $157&1;
     if ($158) {
      label = 50;
      break;
     }
     // unreachable;
    }
    $159 = ($155>>>0)<(11);
    if ($159) {
     $160 = $155 << 1;
     $161 = $160&255;
     HEAP8[$3>>0] = $161;
     $162 = (($3) + 1|0);
     $__p$0$i$i$i = $162;
    } else {
     $163 = (($155) + 16)|0;
     $164 = $163 & -16;
     __THREW__ = 0;
     $165 = (invoke_ii(2988,($164|0))|0);
     $166 = __THREW__; __THREW__ = 0;
     $167 = $166&1;
     if ($167) {
      label = 50;
      break;
     }
     $168 = (($3) + 8|0);
     HEAP32[$168>>2] = $165;
     $169 = $164 | 1;
     HEAP32[$3>>2] = $169;
     $170 = (($3) + 4|0);
     HEAP32[$170>>2] = $155;
     $__p$0$i$i$i = $165;
    }
    _memcpy(($__p$0$i$i$i|0),($153|0),($155|0))|0;
    $171 = (($__p$0$i$i$i) + ($155)|0);
    HEAP8[$171>>0] = 0;
   }
   $172 = HEAP32[$lastUsedTime>>2]|0;
   ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
   __THREW__ = 0;
   (invoke_iii(2233,($2|0),($3|0))|0);
   $173 = __THREW__; __THREW__ = 0;
   $174 = $173&1;
   do {
    if ($174) {
     $175 = ___cxa_find_matching_catch()|0;
     $176 = tempRet0;
     $177 = HEAP8[$2>>0]|0;
     $178 = $177 & 1;
     $179 = ($178<<24>>24)==(0);
     if (!($179)) {
      $180 = (($2) + 8|0);
      $181 = HEAP32[$180>>2]|0;
      __ZdlPv($181);
     }
     $$0 = $176;$$01 = $175;
    } else {
     $182 = (($2) + 12|0);
     HEAP32[$182>>2] = $bytes;
     $183 = (($2) + 16|0);
     HEAP32[$183>>2] = $version$0;
     $184 = (($2) + 20|0);
     HEAP32[$184>>2] = $172;
     $185 = (($this) + 56|0);
     __THREW__ = 0;
     invoke_viii(1778,($4|0),($185|0),($2|0));
     $186 = __THREW__; __THREW__ = 0;
     $187 = $186&1;
     if ($187) {
      $205 = ___cxa_find_matching_catch()|0;
      $206 = tempRet0;
      $207 = HEAP8[$2>>0]|0;
      $208 = $207 & 1;
      $209 = ($208<<24>>24)==(0);
      if ($209) {
       $$0 = $206;$$01 = $205;
       break;
      }
      $210 = (($2) + 8|0);
      $211 = HEAP32[$210>>2]|0;
      __ZdlPv($211);
      $$0 = $206;$$01 = $205;
      break;
     }
     $188 = HEAP8[$2>>0]|0;
     $189 = $188 & 1;
     $190 = ($189<<24>>24)==(0);
     if (!($190)) {
      $191 = (($2) + 8|0);
      $192 = HEAP32[$191>>2]|0;
      __ZdlPv($192);
     }
     $193 = HEAP8[$3>>0]|0;
     $194 = $193 & 1;
     $195 = ($194<<24>>24)==(0);
     if (!($195)) {
      $196 = (($3) + 8|0);
      $197 = HEAP32[$196>>2]|0;
      __ZdlPv($197);
     }
     __THREW__ = 0;
     invoke_v(148);
     $198 = __THREW__; __THREW__ = 0;
     $199 = $198&1;
     if ($199) {
      label = 50;
      break L71;
     }
     $200 = HEAP8[$name>>0]|0;
     $201 = $200 & 1;
     $202 = ($201<<24>>24)==(0);
     if ($202) {
      STACKTOP = sp;return;
     }
     $203 = (($name) + 8|0);
     $204 = HEAP32[$203>>2]|0;
     __ZdlPv($204);
     STACKTOP = sp;return;
    }
   } while(0);
   $212 = HEAP8[$3>>0]|0;
   $213 = $212 & 1;
   $214 = ($213<<24>>24)==(0);
   if ($214) {
    $$1 = $$0;$$12 = $$01;
   } else {
    $215 = (($3) + 8|0);
    $216 = HEAP32[$215>>2]|0;
    __ZdlPv($216);
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 if ((label|0) == 50) {
  $133 = ___cxa_find_matching_catch()|0;
  $134 = tempRet0;
  $$1 = $134;$$12 = $133;
 }
 $217 = HEAP8[$name>>0]|0;
 $218 = $217 & 1;
 $219 = ($218<<24>>24)==(0);
 if ($219) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $220 = (($name) + 8|0);
 $221 = HEAP32[$220>>2]|0;
 __ZdlPv($221);
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN5Cache22ReadCacheIndexThreadedEPv($data) {
 $data = $data|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$1 = 0, $$12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $cachePath = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$index = 0, $lpad$phi$index9 = 0, $paths = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 36|0;
 $cachePath = sp;
 $1 = sp + 12|0;
 $paths = sp + 24|0;
 HEAP8[$1>>0] = 0;
 $2 = (($1) + 1|0);
 HEAP8[$2>>0] = 0;
 $3 = (($data) + 4|0);
 __THREW__ = 0;
 invoke_viii(1776,($0|0),($3|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $46 = ___cxa_find_matching_catch()|0;
   $47 = tempRet0;
   $eh$lpad$body$index3Z2D = $47;$eh$lpad$body$indexZ2D = $46;
  } else {
   __THREW__ = 0;
   invoke_viii(1777,($cachePath|0),($0|0),0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $13 = ___cxa_find_matching_catch()|0;
    $14 = tempRet0;
    $15 = HEAP8[$0>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     $eh$lpad$body$index3Z2D = $14;$eh$lpad$body$indexZ2D = $13;
     break;
    }
    $18 = (($0) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($19);
    $eh$lpad$body$index3Z2D = $14;$eh$lpad$body$indexZ2D = $13;
    break;
   }
   $8 = HEAP8[$0>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if (!($10)) {
    $11 = (($0) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    __ZdlPv($12);
   }
   $20 = HEAP8[$1>>0]|0;
   $21 = $20 & 1;
   $22 = ($21<<24>>24)==(0);
   if (!($22)) {
    $23 = (($1) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZdlPv($24);
   }
   $25 = (($paths) + 4|0);
   HEAP32[$25>>2] = 0;
   $26 = (($paths) + 8|0);
   HEAP32[$26>>2] = 0;
   $27 = (($paths) + 4|0);
   HEAP32[$paths>>2] = $27;
   __THREW__ = 0;
   $28 = (invoke_iii(2417,($cachePath|0),($paths|0))|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   L13: do {
    if ($30) {
     label = 31;
    } else {
     L15: do {
      if ($28) {
       $31 = HEAP32[$paths>>2]|0;
       $32 = ($31|0)==($27|0);
       if (!($32)) {
        $33 = (($data) + 52|0);
        $37 = $31;
        while(1) {
         $34 = HEAP8[$33>>0]|0;
         $35 = ($34<<24>>24)==(0);
         if (!($35)) {
          break L15;
         }
         $36 = (($37) + 16|0);
         __THREW__ = 0;
         $38 = (invoke_ii(3257,($36|0))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break;
         }
         if ($38) {
          __THREW__ = 0;
          $41 = (invoke_ii(3258,($36|0))|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          __THREW__ = 0;
          invoke_viii(1779,($data|0),($36|0),($41|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          }
         }
         $53 = (($37) + 4|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = ($54|0)==(0|0);
         if ($55) {
          $$01$i$i$i = $37;
          while(1) {
           $58 = (($$01$i$i$i) + 8|0);
           $59 = HEAP32[$58>>2]|0;
           $60 = HEAP32[$59>>2]|0;
           $61 = ($60|0)==($$01$i$i$i|0);
           if ($61) {
            $$0$i$i$i = $59;
            break;
           } else {
            $$01$i$i$i = $59;
           }
          }
         } else {
          $$0$i$i$i$i = $54;
          while(1) {
           $56 = HEAP32[$$0$i$i$i$i>>2]|0;
           $57 = ($56|0)==(0|0);
           if ($57) {
            $$0$i$i$i = $$0$i$i$i$i;
            break;
           } else {
            $$0$i$i$i$i = $56;
           }
          }
         }
         $62 = ($$0$i$i$i|0)==($27|0);
         if ($62) {
          break L15;
         } else {
          $37 = $$0$i$i$i;
         }
        }
        $72 = ___cxa_find_matching_catch()|0;
        $73 = tempRet0;
        $lpad$phi$index = $72;$lpad$phi$index9 = $73;
        break L13;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vii(2763,($data|0),0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      label = 31;
     } else {
      $65 = (($data) + 52|0);
      HEAP8[$65>>0] = 1;
      $66 = HEAP32[$25>>2]|0;
      __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($paths,$66);
      $67 = HEAP8[$cachePath>>0]|0;
      $68 = $67 & 1;
      $69 = ($68<<24>>24)==(0);
      if ($69) {
       STACKTOP = sp;return (0|0);
      }
      $70 = (($cachePath) + 8|0);
      $71 = HEAP32[$70>>2]|0;
      __ZdlPv($71);
      STACKTOP = sp;return (0|0);
     }
    }
   } while(0);
   if ((label|0) == 31) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    $lpad$phi$index = $74;$lpad$phi$index9 = $75;
   }
   $76 = HEAP32[$25>>2]|0;
   __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($paths,$76);
   $77 = HEAP8[$cachePath>>0]|0;
   $78 = $77 & 1;
   $79 = ($78<<24>>24)==(0);
   if ($79) {
    $$1 = $lpad$phi$index;$$12 = $lpad$phi$index9;
    ___resumeException($$1|0);
    // unreachable;
   }
   $80 = (($cachePath) + 8|0);
   $81 = HEAP32[$80>>2]|0;
   __ZdlPv($81);
   $$1 = $lpad$phi$index;$$12 = $lpad$phi$index9;
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $48 = HEAP8[$1>>0]|0;
 $49 = $48 & 1;
 $50 = ($49<<24>>24)==(0);
 if ($50) {
  $$1 = $eh$lpad$body$indexZ2D;$$12 = $eh$lpad$body$index3Z2D;
  ___resumeException($$1|0);
  // unreachable;
 }
 $51 = (($1) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 __ZdlPv($52);
 $$1 = $eh$lpad$body$indexZ2D;$$12 = $eh$lpad$body$index3Z2D;
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __ZN5Cache17ReadCacheInfoFileERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPlS9_($this,$path,$expires,$oldestLastUsedTime) {
 $this = $this|0;
 $path = $path|0;
 $expires = $expires|0;
 $oldestLastUsedTime = $oldestLastUsedTime|0;
 var $$0 = 0, $$0$ph = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $$byval_copy1 = 0, $$pr = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i13 = 0, $$pre$i$i$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $headerData = 0, $seperatedHeader = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 52|0;
 $0 = sp;
 $headerData = sp + 4|0;
 $1 = sp + 16|0;
 $2 = sp + 28|0;
 $seperatedHeader = sp + 40|0;
 ;HEAP32[$headerData+0>>2]=0|0;HEAP32[$headerData+4>>2]=0|0;HEAP32[$headerData+8>>2]=0|0;
 HEAP8[$2>>0] = 12;
 $3 = (($2) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[617960+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[617960+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[617960+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[617960+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[617960+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[617960+5>>0]|0;
 $4 = (($2) + 7|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1776,($1|0),($path|0),($2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   $22 = ___cxa_find_matching_catch()|0;
   $23 = tempRet0;
   $$01 = $23;$$03 = $22;
   label = 12;
  } else {
   __THREW__ = 0;
   $7 = (invoke_iii(2418,($headerData|0),($1|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    $26 = HEAP8[$1>>0]|0;
    $27 = $26 & 1;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $$01 = $25;$$03 = $24;
     label = 12;
     break;
    }
    $29 = (($1) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    __ZdlPv($30);
    $$01 = $25;$$03 = $24;
    label = 12;
    break;
   }
   $10 = HEAP8[$1>>0]|0;
   $11 = $10 & 1;
   $12 = ($11<<24>>24)==(0);
   if (!($12)) {
    $13 = (($1) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    __ZdlPv($14);
   }
   $15 = HEAP8[$2>>0]|0;
   $16 = $15 & 1;
   $17 = ($16<<24>>24)==(0);
   if (!($17)) {
    $18 = (($2) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($19);
   }
   if ($7) {
    $36 = HEAP8[$headerData>>0]|0;
    $37 = $36 & 1;
    $38 = ($37<<24>>24)==(0);
    if ($38) {
     $43 = (($headerData) + 1|0);
     $44 = $36&255;
     $45 = $44 >>> 1;
     $46 = $43;$47 = $45;
    } else {
     $39 = (($headerData) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($headerData) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $46 = $40;$47 = $42;
    }
    __THREW__ = 0;
    invoke_viiii(376,($seperatedHeader|0),($46|0),($47|0),10);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $20 = ___cxa_find_matching_catch()|0;
     $21 = tempRet0;
     $$12 = $21;$$14 = $20;
     break;
    }
    $50 = HEAP32[$seperatedHeader>>2]|0;
    $51 = (($seperatedHeader) + 4|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($50|0)==($52|0);
    L23: do {
     if ($53) {
      $$0 = 0;$110 = $50;
     } else {
      $54 = ($expires|0)==(0|0);
      if ($54) {
       $83 = $52;
       label = 32;
      } else {
       $55 = HEAP8[$50>>0]|0;
       $56 = $55 & 1;
       $57 = ($56<<24>>24)==(0);
       if ($57) {
        $60 = (($50) + 1|0);
        $61 = $60;
       } else {
        $58 = (($50) + 8|0);
        $59 = HEAP32[$58>>2]|0;
        $61 = $59;
       }
       __THREW__ = 0;
       $62 = (invoke_ii(3263,($61|0))|0);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if (!($64)) {
        HEAP32[$expires>>2] = $62;
        $$pre = HEAP32[$51>>2]|0;
        $83 = $$pre;
        label = 32;
       }
      }
      do {
       if ((label|0) == 32) {
        $81 = (($50) + 12|0);
        $82 = ($81|0)==($83|0);
        if ($82) {
         $$0$ph = 1;
        } else {
         $84 = HEAP8[$81>>0]|0;
         $85 = $84 & 1;
         $86 = ($85<<24>>24)==(0);
         if ($86) {
          $89 = (($81) + 1|0);
          $90 = $89;
         } else {
          $87 = (($50) + 20|0);
          $88 = HEAP32[$87>>2]|0;
          $90 = $88;
         }
         __THREW__ = 0;
         $91 = (invoke_ii(3263,($90|0))|0);
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          break;
         }
         $94 = ($91|0)<(1);
         if ($94) {
          $$0$ph = 0;
         } else {
          $95 = (($50) + 24|0);
          $96 = HEAP32[$51>>2]|0;
          $97 = ($95|0)==($96|0);
          if ($97) {
           $$0$ph = 0;
          } else {
           $98 = ($oldestLastUsedTime|0)==(0|0);
           if ($98) {
            $$0$ph = 1;
           } else {
            $99 = HEAP8[$95>>0]|0;
            $100 = $99 & 1;
            $101 = ($100<<24>>24)==(0);
            if ($101) {
             $104 = (($95) + 1|0);
             $105 = $104;
            } else {
             $102 = (($50) + 32|0);
             $103 = HEAP32[$102>>2]|0;
             $105 = $103;
            }
            __THREW__ = 0;
            $106 = (invoke_ii(3263,($105|0))|0);
            $107 = __THREW__; __THREW__ = 0;
            $108 = $107&1;
            if ($108) {
             break;
            }
            HEAP32[$oldestLastUsedTime>>2] = $106;
            $$0$ph = 1;
           }
          }
         }
        }
        $$pr = HEAP32[$seperatedHeader>>2]|0;
        $$0 = $$0$ph;$110 = $$pr;
        break L23;
       }
      } while(0);
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      $67 = HEAP32[$seperatedHeader>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       $$12 = $66;$$14 = $65;
       break L1;
      }
      $69 = HEAP32[$51>>2]|0;
      $70 = ($69|0)==($67|0);
      if ($70) {
       $80 = $67;
      } else {
       $72 = $69;
       while(1) {
        $71 = (($72) + -12|0);
        HEAP32[$51>>2] = $71;
        $73 = HEAP8[$71>>0]|0;
        $74 = $73 & 1;
        $75 = ($74<<24>>24)==(0);
        if ($75) {
         $77 = $71;
        } else {
         $78 = (($72) + -4|0);
         $79 = HEAP32[$78>>2]|0;
         __ZdlPv($79);
         $$pre$i$i$i$i$i13 = HEAP32[$51>>2]|0;
         $77 = $$pre$i$i$i$i$i13;
        }
        $76 = ($77|0)==($67|0);
        if ($76) {
         break;
        } else {
         $72 = $77;
        }
       }
       $$pre$i$i$i14 = HEAP32[$seperatedHeader>>2]|0;
       $80 = $$pre$i$i$i14;
      }
      __ZdlPv($80);
      $$12 = $66;$$14 = $65;
      break L1;
     }
    } while(0);
    $109 = ($110|0)==(0|0);
    if ($109) {
     $$1 = $$0;
    } else {
     $111 = HEAP32[$51>>2]|0;
     $112 = ($111|0)==($110|0);
     if ($112) {
      $122 = $110;
     } else {
      $114 = $111;
      while(1) {
       $113 = (($114) + -12|0);
       HEAP32[$51>>2] = $113;
       $115 = HEAP8[$113>>0]|0;
       $116 = $115 & 1;
       $117 = ($116<<24>>24)==(0);
       if ($117) {
        $119 = $113;
       } else {
        $120 = (($114) + -4|0);
        $121 = HEAP32[$120>>2]|0;
        __ZdlPv($121);
        $$pre$i$i$i$i$i = HEAP32[$51>>2]|0;
        $119 = $$pre$i$i$i$i$i;
       }
       $118 = ($119|0)==($110|0);
       if ($118) {
        break;
       } else {
        $114 = $119;
       }
      }
      $$pre$i$i$i = HEAP32[$seperatedHeader>>2]|0;
      $122 = $$pre$i$i$i;
     }
     __ZdlPv($122);
     $$1 = $$0;
    }
   } else {
    $$1 = 0;
   }
   $123 = HEAP8[$headerData>>0]|0;
   $124 = $123 & 1;
   $125 = ($124<<24>>24)==(0);
   if ($125) {
    STACKTOP = sp;return ($$1|0);
   }
   $126 = (($headerData) + 8|0);
   $127 = HEAP32[$126>>2]|0;
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($127|0),($$byval_copy1|0));
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    $130 = ___cxa_find_matching_catch()|0;
    $131 = tempRet0;
    ___cxa_call_unexpected(($130|0));
    // unreachable;
   } else {
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $31 = HEAP8[$2>>0]|0;
  $32 = $31 & 1;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   $$12 = $$01;$$14 = $$03;
  } else {
   $34 = (($2) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   __ZdlPv($35);
   $$12 = $$01;$$14 = $$03;
  }
 }
 $132 = HEAP8[$headerData>>0]|0;
 $133 = $132 & 1;
 $134 = ($133<<24>>24)==(0);
 if ($134) {
  ___resumeException($$14|0);
  // unreachable;
 }
 $135 = (($headerData) + 8|0);
 $136 = HEAP32[$135>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($136|0),($$byval_copy1|0));
 $137 = __THREW__; __THREW__ = 0;
 $138 = $137&1;
 if ($138) {
  $139 = ___cxa_find_matching_catch()|0;
  $140 = tempRet0;
  ___cxa_call_unexpected(($139|0));
  // unreachable;
 } else {
  ___resumeException($$14|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN5Cache14ReadCacheIndexERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEb($this,$name,$getSize) {
 $this = $this|0;
 $name = $name|0;
 $getSize = $getSize|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cachePath = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var $oldestLastUsedTime = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 28|0;
 $cachePath = sp;
 $1 = sp + 12|0;
 $oldestLastUsedTime = sp + 24|0;
 $2 = (($this) + 4|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($2,$name)|0);
 HEAP8[$1>>0] = 0;
 $3 = (($1) + 1|0);
 HEAP8[$3>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1776,($0|0),($2|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $41 = ___cxa_find_matching_catch()|0;
   $42 = tempRet0;
   $eh$lpad$body$index3Z2D = $42;$eh$lpad$body$indexZ2D = $41;
  } else {
   __THREW__ = 0;
   invoke_viii(1777,($cachePath|0),($0|0),0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $13 = ___cxa_find_matching_catch()|0;
    $14 = tempRet0;
    $15 = HEAP8[$0>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     $eh$lpad$body$index3Z2D = $14;$eh$lpad$body$indexZ2D = $13;
     break;
    }
    $18 = (($0) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($19);
    $eh$lpad$body$index3Z2D = $14;$eh$lpad$body$indexZ2D = $13;
    break;
   }
   $8 = HEAP8[$0>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if (!($10)) {
    $11 = (($0) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    __ZdlPv($12);
   }
   $20 = HEAP8[$1>>0]|0;
   $21 = $20 & 1;
   $22 = ($21<<24>>24)==(0);
   if (!($22)) {
    $23 = (($1) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZdlPv($24);
   }
   __THREW__ = 0;
   $25 = (invoke_ii(3264,(0|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    HEAP32[$oldestLastUsedTime>>2] = $25;
    $28 = (($this) + 48|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($29) + ($25))|0;
    $31 = (($this) + 16|0);
    HEAP32[$31>>2] = $30;
    __THREW__ = 0;
    (invoke_iiiii(242,0,($cachePath|0),($31|0),($oldestLastUsedTime|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     __THREW__ = 0;
     (invoke_ii(3265,($this|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      $36 = HEAP8[$cachePath>>0]|0;
      $37 = $36 & 1;
      $38 = ($37<<24>>24)==(0);
      if ($38) {
       STACKTOP = sp;return 1;
      }
      $39 = (($cachePath) + 8|0);
      $40 = HEAP32[$39>>2]|0;
      __ZdlPv($40);
      STACKTOP = sp;return 1;
     }
    }
   }
   $48 = ___cxa_find_matching_catch()|0;
   $49 = tempRet0;
   $50 = HEAP8[$cachePath>>0]|0;
   $51 = $50 & 1;
   $52 = ($51<<24>>24)==(0);
   if ($52) {
    $$0 = $48;$$01 = $49;
    ___resumeException($$0|0);
    // unreachable;
   }
   $53 = (($cachePath) + 8|0);
   $54 = HEAP32[$53>>2]|0;
   __ZdlPv($54);
   $$0 = $48;$$01 = $49;
   ___resumeException($$0|0);
   // unreachable;
  }
 } while(0);
 $43 = HEAP8[$1>>0]|0;
 $44 = $43 & 1;
 $45 = ($44<<24>>24)==(0);
 if ($45) {
  $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index3Z2D;
  ___resumeException($$0|0);
  // unreachable;
 }
 $46 = (($1) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 __ZdlPv($47);
 $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index3Z2D;
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __ZN14CachingManager15ClearTempFolderEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01 = 0, $$01$i$i$i = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $lockPath = 0, $path = 0, $tempFolders = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $path = sp + 48|0;
 $0 = sp;
 $tempFolders = sp + 12|0;
 $lockPath = sp + 24|0;
 $1 = sp + 36|0;
 HEAP8[$0>>0] = 8;
 $2 = (($0) + 1|0);
 HEAP8[$2>>0]=1886217556&255;HEAP8[$2+1>>0]=(1886217556>>8)&255;HEAP8[$2+2>>0]=(1886217556>>16)&255;HEAP8[$2+3>>0]=1886217556>>24;
 $3 = (($0) + 5|0);
 HEAP8[$3>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1777,($path|0),($0|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $16 = HEAP8[$0>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $$2 = $15;$$23 = $14;
   ___resumeException($$23|0);
   // unreachable;
  }
  $19 = (($0) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  __ZdlPv($20);
  $$2 = $15;$$23 = $14;
  ___resumeException($$23|0);
  // unreachable;
 }
 $6 = HEAP8[$0>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 __THREW__ = 0;
 $11 = (invoke_ii(3257,($path|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L11: do {
  if ($13) {
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $$1 = $22;$$12 = $21;
  } else {
   L13: do {
    if ($11) {
     $23 = (($tempFolders) + 4|0);
     HEAP32[$23>>2] = 0;
     $24 = (($tempFolders) + 8|0);
     HEAP32[$24>>2] = 0;
     $25 = (($tempFolders) + 4|0);
     HEAP32[$tempFolders>>2] = $25;
     __THREW__ = 0;
     $26 = (invoke_iii(2417,($path|0),($tempFolders|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     L15: do {
      if ($28) {
       $29 = ___cxa_find_matching_catch()|0;
       $30 = tempRet0;
       $$0 = $30;$$01 = $29;
      } else {
       L17: do {
        if ($26) {
         $31 = HEAP32[$tempFolders>>2]|0;
         $32 = ($31|0)==($25|0);
         if (!($32)) {
          $33 = (($1) + 1|0);
          $34 = (($1) + 7|0);
          $35 = (($lockPath) + 8|0);
          $36 = (($1) + 8|0);
          $38 = $31;
          while(1) {
           $37 = (($38) + 16|0);
           HEAP8[$1>>0] = 12;
           ;HEAP8[$33+0>>0]=HEAP8[617920+0>>0]|0;HEAP8[$33+1>>0]=HEAP8[617920+1>>0]|0;HEAP8[$33+2>>0]=HEAP8[617920+2>>0]|0;HEAP8[$33+3>>0]=HEAP8[617920+3>>0]|0;HEAP8[$33+4>>0]=HEAP8[617920+4>>0]|0;HEAP8[$33+5>>0]=HEAP8[617920+5>>0]|0;
           HEAP8[$34>>0] = 0;
           __THREW__ = 0;
           invoke_viii(1776,($lockPath|0),($37|0),($1|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if ($40) {
            label = 22;
            break;
           }
           $41 = HEAP8[$1>>0]|0;
           $42 = $41 & 1;
           $43 = ($42<<24>>24)==(0);
           if (!($43)) {
            $44 = HEAP32[$36>>2]|0;
            __ZdlPv($44);
           }
           __THREW__ = 0;
           $45 = (invoke_ii(3266,($lockPath|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if ($47) {
            label = 24;
            break;
           }
           if ($45) {
            __THREW__ = 0;
            $48 = (invoke_ii(3267,($37|0))|0);
            $49 = __THREW__; __THREW__ = 0;
            $50 = $49&1;
            if ($50) {
             label = 24;
             break;
            }
            if (!($48)) {
             label = 21;
            }
           } else {
            label = 21;
           }
           if ((label|0) == 21) {
            label = 0;
            __THREW__ = 0;
            (invoke_ii(3262,($37|0))|0);
            $51 = __THREW__; __THREW__ = 0;
            $52 = $51&1;
            if ($52) {
             label = 24;
             break;
            }
           }
           $65 = HEAP8[$lockPath>>0]|0;
           $66 = $65 & 1;
           $67 = ($66<<24>>24)==(0);
           if (!($67)) {
            $68 = HEAP32[$35>>2]|0;
            __ZdlPv($68);
           }
           $69 = (($38) + 4|0);
           $70 = HEAP32[$69>>2]|0;
           $71 = ($70|0)==(0|0);
           if ($71) {
            $$01$i$i$i = $38;
            while(1) {
             $74 = (($$01$i$i$i) + 8|0);
             $75 = HEAP32[$74>>2]|0;
             $76 = HEAP32[$75>>2]|0;
             $77 = ($76|0)==($$01$i$i$i|0);
             if ($77) {
              $$0$i$i$i = $75;
              break;
             } else {
              $$01$i$i$i = $75;
             }
            }
           } else {
            $$0$i$i$i$i = $70;
            while(1) {
             $72 = HEAP32[$$0$i$i$i$i>>2]|0;
             $73 = ($72|0)==(0|0);
             if ($73) {
              $$0$i$i$i = $$0$i$i$i$i;
              break;
             } else {
              $$0$i$i$i$i = $72;
             }
            }
           }
           $78 = ($$0$i$i$i|0)==($25|0);
           if ($78) {
            break L17;
           } else {
            $38 = $$0$i$i$i;
           }
          }
          if ((label|0) == 22) {
           $53 = ___cxa_find_matching_catch()|0;
           $54 = tempRet0;
           $55 = HEAP8[$1>>0]|0;
           $56 = $55 & 1;
           $57 = ($56<<24>>24)==(0);
           if ($57) {
            $$0 = $54;$$01 = $53;
            break L15;
           }
           $58 = HEAP32[$36>>2]|0;
           __ZdlPv($58);
           $$0 = $54;$$01 = $53;
           break L15;
          }
          else if ((label|0) == 24) {
           $59 = ___cxa_find_matching_catch()|0;
           $60 = tempRet0;
           $61 = HEAP8[$lockPath>>0]|0;
           $62 = $61 & 1;
           $63 = ($62<<24>>24)==(0);
           if ($63) {
            $$0 = $60;$$01 = $59;
            break L15;
           }
           $64 = HEAP32[$35>>2]|0;
           __ZdlPv($64);
           $$0 = $60;$$01 = $59;
           break L15;
          }
         }
        }
       } while(0);
       $79 = HEAP32[$23>>2]|0;
       __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($tempFolders,$79);
       break L13;
      }
     } while(0);
     $85 = HEAP32[$23>>2]|0;
     __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($tempFolders,$85);
     $$1 = $$0;$$12 = $$01;
     break L11;
    }
   } while(0);
   $80 = HEAP8[$path>>0]|0;
   $81 = $80 & 1;
   $82 = ($81<<24>>24)==(0);
   if ($82) {
    STACKTOP = sp;return;
   }
   $83 = (($path) + 8|0);
   $84 = HEAP32[$83>>2]|0;
   __ZdlPv($84);
   STACKTOP = sp;return;
  }
 } while(0);
 $86 = HEAP8[$path>>0]|0;
 $87 = $86 & 1;
 $88 = ($87<<24>>24)==(0);
 if ($88) {
  $$2 = $$1;$$23 = $$12;
  ___resumeException($$23|0);
  // unreachable;
 }
 $89 = (($path) + 8|0);
 $90 = HEAP32[$89>>2]|0;
 __ZdlPv($90);
 $$2 = $$1;$$23 = $$12;
 ___resumeException($$23|0);
 // unreachable;
}
function __ZN14CachingManager5ResetEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $defaultCacheName = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $defaultCacheName = sp + 12|0;
 $0 = sp;
 __ZN14CachingManager7DisposeEv($this);
 HEAP32[$this>>2] = 0;
 HEAP8[$defaultCacheName>>0] = 12;
 $1 = (($defaultCacheName) + 1|0);
 ;HEAP8[$1+0>>0]=HEAP8[617912+0>>0]|0;HEAP8[$1+1>>0]=HEAP8[617912+1>>0]|0;HEAP8[$1+2>>0]=HEAP8[617912+2>>0]|0;HEAP8[$1+3>>0]=HEAP8[617912+3>>0]|0;HEAP8[$1+4>>0]=HEAP8[617912+4>>0]|0;HEAP8[$1+5>>0]=HEAP8[617912+5>>0]|0;
 $2 = (($defaultCacheName) + 7|0);
 HEAP8[$2>>0] = 0;
 __THREW__ = 0;
 $3 = (invoke_ii(3257,($defaultCacheName|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   label = 6;
  } else {
   do {
    if (!($3)) {
     HEAP8[$0>>0] = 12;
     $6 = (($0) + 1|0);
     ;HEAP8[$6+0>>0]=HEAP8[617912+0>>0]|0;HEAP8[$6+1>>0]=HEAP8[617912+1>>0]|0;HEAP8[$6+2>>0]=HEAP8[617912+2>>0]|0;HEAP8[$6+3>>0]=HEAP8[617912+3>>0]|0;HEAP8[$6+4>>0]=HEAP8[617912+4>>0]|0;HEAP8[$6+5>>0]=HEAP8[617912+5>>0]|0;
     $7 = (($0) + 7|0);
     HEAP8[$7>>0] = 0;
     __THREW__ = 0;
     (invoke_iii(2233,($defaultCacheName|0),($0|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      $17 = ___cxa_find_matching_catch()|0;
      $18 = tempRet0;
      $19 = HEAP8[$0>>0]|0;
      $20 = $19 & 1;
      $21 = ($20<<24>>24)==(0);
      if ($21) {
       $$0 = $18;$$01 = $17;
       break L1;
      }
      $22 = (($0) + 8|0);
      $23 = HEAP32[$22>>2]|0;
      __ZdlPv($23);
      $$0 = $18;$$01 = $17;
      break L1;
     } else {
      $10 = HEAP8[$0>>0]|0;
      $11 = $10 & 1;
      $12 = ($11<<24>>24)==(0);
      if ($12) {
       break;
      }
      $13 = (($0) + 8|0);
      $14 = HEAP32[$13>>2]|0;
      __ZdlPv($14);
      break;
     }
    }
   } while(0);
   HEAP32[$this>>2] = 1;
   __THREW__ = 0;
   invoke_viiiii(101,($this|0),($defaultCacheName|0),-1,2147483647,0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 6;
   } else {
    __THREW__ = 0;
    invoke_vi(3520,0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     label = 6;
    } else {
     $28 = (($this) + 8|0);
     HEAP8[$28>>0] = 1;
     $29 = HEAP8[$defaultCacheName>>0]|0;
     $30 = $29 & 1;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      STACKTOP = sp;return;
     }
     $32 = (($defaultCacheName) + 8|0);
     $33 = HEAP32[$32>>2]|0;
     __ZdlPv($33);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $$0 = $16;$$01 = $15;
 }
 $34 = HEAP8[$defaultCacheName>>0]|0;
 $35 = $34 & 1;
 $36 = ($35<<24>>24)==(0);
 if ($36) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $37 = (($defaultCacheName) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 __ZdlPv($38);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN14CachingManager7DisposeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[617952>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__Znwj(4)|0);
  HEAP32[$2>>2] = 0;
  HEAP32[617952>>2] = $2;
  $3 = $2;
 } else {
  $3 = $0;
 }
 __ZN20GlobalCachingManager7DisposeEv($3);
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($5) + 52|0);
 HEAP8[$7>>0] = 1;
 $8 = (($5) + 68|0);
 $9 = (($5) + 72|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($8,$10);
 $11 = (($5) + 56|0);
 $12 = (($5) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNSt3__16__treeIN5Cache10CachedFileENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($11,$13);
 $14 = (($5) + 4|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if (!($17)) {
  $18 = (($5) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  __ZdlPv($19);
 }
 __ZdlPv($5);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14CachingManager15SetCurrentCacheERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEExb($this,$name,$0,$1,$includePlayerURL) {
 $this = $this|0;
 $name = $name|0;
 $0 = $0|0;
 $1 = $1|0;
 $includePlayerURL = $includePlayerURL|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $2 = sp;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($4) + 52|0);
  HEAP8[$6>>0] = 1;
  $7 = (($4) + 68|0);
  $8 = (($4) + 72|0);
  $9 = HEAP32[$8>>2]|0;
  __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($7,$9);
  $10 = (($4) + 56|0);
  $11 = (($4) + 60|0);
  $12 = HEAP32[$11>>2]|0;
  __ZNSt3__16__treeIN5Cache10CachedFileENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($10,$12);
  $13 = (($4) + 4|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   $17 = (($4) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   __ZdlPv($18);
  }
  __ZdlPv($4);
 }
 $19 = (__Znwj(80)|0);
 $20 = (($19) + 4|0);
 ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
 $21 = (($19) + 60|0);
 HEAP32[$21>>2] = 0;
 $22 = (($19) + 64|0);
 HEAP32[$22>>2] = 0;
 $23 = (($19) + 56|0);
 HEAP32[$23>>2] = $21;
 $24 = (($19) + 72|0);
 HEAP32[$24>>2] = 0;
 $25 = (($19) + 76|0);
 HEAP32[$25>>2] = 0;
 $26 = (($19) + 68|0);
 HEAP32[$26>>2] = $24;
 $27 = (($19) + 24|0);
 $28 = $27;
 $29 = $28;
 HEAP32[$29>>2] = 0;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = 0;
 $32 = (($19) + 16|0);
 HEAP32[$32>>2] = 2147483647;
 $33 = (($19) + 52|0);
 HEAP8[$33>>0] = 0;
 HEAP8[$19>>0] = 1;
 $34 = (($19) + 48|0);
 HEAP32[$34>>2] = 12960000;
 HEAP32[$3>>2] = $19;
 __Z21GetCachingManagerPathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEb($2,$name,0);
 __THREW__ = 0;
 $35 = (invoke_ii(3257,($2|0))|0);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $46 = HEAP8[$2>>0]|0;
  $47 = $46 & 1;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   ___resumeException($44|0);
   // unreachable;
  }
  $49 = (($2) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  __ZdlPv($50);
  ___resumeException($44|0);
  // unreachable;
 }
 $38 = HEAP8[$2>>0]|0;
 $39 = $38 & 1;
 $40 = ($39<<24>>24)==(0);
 if (!($40)) {
  $41 = (($2) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  __ZdlPv($42);
 }
 if (!($35)) {
  $51 = HEAP32[$3>>2]|0;
  $52 = (($51) + 32|0);
  $53 = $52;
  $54 = $53;
  HEAP32[$54>>2] = $0;
  $55 = (($53) + 4)|0;
  $56 = $55;
  HEAP32[$56>>2] = $1;
  $57 = (($51) + 40|0);
  $58 = $57;
  $59 = $58;
  HEAP32[$59>>2] = $0;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = $1;
  $62 = $includePlayerURL&1;
  HEAP8[$51>>0] = $62;
  (__ZN5Cache14ReadCacheIndexERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEb($51,$name,0)|0);
  STACKTOP = sp;return;
 }
 $43 = HEAP32[$3>>2]|0;
 __ZN5Cache18WriteCacheInfoFileEb($43,1);
 $51 = HEAP32[$3>>2]|0;
 $52 = (($51) + 32|0);
 $53 = $52;
 $54 = $53;
 HEAP32[$54>>2] = $0;
 $55 = (($53) + 4)|0;
 $56 = $55;
 HEAP32[$56>>2] = $1;
 $57 = (($51) + 40|0);
 $58 = $57;
 $59 = $58;
 HEAP32[$59>>2] = $0;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $1;
 $62 = $includePlayerURL&1;
 HEAP8[$51>>0] = $62;
 (__ZN5Cache14ReadCacheIndexERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEb($51,$name,0)|0);
 STACKTOP = sp;return;
}
function __ZN20GlobalCachingManager7DisposeEv($this) {
 $this = $this|0;
 var $$lcssa12 = 0, $$lcssa311 = 0, $$lcssa410 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = (($0) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $$lcssa12 = $0;$$lcssa311 = $3;$$lcssa410 = $2;
  label = 9;
 } else {
  $34 = $0;$7 = $2;
  while(1) {
   $6 = HEAP32[$7>>2]|0;
   $8 = ($6|0)==(0|0);
   if ($8) {
    $24 = $34;
   } else {
    $9 = (($6) + 52|0);
    HEAP8[$9>>0] = 1;
    $10 = (($6) + 68|0);
    $11 = (($6) + 72|0);
    $12 = HEAP32[$11>>2]|0;
    __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($10,$12);
    $13 = (($6) + 56|0);
    $14 = (($6) + 60|0);
    $15 = HEAP32[$14>>2]|0;
    __ZNSt3__16__treeIN5Cache10CachedFileENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($13,$15);
    $16 = (($6) + 4|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = $17 & 1;
    $19 = ($18<<24>>24)==(0);
    if (!($19)) {
     $20 = (($6) + 12|0);
     $21 = HEAP32[$20>>2]|0;
     __ZdlPv($21);
    }
    __ZdlPv($6);
    $$pre = HEAP32[$this>>2]|0;
    $24 = $$pre;
   }
   $22 = (($7) + 4|0);
   $23 = (($24) + 4|0);
   $25 = HEAP32[$23>>2]|0;
   $26 = ($22|0)==($25|0);
   if ($26) {
    break;
   } else {
    $34 = $24;$7 = $22;
   }
  }
  $27 = ($24|0)==(0|0);
  if (!($27)) {
   $$lcssa12 = $24;$$lcssa311 = $23;$$lcssa410 = $22;
   label = 9;
  }
 }
 if ((label|0) == 9) {
  $28 = HEAP32[$$lcssa12>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = ($$lcssa410|0)==($28|0);
   if (!($30)) {
    $__new_last2$i$i$i$i$i = $28;
    $scevgep$i$i$i$i$i = (($$lcssa410) + -4|0);
    $31 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($31)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $32 = $uglygep3$i$i$i$i$i >>> 2;
    $33 = $32 ^ -1;
    $scevgep4$i$i$i$i$i = (($$lcssa410) + ($33<<2)|0);
    HEAP32[$$lcssa311>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($28);
  }
  __ZdlPv($$lcssa12);
 }
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i613 = 0, $$0$i614 = 0, $$0$i8 = 0, $$pre1$i = 0, $$pre1$i1012 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 12|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = (($this) + 8|0);
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($5) - ($17))|0;
 $19 = (($18|0) / 12)&-1;
 $20 = (($19) + ($__n))|0;
 $21 = ($20>>>0)>(357913941);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($4) - ($17))|0;
 $23 = (($22|0) / 12)&-1;
 $24 = ($23>>>0)<(178956970);
 if ($24) {
  $27 = $23 << 1;
  $28 = ($27>>>0)<($20>>>0);
  $29 = $28 ? $20 : $27;
  $30 = (($__v) + 12|0);
  HEAP32[$30>>2] = 0;
  $31 = (($__v) + 16|0);
  HEAP32[$31>>2] = $15;
  $32 = ($29|0)==(0);
  if ($32) {
   $$0$i614 = 0;$35 = 0;$40 = $30;
  } else {
   $$0$i613 = $29;$76 = $30;
   label = 10;
  }
 } else {
  $25 = (($__v) + 12|0);
  HEAP32[$25>>2] = 0;
  $26 = (($__v) + 16|0);
  HEAP32[$26>>2] = $15;
  $$0$i613 = 357913941;$76 = $25;
  label = 10;
 }
 if ((label|0) == 10) {
  $33 = ($$0$i613*12)|0;
  $34 = (__Znwj($33)|0);
  $$0$i614 = $$0$i613;$35 = $34;$40 = $76;
 }
 HEAP32[$__v>>2] = $35;
 $36 = (($35) + (($19*12)|0)|0);
 $37 = (($__v) + 8|0);
 HEAP32[$37>>2] = $36;
 $38 = (($__v) + 4|0);
 HEAP32[$38>>2] = $36;
 $39 = (($35) + (($$0$i614*12)|0)|0);
 HEAP32[$40>>2] = $39;
 $$0$i8 = $__n;$$pre1$i1012 = $36;
 while(1) {
  $41 = ($$pre1$i1012|0)==(0|0);
  if ($41) {
   $43 = 0;
  } else {
   ;HEAP32[$$pre1$i1012+0>>2]=0|0;HEAP32[$$pre1$i1012+4>>2]=0|0;HEAP32[$$pre1$i1012+8>>2]=0|0;
   $43 = $$pre1$i1012;
  }
  $42 = (($43) + 12|0);
  $44 = (($$0$i8) + -1)|0;
  $45 = ($44|0)==(0);
  if ($45) {
   break;
  } else {
   $$0$i8 = $44;$$pre1$i1012 = $42;
  }
 }
 HEAP32[$37>>2] = $42;
 __THREW__ = 0;
 invoke_vii(2524,($this|0),($__v|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $61 = ___cxa_find_matching_catch()|0;
  $62 = tempRet0;
  $63 = HEAP32[$38>>2]|0;
  $64 = HEAP32[$37>>2]|0;
  $65 = ($64|0)==($63|0);
  if (!($65)) {
   $67 = $64;
   while(1) {
    $66 = (($67) + -12|0);
    HEAP32[$37>>2] = $66;
    $68 = HEAP8[$66>>0]|0;
    $69 = $68 & 1;
    $70 = ($69<<24>>24)==(0);
    if (!($70)) {
     $72 = (($67) + -4|0);
     $73 = HEAP32[$72>>2]|0;
     __ZdlPv($73);
    }
    $71 = ($66|0)==($63|0);
    if ($71) {
     break;
    } else {
     $67 = $66;
    }
   }
  }
  $74 = HEAP32[$__v>>2]|0;
  $75 = ($74|0)==(0|0);
  if ($75) {
   ___resumeException($61|0);
   // unreachable;
  }
  __ZdlPv($74);
  ___resumeException($61|0);
  // unreachable;
 } else {
  $48 = HEAP32[$38>>2]|0;
  $49 = HEAP32[$37>>2]|0;
  $50 = ($49|0)==($48|0);
  if (!($50)) {
   $52 = $49;
   while(1) {
    $51 = (($52) + -12|0);
    HEAP32[$37>>2] = $51;
    $53 = HEAP8[$51>>0]|0;
    $54 = $53 & 1;
    $55 = ($54<<24>>24)==(0);
    if (!($55)) {
     $57 = (($52) + -4|0);
     $58 = HEAP32[$57>>2]|0;
     __ZdlPv($58);
    }
    $56 = ($51|0)==($48|0);
    if ($56) {
     break;
    } else {
     $52 = $51;
    }
   }
  }
  $59 = HEAP32[$__v>>2]|0;
  $60 = ($59|0)==(0|0);
  if ($60) {
   STACKTOP = sp;return;
  }
  __ZdlPv($59);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE15__insert_uniqueERKS6_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (__ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEESG_RKT_($this,$__parent,$__v)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $44 = 0;$__r$0 = $1;
  HEAP32[$agg$result>>2] = $__r$0;
  $43 = (($agg$result) + 4|0);
  HEAP8[$43>>0] = $44;
  STACKTOP = sp;return;
 }
 $3 = (__Znwj(28)|0);
 $4 = (($3) + 16|0);
 $5 = HEAP8[$__v>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 L4: do {
  if ($7) {
   ;HEAP32[$4+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__v+8>>2]|0;
  } else {
   $8 = (($__v) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($__v) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11>>>0)>(4294967279);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    } else {
     $15 = ($11>>>0)<(11);
     if ($15) {
      $16 = $11 << 1;
      $17 = $16&255;
      HEAP8[$4>>0] = $17;
      $18 = (($3) + 17|0);
      $__p$0$i$i$i$i$i = $18;
     } else {
      $19 = (($11) + 16)|0;
      $20 = $19 & -16;
      __THREW__ = 0;
      $21 = (invoke_ii(2988,($20|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      $24 = (($3) + 24|0);
      HEAP32[$24>>2] = $21;
      $25 = $20 | 1;
      HEAP32[$4>>2] = $25;
      $26 = (($3) + 20|0);
      HEAP32[$26>>2] = $11;
      $__p$0$i$i$i$i$i = $21;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($9|0),($11|0))|0;
     $27 = (($__p$0$i$i$i$i$i) + ($11)|0);
     HEAP8[$27>>0] = 0;
     break L4;
    }
   } while(0);
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = ($3|0)==(0|0);
   if ($30) {
    ___resumeException($28|0);
    // unreachable;
   }
   __ZdlPv($3);
   ___resumeException($28|0);
   // unreachable;
  }
 } while(0);
 $31 = HEAP32[$__parent>>2]|0;
 HEAP32[$3>>2] = 0;
 $32 = (($3) + 4|0);
 HEAP32[$32>>2] = 0;
 $33 = (($3) + 8|0);
 HEAP32[$33>>2] = $31;
 HEAP32[$0>>2] = $3;
 $34 = HEAP32[$this>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  $39 = $3;
 } else {
  HEAP32[$this>>2] = $35;
  $$pre$i = HEAP32[$0>>2]|0;
  $39 = $$pre$i;
 }
 $37 = (($this) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($38,$39);
 $40 = (($this) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 $44 = 1;$__r$0 = $3;
 HEAP32[$agg$result>>2] = $__r$0;
 $43 = (($agg$result) + 4|0);
 HEAP8[$43>>0] = $44;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEESG_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i = 0, $$$$i$i$i5 = 0, $$$i$i$i = 0, $$$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $60 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $60;
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 $__nd$0$in = $1;
 while(1) {
  $11 = (($__nd$0$in) + 16|0);
  if ($5) {
   $26 = $7;
  } else {
   $12 = HEAP32[$10>>2]|0;
   $26 = $12;
  }
  $13 = HEAP8[$11>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $25 = $19;
  } else {
   $16 = (($__nd$0$in) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $25 = $17;
  }
  if ($5) {
   $28 = $8;
  } else {
   $20 = HEAP32[$9>>2]|0;
   $28 = $20;
  }
  if ($15) {
   $23 = (($11) + 1|0);
   $29 = $23;
  } else {
   $21 = (($__nd$0$in) + 24|0);
   $22 = HEAP32[$21>>2]|0;
   $29 = $22;
  }
  $24 = ($25>>>0)<($26>>>0);
  $27 = $24 ? $25 : $26;
  $30 = (_memcmp($28,$29,$27)|0);
  $31 = ($30|0)==(0);
  if ($31) {
   $32 = ($26>>>0)<($25>>>0);
   $$$i$i$i4 = $24&1;
   $$$$i$i$i5 = $32 ? -1 : $$$i$i$i4;
   $34 = $$$$i$i$i5;
  } else {
   $34 = $30;
  }
  $33 = ($34|0)<(0);
  if ($33) {
   $35 = HEAP32[$__nd$0$in>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 17;
    break;
   } else {
    $__nd$0$in = $35;
    continue;
   }
  }
  if ($15) {
   $39 = $13&255;
   $40 = $39 >>> 1;
   $48 = $40;
  } else {
   $37 = (($__nd$0$in) + 20|0);
   $38 = HEAP32[$37>>2]|0;
   $48 = $38;
  }
  if ($5) {
   $47 = $7;
  } else {
   $41 = HEAP32[$10>>2]|0;
   $47 = $41;
  }
  if ($15) {
   $44 = (($11) + 1|0);
   $50 = $44;
  } else {
   $42 = (($__nd$0$in) + 24|0);
   $43 = HEAP32[$42>>2]|0;
   $50 = $43;
  }
  if ($5) {
   $51 = $8;
  } else {
   $45 = HEAP32[$9>>2]|0;
   $51 = $45;
  }
  $46 = ($47>>>0)<($48>>>0);
  $49 = $46 ? $47 : $48;
  $52 = (_memcmp($50,$51,$49)|0);
  $53 = ($52|0)==(0);
  if ($53) {
   $54 = ($48>>>0)<($47>>>0);
   $$$i$i$i = $46&1;
   $$$$i$i$i = $54 ? -1 : $$$i$i$i;
   $56 = $$$$i$i$i;
  } else {
   $56 = $52;
  }
  $55 = ($56|0)<(0);
  if (!($55)) {
   label = 33;
   break;
  }
  $57 = (($__nd$0$in) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   label = 32;
   break;
  } else {
   $__nd$0$in = $58;
  }
 }
 if ((label|0) == 17) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $57;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE4findIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i = 0, $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE13__lower_boundIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SG_SG_($__p,$this,$__v,$1,$2);
 $3 = HEAP32[$__p>>2]|0;
 $4 = ($3|0)==($2|0);
 if (!($4)) {
  $5 = (($3) + 16|0);
  $6 = HEAP8[$__v>>0]|0;
  $7 = $6 & 1;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $11 = $6&255;
   $12 = $11 >>> 1;
   $28 = $12;
  } else {
   $9 = (($__v) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $28 = $10;
  }
  $13 = HEAP8[$5>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $27 = $19;
  } else {
   $16 = (($3) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $27 = $17;
  }
  if ($8) {
   $22 = (($__v) + 1|0);
   $30 = $22;
  } else {
   $20 = (($__v) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $30 = $21;
  }
  if ($15) {
   $25 = (($5) + 1|0);
   $31 = $25;
  } else {
   $23 = (($3) + 24|0);
   $24 = HEAP32[$23>>2]|0;
   $31 = $24;
  }
  $26 = ($27>>>0)<($28>>>0);
  $29 = $26 ? $27 : $28;
  $32 = (_memcmp($30,$31,$29)|0);
  $33 = ($32|0)==(0);
  if ($33) {
   $34 = ($28>>>0)<($27>>>0);
   $$$i$i$i = $26&1;
   $$$$i$i$i = $34 ? -1 : $$$i$i$i;
   $36 = $$$$i$i$i;
  } else {
   $36 = $32;
  }
  $35 = ($36|0)<(0);
  if (!($35)) {
   HEAP32[$agg$result>>2] = $3;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE13__lower_boundIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SG_SG_($agg$result,$this,$__v,$__root,$__result) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 $__root = $__root|0;
 $__result = $__result|0;
 var $$$$i$i$i = 0, $$$$i$i$i$us = 0, $$$i$i$i = 0, $$$i$i$i$us = 0, $$0$ph6 = 0, $$0$ph9 = 0, $$01$lcssa2 = 0, $$01$ph8 = 0, $$013 = 0, $$013$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__root|0)==(0|0);
 if ($0) {
  $$0$ph6 = $__result;
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
 $1 = HEAP8[$__v>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 $4 = $1&255;
 $5 = $4 >>> 1;
 $6 = (($__v) + 1|0);
 $7 = (($__v) + 8|0);
 $8 = (($__v) + 4|0);
 $$0$ph9 = $__result;$$01$ph8 = $__root;
 L4: while(1) {
  L6: do {
   if ($3) {
    $$013$us = $$01$ph8;
    while(1) {
     $9 = (($$013$us) + 16|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 & 1;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $17 = $10&255;
      $18 = $17 >>> 1;
      $19 = (($9) + 1|0);
      $21 = $18;$23 = $19;
     } else {
      $13 = (($$013$us) + 20|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($$013$us) + 24|0);
      $16 = HEAP32[$15>>2]|0;
      $21 = $14;$23 = $16;
     }
     $20 = ($5>>>0)<($21>>>0);
     $22 = $20 ? $5 : $21;
     $24 = (_memcmp($23,$6,$22)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = ($21>>>0)<($5>>>0);
      $$$i$i$i$us = $20&1;
      $$$$i$i$i$us = $26 ? -1 : $$$i$i$i$us;
      $28 = $$$$i$i$i$us;
     } else {
      $28 = $24;
     }
     $27 = ($28|0)<(0);
     if (!($27)) {
      $$01$lcssa2 = $$013$us;
      break L6;
     }
     $29 = (($$013$us) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013$us = $30;
     }
    }
   } else {
    $$013 = $$01$ph8;
    while(1) {
     $32 = (($$013) + 16|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if ($35) {
      $40 = $33&255;
      $41 = $40 >>> 1;
      $42 = (($32) + 1|0);
      $46 = $41;$48 = $42;
     } else {
      $36 = (($$013) + 20|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($$013) + 24|0);
      $39 = HEAP32[$38>>2]|0;
      $46 = $37;$48 = $39;
     }
     $43 = HEAP32[$8>>2]|0;
     $44 = HEAP32[$7>>2]|0;
     $45 = ($43>>>0)<($46>>>0);
     $47 = $45 ? $43 : $46;
     $49 = (_memcmp($48,$44,$47)|0);
     $50 = ($49|0)==(0);
     if ($50) {
      $51 = ($46>>>0)<($43>>>0);
      $$$i$i$i = $45&1;
      $$$$i$i$i = $51 ? -1 : $$$i$i$i;
      $53 = $$$$i$i$i;
     } else {
      $53 = $49;
     }
     $52 = ($53|0)<(0);
     if (!($52)) {
      $$01$lcssa2 = $$013;
      break L6;
     }
     $56 = (($$013) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013 = $57;
     }
    }
   }
  } while(0);
  $54 = HEAP32[$$01$lcssa2>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$0$ph6 = $$01$lcssa2;
   label = 19;
   break;
  } else {
   $$0$ph9 = $$01$lcssa2;$$01$ph8 = $54;
  }
 }
 if ((label|0) == 19) {
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIN5Cache10CachedFileENS_4lessIS2_EENS_9allocatorIS2_EEE14__insert_multiERKS2_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $13 = (($this) + 4|0);
  $$0$i = $13;$46 = $13;
 } else {
  $3 = (($__v) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $__nd$0$in$i = $1;
  while(1) {
   $5 = (($__nd$0$in$i) + 36|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4|0)<($6|0);
   if ($7) {
    $8 = HEAP32[$__nd$0$in$i>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $$0$i = $__nd$0$in$i;$46 = $__nd$0$in$i;
     break;
    } else {
     $__nd$0$in$i = $8;
     continue;
    }
   } else {
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i = $10;$46 = $__nd$0$in$i;
     break;
    } else {
     $__nd$0$in$i = $11;
     continue;
    }
   }
  }
 }
 $14 = (__Znwj(40)|0);
 $15 = (($14) + 16|0);
 $16 = HEAP8[$__v>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 L10: do {
  if ($18) {
   ;HEAP32[$15+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$__v+8>>2]|0;
  } else {
   $19 = (($__v) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($__v) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22>>>0)>(4294967279);
   do {
    if ($23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      // unreachable;
     }
    } else {
     $26 = ($22>>>0)<(11);
     if ($26) {
      $27 = $22 << 1;
      $28 = $27&255;
      HEAP8[$15>>0] = $28;
      $29 = (($14) + 17|0);
      $__p$0$i$i$i$i$i$i$i = $29;
     } else {
      $30 = (($22) + 16)|0;
      $31 = $30 & -16;
      __THREW__ = 0;
      $32 = (invoke_ii(2988,($31|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = (($14) + 24|0);
      HEAP32[$35>>2] = $32;
      $36 = $31 | 1;
      HEAP32[$15>>2] = $36;
      $37 = (($14) + 20|0);
      HEAP32[$37>>2] = $22;
      $__p$0$i$i$i$i$i$i$i = $32;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($20|0),($22|0))|0;
     $38 = (($__p$0$i$i$i$i$i$i$i) + ($22)|0);
     HEAP8[$38>>0] = 0;
     break L10;
    }
   } while(0);
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   $41 = ($14|0)==(0|0);
   if ($41) {
    ___resumeException($39|0);
    // unreachable;
   }
   __ZdlPv($14);
   ___resumeException($39|0);
   // unreachable;
  }
 } while(0);
 $42 = (($14) + 28|0);
 $43 = (($__v) + 12|0);
 ;HEAP32[$42+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$43+8>>2]|0;
 HEAP32[$14>>2] = 0;
 $44 = (($14) + 4|0);
 HEAP32[$44>>2] = 0;
 $45 = (($14) + 8|0);
 HEAP32[$45>>2] = $46;
 HEAP32[$$0$i>>2] = $14;
 $47 = HEAP32[$this>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  $51 = $14;
  $50 = HEAP32[$0>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($50,$51);
  $52 = (($this) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 1)|0;
  HEAP32[$52>>2] = $54;
  HEAP32[$agg$result>>2] = $14;
  STACKTOP = sp;return;
 }
 HEAP32[$this>>2] = $48;
 $$pre$i = HEAP32[$$0$i>>2]|0;
 $51 = $$pre$i;
 $50 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($50,$51);
 $52 = (($this) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$52>>2] = $54;
 HEAP32[$agg$result>>2] = $14;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeIN5Cache10CachedFileENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeIN5Cache10CachedFileENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeIN5Cache10CachedFileENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($__nd) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEC2ERKS8_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$01$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($__x) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$__x>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($3|0)==($4|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8>>>0)>(357913941);
 do {
  if ($10) {
   __THREW__ = 0;
   invoke_vi(3308,0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 20;
   } else {
    // unreachable;
   }
  } else {
   __THREW__ = 0;
   $13 = (invoke_ii(2988,($7|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 20;
   } else {
    HEAP32[$0>>2] = $13;
    HEAP32[$this>>2] = $13;
    $16 = (($13) + (($8*12)|0)|0);
    HEAP32[$1>>2] = $16;
    $17 = HEAP32[$__x>>2]|0;
    $18 = HEAP32[$2>>2]|0;
    $19 = ($17|0)==($18|0);
    if ($19) {
     STACKTOP = sp;return;
    } else {
     $$01$i = $17;$21 = $13;
    }
    L11: while(1) {
     $20 = ($21|0)==(0|0);
     do {
      if (!($20)) {
       $22 = HEAP8[$$01$i>>0]|0;
       $23 = $22 & 1;
       $24 = ($23<<24>>24)==(0);
       if ($24) {
        ;HEAP32[$21+0>>2]=HEAP32[$$01$i+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$$01$i+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$$01$i+8>>2]|0;
        break;
       }
       $25 = (($$01$i) + 8|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = (($$01$i) + 4|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = ($28>>>0)>(4294967279);
       if ($29) {
        label = 11;
        break L11;
       }
       $32 = ($28>>>0)<(11);
       if ($32) {
        $33 = $28 << 1;
        $34 = $33&255;
        HEAP8[$21>>0] = $34;
        $35 = (($21) + 1|0);
        $__p$0$i$i$i$i$i = $35;
       } else {
        $36 = (($28) + 16)|0;
        $37 = $36 & -16;
        __THREW__ = 0;
        $38 = (invoke_ii(2988,($37|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 19;
         break L11;
        }
        $41 = (($21) + 8|0);
        HEAP32[$41>>2] = $38;
        $42 = $37 | 1;
        HEAP32[$21>>2] = $42;
        $43 = (($21) + 4|0);
        HEAP32[$43>>2] = $28;
        $__p$0$i$i$i$i$i = $38;
       }
       _memcpy(($__p$0$i$i$i$i$i|0),($26|0),($28|0))|0;
       $44 = (($__p$0$i$i$i$i$i) + ($28)|0);
       HEAP8[$44>>0] = 0;
      }
     } while(0);
     $45 = HEAP32[$0>>2]|0;
     $46 = (($45) + 12|0);
     HEAP32[$0>>2] = $46;
     $47 = (($$01$i) + 12|0);
     $48 = ($47|0)==($18|0);
     if ($48) {
      label = 28;
      break;
     } else {
      $$01$i = $47;$21 = $46;
     }
    }
    if ((label|0) == 11) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 20;
      break;
     }
     // unreachable;
    }
    else if ((label|0) == 19) {
     $49 = ___cxa_find_matching_catch()|0;
     $50 = tempRet0;
     $lpad$phi$index = $49;$lpad$phi$index2 = $50;
     break;
    }
    else if ((label|0) == 28) {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $lpad$phi$index = $51;$lpad$phi$index2 = $52;
 }
 $53 = HEAP32[$this>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $55 = HEAP32[$0>>2]|0;
 $56 = ($55|0)==($53|0);
 if ($56) {
  $66 = $53;
 } else {
  $58 = $55;
  while(1) {
   $57 = (($58) + -12|0);
   HEAP32[$0>>2] = $57;
   $59 = HEAP8[$57>>0]|0;
   $60 = $59 & 1;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    $63 = $57;
   } else {
    $64 = (($58) + -4|0);
    $65 = HEAP32[$64>>2]|0;
    __ZdlPv($65);
    $$pre$i$i$i = HEAP32[$0>>2]|0;
    $63 = $$pre$i$i$i;
   }
   $62 = ($63|0)==($53|0);
   if ($62) {
    break;
   } else {
    $58 = $63;
   }
  }
  $$pre$i = HEAP32[$this>>2]|0;
  $66 = $$pre$i;
 }
 __ZdlPv($66);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($__nd) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __Z21WriteImageAsyncThreadPv($data) {
 $data = $data|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($data) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN5Image13ReformatImageEii13TextureFormatN14ImageReference8BlitModeE($2,$4,$6,3,0);
 $7 = HEAP32[$1>>2]|0;
 $8 = (__Z21ConvertImageToPNGFileRK14ImageReferenceRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($7,$data)|0);
 if (!($8)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(617968,0,618000,231,1,0,0,0);
 }
 $9 = HEAP32[$1>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if (!($10)) {
   $11 = (($9) + 16|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[628224>>2]|0;
   HEAP32[$0>>2] = $13;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($12|0),($$byval_copy|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    __ZdlPv($9);
    ___resumeException($22|0);
    // unreachable;
   } else {
    __ZdlPv($9);
    break;
   }
  }
 } while(0);
 $16 = ($data|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return (0|0);
 }
 $17 = HEAP8[$data>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if (!($19)) {
  $20 = (($data) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  __ZdlPv($21);
 }
 __ZdlPv($data);
 STACKTOP = sp;return (0|0);
}
function __Z23UpdateCaptureScreenshotv() {
 var $$0$i = 0, $$01$i = 0, $$02$i = 0, $$1$i = 0, $$13$i = 0, $$2$i = 0, $$24$i = 0, $$byval_copy38 = 0, $$in$i$i = 0, $$in$i37$i = 0, $$lcssa$i$i = 0, $$lcssa17$i$i = 0, $$lcssa19$i$i = 0, $$ph$i = 0, $$ph66$i = 0, $$ph67$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0;
 var $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i3$i$i = 0, $camRect$i$i = 0, $camit$01$i$i = 0, $camit$01$i32$i = 0, $data$sroa$1$i$i = 0, $dstData$02$us$i$i = 0, $eh$lpad$body$i$index17Z2D = 0;
 var $eh$lpad$body$i$indexZ2D = 0, $exitcond$i$i = 0, $exitcond6$i$i = 0, $it$02$i$i = 0, $lpad$phi$i$i$index = 0, $lpad$phi$i$i$index2 = 0, $lpad$phi69$i$index = 0, $lpad$phi69$i$index7 = 0, $objects$i$i = 0, $proj$i$i = 0, $savedMaxAniso$i = 0, $savedMinAniso$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i4$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i8$i$i = 0, $screenImage$i = 0, $srcData$03$us$i$i = 0, $temp$0$i3$i$i = 0, $temp$0$i4$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i6$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i7$i$i = 0, $x$01$us$i$i = 0, $x$056$i = 0, $y$04$us$i$i = 0, $y$057$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $$byval_copy38 = sp + 208|0;
 $0 = sp + 204|0;
 $1 = sp + 200|0;
 $2 = sp + 196|0;
 $3 = sp + 192|0;
 $4 = sp + 188|0;
 $5 = sp + 184|0;
 $camRect$i$i = sp + 168|0;
 $proj$i$i = sp + 104|0;
 $6 = sp + 96|0;
 $7 = sp + 92|0;
 $8 = sp + 88|0;
 $9 = sp + 84|0;
 $objects$i$i = sp + 32|0;
 $10 = sp + 28|0;
 $11 = sp + 16|0;
 $12 = sp + 20|0;
 $13 = sp + 24|0;
 $data$sroa$1$i$i = sp;
 $14 = sp + 44|0;
 $15 = sp + 48|0;
 $16 = sp + 52|0;
 $screenImage$i = sp + 56|0;
 $savedMinAniso$i = sp + 76|0;
 $savedMaxAniso$i = sp + 80|0;
 $17 = (0|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = (__Z12GetGfxDevicev()|0);
 $19 = (__Z16GetRenderManagerv()|0);
 $20 = (($19) + 56|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($19) + 60|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($19) + 64|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($19) + 68|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (~~(($25)));
 $29 = (~~(($27)));
 $30 = (0)>(1);
 $31 = (__Znwj(20)|0);
 L4: do {
  if ($30) {
   $32 = 0;
   $33 = 0;
   __THREW__ = 0;
   invoke_viiii(365,($31|0),($32|0),($33|0),4);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $37 = ___cxa_find_matching_catch()|0;
    $38 = tempRet0;
    __ZdlPv($31);
    $$2$i = $37;$$24$i = $38;
    ___resumeException($$2$i|0);
    // unreachable;
   }
   $36 = ($31|0)==(0|0);
   if ($36) {
    $$0$i = 0;
   } else {
    __ZN5ImageC2Eii13TextureFormat($screenImage$i,$28,$29,4);
    HEAP32[$13>>2] = 61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$13+0>>2]|0;
    invoke_vii(2591,(0|0),($$byval_copy38|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    L11: do {
     if ($40) {
      $$ph66$i = 0;$$ph67$i = 0;
      label = 94;
     } else {
      $41 = (($19) + 4|0);
      $42 = (($19) + 8|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = ($43|0)==($41|0);
      L13: do {
       if ($44) {
        $219 = 0;$233 = 0;$482 = 0;
       } else {
        $46 = $43;$89 = 0;$91 = 0;$99 = 0;
        L15: while(1) {
         $45 = (($46) + 8|0);
         $47 = HEAP32[$45>>2]|0;
         $48 = ($47|0)==(0);
         do {
          if ($48) {
           $522 = $91;$523 = $89;$524 = $99;
          } else {
           HEAP32[$10>>2] = $47;
           $49 = HEAP32[560624>>2]|0;
           $50 = ($49|0)==(0|0);
           if ($50) {
            label = 18;
           } else {
            $51 = (($49) + 36|0);
            $52 = HEAP32[$51>>2]|0;
            $53 = (($49) + 4|0);
            $54 = HEAP32[$53>>2]|0;
            $55 = ($52|0)==($54|0);
            do {
             if ($55) {
              $56 = (($49) + 28|0);
              $57 = HEAP32[$56>>2]|0;
              $58 = (($49) + 32|0);
              $59 = HEAP32[$58>>2]|0;
              $60 = (($57) + ($59<<3)|0);
              $76 = $60;
             } else {
              __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy38,$49,$10);
              $61 = HEAP32[$$byval_copy38>>2]|0;
              $62 = ($61|0)==(-1);
              $63 = (($49) + 28|0);
              $64 = HEAP32[$63>>2]|0;
              if ($62) {
               $65 = (($49) + 32|0);
               $66 = HEAP32[$65>>2]|0;
               $67 = (($64) + ($66<<3)|0);
               $76 = $67;
               break;
              } else {
               $68 = (($64) + ($61<<3)|0);
               $76 = $68;
               break;
              }
             }
            } while(0);
            $69 = HEAP32[560624>>2]|0;
            $70 = (($69) + 28|0);
            $71 = HEAP32[$70>>2]|0;
            $72 = (($69) + 32|0);
            $73 = HEAP32[$72>>2]|0;
            $74 = (($71) + ($73<<3)|0);
            $75 = ($76|0)==($74|0);
            if ($75) {
             label = 18;
            } else {
             $77 = (($76) + 4|0);
             $78 = HEAP32[$77>>2]|0;
             $79 = ($78|0)==(0|0);
             if ($79) {
              label = 18;
             } else {
              $temp$0$i3$i$i = $78;
             }
            }
           }
           if ((label|0) == 18) {
            label = 0;
            $80 = HEAP32[$45>>2]|0;
            __THREW__ = 0;
            $81 = (invoke_ii(3215,($80|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if ($83) {
             $$ph$i = $91;
             break L15;
            }
            $84 = ($81|0)==(0|0);
            if ($84) {
             $522 = $91;$523 = $89;$524 = $99;
             break;
            } else {
             $temp$0$i3$i$i = $81;
            }
           }
           $85 = (($temp$0$i3$i$i) + 4|0);
           $86 = HEAP32[$85>>2]|0;
           $87 = (($temp$0$i3$i$i) + 396|0);
           ;HEAP32[$data$sroa$1$i$i+0>>2]=HEAP32[$87+0>>2]|0;HEAP32[$data$sroa$1$i$i+4>>2]=HEAP32[$87+4>>2]|0;HEAP32[$data$sroa$1$i$i+8>>2]=HEAP32[$87+8>>2]|0;HEAP32[$data$sroa$1$i$i+12>>2]=HEAP32[$87+12>>2]|0;
           $88 = (($89) + 1)|0;
           $90 = $91 & 2147483647;
           $92 = ($88>>>0)>($90>>>0);
           do {
            if ($92) {
             $93 = $91 << 1;
             $94 = ($93|0)==(0);
             $95 = $94 ? 1 : $93;
             $96 = ($90>>>0)<($95>>>0);
             if ($96) {
              $97 = ($91|0)>(-1);
              if ($97) {
               $98 = ($95*20)|0;
               HEAP32[$11>>2] = 61;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$11+0>>2]|0;
               $100 = (invoke_iiiiiiii(108,($99|0),($98|0),4,($$byval_copy38|0),0,(618000|0),370)|0);
               $101 = __THREW__; __THREW__ = 0;
               $102 = $101&1;
               if ($102) {
                $$ph$i = $95;
                break L15;
               }
               $109 = $100;$525 = $95;
               break;
              } else {
               $103 = ($95*20)|0;
               HEAP32[$12>>2] = 61;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$12+0>>2]|0;
               $104 = (invoke_iiiiiii(102,($103|0),4,($$byval_copy38|0),0,(618000|0),352)|0);
               $105 = __THREW__; __THREW__ = 0;
               $106 = $105&1;
               if ($106) {
                $$ph$i = $91;
                break L15;
               }
               $107 = ($88*20)|0;
               _memcpy(($104|0),($99|0),($107|0))|0;
               $109 = $104;$525 = $95;
               break;
              }
             } else {
              $109 = $99;$525 = $91;
             }
            } else {
             $109 = $99;$525 = $91;
            }
           } while(0);
           $108 = (($109) + (($89*20)|0)|0);
           HEAP32[$108>>2] = $86;
           $110 = ((($109) + (($89*20)|0)|0) + 4|0);
           ;HEAP32[$110+0>>2]=HEAP32[$data$sroa$1$i$i+0>>2]|0;HEAP32[$110+4>>2]=HEAP32[$data$sroa$1$i$i+4>>2]|0;HEAP32[$110+8>>2]=HEAP32[$data$sroa$1$i$i+8>>2]|0;HEAP32[$110+12>>2]=HEAP32[$data$sroa$1$i$i+12>>2]|0;
           $522 = $525;$523 = $88;$524 = $109;
          }
         } while(0);
         $111 = (($46) + 4|0);
         $112 = HEAP32[$111>>2]|0;
         $113 = ($112|0)==($41|0);
         if ($113) {
          $219 = $523;$233 = $524;$482 = $522;
          break L13;
         } else {
          $46 = $112;$89 = $523;$91 = $522;$99 = $524;
         }
        }
        $322 = ___cxa_find_matching_catch()|0;
        $323 = tempRet0;
        $535 = $$ph$i;$536 = $99;$lpad$phi69$i$index = $322;$lpad$phi69$i$index7 = $323;
        label = 95;
        break L11;
       }
      } while(0);
      $114 = (Math_fround(0));
      $115 = (Math_fround(+(_log2f((+$114)))));
      $116 = Math_fround(Math_fround(-1.0) - $115);
      HEAP32[$objects$i$i>>2] = 0;
      $117 = (($objects$i$i) + 4|0);
      HEAP32[$117>>2] = 0;
      $118 = (($objects$i$i) + 8|0);
      HEAP32[$118>>2] = 0;
      __THREW__ = 0;
      (invoke_iiii(1530,27,($objects$i$i|0),0)|0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      L45: do {
       if ($120) {
        $526 = 0;$527 = 0;
        label = 53;
       } else {
        HEAP32[$9>>2] = 61;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$9+0>>2]|0;
        invoke_vii(2591,(0|0),($$byval_copy38|0));
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if ($122) {
         $526 = 0;$527 = 0;
         label = 53;
        } else {
         $123 = HEAP32[$117>>2]|0;
         $124 = HEAP32[$objects$i$i>>2]|0;
         $125 = $123;
         $126 = $124;
         $127 = (($125) - ($126))|0;
         $128 = $127 >> 2;
         $129 = ($128|0)==(0);
         if ($129) {
          $528 = 0;$529 = 0;
         } else {
          $130 = $127 << 1;
          HEAP32[$8>>2] = 61;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$8+0>>2]|0;
          $131 = (invoke_iiiiiiii(108,(0|0),($130|0),4,($$byval_copy38|0),0,(618000|0),370)|0);
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           $526 = $128;$527 = 0;
           label = 53;
           break;
          }
          $528 = $128;$529 = $131;
         }
         __THREW__ = 0;
         invoke_vii(2764,($savedMinAniso$i|0),($savedMaxAniso$i|0));
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          $526 = $528;$527 = $529;
          label = 53;
         } else {
          __THREW__ = 0;
          invoke_vii(2765,16,16);
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           $526 = $528;$527 = $529;
           label = 53;
          } else {
           $138 = HEAP32[$117>>2]|0;
           $139 = HEAP32[$objects$i$i>>2]|0;
           $140 = $139;
           $141 = ($138|0)==($139|0);
           L54: do {
            if ($141) {
             $$lcssa$i$i = $138;$$lcssa17$i$i = $138;$$lcssa19$i$i = $140;$375 = 0;$377 = $529;$478 = $528;
            } else {
             $143 = $139;$144 = 0;$153 = $528;$161 = $529;
             L56: while(1) {
              $142 = (($143) + ($144<<2)|0);
              $145 = HEAP32[$142>>2]|0;
              $146 = ($145|0)==(0|0);
              if ($146) {
               $172 = 0;
              } else {
               $147 = (($145) + 4|0);
               $148 = HEAP32[$147>>2]|0;
               $172 = $148;
              }
              $149 = (($145) + 36|0);
              $150 = Math_fround(HEAPF32[$149>>2]);
              $151 = (($144) + 1)|0;
              $152 = $153 & 2147483647;
              $154 = ($151>>>0)>($152>>>0);
              do {
               if ($154) {
                $155 = $153 << 1;
                $156 = ($155|0)==(0);
                $157 = $156 ? 1 : $155;
                $158 = ($152>>>0)<($157>>>0);
                if (!($158)) {
                 $171 = $161;$530 = $153;
                 break;
                }
                $159 = ($153|0)>(-1);
                if ($159) {
                 $160 = $157 << 3;
                 HEAP32[$6>>2] = 61;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$6+0>>2]|0;
                 $162 = (invoke_iiiiiiii(108,($161|0),($160|0),4,($$byval_copy38|0),0,(618000|0),370)|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  $531 = $157;$532 = $161;
                  break L56;
                 }
                 $171 = $162;$530 = $157;
                 break;
                } else {
                 $165 = $157 << 3;
                 HEAP32[$7>>2] = 61;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$7+0>>2]|0;
                 $166 = (invoke_iiiiiii(102,($165|0),4,($$byval_copy38|0),0,(618000|0),352)|0);
                 $167 = __THREW__; __THREW__ = 0;
                 $168 = $167&1;
                 if ($168) {
                  $531 = $153;$532 = $161;
                  break L56;
                 }
                 $169 = $151 << 3;
                 _memcpy(($166|0),($161|0),($169|0))|0;
                 $171 = $166;$530 = $157;
                 break;
                }
               } else {
                $171 = $161;$530 = $153;
               }
              } while(0);
              $170 = (($171) + ($144<<3)|0);
              HEAP32[$170>>2] = $172;
              $173 = ((($171) + ($144<<3)|0) + 4|0);
              HEAPF32[$173>>2] = $150;
              $174 = HEAP32[$145>>2]|0;
              $175 = (($174) + 124|0);
              $176 = HEAP32[$175>>2]|0;
              __THREW__ = 0;
              $177 = (invoke_ii($176|0,($145|0))|0);
              $178 = __THREW__; __THREW__ = 0;
              $179 = $178&1;
              if ($179) {
               $531 = $530;$532 = $171;
               break;
              }
              do {
               if ($177) {
                $180 = HEAP32[$145>>2]|0;
                $181 = (($180) + 92|0);
                $182 = HEAP32[$181>>2]|0;
                __THREW__ = 0;
                $183 = (invoke_ii($182|0,($145|0))|0);
                $184 = __THREW__; __THREW__ = 0;
                $185 = $184&1;
                if ($185) {
                 $531 = $530;$532 = $171;
                 break L56;
                }
                $186 = ($183|0)==(2);
                if (!($186)) {
                 break;
                }
                $187 = Math_fround(HEAPF32[$149>>2]);
                $188 = Math_fround($116 + $187);
                HEAPF32[$149>>2] = $188;
               }
              } while(0);
              $200 = HEAP32[$145>>2]|0;
              $201 = (($200) + 132|0);
              $202 = HEAP32[$201>>2]|0;
              __THREW__ = 0;
              invoke_vi($202|0,($145|0));
              $203 = __THREW__; __THREW__ = 0;
              $204 = $203&1;
              if ($204) {
               $531 = $530;$532 = $171;
               break;
              }
              $205 = HEAP32[$117>>2]|0;
              $206 = HEAP32[$objects$i$i>>2]|0;
              $207 = $205;
              $208 = $206;
              $209 = (($207) - ($208))|0;
              $210 = $209 >> 2;
              $211 = ($151>>>0)<($210>>>0);
              if ($211) {
               $143 = $206;$144 = $151;$153 = $530;$161 = $171;
              } else {
               $$lcssa$i$i = $205;$$lcssa17$i$i = $206;$$lcssa19$i$i = $208;$375 = $151;$377 = $171;$478 = $530;
               break L54;
              }
             }
             $189 = ___cxa_find_matching_catch()|0;
             $190 = tempRet0;
             $533 = $531;$534 = $532;$lpad$phi$i$i$index = $189;$lpad$phi$i$i$index2 = $190;
             label = 54;
             break L45;
            }
           } while(0);
           $212 = ($$lcssa17$i$i|0)==(0|0);
           if (!($212)) {
            $213 = ($$lcssa$i$i|0)==($$lcssa17$i$i|0);
            if (!($213)) {
             $scevgep$i$i$i$i$i$i$i = (($$lcssa$i$i) + -4|0);
             $214 = (0 - ($$lcssa19$i$i))|0;
             $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($214)|0);
             $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
             $215 = $uglygep3$i$i$i$i$i$i$i >>> 2;
             $216 = $215 ^ -1;
             $scevgep4$i$i$i$i$i$i$i = (($$lcssa$i$i) + ($216<<2)|0);
             HEAP32[$117>>2] = $scevgep4$i$i$i$i$i$i$i;
            }
            __ZdlPv($$lcssa17$i$i);
           }
           $217 = (0)>(0);
           L85: do {
            if ($217) {
             $218 = ($219|0)==(0);
             $220 = (~~(($21)));
             $221 = (~~(($23)));
             $222 = (($screenImage$i) + 16|0);
             $223 = (($screenImage$i) + 4|0);
             $224 = (($screenImage$i) + 8|0);
             $225 = (($31) + 16|0);
             $226 = (($camRect$i$i) + 8|0);
             $227 = (($camRect$i$i) + 12|0);
             $228 = (($proj$i$i) + 32|0);
             $229 = (($proj$i$i) + 36|0);
             $230 = (($proj$i$i) + 48|0);
             $231 = (($proj$i$i) + 52|0);
             $232 = (($233) + (($219*20)|0)|0);
             $y$057$i = 0;
             L87: while(1) {
              $234 = (Math_fround(($y$057$i|0)));
              $235 = Math_fround($234 / $114);
              $236 = Math_fround($235 + Math_fround(-0.5));
              $x$056$i = 0;
              while(1) {
               if (!($218)) {
                $237 = (Math_fround(($x$056$i|0)));
                $238 = Math_fround($237 / $114);
                $239 = Math_fround($238 + Math_fround(-0.5));
                $camit$01$i$i = $233;
                while(1) {
                 $240 = HEAP32[$camit$01$i$i>>2]|0;
                 $241 = ($240|0)==(0);
                 do {
                  if (!($241)) {
                   HEAP32[$5>>2] = $240;
                   $242 = HEAP32[560624>>2]|0;
                   $243 = ($242|0)==(0|0);
                   do {
                    if ($243) {
                     label = 78;
                    } else {
                     $244 = (($242) + 36|0);
                     $245 = HEAP32[$244>>2]|0;
                     $246 = (($242) + 4|0);
                     $247 = HEAP32[$246>>2]|0;
                     $248 = ($245|0)==($247|0);
                     do {
                      if ($248) {
                       $249 = (($242) + 28|0);
                       $250 = HEAP32[$249>>2]|0;
                       $251 = (($242) + 32|0);
                       $252 = HEAP32[$251>>2]|0;
                       $253 = (($250) + ($252<<3)|0);
                       $269 = $253;
                      } else {
                       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy38,$242,$5);
                       $254 = HEAP32[$$byval_copy38>>2]|0;
                       $255 = ($254|0)==(-1);
                       $256 = (($242) + 28|0);
                       $257 = HEAP32[$256>>2]|0;
                       if ($255) {
                        $258 = (($242) + 32|0);
                        $259 = HEAP32[$258>>2]|0;
                        $260 = (($257) + ($259<<3)|0);
                        $269 = $260;
                        break;
                       } else {
                        $261 = (($257) + ($254<<3)|0);
                        $269 = $261;
                        break;
                       }
                      }
                     } while(0);
                     $262 = HEAP32[560624>>2]|0;
                     $263 = (($262) + 28|0);
                     $264 = HEAP32[$263>>2]|0;
                     $265 = (($262) + 32|0);
                     $266 = HEAP32[$265>>2]|0;
                     $267 = (($264) + ($266<<3)|0);
                     $268 = ($269|0)==($267|0);
                     if ($268) {
                      label = 78;
                      break;
                     }
                     $270 = (($269) + 4|0);
                     $271 = HEAP32[$270>>2]|0;
                     $272 = ($271|0)==(0|0);
                     if ($272) {
                      label = 78;
                     } else {
                      $$in$i$i = $271;
                     }
                    }
                   } while(0);
                   if ((label|0) == 78) {
                    label = 0;
                    $273 = HEAP32[$camit$01$i$i>>2]|0;
                    __THREW__ = 0;
                    $274 = (invoke_ii(3215,($273|0))|0);
                    $275 = __THREW__; __THREW__ = 0;
                    $276 = $275&1;
                    if ($276) {
                     label = 98;
                     break L87;
                    }
                    $277 = ($274|0)==(0|0);
                    if ($277) {
                     break;
                    } else {
                     $$in$i$i = $274;
                    }
                   }
                   $278 = (($$in$i$i) + 613|0);
                   HEAP8[$278>>0] = 1;
                   $279 = (($$in$i$i) + 609|0);
                   HEAP8[$279>>0] = 1;
                   $280 = (($$in$i$i) + 610|0);
                   HEAP8[$280>>0] = 1;
                   $281 = (($$in$i$i) + 614|0);
                   HEAP8[$281>>0] = 1;
                   $282 = (($$in$i$i) + 611|0);
                   HEAP8[$282>>0] = 1;
                   __THREW__ = 0;
                   invoke_viii(1656,($camRect$i$i|0),($$in$i$i|0),1);
                   $283 = __THREW__; __THREW__ = 0;
                   $284 = $283&1;
                   if ($284) {
                    label = 98;
                    break L87;
                   }
                   $285 = Math_fround(HEAPF32[$226>>2]);
                   $286 = Math_fround($285 * Math_fround(0.5));
                   $287 = Math_fround($239 / $286);
                   $288 = Math_fround(HEAPF32[$227>>2]);
                   $289 = Math_fround($288 * Math_fround(0.5));
                   $290 = Math_fround($236 / $289);
                   __THREW__ = 0;
                   $291 = (invoke_ii(3268,($$in$i$i|0))|0);
                   $292 = __THREW__; __THREW__ = 0;
                   $293 = $292&1;
                   if ($293) {
                    label = 98;
                    break L87;
                   }
                   dest=$proj$i$i+0|0; src=$291+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
                   $294 = (($$in$i$i) + 616|0);
                   $295 = HEAP8[$294>>0]|0;
                   $296 = ($295<<24>>24)==(0);
                   if ($296) {
                    $301 = Math_fround(HEAPF32[$228>>2]);
                    $302 = Math_fround($287 + $301);
                    HEAPF32[$228>>2] = $302;
                    $303 = Math_fround(HEAPF32[$229>>2]);
                    $304 = Math_fround($290 + $303);
                    HEAPF32[$229>>2] = $304;
                   } else {
                    $297 = Math_fround(HEAPF32[$230>>2]);
                    $298 = Math_fround($297 - $287);
                    HEAPF32[$230>>2] = $298;
                    $299 = Math_fround(HEAPF32[$231>>2]);
                    $300 = Math_fround($299 - $290);
                    HEAPF32[$231>>2] = $300;
                   }
                   __THREW__ = 0;
                   invoke_vii(2766,($$in$i$i|0),($proj$i$i|0));
                   $305 = __THREW__; __THREW__ = 0;
                   $306 = $305&1;
                   if ($306) {
                    label = 98;
                    break L87;
                   }
                  }
                 } while(0);
                 $307 = (($camit$01$i$i) + 20|0);
                 $308 = ($307|0)==($232|0);
                 if ($308) {
                  break;
                 } else {
                  $camit$01$i$i = $307;
                 }
                }
               }
               __THREW__ = 0;
               invoke_vii(2767,($19|0),0);
               $309 = __THREW__; __THREW__ = 0;
               $310 = $309&1;
               if ($310) {
                label = 99;
                break L87;
               }
               __THREW__ = 0;
               $311 = (invoke_i(75)|0);
               $312 = __THREW__; __THREW__ = 0;
               $313 = $312&1;
               if ($313) {
                label = 99;
                break L87;
               }
               __THREW__ = 0;
               invoke_vi(3413,($311|0));
               $314 = __THREW__; __THREW__ = 0;
               $315 = $314&1;
               if ($315) {
                label = 99;
                break L87;
               }
               $316 = HEAP32[579440>>2]|0;
               $317 = ($316|0)==(0|0);
               if (!($317)) {
                __THREW__ = 0;
                invoke_v(149);
                $318 = __THREW__; __THREW__ = 0;
                $319 = $318&1;
                if ($319) {
                 label = 99;
                 break L87;
                }
               }
               $341 = HEAP32[$18>>2]|0;
               $342 = (($341) + 596|0);
               $343 = HEAP32[$342>>2]|0;
               $344 = HEAP32[$222>>2]|0;
               __THREW__ = 0;
               (invoke_iiiiiii($343|0,($18|0),($220|0),($221|0),($28|0),($29|0),($344|0))|0);
               $345 = __THREW__; __THREW__ = 0;
               $346 = $345&1;
               if ($346) {
                label = 99;
                break L87;
               }
               $347 = HEAP32[$223>>2]|0;
               $348 = HEAP32[$224>>2]|0;
               $349 = 0;
               $350 = ($348|0)>(0);
               do {
                if ($350) {
                 $351 = ($347|0)>(0);
                 $352 = 0;
                 if (!($351)) {
                  break;
                 }
                 $353 = HEAP32[$225>>2]|0;
                 $354 = Math_imul($349, $y$057$i)|0;
                 $355 = HEAP32[$222>>2]|0;
                 $356 = (($354) + ($x$056$i))|0;
                 $357 = (($353) + ($356<<2)|0);
                 $dstData$02$us$i$i = $357;$srcData$03$us$i$i = $355;$y$04$us$i$i = 0;
                 while(1) {
                  $x$01$us$i$i = 0;
                  while(1) {
                   $361 = (($srcData$03$us$i$i) + ($x$01$us$i$i<<2)|0);
                   $362 = HEAP32[$361>>2]|0;
                   $363 = 0;
                   $364 = (($dstData$02$us$i$i) + ($363<<2)|0);
                   HEAP32[$364>>2] = $362;
                   $365 = (($x$01$us$i$i) + 1)|0;
                   $exitcond$i$i = ($365|0)==($347|0);
                   if ($exitcond$i$i) {
                    break;
                   } else {
                    $x$01$us$i$i = $365;
                   }
                  }
                  $358 = (($dstData$02$us$i$i) + ($352<<2)|0);
                  $359 = (($srcData$03$us$i$i) + ($347<<2)|0);
                  $360 = (($y$04$us$i$i) + 1)|0;
                  $exitcond6$i$i = ($360|0)==($348|0);
                  if ($exitcond6$i$i) {
                   break;
                  } else {
                   $dstData$02$us$i$i = $358;$srcData$03$us$i$i = $359;$y$04$us$i$i = $360;
                  }
                 }
                }
               } while(0);
               $366 = (($x$056$i) + 1)|0;
               $367 = ($366|0)<(0);
               if ($367) {
                $x$056$i = $366;
               } else {
                break;
               }
              }
              $368 = (($y$057$i) + 1)|0;
              $369 = ($368|0)<(0);
              if ($369) {
               $y$057$i = $368;
              } else {
               break L85;
              }
             }
             if ((label|0) == 98) {
              $330 = ___cxa_find_matching_catch()|0;
              $331 = tempRet0;
              $337 = $478;$338 = $377;$eh$lpad$body$i$index17Z2D = $331;$eh$lpad$body$i$indexZ2D = $330;
              break L45;
             }
             else if ((label|0) == 99) {
              $332 = ___cxa_find_matching_catch()|0;
              $333 = tempRet0;
              $337 = $478;$338 = $377;$eh$lpad$body$i$index17Z2D = $333;$eh$lpad$body$i$indexZ2D = $332;
              break L45;
             }
            }
           } while(0);
           $370 = HEAP32[$savedMinAniso$i>>2]|0;
           $371 = HEAP32[$savedMaxAniso$i>>2]|0;
           __THREW__ = 0;
           invoke_vii(2765,($370|0),($371|0));
           $372 = __THREW__; __THREW__ = 0;
           $373 = $372&1;
           if ($373) {
            $334 = ___cxa_find_matching_catch()|0;
            $335 = tempRet0;
            $337 = $478;$338 = $377;$eh$lpad$body$i$index17Z2D = $335;$eh$lpad$body$i$indexZ2D = $334;
            break;
           }
           $374 = ($375|0)==(0);
           L143: do {
            if (!($374)) {
             $376 = (($377) + ($375<<3)|0);
             $it$02$i$i = $377;
             L145: while(1) {
              $378 = HEAP32[$it$02$i$i>>2]|0;
              $379 = ($378|0)==(0);
              do {
               if (!($379)) {
                HEAP32[$4>>2] = $378;
                $380 = HEAP32[560624>>2]|0;
                $381 = ($380|0)==(0|0);
                do {
                 if ($381) {
                  label = 124;
                 } else {
                  $382 = (($380) + 36|0);
                  $383 = HEAP32[$382>>2]|0;
                  $384 = (($380) + 4|0);
                  $385 = HEAP32[$384>>2]|0;
                  $386 = ($383|0)==($385|0);
                  do {
                   if ($386) {
                    $387 = (($380) + 28|0);
                    $388 = HEAP32[$387>>2]|0;
                    $389 = (($380) + 32|0);
                    $390 = HEAP32[$389>>2]|0;
                    $391 = (($388) + ($390<<3)|0);
                    $407 = $391;
                   } else {
                    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy38,$380,$4);
                    $392 = HEAP32[$$byval_copy38>>2]|0;
                    $393 = ($392|0)==(-1);
                    $394 = (($380) + 28|0);
                    $395 = HEAP32[$394>>2]|0;
                    if ($393) {
                     $396 = (($380) + 32|0);
                     $397 = HEAP32[$396>>2]|0;
                     $398 = (($395) + ($397<<3)|0);
                     $407 = $398;
                     break;
                    } else {
                     $399 = (($395) + ($392<<3)|0);
                     $407 = $399;
                     break;
                    }
                   }
                  } while(0);
                  $400 = HEAP32[560624>>2]|0;
                  $401 = (($400) + 28|0);
                  $402 = HEAP32[$401>>2]|0;
                  $403 = (($400) + 32|0);
                  $404 = HEAP32[$403>>2]|0;
                  $405 = (($402) + ($404<<3)|0);
                  $406 = ($407|0)==($405|0);
                  if ($406) {
                   label = 124;
                   break;
                  }
                  $408 = (($407) + 4|0);
                  $409 = HEAP32[$408>>2]|0;
                  $410 = ($409|0)==(0|0);
                  if ($410) {
                   label = 124;
                  } else {
                   $temp$0$i4$i$i = $409;
                  }
                 }
                } while(0);
                if ((label|0) == 124) {
                 label = 0;
                 $411 = HEAP32[$it$02$i$i>>2]|0;
                 __THREW__ = 0;
                 $412 = (invoke_ii(3215,($411|0))|0);
                 $413 = __THREW__; __THREW__ = 0;
                 $414 = $413&1;
                 if ($414) {
                  break L145;
                 }
                 $415 = ($412|0)==(0|0);
                 if ($415) {
                  break;
                 } else {
                  $temp$0$i4$i$i = $412;
                 }
                }
                $416 = (($it$02$i$i) + 4|0);
                $417 = Math_fround(HEAPF32[$416>>2]);
                $418 = (($temp$0$i4$i$i) + 28|0);
                $419 = (($418) + 8|0);
                HEAPF32[$419>>2] = $417;
                $420 = HEAP32[$temp$0$i4$i$i>>2]|0;
                $421 = (($420) + 132|0);
                $422 = HEAP32[$421>>2]|0;
                __THREW__ = 0;
                invoke_vi($422|0,($temp$0$i4$i$i|0));
                $423 = __THREW__; __THREW__ = 0;
                $424 = $423&1;
                if ($424) {
                 break L145;
                }
               }
              } while(0);
              $425 = (($it$02$i$i) + 8|0);
              $426 = ($425|0)==($376|0);
              if ($426) {
               break L143;
              } else {
               $it$02$i$i = $425;
              }
             }
             $328 = ___cxa_find_matching_catch()|0;
             $329 = tempRet0;
             $337 = $478;$338 = $377;$eh$lpad$body$i$index17Z2D = $329;$eh$lpad$body$i$indexZ2D = $328;
             break L45;
            }
           } while(0);
           $427 = ($219|0)==(0);
           L166: do {
            if (!($427)) {
             $428 = (($233) + (($219*20)|0)|0);
             $camit$01$i32$i = $233;
             L168: while(1) {
              $429 = HEAP32[$camit$01$i32$i>>2]|0;
              $430 = ($429|0)==(0);
              do {
               if (!($430)) {
                HEAP32[$3>>2] = $429;
                $431 = HEAP32[560624>>2]|0;
                $432 = ($431|0)==(0|0);
                do {
                 if ($432) {
                  label = 139;
                 } else {
                  $433 = (($431) + 36|0);
                  $434 = HEAP32[$433>>2]|0;
                  $435 = (($431) + 4|0);
                  $436 = HEAP32[$435>>2]|0;
                  $437 = ($434|0)==($436|0);
                  do {
                   if ($437) {
                    $438 = (($431) + 28|0);
                    $439 = HEAP32[$438>>2]|0;
                    $440 = (($431) + 32|0);
                    $441 = HEAP32[$440>>2]|0;
                    $442 = (($439) + ($441<<3)|0);
                    $458 = $442;
                   } else {
                    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy38,$431,$3);
                    $443 = HEAP32[$$byval_copy38>>2]|0;
                    $444 = ($443|0)==(-1);
                    $445 = (($431) + 28|0);
                    $446 = HEAP32[$445>>2]|0;
                    if ($444) {
                     $447 = (($431) + 32|0);
                     $448 = HEAP32[$447>>2]|0;
                     $449 = (($446) + ($448<<3)|0);
                     $458 = $449;
                     break;
                    } else {
                     $450 = (($446) + ($443<<3)|0);
                     $458 = $450;
                     break;
                    }
                   }
                  } while(0);
                  $451 = HEAP32[560624>>2]|0;
                  $452 = (($451) + 28|0);
                  $453 = HEAP32[$452>>2]|0;
                  $454 = (($451) + 32|0);
                  $455 = HEAP32[$454>>2]|0;
                  $456 = (($453) + ($455<<3)|0);
                  $457 = ($458|0)==($456|0);
                  if ($457) {
                   label = 139;
                   break;
                  }
                  $459 = (($458) + 4|0);
                  $460 = HEAP32[$459>>2]|0;
                  $461 = ($460|0)==(0|0);
                  if ($461) {
                   label = 139;
                  } else {
                   $$in$i37$i = $460;
                  }
                 }
                } while(0);
                if ((label|0) == 139) {
                 label = 0;
                 $462 = HEAP32[$camit$01$i32$i>>2]|0;
                 __THREW__ = 0;
                 $463 = (invoke_ii(3215,($462|0))|0);
                 $464 = __THREW__; __THREW__ = 0;
                 $465 = $464&1;
                 if ($465) {
                  break L168;
                 }
                 $466 = ($463|0)==(0|0);
                 if ($466) {
                  break;
                 } else {
                  $$in$i37$i = $463;
                 }
                }
                $467 = (($camit$01$i32$i) + 4|0);
                __THREW__ = 0;
                invoke_vii(2768,($$in$i37$i|0),($467|0));
                $468 = __THREW__; __THREW__ = 0;
                $469 = $468&1;
                if ($469) {
                 break L168;
                }
                $470 = (($$in$i37$i) + 613|0);
                HEAP8[$470>>0] = 1;
                $471 = (($$in$i37$i) + 609|0);
                HEAP8[$471>>0] = 1;
                $472 = (($$in$i37$i) + 610|0);
                HEAP8[$472>>0] = 1;
                $473 = (($$in$i37$i) + 614|0);
                HEAP8[$473>>0] = 1;
                $474 = (($$in$i37$i) + 611|0);
                HEAP8[$474>>0] = 1;
               }
              } while(0);
              $475 = (($camit$01$i32$i) + 20|0);
              $476 = ($475|0)==($428|0);
              if ($476) {
               break L166;
              } else {
               $camit$01$i32$i = $475;
              }
             }
             $326 = ___cxa_find_matching_catch()|0;
             $327 = tempRet0;
             $337 = $478;$338 = $377;$eh$lpad$body$i$index17Z2D = $327;$eh$lpad$body$i$indexZ2D = $326;
             break L45;
            }
           } while(0);
           $477 = ($478|0)>(-1);
           if ($477) {
            HEAP32[$2>>2] = 61;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$2+0>>2]|0;
            invoke_vii(2591,($377|0),($$byval_copy38|0));
            $479 = __THREW__; __THREW__ = 0;
            $480 = $479&1;
            if ($480) {
             $$ph66$i = $482;$$ph67$i = $233;
             label = 94;
             break L11;
            }
           }
           $481 = ($482|0)>(-1);
           do {
            if ($481) {
             HEAP32[$1>>2] = 61;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$1+0>>2]|0;
             invoke_vii(2591,($233|0),($$byval_copy38|0));
             $483 = __THREW__; __THREW__ = 0;
             $484 = $483&1;
             if (!($484)) {
              break;
             }
             $320 = ___cxa_find_matching_catch()|0;
             $321 = tempRet0;
             $$1$i = $320;$$13$i = $321;
             break L11;
            }
           } while(0);
           $485 = (($screenImage$i) + 16|0);
           $486 = HEAP32[$485>>2]|0;
           $487 = HEAP32[628224>>2]|0;
           HEAP32[$0>>2] = $487;
           ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$0+0>>2]|0;
           __Z19free_alloc_internalPv10MemLabelId($486,$$byval_copy38);
           $$0$i = $31;
           break L4;
          }
         }
        }
       }
      } while(0);
      if ((label|0) == 53) {
       $191 = ___cxa_find_matching_catch()|0;
       $192 = tempRet0;
       $533 = $526;$534 = $527;$lpad$phi$i$i$index = $191;$lpad$phi$i$i$index2 = $192;
       label = 54;
      }
      if ((label|0) == 54) {
       $193 = HEAP32[$objects$i$i>>2]|0;
       $194 = ($193|0)==(0|0);
       if ($194) {
        $337 = $533;$338 = $534;$eh$lpad$body$i$index17Z2D = $lpad$phi$i$i$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi$i$i$index;
       } else {
        $195 = HEAP32[$117>>2]|0;
        $196 = ($195|0)==($193|0);
        if (!($196)) {
         $__new_last2$i$i$i$i$i3$i$i = $193;
         $scevgep$i$i$i$i$i4$i$i = (($195) + -4|0);
         $197 = (0 - ($__new_last2$i$i$i$i$i3$i$i))|0;
         $uglygep$i$i$i$i$i6$i$i = (($scevgep$i$i$i$i$i4$i$i) + ($197)|0);
         $uglygep3$i$i$i$i$i7$i$i = $uglygep$i$i$i$i$i6$i$i;
         $198 = $uglygep3$i$i$i$i$i7$i$i >>> 2;
         $199 = $198 ^ -1;
         $scevgep4$i$i$i$i$i8$i$i = (($195) + ($199<<2)|0);
         HEAP32[$117>>2] = $scevgep4$i$i$i$i$i8$i$i;
        }
        __ZdlPv($193);
        $337 = $533;$338 = $534;$eh$lpad$body$i$index17Z2D = $lpad$phi$i$i$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi$i$i$index;
       }
      }
      $336 = ($337|0)>(-1);
      if ($336) {
       HEAP32[$0>>2] = 61;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($338|0),($$byval_copy38|0));
       $339 = __THREW__; __THREW__ = 0;
       $340 = $339&1;
       if ($340) {
        $517 = ___cxa_find_matching_catch(0|0)|0;
        $518 = tempRet0;
        ___clang_call_terminate($517);
        // unreachable;
       } else {
        $$01$i = $eh$lpad$body$i$indexZ2D;$$02$i = $eh$lpad$body$i$index17Z2D;$489 = $482;$490 = $233;
        label = 149;
       }
      } else {
       $$01$i = $eh$lpad$body$i$indexZ2D;$$02$i = $eh$lpad$body$i$index17Z2D;$489 = $482;$490 = $233;
       label = 149;
      }
     }
    } while(0);
    if ((label|0) == 94) {
     $324 = ___cxa_find_matching_catch()|0;
     $325 = tempRet0;
     $535 = $$ph66$i;$536 = $$ph67$i;$lpad$phi69$i$index = $324;$lpad$phi69$i$index7 = $325;
     label = 95;
    }
    if ((label|0) == 95) {
     $$01$i = $lpad$phi69$i$index;$$02$i = $lpad$phi69$i$index7;$489 = $535;$490 = $536;
     label = 149;
    }
    if ((label|0) == 149) {
     $488 = ($489|0)>(-1);
     if ($488) {
      HEAP32[$14>>2] = 61;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$14+0>>2]|0;
      invoke_vii(2591,($490|0),($$byval_copy38|0));
      $491 = __THREW__; __THREW__ = 0;
      $492 = $491&1;
      if ($492) {
       $517 = ___cxa_find_matching_catch(0|0)|0;
       $518 = tempRet0;
       ___clang_call_terminate($517);
       // unreachable;
      } else {
       $$1$i = $$01$i;$$13$i = $$02$i;
      }
     } else {
      $$1$i = $$01$i;$$13$i = $$02$i;
     }
    }
    $493 = (($screenImage$i) + 16|0);
    $494 = HEAP32[$493>>2]|0;
    $495 = HEAP32[628224>>2]|0;
    HEAP32[$15>>2] = $495;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$15+0>>2]|0;
    invoke_vii(2591,($494|0),($$byval_copy38|0));
    $496 = __THREW__; __THREW__ = 0;
    $497 = $496&1;
    if ($497) {
     $517 = ___cxa_find_matching_catch(0|0)|0;
     $518 = tempRet0;
     ___clang_call_terminate($517);
     // unreachable;
    } else {
     $$2$i = $$1$i;$$24$i = $$13$i;
     ___resumeException($$2$i|0);
     // unreachable;
    }
   }
  } else {
   __THREW__ = 0;
   invoke_viiii(365,($31|0),($28|0),($29|0),4);
   $498 = __THREW__; __THREW__ = 0;
   $499 = $498&1;
   if ($499) {
    $501 = ___cxa_find_matching_catch()|0;
    $502 = tempRet0;
    __ZdlPv($31);
    $$2$i = $501;$$24$i = $502;
    ___resumeException($$2$i|0);
    // unreachable;
   }
   $500 = ($31|0)==(0|0);
   if ($500) {
    $$0$i = 0;
   } else {
    $503 = HEAP32[$18>>2]|0;
    $504 = (($503) + 596|0);
    $505 = HEAP32[$504>>2]|0;
    $506 = (~~(($21)));
    $507 = (~~(($23)));
    $508 = (($31) + 16|0);
    $509 = HEAP32[$508>>2]|0;
    $510 = (FUNCTION_TABLE_iiiiiii[$505 & 255]($18,$506,$507,$28,$29,$509)|0);
    if ($510) {
     $$0$i = $31;
    } else {
     $511 = HEAP32[$508>>2]|0;
     $512 = HEAP32[628224>>2]|0;
     HEAP32[$16>>2] = $512;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy38+0>>2]=HEAP32[$16+0>>2]|0;
     invoke_vii(2591,($511|0),($$byval_copy38|0));
     $513 = __THREW__; __THREW__ = 0;
     $514 = $513&1;
     if (!($514)) {
      __ZdlPv($31);
      $$0$i = 0;
      break;
     }
     $515 = ___cxa_find_matching_catch()|0;
     $516 = tempRet0;
     __ZdlPv($31);
     $$2$i = $515;$$24$i = $516;
     ___resumeException($$2$i|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $519 = ($$0$i|0)==(0|0);
 if ($519) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(618008,0,618000,504,1,0,0,0);
 } else {
  $520 = (__Znwj(16)|0);
  ;HEAP32[$520+0>>2]=0|0;HEAP32[$520+4>>2]=0|0;HEAP32[$520+8>>2]=0|0;HEAP32[$520+12>>2]=0|0;
  ;HEAP32[$520+0>>2]=0|0;HEAP32[$520+4>>2]=0|0;HEAP32[$520+8>>2]=0|0;
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($520,0)|0);
  $521 = (($520) + 12|0);
  HEAP32[$521>>2] = $$0$i;
  (__Z21WriteImageAsyncThreadPv($520)|0);
 }
 _free(0);
 STACKTOP = sp;return;
}
function __ZN21ComponentRequirements16StaticInitializeEv() {
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = HEAP32[628392>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy3,0,16,618040,26)|0);
 $6 = (($5) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 8|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$5>>2] = $6;
 HEAP32[618048>>2] = $5;
 $8 = HEAP32[628392>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 $9 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy3,0,16,618040,27)|0);
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($9) + 8|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$9>>2] = $10;
 HEAP32[618056>>2] = $9;
 $12 = HEAP32[628392>>2]|0;
 HEAP32[$2>>2] = $12;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 $13 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy3,0,16,618040,28)|0);
 $14 = (($13) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = (($13) + 8|0);
 HEAP32[$15>>2] = 0;
 HEAP32[$13>>2] = $14;
 HEAP32[618064>>2] = $13;
 $16 = HEAP32[628392>>2]|0;
 HEAP32[$3>>2] = $16;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
 $17 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy3,0,16,618040,29)|0);
 $18 = (($17) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 8|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$17>>2] = $18;
 HEAP32[618072>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN21ComponentRequirements13StaticDestroyEv() {
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[618048>>2]|0;
 $2 = HEAP32[628392>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEEEENS_19__map_value_compareIiS8_S4_Lb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($1,$5);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy3);
 HEAP32[618048>>2] = 0;
 $6 = HEAP32[618056>>2]|0;
 $7 = HEAP32[628392>>2]|0;
 $8 = ($6|0)==(0|0);
 if (!($8)) {
  $9 = (($6) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEEEENS_19__map_value_compareIiS8_S4_Lb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($6,$10);
 }
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy3);
 HEAP32[618056>>2] = 0;
 $11 = HEAP32[618064>>2]|0;
 $12 = HEAP32[628392>>2]|0;
 $13 = ($11|0)==(0|0);
 if (!($13)) {
  $14 = (($11) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($11,$15);
 }
 HEAP32[$0>>2] = $12;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($11,$$byval_copy3);
 HEAP32[618064>>2] = 0;
 $16 = HEAP32[618072>>2]|0;
 $17 = HEAP32[628392>>2]|0;
 $18 = ($16|0)==(0|0);
 if ($18) {
  HEAP32[$0>>2] = $17;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($16,$$byval_copy3);
  HEAP32[618072>>2] = 0;
  STACKTOP = sp;return;
 }
 $19 = (($16) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($16,$20);
 HEAP32[$0>>2] = $17;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($16,$$byval_copy3);
 HEAP32[618072>>2] = 0;
 STACKTOP = sp;return;
}
function __Z34FindRequiredComponentsForComponenti($componentClassID) {
 $componentClassID = $componentClassID|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $componentClassID;
 __Z25InitComponentRequirementsv();
 $1 = HEAP32[618048>>2]|0;
 $2 = (__ZNSt3__13mapIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEES3_NS4_INS_4pairIKiS6_EEEEEixERS8_($1,$0)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z25InitComponentRequirementsv() {
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $__parent$i$i$i$i = 0, $components = 0, $componentsVec = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $$byval_copy = sp + 400|0;
 $0 = sp + 392|0;
 $1 = sp + 384|0;
 $2 = sp + 376|0;
 $3 = sp + 368|0;
 $4 = sp + 360|0;
 $5 = sp + 352|0;
 $6 = sp + 344|0;
 $7 = sp + 336|0;
 $8 = sp + 328|0;
 $9 = sp + 320|0;
 $10 = sp + 312|0;
 $11 = sp + 304|0;
 $12 = sp + 296|0;
 $13 = sp + 288|0;
 $14 = sp + 280|0;
 $15 = sp + 272|0;
 $16 = sp + 264|0;
 $17 = sp + 256|0;
 $18 = sp + 248|0;
 $19 = sp + 240|0;
 $20 = sp + 232|0;
 $21 = sp + 224|0;
 $22 = sp + 216|0;
 $23 = sp + 208|0;
 $24 = sp + 200|0;
 $25 = sp + 192|0;
 $26 = sp + 88|0;
 $27 = sp + 80|0;
 $28 = sp + 72|0;
 $29 = sp + 64|0;
 $30 = sp + 56|0;
 $31 = sp + 48|0;
 $32 = sp + 40|0;
 $33 = sp + 24|0;
 $34 = sp + 16|0;
 $35 = sp + 8|0;
 $36 = sp;
 $37 = sp + 32|0;
 $38 = sp + 92|0;
 $39 = sp + 96|0;
 $40 = sp + 104|0;
 $41 = sp + 112|0;
 $42 = sp + 120|0;
 $43 = sp + 128|0;
 $44 = sp + 136|0;
 $45 = sp + 144|0;
 $46 = sp + 152|0;
 $__parent$i$i$i$i = sp + 156|0;
 $47 = sp + 160|0;
 $componentsVec = sp + 164|0;
 $components = sp + 176|0;
 $48 = HEAP8[618080>>0]|0;
 $49 = ($48<<24>>24)==(0);
 if (!($49)) {
  STACKTOP = sp;return;
 }
 HEAP8[618080>>0] = 1;
 $50 = HEAP32[618048>>2]|0;
 $51 = (($50) + 4|0);
 $52 = HEAP32[$51>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEEEENS_19__map_value_compareIiS8_S4_Lb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($50,$52);
 $53 = (($50) + 8|0);
 HEAP32[$53>>2] = 0;
 $54 = (($50) + 4|0);
 HEAP32[$50>>2] = $54;
 HEAP32[$54>>2] = 0;
 $55 = HEAP32[618056>>2]|0;
 $56 = (($55) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEEEENS_19__map_value_compareIiS8_S4_Lb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($55,$57);
 $58 = (($55) + 8|0);
 HEAP32[$58>>2] = 0;
 $59 = (($55) + 4|0);
 HEAP32[$55>>2] = $59;
 HEAP32[$59>>2] = 0;
 $60 = HEAP32[618064>>2]|0;
 $61 = (($60) + 4|0);
 $62 = HEAP32[$61>>2]|0;
 __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($60,$62);
 $63 = (($60) + 8|0);
 HEAP32[$63>>2] = 0;
 $64 = (($60) + 4|0);
 HEAP32[$60>>2] = $64;
 HEAP32[$64>>2] = 0;
 HEAP32[$componentsVec>>2] = 0;
 $65 = (($componentsVec) + 4|0);
 HEAP32[$65>>2] = 0;
 $66 = (($componentsVec) + 8|0);
 HEAP32[$66>>2] = 0;
 __THREW__ = 0;
 $67 = (invoke_ii(3269,(618088|0))|0);
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 L4: do {
  if ($69) {
   label = 115;
  } else {
   __THREW__ = 0;
   invoke_viii(1628,($67|0),($componentsVec|0),1);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    label = 115;
   } else {
    $72 = HEAP32[$componentsVec>>2]|0;
    $73 = HEAP32[$65>>2]|0;
    $74 = (($components) + 4|0);
    HEAP32[$74>>2] = 0;
    $75 = (($components) + 8|0);
    HEAP32[$75>>2] = 0;
    $76 = (($components) + 4|0);
    HEAP32[$components>>2] = $76;
    $77 = ($72|0)==($73|0);
    L7: do {
     if (!($77)) {
      $78 = $72;
      while(1) {
       HEAP32[$47>>2] = $76;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$47+0>>2]|0;
       $79 = (__ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE12__find_equalIiEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIiPNS_11__tree_nodeIiS8_EEiEESB_RKT_($components,$$byval_copy,$__parent$i$i$i$i,$78)|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = ($80|0)==(0|0);
       if ($81) {
        __THREW__ = 0;
        $82 = (invoke_ii(2988,20)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         break;
        }
        $85 = (($82) + 16|0);
        $86 = HEAP32[$78>>2]|0;
        HEAP32[$85>>2] = $86;
        $87 = HEAP32[$__parent$i$i$i$i>>2]|0;
        HEAP32[$82>>2] = 0;
        $88 = (($82) + 4|0);
        HEAP32[$88>>2] = 0;
        $89 = (($82) + 8|0);
        HEAP32[$89>>2] = $87;
        HEAP32[$79>>2] = $82;
        $90 = HEAP32[$components>>2]|0;
        $91 = HEAP32[$90>>2]|0;
        $92 = ($91|0)==(0|0);
        if ($92) {
         $94 = $82;
        } else {
         HEAP32[$components>>2] = $91;
         $$pre$i$i$i$i$i = HEAP32[$79>>2]|0;
         $94 = $$pre$i$i$i$i$i;
        }
        $93 = HEAP32[$74>>2]|0;
        __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($93,$94);
        $95 = HEAP32[$75>>2]|0;
        $96 = (($95) + 1)|0;
        HEAP32[$75>>2] = $96;
       }
       $97 = (($78) + 4|0);
       $98 = ($97|0)==($73|0);
       if ($98) {
        break L7;
       } else {
        $78 = $97;
       }
      }
      $99 = ___cxa_find_matching_catch()|0;
      $100 = tempRet0;
      $101 = HEAP32[$74>>2]|0;
      __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($components,$101);
      $eh$lpad$body$index2Z2D = $100;$eh$lpad$body$indexZ2D = $99;
      label = 116;
      break L4;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vii(2769,25,4);
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    do {
     if (!($103)) {
      __THREW__ = 0;
      invoke_vii(2769,33,4);
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if (!($105)) {
       __THREW__ = 0;
       invoke_vii(2769,12,4);
       $106 = __THREW__; __THREW__ = 0;
       $107 = $106&1;
       if (!($107)) {
        __THREW__ = 0;
        invoke_vii(2769,15,4);
        $108 = __THREW__; __THREW__ = 0;
        $109 = $108&1;
        if (!($109)) {
         __THREW__ = 0;
         invoke_vii(2769,76,4);
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         if (!($111)) {
          __THREW__ = 0;
          invoke_vii(2769,198,4);
          $112 = __THREW__; __THREW__ = 0;
          $113 = $112&1;
          if (!($113)) {
           __THREW__ = 0;
           invoke_vii(2769,199,4);
           $114 = __THREW__; __THREW__ = 0;
           $115 = $114&1;
           if (!($115)) {
            __THREW__ = 0;
            invoke_vii(2769,20,4);
            $116 = __THREW__; __THREW__ = 0;
            $117 = $116&1;
            if (!($117)) {
             __THREW__ = 0;
             invoke_vii(2769,108,4);
             $118 = __THREW__; __THREW__ = 0;
             $119 = $118&1;
             if (!($119)) {
              __THREW__ = 0;
              invoke_vii(2770,33,102);
              $120 = __THREW__; __THREW__ = 0;
              $121 = $120&1;
              if (!($121)) {
               __THREW__ = 0;
               invoke_vii(2770,102,33);
               $122 = __THREW__; __THREW__ = 0;
               $123 = $122&1;
               if (!($123)) {
                __THREW__ = 0;
                invoke_vii(2769,212,4);
                $124 = __THREW__; __THREW__ = 0;
                $125 = $124&1;
                if (!($125)) {
                 __THREW__ = 0;
                 invoke_vii(2770,33,212);
                 $126 = __THREW__; __THREW__ = 0;
                 $127 = $126&1;
                 if (!($127)) {
                  __THREW__ = 0;
                  invoke_vii(2770,23,212);
                  $128 = __THREW__; __THREW__ = 0;
                  $129 = $128&1;
                  if (!($129)) {
                   __THREW__ = 0;
                   invoke_vii(2770,212,33);
                   $130 = __THREW__; __THREW__ = 0;
                   $131 = $130&1;
                   if ($131) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,212,23);
                   $132 = __THREW__; __THREW__ = 0;
                   $133 = $132&1;
                   if ($133) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,54,4);
                   $134 = __THREW__; __THREW__ = 0;
                   $135 = $134&1;
                   if ($135) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,54,50);
                   $136 = __THREW__; __THREW__ = 0;
                   $137 = $136&1;
                   if ($137) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,54,53);
                   $138 = __THREW__; __THREW__ = 0;
                   $139 = $138&1;
                   if ($139) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,54,230);
                   $140 = __THREW__; __THREW__ = 0;
                   $141 = $140&1;
                   if ($141) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,56,50);
                   $142 = __THREW__; __THREW__ = 0;
                   $143 = $142&1;
                   if ($143) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,56,53);
                   $144 = __THREW__; __THREW__ = 0;
                   $145 = $144&1;
                   if ($145) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,56,230);
                   $146 = __THREW__; __THREW__ = 0;
                   $147 = $146&1;
                   if ($147) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,57,50);
                   $148 = __THREW__; __THREW__ = 0;
                   $149 = $148&1;
                   if ($149) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,57,53);
                   $150 = __THREW__; __THREW__ = 0;
                   $151 = $150&1;
                   if ($151) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,57,230);
                   $152 = __THREW__; __THREW__ = 0;
                   $153 = $152&1;
                   if ($153) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,75,50);
                   $154 = __THREW__; __THREW__ = 0;
                   $155 = $154&1;
                   if ($155) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,75,53);
                   $156 = __THREW__; __THREW__ = 0;
                   $157 = $156&1;
                   if ($157) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,75,230);
                   $158 = __THREW__; __THREW__ = 0;
                   $159 = $158&1;
                   if ($159) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,50,4);
                   $160 = __THREW__; __THREW__ = 0;
                   $161 = $160&1;
                   if ($161) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,53,4);
                   $162 = __THREW__; __THREW__ = 0;
                   $163 = $162&1;
                   if ($163) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,230,4);
                   $164 = __THREW__; __THREW__ = 0;
                   $165 = $164&1;
                   if ($165) {
                    break;
                   }
                   HEAP32[$46>>2] = 231;
                   $166 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($45|0),($166|0),($46|0));
                   $167 = __THREW__; __THREW__ = 0;
                   $168 = $167&1;
                   if ($168) {
                    break;
                   }
                   HEAP32[$44>>2] = 232;
                   $169 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($43|0),($169|0),($44|0));
                   $170 = __THREW__; __THREW__ = 0;
                   $171 = $170&1;
                   if ($171) {
                    break;
                   }
                   HEAP32[$42>>2] = 233;
                   $172 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($41|0),($172|0),($42|0));
                   $173 = __THREW__; __THREW__ = 0;
                   $174 = $173&1;
                   if ($174) {
                    break;
                   }
                   HEAP32[$40>>2] = 234;
                   $175 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($39|0),($175|0),($40|0));
                   $176 = __THREW__; __THREW__ = 0;
                   $177 = $176&1;
                   if ($177) {
                    break;
                   }
                   HEAP32[$38>>2] = 235;
                   $178 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($37|0),($178|0),($38|0));
                   $179 = __THREW__; __THREW__ = 0;
                   $180 = $179&1;
                   if ($180) {
                    break;
                   }
                   HEAP32[$36>>2] = 247;
                   $181 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($35|0),($181|0),($36|0));
                   $182 = __THREW__; __THREW__ = 0;
                   $183 = $182&1;
                   if ($183) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,230,50);
                   $184 = __THREW__; __THREW__ = 0;
                   $185 = $184&1;
                   if ($185) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,247,50);
                   $186 = __THREW__; __THREW__ = 0;
                   $187 = $186&1;
                   if ($187) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,50,54);
                   $188 = __THREW__; __THREW__ = 0;
                   $189 = $188&1;
                   if ($189) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,50,56);
                   $190 = __THREW__; __THREW__ = 0;
                   $191 = $190&1;
                   if ($191) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,50,57);
                   $192 = __THREW__; __THREW__ = 0;
                   $193 = $192&1;
                   if ($193) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,50,75);
                   $194 = __THREW__; __THREW__ = 0;
                   $195 = $194&1;
                   if ($195) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,53,54);
                   $196 = __THREW__; __THREW__ = 0;
                   $197 = $196&1;
                   if ($197) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,53,56);
                   $198 = __THREW__; __THREW__ = 0;
                   $199 = $198&1;
                   if ($199) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,53,57);
                   $200 = __THREW__; __THREW__ = 0;
                   $201 = $200&1;
                   if ($201) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,53,75);
                   $202 = __THREW__; __THREW__ = 0;
                   $203 = $202&1;
                   if ($203) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,230,54);
                   $204 = __THREW__; __THREW__ = 0;
                   $205 = $204&1;
                   if ($205) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,230,56);
                   $206 = __THREW__; __THREW__ = 0;
                   $207 = $206&1;
                   if ($207) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,230,57);
                   $208 = __THREW__; __THREW__ = 0;
                   $209 = $208&1;
                   if ($209) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,230,75);
                   $210 = __THREW__; __THREW__ = 0;
                   $211 = $210&1;
                   if ($211) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,246,54);
                   $212 = __THREW__; __THREW__ = 0;
                   $213 = $212&1;
                   if ($213) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,246,56);
                   $214 = __THREW__; __THREW__ = 0;
                   $215 = $214&1;
                   if ($215) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,246,57);
                   $216 = __THREW__; __THREW__ = 0;
                   $217 = $216&1;
                   if ($217) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,248,54);
                   $218 = __THREW__; __THREW__ = 0;
                   $219 = $218&1;
                   if ($219) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,248,56);
                   $220 = __THREW__; __THREW__ = 0;
                   $221 = $220&1;
                   if ($221) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2770,248,248);
                   $222 = __THREW__; __THREW__ = 0;
                   $223 = $222&1;
                   if ($223) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,133,4);
                   $224 = __THREW__; __THREW__ = 0;
                   $225 = $224&1;
                   if ($225) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,82,4);
                   $226 = __THREW__; __THREW__ = 0;
                   $227 = $226&1;
                   if ($227) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,81,4);
                   $228 = __THREW__; __THREW__ = 0;
                   $229 = $228&1;
                   if ($229) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,167,4);
                   $230 = __THREW__; __THREW__ = 0;
                   $231 = $230&1;
                   if ($231) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,169,180);
                   $232 = __THREW__; __THREW__ = 0;
                   $233 = $232&1;
                   if ($233) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,168,180);
                   $234 = __THREW__; __THREW__ = 0;
                   $235 = $234&1;
                   if ($235) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,170,180);
                   $236 = __THREW__; __THREW__ = 0;
                   $237 = $236&1;
                   if ($237) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,164,180);
                   $238 = __THREW__; __THREW__ = 0;
                   $239 = $238&1;
                   if ($239) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,165,180);
                   $240 = __THREW__; __THREW__ = 0;
                   $241 = $240&1;
                   if ($241) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,166,180);
                   $242 = __THREW__; __THREW__ = 0;
                   $243 = $242&1;
                   if ($243) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,102,4);
                   $244 = __THREW__; __THREW__ = 0;
                   $245 = $244&1;
                   if ($245) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,102,23);
                   $246 = __THREW__; __THREW__ = 0;
                   $247 = $246&1;
                   if ($247) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,56,4);
                   $248 = __THREW__; __THREW__ = 0;
                   $249 = $248&1;
                   if ($249) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,57,54);
                   $250 = __THREW__; __THREW__ = 0;
                   $251 = $250&1;
                   if ($251) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,75,54);
                   $252 = __THREW__; __THREW__ = 0;
                   $253 = $252&1;
                   if ($253) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,124,20);
                   $254 = __THREW__; __THREW__ = 0;
                   $255 = $254&1;
                   if ($255) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,92,20);
                   $256 = __THREW__; __THREW__ = 0;
                   $257 = $256&1;
                   if ($257) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,122,4);
                   $258 = __THREW__; __THREW__ = 0;
                   $259 = $258&1;
                   if ($259) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,223,224);
                   $260 = __THREW__; __THREW__ = 0;
                   $261 = $260&1;
                   if ($261) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,183,4);
                   $262 = __THREW__; __THREW__ = 0;
                   $263 = $262&1;
                   if ($263) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2769,183,137);
                   $264 = __THREW__; __THREW__ = 0;
                   $265 = $264&1;
                   if ($265) {
                    break;
                   }
                   HEAP32[$34>>2] = 59;
                   $266 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($33|0),($266|0),($34|0));
                   $267 = __THREW__; __THREW__ = 0;
                   $268 = $267&1;
                   if ($268) {
                    break;
                   }
                   HEAP32[$32>>2] = 138;
                   $269 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($31|0),($269|0),($32|0));
                   $270 = __THREW__; __THREW__ = 0;
                   $271 = $270&1;
                   if ($271) {
                    break;
                   }
                   HEAP32[$30>>2] = 144;
                   $272 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($29|0),($272|0),($30|0));
                   $273 = __THREW__; __THREW__ = 0;
                   $274 = $273&1;
                   if ($274) {
                    break;
                   }
                   HEAP32[$28>>2] = 153;
                   $275 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($27|0),($275|0),($28|0));
                   $276 = __THREW__; __THREW__ = 0;
                   $277 = $276&1;
                   if ($277) {
                    break;
                   }
                   HEAP32[$26>>2] = 145;
                   $278 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($25|0),($278|0),($26|0));
                   $279 = __THREW__; __THREW__ = 0;
                   $280 = $279&1;
                   if ($280) {
                    break;
                   }
                   HEAP32[$24>>2] = 82;
                   $281 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($23|0),($281|0),($24|0));
                   $282 = __THREW__; __THREW__ = 0;
                   $283 = $282&1;
                   if ($283) {
                    break;
                   }
                   HEAP32[$22>>2] = 191;
                   $284 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($21|0),($284|0),($22|0));
                   $285 = __THREW__; __THREW__ = 0;
                   $286 = $285&1;
                   if ($286) {
                    break;
                   }
                   HEAP32[$20>>2] = 45;
                   $287 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($19|0),($287|0),($20|0));
                   $288 = __THREW__; __THREW__ = 0;
                   $289 = $288&1;
                   if ($289) {
                    break;
                   }
                   HEAP32[$18>>2] = 114;
                   $290 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($17|0),($290|0),($18|0));
                   $291 = __THREW__; __THREW__ = 0;
                   $292 = $291&1;
                   if ($292) {
                    break;
                   }
                   HEAP32[$16>>2] = 148;
                   $293 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($15|0),($293|0),($16|0));
                   $294 = __THREW__; __THREW__ = 0;
                   $295 = $294&1;
                   if ($295) {
                    break;
                   }
                   HEAP32[$14>>2] = 65;
                   $296 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($13|0),($296|0),($14|0));
                   $297 = __THREW__; __THREW__ = 0;
                   $298 = $297&1;
                   if ($298) {
                    break;
                   }
                   HEAP32[$12>>2] = 135;
                   $299 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($11|0),($299|0),($12|0));
                   $300 = __THREW__; __THREW__ = 0;
                   $301 = $300&1;
                   if ($301) {
                    break;
                   }
                   HEAP32[$10>>2] = 136;
                   $302 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($9|0),($302|0),($10|0));
                   $303 = __THREW__; __THREW__ = 0;
                   $304 = $303&1;
                   if ($304) {
                    break;
                   }
                   HEAP32[$8>>2] = 64;
                   $305 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($7|0),($305|0),($8|0));
                   $306 = __THREW__; __THREW__ = 0;
                   $307 = $306&1;
                   if ($307) {
                    break;
                   }
                   HEAP32[$6>>2] = 58;
                   $308 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($5|0),($308|0),($6|0));
                   $309 = __THREW__; __THREW__ = 0;
                   $310 = $309&1;
                   if ($310) {
                    break;
                   }
                   HEAP32[$4>>2] = 61;
                   $311 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($3|0),($311|0),($4|0));
                   $312 = __THREW__; __THREW__ = 0;
                   $313 = $312&1;
                   if ($313) {
                    break;
                   }
                   HEAP32[$2>>2] = 68;
                   $314 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($1|0),($314|0),($2|0));
                   $315 = __THREW__; __THREW__ = 0;
                   $316 = $315&1;
                   if ($316) {
                    break;
                   }
                   HEAP32[$0>>2] = 60;
                   $317 = HEAP32[618064>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(1773,($$byval_copy|0),($317|0),($0|0));
                   $318 = __THREW__; __THREW__ = 0;
                   $319 = $318&1;
                   if ($319) {
                    break;
                   }
                   $320 = HEAP32[$74>>2]|0;
                   __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($components,$320);
                   $321 = HEAP32[$componentsVec>>2]|0;
                   $322 = ($321|0)==(0|0);
                   if ($322) {
                    STACKTOP = sp;return;
                   }
                   $323 = HEAP32[$65>>2]|0;
                   $324 = ($323|0)==($321|0);
                   if (!($324)) {
                    $__new_last2$i$i$i$i$i2 = $321;
                    $scevgep$i$i$i$i$i3 = (($323) + -4|0);
                    $325 = (0 - ($__new_last2$i$i$i$i$i2))|0;
                    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($325)|0);
                    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
                    $326 = $uglygep3$i$i$i$i$i6 >>> 2;
                    $327 = $326 ^ -1;
                    $scevgep4$i$i$i$i$i7 = (($323) + ($327<<2)|0);
                    HEAP32[$65>>2] = $scevgep4$i$i$i$i$i7;
                   }
                   __ZdlPv($321);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    } while(0);
    $330 = ___cxa_find_matching_catch()|0;
    $331 = tempRet0;
    $332 = HEAP32[$74>>2]|0;
    __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($components,$332);
    $$0 = $331;$$01 = $330;
   }
  }
 } while(0);
 if ((label|0) == 115) {
  $328 = ___cxa_find_matching_catch()|0;
  $329 = tempRet0;
  $eh$lpad$body$index2Z2D = $329;$eh$lpad$body$indexZ2D = $328;
  label = 116;
 }
 if ((label|0) == 116) {
  $$0 = $eh$lpad$body$index2Z2D;$$01 = $eh$lpad$body$indexZ2D;
 }
 $333 = HEAP32[$componentsVec>>2]|0;
 $334 = ($333|0)==(0|0);
 if ($334) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $335 = HEAP32[$65>>2]|0;
 $336 = ($335|0)==($333|0);
 if (!($336)) {
  $__new_last2$i$i$i$i$i = $333;
  $scevgep$i$i$i$i$i = (($335) + -4|0);
  $337 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($337)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $338 = $uglygep3$i$i$i$i$i >>> 2;
  $339 = $338 ^ -1;
  $scevgep4$i$i$i$i$i = (($335) + ($339<<2)|0);
  HEAP32[$65>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($333);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZNSt3__13mapIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEES3_NS4_INS_4pairIKiS6_EEEEEixERS8_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$24 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$24 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$24 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$24 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $33 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($33|0);
 }
 $16 = (__Znwj(32)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 24|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 28|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$16>>2] = 0;
 $22 = (($16) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = (($16) + 8|0);
 HEAP32[$23>>2] = $24;
 HEAP32[$$0$i>>2] = $16;
 $25 = HEAP32[$this>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  $29 = $16;
 } else {
  HEAP32[$this>>2] = $26;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $29 = $$pre$i;
 }
 $28 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$29);
 $30 = (($this) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 1)|0;
 HEAP32[$30>>2] = $32;
 $__r$0 = $16;
 $33 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($33|0);
}
function __Z25FindConflictingComponentsi($classID) {
 $classID = $classID|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $classID;
 __Z25InitComponentRequirementsv();
 $1 = HEAP32[618056>>2]|0;
 $2 = (__ZNSt3__13mapIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEES3_NS4_INS_4pairIKiS6_EEEEEixERS8_($1,$0)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z35DoesComponentAllowMultipleInclusioni($componentClassID) {
 $componentClassID = $componentClassID|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __Z25InitComponentRequirementsv();
 $0 = HEAP32[618064>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $5 = (($$013$i$in$i$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<($componentClassID|0);
    if (!($7)) {
     break;
    }
    $10 = (($$013$i$in$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $11;
    }
   }
   $8 = HEAP32[$$013$i$in$i$i>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $8;
   }
  }
  $13 = ($$0$ph5$i$i$i|0)==($3|0);
  if (!($13)) {
   $14 = (($$0$ph5$i$i$i) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>($componentClassID|0);
   if (!($16)) {
    $18 = $$0$ph5$i$i$i;
    $17 = ($18|0)!=($3|0);
    STACKTOP = sp;return ($17|0);
   }
  }
 }
 $18 = $3;
 $17 = ($18|0)!=($3|0);
 STACKTOP = sp;return ($17|0);
}
function __Z20AddRequiredClassIMPLii($classID,$requiredClassID) {
 $classID = $classID|0;
 $requiredClassID = $requiredClassID|0;
 var $$byval_copy6 = 0, $$lcssa27 = 0, $$neg2$i$i$i$i$i = 0, $$neg2$i$i$i$i$i14 = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $__len$0$be$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i15 = 0, $__len$03$i$i$i$i$i = 0, $__len$03$i$i$i$i$i12 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $derivedClasses = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp + 36|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $derivedClasses = sp + 24|0;
 HEAP32[$4>>2] = $classID;
 HEAP32[$5>>2] = $requiredClassID;
 HEAP32[$derivedClasses>>2] = 0;
 $6 = (($derivedClasses) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($derivedClasses) + 8|0);
 HEAP32[$7>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1628,($classID|0),($derivedClasses|0),0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   label = 15;
  } else {
   $10 = HEAP32[$derivedClasses>>2]|0;
   $11 = HEAP32[$6>>2]|0;
   $12 = ($10|0)==($11|0);
   $13 = HEAP32[618048>>2]|0;
   L3: do {
    if ($12) {
     $$lcssa27 = $13;
    } else {
     $14 = $13;$15 = $10;
     while(1) {
      __THREW__ = 0;
      $16 = (invoke_iii(2419,($14|0),($15|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      $19 = HEAP32[$16>>2]|0;
      $20 = (($16) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = $21;
      $23 = $19;
      $24 = (($22) - ($23))|0;
      $25 = $24 >> 2;
      $26 = ($25|0)==(0);
      if ($26) {
       $37 = $19;
      } else {
       $27 = HEAP32[$5>>2]|0;
       $30 = $19;$__len$03$i$i$i$i$i12 = $25;
       while(1) {
        $28 = (($__len$03$i$i$i$i$i12|0) / 2)&-1;
        $29 = (($30) + ($28<<2)|0);
        $31 = HEAP32[$29>>2]|0;
        $32 = ($31|0)<($27|0);
        if ($32) {
         $$sum$i$i$i$i$i13 = (($28) + 1)|0;
         $33 = (($30) + ($$sum$i$i$i$i$i13<<2)|0);
         $$neg2$i$i$i$i$i14 = (($__len$03$i$i$i$i$i12) + -1)|0;
         $34 = (($$neg2$i$i$i$i$i14) - ($28))|0;
         $92 = $33;$__len$0$be$i$i$i$i$i15 = $34;
        } else {
         $92 = $30;$__len$0$be$i$i$i$i$i15 = $28;
        }
        $35 = ($__len$0$be$i$i$i$i$i15|0)==(0);
        if ($35) {
         $37 = $92;
         break;
        } else {
         $30 = $92;$__len$03$i$i$i$i$i12 = $__len$0$be$i$i$i$i$i15;
        }
       }
      }
      $36 = ($37|0)==($21|0);
      if ($36) {
       label = 12;
      } else {
       $38 = HEAP32[$5>>2]|0;
       $39 = HEAP32[$37>>2]|0;
       $40 = ($38|0)<($39|0);
       if ($40) {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       label = 0;
       HEAP32[$1>>2] = $37;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_viiii(377,($0|0),($16|0),($$byval_copy6|0),($5|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
      }
      $43 = (($15) + 4|0);
      $44 = HEAP32[$6>>2]|0;
      $45 = ($43|0)==($44|0);
      $46 = HEAP32[618048>>2]|0;
      if ($45) {
       $$lcssa27 = $46;
       break L3;
      } else {
       $14 = $46;$15 = $43;
      }
     }
     $47 = ___cxa_find_matching_catch()|0;
     $48 = tempRet0;
     $lpad$phi$index = $47;$lpad$phi$index2 = $48;
     break L1;
    }
   } while(0);
   __THREW__ = 0;
   $58 = (invoke_iii(2419,($$lcssa27|0),($4|0))|0);
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    label = 15;
   } else {
    $61 = HEAP32[$58>>2]|0;
    $62 = (($58) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = $63;
    $65 = $61;
    $66 = (($64) - ($65))|0;
    $67 = $66 >> 2;
    $68 = ($67|0)==(0);
    if ($68) {
     $79 = $61;
    } else {
     $69 = HEAP32[$5>>2]|0;
     $72 = $61;$__len$03$i$i$i$i$i = $67;
     while(1) {
      $70 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
      $71 = (($72) + ($70<<2)|0);
      $73 = HEAP32[$71>>2]|0;
      $74 = ($73|0)<($69|0);
      if ($74) {
       $$sum$i$i$i$i$i = (($70) + 1)|0;
       $75 = (($72) + ($$sum$i$i$i$i$i<<2)|0);
       $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
       $76 = (($$neg2$i$i$i$i$i) - ($70))|0;
       $93 = $75;$__len$0$be$i$i$i$i$i = $76;
      } else {
       $93 = $72;$__len$0$be$i$i$i$i$i = $70;
      }
      $77 = ($__len$0$be$i$i$i$i$i|0)==(0);
      if ($77) {
       $79 = $93;
       break;
      } else {
       $72 = $93;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
      }
     }
    }
    $78 = ($79|0)==($63|0);
    if ($78) {
     label = 28;
    } else {
     $80 = HEAP32[$5>>2]|0;
     $81 = HEAP32[$79>>2]|0;
     $82 = ($80|0)<($81|0);
     if ($82) {
      label = 28;
     }
    }
    if ((label|0) == 28) {
     HEAP32[$3>>2] = $79;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_viiii(377,($2|0),($58|0),($$byval_copy6|0),($5|0));
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      label = 15;
      break;
     }
    }
    $85 = HEAP32[$derivedClasses>>2]|0;
    $86 = ($85|0)==(0|0);
    if ($86) {
     STACKTOP = sp;return;
    }
    $87 = HEAP32[$6>>2]|0;
    $88 = ($87|0)==($85|0);
    if (!($88)) {
     $__new_last2$i$i$i$i$i = $85;
     $scevgep$i$i$i$i$i = (($87) + -4|0);
     $89 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($89)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $90 = $uglygep3$i$i$i$i$i >>> 2;
     $91 = $90 ^ -1;
     $scevgep4$i$i$i$i$i = (($87) + ($91<<2)|0);
     HEAP32[$6>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($85);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  $lpad$phi$index = $49;$lpad$phi$index2 = $50;
 }
 $51 = HEAP32[$derivedClasses>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $53 = HEAP32[$6>>2]|0;
 $54 = ($53|0)==($51|0);
 if (!($54)) {
  $__new_last2$i$i$i$i$i2 = $51;
  $scevgep$i$i$i$i$i3 = (($53) + -4|0);
  $55 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($55)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $56 = $uglygep3$i$i$i$i$i6 >>> 2;
  $57 = $56 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($53) + ($57<<2)|0);
  HEAP32[$6>>2] = $scevgep4$i$i$i$i$i7;
 }
 __ZdlPv($51);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z23AddConflictingClassIMPLii($classID,$otherClassID) {
 $classID = $classID|0;
 $otherClassID = $otherClassID|0;
 var $$byval_copy6 = 0, $$lcssa27 = 0, $$neg2$i$i$i$i$i = 0, $$neg2$i$i$i$i$i14 = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i15 = 0, $__len$03$i$i$i$i$i = 0, $__len$03$i$i$i$i$i12 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $derivedClasses = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp + 36|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $derivedClasses = sp + 24|0;
 HEAP32[$4>>2] = $classID;
 HEAP32[$5>>2] = $otherClassID;
 $6 = ($classID|0)==(-1);
 $7 = ($otherClassID|0)==(-1);
 $or$cond = $6 | $7;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 HEAP32[$derivedClasses>>2] = 0;
 $8 = (($derivedClasses) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($derivedClasses) + 8|0);
 HEAP32[$9>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1628,($classID|0),($derivedClasses|0),0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L4: do {
  if ($11) {
   label = 16;
  } else {
   $12 = HEAP32[$derivedClasses>>2]|0;
   $13 = HEAP32[$8>>2]|0;
   $14 = ($12|0)==($13|0);
   $15 = HEAP32[618056>>2]|0;
   L6: do {
    if ($14) {
     $$lcssa27 = $15;
    } else {
     $16 = $15;$17 = $12;
     while(1) {
      __THREW__ = 0;
      $18 = (invoke_iii(2419,($16|0),($17|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP32[$18>>2]|0;
      $22 = (($18) + 4|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = $23;
      $25 = $21;
      $26 = (($24) - ($25))|0;
      $27 = $26 >> 2;
      $28 = ($27|0)==(0);
      if ($28) {
       $39 = $21;
      } else {
       $29 = HEAP32[$5>>2]|0;
       $32 = $21;$__len$03$i$i$i$i$i12 = $27;
       while(1) {
        $30 = (($__len$03$i$i$i$i$i12|0) / 2)&-1;
        $31 = (($32) + ($30<<2)|0);
        $33 = HEAP32[$31>>2]|0;
        $34 = ($33|0)<($29|0);
        if ($34) {
         $$sum$i$i$i$i$i13 = (($30) + 1)|0;
         $35 = (($32) + ($$sum$i$i$i$i$i13<<2)|0);
         $$neg2$i$i$i$i$i14 = (($__len$03$i$i$i$i$i12) + -1)|0;
         $36 = (($$neg2$i$i$i$i$i14) - ($30))|0;
         $94 = $35;$__len$0$be$i$i$i$i$i15 = $36;
        } else {
         $94 = $32;$__len$0$be$i$i$i$i$i15 = $30;
        }
        $37 = ($__len$0$be$i$i$i$i$i15|0)==(0);
        if ($37) {
         $39 = $94;
         break;
        } else {
         $32 = $94;$__len$03$i$i$i$i$i12 = $__len$0$be$i$i$i$i$i15;
        }
       }
      }
      $38 = ($39|0)==($23|0);
      if ($38) {
       label = 13;
      } else {
       $40 = HEAP32[$5>>2]|0;
       $41 = HEAP32[$39>>2]|0;
       $42 = ($40|0)<($41|0);
       if ($42) {
        label = 13;
       }
      }
      if ((label|0) == 13) {
       label = 0;
       HEAP32[$1>>2] = $39;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_viiii(377,($0|0),($18|0),($$byval_copy6|0),($5|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
      }
      $45 = (($17) + 4|0);
      $46 = HEAP32[$8>>2]|0;
      $47 = ($45|0)==($46|0);
      $48 = HEAP32[618056>>2]|0;
      if ($47) {
       $$lcssa27 = $48;
       break L6;
      } else {
       $16 = $48;$17 = $45;
      }
     }
     $49 = ___cxa_find_matching_catch()|0;
     $50 = tempRet0;
     $lpad$phi$index = $49;$lpad$phi$index2 = $50;
     break L4;
    }
   } while(0);
   __THREW__ = 0;
   $60 = (invoke_iii(2419,($$lcssa27|0),($4|0))|0);
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    label = 16;
   } else {
    $63 = HEAP32[$60>>2]|0;
    $64 = (($60) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = $65;
    $67 = $63;
    $68 = (($66) - ($67))|0;
    $69 = $68 >> 2;
    $70 = ($69|0)==(0);
    if ($70) {
     $81 = $63;
    } else {
     $71 = HEAP32[$5>>2]|0;
     $74 = $63;$__len$03$i$i$i$i$i = $69;
     while(1) {
      $72 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
      $73 = (($74) + ($72<<2)|0);
      $75 = HEAP32[$73>>2]|0;
      $76 = ($75|0)<($71|0);
      if ($76) {
       $$sum$i$i$i$i$i = (($72) + 1)|0;
       $77 = (($74) + ($$sum$i$i$i$i$i<<2)|0);
       $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
       $78 = (($$neg2$i$i$i$i$i) - ($72))|0;
       $95 = $77;$__len$0$be$i$i$i$i$i = $78;
      } else {
       $95 = $74;$__len$0$be$i$i$i$i$i = $72;
      }
      $79 = ($__len$0$be$i$i$i$i$i|0)==(0);
      if ($79) {
       $81 = $95;
       break;
      } else {
       $74 = $95;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
      }
     }
    }
    $80 = ($81|0)==($65|0);
    if ($80) {
     label = 29;
    } else {
     $82 = HEAP32[$5>>2]|0;
     $83 = HEAP32[$81>>2]|0;
     $84 = ($82|0)<($83|0);
     if ($84) {
      label = 29;
     }
    }
    if ((label|0) == 29) {
     HEAP32[$3>>2] = $81;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_viiii(377,($2|0),($60|0),($$byval_copy6|0),($5|0));
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      label = 16;
      break;
     }
    }
    $87 = HEAP32[$derivedClasses>>2]|0;
    $88 = ($87|0)==(0|0);
    if ($88) {
     STACKTOP = sp;return;
    }
    $89 = HEAP32[$8>>2]|0;
    $90 = ($89|0)==($87|0);
    if (!($90)) {
     $__new_last2$i$i$i$i$i = $87;
     $scevgep$i$i$i$i$i = (($89) + -4|0);
     $91 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($91)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $92 = $uglygep3$i$i$i$i$i >>> 2;
     $93 = $92 ^ -1;
     $scevgep4$i$i$i$i$i = (($89) + ($93<<2)|0);
     HEAP32[$8>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($87);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $lpad$phi$index = $51;$lpad$phi$index2 = $52;
 }
 $53 = HEAP32[$derivedClasses>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $55 = HEAP32[$8>>2]|0;
 $56 = ($55|0)==($53|0);
 if (!($56)) {
  $__new_last2$i$i$i$i$i2 = $53;
  $scevgep$i$i$i$i$i3 = (($55) + -4|0);
  $57 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($57)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $58 = $uglygep3$i$i$i$i$i6 >>> 2;
  $59 = $58 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($55) + ($59<<2)|0);
  HEAP32[$8>>2] = $scevgep4$i$i$i$i$i7;
 }
 __ZdlPv($53);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE12__find_equalIiEERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIiPNS_11__tree_nodeIiS8_EEiEESB_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = (($1) + 16|0);
  $4 = HEAP32[$__v>>2]|0;
  $5 = HEAP32[$3>>2]|0;
  $6 = ($4|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($4|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($4|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($4|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($4|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEEEENS_19__map_value_compareIiS8_S4_Lb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEEEENS_19__map_value_compareIiS8_S4_Lb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEEEENS_19__map_value_compareIiS8_S4_Lb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($this,$3);
 $4 = (($__nd) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($__nd) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  if (!($9)) {
   $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $5;
   $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($8) + -4|0);
   $10 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($10)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
   $11 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
   $12 = $11 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($8) + ($12<<2)|0);
   HEAP32[$7>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($5);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZL21AddComponentUncheckedRN5Unity10GameObjectEiP14ScriptingClassP10MonoScriptPNSt3__112basic_stringIcNS6_11char_traitsIcEENS6_9allocatorIcEEEE($go,$classID,$klass,$script,$error) {
 $go = $go|0;
 $classID = $classID|0;
 $klass = $klass|0;
 $script = $script|0;
 $error = $error|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp;
 $0 = sp + 40|0;
 $1 = sp + 8|0;
 $2 = sp + 20|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = ($classID|0)==(4);
 if ($5) {
  $6 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($go,4)|0);
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = ($error|0)==(0|0);
   if ($8) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $9 = (__ZN6Object15ClassIDToStringEi(4)|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10 & 1;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    $15 = (($9) + 1|0);
    $16 = $15;
   } else {
    $13 = (($9) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $16 = $14;
   }
   HEAP32[$$byval_copy>>2] = $16;
   __Z6FormatPKcz($1,621104,$$byval_copy);
   __THREW__ = 0;
   (invoke_iii(2233,($error|0),($1|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    $26 = HEAP8[$1>>0]|0;
    $27 = $26 & 1;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $$01 = $24;$$02 = $25;
     ___resumeException($$01|0);
     // unreachable;
    }
    $29 = (($1) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    __ZdlPv($30);
    $$01 = $24;$$02 = $25;
    ___resumeException($$01|0);
    // unreachable;
   } else {
    $19 = HEAP8[$1>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $22 = (($1) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    __ZdlPv($23);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $31 = HEAP32[628384>>2]|0;
 HEAP32[$2>>2] = $31;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
 $32 = (__ZN6Object7ProduceEii10MemLabelId18ObjectCreationMode($classID,0,$$byval_copy,0)|0);
 $33 = ($32|0)==(0|0);
 if ($33) {
  $34 = ($error|0)==(0|0);
  if ($34) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $35 = (__ZN6Object15ClassIDToStringEi($classID)|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  if ($38) {
   $41 = (($35) + 1|0);
   $42 = $41;
  } else {
   $39 = (($35) + 8|0);
   $40 = HEAP32[$39>>2]|0;
   $42 = $40;
  }
  HEAP32[$$byval_copy>>2] = $42;
  __Z6FormatPKcz($3,618120,$$byval_copy);
  __THREW__ = 0;
  (invoke_iii(2233,($error|0),($3|0))|0);
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   $50 = ___cxa_find_matching_catch()|0;
   $51 = tempRet0;
   $52 = HEAP8[$3>>0]|0;
   $53 = $52 & 1;
   $54 = ($53<<24>>24)==(0);
   if ($54) {
    $$01 = $50;$$02 = $51;
    ___resumeException($$01|0);
    // unreachable;
   }
   $55 = (($3) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   __ZdlPv($56);
   $$01 = $50;$$02 = $51;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $45 = HEAP8[$3>>0]|0;
   $46 = $45 & 1;
   $47 = ($46<<24>>24)==(0);
   if ($47) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $48 = (($3) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   __ZdlPv($49);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $57 = HEAP32[$32>>2]|0;
 $58 = (($57) + 24|0);
 $59 = HEAP32[$58>>2]|0;
 FUNCTION_TABLE_vi[$59 & 4095]($32);
 __ZN5Unity10GameObject20AddComponentInternalEPNS_9ComponentE($go,$32);
 $60 = (($32) + 8|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = $61 >>> 21;
 $63 = HEAP32[560640>>2]|0;
 $64 = Math_imul($63, $62)|0;
 $65 = (($64) + 114)|0;
 $66 = $65 >> 5;
 $67 = $66 << 5;
 $68 = (($65) - ($67))|0;
 $69 = HEAP32[560632>>2]|0;
 $70 = (($69) + ($66<<2)|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = 1 << $68;
 $73 = $72 & $71;
 $74 = ($73|0)==(0);
 do {
  if (!($74)) {
   $75 = (($32) + 4|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($script|0)==(0|0);
   if ($77) {
    __ZN13MonoBehaviour8SetClassEP14ScriptingClassP15ScriptingObject($32,$klass,0);
   } else {
    $78 = (($script) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    HEAP32[$4>>2] = $79;
    __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($32,$4,0);
   }
   $80 = ($76|0)==(0);
   if ($80) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$0>>2] = $76;
   $81 = HEAP32[560624>>2]|0;
   $82 = ($81|0)==(0|0);
   if (!($82)) {
    $83 = (($81) + 36|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($81) + 4|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($84|0)==($86|0);
    do {
     if ($87) {
      $88 = (($81) + 28|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = (($81) + 32|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($89) + ($91<<3)|0);
      $108 = $92;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$81,$0);
      $93 = HEAP32[$$byval_copy>>2]|0;
      $94 = ($93|0)==(-1);
      $95 = (($81) + 28|0);
      $96 = HEAP32[$95>>2]|0;
      if ($94) {
       $97 = (($81) + 32|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = (($96) + ($98<<3)|0);
       $108 = $99;
       break;
      } else {
       $100 = (($96) + ($93<<3)|0);
       $108 = $100;
       break;
      }
     }
    } while(0);
    $101 = HEAP32[560624>>2]|0;
    $102 = (($101) + 28|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($101) + 32|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($103) + ($105<<3)|0);
    $107 = ($108|0)==($106|0);
    if (!($107)) {
     $109 = (($108) + 4|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0|0);
     if (!($111)) {
      break;
     }
    }
   }
   $112 = (__Z31ReadObjectFromPersistentManageri($76)|0);
   $113 = ($112|0)==(0|0);
   if ($113) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $114 = HEAP32[$32>>2]|0;
 $115 = (($114) + 24|0);
 $116 = HEAP32[$115>>2]|0;
 FUNCTION_TABLE_vi[$116 & 4095]($32);
 $117 = HEAP32[$32>>2]|0;
 $118 = (($117) + 28|0);
 $119 = HEAP32[$118>>2]|0;
 FUNCTION_TABLE_vi[$119 & 4095]($32);
 if ((($classID|0) == 4) | (($classID|0) == 224)) {
  __ZN5Unity10GameObject21EnsureUniqueTransformEbb($go,$5,1);
 }
 $120 = HEAP32[$32>>2]|0;
 $121 = (($120) + 12|0);
 $122 = HEAP32[$121>>2]|0;
 FUNCTION_TABLE_vii[$122 & 4095]($32,4);
 $$0 = $32;
 STACKTOP = sp;return ($$0|0);
}
function __Z21AddComponentUncheckedRN5Unity10GameObjectEiP14ScriptingClassPNSt3__112basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE($go,$classID,$klass,$error) {
 $go = $go|0;
 $classID = $classID|0;
 $klass = $klass|0;
 $error = $error|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $script$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($klass|0)==(0|0);
 if ($0) {
  $script$0 = 0;
 } else {
  $1 = (__Z19GetScriptingManagerv()|0);
  $2 = (($1) + 24|0);
  $3 = (__ZN17MonoScriptManager17FindRuntimeScriptEP14ScriptingClass($2,$klass)|0);
  $script$0 = $3;
 }
 $4 = (__ZL21AddComponentUncheckedRN5Unity10GameObjectEiP14ScriptingClassP10MonoScriptPNSt3__112basic_stringIcNS6_11char_traitsIcEENS6_9allocatorIcEEEE($go,$classID,$klass,$script$0,$error)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z21CheckForAbstractClassRN5Unity10GameObjectEiPNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($go,$classID,$error) {
 $go = $go|0;
 $classID = $classID|0;
 $error = $error|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i6 = 0, $derivedObjects = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $objectList = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i7 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i11 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i9 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i10 = 0, $vararg_buffer6 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer6 = sp;
 $objectList = sp + 44|0;
 $derivedObjects = sp + 8|0;
 $0 = sp + 20|0;
 $1 = sp + 32|0;
 $2 = (__ZN6Object13ClassIDToRTTIEi($classID)|0);
 $3 = (($2) + 28|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$objectList+0>>2]=0|0;HEAP32[$objectList+4>>2]=0|0;HEAP32[$objectList+8>>2]=0|0;
 HEAP32[$derivedObjects>>2] = 0;
 $6 = (($derivedObjects) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($derivedObjects) + 8|0);
 HEAP32[$7>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1628,($classID|0),($derivedObjects|0),1);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L4: do {
  if ($9) {
   label = 20;
  } else {
   $10 = HEAP32[$derivedObjects>>2]|0;
   $11 = HEAP32[$6>>2]|0;
   $12 = ($10|0)==($11|0);
   L6: do {
    if (!($12)) {
     $13 = (($0) + 1|0);
     $14 = (($0) + 8|0);
     $15 = (($0) + 4|0);
     $17 = $10;
     while(1) {
      $16 = HEAP32[$17>>2]|0;
      __THREW__ = 0;
      $18 = (invoke_ii(3216,($16|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 19;
       break;
      }
      $21 = HEAP8[$18>>0]|0;
      $22 = $21 & 1;
      $23 = ($22<<24>>24)==(0);
      if ($23) {
       $26 = (($18) + 1|0);
       $27 = $26;
      } else {
       $24 = (($18) + 8|0);
       $25 = HEAP32[$24>>2]|0;
       $27 = $25;
      }
      __THREW__ = 0;
      HEAP32[$vararg_buffer6>>2] = $27;
      invoke_viii(1617,($0|0),(618192|0),($vararg_buffer6|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 19;
       break;
      }
      $30 = HEAP8[$0>>0]|0;
      $31 = $30 & 1;
      $32 = ($31<<24>>24)==(0);
      if ($32) {
       $35 = $30&255;
       $36 = $35 >>> 1;
       $37 = $13;$38 = $36;
      } else {
       $33 = HEAP32[$14>>2]|0;
       $34 = HEAP32[$15>>2]|0;
       $37 = $33;$38 = $34;
      }
      __THREW__ = 0;
      (invoke_iiii(1480,($objectList|0),($37|0),($38|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      $41 = HEAP8[$0>>0]|0;
      $42 = $41 & 1;
      $43 = ($42<<24>>24)==(0);
      if (!($43)) {
       $44 = HEAP32[$14>>2]|0;
       __ZdlPv($44);
      }
      $45 = HEAP32[$6>>2]|0;
      $46 = (($45) + -4|0);
      $47 = ($17|0)==($46|0);
      if ($47) {
       $62 = $45;
      } else {
       __THREW__ = 0;
       (invoke_iiii(1480,($objectList|0),(618200|0),4)|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        label = 19;
        break;
       }
       $$pre = HEAP32[$6>>2]|0;
       $62 = $$pre;
      }
      $60 = (($17) + 4|0);
      $61 = ($60|0)==($62|0);
      if ($61) {
       break L6;
      } else {
       $17 = $60;
      }
     }
     if ((label|0) == 19) {
      $50 = ___cxa_find_matching_catch()|0;
      $51 = tempRet0;
      $lpad$phi$index = $50;$lpad$phi$index2 = $51;
      label = 21;
      break L4;
     }
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     $56 = HEAP8[$0>>0]|0;
     $57 = $56 & 1;
     $58 = ($57<<24>>24)==(0);
     if ($58) {
      $$01 = $54;$$02 = $55;
      break L4;
     }
     $59 = HEAP32[$14>>2]|0;
     __ZdlPv($59);
     $$01 = $54;$$02 = $55;
     break L4;
    }
   } while(0);
   $63 = HEAP8[$objectList>>0]|0;
   $64 = $63 & 1;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    $68 = (($objectList) + 1|0);
    $75 = $68;
   } else {
    $66 = (($objectList) + 8|0);
    $67 = HEAP32[$66>>2]|0;
    $75 = $67;
   }
   $69 = HEAP32[$go>>2]|0;
   $70 = (($69) + 32|0);
   $71 = HEAP32[$70>>2]|0;
   __THREW__ = 0;
   $72 = (invoke_ii($71|0,($go|0))|0);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    label = 20;
   } else {
    __THREW__ = 0;
    HEAP32[$vararg_buffer6>>2] = $75;
    $vararg_ptr9 = (($vararg_buffer6) + 4|0);
    HEAP32[$vararg_ptr9>>2] = $72;
    invoke_viii(1617,($1|0),(618208|0),($vararg_buffer6|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     label = 20;
    } else {
     __THREW__ = 0;
     (invoke_iii(2233,($error|0),($1|0))|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      $92 = ___cxa_find_matching_catch()|0;
      $93 = tempRet0;
      $94 = HEAP8[$1>>0]|0;
      $95 = $94 & 1;
      $96 = ($95<<24>>24)==(0);
      if ($96) {
       $$01 = $92;$$02 = $93;
       break;
      }
      $97 = (($1) + 8|0);
      $98 = HEAP32[$97>>2]|0;
      __ZdlPv($98);
      $$01 = $92;$$02 = $93;
      break;
     }
     $80 = HEAP8[$1>>0]|0;
     $81 = $80 & 1;
     $82 = ($81<<24>>24)==(0);
     if (!($82)) {
      $83 = (($1) + 8|0);
      $84 = HEAP32[$83>>2]|0;
      __ZdlPv($84);
     }
     $85 = HEAP32[$derivedObjects>>2]|0;
     $86 = ($85|0)==(0|0);
     if (!($86)) {
      $87 = HEAP32[$6>>2]|0;
      $88 = ($87|0)==($85|0);
      if (!($88)) {
       $__new_last2$i$i$i$i$i6 = $85;
       $scevgep$i$i$i$i$i7 = (($87) + -4|0);
       $89 = (0 - ($__new_last2$i$i$i$i$i6))|0;
       $uglygep$i$i$i$i$i9 = (($scevgep$i$i$i$i$i7) + ($89)|0);
       $uglygep3$i$i$i$i$i10 = $uglygep$i$i$i$i$i9;
       $90 = $uglygep3$i$i$i$i$i10 >>> 2;
       $91 = $90 ^ -1;
       $scevgep4$i$i$i$i$i11 = (($87) + ($91<<2)|0);
       HEAP32[$6>>2] = $scevgep4$i$i$i$i$i11;
      }
      __ZdlPv($85);
     }
     $99 = HEAP8[$objectList>>0]|0;
     $100 = $99 & 1;
     $101 = ($100<<24>>24)==(0);
     if ($101) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $102 = (($objectList) + 8|0);
     $103 = HEAP32[$102>>2]|0;
     __ZdlPv($103);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $52 = ___cxa_find_matching_catch()|0;
  $53 = tempRet0;
  $lpad$phi$index = $52;$lpad$phi$index2 = $53;
  label = 21;
 }
 if ((label|0) == 21) {
  $$01 = $lpad$phi$index;$$02 = $lpad$phi$index2;
 }
 $104 = HEAP32[$derivedObjects>>2]|0;
 $105 = ($104|0)==(0|0);
 if (!($105)) {
  $106 = HEAP32[$6>>2]|0;
  $107 = ($106|0)==($104|0);
  if (!($107)) {
   $__new_last2$i$i$i$i$i = $104;
   $scevgep$i$i$i$i$i = (($106) + -4|0);
   $108 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($108)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $109 = $uglygep3$i$i$i$i$i >>> 2;
   $110 = $109 ^ -1;
   $scevgep4$i$i$i$i$i = (($106) + ($110<<2)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($104);
 }
 $111 = HEAP8[$objectList>>0]|0;
 $112 = $111 & 1;
 $113 = ($112<<24>>24)==(0);
 if ($113) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $114 = (($objectList) + 8|0);
 $115 = HEAP32[$114>>2]|0;
 __ZdlPv($115);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z12CanAddScriptRN5Unity10GameObjectEP14ScriptingClassPS3_S4_($go,$klassToAdd,$baseKlass,$conflictingKlass) {
 $go = $go|0;
 $klassToAdd = $klassToAdd|0;
 $baseKlass = $baseKlass|0;
 $conflictingKlass = $conflictingKlass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $invocation$i = 0, $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$i$byval_copy = sp + 208|0;
 $invocation$i = sp;
 $0 = sp + 200|0;
 $1 = (__Z26scripting_class_get_objectP14ScriptingClass($klassToAdd)|0);
 $2 = (__Z14GetMonoManagerv()|0);
 $3 = (($2) + 416|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i,$tmpcast$i$byval_copy);
 $14 = (($invocation$i) + 32|0);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($14,$1);
 $15 = (__ZN19ScriptingInvocation6InvokeEv($invocation$i)|0);
 $16 = (__Z39scripting_class_from_systemtypeinstanceP15ScriptingObject($15)|0);
 HEAP32[$baseKlass>>2] = $16;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($go) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(0);
 if (!($20)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($go) + 24|0);
 $i$01 = 0;
 while(1) {
  $22 = HEAP32[$21>>2]|0;
  $23 = ((($22) + ($i$01<<3)|0) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   $26 = (($24) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $27 >>> 21;
   $29 = HEAP32[560640>>2]|0;
   $30 = Math_imul($29, $28)|0;
   $31 = (($30) + 114)|0;
   $32 = $31 >> 5;
   $33 = $32 << 5;
   $34 = (($31) - ($33))|0;
   $35 = HEAP32[560632>>2]|0;
   $36 = (($35) + ($32<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = 1 << $34;
   $39 = $38 & $37;
   $40 = ($39|0)==(0);
   if (!($40)) {
    $41 = (__ZNK13MonoBehaviour8GetClassEv($24)|0);
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $43 = HEAP32[$baseKlass>>2]|0;
     $44 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($41,$43)|0);
     if ($44) {
      break;
     }
    }
   }
  }
  $45 = (($i$01) + 1)|0;
  $46 = HEAP32[$18>>2]|0;
  $47 = ($45|0)<($46|0);
  if ($47) {
   $i$01 = $45;
  } else {
   $$0 = 1;
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$conflictingKlass>>2] = $41;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZL30CollectComponentsWithoutAddingRN5Unity10GameObjectEiP14ScriptingClassR13dynamic_arrayI16AddComponentDataLj4EES7_PNSt3__112basic_stringIcNS8_11char_traitsIcEENS8_9allocatorIcEEEE($go,$classID,$klass,$components,$processed,$error) {
 $go = $go|0;
 $classID = $classID|0;
 $klass = $klass|0;
 $components = $components|0;
 $processed = $processed|0;
 $error = $error|0;
 var $$0 = 0, $$01 = 0, $$01$i = 0, $$02 = 0, $$02$i = 0, $$byval_copy57 = 0, $$pre$i$i = 0, $$pre$i$i23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0;
 var $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0;
 var $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $baseklass = 0, $c$0$i41 = 0, $clsID$1$i = 0, $conflictingklass = 0, $curKlass$0$i$i = 0, $curKlass$0$i4$i$i = 0, $i$01$i$i = 0, $it$01$i = 0;
 var $it$02$i = 0, $j$0$i42 = 0, $not$$i = 0, $or$cond$i$i = 0, $requiredScript$0$i = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr18 = 0, $vararg_ptr22 = 0, $vararg_ptr4 = 0, $vararg_ptr47 = 0, $vararg_ptr48 = 0, $vararg_ptr5 = 0, $vararg_ptr52 = 0, $vararg_ptr53 = 0, $vararg_ptr54 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy57 = sp;
 $0 = sp + 192|0;
 $1 = sp + 180|0;
 $2 = sp + 168|0;
 $3 = sp + 156|0;
 $4 = sp + 144|0;
 $5 = sp + 132|0;
 $6 = sp + 120|0;
 $7 = sp + 108|0;
 $8 = sp + 196|0;
 $9 = sp + 52|0;
 $10 = sp + 40|0;
 $11 = sp + 16|0;
 $12 = sp + 28|0;
 $13 = sp + 84|0;
 $baseklass = sp + 64|0;
 $conflictingklass = sp + 68|0;
 $14 = sp + 72|0;
 $15 = sp + 96|0;
 $16 = HEAP32[560640>>2]|0;
 $17 = Math_imul($16, $classID)|0;
 $18 = (($17) + 2)|0;
 $19 = $18 >> 5;
 $20 = $19 << 5;
 $21 = (($18) - ($20))|0;
 $22 = HEAP32[560632>>2]|0;
 $23 = (($22) + ($19<<2)|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = 1 << $21;
 $26 = $25 & $24;
 $27 = ($26|0)==(0);
 if ($27) {
  $28 = ($error|0)==(0|0);
  if ($28) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $29 = (__ZN6Object15ClassIDToStringEi($classID)|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30 & 1;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   $35 = (($29) + 1|0);
   $36 = $35;
  } else {
   $33 = (($29) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $36 = $34;
  }
  HEAP32[$$byval_copy57>>2] = $36;
  __Z6FormatPKcz($8,618376,$$byval_copy57);
  __THREW__ = 0;
  (invoke_iii(2233,($error|0),($8|0))|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   $46 = HEAP8[$8>>0]|0;
   $47 = $46 & 1;
   $48 = ($47<<24>>24)==(0);
   if ($48) {
    $$01 = $44;$$02 = $45;
    ___resumeException($$01|0);
    // unreachable;
   }
   $49 = (($8) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   __ZdlPv($50);
   $$01 = $44;$$02 = $45;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $39 = HEAP8[$8>>0]|0;
   $40 = $39 & 1;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $42 = (($8) + 8|0);
   $43 = HEAP32[$42>>2]|0;
   __ZdlPv($43);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $51 = (__ZNK5Unity10GameObject27FindConflictingComponentPtrEi($go,$classID)|0);
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  $53 = ($error|0)==(0|0);
  if ($53) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $54 = (__ZN6Object15ClassIDToStringEi($classID)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55 & 1;
  $57 = ($56<<24>>24)==(0);
  if ($57) {
   $60 = (($54) + 1|0);
   $75 = $60;
  } else {
   $58 = (($54) + 8|0);
   $59 = HEAP32[$58>>2]|0;
   $75 = $59;
  }
  $61 = HEAP32[$go>>2]|0;
  $62 = (($61) + 32|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_ii[$63 & 4095]($go)|0);
  $65 = (($51) + 8|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = $66 >>> 21;
  $68 = (__ZN6Object15ClassIDToStringEi($67)|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = $69 & 1;
  $71 = ($70<<24>>24)==(0);
  if ($71) {
   $74 = (($68) + 1|0);
   $76 = $74;
  } else {
   $72 = (($68) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   $76 = $73;
  }
  HEAP32[$$byval_copy57>>2] = $75;
  $vararg_ptr4 = (($$byval_copy57) + 4|0);
  HEAP32[$vararg_ptr4>>2] = $64;
  $vararg_ptr5 = (($$byval_copy57) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $76;
  __Z6FormatPKcz($9,619688,$$byval_copy57);
  __THREW__ = 0;
  (invoke_iii(2233,($error|0),($9|0))|0);
  $77 = __THREW__; __THREW__ = 0;
  $78 = $77&1;
  if ($78) {
   $84 = ___cxa_find_matching_catch()|0;
   $85 = tempRet0;
   $86 = HEAP8[$9>>0]|0;
   $87 = $86 & 1;
   $88 = ($87<<24>>24)==(0);
   if ($88) {
    $$01 = $84;$$02 = $85;
    ___resumeException($$01|0);
    // unreachable;
   }
   $89 = (($9) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   __ZdlPv($90);
   $$01 = $84;$$02 = $85;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $79 = HEAP8[$9>>0]|0;
   $80 = $79 & 1;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $82 = (($9) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   __ZdlPv($83);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $91 = (($processed) + 8|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0);
 L47: do {
  if (!($93)) {
   $94 = (__Z25FindConflictingComponentsi($classID)|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($94) + 4|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($95|0)==($97|0);
   if (!($98)) {
    $99 = HEAP32[$processed>>2]|0;
    $100 = HEAP32[$91>>2]|0;
    $101 = ($100|0)==(0);
    if (!($101)) {
     $102 = HEAP32[560640>>2]|0;
     $103 = HEAP32[560632>>2]|0;
     $104 = (($99) + ($100<<3)|0);
     $it$02$i = $99;
     L51: while(1) {
      $105 = HEAP32[$it$02$i>>2]|0;
      $106 = Math_imul($105, $102)|0;
      $110 = $95;
      while(1) {
       $109 = HEAP32[$110>>2]|0;
       $111 = (($109) + ($106))|0;
       $112 = $111 >> 5;
       $113 = $112 << 5;
       $114 = (($111) - ($113))|0;
       $115 = (($103) + ($112<<2)|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = 1 << $114;
       $118 = $117 & $116;
       $119 = ($118|0)==(0);
       $108 = (($110) + 4|0);
       if (!($119)) {
        break L51;
       }
       $107 = ($108|0)==($97|0);
       if ($107) {
        break;
       } else {
        $110 = $108;
       }
      }
      $120 = (($it$02$i) + 8|0);
      $121 = ($120|0)==($104|0);
      if ($121) {
       break L47;
      } else {
       $it$02$i = $120;
      }
     }
     $122 = ($109|0)>(-1);
     if ($122) {
      $123 = ($error|0)==(0|0);
      if ($123) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      $124 = (__ZN6Object15ClassIDToStringEi($classID)|0);
      $125 = HEAP8[$124>>0]|0;
      $126 = $125 & 1;
      $127 = ($126<<24>>24)==(0);
      if ($127) {
       $130 = (($124) + 1|0);
       $142 = $130;
      } else {
       $128 = (($124) + 8|0);
       $129 = HEAP32[$128>>2]|0;
       $142 = $129;
      }
      $131 = HEAP32[$go>>2]|0;
      $132 = (($131) + 32|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = (FUNCTION_TABLE_ii[$133 & 4095]($go)|0);
      $135 = (__ZN6Object15ClassIDToStringEi($109)|0);
      $136 = HEAP8[$135>>0]|0;
      $137 = $136 & 1;
      $138 = ($137<<24>>24)==(0);
      if ($138) {
       $141 = (($135) + 1|0);
       $143 = $141;
      } else {
       $139 = (($135) + 8|0);
       $140 = HEAP32[$139>>2]|0;
       $143 = $140;
      }
      HEAP32[$$byval_copy57>>2] = $142;
      $vararg_ptr9 = (($$byval_copy57) + 4|0);
      HEAP32[$vararg_ptr9>>2] = $134;
      $vararg_ptr10 = (($$byval_copy57) + 8|0);
      HEAP32[$vararg_ptr10>>2] = $143;
      __Z6FormatPKcz($10,619784,$$byval_copy57);
      __THREW__ = 0;
      (invoke_iii(2233,($error|0),($10|0))|0);
      $144 = __THREW__; __THREW__ = 0;
      $145 = $144&1;
      if ($145) {
       $151 = ___cxa_find_matching_catch()|0;
       $152 = tempRet0;
       $153 = HEAP8[$10>>0]|0;
       $154 = $153 & 1;
       $155 = ($154<<24>>24)==(0);
       if ($155) {
        $$01 = $151;$$02 = $152;
        ___resumeException($$01|0);
        // unreachable;
       }
       $156 = (($10) + 8|0);
       $157 = HEAP32[$156>>2]|0;
       __ZdlPv($157);
       $$01 = $151;$$02 = $152;
       ___resumeException($$01|0);
       // unreachable;
      } else {
       $146 = HEAP8[$10>>0]|0;
       $147 = $146 & 1;
       $148 = ($147<<24>>24)==(0);
       if ($148) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       $149 = (($10) + 8|0);
       $150 = HEAP32[$149>>2]|0;
       __ZdlPv($150);
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $158 = (__ZNK5Unity10GameObject22CountDerivedComponentsEi($go,$classID)|0);
 $159 = ($158|0)==(0);
 if ($159) {
  label = 47;
 } else {
  $160 = (__Z35DoesComponentAllowMultipleInclusioni($classID)|0);
  if ($160) {
   label = 47;
  }
 }
 if ((label|0) == 47) {
  $161 = (__ZNK5Unity10GameObject27FindConflictingComponentPtrEi($go,$classID)|0);
  $not$$i = ($161|0)==(0|0);
  if ($not$$i) {
   $189 = (($go) + 8|0);
   $190 = HEAP32[$189>>2]|0;
   $191 = $190 & 1179648;
   $192 = ($191|0)==(1179648);
   if ($192) {
    $193 = ($error|0)==(0|0);
    if ($193) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $194 = (__ZN6Object15ClassIDToStringEi($classID)|0);
    $195 = HEAP8[$194>>0]|0;
    $196 = $195 & 1;
    $197 = ($196<<24>>24)==(0);
    if ($197) {
     $200 = (($194) + 1|0);
     $205 = $200;
    } else {
     $198 = (($194) + 8|0);
     $199 = HEAP32[$198>>2]|0;
     $205 = $199;
    }
    $201 = HEAP32[$go>>2]|0;
    $202 = (($201) + 32|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = (FUNCTION_TABLE_ii[$203 & 4095]($go)|0);
    HEAP32[$$byval_copy57>>2] = $205;
    $vararg_ptr18 = (($$byval_copy57) + 4|0);
    HEAP32[$vararg_ptr18>>2] = $204;
    __Z6FormatPKcz($12,619968,$$byval_copy57);
    __THREW__ = 0;
    (invoke_iii(2233,($error|0),($12|0))|0);
    $206 = __THREW__; __THREW__ = 0;
    $207 = $206&1;
    if ($207) {
     $213 = ___cxa_find_matching_catch()|0;
     $214 = tempRet0;
     $215 = HEAP8[$12>>0]|0;
     $216 = $215 & 1;
     $217 = ($216<<24>>24)==(0);
     if ($217) {
      $$01 = $213;$$02 = $214;
      ___resumeException($$01|0);
      // unreachable;
     }
     $218 = (($12) + 8|0);
     $219 = HEAP32[$218>>2]|0;
     __ZdlPv($219);
     $$01 = $213;$$02 = $214;
     ___resumeException($$01|0);
     // unreachable;
    } else {
     $208 = HEAP8[$12>>0]|0;
     $209 = $208 & 1;
     $210 = ($209<<24>>24)==(0);
     if ($210) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $211 = (($12) + 8|0);
     $212 = HEAP32[$211>>2]|0;
     __ZdlPv($212);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $220 = (__ZN6Object13ClassIDToRTTIEi($classID)|0);
   $221 = (($220) + 28|0);
   $222 = HEAP8[$221>>0]|0;
   $223 = ($222<<24>>24)==(0);
   if (!($223)) {
    $224 = (__ZN6Object15ClassIDToStringEi($classID)|0);
    $225 = HEAP8[$224>>0]|0;
    $226 = $225 & 1;
    $227 = ($226<<24>>24)==(0);
    if ($227) {
     $230 = (($224) + 1|0);
     $238 = $230;
    } else {
     $228 = (($224) + 8|0);
     $229 = HEAP32[$228>>2]|0;
     $238 = $229;
    }
    $231 = (__ZN6Object15ClassIDToStringEi($classID)|0);
    $232 = HEAP8[$231>>0]|0;
    $233 = $232 & 1;
    $234 = ($233<<24>>24)==(0);
    if ($234) {
     $237 = (($231) + 1|0);
     $239 = $237;
    } else {
     $235 = (($231) + 8|0);
     $236 = HEAP32[$235>>2]|0;
     $239 = $236;
    }
    HEAP32[$$byval_copy57>>2] = $238;
    $vararg_ptr22 = (($$byval_copy57) + 4|0);
    HEAP32[$vararg_ptr22>>2] = $239;
    __Z6FormatPKcz($13,620104,$$byval_copy57);
    __THREW__ = 0;
    (invoke_iii(2233,($error|0),($13|0))|0);
    $240 = __THREW__; __THREW__ = 0;
    $241 = $240&1;
    if ($241) {
     $247 = ___cxa_find_matching_catch()|0;
     $248 = tempRet0;
     $249 = HEAP8[$13>>0]|0;
     $250 = $249 & 1;
     $251 = ($250<<24>>24)==(0);
     if ($251) {
      $$01 = $247;$$02 = $248;
      ___resumeException($$01|0);
      // unreachable;
     }
     $252 = (($13) + 8|0);
     $253 = HEAP32[$252>>2]|0;
     __ZdlPv($253);
     $$01 = $247;$$02 = $248;
     ___resumeException($$01|0);
     // unreachable;
    } else {
     $242 = HEAP8[$13>>0]|0;
     $243 = $242 & 1;
     $244 = ($243<<24>>24)==(0);
     if ($244) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $245 = (($13) + 8|0);
     $246 = HEAP32[$245>>2]|0;
     __ZdlPv($246);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $254 = HEAP32[$91>>2]|0;
   $255 = (($254) + 1)|0;
   HEAP32[$91>>2] = $255;
   $256 = (($processed) + 12|0);
   $257 = HEAP32[$256>>2]|0;
   $258 = $257 & 2147483647;
   $259 = ($255>>>0)>($258>>>0);
   if ($259) {
    $260 = $257 << 1;
    $261 = ($260|0)==(0);
    $262 = $261 ? 1 : $260;
    $263 = ($258>>>0)<($262>>>0);
    do {
     if ($263) {
      $264 = ($257|0)>(-1);
      if ($264) {
       HEAP32[$256>>2] = $262;
       $265 = HEAP32[$processed>>2]|0;
       $266 = $262 << 3;
       $267 = (($processed) + 4|0);
       $268 = HEAP32[$267>>2]|0;
       HEAP32[$0>>2] = $268;
       ;HEAP32[$$byval_copy57+0>>2]=HEAP32[$0+0>>2]|0;
       $269 = (__Z16realloc_internalPvji10MemLabelIdiPKci($265,$266,4,$$byval_copy57,0,618440,370)|0);
       HEAP32[$processed>>2] = $269;
       break;
      } else {
       $270 = $262 << 3;
       $271 = (($processed) + 4|0);
       $272 = HEAP32[$271>>2]|0;
       HEAP32[$0>>2] = $272;
       ;HEAP32[$$byval_copy57+0>>2]=HEAP32[$0+0>>2]|0;
       $273 = (__Z15malloc_internaljj10MemLabelIdiPKci($270,4,$$byval_copy57,0,618440,352)|0);
       $274 = HEAP32[$processed>>2]|0;
       $275 = HEAP32[$91>>2]|0;
       $276 = $275 << 3;
       _memcpy(($273|0),($274|0),($276|0))|0;
       HEAP32[$256>>2] = $262;
       HEAP32[$processed>>2] = $273;
       break;
      }
     }
    } while(0);
    $$pre$i$i23 = HEAP32[$91>>2]|0;
    $278 = $$pre$i$i23;
   } else {
    $278 = $255;
   }
   $277 = (($278) + -1)|0;
   $279 = HEAP32[$processed>>2]|0;
   $280 = (($279) + ($277<<3)|0);
   $281 = $klass;
   $282 = $280;
   $283 = $282;
   HEAP32[$283>>2] = $classID;
   $284 = (($282) + 4)|0;
   $285 = $284;
   HEAP32[$285>>2] = $281;
   $286 = (__Z34FindRequiredComponentsForComponenti($classID)|0);
   $287 = HEAP32[$286>>2]|0;
   $288 = (($286) + 4|0);
   $289 = HEAP32[$288>>2]|0;
   $290 = ($287|0)==($289|0);
   L139: do {
    if (!($290)) {
     $292 = $287;
     L140: while(1) {
      $291 = HEAP32[$292>>2]|0;
      $293 = (__ZNK5Unity10GameObject22CountDerivedComponentsEi($go,$291)|0);
      $294 = ($293|0)==(0);
      L142: do {
       if ($294) {
        $295 = HEAP32[$292>>2]|0;
        $296 = HEAP32[$91>>2]|0;
        $297 = ($296|0)==(0);
        if (!($297)) {
         $298 = HEAP32[$processed>>2]|0;
         $299 = HEAP32[560640>>2]|0;
         $300 = HEAP32[560632>>2]|0;
         $301 = (($298) + ($296<<3)|0);
         $it$01$i = $298;
         while(1) {
          $304 = HEAP32[$it$01$i>>2]|0;
          $305 = Math_imul($304, $299)|0;
          $306 = (($305) + ($295))|0;
          $307 = $306 >> 5;
          $308 = $307 << 5;
          $309 = (($306) - ($308))|0;
          $310 = (($300) + ($307<<2)|0);
          $311 = HEAP32[$310>>2]|0;
          $312 = 1 << $309;
          $313 = $312 & $311;
          $314 = ($313|0)==(0);
          $303 = (($it$01$i) + 8|0);
          if (!($314)) {
           break L142;
          }
          $302 = ($303|0)==($301|0);
          if ($302) {
           break;
          } else {
           $it$01$i = $303;
          }
         }
        }
        $315 = (__Z21CheckForAbstractClassRN5Unity10GameObjectEiPNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($go,$295,$error)|0);
        if (!($315)) {
         $$0 = 0;
         label = 191;
         break L140;
        }
        $316 = HEAP32[$292>>2]|0;
        $317 = (__ZL30CollectComponentsWithoutAddingRN5Unity10GameObjectEiP14ScriptingClassR13dynamic_arrayI16AddComponentDataLj4EES7_PNSt3__112basic_stringIcNS8_11char_traitsIcEENS8_9allocatorIcEEEE($go,$316,0,$components,$processed,$error)|0);
        if (!($317)) {
         $$0 = 0;
         label = 191;
         break L140;
        }
       }
      } while(0);
      $318 = (($292) + 4|0);
      $319 = HEAP32[$288>>2]|0;
      $320 = ($318|0)==($319|0);
      if ($320) {
       break L139;
      } else {
       $292 = $318;
      }
     }
     if ((label|0) == 191) {
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $321 = ($classID|0)==(114);
   L156: do {
    if ($321) {
     $322 = (__Z19GetScriptingManagerv()|0);
     $323 = (($322) + 24|0);
     $324 = (__ZN17MonoScriptManager17FindRuntimeScriptEP14ScriptingClass($323,$klass)|0);
     $325 = ($324|0)==(0|0);
     if (!($325)) {
      $326 = (__ZNK10MonoScript13GetScriptTypeEv($324)|0);
      $327 = ($326|0)==(0);
      if (!($327)) {
       $328 = ($326|0)==(-3);
       $329 = ($error|0)!=(0|0);
       if ($328) {
        if (!($329)) {
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
        $330 = HEAP32[$324>>2]|0;
        $331 = (($330) + 32|0);
        $332 = HEAP32[$331>>2]|0;
        $333 = (FUNCTION_TABLE_ii[$332 & 4095]($324)|0);
        HEAP32[$$byval_copy57>>2] = $333;
        __Z6FormatPKcz($1,620432,$$byval_copy57);
        __THREW__ = 0;
        (invoke_iii(2233,($error|0),($1|0))|0);
        $334 = __THREW__; __THREW__ = 0;
        $335 = $334&1;
        if ($335) {
         $341 = ___cxa_find_matching_catch()|0;
         $342 = tempRet0;
         $343 = HEAP8[$1>>0]|0;
         $344 = $343 & 1;
         $345 = ($344<<24>>24)==(0);
         if ($345) {
          $$01$i = $342;$$02$i = $341;
          ___resumeException($$02$i|0);
          // unreachable;
         }
         $346 = (($1) + 8|0);
         $347 = HEAP32[$346>>2]|0;
         __ZdlPv($347);
         $$01$i = $342;$$02$i = $341;
         ___resumeException($$02$i|0);
         // unreachable;
        } else {
         $336 = HEAP8[$1>>0]|0;
         $337 = $336 & 1;
         $338 = ($337<<24>>24)==(0);
         if ($338) {
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
         $339 = (($1) + 8|0);
         $340 = HEAP32[$339>>2]|0;
         __ZdlPv($340);
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
       }
       if (!($329)) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       $348 = (($324) + 112|0);
       $349 = HEAP8[$348>>0]|0;
       $350 = ($349<<24>>24)==(0);
       if (!($350)) {
        $351 = HEAP32[$324>>2]|0;
        $352 = (($351) + 32|0);
        $353 = HEAP32[$352>>2]|0;
        $354 = (FUNCTION_TABLE_ii[$353 & 4095]($324)|0);
        HEAP32[$$byval_copy57>>2] = $354;
        __Z6FormatPKcz($2,620552,$$byval_copy57);
        __THREW__ = 0;
        (invoke_iii(2233,($error|0),($2|0))|0);
        $355 = __THREW__; __THREW__ = 0;
        $356 = $355&1;
        if ($356) {
         $362 = ___cxa_find_matching_catch()|0;
         $363 = tempRet0;
         $364 = HEAP8[$2>>0]|0;
         $365 = $364 & 1;
         $366 = ($365<<24>>24)==(0);
         if ($366) {
          $$01$i = $363;$$02$i = $362;
          ___resumeException($$02$i|0);
          // unreachable;
         }
         $367 = (($2) + 8|0);
         $368 = HEAP32[$367>>2]|0;
         __ZdlPv($368);
         $$01$i = $363;$$02$i = $362;
         ___resumeException($$02$i|0);
         // unreachable;
        } else {
         $357 = HEAP8[$2>>0]|0;
         $358 = $357 & 1;
         $359 = ($358<<24>>24)==(0);
         if ($359) {
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
         $360 = (($2) + 8|0);
         $361 = HEAP32[$360>>2]|0;
         __ZdlPv($361);
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
       }
       if ((($326|0) == -4)) {
        $387 = HEAP32[$324>>2]|0;
        $388 = (($387) + 32|0);
        $389 = HEAP32[$388>>2]|0;
        $390 = (FUNCTION_TABLE_ii[$389 & 4095]($324)|0);
        HEAP32[$$byval_copy57>>2] = $390;
        __Z6FormatPKcz($4,620800,$$byval_copy57);
        __THREW__ = 0;
        (invoke_iii(2233,($error|0),($4|0))|0);
        $391 = __THREW__; __THREW__ = 0;
        $392 = $391&1;
        if ($392) {
         $398 = ___cxa_find_matching_catch()|0;
         $399 = tempRet0;
         $400 = HEAP8[$4>>0]|0;
         $401 = $400 & 1;
         $402 = ($401<<24>>24)==(0);
         if ($402) {
          $$01$i = $399;$$02$i = $398;
          ___resumeException($$02$i|0);
          // unreachable;
         }
         $403 = (($4) + 8|0);
         $404 = HEAP32[$403>>2]|0;
         __ZdlPv($404);
         $$01$i = $399;$$02$i = $398;
         ___resumeException($$02$i|0);
         // unreachable;
        } else {
         $393 = HEAP8[$4>>0]|0;
         $394 = $393 & 1;
         $395 = ($394<<24>>24)==(0);
         if ($395) {
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
         $396 = (($4) + 8|0);
         $397 = HEAP32[$396>>2]|0;
         __ZdlPv($397);
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
       } else if ((($326|0) == -1)) {
        $369 = HEAP32[$324>>2]|0;
        $370 = (($369) + 32|0);
        $371 = HEAP32[$370>>2]|0;
        $372 = (FUNCTION_TABLE_ii[$371 & 4095]($324)|0);
        HEAP32[$$byval_copy57>>2] = $372;
        __Z6FormatPKcz($3,620680,$$byval_copy57);
        __THREW__ = 0;
        (invoke_iii(2233,($error|0),($3|0))|0);
        $373 = __THREW__; __THREW__ = 0;
        $374 = $373&1;
        if ($374) {
         $380 = ___cxa_find_matching_catch()|0;
         $381 = tempRet0;
         $382 = HEAP8[$3>>0]|0;
         $383 = $382 & 1;
         $384 = ($383<<24>>24)==(0);
         if ($384) {
          $$01$i = $381;$$02$i = $380;
          ___resumeException($$02$i|0);
          // unreachable;
         }
         $385 = (($3) + 8|0);
         $386 = HEAP32[$385>>2]|0;
         __ZdlPv($386);
         $$01$i = $381;$$02$i = $380;
         ___resumeException($$02$i|0);
         // unreachable;
        } else {
         $375 = HEAP8[$3>>0]|0;
         $376 = $375 & 1;
         $377 = ($376<<24>>24)==(0);
         if ($377) {
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
         $378 = (($3) + 8|0);
         $379 = HEAP32[$378>>2]|0;
         __ZdlPv($379);
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
       } else if ((($326|0) == -5)) {
        $405 = HEAP32[$324>>2]|0;
        $406 = (($405) + 32|0);
        $407 = HEAP32[$406>>2]|0;
        $408 = (FUNCTION_TABLE_ii[$407 & 4095]($324)|0);
        HEAP32[$$byval_copy57>>2] = $408;
        __Z6FormatPKcz($5,620872,$$byval_copy57);
        __THREW__ = 0;
        (invoke_iii(2233,($error|0),($5|0))|0);
        $409 = __THREW__; __THREW__ = 0;
        $410 = $409&1;
        if ($410) {
         $416 = ___cxa_find_matching_catch()|0;
         $417 = tempRet0;
         $418 = HEAP8[$5>>0]|0;
         $419 = $418 & 1;
         $420 = ($419<<24>>24)==(0);
         if ($420) {
          $$01$i = $417;$$02$i = $416;
          ___resumeException($$02$i|0);
          // unreachable;
         }
         $421 = (($5) + 8|0);
         $422 = HEAP32[$421>>2]|0;
         __ZdlPv($422);
         $$01$i = $417;$$02$i = $416;
         ___resumeException($$02$i|0);
         // unreachable;
        } else {
         $411 = HEAP8[$5>>0]|0;
         $412 = $411 & 1;
         $413 = ($412<<24>>24)==(0);
         if ($413) {
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
         $414 = (($5) + 8|0);
         $415 = HEAP32[$414>>2]|0;
         __ZdlPv($415);
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
       } else {
        $423 = ($326|0)==(-6);
        $424 = HEAP32[$324>>2]|0;
        $425 = (($424) + 32|0);
        $426 = HEAP32[$425>>2]|0;
        $427 = (FUNCTION_TABLE_ii[$426 & 4095]($324)|0);
        if ($423) {
         HEAP32[$$byval_copy57>>2] = $427;
         __Z6FormatPKcz($6,620944,$$byval_copy57);
         __THREW__ = 0;
         (invoke_iii(2233,($error|0),($6|0))|0);
         $428 = __THREW__; __THREW__ = 0;
         $429 = $428&1;
         if ($429) {
          $435 = ___cxa_find_matching_catch()|0;
          $436 = tempRet0;
          $437 = HEAP8[$6>>0]|0;
          $438 = $437 & 1;
          $439 = ($438<<24>>24)==(0);
          if ($439) {
           $$01$i = $436;$$02$i = $435;
           ___resumeException($$02$i|0);
           // unreachable;
          }
          $440 = (($6) + 8|0);
          $441 = HEAP32[$440>>2]|0;
          __ZdlPv($441);
          $$01$i = $436;$$02$i = $435;
          ___resumeException($$02$i|0);
          // unreachable;
         } else {
          $430 = HEAP8[$6>>0]|0;
          $431 = $430 & 1;
          $432 = ($431<<24>>24)==(0);
          if ($432) {
           $$0 = 0;
           STACKTOP = sp;return ($$0|0);
          }
          $433 = (($6) + 8|0);
          $434 = HEAP32[$433>>2]|0;
          __ZdlPv($434);
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
        } else {
         HEAP32[$$byval_copy57>>2] = $427;
         __Z6FormatPKcz($7,621024,$$byval_copy57);
         __THREW__ = 0;
         (invoke_iii(2233,($error|0),($7|0))|0);
         $442 = __THREW__; __THREW__ = 0;
         $443 = $442&1;
         if ($443) {
          $449 = ___cxa_find_matching_catch()|0;
          $450 = tempRet0;
          $451 = HEAP8[$7>>0]|0;
          $452 = $451 & 1;
          $453 = ($452<<24>>24)==(0);
          if ($453) {
           $$01$i = $450;$$02$i = $449;
           ___resumeException($$02$i|0);
           // unreachable;
          }
          $454 = (($7) + 8|0);
          $455 = HEAP32[$454>>2]|0;
          __ZdlPv($455);
          $$01$i = $450;$$02$i = $449;
          ___resumeException($$02$i|0);
          // unreachable;
         } else {
          $444 = HEAP8[$7>>0]|0;
          $445 = $444 & 1;
          $446 = ($445<<24>>24)==(0);
          if ($446) {
           $$0 = 0;
           STACKTOP = sp;return ($$0|0);
          }
          $447 = (($7) + 8|0);
          $448 = HEAP32[$447>>2]|0;
          __ZdlPv($448);
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
     HEAP32[$baseklass>>2] = 0;
     HEAP32[$conflictingklass>>2] = 0;
     $456 = (__Z12CanAddScriptRN5Unity10GameObjectEP14ScriptingClassPS3_S4_($go,$klass,$baseklass,$conflictingklass)|0);
     if (!($456)) {
      $457 = ($error|0)==(0|0);
      if ($457) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      $458 = HEAP32[$baseklass>>2]|0;
      $459 = HEAP32[$conflictingklass>>2]|0;
      $460 = ($458|0)==($459|0);
      $461 = HEAP32[$324>>2]|0;
      $462 = (($461) + 100|0);
      $463 = HEAP32[$462>>2]|0;
      $464 = (FUNCTION_TABLE_ii[$463 & 4095]($324)|0);
      $465 = HEAP8[$464>>0]|0;
      $466 = $465 & 1;
      $467 = ($466<<24>>24)==(0);
      if ($467) {
       $470 = (($464) + 1|0);
       $476 = $470;
      } else {
       $468 = (($464) + 8|0);
       $469 = HEAP32[$468>>2]|0;
       $476 = $469;
      }
      $471 = HEAP32[$go>>2]|0;
      $472 = (($471) + 32|0);
      $473 = HEAP32[$472>>2]|0;
      $474 = (FUNCTION_TABLE_ii[$473 & 4095]($go)|0);
      $475 = (__Z24scripting_class_get_nameP14ScriptingClass($459)|0);
      if ($460) {
       HEAP32[$$byval_copy57>>2] = $476;
       $vararg_ptr47 = (($$byval_copy57) + 4|0);
       HEAP32[$vararg_ptr47>>2] = $474;
       $vararg_ptr48 = (($$byval_copy57) + 8|0);
       HEAP32[$vararg_ptr48>>2] = $475;
       __Z6FormatPKcz($14,620224,$$byval_copy57);
       __THREW__ = 0;
       (invoke_iii(2233,($error|0),($14|0))|0);
       $477 = __THREW__; __THREW__ = 0;
       $478 = $477&1;
       if ($478) {
        $484 = ___cxa_find_matching_catch()|0;
        $485 = tempRet0;
        $486 = HEAP8[$14>>0]|0;
        $487 = $486 & 1;
        $488 = ($487<<24>>24)==(0);
        if ($488) {
         $$01 = $484;$$02 = $485;
         ___resumeException($$01|0);
         // unreachable;
        }
        $489 = (($14) + 8|0);
        $490 = HEAP32[$489>>2]|0;
        __ZdlPv($490);
        $$01 = $484;$$02 = $485;
        ___resumeException($$01|0);
        // unreachable;
       } else {
        $479 = HEAP8[$14>>0]|0;
        $480 = $479 & 1;
        $481 = ($480<<24>>24)==(0);
        if ($481) {
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
        $482 = (($14) + 8|0);
        $483 = HEAP32[$482>>2]|0;
        __ZdlPv($483);
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      } else {
       $491 = (__Z24scripting_class_get_nameP14ScriptingClass($458)|0);
       HEAP32[$$byval_copy57>>2] = $476;
       $vararg_ptr52 = (($$byval_copy57) + 4|0);
       HEAP32[$vararg_ptr52>>2] = $474;
       $vararg_ptr53 = (($$byval_copy57) + 8|0);
       HEAP32[$vararg_ptr53>>2] = $475;
       $vararg_ptr54 = (($$byval_copy57) + 12|0);
       HEAP32[$vararg_ptr54>>2] = $491;
       __Z6FormatPKcz($15,620304,$$byval_copy57);
       __THREW__ = 0;
       (invoke_iii(2233,($error|0),($15|0))|0);
       $492 = __THREW__; __THREW__ = 0;
       $493 = $492&1;
       if ($493) {
        $499 = ___cxa_find_matching_catch()|0;
        $500 = tempRet0;
        $501 = HEAP8[$15>>0]|0;
        $502 = $501 & 1;
        $503 = ($502<<24>>24)==(0);
        if ($503) {
         $$01 = $499;$$02 = $500;
         ___resumeException($$01|0);
         // unreachable;
        }
        $504 = (($15) + 8|0);
        $505 = HEAP32[$504>>2]|0;
        __ZdlPv($505);
        $$01 = $499;$$02 = $500;
        ___resumeException($$01|0);
        // unreachable;
       } else {
        $494 = HEAP8[$15>>0]|0;
        $495 = $494 & 1;
        $496 = ($495<<24>>24)==(0);
        if ($496) {
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
        $497 = (($15) + 8|0);
        $498 = HEAP32[$497>>2]|0;
        __ZdlPv($498);
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
     $506 = (__Z20RequiredComponentsOfP14ScriptingClass($klass)|0);
     $507 = ($506|0)==(0|0);
     if (!($507)) {
      $508 = (__Z21GetScriptingArraySizeP14ScriptingArray($506)|0);
      $509 = ($508|0)>(0);
      if ($509) {
       $510 = (($go) + 32|0);
       $511 = (($go) + 24|0);
       $j$0$i42 = 0;
       L296: while(1) {
        $512 = (__ZN9Scripting39GetScriptingArrayObjectElementNoRefImplEP14ScriptingArrayi($506,$j$0$i42)|0);
        $513 = ($512|0)==(0|0);
        L298: do {
         if (!($513)) {
          $514 = (__Z39scripting_class_from_systemtypeinstanceP15ScriptingObject($512)|0);
          $515 = ($514|0)==(0|0);
          do {
           if (!($515)) {
            $516 = HEAP32[$91>>2]|0;
            $517 = ($516|0)==(0);
            if ($517) {
             break;
            } else {
             $i$01$i$i = 0;
            }
            while(1) {
             $518 = HEAP32[$processed>>2]|0;
             $519 = ((($518) + ($i$01$i$i<<3)|0) + 4|0);
             $520 = HEAP32[$519>>2]|0;
             $521 = ($520|0)==(0|0);
             if ($521) {
              $522 = (__Z14GetMonoManagerv()|0);
              $523 = (($518) + ($i$01$i$i<<3)|0);
              $524 = HEAP32[$523>>2]|0;
              $525 = (__ZN16ScriptingManager23ClassIDToScriptingClassEi($522,$524)|0);
              $526 = ($525|0)==(0|0);
              if (!($526)) {
               $curKlass$0$i4$i$i = $525;
               label = 163;
              }
             } else {
              $curKlass$0$i4$i$i = $520;
              label = 163;
             }
             if ((label|0) == 163) {
              label = 0;
              $527 = ($curKlass$0$i4$i$i|0)==($514|0);
              if ($527) {
               break L298;
              }
              $528 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($curKlass$0$i4$i$i,$514)|0);
              if ($528) {
               break L298;
              }
             }
             $529 = (($i$01$i$i) + 1)|0;
             $530 = HEAP32[$91>>2]|0;
             $531 = ($529>>>0)<($530>>>0);
             if ($531) {
              $i$01$i$i = $529;
             } else {
              break;
             }
            }
           }
          } while(0);
          $532 = HEAP32[$510>>2]|0;
          $533 = ($532|0)>(0);
          if ($533) {
           $c$0$i41 = 0;
           while(1) {
            $534 = HEAP32[$511>>2]|0;
            $535 = ((($534) + ($c$0$i41<<3)|0) + 4|0);
            $536 = HEAP32[$535>>2]|0;
            $537 = (($536) + 8|0);
            $538 = HEAP32[$537>>2]|0;
            $539 = $538 >>> 21;
            $540 = ($536|0)==(0|0);
            do {
             if ($540) {
              label = 170;
             } else {
              $541 = HEAP32[560640>>2]|0;
              $542 = Math_imul($541, $539)|0;
              $543 = (($542) + 114)|0;
              $544 = $543 >> 5;
              $545 = $544 << 5;
              $546 = (($543) - ($545))|0;
              $547 = HEAP32[560632>>2]|0;
              $548 = (($547) + ($544<<2)|0);
              $549 = HEAP32[$548>>2]|0;
              $550 = 1 << $546;
              $551 = $550 & $549;
              $552 = ($551|0)==(0);
              if ($552) {
               label = 170;
               break;
              }
              $553 = (__ZNK13MonoBehaviour8GetClassEv($536)|0);
              $curKlass$0$i$i = $553;
             }
            } while(0);
            if ((label|0) == 170) {
             label = 0;
             $554 = (__Z14GetMonoManagerv()|0);
             $555 = (__ZN16ScriptingManager23ClassIDToScriptingClassEi($554,$539)|0);
             $curKlass$0$i$i = $555;
            }
            $556 = ($curKlass$0$i$i|0)==(0|0);
            $or$cond$i$i = $556 | $515;
            if (!($or$cond$i$i)) {
             $557 = ($curKlass$0$i$i|0)==($514|0);
             if ($557) {
              break L298;
             }
             $558 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($curKlass$0$i$i,$514)|0);
             if ($558) {
              break L298;
             }
            }
            $559 = (($c$0$i41) + 1)|0;
            $560 = HEAP32[$510>>2]|0;
            $561 = ($559|0)<($560|0);
            if ($561) {
             $c$0$i41 = $559;
            } else {
             break;
            }
           }
          }
          $562 = (__Z29scripting_class_get_namespaceP14ScriptingClass($514)|0);
          $563 = (__Z7StrICmpPKcS0_($562,618104)|0);
          $564 = ($563|0)==(0);
          do {
           if ($564) {
            $565 = (__Z24scripting_class_get_nameP14ScriptingClass($514)|0);
            $566 = (__ZN6Object15StringToClassIDEPKc($565)|0);
            $567 = ($566|0)==(-1);
            if ($567) {
             label = 178;
             break;
            }
            $568 = HEAP32[560640>>2]|0;
            $569 = Math_imul($568, $566)|0;
            $570 = (($569) + 2)|0;
            $571 = $570 >> 5;
            $572 = $571 << 5;
            $573 = (($570) - ($572))|0;
            $574 = HEAP32[560632>>2]|0;
            $575 = (($574) + ($571<<2)|0);
            $576 = HEAP32[$575>>2]|0;
            $577 = 1 << $573;
            $578 = $577 & $576;
            $579 = ($578|0)==(0);
            if ($579) {
             label = 178;
            } else {
             $clsID$1$i = $566;$requiredScript$0$i = 0;
            }
           } else {
            label = 178;
           }
          } while(0);
          if ((label|0) == 178) {
           label = 0;
           $580 = (__Z19GetScriptingManagerv()|0);
           $581 = (($580) + 24|0);
           $582 = (__ZN17MonoScriptManager17FindRuntimeScriptEP14ScriptingClass($581,$514)|0);
           $583 = ($582|0)==(0|0);
           if ($583) {
            break;
           } else {
            $clsID$1$i = 114;$requiredScript$0$i = $582;
           }
          }
          $584 = (__Z21CheckForAbstractClassRN5Unity10GameObjectEiPNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($go,$clsID$1$i,$error)|0);
          if (!($584)) {
           $$0 = 0;
           label = 191;
           break L296;
          }
          $585 = ($requiredScript$0$i|0)==(0|0);
          if ($585) {
           $587 = 0;
          } else {
           $586 = (__ZN10MonoScript8GetClassEv($requiredScript$0$i)|0);
           $587 = $586;
          }
          $588 = (__ZL30CollectComponentsWithoutAddingRN5Unity10GameObjectEiP14ScriptingClassR13dynamic_arrayI16AddComponentDataLj4EES7_PNSt3__112basic_stringIcNS8_11char_traitsIcEENS8_9allocatorIcEEEE($go,$clsID$1$i,$587,$components,$processed,$error)|0);
          if (!($588)) {
           $$0 = 0;
           label = 191;
           break L296;
          }
         }
        } while(0);
        $589 = (($j$0$i42) + 1)|0;
        $590 = (__Z21GetScriptingArraySizeP14ScriptingArray($506)|0);
        $591 = ($589|0)<($590|0);
        if ($591) {
         $j$0$i42 = $589;
        } else {
         break L156;
        }
       }
       if ((label|0) == 191) {
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   } while(0);
   $592 = (($components) + 8|0);
   $593 = HEAP32[$592>>2]|0;
   $594 = (($593) + 1)|0;
   HEAP32[$592>>2] = $594;
   $595 = (($components) + 12|0);
   $596 = HEAP32[$595>>2]|0;
   $597 = $596 & 2147483647;
   $598 = ($594>>>0)>($597>>>0);
   if ($598) {
    $599 = $596 << 1;
    $600 = ($599|0)==(0);
    $601 = $600 ? 1 : $599;
    $602 = ($597>>>0)<($601>>>0);
    do {
     if ($602) {
      $603 = ($596|0)>(-1);
      if ($603) {
       HEAP32[$595>>2] = $601;
       $604 = HEAP32[$components>>2]|0;
       $605 = $601 << 3;
       $606 = (($components) + 4|0);
       $607 = HEAP32[$606>>2]|0;
       HEAP32[$0>>2] = $607;
       ;HEAP32[$$byval_copy57+0>>2]=HEAP32[$0+0>>2]|0;
       $608 = (__Z16realloc_internalPvji10MemLabelIdiPKci($604,$605,4,$$byval_copy57,0,618440,370)|0);
       HEAP32[$components>>2] = $608;
       break;
      } else {
       $609 = $601 << 3;
       $610 = (($components) + 4|0);
       $611 = HEAP32[$610>>2]|0;
       HEAP32[$0>>2] = $611;
       ;HEAP32[$$byval_copy57+0>>2]=HEAP32[$0+0>>2]|0;
       $612 = (__Z15malloc_internaljj10MemLabelIdiPKci($609,4,$$byval_copy57,0,618440,352)|0);
       $613 = HEAP32[$components>>2]|0;
       $614 = HEAP32[$592>>2]|0;
       $615 = $614 << 3;
       _memcpy(($612|0),($613|0),($615|0))|0;
       HEAP32[$595>>2] = $601;
       HEAP32[$components>>2] = $612;
       break;
      }
     }
    } while(0);
    $$pre$i$i = HEAP32[$592>>2]|0;
    $617 = $$pre$i$i;
   } else {
    $617 = $594;
   }
   $616 = (($617) + -1)|0;
   $618 = HEAP32[$components>>2]|0;
   $619 = (($618) + ($616<<3)|0);
   $620 = $619;
   $621 = $620;
   HEAP32[$621>>2] = $classID;
   $622 = (($620) + 4)|0;
   $623 = $622;
   HEAP32[$623>>2] = $281;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $162 = ($error|0)==(0|0);
 if ($162) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $163 = (__ZN6Object15ClassIDToStringEi($classID)|0);
 $164 = HEAP8[$163>>0]|0;
 $165 = $164 & 1;
 $166 = ($165<<24>>24)==(0);
 if ($166) {
  $169 = (($163) + 1|0);
  $174 = $169;
 } else {
  $167 = (($163) + 8|0);
  $168 = HEAP32[$167>>2]|0;
  $174 = $168;
 }
 $170 = HEAP32[$go>>2]|0;
 $171 = (($170) + 32|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = (FUNCTION_TABLE_ii[$172 & 4095]($go)|0);
 HEAP32[$$byval_copy57>>2] = $174;
 $vararg_ptr14 = (($$byval_copy57) + 4|0);
 HEAP32[$vararg_ptr14>>2] = $173;
 __Z6FormatPKcz($11,619872,$$byval_copy57);
 __THREW__ = 0;
 (invoke_iii(2233,($error|0),($11|0))|0);
 $175 = __THREW__; __THREW__ = 0;
 $176 = $175&1;
 if ($176) {
  $182 = ___cxa_find_matching_catch()|0;
  $183 = tempRet0;
  $184 = HEAP8[$11>>0]|0;
  $185 = $184 & 1;
  $186 = ($185<<24>>24)==(0);
  if ($186) {
   $$01 = $182;$$02 = $183;
   ___resumeException($$01|0);
   // unreachable;
  }
  $187 = (($11) + 8|0);
  $188 = HEAP32[$187>>2]|0;
  __ZdlPv($188);
  $$01 = $182;$$02 = $183;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $177 = HEAP8[$11>>0]|0;
  $178 = $177 & 1;
  $179 = ($178<<24>>24)==(0);
  if ($179) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $180 = (($11) + 8|0);
  $181 = HEAP32[$180>>2]|0;
  __ZdlPv($181);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z12AddComponentRN5Unity10GameObjectEiP14ScriptingClassPNSt3__112basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE($go,$classID,$klass,$error) {
 $go = $go|0;
 $classID = $classID|0;
 $klass = $klass|0;
 $error = $error|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $components = 0, $i$021 = 0;
 var $processed = 0, $script$0$i = 0, $tempError = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 60|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $components = sp + 16|0;
 $processed = sp + 32|0;
 $tempError = sp + 48|0;
 $3 = HEAP32[628512>>2]|0;
 HEAP32[$components>>2] = 0;
 $4 = (($components) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($components) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($components) + 12|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$processed>>2] = 0;
 $7 = (($processed) + 4|0);
 HEAP32[$7>>2] = $3;
 $8 = (($processed) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($processed) + 12|0);
 HEAP32[$9>>2] = 0;
 __THREW__ = 0;
 $10 = (invoke_iiiiiii(104,($go|0),($classID|0),($klass|0),($components|0),($processed|0),($error|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   $15 = ___cxa_find_matching_catch()|0;
   $16 = tempRet0;
   $$01 = $16;$$02 = $15;
   label = 31;
  } else {
   L4: do {
    if ($10) {
     $17 = HEAP32[$5>>2]|0;
     $18 = ($17|0)==(0);
     if ($18) {
      $$0 = 0;
     } else {
      $19 = (($tempError) + 8|0);
      $20 = (($tempError) + 1|0);
      $21 = (($tempError) + 4|0);
      $i$021 = 0;
      while(1) {
       ;HEAP32[$tempError+0>>2]=0|0;HEAP32[$tempError+4>>2]=0|0;HEAP32[$tempError+8>>2]=0|0;
       $22 = HEAP32[$components>>2]|0;
       $23 = (($22) + ($i$021<<3)|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ((($22) + ($i$021<<3)|0) + 4|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = ($26|0)==(0|0);
       if ($27) {
        $script$0$i = 0;
       } else {
        __THREW__ = 0;
        $28 = (invoke_i(84)|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break;
        }
        $31 = (($28) + 24|0);
        __THREW__ = 0;
        $32 = (invoke_iii(2420,($31|0),($26|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break;
        } else {
         $script$0$i = $32;
        }
       }
       __THREW__ = 0;
       $35 = (invoke_iiiiii(200,($go|0),($24|0),($26|0),($script$0$i|0),($tempError|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
       $38 = HEAP8[$tempError>>0]|0;
       $39 = $38 & 1;
       $40 = ($39<<24>>24)==(0);
       if ($40) {
        $42 = $38&255;
        $43 = $42 >>> 1;
        $45 = $43;
       } else {
        $41 = HEAP32[$21>>2]|0;
        $45 = $41;
       }
       $44 = ($45|0)==(0);
       if ($44) {
        $61 = $38;
       } else {
        if ($40) {
         $48 = $38&255;
         $49 = $48 >>> 1;
         $50 = $20;$51 = $49;
        } else {
         $46 = HEAP32[$19>>2]|0;
         $47 = HEAP32[$21>>2]|0;
         $50 = $46;$51 = $47;
        }
        __THREW__ = 0;
        (invoke_iiii(1480,($error|0),($50|0),($51|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        $$pre = HEAP8[$tempError>>0]|0;
        $61 = $$pre;
       }
       $60 = $61 & 1;
       $62 = ($60<<24>>24)==(0);
       if (!($62)) {
        $63 = HEAP32[$19>>2]|0;
        __ZdlPv($63);
       }
       $64 = (($i$021) + 1)|0;
       $65 = HEAP32[$5>>2]|0;
       $66 = ($64>>>0)<($65>>>0);
       if ($66) {
        $i$021 = $64;
       } else {
        $$0 = $35;
        break L4;
       }
      }
      $54 = ___cxa_find_matching_catch()|0;
      $55 = tempRet0;
      $56 = HEAP8[$tempError>>0]|0;
      $57 = $56 & 1;
      $58 = ($57<<24>>24)==(0);
      if ($58) {
       $$01 = $55;$$02 = $54;
       label = 31;
       break L1;
      }
      $59 = HEAP32[$19>>2]|0;
      __ZdlPv($59);
      $$01 = $55;$$02 = $54;
      label = 31;
      break L1;
     }
    } else {
     $$0 = 0;
    }
   } while(0);
   $67 = HEAP32[$9>>2]|0;
   $68 = ($67|0)>(-1);
   do {
    if ($68) {
     $69 = HEAP32[$processed>>2]|0;
     $70 = HEAP32[$7>>2]|0;
     HEAP32[$0>>2] = $70;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($69|0),($$byval_copy3|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      $13 = ___cxa_find_matching_catch()|0;
      $14 = tempRet0;
      $$1 = $14;$$13 = $13;
      break L1;
     } else {
      HEAP32[$processed>>2] = 0;
      break;
     }
    }
   } while(0);
   $73 = HEAP32[$6>>2]|0;
   $74 = ($73|0)>(-1);
   if (!($74)) {
    STACKTOP = sp;return ($$0|0);
   }
   $75 = HEAP32[$components>>2]|0;
   $76 = HEAP32[$4>>2]|0;
   HEAP32[$0>>2] = $76;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($75,$$byval_copy3);
   HEAP32[$components>>2] = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 do {
  if ((label|0) == 31) {
   $77 = HEAP32[$9>>2]|0;
   $78 = ($77|0)>(-1);
   if ($78) {
    $79 = HEAP32[$processed>>2]|0;
    $80 = HEAP32[$7>>2]|0;
    HEAP32[$1>>2] = $80;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($79|0),($$byval_copy3|0));
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     $89 = ___cxa_find_matching_catch(0|0)|0;
     $90 = tempRet0;
     ___clang_call_terminate($89);
     // unreachable;
    } else {
     HEAP32[$processed>>2] = 0;
     $$1 = $$01;$$13 = $$02;
     break;
    }
   } else {
    $$1 = $$01;$$13 = $$02;
   }
  }
 } while(0);
 $83 = HEAP32[$6>>2]|0;
 $84 = ($83|0)>(-1);
 if (!($84)) {
  ___resumeException($$13|0);
  // unreachable;
 }
 $85 = HEAP32[$components>>2]|0;
 $86 = HEAP32[$4>>2]|0;
 HEAP32[$2>>2] = $86;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($85|0),($$byval_copy3|0));
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if ($88) {
  $89 = ___cxa_find_matching_catch(0|0)|0;
  $90 = tempRet0;
  ___clang_call_terminate($89);
  // unreachable;
 }
 HEAP32[$components>>2] = 0;
 ___resumeException($$13|0);
 // unreachable;
 return 0|0;
}
function __Z12AddComponentRN5Unity10GameObjectEPKcPNSt3__112basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE($go,$name,$error) {
 $go = $go|0;
 $name = $name|0;
 $error = $error|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$name = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__p$0$i$i$i = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer1 = sp;
 $0 = sp + 28|0;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = (__Z10BeginsWithPKcS0_($name,618304)|0);
 $4 = (($name) + 12|0);
 $$name = $3 ? $4 : $name;
 $5 = (__ZN6Object15StringToClassIDEPKc($$name)|0);
 $6 = ($5|0)==(-1);
 if (!($6)) {
  $7 = HEAP32[560640>>2]|0;
  $8 = Math_imul($7, $5)|0;
  $9 = (($8) + 2)|0;
  $10 = $9 >> 5;
  $11 = $10 << 5;
  $12 = (($9) - ($11))|0;
  $13 = HEAP32[560632>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = 1 << $12;
  $17 = $16 & $15;
  $18 = ($17|0)==(0);
  if (!($18)) {
   $19 = (__Z12AddComponentRN5Unity10GameObjectEiP14ScriptingClassPNSt3__112basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE($go,$5,0,$error)|0);
   $$02 = $19;
   STACKTOP = sp;return ($$02|0);
  }
 }
 $20 = (__Z19GetScriptingManagerv()|0);
 $21 = (($20) + 24|0);
 $22 = (_strlen(($$name|0))|0);
 $23 = ($22>>>0)>(4294967279);
 if ($23) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $24 = ($22>>>0)<(11);
 if ($24) {
  $25 = $22 << 1;
  $26 = $25&255;
  HEAP8[$0>>0] = $26;
  $27 = (($0) + 1|0);
  $__p$0$i$i$i = $27;
 } else {
  $28 = (($22) + 16)|0;
  $29 = $28 & -16;
  $30 = (__Znwj($29)|0);
  $31 = (($0) + 8|0);
  HEAP32[$31>>2] = $30;
  $32 = $29 | 1;
  HEAP32[$0>>2] = $32;
  $33 = (($0) + 4|0);
  HEAP32[$33>>2] = $22;
  $__p$0$i$i$i = $30;
 }
 _memcpy(($__p$0$i$i$i|0),($$name|0),($22|0))|0;
 $34 = (($__p$0$i$i$i) + ($22)|0);
 HEAP8[$34>>0] = 0;
 __THREW__ = 0;
 $35 = (invoke_iii(2421,($21|0),($0|0))|0);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $48 = HEAP8[$0>>0]|0;
  $49 = $48 & 1;
  $50 = ($49<<24>>24)==(0);
  if ($50) {
   $$0 = $47;$$01 = $46;
   ___resumeException($$01|0);
   // unreachable;
  }
  $51 = (($0) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  __ZdlPv($52);
  $$0 = $47;$$01 = $46;
  ___resumeException($$01|0);
  // unreachable;
 }
 $38 = HEAP8[$0>>0]|0;
 $39 = $38 & 1;
 $40 = ($39<<24>>24)==(0);
 if (!($40)) {
  $41 = (($0) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  __ZdlPv($42);
 }
 $43 = ($35|0)==(0|0);
 if (!($43)) {
  $44 = (__ZN10MonoScript8GetClassEv($35)|0);
  $45 = (__Z12AddComponentRN5Unity10GameObjectEiP14ScriptingClassPNSt3__112basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE($go,114,$44,$error)|0);
  $$02 = $45;
  STACKTOP = sp;return ($$02|0);
 }
 $53 = ($error|0)==(0|0);
 if ($53) {
  $$02 = 0;
  STACKTOP = sp;return ($$02|0);
 }
 if ($6) {
  HEAP32[$vararg_buffer1>>2] = $$name;
  __Z6FormatPKcz($1,618320,$vararg_buffer1);
  __THREW__ = 0;
  (invoke_iii(2233,($error|0),($1|0))|0);
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if ($55) {
   $61 = ___cxa_find_matching_catch()|0;
   $62 = tempRet0;
   $63 = HEAP8[$1>>0]|0;
   $64 = $63 & 1;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    $$0 = $62;$$01 = $61;
    ___resumeException($$01|0);
    // unreachable;
   }
   $66 = (($1) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   __ZdlPv($67);
   $$0 = $62;$$01 = $61;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $56 = HEAP8[$1>>0]|0;
   $57 = $56 & 1;
   $58 = ($57<<24>>24)==(0);
   if ($58) {
    $$02 = 0;
    STACKTOP = sp;return ($$02|0);
   }
   $59 = (($1) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   __ZdlPv($60);
   $$02 = 0;
   STACKTOP = sp;return ($$02|0);
  }
 } else {
  HEAP32[$vararg_buffer1>>2] = $$name;
  __Z6FormatPKcz($2,618376,$vararg_buffer1);
  __THREW__ = 0;
  (invoke_iii(2233,($error|0),($2|0))|0);
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   $75 = ___cxa_find_matching_catch()|0;
   $76 = tempRet0;
   $77 = HEAP8[$2>>0]|0;
   $78 = $77 & 1;
   $79 = ($78<<24>>24)==(0);
   if ($79) {
    $$0 = $76;$$01 = $75;
    ___resumeException($$01|0);
    // unreachable;
   }
   $80 = (($2) + 8|0);
   $81 = HEAP32[$80>>2]|0;
   __ZdlPv($81);
   $$0 = $76;$$01 = $75;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $70 = HEAP8[$2>>0]|0;
   $71 = $70 & 1;
   $72 = ($71<<24>>24)==(0);
   if ($72) {
    $$02 = 0;
    STACKTOP = sp;return ($$02|0);
   }
   $73 = (($2) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   __ZdlPv($74);
   $$02 = 0;
   STACKTOP = sp;return ($$02|0);
  }
 }
 return 0|0;
}
function __Z23AddComponentsFromVAListRN5Unity10GameObjectEPKcPi($go,$componentName,$componentList) {
 $go = $go|0;
 $componentName = $componentName|0;
 $componentList = $componentList|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arglist_current = 0, $arglist_current7 = 0, $arglist_next = 0, $arglist_next8 = 0, $error = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = ($componentName|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$error+0>>2]=0|0;HEAP32[$error+4>>2]=0|0;HEAP32[$error+8>>2]=0|0;
 __THREW__ = 0;
 $1 = (invoke_iiii(1552,($go|0),($componentName|0),($error|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L4: do {
  if ($3) {
   label = 11;
  } else {
   $4 = ($1|0)==(0|0);
   if ($4) {
    $5 = HEAP8[$error>>0]|0;
    $6 = $5 & 1;
    $7 = ($6<<24>>24)==(0);
    if ($7) {
     $10 = (($error) + 1|0);
     $11 = $10;
    } else {
     $8 = (($error) + 8|0);
     $9 = HEAP32[$8>>2]|0;
     $11 = $9;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($11|0),0,(618440|0),675,1,0,0,(0|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 11;
     break;
    }
   }
   $arglist_current = HEAP32[$componentList>>2]|0;
   $14 = HEAP32[$arglist_current>>2]|0;
   $arglist_next = (($arglist_current) + 4|0);
   HEAP32[$componentList>>2] = $arglist_next;
   $15 = ($14|0)==(0|0);
   L13: do {
    if (!($15)) {
     $16 = (($error) + 1|0);
     $17 = (($error) + 8|0);
     $27 = $14;
     while(1) {
      __THREW__ = 0;
      $28 = (invoke_iiii(1552,($go|0),($27|0),($error|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = ($28|0)==(0|0);
      if ($31) {
       $34 = HEAP8[$error>>0]|0;
       $35 = $34 & 1;
       $36 = ($35<<24>>24)==(0);
       $37 = HEAP32[$17>>2]|0;
       $$ = $36 ? $16 : $37;
       __THREW__ = 0;
       invoke_viiiiiiii(21,($$|0),0,(618440|0),683,1,0,0,(0|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
      }
      $arglist_current7 = HEAP32[$componentList>>2]|0;
      $32 = HEAP32[$arglist_current7>>2]|0;
      $arglist_next8 = (($arglist_current7) + 4|0);
      HEAP32[$componentList>>2] = $arglist_next8;
      $33 = ($32|0)==(0|0);
      if ($33) {
       break L13;
      } else {
       $27 = $32;
      }
     }
     $18 = ___cxa_find_matching_catch()|0;
     $19 = tempRet0;
     $lpad$phi$index = $18;$lpad$phi$index2 = $19;
     break L4;
    }
   } while(0);
   $40 = HEAP8[$error>>0]|0;
   $41 = $40 & 1;
   $42 = ($41<<24>>24)==(0);
   if ($42) {
    STACKTOP = sp;return;
   }
   $43 = (($error) + 8|0);
   $44 = HEAP32[$43>>2]|0;
   __ZdlPv($44);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 11) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $lpad$phi$index = $20;$lpad$phi$index2 = $21;
 }
 $22 = HEAP8[$error>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $25 = (($error) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 __ZdlPv($26);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z16CreateGameObjectRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKcz($name,$componentName,$varargs) {
 $name = $name|0;
 $componentName = $componentName|0;
 $varargs = $varargs|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $ap = sp + 8|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(72,$$byval_copy2,1,16,618440,713)|0);
 $4 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1629,($3|0),($$byval_copy2|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(618440|0),713);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   $28 = ___cxa_find_matching_catch(0|0)|0;
   $29 = tempRet0;
   ___clang_call_terminate($28);
   // unreachable;
  } else {
   ___resumeException($24|0);
   // unreachable;
  }
 }
 $7 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vi[$10 & 4095]($7);
 $11 = HEAP32[$7>>2]|0;
 $12 = (($11) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP8[$name>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $19 = (($name) + 1|0);
  $20 = $19;
 } else {
  $17 = (($name) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $20 = $18;
 }
 FUNCTION_TABLE_vii[$13 & 4095]($7,$20);
 $21 = HEAP32[$7>>2]|0;
 $22 = (($21) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vii[$23 & 4095]($7,4);
 __ZN5Unity10GameObject8ActivateEv($7);
 HEAP32[$ap>>2] = $varargs;
 __Z23AddComponentsFromVAListRN5Unity10GameObjectEPKcPi($7,$componentName,$ap);
 STACKTOP = sp;return ($7|0);
}
function __Z29CreateGameObjectWithHideFlagsRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbiPKcz($name,$isActive,$flags,$componentName,$varargs) {
 $name = $name|0;
 $isActive = $isActive|0;
 $flags = $flags|0;
 $componentName = $componentName|0;
 $varargs = $varargs|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $ap = sp + 8|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(72,$$byval_copy2,1,16,618440,743)|0);
 $4 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1629,($3|0),($$byval_copy2|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(618440|0),743);
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   $38 = ___cxa_find_matching_catch(0|0)|0;
   $39 = tempRet0;
   ___clang_call_terminate($38);
   // unreachable;
  } else {
   ___resumeException($27|0);
   // unreachable;
  }
 }
 $7 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 4095]($7,$flags);
 $11 = HEAP32[$7>>2]|0;
 $12 = (($11) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vi[$13 & 4095]($7);
 $14 = HEAP32[$7>>2]|0;
 $15 = (($14) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP8[$name>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($isActive) {
  if ($19) {
   $22 = (($name) + 1|0);
   $23 = $22;
  } else {
   $20 = (($name) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $23 = $21;
  }
  FUNCTION_TABLE_vii[$16 & 4095]($7,$23);
  $24 = HEAP32[$7>>2]|0;
  $25 = (($24) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  FUNCTION_TABLE_vii[$26 & 4095]($7,4);
  __ZN5Unity10GameObject8ActivateEv($7);
  HEAP32[$ap>>2] = $varargs;
  __Z23AddComponentsFromVAListRN5Unity10GameObjectEPKcPi($7,$componentName,$ap);
  STACKTOP = sp;return ($7|0);
 } else {
  if ($19) {
   $33 = (($name) + 1|0);
   $34 = $33;
  } else {
   $31 = (($name) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   $34 = $32;
  }
  FUNCTION_TABLE_vii[$16 & 4095]($7,$34);
  $35 = HEAP32[$7>>2]|0;
  $36 = (($35) + 12|0);
  $37 = HEAP32[$36>>2]|0;
  FUNCTION_TABLE_vii[$37 & 4095]($7,4);
  HEAP32[$ap>>2] = $varargs;
  __Z23AddComponentsFromVAListRN5Unity10GameObjectEPKcPi($7,$componentName,$ap);
  STACKTOP = sp;return ($7|0);
 }
 return 0|0;
}
function __Z19CanReplaceComponentRN5Unity9ComponentEiPNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($component,$replacementClassID,$error) {
 $component = $component|0;
 $replacementClassID = $replacementClassID|0;
 $error = $error|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $countSameComponentType$017 = 0, $countSameComponentType$1 = 0, $i$019 = 0, $mayRemove$0$off018 = 0, $mayRemove$1$off0 = 0, $or$cond = 0, $or$cond6 = 0;
 var $or$cond6$sink = 0, $or$cond7 = 0, $phitmp = 0, $removeKlass$0 = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer1 = sp;
 $0 = sp + 32|0;
 $1 = sp + 8|0;
 $2 = sp + 20|0;
 $3 = (($component) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__ZN5Unity10GameObject17GetComponentIndexEPNS_9ComponentE($4,$component)|0);
 $7 = ($6|0)==(-1);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($component) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 >>> 21;
 $11 = ($10|0)==(4);
 if ($11) {
  $12 = ($error|0)==(0|0);
  if ($12) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $13 = HEAP32[$4>>2]|0;
  $14 = (($13) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_ii[$15 & 4095]($4)|0);
  HEAP32[$vararg_buffer1>>2] = $16;
  __Z6FormatPKcz($0,618448,$vararg_buffer1);
  __THREW__ = 0;
  (invoke_iii(2233,($error|0),($0|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $26 = HEAP8[$0>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    $$1 = $24;$$13 = $25;
    ___resumeException($$1|0);
    // unreachable;
   }
   $29 = (($0) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   __ZdlPv($30);
   $$1 = $24;$$13 = $25;
   ___resumeException($$1|0);
   // unreachable;
  } else {
   $19 = HEAP8[$0>>0]|0;
   $20 = $19 & 1;
   $21 = ($20<<24>>24)==(0);
   if ($21) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $22 = (($0) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   __ZdlPv($23);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $31 = ($component|0)==(0|0);
 if ($31) {
  $removeKlass$0 = 0;
 } else {
  $32 = HEAP32[560640>>2]|0;
  $33 = Math_imul($32, $10)|0;
  $34 = (($33) + 114)|0;
  $35 = $34 >> 5;
  $36 = $35 << 5;
  $37 = (($34) - ($36))|0;
  $38 = HEAP32[560632>>2]|0;
  $39 = (($38) + ($35<<2)|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = 1 << $37;
  $42 = $41 & $40;
  $43 = ($42|0)==(0);
  if ($43) {
   $removeKlass$0 = 0;
  } else {
   $44 = (__ZNK13MonoBehaviour8GetClassEv($component)|0);
   $removeKlass$0 = $44;
  }
 }
 $45 = (($4) + 32|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)>(0);
 do {
  if ($47) {
   $49 = (($4) + 24|0);
   $50 = ($error|0)==(0|0);
   $countSameComponentType$017 = 0;$i$019 = 0;$mayRemove$0$off018 = 1;
   while(1) {
    $51 = HEAP32[$49>>2]|0;
    $52 = (($51) + ($i$019<<3)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (__Z34FindRequiredComponentsForComponenti($53)|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($54) + 4|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = $57;
    $59 = $55;
    $60 = (($58) - ($59))|0;
    $61 = $60 >> 2;
    $62 = ($61|0)==(0);
    if ($62) {
     $72 = $55;
    } else {
     $65 = $55;$__len$03$i$i$i$i$i = $61;
     while(1) {
      $63 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
      $64 = (($65) + ($63<<2)|0);
      $66 = HEAP32[$64>>2]|0;
      $67 = ($66|0)<($10|0);
      if ($67) {
       $$sum$i$i$i$i$i = (($63) + 1)|0;
       $68 = (($65) + ($$sum$i$i$i$i$i<<2)|0);
       $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
       $69 = (($$neg2$i$i$i$i$i) - ($63))|0;
       $143 = $68;$__len$0$be$i$i$i$i$i = $69;
      } else {
       $143 = $65;$__len$0$be$i$i$i$i$i = $63;
      }
      $70 = ($__len$0$be$i$i$i$i$i|0)==(0);
      if ($70) {
       $72 = $143;
       break;
      } else {
       $65 = $143;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
      }
     }
    }
    $71 = ($72|0)==($57|0);
    if ($71) {
     $mayRemove$1$off0 = $mayRemove$0$off018;
    } else {
     $73 = HEAP32[$72>>2]|0;
     $74 = ($10|0)<($73|0);
     $or$cond = $50 | $74;
     if ($or$cond) {
      $mayRemove$1$off0 = $mayRemove$0$off018;
     } else {
      if (!($mayRemove$0$off018)) {
       (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($error,618632,2)|0);
      }
      $75 = (__ZN6Object15ClassIDToStringEi($53)|0);
      $76 = HEAP8[$75>>0]|0;
      $77 = $76 & 1;
      $78 = ($77<<24>>24)==(0);
      if ($78) {
       $83 = (($75) + 1|0);
       $84 = $76&255;
       $85 = $84 >>> 1;
       $86 = $83;$87 = $85;
      } else {
       $79 = (($75) + 8|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = (($75) + 4|0);
       $82 = HEAP32[$81>>2]|0;
       $86 = $80;$87 = $82;
      }
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($error,$86,$87)|0);
      $mayRemove$1$off0 = 0;
     }
    }
    $88 = ($53|0)==(114);
    if ($88) {
     $89 = HEAP32[$49>>2]|0;
     $90 = ((($89) + ($i$019<<3)|0) + 4|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = (__ZNK13MonoBehaviour8GetClassEv($91)|0);
     $93 = ($92|0)!=(0|0);
     $94 = ($removeKlass$0|0)==($92|0);
     $or$cond6 = $93 & $94;
     $or$cond6$sink = $or$cond6;
    } else {
     $95 = ($53|0)==($10|0);
     $or$cond6$sink = $95;
    }
    $96 = $or$cond6$sink&1;
    $countSameComponentType$1 = (($96) + ($countSameComponentType$017))|0;
    $97 = (($i$019) + 1)|0;
    $98 = HEAP32[$45>>2]|0;
    $99 = ($97|0)<($98|0);
    if ($99) {
     $countSameComponentType$017 = $countSameComponentType$1;$i$019 = $97;$mayRemove$0$off018 = $mayRemove$1$off0;
    } else {
     break;
    }
   }
   $phitmp = ($countSameComponentType$1|0)>(1);
   $or$cond7 = $mayRemove$1$off0 | $phitmp;
   $100 = ($error|0)==(0|0);
   if ($or$cond7) {
    if ($100) {
     $$0 = 1;
    } else {
     break;
    }
    STACKTOP = sp;return ($$0|0);
   }
   if ($100) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   __Z24GetComponentOrScriptNameRN5Unity9ComponentE($2,$component);
   $101 = HEAP8[$2>>0]|0;
   $102 = $101 & 1;
   $103 = ($102<<24>>24)==(0);
   if ($103) {
    $106 = (($2) + 1|0);
    $113 = $106;
   } else {
    $104 = (($2) + 8|0);
    $105 = HEAP32[$104>>2]|0;
    $113 = $105;
   }
   $107 = HEAP8[$error>>0]|0;
   $108 = $107 & 1;
   $109 = ($108<<24>>24)==(0);
   if ($109) {
    $112 = (($error) + 1|0);
    $114 = $112;
   } else {
    $110 = (($error) + 8|0);
    $111 = HEAP32[$110>>2]|0;
    $114 = $111;
   }
   __THREW__ = 0;
   HEAP32[$vararg_buffer1>>2] = $113;
   $vararg_ptr4 = (($vararg_buffer1) + 4|0);
   HEAP32[$vararg_ptr4>>2] = $114;
   invoke_viii(1617,($1|0),(618640|0),($vararg_buffer1|0));
   $115 = __THREW__; __THREW__ = 0;
   $116 = $115&1;
   do {
    if ($116) {
     $129 = ___cxa_find_matching_catch()|0;
     $130 = tempRet0;
     $$01 = $129;$$02 = $130;
    } else {
     __THREW__ = 0;
     (invoke_iii(2233,($error|0),($1|0))|0);
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      $131 = ___cxa_find_matching_catch()|0;
      $132 = tempRet0;
      $133 = HEAP8[$1>>0]|0;
      $134 = $133 & 1;
      $135 = ($134<<24>>24)==(0);
      if ($135) {
       $$01 = $131;$$02 = $132;
       break;
      }
      $136 = (($1) + 8|0);
      $137 = HEAP32[$136>>2]|0;
      __ZdlPv($137);
      $$01 = $131;$$02 = $132;
      break;
     }
     $119 = HEAP8[$1>>0]|0;
     $120 = $119 & 1;
     $121 = ($120<<24>>24)==(0);
     if (!($121)) {
      $122 = (($1) + 8|0);
      $123 = HEAP32[$122>>2]|0;
      __ZdlPv($123);
     }
     $124 = HEAP8[$2>>0]|0;
     $125 = $124 & 1;
     $126 = ($125<<24>>24)==(0);
     if ($126) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $127 = (($2) + 8|0);
     $128 = HEAP32[$127>>2]|0;
     __ZdlPv($128);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $138 = HEAP8[$2>>0]|0;
   $139 = $138 & 1;
   $140 = ($139<<24>>24)==(0);
   if ($140) {
    $$1 = $$01;$$13 = $$02;
    ___resumeException($$1|0);
    // unreachable;
   }
   $141 = (($2) + 8|0);
   $142 = HEAP32[$141>>2]|0;
   __ZdlPv($142);
   $$1 = $$01;$$13 = $$02;
   ___resumeException($$1|0);
   // unreachable;
  } else {
   $48 = ($error|0)==(0|0);
   if ($48) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($error,618440)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z24GetComponentOrScriptNameRN5Unity9ComponentE($agg$result,$com) {
 $agg$result = $agg$result|0;
 $com = $com|0;
 var $$0 = 0, $$01 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = ($com|0)==(0|0);
 if (!($3)) {
  $4 = (($com) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 >>> 21;
  $7 = HEAP32[560640>>2]|0;
  $8 = Math_imul($7, $6)|0;
  $9 = (($8) + 114)|0;
  $10 = $9 >> 5;
  $11 = $10 << 5;
  $12 = (($9) - ($11))|0;
  $13 = HEAP32[560632>>2]|0;
  $14 = (($13) + ($10<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = 1 << $12;
  $17 = $16 & $15;
  $18 = ($17|0)==(0);
  if (!($18)) {
   __ZN13MonoBehaviour18GetScriptClassNameEv($2,$com);
   $19 = HEAP8[$2>>0]|0;
   $20 = $19 & 1;
   $21 = ($20<<24>>24)==(0);
   if ($21) {
    $22 = (($2) + 1|0);
    $23 = $19&255;
    $24 = $23 >>> 1;
    $33 = $24;$45 = $22;
    label = 8;
   } else {
    $25 = (($2) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($2) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28>>>0)>(4294967279);
    if ($29) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 18;
     } else {
      // unreachable;
     }
    } else {
     $33 = $28;$45 = $26;
     label = 8;
    }
   }
   do {
    if ((label|0) == 8) {
     $32 = ($33>>>0)<(11);
     if ($32) {
      $34 = $33 << 1;
      $35 = $34&255;
      HEAP8[$1>>0] = $35;
      $36 = (($1) + 1|0);
      $__p$0$i$i$i$i = $36;
     } else {
      $37 = (($33) + 16)|0;
      $38 = $37 & -16;
      __THREW__ = 0;
      $39 = (invoke_ii(2988,($38|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 18;
       break;
      }
      $42 = (($1) + 8|0);
      HEAP32[$42>>2] = $39;
      $43 = $38 | 1;
      HEAP32[$1>>2] = $43;
      $44 = (($1) + 4|0);
      HEAP32[$44>>2] = $33;
      $__p$0$i$i$i$i = $39;
     }
     _memcpy(($__p$0$i$i$i$i|0),($45|0),($33|0))|0;
     $46 = (($__p$0$i$i$i$i) + ($33)|0);
     HEAP8[$46>>0] = 0;
     __THREW__ = 0;
     invoke_viii(1780,($agg$result|0),($1|0),(619672|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      $67 = HEAP8[$1>>0]|0;
      $68 = $67 & 1;
      $69 = ($68<<24>>24)==(0);
      if ($69) {
       $$0 = $66;$$01 = $65;
       break;
      }
      $70 = (($1) + 8|0);
      $71 = HEAP32[$70>>2]|0;
      __ZdlPv($71);
      $$0 = $66;$$01 = $65;
      break;
     }
     $49 = HEAP8[$1>>0]|0;
     $50 = $49 & 1;
     $51 = ($50<<24>>24)==(0);
     if (!($51)) {
      $52 = (($1) + 8|0);
      $53 = HEAP32[$52>>2]|0;
      __ZdlPv($53);
     }
     $54 = HEAP8[$2>>0]|0;
     $55 = $54 & 1;
     $56 = ($55<<24>>24)==(0);
     if ($56) {
      STACKTOP = sp;return;
     }
     $57 = (($2) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($58|0),($$byval_copy1|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      $61 = ___cxa_find_matching_catch()|0;
      $62 = tempRet0;
      ___cxa_call_unexpected(($61|0));
      // unreachable;
     } else {
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 18) {
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    $$0 = $64;$$01 = $63;
   }
   $72 = HEAP8[$2>>0]|0;
   $73 = $72 & 1;
   $74 = ($73<<24>>24)==(0);
   if ($74) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $75 = (($2) + 8|0);
   $76 = HEAP32[$75>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($76|0),($$byval_copy1|0));
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    $79 = ___cxa_find_matching_catch()|0;
    $80 = tempRet0;
    ___cxa_call_unexpected(($79|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 }
 $81 = (__ZNK6Object12GetClassNameEv($com)|0);
 $82 = HEAP8[$81>>0]|0;
 $83 = $82 & 1;
 $84 = ($83<<24>>24)==(0);
 if ($84) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$81+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$81+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$81+8>>2]|0;
  STACKTOP = sp;return;
 }
 $85 = (($81) + 8|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($81) + 4|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88>>>0)>(4294967279);
 if ($89) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $90 = ($88>>>0)<(11);
 if ($90) {
  $91 = $88 << 1;
  $92 = $91&255;
  HEAP8[$agg$result>>0] = $92;
  $93 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $93;
 } else {
  $94 = (($88) + 16)|0;
  $95 = $94 & -16;
  $96 = (__Znwj($95)|0);
  $97 = (($agg$result) + 8|0);
  HEAP32[$97>>2] = $96;
  $98 = $95 | 1;
  HEAP32[$agg$result>>2] = $98;
  $99 = (($agg$result) + 4|0);
  HEAP32[$99>>2] = $88;
  $__p$0$i$i$i = $96;
 }
 _memcpy(($__p$0$i$i$i|0),($86|0),($88|0))|0;
 $100 = (($__p$0$i$i$i) + ($88)|0);
 HEAP8[$100>>0] = 0;
 STACKTOP = sp;return;
}
function __Z21SendMessageToEveryone17MessageIdentifier11MessageData($message,$msgData) {
 $message = $message|0;
 $msgData = $msgData|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01 = 0, $$01$i$i$i = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__nd$0$in$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $__parent$i = 0, $gameObjects = 0, $i$020 = 0;
 var $ids = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $pos$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__parent$i = sp + 36|0;
 $pos$i$i$i = sp;
 $0 = sp + 8|0;
 $gameObjects = sp + 12|0;
 $ids = sp + 24|0;
 HEAP32[$gameObjects>>2] = 0;
 $1 = (($gameObjects) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($gameObjects) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,1,($gameObjects|0),0)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $46 = ___cxa_find_matching_catch()|0;
   $47 = tempRet0;
   $$0 = $46;$$01 = $47;
  } else {
   $5 = (($ids) + 4|0);
   HEAP32[$5>>2] = 0;
   $6 = (($ids) + 8|0);
   HEAP32[$6>>2] = 0;
   $7 = (($ids) + 4|0);
   HEAP32[$ids>>2] = $7;
   $8 = HEAP32[$1>>2]|0;
   $9 = HEAP32[$gameObjects>>2]|0;
   $10 = ($8|0)==($9|0);
   L4: do {
    if (!($10)) {
     $12 = $9;$i$020 = 0;
     while(1) {
      $11 = (($12) + ($i$020<<2)|0);
      $13 = HEAP32[$11>>2]|0;
      __THREW__ = 0;
      $14 = (invoke_ii(3251,($13|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       label = 22;
       break;
      }
      if ($14) {
       $17 = (($13) + 4|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = HEAP32[$5>>2]|0;
       $20 = ($19|0)==(0|0);
       do {
        if ($20) {
         HEAP32[$__parent$i>>2] = $7;
         $$0$i$i = $7;$38 = $7;
        } else {
         $__nd$0$in$i$i = $19;
         while(1) {
          $21 = (($__nd$0$in$i$i) + 16|0);
          $22 = HEAP32[$21>>2]|0;
          $23 = ($18|0)<($22|0);
          if ($23) {
           $24 = HEAP32[$__nd$0$in$i$i>>2]|0;
           $25 = ($24|0)==(0|0);
           if ($25) {
            label = 9;
            break;
           } else {
            $__nd$0$in$i$i = $24;
            continue;
           }
          }
          $26 = ($22|0)<($18|0);
          if (!($26)) {
           label = 13;
           break;
          }
          $27 = (($__nd$0$in$i$i) + 4|0);
          $28 = HEAP32[$27>>2]|0;
          $29 = ($28|0)==(0|0);
          if ($29) {
           label = 12;
           break;
          } else {
           $__nd$0$in$i$i = $28;
          }
         }
         if ((label|0) == 9) {
          label = 0;
          HEAP32[$__parent$i>>2] = $__nd$0$in$i$i;
          $$0$i$i = $__nd$0$in$i$i;$38 = $__nd$0$in$i$i;
          break;
         }
         else if ((label|0) == 12) {
          label = 0;
          HEAP32[$__parent$i>>2] = $__nd$0$in$i$i;
          $$0$i$i = $27;$38 = $__nd$0$in$i$i;
          break;
         }
         else if ((label|0) == 13) {
          label = 0;
          HEAP32[$__parent$i>>2] = $__nd$0$in$i$i;
          $$0$i$i = $__parent$i;$38 = $__nd$0$in$i$i;
          break;
         }
        }
       } while(0);
       $30 = HEAP32[$$0$i$i>>2]|0;
       $31 = ($30|0)==(0|0);
       if ($31) {
        __THREW__ = 0;
        $32 = (invoke_ii(2988,20)|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         label = 22;
         break;
        }
        $35 = (($32) + 16|0);
        HEAP32[$35>>2] = $18;
        HEAP32[$32>>2] = 0;
        $36 = (($32) + 4|0);
        HEAP32[$36>>2] = 0;
        $37 = (($32) + 8|0);
        HEAP32[$37>>2] = $38;
        HEAP32[$$0$i$i>>2] = $32;
        $39 = HEAP32[$ids>>2]|0;
        $40 = HEAP32[$39>>2]|0;
        $41 = ($40|0)==(0|0);
        if ($41) {
         $43 = $32;
        } else {
         HEAP32[$ids>>2] = $40;
         $$pre$i$i = HEAP32[$$0$i$i>>2]|0;
         $43 = $$pre$i$i;
        }
        $42 = HEAP32[$5>>2]|0;
        __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($42,$43);
        $44 = HEAP32[$6>>2]|0;
        $45 = (($44) + 1)|0;
        HEAP32[$6>>2] = $45;
       }
      }
      $53 = (($i$020) + 1)|0;
      $54 = HEAP32[$1>>2]|0;
      $55 = HEAP32[$gameObjects>>2]|0;
      $56 = $54;
      $57 = $55;
      $58 = (($56) - ($57))|0;
      $59 = $58 >> 2;
      $60 = ($53>>>0)<($59>>>0);
      if ($60) {
       $12 = $55;$i$020 = $53;
      } else {
       label = 25;
       break;
      }
     }
     if ((label|0) == 22) {
      $50 = ___cxa_find_matching_catch()|0;
      $51 = tempRet0;
      $lpad$phi$index = $50;$lpad$phi$index2 = $51;
     }
     else if ((label|0) == 25) {
      $$pre = HEAP32[$ids>>2]|0;
      $61 = ($$pre|0)==($7|0);
      if ($61) {
       break;
      }
      $63 = $$pre;
      while(1) {
       $62 = (($63) + 16|0);
       $64 = HEAP32[$62>>2]|0;
       HEAP32[$0>>2] = $64;
       $65 = HEAP32[560624>>2]|0;
       $66 = ($65|0)==(0|0);
       if (!($66)) {
        $67 = (($65) + 36|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = (($65) + 4|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($68|0)==($70|0);
        do {
         if ($71) {
          $72 = (($65) + 28|0);
          $73 = HEAP32[$72>>2]|0;
          $74 = (($65) + 32|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = (($73) + ($75<<3)|0);
          $92 = $76;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$65,$0);
          $77 = HEAP32[$pos$i$i$i>>2]|0;
          $78 = ($77|0)==(-1);
          $79 = (($65) + 28|0);
          $80 = HEAP32[$79>>2]|0;
          if ($78) {
           $81 = (($65) + 32|0);
           $82 = HEAP32[$81>>2]|0;
           $83 = (($80) + ($82<<3)|0);
           $92 = $83;
           break;
          } else {
           $84 = (($80) + ($77<<3)|0);
           $92 = $84;
           break;
          }
         }
        } while(0);
        $85 = HEAP32[560624>>2]|0;
        $86 = (($85) + 28|0);
        $87 = HEAP32[$86>>2]|0;
        $88 = (($85) + 32|0);
        $89 = HEAP32[$88>>2]|0;
        $90 = (($87) + ($89<<3)|0);
        $91 = ($92|0)==($90|0);
        if (!($91)) {
         $93 = (($92) + 4|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = ($94|0)==(0|0);
         if (!($95)) {
          __THREW__ = 0;
          $96 = (invoke_ii(3251,($94|0))|0);
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           break;
          }
          if ($96) {
           __THREW__ = 0;
           invoke_viii(1781,($94|0),($message|0),($msgData|0));
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            break;
           }
          }
         }
        }
       }
       $101 = (($63) + 4|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ($102|0)==(0|0);
       if ($103) {
        $$01$i$i$i = $63;
        while(1) {
         $106 = (($$01$i$i$i) + 8|0);
         $107 = HEAP32[$106>>2]|0;
         $108 = HEAP32[$107>>2]|0;
         $109 = ($108|0)==($$01$i$i$i|0);
         if ($109) {
          $$0$i$i$i = $107;
          break;
         } else {
          $$01$i$i$i = $107;
         }
        }
       } else {
        $$0$i$i$i$i = $102;
        while(1) {
         $104 = HEAP32[$$0$i$i$i$i>>2]|0;
         $105 = ($104|0)==(0|0);
         if ($105) {
          $$0$i$i$i = $$0$i$i$i$i;
          break;
         } else {
          $$0$i$i$i$i = $104;
         }
        }
       }
       $110 = ($$0$i$i$i|0)==($7|0);
       if ($110) {
        break L4;
       }
       $63 = $$0$i$i$i;
      }
      $48 = ___cxa_find_matching_catch()|0;
      $49 = tempRet0;
      $lpad$phi$index = $48;$lpad$phi$index2 = $49;
     }
     $52 = HEAP32[$5>>2]|0;
     __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($ids,$52);
     $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
     break L1;
    }
   } while(0);
   $111 = HEAP32[$5>>2]|0;
   __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($ids,$111);
   $112 = HEAP32[$gameObjects>>2]|0;
   $113 = ($112|0)==(0|0);
   if ($113) {
    STACKTOP = sp;return;
   }
   $114 = HEAP32[$1>>2]|0;
   $115 = ($114|0)==($112|0);
   if (!($115)) {
    $__new_last2$i$i$i$i$i2 = $112;
    $scevgep$i$i$i$i$i3 = (($114) + -4|0);
    $116 = (0 - ($__new_last2$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($116)|0);
    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
    $117 = $uglygep3$i$i$i$i$i6 >>> 2;
    $118 = $117 ^ -1;
    $scevgep4$i$i$i$i$i7 = (($114) + ($118<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i7;
   }
   __ZdlPv($112);
   STACKTOP = sp;return;
  }
 } while(0);
 $119 = HEAP32[$gameObjects>>2]|0;
 $120 = ($119|0)==(0|0);
 if ($120) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $121 = HEAP32[$1>>2]|0;
 $122 = ($121|0)==($119|0);
 if (!($122)) {
  $__new_last2$i$i$i$i$i = $119;
  $scevgep$i$i$i$i$i = (($121) + -4|0);
  $123 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($123)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $124 = $uglygep3$i$i$i$i$i >>> 2;
  $125 = $124 ^ -1;
  $scevgep4$i$i$i$i$i = (($121) + ($125<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($119);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z22FindGameObjectsWithTagjRNSt3__16vectorIPN5Unity10GameObjectENS_9allocatorIS3_EEEE($tag,$gos) {
 $tag = $tag|0;
 $gos = $gos|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN5Unity20GetGameObjectManagerEv()|0);
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($gos) + 4|0);
 $5 = (($gos) + 8|0);
 $7 = $2;
 L4: while(1) {
  $6 = (($7) + 8|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 44|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = $10&65535;
  $12 = ($11|0)==($tag|0);
  do {
   if ($12) {
    $13 = HEAP32[$4>>2]|0;
    $14 = HEAP32[$5>>2]|0;
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $16 = ($13|0)==(0|0);
     if ($16) {
      $18 = 0;
     } else {
      HEAP32[$13>>2] = $8;
      $$pre$i = HEAP32[$4>>2]|0;
      $18 = $$pre$i;
     }
     $17 = (($18) + 4|0);
     HEAP32[$4>>2] = $17;
     break;
    }
    $19 = HEAP32[$gos>>2]|0;
    $20 = $13;
    $21 = $19;
    $22 = (($20) - ($21))|0;
    $23 = $22 >> 2;
    $24 = (($23) + 1)|0;
    $25 = ($24>>>0)>(1073741823);
    if ($25) {
     label = 9;
     break L4;
    }
    $26 = ($23>>>0)<(536870911);
    if ($26) {
     $27 = $22 >> 1;
     $28 = ($27>>>0)<($24>>>0);
     $29 = $28 ? $24 : $27;
     $30 = ($29|0)==(0);
     if ($30) {
      $$0$i3$i$i = 0;$34 = 0;
     } else {
      $$0$i2$i$i = $29;
      label = 12;
     }
    } else {
     $$0$i2$i$i = 1073741823;
     label = 12;
    }
    if ((label|0) == 12) {
     label = 0;
     $31 = $$0$i2$i$i << 2;
     $32 = (__Znwj($31)|0);
     $$0$i3$i$i = $$0$i2$i$i;$34 = $32;
    }
    $33 = (($34) + ($23<<2)|0);
    $35 = (($34) + ($$0$i3$i$i<<2)|0);
    $36 = ($33|0)==(0|0);
    if (!($36)) {
     HEAP32[$33>>2] = $8;
    }
    $37 = (($34) + ($24<<2)|0);
    _memcpy(($34|0),($19|0),($22|0))|0;
    HEAP32[$gos>>2] = $34;
    HEAP32[$4>>2] = $37;
    HEAP32[$5>>2] = $35;
    $38 = ($19|0)==(0|0);
    if (!($38)) {
     __ZdlPv($19);
    }
   }
  } while(0);
  $39 = (($7) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==($0|0);
  if ($41) {
   label = 18;
   break;
  } else {
   $7 = $40;
  }
 }
 if ((label|0) == 9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 18) {
  STACKTOP = sp;return;
 }
}
function __Z14FindMainCamerav() {
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $gos = 0, $i$010 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $gos = sp;
 HEAP32[$gos>>2] = 0;
 $0 = (($gos) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($gos) + 8|0);
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2771,5,($gos|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if ($3) {
   $22 = ___cxa_find_matching_catch()|0;
   $23 = tempRet0;
   $$pre = HEAP32[$gos>>2]|0;
   $25 = $$pre;$lpad$phi$index = $22;$lpad$phi$index2 = $23;
  } else {
   $4 = HEAP32[$0>>2]|0;
   $5 = HEAP32[$gos>>2]|0;
   $6 = ($4|0)==($5|0);
   L4: do {
    if ($6) {
     $$0 = 0;$34 = $4;
    } else {
     $7 = $4;
     $8 = $5;
     $9 = (($7) - ($8))|0;
     $10 = $9 >> 2;
     $i$010 = 0;
     while(1) {
      $11 = (($5) + ($i$010<<2)|0);
      $12 = HEAP32[$11>>2]|0;
      __THREW__ = 0;
      $13 = (invoke_iii(2363,($12|0),20)|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       label = 7;
       break;
      }
      $16 = ($13|0)==(0|0);
      if (!($16)) {
       $17 = (($13) + 28|0);
       $18 = HEAP8[$17>>0]|0;
       $19 = ($18<<24>>24)==(0);
       if (!($19)) {
        label = 14;
        break;
       }
      }
      $31 = (($i$010) + 1)|0;
      $32 = ($31>>>0)<($10>>>0);
      if ($32) {
       $i$010 = $31;
      } else {
       $$0 = 0;$34 = $5;
       break L4;
      }
     }
     if ((label|0) == 7) {
      $20 = ___cxa_find_matching_catch()|0;
      $21 = tempRet0;
      $25 = $5;$lpad$phi$index = $20;$lpad$phi$index2 = $21;
      break L1;
     }
     else if ((label|0) == 14) {
      $$0 = $13;$34 = $5;
      break;
     }
    }
   } while(0);
   $33 = ($34|0)==(0|0);
   if ($33) {
    STACKTOP = sp;return ($$0|0);
   }
   $35 = ($4|0)==($34|0);
   if (!($35)) {
    $__new_last2$i$i$i$i$i = $34;
    $scevgep$i$i$i$i$i = (($4) + -4|0);
    $36 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($36)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $37 = $uglygep3$i$i$i$i$i >>> 2;
    $38 = $37 ^ -1;
    $scevgep4$i$i$i$i$i = (($4) + ($38<<2)|0);
    HEAP32[$0>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($34);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $24 = ($25|0)==(0|0);
 if ($24) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $26 = HEAP32[$0>>2]|0;
 $27 = ($26|0)==($25|0);
 if (!($27)) {
  $__new_last2$i$i$i$i$i1 = $25;
  $scevgep$i$i$i$i$i2 = (($26) + -4|0);
  $28 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($28)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $29 = $uglygep3$i$i$i$i$i5 >>> 2;
  $30 = $29 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($26) + ($30<<2)|0);
  HEAP32[$0>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($25);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z16SmartResetObjectR6Object($object) {
 $object = $object|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($object|0)==(0|0);
 if (!($0)) {
  $1 = (($object) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = $2 >>> 21;
  $4 = HEAP32[560640>>2]|0;
  $5 = Math_imul($4, $3)|0;
  $6 = (($5) + 114)|0;
  $7 = $6 >> 5;
  $8 = $7 << 5;
  $9 = (($6) - ($8))|0;
  $10 = HEAP32[560632>>2]|0;
  $11 = (($10) + ($7<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = 1 << $9;
  $14 = $13 & $12;
  $15 = ($14|0)==(0);
  if (!($15)) {
   $16 = HEAP32[$object>>2]|0;
   $17 = (($16) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vi[$18 & 4095]($object);
   $19 = HEAP32[$object>>2]|0;
   $20 = (($19) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vi[$21 & 4095]($object);
   $22 = HEAP32[$object>>2]|0;
   $23 = (($22) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_vii[$24 & 4095]($object,0);
   STACKTOP = sp;return;
  }
 }
 $25 = HEAP32[$object>>2]|0;
 $26 = (($25) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vi[$27 & 4095]($object);
 $28 = HEAP32[$object>>2]|0;
 $29 = (($28) + 28|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vi[$30 & 4095]($object);
 $31 = HEAP32[$object>>2]|0;
 $32 = (($31) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vii[$33 & 4095]($object,0);
 STACKTOP = sp;return;
}
function __Z22GetComponentWithScriptRN5Unity10GameObjectEiP10MonoScript($go,$classID,$script) {
 $go = $go|0;
 $classID = $classID|0;
 $script = $script|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($classID|0)==(114);
 if (!($0)) {
  $1 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($go,$classID)|0);
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($script|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZN10MonoScript8GetClassEv($script)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($go) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(0);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($go) + 24|0);
 $i$01 = 0;
 while(1) {
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + ($i$01<<3)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[560640>>2]|0;
  $13 = Math_imul($12, $11)|0;
  $14 = (($13) + 114)|0;
  $15 = $14 >> 5;
  $16 = $15 << 5;
  $17 = (($14) - ($16))|0;
  $18 = HEAP32[560632>>2]|0;
  $19 = (($18) + ($15<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = 1 << $17;
  $22 = $21 & $20;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $24 = ((($9) + ($i$01<<3)|0) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 20|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    $29 = (__Z26scripting_object_get_classP15ScriptingObject($27)|0);
    $30 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($29,$3)|0);
    if ($30) {
     $$0 = $25;
     label = 11;
     break;
    }
   }
  }
  $31 = (($i$01) + 1)|0;
  $32 = ($31|0)<($6|0);
  if ($32) {
   $i$01 = $31;
  } else {
   $$0 = 0;
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN13dynamic_arrayIPN5Unity9ComponentELj4EE9push_backERKS2_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$t>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if (!($8)) {
  $27 = $4;
  $26 = (($27) + -1)|0;
  $28 = HEAP32[$this>>2]|0;
  $29 = (($28) + ($26<<2)|0);
  HEAP32[$29>>2] = $1;
  STACKTOP = sp;return;
 }
 $9 = $6 << 1;
 $10 = ($9|0)==(0);
 $11 = $10 ? 1 : $9;
 $12 = ($7>>>0)<($11>>>0);
 do {
  if ($12) {
   $13 = ($6|0)>(-1);
   if ($13) {
    HEAP32[$5>>2] = $11;
    $14 = HEAP32[$this>>2]|0;
    $15 = $11 << 2;
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy1,0,618440,370)|0);
    HEAP32[$this>>2] = $18;
    break;
   } else {
    $19 = $11 << 2;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,618440,352)|0);
    $23 = HEAP32[$this>>2]|0;
    $24 = HEAP32[$2>>2]|0;
    $25 = $24 << 2;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$5>>2] = $11;
    HEAP32[$this>>2] = $22;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$2>>2]|0;
 $27 = $$pre$i;
 $26 = (($27) + -1)|0;
 $28 = HEAP32[$this>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAP32[$29>>2] = $1;
 STACKTOP = sp;return;
}
function __ZL19PreDestroyRecursiveRN5Unity10GameObjectEPj($gameObject,$destroyedObjectCount) {
 $gameObject = $gameObject|0;
 $destroyedObjectCount = $destroyedObjectCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($gameObject) + 49|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($gameObject) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(619432,0,618440,1240,1,$4,0,0);
  STACKTOP = sp;return;
 }
 __ZN5Unity10GameObject23InvokeDestroyedCallbackEPS0_($gameObject);
 __ZN5Unity10GameObject21WillDestroyGameObjectEv($gameObject);
 $5 = (($gameObject) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1)|0;
 $8 = HEAP32[$destroyedObjectCount>>2]|0;
 $9 = (($7) + ($8))|0;
 HEAP32[$destroyedObjectCount>>2] = $9;
 $10 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($gameObject)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($10) + 140|0);
 $13 = (($10) + 148|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$12>>2]|0;
 $i$01 = $16;
 while(1) {
  $17 = HEAP32[$i$01>>2]|0;
  $18 = (($17) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  __ZL19PreDestroyRecursiveRN5Unity10GameObjectEPj($19,$destroyedObjectCount);
  $20 = (($i$01) + 4|0);
  $21 = HEAP32[$12>>2]|0;
  $22 = HEAP32[$13>>2]|0;
  $23 = (($21) + ($22<<2)|0);
  $24 = ($20|0)==($23|0);
  if ($24) {
   break;
  } else {
   $i$01 = $20;
  }
 }
 STACKTOP = sp;return;
}
function __ZL26DestroyGameObjectRecursiveRN5Unity10GameObjectER11BatchDelete($gameObject,$batchDelete) {
 $gameObject = $gameObject|0;
 $batchDelete = $batchDelete|0;
 var $$pre$i$i = 0, $$pre$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$04 = 0, $i2$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($gameObject)|0);
 $1 = ($0|0)!=(0|0);
 if ($1) {
  $2 = (($0) + 140|0);
  $3 = (($0) + 148|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if (!($5)) {
   $6 = HEAP32[$2>>2]|0;
   $i$04 = $6;
   while(1) {
    $7 = HEAP32[$i$04>>2]|0;
    $8 = (($7) + 24|0);
    $9 = HEAP32[$8>>2]|0;
    __ZL26DestroyGameObjectRecursiveRN5Unity10GameObjectER11BatchDelete($9,$batchDelete);
    $10 = (($i$04) + 4|0);
    $11 = HEAP32[$2>>2]|0;
    $12 = HEAP32[$3>>2]|0;
    $13 = (($11) + ($12<<2)|0);
    $14 = ($10|0)==($13|0);
    if ($14) {
     break;
    } else {
     $i$04 = $10;
    }
   }
  }
 }
 $15 = (($gameObject) + 49|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if (!($17)) {
  if ($1) {
   __ZN9Transform16RemoveFromParentEb($0,1);
  }
  $23 = ($gameObject|0)==(0|0);
  if ($23) {
   $26 = 0;
  } else {
   $24 = (($gameObject) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(619432,0,618440,1223,1,$26,0,0);
  STACKTOP = sp;return;
 }
 $18 = (($gameObject) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(0);
 if ($20) {
  $21 = (($gameObject) + 24|0);
  $22 = (($batchDelete) + 4|0);
  $i2$03 = 0;
  while(1) {
   $27 = HEAP32[$21>>2]|0;
   $28 = ((($27) + ($i2$03<<3)|0) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31 & 1048576;
   $33 = ($32|0)==(0);
   if (!($33)) {
    $34 = (__Z20GetPersistentManagerv()|0);
    $35 = (($29) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    __ZN17PersistentManager22MakeObjectUnpersistentEi13UnpersistMode($34,$36,1);
   }
   $37 = HEAP32[$22>>2]|0;
   $38 = HEAP32[$batchDelete>>2]|0;
   $39 = ($37|0)==($38|0);
   if ($39) {
    __Z17CommitBatchDeleteR11BatchDelete($batchDelete);
    __Z17CreateBatchDeleteR11BatchDeletej($batchDelete,256);
    $$pre$i$i = HEAP32[$22>>2]|0;
    $41 = $$pre$i$i;
   } else {
    $41 = $37;
   }
   $40 = (($41) + 1)|0;
   HEAP32[$22>>2] = $40;
   $42 = ((($batchDelete) + ($41<<2)|0) + 8|0);
   HEAP32[$42>>2] = $29;
   $43 = (($i2$03) + 1)|0;
   $44 = HEAP32[$18>>2]|0;
   $45 = ($43|0)<($44|0);
   if ($45) {
    $i2$03 = $43;
   } else {
    break;
   }
  }
 }
 $46 = (($gameObject) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 & 1048576;
 $49 = ($48|0)==(0);
 if (!($49)) {
  $50 = (__Z20GetPersistentManagerv()|0);
  $51 = (($gameObject) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  __ZN17PersistentManager22MakeObjectUnpersistentEi13UnpersistMode($50,$52,1);
 }
 $53 = (($batchDelete) + 4|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$batchDelete>>2]|0;
 $56 = ($54|0)==($55|0);
 if ($56) {
  __Z17CommitBatchDeleteR11BatchDelete($batchDelete);
  __Z17CreateBatchDeleteR11BatchDeletej($batchDelete,256);
  $$pre$i$i1 = HEAP32[$53>>2]|0;
  $58 = $$pre$i$i1;
 } else {
  $58 = $54;
 }
 $57 = (($58) + 1)|0;
 HEAP32[$53>>2] = $57;
 $59 = ((($batchDelete) + ($58<<2)|0) + 8|0);
 HEAP32[$59>>2] = $gameObject;
 STACKTOP = sp;return;
}
function __Z26DestroyGameObjectHierarchyRN5Unity10GameObjectE($gameObject) {
 $gameObject = $gameObject|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $batchDelete = 0, $objectCount = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $objectCount = sp + 1032|0;
 $batchDelete = sp;
 __ZN5Unity10GameObject10DeactivateENS_19DeactivateOperationE($gameObject,2);
 HEAP32[$objectCount>>2] = 0;
 __ZL19PreDestroyRecursiveRN5Unity10GameObjectEPj($gameObject,$objectCount);
 $0 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($gameObject)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  __ZN9Transform16RemoveFromParentEb($0,1);
 }
 $2 = HEAP32[$objectCount>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __Z17CreateBatchDeleteR11BatchDeletej($batchDelete,$2);
 __ZL26DestroyGameObjectRecursiveRN5Unity10GameObjectER11BatchDelete($gameObject,$batchDelete);
 __Z17CommitBatchDeleteR11BatchDelete($batchDelete);
 STACKTOP = sp;return;
}
function __Z22DestroyObjectHighLevelP6Objectb($object,$forceDestroy) {
 $object = $object|0;
 $forceDestroy = $forceDestroy|0;
 var $$0 = 0, $$0$i11 = 0, $$0$i23 = 0, $$01 = 0, $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error = 0, $temp$0$i = 0, $temp$0$i22 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $0 = sp + 36|0;
 $1 = sp + 8|0;
 $error = sp + 12|0;
 $2 = sp + 24|0;
 $3 = ($object|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($object) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 21;
 $7 = HEAP32[560640>>2]|0;
 $8 = Math_imul($7, $6)|0;
 $9 = (($8) + 2)|0;
 $10 = $9 >> 5;
 $11 = $10 << 5;
 $12 = (($9) - ($11))|0;
 $13 = HEAP32[560632>>2]|0;
 $14 = (($13) + ($10<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = 1 << $12;
 $17 = $16 & $15;
 $18 = ($17|0)==(0);
 if ($18) {
  $206 = (($8) + 1)|0;
  $207 = $206 >> 5;
  $208 = $207 << 5;
  $209 = (($206) - ($208))|0;
  $210 = (($13) + ($207<<2)|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = 1 << $209;
  $213 = $211 & $212;
  $214 = ($213|0)==(0);
  if ($214) {
   $238 = (($8) + 142)|0;
   $239 = $238 >> 5;
   $240 = $239 << 5;
   $241 = (($238) - ($240))|0;
   $242 = (($13) + ($239<<2)|0);
   $243 = HEAP32[$242>>2]|0;
   $244 = 1 << $241;
   $245 = $243 & $244;
   $246 = ($245|0)==(0);
   if ($246) {
    __Z19DestroySingleObjectP6Object($object);
    STACKTOP = sp;return;
   } else {
    $247 = (($object) + 4|0);
    $248 = HEAP32[$247>>2]|0;
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(619504,0,618440,1477,1,$248,0,0);
    STACKTOP = sp;return;
   }
  }
  $215 = (__Z30GetDisableImmediateDestructionv()|0);
  if ($215) {
   $216 = (($object) + 4|0);
   $217 = HEAP32[$216>>2]|0;
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(619272,0,618440,1442,1,$217,0,0);
   STACKTOP = sp;return;
  }
  $218 = (($object) + 48|0);
  $219 = HEAP8[$218>>0]|0;
  $220 = ($219<<24>>24)==(0);
  if (!($220)) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(618688,0,618440,1449,1,0,0,0);
   STACKTOP = sp;return;
  }
  $221 = (($object) + 49|0);
  $222 = HEAP8[$221>>0]|0;
  $223 = ($222<<24>>24)==(0);
  if (!($223)) {
   $224 = (($object) + 4|0);
   $225 = HEAP32[$224>>2]|0;
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(619432,0,618440,1455,1,$225,0,0);
   STACKTOP = sp;return;
  }
  $226 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($object)|0);
  $227 = ($226|0)==(0|0);
  if (!($227)) {
   $228 = (($226) + 156|0);
   $229 = HEAP32[$228>>2]|0;
   $230 = ($229|0)==(0|0);
   if (!($230)) {
    $231 = (($229) + 24|0);
    $232 = HEAP32[$231>>2]|0;
    $233 = (($232) + 49|0);
    $234 = HEAP8[$233>>0]|0;
    $235 = ($234<<24>>24)==(0);
    if (!($235)) {
     $236 = (($object) + 4|0);
     $237 = HEAP32[$236>>2]|0;
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(619432,0,618440,1465,1,$237,0,0);
     STACKTOP = sp;return;
    }
   }
  }
  __Z26DestroyGameObjectHierarchyRN5Unity10GameObjectE($object);
  STACKTOP = sp;return;
 }
 $19 = (($8) + 114)|0;
 $20 = $19 >> 5;
 $21 = $20 << 5;
 $22 = (($19) - ($21))|0;
 $23 = (($13) + ($20<<2)|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = 1 << $22;
 $26 = $24 & $25;
 $27 = ($26|0)==(0);
 if (!($27)) {
  $28 = (($object) + 131|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = ($29<<24>>24)==(0);
  if (!($30)) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(618688,0,618440,1354,1,0,0,0);
   STACKTOP = sp;return;
  }
 }
 $31 = (($object) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 L39: do {
  if ($33) {
   $203 = HEAP32[$object>>2]|0;
   $204 = (($203) + 100|0);
   $205 = HEAP32[$204>>2]|0;
   FUNCTION_TABLE_vi[$205 & 4095]($object);
  } else {
   $34 = (__Z30GetDisableImmediateDestructionv()|0);
   if ($34) {
    $35 = (($object) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(618800,0,618440,1364,1,$36,0,0);
    STACKTOP = sp;return;
   }
   $37 = (($32) + 48|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = ($38<<24>>24)==(0);
   if (!($39)) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(618688,0,618440,1370,1,0,0,0);
    STACKTOP = sp;return;
   }
   $40 = (($32) + 49|0);
   $41 = HEAP8[$40>>0]|0;
   $42 = ($41<<24>>24)==(0);
   if (!($42)) {
    $43 = (($32) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(618960,0,618440,1377,1,$44,0,0);
    STACKTOP = sp;return;
   }
   ;HEAP32[$error+0>>2]=0|0;HEAP32[$error+4>>2]=0|0;HEAP32[$error+8>>2]=0|0;
   if ($forceDestroy) {
    label = 21;
   } else {
    __THREW__ = 0;
    $45 = (invoke_iiii(1553,($object|0),0,($error|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 20;
    } else {
     if ($45) {
      label = 21;
     } else {
      $48 = (($object) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = HEAP8[$error>>0]|0;
      $51 = $50 & 1;
      $52 = ($51<<24>>24)==(0);
      if ($52) {
       $55 = (($error) + 1|0);
       $56 = $55;
      } else {
       $53 = (($error) + 8|0);
       $54 = HEAP32[$53>>2]|0;
       $56 = $54;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($56|0),0,(618440|0),1384,1,($49|0),0,(0|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 20;
      } else {
       $249 = HEAP8[$error>>0]|0;
       $250 = $249 & 1;
       $251 = ($250<<24>>24)==(0);
       if ($251) {
        STACKTOP = sp;return;
       }
       $252 = (($error) + 8|0);
       $253 = HEAP32[$252>>2]|0;
       __ZdlPv($253);
       STACKTOP = sp;return;
      }
     }
    }
   }
   do {
    if ((label|0) == 21) {
     $61 = HEAP32[$4>>2]|0;
     $$mask = $61 & -2097152;
     $62 = ($$mask|0)==(469762048);
     if ($62) {
      $63 = HEAP32[$32>>2]|0;
      $64 = (($63) + 32|0);
      $65 = HEAP32[$64>>2]|0;
      __THREW__ = 0;
      $66 = (invoke_ii($65|0,($32|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 20;
       break;
      }
      __THREW__ = 0;
      HEAP32[$vararg_buffer>>2] = $66;
      invoke_viii(1617,($2|0),(619040|0),($vararg_buffer|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 20;
       break;
      }
      __THREW__ = 0;
      (invoke_iii(2233,($error|0),($2|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       $89 = ___cxa_find_matching_catch()|0;
       $90 = tempRet0;
       $91 = HEAP8[$2>>0]|0;
       $92 = $91 & 1;
       $93 = ($92<<24>>24)==(0);
       if ($93) {
        $$0 = $89;$$01 = $90;
        break;
       }
       $94 = (($2) + 8|0);
       $95 = HEAP32[$94>>2]|0;
       __ZdlPv($95);
       $$0 = $89;$$01 = $90;
       break;
      }
      $73 = HEAP8[$2>>0]|0;
      $74 = $73 & 1;
      $75 = ($74<<24>>24)==(0);
      if (!($75)) {
       $76 = (($2) + 8|0);
       $77 = HEAP32[$76>>2]|0;
       __ZdlPv($77);
      }
      $78 = (($object) + 4|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = HEAP8[$error>>0]|0;
      $81 = $80 & 1;
      $82 = ($81<<24>>24)==(0);
      if ($82) {
       $85 = (($error) + 1|0);
       $86 = $85;
      } else {
       $83 = (($error) + 8|0);
       $84 = HEAP32[$83>>2]|0;
       $86 = $84;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($86|0),0,(618440|0),1398,1,($79|0),0,(0|0));
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 20;
       break;
      }
      $254 = HEAP8[$error>>0]|0;
      $255 = $254 & 1;
      $256 = ($255<<24>>24)==(0);
      if ($256) {
       STACKTOP = sp;return;
      }
      $257 = (($error) + 8|0);
      $258 = HEAP32[$257>>2]|0;
      __ZdlPv($258);
      STACKTOP = sp;return;
     }
     $96 = (($object) + 4|0);
     $97 = HEAP32[$96>>2]|0;
     __THREW__ = 0;
     $98 = (invoke_ii(3251,($32|0))|0);
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      label = 20;
     } else {
      if ($98) {
       $101 = HEAP32[$object>>2]|0;
       $102 = (($101) + 104|0);
       $103 = HEAP32[$102>>2]|0;
       __THREW__ = 0;
       invoke_vii($103|0,($object|0),1);
       $104 = __THREW__; __THREW__ = 0;
       $105 = $104&1;
       if ($105) {
        label = 20;
        break;
       }
       $106 = ($97|0)==(0);
       if ($106) {
        $$0$i23 = 0;$269 = 0;
       } else {
        HEAP32[$0>>2] = $97;
        $107 = HEAP32[560624>>2]|0;
        $108 = ($107|0)==(0|0);
        do {
         if ($108) {
          label = 45;
         } else {
          $109 = (($107) + 36|0);
          $110 = HEAP32[$109>>2]|0;
          $111 = (($107) + 4|0);
          $112 = HEAP32[$111>>2]|0;
          $113 = ($110|0)==($112|0);
          do {
           if ($113) {
            $114 = (($107) + 28|0);
            $115 = HEAP32[$114>>2]|0;
            $116 = (($107) + 32|0);
            $117 = HEAP32[$116>>2]|0;
            $118 = (($115) + ($117<<3)|0);
            $134 = $118;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$107,$0);
            $119 = HEAP32[$vararg_buffer>>2]|0;
            $120 = ($119|0)==(-1);
            $121 = (($107) + 28|0);
            $122 = HEAP32[$121>>2]|0;
            if ($120) {
             $123 = (($107) + 32|0);
             $124 = HEAP32[$123>>2]|0;
             $125 = (($122) + ($124<<3)|0);
             $134 = $125;
             break;
            } else {
             $126 = (($122) + ($119<<3)|0);
             $134 = $126;
             break;
            }
           }
          } while(0);
          $127 = HEAP32[560624>>2]|0;
          $128 = (($127) + 28|0);
          $129 = HEAP32[$128>>2]|0;
          $130 = (($127) + 32|0);
          $131 = HEAP32[$130>>2]|0;
          $132 = (($129) + ($131<<3)|0);
          $133 = ($134|0)==($132|0);
          if ($133) {
           label = 45;
           break;
          }
          $135 = (($134) + 4|0);
          $136 = HEAP32[$135>>2]|0;
          $137 = ($136|0)==(0|0);
          if ($137) {
           label = 45;
          } else {
           $temp$0$i22 = $136;
          }
         }
        } while(0);
        if ((label|0) == 45) {
         __THREW__ = 0;
         $138 = (invoke_ii(3215,($97|0))|0);
         $139 = __THREW__; __THREW__ = 0;
         $140 = $139&1;
         if ($140) {
          label = 20;
          break;
         } else {
          $temp$0$i22 = $138;
         }
        }
        $$0$i23 = $temp$0$i22;$269 = $97;
       }
       $141 = ($$0$i23|0)==($object|0);
       if ($141) {
        $148 = $269;
       } else {
        $259 = HEAP8[$error>>0]|0;
        $260 = $259 & 1;
        $261 = ($260<<24>>24)==(0);
        if ($261) {
         STACKTOP = sp;return;
        }
        $262 = (($error) + 8|0);
        $263 = HEAP32[$262>>2]|0;
        __ZdlPv($263);
        STACKTOP = sp;return;
       }
      } else {
       $148 = $97;
      }
      $142 = HEAP32[$object>>2]|0;
      $143 = (($142) + 100|0);
      $144 = HEAP32[$143>>2]|0;
      __THREW__ = 0;
      invoke_vi($144|0,($object|0));
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       label = 20;
      } else {
       $147 = ($148|0)==(0);
       if ($147) {
        $$0$i11 = 0;
       } else {
        HEAP32[$1>>2] = $148;
        $149 = HEAP32[560624>>2]|0;
        $150 = ($149|0)==(0|0);
        if ($150) {
         label = 58;
        } else {
         $151 = (($149) + 36|0);
         $152 = HEAP32[$151>>2]|0;
         $153 = (($149) + 4|0);
         $154 = HEAP32[$153>>2]|0;
         $155 = ($152|0)==($154|0);
         do {
          if ($155) {
           $156 = (($149) + 28|0);
           $157 = HEAP32[$156>>2]|0;
           $158 = (($149) + 32|0);
           $159 = HEAP32[$158>>2]|0;
           $160 = (($157) + ($159<<3)|0);
           $176 = $160;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$149,$1);
           $161 = HEAP32[$vararg_buffer>>2]|0;
           $162 = ($161|0)==(-1);
           $163 = (($149) + 28|0);
           $164 = HEAP32[$163>>2]|0;
           if ($162) {
            $165 = (($149) + 32|0);
            $166 = HEAP32[$165>>2]|0;
            $167 = (($164) + ($166<<3)|0);
            $176 = $167;
            break;
           } else {
            $168 = (($164) + ($161<<3)|0);
            $176 = $168;
            break;
           }
          }
         } while(0);
         $169 = HEAP32[560624>>2]|0;
         $170 = (($169) + 28|0);
         $171 = HEAP32[$170>>2]|0;
         $172 = (($169) + 32|0);
         $173 = HEAP32[$172>>2]|0;
         $174 = (($171) + ($173<<3)|0);
         $175 = ($176|0)==($174|0);
         if ($175) {
          label = 58;
         } else {
          $177 = (($176) + 4|0);
          $178 = HEAP32[$177>>2]|0;
          $179 = ($178|0)==(0|0);
          if ($179) {
           label = 58;
          } else {
           $temp$0$i = $178;
          }
         }
        }
        if ((label|0) == 58) {
         __THREW__ = 0;
         $180 = (invoke_ii(3215,($148|0))|0);
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if ($182) {
          label = 20;
          break;
         } else {
          $temp$0$i = $180;
         }
        }
        $$0$i11 = $temp$0$i;
       }
       $183 = ($$0$i11|0)==($object|0);
       if (!($183)) {
        $264 = HEAP8[$error>>0]|0;
        $265 = $264 & 1;
        $266 = ($265<<24>>24)==(0);
        if ($266) {
         STACKTOP = sp;return;
        }
        $267 = (($error) + 8|0);
        $268 = HEAP32[$267>>2]|0;
        __ZdlPv($268);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       $184 = (invoke_iii(2422,($32|0),($object|0))|0);
       $185 = __THREW__; __THREW__ = 0;
       $186 = $185&1;
       if ($186) {
        label = 20;
       } else {
        $187 = ($184|0)==(-1);
        if ($187) {
         __THREW__ = 0;
         invoke_viiiiiiii(21,(619232|0),0,(618440|0),1424,1,0,0,(0|0));
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          label = 20;
          break;
         }
        } else {
         $188 = HEAP32[$31>>2]|0;
         __THREW__ = 0;
         invoke_vii(2772,($188|0),($184|0));
         $189 = __THREW__; __THREW__ = 0;
         $190 = $189&1;
         if ($190) {
          label = 20;
          break;
         }
        }
        $193 = HEAP8[$error>>0]|0;
        $194 = $193 & 1;
        $195 = ($194<<24>>24)==(0);
        if ($195) {
         break L39;
        }
        $196 = (($error) + 8|0);
        $197 = HEAP32[$196>>2]|0;
        __ZdlPv($197);
        break L39;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    $$0 = $59;$$01 = $60;
   }
   $198 = HEAP8[$error>>0]|0;
   $199 = $198 & 1;
   $200 = ($199<<24>>24)==(0);
   if ($200) {
    ___resumeException($$0|0);
    // unreachable;
   }
   $201 = (($error) + 8|0);
   $202 = HEAP32[$201>>2]|0;
   __ZdlPv($202);
   ___resumeException($$0|0);
   // unreachable;
  }
 } while(0);
 __Z19DestroySingleObjectP6Object($object);
 STACKTOP = sp;return;
}
function __Z19UnityObjectToStringP6Object($agg$result,$object) {
 $agg$result = $agg$result|0;
 $object = $object|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy2 = 0, $$mask = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $phitmp = 0;
 var $phitmp12 = 0, $type = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp;
 $0 = sp + 60|0;
 $1 = sp + 8|0;
 $type = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 36|0;
 $4 = sp + 48|0;
 ;HEAP32[$type+0>>2]=0|0;HEAP32[$type+4>>2]=0|0;HEAP32[$type+8>>2]=0|0;
 $5 = ($object|0)==(0|0);
 if ($5) {
  HEAP8[$agg$result>>0] = 8;
  $6 = (($agg$result) + 1|0);
  HEAP8[$6>>0]=1819047278&255;HEAP8[$6+1>>0]=(1819047278>>8)&255;HEAP8[$6+2>>0]=(1819047278>>16)&255;HEAP8[$6+3>>0]=1819047278>>24;
  $7 = (($agg$result) + 5|0);
  HEAP8[$7>>0] = 0;
  STACKTOP = sp;return;
 }
 $10 = (($object) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $$mask = $11 & -2097152;
 $12 = ($$mask|0)==(239075328);
 L5: do {
  if ($12) {
   $13 = HEAP32[560640>>2]|0;
   $14 = ($13*114)|0;
   $15 = (($14) + 114)|0;
   $16 = $15 >> 5;
   $17 = $16 << 5;
   $18 = (($15) - ($17))|0;
   $19 = HEAP32[560632>>2]|0;
   $20 = (($19) + ($16<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = 1 << $18;
   $23 = $22 & $21;
   $24 = ($23|0)==(0);
   $$ = $24 ? 0 : $object;
   __THREW__ = 0;
   invoke_vii(2773,($3|0),($$|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 3;
   } else {
    $27 = HEAP8[$3>>0]|0;
    $28 = $27 & 1;
    $29 = ($28<<24>>24)==(0);
    if ($29) {
     $30 = (($3) + 1|0);
     $31 = $27&255;
     $32 = $31 >>> 1;
     $41 = $32;$53 = $30;
     label = 11;
    } else {
     $33 = (($3) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($3) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36>>>0)>(4294967279);
     if ($37) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 21;
      } else {
       // unreachable;
      }
     } else {
      $41 = $36;$53 = $34;
      label = 11;
     }
    }
    do {
     if ((label|0) == 11) {
      $40 = ($41>>>0)<(11);
      if ($40) {
       $42 = $41 << 1;
       $43 = $42&255;
       HEAP8[$2>>0] = $43;
       $44 = (($2) + 1|0);
       $__p$0$i$i$i$i = $44;
      } else {
       $45 = (($41) + 16)|0;
       $46 = $45 & -16;
       __THREW__ = 0;
       $47 = (invoke_ii(2988,($46|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        label = 21;
        break;
       }
       $50 = (($2) + 8|0);
       HEAP32[$50>>2] = $47;
       $51 = $46 | 1;
       HEAP32[$2>>2] = $51;
       $52 = (($2) + 4|0);
       HEAP32[$52>>2] = $41;
       $__p$0$i$i$i$i = $47;
      }
      _memcpy(($__p$0$i$i$i$i|0),($53|0),($41|0))|0;
      $54 = (($__p$0$i$i$i$i) + ($41)|0);
      HEAP8[$54>>0] = 0;
      __THREW__ = 0;
      (invoke_iii(2233,($type|0),($2|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       $73 = ___cxa_find_matching_catch()|0;
       $74 = tempRet0;
       $75 = HEAP8[$2>>0]|0;
       $76 = $75 & 1;
       $77 = ($76<<24>>24)==(0);
       if ($77) {
        $$0 = $74;$$01 = $73;
        break;
       }
       $78 = (($2) + 8|0);
       $79 = HEAP32[$78>>2]|0;
       __ZdlPv($79);
       $$0 = $74;$$01 = $73;
       break;
      }
      $57 = HEAP8[$2>>0]|0;
      $58 = $57 & 1;
      $59 = ($58<<24>>24)==(0);
      if (!($59)) {
       $60 = (($2) + 8|0);
       $61 = HEAP32[$60>>2]|0;
       __ZdlPv($61);
      }
      $62 = HEAP8[$3>>0]|0;
      $63 = $62 & 1;
      $64 = ($63<<24>>24)==(0);
      if ($64) {
       label = 34;
       break L5;
      }
      $65 = (($3) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($66|0),($$byval_copy2|0));
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if (!($68)) {
       label = 34;
       break L5;
      }
      $69 = ___cxa_find_matching_catch()|0;
      $70 = tempRet0;
      ___cxa_call_unexpected(($69|0));
      // unreachable;
     }
    } while(0);
    if ((label|0) == 21) {
     $71 = ___cxa_find_matching_catch()|0;
     $72 = tempRet0;
     $$0 = $72;$$01 = $71;
    }
    $80 = HEAP8[$3>>0]|0;
    $81 = $80 & 1;
    $82 = ($81<<24>>24)==(0);
    if ($82) {
     $$1 = $$0;$$12 = $$01;
    } else {
     $83 = (($3) + 8|0);
     $84 = HEAP32[$83>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($84|0),($$byval_copy2|0));
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $87 = ___cxa_find_matching_catch()|0;
      $88 = tempRet0;
      ___cxa_call_unexpected(($87|0));
      // unreachable;
     } else {
      $$1 = $$0;$$12 = $$01;
     }
    }
   }
  } else {
   __THREW__ = 0;
   $89 = (invoke_ii(3270,($object|0))|0);
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    label = 3;
   } else {
    __THREW__ = 0;
    invoke_viii(1631,($4|0),(618304|0),($89|0));
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     label = 3;
    } else {
     __THREW__ = 0;
     (invoke_iii(2233,($type|0),($4|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      $101 = ___cxa_find_matching_catch()|0;
      $102 = tempRet0;
      $103 = HEAP8[$4>>0]|0;
      $104 = $103 & 1;
      $105 = ($104<<24>>24)==(0);
      if ($105) {
       $$1 = $102;$$12 = $101;
       break;
      }
      $106 = (($4) + 8|0);
      $107 = HEAP32[$106>>2]|0;
      __ZdlPv($107);
      $$1 = $102;$$12 = $101;
      break;
     } else {
      $96 = HEAP8[$4>>0]|0;
      $97 = $96 & 1;
      $98 = ($97<<24>>24)==(0);
      if ($98) {
       label = 34;
       break;
      }
      $99 = (($4) + 8|0);
      $100 = HEAP32[$99>>2]|0;
      __ZdlPv($100);
      label = 34;
      break;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 34) {
  $108 = HEAP32[$object>>2]|0;
  $109 = (($108) + 32|0);
  $110 = HEAP32[$109>>2]|0;
  __THREW__ = 0;
  $111 = (invoke_ii($110|0,($object|0))|0);
  $112 = __THREW__; __THREW__ = 0;
  $113 = $112&1;
  if ($113) {
   label = 3;
  } else {
   $114 = HEAP8[$type>>0]|0;
   $115 = $114 & 1;
   $116 = ($115<<24>>24)==(0);
   if ($116) {
    $119 = (($type) + 1|0);
    $120 = $119;
   } else {
    $117 = (($type) + 8|0);
    $118 = HEAP32[$117>>2]|0;
    $120 = $118;
   }
   __THREW__ = 0;
   HEAP32[$$byval_copy2>>2] = $111;
   $vararg_ptr1 = (($$byval_copy2) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $120;
   invoke_viii(1617,($agg$result|0),(619616|0),($$byval_copy2|0));
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if ($122) {
    label = 3;
   } else {
    $$pre = HEAP8[$type>>0]|0;
    $phitmp = $$pre & 1;
    $phitmp12 = ($phitmp<<24>>24)==(0);
    if ($phitmp12) {
     STACKTOP = sp;return;
    }
    $123 = (($type) + 8|0);
    $124 = HEAP32[$123>>2]|0;
    __ZdlPv($124);
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 3) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $$1 = $9;$$12 = $8;
 }
 $125 = HEAP8[$type>>0]|0;
 $126 = $125 & 1;
 $127 = ($126<<24>>24)==(0);
 if ($127) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $128 = (($type) + 8|0);
 $129 = HEAP32[$128>>2]|0;
 __ZdlPv($129);
 ___resumeException($$12|0);
 // unreachable;
}
function __Z34FindAncestorComponentExactTypeImplRN5Unity10GameObjectEi($gameObject,$classId) {
 $gameObject = $gameObject|0;
 $classId = $classId|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $parent$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($gameObject)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $parent$01 = $0;
 }
 while(1) {
  $2 = (($parent$01) + 24|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($3,$classId)|0);
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $$0 = $4;
   label = 4;
   break;
  }
  $6 = (($parent$01) + 156|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0 = 0;
   label = 4;
   break;
  } else {
   $parent$01 = $7;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z27GetComponentsInChildrenImplILb1EEvRN5Unity10GameObjectEiR13dynamic_arrayIPNS0_9ComponentELj4EE($gameObject,$classID,$output) {
 $gameObject = $gameObject|0;
 $classID = $classID|0;
 $output = $output|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond$i = 0, $i$01 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($gameObject) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $4 = (($gameObject) + 24|0);
  $i$01$i = 0;
  while(1) {
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + ($i$01$i<<3)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($classID|0);
   if ($8) {
    $9 = ((($5) + ($i$01$i<<3)|0) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    HEAP32[$0>>2] = $10;
    __ZN13dynamic_arrayIPN5Unity9ComponentELj4EE9push_backERKS2_($output,$0);
   }
   $11 = (($i$01$i) + 1)|0;
   $exitcond$i = ($11|0)==($2|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $11;
   }
  }
 }
 $12 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($gameObject)|0);
 $13 = (($12) + 148|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = (($12) + 140|0);
 $i$01 = 0;
 while(1) {
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($i$01<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 24|0);
  $21 = HEAP32[$20>>2]|0;
  __Z27GetComponentsInChildrenImplILb1EEvRN5Unity10GameObjectEiR13dynamic_arrayIPNS0_9ComponentELj4EE($21,$classID,$output);
  $22 = (($i$01) + 1)|0;
  $exitcond = ($22|0)==($14|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $22;
  }
 }
 STACKTOP = sp;return;
}
function __Z18ExtractTagThrowingR11ICallString($name) {
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tagString = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $tagString = sp + 4|0;
 $0 = (__ZNK11ICallString6IsNullEv($name)|0);
 if ($0) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(619624,$vararg_buffer1);
  // unreachable;
 }
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($tagString,$name);
 __THREW__ = 0;
 $1 = (invoke_i(91)|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2423,($1|0),($tagString|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)==(-1);
   $8 = HEAP8[$tagString>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if (!($7)) {
    if ($10) {
     STACKTOP = sp;return ($4|0);
    }
    $11 = (($tagString) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    __ZdlPv($12);
    STACKTOP = sp;return ($4|0);
   }
   if ($10) {
    $22 = (($tagString) + 1|0);
    $23 = $22;
   } else {
    $20 = (($tagString) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $23 = $21;
   }
   __THREW__ = 0;
   HEAP32[$vararg_buffer1>>2] = $23;
   invoke_vii(2774,(619648|0),($vararg_buffer1|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    // unreachable;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $15 = HEAP8[$tagString>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  ___resumeException($13|0);
  // unreachable;
 }
 $18 = (($tagString) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 __ZdlPv($19);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z36GiveDebuggerChanceToAttachIfRequiredv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z17CreateBatchDeleteR11BatchDeletej($batch,$size) {
 $batch = $batch|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size>>>0)>(256);
 $1 = $0 ? 256 : $size;
 HEAP32[$batch>>2] = $1;
 $2 = (($batch) + 4|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z17CommitBatchDeleteR11BatchDelete($batchDelete) {
 $batchDelete = $batchDelete|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($batchDelete) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $9 = $1;$i$01 = 0;
 }
 while(1) {
  $3 = ((($batchDelete) + ($i$01<<2)|0) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $8 = $9;
  } else {
   __Z28delete_object_internal_step1P6Object($4);
   __Z28delete_object_internal_step2P6Object($4);
   $$pre = HEAP32[$0>>2]|0;
   $8 = $$pre;
  }
  $6 = (($i$01) + 1)|0;
  $7 = ($6>>>0)<($8>>>0);
  if ($7) {
   $9 = $8;$i$01 = $6;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z21InitializeBatchDeletev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z25BatchDeleteObjectInternalPKii($unloadObjects,$size) {
 $unloadObjects = $unloadObjects|0;
 $size = $size|0;
 var $$0 = 0, $$0$i = 0, $$02 = 0, $$old1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $batch = 0, $i$01$i = 0, $i$03 = 0;
 var $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $pos$i$i$i = sp + 1040|0;
 $0 = sp;
 $batch = sp + 8|0;
 $1 = ($size|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($batch) + 4|0);
 $$0 = $size;$$02 = $unloadObjects;
 while(1) {
  $3 = ($$0>>>0)>(256);
  $4 = $3 ? 256 : $$0;
  HEAP32[$batch>>2] = $4;
  HEAP32[$2>>2] = 0;
  $5 = ($4|0)==(0);
  if ($5) {
   HEAP32[$2>>2] = 0;
   $49 = 0;
  } else {
   $$pre = HEAP32[560624>>2]|0;
   $9 = $$pre;$i$03 = 0;
   while(1) {
    $6 = (($$02) + ($i$03<<2)|0);
    $7 = HEAP32[$6>>2]|0;
    HEAP32[$0>>2] = $7;
    $8 = ($9|0)==(0|0);
    if ($8) {
     $$0$i = 0;$51 = 0;
    } else {
     $10 = (($9) + 36|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($9) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($11|0)==($13|0);
     do {
      if ($14) {
       $15 = (($9) + 28|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = (($9) + 32|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = (($16) + ($18<<3)|0);
       $35 = $19;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$9,$0);
       $20 = HEAP32[$pos$i$i$i>>2]|0;
       $21 = ($20|0)==(-1);
       $22 = (($9) + 28|0);
       $23 = HEAP32[$22>>2]|0;
       if ($21) {
        $24 = (($9) + 32|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = (($23) + ($25<<3)|0);
        $35 = $26;
        break;
       } else {
        $27 = (($23) + ($20<<3)|0);
        $35 = $27;
        break;
       }
      }
     } while(0);
     $28 = HEAP32[560624>>2]|0;
     $29 = (($28) + 28|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + 32|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($30) + ($32<<3)|0);
     $34 = ($35|0)==($33|0);
     if ($34) {
      $$0$i = 0;$51 = $28;
     } else {
      $36 = (($35) + 4|0);
      $37 = HEAP32[$36>>2]|0;
      $$0$i = $37;$51 = $28;
     }
    }
    $38 = ((($batch) + ($i$03<<2)|0) + 8|0);
    HEAP32[$38>>2] = $$0$i;
    $39 = (($i$03) + 1)|0;
    $40 = HEAP32[$batch>>2]|0;
    $41 = ($39>>>0)<($40>>>0);
    if ($41) {
     $9 = $51;$i$03 = $39;
    } else {
     break;
    }
   }
   HEAP32[$2>>2] = $40;
   $42 = ($40|0)==(0);
   if ($42) {
    $49 = 0;
   } else {
    $i$01$i = 0;
    while(1) {
     $43 = ((($batch) + ($i$01$i<<2)|0) + 8|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==(0|0);
     if (!($45)) {
      __Z28delete_object_internal_step1P6Object($44);
      __Z28delete_object_internal_step2P6Object($44);
     }
     $46 = (($i$01$i) + 1)|0;
     $47 = ($46>>>0)<($40>>>0);
     if ($47) {
      $i$01$i = $46;
     } else {
      $49 = $40;
      break;
     }
    }
   }
  }
  $48 = (($$0) - ($49))|0;
  $50 = (($$02) + ($49<<2)|0);
  $$old1 = ($$0|0)==($49|0);
  if ($$old1) {
   break;
  } else {
   $$0 = $48;$$02 = $50;
  }
 }
 STACKTOP = sp;return;
}
function __Z26GarbageCollectSharedAssetsb($monoReferences) {
 $monoReferences = $monoReferences|0;
 var $$0 = 0, $$0$i72 = 0, $$0$i94 = 0, $$01 = 0, $$01$i = 0, $$01$i$i$i$i$i = 0, $$01$i71 = 0, $$01$i93 = 0, $$byval_copy80 = 0, $$idx$i = 0, $$idx$val$i = 0, $$lcssa3566$i = 0, $$lcssa3765$i = 0, $$lcssa3964$i = 0, $$lcssa4363$i = 0, $$lcssa67$i = 0, $$ph$ph$i = 0, $$ph$ph28$i = 0, $$ph23$ph$i = 0, $$ph23$ph29$i = 0;
 var $$ph24$ph$i = 0, $$ph24$ph30$i = 0, $$ph25$ph$i = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i44 = 0, $$pre$i69 = 0, $$pre$phiZ2D = 0, $$pre$pre$phiZZ2D = 0, $$pre$pre$pre$pre = 0, $$pre59$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0.0, $256 = 0, $257 = 0, $258 = 0.0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0.0, $264 = 0, $265 = 0, $266 = 0.0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0.0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0.0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0.0, $334 = 0, $335 = 0, $336 = 0.0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0.0, $342 = 0, $343 = 0, $344 = 0.0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0.0, $427 = 0, $428 = 0, $429 = 0.0, $43 = 0;
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0.0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0.0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0.0, $472 = 0.0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0;
 var $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0;
 var $502 = 0, $503 = 0.0, $504 = 0, $505 = 0, $506 = 0.0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0;
 var $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0;
 var $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0.0, $555 = 0, $556 = 0;
 var $557 = 0.0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0;
 var $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0;
 var $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0.0;
 var $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0;
 var $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0.0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0;
 var $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0;
 var $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0;
 var $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0.0, $7 = 0, $70 = 0;
 var $700 = 0, $701 = 0, $702 = 0.0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0.0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0;
 var $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0.0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0.0, $735 = 0.0, $736 = Math_fround(0);
 var $737 = Math_fround(0), $738 = 0.0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0.0, $744 = 0.0, $745 = Math_fround(0), $746 = Math_fround(0), $747 = 0.0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0.0, $753 = 0.0, $754 = Math_fround(0);
 var $755 = Math_fround(0), $756 = 0.0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0.0, $766 = 0.0, $767 = Math_fround(0), $768 = Math_fround(0), $769 = 0.0, $77 = 0, $770 = 0.0, $771 = Math_fround(0), $772 = Math_fround(0);
 var $773 = 0.0, $774 = 0.0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0;
 var $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0;
 var $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0;
 var $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0;
 var $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i56 = 0, $cond$i = 0, $current$0$ph7$i = 0, $current$05$i = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body35$index11Z2D = 0, $eh$lpad$body35$indexZ2D = 0, $exitcond$i = 0, $exitcond$i$i = 0;
 var $i$01$i = 0, $i$01$i$i = 0, $i$01$i30 = 0, $i$045$i = 0, $index$0$ph$be$i = 0, $index$0$ph17$i = 0, $index$0$ph6$i = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index28 = 0, $lpad$phi$index = 0, $lpad$phi$index21 = 0, $lpad$phi130$index = 0, $lpad$phi130$index2 = 0, $objectsLeft$0$i = 0, $or$cond$i$i$i = 0, $phitmp$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i57 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i61 = 0;
 var $size$0$lcssa$i = 0, $size$0$ph20$i = 0, $size$014$i = 0, $state = 0, $state$idx$val = 0, $switch$i = 0, $threadState = 0, $threadState$idx$val = 0, $threadState$idx2$val = 0, $threadState$idx2$val$idx = 0, $threadState$idx2$val$idx$val = 0, $threadState$idx3$val = 0, $threadState$idx4$val = 0, $threadState$idx4$val$idx = 0, $threadState$idx4$val$idx$val = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i59 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i60 = 0, $vararg_ptr38 = 0;
 var $vararg_ptr42 = 0, $vararg_ptr43 = 0, $vararg_ptr44 = 0, $vararg_ptr45 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy80 = sp;
 $0 = sp + 348|0;
 $1 = sp + 344|0;
 $2 = sp + 340|0;
 $3 = sp + 336|0;
 $4 = sp + 332|0;
 $5 = sp + 328|0;
 $6 = sp + 324|0;
 $7 = sp + 320|0;
 $8 = sp + 316|0;
 $9 = sp + 312|0;
 $10 = sp + 308|0;
 $11 = sp + 304|0;
 $12 = sp + 300|0;
 $13 = sp + 296|0;
 $14 = sp + 292|0;
 $15 = sp + 288|0;
 $16 = sp + 352|0;
 $17 = sp + 80|0;
 $18 = sp + 72|0;
 $19 = sp + 40|0;
 $20 = sp + 56|0;
 $21 = sp + 60|0;
 $22 = sp + 64|0;
 $23 = sp + 68|0;
 $24 = sp + 208|0;
 $25 = sp + 84|0;
 $26 = sp + 88|0;
 $27 = sp + 92|0;
 $28 = sp + 96|0;
 $29 = sp + 100|0;
 $30 = sp + 104|0;
 $state = sp + 112|0;
 $threadState = sp + 212|0;
 $31 = (+_emscripten_get_now());
 $32 = $31 * 1.0E+6;
 $33 = (~~$32)>>>0;
 $34 = +Math_abs($32) >= 1.0 ? $32 > 0.0 ? (Math_min(+Math_floor($32 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($32 - +(~~$32 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $35 = HEAP32[560624>>2]|0;
 $36 = (($35) + 36|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) - ($39))|0;
 $41 = HEAP32[628512>>2]|0;
 HEAP32[$state>>2] = 0;
 $42 = (($state) + 4|0);
 HEAP32[$42>>2] = $41;
 $43 = (($state) + 8|0);
 HEAP32[$43>>2] = 0;
 $44 = (($state) + 12|0);
 HEAP32[$44>>2] = 0;
 $45 = (($state) + 16|0);
 HEAP32[$45>>2] = 0;
 $46 = (($state) + 24|0);
 HEAP32[$46>>2] = 0;
 $47 = (($state) + 28|0);
 HEAP32[$47>>2] = 0;
 $48 = (($state) + 20|0);
 HEAP32[$48>>2] = 61;
 $49 = (($state) + 40|0);
 HEAP32[$49>>2] = 0;
 $50 = (($state) + 44|0);
 HEAP8[$50>>0] = 0;
 $51 = (($state) + 45|0);
 HEAP8[$51>>0] = 0;
 $52 = (($state) + 48|0);
 ;HEAP32[$52+0>>2]=0|0;HEAP32[$52+4>>2]=0|0;HEAP32[$52+8>>2]=0|0;HEAP32[$52+12>>2]=0|0;HEAP32[$52+16>>2]=0|0;
 $53 = (($state) + 68|0);
 HEAP32[$53>>2] = 32;
 $54 = (($state) + 72|0);
 HEAP32[$54>>2] = 0;
 $55 = (($state) + 80|0);
 HEAP32[$55>>2] = 16;
 $56 = (($state) + 76|0);
 HEAP32[$56>>2] = 6;
 $57 = (($state) + 84|0);
 HEAP8[$57>>0] = 0;
 $58 = (($state) + 92|0);
 $59 = $monoReferences&1;
 HEAP8[$58>>0] = $59;
 $60 = (($state) + 88|0);
 HEAP32[$60>>2] = $40;
 __THREW__ = 0;
 $61 = (+invoke_d(2));
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 L1: do {
  if ($63) {
   label = 130;
  } else {
   $64 = $61 * 1.0E+6;
   $65 = (~~$64)>>>0;
   $66 = +Math_abs($64) >= 1.0 ? $64 > 0.0 ? (Math_min(+Math_floor($64 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($64 - +(~~$64 >>> 0)) / 4294967296.0) >>> 0 : 0;
   $67 = HEAP32[560624>>2]|0;
   $68 = (($67) + 36|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($67) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($69) - ($71))|0;
   HEAP32[$60>>2] = $72;
   $73 = HEAP32[$68>>2]|0;
   $74 = HEAP32[$70>>2]|0;
   $75 = (($73) - ($74))|0;
   HEAP32[$43>>2] = $75;
   $76 = HEAP32[$44>>2]|0;
   $77 = $76 & 2147483647;
   $78 = ($77>>>0)<($75>>>0);
   do {
    if ($78) {
     $79 = ($76|0)>(-1);
     if ($79) {
      HEAP32[$44>>2] = $75;
      $80 = HEAP32[$state>>2]|0;
      $81 = $75 << 3;
      $82 = HEAP32[$42>>2]|0;
      HEAP32[$26>>2] = $82;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$26+0>>2]|0;
      $83 = (invoke_iiiiiiii(108,($80|0),($81|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if ($85) {
       label = 130;
       break L1;
      }
      HEAP32[$state>>2] = $83;
      break;
     } else {
      $86 = $75 << 3;
      $87 = HEAP32[$42>>2]|0;
      HEAP32[$27>>2] = $87;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$27+0>>2]|0;
      $88 = (invoke_iiiiiii(102,($86|0),4,($$byval_copy80|0),0,(621264|0),352)|0);
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      if ($90) {
       label = 130;
       break L1;
      }
      $91 = HEAP32[$state>>2]|0;
      $92 = HEAP32[$43>>2]|0;
      $93 = $92 << 3;
      _memcpy(($88|0),($91|0),($93|0))|0;
      HEAP32[$44>>2] = $75;
      HEAP32[$state>>2] = $88;
      break;
     }
    }
   } while(0);
   $94 = (($67) + 28|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($67) + 32|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($95) + ($97<<3)|0);
   $99 = ($97|0)==(0);
   L11: do {
    if ($99) {
     $117 = $95;
     label = 15;
    } else {
     $100 = (($67) + 20|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (($67) + 8|0);
     $103 = (($67) + 12|0);
     $105 = $95;
     while(1) {
      $104 = HEAP32[$105>>2]|0;
      $106 = ($101|0)==($104|0);
      if (!($106)) {
       $107 = HEAP8[$102>>0]|0;
       $108 = ($107<<24>>24)==(0);
       if ($108) {
        $117 = $105;
        label = 15;
        break L11;
       }
       $109 = HEAP32[$70>>2]|0;
       $110 = ($109|0)==(0);
       if ($110) {
        $117 = $105;
        label = 15;
        break L11;
       }
       $111 = HEAP32[$103>>2]|0;
       $112 = ($111|0)==($104|0);
       if (!($112)) {
        $117 = $105;
        label = 15;
        break L11;
       }
      }
      $113 = (($105) + 8|0);
      $114 = ($113|0)==($98|0);
      if ($114) {
       break;
      } else {
       $105 = $113;
      }
     }
    }
   } while(0);
   L20: do {
    if ((label|0) == 15) {
     $115 = HEAP32[$state>>2]|0;
     $116 = ($117|0)==($98|0);
     if (!($116)) {
      $current$0$ph7$i = $117;$index$0$ph6$i = 0;
      while(1) {
       $current$05$i = $current$0$ph7$i;
       while(1) {
        $120 = HEAP32[$current$05$i>>2]|0;
        $switch$i = ($120>>>0)>(4294967293);
        $119 = (($current$05$i) + 8|0);
        if (!($switch$i)) {
         break;
        }
        $118 = ($119|0)==($98|0);
        if ($118) {
         break L20;
        } else {
         $current$05$i = $119;
        }
       }
       $121 = (($current$05$i) + 4|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = (($115) + ($index$0$ph6$i<<3)|0);
       HEAP32[$123>>2] = $122;
       $124 = (($122) + 8|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = $125 >>> 21;
       $127 = ((($115) + ($index$0$ph6$i<<3)|0) + 4|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = $128 & -1073741824;
       $130 = $129 | $126;
       HEAP32[$127>>2] = $130;
       $131 = HEAP32[$124>>2]|0;
       $132 = $131 << 10;
       $133 = $132 & 1073741824;
       $134 = $130 & -2147481601;
       $135 = $134 | $133;
       HEAP32[$127>>2] = $135;
       $136 = HEAP32[$124>>2]|0;
       $137 = $136 << 12;
       $138 = $137 & -2147483648;
       $139 = $135 & 1073743871;
       $140 = $139 | $138;
       HEAP32[$127>>2] = $140;
       $141 = (($index$0$ph6$i) + 1)|0;
       $142 = ($119|0)==($98|0);
       if ($142) {
        break;
       } else {
        $current$0$ph7$i = $119;$index$0$ph6$i = $141;
       }
      }
     }
    }
   } while(0);
   $143 = HEAP32[$43>>2]|0;
   $144 = HEAP32[$state>>2]|0;
   $145 = (($state) + 16|0);
   $146 = HEAP32[$47>>2]|0;
   $147 = $146 & 2147483647;
   $148 = ($147>>>0)<($143>>>0);
   do {
    if ($148) {
     $149 = ($146|0)>(-1);
     if ($149) {
      HEAP32[$47>>2] = $143;
      $150 = HEAP32[$145>>2]|0;
      $151 = $143 << 2;
      $152 = HEAP32[$48>>2]|0;
      HEAP32[$22>>2] = $152;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$22+0>>2]|0;
      $153 = (invoke_iiiiiiii(108,($150|0),($151|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       label = 130;
       break L1;
      }
      HEAP32[$145>>2] = $153;
      break;
     } else {
      $156 = $143 << 2;
      $157 = HEAP32[$48>>2]|0;
      HEAP32[$23>>2] = $157;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$23+0>>2]|0;
      $158 = (invoke_iiiiiii(102,($156|0),4,($$byval_copy80|0),0,(621264|0),352)|0);
      $159 = __THREW__; __THREW__ = 0;
      $160 = $159&1;
      if ($160) {
       label = 130;
       break L1;
      }
      $161 = HEAP32[$145>>2]|0;
      $162 = HEAP32[$46>>2]|0;
      $163 = $162 << 2;
      _memcpy(($158|0),($161|0),($163|0))|0;
      HEAP32[$47>>2] = $143;
      HEAP32[$145>>2] = $158;
      break;
     }
    }
   } while(0);
   $164 = ($143|0)>(0);
   L37: do {
    if ($164) {
     $index$0$ph17$i = 0;$size$0$ph20$i = $143;
     L39: while(1) {
      $165 = (($144) + ($index$0$ph17$i<<3)|0);
      $166 = ((($144) + ($index$0$ph17$i<<3)|0) + 4|0);
      $size$014$i = $size$0$ph20$i;
      L41: while(1) {
       $167 = HEAP32[$166>>2]|0;
       $168 = $167 & 536870911;
       $169 = $167 & 1073741824;
       $170 = ($169|0)==(0);
       do {
        if ($170) {
         if ((($168|0) == 4) | (($168|0) == 1)) {
          break;
         } else if ((($168|0) == 114)) {
          label = 31;
          break L41;
         }
         $175 = HEAP32[560640>>2]|0;
         $176 = Math_imul($175, $168)|0;
         $177 = (($176) + 2)|0;
         $178 = $177 >> 5;
         $179 = $178 << 5;
         $180 = (($177) - ($179))|0;
         $181 = HEAP32[560632>>2]|0;
         $182 = (($181) + ($178<<2)|0);
         $183 = HEAP32[$182>>2]|0;
         $184 = 1 << $180;
         $185 = $184 & $183;
         $186 = ($185|0)==(0);
         if ($186) {
          label = 33;
         } else {
          label = 36;
          break L41;
         }
        } else {
         label = 33;
        }
       } while(0);
       if ((label|0) == 33) {
        label = 0;
        $187 = ($168|0)==(142);
        if (!($187)) {
         label = 34;
         break;
        }
       }
       $190 = (($size$014$i) + -1)|0;
       $191 = (($144) + ($190<<3)|0);
       $192 = $191;
       $193 = $192;
       $194 = HEAP32[$193>>2]|0;
       $195 = (($192) + 4)|0;
       $196 = $195;
       $197 = HEAP32[$196>>2]|0;
       $198 = $165;
       $199 = $198;
       HEAP32[$199>>2] = $194;
       $200 = (($198) + 4)|0;
       $201 = $200;
       HEAP32[$201>>2] = $197;
       $202 = ($index$0$ph17$i|0)<($190|0);
       if ($202) {
        $size$014$i = $190;
       } else {
        $size$0$lcssa$i = $190;
        break L37;
       }
      }
      if ((label|0) == 31) {
       label = 0;
       $171 = HEAP32[$165>>2]|0;
       $172 = (($171) + 24|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ($173|0)==(0|0);
       if ($174) {
        label = 34;
       } else {
        label = 36;
       }
      }
      if ((label|0) == 34) {
       label = 0;
       $188 = $167 >> 31;
       $189 = $188 & 2;
       $cond$i = ($189|0)==(0);
       if (!($cond$i)) {
        label = 36;
       }
      }
      L53: do {
       if ((label|0) == 36) {
        label = 0;
        $203 = HEAP32[$state>>2]|0;
        $204 = ((($203) + ($index$0$ph17$i<<3)|0) + 4|0);
        $205 = HEAP32[$204>>2]|0;
        $206 = $205 | 536870912;
        HEAP32[$204>>2] = $206;
        $207 = $205 & 536870911;
        switch ($207|0) {
        case 78: case 27: case 28: case 43: case 84: case 89: case 115: case 117: case 142: case 147: case 149: case 150: case 158: case 171:  {
         break L53;
         break;
        }
        default: {
        }
        }
        $208 = HEAP32[$46>>2]|0;
        $209 = (($208) + 1)|0;
        HEAP32[$46>>2] = $209;
        $210 = HEAP32[$47>>2]|0;
        $211 = $210 & 2147483647;
        $212 = ($209>>>0)>($211>>>0);
        if ($212) {
         $213 = $210 << 1;
         $214 = ($213|0)==(0);
         $215 = $214 ? 1 : $213;
         $216 = ($211>>>0)<($215>>>0);
         do {
          if ($216) {
           $217 = ($210|0)>(-1);
           if ($217) {
            HEAP32[$47>>2] = $215;
            $218 = HEAP32[$145>>2]|0;
            $219 = $215 << 2;
            $220 = HEAP32[$48>>2]|0;
            HEAP32[$20>>2] = $220;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$20+0>>2]|0;
            $221 = (invoke_iiiiiiii(108,($218|0),($219|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
            $222 = __THREW__; __THREW__ = 0;
            $223 = $222&1;
            if ($223) {
             break L39;
            }
            HEAP32[$145>>2] = $221;
            break;
           } else {
            $224 = $215 << 2;
            $225 = HEAP32[$48>>2]|0;
            HEAP32[$21>>2] = $225;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$21+0>>2]|0;
            $226 = (invoke_iiiiiii(102,($224|0),4,($$byval_copy80|0),0,(621264|0),352)|0);
            $227 = __THREW__; __THREW__ = 0;
            $228 = $227&1;
            if ($228) {
             break L39;
            }
            $229 = HEAP32[$145>>2]|0;
            $230 = HEAP32[$46>>2]|0;
            $231 = $230 << 2;
            _memcpy(($226|0),($229|0),($231|0))|0;
            HEAP32[$47>>2] = $215;
            HEAP32[$145>>2] = $226;
            break;
           }
          }
         } while(0);
         $$pre$i$i$i$i = HEAP32[$46>>2]|0;
         $233 = $$pre$i$i$i$i;
        } else {
         $233 = $209;
        }
        $232 = (($233) + -1)|0;
        $234 = HEAP32[$145>>2]|0;
        $235 = (($234) + ($232<<2)|0);
        HEAP32[$235>>2] = $index$0$ph17$i;
       }
      } while(0);
      $index$0$ph$be$i = (($index$0$ph17$i) + 1)|0;
      $236 = ($index$0$ph$be$i|0)<($size$014$i|0);
      if ($236) {
       $index$0$ph17$i = $index$0$ph$be$i;$size$0$ph20$i = $size$014$i;
      } else {
       $size$0$lcssa$i = $size$014$i;
       break L37;
      }
     }
     $525 = ___cxa_find_matching_catch()|0;
     $526 = tempRet0;
     $lpad$phi130$index = $525;$lpad$phi130$index2 = $526;
     label = 131;
     break L1;
    } else {
     $size$0$lcssa$i = $143;
    }
   } while(0);
   HEAP32[$43>>2] = $size$0$lcssa$i;
   $237 = HEAP32[$44>>2]|0;
   $238 = $237 & 2147483647;
   $239 = ($238>>>0)<($size$0$lcssa$i>>>0);
   do {
    if ($239) {
     $240 = ($237|0)>(-1);
     if ($240) {
      HEAP32[$44>>2] = $size$0$lcssa$i;
      $241 = HEAP32[$state>>2]|0;
      $242 = $size$0$lcssa$i << 3;
      $243 = HEAP32[$42>>2]|0;
      HEAP32[$24>>2] = $243;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$24+0>>2]|0;
      $244 = (invoke_iiiiiiii(108,($241|0),($242|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
      $245 = __THREW__; __THREW__ = 0;
      $246 = $245&1;
      if ($246) {
       label = 130;
       break L1;
      }
      HEAP32[$state>>2] = $244;
      break;
     } else {
      $247 = $size$0$lcssa$i << 3;
      $248 = HEAP32[$42>>2]|0;
      HEAP32[$25>>2] = $248;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$25+0>>2]|0;
      $249 = (invoke_iiiiiii(102,($247|0),4,($$byval_copy80|0),0,(621264|0),352)|0);
      $250 = __THREW__; __THREW__ = 0;
      $251 = $250&1;
      if ($251) {
       label = 130;
       break L1;
      }
      $252 = HEAP32[$state>>2]|0;
      $253 = HEAP32[$43>>2]|0;
      $254 = $253 << 3;
      _memcpy(($249|0),($252|0),($254|0))|0;
      HEAP32[$44>>2] = $size$0$lcssa$i;
      HEAP32[$state>>2] = $249;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   $255 = (+invoke_d(2));
   $256 = __THREW__; __THREW__ = 0;
   $257 = $256&1;
   if ($257) {
    label = 130;
   } else {
    $258 = $255 * 1.0E+6;
    $259 = (~~$258)>>>0;
    $260 = +Math_abs($258) >= 1.0 ? $258 > 0.0 ? (Math_min(+Math_floor($258 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($258 - +(~~$258 >>> 0)) / 4294967296.0) >>> 0 : 0;
    $261 = (_i64Subtract(($259|0),($260|0),($65|0),($66|0))|0);
    $262 = tempRet0;
    __THREW__ = 0;
    $263 = (+invoke_d(2));
    $264 = __THREW__; __THREW__ = 0;
    $265 = $264&1;
    if ($265) {
     label = 130;
    } else {
     $266 = $263 * 1.0E+6;
     $267 = (~~$266)>>>0;
     $268 = +Math_abs($266) >= 1.0 ? $266 > 0.0 ? (Math_min(+Math_floor($266 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($266 - +(~~$266 >>> 0)) / 4294967296.0) >>> 0 : 0;
     HEAP8[$51>>0] = 1;
     $269 = (($state) + 56|0);
     $270 = $269;
     $271 = $270;
     HEAP32[$271>>2] = -1;
     $272 = (($270) + 4)|0;
     $273 = $272;
     HEAP32[$273>>2] = 0;
     $274 = HEAP32[$53>>2]|0;
     $275 = $274 << 3;
     HEAP32[$17>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$17+0>>2]|0;
     $276 = (invoke_iiiiiii(102,($275|0),16,($$byval_copy80|0),0,(621264|0),79)|0);
     $277 = __THREW__; __THREW__ = 0;
     $278 = $277&1;
     if ($278) {
      label = 130;
     } else {
      $279 = (($state) + 64|0);
      HEAP32[$279>>2] = $276;
      $280 = HEAP32[$53>>2]|0;
      $281 = (($276) + ($280<<3)|0);
      $282 = ($276|0)==($281|0);
      if (!($282)) {
       $$01$i$i$i$i$i = $276;
       while(1) {
        $283 = ($$01$i$i$i$i$i|0)==(0|0);
        if (!($283)) {
         $284 = $269;
         $285 = $284;
         $286 = HEAP32[$285>>2]|0;
         $287 = (($284) + 4)|0;
         $288 = $287;
         $289 = HEAP32[$288>>2]|0;
         $290 = $$01$i$i$i$i$i;
         $291 = $290;
         HEAP32[$291>>2] = $286;
         $292 = (($290) + 4)|0;
         $293 = $292;
         HEAP32[$293>>2] = $289;
        }
        $294 = (($$01$i$i$i$i$i) + 8|0);
        $295 = ($294|0)==($281|0);
        if ($295) {
         break;
        } else {
         $$01$i$i$i$i$i = $294;
        }
       }
      }
      $296 = (($state) + 36|0);
      __THREW__ = 0;
      invoke_vi(3521,($296|0));
      $297 = __THREW__; __THREW__ = 0;
      $298 = $297&1;
      if ($298) {
       label = 130;
      } else {
       HEAP8[$50>>0] = 1;
       $299 = (($state) + 48|0);
       $300 = $299;
       $301 = $300;
       HEAP32[$301>>2] = -2;
       $302 = (($300) + 4)|0;
       $303 = $302;
       HEAP32[$303>>2] = 0;
       $304 = HEAP32[$43>>2]|0;
       $305 = $304 << 1;
       $306 = HEAP8[$57>>0]|0;
       $307 = ($306<<24>>24)!=(0);
       $308 = ($305|0)==(0);
       $or$cond$i$i$i = $307 | $308;
       if ($or$cond$i$i$i) {
        __THREW__ = 0;
        invoke_vi(3522,($296|0));
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        if ($310) {
         label = 130;
         break;
        }
       }
       $311 = HEAP32[$54>>2]|0;
       $312 = ($311>>>0)<($305>>>0);
       if ($312) {
        $313 = (($305) - ($311))|0;
        __THREW__ = 0;
        invoke_viii(1782,($296|0),($313|0),0);
        $314 = __THREW__; __THREW__ = 0;
        $315 = $314&1;
        if ($315) {
         label = 130;
         break;
        }
       }
       $316 = HEAP32[$43>>2]|0;
       $317 = ($316|0)==(0);
       L95: do {
        if (!($317)) {
         $318 = (($18) + 4|0);
         $845 = $316;$i$01$i = 0;
         while(1) {
          $319 = HEAP32[$state>>2]|0;
          $320 = ((($319) + ($i$01$i<<3)|0) + 4|0);
          $321 = HEAP32[$320>>2]|0;
          $322 = $321 & 536870912;
          $323 = ($322|0)==(0);
          if ($323) {
           $324 = (($319) + ($i$01$i<<3)|0);
           $325 = HEAP32[$324>>2]|0;
           $326 = (($325) + 4|0);
           $327 = HEAP32[$326>>2]|0;
           HEAP32[$18>>2] = $327;
           HEAP32[$318>>2] = $i$01$i;
           __THREW__ = 0;
           invoke_viii(1782,($296|0),1,0);
           $328 = __THREW__; __THREW__ = 0;
           $329 = $328&1;
           if ($329) {
            break;
           }
           __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E15insert_noresizeERKS3_($19,$296,$18);
           $$pre$i = HEAP32[$43>>2]|0;
           $332 = $$pre$i;
          } else {
           $332 = $845;
          }
          $330 = (($i$01$i) + 1)|0;
          $331 = ($330>>>0)<($332>>>0);
          if ($331) {
           $845 = $332;$i$01$i = $330;
          } else {
           break L95;
          }
         }
         $523 = ___cxa_find_matching_catch()|0;
         $524 = tempRet0;
         $$pre$pre$phiZZ2D = $279;$eh$lpad$body35$index11Z2D = $524;$eh$lpad$body35$indexZ2D = $523;
         label = 132;
         break L1;
        }
       } while(0);
       __THREW__ = 0;
       $333 = (+invoke_d(2));
       $334 = __THREW__; __THREW__ = 0;
       $335 = $334&1;
       if ($335) {
        label = 130;
       } else {
        $336 = $333 * 1.0E+6;
        $337 = (~~$336)>>>0;
        $338 = +Math_abs($336) >= 1.0 ? $336 > 0.0 ? (Math_min(+Math_floor($336 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($336 - +(~~$336 >>> 0)) / 4294967296.0) >>> 0 : 0;
        $339 = (_i64Subtract(($337|0),($338|0),($267|0),($268|0))|0);
        $340 = tempRet0;
        __THREW__ = 0;
        $341 = (+invoke_d(2));
        $342 = __THREW__; __THREW__ = 0;
        $343 = $342&1;
        if ($343) {
         label = 130;
        } else {
         $344 = $341 * 1.0E+6;
         $345 = (~~$344)>>>0;
         $346 = +Math_abs($344) >= 1.0 ? $344 > 0.0 ? (Math_min(+Math_floor($344 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($344 - +(~~$344 >>> 0)) / 4294967296.0) >>> 0 : 0;
         $i$01$i30 = 0;
         while(1) {
          __THREW__ = 0;
          $347 = (invoke_ii(3271,($i$01$i30|0))|0);
          $348 = __THREW__; __THREW__ = 0;
          $349 = $348&1;
          if ($349) {
           label = 127;
           break;
          }
          $350 = ($347|0)==(0|0);
          if (!($350)) {
           __THREW__ = 0;
           $351 = (invoke_ii(3271,($i$01$i30|0))|0);
           $352 = __THREW__; __THREW__ = 0;
           $353 = $352&1;
           if ($353) {
            label = 127;
            break;
           }
           $$idx$i = (($351) + 4|0);
           $$idx$val$i = HEAP32[$$idx$i>>2]|0;
           __THREW__ = 0;
           invoke_vii(2775,($$idx$val$i|0),($state|0));
           $354 = __THREW__; __THREW__ = 0;
           $355 = $354&1;
           if ($355) {
            label = 127;
            break;
           }
          }
          $356 = (($i$01$i30) + 1)|0;
          $exitcond$i = ($356|0)==(20);
          if ($exitcond$i) {
           break;
          } else {
           $i$01$i30 = $356;
          }
         }
         if ((label|0) == 127) {
          $521 = ___cxa_find_matching_catch()|0;
          $522 = tempRet0;
          $$pre$pre$phiZZ2D = $279;$eh$lpad$body35$index11Z2D = $522;$eh$lpad$body35$indexZ2D = $521;
          label = 132;
          break;
         }
         $357 = (($threadState) + 4|0);
         HEAP32[$357>>2] = $state;
         $358 = (($threadState) + 8|0);
         HEAP32[$358>>2] = 0;
         $359 = (($threadState) + 16|0);
         HEAP32[$359>>2] = 0;
         $360 = (($threadState) + 20|0);
         HEAP32[$360>>2] = 0;
         $361 = (($threadState) + 12|0);
         HEAP32[$361>>2] = 61;
         $362 = (($threadState) + 32|0);
         __THREW__ = 0;
         invoke_viii(1728,($362|0),33562624,0);
         $363 = __THREW__; __THREW__ = 0;
         $364 = $363&1;
         if ($364) {
          $365 = ___cxa_find_matching_catch()|0;
          $366 = tempRet0;
          $367 = HEAP32[$360>>2]|0;
          $368 = ($367|0)>(-1);
          if (!($368)) {
           $$pre$pre$phiZZ2D = $279;$eh$lpad$body35$index11Z2D = $366;$eh$lpad$body35$indexZ2D = $365;
           label = 132;
           break;
          }
          $369 = HEAP32[$358>>2]|0;
          $370 = HEAP32[$361>>2]|0;
          HEAP32[$0>>2] = $370;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($369|0),($$byval_copy80|0));
          $371 = __THREW__; __THREW__ = 0;
          $372 = $371&1;
          if ($372) {
           $373 = ___cxa_find_matching_catch(0|0)|0;
           $374 = tempRet0;
           ___clang_call_terminate($373);
           // unreachable;
          } else {
           HEAP32[$358>>2] = 0;
           $$pre$pre$phiZZ2D = $279;$eh$lpad$body35$index11Z2D = $366;$eh$lpad$body35$indexZ2D = $365;
           label = 132;
           break;
          }
         }
         $375 = (($threadState) + 68|0);
         HEAP32[$375>>2] = ((621464 + 8|0));
         $376 = (($threadState) + 72|0);
         HEAP32[$376>>2] = $threadState;
         $377 = (($threadState) + 44|0);
         HEAP32[$377>>2] = $375;
         $378 = (($threadState) + 24|0);
         HEAP32[$378>>2] = 0;
         $379 = (($threadState) + 28|0);
         HEAPF32[$379>>2] = Math_fround(0.0);
         $380 = HEAP32[$357>>2]|0;
         $381 = (($380) + 8|0);
         $382 = HEAP32[$381>>2]|0;
         $383 = (($threadState) + 8|0);
         $384 = HEAP32[$360>>2]|0;
         $385 = $384 & 2147483647;
         $386 = ($385>>>0)<($382>>>0);
         do {
          if ($386) {
           $387 = ($384|0)>(-1);
           if ($387) {
            HEAP32[$360>>2] = $382;
            $388 = HEAP32[$383>>2]|0;
            $389 = $382 << 2;
            $390 = HEAP32[$361>>2]|0;
            HEAP32[$15>>2] = $390;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$15+0>>2]|0;
            $391 = (invoke_iiiiiiii(108,($388|0),($389|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
            $392 = __THREW__; __THREW__ = 0;
            $393 = $392&1;
            if ($393) {
             label = 135;
             break;
            }
            HEAP32[$383>>2] = $391;
            label = 90;
            break;
           } else {
            $394 = $382 << 2;
            $395 = HEAP32[$361>>2]|0;
            HEAP32[$16>>2] = $395;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$16+0>>2]|0;
            $396 = (invoke_iiiiiii(102,($394|0),4,($$byval_copy80|0),0,(621264|0),352)|0);
            $397 = __THREW__; __THREW__ = 0;
            $398 = $397&1;
            if ($398) {
             label = 135;
             break;
            }
            $399 = HEAP32[$383>>2]|0;
            $400 = HEAP32[$359>>2]|0;
            $401 = $400 << 2;
            _memcpy(($396|0),($399|0),($401|0))|0;
            HEAP32[$360>>2] = $382;
            HEAP32[$383>>2] = $396;
            label = 90;
            break;
           }
          } else {
           label = 90;
          }
         } while(0);
         do {
          if ((label|0) == 90) {
           $402 = HEAP32[$357>>2]|0;
           $403 = (($402) + 92|0);
           $404 = HEAP8[$403>>0]|0;
           $405 = ($404<<24>>24)==(0);
           if (!($405)) {
            __THREW__ = 0;
            $406 = (invoke_i(84)|0);
            $407 = __THREW__; __THREW__ = 0;
            $408 = $407&1;
            if ($408) {
             label = 135;
             break;
            }
            __THREW__ = 0;
            $409 = (invoke_iii(2424,($406|0),0)|0);
            $410 = __THREW__; __THREW__ = 0;
            $411 = $410&1;
            if ($411) {
             label = 135;
             break;
            }
            __THREW__ = 0;
            $412 = (invoke_iiiii(243,($409|0),($382|0),(1783|0),($threadState|0))|0);
            $413 = __THREW__; __THREW__ = 0;
            $414 = $413&1;
            if ($414) {
             label = 135;
             break;
            }
            HEAP32[$threadState>>2] = $412;
           }
           $415 = HEAP32[$46>>2]|0;
           $416 = (($state) + 32|0);
           HEAP32[$416>>2] = $415;
           $417 = HEAP8[$58>>0]|0;
           $418 = ($417<<24>>24)==(0);
           if (!($418)) {
            __THREW__ = 0;
            (invoke_i(54)|0);
            $419 = __THREW__; __THREW__ = 0;
            $420 = $419&1;
            if ($420) {
             label = 135;
             break;
            }
            __THREW__ = 0;
            $421 = __THREW__; __THREW__ = 0;
            $422 = $421&1;
            if ($422) {
             label = 135;
             break;
            }
           }
           $threadState$idx2$val = HEAP32[$357>>2]|0;
           $threadState$idx2$val$idx = (($threadState$idx2$val) + 92|0);
           $threadState$idx2$val$idx$val = HEAP8[$threadState$idx2$val$idx>>0]|0;
           $423 = ($threadState$idx2$val$idx$val<<24>>24)==(0);
           if (!($423)) {
            $threadState$idx$val = HEAP32[$threadState>>2]|0;
            __THREW__ = 0;
            invoke_vi(3523,($threadState$idx$val|0));
            $424 = __THREW__; __THREW__ = 0;
            $425 = $424&1;
            if ($425) {
             label = 135;
             break;
            }
           }
           __THREW__ = 0;
           $426 = (+invoke_d(2));
           $427 = __THREW__; __THREW__ = 0;
           $428 = $427&1;
           if ($428) {
            label = 135;
            break;
           }
           $429 = $426 * 1.0E+6;
           $430 = HEAP32[$357>>2]|0;
           $431 = (($430) + 32|0);
           $432 = HEAP32[$431>>2]|0;
           $433 = (($432) + -1)|0;
           HEAP32[$431>>2] = $433;
           $434 = (($430) + 16|0);
           L147: while(1) {
            $objectsLeft$0$i = HEAP32[$431>>2]|0;
            $435 = ($objectsLeft$0$i|0)>(-1);
            if ($435) {
             $438 = HEAP32[$434>>2]|0;
             $439 = (($438) + ($objectsLeft$0$i<<2)|0);
             $440 = HEAP32[$439>>2]|0;
             __THREW__ = 0;
             invoke_vii(2776,($threadState|0),($440|0));
             $441 = __THREW__; __THREW__ = 0;
             $442 = $441&1;
             if ($442) {
              label = 134;
              break;
             }
             $443 = HEAP32[$378>>2]|0;
             $444 = (($443) + 1)|0;
             HEAP32[$378>>2] = $444;
             $$pre$i44 = HEAP32[$359>>2]|0;
             $445 = ($$pre$i44|0)==(0);
             if (!($445)) {
              $447 = $$pre$i44;
              label = 106;
             }
            } else {
             $436 = HEAP32[$359>>2]|0;
             $437 = ($436|0)==(0);
             if ($437) {
              label = 109;
              break;
             } else {
              $447 = $436;
              label = 106;
             }
            }
            if ((label|0) == 106) {
             while(1) {
              label = 0;
              $446 = (($447) + -1)|0;
              $448 = HEAP32[$358>>2]|0;
              $449 = (($448) + ($446<<2)|0);
              $450 = HEAP32[$449>>2]|0;
              HEAP32[$359>>2] = $446;
              __THREW__ = 0;
              invoke_vii(2776,($threadState|0),($450|0));
              $451 = __THREW__; __THREW__ = 0;
              $452 = $451&1;
              if ($452) {
               label = 133;
               break L147;
              }
              $453 = HEAP32[$359>>2]|0;
              $454 = ($453|0)==(0);
              if ($454) {
               break;
              } else {
               $447 = $453;
               label = 106;
              }
             }
            }
            $455 = HEAP32[$431>>2]|0;
            $456 = (($455) + -1)|0;
            HEAP32[$431>>2] = $456;
           }
           if ((label|0) == 109) {
            __THREW__ = 0;
            $457 = (+invoke_d(2));
            $458 = __THREW__; __THREW__ = 0;
            $459 = $458&1;
            if ($459) {
             label = 135;
             break;
            }
            $460 = (~~$429)>>>0;
            $461 = +Math_abs($429) >= 1.0 ? $429 > 0.0 ? (Math_min(+Math_floor($429 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($429 - +(~~$429 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $462 = $457 * 1.0E+6;
            $463 = (~~$462)>>>0;
            $464 = +Math_abs($462) >= 1.0 ? $462 > 0.0 ? (Math_min(+Math_floor($462 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($462 - +(~~$462 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $465 = (_i64Subtract(($463|0),($464|0),($460|0),($461|0))|0);
            $466 = tempRet0;
            __THREW__ = 0;
            $467 = (invoke_iii(2425,($465|0),($466|0))|0);
            $468 = tempRet0;
            $469 = __THREW__; __THREW__ = 0;
            $470 = $469&1;
            if ($470) {
             label = 135;
             break;
            }
            $471 = (+($467>>>0)) + (4294967296.0*(+($468>>>0)));
            $472 = $471 * 1.00000000000000006228E-9;
            $473 = Math_fround($472);
            $474 = Math_fround(HEAPF32[$379>>2]);
            $475 = Math_fround($473 + $474);
            HEAPF32[$379>>2] = $475;
            $state$idx$val = HEAP8[$58>>0]|0;
            $476 = ($state$idx$val<<24>>24)==(0);
            if (!($476)) {
             __THREW__ = 0;
             (invoke_i(54)|0);
             $477 = __THREW__; __THREW__ = 0;
             $478 = $477&1;
             if ($478) {
              label = 135;
              break;
             }
             __THREW__ = 0;
             $479 = __THREW__; __THREW__ = 0;
             $480 = $479&1;
             if ($480) {
              label = 135;
              break;
             }
            }
            $threadState$idx4$val = HEAP32[$357>>2]|0;
            $threadState$idx4$val$idx = (($threadState$idx4$val) + 92|0);
            $threadState$idx4$val$idx$val = HEAP8[$threadState$idx4$val$idx>>0]|0;
            $481 = ($threadState$idx4$val$idx$val<<24>>24)==(0);
            if (!($481)) {
             $threadState$idx3$val = HEAP32[$threadState>>2]|0;
             __THREW__ = 0;
             invoke_vi(3524,($threadState$idx3$val|0));
             $482 = __THREW__; __THREW__ = 0;
             $483 = $482&1;
             if ($483) {
              label = 135;
              break;
             }
            }
            $484 = (($threadState) + 48|0);
            $485 = HEAP32[$484>>2]|0;
            $486 = ($485|0)==(0|0);
            do {
             if (!($486)) {
              $487 = (($threadState) + 52|0);
              $488 = HEAP32[$487>>2]|0;
              $489 = ($488|0)==($485|0);
              if (!($489)) {
               $__new_last2$i$i$i$i$i$i$i$i$i = $485;
               $scevgep$i$i$i$i$i$i$i$i$i = (($488) + -4|0);
               $490 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
               $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($490)|0);
               $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
               $491 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 2;
               $492 = $491 ^ -1;
               $scevgep4$i$i$i$i$i$i$i$i$i = (($488) + ($492<<2)|0);
               HEAP32[$487>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
              }
              HEAP32[$14>>2] = 90;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$14+0>>2]|0;
              invoke_vii(2591,($485|0),($$byval_copy80|0));
              $493 = __THREW__; __THREW__ = 0;
              $494 = $493&1;
              if (!($494)) {
               break;
              }
              $495 = ___cxa_find_matching_catch()|0;
              $496 = tempRet0;
              ___cxa_call_unexpected(($495|0));
              // unreachable;
             }
            } while(0);
            $497 = HEAP32[$360>>2]|0;
            $498 = ($497|0)>(-1);
            if ($498) {
             $499 = HEAP32[$358>>2]|0;
             $500 = HEAP32[$361>>2]|0;
             HEAP32[$13>>2] = $500;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$13+0>>2]|0;
             invoke_vii(2591,($499|0),($$byval_copy80|0));
             $501 = __THREW__; __THREW__ = 0;
             $502 = $501&1;
             if ($502) {
              label = 130;
              break L1;
             }
             HEAP32[$358>>2] = 0;
            }
            __THREW__ = 0;
            $503 = (+invoke_d(2));
            $504 = __THREW__; __THREW__ = 0;
            $505 = $504&1;
            if ($505) {
             label = 130;
             break L1;
            }
            $506 = $503 * 1.0E+6;
            $507 = (~~$506)>>>0;
            $508 = +Math_abs($506) >= 1.0 ? $506 > 0.0 ? (Math_min(+Math_floor($506 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($506 - +(~~$506 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $509 = (_i64Subtract(($507|0),($508|0),($345|0),($346|0))|0);
            $510 = tempRet0;
            $511 = HEAP32[$60>>2]|0;
            $512 = HEAP32[560624>>2]|0;
            $513 = (($512) + 36|0);
            $514 = HEAP32[$513>>2]|0;
            $515 = (($512) + 4|0);
            $516 = HEAP32[$515>>2]|0;
            $517 = (($514) - ($516))|0;
            $518 = ($511|0)==($517|0);
            if (!($518)) {
             __THREW__ = 0;
             invoke_viiiiiiii(21,(621160|0),0,(621264|0),331,1,0,0,(0|0));
             $519 = __THREW__; __THREW__ = 0;
             $520 = $519&1;
             if ($520) {
              label = 130;
              break L1;
             }
            }
            __THREW__ = 0;
            $554 = (+invoke_d(2));
            $555 = __THREW__; __THREW__ = 0;
            $556 = $555&1;
            if ($556) {
             label = 130;
             break L1;
            }
            $557 = $554 * 1.0E+6;
            $558 = (~~$557)>>>0;
            $559 = +Math_abs($557) >= 1.0 ? $557 > 0.0 ? (Math_min(+Math_floor($557 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($557 - +(~~$557 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $560 = HEAP32[$43>>2]|0;
            $561 = ($560|0)==(0);
            L185: do {
             if ($561) {
              $$lcssa3566$i = 0;$$lcssa3765$i = 0;$$lcssa3964$i = 0;$$lcssa4363$i = 0;$$lcssa67$i = 0;
              label = 188;
             } else {
              $562 = $560 << 2;
              HEAP32[$8>>2] = 61;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$8+0>>2]|0;
              $563 = (invoke_iiiiiiii(108,(0|0),($562|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
              $564 = __THREW__; __THREW__ = 0;
              $565 = $564&1;
              if ($565) {
               $566 = ___cxa_find_matching_catch()|0;
               $567 = tempRet0;
               $639 = 0;$846 = $567;$847 = $566;$848 = 0;$849 = $560;
               label = 174;
               break;
              }
              $$pre$i69 = HEAP32[$43>>2]|0;
              $568 = ($$pre$i69|0)==(0);
              if ($568) {
               $$lcssa3566$i = 0;$$lcssa3765$i = $563;$$lcssa3964$i = 0;$$lcssa4363$i = 0;$$lcssa67$i = $560;
               label = 188;
               break;
              }
              $569 = $$pre$i69 << 2;
              HEAP32[$7>>2] = 61;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$7+0>>2]|0;
              $570 = (invoke_iiiiiiii(108,(0|0),($569|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
              $571 = __THREW__; __THREW__ = 0;
              $572 = $571&1;
              if ($572) {
               $$ph$ph28$i = $560;$$ph23$ph29$i = $563;$$ph24$ph30$i = $$pre$i69;$$ph25$ph$i = 0;
               label = 172;
               break;
              }
              $$pre59$i = HEAP32[$43>>2]|0;
              $phitmp$i = ($$pre59$i|0)==(0);
              if ($phitmp$i) {
               $$lcssa3566$i = 0;$$lcssa3765$i = $563;$$lcssa3964$i = $$pre$i69;$$lcssa4363$i = $570;$$lcssa67$i = $560;
               label = 188;
               break;
              }
              $583 = 0;$585 = $560;$593 = $563;$608 = 0;$610 = $$pre$i69;$618 = $570;$i$045$i = 0;
              L193: while(1) {
               $573 = HEAP32[$state>>2]|0;
               $574 = ((($573) + ($i$045$i<<3)|0) + 4|0);
               $575 = HEAP32[$574>>2]|0;
               $576 = $575 & 536870912;
               $577 = ($576|0)==(0);
               do {
                if ($577) {
                 $578 = (($573) + ($i$045$i<<3)|0);
                 $579 = HEAP32[$578>>2]|0;
                 $580 = (($579) + 4|0);
                 $581 = HEAP32[$580>>2]|0;
                 $582 = (($583) + 1)|0;
                 $584 = $585 & 2147483647;
                 $586 = ($582>>>0)>($584>>>0);
                 do {
                  if ($586) {
                   $587 = $585 << 1;
                   $588 = ($587|0)==(0);
                   $589 = $588 ? 1 : $587;
                   $590 = ($584>>>0)<($589>>>0);
                   if (!($590)) {
                    $603 = $593;$854 = $585;
                    break;
                   }
                   $591 = ($585|0)>(-1);
                   if ($591) {
                    $592 = $589 << 2;
                    HEAP32[$3>>2] = 61;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$3+0>>2]|0;
                    $594 = (invoke_iiiiiiii(108,($593|0),($592|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
                    $595 = __THREW__; __THREW__ = 0;
                    $596 = $595&1;
                    if ($596) {
                     $$ph$ph$i = $589;$$ph23$ph$i = $593;$$ph24$ph$i = $610;
                     label = 171;
                     break L193;
                    }
                    $603 = $594;$854 = $589;
                    break;
                   } else {
                    $597 = $589 << 2;
                    HEAP32[$4>>2] = 61;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$4+0>>2]|0;
                    $598 = (invoke_iiiiiii(102,($597|0),4,($$byval_copy80|0),0,(621264|0),352)|0);
                    $599 = __THREW__; __THREW__ = 0;
                    $600 = $599&1;
                    if ($600) {
                     $$ph$ph$i = $585;$$ph23$ph$i = $593;$$ph24$ph$i = $610;
                     label = 171;
                     break L193;
                    }
                    $601 = $582 << 2;
                    _memcpy(($598|0),($593|0),($601|0))|0;
                    $603 = $598;$854 = $589;
                    break;
                   }
                  } else {
                   $603 = $593;$854 = $585;
                  }
                 } while(0);
                 $602 = (($603) + ($583<<2)|0);
                 HEAP32[$602>>2] = $581;
                 $604 = HEAP32[$574>>2]|0;
                 $605 = $604 & 536870911;
                 $606 = ($605|0)==(114);
                 if (!($606)) {
                  $646 = $608;$648 = $618;$850 = $854;$851 = $582;$852 = $603;$853 = $610;
                  break;
                 }
                 $607 = (($608) + 1)|0;
                 $609 = $610 & 2147483647;
                 $611 = ($607>>>0)>($609>>>0);
                 do {
                  if ($611) {
                   $612 = $610 << 1;
                   $613 = ($612|0)==(0);
                   $614 = $613 ? 1 : $612;
                   $615 = ($609>>>0)<($614>>>0);
                   if (!($615)) {
                    $628 = $618;$855 = $610;
                    break;
                   }
                   $616 = ($610|0)>(-1);
                   if ($616) {
                    $617 = $614 << 2;
                    HEAP32[$1>>2] = 61;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$1+0>>2]|0;
                    $619 = (invoke_iiiiiiii(108,($618|0),($617|0),4,($$byval_copy80|0),0,(621264|0),370)|0);
                    $620 = __THREW__; __THREW__ = 0;
                    $621 = $620&1;
                    if ($621) {
                     $$ph$ph$i = $854;$$ph23$ph$i = $603;$$ph24$ph$i = $614;
                     label = 171;
                     break L193;
                    }
                    $628 = $619;$855 = $614;
                    break;
                   } else {
                    $622 = $614 << 2;
                    HEAP32[$2>>2] = 61;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$2+0>>2]|0;
                    $623 = (invoke_iiiiiii(102,($622|0),4,($$byval_copy80|0),0,(621264|0),352)|0);
                    $624 = __THREW__; __THREW__ = 0;
                    $625 = $624&1;
                    if ($625) {
                     $$ph$ph$i = $854;$$ph23$ph$i = $603;$$ph24$ph$i = $610;
                     label = 171;
                     break L193;
                    }
                    $626 = $607 << 2;
                    _memcpy(($623|0),($618|0),($626|0))|0;
                    $628 = $623;$855 = $614;
                    break;
                   }
                  } else {
                   $628 = $618;$855 = $610;
                  }
                 } while(0);
                 $627 = (($628) + ($608<<2)|0);
                 HEAP32[$627>>2] = $581;
                 $646 = $607;$648 = $628;$850 = $854;$851 = $582;$852 = $603;$853 = $855;
                } else {
                 $646 = $608;$648 = $618;$850 = $585;$851 = $583;$852 = $593;$853 = $610;
                }
               } while(0);
               $642 = (($i$045$i) + 1)|0;
               $643 = HEAP32[$43>>2]|0;
               $644 = ($642>>>0)<($643>>>0);
               if ($644) {
                $583 = $851;$585 = $850;$593 = $852;$608 = $646;$610 = $853;$618 = $648;$i$045$i = $642;
               } else {
                break;
               }
              }
              if ((label|0) == 171) {
               $633 = ___cxa_find_matching_catch()|0;
               $634 = tempRet0;
               $638 = $$ph24$ph$i;$856 = $$ph$ph$i;$857 = $$ph23$ph$i;$858 = $618;$lpad$phi$i$index = $633;$lpad$phi$i$index28 = $634;
               label = 173;
               break;
              }
              $645 = ($646|0)>(0);
              if (!($645)) {
               $$lcssa3566$i = $851;$$lcssa3765$i = $852;$$lcssa3964$i = $853;$$lcssa4363$i = $648;$$lcssa67$i = $850;
               label = 188;
               break;
              }
              $i$01$i$i = 0;
              L221: while(1) {
               $647 = (($648) + ($i$01$i$i<<2)|0);
               $649 = HEAP32[$647>>2]|0;
               HEAP32[$5>>2] = $649;
               $650 = HEAP32[560624>>2]|0;
               $651 = ($650|0)==(0|0);
               do {
                if (!($651)) {
                 $652 = (($650) + 36|0);
                 $653 = HEAP32[$652>>2]|0;
                 $654 = (($650) + 4|0);
                 $655 = HEAP32[$654>>2]|0;
                 $656 = ($653|0)==($655|0);
                 do {
                  if ($656) {
                   $657 = (($650) + 28|0);
                   $658 = HEAP32[$657>>2]|0;
                   $659 = (($650) + 32|0);
                   $660 = HEAP32[$659>>2]|0;
                   $661 = (($658) + ($660<<3)|0);
                   $677 = $661;
                  } else {
                   __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy80,$650,$5);
                   $662 = HEAP32[$$byval_copy80>>2]|0;
                   $663 = ($662|0)==(-1);
                   $664 = (($650) + 28|0);
                   $665 = HEAP32[$664>>2]|0;
                   if ($663) {
                    $666 = (($650) + 32|0);
                    $667 = HEAP32[$666>>2]|0;
                    $668 = (($665) + ($667<<3)|0);
                    $677 = $668;
                    break;
                   } else {
                    $669 = (($665) + ($662<<3)|0);
                    $677 = $669;
                    break;
                   }
                  }
                 } while(0);
                 $670 = HEAP32[560624>>2]|0;
                 $671 = (($670) + 28|0);
                 $672 = HEAP32[$671>>2]|0;
                 $673 = (($670) + 32|0);
                 $674 = HEAP32[$673>>2]|0;
                 $675 = (($672) + ($674<<3)|0);
                 $676 = ($677|0)==($675|0);
                 if ($676) {
                  break;
                 }
                 $678 = (($677) + 4|0);
                 $679 = HEAP32[$678>>2]|0;
                 $680 = ($679|0)==(0|0);
                 if ($680) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(3272,($679|0))|0);
                 $681 = __THREW__; __THREW__ = 0;
                 $682 = $681&1;
                 if ($682) {
                  break L221;
                 }
                }
               } while(0);
               $683 = (($i$01$i$i) + 1)|0;
               $exitcond$i$i = ($683|0)==($646|0);
               if ($exitcond$i$i) {
                $$lcssa3566$i = $851;$$lcssa3765$i = $852;$$lcssa3964$i = $853;$$lcssa4363$i = $648;$$lcssa67$i = $850;
                label = 188;
                break L185;
               } else {
                $i$01$i$i = $683;
               }
              }
              $631 = ___cxa_find_matching_catch()|0;
              $632 = tempRet0;
              $638 = $853;$856 = $850;$857 = $852;$858 = $648;$lpad$phi$i$index = $631;$lpad$phi$i$index28 = $632;
              label = 173;
             }
            } while(0);
            L236: do {
             if ((label|0) == 188) {
              __THREW__ = 0;
              invoke_vii(2777,($$lcssa3765$i|0),($$lcssa3566$i|0));
              $684 = __THREW__; __THREW__ = 0;
              $685 = $684&1;
              if ($685) {
               $$ph$ph28$i = $$lcssa67$i;$$ph23$ph29$i = $$lcssa3765$i;$$ph24$ph30$i = $$lcssa3964$i;$$ph25$ph$i = $$lcssa4363$i;
               label = 172;
               break;
              }
              $686 = ($$lcssa3964$i|0)>(-1);
              do {
               if ($686) {
                HEAP32[$6>>2] = 61;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$6+0>>2]|0;
                invoke_vii(2591,($$lcssa4363$i|0),($$byval_copy80|0));
                $687 = __THREW__; __THREW__ = 0;
                $688 = $687&1;
                if (!($688)) {
                 break;
                }
                $629 = ___cxa_find_matching_catch()|0;
                $630 = tempRet0;
                $$0$i72 = $629;$$01$i71 = $630;$693 = $$lcssa67$i;$694 = $$lcssa3765$i;
                break L236;
               }
              } while(0);
              $689 = ($$lcssa67$i|0)>(-1);
              if ($689) {
               HEAP32[$9>>2] = 61;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$9+0>>2]|0;
               invoke_vii(2591,($$lcssa3765$i|0),($$byval_copy80|0));
               $690 = __THREW__; __THREW__ = 0;
               $691 = $690&1;
               if ($691) {
                label = 130;
                break L1;
               }
              }
              __THREW__ = 0;
              $699 = (+invoke_d(2));
              $700 = __THREW__; __THREW__ = 0;
              $701 = $700&1;
              if ($701) {
               label = 130;
               break L1;
              }
              $702 = $699 * 1.0E+6;
              $703 = (~~$702)>>>0;
              $704 = +Math_abs($702) >= 1.0 ? $702 > 0.0 ? (Math_min(+Math_floor($702 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($702 - +(~~$702 >>> 0)) / 4294967296.0) >>> 0 : 0;
              $705 = (_i64Subtract(($703|0),($704|0),($558|0),($559|0))|0);
              $706 = tempRet0;
              $707 = HEAP32[560624>>2]|0;
              $708 = (($707) + 36|0);
              $709 = HEAP32[$708>>2]|0;
              $710 = (($707) + 4|0);
              $711 = HEAP32[$710>>2]|0;
              __THREW__ = 0;
              $712 = (+invoke_d(2));
              $713 = __THREW__; __THREW__ = 0;
              $714 = $713&1;
              if ($714) {
               label = 130;
               break L1;
              }
              $715 = (($40) - ($709))|0;
              $716 = (($715) + ($711))|0;
              $717 = HEAP32[560624>>2]|0;
              $718 = (($717) + 36|0);
              $719 = HEAP32[$718>>2]|0;
              $720 = (($717) + 4|0);
              $721 = HEAP32[$720>>2]|0;
              $722 = (($719) - ($721))|0;
              __THREW__ = 0;
              HEAP32[$$byval_copy80>>2] = $716;
              $vararg_ptr38 = (($$byval_copy80) + 4|0);
              HEAP32[$vararg_ptr38>>2] = $722;
              invoke_vii(2587,(621272|0),($$byval_copy80|0));
              $723 = __THREW__; __THREW__ = 0;
              $724 = $723&1;
              if ($724) {
               label = 130;
               break L1;
              }
              $725 = $712 * 1.0E+6;
              $726 = (~~$725)>>>0;
              $727 = +Math_abs($725) >= 1.0 ? $725 > 0.0 ? (Math_min(+Math_floor($725 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($725 - +(~~$725 >>> 0)) / 4294967296.0) >>> 0 : 0;
              $728 = (_i64Subtract(($726|0),($727|0),($33|0),($34|0))|0);
              $729 = tempRet0;
              __THREW__ = 0;
              $730 = (invoke_iii(2425,($728|0),($729|0))|0);
              $731 = tempRet0;
              $732 = __THREW__; __THREW__ = 0;
              $733 = $732&1;
              if ($733) {
               label = 130;
               break L1;
              }
              $734 = (+($730>>>0)) + (4294967296.0*(+($731>>>0)));
              $735 = $734 * 1.00000000000000006228E-9;
              $736 = Math_fround($735);
              $737 = Math_fround($736 * Math_fround(1000.0));
              $738 = +$737;
              __THREW__ = 0;
              $739 = (invoke_iii(2425,($261|0),($262|0))|0);
              $740 = tempRet0;
              $741 = __THREW__; __THREW__ = 0;
              $742 = $741&1;
              if ($742) {
               label = 130;
               break L1;
              }
              $743 = (+($739>>>0)) + (4294967296.0*(+($740>>>0)));
              $744 = $743 * 1.00000000000000006228E-9;
              $745 = Math_fround($744);
              $746 = Math_fround($745 * Math_fround(1000.0));
              $747 = +$746;
              __THREW__ = 0;
              $748 = (invoke_iii(2425,($339|0),($340|0))|0);
              $749 = tempRet0;
              $750 = __THREW__; __THREW__ = 0;
              $751 = $750&1;
              if ($751) {
               label = 130;
               break L1;
              }
              $752 = (+($748>>>0)) + (4294967296.0*(+($749>>>0)));
              $753 = $752 * 1.00000000000000006228E-9;
              $754 = Math_fround($753);
              $755 = Math_fround($754 * Math_fround(1000.0));
              $756 = +$755;
              __THREW__ = 0;
              $757 = (invoke_iii(2425,($509|0),($510|0))|0);
              $758 = tempRet0;
              $759 = __THREW__; __THREW__ = 0;
              $760 = $759&1;
              if ($760) {
               label = 130;
               break L1;
              }
              __THREW__ = 0;
              $761 = (invoke_iii(2425,($705|0),($706|0))|0);
              $762 = tempRet0;
              $763 = __THREW__; __THREW__ = 0;
              $764 = $763&1;
              if ($764) {
               label = 130;
               break L1;
              }
              $765 = (+($757>>>0)) + (4294967296.0*(+($758>>>0)));
              $766 = $765 * 1.00000000000000006228E-9;
              $767 = Math_fround($766);
              $768 = Math_fround($767 * Math_fround(1000.0));
              $769 = (+($761>>>0)) + (4294967296.0*(+($762>>>0)));
              $770 = $769 * 1.00000000000000006228E-9;
              $771 = Math_fround($770);
              $772 = Math_fround($771 * Math_fround(1000.0));
              $773 = +$768;
              $774 = +$772;
              __THREW__ = 0;
              HEAPF64[tempDoublePtr>>3]=$738;HEAP32[$$byval_copy80>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy80+4>>2]=HEAP32[tempDoublePtr+4>>2];
              $vararg_ptr42 = (($$byval_copy80) + 8|0);
              HEAPF64[tempDoublePtr>>3]=$747;HEAP32[$vararg_ptr42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr42+4>>2]=HEAP32[tempDoublePtr+4>>2];
              $vararg_ptr43 = (($$byval_copy80) + 16|0);
              HEAPF64[tempDoublePtr>>3]=$756;HEAP32[$vararg_ptr43>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr43+4>>2]=HEAP32[tempDoublePtr+4>>2];
              $vararg_ptr44 = (($$byval_copy80) + 24|0);
              HEAPF64[tempDoublePtr>>3]=$773;HEAP32[$vararg_ptr44>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr44+4>>2]=HEAP32[tempDoublePtr+4>>2];
              $vararg_ptr45 = (($$byval_copy80) + 32|0);
              HEAPF64[tempDoublePtr>>3]=$774;HEAP32[$vararg_ptr45>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr45+4>>2]=HEAP32[tempDoublePtr+4>>2];
              invoke_vii(2587,(621352|0),($$byval_copy80|0));
              $775 = __THREW__; __THREW__ = 0;
              $776 = $775&1;
              if ($776) {
               label = 130;
               break L1;
              }
              $777 = HEAP32[$279>>2]|0;
              $778 = ($777|0)==(0|0);
              do {
               if ($778) {
                label = 208;
               } else {
                HEAP32[$3>>2] = 90;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$3+0>>2]|0;
                invoke_vii(2591,($777|0),($$byval_copy80|0));
                $779 = __THREW__; __THREW__ = 0;
                $780 = $779&1;
                if (!($780)) {
                 label = 208;
                 break;
                }
                $791 = ___cxa_find_matching_catch()|0;
                $792 = tempRet0;
                $793 = HEAP32[$47>>2]|0;
                $794 = ($793|0)>(-1);
                if (!($794)) {
                 $$0$i94 = $792;$$01$i93 = $791;
                 break;
                }
                $795 = HEAP32[$45>>2]|0;
                $796 = HEAP32[$48>>2]|0;
                HEAP32[$1>>2] = $796;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$1+0>>2]|0;
                invoke_vii(2591,($795|0),($$byval_copy80|0));
                $797 = __THREW__; __THREW__ = 0;
                $798 = $797&1;
                if ($798) {
                 $807 = ___cxa_find_matching_catch(0|0)|0;
                 $808 = tempRet0;
                 ___clang_call_terminate($807);
                 // unreachable;
                } else {
                 HEAP32[$45>>2] = 0;
                 $$0$i94 = $792;$$01$i93 = $791;
                 break;
                }
               }
              } while(0);
              L262: do {
               if ((label|0) == 208) {
                $781 = HEAP32[$47>>2]|0;
                $782 = ($781|0)>(-1);
                do {
                 if ($782) {
                  $783 = HEAP32[$45>>2]|0;
                  $784 = HEAP32[$48>>2]|0;
                  HEAP32[$2>>2] = $784;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$2+0>>2]|0;
                  invoke_vii(2591,($783|0),($$byval_copy80|0));
                  $785 = __THREW__; __THREW__ = 0;
                  $786 = $785&1;
                  if ($786) {
                   $799 = ___cxa_find_matching_catch()|0;
                   $800 = tempRet0;
                   $$0$i94 = $800;$$01$i93 = $799;
                   break L262;
                  } else {
                   HEAP32[$45>>2] = 0;
                   break;
                  }
                 }
                } while(0);
                $787 = HEAP32[$44>>2]|0;
                $788 = ($787|0)>(-1);
                if (!($788)) {
                 STACKTOP = sp;return;
                }
                $789 = HEAP32[$state>>2]|0;
                $790 = HEAP32[$42>>2]|0;
                HEAP32[$0>>2] = $790;
                ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$0+0>>2]|0;
                __Z19free_alloc_internalPv10MemLabelId($789,$$byval_copy80);
                HEAP32[$state>>2] = 0;
                STACKTOP = sp;return;
               }
              } while(0);
              $801 = HEAP32[$44>>2]|0;
              $802 = ($801|0)>(-1);
              if (!($802)) {
               ___resumeException($$01$i93|0);
               // unreachable;
              }
              $803 = HEAP32[$state>>2]|0;
              $804 = HEAP32[$42>>2]|0;
              HEAP32[$0>>2] = $804;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$0+0>>2]|0;
              invoke_vii(2591,($803|0),($$byval_copy80|0));
              $805 = __THREW__; __THREW__ = 0;
              $806 = $805&1;
              if ($806) {
               $807 = ___cxa_find_matching_catch(0|0)|0;
               $808 = tempRet0;
               ___clang_call_terminate($807);
               // unreachable;
              }
              HEAP32[$state>>2] = 0;
              ___resumeException($$01$i93|0);
              // unreachable;
             }
            } while(0);
            if ((label|0) == 172) {
             $635 = ___cxa_find_matching_catch()|0;
             $636 = tempRet0;
             $638 = $$ph24$ph30$i;$856 = $$ph$ph28$i;$857 = $$ph23$ph29$i;$858 = $$ph25$ph$i;$lpad$phi$i$index = $635;$lpad$phi$i$index28 = $636;
             label = 173;
            }
            if ((label|0) == 173) {
             $637 = ($638|0)>(-1);
             if ($637) {
              $639 = $858;$846 = $lpad$phi$i$index28;$847 = $lpad$phi$i$index;$848 = $857;$849 = $856;
              label = 174;
             } else {
              $$0$i72 = $lpad$phi$i$index;$$01$i71 = $lpad$phi$i$index28;$693 = $856;$694 = $857;
             }
            }
            do {
             if ((label|0) == 174) {
              HEAP32[$0>>2] = 61;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$0+0>>2]|0;
              invoke_vii(2591,($639|0),($$byval_copy80|0));
              $640 = __THREW__; __THREW__ = 0;
              $641 = $640&1;
              if (!($641)) {
               $$0$i72 = $847;$$01$i71 = $846;$693 = $849;$694 = $848;
               break;
              }
              $697 = ___cxa_find_matching_catch(0|0)|0;
              $698 = tempRet0;
              ___clang_call_terminate($697);
              // unreachable;
             }
            } while(0);
            $692 = ($693|0)>(-1);
            do {
             if ($692) {
              HEAP32[$10>>2] = 61;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$10+0>>2]|0;
              invoke_vii(2591,($694|0),($$byval_copy80|0));
              $695 = __THREW__; __THREW__ = 0;
              $696 = $695&1;
              if (!($696)) {
               break;
              }
              $697 = ___cxa_find_matching_catch(0|0)|0;
              $698 = tempRet0;
              ___clang_call_terminate($697);
              // unreachable;
             }
            } while(0);
            $$pre$pre$phiZZ2D = $279;$eh$lpad$body35$index11Z2D = $$01$i71;$eh$lpad$body35$indexZ2D = $$0$i72;
            label = 132;
            break L1;
           }
           else if ((label|0) == 133) {
            $529 = ___cxa_find_matching_catch()|0;
            $530 = tempRet0;
            $lpad$phi$index = $529;$lpad$phi$index21 = $530;
            break;
           }
           else if ((label|0) == 134) {
            $531 = ___cxa_find_matching_catch()|0;
            $532 = tempRet0;
            $lpad$phi$index = $531;$lpad$phi$index21 = $532;
            break;
           }
          }
         } while(0);
         if ((label|0) == 135) {
          $533 = ___cxa_find_matching_catch()|0;
          $534 = tempRet0;
          $lpad$phi$index = $533;$lpad$phi$index21 = $534;
         }
         $535 = (($threadState) + 48|0);
         $536 = HEAP32[$535>>2]|0;
         $537 = ($536|0)==(0|0);
         do {
          if (!($537)) {
           $538 = (($threadState) + 52|0);
           $539 = HEAP32[$538>>2]|0;
           $540 = ($539|0)==($536|0);
           if (!($540)) {
            $__new_last2$i$i$i$i$i$i$i$i$i56 = $536;
            $scevgep$i$i$i$i$i$i$i$i$i57 = (($539) + -4|0);
            $541 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i56))|0;
            $uglygep$i$i$i$i$i$i$i$i$i59 = (($scevgep$i$i$i$i$i$i$i$i$i57) + ($541)|0);
            $uglygep3$i$i$i$i$i$i$i$i$i60 = $uglygep$i$i$i$i$i$i$i$i$i59;
            $542 = $uglygep3$i$i$i$i$i$i$i$i$i60 >>> 2;
            $543 = $542 ^ -1;
            $scevgep4$i$i$i$i$i$i$i$i$i61 = (($539) + ($543<<2)|0);
            HEAP32[$538>>2] = $scevgep4$i$i$i$i$i$i$i$i$i61;
           }
           HEAP32[$12>>2] = 90;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$12+0>>2]|0;
           invoke_vii(2591,($536|0),($$byval_copy80|0));
           $544 = __THREW__; __THREW__ = 0;
           $545 = $544&1;
           if (!($545)) {
            break;
           }
           $546 = ___cxa_find_matching_catch()|0;
           $547 = tempRet0;
           ___cxa_call_unexpected(($546|0));
           // unreachable;
          }
         } while(0);
         $548 = HEAP32[$360>>2]|0;
         $549 = ($548|0)>(-1);
         if (!($549)) {
          $$0 = $lpad$phi$index21;$$01 = $lpad$phi$index;$$pre$phiZ2D = $279;
          label = 223;
          break;
         }
         $550 = HEAP32[$358>>2]|0;
         $551 = HEAP32[$361>>2]|0;
         HEAP32[$11>>2] = $551;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$11+0>>2]|0;
         invoke_vii(2591,($550|0),($$byval_copy80|0));
         $552 = __THREW__; __THREW__ = 0;
         $553 = $552&1;
         if ($553) {
          break;
         }
         HEAP32[$358>>2] = 0;
         $$0 = $lpad$phi$index21;$$01 = $lpad$phi$index;$$pre$phiZ2D = $279;
         label = 223;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 130) {
  $527 = ___cxa_find_matching_catch()|0;
  $528 = tempRet0;
  $lpad$phi130$index = $527;$lpad$phi130$index2 = $528;
  label = 131;
 }
 if ((label|0) == 131) {
  $$pre$pre$pre$pre = (($state) + 64|0);
  $$pre$pre$phiZZ2D = $$pre$pre$pre$pre;$eh$lpad$body35$index11Z2D = $lpad$phi130$index2;$eh$lpad$body35$indexZ2D = $lpad$phi130$index;
  label = 132;
 }
 if ((label|0) == 132) {
  $$0 = $eh$lpad$body35$index11Z2D;$$01 = $eh$lpad$body35$indexZ2D;$$pre$phiZ2D = $$pre$pre$phiZZ2D;
  label = 223;
 }
 L314: do {
  if ((label|0) == 223) {
   $809 = HEAP32[$$pre$phiZ2D>>2]|0;
   $810 = ($809|0)==(0|0);
   do {
    if ($810) {
     label = 225;
    } else {
     HEAP32[$30>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$30+0>>2]|0;
     invoke_vii(2591,($809|0),($$byval_copy80|0));
     $811 = __THREW__; __THREW__ = 0;
     $812 = $811&1;
     if ($812) {
      $825 = ___cxa_find_matching_catch(0|0)|0;
      $826 = tempRet0;
      $827 = HEAP32[$47>>2]|0;
      $828 = ($827|0)>(-1);
      if ($828) {
       $829 = HEAP32[$45>>2]|0;
       $830 = HEAP32[$48>>2]|0;
       HEAP32[$28>>2] = $830;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$28+0>>2]|0;
       invoke_vii(2591,($829|0),($$byval_copy80|0));
       $831 = __THREW__; __THREW__ = 0;
       $832 = $831&1;
       if ($832) {
        $841 = ___cxa_find_matching_catch(0|0)|0;
        $842 = tempRet0;
        ___clang_call_terminate($841);
        // unreachable;
       } else {
        HEAP32[$45>>2] = 0;
        $$01$i = $825;
        break;
       }
      } else {
       $$01$i = $825;
      }
     } else {
      label = 225;
     }
    }
   } while(0);
   L323: do {
    if ((label|0) == 225) {
     $813 = HEAP32[$47>>2]|0;
     $814 = ($813|0)>(-1);
     do {
      if ($814) {
       $815 = HEAP32[$45>>2]|0;
       $816 = HEAP32[$48>>2]|0;
       HEAP32[$29>>2] = $816;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$29+0>>2]|0;
       invoke_vii(2591,($815|0),($$byval_copy80|0));
       $817 = __THREW__; __THREW__ = 0;
       $818 = $817&1;
       if ($818) {
        $833 = ___cxa_find_matching_catch(0|0)|0;
        $834 = tempRet0;
        $$01$i = $833;
        break L323;
       } else {
        HEAP32[$45>>2] = 0;
        break;
       }
      }
     } while(0);
     $819 = HEAP32[$44>>2]|0;
     $820 = ($819|0)>(-1);
     if (!($820)) {
      ___resumeException($$01|0);
      // unreachable;
     }
     $821 = HEAP32[$state>>2]|0;
     $822 = HEAP32[$42>>2]|0;
     HEAP32[$28>>2] = $822;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$28+0>>2]|0;
     invoke_vii(2591,($821|0),($$byval_copy80|0));
     $823 = __THREW__; __THREW__ = 0;
     $824 = $823&1;
     if ($824) {
      break L314;
     }
     HEAP32[$state>>2] = 0;
     ___resumeException($$01|0);
     // unreachable;
    }
   } while(0);
   $835 = HEAP32[$44>>2]|0;
   $836 = ($835|0)>(-1);
   do {
    if ($836) {
     $837 = HEAP32[$state>>2]|0;
     $838 = HEAP32[$42>>2]|0;
     HEAP32[$11>>2] = $838;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy80+0>>2]=HEAP32[$11+0>>2]|0;
     invoke_vii(2591,($837|0),($$byval_copy80|0));
     $839 = __THREW__; __THREW__ = 0;
     $840 = $839&1;
     if ($840) {
      $841 = ___cxa_find_matching_catch(0|0)|0;
      $842 = tempRet0;
      ___clang_call_terminate($841);
      // unreachable;
     } else {
      HEAP32[$state>>2] = 0;
      break;
     }
    }
   } while(0);
   $eh$lpad$body$indexZ2D = $$01$i;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 $843 = ___cxa_find_matching_catch(0|0)|0;
 $844 = tempRet0;
 $eh$lpad$body$indexZ2D = $843;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __Z20MarkInstanceIDAsRootiR21GarbageCollectorState($instanceID,$gcState) {
 $instanceID = $instanceID|0;
 $gcState = $gcState|0;
 var $$byval_copy1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 HEAP32[$0>>2] = $instanceID;
 $1 = ($instanceID|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($gcState) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($gcState) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 do {
  if ($6) {
   $7 = (($gcState) + 64|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($gcState) + 68|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($8) + ($10<<3)|0);
   $22 = $8;$23 = $10;$25 = $11;
  } else {
   $12 = (($gcState) + 36|0);
   __ZNK15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E13find_positionERS2_($$byval_copy1,$12,$0);
   $13 = HEAP32[$$byval_copy1>>2]|0;
   $14 = ($13|0)==(-1);
   $15 = (($gcState) + 64|0);
   $16 = HEAP32[$15>>2]|0;
   if ($14) {
    $17 = (($gcState) + 68|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + ($18<<3)|0);
    $22 = $16;$23 = $18;$25 = $19;
    break;
   } else {
    $20 = (($16) + ($13<<3)|0);
    $$phi$trans$insert = (($gcState) + 68|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $22 = $16;$23 = $$pre;$25 = $20;
    break;
   }
  }
 } while(0);
 $21 = (($22) + ($23<<3)|0);
 $24 = ($25|0)==($21|0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $26 = (($25) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(-1);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$gcState>>2]|0;
 $30 = ((($29) + ($27<<3)|0) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 & 536870912;
 $33 = ($32|0)==(0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $34 = (($gcState) + 16|0);
 $35 = $31 | 536870912;
 HEAP32[$30>>2] = $35;
 $36 = $31 & 536870911;
 switch ($36|0) {
 case 78: case 27: case 28: case 43: case 84: case 89: case 115: case 117: case 142: case 147: case 149: case 150: case 158: case 171:  {
  STACKTOP = sp;return;
  break;
 }
 default: {
 }
 }
 $37 = (($gcState) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 1)|0;
 HEAP32[$37>>2] = $39;
 $40 = (($gcState) + 28|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 2147483647;
 $43 = ($39>>>0)>($42>>>0);
 if ($43) {
  $44 = $41 << 1;
  $45 = ($44|0)==(0);
  $46 = $45 ? 1 : $44;
  $47 = ($42>>>0)<($46>>>0);
  do {
   if ($47) {
    $48 = ($41|0)>(-1);
    if ($48) {
     HEAP32[$40>>2] = $46;
     $49 = HEAP32[$34>>2]|0;
     $50 = $46 << 2;
     $51 = (($gcState) + 20|0);
     $52 = HEAP32[$51>>2]|0;
     HEAP32[$0>>2] = $52;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $53 = (__Z16realloc_internalPvji10MemLabelIdiPKci($49,$50,4,$$byval_copy1,0,621264,370)|0);
     HEAP32[$34>>2] = $53;
     break;
    } else {
     $54 = $46 << 2;
     $55 = (($gcState) + 20|0);
     $56 = HEAP32[$55>>2]|0;
     HEAP32[$0>>2] = $56;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $57 = (__Z15malloc_internaljj10MemLabelIdiPKci($54,4,$$byval_copy1,0,621264,352)|0);
     $58 = HEAP32[$34>>2]|0;
     $59 = HEAP32[$37>>2]|0;
     $60 = $59 << 2;
     _memcpy(($57|0),($58|0),($60|0))|0;
     HEAP32[$40>>2] = $46;
     HEAP32[$34>>2] = $57;
     break;
    }
   }
  } while(0);
  $$pre$i$i$i = HEAP32[$37>>2]|0;
  $62 = $$pre$i$i$i;
 } else {
  $62 = $39;
 }
 $61 = (($62) + -1)|0;
 $63 = HEAP32[$34>>2]|0;
 $64 = (($63) + ($61<<2)|0);
 HEAP32[$64>>2] = $27;
 STACKTOP = sp;return;
}
function __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($instanceID,$gcState) {
 $instanceID = $instanceID|0;
 $gcState = $gcState|0;
 var $$byval_copy1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = (($gcState) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $instanceID;
 $3 = ($instanceID|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 do {
  if ($8) {
   $9 = (($2) + 64|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($2) + 68|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($10) + ($12<<3)|0);
   $24 = $10;$25 = $12;$27 = $13;
  } else {
   $14 = (($2) + 36|0);
   __ZNK15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E13find_positionERS2_($$byval_copy1,$14,$0);
   $15 = HEAP32[$$byval_copy1>>2]|0;
   $16 = ($15|0)==(-1);
   $17 = (($2) + 64|0);
   $18 = HEAP32[$17>>2]|0;
   if ($16) {
    $19 = (($2) + 68|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($18) + ($20<<3)|0);
    $24 = $18;$25 = $20;$27 = $21;
    break;
   } else {
    $22 = (($18) + ($15<<3)|0);
    $$phi$trans$insert = (($2) + 68|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $24 = $18;$25 = $$pre;$27 = $22;
    break;
   }
  }
 } while(0);
 $23 = (($24) + ($25<<3)|0);
 $26 = ($27|0)==($23|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $28 = (($27) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(-1);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = HEAP32[$1>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($32) + ($29<<3)|0) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 536870912;
 $36 = ($35|0)==(0);
 if (!($36)) {
  STACKTOP = sp;return;
 }
 $37 = (($gcState) + 8|0);
 $38 = $34 | 536870912;
 HEAP32[$33>>2] = $38;
 $39 = $34 & 536870911;
 switch ($39|0) {
 case 78: case 27: case 28: case 43: case 84: case 89: case 115: case 117: case 142: case 147: case 149: case 150: case 158: case 171:  {
  STACKTOP = sp;return;
  break;
 }
 default: {
 }
 }
 $40 = (($gcState) + 16|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 1)|0;
 HEAP32[$40>>2] = $42;
 $43 = (($gcState) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 & 2147483647;
 $46 = ($42>>>0)>($45>>>0);
 if ($46) {
  $47 = $44 << 1;
  $48 = ($47|0)==(0);
  $49 = $48 ? 1 : $47;
  $50 = ($45>>>0)<($49>>>0);
  do {
   if ($50) {
    $51 = ($44|0)>(-1);
    if ($51) {
     HEAP32[$43>>2] = $49;
     $52 = HEAP32[$37>>2]|0;
     $53 = $49 << 2;
     $54 = (($gcState) + 12|0);
     $55 = HEAP32[$54>>2]|0;
     HEAP32[$0>>2] = $55;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $56 = (__Z16realloc_internalPvji10MemLabelIdiPKci($52,$53,4,$$byval_copy1,0,621264,370)|0);
     HEAP32[$37>>2] = $56;
     break;
    } else {
     $57 = $49 << 2;
     $58 = (($gcState) + 12|0);
     $59 = HEAP32[$58>>2]|0;
     HEAP32[$0>>2] = $59;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($57,4,$$byval_copy1,0,621264,352)|0);
     $61 = HEAP32[$37>>2]|0;
     $62 = HEAP32[$40>>2]|0;
     $63 = $62 << 2;
     _memcpy(($60|0),($61|0),($63|0))|0;
     HEAP32[$43>>2] = $49;
     HEAP32[$37>>2] = $60;
     break;
    }
   }
  } while(0);
  $$pre$i$i$i = HEAP32[$40>>2]|0;
  $65 = $$pre$i$i$i;
 } else {
  $65 = $42;
 }
 $64 = (($65) + -1)|0;
 $66 = HEAP32[$37>>2]|0;
 $67 = (($66) + ($64<<2)|0);
 HEAP32[$67>>2] = $29;
 STACKTOP = sp;return;
}
function __Z16MarkObjectAsRootRK6ObjectR27GarbageCollectorThreadState($object,$gcState) {
 $object = $object|0;
 $gcState = $gcState|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($object) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($1,$gcState);
 STACKTOP = sp;return;
}
function __ZN27GenericSlowGarbageCollector18GenerateInstanceIDEi17TransferMetaFlags($this,$oldInstanceID,$metaFlag) {
 $this = $this|0;
 $oldInstanceID = $oldInstanceID|0;
 $metaFlag = $metaFlag|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN27GenericSlowGarbageCollector16ProcessReferenceEi($this,$oldInstanceID);
 STACKTOP = sp;return ($oldInstanceID|0);
}
function __ZN27GenericSlowGarbageCollector16ProcessReferenceEi($this,$oldInstanceID) {
 $this = $this|0;
 $oldInstanceID = $oldInstanceID|0;
 var $$byval_copy1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $oldInstanceID;
 $5 = ($oldInstanceID|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($4) + 72|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 do {
  if ($10) {
   $11 = (($4) + 64|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($4) + 68|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($12) + ($14<<3)|0);
   $26 = $12;$27 = $14;$29 = $15;
  } else {
   $16 = (($4) + 36|0);
   __ZNK15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E13find_positionERS2_($$byval_copy1,$16,$0);
   $17 = HEAP32[$$byval_copy1>>2]|0;
   $18 = ($17|0)==(-1);
   $19 = (($4) + 64|0);
   $20 = HEAP32[$19>>2]|0;
   if ($18) {
    $21 = (($4) + 68|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($20) + ($22<<3)|0);
    $26 = $20;$27 = $22;$29 = $23;
    break;
   } else {
    $24 = (($20) + ($17<<3)|0);
    $$phi$trans$insert = (($4) + 68|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $26 = $20;$27 = $$pre;$29 = $24;
    break;
   }
  }
 } while(0);
 $25 = (($26) + ($27<<3)|0);
 $28 = ($29|0)==($25|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $30 = (($29) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(-1);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = (($33) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($36) + ($31<<3)|0) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 536870912;
 $40 = ($39|0)==(0);
 if (!($40)) {
  STACKTOP = sp;return;
 }
 $41 = (($33) + 8|0);
 $42 = $38 | 536870912;
 HEAP32[$37>>2] = $42;
 $43 = $38 & 536870911;
 switch ($43|0) {
 case 78: case 27: case 28: case 43: case 84: case 89: case 115: case 117: case 142: case 147: case 149: case 150: case 158: case 171:  {
  STACKTOP = sp;return;
  break;
 }
 default: {
 }
 }
 $44 = (($33) + 16|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 1)|0;
 HEAP32[$44>>2] = $46;
 $47 = (($33) + 20|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 & 2147483647;
 $50 = ($46>>>0)>($49>>>0);
 if ($50) {
  $51 = $48 << 1;
  $52 = ($51|0)==(0);
  $53 = $52 ? 1 : $51;
  $54 = ($49>>>0)<($53>>>0);
  do {
   if ($54) {
    $55 = ($48|0)>(-1);
    if ($55) {
     HEAP32[$47>>2] = $53;
     $56 = HEAP32[$41>>2]|0;
     $57 = $53 << 2;
     $58 = (($33) + 12|0);
     $59 = HEAP32[$58>>2]|0;
     HEAP32[$0>>2] = $59;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $60 = (__Z16realloc_internalPvji10MemLabelIdiPKci($56,$57,4,$$byval_copy1,0,621264,370)|0);
     HEAP32[$41>>2] = $60;
     break;
    } else {
     $61 = $53 << 2;
     $62 = (($33) + 12|0);
     $63 = HEAP32[$62>>2]|0;
     HEAP32[$0>>2] = $63;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $64 = (__Z15malloc_internaljj10MemLabelIdiPKci($61,4,$$byval_copy1,0,621264,352)|0);
     $65 = HEAP32[$41>>2]|0;
     $66 = HEAP32[$44>>2]|0;
     $67 = $66 << 2;
     _memcpy(($64|0),($65|0),($67|0))|0;
     HEAP32[$47>>2] = $53;
     HEAP32[$41>>2] = $64;
     break;
    }
   }
  } while(0);
  $$pre$i$i$i = HEAP32[$44>>2]|0;
  $69 = $$pre$i$i$i;
 } else {
  $69 = $46;
 }
 $68 = (($69) + -1)|0;
 $70 = HEAP32[$41>>2]|0;
 $71 = (($70) + ($68<<2)|0);
 HEAP32[$71>>2] = $31;
 STACKTOP = sp;return;
}
function __Z16MarkDependenciesR27GarbageCollectorThreadStatej($gcThreadState,$index) {
 $gcThreadState = $gcThreadState|0;
 $index = $index|0;
 var $$0$i$i = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $i$01$i = 0, $i$01$i$i = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($gcThreadState) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($index<<3)|0);
 $4 = ((($2) + ($index<<3)|0) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 536870911;
 do {
  switch ($6|0) {
  case 4:  {
   $10 = $5 & 1073741824;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $12 = HEAP32[$3>>2]|0;
    __ZNK5Unity9Component38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($12,$gcThreadState);
   }
   $13 = HEAP32[$3>>2]|0;
   $14 = (($13) + 140|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($13) + 148|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($15) + ($17<<2)|0);
   $19 = ($17|0)==(0);
   if (!($19)) {
    $i$01$i = $15;
    while(1) {
     $20 = HEAP32[$i$01$i>>2]|0;
     $21 = (($20) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($22,$gcThreadState);
     $23 = (($i$01$i) + 4|0);
     $24 = ($23|0)==($18|0);
     if ($24) {
      break;
     } else {
      $i$01$i = $23;
     }
    }
   }
   $25 = (($13) + 156|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if ($27) {
    $$0$i$i = 0;
   } else {
    $28 = (($26) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $$0$i$i = $29;
   }
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($$0$i$i,$gcThreadState);
   STACKTOP = sp;return;
   break;
  }
  case 23:  {
   $30 = $5 & 1073741824;
   $31 = ($30|0)==(0);
   if (!($31)) {
    $32 = HEAP32[$3>>2]|0;
    __ZNK5Unity9Component38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($32,$gcThreadState);
   }
   $33 = HEAP32[$3>>2]|0;
   $34 = (($33) + 220|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) + 228|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($35) + ($37<<2)|0);
   $39 = ($37|0)==(0);
   if (!($39)) {
    $i$01$i$i = $35;
    while(1) {
     $40 = HEAP32[$i$01$i$i>>2]|0;
     __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($40,$gcThreadState);
     $41 = (($i$01$i$i) + 4|0);
     $42 = ($41|0)==($38|0);
     if ($42) {
      break;
     } else {
      $i$01$i$i = $41;
     }
    }
   }
   $43 = (($33) + 212|0);
   $44 = HEAP32[$43>>2]|0;
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($44,$gcThreadState);
   $45 = (($33) + 304|0);
   $46 = HEAP32[$45>>2]|0;
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($46,$gcThreadState);
   STACKTOP = sp;return;
   break;
  }
  case 1:  {
   $7 = $5 & 1073741824;
   $8 = ($7|0)==(0);
   if ($8) {
    STACKTOP = sp;return;
   }
   $9 = HEAP32[$3>>2]|0;
   __ZNK5Unity10GameObject38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($9,$gcThreadState);
   STACKTOP = sp;return;
   break;
  }
  case 33:  {
   $47 = $5 & 1073741824;
   $48 = ($47|0)==(0);
   if (!($48)) {
    $49 = HEAP32[$3>>2]|0;
    __ZNK5Unity9Component38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($49,$gcThreadState);
   }
   $50 = HEAP32[$3>>2]|0;
   $51 = (($50) + 28|0);
   $52 = HEAP32[$51>>2]|0;
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($52,$gcThreadState);
   STACKTOP = sp;return;
   break;
  }
  case 64:  {
   $72 = $5 & 1073741824;
   $73 = ($72|0)==(0);
   if (!($73)) {
    $74 = HEAP32[$3>>2]|0;
    __ZNK5Unity9Component38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($74,$gcThreadState);
   }
   $75 = HEAP32[$3>>2]|0;
   $76 = (($75) + 28|0);
   $77 = HEAP32[$76>>2]|0;
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($77,$gcThreadState);
   $78 = (($75) + 56|0);
   $79 = HEAP32[$78>>2]|0;
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($79,$gcThreadState);
   STACKTOP = sp;return;
   break;
  }
  case 21:  {
   $53 = HEAP32[$3>>2]|0;
   __ZNK5Unity8Material16MarkDependenciesER27GarbageCollectorThreadState($53,$gcThreadState);
   STACKTOP = sp;return;
   break;
  }
  case 65:  {
   $80 = $5 & 1073741824;
   $81 = ($80|0)==(0);
   if (!($81)) {
    $82 = HEAP32[$3>>2]|0;
    __ZNK5Unity9Component38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($82,$gcThreadState);
   }
   $83 = HEAP32[$3>>2]|0;
   $84 = (($83) + 28|0);
   $85 = HEAP32[$84>>2]|0;
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($85,$gcThreadState);
   STACKTOP = sp;return;
   break;
  }
  case 95:  {
   $54 = $5 & 1073741824;
   $55 = ($54|0)==(0);
   if (!($55)) {
    $56 = HEAP32[$3>>2]|0;
    __ZNK5Unity9Component38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($56,$gcThreadState);
   }
   $57 = HEAP32[$3>>2]|0;
   $58 = (($57) + 56|0);
   $59 = HEAP32[$58>>2]|0;
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($59,$gcThreadState);
   $60 = (($57) + 60|0);
   $61 = HEAP32[$60>>2]|0;
   __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($61,$gcThreadState);
   $62 = (($57) + 372|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($57) + 376|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($63|0)==($65|0);
   if ($66) {
    STACKTOP = sp;return;
   } else {
    $68 = $63;
   }
   while(1) {
    $67 = HEAP32[$68>>2]|0;
    __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($67,$gcThreadState);
    $69 = (($68) + 4|0);
    $70 = HEAP32[$64>>2]|0;
    $71 = ($69|0)==($70|0);
    if ($71) {
     break;
    } else {
     $68 = $69;
    }
   }
   STACKTOP = sp;return;
   break;
  }
  case 114:  {
   $86 = HEAP32[$3>>2]|0;
   $87 = $5 & 1073741824;
   $88 = ($87|0)==(0);
   if ($88) {
    $90 = $1;
   } else {
    __ZNK5Unity9Component38MarkGameObjectAndComponentDependenciesER27GarbageCollectorThreadState($86,$gcThreadState);
    $$pre = HEAP32[$0>>2]|0;
    $90 = $$pre;
   }
   $89 = (($90) + 92|0);
   $91 = HEAP8[$89>>0]|0;
   $92 = ($91<<24>>24)==(0);
   if ($92) {
    $$pre$phiZ2D = $3;
   } else {
    $93 = (($86) + 32|0);
    $94 = HEAP32[$93>>2]|0;
    __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($94,$gcThreadState);
    $95 = HEAP32[$3>>2]|0;
    $96 = (__ZN9Scripting19ScriptingWrapperForEP6Object($95)|0);
    $97 = ($96|0)==(0|0);
    if (!($97)) {
     $98 = HEAP32[$gcThreadState>>2]|0;
     __Z40scripting_liveness_calculation_from_rootP15ScriptingObjectPv($96,$98);
    }
    $99 = (($86) + 56|0);
    $100 = (($99) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ($101|0)==($99|0);
    if (!($102)) {
     $104 = $101;
     while(1) {
      $103 = (($104) + 8|0);
      $105 = HEAP32[$103>>2]|0;
      $106 = HEAP32[$gcThreadState>>2]|0;
      __Z40scripting_liveness_calculation_from_rootP15ScriptingObjectPv($105,$106);
      $107 = (($104) + 4|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = ($108|0)==($99|0);
      if ($109) {
       break;
      } else {
       $104 = $108;
      }
     }
    }
    $$pre$i = HEAP32[$0>>2]|0;
    $$phi$trans$insert$i = (($$pre$i) + 92|0);
    $$pre1$i = HEAP8[$$phi$trans$insert$i>>0]|0;
    $phitmp$i = ($$pre1$i<<24>>24)==(0);
    if ($phitmp$i) {
     $$pre$phiZ2D = $3;
    } else {
     STACKTOP = sp;return;
    }
   }
   break;
  }
  default: {
   $$pre$phiZ2D = $3;
  }
  }
 } while(0);
 $110 = HEAP32[$$pre$phiZ2D>>2]|0;
 $111 = HEAP32[$110>>2]|0;
 $112 = (($111) + 72|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($gcThreadState) + 32|0);
 FUNCTION_TABLE_vii[$113 & 4095]($110,$114);
 STACKTOP = sp;return;
}
function __ZN27GenericSlowGarbageCollectorD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN27GenericSlowGarbageCollectorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZL30RegisterFilteredObjectCallbackPPviS_($arr,$count,$userdata) {
 $arr = $arr|0;
 $count = $count|0;
 $userdata = $userdata|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)>(0);
 if ($0) {
  $i$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $1 = (($arr) + ($i$01<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($2)|0);
  __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($3,$userdata);
  $4 = (($i$01) + 1)|0;
  $exitcond = ($4|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E13find_positionERS2_($agg$result,$this,$key) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $key = $key|0;
 var $$ = 0, $$lcssa2$ph = 0, $$lcssa214 = 0, $$lcssa3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $num_probes$04 = 0, $num_probes$04$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$key>>2]|0;
 $4 = (($3) + 2127912214)|0;
 $5 = $3 << 12;
 $6 = (($4) + ($5))|0;
 $7 = $6 ^ -949894596;
 $8 = $6 >>> 19;
 $9 = $7 ^ $8;
 $10 = (($9) + 374761393)|0;
 $11 = $9 << 5;
 $12 = (($10) + ($11))|0;
 $13 = (($12) + -744332180)|0;
 $14 = $12 << 9;
 $15 = $13 ^ $14;
 $16 = (($15) + -42973499)|0;
 $17 = $15 << 3;
 $18 = (($16) + ($17))|0;
 $19 = $18 ^ -1252372727;
 $20 = $18 >>> 16;
 $21 = $19 ^ $20;
 $22 = $21 & $2;
 $23 = (($this) + 20|0);
 $24 = (($this) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($22<<3)|0);
 $27 = HEAP32[$23>>2]|0;
 $28 = HEAP32[$26>>2]|0;
 $29 = ($27|0)==($28|0);
 L1: do {
  if ($29) {
   $$lcssa2$ph = $22;
   label = 5;
  } else {
   $30 = (($this) + 8|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   $33 = (($this) + 4|0);
   $34 = (($this) + 12|0);
   L3: do {
    if ($32) {
     $36 = $28;$39 = $22;$num_probes$04$us = 0;
     while(1) {
      $35 = ($3|0)==($36|0);
      if ($35) {
       $$lcssa3 = $39;
       break L3;
      }
      $37 = (($num_probes$04$us) + 1)|0;
      $38 = (($37) + ($39))|0;
      $40 = $38 & $2;
      $41 = (($25) + ($40<<3)|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($27|0)==($42|0);
      if ($43) {
       $$lcssa2$ph = $40;
       label = 5;
       break L1;
      } else {
       $36 = $42;$39 = $40;$num_probes$04$us = $37;
      }
     }
    } else {
     $53 = $28;$55 = -1;$56 = $22;$num_probes$04 = 0;
     while(1) {
      $49 = HEAP32[$33>>2]|0;
      $50 = ($49|0)==(0);
      if ($50) {
       label = 12;
      } else {
       $51 = HEAP32[$34>>2]|0;
       $52 = ($51|0)==($53|0);
       if ($52) {
        $54 = ($55|0)==(-1);
        $$ = $54 ? $56 : $55;
        $46 = $$;
       } else {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       label = 0;
       $57 = ($3|0)==($53|0);
       if ($57) {
        $$lcssa3 = $56;
        break L3;
       } else {
        $46 = $55;
       }
      }
      $59 = (($num_probes$04) + 1)|0;
      $60 = (($59) + ($56))|0;
      $61 = $60 & $2;
      $62 = (($25) + ($61<<3)|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($27|0)==($63|0);
      if ($64) {
       break;
      } else {
       $53 = $63;$55 = $46;$56 = $61;$num_probes$04 = $59;
      }
     }
     $45 = ($46|0)==(-1);
     HEAP32[$agg$result>>2] = -1;
     $47 = (($agg$result) + 4|0);
     if ($45) {
      $$lcssa214 = $61;$48 = $47;
      break L1;
     }
     HEAP32[$47>>2] = $46;
     STACKTOP = sp;return;
    }
   } while(0);
   HEAP32[$agg$result>>2] = $$lcssa3;
   $58 = (($agg$result) + 4|0);
   HEAP32[$58>>2] = -1;
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 5) {
  HEAP32[$agg$result>>2] = -1;
  $44 = (($agg$result) + 4|0);
  $$lcssa214 = $$lcssa2$ph;$48 = $44;
 }
 HEAP32[$48>>2] = $$lcssa214;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E12resize_deltaEjj($this,$delta,$min_buckets_wanted) {
 $this = $this|0;
 $delta = $delta|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sz$0$i = 0, $sz$0$i1 = 0, $tmp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 48|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E12maybe_shrinkEv($this);
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)>($min_buckets_wanted>>>0);
 $7 = (($this) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $9 = (($8) + ($delta))|0;
  $10 = (($this) + 44|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9>>>0)>($11>>>0);
  if (!($12)) {
   STACKTOP = sp;return;
  }
 }
 $13 = (($this) + 36|0);
 $14 = (($8) + ($delta))|0;
 $15 = (Math_fround(($14>>>0)));
 $sz$0$i = 32;
 while(1) {
  $16 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($16)) {
   $17 = (Math_fround(($sz$0$i>>>0)));
   $18 = Math_fround($17 * Math_fround(0.5));
   $19 = !($15 >= $18);
   if ($19) {
    break;
   }
  }
  $20 = $sz$0$i << 1;
  $sz$0$i = $20;
 }
 $21 = ($sz$0$i>>>0)>($5>>>0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($14) - ($23))|0;
 $25 = (Math_fround(($24>>>0)));
 $sz$0$i1 = 32;
 while(1) {
  $26 = ($sz$0$i1>>>0)<($min_buckets_wanted>>>0);
  if (!($26)) {
   $27 = (Math_fround(($sz$0$i1>>>0)));
   $28 = Math_fround($27 * Math_fround(0.5));
   $29 = !($25 >= $28);
   if ($29) {
    break;
   }
  }
  $30 = $sz$0$i1 << 1;
  $sz$0$i1 = $30;
 }
 $31 = (($tmp) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = (($tmp) + 8|0);
 $33 = (($this) + 8|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = (($tmp) + 9|0);
 $36 = (($this) + 9|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP8[$35>>0] = $37;
 $38 = (($tmp) + 12|0);
 $39 = (($this) + 12|0);
 $40 = $39;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 4)|0;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = $38;
 $47 = $46;
 HEAP32[$47>>2] = $42;
 $48 = (($46) + 4)|0;
 $49 = $48;
 HEAP32[$49>>2] = $45;
 $50 = (($tmp) + 20|0);
 $51 = (($this) + 20|0);
 $52 = $51;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($52) + 4)|0;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = $50;
 $59 = $58;
 HEAP32[$59>>2] = $54;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $57;
 $62 = (($tmp) + 28|0);
 ;HEAP32[$62+0>>2]=0|0;HEAP32[$62+4>>2]=0|0;HEAP32[$62+8>>2]=0|0;HEAP32[$62+12>>2]=0|0;HEAP32[$62+16>>2]=0|0;HEAP8[$62+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E9copy_fromERKSD_j($tmp,$this,$sz$0$i1);
 $63 = HEAP32[$22>>2]|0;
 $64 = HEAP32[$31>>2]|0;
 HEAP32[$22>>2] = $64;
 HEAP32[$31>>2] = $63;
 $65 = HEAP8[$33>>0]|0;
 $66 = HEAP16[$32>>1]|0;
 $67 = $66&255;
 HEAP8[$33>>0] = $67;
 HEAP8[$32>>0] = $65;
 $68 = HEAP8[$36>>0]|0;
 $69 = ($66&65535) >>> 8;
 $70 = $69&255;
 HEAP8[$36>>0] = $70;
 HEAP8[$35>>0] = $68;
 $71 = $39;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($71) + 4)|0;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = $38;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = (($77) + 4)|0;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = $39;
 $84 = $83;
 HEAP32[$84>>2] = $79;
 $85 = (($83) + 4)|0;
 $86 = $85;
 HEAP32[$86>>2] = $82;
 $87 = $38;
 $88 = $87;
 HEAP32[$88>>2] = $73;
 $89 = (($87) + 4)|0;
 $90 = $89;
 HEAP32[$90>>2] = $76;
 $91 = $51;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = (($91) + 4)|0;
 $95 = $94;
 $96 = HEAP32[$95>>2]|0;
 $97 = $50;
 $98 = $97;
 $99 = HEAP32[$98>>2]|0;
 $100 = (($97) + 4)|0;
 $101 = $100;
 $102 = HEAP32[$101>>2]|0;
 $103 = $51;
 $104 = $103;
 HEAP32[$104>>2] = $99;
 $105 = (($103) + 4)|0;
 $106 = $105;
 HEAP32[$106>>2] = $102;
 $107 = $50;
 $108 = $107;
 HEAP32[$108>>2] = $93;
 $109 = (($107) + 4)|0;
 $110 = $109;
 HEAP32[$110>>2] = $96;
 $111 = (($this) + 28|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = HEAP32[$62>>2]|0;
 HEAP32[$111>>2] = $113;
 HEAP32[$62>>2] = $112;
 $114 = (($tmp) + 32|0);
 $115 = HEAP32[$4>>2]|0;
 $116 = HEAP32[$114>>2]|0;
 HEAP32[$4>>2] = $116;
 HEAP32[$114>>2] = $115;
 $117 = (($tmp) + 36|0);
 $118 = HEAP32[$13>>2]|0;
 $119 = HEAP32[$117>>2]|0;
 HEAP32[$13>>2] = $119;
 HEAP32[$117>>2] = $118;
 $120 = (Math_fround(($116>>>0)));
 $121 = Math_fround($120 * Math_fround(0.5));
 $122 = (~~(($121))>>>0);
 $123 = (($this) + 44|0);
 HEAP32[$123>>2] = $122;
 $124 = Math_fround($120 * Math_fround(0.20000000298023223877));
 $125 = (~~(($124))>>>0);
 $126 = (($this) + 40|0);
 HEAP32[$126>>2] = $125;
 HEAP8[$1>>0] = 0;
 $127 = (Math_fround(($115>>>0)));
 $128 = Math_fround($127 * Math_fround(0.5));
 $129 = (~~(($128))>>>0);
 $130 = (($tmp) + 44|0);
 HEAP32[$130>>2] = $129;
 $131 = Math_fround($127 * Math_fround(0.20000000298023223877));
 $132 = (~~(($131))>>>0);
 $133 = (($tmp) + 40|0);
 HEAP32[$133>>2] = $132;
 $134 = (($tmp) + 48|0);
 HEAP8[$134>>0] = 0;
 $135 = ($112|0)==(0|0);
 if ($135) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($112,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E15insert_noresizeERKS3_($agg$result,$this,$obj) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $obj = $obj|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos = sp;
 __ZNK15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E13find_positionERS2_($pos,$this,$obj);
 $0 = HEAP32[$pos>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  $2 = (($this) + 28|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + ($0<<3)|0);
  $5 = (($this) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + ($6<<3)|0);
  HEAP32[$agg$result>>2] = $this;
  $8 = (($agg$result) + 4|0);
  HEAP32[$8>>2] = $4;
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $7;
  $10 = (($agg$result) + 12|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($pos) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  label = 7;
 } else {
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if ($18) {
   label = 7;
  } else {
   $19 = (($this) + 12|0);
   $20 = (($this) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($12<<3)|0);
   $23 = HEAP32[$19>>2]|0;
   $24 = HEAP32[$22>>2]|0;
   $25 = ($23|0)==($24|0);
   if ($25) {
    $26 = (($17) + -1)|0;
    HEAP32[$16>>2] = $26;
    $32 = $21;
   } else {
    label = 7;
   }
  }
 }
 if ((label|0) == 7) {
  $27 = (($this) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 1)|0;
  HEAP32[$27>>2] = $29;
  $$phi$trans$insert = (($this) + 28|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $32 = $$pre;
 }
 $30 = (($this) + 28|0);
 $31 = (($32) + ($12<<3)|0);
 $33 = ($31|0)==(0|0);
 if (!($33)) {
  $34 = $obj;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 4)|0;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = $31;
  $41 = $40;
  HEAP32[$41>>2] = $36;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = $39;
 }
 $44 = HEAP32[$30>>2]|0;
 $45 = (($44) + ($12<<3)|0);
 $46 = (($this) + 32|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($44) + ($47<<3)|0);
 HEAP32[$agg$result>>2] = $this;
 $49 = (($agg$result) + 4|0);
 HEAP32[$49>>2] = $45;
 $50 = (($agg$result) + 8|0);
 HEAP32[$50>>2] = $48;
 $51 = (($agg$result) + 12|0);
 HEAP8[$51>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E12maybe_shrinkEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $sz$0 = 0, $sz$0$in = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) - ($4))|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if (!($8)) {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 $9 = (($this) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)>(32);
 if ($11) {
  $sz$0$in = $10;
 } else {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $sz$0 = $sz$0$in >>> 1;
  $12 = ($sz$0$in>>>0)<(66);
  if ($12) {
   break;
  }
  $13 = (Math_fround(($5>>>0)));
  $14 = (Math_fround(($sz$0>>>0)));
  $15 = Math_fround($14 * Math_fround(0.20000000298023223877));
  $16 = $13 < $15;
  if ($16) {
   $sz$0$in = $sz$0;
  } else {
   break;
  }
 }
 $17 = (($tmp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($tmp) + 8|0);
 $19 = (($this) + 8|0);
 $20 = HEAP8[$19>>0]|0;
 HEAP8[$18>>0] = $20;
 $21 = (($tmp) + 9|0);
 $22 = (($this) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 HEAP8[$21>>0] = $23;
 $24 = (($tmp) + 12|0);
 $25 = (($this) + 12|0);
 $26 = $25;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $24;
 $33 = $32;
 HEAP32[$33>>2] = $28;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $31;
 $36 = (($tmp) + 20|0);
 $37 = (($this) + 20|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $36;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 $48 = (($tmp) + 28|0);
 ;HEAP32[$48+0>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;HEAP8[$48+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E9copy_fromERKSD_j($tmp,$this,$sz$0);
 $49 = HEAP32[$3>>2]|0;
 $50 = HEAP32[$17>>2]|0;
 HEAP32[$3>>2] = $50;
 HEAP32[$17>>2] = $49;
 $51 = HEAP8[$19>>0]|0;
 $52 = HEAP16[$18>>1]|0;
 $53 = $52&255;
 HEAP8[$19>>0] = $53;
 HEAP8[$18>>0] = $51;
 $54 = HEAP8[$22>>0]|0;
 $55 = ($52&65535) >>> 8;
 $56 = $55&255;
 HEAP8[$22>>0] = $56;
 HEAP8[$21>>0] = $54;
 $57 = $25;
 $58 = $57;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + 4)|0;
 $61 = $60;
 $62 = HEAP32[$61>>2]|0;
 $63 = $24;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $25;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $24;
 $74 = $73;
 HEAP32[$74>>2] = $59;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $62;
 $77 = $37;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = (($77) + 4)|0;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = $36;
 $84 = $83;
 $85 = HEAP32[$84>>2]|0;
 $86 = (($83) + 4)|0;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = $37;
 $90 = $89;
 HEAP32[$90>>2] = $85;
 $91 = (($89) + 4)|0;
 $92 = $91;
 HEAP32[$92>>2] = $88;
 $93 = $36;
 $94 = $93;
 HEAP32[$94>>2] = $79;
 $95 = (($93) + 4)|0;
 $96 = $95;
 HEAP32[$96>>2] = $82;
 $97 = (($this) + 28|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$48>>2]|0;
 HEAP32[$97>>2] = $99;
 HEAP32[$48>>2] = $98;
 $100 = (($tmp) + 32|0);
 $101 = HEAP32[$9>>2]|0;
 $102 = HEAP32[$100>>2]|0;
 HEAP32[$9>>2] = $102;
 HEAP32[$100>>2] = $101;
 $103 = (($tmp) + 36|0);
 $104 = HEAP32[$1>>2]|0;
 $105 = HEAP32[$103>>2]|0;
 HEAP32[$1>>2] = $105;
 HEAP32[$103>>2] = $104;
 $106 = (Math_fround(($102>>>0)));
 $107 = Math_fround($106 * Math_fround(0.5));
 $108 = (~~(($107))>>>0);
 $109 = (($this) + 44|0);
 HEAP32[$109>>2] = $108;
 $110 = Math_fround($106 * Math_fround(0.20000000298023223877));
 $111 = (~~(($110))>>>0);
 HEAP32[$6>>2] = $111;
 $112 = (($this) + 48|0);
 HEAP8[$112>>0] = 0;
 $113 = (Math_fround(($101>>>0)));
 $114 = Math_fround($113 * Math_fround(0.5));
 $115 = (~~(($114))>>>0);
 $116 = (($tmp) + 44|0);
 HEAP32[$116>>2] = $115;
 $117 = Math_fround($113 * Math_fround(0.20000000298023223877));
 $118 = (~~(($117))>>>0);
 $119 = (($tmp) + 40|0);
 HEAP32[$119>>2] = $118;
 $120 = (($tmp) + 48|0);
 HEAP8[$120>>0] = 0;
 $121 = ($98|0)==(0|0);
 if ($121) {
  $122 = (($this) + 48|0);
  HEAP8[$122>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($98,$$byval_copy);
 $122 = (($this) + 48|0);
 HEAP8[$122>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E9copy_fromERKSD_j($this,$ht,$min_buckets_wanted) {
 $this = $this|0;
 $ht = $ht|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$01$i$i$i = 0, $$01$i$i$i4 = 0, $$012$i$i = 0, $$03$i$i = 0, $$be = 0, $$byval_copy3 = 0, $$ph11 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucknum$0 = 0, $bucknum$0$lcssa = 0, $bucknum$07 = 0, $bucknum$09 = 0, $num_probes$08 = 0, $sz$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = 32;
 $3 = (($this) + 44|0);
 HEAP32[$3>>2] = 16;
 $4 = (($this) + 40|0);
 HEAP32[$4>>2] = 6;
 $5 = (($this) + 48|0);
 HEAP8[$5>>0] = 0;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Z15malloc_internaljj10MemLabelIdiPKci(256,16,$$byval_copy3,0,621264,79)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy3);
 }
 HEAP32[$1>>2] = $6;
 $9 = HEAP32[$2>>2]|0;
 $10 = (($6) + ($9<<3)|0);
 $11 = ($6|0)==($10|0);
 if (!($11)) {
  $12 = (($this) + 20|0);
  $$01$i$i$i = $6;
  while(1) {
   $13 = ($$01$i$i$i|0)==(0|0);
   if (!($13)) {
    $14 = $12;
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + 4)|0;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = $$01$i$i$i;
    $21 = $20;
    HEAP32[$21>>2] = $16;
    $22 = (($20) + 4)|0;
    $23 = $22;
    HEAP32[$23>>2] = $19;
   }
   $24 = (($$01$i$i$i) + 8|0);
   $25 = ($24|0)==($10|0);
   if ($25) {
    break;
   } else {
    $$01$i$i$i = $24;
   }
  }
 }
 $26 = (($this) + 36|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 4|0);
 HEAP32[$27>>2] = 0;
 $28 = (($ht) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($ht) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) - ($31))|0;
 $33 = (Math_fround(($32>>>0)));
 $sz$0$i = 32;
 while(1) {
  $34 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($34)) {
   $35 = (Math_fround(($sz$0$i>>>0)));
   $36 = Math_fround($35 * Math_fround(0.5));
   $37 = !($33 >= $36);
   if ($37) {
    break;
   }
  }
  $38 = $sz$0$i << 1;
  $sz$0$i = $38;
 }
 $39 = HEAP32[$2>>2]|0;
 $40 = ($sz$0$i>>>0)>($39>>>0);
 if ($40) {
  $41 = $sz$0$i << 3;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($41,16,$$byval_copy3,0,621264,79)|0);
  $43 = HEAP32[$1>>2]|0;
  $44 = ($43|0)==(0|0);
  if (!($44)) {
   $45 = HEAP32[$2>>2]|0;
   $46 = (($43) + ($45<<3)|0);
   $47 = ($45|0)==(0);
   if ($47) {
    $62 = $43;
   } else {
    $$012$i$i = $42;$$03$i$i = $43;
    while(1) {
     $48 = ($$012$i$i|0)==(0|0);
     if (!($48)) {
      $49 = $$03$i$i;
      $50 = $49;
      $51 = HEAP32[$50>>2]|0;
      $52 = (($49) + 4)|0;
      $53 = $52;
      $54 = HEAP32[$53>>2]|0;
      $55 = $$012$i$i;
      $56 = $55;
      HEAP32[$56>>2] = $51;
      $57 = (($55) + 4)|0;
      $58 = $57;
      HEAP32[$58>>2] = $54;
     }
     $59 = (($$03$i$i) + 8|0);
     $60 = (($$012$i$i) + 8|0);
     $61 = ($59|0)==($46|0);
     if ($61) {
      break;
     } else {
      $$012$i$i = $60;$$03$i$i = $59;
     }
    }
    $$pre$i = HEAP32[$1>>2]|0;
    $62 = $$pre$i;
   }
   HEAP32[$0>>2] = 90;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($62,$$byval_copy3);
  }
  $63 = HEAP32[$2>>2]|0;
  $64 = (($42) + ($sz$0$i<<3)|0);
  $65 = ($63|0)==($sz$0$i|0);
  if (!($65)) {
   $66 = (($42) + ($63<<3)|0);
   $67 = (($this) + 20|0);
   $$01$i$i$i4 = $66;
   while(1) {
    $68 = ($$01$i$i$i4|0)==(0|0);
    if (!($68)) {
     $69 = $67;
     $70 = $69;
     $71 = HEAP32[$70>>2]|0;
     $72 = (($69) + 4)|0;
     $73 = $72;
     $74 = HEAP32[$73>>2]|0;
     $75 = $$01$i$i$i4;
     $76 = $75;
     HEAP32[$76>>2] = $71;
     $77 = (($75) + 4)|0;
     $78 = $77;
     HEAP32[$78>>2] = $74;
    }
    $79 = (($$01$i$i$i4) + 8|0);
    $80 = ($79|0)==($64|0);
    if ($80) {
     break;
    } else {
     $$01$i$i$i4 = $79;
    }
   }
  }
  HEAP32[$1>>2] = $42;
  HEAP32[$2>>2] = $sz$0$i;
  $81 = (~~(($36))>>>0);
  HEAP32[$3>>2] = $81;
  $82 = Math_fround($35 * Math_fround(0.20000000298023223877));
  $83 = (~~(($82))>>>0);
  HEAP32[$4>>2] = $83;
  HEAP8[$5>>0] = 0;
  $174 = $sz$0$i;
 } else {
  $174 = $39;
 }
 $84 = (($ht) + 28|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($ht) + 32|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($85) + ($87<<3)|0);
 $89 = ($87|0)==(0);
 L40: do {
  if ($89) {
   $$ph11 = $85;
  } else {
   $90 = (($ht) + 20|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($ht) + 8|0);
   $93 = (($ht) + 12|0);
   $95 = $85;
   while(1) {
    $94 = HEAP32[$95>>2]|0;
    $96 = ($91|0)==($94|0);
    if (!($96)) {
     $97 = HEAP8[$92>>0]|0;
     $98 = ($97<<24>>24)==(0);
     if ($98) {
      $$ph11 = $95;
      break L40;
     }
     $99 = HEAP32[$30>>2]|0;
     $100 = ($99|0)==(0);
     if ($100) {
      $$ph11 = $95;
      break L40;
     }
     $101 = HEAP32[$93>>2]|0;
     $102 = ($101|0)==($94|0);
     if (!($102)) {
      $$ph11 = $95;
      break L40;
     }
    }
    $103 = (($95) + 8|0);
    $104 = ($103|0)==($88|0);
    if ($104) {
     break;
    } else {
     $95 = $103;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $105 = ($$ph11|0)==($88|0);
 if ($105) {
  STACKTOP = sp;return;
 }
 $106 = (($this) + 20|0);
 $107 = (($ht) + 20|0);
 $108 = (($ht) + 8|0);
 $109 = (($ht) + 12|0);
 $111 = $174;$113 = $$ph11;
 while(1) {
  $110 = (($111) + -1)|0;
  $112 = HEAP32[$113>>2]|0;
  $114 = (($112) + 2127912214)|0;
  $115 = $112 << 12;
  $116 = (($114) + ($115))|0;
  $117 = $116 ^ -949894596;
  $118 = $116 >>> 19;
  $119 = $117 ^ $118;
  $120 = (($119) + 374761393)|0;
  $121 = $119 << 5;
  $122 = (($120) + ($121))|0;
  $123 = (($122) + -744332180)|0;
  $124 = $122 << 9;
  $125 = $123 ^ $124;
  $126 = (($125) + -42973499)|0;
  $127 = $125 << 3;
  $128 = (($126) + ($127))|0;
  $129 = $128 ^ -1252372727;
  $130 = $128 >>> 16;
  $131 = $129 ^ $130;
  $bucknum$07 = $131 & $110;
  $132 = HEAP32[$1>>2]|0;
  $133 = (($132) + ($bucknum$07<<3)|0);
  $134 = HEAP32[$106>>2]|0;
  $135 = HEAP32[$133>>2]|0;
  $136 = ($134|0)==($135|0);
  if ($136) {
   $bucknum$0$lcssa = $bucknum$07;
  } else {
   $bucknum$09 = $bucknum$07;$num_probes$08 = 0;
   while(1) {
    $137 = (($num_probes$08) + 1)|0;
    $138 = (($137) + ($bucknum$09))|0;
    $bucknum$0 = $138 & $110;
    $139 = (($132) + ($bucknum$0<<3)|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = ($134|0)==($140|0);
    if ($141) {
     $bucknum$0$lcssa = $bucknum$0;
     break;
    } else {
     $bucknum$09 = $bucknum$0;$num_probes$08 = $137;
    }
   }
  }
  $142 = (($132) + ($bucknum$0$lcssa<<3)|0);
  $143 = ($142|0)==(0|0);
  if (!($143)) {
   $144 = $113;
   $145 = $144;
   $146 = HEAP32[$145>>2]|0;
   $147 = (($144) + 4)|0;
   $148 = $147;
   $149 = HEAP32[$148>>2]|0;
   $150 = $142;
   $151 = $150;
   HEAP32[$151>>2] = $146;
   $152 = (($150) + 4)|0;
   $153 = $152;
   HEAP32[$153>>2] = $149;
  }
  $154 = HEAP32[$26>>2]|0;
  $155 = (($154) + 1)|0;
  HEAP32[$26>>2] = $155;
  $156 = (($113) + 8|0);
  $157 = ($156|0)==($88|0);
  L63: do {
   if ($157) {
    $$be = $88;
   } else {
    $162 = HEAP32[$107>>2]|0;
    $164 = $156;
    while(1) {
     $163 = HEAP32[$164>>2]|0;
     $165 = ($162|0)==($163|0);
     if (!($165)) {
      $166 = HEAP8[$108>>0]|0;
      $167 = ($166<<24>>24)==(0);
      if ($167) {
       $$be = $164;
       break L63;
      }
      $168 = HEAP32[$30>>2]|0;
      $169 = ($168|0)==(0);
      if ($169) {
       $$be = $164;
       break L63;
      }
      $170 = HEAP32[$109>>2]|0;
      $171 = ($170|0)==($163|0);
      if (!($171)) {
       $$be = $164;
       break L63;
      }
     }
     $172 = (($164) + 8|0);
     $173 = ($172|0)==($88|0);
     if ($173) {
      $$be = $88;
      break;
     } else {
      $164 = $172;
     }
    }
   }
  } while(0);
  $158 = HEAP32[$84>>2]|0;
  $159 = HEAP32[$86>>2]|0;
  $160 = (($158) + ($159<<3)|0);
  $161 = ($$be|0)==($160|0);
  if ($161) {
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $111 = $$pre;$113 = $$be;
 }
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E14squash_deletedEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 56|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($tmp) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($tmp) + 8|0);
 $6 = (($this) + 8|0);
 $7 = HEAP8[$6>>0]|0;
 HEAP8[$5>>0] = $7;
 $8 = (($tmp) + 9|0);
 $9 = (($this) + 9|0);
 $10 = HEAP8[$9>>0]|0;
 HEAP8[$8>>0] = $10;
 $11 = (($tmp) + 12|0);
 $12 = (($this) + 12|0);
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $11;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 $23 = (($tmp) + 20|0);
 $24 = (($this) + 20|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $23;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = (($tmp) + 28|0);
 ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;HEAP8[$35+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E9copy_fromERKSD_j($tmp,$this,0);
 $36 = HEAP32[$1>>2]|0;
 $37 = HEAP32[$4>>2]|0;
 HEAP32[$1>>2] = $37;
 HEAP32[$4>>2] = $36;
 $38 = HEAP8[$6>>0]|0;
 $39 = HEAP16[$5>>1]|0;
 $40 = $39&255;
 HEAP8[$6>>0] = $40;
 HEAP8[$5>>0] = $38;
 $41 = HEAP8[$9>>0]|0;
 $42 = ($39&65535) >>> 8;
 $43 = $42&255;
 HEAP8[$9>>0] = $43;
 HEAP8[$8>>0] = $41;
 $44 = $12;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = (($44) + 4)|0;
 $48 = $47;
 $49 = HEAP32[$48>>2]|0;
 $50 = $11;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 4)|0;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = $12;
 $57 = $56;
 HEAP32[$57>>2] = $52;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = $55;
 $60 = $11;
 $61 = $60;
 HEAP32[$61>>2] = $46;
 $62 = (($60) + 4)|0;
 $63 = $62;
 HEAP32[$63>>2] = $49;
 $64 = $24;
 $65 = $64;
 $66 = HEAP32[$65>>2]|0;
 $67 = (($64) + 4)|0;
 $68 = $67;
 $69 = HEAP32[$68>>2]|0;
 $70 = $23;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = (($70) + 4)|0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = $24;
 $77 = $76;
 HEAP32[$77>>2] = $72;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $75;
 $80 = $23;
 $81 = $80;
 HEAP32[$81>>2] = $66;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $69;
 $84 = (($this) + 28|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = HEAP32[$35>>2]|0;
 HEAP32[$84>>2] = $86;
 HEAP32[$35>>2] = $85;
 $87 = (($this) + 32|0);
 $88 = (($tmp) + 32|0);
 $89 = HEAP32[$87>>2]|0;
 $90 = HEAP32[$88>>2]|0;
 HEAP32[$87>>2] = $90;
 HEAP32[$88>>2] = $89;
 $91 = (($this) + 36|0);
 $92 = (($tmp) + 36|0);
 $93 = HEAP32[$91>>2]|0;
 $94 = HEAP32[$92>>2]|0;
 HEAP32[$91>>2] = $94;
 HEAP32[$92>>2] = $93;
 $95 = (Math_fround(($90>>>0)));
 $96 = Math_fround($95 * Math_fround(0.5));
 $97 = (~~(($96))>>>0);
 $98 = (($this) + 44|0);
 HEAP32[$98>>2] = $97;
 $99 = Math_fround($95 * Math_fround(0.20000000298023223877));
 $100 = (~~(($99))>>>0);
 $101 = (($this) + 40|0);
 HEAP32[$101>>2] = $100;
 $102 = (($this) + 48|0);
 HEAP8[$102>>0] = 0;
 $103 = (Math_fround(($89>>>0)));
 $104 = Math_fround($103 * Math_fround(0.5));
 $105 = (~~(($104))>>>0);
 $106 = (($tmp) + 44|0);
 HEAP32[$106>>2] = $105;
 $107 = Math_fround($103 * Math_fround(0.20000000298023223877));
 $108 = (~~(($107))>>>0);
 $109 = (($tmp) + 40|0);
 HEAP32[$109>>2] = $108;
 $110 = (($tmp) + 48|0);
 HEAP8[$110>>0] = 0;
 $111 = ($85|0)==(0|0);
 if ($111) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($85,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z15CreatePrimitivei($type) {
 $type = $type|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 60|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 switch ($type|0) {
 case 0:  {
  HEAP8[$0>>0] = 12;
  $6 = (($0) + 1|0);
  ;HEAP8[$6+0>>0]=HEAP8[621488+0>>0]|0;HEAP8[$6+1>>0]=HEAP8[621488+1>>0]|0;HEAP8[$6+2>>0]=HEAP8[621488+2>>0]|0;HEAP8[$6+3>>0]=HEAP8[621488+3>>0]|0;HEAP8[$6+4>>0]=HEAP8[621488+4>>0]|0;HEAP8[$6+5>>0]=HEAP8[621488+5>>0]|0;
  $7 = (($0) + 7|0);
  HEAP8[$7>>0] = 0;
  __THREW__ = 0;
  $8 = (invoke_iii(2426,($0|0),0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   $18 = HEAP8[$0>>0]|0;
   $19 = $18 & 1;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $$0 = $17;$$01 = $16;
    ___resumeException($$01|0);
    // unreachable;
   }
   $21 = (($0) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   __ZdlPv($22);
   $$0 = $17;$$01 = $16;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $11 = HEAP8[$0>>0]|0;
   $12 = $11 & 1;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    $$02 = $8;
    STACKTOP = sp;return ($$02|0);
   }
   $14 = (($0) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   __ZdlPv($15);
   $$02 = $8;
   STACKTOP = sp;return ($$02|0);
  }
  break;
 }
 case 2:  {
  HEAP8[$2>>0] = 16;
  $38 = (($2) + 1|0);
  $39 = $38;
  $40 = $39;
  HEAP8[$40>>0]=1768716611&255;HEAP8[$40+1>>0]=(1768716611>>8)&255;HEAP8[$40+2>>0]=(1768716611>>16)&255;HEAP8[$40+3>>0]=1768716611>>24;
  $41 = (($39) + 4)|0;
  $42 = $41;
  HEAP8[$42>>0]=1919247470&255;HEAP8[$42+1>>0]=(1919247470>>8)&255;HEAP8[$42+2>>0]=(1919247470>>16)&255;HEAP8[$42+3>>0]=1919247470>>24;
  $43 = (($2) + 9|0);
  HEAP8[$43>>0] = 0;
  __THREW__ = 0;
  $44 = (invoke_iii(2426,($2|0),2)|0);
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $52 = ___cxa_find_matching_catch()|0;
   $53 = tempRet0;
   $54 = HEAP8[$2>>0]|0;
   $55 = $54 & 1;
   $56 = ($55<<24>>24)==(0);
   if ($56) {
    $$0 = $53;$$01 = $52;
    ___resumeException($$01|0);
    // unreachable;
   }
   $57 = (($2) + 8|0);
   $58 = HEAP32[$57>>2]|0;
   __ZdlPv($58);
   $$0 = $53;$$01 = $52;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $47 = HEAP8[$2>>0]|0;
   $48 = $47 & 1;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    $$02 = $44;
    STACKTOP = sp;return ($$02|0);
   }
   $50 = (($2) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   __ZdlPv($51);
   $$02 = $44;
   STACKTOP = sp;return ($$02|0);
  }
  break;
 }
 case 3:  {
  HEAP8[$3>>0] = 8;
  $59 = (($3) + 1|0);
  HEAP8[$59>>0]=1700951363&255;HEAP8[$59+1>>0]=(1700951363>>8)&255;HEAP8[$59+2>>0]=(1700951363>>16)&255;HEAP8[$59+3>>0]=1700951363>>24;
  $60 = (($3) + 5|0);
  HEAP8[$60>>0] = 0;
  __THREW__ = 0;
  $61 = (invoke_iii(2426,($3|0),3)|0);
  $62 = __THREW__; __THREW__ = 0;
  $63 = $62&1;
  if ($63) {
   $69 = ___cxa_find_matching_catch()|0;
   $70 = tempRet0;
   $71 = HEAP8[$3>>0]|0;
   $72 = $71 & 1;
   $73 = ($72<<24>>24)==(0);
   if ($73) {
    $$0 = $70;$$01 = $69;
    ___resumeException($$01|0);
    // unreachable;
   }
   $74 = (($3) + 8|0);
   $75 = HEAP32[$74>>2]|0;
   __ZdlPv($75);
   $$0 = $70;$$01 = $69;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $64 = HEAP8[$3>>0]|0;
   $65 = $64 & 1;
   $66 = ($65<<24>>24)==(0);
   if ($66) {
    $$02 = $61;
    STACKTOP = sp;return ($$02|0);
   }
   $67 = (($3) + 8|0);
   $68 = HEAP32[$67>>2]|0;
   __ZdlPv($68);
   $$02 = $61;
   STACKTOP = sp;return ($$02|0);
  }
  break;
 }
 case 1:  {
  HEAP8[$1>>0] = 14;
  $23 = (($1) + 1|0);
  ;HEAP8[$23+0>>0]=HEAP8[621496+0>>0]|0;HEAP8[$23+1>>0]=HEAP8[621496+1>>0]|0;HEAP8[$23+2>>0]=HEAP8[621496+2>>0]|0;HEAP8[$23+3>>0]=HEAP8[621496+3>>0]|0;HEAP8[$23+4>>0]=HEAP8[621496+4>>0]|0;HEAP8[$23+5>>0]=HEAP8[621496+5>>0]|0;HEAP8[$23+6>>0]=HEAP8[621496+6>>0]|0;
  $24 = (($1) + 8|0);
  HEAP8[$24>>0] = 0;
  __THREW__ = 0;
  $25 = (invoke_iii(2426,($1|0),1)|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   $34 = HEAP8[$1>>0]|0;
   $35 = $34 & 1;
   $36 = ($35<<24>>24)==(0);
   if ($36) {
    $$0 = $33;$$01 = $32;
    ___resumeException($$01|0);
    // unreachable;
   }
   $37 = HEAP32[$24>>2]|0;
   __ZdlPv($37);
   $$0 = $33;$$01 = $32;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $28 = HEAP8[$1>>0]|0;
   $29 = $28 & 1;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $$02 = $25;
    STACKTOP = sp;return ($$02|0);
   }
   $31 = HEAP32[$24>>2]|0;
   __ZdlPv($31);
   $$02 = $25;
   STACKTOP = sp;return ($$02|0);
  }
  break;
 }
 case 4:  {
  HEAP8[$4>>0] = 10;
  $76 = (($4) + 1|0);
  ;HEAP8[$76+0>>0]=HEAP8[621504+0>>0]|0;HEAP8[$76+1>>0]=HEAP8[621504+1>>0]|0;HEAP8[$76+2>>0]=HEAP8[621504+2>>0]|0;HEAP8[$76+3>>0]=HEAP8[621504+3>>0]|0;HEAP8[$76+4>>0]=HEAP8[621504+4>>0]|0;
  $77 = (($4) + 6|0);
  HEAP8[$77>>0] = 0;
  __THREW__ = 0;
  $78 = (invoke_iii(2426,($4|0),4)|0);
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if ($80) {
   $86 = ___cxa_find_matching_catch()|0;
   $87 = tempRet0;
   $88 = HEAP8[$4>>0]|0;
   $89 = $88 & 1;
   $90 = ($89<<24>>24)==(0);
   if ($90) {
    $$0 = $87;$$01 = $86;
    ___resumeException($$01|0);
    // unreachable;
   }
   $91 = (($4) + 8|0);
   $92 = HEAP32[$91>>2]|0;
   __ZdlPv($92);
   $$0 = $87;$$01 = $86;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $81 = HEAP8[$4>>0]|0;
   $82 = $81 & 1;
   $83 = ($82<<24>>24)==(0);
   if ($83) {
    $$02 = $78;
    STACKTOP = sp;return ($$02|0);
   }
   $84 = (($4) + 8|0);
   $85 = HEAP32[$84>>2]|0;
   __ZdlPv($85);
   $$02 = $78;
   STACKTOP = sp;return ($$02|0);
  }
  break;
 }
 case 5:  {
  HEAP8[$5>>0] = 8;
  $93 = (($5) + 1|0);
  HEAP8[$93>>0]=1684108625&255;HEAP8[$93+1>>0]=(1684108625>>8)&255;HEAP8[$93+2>>0]=(1684108625>>16)&255;HEAP8[$93+3>>0]=1684108625>>24;
  $94 = (($5) + 5|0);
  HEAP8[$94>>0] = 0;
  __THREW__ = 0;
  $95 = (invoke_iii(2426,($5|0),5)|0);
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   $103 = ___cxa_find_matching_catch()|0;
   $104 = tempRet0;
   $105 = HEAP8[$5>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $$0 = $104;$$01 = $103;
    ___resumeException($$01|0);
    // unreachable;
   }
   $108 = (($5) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   __ZdlPv($109);
   $$0 = $104;$$01 = $103;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $98 = HEAP8[$5>>0]|0;
   $99 = $98 & 1;
   $100 = ($99<<24>>24)==(0);
   if ($100) {
    $$02 = $95;
    STACKTOP = sp;return ($$02|0);
   }
   $101 = (($5) + 8|0);
   $102 = HEAP32[$101>>2]|0;
   __ZdlPv($102);
   $$02 = $95;
   STACKTOP = sp;return ($$02|0);
  }
  break;
 }
 default: {
  $$02 = 0;
  STACKTOP = sp;return ($$02|0);
 }
 }
 return 0|0;
}
function __Z15CreatePrimitiveNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi($name,$type) {
 $name = $name|0;
 $type = $type|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $go$0 = 0, $vararg_buffer23 = 0, $vararg_ptr1 = 0, $vararg_ptr11 = 0, $vararg_ptr12 = 0;
 var $vararg_ptr16 = 0, $vararg_ptr17 = 0, $vararg_ptr2 = 0, $vararg_ptr21 = 0, $vararg_ptr22 = 0, $vararg_ptr26 = 0, $vararg_ptr27 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer23 = sp;
 $0 = sp + 124|0;
 $1 = sp + 112|0;
 $2 = sp + 108|0;
 $3 = sp + 104|0;
 $4 = sp + 92|0;
 $5 = sp + 88|0;
 $6 = sp + 84|0;
 $7 = sp + 72|0;
 $8 = sp + 128|0;
 $9 = sp + 32|0;
 $10 = sp + 20|0;
 $11 = sp + 12|0;
 $12 = sp + 16|0;
 $13 = sp + 56|0;
 $14 = sp + 36|0;
 $15 = sp + 40|0;
 $16 = sp + 44|0;
 $17 = sp + 68|0;
 switch ($type|0) {
 case 1:  {
  HEAP32[$vararg_buffer23>>2] = 621576;
  $vararg_ptr6 = (($vararg_buffer23) + 4|0);
  HEAP32[$vararg_ptr6>>2] = 621544;
  $vararg_ptr7 = (($vararg_buffer23) + 8|0);
  HEAP32[$vararg_ptr7>>2] = 0;
  $50 = (__Z16CreateGameObjectRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKcz($name,621512,$vararg_buffer23)|0);
  $51 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($50,33)|0);
  $52 = (__Znwj(16)|0);
  $53 = (($4) + 8|0);
  HEAP32[$53>>2] = $52;
  HEAP32[$4>>2] = 17;
  $54 = (($4) + 4|0);
  HEAP32[$54>>2] = 15;
  dest=$52+0|0; src=621592+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $55 = (($52) + 15|0);
  HEAP8[$55>>0] = 0;
  __THREW__ = 0;
  $56 = (invoke_i(58)|0);
  $57 = __THREW__; __THREW__ = 0;
  $58 = $57&1;
  if (!($58)) {
   __THREW__ = 0;
   $59 = (invoke_iiii(1532,($56|0),43,($4|0))|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if (!($61)) {
    $62 = ($59|0)==(0|0);
    if ($62) {
     HEAP32[$3>>2] = 0;
    } else {
     $63 = (($59) + 4|0);
     $64 = HEAP32[$63>>2]|0;
     HEAP32[$3>>2] = $64;
    }
    __THREW__ = 0;
    invoke_vii(2778,($51|0),($3|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if (!($66)) {
     $67 = HEAP8[$4>>0]|0;
     $68 = $67 & 1;
     $69 = ($68<<24>>24)==(0);
     if (!($69)) {
      $70 = HEAP32[$53>>2]|0;
      __ZdlPv($70);
     }
     $71 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($50,136)|0);
     $72 = ($71|0)==(0|0);
     if (!($72)) {
      $73 = (__Z11GetIPhysicsv()|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = (($74) + 16|0);
      $76 = HEAP32[$75>>2]|0;
      FUNCTION_TABLE_viif[$76 & 63]($73,$71,Math_fround(2.0));
     }
     $83 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($50,25)|0);
     $84 = (__ZN5Unity8Material25GetDefaultDiffuseMaterialEv()|0);
     $85 = ($84|0)==(0|0);
     if ($85) {
      HEAP32[$5>>2] = 0;
     } else {
      $86 = (($84) + 4|0);
      $87 = HEAP32[$86>>2]|0;
      HEAP32[$5>>2] = $87;
     }
     __ZN8Renderer11SetMaterialE4PPtrIN5Unity8MaterialEEi($83,$5,0);
     $go$0 = $50;
     STACKTOP = sp;return ($go$0|0);
    }
   }
  }
  $77 = ___cxa_find_matching_catch()|0;
  $78 = tempRet0;
  $79 = HEAP8[$4>>0]|0;
  $80 = $79 & 1;
  $81 = ($80<<24>>24)==(0);
  if ($81) {
   $$0 = $77;$$01 = $78;
   ___resumeException($$0|0);
   // unreachable;
  }
  $82 = HEAP32[$53>>2]|0;
  __ZdlPv($82);
  $$0 = $77;$$01 = $78;
  ___resumeException($$0|0);
  // unreachable;
  break;
 }
 case 0:  {
  HEAP32[$vararg_buffer23>>2] = 621528;
  $vararg_ptr1 = (($vararg_buffer23) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 621544;
  $vararg_ptr2 = (($vararg_buffer23) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 0;
  $18 = (__Z16CreateGameObjectRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKcz($name,621512,$vararg_buffer23)|0);
  $19 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($18,33)|0);
  $20 = (__Znwj(16)|0);
  $21 = (($1) + 8|0);
  HEAP32[$21>>2] = $20;
  HEAP32[$1>>2] = 17;
  $22 = (($1) + 4|0);
  HEAP32[$22>>2] = 14;
  dest=$20+0|0; src=621560+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $23 = (($20) + 14|0);
  HEAP8[$23>>0] = 0;
  __THREW__ = 0;
  $24 = (invoke_i(58)|0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   __THREW__ = 0;
   $27 = (invoke_iiii(1532,($24|0),43,($1|0))|0);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    $30 = ($27|0)==(0|0);
    if ($30) {
     HEAP32[$0>>2] = 0;
    } else {
     $31 = (($27) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     HEAP32[$0>>2] = $32;
    }
    __THREW__ = 0;
    invoke_vii(2778,($19|0),($0|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = HEAP8[$1>>0]|0;
     $36 = $35 & 1;
     $37 = ($36<<24>>24)==(0);
     if (!($37)) {
      $38 = HEAP32[$21>>2]|0;
      __ZdlPv($38);
     }
     $39 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($18,25)|0);
     $40 = (__ZN5Unity8Material25GetDefaultDiffuseMaterialEv()|0);
     $41 = ($40|0)==(0|0);
     if ($41) {
      HEAP32[$2>>2] = 0;
     } else {
      $42 = (($40) + 4|0);
      $43 = HEAP32[$42>>2]|0;
      HEAP32[$2>>2] = $43;
     }
     __ZN8Renderer11SetMaterialE4PPtrIN5Unity8MaterialEEi($39,$2,0);
     $go$0 = $18;
     STACKTOP = sp;return ($go$0|0);
    }
   }
  }
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $46 = HEAP8[$1>>0]|0;
  $47 = $46 & 1;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   $$0 = $44;$$01 = $45;
   ___resumeException($$0|0);
   // unreachable;
  }
  $49 = HEAP32[$21>>2]|0;
  __ZdlPv($49);
  $$0 = $44;$$01 = $45;
  ___resumeException($$0|0);
  // unreachable;
  break;
 }
 case 2:  {
  HEAP32[$vararg_buffer23>>2] = 621576;
  $vararg_ptr11 = (($vararg_buffer23) + 4|0);
  HEAP32[$vararg_ptr11>>2] = 621544;
  $vararg_ptr12 = (($vararg_buffer23) + 8|0);
  HEAP32[$vararg_ptr12>>2] = 0;
  $88 = (__Z16CreateGameObjectRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKcz($name,621512,$vararg_buffer23)|0);
  $89 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($88,33)|0);
  $90 = (__Znwj(32)|0);
  $91 = (($7) + 8|0);
  HEAP32[$91>>2] = $90;
  HEAP32[$7>>2] = 33;
  $92 = (($7) + 4|0);
  HEAP32[$92>>2] = 16;
  dest=$90+0|0; src=621608+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $93 = (($90) + 16|0);
  HEAP8[$93>>0] = 0;
  __THREW__ = 0;
  $94 = (invoke_i(58)|0);
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if (!($96)) {
   __THREW__ = 0;
   $97 = (invoke_iiii(1532,($94|0),43,($7|0))|0);
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if (!($99)) {
    $100 = ($97|0)==(0|0);
    if ($100) {
     HEAP32[$6>>2] = 0;
    } else {
     $101 = (($97) + 4|0);
     $102 = HEAP32[$101>>2]|0;
     HEAP32[$6>>2] = $102;
    }
    __THREW__ = 0;
    invoke_vii(2778,($89|0),($6|0));
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if (!($104)) {
     $105 = HEAP8[$7>>0]|0;
     $106 = $105 & 1;
     $107 = ($106<<24>>24)==(0);
     if (!($107)) {
      $108 = HEAP32[$91>>2]|0;
      __ZdlPv($108);
     }
     $109 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($88,136)|0);
     $110 = ($109|0)==(0|0);
     if (!($110)) {
      $111 = (__Z11GetIPhysicsv()|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = (($112) + 16|0);
      $114 = HEAP32[$113>>2]|0;
      FUNCTION_TABLE_viif[$114 & 63]($111,$109,Math_fround(2.0));
     }
     $121 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($88,25)|0);
     $122 = (__ZN5Unity8Material25GetDefaultDiffuseMaterialEv()|0);
     $123 = ($122|0)==(0|0);
     if ($123) {
      HEAP32[$8>>2] = 0;
     } else {
      $124 = (($122) + 4|0);
      $125 = HEAP32[$124>>2]|0;
      HEAP32[$8>>2] = $125;
     }
     __ZN8Renderer11SetMaterialE4PPtrIN5Unity8MaterialEEi($121,$8,0);
     $go$0 = $88;
     STACKTOP = sp;return ($go$0|0);
    }
   }
  }
  $115 = ___cxa_find_matching_catch()|0;
  $116 = tempRet0;
  $117 = HEAP8[$7>>0]|0;
  $118 = $117 & 1;
  $119 = ($118<<24>>24)==(0);
  if ($119) {
   $$0 = $115;$$01 = $116;
   ___resumeException($$0|0);
   // unreachable;
  }
  $120 = HEAP32[$91>>2]|0;
  __ZdlPv($120);
  $$0 = $115;$$01 = $116;
  ___resumeException($$0|0);
  // unreachable;
  break;
 }
 case 3:  {
  HEAP32[$vararg_buffer23>>2] = 621632;
  $vararg_ptr16 = (($vararg_buffer23) + 4|0);
  HEAP32[$vararg_ptr16>>2] = 621544;
  $vararg_ptr17 = (($vararg_buffer23) + 8|0);
  HEAP32[$vararg_ptr17>>2] = 0;
  $126 = (__Z16CreateGameObjectRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKcz($name,621512,$vararg_buffer23)|0);
  $127 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($126,33)|0);
  HEAP8[$10>>0] = 16;
  $128 = (($10) + 1|0);
  $129 = $128;
  $130 = $129;
  HEAP8[$130>>0]=1700951363&255;HEAP8[$130+1>>0]=(1700951363>>8)&255;HEAP8[$130+2>>0]=(1700951363>>16)&255;HEAP8[$130+3>>0]=1700951363>>24;
  $131 = (($129) + 4)|0;
  $132 = $131;
  HEAP8[$132>>0]=2019714606&255;HEAP8[$132+1>>0]=(2019714606>>8)&255;HEAP8[$132+2>>0]=(2019714606>>16)&255;HEAP8[$132+3>>0]=2019714606>>24;
  $133 = (($10) + 9|0);
  HEAP8[$133>>0] = 0;
  __THREW__ = 0;
  $134 = (invoke_i(58)|0);
  $135 = __THREW__; __THREW__ = 0;
  $136 = $135&1;
  if (!($136)) {
   __THREW__ = 0;
   $137 = (invoke_iiii(1532,($134|0),43,($10|0))|0);
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   if (!($139)) {
    $140 = ($137|0)==(0|0);
    if ($140) {
     HEAP32[$9>>2] = 0;
    } else {
     $141 = (($137) + 4|0);
     $142 = HEAP32[$141>>2]|0;
     HEAP32[$9>>2] = $142;
    }
    __THREW__ = 0;
    invoke_vii(2778,($127|0),($9|0));
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if (!($144)) {
     $145 = HEAP8[$10>>0]|0;
     $146 = $145 & 1;
     $147 = ($146<<24>>24)==(0);
     if (!($147)) {
      $148 = (($10) + 8|0);
      $149 = HEAP32[$148>>2]|0;
      __ZdlPv($149);
     }
     $150 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($126,56)|0);
     __Z16SmartResetObjectR6Object($150);
     $151 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($126,25)|0);
     $152 = (__ZN5Unity8Material25GetDefaultDiffuseMaterialEv()|0);
     $153 = ($152|0)==(0|0);
     if ($153) {
      HEAP32[$11>>2] = 0;
     } else {
      $154 = (($152) + 4|0);
      $155 = HEAP32[$154>>2]|0;
      HEAP32[$11>>2] = $155;
     }
     __ZN8Renderer11SetMaterialE4PPtrIN5Unity8MaterialEEi($151,$11,0);
     $go$0 = $126;
     STACKTOP = sp;return ($go$0|0);
    }
   }
  }
  $156 = ___cxa_find_matching_catch()|0;
  $157 = tempRet0;
  $158 = HEAP8[$10>>0]|0;
  $159 = $158 & 1;
  $160 = ($159<<24>>24)==(0);
  if ($160) {
   $$0 = $156;$$01 = $157;
   ___resumeException($$0|0);
   // unreachable;
  }
  $161 = (($10) + 8|0);
  $162 = HEAP32[$161>>2]|0;
  __ZdlPv($162);
  $$0 = $156;$$01 = $157;
  ___resumeException($$0|0);
  // unreachable;
  break;
 }
 case 4:  {
  HEAP32[$vararg_buffer23>>2] = 621648;
  $vararg_ptr21 = (($vararg_buffer23) + 4|0);
  HEAP32[$vararg_ptr21>>2] = 621544;
  $vararg_ptr22 = (($vararg_buffer23) + 8|0);
  HEAP32[$vararg_ptr22>>2] = 0;
  $163 = (__Z16CreateGameObjectRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKcz($name,621512,$vararg_buffer23)|0);
  $164 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($163,33)|0);
  $165 = (__Znwj(16)|0);
  $166 = (($13) + 8|0);
  HEAP32[$166>>2] = $165;
  HEAP32[$13>>2] = 17;
  $167 = (($13) + 4|0);
  HEAP32[$167>>2] = 13;
  dest=$165+0|0; src=621664+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $168 = (($165) + 13|0);
  HEAP8[$168>>0] = 0;
  __THREW__ = 0;
  $169 = (invoke_i(58)|0);
  $170 = __THREW__; __THREW__ = 0;
  $171 = $170&1;
  if (!($171)) {
   __THREW__ = 0;
   $172 = (invoke_iiii(1532,($169|0),43,($13|0))|0);
   $173 = __THREW__; __THREW__ = 0;
   $174 = $173&1;
   if (!($174)) {
    $175 = ($172|0)==(0|0);
    if ($175) {
     HEAP32[$12>>2] = 0;
    } else {
     $176 = (($172) + 4|0);
     $177 = HEAP32[$176>>2]|0;
     HEAP32[$12>>2] = $177;
    }
    __THREW__ = 0;
    invoke_vii(2778,($164|0),($12|0));
    $178 = __THREW__; __THREW__ = 0;
    $179 = $178&1;
    if (!($179)) {
     $180 = HEAP8[$13>>0]|0;
     $181 = $180 & 1;
     $182 = ($181<<24>>24)==(0);
     if (!($182)) {
      $183 = HEAP32[$166>>2]|0;
      __ZdlPv($183);
     }
     $184 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($163,56)|0);
     __Z16SmartResetObjectR6Object($184);
     $185 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($163,25)|0);
     $186 = (__ZN5Unity8Material25GetDefaultDiffuseMaterialEv()|0);
     $187 = ($186|0)==(0|0);
     if ($187) {
      HEAP32[$14>>2] = 0;
     } else {
      $188 = (($186) + 4|0);
      $189 = HEAP32[$188>>2]|0;
      HEAP32[$14>>2] = $189;
     }
     __ZN8Renderer11SetMaterialE4PPtrIN5Unity8MaterialEEi($185,$14,0);
     $go$0 = $163;
     STACKTOP = sp;return ($go$0|0);
    }
   }
  }
  $190 = ___cxa_find_matching_catch()|0;
  $191 = tempRet0;
  $192 = HEAP8[$13>>0]|0;
  $193 = $192 & 1;
  $194 = ($193<<24>>24)==(0);
  if ($194) {
   $$0 = $190;$$01 = $191;
   ___resumeException($$0|0);
   // unreachable;
  }
  $195 = HEAP32[$166>>2]|0;
  __ZdlPv($195);
  $$0 = $190;$$01 = $191;
  ___resumeException($$0|0);
  // unreachable;
  break;
 }
 case 5:  {
  HEAP32[$vararg_buffer23>>2] = 621648;
  $vararg_ptr26 = (($vararg_buffer23) + 4|0);
  HEAP32[$vararg_ptr26>>2] = 621544;
  $vararg_ptr27 = (($vararg_buffer23) + 8|0);
  HEAP32[$vararg_ptr27>>2] = 0;
  $196 = (__Z16CreateGameObjectRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKcz($name,621512,$vararg_buffer23)|0);
  $197 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($196,33)|0);
  HEAP8[$16>>0] = 16;
  $198 = (($16) + 1|0);
  $199 = $198;
  $200 = $199;
  HEAP8[$200>>0]=1684108625&255;HEAP8[$200+1>>0]=(1684108625>>8)&255;HEAP8[$200+2>>0]=(1684108625>>16)&255;HEAP8[$200+3>>0]=1684108625>>24;
  $201 = (($199) + 4)|0;
  $202 = $201;
  HEAP8[$202>>0]=2019714606&255;HEAP8[$202+1>>0]=(2019714606>>8)&255;HEAP8[$202+2>>0]=(2019714606>>16)&255;HEAP8[$202+3>>0]=2019714606>>24;
  $203 = (($16) + 9|0);
  HEAP8[$203>>0] = 0;
  __THREW__ = 0;
  $204 = (invoke_i(58)|0);
  $205 = __THREW__; __THREW__ = 0;
  $206 = $205&1;
  if (!($206)) {
   __THREW__ = 0;
   $207 = (invoke_iiii(1532,($204|0),43,($16|0))|0);
   $208 = __THREW__; __THREW__ = 0;
   $209 = $208&1;
   if (!($209)) {
    $210 = ($207|0)==(0|0);
    if ($210) {
     HEAP32[$15>>2] = 0;
    } else {
     $211 = (($207) + 4|0);
     $212 = HEAP32[$211>>2]|0;
     HEAP32[$15>>2] = $212;
    }
    __THREW__ = 0;
    invoke_vii(2778,($197|0),($15|0));
    $213 = __THREW__; __THREW__ = 0;
    $214 = $213&1;
    if (!($214)) {
     $215 = HEAP8[$16>>0]|0;
     $216 = $215 & 1;
     $217 = ($216<<24>>24)==(0);
     if (!($217)) {
      $218 = (($16) + 8|0);
      $219 = HEAP32[$218>>2]|0;
      __ZdlPv($219);
     }
     $220 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($196,56)|0);
     __Z16SmartResetObjectR6Object($220);
     $221 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($196,25)|0);
     $222 = (__ZN5Unity8Material25GetDefaultDiffuseMaterialEv()|0);
     $223 = ($222|0)==(0|0);
     if ($223) {
      HEAP32[$17>>2] = 0;
     } else {
      $224 = (($222) + 4|0);
      $225 = HEAP32[$224>>2]|0;
      HEAP32[$17>>2] = $225;
     }
     __ZN8Renderer11SetMaterialE4PPtrIN5Unity8MaterialEEi($221,$17,0);
     $go$0 = $196;
     STACKTOP = sp;return ($go$0|0);
    }
   }
  }
  $226 = ___cxa_find_matching_catch()|0;
  $227 = tempRet0;
  $228 = HEAP8[$16>>0]|0;
  $229 = $228 & 1;
  $230 = ($229<<24>>24)==(0);
  if ($230) {
   $$0 = $226;$$01 = $227;
   ___resumeException($$0|0);
   // unreachable;
  }
  $231 = (($16) + 8|0);
  $232 = HEAP32[$231>>2]|0;
  __ZdlPv($232);
  $$0 = $226;$$01 = $227;
  ___resumeException($$0|0);
  // unreachable;
  break;
 }
 default: {
  $go$0 = 0;
  STACKTOP = sp;return ($go$0|0);
 }
 }
 return 0|0;
}
function __Z25ScriptingStringToPropertyR11ICallString($iCallString) {
 $iCallString = $iCallString|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (__ZNK11ICallString6IsNullEv($iCallString)|0);
 if ($2) {
  $25 = -1;
  STACKTOP = sp;return ($25|0);
 }
 __ZNK11ICallString6AsUTF8Ev($1,$iCallString);
 $3 = HEAP8[$1>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($1) + 1|0);
  $9 = $8;
 } else {
  $6 = (($1) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $9 = $7;
 }
 HEAP32[$0>>2] = -1;
 __THREW__ = 0;
 invoke_vii(2618,($0|0),($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $20 = HEAP8[$1>>0]|0;
  $21 = $20 & 1;
  $22 = ($21<<24>>24)==(0);
  if ($22) {
   ___resumeException($18|0);
   // unreachable;
  }
  $23 = (($1) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  __ZdlPv($24);
  ___resumeException($18|0);
  // unreachable;
 } else {
  $12 = HEAP32[$0>>2]|0;
  $13 = HEAP8[$1>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $25 = $12;
   STACKTOP = sp;return ($25|0);
  }
  $16 = (($1) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  __ZdlPv($17);
  $25 = $12;
  STACKTOP = sp;return ($25|0);
 }
 return 0|0;
}
function __ZN10InputEventD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZdaPv($1);
 }
 STACKTOP = sp;return;
}
function __ZN10InputEvent4InitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 HEAP32[$this>>2] = 11;
 $1 = (($this) + 20|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN10InputEventC2ERKS_($this,$evt) {
 $this = $this|0;
 $evt = $evt|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 12|0);
 $2 = (($evt) + 4|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($evt) + 12|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $1;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = HEAP32[$evt>>2]|0;
 HEAP32[$this>>2] = $24;
 $25 = (($evt) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = $26;
 $28 = (($evt) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 24|0);
 HEAP32[$30>>2] = $29;
 $31 = (($evt) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 28|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($evt) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 32|0);
 HEAP32[$36>>2] = $35;
 $37 = (($evt) + 36|0);
 $38 = HEAP16[$37>>1]|0;
 $39 = (($this) + 36|0);
 HEAP16[$39>>1] = $38;
 $40 = (($evt) + 38|0);
 $41 = HEAP16[$40>>1]|0;
 $42 = (($this) + 38|0);
 HEAP16[$42>>1] = $41;
 $43 = (($evt) + 40|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  $53 = (($this) + 40|0);
  HEAP32[$53>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $46 = (_strlen(($44|0))|0);
  $47 = (($46) + 1)|0;
  $48 = (__Znaj($47)|0);
  $49 = (($this) + 40|0);
  HEAP32[$49>>2] = $48;
  $50 = HEAP32[$43>>2]|0;
  $51 = (_strlen(($50|0))|0);
  $52 = (($51) + 1)|0;
  _memcpy(($48|0),($50|0),($52|0))|0;
  STACKTOP = sp;return;
 }
}
function __ZN10InputEventaSERKS_($this,$evt) {
 $this = $this|0;
 $evt = $evt|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($evt) + 4|0);
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = (($this) + 12|0);
 $13 = (($evt) + 12|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $12;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = HEAP32[$evt>>2]|0;
 HEAP32[$this>>2] = $24;
 $25 = (($evt) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = $26;
 $28 = (($evt) + 24|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($this) + 24|0);
 HEAP32[$30>>2] = $29;
 $31 = (($evt) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 28|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($evt) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 32|0);
 HEAP32[$36>>2] = $35;
 $37 = (($evt) + 36|0);
 $38 = HEAP16[$37>>1]|0;
 $39 = (($this) + 36|0);
 HEAP16[$39>>1] = $38;
 $40 = (($evt) + 38|0);
 $41 = HEAP16[$40>>1]|0;
 $42 = (($this) + 38|0);
 HEAP16[$42>>1] = $41;
 $43 = (($this) + 40|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  __ZdaPv($44);
  HEAP32[$43>>2] = 0;
 }
 $46 = (($evt) + 40|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 $49 = (_strlen(($47|0))|0);
 $50 = (($49) + 1)|0;
 $51 = (__Znaj($50)|0);
 HEAP32[$43>>2] = $51;
 $52 = HEAP32[$46>>2]|0;
 $53 = (_strlen(($52|0))|0);
 $54 = (($53) + 1)|0;
 _memcpy(($51|0),($52|0),($54|0))|0;
 STACKTOP = sp;return;
}
function __Z16SanitizeKeyEventR10InputEvent($event) {
 $event = $event|0;
 var $$off = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($event) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($event) + 36|0);
  HEAP16[$4>>1] = 0;
 }
 $5 = (($event) + 38|0);
 $6 = HEAP16[$5>>1]|0;
 $$off = (($6) + -256)<<16>>16;
 $7 = ($$off&65535)<(17);
 if ($7) {
  $8 = $1 & -65;
  HEAP32[$0>>2] = $8;
  $11 = $8;
 } else {
  $11 = $1;
 }
 $9 = $6&65535;
 switch ($9|0) {
 case 296: case 295: case 294: case 293: case 292: case 291: case 290: case 289: case 288: case 287: case 286: case 285: case 284: case 283: case 282: case 8: case 127: case 281: case 280: case 279: case 278: case 275: case 276: case 274: case 273:  {
  $10 = $11 | 64;
  HEAP32[$0>>2] = $10;
  $12 = (($event) + 36|0);
  HEAP16[$12>>1] = 0;
  STACKTOP = sp;return;
  break;
 }
 default: {
 }
 }
 $$phi$trans$insert = (($event) + 36|0);
 $$pre = HEAP16[$$phi$trans$insert>>1]|0;
 $phitmp = ($$pre<<16>>16)==(13);
 if (!($phitmp)) {
  STACKTOP = sp;return;
 }
 $13 = (($event) + 36|0);
 HEAP16[$13>>1] = 10;
 STACKTOP = sp;return;
}
function __Z15WeldVertexArrayR13dynamic_arrayI8Vector3fLj4EERS_ItLj2EES4_($vertices,$triangles,$remap) {
 $vertices = $vertices|0;
 $triangles = $triangles|0;
 $remap = $remap|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $skin = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $skin = sp + 8|0;
 HEAP32[$skin>>2] = 0;
 $1 = (($skin) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($skin) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($skin) + 4|0);
 HEAP32[$3>>2] = 61;
 __THREW__ = 0;
 $4 = (invoke_iiiii(244,($vertices|0),($skin|0),($triangles|0),($remap|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = HEAP32[$2>>2]|0;
  $8 = ($7|0)>(-1);
  if (!($8)) {
   STACKTOP = sp;return ($4|0);
  }
  $9 = HEAP32[$skin>>2]|0;
  $10 = HEAP32[$3>>2]|0;
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy1);
  HEAP32[$skin>>2] = 0;
  STACKTOP = sp;return ($4|0);
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $13 = HEAP32[$2>>2]|0;
 $14 = ($13|0)>(-1);
 if (!($14)) {
  ___resumeException($11|0);
  // unreachable;
 }
 $15 = HEAP32[$skin>>2]|0;
 $16 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $16;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($15|0),($$byval_copy1|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 }
 HEAP32[$skin>>2] = 0;
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z15WeldVertexArrayR13dynamic_arrayI8Vector3fLj4EERS_I13BoneInfluenceLj16EERS_ItLj2EES7_($vertices,$skin,$triangles,$remap) {
 $vertices = $vertices|0;
 $skin = $skin|0;
 $triangles = $triangles|0;
 $remap = $remap|0;
 var $$0 = 0, $$arith = 0, $$byval_copy6 = 0, $$overflow = 0, $$pre = 0, $$pre38 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $cond = 0, $cond16 = 0, $i$01$i = 0, $i$01$us$i = 0, $i$023 = 0, $i1$02 = 0, $offset$0 = 0, $offset$015 = 0, $offset$017 = 0, $outputCount$0$lcssa = 0, $outputCount$028 = 0, $outputCount$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy6 = sp + 4|0;
 $0 = sp;
 $1 = (($vertices) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -1)|0;
 $4 = $3 >>> 1;
 $5 = $4 | $3;
 $6 = $5 >>> 2;
 $7 = $6 | $5;
 $8 = $7 >>> 4;
 $9 = $8 | $7;
 $10 = $9 >>> 8;
 $11 = $10 | $9;
 $12 = $11 >>> 16;
 $13 = $12 | $11;
 $14 = (($13) + 1)|0;
 $15 = ($14|0)==(0);
 $16 = $15&1;
 $17 = (($16) + ($14))|0;
 $18 = (($17) + ($2))|0;
 $$arith = $18<<2;
 $$overflow = ($18>>>0)>(1073741823);
 $19 = $$overflow ? -1 : $$arith;
 $20 = (__Znaj($19)|0);
 $21 = (($remap) + 8|0);
 HEAP32[$21>>2] = $2;
 $22 = (($remap) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($24>>>0)<($2>>>0);
 do {
  if ($25) {
   $26 = ($23|0)>(-1);
   if ($26) {
    HEAP32[$22>>2] = $2;
    $27 = HEAP32[$remap>>2]|0;
    $28 = $2 << 1;
    $29 = (($remap) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    HEAP32[$0>>2] = $30;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    $31 = (__Z16realloc_internalPvji10MemLabelIdiPKci($27,$28,2,$$byval_copy6,0,621680,370)|0);
    HEAP32[$remap>>2] = $31;
    break;
   } else {
    $32 = $2 << 1;
    $33 = (($remap) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$0>>2] = $34;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    $35 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,2,$$byval_copy6,0,621680,352)|0);
    $36 = HEAP32[$remap>>2]|0;
    $37 = HEAP32[$21>>2]|0;
    $38 = $37 << 1;
    _memcpy(($35|0),($36|0),($38|0))|0;
    HEAP32[$22>>2] = $2;
    HEAP32[$remap>>2] = $35;
    break;
   }
  }
 } while(0);
 $39 = $17 << 2;
 _memset(($20|0),-1,($39|0))|0;
 $40 = HEAP32[$1>>2]|0;
 $41 = ($40|0)==(0);
 if ($41) {
  $170 = 0;$outputCount$0$lcssa = 0;
 } else {
  $42 = (($16) + ($13))|0;
  $43 = (($skin) + 8|0);
  $171 = $40;$i$023 = 0;$outputCount$028 = 0;
  while(1) {
   $44 = HEAP32[$vertices>>2]|0;
   $45 = (($44) + (($i$023*12)|0)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ((($44) + (($i$023*12)|0)|0) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48*11)|0;
   $50 = (($49) + ($46))|0;
   $51 = ((($44) + (($i$023*12)|0)|0) + 8|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = Math_imul($52, -17)|0;
   $54 = (($50) + ($53))|0;
   $55 = $54 & 2147483647;
   $56 = $55 >>> 22;
   $57 = $55 >>> 12;
   $58 = $57 ^ $55;
   $59 = $58 ^ $56;
   $60 = $59 & $42;
   $61 = (($20) + ($60<<2)|0);
   $offset$015 = HEAP32[$61>>2]|0;
   $cond16 = ($offset$015|0)==(-1);
   $62 = (HEAP32[tempDoublePtr>>2]=$46,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $63 = (HEAP32[tempDoublePtr>>2]=$48,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $64 = (HEAP32[tempDoublePtr>>2]=$52,Math_fround(HEAPF32[tempDoublePtr>>2]));
   L11: do {
    if ($cond16) {
     label = 20;
    } else {
     $offset$017 = $offset$015;
     L12: while(1) {
      $65 = (($44) + (($offset$017*12)|0)|0);
      $66 = Math_fround(HEAPF32[$65>>2]);
      $67 = $66 == $62;
      L14: do {
       if ($67) {
        $68 = ((($44) + (($offset$017*12)|0)|0) + 4|0);
        $69 = Math_fround(HEAPF32[$68>>2]);
        $70 = $69 == $63;
        if ($70) {
         $71 = ((($44) + (($offset$017*12)|0)|0) + 8|0);
         $72 = Math_fround(HEAPF32[$71>>2]);
         $73 = $72 == $64;
         if ($73) {
          $74 = HEAP32[$43>>2]|0;
          $75 = ($74|0)==(0);
          if ($75) {
           break L12;
          }
          $76 = HEAP32[$skin>>2]|0;
          $77 = (($76) + ($i$023<<5)|0);
          $78 = Math_fround(HEAPF32[$77>>2]);
          $79 = (($76) + ($offset$017<<5)|0);
          $80 = Math_fround(HEAPF32[$79>>2]);
          $81 = Math_fround($78 - $80);
          $82 = $81 < Math_fround(0.0);
          if ($82) {
           $83 = !($81 >= Math_fround(-9.99999997475242707878E-7));
           if ($83) {
            break;
           } else {
            $i$01$us$i = 0;
           }
           while(1) {
            $87 = (((($76) + ($i$023<<5)|0) + ($i$01$us$i<<2)|0) + 16|0);
            $88 = HEAP32[$87>>2]|0;
            $89 = (((($76) + ($offset$017<<5)|0) + ($i$01$us$i<<2)|0) + 16|0);
            $90 = HEAP32[$89>>2]|0;
            $91 = ($88|0)==($90|0);
            $86 = (($i$01$us$i) + 1)|0;
            if (!($91)) {
             break L14;
            }
            $85 = ($86|0)<(4);
            if ($85) {
             $i$01$us$i = $86;
            } else {
             break L12;
            }
           }
          } else {
           $84 = !($81 <= Math_fround(9.99999997475242707878E-7));
           if ($84) {
            break;
           } else {
            $i$01$i = 0;
           }
           while(1) {
            $94 = (((($76) + ($i$023<<5)|0) + ($i$01$i<<2)|0) + 16|0);
            $95 = HEAP32[$94>>2]|0;
            $96 = (((($76) + ($offset$017<<5)|0) + ($i$01$i<<2)|0) + 16|0);
            $97 = HEAP32[$96>>2]|0;
            $98 = ($95|0)==($97|0);
            $93 = (($i$01$i) + 1)|0;
            if (!($98)) {
             break L14;
            }
            $92 = ($93|0)<(4);
            if ($92) {
             $i$01$i = $93;
            } else {
             break L12;
            }
           }
          }
         }
        }
       }
      } while(0);
      $$sum1 = (($offset$017) + ($17))|0;
      $99 = (($20) + ($$sum1<<2)|0);
      $offset$0 = HEAP32[$99>>2]|0;
      $cond = ($offset$0|0)==(-1);
      if ($cond) {
       label = 20;
       break L11;
      } else {
       $offset$017 = $offset$0;
      }
     }
     $112 = $offset$017&65535;
     $113 = HEAP32[$remap>>2]|0;
     $114 = (($113) + ($i$023<<1)|0);
     HEAP16[$114>>1] = $112;
     $117 = $171;$outputCount$1 = $outputCount$028;
    }
   } while(0);
   if ((label|0) == 20) {
    label = 0;
    $100 = $outputCount$028&65535;
    $101 = HEAP32[$remap>>2]|0;
    $102 = (($101) + ($i$023<<1)|0);
    HEAP16[$102>>1] = $100;
    $103 = (($44) + (($outputCount$028*12)|0)|0);
    ;HEAP32[$103+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$45+8>>2]|0;
    $104 = HEAP32[$43>>2]|0;
    $105 = ($104|0)==(0);
    if (!($105)) {
     $106 = HEAP32[$skin>>2]|0;
     $107 = (($106) + ($outputCount$028<<5)|0);
     $108 = (($106) + ($i$023<<5)|0);
     ;HEAP32[$107+0>>2]=HEAP32[$108+0>>2]|0;HEAP32[$107+4>>2]=HEAP32[$108+4>>2]|0;HEAP32[$107+8>>2]=HEAP32[$108+8>>2]|0;HEAP32[$107+12>>2]=HEAP32[$108+12>>2]|0;HEAP32[$107+16>>2]=HEAP32[$108+16>>2]|0;HEAP32[$107+20>>2]=HEAP32[$108+20>>2]|0;HEAP32[$107+24>>2]=HEAP32[$108+24>>2]|0;HEAP32[$107+28>>2]=HEAP32[$108+28>>2]|0;
    }
    $109 = HEAP32[$61>>2]|0;
    $$sum = (($outputCount$028) + ($17))|0;
    $110 = (($20) + ($$sum<<2)|0);
    HEAP32[$110>>2] = $109;
    $111 = (($outputCount$028) + 1)|0;
    HEAP32[$61>>2] = $outputCount$028;
    $$pre38 = HEAP32[$1>>2]|0;
    $117 = $$pre38;$outputCount$1 = $111;
   }
   $115 = (($i$023) + 1)|0;
   $116 = ($115>>>0)<($117>>>0);
   if ($116) {
    $171 = $117;$i$023 = $115;$outputCount$028 = $outputCount$1;
   } else {
    $170 = $117;$outputCount$0$lcssa = $outputCount$1;
    break;
   }
  }
 }
 $118 = ($20|0)==(0|0);
 if ($118) {
  $120 = $170;
 } else {
  __ZdaPv($20);
  $$pre = HEAP32[$1>>2]|0;
  $120 = $$pre;
 }
 $119 = ($outputCount$0$lcssa>>>0)<($120>>>0);
 if (!($119)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $outputCount$0$lcssa;
 $121 = (($vertices) + 12|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = $122 & 2147483647;
 $124 = ($123>>>0)<($outputCount$0$lcssa>>>0);
 do {
  if ($124) {
   $125 = ($122|0)>(-1);
   if ($125) {
    HEAP32[$121>>2] = $outputCount$0$lcssa;
    $126 = HEAP32[$vertices>>2]|0;
    $127 = ($outputCount$0$lcssa*12)|0;
    $128 = (($vertices) + 4|0);
    $129 = HEAP32[$128>>2]|0;
    HEAP32[$0>>2] = $129;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    $130 = (__Z16realloc_internalPvji10MemLabelIdiPKci($126,$127,4,$$byval_copy6,0,621680,370)|0);
    HEAP32[$vertices>>2] = $130;
    break;
   } else {
    $131 = ($outputCount$0$lcssa*12)|0;
    $132 = (($vertices) + 4|0);
    $133 = HEAP32[$132>>2]|0;
    HEAP32[$0>>2] = $133;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    $134 = (__Z15malloc_internaljj10MemLabelIdiPKci($131,4,$$byval_copy6,0,621680,352)|0);
    $135 = HEAP32[$vertices>>2]|0;
    $136 = HEAP32[$1>>2]|0;
    $137 = ($136*12)|0;
    _memcpy(($134|0),($135|0),($137|0))|0;
    HEAP32[$121>>2] = $outputCount$0$lcssa;
    HEAP32[$vertices>>2] = $134;
    break;
   }
  }
 } while(0);
 $138 = (($skin) + 8|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = ($139|0)==(0);
 do {
  if (!($140)) {
   HEAP32[$138>>2] = $outputCount$0$lcssa;
   $141 = (($skin) + 12|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = $142 & 2147483647;
   $144 = ($143>>>0)<($outputCount$0$lcssa>>>0);
   if ($144) {
    $145 = ($142|0)>(-1);
    if ($145) {
     HEAP32[$141>>2] = $outputCount$0$lcssa;
     $146 = HEAP32[$skin>>2]|0;
     $147 = $outputCount$0$lcssa << 5;
     $148 = (($skin) + 4|0);
     $149 = HEAP32[$148>>2]|0;
     HEAP32[$0>>2] = $149;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     $150 = (__Z16realloc_internalPvji10MemLabelIdiPKci($146,$147,16,$$byval_copy6,0,621680,370)|0);
     HEAP32[$skin>>2] = $150;
     break;
    } else {
     $151 = $outputCount$0$lcssa << 5;
     $152 = (($skin) + 4|0);
     $153 = HEAP32[$152>>2]|0;
     HEAP32[$0>>2] = $153;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     $154 = (__Z15malloc_internaljj10MemLabelIdiPKci($151,16,$$byval_copy6,0,621680,352)|0);
     $155 = HEAP32[$skin>>2]|0;
     $156 = HEAP32[$138>>2]|0;
     $157 = $156 << 5;
     _memcpy(($154|0),($155|0),($157|0))|0;
     HEAP32[$141>>2] = $outputCount$0$lcssa;
     HEAP32[$skin>>2] = $154;
     break;
    }
   }
  }
 } while(0);
 $158 = (($triangles) + 8|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = ($159|0)==(0);
 if ($160) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $161 = HEAP32[$triangles>>2]|0;
 $162 = HEAP32[$remap>>2]|0;
 $i1$02 = 0;
 while(1) {
  $163 = (($161) + ($i1$02<<1)|0);
  $164 = HEAP16[$163>>1]|0;
  $165 = $164&65535;
  $166 = (($162) + ($165<<1)|0);
  $167 = HEAP16[$166>>1]|0;
  HEAP16[$163>>1] = $167;
  $168 = (($i1$02) + 1)|0;
  $169 = ($168>>>0)<($159>>>0);
  if ($169) {
   $i1$02 = $168;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __Z20ConvertContactToMonoP9Collision($input) {
 $input = $input|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $j$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($input) + 4|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $15 = (($input) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (__ZN9Scripting19ScriptingWrapperForEP6Object($16)|0);
  $18 = (($input) + 20|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (__ZN9Scripting19ScriptingWrapperForEP6Object($19)|0);
  $21 = (($input) + 48|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround(-$22);
  $24 = (($input) + 52|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround(-$25);
  $27 = (($input) + 56|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround(-$28);
  $101 = $17;$103 = $20;$95 = $23;$97 = $26;$99 = $29;
 } else {
  $3 = (($input) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN9Scripting19ScriptingWrapperForEP6Object($4)|0);
  $6 = (($input) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__ZN9Scripting19ScriptingWrapperForEP6Object($7)|0);
  $9 = (($input) + 48|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($input) + 52|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($input) + 56|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $101 = $5;$103 = $8;$95 = $10;$97 = $12;$99 = $14;
 }
 $30 = (__Z14GetMonoManagerv()|0);
 $31 = (($30) + 260|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($input) + 60|0);
 $34 = (($input) + 68|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (__Z19scripting_array_newP14ScriptingClassjj($32,32,$35)|0);
 $37 = (($input) + 64|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==($33|0);
 if ($39) {
  $90 = (__Z14GetMonoManagerv()|0);
  $91 = (($90) + 256|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (_il2cpp_object_new($92)|0);
  $94 = (($93) + 8|0);
  HEAPF32[$94>>2] = $95;
  $96 = (($93) + 12|0);
  HEAPF32[$96>>2] = $97;
  $98 = (($93) + 16|0);
  HEAPF32[$98>>2] = $99;
  $100 = (($93) + 20|0);
  HEAP32[$100>>2] = $101;
  $102 = (($93) + 24|0);
  HEAP32[$102>>2] = $103;
  $104 = (($93) + 28|0);
  HEAP32[$104>>2] = $36;
  STACKTOP = sp;return ($93|0);
 } else {
  $42 = $38;$j$06 = 0;
 }
 while(1) {
  $40 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($36,$j$06,32)|0);
  $41 = (($42) + 8|0);
  $43 = (($42) + 16|0);
  ;HEAP32[$40+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$43+8>>2]|0;
  $44 = HEAP8[$0>>0]|0;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   $71 = HEAP32[$41>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    $76 = 0;
   } else {
    $73 = (($71) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $76 = $74;
   }
   $75 = (($40) + 24|0);
   HEAP32[$75>>2] = $76;
   $77 = (($42) + 12|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==(0|0);
   if ($79) {
    $83 = 0;
   } else {
    $80 = (($78) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    $83 = $81;
   }
   $82 = (($40) + 28|0);
   HEAP32[$82>>2] = $83;
   $84 = (($40) + 12|0);
   $85 = (($42) + 28|0);
   ;HEAP32[$84+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$85+8>>2]|0;
  } else {
   $46 = (($42) + 12|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    $52 = 0;
   } else {
    $49 = (($47) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $52 = $50;
   }
   $51 = (($40) + 24|0);
   HEAP32[$51>>2] = $52;
   $53 = HEAP32[$41>>2]|0;
   $54 = ($53|0)==(0|0);
   if ($54) {
    $58 = 0;
   } else {
    $55 = (($53) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $58 = $56;
   }
   $57 = (($40) + 28|0);
   HEAP32[$57>>2] = $58;
   $59 = (($42) + 28|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround(-$60);
   $62 = (($42) + 32|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = Math_fround(-$63);
   $65 = (($42) + 36|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = Math_fround(-$66);
   $68 = (($40) + 12|0);
   HEAPF32[$68>>2] = $61;
   $69 = (($40) + 16|0);
   HEAPF32[$69>>2] = $64;
   $70 = (($40) + 20|0);
   HEAPF32[$70>>2] = $67;
  }
  $86 = (($j$06) + 1)|0;
  $87 = (($42) + 4|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = ($88|0)==($33|0);
  if ($89) {
   break;
  } else {
   $42 = $88;$j$06 = $86;
  }
 }
 $90 = (__Z14GetMonoManagerv()|0);
 $91 = (($90) + 256|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (_il2cpp_object_new($92)|0);
 $94 = (($93) + 8|0);
 HEAPF32[$94>>2] = $95;
 $96 = (($93) + 12|0);
 HEAPF32[$96>>2] = $97;
 $98 = (($93) + 16|0);
 HEAPF32[$98>>2] = $99;
 $100 = (($93) + 20|0);
 HEAP32[$100>>2] = $101;
 $102 = (($93) + 24|0);
 HEAP32[$102>>2] = $103;
 $104 = (($93) + 28|0);
 HEAP32[$104>>2] = $36;
 STACKTOP = sp;return ($93|0);
}
function __ZN12UserListNode5ClearEv($this) {
 $this = $this|0;
 var $$c = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $entryInOther$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 4|0);
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($1) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + -1)|0;
 $9 = ($8|0)==($5|0);
 if ($9) {
  $35 = $7;
 } else {
  $10 = (($1) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + ($8<<3)|0);
  $13 = (($11) + ($5<<3)|0);
  $14 = $12;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = $13;
  $21 = $20;
  HEAP32[$21>>2] = $16;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  $24 = HEAP32[$10>>2]|0;
  $25 = ((($24) + ($8<<3)|0) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)==(-1);
  $28 = (($24) + ($8<<3)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 4|0);
  if ($27) {
   $entryInOther$0$i$i = $30;
  } else {
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + ($26<<3)|0);
   $entryInOther$0$i$i = $32;
  }
  $33 = (($entryInOther$0$i$i) + 4|0);
  HEAP32[$33>>2] = $5;
  $$pre$i = HEAP32[$6>>2]|0;
  $35 = $$pre$i;
 }
 $34 = (($35) + -1)|0;
 $$c = $34;
 HEAP32[$6>>2] = $$c;
 $36 = $3;
 $37 = $36;
 HEAP32[$37>>2] = 0;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN8UserList5ClearEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$c = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $entryInOther$0$i$i = 0, $index$02 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $index$02 = 0;
  while(1) {
   $5 = HEAP32[$1>>2]|0;
   $6 = ((($5) + ($index$02<<3)|0) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(-1);
   $9 = (($5) + ($index$02<<3)|0);
   $10 = HEAP32[$9>>2]|0;
   if ($8) {
    $11 = (($10) + 4|0);
    $12 = $11;
    $13 = $12;
    HEAP32[$13>>2] = 0;
    $14 = (($12) + 4)|0;
    $15 = $14;
    HEAP32[$15>>2] = -1;
   } else {
    $16 = (($10) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + -1)|0;
    $19 = ($18|0)==($7|0);
    if ($19) {
     $45 = $17;
    } else {
     $20 = (($10) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($21) + ($18<<3)|0);
     $23 = (($21) + ($7<<3)|0);
     $24 = $22;
     $25 = $24;
     $26 = HEAP32[$25>>2]|0;
     $27 = (($24) + 4)|0;
     $28 = $27;
     $29 = HEAP32[$28>>2]|0;
     $30 = $23;
     $31 = $30;
     HEAP32[$31>>2] = $26;
     $32 = (($30) + 4)|0;
     $33 = $32;
     HEAP32[$33>>2] = $29;
     $34 = HEAP32[$20>>2]|0;
     $35 = ((($34) + ($18<<3)|0) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(-1);
     $38 = (($34) + ($18<<3)|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + 4|0);
     if ($37) {
      $entryInOther$0$i$i = $40;
     } else {
      $41 = HEAP32[$40>>2]|0;
      $42 = (($41) + ($36<<3)|0);
      $entryInOther$0$i$i = $42;
     }
     $43 = (($entryInOther$0$i$i) + 4|0);
     HEAP32[$43>>2] = $7;
     $$pre$i = HEAP32[$16>>2]|0;
     $45 = $$pre$i;
    }
    $44 = (($45) + -1)|0;
    $$c = $44;
    HEAP32[$16>>2] = $$c;
   }
   $46 = (($index$02) + 1)|0;
   $47 = HEAP32[$2>>2]|0;
   $48 = ($46>>>0)<($47>>>0);
   if ($48) {
    $index$02 = $46;
   } else {
    break;
   }
  }
 }
 $49 = (($this) + 16|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)>(-1);
 if (!($51)) {
  HEAP32[$2>>2] = 0;
  HEAP32[$49>>2] = 0;
  STACKTOP = sp;return;
 }
 $52 = HEAP32[$1>>2]|0;
 $53 = (($this) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$0>>2] = $54;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($52,$$byval_copy);
 HEAP32[$1>>2] = 0;
 HEAP32[$2>>2] = 0;
 HEAP32[$49>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN8UserList7ReserveEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4>>>0)<($size>>>0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = ($3|0)>(-1);
 if ($6) {
  HEAP32[$2>>2] = $size;
  $7 = HEAP32[$1>>2]|0;
  $8 = $size << 3;
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $11 = (__Z16realloc_internalPvji10MemLabelIdiPKci($7,$8,4,$$byval_copy1,0,621688,370)|0);
  HEAP32[$1>>2] = $11;
  STACKTOP = sp;return;
 } else {
  $12 = $size << 3;
  $13 = (($this) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$0>>2] = $14;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $15 = (__Z15malloc_internaljj10MemLabelIdiPKci($12,4,$$byval_copy1,0,621688,352)|0);
  $16 = HEAP32[$1>>2]|0;
  $17 = (($this) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 << 3;
  _memcpy(($15|0),($16|0),($19|0))|0;
  HEAP32[$2>>2] = $size;
  HEAP32[$1>>2] = $15;
  STACKTOP = sp;return;
 }
}
function __ZN8UserList7AddUserER12UserListNode($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$c$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $entryInOther$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($other) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$pre = (($other) + 8|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $3 = (($other) + 4|0);
  $4 = (($other) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($1) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + -1)|0;
  $9 = ($8|0)==($5|0);
  if ($9) {
   $35 = $7;
  } else {
   $10 = (($1) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + ($8<<3)|0);
   $13 = (($11) + ($5<<3)|0);
   $14 = $12;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = $13;
   $21 = $20;
   HEAP32[$21>>2] = $16;
   $22 = (($20) + 4)|0;
   $23 = $22;
   HEAP32[$23>>2] = $19;
   $24 = HEAP32[$10>>2]|0;
   $25 = ((($24) + ($8<<3)|0) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(-1);
   $28 = (($24) + ($8<<3)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 4|0);
   if ($27) {
    $entryInOther$0$i$i$i = $30;
   } else {
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + ($26<<3)|0);
    $entryInOther$0$i$i$i = $32;
   }
   $33 = (($entryInOther$0$i$i$i) + 4|0);
   HEAP32[$33>>2] = $5;
   $$pre$i$i = HEAP32[$6>>2]|0;
   $35 = $$pre$i$i;
  }
  $34 = (($35) + -1)|0;
  $$c$i = $34;
  HEAP32[$6>>2] = $$c$i;
  $36 = $3;
  $37 = $36;
  HEAP32[$37>>2] = 0;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = -1;
  $$pre$phiZ2D = $4;
 }
 HEAP32[$0>>2] = $this;
 $40 = (($this) + 4|0);
 $41 = (($this) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 HEAP32[$$pre$phiZ2D>>2] = $42;
 $43 = (__ZN13dynamic_arrayIN12UserListBase5EntryELj4EE9push_backEv($40)|0);
 HEAP32[$43>>2] = $other;
 $44 = (($43) + 4|0);
 HEAP32[$44>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIN12UserListBase5EntryELj4EE9push_backEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 do {
  if ($7) {
   $8 = $5 << 1;
   $9 = ($8|0)==(0);
   $10 = $9 ? 1 : $8;
   $11 = ($6>>>0)<($10>>>0);
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = $10 << 3;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,621688,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = $10 << 3;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,621688,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = $23 << 3;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($25) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + ($26<<3)|0);
 STACKTOP = sp;return ($28|0);
}
function __ZN8UserList7AddUserERS_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($other) + 4|0);
 $4 = (($other) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZN13dynamic_arrayIN12UserListBase5EntryELj4EE9push_backEv($0)|0);
 HEAP32[$6>>2] = $other;
 $7 = (($6) + 4|0);
 HEAP32[$7>>2] = $5;
 $8 = (__ZN13dynamic_arrayIN12UserListBase5EntryELj4EE9push_backEv($3)|0);
 HEAP32[$8>>2] = $this;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN8UserList11SendMessageERK17MessageIdentifier($this,$msg) {
 $this = $this|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $storemerge2$i = 0, $storemerge2$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 $0 = (($data) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($data) + 4|0);
 HEAP32[$1>>2] = 0;
 HEAP32[$data>>2] = 0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $storemerge2$in$i = $3;
 while(1) {
  $storemerge2$i = (($storemerge2$in$i) + -1)|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($storemerge2$i<<3)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  __ZN5Unity17SendMessageDirectER6ObjectRK17MessageIdentifierR11MessageData($9,$msg,$data);
  $10 = HEAP32[$2>>2]|0;
  $11 = ($10|0)<($storemerge2$i|0);
  $12 = $11 ? $10 : $storemerge2$i;
  $13 = ($12|0)>(0);
  if ($13) {
   $storemerge2$in$i = $12;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z25PlayerLoadLevelFromThreadiRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER18AwakeFromLoadQueue($levelIndex,$name,$loadQueue) {
 $levelIndex = $levelIndex|0;
 $name = $name|0;
 $loadQueue = $loadQueue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12LevelLoading9LoadLevelEiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER18AwakeFromLoadQueue(621760,$levelIndex,$name,$loadQueue);
 STACKTOP = sp;return;
}
function __ZN12LevelLoading9LoadLevelEiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER18AwakeFromLoadQueue($this,$index,$path,$loadQueue) {
 $this = $this|0;
 $index = $index|0;
 $path = $path|0;
 $loadQueue = $loadQueue|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i14 = 0, $$0$i$i$i18 = 0, $$0$i1041 = 0, $$0$i2539 = 0, $$0$i37 = 0, $$01$i$i$i = 0, $$01$i$i$i16 = 0, $$1 = 0, $$12 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i = 0, $$pre69 = 0, $$pre70 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__nd$0$in$i$i = 0, $it$0$ph62 = 0, $kLevelWasLoaded$byval_copy = 0, $lpad$phi$index = 0, $lpad$phi$index8 = 0, $lpad$phi58$index = 0, $lpad$phi58$index2 = 0, $needActivation = 0, $needsIsTemporaryReset = 0, $temporaryObjects = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp + 80|0;
 $kLevelWasLoaded$byval_copy = sp + 60|0;
 $0 = sp + 56|0;
 $1 = sp + 52|0;
 $2 = sp + 48|0;
 $temporaryObjects = sp + 24|0;
 $needActivation = sp + 12|0;
 $needsIsTemporaryReset = sp;
 $3 = sp + 36|0;
 $4 = (($temporaryObjects) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($temporaryObjects) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($temporaryObjects) + 4|0);
 HEAP32[$temporaryObjects>>2] = $6;
 $7 = (($this) + 4|0);
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 L1: do {
  if (!($10)) {
   $11 = HEAP32[$7>>2]|0;
   $260 = $11;$261 = $9;$it$0$ph62 = $11;
   L3: while(1) {
    $262 = $260;$263 = $261;
    while(1) {
     $12 = HEAP32[$it$0$ph62>>2]|0;
     $13 = ($12|0)==(0);
     if ($13) {
      $62 = $263;$64 = $262;
     } else {
      HEAP32[$2>>2] = $12;
      $14 = HEAP32[560624>>2]|0;
      $15 = ($14|0)==(0|0);
      if (!($15)) {
       $16 = (($14) + 36|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = (($14) + 4|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = ($17|0)==($19|0);
       do {
        if ($20) {
         $21 = (($14) + 28|0);
         $22 = HEAP32[$21>>2]|0;
         $23 = (($14) + 32|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = (($22) + ($24<<3)|0);
         $41 = $25;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$14,$2);
         $26 = HEAP32[$$byval_copy>>2]|0;
         $27 = ($26|0)==(-1);
         $28 = (($14) + 28|0);
         $29 = HEAP32[$28>>2]|0;
         if ($27) {
          $30 = (($14) + 32|0);
          $31 = HEAP32[$30>>2]|0;
          $32 = (($29) + ($31<<3)|0);
          $41 = $32;
          break;
         } else {
          $33 = (($29) + ($26<<3)|0);
          $41 = $33;
          break;
         }
        }
       } while(0);
       $34 = HEAP32[560624>>2]|0;
       $35 = (($34) + 28|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = (($34) + 32|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + ($38<<3)|0);
       $40 = ($41|0)==($39|0);
       if (!($40)) {
        $42 = (($41) + 4|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = ($43|0)==(0|0);
        if (!($44)) {
         $$0$i37 = $43;
         break;
        }
       }
      }
      $45 = HEAP32[$it$0$ph62>>2]|0;
      __THREW__ = 0;
      $46 = (invoke_ii(3215,($45|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 18;
       break L3;
      }
      $49 = ($46|0)==(0|0);
      if (!($49)) {
       $$0$i37 = $46;
       break;
      }
      $$pre69 = HEAP32[$8>>2]|0;
      $$pre70 = HEAP32[$7>>2]|0;
      $62 = $$pre69;$64 = $$pre70;
     }
     $61 = (($62) + -1)|0;
     $63 = (($64) + ($61<<2)|0);
     $65 = HEAP32[$63>>2]|0;
     HEAP32[$it$0$ph62>>2] = $65;
     $66 = HEAP32[$8>>2]|0;
     $67 = (($66) + -1)|0;
     HEAP32[$8>>2] = $67;
     $68 = (($64) + ($67<<2)|0);
     $69 = ($it$0$ph62|0)==($68|0);
     if ($69) {
      break L1;
     } else {
      $262 = $64;$263 = $67;
     }
    }
    __THREW__ = 0;
    invoke_vii(2779,($$0$i37|0),($temporaryObjects|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 19;
     break;
    }
    $52 = (($it$0$ph62) + 4|0);
    $53 = HEAP32[$7>>2]|0;
    $54 = HEAP32[$8>>2]|0;
    $55 = (($53) + ($54<<2)|0);
    $56 = ($52|0)==($55|0);
    if ($56) {
     break L1;
    } else {
     $260 = $53;$261 = $54;$it$0$ph62 = $52;
    }
   }
   if ((label|0) == 18) {
    $57 = ___cxa_find_matching_catch()|0;
    $58 = tempRet0;
    $lpad$phi58$index = $57;$lpad$phi58$index2 = $58;
   }
   else if ((label|0) == 19) {
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    $lpad$phi58$index = $59;$lpad$phi58$index2 = $60;
   }
   $$1 = $lpad$phi58$index;$$12 = $lpad$phi58$index2;
   $259 = HEAP32[$4>>2]|0;
   __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($temporaryObjects,$259);
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $70 = (($needActivation) + 4|0);
 HEAP32[$70>>2] = 0;
 $71 = (($needActivation) + 8|0);
 HEAP32[$71>>2] = 0;
 $72 = (($needActivation) + 4|0);
 HEAP32[$needActivation>>2] = $72;
 $73 = (($needsIsTemporaryReset) + 4|0);
 HEAP32[$73>>2] = 0;
 $74 = (($needsIsTemporaryReset) + 8|0);
 HEAP32[$74>>2] = 0;
 $75 = (($needsIsTemporaryReset) + 4|0);
 HEAP32[$needsIsTemporaryReset>>2] = $75;
 $76 = HEAP32[$temporaryObjects>>2]|0;
 $77 = ($76|0)==($6|0);
 L31: do {
  if ($77) {
   label = 56;
  } else {
   $79 = $76;
   L33: while(1) {
    $78 = (($79) + 16|0);
    $80 = HEAP32[$78>>2]|0;
    $81 = ($80|0)==(0);
    do {
     if (!($81)) {
      HEAP32[$0>>2] = $80;
      $82 = HEAP32[560624>>2]|0;
      $83 = ($82|0)==(0|0);
      if ($83) {
       label = 33;
      } else {
       $84 = (($82) + 36|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = (($82) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($85|0)==($87|0);
       do {
        if ($88) {
         $89 = (($82) + 28|0);
         $90 = HEAP32[$89>>2]|0;
         $91 = (($82) + 32|0);
         $92 = HEAP32[$91>>2]|0;
         $93 = (($90) + ($92<<3)|0);
         $109 = $93;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$82,$0);
         $94 = HEAP32[$$byval_copy>>2]|0;
         $95 = ($94|0)==(-1);
         $96 = (($82) + 28|0);
         $97 = HEAP32[$96>>2]|0;
         if ($95) {
          $98 = (($82) + 32|0);
          $99 = HEAP32[$98>>2]|0;
          $100 = (($97) + ($99<<3)|0);
          $109 = $100;
          break;
         } else {
          $101 = (($97) + ($94<<3)|0);
          $109 = $101;
          break;
         }
        }
       } while(0);
       $102 = HEAP32[560624>>2]|0;
       $103 = (($102) + 28|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = (($102) + 32|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = (($104) + ($106<<3)|0);
       $108 = ($109|0)==($107|0);
       if ($108) {
        label = 33;
       } else {
        $110 = (($109) + 4|0);
        $111 = HEAP32[$110>>2]|0;
        $112 = ($111|0)==(0|0);
        if ($112) {
         label = 33;
        } else {
         $$0$i2539 = $111;
        }
       }
      }
      if ((label|0) == 33) {
       label = 0;
       __THREW__ = 0;
       $113 = (invoke_ii(3215,($80|0))|0);
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        break L33;
       }
       $116 = ($113|0)==(0|0);
       if ($116) {
        break;
       } else {
        $$0$i2539 = $113;
       }
      }
      $117 = (($$0$i2539) + 8|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = $118 & 65536;
      $120 = ($119|0)==(0);
      if ($120) {
       $121 = (($$0$i2539) + 4|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = HEAP32[$73>>2]|0;
       $124 = ($123|0)==(0|0);
       do {
        if ($124) {
         HEAP32[$$byval_copy>>2] = $75;
         $$0$i$i = $75;$142 = $75;
        } else {
         $__nd$0$in$i$i = $123;
         while(1) {
          $125 = (($__nd$0$in$i$i) + 16|0);
          $126 = HEAP32[$125>>2]|0;
          $127 = ($122|0)<($126|0);
          if ($127) {
           $128 = HEAP32[$__nd$0$in$i$i>>2]|0;
           $129 = ($128|0)==(0|0);
           if ($129) {
            label = 39;
            break;
           } else {
            $__nd$0$in$i$i = $128;
            continue;
           }
          }
          $130 = ($126|0)<($122|0);
          if (!($130)) {
           label = 43;
           break;
          }
          $131 = (($__nd$0$in$i$i) + 4|0);
          $132 = HEAP32[$131>>2]|0;
          $133 = ($132|0)==(0|0);
          if ($133) {
           label = 42;
           break;
          } else {
           $__nd$0$in$i$i = $132;
          }
         }
         if ((label|0) == 39) {
          label = 0;
          HEAP32[$$byval_copy>>2] = $__nd$0$in$i$i;
          $$0$i$i = $__nd$0$in$i$i;$142 = $__nd$0$in$i$i;
          break;
         }
         else if ((label|0) == 42) {
          label = 0;
          HEAP32[$$byval_copy>>2] = $__nd$0$in$i$i;
          $$0$i$i = $131;$142 = $__nd$0$in$i$i;
          break;
         }
         else if ((label|0) == 43) {
          label = 0;
          HEAP32[$$byval_copy>>2] = $__nd$0$in$i$i;
          $$0$i$i = $$byval_copy;$142 = $__nd$0$in$i$i;
          break;
         }
        }
       } while(0);
       $134 = HEAP32[$$0$i$i>>2]|0;
       $135 = ($134|0)==(0|0);
       if ($135) {
        __THREW__ = 0;
        $136 = (invoke_ii(2988,20)|0);
        $137 = __THREW__; __THREW__ = 0;
        $138 = $137&1;
        if ($138) {
         break L33;
        }
        $139 = (($136) + 16|0);
        HEAP32[$139>>2] = $122;
        HEAP32[$136>>2] = 0;
        $140 = (($136) + 4|0);
        HEAP32[$140>>2] = 0;
        $141 = (($136) + 8|0);
        HEAP32[$141>>2] = $142;
        HEAP32[$$0$i$i>>2] = $136;
        $143 = HEAP32[$needsIsTemporaryReset>>2]|0;
        $144 = HEAP32[$143>>2]|0;
        $145 = ($144|0)==(0|0);
        if ($145) {
         $147 = $136;
        } else {
         HEAP32[$needsIsTemporaryReset>>2] = $144;
         $$pre$i$i = HEAP32[$$0$i$i>>2]|0;
         $147 = $$pre$i$i;
        }
        $146 = HEAP32[$73>>2]|0;
        __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($146,$147);
        $148 = HEAP32[$74>>2]|0;
        $149 = (($148) + 1)|0;
        HEAP32[$74>>2] = $149;
        $$pre = HEAP32[$117>>2]|0;
        $151 = $$pre;
       } else {
        $151 = $118;
       }
       $150 = $151 | 65536;
       HEAP32[$117>>2] = $150;
      }
     }
    } while(0);
    $152 = (($79) + 4|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = ($153|0)==(0|0);
    if ($154) {
     $$01$i$i$i16 = $79;
     while(1) {
      $157 = (($$01$i$i$i16) + 8|0);
      $158 = HEAP32[$157>>2]|0;
      $159 = HEAP32[$158>>2]|0;
      $160 = ($159|0)==($$01$i$i$i16|0);
      if ($160) {
       $$0$i$i$i18 = $158;
       break;
      } else {
       $$01$i$i$i16 = $158;
      }
     }
    } else {
     $$0$i$i$i$i14 = $153;
     while(1) {
      $155 = HEAP32[$$0$i$i$i$i14>>2]|0;
      $156 = ($155|0)==(0|0);
      if ($156) {
       $$0$i$i$i18 = $$0$i$i$i$i14;
       break;
      } else {
       $$0$i$i$i$i14 = $155;
      }
     }
    }
    $161 = ($$0$i$i$i18|0)==($6|0);
    if ($161) {
     label = 56;
     break L31;
    } else {
     $79 = $$0$i$i$i18;
    }
   }
   $253 = ___cxa_find_matching_catch()|0;
   $254 = tempRet0;
   $lpad$phi$index = $253;$lpad$phi$index8 = $254;
  }
 } while(0);
 L81: do {
  if ((label|0) == 56) {
   __THREW__ = 0;
   invoke_v(150);
   $162 = __THREW__; __THREW__ = 0;
   $163 = $162&1;
   L83: do {
    if (!($163)) {
     $164 = HEAP32[$needsIsTemporaryReset>>2]|0;
     $165 = ($164|0)==($75|0);
     L85: do {
      if (!($165)) {
       $167 = $164;
       L87: while(1) {
        $166 = (($167) + 16|0);
        $168 = HEAP32[$166>>2]|0;
        $169 = ($168|0)==(0);
        do {
         if (!($169)) {
          HEAP32[$1>>2] = $168;
          $170 = HEAP32[560624>>2]|0;
          $171 = ($170|0)==(0|0);
          if ($171) {
           label = 68;
          } else {
           $172 = (($170) + 36|0);
           $173 = HEAP32[$172>>2]|0;
           $174 = (($170) + 4|0);
           $175 = HEAP32[$174>>2]|0;
           $176 = ($173|0)==($175|0);
           do {
            if ($176) {
             $177 = (($170) + 28|0);
             $178 = HEAP32[$177>>2]|0;
             $179 = (($170) + 32|0);
             $180 = HEAP32[$179>>2]|0;
             $181 = (($178) + ($180<<3)|0);
             $197 = $181;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$170,$1);
             $182 = HEAP32[$$byval_copy>>2]|0;
             $183 = ($182|0)==(-1);
             $184 = (($170) + 28|0);
             $185 = HEAP32[$184>>2]|0;
             if ($183) {
              $186 = (($170) + 32|0);
              $187 = HEAP32[$186>>2]|0;
              $188 = (($185) + ($187<<3)|0);
              $197 = $188;
              break;
             } else {
              $189 = (($185) + ($182<<3)|0);
              $197 = $189;
              break;
             }
            }
           } while(0);
           $190 = HEAP32[560624>>2]|0;
           $191 = (($190) + 28|0);
           $192 = HEAP32[$191>>2]|0;
           $193 = (($190) + 32|0);
           $194 = HEAP32[$193>>2]|0;
           $195 = (($192) + ($194<<3)|0);
           $196 = ($197|0)==($195|0);
           if ($196) {
            label = 68;
           } else {
            $198 = (($197) + 4|0);
            $199 = HEAP32[$198>>2]|0;
            $200 = ($199|0)==(0|0);
            if ($200) {
             label = 68;
            } else {
             $$0$i1041 = $199;
            }
           }
          }
          if ((label|0) == 68) {
           label = 0;
           $201 = HEAP32[$166>>2]|0;
           __THREW__ = 0;
           $202 = (invoke_ii(3215,($201|0))|0);
           $203 = __THREW__; __THREW__ = 0;
           $204 = $203&1;
           if ($204) {
            break L87;
           }
           $205 = ($202|0)==(0|0);
           if ($205) {
            break;
           } else {
            $$0$i1041 = $202;
           }
          }
          $206 = (($$0$i1041) + 8|0);
          $207 = HEAP32[$206>>2]|0;
          $208 = $207 & -65537;
          HEAP32[$206>>2] = $208;
         }
        } while(0);
        $209 = (($167) + 4|0);
        $210 = HEAP32[$209>>2]|0;
        $211 = ($210|0)==(0|0);
        if ($211) {
         $$01$i$i$i = $167;
         while(1) {
          $214 = (($$01$i$i$i) + 8|0);
          $215 = HEAP32[$214>>2]|0;
          $216 = HEAP32[$215>>2]|0;
          $217 = ($216|0)==($$01$i$i$i|0);
          if ($217) {
           $$0$i$i$i = $215;
           break;
          } else {
           $$01$i$i$i = $215;
          }
         }
        } else {
         $$0$i$i$i$i = $210;
         while(1) {
          $212 = HEAP32[$$0$i$i$i$i>>2]|0;
          $213 = ($212|0)==(0|0);
          if ($213) {
           $$0$i$i$i = $$0$i$i$i$i;
           break;
          } else {
           $$0$i$i$i$i = $212;
          }
         }
        }
        $218 = ($$0$i$i$i|0)==($75|0);
        if ($218) {
         break L85;
        } else {
         $167 = $$0$i$i$i;
        }
       }
       $251 = ___cxa_find_matching_catch()|0;
       $252 = tempRet0;
       $lpad$phi$index = $251;$lpad$phi$index8 = $252;
       break L81;
      }
     } while(0);
     HEAP32[$this>>2] = $index;
     $219 = (($this) + 20|0);
     HEAP8[$219>>0] = 0;
     $220 = ($index|0)<(0);
     do {
      if ($220) {
       HEAP8[$219>>0] = 1;
       $221 = (($this) + 24|0);
       $222 = (($this) + 36|0);
       __THREW__ = 0;
       (invoke_iii(2359,($221|0),($222|0))|0);
       $223 = __THREW__; __THREW__ = 0;
       $224 = $223&1;
       if ($224) {
        break L83;
       }
       $225 = HEAP8[$222>>0]|0;
       $226 = $225 & 1;
       $227 = ($226<<24>>24)==(0);
       if ($227) {
        $231 = (($222) + 1|0);
        HEAP8[$231>>0] = 0;
        HEAP8[$222>>0] = 0;
        break;
       } else {
        $228 = (($this) + 44|0);
        $229 = HEAP32[$228>>2]|0;
        HEAP8[$229>>0] = 0;
        $230 = (($this) + 40|0);
        HEAP32[$230>>2] = 0;
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vii(2780,($path|0),($loadQueue|0));
     $232 = __THREW__; __THREW__ = 0;
     $233 = $232&1;
     if (!($233)) {
      HEAP32[$3>>2] = 100000;
      $234 = (($3) + 4|0);
      HEAP32[$234>>2] = $index;
      $235 = (($3) + 8|0);
      HEAP32[$235>>2] = 0;
      __THREW__ = 0;
      ;HEAP32[$kLevelWasLoaded$byval_copy+0>>2]=HEAP32[565768+0>>2]|0;HEAP32[$kLevelWasLoaded$byval_copy+4>>2]=HEAP32[565768+4>>2]|0;HEAP32[$kLevelWasLoaded$byval_copy+8>>2]=HEAP32[565768+8>>2]|0;HEAP32[$kLevelWasLoaded$byval_copy+12>>2]=HEAP32[565768+12>>2]|0;HEAP32[$kLevelWasLoaded$byval_copy+16>>2]=HEAP32[565768+16>>2]|0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
      invoke_vii(2781,($kLevelWasLoaded$byval_copy|0),($$byval_copy|0));
      $236 = __THREW__; __THREW__ = 0;
      $237 = $236&1;
      if (!($237)) {
       __THREW__ = 0;
       $238 = (invoke_i(78)|0);
       $239 = __THREW__; __THREW__ = 0;
       $240 = $239&1;
       if (!($240)) {
        __THREW__ = 0;
        invoke_vi(3525,($238|0));
        $241 = __THREW__; __THREW__ = 0;
        $242 = $241&1;
        if (!($242)) {
         __THREW__ = 0;
         $243 = (invoke_i(87)|0);
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if (!($245)) {
          __THREW__ = 0;
          invoke_vi(3526,($243|0));
          $246 = __THREW__; __THREW__ = 0;
          $247 = $246&1;
          if (!($247)) {
           $248 = HEAP32[$73>>2]|0;
           __ZNSt3__16__treeI4PPtrI6ObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($needsIsTemporaryReset,$248);
           $249 = HEAP32[$70>>2]|0;
           __ZNSt3__16__treeI4PPtrIN5Unity10GameObjectEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($needActivation,$249);
           $250 = HEAP32[$4>>2]|0;
           __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($temporaryObjects,$250);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   $255 = ___cxa_find_matching_catch()|0;
   $256 = tempRet0;
   $lpad$phi$index = $255;$lpad$phi$index8 = $256;
  }
 } while(0);
 $257 = HEAP32[$73>>2]|0;
 __ZNSt3__16__treeI4PPtrI6ObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($needsIsTemporaryReset,$257);
 $258 = HEAP32[$70>>2]|0;
 __ZNSt3__16__treeI4PPtrIN5Unity10GameObjectEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($needActivation,$258);
 $$1 = $lpad$phi$index;$$12 = $lpad$phi$index8;
 $259 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($temporaryObjects,$259);
 ___resumeException($$1|0);
 // unreachable;
}
function __Z14SetPlayerPause11PlayerPause($pause) {
 $pause = $pause|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $kPlayerPause$byval_copy = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $kPlayerPause$byval_copy = sp;
 $0 = sp + 20|0;
 $1 = HEAP32[621816>>2]|0;
 $2 = ($1|0)==($pause|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ($1|0)==(2);
 $4 = ($pause|0)==(1);
 $or$cond = $3 & $4;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $5 = (__Z19GetBuildSettingsPtrv()|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (__Z9GetIAudiov()|0);
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = ($pause|0)!=(0);
  $10 = HEAP32[$7>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($7,$9);
 }
 $12 = (__Z14GetTimeManagerv()|0);
 $13 = ($pause|0)==(2);
 __ZN11TimeManager8SetPauseEb($12,$13);
 do {
  if ($13) {
   $14 = (__Z16GetScreenManagerv()|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 76|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vii[$17 & 4095]($14,0);
   $18 = (__Z16GetScreenManagerv()|0);
   __ZN13ScreenManager18SetAllowCursorLockEb($18,0);
   label = 10;
  } else {
   $19 = ($pause|0)==(0);
   if ($19) {
    label = 10;
    break;
   }
   HEAP32[621816>>2] = $pause;
   $20 = $pause & -3;
   $21 = ($20|0)==(0);
   if (!($21)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  HEAP32[621816>>2] = $pause;
 }
 $22 = $13&1;
 HEAP32[$0>>2] = 100001;
 $23 = (($0) + 4|0);
 HEAP32[$23>>2] = $22;
 $24 = (($0) + 8|0);
 HEAP32[$24>>2] = 0;
 ;HEAP32[$kPlayerPause$byval_copy+0>>2]=HEAP32[565816+0>>2]|0;HEAP32[$kPlayerPause$byval_copy+4>>2]=HEAP32[565816+4>>2]|0;HEAP32[$kPlayerPause$byval_copy+8>>2]=HEAP32[565816+8>>2]|0;HEAP32[$kPlayerPause$byval_copy+12>>2]=HEAP32[565816+12>>2]|0;HEAP32[$kPlayerPause$byval_copy+16>>2]=HEAP32[565816+16>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 __Z21SendMessageToEveryone17MessageIdentifier11MessageData($kPlayerPause$byval_copy,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z14GetPlayerPausev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[621816>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z14SetPlayerFocusb($focus) {
 $focus = $focus|0;
 var $$byval_copy = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $kPlayerFocus$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $kPlayerFocus$byval_copy = sp;
 $0 = sp + 20|0;
 $1 = (__Z19GetBuildSettingsPtrv()|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 if (!($focus)) {
 }
 $3 = HEAP8[621832>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (__Z16GetBuildSettingsv()|0);
  $6 = (($5) + 120|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z17GetNumericVersionPKc(621840)|0);
  $9 = ($7|0)>($8|0);
  $10 = $9&1;
  HEAP8[621824>>0] = $10;
  HEAP8[621832>>0] = 1;
  $12 = $10;
 } else {
  $$pr = HEAP8[621824>>0]|0;
  $12 = $$pr;
 }
 $11 = ($12<<24>>24)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $13 = $focus&1;
 HEAP32[$0>>2] = 100001;
 $14 = (($0) + 4|0);
 HEAP32[$14>>2] = $13;
 $15 = (($0) + 8|0);
 HEAP32[$15>>2] = 0;
 ;HEAP32[$kPlayerFocus$byval_copy+0>>2]=HEAP32[565864+0>>2]|0;HEAP32[$kPlayerFocus$byval_copy+4>>2]=HEAP32[565864+4>>2]|0;HEAP32[$kPlayerFocus$byval_copy+8>>2]=HEAP32[565864+8>>2]|0;HEAP32[$kPlayerFocus$byval_copy+12>>2]=HEAP32[565864+12>>2]|0;HEAP32[$kPlayerFocus$byval_copy+16>>2]=HEAP32[565864+16>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 __Z21SendMessageToEveryone17MessageIdentifier11MessageData($kPlayerFocus$byval_copy,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z24GetPlayerRunInBackgroundv() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20GetPlayerSettingsPtrv()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__Z17GetPlayerSettingsv()|0);
 $3 = (($2) + 165|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __Z32AddPathRemapsForBuiltinResourcesRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($applicationContentsFolderPath) {
 $applicationContentsFolderPath = $applicationContentsFolderPath|0;
 var $$0 = 0, $$0$i$i = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$pre$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $extraResourcesLower = 0, $v$off$i$i = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 12|0;
 $extraResourcesLower = sp + 24|0;
 $3 = sp + 36|0;
 $4 = (__Z20GetPersistentManagerv()|0);
 $5 = (__Znwj(32)|0);
 $6 = (($0) + 8|0);
 HEAP32[$6>>2] = $5;
 HEAP32[$0>>2] = 33;
 $7 = (($0) + 4|0);
 HEAP32[$7>>2] = 31;
 dest=$5+0|0; src=621848+0|0; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $8 = (($5) + 31|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 $9 = (invoke_ii(2988,48)|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $73 = ___cxa_find_matching_catch()|0;
  $74 = tempRet0;
  $$1 = $74;$$12 = $73;
 } else {
  $12 = (($2) + 8|0);
  HEAP32[$12>>2] = $9;
  HEAP32[$2>>2] = 49;
  $13 = (($2) + 4|0);
  HEAP32[$13>>2] = 33;
  dest=$9+0|0; src=622456+0|0; stop=dest+33|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $14 = (($9) + 33|0);
  HEAP8[$14>>0] = 0;
  __THREW__ = 0;
  invoke_viii(1776,($1|0),($applicationContentsFolderPath|0),($2|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  do {
   if ($16) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    $$0 = $76;$$01 = $75;
   } else {
    __THREW__ = 0;
    invoke_viii(1784,($4|0),($0|0),($1|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     $77 = ___cxa_find_matching_catch()|0;
     $78 = tempRet0;
     $79 = HEAP8[$1>>0]|0;
     $80 = $79 & 1;
     $81 = ($80<<24>>24)==(0);
     if ($81) {
      $$0 = $78;$$01 = $77;
      break;
     }
     $82 = (($1) + 8|0);
     $83 = HEAP32[$82>>2]|0;
     __ZdlPv($83);
     $$0 = $78;$$01 = $77;
     break;
    }
    $19 = HEAP8[$1>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $22 = (($1) + 8|0);
     $23 = HEAP32[$22>>2]|0;
     __ZdlPv($23);
    }
    $24 = HEAP8[$2>>0]|0;
    $25 = $24 & 1;
    $26 = ($25<<24>>24)==(0);
    if (!($26)) {
     $27 = HEAP32[$12>>2]|0;
     __ZdlPv($27);
    }
    $28 = HEAP8[$0>>0]|0;
    $29 = $28 & 1;
    $30 = ($29<<24>>24)==(0);
    if (!($30)) {
     $31 = HEAP32[$6>>2]|0;
     __ZdlPv($31);
    }
    $32 = (__Znwj(32)|0);
    $33 = (($extraResourcesLower) + 8|0);
    HEAP32[$33>>2] = $32;
    HEAP32[$extraResourcesLower>>2] = 33;
    $34 = (($extraResourcesLower) + 4|0);
    HEAP32[$34>>2] = 29;
    dest=$32+0|0; src=622424+0|0; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $35 = (($32) + 29|0);
    HEAP8[$35>>0] = 0;
    $$pre3$i = (($extraResourcesLower) + 1|0);
    $37 = 33;$47 = $32;
    while(1) {
     $36 = $37 & 1;
     $38 = ($36<<24>>24)==(0);
     if ($38) {
      $41 = $37&255;
      $42 = $41 >>> 1;
      $44 = $$pre3$i;$45 = $42;
     } else {
      $39 = HEAP32[$33>>2]|0;
      $40 = HEAP32[$34>>2]|0;
      $44 = $39;$45 = $40;
     }
     $43 = (($44) + ($45)|0);
     $46 = ($47|0)==($43|0);
     if ($46) {
      break;
     }
     $48 = HEAP8[$47>>0]|0;
     $v$off$i$i = (($48) + -65)<<24>>24;
     $49 = ($v$off$i$i&255)<(26);
     if ($49) {
      $50 = $48&255;
      $51 = $50 | 32;
      $52 = $51&255;
      $$0$i$i = $52;
     } else {
      $$0$i$i = $48;
     }
     HEAP8[$47>>0] = $$0$i$i;
     $53 = (($47) + 1|0);
     $$pre$i = HEAP8[$extraResourcesLower>>0]|0;
     $37 = $$pre$i;$47 = $53;
    }
    __THREW__ = 0;
    $54 = (invoke_i(57)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    do {
     if ($56) {
      label = 34;
     } else {
      __THREW__ = 0;
      $57 = (invoke_ii(2988,32)|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 34;
      } else {
       $60 = (($3) + 8|0);
       HEAP32[$60>>2] = $57;
       HEAP32[$3>>2] = 33;
       $61 = (($3) + 4|0);
       HEAP32[$61>>2] = 29;
       dest=$57+0|0; src=622424+0|0; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $62 = (($57) + 29|0);
       HEAP8[$62>>0] = 0;
       __THREW__ = 0;
       invoke_viii(1784,($54|0),($extraResourcesLower|0),($3|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        $94 = ___cxa_find_matching_catch()|0;
        $95 = tempRet0;
        $96 = HEAP8[$3>>0]|0;
        $97 = $96 & 1;
        $98 = ($97<<24>>24)==(0);
        if ($98) {
         $$2 = $95;$$23 = $94;
         break;
        }
        $99 = HEAP32[$60>>2]|0;
        __ZdlPv($99);
        $$2 = $95;$$23 = $94;
        break;
       }
       $65 = HEAP8[$3>>0]|0;
       $66 = $65 & 1;
       $67 = ($66<<24>>24)==(0);
       if (!($67)) {
        $68 = HEAP32[$60>>2]|0;
        __ZdlPv($68);
       }
       $69 = HEAP8[$extraResourcesLower>>0]|0;
       $70 = $69 & 1;
       $71 = ($70<<24>>24)==(0);
       if ($71) {
        STACKTOP = sp;return;
       }
       $72 = HEAP32[$33>>2]|0;
       __ZdlPv($72);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 34) {
     $92 = ___cxa_find_matching_catch()|0;
     $93 = tempRet0;
     $$2 = $93;$$23 = $92;
    }
    $100 = HEAP8[$extraResourcesLower>>0]|0;
    $101 = $100 & 1;
    $102 = ($101<<24>>24)==(0);
    if ($102) {
     $$3 = $$2;$$34 = $$23;
     ___resumeException($$34|0);
     // unreachable;
    }
    $103 = HEAP32[$33>>2]|0;
    __ZdlPv($103);
    $$3 = $$2;$$34 = $$23;
    ___resumeException($$34|0);
    // unreachable;
   }
  } while(0);
  $84 = HEAP8[$2>>0]|0;
  $85 = $84 & 1;
  $86 = ($85<<24>>24)==(0);
  if ($86) {
   $$1 = $$0;$$12 = $$01;
  } else {
   $87 = HEAP32[$12>>2]|0;
   __ZdlPv($87);
   $$1 = $$0;$$12 = $$01;
  }
 }
 $88 = HEAP8[$0>>0]|0;
 $89 = $88 & 1;
 $90 = ($89<<24>>24)==(0);
 if ($90) {
  $$3 = $$1;$$34 = $$12;
  ___resumeException($$34|0);
  // unreachable;
 }
 $91 = HEAP32[$6>>2]|0;
 __ZdlPv($91);
 $$3 = $$1;$$34 = $$12;
 ___resumeException($$34|0);
 // unreachable;
}
function __Z26PlayerInitEngineNoGraphicsRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_($dataFolder,$applicationContentsFolderPath) {
 $dataFolder = $dataFolder|0;
 $applicationContentsFolderPath = $applicationContentsFolderPath|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i9 = 0, $error = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer3 = sp;
 $0 = sp + 40|0;
 $1 = sp + 4|0;
 $error = sp + 16|0;
 $2 = sp + 28|0;
 $3 = (_strlen((627696|0))|0);
 $4 = ($3>>>0)>(4294967279);
 if ($4) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $5 = ($3>>>0)<(11);
 if ($5) {
  $6 = $3 << 1;
  $7 = $6&255;
  HEAP8[$1>>0] = $7;
  $8 = (($1) + 1|0);
  $__p$0$i$i$i = $8;
 } else {
  $9 = (($3) + 16)|0;
  $10 = $9 & -16;
  $11 = (__Znwj($10)|0);
  $12 = (($1) + 8|0);
  HEAP32[$12>>2] = $11;
  $13 = $10 | 1;
  HEAP32[$1>>2] = $13;
  $14 = (($1) + 4|0);
  HEAP32[$14>>2] = $3;
  $__p$0$i$i$i = $11;
 }
 _memcpy(($__p$0$i$i$i|0),(627696|0),($3|0))|0;
 $15 = (($__p$0$i$i$i) + ($3)|0);
 HEAP8[$15>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1776,($0|0),($dataFolder|0),($1|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if ($17) {
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   $$0 = $32;$$01 = $31;
  } else {
   __THREW__ = 0;
   $18 = (invoke_ii(3266,($0|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $33 = ___cxa_find_matching_catch()|0;
    $34 = tempRet0;
    $35 = HEAP8[$0>>0]|0;
    $36 = $35 & 1;
    $37 = ($36<<24>>24)==(0);
    if ($37) {
     $$0 = $34;$$01 = $33;
     break;
    }
    $38 = (($0) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    __ZdlPv($39);
    $$0 = $34;$$01 = $33;
    break;
   }
   $21 = HEAP8[$0>>0]|0;
   $22 = $21 & 1;
   $23 = ($22<<24>>24)==(0);
   if (!($23)) {
    $24 = (($0) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    __ZdlPv($25);
   }
   $26 = HEAP8[$1>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if (!($28)) {
    $29 = (($1) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    __ZdlPv($30);
   }
   if (!($18)) {
    _printf_console(621880,$vararg_buffer3);
    $$14 = 0;
    STACKTOP = sp;return ($$14|0);
   }
   __Z29InitPathNamePersistentManagerv();
   __ZN4File19SetCurrentDirectoryERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($dataFolder);
   __Z32AddPathRemapsForBuiltinResourcesRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($applicationContentsFolderPath);
   $45 = (__Z26InitializeEngineNoGraphicsv()|0);
   if (!($45)) {
    _printf_console(621928,$vararg_buffer3);
    $$14 = 0;
    STACKTOP = sp;return ($$14|0);
   }
   $46 = (_strlen((627696|0))|0);
   $47 = ($46>>>0)>(4294967279);
   if ($47) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $48 = ($46>>>0)<(11);
   if ($48) {
    $49 = $46 << 1;
    $50 = $49&255;
    HEAP8[$2>>0] = $50;
    $51 = (($2) + 1|0);
    $__p$0$i$i$i9 = $51;
   } else {
    $52 = (($46) + 16)|0;
    $53 = $52 & -16;
    $54 = (__Znwj($53)|0);
    $55 = (($2) + 8|0);
    HEAP32[$55>>2] = $54;
    $56 = $53 | 1;
    HEAP32[$2>>2] = $56;
    $57 = (($2) + 4|0);
    HEAP32[$57>>2] = $46;
    $__p$0$i$i$i9 = $54;
   }
   _memcpy(($__p$0$i$i$i9|0),(627696|0),($46|0))|0;
   $58 = (($__p$0$i$i$i9) + ($46)|0);
   HEAP8[$58>>0] = 0;
   __THREW__ = 0;
   invoke_vii(2782,($error|0),($2|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $81 = ___cxa_find_matching_catch()|0;
    $82 = tempRet0;
    $83 = HEAP8[$2>>0]|0;
    $84 = $83 & 1;
    $85 = ($84<<24>>24)==(0);
    if ($85) {
     $$1 = $82;$$12 = $81;
     ___resumeException($$12|0);
     // unreachable;
    }
    $86 = (($2) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    __ZdlPv($87);
    $$1 = $82;$$12 = $81;
    ___resumeException($$12|0);
    // unreachable;
   }
   $61 = HEAP8[$2>>0]|0;
   $62 = $61 & 1;
   $63 = ($62<<24>>24)==(0);
   if (!($63)) {
    $64 = (($2) + 8|0);
    $65 = HEAP32[$64>>2]|0;
    __ZdlPv($65);
   }
   $66 = HEAP8[$error>>0]|0;
   $67 = $66 & 1;
   $68 = ($67<<24>>24)==(0);
   if ($68) {
    $71 = $66&255;
    $72 = $71 >>> 1;
    $74 = $72;
   } else {
    $69 = (($error) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $74 = $70;
   }
   $73 = ($74|0)==(0);
   if ($73) {
    __THREW__ = 0;
    $95 = (invoke_i(78)|0);
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 39;
    } else {
     $98 = (($95) + 448|0);
     __THREW__ = 0;
     invoke_vi(3525,($98|0));
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      label = 39;
     } else {
      $$03 = 1;
      label = 43;
     }
    }
   } else {
    if ($68) {
     $77 = (($error) + 1|0);
     $78 = $77;
    } else {
     $75 = (($error) + 8|0);
     $76 = HEAP32[$75>>2]|0;
     $78 = $76;
    }
    __THREW__ = 0;
    HEAP32[$vararg_buffer3>>2] = $78;
    invoke_vii(2587,(621984|0),($vararg_buffer3|0));
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     label = 39;
    } else {
     $$03 = 0;
     label = 43;
    }
   }
   if ((label|0) == 39) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    $90 = HEAP8[$error>>0]|0;
    $91 = $90 & 1;
    $92 = ($91<<24>>24)==(0);
    if ($92) {
     $$1 = $89;$$12 = $88;
     ___resumeException($$12|0);
     // unreachable;
    }
    $93 = (($error) + 8|0);
    $94 = HEAP32[$93>>2]|0;
    __ZdlPv($94);
    $$1 = $89;$$12 = $88;
    ___resumeException($$12|0);
    // unreachable;
   }
   else if ((label|0) == 43) {
    $101 = HEAP8[$error>>0]|0;
    $102 = $101 & 1;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $$14 = $$03;
     STACKTOP = sp;return ($$14|0);
    }
    $104 = (($error) + 8|0);
    $105 = HEAP32[$104>>2]|0;
    __ZdlPv($105);
    $$14 = $$03;
    STACKTOP = sp;return ($$14|0);
   }
  }
 } while(0);
 $40 = HEAP8[$1>>0]|0;
 $41 = $40 & 1;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$12|0);
  // unreachable;
 }
 $43 = (($1) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 __ZdlPv($44);
 $$1 = $$0;$$12 = $$01;
 ___resumeException($$12|0);
 // unreachable;
 return 0|0;
}
function __Z24PlayerInitEngineGraphicsb($batchmode) {
 $batchmode = $batchmode|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $gpuMsg = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer3 = sp;
 $gpuMsg = sp + 16|0;
 $error = sp + 4|0;
 $0 = (__Z24InitializeEngineGraphicsb($batchmode)|0);
 if (!($0)) {
  _printf_console(622032,$vararg_buffer3);
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 __ZNK12GraphicsCaps17CheckGPUSupportedEv($gpuMsg,640792);
 $1 = HEAP8[$gpuMsg>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $9 = $7;
 } else {
  $4 = (($gpuMsg) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $9 = $5;
 }
 $8 = ($9|0)==(0);
 do {
  if ($8) {
   __THREW__ = 0;
   invoke_vii(2783,($error|0),(627696|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    label = 11;
   } else {
    $20 = HEAP8[$error>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $25 = $20&255;
     $26 = $25 >>> 1;
     $28 = $26;
    } else {
     $23 = (($error) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $28 = $24;
    }
    $27 = ($28|0)==(0);
    if ($27) {
     __THREW__ = 0;
     invoke_vi(3527,(0|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      label = 21;
     } else {
      $$02 = 1;
      label = 24;
     }
    } else {
     if ($22) {
      $31 = (($error) + 1|0);
      $32 = $31;
     } else {
      $29 = (($error) + 8|0);
      $30 = HEAP32[$29>>2]|0;
      $32 = $30;
     }
     __THREW__ = 0;
     HEAP32[$vararg_buffer3>>2] = $32;
     invoke_vii(2587,(622152|0),($vararg_buffer3|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      label = 21;
     } else {
      $$02 = 0;
      label = 24;
     }
    }
    if ((label|0) == 21) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     $37 = HEAP8[$error>>0]|0;
     $38 = $37 & 1;
     $39 = ($38<<24>>24)==(0);
     if ($39) {
      $$0 = $36;$$01 = $35;
      break;
     }
     $40 = (($error) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     __ZdlPv($41);
     $$0 = $36;$$01 = $35;
     break;
    }
    else if ((label|0) == 24) {
     $44 = HEAP8[$error>>0]|0;
     $45 = $44 & 1;
     $46 = ($45<<24>>24)==(0);
     if ($46) {
      $$1 = $$02;
      label = 26;
      break;
     }
     $47 = (($error) + 8|0);
     $48 = HEAP32[$47>>2]|0;
     __ZdlPv($48);
     $$1 = $$02;
     label = 26;
     break;
    }
   }
  } else {
   if ($3) {
    $12 = (($gpuMsg) + 1|0);
    $13 = $12;
   } else {
    $10 = (($gpuMsg) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $13 = $11;
   }
   __THREW__ = 0;
   HEAP32[$vararg_buffer3>>2] = $13;
   invoke_vii(2587,(622096|0),($vararg_buffer3|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 11;
   } else {
    $$1 = 0;
    label = 26;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $$0 = $17;$$01 = $16;
 }
 else if ((label|0) == 26) {
  $49 = HEAP8[$gpuMsg>>0]|0;
  $50 = $49 & 1;
  $51 = ($50<<24>>24)==(0);
  if ($51) {
   $$2 = $$1;
   STACKTOP = sp;return ($$2|0);
  }
  $52 = (($gpuMsg) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  __ZdlPv($53);
  $$2 = $$1;
  STACKTOP = sp;return ($$2|0);
 }
 $54 = HEAP8[$gpuMsg>>0]|0;
 $55 = $54 & 1;
 $56 = ($55<<24>>24)==(0);
 if ($56) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $57 = (($gpuMsg) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 __ZdlPv($58);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z20PlayerLoadFirstLevelv() {
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $emptyQueue = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy5 = sp + 164|0;
 $0 = sp;
 $1 = sp + 4|0;
 $emptyQueue = sp + 8|0;
 $2 = sp + 136|0;
 $3 = sp + 140|0;
 $4 = sp + 152|0;
 $5 = HEAP32[((621760 + 16|0))>>2]|0;
 $6 = ($5|0)>(-1);
 if ($6) {
  $7 = HEAP32[((621760 + 4|0))>>2]|0;
  $8 = HEAP32[((621760 + 8|0))>>2]|0;
  HEAP32[$0>>2] = $8;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy5);
  HEAP32[((621760 + 4|0))>>2] = 0;
 }
 HEAP32[((621760 + 12|0))>>2] = 0;
 HEAP32[((621760 + 16|0))>>2] = 0;
 HEAP32[621760>>2] = 0;
 HEAP8[((621760 + 20|0))>>0] = 0;
 $9 = HEAP8[((621760 + 24|0))>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  HEAP8[((((621760 + 24|0)) + 1|0))>>0] = 0;
  HEAP8[((621760 + 24|0))>>0] = 0;
 } else {
  $12 = HEAP32[((621760 + 32|0))>>2]|0;
  HEAP8[$12>>0] = 0;
  HEAP32[((621760 + 28|0))>>2] = 0;
 }
 $13 = HEAP8[((621760 + 36|0))>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  HEAP8[((((621760 + 36|0)) + 1|0))>>0] = 0;
  HEAP8[((621760 + 36|0))>>0] = 0;
 } else {
  $16 = HEAP32[((621760 + 44|0))>>2]|0;
  HEAP8[$16>>0] = 0;
  HEAP32[((621760 + 40|0))>>2] = 0;
 }
 $17 = HEAP32[628512>>2]|0;
 HEAP32[$2>>2] = $17;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN18AwakeFromLoadQueueC2E10MemLabelId($emptyQueue,$$byval_copy5);
 __THREW__ = 0;
 invoke_vi(3528,($emptyQueue|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L12: do {
  if ($19) {
   label = 40;
  } else {
   $20 = (_strlen((627696|0))|0);
   $21 = ($20>>>0)>(4294967279);
   if ($21) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 40;
     break;
    }
    // unreachable;
   }
   $24 = ($20>>>0)<(11);
   if ($24) {
    $25 = $20 << 1;
    $26 = $25&255;
    HEAP8[$3>>0] = $26;
    $27 = (($3) + 1|0);
    $__p$0$i$i$i = $27;
   } else {
    $28 = (($20) + 16)|0;
    $29 = $28 & -16;
    __THREW__ = 0;
    $30 = (invoke_ii(2988,($29|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     label = 40;
     break;
    }
    $33 = (($3) + 8|0);
    HEAP32[$33>>2] = $30;
    $34 = $29 | 1;
    HEAP32[$3>>2] = $34;
    $35 = (($3) + 4|0);
    HEAP32[$35>>2] = $20;
    $__p$0$i$i$i = $30;
   }
   _memcpy(($__p$0$i$i$i|0),(627696|0),($20|0))|0;
   $36 = (($__p$0$i$i$i) + ($20)|0);
   HEAP8[$36>>0] = 0;
   __THREW__ = 0;
   $37 = (invoke_ii(2988,32)|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   do {
    if ($39) {
     $92 = ___cxa_find_matching_catch()|0;
     $93 = tempRet0;
     $$0 = $92;$$01 = $93;
    } else {
     $40 = (($4) + 8|0);
     HEAP32[$40>>2] = $37;
     HEAP32[$4>>2] = 33;
     $41 = (($4) + 4|0);
     HEAP32[$41>>2] = 20;
     dest=$37+0|0; src=622400+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $42 = (($37) + 20|0);
     HEAP8[$42>>0] = 0;
     __THREW__ = 0;
     $43 = (invoke_iiiiii(201,($3|0),($4|0),0,2,1)|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      $94 = ___cxa_find_matching_catch()|0;
      $95 = tempRet0;
      $96 = HEAP8[$4>>0]|0;
      $97 = $96 & 1;
      $98 = ($97<<24>>24)==(0);
      if ($98) {
       $$0 = $94;$$01 = $95;
       break;
      }
      $99 = HEAP32[$40>>2]|0;
      __ZdlPv($99);
      $$0 = $94;$$01 = $95;
      break;
     }
     $46 = HEAP8[$4>>0]|0;
     $47 = $46 & 1;
     $48 = ($47<<24>>24)==(0);
     if (!($48)) {
      $49 = HEAP32[$40>>2]|0;
      __ZdlPv($49);
     }
     $50 = HEAP8[$3>>0]|0;
     $51 = $50 & 1;
     $52 = ($51<<24>>24)==(0);
     if (!($52)) {
      $53 = (($3) + 8|0);
      $54 = HEAP32[$53>>2]|0;
      __ZdlPv($54);
     }
     __THREW__ = 0;
     $55 = (invoke_i(92)|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 40;
      break L12;
     }
     __THREW__ = 0;
     invoke_vi(3529,($55|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      label = 40;
      break L12;
     }
     __THREW__ = 0;
     invoke_vi(3530,($43|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 40;
      break L12;
     }
     $62 = (($emptyQueue) + 128|0);
     $64 = $62;
     while(1) {
      $63 = (($64) + -16|0);
      $65 = (($64) + -4|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ($66|0)>(-1);
      if ($67) {
       $68 = HEAP32[$63>>2]|0;
       $69 = (($64) + -12|0);
       $70 = HEAP32[$69>>2]|0;
       HEAP32[$1>>2] = $70;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($68|0),($$byval_copy5|0));
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        break;
       }
       HEAP32[$63>>2] = 0;
      }
      $73 = ($63|0)==($emptyQueue|0);
      if ($73) {
       label = 39;
       break;
      } else {
       $64 = $63;
      }
     }
     if ((label|0) == 39) {
      STACKTOP = sp;return;
     }
     $74 = ___cxa_find_matching_catch()|0;
     $75 = tempRet0;
     $76 = ($emptyQueue|0)==($63|0);
     if ($76) {
      ___resumeException($74|0);
      // unreachable;
     }
     $78 = $63;
     while(1) {
      $77 = (($78) + -16|0);
      $79 = (($78) + -4|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)>(-1);
      if ($81) {
       $82 = HEAP32[$77>>2]|0;
       $83 = (($78) + -12|0);
       $84 = HEAP32[$83>>2]|0;
       HEAP32[$0>>2] = $84;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($82|0),($$byval_copy5|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        label = 38;
        break;
       }
       HEAP32[$77>>2] = 0;
      }
      $87 = ($77|0)==($emptyQueue|0);
      if ($87) {
       label = 37;
       break;
      } else {
       $78 = $77;
      }
     }
     if ((label|0) == 37) {
      ___resumeException($74|0);
      // unreachable;
     }
     else if ((label|0) == 38) {
      $88 = ___cxa_find_matching_catch(0|0)|0;
      $89 = tempRet0;
      ___clang_call_terminate($88);
      // unreachable;
     }
    }
   } while(0);
   $100 = HEAP8[$3>>0]|0;
   $101 = $100 & 1;
   $102 = ($101<<24>>24)==(0);
   if ($102) {
    $$1 = $$0;$$12 = $$01;
   } else {
    $103 = (($3) + 8|0);
    $104 = HEAP32[$103>>2]|0;
    __ZdlPv($104);
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 if ((label|0) == 40) {
  $90 = ___cxa_find_matching_catch()|0;
  $91 = tempRet0;
  $$1 = $90;$$12 = $91;
 }
 $105 = (($emptyQueue) + 128|0);
 $107 = $105;
 while(1) {
  $106 = (($107) + -16|0);
  $108 = (($107) + -4|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)>(-1);
  if ($110) {
   $111 = HEAP32[$106>>2]|0;
   $112 = (($107) + -12|0);
   $113 = HEAP32[$112>>2]|0;
   HEAP32[$1>>2] = $113;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($111|0),($$byval_copy5|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if ($115) {
    break;
   }
   HEAP32[$106>>2] = 0;
  }
  $116 = ($106|0)==($emptyQueue|0);
  if ($116) {
   label = 58;
   break;
  } else {
   $107 = $106;
  }
 }
 if ((label|0) == 58) {
  ___resumeException($$1|0);
  // unreachable;
 }
 $117 = ___cxa_find_matching_catch(0|0)|0;
 $118 = tempRet0;
 $119 = ($emptyQueue|0)==($106|0);
 if ($119) {
  ___clang_call_terminate($117);
  // unreachable;
 }
 $121 = $106;
 while(1) {
  $120 = (($121) + -16|0);
  $122 = (($121) + -4|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)>(-1);
  if ($124) {
   $125 = HEAP32[$120>>2]|0;
   $126 = (($121) + -12|0);
   $127 = HEAP32[$126>>2]|0;
   HEAP32[$0>>2] = $127;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($125|0),($$byval_copy5|0));
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    label = 57;
    break;
   }
   HEAP32[$120>>2] = 0;
  }
  $130 = ($120|0)==($emptyQueue|0);
  if ($130) {
   label = 59;
   break;
  } else {
   $121 = $120;
  }
 }
 if ((label|0) == 57) {
  $131 = ___cxa_find_matching_catch(0|0)|0;
  $132 = tempRet0;
  ___clang_call_terminate($131);
  // unreachable;
 }
 else if ((label|0) == 59) {
  ___clang_call_terminate($117);
  // unreachable;
 }
}
function __Z17RuntimeInitializev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[622184>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 HEAP8[622184>>0] = 1;
 __ZN13MemoryManager16StaticInitializeEv();
 $2 = (__Z13GetFileSystemv()|0);
 __ZN10FileSystem5StartEv($2);
 __ZN35RegisterRuntimeInitializeAndCleanup22ExecuteInitializationsEv();
 STACKTOP = sp;return;
}
function __Z12PlayerRenderb($present) {
 $present = $present|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 while(1) {
  $1 = HEAP32[$0>>2]|0;
  $2 = (($1) + 516|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
  if ($4) {
   break;
  }
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 520|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 4095]($0)|0);
  if (!($8)) {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(622320,0,621808,1495,4,0,0,0);
  STACKTOP = sp;return;
 }
 $9 = (__Z16GetRenderManagerv()|0);
 __ZN13RenderManager22RenderOffscreenCamerasEv($9);
 $10 = (__Z16GetRenderManagerv()|0);
 __ZN13RenderManager13RenderCamerasEi($10,0);
 $11 = (__Z12GetGfxDevicev()|0);
 $12 = (($11) + 5784|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $15 = (__Z12GetGfxDevicev()|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 504|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vi[$18 & 4095]($15);
 }
 $19 = HEAP32[579440>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  __ZZN2UI23InitializeCanvasManagerEvEN27CanvasManagerRenderOverlays7ForwardE_1v();
 }
 $21 = (__Z12GetGfxDevicev()|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 780|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_ii[$24 & 4095]($21)|0);
 $26 = ($25|0)==(2);
 if (!($26)) {
  $27 = (__Z12GetGfxDevicev()|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 780|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 4095]($27)|0);
  $32 = ($31|0)==(4);
  if (!($32)) {
   $33 = (__Z12GetGfxDevicev()|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + 780|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (FUNCTION_TABLE_ii[$36 & 4095]($33)|0);
   $38 = ($37|0)==(8);
   if (!($38)) {
    $39 = (__Z12GetGfxDevicev()|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($40) + 780|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (FUNCTION_TABLE_ii[$42 & 4095]($39)|0);
    $44 = ($43|0)==(1);
    if (!($44)) {
     $45 = (__Z13GetGUIManagerv()|0);
     __ZN10GUIManager7RepaintEv($45);
    }
   }
  }
 }
 __Z23DrawSplashAndWatermarksv();
 __ZN7Cursors20RenderSoftwareCursorEv();
 $46 = (__Z12GetGfxDevicev()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 312|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vi[$49 & 4095]($46);
 HEAP8[622200>>0] = 1;
 if (!($present)) {
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$46>>2]|0;
 $51 = (($50) + 508|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vi[$52 & 4095]($46);
 $53 = (__Z12GetGfxDevicev()|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 512|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vi[$56 & 4095]($53);
 HEAP8[622200>>0] = 0;
 STACKTOP = sp;return;
}
function __Z10PlayerLoopbbP10IHookEvent($batchMode,$performRendering,$pHookEvt) {
 $batchMode = $batchMode|0;
 $performRendering = $performRendering|0;
 $pHookEvt = $pHookEvt|0;
 var $$index = 0, $$index7 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0.0, $143 = 0, $144 = 0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0, $212 = 0.0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0.0, $224 = 0, $225 = 0, $226 = 0.0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0.0, $244 = 0, $245 = 0, $246 = 0.0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0.0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0.0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0.0, $278 = 0, $279 = 0, $28 = 0, $280 = 0.0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0.0, $291 = 0, $292 = 0, $293 = 0.0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0.0, $315 = 0, $316 = 0, $317 = 0.0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0.0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0.0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0.0, $41 = 0, $410 = 0, $411 = 0, $412 = 0.0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0.0, $424 = 0, $425 = 0, $426 = 0.0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0.0, $444 = 0, $445 = 0, $446 = 0.0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0.0, $458 = 0, $459 = 0, $46 = 0, $460 = 0.0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0.0, $481 = 0, $482 = 0, $483 = 0.0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0.0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0.0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0.0, $522 = 0, $523 = 0, $524 = 0.0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0.0, $536 = 0, $537 = 0, $538 = 0.0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0.0, $556 = 0, $557 = 0, $558 = 0.0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0.0, $57 = 0, $570 = 0, $571 = 0, $572 = 0.0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0.0, $625 = 0, $626 = 0, $627 = 0.0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0, $638 = 0.0, $639 = 0, $64 = 0, $640 = 0, $641 = 0.0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0;
 var $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0.0, $683 = 0, $684 = 0, $685 = 0.0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = Math_fround(0), $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0.0, $736 = 0, $737 = 0, $738 = 0.0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0;
 var $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0;
 var $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0;
 var $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $inside$0$off0$i = 0, $inside$1$off0$i = 0, $invocation = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond3 = 0, $or$cond5 = 0, $stepCounter$0 = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$byval_copy = sp + 208|0;
 $invocation = sp;
 $0 = sp + 200|0;
 $1 = (__Z19GetIClusterRendererv()|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 3;
 } else {
  $3 = (__Z19GetIClusterRendererv()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
  if ($7) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $8 = (__Z14GetTimeManagerv()|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 100|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($8);
 }
 $12 = (0|0)==(0|0);
 if (!($12)) {
  abort /* segfault, call an absolute addr */ ();
 }
 $13 = (0|0)==(0|0);
 if (!($13)) {
  abort /* segfault, call an absolute addr */ ();
 }
 $14 = HEAP8[622192>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  __THREW__ = 0;
  invoke_viiiiiiii(21,(622216|0),0,(621808|0),1619,1,0,0,(0|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   STACKTOP = sp;return;
  }
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $$index = $18;$$index7 = $19;
  ___resumeException($$index|0);
  // unreachable;
 }
 HEAP8[622192>>0] = 1;
 __THREW__ = 0;
 $24 = (invoke_i(59)|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 L19: do {
  if ($26) {
   label = 12;
  } else {
   $27 = HEAP32[$24>>2]|0;
   $28 = (($27) + 516|0);
   $29 = HEAP32[$28>>2]|0;
   __THREW__ = 0;
   $30 = (invoke_ii($29|0,($24|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 12;
   } else {
    if ($30) {
     label = 20;
    } else {
     $33 = HEAP32[$24>>2]|0;
     $34 = (($33) + 520|0);
     $35 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     $36 = (invoke_ii($35|0,($24|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 12;
      break;
     }
     if ($36) {
      label = 20;
     } else {
      __THREW__ = 0;
      invoke_viiiiiiii(21,(622248|0),0,(621808|0),1628,4,0,0,(0|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 12;
       break;
      }
     }
    }
    do {
     if ((label|0) == 20) {
      if (!($batchMode)) {
       __THREW__ = 0;
       $41 = (invoke_i(55)|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        label = 12;
        break L19;
       }
       $44 = (($41) + 100|0);
       $45 = Math_fround(HEAPF32[$44>>2]);
       $46 = (($41) + 104|0);
       $47 = Math_fround(HEAPF32[$46>>2]);
       $48 = $45 < Math_fround(0.0);
       if ($48) {
        label = 26;
       } else {
        __THREW__ = 0;
        $49 = (invoke_i(93)|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 12;
         break L19;
        }
        $52 = HEAP32[$49>>2]|0;
        $53 = (($52) + 80|0);
        $54 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        $55 = (invoke_ii($54|0,($49|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 12;
         break L19;
        }
        $58 = (Math_fround(($55|0)));
        $59 = $45 > $58;
        if ($59) {
         label = 26;
        } else {
         $inside$0$off0$i = 1;
        }
       }
       if ((label|0) == 26) {
        $inside$0$off0$i = 0;
       }
       $60 = $47 < Math_fround(0.0);
       if ($60) {
        label = 31;
       } else {
        __THREW__ = 0;
        $61 = (invoke_i(93)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 12;
         break L19;
        }
        $64 = HEAP32[$61>>2]|0;
        $65 = (($64) + 84|0);
        $66 = HEAP32[$65>>2]|0;
        __THREW__ = 0;
        $67 = (invoke_ii($66|0,($61|0))|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         label = 12;
         break L19;
        }
        $70 = (Math_fround(($67|0)));
        $71 = $47 > $70;
        if ($71) {
         label = 31;
        } else {
         $inside$1$off0$i = $inside$0$off0$i;
        }
       }
       if ((label|0) == 31) {
        $inside$1$off0$i = 0;
       }
       __THREW__ = 0;
       $72 = (invoke_i(93)|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 12;
        break L19;
       }
       $75 = HEAP32[$72>>2]|0;
       $76 = (($75) + 76|0);
       $77 = HEAP32[$76>>2]|0;
       __THREW__ = 0;
       invoke_vii($77|0,($72|0),($inside$1$off0$i|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 12;
        break L19;
       }
      }
      $80 = HEAP32[$24>>2]|0;
      $81 = (($80) + 500|0);
      $82 = HEAP32[$81>>2]|0;
      __THREW__ = 0;
      $83 = (invoke_ii($82|0,($24|0))|0);
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if ($85) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $86 = (invoke_i(88)|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 12;
       break L19;
      }
      if (!($batchMode)) {
       $89 = ($83|0)!=(0);
       $90 = HEAP8[622200>>0]|0;
       $91 = ($90<<24>>24)==(0);
       $or$cond$i = $89 | $91;
       if (!($or$cond$i)) {
        $92 = (0|0)==(0|0);
        if (!($92)) {
         __THREW__ = 0;
         invoke_vi(0|0,1);
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          label = 12;
          break L19;
         }
        }
        __THREW__ = 0;
        $95 = (invoke_i(59)|0);
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         label = 12;
         break L19;
        }
        $98 = HEAP32[$95>>2]|0;
        $99 = (($98) + 512|0);
        $100 = HEAP32[$99>>2]|0;
        __THREW__ = 0;
        invoke_vi($100|0,($95|0));
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         label = 12;
         break L19;
        }
        HEAP8[622200>>0] = 0;
        $103 = (0|0)==(0|0);
        if (!($103)) {
         __THREW__ = 0;
         invoke_vi(0|0,0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 12;
          break L19;
         }
        }
        dest=621696+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       }
      }
      $106 = ($83|0)==(0);
      if ($106) {
       $107 = HEAP32[$24>>2]|0;
       $108 = (($107) + 620|0);
       $109 = HEAP32[$108>>2]|0;
       __THREW__ = 0;
       invoke_vi($109|0,($24|0));
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if ($111) {
        label = 12;
        break L19;
       }
      }
      __THREW__ = 0;
      invoke_v(151);
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $114 = (invoke_i(92)|0);
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      invoke_vi(3531,($114|0));
      $117 = __THREW__; __THREW__ = 0;
      $118 = $117&1;
      if ($118) {
       label = 12;
       break L19;
      }
      if ($performRendering) {
       __THREW__ = 0;
       $119 = (invoke_i(94)|0);
       $120 = __THREW__; __THREW__ = 0;
       $121 = $120&1;
       if ($121) {
        label = 12;
        break L19;
       }
       __THREW__ = 0;
       invoke_vi(3532,($119|0));
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if ($123) {
        label = 12;
        break L19;
       }
      }
      __THREW__ = 0;
      $124 = (invoke_i(61)|0);
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if ($126) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      invoke_vii(2784,($124|0),15);
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       label = 12;
       break L19;
      }
      $129 = HEAP32[579464>>2]|0;
      $130 = ($129|0)==(0|0);
      if (!($130)) {
       __THREW__ = 0;
       invoke_v(152);
       $131 = __THREW__; __THREW__ = 0;
       $132 = $131&1;
       if ($132) {
        label = 12;
        break L19;
       }
      }
      $133 = HEAP32[579448>>2]|0;
      $134 = ($133|0)==(0|0);
      if (!($134)) {
       __THREW__ = 0;
       invoke_v(153);
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if ($136) {
        label = 12;
        break L19;
       }
      }
      if ($86) {
       __THREW__ = 0;
       $137 = (invoke_i(55)|0);
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if ($139) {
        label = 12;
        break L19;
       }
       __THREW__ = 0;
       invoke_vi(3533,($137|0));
       $140 = __THREW__; __THREW__ = 0;
       $141 = $140&1;
       if ($141) {
        label = 12;
        break L19;
       }
      }
      __THREW__ = 0;
      $142 = (+invoke_d(2));
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       label = 12;
       break L19;
      }
      $145 = $142 * 1.0E+6;
      $146 = (~~$145)>>>0;
      $147 = +Math_abs($145) >= 1.0 ? $145 > 0.0 ? (Math_min(+Math_floor($145 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($145 - +(~~$145 >>> 0)) / 4294967296.0) >>> 0 : 0;
      __THREW__ = 0;
      $148 = (invoke_i(95)|0);
      $149 = __THREW__; __THREW__ = 0;
      $150 = $149&1;
      if ($150) {
       label = 12;
       break L19;
      }
      $151 = HEAP32[$148>>2]|0;
      $152 = (($151) + 100|0);
      $153 = HEAP32[$152>>2]|0;
      __THREW__ = 0;
      invoke_vii($153|0,($148|0),4);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $156 = (+invoke_d(2));
      $157 = __THREW__; __THREW__ = 0;
      $158 = $157&1;
      if ($158) {
       label = 12;
       break L19;
      }
      $159 = $156 * 1.0E+6;
      $160 = (~~$159)>>>0;
      $161 = +Math_abs($159) >= 1.0 ? $159 > 0.0 ? (Math_min(+Math_floor($159 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($159 - +(~~$159 >>> 0)) / 4294967296.0) >>> 0 : 0;
      $162 = (_i64Subtract(($160|0),($161|0),($146|0),($147|0))|0);
      $163 = tempRet0;
      $164 = ((621696 + 24|0));
      $165 = $164;
      $166 = HEAP32[$165>>2]|0;
      $167 = (($164) + 4)|0;
      $168 = $167;
      $169 = HEAP32[$168>>2]|0;
      $170 = (_i64Add(($162|0),($163|0),($166|0),($169|0))|0);
      $171 = tempRet0;
      $172 = ((621696 + 24|0));
      $173 = $172;
      HEAP32[$173>>2] = $170;
      $174 = (($172) + 4)|0;
      $175 = $174;
      HEAP32[$175>>2] = $171;
      __THREW__ = 0;
      $176 = (invoke_i(87)|0);
      $177 = __THREW__; __THREW__ = 0;
      $178 = $177&1;
      if ($178) {
       label = 12;
       break L19;
      }
      $179 = (($176) + 188|0);
      $180 = Math_fround(HEAPF32[$179>>2]);
      $181 = $180 < Math_fround(0.0);
      if ($181) {
       $182 = Math_fround(-$180);
       $184 = $182;
      } else {
       $184 = $180;
      }
      $183 = $184 <= Math_fround(9.99999997475242707878E-7);
      $185 = HEAP32[579392>>2]|0;
      $186 = ($185|0)!=(0|0);
      $or$cond = $183 & $186;
      if ($or$cond) {
       __THREW__ = 0;
       invoke_v(154);
       $187 = __THREW__; __THREW__ = 0;
       $188 = $187&1;
       if ($188) {
        label = 12;
        break L19;
       } else {
        $stepCounter$0 = 0;
       }
      } else {
       $stepCounter$0 = 0;
      }
      while(1) {
       __THREW__ = 0;
       $189 = (invoke_i(87)|0);
       $190 = __THREW__; __THREW__ = 0;
       $191 = $190&1;
       if ($191) {
        label = 11;
        break;
       }
       __THREW__ = 0;
       $192 = (invoke_ii(3273,($189|0))|0);
       $193 = __THREW__; __THREW__ = 0;
       $194 = $193&1;
       if ($194) {
        label = 11;
        break;
       }
       if (!($192)) {
        break;
       }
       if ($86) {
        $195 = ($stepCounter$0|0)==(0);
        $196 = HEAP32[579408>>2]|0;
        $197 = ($196|0)!=(0|0);
        $or$cond3 = $195 & $197;
        if ($or$cond3) {
         __THREW__ = 0;
         invoke_v(155);
         $198 = __THREW__; __THREW__ = 0;
         $199 = $198&1;
         if ($199) {
          label = 11;
          break;
         }
        }
        __THREW__ = 0;
        $200 = (invoke_i(96)|0);
        $201 = __THREW__; __THREW__ = 0;
        $202 = $201&1;
        if ($202) {
         label = 11;
         break;
        }
        $203 = ($200|0)==(0|0);
        if (!($203)) {
         $204 = HEAP32[$200>>2]|0;
         $205 = (($204) + 4|0);
         $206 = HEAP32[$205>>2]|0;
         __THREW__ = 0;
         invoke_vi($206|0,($200|0));
         $207 = __THREW__; __THREW__ = 0;
         $208 = $207&1;
         if ($208) {
          label = 11;
          break;
         }
        }
        __THREW__ = 0;
        $209 = (+invoke_d(2));
        $210 = __THREW__; __THREW__ = 0;
        $211 = $210&1;
        if ($211) {
         label = 11;
         break;
        }
        $212 = $209 * 1.0E+6;
        $213 = (~~$212)>>>0;
        $214 = +Math_abs($212) >= 1.0 ? $212 > 0.0 ? (Math_min(+Math_floor($212 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($212 - +(~~$212 >>> 0)) / 4294967296.0) >>> 0 : 0;
        __THREW__ = 0;
        $215 = (invoke_i(97)|0);
        $216 = __THREW__; __THREW__ = 0;
        $217 = $216&1;
        if ($217) {
         label = 11;
         break;
        }
        $218 = HEAP32[$215>>2]|0;
        $219 = (($218) + 8|0);
        $220 = HEAP32[$219>>2]|0;
        __THREW__ = 0;
        invoke_vi($220|0,($215|0));
        $221 = __THREW__; __THREW__ = 0;
        $222 = $221&1;
        if ($222) {
         label = 11;
         break;
        }
        __THREW__ = 0;
        $223 = (+invoke_d(2));
        $224 = __THREW__; __THREW__ = 0;
        $225 = $224&1;
        if ($225) {
         label = 11;
         break;
        }
        $226 = $223 * 1.0E+6;
        $227 = (~~$226)>>>0;
        $228 = +Math_abs($226) >= 1.0 ? $226 > 0.0 ? (Math_min(+Math_floor($226 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($226 - +(~~$226 >>> 0)) / 4294967296.0) >>> 0 : 0;
        $229 = (_i64Subtract(($227|0),($228|0),($213|0),($214|0))|0);
        $230 = tempRet0;
        $231 = 621696;
        $232 = $231;
        $233 = HEAP32[$232>>2]|0;
        $234 = (($231) + 4)|0;
        $235 = $234;
        $236 = HEAP32[$235>>2]|0;
        $237 = (_i64Add(($229|0),($230|0),($233|0),($236|0))|0);
        $238 = tempRet0;
        $239 = 621696;
        $240 = $239;
        HEAP32[$240>>2] = $237;
        $241 = (($239) + 4)|0;
        $242 = $241;
        HEAP32[$242>>2] = $238;
        __THREW__ = 0;
        $243 = (+invoke_d(2));
        $244 = __THREW__; __THREW__ = 0;
        $245 = $244&1;
        if ($245) {
         label = 11;
         break;
        }
        $246 = $243 * 1.0E+6;
        $247 = (~~$246)>>>0;
        $248 = +Math_abs($246) >= 1.0 ? $246 > 0.0 ? (Math_min(+Math_floor($246 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($246 - +(~~$246 >>> 0)) / 4294967296.0) >>> 0 : 0;
        $249 = HEAP32[579368>>2]|0;
        $250 = ($249|0)==(0|0);
        if (!($250)) {
         __THREW__ = 0;
         invoke_v(156);
         $251 = __THREW__; __THREW__ = 0;
         $252 = $251&1;
         if ($252) {
          label = 11;
          break;
         }
        }
        $253 = HEAP32[579416>>2]|0;
        $254 = ($253|0)==(0|0);
        if (!($254)) {
         __THREW__ = 0;
         invoke_v(157);
         $255 = __THREW__; __THREW__ = 0;
         $256 = $255&1;
         if ($256) {
          label = 11;
          break;
         }
        }
        __THREW__ = 0;
        $257 = (+invoke_d(2));
        $258 = __THREW__; __THREW__ = 0;
        $259 = $258&1;
        if ($259) {
         label = 11;
         break;
        }
        $260 = $257 * 1.0E+6;
        $261 = (~~$260)>>>0;
        $262 = +Math_abs($260) >= 1.0 ? $260 > 0.0 ? (Math_min(+Math_floor($260 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($260 - +(~~$260 >>> 0)) / 4294967296.0) >>> 0 : 0;
        $263 = (_i64Subtract(($261|0),($262|0),($247|0),($248|0))|0);
        $264 = tempRet0;
        $265 = ((621696 + 40|0));
        $266 = $265;
        $267 = HEAP32[$266>>2]|0;
        $268 = (($265) + 4)|0;
        $269 = $268;
        $270 = HEAP32[$269>>2]|0;
        $271 = (_i64Add(($263|0),($264|0),($267|0),($270|0))|0);
        $272 = tempRet0;
        $273 = ((621696 + 40|0));
        $274 = $273;
        HEAP32[$274>>2] = $271;
        $275 = (($273) + 4)|0;
        $276 = $275;
        HEAP32[$276>>2] = $272;
        __THREW__ = 0;
        $277 = (+invoke_d(2));
        $278 = __THREW__; __THREW__ = 0;
        $279 = $278&1;
        if ($279) {
         label = 11;
         break;
        }
        $280 = $277 * 1.0E+6;
        $281 = (~~$280)>>>0;
        $282 = +Math_abs($280) >= 1.0 ? $280 > 0.0 ? (Math_min(+Math_floor($280 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($280 - +(~~$280 >>> 0)) / 4294967296.0) >>> 0 : 0;
        $283 = HEAP32[579376>>2]|0;
        $284 = ($283|0)==(0|0);
        if (!($284)) {
         __THREW__ = 0;
         invoke_v(158);
         $285 = __THREW__; __THREW__ = 0;
         $286 = $285&1;
         if ($286) {
          label = 11;
          break;
         }
        }
        $287 = (0|0)==(0|0);
        if (!($287)) {
         __THREW__ = 0;
         invoke_v(0|0);
         $288 = __THREW__; __THREW__ = 0;
         $289 = $288&1;
         if ($289) {
          label = 11;
          break;
         }
        }
        __THREW__ = 0;
        $290 = (+invoke_d(2));
        $291 = __THREW__; __THREW__ = 0;
        $292 = $291&1;
        if ($292) {
         label = 11;
         break;
        }
        $293 = $290 * 1.0E+6;
        $294 = (~~$293)>>>0;
        $295 = +Math_abs($293) >= 1.0 ? $293 > 0.0 ? (Math_min(+Math_floor($293 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($293 - +(~~$293 >>> 0)) / 4294967296.0) >>> 0 : 0;
        $296 = (_i64Subtract(($294|0),($295|0),($281|0),($282|0))|0);
        $297 = tempRet0;
        $298 = ((621696 + 8|0));
        $299 = $298;
        $300 = HEAP32[$299>>2]|0;
        $301 = (($298) + 4)|0;
        $302 = $301;
        $303 = HEAP32[$302>>2]|0;
        $304 = (_i64Add(($296|0),($297|0),($300|0),($303|0))|0);
        $305 = tempRet0;
        $306 = ((621696 + 8|0));
        $307 = $306;
        HEAP32[$307>>2] = $304;
        $308 = (($306) + 4)|0;
        $309 = $308;
        HEAP32[$309>>2] = $305;
        $310 = HEAP32[579344>>2]|0;
        $311 = ($310|0)==(0|0);
        if (!($311)) {
         __THREW__ = 0;
         invoke_v(159);
         $312 = __THREW__; __THREW__ = 0;
         $313 = $312&1;
         if ($313) {
          label = 11;
          break;
         }
        }
        __THREW__ = 0;
        $314 = (+invoke_d(2));
        $315 = __THREW__; __THREW__ = 0;
        $316 = $315&1;
        if ($316) {
         label = 11;
         break;
        }
        $317 = $314 * 1.0E+6;
        $318 = (~~$317)>>>0;
        $319 = +Math_abs($317) >= 1.0 ? $317 > 0.0 ? (Math_min(+Math_floor($317 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($317 - +(~~$317 >>> 0)) / 4294967296.0) >>> 0 : 0;
        __THREW__ = 0;
        $320 = (invoke_i(95)|0);
        $321 = __THREW__; __THREW__ = 0;
        $322 = $321&1;
        if ($322) {
         label = 11;
         break;
        }
        $323 = HEAP32[$320>>2]|0;
        $324 = (($323) + 100|0);
        $325 = HEAP32[$324>>2]|0;
        __THREW__ = 0;
        invoke_vii($325|0,($320|0),1);
        $326 = __THREW__; __THREW__ = 0;
        $327 = $326&1;
        if ($327) {
         label = 11;
         break;
        }
        __THREW__ = 0;
        $328 = (+invoke_d(2));
        $329 = __THREW__; __THREW__ = 0;
        $330 = $329&1;
        if ($330) {
         label = 11;
         break;
        }
        $331 = $328 * 1.0E+6;
        $332 = (~~$331)>>>0;
        $333 = +Math_abs($331) >= 1.0 ? $331 > 0.0 ? (Math_min(+Math_floor($331 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($331 - +(~~$331 >>> 0)) / 4294967296.0) >>> 0 : 0;
        $334 = (_i64Subtract(($332|0),($333|0),($318|0),($319|0))|0);
        $335 = tempRet0;
        $336 = ((621696 + 24|0));
        $337 = $336;
        $338 = HEAP32[$337>>2]|0;
        $339 = (($336) + 4)|0;
        $340 = $339;
        $341 = HEAP32[$340>>2]|0;
        $342 = (_i64Add(($334|0),($335|0),($338|0),($341|0))|0);
        $343 = tempRet0;
        $344 = ((621696 + 24|0));
        $345 = $344;
        HEAP32[$345>>2] = $342;
        $346 = (($344) + 4)|0;
        $347 = $346;
        HEAP32[$347>>2] = $343;
       }
       $348 = (($stepCounter$0) + 1)|0;
       $stepCounter$0 = $348;
      }
      if ((label|0) == 11) {
       $20 = ___cxa_find_matching_catch()|0;
       $21 = tempRet0;
       $lpad$phi$index = $20;$lpad$phi$index2 = $21;
       break L19;
      }
      HEAP32[((621696 + 56|0))>>2] = $stepCounter$0;
      do {
       if ($86) {
        $349 = HEAP32[579384>>2]|0;
        $350 = ($349|0)==(0|0);
        if (!($350)) {
         __THREW__ = 0;
         invoke_v(160);
         $351 = __THREW__; __THREW__ = 0;
         $352 = $351&1;
         if ($352) {
          label = 12;
          break L19;
         }
        }
        $353 = (0|0)==(0|0);
        if ($353) {
         break;
        }
        __THREW__ = 0;
        invoke_v(0|0);
        $354 = __THREW__; __THREW__ = 0;
        $355 = $354&1;
        if ($355) {
         label = 12;
         break L19;
        }
       }
      } while(0);
      __THREW__ = 0;
      $356 = (invoke_i(55)|0);
      $357 = __THREW__; __THREW__ = 0;
      $358 = $357&1;
      if ($358) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $359 = (invoke_ii(3274,($356|0))|0);
      $360 = __THREW__; __THREW__ = 0;
      $361 = $360&1;
      if ($361) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $362 = (invoke_i(75)|0);
      $363 = __THREW__; __THREW__ = 0;
      $364 = $363&1;
      if ($364) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      invoke_vi(3534,($362|0));
      $365 = __THREW__; __THREW__ = 0;
      $366 = $365&1;
      if ($366) {
       label = 12;
       break L19;
      }
      do {
       if ($86) {
        __THREW__ = 0;
        $367 = (invoke_i(69)|0);
        $368 = __THREW__; __THREW__ = 0;
        $369 = $368&1;
        if ($369) {
         label = 12;
         break L19;
        }
        $370 = (($367) + 105|0);
        $371 = HEAP8[$370>>0]|0;
        $372 = ($371<<24>>24)==(0);
        if ($372) {
         break;
        }
        __THREW__ = 0;
        $373 = (invoke_i(75)|0);
        $374 = __THREW__; __THREW__ = 0;
        $375 = $374&1;
        if ($375) {
         label = 12;
         break L19;
        }
        $376 = (($373) + 8|0);
        $377 = HEAP8[$376>>0]|0;
        $378 = $377&255;
        __THREW__ = 0;
        $379 = (invoke_i(84)|0);
        $380 = __THREW__; __THREW__ = 0;
        $381 = $380&1;
        if ($381) {
         label = 12;
         break L19;
        }
        $382 = (($379) + 512|0);
        $383 = $382;
        $384 = $383;
        $385 = HEAP32[$384>>2]|0;
        $386 = (($383) + 4)|0;
        $387 = $386;
        $388 = HEAP32[$387>>2]|0;
        $389 = $0;
        $390 = $389;
        HEAP32[$390>>2] = $385;
        $391 = (($389) + 4)|0;
        $392 = $391;
        HEAP32[$392>>2] = $388;
        __THREW__ = 0;
        ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
        invoke_vii(2785,($invocation|0),($tmpcast$byval_copy|0));
        $393 = __THREW__; __THREW__ = 0;
        $394 = $393&1;
        if ($394) {
         label = 12;
         break L19;
        }
        $395 = (($invocation) + 32|0);
        __THREW__ = 0;
        invoke_vii(2786,($395|0),($378|0));
        $396 = __THREW__; __THREW__ = 0;
        $397 = $396&1;
        if ($397) {
         label = 12;
         break L19;
        }
        __THREW__ = 0;
        invoke_vii(2786,($395|0),1);
        $398 = __THREW__; __THREW__ = 0;
        $399 = $398&1;
        if ($399) {
         label = 12;
         break L19;
        }
        __THREW__ = 0;
        (invoke_ii(3275,($invocation|0))|0);
        $400 = __THREW__; __THREW__ = 0;
        $401 = $400&1;
        if ($401) {
         label = 12;
         break L19;
        }
       }
      } while(0);
      $402 = (0|0)==(0|0);
      if (!($402)) {
       __THREW__ = 0;
       invoke_v(0|0);
       $403 = __THREW__; __THREW__ = 0;
       $404 = $403&1;
       if ($404) {
        label = 12;
        break L19;
       }
      }
      $405 = HEAP32[579472>>2]|0;
      $406 = ($405|0)==(0|0);
      if (!($406)) {
       __THREW__ = 0;
       invoke_v(108);
       $407 = __THREW__; __THREW__ = 0;
       $408 = $407&1;
       if ($408) {
        label = 12;
        break L19;
       }
      }
      __THREW__ = 0;
      $409 = (+invoke_d(2));
      $410 = __THREW__; __THREW__ = 0;
      $411 = $410&1;
      if ($411) {
       label = 12;
       break L19;
      }
      $412 = $409 * 1.0E+6;
      $413 = (~~$412)>>>0;
      $414 = +Math_abs($412) >= 1.0 ? $412 > 0.0 ? (Math_min(+Math_floor($412 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($412 - +(~~$412 >>> 0)) / 4294967296.0) >>> 0 : 0;
      __THREW__ = 0;
      $415 = (invoke_i(98)|0);
      $416 = __THREW__; __THREW__ = 0;
      $417 = $416&1;
      if ($417) {
       label = 12;
       break L19;
      }
      $418 = HEAP32[$415>>2]|0;
      $419 = (($418) + 8|0);
      $420 = HEAP32[$419>>2]|0;
      __THREW__ = 0;
      invoke_vi($420|0,($415|0));
      $421 = __THREW__; __THREW__ = 0;
      $422 = $421&1;
      if ($422) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $423 = (+invoke_d(2));
      $424 = __THREW__; __THREW__ = 0;
      $425 = $424&1;
      if ($425) {
       label = 12;
       break L19;
      }
      $426 = $423 * 1.0E+6;
      $427 = (~~$426)>>>0;
      $428 = +Math_abs($426) >= 1.0 ? $426 > 0.0 ? (Math_min(+Math_floor($426 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($426 - +(~~$426 >>> 0)) / 4294967296.0) >>> 0 : 0;
      $429 = (_i64Subtract(($427|0),($428|0),($413|0),($414|0))|0);
      $430 = tempRet0;
      $431 = ((621696 + 16|0));
      $432 = $431;
      $433 = HEAP32[$432>>2]|0;
      $434 = (($431) + 4)|0;
      $435 = $434;
      $436 = HEAP32[$435>>2]|0;
      $437 = (_i64Add(($429|0),($430|0),($433|0),($436|0))|0);
      $438 = tempRet0;
      $439 = ((621696 + 16|0));
      $440 = $439;
      HEAP32[$440>>2] = $437;
      $441 = (($439) + 4)|0;
      $442 = $441;
      HEAP32[$442>>2] = $438;
      __THREW__ = 0;
      $443 = (+invoke_d(2));
      $444 = __THREW__; __THREW__ = 0;
      $445 = $444&1;
      if ($445) {
       label = 12;
       break L19;
      }
      $446 = $443 * 1.0E+6;
      $447 = (~~$446)>>>0;
      $448 = +Math_abs($446) >= 1.0 ? $446 > 0.0 ? (Math_min(+Math_floor($446 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($446 - +(~~$446 >>> 0)) / 4294967296.0) >>> 0 : 0;
      __THREW__ = 0;
      $449 = (invoke_i(95)|0);
      $450 = __THREW__; __THREW__ = 0;
      $451 = $450&1;
      if ($451) {
       label = 12;
       break L19;
      }
      $452 = HEAP32[$449>>2]|0;
      $453 = (($452) + 100|0);
      $454 = HEAP32[$453>>2]|0;
      __THREW__ = 0;
      invoke_vii($454|0,($449|0),2);
      $455 = __THREW__; __THREW__ = 0;
      $456 = $455&1;
      if ($456) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $457 = (+invoke_d(2));
      $458 = __THREW__; __THREW__ = 0;
      $459 = $458&1;
      if ($459) {
       label = 12;
       break L19;
      }
      $460 = $457 * 1.0E+6;
      $461 = (~~$460)>>>0;
      $462 = +Math_abs($460) >= 1.0 ? $460 > 0.0 ? (Math_min(+Math_floor($460 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($460 - +(~~$460 >>> 0)) / 4294967296.0) >>> 0 : 0;
      $463 = (_i64Subtract(($461|0),($462|0),($447|0),($448|0))|0);
      $464 = tempRet0;
      $465 = ((621696 + 24|0));
      $466 = $465;
      $467 = HEAP32[$466>>2]|0;
      $468 = (($465) + 4)|0;
      $469 = $468;
      $470 = HEAP32[$469>>2]|0;
      $471 = (_i64Add(($463|0),($464|0),($467|0),($470|0))|0);
      $472 = tempRet0;
      $473 = ((621696 + 24|0));
      $474 = $473;
      HEAP32[$474>>2] = $471;
      $475 = (($473) + 4)|0;
      $476 = $475;
      HEAP32[$476>>2] = $472;
      $477 = (0|0)==(0|0);
      if (!($477)) {
       __THREW__ = 0;
       invoke_v(0|0);
       $478 = __THREW__; __THREW__ = 0;
       $479 = $478&1;
       if ($479) {
        label = 12;
        break L19;
       }
      }
      if ($86) {
       __THREW__ = 0;
       $480 = (+invoke_d(2));
       $481 = __THREW__; __THREW__ = 0;
       $482 = $481&1;
       if ($482) {
        label = 12;
        break L19;
       }
       $483 = $480 * 1.0E+6;
       $484 = (~~$483)>>>0;
       $485 = +Math_abs($483) >= 1.0 ? $483 > 0.0 ? (Math_min(+Math_floor($483 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($483 - +(~~$483 >>> 0)) / 4294967296.0) >>> 0 : 0;
       $486 = HEAP32[579360>>2]|0;
       $487 = ($486|0)==(0|0);
       if (!($487)) {
        __THREW__ = 0;
        invoke_v(161);
        $488 = __THREW__; __THREW__ = 0;
        $489 = $488&1;
        if ($489) {
         label = 12;
         break L19;
        }
       }
       $490 = HEAP32[579416>>2]|0;
       $491 = ($490|0)==(0|0);
       if (!($491)) {
        __THREW__ = 0;
        invoke_v(157);
        $492 = __THREW__; __THREW__ = 0;
        $493 = $492&1;
        if ($493) {
         label = 12;
         break L19;
        }
       }
       $494 = HEAP32[579352>>2]|0;
       $495 = ($494|0)==(0|0);
       if (!($495)) {
        __THREW__ = 0;
        invoke_v(162);
        $496 = __THREW__; __THREW__ = 0;
        $497 = $496&1;
        if ($497) {
         label = 12;
         break L19;
        }
       }
       __THREW__ = 0;
       $498 = (+invoke_d(2));
       $499 = __THREW__; __THREW__ = 0;
       $500 = $499&1;
       if ($500) {
        label = 12;
        break L19;
       }
       $501 = $498 * 1.0E+6;
       $502 = (~~$501)>>>0;
       $503 = +Math_abs($501) >= 1.0 ? $501 > 0.0 ? (Math_min(+Math_floor($501 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($501 - +(~~$501 >>> 0)) / 4294967296.0) >>> 0 : 0;
       $504 = (_i64Subtract(($502|0),($503|0),($484|0),($485|0))|0);
       $505 = tempRet0;
       $506 = ((621696 + 40|0));
       $507 = $506;
       $508 = HEAP32[$507>>2]|0;
       $509 = (($506) + 4)|0;
       $510 = $509;
       $511 = HEAP32[$510>>2]|0;
       $512 = (_i64Add(($504|0),($505|0),($508|0),($511|0))|0);
       $513 = tempRet0;
       $514 = ((621696 + 40|0));
       $515 = $514;
       HEAP32[$515>>2] = $512;
       $516 = (($514) + 4)|0;
       $517 = $516;
       HEAP32[$517>>2] = $513;
      }
      $518 = (0|0)==(0|0);
      if (!($518)) {
       __THREW__ = 0;
       invoke_v(0|0);
       $519 = __THREW__; __THREW__ = 0;
       $520 = $519&1;
       if ($520) {
        label = 12;
        break L19;
       }
      }
      __THREW__ = 0;
      $521 = (+invoke_d(2));
      $522 = __THREW__; __THREW__ = 0;
      $523 = $522&1;
      if ($523) {
       label = 12;
       break L19;
      }
      $524 = $521 * 1.0E+6;
      $525 = (~~$524)>>>0;
      $526 = +Math_abs($524) >= 1.0 ? $524 > 0.0 ? (Math_min(+Math_floor($524 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($524 - +(~~$524 >>> 0)) / 4294967296.0) >>> 0 : 0;
      __THREW__ = 0;
      $527 = (invoke_i(99)|0);
      $528 = __THREW__; __THREW__ = 0;
      $529 = $528&1;
      if ($529) {
       label = 12;
       break L19;
      }
      $530 = HEAP32[$527>>2]|0;
      $531 = (($530) + 8|0);
      $532 = HEAP32[$531>>2]|0;
      __THREW__ = 0;
      invoke_vi($532|0,($527|0));
      $533 = __THREW__; __THREW__ = 0;
      $534 = $533&1;
      if ($534) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $535 = (+invoke_d(2));
      $536 = __THREW__; __THREW__ = 0;
      $537 = $536&1;
      if ($537) {
       label = 12;
       break L19;
      }
      $538 = $535 * 1.0E+6;
      $539 = (~~$538)>>>0;
      $540 = +Math_abs($538) >= 1.0 ? $538 > 0.0 ? (Math_min(+Math_floor($538 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($538 - +(~~$538 >>> 0)) / 4294967296.0) >>> 0 : 0;
      $541 = (_i64Subtract(($539|0),($540|0),($525|0),($526|0))|0);
      $542 = tempRet0;
      $543 = ((621696 + 16|0));
      $544 = $543;
      $545 = HEAP32[$544>>2]|0;
      $546 = (($543) + 4)|0;
      $547 = $546;
      $548 = HEAP32[$547>>2]|0;
      $549 = (_i64Add(($541|0),($542|0),($545|0),($548|0))|0);
      $550 = tempRet0;
      $551 = ((621696 + 16|0));
      $552 = $551;
      HEAP32[$552>>2] = $549;
      $553 = (($551) + 4)|0;
      $554 = $553;
      HEAP32[$554>>2] = $550;
      __THREW__ = 0;
      $555 = (+invoke_d(2));
      $556 = __THREW__; __THREW__ = 0;
      $557 = $556&1;
      if ($557) {
       label = 12;
       break L19;
      }
      $558 = $555 * 1.0E+6;
      $559 = (~~$558)>>>0;
      $560 = +Math_abs($558) >= 1.0 ? $558 > 0.0 ? (Math_min(+Math_floor($558 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($558 - +(~~$558 >>> 0)) / 4294967296.0) >>> 0 : 0;
      __THREW__ = 0;
      $561 = (invoke_i(95)|0);
      $562 = __THREW__; __THREW__ = 0;
      $563 = $562&1;
      if ($563) {
       label = 12;
       break L19;
      }
      $564 = HEAP32[$561>>2]|0;
      $565 = (($564) + 100|0);
      $566 = HEAP32[$565>>2]|0;
      __THREW__ = 0;
      invoke_vii($566|0,($561|0),2);
      $567 = __THREW__; __THREW__ = 0;
      $568 = $567&1;
      if ($568) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $569 = (+invoke_d(2));
      $570 = __THREW__; __THREW__ = 0;
      $571 = $570&1;
      if ($571) {
       label = 12;
       break L19;
      }
      $572 = $569 * 1.0E+6;
      $573 = (~~$572)>>>0;
      $574 = +Math_abs($572) >= 1.0 ? $572 > 0.0 ? (Math_min(+Math_floor($572 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($572 - +(~~$572 >>> 0)) / 4294967296.0) >>> 0 : 0;
      $575 = (_i64Subtract(($573|0),($574|0),($559|0),($560|0))|0);
      $576 = tempRet0;
      $577 = ((621696 + 24|0));
      $578 = $577;
      $579 = HEAP32[$578>>2]|0;
      $580 = (($577) + 4)|0;
      $581 = $580;
      $582 = HEAP32[$581>>2]|0;
      $583 = (_i64Add(($575|0),($576|0),($579|0),($582|0))|0);
      $584 = tempRet0;
      $585 = ((621696 + 24|0));
      $586 = $585;
      HEAP32[$586>>2] = $583;
      $587 = (($585) + 4)|0;
      $588 = $587;
      HEAP32[$588>>2] = $584;
      __THREW__ = 0;
      $589 = (invoke_i(96)|0);
      $590 = __THREW__; __THREW__ = 0;
      $591 = $590&1;
      if ($591) {
       label = 12;
       break L19;
      }
      $592 = ($589|0)==(0|0);
      if (!($592)) {
       $593 = HEAP32[$589>>2]|0;
       $594 = (($593) + 8|0);
       $595 = HEAP32[$594>>2]|0;
       __THREW__ = 0;
       invoke_vi($595|0,($589|0));
       $596 = __THREW__; __THREW__ = 0;
       $597 = $596&1;
       if ($597) {
        label = 12;
        break L19;
       }
      }
      $598 = (0|0)==(0|0);
      if (!($598)) {
       __THREW__ = 0;
       invoke_v(0|0);
       $599 = __THREW__; __THREW__ = 0;
       $600 = $599&1;
       if ($600) {
        label = 12;
        break L19;
       }
      }
      do {
       if ($performRendering) {
        $601 = HEAP32[$24>>2]|0;
        $602 = (($601) + 516|0);
        $603 = HEAP32[$602>>2]|0;
        __THREW__ = 0;
        $604 = (invoke_ii($603|0,($24|0))|0);
        $605 = __THREW__; __THREW__ = 0;
        $606 = $605&1;
        if ($606) {
         label = 12;
         break L19;
        }
        $607 = HEAP32[579400>>2]|0;
        $608 = ($607|0)!=(0|0);
        $or$cond5 = $604 & $608;
        if (!($or$cond5)) {
         break;
        }
        __THREW__ = 0;
        invoke_v(163);
        $609 = __THREW__; __THREW__ = 0;
        $610 = $609&1;
        if ($610) {
         label = 12;
         break L19;
        }
       }
      } while(0);
      $611 = (0|0)==(0|0);
      if (!($611)) {
       __THREW__ = 0;
       invoke_v(0|0);
       $612 = __THREW__; __THREW__ = 0;
       $613 = $612&1;
       if ($613) {
        label = 12;
        break L19;
       }
      }
      __THREW__ = 0;
      invoke_v(164);
      $614 = __THREW__; __THREW__ = 0;
      $615 = $614&1;
      if ($615) {
       label = 12;
       break L19;
      }
      $616 = (0|0)==(0|0);
      if (!($616)) {
       __THREW__ = 0;
       invoke_v(0|0);
       $617 = __THREW__; __THREW__ = 0;
       $618 = $617&1;
       if ($618) {
        label = 12;
        break L19;
       }
      }
      $619 = ($pHookEvt|0)!=(0|0);
      if ($619) {
       $620 = HEAP32[$pHookEvt>>2]|0;
       $621 = HEAP32[$620>>2]|0;
       __THREW__ = 0;
       invoke_vi($621|0,($pHookEvt|0));
       $622 = __THREW__; __THREW__ = 0;
       $623 = $622&1;
       if ($623) {
        label = 12;
        break L19;
       }
      }
      __THREW__ = 0;
      $624 = (+invoke_d(2));
      $625 = __THREW__; __THREW__ = 0;
      $626 = $625&1;
      if ($626) {
       label = 12;
       break L19;
      }
      $627 = $624 * 1.0E+6;
      $628 = (~~$627)>>>0;
      $629 = +Math_abs($627) >= 1.0 ? $627 > 0.0 ? (Math_min(+Math_floor($627 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($627 - +(~~$627 >>> 0)) / 4294967296.0) >>> 0 : 0;
      do {
       if ($performRendering) {
        $630 = HEAP32[$24>>2]|0;
        $631 = (($630) + 516|0);
        $632 = HEAP32[$631>>2]|0;
        __THREW__ = 0;
        $633 = (invoke_ii($632|0,($24|0))|0);
        $634 = __THREW__; __THREW__ = 0;
        $635 = $634&1;
        if ($635) {
         label = 12;
         break L19;
        }
        if (!($633)) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(2787,1,(0|0));
        $636 = __THREW__; __THREW__ = 0;
        $637 = $636&1;
        if ($637) {
         label = 12;
         break L19;
        }
       }
      } while(0);
      __THREW__ = 0;
      $638 = (+invoke_d(2));
      $639 = __THREW__; __THREW__ = 0;
      $640 = $639&1;
      if ($640) {
       label = 12;
       break L19;
      }
      $641 = $638 * 1.0E+6;
      $642 = (~~$641)>>>0;
      $643 = +Math_abs($641) >= 1.0 ? $641 > 0.0 ? (Math_min(+Math_floor($641 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($641 - +(~~$641 >>> 0)) / 4294967296.0) >>> 0 : 0;
      $644 = (_i64Subtract(($642|0),($643|0),($628|0),($629|0))|0);
      $645 = tempRet0;
      $646 = ((621696 + 32|0));
      $647 = $646;
      $648 = HEAP32[$647>>2]|0;
      $649 = (($646) + 4)|0;
      $650 = $649;
      $651 = HEAP32[$650>>2]|0;
      $652 = (_i64Add(($644|0),($645|0),($648|0),($651|0))|0);
      $653 = tempRet0;
      $654 = ((621696 + 32|0));
      $655 = $654;
      HEAP32[$655>>2] = $652;
      $656 = (($654) + 4)|0;
      $657 = $656;
      HEAP32[$657>>2] = $653;
      __THREW__ = 0;
      $658 = (invoke_i(100)|0);
      $659 = __THREW__; __THREW__ = 0;
      $660 = $659&1;
      if ($660) {
       label = 12;
       break L19;
      }
      $661 = HEAP32[$658>>2]|0;
      $662 = (($661) + 8|0);
      $663 = HEAP32[$662>>2]|0;
      __THREW__ = 0;
      invoke_vi($663|0,($658|0));
      $664 = __THREW__; __THREW__ = 0;
      $665 = $664&1;
      if ($665) {
       label = 12;
       break L19;
      }
      if ($619) {
       $666 = HEAP32[$pHookEvt>>2]|0;
       $667 = HEAP32[$666>>2]|0;
       __THREW__ = 0;
       invoke_vi($667|0,($pHookEvt|0));
       $668 = __THREW__; __THREW__ = 0;
       $669 = $668&1;
       if ($669) {
        label = 12;
        break L19;
       }
      }
      $670 = HEAP32[579456>>2]|0;
      $671 = ($670|0)==(0|0);
      if (!($671)) {
       __THREW__ = 0;
       invoke_v(165);
       $672 = __THREW__; __THREW__ = 0;
       $673 = $672&1;
       if ($673) {
        label = 12;
        break L19;
       }
      }
      $674 = HEAP32[579424>>2]|0;
      $675 = ($674|0)==(0|0);
      if (!($675)) {
       __THREW__ = 0;
       invoke_v(166);
       $676 = __THREW__; __THREW__ = 0;
       $677 = $676&1;
       if ($677) {
        label = 12;
        break L19;
       }
      }
      $678 = HEAP32[579432>>2]|0;
      $679 = ($678|0)==(0|0);
      if (!($679)) {
       __THREW__ = 0;
       invoke_v(167);
       $680 = __THREW__; __THREW__ = 0;
       $681 = $680&1;
       if ($681) {
        label = 12;
        break L19;
       }
      }
      if ($performRendering) {
       __THREW__ = 0;
       $682 = (+invoke_d(2));
       $683 = __THREW__; __THREW__ = 0;
       $684 = $683&1;
       if ($684) {
        label = 12;
        break L19;
       }
       $685 = $682 * 1.0E+6;
       $686 = (~~$685)>>>0;
       $687 = +Math_abs($685) >= 1.0 ? $685 > 0.0 ? (Math_min(+Math_floor($685 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($685 - +(~~$685 >>> 0)) / 4294967296.0) >>> 0 : 0;
       if (!($batchMode)) {
        __THREW__ = 0;
        invoke_vi(3535,0);
        $688 = __THREW__; __THREW__ = 0;
        $689 = $688&1;
        if ($689) {
         label = 12;
         break L19;
        }
       }
       __THREW__ = 0;
       $690 = (invoke_i(95)|0);
       $691 = __THREW__; __THREW__ = 0;
       $692 = $691&1;
       if ($692) {
        label = 12;
        break L19;
       }
       $693 = HEAP32[$690>>2]|0;
       $694 = (($693) + 100|0);
       $695 = HEAP32[$694>>2]|0;
       __THREW__ = 0;
       invoke_vii($695|0,($690|0),32);
       $696 = __THREW__; __THREW__ = 0;
       $697 = $696&1;
       if ($697) {
        label = 12;
        break L19;
       }
       __THREW__ = 0;
       invoke_v(168);
       $698 = __THREW__; __THREW__ = 0;
       $699 = $698&1;
       if ($699) {
        label = 12;
        break L19;
       }
       if (!($batchMode)) {
        $700 = HEAP32[$24>>2]|0;
        $701 = (($700) + 508|0);
        $702 = HEAP32[$701>>2]|0;
        __THREW__ = 0;
        invoke_vi($702|0,($24|0));
        $703 = __THREW__; __THREW__ = 0;
        $704 = $703&1;
        if ($704) {
         label = 12;
         break L19;
        }
        do {
         if ((($83|0) == 1)) {
          $705 = (0|0)==(0|0);
          if (!($705)) {
           __THREW__ = 0;
           invoke_vi(0|0,1);
           $706 = __THREW__; __THREW__ = 0;
           $707 = $706&1;
           if ($707) {
            label = 12;
            break L19;
           }
          }
          __THREW__ = 0;
          $708 = (invoke_i(59)|0);
          $709 = __THREW__; __THREW__ = 0;
          $710 = $709&1;
          if ($710) {
           label = 12;
           break L19;
          }
          $711 = HEAP32[$708>>2]|0;
          $712 = (($711) + 512|0);
          $713 = HEAP32[$712>>2]|0;
          __THREW__ = 0;
          invoke_vi($713|0,($708|0));
          $714 = __THREW__; __THREW__ = 0;
          $715 = $714&1;
          if ($715) {
           label = 12;
           break L19;
          }
          HEAP8[622200>>0] = 0;
          $716 = (0|0)==(0|0);
          if (!($716)) {
           __THREW__ = 0;
           invoke_vi(0|0,0);
           $717 = __THREW__; __THREW__ = 0;
           $718 = $717&1;
           if ($718) {
            label = 12;
            break L19;
           }
          }
          dest=621696+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
         } else if ((($83|0) == 0)) {
          $719 = HEAP8[622208>>0]|0;
          $720 = ($719<<24>>24)==(0);
          if ($720) {
           break;
          }
          $721 = (0|0)==(0|0);
          if (!($721)) {
           __THREW__ = 0;
           invoke_vi(0|0,1);
           $722 = __THREW__; __THREW__ = 0;
           $723 = $722&1;
           if ($723) {
            label = 12;
            break L19;
           }
          }
          __THREW__ = 0;
          $724 = (invoke_i(59)|0);
          $725 = __THREW__; __THREW__ = 0;
          $726 = $725&1;
          if ($726) {
           label = 12;
           break L19;
          }
          $727 = HEAP32[$724>>2]|0;
          $728 = (($727) + 512|0);
          $729 = HEAP32[$728>>2]|0;
          __THREW__ = 0;
          invoke_vi($729|0,($724|0));
          $730 = __THREW__; __THREW__ = 0;
          $731 = $730&1;
          if ($731) {
           label = 12;
           break L19;
          }
          HEAP8[622200>>0] = 0;
          $732 = (0|0)==(0|0);
          if (!($732)) {
           __THREW__ = 0;
           invoke_vi(0|0,0);
           $733 = __THREW__; __THREW__ = 0;
           $734 = $733&1;
           if ($734) {
            label = 12;
            break L19;
           }
          }
          dest=621696+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
         }
        } while(0);
        HEAP8[622208>>0] = 0;
       }
       __THREW__ = 0;
       $735 = (+invoke_d(2));
       $736 = __THREW__; __THREW__ = 0;
       $737 = $736&1;
       if ($737) {
        label = 12;
        break L19;
       }
       $738 = $735 * 1.0E+6;
       $739 = (~~$738)>>>0;
       $740 = +Math_abs($738) >= 1.0 ? $738 > 0.0 ? (Math_min(+Math_floor($738 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($738 - +(~~$738 >>> 0)) / 4294967296.0) >>> 0 : 0;
       $741 = (_i64Subtract(($739|0),($740|0),($686|0),($687|0))|0);
       $742 = tempRet0;
       $743 = ((621696 + 48|0));
       $744 = $743;
       $745 = HEAP32[$744>>2]|0;
       $746 = (($743) + 4)|0;
       $747 = $746;
       $748 = HEAP32[$747>>2]|0;
       $749 = (_i64Add(($741|0),($742|0),($745|0),($748|0))|0);
       $750 = tempRet0;
       $751 = ((621696 + 48|0));
       $752 = $751;
       HEAP32[$752>>2] = $749;
       $753 = (($751) + 4)|0;
       $754 = $753;
       HEAP32[$754>>2] = $750;
      }
      __THREW__ = 0;
      $755 = (invoke_i(94)|0);
      $756 = __THREW__; __THREW__ = 0;
      $757 = $756&1;
      if ($757) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      invoke_vi(3536,($755|0));
      $758 = __THREW__; __THREW__ = 0;
      $759 = $758&1;
      if ($759) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $760 = (invoke_i(93)|0);
      $761 = __THREW__; __THREW__ = 0;
      $762 = $761&1;
      if ($762) {
       label = 12;
       break L19;
      }
      $763 = HEAP32[$760>>2]|0;
      $764 = (($763) + 12|0);
      $765 = HEAP32[$764>>2]|0;
      __THREW__ = 0;
      $766 = (invoke_ii($765|0,($760|0))|0);
      $767 = __THREW__; __THREW__ = 0;
      $768 = $767&1;
      if ($768) {
       label = 12;
       break L19;
      }
      if ($766) {
       HEAP8[622200>>0] = 0;
       HEAP8[622208>>0] = 1;
      }
      __THREW__ = 0;
      $769 = (invoke_i(55)|0);
      $770 = __THREW__; __THREW__ = 0;
      $771 = $770&1;
      if ($771) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      invoke_vi(3537,($769|0));
      $772 = __THREW__; __THREW__ = 0;
      $773 = $772&1;
      if ($773) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $774 = (invoke_i(101)|0);
      $775 = __THREW__; __THREW__ = 0;
      $776 = $775&1;
      if ($776) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      invoke_vi(3538,($774|0));
      $777 = __THREW__; __THREW__ = 0;
      $778 = $777&1;
      if ($778) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      invoke_v(169);
      $779 = __THREW__; __THREW__ = 0;
      $780 = $779&1;
      if ($780) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $781 = (invoke_i(55)|0);
      $782 = __THREW__; __THREW__ = 0;
      $783 = $782&1;
      if ($783) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      $784 = (invoke_ii(3274,($781|0))|0);
      $785 = __THREW__; __THREW__ = 0;
      $786 = $785&1;
      if ($786) {
       label = 12;
       break L19;
      }
      $$not = $784 ^ 1;
      $brmerge = $359 | $$not;
      if (!($brmerge)) {
       __THREW__ = 0;
       $787 = (invoke_i(55)|0);
       $788 = __THREW__; __THREW__ = 0;
       $789 = $788&1;
       if ($789) {
        label = 12;
        break L19;
       }
       __THREW__ = 0;
       invoke_vi(3539,($787|0));
       $790 = __THREW__; __THREW__ = 0;
       $791 = $790&1;
       if ($791) {
        label = 12;
        break L19;
       }
      }
      __THREW__ = 0;
      $792 = (invoke_i(54)|0);
      $793 = __THREW__; __THREW__ = 0;
      $794 = $793&1;
      if ($794) {
       label = 12;
       break L19;
      }
      __THREW__ = 0;
      invoke_vii(2788,($792|0),0);
      $795 = __THREW__; __THREW__ = 0;
      $796 = $795&1;
      if ($796) {
       label = 12;
       break L19;
      }
      $797 = ($83|0)==(1);
      if (!($797)) {
       break;
      }
      $798 = HEAP32[$24>>2]|0;
      $799 = (($798) + 620|0);
      $800 = HEAP32[$799>>2]|0;
      __THREW__ = 0;
      invoke_vi($800|0,($24|0));
      $801 = __THREW__; __THREW__ = 0;
      $802 = $801&1;
      if ($802) {
       label = 12;
       break L19;
      }
     }
    } while(0);
    HEAP8[622192>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $lpad$phi$index = $22;$lpad$phi$index2 = $23;
 }
 HEAP8[622192>>0] = 0;
 $$index = $lpad$phi$index;$$index7 = $lpad$phi$index2;
 ___resumeException($$index|0);
 // unreachable;
}
function __ZNSt3__16__treeI4PPtrIN5Unity10GameObjectEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeI4PPtrIN5Unity10GameObjectEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeI4PPtrIN5Unity10GameObjectEENS_4lessIS4_EENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeI4PPtrI6ObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeI4PPtrI6ObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeI4PPtrI6ObjectENS_4lessIS3_EENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN12LevelLoadingC2Ev($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $phitmp10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 8|0);
 HEAP32[$7>>2] = 61;
 $8 = (($this) + 24|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;
 HEAP32[$1>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy3|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  HEAP32[$4>>2] = 0;
  $$phi$trans$insert = (($this) + 24|0);
  $$pre = HEAP8[$$phi$trans$insert>>0]|0;
  $phitmp = $$pre & 1;
  $phitmp10 = ($phitmp<<24>>24)==(0);
  HEAP32[$5>>2] = 0;
  HEAP32[$6>>2] = 0;
  HEAP32[$this>>2] = -1;
  $11 = (($this) + 20|0);
  HEAP8[$11>>0] = 0;
  if ($phitmp10) {
   $15 = (($$phi$trans$insert) + 1|0);
   HEAP8[$15>>0] = 0;
   HEAP8[$$phi$trans$insert>>0] = 0;
  } else {
   $12 = (($this) + 32|0);
   $13 = HEAP32[$12>>2]|0;
   HEAP8[$13>>0] = 0;
   $14 = (($this) + 28|0);
   HEAP32[$14>>2] = 0;
  }
  $16 = (($this) + 36|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $23 = (($16) + 1|0);
   HEAP8[$23>>0] = 0;
   HEAP8[$16>>0] = 0;
   STACKTOP = sp;return;
  } else {
   $20 = (($this) + 44|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP8[$21>>0] = 0;
   $22 = (($this) + 40|0);
   HEAP32[$22>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $26 = (($this) + 36|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27 & 1;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  $30 = (($this) + 44|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($31|0),($$byval_copy3|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $34 = ___cxa_find_matching_catch()|0;
   $35 = tempRet0;
   ___cxa_call_unexpected(($34|0));
   // unreachable;
  }
 }
 $36 = HEAP8[$8>>0]|0;
 $37 = $36 & 1;
 $38 = ($37<<24>>24)==(0);
 if (!($38)) {
  $39 = (($this) + 32|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($40|0),($$byval_copy3|0));
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if ($42) {
   $43 = ___cxa_find_matching_catch()|0;
   $44 = tempRet0;
   ___cxa_call_unexpected(($43|0));
   // unreachable;
  }
 }
 $45 = HEAP32[$6>>2]|0;
 $46 = ($45|0)>(-1);
 if (!($46)) {
  ___resumeException($24|0);
  // unreachable;
 }
 $47 = HEAP32[$4>>2]|0;
 $48 = HEAP32[$7>>2]|0;
 HEAP32[$3>>2] = $48;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy3|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch(0|0)|0;
  $52 = tempRet0;
  ___clang_call_terminate($51);
  // unreachable;
 }
 HEAP32[$4>>2] = 0;
 ___resumeException($24|0);
 // unreachable;
}
function __GLOBAL__I_a6584() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12LevelLoadingC2Ev(621760);
 STACKTOP = sp;return;
}
function __Z33PluginsInitializePreloadedPluginsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z17GetPreloadManagerv() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[622496>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__Znwj(36)|0);
 HEAP32[$2>>2] = 0;
 $3 = (($2) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($2) + 4|0);
 HEAP32[$5>>2] = 61;
 $6 = (($2) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 24|0);
 HEAP32[$7>>2] = 0;
 $8 = (($2) + 28|0);
 HEAP32[$8>>2] = 0;
 $9 = (($2) + 20|0);
 HEAP32[$9>>2] = 61;
 $10 = (($2) + 32|0);
 HEAP32[$10>>2] = 0;
 HEAP32[622496>>2] = $2;
 $$0 = $2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14PreloadManager10AddToQueueEP23PreloadManagerOperation($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $operation;
 __ZN14AsyncOperation6RetainEv($operation);
 __ZN13dynamic_arrayIP23PreloadManagerOperationLj4EE9push_backERKS1_($this,$0);
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIP23PreloadManagerOperationLj4EE9push_backERKS1_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$t>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if (!($8)) {
  $27 = $4;
  $26 = (($27) + -1)|0;
  $28 = HEAP32[$this>>2]|0;
  $29 = (($28) + ($26<<2)|0);
  HEAP32[$29>>2] = $1;
  STACKTOP = sp;return;
 }
 $9 = $6 << 1;
 $10 = ($9|0)==(0);
 $11 = $10 ? 1 : $9;
 $12 = ($7>>>0)<($11>>>0);
 do {
  if ($12) {
   $13 = ($6|0)>(-1);
   if ($13) {
    HEAP32[$5>>2] = $11;
    $14 = HEAP32[$this>>2]|0;
    $15 = $11 << 2;
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy1,0,622568,370)|0);
    HEAP32[$this>>2] = $18;
    break;
   } else {
    $19 = $11 << 2;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,622568,352)|0);
    $23 = HEAP32[$this>>2]|0;
    $24 = HEAP32[$2>>2]|0;
    $25 = $24 << 2;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$5>>2] = $11;
    HEAP32[$this>>2] = $22;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$2>>2]|0;
 $27 = $$pre$i;
 $26 = (($27) + -1)|0;
 $28 = HEAP32[$this>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAP32[$29>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN14PreloadManager33PrepareProcessingPreloadOperationEv($this) {
 $this = $this|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $highestPriority$02$i = 0, $highestPriority$1$i = 0, $i$03$i = 0, $index$0$lcssa$i = 0, $index$01$i = 0, $index$1$i = 0, $neg = 0, $operation = 0, $tmp = 0, $tmp3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $operation = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $9 = HEAP32[$0>>2]|0;
 $10 = ($9>>>0)>(1);
 if ($10) {
  $highestPriority$02$i = $8;$i$03$i = 1;$index$01$i = 0;
  while(1) {
   $11 = HEAP32[$this>>2]|0;
   $12 = (($11) + ($i$03$i<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (FUNCTION_TABLE_ii[$16 & 4095]($13)|0);
   $18 = ($17|0)>($highestPriority$02$i|0);
   if ($18) {
    $19 = HEAP32[$this>>2]|0;
    $20 = (($19) + ($i$03$i<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + 16|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (FUNCTION_TABLE_ii[$24 & 4095]($21)|0);
    $highestPriority$1$i = $25;$index$1$i = $i$03$i;
   } else {
    $highestPriority$1$i = $highestPriority$02$i;$index$1$i = $index$01$i;
   }
   $26 = (($i$03$i) + 1)|0;
   $27 = HEAP32[$0>>2]|0;
   $28 = ($26>>>0)<($27>>>0);
   if ($28) {
    $highestPriority$02$i = $highestPriority$1$i;$i$03$i = $26;$index$01$i = $index$1$i;
   } else {
    $33 = $27;$index$0$lcssa$i = $index$1$i;
    break;
   }
  }
 } else {
  $33 = $9;$index$0$lcssa$i = 0;
 }
 $29 = HEAP32[$this>>2]|0;
 $30 = (($29) + ($index$0$lcssa$i<<2)|0);
 $31 = HEAP32[$30>>2]|0;
 HEAP32[$operation>>2] = $31;
 $$sum = (($index$0$lcssa$i) + 1)|0;
 $32 = (($29) + ($$sum<<2)|0);
 $neg = $index$0$lcssa$i ^ 1073741823;
 $tmp = (($33) + ($neg))|0;
 $tmp3 = $tmp << 2;
 _memmove(($30|0),($32|0),($tmp3|0))|0;
 $34 = HEAP32[$0>>2]|0;
 $35 = (($34) + -1)|0;
 HEAP32[$0>>2] = $35;
 $36 = (($this) + 16|0);
 __ZN13dynamic_arrayIP23PreloadManagerOperationLj4EE9push_backERKS1_($36,$operation);
 $37 = HEAP32[$operation>>2]|0;
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14PreloadManager26UpdatePreloadingSingleStepEb($this,$stopPreloading) {
 $this = $this|0;
 $stopPreloading = $stopPreloading|0;
 var $$idx$i = 0, $$not = 0, $$stopPreloading = 0, $$stopPreloading$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN14PreloadManager33PrepareProcessingPreloadOperationEv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[$0>>2]|0;
  $3 = (($2) + 32|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095]($0);
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 48|0);
  $7 = HEAP32[$6>>2]|0;
  (FUNCTION_TABLE_ii[$7 & 4095]($0)|0);
  $8 = (($0) + 24|0);
  HEAP32[$8>>2] = 1;
 }
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($14) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (+_emscripten_get_now());
 $19 = $18 * 1.0E+6;
 $20 = (~~$19)>>>0;
 $21 = +Math_abs($19) >= 1.0 ? $19 > 0.0 ? (Math_min(+Math_floor($19 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($19 - +(~~$19 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $22 = HEAP32[$14>>2]|0;
 $23 = (($22) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_iii[$24 & 4095]($14,10)|0);
 $26 = (+_emscripten_get_now());
 $27 = $26 * 1.0E+6;
 $28 = (~~$27)>>>0;
 $29 = +Math_abs($27) >= 1.0 ? $27 > 0.0 ? (Math_min(+Math_floor($27 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($27 - +(~~$27 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $30 = (($14) + 40|0);
 $31 = $30;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (_i64Subtract(($33|0),($36|0),($20|0),($21|0))|0);
 $38 = tempRet0;
 $39 = (_i64Add(($37|0),($38|0),($28|0),($29|0))|0);
 $40 = tempRet0;
 $41 = $30;
 $42 = $41;
 HEAP32[$42>>2] = $39;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $40;
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$14>>2]|0;
 $46 = (($45) + 24|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (FUNCTION_TABLE_ii[$47 & 4095]($14)|0);
 $$stopPreloading = $48 | $stopPreloading;
 $$not = ($17|0)!=(1);
 $$stopPreloading$not = $$stopPreloading ^ 1;
 $brmerge = $$not | $$stopPreloading$not;
 if ($brmerge) {
  STACKTOP = sp;return;
 }
 $49 = HEAP32[$12>>2]|0;
 $50 = (($49) + 4|0);
 $51 = HEAP32[$9>>2]|0;
 $$idx$i = $51 << 2;
 $52 = (($$idx$i) + -4)|0;
 _memmove(($49|0),($50|0),($52|0))|0;
 $53 = HEAP32[$9>>2]|0;
 $54 = (($53) + -1)|0;
 HEAP32[$9>>2] = $54;
 $55 = HEAP32[$14>>2]|0;
 $56 = (($55) + 40|0);
 $57 = HEAP32[$56>>2]|0;
 FUNCTION_TABLE_vi[$57 & 4095]($14);
 HEAP32[$16>>2] = 2;
 __ZN14AsyncOperation15InvokeCoroutineEv($14);
 __ZN14AsyncOperation7ReleaseEv($14);
 STACKTOP = sp;return;
}
function __ZN14PreloadManager35WaitForAllAsyncOperationsToCompleteEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = (($this) + 8|0);
 while(1) {
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0);
  if ($3) {
   $4 = HEAP32[$0>>2]|0;
   $5 = ($4|0)==(0);
   if ($5) {
    break;
   }
  }
  __ZN14PreloadManager26UpdatePreloadingSingleStepEb($this,0);
 }
 STACKTOP = sp;return;
}
function __ZN14PreloadManager16UpdatePreloadingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $i1$04 = 0, $mustCompleteNow$0$off0$lcssa = 0, $mustCompleteNow$0$off05 = 0, $mustCompleteNow$1$off0$lcssa = 0, $mustCompleteNow$1$off03 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $mustCompleteNow$0$off0$lcssa = 0;
 } else {
  $i$06 = 0;$mustCompleteNow$0$off05 = 0;
  while(1) {
   $7 = HEAP32[$this>>2]|0;
   $8 = (($7) + ($i$06<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 44|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
   $14 = $mustCompleteNow$0$off05 | $13;
   $15 = (($i$06) + 1)|0;
   $16 = HEAP32[$0>>2]|0;
   $17 = ($15>>>0)<($16>>>0);
   if ($17) {
    $i$06 = $15;$mustCompleteNow$0$off05 = $14;
   } else {
    $mustCompleteNow$0$off0$lcssa = $14;
    break;
   }
  }
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $mustCompleteNow$1$off0$lcssa = $mustCompleteNow$0$off0$lcssa;
 } else {
  $6 = (($this) + 16|0);
  $i1$04 = 0;$mustCompleteNow$1$off03 = $mustCompleteNow$0$off0$lcssa;
  while(1) {
   $18 = HEAP32[$6>>2]|0;
   $19 = (($18) + ($i1$04<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 44|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (FUNCTION_TABLE_ii[$23 & 4095]($20)|0);
   $25 = $mustCompleteNow$1$off03 | $24;
   $26 = (($i1$04) + 1)|0;
   $27 = HEAP32[$3>>2]|0;
   $28 = ($26>>>0)<($27>>>0);
   if ($28) {
    $i1$04 = $26;$mustCompleteNow$1$off03 = $25;
   } else {
    $mustCompleteNow$1$off0$lcssa = $25;
    break;
   }
  }
 }
 if (!($mustCompleteNow$1$off0$lcssa)) {
  __ZN14PreloadManager26UpdatePreloadingSingleStepEb($this,0);
  STACKTOP = sp;return;
 }
 while(1) {
  $29 = HEAP32[$0>>2]|0;
  $30 = ($29|0)==(0);
  if ($30) {
   $31 = HEAP32[$3>>2]|0;
   $32 = ($31|0)==(0);
   if ($32) {
    break;
   }
  }
  __ZN14PreloadManager26UpdatePreloadingSingleStepEb($this,0);
 }
 STACKTOP = sp;return;
}
function __ZN23PreloadManagerOperation11GetProgressEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN23PreloadManagerOperation6IsDoneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2);
 STACKTOP = sp;return ($2|0);
}
function __ZN23PreloadManagerOperationC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((617224 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 1;
 $1 = (($this) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$this>>2] = ((622504 + 8|0));
 $3 = (($this) + 56|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 24|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 60|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 32|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN23PreloadManagerOperationD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14AsyncOperationD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN23PreloadManagerOperationD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1113,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN23PreloadManagerOperation19IntegrateMainThreadEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11PreloadData23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,622576,622584,$this,0);
 __ZN15SerializeTraitsI11PreloadDataE8TransferI13ProxyTransferEEvRS0_RT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11PreloadData23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,622576,622584,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN11PreloadData8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11PreloadData23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 STACKTOP = sp;return;
}
function __ZN11PreloadData23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 STACKTOP = sp;return;
}
function __ZN11PreloadData23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i = sp;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i$i$i$i>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i$i$i,4);
 }
 $8 = (($this) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = (($9) + ($10<<2)|0);
 $12 = ($10|0)==(0);
 if (!($12)) {
  $i$01$i$i$i$i$i$i = $9;
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i$i$i$i,$transfer);
   $13 = (($i$01$i$i$i$i$i$i) + 4|0);
   $14 = ($13|0)==($11|0);
   if ($14) {
    break;
   } else {
    $i$01$i$i$i$i$i$i = $13;
   }
  }
 }
 $15 = (($this) + 44|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$15,0);
 STACKTOP = sp;return;
}
function __ZN11PreloadData23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($transfer) + 12|0);
 $7 = (($transfer) + 28|0);
 $8 = (($transfer) + 32|0);
 $i$01$i$i$i$i$i$i = $1;
 while(1) {
  $9 = HEAP32[$i$01$i$i$i$i$i$i>>2]|0;
  $10 = HEAP32[$6>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$7>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($10,$9,$13)|0);
  $15 = HEAP8[$8>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   HEAP32[$i$01$i$i$i$i$i$i>>2] = $14;
  }
  $17 = (($i$01$i$i$i$i$i$i) + 4|0);
  $18 = ($17|0)==($4|0);
  if ($18) {
   break;
  } else {
   $i$01$i$i$i$i$i$i = $17;
  }
 }
 STACKTOP = sp;return;
}
function __Z25RegisterClass_PreloadDatav() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(150,170,0,0,0);
 STACKTOP = sp;return;
}
function __ZN11PreloadData13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 11;
 dest=$3+0|0; src=622584+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 11|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,150,130,($0|0),56,(2427|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN11PreloadData7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(56,$$byval_copy2,1,16,622744,11)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1685,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((622600 + 8|0));
  $6 = (($3) + 28|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 36|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 40|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 32|0);
  HEAP32[$9>>2] = 61;
  $10 = (($3) + 44|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 48|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 52|0);
  HEAP32[$12>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(622744|0),11);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK11PreloadData25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 150;
}
function __ZN11PreloadDataD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11PreloadDataD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN11PreloadDataD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3540,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN11PreloadData39ShouldIgnoreInGarbageDependencyTrackingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN11PreloadData8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580760>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,622704,$1,$converter$i$i1,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 44|0);
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,622720,$1,$converter$i$i1,1)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI14ConstantStringNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$7,0);
 } else {
  $11 = HEAP32[$converter$i$i1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (FUNCTION_TABLE_iii[$11 & 4095]($7,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI11PreloadDataE8TransferI13ProxyTransferEEvRS0_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i$i = 0, $p$i$i = 0, $p$i$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 $size$i$i$i = sp + 24|0;
 $p$i$i = sp + 16|0;
 $p$i$i$i = sp + 20|0;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($data,$transfer);
 $0 = (($data) + 28|0);
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,622704,$1,$0,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,622784,622784,$size$i$i$i,0);
 $2 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,622736,$2,$p$i$i,0);
 $3 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $8 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,622752,$8,$p$i$i,1);
 $9 = (($transfer) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($transfer) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($11) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,622768,$15,$3,1);
 $16 = HEAP32[$9>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$12>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($data) + 44|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,622720,$1,$20,0);
 HEAP32[$p$i$i$i>>2] = 0;
 __ZN14ConstantString12create_emptyEv($p$i$i$i);
 __THREW__ = 0;
 invoke_viiiii(87,($transfer|0),(622784|0),(622784|0),($p$i$i|0),0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  $23 = HEAP32[580712>>2]|0;
  __THREW__ = 0;
  invoke_viiiii(86,($transfer|0),(622736|0),($23|0),($p$i$i$i|0),0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   __THREW__ = 0;
   invoke_viiiii(87,($transfer|0),(622784|0),(622784|0),($localIdentifier$i$i$i$i$i$i|0),1);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[580552>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($transfer|0),(622736|0),($28|0),($size$i$i$i|0),0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $31 = HEAP32[$9>>2]|0;
     $32 = HEAP32[$31>>2]|0;
     $33 = HEAP32[$12>>2]|0;
     $34 = ((($32) + (($33*24)|0)|0) + 12|0);
     HEAP32[$34>>2] = 1;
     __THREW__ = 0;
     invoke_vi(3390,($transfer|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      __THREW__ = 0;
      invoke_vi(3391,($transfer|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       __THREW__ = 0;
       invoke_vi(3392,($transfer|0));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if (!($40)) {
        __THREW__ = 0;
        invoke_vi(3390,($transfer|0));
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if (!($42)) {
         __THREW__ = 0;
         invoke_vi(3391,($transfer|0));
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if (!($44)) {
          __ZN14ConstantStringD2Ev($p$i$i$i);
          __ZN13ProxyTransfer11EndTransferEv($transfer);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $45 = ___cxa_find_matching_catch()|0;
 $46 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3382,($p$i$i$i|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 } else {
  ___resumeException($45|0);
  // unreachable;
 }
}
function __ZN11PreloadDataD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((622600 + 8|0));
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if (!($3)) {
   $4 = (($this) + 48|0);
   while(1) {
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5|0)==($2|0);
    if ($6) {
     label = 6;
     break;
    }
    $7 = (($5) + -4|0);
    HEAP32[$4>>2] = $7;
    __THREW__ = 0;
    invoke_vi(3382,($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
     break;
    }
   }
   if ((label|0) == 5) {
    $10 = ___cxa_find_matching_catch()|0;
    $11 = tempRet0;
    ___cxa_call_unexpected(($10|0));
    // unreachable;
   }
   else if ((label|0) == 6) {
    $12 = HEAP32[$1>>2]|0;
    __ZdlPv($12);
    break;
   }
  }
 } while(0);
 $13 = (($this) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(-1);
 if (!($15)) {
  __ZN11NamedObjectD2Ev($this);
  STACKTOP = sp;return;
 }
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$0>>2] = $19;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($17|0),($$byval_copy|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  HEAP32[$16>>2] = 0;
  __ZN11NamedObjectD2Ev($this);
  STACKTOP = sp;return;
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch(0|0)|0;
  $27 = tempRet0;
  ___clang_call_terminate($26);
  // unreachable;
 } else {
  ___resumeException($22|0);
  // unreachable;
 }
}
function __Z48AddToTimeSliceAwakeFromLoadQueueProgressCallbackR6ObjectPv($object,$userData) {
 $object = $object|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($object) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 21;
 $4 = HEAP32[560640>>2]|0;
 $5 = Math_imul($4, $3)|0;
 $6 = (($5) + 74)|0;
 $7 = $6 >> 5;
 $8 = $7 << 5;
 $9 = (($6) - ($8))|0;
 $10 = HEAP32[560632>>2]|0;
 $11 = (($10) + ($7<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = 1 << $9;
 $14 = $13 & $12;
 $15 = ($14|0)==(0);
 if ($15) {
  $16 = (($5) + 27)|0;
  $17 = $16 >> 5;
  $18 = $17 << 5;
  $19 = (($16) - ($18))|0;
  $20 = (($10) + ($17<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = 1 << $19;
  $23 = $21 & $22;
  $24 = ($23|0)==(0);
  if ($24) {
   $25 = (($5) + 43)|0;
   $26 = $25 >> 5;
   $27 = $26 << 5;
   $28 = (($25) - ($27))|0;
   $29 = (($10) + ($26<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = 1 << $28;
   $32 = $30 & $31;
   $33 = ($32|0)==(0);
   if ($33) {
    STACKTOP = sp;return;
   }
  }
 }
 $34 = (($object) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$0>>2] = $35;
 (__ZN19RingbufferTemplates17WriteToRingBufferIi17GrowingRingbufferEEbRT0_RKT_($userData,$0)|0);
 STACKTOP = sp;return;
}
function __ZN18LoadLevelOperation7PerformEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i19 = 0, $$01 = 0, $$01$i = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy31 = 0, $$not$not$i = 0, $$pr$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $brmerge$i = 0, $classIDs$i = 0, $eh$lpad$body$index7Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond = 0, $exitcond71 = 0, $i$061 = 0, $i1$025$i = 0, $i1$053 = 0, $loadProgress = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index2 = 0, $obj$049 = 0, $or$cond = 0, $sourceFileIDs$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy31 = sp + 128|0;
 $0 = sp + 124|0;
 $1 = sp + 120|0;
 $2 = sp + 116|0;
 $3 = sp + 112|0;
 $4 = sp + 108|0;
 $5 = sp + 104|0;
 $6 = sp + 100|0;
 $7 = sp + 96|0;
 $8 = sp + 92|0;
 $9 = sp + 88|0;
 $10 = sp + 36|0;
 $sourceFileIDs$i = sp;
 $classIDs$i = sp + 16|0;
 $11 = sp + 32|0;
 $12 = sp + 40|0;
 $13 = sp + 44|0;
 $14 = sp + 48|0;
 $15 = sp + 52|0;
 $16 = sp + 56|0;
 $loadProgress = sp + 64|0;
 $17 = (__Z20GetPersistentManagerv()|0);
 $18 = (($this) + 104|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $24 = $19&255;
  $25 = $24 >>> 1;
  $27 = $25;
 } else {
  $22 = (($this) + 108|0);
  $23 = HEAP32[$22>>2]|0;
  $27 = $23;
 }
 $26 = ($27|0)==(0);
 do {
  if (!($26)) {
   $28 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($17,$18,1,0)|0);
   $29 = (__ZN6Object21IDToPointerThreadSafeEi($28)|0);
   $30 = ($29|0)==(0|0);
   if ($30) {
    $31 = (__ZN17PersistentManager18ReadObjectThreadedEi($17,$28)|0);
    $32 = ($31|0)==(0|0);
    if ($32) {
     break;
    } else {
     $obj$049 = $31;
    }
   } else {
    $obj$049 = $29;
   }
   $33 = (($obj$049) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = $34 >>> 21;
   $36 = HEAP32[560640>>2]|0;
   $37 = Math_imul($36, $35)|0;
   $38 = (($37) + 150)|0;
   $39 = $38 >> 5;
   $40 = $39 << 5;
   $41 = (($38) - ($40))|0;
   $42 = HEAP32[560632>>2]|0;
   $43 = (($42) + ($39<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = 1 << $41;
   $46 = $45 & $44;
   $47 = ($46|0)==(0);
   $48 = ($obj$049|0)==(0|0);
   $or$cond = $47 | $48;
   if (!($or$cond)) {
    $49 = (($obj$049) + 28|0);
    $50 = (($49) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($this) + 72|0);
    $53 = (($this) + 80|0);
    HEAP32[$53>>2] = $51;
    $54 = (($this) + 84|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = $55 & 2147483647;
    $57 = ($56>>>0)<($51>>>0);
    do {
     if ($57) {
      $58 = ($55|0)>(-1);
      if ($58) {
       HEAP32[$54>>2] = $51;
       $59 = HEAP32[$52>>2]|0;
       $60 = $51 << 2;
       $61 = (($this) + 76|0);
       $62 = HEAP32[$61>>2]|0;
       HEAP32[$0>>2] = $62;
       ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
       $63 = (__Z16realloc_internalPvji10MemLabelIdiPKci($59,$60,4,$$byval_copy31,0,622936,370)|0);
       HEAP32[$52>>2] = $63;
       break;
      } else {
       $64 = $51 << 2;
       $65 = (($this) + 76|0);
       $66 = HEAP32[$65>>2]|0;
       HEAP32[$0>>2] = $66;
       ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
       $67 = (__Z15malloc_internaljj10MemLabelIdiPKci($64,4,$$byval_copy31,0,622936,352)|0);
       $68 = HEAP32[$52>>2]|0;
       $69 = HEAP32[$53>>2]|0;
       $70 = $69 << 2;
       _memcpy(($67|0),($68|0),($70|0))|0;
       HEAP32[$54>>2] = $51;
       HEAP32[$52>>2] = $67;
       break;
      }
     }
    } while(0);
    $71 = ($51|0)>(0);
    if ($71) {
     $72 = HEAP32[$52>>2]|0;
     $73 = HEAP32[$49>>2]|0;
     $i$061 = 0;
     while(1) {
      $74 = (($73) + ($i$061<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($72) + ($i$061<<2)|0);
      HEAP32[$76>>2] = $75;
      $77 = (($i$061) + 1)|0;
      $exitcond71 = ($77|0)==($51|0);
      if ($exitcond71) {
       break;
      } else {
       $i$061 = $77;
      }
     }
    }
    $78 = (__Z21GetAssetBundleManagerv()|0);
    $79 = (($obj$049) + 44|0);
    __ZN18AssetBundleManager18CollectPreloadDataERKNSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEER13dynamic_arrayIiLj4EEbb($78,$79,$52,0,0);
   }
  }
 } while(0);
 $80 = HEAP32[628512>>2]|0;
 $81 = (($this) + 92|0);
 $82 = HEAP8[$81>>0]|0;
 $83 = $82 & 1;
 $84 = ($83<<24>>24)==(0);
 if ($84) {
  $87 = $82&255;
  $88 = $87 >>> 1;
  $90 = $88;
 } else {
  $85 = (($this) + 96|0);
  $86 = HEAP32[$85>>2]|0;
  $90 = $86;
 }
 $89 = ($90|0)==(0);
 L27: do {
  if ($89) {
   $295 = 0;$325 = 0;$331 = 0;$337 = 0;$382 = 0;$386 = 0;
   label = 77;
  } else {
   $91 = (($this) + 116|0);
   $92 = HEAP32[$91>>2]|0;
   __THREW__ = 0;
   $93 = (invoke_i(57)|0);
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    $404 = 0;$405 = 0;$406 = 0;$407 = 0;
    label = 75;
   } else {
    __THREW__ = 0;
    invoke_vi(3541,($93|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     $404 = 0;$405 = 0;$406 = 0;$407 = 0;
     label = 75;
    } else {
     $98 = HEAP32[628512>>2]|0;
     HEAP32[$sourceFileIDs$i>>2] = 0;
     $99 = (($sourceFileIDs$i) + 4|0);
     HEAP32[$99>>2] = $98;
     $100 = (($sourceFileIDs$i) + 8|0);
     HEAP32[$100>>2] = 0;
     $101 = (($sourceFileIDs$i) + 12|0);
     HEAP32[$101>>2] = 0;
     HEAP32[$classIDs$i>>2] = 0;
     $102 = (($classIDs$i) + 4|0);
     HEAP32[$102>>2] = $98;
     $103 = (($classIDs$i) + 8|0);
     HEAP32[$103>>2] = 0;
     $104 = (($classIDs$i) + 12|0);
     HEAP32[$104>>2] = 0;
     __THREW__ = 0;
     $105 = (invoke_i(57)|0);
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     L31: do {
      if ($107) {
       $408 = 0;$409 = 0;$410 = 0;$411 = 0;
       label = 32;
      } else {
       __THREW__ = 0;
       invoke_viiii(330,($105|0),($81|0),($sourceFileIDs$i|0),($classIDs$i|0));
       $108 = __THREW__; __THREW__ = 0;
       $109 = $108&1;
       if ($109) {
        $408 = 0;$409 = 0;$410 = 0;$411 = 0;
        label = 32;
       } else {
        $110 = HEAP32[$100>>2]|0;
        $111 = ($110|0)==(0);
        L34: do {
         if ($111) {
          $412 = 0;$413 = 0;$414 = 0;$415 = 0;$416 = 0;$417 = 0;
         } else {
          $112 = $110 << 3;
          HEAP32[$9>>2] = $80;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$9+0>>2]|0;
          $113 = (invoke_iiiiiiii(108,(0|0),($112|0),8,($$byval_copy31|0),0,(622936|0),370)|0);
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           $408 = $110;$409 = 0;$410 = 0;$411 = 0;
           label = 32;
           break L31;
          }
          $$pre = HEAP32[$100>>2]|0;
          $116 = ($$pre|0)==(0);
          if ($116) {
           $412 = $110;$413 = 0;$414 = $113;$415 = 0;$416 = 0;$417 = 0;
          } else {
           $117 = $$pre << 2;
           HEAP32[$8>>2] = $80;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$8+0>>2]|0;
           $118 = (invoke_iiiiiiii(108,(0|0),($117|0),4,($$byval_copy31|0),0,(622936|0),370)|0);
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if ($120) {
            $408 = $110;$409 = $113;$410 = $$pre;$411 = 0;
            label = 32;
            break L31;
           }
           $$pr$i = HEAP32[$100>>2]|0;
           $121 = ($$pr$i|0)==(0);
           if ($121) {
            $412 = $110;$413 = 0;$414 = $113;$415 = $$pre;$416 = 0;$417 = $118;
           } else {
            $122 = $92 & -5;
            $$not$not$i = ($122|0)!=(1);
            $213 = 0;$215 = $$pre;$223 = $118;$234 = 0;$237 = $110;$245 = $113;$418 = $$pr$i;$i1$025$i = 0;
            L40: while(1) {
             $135 = HEAP32[$sourceFileIDs$i>>2]|0;
             $136 = (($135) + ($i1$025$i<<3)|0);
             $137 = $136;
             $138 = $137;
             $139 = HEAP32[$138>>2]|0;
             $140 = (($137) + 4)|0;
             $141 = $140;
             $142 = HEAP32[$141>>2]|0;
             $143 = HEAP32[$classIDs$i>>2]|0;
             $144 = (($143) + ($i1$025$i<<2)|0);
             $145 = HEAP32[$144>>2]|0;
             $146 = HEAP32[560640>>2]|0;
             $147 = Math_imul($146, $145)|0;
             $148 = (($147) + 6)|0;
             $149 = $148 >> 5;
             $150 = $149 << 5;
             $151 = (($148) - ($150))|0;
             $152 = HEAP32[560632>>2]|0;
             $153 = (($152) + ($149<<2)|0);
             $154 = HEAP32[$153>>2]|0;
             $155 = 1 << $151;
             $156 = $155 & $154;
             $157 = ($156|0)==(0);
             do {
              if ($157) {
               $158 = (($147) + 3)|0;
               $159 = $158 >> 5;
               $160 = $159 << 5;
               $161 = (($158) - ($160))|0;
               $162 = (($152) + ($159<<2)|0);
               $163 = HEAP32[$162>>2]|0;
               $164 = 1 << $161;
               $165 = $163 & $164;
               $166 = ($165|0)==(0);
               $brmerge$i = $166 | $$not$not$i;
               if (!($brmerge$i)) {
                if (!((($145|0) == 157) | (($145|0) == 196))) {
                 $262 = $418;$430 = $237;$431 = $234;$432 = $245;$433 = $215;$434 = $213;$435 = $223;
                 break;
                }
               }
               $167 = (($147) + 21)|0;
               $168 = $167 >> 5;
               $169 = $168 << 5;
               $170 = (($167) - ($169))|0;
               $171 = (($152) + ($168<<2)|0);
               $172 = HEAP32[$171>>2]|0;
               $173 = 1 << $170;
               $174 = $172 & $173;
               $175 = ($174|0)==(0);
               do {
                if ($175) {
                 $176 = (($147) + 213)|0;
                 $177 = $176 >> 5;
                 $178 = $177 << 5;
                 $179 = (($176) - ($178))|0;
                 $180 = (($152) + ($177<<2)|0);
                 $181 = HEAP32[$180>>2]|0;
                 $182 = 1 << $179;
                 $183 = $181 & $182;
                 $184 = ($183|0)==(0);
                 if (!($184)) {
                  $436 = $215;$437 = $213;$438 = $223;
                  break;
                 }
                 $185 = (($147) + 74)|0;
                 $186 = $185 >> 5;
                 $187 = $186 << 5;
                 $188 = (($185) - ($187))|0;
                 $189 = (($152) + ($186<<2)|0);
                 $190 = HEAP32[$189>>2]|0;
                 $191 = 1 << $188;
                 $192 = $190 & $191;
                 $193 = ($192|0)==(0);
                 if (!($193)) {
                  $436 = $215;$437 = $213;$438 = $223;
                  break;
                 }
                 $194 = (($147) + 27)|0;
                 $195 = $194 >> 5;
                 $196 = $195 << 5;
                 $197 = (($194) - ($196))|0;
                 $198 = (($152) + ($195<<2)|0);
                 $199 = HEAP32[$198>>2]|0;
                 $200 = 1 << $197;
                 $201 = $199 & $200;
                 $202 = ($201|0)==(0);
                 if (!($202)) {
                  $436 = $215;$437 = $213;$438 = $223;
                  break;
                 }
                 $203 = (($147) + 43)|0;
                 $204 = $203 >> 5;
                 $205 = $204 << 5;
                 $206 = (($203) - ($205))|0;
                 $207 = (($152) + ($204<<2)|0);
                 $208 = HEAP32[$207>>2]|0;
                 $209 = 1 << $206;
                 $210 = $208 & $209;
                 $211 = ($210|0)==(0);
                 if (!($211)) {
                  $436 = $215;$437 = $213;$438 = $223;
                  break;
                 }
                 $212 = (($213) + 1)|0;
                 $214 = $215 & 2147483647;
                 $216 = ($212>>>0)>($214>>>0);
                 do {
                  if ($216) {
                   $217 = $215 << 1;
                   $218 = ($217|0)==(0);
                   $219 = $218 ? 1 : $217;
                   $220 = ($214>>>0)<($219>>>0);
                   if (!($220)) {
                    $233 = $223;$439 = $215;
                    break;
                   }
                   $221 = ($215|0)>(-1);
                   if ($221) {
                    $222 = $219 << 2;
                    HEAP32[$3>>2] = $80;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$3+0>>2]|0;
                    $224 = (invoke_iiiiiiii(108,($223|0),($222|0),4,($$byval_copy31|0),0,(622936|0),370)|0);
                    $225 = __THREW__; __THREW__ = 0;
                    $226 = $225&1;
                    if ($226) {
                     $427 = $237;$428 = $219;$429 = $223;
                     break L40;
                    }
                    $233 = $224;$439 = $219;
                    break;
                   } else {
                    $227 = $219 << 2;
                    HEAP32[$4>>2] = $80;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$4+0>>2]|0;
                    $228 = (invoke_iiiiiii(102,($227|0),4,($$byval_copy31|0),0,(622936|0),352)|0);
                    $229 = __THREW__; __THREW__ = 0;
                    $230 = $229&1;
                    if ($230) {
                     $427 = $237;$428 = $215;$429 = $223;
                     break L40;
                    }
                    $231 = $212 << 2;
                    _memcpy(($228|0),($223|0),($231|0))|0;
                    $233 = $228;$439 = $219;
                    break;
                   }
                  } else {
                   $233 = $223;$439 = $215;
                  }
                 } while(0);
                 $232 = (($233) + ($213<<2)|0);
                 HEAP32[$232>>2] = $234;
                 $436 = $439;$437 = $212;$438 = $233;
                } else {
                 $436 = $215;$437 = $213;$438 = $223;
                }
               } while(0);
               $235 = (($234) + 1)|0;
               $236 = $237 & 2147483647;
               $238 = ($235>>>0)>($236>>>0);
               do {
                if ($238) {
                 $239 = $237 << 1;
                 $240 = ($239|0)==(0);
                 $241 = $240 ? 1 : $239;
                 $242 = ($236>>>0)<($241>>>0);
                 if (!($242)) {
                  $255 = $245;$440 = $237;
                  break;
                 }
                 $243 = ($237|0)>(-1);
                 if ($243) {
                  $244 = $241 << 3;
                  HEAP32[$5>>2] = $80;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$5+0>>2]|0;
                  $246 = (invoke_iiiiiiii(108,($245|0),($244|0),8,($$byval_copy31|0),0,(622936|0),370)|0);
                  $247 = __THREW__; __THREW__ = 0;
                  $248 = $247&1;
                  if ($248) {
                   $427 = $241;$428 = $436;$429 = $438;
                   break L40;
                  }
                  $255 = $246;$440 = $241;
                  break;
                 } else {
                  $249 = $241 << 3;
                  HEAP32[$6>>2] = $80;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$6+0>>2]|0;
                  $250 = (invoke_iiiiiii(102,($249|0),8,($$byval_copy31|0),0,(622936|0),352)|0);
                  $251 = __THREW__; __THREW__ = 0;
                  $252 = $251&1;
                  if ($252) {
                   $427 = $237;$428 = $436;$429 = $438;
                   break L40;
                  }
                  $253 = $235 << 3;
                  _memcpy(($250|0),($245|0),($253|0))|0;
                  $255 = $250;$440 = $241;
                  break;
                 }
                } else {
                 $255 = $245;$440 = $237;
                }
               } while(0);
               $254 = (($255) + ($234<<3)|0);
               $256 = $254;
               $257 = $256;
               HEAP32[$257>>2] = $139;
               $258 = (($256) + 4)|0;
               $259 = $258;
               HEAP32[$259>>2] = $142;
               $$pre$i = HEAP32[$100>>2]|0;
               $262 = $$pre$i;$430 = $440;$431 = $235;$432 = $255;$433 = $436;$434 = $437;$435 = $438;
              } else {
               $262 = $418;$430 = $237;$431 = $234;$432 = $245;$433 = $215;$434 = $213;$435 = $223;
              }
             } while(0);
             $260 = (($i1$025$i) + 1)|0;
             $261 = ($260>>>0)<($262>>>0);
             if ($261) {
              $213 = $434;$215 = $433;$223 = $435;$234 = $431;$237 = $430;$245 = $432;$418 = $262;$i1$025$i = $260;
             } else {
              $412 = $430;$413 = $431;$414 = $432;$415 = $433;$416 = $434;$417 = $435;
              break L34;
             }
            }
            $125 = ___cxa_find_matching_catch()|0;
            $126 = tempRet0;
            $423 = $427;$424 = $245;$425 = $428;$426 = $429;$lpad$phi$i$index = $125;$lpad$phi$i$index2 = $126;
            label = 33;
            break L31;
           }
          }
         }
        } while(0);
        __THREW__ = 0;
        $263 = (invoke_i(57)|0);
        $264 = __THREW__; __THREW__ = 0;
        $265 = $264&1;
        if ($265) {
         $408 = $412;$409 = $414;$410 = $415;$411 = $417;
         label = 32;
        } else {
         __THREW__ = 0;
         invoke_vi(3383,($263|0));
         $266 = __THREW__; __THREW__ = 0;
         $267 = $266&1;
         if ($267) {
          $408 = $412;$409 = $414;$410 = $415;$411 = $417;
          label = 32;
         } else {
          $268 = HEAP32[$104>>2]|0;
          $269 = ($268|0)>(-1);
          do {
           if ($269) {
            $270 = HEAP32[$classIDs$i>>2]|0;
            $271 = HEAP32[$102>>2]|0;
            HEAP32[$7>>2] = $271;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$7+0>>2]|0;
            invoke_vii(2591,($270|0),($$byval_copy31|0));
            $272 = __THREW__; __THREW__ = 0;
            $273 = $272&1;
            if ($273) {
             $123 = ___cxa_find_matching_catch()|0;
             $124 = tempRet0;
             $$0$i19 = $123;$$01$i = $124;$419 = $412;$420 = $414;$421 = $415;$422 = $417;
             break L31;
            } else {
             HEAP32[$classIDs$i>>2] = 0;
             break;
            }
           }
          } while(0);
          $274 = HEAP32[$101>>2]|0;
          $275 = ($274|0)>(-1);
          if (!($275)) {
           $295 = $413;$325 = $414;$331 = $416;$337 = $417;$382 = $415;$386 = $412;
           label = 77;
           break L27;
          }
          $276 = HEAP32[$sourceFileIDs$i>>2]|0;
          $277 = HEAP32[$99>>2]|0;
          HEAP32[$10>>2] = $277;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$10+0>>2]|0;
          invoke_vii(2591,($276|0),($$byval_copy31|0));
          $278 = __THREW__; __THREW__ = 0;
          $279 = $278&1;
          if ($279) {
           $404 = $412;$405 = $414;$406 = $415;$407 = $417;
           label = 75;
           break L27;
          }
          HEAP32[$sourceFileIDs$i>>2] = 0;
          $295 = $413;$325 = $414;$331 = $416;$337 = $417;$382 = $415;$386 = $412;
          label = 77;
          break L27;
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 32) {
      $127 = ___cxa_find_matching_catch()|0;
      $128 = tempRet0;
      $423 = $408;$424 = $409;$425 = $410;$426 = $411;$lpad$phi$i$index = $127;$lpad$phi$i$index2 = $128;
      label = 33;
     }
     do {
      if ((label|0) == 33) {
       $129 = HEAP32[$104>>2]|0;
       $130 = ($129|0)>(-1);
       if ($130) {
        $131 = HEAP32[$classIDs$i>>2]|0;
        $132 = HEAP32[$102>>2]|0;
        HEAP32[$0>>2] = $132;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($131|0),($$byval_copy31|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         $286 = ___cxa_find_matching_catch(0|0)|0;
         $287 = tempRet0;
         ___clang_call_terminate($286);
         // unreachable;
        } else {
         HEAP32[$classIDs$i>>2] = 0;
         $$0$i19 = $lpad$phi$i$index;$$01$i = $lpad$phi$i$index2;$419 = $423;$420 = $424;$421 = $425;$422 = $426;
         break;
        }
       } else {
        $$0$i19 = $lpad$phi$i$index;$$01$i = $lpad$phi$i$index2;$419 = $423;$420 = $424;$421 = $425;$422 = $426;
       }
      }
     } while(0);
     $280 = HEAP32[$101>>2]|0;
     $281 = ($280|0)>(-1);
     do {
      if ($281) {
       $282 = HEAP32[$sourceFileIDs$i>>2]|0;
       $283 = HEAP32[$99>>2]|0;
       HEAP32[$1>>2] = $283;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($282|0),($$byval_copy31|0));
       $284 = __THREW__; __THREW__ = 0;
       $285 = $284&1;
       if ($285) {
        $286 = ___cxa_find_matching_catch(0|0)|0;
        $287 = tempRet0;
        ___clang_call_terminate($286);
        // unreachable;
       } else {
        HEAP32[$sourceFileIDs$i>>2] = 0;
        break;
       }
      }
     } while(0);
     $441 = $419;$442 = $420;$443 = $421;$444 = $422;$eh$lpad$body$index7Z2D = $$01$i;$eh$lpad$body$indexZ2D = $$0$i19;
     label = 76;
    }
   }
  }
 } while(0);
 L100: do {
  if ((label|0) == 77) {
   $292 = (($this) + 80|0);
   $293 = HEAP32[$292>>2]|0;
   $294 = (($293) + ($295))|0;
   $296 = (($this) + 60|0);
   HEAP32[$loadProgress>>2] = $296;
   $297 = (($loadProgress) + 4|0);
   HEAPF32[$297>>2] = Math_fround(0.899999976158142089843);
   $298 = (($loadProgress) + 8|0);
   $299 = (Math_fround(($294>>>0)));
   HEAPF32[$298>>2] = $299;
   $300 = (($loadProgress) + 12|0);
   HEAPF32[$300>>2] = Math_fround(0.0);
   $301 = (($loadProgress) + 16|0);
   $302 = (($loadProgress) + 20|0);
   $303 = (($this) + 128|0);
   HEAP32[$302>>2] = 2789;
   HEAP32[$301>>2] = $303;
   __THREW__ = 0;
   $304 = (invoke_i(57)|0);
   $305 = __THREW__; __THREW__ = 0;
   $306 = $305&1;
   if ($306) {
    $404 = $386;$405 = $325;$406 = $382;$407 = $337;
    label = 75;
   } else {
    $307 = (($this) + 72|0);
    $308 = HEAP32[$307>>2]|0;
    $309 = HEAP32[$292>>2]|0;
    __THREW__ = 0;
    invoke_viiii(378,($304|0),($308|0),($309|0),($loadProgress|0));
    $310 = __THREW__; __THREW__ = 0;
    $311 = $310&1;
    if ($311) {
     $404 = $386;$405 = $325;$406 = $382;$407 = $337;
     label = 75;
    } else {
     __THREW__ = 0;
     (invoke_iiiiiiii(111,($17|0),($18|0),(0|0),(0|0),-1,0,($loadProgress|0))|0);
     $312 = __THREW__; __THREW__ = 0;
     $313 = $312&1;
     if ($313) {
      $404 = $386;$405 = $325;$406 = $382;$407 = $337;
      label = 75;
     } else {
      __THREW__ = 0;
      invoke_vii(2790,($17|0),($303|0));
      $314 = __THREW__; __THREW__ = 0;
      $315 = $314&1;
      if ($315) {
       $404 = $386;$405 = $325;$406 = $382;$407 = $337;
       label = 75;
      } else {
       $316 = HEAP32[628512>>2]|0;
       $317 = ($295|0)==(0);
       if ($317) {
        $326 = 0;$378 = 0;
        label = 84;
       } else {
        $318 = $295 << 2;
        HEAP32[$2>>2] = $316;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$2+0>>2]|0;
        $319 = (invoke_iiiiiiii(108,(0|0),($318|0),4,($$byval_copy31|0),0,(622936|0),370)|0);
        $320 = __THREW__; __THREW__ = 0;
        $321 = $320&1;
        if ($321) {
         $447 = $295;$448 = 0;
         label = 90;
        } else {
         $326 = $319;$378 = $295;
         label = 84;
        }
       }
       L109: do {
        if ((label|0) == 84) {
         __THREW__ = 0;
         invoke_vi(3541,($17|0));
         $322 = __THREW__; __THREW__ = 0;
         $323 = $322&1;
         if ($323) {
          $447 = $378;$448 = $326;
          label = 90;
         } else {
          $324 = (($17) + 95|0);
          HEAP8[$324>>0] = 0;
          __THREW__ = 0;
          (invoke_iiiiiiii(111,($17|0),($81|0),($325|0),($326|0),($295|0),1,($loadProgress|0))|0);
          $327 = __THREW__; __THREW__ = 0;
          $328 = $327&1;
          if ($328) {
           $447 = $378;$448 = $326;
           label = 90;
          } else {
           HEAP8[$324>>0] = 0;
           $329 = HEAP32[628512>>2]|0;
           $330 = ($331|0)==(0);
           if ($330) {
            $353 = 0;$374 = 0;
            label = 93;
           } else {
            $332 = $331 << 2;
            HEAP32[$1>>2] = $329;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$1+0>>2]|0;
            $333 = (invoke_iiiiiiii(108,(0|0),($332|0),4,($$byval_copy31|0),0,(622936|0),370)|0);
            $334 = __THREW__; __THREW__ = 0;
            $335 = $334&1;
            if ($335) {
             $348 = $331;$349 = 0;
            } else {
             $i1$053 = 0;
             while(1) {
              $336 = (($337) + ($i1$053<<2)|0);
              $338 = HEAP32[$336>>2]|0;
              $339 = (($326) + ($338<<2)|0);
              $340 = HEAP32[$339>>2]|0;
              $341 = (($333) + ($i1$053<<2)|0);
              HEAP32[$341>>2] = $340;
              $342 = (($i1$053) + 1)|0;
              $exitcond = ($342|0)==($331|0);
              if ($exitcond) {
               $353 = $333;$374 = $331;
               label = 93;
               break;
              } else {
               $i1$053 = $342;
              }
             }
            }
           }
           do {
            if ((label|0) == 93) {
             $352 = (($this) + 156|0);
             __THREW__ = 0;
             invoke_viiii(379,($17|0),($353|0),($331|0),($352|0));
             $354 = __THREW__; __THREW__ = 0;
             $355 = $354&1;
             if ($355) {
              $348 = $374;$349 = $353;
             } else {
              __THREW__ = 0;
              invoke_vii(2790,($17|0),($303|0));
              $356 = __THREW__; __THREW__ = 0;
              $357 = $356&1;
              if ($357) {
               $348 = $374;$349 = $353;
              } else {
               __THREW__ = 0;
               $358 = (invoke_i(57)|0);
               $359 = __THREW__; __THREW__ = 0;
               $360 = $359&1;
               if ($360) {
                $348 = $374;$349 = $353;
               } else {
                __THREW__ = 0;
                $361 = (invoke_iii(2428,($358|0),($81|0))|0);
                $362 = __THREW__; __THREW__ = 0;
                $363 = $362&1;
                if ($363) {
                 $348 = $374;$349 = $353;
                } else {
                 if (!($361)) {
                  __THREW__ = 0;
                  invoke_viii(1785,($358|0),($81|0),1);
                  $364 = __THREW__; __THREW__ = 0;
                  $365 = $364&1;
                  if ($365) {
                   $348 = $374;$349 = $353;
                   break;
                  }
                 }
                 __THREW__ = 0;
                 $366 = (invoke_iii(2428,($358|0),($18|0))|0);
                 $367 = __THREW__; __THREW__ = 0;
                 $368 = $367&1;
                 if ($368) {
                  $348 = $374;$349 = $353;
                  break;
                 }
                 if (!($366)) {
                  __THREW__ = 0;
                  invoke_viii(1785,($358|0),($18|0),1);
                  $369 = __THREW__; __THREW__ = 0;
                  $370 = $369&1;
                  if ($370) {
                   $348 = $374;$349 = $353;
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3383,($17|0));
                 $371 = __THREW__; __THREW__ = 0;
                 $372 = $371&1;
                 if ($372) {
                  $348 = $374;$349 = $353;
                  break;
                 }
                 HEAPF32[$296>>2] = Math_fround(0.899999976158142089843);
                 $373 = ($374|0)>(-1);
                 if ($373) {
                  HEAP32[$11>>2] = $329;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$11+0>>2]|0;
                  invoke_vii(2591,($353|0),($$byval_copy31|0));
                  $375 = __THREW__; __THREW__ = 0;
                  $376 = $375&1;
                  if ($376) {
                   $447 = $378;$448 = $326;
                   label = 90;
                   break L109;
                  }
                 }
                 $377 = ($378|0)>(-1);
                 if ($377) {
                  HEAP32[$12>>2] = $316;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$12+0>>2]|0;
                  invoke_vii(2591,($326|0),($$byval_copy31|0));
                  $379 = __THREW__; __THREW__ = 0;
                  $380 = $379&1;
                  if ($380) {
                   $404 = $386;$405 = $325;$406 = $382;$407 = $337;
                   label = 75;
                   break L100;
                  }
                 }
                 $381 = ($382|0)>(-1);
                 do {
                  if ($381) {
                   HEAP32[$13>>2] = $80;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$13+0>>2]|0;
                   invoke_vii(2591,($337|0),($$byval_copy31|0));
                   $383 = __THREW__; __THREW__ = 0;
                   $384 = $383&1;
                   if (!($384)) {
                    break;
                   }
                   $288 = ___cxa_find_matching_catch()|0;
                   $289 = tempRet0;
                   $$2 = $289;$$23 = $288;$398 = $386;$399 = $325;
                   break L100;
                  }
                 } while(0);
                 $385 = ($386|0)>(-1);
                 if (!($385)) {
                  STACKTOP = sp;return;
                 }
                 HEAP32[$0>>2] = $80;
                 ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
                 __Z19free_alloc_internalPv10MemLabelId($325,$$byval_copy31);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           } while(0);
           $345 = ___cxa_find_matching_catch()|0;
           $346 = tempRet0;
           $347 = ($348|0)>(-1);
           if ($347) {
            HEAP32[$0>>2] = $329;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
            invoke_vii(2591,($349|0),($$byval_copy31|0));
            $350 = __THREW__; __THREW__ = 0;
            $351 = $350&1;
            if ($351) {
             $402 = ___cxa_find_matching_catch(0|0)|0;
             $403 = tempRet0;
             ___clang_call_terminate($402);
             // unreachable;
            } else {
             $$0 = $346;$$01 = $345;$388 = $378;$389 = $326;
            }
           } else {
            $$0 = $346;$$01 = $345;$388 = $378;$389 = $326;
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 90) {
        $343 = ___cxa_find_matching_catch()|0;
        $344 = tempRet0;
        $$0 = $344;$$01 = $343;$388 = $447;$389 = $448;
       }
       $387 = ($388|0)>(-1);
       if ($387) {
        HEAP32[$14>>2] = $316;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$14+0>>2]|0;
        invoke_vii(2591,($389|0),($$byval_copy31|0));
        $390 = __THREW__; __THREW__ = 0;
        $391 = $390&1;
        if ($391) {
         $402 = ___cxa_find_matching_catch(0|0)|0;
         $403 = tempRet0;
         ___clang_call_terminate($402);
         // unreachable;
        } else {
         $$1 = $$0;$$12 = $$01;$393 = $382;$394 = $337;$445 = $386;$446 = $325;
         label = 114;
        }
       } else {
        $$1 = $$0;$$12 = $$01;$393 = $382;$394 = $337;$445 = $386;$446 = $325;
        label = 114;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 75) {
  $290 = ___cxa_find_matching_catch()|0;
  $291 = tempRet0;
  $441 = $404;$442 = $405;$443 = $406;$444 = $407;$eh$lpad$body$index7Z2D = $291;$eh$lpad$body$indexZ2D = $290;
  label = 76;
 }
 if ((label|0) == 76) {
  $$1 = $eh$lpad$body$index7Z2D;$$12 = $eh$lpad$body$indexZ2D;$393 = $443;$394 = $444;$445 = $441;$446 = $442;
  label = 114;
 }
 if ((label|0) == 114) {
  $392 = ($393|0)>(-1);
  if ($392) {
   HEAP32[$15>>2] = $80;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$15+0>>2]|0;
   invoke_vii(2591,($394|0),($$byval_copy31|0));
   $395 = __THREW__; __THREW__ = 0;
   $396 = $395&1;
   if ($396) {
    $402 = ___cxa_find_matching_catch(0|0)|0;
    $403 = tempRet0;
    ___clang_call_terminate($402);
    // unreachable;
   } else {
    $$2 = $$1;$$23 = $$12;$398 = $445;$399 = $446;
   }
  } else {
   $$2 = $$1;$$23 = $$12;$398 = $445;$399 = $446;
  }
 }
 $397 = ($398|0)>(-1);
 if (!($397)) {
  ___resumeException($$23|0);
  // unreachable;
 }
 HEAP32[$16>>2] = $80;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$16+0>>2]|0;
 invoke_vii(2591,($399|0),($$byval_copy31|0));
 $400 = __THREW__; __THREW__ = 0;
 $401 = $400&1;
 if ($401) {
  $402 = ___cxa_find_matching_catch(0|0)|0;
  $403 = tempRet0;
  ___clang_call_terminate($402);
  // unreachable;
 } else {
  ___resumeException($$23|0);
  // unreachable;
 }
}
function __ZN18LoadLevelOperation23GetAllowSceneActivationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN18LoadLevelOperation23SetAllowSceneActivationEb($this,$allow) {
 $this = $this|0;
 $allow = $allow|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = $allow&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN18LoadLevelOperation13CleanupMemoryEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (($this) + 72|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 76|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy1);
  HEAP32[$4>>2] = 0;
 }
 $8 = (($this) + 80|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$1>>2] = 0;
 $9 = (($this) + 156|0);
 __ZN18AwakeFromLoadQueue5ClearEv($9);
 $10 = (($this) + 148|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  HEAP32[$10>>2] = 0;
  STACKTOP = sp;return;
 }
 $buffer$02$i$i = $11;
 while(1) {
  $13 = (($buffer$02$i$i) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($buffer$02$i$i) + 4|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   $18 = HEAP32[$buffer$02$i$i>>2]|0;
   $19 = (($buffer$02$i$i) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[$0>>2] = $20;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($18|0),($$byval_copy1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 8;
    break;
   }
  }
  __ZdlPv($buffer$02$i$i);
  $23 = ($14|0)==(0|0);
  if ($23) {
   label = 9;
   break;
  } else {
   $buffer$02$i$i = $14;
  }
 }
 if ((label|0) == 8) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  __ZdlPv($buffer$02$i$i);
  ___resumeException($24|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  HEAP32[$10>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN18LoadLevelOperation19IntegrateTimeSlicedEi($this,$timeSliceMS) {
 $this = $this|0;
 $timeSliceMS = $timeSliceMS|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = (__ZN27TimeSliceAwakeFromLoadQueue19IntegrateTimeSlicedEi($0,$timeSliceMS)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN18LoadLevelOperation19IntegrateMainThreadEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 0)) {
  $4 = (($this) + 88|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 92|0);
  $7 = (($this) + 156|0);
  __Z25PlayerLoadLevelFromThreadiRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER18AwakeFromLoadQueue($5,$6,$7);
 } else if ((($1|0) == 5) | (($1|0) == 1)) {
  $2 = (($this) + 92|0);
  $3 = (($this) + 156|0);
  __Z21PostLoadLevelAdditiveRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER18AwakeFromLoadQueueN18LoadLevelOperation11LoadingModeE($2,$3,$1);
 } else if ((($1|0) == 2)) {
  $8 = (($this) + 156|0);
  __Z23CompletePreloadMainDataR18AwakeFromLoadQueue($8);
 }
 __ZN18LoadLevelOperation13CleanupMemoryEv($this);
 $9 = (($this) + 60|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN18LoadLevelOperation9LoadLevelERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_iNS_11LoadingModeEb($levelPath,$levelAssetPath,$levelIndex,$mode,$mustCompleteNextFrame) {
 $levelPath = $levelPath|0;
 $levelAssetPath = $levelAssetPath|0;
 $levelIndex = $levelIndex|0;
 $mode = $mode|0;
 $mustCompleteNextFrame = $mustCompleteNextFrame|0;
 var $$0$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($mustCompleteNextFrame) {
  $$0$off0 = 1;
 } else {
  $0 = (__Z16GetBuildSettingsv()|0);
  $1 = (($0) + 93|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = ($2<<24>>24)==(0);
  if ($3) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(622792,0,622936,287,1,0,0,0);
   $$0$off0 = 1;
  } else {
   $$0$off0 = 0;
  }
 }
 $4 = (__Znwj(288)|0);
 __THREW__ = 0;
 invoke_vi(3542,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZdlPv($4);
  ___resumeException($14|0);
  // unreachable;
 }
 $7 = (($4) + 92|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($7,$levelPath)|0);
 $8 = (($4) + 104|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($8,$levelAssetPath)|0);
 $9 = (($4) + 116|0);
 HEAP32[$9>>2] = $mode;
 $10 = (($4) + 88|0);
 HEAP32[$10>>2] = $levelIndex;
 $11 = (($4) + 124|0);
 HEAP8[$11>>0] = $$0$off0;
 $12 = (__Z17GetPreloadManagerv()|0);
 __ZN14PreloadManager10AddToQueueEP23PreloadManagerOperation($12,$4);
 if (!((($mode|0) == 0) | (($mode|0) == 3))) {
  STACKTOP = sp;return ($4|0);
 }
 $13 = (__Z33CreateUnloadUnusedAssetsOperationb(1)|0);
 __ZN14AsyncOperation7ReleaseEv($13);
 STACKTOP = sp;return ($4|0);
}
function __ZN18LoadLevelOperationC2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $buffer$02$i$i$i$i$i = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body8$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy13 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 __ZN23PreloadManagerOperationC2Ev($this);
 HEAP32[$this>>2] = ((622944 + 8|0));
 $4 = (($this) + 72|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 80|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 84|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 76|0);
 HEAP32[$7>>2] = 61;
 $8 = (($this) + 92|0);
 $9 = (($this) + 104|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;
 $10 = HEAP32[628360>>2]|0;
 $11 = (($this) + 128|0);
 HEAP32[$11>>2] = -1;
 $12 = (($this) + 132|0);
 HEAP32[$12>>2] = 4096;
 $13 = (($this) + 136|0);
 HEAP32[$13>>2] = $10;
 __THREW__ = 0;
 $14 = (invoke_ii(2988,28)|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 do {
  if ($16) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   $eh$lpad$body$index2Z2D = $45;$eh$lpad$body$indexZ2D = $44;
   label = 7;
  } else {
   $17 = (($14) + 16|0);
   HEAP32[$17>>2] = 0;
   $18 = (($14) + 20|0);
   HEAP32[$18>>2] = 0;
   $19 = (($14) + 12|0);
   HEAP32[$19>>2] = 4096;
   HEAP32[$1>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
   $20 = (invoke_iiiiiii(102,4096,16,($$byval_copy13|0),0,(622936|0),112)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    __ZdlPv($14);
    $eh$lpad$body$index2Z2D = $24;$eh$lpad$body$indexZ2D = $23;
    label = 7;
    break;
   }
   HEAP32[$14>>2] = $20;
   $25 = (($14) + 4|0);
   HEAP8[$25>>0] = 1;
   $26 = (($14) + 8|0);
   HEAP32[$26>>2] = $10;
   $27 = (($14) + 24|0);
   HEAP32[$27>>2] = 0;
   $28 = (($this) + 148|0);
   HEAP32[$28>>2] = $14;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($this) + 152|0);
   HEAP32[$30>>2] = $29;
   $31 = HEAP32[$28>>2]|0;
   $32 = (($31) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($this) + 140|0);
   HEAP32[$34>>2] = $33;
   $35 = (($this) + 144|0);
   HEAP32[$35>>2] = 0;
   $36 = (($this) + 156|0);
   $37 = HEAP32[628360>>2]|0;
   HEAP32[$3>>2] = $37;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2791,($36|0),($$byval_copy13|0));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    $40 = (($this) + 88|0);
    HEAP32[$40>>2] = -1;
    $41 = (($this) + 124|0);
    HEAP8[$41>>0] = 0;
    $42 = (($this) + 68|0);
    HEAP8[$42>>0] = 1;
    $43 = (($this) + 120|0);
    HEAP32[$43>>2] = 42;
    STACKTOP = sp;return;
   }
   $46 = ___cxa_find_matching_catch()|0;
   $47 = tempRet0;
   $48 = HEAP32[$28>>2]|0;
   $49 = ($48|0)==(0|0);
   L9: do {
    if (!($49)) {
     $buffer$02$i$i$i$i$i = $48;
     while(1) {
      $50 = (($buffer$02$i$i$i$i$i) + 24|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = (($buffer$02$i$i$i$i$i) + 4|0);
      $53 = HEAP8[$52>>0]|0;
      $54 = ($53<<24>>24)==(0);
      if (!($54)) {
       $55 = HEAP32[$buffer$02$i$i$i$i$i>>2]|0;
       $56 = (($buffer$02$i$i$i$i$i) + 8|0);
       $57 = HEAP32[$56>>2]|0;
       HEAP32[$0>>2] = $57;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($55|0),($$byval_copy13|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
      }
      __ZdlPv($buffer$02$i$i$i$i$i);
      $60 = ($51|0)==(0|0);
      if ($60) {
       break L9;
      } else {
       $buffer$02$i$i$i$i$i = $51;
      }
     }
     $61 = ___cxa_find_matching_catch(0|0)|0;
     $62 = tempRet0;
     __ZdlPv($buffer$02$i$i$i$i$i);
     $eh$lpad$body8$indexZ2D = $61;
     ___clang_call_terminate($eh$lpad$body8$indexZ2D);
     // unreachable;
    }
   } while(0);
   HEAP32[$28>>2] = 0;
   $$0 = $47;$$01 = $46;
  }
 } while(0);
 if ((label|0) == 7) {
  $$0 = $eh$lpad$body$index2Z2D;$$01 = $eh$lpad$body$indexZ2D;
 }
 $63 = HEAP8[$9>>0]|0;
 $64 = $63 & 1;
 $65 = ($64<<24>>24)==(0);
 if (!($65)) {
  $66 = (($this) + 112|0);
  $67 = HEAP32[$66>>2]|0;
  __ZdlPv($67);
 }
 $68 = HEAP8[$8>>0]|0;
 $69 = $68 & 1;
 $70 = ($69<<24>>24)==(0);
 if (!($70)) {
  $71 = (($this) + 100|0);
  $72 = HEAP32[$71>>2]|0;
  __ZdlPv($72);
 }
 $73 = HEAP32[$6>>2]|0;
 $74 = ($73|0)>(-1);
 if ($74) {
  $75 = HEAP32[$4>>2]|0;
  $76 = HEAP32[$7>>2]|0;
  HEAP32[$2>>2] = $76;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($75|0),($$byval_copy13|0));
  $77 = __THREW__; __THREW__ = 0;
  $78 = $77&1;
  if (!($78)) {
   HEAP32[$4>>2] = 0;
   label = 22;
  }
 } else {
  label = 22;
 }
 if ((label|0) == 22) {
  __THREW__ = 0;
  invoke_vi(1113,($this|0));
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if (!($80)) {
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $81 = ___cxa_find_matching_catch(0|0)|0;
 $82 = tempRet0;
 $eh$lpad$body8$indexZ2D = $81;
 ___clang_call_terminate($eh$lpad$body8$indexZ2D);
 // unreachable;
}
function __ZN18LoadLevelOperationD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1124,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN18LoadLevelOperationD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$3 = 0, $$34 = 0, $$byval_copy10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer$02$i$i$i$i$i = 0;
 var $buffer$02$i$i$i$i$i9 = 0, $eh$lpad$body11$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 HEAP32[$this>>2] = ((622944 + 8|0));
 $5 = (($this) + 156|0);
 $6 = (($this) + 284|0);
 $8 = $6;
 while(1) {
  $7 = (($8) + -16|0);
  $9 = (($8) + -4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)>(-1);
  if ($11) {
   $12 = HEAP32[$7>>2]|0;
   $13 = (($8) + -12|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$4>>2] = $14;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($12|0),($$byval_copy10|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
   HEAP32[$7>>2] = 0;
  }
  $17 = ($7|0)==($5|0);
  if ($17) {
   label = 13;
   break;
  } else {
   $8 = $7;
  }
 }
 L7: do {
  if ((label|0) == 6) {
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   $20 = ($5|0)==($7|0);
   L32: do {
    if (!($20)) {
     $22 = $7;
     while(1) {
      $21 = (($22) + -16|0);
      $23 = (($22) + -4|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24|0)>(-1);
      if ($25) {
       $26 = HEAP32[$21>>2]|0;
       $27 = (($22) + -12|0);
       $28 = HEAP32[$27>>2]|0;
       HEAP32[$0>>2] = $28;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($26|0),($$byval_copy10|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       HEAP32[$21>>2] = 0;
      }
      $31 = ($21|0)==($5|0);
      if ($31) {
       break L32;
      } else {
       $22 = $21;
      }
     }
     $32 = ___cxa_find_matching_catch(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    }
   } while(0);
   $69 = (($this) + 148|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==(0|0);
   L42: do {
    if (!($71)) {
     $buffer$02$i$i$i$i$i9 = $70;
     while(1) {
      $72 = (($buffer$02$i$i$i$i$i9) + 24|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($buffer$02$i$i$i$i$i9) + 4|0);
      $75 = HEAP8[$74>>0]|0;
      $76 = ($75<<24>>24)==(0);
      if (!($76)) {
       $77 = HEAP32[$buffer$02$i$i$i$i$i9>>2]|0;
       $78 = (($buffer$02$i$i$i$i$i9) + 8|0);
       $79 = HEAP32[$78>>2]|0;
       HEAP32[$1>>2] = $79;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($77|0),($$byval_copy10|0));
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
      }
      __ZdlPv($buffer$02$i$i$i$i$i9);
      $82 = ($73|0)==(0|0);
      if ($82) {
       break L42;
      } else {
       $buffer$02$i$i$i$i$i9 = $73;
      }
     }
     $83 = ___cxa_find_matching_catch(0|0)|0;
     $84 = tempRet0;
     __ZdlPv($buffer$02$i$i$i$i$i9);
     $eh$lpad$body11$indexZ2D = $83;
     ___clang_call_terminate($eh$lpad$body11$indexZ2D);
     // unreachable;
    }
   } while(0);
   HEAP32[$69>>2] = 0;
   $$0 = $19;$$01 = $18;
   label = 34;
  }
  else if ((label|0) == 13) {
   $34 = (($this) + 148|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   L9: do {
    if (!($36)) {
     $buffer$02$i$i$i$i$i = $35;
     while(1) {
      $37 = (($buffer$02$i$i$i$i$i) + 24|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($buffer$02$i$i$i$i$i) + 4|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = ($40<<24>>24)==(0);
      if (!($41)) {
       $42 = HEAP32[$buffer$02$i$i$i$i$i>>2]|0;
       $43 = (($buffer$02$i$i$i$i$i) + 8|0);
       $44 = HEAP32[$43>>2]|0;
       HEAP32[$3>>2] = $44;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy10|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
      }
      __ZdlPv($buffer$02$i$i$i$i$i);
      $47 = ($38|0)==(0|0);
      if ($47) {
       break L9;
      } else {
       $buffer$02$i$i$i$i$i = $38;
      }
     }
     $85 = ___cxa_find_matching_catch()|0;
     $86 = tempRet0;
     __ZdlPv($buffer$02$i$i$i$i$i);
     $$0 = $86;$$01 = $85;
     label = 34;
     break L7;
    }
   } while(0);
   HEAP32[$34>>2] = 0;
   $48 = (($this) + 104|0);
   $49 = HEAP8[$48>>0]|0;
   $50 = $49 & 1;
   $51 = ($50<<24>>24)==(0);
   if (!($51)) {
    $52 = (($this) + 112|0);
    $53 = HEAP32[$52>>2]|0;
    __ZdlPv($53);
   }
   $54 = (($this) + 92|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55 & 1;
   $57 = ($56<<24>>24)==(0);
   if (!($57)) {
    $58 = (($this) + 100|0);
    $59 = HEAP32[$58>>2]|0;
    __ZdlPv($59);
   }
   $60 = (($this) + 84|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)>(-1);
   if (!($62)) {
    __ZN14AsyncOperationD2Ev($this);
    STACKTOP = sp;return;
   }
   $63 = (($this) + 72|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($this) + 76|0);
   $66 = HEAP32[$65>>2]|0;
   HEAP32[$2>>2] = $66;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy10|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $99 = ___cxa_find_matching_catch()|0;
    $100 = tempRet0;
    $$3 = $100;$$34 = $99;
    label = 42;
    break;
   }
   HEAP32[$63>>2] = 0;
   __ZN14AsyncOperationD2Ev($this);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 34) {
  $87 = (($this) + 104|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = $88 & 1;
  $90 = ($89<<24>>24)==(0);
  if (!($90)) {
   $91 = (($this) + 112|0);
   $92 = HEAP32[$91>>2]|0;
   __ZdlPv($92);
  }
  $93 = (($this) + 92|0);
  $94 = HEAP8[$93>>0]|0;
  $95 = $94 & 1;
  $96 = ($95<<24>>24)==(0);
  if (!($96)) {
   $97 = (($this) + 100|0);
   $98 = HEAP32[$97>>2]|0;
   __ZdlPv($98);
  }
  $101 = (($this) + 84|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)>(-1);
  if ($103) {
   $104 = (($this) + 72|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($this) + 76|0);
   $107 = HEAP32[$106>>2]|0;
   HEAP32[$0>>2] = $107;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($105|0),($$byval_copy10|0));
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if (!($109)) {
    HEAP32[$104>>2] = 0;
    $$3 = $$0;$$34 = $$01;
    label = 42;
   }
  } else {
   $$3 = $$0;$$34 = $$01;
   label = 42;
  }
 }
 if ((label|0) == 42) {
  __THREW__ = 0;
  invoke_vi(1113,($this|0));
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if (!($111)) {
   ___resumeException($$34|0);
   // unreachable;
  }
 }
 $112 = ___cxa_find_matching_catch(0|0)|0;
 $113 = tempRet0;
 $eh$lpad$body11$indexZ2D = $112;
 ___clang_call_terminate($eh$lpad$body11$indexZ2D);
 // unreachable;
}
function __ZN18LoadLevelOperation21MustCompleteNextFrameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN19RingbufferTemplates17WriteToRingBufferIi17GrowingRingbufferEEbRT0_RKT_($ringbuffer,$data) {
 $ringbuffer = $ringbuffer|0;
 $data = $data|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $phitmp$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$ringbuffer>>2]|0;
 $2 = (($ringbuffer) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($3))|0;
 $5 = ($4>>>0)<(4);
 $6 = $5 ? $4 : 4;
 $7 = (($ringbuffer) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$9>>2]|0;
 $14 = (($8) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($12) - ($13))|0;
 $17 = (($16) + ($15))|0;
 $18 = (($12) + -1)|0;
 $19 = $18 & $10;
 $20 = (($12) - ($19))|0;
 $21 = ($20>>>0)<($17>>>0);
 $22 = $21 ? $20 : $17;
 $23 = ($22>>>0)<($6>>>0);
 $24 = $23 ? $22 : $6;
 $25 = ($24|0)==(4);
 if (!($25)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = HEAP32[$8>>2]|0;
 $27 = (($26) + ($19)|0);
 $28 = HEAP32[$data>>2]|0;
 HEAP32[$27>>2] = $28;
 $29 = HEAP32[$7>>2]|0;
 $30 = (($29) + 20|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 4)|0;
 HEAP32[$30>>2] = $32;
 $33 = HEAP32[$30>>2]|0;
 $34 = HEAP32[$2>>2]|0;
 $35 = (($34) + 4)|0;
 HEAP32[$2>>2] = $35;
 $36 = HEAP32[$2>>2]|0;
 $37 = HEAP32[$7>>2]|0;
 $38 = (($37) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($37) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($39) - ($41))|0;
 $45 = (0 - ($43))|0;
 $46 = ($44|0)==($45|0);
 if (!($46)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $47 = HEAP32[$ringbuffer>>2]|0;
 $48 = HEAP32[$2>>2]|0;
 $49 = ($47|0)==($48|0);
 if ($49) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $50 = (__Znwj(28)|0);
 $51 = (($ringbuffer) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($ringbuffer) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($50) + 16|0);
 HEAP32[$55>>2] = 0;
 $56 = (($50) + 20|0);
 HEAP32[$56>>2] = 0;
 $57 = $54 << 1;
 $58 = (($57) + -1)|0;
 $59 = (_llvm_ctlz_i32(($58|0))|0);
 $phitmp$i$i$i$i$i = (31 - ($59))|0;
 $60 = 1 << $phitmp$i$i$i$i$i;
 $61 = (($50) + 12|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$0>>2] = $52;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $62 = (invoke_iiiiiii(102,($60|0),16,($$byval_copy|0),0,(622936|0),112)|0);
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $74 = ___cxa_find_matching_catch()|0;
  $75 = tempRet0;
  __ZdlPv($50);
  ___resumeException($74|0);
  // unreachable;
 }
 HEAP32[$50>>2] = $62;
 $65 = (($50) + 4|0);
 HEAP8[$65>>0] = 1;
 $66 = (($50) + 8|0);
 HEAP32[$66>>2] = $52;
 $67 = (($50) + 24|0);
 HEAP32[$67>>2] = 0;
 $68 = HEAP32[$7>>2]|0;
 $69 = (($68) + 24|0);
 HEAP32[$69>>2] = $50;
 HEAP32[$7>>2] = $50;
 $70 = HEAP32[$61>>2]|0;
 $71 = HEAP32[$53>>2]|0;
 $72 = (($71) + ($70))|0;
 HEAP32[$53>>2] = $72;
 $73 = HEAP32[$53>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z33CreateUnloadUnusedAssetsOperationb($includeMonoReferencesAsRoots) {
 $includeMonoReferencesAsRoots = $includeMonoReferencesAsRoots|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_vi(3543,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZdlPv($0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  HEAP32[$0>>2] = ((623008 + 8|0));
  $3 = (($0) + 68|0);
  $4 = $includeMonoReferencesAsRoots&1;
  HEAP8[$3>>0] = $4;
  $5 = (__Z17GetPreloadManagerv()|0);
  __ZN14PreloadManager10AddToQueueEP23PreloadManagerOperation($5,$0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN27UnloadUnusedAssetsOperation7PerformEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20GetPersistentManagerv()|0);
 __ZN17PersistentManager21UnloadNonDirtyStreamsEv($0);
 STACKTOP = sp;return;
}
function __ZN27UnloadUnusedAssetsOperation19IntegrateMainThreadEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __Z26GarbageCollectSharedAssetsb($2);
 $3 = (($this) + 60|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN27UnloadUnusedAssetsOperationD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14AsyncOperationD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN27UnloadUnusedAssetsOperationD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1113,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK27UnloadUnusedAssetsOperation25GetAllowParallelExecutionEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN14PlayerSettingsC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$0 = 0, $$01 = 0, $$byval_copy23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, $this2$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy23 = sp + 56|0;
 $0 = sp + 52|0;
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = sp + 36|0;
 $5 = sp + 32|0;
 $6 = sp + 16|0;
 $7 = sp + 12|0;
 $8 = sp + 8|0;
 $9 = sp + 4|0;
 $10 = sp;
 $11 = sp + 20|0;
 $12 = HEAP32[$label>>2]|0;
 HEAP32[$10>>2] = $12;
 ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$10+0>>2]|0;
 __ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy23,$mode);
 HEAP32[$this>>2] = ((623072 + 8|0));
 $13 = (($this) + 24|0);
 $14 = (($this) + 36|0);
 $15 = (($this) + 48|0);
 $this2$i$i$i = (($this) + 120|0);
 dest=$13+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP8[$this2$i$i$i+0>>0]=1|0;HEAP8[$this2$i$i$i+1>>0]=1|0;HEAP8[$this2$i$i$i+2>>0]=1|0;HEAP8[$this2$i$i$i+3>>0]=1|0;HEAP8[$this2$i$i$i+4>>0]=1|0;
 $16 = (($this) + 128|0);
 HEAP32[$16>>2] = 1;
 $17 = (($this) + 132|0);
 HEAP32[$17>>2] = 1;
 $18 = (($this) + 136|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 140|0);
 HEAP8[$19>>0] = 1;
 $20 = (($this) + 141|0);
 HEAP8[$20>>0] = 0;
 $21 = (($this) + 142|0);
 HEAP8[$21>>0] = 1;
 $22 = (($this) + 143|0);
 HEAP8[$22>>0] = 0;
 $23 = (($this) + 204|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 220|0);
 $25 = (($this) + 232|0);
 $26 = (($this) + 244|0);
 $27 = (($this) + 256|0);
 $28 = (($this) + 268|0);
 $29 = (($this) + 276|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 280|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 272|0);
 dest=$24+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$31>>2] = 61;
 HEAP32[$8>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$8+0>>2]|0;
 $32 = (invoke_iiiiiii(102,32,16,($$byval_copy23|0),0,(623368|0),79)|0);
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 do {
  if ($34) {
   $89 = ___cxa_find_matching_catch()|0;
   $90 = tempRet0;
   $$0 = $90;$$01 = $89;
  } else {
   $35 = (($11) + 8|0);
   HEAP32[$35>>2] = $32;
   HEAP32[$11>>2] = 33;
   $36 = (($11) + 4|0);
   HEAP32[$36>>2] = 23;
   dest=$32+0|0; src=623184+0|0; stop=dest+23|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $37 = (($32) + 23|0);
   HEAP8[$37>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($26|0),($11|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    $91 = ___cxa_find_matching_catch()|0;
    $92 = tempRet0;
    $93 = HEAP8[$11>>0]|0;
    $94 = $93 & 1;
    $95 = ($94<<24>>24)==(0);
    if ($95) {
     $$0 = $92;$$01 = $91;
     break;
    }
    $96 = HEAP32[$35>>2]|0;
    HEAP32[$7>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$7+0>>2]|0;
    invoke_vii(2591,($96|0),($$byval_copy23|0));
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if (!($98)) {
     $$0 = $92;$$01 = $91;
     break;
    }
    $99 = ___cxa_find_matching_catch()|0;
    $100 = tempRet0;
    ___cxa_call_unexpected(($99|0));
    // unreachable;
   }
   $40 = HEAP8[$11>>0]|0;
   $41 = $40 & 1;
   $42 = ($41<<24>>24)==(0);
   if (!($42)) {
    $43 = HEAP32[$35>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($43|0),($$byval_copy23|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     $46 = ___cxa_find_matching_catch()|0;
     $47 = tempRet0;
     ___cxa_call_unexpected(($46|0));
     // unreachable;
    }
   }
   $48 = (($this) + 163|0);
   HEAP8[$48>>0] = 1;
   $49 = (($this) + 164|0);
   HEAP8[$49>>0] = 1;
   $50 = (($this) + 116|0);
   HEAP32[$50>>2] = 1;
   $51 = (($this) + 100|0);
   HEAP32[$51>>2] = 1024;
   $52 = (($this) + 104|0);
   HEAP32[$52>>2] = 768;
   $53 = (($this) + 108|0);
   HEAP32[$53>>2] = 960;
   $54 = (($this) + 112|0);
   HEAP32[$54>>2] = 600;
   $55 = (($this) + 200|0);
   HEAP32[$55>>2] = 0;
   $56 = (($this) + 72|0);
   HEAP8[$56>>0] = 0;
   $57 = (($this) + 76|0);
   HEAP32[$57>>2] = 4;
   $58 = (($this) + 156|0);
   $59 = (($this) + 162|0);
   ;HEAP8[$58+0>>0]=1|0;HEAP8[$58+1>>0]=1|0;HEAP8[$58+2>>0]=1|0;HEAP8[$58+3>>0]=1|0;HEAP8[$58+4>>0]=1|0;HEAP8[$58+5>>0]=1|0;
   HEAP8[$59>>0] = 0;
   $60 = (($this) + 148|0);
   HEAP32[$60>>2] = -1;
   $61 = (($this) + 144|0);
   HEAP32[$61>>2] = -1;
   $62 = (($this) + 152|0);
   HEAP32[$62>>2] = 0;
   $63 = (($this) + 165|0);
   HEAP8[$63>>0] = 0;
   $64 = (($this) + 166|0);
   HEAP8[$64>>0] = 0;
   $65 = (($this) + 80|0);
   HEAP32[$65>>2] = 2;
   $66 = (($this) + 84|0);
   HEAP32[$66>>2] = -1;
   $67 = (($this) + 88|0);
   HEAP32[$67>>2] = -1;
   $68 = (($this) + 92|0);
   HEAP32[$68>>2] = 0;
   $69 = (($this) + 96|0);
   HEAP32[$69>>2] = 60;
   $70 = (($this) + 167|0);
   HEAP8[$70>>0] = 0;
   $71 = (($this) + 168|0);
   HEAP8[$71>>0] = 0;
   $72 = (($this) + 169|0);
   HEAP8[$72>>0] = 1;
   $73 = (($this) + 170|0);
   HEAP8[$73>>0] = 1;
   $74 = (($this) + 171|0);
   HEAP8[$74>>0] = 0;
   $75 = (($this) + 180|0);
   HEAP8[$75>>0] = 0;
   $76 = (($this) + 181|0);
   HEAP8[$76>>0] = 0;
   $77 = (($this) + 172|0);
   HEAP8[$77>>0] = 0;
   $78 = (($this) + 176|0);
   HEAP32[$78>>2] = 2;
   $79 = (($this) + 173|0);
   HEAP8[$79>>0] = 0;
   $80 = (($this) + 182|0);
   $81 = (($this) + 188|0);
   $82 = (($this) + 196|0);
   HEAP32[$82>>2] = 0;
   $83 = (($this) + 208|0);
   HEAP32[$83>>2] = 0;
   $84 = (($this) + 284|0);
   HEAP8[$84>>0] = 0;
   $85 = (($this) + 285|0);
   HEAP8[$85>>0] = 0;
   $86 = (($this) + 286|0);
   HEAP8[$86>>0] = 0;
   $87 = (($this) + 212|0);
   HEAP32[$87>>2] = 0;
   $88 = (($this) + 216|0);
   ;HEAP8[$80+0>>0]=0|0;HEAP8[$80+1>>0]=0|0;HEAP8[$80+2>>0]=0|0;HEAP8[$80+3>>0]=0|0;HEAP8[$80+4>>0]=0|0;
   ;HEAP32[$81+0>>2]=0|0;HEAP16[$81+4>>1]=0|0;HEAP8[$81+6>>0]=0|0;
   HEAP8[$88>>0] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 $101 = HEAP32[$30>>2]|0;
 $102 = ($101|0)>(-1);
 if ($102) {
  $103 = HEAP32[$28>>2]|0;
  $104 = HEAP32[$31>>2]|0;
  HEAP32[$6>>2] = $104;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$6+0>>2]|0;
  invoke_vii(2591,($103|0),($$byval_copy23|0));
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if (!($106)) {
   HEAP32[$28>>2] = 0;
   label = 14;
  }
 } else {
  label = 14;
 }
 do {
  if ((label|0) == 14) {
   $107 = HEAP8[$27>>0]|0;
   $108 = $107 & 1;
   $109 = ($108<<24>>24)==(0);
   if (!($109)) {
    $110 = (($this) + 264|0);
    $111 = HEAP32[$110>>2]|0;
    HEAP32[$5>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($111|0),($$byval_copy23|0));
    $112 = __THREW__; __THREW__ = 0;
    $113 = $112&1;
    if ($113) {
     $114 = ___cxa_find_matching_catch()|0;
     $115 = tempRet0;
     ___cxa_call_unexpected(($114|0));
     // unreachable;
    }
   }
   $116 = HEAP8[$26>>0]|0;
   $117 = $116 & 1;
   $118 = ($117<<24>>24)==(0);
   if (!($118)) {
    $119 = (($this) + 252|0);
    $120 = HEAP32[$119>>2]|0;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($120|0),($$byval_copy23|0));
    $121 = __THREW__; __THREW__ = 0;
    $122 = $121&1;
    if ($122) {
     $123 = ___cxa_find_matching_catch()|0;
     $124 = tempRet0;
     ___cxa_call_unexpected(($123|0));
     // unreachable;
    }
   }
   $125 = HEAP8[$25>>0]|0;
   $126 = $125 & 1;
   $127 = ($126<<24>>24)==(0);
   if (!($127)) {
    $128 = (($this) + 240|0);
    $129 = HEAP32[$128>>2]|0;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($129|0),($$byval_copy23|0));
    $130 = __THREW__; __THREW__ = 0;
    $131 = $130&1;
    if ($131) {
     $132 = ___cxa_find_matching_catch()|0;
     $133 = tempRet0;
     ___cxa_call_unexpected(($132|0));
     // unreachable;
    }
   }
   $134 = HEAP8[$24>>0]|0;
   $135 = $134 & 1;
   $136 = ($135<<24>>24)==(0);
   if (!($136)) {
    $137 = (($this) + 228|0);
    $138 = HEAP32[$137>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($138|0),($$byval_copy23|0));
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     $141 = ___cxa_find_matching_catch()|0;
     $142 = tempRet0;
     ___cxa_call_unexpected(($141|0));
     // unreachable;
    }
   }
   $143 = HEAP8[$15>>0]|0;
   $144 = $143 & 1;
   $145 = ($144<<24>>24)==(0);
   if (!($145)) {
    $146 = (($this) + 56|0);
    $147 = HEAP32[$146>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($147|0),($$byval_copy23|0));
    $148 = __THREW__; __THREW__ = 0;
    $149 = $148&1;
    if ($149) {
     $150 = ___cxa_find_matching_catch()|0;
     $151 = tempRet0;
     ___cxa_call_unexpected(($150|0));
     // unreachable;
    }
   }
   $152 = HEAP8[$14>>0]|0;
   $153 = $152 & 1;
   $154 = ($153<<24>>24)==(0);
   if (!($154)) {
    $155 = (($this) + 44|0);
    $156 = HEAP32[$155>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($156|0),($$byval_copy23|0));
    $157 = __THREW__; __THREW__ = 0;
    $158 = $157&1;
    if ($158) {
     $159 = ___cxa_find_matching_catch()|0;
     $160 = tempRet0;
     ___cxa_call_unexpected(($159|0));
     // unreachable;
    }
   }
   $161 = HEAP8[$13>>0]|0;
   $162 = $161 & 1;
   $163 = ($162<<24>>24)==(0);
   if (!($163)) {
    $164 = (($this) + 32|0);
    $165 = HEAP32[$164>>2]|0;
    HEAP32[$9>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy23+0>>2]=HEAP32[$9+0>>2]|0;
    invoke_vii(2591,($165|0),($$byval_copy23|0));
    $166 = __THREW__; __THREW__ = 0;
    $167 = $166&1;
    if ($167) {
     $168 = ___cxa_find_matching_catch()|0;
     $169 = tempRet0;
     ___cxa_call_unexpected(($168|0));
     // unreachable;
    }
   }
   HEAP32[$this>>2] = ((561192 + 8|0));
   __THREW__ = 0;
   $170 = __THREW__; __THREW__ = 0;
   $171 = $170&1;
   if (!($171)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $172 = __THREW__; __THREW__ = 0;
    $173 = $172&1;
    if (!($173)) {
     __THREW__ = 0;
     $180 = __THREW__; __THREW__ = 0;
     $181 = $180&1;
     if ($181) {
      break;
     }
     ___resumeException($$01|0);
     // unreachable;
    }
    $174 = ___cxa_find_matching_catch(0|0)|0;
    $175 = tempRet0;
    __THREW__ = 0;
    $176 = __THREW__; __THREW__ = 0;
    $177 = $176&1;
    if ($177) {
     $178 = ___cxa_find_matching_catch(0|0)|0;
     $179 = tempRet0;
     ___clang_call_terminate($178);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $174;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $182 = ___cxa_find_matching_catch(0|0)|0;
   $183 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $184 = __THREW__; __THREW__ = 0;
   $185 = $184&1;
   if ($185) {
    $188 = ___cxa_find_matching_catch(0|0)|0;
    $189 = tempRet0;
    __THREW__ = 0;
    $190 = __THREW__; __THREW__ = 0;
    $191 = $190&1;
    if ($191) {
     $192 = ___cxa_find_matching_catch(0|0)|0;
     $193 = tempRet0;
     ___clang_call_terminate($192);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $188;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $186 = __THREW__; __THREW__ = 0;
   $187 = $186&1;
   if (!($187)) {
    $eh$lpad$body$indexZ2D = $182;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $194 = ___cxa_find_matching_catch(0|0)|0;
   $195 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $194;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 $196 = ___cxa_find_matching_catch(0|0)|0;
 $197 = tempRet0;
 $eh$lpad$body$indexZ2D = $196;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN14PlayerSettings15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z27RegisterAllowNameConversionPKcS0_S0_(623208,623224,623248);
 __Z27RegisterAllowNameConversionPKcS0_S0_(623208,623272,623296);
 __Z27RegisterAllowNameConversionPKcS0_S0_(623208,623320,623344);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings19PostInitializeClassEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24GetManagerPtrFromContexti(0)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (__Z21GetManagerFromContexti(0)|0);
 __ZN14PlayerSettings18InitDefaultCursorsEv($2);
 STACKTOP = sp;return;
}
function __Z20GetPlayerSettingsPtrv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z24GetManagerPtrFromContexti(0)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z17GetPlayerSettingsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14PlayerSettings18InitDefaultCursorsEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $temp$0$i = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $3;
  $5 = HEAP32[560624>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   label = 10;
  } else {
   $7 = (($5) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   do {
    if ($11) {
     $12 = (($5) + 28|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($5) + 32|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($13) + ($15<<3)|0);
     $32 = $16;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast$byval_copy,$5,$0);
     $17 = HEAP32[$tmpcast$byval_copy>>2]|0;
     $18 = ($17|0)==(-1);
     $19 = (($5) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     if ($18) {
      $21 = (($5) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $32 = $23;
      break;
     } else {
      $24 = (($20) + ($17<<3)|0);
      $32 = $24;
      break;
     }
    }
   } while(0);
   $25 = HEAP32[560624>>2]|0;
   $26 = (($25) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 32|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + ($29<<3)|0);
   $31 = ($32|0)==($30|0);
   if ($31) {
    label = 10;
   } else {
    $33 = (($32) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 10;
    } else {
     $temp$0$i = $34;
    }
   }
  }
  if ((label|0) == 10) {
   $36 = HEAP32[$2>>2]|0;
   $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
   $temp$0$i = $37;
  }
  $$0$i = $temp$0$i;
 }
 $38 = (($this) + 64|0);
 $39 = $38;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + 4)|0;
 $43 = $42;
 $44 = HEAP32[$43>>2]|0;
 $45 = $1;
 $46 = $45;
 HEAP32[$46>>2] = $41;
 $47 = (($45) + 4)|0;
 $48 = $47;
 HEAP32[$48>>2] = $44;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 __ZN7Cursors17InitializeCursorsEP9Texture2D8Vector2f($$0$i,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$$i = 0, $$$i1 = 0, $$0$i = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<(0);
 if ($2) {
  $$0$i2 = 0;
 } else {
  $3 = ($1|0)>(3);
  $$$i1 = $3 ? 3 : $1;
  $$0$i2 = $$$i1;
 }
 HEAP32[$0>>2] = $$0$i2;
 $4 = (($this) + 136|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)<(0);
 if ($6) {
  $$0$i = 0;
  HEAP32[$4>>2] = $$0$i;
  STACKTOP = sp;return;
 }
 $7 = ($5|0)>(1);
 $$$i = $7 ? 1 : $5;
 $$0$i = $$$i;
 HEAP32[$4>>2] = $$0$i;
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $awakeMode$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $awakeMode$off = (($awakeMode) + -1)|0;
 $0 = ($awakeMode$off>>>0)<(2);
 if ($0) {
  $1 = (__Z11IsGfxDevicev()|0);
  if ($1) {
   __ZN14PlayerSettings18InitDefaultCursorsEv($this);
  }
 }
 STACKTOP = sp;return;
}
function __ZNK14PlayerSettings22GetValidatedColorSpaceEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[((640792 + 237|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = (($this) + 136|0);
  $3 = HEAP32[$2>>2]|0;
  $$0 = $3;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN14PlayerSettings23GetRenderingPathRuntimeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z28RegisterClass_PlayerSettingsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(129,171,172,173,174);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 14;
 dest=$3+0|0; src=623208+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 14|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,129,6,($0|0),288,(2429|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN14PlayerSettings12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(288,$$byval_copy2,1,16,623368,59)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1786,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(623368|0),59);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK14PlayerSettings25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 129;
}
function __ZN14PlayerSettings23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623376,623208,$this,0);
 __ZN14PlayerSettings8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623376,623208,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN14PlayerSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PlayerSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PlayerSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PlayerSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PlayerSettings8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettingsD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PlayerSettingsD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettingsD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3544,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN14PlayerSettings8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$0>>2] = -1;
 }
 $3 = (($this) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 if ((($4|0) == 1)) {
  HEAP32[$3>>2] = 6;
 } else if ((($4|0) == 2)) {
  HEAP32[$3>>2] = 0;
 }
 $5 = (($this) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($transfer) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iiii[$10 & 2047]($8,$6,$12)|0);
 $14 = (($transfer) + 32|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if (!($16)) {
  HEAP32[$5>>2] = $13;
 }
 $17 = (($this) + 204|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$7>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$11>>2]|0;
 $23 = (FUNCTION_TABLE_iiii[$21 & 2047]($19,$18,$22)|0);
 $24 = HEAP8[$14>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if (!($25)) {
  HEAP32[$17>>2] = $23;
 }
 $26 = (($this) + 268|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($this) + 276|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + ($29<<2)|0);
 $31 = ($29|0)==(0);
 if ($31) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i = $27;
 }
 while(1) {
  $32 = HEAP32[$i$01$i$i$i>>2]|0;
  $33 = HEAP32[$7>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$11>>2]|0;
  $37 = (FUNCTION_TABLE_iiii[$35 & 2047]($33,$32,$36)|0);
  $38 = HEAP8[$14>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if (!($39)) {
   HEAP32[$i$01$i$i$i>>2] = $37;
  }
  $40 = (($i$01$i$i$i) + 4|0);
  $41 = ($40|0)==($30|0);
  if ($41) {
   break;
  } else {
   $i$01$i$i$i = $40;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre100 = 0, $$pre101 = 0, $$pre102 = 0, $$pre103 = 0, $$pre104 = 0, $$pre105 = 0, $$pre106 = 0, $$pre107 = 0, $$pre108 = 0, $$pre109 = 0, $$pre110 = 0, $$pre111 = 0, $$pre112 = 0, $$pre113 = 0, $$pre114 = 0, $$pre115 = 0, $$pre116 = 0, $$pre117 = 0;
 var $$pre118 = 0, $$pre119 = 0, $$pre120 = 0, $$pre121 = 0, $$pre122 = 0, $$pre123 = 0, $$pre2$i$i$i = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0;
 var $$pre70 = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $$pre75 = 0, $$pre76 = 0, $$pre77 = 0, $$pre78 = 0, $$pre79 = 0, $$pre80 = 0, $$pre81 = 0, $$pre82 = 0, $$pre83 = 0, $$pre84 = 0, $$pre85 = 0, $$pre86 = 0, $$pre87 = 0, $$pre88 = 0, $$pre89 = 0;
 var $$pre90 = 0, $$pre91 = 0, $$pre92 = 0, $$pre93 = 0, $$pre94 = 0, $$pre95 = 0, $$pre96 = 0, $$pre97 = 0, $$pre98 = 0, $$pre99 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP8[$0>>0]|0;
  HEAP8[$2>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $10 = (($this) + 76|0);
 $11 = HEAP32[$1>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$4>>2]|0;
 $14 = ($12>>>0)<($13>>>0);
 if ($14) {
  $15 = HEAP32[$10>>2]|0;
  HEAP32[$11>>2] = $15;
  HEAP32[$1>>2] = $12;
  $18 = $12;$20 = $13;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$10,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre57 = HEAP32[$4>>2]|0;
  $18 = $$pre;$20 = $$pre57;
 }
 $16 = (($this) + 80|0);
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)<($20>>>0);
 if ($19) {
  $21 = HEAP32[$16>>2]|0;
  HEAP32[$18>>2] = $21;
  HEAP32[$1>>2] = $17;
  $24 = $17;$26 = $20;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$16,4);
  $$pre58 = HEAP32[$1>>2]|0;
  $$pre59 = HEAP32[$4>>2]|0;
  $24 = $$pre58;$26 = $$pre59;
 }
 $22 = (($this) + 84|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)<($26>>>0);
 if ($25) {
  $27 = HEAP32[$22>>2]|0;
  HEAP32[$24>>2] = $27;
  HEAP32[$1>>2] = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$22,4);
 }
 $28 = HEAP32[$22>>2]|0;
 $29 = ($28|0)==(0);
 if ($29) {
  HEAP32[$22>>2] = -1;
 }
 $30 = (($this) + 88|0);
 $31 = HEAP32[$1>>2]|0;
 $32 = (($31) + 4|0);
 $33 = HEAP32[$4>>2]|0;
 $34 = ($32>>>0)<($33>>>0);
 if ($34) {
  $35 = HEAP32[$30>>2]|0;
  HEAP32[$31>>2] = $35;
  HEAP32[$1>>2] = $32;
  $38 = $32;$40 = $33;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$30,4);
  $$pre60 = HEAP32[$1>>2]|0;
  $$pre61 = HEAP32[$4>>2]|0;
  $38 = $$pre60;$40 = $$pre61;
 }
 $36 = (($this) + 92|0);
 $37 = (($38) + 4|0);
 $39 = ($37>>>0)<($40>>>0);
 if ($39) {
  $41 = HEAP32[$36>>2]|0;
  HEAP32[$38>>2] = $41;
  HEAP32[$1>>2] = $37;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$36,4);
 }
 $42 = HEAP32[$36>>2]|0;
 if ((($42|0) == 2)) {
  HEAP32[$36>>2] = 0;
 } else if ((($42|0) == 1)) {
  HEAP32[$36>>2] = 6;
 }
 $43 = (($this) + 96|0);
 $44 = HEAP32[$1>>2]|0;
 $45 = (($44) + 4|0);
 $46 = HEAP32[$4>>2]|0;
 $47 = ($45>>>0)<($46>>>0);
 if ($47) {
  $48 = HEAP32[$43>>2]|0;
  HEAP32[$44>>2] = $48;
  HEAP32[$1>>2] = $45;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$43,4);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $49 = (($this) + 24|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$49,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $50 = (($this) + 36|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$50,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $51 = (($this) + 60|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($51,$transfer);
 $52 = (($this) + 64|0);
 $53 = HEAP32[$1>>2]|0;
 $54 = (($53) + 4|0);
 $55 = HEAP32[$4>>2]|0;
 $56 = ($54>>>0)<($55>>>0);
 if ($56) {
  $57 = Math_fround(HEAPF32[$52>>2]);
  HEAPF32[$53>>2] = $57;
  HEAP32[$1>>2] = $54;
  $60 = $54;$62 = $55;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$52,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre2$i$i$i = HEAP32[$4>>2]|0;
  $60 = $$pre$i$i$i;$62 = $$pre2$i$i$i;
 }
 $58 = (($this) + 68|0);
 $59 = (($60) + 4|0);
 $61 = ($59>>>0)<($62>>>0);
 if ($61) {
  $63 = Math_fround(HEAPF32[$58>>2]);
  HEAPF32[$60>>2] = $63;
  HEAP32[$1>>2] = $59;
  $66 = $59;$68 = $62;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$58,4);
  $$pre62 = HEAP32[$1>>2]|0;
  $$pre63 = HEAP32[$4>>2]|0;
  $66 = $$pre62;$68 = $$pre63;
 }
 $64 = (($this) + 100|0);
 $65 = (($66) + 4|0);
 $67 = ($65>>>0)<($68>>>0);
 if ($67) {
  $69 = HEAP32[$64>>2]|0;
  HEAP32[$66>>2] = $69;
  HEAP32[$1>>2] = $65;
  $72 = $65;$74 = $68;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$64,4);
  $$pre64 = HEAP32[$1>>2]|0;
  $$pre65 = HEAP32[$4>>2]|0;
  $72 = $$pre64;$74 = $$pre65;
 }
 $70 = (($this) + 104|0);
 $71 = (($72) + 4|0);
 $73 = ($71>>>0)<($74>>>0);
 if ($73) {
  $75 = HEAP32[$70>>2]|0;
  HEAP32[$72>>2] = $75;
  HEAP32[$1>>2] = $71;
  $78 = $71;$80 = $74;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$70,4);
  $$pre66 = HEAP32[$1>>2]|0;
  $$pre67 = HEAP32[$4>>2]|0;
  $78 = $$pre66;$80 = $$pre67;
 }
 $76 = (($this) + 108|0);
 $77 = (($78) + 4|0);
 $79 = ($77>>>0)<($80>>>0);
 if ($79) {
  $81 = HEAP32[$76>>2]|0;
  HEAP32[$78>>2] = $81;
  HEAP32[$1>>2] = $77;
  $84 = $77;$86 = $80;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$76,4);
  $$pre68 = HEAP32[$1>>2]|0;
  $$pre69 = HEAP32[$4>>2]|0;
  $84 = $$pre68;$86 = $$pre69;
 }
 $82 = (($this) + 112|0);
 $83 = (($84) + 4|0);
 $85 = ($83>>>0)<($86>>>0);
 if ($85) {
  $87 = HEAP32[$82>>2]|0;
  HEAP32[$84>>2] = $87;
  HEAP32[$1>>2] = $83;
  $90 = $83;$92 = $86;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$82,4);
  $$pre70 = HEAP32[$1>>2]|0;
  $$pre71 = HEAP32[$4>>2]|0;
  $90 = $$pre70;$92 = $$pre71;
 }
 $88 = (($this) + 128|0);
 $89 = (($90) + 4|0);
 $91 = ($89>>>0)<($92>>>0);
 if ($91) {
  $93 = HEAP32[$88>>2]|0;
  HEAP32[$90>>2] = $93;
  HEAP32[$1>>2] = $89;
  $96 = $89;$98 = $92;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$88,4);
  $$pre72 = HEAP32[$1>>2]|0;
  $$pre73 = HEAP32[$4>>2]|0;
  $96 = $$pre72;$98 = $$pre73;
 }
 $94 = (($this) + 132|0);
 $95 = (($96) + 4|0);
 $97 = ($95>>>0)<($98>>>0);
 if ($97) {
  $99 = HEAP32[$94>>2]|0;
  HEAP32[$96>>2] = $99;
  HEAP32[$1>>2] = $95;
  $102 = $95;$104 = $98;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$94,4);
  $$pre74 = HEAP32[$1>>2]|0;
  $$pre75 = HEAP32[$4>>2]|0;
  $102 = $$pre74;$104 = $$pre75;
 }
 $100 = (($this) + 136|0);
 $101 = (($102) + 4|0);
 $103 = ($101>>>0)<($104>>>0);
 if ($103) {
  $105 = HEAP32[$100>>2]|0;
  HEAP32[$102>>2] = $105;
  HEAP32[$1>>2] = $101;
  $108 = $101;$110 = $104;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$100,4);
  $$pre76 = HEAP32[$1>>2]|0;
  $$pre77 = HEAP32[$4>>2]|0;
  $108 = $$pre76;$110 = $$pre77;
 }
 $106 = (($this) + 140|0);
 $107 = (($108) + 1|0);
 $109 = ($107>>>0)<($110>>>0);
 if ($109) {
  $111 = HEAP8[$106>>0]|0;
  HEAP8[$108>>0] = $111;
  $112 = HEAP32[$1>>2]|0;
  $113 = (($112) + 1|0);
  HEAP32[$1>>2] = $113;
  $116 = $113;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$106,1);
  $$pre78 = HEAP32[$1>>2]|0;
  $116 = $$pre78;
 }
 $114 = (($this) + 141|0);
 $115 = (($116) + 1|0);
 $117 = HEAP32[$4>>2]|0;
 $118 = ($115>>>0)<($117>>>0);
 if ($118) {
  $119 = HEAP8[$114>>0]|0;
  HEAP8[$116>>0] = $119;
  $120 = HEAP32[$1>>2]|0;
  $121 = (($120) + 1|0);
  HEAP32[$1>>2] = $121;
  $124 = $121;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$114,1);
  $$pre79 = HEAP32[$1>>2]|0;
  $124 = $$pre79;
 }
 $122 = (($this) + 142|0);
 $123 = (($124) + 1|0);
 $125 = HEAP32[$4>>2]|0;
 $126 = ($123>>>0)<($125>>>0);
 if ($126) {
  $127 = HEAP8[$122>>0]|0;
  HEAP8[$124>>0] = $127;
  $128 = HEAP32[$1>>2]|0;
  $129 = (($128) + 1|0);
  HEAP32[$1>>2] = $129;
  $132 = $129;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$122,1);
  $$pre80 = HEAP32[$1>>2]|0;
  $132 = $$pre80;
 }
 $130 = (($this) + 143|0);
 $131 = (($132) + 1|0);
 $133 = HEAP32[$4>>2]|0;
 $134 = ($131>>>0)<($133>>>0);
 if ($134) {
  $135 = HEAP8[$130>>0]|0;
  HEAP8[$132>>0] = $135;
  $136 = HEAP32[$1>>2]|0;
  $137 = (($136) + 1|0);
  HEAP32[$1>>2] = $137;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$130,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $138 = (($this) + 148|0);
 $139 = HEAP32[$1>>2]|0;
 $140 = (($139) + 4|0);
 $141 = HEAP32[$4>>2]|0;
 $142 = ($140>>>0)<($141>>>0);
 if ($142) {
  $143 = HEAP32[$138>>2]|0;
  HEAP32[$139>>2] = $143;
  HEAP32[$1>>2] = $140;
  $146 = $140;$148 = $141;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$138,4);
  $$pre81 = HEAP32[$1>>2]|0;
  $$pre82 = HEAP32[$4>>2]|0;
  $146 = $$pre81;$148 = $$pre82;
 }
 $144 = (($this) + 144|0);
 $145 = (($146) + 4|0);
 $147 = ($145>>>0)<($148>>>0);
 if ($147) {
  $149 = HEAP32[$144>>2]|0;
  HEAP32[$146>>2] = $149;
  HEAP32[$1>>2] = $145;
  $152 = $145;$154 = $148;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$144,4);
  $$pre83 = HEAP32[$1>>2]|0;
  $$pre84 = HEAP32[$4>>2]|0;
  $152 = $$pre83;$154 = $$pre84;
 }
 $150 = (($this) + 152|0);
 $151 = (($152) + 4|0);
 $153 = ($151>>>0)<($154>>>0);
 if ($153) {
  $155 = HEAP32[$150>>2]|0;
  HEAP32[$152>>2] = $155;
  HEAP32[$1>>2] = $151;
  $158 = $151;$160 = $154;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$150,4);
  $$pre85 = HEAP32[$1>>2]|0;
  $$pre86 = HEAP32[$4>>2]|0;
  $158 = $$pre85;$160 = $$pre86;
 }
 $156 = (($this) + 116|0);
 $157 = (($158) + 4|0);
 $159 = ($157>>>0)<($160>>>0);
 if ($159) {
  $161 = HEAP32[$156>>2]|0;
  HEAP32[$158>>2] = $161;
  HEAP32[$1>>2] = $157;
  $164 = $157;$166 = $160;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$156,4);
  $$pre87 = HEAP32[$1>>2]|0;
  $$pre88 = HEAP32[$4>>2]|0;
  $164 = $$pre87;$166 = $$pre88;
 }
 $162 = (($this) + 156|0);
 $163 = (($164) + 1|0);
 $165 = ($163>>>0)<($166>>>0);
 if ($165) {
  $167 = HEAP8[$162>>0]|0;
  HEAP8[$164>>0] = $167;
  $168 = HEAP32[$1>>2]|0;
  $169 = (($168) + 1|0);
  HEAP32[$1>>2] = $169;
  $172 = $169;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$162,1);
  $$pre89 = HEAP32[$1>>2]|0;
  $172 = $$pre89;
 }
 $170 = (($this) + 157|0);
 $171 = (($172) + 1|0);
 $173 = HEAP32[$4>>2]|0;
 $174 = ($171>>>0)<($173>>>0);
 if ($174) {
  $175 = HEAP8[$170>>0]|0;
  HEAP8[$172>>0] = $175;
  $176 = HEAP32[$1>>2]|0;
  $177 = (($176) + 1|0);
  HEAP32[$1>>2] = $177;
  $180 = $177;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$170,1);
  $$pre90 = HEAP32[$1>>2]|0;
  $180 = $$pre90;
 }
 $178 = (($this) + 158|0);
 $179 = (($180) + 1|0);
 $181 = HEAP32[$4>>2]|0;
 $182 = ($179>>>0)<($181>>>0);
 if ($182) {
  $183 = HEAP8[$178>>0]|0;
  HEAP8[$180>>0] = $183;
  $184 = HEAP32[$1>>2]|0;
  $185 = (($184) + 1|0);
  HEAP32[$1>>2] = $185;
  $188 = $185;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$178,1);
  $$pre91 = HEAP32[$1>>2]|0;
  $188 = $$pre91;
 }
 $186 = (($this) + 159|0);
 $187 = (($188) + 1|0);
 $189 = HEAP32[$4>>2]|0;
 $190 = ($187>>>0)<($189>>>0);
 if ($190) {
  $191 = HEAP8[$186>>0]|0;
  HEAP8[$188>>0] = $191;
  $192 = HEAP32[$1>>2]|0;
  $193 = (($192) + 1|0);
  HEAP32[$1>>2] = $193;
  $196 = $193;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$186,1);
  $$pre92 = HEAP32[$1>>2]|0;
  $196 = $$pre92;
 }
 $194 = (($this) + 160|0);
 $195 = (($196) + 1|0);
 $197 = HEAP32[$4>>2]|0;
 $198 = ($195>>>0)<($197>>>0);
 if ($198) {
  $199 = HEAP8[$194>>0]|0;
  HEAP8[$196>>0] = $199;
  $200 = HEAP32[$1>>2]|0;
  $201 = (($200) + 1|0);
  HEAP32[$1>>2] = $201;
  $204 = $201;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$194,1);
  $$pre93 = HEAP32[$1>>2]|0;
  $204 = $$pre93;
 }
 $202 = (($this) + 161|0);
 $203 = (($204) + 1|0);
 $205 = HEAP32[$4>>2]|0;
 $206 = ($203>>>0)<($205>>>0);
 if ($206) {
  $207 = HEAP8[$202>>0]|0;
  HEAP8[$204>>0] = $207;
  $208 = HEAP32[$1>>2]|0;
  $209 = (($208) + 1|0);
  HEAP32[$1>>2] = $209;
  $212 = $209;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$202,1);
  $$pre94 = HEAP32[$1>>2]|0;
  $212 = $$pre94;
 }
 $210 = (($this) + 162|0);
 $211 = (($212) + 1|0);
 $213 = HEAP32[$4>>2]|0;
 $214 = ($211>>>0)<($213>>>0);
 if ($214) {
  $215 = HEAP8[$210>>0]|0;
  HEAP8[$212>>0] = $215;
  $216 = HEAP32[$1>>2]|0;
  $217 = (($216) + 1|0);
  HEAP32[$1>>2] = $217;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$210,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $218 = (($this) + 163|0);
 $219 = HEAP32[$1>>2]|0;
 $220 = (($219) + 1|0);
 $221 = HEAP32[$4>>2]|0;
 $222 = ($220>>>0)<($221>>>0);
 if ($222) {
  $223 = HEAP8[$218>>0]|0;
  HEAP8[$219>>0] = $223;
  $224 = HEAP32[$1>>2]|0;
  $225 = (($224) + 1|0);
  HEAP32[$1>>2] = $225;
  $228 = $225;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$218,1);
  $$pre95 = HEAP32[$1>>2]|0;
  $228 = $$pre95;
 }
 $226 = (($this) + 164|0);
 $227 = (($228) + 1|0);
 $229 = HEAP32[$4>>2]|0;
 $230 = ($227>>>0)<($229>>>0);
 if ($230) {
  $231 = HEAP8[$226>>0]|0;
  HEAP8[$228>>0] = $231;
  $232 = HEAP32[$1>>2]|0;
  $233 = (($232) + 1|0);
  HEAP32[$1>>2] = $233;
  $236 = $233;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$226,1);
  $$pre96 = HEAP32[$1>>2]|0;
  $236 = $$pre96;
 }
 $234 = (($this) + 165|0);
 $235 = (($236) + 1|0);
 $237 = HEAP32[$4>>2]|0;
 $238 = ($235>>>0)<($237>>>0);
 if ($238) {
  $239 = HEAP8[$234>>0]|0;
  HEAP8[$236>>0] = $239;
  $240 = HEAP32[$1>>2]|0;
  $241 = (($240) + 1|0);
  HEAP32[$1>>2] = $241;
  $244 = $241;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$234,1);
  $$pre97 = HEAP32[$1>>2]|0;
  $244 = $$pre97;
 }
 $242 = (($this) + 166|0);
 $243 = (($244) + 1|0);
 $245 = HEAP32[$4>>2]|0;
 $246 = ($243>>>0)<($245>>>0);
 if ($246) {
  $247 = HEAP8[$242>>0]|0;
  HEAP8[$244>>0] = $247;
  $248 = HEAP32[$1>>2]|0;
  $249 = (($248) + 1|0);
  HEAP32[$1>>2] = $249;
  $252 = $249;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$242,1);
  $$pre98 = HEAP32[$1>>2]|0;
  $252 = $$pre98;
 }
 $250 = (($this) + 167|0);
 $251 = (($252) + 1|0);
 $253 = HEAP32[$4>>2]|0;
 $254 = ($251>>>0)<($253>>>0);
 if ($254) {
  $255 = HEAP8[$250>>0]|0;
  HEAP8[$252>>0] = $255;
  $256 = HEAP32[$1>>2]|0;
  $257 = (($256) + 1|0);
  HEAP32[$1>>2] = $257;
  $260 = $257;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$250,1);
  $$pre99 = HEAP32[$1>>2]|0;
  $260 = $$pre99;
 }
 $258 = (($this) + 168|0);
 $259 = (($260) + 1|0);
 $261 = HEAP32[$4>>2]|0;
 $262 = ($259>>>0)<($261>>>0);
 if ($262) {
  $263 = HEAP8[$258>>0]|0;
  HEAP8[$260>>0] = $263;
  $264 = HEAP32[$1>>2]|0;
  $265 = (($264) + 1|0);
  HEAP32[$1>>2] = $265;
  $268 = $265;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$258,1);
  $$pre100 = HEAP32[$1>>2]|0;
  $268 = $$pre100;
 }
 $266 = (($this) + 169|0);
 $267 = (($268) + 1|0);
 $269 = HEAP32[$4>>2]|0;
 $270 = ($267>>>0)<($269>>>0);
 if ($270) {
  $271 = HEAP8[$266>>0]|0;
  HEAP8[$268>>0] = $271;
  $272 = HEAP32[$1>>2]|0;
  $273 = (($272) + 1|0);
  HEAP32[$1>>2] = $273;
  $276 = $273;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$266,1);
  $$pre101 = HEAP32[$1>>2]|0;
  $276 = $$pre101;
 }
 $274 = (($this) + 170|0);
 $275 = (($276) + 1|0);
 $277 = HEAP32[$4>>2]|0;
 $278 = ($275>>>0)<($277>>>0);
 if ($278) {
  $279 = HEAP8[$274>>0]|0;
  HEAP8[$276>>0] = $279;
  $280 = HEAP32[$1>>2]|0;
  $281 = (($280) + 1|0);
  HEAP32[$1>>2] = $281;
  $284 = $281;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$274,1);
  $$pre102 = HEAP32[$1>>2]|0;
  $284 = $$pre102;
 }
 $282 = (($this) + 171|0);
 $283 = (($284) + 1|0);
 $285 = HEAP32[$4>>2]|0;
 $286 = ($283>>>0)<($285>>>0);
 if ($286) {
  $287 = HEAP8[$282>>0]|0;
  HEAP8[$284>>0] = $287;
  $288 = HEAP32[$1>>2]|0;
  $289 = (($288) + 1|0);
  HEAP32[$1>>2] = $289;
  $292 = $289;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$282,1);
  $$pre103 = HEAP32[$1>>2]|0;
  $292 = $$pre103;
 }
 $290 = (($this) + 180|0);
 $291 = (($292) + 1|0);
 $293 = HEAP32[$4>>2]|0;
 $294 = ($291>>>0)<($293>>>0);
 if ($294) {
  $295 = HEAP8[$290>>0]|0;
  HEAP8[$292>>0] = $295;
  $296 = HEAP32[$1>>2]|0;
  $297 = (($296) + 1|0);
  HEAP32[$1>>2] = $297;
  $300 = $297;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$290,1);
  $$pre104 = HEAP32[$1>>2]|0;
  $300 = $$pre104;
 }
 $298 = (($this) + 181|0);
 $299 = (($300) + 1|0);
 $301 = HEAP32[$4>>2]|0;
 $302 = ($299>>>0)<($301>>>0);
 if ($302) {
  $303 = HEAP8[$298>>0]|0;
  HEAP8[$300>>0] = $303;
  $304 = HEAP32[$1>>2]|0;
  $305 = (($304) + 1|0);
  HEAP32[$1>>2] = $305;
  $308 = $305;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$298,1);
  $$pre105 = HEAP32[$1>>2]|0;
  $308 = $$pre105;
 }
 $306 = (($this) + 172|0);
 $307 = (($308) + 1|0);
 $309 = HEAP32[$4>>2]|0;
 $310 = ($307>>>0)<($309>>>0);
 if ($310) {
  $311 = HEAP8[$306>>0]|0;
  HEAP8[$308>>0] = $311;
  $312 = HEAP32[$1>>2]|0;
  $313 = (($312) + 1|0);
  HEAP32[$1>>2] = $313;
  $316 = $313;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$306,1);
  $$pre106 = HEAP32[$1>>2]|0;
  $316 = $$pre106;
 }
 $314 = (($this) + 182|0);
 $315 = (($316) + 1|0);
 $317 = HEAP32[$4>>2]|0;
 $318 = ($315>>>0)<($317>>>0);
 if ($318) {
  $319 = HEAP8[$314>>0]|0;
  HEAP8[$316>>0] = $319;
  $320 = HEAP32[$1>>2]|0;
  $321 = (($320) + 1|0);
  HEAP32[$1>>2] = $321;
  $324 = $321;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$314,1);
  $$pre107 = HEAP32[$1>>2]|0;
  $324 = $$pre107;
 }
 $322 = (($this) + 183|0);
 $323 = (($324) + 1|0);
 $325 = HEAP32[$4>>2]|0;
 $326 = ($323>>>0)<($325>>>0);
 if ($326) {
  $327 = HEAP8[$322>>0]|0;
  HEAP8[$324>>0] = $327;
  $328 = HEAP32[$1>>2]|0;
  $329 = (($328) + 1|0);
  HEAP32[$1>>2] = $329;
  $332 = $329;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$322,1);
  $$pre108 = HEAP32[$1>>2]|0;
  $332 = $$pre108;
 }
 $330 = (($this) + 184|0);
 $331 = (($332) + 1|0);
 $333 = HEAP32[$4>>2]|0;
 $334 = ($331>>>0)<($333>>>0);
 if ($334) {
  $335 = HEAP8[$330>>0]|0;
  HEAP8[$332>>0] = $335;
  $336 = HEAP32[$1>>2]|0;
  $337 = (($336) + 1|0);
  HEAP32[$1>>2] = $337;
  $340 = $337;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$330,1);
  $$pre109 = HEAP32[$1>>2]|0;
  $340 = $$pre109;
 }
 $338 = (($this) + 185|0);
 $339 = (($340) + 1|0);
 $341 = HEAP32[$4>>2]|0;
 $342 = ($339>>>0)<($341>>>0);
 if ($342) {
  $343 = HEAP8[$338>>0]|0;
  HEAP8[$340>>0] = $343;
  $344 = HEAP32[$1>>2]|0;
  $345 = (($344) + 1|0);
  HEAP32[$1>>2] = $345;
  $348 = $345;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$338,1);
  $$pre110 = HEAP32[$1>>2]|0;
  $348 = $$pre110;
 }
 $346 = (($this) + 186|0);
 $347 = (($348) + 1|0);
 $349 = HEAP32[$4>>2]|0;
 $350 = ($347>>>0)<($349>>>0);
 if ($350) {
  $351 = HEAP8[$346>>0]|0;
  HEAP8[$348>>0] = $351;
  $352 = HEAP32[$1>>2]|0;
  $353 = (($352) + 1|0);
  HEAP32[$1>>2] = $353;
  $356 = $353;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$346,1);
  $$pre111 = HEAP32[$1>>2]|0;
  $356 = $$pre111;
 }
 $354 = (($this) + 192|0);
 $355 = (($356) + 1|0);
 $357 = HEAP32[$4>>2]|0;
 $358 = ($355>>>0)<($357>>>0);
 if ($358) {
  $359 = HEAP8[$354>>0]|0;
  HEAP8[$356>>0] = $359;
  $360 = HEAP32[$1>>2]|0;
  $361 = (($360) + 1|0);
  HEAP32[$1>>2] = $361;
  $364 = $361;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$354,1);
  $$pre112 = HEAP32[$1>>2]|0;
  $364 = $$pre112;
 }
 $362 = (($this) + 173|0);
 $363 = (($364) + 1|0);
 $365 = HEAP32[$4>>2]|0;
 $366 = ($363>>>0)<($365>>>0);
 if ($366) {
  $367 = HEAP8[$362>>0]|0;
  HEAP8[$364>>0] = $367;
  $368 = HEAP32[$1>>2]|0;
  $369 = (($368) + 1|0);
  HEAP32[$1>>2] = $369;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$362,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $370 = (($this) + 176|0);
 $371 = HEAP32[$1>>2]|0;
 $372 = (($371) + 4|0);
 $373 = HEAP32[$4>>2]|0;
 $374 = ($372>>>0)<($373>>>0);
 if ($374) {
  $375 = HEAP32[$370>>2]|0;
  HEAP32[$371>>2] = $375;
  HEAP32[$1>>2] = $372;
  $378 = $372;$380 = $373;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$370,4);
  $$pre113 = HEAP32[$1>>2]|0;
  $$pre114 = HEAP32[$4>>2]|0;
  $378 = $$pre113;$380 = $$pre114;
 }
 $376 = (($this) + 188|0);
 $377 = (($378) + 4|0);
 $379 = ($377>>>0)<($380>>>0);
 if ($379) {
  $381 = HEAP32[$376>>2]|0;
  HEAP32[$378>>2] = $381;
  HEAP32[$1>>2] = $377;
  $384 = $377;$386 = $380;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$376,4);
  $$pre115 = HEAP32[$1>>2]|0;
  $$pre116 = HEAP32[$4>>2]|0;
  $384 = $$pre115;$386 = $$pre116;
 }
 $382 = (($this) + 193|0);
 $383 = (($384) + 1|0);
 $385 = ($383>>>0)<($386>>>0);
 if ($385) {
  $387 = HEAP8[$382>>0]|0;
  HEAP8[$384>>0] = $387;
  $388 = HEAP32[$1>>2]|0;
  $389 = (($388) + 1|0);
  HEAP32[$1>>2] = $389;
  $392 = $389;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$382,1);
  $$pre117 = HEAP32[$1>>2]|0;
  $392 = $$pre117;
 }
 $390 = (($this) + 194|0);
 $391 = (($392) + 1|0);
 $393 = HEAP32[$4>>2]|0;
 $394 = ($391>>>0)<($393>>>0);
 if ($394) {
  $395 = HEAP8[$390>>0]|0;
  HEAP8[$392>>0] = $395;
  $396 = HEAP32[$1>>2]|0;
  $397 = (($396) + 1|0);
  HEAP32[$1>>2] = $397;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$390,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $398 = (($this) + 196|0);
 $399 = HEAP32[$1>>2]|0;
 $400 = (($399) + 4|0);
 $401 = HEAP32[$4>>2]|0;
 $402 = ($400>>>0)<($401>>>0);
 if ($402) {
  $403 = HEAP32[$398>>2]|0;
  HEAP32[$399>>2] = $403;
  HEAP32[$1>>2] = $400;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$398,4);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $404 = (($this) + 204|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($404,$transfer);
 $405 = (($this) + 208|0);
 $406 = HEAP32[$1>>2]|0;
 $407 = (($406) + 4|0);
 $408 = HEAP32[$4>>2]|0;
 $409 = ($407>>>0)<($408>>>0);
 if ($409) {
  $410 = HEAP32[$405>>2]|0;
  HEAP32[$406>>2] = $410;
  HEAP32[$1>>2] = $407;
  $413 = $407;$415 = $408;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$405,4);
  $$pre118 = HEAP32[$1>>2]|0;
  $$pre119 = HEAP32[$4>>2]|0;
  $413 = $$pre118;$415 = $$pre119;
 }
 $411 = (($this) + 212|0);
 $412 = (($413) + 4|0);
 $414 = ($412>>>0)<($415>>>0);
 if ($414) {
  $416 = HEAP32[$411>>2]|0;
  HEAP32[$413>>2] = $416;
  HEAP32[$1>>2] = $412;
  $419 = $412;$421 = $415;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$411,4);
  $$pre120 = HEAP32[$1>>2]|0;
  $$pre121 = HEAP32[$4>>2]|0;
  $419 = $$pre120;$421 = $$pre121;
 }
 $417 = (($this) + 216|0);
 $418 = (($419) + 1|0);
 $420 = ($418>>>0)<($421>>>0);
 if ($420) {
  $422 = HEAP8[$417>>0]|0;
  HEAP8[$419>>0] = $422;
  $423 = HEAP32[$1>>2]|0;
  $424 = (($423) + 1|0);
  HEAP32[$1>>2] = $424;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$417,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $425 = (($this) + 120|0);
 __ZN12AspectRatios8TransferI19StreamedBinaryWriteILb0EEEEvRT_($425,$transfer);
 $426 = (($this) + 244|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$426,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $427 = (($this) + 276|0);
 $428 = HEAP32[$427>>2]|0;
 HEAP32[$size$i$i$i>>2] = $428;
 $429 = HEAP32[$1>>2]|0;
 $430 = (($429) + 4|0);
 $431 = HEAP32[$4>>2]|0;
 $432 = ($430>>>0)<($431>>>0);
 if ($432) {
  HEAP32[$429>>2] = $428;
  HEAP32[$1>>2] = $430;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i,4);
 }
 $433 = (($this) + 268|0);
 $434 = HEAP32[$433>>2]|0;
 $435 = HEAP32[$427>>2]|0;
 $436 = (($434) + ($435<<2)|0);
 $437 = ($435|0)==(0);
 if (!($437)) {
  $i$01$i$i$i = $434;
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $438 = (($i$01$i$i$i) + 4|0);
   $439 = ($438|0)==($436|0);
   if ($439) {
    break;
   } else {
    $i$01$i$i$i = $438;
   }
  }
 }
 $440 = (($this) + 284|0);
 $441 = HEAP32[$1>>2]|0;
 $442 = (($441) + 1|0);
 $443 = HEAP32[$4>>2]|0;
 $444 = ($442>>>0)<($443>>>0);
 if ($444) {
  $445 = HEAP8[$440>>0]|0;
  HEAP8[$441>>0] = $445;
  $446 = HEAP32[$1>>2]|0;
  $447 = (($446) + 1|0);
  HEAP32[$1>>2] = $447;
  $450 = $447;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$440,1);
  $$pre122 = HEAP32[$1>>2]|0;
  $450 = $$pre122;
 }
 $448 = (($this) + 285|0);
 $449 = (($450) + 1|0);
 $451 = HEAP32[$4>>2]|0;
 $452 = ($449>>>0)<($451>>>0);
 if ($452) {
  $453 = HEAP8[$448>>0]|0;
  HEAP8[$450>>0] = $453;
  $454 = HEAP32[$1>>2]|0;
  $455 = (($454) + 1|0);
  HEAP32[$1>>2] = $455;
  $458 = $455;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$448,1);
  $$pre123 = HEAP32[$1>>2]|0;
  $458 = $$pre123;
 }
 $456 = (($this) + 286|0);
 $457 = (($458) + 1|0);
 $459 = HEAP32[$4>>2]|0;
 $460 = ($457>>>0)<($459>>>0);
 if ($460) {
  $461 = HEAP8[$456>>0]|0;
  HEAP8[$458>>0] = $461;
  $462 = HEAP32[$1>>2]|0;
  $463 = (($462) + 1|0);
  HEAP32[$1>>2] = $463;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$456,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN12AspectRatios8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 20|0);
 $2 = (($this) + 1|0);
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 1|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = ($4>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$3>>0] = $7;
  $8 = HEAP32[$0>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$0>>2] = $9;
  $12 = $9;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$2,1);
  $$pre = HEAP32[$0>>2]|0;
  $12 = $$pre;
 }
 $10 = (($this) + 2|0);
 $11 = (($12) + 1|0);
 $13 = HEAP32[$1>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $19 = HEAP8[$10>>0]|0;
  HEAP8[$12>>0] = $19;
  $20 = HEAP32[$0>>2]|0;
  $21 = (($20) + 1|0);
  HEAP32[$0>>2] = $21;
  $24 = $21;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$10,1);
  $$pre3 = HEAP32[$0>>2]|0;
  $24 = $$pre3;
 }
 $22 = (($this) + 3|0);
 $23 = (($24) + 1|0);
 $25 = HEAP32[$1>>2]|0;
 $26 = ($23>>>0)<($25>>>0);
 if ($26) {
  $27 = HEAP8[$22>>0]|0;
  HEAP8[$24>>0] = $27;
  $28 = HEAP32[$0>>2]|0;
  $29 = (($28) + 1|0);
  HEAP32[$0>>2] = $29;
  $32 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$22,1);
  $$pre4 = HEAP32[$0>>2]|0;
  $32 = $$pre4;
 }
 $30 = (($this) + 4|0);
 $31 = (($32) + 1|0);
 $33 = HEAP32[$1>>2]|0;
 $34 = ($31>>>0)<($33>>>0);
 if ($34) {
  $35 = HEAP8[$30>>0]|0;
  HEAP8[$32>>0] = $35;
  $36 = HEAP32[$0>>2]|0;
  $37 = (($36) + 1|0);
  HEAP32[$0>>2] = $37;
  $16 = $37;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$30,1);
  $$pre5 = HEAP32[$0>>2]|0;
  $16 = $$pre5;
 }
 $38 = (($16) + 1|0);
 $39 = HEAP32[$1>>2]|0;
 $40 = ($38>>>0)<($39>>>0);
 if ($40) {
  $15 = HEAP8[$this>>0]|0;
  HEAP8[$16>>0] = $15;
  $17 = HEAP32[$0>>2]|0;
  $18 = (($17) + 1|0);
  HEAP32[$0>>2] = $18;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN14PlayerSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$ = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i12 = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i17 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i21 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i25 = 0, $$pre$i$i$i3$i$i$i = 0, $$pre$i$i$i31 = 0, $$pre$i$i$i33 = 0, $$pre$i$i$i35 = 0, $$pre$i$i$i37 = 0, $$pre$i$i$i4 = 0;
 var $$pre$i$i$i6 = 0, $$pre$i$i$i65 = 0, $$pre$i$i$i67 = 0, $$pre$i$i$i70 = 0, $$pre$i$i$i72 = 0, $$pre$i$i$i74 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$i4$i$i$iZ2D = 0, $$pre100 = 0, $$pre101 = 0, $$pre102 = 0, $$pre103 = 0, $$pre104 = 0, $$pre105 = 0, $$pre106 = 0, $$pre107 = 0, $$pre108 = 0, $$pre109 = 0, $$pre110 = 0;
 var $$pre111 = 0, $$pre112 = 0, $$pre113 = 0, $$pre114 = 0, $$pre115 = 0, $$pre116 = 0, $$pre117 = 0, $$pre118 = 0, $$pre119 = 0, $$pre120 = 0, $$pre121 = 0, $$pre122 = 0, $$pre123 = 0, $$pre124 = 0, $$pre125 = 0, $$pre126 = 0, $$pre127 = 0, $$pre128 = 0, $$pre129 = 0, $$pre130 = 0;
 var $$pre131 = 0, $$pre132 = 0, $$pre133 = 0, $$pre134 = 0, $$pre135 = 0, $$pre136 = 0, $$pre137 = 0, $$pre138 = 0, $$pre139 = 0, $$pre140 = 0, $$pre141 = 0, $$pre142 = 0, $$pre143 = 0, $$pre144 = 0, $$pre145 = 0, $$pre146 = 0, $$pre147 = 0, $$pre6$i$i$i = 0, $$pre79 = 0, $$pre80 = 0;
 var $$pre81 = 0, $$pre82 = 0, $$pre83 = 0, $$pre84 = 0, $$pre85 = 0, $$pre86 = 0, $$pre87 = 0, $$pre88 = 0, $$pre89 = 0, $$pre90 = 0, $$pre91 = 0, $$pre92 = 0, $$pre93 = 0, $$pre94 = 0, $$pre95 = 0, $$pre96 = 0, $$pre97 = 0, $$pre98 = 0, $$pre99 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $10 = (($this) + 76|0);
 $11 = HEAP32[$1>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$4>>2]|0;
 $14 = ($12>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,4);
  $$pre$i$i$i = HEAP32[$10>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre79 = HEAP32[$4>>2]|0;
  $16 = $$pre$i$i$i;$20 = $$pre;$22 = $$pre79;
 } else {
  $15 = HEAP32[$11>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$1>>2] = $12;
  $16 = $15;$20 = $12;$22 = $13;
 }
 $17 = (_llvm_bswap_i32(($16|0))|0);
 HEAP32[$10>>2] = $17;
 $18 = (($this) + 80|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)>($22>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$18,4);
  $$pre$i$i$i2 = HEAP32[$18>>2]|0;
  $$pre80 = HEAP32[$1>>2]|0;
  $$pre81 = HEAP32[$4>>2]|0;
  $24 = $$pre$i$i$i2;$28 = $$pre80;$30 = $$pre81;
 } else {
  $23 = HEAP32[$20>>2]|0;
  HEAP32[$18>>2] = $23;
  HEAP32[$1>>2] = $19;
  $24 = $23;$28 = $19;$30 = $22;
 }
 $25 = (_llvm_bswap_i32(($24|0))|0);
 HEAP32[$18>>2] = $25;
 $26 = (($this) + 84|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre$i$i$i4 = HEAP32[$26>>2]|0;
  $$pre82 = HEAP32[$1>>2]|0;
  $$pre83 = HEAP32[$4>>2]|0;
  $32 = $$pre$i$i$i4;$37 = $$pre82;$39 = $$pre83;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $32 = $31;$37 = $27;$39 = $30;
 }
 $33 = (_llvm_bswap_i32(($32|0))|0);
 $34 = ($32|0)==(0);
 $$ = $34 ? -1 : $33;
 HEAP32[$26>>2] = $$;
 $35 = (($this) + 88|0);
 $36 = (($37) + 4|0);
 $38 = ($36>>>0)>($39>>>0);
 if ($38) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$35,4);
  $$pre$i$i$i6 = HEAP32[$35>>2]|0;
  $$pre84 = HEAP32[$1>>2]|0;
  $$pre85 = HEAP32[$4>>2]|0;
  $41 = $$pre$i$i$i6;$45 = $$pre84;$47 = $$pre85;
 } else {
  $40 = HEAP32[$37>>2]|0;
  HEAP32[$35>>2] = $40;
  HEAP32[$1>>2] = $36;
  $41 = $40;$45 = $36;$47 = $39;
 }
 $42 = (_llvm_bswap_i32(($41|0))|0);
 HEAP32[$35>>2] = $42;
 $43 = (($this) + 92|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)>($47>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$43,4);
  $$pre$i$i$i8 = HEAP32[$43>>2]|0;
  $49 = $$pre$i$i$i8;
 } else {
  $48 = HEAP32[$45>>2]|0;
  HEAP32[$43>>2] = $48;
  HEAP32[$1>>2] = $44;
  $49 = $48;
 }
 $50 = (_llvm_bswap_i32(($49|0))|0);
 HEAP32[$43>>2] = $50;
 if ((($50|0) == 2)) {
  HEAP32[$43>>2] = 0;
 } else if ((($50|0) == 1)) {
  HEAP32[$43>>2] = 6;
 }
 $51 = (($this) + 96|0);
 $52 = HEAP32[$1>>2]|0;
 $53 = (($52) + 4|0);
 $54 = HEAP32[$4>>2]|0;
 $55 = ($53>>>0)>($54>>>0);
 if ($55) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$51,4);
  $$pre$i$i$i10 = HEAP32[$51>>2]|0;
  $57 = $$pre$i$i$i10;
 } else {
  $56 = HEAP32[$52>>2]|0;
  HEAP32[$51>>2] = $56;
  HEAP32[$1>>2] = $53;
  $57 = $56;
 }
 $58 = (_llvm_bswap_i32(($57|0))|0);
 HEAP32[$51>>2] = $58;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $59 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$59,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $60 = (($this) + 36|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$60,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $61 = (($this) + 60|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($61,$transfer);
 $62 = (($this) + 64|0);
 $63 = HEAP32[$1>>2]|0;
 $64 = (($63) + 4|0);
 $65 = HEAP32[$4>>2]|0;
 $66 = ($64>>>0)>($65>>>0);
 if ($66) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$62,4);
  $$pre$i$i$i3$i$i$i = HEAP32[$62>>2]|0;
  $$pre$i$i$i12 = HEAP32[$1>>2]|0;
  $$pre6$i$i$i = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i4$i$i$iZ2D = $62;$69 = $$pre$i$i$i3$i$i$i;$73 = $$pre$i$i$i12;$75 = $$pre6$i$i$i;
 } else {
  $67 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$62>>2] = $67;
  HEAP32[$1>>2] = $64;
  $68 = (HEAPF32[tempDoublePtr>>2]=$67,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4$i$i$iZ2D = $62;$69 = $68;$73 = $64;$75 = $65;
 }
 $70 = (_llvm_bswap_i32(($69|0))|0);
 HEAP32[$$pre$phi$i$i$i4$i$i$iZ2D>>2] = $70;
 $71 = (($this) + 68|0);
 $72 = (($73) + 4|0);
 $74 = ($72>>>0)>($75>>>0);
 if ($74) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$71,4);
  $$pre$i$i$i$i$i$i = HEAP32[$71>>2]|0;
  $$pre86 = HEAP32[$1>>2]|0;
  $$pre87 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i$i$i$iZ2D = $71;$78 = $$pre$i$i$i$i$i$i;$82 = $$pre86;$84 = $$pre87;
 } else {
  $76 = Math_fround(HEAPF32[$73>>2]);
  HEAPF32[$71>>2] = $76;
  HEAP32[$1>>2] = $72;
  $77 = (HEAPF32[tempDoublePtr>>2]=$76,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i$i$i$iZ2D = $71;$78 = $77;$82 = $72;$84 = $75;
 }
 $79 = (_llvm_bswap_i32(($78|0))|0);
 HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $79;
 $80 = (($this) + 100|0);
 $81 = (($82) + 4|0);
 $83 = ($81>>>0)>($84>>>0);
 if ($83) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$80,4);
  $$pre$i$i$i13 = HEAP32[$80>>2]|0;
  $$pre88 = HEAP32[$1>>2]|0;
  $$pre89 = HEAP32[$4>>2]|0;
  $86 = $$pre$i$i$i13;$90 = $$pre88;$92 = $$pre89;
 } else {
  $85 = HEAP32[$82>>2]|0;
  HEAP32[$80>>2] = $85;
  HEAP32[$1>>2] = $81;
  $86 = $85;$90 = $81;$92 = $84;
 }
 $87 = (_llvm_bswap_i32(($86|0))|0);
 HEAP32[$80>>2] = $87;
 $88 = (($this) + 104|0);
 $89 = (($90) + 4|0);
 $91 = ($89>>>0)>($92>>>0);
 if ($91) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$88,4);
  $$pre$i$i$i15 = HEAP32[$88>>2]|0;
  $$pre90 = HEAP32[$1>>2]|0;
  $$pre91 = HEAP32[$4>>2]|0;
  $100 = $$pre91;$94 = $$pre$i$i$i15;$98 = $$pre90;
 } else {
  $93 = HEAP32[$90>>2]|0;
  HEAP32[$88>>2] = $93;
  HEAP32[$1>>2] = $89;
  $100 = $92;$94 = $93;$98 = $89;
 }
 $95 = (_llvm_bswap_i32(($94|0))|0);
 HEAP32[$88>>2] = $95;
 $96 = (($this) + 108|0);
 $97 = (($98) + 4|0);
 $99 = ($97>>>0)>($100>>>0);
 if ($99) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$96,4);
  $$pre$i$i$i17 = HEAP32[$96>>2]|0;
  $$pre92 = HEAP32[$1>>2]|0;
  $$pre93 = HEAP32[$4>>2]|0;
  $102 = $$pre$i$i$i17;$106 = $$pre92;$108 = $$pre93;
 } else {
  $101 = HEAP32[$98>>2]|0;
  HEAP32[$96>>2] = $101;
  HEAP32[$1>>2] = $97;
  $102 = $101;$106 = $97;$108 = $100;
 }
 $103 = (_llvm_bswap_i32(($102|0))|0);
 HEAP32[$96>>2] = $103;
 $104 = (($this) + 112|0);
 $105 = (($106) + 4|0);
 $107 = ($105>>>0)>($108>>>0);
 if ($107) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$104,4);
  $$pre$i$i$i19 = HEAP32[$104>>2]|0;
  $$pre94 = HEAP32[$1>>2]|0;
  $$pre95 = HEAP32[$4>>2]|0;
  $110 = $$pre$i$i$i19;$114 = $$pre94;$116 = $$pre95;
 } else {
  $109 = HEAP32[$106>>2]|0;
  HEAP32[$104>>2] = $109;
  HEAP32[$1>>2] = $105;
  $110 = $109;$114 = $105;$116 = $108;
 }
 $111 = (_llvm_bswap_i32(($110|0))|0);
 HEAP32[$104>>2] = $111;
 $112 = (($this) + 128|0);
 $113 = (($114) + 4|0);
 $115 = ($113>>>0)>($116>>>0);
 if ($115) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$112,4);
  $$pre$i$i$i21 = HEAP32[$112>>2]|0;
  $$pre96 = HEAP32[$1>>2]|0;
  $$pre97 = HEAP32[$4>>2]|0;
  $118 = $$pre$i$i$i21;$122 = $$pre96;$124 = $$pre97;
 } else {
  $117 = HEAP32[$114>>2]|0;
  HEAP32[$112>>2] = $117;
  HEAP32[$1>>2] = $113;
  $118 = $117;$122 = $113;$124 = $116;
 }
 $119 = (_llvm_bswap_i32(($118|0))|0);
 HEAP32[$112>>2] = $119;
 $120 = (($this) + 132|0);
 $121 = (($122) + 4|0);
 $123 = ($121>>>0)>($124>>>0);
 if ($123) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$120,4);
  $$pre$i$i$i23 = HEAP32[$120>>2]|0;
  $$pre98 = HEAP32[$1>>2]|0;
  $$pre99 = HEAP32[$4>>2]|0;
  $126 = $$pre$i$i$i23;$130 = $$pre98;$132 = $$pre99;
 } else {
  $125 = HEAP32[$122>>2]|0;
  HEAP32[$120>>2] = $125;
  HEAP32[$1>>2] = $121;
  $126 = $125;$130 = $121;$132 = $124;
 }
 $127 = (_llvm_bswap_i32(($126|0))|0);
 HEAP32[$120>>2] = $127;
 $128 = (($this) + 136|0);
 $129 = (($130) + 4|0);
 $131 = ($129>>>0)>($132>>>0);
 if ($131) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$128,4);
  $$pre$i$i$i25 = HEAP32[$128>>2]|0;
  $$pre100 = HEAP32[$1>>2]|0;
  $$pre101 = HEAP32[$4>>2]|0;
  $134 = $$pre$i$i$i25;$138 = $$pre100;$140 = $$pre101;
 } else {
  $133 = HEAP32[$130>>2]|0;
  HEAP32[$128>>2] = $133;
  HEAP32[$1>>2] = $129;
  $134 = $133;$138 = $129;$140 = $132;
 }
 $135 = (_llvm_bswap_i32(($134|0))|0);
 HEAP32[$128>>2] = $135;
 $136 = (($this) + 140|0);
 $137 = (($138) + 1|0);
 $139 = ($137>>>0)>($140>>>0);
 if ($139) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$136,1);
  $$pre102 = HEAP32[$1>>2]|0;
  $146 = $$pre102;
 } else {
  $141 = HEAP8[$138>>0]|0;
  HEAP8[$136>>0] = $141;
  $142 = HEAP32[$1>>2]|0;
  $143 = (($142) + 1|0);
  HEAP32[$1>>2] = $143;
  $146 = $143;
 }
 $144 = (($this) + 141|0);
 $145 = (($146) + 1|0);
 $147 = HEAP32[$4>>2]|0;
 $148 = ($145>>>0)>($147>>>0);
 if ($148) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$144,1);
  $$pre103 = HEAP32[$1>>2]|0;
  $154 = $$pre103;
 } else {
  $149 = HEAP8[$146>>0]|0;
  HEAP8[$144>>0] = $149;
  $150 = HEAP32[$1>>2]|0;
  $151 = (($150) + 1|0);
  HEAP32[$1>>2] = $151;
  $154 = $151;
 }
 $152 = (($this) + 142|0);
 $153 = (($154) + 1|0);
 $155 = HEAP32[$4>>2]|0;
 $156 = ($153>>>0)>($155>>>0);
 if ($156) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$152,1);
  $$pre104 = HEAP32[$1>>2]|0;
  $162 = $$pre104;
 } else {
  $157 = HEAP8[$154>>0]|0;
  HEAP8[$152>>0] = $157;
  $158 = HEAP32[$1>>2]|0;
  $159 = (($158) + 1|0);
  HEAP32[$1>>2] = $159;
  $162 = $159;
 }
 $160 = (($this) + 143|0);
 $161 = (($162) + 1|0);
 $163 = HEAP32[$4>>2]|0;
 $164 = ($161>>>0)>($163>>>0);
 if ($164) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$160,1);
 } else {
  $165 = HEAP8[$162>>0]|0;
  HEAP8[$160>>0] = $165;
  $166 = HEAP32[$1>>2]|0;
  $167 = (($166) + 1|0);
  HEAP32[$1>>2] = $167;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $168 = (($this) + 148|0);
 $169 = HEAP32[$1>>2]|0;
 $170 = (($169) + 4|0);
 $171 = HEAP32[$4>>2]|0;
 $172 = ($170>>>0)>($171>>>0);
 if ($172) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$168,4);
  $$pre$i$i$i31 = HEAP32[$168>>2]|0;
  $$pre105 = HEAP32[$1>>2]|0;
  $$pre106 = HEAP32[$4>>2]|0;
  $174 = $$pre$i$i$i31;$178 = $$pre105;$180 = $$pre106;
 } else {
  $173 = HEAP32[$169>>2]|0;
  HEAP32[$168>>2] = $173;
  HEAP32[$1>>2] = $170;
  $174 = $173;$178 = $170;$180 = $171;
 }
 $175 = (_llvm_bswap_i32(($174|0))|0);
 HEAP32[$168>>2] = $175;
 $176 = (($this) + 144|0);
 $177 = (($178) + 4|0);
 $179 = ($177>>>0)>($180>>>0);
 if ($179) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$176,4);
  $$pre$i$i$i33 = HEAP32[$176>>2]|0;
  $$pre107 = HEAP32[$1>>2]|0;
  $$pre108 = HEAP32[$4>>2]|0;
  $182 = $$pre$i$i$i33;$186 = $$pre107;$188 = $$pre108;
 } else {
  $181 = HEAP32[$178>>2]|0;
  HEAP32[$176>>2] = $181;
  HEAP32[$1>>2] = $177;
  $182 = $181;$186 = $177;$188 = $180;
 }
 $183 = (_llvm_bswap_i32(($182|0))|0);
 HEAP32[$176>>2] = $183;
 $184 = (($this) + 152|0);
 $185 = (($186) + 4|0);
 $187 = ($185>>>0)>($188>>>0);
 if ($187) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$184,4);
  $$pre$i$i$i35 = HEAP32[$184>>2]|0;
  $$pre109 = HEAP32[$1>>2]|0;
  $$pre110 = HEAP32[$4>>2]|0;
  $190 = $$pre$i$i$i35;$194 = $$pre109;$196 = $$pre110;
 } else {
  $189 = HEAP32[$186>>2]|0;
  HEAP32[$184>>2] = $189;
  HEAP32[$1>>2] = $185;
  $190 = $189;$194 = $185;$196 = $188;
 }
 $191 = (_llvm_bswap_i32(($190|0))|0);
 HEAP32[$184>>2] = $191;
 $192 = (($this) + 116|0);
 $193 = (($194) + 4|0);
 $195 = ($193>>>0)>($196>>>0);
 if ($195) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$192,4);
  $$pre$i$i$i37 = HEAP32[$192>>2]|0;
  $$pre111 = HEAP32[$1>>2]|0;
  $$pre112 = HEAP32[$4>>2]|0;
  $198 = $$pre$i$i$i37;$202 = $$pre111;$204 = $$pre112;
 } else {
  $197 = HEAP32[$194>>2]|0;
  HEAP32[$192>>2] = $197;
  HEAP32[$1>>2] = $193;
  $198 = $197;$202 = $193;$204 = $196;
 }
 $199 = (_llvm_bswap_i32(($198|0))|0);
 HEAP32[$192>>2] = $199;
 $200 = (($this) + 156|0);
 $201 = (($202) + 1|0);
 $203 = ($201>>>0)>($204>>>0);
 if ($203) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$200,1);
  $$pre113 = HEAP32[$1>>2]|0;
  $210 = $$pre113;
 } else {
  $205 = HEAP8[$202>>0]|0;
  HEAP8[$200>>0] = $205;
  $206 = HEAP32[$1>>2]|0;
  $207 = (($206) + 1|0);
  HEAP32[$1>>2] = $207;
  $210 = $207;
 }
 $208 = (($this) + 157|0);
 $209 = (($210) + 1|0);
 $211 = HEAP32[$4>>2]|0;
 $212 = ($209>>>0)>($211>>>0);
 if ($212) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$208,1);
  $$pre114 = HEAP32[$1>>2]|0;
  $218 = $$pre114;
 } else {
  $213 = HEAP8[$210>>0]|0;
  HEAP8[$208>>0] = $213;
  $214 = HEAP32[$1>>2]|0;
  $215 = (($214) + 1|0);
  HEAP32[$1>>2] = $215;
  $218 = $215;
 }
 $216 = (($this) + 158|0);
 $217 = (($218) + 1|0);
 $219 = HEAP32[$4>>2]|0;
 $220 = ($217>>>0)>($219>>>0);
 if ($220) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$216,1);
  $$pre115 = HEAP32[$1>>2]|0;
  $226 = $$pre115;
 } else {
  $221 = HEAP8[$218>>0]|0;
  HEAP8[$216>>0] = $221;
  $222 = HEAP32[$1>>2]|0;
  $223 = (($222) + 1|0);
  HEAP32[$1>>2] = $223;
  $226 = $223;
 }
 $224 = (($this) + 159|0);
 $225 = (($226) + 1|0);
 $227 = HEAP32[$4>>2]|0;
 $228 = ($225>>>0)>($227>>>0);
 if ($228) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$224,1);
  $$pre116 = HEAP32[$1>>2]|0;
  $234 = $$pre116;
 } else {
  $229 = HEAP8[$226>>0]|0;
  HEAP8[$224>>0] = $229;
  $230 = HEAP32[$1>>2]|0;
  $231 = (($230) + 1|0);
  HEAP32[$1>>2] = $231;
  $234 = $231;
 }
 $232 = (($this) + 160|0);
 $233 = (($234) + 1|0);
 $235 = HEAP32[$4>>2]|0;
 $236 = ($233>>>0)>($235>>>0);
 if ($236) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$232,1);
  $$pre117 = HEAP32[$1>>2]|0;
  $242 = $$pre117;
 } else {
  $237 = HEAP8[$234>>0]|0;
  HEAP8[$232>>0] = $237;
  $238 = HEAP32[$1>>2]|0;
  $239 = (($238) + 1|0);
  HEAP32[$1>>2] = $239;
  $242 = $239;
 }
 $240 = (($this) + 161|0);
 $241 = (($242) + 1|0);
 $243 = HEAP32[$4>>2]|0;
 $244 = ($241>>>0)>($243>>>0);
 if ($244) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$240,1);
  $$pre118 = HEAP32[$1>>2]|0;
  $250 = $$pre118;
 } else {
  $245 = HEAP8[$242>>0]|0;
  HEAP8[$240>>0] = $245;
  $246 = HEAP32[$1>>2]|0;
  $247 = (($246) + 1|0);
  HEAP32[$1>>2] = $247;
  $250 = $247;
 }
 $248 = (($this) + 162|0);
 $249 = (($250) + 1|0);
 $251 = HEAP32[$4>>2]|0;
 $252 = ($249>>>0)>($251>>>0);
 if ($252) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$248,1);
 } else {
  $253 = HEAP8[$250>>0]|0;
  HEAP8[$248>>0] = $253;
  $254 = HEAP32[$1>>2]|0;
  $255 = (($254) + 1|0);
  HEAP32[$1>>2] = $255;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $256 = (($this) + 163|0);
 $257 = HEAP32[$1>>2]|0;
 $258 = (($257) + 1|0);
 $259 = HEAP32[$4>>2]|0;
 $260 = ($258>>>0)>($259>>>0);
 if ($260) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$256,1);
  $$pre119 = HEAP32[$1>>2]|0;
  $266 = $$pre119;
 } else {
  $261 = HEAP8[$257>>0]|0;
  HEAP8[$256>>0] = $261;
  $262 = HEAP32[$1>>2]|0;
  $263 = (($262) + 1|0);
  HEAP32[$1>>2] = $263;
  $266 = $263;
 }
 $264 = (($this) + 164|0);
 $265 = (($266) + 1|0);
 $267 = HEAP32[$4>>2]|0;
 $268 = ($265>>>0)>($267>>>0);
 if ($268) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$264,1);
  $$pre120 = HEAP32[$1>>2]|0;
  $274 = $$pre120;
 } else {
  $269 = HEAP8[$266>>0]|0;
  HEAP8[$264>>0] = $269;
  $270 = HEAP32[$1>>2]|0;
  $271 = (($270) + 1|0);
  HEAP32[$1>>2] = $271;
  $274 = $271;
 }
 $272 = (($this) + 165|0);
 $273 = (($274) + 1|0);
 $275 = HEAP32[$4>>2]|0;
 $276 = ($273>>>0)>($275>>>0);
 if ($276) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$272,1);
  $$pre121 = HEAP32[$1>>2]|0;
  $282 = $$pre121;
 } else {
  $277 = HEAP8[$274>>0]|0;
  HEAP8[$272>>0] = $277;
  $278 = HEAP32[$1>>2]|0;
  $279 = (($278) + 1|0);
  HEAP32[$1>>2] = $279;
  $282 = $279;
 }
 $280 = (($this) + 166|0);
 $281 = (($282) + 1|0);
 $283 = HEAP32[$4>>2]|0;
 $284 = ($281>>>0)>($283>>>0);
 if ($284) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$280,1);
  $$pre122 = HEAP32[$1>>2]|0;
  $290 = $$pre122;
 } else {
  $285 = HEAP8[$282>>0]|0;
  HEAP8[$280>>0] = $285;
  $286 = HEAP32[$1>>2]|0;
  $287 = (($286) + 1|0);
  HEAP32[$1>>2] = $287;
  $290 = $287;
 }
 $288 = (($this) + 167|0);
 $289 = (($290) + 1|0);
 $291 = HEAP32[$4>>2]|0;
 $292 = ($289>>>0)>($291>>>0);
 if ($292) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$288,1);
  $$pre123 = HEAP32[$1>>2]|0;
  $298 = $$pre123;
 } else {
  $293 = HEAP8[$290>>0]|0;
  HEAP8[$288>>0] = $293;
  $294 = HEAP32[$1>>2]|0;
  $295 = (($294) + 1|0);
  HEAP32[$1>>2] = $295;
  $298 = $295;
 }
 $296 = (($this) + 168|0);
 $297 = (($298) + 1|0);
 $299 = HEAP32[$4>>2]|0;
 $300 = ($297>>>0)>($299>>>0);
 if ($300) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$296,1);
  $$pre124 = HEAP32[$1>>2]|0;
  $306 = $$pre124;
 } else {
  $301 = HEAP8[$298>>0]|0;
  HEAP8[$296>>0] = $301;
  $302 = HEAP32[$1>>2]|0;
  $303 = (($302) + 1|0);
  HEAP32[$1>>2] = $303;
  $306 = $303;
 }
 $304 = (($this) + 169|0);
 $305 = (($306) + 1|0);
 $307 = HEAP32[$4>>2]|0;
 $308 = ($305>>>0)>($307>>>0);
 if ($308) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$304,1);
  $$pre125 = HEAP32[$1>>2]|0;
  $314 = $$pre125;
 } else {
  $309 = HEAP8[$306>>0]|0;
  HEAP8[$304>>0] = $309;
  $310 = HEAP32[$1>>2]|0;
  $311 = (($310) + 1|0);
  HEAP32[$1>>2] = $311;
  $314 = $311;
 }
 $312 = (($this) + 170|0);
 $313 = (($314) + 1|0);
 $315 = HEAP32[$4>>2]|0;
 $316 = ($313>>>0)>($315>>>0);
 if ($316) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$312,1);
  $$pre126 = HEAP32[$1>>2]|0;
  $322 = $$pre126;
 } else {
  $317 = HEAP8[$314>>0]|0;
  HEAP8[$312>>0] = $317;
  $318 = HEAP32[$1>>2]|0;
  $319 = (($318) + 1|0);
  HEAP32[$1>>2] = $319;
  $322 = $319;
 }
 $320 = (($this) + 171|0);
 $321 = (($322) + 1|0);
 $323 = HEAP32[$4>>2]|0;
 $324 = ($321>>>0)>($323>>>0);
 if ($324) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$320,1);
  $$pre127 = HEAP32[$1>>2]|0;
  $330 = $$pre127;
 } else {
  $325 = HEAP8[$322>>0]|0;
  HEAP8[$320>>0] = $325;
  $326 = HEAP32[$1>>2]|0;
  $327 = (($326) + 1|0);
  HEAP32[$1>>2] = $327;
  $330 = $327;
 }
 $328 = (($this) + 180|0);
 $329 = (($330) + 1|0);
 $331 = HEAP32[$4>>2]|0;
 $332 = ($329>>>0)>($331>>>0);
 if ($332) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$328,1);
  $$pre128 = HEAP32[$1>>2]|0;
  $338 = $$pre128;
 } else {
  $333 = HEAP8[$330>>0]|0;
  HEAP8[$328>>0] = $333;
  $334 = HEAP32[$1>>2]|0;
  $335 = (($334) + 1|0);
  HEAP32[$1>>2] = $335;
  $338 = $335;
 }
 $336 = (($this) + 181|0);
 $337 = (($338) + 1|0);
 $339 = HEAP32[$4>>2]|0;
 $340 = ($337>>>0)>($339>>>0);
 if ($340) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$336,1);
  $$pre129 = HEAP32[$1>>2]|0;
  $346 = $$pre129;
 } else {
  $341 = HEAP8[$338>>0]|0;
  HEAP8[$336>>0] = $341;
  $342 = HEAP32[$1>>2]|0;
  $343 = (($342) + 1|0);
  HEAP32[$1>>2] = $343;
  $346 = $343;
 }
 $344 = (($this) + 172|0);
 $345 = (($346) + 1|0);
 $347 = HEAP32[$4>>2]|0;
 $348 = ($345>>>0)>($347>>>0);
 if ($348) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$344,1);
  $$pre130 = HEAP32[$1>>2]|0;
  $354 = $$pre130;
 } else {
  $349 = HEAP8[$346>>0]|0;
  HEAP8[$344>>0] = $349;
  $350 = HEAP32[$1>>2]|0;
  $351 = (($350) + 1|0);
  HEAP32[$1>>2] = $351;
  $354 = $351;
 }
 $352 = (($this) + 182|0);
 $353 = (($354) + 1|0);
 $355 = HEAP32[$4>>2]|0;
 $356 = ($353>>>0)>($355>>>0);
 if ($356) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$352,1);
  $$pre131 = HEAP32[$1>>2]|0;
  $362 = $$pre131;
 } else {
  $357 = HEAP8[$354>>0]|0;
  HEAP8[$352>>0] = $357;
  $358 = HEAP32[$1>>2]|0;
  $359 = (($358) + 1|0);
  HEAP32[$1>>2] = $359;
  $362 = $359;
 }
 $360 = (($this) + 183|0);
 $361 = (($362) + 1|0);
 $363 = HEAP32[$4>>2]|0;
 $364 = ($361>>>0)>($363>>>0);
 if ($364) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$360,1);
  $$pre132 = HEAP32[$1>>2]|0;
  $370 = $$pre132;
 } else {
  $365 = HEAP8[$362>>0]|0;
  HEAP8[$360>>0] = $365;
  $366 = HEAP32[$1>>2]|0;
  $367 = (($366) + 1|0);
  HEAP32[$1>>2] = $367;
  $370 = $367;
 }
 $368 = (($this) + 184|0);
 $369 = (($370) + 1|0);
 $371 = HEAP32[$4>>2]|0;
 $372 = ($369>>>0)>($371>>>0);
 if ($372) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$368,1);
  $$pre133 = HEAP32[$1>>2]|0;
  $378 = $$pre133;
 } else {
  $373 = HEAP8[$370>>0]|0;
  HEAP8[$368>>0] = $373;
  $374 = HEAP32[$1>>2]|0;
  $375 = (($374) + 1|0);
  HEAP32[$1>>2] = $375;
  $378 = $375;
 }
 $376 = (($this) + 185|0);
 $377 = (($378) + 1|0);
 $379 = HEAP32[$4>>2]|0;
 $380 = ($377>>>0)>($379>>>0);
 if ($380) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$376,1);
  $$pre134 = HEAP32[$1>>2]|0;
  $386 = $$pre134;
 } else {
  $381 = HEAP8[$378>>0]|0;
  HEAP8[$376>>0] = $381;
  $382 = HEAP32[$1>>2]|0;
  $383 = (($382) + 1|0);
  HEAP32[$1>>2] = $383;
  $386 = $383;
 }
 $384 = (($this) + 186|0);
 $385 = (($386) + 1|0);
 $387 = HEAP32[$4>>2]|0;
 $388 = ($385>>>0)>($387>>>0);
 if ($388) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$384,1);
  $$pre135 = HEAP32[$1>>2]|0;
  $394 = $$pre135;
 } else {
  $389 = HEAP8[$386>>0]|0;
  HEAP8[$384>>0] = $389;
  $390 = HEAP32[$1>>2]|0;
  $391 = (($390) + 1|0);
  HEAP32[$1>>2] = $391;
  $394 = $391;
 }
 $392 = (($this) + 192|0);
 $393 = (($394) + 1|0);
 $395 = HEAP32[$4>>2]|0;
 $396 = ($393>>>0)>($395>>>0);
 if ($396) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$392,1);
  $$pre136 = HEAP32[$1>>2]|0;
  $402 = $$pre136;
 } else {
  $397 = HEAP8[$394>>0]|0;
  HEAP8[$392>>0] = $397;
  $398 = HEAP32[$1>>2]|0;
  $399 = (($398) + 1|0);
  HEAP32[$1>>2] = $399;
  $402 = $399;
 }
 $400 = (($this) + 173|0);
 $401 = (($402) + 1|0);
 $403 = HEAP32[$4>>2]|0;
 $404 = ($401>>>0)>($403>>>0);
 if ($404) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$400,1);
 } else {
  $405 = HEAP8[$402>>0]|0;
  HEAP8[$400>>0] = $405;
  $406 = HEAP32[$1>>2]|0;
  $407 = (($406) + 1|0);
  HEAP32[$1>>2] = $407;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $408 = (($this) + 176|0);
 $409 = HEAP32[$1>>2]|0;
 $410 = (($409) + 4|0);
 $411 = HEAP32[$4>>2]|0;
 $412 = ($410>>>0)>($411>>>0);
 if ($412) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$408,4);
  $$pre$i$i$i65 = HEAP32[$408>>2]|0;
  $$pre137 = HEAP32[$1>>2]|0;
  $$pre138 = HEAP32[$4>>2]|0;
  $414 = $$pre$i$i$i65;$418 = $$pre137;$420 = $$pre138;
 } else {
  $413 = HEAP32[$409>>2]|0;
  HEAP32[$408>>2] = $413;
  HEAP32[$1>>2] = $410;
  $414 = $413;$418 = $410;$420 = $411;
 }
 $415 = (_llvm_bswap_i32(($414|0))|0);
 HEAP32[$408>>2] = $415;
 $416 = (($this) + 188|0);
 $417 = (($418) + 4|0);
 $419 = ($417>>>0)>($420>>>0);
 if ($419) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$416,4);
  $$pre$i$i$i67 = HEAP32[$416>>2]|0;
  $$pre139 = HEAP32[$1>>2]|0;
  $$pre140 = HEAP32[$4>>2]|0;
  $422 = $$pre$i$i$i67;$426 = $$pre139;$428 = $$pre140;
 } else {
  $421 = HEAP32[$418>>2]|0;
  HEAP32[$416>>2] = $421;
  HEAP32[$1>>2] = $417;
  $422 = $421;$426 = $417;$428 = $420;
 }
 $423 = (_llvm_bswap_i32(($422|0))|0);
 HEAP32[$416>>2] = $423;
 $424 = (($this) + 193|0);
 $425 = (($426) + 1|0);
 $427 = ($425>>>0)>($428>>>0);
 if ($427) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$424,1);
  $$pre141 = HEAP32[$1>>2]|0;
  $434 = $$pre141;
 } else {
  $429 = HEAP8[$426>>0]|0;
  HEAP8[$424>>0] = $429;
  $430 = HEAP32[$1>>2]|0;
  $431 = (($430) + 1|0);
  HEAP32[$1>>2] = $431;
  $434 = $431;
 }
 $432 = (($this) + 194|0);
 $433 = (($434) + 1|0);
 $435 = HEAP32[$4>>2]|0;
 $436 = ($433>>>0)>($435>>>0);
 if ($436) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$432,1);
 } else {
  $437 = HEAP8[$434>>0]|0;
  HEAP8[$432>>0] = $437;
  $438 = HEAP32[$1>>2]|0;
  $439 = (($438) + 1|0);
  HEAP32[$1>>2] = $439;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $440 = (($this) + 196|0);
 $441 = HEAP32[$1>>2]|0;
 $442 = (($441) + 4|0);
 $443 = HEAP32[$4>>2]|0;
 $444 = ($442>>>0)>($443>>>0);
 if ($444) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$440,4);
  $$pre$i$i$i70 = HEAP32[$440>>2]|0;
  $446 = $$pre$i$i$i70;
 } else {
  $445 = HEAP32[$441>>2]|0;
  HEAP32[$440>>2] = $445;
  HEAP32[$1>>2] = $442;
  $446 = $445;
 }
 $447 = (_llvm_bswap_i32(($446|0))|0);
 HEAP32[$440>>2] = $447;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $448 = (($this) + 204|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($448,$transfer);
 $449 = (($this) + 208|0);
 $450 = HEAP32[$1>>2]|0;
 $451 = (($450) + 4|0);
 $452 = HEAP32[$4>>2]|0;
 $453 = ($451>>>0)>($452>>>0);
 if ($453) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$449,4);
  $$pre$i$i$i72 = HEAP32[$449>>2]|0;
  $$pre142 = HEAP32[$1>>2]|0;
  $$pre143 = HEAP32[$4>>2]|0;
  $455 = $$pre$i$i$i72;$459 = $$pre142;$461 = $$pre143;
 } else {
  $454 = HEAP32[$450>>2]|0;
  HEAP32[$449>>2] = $454;
  HEAP32[$1>>2] = $451;
  $455 = $454;$459 = $451;$461 = $452;
 }
 $456 = (_llvm_bswap_i32(($455|0))|0);
 HEAP32[$449>>2] = $456;
 $457 = (($this) + 212|0);
 $458 = (($459) + 4|0);
 $460 = ($458>>>0)>($461>>>0);
 if ($460) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$457,4);
  $$pre$i$i$i74 = HEAP32[$457>>2]|0;
  $$pre144 = HEAP32[$1>>2]|0;
  $$pre145 = HEAP32[$4>>2]|0;
  $463 = $$pre$i$i$i74;$467 = $$pre144;$469 = $$pre145;
 } else {
  $462 = HEAP32[$459>>2]|0;
  HEAP32[$457>>2] = $462;
  HEAP32[$1>>2] = $458;
  $463 = $462;$467 = $458;$469 = $461;
 }
 $464 = (_llvm_bswap_i32(($463|0))|0);
 HEAP32[$457>>2] = $464;
 $465 = (($this) + 216|0);
 $466 = (($467) + 1|0);
 $468 = ($466>>>0)>($469>>>0);
 if ($468) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$465,1);
 } else {
  $470 = HEAP8[$467>>0]|0;
  HEAP8[$465>>0] = $470;
  $471 = HEAP32[$1>>2]|0;
  $472 = (($471) + 1|0);
  HEAP32[$1>>2] = $472;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $473 = (($this) + 120|0);
 __ZN12AspectRatios8TransferI18StreamedBinaryReadILb1EEEEvRT_($473,$transfer);
 $474 = (($this) + 244|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$474,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $475 = (($this) + 268|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$475,0);
 $476 = (($this) + 284|0);
 $477 = HEAP32[$1>>2]|0;
 $478 = (($477) + 1|0);
 $479 = HEAP32[$4>>2]|0;
 $480 = ($478>>>0)>($479>>>0);
 if ($480) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$476,1);
  $$pre146 = HEAP32[$1>>2]|0;
  $486 = $$pre146;
 } else {
  $481 = HEAP8[$477>>0]|0;
  HEAP8[$476>>0] = $481;
  $482 = HEAP32[$1>>2]|0;
  $483 = (($482) + 1|0);
  HEAP32[$1>>2] = $483;
  $486 = $483;
 }
 $484 = (($this) + 285|0);
 $485 = (($486) + 1|0);
 $487 = HEAP32[$4>>2]|0;
 $488 = ($485>>>0)>($487>>>0);
 if ($488) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$484,1);
  $$pre147 = HEAP32[$1>>2]|0;
  $494 = $$pre147;
 } else {
  $489 = HEAP8[$486>>0]|0;
  HEAP8[$484>>0] = $489;
  $490 = HEAP32[$1>>2]|0;
  $491 = (($490) + 1|0);
  HEAP32[$1>>2] = $491;
  $494 = $491;
 }
 $492 = (($this) + 286|0);
 $493 = (($494) + 1|0);
 $495 = HEAP32[$4>>2]|0;
 $496 = ($493>>>0)>($495>>>0);
 if ($496) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$492,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $497 = HEAP8[$494>>0]|0;
  HEAP8[$492>>0] = $497;
  $498 = HEAP32[$1>>2]|0;
  $499 = (($498) + 1|0);
  HEAP32[$1>>2] = $499;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN12AspectRatios8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 20|0);
 $2 = (($this) + 1|0);
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 1|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = ($4>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$2,1);
  $$pre = HEAP32[$0>>2]|0;
  $12 = $$pre;
 } else {
  $7 = HEAP8[$3>>0]|0;
  HEAP8[$2>>0] = $7;
  $8 = HEAP32[$0>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$0>>2] = $9;
  $12 = $9;
 }
 $10 = (($this) + 2|0);
 $11 = (($12) + 1|0);
 $13 = HEAP32[$1>>2]|0;
 $14 = ($11>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,1);
  $$pre3 = HEAP32[$0>>2]|0;
  $24 = $$pre3;
 } else {
  $19 = HEAP8[$12>>0]|0;
  HEAP8[$10>>0] = $19;
  $20 = HEAP32[$0>>2]|0;
  $21 = (($20) + 1|0);
  HEAP32[$0>>2] = $21;
  $24 = $21;
 }
 $22 = (($this) + 3|0);
 $23 = (($24) + 1|0);
 $25 = HEAP32[$1>>2]|0;
 $26 = ($23>>>0)>($25>>>0);
 if ($26) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$22,1);
  $$pre4 = HEAP32[$0>>2]|0;
  $32 = $$pre4;
 } else {
  $27 = HEAP8[$24>>0]|0;
  HEAP8[$22>>0] = $27;
  $28 = HEAP32[$0>>2]|0;
  $29 = (($28) + 1|0);
  HEAP32[$0>>2] = $29;
  $32 = $29;
 }
 $30 = (($this) + 4|0);
 $31 = (($32) + 1|0);
 $33 = HEAP32[$1>>2]|0;
 $34 = ($31>>>0)>($33>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$30,1);
  $$pre5 = HEAP32[$0>>2]|0;
  $16 = $$pre5;
 } else {
  $35 = HEAP8[$32>>0]|0;
  HEAP8[$30>>0] = $35;
  $36 = HEAP32[$0>>2]|0;
  $37 = (($36) + 1|0);
  HEAP32[$0>>2] = $37;
  $16 = $37;
 }
 $38 = (($16) + 1|0);
 $39 = HEAP32[$1>>2]|0;
 $40 = ($38>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $15 = HEAP8[$16>>0]|0;
  HEAP8[$this>>0] = $15;
  $17 = HEAP32[$0>>2]|0;
  $18 = (($17) + 1|0);
  HEAP32[$0>>2] = $18;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN14PlayerSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre100 = 0, $$pre101 = 0, $$pre102 = 0, $$pre103 = 0, $$pre104 = 0, $$pre105 = 0, $$pre106 = 0, $$pre107 = 0, $$pre108 = 0, $$pre109 = 0, $$pre110 = 0, $$pre111 = 0, $$pre112 = 0, $$pre113 = 0, $$pre114 = 0, $$pre115 = 0, $$pre116 = 0, $$pre117 = 0;
 var $$pre118 = 0, $$pre119 = 0, $$pre120 = 0, $$pre121 = 0, $$pre122 = 0, $$pre123 = 0, $$pre124 = 0, $$pre125 = 0, $$pre2$i$i$i = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0, $$pre60 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0;
 var $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $$pre71 = 0, $$pre72 = 0, $$pre73 = 0, $$pre74 = 0, $$pre75 = 0, $$pre76 = 0, $$pre77 = 0, $$pre78 = 0, $$pre79 = 0, $$pre80 = 0, $$pre81 = 0, $$pre82 = 0, $$pre83 = 0, $$pre84 = 0, $$pre85 = 0, $$pre86 = 0, $$pre87 = 0;
 var $$pre88 = 0, $$pre89 = 0, $$pre90 = 0, $$pre91 = 0, $$pre92 = 0, $$pre93 = 0, $$pre94 = 0, $$pre95 = 0, $$pre96 = 0, $$pre97 = 0, $$pre98 = 0, $$pre99 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $10 = (($this) + 76|0);
 $11 = HEAP32[$1>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$4>>2]|0;
 $14 = ($12>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre57 = HEAP32[$4>>2]|0;
  $18 = $$pre;$20 = $$pre57;
 } else {
  $15 = HEAP32[$11>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$1>>2] = $12;
  $18 = $12;$20 = $13;
 }
 $16 = (($this) + 80|0);
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)>($20>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$16,4);
  $$pre58 = HEAP32[$1>>2]|0;
  $$pre59 = HEAP32[$4>>2]|0;
  $24 = $$pre58;$26 = $$pre59;
 } else {
  $21 = HEAP32[$18>>2]|0;
  HEAP32[$16>>2] = $21;
  HEAP32[$1>>2] = $17;
  $24 = $17;$26 = $20;
 }
 $22 = (($this) + 84|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)>($26>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$22,4);
  $$pre60 = HEAP32[$22>>2]|0;
  $29 = $$pre60;
 } else {
  $27 = HEAP32[$24>>2]|0;
  HEAP32[$22>>2] = $27;
  HEAP32[$1>>2] = $23;
  $29 = $27;
 }
 $28 = ($29|0)==(0);
 if ($28) {
  HEAP32[$22>>2] = -1;
 }
 $30 = (($this) + 88|0);
 $31 = HEAP32[$1>>2]|0;
 $32 = (($31) + 4|0);
 $33 = HEAP32[$4>>2]|0;
 $34 = ($32>>>0)>($33>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$30,4);
  $$pre61 = HEAP32[$1>>2]|0;
  $$pre62 = HEAP32[$4>>2]|0;
  $38 = $$pre61;$40 = $$pre62;
 } else {
  $35 = HEAP32[$31>>2]|0;
  HEAP32[$30>>2] = $35;
  HEAP32[$1>>2] = $32;
  $38 = $32;$40 = $33;
 }
 $36 = (($this) + 92|0);
 $37 = (($38) + 4|0);
 $39 = ($37>>>0)>($40>>>0);
 if ($39) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$36,4);
  $$pre63 = HEAP32[$36>>2]|0;
  $451 = $$pre63;
 } else {
  $41 = HEAP32[$38>>2]|0;
  HEAP32[$36>>2] = $41;
  HEAP32[$1>>2] = $37;
  $451 = $41;
 }
 if ((($451|0) == 1)) {
  HEAP32[$36>>2] = 6;
 } else if ((($451|0) == 2)) {
  HEAP32[$36>>2] = 0;
 }
 $42 = (($this) + 96|0);
 $43 = HEAP32[$1>>2]|0;
 $44 = (($43) + 4|0);
 $45 = HEAP32[$4>>2]|0;
 $46 = ($44>>>0)>($45>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$42,4);
 } else {
  $47 = HEAP32[$43>>2]|0;
  HEAP32[$42>>2] = $47;
  HEAP32[$1>>2] = $44;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $48 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$48,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $49 = (($this) + 36|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$49,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $50 = (($this) + 60|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($50,$transfer);
 $51 = (($this) + 64|0);
 $52 = HEAP32[$1>>2]|0;
 $53 = (($52) + 4|0);
 $54 = HEAP32[$4>>2]|0;
 $55 = ($53>>>0)>($54>>>0);
 if ($55) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$51,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre2$i$i$i = HEAP32[$4>>2]|0;
  $59 = $$pre$i$i$i;$61 = $$pre2$i$i$i;
 } else {
  $56 = Math_fround(HEAPF32[$52>>2]);
  HEAPF32[$51>>2] = $56;
  HEAP32[$1>>2] = $53;
  $59 = $53;$61 = $54;
 }
 $57 = (($this) + 68|0);
 $58 = (($59) + 4|0);
 $60 = ($58>>>0)>($61>>>0);
 if ($60) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$57,4);
  $$pre64 = HEAP32[$1>>2]|0;
  $$pre65 = HEAP32[$4>>2]|0;
  $65 = $$pre64;$67 = $$pre65;
 } else {
  $62 = Math_fround(HEAPF32[$59>>2]);
  HEAPF32[$57>>2] = $62;
  HEAP32[$1>>2] = $58;
  $65 = $58;$67 = $61;
 }
 $63 = (($this) + 100|0);
 $64 = (($65) + 4|0);
 $66 = ($64>>>0)>($67>>>0);
 if ($66) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$63,4);
  $$pre66 = HEAP32[$1>>2]|0;
  $$pre67 = HEAP32[$4>>2]|0;
  $71 = $$pre66;$73 = $$pre67;
 } else {
  $68 = HEAP32[$65>>2]|0;
  HEAP32[$63>>2] = $68;
  HEAP32[$1>>2] = $64;
  $71 = $64;$73 = $67;
 }
 $69 = (($this) + 104|0);
 $70 = (($71) + 4|0);
 $72 = ($70>>>0)>($73>>>0);
 if ($72) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$69,4);
  $$pre68 = HEAP32[$1>>2]|0;
  $$pre69 = HEAP32[$4>>2]|0;
  $77 = $$pre68;$79 = $$pre69;
 } else {
  $74 = HEAP32[$71>>2]|0;
  HEAP32[$69>>2] = $74;
  HEAP32[$1>>2] = $70;
  $77 = $70;$79 = $73;
 }
 $75 = (($this) + 108|0);
 $76 = (($77) + 4|0);
 $78 = ($76>>>0)>($79>>>0);
 if ($78) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$75,4);
  $$pre70 = HEAP32[$1>>2]|0;
  $$pre71 = HEAP32[$4>>2]|0;
  $83 = $$pre70;$85 = $$pre71;
 } else {
  $80 = HEAP32[$77>>2]|0;
  HEAP32[$75>>2] = $80;
  HEAP32[$1>>2] = $76;
  $83 = $76;$85 = $79;
 }
 $81 = (($this) + 112|0);
 $82 = (($83) + 4|0);
 $84 = ($82>>>0)>($85>>>0);
 if ($84) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$81,4);
  $$pre72 = HEAP32[$1>>2]|0;
  $$pre73 = HEAP32[$4>>2]|0;
  $89 = $$pre72;$91 = $$pre73;
 } else {
  $86 = HEAP32[$83>>2]|0;
  HEAP32[$81>>2] = $86;
  HEAP32[$1>>2] = $82;
  $89 = $82;$91 = $85;
 }
 $87 = (($this) + 128|0);
 $88 = (($89) + 4|0);
 $90 = ($88>>>0)>($91>>>0);
 if ($90) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$87,4);
  $$pre74 = HEAP32[$1>>2]|0;
  $$pre75 = HEAP32[$4>>2]|0;
  $95 = $$pre74;$97 = $$pre75;
 } else {
  $92 = HEAP32[$89>>2]|0;
  HEAP32[$87>>2] = $92;
  HEAP32[$1>>2] = $88;
  $95 = $88;$97 = $91;
 }
 $93 = (($this) + 132|0);
 $94 = (($95) + 4|0);
 $96 = ($94>>>0)>($97>>>0);
 if ($96) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$93,4);
  $$pre76 = HEAP32[$1>>2]|0;
  $$pre77 = HEAP32[$4>>2]|0;
  $101 = $$pre76;$103 = $$pre77;
 } else {
  $98 = HEAP32[$95>>2]|0;
  HEAP32[$93>>2] = $98;
  HEAP32[$1>>2] = $94;
  $101 = $94;$103 = $97;
 }
 $99 = (($this) + 136|0);
 $100 = (($101) + 4|0);
 $102 = ($100>>>0)>($103>>>0);
 if ($102) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$99,4);
  $$pre78 = HEAP32[$1>>2]|0;
  $$pre79 = HEAP32[$4>>2]|0;
  $107 = $$pre78;$109 = $$pre79;
 } else {
  $104 = HEAP32[$101>>2]|0;
  HEAP32[$99>>2] = $104;
  HEAP32[$1>>2] = $100;
  $107 = $100;$109 = $103;
 }
 $105 = (($this) + 140|0);
 $106 = (($107) + 1|0);
 $108 = ($106>>>0)>($109>>>0);
 if ($108) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$105,1);
  $$pre80 = HEAP32[$1>>2]|0;
  $115 = $$pre80;
 } else {
  $110 = HEAP8[$107>>0]|0;
  HEAP8[$105>>0] = $110;
  $111 = HEAP32[$1>>2]|0;
  $112 = (($111) + 1|0);
  HEAP32[$1>>2] = $112;
  $115 = $112;
 }
 $113 = (($this) + 141|0);
 $114 = (($115) + 1|0);
 $116 = HEAP32[$4>>2]|0;
 $117 = ($114>>>0)>($116>>>0);
 if ($117) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$113,1);
  $$pre81 = HEAP32[$1>>2]|0;
  $123 = $$pre81;
 } else {
  $118 = HEAP8[$115>>0]|0;
  HEAP8[$113>>0] = $118;
  $119 = HEAP32[$1>>2]|0;
  $120 = (($119) + 1|0);
  HEAP32[$1>>2] = $120;
  $123 = $120;
 }
 $121 = (($this) + 142|0);
 $122 = (($123) + 1|0);
 $124 = HEAP32[$4>>2]|0;
 $125 = ($122>>>0)>($124>>>0);
 if ($125) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$121,1);
  $$pre82 = HEAP32[$1>>2]|0;
  $131 = $$pre82;
 } else {
  $126 = HEAP8[$123>>0]|0;
  HEAP8[$121>>0] = $126;
  $127 = HEAP32[$1>>2]|0;
  $128 = (($127) + 1|0);
  HEAP32[$1>>2] = $128;
  $131 = $128;
 }
 $129 = (($this) + 143|0);
 $130 = (($131) + 1|0);
 $132 = HEAP32[$4>>2]|0;
 $133 = ($130>>>0)>($132>>>0);
 if ($133) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$129,1);
 } else {
  $134 = HEAP8[$131>>0]|0;
  HEAP8[$129>>0] = $134;
  $135 = HEAP32[$1>>2]|0;
  $136 = (($135) + 1|0);
  HEAP32[$1>>2] = $136;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $137 = (($this) + 148|0);
 $138 = HEAP32[$1>>2]|0;
 $139 = (($138) + 4|0);
 $140 = HEAP32[$4>>2]|0;
 $141 = ($139>>>0)>($140>>>0);
 if ($141) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$137,4);
  $$pre83 = HEAP32[$1>>2]|0;
  $$pre84 = HEAP32[$4>>2]|0;
  $145 = $$pre83;$147 = $$pre84;
 } else {
  $142 = HEAP32[$138>>2]|0;
  HEAP32[$137>>2] = $142;
  HEAP32[$1>>2] = $139;
  $145 = $139;$147 = $140;
 }
 $143 = (($this) + 144|0);
 $144 = (($145) + 4|0);
 $146 = ($144>>>0)>($147>>>0);
 if ($146) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$143,4);
  $$pre85 = HEAP32[$1>>2]|0;
  $$pre86 = HEAP32[$4>>2]|0;
  $151 = $$pre85;$153 = $$pre86;
 } else {
  $148 = HEAP32[$145>>2]|0;
  HEAP32[$143>>2] = $148;
  HEAP32[$1>>2] = $144;
  $151 = $144;$153 = $147;
 }
 $149 = (($this) + 152|0);
 $150 = (($151) + 4|0);
 $152 = ($150>>>0)>($153>>>0);
 if ($152) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$149,4);
  $$pre87 = HEAP32[$1>>2]|0;
  $$pre88 = HEAP32[$4>>2]|0;
  $157 = $$pre87;$159 = $$pre88;
 } else {
  $154 = HEAP32[$151>>2]|0;
  HEAP32[$149>>2] = $154;
  HEAP32[$1>>2] = $150;
  $157 = $150;$159 = $153;
 }
 $155 = (($this) + 116|0);
 $156 = (($157) + 4|0);
 $158 = ($156>>>0)>($159>>>0);
 if ($158) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$155,4);
  $$pre89 = HEAP32[$1>>2]|0;
  $$pre90 = HEAP32[$4>>2]|0;
  $163 = $$pre89;$165 = $$pre90;
 } else {
  $160 = HEAP32[$157>>2]|0;
  HEAP32[$155>>2] = $160;
  HEAP32[$1>>2] = $156;
  $163 = $156;$165 = $159;
 }
 $161 = (($this) + 156|0);
 $162 = (($163) + 1|0);
 $164 = ($162>>>0)>($165>>>0);
 if ($164) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$161,1);
  $$pre91 = HEAP32[$1>>2]|0;
  $171 = $$pre91;
 } else {
  $166 = HEAP8[$163>>0]|0;
  HEAP8[$161>>0] = $166;
  $167 = HEAP32[$1>>2]|0;
  $168 = (($167) + 1|0);
  HEAP32[$1>>2] = $168;
  $171 = $168;
 }
 $169 = (($this) + 157|0);
 $170 = (($171) + 1|0);
 $172 = HEAP32[$4>>2]|0;
 $173 = ($170>>>0)>($172>>>0);
 if ($173) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$169,1);
  $$pre92 = HEAP32[$1>>2]|0;
  $179 = $$pre92;
 } else {
  $174 = HEAP8[$171>>0]|0;
  HEAP8[$169>>0] = $174;
  $175 = HEAP32[$1>>2]|0;
  $176 = (($175) + 1|0);
  HEAP32[$1>>2] = $176;
  $179 = $176;
 }
 $177 = (($this) + 158|0);
 $178 = (($179) + 1|0);
 $180 = HEAP32[$4>>2]|0;
 $181 = ($178>>>0)>($180>>>0);
 if ($181) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$177,1);
  $$pre93 = HEAP32[$1>>2]|0;
  $187 = $$pre93;
 } else {
  $182 = HEAP8[$179>>0]|0;
  HEAP8[$177>>0] = $182;
  $183 = HEAP32[$1>>2]|0;
  $184 = (($183) + 1|0);
  HEAP32[$1>>2] = $184;
  $187 = $184;
 }
 $185 = (($this) + 159|0);
 $186 = (($187) + 1|0);
 $188 = HEAP32[$4>>2]|0;
 $189 = ($186>>>0)>($188>>>0);
 if ($189) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$185,1);
  $$pre94 = HEAP32[$1>>2]|0;
  $195 = $$pre94;
 } else {
  $190 = HEAP8[$187>>0]|0;
  HEAP8[$185>>0] = $190;
  $191 = HEAP32[$1>>2]|0;
  $192 = (($191) + 1|0);
  HEAP32[$1>>2] = $192;
  $195 = $192;
 }
 $193 = (($this) + 160|0);
 $194 = (($195) + 1|0);
 $196 = HEAP32[$4>>2]|0;
 $197 = ($194>>>0)>($196>>>0);
 if ($197) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$193,1);
  $$pre95 = HEAP32[$1>>2]|0;
  $203 = $$pre95;
 } else {
  $198 = HEAP8[$195>>0]|0;
  HEAP8[$193>>0] = $198;
  $199 = HEAP32[$1>>2]|0;
  $200 = (($199) + 1|0);
  HEAP32[$1>>2] = $200;
  $203 = $200;
 }
 $201 = (($this) + 161|0);
 $202 = (($203) + 1|0);
 $204 = HEAP32[$4>>2]|0;
 $205 = ($202>>>0)>($204>>>0);
 if ($205) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$201,1);
  $$pre96 = HEAP32[$1>>2]|0;
  $211 = $$pre96;
 } else {
  $206 = HEAP8[$203>>0]|0;
  HEAP8[$201>>0] = $206;
  $207 = HEAP32[$1>>2]|0;
  $208 = (($207) + 1|0);
  HEAP32[$1>>2] = $208;
  $211 = $208;
 }
 $209 = (($this) + 162|0);
 $210 = (($211) + 1|0);
 $212 = HEAP32[$4>>2]|0;
 $213 = ($210>>>0)>($212>>>0);
 if ($213) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$209,1);
 } else {
  $214 = HEAP8[$211>>0]|0;
  HEAP8[$209>>0] = $214;
  $215 = HEAP32[$1>>2]|0;
  $216 = (($215) + 1|0);
  HEAP32[$1>>2] = $216;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $217 = (($this) + 163|0);
 $218 = HEAP32[$1>>2]|0;
 $219 = (($218) + 1|0);
 $220 = HEAP32[$4>>2]|0;
 $221 = ($219>>>0)>($220>>>0);
 if ($221) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$217,1);
  $$pre97 = HEAP32[$1>>2]|0;
  $227 = $$pre97;
 } else {
  $222 = HEAP8[$218>>0]|0;
  HEAP8[$217>>0] = $222;
  $223 = HEAP32[$1>>2]|0;
  $224 = (($223) + 1|0);
  HEAP32[$1>>2] = $224;
  $227 = $224;
 }
 $225 = (($this) + 164|0);
 $226 = (($227) + 1|0);
 $228 = HEAP32[$4>>2]|0;
 $229 = ($226>>>0)>($228>>>0);
 if ($229) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$225,1);
  $$pre98 = HEAP32[$1>>2]|0;
  $235 = $$pre98;
 } else {
  $230 = HEAP8[$227>>0]|0;
  HEAP8[$225>>0] = $230;
  $231 = HEAP32[$1>>2]|0;
  $232 = (($231) + 1|0);
  HEAP32[$1>>2] = $232;
  $235 = $232;
 }
 $233 = (($this) + 165|0);
 $234 = (($235) + 1|0);
 $236 = HEAP32[$4>>2]|0;
 $237 = ($234>>>0)>($236>>>0);
 if ($237) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$233,1);
  $$pre99 = HEAP32[$1>>2]|0;
  $243 = $$pre99;
 } else {
  $238 = HEAP8[$235>>0]|0;
  HEAP8[$233>>0] = $238;
  $239 = HEAP32[$1>>2]|0;
  $240 = (($239) + 1|0);
  HEAP32[$1>>2] = $240;
  $243 = $240;
 }
 $241 = (($this) + 166|0);
 $242 = (($243) + 1|0);
 $244 = HEAP32[$4>>2]|0;
 $245 = ($242>>>0)>($244>>>0);
 if ($245) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$241,1);
  $$pre100 = HEAP32[$1>>2]|0;
  $251 = $$pre100;
 } else {
  $246 = HEAP8[$243>>0]|0;
  HEAP8[$241>>0] = $246;
  $247 = HEAP32[$1>>2]|0;
  $248 = (($247) + 1|0);
  HEAP32[$1>>2] = $248;
  $251 = $248;
 }
 $249 = (($this) + 167|0);
 $250 = (($251) + 1|0);
 $252 = HEAP32[$4>>2]|0;
 $253 = ($250>>>0)>($252>>>0);
 if ($253) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$249,1);
  $$pre101 = HEAP32[$1>>2]|0;
  $259 = $$pre101;
 } else {
  $254 = HEAP8[$251>>0]|0;
  HEAP8[$249>>0] = $254;
  $255 = HEAP32[$1>>2]|0;
  $256 = (($255) + 1|0);
  HEAP32[$1>>2] = $256;
  $259 = $256;
 }
 $257 = (($this) + 168|0);
 $258 = (($259) + 1|0);
 $260 = HEAP32[$4>>2]|0;
 $261 = ($258>>>0)>($260>>>0);
 if ($261) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$257,1);
  $$pre102 = HEAP32[$1>>2]|0;
  $267 = $$pre102;
 } else {
  $262 = HEAP8[$259>>0]|0;
  HEAP8[$257>>0] = $262;
  $263 = HEAP32[$1>>2]|0;
  $264 = (($263) + 1|0);
  HEAP32[$1>>2] = $264;
  $267 = $264;
 }
 $265 = (($this) + 169|0);
 $266 = (($267) + 1|0);
 $268 = HEAP32[$4>>2]|0;
 $269 = ($266>>>0)>($268>>>0);
 if ($269) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$265,1);
  $$pre103 = HEAP32[$1>>2]|0;
  $275 = $$pre103;
 } else {
  $270 = HEAP8[$267>>0]|0;
  HEAP8[$265>>0] = $270;
  $271 = HEAP32[$1>>2]|0;
  $272 = (($271) + 1|0);
  HEAP32[$1>>2] = $272;
  $275 = $272;
 }
 $273 = (($this) + 170|0);
 $274 = (($275) + 1|0);
 $276 = HEAP32[$4>>2]|0;
 $277 = ($274>>>0)>($276>>>0);
 if ($277) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$273,1);
  $$pre104 = HEAP32[$1>>2]|0;
  $283 = $$pre104;
 } else {
  $278 = HEAP8[$275>>0]|0;
  HEAP8[$273>>0] = $278;
  $279 = HEAP32[$1>>2]|0;
  $280 = (($279) + 1|0);
  HEAP32[$1>>2] = $280;
  $283 = $280;
 }
 $281 = (($this) + 171|0);
 $282 = (($283) + 1|0);
 $284 = HEAP32[$4>>2]|0;
 $285 = ($282>>>0)>($284>>>0);
 if ($285) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$281,1);
  $$pre105 = HEAP32[$1>>2]|0;
  $291 = $$pre105;
 } else {
  $286 = HEAP8[$283>>0]|0;
  HEAP8[$281>>0] = $286;
  $287 = HEAP32[$1>>2]|0;
  $288 = (($287) + 1|0);
  HEAP32[$1>>2] = $288;
  $291 = $288;
 }
 $289 = (($this) + 180|0);
 $290 = (($291) + 1|0);
 $292 = HEAP32[$4>>2]|0;
 $293 = ($290>>>0)>($292>>>0);
 if ($293) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$289,1);
  $$pre106 = HEAP32[$1>>2]|0;
  $299 = $$pre106;
 } else {
  $294 = HEAP8[$291>>0]|0;
  HEAP8[$289>>0] = $294;
  $295 = HEAP32[$1>>2]|0;
  $296 = (($295) + 1|0);
  HEAP32[$1>>2] = $296;
  $299 = $296;
 }
 $297 = (($this) + 181|0);
 $298 = (($299) + 1|0);
 $300 = HEAP32[$4>>2]|0;
 $301 = ($298>>>0)>($300>>>0);
 if ($301) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$297,1);
  $$pre107 = HEAP32[$1>>2]|0;
  $307 = $$pre107;
 } else {
  $302 = HEAP8[$299>>0]|0;
  HEAP8[$297>>0] = $302;
  $303 = HEAP32[$1>>2]|0;
  $304 = (($303) + 1|0);
  HEAP32[$1>>2] = $304;
  $307 = $304;
 }
 $305 = (($this) + 172|0);
 $306 = (($307) + 1|0);
 $308 = HEAP32[$4>>2]|0;
 $309 = ($306>>>0)>($308>>>0);
 if ($309) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$305,1);
  $$pre108 = HEAP32[$1>>2]|0;
  $315 = $$pre108;
 } else {
  $310 = HEAP8[$307>>0]|0;
  HEAP8[$305>>0] = $310;
  $311 = HEAP32[$1>>2]|0;
  $312 = (($311) + 1|0);
  HEAP32[$1>>2] = $312;
  $315 = $312;
 }
 $313 = (($this) + 182|0);
 $314 = (($315) + 1|0);
 $316 = HEAP32[$4>>2]|0;
 $317 = ($314>>>0)>($316>>>0);
 if ($317) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$313,1);
  $$pre109 = HEAP32[$1>>2]|0;
  $323 = $$pre109;
 } else {
  $318 = HEAP8[$315>>0]|0;
  HEAP8[$313>>0] = $318;
  $319 = HEAP32[$1>>2]|0;
  $320 = (($319) + 1|0);
  HEAP32[$1>>2] = $320;
  $323 = $320;
 }
 $321 = (($this) + 183|0);
 $322 = (($323) + 1|0);
 $324 = HEAP32[$4>>2]|0;
 $325 = ($322>>>0)>($324>>>0);
 if ($325) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$321,1);
  $$pre110 = HEAP32[$1>>2]|0;
  $331 = $$pre110;
 } else {
  $326 = HEAP8[$323>>0]|0;
  HEAP8[$321>>0] = $326;
  $327 = HEAP32[$1>>2]|0;
  $328 = (($327) + 1|0);
  HEAP32[$1>>2] = $328;
  $331 = $328;
 }
 $329 = (($this) + 184|0);
 $330 = (($331) + 1|0);
 $332 = HEAP32[$4>>2]|0;
 $333 = ($330>>>0)>($332>>>0);
 if ($333) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$329,1);
  $$pre111 = HEAP32[$1>>2]|0;
  $339 = $$pre111;
 } else {
  $334 = HEAP8[$331>>0]|0;
  HEAP8[$329>>0] = $334;
  $335 = HEAP32[$1>>2]|0;
  $336 = (($335) + 1|0);
  HEAP32[$1>>2] = $336;
  $339 = $336;
 }
 $337 = (($this) + 185|0);
 $338 = (($339) + 1|0);
 $340 = HEAP32[$4>>2]|0;
 $341 = ($338>>>0)>($340>>>0);
 if ($341) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$337,1);
  $$pre112 = HEAP32[$1>>2]|0;
  $347 = $$pre112;
 } else {
  $342 = HEAP8[$339>>0]|0;
  HEAP8[$337>>0] = $342;
  $343 = HEAP32[$1>>2]|0;
  $344 = (($343) + 1|0);
  HEAP32[$1>>2] = $344;
  $347 = $344;
 }
 $345 = (($this) + 186|0);
 $346 = (($347) + 1|0);
 $348 = HEAP32[$4>>2]|0;
 $349 = ($346>>>0)>($348>>>0);
 if ($349) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$345,1);
  $$pre113 = HEAP32[$1>>2]|0;
  $355 = $$pre113;
 } else {
  $350 = HEAP8[$347>>0]|0;
  HEAP8[$345>>0] = $350;
  $351 = HEAP32[$1>>2]|0;
  $352 = (($351) + 1|0);
  HEAP32[$1>>2] = $352;
  $355 = $352;
 }
 $353 = (($this) + 192|0);
 $354 = (($355) + 1|0);
 $356 = HEAP32[$4>>2]|0;
 $357 = ($354>>>0)>($356>>>0);
 if ($357) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$353,1);
  $$pre114 = HEAP32[$1>>2]|0;
  $363 = $$pre114;
 } else {
  $358 = HEAP8[$355>>0]|0;
  HEAP8[$353>>0] = $358;
  $359 = HEAP32[$1>>2]|0;
  $360 = (($359) + 1|0);
  HEAP32[$1>>2] = $360;
  $363 = $360;
 }
 $361 = (($this) + 173|0);
 $362 = (($363) + 1|0);
 $364 = HEAP32[$4>>2]|0;
 $365 = ($362>>>0)>($364>>>0);
 if ($365) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$361,1);
 } else {
  $366 = HEAP8[$363>>0]|0;
  HEAP8[$361>>0] = $366;
  $367 = HEAP32[$1>>2]|0;
  $368 = (($367) + 1|0);
  HEAP32[$1>>2] = $368;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $369 = (($this) + 176|0);
 $370 = HEAP32[$1>>2]|0;
 $371 = (($370) + 4|0);
 $372 = HEAP32[$4>>2]|0;
 $373 = ($371>>>0)>($372>>>0);
 if ($373) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$369,4);
  $$pre115 = HEAP32[$1>>2]|0;
  $$pre116 = HEAP32[$4>>2]|0;
  $377 = $$pre115;$379 = $$pre116;
 } else {
  $374 = HEAP32[$370>>2]|0;
  HEAP32[$369>>2] = $374;
  HEAP32[$1>>2] = $371;
  $377 = $371;$379 = $372;
 }
 $375 = (($this) + 188|0);
 $376 = (($377) + 4|0);
 $378 = ($376>>>0)>($379>>>0);
 if ($378) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$375,4);
  $$pre117 = HEAP32[$1>>2]|0;
  $$pre118 = HEAP32[$4>>2]|0;
  $383 = $$pre117;$385 = $$pre118;
 } else {
  $380 = HEAP32[$377>>2]|0;
  HEAP32[$375>>2] = $380;
  HEAP32[$1>>2] = $376;
  $383 = $376;$385 = $379;
 }
 $381 = (($this) + 193|0);
 $382 = (($383) + 1|0);
 $384 = ($382>>>0)>($385>>>0);
 if ($384) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$381,1);
  $$pre119 = HEAP32[$1>>2]|0;
  $391 = $$pre119;
 } else {
  $386 = HEAP8[$383>>0]|0;
  HEAP8[$381>>0] = $386;
  $387 = HEAP32[$1>>2]|0;
  $388 = (($387) + 1|0);
  HEAP32[$1>>2] = $388;
  $391 = $388;
 }
 $389 = (($this) + 194|0);
 $390 = (($391) + 1|0);
 $392 = HEAP32[$4>>2]|0;
 $393 = ($390>>>0)>($392>>>0);
 if ($393) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$389,1);
 } else {
  $394 = HEAP8[$391>>0]|0;
  HEAP8[$389>>0] = $394;
  $395 = HEAP32[$1>>2]|0;
  $396 = (($395) + 1|0);
  HEAP32[$1>>2] = $396;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $397 = (($this) + 196|0);
 $398 = HEAP32[$1>>2]|0;
 $399 = (($398) + 4|0);
 $400 = HEAP32[$4>>2]|0;
 $401 = ($399>>>0)>($400>>>0);
 if ($401) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$397,4);
 } else {
  $402 = HEAP32[$398>>2]|0;
  HEAP32[$397>>2] = $402;
  HEAP32[$1>>2] = $399;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $403 = (($this) + 204|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($403,$transfer);
 $404 = (($this) + 208|0);
 $405 = HEAP32[$1>>2]|0;
 $406 = (($405) + 4|0);
 $407 = HEAP32[$4>>2]|0;
 $408 = ($406>>>0)>($407>>>0);
 if ($408) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$404,4);
  $$pre120 = HEAP32[$1>>2]|0;
  $$pre121 = HEAP32[$4>>2]|0;
  $412 = $$pre120;$414 = $$pre121;
 } else {
  $409 = HEAP32[$405>>2]|0;
  HEAP32[$404>>2] = $409;
  HEAP32[$1>>2] = $406;
  $412 = $406;$414 = $407;
 }
 $410 = (($this) + 212|0);
 $411 = (($412) + 4|0);
 $413 = ($411>>>0)>($414>>>0);
 if ($413) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$410,4);
  $$pre122 = HEAP32[$1>>2]|0;
  $$pre123 = HEAP32[$4>>2]|0;
  $418 = $$pre122;$420 = $$pre123;
 } else {
  $415 = HEAP32[$412>>2]|0;
  HEAP32[$410>>2] = $415;
  HEAP32[$1>>2] = $411;
  $418 = $411;$420 = $414;
 }
 $416 = (($this) + 216|0);
 $417 = (($418) + 1|0);
 $419 = ($417>>>0)>($420>>>0);
 if ($419) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$416,1);
 } else {
  $421 = HEAP8[$418>>0]|0;
  HEAP8[$416>>0] = $421;
  $422 = HEAP32[$1>>2]|0;
  $423 = (($422) + 1|0);
  HEAP32[$1>>2] = $423;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $424 = (($this) + 120|0);
 __ZN12AspectRatios8TransferI18StreamedBinaryReadILb0EEEEvRT_($424,$transfer);
 $425 = (($this) + 244|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$425,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $426 = (($this) + 268|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$426,0);
 $427 = (($this) + 284|0);
 $428 = HEAP32[$1>>2]|0;
 $429 = (($428) + 1|0);
 $430 = HEAP32[$4>>2]|0;
 $431 = ($429>>>0)>($430>>>0);
 if ($431) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$427,1);
  $$pre124 = HEAP32[$1>>2]|0;
  $437 = $$pre124;
 } else {
  $432 = HEAP8[$428>>0]|0;
  HEAP8[$427>>0] = $432;
  $433 = HEAP32[$1>>2]|0;
  $434 = (($433) + 1|0);
  HEAP32[$1>>2] = $434;
  $437 = $434;
 }
 $435 = (($this) + 285|0);
 $436 = (($437) + 1|0);
 $438 = HEAP32[$4>>2]|0;
 $439 = ($436>>>0)>($438>>>0);
 if ($439) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$435,1);
  $$pre125 = HEAP32[$1>>2]|0;
  $445 = $$pre125;
 } else {
  $440 = HEAP8[$437>>0]|0;
  HEAP8[$435>>0] = $440;
  $441 = HEAP32[$1>>2]|0;
  $442 = (($441) + 1|0);
  HEAP32[$1>>2] = $442;
  $445 = $442;
 }
 $443 = (($this) + 286|0);
 $444 = (($445) + 1|0);
 $446 = HEAP32[$4>>2]|0;
 $447 = ($444>>>0)>($446>>>0);
 if ($447) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$443,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $448 = HEAP8[$445>>0]|0;
  HEAP8[$443>>0] = $448;
  $449 = HEAP32[$1>>2]|0;
  $450 = (($449) + 1|0);
  HEAP32[$1>>2] = $450;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN12AspectRatios8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 20|0);
 $2 = (($this) + 1|0);
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 1|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = ($4>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$2,1);
  $$pre = HEAP32[$0>>2]|0;
  $12 = $$pre;
 } else {
  $7 = HEAP8[$3>>0]|0;
  HEAP8[$2>>0] = $7;
  $8 = HEAP32[$0>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$0>>2] = $9;
  $12 = $9;
 }
 $10 = (($this) + 2|0);
 $11 = (($12) + 1|0);
 $13 = HEAP32[$1>>2]|0;
 $14 = ($11>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,1);
  $$pre3 = HEAP32[$0>>2]|0;
  $24 = $$pre3;
 } else {
  $19 = HEAP8[$12>>0]|0;
  HEAP8[$10>>0] = $19;
  $20 = HEAP32[$0>>2]|0;
  $21 = (($20) + 1|0);
  HEAP32[$0>>2] = $21;
  $24 = $21;
 }
 $22 = (($this) + 3|0);
 $23 = (($24) + 1|0);
 $25 = HEAP32[$1>>2]|0;
 $26 = ($23>>>0)>($25>>>0);
 if ($26) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$22,1);
  $$pre4 = HEAP32[$0>>2]|0;
  $32 = $$pre4;
 } else {
  $27 = HEAP8[$24>>0]|0;
  HEAP8[$22>>0] = $27;
  $28 = HEAP32[$0>>2]|0;
  $29 = (($28) + 1|0);
  HEAP32[$0>>2] = $29;
  $32 = $29;
 }
 $30 = (($this) + 4|0);
 $31 = (($32) + 1|0);
 $33 = HEAP32[$1>>2]|0;
 $34 = ($31>>>0)>($33>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$30,1);
  $$pre5 = HEAP32[$0>>2]|0;
  $16 = $$pre5;
 } else {
  $35 = HEAP8[$32>>0]|0;
  HEAP8[$30>>0] = $35;
  $36 = HEAP32[$0>>2]|0;
  $37 = (($36) + 1|0);
  HEAP32[$0>>2] = $37;
  $16 = $37;
 }
 $38 = (($16) + 1|0);
 $39 = HEAP32[$1>>2]|0;
 $40 = ($38>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $15 = HEAP8[$16>>0]|0;
  HEAP8[$this>>0] = $15;
  $17 = HEAP32[$0>>2]|0;
  $18 = (($17) + 1|0);
  HEAP32[$0>>2] = $18;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN14PlayerSettings8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i102 = 0, $$sum$i$i$i$i$i107 = 0, $$sum$i$i$i$i$i112 = 0, $$sum$i$i$i$i$i117 = 0, $$sum$i$i$i$i$i12 = 0, $$sum$i$i$i$i$i122 = 0, $$sum$i$i$i$i$i127 = 0, $$sum$i$i$i$i$i132 = 0, $$sum$i$i$i$i$i137 = 0, $$sum$i$i$i$i$i142 = 0, $$sum$i$i$i$i$i147 = 0, $$sum$i$i$i$i$i152 = 0, $$sum$i$i$i$i$i157 = 0, $$sum$i$i$i$i$i162 = 0, $$sum$i$i$i$i$i169 = 0, $$sum$i$i$i$i$i17 = 0, $$sum$i$i$i$i$i175 = 0, $$sum$i$i$i$i$i183 = 0, $$sum$i$i$i$i$i188 = 0;
 var $$sum$i$i$i$i$i193 = 0, $$sum$i$i$i$i$i198 = 0, $$sum$i$i$i$i$i203 = 0, $$sum$i$i$i$i$i208 = 0, $$sum$i$i$i$i$i213 = 0, $$sum$i$i$i$i$i22 = 0, $$sum$i$i$i$i$i27 = 0, $$sum$i$i$i$i$i32 = 0, $$sum$i$i$i$i$i37 = 0, $$sum$i$i$i$i$i42 = 0, $$sum$i$i$i$i$i47 = 0, $$sum$i$i$i$i$i52 = 0, $$sum$i$i$i$i$i57 = 0, $$sum$i$i$i$i$i62 = 0, $$sum$i$i$i$i$i67 = 0, $$sum$i$i$i$i$i7 = 0, $$sum$i$i$i$i$i72 = 0, $$sum$i$i$i$i$i77 = 0, $$sum$i$i$i$i$i82 = 0, $$sum$i$i$i$i$i87 = 0;
 var $$sum$i$i$i$i$i92 = 0, $$sum$i$i$i$i$i97 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i103 = 0, $$sum1$i$i$i$i$i108 = 0, $$sum1$i$i$i$i$i113 = 0, $$sum1$i$i$i$i$i118 = 0, $$sum1$i$i$i$i$i123 = 0, $$sum1$i$i$i$i$i128 = 0, $$sum1$i$i$i$i$i13 = 0, $$sum1$i$i$i$i$i133 = 0, $$sum1$i$i$i$i$i138 = 0, $$sum1$i$i$i$i$i143 = 0, $$sum1$i$i$i$i$i148 = 0, $$sum1$i$i$i$i$i153 = 0, $$sum1$i$i$i$i$i158 = 0, $$sum1$i$i$i$i$i163 = 0, $$sum1$i$i$i$i$i170 = 0, $$sum1$i$i$i$i$i176 = 0, $$sum1$i$i$i$i$i18 = 0;
 var $$sum1$i$i$i$i$i184 = 0, $$sum1$i$i$i$i$i189 = 0, $$sum1$i$i$i$i$i194 = 0, $$sum1$i$i$i$i$i199 = 0, $$sum1$i$i$i$i$i204 = 0, $$sum1$i$i$i$i$i209 = 0, $$sum1$i$i$i$i$i214 = 0, $$sum1$i$i$i$i$i23 = 0, $$sum1$i$i$i$i$i28 = 0, $$sum1$i$i$i$i$i33 = 0, $$sum1$i$i$i$i$i38 = 0, $$sum1$i$i$i$i$i43 = 0, $$sum1$i$i$i$i$i48 = 0, $$sum1$i$i$i$i$i53 = 0, $$sum1$i$i$i$i$i58 = 0, $$sum1$i$i$i$i$i63 = 0, $$sum1$i$i$i$i$i68 = 0, $$sum1$i$i$i$i$i73 = 0, $$sum1$i$i$i$i$i78 = 0, $$sum1$i$i$i$i$i8 = 0;
 var $$sum1$i$i$i$i$i83 = 0, $$sum1$i$i$i$i$i88 = 0, $$sum1$i$i$i$i$i93 = 0, $$sum1$i$i$i$i$i98 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0;
 var $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0;
 var $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0;
 var $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0;
 var $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0;
 var $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0;
 var $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0;
 var $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0;
 var $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0;
 var $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0;
 var $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0;
 var $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0;
 var $121 = 0, $1210 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0;
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0;
 var $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0;
 var $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0;
 var $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0;
 var $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0;
 var $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0;
 var $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0;
 var $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0;
 var $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $converter$i$i192 = 0, $converter$i$i212 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i212 = sp + 4|0;
 $converter$i$i192 = sp;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,6);
 $0 = (($this) + 72|0);
 $1 = HEAP32[580544>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623384,$1,$converter$i$i212,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  do {
   if ($4) {
    $5 = (($transfer) + 12|0);
    $6 = (($transfer) + 80|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($transfer) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($transfer) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($transfer) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = Math_imul($15, $13)|0;
    $$sum$i$i$i$i$i = (($9) - ($16))|0;
    $17 = (($11) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$5>>2] = $17;
    $18 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($18)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $19 = (($11) + ($$sum1$i$i$i$i$i)|0);
     $20 = (($transfer) + 20|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($19>>>0)>($21>>>0);
     if (!($22)) {
      $23 = HEAP8[$17>>0]|0;
      HEAP8[$0>>0] = $23;
      $24 = HEAP32[$5>>2]|0;
      $25 = (($24) + 1|0);
      HEAP32[$5>>2] = $25;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($5,$0,1);
   } else {
    $26 = HEAP32[$converter$i$i212>>2]|0;
    $27 = ($26|0)==(0|0);
    if (!($27)) {
     (FUNCTION_TABLE_iii[$26 & 4095]($0,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $28 = (($this) + 76|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$28,623400,0);
 $29 = (($this) + 80|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$29,623432,0);
 $30 = (($this) + 84|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$30,623448,0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0);
 if ($32) {
  HEAP32[$30>>2] = -1;
 }
 $33 = (($this) + 88|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$33,623472,0);
 $34 = (($this) + 92|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$34,623496,0);
 $35 = HEAP32[$34>>2]|0;
 if ((($35|0) == 1)) {
  HEAP32[$34>>2] = 6;
 } else if ((($35|0) == 2)) {
  HEAP32[$34>>2] = 0;
 }
 $36 = (($this) + 96|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$36,623520,0);
 $37 = (($this) + 24|0);
 $38 = HEAP32[580712>>2]|0;
 $39 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623544,$38,$converter$i$i212,0)|0);
 $40 = ($39|0)==(0);
 if (!($40)) {
  $41 = ($39|0)>(0);
  if ($41) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$37,0);
  } else {
   $42 = HEAP32[$converter$i$i212>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    (FUNCTION_TABLE_iii[$42 & 4095]($37,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $44 = (($this) + 36|0);
 $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623560,$38,$converter$i$i212,0)|0);
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = ($45|0)>(0);
  if ($47) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$44,0);
  } else {
   $48 = HEAP32[$converter$i$i212>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    (FUNCTION_TABLE_iii[$48 & 4095]($44,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $50 = (($this) + 60|0);
 $51 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623576,625096,$converter$i$i212,1)|0);
 $52 = ($51|0)==(0);
 if (!($52)) {
  $53 = ($51|0)>(0);
  if ($53) {
   __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($50,$transfer);
  } else {
   $54 = HEAP32[$converter$i$i212>>2]|0;
   $55 = ($54|0)==(0|0);
   if (!($55)) {
    (FUNCTION_TABLE_iii[$54 & 4095]($50,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $56 = (($this) + 64|0);
 $57 = HEAP32[580768>>2]|0;
 $58 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623592,$57,$converter$i$i212,1)|0);
 $59 = ($58|0)==(0);
 if (!($59)) {
  $60 = ($58|0)>(0);
  if ($60) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$56,625056,0);
   $61 = (($this) + 68|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$61,625064,0);
  } else {
   $62 = HEAP32[$converter$i$i212>>2]|0;
   $63 = ($62|0)==(0|0);
   if (!($63)) {
    (FUNCTION_TABLE_iii[$62 & 4095]($56,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $64 = (($this) + 100|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$64,623608,0);
 $65 = (($this) + 104|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$65,623632,0);
 $66 = (($this) + 108|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$66,623248,0);
 $67 = (($this) + 112|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$67,623296,0);
 $68 = (($this) + 128|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$68,623656,0);
 $69 = (($this) + 132|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$69,623672,0);
 $70 = (($this) + 136|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$70,623696,0);
 $71 = (($this) + 140|0);
 $72 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623720,$1,$converter$i$i212,0)|0);
 $73 = ($72|0)==(0);
 if (!($73)) {
  $74 = ($72|0)>(0);
  do {
   if ($74) {
    $75 = (($transfer) + 12|0);
    $76 = (($transfer) + 80|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + 12|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($transfer) + 16|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($transfer) + 28|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($transfer) + 32|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = Math_imul($85, $83)|0;
    $$sum$i$i$i$i$i7 = (($79) - ($86))|0;
    $87 = (($81) + ($$sum$i$i$i$i$i7)|0);
    HEAP32[$75>>2] = $87;
    $88 = ($$sum$i$i$i$i$i7|0)<(0);
    if (!($88)) {
     $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
     $89 = (($81) + ($$sum1$i$i$i$i$i8)|0);
     $90 = (($transfer) + 20|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($89>>>0)>($91>>>0);
     if (!($92)) {
      $93 = HEAP8[$87>>0]|0;
      HEAP8[$71>>0] = $93;
      $94 = HEAP32[$75>>2]|0;
      $95 = (($94) + 1|0);
      HEAP32[$75>>2] = $95;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($75,$71,1);
   } else {
    $96 = HEAP32[$converter$i$i212>>2]|0;
    $97 = ($96|0)==(0|0);
    if (!($97)) {
     (FUNCTION_TABLE_iii[$96 & 4095]($71,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $98 = (($this) + 141|0);
 $99 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623736,$1,$converter$i$i212,0)|0);
 $100 = ($99|0)==(0);
 if (!($100)) {
  $101 = ($99|0)>(0);
  do {
   if ($101) {
    $102 = (($transfer) + 12|0);
    $103 = (($transfer) + 80|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($104) + 12|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = (($transfer) + 16|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = (($transfer) + 28|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = (($transfer) + 32|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = Math_imul($112, $110)|0;
    $$sum$i$i$i$i$i12 = (($106) - ($113))|0;
    $114 = (($108) + ($$sum$i$i$i$i$i12)|0);
    HEAP32[$102>>2] = $114;
    $115 = ($$sum$i$i$i$i$i12|0)<(0);
    if (!($115)) {
     $$sum1$i$i$i$i$i13 = (($$sum$i$i$i$i$i12) + 1)|0;
     $116 = (($108) + ($$sum1$i$i$i$i$i13)|0);
     $117 = (($transfer) + 20|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = ($116>>>0)>($118>>>0);
     if (!($119)) {
      $120 = HEAP8[$114>>0]|0;
      HEAP8[$98>>0] = $120;
      $121 = HEAP32[$102>>2]|0;
      $122 = (($121) + 1|0);
      HEAP32[$102>>2] = $122;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($102,$98,1);
   } else {
    $123 = HEAP32[$converter$i$i212>>2]|0;
    $124 = ($123|0)==(0|0);
    if (!($124)) {
     (FUNCTION_TABLE_iii[$123 & 4095]($98,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $125 = (($this) + 142|0);
 $126 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623760,$1,$converter$i$i212,0)|0);
 $127 = ($126|0)==(0);
 if (!($127)) {
  $128 = ($126|0)>(0);
  do {
   if ($128) {
    $129 = (($transfer) + 12|0);
    $130 = (($transfer) + 80|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($131) + 12|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = (($transfer) + 16|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($transfer) + 28|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = (($transfer) + 32|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = Math_imul($139, $137)|0;
    $$sum$i$i$i$i$i17 = (($133) - ($140))|0;
    $141 = (($135) + ($$sum$i$i$i$i$i17)|0);
    HEAP32[$129>>2] = $141;
    $142 = ($$sum$i$i$i$i$i17|0)<(0);
    if (!($142)) {
     $$sum1$i$i$i$i$i18 = (($$sum$i$i$i$i$i17) + 1)|0;
     $143 = (($135) + ($$sum1$i$i$i$i$i18)|0);
     $144 = (($transfer) + 20|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = ($143>>>0)>($145>>>0);
     if (!($146)) {
      $147 = HEAP8[$141>>0]|0;
      HEAP8[$125>>0] = $147;
      $148 = HEAP32[$129>>2]|0;
      $149 = (($148) + 1|0);
      HEAP32[$129>>2] = $149;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($129,$125,1);
   } else {
    $150 = HEAP32[$converter$i$i212>>2]|0;
    $151 = ($150|0)==(0|0);
    if (!($151)) {
     (FUNCTION_TABLE_iii[$150 & 4095]($125,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $152 = (($this) + 143|0);
 $153 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623776,$1,$converter$i$i212,0)|0);
 $154 = ($153|0)==(0);
 if (!($154)) {
  $155 = ($153|0)>(0);
  do {
   if ($155) {
    $156 = (($transfer) + 12|0);
    $157 = (($transfer) + 80|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($158) + 12|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = (($transfer) + 16|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = (($transfer) + 28|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = (($transfer) + 32|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = Math_imul($166, $164)|0;
    $$sum$i$i$i$i$i22 = (($160) - ($167))|0;
    $168 = (($162) + ($$sum$i$i$i$i$i22)|0);
    HEAP32[$156>>2] = $168;
    $169 = ($$sum$i$i$i$i$i22|0)<(0);
    if (!($169)) {
     $$sum1$i$i$i$i$i23 = (($$sum$i$i$i$i$i22) + 1)|0;
     $170 = (($162) + ($$sum1$i$i$i$i$i23)|0);
     $171 = (($transfer) + 20|0);
     $172 = HEAP32[$171>>2]|0;
     $173 = ($170>>>0)>($172>>>0);
     if (!($173)) {
      $174 = HEAP8[$168>>0]|0;
      HEAP8[$152>>0] = $174;
      $175 = HEAP32[$156>>2]|0;
      $176 = (($175) + 1|0);
      HEAP32[$156>>2] = $176;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($156,$152,1);
   } else {
    $177 = HEAP32[$converter$i$i212>>2]|0;
    $178 = ($177|0)==(0|0);
    if (!($178)) {
     (FUNCTION_TABLE_iii[$177 & 4095]($152,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $179 = (($this) + 148|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$179,623800,0);
 $180 = (($this) + 144|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$180,623840,0);
 $181 = (($this) + 152|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$181,623880,0);
 $182 = (($this) + 116|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$182,623912,0);
 $183 = (($this) + 156|0);
 $184 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623936,$1,$converter$i$i212,0)|0);
 $185 = ($184|0)==(0);
 if (!($185)) {
  $186 = ($184|0)>(0);
  do {
   if ($186) {
    $187 = (($transfer) + 12|0);
    $188 = (($transfer) + 80|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = (($189) + 12|0);
    $191 = HEAP32[$190>>2]|0;
    $192 = (($transfer) + 16|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = (($transfer) + 28|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = (($transfer) + 32|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = Math_imul($197, $195)|0;
    $$sum$i$i$i$i$i27 = (($191) - ($198))|0;
    $199 = (($193) + ($$sum$i$i$i$i$i27)|0);
    HEAP32[$187>>2] = $199;
    $200 = ($$sum$i$i$i$i$i27|0)<(0);
    if (!($200)) {
     $$sum1$i$i$i$i$i28 = (($$sum$i$i$i$i$i27) + 1)|0;
     $201 = (($193) + ($$sum1$i$i$i$i$i28)|0);
     $202 = (($transfer) + 20|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = ($201>>>0)>($203>>>0);
     if (!($204)) {
      $205 = HEAP8[$199>>0]|0;
      HEAP8[$183>>0] = $205;
      $206 = HEAP32[$187>>2]|0;
      $207 = (($206) + 1|0);
      HEAP32[$187>>2] = $207;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($187,$183,1);
   } else {
    $208 = HEAP32[$converter$i$i212>>2]|0;
    $209 = ($208|0)==(0|0);
    if (!($209)) {
     (FUNCTION_TABLE_iii[$208 & 4095]($183,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $210 = (($this) + 157|0);
 $211 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623968,$1,$converter$i$i212,0)|0);
 $212 = ($211|0)==(0);
 if (!($212)) {
  $213 = ($211|0)>(0);
  do {
   if ($213) {
    $214 = (($transfer) + 12|0);
    $215 = (($transfer) + 80|0);
    $216 = HEAP32[$215>>2]|0;
    $217 = (($216) + 12|0);
    $218 = HEAP32[$217>>2]|0;
    $219 = (($transfer) + 16|0);
    $220 = HEAP32[$219>>2]|0;
    $221 = (($transfer) + 28|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = (($transfer) + 32|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = Math_imul($224, $222)|0;
    $$sum$i$i$i$i$i32 = (($218) - ($225))|0;
    $226 = (($220) + ($$sum$i$i$i$i$i32)|0);
    HEAP32[$214>>2] = $226;
    $227 = ($$sum$i$i$i$i$i32|0)<(0);
    if (!($227)) {
     $$sum1$i$i$i$i$i33 = (($$sum$i$i$i$i$i32) + 1)|0;
     $228 = (($220) + ($$sum1$i$i$i$i$i33)|0);
     $229 = (($transfer) + 20|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = ($228>>>0)>($230>>>0);
     if (!($231)) {
      $232 = HEAP8[$226>>0]|0;
      HEAP8[$210>>0] = $232;
      $233 = HEAP32[$214>>2]|0;
      $234 = (($233) + 1|0);
      HEAP32[$214>>2] = $234;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($214,$210,1);
   } else {
    $235 = HEAP32[$converter$i$i212>>2]|0;
    $236 = ($235|0)==(0|0);
    if (!($236)) {
     (FUNCTION_TABLE_iii[$235 & 4095]($210,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $237 = (($this) + 158|0);
 $238 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624008,$1,$converter$i$i212,0)|0);
 $239 = ($238|0)==(0);
 if (!($239)) {
  $240 = ($238|0)>(0);
  do {
   if ($240) {
    $241 = (($transfer) + 12|0);
    $242 = (($transfer) + 80|0);
    $243 = HEAP32[$242>>2]|0;
    $244 = (($243) + 12|0);
    $245 = HEAP32[$244>>2]|0;
    $246 = (($transfer) + 16|0);
    $247 = HEAP32[$246>>2]|0;
    $248 = (($transfer) + 28|0);
    $249 = HEAP32[$248>>2]|0;
    $250 = (($transfer) + 32|0);
    $251 = HEAP32[$250>>2]|0;
    $252 = Math_imul($251, $249)|0;
    $$sum$i$i$i$i$i37 = (($245) - ($252))|0;
    $253 = (($247) + ($$sum$i$i$i$i$i37)|0);
    HEAP32[$241>>2] = $253;
    $254 = ($$sum$i$i$i$i$i37|0)<(0);
    if (!($254)) {
     $$sum1$i$i$i$i$i38 = (($$sum$i$i$i$i$i37) + 1)|0;
     $255 = (($247) + ($$sum1$i$i$i$i$i38)|0);
     $256 = (($transfer) + 20|0);
     $257 = HEAP32[$256>>2]|0;
     $258 = ($255>>>0)>($257>>>0);
     if (!($258)) {
      $259 = HEAP8[$253>>0]|0;
      HEAP8[$237>>0] = $259;
      $260 = HEAP32[$241>>2]|0;
      $261 = (($260) + 1|0);
      HEAP32[$241>>2] = $261;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($241,$237,1);
   } else {
    $262 = HEAP32[$converter$i$i212>>2]|0;
    $263 = ($262|0)==(0|0);
    if (!($263)) {
     (FUNCTION_TABLE_iii[$262 & 4095]($237,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $264 = (($this) + 159|0);
 $265 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624048,$1,$converter$i$i212,0)|0);
 $266 = ($265|0)==(0);
 if (!($266)) {
  $267 = ($265|0)>(0);
  do {
   if ($267) {
    $268 = (($transfer) + 12|0);
    $269 = (($transfer) + 80|0);
    $270 = HEAP32[$269>>2]|0;
    $271 = (($270) + 12|0);
    $272 = HEAP32[$271>>2]|0;
    $273 = (($transfer) + 16|0);
    $274 = HEAP32[$273>>2]|0;
    $275 = (($transfer) + 28|0);
    $276 = HEAP32[$275>>2]|0;
    $277 = (($transfer) + 32|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = Math_imul($278, $276)|0;
    $$sum$i$i$i$i$i42 = (($272) - ($279))|0;
    $280 = (($274) + ($$sum$i$i$i$i$i42)|0);
    HEAP32[$268>>2] = $280;
    $281 = ($$sum$i$i$i$i$i42|0)<(0);
    if (!($281)) {
     $$sum1$i$i$i$i$i43 = (($$sum$i$i$i$i$i42) + 1)|0;
     $282 = (($274) + ($$sum1$i$i$i$i$i43)|0);
     $283 = (($transfer) + 20|0);
     $284 = HEAP32[$283>>2]|0;
     $285 = ($282>>>0)>($284>>>0);
     if (!($285)) {
      $286 = HEAP8[$280>>0]|0;
      HEAP8[$264>>0] = $286;
      $287 = HEAP32[$268>>2]|0;
      $288 = (($287) + 1|0);
      HEAP32[$268>>2] = $288;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($268,$264,1);
   } else {
    $289 = HEAP32[$converter$i$i212>>2]|0;
    $290 = ($289|0)==(0|0);
    if (!($290)) {
     (FUNCTION_TABLE_iii[$289 & 4095]($264,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $291 = (($this) + 160|0);
 $292 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624088,$1,$converter$i$i212,0)|0);
 $293 = ($292|0)==(0);
 if (!($293)) {
  $294 = ($292|0)>(0);
  L150: do {
   if ($294) {
    $295 = (($transfer) + 12|0);
    $296 = (($transfer) + 80|0);
    $297 = HEAP32[$296>>2]|0;
    $298 = (($297) + 12|0);
    $299 = HEAP32[$298>>2]|0;
    $300 = (($transfer) + 16|0);
    $301 = HEAP32[$300>>2]|0;
    $302 = (($transfer) + 28|0);
    $303 = HEAP32[$302>>2]|0;
    $304 = (($transfer) + 32|0);
    $305 = HEAP32[$304>>2]|0;
    $306 = Math_imul($305, $303)|0;
    $$sum$i$i$i$i$i47 = (($299) - ($306))|0;
    $307 = (($301) + ($$sum$i$i$i$i$i47)|0);
    HEAP32[$295>>2] = $307;
    $308 = ($$sum$i$i$i$i$i47|0)<(0);
    do {
     if (!($308)) {
      $$sum1$i$i$i$i$i48 = (($$sum$i$i$i$i$i47) + 1)|0;
      $309 = (($301) + ($$sum1$i$i$i$i$i48)|0);
      $310 = (($transfer) + 20|0);
      $311 = HEAP32[$310>>2]|0;
      $312 = ($309>>>0)>($311>>>0);
      if ($312) {
       break;
      }
      $313 = HEAP8[$307>>0]|0;
      HEAP8[$291>>0] = $313;
      $314 = HEAP32[$295>>2]|0;
      $315 = (($314) + 1|0);
      HEAP32[$295>>2] = $315;
      break L150;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($295,$291,1);
   } else {
    $316 = HEAP32[$converter$i$i212>>2]|0;
    $317 = ($316|0)==(0|0);
    if (!($317)) {
     (FUNCTION_TABLE_iii[$316 & 4095]($291,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $318 = (($this) + 161|0);
 $319 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624112,$1,$converter$i$i212,0)|0);
 $320 = ($319|0)==(0);
 if (!($320)) {
  $321 = ($319|0)>(0);
  L162: do {
   if ($321) {
    $322 = (($transfer) + 12|0);
    $323 = (($transfer) + 80|0);
    $324 = HEAP32[$323>>2]|0;
    $325 = (($324) + 12|0);
    $326 = HEAP32[$325>>2]|0;
    $327 = (($transfer) + 16|0);
    $328 = HEAP32[$327>>2]|0;
    $329 = (($transfer) + 28|0);
    $330 = HEAP32[$329>>2]|0;
    $331 = (($transfer) + 32|0);
    $332 = HEAP32[$331>>2]|0;
    $333 = Math_imul($332, $330)|0;
    $$sum$i$i$i$i$i52 = (($326) - ($333))|0;
    $334 = (($328) + ($$sum$i$i$i$i$i52)|0);
    HEAP32[$322>>2] = $334;
    $335 = ($$sum$i$i$i$i$i52|0)<(0);
    do {
     if (!($335)) {
      $$sum1$i$i$i$i$i53 = (($$sum$i$i$i$i$i52) + 1)|0;
      $336 = (($328) + ($$sum1$i$i$i$i$i53)|0);
      $337 = (($transfer) + 20|0);
      $338 = HEAP32[$337>>2]|0;
      $339 = ($336>>>0)>($338>>>0);
      if ($339) {
       break;
      }
      $340 = HEAP8[$334>>0]|0;
      HEAP8[$318>>0] = $340;
      $341 = HEAP32[$322>>2]|0;
      $342 = (($341) + 1|0);
      HEAP32[$322>>2] = $342;
      break L162;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($322,$318,1);
   } else {
    $343 = HEAP32[$converter$i$i212>>2]|0;
    $344 = ($343|0)==(0|0);
    if (!($344)) {
     (FUNCTION_TABLE_iii[$343 & 4095]($318,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $345 = (($this) + 162|0);
 $346 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624136,$1,$converter$i$i212,0)|0);
 $347 = ($346|0)==(0);
 if (!($347)) {
  $348 = ($346|0)>(0);
  L174: do {
   if ($348) {
    $349 = (($transfer) + 12|0);
    $350 = (($transfer) + 80|0);
    $351 = HEAP32[$350>>2]|0;
    $352 = (($351) + 12|0);
    $353 = HEAP32[$352>>2]|0;
    $354 = (($transfer) + 16|0);
    $355 = HEAP32[$354>>2]|0;
    $356 = (($transfer) + 28|0);
    $357 = HEAP32[$356>>2]|0;
    $358 = (($transfer) + 32|0);
    $359 = HEAP32[$358>>2]|0;
    $360 = Math_imul($359, $357)|0;
    $$sum$i$i$i$i$i57 = (($353) - ($360))|0;
    $361 = (($355) + ($$sum$i$i$i$i$i57)|0);
    HEAP32[$349>>2] = $361;
    $362 = ($$sum$i$i$i$i$i57|0)<(0);
    do {
     if (!($362)) {
      $$sum1$i$i$i$i$i58 = (($$sum$i$i$i$i$i57) + 1)|0;
      $363 = (($355) + ($$sum1$i$i$i$i$i58)|0);
      $364 = (($transfer) + 20|0);
      $365 = HEAP32[$364>>2]|0;
      $366 = ($363>>>0)>($365>>>0);
      if ($366) {
       break;
      }
      $367 = HEAP8[$361>>0]|0;
      HEAP8[$345>>0] = $367;
      $368 = HEAP32[$349>>2]|0;
      $369 = (($368) + 1|0);
      HEAP32[$349>>2] = $369;
      break L174;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($349,$345,1);
   } else {
    $370 = HEAP32[$converter$i$i212>>2]|0;
    $371 = ($370|0)==(0|0);
    if ($371) {
     break;
    }
    (FUNCTION_TABLE_iii[$370 & 4095]($345,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $372 = (($this) + 163|0);
 $373 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624168,$1,$converter$i$i212,0)|0);
 $374 = ($373|0)==(0);
 if (!($374)) {
  $375 = ($373|0)>(0);
  L186: do {
   if ($375) {
    $376 = (($transfer) + 12|0);
    $377 = (($transfer) + 80|0);
    $378 = HEAP32[$377>>2]|0;
    $379 = (($378) + 12|0);
    $380 = HEAP32[$379>>2]|0;
    $381 = (($transfer) + 16|0);
    $382 = HEAP32[$381>>2]|0;
    $383 = (($transfer) + 28|0);
    $384 = HEAP32[$383>>2]|0;
    $385 = (($transfer) + 32|0);
    $386 = HEAP32[$385>>2]|0;
    $387 = Math_imul($386, $384)|0;
    $$sum$i$i$i$i$i62 = (($380) - ($387))|0;
    $388 = (($382) + ($$sum$i$i$i$i$i62)|0);
    HEAP32[$376>>2] = $388;
    $389 = ($$sum$i$i$i$i$i62|0)<(0);
    do {
     if (!($389)) {
      $$sum1$i$i$i$i$i63 = (($$sum$i$i$i$i$i62) + 1)|0;
      $390 = (($382) + ($$sum1$i$i$i$i$i63)|0);
      $391 = (($transfer) + 20|0);
      $392 = HEAP32[$391>>2]|0;
      $393 = ($390>>>0)>($392>>>0);
      if ($393) {
       break;
      }
      $394 = HEAP8[$388>>0]|0;
      HEAP8[$372>>0] = $394;
      $395 = HEAP32[$376>>2]|0;
      $396 = (($395) + 1|0);
      HEAP32[$376>>2] = $396;
      break L186;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($376,$372,1);
   } else {
    $397 = HEAP32[$converter$i$i212>>2]|0;
    $398 = ($397|0)==(0|0);
    if ($398) {
     break;
    }
    (FUNCTION_TABLE_iii[$397 & 4095]($372,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $399 = (($this) + 164|0);
 $400 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624192,$1,$converter$i$i212,0)|0);
 $401 = ($400|0)==(0);
 if (!($401)) {
  $402 = ($400|0)>(0);
  L198: do {
   if ($402) {
    $403 = (($transfer) + 12|0);
    $404 = (($transfer) + 80|0);
    $405 = HEAP32[$404>>2]|0;
    $406 = (($405) + 12|0);
    $407 = HEAP32[$406>>2]|0;
    $408 = (($transfer) + 16|0);
    $409 = HEAP32[$408>>2]|0;
    $410 = (($transfer) + 28|0);
    $411 = HEAP32[$410>>2]|0;
    $412 = (($transfer) + 32|0);
    $413 = HEAP32[$412>>2]|0;
    $414 = Math_imul($413, $411)|0;
    $$sum$i$i$i$i$i67 = (($407) - ($414))|0;
    $415 = (($409) + ($$sum$i$i$i$i$i67)|0);
    HEAP32[$403>>2] = $415;
    $416 = ($$sum$i$i$i$i$i67|0)<(0);
    do {
     if (!($416)) {
      $$sum1$i$i$i$i$i68 = (($$sum$i$i$i$i$i67) + 1)|0;
      $417 = (($409) + ($$sum1$i$i$i$i$i68)|0);
      $418 = (($transfer) + 20|0);
      $419 = HEAP32[$418>>2]|0;
      $420 = ($417>>>0)>($419>>>0);
      if ($420) {
       break;
      }
      $421 = HEAP8[$415>>0]|0;
      HEAP8[$399>>0] = $421;
      $422 = HEAP32[$403>>2]|0;
      $423 = (($422) + 1|0);
      HEAP32[$403>>2] = $423;
      break L198;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($403,$399,1);
   } else {
    $424 = HEAP32[$converter$i$i212>>2]|0;
    $425 = ($424|0)==(0|0);
    if ($425) {
     break;
    }
    (FUNCTION_TABLE_iii[$424 & 4095]($399,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $426 = (($this) + 165|0);
 $427 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624224,$1,$converter$i$i212,0)|0);
 $428 = ($427|0)==(0);
 if (!($428)) {
  $429 = ($427|0)>(0);
  L210: do {
   if ($429) {
    $430 = (($transfer) + 12|0);
    $431 = (($transfer) + 80|0);
    $432 = HEAP32[$431>>2]|0;
    $433 = (($432) + 12|0);
    $434 = HEAP32[$433>>2]|0;
    $435 = (($transfer) + 16|0);
    $436 = HEAP32[$435>>2]|0;
    $437 = (($transfer) + 28|0);
    $438 = HEAP32[$437>>2]|0;
    $439 = (($transfer) + 32|0);
    $440 = HEAP32[$439>>2]|0;
    $441 = Math_imul($440, $438)|0;
    $$sum$i$i$i$i$i72 = (($434) - ($441))|0;
    $442 = (($436) + ($$sum$i$i$i$i$i72)|0);
    HEAP32[$430>>2] = $442;
    $443 = ($$sum$i$i$i$i$i72|0)<(0);
    do {
     if (!($443)) {
      $$sum1$i$i$i$i$i73 = (($$sum$i$i$i$i$i72) + 1)|0;
      $444 = (($436) + ($$sum1$i$i$i$i$i73)|0);
      $445 = (($transfer) + 20|0);
      $446 = HEAP32[$445>>2]|0;
      $447 = ($444>>>0)>($446>>>0);
      if ($447) {
       break;
      }
      $448 = HEAP8[$442>>0]|0;
      HEAP8[$426>>0] = $448;
      $449 = HEAP32[$430>>2]|0;
      $450 = (($449) + 1|0);
      HEAP32[$430>>2] = $450;
      break L210;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($430,$426,1);
   } else {
    $451 = HEAP32[$converter$i$i212>>2]|0;
    $452 = ($451|0)==(0|0);
    if ($452) {
     break;
    }
    (FUNCTION_TABLE_iii[$451 & 4095]($426,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $453 = (($this) + 166|0);
 $454 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624240,$1,$converter$i$i212,0)|0);
 $455 = ($454|0)==(0);
 if (!($455)) {
  $456 = ($454|0)>(0);
  L222: do {
   if ($456) {
    $457 = (($transfer) + 12|0);
    $458 = (($transfer) + 80|0);
    $459 = HEAP32[$458>>2]|0;
    $460 = (($459) + 12|0);
    $461 = HEAP32[$460>>2]|0;
    $462 = (($transfer) + 16|0);
    $463 = HEAP32[$462>>2]|0;
    $464 = (($transfer) + 28|0);
    $465 = HEAP32[$464>>2]|0;
    $466 = (($transfer) + 32|0);
    $467 = HEAP32[$466>>2]|0;
    $468 = Math_imul($467, $465)|0;
    $$sum$i$i$i$i$i77 = (($461) - ($468))|0;
    $469 = (($463) + ($$sum$i$i$i$i$i77)|0);
    HEAP32[$457>>2] = $469;
    $470 = ($$sum$i$i$i$i$i77|0)<(0);
    do {
     if (!($470)) {
      $$sum1$i$i$i$i$i78 = (($$sum$i$i$i$i$i77) + 1)|0;
      $471 = (($463) + ($$sum1$i$i$i$i$i78)|0);
      $472 = (($transfer) + 20|0);
      $473 = HEAP32[$472>>2]|0;
      $474 = ($471>>>0)>($473>>>0);
      if ($474) {
       break;
      }
      $475 = HEAP8[$469>>0]|0;
      HEAP8[$453>>0] = $475;
      $476 = HEAP32[$457>>2]|0;
      $477 = (($476) + 1|0);
      HEAP32[$457>>2] = $477;
      break L222;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($457,$453,1);
   } else {
    $478 = HEAP32[$converter$i$i212>>2]|0;
    $479 = ($478|0)==(0|0);
    if ($479) {
     break;
    }
    (FUNCTION_TABLE_iii[$478 & 4095]($453,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $480 = (($this) + 167|0);
 $481 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624264,$1,$converter$i$i212,0)|0);
 $482 = ($481|0)==(0);
 if (!($482)) {
  $483 = ($481|0)>(0);
  L234: do {
   if ($483) {
    $484 = (($transfer) + 12|0);
    $485 = (($transfer) + 80|0);
    $486 = HEAP32[$485>>2]|0;
    $487 = (($486) + 12|0);
    $488 = HEAP32[$487>>2]|0;
    $489 = (($transfer) + 16|0);
    $490 = HEAP32[$489>>2]|0;
    $491 = (($transfer) + 28|0);
    $492 = HEAP32[$491>>2]|0;
    $493 = (($transfer) + 32|0);
    $494 = HEAP32[$493>>2]|0;
    $495 = Math_imul($494, $492)|0;
    $$sum$i$i$i$i$i82 = (($488) - ($495))|0;
    $496 = (($490) + ($$sum$i$i$i$i$i82)|0);
    HEAP32[$484>>2] = $496;
    $497 = ($$sum$i$i$i$i$i82|0)<(0);
    do {
     if (!($497)) {
      $$sum1$i$i$i$i$i83 = (($$sum$i$i$i$i$i82) + 1)|0;
      $498 = (($490) + ($$sum1$i$i$i$i$i83)|0);
      $499 = (($transfer) + 20|0);
      $500 = HEAP32[$499>>2]|0;
      $501 = ($498>>>0)>($500>>>0);
      if ($501) {
       break;
      }
      $502 = HEAP8[$496>>0]|0;
      HEAP8[$480>>0] = $502;
      $503 = HEAP32[$484>>2]|0;
      $504 = (($503) + 1|0);
      HEAP32[$484>>2] = $504;
      break L234;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($484,$480,1);
   } else {
    $505 = HEAP32[$converter$i$i212>>2]|0;
    $506 = ($505|0)==(0|0);
    if ($506) {
     break;
    }
    (FUNCTION_TABLE_iii[$505 & 4095]($480,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $507 = (($this) + 168|0);
 $508 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624288,$1,$converter$i$i212,0)|0);
 $509 = ($508|0)==(0);
 if (!($509)) {
  $510 = ($508|0)>(0);
  L246: do {
   if ($510) {
    $511 = (($transfer) + 12|0);
    $512 = (($transfer) + 80|0);
    $513 = HEAP32[$512>>2]|0;
    $514 = (($513) + 12|0);
    $515 = HEAP32[$514>>2]|0;
    $516 = (($transfer) + 16|0);
    $517 = HEAP32[$516>>2]|0;
    $518 = (($transfer) + 28|0);
    $519 = HEAP32[$518>>2]|0;
    $520 = (($transfer) + 32|0);
    $521 = HEAP32[$520>>2]|0;
    $522 = Math_imul($521, $519)|0;
    $$sum$i$i$i$i$i87 = (($515) - ($522))|0;
    $523 = (($517) + ($$sum$i$i$i$i$i87)|0);
    HEAP32[$511>>2] = $523;
    $524 = ($$sum$i$i$i$i$i87|0)<(0);
    do {
     if (!($524)) {
      $$sum1$i$i$i$i$i88 = (($$sum$i$i$i$i$i87) + 1)|0;
      $525 = (($517) + ($$sum1$i$i$i$i$i88)|0);
      $526 = (($transfer) + 20|0);
      $527 = HEAP32[$526>>2]|0;
      $528 = ($525>>>0)>($527>>>0);
      if ($528) {
       break;
      }
      $529 = HEAP8[$523>>0]|0;
      HEAP8[$507>>0] = $529;
      $530 = HEAP32[$511>>2]|0;
      $531 = (($530) + 1|0);
      HEAP32[$511>>2] = $531;
      break L246;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($511,$507,1);
   } else {
    $532 = HEAP32[$converter$i$i212>>2]|0;
    $533 = ($532|0)==(0|0);
    if ($533) {
     break;
    }
    (FUNCTION_TABLE_iii[$532 & 4095]($507,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $534 = (($this) + 169|0);
 $535 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,623344,$1,$converter$i$i212,0)|0);
 $536 = ($535|0)==(0);
 if (!($536)) {
  $537 = ($535|0)>(0);
  L258: do {
   if ($537) {
    $538 = (($transfer) + 12|0);
    $539 = (($transfer) + 80|0);
    $540 = HEAP32[$539>>2]|0;
    $541 = (($540) + 12|0);
    $542 = HEAP32[$541>>2]|0;
    $543 = (($transfer) + 16|0);
    $544 = HEAP32[$543>>2]|0;
    $545 = (($transfer) + 28|0);
    $546 = HEAP32[$545>>2]|0;
    $547 = (($transfer) + 32|0);
    $548 = HEAP32[$547>>2]|0;
    $549 = Math_imul($548, $546)|0;
    $$sum$i$i$i$i$i92 = (($542) - ($549))|0;
    $550 = (($544) + ($$sum$i$i$i$i$i92)|0);
    HEAP32[$538>>2] = $550;
    $551 = ($$sum$i$i$i$i$i92|0)<(0);
    do {
     if (!($551)) {
      $$sum1$i$i$i$i$i93 = (($$sum$i$i$i$i$i92) + 1)|0;
      $552 = (($544) + ($$sum1$i$i$i$i$i93)|0);
      $553 = (($transfer) + 20|0);
      $554 = HEAP32[$553>>2]|0;
      $555 = ($552>>>0)>($554>>>0);
      if ($555) {
       break;
      }
      $556 = HEAP8[$550>>0]|0;
      HEAP8[$534>>0] = $556;
      $557 = HEAP32[$538>>2]|0;
      $558 = (($557) + 1|0);
      HEAP32[$538>>2] = $558;
      break L258;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($538,$534,1);
   } else {
    $559 = HEAP32[$converter$i$i212>>2]|0;
    $560 = ($559|0)==(0|0);
    if ($560) {
     break;
    }
    (FUNCTION_TABLE_iii[$559 & 4095]($534,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $561 = (($this) + 170|0);
 $562 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624320,$1,$converter$i$i212,0)|0);
 $563 = ($562|0)==(0);
 if (!($563)) {
  $564 = ($562|0)>(0);
  L270: do {
   if ($564) {
    $565 = (($transfer) + 12|0);
    $566 = (($transfer) + 80|0);
    $567 = HEAP32[$566>>2]|0;
    $568 = (($567) + 12|0);
    $569 = HEAP32[$568>>2]|0;
    $570 = (($transfer) + 16|0);
    $571 = HEAP32[$570>>2]|0;
    $572 = (($transfer) + 28|0);
    $573 = HEAP32[$572>>2]|0;
    $574 = (($transfer) + 32|0);
    $575 = HEAP32[$574>>2]|0;
    $576 = Math_imul($575, $573)|0;
    $$sum$i$i$i$i$i97 = (($569) - ($576))|0;
    $577 = (($571) + ($$sum$i$i$i$i$i97)|0);
    HEAP32[$565>>2] = $577;
    $578 = ($$sum$i$i$i$i$i97|0)<(0);
    do {
     if (!($578)) {
      $$sum1$i$i$i$i$i98 = (($$sum$i$i$i$i$i97) + 1)|0;
      $579 = (($571) + ($$sum1$i$i$i$i$i98)|0);
      $580 = (($transfer) + 20|0);
      $581 = HEAP32[$580>>2]|0;
      $582 = ($579>>>0)>($581>>>0);
      if ($582) {
       break;
      }
      $583 = HEAP8[$577>>0]|0;
      HEAP8[$561>>0] = $583;
      $584 = HEAP32[$565>>2]|0;
      $585 = (($584) + 1|0);
      HEAP32[$565>>2] = $585;
      break L270;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($565,$561,1);
   } else {
    $586 = HEAP32[$converter$i$i212>>2]|0;
    $587 = ($586|0)==(0|0);
    if ($587) {
     break;
    }
    (FUNCTION_TABLE_iii[$586 & 4095]($561,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $588 = (($this) + 171|0);
 $589 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624336,$1,$converter$i$i212,0)|0);
 $590 = ($589|0)==(0);
 if (!($590)) {
  $591 = ($589|0)>(0);
  L282: do {
   if ($591) {
    $592 = (($transfer) + 12|0);
    $593 = (($transfer) + 80|0);
    $594 = HEAP32[$593>>2]|0;
    $595 = (($594) + 12|0);
    $596 = HEAP32[$595>>2]|0;
    $597 = (($transfer) + 16|0);
    $598 = HEAP32[$597>>2]|0;
    $599 = (($transfer) + 28|0);
    $600 = HEAP32[$599>>2]|0;
    $601 = (($transfer) + 32|0);
    $602 = HEAP32[$601>>2]|0;
    $603 = Math_imul($602, $600)|0;
    $$sum$i$i$i$i$i102 = (($596) - ($603))|0;
    $604 = (($598) + ($$sum$i$i$i$i$i102)|0);
    HEAP32[$592>>2] = $604;
    $605 = ($$sum$i$i$i$i$i102|0)<(0);
    do {
     if (!($605)) {
      $$sum1$i$i$i$i$i103 = (($$sum$i$i$i$i$i102) + 1)|0;
      $606 = (($598) + ($$sum1$i$i$i$i$i103)|0);
      $607 = (($transfer) + 20|0);
      $608 = HEAP32[$607>>2]|0;
      $609 = ($606>>>0)>($608>>>0);
      if ($609) {
       break;
      }
      $610 = HEAP8[$604>>0]|0;
      HEAP8[$588>>0] = $610;
      $611 = HEAP32[$592>>2]|0;
      $612 = (($611) + 1|0);
      HEAP32[$592>>2] = $612;
      break L282;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($592,$588,1);
   } else {
    $613 = HEAP32[$converter$i$i212>>2]|0;
    $614 = ($613|0)==(0|0);
    if ($614) {
     break;
    }
    (FUNCTION_TABLE_iii[$613 & 4095]($588,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $615 = (($this) + 180|0);
 $616 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624360,$1,$converter$i$i212,0)|0);
 $617 = ($616|0)==(0);
 if (!($617)) {
  $618 = ($616|0)>(0);
  L294: do {
   if ($618) {
    $619 = (($transfer) + 12|0);
    $620 = (($transfer) + 80|0);
    $621 = HEAP32[$620>>2]|0;
    $622 = (($621) + 12|0);
    $623 = HEAP32[$622>>2]|0;
    $624 = (($transfer) + 16|0);
    $625 = HEAP32[$624>>2]|0;
    $626 = (($transfer) + 28|0);
    $627 = HEAP32[$626>>2]|0;
    $628 = (($transfer) + 32|0);
    $629 = HEAP32[$628>>2]|0;
    $630 = Math_imul($629, $627)|0;
    $$sum$i$i$i$i$i107 = (($623) - ($630))|0;
    $631 = (($625) + ($$sum$i$i$i$i$i107)|0);
    HEAP32[$619>>2] = $631;
    $632 = ($$sum$i$i$i$i$i107|0)<(0);
    do {
     if (!($632)) {
      $$sum1$i$i$i$i$i108 = (($$sum$i$i$i$i$i107) + 1)|0;
      $633 = (($625) + ($$sum1$i$i$i$i$i108)|0);
      $634 = (($transfer) + 20|0);
      $635 = HEAP32[$634>>2]|0;
      $636 = ($633>>>0)>($635>>>0);
      if ($636) {
       break;
      }
      $637 = HEAP8[$631>>0]|0;
      HEAP8[$615>>0] = $637;
      $638 = HEAP32[$619>>2]|0;
      $639 = (($638) + 1|0);
      HEAP32[$619>>2] = $639;
      break L294;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($619,$615,1);
   } else {
    $640 = HEAP32[$converter$i$i212>>2]|0;
    $641 = ($640|0)==(0|0);
    if ($641) {
     break;
    }
    (FUNCTION_TABLE_iii[$640 & 4095]($615,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $642 = (($this) + 181|0);
 $643 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624384,$1,$converter$i$i212,0)|0);
 $644 = ($643|0)==(0);
 if (!($644)) {
  $645 = ($643|0)>(0);
  L306: do {
   if ($645) {
    $646 = (($transfer) + 12|0);
    $647 = (($transfer) + 80|0);
    $648 = HEAP32[$647>>2]|0;
    $649 = (($648) + 12|0);
    $650 = HEAP32[$649>>2]|0;
    $651 = (($transfer) + 16|0);
    $652 = HEAP32[$651>>2]|0;
    $653 = (($transfer) + 28|0);
    $654 = HEAP32[$653>>2]|0;
    $655 = (($transfer) + 32|0);
    $656 = HEAP32[$655>>2]|0;
    $657 = Math_imul($656, $654)|0;
    $$sum$i$i$i$i$i112 = (($650) - ($657))|0;
    $658 = (($652) + ($$sum$i$i$i$i$i112)|0);
    HEAP32[$646>>2] = $658;
    $659 = ($$sum$i$i$i$i$i112|0)<(0);
    do {
     if (!($659)) {
      $$sum1$i$i$i$i$i113 = (($$sum$i$i$i$i$i112) + 1)|0;
      $660 = (($652) + ($$sum1$i$i$i$i$i113)|0);
      $661 = (($transfer) + 20|0);
      $662 = HEAP32[$661>>2]|0;
      $663 = ($660>>>0)>($662>>>0);
      if ($663) {
       break;
      }
      $664 = HEAP8[$658>>0]|0;
      HEAP8[$642>>0] = $664;
      $665 = HEAP32[$646>>2]|0;
      $666 = (($665) + 1|0);
      HEAP32[$646>>2] = $666;
      break L306;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($646,$642,1);
   } else {
    $667 = HEAP32[$converter$i$i212>>2]|0;
    $668 = ($667|0)==(0|0);
    if ($668) {
     break;
    }
    (FUNCTION_TABLE_iii[$667 & 4095]($642,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $669 = (($this) + 172|0);
 $670 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624400,$1,$converter$i$i212,0)|0);
 $671 = ($670|0)==(0);
 if (!($671)) {
  $672 = ($670|0)>(0);
  L318: do {
   if ($672) {
    $673 = (($transfer) + 12|0);
    $674 = (($transfer) + 80|0);
    $675 = HEAP32[$674>>2]|0;
    $676 = (($675) + 12|0);
    $677 = HEAP32[$676>>2]|0;
    $678 = (($transfer) + 16|0);
    $679 = HEAP32[$678>>2]|0;
    $680 = (($transfer) + 28|0);
    $681 = HEAP32[$680>>2]|0;
    $682 = (($transfer) + 32|0);
    $683 = HEAP32[$682>>2]|0;
    $684 = Math_imul($683, $681)|0;
    $$sum$i$i$i$i$i117 = (($677) - ($684))|0;
    $685 = (($679) + ($$sum$i$i$i$i$i117)|0);
    HEAP32[$673>>2] = $685;
    $686 = ($$sum$i$i$i$i$i117|0)<(0);
    do {
     if (!($686)) {
      $$sum1$i$i$i$i$i118 = (($$sum$i$i$i$i$i117) + 1)|0;
      $687 = (($679) + ($$sum1$i$i$i$i$i118)|0);
      $688 = (($transfer) + 20|0);
      $689 = HEAP32[$688>>2]|0;
      $690 = ($687>>>0)>($689>>>0);
      if ($690) {
       break;
      }
      $691 = HEAP8[$685>>0]|0;
      HEAP8[$669>>0] = $691;
      $692 = HEAP32[$673>>2]|0;
      $693 = (($692) + 1|0);
      HEAP32[$673>>2] = $693;
      break L318;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($673,$669,1);
   } else {
    $694 = HEAP32[$converter$i$i212>>2]|0;
    $695 = ($694|0)==(0|0);
    if ($695) {
     break;
    }
    (FUNCTION_TABLE_iii[$694 & 4095]($669,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $696 = (($this) + 182|0);
 $697 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624432,$1,$converter$i$i212,0)|0);
 $698 = ($697|0)==(0);
 if (!($698)) {
  $699 = ($697|0)>(0);
  L330: do {
   if ($699) {
    $700 = (($transfer) + 12|0);
    $701 = (($transfer) + 80|0);
    $702 = HEAP32[$701>>2]|0;
    $703 = (($702) + 12|0);
    $704 = HEAP32[$703>>2]|0;
    $705 = (($transfer) + 16|0);
    $706 = HEAP32[$705>>2]|0;
    $707 = (($transfer) + 28|0);
    $708 = HEAP32[$707>>2]|0;
    $709 = (($transfer) + 32|0);
    $710 = HEAP32[$709>>2]|0;
    $711 = Math_imul($710, $708)|0;
    $$sum$i$i$i$i$i122 = (($704) - ($711))|0;
    $712 = (($706) + ($$sum$i$i$i$i$i122)|0);
    HEAP32[$700>>2] = $712;
    $713 = ($$sum$i$i$i$i$i122|0)<(0);
    do {
     if (!($713)) {
      $$sum1$i$i$i$i$i123 = (($$sum$i$i$i$i$i122) + 1)|0;
      $714 = (($706) + ($$sum1$i$i$i$i$i123)|0);
      $715 = (($transfer) + 20|0);
      $716 = HEAP32[$715>>2]|0;
      $717 = ($714>>>0)>($716>>>0);
      if ($717) {
       break;
      }
      $718 = HEAP8[$712>>0]|0;
      HEAP8[$696>>0] = $718;
      $719 = HEAP32[$700>>2]|0;
      $720 = (($719) + 1|0);
      HEAP32[$700>>2] = $720;
      break L330;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($700,$696,1);
   } else {
    $721 = HEAP32[$converter$i$i212>>2]|0;
    $722 = ($721|0)==(0|0);
    if ($722) {
     break;
    }
    (FUNCTION_TABLE_iii[$721 & 4095]($696,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $723 = (($this) + 183|0);
 $724 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624448,$1,$converter$i$i212,0)|0);
 $725 = ($724|0)==(0);
 if (!($725)) {
  $726 = ($724|0)>(0);
  L342: do {
   if ($726) {
    $727 = (($transfer) + 12|0);
    $728 = (($transfer) + 80|0);
    $729 = HEAP32[$728>>2]|0;
    $730 = (($729) + 12|0);
    $731 = HEAP32[$730>>2]|0;
    $732 = (($transfer) + 16|0);
    $733 = HEAP32[$732>>2]|0;
    $734 = (($transfer) + 28|0);
    $735 = HEAP32[$734>>2]|0;
    $736 = (($transfer) + 32|0);
    $737 = HEAP32[$736>>2]|0;
    $738 = Math_imul($737, $735)|0;
    $$sum$i$i$i$i$i127 = (($731) - ($738))|0;
    $739 = (($733) + ($$sum$i$i$i$i$i127)|0);
    HEAP32[$727>>2] = $739;
    $740 = ($$sum$i$i$i$i$i127|0)<(0);
    do {
     if (!($740)) {
      $$sum1$i$i$i$i$i128 = (($$sum$i$i$i$i$i127) + 1)|0;
      $741 = (($733) + ($$sum1$i$i$i$i$i128)|0);
      $742 = (($transfer) + 20|0);
      $743 = HEAP32[$742>>2]|0;
      $744 = ($741>>>0)>($743>>>0);
      if ($744) {
       break;
      }
      $745 = HEAP8[$739>>0]|0;
      HEAP8[$723>>0] = $745;
      $746 = HEAP32[$727>>2]|0;
      $747 = (($746) + 1|0);
      HEAP32[$727>>2] = $747;
      break L342;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($727,$723,1);
   } else {
    $748 = HEAP32[$converter$i$i212>>2]|0;
    $749 = ($748|0)==(0|0);
    if ($749) {
     break;
    }
    (FUNCTION_TABLE_iii[$748 & 4095]($723,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $750 = (($this) + 184|0);
 $751 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624472,$1,$converter$i$i212,0)|0);
 $752 = ($751|0)==(0);
 if (!($752)) {
  $753 = ($751|0)>(0);
  L354: do {
   if ($753) {
    $754 = (($transfer) + 12|0);
    $755 = (($transfer) + 80|0);
    $756 = HEAP32[$755>>2]|0;
    $757 = (($756) + 12|0);
    $758 = HEAP32[$757>>2]|0;
    $759 = (($transfer) + 16|0);
    $760 = HEAP32[$759>>2]|0;
    $761 = (($transfer) + 28|0);
    $762 = HEAP32[$761>>2]|0;
    $763 = (($transfer) + 32|0);
    $764 = HEAP32[$763>>2]|0;
    $765 = Math_imul($764, $762)|0;
    $$sum$i$i$i$i$i132 = (($758) - ($765))|0;
    $766 = (($760) + ($$sum$i$i$i$i$i132)|0);
    HEAP32[$754>>2] = $766;
    $767 = ($$sum$i$i$i$i$i132|0)<(0);
    do {
     if (!($767)) {
      $$sum1$i$i$i$i$i133 = (($$sum$i$i$i$i$i132) + 1)|0;
      $768 = (($760) + ($$sum1$i$i$i$i$i133)|0);
      $769 = (($transfer) + 20|0);
      $770 = HEAP32[$769>>2]|0;
      $771 = ($768>>>0)>($770>>>0);
      if ($771) {
       break;
      }
      $772 = HEAP8[$766>>0]|0;
      HEAP8[$750>>0] = $772;
      $773 = HEAP32[$754>>2]|0;
      $774 = (($773) + 1|0);
      HEAP32[$754>>2] = $774;
      break L354;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($754,$750,1);
   } else {
    $775 = HEAP32[$converter$i$i212>>2]|0;
    $776 = ($775|0)==(0|0);
    if ($776) {
     break;
    }
    (FUNCTION_TABLE_iii[$775 & 4095]($750,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $777 = (($this) + 185|0);
 $778 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624496,$1,$converter$i$i212,0)|0);
 $779 = ($778|0)==(0);
 if (!($779)) {
  $780 = ($778|0)>(0);
  L366: do {
   if ($780) {
    $781 = (($transfer) + 12|0);
    $782 = (($transfer) + 80|0);
    $783 = HEAP32[$782>>2]|0;
    $784 = (($783) + 12|0);
    $785 = HEAP32[$784>>2]|0;
    $786 = (($transfer) + 16|0);
    $787 = HEAP32[$786>>2]|0;
    $788 = (($transfer) + 28|0);
    $789 = HEAP32[$788>>2]|0;
    $790 = (($transfer) + 32|0);
    $791 = HEAP32[$790>>2]|0;
    $792 = Math_imul($791, $789)|0;
    $$sum$i$i$i$i$i137 = (($785) - ($792))|0;
    $793 = (($787) + ($$sum$i$i$i$i$i137)|0);
    HEAP32[$781>>2] = $793;
    $794 = ($$sum$i$i$i$i$i137|0)<(0);
    do {
     if (!($794)) {
      $$sum1$i$i$i$i$i138 = (($$sum$i$i$i$i$i137) + 1)|0;
      $795 = (($787) + ($$sum1$i$i$i$i$i138)|0);
      $796 = (($transfer) + 20|0);
      $797 = HEAP32[$796>>2]|0;
      $798 = ($795>>>0)>($797>>>0);
      if ($798) {
       break;
      }
      $799 = HEAP8[$793>>0]|0;
      HEAP8[$777>>0] = $799;
      $800 = HEAP32[$781>>2]|0;
      $801 = (($800) + 1|0);
      HEAP32[$781>>2] = $801;
      break L366;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($781,$777,1);
   } else {
    $802 = HEAP32[$converter$i$i212>>2]|0;
    $803 = ($802|0)==(0|0);
    if ($803) {
     break;
    }
    (FUNCTION_TABLE_iii[$802 & 4095]($777,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $804 = (($this) + 186|0);
 $805 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624520,$1,$converter$i$i212,0)|0);
 $806 = ($805|0)==(0);
 if (!($806)) {
  $807 = ($805|0)>(0);
  L378: do {
   if ($807) {
    $808 = (($transfer) + 12|0);
    $809 = (($transfer) + 80|0);
    $810 = HEAP32[$809>>2]|0;
    $811 = (($810) + 12|0);
    $812 = HEAP32[$811>>2]|0;
    $813 = (($transfer) + 16|0);
    $814 = HEAP32[$813>>2]|0;
    $815 = (($transfer) + 28|0);
    $816 = HEAP32[$815>>2]|0;
    $817 = (($transfer) + 32|0);
    $818 = HEAP32[$817>>2]|0;
    $819 = Math_imul($818, $816)|0;
    $$sum$i$i$i$i$i142 = (($812) - ($819))|0;
    $820 = (($814) + ($$sum$i$i$i$i$i142)|0);
    HEAP32[$808>>2] = $820;
    $821 = ($$sum$i$i$i$i$i142|0)<(0);
    do {
     if (!($821)) {
      $$sum1$i$i$i$i$i143 = (($$sum$i$i$i$i$i142) + 1)|0;
      $822 = (($814) + ($$sum1$i$i$i$i$i143)|0);
      $823 = (($transfer) + 20|0);
      $824 = HEAP32[$823>>2]|0;
      $825 = ($822>>>0)>($824>>>0);
      if ($825) {
       break;
      }
      $826 = HEAP8[$820>>0]|0;
      HEAP8[$804>>0] = $826;
      $827 = HEAP32[$808>>2]|0;
      $828 = (($827) + 1|0);
      HEAP32[$808>>2] = $828;
      break L378;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($808,$804,1);
   } else {
    $829 = HEAP32[$converter$i$i212>>2]|0;
    $830 = ($829|0)==(0|0);
    if ($830) {
     break;
    }
    (FUNCTION_TABLE_iii[$829 & 4095]($804,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $831 = (($this) + 192|0);
 $832 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624552,$1,$converter$i$i212,0)|0);
 $833 = ($832|0)==(0);
 if (!($833)) {
  $834 = ($832|0)>(0);
  L390: do {
   if ($834) {
    $835 = (($transfer) + 12|0);
    $836 = (($transfer) + 80|0);
    $837 = HEAP32[$836>>2]|0;
    $838 = (($837) + 12|0);
    $839 = HEAP32[$838>>2]|0;
    $840 = (($transfer) + 16|0);
    $841 = HEAP32[$840>>2]|0;
    $842 = (($transfer) + 28|0);
    $843 = HEAP32[$842>>2]|0;
    $844 = (($transfer) + 32|0);
    $845 = HEAP32[$844>>2]|0;
    $846 = Math_imul($845, $843)|0;
    $$sum$i$i$i$i$i147 = (($839) - ($846))|0;
    $847 = (($841) + ($$sum$i$i$i$i$i147)|0);
    HEAP32[$835>>2] = $847;
    $848 = ($$sum$i$i$i$i$i147|0)<(0);
    do {
     if (!($848)) {
      $$sum1$i$i$i$i$i148 = (($$sum$i$i$i$i$i147) + 1)|0;
      $849 = (($841) + ($$sum1$i$i$i$i$i148)|0);
      $850 = (($transfer) + 20|0);
      $851 = HEAP32[$850>>2]|0;
      $852 = ($849>>>0)>($851>>>0);
      if ($852) {
       break;
      }
      $853 = HEAP8[$847>>0]|0;
      HEAP8[$831>>0] = $853;
      $854 = HEAP32[$835>>2]|0;
      $855 = (($854) + 1|0);
      HEAP32[$835>>2] = $855;
      break L390;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($835,$831,1);
   } else {
    $856 = HEAP32[$converter$i$i212>>2]|0;
    $857 = ($856|0)==(0|0);
    if ($857) {
     break;
    }
    (FUNCTION_TABLE_iii[$856 & 4095]($831,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $858 = (($this) + 173|0);
 $859 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624576,$1,$converter$i$i212,0)|0);
 $860 = ($859|0)==(0);
 if (!($860)) {
  $861 = ($859|0)>(0);
  L402: do {
   if ($861) {
    $862 = (($transfer) + 12|0);
    $863 = (($transfer) + 80|0);
    $864 = HEAP32[$863>>2]|0;
    $865 = (($864) + 12|0);
    $866 = HEAP32[$865>>2]|0;
    $867 = (($transfer) + 16|0);
    $868 = HEAP32[$867>>2]|0;
    $869 = (($transfer) + 28|0);
    $870 = HEAP32[$869>>2]|0;
    $871 = (($transfer) + 32|0);
    $872 = HEAP32[$871>>2]|0;
    $873 = Math_imul($872, $870)|0;
    $$sum$i$i$i$i$i152 = (($866) - ($873))|0;
    $874 = (($868) + ($$sum$i$i$i$i$i152)|0);
    HEAP32[$862>>2] = $874;
    $875 = ($$sum$i$i$i$i$i152|0)<(0);
    do {
     if (!($875)) {
      $$sum1$i$i$i$i$i153 = (($$sum$i$i$i$i$i152) + 1)|0;
      $876 = (($868) + ($$sum1$i$i$i$i$i153)|0);
      $877 = (($transfer) + 20|0);
      $878 = HEAP32[$877>>2]|0;
      $879 = ($876>>>0)>($878>>>0);
      if ($879) {
       break;
      }
      $880 = HEAP8[$874>>0]|0;
      HEAP8[$858>>0] = $880;
      $881 = HEAP32[$862>>2]|0;
      $882 = (($881) + 1|0);
      HEAP32[$862>>2] = $882;
      break L402;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($862,$858,1);
   } else {
    $883 = HEAP32[$converter$i$i212>>2]|0;
    $884 = ($883|0)==(0|0);
    if ($884) {
     break;
    }
    (FUNCTION_TABLE_iii[$883 & 4095]($858,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $885 = (($this) + 176|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$885,624600,0);
 $886 = (($this) + 188|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$886,624624,0);
 $887 = (($this) + 193|0);
 $888 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624640,$1,$converter$i$i212,0)|0);
 $889 = ($888|0)==(0);
 if (!($889)) {
  $890 = ($888|0)>(0);
  L414: do {
   if ($890) {
    $891 = (($transfer) + 12|0);
    $892 = (($transfer) + 80|0);
    $893 = HEAP32[$892>>2]|0;
    $894 = (($893) + 12|0);
    $895 = HEAP32[$894>>2]|0;
    $896 = (($transfer) + 16|0);
    $897 = HEAP32[$896>>2]|0;
    $898 = (($transfer) + 28|0);
    $899 = HEAP32[$898>>2]|0;
    $900 = (($transfer) + 32|0);
    $901 = HEAP32[$900>>2]|0;
    $902 = Math_imul($901, $899)|0;
    $$sum$i$i$i$i$i157 = (($895) - ($902))|0;
    $903 = (($897) + ($$sum$i$i$i$i$i157)|0);
    HEAP32[$891>>2] = $903;
    $904 = ($$sum$i$i$i$i$i157|0)<(0);
    do {
     if (!($904)) {
      $$sum1$i$i$i$i$i158 = (($$sum$i$i$i$i$i157) + 1)|0;
      $905 = (($897) + ($$sum1$i$i$i$i$i158)|0);
      $906 = (($transfer) + 20|0);
      $907 = HEAP32[$906>>2]|0;
      $908 = ($905>>>0)>($907>>>0);
      if ($908) {
       break;
      }
      $909 = HEAP8[$903>>0]|0;
      HEAP8[$887>>0] = $909;
      $910 = HEAP32[$891>>2]|0;
      $911 = (($910) + 1|0);
      HEAP32[$891>>2] = $911;
      break L414;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($891,$887,1);
   } else {
    $912 = HEAP32[$converter$i$i212>>2]|0;
    $913 = ($912|0)==(0|0);
    if ($913) {
     break;
    }
    (FUNCTION_TABLE_iii[$912 & 4095]($887,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $914 = (($this) + 194|0);
 $915 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624672,$1,$converter$i$i212,0)|0);
 $916 = ($915|0)==(0);
 if (!($916)) {
  $917 = ($915|0)>(0);
  L426: do {
   if ($917) {
    $918 = (($transfer) + 12|0);
    $919 = (($transfer) + 80|0);
    $920 = HEAP32[$919>>2]|0;
    $921 = (($920) + 12|0);
    $922 = HEAP32[$921>>2]|0;
    $923 = (($transfer) + 16|0);
    $924 = HEAP32[$923>>2]|0;
    $925 = (($transfer) + 28|0);
    $926 = HEAP32[$925>>2]|0;
    $927 = (($transfer) + 32|0);
    $928 = HEAP32[$927>>2]|0;
    $929 = Math_imul($928, $926)|0;
    $$sum$i$i$i$i$i162 = (($922) - ($929))|0;
    $930 = (($924) + ($$sum$i$i$i$i$i162)|0);
    HEAP32[$918>>2] = $930;
    $931 = ($$sum$i$i$i$i$i162|0)<(0);
    do {
     if (!($931)) {
      $$sum1$i$i$i$i$i163 = (($$sum$i$i$i$i$i162) + 1)|0;
      $932 = (($924) + ($$sum1$i$i$i$i$i163)|0);
      $933 = (($transfer) + 20|0);
      $934 = HEAP32[$933>>2]|0;
      $935 = ($932>>>0)>($934>>>0);
      if ($935) {
       break;
      }
      $936 = HEAP8[$930>>0]|0;
      HEAP8[$914>>0] = $936;
      $937 = HEAP32[$918>>2]|0;
      $938 = (($937) + 1|0);
      HEAP32[$918>>2] = $938;
      break L426;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($918,$914,1);
   } else {
    $939 = HEAP32[$converter$i$i212>>2]|0;
    $940 = ($939|0)==(0|0);
    if ($940) {
     break;
    }
    (FUNCTION_TABLE_iii[$939 & 4095]($914,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $941 = (($this) + 196|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$941,624688,0);
 $942 = (($this) + 204|0);
 $943 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624712,625096,$converter$i$i212,1)|0);
 $944 = ($943|0)==(0);
 if (!($944)) {
  $945 = ($943|0)>(0);
  do {
   if ($945) {
    __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($942,$transfer);
   } else {
    $946 = HEAP32[$converter$i$i212>>2]|0;
    $947 = ($946|0)==(0|0);
    if ($947) {
     break;
    }
    (FUNCTION_TABLE_iii[$946 & 4095]($942,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $948 = (($this) + 208|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$948,624728,0);
 $949 = (($this) + 212|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$949,624760,0);
 $950 = (($this) + 216|0);
 $951 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624776,$1,$converter$i$i212,0)|0);
 $952 = ($951|0)==(0);
 if (!($952)) {
  $953 = ($951|0)>(0);
  L446: do {
   if ($953) {
    $954 = (($transfer) + 12|0);
    $955 = (($transfer) + 80|0);
    $956 = HEAP32[$955>>2]|0;
    $957 = (($956) + 12|0);
    $958 = HEAP32[$957>>2]|0;
    $959 = (($transfer) + 16|0);
    $960 = HEAP32[$959>>2]|0;
    $961 = (($transfer) + 28|0);
    $962 = HEAP32[$961>>2]|0;
    $963 = (($transfer) + 32|0);
    $964 = HEAP32[$963>>2]|0;
    $965 = Math_imul($964, $962)|0;
    $$sum$i$i$i$i$i169 = (($958) - ($965))|0;
    $966 = (($960) + ($$sum$i$i$i$i$i169)|0);
    HEAP32[$954>>2] = $966;
    $967 = ($$sum$i$i$i$i$i169|0)<(0);
    do {
     if (!($967)) {
      $$sum1$i$i$i$i$i170 = (($$sum$i$i$i$i$i169) + 1)|0;
      $968 = (($960) + ($$sum1$i$i$i$i$i170)|0);
      $969 = (($transfer) + 20|0);
      $970 = HEAP32[$969>>2]|0;
      $971 = ($968>>>0)>($970>>>0);
      if ($971) {
       break;
      }
      $972 = HEAP8[$966>>0]|0;
      HEAP8[$950>>0] = $972;
      $973 = HEAP32[$954>>2]|0;
      $974 = (($973) + 1|0);
      HEAP32[$954>>2] = $974;
      break L446;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($954,$950,1);
   } else {
    $975 = HEAP32[$converter$i$i212>>2]|0;
    $976 = ($975|0)==(0|0);
    if ($976) {
     break;
    }
    (FUNCTION_TABLE_iii[$975 & 4095]($950,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $977 = (($this) + 120|0);
 $978 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624792,625080,$converter$i$i192,1)|0);
 $979 = ($978|0)==(0);
 if (!($979)) {
  $980 = ($978|0)>(0);
  do {
   if ($980) {
    $981 = (($this) + 121|0);
    $982 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,625024,$1,$converter$i$i212,0)|0);
    $983 = ($982|0)==(0);
    if (!($983)) {
     $984 = ($982|0)>(0);
     L462: do {
      if ($984) {
       $985 = (($transfer) + 12|0);
       $986 = (($transfer) + 80|0);
       $987 = HEAP32[$986>>2]|0;
       $988 = (($987) + 12|0);
       $989 = HEAP32[$988>>2]|0;
       $990 = (($transfer) + 16|0);
       $991 = HEAP32[$990>>2]|0;
       $992 = (($transfer) + 28|0);
       $993 = HEAP32[$992>>2]|0;
       $994 = (($transfer) + 32|0);
       $995 = HEAP32[$994>>2]|0;
       $996 = Math_imul($995, $993)|0;
       $$sum$i$i$i$i$i203 = (($989) - ($996))|0;
       $997 = (($991) + ($$sum$i$i$i$i$i203)|0);
       HEAP32[$985>>2] = $997;
       $998 = ($$sum$i$i$i$i$i203|0)<(0);
       do {
        if (!($998)) {
         $$sum1$i$i$i$i$i204 = (($$sum$i$i$i$i$i203) + 1)|0;
         $999 = (($991) + ($$sum1$i$i$i$i$i204)|0);
         $1000 = (($transfer) + 20|0);
         $1001 = HEAP32[$1000>>2]|0;
         $1002 = ($999>>>0)>($1001>>>0);
         if ($1002) {
          break;
         }
         $1003 = HEAP8[$997>>0]|0;
         HEAP8[$981>>0] = $1003;
         $1004 = HEAP32[$985>>2]|0;
         $1005 = (($1004) + 1|0);
         HEAP32[$985>>2] = $1005;
         break L462;
        }
       } while(0);
       __ZN12CachedReader15UpdateReadCacheEPvj($985,$981,1);
      } else {
       $1006 = HEAP32[$converter$i$i212>>2]|0;
       $1007 = ($1006|0)==(0|0);
       if ($1007) {
        break;
       }
       (FUNCTION_TABLE_iii[$1006 & 4095]($981,$transfer)|0);
      }
     } while(0);
     __ZN14SafeBinaryRead11EndTransferEv($transfer);
    }
    $1008 = (($this) + 122|0);
    $1009 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,625032,$1,$converter$i$i212,0)|0);
    $1010 = ($1009|0)==(0);
    if (!($1010)) {
     $1011 = ($1009|0)>(0);
     L474: do {
      if ($1011) {
       $1012 = (($transfer) + 12|0);
       $1013 = (($transfer) + 80|0);
       $1014 = HEAP32[$1013>>2]|0;
       $1015 = (($1014) + 12|0);
       $1016 = HEAP32[$1015>>2]|0;
       $1017 = (($transfer) + 16|0);
       $1018 = HEAP32[$1017>>2]|0;
       $1019 = (($transfer) + 28|0);
       $1020 = HEAP32[$1019>>2]|0;
       $1021 = (($transfer) + 32|0);
       $1022 = HEAP32[$1021>>2]|0;
       $1023 = Math_imul($1022, $1020)|0;
       $$sum$i$i$i$i$i213 = (($1016) - ($1023))|0;
       $1024 = (($1018) + ($$sum$i$i$i$i$i213)|0);
       HEAP32[$1012>>2] = $1024;
       $1025 = ($$sum$i$i$i$i$i213|0)<(0);
       do {
        if (!($1025)) {
         $$sum1$i$i$i$i$i214 = (($$sum$i$i$i$i$i213) + 1)|0;
         $1026 = (($1018) + ($$sum1$i$i$i$i$i214)|0);
         $1027 = (($transfer) + 20|0);
         $1028 = HEAP32[$1027>>2]|0;
         $1029 = ($1026>>>0)>($1028>>>0);
         if ($1029) {
          break;
         }
         $1030 = HEAP8[$1024>>0]|0;
         HEAP8[$1008>>0] = $1030;
         $1031 = HEAP32[$1012>>2]|0;
         $1032 = (($1031) + 1|0);
         HEAP32[$1012>>2] = $1032;
         break L474;
        }
       } while(0);
       __ZN12CachedReader15UpdateReadCacheEPvj($1012,$1008,1);
      } else {
       $1033 = HEAP32[$converter$i$i212>>2]|0;
       $1034 = ($1033|0)==(0|0);
       if ($1034) {
        break;
       }
       (FUNCTION_TABLE_iii[$1033 & 4095]($1008,$transfer)|0);
      }
     } while(0);
     __ZN14SafeBinaryRead11EndTransferEv($transfer);
    }
    $1035 = (($this) + 123|0);
    $1036 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,625040,$1,$converter$i$i212,0)|0);
    $1037 = ($1036|0)==(0);
    if (!($1037)) {
     $1038 = ($1036|0)>(0);
     L486: do {
      if ($1038) {
       $1039 = (($transfer) + 12|0);
       $1040 = (($transfer) + 80|0);
       $1041 = HEAP32[$1040>>2]|0;
       $1042 = (($1041) + 12|0);
       $1043 = HEAP32[$1042>>2]|0;
       $1044 = (($transfer) + 16|0);
       $1045 = HEAP32[$1044>>2]|0;
       $1046 = (($transfer) + 28|0);
       $1047 = HEAP32[$1046>>2]|0;
       $1048 = (($transfer) + 32|0);
       $1049 = HEAP32[$1048>>2]|0;
       $1050 = Math_imul($1049, $1047)|0;
       $$sum$i$i$i$i$i175 = (($1043) - ($1050))|0;
       $1051 = (($1045) + ($$sum$i$i$i$i$i175)|0);
       HEAP32[$1039>>2] = $1051;
       $1052 = ($$sum$i$i$i$i$i175|0)<(0);
       do {
        if (!($1052)) {
         $$sum1$i$i$i$i$i176 = (($$sum$i$i$i$i$i175) + 1)|0;
         $1053 = (($1045) + ($$sum1$i$i$i$i$i176)|0);
         $1054 = (($transfer) + 20|0);
         $1055 = HEAP32[$1054>>2]|0;
         $1056 = ($1053>>>0)>($1055>>>0);
         if ($1056) {
          break;
         }
         $1057 = HEAP8[$1051>>0]|0;
         HEAP8[$1035>>0] = $1057;
         $1058 = HEAP32[$1039>>2]|0;
         $1059 = (($1058) + 1|0);
         HEAP32[$1039>>2] = $1059;
         break L486;
        }
       } while(0);
       __ZN12CachedReader15UpdateReadCacheEPvj($1039,$1035,1);
      } else {
       $1060 = HEAP32[$converter$i$i212>>2]|0;
       $1061 = ($1060|0)==(0|0);
       if ($1061) {
        break;
       }
       (FUNCTION_TABLE_iii[$1060 & 4095]($1035,$transfer)|0);
      }
     } while(0);
     __ZN14SafeBinaryRead11EndTransferEv($transfer);
    }
    $1062 = (($this) + 124|0);
    $1063 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,625048,$1,$converter$i$i212,0)|0);
    $1064 = ($1063|0)==(0);
    if (!($1064)) {
     $1065 = ($1063|0)>(0);
     L498: do {
      if ($1065) {
       $1066 = (($transfer) + 12|0);
       $1067 = (($transfer) + 80|0);
       $1068 = HEAP32[$1067>>2]|0;
       $1069 = (($1068) + 12|0);
       $1070 = HEAP32[$1069>>2]|0;
       $1071 = (($transfer) + 16|0);
       $1072 = HEAP32[$1071>>2]|0;
       $1073 = (($transfer) + 28|0);
       $1074 = HEAP32[$1073>>2]|0;
       $1075 = (($transfer) + 32|0);
       $1076 = HEAP32[$1075>>2]|0;
       $1077 = Math_imul($1076, $1074)|0;
       $$sum$i$i$i$i$i198 = (($1070) - ($1077))|0;
       $1078 = (($1072) + ($$sum$i$i$i$i$i198)|0);
       HEAP32[$1066>>2] = $1078;
       $1079 = ($$sum$i$i$i$i$i198|0)<(0);
       do {
        if (!($1079)) {
         $$sum1$i$i$i$i$i199 = (($$sum$i$i$i$i$i198) + 1)|0;
         $1080 = (($1072) + ($$sum1$i$i$i$i$i199)|0);
         $1081 = (($transfer) + 20|0);
         $1082 = HEAP32[$1081>>2]|0;
         $1083 = ($1080>>>0)>($1082>>>0);
         if ($1083) {
          break;
         }
         $1084 = HEAP8[$1078>>0]|0;
         HEAP8[$1062>>0] = $1084;
         $1085 = HEAP32[$1066>>2]|0;
         $1086 = (($1085) + 1|0);
         HEAP32[$1066>>2] = $1086;
         break L498;
        }
       } while(0);
       __ZN12CachedReader15UpdateReadCacheEPvj($1066,$1062,1);
      } else {
       $1087 = HEAP32[$converter$i$i212>>2]|0;
       $1088 = ($1087|0)==(0|0);
       if ($1088) {
        break;
       }
       (FUNCTION_TABLE_iii[$1087 & 4095]($1062,$transfer)|0);
      }
     } while(0);
     __ZN14SafeBinaryRead11EndTransferEv($transfer);
    }
    $1089 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,625016,$1,$converter$i$i212,0)|0);
    $1090 = ($1089|0)==(0);
    if ($1090) {
     break;
    }
    $1091 = ($1089|0)>(0);
    L509: do {
     if ($1091) {
      $1092 = (($transfer) + 12|0);
      $1093 = (($transfer) + 80|0);
      $1094 = HEAP32[$1093>>2]|0;
      $1095 = (($1094) + 12|0);
      $1096 = HEAP32[$1095>>2]|0;
      $1097 = (($transfer) + 16|0);
      $1098 = HEAP32[$1097>>2]|0;
      $1099 = (($transfer) + 28|0);
      $1100 = HEAP32[$1099>>2]|0;
      $1101 = (($transfer) + 32|0);
      $1102 = HEAP32[$1101>>2]|0;
      $1103 = Math_imul($1102, $1100)|0;
      $$sum$i$i$i$i$i208 = (($1096) - ($1103))|0;
      $1104 = (($1098) + ($$sum$i$i$i$i$i208)|0);
      HEAP32[$1092>>2] = $1104;
      $1105 = ($$sum$i$i$i$i$i208|0)<(0);
      do {
       if (!($1105)) {
        $$sum1$i$i$i$i$i209 = (($$sum$i$i$i$i$i208) + 1)|0;
        $1106 = (($1098) + ($$sum1$i$i$i$i$i209)|0);
        $1107 = (($transfer) + 20|0);
        $1108 = HEAP32[$1107>>2]|0;
        $1109 = ($1106>>>0)>($1108>>>0);
        if ($1109) {
         break;
        }
        $1110 = HEAP8[$1104>>0]|0;
        HEAP8[$977>>0] = $1110;
        $1111 = HEAP32[$1092>>2]|0;
        $1112 = (($1111) + 1|0);
        HEAP32[$1092>>2] = $1112;
        break L509;
       }
      } while(0);
      __ZN12CachedReader15UpdateReadCacheEPvj($1092,$977,1);
     } else {
      $1113 = HEAP32[$converter$i$i212>>2]|0;
      $1114 = ($1113|0)==(0|0);
      if ($1114) {
       break;
      }
      (FUNCTION_TABLE_iii[$1113 & 4095]($977,$transfer)|0);
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   } else {
    $1115 = HEAP32[$converter$i$i192>>2]|0;
    $1116 = ($1115|0)==(0|0);
    if ($1116) {
     break;
    }
    (FUNCTION_TABLE_iii[$1115 & 4095]($977,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $1117 = (($this) + 244|0);
 $1118 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624816,$38,$converter$i$i192,0)|0);
 $1119 = ($1118|0)==(0);
 if (!($1119)) {
  $1120 = ($1118|0)>(0);
  do {
   if ($1120) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1117,0);
   } else {
    $1121 = HEAP32[$converter$i$i192>>2]|0;
    $1122 = ($1121|0)==(0|0);
    if ($1122) {
     break;
    }
    (FUNCTION_TABLE_iii[$1121 & 4095]($1117,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $1123 = (($this) + 268|0);
 $1124 = HEAP32[580760>>2]|0;
 $1125 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624840,$1124,$converter$i$i192,1)|0);
 $1126 = ($1125|0)==(0);
 if (!($1126)) {
  $1127 = ($1125|0)>(0);
  do {
   if ($1127) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$1123,0);
   } else {
    $1128 = HEAP32[$converter$i$i192>>2]|0;
    $1129 = ($1128|0)==(0|0);
    if ($1129) {
     break;
    }
    (FUNCTION_TABLE_iii[$1128 & 4095]($1123,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $1130 = (($this) + 284|0);
 $1131 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624856,$1,$converter$i$i192,0)|0);
 $1132 = ($1131|0)==(0);
 if (!($1132)) {
  $1133 = ($1131|0)>(0);
  L540: do {
   if ($1133) {
    $1134 = (($transfer) + 12|0);
    $1135 = (($transfer) + 80|0);
    $1136 = HEAP32[$1135>>2]|0;
    $1137 = (($1136) + 12|0);
    $1138 = HEAP32[$1137>>2]|0;
    $1139 = (($transfer) + 16|0);
    $1140 = HEAP32[$1139>>2]|0;
    $1141 = (($transfer) + 28|0);
    $1142 = HEAP32[$1141>>2]|0;
    $1143 = (($transfer) + 32|0);
    $1144 = HEAP32[$1143>>2]|0;
    $1145 = Math_imul($1144, $1142)|0;
    $$sum$i$i$i$i$i183 = (($1138) - ($1145))|0;
    $1146 = (($1140) + ($$sum$i$i$i$i$i183)|0);
    HEAP32[$1134>>2] = $1146;
    $1147 = ($$sum$i$i$i$i$i183|0)<(0);
    do {
     if (!($1147)) {
      $$sum1$i$i$i$i$i184 = (($$sum$i$i$i$i$i183) + 1)|0;
      $1148 = (($1140) + ($$sum1$i$i$i$i$i184)|0);
      $1149 = (($transfer) + 20|0);
      $1150 = HEAP32[$1149>>2]|0;
      $1151 = ($1148>>>0)>($1150>>>0);
      if ($1151) {
       break;
      }
      $1152 = HEAP8[$1146>>0]|0;
      HEAP8[$1130>>0] = $1152;
      $1153 = HEAP32[$1134>>2]|0;
      $1154 = (($1153) + 1|0);
      HEAP32[$1134>>2] = $1154;
      break L540;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($1134,$1130,1);
   } else {
    $1155 = HEAP32[$converter$i$i192>>2]|0;
    $1156 = ($1155|0)==(0|0);
    if ($1156) {
     break;
    }
    (FUNCTION_TABLE_iii[$1155 & 4095]($1130,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $1157 = (($this) + 285|0);
 $1158 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624896,$1,$converter$i$i192,0)|0);
 $1159 = ($1158|0)==(0);
 if (!($1159)) {
  $1160 = ($1158|0)>(0);
  L552: do {
   if ($1160) {
    $1161 = (($transfer) + 12|0);
    $1162 = (($transfer) + 80|0);
    $1163 = HEAP32[$1162>>2]|0;
    $1164 = (($1163) + 12|0);
    $1165 = HEAP32[$1164>>2]|0;
    $1166 = (($transfer) + 16|0);
    $1167 = HEAP32[$1166>>2]|0;
    $1168 = (($transfer) + 28|0);
    $1169 = HEAP32[$1168>>2]|0;
    $1170 = (($transfer) + 32|0);
    $1171 = HEAP32[$1170>>2]|0;
    $1172 = Math_imul($1171, $1169)|0;
    $$sum$i$i$i$i$i188 = (($1165) - ($1172))|0;
    $1173 = (($1167) + ($$sum$i$i$i$i$i188)|0);
    HEAP32[$1161>>2] = $1173;
    $1174 = ($$sum$i$i$i$i$i188|0)<(0);
    do {
     if (!($1174)) {
      $$sum1$i$i$i$i$i189 = (($$sum$i$i$i$i$i188) + 1)|0;
      $1175 = (($1167) + ($$sum1$i$i$i$i$i189)|0);
      $1176 = (($transfer) + 20|0);
      $1177 = HEAP32[$1176>>2]|0;
      $1178 = ($1175>>>0)>($1177>>>0);
      if ($1178) {
       break;
      }
      $1179 = HEAP8[$1173>>0]|0;
      HEAP8[$1157>>0] = $1179;
      $1180 = HEAP32[$1161>>2]|0;
      $1181 = (($1180) + 1|0);
      HEAP32[$1161>>2] = $1181;
      break L552;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($1161,$1157,1);
   } else {
    $1182 = HEAP32[$converter$i$i192>>2]|0;
    $1183 = ($1182|0)==(0|0);
    if ($1183) {
     break;
    }
    (FUNCTION_TABLE_iii[$1182 & 4095]($1157,$transfer)|0);
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $1184 = (($this) + 286|0);
 $1185 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,624936,$1,$converter$i$i192,0)|0);
 $1186 = ($1185|0)==(0);
 if ($1186) {
  STACKTOP = sp;return;
 }
 $1187 = ($1185|0)>(0);
 L565: do {
  if ($1187) {
   $1188 = (($transfer) + 12|0);
   $1189 = (($transfer) + 80|0);
   $1190 = HEAP32[$1189>>2]|0;
   $1191 = (($1190) + 12|0);
   $1192 = HEAP32[$1191>>2]|0;
   $1193 = (($transfer) + 16|0);
   $1194 = HEAP32[$1193>>2]|0;
   $1195 = (($transfer) + 28|0);
   $1196 = HEAP32[$1195>>2]|0;
   $1197 = (($transfer) + 32|0);
   $1198 = HEAP32[$1197>>2]|0;
   $1199 = Math_imul($1198, $1196)|0;
   $$sum$i$i$i$i$i193 = (($1192) - ($1199))|0;
   $1200 = (($1194) + ($$sum$i$i$i$i$i193)|0);
   HEAP32[$1188>>2] = $1200;
   $1201 = ($$sum$i$i$i$i$i193|0)<(0);
   do {
    if (!($1201)) {
     $$sum1$i$i$i$i$i194 = (($$sum$i$i$i$i$i193) + 1)|0;
     $1202 = (($1194) + ($$sum1$i$i$i$i$i194)|0);
     $1203 = (($transfer) + 20|0);
     $1204 = HEAP32[$1203>>2]|0;
     $1205 = ($1202>>>0)>($1204>>>0);
     if ($1205) {
      break;
     }
     $1206 = HEAP8[$1200>>0]|0;
     HEAP8[$1184>>0] = $1206;
     $1207 = HEAP32[$1188>>2]|0;
     $1208 = (($1207) + 1|0);
     HEAP32[$1188>>2] = $1208;
     break L565;
    }
   } while(0);
   __ZN12CachedReader15UpdateReadCacheEPvj($1188,$1184,1);
  } else {
   $1209 = HEAP32[$converter$i$i192>>2]|0;
   $1210 = ($1209|0)==(0|0);
   if ($1210) {
    break;
   }
   (FUNCTION_TABLE_iii[$1209 & 4095]($1184,$transfer)|0);
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettings8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $localIdentifier$i$i$i$i$i$i = 0;
 var $p$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 $size$i$i$i = sp + 20|0;
 $p$i$i = sp + 16|0;
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,6);
 $0 = (($this) + 72|0);
 $1 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623384,$1,$0,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $8 = (($this) + 76|0);
 $9 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623400,$9,$8,0);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($this) + 80|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623432,$9,$14,0);
 $15 = HEAP32[$2>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$5>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 84|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623448,$9,$19,0);
 $20 = HEAP32[$2>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$5>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = HEAP32[$19>>2]|0;
 $25 = ($24|0)==(0);
 if ($25) {
  HEAP32[$19>>2] = -1;
 }
 $26 = (($this) + 88|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623472,$9,$26,0);
 $27 = HEAP32[$2>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$5>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $31 = (($this) + 92|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623496,$9,$31,0);
 $32 = HEAP32[$2>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$5>>2]|0;
 $35 = ((($33) + (($34*24)|0)|0) + 12|0);
 HEAP32[$35>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $36 = HEAP32[$31>>2]|0;
 if ((($36|0) == 2)) {
  HEAP32[$31>>2] = 0;
 } else if ((($36|0) == 1)) {
  HEAP32[$31>>2] = 6;
 }
 $37 = (($this) + 96|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623520,$9,$37,0);
 $38 = HEAP32[$2>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$5>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $42 = (($this) + 24|0);
 $43 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623544,$43,$42,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,625072,625072,$localIdentifier$i$i$i$i$i$i,1);
 $44 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624976,$44,$size$i$i$i,0);
 $45 = HEAP32[$2>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$5>>2]|0;
 $48 = ((($46) + (($47*24)|0)|0) + 12|0);
 HEAP32[$48>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $49 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623560,$43,$49,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,625072,625072,$localIdentifier$i$i$i$i$i$i,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624976,$44,$size$i$i$i,0);
 $50 = HEAP32[$2>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = HEAP32[$5>>2]|0;
 $53 = ((($51) + (($52*24)|0)|0) + 12|0);
 HEAP32[$53>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $54 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623576,625096,$54,0);
 $55 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $56 = $55;
 $57 = $56;
 HEAP32[$57>>2] = 0;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624984,$9,$54,1);
 $60 = HEAP32[$2>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$5>>2]|0;
 $63 = ((($61) + (($62*24)|0)|0) + 12|0);
 HEAP32[$63>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $64 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625000,$64,$55,1);
 $65 = HEAP32[$2>>2]|0;
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$5>>2]|0;
 $68 = ((($66) + (($67*24)|0)|0) + 12|0);
 HEAP32[$68>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $69 = (($this) + 64|0);
 $70 = HEAP32[580768>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623592,$70,$69,0);
 $71 = (($transfer) + 16|0);
 $72 = (__ZNK16TypeTreeIterator7GetNodeEv($71)|0);
 $73 = (($72) + 20|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $74 | 2097152;
 $76 = HEAP32[$2>>2]|0;
 $77 = HEAP32[$76>>2]|0;
 $78 = HEAP32[$5>>2]|0;
 $79 = ((($77) + (($78*24)|0)|0) + 20|0);
 HEAP32[$79>>2] = $75;
 $80 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625056,$80,$69,0);
 $81 = HEAP32[$2>>2]|0;
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$5>>2]|0;
 $84 = ((($82) + (($83*24)|0)|0) + 12|0);
 HEAP32[$84>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $85 = (($this) + 68|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625064,$80,$85,0);
 $86 = HEAP32[$2>>2]|0;
 $87 = HEAP32[$86>>2]|0;
 $88 = HEAP32[$5>>2]|0;
 $89 = ((($87) + (($88*24)|0)|0) + 12|0);
 HEAP32[$89>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $90 = (($this) + 100|0);
 $91 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623608,$91,$90,0);
 $92 = HEAP32[$2>>2]|0;
 $93 = HEAP32[$92>>2]|0;
 $94 = HEAP32[$5>>2]|0;
 $95 = ((($93) + (($94*24)|0)|0) + 12|0);
 HEAP32[$95>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $96 = (($this) + 104|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623632,$91,$96,0);
 $97 = HEAP32[$2>>2]|0;
 $98 = HEAP32[$97>>2]|0;
 $99 = HEAP32[$5>>2]|0;
 $100 = ((($98) + (($99*24)|0)|0) + 12|0);
 HEAP32[$100>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $101 = (($this) + 108|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623248,$91,$101,0);
 $102 = HEAP32[$2>>2]|0;
 $103 = HEAP32[$102>>2]|0;
 $104 = HEAP32[$5>>2]|0;
 $105 = ((($103) + (($104*24)|0)|0) + 12|0);
 HEAP32[$105>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $106 = (($this) + 112|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623296,$91,$106,0);
 $107 = HEAP32[$2>>2]|0;
 $108 = HEAP32[$107>>2]|0;
 $109 = HEAP32[$5>>2]|0;
 $110 = ((($108) + (($109*24)|0)|0) + 12|0);
 HEAP32[$110>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $111 = (($this) + 128|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623656,$91,$111,0);
 $112 = HEAP32[$2>>2]|0;
 $113 = HEAP32[$112>>2]|0;
 $114 = HEAP32[$5>>2]|0;
 $115 = ((($113) + (($114*24)|0)|0) + 12|0);
 HEAP32[$115>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $116 = (($this) + 132|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623672,$91,$116,0);
 $117 = HEAP32[$2>>2]|0;
 $118 = HEAP32[$117>>2]|0;
 $119 = HEAP32[$5>>2]|0;
 $120 = ((($118) + (($119*24)|0)|0) + 12|0);
 HEAP32[$120>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $121 = (($this) + 136|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623696,$91,$121,0);
 $122 = HEAP32[$2>>2]|0;
 $123 = HEAP32[$122>>2]|0;
 $124 = HEAP32[$5>>2]|0;
 $125 = ((($123) + (($124*24)|0)|0) + 12|0);
 HEAP32[$125>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $126 = (($this) + 140|0);
 $127 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623720,$127,$126,0);
 $128 = HEAP32[$2>>2]|0;
 $129 = HEAP32[$128>>2]|0;
 $130 = HEAP32[$5>>2]|0;
 $131 = ((($129) + (($130*24)|0)|0) + 12|0);
 HEAP32[$131>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $132 = (($this) + 141|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623736,$127,$132,0);
 $133 = HEAP32[$2>>2]|0;
 $134 = HEAP32[$133>>2]|0;
 $135 = HEAP32[$5>>2]|0;
 $136 = ((($134) + (($135*24)|0)|0) + 12|0);
 HEAP32[$136>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $137 = (($this) + 142|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623760,$127,$137,0);
 $138 = HEAP32[$2>>2]|0;
 $139 = HEAP32[$138>>2]|0;
 $140 = HEAP32[$5>>2]|0;
 $141 = ((($139) + (($140*24)|0)|0) + 12|0);
 HEAP32[$141>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $142 = (($this) + 143|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623776,$127,$142,0);
 $143 = HEAP32[$2>>2]|0;
 $144 = HEAP32[$143>>2]|0;
 $145 = HEAP32[$5>>2]|0;
 $146 = ((($144) + (($145*24)|0)|0) + 12|0);
 HEAP32[$146>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $147 = (($this) + 148|0);
 $148 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623800,$148,$147,0);
 $149 = HEAP32[$2>>2]|0;
 $150 = HEAP32[$149>>2]|0;
 $151 = HEAP32[$5>>2]|0;
 $152 = ((($150) + (($151*24)|0)|0) + 12|0);
 HEAP32[$152>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $153 = (($this) + 144|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623840,$148,$153,0);
 $154 = HEAP32[$2>>2]|0;
 $155 = HEAP32[$154>>2]|0;
 $156 = HEAP32[$5>>2]|0;
 $157 = ((($155) + (($156*24)|0)|0) + 12|0);
 HEAP32[$157>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $158 = (($this) + 152|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623880,$148,$158,0);
 $159 = HEAP32[$2>>2]|0;
 $160 = HEAP32[$159>>2]|0;
 $161 = HEAP32[$5>>2]|0;
 $162 = ((($160) + (($161*24)|0)|0) + 12|0);
 HEAP32[$162>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $163 = (($this) + 116|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623912,$148,$163,0);
 $164 = HEAP32[$2>>2]|0;
 $165 = HEAP32[$164>>2]|0;
 $166 = HEAP32[$5>>2]|0;
 $167 = ((($165) + (($166*24)|0)|0) + 12|0);
 HEAP32[$167>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $168 = (($this) + 156|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623936,$127,$168,0);
 $169 = HEAP32[$2>>2]|0;
 $170 = HEAP32[$169>>2]|0;
 $171 = HEAP32[$5>>2]|0;
 $172 = ((($170) + (($171*24)|0)|0) + 12|0);
 HEAP32[$172>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $173 = (($this) + 157|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623968,$127,$173,0);
 $174 = HEAP32[$2>>2]|0;
 $175 = HEAP32[$174>>2]|0;
 $176 = HEAP32[$5>>2]|0;
 $177 = ((($175) + (($176*24)|0)|0) + 12|0);
 HEAP32[$177>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $178 = (($this) + 158|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624008,$127,$178,0);
 $179 = HEAP32[$2>>2]|0;
 $180 = HEAP32[$179>>2]|0;
 $181 = HEAP32[$5>>2]|0;
 $182 = ((($180) + (($181*24)|0)|0) + 12|0);
 HEAP32[$182>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $183 = (($this) + 159|0);
 $184 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624048,$184,$183,0);
 $185 = HEAP32[$2>>2]|0;
 $186 = HEAP32[$185>>2]|0;
 $187 = HEAP32[$5>>2]|0;
 $188 = ((($186) + (($187*24)|0)|0) + 12|0);
 HEAP32[$188>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $189 = (($this) + 160|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624088,$184,$189,0);
 $190 = HEAP32[$2>>2]|0;
 $191 = HEAP32[$190>>2]|0;
 $192 = HEAP32[$5>>2]|0;
 $193 = ((($191) + (($192*24)|0)|0) + 12|0);
 HEAP32[$193>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $194 = (($this) + 161|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624112,$184,$194,0);
 $195 = HEAP32[$2>>2]|0;
 $196 = HEAP32[$195>>2]|0;
 $197 = HEAP32[$5>>2]|0;
 $198 = ((($196) + (($197*24)|0)|0) + 12|0);
 HEAP32[$198>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $199 = (($this) + 162|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624136,$184,$199,0);
 $200 = HEAP32[$2>>2]|0;
 $201 = HEAP32[$200>>2]|0;
 $202 = HEAP32[$5>>2]|0;
 $203 = ((($201) + (($202*24)|0)|0) + 12|0);
 HEAP32[$203>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $204 = (($this) + 163|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624168,$184,$204,0);
 $205 = HEAP32[$2>>2]|0;
 $206 = HEAP32[$205>>2]|0;
 $207 = HEAP32[$5>>2]|0;
 $208 = ((($206) + (($207*24)|0)|0) + 12|0);
 HEAP32[$208>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $209 = (($this) + 164|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624192,$184,$209,0);
 $210 = HEAP32[$2>>2]|0;
 $211 = HEAP32[$210>>2]|0;
 $212 = HEAP32[$5>>2]|0;
 $213 = ((($211) + (($212*24)|0)|0) + 12|0);
 HEAP32[$213>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $214 = (($this) + 165|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624224,$184,$214,0);
 $215 = HEAP32[$2>>2]|0;
 $216 = HEAP32[$215>>2]|0;
 $217 = HEAP32[$5>>2]|0;
 $218 = ((($216) + (($217*24)|0)|0) + 12|0);
 HEAP32[$218>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $219 = (($this) + 166|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624240,$184,$219,0);
 $220 = HEAP32[$2>>2]|0;
 $221 = HEAP32[$220>>2]|0;
 $222 = HEAP32[$5>>2]|0;
 $223 = ((($221) + (($222*24)|0)|0) + 12|0);
 HEAP32[$223>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $224 = (($this) + 167|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624264,$184,$224,0);
 $225 = HEAP32[$2>>2]|0;
 $226 = HEAP32[$225>>2]|0;
 $227 = HEAP32[$5>>2]|0;
 $228 = ((($226) + (($227*24)|0)|0) + 12|0);
 HEAP32[$228>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $229 = (($this) + 168|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624288,$184,$229,0);
 $230 = HEAP32[$2>>2]|0;
 $231 = HEAP32[$230>>2]|0;
 $232 = HEAP32[$5>>2]|0;
 $233 = ((($231) + (($232*24)|0)|0) + 12|0);
 HEAP32[$233>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $234 = (($this) + 169|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,623344,$184,$234,0);
 $235 = HEAP32[$2>>2]|0;
 $236 = HEAP32[$235>>2]|0;
 $237 = HEAP32[$5>>2]|0;
 $238 = ((($236) + (($237*24)|0)|0) + 12|0);
 HEAP32[$238>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $239 = (($this) + 170|0);
 $240 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624320,$240,$239,0);
 $241 = HEAP32[$2>>2]|0;
 $242 = HEAP32[$241>>2]|0;
 $243 = HEAP32[$5>>2]|0;
 $244 = ((($242) + (($243*24)|0)|0) + 12|0);
 HEAP32[$244>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $245 = (($this) + 171|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624336,$240,$245,0);
 $246 = HEAP32[$2>>2]|0;
 $247 = HEAP32[$246>>2]|0;
 $248 = HEAP32[$5>>2]|0;
 $249 = ((($247) + (($248*24)|0)|0) + 12|0);
 HEAP32[$249>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $250 = (($this) + 180|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624360,$240,$250,0);
 $251 = HEAP32[$2>>2]|0;
 $252 = HEAP32[$251>>2]|0;
 $253 = HEAP32[$5>>2]|0;
 $254 = ((($252) + (($253*24)|0)|0) + 12|0);
 HEAP32[$254>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $255 = (($this) + 181|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624384,$240,$255,0);
 $256 = HEAP32[$2>>2]|0;
 $257 = HEAP32[$256>>2]|0;
 $258 = HEAP32[$5>>2]|0;
 $259 = ((($257) + (($258*24)|0)|0) + 12|0);
 HEAP32[$259>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $260 = (($this) + 172|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624400,$240,$260,0);
 $261 = HEAP32[$2>>2]|0;
 $262 = HEAP32[$261>>2]|0;
 $263 = HEAP32[$5>>2]|0;
 $264 = ((($262) + (($263*24)|0)|0) + 12|0);
 HEAP32[$264>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $265 = (($this) + 182|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624432,$240,$265,0);
 $266 = HEAP32[$2>>2]|0;
 $267 = HEAP32[$266>>2]|0;
 $268 = HEAP32[$5>>2]|0;
 $269 = ((($267) + (($268*24)|0)|0) + 12|0);
 HEAP32[$269>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $270 = (($this) + 183|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624448,$240,$270,0);
 $271 = HEAP32[$2>>2]|0;
 $272 = HEAP32[$271>>2]|0;
 $273 = HEAP32[$5>>2]|0;
 $274 = ((($272) + (($273*24)|0)|0) + 12|0);
 HEAP32[$274>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $275 = (($this) + 184|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624472,$240,$275,0);
 $276 = HEAP32[$2>>2]|0;
 $277 = HEAP32[$276>>2]|0;
 $278 = HEAP32[$5>>2]|0;
 $279 = ((($277) + (($278*24)|0)|0) + 12|0);
 HEAP32[$279>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $280 = (($this) + 185|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624496,$240,$280,0);
 $281 = HEAP32[$2>>2]|0;
 $282 = HEAP32[$281>>2]|0;
 $283 = HEAP32[$5>>2]|0;
 $284 = ((($282) + (($283*24)|0)|0) + 12|0);
 HEAP32[$284>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $285 = (($this) + 186|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624520,$240,$285,0);
 $286 = HEAP32[$2>>2]|0;
 $287 = HEAP32[$286>>2]|0;
 $288 = HEAP32[$5>>2]|0;
 $289 = ((($287) + (($288*24)|0)|0) + 12|0);
 HEAP32[$289>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $290 = (($this) + 192|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624552,$240,$290,0);
 $291 = HEAP32[$2>>2]|0;
 $292 = HEAP32[$291>>2]|0;
 $293 = HEAP32[$5>>2]|0;
 $294 = ((($292) + (($293*24)|0)|0) + 12|0);
 HEAP32[$294>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $295 = (($this) + 173|0);
 $296 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624576,$296,$295,0);
 $297 = HEAP32[$2>>2]|0;
 $298 = HEAP32[$297>>2]|0;
 $299 = HEAP32[$5>>2]|0;
 $300 = ((($298) + (($299*24)|0)|0) + 12|0);
 HEAP32[$300>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $301 = (($this) + 176|0);
 $302 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624600,$302,$301,0);
 $303 = HEAP32[$2>>2]|0;
 $304 = HEAP32[$303>>2]|0;
 $305 = HEAP32[$5>>2]|0;
 $306 = ((($304) + (($305*24)|0)|0) + 12|0);
 HEAP32[$306>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $307 = (($this) + 188|0);
 $308 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624624,$308,$307,0);
 $309 = HEAP32[$2>>2]|0;
 $310 = HEAP32[$309>>2]|0;
 $311 = HEAP32[$5>>2]|0;
 $312 = ((($310) + (($311*24)|0)|0) + 12|0);
 HEAP32[$312>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $313 = (($this) + 193|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624640,$296,$313,0);
 $314 = HEAP32[$2>>2]|0;
 $315 = HEAP32[$314>>2]|0;
 $316 = HEAP32[$5>>2]|0;
 $317 = ((($315) + (($316*24)|0)|0) + 12|0);
 HEAP32[$317>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $318 = (($this) + 194|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624672,$296,$318,0);
 $319 = HEAP32[$2>>2]|0;
 $320 = HEAP32[$319>>2]|0;
 $321 = HEAP32[$5>>2]|0;
 $322 = ((($320) + (($321*24)|0)|0) + 12|0);
 HEAP32[$322>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $323 = (($this) + 196|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624688,$302,$323,0);
 $324 = HEAP32[$2>>2]|0;
 $325 = HEAP32[$324>>2]|0;
 $326 = HEAP32[$5>>2]|0;
 $327 = ((($325) + (($326*24)|0)|0) + 12|0);
 HEAP32[$327>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $328 = (($this) + 204|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624712,625096,$328,0);
 $329 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $330 = $329;
 $331 = $330;
 HEAP32[$331>>2] = 0;
 $332 = (($330) + 4)|0;
 $333 = $332;
 HEAP32[$333>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624984,$302,$328,1);
 $334 = HEAP32[$2>>2]|0;
 $335 = HEAP32[$334>>2]|0;
 $336 = HEAP32[$5>>2]|0;
 $337 = ((($335) + (($336*24)|0)|0) + 12|0);
 HEAP32[$337>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $338 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625000,$338,$329,1);
 $339 = HEAP32[$2>>2]|0;
 $340 = HEAP32[$339>>2]|0;
 $341 = HEAP32[$5>>2]|0;
 $342 = ((($340) + (($341*24)|0)|0) + 12|0);
 HEAP32[$342>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $343 = (($this) + 208|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624728,$302,$343,0);
 $344 = HEAP32[$2>>2]|0;
 $345 = HEAP32[$344>>2]|0;
 $346 = HEAP32[$5>>2]|0;
 $347 = ((($345) + (($346*24)|0)|0) + 12|0);
 HEAP32[$347>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $348 = (($this) + 212|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624760,$302,$348,0);
 $349 = HEAP32[$2>>2]|0;
 $350 = HEAP32[$349>>2]|0;
 $351 = HEAP32[$5>>2]|0;
 $352 = ((($350) + (($351*24)|0)|0) + 12|0);
 HEAP32[$352>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $353 = (($this) + 216|0);
 $354 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624776,$354,$353,0);
 $355 = HEAP32[$2>>2]|0;
 $356 = HEAP32[$355>>2]|0;
 $357 = HEAP32[$5>>2]|0;
 $358 = ((($356) + (($357*24)|0)|0) + 12|0);
 HEAP32[$358>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $359 = (($this) + 120|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624792,625080,$359,0);
 __ZN12AspectRatios8TransferI13ProxyTransferEEvRT_($359,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $360 = (($this) + 244|0);
 $361 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624816,$361,$360,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,625072,625072,$localIdentifier$i$i$i$i$i$i,1);
 $362 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624976,$362,$size$i$i$i,0);
 $363 = HEAP32[$2>>2]|0;
 $364 = HEAP32[$363>>2]|0;
 $365 = HEAP32[$5>>2]|0;
 $366 = ((($364) + (($365*24)|0)|0) + 12|0);
 HEAP32[$366>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $367 = (($this) + 268|0);
 $368 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624840,$368,$367,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,625072,625072,$size$i$i$i,0);
 $369 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624976,$369,$p$i$i,0);
 $370 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $371 = $370;
 $372 = $371;
 HEAP32[$372>>2] = 0;
 $373 = (($371) + 4)|0;
 $374 = $373;
 HEAP32[$374>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $375 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624984,$375,$p$i$i,1);
 $376 = HEAP32[$2>>2]|0;
 $377 = HEAP32[$376>>2]|0;
 $378 = HEAP32[$5>>2]|0;
 $379 = ((($377) + (($378*24)|0)|0) + 12|0);
 HEAP32[$379>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625000,$338,$370,1);
 $380 = HEAP32[$2>>2]|0;
 $381 = HEAP32[$380>>2]|0;
 $382 = HEAP32[$5>>2]|0;
 $383 = ((($381) + (($382*24)|0)|0) + 12|0);
 HEAP32[$383>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $384 = (($this) + 284|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624856,$354,$384,0);
 $385 = HEAP32[$2>>2]|0;
 $386 = HEAP32[$385>>2]|0;
 $387 = HEAP32[$5>>2]|0;
 $388 = ((($386) + (($387*24)|0)|0) + 12|0);
 HEAP32[$388>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $389 = (($this) + 285|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624896,$354,$389,0);
 $390 = HEAP32[$2>>2]|0;
 $391 = HEAP32[$390>>2]|0;
 $392 = HEAP32[$5>>2]|0;
 $393 = ((($391) + (($392*24)|0)|0) + 12|0);
 HEAP32[$393>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $394 = (($this) + 286|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,624936,$354,$394,0);
 $395 = HEAP32[$2>>2]|0;
 $396 = HEAP32[$395>>2]|0;
 $397 = HEAP32[$5>>2]|0;
 $398 = ((($396) + (($397*24)|0)|0) + 12|0);
 HEAP32[$398>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12AspectRatios8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580544>>2]|0;
 $1 = (($transfer) + 12|0);
 $2 = (($transfer) + 20|0);
 $3 = (($this) + 1|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625024,$0,$3,0);
 $4 = HEAP32[$1>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$2>>2]|0;
 $7 = ((($5) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 2|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625032,$0,$8,0);
 $9 = HEAP32[$1>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 3|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625040,$0,$13,0);
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$2>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625048,$0,$18,0);
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$2>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,625016,$0,$this,0);
 $23 = HEAP32[$1>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$2>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14PlayerSettingsD2Ev($this) {
 $this = $this|0;
 var $$byval_copy31 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i22$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy31 = sp + 32|0;
 $0 = sp + 28|0;
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 12|0;
 HEAP32[$this>>2] = ((623072 + 8|0));
 $8 = (($this) + 280|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(-1);
 do {
  if ($10) {
   $11 = (($this) + 268|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 272|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$7>>2] = $14;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$7+0>>2]|0;
   invoke_vii(2591,($12|0),($$byval_copy31|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    HEAP32[$11>>2] = 0;
    break;
   }
   $111 = ___cxa_find_matching_catch()|0;
   $112 = tempRet0;
   $113 = (($this) + 256|0);
   $114 = HEAP8[$113>>0]|0;
   $115 = $114 & 1;
   $116 = ($115<<24>>24)==(0);
   if (!($116)) {
    $117 = (($this) + 264|0);
    $118 = HEAP32[$117>>2]|0;
    HEAP32[$6>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_vii(2591,($118|0),($$byval_copy31|0));
    $119 = __THREW__; __THREW__ = 0;
    $120 = $119&1;
    if ($120) {
     $121 = ___cxa_find_matching_catch()|0;
     $122 = tempRet0;
     ___cxa_call_unexpected(($121|0));
     // unreachable;
    }
   }
   $123 = (($this) + 244|0);
   $124 = HEAP8[$123>>0]|0;
   $125 = $124 & 1;
   $126 = ($125<<24>>24)==(0);
   if (!($126)) {
    $127 = (($this) + 252|0);
    $128 = HEAP32[$127>>2]|0;
    HEAP32[$5>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($128|0),($$byval_copy31|0));
    $129 = __THREW__; __THREW__ = 0;
    $130 = $129&1;
    if ($130) {
     $131 = ___cxa_find_matching_catch()|0;
     $132 = tempRet0;
     ___cxa_call_unexpected(($131|0));
     // unreachable;
    }
   }
   $133 = (($this) + 232|0);
   $134 = HEAP8[$133>>0]|0;
   $135 = $134 & 1;
   $136 = ($135<<24>>24)==(0);
   if (!($136)) {
    $137 = (($this) + 240|0);
    $138 = HEAP32[$137>>2]|0;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($138|0),($$byval_copy31|0));
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     $141 = ___cxa_find_matching_catch()|0;
     $142 = tempRet0;
     ___cxa_call_unexpected(($141|0));
     // unreachable;
    }
   }
   $143 = (($this) + 220|0);
   $144 = HEAP8[$143>>0]|0;
   $145 = $144 & 1;
   $146 = ($145<<24>>24)==(0);
   if (!($146)) {
    $147 = (($this) + 228|0);
    $148 = HEAP32[$147>>2]|0;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($148|0),($$byval_copy31|0));
    $149 = __THREW__; __THREW__ = 0;
    $150 = $149&1;
    if ($150) {
     $151 = ___cxa_find_matching_catch()|0;
     $152 = tempRet0;
     ___cxa_call_unexpected(($151|0));
     // unreachable;
    }
   }
   $153 = (($this) + 48|0);
   $154 = HEAP8[$153>>0]|0;
   $155 = $154 & 1;
   $156 = ($155<<24>>24)==(0);
   if (!($156)) {
    $157 = (($this) + 56|0);
    $158 = HEAP32[$157>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($158|0),($$byval_copy31|0));
    $159 = __THREW__; __THREW__ = 0;
    $160 = $159&1;
    if ($160) {
     $161 = ___cxa_find_matching_catch()|0;
     $162 = tempRet0;
     ___cxa_call_unexpected(($161|0));
     // unreachable;
    }
   }
   $163 = (($this) + 36|0);
   $164 = HEAP8[$163>>0]|0;
   $165 = $164 & 1;
   $166 = ($165<<24>>24)==(0);
   if (!($166)) {
    $167 = (($this) + 44|0);
    $168 = HEAP32[$167>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($168|0),($$byval_copy31|0));
    $169 = __THREW__; __THREW__ = 0;
    $170 = $169&1;
    if ($170) {
     $171 = ___cxa_find_matching_catch()|0;
     $172 = tempRet0;
     ___cxa_call_unexpected(($171|0));
     // unreachable;
    }
   }
   $173 = (($this) + 24|0);
   $174 = HEAP8[$173>>0]|0;
   $175 = $174 & 1;
   $176 = ($175<<24>>24)==(0);
   if (!($176)) {
    $177 = (($this) + 32|0);
    $178 = HEAP32[$177>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($178|0),($$byval_copy31|0));
    $179 = __THREW__; __THREW__ = 0;
    $180 = $179&1;
    if ($180) {
     $181 = ___cxa_find_matching_catch()|0;
     $182 = tempRet0;
     ___cxa_call_unexpected(($181|0));
     // unreachable;
    }
   }
   HEAP32[$this>>2] = ((561192 + 8|0));
   __THREW__ = 0;
   $183 = __THREW__; __THREW__ = 0;
   $184 = $183&1;
   if ($184) {
    $195 = ___cxa_find_matching_catch(0|0)|0;
    $196 = tempRet0;
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $197 = __THREW__; __THREW__ = 0;
    $198 = $197&1;
    if ($198) {
     $201 = ___cxa_find_matching_catch(0|0)|0;
     $202 = tempRet0;
     __THREW__ = 0;
     $203 = __THREW__; __THREW__ = 0;
     $204 = $203&1;
     if ($204) {
      $205 = ___cxa_find_matching_catch(0|0)|0;
      $206 = tempRet0;
      ___clang_call_terminate($205);
      // unreachable;
     } else {
      $eh$lpad$body$i22$indexZ2D = $201;
      ___clang_call_terminate($eh$lpad$body$i22$indexZ2D);
      // unreachable;
     }
    }
    __THREW__ = 0;
    $199 = __THREW__; __THREW__ = 0;
    $200 = $199&1;
    if (!($200)) {
     $eh$lpad$body$indexZ2D = $195;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
    $207 = ___cxa_find_matching_catch(0|0)|0;
    $208 = tempRet0;
    $eh$lpad$body$i22$indexZ2D = $207;
    ___clang_call_terminate($eh$lpad$body$i22$indexZ2D);
    // unreachable;
   } else {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $185 = __THREW__; __THREW__ = 0;
    $186 = $185&1;
    if ($186) {
     $187 = ___cxa_find_matching_catch(0|0)|0;
     $188 = tempRet0;
     __THREW__ = 0;
     $189 = __THREW__; __THREW__ = 0;
     $190 = $189&1;
     if ($190) {
      $191 = ___cxa_find_matching_catch(0|0)|0;
      $192 = tempRet0;
      ___clang_call_terminate($191);
      // unreachable;
     } else {
      $eh$lpad$body$indexZ2D = $187;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
    }
    __THREW__ = 0;
    $193 = __THREW__; __THREW__ = 0;
    $194 = $193&1;
    if (!($194)) {
     ___resumeException($111|0);
     // unreachable;
    }
    $209 = ___cxa_find_matching_catch(0|0)|0;
    $210 = tempRet0;
    $eh$lpad$body$indexZ2D = $209;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
 } while(0);
 $17 = (($this) + 256|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  $21 = (($this) + 264|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$6>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$6+0>>2]|0;
  invoke_vii(2591,($22|0),($$byval_copy31|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   ___cxa_call_unexpected(($25|0));
   // unreachable;
  }
 }
 $27 = (($this) + 244|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = $28 & 1;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = (($this) + 252|0);
  $32 = HEAP32[$31>>2]|0;
  HEAP32[$5>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,($32|0),($$byval_copy31|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $35 = ___cxa_find_matching_catch()|0;
   $36 = tempRet0;
   ___cxa_call_unexpected(($35|0));
   // unreachable;
  }
 }
 $37 = (($this) + 232|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = $38 & 1;
 $40 = ($39<<24>>24)==(0);
 if (!($40)) {
  $41 = (($this) + 240|0);
  $42 = HEAP32[$41>>2]|0;
  HEAP32[$4>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($42|0),($$byval_copy31|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   $45 = ___cxa_find_matching_catch()|0;
   $46 = tempRet0;
   ___cxa_call_unexpected(($45|0));
   // unreachable;
  }
 }
 $47 = (($this) + 220|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48 & 1;
 $50 = ($49<<24>>24)==(0);
 if (!($50)) {
  $51 = (($this) + 228|0);
  $52 = HEAP32[$51>>2]|0;
  HEAP32[$3>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($52|0),($$byval_copy31|0));
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if ($54) {
   $55 = ___cxa_find_matching_catch()|0;
   $56 = tempRet0;
   ___cxa_call_unexpected(($55|0));
   // unreachable;
  }
 }
 $57 = (($this) + 48|0);
 $58 = HEAP8[$57>>0]|0;
 $59 = $58 & 1;
 $60 = ($59<<24>>24)==(0);
 if (!($60)) {
  $61 = (($this) + 56|0);
  $62 = HEAP32[$61>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($62|0),($$byval_copy31|0));
  $63 = __THREW__; __THREW__ = 0;
  $64 = $63&1;
  if ($64) {
   $65 = ___cxa_find_matching_catch()|0;
   $66 = tempRet0;
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 }
 $67 = (($this) + 36|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = $68 & 1;
 $70 = ($69<<24>>24)==(0);
 if (!($70)) {
  $71 = (($this) + 44|0);
  $72 = HEAP32[$71>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($72|0),($$byval_copy31|0));
  $73 = __THREW__; __THREW__ = 0;
  $74 = $73&1;
  if ($74) {
   $75 = ___cxa_find_matching_catch()|0;
   $76 = tempRet0;
   ___cxa_call_unexpected(($75|0));
   // unreachable;
  }
 }
 $77 = (($this) + 24|0);
 $78 = HEAP8[$77>>0]|0;
 $79 = $78 & 1;
 $80 = ($79<<24>>24)==(0);
 if (!($80)) {
  $81 = (($this) + 32|0);
  $82 = HEAP32[$81>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($82|0),($$byval_copy31|0));
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if ($84) {
   $85 = ___cxa_find_matching_catch()|0;
   $86 = tempRet0;
   ___cxa_call_unexpected(($85|0));
   // unreachable;
  }
 }
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if (!($88)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $89 = __THREW__; __THREW__ = 0;
  $90 = $89&1;
  if (!($90)) {
   STACKTOP = sp;return;
  }
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  __THREW__ = 0;
  $93 = __THREW__; __THREW__ = 0;
  $94 = $93&1;
  if ($94) {
   $95 = ___cxa_find_matching_catch(0|0)|0;
   $96 = tempRet0;
   ___clang_call_terminate($95);
   // unreachable;
  } else {
   ___resumeException($91|0);
   // unreachable;
  }
 }
 $97 = ___cxa_find_matching_catch()|0;
 $98 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $99 = __THREW__; __THREW__ = 0;
 $100 = $99&1;
 if ($100) {
  $103 = ___cxa_find_matching_catch(0|0)|0;
  $104 = tempRet0;
  __THREW__ = 0;
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if ($106) {
   $107 = ___cxa_find_matching_catch(0|0)|0;
   $108 = tempRet0;
   ___clang_call_terminate($107);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $103;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $101 = __THREW__; __THREW__ = 0;
 $102 = $101&1;
 if (!($102)) {
  ___resumeException($97|0);
  // unreachable;
 }
 $109 = ___cxa_find_matching_catch(0|0)|0;
 $110 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $109;
 ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
 // unreachable;
}
function __ZN22BuiltinResourceManager19InitializeResourcesEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i10 = 0, $$pre$i$i$i$i101 = 0, $$pre$i$i$i$i105 = 0, $$pre$i$i$i$i109 = 0, $$pre$i$i$i$i113 = 0, $$pre$i$i$i$i117 = 0, $$pre$i$i$i$i121 = 0, $$pre$i$i$i$i125 = 0, $$pre$i$i$i$i129 = 0, $$pre$i$i$i$i133 = 0, $$pre$i$i$i$i137 = 0, $$pre$i$i$i$i14 = 0, $$pre$i$i$i$i141 = 0, $$pre$i$i$i$i145 = 0, $$pre$i$i$i$i149 = 0, $$pre$i$i$i$i153 = 0, $$pre$i$i$i$i157 = 0, $$pre$i$i$i$i161 = 0;
 var $$pre$i$i$i$i165 = 0, $$pre$i$i$i$i169 = 0, $$pre$i$i$i$i173 = 0, $$pre$i$i$i$i177 = 0, $$pre$i$i$i$i18 = 0, $$pre$i$i$i$i181 = 0, $$pre$i$i$i$i185 = 0, $$pre$i$i$i$i189 = 0, $$pre$i$i$i$i193 = 0, $$pre$i$i$i$i197 = 0, $$pre$i$i$i$i2 = 0, $$pre$i$i$i$i201 = 0, $$pre$i$i$i$i205 = 0, $$pre$i$i$i$i209 = 0, $$pre$i$i$i$i213 = 0, $$pre$i$i$i$i217 = 0, $$pre$i$i$i$i22 = 0, $$pre$i$i$i$i221 = 0, $$pre$i$i$i$i225 = 0, $$pre$i$i$i$i229 = 0;
 var $$pre$i$i$i$i233 = 0, $$pre$i$i$i$i237 = 0, $$pre$i$i$i$i241 = 0, $$pre$i$i$i$i245 = 0, $$pre$i$i$i$i249 = 0, $$pre$i$i$i$i253 = 0, $$pre$i$i$i$i257 = 0, $$pre$i$i$i$i26 = 0, $$pre$i$i$i$i261 = 0, $$pre$i$i$i$i265 = 0, $$pre$i$i$i$i269 = 0, $$pre$i$i$i$i273 = 0, $$pre$i$i$i$i277 = 0, $$pre$i$i$i$i281 = 0, $$pre$i$i$i$i285 = 0, $$pre$i$i$i$i289 = 0, $$pre$i$i$i$i293 = 0, $$pre$i$i$i$i297 = 0, $$pre$i$i$i$i30 = 0, $$pre$i$i$i$i301 = 0;
 var $$pre$i$i$i$i305 = 0, $$pre$i$i$i$i34 = 0, $$pre$i$i$i$i38 = 0, $$pre$i$i$i$i41 = 0, $$pre$i$i$i$i45 = 0, $$pre$i$i$i$i49 = 0, $$pre$i$i$i$i53 = 0, $$pre$i$i$i$i57 = 0, $$pre$i$i$i$i6 = 0, $$pre$i$i$i$i61 = 0, $$pre$i$i$i$i65 = 0, $$pre$i$i$i$i69 = 0, $$pre$i$i$i$i73 = 0, $$pre$i$i$i$i77 = 0, $$pre$i$i$i$i81 = 0, $$pre$i$i$i$i85 = 0, $$pre$i$i$i$i89 = 0, $$pre$i$i$i$i93 = 0, $$pre$i$i$i$i97 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0;
 var $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0;
 var $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0;
 var $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0;
 var $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0;
 var $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0;
 var $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0;
 var $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0;
 var $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0;
 var $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0;
 var $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0;
 var $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0;
 var $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0;
 var $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0;
 var $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0;
 var $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0;
 var $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0;
 var $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0;
 var $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0;
 var $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0;
 var $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0;
 var $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0;
 var $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0;
 var $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0;
 var $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0;
 var $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0;
 var $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0;
 var $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0;
 var $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0;
 var $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0;
 var $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0;
 var $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0;
 var $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0;
 var $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0;
 var $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0;
 var $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0;
 var $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0;
 var $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0;
 var $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0;
 var $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0;
 var $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0;
 var $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0;
 var $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0;
 var $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0;
 var $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0;
 var $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($1,625112)|0);
 $2 = (($this) + 24|0);
 HEAP32[$2>>2] = 63;
 $3 = (($this) + 28|0);
 HEAP8[$3>>0] = 1;
 HEAP32[$0>>2] = 625144;
 $4 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($0) + 8|0);
 $7 = $6;
 $8 = $7;
 HEAP32[$8>>2] = 17;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 $11 = (__Z20GetPersistentManagerv()|0);
 $12 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($11,$1,17,0)|0);
 $13 = (($0) + 16|0);
 HEAP32[$13>>2] = $12;
 $14 = (($0) + 20|0);
 HEAP8[$14>>0] = 0;
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16|0)==($18|0);
 if ($19) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $20 = ($16|0)==(0|0);
  if ($20) {
   $22 = 0;
  } else {
   ;HEAP32[$16+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$16+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$16+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i = HEAP32[$15>>2]|0;
   $22 = $$pre$i$i$i$i;
  }
  $21 = (($22) + 24|0);
  HEAP32[$15>>2] = $21;
 }
 HEAP32[$0>>2] = 625176;
 $23 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $24 = (($0) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = (($0) + 8|0);
 $26 = $25;
 $27 = $26;
 HEAP32[$27>>2] = 60;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = 0;
 $30 = (__Z20GetPersistentManagerv()|0);
 $31 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($30,$1,60,0)|0);
 $32 = (($0) + 16|0);
 HEAP32[$32>>2] = $31;
 $33 = (($0) + 20|0);
 HEAP8[$33>>0] = 0;
 $34 = HEAP32[$15>>2]|0;
 $35 = HEAP32[$17>>2]|0;
 $36 = ($34|0)==($35|0);
 if ($36) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $37 = ($34|0)==(0|0);
  if ($37) {
   $39 = 0;
  } else {
   ;HEAP32[$34+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$34+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$34+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i2 = HEAP32[$15>>2]|0;
   $39 = $$pre$i$i$i$i2;
  }
  $38 = (($39) + 24|0);
  HEAP32[$15>>2] = $38;
 }
 HEAP32[$0>>2] = 625208;
 $40 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $41 = (($0) + 4|0);
 HEAP32[$41>>2] = $40;
 $42 = (($0) + 8|0);
 $43 = $42;
 $44 = $43;
 HEAP32[$44>>2] = 62;
 $45 = (($43) + 4)|0;
 $46 = $45;
 HEAP32[$46>>2] = 0;
 $47 = (__Z20GetPersistentManagerv()|0);
 $48 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($47,$1,62,0)|0);
 $49 = (($0) + 16|0);
 HEAP32[$49>>2] = $48;
 $50 = (($0) + 20|0);
 HEAP8[$50>>0] = 0;
 $51 = HEAP32[$15>>2]|0;
 $52 = HEAP32[$17>>2]|0;
 $53 = ($51|0)==($52|0);
 if ($53) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $54 = ($51|0)==(0|0);
  if ($54) {
   $56 = 0;
  } else {
   ;HEAP32[$51+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$51+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$51+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$51+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$51+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i6 = HEAP32[$15>>2]|0;
   $56 = $$pre$i$i$i$i6;
  }
  $55 = (($56) + 24|0);
  HEAP32[$15>>2] = $55;
 }
 HEAP32[$0>>2] = 625248;
 $57 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $58 = (($0) + 4|0);
 HEAP32[$58>>2] = $57;
 $59 = (($0) + 8|0);
 $60 = $59;
 $61 = $60;
 HEAP32[$61>>2] = 64;
 $62 = (($60) + 4)|0;
 $63 = $62;
 HEAP32[$63>>2] = 0;
 $64 = (__Z20GetPersistentManagerv()|0);
 $65 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($64,$1,64,0)|0);
 $66 = (($0) + 16|0);
 HEAP32[$66>>2] = $65;
 $67 = (($0) + 20|0);
 HEAP8[$67>>0] = 0;
 $68 = HEAP32[$15>>2]|0;
 $69 = HEAP32[$17>>2]|0;
 $70 = ($68|0)==($69|0);
 if ($70) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $71 = ($68|0)==(0|0);
  if ($71) {
   $73 = 0;
  } else {
   ;HEAP32[$68+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$68+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$68+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$68+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$68+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$68+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i10 = HEAP32[$15>>2]|0;
   $73 = $$pre$i$i$i$i10;
  }
  $72 = (($73) + 24|0);
  HEAP32[$15>>2] = $72;
 }
 HEAP32[$0>>2] = 625288;
 $74 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $75 = (($0) + 4|0);
 HEAP32[$75>>2] = $74;
 $76 = (($0) + 8|0);
 $77 = $76;
 $78 = $77;
 HEAP32[$78>>2] = 65;
 $79 = (($77) + 4)|0;
 $80 = $79;
 HEAP32[$80>>2] = 0;
 $81 = (__Z20GetPersistentManagerv()|0);
 $82 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($81,$1,65,0)|0);
 $83 = (($0) + 16|0);
 HEAP32[$83>>2] = $82;
 $84 = (($0) + 20|0);
 HEAP8[$84>>0] = 0;
 $85 = HEAP32[$15>>2]|0;
 $86 = HEAP32[$17>>2]|0;
 $87 = ($85|0)==($86|0);
 if ($87) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $88 = ($85|0)==(0|0);
  if ($88) {
   $90 = 0;
  } else {
   ;HEAP32[$85+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$85+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$85+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$85+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i14 = HEAP32[$15>>2]|0;
   $90 = $$pre$i$i$i$i14;
  }
  $89 = (($90) + 24|0);
  HEAP32[$15>>2] = $89;
 }
 HEAP32[$0>>2] = 625328;
 $91 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $92 = (($0) + 4|0);
 HEAP32[$92>>2] = $91;
 $93 = (($0) + 8|0);
 $94 = $93;
 $95 = $94;
 HEAP32[$95>>2] = 66;
 $96 = (($94) + 4)|0;
 $97 = $96;
 HEAP32[$97>>2] = 0;
 $98 = (__Z20GetPersistentManagerv()|0);
 $99 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($98,$1,66,0)|0);
 $100 = (($0) + 16|0);
 HEAP32[$100>>2] = $99;
 $101 = (($0) + 20|0);
 HEAP8[$101>>0] = 0;
 $102 = HEAP32[$15>>2]|0;
 $103 = HEAP32[$17>>2]|0;
 $104 = ($102|0)==($103|0);
 if ($104) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $105 = ($102|0)==(0|0);
  if ($105) {
   $107 = 0;
  } else {
   ;HEAP32[$102+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$102+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$102+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$102+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$102+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$102+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i18 = HEAP32[$15>>2]|0;
   $107 = $$pre$i$i$i$i18;
  }
  $106 = (($107) + 24|0);
  HEAP32[$15>>2] = $106;
 }
 HEAP32[$0>>2] = 625360;
 $108 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $109 = (($0) + 4|0);
 HEAP32[$109>>2] = $108;
 $110 = (($0) + 8|0);
 $111 = $110;
 $112 = $111;
 HEAP32[$112>>2] = 67;
 $113 = (($111) + 4)|0;
 $114 = $113;
 HEAP32[$114>>2] = 0;
 $115 = (__Z20GetPersistentManagerv()|0);
 $116 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($115,$1,67,0)|0);
 $117 = (($0) + 16|0);
 HEAP32[$117>>2] = $116;
 $118 = (($0) + 20|0);
 HEAP8[$118>>0] = 0;
 $119 = HEAP32[$15>>2]|0;
 $120 = HEAP32[$17>>2]|0;
 $121 = ($119|0)==($120|0);
 if ($121) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $122 = ($119|0)==(0|0);
  if ($122) {
   $124 = 0;
  } else {
   ;HEAP32[$119+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$119+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$119+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$119+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$119+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$119+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i22 = HEAP32[$15>>2]|0;
   $124 = $$pre$i$i$i$i22;
  }
  $123 = (($124) + 24|0);
  HEAP32[$15>>2] = $123;
 }
 HEAP32[$0>>2] = 625392;
 $125 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $126 = (($0) + 4|0);
 HEAP32[$126>>2] = $125;
 $127 = (($0) + 8|0);
 $128 = $127;
 $129 = $128;
 HEAP32[$129>>2] = 68;
 $130 = (($128) + 4)|0;
 $131 = $130;
 HEAP32[$131>>2] = 0;
 $132 = (__Z20GetPersistentManagerv()|0);
 $133 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($132,$1,68,0)|0);
 $134 = (($0) + 16|0);
 HEAP32[$134>>2] = $133;
 $135 = (($0) + 20|0);
 HEAP8[$135>>0] = 0;
 $136 = HEAP32[$15>>2]|0;
 $137 = HEAP32[$17>>2]|0;
 $138 = ($136|0)==($137|0);
 if ($138) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $139 = ($136|0)==(0|0);
  if ($139) {
   $141 = 0;
  } else {
   ;HEAP32[$136+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$136+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$136+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$136+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$136+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i26 = HEAP32[$15>>2]|0;
   $141 = $$pre$i$i$i$i26;
  }
  $140 = (($141) + 24|0);
  HEAP32[$15>>2] = $140;
 }
 HEAP32[$0>>2] = 625416;
 $142 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $143 = (($0) + 4|0);
 HEAP32[$143>>2] = $142;
 $144 = (($0) + 8|0);
 $145 = $144;
 $146 = $145;
 HEAP32[$146>>2] = 102;
 $147 = (($145) + 4)|0;
 $148 = $147;
 HEAP32[$148>>2] = 0;
 $149 = (__Z20GetPersistentManagerv()|0);
 $150 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($149,$1,102,0)|0);
 $151 = (($0) + 16|0);
 HEAP32[$151>>2] = $150;
 $152 = (($0) + 20|0);
 HEAP8[$152>>0] = 0;
 $153 = HEAP32[$15>>2]|0;
 $154 = HEAP32[$17>>2]|0;
 $155 = ($153|0)==($154|0);
 if ($155) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $156 = ($153|0)==(0|0);
  if ($156) {
   $158 = 0;
  } else {
   ;HEAP32[$153+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$153+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$153+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$153+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$153+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$153+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i30 = HEAP32[$15>>2]|0;
   $158 = $$pre$i$i$i$i30;
  }
  $157 = (($158) + 24|0);
  HEAP32[$15>>2] = $157;
 }
 HEAP32[$0>>2] = 625440;
 $159 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $160 = (($0) + 4|0);
 HEAP32[$160>>2] = $159;
 $161 = (($0) + 8|0);
 $162 = $161;
 $163 = $162;
 HEAP32[$163>>2] = 105;
 $164 = (($162) + 4)|0;
 $165 = $164;
 HEAP32[$165>>2] = 0;
 $166 = (__Z20GetPersistentManagerv()|0);
 $167 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($166,$1,105,0)|0);
 $168 = (($0) + 16|0);
 HEAP32[$168>>2] = $167;
 $169 = (($0) + 20|0);
 HEAP8[$169>>0] = 0;
 $170 = HEAP32[$15>>2]|0;
 $171 = HEAP32[$17>>2]|0;
 $172 = ($170|0)==($171|0);
 if ($172) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $173 = ($170|0)==(0|0);
  if ($173) {
   $175 = 0;
  } else {
   ;HEAP32[$170+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$170+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$170+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$170+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$170+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$170+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i34 = HEAP32[$15>>2]|0;
   $175 = $$pre$i$i$i$i34;
  }
  $174 = (($175) + 24|0);
  HEAP32[$15>>2] = $174;
 }
 HEAP32[$0>>2] = 625464;
 $176 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $177 = (($0) + 4|0);
 HEAP32[$177>>2] = $176;
 $178 = (($0) + 8|0);
 $179 = $178;
 $180 = $179;
 HEAP32[$180>>2] = 10001;
 $181 = (($179) + 4)|0;
 $182 = $181;
 HEAP32[$182>>2] = 0;
 $183 = (__Z20GetPersistentManagerv()|0);
 $184 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($183,$1,10001,0)|0);
 $185 = (($0) + 16|0);
 HEAP32[$185>>2] = $184;
 $186 = (($0) + 20|0);
 HEAP8[$186>>0] = 0;
 $187 = HEAP32[$15>>2]|0;
 $188 = HEAP32[$17>>2]|0;
 $189 = ($187|0)==($188|0);
 if ($189) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $190 = ($187|0)==(0|0);
  if ($190) {
   $192 = 0;
  } else {
   ;HEAP32[$187+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$187+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$187+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$187+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$187+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$187+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i38 = HEAP32[$15>>2]|0;
   $192 = $$pre$i$i$i$i38;
  }
  $191 = (($192) + 24|0);
  HEAP32[$15>>2] = $191;
 }
 HEAP32[$0>>2] = 625496;
 $193 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $194 = (($0) + 4|0);
 HEAP32[$194>>2] = $193;
 $195 = (($0) + 8|0);
 $196 = $195;
 $197 = $196;
 HEAP32[$197>>2] = 9000;
 $198 = (($196) + 4)|0;
 $199 = $198;
 HEAP32[$199>>2] = 0;
 $200 = (__Z20GetPersistentManagerv()|0);
 $201 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($200,$1,9000,0)|0);
 $202 = (($0) + 16|0);
 HEAP32[$202>>2] = $201;
 $203 = (($0) + 20|0);
 HEAP8[$203>>0] = 0;
 $204 = HEAP32[$15>>2]|0;
 $205 = HEAP32[$17>>2]|0;
 $206 = ($204|0)==($205|0);
 if ($206) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $207 = ($204|0)==(0|0);
  if ($207) {
   $209 = 0;
  } else {
   ;HEAP32[$204+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$204+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$204+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$204+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$204+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$204+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i41 = HEAP32[$15>>2]|0;
   $209 = $$pre$i$i$i$i41;
  }
  $208 = (($209) + 24|0);
  HEAP32[$15>>2] = $208;
 }
 HEAP32[$0>>2] = 625528;
 $210 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $211 = (($0) + 4|0);
 HEAP32[$211>>2] = $210;
 $212 = (($0) + 8|0);
 $213 = $212;
 $214 = $213;
 HEAP32[$214>>2] = 9001;
 $215 = (($213) + 4)|0;
 $216 = $215;
 HEAP32[$216>>2] = 0;
 $217 = (__Z20GetPersistentManagerv()|0);
 $218 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($217,$1,9001,0)|0);
 $219 = (($0) + 16|0);
 HEAP32[$219>>2] = $218;
 $220 = (($0) + 20|0);
 HEAP8[$220>>0] = 0;
 $221 = HEAP32[$15>>2]|0;
 $222 = HEAP32[$17>>2]|0;
 $223 = ($221|0)==($222|0);
 if ($223) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $224 = ($221|0)==(0|0);
  if ($224) {
   $226 = 0;
  } else {
   ;HEAP32[$221+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$221+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$221+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$221+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$221+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$221+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i45 = HEAP32[$15>>2]|0;
   $226 = $$pre$i$i$i$i45;
  }
  $225 = (($226) + 24|0);
  HEAP32[$15>>2] = $225;
 }
 HEAP32[$0>>2] = 625568;
 $227 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $228 = (($0) + 4|0);
 HEAP32[$228>>2] = $227;
 $229 = (($0) + 8|0);
 $230 = $229;
 $231 = $230;
 HEAP32[$231>>2] = 9002;
 $232 = (($230) + 4)|0;
 $233 = $232;
 HEAP32[$233>>2] = 0;
 $234 = (__Z20GetPersistentManagerv()|0);
 $235 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($234,$1,9002,0)|0);
 $236 = (($0) + 16|0);
 HEAP32[$236>>2] = $235;
 $237 = (($0) + 20|0);
 HEAP8[$237>>0] = 0;
 $238 = HEAP32[$15>>2]|0;
 $239 = HEAP32[$17>>2]|0;
 $240 = ($238|0)==($239|0);
 if ($240) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $241 = ($238|0)==(0|0);
  if ($241) {
   $243 = 0;
  } else {
   ;HEAP32[$238+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$238+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$238+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$238+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$238+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$238+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i49 = HEAP32[$15>>2]|0;
   $243 = $$pre$i$i$i$i49;
  }
  $242 = (($243) + 24|0);
  HEAP32[$15>>2] = $242;
 }
 HEAP32[$0>>2] = 625600;
 $244 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $245 = (($0) + 4|0);
 HEAP32[$245>>2] = $244;
 $246 = (($0) + 8|0);
 $247 = $246;
 $248 = $247;
 HEAP32[$248>>2] = 9003;
 $249 = (($247) + 4)|0;
 $250 = $249;
 HEAP32[$250>>2] = 0;
 $251 = (__Z20GetPersistentManagerv()|0);
 $252 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($251,$1,9003,0)|0);
 $253 = (($0) + 16|0);
 HEAP32[$253>>2] = $252;
 $254 = (($0) + 20|0);
 HEAP8[$254>>0] = 0;
 $255 = HEAP32[$15>>2]|0;
 $256 = HEAP32[$17>>2]|0;
 $257 = ($255|0)==($256|0);
 if ($257) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $258 = ($255|0)==(0|0);
  if ($258) {
   $260 = 0;
  } else {
   ;HEAP32[$255+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$255+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$255+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$255+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$255+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$255+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i53 = HEAP32[$15>>2]|0;
   $260 = $$pre$i$i$i$i53;
  }
  $259 = (($260) + 24|0);
  HEAP32[$15>>2] = $259;
 }
 HEAP32[$0>>2] = 625632;
 $261 = (__ZN6Object15StringToClassIDEPKc(625648)|0);
 $262 = (($0) + 4|0);
 HEAP32[$262>>2] = $261;
 $263 = (($0) + 8|0);
 $264 = $263;
 $265 = $264;
 HEAP32[$265>>2] = 10100;
 $266 = (($264) + 4)|0;
 $267 = $266;
 HEAP32[$267>>2] = 0;
 $268 = (__Z20GetPersistentManagerv()|0);
 $269 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($268,$1,10100,0)|0);
 $270 = (($0) + 16|0);
 HEAP32[$270>>2] = $269;
 $271 = (($0) + 20|0);
 HEAP8[$271>>0] = 0;
 $272 = HEAP32[$15>>2]|0;
 $273 = HEAP32[$17>>2]|0;
 $274 = ($272|0)==($273|0);
 if ($274) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $275 = ($272|0)==(0|0);
  if ($275) {
   $277 = 0;
  } else {
   ;HEAP32[$272+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$272+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$272+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$272+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$272+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$272+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i57 = HEAP32[$15>>2]|0;
   $277 = $$pre$i$i$i$i57;
  }
  $276 = (($277) + 24|0);
  HEAP32[$15>>2] = $276;
 }
 HEAP32[$0>>2] = 625664;
 $278 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $279 = (($0) + 4|0);
 HEAP32[$279>>2] = $278;
 $280 = (($0) + 8|0);
 $281 = $280;
 $282 = $281;
 HEAP32[$282>>2] = 10101;
 $283 = (($281) + 4)|0;
 $284 = $283;
 HEAP32[$284>>2] = 0;
 $285 = (__Z20GetPersistentManagerv()|0);
 $286 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($285,$1,10101,0)|0);
 $287 = (($0) + 16|0);
 HEAP32[$287>>2] = $286;
 $288 = (($0) + 20|0);
 HEAP8[$288>>0] = 1;
 $289 = HEAP32[$15>>2]|0;
 $290 = HEAP32[$17>>2]|0;
 $291 = ($289|0)==($290|0);
 if ($291) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $292 = ($289|0)==(0|0);
  if ($292) {
   $294 = 0;
  } else {
   ;HEAP32[$289+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$289+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$289+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$289+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$289+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$289+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i61 = HEAP32[$15>>2]|0;
   $294 = $$pre$i$i$i$i61;
  }
  $293 = (($294) + 24|0);
  HEAP32[$15>>2] = $293;
 }
 HEAP32[$0>>2] = 625632;
 $295 = (__ZN6Object15StringToClassIDEPKc(625680)|0);
 $296 = (($0) + 4|0);
 HEAP32[$296>>2] = $295;
 $297 = (($0) + 8|0);
 $298 = $297;
 $299 = $298;
 HEAP32[$299>>2] = 10102;
 $300 = (($298) + 4)|0;
 $301 = $300;
 HEAP32[$301>>2] = 0;
 $302 = (__Z20GetPersistentManagerv()|0);
 $303 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($302,$1,10102,0)|0);
 $304 = (($0) + 16|0);
 HEAP32[$304>>2] = $303;
 $305 = (($0) + 20|0);
 HEAP8[$305>>0] = 1;
 $306 = HEAP32[$15>>2]|0;
 $307 = HEAP32[$17>>2]|0;
 $308 = ($306|0)==($307|0);
 if ($308) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $309 = ($306|0)==(0|0);
  if ($309) {
   $311 = 0;
  } else {
   ;HEAP32[$306+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$306+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$306+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$306+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$306+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$306+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i65 = HEAP32[$15>>2]|0;
   $311 = $$pre$i$i$i$i65;
  }
  $310 = (($311) + 24|0);
  HEAP32[$15>>2] = $310;
 }
 HEAP32[$0>>2] = 625632;
 $312 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $313 = (($0) + 4|0);
 HEAP32[$313>>2] = $312;
 $314 = (($0) + 8|0);
 $315 = $314;
 $316 = $315;
 HEAP32[$316>>2] = 10103;
 $317 = (($315) + 4)|0;
 $318 = $317;
 HEAP32[$318>>2] = 0;
 $319 = (__Z20GetPersistentManagerv()|0);
 $320 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($319,$1,10103,0)|0);
 $321 = (($0) + 16|0);
 HEAP32[$321>>2] = $320;
 $322 = (($0) + 20|0);
 HEAP8[$322>>0] = 0;
 $323 = HEAP32[$15>>2]|0;
 $324 = HEAP32[$17>>2]|0;
 $325 = ($323|0)==($324|0);
 if ($325) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $326 = ($323|0)==(0|0);
  if ($326) {
   $328 = 0;
  } else {
   ;HEAP32[$323+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$323+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$323+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$323+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$323+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$323+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i69 = HEAP32[$15>>2]|0;
   $328 = $$pre$i$i$i$i69;
  }
  $327 = (($328) + 24|0);
  HEAP32[$15>>2] = $327;
 }
 HEAP32[$0>>2] = 625688;
 $329 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $330 = (($0) + 4|0);
 HEAP32[$330>>2] = $329;
 $331 = (($0) + 8|0);
 $332 = $331;
 $333 = $332;
 HEAP32[$333>>2] = 10202;
 $334 = (($332) + 4)|0;
 $335 = $334;
 HEAP32[$335>>2] = 0;
 $336 = (__Z20GetPersistentManagerv()|0);
 $337 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($336,$1,10202,0)|0);
 $338 = (($0) + 16|0);
 HEAP32[$338>>2] = $337;
 $339 = (($0) + 20|0);
 HEAP8[$339>>0] = 1;
 $340 = HEAP32[$15>>2]|0;
 $341 = HEAP32[$17>>2]|0;
 $342 = ($340|0)==($341|0);
 if ($342) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $343 = ($340|0)==(0|0);
  if ($343) {
   $345 = 0;
  } else {
   ;HEAP32[$340+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$340+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$340+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$340+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$340+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$340+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i73 = HEAP32[$15>>2]|0;
   $345 = $$pre$i$i$i$i73;
  }
  $344 = (($345) + 24|0);
  HEAP32[$15>>2] = $344;
 }
 HEAP32[$0>>2] = 625712;
 $346 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $347 = (($0) + 4|0);
 HEAP32[$347>>2] = $346;
 $348 = (($0) + 8|0);
 $349 = $348;
 $350 = $349;
 HEAP32[$350>>2] = 10206;
 $351 = (($349) + 4)|0;
 $352 = $351;
 HEAP32[$352>>2] = 0;
 $353 = (__Z20GetPersistentManagerv()|0);
 $354 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($353,$1,10206,0)|0);
 $355 = (($0) + 16|0);
 HEAP32[$355>>2] = $354;
 $356 = (($0) + 20|0);
 HEAP8[$356>>0] = 1;
 $357 = HEAP32[$15>>2]|0;
 $358 = HEAP32[$17>>2]|0;
 $359 = ($357|0)==($358|0);
 if ($359) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $360 = ($357|0)==(0|0);
  if ($360) {
   $362 = 0;
  } else {
   ;HEAP32[$357+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$357+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$357+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$357+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$357+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$357+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i77 = HEAP32[$15>>2]|0;
   $362 = $$pre$i$i$i$i77;
  }
  $361 = (($362) + 24|0);
  HEAP32[$15>>2] = $361;
 }
 HEAP32[$0>>2] = 625736;
 $363 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $364 = (($0) + 4|0);
 HEAP32[$364>>2] = $363;
 $365 = (($0) + 8|0);
 $366 = $365;
 $367 = $366;
 HEAP32[$367>>2] = 10207;
 $368 = (($366) + 4)|0;
 $369 = $368;
 HEAP32[$369>>2] = 0;
 $370 = (__Z20GetPersistentManagerv()|0);
 $371 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($370,$1,10207,0)|0);
 $372 = (($0) + 16|0);
 HEAP32[$372>>2] = $371;
 $373 = (($0) + 20|0);
 HEAP8[$373>>0] = 1;
 $374 = HEAP32[$15>>2]|0;
 $375 = HEAP32[$17>>2]|0;
 $376 = ($374|0)==($375|0);
 if ($376) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $377 = ($374|0)==(0|0);
  if ($377) {
   $379 = 0;
  } else {
   ;HEAP32[$374+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$374+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$374+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$374+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$374+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$374+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i81 = HEAP32[$15>>2]|0;
   $379 = $$pre$i$i$i$i81;
  }
  $378 = (($379) + 24|0);
  HEAP32[$15>>2] = $378;
 }
 HEAP32[$0>>2] = 625752;
 $380 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $381 = (($0) + 4|0);
 HEAP32[$381>>2] = $380;
 $382 = (($0) + 8|0);
 $383 = $382;
 $384 = $383;
 HEAP32[$384>>2] = 10208;
 $385 = (($383) + 4)|0;
 $386 = $385;
 HEAP32[$386>>2] = 0;
 $387 = (__Z20GetPersistentManagerv()|0);
 $388 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($387,$1,10208,0)|0);
 $389 = (($0) + 16|0);
 HEAP32[$389>>2] = $388;
 $390 = (($0) + 20|0);
 HEAP8[$390>>0] = 1;
 $391 = HEAP32[$15>>2]|0;
 $392 = HEAP32[$17>>2]|0;
 $393 = ($391|0)==($392|0);
 if ($393) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $394 = ($391|0)==(0|0);
  if ($394) {
   $396 = 0;
  } else {
   ;HEAP32[$391+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$391+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$391+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$391+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$391+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$391+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i85 = HEAP32[$15>>2]|0;
   $396 = $$pre$i$i$i$i85;
  }
  $395 = (($396) + 24|0);
  HEAP32[$15>>2] = $395;
 }
 HEAP32[$0>>2] = 625768;
 $397 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $398 = (($0) + 4|0);
 HEAP32[$398>>2] = $397;
 $399 = (($0) + 8|0);
 $400 = $399;
 $401 = $400;
 HEAP32[$401>>2] = 10209;
 $402 = (($400) + 4)|0;
 $403 = $402;
 HEAP32[$403>>2] = 0;
 $404 = (__Z20GetPersistentManagerv()|0);
 $405 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($404,$1,10209,0)|0);
 $406 = (($0) + 16|0);
 HEAP32[$406>>2] = $405;
 $407 = (($0) + 20|0);
 HEAP8[$407>>0] = 1;
 $408 = HEAP32[$15>>2]|0;
 $409 = HEAP32[$17>>2]|0;
 $410 = ($408|0)==($409|0);
 if ($410) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $411 = ($408|0)==(0|0);
  if ($411) {
   $413 = 0;
  } else {
   ;HEAP32[$408+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$408+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$408+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$408+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$408+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$408+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i89 = HEAP32[$15>>2]|0;
   $413 = $$pre$i$i$i$i89;
  }
  $412 = (($413) + 24|0);
  HEAP32[$15>>2] = $412;
 }
 HEAP32[$0>>2] = 625784;
 $414 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $415 = (($0) + 4|0);
 HEAP32[$415>>2] = $414;
 $416 = (($0) + 8|0);
 $417 = $416;
 $418 = $417;
 HEAP32[$418>>2] = 10210;
 $419 = (($417) + 4)|0;
 $420 = $419;
 HEAP32[$420>>2] = 0;
 $421 = (__Z20GetPersistentManagerv()|0);
 $422 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($421,$1,10210,0)|0);
 $423 = (($0) + 16|0);
 HEAP32[$423>>2] = $422;
 $424 = (($0) + 20|0);
 HEAP8[$424>>0] = 1;
 $425 = HEAP32[$15>>2]|0;
 $426 = HEAP32[$17>>2]|0;
 $427 = ($425|0)==($426|0);
 if ($427) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $428 = ($425|0)==(0|0);
  if ($428) {
   $430 = 0;
  } else {
   ;HEAP32[$425+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$425+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$425+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$425+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$425+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$425+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i93 = HEAP32[$15>>2]|0;
   $430 = $$pre$i$i$i$i93;
  }
  $429 = (($430) + 24|0);
  HEAP32[$15>>2] = $429;
 }
 HEAP32[$0>>2] = 625800;
 $431 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $432 = (($0) + 4|0);
 HEAP32[$432>>2] = $431;
 $433 = (($0) + 8|0);
 $434 = $433;
 $435 = $434;
 HEAP32[$435>>2] = 10211;
 $436 = (($434) + 4)|0;
 $437 = $436;
 HEAP32[$437>>2] = 0;
 $438 = (__Z20GetPersistentManagerv()|0);
 $439 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($438,$1,10211,0)|0);
 $440 = (($0) + 16|0);
 HEAP32[$440>>2] = $439;
 $441 = (($0) + 20|0);
 HEAP8[$441>>0] = 0;
 $442 = HEAP32[$15>>2]|0;
 $443 = HEAP32[$17>>2]|0;
 $444 = ($442|0)==($443|0);
 if ($444) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $445 = ($442|0)==(0|0);
  if ($445) {
   $447 = 0;
  } else {
   ;HEAP32[$442+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$442+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$442+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$442+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$442+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$442+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i97 = HEAP32[$15>>2]|0;
   $447 = $$pre$i$i$i$i97;
  }
  $446 = (($447) + 24|0);
  HEAP32[$15>>2] = $446;
 }
 HEAP32[$0>>2] = 625816;
 $448 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $449 = (($0) + 4|0);
 HEAP32[$449>>2] = $448;
 $450 = (($0) + 8|0);
 $451 = $450;
 $452 = $451;
 HEAP32[$452>>2] = 10212;
 $453 = (($451) + 4)|0;
 $454 = $453;
 HEAP32[$454>>2] = 0;
 $455 = (__Z20GetPersistentManagerv()|0);
 $456 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($455,$1,10212,0)|0);
 $457 = (($0) + 16|0);
 HEAP32[$457>>2] = $456;
 $458 = (($0) + 20|0);
 HEAP8[$458>>0] = 0;
 $459 = HEAP32[$15>>2]|0;
 $460 = HEAP32[$17>>2]|0;
 $461 = ($459|0)==($460|0);
 if ($461) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $462 = ($459|0)==(0|0);
  if ($462) {
   $464 = 0;
  } else {
   ;HEAP32[$459+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$459+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$459+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$459+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$459+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$459+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i101 = HEAP32[$15>>2]|0;
   $464 = $$pre$i$i$i$i101;
  }
  $463 = (($464) + 24|0);
  HEAP32[$15>>2] = $463;
 }
 HEAP32[$0>>2] = 625832;
 $465 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $466 = (($0) + 4|0);
 HEAP32[$466>>2] = $465;
 $467 = (($0) + 8|0);
 $468 = $467;
 $469 = $468;
 HEAP32[$469>>2] = 10213;
 $470 = (($468) + 4)|0;
 $471 = $470;
 HEAP32[$471>>2] = 0;
 $472 = (__Z20GetPersistentManagerv()|0);
 $473 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($472,$1,10213,0)|0);
 $474 = (($0) + 16|0);
 HEAP32[$474>>2] = $473;
 $475 = (($0) + 20|0);
 HEAP8[$475>>0] = 0;
 $476 = HEAP32[$15>>2]|0;
 $477 = HEAP32[$17>>2]|0;
 $478 = ($476|0)==($477|0);
 if ($478) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $479 = ($476|0)==(0|0);
  if ($479) {
   $481 = 0;
  } else {
   ;HEAP32[$476+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$476+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$476+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$476+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$476+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$476+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i105 = HEAP32[$15>>2]|0;
   $481 = $$pre$i$i$i$i105;
  }
  $480 = (($481) + 24|0);
  HEAP32[$15>>2] = $480;
 }
 HEAP32[$0>>2] = 625848;
 $482 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $483 = (($0) + 4|0);
 HEAP32[$483>>2] = $482;
 $484 = (($0) + 8|0);
 $485 = $484;
 $486 = $485;
 HEAP32[$486>>2] = 10200;
 $487 = (($485) + 4)|0;
 $488 = $487;
 HEAP32[$488>>2] = 0;
 $489 = (__Z20GetPersistentManagerv()|0);
 $490 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($489,$1,10200,0)|0);
 $491 = (($0) + 16|0);
 HEAP32[$491>>2] = $490;
 $492 = (($0) + 20|0);
 HEAP8[$492>>0] = 0;
 $493 = HEAP32[$15>>2]|0;
 $494 = HEAP32[$17>>2]|0;
 $495 = ($493|0)==($494|0);
 if ($495) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $496 = ($493|0)==(0|0);
  if ($496) {
   $498 = 0;
  } else {
   ;HEAP32[$493+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$493+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$493+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$493+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$493+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$493+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i109 = HEAP32[$15>>2]|0;
   $498 = $$pre$i$i$i$i109;
  }
  $497 = (($498) + 24|0);
  HEAP32[$15>>2] = $497;
 }
 HEAP32[$0>>2] = 625864;
 $499 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $500 = (($0) + 4|0);
 HEAP32[$500>>2] = $499;
 $501 = (($0) + 8|0);
 $502 = $501;
 $503 = $502;
 HEAP32[$503>>2] = 10203;
 $504 = (($502) + 4)|0;
 $505 = $504;
 HEAP32[$505>>2] = 0;
 $506 = (__Z20GetPersistentManagerv()|0);
 $507 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($506,$1,10203,0)|0);
 $508 = (($0) + 16|0);
 HEAP32[$508>>2] = $507;
 $509 = (($0) + 20|0);
 HEAP8[$509>>0] = 0;
 $510 = HEAP32[$15>>2]|0;
 $511 = HEAP32[$17>>2]|0;
 $512 = ($510|0)==($511|0);
 if ($512) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $513 = ($510|0)==(0|0);
  if ($513) {
   $515 = 0;
  } else {
   ;HEAP32[$510+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$510+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$510+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$510+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$510+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$510+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i113 = HEAP32[$15>>2]|0;
   $515 = $$pre$i$i$i$i113;
  }
  $514 = (($515) + 24|0);
  HEAP32[$15>>2] = $514;
 }
 HEAP32[$0>>2] = 625880;
 $516 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $517 = (($0) + 4|0);
 HEAP32[$517>>2] = $516;
 $518 = (($0) + 8|0);
 $519 = $518;
 $520 = $519;
 HEAP32[$520>>2] = 10204;
 $521 = (($519) + 4)|0;
 $522 = $521;
 HEAP32[$522>>2] = 0;
 $523 = (__Z20GetPersistentManagerv()|0);
 $524 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($523,$1,10204,0)|0);
 $525 = (($0) + 16|0);
 HEAP32[$525>>2] = $524;
 $526 = (($0) + 20|0);
 HEAP8[$526>>0] = 0;
 $527 = HEAP32[$15>>2]|0;
 $528 = HEAP32[$17>>2]|0;
 $529 = ($527|0)==($528|0);
 if ($529) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $530 = ($527|0)==(0|0);
  if ($530) {
   $532 = 0;
  } else {
   ;HEAP32[$527+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$527+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$527+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$527+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$527+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$527+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i117 = HEAP32[$15>>2]|0;
   $532 = $$pre$i$i$i$i117;
  }
  $531 = (($532) + 24|0);
  HEAP32[$15>>2] = $531;
 }
 HEAP32[$0>>2] = 625896;
 $533 = (__ZN6Object15StringToClassIDEPKc(625704)|0);
 $534 = (($0) + 4|0);
 HEAP32[$534>>2] = $533;
 $535 = (($0) + 8|0);
 $536 = $535;
 $537 = $536;
 HEAP32[$537>>2] = 10205;
 $538 = (($536) + 4)|0;
 $539 = $538;
 HEAP32[$539>>2] = 0;
 $540 = (__Z20GetPersistentManagerv()|0);
 $541 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($540,$1,10205,0)|0);
 $542 = (($0) + 16|0);
 HEAP32[$542>>2] = $541;
 $543 = (($0) + 20|0);
 HEAP8[$543>>0] = 0;
 $544 = HEAP32[$15>>2]|0;
 $545 = HEAP32[$17>>2]|0;
 $546 = ($544|0)==($545|0);
 if ($546) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $547 = ($544|0)==(0|0);
  if ($547) {
   $549 = 0;
  } else {
   ;HEAP32[$544+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$544+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$544+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$544+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$544+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$544+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i121 = HEAP32[$15>>2]|0;
   $549 = $$pre$i$i$i$i121;
  }
  $548 = (($549) + 24|0);
  HEAP32[$15>>2] = $548;
 }
 HEAP32[$0>>2] = 625912;
 $550 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $551 = (($0) + 4|0);
 HEAP32[$551>>2] = $550;
 $552 = (($0) + 8|0);
 $553 = $552;
 $554 = $553;
 HEAP32[$554>>2] = 10400;
 $555 = (($553) + 4)|0;
 $556 = $555;
 HEAP32[$556>>2] = 0;
 $557 = (__Z20GetPersistentManagerv()|0);
 $558 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($557,$1,10400,0)|0);
 $559 = (($0) + 16|0);
 HEAP32[$559>>2] = $558;
 $560 = (($0) + 20|0);
 HEAP8[$560>>0] = 0;
 $561 = HEAP32[$15>>2]|0;
 $562 = HEAP32[$17>>2]|0;
 $563 = ($561|0)==($562|0);
 if ($563) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $564 = ($561|0)==(0|0);
  if ($564) {
   $566 = 0;
  } else {
   ;HEAP32[$561+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$561+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$561+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$561+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$561+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$561+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i125 = HEAP32[$15>>2]|0;
   $566 = $$pre$i$i$i$i125;
  }
  $565 = (($566) + 24|0);
  HEAP32[$15>>2] = $565;
 }
 HEAP32[$0>>2] = 625944;
 $567 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $568 = (($0) + 4|0);
 HEAP32[$568>>2] = $567;
 $569 = (($0) + 8|0);
 $570 = $569;
 $571 = $570;
 HEAP32[$571>>2] = 10401;
 $572 = (($570) + 4)|0;
 $573 = $572;
 HEAP32[$573>>2] = 0;
 $574 = (__Z20GetPersistentManagerv()|0);
 $575 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($574,$1,10401,0)|0);
 $576 = (($0) + 16|0);
 HEAP32[$576>>2] = $575;
 $577 = (($0) + 20|0);
 HEAP8[$577>>0] = 0;
 $578 = HEAP32[$15>>2]|0;
 $579 = HEAP32[$17>>2]|0;
 $580 = ($578|0)==($579|0);
 if ($580) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $581 = ($578|0)==(0|0);
  if ($581) {
   $583 = 0;
  } else {
   ;HEAP32[$578+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$578+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$578+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$578+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$578+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$578+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i129 = HEAP32[$15>>2]|0;
   $583 = $$pre$i$i$i$i129;
  }
  $582 = (($583) + 24|0);
  HEAP32[$15>>2] = $582;
 }
 HEAP32[$0>>2] = 625968;
 $584 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $585 = (($0) + 4|0);
 HEAP32[$585>>2] = $584;
 $586 = (($0) + 8|0);
 $587 = $586;
 $588 = $587;
 HEAP32[$588>>2] = 10402;
 $589 = (($587) + 4)|0;
 $590 = $589;
 HEAP32[$590>>2] = 0;
 $591 = (__Z20GetPersistentManagerv()|0);
 $592 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($591,$1,10402,0)|0);
 $593 = (($0) + 16|0);
 HEAP32[$593>>2] = $592;
 $594 = (($0) + 20|0);
 HEAP8[$594>>0] = 0;
 $595 = HEAP32[$15>>2]|0;
 $596 = HEAP32[$17>>2]|0;
 $597 = ($595|0)==($596|0);
 if ($597) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $598 = ($595|0)==(0|0);
  if ($598) {
   $600 = 0;
  } else {
   ;HEAP32[$595+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$595+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$595+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$595+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$595+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$595+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i133 = HEAP32[$15>>2]|0;
   $600 = $$pre$i$i$i$i133;
  }
  $599 = (($600) + 24|0);
  HEAP32[$15>>2] = $599;
 }
 HEAP32[$0>>2] = 625992;
 $601 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $602 = (($0) + 4|0);
 HEAP32[$602>>2] = $601;
 $603 = (($0) + 8|0);
 $604 = $603;
 $605 = $604;
 HEAP32[$605>>2] = 10407;
 $606 = (($604) + 4)|0;
 $607 = $606;
 HEAP32[$607>>2] = 0;
 $608 = (__Z20GetPersistentManagerv()|0);
 $609 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($608,$1,10407,0)|0);
 $610 = (($0) + 16|0);
 HEAP32[$610>>2] = $609;
 $611 = (($0) + 20|0);
 HEAP8[$611>>0] = 0;
 $612 = HEAP32[$15>>2]|0;
 $613 = HEAP32[$17>>2]|0;
 $614 = ($612|0)==($613|0);
 if ($614) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $615 = ($612|0)==(0|0);
  if ($615) {
   $617 = 0;
  } else {
   ;HEAP32[$612+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$612+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$612+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$612+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$612+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$612+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i137 = HEAP32[$15>>2]|0;
   $617 = $$pre$i$i$i$i137;
  }
  $616 = (($617) + 24|0);
  HEAP32[$15>>2] = $616;
 }
 HEAP32[$0>>2] = 626024;
 $618 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $619 = (($0) + 4|0);
 HEAP32[$619>>2] = $618;
 $620 = (($0) + 8|0);
 $621 = $620;
 $622 = $621;
 HEAP32[$622>>2] = 10408;
 $623 = (($621) + 4)|0;
 $624 = $623;
 HEAP32[$624>>2] = 0;
 $625 = (__Z20GetPersistentManagerv()|0);
 $626 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($625,$1,10408,0)|0);
 $627 = (($0) + 16|0);
 HEAP32[$627>>2] = $626;
 $628 = (($0) + 20|0);
 HEAP8[$628>>0] = 0;
 $629 = HEAP32[$15>>2]|0;
 $630 = HEAP32[$17>>2]|0;
 $631 = ($629|0)==($630|0);
 if ($631) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $632 = ($629|0)==(0|0);
  if ($632) {
   $634 = 0;
  } else {
   ;HEAP32[$629+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$629+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$629+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$629+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$629+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$629+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i141 = HEAP32[$15>>2]|0;
   $634 = $$pre$i$i$i$i141;
  }
  $633 = (($634) + 24|0);
  HEAP32[$15>>2] = $633;
 }
 HEAP32[$0>>2] = 626048;
 $635 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $636 = (($0) + 4|0);
 HEAP32[$636>>2] = $635;
 $637 = (($0) + 8|0);
 $638 = $637;
 $639 = $638;
 HEAP32[$639>>2] = 10409;
 $640 = (($638) + 4)|0;
 $641 = $640;
 HEAP32[$641>>2] = 0;
 $642 = (__Z20GetPersistentManagerv()|0);
 $643 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($642,$1,10409,0)|0);
 $644 = (($0) + 16|0);
 HEAP32[$644>>2] = $643;
 $645 = (($0) + 20|0);
 HEAP8[$645>>0] = 0;
 $646 = HEAP32[$15>>2]|0;
 $647 = HEAP32[$17>>2]|0;
 $648 = ($646|0)==($647|0);
 if ($648) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $649 = ($646|0)==(0|0);
  if ($649) {
   $651 = 0;
  } else {
   ;HEAP32[$646+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$646+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$646+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$646+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$646+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$646+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i145 = HEAP32[$15>>2]|0;
   $651 = $$pre$i$i$i$i145;
  }
  $650 = (($651) + 24|0);
  HEAP32[$15>>2] = $650;
 }
 HEAP32[$0>>2] = 626072;
 $652 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $653 = (($0) + 4|0);
 HEAP32[$653>>2] = $652;
 $654 = (($0) + 8|0);
 $655 = $654;
 $656 = $655;
 HEAP32[$656>>2] = 10410;
 $657 = (($655) + 4)|0;
 $658 = $657;
 HEAP32[$658>>2] = 0;
 $659 = (__Z20GetPersistentManagerv()|0);
 $660 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($659,$1,10410,0)|0);
 $661 = (($0) + 16|0);
 HEAP32[$661>>2] = $660;
 $662 = (($0) + 20|0);
 HEAP8[$662>>0] = 0;
 $663 = HEAP32[$15>>2]|0;
 $664 = HEAP32[$17>>2]|0;
 $665 = ($663|0)==($664|0);
 if ($665) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $666 = ($663|0)==(0|0);
  if ($666) {
   $668 = 0;
  } else {
   ;HEAP32[$663+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$663+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$663+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$663+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$663+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$663+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i149 = HEAP32[$15>>2]|0;
   $668 = $$pre$i$i$i$i149;
  }
  $667 = (($668) + 24|0);
  HEAP32[$15>>2] = $667;
 }
 HEAP32[$0>>2] = 626096;
 $669 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $670 = (($0) + 4|0);
 HEAP32[$670>>2] = $669;
 $671 = (($0) + 8|0);
 $672 = $671;
 $673 = $672;
 HEAP32[$673>>2] = 10411;
 $674 = (($672) + 4)|0;
 $675 = $674;
 HEAP32[$675>>2] = 0;
 $676 = (__Z20GetPersistentManagerv()|0);
 $677 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($676,$1,10411,0)|0);
 $678 = (($0) + 16|0);
 HEAP32[$678>>2] = $677;
 $679 = (($0) + 20|0);
 HEAP8[$679>>0] = 0;
 $680 = HEAP32[$15>>2]|0;
 $681 = HEAP32[$17>>2]|0;
 $682 = ($680|0)==($681|0);
 if ($682) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $683 = ($680|0)==(0|0);
  if ($683) {
   $685 = 0;
  } else {
   ;HEAP32[$680+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$680+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$680+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$680+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$680+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$680+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i153 = HEAP32[$15>>2]|0;
   $685 = $$pre$i$i$i$i153;
  }
  $684 = (($685) + 24|0);
  HEAP32[$15>>2] = $684;
 }
 HEAP32[$0>>2] = 626112;
 $686 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $687 = (($0) + 4|0);
 HEAP32[$687>>2] = $686;
 $688 = (($0) + 8|0);
 $689 = $688;
 $690 = $689;
 HEAP32[$690>>2] = 10413;
 $691 = (($689) + 4)|0;
 $692 = $691;
 HEAP32[$692>>2] = 0;
 $693 = (__Z20GetPersistentManagerv()|0);
 $694 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($693,$1,10413,0)|0);
 $695 = (($0) + 16|0);
 HEAP32[$695>>2] = $694;
 $696 = (($0) + 20|0);
 HEAP8[$696>>0] = 0;
 $697 = HEAP32[$15>>2]|0;
 $698 = HEAP32[$17>>2]|0;
 $699 = ($697|0)==($698|0);
 if ($699) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $700 = ($697|0)==(0|0);
  if ($700) {
   $702 = 0;
  } else {
   ;HEAP32[$697+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$697+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$697+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$697+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$697+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$697+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i157 = HEAP32[$15>>2]|0;
   $702 = $$pre$i$i$i$i157;
  }
  $701 = (($702) + 24|0);
  HEAP32[$15>>2] = $701;
 }
 HEAP32[$0>>2] = 626144;
 $703 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $704 = (($0) + 4|0);
 HEAP32[$704>>2] = $703;
 $705 = (($0) + 8|0);
 $706 = $705;
 $707 = $706;
 HEAP32[$707>>2] = 10414;
 $708 = (($706) + 4)|0;
 $709 = $708;
 HEAP32[$709>>2] = 0;
 $710 = (__Z20GetPersistentManagerv()|0);
 $711 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($710,$1,10414,0)|0);
 $712 = (($0) + 16|0);
 HEAP32[$712>>2] = $711;
 $713 = (($0) + 20|0);
 HEAP8[$713>>0] = 0;
 $714 = HEAP32[$15>>2]|0;
 $715 = HEAP32[$17>>2]|0;
 $716 = ($714|0)==($715|0);
 if ($716) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $717 = ($714|0)==(0|0);
  if ($717) {
   $719 = 0;
  } else {
   ;HEAP32[$714+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$714+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$714+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$714+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$714+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$714+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i161 = HEAP32[$15>>2]|0;
   $719 = $$pre$i$i$i$i161;
  }
  $718 = (($719) + 24|0);
  HEAP32[$15>>2] = $718;
 }
 HEAP32[$0>>2] = 626176;
 $720 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $721 = (($0) + 4|0);
 HEAP32[$721>>2] = $720;
 $722 = (($0) + 8|0);
 $723 = $722;
 $724 = $723;
 HEAP32[$724>>2] = 10403;
 $725 = (($723) + 4)|0;
 $726 = $725;
 HEAP32[$726>>2] = 0;
 $727 = (__Z20GetPersistentManagerv()|0);
 $728 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($727,$1,10403,0)|0);
 $729 = (($0) + 16|0);
 HEAP32[$729>>2] = $728;
 $730 = (($0) + 20|0);
 HEAP8[$730>>0] = 0;
 $731 = HEAP32[$15>>2]|0;
 $732 = HEAP32[$17>>2]|0;
 $733 = ($731|0)==($732|0);
 if ($733) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $734 = ($731|0)==(0|0);
  if ($734) {
   $736 = 0;
  } else {
   ;HEAP32[$731+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$731+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$731+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$731+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$731+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$731+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i165 = HEAP32[$15>>2]|0;
   $736 = $$pre$i$i$i$i165;
  }
  $735 = (($736) + 24|0);
  HEAP32[$15>>2] = $735;
 }
 HEAP32[$0>>2] = 626192;
 $737 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $738 = (($0) + 4|0);
 HEAP32[$738>>2] = $737;
 $739 = (($0) + 8|0);
 $740 = $739;
 $741 = $740;
 HEAP32[$741>>2] = 10404;
 $742 = (($740) + 4)|0;
 $743 = $742;
 HEAP32[$743>>2] = 0;
 $744 = (__Z20GetPersistentManagerv()|0);
 $745 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($744,$1,10404,0)|0);
 $746 = (($0) + 16|0);
 HEAP32[$746>>2] = $745;
 $747 = (($0) + 20|0);
 HEAP8[$747>>0] = 0;
 $748 = HEAP32[$15>>2]|0;
 $749 = HEAP32[$17>>2]|0;
 $750 = ($748|0)==($749|0);
 if ($750) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $751 = ($748|0)==(0|0);
  if ($751) {
   $753 = 0;
  } else {
   ;HEAP32[$748+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$748+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$748+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$748+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$748+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$748+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i169 = HEAP32[$15>>2]|0;
   $753 = $$pre$i$i$i$i169;
  }
  $752 = (($753) + 24|0);
  HEAP32[$15>>2] = $752;
 }
 HEAP32[$0>>2] = 626216;
 $754 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $755 = (($0) + 4|0);
 HEAP32[$755>>2] = $754;
 $756 = (($0) + 8|0);
 $757 = $756;
 $758 = $757;
 HEAP32[$758>>2] = 10406;
 $759 = (($757) + 4)|0;
 $760 = $759;
 HEAP32[$760>>2] = 0;
 $761 = (__Z20GetPersistentManagerv()|0);
 $762 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($761,$1,10406,0)|0);
 $763 = (($0) + 16|0);
 HEAP32[$763>>2] = $762;
 $764 = (($0) + 20|0);
 HEAP8[$764>>0] = 0;
 $765 = HEAP32[$15>>2]|0;
 $766 = HEAP32[$17>>2]|0;
 $767 = ($765|0)==($766|0);
 if ($767) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $768 = ($765|0)==(0|0);
  if ($768) {
   $770 = 0;
  } else {
   ;HEAP32[$765+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$765+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$765+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$765+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$765+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$765+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i173 = HEAP32[$15>>2]|0;
   $770 = $$pre$i$i$i$i173;
  }
  $769 = (($770) + 24|0);
  HEAP32[$15>>2] = $769;
 }
 HEAP32[$0>>2] = 626240;
 $771 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $772 = (($0) + 4|0);
 HEAP32[$772>>2] = $771;
 $773 = (($0) + 8|0);
 $774 = $773;
 $775 = $774;
 HEAP32[$775>>2] = 10753;
 $776 = (($774) + 4)|0;
 $777 = $776;
 HEAP32[$777>>2] = 0;
 $778 = (__Z20GetPersistentManagerv()|0);
 $779 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($778,$1,10753,0)|0);
 $780 = (($0) + 16|0);
 HEAP32[$780>>2] = $779;
 $781 = (($0) + 20|0);
 HEAP8[$781>>0] = 1;
 $782 = HEAP32[$15>>2]|0;
 $783 = HEAP32[$17>>2]|0;
 $784 = ($782|0)==($783|0);
 if ($784) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $785 = ($782|0)==(0|0);
  if ($785) {
   $787 = 0;
  } else {
   ;HEAP32[$782+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$782+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$782+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$782+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$782+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$782+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i177 = HEAP32[$15>>2]|0;
   $787 = $$pre$i$i$i$i177;
  }
  $786 = (($787) + 24|0);
  HEAP32[$15>>2] = $786;
 }
 HEAP32[$0>>2] = 626264;
 $788 = (__ZN6Object15StringToClassIDEPKc(625648)|0);
 $789 = (($0) + 4|0);
 HEAP32[$789>>2] = $788;
 $790 = (($0) + 8|0);
 $791 = $790;
 $792 = $791;
 HEAP32[$792>>2] = 10754;
 $793 = (($791) + 4)|0;
 $794 = $793;
 HEAP32[$794>>2] = 0;
 $795 = (__Z20GetPersistentManagerv()|0);
 $796 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($795,$1,10754,0)|0);
 $797 = (($0) + 16|0);
 HEAP32[$797>>2] = $796;
 $798 = (($0) + 20|0);
 HEAP8[$798>>0] = 1;
 $799 = HEAP32[$15>>2]|0;
 $800 = HEAP32[$17>>2]|0;
 $801 = ($799|0)==($800|0);
 if ($801) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $802 = ($799|0)==(0|0);
  if ($802) {
   $804 = 0;
  } else {
   ;HEAP32[$799+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$799+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$799+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$799+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$799+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$799+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i181 = HEAP32[$15>>2]|0;
   $804 = $$pre$i$i$i$i181;
  }
  $803 = (($804) + 24|0);
  HEAP32[$15>>2] = $803;
 }
 HEAP32[$0>>2] = 626288;
 $805 = (__ZN6Object15StringToClassIDEPKc(626320)|0);
 $806 = (($0) + 4|0);
 HEAP32[$806>>2] = $805;
 $807 = (($0) + 8|0);
 $808 = $807;
 $809 = $808;
 HEAP32[$809>>2] = 11000;
 $810 = (($808) + 4)|0;
 $811 = $810;
 HEAP32[$811>>2] = 0;
 $812 = (__Z20GetPersistentManagerv()|0);
 $813 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($812,$1,11000,0)|0);
 $814 = (($0) + 16|0);
 HEAP32[$814>>2] = $813;
 $815 = (($0) + 20|0);
 HEAP8[$815>>0] = 0;
 $816 = HEAP32[$15>>2]|0;
 $817 = HEAP32[$17>>2]|0;
 $818 = ($816|0)==($817|0);
 if ($818) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $819 = ($816|0)==(0|0);
  if ($819) {
   $821 = 0;
  } else {
   ;HEAP32[$816+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$816+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$816+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$816+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$816+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$816+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i185 = HEAP32[$15>>2]|0;
   $821 = $$pre$i$i$i$i185;
  }
  $820 = (($821) + 24|0);
  HEAP32[$15>>2] = $820;
 }
 HEAP32[$0>>2] = 626336;
 $822 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $823 = (($0) + 4|0);
 HEAP32[$823>>2] = $822;
 $824 = (($0) + 8|0);
 $825 = $824;
 $826 = $825;
 HEAP32[$826>>2] = 11001;
 $827 = (($825) + 4)|0;
 $828 = $827;
 HEAP32[$828>>2] = 0;
 $829 = (__Z20GetPersistentManagerv()|0);
 $830 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($829,$1,11001,0)|0);
 $831 = (($0) + 16|0);
 HEAP32[$831>>2] = $830;
 $832 = (($0) + 20|0);
 HEAP8[$832>>0] = 0;
 $833 = HEAP32[$15>>2]|0;
 $834 = HEAP32[$17>>2]|0;
 $835 = ($833|0)==($834|0);
 if ($835) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $836 = ($833|0)==(0|0);
  if ($836) {
   $838 = 0;
  } else {
   ;HEAP32[$833+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$833+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$833+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$833+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$833+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$833+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i189 = HEAP32[$15>>2]|0;
   $838 = $$pre$i$i$i$i189;
  }
  $837 = (($838) + 24|0);
  HEAP32[$15>>2] = $837;
 }
 HEAP32[$0>>2] = 626360;
 $839 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $840 = (($0) + 4|0);
 HEAP32[$840>>2] = $839;
 $841 = (($0) + 8|0);
 $842 = $841;
 $843 = $842;
 HEAP32[$843>>2] = 11002;
 $844 = (($842) + 4)|0;
 $845 = $844;
 HEAP32[$845>>2] = 0;
 $846 = (__Z20GetPersistentManagerv()|0);
 $847 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($846,$1,11002,0)|0);
 $848 = (($0) + 16|0);
 HEAP32[$848>>2] = $847;
 $849 = (($0) + 20|0);
 HEAP8[$849>>0] = 0;
 $850 = HEAP32[$15>>2]|0;
 $851 = HEAP32[$17>>2]|0;
 $852 = ($850|0)==($851|0);
 if ($852) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $853 = ($850|0)==(0|0);
  if ($853) {
   $855 = 0;
  } else {
   ;HEAP32[$850+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$850+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$850+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$850+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$850+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$850+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i193 = HEAP32[$15>>2]|0;
   $855 = $$pre$i$i$i$i193;
  }
  $854 = (($855) + 24|0);
  HEAP32[$15>>2] = $854;
 }
 HEAP32[$0>>2] = 626392;
 $856 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $857 = (($0) + 4|0);
 HEAP32[$857>>2] = $856;
 $858 = (($0) + 8|0);
 $859 = $858;
 $860 = $859;
 HEAP32[$860>>2] = 11003;
 $861 = (($859) + 4)|0;
 $862 = $861;
 HEAP32[$862>>2] = 0;
 $863 = (__Z20GetPersistentManagerv()|0);
 $864 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($863,$1,11003,0)|0);
 $865 = (($0) + 16|0);
 HEAP32[$865>>2] = $864;
 $866 = (($0) + 20|0);
 HEAP8[$866>>0] = 0;
 $867 = HEAP32[$15>>2]|0;
 $868 = HEAP32[$17>>2]|0;
 $869 = ($867|0)==($868|0);
 if ($869) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $870 = ($867|0)==(0|0);
  if ($870) {
   $872 = 0;
  } else {
   ;HEAP32[$867+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$867+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$867+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$867+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$867+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$867+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i197 = HEAP32[$15>>2]|0;
   $872 = $$pre$i$i$i$i197;
  }
  $871 = (($872) + 24|0);
  HEAP32[$15>>2] = $871;
 }
 HEAP32[$0>>2] = 626424;
 $873 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $874 = (($0) + 4|0);
 HEAP32[$874>>2] = $873;
 $875 = (($0) + 8|0);
 $876 = $875;
 $877 = $876;
 HEAP32[$877>>2] = 11004;
 $878 = (($876) + 4)|0;
 $879 = $878;
 HEAP32[$879>>2] = 0;
 $880 = (__Z20GetPersistentManagerv()|0);
 $881 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($880,$1,11004,0)|0);
 $882 = (($0) + 16|0);
 HEAP32[$882>>2] = $881;
 $883 = (($0) + 20|0);
 HEAP8[$883>>0] = 0;
 $884 = HEAP32[$15>>2]|0;
 $885 = HEAP32[$17>>2]|0;
 $886 = ($884|0)==($885|0);
 if ($886) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $887 = ($884|0)==(0|0);
  if ($887) {
   $889 = 0;
  } else {
   ;HEAP32[$884+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$884+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$884+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$884+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$884+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$884+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i201 = HEAP32[$15>>2]|0;
   $889 = $$pre$i$i$i$i201;
  }
  $888 = (($889) + 24|0);
  HEAP32[$15>>2] = $888;
 }
 HEAP32[$0>>2] = 626456;
 $890 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $891 = (($0) + 4|0);
 HEAP32[$891>>2] = $890;
 $892 = (($0) + 8|0);
 $893 = $892;
 $894 = $893;
 HEAP32[$894>>2] = 11005;
 $895 = (($893) + 4)|0;
 $896 = $895;
 HEAP32[$896>>2] = 0;
 $897 = (__Z20GetPersistentManagerv()|0);
 $898 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($897,$1,11005,0)|0);
 $899 = (($0) + 16|0);
 HEAP32[$899>>2] = $898;
 $900 = (($0) + 20|0);
 HEAP8[$900>>0] = 0;
 $901 = HEAP32[$15>>2]|0;
 $902 = HEAP32[$17>>2]|0;
 $903 = ($901|0)==($902|0);
 if ($903) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $904 = ($901|0)==(0|0);
  if ($904) {
   $906 = 0;
  } else {
   ;HEAP32[$901+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$901+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$901+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$901+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$901+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$901+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i205 = HEAP32[$15>>2]|0;
   $906 = $$pre$i$i$i$i205;
  }
  $905 = (($906) + 24|0);
  HEAP32[$15>>2] = $905;
 }
 HEAP32[$0>>2] = 626480;
 $907 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $908 = (($0) + 4|0);
 HEAP32[$908>>2] = $907;
 $909 = (($0) + 8|0);
 $910 = $909;
 $911 = $910;
 HEAP32[$911>>2] = 11006;
 $912 = (($910) + 4)|0;
 $913 = $912;
 HEAP32[$913>>2] = 0;
 $914 = (__Z20GetPersistentManagerv()|0);
 $915 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($914,$1,11006,0)|0);
 $916 = (($0) + 16|0);
 HEAP32[$916>>2] = $915;
 $917 = (($0) + 20|0);
 HEAP8[$917>>0] = 0;
 $918 = HEAP32[$15>>2]|0;
 $919 = HEAP32[$17>>2]|0;
 $920 = ($918|0)==($919|0);
 if ($920) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $921 = ($918|0)==(0|0);
  if ($921) {
   $923 = 0;
  } else {
   ;HEAP32[$918+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$918+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$918+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$918+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$918+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$918+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i209 = HEAP32[$15>>2]|0;
   $923 = $$pre$i$i$i$i209;
  }
  $922 = (($923) + 24|0);
  HEAP32[$15>>2] = $922;
 }
 HEAP32[$0>>2] = 626504;
 $924 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $925 = (($0) + 4|0);
 HEAP32[$925>>2] = $924;
 $926 = (($0) + 8|0);
 $927 = $926;
 $928 = $927;
 HEAP32[$928>>2] = 11007;
 $929 = (($927) + 4)|0;
 $930 = $929;
 HEAP32[$930>>2] = 0;
 $931 = (__Z20GetPersistentManagerv()|0);
 $932 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($931,$1,11007,0)|0);
 $933 = (($0) + 16|0);
 HEAP32[$933>>2] = $932;
 $934 = (($0) + 20|0);
 HEAP8[$934>>0] = 0;
 $935 = HEAP32[$15>>2]|0;
 $936 = HEAP32[$17>>2]|0;
 $937 = ($935|0)==($936|0);
 if ($937) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $938 = ($935|0)==(0|0);
  if ($938) {
   $940 = 0;
  } else {
   ;HEAP32[$935+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$935+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$935+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$935+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$935+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$935+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i213 = HEAP32[$15>>2]|0;
   $940 = $$pre$i$i$i$i213;
  }
  $939 = (($940) + 24|0);
  HEAP32[$15>>2] = $939;
 }
 HEAP32[$0>>2] = 626544;
 $941 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $942 = (($0) + 4|0);
 HEAP32[$942>>2] = $941;
 $943 = (($0) + 8|0);
 $944 = $943;
 $945 = $944;
 HEAP32[$945>>2] = 11008;
 $946 = (($944) + 4)|0;
 $947 = $946;
 HEAP32[$947>>2] = 0;
 $948 = (__Z20GetPersistentManagerv()|0);
 $949 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($948,$1,11008,0)|0);
 $950 = (($0) + 16|0);
 HEAP32[$950>>2] = $949;
 $951 = (($0) + 20|0);
 HEAP8[$951>>0] = 0;
 $952 = HEAP32[$15>>2]|0;
 $953 = HEAP32[$17>>2]|0;
 $954 = ($952|0)==($953|0);
 if ($954) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $955 = ($952|0)==(0|0);
  if ($955) {
   $957 = 0;
  } else {
   ;HEAP32[$952+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$952+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$952+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$952+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$952+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$952+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i217 = HEAP32[$15>>2]|0;
   $957 = $$pre$i$i$i$i217;
  }
  $956 = (($957) + 24|0);
  HEAP32[$15>>2] = $956;
 }
 HEAP32[$0>>2] = 626584;
 $958 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $959 = (($0) + 4|0);
 HEAP32[$959>>2] = $958;
 $960 = (($0) + 8|0);
 $961 = $960;
 $962 = $961;
 HEAP32[$962>>2] = 11009;
 $963 = (($961) + 4)|0;
 $964 = $963;
 HEAP32[$964>>2] = 0;
 $965 = (__Z20GetPersistentManagerv()|0);
 $966 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($965,$1,11009,0)|0);
 $967 = (($0) + 16|0);
 HEAP32[$967>>2] = $966;
 $968 = (($0) + 20|0);
 HEAP8[$968>>0] = 0;
 $969 = HEAP32[$15>>2]|0;
 $970 = HEAP32[$17>>2]|0;
 $971 = ($969|0)==($970|0);
 if ($971) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $972 = ($969|0)==(0|0);
  if ($972) {
   $974 = 0;
  } else {
   ;HEAP32[$969+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$969+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$969+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$969+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$969+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$969+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i221 = HEAP32[$15>>2]|0;
   $974 = $$pre$i$i$i$i221;
  }
  $973 = (($974) + 24|0);
  HEAP32[$15>>2] = $973;
 }
 HEAP32[$0>>2] = 626616;
 $975 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $976 = (($0) + 4|0);
 HEAP32[$976>>2] = $975;
 $977 = (($0) + 8|0);
 $978 = $977;
 $979 = $978;
 HEAP32[$979>>2] = 11010;
 $980 = (($978) + 4)|0;
 $981 = $980;
 HEAP32[$981>>2] = 0;
 $982 = (__Z20GetPersistentManagerv()|0);
 $983 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($982,$1,11010,0)|0);
 $984 = (($0) + 16|0);
 HEAP32[$984>>2] = $983;
 $985 = (($0) + 20|0);
 HEAP8[$985>>0] = 0;
 $986 = HEAP32[$15>>2]|0;
 $987 = HEAP32[$17>>2]|0;
 $988 = ($986|0)==($987|0);
 if ($988) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $989 = ($986|0)==(0|0);
  if ($989) {
   $991 = 0;
  } else {
   ;HEAP32[$986+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$986+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$986+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$986+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$986+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$986+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i225 = HEAP32[$15>>2]|0;
   $991 = $$pre$i$i$i$i225;
  }
  $990 = (($991) + 24|0);
  HEAP32[$15>>2] = $990;
 }
 HEAP32[$0>>2] = 626656;
 $992 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $993 = (($0) + 4|0);
 HEAP32[$993>>2] = $992;
 $994 = (($0) + 8|0);
 $995 = $994;
 $996 = $995;
 HEAP32[$996>>2] = 11011;
 $997 = (($995) + 4)|0;
 $998 = $997;
 HEAP32[$998>>2] = 0;
 $999 = (__Z20GetPersistentManagerv()|0);
 $1000 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($999,$1,11011,0)|0);
 $1001 = (($0) + 16|0);
 HEAP32[$1001>>2] = $1000;
 $1002 = (($0) + 20|0);
 HEAP8[$1002>>0] = 0;
 $1003 = HEAP32[$15>>2]|0;
 $1004 = HEAP32[$17>>2]|0;
 $1005 = ($1003|0)==($1004|0);
 if ($1005) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1006 = ($1003|0)==(0|0);
  if ($1006) {
   $1008 = 0;
  } else {
   ;HEAP32[$1003+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1003+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1003+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1003+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1003+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1003+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i229 = HEAP32[$15>>2]|0;
   $1008 = $$pre$i$i$i$i229;
  }
  $1007 = (($1008) + 24|0);
  HEAP32[$15>>2] = $1007;
 }
 HEAP32[$0>>2] = 626688;
 $1009 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1010 = (($0) + 4|0);
 HEAP32[$1010>>2] = $1009;
 $1011 = (($0) + 8|0);
 $1012 = $1011;
 $1013 = $1012;
 HEAP32[$1013>>2] = 11012;
 $1014 = (($1012) + 4)|0;
 $1015 = $1014;
 HEAP32[$1015>>2] = 0;
 $1016 = (__Z20GetPersistentManagerv()|0);
 $1017 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1016,$1,11012,0)|0);
 $1018 = (($0) + 16|0);
 HEAP32[$1018>>2] = $1017;
 $1019 = (($0) + 20|0);
 HEAP8[$1019>>0] = 0;
 $1020 = HEAP32[$15>>2]|0;
 $1021 = HEAP32[$17>>2]|0;
 $1022 = ($1020|0)==($1021|0);
 if ($1022) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1023 = ($1020|0)==(0|0);
  if ($1023) {
   $1025 = 0;
  } else {
   ;HEAP32[$1020+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1020+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1020+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1020+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1020+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1020+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i233 = HEAP32[$15>>2]|0;
   $1025 = $$pre$i$i$i$i233;
  }
  $1024 = (($1025) + 24|0);
  HEAP32[$15>>2] = $1024;
 }
 HEAP32[$0>>2] = 626720;
 $1026 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1027 = (($0) + 4|0);
 HEAP32[$1027>>2] = $1026;
 $1028 = (($0) + 8|0);
 $1029 = $1028;
 $1030 = $1029;
 HEAP32[$1030>>2] = 11013;
 $1031 = (($1029) + 4)|0;
 $1032 = $1031;
 HEAP32[$1032>>2] = 0;
 $1033 = (__Z20GetPersistentManagerv()|0);
 $1034 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1033,$1,11013,0)|0);
 $1035 = (($0) + 16|0);
 HEAP32[$1035>>2] = $1034;
 $1036 = (($0) + 20|0);
 HEAP8[$1036>>0] = 0;
 $1037 = HEAP32[$15>>2]|0;
 $1038 = HEAP32[$17>>2]|0;
 $1039 = ($1037|0)==($1038|0);
 if ($1039) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1040 = ($1037|0)==(0|0);
  if ($1040) {
   $1042 = 0;
  } else {
   ;HEAP32[$1037+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1037+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1037+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1037+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1037+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1037+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i237 = HEAP32[$15>>2]|0;
   $1042 = $$pre$i$i$i$i237;
  }
  $1041 = (($1042) + 24|0);
  HEAP32[$15>>2] = $1041;
 }
 HEAP32[$0>>2] = 626752;
 $1043 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1044 = (($0) + 4|0);
 HEAP32[$1044>>2] = $1043;
 $1045 = (($0) + 8|0);
 $1046 = $1045;
 $1047 = $1046;
 HEAP32[$1047>>2] = 11014;
 $1048 = (($1046) + 4)|0;
 $1049 = $1048;
 HEAP32[$1049>>2] = 0;
 $1050 = (__Z20GetPersistentManagerv()|0);
 $1051 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1050,$1,11014,0)|0);
 $1052 = (($0) + 16|0);
 HEAP32[$1052>>2] = $1051;
 $1053 = (($0) + 20|0);
 HEAP8[$1053>>0] = 0;
 $1054 = HEAP32[$15>>2]|0;
 $1055 = HEAP32[$17>>2]|0;
 $1056 = ($1054|0)==($1055|0);
 if ($1056) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1057 = ($1054|0)==(0|0);
  if ($1057) {
   $1059 = 0;
  } else {
   ;HEAP32[$1054+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1054+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1054+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1054+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1054+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1054+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i241 = HEAP32[$15>>2]|0;
   $1059 = $$pre$i$i$i$i241;
  }
  $1058 = (($1059) + 24|0);
  HEAP32[$15>>2] = $1058;
 }
 HEAP32[$0>>2] = 626784;
 $1060 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1061 = (($0) + 4|0);
 HEAP32[$1061>>2] = $1060;
 $1062 = (($0) + 8|0);
 $1063 = $1062;
 $1064 = $1063;
 HEAP32[$1064>>2] = 11015;
 $1065 = (($1063) + 4)|0;
 $1066 = $1065;
 HEAP32[$1066>>2] = 0;
 $1067 = (__Z20GetPersistentManagerv()|0);
 $1068 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1067,$1,11015,0)|0);
 $1069 = (($0) + 16|0);
 HEAP32[$1069>>2] = $1068;
 $1070 = (($0) + 20|0);
 HEAP8[$1070>>0] = 0;
 $1071 = HEAP32[$15>>2]|0;
 $1072 = HEAP32[$17>>2]|0;
 $1073 = ($1071|0)==($1072|0);
 if ($1073) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1074 = ($1071|0)==(0|0);
  if ($1074) {
   $1076 = 0;
  } else {
   ;HEAP32[$1071+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1071+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1071+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1071+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1071+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1071+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i245 = HEAP32[$15>>2]|0;
   $1076 = $$pre$i$i$i$i245;
  }
  $1075 = (($1076) + 24|0);
  HEAP32[$15>>2] = $1075;
 }
 HEAP32[$0>>2] = 626816;
 $1077 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1078 = (($0) + 4|0);
 HEAP32[$1078>>2] = $1077;
 $1079 = (($0) + 8|0);
 $1080 = $1079;
 $1081 = $1080;
 HEAP32[$1081>>2] = 11016;
 $1082 = (($1080) + 4)|0;
 $1083 = $1082;
 HEAP32[$1083>>2] = 0;
 $1084 = (__Z20GetPersistentManagerv()|0);
 $1085 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1084,$1,11016,0)|0);
 $1086 = (($0) + 16|0);
 HEAP32[$1086>>2] = $1085;
 $1087 = (($0) + 20|0);
 HEAP8[$1087>>0] = 0;
 $1088 = HEAP32[$15>>2]|0;
 $1089 = HEAP32[$17>>2]|0;
 $1090 = ($1088|0)==($1089|0);
 if ($1090) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1091 = ($1088|0)==(0|0);
  if ($1091) {
   $1093 = 0;
  } else {
   ;HEAP32[$1088+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1088+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1088+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1088+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1088+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1088+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i249 = HEAP32[$15>>2]|0;
   $1093 = $$pre$i$i$i$i249;
  }
  $1092 = (($1093) + 24|0);
  HEAP32[$15>>2] = $1092;
 }
 HEAP32[$0>>2] = 626840;
 $1094 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1095 = (($0) + 4|0);
 HEAP32[$1095>>2] = $1094;
 $1096 = (($0) + 8|0);
 $1097 = $1096;
 $1098 = $1097;
 HEAP32[$1098>>2] = 11017;
 $1099 = (($1097) + 4)|0;
 $1100 = $1099;
 HEAP32[$1100>>2] = 0;
 $1101 = (__Z20GetPersistentManagerv()|0);
 $1102 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1101,$1,11017,0)|0);
 $1103 = (($0) + 16|0);
 HEAP32[$1103>>2] = $1102;
 $1104 = (($0) + 20|0);
 HEAP8[$1104>>0] = 0;
 $1105 = HEAP32[$15>>2]|0;
 $1106 = HEAP32[$17>>2]|0;
 $1107 = ($1105|0)==($1106|0);
 if ($1107) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1108 = ($1105|0)==(0|0);
  if ($1108) {
   $1110 = 0;
  } else {
   ;HEAP32[$1105+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1105+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1105+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1105+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1105+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1105+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i253 = HEAP32[$15>>2]|0;
   $1110 = $$pre$i$i$i$i253;
  }
  $1109 = (($1110) + 24|0);
  HEAP32[$15>>2] = $1109;
 }
 HEAP32[$0>>2] = 626872;
 $1111 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1112 = (($0) + 4|0);
 HEAP32[$1112>>2] = $1111;
 $1113 = (($0) + 8|0);
 $1114 = $1113;
 $1115 = $1114;
 HEAP32[$1115>>2] = 11018;
 $1116 = (($1114) + 4)|0;
 $1117 = $1116;
 HEAP32[$1117>>2] = 0;
 $1118 = (__Z20GetPersistentManagerv()|0);
 $1119 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1118,$1,11018,0)|0);
 $1120 = (($0) + 16|0);
 HEAP32[$1120>>2] = $1119;
 $1121 = (($0) + 20|0);
 HEAP8[$1121>>0] = 0;
 $1122 = HEAP32[$15>>2]|0;
 $1123 = HEAP32[$17>>2]|0;
 $1124 = ($1122|0)==($1123|0);
 if ($1124) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1125 = ($1122|0)==(0|0);
  if ($1125) {
   $1127 = 0;
  } else {
   ;HEAP32[$1122+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1122+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1122+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1122+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1122+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1122+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i257 = HEAP32[$15>>2]|0;
   $1127 = $$pre$i$i$i$i257;
  }
  $1126 = (($1127) + 24|0);
  HEAP32[$15>>2] = $1126;
 }
 HEAP32[$0>>2] = 626896;
 $1128 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1129 = (($0) + 4|0);
 HEAP32[$1129>>2] = $1128;
 $1130 = (($0) + 8|0);
 $1131 = $1130;
 $1132 = $1131;
 HEAP32[$1132>>2] = 11019;
 $1133 = (($1131) + 4)|0;
 $1134 = $1133;
 HEAP32[$1134>>2] = 0;
 $1135 = (__Z20GetPersistentManagerv()|0);
 $1136 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1135,$1,11019,0)|0);
 $1137 = (($0) + 16|0);
 HEAP32[$1137>>2] = $1136;
 $1138 = (($0) + 20|0);
 HEAP8[$1138>>0] = 0;
 $1139 = HEAP32[$15>>2]|0;
 $1140 = HEAP32[$17>>2]|0;
 $1141 = ($1139|0)==($1140|0);
 if ($1141) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1142 = ($1139|0)==(0|0);
  if ($1142) {
   $1144 = 0;
  } else {
   ;HEAP32[$1139+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1139+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1139+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1139+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1139+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1139+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i261 = HEAP32[$15>>2]|0;
   $1144 = $$pre$i$i$i$i261;
  }
  $1143 = (($1144) + 24|0);
  HEAP32[$15>>2] = $1143;
 }
 HEAP32[$0>>2] = 626936;
 $1145 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1146 = (($0) + 4|0);
 HEAP32[$1146>>2] = $1145;
 $1147 = (($0) + 8|0);
 $1148 = $1147;
 $1149 = $1148;
 HEAP32[$1149>>2] = 11020;
 $1150 = (($1148) + 4)|0;
 $1151 = $1150;
 HEAP32[$1151>>2] = 0;
 $1152 = (__Z20GetPersistentManagerv()|0);
 $1153 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1152,$1,11020,0)|0);
 $1154 = (($0) + 16|0);
 HEAP32[$1154>>2] = $1153;
 $1155 = (($0) + 20|0);
 HEAP8[$1155>>0] = 0;
 $1156 = HEAP32[$15>>2]|0;
 $1157 = HEAP32[$17>>2]|0;
 $1158 = ($1156|0)==($1157|0);
 if ($1158) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1159 = ($1156|0)==(0|0);
  if ($1159) {
   $1161 = 0;
  } else {
   ;HEAP32[$1156+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1156+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1156+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1156+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1156+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1156+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i265 = HEAP32[$15>>2]|0;
   $1161 = $$pre$i$i$i$i265;
  }
  $1160 = (($1161) + 24|0);
  HEAP32[$15>>2] = $1160;
 }
 HEAP32[$0>>2] = 626968;
 $1162 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1163 = (($0) + 4|0);
 HEAP32[$1163>>2] = $1162;
 $1164 = (($0) + 8|0);
 $1165 = $1164;
 $1166 = $1165;
 HEAP32[$1166>>2] = 11021;
 $1167 = (($1165) + 4)|0;
 $1168 = $1167;
 HEAP32[$1168>>2] = 0;
 $1169 = (__Z20GetPersistentManagerv()|0);
 $1170 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1169,$1,11021,0)|0);
 $1171 = (($0) + 16|0);
 HEAP32[$1171>>2] = $1170;
 $1172 = (($0) + 20|0);
 HEAP8[$1172>>0] = 0;
 $1173 = HEAP32[$15>>2]|0;
 $1174 = HEAP32[$17>>2]|0;
 $1175 = ($1173|0)==($1174|0);
 if ($1175) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1176 = ($1173|0)==(0|0);
  if ($1176) {
   $1178 = 0;
  } else {
   ;HEAP32[$1173+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1173+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1173+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1173+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1173+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1173+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i269 = HEAP32[$15>>2]|0;
   $1178 = $$pre$i$i$i$i269;
  }
  $1177 = (($1178) + 24|0);
  HEAP32[$15>>2] = $1177;
 }
 HEAP32[$0>>2] = 627000;
 $1179 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1180 = (($0) + 4|0);
 HEAP32[$1180>>2] = $1179;
 $1181 = (($0) + 8|0);
 $1182 = $1181;
 $1183 = $1182;
 HEAP32[$1183>>2] = 11022;
 $1184 = (($1182) + 4)|0;
 $1185 = $1184;
 HEAP32[$1185>>2] = 0;
 $1186 = (__Z20GetPersistentManagerv()|0);
 $1187 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1186,$1,11022,0)|0);
 $1188 = (($0) + 16|0);
 HEAP32[$1188>>2] = $1187;
 $1189 = (($0) + 20|0);
 HEAP8[$1189>>0] = 0;
 $1190 = HEAP32[$15>>2]|0;
 $1191 = HEAP32[$17>>2]|0;
 $1192 = ($1190|0)==($1191|0);
 if ($1192) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1193 = ($1190|0)==(0|0);
  if ($1193) {
   $1195 = 0;
  } else {
   ;HEAP32[$1190+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1190+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1190+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1190+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1190+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1190+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i273 = HEAP32[$15>>2]|0;
   $1195 = $$pre$i$i$i$i273;
  }
  $1194 = (($1195) + 24|0);
  HEAP32[$15>>2] = $1194;
 }
 HEAP32[$0>>2] = 627024;
 $1196 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1197 = (($0) + 4|0);
 HEAP32[$1197>>2] = $1196;
 $1198 = (($0) + 8|0);
 $1199 = $1198;
 $1200 = $1199;
 HEAP32[$1200>>2] = 11023;
 $1201 = (($1199) + 4)|0;
 $1202 = $1201;
 HEAP32[$1202>>2] = 0;
 $1203 = (__Z20GetPersistentManagerv()|0);
 $1204 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1203,$1,11023,0)|0);
 $1205 = (($0) + 16|0);
 HEAP32[$1205>>2] = $1204;
 $1206 = (($0) + 20|0);
 HEAP8[$1206>>0] = 0;
 $1207 = HEAP32[$15>>2]|0;
 $1208 = HEAP32[$17>>2]|0;
 $1209 = ($1207|0)==($1208|0);
 if ($1209) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1210 = ($1207|0)==(0|0);
  if ($1210) {
   $1212 = 0;
  } else {
   ;HEAP32[$1207+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1207+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1207+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1207+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1207+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1207+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i277 = HEAP32[$15>>2]|0;
   $1212 = $$pre$i$i$i$i277;
  }
  $1211 = (($1212) + 24|0);
  HEAP32[$15>>2] = $1211;
 }
 HEAP32[$0>>2] = 627048;
 $1213 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1214 = (($0) + 4|0);
 HEAP32[$1214>>2] = $1213;
 $1215 = (($0) + 8|0);
 $1216 = $1215;
 $1217 = $1216;
 HEAP32[$1217>>2] = 11024;
 $1218 = (($1216) + 4)|0;
 $1219 = $1218;
 HEAP32[$1219>>2] = 0;
 $1220 = (__Z20GetPersistentManagerv()|0);
 $1221 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1220,$1,11024,0)|0);
 $1222 = (($0) + 16|0);
 HEAP32[$1222>>2] = $1221;
 $1223 = (($0) + 20|0);
 HEAP8[$1223>>0] = 0;
 $1224 = HEAP32[$15>>2]|0;
 $1225 = HEAP32[$17>>2]|0;
 $1226 = ($1224|0)==($1225|0);
 if ($1226) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1227 = ($1224|0)==(0|0);
  if ($1227) {
   $1229 = 0;
  } else {
   ;HEAP32[$1224+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1224+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1224+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1224+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1224+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1224+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i281 = HEAP32[$15>>2]|0;
   $1229 = $$pre$i$i$i$i281;
  }
  $1228 = (($1229) + 24|0);
  HEAP32[$15>>2] = $1228;
 }
 HEAP32[$0>>2] = 627072;
 $1230 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1231 = (($0) + 4|0);
 HEAP32[$1231>>2] = $1230;
 $1232 = (($0) + 8|0);
 $1233 = $1232;
 $1234 = $1233;
 HEAP32[$1234>>2] = 11025;
 $1235 = (($1233) + 4)|0;
 $1236 = $1235;
 HEAP32[$1236>>2] = 0;
 $1237 = (__Z20GetPersistentManagerv()|0);
 $1238 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1237,$1,11025,0)|0);
 $1239 = (($0) + 16|0);
 HEAP32[$1239>>2] = $1238;
 $1240 = (($0) + 20|0);
 HEAP8[$1240>>0] = 0;
 $1241 = HEAP32[$15>>2]|0;
 $1242 = HEAP32[$17>>2]|0;
 $1243 = ($1241|0)==($1242|0);
 if ($1243) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1244 = ($1241|0)==(0|0);
  if ($1244) {
   $1246 = 0;
  } else {
   ;HEAP32[$1241+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1241+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1241+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1241+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1241+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1241+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i285 = HEAP32[$15>>2]|0;
   $1246 = $$pre$i$i$i$i285;
  }
  $1245 = (($1246) + 24|0);
  HEAP32[$15>>2] = $1245;
 }
 HEAP32[$0>>2] = 627104;
 $1247 = (__ZN6Object15StringToClassIDEPKc(625480)|0);
 $1248 = (($0) + 4|0);
 HEAP32[$1248>>2] = $1247;
 $1249 = (($0) + 8|0);
 $1250 = $1249;
 $1251 = $1250;
 HEAP32[$1251>>2] = 11026;
 $1252 = (($1250) + 4)|0;
 $1253 = $1252;
 HEAP32[$1253>>2] = 0;
 $1254 = (__Z20GetPersistentManagerv()|0);
 $1255 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1254,$1,11026,0)|0);
 $1256 = (($0) + 16|0);
 HEAP32[$1256>>2] = $1255;
 $1257 = (($0) + 20|0);
 HEAP8[$1257>>0] = 0;
 $1258 = HEAP32[$15>>2]|0;
 $1259 = HEAP32[$17>>2]|0;
 $1260 = ($1258|0)==($1259|0);
 if ($1260) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1261 = ($1258|0)==(0|0);
  if ($1261) {
   $1263 = 0;
  } else {
   ;HEAP32[$1258+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1258+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1258+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1258+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1258+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1258+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i289 = HEAP32[$15>>2]|0;
   $1263 = $$pre$i$i$i$i289;
  }
  $1262 = (($1263) + 24|0);
  HEAP32[$15>>2] = $1262;
 }
 HEAP32[$0>>2] = 627136;
 $1264 = (__ZN6Object15StringToClassIDEPKc(627160)|0);
 $1265 = (($0) + 4|0);
 HEAP32[$1265>>2] = $1264;
 $1266 = (($0) + 8|0);
 $1267 = $1266;
 $1268 = $1267;
 HEAP32[$1268>>2] = 11998;
 $1269 = (($1267) + 4)|0;
 $1270 = $1269;
 HEAP32[$1270>>2] = 0;
 $1271 = (__Z20GetPersistentManagerv()|0);
 $1272 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1271,$1,11998,0)|0);
 $1273 = (($0) + 16|0);
 HEAP32[$1273>>2] = $1272;
 $1274 = (($0) + 20|0);
 HEAP8[$1274>>0] = 0;
 $1275 = HEAP32[$15>>2]|0;
 $1276 = HEAP32[$17>>2]|0;
 $1277 = ($1275|0)==($1276|0);
 if ($1277) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1278 = ($1275|0)==(0|0);
  if ($1278) {
   $1280 = 0;
  } else {
   ;HEAP32[$1275+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1275+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1275+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1275+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1275+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1275+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i293 = HEAP32[$15>>2]|0;
   $1280 = $$pre$i$i$i$i293;
  }
  $1279 = (($1280) + 24|0);
  HEAP32[$15>>2] = $1279;
 }
 HEAP32[$0>>2] = 627176;
 $1281 = (__ZN6Object15StringToClassIDEPKc(627160)|0);
 $1282 = (($0) + 4|0);
 HEAP32[$1282>>2] = $1281;
 $1283 = (($0) + 8|0);
 $1284 = $1283;
 $1285 = $1284;
 HEAP32[$1285>>2] = 11999;
 $1286 = (($1284) + 4)|0;
 $1287 = $1286;
 HEAP32[$1287>>2] = 0;
 $1288 = (__Z20GetPersistentManagerv()|0);
 $1289 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1288,$1,11999,0)|0);
 $1290 = (($0) + 16|0);
 HEAP32[$1290>>2] = $1289;
 $1291 = (($0) + 20|0);
 HEAP8[$1291>>0] = 0;
 $1292 = HEAP32[$15>>2]|0;
 $1293 = HEAP32[$17>>2]|0;
 $1294 = ($1292|0)==($1293|0);
 if ($1294) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1295 = ($1292|0)==(0|0);
  if ($1295) {
   $1297 = 0;
  } else {
   ;HEAP32[$1292+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1292+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1292+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1292+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1292+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1292+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i297 = HEAP32[$15>>2]|0;
   $1297 = $$pre$i$i$i$i297;
  }
  $1296 = (($1297) + 24|0);
  HEAP32[$15>>2] = $1296;
 }
 HEAP32[$0>>2] = 627200;
 $1298 = (__ZN6Object15StringToClassIDEPKc(627160)|0);
 $1299 = (($0) + 4|0);
 HEAP32[$1299>>2] = $1298;
 $1300 = (($0) + 8|0);
 $1301 = $1300;
 $1302 = $1301;
 HEAP32[$1302>>2] = 12001;
 $1303 = (($1301) + 4)|0;
 $1304 = $1303;
 HEAP32[$1304>>2] = 0;
 $1305 = (__Z20GetPersistentManagerv()|0);
 $1306 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1305,$1,12001,0)|0);
 $1307 = (($0) + 16|0);
 HEAP32[$1307>>2] = $1306;
 $1308 = (($0) + 20|0);
 HEAP8[$1308>>0] = 0;
 $1309 = HEAP32[$15>>2]|0;
 $1310 = HEAP32[$17>>2]|0;
 $1311 = ($1309|0)==($1310|0);
 if ($1311) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
 } else {
  $1312 = ($1309|0)==(0|0);
  if ($1312) {
   $1314 = 0;
  } else {
   ;HEAP32[$1309+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1309+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1309+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1309+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1309+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1309+20>>2]=HEAP32[$0+20>>2]|0;
   $$pre$i$i$i$i301 = HEAP32[$15>>2]|0;
   $1314 = $$pre$i$i$i$i301;
  }
  $1313 = (($1314) + 24|0);
  HEAP32[$15>>2] = $1313;
 }
 HEAP32[$0>>2] = 627208;
 $1315 = (__ZN6Object15StringToClassIDEPKc(627392)|0);
 $1316 = (($0) + 4|0);
 HEAP32[$1316>>2] = $1315;
 $1317 = (($0) + 8|0);
 $1318 = $1317;
 $1319 = $1318;
 HEAP32[$1319>>2] = 15000;
 $1320 = (($1318) + 4)|0;
 $1321 = $1320;
 HEAP32[$1321>>2] = 0;
 $1322 = (__Z20GetPersistentManagerv()|0);
 $1323 = (__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($1322,$1,15000,0)|0);
 $1324 = (($0) + 16|0);
 HEAP32[$1324>>2] = $1323;
 $1325 = (($0) + 20|0);
 HEAP8[$1325>>0] = 1;
 $1326 = HEAP32[$15>>2]|0;
 $1327 = HEAP32[$17>>2]|0;
 $1328 = ($1326|0)==($1327|0);
 if ($1328) {
  __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$0);
  $$pre = HEAP32[$15>>2]|0;
  $1333 = $$pre;
  $1332 = HEAP32[$this>>2]|0;
  __ZNSt3__16__sortIRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEvT0_S7_T_($1332,$1333,$0);
  STACKTOP = sp;return;
 }
 $1329 = ($1326|0)==(0|0);
 if ($1329) {
  $1331 = 0;
 } else {
  ;HEAP32[$1326+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1326+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1326+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1326+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$1326+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$1326+20>>2]=HEAP32[$0+20>>2]|0;
  $$pre$i$i$i$i305 = HEAP32[$15>>2]|0;
  $1331 = $$pre$i$i$i$i305;
 }
 $1330 = (($1331) + 24|0);
 HEAP32[$15>>2] = $1330;
 $1333 = $1330;
 $1332 = HEAP32[$this>>2]|0;
 __ZNSt3__16__sortIRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEvT0_S7_T_($1332,$1333,$0);
 STACKTOP = sp;return;
}
function __ZN22BuiltinResourceManager22InitializeAllResourcesEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[627400>>2]|0;
 __ZN22BuiltinResourceManager19InitializeResourcesEv($0);
 STACKTOP = sp;return;
}
function __Z25GetBuiltinResourceManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[627400>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNK22BuiltinResourceManager11GetResourceEiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$classID,$name) {
 $this = $this|0;
 $classID = $classID|0;
 $name = $name|0;
 var $$0 = 0, $$0$i41 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$42 = 0, $not$43 = 0, $not$44 = 0, $not$45 = 0, $not$46 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = (($this) + 28|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   $6 = HEAP8[$name>>0]|0;
   $7 = $6 & 1;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    $13 = $6&255;
    $14 = $13 >>> 1;
    $15 = (($name) + 1|0);
    $17 = $14;$19 = $15;
   } else {
    $9 = (($name) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($name) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $17 = $10;$19 = $12;
   }
   $16 = ($17>>>0)>(20);
   $18 = $16 ? 20 : $17;
   $20 = (_memcmp($19,625440,$18)|0);
   $21 = ($20|0)==(0);
   if ($21) {
    $22 = $16 ^ 1;
    $not$46 = ($17>>>0)>(19);
    $23 = $not$46 & $22;
    if ($23) {
     break;
    }
   }
   if ($8) {
    $28 = $6&255;
    $29 = $28 >>> 1;
    $30 = (($name) + 1|0);
    $32 = $29;$34 = $30;
   } else {
    $24 = (($name) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($name) + 8|0);
    $27 = HEAP32[$26>>2]|0;
    $32 = $25;$34 = $27;
   }
   $31 = ($32>>>0)>(26);
   $33 = $31 ? 26 : $32;
   $35 = (_memcmp($34,625568,$33)|0);
   $36 = ($35|0)==(0);
   if ($36) {
    $37 = $31 ^ 1;
    $not$45 = ($32>>>0)>(25);
    $38 = $not$45 & $37;
    if ($38) {
     break;
    }
   }
   if ($8) {
    $43 = $6&255;
    $44 = $43 >>> 1;
    $45 = (($name) + 1|0);
    $47 = $44;$49 = $45;
   } else {
    $39 = (($name) + 4|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($name) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $47 = $40;$49 = $42;
   }
   $46 = ($47>>>0)>(8);
   $48 = $46 ? 8 : $47;
   $50 = (_memcmp($49,625464,$48)|0);
   $51 = ($50|0)==(0);
   if ($51) {
    $52 = $46 ^ 1;
    $not$44 = ($47>>>0)>(7);
    $53 = $not$44 & $52;
    if ($53) {
     break;
    }
   }
   if ($8) {
    $58 = $6&255;
    $59 = $58 >>> 1;
    $60 = (($name) + 1|0);
    $62 = $59;$64 = $60;
   } else {
    $54 = (($name) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($name) + 8|0);
    $57 = HEAP32[$56>>2]|0;
    $62 = $55;$64 = $57;
   }
   $61 = ($62>>>0)>(20);
   $63 = $61 ? 20 : $62;
   $65 = (_memcmp($64,627240,$63)|0);
   $66 = ($65|0)==(0);
   if ($66) {
    $67 = $61 ^ 1;
    $not$43 = ($62>>>0)>(19);
    $68 = $not$43 & $67;
    if ($68) {
     break;
    }
   }
   if ($8) {
    $73 = $6&255;
    $74 = $73 >>> 1;
    $75 = (($name) + 1|0);
    $77 = $74;$79 = $75;
   } else {
    $69 = (($name) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($name) + 8|0);
    $72 = HEAP32[$71>>2]|0;
    $77 = $70;$79 = $72;
   }
   $76 = ($77>>>0)>(24);
   $78 = $76 ? 24 : $77;
   $80 = (_memcmp($79,627264,$78)|0);
   $81 = ($80|0)==(0);
   if ($81) {
    $82 = $76 ^ 1;
    $not$42 = ($77>>>0)>(23);
    $83 = $not$42 & $82;
    if ($83) {
     break;
    }
   }
   if ($8) {
    $88 = $6&255;
    $89 = $88 >>> 1;
    $90 = (($name) + 1|0);
    $92 = $89;$94 = $90;
   } else {
    $84 = (($name) + 4|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($name) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $92 = $85;$94 = $87;
   }
   $91 = ($92>>>0)>(21);
   $93 = $91 ? 21 : $92;
   $95 = (_memcmp($94,627296,$93)|0);
   $96 = ($95|0)==(0);
   if (!($96)) {
    $$02 = 0;
    STACKTOP = sp;return ($$02|0);
   }
   $97 = $91 ^ 1;
   $not$ = ($92>>>0)>(20);
   $98 = $not$ & $97;
   if (!($98)) {
    $$02 = 0;
    STACKTOP = sp;return ($$02|0);
   }
  }
 } while(0);
 $99 = (__ZNK22BuiltinResourceManager21GetResourceInstanceIDEiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$classID,$name)|0);
 $100 = ($99|0)==(0);
 do {
  if (!($100)) {
   HEAP32[$0>>2] = $99;
   $101 = HEAP32[560624>>2]|0;
   $102 = ($101|0)==(0|0);
   if ($102) {
    label = 41;
   } else {
    $103 = (($101) + 36|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($101) + 4|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ($104|0)==($106|0);
    do {
     if ($107) {
      $108 = (($101) + 28|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = (($101) + 32|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = (($109) + ($111<<3)|0);
      $128 = $112;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$101,$0);
      $113 = HEAP32[$pos$i$i$i$i>>2]|0;
      $114 = ($113|0)==(-1);
      $115 = (($101) + 28|0);
      $116 = HEAP32[$115>>2]|0;
      if ($114) {
       $117 = (($101) + 32|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = (($116) + ($118<<3)|0);
       $128 = $119;
       break;
      } else {
       $120 = (($116) + ($113<<3)|0);
       $128 = $120;
       break;
      }
     }
    } while(0);
    $121 = HEAP32[560624>>2]|0;
    $122 = (($121) + 28|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = (($121) + 32|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = (($123) + ($125<<3)|0);
    $127 = ($128|0)==($126|0);
    if ($127) {
     label = 41;
    } else {
     $129 = (($128) + 4|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($130|0)==(0|0);
     if ($131) {
      label = 41;
     } else {
      $$0$i41 = $130;
     }
    }
   }
   if ((label|0) == 41) {
    $132 = (__Z31ReadObjectFromPersistentManageri($99)|0);
    $133 = ($132|0)==(0|0);
    if ($133) {
     break;
    } else {
     $$0$i41 = $132;
    }
   }
   $134 = (($$0$i41) + 8|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = $135 >>> 21;
   $137 = HEAP32[560640>>2]|0;
   $138 = Math_imul($137, $136)|0;
   $139 = (($138) + ($classID))|0;
   $140 = $139 >> 5;
   $141 = $140 << 5;
   $142 = (($139) - ($141))|0;
   $143 = HEAP32[560632>>2]|0;
   $144 = (($143) + ($140<<2)|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = 1 << $142;
   $147 = $146 & $145;
   $148 = ($147|0)==(0);
   if (!($148)) {
    $$02 = $$0$i41;
    STACKTOP = sp;return ($$02|0);
   }
  }
 } while(0);
 __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($2,627320,$name);
 __THREW__ = 0;
 invoke_viii(1627,($1|0),($2|0),(627336|0));
 $149 = __THREW__; __THREW__ = 0;
 $150 = $149&1;
 do {
  if ($150) {
   $170 = ___cxa_find_matching_catch()|0;
   $171 = tempRet0;
   $$0 = $171;$$01 = $170;
  } else {
   $151 = HEAP8[$1>>0]|0;
   $152 = $151 & 1;
   $153 = ($152<<24>>24)==(0);
   if ($153) {
    $156 = (($1) + 1|0);
    $157 = $156;
   } else {
    $154 = (($1) + 8|0);
    $155 = HEAP32[$154>>2]|0;
    $157 = $155;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($157|0),0,(627384|0),1057,1,0,0,(0|0));
   $158 = __THREW__; __THREW__ = 0;
   $159 = $158&1;
   if ($159) {
    $172 = ___cxa_find_matching_catch()|0;
    $173 = tempRet0;
    $174 = HEAP8[$1>>0]|0;
    $175 = $174 & 1;
    $176 = ($175<<24>>24)==(0);
    if ($176) {
     $$0 = $173;$$01 = $172;
     break;
    }
    $177 = (($1) + 8|0);
    $178 = HEAP32[$177>>2]|0;
    __ZdlPv($178);
    $$0 = $173;$$01 = $172;
    break;
   }
   $160 = HEAP8[$1>>0]|0;
   $161 = $160 & 1;
   $162 = ($161<<24>>24)==(0);
   if (!($162)) {
    $163 = (($1) + 8|0);
    $164 = HEAP32[$163>>2]|0;
    __ZdlPv($164);
   }
   $165 = HEAP8[$2>>0]|0;
   $166 = $165 & 1;
   $167 = ($166<<24>>24)==(0);
   if ($167) {
    $$02 = 0;
    STACKTOP = sp;return ($$02|0);
   }
   $168 = (($2) + 8|0);
   $169 = HEAP32[$168>>2]|0;
   __ZdlPv($169);
   $$02 = 0;
   STACKTOP = sp;return ($$02|0);
  }
 } while(0);
 $179 = HEAP8[$2>>0]|0;
 $180 = $179 & 1;
 $181 = ($180<<24>>24)==(0);
 if ($181) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $182 = (($2) + 8|0);
 $183 = HEAP32[$182>>2]|0;
 __ZdlPv($183);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __ZNK22BuiltinResourceManager21GetResourceInstanceIDEiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$classID,$name) {
 $this = $this|0;
 $classID = $classID|0;
 $name = $name|0;
 var $$0 = 0, $$neg2$i$i$i$i = 0, $$old = 0, $$sum$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i = 0, $__len$03$i$i$i$i = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$name>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($name) + 1|0);
  $18 = $5;
 } else {
  $3 = (($name) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $18 = $4;
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($6|0);
 if ($9) {
  $29 = $6;
 } else {
  $10 = $6;
  $11 = $8;
  $12 = (($11) - ($10))|0;
  $13 = (($12|0) / 24)&-1;
  $16 = $6;$__len$03$i$i$i$i = $13;
  while(1) {
   $14 = (($__len$03$i$i$i$i|0) / 2)&-1;
   $15 = (($16) + (($14*24)|0)|0);
   $17 = HEAP32[$15>>2]|0;
   $19 = (_strcmp($17,$18)|0);
   $20 = ($19|0)==(0);
   if ($20) {
    $22 = ((($16) + (($14*24)|0)|0) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)<($classID|0);
    if ($24) {
     label = 9;
    } else {
     $40 = $16;$__len$0$be$i$i$i$i = $14;
    }
   } else {
    $21 = ($19|0)<(0);
    if ($21) {
     label = 9;
    } else {
     $40 = $16;$__len$0$be$i$i$i$i = $14;
    }
   }
   if ((label|0) == 9) {
    label = 0;
    $$sum$i$i$i$i = (($14) + 1)|0;
    $25 = (($16) + (($$sum$i$i$i$i*24)|0)|0);
    $$neg2$i$i$i$i = (($__len$03$i$i$i$i) + -1)|0;
    $26 = (($$neg2$i$i$i$i) - ($14))|0;
    $40 = $25;$__len$0$be$i$i$i$i = $26;
   }
   $27 = ($__len$0$be$i$i$i$i|0)==(0);
   if ($27) {
    $29 = $40;
    break;
   } else {
    $16 = $40;$__len$03$i$i$i$i = $__len$0$be$i$i$i$i;
   }
  }
 }
 $28 = ($29|0)==($8|0);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = HEAP32[$29>>2]|0;
 $31 = (_strcmp($18,$30)|0);
 $32 = ($31|0)==(0);
 if ($32) {
  $35 = (($29) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)>($classID|0);
  $$old = ($29|0)==($8|0);
  $or$cond1 = $37 | $$old;
  if ($or$cond1) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $33 = ($31|0)<(0);
  $34 = ($29|0)==($8|0);
  $or$cond = $33 | $34;
  if ($or$cond) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $38 = (($29) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 $$0 = $39;
 STACKTOP = sp;return ($$0|0);
}
function __ZN22BuiltinResourceManager16StaticInitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628392>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(32,$$byval_copy,0,16,627384,1114)|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 HEAP32[627400>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN22BuiltinResourceManager13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[627400>>2]|0;
 $2 = HEAP32[628392>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 12|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   $8 = (($1) + 20|0);
   $9 = HEAP32[$8>>2]|0;
   __ZdlPv($9);
  }
  $10 = HEAP32[$1>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   $12 = (($1) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==($10|0);
   if (!($14)) {
    $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = $10;
    $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = (($13) + -24|0);
    $15 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i) + ($15)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i;
    $16 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i>>>0) / 24)&-1;
    $17 = $16 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = (($13) + (($17*24)|0)|0);
    HEAP32[$12>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($10);
  }
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[627400>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15ResourceManager12GetPathRangeERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($agg$result,$this,$path) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $path = $path|0;
 var $$byval_copy1 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 __Z7ToLowerINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_($2,$path);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $10 = (($2) + 1|0);
  $11 = $3&255;
  $12 = $11 >>> 1;
  $14 = $12;$29 = $10;
 } else {
  $6 = (($2) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $14 = $9;$29 = $7;
 }
 $13 = ($14>>>0)>(2147483631);
 do {
  if ($13) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    // unreachable;
   }
  } else {
   $17 = ($14>>>0)<(11);
   if ($17) {
    $18 = $14 << 1;
    $19 = $18&255;
    HEAP8[$1>>0] = $19;
    $20 = (($1) + 1|0);
    $$pre$phiZ2D = $1;$__p$0$i$i$i$i = $20;
   } else {
    $21 = (($14) + 16)|0;
    $22 = $21 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy1|0),0,(627384|0),79)|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    $26 = (($1) + 8|0);
    HEAP32[$26>>2] = $23;
    $27 = $22 | 1;
    HEAP32[$1>>2] = $27;
    $28 = (($1) + 4|0);
    HEAP32[$28>>2] = $14;
    $$pre$phiZ2D = $1;$__p$0$i$i$i$i = $23;
   }
   _memcpy(($__p$0$i$i$i$i|0),($29|0),($14|0))|0;
   $30 = (($__p$0$i$i$i$i) + ($14)|0);
   HEAP8[$30>>0] = 0;
   $31 = (($this) + 36|0);
   __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE19__equal_range_multiIS2_EENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEESL_EERKT_($$byval_copy1,$31,$1);
   $32 = HEAP32[$$byval_copy1>>2]|0;
   HEAP32[$agg$result>>2] = $32;
   $33 = (($$byval_copy1) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($agg$result) + 4|0);
   HEAP32[$35>>2] = $34;
   $36 = HEAP8[$$pre$phiZ2D>>0]|0;
   $37 = $36 & 1;
   $38 = ($37<<24>>24)==(0);
   if (!($38)) {
    $39 = (($1) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($40|0),($$byval_copy1|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     $43 = ___cxa_find_matching_catch()|0;
     $44 = tempRet0;
     ___cxa_call_unexpected(($43|0));
     // unreachable;
    }
   }
   $45 = HEAP8[$2>>0]|0;
   $46 = $45 & 1;
   $47 = ($46<<24>>24)==(0);
   if ($47) {
    STACKTOP = sp;return;
   }
   $48 = (($2) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   __ZdlPv($49);
   STACKTOP = sp;return;
  }
 } while(0);
 $50 = ___cxa_find_matching_catch()|0;
 $51 = tempRet0;
 $52 = HEAP8[$2>>0]|0;
 $53 = $52 & 1;
 $54 = ($53<<24>>24)==(0);
 if ($54) {
  ___resumeException($50|0);
  // unreachable;
 }
 $55 = (($2) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 __ZdlPv($56);
 ___resumeException($50|0);
 // unreachable;
}
function __ZN15ResourceManager19PreloadDependenciesEi($this,$instanceId) {
 $this = $this|0;
 $instanceId = $instanceId|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $parents = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $parents = sp;
 $0 = (($parents) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($parents) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($parents) + 4|0);
 HEAP32[$parents>>2] = $2;
 __THREW__ = 0;
 invoke_viiii(380,($this|0),($instanceId|0),($parents|0),1);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = HEAP32[$0>>2]|0;
  __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($parents,$5);
  HEAP32[$1>>2] = 0;
  HEAP32[$parents>>2] = $2;
  HEAP32[$2>>2] = 0;
  __THREW__ = 0;
  invoke_viiii(380,($this|0),($instanceId|0),($parents|0),0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = HEAP32[$0>>2]|0;
   __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($parents,$8);
   STACKTOP = sp;return;
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $11 = HEAP32[$0>>2]|0;
 __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE7destroyEPNS_11__tree_nodeIiPvEE($parents,$11);
 ___resumeException($9|0);
 // unreachable;
}
function __ZN15ResourceManager19PreloadDependenciesEiRNSt3__13setIiNS0_4lessIiEENS0_9allocatorIiEEEEb($this,$instanceId,$visited,$scriptsOnly) {
 $this = $this|0;
 $instanceId = $instanceId|0;
 $visited = $visited|0;
 $scriptsOnly = $scriptsOnly|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$neg2$i$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__len$0$be$i$i = 0, $__len$03$i$i = 0, $i$015 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = (($visited) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($visited) + 4|0);
 $6 = ($4|0)==(0|0);
 if (!($6)) {
  $$0$ph7$i$i$i = $5;$$01$ph6$i$in$i$i = $4;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<($instanceId|0);
    if (!($9)) {
     break;
    }
    $12 = (($$013$i$in$i$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $13;
    }
   }
   $10 = HEAP32[$$013$i$in$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $10;
   }
  }
  $15 = ($$0$ph5$i$i$i|0)==($5|0);
  if (!($15)) {
   $16 = (($$0$ph5$i$i$i) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>($instanceId|0);
   if (!($18)) {
    STACKTOP = sp;return;
   }
  }
 }
 $19 = (($this) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22;
 $24 = $20;
 $25 = (($23) - ($24))|0;
 $26 = $25 >> 4;
 $27 = ($26|0)==(0);
 if ($27) {
  $37 = $20;
 } else {
  $30 = $20;$__len$03$i$i = $26;
  while(1) {
   $28 = (($__len$03$i$i|0) / 2)&-1;
   $29 = (($30) + ($28<<4)|0);
   $31 = HEAP32[$29>>2]|0;
   $32 = ($31|0)<($instanceId|0);
   if ($32) {
    $$sum$i$i = (($28) + 1)|0;
    $33 = (($30) + ($$sum$i$i<<4)|0);
    $$neg2$i$i = (($__len$03$i$i) + -1)|0;
    $34 = (($$neg2$i$i) - ($28))|0;
    $90 = $33;$__len$0$be$i$i = $34;
   } else {
    $90 = $30;$__len$0$be$i$i = $28;
   }
   $35 = ($__len$0$be$i$i|0)==(0);
   if ($35) {
    $37 = $90;
    break;
   } else {
    $30 = $90;$__len$03$i$i = $__len$0$be$i$i;
   }
  }
 }
 $36 = ($37|0)==($22|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==($instanceId|0);
 if (!($39)) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $instanceId;
 __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE15__insert_uniqueERKi($0,$visited,$2);
 $40 = (($37) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($37) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($41|0)==($43|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $46 = $43;$i$015 = 0;
 while(1) {
  $45 = (($46) + ($i$015<<2)|0);
  $47 = HEAP32[$45>>2]|0;
  if ($scriptsOnly) {
   $48 = (__Z20GetPersistentManagerv()|0);
   $49 = (__ZN17PersistentManager20GetSerializedClassIDEi($48,$47)|0);
   $50 = ($49|0)==(115);
   if ($50) {
    label = 18;
   }
  } else {
   label = 18;
  }
  do {
   if ((label|0) == 18) {
    label = 0;
    HEAP32[$1>>2] = $47;
    $51 = HEAP32[560624>>2]|0;
    $52 = ($51|0)==(0|0);
    if (!($52)) {
     $53 = (($51) + 36|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = (($51) + 4|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($54|0)==($56|0);
     do {
      if ($57) {
       $58 = (($51) + 28|0);
       $59 = HEAP32[$58>>2]|0;
       $60 = (($51) + 32|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($59) + ($61<<3)|0);
       $78 = $62;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($0,$51,$1);
       $63 = HEAP32[$0>>2]|0;
       $64 = ($63|0)==(-1);
       $65 = (($51) + 28|0);
       $66 = HEAP32[$65>>2]|0;
       if ($64) {
        $67 = (($51) + 32|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = (($66) + ($68<<3)|0);
        $78 = $69;
        break;
       } else {
        $70 = (($66) + ($63<<3)|0);
        $78 = $70;
        break;
       }
      }
     } while(0);
     $71 = HEAP32[560624>>2]|0;
     $72 = (($71) + 28|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = (($71) + 32|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($73) + ($75<<3)|0);
     $77 = ($78|0)==($76|0);
     if (!($77)) {
      $79 = (($78) + 4|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)==(0|0);
      if (!($81)) {
       break;
      }
     }
    }
    (__Z31ReadObjectFromPersistentManageri($47)|0);
   }
  } while(0);
  __ZN15ResourceManager19PreloadDependenciesEiRNSt3__13setIiNS0_4lessIiEENS0_9allocatorIiEEEEb($this,$47,$visited,$scriptsOnly);
  $82 = (($i$015) + 1)|0;
  $83 = HEAP32[$40>>2]|0;
  $84 = HEAP32[$42>>2]|0;
  $85 = $83;
  $86 = $84;
  $87 = (($85) - ($86))|0;
  $88 = $87 >> 2;
  $89 = ($82>>>0)<($88>>>0);
  if ($89) {
   $46 = $84;$i$015 = $82;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15ResourceManager39ShouldIgnoreInGarbageDependencyTrackingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __Z29RegisterClass_ResourceManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(147,175,0,0,0);
 STACKTOP = sp;return;
}
function __ZN15ResourceManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 15;
 dest=$3+0|0; src=627520+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 15|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,147,6,($0|0),52,(2430|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN15ResourceManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(52,$$byval_copy2,1,16,627384,177)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1678,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((627408 + 8|0));
  $6 = (($3) + 24|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 28|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 32|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 44|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 36|0);
  HEAP32[$11>>2] = $9;
  $12 = (($3) + 48|0);
  HEAP8[$12>>0] = 1;
  STACKTOP = sp;return ($3|0);
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(627384|0),177);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK15ResourceManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 147;
}
function __ZN15ResourceManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627536,627520,$this,0);
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 36|0);
 __ZN13ProxyTransfer8TransferINSt3__18multimapI8UnityStr4PPtrI6ObjectENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S6_EEEEEEEEvRT_PKc17TransferMetaFlags($transfer,$0,627544,0);
 $1 = (($this) + 24|0);
 __ZN13ProxyTransfer8TransferINSt3__16vectorIN15ResourceManager10DependencyENS1_9allocatorIS4_EEEEEEvRT_PKc17TransferMetaFlags($transfer,$1,627560,0);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15ResourceManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,627536,627520,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN15ResourceManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15ResourceManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $1 = (($this) + 36|0);
 __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN15ResourceManager10DependencyENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$2,0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__sortIRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($3,$5,$0);
 STACKTOP = sp;return;
}
function __ZN15ResourceManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $1 = (($this) + 36|0);
 __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN15ResourceManager10DependencyENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$2,0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__sortIRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($3,$5,$0);
 STACKTOP = sp;return;
}
function __ZN15ResourceManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 36|0);
 __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 24|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorIN15ResourceManager10DependencyENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 STACKTOP = sp;return;
}
function __ZN15ResourceManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15ResourceManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z18GetResourceManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(12)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN15ResourceManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15ResourceManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN15ResourceManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3545,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN15ResourceManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i = 0, $$01$i$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = ($1|0)==($2|0);
 if (!($3)) {
  $4 = (($transfer) + 12|0);
  $5 = (($transfer) + 28|0);
  $6 = (($transfer) + 32|0);
  $8 = $1;
  while(1) {
   $7 = (($8) + 28|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = HEAP32[$4>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$5>>2]|0;
   $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($10,$9,$13)|0);
   $15 = HEAP8[$6>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    HEAP32[$7>>2] = $14;
   }
   $17 = (($8) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    $$01$i$i$i$i$i$i$i = $8;
    while(1) {
     $22 = (($$01$i$i$i$i$i$i$i) + 8|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)==($$01$i$i$i$i$i$i$i|0);
     if ($25) {
      $$0$i$i$i$i$i$i$i = $23;
      break;
     } else {
      $$01$i$i$i$i$i$i$i = $23;
     }
    }
   } else {
    $$0$i$i$i$i$i$i$i$i = $18;
    while(1) {
     $20 = HEAP32[$$0$i$i$i$i$i$i$i$i>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      $$0$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i$i$i = $20;
     }
    }
   }
   $26 = ($$0$i$i$i$i$i$i$i|0)==($2|0);
   if ($26) {
    break;
   } else {
    $8 = $$0$i$i$i$i$i$i$i;
   }
  }
 }
 $27 = (($this) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 28|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($28|0)==($30|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = (($transfer) + 12|0);
 $33 = (($transfer) + 28|0);
 $34 = (($transfer) + 32|0);
 $36 = $28;
 while(1) {
  $35 = HEAP32[$36>>2]|0;
  $37 = HEAP32[$32>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$38>>2]|0;
  $40 = HEAP32[$33>>2]|0;
  $41 = (FUNCTION_TABLE_iiii[$39 & 2047]($37,$35,$40)|0);
  $42 = HEAP8[$34>>0]|0;
  $43 = ($42<<24>>24)==(0);
  if (!($43)) {
   HEAP32[$36>>2] = $41;
  }
  $44 = (($36) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($36) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($45|0)==($47|0);
  if (!($48)) {
   $50 = $45;
   while(1) {
    $49 = HEAP32[$50>>2]|0;
    $51 = HEAP32[$32>>2]|0;
    $52 = HEAP32[$51>>2]|0;
    $53 = HEAP32[$52>>2]|0;
    $54 = HEAP32[$33>>2]|0;
    $55 = (FUNCTION_TABLE_iiii[$53 & 2047]($51,$49,$54)|0);
    $56 = HEAP8[$34>>0]|0;
    $57 = ($56<<24>>24)==(0);
    if (!($57)) {
     HEAP32[$50>>2] = $55;
    }
    $58 = (($50) + 4|0);
    $59 = ($58|0)==($47|0);
    if ($59) {
     break;
    } else {
     $50 = $58;
    }
   }
  }
  $60 = (($36) + 16|0);
  $61 = ($60|0)==($30|0);
  if ($61) {
   break;
  } else {
   $36 = $60;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$i = 0, $$pre$i100 = 0, $$pre$i28 = 0, $$pre$i4 = 0, $$pre$i52 = 0, $$pre$i76 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$0130 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i112 = 0, $__new_last2$i$i$i$i$i$i$i$i16 = 0, $__new_last2$i$i$i$i$i$i$i$i40 = 0, $__new_last2$i$i$i$i$i$i$i$i64 = 0, $__new_last2$i$i$i$i$i$i$i$i88 = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $__new_last2$i$i$i$i$i$i$i1$i104 = 0, $__new_last2$i$i$i$i$i$i$i1$i32 = 0, $__new_last2$i$i$i$i$i$i$i1$i56 = 0, $__new_last2$i$i$i$i$i$i$i1$i8 = 0, $__new_last2$i$i$i$i$i$i$i1$i80 = 0, $__t$i2 = 0;
 var $__t$i26 = 0, $__t$i98 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i113 = 0, $scevgep$i$i$i$i$i$i$i$i17 = 0, $scevgep$i$i$i$i$i$i$i$i41 = 0, $scevgep$i$i$i$i$i$i$i$i65 = 0, $scevgep$i$i$i$i$i$i$i$i89 = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep$i$i$i$i$i$i$i2$i105 = 0, $scevgep$i$i$i$i$i$i$i2$i33 = 0, $scevgep$i$i$i$i$i$i$i2$i57 = 0, $scevgep$i$i$i$i$i$i$i2$i81 = 0, $scevgep$i$i$i$i$i$i$i2$i9 = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i117 = 0, $scevgep4$i$i$i$i$i$i$i$i21 = 0, $scevgep4$i$i$i$i$i$i$i$i45 = 0, $scevgep4$i$i$i$i$i$i$i$i69 = 0, $scevgep4$i$i$i$i$i$i$i$i93 = 0;
 var $scevgep4$i$i$i$i$i$i$i6$i = 0, $scevgep4$i$i$i$i$i$i$i6$i109 = 0, $scevgep4$i$i$i$i$i$i$i6$i13 = 0, $scevgep4$i$i$i$i$i$i$i6$i37 = 0, $scevgep4$i$i$i$i$i$i$i6$i61 = 0, $scevgep4$i$i$i$i$i$i$i6$i85 = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i115 = 0, $uglygep$i$i$i$i$i$i$i$i19 = 0, $uglygep$i$i$i$i$i$i$i$i43 = 0, $uglygep$i$i$i$i$i$i$i$i67 = 0, $uglygep$i$i$i$i$i$i$i$i91 = 0, $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep$i$i$i$i$i$i$i4$i107 = 0, $uglygep$i$i$i$i$i$i$i4$i11 = 0, $uglygep$i$i$i$i$i$i$i4$i35 = 0, $uglygep$i$i$i$i$i$i$i4$i59 = 0, $uglygep$i$i$i$i$i$i$i4$i83 = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i116 = 0;
 var $uglygep3$i$i$i$i$i$i$i$i20 = 0, $uglygep3$i$i$i$i$i$i$i$i44 = 0, $uglygep3$i$i$i$i$i$i$i$i68 = 0, $uglygep3$i$i$i$i$i$i$i$i92 = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, $uglygep3$i$i$i$i$i$i$i5$i108 = 0, $uglygep3$i$i$i$i$i$i$i5$i12 = 0, $uglygep3$i$i$i$i$i$i$i5$i36 = 0, $uglygep3$i$i$i$i$i$i$i5$i60 = 0, $uglygep3$i$i$i$i$i$i$i5$i84 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i98 = sp + 32|0;
 $__t$i26 = sp;
 $__t$i2 = sp + 16|0;
 $0 = (($__t$i98) + 4|0);
 $$pre$i100 = (($__t$i98) + 4|0);
 $1 = (($__t$i98) + 8|0);
 $2 = (($__t$i98) + 4|0);
 $$pre$i76 = (($__t$i98) + 4|0);
 $3 = (($__t$i98) + 8|0);
 $4 = (($__t$i26) + 4|0);
 $$pre$i28 = (($__t$i26) + 4|0);
 $5 = (($__t$i26) + 8|0);
 $6 = (($__t$i2) + 4|0);
 $$pre$i4 = (($__t$i2) + 4|0);
 $7 = (($__t$i2) + 8|0);
 $8 = (($__t$i98) + 4|0);
 $$pre$i52 = (($__t$i98) + 4|0);
 $9 = (($__t$i98) + 8|0);
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $10 = $$01$ph;
  $11 = (($$01$ph) + -16|0);
  $12 = ($__t$i2|0)==($11|0);
  $13 = (($$01$ph) + -12|0);
  $14 = (($$01$ph) + -12|0);
  $15 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $16 = $$0;
   $17 = (($10) - ($16))|0;
   $18 = $17 >> 4;
   switch ($18|0) {
   case 3:  {
    label = 18;
    break L1;
    break;
   }
   case 4:  {
    label = 19;
    break L1;
    break;
   }
   case 5:  {
    label = 20;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 117;
    break L1;
    break;
   }
   default: {
   }
   }
   $62 = ($17|0)<(112);
   if ($62) {
    label = 22;
    break L1;
   }
   $63 = ($17|0)>(15984);
   $64 = (($18|0) / 2)&-1;
   $65 = (($$0) + ($64<<4)|0);
   if ($63) {
    $66 = (($18|0) / 4)&-1;
    $67 = (($$0) + ($66<<4)|0);
    $$sum = (($66) + ($64))|0;
    $68 = (($$0) + ($$sum<<4)|0);
    $69 = (__ZNSt3__17__sort5IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_S6_S6_T_($$0,$67,$65,$68,$11,0)|0);
    $__n_swaps$0 = $69;
   } else {
    $70 = (__ZNSt3__17__sort3IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_T_($$0,$65,$11,0)|0);
    $__n_swaps$0 = $70;
   }
   $71 = HEAP32[$$0>>2]|0;
   $72 = HEAP32[$65>>2]|0;
   $73 = ($71|0)<($72|0);
   do {
    if ($73) {
     $__j$3 = $11;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $11;
     while(1) {
      $74 = (($__j$0) + -16|0);
      $75 = ($$0|0)==($74|0);
      if ($75) {
       break;
      }
      $152 = HEAP32[$74>>2]|0;
      $153 = ($152|0)<($72|0);
      if ($153) {
       label = 63;
       break;
      } else {
       $__j$0 = $74;
      }
     }
     if ((label|0) == 63) {
      label = 0;
      HEAP32[$__t$i98>>2] = $71;
      $154 = (($$0) + 4|0);
      __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($8,$154);
      $155 = HEAP32[$74>>2]|0;
      HEAP32[$$0>>2] = $155;
      $156 = (($__j$0) + -12|0);
      $157 = HEAP32[$156>>2]|0;
      $158 = (($__j$0) + -8|0);
      $159 = HEAP32[$158>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($154|0),($157|0),($159|0));
      $160 = __THREW__; __THREW__ = 0;
      $161 = $160&1;
      if ($161) {
       label = 70;
       break L1;
      }
      $162 = HEAP32[$__t$i98>>2]|0;
      HEAP32[$74>>2] = $162;
      $163 = ($__t$i98|0)==($74|0);
      if (!($163)) {
       $164 = (($__j$0) + -12|0);
       $165 = HEAP32[$$pre$i52>>2]|0;
       $166 = HEAP32[$9>>2]|0;
       __THREW__ = 0;
       invoke_viii(1787,($164|0),($165|0),($166|0));
       $167 = __THREW__; __THREW__ = 0;
       $168 = $167&1;
       if ($168) {
        label = 70;
        break L1;
       }
      }
      $169 = HEAP32[$$pre$i52>>2]|0;
      $170 = ($169|0)==(0|0);
      if (!($170)) {
       $171 = HEAP32[$9>>2]|0;
       $172 = ($171|0)==($169|0);
       if (!($172)) {
        $__new_last2$i$i$i$i$i$i$i1$i56 = $169;
        $scevgep$i$i$i$i$i$i$i2$i57 = (($171) + -4|0);
        $173 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i56))|0;
        $uglygep$i$i$i$i$i$i$i4$i59 = (($scevgep$i$i$i$i$i$i$i2$i57) + ($173)|0);
        $uglygep3$i$i$i$i$i$i$i5$i60 = $uglygep$i$i$i$i$i$i$i4$i59;
        $174 = $uglygep3$i$i$i$i$i$i$i5$i60 >>> 2;
        $175 = $174 ^ -1;
        $scevgep4$i$i$i$i$i$i$i6$i61 = (($171) + ($175<<2)|0);
        HEAP32[$9>>2] = $scevgep4$i$i$i$i$i$i$i6$i61;
       }
       __ZdlPv($169);
      }
      $185 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $74;$__n_swaps$3 = $185;
      break;
     }
     $76 = (($$0) + 16|0);
     $77 = HEAP32[$11>>2]|0;
     $78 = ($71|0)<($77|0);
     if ($78) {
      $__i$1 = $76;
     } else {
      $79 = ($76|0)==($11|0);
      if ($79) {
       label = 117;
       break L1;
      } else {
       $__i$0130 = $76;
      }
      while(1) {
       $82 = HEAP32[$__i$0130>>2]|0;
       $83 = ($71|0)<($82|0);
       $81 = (($__i$0130) + 16|0);
       if ($83) {
        break;
       }
       $80 = ($81|0)==($11|0);
       if ($80) {
        label = 117;
        break L1;
       } else {
        $__i$0130 = $81;
       }
      }
      HEAP32[$__t$i2>>2] = $82;
      $84 = (($__i$0130) + 4|0);
      __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($6,$84);
      $85 = HEAP32[$11>>2]|0;
      HEAP32[$__i$0130>>2] = $85;
      $86 = HEAP32[$14>>2]|0;
      $87 = HEAP32[$15>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($84|0),($86|0),($87|0));
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       label = 39;
       break L1;
      }
      $90 = HEAP32[$__t$i2>>2]|0;
      HEAP32[$11>>2] = $90;
      if (!($12)) {
       $91 = HEAP32[$$pre$i4>>2]|0;
       $92 = HEAP32[$7>>2]|0;
       __THREW__ = 0;
       invoke_viii(1787,($13|0),($91|0),($92|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        label = 39;
        break L1;
       }
      }
      $95 = HEAP32[$$pre$i4>>2]|0;
      $96 = ($95|0)==(0|0);
      if ($96) {
       $__i$1 = $81;
      } else {
       $97 = HEAP32[$7>>2]|0;
       $98 = ($97|0)==($95|0);
       if (!($98)) {
        $__new_last2$i$i$i$i$i$i$i1$i8 = $95;
        $scevgep$i$i$i$i$i$i$i2$i9 = (($97) + -4|0);
        $99 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i8))|0;
        $uglygep$i$i$i$i$i$i$i4$i11 = (($scevgep$i$i$i$i$i$i$i2$i9) + ($99)|0);
        $uglygep3$i$i$i$i$i$i$i5$i12 = $uglygep$i$i$i$i$i$i$i4$i11;
        $100 = $uglygep3$i$i$i$i$i$i$i5$i12 >>> 2;
        $101 = $100 ^ -1;
        $scevgep4$i$i$i$i$i$i$i6$i13 = (($97) + ($101<<2)|0);
        HEAP32[$7>>2] = $scevgep4$i$i$i$i$i$i$i6$i13;
       }
       __ZdlPv($95);
       $__i$1 = $81;
      }
     }
     $111 = ($__i$1|0)==($11|0);
     if ($111) {
      label = 117;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $11;
     }
     while(1) {
      $112 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $113 = HEAP32[$__i$2>>2]|0;
       $114 = ($112|0)<($113|0);
       $115 = (($__i$2) + 16|0);
       if ($114) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $115;
       }
      }
      while(1) {
       $116 = (($__j$2) + -16|0);
       $117 = HEAP32[$116>>2]|0;
       $118 = ($112|0)<($117|0);
       if ($118) {
        $__j$2 = $116;
       } else {
        break;
       }
      }
      $119 = ($__i$2>>>0)<($116>>>0);
      if (!($119)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__t$i26>>2] = $113;
      $120 = (($__i$2) + 4|0);
      __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($4,$120);
      $121 = HEAP32[$116>>2]|0;
      HEAP32[$__i$2>>2] = $121;
      $122 = ($__i$2|0)==($116|0);
      if (!($122)) {
       $123 = (($__j$2) + -12|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = (($__j$2) + -8|0);
       $126 = HEAP32[$125>>2]|0;
       __THREW__ = 0;
       invoke_viii(1787,($120|0),($124|0),($126|0));
       $127 = __THREW__; __THREW__ = 0;
       $128 = $127&1;
       if ($128) {
        label = 57;
        break L1;
       }
      }
      $129 = HEAP32[$__t$i26>>2]|0;
      HEAP32[$116>>2] = $129;
      $130 = ($__t$i26|0)==($116|0);
      if (!($130)) {
       $131 = (($__j$2) + -12|0);
       $132 = HEAP32[$$pre$i28>>2]|0;
       $133 = HEAP32[$5>>2]|0;
       __THREW__ = 0;
       invoke_viii(1787,($131|0),($132|0),($133|0));
       $134 = __THREW__; __THREW__ = 0;
       $135 = $134&1;
       if ($135) {
        label = 57;
        break L1;
       }
      }
      $136 = HEAP32[$$pre$i28>>2]|0;
      $137 = ($136|0)==(0|0);
      if ($137) {
       $__i$2$ph = $115;$__j$1$ph = $116;
       continue;
      }
      $138 = HEAP32[$5>>2]|0;
      $139 = ($138|0)==($136|0);
      if (!($139)) {
       $__new_last2$i$i$i$i$i$i$i1$i32 = $136;
       $scevgep$i$i$i$i$i$i$i2$i33 = (($138) + -4|0);
       $140 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i32))|0;
       $uglygep$i$i$i$i$i$i$i4$i35 = (($scevgep$i$i$i$i$i$i$i2$i33) + ($140)|0);
       $uglygep3$i$i$i$i$i$i$i5$i36 = $uglygep$i$i$i$i$i$i$i4$i35;
       $141 = $uglygep3$i$i$i$i$i$i$i5$i36 >>> 2;
       $142 = $141 ^ -1;
       $scevgep4$i$i$i$i$i$i$i6$i37 = (($138) + ($142<<2)|0);
       HEAP32[$5>>2] = $scevgep4$i$i$i$i$i$i$i6$i37;
      }
      __ZdlPv($136);
      $__i$2$ph = $115;$__j$1$ph = $116;
     }
    }
   } while(0);
   $186 = (($$0) + 16|0);
   $187 = ($186>>>0)<($__j$3>>>0);
   L62: do {
    if ($187) {
     $__i$3$ph = $186;$__j$4$ph = $__j$3;$__m$0$ph = $65;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $188 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $189 = HEAP32[$__i$3>>2]|0;
       $190 = ($189|0)<($188|0);
       $191 = (($__i$3) + 16|0);
       if ($190) {
        $__i$3 = $191;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $192 = (($__j$5) + -16|0);
       $193 = HEAP32[$192>>2]|0;
       $194 = ($193|0)<($188|0);
       if ($194) {
        break;
       } else {
        $__j$5 = $192;
       }
      }
      $195 = ($__i$3>>>0)>($192>>>0);
      if ($195) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L62;
      }
      HEAP32[$__t$i98>>2] = $189;
      $196 = (($__i$3) + 4|0);
      __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($2,$196);
      $197 = HEAP32[$192>>2]|0;
      HEAP32[$__i$3>>2] = $197;
      $198 = ($__i$3|0)==($192|0);
      if (!($198)) {
       $199 = (($__j$5) + -12|0);
       $200 = HEAP32[$199>>2]|0;
       $201 = (($__j$5) + -8|0);
       $202 = HEAP32[$201>>2]|0;
       __THREW__ = 0;
       invoke_viii(1787,($196|0),($200|0),($202|0));
       $203 = __THREW__; __THREW__ = 0;
       $204 = $203&1;
       if ($204) {
        label = 89;
        break L1;
       }
      }
      $205 = HEAP32[$__t$i98>>2]|0;
      HEAP32[$192>>2] = $205;
      $206 = ($__t$i98|0)==($192|0);
      if (!($206)) {
       $207 = (($__j$5) + -12|0);
       $208 = HEAP32[$$pre$i76>>2]|0;
       $209 = HEAP32[$3>>2]|0;
       __THREW__ = 0;
       invoke_viii(1787,($207|0),($208|0),($209|0));
       $210 = __THREW__; __THREW__ = 0;
       $211 = $210&1;
       if ($211) {
        label = 89;
        break L1;
       }
      }
      $212 = HEAP32[$$pre$i76>>2]|0;
      $213 = ($212|0)==(0|0);
      if (!($213)) {
       $214 = HEAP32[$3>>2]|0;
       $215 = ($214|0)==($212|0);
       if (!($215)) {
        $__new_last2$i$i$i$i$i$i$i1$i80 = $212;
        $scevgep$i$i$i$i$i$i$i2$i81 = (($214) + -4|0);
        $216 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i80))|0;
        $uglygep$i$i$i$i$i$i$i4$i83 = (($scevgep$i$i$i$i$i$i$i2$i81) + ($216)|0);
        $uglygep3$i$i$i$i$i$i$i5$i84 = $uglygep$i$i$i$i$i$i$i4$i83;
        $217 = $uglygep3$i$i$i$i$i$i$i5$i84 >>> 2;
        $218 = $217 ^ -1;
        $scevgep4$i$i$i$i$i$i$i6$i85 = (($214) + ($218<<2)|0);
        HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i$i6$i85;
       }
       __ZdlPv($212);
      }
      $228 = (($__n_swaps$4$ph) + 1)|0;
      $229 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $229 ? $192 : $__m$0$ph;
      $__i$3$ph = $191;$__j$4$ph = $192;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $228;
     }
    } else {
     $__i$4 = $186;$__m$2 = $65;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $230 = ($__i$4|0)==($__m$2|0);
   if ($230) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $231 = HEAP32[$__m$2>>2]|0;
    $232 = HEAP32[$__i$4>>2]|0;
    $233 = ($231|0)<($232|0);
    if ($233) {
     HEAP32[$__t$i98>>2] = $232;
     $234 = (($__i$4) + 4|0);
     __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($0,$234);
     $235 = HEAP32[$__m$2>>2]|0;
     HEAP32[$__i$4>>2] = $235;
     $236 = (($__m$2) + 4|0);
     $237 = HEAP32[$236>>2]|0;
     $238 = (($__m$2) + 8|0);
     $239 = HEAP32[$238>>2]|0;
     __THREW__ = 0;
     invoke_viii(1787,($234|0),($237|0),($239|0));
     $240 = __THREW__; __THREW__ = 0;
     $241 = $240&1;
     if ($241) {
      label = 104;
      break L1;
     }
     $242 = HEAP32[$__t$i98>>2]|0;
     HEAP32[$__m$2>>2] = $242;
     $243 = ($__t$i98|0)==($__m$2|0);
     if (!($243)) {
      $244 = (($__m$2) + 4|0);
      $245 = HEAP32[$$pre$i100>>2]|0;
      $246 = HEAP32[$1>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($244|0),($245|0),($246|0));
      $247 = __THREW__; __THREW__ = 0;
      $248 = $247&1;
      if ($248) {
       label = 104;
       break L1;
      }
     }
     $249 = HEAP32[$$pre$i100>>2]|0;
     $250 = ($249|0)==(0|0);
     if (!($250)) {
      $251 = HEAP32[$1>>2]|0;
      $252 = ($251|0)==($249|0);
      if (!($252)) {
       $__new_last2$i$i$i$i$i$i$i1$i104 = $249;
       $scevgep$i$i$i$i$i$i$i2$i105 = (($251) + -4|0);
       $253 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i104))|0;
       $uglygep$i$i$i$i$i$i$i4$i107 = (($scevgep$i$i$i$i$i$i$i2$i105) + ($253)|0);
       $uglygep3$i$i$i$i$i$i$i5$i108 = $uglygep$i$i$i$i$i$i$i4$i107;
       $254 = $uglygep3$i$i$i$i$i$i$i5$i108 >>> 2;
       $255 = $254 ^ -1;
       $scevgep4$i$i$i$i$i$i$i6$i109 = (($251) + ($255<<2)|0);
       HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6$i109;
      }
      __ZdlPv($249);
     }
     $265 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $265;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $266 = ($__n_swaps$6|0)==(0);
   if ($266) {
    $267 = (__ZNSt3__127__insertion_sort_incompleteIRN15ResourceManager10Dependency6SorterEPS2_EEbT0_S6_T_($$0,$__i$4,0)|0);
    $268 = (($__i$4) + 16|0);
    $269 = (__ZNSt3__127__insertion_sort_incompleteIRN15ResourceManager10Dependency6SorterEPS2_EEbT0_S6_T_($268,$$01$ph,0)|0);
    if ($269) {
     label = 112;
     break;
    }
    if ($267) {
     $$0 = $268;
     continue;
    }
   }
   $270 = $__i$4;
   $271 = (($270) - ($16))|0;
   $272 = (($10) - ($270))|0;
   $273 = ($271|0)<($272|0);
   if (!($273)) {
    label = 116;
    break;
   }
   __ZNSt3__16__sortIRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($$0,$__i$4,$__comp);
   $274 = (($__i$4) + 16|0);
   $$0 = $274;
  }
  if ((label|0) == 112) {
   label = 0;
   if ($267) {
    label = 117;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 116) {
   label = 0;
   $275 = (($__i$4) + 16|0);
   __ZNSt3__16__sortIRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($275,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 switch (label|0) {
  case 4: {
   $19 = HEAP32[$11>>2]|0;
   $20 = HEAP32[$$0>>2]|0;
   $21 = ($19|0)<($20|0);
   if (!($21)) {
    STACKTOP = sp;return;
   }
   HEAP32[$__t$i98>>2] = $20;
   $22 = (($__t$i98) + 4|0);
   $23 = (($$0) + 4|0);
   __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($22,$23);
   $24 = HEAP32[$11>>2]|0;
   HEAP32[$$0>>2] = $24;
   $25 = ($$0|0)==($11|0);
   if ($25) {
    label = 7;
   } else {
    $26 = HEAP32[$14>>2]|0;
    $27 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($23|0),($26|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     label = 7;
    }
   }
   do {
    if ((label|0) == 7) {
     $30 = HEAP32[$__t$i98>>2]|0;
     HEAP32[$11>>2] = $30;
     $31 = ($__t$i98|0)==($11|0);
     $$pre$i = (($__t$i98) + 4|0);
     if (!($31)) {
      $32 = HEAP32[$$pre$i>>2]|0;
      $33 = (($__t$i98) + 8|0);
      $34 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($13|0),($32|0),($34|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
     }
     $37 = HEAP32[$$pre$i>>2]|0;
     $38 = ($37|0)==(0|0);
     if ($38) {
      STACKTOP = sp;return;
     }
     $39 = (($__t$i98) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($37|0);
     if (!($41)) {
      $__new_last2$i$i$i$i$i$i$i1$i = $37;
      $scevgep$i$i$i$i$i$i$i2$i = (($40) + -4|0);
      $42 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
      $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($42)|0);
      $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
      $43 = $uglygep3$i$i$i$i$i$i$i5$i >>> 2;
      $44 = $43 ^ -1;
      $scevgep4$i$i$i$i$i$i$i6$i = (($40) + ($44<<2)|0);
      HEAP32[$39>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
     }
     __ZdlPv($37);
     STACKTOP = sp;return;
    }
   } while(0);
   $45 = ___cxa_find_matching_catch()|0;
   $46 = tempRet0;
   $47 = (($__t$i98) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if ($49) {
    ___resumeException($45|0);
    // unreachable;
   }
   $50 = (($__t$i98) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==($48|0);
   if (!($52)) {
    $__new_last2$i$i$i$i$i$i$i$i = $48;
    $scevgep$i$i$i$i$i$i$i$i = (($51) + -4|0);
    $53 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($53)|0);
    $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
    $54 = $uglygep3$i$i$i$i$i$i$i$i >>> 2;
    $55 = $54 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i = (($51) + ($55<<2)|0);
    HEAP32[$50>>2] = $scevgep4$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($48);
   ___resumeException($45|0);
   // unreachable;
   break;
  }
  case 18: {
   $56 = (($$0) + 16|0);
   (__ZNSt3__17__sort3IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_T_($$0,$56,$11,0)|0);
   STACKTOP = sp;return;
   break;
  }
  case 19: {
   $57 = (($$0) + 16|0);
   $58 = (($$0) + 32|0);
   (__ZNSt3__17__sort4IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_S6_T_($$0,$57,$58,$11,0)|0);
   STACKTOP = sp;return;
   break;
  }
  case 20: {
   $59 = (($$0) + 16|0);
   $60 = (($$0) + 32|0);
   $61 = (($$0) + 48|0);
   (__ZNSt3__17__sort5IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_S6_S6_T_($$0,$59,$60,$61,$11,0)|0);
   STACKTOP = sp;return;
   break;
  }
  case 22: {
   __ZNSt3__118__insertion_sort_3IRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($$0,$$01$ph,0);
   STACKTOP = sp;return;
   break;
  }
  case 39: {
   $102 = ___cxa_find_matching_catch()|0;
   $103 = tempRet0;
   $104 = HEAP32[$$pre$i4>>2]|0;
   $105 = ($104|0)==(0|0);
   if ($105) {
    ___resumeException($102|0);
    // unreachable;
   }
   $106 = HEAP32[$7>>2]|0;
   $107 = ($106|0)==($104|0);
   if (!($107)) {
    $__new_last2$i$i$i$i$i$i$i$i16 = $104;
    $scevgep$i$i$i$i$i$i$i$i17 = (($106) + -4|0);
    $108 = (0 - ($__new_last2$i$i$i$i$i$i$i$i16))|0;
    $uglygep$i$i$i$i$i$i$i$i19 = (($scevgep$i$i$i$i$i$i$i$i17) + ($108)|0);
    $uglygep3$i$i$i$i$i$i$i$i20 = $uglygep$i$i$i$i$i$i$i$i19;
    $109 = $uglygep3$i$i$i$i$i$i$i$i20 >>> 2;
    $110 = $109 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i21 = (($106) + ($110<<2)|0);
    HEAP32[$7>>2] = $scevgep4$i$i$i$i$i$i$i$i21;
   }
   __ZdlPv($104);
   ___resumeException($102|0);
   // unreachable;
   break;
  }
  case 57: {
   $143 = ___cxa_find_matching_catch()|0;
   $144 = tempRet0;
   $145 = HEAP32[$$pre$i28>>2]|0;
   $146 = ($145|0)==(0|0);
   if ($146) {
    ___resumeException($143|0);
    // unreachable;
   }
   $147 = HEAP32[$5>>2]|0;
   $148 = ($147|0)==($145|0);
   if (!($148)) {
    $__new_last2$i$i$i$i$i$i$i$i40 = $145;
    $scevgep$i$i$i$i$i$i$i$i41 = (($147) + -4|0);
    $149 = (0 - ($__new_last2$i$i$i$i$i$i$i$i40))|0;
    $uglygep$i$i$i$i$i$i$i$i43 = (($scevgep$i$i$i$i$i$i$i$i41) + ($149)|0);
    $uglygep3$i$i$i$i$i$i$i$i44 = $uglygep$i$i$i$i$i$i$i$i43;
    $150 = $uglygep3$i$i$i$i$i$i$i$i44 >>> 2;
    $151 = $150 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i45 = (($147) + ($151<<2)|0);
    HEAP32[$5>>2] = $scevgep4$i$i$i$i$i$i$i$i45;
   }
   __ZdlPv($145);
   ___resumeException($143|0);
   // unreachable;
   break;
  }
  case 70: {
   $176 = ___cxa_find_matching_catch()|0;
   $177 = tempRet0;
   $178 = HEAP32[$$pre$i52>>2]|0;
   $179 = ($178|0)==(0|0);
   if ($179) {
    ___resumeException($176|0);
    // unreachable;
   }
   $180 = HEAP32[$9>>2]|0;
   $181 = ($180|0)==($178|0);
   if (!($181)) {
    $__new_last2$i$i$i$i$i$i$i$i64 = $178;
    $scevgep$i$i$i$i$i$i$i$i65 = (($180) + -4|0);
    $182 = (0 - ($__new_last2$i$i$i$i$i$i$i$i64))|0;
    $uglygep$i$i$i$i$i$i$i$i67 = (($scevgep$i$i$i$i$i$i$i$i65) + ($182)|0);
    $uglygep3$i$i$i$i$i$i$i$i68 = $uglygep$i$i$i$i$i$i$i$i67;
    $183 = $uglygep3$i$i$i$i$i$i$i$i68 >>> 2;
    $184 = $183 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i69 = (($180) + ($184<<2)|0);
    HEAP32[$9>>2] = $scevgep4$i$i$i$i$i$i$i$i69;
   }
   __ZdlPv($178);
   ___resumeException($176|0);
   // unreachable;
   break;
  }
  case 89: {
   $219 = ___cxa_find_matching_catch()|0;
   $220 = tempRet0;
   $221 = HEAP32[$$pre$i76>>2]|0;
   $222 = ($221|0)==(0|0);
   if ($222) {
    ___resumeException($219|0);
    // unreachable;
   }
   $223 = HEAP32[$3>>2]|0;
   $224 = ($223|0)==($221|0);
   if (!($224)) {
    $__new_last2$i$i$i$i$i$i$i$i88 = $221;
    $scevgep$i$i$i$i$i$i$i$i89 = (($223) + -4|0);
    $225 = (0 - ($__new_last2$i$i$i$i$i$i$i$i88))|0;
    $uglygep$i$i$i$i$i$i$i$i91 = (($scevgep$i$i$i$i$i$i$i$i89) + ($225)|0);
    $uglygep3$i$i$i$i$i$i$i$i92 = $uglygep$i$i$i$i$i$i$i$i91;
    $226 = $uglygep3$i$i$i$i$i$i$i$i92 >>> 2;
    $227 = $226 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i93 = (($223) + ($227<<2)|0);
    HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i$i$i93;
   }
   __ZdlPv($221);
   ___resumeException($219|0);
   // unreachable;
   break;
  }
  case 104: {
   $256 = ___cxa_find_matching_catch()|0;
   $257 = tempRet0;
   $258 = HEAP32[$$pre$i100>>2]|0;
   $259 = ($258|0)==(0|0);
   if ($259) {
    ___resumeException($256|0);
    // unreachable;
   }
   $260 = HEAP32[$1>>2]|0;
   $261 = ($260|0)==($258|0);
   if (!($261)) {
    $__new_last2$i$i$i$i$i$i$i$i112 = $258;
    $scevgep$i$i$i$i$i$i$i$i113 = (($260) + -4|0);
    $262 = (0 - ($__new_last2$i$i$i$i$i$i$i$i112))|0;
    $uglygep$i$i$i$i$i$i$i$i115 = (($scevgep$i$i$i$i$i$i$i$i113) + ($262)|0);
    $uglygep3$i$i$i$i$i$i$i$i116 = $uglygep$i$i$i$i$i$i$i$i115;
    $263 = $uglygep3$i$i$i$i$i$i$i$i116 >>> 2;
    $264 = $263 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i117 = (($260) + ($264<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i117;
   }
   __ZdlPv($258);
   ___resumeException($256|0);
   // unreachable;
   break;
  }
  case 117: {
   STACKTOP = sp;return;
   break;
  }
 }
}
function __ZNSt3__17__sort3IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $$pre$i = 0, $$pre$i27 = 0, $$pre$i3 = 0, $$pre$i51 = 0, $$pre$i75 = 0, $$pre$phi$i53Z2D = 0, $$pre$phi$i5Z2D = 0, $$pre$phi$i77Z2D = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i$i$i$i39 = 0, $__new_last2$i$i$i$i$i$i$i$i63 = 0, $__new_last2$i$i$i$i$i$i$i$i87 = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $__new_last2$i$i$i$i$i$i$i1$i31 = 0, $__new_last2$i$i$i$i$i$i$i1$i55 = 0, $__new_last2$i$i$i$i$i$i$i1$i7 = 0, $__new_last2$i$i$i$i$i$i$i1$i79 = 0, $__t$i = 0;
 var $__t$i25 = 0, $__t$i73 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i$i$i$i40 = 0, $scevgep$i$i$i$i$i$i$i$i64 = 0, $scevgep$i$i$i$i$i$i$i$i88 = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep$i$i$i$i$i$i$i2$i32 = 0, $scevgep$i$i$i$i$i$i$i2$i56 = 0, $scevgep$i$i$i$i$i$i$i2$i8 = 0, $scevgep$i$i$i$i$i$i$i2$i80 = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i$i$i$i44 = 0, $scevgep4$i$i$i$i$i$i$i$i68 = 0, $scevgep4$i$i$i$i$i$i$i$i92 = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $scevgep4$i$i$i$i$i$i$i6$i12 = 0, $scevgep4$i$i$i$i$i$i$i6$i36 = 0;
 var $scevgep4$i$i$i$i$i$i$i6$i60 = 0, $scevgep4$i$i$i$i$i$i$i6$i84 = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i$i$i$i42 = 0, $uglygep$i$i$i$i$i$i$i$i66 = 0, $uglygep$i$i$i$i$i$i$i$i90 = 0, $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep$i$i$i$i$i$i$i4$i10 = 0, $uglygep$i$i$i$i$i$i$i4$i34 = 0, $uglygep$i$i$i$i$i$i$i4$i58 = 0, $uglygep$i$i$i$i$i$i$i4$i82 = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i$i$i$i43 = 0, $uglygep3$i$i$i$i$i$i$i$i67 = 0, $uglygep3$i$i$i$i$i$i$i$i91 = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, $uglygep3$i$i$i$i$i$i$i5$i11 = 0, $uglygep3$i$i$i$i$i$i$i5$i35 = 0;
 var $uglygep3$i$i$i$i$i$i$i5$i59 = 0, $uglygep3$i$i$i$i$i$i$i5$i83 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i73 = sp + 32|0;
 $__t$i25 = sp;
 $__t$i = sp + 16|0;
 $0 = HEAP32[$__y>>2]|0;
 $1 = HEAP32[$__x>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__z>>2]|0;
 $4 = ($3|0)<($0|0);
 if (!($2)) {
  if (!($4)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__t$i73>>2] = $0;
  $5 = (($__t$i73) + 4|0);
  $6 = (($__y) + 4|0);
  __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($5,$6);
  $7 = HEAP32[$__z>>2]|0;
  HEAP32[$__y>>2] = $7;
  $8 = ($__y|0)==($__z|0);
  if ($8) {
   label = 5;
  } else {
   $9 = (($__z) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($__z) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   __THREW__ = 0;
   invoke_viii(1787,($6|0),($10|0),($12|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    label = 5;
   }
  }
  do {
   if ((label|0) == 5) {
    $15 = HEAP32[$__t$i73>>2]|0;
    HEAP32[$__z>>2] = $15;
    $16 = ($__t$i73|0)==($__z|0);
    if ($16) {
     $$pre$i3 = (($__z) + 4|0);
     $$pre$phi$i5Z2D = $$pre$i3;
    } else {
     $17 = (($__z) + 4|0);
     $18 = (($__t$i73) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($__t$i73) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     invoke_viii(1787,($17|0),($19|0),($21|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     } else {
      $$pre$phi$i5Z2D = $18;
     }
    }
    $24 = HEAP32[$$pre$phi$i5Z2D>>2]|0;
    $25 = ($24|0)==(0|0);
    if (!($25)) {
     $26 = (($__t$i73) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==($24|0);
     if (!($28)) {
      $__new_last2$i$i$i$i$i$i$i1$i7 = $24;
      $scevgep$i$i$i$i$i$i$i2$i8 = (($27) + -4|0);
      $29 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i7))|0;
      $uglygep$i$i$i$i$i$i$i4$i10 = (($scevgep$i$i$i$i$i$i$i2$i8) + ($29)|0);
      $uglygep3$i$i$i$i$i$i$i5$i11 = $uglygep$i$i$i$i$i$i$i4$i10;
      $30 = $uglygep3$i$i$i$i$i$i$i5$i11 >>> 2;
      $31 = $30 ^ -1;
      $scevgep4$i$i$i$i$i$i$i6$i12 = (($27) + ($31<<2)|0);
      HEAP32[$26>>2] = $scevgep4$i$i$i$i$i$i$i6$i12;
     }
     __ZdlPv($24);
    }
    $43 = HEAP32[$__y>>2]|0;
    $44 = HEAP32[$__x>>2]|0;
    $45 = ($43|0)<($44|0);
    if (!($45)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    HEAP32[$__t$i25>>2] = $44;
    $46 = (($__t$i25) + 4|0);
    $47 = (($__x) + 4|0);
    __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($46,$47);
    $48 = HEAP32[$__y>>2]|0;
    HEAP32[$__x>>2] = $48;
    $49 = ($__x|0)==($__y|0);
    if ($49) {
     label = 20;
    } else {
     $50 = (($__y) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($__y) + 8|0);
     $53 = HEAP32[$52>>2]|0;
     __THREW__ = 0;
     invoke_viii(1787,($47|0),($51|0),($53|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if (!($55)) {
      label = 20;
     }
    }
    do {
     if ((label|0) == 20) {
      $56 = HEAP32[$__t$i25>>2]|0;
      HEAP32[$__y>>2] = $56;
      $57 = ($__t$i25|0)==($__y|0);
      $$pre$i27 = (($__t$i25) + 4|0);
      if (!($57)) {
       $58 = HEAP32[$$pre$i27>>2]|0;
       $59 = (($__t$i25) + 8|0);
       $60 = HEAP32[$59>>2]|0;
       __THREW__ = 0;
       invoke_viii(1787,($6|0),($58|0),($60|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
      }
      $63 = HEAP32[$$pre$i27>>2]|0;
      $64 = ($63|0)==(0|0);
      if ($64) {
       $$0 = 2;
       STACKTOP = sp;return ($$0|0);
      }
      $65 = (($__t$i25) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ($66|0)==($63|0);
      if (!($67)) {
       $__new_last2$i$i$i$i$i$i$i1$i31 = $63;
       $scevgep$i$i$i$i$i$i$i2$i32 = (($66) + -4|0);
       $68 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i31))|0;
       $uglygep$i$i$i$i$i$i$i4$i34 = (($scevgep$i$i$i$i$i$i$i2$i32) + ($68)|0);
       $uglygep3$i$i$i$i$i$i$i5$i35 = $uglygep$i$i$i$i$i$i$i4$i34;
       $69 = $uglygep3$i$i$i$i$i$i$i5$i35 >>> 2;
       $70 = $69 ^ -1;
       $scevgep4$i$i$i$i$i$i$i6$i36 = (($66) + ($70<<2)|0);
       HEAP32[$65>>2] = $scevgep4$i$i$i$i$i$i$i6$i36;
      }
      __ZdlPv($63);
      $$0 = 2;
      STACKTOP = sp;return ($$0|0);
     }
    } while(0);
    $71 = ___cxa_find_matching_catch()|0;
    $72 = tempRet0;
    $73 = (($__t$i25) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)==(0|0);
    if ($75) {
     ___resumeException($71|0);
     // unreachable;
    }
    $76 = (($__t$i25) + 8|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = ($77|0)==($74|0);
    if (!($78)) {
     $__new_last2$i$i$i$i$i$i$i$i39 = $74;
     $scevgep$i$i$i$i$i$i$i$i40 = (($77) + -4|0);
     $79 = (0 - ($__new_last2$i$i$i$i$i$i$i$i39))|0;
     $uglygep$i$i$i$i$i$i$i$i42 = (($scevgep$i$i$i$i$i$i$i$i40) + ($79)|0);
     $uglygep3$i$i$i$i$i$i$i$i43 = $uglygep$i$i$i$i$i$i$i$i42;
     $80 = $uglygep3$i$i$i$i$i$i$i$i43 >>> 2;
     $81 = $80 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i44 = (($77) + ($81<<2)|0);
     HEAP32[$76>>2] = $scevgep4$i$i$i$i$i$i$i$i44;
    }
    __ZdlPv($74);
    ___resumeException($71|0);
    // unreachable;
   }
  } while(0);
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  $34 = (($__t$i73) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   ___resumeException($32|0);
   // unreachable;
  }
  $37 = (($__t$i73) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==($35|0);
  if (!($39)) {
   $__new_last2$i$i$i$i$i$i$i$i15 = $35;
   $scevgep$i$i$i$i$i$i$i$i16 = (($38) + -4|0);
   $40 = (0 - ($__new_last2$i$i$i$i$i$i$i$i15))|0;
   $uglygep$i$i$i$i$i$i$i$i18 = (($scevgep$i$i$i$i$i$i$i$i16) + ($40)|0);
   $uglygep3$i$i$i$i$i$i$i$i19 = $uglygep$i$i$i$i$i$i$i$i18;
   $41 = $uglygep3$i$i$i$i$i$i$i$i19 >>> 2;
   $42 = $41 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i20 = (($38) + ($42<<2)|0);
   HEAP32[$37>>2] = $scevgep4$i$i$i$i$i$i$i$i20;
  }
  __ZdlPv($35);
  ___resumeException($32|0);
  // unreachable;
 }
 if ($4) {
  HEAP32[$__t$i73>>2] = $1;
  $82 = (($__t$i73) + 4|0);
  $83 = (($__x) + 4|0);
  __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($82,$83);
  $84 = HEAP32[$__z>>2]|0;
  HEAP32[$__x>>2] = $84;
  $85 = ($__x|0)==($__z|0);
  if ($85) {
   label = 34;
  } else {
   $86 = (($__z) + 4|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($__z) + 8|0);
   $89 = HEAP32[$88>>2]|0;
   __THREW__ = 0;
   invoke_viii(1787,($83|0),($87|0),($89|0));
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if (!($91)) {
    label = 34;
   }
  }
  do {
   if ((label|0) == 34) {
    $92 = HEAP32[$__t$i73>>2]|0;
    HEAP32[$__z>>2] = $92;
    $93 = ($__t$i73|0)==($__z|0);
    if ($93) {
     $$pre$i51 = (($__z) + 4|0);
     $$pre$phi$i53Z2D = $$pre$i51;
    } else {
     $94 = (($__z) + 4|0);
     $95 = (($__t$i73) + 4|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($__t$i73) + 8|0);
     $98 = HEAP32[$97>>2]|0;
     __THREW__ = 0;
     invoke_viii(1787,($94|0),($96|0),($98|0));
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      break;
     } else {
      $$pre$phi$i53Z2D = $95;
     }
    }
    $101 = HEAP32[$$pre$phi$i53Z2D>>2]|0;
    $102 = ($101|0)==(0|0);
    if ($102) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $103 = (($__t$i73) + 8|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($104|0)==($101|0);
    if (!($105)) {
     $__new_last2$i$i$i$i$i$i$i1$i55 = $101;
     $scevgep$i$i$i$i$i$i$i2$i56 = (($104) + -4|0);
     $106 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i55))|0;
     $uglygep$i$i$i$i$i$i$i4$i58 = (($scevgep$i$i$i$i$i$i$i2$i56) + ($106)|0);
     $uglygep3$i$i$i$i$i$i$i5$i59 = $uglygep$i$i$i$i$i$i$i4$i58;
     $107 = $uglygep3$i$i$i$i$i$i$i5$i59 >>> 2;
     $108 = $107 ^ -1;
     $scevgep4$i$i$i$i$i$i$i6$i60 = (($104) + ($108<<2)|0);
     HEAP32[$103>>2] = $scevgep4$i$i$i$i$i$i$i6$i60;
    }
    __ZdlPv($101);
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $109 = ___cxa_find_matching_catch()|0;
  $110 = tempRet0;
  $111 = (($__t$i73) + 4|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = ($112|0)==(0|0);
  if ($113) {
   ___resumeException($109|0);
   // unreachable;
  }
  $114 = (($__t$i73) + 8|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = ($115|0)==($112|0);
  if (!($116)) {
   $__new_last2$i$i$i$i$i$i$i$i63 = $112;
   $scevgep$i$i$i$i$i$i$i$i64 = (($115) + -4|0);
   $117 = (0 - ($__new_last2$i$i$i$i$i$i$i$i63))|0;
   $uglygep$i$i$i$i$i$i$i$i66 = (($scevgep$i$i$i$i$i$i$i$i64) + ($117)|0);
   $uglygep3$i$i$i$i$i$i$i$i67 = $uglygep$i$i$i$i$i$i$i$i66;
   $118 = $uglygep3$i$i$i$i$i$i$i$i67 >>> 2;
   $119 = $118 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i68 = (($115) + ($119<<2)|0);
   HEAP32[$114>>2] = $scevgep4$i$i$i$i$i$i$i$i68;
  }
  __ZdlPv($112);
  ___resumeException($109|0);
  // unreachable;
 }
 HEAP32[$__t$i73>>2] = $1;
 $120 = (($__t$i73) + 4|0);
 $121 = (($__x) + 4|0);
 __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($120,$121);
 $122 = HEAP32[$__y>>2]|0;
 HEAP32[$__x>>2] = $122;
 $123 = ($__x|0)==($__y|0);
 if ($123) {
  label = 48;
 } else {
  $124 = (($__y) + 4|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (($__y) + 8|0);
  $127 = HEAP32[$126>>2]|0;
  __THREW__ = 0;
  invoke_viii(1787,($121|0),($125|0),($127|0));
  $128 = __THREW__; __THREW__ = 0;
  $129 = $128&1;
  if (!($129)) {
   label = 48;
  }
 }
 do {
  if ((label|0) == 48) {
   $130 = HEAP32[$__t$i73>>2]|0;
   HEAP32[$__y>>2] = $130;
   $131 = ($__t$i73|0)==($__y|0);
   if ($131) {
    $$pre$i75 = (($__y) + 4|0);
    $$pre$phi$i77Z2D = $$pre$i75;
   } else {
    $132 = (($__y) + 4|0);
    $133 = (($__t$i73) + 4|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = (($__t$i73) + 8|0);
    $136 = HEAP32[$135>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($132|0),($134|0),($136|0));
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if ($138) {
     break;
    } else {
     $$pre$phi$i77Z2D = $133;
    }
   }
   $139 = HEAP32[$$pre$phi$i77Z2D>>2]|0;
   $140 = ($139|0)==(0|0);
   if (!($140)) {
    $141 = (($__t$i73) + 8|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = ($142|0)==($139|0);
    if (!($143)) {
     $__new_last2$i$i$i$i$i$i$i1$i79 = $139;
     $scevgep$i$i$i$i$i$i$i2$i80 = (($142) + -4|0);
     $144 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i79))|0;
     $uglygep$i$i$i$i$i$i$i4$i82 = (($scevgep$i$i$i$i$i$i$i2$i80) + ($144)|0);
     $uglygep3$i$i$i$i$i$i$i5$i83 = $uglygep$i$i$i$i$i$i$i4$i82;
     $145 = $uglygep3$i$i$i$i$i$i$i5$i83 >>> 2;
     $146 = $145 ^ -1;
     $scevgep4$i$i$i$i$i$i$i6$i84 = (($142) + ($146<<2)|0);
     HEAP32[$141>>2] = $scevgep4$i$i$i$i$i$i$i6$i84;
    }
    __ZdlPv($139);
   }
   $158 = HEAP32[$__z>>2]|0;
   $159 = HEAP32[$__y>>2]|0;
   $160 = ($158|0)<($159|0);
   if (!($160)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__t$i>>2] = $159;
   $161 = (($__t$i) + 4|0);
   $162 = (($__y) + 4|0);
   __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($161,$162);
   $163 = HEAP32[$__z>>2]|0;
   HEAP32[$__y>>2] = $163;
   $164 = ($__y|0)==($__z|0);
   if ($164) {
    label = 63;
   } else {
    $165 = (($__z) + 4|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = (($__z) + 8|0);
    $168 = HEAP32[$167>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($162|0),($166|0),($168|0));
    $169 = __THREW__; __THREW__ = 0;
    $170 = $169&1;
    if (!($170)) {
     label = 63;
    }
   }
   do {
    if ((label|0) == 63) {
     $171 = HEAP32[$__t$i>>2]|0;
     HEAP32[$__z>>2] = $171;
     $172 = ($__t$i|0)==($__z|0);
     if ($172) {
      $$pre$i = (($__z) + 4|0);
      $$pre$phi$iZ2D = $$pre$i;
     } else {
      $173 = (($__z) + 4|0);
      $174 = (($__t$i) + 4|0);
      $175 = HEAP32[$174>>2]|0;
      $176 = (($__t$i) + 8|0);
      $177 = HEAP32[$176>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($173|0),($175|0),($177|0));
      $178 = __THREW__; __THREW__ = 0;
      $179 = $178&1;
      if ($179) {
       break;
      } else {
       $$pre$phi$iZ2D = $174;
      }
     }
     $180 = HEAP32[$$pre$phi$iZ2D>>2]|0;
     $181 = ($180|0)==(0|0);
     if ($181) {
      $$0 = 2;
      STACKTOP = sp;return ($$0|0);
     }
     $182 = (($__t$i) + 8|0);
     $183 = HEAP32[$182>>2]|0;
     $184 = ($183|0)==($180|0);
     if (!($184)) {
      $__new_last2$i$i$i$i$i$i$i1$i = $180;
      $scevgep$i$i$i$i$i$i$i2$i = (($183) + -4|0);
      $185 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
      $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($185)|0);
      $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
      $186 = $uglygep3$i$i$i$i$i$i$i5$i >>> 2;
      $187 = $186 ^ -1;
      $scevgep4$i$i$i$i$i$i$i6$i = (($183) + ($187<<2)|0);
      HEAP32[$182>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
     }
     __ZdlPv($180);
     $$0 = 2;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $188 = ___cxa_find_matching_catch()|0;
   $189 = tempRet0;
   $190 = (($__t$i) + 4|0);
   $191 = HEAP32[$190>>2]|0;
   $192 = ($191|0)==(0|0);
   if ($192) {
    ___resumeException($188|0);
    // unreachable;
   }
   $193 = (($__t$i) + 8|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = ($194|0)==($191|0);
   if (!($195)) {
    $__new_last2$i$i$i$i$i$i$i$i = $191;
    $scevgep$i$i$i$i$i$i$i$i = (($194) + -4|0);
    $196 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($196)|0);
    $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
    $197 = $uglygep3$i$i$i$i$i$i$i$i >>> 2;
    $198 = $197 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i = (($194) + ($198<<2)|0);
    HEAP32[$193>>2] = $scevgep4$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($191);
   ___resumeException($188|0);
   // unreachable;
  }
 } while(0);
 $147 = ___cxa_find_matching_catch()|0;
 $148 = tempRet0;
 $149 = (($__t$i73) + 4|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = ($150|0)==(0|0);
 if ($151) {
  ___resumeException($147|0);
  // unreachable;
 }
 $152 = (($__t$i73) + 8|0);
 $153 = HEAP32[$152>>2]|0;
 $154 = ($153|0)==($150|0);
 if (!($154)) {
  $__new_last2$i$i$i$i$i$i$i$i87 = $150;
  $scevgep$i$i$i$i$i$i$i$i88 = (($153) + -4|0);
  $155 = (0 - ($__new_last2$i$i$i$i$i$i$i$i87))|0;
  $uglygep$i$i$i$i$i$i$i$i90 = (($scevgep$i$i$i$i$i$i$i$i88) + ($155)|0);
  $uglygep3$i$i$i$i$i$i$i$i91 = $uglygep$i$i$i$i$i$i$i$i90;
  $156 = $uglygep3$i$i$i$i$i$i$i$i91 >>> 2;
  $157 = $156 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i92 = (($153) + ($157<<2)|0);
  HEAP32[$152>>2] = $scevgep4$i$i$i$i$i$i$i$i92;
 }
 __ZdlPv($150);
 ___resumeException($147|0);
 // unreachable;
 return 0|0;
}
function __ZNSt3__17__sort4IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$pre$i = 0, $$pre$i27 = 0, $$pre$i3 = 0, $$pre$phi$i5Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i$i$i$i39 = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $__new_last2$i$i$i$i$i$i$i1$i31 = 0, $__new_last2$i$i$i$i$i$i$i1$i7 = 0, $__r$0 = 0, $__t$i25 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i$i$i$i40 = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep$i$i$i$i$i$i$i2$i32 = 0;
 var $scevgep$i$i$i$i$i$i$i2$i8 = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i$i$i$i44 = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $scevgep4$i$i$i$i$i$i$i6$i12 = 0, $scevgep4$i$i$i$i$i$i$i6$i36 = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i$i$i$i42 = 0, $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep$i$i$i$i$i$i$i4$i10 = 0, $uglygep$i$i$i$i$i$i$i4$i34 = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i$i$i$i43 = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, $uglygep3$i$i$i$i$i$i$i5$i11 = 0, $uglygep3$i$i$i$i$i$i$i5$i35 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i25 = sp;
 $0 = (__ZNSt3__17__sort3IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_T_($__x1,$__x2,$__x3,0)|0);
 $1 = HEAP32[$__x4>>2]|0;
 $2 = HEAP32[$__x3>>2]|0;
 $3 = ($1|0)<($2|0);
 if (!($3)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__t$i25>>2] = $2;
 $4 = (($__t$i25) + 4|0);
 $5 = (($__x3) + 4|0);
 __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($4,$5);
 $6 = HEAP32[$__x4>>2]|0;
 HEAP32[$__x3>>2] = $6;
 $7 = ($__x3|0)==($__x4|0);
 if ($7) {
  label = 4;
 } else {
  $8 = (($__x4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($__x4) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __THREW__ = 0;
  invoke_viii(1787,($5|0),($9|0),($11|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   $14 = HEAP32[$__t$i25>>2]|0;
   HEAP32[$__x4>>2] = $14;
   $15 = ($__t$i25|0)==($__x4|0);
   if ($15) {
    $$pre$i3 = (($__x4) + 4|0);
    $$pre$phi$i5Z2D = $$pre$i3;
   } else {
    $16 = (($__x4) + 4|0);
    $17 = (($__t$i25) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__t$i25) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($16|0),($18|0),($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    } else {
     $$pre$phi$i5Z2D = $17;
    }
   }
   $23 = HEAP32[$$pre$phi$i5Z2D>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = (($__t$i25) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==($23|0);
    if (!($27)) {
     $__new_last2$i$i$i$i$i$i$i1$i7 = $23;
     $scevgep$i$i$i$i$i$i$i2$i8 = (($26) + -4|0);
     $28 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i7))|0;
     $uglygep$i$i$i$i$i$i$i4$i10 = (($scevgep$i$i$i$i$i$i$i2$i8) + ($28)|0);
     $uglygep3$i$i$i$i$i$i$i5$i11 = $uglygep$i$i$i$i$i$i$i4$i10;
     $29 = $uglygep3$i$i$i$i$i$i$i5$i11 >>> 2;
     $30 = $29 ^ -1;
     $scevgep4$i$i$i$i$i$i$i6$i12 = (($26) + ($30<<2)|0);
     HEAP32[$25>>2] = $scevgep4$i$i$i$i$i$i$i6$i12;
    }
    __ZdlPv($23);
   }
   $42 = (($0) + 1)|0;
   $43 = HEAP32[$__x3>>2]|0;
   $44 = HEAP32[$__x2>>2]|0;
   $45 = ($43|0)<($44|0);
   if (!($45)) {
    $__r$0 = $42;
    STACKTOP = sp;return ($__r$0|0);
   }
   HEAP32[$__t$i25>>2] = $44;
   $46 = (($__t$i25) + 4|0);
   $47 = (($__x2) + 4|0);
   __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($46,$47);
   $48 = HEAP32[$__x3>>2]|0;
   HEAP32[$__x2>>2] = $48;
   $49 = ($__x2|0)==($__x3|0);
   if ($49) {
    label = 19;
   } else {
    $50 = (($__x3) + 4|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($__x3) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($47|0),($51|0),($53|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     label = 19;
    }
   }
   do {
    if ((label|0) == 19) {
     $56 = HEAP32[$__t$i25>>2]|0;
     HEAP32[$__x3>>2] = $56;
     $57 = ($__t$i25|0)==($__x3|0);
     $$pre$i27 = (($__t$i25) + 4|0);
     if (!($57)) {
      $58 = HEAP32[$$pre$i27>>2]|0;
      $59 = (($__t$i25) + 8|0);
      $60 = HEAP32[$59>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($5|0),($58|0),($60|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
     }
     $63 = HEAP32[$$pre$i27>>2]|0;
     $64 = ($63|0)==(0|0);
     if (!($64)) {
      $65 = (($__t$i25) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ($66|0)==($63|0);
      if (!($67)) {
       $__new_last2$i$i$i$i$i$i$i1$i31 = $63;
       $scevgep$i$i$i$i$i$i$i2$i32 = (($66) + -4|0);
       $68 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i31))|0;
       $uglygep$i$i$i$i$i$i$i4$i34 = (($scevgep$i$i$i$i$i$i$i2$i32) + ($68)|0);
       $uglygep3$i$i$i$i$i$i$i5$i35 = $uglygep$i$i$i$i$i$i$i4$i34;
       $69 = $uglygep3$i$i$i$i$i$i$i5$i35 >>> 2;
       $70 = $69 ^ -1;
       $scevgep4$i$i$i$i$i$i$i6$i36 = (($66) + ($70<<2)|0);
       HEAP32[$65>>2] = $scevgep4$i$i$i$i$i$i$i6$i36;
      }
      __ZdlPv($63);
     }
     $82 = (($0) + 2)|0;
     $83 = HEAP32[$__x2>>2]|0;
     $84 = HEAP32[$__x1>>2]|0;
     $85 = ($83|0)<($84|0);
     if (!($85)) {
      $__r$0 = $82;
      STACKTOP = sp;return ($__r$0|0);
     }
     HEAP32[$__t$i25>>2] = $84;
     $86 = (($__t$i25) + 4|0);
     $87 = (($__x1) + 4|0);
     __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($86,$87);
     $88 = HEAP32[$__x2>>2]|0;
     HEAP32[$__x1>>2] = $88;
     $89 = ($__x1|0)==($__x2|0);
     if ($89) {
      label = 33;
     } else {
      $90 = (($__x2) + 4|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($__x2) + 8|0);
      $93 = HEAP32[$92>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($87|0),($91|0),($93|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if (!($95)) {
       label = 33;
      }
     }
     do {
      if ((label|0) == 33) {
       $96 = HEAP32[$__t$i25>>2]|0;
       HEAP32[$__x2>>2] = $96;
       $97 = ($__t$i25|0)==($__x2|0);
       $$pre$i = (($__t$i25) + 4|0);
       if (!($97)) {
        $98 = HEAP32[$$pre$i>>2]|0;
        $99 = (($__t$i25) + 8|0);
        $100 = HEAP32[$99>>2]|0;
        __THREW__ = 0;
        invoke_viii(1787,($47|0),($98|0),($100|0));
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         break;
        }
       }
       $103 = HEAP32[$$pre$i>>2]|0;
       $104 = ($103|0)==(0|0);
       if (!($104)) {
        $105 = (($__t$i25) + 8|0);
        $106 = HEAP32[$105>>2]|0;
        $107 = ($106|0)==($103|0);
        if (!($107)) {
         $__new_last2$i$i$i$i$i$i$i1$i = $103;
         $scevgep$i$i$i$i$i$i$i2$i = (($106) + -4|0);
         $108 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
         $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($108)|0);
         $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
         $109 = $uglygep3$i$i$i$i$i$i$i5$i >>> 2;
         $110 = $109 ^ -1;
         $scevgep4$i$i$i$i$i$i$i6$i = (($106) + ($110<<2)|0);
         HEAP32[$105>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
        }
        __ZdlPv($103);
       }
       $122 = (($0) + 3)|0;
       $__r$0 = $122;
       STACKTOP = sp;return ($__r$0|0);
      }
     } while(0);
     $111 = ___cxa_find_matching_catch()|0;
     $112 = tempRet0;
     $113 = (($__t$i25) + 4|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)==(0|0);
     if ($115) {
      ___resumeException($111|0);
      // unreachable;
     }
     $116 = (($__t$i25) + 8|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ($117|0)==($114|0);
     if (!($118)) {
      $__new_last2$i$i$i$i$i$i$i$i = $114;
      $scevgep$i$i$i$i$i$i$i$i = (($117) + -4|0);
      $119 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($119)|0);
      $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
      $120 = $uglygep3$i$i$i$i$i$i$i$i >>> 2;
      $121 = $120 ^ -1;
      $scevgep4$i$i$i$i$i$i$i$i = (($117) + ($121<<2)|0);
      HEAP32[$116>>2] = $scevgep4$i$i$i$i$i$i$i$i;
     }
     __ZdlPv($114);
     ___resumeException($111|0);
     // unreachable;
    }
   } while(0);
   $71 = ___cxa_find_matching_catch()|0;
   $72 = tempRet0;
   $73 = (($__t$i25) + 4|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    ___resumeException($71|0);
    // unreachable;
   }
   $76 = (($__t$i25) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==($74|0);
   if (!($78)) {
    $__new_last2$i$i$i$i$i$i$i$i39 = $74;
    $scevgep$i$i$i$i$i$i$i$i40 = (($77) + -4|0);
    $79 = (0 - ($__new_last2$i$i$i$i$i$i$i$i39))|0;
    $uglygep$i$i$i$i$i$i$i$i42 = (($scevgep$i$i$i$i$i$i$i$i40) + ($79)|0);
    $uglygep3$i$i$i$i$i$i$i$i43 = $uglygep$i$i$i$i$i$i$i$i42;
    $80 = $uglygep3$i$i$i$i$i$i$i$i43 >>> 2;
    $81 = $80 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i44 = (($77) + ($81<<2)|0);
    HEAP32[$76>>2] = $scevgep4$i$i$i$i$i$i$i$i44;
   }
   __ZdlPv($74);
   ___resumeException($71|0);
   // unreachable;
  }
 } while(0);
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $33 = (($__t$i25) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  ___resumeException($31|0);
  // unreachable;
 }
 $36 = (($__t$i25) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($34|0);
 if (!($38)) {
  $__new_last2$i$i$i$i$i$i$i$i15 = $34;
  $scevgep$i$i$i$i$i$i$i$i16 = (($37) + -4|0);
  $39 = (0 - ($__new_last2$i$i$i$i$i$i$i$i15))|0;
  $uglygep$i$i$i$i$i$i$i$i18 = (($scevgep$i$i$i$i$i$i$i$i16) + ($39)|0);
  $uglygep3$i$i$i$i$i$i$i$i19 = $uglygep$i$i$i$i$i$i$i$i18;
  $40 = $uglygep3$i$i$i$i$i$i$i$i19 >>> 2;
  $41 = $40 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i20 = (($37) + ($41<<2)|0);
  HEAP32[$36>>2] = $scevgep4$i$i$i$i$i$i$i$i20;
 }
 __ZdlPv($34);
 ___resumeException($31|0);
 // unreachable;
 return 0|0;
}
function __ZNSt3__17__sort5IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $$pre$i = 0, $$pre$i27 = 0, $$pre$i3 = 0, $$pre$i51 = 0, $$pre$phi$i5Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i$i$i$i39 = 0, $__new_last2$i$i$i$i$i$i$i$i63 = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $__new_last2$i$i$i$i$i$i$i1$i31 = 0, $__new_last2$i$i$i$i$i$i$i1$i55 = 0, $__new_last2$i$i$i$i$i$i$i1$i7 = 0, $__r$0 = 0, $__t$i49 = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i16 = 0;
 var $scevgep$i$i$i$i$i$i$i$i40 = 0, $scevgep$i$i$i$i$i$i$i$i64 = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep$i$i$i$i$i$i$i2$i32 = 0, $scevgep$i$i$i$i$i$i$i2$i56 = 0, $scevgep$i$i$i$i$i$i$i2$i8 = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i$i$i$i44 = 0, $scevgep4$i$i$i$i$i$i$i$i68 = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $scevgep4$i$i$i$i$i$i$i6$i12 = 0, $scevgep4$i$i$i$i$i$i$i6$i36 = 0, $scevgep4$i$i$i$i$i$i$i6$i60 = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i$i$i$i42 = 0, $uglygep$i$i$i$i$i$i$i$i66 = 0, $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep$i$i$i$i$i$i$i4$i10 = 0;
 var $uglygep$i$i$i$i$i$i$i4$i34 = 0, $uglygep$i$i$i$i$i$i$i4$i58 = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i$i$i$i43 = 0, $uglygep3$i$i$i$i$i$i$i$i67 = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, $uglygep3$i$i$i$i$i$i$i5$i11 = 0, $uglygep3$i$i$i$i$i$i$i5$i35 = 0, $uglygep3$i$i$i$i$i$i$i5$i59 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i49 = sp;
 $0 = (__ZNSt3__17__sort4IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = HEAP32[$__x5>>2]|0;
 $2 = HEAP32[$__x4>>2]|0;
 $3 = ($1|0)<($2|0);
 if (!($3)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__t$i49>>2] = $2;
 $4 = (($__t$i49) + 4|0);
 $5 = (($__x4) + 4|0);
 __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($4,$5);
 $6 = HEAP32[$__x5>>2]|0;
 HEAP32[$__x4>>2] = $6;
 $7 = ($__x4|0)==($__x5|0);
 if ($7) {
  label = 4;
 } else {
  $8 = (($__x5) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($__x5) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __THREW__ = 0;
  invoke_viii(1787,($5|0),($9|0),($11|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   $14 = HEAP32[$__t$i49>>2]|0;
   HEAP32[$__x5>>2] = $14;
   $15 = ($__t$i49|0)==($__x5|0);
   if ($15) {
    $$pre$i3 = (($__x5) + 4|0);
    $$pre$phi$i5Z2D = $$pre$i3;
   } else {
    $16 = (($__x5) + 4|0);
    $17 = (($__t$i49) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__t$i49) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($16|0),($18|0),($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    } else {
     $$pre$phi$i5Z2D = $17;
    }
   }
   $23 = HEAP32[$$pre$phi$i5Z2D>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    $25 = (($__t$i49) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==($23|0);
    if (!($27)) {
     $__new_last2$i$i$i$i$i$i$i1$i7 = $23;
     $scevgep$i$i$i$i$i$i$i2$i8 = (($26) + -4|0);
     $28 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i7))|0;
     $uglygep$i$i$i$i$i$i$i4$i10 = (($scevgep$i$i$i$i$i$i$i2$i8) + ($28)|0);
     $uglygep3$i$i$i$i$i$i$i5$i11 = $uglygep$i$i$i$i$i$i$i4$i10;
     $29 = $uglygep3$i$i$i$i$i$i$i5$i11 >>> 2;
     $30 = $29 ^ -1;
     $scevgep4$i$i$i$i$i$i$i6$i12 = (($26) + ($30<<2)|0);
     HEAP32[$25>>2] = $scevgep4$i$i$i$i$i$i$i6$i12;
    }
    __ZdlPv($23);
   }
   $42 = (($0) + 1)|0;
   $43 = HEAP32[$__x4>>2]|0;
   $44 = HEAP32[$__x3>>2]|0;
   $45 = ($43|0)<($44|0);
   if (!($45)) {
    $__r$0 = $42;
    STACKTOP = sp;return ($__r$0|0);
   }
   HEAP32[$__t$i49>>2] = $44;
   $46 = (($__t$i49) + 4|0);
   $47 = (($__x3) + 4|0);
   __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($46,$47);
   $48 = HEAP32[$__x4>>2]|0;
   HEAP32[$__x3>>2] = $48;
   $49 = ($__x3|0)==($__x4|0);
   if ($49) {
    label = 19;
   } else {
    $50 = (($__x4) + 4|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($__x4) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($47|0),($51|0),($53|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     label = 19;
    }
   }
   do {
    if ((label|0) == 19) {
     $56 = HEAP32[$__t$i49>>2]|0;
     HEAP32[$__x4>>2] = $56;
     $57 = ($__t$i49|0)==($__x4|0);
     $$pre$i27 = (($__t$i49) + 4|0);
     if (!($57)) {
      $58 = HEAP32[$$pre$i27>>2]|0;
      $59 = (($__t$i49) + 8|0);
      $60 = HEAP32[$59>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($5|0),($58|0),($60|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
     }
     $63 = HEAP32[$$pre$i27>>2]|0;
     $64 = ($63|0)==(0|0);
     if (!($64)) {
      $65 = (($__t$i49) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ($66|0)==($63|0);
      if (!($67)) {
       $__new_last2$i$i$i$i$i$i$i1$i31 = $63;
       $scevgep$i$i$i$i$i$i$i2$i32 = (($66) + -4|0);
       $68 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i31))|0;
       $uglygep$i$i$i$i$i$i$i4$i34 = (($scevgep$i$i$i$i$i$i$i2$i32) + ($68)|0);
       $uglygep3$i$i$i$i$i$i$i5$i35 = $uglygep$i$i$i$i$i$i$i4$i34;
       $69 = $uglygep3$i$i$i$i$i$i$i5$i35 >>> 2;
       $70 = $69 ^ -1;
       $scevgep4$i$i$i$i$i$i$i6$i36 = (($66) + ($70<<2)|0);
       HEAP32[$65>>2] = $scevgep4$i$i$i$i$i$i$i6$i36;
      }
      __ZdlPv($63);
     }
     $82 = (($0) + 2)|0;
     $83 = HEAP32[$__x3>>2]|0;
     $84 = HEAP32[$__x2>>2]|0;
     $85 = ($83|0)<($84|0);
     if (!($85)) {
      $__r$0 = $82;
      STACKTOP = sp;return ($__r$0|0);
     }
     HEAP32[$__t$i49>>2] = $84;
     $86 = (($__t$i49) + 4|0);
     $87 = (($__x2) + 4|0);
     __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($86,$87);
     $88 = HEAP32[$__x3>>2]|0;
     HEAP32[$__x2>>2] = $88;
     $89 = ($__x2|0)==($__x3|0);
     if ($89) {
      label = 33;
     } else {
      $90 = (($__x3) + 4|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($__x3) + 8|0);
      $93 = HEAP32[$92>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($87|0),($91|0),($93|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if (!($95)) {
       label = 33;
      }
     }
     do {
      if ((label|0) == 33) {
       $96 = HEAP32[$__t$i49>>2]|0;
       HEAP32[$__x3>>2] = $96;
       $97 = ($__t$i49|0)==($__x3|0);
       $$pre$i51 = (($__t$i49) + 4|0);
       if (!($97)) {
        $98 = HEAP32[$$pre$i51>>2]|0;
        $99 = (($__t$i49) + 8|0);
        $100 = HEAP32[$99>>2]|0;
        __THREW__ = 0;
        invoke_viii(1787,($47|0),($98|0),($100|0));
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         break;
        }
       }
       $103 = HEAP32[$$pre$i51>>2]|0;
       $104 = ($103|0)==(0|0);
       if (!($104)) {
        $105 = (($__t$i49) + 8|0);
        $106 = HEAP32[$105>>2]|0;
        $107 = ($106|0)==($103|0);
        if (!($107)) {
         $__new_last2$i$i$i$i$i$i$i1$i55 = $103;
         $scevgep$i$i$i$i$i$i$i2$i56 = (($106) + -4|0);
         $108 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i55))|0;
         $uglygep$i$i$i$i$i$i$i4$i58 = (($scevgep$i$i$i$i$i$i$i2$i56) + ($108)|0);
         $uglygep3$i$i$i$i$i$i$i5$i59 = $uglygep$i$i$i$i$i$i$i4$i58;
         $109 = $uglygep3$i$i$i$i$i$i$i5$i59 >>> 2;
         $110 = $109 ^ -1;
         $scevgep4$i$i$i$i$i$i$i6$i60 = (($106) + ($110<<2)|0);
         HEAP32[$105>>2] = $scevgep4$i$i$i$i$i$i$i6$i60;
        }
        __ZdlPv($103);
       }
       $122 = (($0) + 3)|0;
       $123 = HEAP32[$__x2>>2]|0;
       $124 = HEAP32[$__x1>>2]|0;
       $125 = ($123|0)<($124|0);
       if (!($125)) {
        $__r$0 = $122;
        STACKTOP = sp;return ($__r$0|0);
       }
       HEAP32[$__t$i49>>2] = $124;
       $126 = (($__t$i49) + 4|0);
       $127 = (($__x1) + 4|0);
       __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($126,$127);
       $128 = HEAP32[$__x2>>2]|0;
       HEAP32[$__x1>>2] = $128;
       $129 = ($__x1|0)==($__x2|0);
       if ($129) {
        label = 47;
       } else {
        $130 = (($__x2) + 4|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = (($__x2) + 8|0);
        $133 = HEAP32[$132>>2]|0;
        __THREW__ = 0;
        invoke_viii(1787,($127|0),($131|0),($133|0));
        $134 = __THREW__; __THREW__ = 0;
        $135 = $134&1;
        if (!($135)) {
         label = 47;
        }
       }
       do {
        if ((label|0) == 47) {
         $136 = HEAP32[$__t$i49>>2]|0;
         HEAP32[$__x2>>2] = $136;
         $137 = ($__t$i49|0)==($__x2|0);
         $$pre$i = (($__t$i49) + 4|0);
         if (!($137)) {
          $138 = HEAP32[$$pre$i>>2]|0;
          $139 = (($__t$i49) + 8|0);
          $140 = HEAP32[$139>>2]|0;
          __THREW__ = 0;
          invoke_viii(1787,($87|0),($138|0),($140|0));
          $141 = __THREW__; __THREW__ = 0;
          $142 = $141&1;
          if ($142) {
           break;
          }
         }
         $143 = HEAP32[$$pre$i>>2]|0;
         $144 = ($143|0)==(0|0);
         if (!($144)) {
          $145 = (($__t$i49) + 8|0);
          $146 = HEAP32[$145>>2]|0;
          $147 = ($146|0)==($143|0);
          if (!($147)) {
           $__new_last2$i$i$i$i$i$i$i1$i = $143;
           $scevgep$i$i$i$i$i$i$i2$i = (($146) + -4|0);
           $148 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
           $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($148)|0);
           $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
           $149 = $uglygep3$i$i$i$i$i$i$i5$i >>> 2;
           $150 = $149 ^ -1;
           $scevgep4$i$i$i$i$i$i$i6$i = (($146) + ($150<<2)|0);
           HEAP32[$145>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
          }
          __ZdlPv($143);
         }
         $162 = (($0) + 4)|0;
         $__r$0 = $162;
         STACKTOP = sp;return ($__r$0|0);
        }
       } while(0);
       $151 = ___cxa_find_matching_catch()|0;
       $152 = tempRet0;
       $153 = (($__t$i49) + 4|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = ($154|0)==(0|0);
       if ($155) {
        ___resumeException($151|0);
        // unreachable;
       }
       $156 = (($__t$i49) + 8|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = ($157|0)==($154|0);
       if (!($158)) {
        $__new_last2$i$i$i$i$i$i$i$i = $154;
        $scevgep$i$i$i$i$i$i$i$i = (($157) + -4|0);
        $159 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($159)|0);
        $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
        $160 = $uglygep3$i$i$i$i$i$i$i$i >>> 2;
        $161 = $160 ^ -1;
        $scevgep4$i$i$i$i$i$i$i$i = (($157) + ($161<<2)|0);
        HEAP32[$156>>2] = $scevgep4$i$i$i$i$i$i$i$i;
       }
       __ZdlPv($154);
       ___resumeException($151|0);
       // unreachable;
      }
     } while(0);
     $111 = ___cxa_find_matching_catch()|0;
     $112 = tempRet0;
     $113 = (($__t$i49) + 4|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)==(0|0);
     if ($115) {
      ___resumeException($111|0);
      // unreachable;
     }
     $116 = (($__t$i49) + 8|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ($117|0)==($114|0);
     if (!($118)) {
      $__new_last2$i$i$i$i$i$i$i$i63 = $114;
      $scevgep$i$i$i$i$i$i$i$i64 = (($117) + -4|0);
      $119 = (0 - ($__new_last2$i$i$i$i$i$i$i$i63))|0;
      $uglygep$i$i$i$i$i$i$i$i66 = (($scevgep$i$i$i$i$i$i$i$i64) + ($119)|0);
      $uglygep3$i$i$i$i$i$i$i$i67 = $uglygep$i$i$i$i$i$i$i$i66;
      $120 = $uglygep3$i$i$i$i$i$i$i$i67 >>> 2;
      $121 = $120 ^ -1;
      $scevgep4$i$i$i$i$i$i$i$i68 = (($117) + ($121<<2)|0);
      HEAP32[$116>>2] = $scevgep4$i$i$i$i$i$i$i$i68;
     }
     __ZdlPv($114);
     ___resumeException($111|0);
     // unreachable;
    }
   } while(0);
   $71 = ___cxa_find_matching_catch()|0;
   $72 = tempRet0;
   $73 = (($__t$i49) + 4|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    ___resumeException($71|0);
    // unreachable;
   }
   $76 = (($__t$i49) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==($74|0);
   if (!($78)) {
    $__new_last2$i$i$i$i$i$i$i$i39 = $74;
    $scevgep$i$i$i$i$i$i$i$i40 = (($77) + -4|0);
    $79 = (0 - ($__new_last2$i$i$i$i$i$i$i$i39))|0;
    $uglygep$i$i$i$i$i$i$i$i42 = (($scevgep$i$i$i$i$i$i$i$i40) + ($79)|0);
    $uglygep3$i$i$i$i$i$i$i$i43 = $uglygep$i$i$i$i$i$i$i$i42;
    $80 = $uglygep3$i$i$i$i$i$i$i$i43 >>> 2;
    $81 = $80 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i44 = (($77) + ($81<<2)|0);
    HEAP32[$76>>2] = $scevgep4$i$i$i$i$i$i$i$i44;
   }
   __ZdlPv($74);
   ___resumeException($71|0);
   // unreachable;
  }
 } while(0);
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $33 = (($__t$i49) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  ___resumeException($31|0);
  // unreachable;
 }
 $36 = (($__t$i49) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($34|0);
 if (!($38)) {
  $__new_last2$i$i$i$i$i$i$i$i15 = $34;
  $scevgep$i$i$i$i$i$i$i$i16 = (($37) + -4|0);
  $39 = (0 - ($__new_last2$i$i$i$i$i$i$i$i15))|0;
  $uglygep$i$i$i$i$i$i$i$i18 = (($scevgep$i$i$i$i$i$i$i$i16) + ($39)|0);
  $uglygep3$i$i$i$i$i$i$i$i19 = $uglygep$i$i$i$i$i$i$i$i18;
  $40 = $uglygep3$i$i$i$i$i$i$i$i19 >>> 2;
  $41 = $40 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i20 = (($37) + ($41<<2)|0);
  HEAP32[$36>>2] = $scevgep4$i$i$i$i$i$i$i$i20;
 }
 __ZdlPv($34);
 ___resumeException($31|0);
 // unreachable;
 return 0|0;
}
function __ZNSt3__118__insertion_sort_3IRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$pre = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$014 = 0, $__j$015 = 0, $__j$015$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa16 = 0;
 var $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $__t = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = (($__first) + 32|0);
 $1 = (($__first) + 16|0);
 (__ZNSt3__17__sort3IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 48|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($__t) + 4|0);
 $5 = (($__t) + 4|0);
 $6 = (($__t) + 8|0);
 $__i$014 = $2;$__j$015 = $0;
 L4: while(1) {
  $7 = HEAP32[$__i$014>>2]|0;
  $8 = HEAP32[$__j$015>>2]|0;
  $9 = ($7|0)<($8|0);
  if ($9) {
   HEAP32[$__t>>2] = $7;
   $10 = (($__i$014) + 4|0);
   __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($4,$10);
   $$pre = HEAP32[$__j$015>>2]|0;
   $11 = $$pre;$__j$1 = $__i$014;$__k$0 = $__j$015;
   while(1) {
    HEAP32[$__j$1>>2] = $11;
    $12 = (($__j$1) + 4|0);
    $13 = (($__k$0) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($__k$0) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($12|0),($14|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 15;
     break L4;
    }
    $19 = ($__k$0|0)==($__first|0);
    if ($19) {
     label = 7;
     break;
    }
    $20 = (($__k$0) + -16|0);
    $21 = HEAP32[$__t>>2]|0;
    $22 = HEAP32[$20>>2]|0;
    $23 = ($21|0)<($22|0);
    if ($23) {
     $__j$1$phi = $__k$0;$11 = $22;$__k$0 = $20;$__j$1 = $__j$1$phi;
    } else {
     $24 = $21;$__k$0$lcssa16 = $__k$0;
     break;
    }
   }
   if ((label|0) == 7) {
    label = 0;
    $$pre18 = HEAP32[$__t>>2]|0;
    $24 = $$pre18;$__k$0$lcssa16 = $__first;
   }
   HEAP32[$__k$0>>2] = $24;
   $25 = ($__k$0$lcssa16|0)==($__t|0);
   if (!($25)) {
    $26 = (($__k$0$lcssa16) + 4|0);
    $27 = HEAP32[$5>>2]|0;
    $28 = HEAP32[$6>>2]|0;
    __THREW__ = 0;
    invoke_viii(1787,($26|0),($27|0),($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     label = 16;
     break;
    }
   }
   $31 = HEAP32[$5>>2]|0;
   $32 = ($31|0)==(0|0);
   if (!($32)) {
    $33 = HEAP32[$6>>2]|0;
    $34 = ($33|0)==($31|0);
    if (!($34)) {
     $__new_last2$i$i$i$i$i$i$i1 = $31;
     $scevgep$i$i$i$i$i$i$i2 = (($33) + -4|0);
     $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
     $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
     $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
     $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
     $37 = $36 ^ -1;
     $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<2)|0);
     HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i6;
    }
    __ZdlPv($31);
   }
  }
  $49 = (($__i$014) + 16|0);
  $50 = ($49|0)==($__last|0);
  if ($50) {
   label = 22;
   break;
  } else {
   $__j$015$phi = $__i$014;$__i$014 = $49;$__j$015 = $__j$015$phi;
  }
 }
 if ((label|0) == 15) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  $lpad$phi$index = $38;$lpad$phi$index2 = $39;
 }
 else if ((label|0) == 16) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  $lpad$phi$index = $40;$lpad$phi$index2 = $41;
 }
 else if ((label|0) == 22) {
  STACKTOP = sp;return;
 }
 $42 = HEAP32[$5>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $44 = HEAP32[$6>>2]|0;
 $45 = ($44|0)==($42|0);
 if (!($45)) {
  $__new_last2$i$i$i$i$i$i$i = $42;
  $scevgep$i$i$i$i$i$i$i = (($44) + -4|0);
  $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
  $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
  $47 = $uglygep3$i$i$i$i$i$i$i >>> 2;
  $48 = $47 ^ -1;
  $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<2)|0);
  HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i;
 }
 __ZdlPv($42);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__127__insertion_sort_incompleteIRN15ResourceManager10Dependency6SorterEPS2_EEbT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0118 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $$pre = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre21 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__count$016 = 0, $__count$1 = 0, $__i$017 = 0, $__i$1 = 0, $__i$2 = 0, $__j$015 = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa19 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $__t = 0, $__t$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i = sp + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 4;
 switch ($3|0) {
 case 1: case 0:  {
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 4:  {
  $48 = (($__first) + 16|0);
  $49 = (($__first) + 32|0);
  $50 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_S6_T_($__first,$48,$49,$50,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  HEAP32[$__t$i>>2] = $6;
  $8 = (($__t$i) + 4|0);
  $9 = (($__first) + 4|0);
  __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($8,$9);
  $10 = HEAP32[$4>>2]|0;
  HEAP32[$__first>>2] = $10;
  $11 = ($4|0)==($__first|0);
  if ($11) {
   label = 5;
  } else {
   $12 = (($__last) + -12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($__last) + -8|0);
   $15 = HEAP32[$14>>2]|0;
   __THREW__ = 0;
   invoke_viii(1787,($9|0),($13|0),($15|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    label = 5;
   }
  }
  do {
   if ((label|0) == 5) {
    $18 = HEAP32[$__t$i>>2]|0;
    HEAP32[$4>>2] = $18;
    $19 = ($__t$i|0)==($4|0);
    if ($19) {
     $$pre$i = (($__t$i) + 4|0);
     $$pre$phi$iZ2D = $$pre$i;
    } else {
     $20 = (($__last) + -12|0);
     $21 = (($__t$i) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($__t$i) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_viii(1787,($20|0),($22|0),($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     } else {
      $$pre$phi$iZ2D = $21;
     }
    }
    $27 = HEAP32[$$pre$phi$iZ2D>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     $$3 = 1;
     STACKTOP = sp;return ($$3|0);
    }
    $29 = (($__t$i) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==($27|0);
    if (!($31)) {
     $__new_last2$i$i$i$i$i$i$i1$i = $27;
     $scevgep$i$i$i$i$i$i$i2$i = (($30) + -4|0);
     $32 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
     $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($32)|0);
     $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
     $33 = $uglygep3$i$i$i$i$i$i$i5$i >>> 2;
     $34 = $33 ^ -1;
     $scevgep4$i$i$i$i$i$i$i6$i = (($30) + ($34<<2)|0);
     HEAP32[$29>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
    }
    __ZdlPv($27);
    $$3 = 1;
    STACKTOP = sp;return ($$3|0);
   }
  } while(0);
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  $37 = (($__t$i) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0|0);
  if ($39) {
   ___resumeException($35|0);
   // unreachable;
  }
  $40 = (($__t$i) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==($38|0);
  if (!($42)) {
   $__new_last2$i$i$i$i$i$i$i$i = $38;
   $scevgep$i$i$i$i$i$i$i$i = (($41) + -4|0);
   $43 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($43)|0);
   $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
   $44 = $uglygep3$i$i$i$i$i$i$i$i >>> 2;
   $45 = $44 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i = (($41) + ($45<<2)|0);
   HEAP32[$40>>2] = $scevgep4$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($38);
  ___resumeException($35|0);
  // unreachable;
  break;
 }
 case 3:  {
  $46 = (($__first) + 16|0);
  $47 = (($__last) + -16|0);
  (__ZNSt3__17__sort3IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_T_($__first,$46,$47,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 5:  {
  $51 = (($__first) + 16|0);
  $52 = (($__first) + 32|0);
  $53 = (($__first) + 48|0);
  $54 = (($__last) + -16|0);
  (__ZNSt3__17__sort5IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_S6_S6_T_($__first,$51,$52,$53,$54,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 default: {
  $55 = (($__first) + 32|0);
  $56 = (($__first) + 16|0);
  (__ZNSt3__17__sort3IRN15ResourceManager10Dependency6SorterEPS2_EEjT0_S6_S6_T_($__first,$56,$55,0)|0);
  $57 = (($__first) + 48|0);
  $58 = ($57|0)==($__last|0);
  if ($58) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  $59 = (($__t) + 4|0);
  $60 = (($__t) + 4|0);
  $61 = (($__t) + 8|0);
  $$0118 = 0;$__count$016 = 0;$__i$017 = $57;$__j$015 = $55;
  L9: while(1) {
   $62 = HEAP32[$__i$017>>2]|0;
   $63 = HEAP32[$__j$015>>2]|0;
   $64 = ($62|0)<($63|0);
   if ($64) {
    HEAP32[$__t>>2] = $62;
    $65 = (($__i$017) + 4|0);
    __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($59,$65);
    $$pre = HEAP32[$__j$015>>2]|0;
    $66 = $$pre;$__j$1 = $__i$017;$__k$0 = $__j$015;
    while(1) {
     HEAP32[$__j$1>>2] = $66;
     $67 = ($__j$1|0)==($__k$0|0);
     if (!($67)) {
      $68 = (($__j$1) + 4|0);
      $69 = (($__k$0) + 4|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = (($__k$0) + 8|0);
      $72 = HEAP32[$71>>2]|0;
      __THREW__ = 0;
      invoke_viii(1787,($68|0),($70|0),($72|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       label = 33;
       break L9;
      }
     }
     $75 = ($__k$0|0)==($__first|0);
     if ($75) {
      label = 27;
      break;
     }
     $76 = (($__k$0) + -16|0);
     $77 = HEAP32[$__t>>2]|0;
     $78 = HEAP32[$76>>2]|0;
     $79 = ($77|0)<($78|0);
     if ($79) {
      $__j$1$phi = $__k$0;$66 = $78;$__k$0 = $76;$__j$1 = $__j$1$phi;
     } else {
      $80 = $77;$__k$0$lcssa19 = $__k$0;
      break;
     }
    }
    if ((label|0) == 27) {
     label = 0;
     $$pre21 = HEAP32[$__t>>2]|0;
     $80 = $$pre21;$__k$0$lcssa19 = $__first;
    }
    HEAP32[$__k$0>>2] = $80;
    $81 = ($__k$0$lcssa19|0)==($__t|0);
    if (!($81)) {
     $82 = (($__k$0$lcssa19) + 4|0);
     $83 = HEAP32[$60>>2]|0;
     $84 = HEAP32[$61>>2]|0;
     __THREW__ = 0;
     invoke_viii(1787,($82|0),($83|0),($84|0));
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      label = 34;
      break;
     }
    }
    $87 = (($__count$016) + 1)|0;
    $88 = ($87|0)==(8);
    if ($88) {
     $89 = (($__i$017) + 16|0);
     $90 = ($89|0)==($__last|0);
     $$0 = 1;$$1 = $90;$__i$1 = $89;
    } else {
     $$0 = 0;$$1 = $$0118;$__i$1 = $__i$017;
    }
    $102 = HEAP32[$60>>2]|0;
    $103 = ($102|0)==(0|0);
    if (!($103)) {
     $104 = HEAP32[$61>>2]|0;
     $105 = ($104|0)==($102|0);
     if (!($105)) {
      $__new_last2$i$i$i$i$i$i$i = $102;
      $scevgep$i$i$i$i$i$i$i = (($104) + -4|0);
      $106 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($106)|0);
      $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
      $107 = $uglygep3$i$i$i$i$i$i$i >>> 2;
      $108 = $107 ^ -1;
      $scevgep4$i$i$i$i$i$i$i = (($104) + ($108<<2)|0);
      HEAP32[$61>>2] = $scevgep4$i$i$i$i$i$i$i;
     }
     __ZdlPv($102);
    }
    if ($$0) {
     $$3 = $$1;
     label = 45;
     break;
    } else {
     $$2 = $$1;$__count$1 = $87;$__i$2 = $__i$1;
    }
   } else {
    $$2 = $$0118;$__count$1 = $__count$016;$__i$2 = $__i$017;
   }
   $109 = (($__i$2) + 16|0);
   $110 = ($109|0)==($__last|0);
   if ($110) {
    $$3 = 1;
    label = 45;
    break;
   } else {
    $$0118 = $$2;$__count$016 = $__count$1;$__i$017 = $109;$__j$015 = $__i$2;
   }
  }
  if ((label|0) == 33) {
   $91 = ___cxa_find_matching_catch()|0;
   $92 = tempRet0;
   $lpad$phi$index = $91;$lpad$phi$index2 = $92;
  }
  else if ((label|0) == 34) {
   $93 = ___cxa_find_matching_catch()|0;
   $94 = tempRet0;
   $lpad$phi$index = $93;$lpad$phi$index2 = $94;
  }
  else if ((label|0) == 45) {
   STACKTOP = sp;return ($$3|0);
  }
  $95 = HEAP32[$60>>2]|0;
  $96 = ($95|0)==(0|0);
  if ($96) {
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  $97 = HEAP32[$61>>2]|0;
  $98 = ($97|0)==($95|0);
  if (!($98)) {
   $__new_last2$i$i$i$i$i$i$i2 = $95;
   $scevgep$i$i$i$i$i$i$i3 = (($97) + -4|0);
   $99 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
   $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($99)|0);
   $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
   $100 = $uglygep3$i$i$i$i$i$i$i6 >>> 2;
   $101 = $100 ^ -1;
   $scevgep4$i$i$i$i$i$i$i7 = (($97) + ($101<<2)|0);
   HEAP32[$61>>2] = $scevgep4$i$i$i$i$i$i$i7;
  }
  __ZdlPv($95);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 }
 return 0|0;
}
function __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i17 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i8 = 0, $$012$i$i = 0, $$03$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $__first3$i1 = 0, $__growing$0$off0 = 0;
 var $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i13 = 0, $scevgep$i3 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep5$i = 0, $scevgep5$i10 = 0, $scevgep7$i$i = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i15 = 0, $uglygep$i5 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep4$i = 0, $uglygep4$i6 = 0;
 var $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($3>>>0)>($10>>>0);
 if ($11) {
  $42 = ($6|0)==(0|0);
  if ($42) {
   $51 = $5;
  } else {
   $43 = (($this) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==($6|0);
   if (!($45)) {
    $scevgep$i$i$i$i = (($44) + -4|0);
    $46 = (0 - ($8))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($46)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $47 = $uglygep3$i$i$i$i >>> 2;
    $48 = $47 ^ -1;
    $scevgep4$i$i$i$i = (($44) + ($48<<2)|0);
    HEAP32[$43>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($6);
   HEAP32[$4>>2] = 0;
   HEAP32[$43>>2] = 0;
   HEAP32[$this>>2] = 0;
   $51 = 0;
  }
  $49 = ($3>>>0)>(1073741823);
  if ($49) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $50 = $51;
  $52 = $50 >> 2;
  $53 = ($52>>>0)<(536870911);
  if ($53) {
   $54 = $50 >> 1;
   $55 = ($54>>>0)<($3>>>0);
   $56 = $55 ? $3 : $54;
   $57 = ($56>>>0)>(1073741823);
   if ($57) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i17 = $56;
   }
  } else {
   $$0$i17 = 1073741823;
  }
  $58 = $$0$i17 << 2;
  $59 = (__Znwj($58)|0);
  $60 = (($this) + 4|0);
  HEAP32[$60>>2] = $59;
  HEAP32[$this>>2] = $59;
  $61 = (($59) + ($$0$i17<<2)|0);
  HEAP32[$4>>2] = $61;
  $62 = ($__first|0)==($__last|0);
  if ($62) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($__last) + -4|0);
  $63 = (0 - ($1))|0;
  $uglygep$i = (($scevgep$i) + ($63)|0);
  $uglygep4$i = $uglygep$i;
  $64 = $uglygep4$i >>> 2;
  $$01$i = $__first;$66 = $59;
  while(1) {
   $65 = ($66|0)==(0|0);
   if (!($65)) {
    $67 = HEAP32[$$01$i>>2]|0;
    HEAP32[$66>>2] = $67;
   }
   $68 = (($66) + 4|0);
   $69 = (($$01$i) + 4|0);
   $70 = ($69|0)==($__last|0);
   if ($70) {
    break;
   } else {
    $$01$i = $69;$66 = $68;
   }
  }
  $71 = (($64) + 1)|0;
  $scevgep5$i = (($59) + ($71<<2)|0);
  HEAP32[$60>>2] = $scevgep5$i;
  STACKTOP = sp;return;
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = $15 >> 2;
 $17 = ($3>>>0)>($16>>>0);
 if ($17) {
  $18 = (($__first) + ($16<<2)|0);
  $20 = $18;$__growing$0$off0 = 1;
 } else {
  $20 = $__last;$__growing$0$off0 = 0;
 }
 $19 = ($20|0)==($__first|0);
 if ($19) {
  $$0$lcssa$i$i = $6;
 } else {
  $scevgep$i$i13 = (($20) + -4|0);
  $21 = (0 - ($1))|0;
  $uglygep$i$i15 = (($scevgep$i$i13) + ($21)|0);
  $uglygep6$i$i = $uglygep$i$i15;
  $$012$i$i = $__first;$$03$i$i = $6;
  while(1) {
   $22 = HEAP32[$$012$i$i>>2]|0;
   HEAP32[$$03$i$i>>2] = $22;
   $23 = (($$012$i$i) + 4|0);
   $24 = (($$03$i$i) + 4|0);
   $25 = ($23|0)==($20|0);
   if ($25) {
    break;
   } else {
    $$012$i$i = $23;$$03$i$i = $24;
   }
  }
  $26 = $uglygep6$i$i >>> 2;
  $27 = (($26) + 1)|0;
  $scevgep7$i$i = (($6) + ($27<<2)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if (!($__growing$0$off0)) {
  $38 = ($13|0)==($$0$lcssa$i$i|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($13) + -4|0);
  $39 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($39)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $40 = $uglygep3$i$i >>> 2;
  $41 = $40 ^ -1;
  $scevgep4$i$i = (($13) + ($41<<2)|0);
  HEAP32[$12>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $28 = ($20|0)==($__last|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $__first3$i1 = $20;
 $scevgep$i3 = (($__last) + -4|0);
 $29 = (0 - ($__first3$i1))|0;
 $uglygep$i5 = (($scevgep$i3) + ($29)|0);
 $uglygep4$i6 = $uglygep$i5;
 $30 = $uglygep4$i6 >>> 2;
 $$01$i8 = $20;$32 = $13;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   $33 = HEAP32[$$01$i8>>2]|0;
   HEAP32[$32>>2] = $33;
  }
  $34 = (($32) + 4|0);
  $35 = (($$01$i8) + 4|0);
  $36 = ($35|0)==($__last|0);
  if ($36) {
   break;
  } else {
   $$01$i8 = $35;$32 = $34;
  }
 }
 $37 = (($30) + 1)|0;
 $scevgep5$i10 = (($13) + ($37<<2)|0);
 HEAP32[$12>>2] = $scevgep5$i10;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__first3$i = 0;
 var $__new_last2$i$i$i = 0, $scevgep$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep5$i = 0, $uglygep$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, $uglygep4$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($__x) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$__x>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8>>>0)>(1073741823);
 if ($10) {
  __THREW__ = 0;
  invoke_vi(3308,0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   // unreachable;
  }
 } else {
  __THREW__ = 0;
  $13 = (invoke_ii(2988,($7|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   HEAP32[$0>>2] = $13;
   HEAP32[$this>>2] = $13;
   $16 = (($13) + ($8<<2)|0);
   HEAP32[$1>>2] = $16;
   $17 = HEAP32[$__x>>2]|0;
   $18 = HEAP32[$2>>2]|0;
   $19 = ($17|0)==($18|0);
   if ($19) {
    STACKTOP = sp;return;
   }
   $__first3$i = $17;
   $scevgep$i = (($18) + -4|0);
   $20 = (0 - ($__first3$i))|0;
   $uglygep$i = (($scevgep$i) + ($20)|0);
   $uglygep4$i = $uglygep$i;
   $21 = $uglygep4$i >>> 2;
   $$01$i = $17;$23 = $13;
   while(1) {
    $22 = ($23|0)==(0|0);
    if (!($22)) {
     $24 = HEAP32[$$01$i>>2]|0;
     HEAP32[$23>>2] = $24;
    }
    $25 = (($23) + 4|0);
    $26 = (($$01$i) + 4|0);
    $27 = ($26|0)==($18|0);
    if ($27) {
     break;
    } else {
     $$01$i = $26;$23 = $25;
    }
   }
   $28 = (($21) + 1)|0;
   $scevgep5$i = (($13) + ($28<<2)|0);
   HEAP32[$0>>2] = $scevgep5$i;
   STACKTOP = sp;return;
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$this>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$0>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i = $31;
  $scevgep$i$i$i = (($33) + -4|0);
  $35 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($35)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $36 = $uglygep3$i$i$i >>> 2;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i = (($33) + ($37<<2)|0);
  HEAP32[$0>>2] = $scevgep4$i$i$i;
 }
 __ZdlPv($31);
 ___resumeException($29|0);
 // unreachable;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorIN15ResourceManager10DependencyENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, $size$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i = sp + 4|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$data>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 HEAP32[$size>>2] = $7;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size,4);
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$data>>2]|0;
 $16 = ($15|0)==($14|0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = $15;
 while(1) {
  __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($17,$this);
  $18 = (($17) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $19;
  $23 = $21;
  $24 = (($22) - ($23))|0;
  $25 = $24 >> 2;
  HEAP32[$size$i$i$i$i$i$i>>2] = $25;
  $26 = HEAP32[$8>>2]|0;
  $27 = (($26) + 4|0);
  $28 = HEAP32[$11>>2]|0;
  $29 = ($27>>>0)<($28>>>0);
  if ($29) {
   HEAP32[$26>>2] = $25;
   HEAP32[$8>>2] = $27;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i$i$i$i,4);
  }
  $30 = HEAP32[$18>>2]|0;
  $31 = HEAP32[$20>>2]|0;
  $32 = ($31|0)==($30|0);
  if (!($32)) {
   $33 = $31;
   while(1) {
    __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($33,$this);
    $34 = (($33) + 4|0);
    $35 = ($34|0)==($30|0);
    if ($35) {
     break;
    } else {
     $33 = $34;
    }
   }
  }
  $36 = (($17) + 16|0);
  $37 = ($36|0)==($14|0);
  if ($37) {
   break;
  } else {
   $17 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size,4);
 }
 $9 = (($data) + 4|0);
 $10 = HEAP32[$data>>2]|0;
 $11 = ($10|0)==($9|0);
 if ($11) {
  STACKTOP = sp;return;
 } else {
  $13 = $10;
 }
 while(1) {
  $12 = (($13) + 16|0);
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$12,0);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($this);
  $14 = (($13) + 28|0);
  __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($14,$this);
  $15 = (($13) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $$01$i$i$i = $13;
   while(1) {
    $20 = (($$01$i$i$i) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($$01$i$i$i|0);
    if ($23) {
     $$0$i$i$i = $21;
     break;
    } else {
     $$01$i$i$i = $21;
    }
   }
  } else {
   $$0$i$i$i$i = $16;
   while(1) {
    $18 = HEAP32[$$0$i$i$i$i>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $18;
    }
   }
  }
  $24 = ($$0$i$i$i|0)==($9|0);
  if ($24) {
   break;
  } else {
   $13 = $$0$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN15ResourceManager10DependencyENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0;
 var $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorIN15ResourceManager10DependencyENS0_9allocatorIS3_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ObjectENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$30,0);
   $31 = (($29) + 16|0);
   $32 = ($31|0)==($26|0);
   if ($32) {
    break;
   } else {
    $29 = $31;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ObjectENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4PPtrI6ObjectENS0_9allocatorIS4_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI4PPtrI6ObjectENS0_9allocatorIS4_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$idx = 0, $$pre54 = 0, $$pre55 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i30 = 0, $__new_last2$i$i$i$i$i39 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i31 = 0, $scevgep$i$i$i$i$i40 = 0, $scevgep$i$i$i17 = 0, $scevgep4$i$i$i$i$i35 = 0, $scevgep4$i$i$i$i$i44 = 0;
 var $scevgep4$i$i$i19 = 0, $scevgep8$i$i$i = 0, $scevgep8$i$i$i52 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i42 = 0, $uglygep$i$i$i18 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i34 = 0, $uglygep3$i$i$i$i$i43 = 0, $uglygep6$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($sz>>>0);
 if (!($9)) {
  $63 = ($8>>>0)>($sz>>>0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  $64 = (($4) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $65 = $$idx >> 2;
  $66 = ($65|0)==(0);
  if ($66) {
   $81 = 0;$83 = 0;$scevgep8$i$i$i52 = 0;
  } else {
   $67 = ($65>>>0)>(1073741823);
   if ($67) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $68 = (__Znwj($$idx)|0);
   $69 = (($68) + ($65<<2)|0);
   $70 = ($sz|0)==(0);
   if ($70) {
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $68;
   } else {
    $$sum = (($sz) + -1)|0;
    $scevgep$i$i$i = (($4) + ($$sum<<2)|0);
    $71 = (0 - ($6))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($71)|0);
    $73 = $68;$75 = $4;
    while(1) {
     $72 = ($73|0)==(0|0);
     if (!($72)) {
      $74 = HEAP32[$75>>2]|0;
      HEAP32[$73>>2] = $74;
     }
     $76 = (($73) + 4|0);
     $77 = (($75) + 4|0);
     $78 = ($77|0)==($64|0);
     if ($78) {
      break;
     } else {
      $73 = $76;$75 = $77;
     }
    }
    $uglygep6$i$i$i = $uglygep$i$i$i;
    $79 = $uglygep6$i$i$i >>> 2;
    $80 = (($79) + 1)|0;
    $scevgep8$i$i$i = (($68) + ($80<<2)|0);
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $scevgep8$i$i$i;
   }
  }
  HEAP32[$v>>2] = $81;
  HEAP32[$2>>2] = $scevgep8$i$i$i52;
  $82 = (($v) + 8|0);
  HEAP32[$82>>2] = $83;
  $84 = ($4|0)==(0|0);
  if ($84) {
   STACKTOP = sp;return;
  }
  __ZdlPv($4);
  STACKTOP = sp;return;
 }
 $10 = (($v) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($6))|0;
 $14 = $13 >> 2;
 $15 = ($14|0)==($sz|0);
 if ($15) {
  $62 = (($sz) - ($8))|0;
  __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEE8__appendEj($v,$62);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $16 = (($temp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($temp) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = ($sz|0)==(0);
 if ($18) {
  label = 6;
 } else {
  $19 = $sz << 2;
  __THREW__ = 0;
  $20 = (invoke_ii(2988,($19|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $23 = (($20) + ($sz<<2)|0);
   HEAP32[$temp>>2] = $20;
   HEAP32[$16>>2] = $20;
   HEAP32[$17>>2] = $23;
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$0>>2] = $4;
   HEAP32[$1>>2] = $3;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1788,($temp|0),($$byval_copy|0),($$byval_copy1|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$16>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = $30 >> 2;
    $32 = ($31>>>0)<($sz>>>0);
    if ($32) {
     $33 = (($sz) - ($31))|0;
     __THREW__ = 0;
     invoke_vii(2792,($temp|0),($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $$pre54 = HEAP32[$temp>>2]|0;
     $$pre55 = HEAP32[$16>>2]|0;
     $43 = $$pre54;$45 = $$pre55;
    } else {
     $36 = ($31>>>0)>($sz>>>0);
     if ($36) {
      $37 = (($27) + ($sz<<2)|0);
      $38 = ($26|0)==($37|0);
      if ($38) {
       $43 = $27;$45 = $26;
      } else {
       $__new_last2$i$i$i = $37;
       $scevgep$i$i$i17 = (($26) + -4|0);
       $39 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i18 = (($scevgep$i$i$i17) + ($39)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i18;
       $40 = $uglygep3$i$i$i >>> 2;
       $41 = $40 ^ -1;
       $scevgep4$i$i$i19 = (($26) + ($41<<2)|0);
       HEAP32[$16>>2] = $scevgep4$i$i$i19;
       $43 = $27;$45 = $scevgep4$i$i$i19;
      }
     } else {
      $43 = $27;$45 = $26;
     }
    }
    $42 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $42;
    HEAP32[$v>>2] = $43;
    $44 = HEAP32[$2>>2]|0;
    HEAP32[$16>>2] = $44;
    HEAP32[$2>>2] = $45;
    $46 = HEAP32[$17>>2]|0;
    $47 = HEAP32[$10>>2]|0;
    HEAP32[$17>>2] = $47;
    HEAP32[$10>>2] = $46;
    $48 = ($42|0)==(0|0);
    if ($48) {
     STACKTOP = sp;return;
    }
    $49 = ($44|0)==($42|0);
    if (!($49)) {
     $__new_last2$i$i$i$i$i30 = $42;
     $scevgep$i$i$i$i$i31 = (($44) + -4|0);
     $50 = (0 - ($__new_last2$i$i$i$i$i30))|0;
     $uglygep$i$i$i$i$i33 = (($scevgep$i$i$i$i$i31) + ($50)|0);
     $uglygep3$i$i$i$i$i34 = $uglygep$i$i$i$i$i33;
     $51 = $uglygep3$i$i$i$i$i34 >>> 2;
     $52 = $51 ^ -1;
     $scevgep4$i$i$i$i$i35 = (($44) + ($52<<2)|0);
     HEAP32[$16>>2] = $scevgep4$i$i$i$i$i35;
    }
    __ZdlPv($42);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $53 = ___cxa_find_matching_catch()|0;
 $54 = tempRet0;
 $55 = HEAP32[$temp>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($53|0);
  // unreachable;
 }
 $57 = HEAP32[$16>>2]|0;
 $58 = ($57|0)==($55|0);
 if (!($58)) {
  $__new_last2$i$i$i$i$i39 = $55;
  $scevgep$i$i$i$i$i40 = (($57) + -4|0);
  $59 = (0 - ($__new_last2$i$i$i$i$i39))|0;
  $uglygep$i$i$i$i$i42 = (($scevgep$i$i$i$i$i40) + ($59)|0);
  $uglygep3$i$i$i$i$i43 = $uglygep$i$i$i$i$i42;
  $60 = $uglygep3$i$i$i$i$i43 >>> 2;
  $61 = $60 ^ -1;
  $scevgep4$i$i$i$i$i44 = (($57) + ($61<<2)|0);
  HEAP32[$16>>2] = $scevgep4$i$i$i$i$i44;
 }
 __ZdlPv($55);
 ___resumeException($53|0);
 // unreachable;
}
function __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$promoted15$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0;
 var $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i24 = 0, $scevgep$i10 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i17 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i25 = 0, $uglygep$i12 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0;
 var $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $46 = ($8|0)==(0|0);
  if ($46) {
   $55 = $7;
  } else {
   $47 = (($this) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($8|0);
   if (!($49)) {
    $scevgep$i$i$i$i = (($48) + -4|0);
    $50 = (0 - ($10))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($50)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $51 = $uglygep3$i$i$i$i >>> 2;
    $52 = $51 ^ -1;
    $scevgep4$i$i$i$i = (($48) + ($52<<2)|0);
    HEAP32[$47>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($8);
   HEAP32[$6>>2] = 0;
   HEAP32[$47>>2] = 0;
   HEAP32[$this>>2] = 0;
   $55 = 0;
  }
  $53 = ($5>>>0)>(1073741823);
  if ($53) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $54 = $55;
  $56 = $54 >> 2;
  $57 = ($56>>>0)<(536870911);
  if ($57) {
   $58 = $54 >> 1;
   $59 = ($58>>>0)<($5>>>0);
   $60 = $59 ? $5 : $58;
   $61 = ($60>>>0)>(1073741823);
   if ($61) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $60;
   }
  } else {
   $$0$i40 = 1073741823;
  }
  $62 = $$0$i40 << 2;
  $63 = (__Znwj($62)|0);
  $64 = (($this) + 4|0);
  HEAP32[$64>>2] = $63;
  HEAP32[$this>>2] = $63;
  $65 = (($63) + ($$0$i40<<2)|0);
  HEAP32[$6>>2] = $65;
  $66 = ($0|0)==($1|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($1) + -4|0);
  $67 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($67)|0);
  $uglygep6$i = $uglygep$i;
  $68 = $uglygep6$i >>> 2;
  $70 = $63;$72 = $0;
  while(1) {
   $69 = ($70|0)==(0|0);
   if (!($69)) {
    $71 = HEAP32[$72>>2]|0;
    HEAP32[$70>>2] = $71;
   }
   $73 = (($70) + 4|0);
   $74 = (($72) + 4|0);
   $75 = ($74|0)==($1|0);
   if ($75) {
    break;
   } else {
    $70 = $73;$72 = $74;
   }
  }
  $76 = (($68) + 1)|0;
  $scevgep8$i = (($63) + ($76<<2)|0);
  HEAP32[$64>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 2;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<2)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i24 = (($22) + -4|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i25 = (($scevgep$i$i24) + ($23)|0);
  $uglygep5$i$i = $uglygep$i$i25;
  $24 = $uglygep5$i$i >>> 2;
  $$01$i$i = $8;$26 = $0;
  while(1) {
   $25 = HEAP32[$26>>2]|0;
   HEAP32[$$01$i$i>>2] = $25;
   $27 = (($26) + 4|0);
   $28 = (($$01$i$i) + 4|0);
   $29 = ($27|0)==($22|0);
   if ($29) {
    break;
   } else {
    $$01$i$i = $28;$26 = $27;
   }
  }
  $30 = (($24) + 1)|0;
  $scevgep6$i$i = (($8) + ($30<<2)|0);
  $$0$lcssa$i$i = $scevgep6$i$i;
 }
 if (!($__growing$0$off0)) {
  $42 = ($15|0)==($$0$lcssa$i$i|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($15) + -4|0);
  $43 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($43)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $44 = $uglygep3$i$i >>> 2;
  $45 = $44 ^ -1;
  $scevgep4$i$i = (($15) + ($45<<2)|0);
  HEAP32[$14>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $31 = ($22|0)==($1|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $$promoted15$i9 = $22;
 $scevgep$i10 = (($1) + -4|0);
 $32 = (0 - ($$promoted15$i9))|0;
 $uglygep$i12 = (($scevgep$i10) + ($32)|0);
 $uglygep6$i13 = $uglygep$i12;
 $33 = $uglygep6$i13 >>> 2;
 $35 = $15;$37 = $22;
 while(1) {
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   $36 = HEAP32[$37>>2]|0;
   HEAP32[$35>>2] = $36;
  }
  $38 = (($35) + 4|0);
  $39 = (($37) + 4|0);
  $40 = ($39|0)==($1|0);
  if ($40) {
   break;
  } else {
   $35 = $38;$37 = $39;
  }
 }
 $41 = (($33) + 1)|0;
 $scevgep8$i17 = (($15) + ($41<<2)|0);
 HEAP32[$14>>2] = $scevgep8$i17;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0;
 var $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
   }
   $11 = (($10) + 4|0);
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$10 = $11;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($__n))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 if ($22) {
  $23 = $20 >> 1;
  $24 = ($23>>>0)<($18>>>0);
  $25 = $24 ? $18 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 2;
  $28 = (__Znwj($27)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($17<<2)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP32[$32>>2] = 0;
  }
  $33 = (($32) + 4|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($30) + ($18<<2)|0);
 $37 = ($3|0)==($14|0);
 if ($37) {
  $47 = $29;$49 = $3;
 } else {
  $scevgep$i$i = (($3) + -4|0);
  $38 = (0 - ($15))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($38)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $3;$42 = $29;
  while(1) {
   $39 = (($$01$i$i) + -4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($42) + -4|0);
   HEAP32[$41>>2] = $40;
   $43 = (($42) + -4|0);
   $44 = ($39|0)==($14|0);
   if ($44) {
    break;
   } else {
    $$01$i$i = $39;$42 = $43;
   }
  }
  $45 = $uglygep4$i$i >>> 2;
  $46 = $45 ^ -1;
  $$sum6 = (($17) + ($46))|0;
  $scevgep5$i$i = (($30) + ($$sum6<<2)|0);
  $47 = $scevgep5$i$i;$49 = $14;
 }
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $36;
 $48 = ($49|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($49);
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIN15ResourceManager10DependencyENS0_9allocatorIS3_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy2 = 0, $$byval_copy3 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$pre = 0, $$pre$i$i$i$i$i27 = 0, $$pre$i$i$i$i$i42 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i29 = 0, $$pre$i$i$i44 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i20 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i35 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i8 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i21 = 0;
 var $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i36 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i9 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i25 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i40 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i13 = 0, $temp = 0, $temp1 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i23 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i38 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i11 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i24 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i39 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 24|0;
 $$byval_copy2 = sp + 48|0;
 $0 = sp;
 $1 = sp + 8|0;
 $temp = sp + 36|0;
 $2 = sp + 28|0;
 $3 = sp + 32|0;
 $temp1 = sp + 12|0;
 $4 = sp + 52|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 4;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $96 = ($11>>>0)>($sz>>>0);
  if (!($96)) {
   STACKTOP = sp;return;
  }
  $97 = (($7) + ($sz<<4)|0);
  HEAP32[$1>>2] = $7;
  HEAP32[$0>>2] = $97;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEEC2INS_11__wrap_iterIPS2_EEEET_SA_RKS4_PNS_9enable_ifIXaasr21__is_forward_iteratorISA_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeE($temp1,$$byval_copy2,$$byval_copy3,$4,0);
  $98 = HEAP32[$temp1>>2]|0;
  $99 = HEAP32[$v>>2]|0;
  HEAP32[$temp1>>2] = $99;
  HEAP32[$v>>2] = $98;
  $100 = (($temp1) + 4|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = HEAP32[$5>>2]|0;
  HEAP32[$100>>2] = $102;
  HEAP32[$5>>2] = $101;
  $103 = (($temp1) + 8|0);
  $104 = (($v) + 8|0);
  $105 = HEAP32[$103>>2]|0;
  $106 = HEAP32[$104>>2]|0;
  HEAP32[$103>>2] = $106;
  HEAP32[$104>>2] = $105;
  $107 = ($99|0)==(0|0);
  if ($107) {
   STACKTOP = sp;return;
  }
  $108 = ($102|0)==($99|0);
  if ($108) {
   $122 = $99;
  } else {
   $110 = $102;
   while(1) {
    $109 = (($110) + -16|0);
    HEAP32[$100>>2] = $109;
    $111 = (($110) + -12|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($112|0)==(0|0);
    if ($113) {
     $115 = $109;
    } else {
     $116 = (($110) + -8|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ($117|0)==($112|0);
     if ($118) {
      $$pre$i$i$i$i$i = $109;
     } else {
      $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $112;
      $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($117) + -4|0);
      $119 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($119)|0);
      $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      $120 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
      $121 = $120 ^ -1;
      $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($117) + ($121<<2)|0);
      HEAP32[$116>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      $$pre$i$i$i$i$i$pre = HEAP32[$100>>2]|0;
      $$pre$i$i$i$i$i = $$pre$i$i$i$i$i$pre;
     }
     __ZdlPv($112);
     $115 = $$pre$i$i$i$i$i;
    }
    $114 = ($115|0)==($99|0);
    if ($114) {
     break;
    } else {
     $110 = $115;
    }
   }
   $$pre$i$i$i = HEAP32[$temp1>>2]|0;
   $122 = $$pre$i$i$i;
  }
  __ZdlPv($122);
  STACKTOP = sp;return;
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 4;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $95 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEE8__appendEj($v,$95);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2793,($temp|0),($sz|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 do {
  if (!($22)) {
   $23 = HEAP32[$v>>2]|0;
   HEAP32[$2>>2] = $23;
   $24 = HEAP32[$5>>2]|0;
   HEAP32[$3>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viii(1789,($temp|0),($$byval_copy2|0),($$byval_copy3|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP32[$19>>2]|0;
    $28 = HEAP32[$temp>>2]|0;
    $29 = $27;
    $30 = $28;
    $31 = (($29) - ($30))|0;
    $32 = $31 >> 4;
    $33 = ($32>>>0)<($sz>>>0);
    if ($33) {
     $34 = (($sz) - ($32))|0;
     __THREW__ = 0;
     invoke_vii(2794,($temp|0),($34|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     $$pre = HEAP32[$19>>2]|0;
     $56 = $$pre;
    } else {
     $37 = ($32>>>0)>($sz>>>0);
     if ($37) {
      $38 = (($28) + ($sz<<4)|0);
      $39 = ($27|0)==($38|0);
      if ($39) {
       $56 = $27;
      } else {
       $41 = $27;
       while(1) {
        $40 = (($41) + -16|0);
        HEAP32[$19>>2] = $40;
        $42 = (($41) + -12|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = ($43|0)==(0|0);
        if ($44) {
         $46 = $40;
        } else {
         $47 = (($41) + -8|0);
         $48 = HEAP32[$47>>2]|0;
         $49 = ($48|0)==($43|0);
         if (!($49)) {
          $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i8 = $43;
          $scevgep$i$i$i$i$i$i$i$i$i$i$i$i9 = (($48) + -4|0);
          $50 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i8))|0;
          $uglygep$i$i$i$i$i$i$i$i$i$i$i$i11 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i9) + ($50)|0);
          $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i12 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i11;
          $51 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i12 >>> 2;
          $52 = $51 ^ -1;
          $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i13 = (($48) + ($52<<2)|0);
          HEAP32[$47>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i13;
         }
         __ZdlPv($43);
         $$pre$i$i$i15 = HEAP32[$19>>2]|0;
         $46 = $$pre$i$i$i15;
        }
        $45 = ($46|0)==($38|0);
        if ($45) {
         $56 = $38;
         break;
        } else {
         $41 = $46;
        }
       }
      }
     } else {
      $56 = $27;
     }
    }
    $53 = HEAP32[$temp>>2]|0;
    $54 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $54;
    HEAP32[$v>>2] = $53;
    $55 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $55;
    HEAP32[$5>>2] = $56;
    $57 = HEAP32[$20>>2]|0;
    $58 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $58;
    HEAP32[$13>>2] = $57;
    $59 = ($54|0)==(0|0);
    if ($59) {
     STACKTOP = sp;return;
    }
    $60 = ($55|0)==($54|0);
    if ($60) {
     $74 = $54;
    } else {
     $62 = $55;
     while(1) {
      $61 = (($62) + -16|0);
      HEAP32[$19>>2] = $61;
      $63 = (($62) + -12|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==(0|0);
      if ($65) {
       $67 = $61;
      } else {
       $68 = (($62) + -8|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ($69|0)==($64|0);
       if (!($70)) {
        $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i20 = $64;
        $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i21 = (($69) + -4|0);
        $71 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i20))|0;
        $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i23 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i21) + ($71)|0);
        $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i24 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i23;
        $72 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i24 >>> 2;
        $73 = $72 ^ -1;
        $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i25 = (($69) + ($73<<2)|0);
        HEAP32[$68>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i25;
       }
       __ZdlPv($64);
       $$pre$i$i$i$i$i27 = HEAP32[$19>>2]|0;
       $67 = $$pre$i$i$i$i$i27;
      }
      $66 = ($67|0)==($54|0);
      if ($66) {
       break;
      } else {
       $62 = $67;
      }
     }
     $$pre$i$i$i29 = HEAP32[$temp>>2]|0;
     $74 = $$pre$i$i$i29;
    }
    __ZdlPv($74);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $75 = ___cxa_find_matching_catch()|0;
 $76 = tempRet0;
 $77 = HEAP32[$temp>>2]|0;
 $78 = ($77|0)==(0|0);
 if ($78) {
  ___resumeException($75|0);
  // unreachable;
 }
 $79 = HEAP32[$19>>2]|0;
 $80 = ($79|0)==($77|0);
 if ($80) {
  $94 = $77;
 } else {
  $82 = $79;
  while(1) {
   $81 = (($82) + -16|0);
   HEAP32[$19>>2] = $81;
   $83 = (($82) + -12|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $87 = $81;
   } else {
    $88 = (($82) + -8|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)==($84|0);
    if (!($90)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i35 = $84;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i36 = (($89) + -4|0);
     $91 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i35))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i38 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i36) + ($91)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i39 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i38;
     $92 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i39 >>> 2;
     $93 = $92 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i40 = (($89) + ($93<<2)|0);
     HEAP32[$88>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i40;
    }
    __ZdlPv($84);
    $$pre$i$i$i$i$i42 = HEAP32[$19>>2]|0;
    $87 = $$pre$i$i$i$i$i42;
   }
   $86 = ($87|0)==($77|0);
   if ($86) {
    break;
   } else {
    $82 = $87;
   }
  }
  $$pre$i$i$i44 = HEAP32[$temp>>2]|0;
  $94 = $$pre$i$i$i44;
 }
 __ZdlPv($94);
 ___resumeException($75|0);
 // unreachable;
}
function __ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i3 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) - ($4))|0;
 $12 = $11 >> 4;
 $13 = ($__n|0)==(0);
 if ($13) {
  $17 = 0;
 } else {
  $14 = $__n << 4;
  $15 = (__Znwj($14)|0);
  $17 = $15;
 }
 $16 = (($17) + ($12<<4)|0);
 $18 = (($17) + ($__n<<4)|0);
 $19 = ($9|0)==($2|0);
 L7: do {
  if ($19) {
   HEAP32[$this>>2] = $16;
   HEAP32[$8>>2] = $16;
   HEAP32[$0>>2] = $18;
   $44 = $2;
  } else {
   $$01$i$i = $9;$23 = $16;
   while(1) {
    $20 = (($$01$i$i) + -16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($23) + -16|0);
    HEAP32[$22>>2] = $21;
    $24 = (($23) + -12|0);
    $25 = (($$01$i$i) + -12|0);
    __THREW__ = 0;
    invoke_vii(2795,($24|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = (($23) + -16|0);
    $29 = ($20|0)==($2|0);
    if ($29) {
     label = 8;
     break;
    } else {
     $$01$i$i = $20;$23 = $28;
    }
   }
   if ((label|0) == 8) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$8>>2]|0;
    HEAP32[$this>>2] = $28;
    HEAP32[$8>>2] = $16;
    HEAP32[$0>>2] = $18;
    $30 = ($$pre|0)==($$pre$i|0);
    if ($30) {
     $44 = $$pre$i;
     break;
    } else {
     $32 = $$pre;
    }
    while(1) {
     $31 = (($32) + -16|0);
     $33 = (($32) + -12|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if (!($35)) {
      $37 = (($32) + -8|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38|0)==($34|0);
      if (!($39)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i3 = $34;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = (($38) + -4|0);
       $40 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i3))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i4) + ($40)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6;
       $41 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 >>> 2;
       $42 = $41 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = (($38) + ($42<<2)|0);
       HEAP32[$37>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i8;
      }
      __ZdlPv($34);
     }
     $36 = ($31|0)==($$pre$i|0);
     if ($36) {
      $44 = $$pre$i;
      break L7;
     } else {
      $32 = $31;
     }
    }
   }
   $45 = ___cxa_find_matching_catch()|0;
   $46 = tempRet0;
   $47 = ($16|0)==($23|0);
   if (!($47)) {
    $49 = $16;
    while(1) {
     $48 = (($49) + -16|0);
     $50 = (($49) + -12|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if (!($52)) {
      $54 = (($49) + -8|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ($55|0)==($51|0);
      if (!($56)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $51;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($55) + -4|0);
       $57 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($57)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
       $58 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
       $59 = $58 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($55) + ($59<<2)|0);
       HEAP32[$54>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      }
      __ZdlPv($51);
     }
     $53 = ($48|0)==($23|0);
     if ($53) {
      break;
     } else {
      $49 = $48;
     }
    }
   }
   $60 = ($17|0)==(0|0);
   if ($60) {
    ___resumeException($45|0);
    // unreachable;
   }
   __ZdlPv($17);
   ___resumeException($45|0);
   // unreachable;
  }
 } while(0);
 $43 = ($44|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 __ZdlPv($44);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i34 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i13 = 0, $$pre$i4 = 0, $$pre1$i = 0, $$pre1$i15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep17$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep16$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 4;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 4;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $64 = ($8|0)==(0|0);
  if ($64) {
   $84 = $7;
  } else {
   $65 = (($this) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==($8|0);
   if ($67) {
    $81 = $8;
   } else {
    $69 = $66;
    while(1) {
     $68 = (($69) + -16|0);
     HEAP32[$65>>2] = $68;
     $70 = (($69) + -12|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0|0);
     if ($72) {
      $74 = $68;
     } else {
      $75 = (($69) + -8|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = ($76|0)==($71|0);
      if (!($77)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i = $71;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i = (($76) + -4|0);
       $78 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($78)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i;
       $79 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
       $80 = $79 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i = (($76) + ($80<<2)|0);
       HEAP32[$75>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i;
      }
      __ZdlPv($71);
      $$pre$i$i$i$i = HEAP32[$65>>2]|0;
      $74 = $$pre$i$i$i$i;
     }
     $73 = ($74|0)==($8|0);
     if ($73) {
      break;
     } else {
      $69 = $74;
     }
    }
    $$pre$i4 = HEAP32[$this>>2]|0;
    $81 = $$pre$i4;
   }
   __ZdlPv($81);
   HEAP32[$6>>2] = 0;
   HEAP32[$65>>2] = 0;
   HEAP32[$this>>2] = 0;
   $84 = 0;
  }
  $82 = ($5>>>0)>(268435455);
  if ($82) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $83 = $84;
  $85 = $83 >> 4;
  $86 = ($85>>>0)<(134217727);
  if ($86) {
   $87 = $83 >> 3;
   $88 = ($87>>>0)<($5>>>0);
   $89 = $88 ? $5 : $87;
   $90 = ($89>>>0)>(268435455);
   if ($90) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i34 = $89;
   }
  } else {
   $$0$i34 = 268435455;
  }
  $91 = $$0$i34 << 4;
  $92 = (__Znwj($91)|0);
  $93 = (($this) + 4|0);
  HEAP32[$93>>2] = $92;
  HEAP32[$this>>2] = $92;
  $94 = (($92) + ($$0$i34<<4)|0);
  HEAP32[$6>>2] = $94;
  $95 = HEAP32[$__first>>2]|0;
  $96 = HEAP32[$__last>>2]|0;
  $97 = ($95|0)==($96|0);
  if ($97) {
   STACKTOP = sp;return;
  } else {
   $101 = $95;$99 = $92;
  }
  while(1) {
   $98 = ($99|0)==(0|0);
   if ($98) {
    $105 = 0;
   } else {
    $100 = HEAP32[$101>>2]|0;
    HEAP32[$99>>2] = $100;
    $102 = (($99) + 4|0);
    $103 = (($101) + 4|0);
    __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($102,$103);
    $$pre1$i = HEAP32[$93>>2]|0;
    $105 = $$pre1$i;
   }
   $104 = (($105) + 16|0);
   HEAP32[$93>>2] = $104;
   $106 = (($101) + 16|0);
   $107 = ($106|0)==($96|0);
   if ($107) {
    break;
   } else {
    $101 = $106;$99 = $104;
   }
  }
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 4;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<4)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i = (($22) + -16|0);
  $23 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($23)|0);
  $uglygep16$i = $uglygep$i;
  $24 = $uglygep16$i >>> 4;
  $$01$i$i = $8;$26 = $0;
  while(1) {
   $25 = HEAP32[$26>>2]|0;
   HEAP32[$$01$i$i>>2] = $25;
   $27 = ($$01$i$i|0)==($26|0);
   if (!($27)) {
    $28 = (($$01$i$i) + 4|0);
    $29 = (($26) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($26) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($28,$30,$32);
   }
   $33 = (($26) + 16|0);
   $34 = (($$01$i$i) + 16|0);
   $35 = ($33|0)==($22|0);
   if ($35) {
    break;
   } else {
    $$01$i$i = $34;$26 = $33;
   }
  }
  $36 = (($24) + 1)|0;
  $scevgep17$i = (($8) + ($36<<4)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  $37 = HEAP32[$__last>>2]|0;
  $38 = ($22|0)==($37|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  $$pre$i13 = HEAP32[$14>>2]|0;
  $40 = $$pre$i13;$42 = $22;
  while(1) {
   $39 = ($40|0)==(0|0);
   if ($39) {
    $46 = 0;
   } else {
    $41 = HEAP32[$42>>2]|0;
    HEAP32[$40>>2] = $41;
    $43 = (($40) + 4|0);
    $44 = (($42) + 4|0);
    __ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_($43,$44);
    $$pre1$i15 = HEAP32[$14>>2]|0;
    $46 = $$pre1$i15;
   }
   $45 = (($46) + 16|0);
   HEAP32[$14>>2] = $45;
   $47 = (($42) + 16|0);
   $48 = ($47|0)==($37|0);
   if ($48) {
    break;
   } else {
    $40 = $45;$42 = $47;
   }
  }
  STACKTOP = sp;return;
 }
 $49 = HEAP32[$14>>2]|0;
 $50 = ($49|0)==($$0$lcssa$i$i|0);
 if ($50) {
  STACKTOP = sp;return;
 } else {
  $52 = $49;
 }
 while(1) {
  $51 = (($52) + -16|0);
  HEAP32[$14>>2] = $51;
  $53 = (($52) + -12|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $57 = $51;
  } else {
   $58 = (($52) + -8|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==($54|0);
   if (!($60)) {
    $__new_last2$i$i$i$i$i$i$i$i$i$i$i = $54;
    $scevgep$i$i$i$i$i$i$i$i$i$i$i = (($59) + -4|0);
    $61 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i) + ($61)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i;
    $62 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i >>> 2;
    $63 = $62 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i$i$i = (($59) + ($63<<2)|0);
    HEAP32[$58>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($54);
   $$pre$i$i = HEAP32[$14>>2]|0;
   $57 = $$pre$i$i;
  }
  $56 = ($57|0)==($$0$lcssa$i$i|0);
  if ($56) {
   break;
  } else {
   $52 = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEEC2INS_11__wrap_iterIPS2_EEEET_SA_RKS4_PNS_9enable_ifIXaasr21__is_forward_iteratorISA_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeE($this,$__first,$__last,$__a,$0) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 $__a = $__a|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $$pre$i6 = 0, $$pre1$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = HEAP32[$__last>>2]|0;
 $5 = $4;
 $6 = $3;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8>>>0)>(268435455);
 do {
  if ($10) {
   __THREW__ = 0;
   invoke_vi(3308,0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 12;
   } else {
    // unreachable;
   }
  } else {
   __THREW__ = 0;
   $13 = (invoke_ii(2988,($7|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 12;
   } else {
    HEAP32[$1>>2] = $13;
    HEAP32[$this>>2] = $13;
    $16 = (($13) + ($8<<4)|0);
    HEAP32[$2>>2] = $16;
    $17 = ($3|0)==($4|0);
    if ($17) {
     STACKTOP = sp;return;
    } else {
     $19 = $13;$21 = $3;
    }
    while(1) {
     $18 = ($19|0)==(0|0);
     if ($18) {
      $27 = 0;
     } else {
      $20 = HEAP32[$21>>2]|0;
      HEAP32[$19>>2] = $20;
      $22 = (($19) + 4|0);
      $23 = (($21) + 4|0);
      __THREW__ = 0;
      invoke_vii(2795,($22|0),($23|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       label = 11;
       break;
      }
      $$pre1$i = HEAP32[$1>>2]|0;
      $27 = $$pre1$i;
     }
     $26 = (($27) + 16|0);
     HEAP32[$1>>2] = $26;
     $28 = (($21) + 16|0);
     $29 = ($28|0)==($4|0);
     if ($29) {
      label = 22;
      break;
     } else {
      $19 = $26;$21 = $28;
     }
    }
    if ((label|0) == 11) {
     $30 = ___cxa_find_matching_catch()|0;
     $31 = tempRet0;
     $lpad$phi$index = $30;$lpad$phi$index2 = $31;
     break;
    }
    else if ((label|0) == 22) {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  $lpad$phi$index = $32;$lpad$phi$index2 = $33;
 }
 $34 = HEAP32[$this>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $36 = HEAP32[$1>>2]|0;
 $37 = ($36|0)==($34|0);
 if ($37) {
  $51 = $34;
 } else {
  $39 = $36;
  while(1) {
   $38 = (($39) + -16|0);
   HEAP32[$1>>2] = $38;
   $40 = (($39) + -12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0|0);
   if ($42) {
    $44 = $38;
   } else {
    $45 = (($39) + -8|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)==($41|0);
    if (!($47)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i = $41;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i$i = (($46) + -4|0);
     $48 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i) + ($48)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i;
     $49 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
     $50 = $49 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i = (($46) + ($50<<2)|0);
     HEAP32[$45>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($41);
    $$pre$i$i$i = HEAP32[$1>>2]|0;
    $44 = $$pre$i$i$i;
   }
   $43 = ($44|0)==($34|0);
   if ($43) {
    break;
   } else {
    $39 = $44;
   }
  }
  $$pre$i6 = HEAP32[$this>>2]|0;
  $51 = $$pre$i6;
 }
 __ZdlPv($51);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i1427 = 0, $$0$i1428 = 0, $$0$i18 = 0, $$01$i$i = 0, $$pre = 0, $$pre$i16 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i3 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 16|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 4;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(268435455);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 4;
 $23 = ($22>>>0)<(134217727);
 if ($23) {
  $24 = $21 >> 3;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i1428 = 0;$31 = 0;
  } else {
   $$0$i1427 = $26;
   label = 9;
  }
 } else {
  $$0$i1427 = 268435455;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = $$0$i1427 << 4;
  $29 = (__Znwj($28)|0);
  $$0$i1428 = $$0$i1427;$31 = $29;
 }
 $30 = (($31) + ($18<<4)|0);
 $$0$i18 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if ($32) {
   $35 = 0;
  } else {
   ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;
   $35 = $33;
  }
  $34 = (($35) + 16|0);
  $36 = (($$0$i18) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i18 = $36;$33 = $34;
  }
 }
 $38 = (($31) + ($$0$i1428<<4)|0);
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = ($40|0)==($39|0);
 L23: do {
  if ($41) {
   HEAP32[$this>>2] = $30;
   HEAP32[$2>>2] = $34;
   HEAP32[$0>>2] = $38;
   $66 = $39;
  } else {
   $$01$i$i = $40;$45 = $30;
   while(1) {
    $42 = (($$01$i$i) + -16|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($45) + -16|0);
    HEAP32[$44>>2] = $43;
    $46 = (($45) + -12|0);
    $47 = (($$01$i$i) + -12|0);
    __THREW__ = 0;
    invoke_vii(2795,($46|0),($47|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    $50 = (($45) + -16|0);
    $51 = ($42|0)==($39|0);
    if ($51) {
     label = 18;
     break;
    } else {
     $$01$i$i = $42;$45 = $50;
    }
   }
   if ((label|0) == 18) {
    $$pre$i16 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$2>>2]|0;
    HEAP32[$this>>2] = $50;
    HEAP32[$2>>2] = $34;
    HEAP32[$0>>2] = $38;
    $52 = ($$pre|0)==($$pre$i16|0);
    if ($52) {
     $66 = $$pre$i16;
     break;
    } else {
     $54 = $$pre;
    }
    while(1) {
     $53 = (($54) + -16|0);
     $55 = (($54) + -12|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($56|0)==(0|0);
     if (!($57)) {
      $59 = (($54) + -8|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==($56|0);
      if (!($61)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i3 = $56;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = (($60) + -4|0);
       $62 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i3))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i4) + ($62)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i6;
       $63 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 >>> 2;
       $64 = $63 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = (($60) + ($64<<2)|0);
       HEAP32[$59>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i8;
      }
      __ZdlPv($56);
     }
     $58 = ($53|0)==($$pre$i16|0);
     if ($58) {
      $66 = $$pre$i16;
      break L23;
     } else {
      $54 = $53;
     }
    }
   }
   $67 = ___cxa_find_matching_catch()|0;
   $68 = tempRet0;
   $69 = ($34|0)==($45|0);
   if (!($69)) {
    $71 = $34;
    while(1) {
     $70 = (($71) + -16|0);
     $72 = (($71) + -12|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ($73|0)==(0|0);
     if (!($74)) {
      $76 = (($71) + -8|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = ($77|0)==($73|0);
      if (!($78)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $73;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($77) + -4|0);
       $79 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($79)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
       $80 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
       $81 = $80 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($77) + ($81<<2)|0);
       HEAP32[$76>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      }
      __ZdlPv($73);
     }
     $75 = ($70|0)==($45|0);
     if ($75) {
      break;
     } else {
      $71 = $70;
     }
    }
   }
   $82 = ($31|0)==(0|0);
   if ($82) {
    ___resumeException($67|0);
    // unreachable;
   }
   __ZdlPv($31);
   ___resumeException($67|0);
   // unreachable;
  }
 } while(0);
 $65 = ($66|0)==(0|0);
 if ($65) {
  STACKTOP = sp;return;
 }
 __ZdlPv($66);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$$$i$i$i$i$i$i = 0, $$$i = 0, $$$i$i$i$i$i$i = 0, $$0 = 0, $$0$i$i = 0, $$01 = 0, $$6$i = 0, $$byval_copy34 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i6 = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__nd$0$in$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$i$index8Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$036 = 0, $lpad$phi$index = 0, $lpad$phi$index14 = 0, $lpad$phi20$index = 0, $lpad$phi20$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy34 = sp + 88|0;
 $1 = sp + 84|0;
 $2 = sp + 80|0;
 $3 = sp + 76|0;
 $4 = sp + 72|0;
 $5 = sp + 68|0;
 $6 = sp + 64|0;
 $7 = sp + 32|0;
 $8 = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 48|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$size>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = $17;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$size>>2] = $19;
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$21);
 $22 = (($data) + 8|0);
 HEAP32[$22>>2] = 0;
 $23 = (($data) + 4|0);
 HEAP32[$data>>2] = $23;
 HEAP32[$23>>2] = 0;
 $24 = HEAP32[$size>>2]|0;
 $25 = ($24|0)>(0);
 L5: do {
  if ($25) {
   $26 = (($p) + 12|0);
   $27 = (($p) + 1|0);
   $28 = (($10) + 1|0);
   $29 = (($p) + 12|0);
   $30 = (($10) + 12|0);
   $31 = (($7) + 1|0);
   $32 = (($7) + 12|0);
   $33 = (($10) + 8|0);
   $34 = (($7) + 8|0);
   $35 = (($7) + 4|0);
   $36 = (($10) + 4|0);
   $37 = (($p) + 8|0);
   $38 = (($p) + 4|0);
   $i$036 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_viii(1765,($this|0),($p|0),0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 67;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3377,($this|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 67;
     break;
    }
    __THREW__ = 0;
    invoke_vii(2796,($26|0),($this|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     label = 67;
     break;
    }
    $45 = HEAP8[$p>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $50 = $45&255;
     $51 = $50 >>> 1;
     $53 = $51;$66 = $27;
    } else {
     $48 = HEAP32[$37>>2]|0;
     $49 = HEAP32[$38>>2]|0;
     $53 = $49;$66 = $48;
    }
    $52 = ($53>>>0)>(2147483631);
    if ($52) {
     label = 13;
     break;
    }
    $56 = ($53>>>0)<(11);
    if ($56) {
     $57 = $53 << 1;
     $58 = $57&255;
     HEAP8[$10>>0] = $58;
     $70 = $58;$__p$0$i$i$i$i$i$i = $28;
    } else {
     $59 = (($53) + 16)|0;
     $60 = $59 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$8+0>>2]|0;
     $61 = (invoke_iiiiiii(102,($60|0),16,($$byval_copy34|0),0,(627384|0),79)|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      label = 67;
      break;
     }
     HEAP32[$33>>2] = $61;
     $64 = $60 | 1;
     HEAP32[$10>>2] = $64;
     HEAP32[$36>>2] = $53;
     $65 = $64&255;
     $70 = $65;$__p$0$i$i$i$i$i$i = $61;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($66|0),($53|0))|0;
    $67 = (($__p$0$i$i$i$i$i$i) + ($53)|0);
    HEAP8[$67>>0] = 0;
    $68 = HEAP32[$29>>2]|0;
    HEAP32[$30>>2] = $68;
    $69 = $70 & 1;
    $71 = ($69<<24>>24)==(0);
    if ($71) {
     $74 = $70&255;
     $75 = $74 >>> 1;
     $77 = $75;$90 = $28;
    } else {
     $72 = HEAP32[$33>>2]|0;
     $73 = HEAP32[$36>>2]|0;
     $77 = $73;$90 = $72;
    }
    $76 = ($77>>>0)>(2147483631);
    if ($76) {
     label = 23;
     break;
    }
    $80 = ($77>>>0)<(11);
    if ($80) {
     $81 = $77 << 1;
     $82 = $81&255;
     HEAP8[$7>>0] = $82;
     $95 = $82;$__p$0$i$i$i$i$i$i$i$i$i = $31;
    } else {
     $83 = (($77) + 16)|0;
     $84 = $83 & -16;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$6+0>>2]|0;
     $85 = (invoke_iiiiiii(102,($84|0),16,($$byval_copy34|0),0,(627384|0),79)|0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      label = 70;
      break;
     }
     HEAP32[$34>>2] = $85;
     $88 = $84 | 1;
     HEAP32[$7>>2] = $88;
     HEAP32[$35>>2] = $77;
     $89 = $88&255;
     $95 = $89;$__p$0$i$i$i$i$i$i$i$i$i = $85;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($90|0),($77|0))|0;
    $91 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($77)|0);
    HEAP8[$91>>0] = 0;
    HEAP32[$32>>2] = $68;
    $92 = HEAP32[$20>>2]|0;
    $93 = ($92|0)==(0|0);
    if ($93) {
     $$0$i$i = $23;$162 = $23;
    } else {
     $94 = $95 & 1;
     $96 = ($94<<24>>24)==(0);
     $97 = $95&255;
     $98 = $97 >>> 1;
     $99 = HEAP32[$35>>2]|0;
     $$$i = $96 ? $98 : $99;
     $100 = HEAP32[$34>>2]|0;
     $$6$i = $96 ? $31 : $100;
     $__nd$0$in$i$i = $92;
     while(1) {
      $101 = (($__nd$0$in$i$i) + 16|0);
      $102 = HEAP8[$101>>0]|0;
      $103 = $102 & 1;
      $104 = ($103<<24>>24)==(0);
      if ($104) {
       $109 = $102&255;
       $110 = $109 >>> 1;
       $111 = (($101) + 1|0);
       $113 = $110;$115 = $111;
      } else {
       $105 = (($__nd$0$in$i$i) + 20|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = (($__nd$0$in$i$i) + 24|0);
       $108 = HEAP32[$107>>2]|0;
       $113 = $106;$115 = $108;
      }
      $112 = ($113>>>0)<($$$i>>>0);
      $114 = $112 ? $113 : $$$i;
      $116 = (_memcmp($$6$i,$115,$114)|0);
      $117 = ($116|0)==(0);
      if ($117) {
       $118 = ($$$i>>>0)<($113>>>0);
       $$$i$i$i$i$i$i = $112&1;
       $$$$i$i$i$i$i$i = $118 ? -1 : $$$i$i$i$i$i$i;
       $120 = $$$$i$i$i$i$i$i;
      } else {
       $120 = $116;
      }
      $119 = ($120|0)<(0);
      if ($119) {
       $121 = HEAP32[$__nd$0$in$i$i>>2]|0;
       $122 = ($121|0)==(0|0);
       if ($122) {
        $$0$i$i = $__nd$0$in$i$i;$162 = $__nd$0$in$i$i;
        break;
       } else {
        $__nd$0$in$i$i = $121;
        continue;
       }
      } else {
       $123 = (($__nd$0$in$i$i) + 4|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = ($124|0)==(0|0);
       if ($125) {
        $$0$i$i = $123;$162 = $__nd$0$in$i$i;
        break;
       } else {
        $__nd$0$in$i$i = $124;
        continue;
       }
      }
     }
    }
    __THREW__ = 0;
    $126 = (invoke_ii(2988,32)|0);
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     label = 59;
     break;
    }
    $129 = (($126) + 16|0);
    $130 = $95 & 1;
    $131 = ($130<<24>>24)==(0);
    if ($131) {
     $134 = $95&255;
     $135 = $134 >>> 1;
     $137 = $135;$157 = $31;
    } else {
     $132 = HEAP32[$34>>2]|0;
     $133 = HEAP32[$35>>2]|0;
     $137 = $133;$157 = $132;
    }
    $136 = ($137>>>0)>(2147483631);
    if ($136) {
     label = 44;
     break;
    }
    $140 = ($137>>>0)<(11);
    if ($140) {
     $141 = $137 << 1;
     $142 = $141&255;
     HEAP8[$129>>0] = $142;
     $143 = (($126) + 17|0);
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $143;
    } else {
     $144 = (($137) + 16)|0;
     $145 = $144 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$5+0>>2]|0;
     $146 = (invoke_iiiiiii(102,($145|0),16,($$byval_copy34|0),0,(627384|0),79)|0);
     $147 = __THREW__; __THREW__ = 0;
     $148 = $147&1;
     if ($148) {
      label = 50;
      break;
     }
     $149 = (($126) + 24|0);
     HEAP32[$149>>2] = $146;
     $150 = $145 | 1;
     HEAP32[$129>>2] = $150;
     $151 = (($126) + 20|0);
     HEAP32[$151>>2] = $137;
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $146;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i$i$i|0),($157|0),($137|0))|0;
    $158 = (($__p$0$i$i$i$i$i$i$i$i$i$i$i) + ($137)|0);
    HEAP8[$158>>0] = 0;
    $159 = (($126) + 28|0);
    HEAP32[$159>>2] = $68;
    HEAP32[$126>>2] = 0;
    $160 = (($126) + 4|0);
    HEAP32[$160>>2] = 0;
    $161 = (($126) + 8|0);
    HEAP32[$161>>2] = $162;
    HEAP32[$$0$i$i>>2] = $126;
    $163 = HEAP32[$data>>2]|0;
    $164 = HEAP32[$163>>2]|0;
    $165 = ($164|0)==(0|0);
    if ($165) {
     $167 = $126;
    } else {
     HEAP32[$data>>2] = $164;
     $$pre$i$i$i6 = HEAP32[$$0$i$i>>2]|0;
     $167 = $$pre$i$i$i6;
    }
    $166 = HEAP32[$20>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($166,$167);
    $168 = HEAP32[$22>>2]|0;
    $169 = (($168) + 1)|0;
    HEAP32[$22>>2] = $169;
    $170 = HEAP8[$7>>0]|0;
    $171 = $170 & 1;
    $172 = ($171<<24>>24)==(0);
    if (!($172)) {
     $173 = HEAP32[$34>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($173|0),($$byval_copy34|0));
     $174 = __THREW__; __THREW__ = 0;
     $175 = $174&1;
     if ($175) {
      label = 58;
      break;
     }
    }
    $186 = HEAP8[$10>>0]|0;
    $187 = $186 & 1;
    $188 = ($187<<24>>24)==(0);
    if (!($188)) {
     $189 = HEAP32[$33>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($189|0),($$byval_copy34|0));
     $190 = __THREW__; __THREW__ = 0;
     $191 = $190&1;
     if ($191) {
      label = 65;
      break;
     }
    }
    $194 = (($i$036) + 1)|0;
    $195 = HEAP32[$size>>2]|0;
    $196 = ($194|0)<($195|0);
    if ($196) {
     $i$036 = $194;
    } else {
     break L5;
    }
   }
   do {
    if ((label|0) == 13) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      $199 = ___cxa_find_matching_catch()|0;
      $200 = tempRet0;
      $lpad$phi$index = $199;$lpad$phi$index14 = $200;
      label = 69;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      $203 = ___cxa_find_matching_catch()|0;
      $204 = tempRet0;
      $eh$lpad$body$index21Z2D = $204;$eh$lpad$body$indexZ2D = $203;
      label = 72;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 44) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if ($139) {
      $154 = ___cxa_find_matching_catch()|0;
      $155 = tempRet0;
      $lpad$phi20$index = $154;$lpad$phi20$index2 = $155;
      label = 52;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 50) {
     $152 = ___cxa_find_matching_catch()|0;
     $153 = tempRet0;
     $lpad$phi20$index = $152;$lpad$phi20$index2 = $153;
     label = 52;
    }
    else if ((label|0) == 58) {
     $176 = ___cxa_find_matching_catch()|0;
     $177 = tempRet0;
     ___cxa_call_unexpected(($176|0));
     // unreachable;
    }
    else if ((label|0) == 59) {
     $178 = ___cxa_find_matching_catch()|0;
     $179 = tempRet0;
     $$pre = $95 & 1;
     $$pre$phiZ2D = $$pre;$eh$lpad$body$i$index8Z2D = $179;$eh$lpad$body$i$indexZ2D = $178;
     label = 60;
    }
    else if ((label|0) == 65) {
     $192 = ___cxa_find_matching_catch()|0;
     $193 = tempRet0;
     ___cxa_call_unexpected(($192|0));
     // unreachable;
    }
    else if ((label|0) == 67) {
     $197 = ___cxa_find_matching_catch()|0;
     $198 = tempRet0;
     $lpad$phi$index = $197;$lpad$phi$index14 = $198;
     label = 69;
    }
    else if ((label|0) == 70) {
     $201 = ___cxa_find_matching_catch()|0;
     $202 = tempRet0;
     $eh$lpad$body$index21Z2D = $202;$eh$lpad$body$indexZ2D = $201;
     label = 72;
    }
   } while(0);
   if ((label|0) == 52) {
    $156 = ($126|0)==(0|0);
    if ($156) {
     $$pre$phiZ2D = $130;$eh$lpad$body$i$index8Z2D = $lpad$phi20$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi20$index;
     label = 60;
    } else {
     __ZdlPv($126);
     $$pre$phiZ2D = $130;$eh$lpad$body$i$index8Z2D = $lpad$phi20$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi20$index;
     label = 60;
    }
   }
   else if ((label|0) == 69) {
    $$0 = $lpad$phi$index14;$$01 = $lpad$phi$index;
   }
   if ((label|0) == 60) {
    $180 = ($$pre$phiZ2D<<24>>24)==(0);
    if ($180) {
     $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
     label = 72;
    } else {
     $181 = HEAP32[$34>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($181|0),($$byval_copy34|0));
     $182 = __THREW__; __THREW__ = 0;
     $183 = $182&1;
     if ($183) {
      $184 = ___cxa_find_matching_catch()|0;
      $185 = tempRet0;
      ___cxa_call_unexpected(($184|0));
      // unreachable;
     } else {
      $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
      label = 72;
     }
    }
   }
   if ((label|0) == 72) {
    $205 = $70 & 1;
    $206 = ($205<<24>>24)==(0);
    if ($206) {
     $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
    } else {
     $207 = HEAP32[$33>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($207|0),($$byval_copy34|0));
     $208 = __THREW__; __THREW__ = 0;
     $209 = $208&1;
     if ($209) {
      $210 = ___cxa_find_matching_catch()|0;
      $211 = tempRet0;
      ___cxa_call_unexpected(($210|0));
      // unreachable;
     } else {
      $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
    }
   }
   $221 = HEAP8[$p>>0]|0;
   $222 = $221 & 1;
   $223 = ($222<<24>>24)==(0);
   if ($223) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $224 = HEAP32[$37>>2]|0;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($224|0),($$byval_copy34|0));
   $225 = __THREW__; __THREW__ = 0;
   $226 = $225&1;
   if ($226) {
    $227 = ___cxa_find_matching_catch()|0;
    $228 = tempRet0;
    ___cxa_call_unexpected(($227|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $212 = HEAP8[$p>>0]|0;
 $213 = $212 & 1;
 $214 = ($213<<24>>24)==(0);
 if ($214) {
  STACKTOP = sp;return;
 }
 $215 = (($p) + 8|0);
 $216 = HEAP32[$215>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($216|0),($$byval_copy34|0));
 $217 = __THREW__; __THREW__ = 0;
 $218 = $217&1;
 if ($218) {
  $219 = ___cxa_find_matching_catch()|0;
  $220 = tempRet0;
  ___cxa_call_unexpected(($219|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN15ResourceManager10DependencyENS2_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIN15ResourceManager10DependencyENS0_9allocatorIS3_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ObjectENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$26,0);
   $27 = (($25) + 16|0);
   $28 = ($27|0)==($22|0);
   if ($28) {
    break;
   } else {
    $25 = $27;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ObjectENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4PPtrI6ObjectENS0_9allocatorIS4_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS2_4lessIS4_EENS2_9allocatorINS2_4pairIKS4_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$$$i$i$i$i$i$i = 0, $$$i = 0, $$$i$i$i$i$i$i = 0, $$0 = 0, $$0$i$i = 0, $$01 = 0, $$6$i = 0, $$byval_copy34 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$phiZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__nd$0$in$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0;
 var $__p$0$i$i$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$i$index8Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$035 = 0, $lpad$phi$index = 0, $lpad$phi$index14 = 0, $lpad$phi19$index = 0, $lpad$phi19$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy34 = sp + 88|0;
 $1 = sp + 84|0;
 $2 = sp + 80|0;
 $3 = sp + 76|0;
 $4 = sp + 72|0;
 $5 = sp + 68|0;
 $6 = sp + 64|0;
 $7 = sp + 32|0;
 $8 = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 48|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$size,4);
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$size>>2] = $17;
  HEAP32[$11>>2] = $13;
 }
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $18 = (($data) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$19);
 $20 = (($data) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = (($data) + 4|0);
 HEAP32[$data>>2] = $21;
 HEAP32[$21>>2] = 0;
 $22 = HEAP32[$size>>2]|0;
 $23 = ($22|0)>(0);
 L5: do {
  if ($23) {
   $24 = (($p) + 12|0);
   $25 = (($p) + 1|0);
   $26 = (($10) + 1|0);
   $27 = (($p) + 12|0);
   $28 = (($10) + 12|0);
   $29 = (($7) + 1|0);
   $30 = (($7) + 12|0);
   $31 = (($10) + 8|0);
   $32 = (($7) + 8|0);
   $33 = (($7) + 4|0);
   $34 = (($10) + 4|0);
   $35 = (($p) + 8|0);
   $36 = (($p) + 4|0);
   $i$035 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_viii(1767,($this|0),($p|0),0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 67;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3376,($this|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 67;
     break;
    }
    __THREW__ = 0;
    invoke_vii(2797,($24|0),($this|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 67;
     break;
    }
    $43 = HEAP8[$p>>0]|0;
    $44 = $43 & 1;
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     $48 = $43&255;
     $49 = $48 >>> 1;
     $51 = $49;$64 = $25;
    } else {
     $46 = HEAP32[$35>>2]|0;
     $47 = HEAP32[$36>>2]|0;
     $51 = $47;$64 = $46;
    }
    $50 = ($51>>>0)>(2147483631);
    if ($50) {
     label = 13;
     break;
    }
    $54 = ($51>>>0)<(11);
    if ($54) {
     $55 = $51 << 1;
     $56 = $55&255;
     HEAP8[$10>>0] = $56;
     $68 = $56;$__p$0$i$i$i$i$i$i = $26;
    } else {
     $57 = (($51) + 16)|0;
     $58 = $57 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$8+0>>2]|0;
     $59 = (invoke_iiiiiii(102,($58|0),16,($$byval_copy34|0),0,(627384|0),79)|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 67;
      break;
     }
     HEAP32[$31>>2] = $59;
     $62 = $58 | 1;
     HEAP32[$10>>2] = $62;
     HEAP32[$34>>2] = $51;
     $63 = $62&255;
     $68 = $63;$__p$0$i$i$i$i$i$i = $59;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($64|0),($51|0))|0;
    $65 = (($__p$0$i$i$i$i$i$i) + ($51)|0);
    HEAP8[$65>>0] = 0;
    $66 = HEAP32[$27>>2]|0;
    HEAP32[$28>>2] = $66;
    $67 = $68 & 1;
    $69 = ($67<<24>>24)==(0);
    if ($69) {
     $72 = $68&255;
     $73 = $72 >>> 1;
     $75 = $73;$88 = $26;
    } else {
     $70 = HEAP32[$31>>2]|0;
     $71 = HEAP32[$34>>2]|0;
     $75 = $71;$88 = $70;
    }
    $74 = ($75>>>0)>(2147483631);
    if ($74) {
     label = 23;
     break;
    }
    $78 = ($75>>>0)<(11);
    if ($78) {
     $79 = $75 << 1;
     $80 = $79&255;
     HEAP8[$7>>0] = $80;
     $93 = $80;$__p$0$i$i$i$i$i$i$i$i$i = $29;
    } else {
     $81 = (($75) + 16)|0;
     $82 = $81 & -16;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$6+0>>2]|0;
     $83 = (invoke_iiiiiii(102,($82|0),16,($$byval_copy34|0),0,(627384|0),79)|0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if ($85) {
      label = 70;
      break;
     }
     HEAP32[$32>>2] = $83;
     $86 = $82 | 1;
     HEAP32[$7>>2] = $86;
     HEAP32[$33>>2] = $75;
     $87 = $86&255;
     $93 = $87;$__p$0$i$i$i$i$i$i$i$i$i = $83;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($88|0),($75|0))|0;
    $89 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($75)|0);
    HEAP8[$89>>0] = 0;
    HEAP32[$30>>2] = $66;
    $90 = HEAP32[$18>>2]|0;
    $91 = ($90|0)==(0|0);
    if ($91) {
     $$0$i$i = $21;$160 = $21;
    } else {
     $92 = $93 & 1;
     $94 = ($92<<24>>24)==(0);
     $95 = $93&255;
     $96 = $95 >>> 1;
     $97 = HEAP32[$33>>2]|0;
     $$$i = $94 ? $96 : $97;
     $98 = HEAP32[$32>>2]|0;
     $$6$i = $94 ? $29 : $98;
     $__nd$0$in$i$i = $90;
     while(1) {
      $99 = (($__nd$0$in$i$i) + 16|0);
      $100 = HEAP8[$99>>0]|0;
      $101 = $100 & 1;
      $102 = ($101<<24>>24)==(0);
      if ($102) {
       $107 = $100&255;
       $108 = $107 >>> 1;
       $109 = (($99) + 1|0);
       $111 = $108;$113 = $109;
      } else {
       $103 = (($__nd$0$in$i$i) + 20|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = (($__nd$0$in$i$i) + 24|0);
       $106 = HEAP32[$105>>2]|0;
       $111 = $104;$113 = $106;
      }
      $110 = ($111>>>0)<($$$i>>>0);
      $112 = $110 ? $111 : $$$i;
      $114 = (_memcmp($$6$i,$113,$112)|0);
      $115 = ($114|0)==(0);
      if ($115) {
       $116 = ($$$i>>>0)<($111>>>0);
       $$$i$i$i$i$i$i = $110&1;
       $$$$i$i$i$i$i$i = $116 ? -1 : $$$i$i$i$i$i$i;
       $118 = $$$$i$i$i$i$i$i;
      } else {
       $118 = $114;
      }
      $117 = ($118|0)<(0);
      if ($117) {
       $119 = HEAP32[$__nd$0$in$i$i>>2]|0;
       $120 = ($119|0)==(0|0);
       if ($120) {
        $$0$i$i = $__nd$0$in$i$i;$160 = $__nd$0$in$i$i;
        break;
       } else {
        $__nd$0$in$i$i = $119;
        continue;
       }
      } else {
       $121 = (($__nd$0$in$i$i) + 4|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = ($122|0)==(0|0);
       if ($123) {
        $$0$i$i = $121;$160 = $__nd$0$in$i$i;
        break;
       } else {
        $__nd$0$in$i$i = $122;
        continue;
       }
      }
     }
    }
    __THREW__ = 0;
    $124 = (invoke_ii(2988,32)|0);
    $125 = __THREW__; __THREW__ = 0;
    $126 = $125&1;
    if ($126) {
     label = 59;
     break;
    }
    $127 = (($124) + 16|0);
    $128 = $93 & 1;
    $129 = ($128<<24>>24)==(0);
    if ($129) {
     $132 = $93&255;
     $133 = $132 >>> 1;
     $135 = $133;$155 = $29;
    } else {
     $130 = HEAP32[$32>>2]|0;
     $131 = HEAP32[$33>>2]|0;
     $135 = $131;$155 = $130;
    }
    $134 = ($135>>>0)>(2147483631);
    if ($134) {
     label = 44;
     break;
    }
    $138 = ($135>>>0)<(11);
    if ($138) {
     $139 = $135 << 1;
     $140 = $139&255;
     HEAP8[$127>>0] = $140;
     $141 = (($124) + 17|0);
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $141;
    } else {
     $142 = (($135) + 16)|0;
     $143 = $142 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$5+0>>2]|0;
     $144 = (invoke_iiiiiii(102,($143|0),16,($$byval_copy34|0),0,(627384|0),79)|0);
     $145 = __THREW__; __THREW__ = 0;
     $146 = $145&1;
     if ($146) {
      label = 50;
      break;
     }
     $147 = (($124) + 24|0);
     HEAP32[$147>>2] = $144;
     $148 = $143 | 1;
     HEAP32[$127>>2] = $148;
     $149 = (($124) + 20|0);
     HEAP32[$149>>2] = $135;
     $__p$0$i$i$i$i$i$i$i$i$i$i$i = $144;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i$i$i|0),($155|0),($135|0))|0;
    $156 = (($__p$0$i$i$i$i$i$i$i$i$i$i$i) + ($135)|0);
    HEAP8[$156>>0] = 0;
    $157 = (($124) + 28|0);
    HEAP32[$157>>2] = $66;
    HEAP32[$124>>2] = 0;
    $158 = (($124) + 4|0);
    HEAP32[$158>>2] = 0;
    $159 = (($124) + 8|0);
    HEAP32[$159>>2] = $160;
    HEAP32[$$0$i$i>>2] = $124;
    $161 = HEAP32[$data>>2]|0;
    $162 = HEAP32[$161>>2]|0;
    $163 = ($162|0)==(0|0);
    if ($163) {
     $165 = $124;
    } else {
     HEAP32[$data>>2] = $162;
     $$pre$i$i$i = HEAP32[$$0$i$i>>2]|0;
     $165 = $$pre$i$i$i;
    }
    $164 = HEAP32[$18>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($164,$165);
    $166 = HEAP32[$20>>2]|0;
    $167 = (($166) + 1)|0;
    HEAP32[$20>>2] = $167;
    $168 = HEAP8[$7>>0]|0;
    $169 = $168 & 1;
    $170 = ($169<<24>>24)==(0);
    if (!($170)) {
     $171 = HEAP32[$32>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($171|0),($$byval_copy34|0));
     $172 = __THREW__; __THREW__ = 0;
     $173 = $172&1;
     if ($173) {
      label = 58;
      break;
     }
    }
    $184 = HEAP8[$10>>0]|0;
    $185 = $184 & 1;
    $186 = ($185<<24>>24)==(0);
    if (!($186)) {
     $187 = HEAP32[$31>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($187|0),($$byval_copy34|0));
     $188 = __THREW__; __THREW__ = 0;
     $189 = $188&1;
     if ($189) {
      label = 65;
      break;
     }
    }
    $192 = (($i$035) + 1)|0;
    $193 = HEAP32[$size>>2]|0;
    $194 = ($192|0)<($193|0);
    if ($194) {
     $i$035 = $192;
    } else {
     break L5;
    }
   }
   do {
    if ((label|0) == 13) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $197 = ___cxa_find_matching_catch()|0;
      $198 = tempRet0;
      $lpad$phi$index = $197;$lpad$phi$index14 = $198;
      label = 69;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      $201 = ___cxa_find_matching_catch()|0;
      $202 = tempRet0;
      $eh$lpad$body$index21Z2D = $202;$eh$lpad$body$indexZ2D = $201;
      label = 72;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 44) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $136 = __THREW__; __THREW__ = 0;
     $137 = $136&1;
     if ($137) {
      $152 = ___cxa_find_matching_catch()|0;
      $153 = tempRet0;
      $lpad$phi19$index = $152;$lpad$phi19$index2 = $153;
      label = 52;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 50) {
     $150 = ___cxa_find_matching_catch()|0;
     $151 = tempRet0;
     $lpad$phi19$index = $150;$lpad$phi19$index2 = $151;
     label = 52;
    }
    else if ((label|0) == 58) {
     $174 = ___cxa_find_matching_catch()|0;
     $175 = tempRet0;
     ___cxa_call_unexpected(($174|0));
     // unreachable;
    }
    else if ((label|0) == 59) {
     $176 = ___cxa_find_matching_catch()|0;
     $177 = tempRet0;
     $$pre = $93 & 1;
     $$pre$phiZ2D = $$pre;$eh$lpad$body$i$index8Z2D = $177;$eh$lpad$body$i$indexZ2D = $176;
     label = 60;
    }
    else if ((label|0) == 65) {
     $190 = ___cxa_find_matching_catch()|0;
     $191 = tempRet0;
     ___cxa_call_unexpected(($190|0));
     // unreachable;
    }
    else if ((label|0) == 67) {
     $195 = ___cxa_find_matching_catch()|0;
     $196 = tempRet0;
     $lpad$phi$index = $195;$lpad$phi$index14 = $196;
     label = 69;
    }
    else if ((label|0) == 70) {
     $199 = ___cxa_find_matching_catch()|0;
     $200 = tempRet0;
     $eh$lpad$body$index21Z2D = $200;$eh$lpad$body$indexZ2D = $199;
     label = 72;
    }
   } while(0);
   if ((label|0) == 52) {
    $154 = ($124|0)==(0|0);
    if ($154) {
     $$pre$phiZ2D = $128;$eh$lpad$body$i$index8Z2D = $lpad$phi19$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi19$index;
     label = 60;
    } else {
     __ZdlPv($124);
     $$pre$phiZ2D = $128;$eh$lpad$body$i$index8Z2D = $lpad$phi19$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi19$index;
     label = 60;
    }
   }
   else if ((label|0) == 69) {
    $$0 = $lpad$phi$index14;$$01 = $lpad$phi$index;
   }
   if ((label|0) == 60) {
    $178 = ($$pre$phiZ2D<<24>>24)==(0);
    if ($178) {
     $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
     label = 72;
    } else {
     $179 = HEAP32[$32>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($179|0),($$byval_copy34|0));
     $180 = __THREW__; __THREW__ = 0;
     $181 = $180&1;
     if ($181) {
      $182 = ___cxa_find_matching_catch()|0;
      $183 = tempRet0;
      ___cxa_call_unexpected(($182|0));
      // unreachable;
     } else {
      $eh$lpad$body$index21Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
      label = 72;
     }
    }
   }
   if ((label|0) == 72) {
    $203 = $68 & 1;
    $204 = ($203<<24>>24)==(0);
    if ($204) {
     $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
    } else {
     $205 = HEAP32[$31>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($205|0),($$byval_copy34|0));
     $206 = __THREW__; __THREW__ = 0;
     $207 = $206&1;
     if ($207) {
      $208 = ___cxa_find_matching_catch()|0;
      $209 = tempRet0;
      ___cxa_call_unexpected(($208|0));
      // unreachable;
     } else {
      $$0 = $eh$lpad$body$index21Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
    }
   }
   $219 = HEAP8[$p>>0]|0;
   $220 = $219 & 1;
   $221 = ($220<<24>>24)==(0);
   if ($221) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $222 = HEAP32[$35>>2]|0;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($222|0),($$byval_copy34|0));
   $223 = __THREW__; __THREW__ = 0;
   $224 = $223&1;
   if ($224) {
    $225 = ___cxa_find_matching_catch()|0;
    $226 = tempRet0;
    ___cxa_call_unexpected(($225|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $210 = HEAP8[$p>>0]|0;
 $211 = $210 & 1;
 $212 = ($211<<24>>24)==(0);
 if ($212) {
  STACKTOP = sp;return;
 }
 $213 = (($p) + 8|0);
 $214 = HEAP32[$213>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy34+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($214|0),($$byval_copy34|0));
 $215 = __THREW__; __THREW__ = 0;
 $216 = $215&1;
 if ($216) {
  $217 = ___cxa_find_matching_catch()|0;
  $218 = tempRet0;
  ___cxa_call_unexpected(($217|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN15ResourceManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $converter$i$i1 = sp + 4|0;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $1 = (($this) + 36|0);
 $2 = HEAP32[580600>>2]|0;
 $3 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,627544,$2,$converter$i$i1,1)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ($3|0)>(0);
  if ($5) {
   __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S6_EEEEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
  } else {
   $6 = HEAP32[$converter$i$i1>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    (FUNCTION_TABLE_iii[$6 & 4095]($1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $8 = (($this) + 24|0);
 $9 = HEAP32[580760>>2]|0;
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,627560,$9,$converter$i$i1,1)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  $15 = HEAP32[$8>>2]|0;
  $16 = (($this) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  __ZNSt3__16__sortIRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($15,$17,$0);
  STACKTOP = sp;return;
 }
 $12 = ($10|0)>(0);
 if ($12) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN15ResourceManager10DependencyENS1_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$8,0);
 } else {
  $13 = HEAP32[$converter$i$i1>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   (FUNCTION_TABLE_iii[$13 & 4095]($8,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $15 = HEAP32[$8>>2]|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 __ZNSt3__16__sortIRN15ResourceManager10Dependency6SorterEPS2_EEvT0_S6_T_($15,$17,$0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN15ResourceManager10DependencyENS1_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,627656,627656,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIN15ResourceManager10DependencyENS0_9allocatorIS3_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,627584,627664,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN15ResourceManager10Dependency8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 16|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,627584,627664,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN15ResourceManager10Dependency8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 16|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15ResourceManager10Dependency8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580624>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,627592,$0,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 4|0);
 $7 = HEAP32[580760>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,627608,$7,$converter$i$i1,1)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ObjectENS1_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$6,0);
 } else {
  $11 = HEAP32[$converter$i$i1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (FUNCTION_TABLE_iii[$11 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ObjectENS1_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,627656,627656,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4PPtrI6ObjectENS0_9allocatorIS4_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580624>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,627584,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$49 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($49,$this);
       $50 = (($49) + 4|0);
       $51 = ($50|0)==($11|0);
       if ($51) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$16>>2]|0;
       $30 = $$pre9;$33 = $$pre10;$49 = $50;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $52 = HEAP32[$data>>2]|0;
   $53 = ($52|0)==($11|0);
   if (!($53)) {
    $57 = $52;
    while(1) {
     $54 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,627584,$14,$converter$i$i,1)|0);
     $55 = ($54|0)==(0);
     if (!($55)) {
      $56 = ($54|0)>(0);
      if ($56) {
       __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($57,$this);
      } else {
       $58 = HEAP32[$converter$i$i>>2]|0;
       $59 = ($58|0)==(0|0);
       if (!($59)) {
        (FUNCTION_TABLE_iii[$58 & 4095]($57,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $60 = (($57) + 4|0);
     $61 = ($60|0)==($11|0);
     if ($61) {
      break;
     } else {
      $57 = $60;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferINSt3__18multimapI8UnityStr4PPtrI6ObjectENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S6_EEEEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $size$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $size$i$i = sp + 4|0;
 $p$i$i = sp + 8|0;
 $1 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$1,$data,$metaFlag);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,627656,627656,$size$i$i,0);
 ;HEAP32[$p$i$i+0>>2]=0|0;HEAP32[$p$i$i+4>>2]=0|0;HEAP32[$p$i$i+8>>2]=0|0;HEAP32[$p$i$i+12>>2]=0|0;
 $2 = HEAP32[580608>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($this|0),(627584|0),($2|0),($p$i$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vii(2798,($p$i$i|0),($this|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_vi(3390,($this|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(3391,($this|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP8[$p$i$i>>0]|0;
     $12 = $11 & 1;
     $13 = ($12<<24>>24)==(0);
     if ($13) {
      __ZN13ProxyTransfer11EndTransferEv($this);
      STACKTOP = sp;return;
     }
     $14 = (($p$i$i) + 8|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy1|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      $18 = ___cxa_find_matching_catch()|0;
      $19 = tempRet0;
      ___cxa_call_unexpected(($18|0));
      // unreachable;
     } else {
      __ZN13ProxyTransfer11EndTransferEv($this);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $22 = HEAP8[$p$i$i>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  ___resumeException($20|0);
  // unreachable;
 }
 $25 = (($p$i$i) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($26|0),($$byval_copy1|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  ___cxa_call_unexpected(($29|0));
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorIN15ResourceManager10DependencyENS1_9allocatorIS4_EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i$i = 0, $p$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i$i = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i4$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i = sp + 16|0;
 $p$i$i = sp;
 $0 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$0,$data,$metaFlag);
 ;HEAP32[$p$i$i+0>>2]=0|0;HEAP32[$p$i$i+4>>2]=0|0;HEAP32[$p$i$i+8>>2]=0|0;HEAP32[$p$i$i+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(627656|0),(627656|0),($size$i$i$i|0),0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(627584|0),(627664|0),($p$i$i|0),0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(2799,($p$i$i|0),($this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3390,($this|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vi(3391,($this|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = (($p$i$i) + 4|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = ($12|0)==(0|0);
      if ($13) {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
      $14 = (($p$i$i) + 8|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = ($15|0)==($12|0);
      if (!($16)) {
       $__new_last2$i$i$i$i$i$i$i1$i$i = $12;
       $scevgep$i$i$i$i$i$i$i2$i$i = (($15) + -4|0);
       $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i$i))|0;
       $uglygep$i$i$i$i$i$i$i4$i$i = (($scevgep$i$i$i$i$i$i$i2$i$i) + ($17)|0);
       $uglygep3$i$i$i$i$i$i$i5$i$i = $uglygep$i$i$i$i$i$i$i4$i$i;
       $18 = $uglygep3$i$i$i$i$i$i$i5$i$i >>> 2;
       $19 = $18 ^ -1;
       $scevgep4$i$i$i$i$i$i$i6$i$i = (($15) + ($19<<2)|0);
       HEAP32[$14>>2] = $scevgep4$i$i$i$i$i$i$i6$i$i;
      }
      __ZdlPv($12);
      __ZN13ProxyTransfer11EndTransferEv($this);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $22 = (($p$i$i) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  ___resumeException($20|0);
  // unreachable;
 }
 $25 = (($p$i$i) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==($23|0);
 if (!($27)) {
  $__new_last2$i$i$i$i$i$i$i$i$i = $23;
  $scevgep$i$i$i$i$i$i$i$i$i = (($26) + -4|0);
  $28 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($28)|0);
  $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
  $29 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 2;
  $30 = $29 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i$i = (($26) + ($30<<2)|0);
  HEAP32[$25>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
 }
 __ZdlPv($23);
 ___resumeException($20|0);
 // unreachable;
}
function __ZN15ResourceManager10Dependency8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i$i = 0, $p$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 $size$i$i$i = sp + 20|0;
 $p$i$i = sp + 16|0;
 $0 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627592,$0,$this,0);
 $1 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627624,$6,$this,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627640,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 4|0);
 $19 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627608,$19,$18,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,627656,627656,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627584,$0,$p$i$i,0);
 $20 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $21 = $20;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627624,$6,$p$i$i,1);
 $25 = HEAP32[$7>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$10>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627640,$13,$20,1);
 $29 = HEAP32[$7>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$10>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairI8UnityStr4PPtrI6ObjectEEEE8TransferI13ProxyTransferEEvRS6_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, $p$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i = sp;
 $p$i$i$i = sp + 16|0;
 $0 = HEAP32[580576>>2]|0;
 $1 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$0,$1,$data,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,627656,627656,$localIdentifier$i$i$i,1);
 $2 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627584,$2,$p$i$i$i,0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($data) + 12|0);
 $10 = HEAP32[580656>>2]|0;
 $11 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$10,$11,$9,0);
 $12 = (($localIdentifier$i$i$i) + 8|0);
 $13 = $12;
 $14 = $13;
 HEAP32[$14>>2] = 0;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $17 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627624,$17,$9,1);
 $18 = HEAP32[$3>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$6>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,627640,$22,$12,1);
 $23 = HEAP32[$3>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$6>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE19__equal_range_multiIS2_EENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEESL_EERKT_($agg$result,$this,$__k) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__k = $__k|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i6 = 0, $$$i$i$i$i = 0, $$$i$i$i$i5 = 0, $$c$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__result$0$ph18 = 0, $__result$0$ph21 = 0, $__rt$0$in = 0, $__rt$0$in12 = 0, $__rt$0$in1219 = 0, $__rt$01323$in = 0, $__rt$015$in = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (($this) + 4|0);
 $3 = (($this) + 4|0);
 $__rt$0$in1219 = HEAP32[$3>>2]|0;
 $4 = ($__rt$0$in1219|0)==(0|0);
 L1: do {
  if ($4) {
   $__result$0$ph18 = $2;
  } else {
   $5 = HEAP8[$__k>>0]|0;
   $6 = $5 & 1;
   $7 = ($6<<24>>24)==(0);
   $8 = $5&255;
   $9 = $8 >>> 1;
   $10 = (($__k) + 1|0);
   $11 = (($__k) + 8|0);
   $12 = (($__k) + 4|0);
   $__result$0$ph21 = $2;$__rt$01323$in = $__rt$0$in1219;
   L3: while(1) {
    $__rt$015$in = $__rt$01323$in;
    while(1) {
     $15 = (($__rt$015$in) + 16|0);
     if ($7) {
      $30 = $9;
     } else {
      $16 = HEAP32[$12>>2]|0;
      $30 = $16;
     }
     $17 = HEAP8[$15>>0]|0;
     $18 = $17 & 1;
     $19 = ($18<<24>>24)==(0);
     if ($19) {
      $22 = $17&255;
      $23 = $22 >>> 1;
      $29 = $23;
     } else {
      $20 = (($__rt$015$in) + 20|0);
      $21 = HEAP32[$20>>2]|0;
      $29 = $21;
     }
     if ($7) {
      $32 = $10;
     } else {
      $24 = HEAP32[$11>>2]|0;
      $32 = $24;
     }
     if ($19) {
      $27 = (($15) + 1|0);
      $33 = $27;
     } else {
      $25 = (($__rt$015$in) + 24|0);
      $26 = HEAP32[$25>>2]|0;
      $33 = $26;
     }
     $28 = ($29>>>0)<($30>>>0);
     $31 = $28 ? $29 : $30;
     $34 = (_memcmp($32,$33,$31)|0);
     $35 = ($34|0)==(0);
     if ($35) {
      $36 = ($30>>>0)<($29>>>0);
      $$$i$i$i$i5 = $28&1;
      $$$$i$i$i$i6 = $36 ? -1 : $$$i$i$i$i5;
      $38 = $$$$i$i$i$i6;
     } else {
      $38 = $34;
     }
     $37 = ($38|0)<(0);
     if ($37) {
      break;
     }
     if ($19) {
      $42 = $17&255;
      $43 = $42 >>> 1;
      $51 = $43;
     } else {
      $40 = (($__rt$015$in) + 20|0);
      $41 = HEAP32[$40>>2]|0;
      $51 = $41;
     }
     if ($7) {
      $50 = $9;
     } else {
      $44 = HEAP32[$12>>2]|0;
      $50 = $44;
     }
     if ($19) {
      $47 = (($15) + 1|0);
      $53 = $47;
     } else {
      $45 = (($__rt$015$in) + 24|0);
      $46 = HEAP32[$45>>2]|0;
      $53 = $46;
     }
     if ($7) {
      $54 = $10;
     } else {
      $48 = HEAP32[$11>>2]|0;
      $54 = $48;
     }
     $49 = ($50>>>0)<($51>>>0);
     $52 = $49 ? $50 : $51;
     $55 = (_memcmp($53,$54,$52)|0);
     $56 = ($55|0)==(0);
     if ($56) {
      $57 = ($51>>>0)<($50>>>0);
      $$$i$i$i$i = $49&1;
      $$$$i$i$i$i = $57 ? -1 : $$$i$i$i$i;
      $59 = $$$$i$i$i$i;
     } else {
      $59 = $55;
     }
     $58 = ($59|0)<(0);
     if (!($58)) {
      break L3;
     }
     $13 = (($__rt$015$in) + 4|0);
     $__rt$0$in = HEAP32[$13>>2]|0;
     $14 = ($__rt$0$in|0)==(0|0);
     if ($14) {
      $__result$0$ph18 = $__result$0$ph21;
      break L1;
     } else {
      $__rt$015$in = $__rt$0$in;
     }
    }
    $__rt$0$in12 = HEAP32[$__rt$015$in>>2]|0;
    $39 = ($__rt$0$in12|0)==(0|0);
    if ($39) {
     $__result$0$ph18 = $__rt$015$in;
     break L1;
    } else {
     $__result$0$ph21 = $__rt$015$in;$__rt$01323$in = $__rt$0$in12;
    }
   }
   $60 = HEAP32[$__rt$015$in>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_($0,$this,$__k,$60,$__rt$015$in);
   $61 = (($__rt$015$in) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE13__upper_boundIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_($1,$this,$__k,$62,$__result$0$ph21);
   $63 = HEAP32[$0>>2]|0;
   $$c$i$i1 = $63;
   HEAP32[$agg$result>>2] = $$c$i$i1;
   $64 = HEAP32[$1>>2]|0;
   $65 = (($agg$result) + 4|0);
   HEAP32[$65>>2] = $64;
   STACKTOP = sp;return;
  }
 } while(0);
 HEAP32[$agg$result>>2] = $__result$0$ph18;
 $66 = (($agg$result) + 4|0);
 HEAP32[$66>>2] = $__result$0$ph18;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_($agg$result,$this,$__v,$__root,$__result) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 $__root = $__root|0;
 $__result = $__result|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0$ph6 = 0, $$0$ph9 = 0, $$01$lcssa2 = 0, $$01$ph8 = 0, $$013 = 0, $$013$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__root|0)==(0|0);
 if ($0) {
  $$0$ph6 = $__result;
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
 $1 = HEAP8[$__v>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 $4 = $1&255;
 $5 = $4 >>> 1;
 $6 = (($__v) + 1|0);
 $7 = (($__v) + 8|0);
 $8 = (($__v) + 4|0);
 $$0$ph9 = $__result;$$01$ph8 = $__root;
 L4: while(1) {
  L6: do {
   if ($3) {
    $$013$us = $$01$ph8;
    while(1) {
     $9 = (($$013$us) + 16|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 & 1;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $17 = $10&255;
      $18 = $17 >>> 1;
      $19 = (($9) + 1|0);
      $21 = $18;$23 = $19;
     } else {
      $13 = (($$013$us) + 20|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($$013$us) + 24|0);
      $16 = HEAP32[$15>>2]|0;
      $21 = $14;$23 = $16;
     }
     $20 = ($5>>>0)<($21>>>0);
     $22 = $20 ? $5 : $21;
     $24 = (_memcmp($23,$6,$22)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = ($21>>>0)<($5>>>0);
      $$$i$i$i$i$us = $20&1;
      $$$$i$i$i$i$us = $26 ? -1 : $$$i$i$i$i$us;
      $28 = $$$$i$i$i$i$us;
     } else {
      $28 = $24;
     }
     $27 = ($28|0)<(0);
     if (!($27)) {
      $$01$lcssa2 = $$013$us;
      break L6;
     }
     $29 = (($$013$us) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013$us = $30;
     }
    }
   } else {
    $$013 = $$01$ph8;
    while(1) {
     $32 = (($$013) + 16|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if ($35) {
      $40 = $33&255;
      $41 = $40 >>> 1;
      $42 = (($32) + 1|0);
      $46 = $41;$48 = $42;
     } else {
      $36 = (($$013) + 20|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($$013) + 24|0);
      $39 = HEAP32[$38>>2]|0;
      $46 = $37;$48 = $39;
     }
     $43 = HEAP32[$8>>2]|0;
     $44 = HEAP32[$7>>2]|0;
     $45 = ($43>>>0)<($46>>>0);
     $47 = $45 ? $43 : $46;
     $49 = (_memcmp($48,$44,$47)|0);
     $50 = ($49|0)==(0);
     if ($50) {
      $51 = ($46>>>0)<($43>>>0);
      $$$i$i$i$i = $45&1;
      $$$$i$i$i$i = $51 ? -1 : $$$i$i$i$i;
      $53 = $$$$i$i$i$i;
     } else {
      $53 = $49;
     }
     $52 = ($53|0)<(0);
     if (!($52)) {
      $$01$lcssa2 = $$013;
      break L6;
     }
     $56 = (($$013) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013 = $57;
     }
    }
   }
  } while(0);
  $54 = HEAP32[$$01$lcssa2>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$0$ph6 = $$01$lcssa2;
   label = 19;
   break;
  } else {
   $$0$ph9 = $$01$lcssa2;$$01$ph8 = $54;
  }
 }
 if ((label|0) == 19) {
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE13__upper_boundIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_($agg$result,$this,$__v,$__root,$__result) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 $__root = $__root|0;
 $__result = $__result|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0$ph6 = 0, $$0$ph9 = 0, $$01$lcssa2 = 0, $$01$ph8 = 0, $$013 = 0, $$013$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__root|0)==(0|0);
 if ($0) {
  $$0$ph6 = $__result;
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
 $1 = HEAP8[$__v>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 $4 = $1&255;
 $5 = $4 >>> 1;
 $6 = (($__v) + 1|0);
 $7 = (($__v) + 8|0);
 $8 = (($__v) + 4|0);
 $$0$ph9 = $__result;$$01$ph8 = $__root;
 L4: while(1) {
  L6: do {
   if ($3) {
    $$013$us = $$01$ph8;
    while(1) {
     $9 = (($$013$us) + 16|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 & 1;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $17 = $10&255;
      $18 = $17 >>> 1;
      $19 = (($9) + 1|0);
      $21 = $18;$23 = $19;
     } else {
      $13 = (($$013$us) + 20|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($$013$us) + 24|0);
      $16 = HEAP32[$15>>2]|0;
      $21 = $14;$23 = $16;
     }
     $20 = ($21>>>0)<($5>>>0);
     $22 = $20 ? $21 : $5;
     $24 = (_memcmp($6,$23,$22)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = ($5>>>0)<($21>>>0);
      $$$i$i$i$i$us = $20&1;
      $$$$i$i$i$i$us = $26 ? -1 : $$$i$i$i$i$us;
      $28 = $$$$i$i$i$i$us;
     } else {
      $28 = $24;
     }
     $27 = ($28|0)<(0);
     if ($27) {
      $$01$lcssa2 = $$013$us;
      break L6;
     }
     $29 = (($$013$us) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013$us = $30;
     }
    }
   } else {
    $$013 = $$01$ph8;
    while(1) {
     $32 = (($$013) + 16|0);
     $33 = HEAP32[$8>>2]|0;
     $34 = HEAP8[$32>>0]|0;
     $35 = $34 & 1;
     $36 = ($35<<24>>24)==(0);
     if ($36) {
      $41 = $34&255;
      $42 = $41 >>> 1;
      $43 = (($32) + 1|0);
      $46 = $42;$48 = $43;
     } else {
      $37 = (($$013) + 20|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($$013) + 24|0);
      $40 = HEAP32[$39>>2]|0;
      $46 = $38;$48 = $40;
     }
     $44 = HEAP32[$7>>2]|0;
     $45 = ($46>>>0)<($33>>>0);
     $47 = $45 ? $46 : $33;
     $49 = (_memcmp($44,$48,$47)|0);
     $50 = ($49|0)==(0);
     if ($50) {
      $51 = ($33>>>0)<($46>>>0);
      $$$i$i$i$i = $45&1;
      $$$$i$i$i$i = $51 ? -1 : $$$i$i$i$i;
      $53 = $$$$i$i$i$i;
     } else {
      $53 = $49;
     }
     $52 = ($53|0)<(0);
     if ($52) {
      $$01$lcssa2 = $$013;
      break L6;
     }
     $56 = (($$013) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013 = $57;
     }
    }
   }
  } while(0);
  $54 = HEAP32[$$01$lcssa2>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$0$ph6 = $$01$lcssa2;
   label = 19;
   break;
  } else {
   $$0$ph9 = $$01$lcssa2;$$01$ph8 = $54;
  }
 }
 if ((label|0) == 19) {
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN22BuiltinResourceManager8ResourceENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 24)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(178956970);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 24)&-1;
 $14 = ($13>>>0)<(89478485);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 178956970;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*24)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*24)|0)|0);
 $23 = (($22) + (($$0$i3*24)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  ;HEAP32[$21+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$21+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$21+20>>2]=HEAP32[$__x+20>>2]|0;
 }
 $25 = (($22) + (($7*24)|0)|0);
 $26 = (($5|0) / -24)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*24)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$029 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0;
 var $__j$026 = 0, $__j$026$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i22 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -24|0);
  $2 = (($$01$ph) + -48|0);
  $3 = (($$01$ph) + -20|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $4 = $$0;
   $5 = (($0) - ($4))|0;
   $6 = (($5|0) / 24)&-1;
   switch ($6|0) {
   case 5:  {
    label = 10;
    break L1;
    break;
   }
   case 3:  {
    label = 8;
    break L1;
    break;
   }
   case 4:  {
    label = 9;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 71;
    break L1;
    break;
   }
   default: {
   }
   }
   $22 = ($5|0)<(744);
   if ($22) {
    label = 12;
    break L1;
   }
   $23 = ($5|0)>(23976);
   $24 = (($5|0) / 48)&-1;
   $25 = (($$0) + (($24*24)|0)|0);
   if ($23) {
    $26 = (($5|0) / 96)&-1;
    $27 = (($$0) + (($26*24)|0)|0);
    $$sum = (($26) + ($24))|0;
    $28 = (($$0) + (($$sum*24)|0)|0);
    $29 = (__ZNSt3__17__sort5IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_S7_S7_T_($$0,$27,$25,$28,$1,0)|0);
    $__n_swaps$0 = $29;
   } else {
    $30 = (__ZNSt3__17__sort3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_T_($$0,$25,$1,0)|0);
    $__n_swaps$0 = $30;
   }
   $31 = HEAP32[$$0>>2]|0;
   $32 = HEAP32[$25>>2]|0;
   $33 = (_strcmp($31,$32)|0);
   $34 = ($33|0)==(0);
   if ($34) {
    $36 = (($$0) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($$0) + (($24*24)|0)|0) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($37|0)<($39|0);
    if ($40) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     label = 19;
    }
   } else {
    $35 = ($33|0)<(0);
    if ($35) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     label = 19;
    }
   }
   L14: do {
    if ((label|0) == 19) {
     label = 0;
     $41 = ($$0|0)==($2|0);
     L16: do {
      if (!($41)) {
       $42 = ((($$0) + (($24*24)|0)|0) + 4|0);
       $89 = $2;$__j$026 = $1;
       while(1) {
        $88 = HEAP32[$89>>2]|0;
        $90 = (_strcmp($88,$32)|0);
        $91 = ($90|0)==(0);
        if ($91) {
         $93 = (($__j$026) + -20|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = HEAP32[$42>>2]|0;
         $96 = ($94|0)<($95|0);
         if ($96) {
          break;
         }
        } else {
         $92 = ($90|0)<(0);
         if ($92) {
          break;
         }
        }
        $97 = (($89) + -24|0);
        $98 = ($$0|0)==($97|0);
        if ($98) {
         break L16;
        } else {
         $__j$026$phi = $89;$89 = $97;$__j$026 = $__j$026$phi;
        }
       }
       ;HEAP32[$__t$i22+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i22+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i22+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i22+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i22+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i22+20>>2]=HEAP32[$$0+20>>2]|0;
       ;HEAP32[$$0+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$89+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$89+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$89+20>>2]|0;
       ;HEAP32[$89+0>>2]=HEAP32[$__t$i22+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$__t$i22+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$__t$i22+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$__t$i22+12>>2]|0;HEAP32[$89+16>>2]=HEAP32[$__t$i22+16>>2]|0;HEAP32[$89+20>>2]=HEAP32[$__t$i22+20>>2]|0;
       $99 = (($__n_swaps$0) + 1)|0;
       $__j$3 = $89;$__n_swaps$3 = $99;
       break L14;
      }
     } while(0);
     $43 = (($$0) + 24|0);
     $44 = HEAP32[$1>>2]|0;
     $45 = (_strcmp($31,$44)|0);
     $46 = ($45|0)==(0);
     if ($46) {
      $48 = (($$0) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = HEAP32[$3>>2]|0;
      $51 = ($49|0)<($50|0);
      if ($51) {
       $__i$1 = $43;
      } else {
       label = 24;
      }
     } else {
      $47 = ($45|0)<(0);
      if ($47) {
       $__i$1 = $43;
      } else {
       label = 24;
      }
     }
     if ((label|0) == 24) {
      label = 0;
      $52 = ($43|0)==($1|0);
      if ($52) {
       label = 71;
       break L1;
      }
      $53 = (($$0) + 4|0);
      $__i$029 = $43;
      while(1) {
       $54 = HEAP32[$__i$029>>2]|0;
       $55 = (_strcmp($31,$54)|0);
       $56 = ($55|0)==(0);
       if ($56) {
        $58 = HEAP32[$53>>2]|0;
        $59 = (($__i$029) + 4|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = ($58|0)<($60|0);
        if ($61) {
         break;
        }
       } else {
        $57 = ($55|0)<(0);
        if ($57) {
         break;
        }
       }
       $63 = (($__i$029) + 24|0);
       $64 = ($63|0)==($1|0);
       if ($64) {
        label = 71;
        break L1;
       } else {
        $__i$029 = $63;
       }
      }
      ;HEAP32[$__t$i22+0>>2]=HEAP32[$__i$029+0>>2]|0;HEAP32[$__t$i22+4>>2]=HEAP32[$__i$029+4>>2]|0;HEAP32[$__t$i22+8>>2]=HEAP32[$__i$029+8>>2]|0;HEAP32[$__t$i22+12>>2]=HEAP32[$__i$029+12>>2]|0;HEAP32[$__t$i22+16>>2]=HEAP32[$__i$029+16>>2]|0;HEAP32[$__t$i22+20>>2]=HEAP32[$__i$029+20>>2]|0;
      ;HEAP32[$__i$029+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$029+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$029+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$029+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__i$029+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__i$029+20>>2]=HEAP32[$1+20>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i22+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i22+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i22+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i22+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i22+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i22+20>>2]|0;
      $62 = (($__i$029) + 24|0);
      $__i$1 = $62;
     }
     $65 = ($__i$1|0)==($1|0);
     if ($65) {
      label = 71;
      break L1;
     }
     $66 = (($$0) + 4|0);
     $__i$2$ph = $__i$1;$__j$1$ph = $1;
     while(1) {
      $67 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $68 = HEAP32[$__i$2>>2]|0;
       $69 = (_strcmp($67,$68)|0);
       $70 = ($69|0)==(0);
       if ($70) {
        $72 = HEAP32[$66>>2]|0;
        $73 = (($__i$2) + 4|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ($72|0)<($74|0);
        if ($75) {
         $__j$2 = $__j$1$ph;
         break;
        }
       } else {
        $71 = ($69|0)<(0);
        if ($71) {
         $__j$2 = $__j$1$ph;
         break;
        }
       }
       $76 = (($__i$2) + 24|0);
       $__i$2 = $76;
      }
      while(1) {
       $77 = (($__j$2) + -24|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = (_strcmp($67,$78)|0);
       $80 = ($79|0)==(0);
       if ($80) {
        $82 = HEAP32[$66>>2]|0;
        $83 = (($__j$2) + -20|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = ($82|0)<($84|0);
        if ($85) {
         $__j$2 = $77;
         continue;
        } else {
         break;
        }
       } else {
        $81 = ($79|0)<(0);
        if ($81) {
         $__j$2 = $77;
         continue;
        } else {
         break;
        }
       }
      }
      $86 = ($__i$2>>>0)<($77>>>0);
      if (!($86)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i22+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i22+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i22+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i22+12>>2]=HEAP32[$__i$2+12>>2]|0;HEAP32[$__t$i22+16>>2]=HEAP32[$__i$2+16>>2]|0;HEAP32[$__t$i22+20>>2]=HEAP32[$__i$2+20>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$77+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$77+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$77+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$77+12>>2]|0;HEAP32[$__i$2+16>>2]=HEAP32[$77+16>>2]|0;HEAP32[$__i$2+20>>2]=HEAP32[$77+20>>2]|0;
      ;HEAP32[$77+0>>2]=HEAP32[$__t$i22+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$__t$i22+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$__t$i22+8>>2]|0;HEAP32[$77+12>>2]=HEAP32[$__t$i22+12>>2]|0;HEAP32[$77+16>>2]=HEAP32[$__t$i22+16>>2]|0;HEAP32[$77+20>>2]=HEAP32[$__t$i22+20>>2]|0;
      $87 = (($__i$2) + 24|0);
      $__i$2$ph = $87;$__j$1$ph = $77;
     }
    }
   } while(0);
   $100 = (($$0) + 24|0);
   $101 = ($100>>>0)<($__j$3>>>0);
   L57: do {
    if ($101) {
     $__i$3$ph = $100;$__j$4$ph = $__j$3;$__m$0$ph = $25;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $102 = HEAP32[$__m$0$ph>>2]|0;
      $103 = (($__m$0$ph) + 4|0);
      $__i$3 = $__i$3$ph;
      while(1) {
       $104 = HEAP32[$__i$3>>2]|0;
       $105 = (_strcmp($104,$102)|0);
       $106 = ($105|0)==(0);
       if ($106) {
        $108 = (($__i$3) + 4|0);
        $109 = HEAP32[$108>>2]|0;
        $110 = HEAP32[$103>>2]|0;
        $111 = ($109|0)<($110|0);
        if (!($111)) {
         $__j$5 = $__j$4$ph;
         break;
        }
       } else {
        $107 = ($105|0)<(0);
        if (!($107)) {
         $__j$5 = $__j$4$ph;
         break;
        }
       }
       $112 = (($__i$3) + 24|0);
       $__i$3 = $112;
      }
      while(1) {
       $113 = (($__j$5) + -24|0);
       $114 = HEAP32[$113>>2]|0;
       $115 = (_strcmp($114,$102)|0);
       $116 = ($115|0)==(0);
       if ($116) {
        $118 = (($__j$5) + -20|0);
        $119 = HEAP32[$118>>2]|0;
        $120 = HEAP32[$103>>2]|0;
        $121 = ($119|0)<($120|0);
        if ($121) {
         break;
        } else {
         $__j$5 = $113;
         continue;
        }
       } else {
        $117 = ($115|0)<(0);
        if ($117) {
         break;
        } else {
         $__j$5 = $113;
         continue;
        }
       }
      }
      $122 = ($__i$3>>>0)>($113>>>0);
      if ($122) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L57;
      }
      ;HEAP32[$__t$i22+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i22+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i22+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i22+12>>2]=HEAP32[$__i$3+12>>2]|0;HEAP32[$__t$i22+16>>2]=HEAP32[$__i$3+16>>2]|0;HEAP32[$__t$i22+20>>2]=HEAP32[$__i$3+20>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$113+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$113+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$113+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$113+12>>2]|0;HEAP32[$__i$3+16>>2]=HEAP32[$113+16>>2]|0;HEAP32[$__i$3+20>>2]=HEAP32[$113+20>>2]|0;
      ;HEAP32[$113+0>>2]=HEAP32[$__t$i22+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[$__t$i22+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[$__t$i22+8>>2]|0;HEAP32[$113+12>>2]=HEAP32[$__t$i22+12>>2]|0;HEAP32[$113+16>>2]=HEAP32[$__t$i22+16>>2]|0;HEAP32[$113+20>>2]=HEAP32[$__t$i22+20>>2]|0;
      $123 = (($__n_swaps$4$ph) + 1)|0;
      $124 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $124 ? $113 : $__m$0$ph;
      $125 = (($__i$3) + 24|0);
      $__i$3$ph = $125;$__j$4$ph = $113;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $123;
     }
    } else {
     $__i$4 = $100;$__m$2 = $25;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $126 = ($__i$4|0)==($__m$2|0);
   do {
    if ($126) {
     $__n_swaps$6 = $__n_swaps$5;
    } else {
     $127 = HEAP32[$__m$2>>2]|0;
     $128 = HEAP32[$__i$4>>2]|0;
     $129 = (_strcmp($127,$128)|0);
     $130 = ($129|0)==(0);
     if ($130) {
      $132 = (($__m$2) + 4|0);
      $133 = HEAP32[$132>>2]|0;
      $134 = (($__i$4) + 4|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ($133|0)<($135|0);
      if (!($136)) {
       $__n_swaps$6 = $__n_swaps$5;
       break;
      }
     } else {
      $131 = ($129|0)<(0);
      if (!($131)) {
       $__n_swaps$6 = $__n_swaps$5;
       break;
      }
     }
     ;HEAP32[$__t$i22+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i22+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i22+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i22+12>>2]=HEAP32[$__i$4+12>>2]|0;HEAP32[$__t$i22+16>>2]=HEAP32[$__i$4+16>>2]|0;HEAP32[$__t$i22+20>>2]=HEAP32[$__i$4+20>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;HEAP32[$__i$4+16>>2]=HEAP32[$__m$2+16>>2]|0;HEAP32[$__i$4+20>>2]=HEAP32[$__m$2+20>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i22+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i22+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i22+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i22+12>>2]|0;HEAP32[$__m$2+16>>2]=HEAP32[$__t$i22+16>>2]|0;HEAP32[$__m$2+20>>2]=HEAP32[$__t$i22+20>>2]|0;
     $137 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $137;
    }
   } while(0);
   $138 = ($__n_swaps$6|0)==(0);
   if ($138) {
    $139 = (__ZNSt3__127__insertion_sort_incompleteIRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEbT0_S7_T_($$0,$__i$4,0)|0);
    $140 = (($__i$4) + 24|0);
    $141 = (__ZNSt3__127__insertion_sort_incompleteIRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEbT0_S7_T_($140,$$01$ph,0)|0);
    if ($141) {
     label = 66;
     break;
    }
    if ($139) {
     $$0 = $140;
     continue;
    }
   }
   $142 = $__i$4;
   $143 = (($142) - ($4))|0;
   $144 = (($0) - ($142))|0;
   $145 = ($143|0)<($144|0);
   if (!($145)) {
    label = 70;
    break;
   }
   __ZNSt3__16__sortIRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEvT0_S7_T_($$0,$__i$4,$__comp);
   $146 = (($__i$4) + 24|0);
   $$0 = $146;
  }
  if ((label|0) == 66) {
   label = 0;
   if ($139) {
    label = 71;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 70) {
   label = 0;
   $147 = (($__i$4) + 24|0);
   __ZNSt3__16__sortIRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEvT0_S7_T_($147,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $7 = HEAP32[$1>>2]|0;
  $8 = HEAP32[$$0>>2]|0;
  $9 = (_strcmp($7,$8)|0);
  $10 = ($9|0)==(0);
  if ($10) {
   $12 = HEAP32[$3>>2]|0;
   $13 = (($$0) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12|0)<($14|0);
   if (!($15)) {
    STACKTOP = sp;return;
   }
  } else {
   $11 = ($9|0)<(0);
   if (!($11)) {
    STACKTOP = sp;return;
   }
  }
  ;HEAP32[$__t$i22+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i22+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i22+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i22+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i22+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i22+20>>2]=HEAP32[$$0+20>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$1+20>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i22+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i22+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i22+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i22+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i22+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i22+20>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $16 = (($$0) + 24|0);
  (__ZNSt3__17__sort3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_T_($$0,$16,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 9) {
  $17 = (($$0) + 24|0);
  $18 = (($$0) + 48|0);
  (__ZNSt3__17__sort4IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_S7_T_($$0,$17,$18,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  $19 = (($$0) + 24|0);
  $20 = (($$0) + 48|0);
  $21 = (($$0) + 72|0);
  (__ZNSt3__17__sort5IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_S7_S7_T_($$0,$19,$20,$21,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  __ZNSt3__118__insertion_sort_3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEvT0_S7_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 71) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__t$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i10 = sp;
 $0 = HEAP32[$__y>>2]|0;
 $1 = HEAP32[$__x>>2]|0;
 $2 = (_strcmp($0,$1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $5 = (($__y) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($__x) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)<($8|0);
  $$0$i$i = $9;
 } else {
  $4 = ($2|0)<(0);
  $$0$i$i = $4;
 }
 $10 = HEAP32[$__z>>2]|0;
 $11 = (_strcmp($10,$0)|0);
 $12 = ($11|0)==(0);
 if ($12) {
  $14 = (($__z) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($__y) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($15|0)<($17|0);
  $$0$i$i1 = $18;
 } else {
  $13 = ($11|0)<(0);
  $$0$i$i1 = $13;
 }
 if (!($$0$i$i)) {
  if (!($$0$i$i1)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i10+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__y+20>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__z+20>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i10+20>>2]|0;
  $19 = HEAP32[$__y>>2]|0;
  $20 = HEAP32[$__x>>2]|0;
  $21 = (_strcmp($19,$20)|0);
  $22 = ($21|0)==(0);
  if ($22) {
   $24 = (($__y) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($__x) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($25|0)<($27|0);
   if (!($28)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $23 = ($21|0)<(0);
   if (!($23)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  ;HEAP32[$__t$i10+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__x+20>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__y+20>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__t$i10+20>>2]|0;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($$0$i$i1) {
  ;HEAP32[$__t$i10+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__x+20>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__z+20>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i10+20>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$__t$i10+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__x+20>>2]|0;
 ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__y+20>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__t$i10+20>>2]|0;
 $29 = HEAP32[$__z>>2]|0;
 $30 = HEAP32[$__y>>2]|0;
 $31 = (_strcmp($29,$30)|0);
 $32 = ($31|0)==(0);
 if ($32) {
  $34 = (($__z) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($__y) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($35|0)<($37|0);
  if (!($38)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $33 = ($31|0)<(0);
  if (!($33)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 ;HEAP32[$__t$i10+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i10+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i10+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i10+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i10+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__t$i10+20>>2]=HEAP32[$__y+20>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__z+20>>2]|0;
 ;HEAP32[$__z+0>>2]=HEAP32[$__t$i10+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i10+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i10+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i10+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i10+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i10+20>>2]|0;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i6 = sp;
 $0 = (__ZNSt3__17__sort3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_T_($__x1,$__x2,$__x3,0)|0);
 $1 = HEAP32[$__x4>>2]|0;
 $2 = HEAP32[$__x3>>2]|0;
 $3 = (_strcmp($1,$2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $6 = (($__x4) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($__x3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)<($9|0);
  if (!($10)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $5 = ($3|0)<(0);
  if (!($5)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__x3+20>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i6+20>>2]|0;
 $11 = (($0) + 1)|0;
 $12 = HEAP32[$__x3>>2]|0;
 $13 = HEAP32[$__x2>>2]|0;
 $14 = (_strcmp($12,$13)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  $17 = (($__x3) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($__x2) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($18|0)<($20|0);
  if (!($21)) {
   $__r$0 = $11;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $16 = ($14|0)<(0);
  if (!($16)) {
   $__r$0 = $11;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__x2+20>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i6+20>>2]|0;
 $22 = (($0) + 2)|0;
 $23 = HEAP32[$__x2>>2]|0;
 $24 = HEAP32[$__x1>>2]|0;
 $25 = (_strcmp($23,$24)|0);
 $26 = ($25|0)==(0);
 if ($26) {
  $28 = (($__x2) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($__x1) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($29|0)<($31|0);
  if (!($32)) {
   $__r$0 = $22;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $27 = ($25|0)<(0);
  if (!($27)) {
   $__r$0 = $22;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__x1+20>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i6+20>>2]|0;
 $33 = (($0) + 3)|0;
 $__r$0 = $33;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i7 = sp;
 $0 = (__ZNSt3__17__sort4IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = HEAP32[$__x5>>2]|0;
 $2 = HEAP32[$__x4>>2]|0;
 $3 = (_strcmp($1,$2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $6 = (($__x5) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($__x4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)<($9|0);
  if (!($10)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $5 = ($3|0)<(0);
  if (!($5)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i7+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__t$i7+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__t$i7+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__t$i7+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__t$i7+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__t$i7+20>>2]=HEAP32[$__x4+20>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__x5+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__x5+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__x5+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__x5+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__x5+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__x5+20>>2]|0;
 ;HEAP32[$__x5+0>>2]=HEAP32[$__t$i7+0>>2]|0;HEAP32[$__x5+4>>2]=HEAP32[$__t$i7+4>>2]|0;HEAP32[$__x5+8>>2]=HEAP32[$__t$i7+8>>2]|0;HEAP32[$__x5+12>>2]=HEAP32[$__t$i7+12>>2]|0;HEAP32[$__x5+16>>2]=HEAP32[$__t$i7+16>>2]|0;HEAP32[$__x5+20>>2]=HEAP32[$__t$i7+20>>2]|0;
 $11 = (($0) + 1)|0;
 $12 = HEAP32[$__x4>>2]|0;
 $13 = HEAP32[$__x3>>2]|0;
 $14 = (_strcmp($12,$13)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  $17 = (($__x4) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($__x3) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($18|0)<($20|0);
  if (!($21)) {
   $__r$0 = $11;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $16 = ($14|0)<(0);
  if (!($16)) {
   $__r$0 = $11;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i7+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i7+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i7+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i7+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i7+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i7+20>>2]=HEAP32[$__x3+20>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i7+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i7+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i7+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i7+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i7+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i7+20>>2]|0;
 $22 = (($0) + 2)|0;
 $23 = HEAP32[$__x3>>2]|0;
 $24 = HEAP32[$__x2>>2]|0;
 $25 = (_strcmp($23,$24)|0);
 $26 = ($25|0)==(0);
 if ($26) {
  $28 = (($__x3) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($__x2) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($29|0)<($31|0);
  if (!($32)) {
   $__r$0 = $22;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $27 = ($25|0)<(0);
  if (!($27)) {
   $__r$0 = $22;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i7+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i7+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i7+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i7+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i7+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i7+20>>2]=HEAP32[$__x2+20>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i7+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i7+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i7+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i7+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i7+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i7+20>>2]|0;
 $33 = (($0) + 3)|0;
 $34 = HEAP32[$__x2>>2]|0;
 $35 = HEAP32[$__x1>>2]|0;
 $36 = (_strcmp($34,$35)|0);
 $37 = ($36|0)==(0);
 if ($37) {
  $39 = (($__x2) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($__x1) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($40|0)<($42|0);
  if (!($43)) {
   $__r$0 = $33;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $38 = ($36|0)<(0);
  if (!($38)) {
   $__r$0 = $33;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 ;HEAP32[$__t$i7+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i7+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i7+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i7+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i7+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i7+20>>2]=HEAP32[$__x1+20>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i7+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i7+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i7+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i7+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i7+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i7+20>>2]|0;
 $44 = (($0) + 4)|0;
 $__r$0 = $44;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$05 = 0, $__j$04 = 0, $__j$04$phi = 0, $__k$0$lcssa = 0, $__k$03 = 0, $__t$sroa$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$sroa$2 = sp;
 $0 = (($__first) + 48|0);
 $1 = (($__first) + 24|0);
 (__ZNSt3__17__sort3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 72|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $__i$05 = $2;$__j$04 = $0;
 while(1) {
  $4 = HEAP32[$__i$05>>2]|0;
  $5 = HEAP32[$__j$04>>2]|0;
  $6 = (_strcmp($4,$5)|0);
  $7 = ($6|0)==(0);
  if ($7) {
   $9 = (($__i$05) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($__j$04) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($10|0)<($12|0);
   if ($13) {
    $24 = $10;
    label = 7;
   }
  } else {
   $8 = ($6|0)<(0);
   if ($8) {
    $$phi$trans$insert = (($__i$05) + 4|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $24 = $$pre;
    label = 7;
   }
  }
  if ((label|0) == 7) {
   label = 0;
   $14 = (($__i$05) + 8|0);
   ;HEAP32[$__t$sroa$2+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$__t$sroa$2+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$__t$sroa$2+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$__t$sroa$2+12>>2]=HEAP32[$14+12>>2]|0;
   ;HEAP32[$__i$05+0>>2]=HEAP32[$__j$04+0>>2]|0;HEAP32[$__i$05+4>>2]=HEAP32[$__j$04+4>>2]|0;HEAP32[$__i$05+8>>2]=HEAP32[$__j$04+8>>2]|0;HEAP32[$__i$05+12>>2]=HEAP32[$__j$04+12>>2]|0;HEAP32[$__i$05+16>>2]=HEAP32[$__j$04+16>>2]|0;HEAP32[$__i$05+20>>2]=HEAP32[$__j$04+20>>2]|0;
   $15 = ($__j$04|0)==($__first|0);
   L12: do {
    if ($15) {
     $__k$0$lcssa = $__first;
    } else {
     $__k$03 = $__j$04;
     while(1) {
      $16 = (($__k$03) + -24|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (_strcmp($4,$17)|0);
      $19 = ($18|0)==(0);
      if ($19) {
       $21 = (($__k$03) + -20|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($24|0)<($22|0);
       if (!($23)) {
        $__k$0$lcssa = $__k$03;
        break L12;
       }
      } else {
       $20 = ($18|0)<(0);
       if (!($20)) {
        $__k$0$lcssa = $__k$03;
        break L12;
       }
      }
      ;HEAP32[$__k$03+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$__k$03+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$__k$03+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$__k$03+12>>2]=HEAP32[$16+12>>2]|0;HEAP32[$__k$03+16>>2]=HEAP32[$16+16>>2]|0;HEAP32[$__k$03+20>>2]=HEAP32[$16+20>>2]|0;
      $25 = ($16|0)==($__first|0);
      if ($25) {
       $__k$0$lcssa = $__first;
       break;
      } else {
       $__k$03 = $16;
      }
     }
    }
   } while(0);
   HEAP32[$__k$0$lcssa>>2] = $4;
   $26 = (($__k$0$lcssa) + 4|0);
   HEAP32[$26>>2] = $24;
   $27 = (($__k$0$lcssa) + 8|0);
   ;HEAP32[$27+0>>2]=HEAP32[$__t$sroa$2+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__t$sroa$2+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__t$sroa$2+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$__t$sroa$2+12>>2]|0;
  }
  $28 = (($__i$05) + 24|0);
  $29 = ($28|0)==($__last|0);
  if ($29) {
   break;
  } else {
   $__j$04$phi = $__i$05;$__i$05 = $28;$__j$04 = $__j$04$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__count$08 = 0, $__count$1 = 0, $__i$09 = 0, $__j$07 = 0, $__j$07$phi = 0, $__k$0$lcssa = 0, $__k$05 = 0, $__t$i = 0, $__t$sroa$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i = sp + 16|0;
 $__t$sroa$2 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 24)&-1;
 switch ($3|0) {
 case 2:  {
  $4 = (($__last) + -24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = (_strcmp($5,$6)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $10 = (($__last) + -20|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($__first) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11|0)<($13|0);
   if (!($14)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $9 = ($7|0)<(0);
   if (!($9)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  ;HEAP32[$__t$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i+20>>2]=HEAP32[$__first+20>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$4+20>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$__t$i+16>>2]|0;HEAP32[$4+20>>2]=HEAP32[$__t$i+20>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $20 = (($__first) + 24|0);
  $21 = (($__first) + 48|0);
  $22 = (($__first) + 72|0);
  $23 = (($__last) + -24|0);
  (__ZNSt3__17__sort5IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_S7_S7_T_($__first,$20,$21,$22,$23,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $15 = (($__first) + 24|0);
  $16 = (($__last) + -24|0);
  (__ZNSt3__17__sort3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_T_($__first,$15,$16,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $17 = (($__first) + 24|0);
  $18 = (($__first) + 48|0);
  $19 = (($__last) + -24|0);
  (__ZNSt3__17__sort4IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_S7_T_($__first,$17,$18,$19,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $24 = (($__first) + 48|0);
  $25 = (($__first) + 24|0);
  (__ZNSt3__17__sort3IRNS_4lessIN22BuiltinResourceManager8ResourceEEEPS3_EEjT0_S7_S7_T_($__first,$25,$24,0)|0);
  $26 = (($__first) + 72|0);
  $27 = ($26|0)==($__last|0);
  if ($27) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$08 = 0;$__i$09 = $26;$__j$07 = $24;
  while(1) {
   $28 = HEAP32[$__i$09>>2]|0;
   $29 = HEAP32[$__j$07>>2]|0;
   $30 = (_strcmp($28,$29)|0);
   $31 = ($30|0)==(0);
   if ($31) {
    $33 = (($__i$09) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($__j$07) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($34|0)<($36|0);
    if ($37) {
     $48 = $34;
     label = 15;
    } else {
     $__count$1 = $__count$08;
    }
   } else {
    $32 = ($30|0)<(0);
    if ($32) {
     $$phi$trans$insert = (($__i$09) + 4|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $48 = $$pre;
     label = 15;
    } else {
     $__count$1 = $__count$08;
    }
   }
   if ((label|0) == 15) {
    label = 0;
    $38 = (($__i$09) + 8|0);
    ;HEAP32[$__t$sroa$2+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$__t$sroa$2+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$__t$sroa$2+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$__t$sroa$2+12>>2]=HEAP32[$38+12>>2]|0;
    ;HEAP32[$__i$09+0>>2]=HEAP32[$__j$07+0>>2]|0;HEAP32[$__i$09+4>>2]=HEAP32[$__j$07+4>>2]|0;HEAP32[$__i$09+8>>2]=HEAP32[$__j$07+8>>2]|0;HEAP32[$__i$09+12>>2]=HEAP32[$__j$07+12>>2]|0;HEAP32[$__i$09+16>>2]=HEAP32[$__j$07+16>>2]|0;HEAP32[$__i$09+20>>2]=HEAP32[$__j$07+20>>2]|0;
    $39 = ($__j$07|0)==($__first|0);
    L14: do {
     if ($39) {
      $__k$0$lcssa = $__first;
     } else {
      $__k$05 = $__j$07;
      while(1) {
       $40 = (($__k$05) + -24|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = (_strcmp($28,$41)|0);
       $43 = ($42|0)==(0);
       if ($43) {
        $45 = (($__k$05) + -20|0);
        $46 = HEAP32[$45>>2]|0;
        $47 = ($48|0)<($46|0);
        if (!($47)) {
         $__k$0$lcssa = $__k$05;
         break L14;
        }
       } else {
        $44 = ($42|0)<(0);
        if (!($44)) {
         $__k$0$lcssa = $__k$05;
         break L14;
        }
       }
       ;HEAP32[$__k$05+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__k$05+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__k$05+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__k$05+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$__k$05+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$__k$05+20>>2]=HEAP32[$40+20>>2]|0;
       $49 = ($40|0)==($__first|0);
       if ($49) {
        $__k$0$lcssa = $__first;
        break;
       } else {
        $__k$05 = $40;
       }
      }
     }
    } while(0);
    HEAP32[$__k$0$lcssa>>2] = $28;
    $50 = (($__k$0$lcssa) + 4|0);
    HEAP32[$50>>2] = $48;
    $51 = (($__k$0$lcssa) + 8|0);
    ;HEAP32[$51+0>>2]=HEAP32[$__t$sroa$2+0>>2]|0;HEAP32[$51+4>>2]=HEAP32[$__t$sroa$2+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$__t$sroa$2+8>>2]|0;HEAP32[$51+12>>2]=HEAP32[$__t$sroa$2+12>>2]|0;
    $52 = (($__count$08) + 1)|0;
    $53 = ($52|0)==(8);
    if ($53) {
     break;
    } else {
     $__count$1 = $52;
    }
   }
   $56 = (($__i$09) + 24|0);
   $57 = ($56|0)==($__last|0);
   if ($57) {
    $$0 = 1;
    label = 23;
    break;
   } else {
    $__j$07$phi = $__i$09;$__count$08 = $__count$1;$__i$09 = $56;$__j$07 = $__j$07$phi;
   }
  }
  if ((label|0) == 23) {
   STACKTOP = sp;return ($$0|0);
  }
  $54 = (($__i$09) + 24|0);
  $55 = ($54|0)==($__last|0);
  $$0 = $55;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN15ResourceManagerD2Ev($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$i$indexZ2D = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((627408 + 8|0));
 $0 = (($this) + 36|0);
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ObjectEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$2);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if ($8) {
   $22 = $4;
  } else {
   $10 = $7;
   while(1) {
    $9 = (($10) + -16|0);
    HEAP32[$6>>2] = $9;
    $11 = (($10) + -12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $15 = $9;
    } else {
     $16 = (($10) + -8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==($12|0);
     if (!($18)) {
      $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $12;
      $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($17) + -4|0);
      $19 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($19)|0);
      $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      $20 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 2;
      $21 = $20 ^ -1;
      $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($17) + ($21<<2)|0);
      HEAP32[$16>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
     }
     __ZdlPv($12);
     $$pre$i$i$i$i$i = HEAP32[$6>>2]|0;
     $15 = $$pre$i$i$i$i$i;
    }
    $14 = ($15|0)==($4|0);
    if ($14) {
     break;
    } else {
     $10 = $15;
    }
   }
   $$pre$i$i$i = HEAP32[$3>>2]|0;
   $22 = $$pre$i$i$i;
  }
  __ZdlPv($22);
 }
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if (!($24)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   STACKTOP = sp;return;
  }
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  __THREW__ = 0;
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   $31 = ___cxa_find_matching_catch(0|0)|0;
   $32 = tempRet0;
   ___clang_call_terminate($31);
   // unreachable;
  } else {
   ___resumeException($27|0);
   // unreachable;
  }
 }
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $39 = ___cxa_find_matching_catch(0|0)|0;
  $40 = tempRet0;
  __THREW__ = 0;
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if ($42) {
   $43 = ___cxa_find_matching_catch(0|0)|0;
   $44 = tempRet0;
   ___clang_call_terminate($43);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $39;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if (!($38)) {
  ___resumeException($33|0);
  // unreachable;
 }
 $45 = ___cxa_find_matching_catch(0|0)|0;
 $46 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $45;
 ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
 // unreachable;
}
function __Z23CollectSceneGameObjectsR13dynamic_arrayIiLj4EE($outputObjects) {
 $outputObjects = $outputObjects|0;
 var $$byval_copy6 = 0, $$lcssa = 0, $$pre = 0, $$pre$i$i = 0, $$pre15 = 0, $$pre15$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i3 = 0, $gameObjects = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $gameObjects = sp + 8|0;
 HEAP32[$gameObjects>>2] = 0;
 $2 = (($gameObjects) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($gameObjects) + 8|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,1,($gameObjects|0),0)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   $lpad$phi$index = $20;$lpad$phi$index2 = $21;
  } else {
   $6 = HEAP32[$gameObjects>>2]|0;
   $7 = HEAP32[$2>>2]|0;
   $8 = ($6|0)==($7|0);
   do {
    if ($8) {
     $$lcssa = $6;$63 = $6;
    } else {
     $9 = (($outputObjects) + 8|0);
     $10 = (($outputObjects) + 12|0);
     $11 = (($outputObjects) + 4|0);
     $13 = $6;$68 = $7;
     L6: while(1) {
      $12 = HEAP32[$13>>2]|0;
      $14 = (($12) + 8|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = $15 & 1114112;
      $17 = ($16|0)==(0);
      if ($17) {
       $29 = (($12) + 4|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = HEAP32[$9>>2]|0;
       $32 = (($31) + 1)|0;
       HEAP32[$9>>2] = $32;
       $33 = HEAP32[$10>>2]|0;
       $34 = $33 & 2147483647;
       $35 = ($32>>>0)>($34>>>0);
       if ($35) {
        $36 = $33 << 1;
        $37 = ($36|0)==(0);
        $38 = $37 ? 1 : $36;
        $39 = ($34>>>0)<($38>>>0);
        do {
         if ($39) {
          $40 = ($33|0)>(-1);
          if ($40) {
           HEAP32[$10>>2] = $38;
           $41 = HEAP32[$outputObjects>>2]|0;
           $42 = $38 << 2;
           $43 = HEAP32[$11>>2]|0;
           HEAP32[$0>>2] = $43;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
           $44 = (invoke_iiiiiiii(108,($41|0),($42|0),4,($$byval_copy6|0),0,(627888|0),370)|0);
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            label = 5;
            break L6;
           }
           HEAP32[$outputObjects>>2] = $44;
           break;
          } else {
           $47 = $38 << 2;
           $48 = HEAP32[$11>>2]|0;
           HEAP32[$1>>2] = $48;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
           $49 = (invoke_iiiiiii(102,($47|0),4,($$byval_copy6|0),0,(627888|0),352)|0);
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           if ($51) {
            label = 5;
            break L6;
           }
           $52 = HEAP32[$outputObjects>>2]|0;
           $53 = HEAP32[$9>>2]|0;
           $54 = $53 << 2;
           _memcpy(($49|0),($52|0),($54|0))|0;
           HEAP32[$10>>2] = $38;
           HEAP32[$outputObjects>>2] = $49;
           break;
          }
         }
        } while(0);
        $$pre$i$i = HEAP32[$9>>2]|0;
        $$pre15$pre = HEAP32[$2>>2]|0;
        $$pre15 = $$pre15$pre;$56 = $$pre$i$i;
       } else {
        $$pre15 = $68;$56 = $32;
       }
       $55 = (($56) + -1)|0;
       $57 = HEAP32[$outputObjects>>2]|0;
       $58 = (($57) + ($55<<2)|0);
       HEAP32[$58>>2] = $30;
       $61 = $$pre15;
      } else {
       $61 = $68;
      }
      $59 = (($13) + 4|0);
      $60 = ($59|0)==($61|0);
      if ($60) {
       label = 21;
       break;
      } else {
       $13 = $59;$68 = $61;
      }
     }
     if ((label|0) == 5) {
      $18 = ___cxa_find_matching_catch()|0;
      $19 = tempRet0;
      $lpad$phi$index = $18;$lpad$phi$index2 = $19;
      break L1;
     }
     else if ((label|0) == 21) {
      $$pre = HEAP32[$gameObjects>>2]|0;
      $$lcssa = $61;$63 = $$pre;
      break;
     }
    }
   } while(0);
   $62 = ($63|0)==(0|0);
   if ($62) {
    STACKTOP = sp;return;
   }
   $64 = ($$lcssa|0)==($63|0);
   if (!($64)) {
    $__new_last2$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i = (($$lcssa) + -4|0);
    $65 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($65)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $66 = $uglygep3$i$i$i$i$i >>> 2;
    $67 = $66 ^ -1;
    $scevgep4$i$i$i$i$i = (($$lcssa) + ($67<<2)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($63);
   STACKTOP = sp;return;
  }
 } while(0);
 $22 = HEAP32[$gameObjects>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $24 = HEAP32[$2>>2]|0;
 $25 = ($24|0)==($22|0);
 if (!($25)) {
  $__new_last2$i$i$i$i$i3 = $22;
  $scevgep$i$i$i$i$i4 = (($24) + -4|0);
  $26 = (0 - ($__new_last2$i$i$i$i$i3))|0;
  $uglygep$i$i$i$i$i6 = (($scevgep$i$i$i$i$i4) + ($26)|0);
  $uglygep3$i$i$i$i$i7 = $uglygep$i$i$i$i$i6;
  $27 = $uglygep3$i$i$i$i$i7 >>> 2;
  $28 = $27 ^ -1;
  $scevgep4$i$i$i$i$i8 = (($24) + ($28<<2)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i8;
 }
 __ZdlPv($22);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z26InitializeEngineNoGraphicsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __Z18RegisterAllClassesv();
 __ZN6Object20InitializeAllClassesEv();
 __Z26InitializeAsyncReadManagerv();
 __ZN5Unity10GameObject28InitializeMessageIdentifiersEv();
 __Z31ManagerContextInitializeClassesv();
 __ZN19RenderBufferManager23InitRenderBufferManagerEv();
 $0 = (__ZN13ModuleManager3GetEv()|0);
 __ZN13ModuleManager4LoadEv($0);
 __ZN13CallbackArray6InvokeEv($0);
 __Z17InitScreenManagerv();
 __Z14InitGUIManagerv();
 __ZN6Object19CallInitializeClassEv();
 STACKTOP = sp;return 1;
}
function __Z24InitializeEngineGraphicsb($batch) {
 $batch = $batch|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP8[627712>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = 627752;
 _printf_console(627720,$vararg_buffer);
 $2 = (__Z19InitializeGfxDevicev()|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __Z14CreateJobQueuev();
 __ZN9ShaderLab13InitShaderLabEv();
 __ZN6Object23CallPostInitializeClassEv();
 __ZN5Unity10GameObject25InitializeMessageHandlersEv();
 __ZN22BuiltinResourceManager22InitializeAllResourcesEv();
 __ZN6Shader18LoadDefaultShadersEv();
 $3 = (__Z22GetGraphicsSettingsPtrv()|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (__Z19GetGraphicsSettingsv()|0);
  __ZN16GraphicsSettings22WarmupPreloadedShadersEv($5);
 }
 HEAP8[627712>>0] = 1;
 $6 = (__ZN15GlobalCallbacks3GetEv()|0);
 $7 = (($6) + 512|0);
 __ZN13CallbackArray6InvokeEv($7);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z16CleanupAfterLoadv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN15GlobalCallbacks3GetEv()|0);
 $1 = (($0) + 320|0);
 __ZN13CallbackArray6InvokeEv($1);
 $2 = (__Z22GetRenderBufferManagerv()|0);
 __ZN19RenderBufferManager14GarbageCollectEi($2,0);
 $3 = (__Z12GetGfxDevicev()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vi[$6 & 4095]($3);
 __ZN13RenderManager18UpdateAllRenderersEv();
 $7 = (__Z22GetGameManagerIfExistsi(9)|0);
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($7,0);
 }
 $12 = (__Z21GetDelayedCallManagerv()|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 100|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($12,16);
 $16 = (__Z18GetQualitySettingsv()|0);
 __ZN15QualitySettings13ApplySettingsEib($16,-1,0);
 STACKTOP = sp;return;
}
function __Z28PatchRendererLightmapIndicesR18AwakeFromLoadQueue($awakeQueue) {
 $awakeQueue = $awakeQueue|0;
 var $$off$i = 0, $$off$i1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $i$04 = 0, $pos$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (__Z19GetLightmapSettingsv()|0);
 $2 = (($1) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($awakeQueue) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($awakeQueue) + 64|0);
 $i$04 = 0;
 while(1) {
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9) + (($i$04*12)|0)|0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = $11;
  $12 = HEAP32[560624>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   $14 = (($12) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($12) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($15|0)==($17|0);
   do {
    if ($18) {
     $19 = (($12) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($12) + 32|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + ($22<<3)|0);
     $39 = $23;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$12,$0);
     $24 = HEAP32[$pos$i$i$i>>2]|0;
     $25 = ($24|0)==(-1);
     $26 = (($12) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     if ($25) {
      $28 = (($12) + 32|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($27) + ($29<<3)|0);
      $39 = $30;
      break;
     } else {
      $31 = (($27) + ($24<<3)|0);
      $39 = $31;
      break;
     }
    }
   } while(0);
   $32 = HEAP32[560624>>2]|0;
   $33 = (($32) + 28|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + 32|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + ($36<<3)|0);
   $38 = ($39|0)==($37|0);
   if (!($38)) {
    $40 = (($39) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $43 = (($41) + 8|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = $44 >>> 21;
     $46 = HEAP32[560640>>2]|0;
     $47 = Math_imul($46, $45)|0;
     $48 = (($47) + 25)|0;
     $49 = $48 >> 5;
     $50 = $49 << 5;
     $51 = (($48) - ($50))|0;
     $52 = HEAP32[560632>>2]|0;
     $53 = (($52) + ($49<<2)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = 1 << $51;
     $56 = $55 & $54;
     $57 = ($56|0)==(0);
     if (!($57)) {
      $58 = (($41) + 28|0);
      $59 = (($58) + 36|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = $60&65535;
      $$off$i1 = (($61) + -254)<<16>>16;
      $62 = ($$off$i1&65535)>(1);
      if ($62) {
       $63 = (__ZNK12BaseRenderer19GetLightmapIndexIntE12LightmapType($58,0)|0);
       $64 = (($63) + ($3))|0;
       __ZN8Renderer19SetLightmapIndexIntEi12LightmapType($41,$64,0);
       $$pre = HEAP32[$59>>2]|0;
       $66 = $$pre;
      } else {
       $66 = $60;
      }
      $65 = $66 >>> 16;
      $67 = $65&65535;
      $$off$i = (($67) + -254)<<16>>16;
      $68 = ($$off$i&65535)>(1);
      if ($68) {
       $69 = (__ZNK12BaseRenderer19GetLightmapIndexIntE12LightmapType($58,0)|0);
       $70 = (($69) + ($3))|0;
       __ZN8Renderer19SetLightmapIndexIntEi12LightmapType($41,$70,1);
      }
     }
    }
   }
  }
  $71 = (($i$04) + 1)|0;
  $72 = HEAP32[$5>>2]|0;
  $73 = ($71>>>0)<($72>>>0);
  if ($73) {
   $i$04 = $71;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z17MergeLightmapDataR18AwakeFromLoadQueue($awakeQueue) {
 $awakeQueue = $awakeQueue|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 12|0;
 $1 = (__ZN18AwakeFromLoadQueue19GetManagerFromQueueI16LightmapSettingsEEPT_v($awakeQueue)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 68|0);
 $4 = (($1) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (__Z19GetLightmapSettingsv()|0);
  $8 = (__ZNK16LightmapSettings22GetLightmapsModeLegacyEv($7)|0);
  $9 = (__ZNK16LightmapSettings22GetLightmapsModeLegacyEv($1)|0);
  $10 = ($9|0)==($8|0);
  do {
   if (!($10)) {
    $11 = (602648 + ($8<<2)|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (602648 + ($9<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$vararg_buffer>>2] = $12;
    $vararg_ptr1 = (($vararg_buffer) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $14;
    $vararg_ptr2 = (($vararg_buffer) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $12;
    __Z6FormatPKcz($0,627776,$vararg_buffer);
    $15 = HEAP8[$0>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     $20 = (($0) + 1|0);
     $21 = $20;
    } else {
     $18 = (($0) + 8|0);
     $19 = HEAP32[$18>>2]|0;
     $21 = $19;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($21|0),0,(627888|0),613,512,0,0,(0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP8[$0>>0]|0;
     $25 = $24 & 1;
     $26 = ($25<<24>>24)==(0);
     if ($26) {
      break;
     }
     $27 = (($0) + 8|0);
     $28 = HEAP32[$27>>2]|0;
     __ZdlPv($28);
     break;
    }
    $29 = ___cxa_find_matching_catch()|0;
    $30 = tempRet0;
    $31 = HEAP8[$0>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if ($33) {
     ___resumeException($29|0);
     // unreachable;
    }
    $34 = (($0) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    __ZdlPv($35);
    ___resumeException($29|0);
    // unreachable;
   }
  } while(0);
  __Z28PatchRendererLightmapIndicesR18AwakeFromLoadQueue($awakeQueue);
  $36 = (__Z19GetLightmapSettingsv()|0);
  __ZN16LightmapSettings15AppendLightmapsERK13dynamic_arrayI12LightmapDataLj4EE($36,$3);
 }
 __Z22DestroyObjectHighLevelP6Objectb($1,0);
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue19GetManagerFromQueueI16LightmapSettingsEEPT_v($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$03 = 0, $or$cond = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $i$03 = 0;
 L4: while(1) {
  $4 = HEAP32[$this>>2]|0;
  $5 = ((($4) + (($i$03*12)|0)|0) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  do {
   if (!($7)) {
    HEAP32[$0>>2] = $6;
    $8 = HEAP32[560624>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     label = 12;
    } else {
     $10 = (($8) + 36|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($8) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($11|0)==($13|0);
     do {
      if ($14) {
       $15 = (($8) + 28|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = (($8) + 32|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = (($16) + ($18<<3)|0);
       $35 = $19;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$8,$0);
       $20 = HEAP32[$pos$i$i$i$i>>2]|0;
       $21 = ($20|0)==(-1);
       $22 = (($8) + 28|0);
       $23 = HEAP32[$22>>2]|0;
       if ($21) {
        $24 = (($8) + 32|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = (($23) + ($25<<3)|0);
        $35 = $26;
        break;
       } else {
        $27 = (($23) + ($20<<3)|0);
        $35 = $27;
        break;
       }
      }
     } while(0);
     $28 = HEAP32[560624>>2]|0;
     $29 = (($28) + 28|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + 32|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($30) + ($32<<3)|0);
     $34 = ($35|0)==($33|0);
     if ($34) {
      label = 12;
     } else {
      $36 = (($35) + 4|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = ($37|0)==(0|0);
      if ($38) {
       label = 12;
      } else {
       $$0$i2 = $37;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $39 = (__Z31ReadObjectFromPersistentManageri($6)|0);
     $40 = ($39|0)==(0|0);
     if ($40) {
      break;
     } else {
      $$0$i2 = $39;
     }
    }
    $41 = (($$0$i2) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42 >>> 21;
    $44 = HEAP32[560640>>2]|0;
    $45 = Math_imul($44, $43)|0;
    $46 = (($45) + 157)|0;
    $47 = $46 >> 5;
    $48 = $47 << 5;
    $49 = (($46) - ($48))|0;
    $50 = HEAP32[560632>>2]|0;
    $51 = (($50) + ($47<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = 1 << $49;
    $54 = $53 & $52;
    $55 = ($54|0)==(0);
    $56 = ($$0$i2|0)==(0|0);
    $or$cond = $55 | $56;
    if (!($or$cond)) {
     break L4;
    }
   }
  } while(0);
  $57 = (($i$03) + 1)|0;
  $58 = HEAP32[$1>>2]|0;
  $59 = ($57>>>0)<($58>>>0);
  if ($59) {
   $i$03 = $57;
  } else {
   $$0 = 0;
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 $$0 = $$0$i2;
 STACKTOP = sp;return ($$0|0);
}
function __Z21PostLoadLevelAdditiveRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER18AwakeFromLoadQueueN18LoadLevelOperation11LoadingModeE($pathName,$awakeQueue,$loadOperationMode) {
 $pathName = $pathName|0;
 $awakeQueue = $awakeQueue|0;
 $loadOperationMode = $loadOperationMode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $exitcond$i2$i = 0, $i$01$i$i = 0, $i$01$i1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18AwakeFromLoadQueue25RegisterObjectInstanceIDsEv($awakeQueue);
 $0 = (__ZN15GlobalCallbacks3GetEv()|0);
 $i$01$i$i = 0;
 while(1) {
  $1 = ((($0) + ($i$01$i$i<<2)|0) + 192|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   FUNCTION_TABLE_viii[$2 & 4095]($pathName,$awakeQueue,$loadOperationMode);
  }
  $4 = (($i$01$i$i) + 1)|0;
  $exitcond$i$i = ($4|0)==(16);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$01$i$i = $4;
  }
 }
 __ZN18AwakeFromLoadQueue30PersistentManagerAwakeFromLoadEv($awakeQueue);
 $5 = (__ZN15GlobalCallbacks3GetEv()|0);
 $i$01$i1$i = 0;
 while(1) {
  $6 = ((($5) + ($i$01$i1$i<<2)|0) + 256|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   FUNCTION_TABLE_viii[$7 & 4095]($pathName,$awakeQueue,$loadOperationMode);
  }
  $9 = (($i$01$i1$i) + 1)|0;
  $exitcond$i2$i = ($9|0)==(16);
  if ($exitcond$i2$i) {
   break;
  } else {
   $i$01$i1$i = $9;
  }
 }
 __Z17MergeLightmapDataR18AwakeFromLoadQueue($awakeQueue);
 STACKTOP = sp;return;
}
function __Z38VerifyNothingIsPersistentInLoadedSceneRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName) {
 $pathName = $pathName|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z31ValidateNoSceneObjectsAreLoadedb($includeAllEditorExtensions) {
 $includeAllEditorExtensions = $includeAllEditorExtensions|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z23CompletePreloadMainDataR18AwakeFromLoadQueue($awakeQueue) {
 $awakeQueue = $awakeQueue|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p$0$i$i$i = 0, $exitcond$i$i = 0, $exitcond$i2$i = 0, $i$01$i$i = 0, $i$01$i1$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __Z20DestroyLevelManagersv();
 __ZN18AwakeFromLoadQueue25RegisterObjectInstanceIDsEv($awakeQueue);
 __Z12LoadManagersR18AwakeFromLoadQueue($awakeQueue);
 $1 = (_strlen((627696|0))|0);
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$0>>0] = $5;
  $6 = (($0) + 1|0);
  $__p$0$i$i$i = $6;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  $10 = (($0) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$0>>2] = $11;
  $12 = (($0) + 4|0);
  HEAP32[$12>>2] = $1;
  $__p$0$i$i$i = $9;
 }
 _memcpy(($__p$0$i$i$i|0),(627696|0),($1|0))|0;
 $13 = (($__p$0$i$i$i) + ($1)|0);
 HEAP8[$13>>0] = 0;
 __THREW__ = 0;
 $14 = (invoke_i(78)|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 do {
  if ($16) {
   label = 21;
  } else {
   $i$01$i$i = 0;
   while(1) {
    $17 = ((($14) + ($i$01$i$i<<2)|0) + 192|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     __THREW__ = 0;
     invoke_viii($18|0,($0|0),($awakeQueue|0),2);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      label = 20;
      break;
     }
    }
    $22 = (($i$01$i$i) + 1)|0;
    $exitcond$i$i = ($22|0)==(16);
    if ($exitcond$i$i) {
     break;
    } else {
     $i$01$i$i = $22;
    }
   }
   if ((label|0) == 20) {
    $46 = ___cxa_find_matching_catch()|0;
    $47 = tempRet0;
    $lpad$phi$index = $46;$lpad$phi$index3 = $47;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3546,($awakeQueue|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 21;
   } else {
    __THREW__ = 0;
    $25 = (invoke_i(78)|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     label = 21;
    } else {
     $i$01$i1$i = 0;
     while(1) {
      $28 = ((($25) + ($i$01$i1$i<<2)|0) + 256|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==(0|0);
      if (!($30)) {
       __THREW__ = 0;
       invoke_viii($29|0,($0|0),($awakeQueue|0),2);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        label = 19;
        break;
       }
      }
      $33 = (($i$01$i1$i) + 1)|0;
      $exitcond$i2$i = ($33|0)==(16);
      if ($exitcond$i2$i) {
       break;
      } else {
       $i$01$i1$i = $33;
      }
     }
     if ((label|0) == 19) {
      $44 = ___cxa_find_matching_catch()|0;
      $45 = tempRet0;
      $lpad$phi$index = $44;$lpad$phi$index3 = $45;
      break;
     }
     $34 = HEAP8[$0>>0]|0;
     $35 = $34 & 1;
     $36 = ($35<<24>>24)==(0);
     if (!($36)) {
      $37 = (($0) + 8|0);
      $38 = HEAP32[$37>>2]|0;
      __ZdlPv($38);
     }
     $39 = (__Z22GetGameManagerIfExistsi(9)|0);
     $40 = ($39|0)==(0|0);
     if ($40) {
      $55 = (__Z21GetDelayedCallManagerv()|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = (($56) + 100|0);
      $58 = HEAP32[$57>>2]|0;
      FUNCTION_TABLE_vii[$58 & 4095]($55,16);
      $59 = (__Z18GetQualitySettingsv()|0);
      __ZN15QualitySettings13ApplySettingsEib($59,-1,0);
      __ZN13RenderManager18UpdateAllRenderersEv();
      STACKTOP = sp;return;
     }
     $41 = HEAP32[$39>>2]|0;
     $42 = (($41) + 12|0);
     $43 = HEAP32[$42>>2]|0;
     FUNCTION_TABLE_vii[$43 & 4095]($39,0);
     $55 = (__Z21GetDelayedCallManagerv()|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($56) + 100|0);
     $58 = HEAP32[$57>>2]|0;
     FUNCTION_TABLE_vii[$58 & 4095]($55,16);
     $59 = (__Z18GetQualitySettingsv()|0);
     __ZN15QualitySettings13ApplySettingsEib($59,-1,0);
     __ZN13RenderManager18UpdateAllRenderersEv();
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $lpad$phi$index = $48;$lpad$phi$index3 = $49;
 }
 $50 = HEAP8[$0>>0]|0;
 $51 = $50 & 1;
 $52 = ($51<<24>>24)==(0);
 if ($52) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $53 = (($0) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z31CompletePreloadManagerLoadLevelRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER18AwakeFromLoadQueue($path,$awakeQueue) {
 $path = $path|0;
 $awakeQueue = $awakeQueue|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $exitcond$i2$i = 0, $i$01$i$i = 0, $i$01$i1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18AwakeFromLoadQueue25RegisterObjectInstanceIDsEv($awakeQueue);
 __Z12LoadManagersR18AwakeFromLoadQueue($awakeQueue);
 $0 = (__ZN15GlobalCallbacks3GetEv()|0);
 $i$01$i$i = 0;
 while(1) {
  $1 = ((($0) + ($i$01$i$i<<2)|0) + 192|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   FUNCTION_TABLE_viii[$2 & 4095]($path,$awakeQueue,0);
  }
  $4 = (($i$01$i$i) + 1)|0;
  $exitcond$i$i = ($4|0)==(16);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$01$i$i = $4;
  }
 }
 __ZN18AwakeFromLoadQueue30PersistentManagerAwakeFromLoadEv($awakeQueue);
 $5 = (__ZN15GlobalCallbacks3GetEv()|0);
 $i$01$i1$i = 0;
 while(1) {
  $6 = ((($5) + ($i$01$i1$i<<2)|0) + 256|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   FUNCTION_TABLE_viii[$7 & 4095]($path,$awakeQueue,0);
  }
  $9 = (($i$01$i1$i) + 1)|0;
  $exitcond$i2$i = ($9|0)==(16);
  if ($exitcond$i2$i) {
   break;
  } else {
   $i$01$i1$i = $9;
  }
 }
 __Z16CleanupAfterLoadv();
 STACKTOP = sp;return;
}
function __Z15UnloadGameScenev() {
 var $$0$i10 = 0, $$0$i4 = 0, $$byval_copy11 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0.0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0.0, $198 = 0.0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0.0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$026 = 0, $i1$019 = 0, $i2$014 = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0;
 var $objects = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy11 = sp;
 $0 = sp + 32|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $objects = sp + 16|0;
 $3 = (+_emscripten_get_now());
 $4 = $3 * 1.0E+6;
 $5 = (~~$4)>>>0;
 $6 = +Math_abs($4) >= 1.0 ? $4 > 0.0 ? (Math_min(+Math_floor($4 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($4 - +(~~$4 >>> 0)) / 4294967296.0) >>> 0 : 0;
 HEAP32[$objects>>2] = 0;
 $7 = (($objects) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($objects) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = (($objects) + 4|0);
 HEAP32[$9>>2] = 61;
 __THREW__ = 0;
 invoke_vi(3547,($objects|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 21;
  } else {
   $12 = HEAP32[$objects>>2]|0;
   $13 = HEAP32[$7>>2]|0;
   $14 = ($13|0)==(0);
   L3: do {
    if ($14) {
     $16 = 0;$210 = $12;
    } else {
     $i$026 = $12;
     while(1) {
      $17 = HEAP32[$i$026>>2]|0;
      HEAP32[$2>>2] = $17;
      $18 = HEAP32[560624>>2]|0;
      $19 = ($18|0)==(0|0);
      if (!($19)) {
       $20 = (($18) + 36|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($18) + 4|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = ($21|0)==($23|0);
       do {
        if ($24) {
         $25 = (($18) + 28|0);
         $26 = HEAP32[$25>>2]|0;
         $27 = (($18) + 32|0);
         $28 = HEAP32[$27>>2]|0;
         $29 = (($26) + ($28<<3)|0);
         $45 = $29;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy11,$18,$2);
         $30 = HEAP32[$$byval_copy11>>2]|0;
         $31 = ($30|0)==(-1);
         $32 = (($18) + 28|0);
         $33 = HEAP32[$32>>2]|0;
         if ($31) {
          $34 = (($18) + 32|0);
          $35 = HEAP32[$34>>2]|0;
          $36 = (($33) + ($35<<3)|0);
          $45 = $36;
          break;
         } else {
          $37 = (($33) + ($30<<3)|0);
          $45 = $37;
          break;
         }
        }
       } while(0);
       $38 = HEAP32[560624>>2]|0;
       $39 = (($38) + 28|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = (($38) + 32|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = (($40) + ($42<<3)|0);
       $44 = ($45|0)==($43|0);
       if (!($44)) {
        $46 = (($45) + 4|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = ($47|0)==(0|0);
        if (!($48)) {
         $49 = (($47) + 8|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = $50 >>> 21;
         $52 = HEAP32[560640>>2]|0;
         $53 = Math_imul($52, $51)|0;
         $54 = (($53) + 1)|0;
         $55 = $54 >> 5;
         $56 = $55 << 5;
         $57 = (($54) - ($56))|0;
         $58 = HEAP32[560632>>2]|0;
         $59 = (($58) + ($55<<2)|0);
         $60 = HEAP32[$59>>2]|0;
         $61 = 1 << $57;
         $62 = $61 & $60;
         $63 = ($62|0)==(0);
         if (!($63)) {
          __THREW__ = 0;
          $64 = (invoke_ii(3220,($47|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           break;
          }
          $67 = (($64) + 156|0);
          $68 = HEAP32[$67>>2]|0;
          $69 = ($68|0)==(0|0);
          if ($69) {
           __THREW__ = 0;
           invoke_vii(2597,($47|0),0);
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            break;
           }
          }
         }
        }
       }
      }
      $86 = (($i$026) + 4|0);
      $87 = HEAP32[$objects>>2]|0;
      $88 = HEAP32[$7>>2]|0;
      $89 = (($87) + ($88<<2)|0);
      $90 = ($86|0)==($89|0);
      if ($90) {
       $16 = $88;$210 = $87;
       break L3;
      } else {
       $i$026 = $86;
      }
     }
     $76 = ___cxa_find_matching_catch()|0;
     $77 = tempRet0;
     $lpad$phi$index = $76;$lpad$phi$index4 = $77;
     break L1;
    }
   } while(0);
   $15 = ($16|0)==(0);
   L24: do {
    if ($15) {
     $$lcssa = $210;
    } else {
     $i1$019 = $210;
     while(1) {
      $91 = HEAP32[$i1$019>>2]|0;
      HEAP32[$0>>2] = $91;
      $92 = HEAP32[560624>>2]|0;
      $93 = ($92|0)==(0|0);
      if ($93) {
       $$0$i10 = 0;
      } else {
       $94 = (($92) + 36|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = (($92) + 4|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = ($95|0)==($97|0);
       do {
        if ($98) {
         $99 = (($92) + 28|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = (($92) + 32|0);
         $102 = HEAP32[$101>>2]|0;
         $103 = (($100) + ($102<<3)|0);
         $119 = $103;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy11,$92,$0);
         $104 = HEAP32[$$byval_copy11>>2]|0;
         $105 = ($104|0)==(-1);
         $106 = (($92) + 28|0);
         $107 = HEAP32[$106>>2]|0;
         if ($105) {
          $108 = (($92) + 32|0);
          $109 = HEAP32[$108>>2]|0;
          $110 = (($107) + ($109<<3)|0);
          $119 = $110;
          break;
         } else {
          $111 = (($107) + ($104<<3)|0);
          $119 = $111;
          break;
         }
        }
       } while(0);
       $112 = HEAP32[560624>>2]|0;
       $113 = (($112) + 28|0);
       $114 = HEAP32[$113>>2]|0;
       $115 = (($112) + 32|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = (($114) + ($116<<3)|0);
       $118 = ($119|0)==($117|0);
       if ($118) {
        $$0$i10 = 0;
       } else {
        $120 = (($119) + 4|0);
        $121 = HEAP32[$120>>2]|0;
        $$0$i10 = $121;
       }
      }
      __THREW__ = 0;
      invoke_vii(2597,($$0$i10|0),0);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       break;
      }
      $124 = (($i1$019) + 4|0);
      $125 = HEAP32[$objects>>2]|0;
      $126 = HEAP32[$7>>2]|0;
      $127 = (($125) + ($126<<2)|0);
      $128 = ($124|0)==($127|0);
      if ($128) {
       $$lcssa = $125;
       break L24;
      } else {
       $i1$019 = $124;
      }
     }
     $74 = ___cxa_find_matching_catch()|0;
     $75 = tempRet0;
     $lpad$phi$index = $74;$lpad$phi$index4 = $75;
     break L1;
    }
   } while(0);
   $129 = HEAP32[$8>>2]|0;
   $130 = ($129|0)>(-1);
   if ($130) {
    $131 = HEAP32[$9>>2]|0;
    HEAP32[$0>>2] = $131;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($$lcssa|0),($$byval_copy11|0));
    $132 = __THREW__; __THREW__ = 0;
    $133 = $132&1;
    if ($133) {
     label = 21;
     break;
    }
    HEAP32[$objects>>2] = 0;
   }
   HEAP32[$7>>2] = 0;
   HEAP32[$8>>2] = 0;
   __THREW__ = 0;
   invoke_vii(2596,($objects|0),0);
   $134 = __THREW__; __THREW__ = 0;
   $135 = $134&1;
   if ($135) {
    label = 21;
   } else {
    $136 = HEAP32[$7>>2]|0;
    $137 = ($136|0)==(0);
    L47: do {
     if (!($137)) {
      $138 = HEAP32[$objects>>2]|0;
      $i2$014 = $138;
      while(1) {
       $139 = HEAP32[$i2$014>>2]|0;
       HEAP32[$0>>2] = $139;
       $140 = HEAP32[560624>>2]|0;
       $141 = ($140|0)==(0|0);
       if ($141) {
        $$0$i4 = 0;
       } else {
        $142 = (($140) + 36|0);
        $143 = HEAP32[$142>>2]|0;
        $144 = (($140) + 4|0);
        $145 = HEAP32[$144>>2]|0;
        $146 = ($143|0)==($145|0);
        do {
         if ($146) {
          $147 = (($140) + 28|0);
          $148 = HEAP32[$147>>2]|0;
          $149 = (($140) + 32|0);
          $150 = HEAP32[$149>>2]|0;
          $151 = (($148) + ($150<<3)|0);
          $167 = $151;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy11,$140,$0);
          $152 = HEAP32[$$byval_copy11>>2]|0;
          $153 = ($152|0)==(-1);
          $154 = (($140) + 28|0);
          $155 = HEAP32[$154>>2]|0;
          if ($153) {
           $156 = (($140) + 32|0);
           $157 = HEAP32[$156>>2]|0;
           $158 = (($155) + ($157<<3)|0);
           $167 = $158;
           break;
          } else {
           $159 = (($155) + ($152<<3)|0);
           $167 = $159;
           break;
          }
         }
        } while(0);
        $160 = HEAP32[560624>>2]|0;
        $161 = (($160) + 28|0);
        $162 = HEAP32[$161>>2]|0;
        $163 = (($160) + 32|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = (($162) + ($164<<3)|0);
        $166 = ($167|0)==($165|0);
        if ($166) {
         $$0$i4 = 0;
        } else {
         $168 = (($167) + 4|0);
         $169 = HEAP32[$168>>2]|0;
         $$0$i4 = $169;
        }
       }
       __THREW__ = 0;
       invoke_vii(2597,($$0$i4|0),0);
       $170 = __THREW__; __THREW__ = 0;
       $171 = $170&1;
       if ($171) {
        break;
       }
       $172 = (($i2$014) + 4|0);
       $173 = HEAP32[$objects>>2]|0;
       $174 = HEAP32[$7>>2]|0;
       $175 = (($173) + ($174<<2)|0);
       $176 = ($172|0)==($175|0);
       if ($176) {
        break L47;
       } else {
        $i2$014 = $172;
       }
      }
      $72 = ___cxa_find_matching_catch()|0;
      $73 = tempRet0;
      $lpad$phi$index = $72;$lpad$phi$index4 = $73;
      break L1;
     }
    } while(0);
    __THREW__ = 0;
    $177 = (invoke_i(78)|0);
    $178 = __THREW__; __THREW__ = 0;
    $179 = $178&1;
    if ($179) {
     label = 21;
    } else {
     $180 = (($177) + 128|0);
     __THREW__ = 0;
     invoke_vi(3525,($180|0));
     $181 = __THREW__; __THREW__ = 0;
     $182 = $181&1;
     if ($182) {
      label = 21;
     } else {
      __THREW__ = 0;
      $183 = __THREW__; __THREW__ = 0;
      $184 = $183&1;
      if ($184) {
       label = 21;
      } else {
       __THREW__ = 0;
       $185 = (+invoke_d(2));
       $186 = __THREW__; __THREW__ = 0;
       $187 = $186&1;
       if ($187) {
        label = 21;
       } else {
        $188 = $185 * 1.0E+6;
        $189 = (~~$188)>>>0;
        $190 = +Math_abs($188) >= 1.0 ? $188 > 0.0 ? (Math_min(+Math_floor($188 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($188 - +(~~$188 >>> 0)) / 4294967296.0) >>> 0 : 0;
        $191 = (_i64Subtract(($189|0),($190|0),($5|0),($6|0))|0);
        $192 = tempRet0;
        __THREW__ = 0;
        $193 = (invoke_iii(2425,($191|0),($192|0))|0);
        $194 = tempRet0;
        $195 = __THREW__; __THREW__ = 0;
        $196 = $195&1;
        if ($196) {
         label = 21;
        } else {
         $197 = (+($193>>>0)) + (4294967296.0*(+($194>>>0)));
         $198 = $197 * 1.00000000000000006228E-9;
         $199 = Math_fround($198);
         $200 = Math_fround($199 * Math_fround(1000.0));
         $201 = +$200;
         __THREW__ = 0;
         HEAPF64[tempDoublePtr>>3]=$201;HEAP32[$$byval_copy11>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy11+4>>2]=HEAP32[tempDoublePtr+4>>2];
         invoke_vii(2587,(627896|0),($$byval_copy11|0));
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          label = 21;
         } else {
          $204 = HEAP32[$8>>2]|0;
          $205 = ($204|0)>(-1);
          if (!($205)) {
           STACKTOP = sp;return;
          }
          $206 = HEAP32[$objects>>2]|0;
          $207 = HEAP32[$9>>2]|0;
          HEAP32[$0>>2] = $207;
          ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
          __Z19free_alloc_internalPv10MemLabelId($206,$$byval_copy11);
          HEAP32[$objects>>2] = 0;
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  $lpad$phi$index = $78;$lpad$phi$index4 = $79;
 }
 $80 = HEAP32[$8>>2]|0;
 $81 = ($80|0)>(-1);
 if (!($81)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $82 = HEAP32[$objects>>2]|0;
 $83 = HEAP32[$9>>2]|0;
 HEAP32[$1>>2] = $83;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy11|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $208 = ___cxa_find_matching_catch(0|0)|0;
  $209 = tempRet0;
  ___clang_call_terminate($208);
  // unreachable;
 }
 HEAP32[$objects>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN10systeminfo18GetRuntimePlatformEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 17;
}
function __ZN10systeminfo19IsPlatformWebPlayerE15RuntimePlatform($p) {
 $p = $p|0;
 var $p$off = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $p$off = (($p) + -3)|0;
 $switch = ($p$off>>>0)<(3);
 STACKTOP = sp;return ($switch|0);
}
function __Z18ConvertUTF8toUTF16PPKhS0_PPtS2_15ConversionFlags($sourceStart,$sourceEnd,$targetStart,$targetEnd,$flags) {
 $sourceStart = $sourceStart|0;
 $sourceEnd = $sourceEnd|0;
 $targetStart = $targetStart|0;
 $targetEnd = $targetEnd|0;
 $flags = $flags|0;
 var $$not = 0, $$not2 = 0, $$not3 = 0, $$off = 0, $$pre = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $ch$0 = 0, $ch$1 = 0, $ch$2 = 0, $ch$3 = 0, $ch$4 = 0, $ch$5 = 0, $not$$i = 0, $notlhs = 0;
 var $notrhs = 0, $or$cond = 0, $or$cond$i = 0, $or$cond1$i = 0, $or$cond2$i$not = 0, $result$0 = 0, $source$015 = 0, $source$1 = 0, $source$2 = 0, $source$3 = 0, $source$4 = 0, $source$5 = 0, $source$6 = 0, $source$7 = 0, $srcptr$0$i = 0, $srcptr$1$i = 0, $target$0$be = 0, $target$010 = 0, $target$016 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$sourceStart>>2]|0;
 $1 = HEAP32[$targetStart>>2]|0;
 $2 = ($0>>>0)<($sourceEnd>>>0);
 L1: do {
  if ($2) {
   $3 = ($flags|0)==(0);
   $source$015 = $0;$target$016 = $1;
   L3: while(1) {
    $4 = HEAP8[$source$015>>0]|0;
    $5 = $4&255;
    $6 = (627920 + ($5)|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = $7 << 24 >> 24;
    $9 = $8 & 65535;
    $10 = (($source$015) + ($9)|0);
    $11 = ($10>>>0)<($sourceEnd>>>0);
    if (!($11)) {
     $result$0 = 1;$source$7 = $source$015;$target$010 = $target$016;
     break L1;
    }
    $12 = (($9) + 1)|0;
    $13 = (($source$015) + ($12)|0);
    if ((($9|0) == 2)) {
     $srcptr$0$i = $13;
     label = 6;
    } else if ((($9|0) == 3)) {
     $14 = (($source$015) + 3|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = ($15<<24>>24)>(-1);
     $17 = ($15&255)>(191);
     $or$cond$i = $16 | $17;
     if ($or$cond$i) {
      $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
      break L1;
     } else {
      $srcptr$0$i = $14;
      label = 6;
     }
    } else if ((($9|0) == 1)) {
     $srcptr$1$i = $13;
     label = 7;
    } else if (!((($9|0) == 0))) {
     $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
     break L1;
    }
    if ((label|0) == 6) {
     label = 0;
     $18 = (($srcptr$0$i) + -1|0);
     $19 = HEAP8[$18>>0]|0;
     $20 = ($19<<24>>24)>(-1);
     $21 = ($19&255)>(191);
     $or$cond1$i = $20 | $21;
     if ($or$cond1$i) {
      $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
      break L1;
     } else {
      $srcptr$1$i = $18;
      label = 7;
     }
    }
    do {
     if ((label|0) == 7) {
      label = 0;
      $22 = (($srcptr$1$i) + -1|0);
      $23 = HEAP8[$22>>0]|0;
      $24 = ($23&255)>(191);
      if ($24) {
       $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
       break L1;
      }
      if ((($5|0) == 240)) {
       $27 = ($23&255)<(144);
       if ($27) {
        $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
        break L1;
       } else {
        break;
       }
      } else if ((($5|0) == 244)) {
       $28 = ($23&255)>(143);
       if ($28) {
        $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
        break L1;
       } else {
        break;
       }
      } else if ((($5|0) == 224)) {
       $25 = ($23&255)<(160);
       if ($25) {
        $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
        break L1;
       } else {
        break;
       }
      } else if ((($5|0) == 237)) {
       $26 = ($23&255)>(159);
       if ($26) {
        $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
        break L1;
       } else {
        break;
       }
      } else {
       $29 = ($23<<24>>24)>(-1);
       if ($29) {
        $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
        break L1;
       } else {
        break;
       }
      }
     }
    } while(0);
    $notlhs = ($4<<24>>24)>(-1);
    $notrhs = ($4&255)>(193);
    $or$cond2$i$not = $notrhs | $notlhs;
    $not$$i = ($4&255)<(245);
    $or$cond = $or$cond2$i$not & $not$$i;
    if (!($or$cond)) {
     $result$0 = 3;$source$7 = $source$015;$target$010 = $target$016;
     break L1;
    }
    switch ($9|0) {
    case 0:  {
     $54 = $4;$ch$4 = 0;$source$5 = $source$015;
     label = 21;
     break;
    }
    case 4:  {
     $34 = $4;$ch$0 = 0;$source$1 = $source$015;
     label = 17;
     break;
    }
    case 3:  {
     $39 = $4;$ch$1 = 0;$source$2 = $source$015;
     label = 18;
     break;
    }
    case 2:  {
     $44 = $4;$ch$2 = 0;$source$3 = $source$015;
     label = 19;
     break;
    }
    case 5:  {
     $30 = (($source$015) + 1|0);
     $31 = $5 << 6;
     $$pre = HEAP8[$30>>0]|0;
     $34 = $$pre;$ch$0 = $31;$source$1 = $30;
     label = 17;
     break;
    }
    case 1:  {
     $49 = $4;$ch$3 = 0;$source$4 = $source$015;
     label = 20;
     break;
    }
    default: {
     $ch$5 = 0;$source$6 = $source$015;
    }
    }
    if ((label|0) == 17) {
     label = 0;
     $32 = (($source$1) + 1|0);
     $33 = $34&255;
     $35 = (($33) + ($ch$0))|0;
     $36 = $35 << 6;
     $$pre34 = HEAP8[$32>>0]|0;
     $39 = $$pre34;$ch$1 = $36;$source$2 = $32;
     label = 18;
    }
    if ((label|0) == 18) {
     label = 0;
     $37 = (($source$2) + 1|0);
     $38 = $39&255;
     $40 = (($38) + ($ch$1))|0;
     $41 = $40 << 6;
     $$pre35 = HEAP8[$37>>0]|0;
     $44 = $$pre35;$ch$2 = $41;$source$3 = $37;
     label = 19;
    }
    if ((label|0) == 19) {
     label = 0;
     $42 = (($source$3) + 1|0);
     $43 = $44&255;
     $45 = (($43) + ($ch$2))|0;
     $46 = $45 << 6;
     $$pre36 = HEAP8[$42>>0]|0;
     $49 = $$pre36;$ch$3 = $46;$source$4 = $42;
     label = 20;
    }
    if ((label|0) == 20) {
     label = 0;
     $47 = (($source$4) + 1|0);
     $48 = $49&255;
     $50 = (($48) + ($ch$3))|0;
     $51 = $50 << 6;
     $$pre37 = HEAP8[$47>>0]|0;
     $54 = $$pre37;$ch$4 = $51;$source$5 = $47;
     label = 21;
    }
    if ((label|0) == 21) {
     label = 0;
     $52 = (($source$5) + 1|0);
     $53 = $54&255;
     $55 = (($53) + ($ch$4))|0;
     $ch$5 = $55;$source$6 = $52;
    }
    $56 = (628176 + ($9<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($ch$5) - ($57))|0;
    $59 = ($58>>>0)<(65536);
    do {
     if ($59) {
      $$off = (($58) + -55296)|0;
      $60 = ($$off>>>0)<(2048);
      if (!($60)) {
       $64 = $58&65535;
       $65 = (($target$016) + 2|0);
       HEAP16[$target$016>>1] = $64;
       $target$0$be = $65;
       break;
      }
      if ($3) {
       label = 25;
       break L3;
      }
      $63 = (($target$016) + 2|0);
      HEAP16[$target$016>>1] = -3;
      $target$0$be = $63;
     } else {
      $66 = ($58>>>0)>(1114111);
      if ($66) {
       if ($3) {
        label = 30;
        break L3;
       }
       $69 = (($target$016) + 2|0);
       HEAP16[$target$016>>1] = -3;
       $target$0$be = $69;
       break;
      } else {
       $71 = (($target$016) + 2|0);
       $72 = ($71>>>0)<($targetEnd>>>0);
       if (!($72)) {
        label = 34;
        break L3;
       }
       $75 = (($58) + -65536)|0;
       $76 = $75 >>> 10;
       $77 = (($76) + 55296)|0;
       $78 = $77&65535;
       HEAP16[$target$016>>1] = $78;
       $79 = $75 & 1023;
       $80 = $79 | 56320;
       $81 = $80&65535;
       $82 = (($target$016) + 4|0);
       HEAP16[$71>>1] = $81;
       $target$0$be = $82;
       break;
      }
     }
    } while(0);
    $70 = ($source$6>>>0)<($sourceEnd>>>0);
    if ($70) {
     $source$015 = $source$6;$target$016 = $target$0$be;
    } else {
     $result$0 = 0;$source$7 = $source$6;$target$010 = $target$0$be;
     break L1;
    }
   }
   if ((label|0) == 25) {
    $$not3 = $8 | -65536;
    $61 = $$not3 ^ 65535;
    $62 = (($source$6) + ($61)|0);
    $result$0 = 3;$source$7 = $62;$target$010 = $target$016;
    break;
   }
   else if ((label|0) == 30) {
    $$not2 = $8 | -65536;
    $67 = $$not2 ^ 65535;
    $68 = (($source$6) + ($67)|0);
    $result$0 = 3;$source$7 = $68;$target$010 = $target$016;
    break;
   }
   else if ((label|0) == 34) {
    $$not = $8 | -65536;
    $73 = $$not ^ 65535;
    $74 = (($source$6) + ($73)|0);
    $result$0 = 2;$source$7 = $74;$target$010 = $target$016;
    break;
   }
  } else {
   $result$0 = 0;$source$7 = $0;$target$010 = $1;
  }
 } while(0);
 HEAP32[$sourceStart>>2] = $source$7;
 HEAP32[$targetStart>>2] = $target$010;
 STACKTOP = sp;return ($result$0|0);
}
function __Z18ConvertUTF16toUTF8PPKtS0_PPhS2_15ConversionFlags($sourceStart,$sourceEnd,$targetStart,$targetEnd,$flags) {
 $sourceStart = $sourceStart|0;
 $sourceEnd = $sourceEnd|0;
 $targetStart = $targetStart|0;
 $targetEnd = $targetEnd|0;
 $flags = $flags|0;
 var $$ = 0, $$$us = 0, $$off = 0, $$off$us = 0, $$off7$us = 0, $$off8 = 0, $$off8$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $bytesToWrite$0 = 0, $bytesToWrite$0$us = 0, $ch$0 = 0, $ch$0$ = 0, $ch$0$$us = 0, $ch$0$us = 0;
 var $ch$1 = 0, $ch$1$us = 0, $ch$2 = 0, $ch$2$us = 0, $ch$3 = 0, $ch$3$us = 0, $ch$4 = 0, $ch$4$us = 0, $or$cond = 0, $or$cond$us = 0, $result$0 = 0, $source$0$lcssa = 0, $source$010 = 0, $source$010$us = 0, $source$1 = 0, $source$1$us = 0, $target$0$lcssa = 0, $target$09 = 0, $target$09$us = 0, $target$1 = 0;
 var $target$1$us = 0, $target$2 = 0, $target$2$us = 0, $target$3 = 0, $target$3$us = 0, $target$4 = 0, $target$4$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$sourceStart>>2]|0;
 $1 = HEAP32[$targetStart>>2]|0;
 $2 = ($0>>>0)<($sourceEnd>>>0);
 L1: do {
  if ($2) {
   $3 = ($flags|0)==(0);
   if ($3) {
    $source$010$us = $0;$target$09$us = $1;
   } else {
    $source$010 = $0;$target$09 = $1;
    while(1) {
     $46 = (($source$010) + 2|0);
     $47 = HEAP16[$source$010>>1]|0;
     $48 = $47&65535;
     $$off = (($47) + 10240)<<16>>16;
     $49 = ($$off&65535)<(1024);
     $50 = ($46>>>0)<($sourceEnd>>>0);
     $or$cond = $49 & $50;
     if ($or$cond) {
      $51 = HEAP16[$46>>1]|0;
      $$off8 = (($51) + 9216)<<16>>16;
      $52 = ($$off8&65535)<(1024);
      if ($52) {
       $53 = $51&65535;
       $54 = $48 << 10;
       $55 = (($54) + -56613888)|0;
       $56 = (($55) + ($53))|0;
       $57 = (($source$010) + 4|0);
       $ch$0 = $56;$source$1 = $57;
      } else {
       $ch$0 = $48;$source$1 = $46;
      }
     } else {
      $ch$0 = $48;$source$1 = $46;
     }
     $58 = ($ch$0>>>0)<(128);
     if ($58) {
      $bytesToWrite$0 = 1;$ch$1 = $ch$0;
     } else {
      $59 = ($ch$0>>>0)<(2048);
      if ($59) {
       $bytesToWrite$0 = 2;$ch$1 = $ch$0;
      } else {
       $60 = ($ch$0>>>0)<(65536);
       if ($60) {
        $bytesToWrite$0 = 3;$ch$1 = $ch$0;
       } else {
        $61 = ($ch$0>>>0)<(2097152);
        $$ = $61 ? 4 : 2;
        $ch$0$ = $61 ? $ch$0 : 65533;
        $bytesToWrite$0 = $$;$ch$1 = $ch$0$;
       }
      }
     }
     $62 = (($target$09) + ($bytesToWrite$0)|0);
     $63 = ($62>>>0)>($targetEnd>>>0);
     if ($63) {
      $result$0 = 2;$source$0$lcssa = $source$010;$target$0$lcssa = $target$09;
      break L1;
     }
     if ((($bytesToWrite$0|0) == 1)) {
      $ch$4 = $ch$1;$target$3 = $62;
      label = 30;
     } else if ((($bytesToWrite$0|0) == 2)) {
      $ch$3 = $ch$1;$target$2 = $62;
      label = 29;
     } else if ((($bytesToWrite$0|0) == 3)) {
      $ch$2 = $ch$1;$target$1 = $62;
      label = 28;
     } else if ((($bytesToWrite$0|0) == 4)) {
      $64 = $ch$1 & 63;
      $65 = $64 | 128;
      $66 = $65&255;
      $67 = (($target$09) + 3|0);
      HEAP8[$67>>0] = $66;
      $68 = $ch$1 >>> 6;
      $ch$2 = $68;$target$1 = $67;
      label = 28;
     } else {
      $target$4 = $62;
     }
     if ((label|0) == 28) {
      label = 0;
      $69 = $ch$2 & 63;
      $70 = $69 | 128;
      $71 = $70&255;
      $72 = (($target$1) + -1|0);
      HEAP8[$72>>0] = $71;
      $73 = $ch$2 >>> 6;
      $ch$3 = $73;$target$2 = $72;
      label = 29;
     }
     if ((label|0) == 29) {
      label = 0;
      $74 = $ch$3 & 63;
      $75 = $74 | 128;
      $76 = $75&255;
      $77 = (($target$2) + -1|0);
      HEAP8[$77>>0] = $76;
      $78 = $ch$3 >>> 6;
      $ch$4 = $78;$target$3 = $77;
      label = 30;
     }
     if ((label|0) == 30) {
      label = 0;
      $79 = (628200 + ($bytesToWrite$0)|0);
      $80 = HEAP8[$79>>0]|0;
      $81 = $80&255;
      $82 = $81 | $ch$4;
      $83 = $82&255;
      $84 = (($target$3) + -1|0);
      HEAP8[$84>>0] = $83;
      $target$4 = $84;
     }
     $85 = (($target$4) + ($bytesToWrite$0)|0);
     $86 = ($source$1>>>0)<($sourceEnd>>>0);
     if ($86) {
      $source$010 = $source$1;$target$09 = $85;
     } else {
      $result$0 = 0;$source$0$lcssa = $source$1;$target$0$lcssa = $85;
      break L1;
     }
    }
   }
   while(1) {
    $4 = (($source$010$us) + 2|0);
    $5 = HEAP16[$source$010$us>>1]|0;
    $6 = $5&65535;
    $$off$us = (($5) + 10240)<<16>>16;
    $7 = ($$off$us&65535)<(1024);
    $8 = ($4>>>0)<($sourceEnd>>>0);
    $or$cond$us = $7 & $8;
    if ($or$cond$us) {
     $10 = HEAP16[$4>>1]|0;
     $$off8$us = (($10) + 9216)<<16>>16;
     $11 = ($$off8$us&65535)<(1024);
     if (!($11)) {
      $result$0 = 3;$source$0$lcssa = $source$010$us;$target$0$lcssa = $target$09$us;
      break L1;
     }
     $12 = $10&65535;
     $13 = $6 << 10;
     $14 = (($13) + -56613888)|0;
     $15 = (($14) + ($12))|0;
     $16 = (($source$010$us) + 4|0);
     $ch$0$us = $15;$source$1$us = $16;
    } else {
     $$off7$us = (($5) + 9216)<<16>>16;
     $9 = ($$off7$us&65535)<(1024);
     if ($9) {
      $result$0 = 3;$source$0$lcssa = $source$010$us;$target$0$lcssa = $target$09$us;
      break L1;
     } else {
      $ch$0$us = $6;$source$1$us = $4;
     }
    }
    $17 = ($ch$0$us>>>0)<(128);
    if ($17) {
     $bytesToWrite$0$us = 1;$ch$1$us = $ch$0$us;
    } else {
     $18 = ($ch$0$us>>>0)<(2048);
     if ($18) {
      $bytesToWrite$0$us = 2;$ch$1$us = $ch$0$us;
     } else {
      $19 = ($ch$0$us>>>0)<(65536);
      if ($19) {
       $bytesToWrite$0$us = 3;$ch$1$us = $ch$0$us;
      } else {
       $20 = ($ch$0$us>>>0)<(2097152);
       $$$us = $20 ? 4 : 2;
       $ch$0$$us = $20 ? $ch$0$us : 65533;
       $bytesToWrite$0$us = $$$us;$ch$1$us = $ch$0$$us;
      }
     }
    }
    $21 = (($target$09$us) + ($bytesToWrite$0$us)|0);
    $22 = ($21>>>0)>($targetEnd>>>0);
    if ($22) {
     $result$0 = 2;$source$0$lcssa = $source$010$us;$target$0$lcssa = $target$09$us;
     break L1;
    }
    if ((($bytesToWrite$0$us|0) == 2)) {
     $ch$3$us = $ch$1$us;$target$2$us = $21;
     label = 15;
    } else if ((($bytesToWrite$0$us|0) == 4)) {
     $23 = $ch$1$us & 63;
     $24 = $23 | 128;
     $25 = $24&255;
     $26 = (($target$09$us) + 3|0);
     HEAP8[$26>>0] = $25;
     $27 = $ch$1$us >>> 6;
     $ch$2$us = $27;$target$1$us = $26;
     label = 14;
    } else if ((($bytesToWrite$0$us|0) == 3)) {
     $ch$2$us = $ch$1$us;$target$1$us = $21;
     label = 14;
    } else if ((($bytesToWrite$0$us|0) == 1)) {
     $ch$4$us = $ch$1$us;$target$3$us = $21;
     label = 16;
    } else {
     $target$4$us = $21;
    }
    if ((label|0) == 14) {
     label = 0;
     $28 = $ch$2$us & 63;
     $29 = $28 | 128;
     $30 = $29&255;
     $31 = (($target$1$us) + -1|0);
     HEAP8[$31>>0] = $30;
     $32 = $ch$2$us >>> 6;
     $ch$3$us = $32;$target$2$us = $31;
     label = 15;
    }
    if ((label|0) == 15) {
     label = 0;
     $33 = $ch$3$us & 63;
     $34 = $33 | 128;
     $35 = $34&255;
     $36 = (($target$2$us) + -1|0);
     HEAP8[$36>>0] = $35;
     $37 = $ch$3$us >>> 6;
     $ch$4$us = $37;$target$3$us = $36;
     label = 16;
    }
    if ((label|0) == 16) {
     label = 0;
     $38 = (628200 + ($bytesToWrite$0$us)|0);
     $39 = HEAP8[$38>>0]|0;
     $40 = $39&255;
     $41 = $40 | $ch$4$us;
     $42 = $41&255;
     $43 = (($target$3$us) + -1|0);
     HEAP8[$43>>0] = $42;
     $target$4$us = $43;
    }
    $44 = (($target$4$us) + ($bytesToWrite$0$us)|0);
    $45 = ($source$1$us>>>0)<($sourceEnd>>>0);
    if ($45) {
     $source$010$us = $source$1$us;$target$09$us = $44;
    } else {
     $result$0 = 0;$source$0$lcssa = $source$1$us;$target$0$lcssa = $44;
     break;
    }
   }
  } else {
   $result$0 = 0;$source$0$lcssa = $0;$target$0$lcssa = $1;
  }
 } while(0);
 HEAP32[$sourceStart>>2] = $source$0$lcssa;
 HEAP32[$targetStart>>2] = $target$0$lcssa;
 STACKTOP = sp;return ($result$0|0);
}
function __Z18ConvertUTF8toUTF16PKciPtRi($source,$srcLength,$output,$outlength) {
 $source = $source|0;
 $srcLength = $srcLength|0;
 $output = $output|0;
 $outlength = $outlength|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $newoutput = 0, $src = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newoutput = sp + 4|0;
 $src = sp;
 HEAP32[$newoutput>>2] = $output;
 HEAP32[$src>>2] = $source;
 $0 = (($source) + ($srcLength)|0);
 $1 = (($output) + ($srcLength<<1)|0);
 $2 = (__Z18ConvertUTF8toUTF16PPKhS0_PPtS2_15ConversionFlags($src,$0,$newoutput,$1,1)|0);
 $3 = ($2|0)==(3);
 if ($3) {
  $$0 = 0;$storemerge = 0;
  HEAP32[$outlength>>2] = $storemerge;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[$newoutput>>2]|0;
 $5 = $4;
 $6 = $output;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 1;
 $$0 = 1;$storemerge = $8;
 HEAP32[$outlength>>2] = $storemerge;
 STACKTOP = sp;return ($$0|0);
}
function __Z18ConvertUTF8toUTF16RKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER13dynamic_arrayItLj2EE($source,$utf16) {
 $source = $source|0;
 $utf16 = $utf16|0;
 var $$0$i = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $src$i = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $src$i = sp;
 $0 = HEAP8[$source>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($source) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = (($utf16) + 8|0);
 HEAP32[$7>>2] = $8;
 $9 = (($utf16) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11>>>0)<($8>>>0);
 do {
  if ($12) {
   $13 = ($10|0)>(-1);
   if ($13) {
    HEAP32[$9>>2] = $8;
    $14 = HEAP32[$utf16>>2]|0;
    $15 = $8 << 1;
    $16 = (($utf16) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$src$i>>2] = $17;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$src$i+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,2,$$byval_copy3,0,628208,370)|0);
    HEAP32[$utf16>>2] = $18;
    break;
   } else {
    $19 = $8 << 1;
    $20 = (($utf16) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$src$i>>2] = $21;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$src$i+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,2,$$byval_copy3,0,628208,352)|0);
    $23 = HEAP32[$utf16>>2]|0;
    $24 = HEAP32[$7>>2]|0;
    $25 = $24 << 1;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$9>>2] = $8;
    HEAP32[$utf16>>2] = $22;
    break;
   }
  }
 } while(0);
 $26 = HEAP8[$source>>0]|0;
 $27 = $26 & 1;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  $33 = (($source) + 1|0);
  $34 = $26&255;
  $35 = $34 >>> 1;
  $37 = $33;$39 = $35;
 } else {
  $29 = (($source) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($source) + 4|0);
  $32 = HEAP32[$31>>2]|0;
  $37 = $30;$39 = $32;
 }
 $36 = HEAP32[$utf16>>2]|0;
 HEAP32[$$byval_copy3>>2] = $36;
 HEAP32[$src$i>>2] = $37;
 $38 = (($37) + ($39)|0);
 $40 = (($36) + ($39<<1)|0);
 $41 = (__Z18ConvertUTF8toUTF16PPKhS0_PPtS2_15ConversionFlags($src$i,$38,$$byval_copy3,$40,1)|0);
 $42 = ($41|0)==(3);
 if ($42) {
  $$0$i = 0;$storemerge$i = 0;
 } else {
  $43 = HEAP32[$$byval_copy3>>2]|0;
  $44 = $43;
  $45 = $36;
  $46 = (($44) - ($45))|0;
  $47 = $46 >> 1;
  $$0$i = 1;$storemerge$i = $47;
 }
 HEAP32[$7>>2] = $storemerge$i;
 $48 = HEAP32[$9>>2]|0;
 $49 = $48 & 2147483647;
 $50 = ($49>>>0)<($storemerge$i>>>0);
 if (!($50)) {
  STACKTOP = sp;return ($$0$i|0);
 }
 $51 = ($48|0)>(-1);
 if ($51) {
  HEAP32[$9>>2] = $storemerge$i;
  $52 = HEAP32[$utf16>>2]|0;
  $53 = $storemerge$i << 1;
  $54 = (($utf16) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  HEAP32[$src$i>>2] = $55;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$src$i+0>>2]|0;
  $56 = (__Z16realloc_internalPvji10MemLabelIdiPKci($52,$53,2,$$byval_copy3,0,628208,370)|0);
  HEAP32[$utf16>>2] = $56;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $57 = $storemerge$i << 1;
  $58 = (($utf16) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$src$i>>2] = $59;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$src$i+0>>2]|0;
  $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($57,2,$$byval_copy3,0,628208,352)|0);
  $61 = HEAP32[$utf16>>2]|0;
  $62 = HEAP32[$7>>2]|0;
  $63 = $62 << 1;
  _memcpy(($60|0),($61|0),($63|0))|0;
  HEAP32[$9>>2] = $storemerge$i;
  HEAP32[$utf16>>2] = $60;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __Z18ConvertUTF16toUTF8PKtiPcRi($source,$srcLength,$output,$outlength) {
 $source = $source|0;
 $srcLength = $srcLength|0;
 $output = $output|0;
 $outlength = $outlength|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $newoutput = 0, $src = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newoutput = sp + 4|0;
 $src = sp;
 HEAP32[$newoutput>>2] = $output;
 HEAP32[$src>>2] = $source;
 $0 = (($source) + ($srcLength<<1)|0);
 $1 = $srcLength << 2;
 $2 = (($output) + ($1)|0);
 $3 = (__Z18ConvertUTF16toUTF8PPKtS0_PPhS2_15ConversionFlags($src,$0,$newoutput,$2,1)|0);
 $4 = ($3|0)==(3);
 if ($4) {
  $$0 = 0;$storemerge = 0;
  HEAP32[$outlength>>2] = $storemerge;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$newoutput>>2]|0;
 $6 = $5;
 $7 = $output;
 $8 = (($6) - ($7))|0;
 $$0 = 1;$storemerge = $8;
 HEAP32[$outlength>>2] = $storemerge;
 STACKTOP = sp;return ($$0|0);
}
function __Z22InitializeMemoryLabelsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[628216>>2] = 1;
 HEAP32[628224>>2] = 2;
 HEAP32[628232>>2] = 4;
 HEAP32[628240>>2] = 6;
 HEAP32[628248>>2] = 8;
 HEAP32[628256>>2] = 11;
 HEAP32[628264>>2] = 13;
 HEAP32[628272>>2] = 14;
 HEAP32[628280>>2] = 16;
 HEAP32[628288>>2] = 17;
 HEAP32[628296>>2] = 18;
 HEAP32[628304>>2] = 19;
 HEAP32[628312>>2] = 23;
 HEAP32[628320>>2] = 24;
 HEAP32[628328>>2] = 25;
 HEAP32[628336>>2] = 26;
 HEAP32[628344>>2] = 27;
 HEAP32[628352>>2] = 28;
 HEAP32[628360>>2] = 30;
 HEAP32[628368>>2] = 31;
 HEAP32[628376>>2] = 40;
 HEAP32[628384>>2] = 42;
 HEAP32[628392>>2] = 43;
 HEAP32[628400>>2] = 44;
 HEAP32[628408>>2] = 46;
 HEAP32[628416>>2] = 47;
 HEAP32[628424>>2] = 53;
 HEAP32[628432>>2] = 54;
 HEAP32[628440>>2] = 55;
 HEAP32[628448>>2] = 59;
 HEAP32[628456>>2] = 61;
 HEAP32[628464>>2] = 62;
 HEAP32[628472>>2] = 63;
 HEAP32[628480>>2] = 65;
 HEAP32[628488>>2] = 68;
 HEAP32[628496>>2] = 69;
 HEAP32[628504>>2] = 72;
 HEAP32[628512>>2] = 90;
 HEAP32[628520>>2] = 91;
 STACKTOP = sp;return;
}
function __Z30GetOrCreateObjectStoredInFieldP14ScriptingFieldRK17GeneralMonoObjectb($agg$result,$field,$instance,$storeCreatedObjectInField) {
 $agg$result = $agg$result|0;
 $field = $field|0;
 $instance = $instance|0;
 $storeCreatedObjectInField = $storeCreatedObjectInField|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($instance) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP8[$agg$result>>0] = 1;
  $3 = (($agg$result) + 4|0);
  HEAP32[$3>>2] = 0;
  $4 = (($agg$result) + 8|0);
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = (__Z26scripting_field_get_offsetP14ScriptingField($field)|0);
 $6 = HEAP8[$instance>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (($5) + -8)|0;
 $9 = $7 ? $5 : $8;
 $10 = HEAP32[$0>>2]|0;
 $11 = (($10) + ($9)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__Z24scripting_field_get_typeP14ScriptingField($field)|0);
 $14 = (__Z25scripting_class_from_typeP13ScriptingType($13)|0);
 $15 = ($12|0)==(0|0);
 if ($15) {
  $16 = (_il2cpp_object_new($14)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($16);
  if ($storeCreatedObjectInField) {
   $17 = (__Z26scripting_field_get_offsetP14ScriptingField($field)|0);
   $18 = HEAP8[$instance>>0]|0;
   $19 = ($18<<24>>24)!=(0);
   $20 = (($17) + -8)|0;
   $21 = $19 ? $17 : $20;
   $22 = HEAP32[$0>>2]|0;
   $23 = (($22) + ($21)|0);
   HEAP32[$23>>2] = $16;
   $25 = $16;
  } else {
   $25 = $16;
  }
 } else {
  $25 = $12;
 }
 HEAP8[$agg$result>>0] = 1;
 $24 = (($agg$result) + 4|0);
 HEAP32[$24>>2] = $25;
 $26 = (($agg$result) + 8|0);
 HEAP32[$26>>2] = $14;
 STACKTOP = sp;return;
}
function __Z19FindCommandsInCachePK15MonoScriptCacheRK24TransferRequestSignature($monoScriptCache,$transferSignature) {
 $monoScriptCache = $monoScriptCache|0;
 $transferSignature = $transferSignature|0;
 var $$0 = 0, $$byval_copy27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $data$0 = 0, $eh$lpad$body$i$i$index3Z2D = 0, $eh$lpad$body$i$i$indexZ2D = 0, $eh$lpad$body$i15$i$index10Z2D = 0, $eh$lpad$body$i15$i$indexZ2D = 0, $i$02$i = 0, $transfer$i11$i = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy27 = sp + 196|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 24|0;
 $transfer$i11$i = sp + 48|0;
 $3 = sp + 192|0;
 $4 = ($monoScriptCache|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($monoScriptCache) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 L4: do {
  if ($7) {
   $8 = (($monoScriptCache) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[628376>>2]|0;
   HEAP32[$3>>2] = $10;
   ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$3+0>>2]|0;
   $11 = (__Znwj10MemLabelIdbiPKci(148,$$byval_copy27,0,16,630440,102)|0);
   $12 = (($11) + 12|0);
   HEAP32[$12>>2] = 0;
   $13 = (($11) + 20|0);
   HEAP32[$13>>2] = 0;
   $14 = (($11) + 24|0);
   HEAP32[$14>>2] = 0;
   $15 = (($11) + 16|0);
   ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP16[$11+8>>1]=0|0;
   HEAP32[$15>>2] = 61;
   $16 = (($11) + 28|0);
   HEAP8[$16>>0] = 0;
   $17 = (($11) + 29|0);
   HEAP8[$17>>0] = 0;
   $18 = (($11) + 32|0);
   HEAP32[$18>>2] = 0;
   $19 = (($11) + 40|0);
   HEAP32[$19>>2] = 0;
   $20 = (($11) + 44|0);
   HEAP32[$20>>2] = 0;
   $21 = (($11) + 36|0);
   HEAP32[$21>>2] = 61;
   $22 = (($11) + 48|0);
   HEAP8[$22>>0] = 0;
   $23 = (($11) + 49|0);
   HEAP8[$23>>0] = 0;
   $24 = (($11) + 52|0);
   HEAP32[$24>>2] = 0;
   $25 = (($11) + 60|0);
   HEAP32[$25>>2] = 0;
   $26 = (($11) + 64|0);
   HEAP32[$26>>2] = 0;
   $27 = (($11) + 56|0);
   HEAP32[$27>>2] = 61;
   $28 = (($11) + 68|0);
   HEAP8[$28>>0] = 0;
   $29 = (($11) + 69|0);
   HEAP8[$29>>0] = 0;
   $30 = (($11) + 72|0);
   HEAP32[$30>>2] = 0;
   $31 = (($11) + 80|0);
   HEAP32[$31>>2] = 0;
   $32 = (($11) + 84|0);
   HEAP32[$32>>2] = 0;
   $33 = (($11) + 76|0);
   HEAP32[$33>>2] = 61;
   $34 = (($11) + 88|0);
   HEAP8[$34>>0] = 0;
   $35 = (($11) + 89|0);
   HEAP8[$35>>0] = 0;
   $36 = (($11) + 92|0);
   HEAP32[$36>>2] = 0;
   $37 = (($11) + 100|0);
   HEAP32[$37>>2] = 0;
   $38 = (($11) + 104|0);
   HEAP32[$38>>2] = 0;
   $39 = (($11) + 96|0);
   HEAP32[$39>>2] = 61;
   $40 = (($11) + 108|0);
   HEAP8[$40>>0] = 0;
   $41 = (($11) + 109|0);
   HEAP8[$41>>0] = 0;
   $42 = (($11) + 112|0);
   HEAP32[$42>>2] = 0;
   $43 = (($11) + 120|0);
   HEAP32[$43>>2] = 0;
   $44 = (($11) + 124|0);
   HEAP32[$44>>2] = 0;
   $45 = (($11) + 116|0);
   HEAP32[$45>>2] = 61;
   $46 = (($11) + 128|0);
   HEAP8[$46>>0] = 0;
   $47 = (($11) + 129|0);
   HEAP8[$47>>0] = 0;
   $48 = (($11) + 132|0);
   HEAP32[$48>>2] = 0;
   $49 = (($11) + 140|0);
   HEAP32[$49>>2] = 0;
   $50 = (($11) + 144|0);
   HEAP32[$50>>2] = 0;
   $51 = (($11) + 136|0);
   HEAP32[$51>>2] = 61;
   HEAP32[$transfer$i11$i>>2] = 0;
   $52 = (($transfer$i11$i) + 4|0);
   HEAP32[$52>>2] = 0;
   $53 = (($transfer$i11$i) + 12|0);
   __ZN12CachedReaderC2Ev($53);
   HEAP32[$1>>2] = $9;
   $54 = (($1) + 4|0);
   HEAP32[$54>>2] = $9;
   __THREW__ = 0;
   $55 = (invoke_i(84)|0);
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   do {
    if ($57) {
     label = 13;
    } else {
     $58 = (($1) + 8|0);
     $59 = (($55) + 36|0);
     HEAP32[$58>>2] = $59;
     $60 = (($1) + 12|0);
     HEAP32[$60>>2] = 0;
     $61 = (($1) + 16|0);
     HEAP16[$61>>1] = 1;
     HEAP32[$2>>2] = 0;
     $62 = (($2) + 8|0);
     HEAP32[$62>>2] = 0;
     $63 = (($2) + 12|0);
     HEAP32[$63>>2] = 0;
     $64 = (($2) + 4|0);
     HEAP32[$64>>2] = 61;
     $65 = (($2) + 16|0);
     HEAP8[$65>>0] = 0;
     __THREW__ = 0;
     invoke_viiii(381,($1|0),($2|0),($11|0),0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if (!($67)) {
      $68 = (($11) + 4|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($69) + 1)|0;
      HEAP32[$68>>2] = $70;
      $71 = ((($11) + (($69*20)|0)|0) + 12|0);
      __THREW__ = 0;
      (invoke_iii(2431,($71|0),($2|0))|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if (!($73)) {
       $74 = ((($11) + (($69*20)|0)|0) + 8|0);
       HEAP8[$74>>0]=1&255;HEAP8[$74+1>>0]=1>>8;
       $75 = HEAP32[$63>>2]|0;
       $76 = ($75|0)>(-1);
       if ($76) {
        $77 = HEAP32[$2>>2]|0;
        $78 = HEAP32[$64>>2]|0;
        HEAP32[$0>>2] = $78;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($77|0),($$byval_copy27|0));
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         label = 13;
         break;
        }
        HEAP32[$2>>2] = 0;
       }
       HEAP32[$1>>2] = $9;
       $97 = (($1) + 4|0);
       HEAP32[$97>>2] = $9;
       $98 = (($1) + 8|0);
       $99 = (__Z19GetScriptingManagerv()|0);
       $100 = (($99) + 36|0);
       HEAP32[$98>>2] = $100;
       $101 = (($1) + 12|0);
       HEAP32[$101>>2] = 0;
       $102 = (($1) + 16|0);
       HEAP16[$102>>1] = 3;
       HEAP32[$2>>2] = 0;
       $103 = (($2) + 8|0);
       HEAP32[$103>>2] = 0;
       $104 = (($2) + 12|0);
       HEAP32[$104>>2] = 0;
       $105 = (($2) + 4|0);
       HEAP32[$105>>2] = 61;
       $106 = (($2) + 16|0);
       HEAP8[$106>>0] = 0;
       __THREW__ = 0;
       invoke_viiii(382,($1|0),($2|0),($11|0),0);
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if (!($108)) {
        $109 = HEAP32[$68>>2]|0;
        $110 = (($109) + 1)|0;
        HEAP32[$68>>2] = $110;
        $111 = ((($11) + (($109*20)|0)|0) + 12|0);
        __THREW__ = 0;
        (invoke_iii(2431,($111|0),($2|0))|0);
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if (!($113)) {
         $114 = ((($11) + (($109*20)|0)|0) + 8|0);
         HEAP8[$114>>0]=3&255;HEAP8[$114+1>>0]=3>>8;
         $115 = HEAP32[$104>>2]|0;
         $116 = ($115|0)>(-1);
         if ($116) {
          $117 = HEAP32[$2>>2]|0;
          $118 = HEAP32[$105>>2]|0;
          HEAP32[$0>>2] = $118;
          ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
          __Z19free_alloc_internalPv10MemLabelId($117,$$byval_copy27);
          HEAP32[$2>>2] = 0;
         }
         HEAP32[$1>>2] = $9;
         $129 = (($1) + 4|0);
         HEAP32[$129>>2] = $9;
         $130 = (($1) + 8|0);
         $131 = (__Z19GetScriptingManagerv()|0);
         $132 = (($131) + 36|0);
         HEAP32[$130>>2] = $132;
         $133 = (($1) + 12|0);
         HEAP32[$133>>2] = 0;
         $134 = (($1) + 16|0);
         HEAP16[$134>>1] = 6;
         HEAP32[$2>>2] = 0;
         $135 = (($2) + 8|0);
         HEAP32[$135>>2] = 0;
         $136 = (($2) + 12|0);
         HEAP32[$136>>2] = 0;
         $137 = (($2) + 4|0);
         HEAP32[$137>>2] = 61;
         $138 = (($2) + 16|0);
         HEAP8[$138>>0] = 0;
         __THREW__ = 0;
         invoke_viiii(383,($1|0),($2|0),($11|0),0);
         $139 = __THREW__; __THREW__ = 0;
         $140 = $139&1;
         if (!($140)) {
          $141 = HEAP32[$68>>2]|0;
          $142 = (($141) + 1)|0;
          HEAP32[$68>>2] = $142;
          $143 = ((($11) + (($141*20)|0)|0) + 12|0);
          __THREW__ = 0;
          (invoke_iii(2431,($143|0),($2|0))|0);
          $144 = __THREW__; __THREW__ = 0;
          $145 = $144&1;
          if (!($145)) {
           $146 = ((($11) + (($141*20)|0)|0) + 8|0);
           HEAP8[$146>>0]=6&255;HEAP8[$146+1>>0]=6>>8;
           $147 = HEAP32[$136>>2]|0;
           $148 = ($147|0)>(-1);
           if ($148) {
            $149 = HEAP32[$2>>2]|0;
            $150 = HEAP32[$137>>2]|0;
            HEAP32[$0>>2] = $150;
            ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
            __Z19free_alloc_internalPv10MemLabelId($149,$$byval_copy27);
            HEAP32[$2>>2] = 0;
           }
           HEAP32[$1>>2] = $9;
           $161 = (($1) + 4|0);
           HEAP32[$161>>2] = $9;
           $162 = (($1) + 8|0);
           $163 = (__Z19GetScriptingManagerv()|0);
           $164 = (($163) + 36|0);
           HEAP32[$162>>2] = $164;
           $165 = (($1) + 12|0);
           HEAP32[$165>>2] = 0;
           $166 = (($1) + 16|0);
           HEAP16[$166>>1] = 263;
           HEAP32[$2>>2] = 0;
           $167 = (($2) + 8|0);
           HEAP32[$167>>2] = 0;
           $168 = (($2) + 12|0);
           HEAP32[$168>>2] = 0;
           $169 = (($2) + 4|0);
           HEAP32[$169>>2] = 61;
           $170 = (($2) + 16|0);
           HEAP8[$170>>0] = 0;
           __THREW__ = 0;
           invoke_viiii(384,($1|0),($2|0),($11|0),0);
           $171 = __THREW__; __THREW__ = 0;
           $172 = $171&1;
           if (!($172)) {
            $173 = HEAP32[$68>>2]|0;
            $174 = (($173) + 1)|0;
            HEAP32[$68>>2] = $174;
            $175 = ((($11) + (($173*20)|0)|0) + 12|0);
            __THREW__ = 0;
            (invoke_iii(2431,($175|0),($2|0))|0);
            $176 = __THREW__; __THREW__ = 0;
            $177 = $176&1;
            if (!($177)) {
             $178 = ((($11) + (($173*20)|0)|0) + 8|0);
             HEAP8[$178>>0]=263&255;HEAP8[$178+1>>0]=263>>8;
             $179 = HEAP32[$168>>2]|0;
             $180 = ($179|0)>(-1);
             if ($180) {
              $181 = HEAP32[$2>>2]|0;
              $182 = HEAP32[$169>>2]|0;
              HEAP32[$0>>2] = $182;
              ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
              __Z19free_alloc_internalPv10MemLabelId($181,$$byval_copy27);
              HEAP32[$2>>2] = 0;
             }
             HEAP32[$transfer$i11$i>>2] = 0;
             $193 = (($transfer$i11$i) + 4|0);
             HEAP32[$193>>2] = 0;
             $194 = (($transfer$i11$i) + 12|0);
             __ZN12CachedReaderC2Ev($194);
             $195 = (($transfer$i11$i) + 72|0);
             HEAP32[$195>>2] = 0;
             $196 = (($transfer$i11$i) + 76|0);
             HEAP32[$196>>2] = 0;
             $197 = (($transfer$i11$i) + 88|0);
             dest=$197+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
             HEAP32[$1>>2] = $9;
             $198 = (($1) + 4|0);
             HEAP32[$198>>2] = $9;
             __THREW__ = 0;
             $199 = (invoke_i(84)|0);
             $200 = __THREW__; __THREW__ = 0;
             $201 = $200&1;
             L33: do {
              if ($201) {
               label = 54;
              } else {
               $202 = (($1) + 8|0);
               $203 = (($199) + 36|0);
               HEAP32[$202>>2] = $203;
               $204 = (($1) + 12|0);
               HEAP32[$204>>2] = 0;
               $205 = (($1) + 16|0);
               HEAP16[$205>>1] = 5;
               HEAP32[$2>>2] = 0;
               $206 = (($2) + 8|0);
               HEAP32[$206>>2] = 0;
               $207 = (($2) + 12|0);
               HEAP32[$207>>2] = 0;
               $208 = (($2) + 4|0);
               HEAP32[$208>>2] = 61;
               $209 = (($2) + 16|0);
               HEAP8[$209>>0] = 0;
               __THREW__ = 0;
               invoke_viiii(385,($1|0),($2|0),($11|0),0);
               $210 = __THREW__; __THREW__ = 0;
               $211 = $210&1;
               do {
                if (!($211)) {
                 $212 = HEAP32[$68>>2]|0;
                 $213 = (($212) + 1)|0;
                 HEAP32[$68>>2] = $213;
                 $214 = ((($11) + (($212*20)|0)|0) + 12|0);
                 __THREW__ = 0;
                 (invoke_iii(2431,($214|0),($2|0))|0);
                 $215 = __THREW__; __THREW__ = 0;
                 $216 = $215&1;
                 if ($216) {
                  break;
                 }
                 $217 = ((($11) + (($212*20)|0)|0) + 8|0);
                 HEAP8[$217>>0]=5&255;HEAP8[$217+1>>0]=5>>8;
                 $218 = HEAP32[$207>>2]|0;
                 $219 = ($218|0)>(-1);
                 if ($219) {
                  $220 = HEAP32[$2>>2]|0;
                  $221 = HEAP32[$208>>2]|0;
                  HEAP32[$0>>2] = $221;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
                  invoke_vii(2591,($220|0),($$byval_copy27|0));
                  $222 = __THREW__; __THREW__ = 0;
                  $223 = $222&1;
                  if ($223) {
                   label = 54;
                   break L33;
                  }
                  HEAP32[$2>>2] = 0;
                 }
                 __ZN14SafeBinaryReadD2Ev($transfer$i11$i);
                 $240 = HEAP32[$5>>2]|0;
                 $241 = ($240|0)==(0|0);
                 if ($241) {
                  HEAP32[$5>>2] = $11;
                  $data$0 = $11;
                  break L4;
                 }
                 $242 = HEAP32[628376>>2]|0;
                 $243 = ($11|0)==(0|0);
                 L45: do {
                  if (!($243)) {
                   $244 = (($11) + 8|0);
                   $245 = (($11) + 148|0);
                   $247 = $245;
                   while(1) {
                    $246 = (($247) + -20|0);
                    $248 = (($247) + -4|0);
                    $249 = HEAP32[$248>>2]|0;
                    $250 = ($249|0)>(-1);
                    if ($250) {
                     $251 = (($247) + -16|0);
                     $252 = HEAP32[$251>>2]|0;
                     $253 = (($247) + -12|0);
                     $254 = HEAP32[$253>>2]|0;
                     HEAP32[$1>>2] = $254;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$1+0>>2]|0;
                     invoke_vii(2591,($252|0),($$byval_copy27|0));
                     $255 = __THREW__; __THREW__ = 0;
                     $256 = $255&1;
                     if ($256) {
                      break;
                     }
                     HEAP32[$251>>2] = 0;
                    }
                    $257 = ($246|0)==($244|0);
                    if ($257) {
                     break L45;
                    } else {
                     $247 = $246;
                    }
                   }
                   $258 = ___cxa_find_matching_catch()|0;
                   $259 = tempRet0;
                   $260 = ($244|0)==($246|0);
                   if ($260) {
                    ___resumeException($258|0);
                    // unreachable;
                   }
                   $262 = $246;
                   while(1) {
                    $261 = (($262) + -20|0);
                    $263 = (($262) + -4|0);
                    $264 = HEAP32[$263>>2]|0;
                    $265 = ($264|0)>(-1);
                    if ($265) {
                     $266 = (($262) + -16|0);
                     $267 = HEAP32[$266>>2]|0;
                     $268 = (($262) + -12|0);
                     $269 = HEAP32[$268>>2]|0;
                     HEAP32[$0>>2] = $269;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
                     invoke_vii(2591,($267|0),($$byval_copy27|0));
                     $270 = __THREW__; __THREW__ = 0;
                     $271 = $270&1;
                     if ($271) {
                      label = 73;
                      break;
                     }
                     HEAP32[$266>>2] = 0;
                    }
                    $272 = ($261|0)==($244|0);
                    if ($272) {
                     label = 72;
                     break;
                    } else {
                     $262 = $261;
                    }
                   }
                   if ((label|0) == 72) {
                    ___resumeException($258|0);
                    // unreachable;
                   }
                   else if ((label|0) == 73) {
                    $273 = ___cxa_find_matching_catch(0|0)|0;
                    $274 = tempRet0;
                    ___clang_call_terminate($273);
                    // unreachable;
                   }
                  }
                 } while(0);
                 HEAP32[$2>>2] = $242;
                 ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$2+0>>2]|0;
                 __Z19free_alloc_internalPv10MemLabelId($11,$$byval_copy27);
                 $275 = (__Z19FindCommandsInCachePK15MonoScriptCacheRK24TransferRequestSignature($monoScriptCache,$transferSignature)|0);
                 $$0 = $275;
                 STACKTOP = sp;return ($$0|0);
                }
               } while(0);
               $224 = ___cxa_find_matching_catch()|0;
               $225 = tempRet0;
               $226 = HEAP32[$207>>2]|0;
               $227 = ($226|0)>(-1);
               if (!($227)) {
                $eh$lpad$body$i15$i$index10Z2D = $225;$eh$lpad$body$i15$i$indexZ2D = $224;
                break;
               }
               $228 = HEAP32[$2>>2]|0;
               $229 = HEAP32[$208>>2]|0;
               HEAP32[$0>>2] = $229;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
               invoke_vii(2591,($228|0),($$byval_copy27|0));
               $230 = __THREW__; __THREW__ = 0;
               $231 = $230&1;
               if ($231) {
                $232 = ___cxa_find_matching_catch(0|0)|0;
                $233 = tempRet0;
                ___clang_call_terminate($232);
                // unreachable;
               } else {
                HEAP32[$2>>2] = 0;
                $eh$lpad$body$i15$i$index10Z2D = $225;$eh$lpad$body$i15$i$indexZ2D = $224;
                break;
               }
              }
             } while(0);
             if ((label|0) == 54) {
              $234 = ___cxa_find_matching_catch()|0;
              $235 = tempRet0;
              $eh$lpad$body$i15$i$index10Z2D = $235;$eh$lpad$body$i15$i$indexZ2D = $234;
             }
             __THREW__ = 0;
             invoke_vi(3548,($transfer$i11$i|0));
             $236 = __THREW__; __THREW__ = 0;
             $237 = $236&1;
             if ($237) {
              $238 = ___cxa_find_matching_catch(0|0)|0;
              $239 = tempRet0;
              ___clang_call_terminate($238);
              // unreachable;
             } else {
              ___resumeException($eh$lpad$body$i15$i$indexZ2D|0);
              // unreachable;
             }
            }
           }
           $183 = ___cxa_find_matching_catch()|0;
           $184 = tempRet0;
           $185 = HEAP32[$168>>2]|0;
           $186 = ($185|0)>(-1);
           if (!($186)) {
            ___resumeException($183|0);
            // unreachable;
           }
           $187 = HEAP32[$2>>2]|0;
           $188 = HEAP32[$169>>2]|0;
           HEAP32[$0>>2] = $188;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($187|0),($$byval_copy27|0));
           $189 = __THREW__; __THREW__ = 0;
           $190 = $189&1;
           if ($190) {
            $191 = ___cxa_find_matching_catch(0|0)|0;
            $192 = tempRet0;
            ___clang_call_terminate($191);
            // unreachable;
           }
           HEAP32[$2>>2] = 0;
           ___resumeException($183|0);
           // unreachable;
          }
         }
         $151 = ___cxa_find_matching_catch()|0;
         $152 = tempRet0;
         $153 = HEAP32[$136>>2]|0;
         $154 = ($153|0)>(-1);
         if (!($154)) {
          ___resumeException($151|0);
          // unreachable;
         }
         $155 = HEAP32[$2>>2]|0;
         $156 = HEAP32[$137>>2]|0;
         HEAP32[$0>>2] = $156;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($155|0),($$byval_copy27|0));
         $157 = __THREW__; __THREW__ = 0;
         $158 = $157&1;
         if ($158) {
          $159 = ___cxa_find_matching_catch(0|0)|0;
          $160 = tempRet0;
          ___clang_call_terminate($159);
          // unreachable;
         }
         HEAP32[$2>>2] = 0;
         ___resumeException($151|0);
         // unreachable;
        }
       }
       $119 = ___cxa_find_matching_catch()|0;
       $120 = tempRet0;
       $121 = HEAP32[$104>>2]|0;
       $122 = ($121|0)>(-1);
       if (!($122)) {
        ___resumeException($119|0);
        // unreachable;
       }
       $123 = HEAP32[$2>>2]|0;
       $124 = HEAP32[$105>>2]|0;
       HEAP32[$0>>2] = $124;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($123|0),($$byval_copy27|0));
       $125 = __THREW__; __THREW__ = 0;
       $126 = $125&1;
       if ($126) {
        $127 = ___cxa_find_matching_catch(0|0)|0;
        $128 = tempRet0;
        ___clang_call_terminate($127);
        // unreachable;
       }
       HEAP32[$2>>2] = 0;
       ___resumeException($119|0);
       // unreachable;
      }
     }
     $81 = ___cxa_find_matching_catch()|0;
     $82 = tempRet0;
     $83 = HEAP32[$63>>2]|0;
     $84 = ($83|0)>(-1);
     if ($84) {
      $85 = HEAP32[$2>>2]|0;
      $86 = HEAP32[$64>>2]|0;
      HEAP32[$0>>2] = $86;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy27+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($85|0),($$byval_copy27|0));
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       $89 = ___cxa_find_matching_catch(0|0)|0;
       $90 = tempRet0;
       ___clang_call_terminate($89);
       // unreachable;
      } else {
       HEAP32[$2>>2] = 0;
       $eh$lpad$body$i$i$index3Z2D = $82;$eh$lpad$body$i$i$indexZ2D = $81;
       break;
      }
     } else {
      $eh$lpad$body$i$i$index3Z2D = $82;$eh$lpad$body$i$i$indexZ2D = $81;
     }
    }
   } while(0);
   if ((label|0) == 13) {
    $91 = ___cxa_find_matching_catch()|0;
    $92 = tempRet0;
    $eh$lpad$body$i$i$index3Z2D = $92;$eh$lpad$body$i$i$indexZ2D = $91;
   }
   __THREW__ = 0;
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $95 = ___cxa_find_matching_catch(0|0)|0;
    $96 = tempRet0;
    ___clang_call_terminate($95);
    // unreachable;
   } else {
    ___resumeException($eh$lpad$body$i$i$indexZ2D|0);
    // unreachable;
   }
  } else {
   $data$0 = $6;
  }
 } while(0);
 $276 = (($data$0) + 4|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = ($277|0)==(0);
 if ($278) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $279 = HEAP8[$transferSignature>>0]|0;
 $280 = (($transferSignature) + 1|0);
 $i$02$i = 0;
 while(1) {
  $281 = ((($data$0) + (($i$02$i*20)|0)|0) + 8|0);
  $282 = HEAP8[$281>>0]|0;
  $283 = ($282<<24>>24)==($279<<24>>24);
  if ($283) {
   $284 = ((($data$0) + (($i$02$i*20)|0)|0) + 9|0);
   $285 = HEAP8[$284>>0]|0;
   $286 = HEAP8[$280>>0]|0;
   $287 = ($285<<24>>24)==($286<<24>>24);
   if ($287) {
    break;
   }
  }
  $289 = (($i$02$i) + 1)|0;
  $290 = ($289|0)==($277|0);
  if ($290) {
   $$0 = 0;
   label = 81;
   break;
  } else {
   $i$02$i = $289;
  }
 }
 if ((label|0) == 81) {
  STACKTOP = sp;return ($$0|0);
 }
 $288 = ((($data$0) + (($i$02$i*20)|0)|0) + 12|0);
 $$0 = $288;
 STACKTOP = sp;return ($$0|0);
}
function __Z23TransferScriptingObjectI19StreamedBinaryWriteILb0EEEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$instance,$klass,$monoScriptCache) {
 $transfer = $transfer|0;
 $instance = $instance|0;
 $klass = $klass|0;
 $monoScriptCache = $monoScriptCache|0;
 var $$byval_copy6 = 0, $$idx$i$i$i = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandProvider$i = 0, $commandQueueBuilder = 0, $commands$0 = 0, $localNameConversion = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $runtimeInfo$i$i = 0, $transferRequestSignature = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy6 = sp + 96|0;
 $0 = sp;
 $runtimeInfo$i$i = sp + 8|0;
 $commandProvider$i = sp + 32|0;
 $transferRequestSignature = sp + 100|0;
 $localNameConversion = sp + 72|0;
 $commandQueueBuilder = sp + 76|0;
 $args = sp + 52|0;
 $$sroa$1 = sp + 102|0;
 $1 = (($transferRequestSignature) + 1|0);
 HEAP8[$transferRequestSignature>>0] = 3;
 HEAP8[$1>>0] = 0;
 $2 = (__Z19FindCommandsInCachePK15MonoScriptCacheRK24TransferRequestSignature($monoScriptCache,$transferRequestSignature)|0);
 HEAP32[$localNameConversion>>2] = 0;
 HEAP32[$commandQueueBuilder>>2] = 0;
 $3 = (($commandQueueBuilder) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($commandQueueBuilder) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($commandQueueBuilder) + 4|0);
 HEAP32[$5>>2] = 61;
 $6 = (($commandQueueBuilder) + 16|0);
 HEAP8[$6>>0] = 0;
 $7 = ($2|0)==(0|0);
 do {
  if ($7) {
   HEAP32[$args>>2] = $klass;
   $8 = (($args) + 4|0);
   HEAP32[$8>>2] = $klass;
   __THREW__ = 0;
   $9 = (invoke_i(84)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($args) + 8|0);
    $13 = (($9) + 36|0);
    HEAP32[$12>>2] = $13;
    $14 = (($args) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = (($args) + 16|0);
    $16 = HEAP16[$transferRequestSignature>>1]|0;
    HEAP16[$15>>1] = $16;
    __THREW__ = 0;
    invoke_viiii(382,($args|0),($commandQueueBuilder|0),($localNameConversion|0),0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $commands$0 = $commandQueueBuilder;
     label = 10;
     break;
    }
   }
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $lpad$phi$index = $21;$lpad$phi$index2 = $22;
  } else {
   $commands$0 = $2;
   label = 10;
  }
 } while(0);
 L7: do {
  if ((label|0) == 10) {
   $29 = HEAP32[$commands$0>>2]|0;
   $30 = (($commands$0) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + ($31<<6)|0);
   $33 = (($commandProvider$i) + 4|0);
   HEAP32[$33>>2] = $29;
   HEAP32[$commandProvider$i>>2] = $29;
   $34 = (($commandProvider$i) + 8|0);
   HEAP32[$34>>2] = $32;
   $$idx$i$i$i = $31 << 6;
   $35 = $$idx$i$i$i >> 6;
   $36 = (($commandProvider$i) + 16|0);
   HEAP32[$36>>2] = $35;
   $37 = (($commandProvider$i) + 12|0);
   HEAP32[$37>>2] = $35;
   ;HEAP32[$runtimeInfo$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i+20>>2]=0|0;
   $38 = (($runtimeInfo$i$i) + 16|0);
   HEAP32[$38>>2] = $transfer;
   HEAP8[$runtimeInfo$i$i>>0] = 1;
   $39 = (($runtimeInfo$i$i) + 1|0);
   ;HEAP8[$39+0>>0]=HEAP8[$$sroa$1+0>>0]|0;HEAP8[$39+1>>0]=HEAP8[$$sroa$1+1>>0]|0;HEAP8[$39+2>>0]=HEAP8[$$sroa$1+2>>0]|0;
   $40 = (($runtimeInfo$i$i) + 4|0);
   HEAP32[$40>>2] = $instance;
   $41 = (($runtimeInfo$i$i) + 8|0);
   HEAP32[$41>>2] = $klass;
   $42 = (($runtimeInfo$i$i) + 12|0);
   HEAP32[$42>>2] = $commandProvider$i;
   $43 = ($31|0)==(0);
   L9: do {
    if (!($43)) {
     $45 = $29;$47 = $32;
     while(1) {
      $44 = (($45) + 64|0);
      HEAP32[$33>>2] = $44;
      $46 = $47;
      $48 = $44;
      $49 = (($46) - ($48))|0;
      $50 = $49 >> 6;
      HEAP32[$37>>2] = $50;
      $51 = HEAP32[$45>>2]|0;
      $52 = (($45) + 4|0);
      __THREW__ = 0;
      invoke_vii($51|0,($52|0),($runtimeInfo$i$i|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$33>>2]|0;
      $56 = HEAP32[$34>>2]|0;
      $57 = ($55|0)==($56|0);
      if ($57) {
       break L9;
      } else {
       $45 = $55;$47 = $56;
      }
     }
     $19 = ___cxa_find_matching_catch()|0;
     $20 = tempRet0;
     $lpad$phi$index = $19;$lpad$phi$index2 = $20;
     break L7;
    }
   } while(0);
   $58 = HEAP32[$4>>2]|0;
   $59 = ($58|0)>(-1);
   if (!($59)) {
    STACKTOP = sp;return;
   }
   $60 = HEAP32[$commandQueueBuilder>>2]|0;
   $61 = HEAP32[$5>>2]|0;
   HEAP32[$0>>2] = $61;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($60,$$byval_copy6);
   HEAP32[$commandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = HEAP32[$4>>2]|0;
 $24 = ($23|0)>(-1);
 if (!($24)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $25 = HEAP32[$commandQueueBuilder>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $26;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy6|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 }
 HEAP32[$commandQueueBuilder>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z33BuildSerializationCommandQueueForI19StreamedBinaryWriteILb0EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($args,$commandQueueBuilder,$localNameConversions,$operatingOnBaseClass) {
 $args = $args|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $localNameConversions = $localNameConversions|0;
 $operatingOnBaseClass = $operatingOnBaseClass|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i5 = 0, $actualMethod$i$i = 0, $actualMethod$i$i14 = 0, $fields = 0, $forParent = 0, $invokeMethodCommand$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $tfi = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy6 = sp + 184|0;
 $actualMethod$i$i14 = sp + 176|0;
 $0 = sp;
 $1 = sp + 168|0;
 $actualMethod$i$i = sp + 160|0;
 $2 = sp + 8|0;
 $invokeMethodCommand$i$i = sp + 40|0;
 $forParent = sp + 16|0;
 $fields = sp + 104|0;
 $tfi = sp + 120|0;
 $3 = HEAP32[$args>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 if (!($operatingOnBaseClass)) {
  $6 = (($5) + 256|0);
  $7 = $6;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($5) + 252|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($3)|0);
  if (!($15)) {
   $16 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($3,$14)|0);
   if ($16) {
    $17 = (__Z20scripting_object_newP14ScriptingClass($3)|0);
    $18 = $12 & 255;
    $19 = $0;
    $20 = $19;
    HEAP32[$20>>2] = $9;
    $21 = (($19) + 4)|0;
    $22 = $21;
    HEAP32[$22>>2] = $18;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$0+4>>2]|0;
    __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($actualMethod$i$i14,$17,$$byval_copy6);
    $23 = HEAP32[$actualMethod$i$i14>>2]|0;
    $24 = ($23|0)==(0|0);
    if (!($24)) {
     dest=$$byval_copy6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAP32[$$byval_copy6>>2] = 2800;
     $25 = (($$byval_copy6) + 52|0);
     ;HEAP32[$25+0>>2]=HEAP32[$actualMethod$i$i14+0>>2]|0;HEAP8[$25+4>>0]=HEAP8[$actualMethod$i$i14+4>>0]|0;
     $26 = (($$byval_copy6) + 61|0);
     HEAP8[$26>>0] = 0;
     $27 = (($$byval_copy6) + 60|0);
     HEAP8[$27>>0] = 1;
     __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$$byval_copy6);
    }
   }
  }
 }
 $28 = (__Z26scripting_class_get_parentP14ScriptingClass($3)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$5>>2]|0;
  $31 = ($30|0)==($28|0);
  if (!($31)) {
   $32 = (($5) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==($28|0);
   if (!($34)) {
    $35 = (($5) + 108|0);
    $36 = HEAP32[$35>>2]|0;
    $not$$i = ($36|0)==($28|0);
    if (!($not$$i)) {
     ;HEAP32[$forParent+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$forParent+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$forParent+8>>2]=HEAP32[$args+8>>2]|0;HEAP32[$forParent+12>>2]=HEAP32[$args+12>>2]|0;HEAP32[$forParent+16>>2]=HEAP32[$args+16>>2]|0;
     HEAP32[$forParent>>2] = $28;
     __Z33BuildSerializationCommandQueueForI19StreamedBinaryWriteILb0EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($forParent,$commandQueueBuilder,$localNameConversions,1);
    }
   }
  }
 }
 HEAP32[$fields>>2] = 0;
 $37 = (($fields) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($fields) + 8|0);
 HEAP32[$38>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2702,($3|0),($fields|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L13: do {
  if ($40) {
   label = 22;
  } else {
   $41 = HEAP32[$fields>>2]|0;
   $42 = HEAP32[$37>>2]|0;
   $43 = ($41|0)==($42|0);
   L15: do {
    if (!($43)) {
     $44 = (($tfi) + 24|0);
     $45 = (($tfi) + 8|0);
     $46 = (($tfi) + 12|0);
     $47 = (($tfi) + 4|0);
     $48 = (($tfi) + 16|0);
     $49 = (($tfi) + 20|0);
     $50 = (($args) + 16|0);
     $51 = (($args) + 12|0);
     $52 = (($tfi) + 32|0);
     $53 = (($tfi) + 28|0);
     $54 = (($tfi) + 36|0);
     $56 = $41;
     while(1) {
      $55 = HEAP32[$56>>2]|0;
      dest=$tfi+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
      HEAP32[$tfi>>2] = $55;
      __THREW__ = 0;
      $57 = (invoke_ii(3276,($55|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      HEAP32[$45>>2] = $57;
      __THREW__ = 0;
      $60 = (invoke_ii(3277,($57|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      HEAP32[$46>>2] = $60;
      __THREW__ = 0;
      $63 = (invoke_ii(3278,($57|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      HEAP32[$47>>2] = $63;
      __THREW__ = 0;
      $66 = (invoke_ii(3279,($55|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      HEAP32[$48>>2] = $66;
      __THREW__ = 0;
      $69 = (invoke_ii(3280,($55|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      HEAP32[$49>>2] = $69;
      $72 = HEAPU8[$50>>0]|(HEAPU8[$50+1>>0]<<8);
      HEAP16[$44>>1] = $72;
      $73 = HEAP32[$51>>2]|0;
      HEAP32[$52>>2] = $73;
      HEAP32[$53>>2] = 0;
      $74 = HEAP32[$4>>2]|0;
      HEAP32[$54>>2] = $74;
      __THREW__ = 0;
      $75 = (invoke_iiiiii(202,($commandQueueBuilder|0),($3|0),($73|0),($tfi|0),($74|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      if ($75) {
       __THREW__ = 0;
       invoke_viii(1790,($tfi|0),($commandQueueBuilder|0),($localNameConversions|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break;
       }
      }
      $95 = (($56) + 4|0);
      $96 = HEAP32[$37>>2]|0;
      $97 = ($95|0)==($96|0);
      if ($97) {
       break L15;
      } else {
       $56 = $95;
      }
     }
     $78 = ___cxa_find_matching_catch()|0;
     $79 = tempRet0;
     $lpad$phi$index = $78;$lpad$phi$index2 = $79;
     break L13;
    }
   } while(0);
   if (!($operatingOnBaseClass)) {
    $98 = (($5) + 264|0);
    $99 = $98;
    $100 = $99;
    $101 = HEAP32[$100>>2]|0;
    $102 = (($99) + 4)|0;
    $103 = $102;
    $104 = HEAP32[$103>>2]|0;
    $105 = (($5) + 252|0);
    $106 = HEAP32[$105>>2]|0;
    __THREW__ = 0;
    $107 = (invoke_ii(3281,($3|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     label = 22;
     break;
    }
    if (!($107)) {
     __THREW__ = 0;
     $110 = (invoke_iii(2432,($3|0),($106|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      label = 22;
      break;
     }
     if ($110) {
      __THREW__ = 0;
      $113 = (invoke_ii(3282,($3|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       label = 22;
       break;
      }
      $116 = $104 & 255;
      $117 = $2;
      $118 = $117;
      HEAP32[$118>>2] = $101;
      $119 = (($117) + 4)|0;
      $120 = $119;
      HEAP32[$120>>2] = $116;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;
      invoke_viii(1791,($actualMethod$i$i|0),($113|0),($$byval_copy6|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 22;
       break;
      }
      $123 = HEAP32[$actualMethod$i$i>>2]|0;
      $124 = ($123|0)==(0|0);
      if (!($124)) {
       dest=$invokeMethodCommand$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       HEAP32[$invokeMethodCommand$i$i>>2] = 2800;
       $125 = (($invokeMethodCommand$i$i) + 52|0);
       ;HEAP32[$125+0>>2]=HEAP32[$actualMethod$i$i+0>>2]|0;HEAP8[$125+4>>0]=HEAP8[$actualMethod$i$i+4>>0]|0;
       $126 = (($invokeMethodCommand$i$i) + 61|0);
       HEAP8[$126>>0] = 1;
       $127 = (($invokeMethodCommand$i$i) + 60|0);
       HEAP8[$127>>0] = 0;
       __THREW__ = 0;
       invoke_vii(2801,($commandQueueBuilder|0),($invokeMethodCommand$i$i|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 22;
        break;
       }
      }
     }
    }
   }
   $130 = HEAP32[$fields>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    STACKTOP = sp;return;
   }
   $132 = HEAP32[$37>>2]|0;
   $133 = ($132|0)==($130|0);
   if (!($133)) {
    $__new_last2$i$i$i$i$i = $130;
    $scevgep$i$i$i$i$i = (($132) + -4|0);
    $134 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($134)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $135 = $uglygep3$i$i$i$i$i >>> 2;
    $136 = $135 ^ -1;
    $scevgep4$i$i$i$i$i = (($132) + ($136<<2)|0);
    HEAP32[$37>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($130|0),($$byval_copy6|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $139 = ___cxa_find_matching_catch()|0;
    $140 = tempRet0;
    ___cxa_call_unexpected(($139|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $lpad$phi$index = $80;$lpad$phi$index2 = $81;
 }
 $82 = HEAP32[$fields>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $84 = HEAP32[$37>>2]|0;
 $85 = ($84|0)==($82|0);
 if (!($85)) {
  $__new_last2$i$i$i$i$i5 = $82;
  $scevgep$i$i$i$i$i6 = (($84) + -4|0);
  $86 = (0 - ($__new_last2$i$i$i$i$i5))|0;
  $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($86)|0);
  $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
  $87 = $uglygep3$i$i$i$i$i9 >>> 2;
  $88 = $87 ^ -1;
  $scevgep4$i$i$i$i$i10 = (($84) + ($88<<2)|0);
  HEAP32[$37>>2] = $scevgep4$i$i$i$i$i10;
 }
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy6|0));
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  ___cxa_call_unexpected(($91|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z23TransferScriptingObjectI18StreamedBinaryReadILb0EEEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$instance,$klass,$monoScriptCache) {
 $transfer = $transfer|0;
 $instance = $instance|0;
 $klass = $klass|0;
 $monoScriptCache = $monoScriptCache|0;
 var $$byval_copy6 = 0, $$idx$i$i$i = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandProvider$i = 0, $commandQueueBuilder = 0, $commands$0 = 0, $localNameConversion = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $runtimeInfo$i$i = 0, $transferRequestSignature = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy6 = sp + 96|0;
 $0 = sp;
 $runtimeInfo$i$i = sp + 8|0;
 $commandProvider$i = sp + 32|0;
 $transferRequestSignature = sp + 100|0;
 $localNameConversion = sp + 72|0;
 $commandQueueBuilder = sp + 76|0;
 $args = sp + 52|0;
 $$sroa$1 = sp + 102|0;
 $1 = (($transferRequestSignature) + 1|0);
 HEAP8[$transferRequestSignature>>0] = 1;
 HEAP8[$1>>0] = 0;
 $2 = (__Z19FindCommandsInCachePK15MonoScriptCacheRK24TransferRequestSignature($monoScriptCache,$transferRequestSignature)|0);
 HEAP32[$localNameConversion>>2] = 0;
 HEAP32[$commandQueueBuilder>>2] = 0;
 $3 = (($commandQueueBuilder) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($commandQueueBuilder) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($commandQueueBuilder) + 4|0);
 HEAP32[$5>>2] = 61;
 $6 = (($commandQueueBuilder) + 16|0);
 HEAP8[$6>>0] = 0;
 $7 = ($2|0)==(0|0);
 do {
  if ($7) {
   HEAP32[$args>>2] = $klass;
   $8 = (($args) + 4|0);
   HEAP32[$8>>2] = $klass;
   __THREW__ = 0;
   $9 = (invoke_i(84)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($args) + 8|0);
    $13 = (($9) + 36|0);
    HEAP32[$12>>2] = $13;
    $14 = (($args) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = (($args) + 16|0);
    $16 = HEAP16[$transferRequestSignature>>1]|0;
    HEAP16[$15>>1] = $16;
    __THREW__ = 0;
    invoke_viiii(381,($args|0),($commandQueueBuilder|0),($localNameConversion|0),0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $commands$0 = $commandQueueBuilder;
     label = 10;
     break;
    }
   }
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $lpad$phi$index = $21;$lpad$phi$index2 = $22;
  } else {
   $commands$0 = $2;
   label = 10;
  }
 } while(0);
 L7: do {
  if ((label|0) == 10) {
   $29 = HEAP32[$commands$0>>2]|0;
   $30 = (($commands$0) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + ($31<<6)|0);
   $33 = (($commandProvider$i) + 4|0);
   HEAP32[$33>>2] = $29;
   HEAP32[$commandProvider$i>>2] = $29;
   $34 = (($commandProvider$i) + 8|0);
   HEAP32[$34>>2] = $32;
   $$idx$i$i$i = $31 << 6;
   $35 = $$idx$i$i$i >> 6;
   $36 = (($commandProvider$i) + 16|0);
   HEAP32[$36>>2] = $35;
   $37 = (($commandProvider$i) + 12|0);
   HEAP32[$37>>2] = $35;
   ;HEAP32[$runtimeInfo$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i+20>>2]=0|0;
   $38 = (($runtimeInfo$i$i) + 16|0);
   HEAP32[$38>>2] = $transfer;
   HEAP8[$runtimeInfo$i$i>>0] = 1;
   $39 = (($runtimeInfo$i$i) + 1|0);
   ;HEAP8[$39+0>>0]=HEAP8[$$sroa$1+0>>0]|0;HEAP8[$39+1>>0]=HEAP8[$$sroa$1+1>>0]|0;HEAP8[$39+2>>0]=HEAP8[$$sroa$1+2>>0]|0;
   $40 = (($runtimeInfo$i$i) + 4|0);
   HEAP32[$40>>2] = $instance;
   $41 = (($runtimeInfo$i$i) + 8|0);
   HEAP32[$41>>2] = $klass;
   $42 = (($runtimeInfo$i$i) + 12|0);
   HEAP32[$42>>2] = $commandProvider$i;
   $43 = ($31|0)==(0);
   L9: do {
    if (!($43)) {
     $45 = $29;$47 = $32;
     while(1) {
      $44 = (($45) + 64|0);
      HEAP32[$33>>2] = $44;
      $46 = $47;
      $48 = $44;
      $49 = (($46) - ($48))|0;
      $50 = $49 >> 6;
      HEAP32[$37>>2] = $50;
      $51 = HEAP32[$45>>2]|0;
      $52 = (($45) + 4|0);
      __THREW__ = 0;
      invoke_vii($51|0,($52|0),($runtimeInfo$i$i|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$33>>2]|0;
      $56 = HEAP32[$34>>2]|0;
      $57 = ($55|0)==($56|0);
      if ($57) {
       break L9;
      } else {
       $45 = $55;$47 = $56;
      }
     }
     $19 = ___cxa_find_matching_catch()|0;
     $20 = tempRet0;
     $lpad$phi$index = $19;$lpad$phi$index2 = $20;
     break L7;
    }
   } while(0);
   $58 = HEAP32[$4>>2]|0;
   $59 = ($58|0)>(-1);
   if (!($59)) {
    STACKTOP = sp;return;
   }
   $60 = HEAP32[$commandQueueBuilder>>2]|0;
   $61 = HEAP32[$5>>2]|0;
   HEAP32[$0>>2] = $61;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($60,$$byval_copy6);
   HEAP32[$commandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = HEAP32[$4>>2]|0;
 $24 = ($23|0)>(-1);
 if (!($24)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $25 = HEAP32[$commandQueueBuilder>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $26;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy6|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 }
 HEAP32[$commandQueueBuilder>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z33BuildSerializationCommandQueueForI18StreamedBinaryReadILb0EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($args,$commandQueueBuilder,$localNameConversions,$operatingOnBaseClass) {
 $args = $args|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $localNameConversions = $localNameConversions|0;
 $operatingOnBaseClass = $operatingOnBaseClass|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i5 = 0, $actualMethod$i$i = 0, $actualMethod$i$i14 = 0, $fields = 0, $forParent = 0, $invokeMethodCommand$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $tfi = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy6 = sp + 184|0;
 $actualMethod$i$i14 = sp + 176|0;
 $0 = sp;
 $1 = sp + 168|0;
 $actualMethod$i$i = sp + 160|0;
 $2 = sp + 8|0;
 $invokeMethodCommand$i$i = sp + 40|0;
 $forParent = sp + 16|0;
 $fields = sp + 104|0;
 $tfi = sp + 120|0;
 $3 = HEAP32[$args>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 if (!($operatingOnBaseClass)) {
  $6 = (($5) + 256|0);
  $7 = $6;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($5) + 252|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($3)|0);
  if (!($15)) {
   $16 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($3,$14)|0);
   if ($16) {
    $17 = (__Z20scripting_object_newP14ScriptingClass($3)|0);
    $18 = $12 & 255;
    $19 = $0;
    $20 = $19;
    HEAP32[$20>>2] = $9;
    $21 = (($19) + 4)|0;
    $22 = $21;
    HEAP32[$22>>2] = $18;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$0+4>>2]|0;
    __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($actualMethod$i$i14,$17,$$byval_copy6);
    $23 = HEAP32[$actualMethod$i$i14>>2]|0;
    $24 = ($23|0)==(0|0);
    if (!($24)) {
     dest=$$byval_copy6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAP32[$$byval_copy6>>2] = 2802;
     $25 = (($$byval_copy6) + 52|0);
     ;HEAP32[$25+0>>2]=HEAP32[$actualMethod$i$i14+0>>2]|0;HEAP8[$25+4>>0]=HEAP8[$actualMethod$i$i14+4>>0]|0;
     $26 = (($$byval_copy6) + 61|0);
     HEAP8[$26>>0] = 0;
     $27 = (($$byval_copy6) + 60|0);
     HEAP8[$27>>0] = 1;
     __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$$byval_copy6);
    }
   }
  }
 }
 $28 = (__Z26scripting_class_get_parentP14ScriptingClass($3)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$5>>2]|0;
  $31 = ($30|0)==($28|0);
  if (!($31)) {
   $32 = (($5) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==($28|0);
   if (!($34)) {
    $35 = (($5) + 108|0);
    $36 = HEAP32[$35>>2]|0;
    $not$$i = ($36|0)==($28|0);
    if (!($not$$i)) {
     ;HEAP32[$forParent+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$forParent+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$forParent+8>>2]=HEAP32[$args+8>>2]|0;HEAP32[$forParent+12>>2]=HEAP32[$args+12>>2]|0;HEAP32[$forParent+16>>2]=HEAP32[$args+16>>2]|0;
     HEAP32[$forParent>>2] = $28;
     __Z33BuildSerializationCommandQueueForI18StreamedBinaryReadILb0EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($forParent,$commandQueueBuilder,$localNameConversions,1);
    }
   }
  }
 }
 HEAP32[$fields>>2] = 0;
 $37 = (($fields) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($fields) + 8|0);
 HEAP32[$38>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2702,($3|0),($fields|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L13: do {
  if ($40) {
   label = 22;
  } else {
   $41 = HEAP32[$fields>>2]|0;
   $42 = HEAP32[$37>>2]|0;
   $43 = ($41|0)==($42|0);
   L15: do {
    if (!($43)) {
     $44 = (($tfi) + 24|0);
     $45 = (($tfi) + 8|0);
     $46 = (($tfi) + 12|0);
     $47 = (($tfi) + 4|0);
     $48 = (($tfi) + 16|0);
     $49 = (($tfi) + 20|0);
     $50 = (($args) + 16|0);
     $51 = (($args) + 12|0);
     $52 = (($tfi) + 32|0);
     $53 = (($tfi) + 28|0);
     $54 = (($tfi) + 36|0);
     $56 = $41;
     while(1) {
      $55 = HEAP32[$56>>2]|0;
      dest=$tfi+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
      HEAP32[$tfi>>2] = $55;
      __THREW__ = 0;
      $57 = (invoke_ii(3276,($55|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      HEAP32[$45>>2] = $57;
      __THREW__ = 0;
      $60 = (invoke_ii(3277,($57|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      HEAP32[$46>>2] = $60;
      __THREW__ = 0;
      $63 = (invoke_ii(3278,($57|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      HEAP32[$47>>2] = $63;
      __THREW__ = 0;
      $66 = (invoke_ii(3279,($55|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      HEAP32[$48>>2] = $66;
      __THREW__ = 0;
      $69 = (invoke_ii(3280,($55|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      HEAP32[$49>>2] = $69;
      $72 = HEAPU8[$50>>0]|(HEAPU8[$50+1>>0]<<8);
      HEAP16[$44>>1] = $72;
      $73 = HEAP32[$51>>2]|0;
      HEAP32[$52>>2] = $73;
      HEAP32[$53>>2] = 0;
      $74 = HEAP32[$4>>2]|0;
      HEAP32[$54>>2] = $74;
      __THREW__ = 0;
      $75 = (invoke_iiiiii(202,($commandQueueBuilder|0),($3|0),($73|0),($tfi|0),($74|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      if ($75) {
       __THREW__ = 0;
       invoke_viii(1792,($tfi|0),($commandQueueBuilder|0),($localNameConversions|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break;
       }
      }
      $95 = (($56) + 4|0);
      $96 = HEAP32[$37>>2]|0;
      $97 = ($95|0)==($96|0);
      if ($97) {
       break L15;
      } else {
       $56 = $95;
      }
     }
     $78 = ___cxa_find_matching_catch()|0;
     $79 = tempRet0;
     $lpad$phi$index = $78;$lpad$phi$index2 = $79;
     break L13;
    }
   } while(0);
   if (!($operatingOnBaseClass)) {
    $98 = (($5) + 264|0);
    $99 = $98;
    $100 = $99;
    $101 = HEAP32[$100>>2]|0;
    $102 = (($99) + 4)|0;
    $103 = $102;
    $104 = HEAP32[$103>>2]|0;
    $105 = (($5) + 252|0);
    $106 = HEAP32[$105>>2]|0;
    __THREW__ = 0;
    $107 = (invoke_ii(3281,($3|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     label = 22;
     break;
    }
    if (!($107)) {
     __THREW__ = 0;
     $110 = (invoke_iii(2432,($3|0),($106|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      label = 22;
      break;
     }
     if ($110) {
      __THREW__ = 0;
      $113 = (invoke_ii(3282,($3|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       label = 22;
       break;
      }
      $116 = $104 & 255;
      $117 = $2;
      $118 = $117;
      HEAP32[$118>>2] = $101;
      $119 = (($117) + 4)|0;
      $120 = $119;
      HEAP32[$120>>2] = $116;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;
      invoke_viii(1791,($actualMethod$i$i|0),($113|0),($$byval_copy6|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 22;
       break;
      }
      $123 = HEAP32[$actualMethod$i$i>>2]|0;
      $124 = ($123|0)==(0|0);
      if (!($124)) {
       dest=$invokeMethodCommand$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       HEAP32[$invokeMethodCommand$i$i>>2] = 2802;
       $125 = (($invokeMethodCommand$i$i) + 52|0);
       ;HEAP32[$125+0>>2]=HEAP32[$actualMethod$i$i+0>>2]|0;HEAP8[$125+4>>0]=HEAP8[$actualMethod$i$i+4>>0]|0;
       $126 = (($invokeMethodCommand$i$i) + 61|0);
       HEAP8[$126>>0] = 1;
       $127 = (($invokeMethodCommand$i$i) + 60|0);
       HEAP8[$127>>0] = 0;
       __THREW__ = 0;
       invoke_vii(2801,($commandQueueBuilder|0),($invokeMethodCommand$i$i|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 22;
        break;
       }
      }
     }
    }
   }
   $130 = HEAP32[$fields>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    STACKTOP = sp;return;
   }
   $132 = HEAP32[$37>>2]|0;
   $133 = ($132|0)==($130|0);
   if (!($133)) {
    $__new_last2$i$i$i$i$i = $130;
    $scevgep$i$i$i$i$i = (($132) + -4|0);
    $134 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($134)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $135 = $uglygep3$i$i$i$i$i >>> 2;
    $136 = $135 ^ -1;
    $scevgep4$i$i$i$i$i = (($132) + ($136<<2)|0);
    HEAP32[$37>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($130|0),($$byval_copy6|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $139 = ___cxa_find_matching_catch()|0;
    $140 = tempRet0;
    ___cxa_call_unexpected(($139|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $lpad$phi$index = $80;$lpad$phi$index2 = $81;
 }
 $82 = HEAP32[$fields>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $84 = HEAP32[$37>>2]|0;
 $85 = ($84|0)==($82|0);
 if (!($85)) {
  $__new_last2$i$i$i$i$i5 = $82;
  $scevgep$i$i$i$i$i6 = (($84) + -4|0);
  $86 = (0 - ($__new_last2$i$i$i$i$i5))|0;
  $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($86)|0);
  $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
  $87 = $uglygep3$i$i$i$i$i9 >>> 2;
  $88 = $87 ^ -1;
  $scevgep4$i$i$i$i$i10 = (($84) + ($88<<2)|0);
  HEAP32[$37>>2] = $scevgep4$i$i$i$i$i10;
 }
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy6|0));
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  ___cxa_call_unexpected(($91|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z23TransferScriptingObjectI17RemapPPtrTransferEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$instance,$klass,$monoScriptCache) {
 $transfer = $transfer|0;
 $instance = $instance|0;
 $klass = $klass|0;
 $monoScriptCache = $monoScriptCache|0;
 var $$byval_copy6 = 0, $$idx$i$i$i = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandProvider$i = 0, $commandQueueBuilder = 0, $commands$0 = 0, $localNameConversion = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $runtimeInfo$i$i = 0, $transferRequestSignature = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy6 = sp + 96|0;
 $0 = sp;
 $runtimeInfo$i$i = sp + 8|0;
 $commandProvider$i = sp + 32|0;
 $transferRequestSignature = sp + 100|0;
 $localNameConversion = sp + 72|0;
 $commandQueueBuilder = sp + 76|0;
 $args = sp + 52|0;
 $$sroa$1 = sp + 102|0;
 $1 = (($transferRequestSignature) + 1|0);
 HEAP8[$transferRequestSignature>>0] = 7;
 HEAP8[$1>>0] = 1;
 $2 = (__Z19FindCommandsInCachePK15MonoScriptCacheRK24TransferRequestSignature($monoScriptCache,$transferRequestSignature)|0);
 HEAP32[$localNameConversion>>2] = 0;
 HEAP32[$commandQueueBuilder>>2] = 0;
 $3 = (($commandQueueBuilder) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($commandQueueBuilder) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($commandQueueBuilder) + 4|0);
 HEAP32[$5>>2] = 61;
 $6 = (($commandQueueBuilder) + 16|0);
 HEAP8[$6>>0] = 0;
 $7 = ($2|0)==(0|0);
 do {
  if ($7) {
   HEAP32[$args>>2] = $klass;
   $8 = (($args) + 4|0);
   HEAP32[$8>>2] = $klass;
   __THREW__ = 0;
   $9 = (invoke_i(84)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($args) + 8|0);
    $13 = (($9) + 36|0);
    HEAP32[$12>>2] = $13;
    $14 = (($args) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = (($args) + 16|0);
    $16 = HEAP16[$transferRequestSignature>>1]|0;
    HEAP16[$15>>1] = $16;
    __THREW__ = 0;
    invoke_viiii(384,($args|0),($commandQueueBuilder|0),($localNameConversion|0),0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $commands$0 = $commandQueueBuilder;
     label = 10;
     break;
    }
   }
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $lpad$phi$index = $21;$lpad$phi$index2 = $22;
  } else {
   $commands$0 = $2;
   label = 10;
  }
 } while(0);
 L7: do {
  if ((label|0) == 10) {
   $29 = HEAP32[$commands$0>>2]|0;
   $30 = (($commands$0) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + ($31<<6)|0);
   $33 = (($commandProvider$i) + 4|0);
   HEAP32[$33>>2] = $29;
   HEAP32[$commandProvider$i>>2] = $29;
   $34 = (($commandProvider$i) + 8|0);
   HEAP32[$34>>2] = $32;
   $$idx$i$i$i = $31 << 6;
   $35 = $$idx$i$i$i >> 6;
   $36 = (($commandProvider$i) + 16|0);
   HEAP32[$36>>2] = $35;
   $37 = (($commandProvider$i) + 12|0);
   HEAP32[$37>>2] = $35;
   ;HEAP32[$runtimeInfo$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i+20>>2]=0|0;
   $38 = (($runtimeInfo$i$i) + 16|0);
   HEAP32[$38>>2] = $transfer;
   HEAP8[$runtimeInfo$i$i>>0] = 1;
   $39 = (($runtimeInfo$i$i) + 1|0);
   ;HEAP8[$39+0>>0]=HEAP8[$$sroa$1+0>>0]|0;HEAP8[$39+1>>0]=HEAP8[$$sroa$1+1>>0]|0;HEAP8[$39+2>>0]=HEAP8[$$sroa$1+2>>0]|0;
   $40 = (($runtimeInfo$i$i) + 4|0);
   HEAP32[$40>>2] = $instance;
   $41 = (($runtimeInfo$i$i) + 8|0);
   HEAP32[$41>>2] = $klass;
   $42 = (($runtimeInfo$i$i) + 12|0);
   HEAP32[$42>>2] = $commandProvider$i;
   $43 = ($31|0)==(0);
   L9: do {
    if (!($43)) {
     $45 = $29;$47 = $32;
     while(1) {
      $44 = (($45) + 64|0);
      HEAP32[$33>>2] = $44;
      $46 = $47;
      $48 = $44;
      $49 = (($46) - ($48))|0;
      $50 = $49 >> 6;
      HEAP32[$37>>2] = $50;
      $51 = HEAP32[$45>>2]|0;
      $52 = (($45) + 4|0);
      __THREW__ = 0;
      invoke_vii($51|0,($52|0),($runtimeInfo$i$i|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$33>>2]|0;
      $56 = HEAP32[$34>>2]|0;
      $57 = ($55|0)==($56|0);
      if ($57) {
       break L9;
      } else {
       $45 = $55;$47 = $56;
      }
     }
     $19 = ___cxa_find_matching_catch()|0;
     $20 = tempRet0;
     $lpad$phi$index = $19;$lpad$phi$index2 = $20;
     break L7;
    }
   } while(0);
   $58 = HEAP32[$4>>2]|0;
   $59 = ($58|0)>(-1);
   if (!($59)) {
    STACKTOP = sp;return;
   }
   $60 = HEAP32[$commandQueueBuilder>>2]|0;
   $61 = HEAP32[$5>>2]|0;
   HEAP32[$0>>2] = $61;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($60,$$byval_copy6);
   HEAP32[$commandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = HEAP32[$4>>2]|0;
 $24 = ($23|0)>(-1);
 if (!($24)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $25 = HEAP32[$commandQueueBuilder>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $26;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy6|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 }
 HEAP32[$commandQueueBuilder>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z33BuildSerializationCommandQueueForI17RemapPPtrTransferEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($args,$commandQueueBuilder,$localNameConversions,$operatingOnBaseClass) {
 $args = $args|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $localNameConversions = $localNameConversions|0;
 $operatingOnBaseClass = $operatingOnBaseClass|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i5 = 0, $actualMethod$i$i = 0, $actualMethod$i$i14 = 0, $fields = 0, $forParent = 0, $invokeMethodCommand$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $tfi = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy6 = sp + 184|0;
 $actualMethod$i$i14 = sp + 176|0;
 $0 = sp;
 $1 = sp + 168|0;
 $actualMethod$i$i = sp + 160|0;
 $2 = sp + 8|0;
 $invokeMethodCommand$i$i = sp + 40|0;
 $forParent = sp + 16|0;
 $fields = sp + 104|0;
 $tfi = sp + 120|0;
 $3 = HEAP32[$args>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 if (!($operatingOnBaseClass)) {
  $6 = (($5) + 256|0);
  $7 = $6;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($5) + 252|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($3)|0);
  if (!($15)) {
   $16 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($3,$14)|0);
   if ($16) {
    $17 = (__Z20scripting_object_newP14ScriptingClass($3)|0);
    $18 = $12 & 255;
    $19 = $0;
    $20 = $19;
    HEAP32[$20>>2] = $9;
    $21 = (($19) + 4)|0;
    $22 = $21;
    HEAP32[$22>>2] = $18;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$0+4>>2]|0;
    __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($actualMethod$i$i14,$17,$$byval_copy6);
    $23 = HEAP32[$actualMethod$i$i14>>2]|0;
    $24 = ($23|0)==(0|0);
    if (!($24)) {
     dest=$$byval_copy6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAP32[$$byval_copy6>>2] = 2803;
     $25 = (($$byval_copy6) + 52|0);
     ;HEAP32[$25+0>>2]=HEAP32[$actualMethod$i$i14+0>>2]|0;HEAP8[$25+4>>0]=HEAP8[$actualMethod$i$i14+4>>0]|0;
     $26 = (($$byval_copy6) + 61|0);
     HEAP8[$26>>0] = 0;
     $27 = (($$byval_copy6) + 60|0);
     HEAP8[$27>>0] = 1;
     __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$$byval_copy6);
    }
   }
  }
 }
 $28 = (__Z26scripting_class_get_parentP14ScriptingClass($3)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$5>>2]|0;
  $31 = ($30|0)==($28|0);
  if (!($31)) {
   $32 = (($5) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==($28|0);
   if (!($34)) {
    $35 = (($5) + 108|0);
    $36 = HEAP32[$35>>2]|0;
    $not$$i = ($36|0)==($28|0);
    if (!($not$$i)) {
     ;HEAP32[$forParent+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$forParent+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$forParent+8>>2]=HEAP32[$args+8>>2]|0;HEAP32[$forParent+12>>2]=HEAP32[$args+12>>2]|0;HEAP32[$forParent+16>>2]=HEAP32[$args+16>>2]|0;
     HEAP32[$forParent>>2] = $28;
     __Z33BuildSerializationCommandQueueForI17RemapPPtrTransferEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($forParent,$commandQueueBuilder,$localNameConversions,1);
    }
   }
  }
 }
 HEAP32[$fields>>2] = 0;
 $37 = (($fields) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($fields) + 8|0);
 HEAP32[$38>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2702,($3|0),($fields|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L13: do {
  if ($40) {
   label = 22;
  } else {
   $41 = HEAP32[$fields>>2]|0;
   $42 = HEAP32[$37>>2]|0;
   $43 = ($41|0)==($42|0);
   L15: do {
    if (!($43)) {
     $44 = (($tfi) + 24|0);
     $45 = (($tfi) + 8|0);
     $46 = (($tfi) + 12|0);
     $47 = (($tfi) + 4|0);
     $48 = (($tfi) + 16|0);
     $49 = (($tfi) + 20|0);
     $50 = (($args) + 16|0);
     $51 = (($args) + 12|0);
     $52 = (($tfi) + 32|0);
     $53 = (($tfi) + 28|0);
     $54 = (($tfi) + 36|0);
     $56 = $41;
     while(1) {
      $55 = HEAP32[$56>>2]|0;
      dest=$tfi+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
      HEAP32[$tfi>>2] = $55;
      __THREW__ = 0;
      $57 = (invoke_ii(3276,($55|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      HEAP32[$45>>2] = $57;
      __THREW__ = 0;
      $60 = (invoke_ii(3277,($57|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      HEAP32[$46>>2] = $60;
      __THREW__ = 0;
      $63 = (invoke_ii(3278,($57|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      HEAP32[$47>>2] = $63;
      __THREW__ = 0;
      $66 = (invoke_ii(3279,($55|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      HEAP32[$48>>2] = $66;
      __THREW__ = 0;
      $69 = (invoke_ii(3280,($55|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      HEAP32[$49>>2] = $69;
      $72 = HEAPU8[$50>>0]|(HEAPU8[$50+1>>0]<<8);
      HEAP16[$44>>1] = $72;
      $73 = HEAP32[$51>>2]|0;
      HEAP32[$52>>2] = $73;
      HEAP32[$53>>2] = 0;
      $74 = HEAP32[$4>>2]|0;
      HEAP32[$54>>2] = $74;
      __THREW__ = 0;
      $75 = (invoke_iiiiii(202,($commandQueueBuilder|0),($3|0),($73|0),($tfi|0),($74|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      if ($75) {
       __THREW__ = 0;
       invoke_viii(1793,($tfi|0),($commandQueueBuilder|0),($localNameConversions|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break;
       }
      }
      $95 = (($56) + 4|0);
      $96 = HEAP32[$37>>2]|0;
      $97 = ($95|0)==($96|0);
      if ($97) {
       break L15;
      } else {
       $56 = $95;
      }
     }
     $78 = ___cxa_find_matching_catch()|0;
     $79 = tempRet0;
     $lpad$phi$index = $78;$lpad$phi$index2 = $79;
     break L13;
    }
   } while(0);
   if (!($operatingOnBaseClass)) {
    $98 = (($5) + 264|0);
    $99 = $98;
    $100 = $99;
    $101 = HEAP32[$100>>2]|0;
    $102 = (($99) + 4)|0;
    $103 = $102;
    $104 = HEAP32[$103>>2]|0;
    $105 = (($5) + 252|0);
    $106 = HEAP32[$105>>2]|0;
    __THREW__ = 0;
    $107 = (invoke_ii(3281,($3|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     label = 22;
     break;
    }
    if (!($107)) {
     __THREW__ = 0;
     $110 = (invoke_iii(2432,($3|0),($106|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      label = 22;
      break;
     }
     if ($110) {
      __THREW__ = 0;
      $113 = (invoke_ii(3282,($3|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       label = 22;
       break;
      }
      $116 = $104 & 255;
      $117 = $2;
      $118 = $117;
      HEAP32[$118>>2] = $101;
      $119 = (($117) + 4)|0;
      $120 = $119;
      HEAP32[$120>>2] = $116;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;
      invoke_viii(1791,($actualMethod$i$i|0),($113|0),($$byval_copy6|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 22;
       break;
      }
      $123 = HEAP32[$actualMethod$i$i>>2]|0;
      $124 = ($123|0)==(0|0);
      if (!($124)) {
       dest=$invokeMethodCommand$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       HEAP32[$invokeMethodCommand$i$i>>2] = 2803;
       $125 = (($invokeMethodCommand$i$i) + 52|0);
       ;HEAP32[$125+0>>2]=HEAP32[$actualMethod$i$i+0>>2]|0;HEAP8[$125+4>>0]=HEAP8[$actualMethod$i$i+4>>0]|0;
       $126 = (($invokeMethodCommand$i$i) + 61|0);
       HEAP8[$126>>0] = 1;
       $127 = (($invokeMethodCommand$i$i) + 60|0);
       HEAP8[$127>>0] = 0;
       __THREW__ = 0;
       invoke_vii(2801,($commandQueueBuilder|0),($invokeMethodCommand$i$i|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 22;
        break;
       }
      }
     }
    }
   }
   $130 = HEAP32[$fields>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    STACKTOP = sp;return;
   }
   $132 = HEAP32[$37>>2]|0;
   $133 = ($132|0)==($130|0);
   if (!($133)) {
    $__new_last2$i$i$i$i$i = $130;
    $scevgep$i$i$i$i$i = (($132) + -4|0);
    $134 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($134)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $135 = $uglygep3$i$i$i$i$i >>> 2;
    $136 = $135 ^ -1;
    $scevgep4$i$i$i$i$i = (($132) + ($136<<2)|0);
    HEAP32[$37>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($130|0),($$byval_copy6|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $139 = ___cxa_find_matching_catch()|0;
    $140 = tempRet0;
    ___cxa_call_unexpected(($139|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $lpad$phi$index = $80;$lpad$phi$index2 = $81;
 }
 $82 = HEAP32[$fields>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $84 = HEAP32[$37>>2]|0;
 $85 = ($84|0)==($82|0);
 if (!($85)) {
  $__new_last2$i$i$i$i$i5 = $82;
  $scevgep$i$i$i$i$i6 = (($84) + -4|0);
  $86 = (0 - ($__new_last2$i$i$i$i$i5))|0;
  $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($86)|0);
  $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
  $87 = $uglygep3$i$i$i$i$i9 >>> 2;
  $88 = $87 ^ -1;
  $scevgep4$i$i$i$i$i10 = (($84) + ($88<<2)|0);
  HEAP32[$37>>2] = $scevgep4$i$i$i$i$i10;
 }
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy6|0));
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  ___cxa_call_unexpected(($91|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z23TransferScriptingObjectI13ProxyTransferEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$instance,$klass,$monoScriptCache) {
 $transfer = $transfer|0;
 $instance = $instance|0;
 $klass = $klass|0;
 $monoScriptCache = $monoScriptCache|0;
 var $$byval_copy6 = 0, $$idx$i$i$i = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandProvider$i = 0, $commandQueueBuilder = 0, $commands$0 = 0, $localNameConversion = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $runtimeInfo$i$i = 0, $transferRequestSignature = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy6 = sp + 96|0;
 $0 = sp;
 $runtimeInfo$i$i = sp + 8|0;
 $commandProvider$i = sp + 32|0;
 $transferRequestSignature = sp + 100|0;
 $localNameConversion = sp + 72|0;
 $commandQueueBuilder = sp + 76|0;
 $args = sp + 52|0;
 $$sroa$1 = sp + 102|0;
 $1 = (($transferRequestSignature) + 1|0);
 HEAP8[$transferRequestSignature>>0] = 6;
 HEAP8[$1>>0] = 0;
 $2 = (__Z19FindCommandsInCachePK15MonoScriptCacheRK24TransferRequestSignature($monoScriptCache,$transferRequestSignature)|0);
 HEAP32[$localNameConversion>>2] = 0;
 HEAP32[$commandQueueBuilder>>2] = 0;
 $3 = (($commandQueueBuilder) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($commandQueueBuilder) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($commandQueueBuilder) + 4|0);
 HEAP32[$5>>2] = 61;
 $6 = (($commandQueueBuilder) + 16|0);
 HEAP8[$6>>0] = 0;
 $7 = ($2|0)==(0|0);
 do {
  if ($7) {
   HEAP32[$args>>2] = $klass;
   $8 = (($args) + 4|0);
   HEAP32[$8>>2] = $klass;
   __THREW__ = 0;
   $9 = (invoke_i(84)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($args) + 8|0);
    $13 = (($9) + 36|0);
    HEAP32[$12>>2] = $13;
    $14 = (($args) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = (($args) + 16|0);
    $16 = HEAP16[$transferRequestSignature>>1]|0;
    HEAP16[$15>>1] = $16;
    __THREW__ = 0;
    invoke_viiii(383,($args|0),($commandQueueBuilder|0),($localNameConversion|0),0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $commands$0 = $commandQueueBuilder;
     label = 10;
     break;
    }
   }
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $lpad$phi$index = $21;$lpad$phi$index2 = $22;
  } else {
   $commands$0 = $2;
   label = 10;
  }
 } while(0);
 L7: do {
  if ((label|0) == 10) {
   $29 = HEAP32[$commands$0>>2]|0;
   $30 = (($commands$0) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + ($31<<6)|0);
   $33 = (($commandProvider$i) + 4|0);
   HEAP32[$33>>2] = $29;
   HEAP32[$commandProvider$i>>2] = $29;
   $34 = (($commandProvider$i) + 8|0);
   HEAP32[$34>>2] = $32;
   $$idx$i$i$i = $31 << 6;
   $35 = $$idx$i$i$i >> 6;
   $36 = (($commandProvider$i) + 16|0);
   HEAP32[$36>>2] = $35;
   $37 = (($commandProvider$i) + 12|0);
   HEAP32[$37>>2] = $35;
   ;HEAP32[$runtimeInfo$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i+20>>2]=0|0;
   $38 = (($runtimeInfo$i$i) + 16|0);
   HEAP32[$38>>2] = $transfer;
   HEAP8[$runtimeInfo$i$i>>0] = 1;
   $39 = (($runtimeInfo$i$i) + 1|0);
   ;HEAP8[$39+0>>0]=HEAP8[$$sroa$1+0>>0]|0;HEAP8[$39+1>>0]=HEAP8[$$sroa$1+1>>0]|0;HEAP8[$39+2>>0]=HEAP8[$$sroa$1+2>>0]|0;
   $40 = (($runtimeInfo$i$i) + 4|0);
   HEAP32[$40>>2] = $instance;
   $41 = (($runtimeInfo$i$i) + 8|0);
   HEAP32[$41>>2] = $klass;
   $42 = (($runtimeInfo$i$i) + 12|0);
   HEAP32[$42>>2] = $commandProvider$i;
   $43 = ($31|0)==(0);
   L9: do {
    if (!($43)) {
     $45 = $29;$47 = $32;
     while(1) {
      $44 = (($45) + 64|0);
      HEAP32[$33>>2] = $44;
      $46 = $47;
      $48 = $44;
      $49 = (($46) - ($48))|0;
      $50 = $49 >> 6;
      HEAP32[$37>>2] = $50;
      $51 = HEAP32[$45>>2]|0;
      $52 = (($45) + 4|0);
      __THREW__ = 0;
      invoke_vii($51|0,($52|0),($runtimeInfo$i$i|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$33>>2]|0;
      $56 = HEAP32[$34>>2]|0;
      $57 = ($55|0)==($56|0);
      if ($57) {
       break L9;
      } else {
       $45 = $55;$47 = $56;
      }
     }
     $19 = ___cxa_find_matching_catch()|0;
     $20 = tempRet0;
     $lpad$phi$index = $19;$lpad$phi$index2 = $20;
     break L7;
    }
   } while(0);
   $58 = HEAP32[$4>>2]|0;
   $59 = ($58|0)>(-1);
   if (!($59)) {
    STACKTOP = sp;return;
   }
   $60 = HEAP32[$commandQueueBuilder>>2]|0;
   $61 = HEAP32[$5>>2]|0;
   HEAP32[$0>>2] = $61;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($60,$$byval_copy6);
   HEAP32[$commandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = HEAP32[$4>>2]|0;
 $24 = ($23|0)>(-1);
 if (!($24)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $25 = HEAP32[$commandQueueBuilder>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $26;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy6|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 }
 HEAP32[$commandQueueBuilder>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z33BuildSerializationCommandQueueForI13ProxyTransferEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($args,$commandQueueBuilder,$localNameConversions,$operatingOnBaseClass) {
 $args = $args|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $localNameConversions = $localNameConversions|0;
 $operatingOnBaseClass = $operatingOnBaseClass|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i5 = 0, $actualMethod$i$i = 0, $actualMethod$i$i14 = 0, $fields = 0, $forParent = 0, $invokeMethodCommand$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $tfi = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy6 = sp + 184|0;
 $actualMethod$i$i14 = sp + 176|0;
 $0 = sp;
 $1 = sp + 168|0;
 $actualMethod$i$i = sp + 160|0;
 $2 = sp + 8|0;
 $invokeMethodCommand$i$i = sp + 40|0;
 $forParent = sp + 16|0;
 $fields = sp + 104|0;
 $tfi = sp + 120|0;
 $3 = HEAP32[$args>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 if (!($operatingOnBaseClass)) {
  $6 = (($5) + 256|0);
  $7 = $6;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($5) + 252|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($3)|0);
  if (!($15)) {
   $16 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($3,$14)|0);
   if ($16) {
    $17 = (__Z20scripting_object_newP14ScriptingClass($3)|0);
    $18 = $12 & 255;
    $19 = $0;
    $20 = $19;
    HEAP32[$20>>2] = $9;
    $21 = (($19) + 4)|0;
    $22 = $21;
    HEAP32[$22>>2] = $18;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$0+4>>2]|0;
    __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($actualMethod$i$i14,$17,$$byval_copy6);
    $23 = HEAP32[$actualMethod$i$i14>>2]|0;
    $24 = ($23|0)==(0|0);
    if (!($24)) {
     dest=$$byval_copy6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAP32[$$byval_copy6>>2] = 2804;
     $25 = (($$byval_copy6) + 52|0);
     ;HEAP32[$25+0>>2]=HEAP32[$actualMethod$i$i14+0>>2]|0;HEAP8[$25+4>>0]=HEAP8[$actualMethod$i$i14+4>>0]|0;
     $26 = (($$byval_copy6) + 61|0);
     HEAP8[$26>>0] = 0;
     $27 = (($$byval_copy6) + 60|0);
     HEAP8[$27>>0] = 1;
     __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$$byval_copy6);
    }
   }
  }
 }
 $28 = (__Z26scripting_class_get_parentP14ScriptingClass($3)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$5>>2]|0;
  $31 = ($30|0)==($28|0);
  if (!($31)) {
   $32 = (($5) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==($28|0);
   if (!($34)) {
    $35 = (($5) + 108|0);
    $36 = HEAP32[$35>>2]|0;
    $not$$i = ($36|0)==($28|0);
    if (!($not$$i)) {
     ;HEAP32[$forParent+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$forParent+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$forParent+8>>2]=HEAP32[$args+8>>2]|0;HEAP32[$forParent+12>>2]=HEAP32[$args+12>>2]|0;HEAP32[$forParent+16>>2]=HEAP32[$args+16>>2]|0;
     HEAP32[$forParent>>2] = $28;
     __Z33BuildSerializationCommandQueueForI13ProxyTransferEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($forParent,$commandQueueBuilder,$localNameConversions,1);
    }
   }
  }
 }
 HEAP32[$fields>>2] = 0;
 $37 = (($fields) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($fields) + 8|0);
 HEAP32[$38>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2702,($3|0),($fields|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L13: do {
  if ($40) {
   label = 22;
  } else {
   $41 = HEAP32[$fields>>2]|0;
   $42 = HEAP32[$37>>2]|0;
   $43 = ($41|0)==($42|0);
   L15: do {
    if (!($43)) {
     $44 = (($tfi) + 24|0);
     $45 = (($tfi) + 8|0);
     $46 = (($tfi) + 12|0);
     $47 = (($tfi) + 4|0);
     $48 = (($tfi) + 16|0);
     $49 = (($tfi) + 20|0);
     $50 = (($args) + 16|0);
     $51 = (($args) + 12|0);
     $52 = (($tfi) + 32|0);
     $53 = (($tfi) + 28|0);
     $54 = (($tfi) + 36|0);
     $56 = $41;
     while(1) {
      $55 = HEAP32[$56>>2]|0;
      dest=$tfi+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
      HEAP32[$tfi>>2] = $55;
      __THREW__ = 0;
      $57 = (invoke_ii(3276,($55|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      HEAP32[$45>>2] = $57;
      __THREW__ = 0;
      $60 = (invoke_ii(3277,($57|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      HEAP32[$46>>2] = $60;
      __THREW__ = 0;
      $63 = (invoke_ii(3278,($57|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      HEAP32[$47>>2] = $63;
      __THREW__ = 0;
      $66 = (invoke_ii(3279,($55|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      HEAP32[$48>>2] = $66;
      __THREW__ = 0;
      $69 = (invoke_ii(3280,($55|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      HEAP32[$49>>2] = $69;
      $72 = HEAPU8[$50>>0]|(HEAPU8[$50+1>>0]<<8);
      HEAP16[$44>>1] = $72;
      $73 = HEAP32[$51>>2]|0;
      HEAP32[$52>>2] = $73;
      HEAP32[$53>>2] = 0;
      $74 = HEAP32[$4>>2]|0;
      HEAP32[$54>>2] = $74;
      __THREW__ = 0;
      $75 = (invoke_iiiiii(202,($commandQueueBuilder|0),($3|0),($73|0),($tfi|0),($74|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      if ($75) {
       __THREW__ = 0;
       invoke_viii(1794,($tfi|0),($commandQueueBuilder|0),($localNameConversions|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break;
       }
      }
      $95 = (($56) + 4|0);
      $96 = HEAP32[$37>>2]|0;
      $97 = ($95|0)==($96|0);
      if ($97) {
       break L15;
      } else {
       $56 = $95;
      }
     }
     $78 = ___cxa_find_matching_catch()|0;
     $79 = tempRet0;
     $lpad$phi$index = $78;$lpad$phi$index2 = $79;
     break L13;
    }
   } while(0);
   if (!($operatingOnBaseClass)) {
    $98 = (($5) + 264|0);
    $99 = $98;
    $100 = $99;
    $101 = HEAP32[$100>>2]|0;
    $102 = (($99) + 4)|0;
    $103 = $102;
    $104 = HEAP32[$103>>2]|0;
    $105 = (($5) + 252|0);
    $106 = HEAP32[$105>>2]|0;
    __THREW__ = 0;
    $107 = (invoke_ii(3281,($3|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     label = 22;
     break;
    }
    if (!($107)) {
     __THREW__ = 0;
     $110 = (invoke_iii(2432,($3|0),($106|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      label = 22;
      break;
     }
     if ($110) {
      __THREW__ = 0;
      $113 = (invoke_ii(3282,($3|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       label = 22;
       break;
      }
      $116 = $104 & 255;
      $117 = $2;
      $118 = $117;
      HEAP32[$118>>2] = $101;
      $119 = (($117) + 4)|0;
      $120 = $119;
      HEAP32[$120>>2] = $116;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;
      invoke_viii(1791,($actualMethod$i$i|0),($113|0),($$byval_copy6|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 22;
       break;
      }
      $123 = HEAP32[$actualMethod$i$i>>2]|0;
      $124 = ($123|0)==(0|0);
      if (!($124)) {
       dest=$invokeMethodCommand$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       HEAP32[$invokeMethodCommand$i$i>>2] = 2804;
       $125 = (($invokeMethodCommand$i$i) + 52|0);
       ;HEAP32[$125+0>>2]=HEAP32[$actualMethod$i$i+0>>2]|0;HEAP8[$125+4>>0]=HEAP8[$actualMethod$i$i+4>>0]|0;
       $126 = (($invokeMethodCommand$i$i) + 61|0);
       HEAP8[$126>>0] = 1;
       $127 = (($invokeMethodCommand$i$i) + 60|0);
       HEAP8[$127>>0] = 0;
       __THREW__ = 0;
       invoke_vii(2801,($commandQueueBuilder|0),($invokeMethodCommand$i$i|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 22;
        break;
       }
      }
     }
    }
   }
   $130 = HEAP32[$fields>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    STACKTOP = sp;return;
   }
   $132 = HEAP32[$37>>2]|0;
   $133 = ($132|0)==($130|0);
   if (!($133)) {
    $__new_last2$i$i$i$i$i = $130;
    $scevgep$i$i$i$i$i = (($132) + -4|0);
    $134 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($134)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $135 = $uglygep3$i$i$i$i$i >>> 2;
    $136 = $135 ^ -1;
    $scevgep4$i$i$i$i$i = (($132) + ($136<<2)|0);
    HEAP32[$37>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($130|0),($$byval_copy6|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $139 = ___cxa_find_matching_catch()|0;
    $140 = tempRet0;
    ___cxa_call_unexpected(($139|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $lpad$phi$index = $80;$lpad$phi$index2 = $81;
 }
 $82 = HEAP32[$fields>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $84 = HEAP32[$37>>2]|0;
 $85 = ($84|0)==($82|0);
 if (!($85)) {
  $__new_last2$i$i$i$i$i5 = $82;
  $scevgep$i$i$i$i$i6 = (($84) + -4|0);
  $86 = (0 - ($__new_last2$i$i$i$i$i5))|0;
  $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($86)|0);
  $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
  $87 = $uglygep3$i$i$i$i$i9 >>> 2;
  $88 = $87 ^ -1;
  $scevgep4$i$i$i$i$i10 = (($84) + ($88<<2)|0);
  HEAP32[$37>>2] = $scevgep4$i$i$i$i$i10;
 }
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy6|0));
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  ___cxa_call_unexpected(($91|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z23TransferScriptingObjectI14SafeBinaryReadEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$instance,$klass,$monoScriptCache) {
 $transfer = $transfer|0;
 $instance = $instance|0;
 $klass = $klass|0;
 $monoScriptCache = $monoScriptCache|0;
 var $$byval_copy6 = 0, $$idx$i$i$i = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandProvider$i = 0, $commandQueueBuilder = 0, $commands$0 = 0, $localNameConversion = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $runtimeInfo$i$i = 0, $transferRequestSignature = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy6 = sp + 96|0;
 $0 = sp;
 $runtimeInfo$i$i = sp + 8|0;
 $commandProvider$i = sp + 32|0;
 $transferRequestSignature = sp + 100|0;
 $localNameConversion = sp + 72|0;
 $commandQueueBuilder = sp + 76|0;
 $args = sp + 52|0;
 $$sroa$1 = sp + 102|0;
 $1 = (($transferRequestSignature) + 1|0);
 HEAP8[$transferRequestSignature>>0] = 5;
 HEAP8[$1>>0] = 0;
 $2 = (__Z19FindCommandsInCachePK15MonoScriptCacheRK24TransferRequestSignature($monoScriptCache,$transferRequestSignature)|0);
 HEAP32[$localNameConversion>>2] = 0;
 HEAP32[$commandQueueBuilder>>2] = 0;
 $3 = (($commandQueueBuilder) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($commandQueueBuilder) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($commandQueueBuilder) + 4|0);
 HEAP32[$5>>2] = 61;
 $6 = (($commandQueueBuilder) + 16|0);
 HEAP8[$6>>0] = 0;
 $7 = ($2|0)==(0|0);
 do {
  if ($7) {
   HEAP32[$args>>2] = $klass;
   $8 = (($args) + 4|0);
   HEAP32[$8>>2] = $klass;
   __THREW__ = 0;
   $9 = (invoke_i(84)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($args) + 8|0);
    $13 = (($9) + 36|0);
    HEAP32[$12>>2] = $13;
    $14 = (($args) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = (($args) + 16|0);
    $16 = HEAP16[$transferRequestSignature>>1]|0;
    HEAP16[$15>>1] = $16;
    __THREW__ = 0;
    invoke_viiii(385,($args|0),($commandQueueBuilder|0),($localNameConversion|0),0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $commands$0 = $commandQueueBuilder;
     label = 10;
     break;
    }
   }
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $lpad$phi$index = $21;$lpad$phi$index2 = $22;
  } else {
   $commands$0 = $2;
   label = 10;
  }
 } while(0);
 L7: do {
  if ((label|0) == 10) {
   $29 = HEAP32[$commands$0>>2]|0;
   $30 = (($commands$0) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + ($31<<6)|0);
   $33 = (($commandProvider$i) + 4|0);
   HEAP32[$33>>2] = $29;
   HEAP32[$commandProvider$i>>2] = $29;
   $34 = (($commandProvider$i) + 8|0);
   HEAP32[$34>>2] = $32;
   $$idx$i$i$i = $31 << 6;
   $35 = $$idx$i$i$i >> 6;
   $36 = (($commandProvider$i) + 16|0);
   HEAP32[$36>>2] = $35;
   $37 = (($commandProvider$i) + 12|0);
   HEAP32[$37>>2] = $35;
   ;HEAP32[$runtimeInfo$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i+20>>2]=0|0;
   $38 = (($runtimeInfo$i$i) + 16|0);
   HEAP32[$38>>2] = $transfer;
   HEAP8[$runtimeInfo$i$i>>0] = 1;
   $39 = (($runtimeInfo$i$i) + 1|0);
   ;HEAP8[$39+0>>0]=HEAP8[$$sroa$1+0>>0]|0;HEAP8[$39+1>>0]=HEAP8[$$sroa$1+1>>0]|0;HEAP8[$39+2>>0]=HEAP8[$$sroa$1+2>>0]|0;
   $40 = (($runtimeInfo$i$i) + 4|0);
   HEAP32[$40>>2] = $instance;
   $41 = (($runtimeInfo$i$i) + 8|0);
   HEAP32[$41>>2] = $klass;
   $42 = (($runtimeInfo$i$i) + 12|0);
   HEAP32[$42>>2] = $commandProvider$i;
   $43 = ($31|0)==(0);
   L9: do {
    if (!($43)) {
     $45 = $29;$47 = $32;
     while(1) {
      $44 = (($45) + 64|0);
      HEAP32[$33>>2] = $44;
      $46 = $47;
      $48 = $44;
      $49 = (($46) - ($48))|0;
      $50 = $49 >> 6;
      HEAP32[$37>>2] = $50;
      $51 = HEAP32[$45>>2]|0;
      $52 = (($45) + 4|0);
      __THREW__ = 0;
      invoke_vii($51|0,($52|0),($runtimeInfo$i$i|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$33>>2]|0;
      $56 = HEAP32[$34>>2]|0;
      $57 = ($55|0)==($56|0);
      if ($57) {
       break L9;
      } else {
       $45 = $55;$47 = $56;
      }
     }
     $19 = ___cxa_find_matching_catch()|0;
     $20 = tempRet0;
     $lpad$phi$index = $19;$lpad$phi$index2 = $20;
     break L7;
    }
   } while(0);
   $58 = HEAP32[$4>>2]|0;
   $59 = ($58|0)>(-1);
   if (!($59)) {
    STACKTOP = sp;return;
   }
   $60 = HEAP32[$commandQueueBuilder>>2]|0;
   $61 = HEAP32[$5>>2]|0;
   HEAP32[$0>>2] = $61;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($60,$$byval_copy6);
   HEAP32[$commandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = HEAP32[$4>>2]|0;
 $24 = ($23|0)>(-1);
 if (!($24)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $25 = HEAP32[$commandQueueBuilder>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $26;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy6|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 }
 HEAP32[$commandQueueBuilder>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z33BuildSerializationCommandQueueForI14SafeBinaryReadEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($args,$commandQueueBuilder,$localNameConversions,$operatingOnBaseClass) {
 $args = $args|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $localNameConversions = $localNameConversions|0;
 $operatingOnBaseClass = $operatingOnBaseClass|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i5 = 0, $actualMethod$i$i = 0, $actualMethod$i$i14 = 0, $fields = 0, $forParent = 0, $invokeMethodCommand$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $tfi = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy6 = sp + 184|0;
 $actualMethod$i$i14 = sp + 176|0;
 $0 = sp;
 $1 = sp + 168|0;
 $actualMethod$i$i = sp + 160|0;
 $2 = sp + 8|0;
 $invokeMethodCommand$i$i = sp + 40|0;
 $forParent = sp + 16|0;
 $fields = sp + 104|0;
 $tfi = sp + 120|0;
 $3 = HEAP32[$args>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 if (!($operatingOnBaseClass)) {
  $6 = (($5) + 256|0);
  $7 = $6;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($5) + 252|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($3)|0);
  if (!($15)) {
   $16 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($3,$14)|0);
   if ($16) {
    $17 = (__Z20scripting_object_newP14ScriptingClass($3)|0);
    $18 = $12 & 255;
    $19 = $0;
    $20 = $19;
    HEAP32[$20>>2] = $9;
    $21 = (($19) + 4)|0;
    $22 = $21;
    HEAP32[$22>>2] = $18;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$0+4>>2]|0;
    __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($actualMethod$i$i14,$17,$$byval_copy6);
    $23 = HEAP32[$actualMethod$i$i14>>2]|0;
    $24 = ($23|0)==(0|0);
    if (!($24)) {
     dest=$$byval_copy6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAP32[$$byval_copy6>>2] = 2805;
     $25 = (($$byval_copy6) + 52|0);
     ;HEAP32[$25+0>>2]=HEAP32[$actualMethod$i$i14+0>>2]|0;HEAP8[$25+4>>0]=HEAP8[$actualMethod$i$i14+4>>0]|0;
     $26 = (($$byval_copy6) + 61|0);
     HEAP8[$26>>0] = 0;
     $27 = (($$byval_copy6) + 60|0);
     HEAP8[$27>>0] = 1;
     __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$$byval_copy6);
    }
   }
  }
 }
 $28 = (__Z26scripting_class_get_parentP14ScriptingClass($3)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$5>>2]|0;
  $31 = ($30|0)==($28|0);
  if (!($31)) {
   $32 = (($5) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==($28|0);
   if (!($34)) {
    $35 = (($5) + 108|0);
    $36 = HEAP32[$35>>2]|0;
    $not$$i = ($36|0)==($28|0);
    if (!($not$$i)) {
     ;HEAP32[$forParent+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$forParent+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$forParent+8>>2]=HEAP32[$args+8>>2]|0;HEAP32[$forParent+12>>2]=HEAP32[$args+12>>2]|0;HEAP32[$forParent+16>>2]=HEAP32[$args+16>>2]|0;
     HEAP32[$forParent>>2] = $28;
     __Z33BuildSerializationCommandQueueForI14SafeBinaryReadEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($forParent,$commandQueueBuilder,$localNameConversions,1);
    }
   }
  }
 }
 HEAP32[$fields>>2] = 0;
 $37 = (($fields) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($fields) + 8|0);
 HEAP32[$38>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2702,($3|0),($fields|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L13: do {
  if ($40) {
   label = 22;
  } else {
   $41 = HEAP32[$fields>>2]|0;
   $42 = HEAP32[$37>>2]|0;
   $43 = ($41|0)==($42|0);
   L15: do {
    if (!($43)) {
     $44 = (($tfi) + 24|0);
     $45 = (($tfi) + 8|0);
     $46 = (($tfi) + 12|0);
     $47 = (($tfi) + 4|0);
     $48 = (($tfi) + 16|0);
     $49 = (($tfi) + 20|0);
     $50 = (($args) + 16|0);
     $51 = (($args) + 12|0);
     $52 = (($tfi) + 32|0);
     $53 = (($tfi) + 28|0);
     $54 = (($tfi) + 36|0);
     $56 = $41;
     while(1) {
      $55 = HEAP32[$56>>2]|0;
      dest=$tfi+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
      HEAP32[$tfi>>2] = $55;
      __THREW__ = 0;
      $57 = (invoke_ii(3276,($55|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      HEAP32[$45>>2] = $57;
      __THREW__ = 0;
      $60 = (invoke_ii(3277,($57|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      HEAP32[$46>>2] = $60;
      __THREW__ = 0;
      $63 = (invoke_ii(3278,($57|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      HEAP32[$47>>2] = $63;
      __THREW__ = 0;
      $66 = (invoke_ii(3279,($55|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      HEAP32[$48>>2] = $66;
      __THREW__ = 0;
      $69 = (invoke_ii(3280,($55|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      HEAP32[$49>>2] = $69;
      $72 = HEAPU8[$50>>0]|(HEAPU8[$50+1>>0]<<8);
      HEAP16[$44>>1] = $72;
      $73 = HEAP32[$51>>2]|0;
      HEAP32[$52>>2] = $73;
      HEAP32[$53>>2] = 0;
      $74 = HEAP32[$4>>2]|0;
      HEAP32[$54>>2] = $74;
      __THREW__ = 0;
      $75 = (invoke_iiiiii(202,($commandQueueBuilder|0),($3|0),($73|0),($tfi|0),($74|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      if ($75) {
       __THREW__ = 0;
       invoke_viii(1795,($tfi|0),($commandQueueBuilder|0),($localNameConversions|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break;
       }
      }
      $95 = (($56) + 4|0);
      $96 = HEAP32[$37>>2]|0;
      $97 = ($95|0)==($96|0);
      if ($97) {
       break L15;
      } else {
       $56 = $95;
      }
     }
     $78 = ___cxa_find_matching_catch()|0;
     $79 = tempRet0;
     $lpad$phi$index = $78;$lpad$phi$index2 = $79;
     break L13;
    }
   } while(0);
   if (!($operatingOnBaseClass)) {
    $98 = (($5) + 264|0);
    $99 = $98;
    $100 = $99;
    $101 = HEAP32[$100>>2]|0;
    $102 = (($99) + 4)|0;
    $103 = $102;
    $104 = HEAP32[$103>>2]|0;
    $105 = (($5) + 252|0);
    $106 = HEAP32[$105>>2]|0;
    __THREW__ = 0;
    $107 = (invoke_ii(3281,($3|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     label = 22;
     break;
    }
    if (!($107)) {
     __THREW__ = 0;
     $110 = (invoke_iii(2432,($3|0),($106|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      label = 22;
      break;
     }
     if ($110) {
      __THREW__ = 0;
      $113 = (invoke_ii(3282,($3|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       label = 22;
       break;
      }
      $116 = $104 & 255;
      $117 = $2;
      $118 = $117;
      HEAP32[$118>>2] = $101;
      $119 = (($117) + 4)|0;
      $120 = $119;
      HEAP32[$120>>2] = $116;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;
      invoke_viii(1791,($actualMethod$i$i|0),($113|0),($$byval_copy6|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 22;
       break;
      }
      $123 = HEAP32[$actualMethod$i$i>>2]|0;
      $124 = ($123|0)==(0|0);
      if (!($124)) {
       dest=$invokeMethodCommand$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       HEAP32[$invokeMethodCommand$i$i>>2] = 2805;
       $125 = (($invokeMethodCommand$i$i) + 52|0);
       ;HEAP32[$125+0>>2]=HEAP32[$actualMethod$i$i+0>>2]|0;HEAP8[$125+4>>0]=HEAP8[$actualMethod$i$i+4>>0]|0;
       $126 = (($invokeMethodCommand$i$i) + 61|0);
       HEAP8[$126>>0] = 1;
       $127 = (($invokeMethodCommand$i$i) + 60|0);
       HEAP8[$127>>0] = 0;
       __THREW__ = 0;
       invoke_vii(2801,($commandQueueBuilder|0),($invokeMethodCommand$i$i|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 22;
        break;
       }
      }
     }
    }
   }
   $130 = HEAP32[$fields>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    STACKTOP = sp;return;
   }
   $132 = HEAP32[$37>>2]|0;
   $133 = ($132|0)==($130|0);
   if (!($133)) {
    $__new_last2$i$i$i$i$i = $130;
    $scevgep$i$i$i$i$i = (($132) + -4|0);
    $134 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($134)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $135 = $uglygep3$i$i$i$i$i >>> 2;
    $136 = $135 ^ -1;
    $scevgep4$i$i$i$i$i = (($132) + ($136<<2)|0);
    HEAP32[$37>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($130|0),($$byval_copy6|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $139 = ___cxa_find_matching_catch()|0;
    $140 = tempRet0;
    ___cxa_call_unexpected(($139|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $lpad$phi$index = $80;$lpad$phi$index2 = $81;
 }
 $82 = HEAP32[$fields>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $84 = HEAP32[$37>>2]|0;
 $85 = ($84|0)==($82|0);
 if (!($85)) {
  $__new_last2$i$i$i$i$i5 = $82;
  $scevgep$i$i$i$i$i6 = (($84) + -4|0);
  $86 = (0 - ($__new_last2$i$i$i$i$i5))|0;
  $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($86)|0);
  $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
  $87 = $uglygep3$i$i$i$i$i9 >>> 2;
  $88 = $87 ^ -1;
  $scevgep4$i$i$i$i$i10 = (($84) + ($88<<2)|0);
  HEAP32[$37>>2] = $scevgep4$i$i$i$i$i10;
 }
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy6|0));
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  ___cxa_call_unexpected(($91|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z23TransferScriptingObjectI18StreamedBinaryReadILb1EEEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$instance,$klass,$monoScriptCache) {
 $transfer = $transfer|0;
 $instance = $instance|0;
 $klass = $klass|0;
 $monoScriptCache = $monoScriptCache|0;
 var $$byval_copy6 = 0, $$idx$i$i$i = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandProvider$i = 0, $commandQueueBuilder = 0, $commands$0 = 0, $localNameConversion = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $runtimeInfo$i$i = 0, $transferRequestSignature = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy6 = sp + 96|0;
 $0 = sp;
 $runtimeInfo$i$i = sp + 8|0;
 $commandProvider$i = sp + 32|0;
 $transferRequestSignature = sp + 100|0;
 $localNameConversion = sp + 72|0;
 $commandQueueBuilder = sp + 76|0;
 $args = sp + 52|0;
 $$sroa$1 = sp + 102|0;
 $1 = (($transferRequestSignature) + 1|0);
 HEAP8[$transferRequestSignature>>0] = 2;
 HEAP8[$1>>0] = 0;
 $2 = (__Z19FindCommandsInCachePK15MonoScriptCacheRK24TransferRequestSignature($monoScriptCache,$transferRequestSignature)|0);
 HEAP32[$localNameConversion>>2] = 0;
 HEAP32[$commandQueueBuilder>>2] = 0;
 $3 = (($commandQueueBuilder) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($commandQueueBuilder) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($commandQueueBuilder) + 4|0);
 HEAP32[$5>>2] = 61;
 $6 = (($commandQueueBuilder) + 16|0);
 HEAP8[$6>>0] = 0;
 $7 = ($2|0)==(0|0);
 do {
  if ($7) {
   HEAP32[$args>>2] = $klass;
   $8 = (($args) + 4|0);
   HEAP32[$8>>2] = $klass;
   __THREW__ = 0;
   $9 = (invoke_i(84)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($args) + 8|0);
    $13 = (($9) + 36|0);
    HEAP32[$12>>2] = $13;
    $14 = (($args) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = (($args) + 16|0);
    $16 = HEAP16[$transferRequestSignature>>1]|0;
    HEAP16[$15>>1] = $16;
    __THREW__ = 0;
    invoke_viiii(386,($args|0),($commandQueueBuilder|0),($localNameConversion|0),0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $commands$0 = $commandQueueBuilder;
     label = 10;
     break;
    }
   }
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $lpad$phi$index = $21;$lpad$phi$index2 = $22;
  } else {
   $commands$0 = $2;
   label = 10;
  }
 } while(0);
 L7: do {
  if ((label|0) == 10) {
   $29 = HEAP32[$commands$0>>2]|0;
   $30 = (($commands$0) + 8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + ($31<<6)|0);
   $33 = (($commandProvider$i) + 4|0);
   HEAP32[$33>>2] = $29;
   HEAP32[$commandProvider$i>>2] = $29;
   $34 = (($commandProvider$i) + 8|0);
   HEAP32[$34>>2] = $32;
   $$idx$i$i$i = $31 << 6;
   $35 = $$idx$i$i$i >> 6;
   $36 = (($commandProvider$i) + 16|0);
   HEAP32[$36>>2] = $35;
   $37 = (($commandProvider$i) + 12|0);
   HEAP32[$37>>2] = $35;
   ;HEAP32[$runtimeInfo$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i+20>>2]=0|0;
   $38 = (($runtimeInfo$i$i) + 16|0);
   HEAP32[$38>>2] = $transfer;
   HEAP8[$runtimeInfo$i$i>>0] = 1;
   $39 = (($runtimeInfo$i$i) + 1|0);
   ;HEAP8[$39+0>>0]=HEAP8[$$sroa$1+0>>0]|0;HEAP8[$39+1>>0]=HEAP8[$$sroa$1+1>>0]|0;HEAP8[$39+2>>0]=HEAP8[$$sroa$1+2>>0]|0;
   $40 = (($runtimeInfo$i$i) + 4|0);
   HEAP32[$40>>2] = $instance;
   $41 = (($runtimeInfo$i$i) + 8|0);
   HEAP32[$41>>2] = $klass;
   $42 = (($runtimeInfo$i$i) + 12|0);
   HEAP32[$42>>2] = $commandProvider$i;
   $43 = ($31|0)==(0);
   L9: do {
    if (!($43)) {
     $45 = $29;$47 = $32;
     while(1) {
      $44 = (($45) + 64|0);
      HEAP32[$33>>2] = $44;
      $46 = $47;
      $48 = $44;
      $49 = (($46) - ($48))|0;
      $50 = $49 >> 6;
      HEAP32[$37>>2] = $50;
      $51 = HEAP32[$45>>2]|0;
      $52 = (($45) + 4|0);
      __THREW__ = 0;
      invoke_vii($51|0,($52|0),($runtimeInfo$i$i|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$33>>2]|0;
      $56 = HEAP32[$34>>2]|0;
      $57 = ($55|0)==($56|0);
      if ($57) {
       break L9;
      } else {
       $45 = $55;$47 = $56;
      }
     }
     $19 = ___cxa_find_matching_catch()|0;
     $20 = tempRet0;
     $lpad$phi$index = $19;$lpad$phi$index2 = $20;
     break L7;
    }
   } while(0);
   $58 = HEAP32[$4>>2]|0;
   $59 = ($58|0)>(-1);
   if (!($59)) {
    STACKTOP = sp;return;
   }
   $60 = HEAP32[$commandQueueBuilder>>2]|0;
   $61 = HEAP32[$5>>2]|0;
   HEAP32[$0>>2] = $61;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($60,$$byval_copy6);
   HEAP32[$commandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = HEAP32[$4>>2]|0;
 $24 = ($23|0)>(-1);
 if (!($24)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $25 = HEAP32[$commandQueueBuilder>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $26;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy6|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $62 = ___cxa_find_matching_catch(0|0)|0;
  $63 = tempRet0;
  ___clang_call_terminate($62);
  // unreachable;
 }
 HEAP32[$commandQueueBuilder>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z33BuildSerializationCommandQueueForI18StreamedBinaryReadILb1EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($args,$commandQueueBuilder,$localNameConversions,$operatingOnBaseClass) {
 $args = $args|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $localNameConversions = $localNameConversions|0;
 $operatingOnBaseClass = $operatingOnBaseClass|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i5 = 0, $actualMethod$i$i = 0, $actualMethod$i$i14 = 0, $fields = 0, $forParent = 0, $invokeMethodCommand$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $tfi = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy6 = sp + 184|0;
 $actualMethod$i$i14 = sp + 176|0;
 $0 = sp;
 $1 = sp + 168|0;
 $actualMethod$i$i = sp + 160|0;
 $2 = sp + 8|0;
 $invokeMethodCommand$i$i = sp + 40|0;
 $forParent = sp + 16|0;
 $fields = sp + 104|0;
 $tfi = sp + 120|0;
 $3 = HEAP32[$args>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 if (!($operatingOnBaseClass)) {
  $6 = (($5) + 256|0);
  $7 = $6;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($5) + 252|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($3)|0);
  if (!($15)) {
   $16 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($3,$14)|0);
   if ($16) {
    $17 = (__Z20scripting_object_newP14ScriptingClass($3)|0);
    $18 = $12 & 255;
    $19 = $0;
    $20 = $19;
    HEAP32[$20>>2] = $9;
    $21 = (($19) + 4)|0;
    $22 = $21;
    HEAP32[$22>>2] = $18;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$0+4>>2]|0;
    __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($actualMethod$i$i14,$17,$$byval_copy6);
    $23 = HEAP32[$actualMethod$i$i14>>2]|0;
    $24 = ($23|0)==(0|0);
    if (!($24)) {
     dest=$$byval_copy6+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     HEAP32[$$byval_copy6>>2] = 2806;
     $25 = (($$byval_copy6) + 52|0);
     ;HEAP32[$25+0>>2]=HEAP32[$actualMethod$i$i14+0>>2]|0;HEAP8[$25+4>>0]=HEAP8[$actualMethod$i$i14+4>>0]|0;
     $26 = (($$byval_copy6) + 61|0);
     HEAP8[$26>>0] = 0;
     $27 = (($$byval_copy6) + 60|0);
     HEAP8[$27>>0] = 1;
     __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$$byval_copy6);
    }
   }
  }
 }
 $28 = (__Z26scripting_class_get_parentP14ScriptingClass($3)|0);
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = HEAP32[$5>>2]|0;
  $31 = ($30|0)==($28|0);
  if (!($31)) {
   $32 = (($5) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==($28|0);
   if (!($34)) {
    $35 = (($5) + 108|0);
    $36 = HEAP32[$35>>2]|0;
    $not$$i = ($36|0)==($28|0);
    if (!($not$$i)) {
     ;HEAP32[$forParent+0>>2]=HEAP32[$args+0>>2]|0;HEAP32[$forParent+4>>2]=HEAP32[$args+4>>2]|0;HEAP32[$forParent+8>>2]=HEAP32[$args+8>>2]|0;HEAP32[$forParent+12>>2]=HEAP32[$args+12>>2]|0;HEAP32[$forParent+16>>2]=HEAP32[$args+16>>2]|0;
     HEAP32[$forParent>>2] = $28;
     __Z33BuildSerializationCommandQueueForI18StreamedBinaryReadILb1EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb($forParent,$commandQueueBuilder,$localNameConversions,1);
    }
   }
  }
 }
 HEAP32[$fields>>2] = 0;
 $37 = (($fields) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($fields) + 8|0);
 HEAP32[$38>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2702,($3|0),($fields|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 L13: do {
  if ($40) {
   label = 22;
  } else {
   $41 = HEAP32[$fields>>2]|0;
   $42 = HEAP32[$37>>2]|0;
   $43 = ($41|0)==($42|0);
   L15: do {
    if (!($43)) {
     $44 = (($tfi) + 24|0);
     $45 = (($tfi) + 8|0);
     $46 = (($tfi) + 12|0);
     $47 = (($tfi) + 4|0);
     $48 = (($tfi) + 16|0);
     $49 = (($tfi) + 20|0);
     $50 = (($args) + 16|0);
     $51 = (($args) + 12|0);
     $52 = (($tfi) + 32|0);
     $53 = (($tfi) + 28|0);
     $54 = (($tfi) + 36|0);
     $56 = $41;
     while(1) {
      $55 = HEAP32[$56>>2]|0;
      dest=$tfi+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
      HEAP32[$tfi>>2] = $55;
      __THREW__ = 0;
      $57 = (invoke_ii(3276,($55|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      HEAP32[$45>>2] = $57;
      __THREW__ = 0;
      $60 = (invoke_ii(3277,($57|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      HEAP32[$46>>2] = $60;
      __THREW__ = 0;
      $63 = (invoke_ii(3278,($57|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      HEAP32[$47>>2] = $63;
      __THREW__ = 0;
      $66 = (invoke_ii(3279,($55|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      HEAP32[$48>>2] = $66;
      __THREW__ = 0;
      $69 = (invoke_ii(3280,($55|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      HEAP32[$49>>2] = $69;
      $72 = HEAPU8[$50>>0]|(HEAPU8[$50+1>>0]<<8);
      HEAP16[$44>>1] = $72;
      $73 = HEAP32[$51>>2]|0;
      HEAP32[$52>>2] = $73;
      HEAP32[$53>>2] = 0;
      $74 = HEAP32[$4>>2]|0;
      HEAP32[$54>>2] = $74;
      __THREW__ = 0;
      $75 = (invoke_iiiiii(202,($commandQueueBuilder|0),($3|0),($73|0),($tfi|0),($74|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      if ($75) {
       __THREW__ = 0;
       invoke_viii(1796,($tfi|0),($commandQueueBuilder|0),($localNameConversions|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break;
       }
      }
      $95 = (($56) + 4|0);
      $96 = HEAP32[$37>>2]|0;
      $97 = ($95|0)==($96|0);
      if ($97) {
       break L15;
      } else {
       $56 = $95;
      }
     }
     $78 = ___cxa_find_matching_catch()|0;
     $79 = tempRet0;
     $lpad$phi$index = $78;$lpad$phi$index2 = $79;
     break L13;
    }
   } while(0);
   if (!($operatingOnBaseClass)) {
    $98 = (($5) + 264|0);
    $99 = $98;
    $100 = $99;
    $101 = HEAP32[$100>>2]|0;
    $102 = (($99) + 4)|0;
    $103 = $102;
    $104 = HEAP32[$103>>2]|0;
    $105 = (($5) + 252|0);
    $106 = HEAP32[$105>>2]|0;
    __THREW__ = 0;
    $107 = (invoke_ii(3281,($3|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     label = 22;
     break;
    }
    if (!($107)) {
     __THREW__ = 0;
     $110 = (invoke_iii(2432,($3|0),($106|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      label = 22;
      break;
     }
     if ($110) {
      __THREW__ = 0;
      $113 = (invoke_ii(3282,($3|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       label = 22;
       break;
      }
      $116 = $104 & 255;
      $117 = $2;
      $118 = $117;
      HEAP32[$118>>2] = $101;
      $119 = (($117) + 4)|0;
      $120 = $119;
      HEAP32[$120>>2] = $116;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$2+4>>2]|0;
      invoke_viii(1791,($actualMethod$i$i|0),($113|0),($$byval_copy6|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 22;
       break;
      }
      $123 = HEAP32[$actualMethod$i$i>>2]|0;
      $124 = ($123|0)==(0|0);
      if (!($124)) {
       dest=$invokeMethodCommand$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       HEAP32[$invokeMethodCommand$i$i>>2] = 2806;
       $125 = (($invokeMethodCommand$i$i) + 52|0);
       ;HEAP32[$125+0>>2]=HEAP32[$actualMethod$i$i+0>>2]|0;HEAP8[$125+4>>0]=HEAP8[$actualMethod$i$i+4>>0]|0;
       $126 = (($invokeMethodCommand$i$i) + 61|0);
       HEAP8[$126>>0] = 1;
       $127 = (($invokeMethodCommand$i$i) + 60|0);
       HEAP8[$127>>0] = 0;
       __THREW__ = 0;
       invoke_vii(2801,($commandQueueBuilder|0),($invokeMethodCommand$i$i|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 22;
        break;
       }
      }
     }
    }
   }
   $130 = HEAP32[$fields>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    STACKTOP = sp;return;
   }
   $132 = HEAP32[$37>>2]|0;
   $133 = ($132|0)==($130|0);
   if (!($133)) {
    $__new_last2$i$i$i$i$i = $130;
    $scevgep$i$i$i$i$i = (($132) + -4|0);
    $134 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($134)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $135 = $uglygep3$i$i$i$i$i >>> 2;
    $136 = $135 ^ -1;
    $scevgep4$i$i$i$i$i = (($132) + ($136<<2)|0);
    HEAP32[$37>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($130|0),($$byval_copy6|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $139 = ___cxa_find_matching_catch()|0;
    $140 = tempRet0;
    ___cxa_call_unexpected(($139|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $lpad$phi$index = $80;$lpad$phi$index2 = $81;
 }
 $82 = HEAP32[$fields>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $84 = HEAP32[$37>>2]|0;
 $85 = ($84|0)==($82|0);
 if (!($85)) {
  $__new_last2$i$i$i$i$i5 = $82;
  $scevgep$i$i$i$i$i6 = (($84) + -4|0);
  $86 = (0 - ($__new_last2$i$i$i$i$i5))|0;
  $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($86)|0);
  $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
  $87 = $uglygep3$i$i$i$i$i9 >>> 2;
  $88 = $87 ^ -1;
  $scevgep4$i$i$i$i$i10 = (($84) + ($88<<2)|0);
  HEAP32[$37>>2] = $scevgep4$i$i$i$i$i10;
 }
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy6|0));
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  ___cxa_call_unexpected(($91|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19ShouldTransferFieldR32SerializationCommandQueueBuilderP14ScriptingClassiR18TransferField_InfoRK22CommonScriptingClasses($commandQueueBuilder,$klass,$depthCounter,$tfi,$commonClasses) {
 $commandQueueBuilder = $commandQueueBuilder|0;
 $klass = $klass|0;
 $depthCounter = $depthCounter|0;
 $tfi = $tfi|0;
 $commonClasses = $commonClasses|0;
 var $$0 = 0, $$0$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0;
 var $full_name$i = 0, $strchr = 0, $strlenfirst$i = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer2 = sp;
 $full_name$i = sp + 32|0;
 $0 = sp + 8|0;
 $1 = sp + 20|0;
 $2 = (($tfi) + 28|0);
 HEAP32[$2>>2] = 2048;
 $3 = (($tfi) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 176;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($tfi) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(18);
 if ($9) {
  $10 = (($tfi) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__Z41scripting_type_get_class_or_element_classP13ScriptingType($11)|0);
  $13 = (($commonClasses) + 136|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($12,$14)|0);
  if ($15) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $16 = (($tfi) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$tfi>>2]|0;
  $19 = (__Z26scripting_field_get_parentP14ScriptingField($18)|0);
  $20 = ($17|0)==($19|0);
  if ($20) {
   $21 = HEAP32[$16>>2]|0;
   $22 = (($commonClasses) + 244|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($21,$23)|0);
   if (!($24)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $25 = ($depthCounter|0)>(7);
 do {
  if ($25) {
   $26 = HEAP32[$7>>2]|0;
   $27 = ($26|0)==(18);
   if (!($27)) {
    $28 = (($tfi) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (__Z24scripting_class_get_typeP14ScriptingClass($29)|0);
    $31 = (__Z23scripting_type_get_typeP13ScriptingType($30)|0);
    $32 = ($31|0)==(29);
    if (!($32)) {
     $33 = (__ZN9Scripting30IsSystemCollectionsGenericListEP14ScriptingClass($29)|0);
     if (!($33)) {
      break;
     }
    }
   }
   $34 = (($commandQueueBuilder) + 16|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)==(0);
   if (!($36)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (__Z29scripting_class_get_namespaceP14ScriptingClass($klass)|0);
   $38 = (__Z24scripting_class_get_nameP14ScriptingClass($klass)|0);
   $39 = (_strlen(($38|0))|0);
   $40 = ($39>>>0)>(4294967279);
   if ($40) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $41 = ($39>>>0)<(11);
   if ($41) {
    $42 = $39 << 1;
    $43 = $42&255;
    HEAP8[$full_name$i>>0] = $43;
    $44 = (($full_name$i) + 1|0);
    $__p$0$i$i$i$i = $44;
   } else {
    $45 = (($39) + 16)|0;
    $46 = $45 & -16;
    $47 = (__Znwj($46)|0);
    $48 = (($full_name$i) + 8|0);
    HEAP32[$48>>2] = $47;
    $49 = $46 | 1;
    HEAP32[$full_name$i>>2] = $49;
    $50 = (($full_name$i) + 4|0);
    HEAP32[$50>>2] = $39;
    $__p$0$i$i$i$i = $47;
   }
   _memcpy(($__p$0$i$i$i$i|0),($38|0),($39|0))|0;
   $51 = (($__p$0$i$i$i$i) + ($39)|0);
   HEAP8[$51>>0] = 0;
   $52 = ($37|0)==(0|0);
   do {
    if ($52) {
     label = 25;
    } else {
     $strlenfirst$i = HEAP8[$37>>0]|0;
     $53 = ($strlenfirst$i<<24>>24)==(0);
     if ($53) {
      label = 25;
     } else {
      __THREW__ = 0;
      HEAP32[$vararg_buffer2>>2] = $37;
      $vararg_ptr1 = (($vararg_buffer2) + 4|0);
      HEAP32[$vararg_ptr1>>2] = $38;
      invoke_viii(1617,($0|0),(631288|0),($vararg_buffer2|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 22;
      } else {
       __THREW__ = 0;
       (invoke_iii(2233,($full_name$i|0),($0|0))|0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        $65 = ___cxa_find_matching_catch()|0;
        $66 = tempRet0;
        $67 = HEAP8[$0>>0]|0;
        $68 = $67 & 1;
        $69 = ($68<<24>>24)==(0);
        if ($69) {
         $$0$i = $66;$$01$i = $65;
         break;
        }
        $70 = (($0) + 8|0);
        $71 = HEAP32[$70>>2]|0;
        __ZdlPv($71);
        $$0$i = $66;$$01$i = $65;
        break;
       } else {
        $58 = HEAP8[$0>>0]|0;
        $59 = $58 & 1;
        $60 = ($59<<24>>24)==(0);
        if ($60) {
         label = 25;
         break;
        }
        $61 = (($0) + 8|0);
        $62 = HEAP32[$61>>2]|0;
        __ZdlPv($62);
        label = 25;
        break;
       }
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 25) {
     __THREW__ = 0;
     $72 = (invoke_i(84)|0);
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      label = 22;
     } else {
      $75 = (($72) + 24|0);
      __THREW__ = 0;
      $76 = (invoke_iii(2420,($75|0),($klass|0))|0);
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       label = 22;
      } else {
       $79 = HEAP8[$full_name$i>>0]|0;
       $80 = $79 & 1;
       $81 = ($80<<24>>24)==(0);
       if ($81) {
        $84 = (($full_name$i) + 1|0);
        $85 = $84;
       } else {
        $82 = (($full_name$i) + 8|0);
        $83 = HEAP32[$82>>2]|0;
        $85 = $83;
       }
       __THREW__ = 0;
       HEAP32[$vararg_buffer2>>2] = $85;
       invoke_viii(1617,($1|0),(631296|0),($vararg_buffer2|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        label = 22;
       } else {
        $88 = ($76|0)==(0|0);
        if ($88) {
         $98 = 0;
        } else {
         $89 = (($76) + 4|0);
         $90 = HEAP32[$89>>2]|0;
         $98 = $90;
        }
        $91 = HEAP8[$1>>0]|0;
        $92 = $91 & 1;
        $93 = ($92<<24>>24)==(0);
        if ($93) {
         $96 = (($1) + 1|0);
         $97 = $96;
        } else {
         $94 = (($1) + 8|0);
         $95 = HEAP32[$94>>2]|0;
         $97 = $95;
        }
        __THREW__ = 0;
        invoke_viiiiiiii(21,($97|0),0,(630440|0),67,1,($98|0),0,(0|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         $111 = ___cxa_find_matching_catch()|0;
         $112 = tempRet0;
         $113 = HEAP8[$1>>0]|0;
         $114 = $113 & 1;
         $115 = ($114<<24>>24)==(0);
         if ($115) {
          $$0$i = $112;$$01$i = $111;
          break;
         }
         $116 = (($1) + 8|0);
         $117 = HEAP32[$116>>2]|0;
         __ZdlPv($117);
         $$0$i = $112;$$01$i = $111;
         break;
        }
        $101 = HEAP8[$1>>0]|0;
        $102 = $101 & 1;
        $103 = ($102<<24>>24)==(0);
        if (!($103)) {
         $104 = (($1) + 8|0);
         $105 = HEAP32[$104>>2]|0;
         __ZdlPv($105);
        }
        $106 = HEAP8[$full_name$i>>0]|0;
        $107 = $106 & 1;
        $108 = ($107<<24>>24)==(0);
        if (!($108)) {
         $109 = (($full_name$i) + 8|0);
         $110 = HEAP32[$109>>2]|0;
         __ZdlPv($110);
        }
        HEAP8[$34>>0] = 1;
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 22) {
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    $$0$i = $64;$$01$i = $63;
   }
   $118 = HEAP8[$full_name$i>>0]|0;
   $119 = $118 & 1;
   $120 = ($119<<24>>24)==(0);
   if ($120) {
    ___resumeException($$01$i|0);
    // unreachable;
   }
   $121 = (($full_name$i) + 8|0);
   $122 = HEAP32[$121>>2]|0;
   __ZdlPv($122);
   ___resumeException($$01$i|0);
   // unreachable;
  }
 } while(0);
 $123 = (($tfi) + 20|0);
 $124 = HEAP32[$123>>2]|0;
 $strchr = (_strchr($124,46)|0);
 $125 = ($strchr|0)==(0|0);
 if (!($125)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $126 = HEAP32[$3>>2]|0;
 $127 = (__ZN9Scripting18IsFieldFlagsPublicEi($126)|0);
 if ($127) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $128 = (__Z19GetScriptingManagerv()|0);
 $129 = (($128) + 284|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (__Z29scripting_class_has_attributeP14ScriptingClassS0_($klass,$130)|0);
 if ($131) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $132 = HEAP32[$tfi>>2]|0;
  $133 = (($commonClasses) + 92|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = (__Z29scripting_field_has_attributeP14ScriptingClassP14ScriptingFieldS0_($klass,$132,$134)|0);
  STACKTOP = sp;return ($135|0);
 }
 return 0|0;
}
function __Z26Transfer_UnityEngineObjectI13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, $pptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $buffer = sp + 16|0;
 $pptr = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$pptr>>2] = 0;
 $2 = (($pptr) + 4|0);
 $3 = (($pptr) + 8|0);
 HEAP32[$2>>2] = $buffer;
 $4 = (($args) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 $6 = (($args) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN13ProxyTransfer8TransferI8MonoPPtrEEvRT_PKc17TransferMetaFlags($1,$pptr,$7,$9);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI8MonoPPtrEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0$lcssa$i$i = 0, $c$01$i$i = 0;
 var $className$02$i$i = 0, $localIdentifier$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i = sp;
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i = 630432;
 } else {
  $3 = (($data) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 1|0);
  HEAP8[$1>>0] = 80;
  $6 = (($1) + 2|0);
  HEAP8[$5>>0] = 80;
  $7 = (($1) + 3|0);
  HEAP8[$6>>0] = 116;
  $8 = (($1) + 4|0);
  HEAP8[$7>>0] = 114;
  $9 = (($1) + 5|0);
  HEAP8[$8>>0] = 60;
  $10 = (($1) + 6|0);
  HEAP8[$9>>0] = 36;
  $11 = (__Z24scripting_class_get_nameP14ScriptingClass($4)|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $c$0$lcssa$i$i = $10;
  } else {
   $14 = $12;$c$01$i$i = $10;$className$02$i$i = $11;
   while(1) {
    HEAP8[$c$01$i$i>>0] = $14;
    $15 = (($c$01$i$i) + 1|0);
    $16 = (($className$02$i$i) + 1|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     $c$0$lcssa$i$i = $15;
     break;
    } else {
     $14 = $17;$c$01$i$i = $15;$className$02$i$i = $16;
    }
   }
  }
  $19 = (($c$0$lcssa$i$i) + 1|0);
  HEAP8[$c$0$lcssa$i$i>>0] = 62;
  HEAP8[$19>>0] = 0;
  $$0$i = $1;
 }
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$$0$i,$data,$metaFlag);
 $20 = (($localIdentifier$i$i) + 8|0);
 $21 = $20;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = 0;
 HEAP32[$localIdentifier$i$i>>2] = 0;
 $25 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,630400,$25,$data,1);
 $26 = (($this) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($28) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $32 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,630416,$32,$20,1);
 $33 = HEAP32[$26>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$29>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i1 = 0, $buffer = 0, $dummyvector = 0, $monopptr = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $size$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $size$i = sp + 24|0;
 $buffer = sp + 32|0;
 $monopptr = sp + 12|0;
 $dummyvector = sp;
 HEAP32[$monopptr>>2] = 0;
 $0 = (($monopptr) + 4|0);
 $1 = (($monopptr) + 8|0);
 HEAP32[$0>>2] = $buffer;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$1>>2] = $3;
 HEAP32[$dummyvector>>2] = 0;
 $4 = (($dummyvector) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($dummyvector) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[580760>>2]|0;
 $11 = (($args) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($7|0),($9|0),($10|0),($dummyvector|0),($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  __THREW__ = 0;
  invoke_viiiii(87,($7|0),(630368|0),(630368|0),($size$i|0),0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   invoke_viiii(387,($7|0),($monopptr|0),(630376|0),0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    invoke_vi(3391,($7|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     invoke_vi(3390,($7|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = HEAP32[$dummyvector>>2]|0;
      $24 = ($23|0)==(0|0);
      if ($24) {
       STACKTOP = sp;return;
      }
      $25 = HEAP32[$4>>2]|0;
      $26 = ($25|0)==($23|0);
      if (!($26)) {
       $__new_last2$i$i$i$i$i1 = $23;
       $scevgep$i$i$i$i$i2 = (($25) + -12|0);
       $27 = (0 - ($__new_last2$i$i$i$i$i1))|0;
       $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($27)|0);
       $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
       $28 = (($uglygep3$i$i$i$i$i5>>>0) / 12)&-1;
       $29 = $28 ^ -1;
       $scevgep4$i$i$i$i$i6 = (($25) + (($29*12)|0)|0);
       HEAP32[$4>>2] = $scevgep4$i$i$i$i$i6;
      }
      __ZdlPv($23);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 $32 = HEAP32[$dummyvector>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  ___resumeException($30|0);
  // unreachable;
 }
 $34 = HEAP32[$4>>2]|0;
 $35 = ($34|0)==($32|0);
 if (!($35)) {
  $__new_last2$i$i$i$i$i = $32;
  $scevgep$i$i$i$i$i = (($34) + -12|0);
  $36 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($36)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $37 = (($uglygep3$i$i$i$i$i>>>0) / 12)&-1;
  $38 = $37 ^ -1;
  $scevgep4$i$i$i$i$i = (($34) + (($38*12)|0)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($32);
 ___resumeException($30|0);
 // unreachable;
}
function __ZN13ProxyTransfer32TransferSTLStyleArrayWithElementI23ManagedObjectTransfererEEvRT_17TransferMetaFlags($this,$elementType,$metaFlag) {
 $this = $this|0;
 $elementType = $elementType|0;
 $metaFlag = $metaFlag|0;
 var $$0$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $runtimeInfo$i$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $runtimeInfo$i$i$i = sp + 8|0;
 $size = sp;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,630368,630368,$size,$metaFlag);
 $0 = (($elementType) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i$i$i = 630384;
 } else {
  $3 = (__Z24scripting_class_get_nameP14ScriptingClass($1)|0);
  $$0$i$i$i = $3;
 }
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,630376,$$0$i$i$i,$elementType,0);
 $4 = HEAP32[$elementType>>2]|0;
 ;HEAP32[$runtimeInfo$i$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+20>>2]=0|0;
 $5 = (($runtimeInfo$i$i$i) + 16|0);
 HEAP32[$5>>2] = $this;
 $6 = (($elementType) + 4|0);
 ;HEAP32[$runtimeInfo$i$i$i+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=HEAP32[$6+8>>2]|0;
 $7 = (($runtimeInfo$i$i$i) + 12|0);
 HEAP32[$7>>2] = $4;
 $8 = (($4) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($4) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 if ($12) {
  __ZN13ProxyTransfer11EndTransferEv($this);
  __ZN13ProxyTransfer16EndArrayTransferEv($this);
  STACKTOP = sp;return;
 }
 $13 = (($4) + 12|0);
 $15 = $9;$17 = $11;
 while(1) {
  $14 = (($15) + 64|0);
  HEAP32[$8>>2] = $14;
  $16 = $17;
  $18 = $14;
  $19 = (($16) - ($18))|0;
  $20 = $19 >> 6;
  HEAP32[$13>>2] = $20;
  $21 = HEAP32[$15>>2]|0;
  $22 = (($15) + 4|0);
  FUNCTION_TABLE_vii[$21 & 4095]($22,$runtimeInfo$i$i$i);
  $23 = HEAP32[$8>>2]|0;
  $24 = HEAP32[$10>>2]|0;
  $25 = ($23|0)==($24|0);
  if ($25) {
   break;
  } else {
   $15 = $23;$17 = $24;
  }
 }
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z33EmitSerializationCommandsForFieldI18StreamedBinaryReadILb1EEEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$0$i$ph9 = 0, $$off = 0, $$ph = 0, $$ph8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $serializeFieldCommand = 0, $staticInfo$sroa$9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $staticInfo$sroa$9 = sp;
 $serializeFieldCommand = sp + 16|0;
 $1 = (($tfi) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z24scripting_class_get_typeP14ScriptingClass($2)|0);
 $4 = (__Z23scripting_type_get_typeP13ScriptingType($3)|0);
 $5 = ($4|0)==(29);
 if (!($5)) {
  $6 = (__ZN9Scripting30IsSystemCollectionsGenericListEP14ScriptingClass($2)|0);
  if (!($6)) {
   ;HEAP32[$staticInfo$sroa$9+0>>2]=0|0;HEAP32[$staticInfo$sroa$9+4>>2]=0|0;HEAP32[$staticInfo$sroa$9+8>>2]=0|0;
   $7 = HEAP32[$tfi>>2]|0;
   $8 = (__Z24scripting_field_get_nameP14ScriptingField($7)|0);
   $9 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $10 = (__Z25scripting_class_from_typeP13ScriptingType($9)|0);
   $11 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $12 = (__Z23scripting_type_get_typeP13ScriptingType($11)|0);
   $13 = (__Z26scripting_field_get_offsetP14ScriptingField($7)|0);
   $14 = (__Z24scripting_class_get_nameP14ScriptingClass($10)|0);
   $15 = (($tfi) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = (($tfi) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($tfi) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   L4: do {
    switch ($19|0) {
    case 7:  {
     $$0$i$ph = 2808;$$ph = $16;
     label = 47;
     break;
    }
    case 11:  {
     $$0$i$ph = 2815;$$ph = $16;
     label = 47;
     break;
    }
    case 6:  {
     $$0$i$ph = 2811;$$ph = $16;
     label = 47;
     break;
    }
    case 13:  {
     $$0$i$ph = 2817;$$ph = $16;
     label = 47;
     break;
    }
    case 5:  {
     $$0$i$ph = 2810;$$ph = $16;
     label = 47;
     break;
    }
    case 10:  {
     $$0$i$ph = 2814;$$ph = $16;
     label = 47;
     break;
    }
    case 2:  {
     $23 = $16 | 256;
     $$0$i$ph = 2810;$$ph = $23;
     label = 47;
     break;
    }
    case 4:  {
     $$0$i$ph = 2809;$$ph = $16;
     label = 47;
     break;
    }
    case 9:  {
     $$0$i$ph = 2813;$$ph = $16;
     label = 47;
     break;
    }
    case 8:  {
     $$0$i$ph = 2812;$$ph = $16;
     label = 47;
     break;
    }
    case 12:  {
     $$0$i$ph = 2816;$$ph = $16;
     label = 47;
     break;
    }
    case 3:  {
     $22 = $16 | 33554432;
     $$0$i$ph = 2808;$$ph = $22;
     label = 47;
     break;
    }
    case 14:  {
     $$0$i$ph = 2807;$$ph = $16;
     label = 47;
     break;
    }
    default: {
     $24 = (($21) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($17|0)==($25|0);
     if ($26) {
      $$0$i$ph = 2818;$$ph = $16;
      label = 47;
     } else {
      $27 = (($21) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($17|0)==($28|0);
      if ($29) {
       $$0$i$ph = 2819;$$ph = $16;
       label = 47;
      } else {
       $30 = (($21) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($17|0)==($31|0);
       if ($32) {
        $$0$i$ph = 2820;$$ph = $16;
        label = 47;
       } else {
        $33 = (($21) + 24|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = ($17|0)==($34|0);
        if ($35) {
         $$0$i$ph = 2821;$$ph = $16;
         label = 47;
        } else {
         $36 = (($21) + 32|0);
         $37 = HEAP32[$36>>2]|0;
         $38 = ($17|0)==($37|0);
         if ($38) {
          $$0$i$ph = 2822;$$ph = $16;
          label = 47;
         } else {
          $39 = (($21) + 36|0);
          $40 = HEAP32[$39>>2]|0;
          $41 = ($17|0)==($40|0);
          if ($41) {
           $$0$i$ph = 2823;$$ph = $16;
           label = 47;
          } else {
           $42 = (($21) + 40|0);
           $43 = HEAP32[$42>>2]|0;
           $44 = ($17|0)==($43|0);
           if ($44) {
            $$0$i$ph = 2824;$$ph = $16;
            label = 47;
           } else {
            $45 = (($21) + 52|0);
            $46 = HEAP32[$45>>2]|0;
            $47 = ($17|0)==($46|0);
            if ($47) {
             $$0$i$ph = 2825;$$ph = $16;
             label = 47;
            } else {
             $48 = (($21) + 56|0);
             $49 = HEAP32[$48>>2]|0;
             $50 = ($17|0)==($49|0);
             if ($50) {
              $$0$i$ph = 2826;$$ph = $16;
              label = 47;
             } else {
              $51 = (($21) + 88|0);
              $52 = HEAP32[$51>>2]|0;
              $53 = ($17|0)==($52|0);
              if ($53) {
               $$0$i$ph = 2827;$$ph = $16;
               label = 47;
              } else {
               $54 = (($21) + 492|0);
               $55 = HEAP32[$54>>2]|0;
               $56 = ($17|0)==($55|0);
               do {
                if (!($56)) {
                 $57 = (($21) + 496|0);
                 $58 = HEAP32[$57>>2]|0;
                 $59 = ($17|0)==($58|0);
                 if (!($59)) {
                  $60 = (__Z23scripting_class_is_enumP14ScriptingClass($17)|0);
                  if (!($60)) {
                   $85 = (($21) + 280|0);
                   $86 = HEAP32[$85>>2]|0;
                   $87 = ($17|0)==($86|0);
                   if ($87) {
                    $$0$i$ph = 2828;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $88 = (($21) + 504|0);
                   $89 = HEAP32[$88>>2]|0;
                   $90 = ($17|0)==($89|0);
                   if ($90) {
                    $$0$i$ph = 2829;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $91 = (($21) + 28|0);
                   $92 = HEAP32[$91>>2]|0;
                   $93 = ($17|0)==($92|0);
                   if ($93) {
                    $$0$i$ph = 2830;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $94 = (($21) + 272|0);
                   $95 = HEAP32[$94>>2]|0;
                   $96 = ($17|0)==($95|0);
                   if ($96) {
                    $$0$i$ph9 = 2831;$$ph8 = $16;
                    break L4;
                   }
                   $97 = ($19|0)==(18);
                   if (!($97)) {
                    break;
                   }
                   $98 = (($21) + 244|0);
                   $99 = HEAP32[$98>>2]|0;
                   $100 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($17,$99)|0);
                   if ($100) {
                    $$0$i$ph9 = 2832;$$ph8 = $16;
                    break L4;
                   } else {
                    break;
                   }
                  }
                  $61 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($17)|0);
                  $62 = (__Z23scripting_type_get_typeP13ScriptingType($61)|0);
                  if ((($62|0) == 5)) {
                   $$0$i$ph = 2810;$$ph = $16;
                   label = 47;
                   break L4;
                  } else if ((($62|0) == 8)) {
                   $$0$i$ph = 2812;$$ph = $16;
                   label = 47;
                   break L4;
                  }
                  $63 = HEAP32[$tfi>>2]|0;
                  __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$63);
                  $64 = HEAP8[$0>>0]|0;
                  $65 = $64 & 1;
                  $66 = ($65<<24>>24)==(0);
                  if ($66) {
                   $69 = (($0) + 1|0);
                   $70 = $69;
                  } else {
                   $67 = (($0) + 8|0);
                   $68 = HEAP32[$67>>2]|0;
                   $70 = $68;
                  }
                  __THREW__ = 0;
                  invoke_viiiiiiii(21,($70|0),0,(630440|0),188,1,0,0,(0|0));
                  $71 = __THREW__; __THREW__ = 0;
                  $72 = $71&1;
                  if (!($72)) {
                   $73 = HEAP8[$0>>0]|0;
                   $74 = $73 & 1;
                   $75 = ($74<<24>>24)==(0);
                   if ($75) {
                    break;
                   }
                   $76 = (($0) + 8|0);
                   $77 = HEAP32[$76>>2]|0;
                   __ZdlPv($77);
                   break;
                  }
                  $78 = ___cxa_find_matching_catch()|0;
                  $79 = tempRet0;
                  $80 = HEAP8[$0>>0]|0;
                  $81 = $80 & 1;
                  $82 = ($81<<24>>24)==(0);
                  if ($82) {
                   ___resumeException($78|0);
                   // unreachable;
                  }
                  $83 = (($0) + 8|0);
                  $84 = HEAP32[$83>>2]|0;
                  __ZdlPv($84);
                  ___resumeException($78|0);
                  // unreachable;
                 }
                }
               } while(0);
               $114 = HEAP32[$18>>2]|0;
               $$off = (($114) + -17)|0;
               $115 = ($$off>>>0)<(2);
               if (!($115)) {
                STACKTOP = sp;return;
               }
               __Z46EmitSerializationCommandsForManagedObjectFieldI18StreamedBinaryReadILb1EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
    }
   } while(0);
   if ((label|0) == 47) {
    $101 = (($tfi) + 25|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $$0$i$ph9 = $$0$i$ph;$$ph8 = $$ph;
    } else {
     STACKTOP = sp;return;
    }
   }
   dest=$serializeFieldCommand+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$serializeFieldCommand>>2] = $$0$i$ph9;
   $104 = (($serializeFieldCommand) + 4|0);
   HEAP32[$104>>2] = $7;
   $105 = (($serializeFieldCommand) + 8|0);
   HEAP32[$105>>2] = $8;
   $106 = (($serializeFieldCommand) + 12|0);
   HEAP32[$106>>2] = $14;
   $107 = (($serializeFieldCommand) + 16|0);
   HEAP32[$107>>2] = $10;
   $108 = (($serializeFieldCommand) + 20|0);
   HEAP32[$108>>2] = $12;
   $109 = (($serializeFieldCommand) + 24|0);
   HEAP32[$109>>2] = $13;
   $110 = (($serializeFieldCommand) + 28|0);
   HEAP32[$110>>2] = $$ph8;
   $111 = (($serializeFieldCommand) + 32|0);
   HEAP32[$111>>2] = $17;
   $112 = (($serializeFieldCommand) + 36|0);
   HEAP32[$112>>2] = $19;
   $113 = (($serializeFieldCommand) + 40|0);
   ;HEAP32[$113+0>>2]=HEAP32[$staticInfo$sroa$9+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[$staticInfo$sroa$9+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[$staticInfo$sroa$9+8>>2]|0;
   __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$serializeFieldCommand);
   STACKTOP = sp;return;
  }
 }
 __Z49EmitSerializationCommandsForLinearCollectionFieldI18StreamedBinaryReadILb1EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
 STACKTOP = sp;return;
}
function __ZL12InvokeMethodI18StreamedBinaryReadILb1EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $invocation = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $invocation = sp + 8|0;
 $0 = sp;
 $1 = (($args) + 56|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($args) + 48|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $15 = (($runtimeInfo) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($invocation) + 12|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP8[$runtimeInfo>>0]|0;
 $19 = (($invocation) + 24|0);
 HEAP8[$19>>0] = $18;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation)|0);
 STACKTOP = sp;return;
}
function __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($this,$command) {
 $this = $this|0;
 $command = $command|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if (!($7)) {
  $26 = $3;
  $25 = (($26) + -1)|0;
  $27 = HEAP32[$this>>2]|0;
  $28 = (($27) + ($25<<6)|0);
  dest=$28+0|0; src=$command+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $8 = $5 << 1;
 $9 = ($8|0)==(0);
 $10 = $9 ? 1 : $8;
 $11 = ($6>>>0)<($10>>>0);
 do {
  if ($11) {
   $12 = ($5|0)>(-1);
   if ($12) {
    HEAP32[$4>>2] = $10;
    $13 = HEAP32[$this>>2]|0;
    $14 = $10 << 6;
    $15 = (($this) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,630440,370)|0);
    HEAP32[$this>>2] = $17;
    break;
   } else {
    $18 = $10 << 6;
    $19 = (($this) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,630440,352)|0);
    $22 = HEAP32[$this>>2]|0;
    $23 = HEAP32[$1>>2]|0;
    $24 = $23 << 6;
    _memcpy(($21|0),($22|0),($24|0))|0;
    HEAP32[$4>>2] = $10;
    HEAP32[$this>>2] = $21;
    break;
   }
  }
 } while(0);
 $$pre$i$i = HEAP32[$1>>2]|0;
 $26 = $$pre$i$i;
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + ($25<<6)|0);
 dest=$28+0|0; src=$command+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __Z49EmitSerializationCommandsForLinearCollectionFieldI18StreamedBinaryReadILb1EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($info,$commandQueueBuilder,$nameConversions) {
 $info = $info|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$off = 0, $$ph = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $command = 0, $linearCollectionField = 0, $switch = 0, $tfi = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 184|0;
 $linearCollectionField = sp + 144|0;
 $1 = sp + 68|0;
 $tfi = sp;
 $command = sp + 80|0;
 $$sroa$9 = sp + 56|0;
 HEAP8[$1>>0] = 1;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$info>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$1,$4);
 dest=$tfi+0|0; src=$info+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = HEAP32[$info>>2]|0;
 HEAP32[$tfi>>2] = $5;
 $6 = (__ZN21LinearCollectionField15GetElementClassEv($linearCollectionField)|0);
 $7 = (($tfi) + 40|0);
 HEAP32[$7>>2] = $6;
 $8 = (__Z24scripting_class_get_typeP14ScriptingClass($6)|0);
 $9 = (__Z23scripting_type_get_typeP13ScriptingType($8)|0);
 $10 = (($tfi) + 44|0);
 HEAP32[$10>>2] = $9;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 dest=$command+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$command>>2] = 2833;
 ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
 $14 = (__Z24scripting_field_get_nameP14ScriptingField($5)|0);
 $15 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $16 = (__Z25scripting_class_from_typeP13ScriptingType($15)|0);
 $17 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $18 = (__Z23scripting_type_get_typeP13ScriptingType($17)|0);
 $19 = (__Z26scripting_field_get_offsetP14ScriptingField($5)|0);
 $20 = (__Z24scripting_class_get_nameP14ScriptingClass($16)|0);
 $21 = (($tfi) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($command) + 4|0);
 HEAP32[$23>>2] = $5;
 $24 = (($command) + 8|0);
 HEAP32[$24>>2] = $14;
 $25 = (($command) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($command) + 16|0);
 HEAP32[$26>>2] = $16;
 $27 = (($command) + 20|0);
 HEAP32[$27>>2] = $18;
 $28 = (($command) + 24|0);
 HEAP32[$28>>2] = $19;
 $29 = (($command) + 28|0);
 HEAP32[$29>>2] = $22;
 $30 = (($command) + 32|0);
 HEAP32[$30>>2] = $6;
 $31 = (($command) + 36|0);
 HEAP32[$31>>2] = $9;
 $32 = (($command) + 40|0);
 ;HEAP32[$32+0>>2]=HEAP32[$$sroa$9+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$$sroa$9+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$$sroa$9+8>>2]|0;
 $33 = (($tfi) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 L1: do {
  switch ($9|0) {
  case 10:  {
   $$0$i$ph = 2841;$$ph = 1;
   break;
  }
  case 12:  {
   $$0$i$ph = 2843;$$ph = 1;
   break;
  }
  case 13:  {
   $$0$i$ph = 2844;$$ph = 1;
   break;
  }
  case 6:  {
   $$0$i$ph = 2838;$$ph = 1;
   break;
  }
  case 11:  {
   $$0$i$ph = 2842;$$ph = 1;
   break;
  }
  case 3:  {
   $35 = $22 | 33554432;
   HEAP32[$29>>2] = $35;
   $$0$i$ph = 2835;$$ph = 1;
   break;
  }
  case 8:  {
   $$0$i$ph = 2839;$$ph = 1;
   break;
  }
  case 9:  {
   $$0$i$ph = 2840;$$ph = 1;
   break;
  }
  case 14:  {
   $$0$i$ph = 2834;$$ph = 1;
   break;
  }
  case 2:  {
   $36 = $22 | 256;
   HEAP32[$29>>2] = $36;
   $$0$i$ph = 2837;$$ph = 1;
   break;
  }
  case 5:  {
   $$0$i$ph = 2837;$$ph = 1;
   break;
  }
  case 7:  {
   $$0$i$ph = 2835;$$ph = 1;
   break;
  }
  case 4:  {
   $$0$i$ph = 2836;$$ph = 1;
   break;
  }
  default: {
   $37 = (($34) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($6|0)==($38|0);
   if ($39) {
    $$0$i$ph = 2845;$$ph = 1;
   } else {
    $40 = (($34) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($6|0)==($41|0);
    if ($42) {
     $$0$i$ph = 2846;$$ph = 1;
    } else {
     $43 = (($34) + 20|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($6|0)==($44|0);
     if ($45) {
      $$0$i$ph = 2847;$$ph = 1;
     } else {
      $46 = (($34) + 24|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($6|0)==($47|0);
      if ($48) {
       $$0$i$ph = 2848;$$ph = 1;
      } else {
       $49 = (($34) + 32|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($6|0)==($50|0);
       if ($51) {
        $$0$i$ph = 2849;$$ph = 1;
       } else {
        $52 = (($34) + 36|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($6|0)==($53|0);
        if ($54) {
         $$0$i$ph = 2850;$$ph = 1;
        } else {
         $55 = (($34) + 40|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($6|0)==($56|0);
         if ($57) {
          $$0$i$ph = 2851;$$ph = 1;
         } else {
          $58 = (($34) + 52|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = ($6|0)==($59|0);
          if ($60) {
           $$0$i$ph = 2852;$$ph = 1;
          } else {
           $61 = (($34) + 56|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = ($6|0)==($62|0);
           if ($63) {
            $$0$i$ph = 2853;$$ph = 1;
           } else {
            $64 = (($34) + 88|0);
            $65 = HEAP32[$64>>2]|0;
            $66 = ($6|0)==($65|0);
            if ($66) {
             $$0$i$ph = 2854;$$ph = 1;
            } else {
             $67 = (($34) + 492|0);
             $68 = HEAP32[$67>>2]|0;
             $69 = ($6|0)==($68|0);
             do {
              if ($69) {
               label = 44;
              } else {
               $70 = (($34) + 496|0);
               $71 = HEAP32[$70>>2]|0;
               $72 = ($6|0)==($71|0);
               if ($72) {
                label = 44;
               } else {
                $73 = (__Z23scripting_class_is_enumP14ScriptingClass($6)|0);
                if (!($73)) {
                 $97 = (($34) + 280|0);
                 $98 = HEAP32[$97>>2]|0;
                 $99 = ($6|0)==($98|0);
                 if ($99) {
                  $$0$i$ph = 2855;$$ph = 1;
                  break L1;
                 }
                 $100 = (($34) + 504|0);
                 $101 = HEAP32[$100>>2]|0;
                 $102 = ($6|0)==($101|0);
                 if ($102) {
                  $$0$i$ph = 2856;$$ph = 1;
                  break L1;
                 }
                 $103 = (($34) + 28|0);
                 $104 = HEAP32[$103>>2]|0;
                 $105 = ($6|0)==($104|0);
                 if ($105) {
                  $$0$i$ph = 2857;$$ph = 1;
                  break L1;
                 }
                 $106 = (($34) + 272|0);
                 $107 = HEAP32[$106>>2]|0;
                 $108 = ($6|0)==($107|0);
                 if ($108) {
                  $$0$i$ph = 2858;$$ph = 0;
                  break L1;
                 }
                 $109 = ($9|0)==(18);
                 if (!($109)) {
                  label = 44;
                  break;
                 }
                 $110 = (($34) + 244|0);
                 $111 = HEAP32[$110>>2]|0;
                 $112 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$111)|0);
                 if ($112) {
                  $$0$i$ph = 2859;$$ph = 0;
                  break L1;
                 } else {
                  break;
                 }
                }
                $74 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($6)|0);
                $75 = (__Z23scripting_type_get_typeP13ScriptingType($74)|0);
                if ((($75|0) == 5)) {
                 $$0$i$ph = 2837;$$ph = 1;
                 break L1;
                } else if ((($75|0) == 8)) {
                 $$0$i$ph = 2839;$$ph = 1;
                 break L1;
                }
                __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$5);
                $76 = HEAP8[$0>>0]|0;
                $77 = $76 & 1;
                $78 = ($77<<24>>24)==(0);
                if ($78) {
                 $81 = (($0) + 1|0);
                 $82 = $81;
                } else {
                 $79 = (($0) + 8|0);
                 $80 = HEAP32[$79>>2]|0;
                 $82 = $80;
                }
                __THREW__ = 0;
                invoke_viiiiiiii(21,($82|0),0,(630440|0),188,1,0,0,(0|0));
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if (!($84)) {
                 $85 = HEAP8[$0>>0]|0;
                 $86 = $85 & 1;
                 $87 = ($86<<24>>24)==(0);
                 if ($87) {
                  label = 44;
                  break;
                 }
                 $88 = (($0) + 8|0);
                 $89 = HEAP32[$88>>2]|0;
                 __ZdlPv($89);
                 label = 44;
                 break;
                }
                $90 = ___cxa_find_matching_catch()|0;
                $91 = tempRet0;
                $92 = HEAP8[$0>>0]|0;
                $93 = $92 & 1;
                $94 = ($93<<24>>24)==(0);
                if ($94) {
                 ___resumeException($90|0);
                 // unreachable;
                }
                $95 = (($0) + 8|0);
                $96 = HEAP32[$95>>2]|0;
                __ZdlPv($96);
                ___resumeException($90|0);
                // unreachable;
               }
              }
             } while(0);
             if ((label|0) == 44) {
              $$off = (($9) + -17)|0;
              $switch = ($$off>>>0)<(2);
              if (!($switch)) {
               STACKTOP = sp;return;
              }
             }
             __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI18StreamedBinaryReadILb1EEEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$command,$commandQueueBuilder,$nameConversions);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
  }
 } while(0);
 $113 = (($tfi) + 25|0);
 $114 = HEAP8[$113>>0]|0;
 $115 = $114 & $$ph;
 $116 = ($115<<24>>24)==(0);
 if (!($116)) {
  STACKTOP = sp;return;
 }
 $117 = (($command) + 44|0);
 HEAP32[$117>>2] = $$0$i$ph;
 __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$command);
 STACKTOP = sp;return;
}
function __Z46EmitSerializationCommandsForManagedObjectFieldI18StreamedBinaryReadILb1EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $args = 0, $newCommandQueueBuilder = 0, $serializeManagedObject = 0, $tfi$idx = 0, $tfi$idx$val = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy1 = sp + 124|0;
 $0 = sp + 120|0;
 $args = sp + 12|0;
 $newCommandQueueBuilder = sp + 32|0;
 $serializeManagedObject = sp + 56|0;
 $$sroa$9 = sp;
 $tfi$idx = (($tfi) + 4|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI18TransferField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$8>>2] = $13;
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 $14 = (($newCommandQueueBuilder) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($newCommandQueueBuilder) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($newCommandQueueBuilder) + 4|0);
 HEAP32[$16>>2] = 61;
 $17 = (($newCommandQueueBuilder) + 16|0);
 HEAP8[$17>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(386,($args|0),($newCommandQueueBuilder|0),($nameConversions|0),0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 do {
  if (!($19)) {
   $20 = (($tfi) + 25|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    label = 8;
   } else {
    $23 = HEAP32[$14>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    dest=$serializeManagedObject+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$serializeManagedObject>>2] = 2860;
    ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
    $33 = HEAP32[$tfi>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3280,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3276,($33|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3278,($37|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_ii(3276,($33|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    $46 = (invoke_ii(3277,($43|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    __THREW__ = 0;
    $49 = (invoke_ii(3283,($33|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    __THREW__ = 0;
    $52 = (invoke_ii(3284,($40|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    $55 = (($tfi) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$tfi$idx>>2]|0;
    $58 = (($tfi) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($serializeManagedObject) + 4|0);
    HEAP32[$60>>2] = $33;
    $61 = (($serializeManagedObject) + 8|0);
    HEAP32[$61>>2] = $34;
    $62 = (($serializeManagedObject) + 12|0);
    HEAP32[$62>>2] = $52;
    $63 = (($serializeManagedObject) + 16|0);
    HEAP32[$63>>2] = $40;
    $64 = (($serializeManagedObject) + 20|0);
    HEAP32[$64>>2] = $46;
    $65 = (($serializeManagedObject) + 24|0);
    HEAP32[$65>>2] = $49;
    $66 = (($serializeManagedObject) + 28|0);
    HEAP32[$66>>2] = $56;
    $67 = (($serializeManagedObject) + 32|0);
    HEAP32[$67>>2] = $57;
    $68 = (($serializeManagedObject) + 36|0);
    HEAP32[$68>>2] = $59;
    $69 = (($serializeManagedObject) + 40|0);
    $70 = $$sroa$9;
    $71 = $70;
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + 4)|0;
    $74 = $73;
    $75 = HEAP32[$74>>2]|0;
    $76 = $69;
    $77 = $76;
    HEAP32[$77>>2] = $72;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = $75;
    $80 = HEAP32[$14>>2]|0;
    $81 = (($serializeManagedObject) + 48|0);
    HEAP32[$81>>2] = $80;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($serializeManagedObject|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($newCommandQueueBuilder|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
   }
   $86 = HEAP32[$15>>2]|0;
   $87 = ($86|0)>(-1);
   if (!($87)) {
    STACKTOP = sp;return;
   }
   $88 = HEAP32[$newCommandQueueBuilder>>2]|0;
   $89 = HEAP32[$16>>2]|0;
   HEAP32[$0>>2] = $89;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($88,$$byval_copy1);
   HEAP32[$newCommandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$15>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$newCommandQueueBuilder>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $90 = ___cxa_find_matching_catch(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 }
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 ___resumeException($25|0);
 // unreachable;
}
function __ZL29CanTransferTypeAsNestedObjectI18TransferField_InfoEbRKT_($tfi$0$1$val) {
 $tfi$0$1$val = $tfi$0$1$val|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z25scripting_class_get_flagsP14ScriptingClass($tfi$0$1$val)|0);
 $1 = $0 & 8192;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (__Z27scripting_class_is_abstractP14ScriptingClass($tfi$0$1$val)|0);
  if ($3) {
   $$0 = 0;
  } else {
   $4 = (__Z28scripting_class_is_interfaceP14ScriptingClass($tfi$0$1$val)|0);
   if ($4) {
    $$0 = 0;
   } else {
    $5 = (__Z25scripting_class_get_imageP14ScriptingClass($tfi$0$1$val)|0);
    $6 = (__Z20scripting_get_corlibv()|0);
    $7 = ($5|0)==($6|0);
    if ($7) {
     $$0 = 0;
    } else {
     $8 = (__Z14GetMonoManagerv()|0);
     $9 = (__ZN11MonoManager25GetAssemblyIndexFromImageEP14ScriptingImage($8,$5)|0);
     $not$ = ($9|0)!=(-1);
     $$0 = $not$;
    }
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL22Transfer_ManagedObjectI18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $$phi$trans$insert1 = 0, $$phi$trans$insert3 = 0, $$pre = 0, $$pre$i = 0, $$pre2 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $managedObjectTransferer$sroa$2 = 0, $newProvider = 0, $runtimeInfo$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $runtimeInfo$i$i$i = sp + 32|0;
 $managedObjectTransferer$sroa$2 = sp + 56|0;
 $0 = sp + 20|0;
 $newProvider = sp;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP8[$managedObjectTransferer$sroa$2+0>>0]=0|0;HEAP8[$managedObjectTransferer$sroa$2+1>>0]=0|0;HEAP8[$managedObjectTransferer$sroa$2+2>>0]=0|0;
 $3 = (($runtimeInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = (($args) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(17);
 do {
  if ($5) {
   $$pre$i = (($args) + 12|0);
   if ($8) {
    $13 = 0;
   } else {
    $9 = HEAP32[$$pre$i>>2]|0;
    $10 = (_il2cpp_object_new($9)|0);
    $13 = $10;
   }
   $11 = HEAP32[$$pre$i>>2]|0;
   HEAP8[$0>>0] = 1;
   $12 = (($0) + 4|0);
   HEAP32[$12>>2] = $13;
   $14 = (($0) + 8|0);
   HEAP32[$14>>2] = $11;
   $41 = 1;$44 = $13;$46 = $11;
  } else {
   if ($8) {
    $15 = (($args) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP8[$runtimeInfo>>0]|0;
    $18 = ($17<<24>>24)!=(0);
    $19 = (($16) + -8)|0;
    $20 = $18 ? $16 : $19;
    $21 = (($4) + ($20)|0);
    $22 = (($args) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    HEAP8[$0>>0] = 0;
    $24 = (($0) + 4|0);
    HEAP32[$24>>2] = $21;
    $25 = (($0) + 8|0);
    HEAP32[$25>>2] = $23;
    $41 = 0;$44 = $21;$46 = $23;
    break;
   } else {
    $26 = HEAP32[$args>>2]|0;
    __Z30GetOrCreateObjectStoredInFieldP14ScriptingFieldRK17GeneralMonoObjectb($0,$26,$runtimeInfo,1);
    $$pre = HEAP8[$0>>0]|0;
    $$phi$trans$insert1 = (($0) + 4|0);
    $$pre2 = HEAP32[$$phi$trans$insert1>>2]|0;
    $$phi$trans$insert3 = (($0) + 8|0);
    $$pre4 = HEAP32[$$phi$trans$insert3>>2]|0;
    $41 = $$pre;$44 = $$pre2;$46 = $$pre4;
    break;
   }
  }
 } while(0);
 $27 = (($0) + 1|0);
 ;HEAP8[$managedObjectTransferer$sroa$2+0>>0]=HEAP8[$27+0>>0]|0;HEAP8[$managedObjectTransferer$sroa$2+1>>0]=HEAP8[$27+1>>0]|0;HEAP8[$managedObjectTransferer$sroa$2+2>>0]=HEAP8[$27+2>>0]|0;
 $28 = (($runtimeInfo) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($args) + 44|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + ($31<<6)|0);
 HEAP32[$32>>2] = $34;
 $35 = (($newProvider) + 4|0);
 HEAP32[$35>>2] = $33;
 HEAP32[$newProvider>>2] = $33;
 $36 = (($newProvider) + 8|0);
 HEAP32[$36>>2] = $34;
 $$idx$i = $31 << 6;
 $37 = $$idx$i >> 6;
 $38 = (($newProvider) + 16|0);
 HEAP32[$38>>2] = $37;
 $39 = (($newProvider) + 12|0);
 HEAP32[$39>>2] = $37;
 ;HEAP32[$runtimeInfo$i$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+20>>2]=0|0;
 $40 = (($runtimeInfo$i$i$i) + 16|0);
 HEAP32[$40>>2] = $2;
 HEAP8[$runtimeInfo$i$i$i>>0] = $41;
 $42 = (($runtimeInfo$i$i$i) + 1|0);
 ;HEAP8[$42+0>>0]=HEAP8[$managedObjectTransferer$sroa$2+0>>0]|0;HEAP8[$42+1>>0]=HEAP8[$managedObjectTransferer$sroa$2+1>>0]|0;HEAP8[$42+2>>0]=HEAP8[$managedObjectTransferer$sroa$2+2>>0]|0;
 $43 = (($runtimeInfo$i$i$i) + 4|0);
 HEAP32[$43>>2] = $44;
 $45 = (($runtimeInfo$i$i$i) + 8|0);
 HEAP32[$45>>2] = $46;
 $47 = (($runtimeInfo$i$i$i) + 12|0);
 HEAP32[$47>>2] = $newProvider;
 $48 = ($31|0)==(0);
 if ($48) {
  STACKTOP = sp;return;
 } else {
  $50 = $33;$52 = $34;
 }
 while(1) {
  $49 = (($50) + 64|0);
  HEAP32[$35>>2] = $49;
  $51 = $52;
  $53 = $49;
  $54 = (($51) - ($53))|0;
  $55 = $54 >> 6;
  HEAP32[$39>>2] = $55;
  $56 = HEAP32[$50>>2]|0;
  $57 = (($50) + 4|0);
  FUNCTION_TABLE_vii[$56 & 4095]($57,$runtimeInfo$i$i$i);
  $58 = HEAP32[$35>>2]|0;
  $59 = HEAP32[$36>>2]|0;
  $60 = ($58|0)==($59|0);
  if ($60) {
   break;
  } else {
   $50 = $58;$52 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZN32SerializationCommandQueueBuilder3AddERK13dynamic_arrayI20SerializationCommandLj4EE($this,$commands) {
 $this = $this|0;
 $commands = $commands|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($commands) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$commands>>2]|0;
 $5 = (($this) + 8|0);
 $6 = (($this) + 12|0);
 $7 = (($this) + 4|0);
 $i$01 = $4;
 while(1) {
  $8 = HEAP32[$5>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$5>>2] = $9;
  $10 = HEAP32[$6>>2]|0;
  $11 = $10 & 2147483647;
  $12 = ($9>>>0)>($11>>>0);
  if ($12) {
   $13 = $10 << 1;
   $14 = ($13|0)==(0);
   $15 = $14 ? 1 : $13;
   $16 = ($11>>>0)<($15>>>0);
   do {
    if ($16) {
     $17 = ($10|0)>(-1);
     if ($17) {
      HEAP32[$6>>2] = $15;
      $18 = HEAP32[$this>>2]|0;
      $19 = $15 << 6;
      $20 = HEAP32[$7>>2]|0;
      HEAP32[$0>>2] = $20;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $21 = (__Z16realloc_internalPvji10MemLabelIdiPKci($18,$19,4,$$byval_copy1,0,630440,370)|0);
      HEAP32[$this>>2] = $21;
      break;
     } else {
      $22 = $15 << 6;
      $23 = HEAP32[$7>>2]|0;
      HEAP32[$0>>2] = $23;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,4,$$byval_copy1,0,630440,352)|0);
      $25 = HEAP32[$this>>2]|0;
      $26 = HEAP32[$5>>2]|0;
      $27 = $26 << 6;
      _memcpy(($24|0),($25|0),($27|0))|0;
      HEAP32[$6>>2] = $15;
      HEAP32[$this>>2] = $24;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$5>>2]|0;
   $29 = $$pre$i$i;
  } else {
   $29 = $9;
  }
  $28 = (($29) + -1)|0;
  $30 = HEAP32[$this>>2]|0;
  $31 = (($30) + ($28<<6)|0);
  dest=$31+0|0; src=$i$01+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $32 = (($i$01) + 64|0);
  $33 = HEAP32[$commands>>2]|0;
  $34 = HEAP32[$1>>2]|0;
  $35 = (($33) + ($34<<6)|0);
  $36 = ($32|0)==($35|0);
  if ($36) {
   break;
  } else {
   $i$01 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 HEAP8[$converter>>0] = 0;
 __Z13TransferFieldI18StreamedBinaryReadILb1EELb0E16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,1);
  $20 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($20);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP8[$12>>0]|0;
  HEAP8[$8>>0] = $17;
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$11>>2] = $19;
  $20 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($20);
  STACKTOP = sp;return;
 }
}
function __Z22Transfer_Builtin_AlignIh18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,1);
  $20 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($20);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP8[$12>>0]|0;
  HEAP8[$8>>0] = $17;
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$11>>2] = $19;
  $20 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($20);
  STACKTOP = sp;return;
 }
}
function __Z22Transfer_Builtin_AlignIs18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 2|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,2);
  $$pre$i$i$i$i = HEAP16[$8>>1]|0;
  $19 = $$pre$i$i$i$i;
 } else {
  $17 = HEAP16[$12>>1]|0;
  HEAP16[$8>>1] = $17;
  HEAP32[$11>>2] = $13;
  $19 = $17;
 }
 $18 = $19&65535;
 $20 = $18 << 8;
 $21 = $18 >>> 8;
 $22 = $20 | $21;
 $23 = $22&65535;
 HEAP16[$8>>1] = $23;
 $24 = HEAP32[$9>>2]|0;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($24);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 2|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,2);
  $$pre$i$i$i$i = HEAP16[$8>>1]|0;
  $19 = $$pre$i$i$i$i;
 } else {
  $17 = HEAP16[$12>>1]|0;
  HEAP16[$8>>1] = $17;
  HEAP32[$11>>2] = $13;
  $19 = $17;
 }
 $18 = $19&65535;
 $20 = $18 << 8;
 $21 = $18 >>> 8;
 $22 = $20 | $21;
 $23 = $22&65535;
 HEAP16[$8>>1] = $23;
 $24 = HEAP32[$9>>2]|0;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($24);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  $$pre$i$i$i = HEAP32[$8>>2]|0;
  $18 = $$pre$i$i$i;
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$8>>2] = $19;
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = $17;
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$8>>2] = $19;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIj18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  $$pre$i$i$i = HEAP32[$8>>2]|0;
  $18 = $$pre$i$i$i;
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$8>>2] = $19;
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = $17;
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$8>>2] = $19;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIx18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$phi$trans$insert2$i$i$i = 0, $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre3$i$i$i = 0, $$pre5$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,8);
  $$pre$i$i$i = HEAP32[$8>>2]|0;
  $$sum1 = (($5) + 4)|0;
  $$phi$trans$insert2$i$i$i = (($7) + ($$sum1)|0);
  $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
  $$pre$phi$i$i$iZ2D = $8;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$27 = $$pre$i$i$i;$29 = $$pre3$i$i$i;
  $28 = (_llvm_bswap_i32(($27|0))|0);
  $30 = (_llvm_bswap_i32(($29|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $30;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $28;
  STACKTOP = sp;return;
 } else {
  $17 = $12;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = $8;
  $24 = $23;
  HEAP32[$24>>2] = $19;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $22;
  HEAP32[$11>>2] = $13;
  $$sum = (($5) + 4)|0;
  $$pre5$i$i$i = (($7) + ($$sum)|0);
  $$pre$phi$i$i$iZ2D = $8;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$27 = $19;$29 = $22;
  $28 = (_llvm_bswap_i32(($27|0))|0);
  $30 = (_llvm_bswap_i32(($29|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $30;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $28;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIy18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$phi$trans$insert2$i$i$i = 0, $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre3$i$i$i = 0, $$pre5$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,8);
  $$pre$i$i$i = HEAP32[$8>>2]|0;
  $$sum1 = (($5) + 4)|0;
  $$phi$trans$insert2$i$i$i = (($7) + ($$sum1)|0);
  $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
  $$pre$phi$i$i$iZ2D = $8;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$27 = $$pre$i$i$i;$29 = $$pre3$i$i$i;
  $28 = (_llvm_bswap_i32(($27|0))|0);
  $30 = (_llvm_bswap_i32(($29|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $30;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $28;
  STACKTOP = sp;return;
 } else {
  $17 = $12;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = $8;
  $24 = $23;
  HEAP32[$24>>2] = $19;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $22;
  HEAP32[$11>>2] = $13;
  $$sum = (($5) + 4)|0;
  $$pre5$i$i$i = (($7) + ($$sum)|0);
  $$pre$phi$i$i$iZ2D = $8;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$27 = $19;$29 = $22;
  $28 = (_llvm_bswap_i32(($27|0))|0);
  $30 = (_llvm_bswap_i32(($29|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $30;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $28;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIf18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  $$pre$i$i$i = HEAP32[$8>>2]|0;
  $$pre$phi$i$i$iZ2D = $8;$19 = $$pre$i$i$i;
  $20 = (_llvm_bswap_i32(($19|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $20;
  STACKTOP = sp;return;
 } else {
  $17 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $8;$19 = $18;
  $20 = (_llvm_bswap_i32(($19|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinId18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$phi$trans$insert2$i$i$i = 0, $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre3$i$i$i = 0, $$pre5$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,8);
  $$pre$i$i$i = HEAP32[$8>>2]|0;
  $$sum1 = (($5) + 4)|0;
  $$phi$trans$insert2$i$i$i = (($7) + ($$sum1)|0);
  $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
  $$pre$phi$i$i$iZ2D = $8;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$22 = $$pre$i$i$i;$24 = $$pre3$i$i$i;
  $23 = (_llvm_bswap_i32(($22|0))|0);
  $25 = (_llvm_bswap_i32(($24|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $25;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $23;
  STACKTOP = sp;return;
 } else {
  HEAP8[tempDoublePtr>>0]=HEAP8[$12>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$12+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$12+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$12+3>>0];HEAP8[tempDoublePtr+4>>0]=HEAP8[$12+4>>0];HEAP8[tempDoublePtr+5>>0]=HEAP8[$12+5>>0];HEAP8[tempDoublePtr+6>>0]=HEAP8[$12+6>>0];HEAP8[tempDoublePtr+7>>0]=HEAP8[$12+7>>0];$17 = +HEAPF64[tempDoublePtr>>3];
  HEAPF64[tempDoublePtr>>3]=$17;HEAP8[$8>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$8+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$8+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$8+3>>0]=HEAP8[tempDoublePtr+3>>0];HEAP8[$8+4>>0]=HEAP8[tempDoublePtr+4>>0];HEAP8[$8+5>>0]=HEAP8[tempDoublePtr+5>>0];HEAP8[$8+6>>0]=HEAP8[tempDoublePtr+6>>0];HEAP8[$8+7>>0]=HEAP8[tempDoublePtr+7>>0];
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 8|0);
  HEAP32[$11>>2] = $19;
  HEAPF64[tempDoublePtr>>3] = $17;$20 = HEAP32[tempDoublePtr>>2]|0;
  $21 = HEAP32[tempDoublePtr+4>>2]|0;
  $$sum = (($5) + 4)|0;
  $$pre5$i$i$i = (($7) + ($$sum)|0);
  $$pre$phi$i$i$iZ2D = $8;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$22 = $20;$24 = $21;
  $23 = (_llvm_bswap_i32(($22|0))|0);
  $25 = (_llvm_bswap_i32(($24|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $25;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $23;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8Vector3f18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($10,$8,0,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i3$i$i$i = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$i4$i$i$iZ2D = 0, $$pre6$i$i$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  $$pre$i$i$i3$i$i$i = HEAP32[$8>>2]|0;
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $$pre6$i$i$i = HEAP32[$14>>2]|0;
  $$pre$phi$i$i$i4$i$i$iZ2D = $8;$19 = $$pre$i$i$i3$i$i$i;$23 = $$pre$i$i$i;$25 = $$pre6$i$i$i;
 } else {
  $17 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4$i$i$iZ2D = $8;$19 = $18;$23 = $13;$25 = $15;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$$pre$phi$i$i$i4$i$i$iZ2D>>2] = $20;
 $$sum = (($5) + 4)|0;
 $21 = (($7) + ($$sum)|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$21,4);
  $$pre$i$i$i$i$i$i = HEAP32[$21>>2]|0;
  $$pre$phi$i$i$i$i$i$iZ2D = $21;$28 = $$pre$i$i$i$i$i$i;
  $29 = (_llvm_bswap_i32(($28|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $29;
  STACKTOP = sp;return;
 } else {
  $26 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$21>>2] = $26;
  HEAP32[$11>>2] = $22;
  $27 = (HEAPF32[tempDoublePtr>>2]=$26,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i$i$i$iZ2D = $21;$28 = $27;
  $29 = (_llvm_bswap_i32(($28|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $29;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8Vector4f18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5RectTIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN11Quaternionf8TransferI18StreamedBinaryReadILb1EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN10Matrix4x4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($10,$8,0,0);
 $$sum = (($5) + 12)|0;
 $11 = (($7) + ($$sum)|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($10,$11,0,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3218StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  $$pre$i$i$i$i$i$i = HEAP32[$8>>2]|0;
  $18 = $$pre$i$i$i$i$i$i;
  HEAP32[$8>>2] = $18;
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = $17;
  HEAP32[$8>>2] = $18;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8BitField18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  $$pre$i$i$i$i$i$i = HEAP32[$8>>2]|0;
  $18 = $$pre$i$i$i$i$i$i;
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$8>>2] = $19;
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = $17;
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$8>>2] = $19;
  STACKTOP = sp;return;
 }
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$native$i$i+0>>2]=0|0;HEAP32[$native$i$i+4>>2]=0|0;HEAP32[$native$i$i+8>>2]=0|0;HEAP32[$native$i$i+12>>2]=0|0;
 $2 = (($runtimeInfo) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb1EEEEvRT_($native$i$i,$3);
 $4 = (($args) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$runtimeInfo>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (($5) + -8)|0;
 $9 = $7 ? $5 : $8;
 $10 = (($runtimeInfo) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (_il2cpp_object_new($1)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($15);
  $17 = $15;
 } else {
  $17 = $13;
 }
 $16 = (($17) + 8|0);
 $18 = HEAP32[$16>>2]|0;
 ;HEAP32[$18+0>>2]=HEAP32[$native$i$i+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$native$i$i+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$native$i$i+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$native$i$i+12>>2]|0;
 $19 = HEAP32[$4>>2]|0;
 $20 = HEAP8[$runtimeInfo>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = (($19) + -8)|0;
 $23 = $21 ? $19 : $22;
 $24 = HEAP32[$10>>2]|0;
 $25 = (($24) + ($23)|0);
 HEAP32[$25>>2] = $17;
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$native$i$i>>2] = 0;
 $5 = (($native$i$i) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($native$i$i) + 8|0);
 HEAP32[$6>>2] = 0;
 __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($native$i$i,$1);
 $7 = HEAP32[$native$i$i>>2]|0;
 $8 = (__Z24TransferPPtrToMonoObjectiP14ScriptingClassP23DataToCreateNullWrapper24TransferInstructionFlags($7,$3,0,$4)|0);
 $9 = (($args) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP8[$runtimeInfo>>0]|0;
 $12 = ($11<<24>>24)!=(0);
 $13 = (($10) + -8)|0;
 $14 = $12 ? $10 : $13;
 $15 = (($runtimeInfo) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14)|0);
 HEAP32[$17>>2] = $8;
 STACKTOP = sp;return;
}
function __Z22TransferField_NonArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $invocation$i = 0, $method$i = 0, $native = 0, $scripting1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy1 = sp + 352|0;
 $method$i = sp;
 $invocation$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 48|0;
 $native = sp + 52|0;
 $scripting1 = sp + 344|0;
 __ZN8GUIStyleC2Ev($native);
 $2 = (($runtimeInfo) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vii(2862,($native|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $17 = (($staticInfo) + 20|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP8[$runtimeInfo>>0]|0;
   $20 = ($19<<24>>24)!=(0);
   $21 = (($18) + -8)|0;
   $22 = $20 ? $18 : $21;
   $23 = (($runtimeInfo) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + ($22)|0);
   $26 = HEAP32[$25>>2]|0;
   HEAP32[$scripting1>>2] = $26;
   __THREW__ = 0;
   invoke_viii(1797,($converter|0),($native|0),($scripting1|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[$17>>2]|0;
    $30 = HEAP8[$runtimeInfo>>0]|0;
    $31 = ($30<<24>>24)!=(0);
    $32 = (($29) + -8)|0;
    $33 = $31 ? $29 : $32;
    $34 = HEAP32[$23>>2]|0;
    $35 = (($34) + ($33)|0);
    $36 = HEAP32[$scripting1>>2]|0;
    HEAP32[$35>>2] = $36;
    __THREW__ = 0;
    $37 = (invoke_i(84)|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     $40 = (($37) + 308|0);
     $41 = HEAP32[$40>>2]|0;
     __THREW__ = 0;
     invoke_viiii(388,($method$i|0),($41|0),(630336|0),1);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      $44 = HEAP32[$method$i>>2]|0;
      $45 = ($44|0)==(0|0);
      if (!($45)) {
       $46 = $method$i;
       $47 = $46;
       $48 = HEAP32[$47>>2]|0;
       $49 = (($46) + 4)|0;
       $50 = $49;
       $51 = HEAP32[$50>>2]|0;
       $52 = $0;
       $53 = $52;
       HEAP32[$53>>2] = $48;
       $54 = (($52) + 4)|0;
       $55 = $54;
       HEAP32[$55>>2] = $51;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;
       invoke_vii(2863,($invocation$i|0),($$byval_copy1|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       $58 = (($invocation$i) + 12|0);
       HEAP32[$58>>2] = $36;
       __THREW__ = 0;
       (invoke_ii(3285,($invocation$i|0))|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
      }
      $61 = HEAP8[$native>>0]|0;
      $62 = $61 & 1;
      $63 = ($62<<24>>24)==(0);
      if ($63) {
       STACKTOP = sp;return;
      }
      $64 = (($native) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      HEAP32[$method$i>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$method$i+0>>2]|0;
      invoke_vii(2591,($65|0),($$byval_copy1|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       $68 = ___cxa_find_matching_catch()|0;
       $69 = tempRet0;
       ___cxa_call_unexpected(($68|0));
       // unreachable;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $8 = HEAP8[$native>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  ___resumeException($6|0);
  // unreachable;
 }
 $11 = (($native) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($12|0),($$byval_copy1|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  ___cxa_call_unexpected(($15|0));
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
}
function __ZN27Converter_SimpleNativeClassI8GUIStyleE17NativeToScriptingERKS0_RP15ScriptingObject($this,$native,$out_scripting) {
 $this = $this|0;
 $native = $native|0;
 $out_scripting = $out_scripting|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0;
 var $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0);
 var $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$out_scripting>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = HEAP32[$this>>2]|0;
  $3 = (_il2cpp_object_new($2)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($3);
  HEAP32[$out_scripting>>2] = $3;
  $5 = $3;
 } else {
  $5 = $0;
 }
 $4 = (($5) + 8|0);
 $6 = HEAP32[$4>>2]|0;
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($6,$native)|0);
 $7 = (($native) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 12|0);
 HEAP32[$9>>2] = $8;
 $10 = (($native) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($native) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($native) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($native) + 28|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($6) + 16|0);
 HEAPF32[$18>>2] = $11;
 $19 = (($6) + 20|0);
 HEAPF32[$19>>2] = $13;
 $20 = (($6) + 24|0);
 HEAPF32[$20>>2] = $15;
 $21 = (($6) + 28|0);
 HEAPF32[$21>>2] = $17;
 $22 = (($native) + 32|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($6) + 32|0);
 HEAP32[$24>>2] = $23;
 $25 = (($native) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($native) + 40|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($native) + 44|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($native) + 48|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($6) + 36|0);
 HEAPF32[$33>>2] = $26;
 $34 = (($6) + 40|0);
 HEAPF32[$34>>2] = $28;
 $35 = (($6) + 44|0);
 HEAPF32[$35>>2] = $30;
 $36 = (($6) + 48|0);
 HEAPF32[$36>>2] = $32;
 $37 = (($native) + 52|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($6) + 52|0);
 HEAP32[$39>>2] = $38;
 $40 = (($native) + 56|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($native) + 60|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($native) + 64|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($native) + 68|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($6) + 56|0);
 HEAPF32[$48>>2] = $41;
 $49 = (($6) + 60|0);
 HEAPF32[$49>>2] = $43;
 $50 = (($6) + 64|0);
 HEAPF32[$50>>2] = $45;
 $51 = (($6) + 68|0);
 HEAPF32[$51>>2] = $47;
 $52 = (($native) + 72|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($6) + 72|0);
 HEAP32[$54>>2] = $53;
 $55 = (($native) + 76|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($native) + 80|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($native) + 84|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($native) + 88|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($6) + 76|0);
 HEAPF32[$63>>2] = $56;
 $64 = (($6) + 80|0);
 HEAPF32[$64>>2] = $58;
 $65 = (($6) + 84|0);
 HEAPF32[$65>>2] = $60;
 $66 = (($6) + 88|0);
 HEAPF32[$66>>2] = $62;
 $67 = (($native) + 92|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($6) + 92|0);
 HEAP32[$69>>2] = $68;
 $70 = (($native) + 96|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($native) + 100|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($native) + 104|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($native) + 108|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($6) + 96|0);
 HEAPF32[$78>>2] = $71;
 $79 = (($6) + 100|0);
 HEAPF32[$79>>2] = $73;
 $80 = (($6) + 104|0);
 HEAPF32[$80>>2] = $75;
 $81 = (($6) + 108|0);
 HEAPF32[$81>>2] = $77;
 $82 = (($native) + 112|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($6) + 112|0);
 HEAP32[$84>>2] = $83;
 $85 = (($native) + 116|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($native) + 120|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($native) + 124|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($native) + 128|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($6) + 116|0);
 HEAPF32[$93>>2] = $86;
 $94 = (($6) + 120|0);
 HEAPF32[$94>>2] = $88;
 $95 = (($6) + 124|0);
 HEAPF32[$95>>2] = $90;
 $96 = (($6) + 128|0);
 HEAPF32[$96>>2] = $92;
 $97 = (($native) + 132|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (($6) + 132|0);
 HEAP32[$99>>2] = $98;
 $100 = (($native) + 136|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($native) + 140|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($native) + 144|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($native) + 148|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($6) + 136|0);
 HEAPF32[$108>>2] = $101;
 $109 = (($6) + 140|0);
 HEAPF32[$109>>2] = $103;
 $110 = (($6) + 144|0);
 HEAPF32[$110>>2] = $105;
 $111 = (($6) + 148|0);
 HEAPF32[$111>>2] = $107;
 $112 = (($native) + 152|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($6) + 152|0);
 HEAP32[$114>>2] = $113;
 $115 = (($native) + 156|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (($native) + 160|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($native) + 164|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($native) + 168|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($6) + 156|0);
 HEAPF32[$123>>2] = $116;
 $124 = (($6) + 160|0);
 HEAPF32[$124>>2] = $118;
 $125 = (($6) + 164|0);
 HEAPF32[$125>>2] = $120;
 $126 = (($6) + 168|0);
 HEAPF32[$126>>2] = $122;
 $127 = (($6) + 172|0);
 $128 = (($native) + 172|0);
 dest=$127+0|0; src=$128+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $129 = (($native) + 236|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (($6) + 236|0);
 HEAP32[$131>>2] = $130;
 $132 = (($6) + 240|0);
 $133 = (($native) + 240|0);
 dest=$132+0|0; src=$133+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[$132+48>>1]=HEAP16[$133+48>>1]|0;
 STACKTOP = sp;return;
}
function __ZN8GUIStyle8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i3$i$i$i = 0, $$pre$i$i$i6 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$i15Z2D = 0, $$pre$phi$i$i$i4$i$i$iZ2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0;
 var $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre6$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($this) + 16|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($1,$transfer);
 $2 = (($this) + 32|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($2,$transfer);
 $3 = (($this) + 36|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($3,$transfer);
 $4 = (($this) + 52|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($4,$transfer);
 $5 = (($this) + 56|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($5,$transfer);
 $6 = (($this) + 72|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($6,$transfer);
 $7 = (($this) + 76|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($7,$transfer);
 $8 = (($this) + 92|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($8,$transfer);
 $9 = (($this) + 96|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($9,$transfer);
 $10 = (($this) + 112|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 $11 = (($this) + 116|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($11,$transfer);
 $12 = (($this) + 132|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$transfer);
 $13 = (($this) + 136|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($13,$transfer);
 $14 = (($this) + 152|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb1EEEEvRT_($14,$transfer);
 $15 = (($this) + 156|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($15,$transfer);
 $16 = (($this) + 172|0);
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb1EEEEvRT_($16,$transfer);
 $17 = (($this) + 188|0);
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb1EEEEvRT_($17,$transfer);
 $18 = (($this) + 204|0);
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb1EEEEvRT_($18,$transfer);
 $19 = (($this) + 220|0);
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb1EEEEvRT_($19,$transfer);
 $20 = (($this) + 236|0);
 __ZN4PPtrIN13TextRendering4FontEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($20,$transfer);
 $21 = (($this) + 280|0);
 $22 = (($transfer) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 4|0);
 $25 = (($transfer) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24>>>0)>($26>>>0);
 if ($27) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$21,4);
  $$pre$i$i$i = HEAP32[$21>>2]|0;
  $$pre = HEAP32[$22>>2]|0;
  $$pre19 = HEAP32[$25>>2]|0;
  $29 = $$pre$i$i$i;$33 = $$pre;$35 = $$pre19;
 } else {
  $28 = HEAP32[$23>>2]|0;
  HEAP32[$21>>2] = $28;
  HEAP32[$22>>2] = $24;
  $29 = $28;$33 = $24;$35 = $26;
 }
 $30 = (_llvm_bswap_i32(($29|0))|0);
 HEAP32[$21>>2] = $30;
 $31 = (($this) + 284|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$31,4);
  $$pre$i$i$i1 = HEAP32[$31>>2]|0;
  $$pre20 = HEAP32[$22>>2]|0;
  $$pre21 = HEAP32[$25>>2]|0;
  $37 = $$pre$i$i$i1;$41 = $$pre20;$43 = $$pre21;
 } else {
  $36 = HEAP32[$33>>2]|0;
  HEAP32[$31>>2] = $36;
  HEAP32[$22>>2] = $32;
  $37 = $36;$41 = $32;$43 = $35;
 }
 $38 = (_llvm_bswap_i32(($37|0))|0);
 HEAP32[$31>>2] = $38;
 $39 = (($this) + 240|0);
 $40 = (($41) + 4|0);
 $42 = ($40>>>0)>($43>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$39,4);
  $$pre$i$i$i3 = HEAP32[$39>>2]|0;
  $$pre22 = HEAP32[$22>>2]|0;
  $$pre23 = HEAP32[$25>>2]|0;
  $45 = $$pre$i$i$i3;$49 = $$pre22;$51 = $$pre23;
 } else {
  $44 = HEAP32[$41>>2]|0;
  HEAP32[$39>>2] = $44;
  HEAP32[$22>>2] = $40;
  $45 = $44;$49 = $40;$51 = $43;
 }
 $46 = (_llvm_bswap_i32(($45|0))|0);
 HEAP32[$39>>2] = $46;
 $47 = (($this) + 244|0);
 $48 = (($49) + 1|0);
 $50 = ($48>>>0)>($51>>>0);
 if ($50) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$47,1);
  $$pre24 = HEAP32[$22>>2]|0;
  $57 = $$pre24;
 } else {
  $52 = HEAP8[$49>>0]|0;
  HEAP8[$47>>0] = $52;
  $53 = HEAP32[$22>>2]|0;
  $54 = (($53) + 1|0);
  HEAP32[$22>>2] = $54;
  $57 = $54;
 }
 $55 = (($this) + 245|0);
 $56 = (($57) + 1|0);
 $58 = HEAP32[$25>>2]|0;
 $59 = ($56>>>0)>($58>>>0);
 if ($59) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$55,1);
 } else {
  $60 = HEAP8[$57>>0]|0;
  HEAP8[$55>>0] = $60;
  $61 = HEAP32[$22>>2]|0;
  $62 = (($61) + 1|0);
  HEAP32[$22>>2] = $62;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $63 = (($this) + 248|0);
 $64 = HEAP32[$22>>2]|0;
 $65 = (($64) + 4|0);
 $66 = HEAP32[$25>>2]|0;
 $67 = ($65>>>0)>($66>>>0);
 if ($67) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$63,4);
  $$pre$i$i$i6 = HEAP32[$63>>2]|0;
  $$pre25 = HEAP32[$22>>2]|0;
  $$pre26 = HEAP32[$25>>2]|0;
  $69 = $$pre$i$i$i6;$73 = $$pre25;$75 = $$pre26;
 } else {
  $68 = HEAP32[$64>>2]|0;
  HEAP32[$63>>2] = $68;
  HEAP32[$22>>2] = $65;
  $69 = $68;$73 = $65;$75 = $66;
 }
 $70 = (_llvm_bswap_i32(($69|0))|0);
 HEAP32[$63>>2] = $70;
 $71 = (($this) + 252|0);
 $72 = (($73) + 4|0);
 $74 = ($72>>>0)>($75>>>0);
 if ($74) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$71,4);
  $$pre$i$i$i8 = HEAP32[$71>>2]|0;
  $$pre27 = HEAP32[$22>>2]|0;
  $$pre28 = HEAP32[$25>>2]|0;
  $77 = $$pre$i$i$i8;$81 = $$pre27;$83 = $$pre28;
 } else {
  $76 = HEAP32[$73>>2]|0;
  HEAP32[$71>>2] = $76;
  HEAP32[$22>>2] = $72;
  $77 = $76;$81 = $72;$83 = $75;
 }
 $78 = (_llvm_bswap_i32(($77|0))|0);
 HEAP32[$71>>2] = $78;
 $79 = (($this) + 256|0);
 $80 = (($81) + 4|0);
 $82 = ($80>>>0)>($83>>>0);
 if ($82) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$79,4);
  $$pre$i$i$i3$i$i$i = HEAP32[$79>>2]|0;
  $$pre$i$i$i10 = HEAP32[$22>>2]|0;
  $$pre6$i$i$i = HEAP32[$25>>2]|0;
  $$pre$phi$i$i$i4$i$i$iZ2D = $79;$86 = $$pre$i$i$i3$i$i$i;$90 = $$pre$i$i$i10;$92 = $$pre6$i$i$i;
 } else {
  $84 = Math_fround(HEAPF32[$81>>2]);
  HEAPF32[$79>>2] = $84;
  HEAP32[$22>>2] = $80;
  $85 = (HEAPF32[tempDoublePtr>>2]=$84,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4$i$i$iZ2D = $79;$86 = $85;$90 = $80;$92 = $83;
 }
 $87 = (_llvm_bswap_i32(($86|0))|0);
 HEAP32[$$pre$phi$i$i$i4$i$i$iZ2D>>2] = $87;
 $88 = (($this) + 260|0);
 $89 = (($90) + 4|0);
 $91 = ($89>>>0)>($92>>>0);
 if ($91) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$88,4);
  $$pre$i$i$i$i$i$i = HEAP32[$88>>2]|0;
  $$pre29 = HEAP32[$22>>2]|0;
  $$pre30 = HEAP32[$25>>2]|0;
  $$pre$phi$i$i$i$i$i$iZ2D = $88;$101 = $$pre30;$95 = $$pre$i$i$i$i$i$i;$99 = $$pre29;
 } else {
  $93 = Math_fround(HEAPF32[$90>>2]);
  HEAPF32[$88>>2] = $93;
  HEAP32[$22>>2] = $89;
  $94 = (HEAPF32[tempDoublePtr>>2]=$93,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i$i$i$iZ2D = $88;$101 = $92;$95 = $94;$99 = $89;
 }
 $96 = (_llvm_bswap_i32(($95|0))|0);
 HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $96;
 $97 = (($this) + 272|0);
 $98 = (($99) + 4|0);
 $100 = ($98>>>0)>($101>>>0);
 if ($100) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$97,4);
  $$pre$i$i$i11 = HEAP32[$97>>2]|0;
  $$pre31 = HEAP32[$22>>2]|0;
  $$pre32 = HEAP32[$25>>2]|0;
  $$pre$phi$i$i$iZ2D = $97;$104 = $$pre$i$i$i11;$108 = $$pre31;$110 = $$pre32;
 } else {
  $102 = Math_fround(HEAPF32[$99>>2]);
  HEAPF32[$97>>2] = $102;
  HEAP32[$22>>2] = $98;
  $103 = (HEAPF32[tempDoublePtr>>2]=$102,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $97;$104 = $103;$108 = $98;$110 = $101;
 }
 $105 = (_llvm_bswap_i32(($104|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $105;
 $106 = (($this) + 276|0);
 $107 = (($108) + 4|0);
 $109 = ($107>>>0)>($110>>>0);
 if ($109) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$106,4);
  $$pre$i$i$i14 = HEAP32[$106>>2]|0;
  $$pre33 = HEAP32[$22>>2]|0;
  $$pre34 = HEAP32[$25>>2]|0;
  $$pre$phi$i$i$i15Z2D = $106;$113 = $$pre$i$i$i14;$117 = $$pre33;$119 = $$pre34;
 } else {
  $111 = Math_fround(HEAPF32[$108>>2]);
  HEAPF32[$106>>2] = $111;
  HEAP32[$22>>2] = $107;
  $112 = (HEAPF32[tempDoublePtr>>2]=$111,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i15Z2D = $106;$113 = $112;$117 = $107;$119 = $110;
 }
 $114 = (_llvm_bswap_i32(($113|0))|0);
 HEAP32[$$pre$phi$i$i$i15Z2D>>2] = $114;
 $115 = (($this) + 288|0);
 $116 = (($117) + 1|0);
 $118 = ($116>>>0)>($119>>>0);
 if ($118) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$115,1);
  $$pre35 = HEAP32[$22>>2]|0;
  $125 = $$pre35;
 } else {
  $120 = HEAP8[$117>>0]|0;
  HEAP8[$115>>0] = $120;
  $121 = HEAP32[$22>>2]|0;
  $122 = (($121) + 1|0);
  HEAP32[$22>>2] = $122;
  $125 = $122;
 }
 $123 = (($this) + 289|0);
 $124 = (($125) + 1|0);
 $126 = HEAP32[$25>>2]|0;
 $127 = ($124>>>0)>($126>>>0);
 if ($127) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$123,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $128 = HEAP8[$125>>0]|0;
  HEAP8[$123>>0] = $128;
  $129 = HEAP32[$22>>2]|0;
  $130 = (($129) + 1|0);
  HEAP32[$22>>2] = $130;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrIN13TextRendering4FontEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN10RectOffset8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre10 = 0, $$pre11 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre7;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre8;$21 = $$pre9;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $23 = $$pre$i$i$i3;$27 = $$pre10;$29 = $$pre11;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = $22;$27 = $18;$29 = $21;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$17>>2] = $24;
 $25 = (($this) + 12|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre$i$i$i5 = HEAP32[$25>>2]|0;
  $31 = $$pre$i$i$i5;
  $32 = (_llvm_bswap_i32(($31|0))|0);
  HEAP32[$25>>2] = $32;
  STACKTOP = sp;return;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = $30;
  $32 = (_llvm_bswap_i32(($31|0))|0);
  HEAP32[$25>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __Z22TransferField_NonArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $native = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $native = sp;
 __ZN11GradientNEWC2Ev($native);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(2864,($native|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $8 = (($staticInfo) + 20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP8[$runtimeInfo>>0]|0;
   $11 = ($10<<24>>24)!=(0);
   $12 = (($9) + -8)|0;
   $13 = $11 ? $9 : $12;
   $14 = (($runtimeInfo) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + ($13)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $19 = HEAP32[$converter>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_ii(3286,($19|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3549,($20|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    } else {
     $26 = $20;
    }
   } else {
    $26 = $17;
   }
   $25 = (($26) + 8|0);
   $27 = HEAP32[$25>>2]|0;
   $28 = HEAP32[$native>>2]|0;
   HEAP32[$27>>2] = $28;
   $29 = (($27) + 4|0);
   $30 = (($native) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[$29>>2] = $31;
   $32 = (($27) + 8|0);
   $33 = (($native) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   HEAP32[$32>>2] = $34;
   $35 = (($27) + 12|0);
   $36 = (($native) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$35>>2] = $37;
   $38 = (($27) + 16|0);
   $39 = (($native) + 16|0);
   $40 = HEAP32[$39>>2]|0;
   HEAP32[$38>>2] = $40;
   $41 = (($27) + 20|0);
   $42 = (($native) + 20|0);
   $43 = HEAP32[$42>>2]|0;
   HEAP32[$41>>2] = $43;
   $44 = (($27) + 24|0);
   $45 = (($native) + 24|0);
   $46 = HEAP32[$45>>2]|0;
   HEAP32[$44>>2] = $46;
   $47 = (($27) + 28|0);
   $48 = (($native) + 28|0);
   $49 = HEAP32[$48>>2]|0;
   HEAP32[$47>>2] = $49;
   $50 = (($27) + 32|0);
   $51 = (($native) + 32|0);
   dest=$50+0|0; src=$51+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
   $52 = HEAP32[$8>>2]|0;
   $53 = HEAP8[$runtimeInfo>>0]|0;
   $54 = ($53<<24>>24)!=(0);
   $55 = (($52) + -8)|0;
   $56 = $54 ? $52 : $55;
   $57 = HEAP32[$14>>2]|0;
   $58 = (($57) + ($56)|0);
   HEAP32[$58>>2] = $26;
   STACKTOP = sp;return;
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __THREW__ = 0;
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $59 = ___cxa_find_matching_catch(0|0)|0;
  $60 = tempRet0;
  ___clang_call_terminate($59);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __Z22TransferField_NonArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native = 0, $scripting1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 92|0;
 $0 = sp;
 $native = sp + 8|0;
 $scripting1 = sp + 88|0;
 $1 = (($native) + 4|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 HEAP32[$native>>2] = 0;
 $2 = (($native) + 8|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $3 = (($native) + 32|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($native) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($native) + 36|0);
 $6 = (($native) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($native) + 68|0);
 HEAP32[$7>>2] = 0;
 $8 = (($native) + 60|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$8>>2] = 61;
 $9 = (($native) + 76|0);
 HEAP32[$9>>2] = 2;
 $10 = (($native) + 72|0);
 HEAP32[$10>>2] = 2;
 $11 = (($runtimeInfo) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 invoke_vii(2865,($native|0),($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  $24 = (($staticInfo) + 20|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP8[$runtimeInfo>>0]|0;
  $27 = ($26<<24>>24)!=(0);
  $28 = (($25) + -8)|0;
  $29 = $27 ? $25 : $28;
  $30 = (($runtimeInfo) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + ($29)|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$scripting1>>2] = $33;
  __THREW__ = 0;
  invoke_viii(1798,($converter|0),($native|0),($scripting1|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if (!($35)) {
   $36 = HEAP32[$24>>2]|0;
   $37 = HEAP8[$runtimeInfo>>0]|0;
   $38 = ($37<<24>>24)!=(0);
   $39 = (($36) + -8)|0;
   $40 = $38 ? $36 : $39;
   $41 = HEAP32[$30>>2]|0;
   $42 = (($41) + ($40)|0);
   $43 = HEAP32[$scripting1>>2]|0;
   HEAP32[$42>>2] = $43;
   $44 = HEAP32[$7>>2]|0;
   $45 = ($44|0)>(-1);
   if (!($45)) {
    STACKTOP = sp;return;
   }
   $46 = (($native) + 56|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $48;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($47,$$byval_copy1);
   HEAP32[$46>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $17 = HEAP32[$7>>2]|0;
 $18 = ($17|0)>(-1);
 if (!($18)) {
  ___resumeException($15|0);
  // unreachable;
 }
 $19 = (($native) + 56|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $21;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($20|0),($$byval_copy1|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $49 = ___cxa_find_matching_catch(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 }
 HEAP32[$19>>2] = 0;
 ___resumeException($15|0);
 // unreachable;
}
function __ZN27Converter_SimpleNativeClassI17AnimationCurveTplIfEE17ScriptingToNativeERP15ScriptingObjectPS1_($this,$scriptingObject,$nativeObject) {
 $this = $this|0;
 $scriptingObject = $scriptingObject|0;
 $nativeObject = $nativeObject|0;
 var $$byval_copy1 = 0, $$idx$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$scriptingObject>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (_il2cpp_object_new($3)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($4);
  HEAP32[$scriptingObject>>2] = $4;
  $6 = $4;
 } else {
  $6 = $1;
 }
 $5 = (($6) + 8|0);
 $7 = HEAP32[$5>>2]|0;
 ;HEAP32[$nativeObject+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$nativeObject+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$nativeObject+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$nativeObject+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$nativeObject+16>>2]=HEAP32[$7+16>>2]|0;HEAP32[$nativeObject+20>>2]=HEAP32[$7+20>>2]|0;HEAP32[$nativeObject+24>>2]=HEAP32[$7+24>>2]|0;
 $8 = (($nativeObject) + 28|0);
 $9 = (($7) + 28|0);
 ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$9+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$9+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$9+24>>2]|0;
 $10 = (($nativeObject) + 56|0);
 $11 = ($7|0)==($nativeObject|0);
 if ($11) {
  $36 = (($nativeObject) + 72|0);
  $37 = (($7) + 72|0);
  $38 = $37;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 4)|0;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = $36;
  $45 = $44;
  HEAP32[$45>>2] = $40;
  $46 = (($44) + 4)|0;
  $47 = $46;
  HEAP32[$47>>2] = $43;
  STACKTOP = sp;return;
 }
 $12 = (($7) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($7) + 64|0);
 $15 = HEAP32[$14>>2]|0;
 $$idx$i = $15 << 4;
 $16 = $$idx$i >> 4;
 $17 = (($nativeObject) + 64|0);
 HEAP32[$17>>2] = $16;
 $18 = (($nativeObject) + 68|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & 2147483647;
 $21 = ($20>>>0)<($16>>>0);
 do {
  if ($21) {
   $22 = ($19|0)>(-1);
   if ($22) {
    HEAP32[$18>>2] = $16;
    $23 = HEAP32[$10>>2]|0;
    $24 = (($nativeObject) + 60|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$0>>2] = $25;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z16realloc_internalPvji10MemLabelIdiPKci($23,$$idx$i,4,$$byval_copy1,0,630440,370)|0);
    HEAP32[$10>>2] = $26;
    $35 = $26;
    break;
   } else {
    $27 = (($nativeObject) + 60|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$0>>2] = $28;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx$i,4,$$byval_copy1,0,630440,352)|0);
    $30 = HEAP32[$10>>2]|0;
    $31 = HEAP32[$17>>2]|0;
    $32 = $31 << 4;
    _memcpy(($29|0),($30|0),($32|0))|0;
    HEAP32[$18>>2] = $16;
    HEAP32[$10>>2] = $29;
    $35 = $29;
    break;
   }
  } else {
   $$pre$i$i = HEAP32[$10>>2]|0;
   $35 = $$pre$i$i;
  }
 } while(0);
 $33 = HEAP32[$17>>2]|0;
 $34 = $33 << 4;
 _memcpy(($35|0),($13|0),($34|0))|0;
 $36 = (($nativeObject) + 72|0);
 $37 = (($7) + 72|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $36;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 STACKTOP = sp;return;
}
function __ZN27Converter_SimpleNativeClassI17AnimationCurveTplIfEE17NativeToScriptingERKS1_RP15ScriptingObject($this,$native,$out_scripting) {
 $this = $this|0;
 $native = $native|0;
 $out_scripting = $out_scripting|0;
 var $$byval_copy1 = 0, $$idx$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$out_scripting>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (_il2cpp_object_new($3)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($4);
  HEAP32[$out_scripting>>2] = $4;
  $6 = $4;
 } else {
  $6 = $1;
 }
 $5 = (($6) + 8|0);
 $7 = HEAP32[$5>>2]|0;
 ;HEAP32[$7+0>>2]=HEAP32[$native+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$native+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$native+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$native+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$native+16>>2]|0;HEAP32[$7+20>>2]=HEAP32[$native+20>>2]|0;HEAP32[$7+24>>2]=HEAP32[$native+24>>2]|0;
 $8 = (($7) + 28|0);
 $9 = (($native) + 28|0);
 ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$8+16>>2]=HEAP32[$9+16>>2]|0;HEAP32[$8+20>>2]=HEAP32[$9+20>>2]|0;HEAP32[$8+24>>2]=HEAP32[$9+24>>2]|0;
 $10 = (($7) + 56|0);
 $11 = ($7|0)==($native|0);
 if ($11) {
  $36 = (($7) + 72|0);
  $37 = (($native) + 72|0);
  $38 = $37;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 4)|0;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = $36;
  $45 = $44;
  HEAP32[$45>>2] = $40;
  $46 = (($44) + 4)|0;
  $47 = $46;
  HEAP32[$47>>2] = $43;
  STACKTOP = sp;return;
 }
 $12 = (($native) + 56|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($native) + 64|0);
 $15 = HEAP32[$14>>2]|0;
 $$idx$i = $15 << 4;
 $16 = $$idx$i >> 4;
 $17 = (($7) + 64|0);
 HEAP32[$17>>2] = $16;
 $18 = (($7) + 68|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 & 2147483647;
 $21 = ($20>>>0)<($16>>>0);
 do {
  if ($21) {
   $22 = ($19|0)>(-1);
   if ($22) {
    HEAP32[$18>>2] = $16;
    $23 = HEAP32[$10>>2]|0;
    $24 = (($7) + 60|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$0>>2] = $25;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z16realloc_internalPvji10MemLabelIdiPKci($23,$$idx$i,4,$$byval_copy1,0,630440,370)|0);
    HEAP32[$10>>2] = $26;
    $35 = $26;
    break;
   } else {
    $27 = (($7) + 60|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$0>>2] = $28;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx$i,4,$$byval_copy1,0,630440,352)|0);
    $30 = HEAP32[$10>>2]|0;
    $31 = HEAP32[$17>>2]|0;
    $32 = $31 << 4;
    _memcpy(($29|0),($30|0),($32|0))|0;
    HEAP32[$18>>2] = $16;
    HEAP32[$10>>2] = $29;
    $35 = $29;
    break;
   }
  } else {
   $$pre$i$i = HEAP32[$10>>2]|0;
   $35 = $$pre$i$i;
  }
 } while(0);
 $33 = HEAP32[$17>>2]|0;
 $34 = $33 << 4;
 _memcpy(($35|0),($13|0),($34|0))|0;
 $36 = (($7) + 72|0);
 $37 = (($native) + 72|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $36;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplIfELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 72|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre$i$i$i1 = HEAP32[$1>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre3 = HEAP32[$5>>2]|0;
  $13 = $$pre;$15 = $$pre3;$9 = $$pre$i$i$i1;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $13 = $4;$15 = $6;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$1>>2] = $10;
 $11 = (($this) + 76|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$11,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $17 = $$pre$i$i$i;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$11>>2] = $18;
  __ZN17AnimationCurveTplIfE15InvalidateCacheEv($this);
  STACKTOP = sp;return;
 } else {
  $16 = HEAP32[$13>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$2>>2] = $12;
  $17 = $16;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$11>>2] = $18;
  __ZN17AnimationCurveTplIfE15InvalidateCacheEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplIfELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplIfELj4EEE19ResizeSTLStyleArrayERS3_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<4)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN11KeyframeTplIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 16|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = $23 << 4;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = $22 >> 4;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplIfELj4EEE19ResizeSTLStyleArrayERS3_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($data) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = $rs << 4;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,4,$$byval_copy1,0,630440,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = $rs << 4;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,4,$$byval_copy1,0,630440,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 << 4;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + ($rs<<4)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + ($24<<4)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$01$i$i+12>>2]=HEAP32[$1+12>>2]|0;
  }
  $31 = (($$01$i$i) + 16|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN11KeyframeTplIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $this;$12 = $$pre;$14 = $$pre16;$8 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $this;$12 = $2;$14 = $4;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $9;
 $10 = (($this) + 4|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre$i$i$i3 = HEAP32[$10>>2]|0;
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $10;$17 = $$pre$i$i$i3;$21 = $$pre17;$23 = $$pre18;
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $11;
  $16 = (HEAPF32[tempDoublePtr>>2]=$15,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $10;$17 = $16;$21 = $11;$23 = $14;
 }
 $18 = (_llvm_bswap_i32(($17|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $18;
 $19 = (($this) + 8|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  $$pre$i$i$i8 = HEAP32[$19>>2]|0;
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i9Z2D = $19;$26 = $$pre$i$i$i8;$30 = $$pre19;$32 = $$pre20;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $19;$26 = $25;$30 = $20;$32 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $27;
 $28 = (($this) + 12|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)>($32>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,4);
  $$pre$i$i$i13 = HEAP32[$28>>2]|0;
  $$pre$phi$i$i$i14Z2D = $28;$35 = $$pre$i$i$i13;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $36;
  STACKTOP = sp;return;
 } else {
  $33 = Math_fround(HEAPF32[$30>>2]);
  HEAPF32[$28>>2] = $33;
  HEAP32[$0>>2] = $29;
  $34 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $28;$35 = $34;
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $36;
  STACKTOP = sp;return;
 }
}
function __Z13TransferFieldI18StreamedBinaryReadILb1EELb0E16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $native$i = sp + 4|0;
 ;HEAP32[$native$i+0>>2]=0|0;HEAP32[$native$i+4>>2]=0|0;HEAP32[$native$i+8>>2]=0|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_viii(1623,($2|0),($native$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3377,($2|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $18 = HEAP8[$native$i>>0]|0;
   $19 = $18 & 1;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $23 = (($native$i) + 1|0);
    $24 = $23;
   } else {
    $21 = (($native$i) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $24 = $22;
   }
   __THREW__ = 0;
   $25 = (invoke_ii(3287,($24|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = (($staticInfo) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = HEAP8[$runtimeInfo>>0]|0;
    $31 = ($30<<24>>24)!=(0);
    $32 = (($29) + -8)|0;
    $33 = $31 ? $29 : $32;
    $34 = (($runtimeInfo) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + ($33)|0);
    HEAP32[$36>>2] = $25;
    $37 = HEAP8[$native$i>>0]|0;
    $38 = $37 & 1;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     STACKTOP = sp;return;
    }
    $40 = (($native$i) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($41|0),($$byval_copy1|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     $44 = ___cxa_find_matching_catch()|0;
     $45 = tempRet0;
     ___cxa_call_unexpected(($44|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $9 = HEAP8[$native$i>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  ___resumeException($7|0);
  // unreachable;
 }
 $12 = (($native$i) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  ___cxa_call_unexpected(($16|0));
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN16Converter_String17ScriptingToNativeEP15ScriptingObjectPNSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEE($this,$scriptingObject,$nativeObject) {
 $this = $this|0;
 $scriptingObject = $scriptingObject|0;
 $nativeObject = $nativeObject|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $p = sp;
 __Z24scripting_cpp_string_forP15ScriptingString($p,$scriptingObject);
 $0 = HEAP8[$p>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($p) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8|0)==(0);
 do {
  if ($7) {
   $9 = HEAP8[$nativeObject>>0]|0;
   $10 = $9 & 1;
   $11 = ($10<<24>>24)==(0);
   if ($11) {
    $15 = (($nativeObject) + 1|0);
    HEAP8[$15>>0] = 0;
    HEAP8[$nativeObject>>0] = 0;
    break;
   } else {
    $12 = (($nativeObject) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP8[$13>>0] = 0;
    $14 = (($nativeObject) + 4|0);
    HEAP32[$14>>2] = 0;
    break;
   }
  } else {
   if ($2) {
    $18 = (($p) + 1|0);
    $19 = $18;
   } else {
    $16 = (($p) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $19 = $17;
   }
   __THREW__ = 0;
   (invoke_iii(2353,($nativeObject|0),($19|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $27 = ___cxa_find_matching_catch()|0;
    $28 = tempRet0;
    $29 = HEAP8[$p>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if ($31) {
     ___resumeException($27|0);
     // unreachable;
    }
    $32 = (($p) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    __ZdlPv($33);
    ___resumeException($27|0);
    // unreachable;
   }
  }
 } while(0);
 $22 = HEAP8[$p>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (($p) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 __ZdlPv($26);
 STACKTOP = sp;return;
}
function __Z30TransferField_LinearCollectionI18StreamedBinaryReadILb1EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $array = 0, $linearCollectionField = 0, $newRuntimeInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $linearCollectionField = sp + 40|0;
 $array = sp;
 $0 = sp + 8|0;
 $newRuntimeInfo = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$runtimeInfo,$1);
 HEAP32[$array>>2] = 0;
 $2 = (($array) + 4|0);
 HEAP32[$2>>2] = -1;
 $3 = (($runtimeInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $18 = 0;
 } else {
  __ZN21LinearCollectionField8GetArrayEv($0,$linearCollectionField);
  $6 = $0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $array;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  $$pre = HEAP32[$3>>2]|0;
  $18 = $$pre;
 }
 $16 = HEAP8[$runtimeInfo>>0]|0;
 HEAP8[$newRuntimeInfo>>0] = $16;
 $17 = (($newRuntimeInfo) + 4|0);
 HEAP32[$17>>2] = $18;
 $19 = (($newRuntimeInfo) + 8|0);
 $20 = (($runtimeInfo) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = (($newRuntimeInfo) + 12|0);
 $23 = (($runtimeInfo) + 12|0);
 $24 = $23;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $22;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (($newRuntimeInfo) + 20|0);
 HEAP32[$34>>2] = $array;
 $35 = (($args) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($args,$newRuntimeInfo);
 $37 = HEAP32[$2>>2]|0;
 $38 = ($37|0)==(-1);
 if ($38) {
  STACKTOP = sp;return;
 }
 __ZN21LinearCollectionField8SetArrayERK9ArrayInfo($linearCollectionField,$array);
 STACKTOP = sp;return;
}
function __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI18StreamedBinaryReadILb1EEEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$partiallySetuplinearCollectionCommand,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $partiallySetuplinearCollectionCommand = $partiallySetuplinearCollectionCommand|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandQueueForSingleElement = 0, $or$cond = 0, $tfi$idx = 0, $tfi$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 44|0;
 $0 = sp;
 $args = sp + 4|0;
 $commandQueueForSingleElement = sp + 24|0;
 $tfi$idx = (($tfi) + 40|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI23TransferArrayField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$8>>2] = $12;
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 $13 = (($commandQueueForSingleElement) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($commandQueueForSingleElement) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($commandQueueForSingleElement) + 4|0);
 HEAP32[$15>>2] = 61;
 $16 = (($commandQueueForSingleElement) + 16|0);
 HEAP8[$16>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(386,($args|0),($commandQueueForSingleElement|0),($nameConversions|0),0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = (($tfi) + 25|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)!=(0);
   $$pre = HEAP32[$13>>2]|0;
   $22 = ($$pre|0)==(0);
   $or$cond = $21 & $22;
   if (!($or$cond)) {
    $31 = (($partiallySetuplinearCollectionCommand) + 44|0);
    HEAP32[$31>>2] = 2866;
    $32 = (($partiallySetuplinearCollectionCommand) + 48|0);
    HEAP32[$32>>2] = $$pre;
    $33 = HEAP32[$tfi$idx>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3284,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = (($partiallySetuplinearCollectionCommand) + 40|0);
    HEAP32[$37>>2] = $34;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($partiallySetuplinearCollectionCommand|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($commandQueueForSingleElement|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
   }
   $42 = HEAP32[$14>>2]|0;
   $43 = ($42|0)>(-1);
   if (!($43)) {
    STACKTOP = sp;return;
   }
   $44 = HEAP32[$commandQueueForSingleElement>>2]|0;
   $45 = HEAP32[$15>>2]|0;
   HEAP32[$0>>2] = $45;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($44,$$byval_copy1);
   HEAP32[$commandQueueForSingleElement>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$14>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$commandQueueForSingleElement>>2]|0;
 $28 = HEAP32[$15>>2]|0;
 HEAP32[$0>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $46 = ___cxa_find_matching_catch(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 }
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZL29CanTransferTypeAsNestedObjectI23TransferArrayField_InfoEbRKT_($tfi$0$1$val) {
 $tfi$0$1$val = $tfi$0$1$val|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z25scripting_class_get_flagsP14ScriptingClass($tfi$0$1$val)|0);
 $1 = $0 & 8192;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (__Z27scripting_class_is_abstractP14ScriptingClass($tfi$0$1$val)|0);
  if ($3) {
   $$0 = 0;
  } else {
   $4 = (__Z28scripting_class_is_interfaceP14ScriptingClass($tfi$0$1$val)|0);
   if ($4) {
    $$0 = 0;
   } else {
    $5 = (__Z25scripting_class_get_imageP14ScriptingClass($tfi$0$1$val)|0);
    $6 = (__Z20scripting_get_corlibv()|0);
    $7 = ($5|0)==($6|0);
    if ($7) {
     $$0 = 0;
    } else {
     $8 = (__Z14GetMonoManagerv()|0);
     $9 = (__ZN11MonoManager25GetAssemblyIndexFromImageEP14ScriptingImage($8,$5)|0);
     $not$ = ($9|0)!=(-1);
     $$0 = $not$;
    }
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL22Transfer_ManagedObjectI18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arrayOfManagedObjectsTransferer = 0, $newProvider = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $arrayOfManagedObjectsTransferer = sp;
 $newProvider = sp + 12|0;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $arrayOfManagedObjectsTransferer;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$arrayOfManagedObjectsTransferer>>2] = $7;
 $8 = (($args) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($arrayOfManagedObjectsTransferer) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = (($runtimeInfo) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14<<6)|0);
 HEAP32[$15>>2] = $17;
 $18 = (($newProvider) + 4|0);
 HEAP32[$18>>2] = $16;
 HEAP32[$newProvider>>2] = $16;
 $19 = (($newProvider) + 8|0);
 HEAP32[$19>>2] = $17;
 $$idx$i = $14 << 6;
 $20 = $$idx$i >> 6;
 $21 = (($newProvider) + 16|0);
 HEAP32[$21>>2] = $20;
 $22 = (($newProvider) + 12|0);
 HEAP32[$22>>2] = $20;
 $23 = (($arrayOfManagedObjectsTransferer) + 8|0);
 HEAP32[$23>>2] = $newProvider;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($1,$arrayOfManagedObjectsTransferer,0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre8 = 0, $$pre9 = 0, $$sroa$1$i = 0, $$sroa$12$i = 0, $$sroa$2 = 0, $$sroa$8 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i = 0, $instance$0$i = 0, $offset = 0, $size = 0, $size1 = 0, $storemerge = 0, $storemerge7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$sroa$12$i = sp + 72|0;
 $$sroa$1$i = sp + 102|0;
 $offset = sp + 56|0;
 $size = sp + 60|0;
 $size1 = sp + 64|0;
 $i = sp;
 $$sroa$2 = sp + 96|0;
 $$sroa$8 = sp + 99|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i3;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = HEAP32[$data>>2]|0;
 $26 = (($25) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==($24|0);
 $$pre13 = (($data) + 4|0);
 if ($28) {
  $58 = $25;
 } else {
  $29 = HEAP32[$$pre13>>2]|0;
  $30 = (__Z34scripting_class_array_element_sizeP14ScriptingClass($29)|0);
  $31 = HEAP32[$$pre13>>2]|0;
  $32 = (__Z19scripting_array_newP14ScriptingClassjj($31,$30,$24)|0);
  $33 = HEAP32[$data>>2]|0;
  HEAP32[$33>>2] = $32;
  $34 = HEAP32[$data>>2]|0;
  $35 = (($34) + 4|0);
  HEAP32[$35>>2] = $24;
  $58 = $34;
 }
 $36 = (($i) + 24|0);
 HEAP8[$36>>0] = 1;
 $37 = (($i) + 28|0);
 HEAP32[$37>>2] = 0;
 $38 = (($i) + 32|0);
 HEAP32[$38>>2] = 0;
 $39 = (($i) + 40|0);
 HEAP32[$39>>2] = 0;
 $40 = (($i) + 44|0);
 HEAP32[$40>>2] = 0;
 $41 = HEAP32[$$pre13>>2]|0;
 $42 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($41)|0);
 $43 = $42&1;
 $44 = HEAP32[$data>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = (__Z26scripting_object_get_classP15ScriptingObject($45)|0);
 $47 = (__Z28scripting_array_element_sizeP14ScriptingClass($46)|0);
 $48 = HEAP32[$$pre13>>2]|0;
 $49 = (($data) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($50) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = $53;
 $55 = $51;
 $56 = (($54) - ($55))|0;
 $57 = $56 >> 6;
 HEAP32[$i>>2] = $58;
 $59 = (($i) + 4|0);
 HEAP8[$59>>0] = $43;
 $60 = (($i) + 5|0);
 ;HEAP8[$60+0>>0]=HEAP8[$$sroa$2+0>>0]|0;HEAP8[$60+1>>0]=HEAP8[$$sroa$2+1>>0]|0;HEAP8[$60+2>>0]=HEAP8[$$sroa$2+2>>0]|0;
 $61 = (($i) + 8|0);
 HEAP32[$61>>2] = $47;
 $62 = (($i) + 12|0);
 HEAP32[$62>>2] = 0;
 $63 = (($i) + 16|0);
 HEAP32[$63>>2] = $48;
 $64 = (($i) + 20|0);
 HEAP8[$36>>0] = 1;
 $65 = (($i) + 25|0);
 ;HEAP8[$65+0>>0]=HEAP8[$$sroa$8+0>>0]|0;HEAP8[$65+1>>0]=HEAP8[$$sroa$8+1>>0]|0;HEAP8[$65+2>>0]=HEAP8[$$sroa$8+2>>0]|0;
 HEAP32[$37>>2] = 0;
 HEAP32[$38>>2] = 0;
 $66 = (($i) + 36|0);
 HEAP32[$66>>2] = $51;
 HEAP32[$39>>2] = $51;
 HEAP32[$40>>2] = $53;
 $67 = (($i) + 48|0);
 HEAP32[$67>>2] = $57;
 $68 = (($i) + 52|0);
 HEAP32[$68>>2] = $57;
 $69 = ($23|0)==(0);
 if ($69) {
  STACKTOP = sp;return;
 }
 $70 = (($i) + 36|0);
 $71 = (($$sroa$12$i) + 16|0);
 $72 = (($$sroa$12$i) + 12|0);
 $73 = $51;$75 = $58;$76 = 0;$77 = $47;
 while(1) {
  HEAP32[$39>>2] = $73;
  HEAP32[$64>>2] = $70;
  $74 = HEAP32[$75>>2]|0;
  $78 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($74,$76,$77)|0);
  $79 = HEAP8[$59>>0]|0;
  $80 = ($79<<24>>24)==(0);
  if ($80) {
   $82 = HEAP32[$78>>2]|0;
   $83 = ($82|0)==(0|0);
   if ($83) {
    $84 = HEAP32[$63>>2]|0;
    $85 = (_il2cpp_object_new($84)|0);
    __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($85);
    $86 = HEAP32[$i>>2]|0;
    $87 = HEAP32[$86>>2]|0;
    $88 = HEAP32[$62>>2]|0;
    __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($87,$88,$85);
    $instance$0$i = $85;
   } else {
    $instance$0$i = $82;
   }
   $89 = HEAP32[$63>>2]|0;
   HEAP8[$36>>0] = 1;
   ;HEAP8[$65+0>>0]=HEAP8[$$sroa$1$i+0>>0]|0;HEAP8[$65+1>>0]=HEAP8[$$sroa$1$i+1>>0]|0;HEAP8[$65+2>>0]=HEAP8[$$sroa$1$i+2>>0]|0;
   $storemerge = $89;$storemerge7 = $instance$0$i;
  } else {
   $81 = HEAP32[$63>>2]|0;
   HEAP8[$36>>0] = 0;
   ;HEAP8[$65+0>>0]=HEAP8[$$sroa$12$i+0>>0]|0;HEAP8[$65+1>>0]=HEAP8[$$sroa$12$i+1>>0]|0;HEAP8[$65+2>>0]=HEAP8[$$sroa$12$i+2>>0]|0;
   $storemerge = $81;$storemerge7 = $78;
  }
  HEAP32[$37>>2] = $storemerge7;
  HEAP32[$38>>2] = $storemerge;
  $90 = HEAP32[$64>>2]|0;
  ;HEAP32[$$sroa$12$i+0>>2]=0|0;HEAP32[$$sroa$12$i+4>>2]=0|0;HEAP32[$$sroa$12$i+8>>2]=0|0;HEAP32[$$sroa$12$i+12>>2]=0|0;HEAP32[$$sroa$12$i+16>>2]=0|0;HEAP32[$$sroa$12$i+20>>2]=0|0;
  HEAP32[$71>>2] = $this;
  ;HEAP32[$$sroa$12$i+0>>2]=HEAP32[$36+0>>2]|0;HEAP32[$$sroa$12$i+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$$sroa$12$i+8>>2]=HEAP32[$36+8>>2]|0;
  HEAP32[$72>>2] = $90;
  $91 = (($90) + 4|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (($90) + 8|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ($92|0)==($94|0);
  if (!($95)) {
   $96 = (($90) + 12|0);
   $100 = $94;$98 = $92;
   while(1) {
    $97 = (($98) + 64|0);
    HEAP32[$91>>2] = $97;
    $99 = $100;
    $101 = $97;
    $102 = (($99) - ($101))|0;
    $103 = $102 >> 6;
    HEAP32[$96>>2] = $103;
    $104 = HEAP32[$98>>2]|0;
    $105 = (($98) + 4|0);
    FUNCTION_TABLE_vii[$104 & 4095]($105,$$sroa$12$i);
    $106 = HEAP32[$91>>2]|0;
    $107 = HEAP32[$93>>2]|0;
    $108 = ($106|0)==($107|0);
    if ($108) {
     break;
    } else {
     $100 = $107;$98 = $106;
    }
   }
  }
  $109 = HEAP32[$62>>2]|0;
  $110 = (($109) + 1)|0;
  HEAP32[$62>>2] = $110;
  $111 = ($110|0)==($24|0);
  if ($111) {
   break;
  }
  $$pre10 = HEAP32[$70>>2]|0;
  $$pre11 = HEAP32[$i>>2]|0;
  $$pre12 = HEAP32[$61>>2]|0;
  $73 = $$pre10;$75 = $$pre11;$76 = $110;$77 = $$pre12;
 }
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 HEAP8[$converter>>0] = 0;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIaEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIh18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIhEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIs18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3218StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$converter>>2] = $3;
 $5 = (($converter) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($converter) + 8|0);
 HEAP32[$6>>2] = 0;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$013 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 32|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 12|0);
 ;HEAP32[$3+0>>2]=HEAP32[$converter+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$converter+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$converter+8>>2]|0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viii(1799,($5|0),($buffer|0),0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 4;
  } else {
   $25 = (($runtimeInfo) + 20|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($staticInfo) + 28|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$1>>2]|0;
   $30 = HEAP32[$buffer>>2]|0;
   $31 = $29;
   $32 = $30;
   $33 = (($31) - ($32))|0;
   $34 = (($33|0) / 12)&-1;
   $35 = (($26) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==($34|0);
   if (!($37)) {
    __THREW__ = 0;
    $38 = (invoke_ii(3288,($28|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $41 = (invoke_iiii(1554,($28|0),($38|0),($34|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 4;
     break;
    }
    HEAP32[$26>>2] = $41;
    HEAP32[$35>>2] = $34;
   }
   $44 = ($29|0)==($30|0);
   L8: do {
    if (!($44)) {
     $45 = (($buffer) + 12|0);
     $46 = (($buffer) + 20|0);
     $47 = (($buffer) + 16|0);
     $index$01$i = 0;
     while(1) {
      $48 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      $49 = (invoke_iii(2433,($48|0),($index$01$i|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
      $52 = HEAP32[$buffer>>2]|0;
      $53 = (($52) + (($index$01$i*12)|0)|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = HEAP32[$45>>2]|0;
      $56 = HEAP32[$46>>2]|0;
      $57 = HEAP32[$47>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_iiiii(245,($54|0),($55|0),($56|0),($57|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
      HEAP32[$49>>2] = $58;
      $61 = (($index$01$i) + 1)|0;
      $62 = ($61|0)==($34|0);
      if ($62) {
       break L8;
      } else {
       $index$01$i = $61;
      }
     }
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index3 = $11;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$25>>2]|0;
   $64 = (($63) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==(0);
   L16: do {
    if (!($66)) {
     $68 = $63;$index$013 = 0;
     while(1) {
      $67 = HEAP32[$68>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2433,($67|0),($index$013|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       break;
      }
      $71 = (($index$013) + 1)|0;
      $72 = HEAP32[$25>>2]|0;
      $73 = (($72) + 4|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($71|0)==($74|0);
      if ($75) {
       break L16;
      } else {
       $68 = $72;$index$013 = $71;
      }
     }
     $8 = ___cxa_find_matching_catch()|0;
     $9 = tempRet0;
     $lpad$phi$index = $8;$lpad$phi$index3 = $9;
     break L1;
    }
   } while(0);
   $76 = HEAP32[$buffer>>2]|0;
   $77 = ($76|0)==(0|0);
   if ($77) {
    STACKTOP = sp;return;
   }
   $78 = HEAP32[$1>>2]|0;
   $79 = ($78|0)==($76|0);
   if (!($79)) {
    $__new_last2$i$i$i$i$i$i$i = $76;
    $scevgep$i$i$i$i$i$i$i = (($78) + -12|0);
    $80 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($80)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $81 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $82 = $81 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($78) + (($82*12)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($76|0),($$byval_copy8|0));
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $85 = ___cxa_find_matching_catch()|0;
    $86 = tempRet0;
    ___cxa_call_unexpected(($85|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index3 = $13;
 }
 $14 = HEAP32[$buffer>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $16 = HEAP32[$1>>2]|0;
 $17 = ($16|0)==($14|0);
 if (!($17)) {
  $__new_last2$i$i$i$i$i$i$i1 = $14;
  $scevgep$i$i$i$i$i$i$i2 = (($16) + -12|0);
  $18 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($18)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $19 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 12)&-1;
  $20 = $19 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($16) + (($20*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($14|0),($$byval_copy8|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  ___cxa_call_unexpected(($23|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN12NativeBufferI27Converter_UnityEngineObjectE15SetupForWritingER9ArrayInfo($this,$inputArray) {
 $this = $this|0;
 $inputArray = $inputArray|0;
 var $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $index$01 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inputArray) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($1>>>0);
 if ($9) {
  $10 = (($1) - ($8))|0;
  __ZNSt3__16vectorI8MonoPPtr13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$10);
 } else {
  $11 = ($8>>>0)>($1>>>0);
  if ($11) {
   $12 = (($4) + (($1*12)|0)|0);
   $13 = ($3|0)==($12|0);
   if (!($13)) {
    $__new_last2$i$i$i = $12;
    $scevgep$i$i$i = (($3) + -12|0);
    $14 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($14)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $15 = (($uglygep3$i$i$i>>>0) / 12)&-1;
    $16 = $15 ^ -1;
    $scevgep4$i$i$i = (($3) + (($16*12)|0)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i;
   }
  }
 }
 $17 = ($1|0)==(0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $index$01 = 0;
 while(1) {
  $18 = HEAP32[$inputArray>>2]|0;
  $19 = (__ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi($18,$index$01)|0);
  $$val = HEAP32[$19>>2]|0;
  $20 = ($$val|0)==(0|0);
  if (!($20)) {
   $21 = HEAP32[$this>>2]|0;
   $22 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($$val)|0);
   $23 = (($21) + (($index$01*12)|0)|0);
   HEAP32[$23>>2] = $22;
  }
  $24 = (($index$01) + 1)|0;
  $25 = ($24|0)==($1|0);
  if ($25) {
   break;
  } else {
   $index$01 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8MonoPPtr13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI8MonoPPtr13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 12|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI8MonoPPtr13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy5 = 0, $$idx = 0, $$pre = 0, $$pre44 = 0, $$pre45 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i22 = 0, $__new_last2$i$i$i$i$i31 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i23 = 0, $scevgep$i$i$i$i$i32 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i27 = 0, $scevgep4$i$i$i$i$i36 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i25 = 0, $uglygep$i$i$i$i$i34 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i26 = 0, $uglygep3$i$i$i$i$i35 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $temp = sp + 8|0;
 $1 = sp + 20|0;
 $2 = sp + 24|0;
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$v>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ($9>>>0)<($sz>>>0);
 if (!($10)) {
  $70 = ($9>>>0)>($sz>>>0);
  if (!($70)) {
   STACKTOP = sp;return;
  }
  $71 = (($5) + (($sz*12)|0)|0);
  $$idx = ($sz*12)|0;
  $72 = (($$idx|0) / 12)&-1;
  $73 = ($sz|0)==(0);
  do {
   if ($73) {
    $101 = 0;$102 = 0;$104 = 0;$106 = $5;
   } else {
    $74 = ($$idx|0)<(0);
    if ($74) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if (!($76)) {
      // unreachable;
     }
    } else {
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $77 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy5|0),0,(630440|0),79)|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if (!($79)) {
      $81 = $77;$83 = $5;
      while(1) {
       $80 = ($81|0)==(0|0);
       if ($80) {
        $97 = 0;
       } else {
        $82 = HEAP32[$83>>2]|0;
        HEAP32[$81>>2] = $82;
        $84 = (($81) + 4|0);
        $85 = (($83) + 4|0);
        $86 = $85;
        $87 = $86;
        $88 = HEAP32[$87>>2]|0;
        $89 = (($86) + 4)|0;
        $90 = $89;
        $91 = HEAP32[$90>>2]|0;
        $92 = $84;
        $93 = $92;
        HEAP32[$93>>2] = $88;
        $94 = (($92) + 4)|0;
        $95 = $94;
        HEAP32[$95>>2] = $91;
        $97 = $81;
       }
       $96 = (($97) + 12|0);
       $98 = (($83) + 12|0);
       $99 = ($98|0)==($71|0);
       if ($99) {
        break;
       } else {
        $81 = $96;$83 = $98;
       }
      }
      $100 = (($77) + (($72*12)|0)|0);
      $$pre = HEAP32[$v>>2]|0;
      $101 = $77;$102 = $96;$104 = $100;$106 = $$pre;
      break;
     }
    }
    $111 = ___cxa_find_matching_catch()|0;
    $112 = tempRet0;
    $$0 = $112;$$01 = $111;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $101;
  HEAP32[$3>>2] = $102;
  $103 = (($v) + 8|0);
  HEAP32[$103>>2] = $104;
  $105 = ($106|0)==(0|0);
  if ($105) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($106|0),($$byval_copy5|0));
  $107 = __THREW__; __THREW__ = 0;
  $108 = $107&1;
  if ($108) {
   $109 = ___cxa_find_matching_catch()|0;
   $110 = tempRet0;
   ___cxa_call_unexpected(($109|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $11 = (($v) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($7))|0;
 $15 = (($14|0) / 12)&-1;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $69 = (($sz) - ($9))|0;
  __ZNSt3__16vectorI8MonoPPtr13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$69);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2867,($temp|0),($sz|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if (!($20)) {
   $21 = HEAP32[$v>>2]|0;
   HEAP32[$1>>2] = $21;
   $22 = HEAP32[$3>>2]|0;
   HEAP32[$2>>2] = $22;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viii(1800,($temp|0),($$byval_copy|0),($$byval_copy5|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$17>>2]|0;
    $26 = HEAP32[$temp>>2]|0;
    $27 = $25;
    $28 = $26;
    $29 = (($27) - ($28))|0;
    $30 = (($29|0) / 12)&-1;
    $31 = ($30>>>0)<($sz>>>0);
    if ($31) {
     $32 = (($sz) - ($30))|0;
     __THREW__ = 0;
     invoke_vii(2868,($temp|0),($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     $$pre44 = HEAP32[$temp>>2]|0;
     $$pre45 = HEAP32[$17>>2]|0;
     $42 = $$pre44;$44 = $$pre45;
    } else {
     $35 = ($30>>>0)>($sz>>>0);
     if ($35) {
      $36 = (($26) + (($sz*12)|0)|0);
      $37 = ($25|0)==($36|0);
      if ($37) {
       $42 = $26;$44 = $25;
      } else {
       $__new_last2$i$i$i = $36;
       $scevgep$i$i$i = (($25) + -12|0);
       $38 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($38)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $39 = (($uglygep3$i$i$i>>>0) / 12)&-1;
       $40 = $39 ^ -1;
       $scevgep4$i$i$i = (($25) + (($40*12)|0)|0);
       HEAP32[$17>>2] = $scevgep4$i$i$i;
       $42 = $26;$44 = $scevgep4$i$i$i;
      }
     } else {
      $42 = $26;$44 = $25;
     }
    }
    $41 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $41;
    HEAP32[$v>>2] = $42;
    $43 = HEAP32[$3>>2]|0;
    HEAP32[$17>>2] = $43;
    HEAP32[$3>>2] = $44;
    $45 = HEAP32[$18>>2]|0;
    $46 = HEAP32[$11>>2]|0;
    HEAP32[$18>>2] = $46;
    HEAP32[$11>>2] = $45;
    $47 = ($41|0)==(0|0);
    if ($47) {
     STACKTOP = sp;return;
    }
    $48 = ($43|0)==($41|0);
    if (!($48)) {
     $__new_last2$i$i$i$i$i22 = $41;
     $scevgep$i$i$i$i$i23 = (($43) + -12|0);
     $49 = (0 - ($__new_last2$i$i$i$i$i22))|0;
     $uglygep$i$i$i$i$i25 = (($scevgep$i$i$i$i$i23) + ($49)|0);
     $uglygep3$i$i$i$i$i26 = $uglygep$i$i$i$i$i25;
     $50 = (($uglygep3$i$i$i$i$i26>>>0) / 12)&-1;
     $51 = $50 ^ -1;
     $scevgep4$i$i$i$i$i27 = (($43) + (($51*12)|0)|0);
     HEAP32[$17>>2] = $scevgep4$i$i$i$i$i27;
    }
    HEAP32[$$byval_copy>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($41|0),($$byval_copy5|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     ___cxa_call_unexpected(($54|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 $58 = HEAP32[$temp>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
 $60 = HEAP32[$17>>2]|0;
 $61 = ($60|0)==($58|0);
 if (!($61)) {
  $__new_last2$i$i$i$i$i31 = $58;
  $scevgep$i$i$i$i$i32 = (($60) + -12|0);
  $62 = (0 - ($__new_last2$i$i$i$i$i31))|0;
  $uglygep$i$i$i$i$i34 = (($scevgep$i$i$i$i$i32) + ($62)|0);
  $uglygep3$i$i$i$i$i35 = $uglygep$i$i$i$i$i34;
  $63 = (($uglygep3$i$i$i$i$i35>>>0) / 12)&-1;
  $64 = $63 ^ -1;
  $scevgep4$i$i$i$i$i36 = (($60) + (($64*12)|0)|0);
  HEAP32[$17>>2] = $scevgep4$i$i$i$i$i36;
 }
 HEAP32[$$byval_copy>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($58|0),($$byval_copy5|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  ___cxa_call_unexpected(($67|0));
  // unreachable;
 } else {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8MonoPPtr13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $scevgep3 = 0;
 var $uglygep = 0, $uglygep2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($__n|0)==(0);
 if ($14) {
  $18 = 0;$21 = $10;$22 = $3;
 } else {
  $15 = ($__n*12)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy1,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $18 = $16;$21 = $$pre4;$22 = $$pre;
 }
 $17 = (($18) + (($13*12)|0)|0);
 $19 = (($18) + (($__n*12)|0)|0);
 $20 = ($21|0)==($22|0);
 if ($20) {
  $46 = $17;$48 = $21;
 } else {
  $23 = $22;
  $24 = (($13) + -1)|0;
  $scevgep = (($21) + -12|0);
  $25 = (0 - ($23))|0;
  $uglygep = (($scevgep) + ($25)|0);
  $uglygep2 = $uglygep;
  $26 = (($uglygep2>>>0) / 12)&-1;
  $27 = (($24) - ($26))|0;
  $$01$i$i = $21;$31 = $17;
  while(1) {
   $28 = (($$01$i$i) + -12|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($31) + -12|0);
   HEAP32[$30>>2] = $29;
   $32 = (($31) + -8|0);
   $33 = (($$01$i$i) + -8|0);
   $34 = $33;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $32;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   $44 = (($31) + -12|0);
   $45 = ($28|0)==($22|0);
   if ($45) {
    break;
   } else {
    $$01$i$i = $28;$31 = $44;
   }
  }
  $scevgep3 = (($18) + (($27*12)|0)|0);
  $$pre$i = HEAP32[$this>>2]|0;
  $46 = $scevgep3;$48 = $$pre$i;
 }
 HEAP32[$this>>2] = $46;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $47 = ($48|0)==(0|0);
 if ($47) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($48|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8MonoPPtr13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre$i20 = 0, $$pre5$i = 0, $$pre5$i22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i8 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i9 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $70 = ($9|0)==(0|0);
  do {
   if ($70) {
    $83 = $8;
   } else {
    $71 = (($this) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==($9|0);
    if (!($73)) {
     $scevgep$i$i$i$i = (($72) + -12|0);
     $74 = (0 - ($11))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($74)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $75 = (($uglygep3$i$i$i$i>>>0) / 12)&-1;
     $76 = $75 ^ -1;
     $scevgep4$i$i$i$i = (($72) + (($76*12)|0)|0);
     HEAP32[$71>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy1|0));
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     $79 = ___cxa_find_matching_catch()|0;
     $80 = tempRet0;
     ___cxa_call_unexpected(($79|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$71>>2] = 0;
     HEAP32[$this>>2] = 0;
     $83 = 0;
     break;
    }
   }
  } while(0);
  $81 = ($5|0)<(0);
  if ($81) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $82 = $83;
  $84 = (($82|0) / 12)&-1;
  $85 = ($84>>>0)<(1073741823);
  if ($85) {
   $86 = $84 << 1;
   $87 = ($86>>>0)<($6>>>0);
   $88 = $87 ? $6 : $86;
   $89 = ($88|0)<(0);
   if ($89) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $88;
   }
  } else {
   $$0$i40 = 2147483647;
  }
  $90 = ($$0$i40*12)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $91 = (__Z15malloc_internaljj10MemLabelIdiPKci($90,16,$$byval_copy1,0,630440,79)|0);
  $92 = (($this) + 4|0);
  HEAP32[$92>>2] = $91;
  HEAP32[$this>>2] = $91;
  $93 = (($91) + (($$0$i40*12)|0)|0);
  HEAP32[$7>>2] = $93;
  $94 = ($1|0)==($2|0);
  if ($94) {
   STACKTOP = sp;return;
  } else {
   $96 = $91;$98 = $1;
  }
  while(1) {
   $95 = ($96|0)==(0|0);
   if ($95) {
    $112 = 0;
   } else {
    $97 = HEAP32[$98>>2]|0;
    HEAP32[$96>>2] = $97;
    $99 = (($96) + 4|0);
    $100 = (($98) + 4|0);
    $101 = $100;
    $102 = $101;
    $103 = HEAP32[$102>>2]|0;
    $104 = (($101) + 4)|0;
    $105 = $104;
    $106 = HEAP32[$105>>2]|0;
    $107 = $99;
    $108 = $107;
    HEAP32[$108>>2] = $103;
    $109 = (($107) + 4)|0;
    $110 = $109;
    HEAP32[$110>>2] = $106;
    $$pre5$i = HEAP32[$92>>2]|0;
    $112 = $$pre5$i;
   }
   $111 = (($112) + 12|0);
   HEAP32[$92>>2] = $111;
   $113 = (($98) + 12|0);
   $114 = ($113|0)==($2|0);
   if ($114) {
    break;
   } else {
    $96 = $111;$98 = $113;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16;
 $18 = (($17) - ($11))|0;
 $19 = (($18|0) / 12)&-1;
 $20 = ($6>>>0)>($19>>>0);
 if ($20) {
  $21 = (($1) + (($19*12)|0)|0);
  $23 = $21;$__growing$0$off0 = 1;
 } else {
  $23 = $2;$__growing$0$off0 = 0;
 }
 $22 = ($1|0)==($23|0);
 if ($22) {
  $$0$lcssa$i$i = $9;
 } else {
  $scevgep$i$i = (($23) + -12|0);
  $24 = (0 - ($4))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($24)|0);
  $uglygep5$i$i = $uglygep$i$i;
  $25 = (($uglygep5$i$i>>>0) / 12)&-1;
  $$01$i$i = $9;$27 = $1;
  while(1) {
   $26 = HEAP32[$27>>2]|0;
   HEAP32[$$01$i$i>>2] = $26;
   $28 = (($$01$i$i) + 4|0);
   $29 = (($27) + 4|0);
   $30 = $29;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $28;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
   $40 = (($27) + 12|0);
   $41 = (($$01$i$i) + 12|0);
   $42 = ($40|0)==($23|0);
   if ($42) {
    break;
   } else {
    $$01$i$i = $41;$27 = $40;
   }
  }
  $43 = (($25) + 1)|0;
  $scevgep6$i$i = (($9) + (($43*12)|0)|0);
  $$0$lcssa$i$i = $scevgep6$i$i;
 }
 if (!($__growing$0$off0)) {
  $65 = HEAP32[$15>>2]|0;
  $66 = ($65|0)==($$0$lcssa$i$i|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i8 = (($65) + -12|0);
  $67 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i9 = (($scevgep$i$i8) + ($67)|0);
  $uglygep3$i$i = $uglygep$i$i9;
  $68 = (($uglygep3$i$i>>>0) / 12)&-1;
  $69 = $68 ^ -1;
  $scevgep4$i$i = (($65) + (($69*12)|0)|0);
  HEAP32[$15>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $44 = ($23|0)==($2|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $$pre$i20 = HEAP32[$15>>2]|0;
 $46 = $$pre$i20;$48 = $23;
 while(1) {
  $45 = ($46|0)==(0|0);
  if ($45) {
   $62 = 0;
  } else {
   $47 = HEAP32[$48>>2]|0;
   HEAP32[$46>>2] = $47;
   $49 = (($46) + 4|0);
   $50 = (($48) + 4|0);
   $51 = $50;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($51) + 4)|0;
   $55 = $54;
   $56 = HEAP32[$55>>2]|0;
   $57 = $49;
   $58 = $57;
   HEAP32[$58>>2] = $53;
   $59 = (($57) + 4)|0;
   $60 = $59;
   HEAP32[$60>>2] = $56;
   $$pre5$i22 = HEAP32[$15>>2]|0;
   $62 = $$pre5$i22;
  }
  $61 = (($62) + 12|0);
  HEAP32[$15>>2] = $61;
  $63 = (($48) + 12|0);
  $64 = ($63|0)==($2|0);
  if ($64) {
   break;
  } else {
   $46 = $61;$48 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8MonoPPtr13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i712 = 0, $$0$i713 = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre$i2 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $scevgep = 0, $scevgep11 = 0, $uglygep = 0, $uglygep10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $15 = 0;
   } else {
    HEAP32[$11>>2] = 0;
    $12 = (($11) + 4|0);
    HEAP32[$12>>2] = 0;
    $13 = (($11) + 8|0);
    HEAP32[$13>>2] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $15 = $$pre1$i;
   }
   $14 = (($15) + 12|0);
   HEAP32[$3>>2] = $14;
   $16 = (($$0$i) + -1)|0;
   $17 = ($16|0)==(0);
   if ($17) {
    break;
   } else {
    $$0$i = $16;$11 = $14;
   }
  }
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = $18;
 $20 = (($6) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($__n))|0;
 $23 = ($22|0)<(0);
 if ($23) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $24 = (($5) - ($19))|0;
 $25 = (($24|0) / 12)&-1;
 $26 = ($25>>>0)<(1073741823);
 if ($26) {
  $27 = $25 << 1;
  $28 = ($27>>>0)<($22>>>0);
  $29 = $28 ? $22 : $27;
  $30 = ($29|0)==(0);
  if ($30) {
   $$0$i713 = 0;$34 = 0;
  } else {
   $$0$i712 = $29;
   label = 9;
  }
 } else {
  $$0$i712 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $31 = ($$0$i712*12)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $32 = (__Z15malloc_internaljj10MemLabelIdiPKci($31,16,$$byval_copy1,0,630440,79)|0);
  $$0$i713 = $$0$i712;$34 = $32;
 }
 $33 = (($34) + (($21*12)|0)|0);
 $$0$i4 = $__n;$36 = $33;
 while(1) {
  $35 = ($36|0)==(0|0);
  if ($35) {
   $40 = 0;
  } else {
   HEAP32[$36>>2] = 0;
   $37 = (($36) + 4|0);
   HEAP32[$37>>2] = 0;
   $38 = (($36) + 8|0);
   HEAP32[$38>>2] = 0;
   $40 = $36;
  }
  $39 = (($40) + 12|0);
  $41 = (($$0$i4) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $$0$i4 = $41;$36 = $39;
  }
 }
 $43 = (($34) + (($$0$i713*12)|0)|0);
 $44 = HEAP32[$this>>2]|0;
 $45 = HEAP32[$3>>2]|0;
 $46 = ($45|0)==($44|0);
 if ($46) {
  $70 = $33;$72 = $44;
 } else {
  $47 = $44;
  $48 = (($21) + -1)|0;
  $scevgep = (($45) + -12|0);
  $49 = (0 - ($47))|0;
  $uglygep = (($scevgep) + ($49)|0);
  $uglygep10 = $uglygep;
  $50 = (($uglygep10>>>0) / 12)&-1;
  $51 = (($48) - ($50))|0;
  $$01$i$i = $45;$55 = $33;
  while(1) {
   $52 = (($$01$i$i) + -12|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($55) + -12|0);
   HEAP32[$54>>2] = $53;
   $56 = (($55) + -8|0);
   $57 = (($$01$i$i) + -8|0);
   $58 = $57;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = (($58) + 4)|0;
   $62 = $61;
   $63 = HEAP32[$62>>2]|0;
   $64 = $56;
   $65 = $64;
   HEAP32[$65>>2] = $60;
   $66 = (($64) + 4)|0;
   $67 = $66;
   HEAP32[$67>>2] = $63;
   $68 = (($55) + -12|0);
   $69 = ($52|0)==($44|0);
   if ($69) {
    break;
   } else {
    $$01$i$i = $52;$55 = $68;
   }
  }
  $scevgep11 = (($34) + (($51*12)|0)|0);
  $$pre$i2 = HEAP32[$this>>2]|0;
  $70 = $scevgep11;$72 = $$pre$i2;
 }
 HEAP32[$this>>2] = $70;
 HEAP32[$3>>2] = $39;
 HEAP32[$1>>2] = $43;
 $71 = ($72|0)==(0|0);
 if ($71) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($72|0),($$byval_copy1|0));
 $73 = __THREW__; __THREW__ = 0;
 $74 = $73&1;
 if ($74) {
  $75 = ___cxa_find_matching_catch()|0;
  $76 = tempRet0;
  ___cxa_call_unexpected(($75|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $index$01$i = 0, $index$017 = 0, $invocation$i = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $method$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy10 = sp + 72|0;
 $method$i = sp;
 $invocation$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 48|0;
 $2 = sp + 52|0;
 $buffer = sp + 56|0;
 HEAP32[$buffer>>2] = 0;
 $3 = (($buffer) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($buffer) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[$converter>>2]|0;
 $6 = (($buffer) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (($runtimeInfo) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_viii(1801,($8|0),($buffer|0),0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 4;
  } else {
   $39 = (($runtimeInfo) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($staticInfo) + 28|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$3>>2]|0;
   $44 = HEAP32[$buffer>>2]|0;
   $45 = $43;
   $46 = $44;
   $47 = (($45) - ($46))|0;
   $48 = (($47|0) / 292)&-1;
   $49 = (($40) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==($48|0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_ii(3288,($42|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $55 = (invoke_iiii(1554,($42|0),($52|0),($48|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     label = 4;
     break;
    }
    HEAP32[$40>>2] = $55;
    HEAP32[$49>>2] = $48;
   }
   $58 = ($43|0)==($44|0);
   L8: do {
    if (!($58)) {
     $59 = (($buffer) + 12|0);
     $index$01$i = 0;
     while(1) {
      $60 = HEAP32[$40>>2]|0;
      __THREW__ = 0;
      $61 = (invoke_iii(2433,($60|0),($index$01$i|0))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
      $64 = HEAP32[$buffer>>2]|0;
      $65 = (($64) + (($index$01$i*292)|0)|0);
      __THREW__ = 0;
      invoke_viii(1797,($59|0),($65|0),($61|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$01$i) + 1)|0;
      $69 = ($68|0)==($48|0);
      if ($69) {
       break L8;
      } else {
       $index$01$i = $68;
      }
     }
     $13 = ___cxa_find_matching_catch()|0;
     $14 = tempRet0;
     $lpad$phi$index = $13;$lpad$phi$index3 = $14;
     break L1;
    }
   } while(0);
   $70 = HEAP32[$39>>2]|0;
   $71 = (($70) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0);
   L16: do {
    if (!($73)) {
     $74 = (($invocation$i) + 12|0);
     $76 = $70;$index$017 = 0;
     while(1) {
      $75 = HEAP32[$76>>2]|0;
      __THREW__ = 0;
      $77 = (invoke_iii(2433,($75|0),($index$017|0))|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       break;
      }
      $80 = HEAP32[$77>>2]|0;
      __THREW__ = 0;
      $81 = (invoke_i(84)|0);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      $84 = (($81) + 308|0);
      $85 = HEAP32[$84>>2]|0;
      __THREW__ = 0;
      invoke_viiii(388,($method$i|0),($85|0),(630336|0),1);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       break;
      }
      $88 = HEAP32[$method$i>>2]|0;
      $89 = ($88|0)==(0|0);
      if (!($89)) {
       $90 = $method$i;
       $91 = $90;
       $92 = HEAP32[$91>>2]|0;
       $93 = (($90) + 4)|0;
       $94 = $93;
       $95 = HEAP32[$94>>2]|0;
       $96 = $0;
       $97 = $96;
       HEAP32[$97>>2] = $92;
       $98 = (($96) + 4)|0;
       $99 = $98;
       HEAP32[$99>>2] = $95;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy10+4>>2]=HEAP32[$0+4>>2]|0;
       invoke_vii(2863,($invocation$i|0),($$byval_copy10|0));
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        break;
       }
       HEAP32[$74>>2] = $80;
       __THREW__ = 0;
       (invoke_ii(3285,($invocation$i|0))|0);
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if ($103) {
        break;
       }
      }
      $104 = (($index$017) + 1)|0;
      $105 = HEAP32[$39>>2]|0;
      $106 = (($105) + 4|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = ($104|0)==($107|0);
      if ($108) {
       break L16;
      } else {
       $76 = $105;$index$017 = $104;
      }
     }
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index3 = $12;
     break L1;
    }
   } while(0);
   $109 = HEAP32[$buffer>>2]|0;
   $110 = ($109|0)==(0|0);
   if ($110) {
    STACKTOP = sp;return;
   }
   $111 = HEAP32[$3>>2]|0;
   $112 = ($111|0)==($109|0);
   do {
    if ($112) {
     $126 = $109;
    } else {
     $114 = $111;
     while(1) {
      $113 = (($114) + -292|0);
      HEAP32[$3>>2] = $113;
      $115 = HEAP8[$113>>0]|0;
      $116 = $115 & 1;
      $117 = ($116<<24>>24)==(0);
      if ($117) {
       $119 = $113;
      } else {
       $120 = (($114) + -284|0);
       $121 = HEAP32[$120>>2]|0;
       HEAP32[$method$i>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$method$i+0>>2]|0;
       invoke_vii(2591,($121|0),($$byval_copy10|0));
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if ($123) {
        label = 41;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$3>>2]|0;
       $119 = $$pre$i$i$i$i$i$i$i;
      }
      $118 = ($119|0)==($109|0);
      if ($118) {
       label = 42;
       break;
      } else {
       $114 = $119;
      }
     }
     if ((label|0) == 41) {
      $124 = ___cxa_find_matching_catch()|0;
      $125 = tempRet0;
      ___cxa_call_unexpected(($124|0));
      // unreachable;
     }
     else if ((label|0) == 42) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $126 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$invocation$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$invocation$i+0>>2]|0;
   invoke_vii(2591,($126|0),($$byval_copy10|0));
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if ($128) {
    $129 = ___cxa_find_matching_catch()|0;
    $130 = tempRet0;
    ___cxa_call_unexpected(($129|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 }
 $17 = HEAP32[$buffer>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $19 = HEAP32[$3>>2]|0;
 $20 = ($19|0)==($17|0);
 do {
  if ($20) {
   $34 = $17;
  } else {
   $22 = $19;
   while(1) {
    $21 = (($22) + -292|0);
    HEAP32[$3>>2] = $21;
    $23 = HEAP8[$21>>0]|0;
    $24 = $23 & 1;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     $27 = $21;
    } else {
     $28 = (($22) + -284|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($29|0),($$byval_copy10|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 12;
      break;
     }
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$3>>2]|0;
     $27 = $$pre$i$i$i$i$i$i$i3;
    }
    $26 = ($27|0)==($17|0);
    if ($26) {
     label = 13;
     break;
    } else {
     $22 = $27;
    }
   }
   if ((label|0) == 12) {
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $34 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy10|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN12NativeBufferI27Converter_SimpleNativeClassI8GUIStyleEE15SetupForWritingER9ArrayInfo($this,$inputArray) {
 $this = $this|0;
 $inputArray = $inputArray|0;
 var $$byval_copy = 0, $$pre$i$i$i = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0);
 var $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0);
 var $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0);
 var $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0;
 var $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0);
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $index$01 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($inputArray) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 292)&-1;
 $10 = ($9>>>0)<($2>>>0);
 L1: do {
  if ($10) {
   $11 = (($2) - ($9))|0;
   __ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$11);
  } else {
   $12 = ($9>>>0)>($2>>>0);
   if ($12) {
    $13 = (($5) + (($2*292)|0)|0);
    $14 = ($4|0)==($13|0);
    if (!($14)) {
     $16 = $4;
     while(1) {
      $15 = (($16) + -292|0);
      HEAP32[$3>>2] = $15;
      $17 = HEAP8[$15>>0]|0;
      $18 = $17 & 1;
      $19 = ($18<<24>>24)==(0);
      if ($19) {
       $21 = $15;
      } else {
       $23 = (($16) + -284|0);
       $24 = HEAP32[$23>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($24|0),($$byval_copy|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       $$pre$i$i$i = HEAP32[$3>>2]|0;
       $21 = $$pre$i$i$i;
      }
      $20 = ($21|0)==($13|0);
      if ($20) {
       break L1;
      } else {
       $16 = $21;
      }
     }
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     ___cxa_call_unexpected(($27|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $22 = ($2|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $index$01 = 0;
 while(1) {
  $29 = HEAP32[$inputArray>>2]|0;
  $30 = (__ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi($29,$index$01)|0);
  $$val = HEAP32[$30>>2]|0;
  $31 = ($$val|0)==(0|0);
  if (!($31)) {
   $32 = HEAP32[$this>>2]|0;
   $33 = (($$val) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + (($index$01*292)|0)|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($35,$34)|0);
   $36 = (($34) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($32) + (($index$01*292)|0)|0) + 12|0);
   HEAP32[$38>>2] = $37;
   $39 = (($34) + 16|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = (($34) + 20|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = (($34) + 24|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($34) + 28|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = ((($32) + (($index$01*292)|0)|0) + 16|0);
   HEAPF32[$47>>2] = $40;
   $48 = ((($32) + (($index$01*292)|0)|0) + 20|0);
   HEAPF32[$48>>2] = $42;
   $49 = ((($32) + (($index$01*292)|0)|0) + 24|0);
   HEAPF32[$49>>2] = $44;
   $50 = ((($32) + (($index$01*292)|0)|0) + 28|0);
   HEAPF32[$50>>2] = $46;
   $51 = (($34) + 32|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($32) + (($index$01*292)|0)|0) + 32|0);
   HEAP32[$53>>2] = $52;
   $54 = (($34) + 36|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = (($34) + 40|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = (($34) + 44|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = (($34) + 48|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = ((($32) + (($index$01*292)|0)|0) + 36|0);
   HEAPF32[$62>>2] = $55;
   $63 = ((($32) + (($index$01*292)|0)|0) + 40|0);
   HEAPF32[$63>>2] = $57;
   $64 = ((($32) + (($index$01*292)|0)|0) + 44|0);
   HEAPF32[$64>>2] = $59;
   $65 = ((($32) + (($index$01*292)|0)|0) + 48|0);
   HEAPF32[$65>>2] = $61;
   $66 = (($34) + 52|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ((($32) + (($index$01*292)|0)|0) + 52|0);
   HEAP32[$68>>2] = $67;
   $69 = (($34) + 56|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = (($34) + 60|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = (($34) + 64|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = (($34) + 68|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = ((($32) + (($index$01*292)|0)|0) + 56|0);
   HEAPF32[$77>>2] = $70;
   $78 = ((($32) + (($index$01*292)|0)|0) + 60|0);
   HEAPF32[$78>>2] = $72;
   $79 = ((($32) + (($index$01*292)|0)|0) + 64|0);
   HEAPF32[$79>>2] = $74;
   $80 = ((($32) + (($index$01*292)|0)|0) + 68|0);
   HEAPF32[$80>>2] = $76;
   $81 = (($34) + 72|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ((($32) + (($index$01*292)|0)|0) + 72|0);
   HEAP32[$83>>2] = $82;
   $84 = (($34) + 76|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = (($34) + 80|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = (($34) + 84|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = (($34) + 88|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = ((($32) + (($index$01*292)|0)|0) + 76|0);
   HEAPF32[$92>>2] = $85;
   $93 = ((($32) + (($index$01*292)|0)|0) + 80|0);
   HEAPF32[$93>>2] = $87;
   $94 = ((($32) + (($index$01*292)|0)|0) + 84|0);
   HEAPF32[$94>>2] = $89;
   $95 = ((($32) + (($index$01*292)|0)|0) + 88|0);
   HEAPF32[$95>>2] = $91;
   $96 = (($34) + 92|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ((($32) + (($index$01*292)|0)|0) + 92|0);
   HEAP32[$98>>2] = $97;
   $99 = (($34) + 96|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = (($34) + 100|0);
   $102 = Math_fround(HEAPF32[$101>>2]);
   $103 = (($34) + 104|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = (($34) + 108|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = ((($32) + (($index$01*292)|0)|0) + 96|0);
   HEAPF32[$107>>2] = $100;
   $108 = ((($32) + (($index$01*292)|0)|0) + 100|0);
   HEAPF32[$108>>2] = $102;
   $109 = ((($32) + (($index$01*292)|0)|0) + 104|0);
   HEAPF32[$109>>2] = $104;
   $110 = ((($32) + (($index$01*292)|0)|0) + 108|0);
   HEAPF32[$110>>2] = $106;
   $111 = (($34) + 112|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ((($32) + (($index$01*292)|0)|0) + 112|0);
   HEAP32[$113>>2] = $112;
   $114 = (($34) + 116|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = (($34) + 120|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = (($34) + 124|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = (($34) + 128|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = ((($32) + (($index$01*292)|0)|0) + 116|0);
   HEAPF32[$122>>2] = $115;
   $123 = ((($32) + (($index$01*292)|0)|0) + 120|0);
   HEAPF32[$123>>2] = $117;
   $124 = ((($32) + (($index$01*292)|0)|0) + 124|0);
   HEAPF32[$124>>2] = $119;
   $125 = ((($32) + (($index$01*292)|0)|0) + 128|0);
   HEAPF32[$125>>2] = $121;
   $126 = (($34) + 132|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ((($32) + (($index$01*292)|0)|0) + 132|0);
   HEAP32[$128>>2] = $127;
   $129 = (($34) + 136|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = (($34) + 140|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = (($34) + 144|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = (($34) + 148|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = ((($32) + (($index$01*292)|0)|0) + 136|0);
   HEAPF32[$137>>2] = $130;
   $138 = ((($32) + (($index$01*292)|0)|0) + 140|0);
   HEAPF32[$138>>2] = $132;
   $139 = ((($32) + (($index$01*292)|0)|0) + 144|0);
   HEAPF32[$139>>2] = $134;
   $140 = ((($32) + (($index$01*292)|0)|0) + 148|0);
   HEAPF32[$140>>2] = $136;
   $141 = (($34) + 152|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = ((($32) + (($index$01*292)|0)|0) + 152|0);
   HEAP32[$143>>2] = $142;
   $144 = (($34) + 156|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = (($34) + 160|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = (($34) + 164|0);
   $149 = Math_fround(HEAPF32[$148>>2]);
   $150 = (($34) + 168|0);
   $151 = Math_fround(HEAPF32[$150>>2]);
   $152 = ((($32) + (($index$01*292)|0)|0) + 156|0);
   HEAPF32[$152>>2] = $145;
   $153 = ((($32) + (($index$01*292)|0)|0) + 160|0);
   HEAPF32[$153>>2] = $147;
   $154 = ((($32) + (($index$01*292)|0)|0) + 164|0);
   HEAPF32[$154>>2] = $149;
   $155 = ((($32) + (($index$01*292)|0)|0) + 168|0);
   HEAPF32[$155>>2] = $151;
   $156 = ((($32) + (($index$01*292)|0)|0) + 172|0);
   $157 = (($34) + 172|0);
   dest=$156+0|0; src=$157+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $158 = (($34) + 236|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = ((($32) + (($index$01*292)|0)|0) + 236|0);
   HEAP32[$160>>2] = $159;
   $161 = ((($32) + (($index$01*292)|0)|0) + 240|0);
   $162 = (($34) + 240|0);
   dest=$161+0|0; src=$162+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[$161+48>>1]=HEAP16[$162+48>>1]|0;
  }
  $163 = (($index$01) + 1)|0;
  $164 = ($163|0)==($2|0);
  if ($164) {
   break;
  } else {
   $index$01 = $163;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8GUIStyle13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI8GUIStyle13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN8GUIStyle8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 292|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*292)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI8GUIStyle13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy10 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre$i$i$i$i$i13 = 0, $$pre$i$i$i$i$i21 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $temp = 0, $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy10 = sp + 12|0;
 $$byval_copy7 = sp + 64|0;
 $0 = sp + 60|0;
 $1 = sp + 56|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = sp + 52|0;
 $5 = sp + 16|0;
 $temp = sp + 20|0;
 $6 = sp + 32|0;
 $7 = sp + 36|0;
 $temp1 = sp + 40|0;
 $8 = sp + 68|0;
 $9 = (($v) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$v>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 292)&-1;
 $16 = ($15>>>0)<($sz>>>0);
 if (!($16)) {
  $108 = ($15>>>0)>($sz>>>0);
  if (!($108)) {
   STACKTOP = sp;return;
  }
  $109 = (($11) + (($sz*292)|0)|0);
  HEAP32[$3>>2] = $11;
  HEAP32[$2>>2] = $109;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_viiiii(102,($temp1|0),($$byval_copy7|0),($$byval_copy10|0),($8|0),0);
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if ($111) {
   $139 = ___cxa_find_matching_catch()|0;
   $140 = tempRet0;
   $$0 = $140;$$01 = $139;
   ___resumeException($$01|0);
   // unreachable;
  }
  $112 = HEAP32[$temp1>>2]|0;
  $113 = HEAP32[$v>>2]|0;
  HEAP32[$temp1>>2] = $113;
  HEAP32[$v>>2] = $112;
  $114 = (($temp1) + 4|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = HEAP32[$9>>2]|0;
  HEAP32[$114>>2] = $116;
  HEAP32[$9>>2] = $115;
  $117 = (($temp1) + 8|0);
  $118 = (($v) + 8|0);
  $119 = HEAP32[$117>>2]|0;
  $120 = HEAP32[$118>>2]|0;
  HEAP32[$117>>2] = $120;
  HEAP32[$118>>2] = $119;
  $121 = ($113|0)==(0|0);
  if ($121) {
   STACKTOP = sp;return;
  }
  $122 = ($116|0)==($113|0);
  L13: do {
   if (!($122)) {
    $124 = $116;
    while(1) {
     $123 = (($124) + -292|0);
     HEAP32[$114>>2] = $123;
     $125 = HEAP8[$123>>0]|0;
     $126 = $125 & 1;
     $127 = ($126<<24>>24)==(0);
     if (!($127)) {
      $129 = (($124) + -284|0);
      $130 = HEAP32[$129>>2]|0;
      HEAP32[$4>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($130|0),($$byval_copy10|0));
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       break;
      }
     }
     $128 = ($123|0)==($113|0);
     if ($128) {
      break L13;
     } else {
      $124 = $123;
     }
    }
    $133 = ___cxa_find_matching_catch()|0;
    $134 = tempRet0;
    ___cxa_call_unexpected(($133|0));
    // unreachable;
   }
  } while(0);
  HEAP32[$5>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,($113|0),($$byval_copy10|0));
  $135 = __THREW__; __THREW__ = 0;
  $136 = $135&1;
  if ($136) {
   $137 = ___cxa_find_matching_catch()|0;
   $138 = tempRet0;
   ___cxa_call_unexpected(($137|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $17 = (($v) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18;
 $20 = (($19) - ($13))|0;
 $21 = (($20|0) / 292)&-1;
 $22 = ($21|0)==($sz|0);
 if ($22) {
  $107 = (($sz) - ($15))|0;
  __ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$107);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $23 = (($temp) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = (($temp) + 8|0);
 HEAP32[$24>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2869,($temp|0),($sz|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 L30: do {
  if (!($26)) {
   $27 = HEAP32[$v>>2]|0;
   HEAP32[$6>>2] = $27;
   $28 = HEAP32[$9>>2]|0;
   HEAP32[$7>>2] = $28;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$7+0>>2]|0;
   invoke_viii(1802,($temp|0),($$byval_copy7|0),($$byval_copy10|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    $31 = HEAP32[$23>>2]|0;
    $32 = HEAP32[$temp>>2]|0;
    $33 = $31;
    $34 = $32;
    $35 = (($33) - ($34))|0;
    $36 = (($35|0) / 292)&-1;
    $37 = ($36>>>0)<($sz>>>0);
    L33: do {
     if ($37) {
      $38 = (($sz) - ($36))|0;
      __THREW__ = 0;
      invoke_vii(2870,($temp|0),($38|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break L30;
      }
      $$pre = HEAP32[$23>>2]|0;
      $60 = $$pre;
     } else {
      $41 = ($36>>>0)>($sz>>>0);
      if ($41) {
       $42 = (($32) + (($sz*292)|0)|0);
       $43 = ($31|0)==($42|0);
       if ($43) {
        $60 = $31;
       } else {
        $45 = $31;
        while(1) {
         $44 = (($45) + -292|0);
         HEAP32[$23>>2] = $44;
         $46 = HEAP8[$44>>0]|0;
         $47 = $46 & 1;
         $48 = ($47<<24>>24)==(0);
         if ($48) {
          $50 = $44;
         } else {
          $51 = (($45) + -284|0);
          $52 = HEAP32[$51>>2]|0;
          HEAP32[$1>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
          invoke_vii(2591,($52|0),($$byval_copy10|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break;
          }
          $$pre$i$i$i8 = HEAP32[$23>>2]|0;
          $50 = $$pre$i$i$i8;
         }
         $49 = ($50|0)==($42|0);
         if ($49) {
          $60 = $42;
          break L33;
         } else {
          $45 = $50;
         }
        }
        $55 = ___cxa_find_matching_catch()|0;
        $56 = tempRet0;
        ___cxa_call_unexpected(($55|0));
        // unreachable;
       }
      } else {
       $60 = $31;
      }
     }
    } while(0);
    $57 = HEAP32[$temp>>2]|0;
    $58 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $58;
    HEAP32[$v>>2] = $57;
    $59 = HEAP32[$9>>2]|0;
    HEAP32[$23>>2] = $59;
    HEAP32[$9>>2] = $60;
    $61 = HEAP32[$24>>2]|0;
    $62 = HEAP32[$17>>2]|0;
    HEAP32[$24>>2] = $62;
    HEAP32[$17>>2] = $61;
    $63 = ($58|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($58|0);
    do {
     if ($64) {
      $78 = $58;
     } else {
      $66 = $59;
      while(1) {
       $65 = (($66) + -292|0);
       HEAP32[$23>>2] = $65;
       $67 = HEAP8[$65>>0]|0;
       $68 = $67 & 1;
       $69 = ($68<<24>>24)==(0);
       if ($69) {
        $71 = $65;
       } else {
        $72 = (($66) + -284|0);
        $73 = HEAP32[$72>>2]|0;
        HEAP32[$$byval_copy7>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$$byval_copy7+0>>2]|0;
        invoke_vii(2591,($73|0),($$byval_copy10|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 23;
         break;
        }
        $$pre$i$i$i$i$i13 = HEAP32[$23>>2]|0;
        $71 = $$pre$i$i$i$i$i13;
       }
       $70 = ($71|0)==($58|0);
       if ($70) {
        label = 24;
        break;
       } else {
        $66 = $71;
       }
      }
      if ((label|0) == 23) {
       $76 = ___cxa_find_matching_catch()|0;
       $77 = tempRet0;
       ___cxa_call_unexpected(($76|0));
       // unreachable;
      }
      else if ((label|0) == 24) {
       $$pre$i$i$i15 = HEAP32[$temp>>2]|0;
       $78 = $$pre$i$i$i15;
       break;
      }
     }
    } while(0);
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($78|0),($$byval_copy10|0));
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     $81 = ___cxa_find_matching_catch()|0;
     $82 = tempRet0;
     ___cxa_call_unexpected(($81|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $83 = ___cxa_find_matching_catch()|0;
 $84 = tempRet0;
 $85 = HEAP32[$temp>>2]|0;
 $86 = ($85|0)==(0|0);
 if ($86) {
  $$0 = $84;$$01 = $83;
  ___resumeException($$01|0);
  // unreachable;
 }
 $87 = HEAP32[$23>>2]|0;
 $88 = ($87|0)==($85|0);
 do {
  if ($88) {
   $102 = $85;
  } else {
   $90 = $87;
   while(1) {
    $89 = (($90) + -292|0);
    HEAP32[$23>>2] = $89;
    $91 = HEAP8[$89>>0]|0;
    $92 = $91 & 1;
    $93 = ($92<<24>>24)==(0);
    if ($93) {
     $95 = $89;
    } else {
     $96 = (($90) + -284|0);
     $97 = HEAP32[$96>>2]|0;
     HEAP32[$$byval_copy7>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$$byval_copy7+0>>2]|0;
     invoke_vii(2591,($97|0),($$byval_copy10|0));
     $98 = __THREW__; __THREW__ = 0;
     $99 = $98&1;
     if ($99) {
      label = 34;
      break;
     }
     $$pre$i$i$i$i$i21 = HEAP32[$23>>2]|0;
     $95 = $$pre$i$i$i$i$i21;
    }
    $94 = ($95|0)==($85|0);
    if ($94) {
     label = 35;
     break;
    } else {
     $90 = $95;
    }
   }
   if ((label|0) == 34) {
    $100 = ___cxa_find_matching_catch()|0;
    $101 = tempRet0;
    ___cxa_call_unexpected(($100|0));
    // unreachable;
   }
   else if ((label|0) == 35) {
    $$pre$i$i$i23 = HEAP32[$temp>>2]|0;
    $102 = $$pre$i$i$i23;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($102|0),($$byval_copy10|0));
 $103 = __THREW__; __THREW__ = 0;
 $104 = $103&1;
 if ($104) {
  $105 = ___cxa_find_matching_catch()|0;
  $106 = tempRet0;
  ___cxa_call_unexpected(($105|0));
  // unreachable;
 } else {
  $$0 = $84;$$01 = $83;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy4 = 0, $$pre = 0, $$pre$i = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 292)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($6))|0;
 $14 = (($13|0) / 292)&-1;
 $15 = ($__n|0)==(0);
 if ($15) {
  $19 = 0;$22 = $11;$23 = $4;
 } else {
  $16 = ($__n*292)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($16,16,$$byval_copy4,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre13 = HEAP32[$10>>2]|0;
  $19 = $17;$22 = $$pre13;$23 = $$pre;
 }
 $18 = (($19) + (($14*292)|0)|0);
 $20 = (($19) + (($__n*292)|0)|0);
 $21 = ($22|0)==($23|0);
 L7: do {
  if ($21) {
   HEAP32[$this>>2] = $18;
   HEAP32[$10>>2] = $18;
   HEAP32[$2>>2] = $20;
   $44 = $22;
  } else {
   $$01$i$i = $22;$25 = $18;
   while(1) {
    $24 = (($25) + -292|0);
    $26 = (($$01$i$i) + -292|0);
    __THREW__ = 0;
    invoke_vii(2871,($24|0),($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = ($26|0)==($23|0);
    if ($29) {
     label = 8;
     break;
    } else {
     $$01$i$i = $26;$25 = $24;
    }
   }
   if ((label|0) == 8) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre14 = HEAP32[$10>>2]|0;
    HEAP32[$this>>2] = $24;
    HEAP32[$10>>2] = $18;
    HEAP32[$2>>2] = $20;
    $30 = ($$pre14|0)==($$pre$i|0);
    if ($30) {
     $44 = $$pre$i;
     break;
    }
    $32 = $$pre14;
    while(1) {
     $31 = (($32) + -292|0);
     $33 = HEAP8[$31>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if (!($35)) {
      $37 = (($32) + -284|0);
      $38 = HEAP32[$37>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($38|0),($$byval_copy4|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
     }
     $36 = ($31|0)==($$pre$i|0);
     if ($36) {
      $44 = $$pre$i;
      break L7;
     } else {
      $32 = $31;
     }
    }
    $41 = ___cxa_find_matching_catch()|0;
    $42 = tempRet0;
    ___cxa_call_unexpected(($41|0));
    // unreachable;
   }
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $51 = ($18|0)==($25|0);
   L22: do {
    if (!($51)) {
     $53 = $18;
     while(1) {
      $52 = (($53) + -292|0);
      $54 = HEAP8[$52>>0]|0;
      $55 = $54 & 1;
      $56 = ($55<<24>>24)==(0);
      if (!($56)) {
       $58 = (($53) + -284|0);
       $59 = HEAP32[$58>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($59|0),($$byval_copy4|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        break;
       }
      }
      $57 = ($52|0)==($25|0);
      if ($57) {
       break L22;
      } else {
       $53 = $52;
      }
     }
     $62 = ___cxa_find_matching_catch()|0;
     $63 = tempRet0;
     ___cxa_call_unexpected(($62|0));
     // unreachable;
    }
   } while(0);
   $64 = ($19|0)==(0|0);
   if ($64) {
    ___resumeException($49|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($19|0),($$byval_copy4|0));
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if ($66) {
    $67 = ___cxa_find_matching_catch()|0;
    $68 = tempRet0;
    ___cxa_call_unexpected(($67|0));
    // unreachable;
   } else {
    ___resumeException($49|0);
    // unreachable;
   }
  }
 } while(0);
 $43 = ($44|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($44|0),($$byval_copy4|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $47 = ___cxa_find_matching_catch()|0;
  $48 = tempRet0;
  ___cxa_call_unexpected(($47|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i32 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy3 = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i13 = 0, $$pre$i4 = 0, $$pre1$i = 0, $$pre1$i15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0);
 var $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0;
 var $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0);
 var $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0;
 var $uglygep16$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$__first>>2]|0;
 $3 = HEAP32[$__last>>2]|0;
 $4 = $3;
 $5 = $2;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 292)&-1;
 $8 = (($this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = $9;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = (($13|0) / 292)&-1;
 $15 = ($7>>>0)>($14>>>0);
 if ($15) {
  $183 = ($10|0)==(0|0);
  do {
   if ($183) {
    $207 = $9;
   } else {
    $184 = (($this) + 4|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ($185|0)==($10|0);
    do {
     if ($186) {
      $200 = $10;
     } else {
      $188 = $185;
      while(1) {
       $187 = (($188) + -292|0);
       HEAP32[$184>>2] = $187;
       $189 = HEAP8[$187>>0]|0;
       $190 = $189 & 1;
       $191 = ($190<<24>>24)==(0);
       if ($191) {
        $193 = $187;
       } else {
        $194 = (($188) + -284|0);
        $195 = HEAP32[$194>>2]|0;
        HEAP32[$1>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($195|0),($$byval_copy3|0));
        $196 = __THREW__; __THREW__ = 0;
        $197 = $196&1;
        if ($197) {
         label = 28;
         break;
        }
        $$pre$i$i$i$i = HEAP32[$184>>2]|0;
        $193 = $$pre$i$i$i$i;
       }
       $192 = ($193|0)==($10|0);
       if ($192) {
        label = 29;
        break;
       } else {
        $188 = $193;
       }
      }
      if ((label|0) == 28) {
       $198 = ___cxa_find_matching_catch()|0;
       $199 = tempRet0;
       ___cxa_call_unexpected(($198|0));
       // unreachable;
      }
      else if ((label|0) == 29) {
       $$pre$i4 = HEAP32[$this>>2]|0;
       $200 = $$pre$i4;
       break;
      }
     }
    } while(0);
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($200|0),($$byval_copy3|0));
    $201 = __THREW__; __THREW__ = 0;
    $202 = $201&1;
    if ($202) {
     $203 = ___cxa_find_matching_catch()|0;
     $204 = tempRet0;
     ___cxa_call_unexpected(($203|0));
     // unreachable;
    } else {
     HEAP32[$8>>2] = 0;
     HEAP32[$184>>2] = 0;
     HEAP32[$this>>2] = 0;
     $207 = 0;
     break;
    }
   }
  } while(0);
  $205 = ($6|0)<(0);
  if ($205) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $206 = $207;
  $208 = (($206|0) / 292)&-1;
  $209 = ($208>>>0)<(1073741823);
  if ($209) {
   $210 = $208 << 1;
   $211 = ($210>>>0)<($7>>>0);
   $212 = $211 ? $7 : $210;
   $213 = ($212|0)<(0);
   if ($213) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i32 = $212;
   }
  } else {
   $$0$i32 = 2147483647;
  }
  $214 = ($$0$i32*292)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $215 = (__Z15malloc_internaljj10MemLabelIdiPKci($214,16,$$byval_copy3,0,630440,79)|0);
  $216 = (($this) + 4|0);
  HEAP32[$216>>2] = $215;
  HEAP32[$this>>2] = $215;
  $217 = (($215) + (($$0$i32*292)|0)|0);
  HEAP32[$8>>2] = $217;
  $218 = ($2|0)==($3|0);
  if ($218) {
   STACKTOP = sp;return;
  } else {
   $220 = $215;$221 = $2;
  }
  while(1) {
   $219 = ($220|0)==(0|0);
   if ($219) {
    $223 = 0;
   } else {
    __ZN8GUIStyleC2ERKS_($220,$221);
    $$pre1$i = HEAP32[$216>>2]|0;
    $223 = $$pre1$i;
   }
   $222 = (($223) + 292|0);
   HEAP32[$216>>2] = $222;
   $224 = (($221) + 292|0);
   $225 = ($224|0)==($3|0);
   if ($225) {
    break;
   } else {
    $220 = $222;$221 = $224;
   }
  }
  STACKTOP = sp;return;
 } else {
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17;
  $19 = (($18) - ($12))|0;
  $20 = (($19|0) / 292)&-1;
  $21 = ($7>>>0)>($20>>>0);
  if ($21) {
   $22 = (($2) + (($20*292)|0)|0);
   $24 = $22;$__growing$0$off0 = 1;
  } else {
   $24 = $3;$__growing$0$off0 = 0;
  }
  $23 = ($2|0)==($24|0);
  if ($23) {
   $$0$lcssa$i$i = $10;
  } else {
   $scevgep$i = (($24) + -292|0);
   $25 = (0 - ($5))|0;
   $uglygep$i = (($scevgep$i) + ($25)|0);
   $uglygep16$i = $uglygep$i;
   $26 = (($uglygep16$i>>>0) / 292)&-1;
   $$01$i$i = $10;$27 = $2;
   while(1) {
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($$01$i$i,$27)|0);
    $28 = (($27) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($$01$i$i) + 12|0);
    HEAP32[$30>>2] = $29;
    $31 = (($27) + 16|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = (($27) + 20|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($27) + 24|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = (($27) + 28|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = (($$01$i$i) + 16|0);
    HEAPF32[$39>>2] = $32;
    $40 = (($$01$i$i) + 20|0);
    HEAPF32[$40>>2] = $34;
    $41 = (($$01$i$i) + 24|0);
    HEAPF32[$41>>2] = $36;
    $42 = (($$01$i$i) + 28|0);
    HEAPF32[$42>>2] = $38;
    $43 = (($27) + 32|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($$01$i$i) + 32|0);
    HEAP32[$45>>2] = $44;
    $46 = (($27) + 36|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = (($27) + 40|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = (($27) + 44|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = (($27) + 48|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = (($$01$i$i) + 36|0);
    HEAPF32[$54>>2] = $47;
    $55 = (($$01$i$i) + 40|0);
    HEAPF32[$55>>2] = $49;
    $56 = (($$01$i$i) + 44|0);
    HEAPF32[$56>>2] = $51;
    $57 = (($$01$i$i) + 48|0);
    HEAPF32[$57>>2] = $53;
    $58 = (($27) + 52|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($$01$i$i) + 52|0);
    HEAP32[$60>>2] = $59;
    $61 = (($27) + 56|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = (($27) + 60|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = (($27) + 64|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = (($27) + 68|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = (($$01$i$i) + 56|0);
    HEAPF32[$69>>2] = $62;
    $70 = (($$01$i$i) + 60|0);
    HEAPF32[$70>>2] = $64;
    $71 = (($$01$i$i) + 64|0);
    HEAPF32[$71>>2] = $66;
    $72 = (($$01$i$i) + 68|0);
    HEAPF32[$72>>2] = $68;
    $73 = (($27) + 72|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($$01$i$i) + 72|0);
    HEAP32[$75>>2] = $74;
    $76 = (($27) + 76|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = (($27) + 80|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = (($27) + 84|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = (($27) + 88|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = (($$01$i$i) + 76|0);
    HEAPF32[$84>>2] = $77;
    $85 = (($$01$i$i) + 80|0);
    HEAPF32[$85>>2] = $79;
    $86 = (($$01$i$i) + 84|0);
    HEAPF32[$86>>2] = $81;
    $87 = (($$01$i$i) + 88|0);
    HEAPF32[$87>>2] = $83;
    $88 = (($27) + 92|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($$01$i$i) + 92|0);
    HEAP32[$90>>2] = $89;
    $91 = (($27) + 96|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = (($27) + 100|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $95 = (($27) + 104|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $97 = (($27) + 108|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = (($$01$i$i) + 96|0);
    HEAPF32[$99>>2] = $92;
    $100 = (($$01$i$i) + 100|0);
    HEAPF32[$100>>2] = $94;
    $101 = (($$01$i$i) + 104|0);
    HEAPF32[$101>>2] = $96;
    $102 = (($$01$i$i) + 108|0);
    HEAPF32[$102>>2] = $98;
    $103 = (($27) + 112|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($$01$i$i) + 112|0);
    HEAP32[$105>>2] = $104;
    $106 = (($27) + 116|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = (($27) + 120|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = (($27) + 124|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = (($27) + 128|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = (($$01$i$i) + 116|0);
    HEAPF32[$114>>2] = $107;
    $115 = (($$01$i$i) + 120|0);
    HEAPF32[$115>>2] = $109;
    $116 = (($$01$i$i) + 124|0);
    HEAPF32[$116>>2] = $111;
    $117 = (($$01$i$i) + 128|0);
    HEAPF32[$117>>2] = $113;
    $118 = (($27) + 132|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($$01$i$i) + 132|0);
    HEAP32[$120>>2] = $119;
    $121 = (($27) + 136|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = (($27) + 140|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = (($27) + 144|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = (($27) + 148|0);
    $128 = Math_fround(HEAPF32[$127>>2]);
    $129 = (($$01$i$i) + 136|0);
    HEAPF32[$129>>2] = $122;
    $130 = (($$01$i$i) + 140|0);
    HEAPF32[$130>>2] = $124;
    $131 = (($$01$i$i) + 144|0);
    HEAPF32[$131>>2] = $126;
    $132 = (($$01$i$i) + 148|0);
    HEAPF32[$132>>2] = $128;
    $133 = (($27) + 152|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = (($$01$i$i) + 152|0);
    HEAP32[$135>>2] = $134;
    $136 = (($27) + 156|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = (($27) + 160|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = (($27) + 164|0);
    $141 = Math_fround(HEAPF32[$140>>2]);
    $142 = (($27) + 168|0);
    $143 = Math_fround(HEAPF32[$142>>2]);
    $144 = (($$01$i$i) + 156|0);
    HEAPF32[$144>>2] = $137;
    $145 = (($$01$i$i) + 160|0);
    HEAPF32[$145>>2] = $139;
    $146 = (($$01$i$i) + 164|0);
    HEAPF32[$146>>2] = $141;
    $147 = (($$01$i$i) + 168|0);
    HEAPF32[$147>>2] = $143;
    $148 = (($$01$i$i) + 172|0);
    $149 = (($27) + 172|0);
    dest=$148+0|0; src=$149+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $150 = (($27) + 236|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = (($$01$i$i) + 236|0);
    HEAP32[$152>>2] = $151;
    $153 = (($$01$i$i) + 240|0);
    $154 = (($27) + 240|0);
    dest=$153+0|0; src=$154+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[$153+48>>1]=HEAP16[$154+48>>1]|0;
    $155 = (($27) + 292|0);
    $156 = (($$01$i$i) + 292|0);
    $157 = ($155|0)==($24|0);
    if ($157) {
     break;
    } else {
     $$01$i$i = $156;$27 = $155;
    }
   }
   $158 = (($26) + 1)|0;
   $scevgep17$i = (($10) + (($158*292)|0)|0);
   $$0$lcssa$i$i = $scevgep17$i;
  }
  if ($__growing$0$off0) {
   $159 = HEAP32[$__last>>2]|0;
   $160 = ($24|0)==($159|0);
   if ($160) {
    STACKTOP = sp;return;
   }
   $$pre$i13 = HEAP32[$16>>2]|0;
   $162 = $$pre$i13;$163 = $24;
   while(1) {
    $161 = ($162|0)==(0|0);
    if ($161) {
     $165 = 0;
    } else {
     __ZN8GUIStyleC2ERKS_($162,$163);
     $$pre1$i15 = HEAP32[$16>>2]|0;
     $165 = $$pre1$i15;
    }
    $164 = (($165) + 292|0);
    HEAP32[$16>>2] = $164;
    $166 = (($163) + 292|0);
    $167 = ($166|0)==($159|0);
    if ($167) {
     break;
    } else {
     $162 = $164;$163 = $166;
    }
   }
   STACKTOP = sp;return;
  }
  $168 = HEAP32[$16>>2]|0;
  $169 = ($168|0)==($$0$lcssa$i$i|0);
  if ($169) {
   STACKTOP = sp;return;
  }
  $171 = $168;
  while(1) {
   $170 = (($171) + -292|0);
   HEAP32[$16>>2] = $170;
   $172 = HEAP8[$170>>0]|0;
   $173 = $172 & 1;
   $174 = ($173<<24>>24)==(0);
   if ($174) {
    $176 = $170;
   } else {
    $177 = (($171) + -284|0);
    $178 = HEAP32[$177>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($178|0),($$byval_copy3|0));
    $179 = __THREW__; __THREW__ = 0;
    $180 = $179&1;
    if ($180) {
     label = 20;
     break;
    }
    $$pre$i$i = HEAP32[$16>>2]|0;
    $176 = $$pre$i$i;
   }
   $175 = ($176|0)==($$0$lcssa$i$i|0);
   if ($175) {
    label = 42;
    break;
   } else {
    $171 = $176;
   }
  }
  if ((label|0) == 20) {
   $181 = ___cxa_find_matching_catch()|0;
   $182 = tempRet0;
   ___cxa_call_unexpected(($181|0));
   // unreachable;
  }
  else if ((label|0) == 42) {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEC2INS_11__wrap_iterIPS1_EEEET_SA_RKS4_PNS_9enable_ifIXaasr21__is_forward_iteratorISA_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeE($this,$__first,$__last,$__a,$0) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 $__a = $__a|0;
 $0 = $0|0;
 var $$byval_copy7 = 0, $$pre$i$i$i = 0, $$pre$i6 = 0, $$pre1$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 12|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = sp + 8|0;
 HEAP32[$this>>2] = 0;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = HEAP32[$__first>>2]|0;
 $7 = HEAP32[$__last>>2]|0;
 $8 = $7;
 $9 = $6;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 292)&-1;
 $12 = ($7|0)==($6|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = ($10|0)<(0);
 do {
  if ($13) {
   __THREW__ = 0;
   invoke_vi(3308,0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 12;
   } else {
    // unreachable;
   }
  } else {
   HEAP32[$3>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
   $16 = (invoke_iiiiiii(102,($10|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 12;
   } else {
    HEAP32[$4>>2] = $16;
    HEAP32[$this>>2] = $16;
    $19 = (($16) + (($11*292)|0)|0);
    HEAP32[$5>>2] = $19;
    $21 = $16;$22 = $6;
    while(1) {
     $20 = ($21|0)==(0|0);
     if ($20) {
      $26 = 0;
     } else {
      __THREW__ = 0;
      invoke_vii(2871,($21|0),($22|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       label = 11;
       break;
      }
      $$pre1$i = HEAP32[$4>>2]|0;
      $26 = $$pre1$i;
     }
     $25 = (($26) + 292|0);
     HEAP32[$4>>2] = $25;
     $27 = (($22) + 292|0);
     $28 = ($27|0)==($7|0);
     if ($28) {
      label = 24;
      break;
     } else {
      $21 = $25;$22 = $27;
     }
    }
    if ((label|0) == 11) {
     $29 = ___cxa_find_matching_catch()|0;
     $30 = tempRet0;
     $lpad$phi$index = $29;$lpad$phi$index2 = $30;
     break;
    }
    else if ((label|0) == 24) {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $lpad$phi$index = $31;$lpad$phi$index2 = $32;
 }
 $33 = HEAP32[$this>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $35 = HEAP32[$4>>2]|0;
 $36 = ($35|0)==($33|0);
 do {
  if ($36) {
   $50 = $33;
  } else {
   $38 = $35;
   while(1) {
    $37 = (($38) + -292|0);
    HEAP32[$4>>2] = $37;
    $39 = HEAP8[$37>>0]|0;
    $40 = $39 & 1;
    $41 = ($40<<24>>24)==(0);
    if ($41) {
     $43 = $37;
    } else {
     $44 = (($38) + -284|0);
     $45 = HEAP32[$44>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($45|0),($$byval_copy7|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 20;
      break;
     }
     $$pre$i$i$i = HEAP32[$4>>2]|0;
     $43 = $$pre$i$i$i;
    }
    $42 = ($43|0)==($33|0);
    if ($42) {
     label = 21;
     break;
    } else {
     $38 = $43;
    }
   }
   if ((label|0) == 20) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   }
   else if ((label|0) == 21) {
    $$pre$i6 = HEAP32[$this>>2]|0;
    $50 = $$pre$i6;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($50|0),($$byval_copy7|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  ___cxa_call_unexpected(($53|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i125 = 0, $$0$i126 = 0, $$0$i3 = 0, $$01$i$i = 0, $$byval_copy9 = 0, $$pre = 0, $$pre$i7 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy9 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 292)&-1;
 $10 = ($9>>>0)<($__n>>>0);
 if (!($10)) {
  $$0$i = $__n;$12 = $5;
  while(1) {
   $11 = ($12|0)==(0|0);
   if ($11) {
    $14 = 0;
   } else {
    __ZN8GUIStyleC2Ev($12);
    $$pre1$i = HEAP32[$4>>2]|0;
    $14 = $$pre1$i;
   }
   $13 = (($14) + 292|0);
   HEAP32[$4>>2] = $13;
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$12 = $13;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($7) - ($18))|0;
 $20 = (($19|0) / 292)&-1;
 $21 = (($20) + ($__n))|0;
 $22 = ($21|0)<(0);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($6) - ($18))|0;
 $24 = (($23|0) / 292)&-1;
 $25 = ($24>>>0)<(1073741823);
 if ($25) {
  $26 = $24 << 1;
  $27 = ($26>>>0)<($21>>>0);
  $28 = $27 ? $21 : $26;
  $29 = ($28|0)==(0);
  if ($29) {
   $$0$i126 = 0;$33 = 0;
  } else {
   $$0$i125 = $28;
   label = 9;
  }
 } else {
  $$0$i125 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $30 = ($$0$i125*292)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  $31 = (__Z15malloc_internaljj10MemLabelIdiPKci($30,16,$$byval_copy9,0,630440,79)|0);
  $$0$i126 = $$0$i125;$33 = $31;
 }
 $32 = (($33) + (($20*292)|0)|0);
 $34 = (($33) + (($$0$i126*292)|0)|0);
 $$0$i3 = $__n;$36 = $32;
 while(1) {
  $35 = ($36|0)==(0|0);
  if ($35) {
   $40 = 0;
  } else {
   __THREW__ = 0;
   invoke_vi(3550,($36|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 28;
    break;
   } else {
    $40 = $36;
   }
  }
  $39 = (($40) + 292|0);
  $41 = (($$0$i3) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   label = 14;
   break;
  } else {
   $$0$i3 = $41;$36 = $39;
  }
 }
 L22: do {
  if ((label|0) == 14) {
   $43 = HEAP32[$this>>2]|0;
   $44 = HEAP32[$4>>2]|0;
   $45 = ($44|0)==($43|0);
   L24: do {
    if ($45) {
     HEAP32[$this>>2] = $32;
     HEAP32[$4>>2] = $39;
     HEAP32[$2>>2] = $34;
     $66 = $43;
    } else {
     $$01$i$i = $44;$47 = $32;
     while(1) {
      $46 = (($47) + -292|0);
      $48 = (($$01$i$i) + -292|0);
      __THREW__ = 0;
      invoke_vii(2871,($46|0),($48|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 27;
       break;
      }
      $51 = ($48|0)==($43|0);
      if ($51) {
       break;
      } else {
       $$01$i$i = $48;$47 = $46;
      }
     }
     if ((label|0) == 27) {
      $71 = ___cxa_find_matching_catch()|0;
      $72 = tempRet0;
      $76 = $39;$77 = $47;$lpad$phi$index = $71;$lpad$phi$index2 = $72;
      break L22;
     }
     $$pre$i7 = HEAP32[$this>>2]|0;
     $$pre = HEAP32[$4>>2]|0;
     HEAP32[$this>>2] = $46;
     HEAP32[$4>>2] = $39;
     HEAP32[$2>>2] = $34;
     $52 = ($$pre|0)==($$pre$i7|0);
     if ($52) {
      $66 = $$pre$i7;
     } else {
      $54 = $$pre;
      while(1) {
       $53 = (($54) + -292|0);
       $55 = HEAP8[$53>>0]|0;
       $56 = $55 & 1;
       $57 = ($56<<24>>24)==(0);
       if (!($57)) {
        $59 = (($54) + -284|0);
        $60 = HEAP32[$59>>2]|0;
        HEAP32[$1>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($60|0),($$byval_copy9|0));
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         break;
        }
       }
       $58 = ($53|0)==($$pre$i7|0);
       if ($58) {
        $66 = $$pre$i7;
        break L24;
       } else {
        $54 = $53;
       }
      }
      $63 = ___cxa_find_matching_catch()|0;
      $64 = tempRet0;
      ___cxa_call_unexpected(($63|0));
      // unreachable;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy9|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    ___cxa_call_unexpected(($69|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
  else if ((label|0) == 28) {
   $73 = ___cxa_find_matching_catch()|0;
   $74 = tempRet0;
   $76 = $36;$77 = $32;$lpad$phi$index = $73;$lpad$phi$index2 = $74;
  }
 } while(0);
 $75 = ($76|0)==($77|0);
 L48: do {
  if (!($75)) {
   $79 = $76;
   while(1) {
    $78 = (($79) + -292|0);
    $80 = HEAP8[$78>>0]|0;
    $81 = $80 & 1;
    $82 = ($81<<24>>24)==(0);
    if (!($82)) {
     $84 = (($79) + -284|0);
     $85 = HEAP32[$84>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($85|0),($$byval_copy9|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      break;
     }
    }
    $83 = ($78|0)==($77|0);
    if ($83) {
     break L48;
    } else {
     $79 = $78;
    }
   }
   $88 = ___cxa_find_matching_catch()|0;
   $89 = tempRet0;
   ___cxa_call_unexpected(($88|0));
   // unreachable;
  }
 } while(0);
 $90 = ($33|0)==(0|0);
 if ($90) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy9|0));
 $91 = __THREW__; __THREW__ = 0;
 $92 = $91&1;
 if ($92) {
  $93 = ___cxa_find_matching_catch()|0;
  $94 = tempRet0;
  ___cxa_call_unexpected(($93|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$010 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viii(1803,($6|0),($buffer|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 3;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   __THREW__ = 0;
   invoke_viii(1804,($buffer|0),($25|0),($27|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    label = 3;
   } else {
    $30 = HEAP32[$24>>2]|0;
    $31 = (($30) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0);
    L4: do {
     if (!($33)) {
      $35 = $30;$index$010 = 0;
      while(1) {
       $34 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($34|0),($index$010|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
       $38 = (($index$010) + 1)|0;
       $39 = HEAP32[$24>>2]|0;
       $40 = (($39) + 4|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = ($38|0)==($41|0);
       if ($42) {
        break L4;
       } else {
        $35 = $39;$index$010 = $38;
       }
      }
      $9 = ___cxa_find_matching_catch()|0;
      $10 = tempRet0;
      $lpad$phi$index = $9;$lpad$phi$index2 = $10;
      break L1;
     }
    } while(0);
    $43 = HEAP32[$buffer>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     STACKTOP = sp;return;
    }
    $45 = HEAP32[$1>>2]|0;
    $46 = ($45|0)==($43|0);
    if (!($46)) {
     $__new_last2$i$i$i$i$i$i$i = $43;
     $scevgep$i$i$i$i$i$i$i = (($45) + -16|0);
     $47 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($47)|0);
     $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
     $48 = $uglygep3$i$i$i$i$i$i$i >>> 4;
     $49 = $48 ^ -1;
     $scevgep4$i$i$i$i$i$i$i = (($45) + ($49<<4)|0);
     HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($43|0),($$byval_copy6|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     $52 = ___cxa_find_matching_catch()|0;
     $53 = tempRet0;
     ___cxa_call_unexpected(($52|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy6|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN12NativeBufferI27Converter_SimpleNativeClassI10RectOffsetEE19ProcessAfterReadingER9ArrayInfoP14ScriptingClass($this,$arrayInfo,$elementClass) {
 $this = $this|0;
 $arrayInfo = $arrayInfo|0;
 $elementClass = $elementClass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($arrayInfo) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($6|0);
 if (!($9)) {
  $10 = (__Z34scripting_class_array_element_sizeP14ScriptingClass($elementClass)|0);
  $11 = (__Z19scripting_array_newP14ScriptingClassjj($elementClass,$10,$6)|0);
  HEAP32[$arrayInfo>>2] = $11;
  HEAP32[$7>>2] = $6;
 }
 $12 = ($6|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 12|0);
 $index$01 = 0;
 while(1) {
  $14 = HEAP32[$arrayInfo>>2]|0;
  $15 = (__ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi($14,$index$01)|0);
  $16 = HEAP32[$this>>2]|0;
  $17 = (($16) + ($index$01<<4)|0);
  $18 = HEAP32[$15>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   $20 = HEAP32[$13>>2]|0;
   $21 = (_il2cpp_object_new($20)|0);
   __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($21);
   HEAP32[$15>>2] = $21;
   $23 = $21;
  } else {
   $23 = $18;
  }
  $22 = (($23) + 8|0);
  $24 = HEAP32[$22>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$17+12>>2]|0;
  $25 = (($index$01) + 1)|0;
  $26 = ($25|0)==($6|0);
  if ($26) {
   break;
  } else {
   $index$01 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI10RectOffset13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI10RectOffset13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN10RectOffset8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 16|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI10RectOffset13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $$byval_copy6 = 0, $$pre = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i22 = 0, $__new_last2$i$i$i$i$i5 = 0, $__new_last2$i$i$i14 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i23 = 0, $scevgep$i$i$i$i$i6 = 0, $scevgep$i$i$i15 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i10 = 0, $scevgep4$i$i$i$i$i27 = 0, $scevgep4$i$i$i19 = 0, $temp = 0, $temp1 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i25 = 0, $uglygep$i$i$i$i$i8 = 0;
 var $uglygep$i$i$i17 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i26 = 0, $uglygep3$i$i$i$i$i9 = 0, $uglygep3$i$i$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy6 = sp + 28|0;
 $$byval_copy4 = sp + 52|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 48|0;
 $temp = sp + 36|0;
 $3 = sp + 32|0;
 $4 = sp + 24|0;
 $temp1 = sp + 12|0;
 $5 = sp + 56|0;
 $6 = (($v) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$v>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 4;
 $13 = ($12>>>0)<($sz>>>0);
 if (!($13)) {
  $73 = ($12>>>0)>($sz>>>0);
  if (!($73)) {
   STACKTOP = sp;return;
  }
  $74 = (($8) + ($sz<<4)|0);
  HEAP32[$1>>2] = $8;
  HEAP32[$0>>2] = $74;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiii(103,($temp1|0),($$byval_copy4|0),($$byval_copy6|0),($5|0),0);
  $75 = __THREW__; __THREW__ = 0;
  $76 = $75&1;
  if ($76) {
   $95 = ___cxa_find_matching_catch()|0;
   $96 = tempRet0;
   $$0 = $96;$$01 = $95;
   ___resumeException($$01|0);
   // unreachable;
  }
  $77 = HEAP32[$temp1>>2]|0;
  $78 = HEAP32[$v>>2]|0;
  HEAP32[$temp1>>2] = $78;
  HEAP32[$v>>2] = $77;
  $79 = (($temp1) + 4|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = HEAP32[$6>>2]|0;
  HEAP32[$79>>2] = $81;
  HEAP32[$6>>2] = $80;
  $82 = (($temp1) + 8|0);
  $83 = (($v) + 8|0);
  $84 = HEAP32[$82>>2]|0;
  $85 = HEAP32[$83>>2]|0;
  HEAP32[$82>>2] = $85;
  HEAP32[$83>>2] = $84;
  $86 = ($78|0)==(0|0);
  if ($86) {
   STACKTOP = sp;return;
  }
  $87 = ($81|0)==($78|0);
  if (!($87)) {
   $__new_last2$i$i$i$i$i = $78;
   $scevgep$i$i$i$i$i = (($81) + -16|0);
   $88 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($88)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $89 = $uglygep3$i$i$i$i$i >>> 4;
   $90 = $89 ^ -1;
   $scevgep4$i$i$i$i$i = (($81) + ($90<<4)|0);
   HEAP32[$79>>2] = $scevgep4$i$i$i$i$i;
  }
  HEAP32[$2>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($78|0),($$byval_copy6|0));
  $91 = __THREW__; __THREW__ = 0;
  $92 = $91&1;
  if ($92) {
   $93 = ___cxa_find_matching_catch()|0;
   $94 = tempRet0;
   ___cxa_call_unexpected(($93|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $14 = (($v) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 4;
 $19 = ($18|0)==($sz|0);
 if ($19) {
  $72 = (($sz) - ($12))|0;
  __ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$72);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $20 = (($temp) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($temp) + 8|0);
 HEAP32[$21>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2872,($temp|0),($sz|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 do {
  if (!($23)) {
   $24 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $24;
   $25 = HEAP32[$6>>2]|0;
   HEAP32[$4>>2] = $25;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1805,($temp|0),($$byval_copy4|0),($$byval_copy6|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[$20>>2]|0;
    $29 = HEAP32[$temp>>2]|0;
    $30 = $28;
    $31 = $29;
    $32 = (($30) - ($31))|0;
    $33 = $32 >> 4;
    $34 = ($33>>>0)<($sz>>>0);
    if ($34) {
     $35 = (($sz) - ($33))|0;
     __THREW__ = 0;
     invoke_vii(2873,($temp|0),($35|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre33 = HEAP32[$20>>2]|0;
     $45 = $$pre;$47 = $$pre33;
    } else {
     $38 = ($33>>>0)>($sz>>>0);
     if ($38) {
      $39 = (($29) + ($sz<<4)|0);
      $40 = ($28|0)==($39|0);
      if ($40) {
       $45 = $29;$47 = $28;
      } else {
       $__new_last2$i$i$i14 = $39;
       $scevgep$i$i$i15 = (($28) + -16|0);
       $41 = (0 - ($__new_last2$i$i$i14))|0;
       $uglygep$i$i$i17 = (($scevgep$i$i$i15) + ($41)|0);
       $uglygep3$i$i$i18 = $uglygep$i$i$i17;
       $42 = $uglygep3$i$i$i18 >>> 4;
       $43 = $42 ^ -1;
       $scevgep4$i$i$i19 = (($28) + ($43<<4)|0);
       HEAP32[$20>>2] = $scevgep4$i$i$i19;
       $45 = $29;$47 = $scevgep4$i$i$i19;
      }
     } else {
      $45 = $29;$47 = $28;
     }
    }
    $44 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $44;
    HEAP32[$v>>2] = $45;
    $46 = HEAP32[$6>>2]|0;
    HEAP32[$20>>2] = $46;
    HEAP32[$6>>2] = $47;
    $48 = HEAP32[$21>>2]|0;
    $49 = HEAP32[$14>>2]|0;
    HEAP32[$21>>2] = $49;
    HEAP32[$14>>2] = $48;
    $50 = ($44|0)==(0|0);
    if ($50) {
     STACKTOP = sp;return;
    }
    $51 = ($46|0)==($44|0);
    if (!($51)) {
     $__new_last2$i$i$i$i$i22 = $44;
     $scevgep$i$i$i$i$i23 = (($46) + -16|0);
     $52 = (0 - ($__new_last2$i$i$i$i$i22))|0;
     $uglygep$i$i$i$i$i25 = (($scevgep$i$i$i$i$i23) + ($52)|0);
     $uglygep3$i$i$i$i$i26 = $uglygep$i$i$i$i$i25;
     $53 = $uglygep3$i$i$i$i$i26 >>> 4;
     $54 = $53 ^ -1;
     $scevgep4$i$i$i$i$i27 = (($46) + ($54<<4)|0);
     HEAP32[$20>>2] = $scevgep4$i$i$i$i$i27;
    }
    HEAP32[$$byval_copy4>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$$byval_copy4+0>>2]|0;
    invoke_vii(2591,($44|0),($$byval_copy6|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     $57 = ___cxa_find_matching_catch()|0;
     $58 = tempRet0;
     ___cxa_call_unexpected(($57|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $59 = ___cxa_find_matching_catch()|0;
 $60 = tempRet0;
 $61 = HEAP32[$temp>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  $$0 = $60;$$01 = $59;
  ___resumeException($$01|0);
  // unreachable;
 }
 $63 = HEAP32[$20>>2]|0;
 $64 = ($63|0)==($61|0);
 if (!($64)) {
  $__new_last2$i$i$i$i$i5 = $61;
  $scevgep$i$i$i$i$i6 = (($63) + -16|0);
  $65 = (0 - ($__new_last2$i$i$i$i$i5))|0;
  $uglygep$i$i$i$i$i8 = (($scevgep$i$i$i$i$i6) + ($65)|0);
  $uglygep3$i$i$i$i$i9 = $uglygep$i$i$i$i$i8;
  $66 = $uglygep3$i$i$i$i$i9 >>> 4;
  $67 = $66 ^ -1;
  $scevgep4$i$i$i$i$i10 = (($63) + ($67<<4)|0);
  HEAP32[$20>>2] = $scevgep4$i$i$i$i$i10;
 }
 HEAP32[$$byval_copy4>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$$byval_copy4+0>>2]|0;
 invoke_vii(2591,($61|0),($$byval_copy6|0));
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $70 = ___cxa_find_matching_catch()|0;
  $71 = tempRet0;
  ___cxa_call_unexpected(($70|0));
  // unreachable;
 } else {
  $$0 = $60;$$01 = $59;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = $12 >> 4;
 $14 = ($__n|0)==(0);
 if ($14) {
  $$pre$i = $3;$18 = 0;$21 = $10;
 } else {
  $15 = $__n << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy1,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre1 = HEAP32[$9>>2]|0;
  $$pre$i = $$pre;$18 = $16;$21 = $$pre1;
 }
 $17 = (($18) + ($13<<4)|0);
 $19 = (($18) + ($__n<<4)|0);
 $20 = ($21|0)==($$pre$i|0);
 if ($20) {
  $40 = $17;$42 = $21;
 } else {
  $__begin13$i$i = $$pre$i;
  $scevgep$i$i = (($21) + -16|0);
  $22 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($22)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $21;$26 = $17;
  while(1) {
   $23 = (($$01$i$i) + -16|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($26) + -16|0);
   HEAP32[$25>>2] = $24;
   $27 = (($$01$i$i) + -12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + -12|0);
   HEAP32[$29>>2] = $28;
   $30 = (($$01$i$i) + -8|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($26) + -8|0);
   HEAP32[$32>>2] = $31;
   $33 = (($$01$i$i) + -4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($26) + -4|0);
   HEAP32[$35>>2] = $34;
   $36 = (($26) + -16|0);
   $37 = ($23|0)==($$pre$i|0);
   if ($37) {
    break;
   } else {
    $$01$i$i = $23;$26 = $36;
   }
  }
  $38 = $uglygep4$i$i >>> 4;
  $39 = $38 ^ -1;
  $$sum = (($13) + ($39))|0;
  $scevgep5$i$i = (($18) + ($$sum<<4)|0);
  $40 = $scevgep5$i$i;$42 = $$pre$i;
 }
 HEAP32[$this>>2] = $40;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $41 = ($42|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($42|0),($$byval_copy1|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  ___cxa_call_unexpected(($45|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $__new_last2$i$i = 0;
 var $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 4;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 4;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $43 = $2;
   $44 = (($43) - ($4))|0;
   $45 = $44 >> 4;
   _memmove(($9|0),($1|0),($44|0))|0;
   $46 = (($9) + ($45<<4)|0);
   $47 = HEAP32[$15>>2]|0;
   $48 = ($47|0)==($46|0);
   if ($48) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $46;
   $scevgep$i$i = (($47) + -16|0);
   $49 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($49)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $50 = $uglygep3$i$i >>> 4;
   $51 = $50 ^ -1;
   $scevgep4$i$i = (($47) + ($51<<4)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<4)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -16|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 4;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = HEAP32[$29>>2]|0;
    HEAP32[$27>>2] = $28;
    $30 = (($29) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($27) + 4|0);
    HEAP32[$32>>2] = $31;
    $33 = (($29) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($27) + 8|0);
    HEAP32[$35>>2] = $34;
    $36 = (($29) + 12|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($27) + 12|0);
    HEAP32[$38>>2] = $37;
   }
   $39 = (($27) + 16|0);
   $40 = (($29) + 16|0);
   $41 = ($40|0)==($2|0);
   if ($41) {
    break;
   } else {
    $27 = $39;$29 = $40;
   }
  }
  $42 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($42<<4)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $52 = ($9|0)==(0|0);
 do {
  if ($52) {
   $65 = $8;
  } else {
   $53 = (($this) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==($9|0);
   if (!($55)) {
    $scevgep$i$i$i$i = (($54) + -16|0);
    $56 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($56)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $57 = $uglygep3$i$i$i$i >>> 4;
    $58 = $57 ^ -1;
    $scevgep4$i$i$i$i = (($54) + ($58<<4)|0);
    HEAP32[$53>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $61 = ___cxa_find_matching_catch()|0;
    $62 = tempRet0;
    ___cxa_call_unexpected(($61|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$53>>2] = 0;
    HEAP32[$this>>2] = 0;
    $65 = 0;
    break;
   }
  }
 } while(0);
 $63 = ($5|0)<(0);
 if ($63) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $64 = $65;
 $66 = $64 >> 4;
 $67 = ($66>>>0)<(1073741823);
 if ($67) {
  $68 = $64 >> 3;
  $69 = ($68>>>0)<($6>>>0);
  $70 = $69 ? $6 : $68;
  $71 = ($70|0)<(0);
  if ($71) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $70;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $72 = $$0$i37 << 4;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $73 = (__Z15malloc_internaljj10MemLabelIdiPKci($72,16,$$byval_copy1,0,630440,79)|0);
 $74 = (($this) + 4|0);
 HEAP32[$74>>2] = $73;
 HEAP32[$this>>2] = $73;
 $75 = (($73) + ($$0$i37<<4)|0);
 HEAP32[$7>>2] = $75;
 $76 = ($1|0)==($2|0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -16|0);
 $77 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($77)|0);
 $uglygep6$i = $uglygep$i;
 $78 = $uglygep6$i >>> 4;
 $80 = $73;$82 = $1;
 while(1) {
  $79 = ($80|0)==(0|0);
  if (!($79)) {
   $81 = HEAP32[$82>>2]|0;
   HEAP32[$80>>2] = $81;
   $83 = (($82) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($80) + 4|0);
   HEAP32[$85>>2] = $84;
   $86 = (($82) + 8|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = (($80) + 8|0);
   HEAP32[$88>>2] = $87;
   $89 = (($82) + 12|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($80) + 12|0);
   HEAP32[$91>>2] = $90;
  }
  $92 = (($80) + 16|0);
  $93 = (($82) + 16|0);
  $94 = ($93|0)==($2|0);
  if ($94) {
   break;
  } else {
   $80 = $92;$82 = $93;
  }
 }
 $95 = (($78) + 1)|0;
 $scevgep8$i = (($73) + ($95<<4)|0);
 HEAP32[$74>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEC2INS_11__wrap_iterIPS1_EEEET_SA_RKS4_PNS_9enable_ifIXaasr21__is_forward_iteratorISA_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeE($this,$__first,$__last,$__a,$0) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 $__a = $__a|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep8$i = 0, $uglygep$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0;
 var $uglygep6$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 HEAP32[$this>>2] = 0;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[$__first>>2]|0;
 $6 = HEAP32[$__last>>2]|0;
 $7 = $6;
 $8 = $5;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($9|0)<(0);
 if ($12) {
  __THREW__ = 0;
  invoke_vi(3308,0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   // unreachable;
  }
 } else {
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  $15 = (invoke_iiiiiii(102,($9|0),16,($$byval_copy1|0),0,(630440|0),79)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   HEAP32[$3>>2] = $15;
   HEAP32[$this>>2] = $15;
   $18 = (($15) + ($10<<4)|0);
   HEAP32[$4>>2] = $18;
   $19 = ($5|0)==($6|0);
   if ($19) {
    STACKTOP = sp;return;
   }
   $scevgep$i = (($6) + -16|0);
   $20 = (0 - ($8))|0;
   $uglygep$i = (($scevgep$i) + ($20)|0);
   $uglygep6$i = $uglygep$i;
   $21 = $uglygep6$i >>> 4;
   $23 = $15;$25 = $5;
   while(1) {
    $22 = ($23|0)==(0|0);
    if (!($22)) {
     $24 = HEAP32[$25>>2]|0;
     HEAP32[$23>>2] = $24;
     $26 = (($25) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($23) + 4|0);
     HEAP32[$28>>2] = $27;
     $29 = (($25) + 8|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($23) + 8|0);
     HEAP32[$31>>2] = $30;
     $32 = (($25) + 12|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($23) + 12|0);
     HEAP32[$34>>2] = $33;
    }
    $35 = (($23) + 16|0);
    $36 = (($25) + 16|0);
    $37 = ($36|0)==($6|0);
    if ($37) {
     break;
    } else {
     $23 = $35;$25 = $36;
    }
   }
   $38 = (($21) + 1)|0;
   $scevgep8$i = (($15) + ($38<<4)|0);
   HEAP32[$3>>2] = $scevgep8$i;
   STACKTOP = sp;return;
  }
 }
 $39 = ___cxa_find_matching_catch()|0;
 $40 = tempRet0;
 $41 = HEAP32[$this>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  ___resumeException($39|0);
  // unreachable;
 }
 $43 = HEAP32[$3>>2]|0;
 $44 = ($43|0)==($41|0);
 if (!($44)) {
  $__new_last2$i$i$i = $41;
  $scevgep$i$i$i = (($43) + -16|0);
  $45 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($45)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $46 = $uglygep3$i$i$i >>> 4;
  $47 = $46 ^ -1;
  $scevgep4$i$i$i = (($43) + ($47<<4)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i;
 }
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy1|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  ___cxa_call_unexpected(($50|0));
  // unreachable;
 } else {
  ___resumeException($39|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i78 = 0, $$0$i79 = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 16|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = $18 >> 4;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = $22 >> 4;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $22 >> 3;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i79 = 0;$32 = 0;
  } else {
   $$0$i78 = $27;
   label = 9;
  }
 } else {
  $$0$i78 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = $$0$i78 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,630440,79)|0);
  $$0$i79 = $$0$i78;$32 = $30;
 }
 $31 = (($32) + ($19<<4)|0);
 $$0$i4 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $36 = 0;
  } else {
   ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
   $36 = $34;
  }
  $35 = (($36) + 16|0);
  $37 = (($$0$i4) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i4 = $37;$34 = $35;
  }
 }
 $39 = (($32) + ($$0$i79<<4)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = ($41|0)==($40|0);
 if ($42) {
  $61 = $31;
 } else {
  $__begin13$i$i = $40;
  $scevgep$i$i = (($41) + -16|0);
  $43 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($43)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $41;$47 = $31;
  while(1) {
   $44 = (($$01$i$i) + -16|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($47) + -16|0);
   HEAP32[$46>>2] = $45;
   $48 = (($$01$i$i) + -12|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($47) + -12|0);
   HEAP32[$50>>2] = $49;
   $51 = (($$01$i$i) + -8|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($47) + -8|0);
   HEAP32[$53>>2] = $52;
   $54 = (($$01$i$i) + -4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($47) + -4|0);
   HEAP32[$56>>2] = $55;
   $57 = (($47) + -16|0);
   $58 = ($44|0)==($40|0);
   if ($58) {
    break;
   } else {
    $$01$i$i = $44;$47 = $57;
   }
  }
  $59 = $uglygep4$i$i >>> 4;
  $60 = $59 ^ -1;
  $$sum = (($19) + ($60))|0;
  $scevgep5$i$i = (($32) + ($$sum<<4)|0);
  $61 = $scevgep5$i$i;
 }
 HEAP32[$this>>2] = $61;
 HEAP32[$3>>2] = $35;
 HEAP32[$1>>2] = $39;
 $62 = ($40|0)==(0|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($40|0),($$byval_copy1|0));
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $65 = ___cxa_find_matching_catch()|0;
  $66 = tempRet0;
  ___cxa_call_unexpected(($65|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $buffer = 0, $index$04 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viii(1806,($6|0),($buffer|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 3;
  } else {
   $27 = (($runtimeInfo) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($staticInfo) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   __THREW__ = 0;
   invoke_viii(1807,($buffer|0),($28|0),($30|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 3;
   } else {
    $33 = HEAP32[$27>>2]|0;
    $34 = (($33) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==(0);
    L4: do {
     if (!($36)) {
      $38 = $33;$index$04 = 0;
      while(1) {
       $37 = HEAP32[$38>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($37|0),($index$04|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break;
       }
       $41 = (($index$04) + 1)|0;
       $42 = HEAP32[$27>>2]|0;
       $43 = (($42) + 4|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ($41|0)==($44|0);
       if ($45) {
        break L4;
       } else {
        $38 = $42;$index$04 = $41;
       }
      }
      $9 = ___cxa_find_matching_catch()|0;
      $10 = tempRet0;
      $lpad$phi$index = $9;$lpad$phi$index2 = $10;
      break L1;
     }
    } while(0);
    $46 = HEAP32[$buffer>>2]|0;
    $47 = ($46|0)==(0|0);
    if ($47) {
     STACKTOP = sp;return;
    }
    while(1) {
     $48 = HEAP32[$1>>2]|0;
     $49 = ($48|0)==($46|0);
     if ($49) {
      break;
     }
     $50 = (($48) + -68|0);
     HEAP32[$1>>2] = $50;
     __THREW__ = 0;
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 17;
      break;
     }
    }
    if ((label|0) == 17) {
     $53 = ___cxa_find_matching_catch()|0;
     $54 = tempRet0;
     ___cxa_call_unexpected(($53|0));
     // unreachable;
    }
    $55 = HEAP32[$buffer>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($55|0),($$byval_copy6|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     ___cxa_call_unexpected(($58|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 while(1) {
  $15 = HEAP32[$1>>2]|0;
  $16 = ($15|0)==($13|0);
  if ($16) {
   break;
  }
  $17 = (($15) + -68|0);
  HEAP32[$1>>2] = $17;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  ___cxa_call_unexpected(($20|0));
  // unreachable;
 }
 $22 = HEAP32[$buffer>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($22|0),($$byval_copy6|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  ___cxa_call_unexpected(($25|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN12NativeBufferI27Converter_SimpleNativeClassI11GradientNEWEE15SetupForWritingER9ArrayInfo($this,$inputArray) {
 $this = $this|0;
 $inputArray = $inputArray|0;
 var $$pre$i = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$01 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($inputArray) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 68)&-1;
 $9 = ($8>>>0)<($1>>>0);
 L1: do {
  if ($9) {
   $10 = (($1) - ($8))|0;
   __ZNSt3__16vectorI11GradientNEW13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$10);
  } else {
   $11 = ($8>>>0)>($1>>>0);
   if ($11) {
    $12 = (($4) + (($1*68)|0)|0);
    $13 = ($3|0)==($12|0);
    if (!($13)) {
     $16 = $3;
     while(1) {
      $15 = (($16) + -68|0);
      HEAP32[$2>>2] = $15;
      __THREW__ = 0;
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      $$pre$i = HEAP32[$2>>2]|0;
      $19 = ($$pre$i|0)==($12|0);
      if ($19) {
       break L1;
      } else {
       $16 = $$pre$i;
      }
     }
     $20 = ___cxa_find_matching_catch()|0;
     $21 = tempRet0;
     ___cxa_call_unexpected(($20|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $14 = ($1|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $index$01 = 0;
 while(1) {
  $22 = HEAP32[$inputArray>>2]|0;
  $23 = (__ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi($22,$index$01)|0);
  $$val = HEAP32[$23>>2]|0;
  $24 = ($$val|0)==(0|0);
  if (!($24)) {
   $25 = HEAP32[$this>>2]|0;
   $26 = (($25) + (($index$01*68)|0)|0);
   $27 = (($$val) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$26>>2] = $29;
   $30 = ((($25) + (($index$01*68)|0)|0) + 4|0);
   $31 = (($28) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$30>>2] = $32;
   $33 = ((($25) + (($index$01*68)|0)|0) + 8|0);
   $34 = (($28) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   HEAP32[$33>>2] = $35;
   $36 = ((($25) + (($index$01*68)|0)|0) + 12|0);
   $37 = (($28) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   HEAP32[$36>>2] = $38;
   $39 = ((($25) + (($index$01*68)|0)|0) + 16|0);
   $40 = (($28) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$39>>2] = $41;
   $42 = ((($25) + (($index$01*68)|0)|0) + 20|0);
   $43 = (($28) + 20|0);
   $44 = HEAP32[$43>>2]|0;
   HEAP32[$42>>2] = $44;
   $45 = ((($25) + (($index$01*68)|0)|0) + 24|0);
   $46 = (($28) + 24|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$45>>2] = $47;
   $48 = ((($25) + (($index$01*68)|0)|0) + 28|0);
   $49 = (($28) + 28|0);
   $50 = HEAP32[$49>>2]|0;
   HEAP32[$48>>2] = $50;
   $51 = ((($25) + (($index$01*68)|0)|0) + 32|0);
   $52 = (($28) + 32|0);
   dest=$51+0|0; src=$52+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
  }
  $53 = (($index$01) + 1)|0;
  $54 = ($53|0)==($1|0);
  if ($54) {
   break;
  } else {
   $index$01 = $53;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12NativeBufferI27Converter_SimpleNativeClassI11GradientNEWEE19ProcessAfterReadingER9ArrayInfoP14ScriptingClass($this,$arrayInfo,$elementClass) {
 $this = $this|0;
 $arrayInfo = $arrayInfo|0;
 $elementClass = $elementClass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$01 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 68)&-1;
 $7 = (($arrayInfo) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($6|0);
 if (!($9)) {
  $10 = (__Z34scripting_class_array_element_sizeP14ScriptingClass($elementClass)|0);
  $11 = (__Z19scripting_array_newP14ScriptingClassjj($elementClass,$10,$6)|0);
  HEAP32[$arrayInfo>>2] = $11;
  HEAP32[$7>>2] = $6;
 }
 $12 = ($1|0)==($2|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 12|0);
 $index$01 = 0;
 while(1) {
  $14 = HEAP32[$arrayInfo>>2]|0;
  $15 = (__ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi($14,$index$01)|0);
  $16 = HEAP32[$this>>2]|0;
  $17 = (($16) + (($index$01*68)|0)|0);
  $18 = HEAP32[$15>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   $20 = HEAP32[$13>>2]|0;
   $21 = (_il2cpp_object_new($20)|0);
   __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($21);
   HEAP32[$15>>2] = $21;
   $23 = $21;
  } else {
   $23 = $18;
  }
  $22 = (($23) + 8|0);
  $24 = HEAP32[$22>>2]|0;
  $25 = HEAP32[$17>>2]|0;
  HEAP32[$24>>2] = $25;
  $26 = (($24) + 4|0);
  $27 = ((($16) + (($index$01*68)|0)|0) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$26>>2] = $28;
  $29 = (($24) + 8|0);
  $30 = ((($16) + (($index$01*68)|0)|0) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$29>>2] = $31;
  $32 = (($24) + 12|0);
  $33 = ((($16) + (($index$01*68)|0)|0) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  HEAP32[$32>>2] = $34;
  $35 = (($24) + 16|0);
  $36 = ((($16) + (($index$01*68)|0)|0) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  HEAP32[$35>>2] = $37;
  $38 = (($24) + 20|0);
  $39 = ((($16) + (($index$01*68)|0)|0) + 20|0);
  $40 = HEAP32[$39>>2]|0;
  HEAP32[$38>>2] = $40;
  $41 = (($24) + 24|0);
  $42 = ((($16) + (($index$01*68)|0)|0) + 24|0);
  $43 = HEAP32[$42>>2]|0;
  HEAP32[$41>>2] = $43;
  $44 = (($24) + 28|0);
  $45 = ((($16) + (($index$01*68)|0)|0) + 28|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$44>>2] = $46;
  $47 = (($24) + 32|0);
  $48 = ((($16) + (($index$01*68)|0)|0) + 32|0);
  dest=$47+0|0; src=$48+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
  $49 = (($index$01) + 1)|0;
  $50 = ($49|0)==($6|0);
  if ($50) {
   break;
  } else {
   $index$01 = $49;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI11GradientNEW13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI11GradientNEW13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN11GradientNEW8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 68|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*68)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI11GradientNEW13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy5 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $temp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $temp = sp + 8|0;
 $1 = sp + 20|0;
 $2 = sp + 24|0;
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$v>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 68)&-1;
 $10 = ($9>>>0)<($sz>>>0);
 if (!($10)) {
  $81 = ($9>>>0)>($sz>>>0);
  if (!($81)) {
   STACKTOP = sp;return;
  }
  $82 = (($5) + (($sz*68)|0)|0);
  $$idx = ($sz*68)|0;
  $83 = (($$idx|0) / 68)&-1;
  $84 = ($sz|0)==(0);
  do {
   if ($84) {
    $101 = 0;$102 = 0;$104 = 0;$106 = $5;$118 = $4;
   } else {
    $85 = ($$idx|0)<(0);
    if ($85) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if (!($87)) {
      // unreachable;
     }
    } else {
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $88 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy5|0),0,(630440|0),79)|0);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if (!($90)) {
      $92 = $88;$93 = $5;
      while(1) {
       $91 = ($92|0)==(0|0);
       if ($91) {
        $95 = 0;
       } else {
        dest=$92+0|0; src=$93+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $95 = $92;
       }
       $94 = (($95) + 68|0);
       $96 = (($93) + 68|0);
       $97 = ($96|0)==($82|0);
       if ($97) {
        break;
       } else {
        $92 = $94;$93 = $96;
       }
      }
      $100 = (($88) + (($83*68)|0)|0);
      $$pre = HEAP32[$v>>2]|0;
      $$pre26 = HEAP32[$3>>2]|0;
      $101 = $88;$102 = $94;$104 = $100;$106 = $$pre;$118 = $$pre26;
      break;
     }
    }
    $98 = ___cxa_find_matching_catch()|0;
    $99 = tempRet0;
    $$0 = $99;$$01 = $98;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $101;
  HEAP32[$3>>2] = $102;
  $103 = (($v) + 8|0);
  HEAP32[$103>>2] = $104;
  $105 = ($106|0)==(0|0);
  if ($105) {
   STACKTOP = sp;return;
  } else {
   $108 = $118;
  }
  while(1) {
   $107 = ($108|0)==($106|0);
   if ($107) {
    break;
   }
   $109 = (($108) + -68|0);
   __THREW__ = 0;
   $110 = __THREW__; __THREW__ = 0;
   $111 = $110&1;
   if ($111) {
    label = 42;
    break;
   } else {
    $108 = $109;
   }
  }
  if ((label|0) == 42) {
   $112 = ___cxa_find_matching_catch()|0;
   $113 = tempRet0;
   ___cxa_call_unexpected(($112|0));
   // unreachable;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($106|0),($$byval_copy5|0));
  $114 = __THREW__; __THREW__ = 0;
  $115 = $114&1;
  if ($115) {
   $116 = ___cxa_find_matching_catch()|0;
   $117 = tempRet0;
   ___cxa_call_unexpected(($116|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $11 = (($v) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($7))|0;
 $15 = (($14|0) / 68)&-1;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $80 = (($sz) - ($9))|0;
  __ZNSt3__16vectorI11GradientNEW13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$80);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2874,($temp|0),($sz|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 L38: do {
  if (!($20)) {
   $21 = HEAP32[$v>>2]|0;
   HEAP32[$1>>2] = $21;
   $22 = HEAP32[$3>>2]|0;
   HEAP32[$2>>2] = $22;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viii(1808,($temp|0),($$byval_copy|0),($$byval_copy5|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$17>>2]|0;
    $26 = HEAP32[$temp>>2]|0;
    $27 = $25;
    $28 = $26;
    $29 = (($27) - ($28))|0;
    $30 = (($29|0) / 68)&-1;
    $31 = ($30>>>0)<($sz>>>0);
    L41: do {
     if ($31) {
      $32 = (($sz) - ($30))|0;
      __THREW__ = 0;
      invoke_vii(2875,($temp|0),($32|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break L38;
      }
      $$pre27 = HEAP32[$17>>2]|0;
      $48 = $$pre27;
     } else {
      $35 = ($30>>>0)>($sz>>>0);
      if ($35) {
       $36 = (($26) + (($sz*68)|0)|0);
       $37 = ($25|0)==($36|0);
       if ($37) {
        $48 = $25;
       } else {
        $39 = $25;
        while(1) {
         $38 = (($39) + -68|0);
         HEAP32[$17>>2] = $38;
         __THREW__ = 0;
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break;
         }
         $$pre$i = HEAP32[$17>>2]|0;
         $42 = ($$pre$i|0)==($36|0);
         if ($42) {
          $48 = $36;
          break L41;
         } else {
          $39 = $$pre$i;
         }
        }
        $43 = ___cxa_find_matching_catch()|0;
        $44 = tempRet0;
        ___cxa_call_unexpected(($43|0));
        // unreachable;
       }
      } else {
       $48 = $25;
      }
     }
    } while(0);
    $45 = HEAP32[$temp>>2]|0;
    $46 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $46;
    HEAP32[$v>>2] = $45;
    $47 = HEAP32[$3>>2]|0;
    HEAP32[$17>>2] = $47;
    HEAP32[$3>>2] = $48;
    $49 = HEAP32[$18>>2]|0;
    $50 = HEAP32[$11>>2]|0;
    HEAP32[$18>>2] = $50;
    HEAP32[$11>>2] = $49;
    $51 = ($46|0)==(0|0);
    if ($51) {
     STACKTOP = sp;return;
    } else {
     $53 = $47;
    }
    while(1) {
     $52 = ($53|0)==($46|0);
     if ($52) {
      break;
     }
     $54 = (($53) + -68|0);
     HEAP32[$17>>2] = $54;
     __THREW__ = 0;
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 17;
      break;
     }
     $$pre28 = HEAP32[$17>>2]|0;
     $53 = $$pre28;
    }
    if ((label|0) == 17) {
     $57 = ___cxa_find_matching_catch()|0;
     $58 = tempRet0;
     ___cxa_call_unexpected(($57|0));
     // unreachable;
    }
    $59 = HEAP32[$temp>>2]|0;
    HEAP32[$$byval_copy>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($59|0),($$byval_copy5|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     $62 = ___cxa_find_matching_catch()|0;
     $63 = tempRet0;
     ___cxa_call_unexpected(($62|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $64 = ___cxa_find_matching_catch()|0;
 $65 = tempRet0;
 $66 = HEAP32[$temp>>2]|0;
 $67 = ($66|0)==(0|0);
 if ($67) {
  $$0 = $65;$$01 = $64;
  ___resumeException($$01|0);
  // unreachable;
 }
 while(1) {
  $68 = HEAP32[$17>>2]|0;
  $69 = ($68|0)==($66|0);
  if ($69) {
   break;
  }
  $70 = (($68) + -68|0);
  HEAP32[$17>>2] = $70;
  __THREW__ = 0;
  $71 = __THREW__; __THREW__ = 0;
  $72 = $71&1;
  if ($72) {
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  $73 = ___cxa_find_matching_catch()|0;
  $74 = tempRet0;
  ___cxa_call_unexpected(($73|0));
  // unreachable;
 }
 $75 = HEAP32[$temp>>2]|0;
 HEAP32[$$byval_copy>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($75|0),($$byval_copy5|0));
 $76 = __THREW__; __THREW__ = 0;
 $77 = $76&1;
 if ($77) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  ___cxa_call_unexpected(($78|0));
  // unreachable;
 } else {
  $$0 = $65;$$01 = $64;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI11GradientNEW13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $scevgep1 = 0, $scevgep12 = 0, $scevgep3 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 68)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = (($12|0) / 68)&-1;
 $14 = ($__n|0)==(0);
 if ($14) {
  $18 = 0;$21 = $10;$22 = $3;
 } else {
  $15 = ($__n*68)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy1,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $18 = $16;$21 = $$pre4;$22 = $$pre;
 }
 $17 = (($18) + (($13*68)|0)|0);
 $19 = (($18) + (($__n*68)|0)|0);
 $20 = ($21|0)==($22|0);
 if ($20) {
  $33 = $17;$36 = $21;$47 = $21;
 } else {
  $23 = $22;
  $24 = (($13) + -1)|0;
  $scevgep = (($21) + -68|0);
  $25 = (0 - ($23))|0;
  $scevgep1 = (($scevgep) + ($25)|0);
  $scevgep12 = $scevgep1;
  $26 = (($scevgep12>>>0) / 68)&-1;
  $27 = (($24) - ($26))|0;
  $$01$i$i = $21;$30 = $17;
  while(1) {
   $28 = (($$01$i$i) + -68|0);
   $29 = (($30) + -68|0);
   dest=$29+0|0; src=$28+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $31 = (($30) + -68|0);
   $32 = ($28|0)==($22|0);
   if ($32) {
    break;
   } else {
    $$01$i$i = $28;$30 = $31;
   }
  }
  $scevgep3 = (($18) + (($27*68)|0)|0);
  $$pre$i = HEAP32[$this>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $33 = $scevgep3;$36 = $$pre$i;$47 = $$pre5;
 }
 HEAP32[$this>>2] = $33;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $35 = $47;
 while(1) {
  $34 = ($35|0)==($36|0);
  if ($34) {
   break;
  }
  $37 = (($35) + -68|0);
  __THREW__ = 0;
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   label = 11;
   break;
  } else {
   $35 = $37;
  }
 }
 if ((label|0) == 11) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 }
 $42 = ($36|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($36|0),($$byval_copy1|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  ___cxa_call_unexpected(($45|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI11GradientNEW13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i36 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre$i16 = 0, $$pre5$i = 0, $$pre5$i18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $scevgep$i$i = 0, $scevgep4$i$i = 0, $scevgep45$i$i = 0, $scevgep6$i$i = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 68)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 68)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = (($18|0) / 68)&-1;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + (($19*68)|0)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i$i = (($23) + -68|0);
   $24 = (0 - ($4))|0;
   $scevgep4$i$i = (($scevgep$i$i) + ($24)|0);
   $scevgep45$i$i = $scevgep4$i$i;
   $25 = (($scevgep45$i$i>>>0) / 68)&-1;
   $$01$i$i = $9;$27 = $1;
   while(1) {
    $26 = HEAP32[$27>>2]|0;
    HEAP32[$$01$i$i>>2] = $26;
    $28 = (($$01$i$i) + 4|0);
    $29 = (($27) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    HEAP32[$28>>2] = $30;
    $31 = (($$01$i$i) + 8|0);
    $32 = (($27) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    HEAP32[$31>>2] = $33;
    $34 = (($$01$i$i) + 12|0);
    $35 = (($27) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$34>>2] = $36;
    $37 = (($$01$i$i) + 16|0);
    $38 = (($27) + 16|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$37>>2] = $39;
    $40 = (($$01$i$i) + 20|0);
    $41 = (($27) + 20|0);
    $42 = HEAP32[$41>>2]|0;
    HEAP32[$40>>2] = $42;
    $43 = (($$01$i$i) + 24|0);
    $44 = (($27) + 24|0);
    $45 = HEAP32[$44>>2]|0;
    HEAP32[$43>>2] = $45;
    $46 = (($$01$i$i) + 28|0);
    $47 = (($27) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    HEAP32[$46>>2] = $48;
    $49 = (($$01$i$i) + 32|0);
    $50 = (($27) + 32|0);
    dest=$49+0|0; src=$50+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
    $51 = (($27) + 68|0);
    $52 = (($$01$i$i) + 68|0);
    $53 = ($51|0)==($23|0);
    if ($53) {
     break;
    } else {
     $$01$i$i = $52;$27 = $51;
    }
   }
   $54 = (($25) + 1)|0;
   $scevgep6$i$i = (($9) + (($54*68)|0)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  if (!($__growing$0$off0)) {
   while(1) {
    $63 = HEAP32[$15>>2]|0;
    $64 = ($63|0)==($$0$lcssa$i$i|0);
    if ($64) {
     label = 34;
     break;
    }
    $65 = (($63) + -68|0);
    HEAP32[$15>>2] = $65;
    __THREW__ = 0;
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     label = 16;
     break;
    }
   }
   if ((label|0) == 16) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    ___cxa_call_unexpected(($68|0));
    // unreachable;
   }
   else if ((label|0) == 34) {
    STACKTOP = sp;return;
   }
  }
  $55 = ($23|0)==($2|0);
  if ($55) {
   STACKTOP = sp;return;
  }
  $$pre$i16 = HEAP32[$15>>2]|0;
  $57 = $$pre$i16;$58 = $23;
  while(1) {
   $56 = ($57|0)==(0|0);
   if ($56) {
    $60 = 0;
   } else {
    dest=$57+0|0; src=$58+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre5$i18 = HEAP32[$15>>2]|0;
    $60 = $$pre5$i18;
   }
   $59 = (($60) + 68|0);
   HEAP32[$15>>2] = $59;
   $61 = (($58) + 68|0);
   $62 = ($61|0)==($2|0);
   if ($62) {
    break;
   } else {
    $57 = $59;$58 = $61;
   }
  }
  STACKTOP = sp;return;
 }
 $70 = ($9|0)==(0|0);
 do {
  if ($70) {
   $86 = $8;
  } else {
   $71 = (($this) + 4|0);
   while(1) {
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)==($9|0);
    if ($73) {
     break;
    }
    $74 = (($72) + -68|0);
    HEAP32[$71>>2] = $74;
    __THREW__ = 0;
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     label = 21;
     break;
    }
   }
   if ((label|0) == 21) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    ___cxa_call_unexpected(($77|0));
    // unreachable;
   }
   $79 = HEAP32[$this>>2]|0;
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($79|0),($$byval_copy1|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$71>>2] = 0;
    HEAP32[$this>>2] = 0;
    $86 = 0;
    break;
   }
  }
 } while(0);
 $84 = ($5|0)<(0);
 if ($84) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $85 = $86;
 $87 = (($85|0) / 68)&-1;
 $88 = ($87>>>0)<(1073741823);
 if ($88) {
  $89 = $87 << 1;
  $90 = ($89>>>0)<($6>>>0);
  $91 = $90 ? $6 : $89;
  $92 = ($91|0)<(0);
  if ($92) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i36 = $91;
  }
 } else {
  $$0$i36 = 2147483647;
 }
 $93 = ($$0$i36*68)|0;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $94 = (__Z15malloc_internaljj10MemLabelIdiPKci($93,16,$$byval_copy1,0,630440,79)|0);
 $95 = (($this) + 4|0);
 HEAP32[$95>>2] = $94;
 HEAP32[$this>>2] = $94;
 $96 = (($94) + (($$0$i36*68)|0)|0);
 HEAP32[$7>>2] = $96;
 $97 = ($1|0)==($2|0);
 if ($97) {
  STACKTOP = sp;return;
 } else {
  $100 = $1;$99 = $94;
 }
 while(1) {
  $98 = ($99|0)==(0|0);
  if ($98) {
   $102 = 0;
  } else {
   dest=$99+0|0; src=$100+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre5$i = HEAP32[$95>>2]|0;
   $102 = $$pre5$i;
  }
  $101 = (($102) + 68|0);
  HEAP32[$95>>2] = $101;
  $103 = (($100) + 68|0);
  $104 = ($103|0)==($2|0);
  if ($104) {
   break;
  } else {
   $100 = $103;$99 = $101;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI11GradientNEW13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i119 = 0, $$0$i120 = 0, $$0$i3 = 0, $$01$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i7 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $scevgep = 0, $scevgep14 = 0, $scevgep1415 = 0, $scevgep16 = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 68)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    __ZN11GradientNEWC2Ev($11);
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 68|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = (($18|0) / 68)&-1;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = (($22|0) / 68)&-1;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $23 << 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i120 = 0;$32 = 0;
  } else {
   $$0$i119 = $27;
   label = 9;
  }
 } else {
  $$0$i119 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = ($$0$i119*68)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy2,0,630440,79)|0);
  $$0$i120 = $$0$i119;$32 = $30;
 }
 $31 = (($32) + (($19*68)|0)|0);
 $33 = (($32) + (($$0$i120*68)|0)|0);
 $$0$i3 = $__n;$35 = $31;
 while(1) {
  $34 = ($35|0)==(0|0);
  if ($34) {
   $39 = 0;
  } else {
   __THREW__ = 0;
   invoke_vi(3551,($35|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    label = 25;
    break;
   } else {
    $39 = $35;
   }
  }
  $38 = (($39) + 68|0);
  $40 = (($$0$i3) + -1)|0;
  $41 = ($40|0)==(0);
  if ($41) {
   break;
  } else {
   $$0$i3 = $40;$35 = $38;
  }
 }
 if ((label|0) == 25) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  $72 = $35;
  while(1) {
   $71 = ($72|0)==($31|0);
   if ($71) {
    break;
   }
   $73 = (($72) + -68|0);
   __THREW__ = 0;
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 28;
    break;
   } else {
    $72 = $73;
   }
  }
  if ((label|0) == 28) {
   $76 = ___cxa_find_matching_catch()|0;
   $77 = tempRet0;
   ___cxa_call_unexpected(($76|0));
   // unreachable;
  }
  $78 = ($32|0)==(0|0);
  if ($78) {
   ___resumeException($69|0);
   // unreachable;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($32|0),($$byval_copy2|0));
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if ($80) {
   $81 = ___cxa_find_matching_catch()|0;
   $82 = tempRet0;
   ___cxa_call_unexpected(($81|0));
   // unreachable;
  } else {
   ___resumeException($69|0);
   // unreachable;
  }
 }
 $42 = HEAP32[$this>>2]|0;
 $43 = HEAP32[$3>>2]|0;
 $44 = ($43|0)==($42|0);
 if ($44) {
  $55 = $31;$58 = $42;$83 = $42;
 } else {
  $45 = $42;
  $46 = (($19) + -1)|0;
  $scevgep = (($43) + -68|0);
  $47 = (0 - ($45))|0;
  $scevgep14 = (($scevgep) + ($47)|0);
  $scevgep1415 = $scevgep14;
  $48 = (($scevgep1415>>>0) / 68)&-1;
  $49 = (($46) - ($48))|0;
  $$01$i$i = $43;$52 = $31;
  while(1) {
   $50 = (($$01$i$i) + -68|0);
   $51 = (($52) + -68|0);
   dest=$51+0|0; src=$50+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $53 = (($52) + -68|0);
   $54 = ($50|0)==($42|0);
   if ($54) {
    break;
   } else {
    $$01$i$i = $50;$52 = $53;
   }
  }
  $scevgep16 = (($32) + (($49*68)|0)|0);
  $$pre$i7 = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $55 = $scevgep16;$58 = $$pre$i7;$83 = $$pre;
 }
 HEAP32[$this>>2] = $55;
 HEAP32[$3>>2] = $38;
 HEAP32[$1>>2] = $33;
 $57 = $83;
 while(1) {
  $56 = ($57|0)==($58|0);
  if ($56) {
   break;
  }
  $59 = (($57) + -68|0);
  __THREW__ = 0;
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if ($61) {
   label = 21;
   break;
  } else {
   $57 = $59;
  }
 }
 if ((label|0) == 21) {
  $62 = ___cxa_find_matching_catch()|0;
  $63 = tempRet0;
  ___cxa_call_unexpected(($62|0));
  // unreachable;
 }
 $64 = ($58|0)==(0|0);
 if ($64) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($58|0),($$byval_copy2|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  ___cxa_call_unexpected(($67|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $index$01$i = 0, $index$013 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viii(1809,($6|0),($buffer|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 4;
  } else {
   $39 = (($runtimeInfo) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($staticInfo) + 28|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$1>>2]|0;
   $44 = HEAP32[$buffer>>2]|0;
   $45 = $43;
   $46 = $44;
   $47 = (($45) - ($46))|0;
   $48 = (($47|0) / 80)&-1;
   $49 = (($40) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==($48|0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_ii(3288,($42|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $55 = (invoke_iiii(1554,($42|0),($52|0),($48|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     label = 4;
     break;
    }
    HEAP32[$40>>2] = $55;
    HEAP32[$49>>2] = $48;
   }
   $58 = ($43|0)==($44|0);
   L8: do {
    if (!($58)) {
     $59 = (($buffer) + 12|0);
     $index$01$i = 0;
     while(1) {
      $60 = HEAP32[$40>>2]|0;
      __THREW__ = 0;
      $61 = (invoke_iii(2433,($60|0),($index$01$i|0))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
      $64 = HEAP32[$buffer>>2]|0;
      $65 = (($64) + (($index$01$i*80)|0)|0);
      __THREW__ = 0;
      invoke_viii(1798,($59|0),($65|0),($61|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$01$i) + 1)|0;
      $69 = ($68|0)==($48|0);
      if ($69) {
       break L8;
      } else {
       $index$01$i = $68;
      }
     }
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index3 = $12;
     break L1;
    }
   } while(0);
   $70 = HEAP32[$39>>2]|0;
   $71 = (($70) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0);
   L16: do {
    if (!($73)) {
     $75 = $70;$index$013 = 0;
     while(1) {
      $74 = HEAP32[$75>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2433,($74|0),($index$013|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      $78 = (($index$013) + 1)|0;
      $79 = HEAP32[$39>>2]|0;
      $80 = (($79) + 4|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ($78|0)==($81|0);
      if ($82) {
       break L16;
      } else {
       $75 = $79;$index$013 = $78;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $83 = HEAP32[$buffer>>2]|0;
   $84 = ($83|0)==(0|0);
   if ($84) {
    STACKTOP = sp;return;
   }
   $85 = HEAP32[$1>>2]|0;
   $86 = ($85|0)==($83|0);
   do {
    if ($86) {
     $102 = $83;
    } else {
     $88 = $85;
     while(1) {
      $87 = (($88) + -80|0);
      HEAP32[$1>>2] = $87;
      $89 = (($88) + -12|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = ($90|0)>(-1);
      if ($91) {
       $94 = (($88) + -24|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = (($88) + -20|0);
       $97 = HEAP32[$96>>2]|0;
       HEAP32[$0>>2] = $97;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($95|0),($$byval_copy10|0));
       $98 = __THREW__; __THREW__ = 0;
       $99 = $98&1;
       if ($99) {
        label = 35;
        break;
       }
       HEAP32[$94>>2] = 0;
       $$pre$i$i$i$i$i$i$i = HEAP32[$1>>2]|0;
       $93 = $$pre$i$i$i$i$i$i$i;
      } else {
       $93 = $87;
      }
      $92 = ($93|0)==($83|0);
      if ($92) {
       label = 36;
       break;
      } else {
       $88 = $93;
      }
     }
     if ((label|0) == 35) {
      $100 = ___cxa_find_matching_catch()|0;
      $101 = tempRet0;
      ___cxa_call_unexpected(($100|0));
      // unreachable;
     }
     else if ((label|0) == 36) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $102 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($102|0),($$byval_copy10|0));
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    $105 = ___cxa_find_matching_catch()|0;
    $106 = tempRet0;
    ___cxa_call_unexpected(($105|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 }
 $15 = HEAP32[$buffer>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ($17|0)==($15|0);
 do {
  if ($18) {
   $34 = $15;
  } else {
   $20 = $17;
   while(1) {
    $19 = (($20) + -80|0);
    HEAP32[$1>>2] = $19;
    $21 = (($20) + -12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)>(-1);
    if ($23) {
     $26 = (($20) + -24|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($20) + -20|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$0>>2] = $29;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($27|0),($$byval_copy10|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 12;
      break;
     }
     HEAP32[$26>>2] = 0;
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$1>>2]|0;
     $25 = $$pre$i$i$i$i$i$i$i3;
    } else {
     $25 = $19;
    }
    $24 = ($25|0)==($15|0);
    if ($24) {
     label = 13;
     break;
    } else {
     $20 = $25;
    }
   }
   if ((label|0) == 12) {
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $34 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy10|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN12NativeBufferI27Converter_SimpleNativeClassI17AnimationCurveTplIfEEE15SetupForWritingER9ArrayInfo($this,$inputArray) {
 $this = $this|0;
 $inputArray = $inputArray|0;
 var $$byval_copy = 0, $$pre$i$i$i = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $index$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($inputArray) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 80)&-1;
 $10 = ($9>>>0)<($2>>>0);
 L1: do {
  if ($10) {
   $11 = (($2) - ($9))|0;
   __ZNSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$11);
  } else {
   $12 = ($9>>>0)>($2>>>0);
   if ($12) {
    $13 = (($5) + (($2*80)|0)|0);
    $14 = ($4|0)==($13|0);
    if (!($14)) {
     $16 = $4;
     while(1) {
      $15 = (($16) + -80|0);
      HEAP32[$3>>2] = $15;
      $17 = (($16) + -12|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)>(-1);
      if ($19) {
       $24 = (($16) + -24|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (($16) + -20|0);
       $27 = HEAP32[$26>>2]|0;
       HEAP32[$0>>2] = $27;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($25|0),($$byval_copy|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
       HEAP32[$24>>2] = 0;
       $$pre$i$i$i = HEAP32[$3>>2]|0;
       $21 = $$pre$i$i$i;
      } else {
       $21 = $15;
      }
      $20 = ($21|0)==($13|0);
      if ($20) {
       break L1;
      } else {
       $16 = $21;
      }
     }
     $30 = ___cxa_find_matching_catch()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $22 = ($2|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (($this) + 12|0);
 $index$01 = 0;
 while(1) {
  $32 = HEAP32[$inputArray>>2]|0;
  $33 = (__ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi($32,$index$01)|0);
  $$val = HEAP32[$33>>2]|0;
  $34 = ($$val|0)==(0|0);
  if (!($34)) {
   $35 = HEAP32[$this>>2]|0;
   $36 = (($35) + (($index$01*80)|0)|0);
   __ZN27Converter_SimpleNativeClassI17AnimationCurveTplIfEE17ScriptingToNativeERP15ScriptingObjectPS1_($23,$33,$36);
  }
  $37 = (($index$01) + 1)|0;
  $38 = ($37|0)==($2|0);
  if ($38) {
   break;
  } else {
   $index$01 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN17AnimationCurveTplIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 80|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*80)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy19 = 0, $$idx = 0, $$idx$i$i$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i$i$i14 = 0, $$pre$i$i$i$i$i22 = 0, $$pre$i$i$i$i$i9 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $phitmp$i$i$i$i$i = 0, $temp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy19 = sp + 36|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 80)&-1;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $110 = ($11>>>0)>($sz>>>0);
  if (!($110)) {
   STACKTOP = sp;return;
  }
  $111 = (($7) + (($sz*80)|0)|0);
  $$idx = ($sz*80)|0;
  $112 = (($$idx|0) / 80)&-1;
  $113 = ($sz|0)==(0);
  L6: do {
   if ($113) {
    $182 = 0;$184 = 0;$186 = 0;
   } else {
    $114 = ($$idx|0)<(0);
    if ($114) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     if ($116) {
      label = 52;
     } else {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
     $117 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy19|0),0,(630440|0),79)|0);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      label = 52;
     } else {
      $120 = (($117) + (($112*80)|0)|0);
      $122 = $117;$123 = $7;
      while(1) {
       $121 = ($122|0)==(0|0);
       if ($121) {
        $154 = 0;
       } else {
        dest=$122+0|0; src=$123+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $124 = (($123) + 60|0);
        $125 = HEAP32[$124>>2]|0;
        $126 = (($122) + 60|0);
        HEAP32[$126>>2] = $125;
        $127 = (($122) + 64|0);
        HEAP32[$127>>2] = 0;
        $128 = (($122) + 68|0);
        HEAP32[$128>>2] = 0;
        $129 = (($122) + 56|0);
        HEAP32[$129>>2] = 0;
        $130 = (($123) + 56|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = (($123) + 64|0);
        $133 = HEAP32[$132>>2]|0;
        $$idx$i$i$i$i$i$i = $133 << 4;
        $134 = $$idx$i$i$i$i$i$i >> 4;
        HEAP32[$127>>2] = $134;
        $135 = ($134|0)==(0);
        if ($135) {
         $139 = 0;$140 = 0;
        } else {
         HEAP32[$128>>2] = $134;
         HEAP32[$1>>2] = $125;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
         $136 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i$i$i|0),4,($$byval_copy19|0),0,(630440|0),370)|0);
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if ($138) {
          break;
         }
         HEAP32[$129>>2] = $136;
         $$pre$i$i$i$i$i9 = HEAP32[$127>>2]|0;
         $phitmp$i$i$i$i$i = $$pre$i$i$i$i$i9 << 4;
         $139 = $136;$140 = $phitmp$i$i$i$i$i;
        }
        _memcpy(($139|0),($131|0),($140|0))|0;
        $141 = (($122) + 72|0);
        $142 = (($123) + 72|0);
        $143 = $142;
        $144 = $143;
        $145 = HEAP32[$144>>2]|0;
        $146 = (($143) + 4)|0;
        $147 = $146;
        $148 = HEAP32[$147>>2]|0;
        $149 = $141;
        $150 = $149;
        HEAP32[$150>>2] = $145;
        $151 = (($149) + 4)|0;
        $152 = $151;
        HEAP32[$152>>2] = $148;
        $154 = $122;
       }
       $153 = (($154) + 80|0);
       $155 = (($123) + 80|0);
       $156 = ($155|0)==($111|0);
       if ($156) {
        $182 = $117;$184 = $153;$186 = $120;
        break L6;
       } else {
        $122 = $153;$123 = $155;
       }
      }
      $159 = ___cxa_find_matching_catch()|0;
      $160 = tempRet0;
      $161 = ($117|0)==(0|0);
      if ($161) {
       $eh$lpad$body$index3Z2D = $160;$eh$lpad$body$indexZ2D = $159;
      } else {
       $162 = ($122|0)==($117|0);
       L24: do {
        if (!($162)) {
         $164 = $122;
         while(1) {
          $163 = (($164) + -80|0);
          $165 = (($164) + -12|0);
          $166 = HEAP32[$165>>2]|0;
          $167 = ($166|0)>(-1);
          if ($167) {
           $169 = (($164) + -24|0);
           $170 = HEAP32[$169>>2]|0;
           $171 = (($164) + -20|0);
           $172 = HEAP32[$171>>2]|0;
           HEAP32[$$byval_copy>>2] = $172;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
           invoke_vii(2591,($170|0),($$byval_copy19|0));
           $173 = __THREW__; __THREW__ = 0;
           $174 = $173&1;
           if ($174) {
            break;
           }
           HEAP32[$169>>2] = 0;
          }
          $168 = ($163|0)==($117|0);
          if ($168) {
           break L24;
          } else {
           $164 = $163;
          }
         }
         $175 = ___cxa_find_matching_catch()|0;
         $176 = tempRet0;
         ___cxa_call_unexpected(($175|0));
         // unreachable;
        }
       } while(0);
       HEAP32[$$byval_copy>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
       invoke_vii(2591,($117|0),($$byval_copy19|0));
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        $179 = ___cxa_find_matching_catch()|0;
        $180 = tempRet0;
        ___cxa_call_unexpected(($179|0));
        // unreachable;
       } else {
        $eh$lpad$body$index3Z2D = $160;$eh$lpad$body$indexZ2D = $159;
       }
      }
     }
    }
    if ((label|0) == 52) {
     $157 = ___cxa_find_matching_catch()|0;
     $158 = tempRet0;
     $eh$lpad$body$index3Z2D = $158;$eh$lpad$body$indexZ2D = $157;
    }
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $181 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $182;
  $183 = HEAP32[$5>>2]|0;
  HEAP32[$5>>2] = $184;
  $185 = (($v) + 8|0);
  HEAP32[$185>>2] = $186;
  $187 = ($181|0)==(0|0);
  if ($187) {
   STACKTOP = sp;return;
  }
  $188 = ($183|0)==($181|0);
  L43: do {
   if (!($188)) {
    $190 = $183;
    while(1) {
     $189 = (($190) + -80|0);
     $191 = (($190) + -12|0);
     $192 = HEAP32[$191>>2]|0;
     $193 = ($192|0)>(-1);
     if ($193) {
      $195 = (($190) + -24|0);
      $196 = HEAP32[$195>>2]|0;
      $197 = (($190) + -20|0);
      $198 = HEAP32[$197>>2]|0;
      HEAP32[$$byval_copy>>2] = $198;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
      invoke_vii(2591,($196|0),($$byval_copy19|0));
      $199 = __THREW__; __THREW__ = 0;
      $200 = $199&1;
      if ($200) {
       break;
      }
      HEAP32[$195>>2] = 0;
     }
     $194 = ($189|0)==($181|0);
     if ($194) {
      break L43;
     } else {
      $190 = $189;
     }
    }
    $201 = ___cxa_find_matching_catch()|0;
    $202 = tempRet0;
    ___cxa_call_unexpected(($201|0));
    // unreachable;
   }
  } while(0);
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($181|0),($$byval_copy19|0));
  $203 = __THREW__; __THREW__ = 0;
  $204 = $203&1;
  if ($204) {
   $205 = ___cxa_find_matching_catch()|0;
   $206 = tempRet0;
   ___cxa_call_unexpected(($205|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 80)&-1;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $109 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$109);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2876,($temp|0),($sz|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 L61: do {
  if (!($22)) {
   $23 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $23;
   $24 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1810,($temp|0),($$byval_copy|0),($$byval_copy19|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP32[$19>>2]|0;
    $28 = HEAP32[$temp>>2]|0;
    $29 = $27;
    $30 = $28;
    $31 = (($29) - ($30))|0;
    $32 = (($31|0) / 80)&-1;
    $33 = ($32>>>0)<($sz>>>0);
    L64: do {
     if ($33) {
      $34 = (($sz) - ($32))|0;
      __THREW__ = 0;
      invoke_vii(2877,($temp|0),($34|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break L61;
      }
      $$pre = HEAP32[$19>>2]|0;
      $58 = $$pre;
     } else {
      $37 = ($32>>>0)>($sz>>>0);
      if ($37) {
       $38 = (($28) + (($sz*80)|0)|0);
       $39 = ($27|0)==($38|0);
       if ($39) {
        $58 = $27;
       } else {
        $41 = $27;
        while(1) {
         $40 = (($41) + -80|0);
         HEAP32[$19>>2] = $40;
         $42 = (($41) + -12|0);
         $43 = HEAP32[$42>>2]|0;
         $44 = ($43|0)>(-1);
         if ($44) {
          $47 = (($41) + -24|0);
          $48 = HEAP32[$47>>2]|0;
          $49 = (($41) + -20|0);
          $50 = HEAP32[$49>>2]|0;
          HEAP32[$$byval_copy>>2] = $50;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
          invoke_vii(2591,($48|0),($$byval_copy19|0));
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          HEAP32[$47>>2] = 0;
          $$pre$i$i$i10 = HEAP32[$19>>2]|0;
          $46 = $$pre$i$i$i10;
         } else {
          $46 = $40;
         }
         $45 = ($46|0)==($38|0);
         if ($45) {
          $58 = $38;
          break L64;
         } else {
          $41 = $46;
         }
        }
        $53 = ___cxa_find_matching_catch()|0;
        $54 = tempRet0;
        ___cxa_call_unexpected(($53|0));
        // unreachable;
       }
      } else {
       $58 = $27;
      }
     }
    } while(0);
    $55 = HEAP32[$temp>>2]|0;
    $56 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $56;
    HEAP32[$v>>2] = $55;
    $57 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $57;
    HEAP32[$5>>2] = $58;
    $59 = HEAP32[$20>>2]|0;
    $60 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $60;
    HEAP32[$13>>2] = $59;
    $61 = ($56|0)==(0|0);
    if ($61) {
     STACKTOP = sp;return;
    }
    $62 = ($57|0)==($56|0);
    do {
     if ($62) {
      $78 = $56;
     } else {
      $64 = $57;
      while(1) {
       $63 = (($64) + -80|0);
       HEAP32[$19>>2] = $63;
       $65 = (($64) + -12|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = ($66|0)>(-1);
       if ($67) {
        $70 = (($64) + -24|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = (($64) + -20|0);
        $73 = HEAP32[$72>>2]|0;
        HEAP32[$$byval_copy>>2] = $73;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
        invoke_vii(2591,($71|0),($$byval_copy19|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 23;
         break;
        }
        HEAP32[$70>>2] = 0;
        $$pre$i$i$i$i$i14 = HEAP32[$19>>2]|0;
        $69 = $$pre$i$i$i$i$i14;
       } else {
        $69 = $63;
       }
       $68 = ($69|0)==($56|0);
       if ($68) {
        label = 24;
        break;
       } else {
        $64 = $69;
       }
      }
      if ((label|0) == 23) {
       $76 = ___cxa_find_matching_catch()|0;
       $77 = tempRet0;
       ___cxa_call_unexpected(($76|0));
       // unreachable;
      }
      else if ((label|0) == 24) {
       $$pre$i$i$i16 = HEAP32[$temp>>2]|0;
       $78 = $$pre$i$i$i16;
       break;
      }
     }
    } while(0);
    HEAP32[$$byval_copy>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($78|0),($$byval_copy19|0));
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     $81 = ___cxa_find_matching_catch()|0;
     $82 = tempRet0;
     ___cxa_call_unexpected(($81|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $83 = ___cxa_find_matching_catch()|0;
 $84 = tempRet0;
 $85 = HEAP32[$temp>>2]|0;
 $86 = ($85|0)==(0|0);
 if ($86) {
  $$0 = $84;$$01 = $83;
  ___resumeException($$01|0);
  // unreachable;
 }
 $87 = HEAP32[$19>>2]|0;
 $88 = ($87|0)==($85|0);
 do {
  if ($88) {
   $104 = $85;
  } else {
   $90 = $87;
   while(1) {
    $89 = (($90) + -80|0);
    HEAP32[$19>>2] = $89;
    $91 = (($90) + -12|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)>(-1);
    if ($93) {
     $96 = (($90) + -24|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = (($90) + -20|0);
     $99 = HEAP32[$98>>2]|0;
     HEAP32[$$byval_copy>>2] = $99;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
     invoke_vii(2591,($97|0),($$byval_copy19|0));
     $100 = __THREW__; __THREW__ = 0;
     $101 = $100&1;
     if ($101) {
      label = 34;
      break;
     }
     HEAP32[$96>>2] = 0;
     $$pre$i$i$i$i$i22 = HEAP32[$19>>2]|0;
     $95 = $$pre$i$i$i$i$i22;
    } else {
     $95 = $89;
    }
    $94 = ($95|0)==($85|0);
    if ($94) {
     label = 35;
     break;
    } else {
     $90 = $95;
    }
   }
   if ((label|0) == 34) {
    $102 = ___cxa_find_matching_catch()|0;
    $103 = tempRet0;
    ___cxa_call_unexpected(($102|0));
    // unreachable;
   }
   else if ((label|0) == 35) {
    $$pre$i$i$i24 = HEAP32[$temp>>2]|0;
    $104 = $$pre$i$i$i24;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($104|0),($$byval_copy19|0));
 $105 = __THREW__; __THREW__ = 0;
 $106 = $105&1;
 if ($106) {
  $107 = ___cxa_find_matching_catch()|0;
  $108 = tempRet0;
  ___cxa_call_unexpected(($107|0));
  // unreachable;
 } else {
  $$0 = $84;$$01 = $83;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy5 = 0, $$idx$i$i$i$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre11 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 80)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($6))|0;
 $14 = (($13|0) / 80)&-1;
 $15 = ($__n|0)==(0);
 if ($15) {
  $19 = 0;$22 = $11;$23 = $4;
 } else {
  $16 = ($__n*80)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($16,16,$$byval_copy5,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre11 = HEAP32[$10>>2]|0;
  $19 = $17;$22 = $$pre11;$23 = $$pre;
 }
 $18 = (($19) + (($14*80)|0)|0);
 $20 = (($19) + (($__n*80)|0)|0);
 $21 = ($22|0)==($23|0);
 L7: do {
  if ($21) {
   HEAP32[$this>>2] = $18;
   HEAP32[$10>>2] = $18;
   HEAP32[$2>>2] = $20;
   $73 = $22;
  } else {
   $$01$i$i = $22;$25 = $18;
   while(1) {
    $24 = (($25) + -80|0);
    $26 = (($$01$i$i) + -80|0);
    dest=$24+0|0; src=$26+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $27 = (($$01$i$i) + -20|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($25) + -20|0);
    HEAP32[$29>>2] = $28;
    $30 = (($25) + -16|0);
    HEAP32[$30>>2] = 0;
    $31 = (($25) + -12|0);
    HEAP32[$31>>2] = 0;
    $32 = (($25) + -24|0);
    HEAP32[$32>>2] = 0;
    $33 = (($$01$i$i) + -24|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($$01$i$i) + -16|0);
    $36 = HEAP32[$35>>2]|0;
    $$idx$i$i$i$i$i$i$i = $36 << 4;
    $37 = $$idx$i$i$i$i$i$i$i >> 4;
    HEAP32[$30>>2] = $37;
    $38 = ($37|0)==(0);
    if ($38) {
     $42 = 0;$43 = 0;
    } else {
     HEAP32[$31>>2] = $37;
     HEAP32[$0>>2] = $28;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $39 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i$i$i$i|0),4,($$byval_copy5|0),0,(630440|0),370)|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     HEAP32[$32>>2] = $39;
     $$pre$i$i$i$i$i$i = HEAP32[$30>>2]|0;
     $phitmp$i$i$i$i$i$i = $$pre$i$i$i$i$i$i << 4;
     $42 = $39;$43 = $phitmp$i$i$i$i$i$i;
    }
    _memcpy(($42|0),($34|0),($43|0))|0;
    $44 = (($25) + -8|0);
    $45 = (($$01$i$i) + -8|0);
    $46 = $45;
    $47 = $46;
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4)|0;
    $50 = $49;
    $51 = HEAP32[$50>>2]|0;
    $52 = $44;
    $53 = $52;
    HEAP32[$53>>2] = $48;
    $54 = (($52) + 4)|0;
    $55 = $54;
    HEAP32[$55>>2] = $51;
    $56 = ($26|0)==($23|0);
    if ($56) {
     label = 11;
     break;
    } else {
     $$01$i$i = $26;$25 = $24;
    }
   }
   if ((label|0) == 11) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre12 = HEAP32[$10>>2]|0;
    HEAP32[$this>>2] = $24;
    HEAP32[$10>>2] = $18;
    HEAP32[$2>>2] = $20;
    $57 = ($$pre12|0)==($$pre$i|0);
    if ($57) {
     $73 = $$pre$i;
     break;
    }
    $59 = $$pre12;
    while(1) {
     $58 = (($59) + -80|0);
     $60 = (($59) + -12|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)>(-1);
     if ($62) {
      $64 = (($59) + -24|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($59) + -20|0);
      $67 = HEAP32[$66>>2]|0;
      HEAP32[$0>>2] = $67;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($65|0),($$byval_copy5|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       break;
      }
      HEAP32[$64>>2] = 0;
     }
     $63 = ($58|0)==($$pre$i|0);
     if ($63) {
      $73 = $$pre$i;
      break L7;
     } else {
      $59 = $58;
     }
    }
    $70 = ___cxa_find_matching_catch()|0;
    $71 = tempRet0;
    ___cxa_call_unexpected(($70|0));
    // unreachable;
   }
   $78 = ___cxa_find_matching_catch()|0;
   $79 = tempRet0;
   $80 = ($18|0)==($25|0);
   L26: do {
    if (!($80)) {
     $82 = $18;
     while(1) {
      $81 = (($82) + -80|0);
      $83 = (($82) + -12|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = ($84|0)>(-1);
      if ($85) {
       $87 = (($82) + -24|0);
       $88 = HEAP32[$87>>2]|0;
       $89 = (($82) + -20|0);
       $90 = HEAP32[$89>>2]|0;
       HEAP32[$1>>2] = $90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($88|0),($$byval_copy5|0));
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        break;
       }
       HEAP32[$87>>2] = 0;
      }
      $86 = ($81|0)==($25|0);
      if ($86) {
       break L26;
      } else {
       $82 = $81;
      }
     }
     $93 = ___cxa_find_matching_catch()|0;
     $94 = tempRet0;
     ___cxa_call_unexpected(($93|0));
     // unreachable;
    }
   } while(0);
   $95 = ($19|0)==(0|0);
   if ($95) {
    ___resumeException($78|0);
    // unreachable;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($19|0),($$byval_copy5|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $98 = ___cxa_find_matching_catch()|0;
    $99 = tempRet0;
    ___cxa_call_unexpected(($98|0));
    // unreachable;
   } else {
    ___resumeException($78|0);
    // unreachable;
   }
  }
 } while(0);
 $72 = ($73|0)==(0|0);
 if ($72) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($73|0),($$byval_copy5|0));
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if ($75) {
  $76 = ___cxa_find_matching_catch()|0;
  $77 = tempRet0;
  ___cxa_call_unexpected(($76|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i38 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy7 = 0, $$idx$i$i$i = 0, $$idx$i$i$i$i$i$i = 0, $$idx$i$i$i$i$i$i16 = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i17 = 0, $$pre$i$i$i$i9 = 0, $$pre$i14 = 0, $$pre$i4 = 0, $$pre1$i = 0, $$pre1$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $phitmp$i$i$i$i$i = 0, $phitmp$i$i$i$i$i18 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0;
 var $uglygep16$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 80)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 80)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $124 = ($9|0)==(0|0);
  do {
   if ($124) {
    $150 = $8;
   } else {
    $125 = (($this) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ($126|0)==($9|0);
    do {
     if ($127) {
      $143 = $9;
     } else {
      $129 = $126;
      while(1) {
       $128 = (($129) + -80|0);
       HEAP32[$125>>2] = $128;
       $130 = (($129) + -12|0);
       $131 = HEAP32[$130>>2]|0;
       $132 = ($131|0)>(-1);
       if ($132) {
        $135 = (($129) + -24|0);
        $136 = HEAP32[$135>>2]|0;
        $137 = (($129) + -20|0);
        $138 = HEAP32[$137>>2]|0;
        HEAP32[$0>>2] = $138;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($136|0),($$byval_copy7|0));
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         label = 37;
         break;
        }
        HEAP32[$135>>2] = 0;
        $$pre$i$i$i$i = HEAP32[$125>>2]|0;
        $134 = $$pre$i$i$i$i;
       } else {
        $134 = $128;
       }
       $133 = ($134|0)==($9|0);
       if ($133) {
        label = 38;
        break;
       } else {
        $129 = $134;
       }
      }
      if ((label|0) == 37) {
       $141 = ___cxa_find_matching_catch()|0;
       $142 = tempRet0;
       ___cxa_call_unexpected(($141|0));
       // unreachable;
      }
      else if ((label|0) == 38) {
       $$pre$i4 = HEAP32[$this>>2]|0;
       $143 = $$pre$i4;
       break;
      }
     }
    } while(0);
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($143|0),($$byval_copy7|0));
    $144 = __THREW__; __THREW__ = 0;
    $145 = $144&1;
    if ($145) {
     $146 = ___cxa_find_matching_catch()|0;
     $147 = tempRet0;
     ___cxa_call_unexpected(($146|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$125>>2] = 0;
     HEAP32[$this>>2] = 0;
     $150 = 0;
     break;
    }
   }
  } while(0);
  $148 = ($5|0)<(0);
  if ($148) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $149 = $150;
  $151 = (($149|0) / 80)&-1;
  $152 = ($151>>>0)<(1073741823);
  if ($152) {
   $153 = $151 << 1;
   $154 = ($153>>>0)<($6>>>0);
   $155 = $154 ? $6 : $153;
   $156 = ($155|0)<(0);
   if ($156) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i38 = $155;
   }
  } else {
   $$0$i38 = 2147483647;
  }
  $157 = ($$0$i38*80)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $158 = (__Z15malloc_internaljj10MemLabelIdiPKci($157,16,$$byval_copy7,0,630440,79)|0);
  $159 = (($this) + 4|0);
  HEAP32[$159>>2] = $158;
  HEAP32[$this>>2] = $158;
  $160 = (($158) + (($$0$i38*80)|0)|0);
  HEAP32[$7>>2] = $160;
  $161 = HEAP32[$__first>>2]|0;
  $162 = HEAP32[$__last>>2]|0;
  $163 = ($161|0)==($162|0);
  if ($163) {
   STACKTOP = sp;return;
  }
  $165 = $158;$166 = $161;
  while(1) {
   $164 = ($165|0)==(0|0);
   if ($164) {
    $195 = 0;
   } else {
    dest=$165+0|0; src=$166+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $167 = (($166) + 60|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = (($165) + 60|0);
    HEAP32[$169>>2] = $168;
    $170 = (($165) + 64|0);
    HEAP32[$170>>2] = 0;
    $171 = (($165) + 68|0);
    HEAP32[$171>>2] = 0;
    $172 = (($165) + 56|0);
    HEAP32[$172>>2] = 0;
    $173 = (($166) + 56|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = (($166) + 64|0);
    $176 = HEAP32[$175>>2]|0;
    $$idx$i$i$i$i$i$i = $176 << 4;
    $177 = $$idx$i$i$i$i$i$i >> 4;
    HEAP32[$170>>2] = $177;
    $178 = ($177|0)==(0);
    if ($178) {
     $180 = 0;$181 = 0;
    } else {
     HEAP32[$171>>2] = $177;
     HEAP32[$0>>2] = $168;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
     $179 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i$i$i$i$i,4,$$byval_copy7,0,630440,370)|0);
     HEAP32[$172>>2] = $179;
     $$pre$i$i$i$i$i = HEAP32[$170>>2]|0;
     $phitmp$i$i$i$i$i = $$pre$i$i$i$i$i << 4;
     $180 = $179;$181 = $phitmp$i$i$i$i$i;
    }
    _memcpy(($180|0),($174|0),($181|0))|0;
    $182 = (($165) + 72|0);
    $183 = (($166) + 72|0);
    $184 = $183;
    $185 = $184;
    $186 = HEAP32[$185>>2]|0;
    $187 = (($184) + 4)|0;
    $188 = $187;
    $189 = HEAP32[$188>>2]|0;
    $190 = $182;
    $191 = $190;
    HEAP32[$191>>2] = $186;
    $192 = (($190) + 4)|0;
    $193 = $192;
    HEAP32[$193>>2] = $189;
    $$pre1$i = HEAP32[$159>>2]|0;
    $195 = $$pre1$i;
   }
   $194 = (($195) + 80|0);
   HEAP32[$159>>2] = $194;
   $196 = (($166) + 80|0);
   $197 = ($196|0)==($162|0);
   if ($197) {
    break;
   } else {
    $165 = $194;$166 = $196;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16;
 $18 = (($17) - ($11))|0;
 $19 = (($18|0) / 80)&-1;
 $20 = ($6>>>0)>($19>>>0);
 if ($20) {
  $21 = (($1) + (($19*80)|0)|0);
  $23 = $21;$__growing$0$off0 = 1;
 } else {
  $23 = $2;$__growing$0$off0 = 0;
 }
 $22 = ($1|0)==($23|0);
 if ($22) {
  $$0$lcssa$i$i = $9;
 } else {
  $scevgep$i = (($23) + -80|0);
  $24 = (0 - ($4))|0;
  $uglygep$i = (($scevgep$i) + ($24)|0);
  $uglygep16$i = $uglygep$i;
  $25 = (($uglygep16$i>>>0) / 80)&-1;
  $$01$i$i = $9;$26 = $1;
  while(1) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$$01$i$i+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$$01$i$i+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$$01$i$i+20>>2]=HEAP32[$26+20>>2]|0;HEAP32[$$01$i$i+24>>2]=HEAP32[$26+24>>2]|0;
   $27 = (($$01$i$i) + 28|0);
   $28 = (($26) + 28|0);
   ;HEAP32[$27+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$28+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$28+12>>2]|0;HEAP32[$27+16>>2]=HEAP32[$28+16>>2]|0;HEAP32[$27+20>>2]=HEAP32[$28+20>>2]|0;HEAP32[$27+24>>2]=HEAP32[$28+24>>2]|0;
   $29 = (($$01$i$i) + 56|0);
   $30 = ($26|0)==($$01$i$i|0);
   if (!($30)) {
    $31 = (($26) + 56|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($26) + 64|0);
    $34 = HEAP32[$33>>2]|0;
    $$idx$i$i$i = $34 << 4;
    $35 = $$idx$i$i$i >> 4;
    $36 = (($$01$i$i) + 64|0);
    HEAP32[$36>>2] = $35;
    $37 = (($$01$i$i) + 68|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = $38 & 2147483647;
    $40 = ($39>>>0)<($35>>>0);
    do {
     if ($40) {
      $41 = ($38|0)>(-1);
      if ($41) {
       HEAP32[$37>>2] = $35;
       $42 = HEAP32[$29>>2]|0;
       $43 = (($$01$i$i) + 60|0);
       $44 = HEAP32[$43>>2]|0;
       HEAP32[$0>>2] = $44;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
       $45 = (__Z16realloc_internalPvji10MemLabelIdiPKci($42,$$idx$i$i$i,4,$$byval_copy7,0,630440,370)|0);
       HEAP32[$29>>2] = $45;
       $54 = $45;
       break;
      } else {
       $46 = (($$01$i$i) + 60|0);
       $47 = HEAP32[$46>>2]|0;
       HEAP32[$0>>2] = $47;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
       $48 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx$i$i$i,4,$$byval_copy7,0,630440,352)|0);
       $49 = HEAP32[$29>>2]|0;
       $50 = HEAP32[$36>>2]|0;
       $51 = $50 << 4;
       _memcpy(($48|0),($49|0),($51|0))|0;
       HEAP32[$37>>2] = $35;
       HEAP32[$29>>2] = $48;
       $54 = $48;
       break;
      }
     } else {
      $$pre$i$i$i$i9 = HEAP32[$29>>2]|0;
      $54 = $$pre$i$i$i$i9;
     }
    } while(0);
    $52 = HEAP32[$36>>2]|0;
    $53 = $52 << 4;
    _memcpy(($54|0),($32|0),($53|0))|0;
   }
   $55 = (($$01$i$i) + 72|0);
   $56 = (($26) + 72|0);
   $57 = $56;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + 4)|0;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = $55;
   $64 = $63;
   HEAP32[$64>>2] = $59;
   $65 = (($63) + 4)|0;
   $66 = $65;
   HEAP32[$66>>2] = $62;
   $67 = (($26) + 80|0);
   $68 = (($$01$i$i) + 80|0);
   $69 = ($67|0)==($23|0);
   if ($69) {
    break;
   } else {
    $$01$i$i = $68;$26 = $67;
   }
  }
  $70 = (($25) + 1)|0;
  $scevgep17$i = (($9) + (($70*80)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  $71 = HEAP32[$__last>>2]|0;
  $72 = ($23|0)==($71|0);
  if ($72) {
   STACKTOP = sp;return;
  }
  $$pre$i14 = HEAP32[$15>>2]|0;
  $74 = $$pre$i14;$75 = $23;
  while(1) {
   $73 = ($74|0)==(0|0);
   if ($73) {
    $104 = 0;
   } else {
    dest=$74+0|0; src=$75+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $76 = (($75) + 60|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($74) + 60|0);
    HEAP32[$78>>2] = $77;
    $79 = (($74) + 64|0);
    HEAP32[$79>>2] = 0;
    $80 = (($74) + 68|0);
    HEAP32[$80>>2] = 0;
    $81 = (($74) + 56|0);
    HEAP32[$81>>2] = 0;
    $82 = (($75) + 56|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($75) + 64|0);
    $85 = HEAP32[$84>>2]|0;
    $$idx$i$i$i$i$i$i16 = $85 << 4;
    $86 = $$idx$i$i$i$i$i$i16 >> 4;
    HEAP32[$79>>2] = $86;
    $87 = ($86|0)==(0);
    if ($87) {
     $89 = 0;$90 = 0;
    } else {
     HEAP32[$80>>2] = $86;
     HEAP32[$0>>2] = $77;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
     $88 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i$i$i$i$i16,4,$$byval_copy7,0,630440,370)|0);
     HEAP32[$81>>2] = $88;
     $$pre$i$i$i$i$i17 = HEAP32[$79>>2]|0;
     $phitmp$i$i$i$i$i18 = $$pre$i$i$i$i$i17 << 4;
     $89 = $88;$90 = $phitmp$i$i$i$i$i18;
    }
    _memcpy(($89|0),($83|0),($90|0))|0;
    $91 = (($74) + 72|0);
    $92 = (($75) + 72|0);
    $93 = $92;
    $94 = $93;
    $95 = HEAP32[$94>>2]|0;
    $96 = (($93) + 4)|0;
    $97 = $96;
    $98 = HEAP32[$97>>2]|0;
    $99 = $91;
    $100 = $99;
    HEAP32[$100>>2] = $95;
    $101 = (($99) + 4)|0;
    $102 = $101;
    HEAP32[$102>>2] = $98;
    $$pre1$i19 = HEAP32[$15>>2]|0;
    $104 = $$pre1$i19;
   }
   $103 = (($104) + 80|0);
   HEAP32[$15>>2] = $103;
   $105 = (($75) + 80|0);
   $106 = ($105|0)==($71|0);
   if ($106) {
    break;
   } else {
    $74 = $103;$75 = $105;
   }
  }
  STACKTOP = sp;return;
 } else {
  $107 = HEAP32[$15>>2]|0;
  $108 = ($107|0)==($$0$lcssa$i$i|0);
  if ($108) {
   STACKTOP = sp;return;
  }
  $110 = $107;
  while(1) {
   $109 = (($110) + -80|0);
   HEAP32[$15>>2] = $109;
   $111 = (($110) + -12|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ($112|0)>(-1);
   if ($113) {
    $116 = (($110) + -24|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = (($110) + -20|0);
    $119 = HEAP32[$118>>2]|0;
    HEAP32[$0>>2] = $119;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($117|0),($$byval_copy7|0));
    $120 = __THREW__; __THREW__ = 0;
    $121 = $120&1;
    if ($121) {
     label = 29;
     break;
    }
    HEAP32[$116>>2] = 0;
    $$pre$i$i = HEAP32[$15>>2]|0;
    $115 = $$pre$i$i;
   } else {
    $115 = $109;
   }
   $114 = ($115|0)==($$0$lcssa$i$i|0);
   if ($114) {
    label = 54;
    break;
   } else {
    $110 = $115;
   }
  }
  if ((label|0) == 29) {
   $122 = ___cxa_find_matching_catch()|0;
   $123 = tempRet0;
   ___cxa_call_unexpected(($122|0));
   // unreachable;
  }
  else if ((label|0) == 54) {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i120 = 0, $$0$i121 = 0, $$0$i9 = 0, $$01$i$i = 0, $$byval_copy5 = 0, $$idx$i$i$i$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i13 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 80)&-1;
 $10 = ($9>>>0)<($__n>>>0);
 if (!($10)) {
  $$0$i = $__n;$12 = $5;
  while(1) {
   $11 = ($12|0)==(0|0);
   if ($11) {
    $24 = 0;
   } else {
    $13 = (($12) + 4|0);
    HEAPF32[$13>>2] = Math_fround(inf);
    HEAP32[$12>>2] = 0;
    $14 = (($12) + 8|0);
    ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;HEAP32[$14+16>>2]=0|0;
    $15 = (($12) + 32|0);
    HEAPF32[$15>>2] = Math_fround(inf);
    $16 = (($12) + 28|0);
    HEAP32[$16>>2] = 0;
    $17 = (($12) + 36|0);
    $18 = (($12) + 64|0);
    HEAP32[$18>>2] = 0;
    $19 = (($12) + 68|0);
    HEAP32[$19>>2] = 0;
    $20 = (($12) + 60|0);
    ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;HEAP32[$17+16>>2]=0|0;HEAP32[$17+20>>2]=0|0;
    HEAP32[$20>>2] = 61;
    $21 = (($12) + 76|0);
    HEAP32[$21>>2] = 2;
    $22 = (($12) + 72|0);
    HEAP32[$22>>2] = 2;
    $$pre1$i = HEAP32[$4>>2]|0;
    $24 = $$pre1$i;
   }
   $23 = (($24) + 80|0);
   HEAP32[$4>>2] = $23;
   $25 = (($$0$i) + -1)|0;
   $26 = ($25|0)==(0);
   if ($26) {
    break;
   } else {
    $$0$i = $25;$12 = $23;
   }
  }
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = $27;
 $29 = (($7) - ($28))|0;
 $30 = (($29|0) / 80)&-1;
 $31 = (($30) + ($__n))|0;
 $32 = ($31|0)<(0);
 if ($32) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $33 = (($6) - ($28))|0;
 $34 = (($33|0) / 80)&-1;
 $35 = ($34>>>0)<(1073741823);
 if ($35) {
  $36 = $34 << 1;
  $37 = ($36>>>0)<($31>>>0);
  $38 = $37 ? $31 : $36;
  $39 = ($38|0)==(0);
  if ($39) {
   $$0$i121 = 0;$43 = 0;
  } else {
   $$0$i120 = $38;
   label = 9;
  }
 } else {
  $$0$i120 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $40 = ($$0$i120*80)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  $41 = (__Z15malloc_internaljj10MemLabelIdiPKci($40,16,$$byval_copy5,0,630440,79)|0);
  $$0$i121 = $$0$i120;$43 = $41;
 }
 $42 = (($43) + (($30*80)|0)|0);
 $$0$i9 = $__n;$45 = $42;
 while(1) {
  $44 = ($45|0)==(0|0);
  if ($44) {
   $57 = 0;
  } else {
   $46 = (($45) + 4|0);
   HEAPF32[$46>>2] = Math_fround(inf);
   HEAP32[$45>>2] = 0;
   $47 = (($45) + 8|0);
   ;HEAP32[$47+0>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;HEAP32[$47+12>>2]=0|0;HEAP32[$47+16>>2]=0|0;
   $48 = (($45) + 32|0);
   HEAPF32[$48>>2] = Math_fround(inf);
   $49 = (($45) + 28|0);
   HEAP32[$49>>2] = 0;
   $50 = (($45) + 36|0);
   $51 = (($45) + 64|0);
   HEAP32[$51>>2] = 0;
   $52 = (($45) + 68|0);
   HEAP32[$52>>2] = 0;
   $53 = (($45) + 60|0);
   ;HEAP32[$50+0>>2]=0|0;HEAP32[$50+4>>2]=0|0;HEAP32[$50+8>>2]=0|0;HEAP32[$50+12>>2]=0|0;HEAP32[$50+16>>2]=0|0;HEAP32[$50+20>>2]=0|0;
   HEAP32[$53>>2] = 61;
   $54 = (($45) + 76|0);
   HEAP32[$54>>2] = 2;
   $55 = (($45) + 72|0);
   HEAP32[$55>>2] = 2;
   $57 = $45;
  }
  $56 = (($57) + 80|0);
  $58 = (($$0$i9) + -1)|0;
  $59 = ($58|0)==(0);
  if ($59) {
   break;
  } else {
   $$0$i9 = $58;$45 = $56;
  }
 }
 $60 = (($43) + (($$0$i121*80)|0)|0);
 $61 = HEAP32[$this>>2]|0;
 $62 = HEAP32[$4>>2]|0;
 $63 = ($62|0)==($61|0);
 L23: do {
  if ($63) {
   HEAP32[$this>>2] = $42;
   HEAP32[$4>>2] = $56;
   HEAP32[$2>>2] = $60;
   $113 = $61;
  } else {
   $$01$i$i = $62;$65 = $42;
   while(1) {
    $64 = (($65) + -80|0);
    $66 = (($$01$i$i) + -80|0);
    dest=$64+0|0; src=$66+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $67 = (($$01$i$i) + -20|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($65) + -20|0);
    HEAP32[$69>>2] = $68;
    $70 = (($65) + -16|0);
    HEAP32[$70>>2] = 0;
    $71 = (($65) + -12|0);
    HEAP32[$71>>2] = 0;
    $72 = (($65) + -24|0);
    HEAP32[$72>>2] = 0;
    $73 = (($$01$i$i) + -24|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($$01$i$i) + -16|0);
    $76 = HEAP32[$75>>2]|0;
    $$idx$i$i$i$i$i$i$i = $76 << 4;
    $77 = $$idx$i$i$i$i$i$i$i >> 4;
    HEAP32[$70>>2] = $77;
    $78 = ($77|0)==(0);
    if ($78) {
     $82 = 0;$83 = 0;
    } else {
     HEAP32[$71>>2] = $77;
     HEAP32[$0>>2] = $68;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $79 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i$i$i$i|0),4,($$byval_copy5|0),0,(630440|0),370)|0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     HEAP32[$72>>2] = $79;
     $$pre$i$i$i$i$i$i = HEAP32[$70>>2]|0;
     $phitmp$i$i$i$i$i$i = $$pre$i$i$i$i$i$i << 4;
     $82 = $79;$83 = $phitmp$i$i$i$i$i$i;
    }
    _memcpy(($82|0),($74|0),($83|0))|0;
    $84 = (($65) + -8|0);
    $85 = (($$01$i$i) + -8|0);
    $86 = $85;
    $87 = $86;
    $88 = HEAP32[$87>>2]|0;
    $89 = (($86) + 4)|0;
    $90 = $89;
    $91 = HEAP32[$90>>2]|0;
    $92 = $84;
    $93 = $92;
    HEAP32[$93>>2] = $88;
    $94 = (($92) + 4)|0;
    $95 = $94;
    HEAP32[$95>>2] = $91;
    $96 = ($66|0)==($61|0);
    if ($96) {
     label = 21;
     break;
    } else {
     $$01$i$i = $66;$65 = $64;
    }
   }
   if ((label|0) == 21) {
    $$pre$i13 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$4>>2]|0;
    HEAP32[$this>>2] = $64;
    HEAP32[$4>>2] = $56;
    HEAP32[$2>>2] = $60;
    $97 = ($$pre|0)==($$pre$i13|0);
    if ($97) {
     $113 = $$pre$i13;
     break;
    }
    $99 = $$pre;
    while(1) {
     $98 = (($99) + -80|0);
     $100 = (($99) + -12|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101|0)>(-1);
     if ($102) {
      $104 = (($99) + -24|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = (($99) + -20|0);
      $107 = HEAP32[$106>>2]|0;
      HEAP32[$0>>2] = $107;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($105|0),($$byval_copy5|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       break;
      }
      HEAP32[$104>>2] = 0;
     }
     $103 = ($98|0)==($$pre$i13|0);
     if ($103) {
      $113 = $$pre$i13;
      break L23;
     } else {
      $99 = $98;
     }
    }
    $110 = ___cxa_find_matching_catch()|0;
    $111 = tempRet0;
    ___cxa_call_unexpected(($110|0));
    // unreachable;
   }
   $118 = ___cxa_find_matching_catch()|0;
   $119 = tempRet0;
   $120 = ($56|0)==($65|0);
   L43: do {
    if (!($120)) {
     $122 = $56;
     while(1) {
      $121 = (($122) + -80|0);
      $123 = (($122) + -12|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = ($124|0)>(-1);
      if ($125) {
       $127 = (($122) + -24|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = (($122) + -20|0);
       $130 = HEAP32[$129>>2]|0;
       HEAP32[$1>>2] = $130;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($128|0),($$byval_copy5|0));
       $131 = __THREW__; __THREW__ = 0;
       $132 = $131&1;
       if ($132) {
        break;
       }
       HEAP32[$127>>2] = 0;
      }
      $126 = ($121|0)==($65|0);
      if ($126) {
       break L43;
      } else {
       $122 = $121;
      }
     }
     $133 = ___cxa_find_matching_catch()|0;
     $134 = tempRet0;
     ___cxa_call_unexpected(($133|0));
     // unreachable;
    }
   } while(0);
   $135 = ($43|0)==(0|0);
   if ($135) {
    ___resumeException($118|0);
    // unreachable;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($43|0),($$byval_copy5|0));
   $136 = __THREW__; __THREW__ = 0;
   $137 = $136&1;
   if ($137) {
    $138 = ___cxa_find_matching_catch()|0;
    $139 = tempRet0;
    ___cxa_call_unexpected(($138|0));
    // unreachable;
   } else {
    ___resumeException($118|0);
    // unreachable;
   }
  }
 } while(0);
 $112 = ($113|0)==(0|0);
 if ($112) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($113|0),($$byval_copy5|0));
 $114 = __THREW__; __THREW__ = 0;
 $115 = $114&1;
 if ($115) {
  $116 = ___cxa_find_matching_catch()|0;
  $117 = tempRet0;
  ___cxa_call_unexpected(($116|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1811,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8BitField13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorI8BitField13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
   $$pre$i$i$i$i$i$i = HEAP32[$34>>2]|0;
   $35 = $$pre$i$i$i$i$i$i;
  } else {
   $33 = HEAP32[$29>>2]|0;
   HEAP32[$34>>2] = $33;
   HEAP32[$1>>2] = $30;
   $35 = $33;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$34>>2] = $36;
  $37 = (($34) + 4|0);
  $38 = ($37|0)==($26|0);
  if ($38) {
   break;
  } else {
   $34 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI8BitField13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0;
 var $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $88 = $$idx >> 2;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $109 = 0;$111 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<2)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $109 = $93;$111 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<2)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = HEAP32[$102>>2]|0;
        HEAP32[$100>>2] = $101;
       }
       $103 = (($100) + 4|0);
       $104 = (($102) + 4|0);
       $105 = ($104|0)==($87|0);
       if ($105) {
        break;
       } else {
        $100 = $103;$102 = $104;
       }
      }
      $106 = $uglygep6$i$i >>> 2;
      $107 = (($106) + 1)|0;
      $scevgep8$i$i = (($93) + ($107<<2)|0);
      $109 = $93;$111 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $117 = ___cxa_find_matching_catch()|0;
    $118 = tempRet0;
    $$0 = $118;$$01 = $117;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $108 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $109;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $110 = (($v) + 8|0);
  HEAP32[$110>>2] = $111;
  $112 = ($108|0)==(0|0);
  if ($112) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($108|0),($$byval_copy7|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   ___cxa_call_unexpected(($115|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 2;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI8BitField13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 2;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<2)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 2;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<2)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1812,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 2;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2878,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<2)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -4|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 2;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<2)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -4|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 2;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<2)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -4|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 2;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<2)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8BitField13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $34 = $2;
   $35 = (($34) - ($4))|0;
   $36 = $35 >> 2;
   _memmove(($9|0),($1|0),($35|0))|0;
   $37 = (($9) + ($36<<2)|0);
   $38 = HEAP32[$15>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $37;
   $scevgep$i$i = (($38) + -4|0);
   $40 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($40)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $41 = $uglygep3$i$i >>> 2;
   $42 = $41 ^ -1;
   $scevgep4$i$i = (($38) + ($42<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<2)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -4|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 2;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = HEAP32[$29>>2]|0;
    HEAP32[$27>>2] = $28;
   }
   $30 = (($27) + 4|0);
   $31 = (($29) + 4|0);
   $32 = ($31|0)==($2|0);
   if ($32) {
    break;
   } else {
    $27 = $30;$29 = $31;
   }
  }
  $33 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($33<<2)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $43 = ($9|0)==(0|0);
 do {
  if ($43) {
   $56 = $8;
  } else {
   $44 = (($this) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==($9|0);
   if (!($46)) {
    $scevgep$i$i$i$i = (($45) + -4|0);
    $47 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($47)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $48 = $uglygep3$i$i$i$i >>> 2;
    $49 = $48 ^ -1;
    $scevgep4$i$i$i$i = (($45) + ($49<<2)|0);
    HEAP32[$44>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    ___cxa_call_unexpected(($52|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$44>>2] = 0;
    HEAP32[$this>>2] = 0;
    $56 = 0;
    break;
   }
  }
 } while(0);
 $54 = ($5|0)<(0);
 if ($54) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $55 = $56;
 $57 = $55 >> 2;
 $58 = ($57>>>0)<(1073741823);
 if ($58) {
  $59 = $55 >> 1;
  $60 = ($59>>>0)<($6>>>0);
  $61 = $60 ? $6 : $59;
  $62 = ($61|0)<(0);
  if ($62) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $61;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $63 = $$0$i37 << 2;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $64 = (__Z15malloc_internaljj10MemLabelIdiPKci($63,16,$$byval_copy1,0,630440,79)|0);
 $65 = (($this) + 4|0);
 HEAP32[$65>>2] = $64;
 HEAP32[$this>>2] = $64;
 $66 = (($64) + ($$0$i37<<2)|0);
 HEAP32[$7>>2] = $66;
 $67 = ($1|0)==($2|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -4|0);
 $68 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($68)|0);
 $uglygep6$i = $uglygep$i;
 $69 = $uglygep6$i >>> 2;
 $71 = $64;$73 = $1;
 while(1) {
  $70 = ($71|0)==(0|0);
  if (!($70)) {
   $72 = HEAP32[$73>>2]|0;
   HEAP32[$71>>2] = $72;
  }
  $74 = (($71) + 4|0);
  $75 = (($73) + 4|0);
  $76 = ($75|0)==($2|0);
  if ($76) {
   break;
  } else {
   $71 = $74;$73 = $75;
  }
 }
 $77 = (($69) + 1)|0;
 $scevgep8$i = (($64) + ($77<<2)|0);
 HEAP32[$65>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8BitField13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    HEAP32[$11>>2] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 4|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = $18 >> 2;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = $22 >> 2;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $22 >> 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = $$0$i56 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,630440,79)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + ($19<<2)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $36 = 0;
  } else {
   HEAP32[$34>>2] = 0;
   $36 = $34;
  }
  $35 = (($36) + 4|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $35;
  }
 }
 $39 = (($32) + ($$0$i57<<2)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = $44 >> 2;
 $$sum = (($19) - ($45))|0;
 $46 = (($32) + ($$sum<<2)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $35;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last1$i$i$i$i$i$i$i = 0, $__new_last1$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$011 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep2$i$i$i$i$i$i$i = 0, $scevgep2$i$i$i$i$i$i$i3 = 0, $scevgep23$i$i$i$i$i$i$i = 0, $scevgep23$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1813,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$011 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$011) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$011 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last1$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last1$i$i$i$i$i$i$i))|0;
    $scevgep2$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $scevgep23$i$i$i$i$i$i$i = $scevgep2$i$i$i$i$i$i$i;
    $69 = $scevgep23$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last1$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last1$i$i$i$i$i$i$i1))|0;
  $scevgep2$i$i$i$i$i$i$i3 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $scevgep23$i$i$i$i$i$i$i4 = $scevgep2$i$i$i$i$i$i$i3;
  $18 = $scevgep23$i$i$i$i$i$i$i4 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i5 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i5;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI11ColorRGBA3213stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorI11ColorRGBA3213stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
   $$pre$i$i$i$i$i$i = HEAP32[$34>>2]|0;
   $35 = $$pre$i$i$i$i$i$i;
  } else {
   $33 = HEAP32[$29>>2]|0;
   HEAP32[$34>>2] = $33;
   HEAP32[$1>>2] = $30;
   $35 = $33;
  }
  HEAP32[$34>>2] = $35;
  $36 = (($34) + 4|0);
  $37 = ($36|0)==($26|0);
  if ($37) {
   break;
  } else {
   $34 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI11ColorRGBA3213stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre42 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last1$i$i$i = 0, $__new_last1$i$i$i$i$i14 = 0, $__new_last1$i$i$i$i$i22 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i15 = 0, $scevgep$i$i$i$i$i23 = 0, $scevgep2$i$i$i = 0, $scevgep2$i$i$i$i$i16 = 0, $scevgep2$i$i$i$i$i24 = 0, $scevgep23$i$i$i = 0, $scevgep23$i$i$i$i$i17 = 0;
 var $scevgep23$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i18 = 0, $scevgep4$i$i$i$i$i26 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $88 = $$idx >> 2;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $107 = 0;$108 = 0;$110 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<2)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $107 = $93;$108 = $93;$110 = $96;
       break;
      } else {
       $101 = $7;$99 = $93;
      }
      while(1) {
       $98 = ($99|0)==(0|0);
       if ($98) {
        $103 = 0;
       } else {
        $100 = HEAP32[$101>>2]|0;
        HEAP32[$99>>2] = $100;
        $103 = $99;
       }
       $102 = (($103) + 4|0);
       $104 = (($101) + 4|0);
       $105 = ($104|0)==($87|0);
       if ($105) {
        $107 = $93;$108 = $102;$110 = $96;
        break L6;
       } else {
        $101 = $104;$99 = $102;
       }
      }
     }
    }
    $116 = ___cxa_find_matching_catch()|0;
    $117 = tempRet0;
    $$0 = $117;$$01 = $116;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $106 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $107;
  HEAP32[$5>>2] = $108;
  $109 = (($v) + 8|0);
  HEAP32[$109>>2] = $110;
  $111 = ($106|0)==(0|0);
  if ($111) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($106|0),($$byval_copy7|0));
  $112 = __THREW__; __THREW__ = 0;
  $113 = $112&1;
  if ($113) {
   $114 = ___cxa_find_matching_catch()|0;
   $115 = tempRet0;
   ___cxa_call_unexpected(($114|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 2;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI11ColorRGBA3213stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 2;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<2)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 2;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<2)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1814,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 2;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2879,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre42 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre42;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<2)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last1$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -4|0);
       $54 = (0 - ($__new_last1$i$i$i))|0;
       $scevgep2$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $scevgep23$i$i$i = $scevgep2$i$i$i;
       $55 = $scevgep23$i$i$i >>> 2;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<2)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last1$i$i$i$i$i14 = $57;
     $scevgep$i$i$i$i$i15 = (($59) + -4|0);
     $65 = (0 - ($__new_last1$i$i$i$i$i14))|0;
     $scevgep2$i$i$i$i$i16 = (($scevgep$i$i$i$i$i15) + ($65)|0);
     $scevgep23$i$i$i$i$i17 = $scevgep2$i$i$i$i$i16;
     $66 = $scevgep23$i$i$i$i$i17 >>> 2;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i18 = (($59) + ($67<<2)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i18;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last1$i$i$i$i$i22 = $74;
  $scevgep$i$i$i$i$i23 = (($76) + -4|0);
  $78 = (0 - ($__new_last1$i$i$i$i$i22))|0;
  $scevgep2$i$i$i$i$i24 = (($scevgep$i$i$i$i$i23) + ($78)|0);
  $scevgep23$i$i$i$i$i25 = $scevgep2$i$i$i$i$i24;
  $79 = $scevgep23$i$i$i$i$i25 >>> 2;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i26 = (($76) + ($80<<2)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i26;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI11ColorRGBA3213stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i39 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre5$i = 0, $$pre5$i21 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $8 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last1$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i8 = 0, $scevgep2$i$i = 0, $scevgep2$i$i$i$i = 0, $scevgep23$i$i = 0, $scevgep23$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep4$i$i9 = 0, $scevgep45$i$i = 0, $scevgep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $45 = ($9|0)==(0|0);
  do {
   if ($45) {
    $58 = $8;
   } else {
    $46 = (($this) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==($9|0);
    if (!($48)) {
     $scevgep$i$i$i$i = (($47) + -4|0);
     $49 = (0 - ($11))|0;
     $scevgep2$i$i$i$i = (($scevgep$i$i$i$i) + ($49)|0);
     $scevgep23$i$i$i$i = $scevgep2$i$i$i$i;
     $50 = $scevgep23$i$i$i$i >>> 2;
     $51 = $50 ^ -1;
     $scevgep4$i$i$i$i = (($47) + ($51<<2)|0);
     HEAP32[$46>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy1|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     ___cxa_call_unexpected(($54|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$46>>2] = 0;
     HEAP32[$this>>2] = 0;
     $58 = 0;
     break;
    }
   }
  } while(0);
  $56 = ($5|0)<(0);
  if ($56) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $57 = $58;
  $59 = $57 >> 2;
  $60 = ($59>>>0)<(1073741823);
  if ($60) {
   $61 = $57 >> 1;
   $62 = ($61>>>0)<($6>>>0);
   $63 = $62 ? $6 : $61;
   $64 = ($63|0)<(0);
   if ($64) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i39 = $63;
   }
  } else {
   $$0$i39 = 2147483647;
  }
  $65 = $$0$i39 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $66 = (__Z15malloc_internaljj10MemLabelIdiPKci($65,16,$$byval_copy1,0,630440,79)|0);
  $67 = (($this) + 4|0);
  HEAP32[$67>>2] = $66;
  HEAP32[$this>>2] = $66;
  $68 = (($66) + ($$0$i39<<2)|0);
  HEAP32[$7>>2] = $68;
  $69 = ($1|0)==($2|0);
  if ($69) {
   STACKTOP = sp;return;
  } else {
   $71 = $66;$73 = $1;
  }
  while(1) {
   $70 = ($71|0)==(0|0);
   if ($70) {
    $75 = 0;
   } else {
    $72 = HEAP32[$73>>2]|0;
    HEAP32[$71>>2] = $72;
    $$pre5$i = HEAP32[$67>>2]|0;
    $75 = $$pre5$i;
   }
   $74 = (($75) + 4|0);
   HEAP32[$67>>2] = $74;
   $76 = (($73) + 4|0);
   $77 = ($76|0)==($2|0);
   if ($77) {
    break;
   } else {
    $71 = $74;$73 = $76;
   }
  }
  STACKTOP = sp;return;
 } else {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + ($19<<2)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i$i = (($23) + -4|0);
   $24 = (0 - ($4))|0;
   $scevgep4$i$i = (($scevgep$i$i) + ($24)|0);
   $scevgep45$i$i = $scevgep4$i$i;
   $25 = $scevgep45$i$i >>> 2;
   $$01$i$i = $9;$27 = $1;
   while(1) {
    $26 = HEAP32[$27>>2]|0;
    HEAP32[$$01$i$i>>2] = $26;
    $28 = (($27) + 4|0);
    $29 = (($$01$i$i) + 4|0);
    $30 = ($28|0)==($23|0);
    if ($30) {
     break;
    } else {
     $$01$i$i = $29;$27 = $28;
    }
   }
   $31 = (($25) + 1)|0;
   $scevgep6$i$i = (($9) + ($31<<2)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  if (!($__growing$0$off0)) {
   $41 = ($16|0)==($$0$lcssa$i$i|0);
   if ($41) {
    STACKTOP = sp;return;
   }
   $__new_last1$i$i = $$0$lcssa$i$i;
   $scevgep$i$i8 = (($16) + -4|0);
   $42 = (0 - ($__new_last1$i$i))|0;
   $scevgep2$i$i = (($scevgep$i$i8) + ($42)|0);
   $scevgep23$i$i = $scevgep2$i$i;
   $43 = $scevgep23$i$i >>> 2;
   $44 = $43 ^ -1;
   $scevgep4$i$i9 = (($16) + ($44<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i9;
   STACKTOP = sp;return;
  }
  $32 = ($23|0)==($2|0);
  if ($32) {
   STACKTOP = sp;return;
  } else {
   $34 = $16;$36 = $23;
  }
  while(1) {
   $33 = ($34|0)==(0|0);
   if ($33) {
    $38 = 0;
   } else {
    $35 = HEAP32[$36>>2]|0;
    HEAP32[$34>>2] = $35;
    $$pre5$i21 = HEAP32[$15>>2]|0;
    $38 = $$pre5$i21;
   }
   $37 = (($38) + 4|0);
   HEAP32[$15>>2] = $37;
   $39 = (($36) + 4|0);
   $40 = ($39|0)==($2|0);
   if ($40) {
    break;
   } else {
    $34 = $37;$36 = $39;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI11ColorRGBA3213stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i5 = 0, $$0$i6 = 0, $$byval_copy1 = 0, $$pre = 0, $$pre4 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $scevgep$i = (($4) + ($__n<<2)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$this>>2]|0;
 $11 = $10;
 $12 = (($6) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + ($__n))|0;
 $15 = ($14|0)<(0);
 if ($15) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = (($5) - ($11))|0;
 $17 = $16 >> 2;
 $18 = ($17>>>0)<(1073741823);
 if ($18) {
  $19 = $16 >> 1;
  $20 = ($19>>>0)<($14>>>0);
  $21 = $20 ? $14 : $19;
  $22 = ($21|0)==(0);
  if ($22) {
   $$0$i6 = 0;$26 = 0;$28 = $4;$30 = $10;
  } else {
   $$0$i5 = $21;
   label = 7;
  }
 } else {
  $$0$i5 = 2147483647;
  label = 7;
 }
 if ((label|0) == 7) {
  $23 = $$0$i5 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,16,$$byval_copy1,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $$0$i6 = $$0$i5;$26 = $24;$28 = $$pre4;$30 = $$pre;
 }
 $25 = (($26) + ($$0$i6<<2)|0);
 $scevgep$i2 = (($26) + ($14<<2)|0);
 $27 = $28;
 $29 = $30;
 $31 = (($27) - ($29))|0;
 $32 = $31 >> 2;
 $$sum3 = (($13) - ($32))|0;
 $33 = (($26) + ($$sum3<<2)|0);
 _memcpy(($33|0),($30|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$3>>2] = $scevgep$i2;
 HEAP32[$1>>2] = $25;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1815,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 4;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),16)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<4)|0);
      $50 = Math_fround(HEAPF32[$49>>2]);
      $51 = ((($48) + ($index$01$i<<4)|0) + 4|0);
      $52 = Math_fround(HEAPF32[$51>>2]);
      $53 = ((($48) + ($index$01$i<<4)|0) + 8|0);
      $54 = Math_fround(HEAPF32[$53>>2]);
      $55 = ((($48) + ($index$01$i<<4)|0) + 12|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      HEAPF32[$45>>2] = $50;
      $57 = (($45) + 4|0);
      HEAPF32[$57>>2] = $52;
      $58 = (($45) + 8|0);
      HEAPF32[$58>>2] = $54;
      $59 = (($45) + 12|0);
      HEAPF32[$59>>2] = $56;
      $60 = (($index$01$i) + 1)|0;
      $61 = ($60|0)==($33|0);
      if ($61) {
       break L8;
      } else {
       $index$01$i = $60;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $62 = HEAP32[$24>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L15: do {
    if (!($65)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$012) + 1)|0;
      $69 = HEAP32[$24>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($68|0)==($71|0);
      if ($72) {
       break L15;
      } else {
       $index$012 = $68;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $73 = HEAP32[$buffer>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$1>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i$i$i = $73;
    $scevgep$i$i$i$i$i$i$i = (($75) + -16|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($77)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $78 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($75) + ($79<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($73|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN12NativeBufferI19Converter_PrimitiveI10ColorRGBAfEE15SetupForWritingER9ArrayInfo($this,$inputArray) {
 $this = $this|0;
 $inputArray = $inputArray|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $index$06 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inputArray) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($1>>>0);
 if ($9) {
  $10 = (($1) - ($8))|0;
  __ZNSt3__16vectorI10ColorRGBAf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$10);
 } else {
  $11 = ($8>>>0)>($1>>>0);
  if ($11) {
   $12 = (($4) + ($1<<4)|0);
   $13 = ($3|0)==($12|0);
   if (!($13)) {
    $__new_last2$i$i$i = $12;
    $scevgep$i$i$i = (($3) + -16|0);
    $14 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($14)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $15 = $uglygep3$i$i$i >>> 4;
    $16 = $15 ^ -1;
    $scevgep4$i$i$i = (($3) + ($16<<4)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i;
   }
  }
 }
 $17 = ($1|0)==(0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $index$06 = 0;
 while(1) {
  $18 = HEAP32[$inputArray>>2]|0;
  $19 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($18,$index$06,16)|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($19) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($19) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($19) + 12|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = HEAP32[$this>>2]|0;
  $28 = (($27) + ($index$06<<4)|0);
  HEAPF32[$28>>2] = $20;
  $29 = ((($27) + ($index$06<<4)|0) + 4|0);
  HEAPF32[$29>>2] = $22;
  $30 = ((($27) + ($index$06<<4)|0) + 8|0);
  HEAPF32[$30>>2] = $24;
  $31 = ((($27) + ($index$06<<4)|0) + 12|0);
  HEAPF32[$31>>2] = $26;
  $32 = (($index$06) + 1)|0;
  $33 = ($32|0)==($1|0);
  if ($33) {
   break;
  } else {
   $index$06 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI10ColorRGBAf13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI10ColorRGBAf13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 16|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI10ColorRGBAf13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre46 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0;
 var $uglygep$i$i$i$i$i27 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 4;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<4)|0);
  $$idx = $sz << 4;
  $88 = $$idx >> 4;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $106 = 0;$107 = 0;$109 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<4)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $106 = $93;$107 = $93;$109 = $96;
       break;
      } else {
       $100 = $7;$99 = $93;
      }
      while(1) {
       $98 = ($99|0)==(0|0);
       if ($98) {
        $102 = 0;
       } else {
        ;HEAP32[$99+0>>2]=HEAP32[$100+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$100+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$100+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$100+12>>2]|0;
        $102 = $99;
       }
       $101 = (($102) + 16|0);
       $103 = (($100) + 16|0);
       $104 = ($103|0)==($87|0);
       if ($104) {
        $106 = $93;$107 = $101;$109 = $96;
        break L6;
       } else {
        $100 = $103;$99 = $101;
       }
      }
     }
    }
    $115 = ___cxa_find_matching_catch()|0;
    $116 = tempRet0;
    $$0 = $116;$$01 = $115;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $105 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $106;
  HEAP32[$5>>2] = $107;
  $108 = (($v) + 8|0);
  HEAP32[$108>>2] = $109;
  $110 = ($105|0)==(0|0);
  if ($110) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($105|0),($$byval_copy7|0));
  $111 = __THREW__; __THREW__ = 0;
  $112 = $111&1;
  if ($112) {
   $113 = ___cxa_find_matching_catch()|0;
   $114 = tempRet0;
   ___cxa_call_unexpected(($113|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 4;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI10ColorRGBAf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 4;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<4)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 4;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<4)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1816,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 4;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2880,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<4)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -16|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 4;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<4)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -16|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = $uglygep3$i$i$i$i$i19 >>> 4;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + ($67<<4)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -16|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = $uglygep3$i$i$i$i$i28 >>> 4;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + ($80<<4)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI10ColorRGBAf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre5$i = 0, $$pre5$i22 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i8 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $uglygep$i$i = 0;
 var $uglygep$i$i$i$i = 0, $uglygep$i$i9 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 4;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $53 = ($9|0)==(0|0);
  do {
   if ($53) {
    $66 = $8;
   } else {
    $54 = (($this) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==($9|0);
    if (!($56)) {
     $scevgep$i$i$i$i = (($55) + -16|0);
     $57 = (0 - ($11))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($57)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $58 = $uglygep3$i$i$i$i >>> 4;
     $59 = $58 ^ -1;
     $scevgep4$i$i$i$i = (($55) + ($59<<4)|0);
     HEAP32[$54>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy1|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     $62 = ___cxa_find_matching_catch()|0;
     $63 = tempRet0;
     ___cxa_call_unexpected(($62|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$54>>2] = 0;
     HEAP32[$this>>2] = 0;
     $66 = 0;
     break;
    }
   }
  } while(0);
  $64 = ($5|0)<(0);
  if ($64) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $65 = $66;
  $67 = $65 >> 4;
  $68 = ($67>>>0)<(1073741823);
  if ($68) {
   $69 = $65 >> 3;
   $70 = ($69>>>0)<($6>>>0);
   $71 = $70 ? $6 : $69;
   $72 = ($71|0)<(0);
   if ($72) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $71;
   }
  } else {
   $$0$i40 = 2147483647;
  }
  $73 = $$0$i40 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $74 = (__Z15malloc_internaljj10MemLabelIdiPKci($73,16,$$byval_copy1,0,630440,79)|0);
  $75 = (($this) + 4|0);
  HEAP32[$75>>2] = $74;
  HEAP32[$this>>2] = $74;
  $76 = (($74) + ($$0$i40<<4)|0);
  HEAP32[$7>>2] = $76;
  $77 = ($1|0)==($2|0);
  if ($77) {
   STACKTOP = sp;return;
  } else {
   $79 = $74;$80 = $1;
  }
  while(1) {
   $78 = ($79|0)==(0|0);
   if ($78) {
    $82 = 0;
   } else {
    ;HEAP32[$79+0>>2]=HEAP32[$80+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$80+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$80+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$80+12>>2]|0;
    $$pre5$i = HEAP32[$75>>2]|0;
    $82 = $$pre5$i;
   }
   $81 = (($82) + 16|0);
   HEAP32[$75>>2] = $81;
   $83 = (($80) + 16|0);
   $84 = ($83|0)==($2|0);
   if ($84) {
    break;
   } else {
    $79 = $81;$80 = $83;
   }
  }
  STACKTOP = sp;return;
 } else {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 4;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + ($19<<4)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i$i = (($23) + -16|0);
   $24 = (0 - ($4))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($24)|0);
   $uglygep5$i$i = $uglygep$i$i;
   $25 = $uglygep5$i$i >>> 4;
   $$01$i$i = $9;$27 = $1;
   while(1) {
    $26 = Math_fround(HEAPF32[$27>>2]);
    $28 = (($27) + 4|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = (($27) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = (($27) + 12|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    HEAPF32[$$01$i$i>>2] = $26;
    $34 = (($$01$i$i) + 4|0);
    HEAPF32[$34>>2] = $29;
    $35 = (($$01$i$i) + 8|0);
    HEAPF32[$35>>2] = $31;
    $36 = (($$01$i$i) + 12|0);
    HEAPF32[$36>>2] = $33;
    $37 = (($27) + 16|0);
    $38 = (($$01$i$i) + 16|0);
    $39 = ($37|0)==($23|0);
    if ($39) {
     break;
    } else {
     $$01$i$i = $38;$27 = $37;
    }
   }
   $40 = (($25) + 1)|0;
   $scevgep6$i$i = (($9) + ($40<<4)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  if (!($__growing$0$off0)) {
   $49 = ($16|0)==($$0$lcssa$i$i|0);
   if ($49) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $$0$lcssa$i$i;
   $scevgep$i$i8 = (($16) + -16|0);
   $50 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i9 = (($scevgep$i$i8) + ($50)|0);
   $uglygep3$i$i = $uglygep$i$i9;
   $51 = $uglygep3$i$i >>> 4;
   $52 = $51 ^ -1;
   $scevgep4$i$i = (($16) + ($52<<4)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $41 = ($23|0)==($2|0);
  if ($41) {
   STACKTOP = sp;return;
  } else {
   $43 = $16;$44 = $23;
  }
  while(1) {
   $42 = ($43|0)==(0|0);
   if ($42) {
    $46 = 0;
   } else {
    ;HEAP32[$43+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$44+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$44+12>>2]|0;
    $$pre5$i22 = HEAP32[$15>>2]|0;
    $46 = $$pre5$i22;
   }
   $45 = (($46) + 16|0);
   HEAP32[$15>>2] = $45;
   $47 = (($44) + 16|0);
   $48 = ($47|0)==($2|0);
   if ($48) {
    break;
   } else {
    $43 = $45;$44 = $47;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI10ColorRGBAf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i5 = 0, $$0$i6 = 0, $$byval_copy1 = 0, $$pre = 0, $$pre4 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $scevgep$i = (($4) + ($__n<<4)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$this>>2]|0;
 $11 = $10;
 $12 = (($6) - ($11))|0;
 $13 = $12 >> 4;
 $14 = (($13) + ($__n))|0;
 $15 = ($14|0)<(0);
 if ($15) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = (($5) - ($11))|0;
 $17 = $16 >> 4;
 $18 = ($17>>>0)<(1073741823);
 if ($18) {
  $19 = $16 >> 3;
  $20 = ($19>>>0)<($14>>>0);
  $21 = $20 ? $14 : $19;
  $22 = ($21|0)==(0);
  if ($22) {
   $$0$i6 = 0;$26 = 0;$28 = $4;$30 = $10;
  } else {
   $$0$i5 = $21;
   label = 7;
  }
 } else {
  $$0$i5 = 2147483647;
  label = 7;
 }
 if ((label|0) == 7) {
  $23 = $$0$i5 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,16,$$byval_copy1,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $$0$i6 = $$0$i5;$26 = $24;$28 = $$pre4;$30 = $$pre;
 }
 $25 = (($26) + ($$0$i6<<4)|0);
 $scevgep$i2 = (($26) + ($14<<4)|0);
 $27 = $28;
 $29 = $30;
 $31 = (($27) - ($29))|0;
 $32 = $31 >> 4;
 $$sum3 = (($13) - ($32))|0;
 $33 = (($26) + ($$sum3<<4)|0);
 _memcpy(($33|0),($30|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$3>>2] = $scevgep$i2;
 HEAP32[$1>>2] = $25;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1817,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = (($32|0) / 24)&-1;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($28|0)==($29|0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),24)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + (($index$01$i*24)|0)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$49+12>>2]|0;HEAP32[$45+16>>2]=HEAP32[$49+16>>2]|0;HEAP32[$45+20>>2]=HEAP32[$49+20>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -24|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 24)&-1;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + (($69*24)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -24|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 24)&-1;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + (($19*24)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4AABB13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0;
 var $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4AABB13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$29,0,0);
   $30 = (($29) + 12|0);
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$30,0,0);
   $31 = (($29) + 24|0);
   $32 = ($31|0)==($26|0);
   if ($32) {
    break;
   } else {
    $29 = $31;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*24)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI4AABB13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i27 = 0;
 var $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 24)&-1;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + (($sz*24)|0)|0);
  $$idx = ($sz*24)|0;
  $88 = (($$idx|0) / 24)&-1;
  $89 = ($sz|0)==(0);
  do {
   if ($89) {
    $104 = 0;$105 = 0;$107 = 0;$109 = $7;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $97 = $93;$98 = $7;
      while(1) {
       $96 = ($97|0)==(0|0);
       if ($96) {
        $100 = 0;
       } else {
        ;HEAP32[$97+0>>2]=HEAP32[$98+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$98+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$98+8>>2]|0;HEAP32[$97+12>>2]=HEAP32[$98+12>>2]|0;HEAP32[$97+16>>2]=HEAP32[$98+16>>2]|0;HEAP32[$97+20>>2]=HEAP32[$98+20>>2]|0;
        $100 = $97;
       }
       $99 = (($100) + 24|0);
       $101 = (($98) + 24|0);
       $102 = ($101|0)==($87|0);
       if ($102) {
        break;
       } else {
        $97 = $99;$98 = $101;
       }
      }
      $103 = (($93) + (($88*24)|0)|0);
      $$pre = HEAP32[$v>>2]|0;
      $104 = $93;$105 = $99;$107 = $103;$109 = $$pre;
      break;
     }
    }
    $114 = ___cxa_find_matching_catch()|0;
    $115 = tempRet0;
    $$0 = $115;$$01 = $114;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $104;
  HEAP32[$5>>2] = $105;
  $106 = (($v) + 8|0);
  HEAP32[$106>>2] = $107;
  $108 = ($109|0)==(0|0);
  if ($108) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($109|0),($$byval_copy7|0));
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if ($111) {
   $112 = ___cxa_find_matching_catch()|0;
   $113 = tempRet0;
   ___cxa_call_unexpected(($112|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 24)&-1;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI4AABB13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = ($sz*24)|0;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + (($sz*24)|0)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = (($28|0) / -24)&-1;
   $30 = (($23) + (($29*24)|0)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1818,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = (($45|0) / 24)&-1;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2881,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre45 = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre45;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + (($sz*24)|0)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -24|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = (($uglygep3$i$i$i>>>0) / 24)&-1;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + (($56*24)|0)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -24|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = (($uglygep3$i$i$i$i$i19>>>0) / 24)&-1;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + (($67*24)|0)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -24|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = (($uglygep3$i$i$i$i$i28>>>0) / 24)&-1;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + (($80*24)|0)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI4AABB13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 24)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 24)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = (($18|0) / 24)&-1;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = (($31|0) / 24)&-1;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + (($32*24)|0)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -24|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = (($uglygep3$i$i>>>0) / 24)&-1;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + (($38*24)|0)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + (($19*24)|0)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$25+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$25+20>>2]|0;
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 24|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 24|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -24|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = (($uglygep3$i$i$i$i>>>0) / 24)&-1;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + (($45*24)|0)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = (($51|0) / 24)&-1;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $53 << 1;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = ($$0$i37*24)|0;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,630440,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + (($$0$i37*24)|0)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   ;HEAP32[$65+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$66+12>>2]|0;HEAP32[$65+16>>2]=HEAP32[$66+16>>2]|0;HEAP32[$65+20>>2]=HEAP32[$66+20>>2]|0;
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 24|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 24|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI4AABB13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 24)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 24|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = (($18|0) / 24)&-1;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = (($22|0) / 24)&-1;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $23 << 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = ($$0$i56*24)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,630440,79)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + (($19*24)|0)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $36 = 0;
  } else {
   ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;
   $36 = $34;
  }
  $35 = (($36) + 24|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $35;
  }
 }
 $39 = (($32) + (($$0$i57*24)|0)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = (($44|0) / -24)&-1;
 $$sum = (($45) + ($19))|0;
 $46 = (($32) + (($$sum*24)|0)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $35;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1819,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 6;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),64)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<6)|0);
      dest=$45+0|0; src=$49+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -64|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = $uglygep3$i$i$i$i$i$i$i >>> 6;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + ($69<<6)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -64|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 6;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<6)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI10Matrix4x4f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI10Matrix4x4f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN10Matrix4x4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 64|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 6;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI10Matrix4x4f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre46 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0;
 var $uglygep$i$i$i$i$i27 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 6;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<6)|0);
  $$idx = $sz << 6;
  $88 = $$idx >> 6;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $106 = 0;$107 = 0;$109 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<6)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $106 = $93;$107 = $93;$109 = $96;
       break;
      } else {
       $100 = $7;$99 = $93;
      }
      while(1) {
       $98 = ($99|0)==(0|0);
       if ($98) {
        $102 = 0;
       } else {
        dest=$99+0|0; src=$100+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $102 = $99;
       }
       $101 = (($102) + 64|0);
       $103 = (($100) + 64|0);
       $104 = ($103|0)==($87|0);
       if ($104) {
        $106 = $93;$107 = $101;$109 = $96;
        break L6;
       } else {
        $100 = $103;$99 = $101;
       }
      }
     }
    }
    $115 = ___cxa_find_matching_catch()|0;
    $116 = tempRet0;
    $$0 = $116;$$01 = $115;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $105 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $106;
  HEAP32[$5>>2] = $107;
  $108 = (($v) + 8|0);
  HEAP32[$108>>2] = $109;
  $110 = ($105|0)==(0|0);
  if ($110) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($105|0),($$byval_copy7|0));
  $111 = __THREW__; __THREW__ = 0;
  $112 = $111&1;
  if ($112) {
   $113 = ___cxa_find_matching_catch()|0;
   $114 = tempRet0;
   ___cxa_call_unexpected(($113|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 6;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI10Matrix4x4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 6;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<6)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 6;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<6)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1820,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 6;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2882,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<6)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -64|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 6;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<6)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -64|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = $uglygep3$i$i$i$i$i19 >>> 6;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + ($67<<6)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -64|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = $uglygep3$i$i$i$i$i28 >>> 6;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + ($80<<6)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI10Matrix4x4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 6;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 6;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 6;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = $31 >> 6;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + ($32<<6)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -64|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = $uglygep3$i$i >>> 6;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + ($38<<6)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<6)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    dest=$24+0|0; src=$25+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 64|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 64|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -64|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = $uglygep3$i$i$i$i >>> 6;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + ($45<<6)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = $51 >> 6;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $51 >> 5;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = $$0$i37 << 6;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,630440,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + ($$0$i37<<6)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   dest=$65+0|0; src=$66+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 64|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 64|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI10Matrix4x4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i5 = 0, $$0$i6 = 0, $$byval_copy1 = 0, $$pre = 0, $$pre4 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 6;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $scevgep$i = (($4) + ($__n<<6)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$this>>2]|0;
 $11 = $10;
 $12 = (($6) - ($11))|0;
 $13 = $12 >> 6;
 $14 = (($13) + ($__n))|0;
 $15 = ($14|0)<(0);
 if ($15) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = (($5) - ($11))|0;
 $17 = $16 >> 6;
 $18 = ($17>>>0)<(1073741823);
 if ($18) {
  $19 = $16 >> 5;
  $20 = ($19>>>0)<($14>>>0);
  $21 = $20 ? $14 : $19;
  $22 = ($21|0)==(0);
  if ($22) {
   $$0$i6 = 0;$26 = 0;$28 = $4;$30 = $10;
  } else {
   $$0$i5 = $21;
   label = 7;
  }
 } else {
  $$0$i5 = 2147483647;
  label = 7;
 }
 if ((label|0) == 7) {
  $23 = $$0$i5 << 6;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,16,$$byval_copy1,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $$0$i6 = $$0$i5;$26 = $24;$28 = $$pre4;$30 = $$pre;
 }
 $25 = (($26) + ($$0$i6<<6)|0);
 $scevgep$i2 = (($26) + ($14<<6)|0);
 $27 = $28;
 $29 = $30;
 $31 = (($27) - ($29))|0;
 $32 = $31 >> 6;
 $$sum3 = (($13) - ($32))|0;
 $33 = (($26) + ($$sum3<<6)|0);
 _memcpy(($33|0),($30|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$3>>2] = $scevgep$i2;
 HEAP32[$1>>2] = $25;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1821,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 4;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),16)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<4)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$49+12>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -16|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + ($69<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI11Quaternionf13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI11Quaternionf13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN11Quaternionf8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 16|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI11Quaternionf13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre46 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0;
 var $uglygep$i$i$i$i$i27 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 4;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<4)|0);
  $$idx = $sz << 4;
  $88 = $$idx >> 4;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $106 = 0;$107 = 0;$109 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<4)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $106 = $93;$107 = $93;$109 = $96;
       break;
      } else {
       $100 = $7;$99 = $93;
      }
      while(1) {
       $98 = ($99|0)==(0|0);
       if ($98) {
        $102 = 0;
       } else {
        ;HEAP32[$99+0>>2]=HEAP32[$100+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$100+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$100+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$100+12>>2]|0;
        $102 = $99;
       }
       $101 = (($102) + 16|0);
       $103 = (($100) + 16|0);
       $104 = ($103|0)==($87|0);
       if ($104) {
        $106 = $93;$107 = $101;$109 = $96;
        break L6;
       } else {
        $100 = $103;$99 = $101;
       }
      }
     }
    }
    $115 = ___cxa_find_matching_catch()|0;
    $116 = tempRet0;
    $$0 = $116;$$01 = $115;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $105 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $106;
  HEAP32[$5>>2] = $107;
  $108 = (($v) + 8|0);
  HEAP32[$108>>2] = $109;
  $110 = ($105|0)==(0|0);
  if ($110) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($105|0),($$byval_copy7|0));
  $111 = __THREW__; __THREW__ = 0;
  $112 = $111&1;
  if ($112) {
   $113 = ___cxa_find_matching_catch()|0;
   $114 = tempRet0;
   ___cxa_call_unexpected(($113|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 4;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI11Quaternionf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 4;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<4)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 4;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<4)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1822,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 4;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2883,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<4)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -16|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 4;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<4)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -16|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = $uglygep3$i$i$i$i$i19 >>> 4;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + ($67<<4)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -16|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = $uglygep3$i$i$i$i$i28 >>> 4;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + ($80<<4)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI11Quaternionf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 4;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 4;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = $31 >> 4;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + ($32<<4)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -16|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = $uglygep3$i$i >>> 4;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + ($38<<4)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<4)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 16|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 16|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -16|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = $uglygep3$i$i$i$i >>> 4;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + ($45<<4)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = $51 >> 4;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $51 >> 3;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = $$0$i37 << 4;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,630440,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + ($$0$i37<<4)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   ;HEAP32[$65+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$66+12>>2]|0;
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 16|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 16|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI11Quaternionf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i5 = 0, $$0$i6 = 0, $$byval_copy1 = 0, $$pre = 0, $$pre4 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $scevgep$i = (($4) + ($__n<<4)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$this>>2]|0;
 $11 = $10;
 $12 = (($6) - ($11))|0;
 $13 = $12 >> 4;
 $14 = (($13) + ($__n))|0;
 $15 = ($14|0)<(0);
 if ($15) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = (($5) - ($11))|0;
 $17 = $16 >> 4;
 $18 = ($17>>>0)<(1073741823);
 if ($18) {
  $19 = $16 >> 3;
  $20 = ($19>>>0)<($14>>>0);
  $21 = $20 ? $14 : $19;
  $22 = ($21|0)==(0);
  if ($22) {
   $$0$i6 = 0;$26 = 0;$28 = $4;$30 = $10;
  } else {
   $$0$i5 = $21;
   label = 7;
  }
 } else {
  $$0$i5 = 2147483647;
  label = 7;
 }
 if ((label|0) == 7) {
  $23 = $$0$i5 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,16,$$byval_copy1,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $$0$i6 = $$0$i5;$26 = $24;$28 = $$pre4;$30 = $$pre;
 }
 $25 = (($26) + ($$0$i6<<4)|0);
 $scevgep$i2 = (($26) + ($14<<4)|0);
 $27 = $28;
 $29 = $30;
 $31 = (($27) - ($29))|0;
 $32 = $31 >> 4;
 $$sum3 = (($13) - ($32))|0;
 $33 = (($26) + ($$sum3<<4)|0);
 _memcpy(($33|0),($30|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$3>>2] = $scevgep$i2;
 HEAP32[$1>>2] = $25;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1823,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 4;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),16)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<4)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$49+12>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -16|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + ($69<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI5RectTIfE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI5RectTIfE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN5RectTIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 16|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI5RectTIfE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre46 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0;
 var $uglygep$i$i$i$i$i27 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 4;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<4)|0);
  $$idx = $sz << 4;
  $88 = $$idx >> 4;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $106 = 0;$107 = 0;$109 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<4)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $106 = $93;$107 = $93;$109 = $96;
       break;
      } else {
       $100 = $7;$99 = $93;
      }
      while(1) {
       $98 = ($99|0)==(0|0);
       if ($98) {
        $102 = 0;
       } else {
        ;HEAP32[$99+0>>2]=HEAP32[$100+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$100+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$100+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$100+12>>2]|0;
        $102 = $99;
       }
       $101 = (($102) + 16|0);
       $103 = (($100) + 16|0);
       $104 = ($103|0)==($87|0);
       if ($104) {
        $106 = $93;$107 = $101;$109 = $96;
        break L6;
       } else {
        $100 = $103;$99 = $101;
       }
      }
     }
    }
    $115 = ___cxa_find_matching_catch()|0;
    $116 = tempRet0;
    $$0 = $116;$$01 = $115;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $105 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $106;
  HEAP32[$5>>2] = $107;
  $108 = (($v) + 8|0);
  HEAP32[$108>>2] = $109;
  $110 = ($105|0)==(0|0);
  if ($110) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($105|0),($$byval_copy7|0));
  $111 = __THREW__; __THREW__ = 0;
  $112 = $111&1;
  if ($112) {
   $113 = ___cxa_find_matching_catch()|0;
   $114 = tempRet0;
   ___cxa_call_unexpected(($113|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 4;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI5RectTIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 4;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<4)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 4;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<4)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1824,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 4;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2884,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<4)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -16|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 4;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<4)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -16|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = $uglygep3$i$i$i$i$i19 >>> 4;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + ($67<<4)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -16|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = $uglygep3$i$i$i$i$i28 >>> 4;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + ($80<<4)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI5RectTIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 4;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 4;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = $31 >> 4;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + ($32<<4)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -16|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = $uglygep3$i$i >>> 4;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + ($38<<4)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<4)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 16|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 16|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -16|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = $uglygep3$i$i$i$i >>> 4;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + ($45<<4)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = $51 >> 4;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $51 >> 3;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = $$0$i37 << 4;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,630440,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + ($$0$i37<<4)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   ;HEAP32[$65+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$66+12>>2]|0;
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 16|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 16|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI5RectTIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 16|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = $18 >> 4;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = $22 >> 4;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $22 >> 3;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = $$0$i56 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,630440,79)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + ($19<<4)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $36 = 0;
  } else {
   ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
   $36 = $34;
  }
  $35 = (($36) + 16|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $35;
  }
 }
 $39 = (($32) + ($$0$i57<<4)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = $44 >> 4;
 $$sum = (($19) - ($45))|0;
 $46 = (($32) + ($$sum<<4)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $35;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1825,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 4;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),16)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<4)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$49+12>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -16|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + ($69<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8Vector4f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI8Vector4f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 16|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI8Vector4f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre46 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0;
 var $uglygep$i$i$i$i$i27 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 4;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<4)|0);
  $$idx = $sz << 4;
  $88 = $$idx >> 4;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $106 = 0;$107 = 0;$109 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<4)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $106 = $93;$107 = $93;$109 = $96;
       break;
      } else {
       $100 = $7;$99 = $93;
      }
      while(1) {
       $98 = ($99|0)==(0|0);
       if ($98) {
        $102 = 0;
       } else {
        ;HEAP32[$99+0>>2]=HEAP32[$100+0>>2]|0;HEAP32[$99+4>>2]=HEAP32[$100+4>>2]|0;HEAP32[$99+8>>2]=HEAP32[$100+8>>2]|0;HEAP32[$99+12>>2]=HEAP32[$100+12>>2]|0;
        $102 = $99;
       }
       $101 = (($102) + 16|0);
       $103 = (($100) + 16|0);
       $104 = ($103|0)==($87|0);
       if ($104) {
        $106 = $93;$107 = $101;$109 = $96;
        break L6;
       } else {
        $100 = $103;$99 = $101;
       }
      }
     }
    }
    $115 = ___cxa_find_matching_catch()|0;
    $116 = tempRet0;
    $$0 = $116;$$01 = $115;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $105 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $106;
  HEAP32[$5>>2] = $107;
  $108 = (($v) + 8|0);
  HEAP32[$108>>2] = $109;
  $110 = ($105|0)==(0|0);
  if ($110) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($105|0),($$byval_copy7|0));
  $111 = __THREW__; __THREW__ = 0;
  $112 = $111&1;
  if ($112) {
   $113 = ___cxa_find_matching_catch()|0;
   $114 = tempRet0;
   ___cxa_call_unexpected(($113|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 4;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI8Vector4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 4;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<4)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 4;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<4)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1826,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 4;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2885,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<4)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -16|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 4;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<4)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -16|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = $uglygep3$i$i$i$i$i19 >>> 4;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + ($67<<4)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -16|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = $uglygep3$i$i$i$i$i28 >>> 4;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + ($80<<4)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8Vector4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 4;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 4;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 4;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = $31 >> 4;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + ($32<<4)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -16|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = $uglygep3$i$i >>> 4;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + ($38<<4)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<4)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 16|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 16|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -16|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = $uglygep3$i$i$i$i >>> 4;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + ($45<<4)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = $51 >> 4;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $51 >> 3;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = $$0$i37 << 4;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,630440,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + ($$0$i37<<4)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   ;HEAP32[$65+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$66+12>>2]|0;
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 16|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 16|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8Vector4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i5 = 0, $$0$i6 = 0, $$byval_copy1 = 0, $$pre = 0, $$pre4 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $scevgep$i = (($4) + ($__n<<4)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$this>>2]|0;
 $11 = $10;
 $12 = (($6) - ($11))|0;
 $13 = $12 >> 4;
 $14 = (($13) + ($__n))|0;
 $15 = ($14|0)<(0);
 if ($15) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = (($5) - ($11))|0;
 $17 = $16 >> 4;
 $18 = ($17>>>0)<(1073741823);
 if ($18) {
  $19 = $16 >> 3;
  $20 = ($19>>>0)<($14>>>0);
  $21 = $20 ? $14 : $19;
  $22 = ($21|0)==(0);
  if ($22) {
   $$0$i6 = 0;$26 = 0;$28 = $4;$30 = $10;
  } else {
   $$0$i5 = $21;
   label = 7;
  }
 } else {
  $$0$i5 = 2147483647;
  label = 7;
 }
 if ((label|0) == 7) {
  $23 = $$0$i5 << 4;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,16,$$byval_copy1,0,630440,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $$0$i6 = $$0$i5;$26 = $24;$28 = $$pre4;$30 = $$pre;
 }
 $25 = (($26) + ($$0$i6<<4)|0);
 $scevgep$i2 = (($26) + ($14<<4)|0);
 $27 = $28;
 $29 = $30;
 $31 = (($27) - ($29))|0;
 $32 = $31 >> 4;
 $$sum3 = (($13) - ($32))|0;
 $33 = (($26) + ($$sum3<<4)|0);
 _memcpy(($33|0),($30|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$3>>2] = $scevgep$i2;
 HEAP32[$1>>2] = $25;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1827,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),8)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<3)|0);
      $50 = $49;
      $51 = $50;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($50) + 4)|0;
      $54 = $53;
      $55 = HEAP32[$54>>2]|0;
      $56 = $45;
      $57 = $56;
      HEAP32[$57>>2] = $52;
      $58 = (($56) + 4)|0;
      $59 = $58;
      HEAP32[$59>>2] = $55;
      $60 = (($index$01$i) + 1)|0;
      $61 = ($60|0)==($33|0);
      if ($61) {
       break L8;
      } else {
       $index$01$i = $60;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $62 = HEAP32[$24>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L15: do {
    if (!($65)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$012) + 1)|0;
      $69 = HEAP32[$24>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($68|0)==($71|0);
      if ($72) {
       break L15;
      } else {
       $index$012 = $68;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $73 = HEAP32[$buffer>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$1>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i$i$i = $73;
    $scevgep$i$i$i$i$i$i$i = (($75) + -8|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($77)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $78 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($75) + ($79<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($73|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -8|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8Vector2f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i3$i$i$i = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$i4$i$i$iZ2D = 0, $$pre6$i$i$i = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorI8Vector2f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
   $$pre$i$i$i3$i$i$i = HEAP32[$34>>2]|0;
   $$pre$i$i$i = HEAP32[$1>>2]|0;
   $$pre6$i$i$i = HEAP32[$7>>2]|0;
   $$pre$phi$i$i$i4$i$i$iZ2D = $34;$36 = $$pre$i$i$i3$i$i$i;$40 = $$pre$i$i$i;$42 = $$pre6$i$i$i;
  } else {
   $33 = Math_fround(HEAPF32[$29>>2]);
   HEAPF32[$34>>2] = $33;
   HEAP32[$1>>2] = $30;
   $35 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$i4$i$i$iZ2D = $34;$36 = $35;$40 = $30;$42 = $31;
  }
  $37 = (_llvm_bswap_i32(($36|0))|0);
  HEAP32[$$pre$phi$i$i$i4$i$i$iZ2D>>2] = $37;
  $38 = (($34) + 4|0);
  $39 = (($40) + 4|0);
  $41 = ($39>>>0)>($42>>>0);
  if ($41) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
   $$pre$i$i$i$i$i$i = HEAP32[$38>>2]|0;
   $$pre$phi$i$i$i$i$i$iZ2D = $38;$45 = $$pre$i$i$i$i$i$i;
  } else {
   $43 = Math_fround(HEAPF32[$40>>2]);
   HEAPF32[$38>>2] = $43;
   HEAP32[$1>>2] = $39;
   $44 = (HEAPF32[tempDoublePtr>>2]=$43,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$i$i$i$iZ2D = $38;$45 = $44;
  }
  $46 = (_llvm_bswap_i32(($45|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $46;
  $47 = (($34) + 8|0);
  $48 = ($47|0)==($26|0);
  if ($48) {
   break;
  } else {
   $34 = $47;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI8Vector2f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre46 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0;
 var $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i27 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<3)|0);
  $$idx = $sz << 3;
  $88 = $$idx >> 3;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $116 = 0;$117 = 0;$119 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<3)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $116 = $93;$117 = $93;$119 = $96;
       break;
      } else {
       $101 = $7;$99 = $93;
      }
      while(1) {
       $98 = ($99|0)==(0|0);
       if ($98) {
        $112 = 0;
       } else {
        $100 = $101;
        $102 = $100;
        $103 = HEAP32[$102>>2]|0;
        $104 = (($100) + 4)|0;
        $105 = $104;
        $106 = HEAP32[$105>>2]|0;
        $107 = $99;
        $108 = $107;
        HEAP32[$108>>2] = $103;
        $109 = (($107) + 4)|0;
        $110 = $109;
        HEAP32[$110>>2] = $106;
        $112 = $99;
       }
       $111 = (($112) + 8|0);
       $113 = (($101) + 8|0);
       $114 = ($113|0)==($87|0);
       if ($114) {
        $116 = $93;$117 = $111;$119 = $96;
        break L6;
       } else {
        $101 = $113;$99 = $111;
       }
      }
     }
    }
    $125 = ___cxa_find_matching_catch()|0;
    $126 = tempRet0;
    $$0 = $126;$$01 = $125;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $115 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $116;
  HEAP32[$5>>2] = $117;
  $118 = (($v) + 8|0);
  HEAP32[$118>>2] = $119;
  $120 = ($115|0)==(0|0);
  if ($120) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($115|0),($$byval_copy7|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   $123 = ___cxa_find_matching_catch()|0;
   $124 = tempRet0;
   ___cxa_call_unexpected(($123|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 3;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI8Vector2f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 3;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<3)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 3;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<3)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1828,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 3;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2886,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<3)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -8|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 3;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<3)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -8|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = $uglygep3$i$i$i$i$i19 >>> 3;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + ($67<<3)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -8|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = $uglygep3$i$i$i$i$i28 >>> 3;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + ($80<<3)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8Vector2f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 3;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 3;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $40 = $2;
   $41 = (($40) - ($4))|0;
   $42 = $41 >> 3;
   _memmove(($9|0),($1|0),($41|0))|0;
   $43 = (($9) + ($42<<3)|0);
   $44 = HEAP32[$15>>2]|0;
   $45 = ($44|0)==($43|0);
   if ($45) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $43;
   $scevgep$i$i = (($44) + -8|0);
   $46 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($46)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $47 = $uglygep3$i$i >>> 3;
   $48 = $47 ^ -1;
   $scevgep4$i$i = (($44) + ($48<<3)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<3)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$26 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $37 = 0;
   } else {
    $25 = $26;
    $27 = $25;
    $28 = HEAP32[$27>>2]|0;
    $29 = (($25) + 4)|0;
    $30 = $29;
    $31 = HEAP32[$30>>2]|0;
    $32 = $24;
    $33 = $32;
    HEAP32[$33>>2] = $28;
    $34 = (($32) + 4)|0;
    $35 = $34;
    HEAP32[$35>>2] = $31;
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $37 = $$pre5$i19;
   }
   $36 = (($37) + 8|0);
   HEAP32[$15>>2] = $36;
   $38 = (($26) + 8|0);
   $39 = ($38|0)==($2|0);
   if ($39) {
    break;
   } else {
    $24 = $36;$26 = $38;
   }
  }
  STACKTOP = sp;return;
 }
 $49 = ($9|0)==(0|0);
 do {
  if ($49) {
   $62 = $8;
  } else {
   $50 = (($this) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==($9|0);
   if (!($52)) {
    $scevgep$i$i$i$i = (($51) + -8|0);
    $53 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($53)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $54 = $uglygep3$i$i$i$i >>> 3;
    $55 = $54 ^ -1;
    $scevgep4$i$i$i$i = (($51) + ($55<<3)|0);
    HEAP32[$50>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    ___cxa_call_unexpected(($58|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$50>>2] = 0;
    HEAP32[$this>>2] = 0;
    $62 = 0;
    break;
   }
  }
 } while(0);
 $60 = ($5|0)<(0);
 if ($60) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $61 = $62;
 $63 = $61 >> 3;
 $64 = ($63>>>0)<(1073741823);
 if ($64) {
  $65 = $61 >> 2;
  $66 = ($65>>>0)<($6>>>0);
  $67 = $66 ? $6 : $65;
  $68 = ($67|0)<(0);
  if ($68) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $67;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $69 = $$0$i37 << 3;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $70 = (__Z15malloc_internaljj10MemLabelIdiPKci($69,16,$$byval_copy1,0,630440,79)|0);
 $71 = (($this) + 4|0);
 HEAP32[$71>>2] = $70;
 HEAP32[$this>>2] = $70;
 $72 = (($70) + ($$0$i37<<3)|0);
 HEAP32[$7>>2] = $72;
 $73 = ($1|0)==($2|0);
 if ($73) {
  STACKTOP = sp;return;
 } else {
  $75 = $70;$77 = $1;
 }
 while(1) {
  $74 = ($75|0)==(0|0);
  if ($74) {
   $88 = 0;
  } else {
   $76 = $77;
   $78 = $76;
   $79 = HEAP32[$78>>2]|0;
   $80 = (($76) + 4)|0;
   $81 = $80;
   $82 = HEAP32[$81>>2]|0;
   $83 = $75;
   $84 = $83;
   HEAP32[$84>>2] = $79;
   $85 = (($83) + 4)|0;
   $86 = $85;
   HEAP32[$86>>2] = $82;
   $$pre5$i = HEAP32[$71>>2]|0;
   $88 = $$pre5$i;
  }
  $87 = (($88) + 8|0);
  HEAP32[$71>>2] = $87;
  $89 = (($77) + 8|0);
  $90 = ($89|0)==($2|0);
  if ($90) {
   break;
  } else {
   $75 = $87;$77 = $89;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8Vector2f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0;
 var $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAPF32[$11>>2] = Math_fround(0.0);
    $12 = (($11) + 4|0);
    HEAPF32[$12>>2] = Math_fround(0.0);
   }
   $13 = (($11) + 8|0);
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $13;
   }
  }
  $scevgep$i = (($4) + ($__n<<3)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = $18 >> 3;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = $22 >> 3;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $22 >> 2;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i58 = 0;$32 = 0;
  } else {
   $$0$i57 = $27;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $29 = $$0$i57 << 3;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,630440,79)|0);
  $$0$i58 = $$0$i57;$32 = $30;
 }
 $31 = (($32) + ($19<<3)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if (!($33)) {
   HEAPF32[$34>>2] = Math_fround(0.0);
   $35 = (($34) + 4|0);
   HEAPF32[$35>>2] = Math_fround(0.0);
  }
  $36 = (($34) + 8|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $36;
  }
 }
 $39 = (($32) + ($$0$i58<<3)|0);
 $scevgep$i4 = (($32) + ($20<<3)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = $44 >> 3;
 $$sum6 = (($19) - ($45))|0;
 $46 = (($32) + ($$sum6<<3)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1829,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = (($32|0) / 12)&-1;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($28|0)==($29|0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),12)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + (($index$01$i*12)|0)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -12|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + (($69*12)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -12|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 12)&-1;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + (($19*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8Vector3f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI8Vector3f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$29,0,0);
   $30 = (($29) + 12|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI8Vector3f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i27 = 0;
 var $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 12)&-1;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + (($sz*12)|0)|0);
  $$idx = ($sz*12)|0;
  $88 = (($$idx|0) / 12)&-1;
  $89 = ($sz|0)==(0);
  do {
   if ($89) {
    $104 = 0;$105 = 0;$107 = 0;$109 = $7;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $97 = $93;$98 = $7;
      while(1) {
       $96 = ($97|0)==(0|0);
       if ($96) {
        $100 = 0;
       } else {
        ;HEAP32[$97+0>>2]=HEAP32[$98+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$98+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$98+8>>2]|0;
        $100 = $97;
       }
       $99 = (($100) + 12|0);
       $101 = (($98) + 12|0);
       $102 = ($101|0)==($87|0);
       if ($102) {
        break;
       } else {
        $97 = $99;$98 = $101;
       }
      }
      $103 = (($93) + (($88*12)|0)|0);
      $$pre = HEAP32[$v>>2]|0;
      $104 = $93;$105 = $99;$107 = $103;$109 = $$pre;
      break;
     }
    }
    $114 = ___cxa_find_matching_catch()|0;
    $115 = tempRet0;
    $$0 = $115;$$01 = $114;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $104;
  HEAP32[$5>>2] = $105;
  $106 = (($v) + 8|0);
  HEAP32[$106>>2] = $107;
  $108 = ($109|0)==(0|0);
  if ($108) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($109|0),($$byval_copy7|0));
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if ($111) {
   $112 = ___cxa_find_matching_catch()|0;
   $113 = tempRet0;
   ___cxa_call_unexpected(($112|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorI8Vector3f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = ($sz*12)|0;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + (($sz*12)|0)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = (($28|0) / -12)&-1;
   $30 = (($23) + (($29*12)|0)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1830,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = (($45|0) / 12)&-1;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2887,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre45 = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre45;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + (($sz*12)|0)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -12|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = (($uglygep3$i$i$i>>>0) / 12)&-1;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + (($56*12)|0)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -12|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = (($uglygep3$i$i$i$i$i19>>>0) / 12)&-1;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + (($67*12)|0)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -12|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = (($uglygep3$i$i$i$i$i28>>>0) / 12)&-1;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + (($80*12)|0)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8Vector3f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = (($18|0) / 12)&-1;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = (($31|0) / 12)&-1;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + (($32*12)|0)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -12|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = (($uglygep3$i$i>>>0) / 12)&-1;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + (($38*12)|0)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + (($19*12)|0)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 12|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 12|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -12|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = (($uglygep3$i$i$i$i>>>0) / 12)&-1;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + (($45*12)|0)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = (($51|0) / 12)&-1;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $53 << 1;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = ($$0$i37*12)|0;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,630440,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + (($$0$i37*12)|0)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   ;HEAP32[$65+0>>2]=HEAP32[$66+0>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 12|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 12|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8Vector3f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAPF32[$11>>2] = Math_fround(0.0);
    $12 = (($11) + 4|0);
    HEAPF32[$12>>2] = Math_fround(0.0);
    $13 = (($11) + 8|0);
    HEAPF32[$13>>2] = Math_fround(0.0);
   }
   $14 = (($11) + 12|0);
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$11 = $14;
   }
  }
  $scevgep$i = (($4) + (($__n*12)|0)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($6) - ($18))|0;
 $20 = (($19|0) / 12)&-1;
 $21 = (($20) + ($__n))|0;
 $22 = ($21|0)<(0);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($5) - ($18))|0;
 $24 = (($23|0) / 12)&-1;
 $25 = ($24>>>0)<(1073741823);
 if ($25) {
  $26 = $24 << 1;
  $27 = ($26>>>0)<($21>>>0);
  $28 = $27 ? $21 : $26;
  $29 = ($28|0)==(0);
  if ($29) {
   $$0$i58 = 0;$33 = 0;
  } else {
   $$0$i57 = $28;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $30 = ($$0$i57*12)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $31 = (__Z15malloc_internaljj10MemLabelIdiPKci($30,16,$$byval_copy1,0,630440,79)|0);
  $$0$i58 = $$0$i57;$33 = $31;
 }
 $32 = (($33) + (($20*12)|0)|0);
 $$0$i2 = $__n;$35 = $32;
 while(1) {
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   HEAPF32[$35>>2] = Math_fround(0.0);
   $36 = (($35) + 4|0);
   HEAPF32[$36>>2] = Math_fround(0.0);
   $37 = (($35) + 8|0);
   HEAPF32[$37>>2] = Math_fround(0.0);
  }
  $38 = (($35) + 12|0);
  $39 = (($$0$i2) + -1)|0;
  $40 = ($39|0)==(0);
  if ($40) {
   break;
  } else {
   $$0$i2 = $39;$35 = $38;
  }
 }
 $41 = (($33) + (($$0$i58*12)|0)|0);
 $scevgep$i4 = (($33) + (($21*12)|0)|0);
 $42 = HEAP32[$this>>2]|0;
 $43 = HEAP32[$3>>2]|0;
 $44 = $43;
 $45 = $42;
 $46 = (($44) - ($45))|0;
 $47 = (($46|0) / -12)&-1;
 $$sum6 = (($47) + ($20))|0;
 $48 = (($33) + (($$sum6*12)|0)|0);
 _memcpy(($48|0),($42|0),($46|0))|0;
 $49 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $48;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $41;
 $50 = ($49|0)==(0|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($49|0),($$byval_copy1|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  ___cxa_call_unexpected(($53|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1831,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),8)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<3)|0);
      $50 = +HEAPF64[$49>>3];
      HEAPF64[$45>>3] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -8|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -8|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert2$i$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre3$i$i$i = 0, $$pre5$i$i$i = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 8|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,8);
   $$pre$i$i$i = HEAP32[$34>>2]|0;
   $$phi$trans$insert2$i$i$i = (($34) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $34;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$39 = $$pre$i$i$i;$41 = $$pre3$i$i$i;
  } else {
   HEAP8[tempDoublePtr>>0]=HEAP8[$29>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$29+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$29+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$29+3>>0];HEAP8[tempDoublePtr+4>>0]=HEAP8[$29+4>>0];HEAP8[tempDoublePtr+5>>0]=HEAP8[$29+5>>0];HEAP8[tempDoublePtr+6>>0]=HEAP8[$29+6>>0];HEAP8[tempDoublePtr+7>>0]=HEAP8[$29+7>>0];$33 = +HEAPF64[tempDoublePtr>>3];
   HEAPF64[tempDoublePtr>>3]=$33;HEAP8[$34>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$34+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$34+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$34+3>>0]=HEAP8[tempDoublePtr+3>>0];HEAP8[$34+4>>0]=HEAP8[tempDoublePtr+4>>0];HEAP8[$34+5>>0]=HEAP8[tempDoublePtr+5>>0];HEAP8[$34+6>>0]=HEAP8[tempDoublePtr+6>>0];HEAP8[$34+7>>0]=HEAP8[tempDoublePtr+7>>0];
   $35 = HEAP32[$1>>2]|0;
   $36 = (($35) + 8|0);
   HEAP32[$1>>2] = $36;
   HEAPF64[tempDoublePtr>>3] = $33;$37 = HEAP32[tempDoublePtr>>2]|0;
   $38 = HEAP32[tempDoublePtr+4>>2]|0;
   $$pre5$i$i$i = (($34) + 4|0);
   $$pre$phi$i$i$iZ2D = $34;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$39 = $37;$41 = $38;
  }
  $40 = (_llvm_bswap_i32(($39|0))|0);
  $42 = (_llvm_bswap_i32(($41|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $42;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $40;
  $43 = (($34) + 8|0);
  $44 = ($43|0)==($26|0);
  if ($44) {
   break;
  } else {
   $34 = $43;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0;
 var $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<3)|0);
  $$idx = $sz << 3;
  $88 = $$idx >> 3;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $109 = 0;$111 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<3)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $109 = $93;$111 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<3)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = +HEAPF64[$102>>3];
        HEAPF64[$100>>3] = $101;
       }
       $103 = (($100) + 8|0);
       $104 = (($102) + 8|0);
       $105 = ($104|0)==($87|0);
       if ($105) {
        break;
       } else {
        $100 = $103;$102 = $104;
       }
      }
      $106 = $uglygep6$i$i >>> 3;
      $107 = (($106) + 1)|0;
      $scevgep8$i$i = (($93) + ($107<<3)|0);
      $109 = $93;$111 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $117 = ___cxa_find_matching_catch()|0;
    $118 = tempRet0;
    $$0 = $118;$$01 = $117;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $108 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $109;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $110 = (($v) + 8|0);
  HEAP32[$110>>2] = $111;
  $112 = ($108|0)==(0|0);
  if ($112) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($108|0),($$byval_copy7|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   ___cxa_call_unexpected(($115|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 3;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 3;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<3)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 3;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<3)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1832,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 3;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2888,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<3)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -8|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 3;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<3)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -8|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 3;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<3)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -8|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 3;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<3)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPdEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIdNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 3;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 3;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $34 = $2;
   $35 = (($34) - ($4))|0;
   $36 = $35 >> 3;
   _memmove(($9|0),($1|0),($35|0))|0;
   $37 = (($9) + ($36<<3)|0);
   $38 = HEAP32[$15>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $37;
   $scevgep$i$i = (($38) + -8|0);
   $40 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($40)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $41 = $uglygep3$i$i >>> 3;
   $42 = $41 ^ -1;
   $scevgep4$i$i = (($38) + ($42<<3)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<3)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -8|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 3;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = +HEAPF64[$29>>3];
    HEAPF64[$27>>3] = $28;
   }
   $30 = (($27) + 8|0);
   $31 = (($29) + 8|0);
   $32 = ($31|0)==($2|0);
   if ($32) {
    break;
   } else {
    $27 = $30;$29 = $31;
   }
  }
  $33 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($33<<3)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $43 = ($9|0)==(0|0);
 do {
  if ($43) {
   $56 = $8;
  } else {
   $44 = (($this) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==($9|0);
   if (!($46)) {
    $scevgep$i$i$i$i = (($45) + -8|0);
    $47 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($47)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $48 = $uglygep3$i$i$i$i >>> 3;
    $49 = $48 ^ -1;
    $scevgep4$i$i$i$i = (($45) + ($49<<3)|0);
    HEAP32[$44>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    ___cxa_call_unexpected(($52|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$44>>2] = 0;
    HEAP32[$this>>2] = 0;
    $56 = 0;
    break;
   }
  }
 } while(0);
 $54 = ($5|0)<(0);
 if ($54) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $55 = $56;
 $57 = $55 >> 3;
 $58 = ($57>>>0)<(1073741823);
 if ($58) {
  $59 = $55 >> 2;
  $60 = ($59>>>0)<($6>>>0);
  $61 = $60 ? $6 : $59;
  $62 = ($61|0)<(0);
  if ($62) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $61;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $63 = $$0$i37 << 3;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $64 = (__Z15malloc_internaljj10MemLabelIdiPKci($63,16,$$byval_copy1,0,630440,79)|0);
 $65 = (($this) + 4|0);
 HEAP32[$65>>2] = $64;
 HEAP32[$this>>2] = $64;
 $66 = (($64) + ($$0$i37<<3)|0);
 HEAP32[$7>>2] = $66;
 $67 = ($1|0)==($2|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -8|0);
 $68 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($68)|0);
 $uglygep6$i = $uglygep$i;
 $69 = $uglygep6$i >>> 3;
 $71 = $64;$73 = $1;
 while(1) {
  $70 = ($71|0)==(0|0);
  if (!($70)) {
   $72 = +HEAPF64[$73>>3];
   HEAPF64[$71>>3] = $72;
  }
  $74 = (($71) + 8|0);
  $75 = (($73) + 8|0);
  $76 = ($75|0)==($2|0);
  if ($76) {
   break;
  } else {
   $71 = $74;$73 = $75;
  }
 }
 $77 = (($69) + 1)|0;
 $scevgep8$i = (($64) + ($77<<3)|0);
 HEAP32[$65>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAPF64[$11>>3] = 0.0;
   }
   $12 = (($11) + 8|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<3)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 3;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 3;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = $21 >> 2;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 3;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy1,0,630440,79)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<3)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAPF64[$33>>3] = 0.0;
  }
  $34 = (($33) + 8|0);
  $35 = (($$0$i2) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i2 = $35;$33 = $34;
  }
 }
 $37 = (($31) + ($$0$i58<<3)|0);
 $scevgep$i4 = (($31) + ($19<<3)|0);
 $38 = HEAP32[$this>>2]|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = $39;
 $41 = $38;
 $42 = (($40) - ($41))|0;
 $43 = $42 >> 3;
 $$sum6 = (($18) - ($43))|0;
 $44 = (($31) + ($$sum6<<3)|0);
 _memcpy(($44|0),($38|0),($42|0))|0;
 $45 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $44;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $37;
 $46 = ($45|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($45|0),($$byval_copy1|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1833,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = Math_fround(HEAPF32[$49>>2]);
      HEAPF32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
   $$pre$i$i$i = HEAP32[$34>>2]|0;
   $$pre$phi$i$i$iZ2D = $34;$36 = $$pre$i$i$i;
  } else {
   $33 = Math_fround(HEAPF32[$29>>2]);
   HEAPF32[$34>>2] = $33;
   HEAP32[$1>>2] = $30;
   $35 = (HEAPF32[tempDoublePtr>>2]=$33,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$iZ2D = $34;$36 = $35;
  }
  $37 = (_llvm_bswap_i32(($36|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $37;
  $38 = (($34) + 4|0);
  $39 = ($38|0)==($26|0);
  if ($39) {
   break;
  } else {
   $34 = $38;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0;
 var $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $88 = $$idx >> 2;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $109 = 0;$111 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<2)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $109 = $93;$111 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<2)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = Math_fround(HEAPF32[$102>>2]);
        HEAPF32[$100>>2] = $101;
       }
       $103 = (($100) + 4|0);
       $104 = (($102) + 4|0);
       $105 = ($104|0)==($87|0);
       if ($105) {
        break;
       } else {
        $100 = $103;$102 = $104;
       }
      }
      $106 = $uglygep6$i$i >>> 2;
      $107 = (($106) + 1)|0;
      $scevgep8$i$i = (($93) + ($107<<2)|0);
      $109 = $93;$111 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $117 = ___cxa_find_matching_catch()|0;
    $118 = tempRet0;
    $$0 = $118;$$01 = $117;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $108 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $109;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $110 = (($v) + 8|0);
  HEAP32[$110>>2] = $111;
  $112 = ($108|0)==(0|0);
  if ($112) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($108|0),($$byval_copy7|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   ___cxa_call_unexpected(($115|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 2;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 2;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<2)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 2;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<2)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1834,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 2;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2889,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<2)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -4|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 2;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<2)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -4|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 2;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<2)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -4|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 2;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<2)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPfEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIfNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $34 = $2;
   $35 = (($34) - ($4))|0;
   $36 = $35 >> 2;
   _memmove(($9|0),($1|0),($35|0))|0;
   $37 = (($9) + ($36<<2)|0);
   $38 = HEAP32[$15>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $37;
   $scevgep$i$i = (($38) + -4|0);
   $40 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($40)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $41 = $uglygep3$i$i >>> 2;
   $42 = $41 ^ -1;
   $scevgep4$i$i = (($38) + ($42<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<2)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -4|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 2;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$27>>2] = $28;
   }
   $30 = (($27) + 4|0);
   $31 = (($29) + 4|0);
   $32 = ($31|0)==($2|0);
   if ($32) {
    break;
   } else {
    $27 = $30;$29 = $31;
   }
  }
  $33 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($33<<2)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $43 = ($9|0)==(0|0);
 do {
  if ($43) {
   $56 = $8;
  } else {
   $44 = (($this) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==($9|0);
   if (!($46)) {
    $scevgep$i$i$i$i = (($45) + -4|0);
    $47 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($47)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $48 = $uglygep3$i$i$i$i >>> 2;
    $49 = $48 ^ -1;
    $scevgep4$i$i$i$i = (($45) + ($49<<2)|0);
    HEAP32[$44>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    ___cxa_call_unexpected(($52|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$44>>2] = 0;
    HEAP32[$this>>2] = 0;
    $56 = 0;
    break;
   }
  }
 } while(0);
 $54 = ($5|0)<(0);
 if ($54) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $55 = $56;
 $57 = $55 >> 2;
 $58 = ($57>>>0)<(1073741823);
 if ($58) {
  $59 = $55 >> 1;
  $60 = ($59>>>0)<($6>>>0);
  $61 = $60 ? $6 : $59;
  $62 = ($61|0)<(0);
  if ($62) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $61;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $63 = $$0$i37 << 2;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $64 = (__Z15malloc_internaljj10MemLabelIdiPKci($63,16,$$byval_copy1,0,630440,79)|0);
 $65 = (($this) + 4|0);
 HEAP32[$65>>2] = $64;
 HEAP32[$this>>2] = $64;
 $66 = (($64) + ($$0$i37<<2)|0);
 HEAP32[$7>>2] = $66;
 $67 = ($1|0)==($2|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -4|0);
 $68 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($68)|0);
 $uglygep6$i = $uglygep$i;
 $69 = $uglygep6$i >>> 2;
 $71 = $64;$73 = $1;
 while(1) {
  $70 = ($71|0)==(0|0);
  if (!($70)) {
   $72 = Math_fround(HEAPF32[$73>>2]);
   HEAPF32[$71>>2] = $72;
  }
  $74 = (($71) + 4|0);
  $75 = (($73) + 4|0);
  $76 = ($75|0)==($2|0);
  if ($76) {
   break;
  } else {
   $71 = $74;$73 = $75;
  }
 }
 $77 = (($69) + 1)|0;
 $scevgep8$i = (($64) + ($77<<2)|0);
 HEAP32[$65>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAPF32[$11>>2] = Math_fround(0.0);
   }
   $12 = (($11) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<2)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy1,0,630440,79)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAPF32[$33>>2] = Math_fround(0.0);
  }
  $34 = (($33) + 4|0);
  $35 = (($$0$i2) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i2 = $35;$33 = $34;
  }
 }
 $37 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 $38 = HEAP32[$this>>2]|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = $39;
 $41 = $38;
 $42 = (($40) - ($41))|0;
 $43 = $42 >> 2;
 $$sum6 = (($18) - ($43))|0;
 $44 = (($31) + ($$sum6<<2)|0);
 _memcpy(($44|0),($38|0),($42|0))|0;
 $45 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $44;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $37;
 $46 = ($45|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($45|0),($$byval_copy1|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1835,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),8)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<3)|0);
      $50 = $49;
      $51 = $50;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($50) + 4)|0;
      $54 = $53;
      $55 = HEAP32[$54>>2]|0;
      $56 = $45;
      $57 = $56;
      HEAP32[$57>>2] = $52;
      $58 = (($56) + 4)|0;
      $59 = $58;
      HEAP32[$59>>2] = $55;
      $60 = (($index$01$i) + 1)|0;
      $61 = ($60|0)==($33|0);
      if ($61) {
       break L8;
      } else {
       $index$01$i = $60;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $62 = HEAP32[$24>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L15: do {
    if (!($65)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$012) + 1)|0;
      $69 = HEAP32[$24>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($68|0)==($71|0);
      if ($72) {
       break L15;
      } else {
       $index$012 = $68;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $73 = HEAP32[$buffer>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$1>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i$i$i = $73;
    $scevgep$i$i$i$i$i$i$i = (($75) + -8|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($77)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $78 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($75) + ($79<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($73|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -8|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert2$i$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre3$i$i$i = 0, $$pre5$i$i$i = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $40 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 8|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$40,8);
   $$pre$i$i$i = HEAP32[$40>>2]|0;
   $$phi$trans$insert2$i$i$i = (($40) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $40;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$44 = $$pre$i$i$i;$46 = $$pre3$i$i$i;
  } else {
   $33 = $29;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) + 4)|0;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = $40;
   $41 = $39;
   HEAP32[$41>>2] = $35;
   $42 = (($39) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $38;
   HEAP32[$1>>2] = $30;
   $$pre5$i$i$i = (($40) + 4|0);
   $$pre$phi$i$i$iZ2D = $40;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$44 = $35;$46 = $38;
  }
  $45 = (_llvm_bswap_i32(($44|0))|0);
  $47 = (_llvm_bswap_i32(($46|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $47;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $45;
  $48 = (($40) + 8|0);
  $49 = ($48|0)==($26|0);
  if ($49) {
   break;
  } else {
   $40 = $48;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0;
 var $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0, $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0;
 var $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<3)|0);
  $$idx = $sz << 3;
  $88 = $$idx >> 3;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $118 = 0;$120 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<3)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $118 = $93;$120 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<3)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = $102;
        $103 = $101;
        $104 = HEAP32[$103>>2]|0;
        $105 = (($101) + 4)|0;
        $106 = $105;
        $107 = HEAP32[$106>>2]|0;
        $108 = $100;
        $109 = $108;
        HEAP32[$109>>2] = $104;
        $110 = (($108) + 4)|0;
        $111 = $110;
        HEAP32[$111>>2] = $107;
       }
       $112 = (($100) + 8|0);
       $113 = (($102) + 8|0);
       $114 = ($113|0)==($87|0);
       if ($114) {
        break;
       } else {
        $100 = $112;$102 = $113;
       }
      }
      $115 = $uglygep6$i$i >>> 3;
      $116 = (($115) + 1)|0;
      $scevgep8$i$i = (($93) + ($116<<3)|0);
      $118 = $93;$120 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $126 = ___cxa_find_matching_catch()|0;
    $127 = tempRet0;
    $$0 = $127;$$01 = $126;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $117 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $118;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $119 = (($v) + 8|0);
  HEAP32[$119>>2] = $120;
  $121 = ($117|0)==(0|0);
  if ($121) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($117|0),($$byval_copy7|0));
  $122 = __THREW__; __THREW__ = 0;
  $123 = $122&1;
  if ($123) {
   $124 = ___cxa_find_matching_catch()|0;
   $125 = tempRet0;
   ___cxa_call_unexpected(($124|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 3;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 3;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<3)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 3;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<3)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1836,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 3;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2890,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<3)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -8|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 3;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<3)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -8|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 3;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<3)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -8|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 3;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<3)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPyEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIyNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $__new_last2$i$i = 0;
 var $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 3;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 3;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $43 = $2;
   $44 = (($43) - ($4))|0;
   $45 = $44 >> 3;
   _memmove(($9|0),($1|0),($44|0))|0;
   $46 = (($9) + ($45<<3)|0);
   $47 = HEAP32[$15>>2]|0;
   $48 = ($47|0)==($46|0);
   if ($48) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $46;
   $scevgep$i$i = (($47) + -8|0);
   $49 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($49)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $50 = $uglygep3$i$i >>> 3;
   $51 = $50 ^ -1;
   $scevgep4$i$i = (($47) + ($51<<3)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<3)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -8|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 3;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = $29;
    $30 = $28;
    $31 = HEAP32[$30>>2]|0;
    $32 = (($28) + 4)|0;
    $33 = $32;
    $34 = HEAP32[$33>>2]|0;
    $35 = $27;
    $36 = $35;
    HEAP32[$36>>2] = $31;
    $37 = (($35) + 4)|0;
    $38 = $37;
    HEAP32[$38>>2] = $34;
   }
   $39 = (($27) + 8|0);
   $40 = (($29) + 8|0);
   $41 = ($40|0)==($2|0);
   if ($41) {
    break;
   } else {
    $27 = $39;$29 = $40;
   }
  }
  $42 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($42<<3)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $52 = ($9|0)==(0|0);
 do {
  if ($52) {
   $65 = $8;
  } else {
   $53 = (($this) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==($9|0);
   if (!($55)) {
    $scevgep$i$i$i$i = (($54) + -8|0);
    $56 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($56)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $57 = $uglygep3$i$i$i$i >>> 3;
    $58 = $57 ^ -1;
    $scevgep4$i$i$i$i = (($54) + ($58<<3)|0);
    HEAP32[$53>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $61 = ___cxa_find_matching_catch()|0;
    $62 = tempRet0;
    ___cxa_call_unexpected(($61|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$53>>2] = 0;
    HEAP32[$this>>2] = 0;
    $65 = 0;
    break;
   }
  }
 } while(0);
 $63 = ($5|0)<(0);
 if ($63) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $64 = $65;
 $66 = $64 >> 3;
 $67 = ($66>>>0)<(1073741823);
 if ($67) {
  $68 = $64 >> 2;
  $69 = ($68>>>0)<($6>>>0);
  $70 = $69 ? $6 : $68;
  $71 = ($70|0)<(0);
  if ($71) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $70;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $72 = $$0$i37 << 3;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $73 = (__Z15malloc_internaljj10MemLabelIdiPKci($72,16,$$byval_copy1,0,630440,79)|0);
 $74 = (($this) + 4|0);
 HEAP32[$74>>2] = $73;
 HEAP32[$this>>2] = $73;
 $75 = (($73) + ($$0$i37<<3)|0);
 HEAP32[$7>>2] = $75;
 $76 = ($1|0)==($2|0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -8|0);
 $77 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($77)|0);
 $uglygep6$i = $uglygep$i;
 $78 = $uglygep6$i >>> 3;
 $80 = $73;$82 = $1;
 while(1) {
  $79 = ($80|0)==(0|0);
  if (!($79)) {
   $81 = $82;
   $83 = $81;
   $84 = HEAP32[$83>>2]|0;
   $85 = (($81) + 4)|0;
   $86 = $85;
   $87 = HEAP32[$86>>2]|0;
   $88 = $80;
   $89 = $88;
   HEAP32[$89>>2] = $84;
   $90 = (($88) + 4)|0;
   $91 = $90;
   HEAP32[$91>>2] = $87;
  }
  $92 = (($80) + 8|0);
  $93 = (($82) + 8|0);
  $94 = ($93|0)==($2|0);
  if ($94) {
   break;
  } else {
   $80 = $92;$82 = $93;
  }
 }
 $95 = (($78) + 1)|0;
 $scevgep8$i = (($73) + ($95<<3)|0);
 HEAP32[$74>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    $12 = $11;
    $13 = $12;
    HEAP32[$13>>2] = 0;
    $14 = (($12) + 4)|0;
    $15 = $14;
    HEAP32[$15>>2] = 0;
   }
   $16 = (($11) + 8|0);
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$11 = $16;
   }
  }
  $scevgep$i = (($4) + ($__n<<3)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = $19;
 $21 = (($6) - ($20))|0;
 $22 = $21 >> 3;
 $23 = (($22) + ($__n))|0;
 $24 = ($23|0)<(0);
 if ($24) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $25 = (($5) - ($20))|0;
 $26 = $25 >> 3;
 $27 = ($26>>>0)<(1073741823);
 if ($27) {
  $28 = $25 >> 2;
  $29 = ($28>>>0)<($23>>>0);
  $30 = $29 ? $23 : $28;
  $31 = ($30|0)==(0);
  if ($31) {
   $$0$i58 = 0;$35 = 0;
  } else {
   $$0$i57 = $30;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $32 = $$0$i57 << 3;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,16,$$byval_copy1,0,630440,79)|0);
  $$0$i58 = $$0$i57;$35 = $33;
 }
 $34 = (($35) + ($22<<3)|0);
 $$0$i2 = $__n;$37 = $34;
 while(1) {
  $36 = ($37|0)==(0|0);
  if (!($36)) {
   $38 = $37;
   $39 = $38;
   HEAP32[$39>>2] = 0;
   $40 = (($38) + 4)|0;
   $41 = $40;
   HEAP32[$41>>2] = 0;
  }
  $42 = (($37) + 8|0);
  $43 = (($$0$i2) + -1)|0;
  $44 = ($43|0)==(0);
  if ($44) {
   break;
  } else {
   $$0$i2 = $43;$37 = $42;
  }
 }
 $45 = (($35) + ($$0$i58<<3)|0);
 $scevgep$i4 = (($35) + ($23<<3)|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = HEAP32[$3>>2]|0;
 $48 = $47;
 $49 = $46;
 $50 = (($48) - ($49))|0;
 $51 = $50 >> 3;
 $$sum6 = (($22) - ($51))|0;
 $52 = (($35) + ($$sum6<<3)|0);
 _memcpy(($52|0),($46|0),($50|0))|0;
 $53 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $52;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $45;
 $54 = ($53|0)==(0|0);
 if ($54) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($53|0),($$byval_copy1|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  ___cxa_call_unexpected(($57|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1837,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),8)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<3)|0);
      $50 = $49;
      $51 = $50;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($50) + 4)|0;
      $54 = $53;
      $55 = HEAP32[$54>>2]|0;
      $56 = $45;
      $57 = $56;
      HEAP32[$57>>2] = $52;
      $58 = (($56) + 4)|0;
      $59 = $58;
      HEAP32[$59>>2] = $55;
      $60 = (($index$01$i) + 1)|0;
      $61 = ($60|0)==($33|0);
      if ($61) {
       break L8;
      } else {
       $index$01$i = $60;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $62 = HEAP32[$24>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L15: do {
    if (!($65)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$012) + 1)|0;
      $69 = HEAP32[$24>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($68|0)==($71|0);
      if ($72) {
       break L15;
      } else {
       $index$012 = $68;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $73 = HEAP32[$buffer>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$1>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i$i$i = $73;
    $scevgep$i$i$i$i$i$i$i = (($75) + -8|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($77)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $78 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($75) + ($79<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($73|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -8|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert2$i$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre3$i$i$i = 0, $$pre5$i$i$i = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $40 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 8|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$40,8);
   $$pre$i$i$i = HEAP32[$40>>2]|0;
   $$phi$trans$insert2$i$i$i = (($40) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $40;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$44 = $$pre$i$i$i;$46 = $$pre3$i$i$i;
  } else {
   $33 = $29;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) + 4)|0;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = $40;
   $41 = $39;
   HEAP32[$41>>2] = $35;
   $42 = (($39) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $38;
   HEAP32[$1>>2] = $30;
   $$pre5$i$i$i = (($40) + 4|0);
   $$pre$phi$i$i$iZ2D = $40;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$44 = $35;$46 = $38;
  }
  $45 = (_llvm_bswap_i32(($44|0))|0);
  $47 = (_llvm_bswap_i32(($46|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $47;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $45;
  $48 = (($40) + 8|0);
  $49 = ($48|0)==($26|0);
  if ($49) {
   break;
  } else {
   $40 = $48;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0;
 var $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0, $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0;
 var $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<3)|0);
  $$idx = $sz << 3;
  $88 = $$idx >> 3;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $118 = 0;$120 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<3)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $118 = $93;$120 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<3)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = $102;
        $103 = $101;
        $104 = HEAP32[$103>>2]|0;
        $105 = (($101) + 4)|0;
        $106 = $105;
        $107 = HEAP32[$106>>2]|0;
        $108 = $100;
        $109 = $108;
        HEAP32[$109>>2] = $104;
        $110 = (($108) + 4)|0;
        $111 = $110;
        HEAP32[$111>>2] = $107;
       }
       $112 = (($100) + 8|0);
       $113 = (($102) + 8|0);
       $114 = ($113|0)==($87|0);
       if ($114) {
        break;
       } else {
        $100 = $112;$102 = $113;
       }
      }
      $115 = $uglygep6$i$i >>> 3;
      $116 = (($115) + 1)|0;
      $scevgep8$i$i = (($93) + ($116<<3)|0);
      $118 = $93;$120 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $126 = ___cxa_find_matching_catch()|0;
    $127 = tempRet0;
    $$0 = $127;$$01 = $126;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $117 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $118;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $119 = (($v) + 8|0);
  HEAP32[$119>>2] = $120;
  $121 = ($117|0)==(0|0);
  if ($121) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($117|0),($$byval_copy7|0));
  $122 = __THREW__; __THREW__ = 0;
  $123 = $122&1;
  if ($123) {
   $124 = ___cxa_find_matching_catch()|0;
   $125 = tempRet0;
   ___cxa_call_unexpected(($124|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 3;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 3;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<3)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 3;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<3)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1838,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 3;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2891,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<3)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -8|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 3;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<3)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -8|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 3;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<3)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -8|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 3;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<3)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPxEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIxNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $__new_last2$i$i = 0;
 var $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 3;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 3;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $43 = $2;
   $44 = (($43) - ($4))|0;
   $45 = $44 >> 3;
   _memmove(($9|0),($1|0),($44|0))|0;
   $46 = (($9) + ($45<<3)|0);
   $47 = HEAP32[$15>>2]|0;
   $48 = ($47|0)==($46|0);
   if ($48) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $46;
   $scevgep$i$i = (($47) + -8|0);
   $49 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($49)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $50 = $uglygep3$i$i >>> 3;
   $51 = $50 ^ -1;
   $scevgep4$i$i = (($47) + ($51<<3)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<3)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -8|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 3;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = $29;
    $30 = $28;
    $31 = HEAP32[$30>>2]|0;
    $32 = (($28) + 4)|0;
    $33 = $32;
    $34 = HEAP32[$33>>2]|0;
    $35 = $27;
    $36 = $35;
    HEAP32[$36>>2] = $31;
    $37 = (($35) + 4)|0;
    $38 = $37;
    HEAP32[$38>>2] = $34;
   }
   $39 = (($27) + 8|0);
   $40 = (($29) + 8|0);
   $41 = ($40|0)==($2|0);
   if ($41) {
    break;
   } else {
    $27 = $39;$29 = $40;
   }
  }
  $42 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($42<<3)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $52 = ($9|0)==(0|0);
 do {
  if ($52) {
   $65 = $8;
  } else {
   $53 = (($this) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==($9|0);
   if (!($55)) {
    $scevgep$i$i$i$i = (($54) + -8|0);
    $56 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($56)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $57 = $uglygep3$i$i$i$i >>> 3;
    $58 = $57 ^ -1;
    $scevgep4$i$i$i$i = (($54) + ($58<<3)|0);
    HEAP32[$53>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $61 = ___cxa_find_matching_catch()|0;
    $62 = tempRet0;
    ___cxa_call_unexpected(($61|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$53>>2] = 0;
    HEAP32[$this>>2] = 0;
    $65 = 0;
    break;
   }
  }
 } while(0);
 $63 = ($5|0)<(0);
 if ($63) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $64 = $65;
 $66 = $64 >> 3;
 $67 = ($66>>>0)<(1073741823);
 if ($67) {
  $68 = $64 >> 2;
  $69 = ($68>>>0)<($6>>>0);
  $70 = $69 ? $6 : $68;
  $71 = ($70|0)<(0);
  if ($71) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $70;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $72 = $$0$i37 << 3;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $73 = (__Z15malloc_internaljj10MemLabelIdiPKci($72,16,$$byval_copy1,0,630440,79)|0);
 $74 = (($this) + 4|0);
 HEAP32[$74>>2] = $73;
 HEAP32[$this>>2] = $73;
 $75 = (($73) + ($$0$i37<<3)|0);
 HEAP32[$7>>2] = $75;
 $76 = ($1|0)==($2|0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -8|0);
 $77 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($77)|0);
 $uglygep6$i = $uglygep$i;
 $78 = $uglygep6$i >>> 3;
 $80 = $73;$82 = $1;
 while(1) {
  $79 = ($80|0)==(0|0);
  if (!($79)) {
   $81 = $82;
   $83 = $81;
   $84 = HEAP32[$83>>2]|0;
   $85 = (($81) + 4)|0;
   $86 = $85;
   $87 = HEAP32[$86>>2]|0;
   $88 = $80;
   $89 = $88;
   HEAP32[$89>>2] = $84;
   $90 = (($88) + 4)|0;
   $91 = $90;
   HEAP32[$91>>2] = $87;
  }
  $92 = (($80) + 8|0);
  $93 = (($82) + 8|0);
  $94 = ($93|0)==($2|0);
  if ($94) {
   break;
  } else {
   $80 = $92;$82 = $93;
  }
 }
 $95 = (($78) + 1)|0;
 $scevgep8$i = (($73) + ($95<<3)|0);
 HEAP32[$74>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    $12 = $11;
    $13 = $12;
    HEAP32[$13>>2] = 0;
    $14 = (($12) + 4)|0;
    $15 = $14;
    HEAP32[$15>>2] = 0;
   }
   $16 = (($11) + 8|0);
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$11 = $16;
   }
  }
  $scevgep$i = (($4) + ($__n<<3)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = $19;
 $21 = (($6) - ($20))|0;
 $22 = $21 >> 3;
 $23 = (($22) + ($__n))|0;
 $24 = ($23|0)<(0);
 if ($24) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $25 = (($5) - ($20))|0;
 $26 = $25 >> 3;
 $27 = ($26>>>0)<(1073741823);
 if ($27) {
  $28 = $25 >> 2;
  $29 = ($28>>>0)<($23>>>0);
  $30 = $29 ? $23 : $28;
  $31 = ($30|0)==(0);
  if ($31) {
   $$0$i58 = 0;$35 = 0;
  } else {
   $$0$i57 = $30;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $32 = $$0$i57 << 3;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,16,$$byval_copy1,0,630440,79)|0);
  $$0$i58 = $$0$i57;$35 = $33;
 }
 $34 = (($35) + ($22<<3)|0);
 $$0$i2 = $__n;$37 = $34;
 while(1) {
  $36 = ($37|0)==(0|0);
  if (!($36)) {
   $38 = $37;
   $39 = $38;
   HEAP32[$39>>2] = 0;
   $40 = (($38) + 4)|0;
   $41 = $40;
   HEAP32[$41>>2] = 0;
  }
  $42 = (($37) + 8|0);
  $43 = (($$0$i2) + -1)|0;
  $44 = ($43|0)==(0);
  if ($44) {
   break;
  } else {
   $$0$i2 = $43;$37 = $42;
  }
 }
 $45 = (($35) + ($$0$i58<<3)|0);
 $scevgep$i4 = (($35) + ($23<<3)|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = HEAP32[$3>>2]|0;
 $48 = $47;
 $49 = $46;
 $50 = (($48) - ($49))|0;
 $51 = $50 >> 3;
 $$sum6 = (($22) - ($51))|0;
 $52 = (($35) + ($$sum6<<3)|0);
 _memcpy(($52|0),($46|0),($50|0))|0;
 $53 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $52;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $45;
 $54 = ($53|0)==(0|0);
 if ($54) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($53|0),($$byval_copy1|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  ___cxa_call_unexpected(($57|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1839,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i3 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i3;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i6 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i6;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
   $$pre$i$i$i = HEAP32[$34>>2]|0;
   $35 = $$pre$i$i$i;
  } else {
   $33 = HEAP32[$29>>2]|0;
   HEAP32[$34>>2] = $33;
   HEAP32[$1>>2] = $30;
   $35 = $33;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$34>>2] = $36;
  $37 = (($34) + 4|0);
  $38 = ($37|0)==($26|0);
  if ($38) {
   break;
  } else {
   $34 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0;
 var $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $88 = $$idx >> 2;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $109 = 0;$111 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<2)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $109 = $93;$111 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<2)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = HEAP32[$102>>2]|0;
        HEAP32[$100>>2] = $101;
       }
       $103 = (($100) + 4|0);
       $104 = (($102) + 4|0);
       $105 = ($104|0)==($87|0);
       if ($105) {
        break;
       } else {
        $100 = $103;$102 = $104;
       }
      }
      $106 = $uglygep6$i$i >>> 2;
      $107 = (($106) + 1)|0;
      $scevgep8$i$i = (($93) + ($107<<2)|0);
      $109 = $93;$111 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $117 = ___cxa_find_matching_catch()|0;
    $118 = tempRet0;
    $$0 = $118;$$01 = $117;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $108 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $109;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $110 = (($v) + 8|0);
  HEAP32[$110>>2] = $111;
  $112 = ($108|0)==(0|0);
  if ($112) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($108|0),($$byval_copy7|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   ___cxa_call_unexpected(($115|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 2;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 2;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<2)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 2;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<2)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1751,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 2;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2892,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<2)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -4|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 2;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<2)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -4|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 2;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<2)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -4|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 2;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<2)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1840,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
   $$pre$i$i$i = HEAP32[$34>>2]|0;
   $35 = $$pre$i$i$i;
  } else {
   $33 = HEAP32[$29>>2]|0;
   HEAP32[$34>>2] = $33;
   HEAP32[$1>>2] = $30;
   $35 = $33;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$34>>2] = $36;
  $37 = (($34) + 4|0);
  $38 = ($37|0)==($26|0);
  if ($38) {
   break;
  } else {
   $34 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0;
 var $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $88 = $$idx >> 2;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $109 = 0;$111 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<2)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $109 = $93;$111 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<2)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = HEAP32[$102>>2]|0;
        HEAP32[$100>>2] = $101;
       }
       $103 = (($100) + 4|0);
       $104 = (($102) + 4|0);
       $105 = ($104|0)==($87|0);
       if ($105) {
        break;
       } else {
        $100 = $103;$102 = $104;
       }
      }
      $106 = $uglygep6$i$i >>> 2;
      $107 = (($106) + 1)|0;
      $scevgep8$i$i = (($93) + ($107<<2)|0);
      $109 = $93;$111 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $117 = ___cxa_find_matching_catch()|0;
    $118 = tempRet0;
    $$0 = $118;$$01 = $117;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $108 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $109;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $110 = (($v) + 8|0);
  HEAP32[$110>>2] = $111;
  $112 = ($108|0)==(0|0);
  if ($112) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($108|0),($$byval_copy7|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   ___cxa_call_unexpected(($115|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 2;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 2;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<2)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 2;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<2)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1841,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 2;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2893,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<2)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -4|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 2;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<2)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -4|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 2;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<2)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -4|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 2;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<2)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPiEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIiNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $34 = $2;
   $35 = (($34) - ($4))|0;
   $36 = $35 >> 2;
   _memmove(($9|0),($1|0),($35|0))|0;
   $37 = (($9) + ($36<<2)|0);
   $38 = HEAP32[$15>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $37;
   $scevgep$i$i = (($38) + -4|0);
   $40 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($40)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $41 = $uglygep3$i$i >>> 2;
   $42 = $41 ^ -1;
   $scevgep4$i$i = (($38) + ($42<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<2)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -4|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 2;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = HEAP32[$29>>2]|0;
    HEAP32[$27>>2] = $28;
   }
   $30 = (($27) + 4|0);
   $31 = (($29) + 4|0);
   $32 = ($31|0)==($2|0);
   if ($32) {
    break;
   } else {
    $27 = $30;$29 = $31;
   }
  }
  $33 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($33<<2)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $43 = ($9|0)==(0|0);
 do {
  if ($43) {
   $56 = $8;
  } else {
   $44 = (($this) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==($9|0);
   if (!($46)) {
    $scevgep$i$i$i$i = (($45) + -4|0);
    $47 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($47)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $48 = $uglygep3$i$i$i$i >>> 2;
    $49 = $48 ^ -1;
    $scevgep4$i$i$i$i = (($45) + ($49<<2)|0);
    HEAP32[$44>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    ___cxa_call_unexpected(($52|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$44>>2] = 0;
    HEAP32[$this>>2] = 0;
    $56 = 0;
    break;
   }
  }
 } while(0);
 $54 = ($5|0)<(0);
 if ($54) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $55 = $56;
 $57 = $55 >> 2;
 $58 = ($57>>>0)<(1073741823);
 if ($58) {
  $59 = $55 >> 1;
  $60 = ($59>>>0)<($6>>>0);
  $61 = $60 ? $6 : $59;
  $62 = ($61|0)<(0);
  if ($62) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $61;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $63 = $$0$i37 << 2;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $64 = (__Z15malloc_internaljj10MemLabelIdiPKci($63,16,$$byval_copy1,0,630440,79)|0);
 $65 = (($this) + 4|0);
 HEAP32[$65>>2] = $64;
 HEAP32[$this>>2] = $64;
 $66 = (($64) + ($$0$i37<<2)|0);
 HEAP32[$7>>2] = $66;
 $67 = ($1|0)==($2|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -4|0);
 $68 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($68)|0);
 $uglygep6$i = $uglygep$i;
 $69 = $uglygep6$i >>> 2;
 $71 = $64;$73 = $1;
 while(1) {
  $70 = ($71|0)==(0|0);
  if (!($70)) {
   $72 = HEAP32[$73>>2]|0;
   HEAP32[$71>>2] = $72;
  }
  $74 = (($71) + 4|0);
  $75 = (($73) + 4|0);
  $76 = ($75|0)==($2|0);
  if ($76) {
   break;
  } else {
   $71 = $74;$73 = $75;
  }
 }
 $77 = (($69) + 1)|0;
 $scevgep8$i = (($64) + ($77<<2)|0);
 HEAP32[$65>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP32[$11>>2] = 0;
   }
   $12 = (($11) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<2)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy1,0,630440,79)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAP32[$33>>2] = 0;
  }
  $34 = (($33) + 4|0);
  $35 = (($$0$i2) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i2 = $35;$33 = $34;
  }
 }
 $37 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 $38 = HEAP32[$this>>2]|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = $39;
 $41 = $38;
 $42 = (($40) - ($41))|0;
 $43 = $42 >> 2;
 $$sum6 = (($18) - ($43))|0;
 $44 = (($31) + ($$sum6<<2)|0);
 _memcpy(($44|0),($38|0),($42|0))|0;
 $45 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $44;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $37;
 $46 = ($45|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($45|0),($$byval_copy1|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1842,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 1;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),2)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<1)|0);
      $50 = HEAP16[$49>>1]|0;
      HEAP16[$45>>1] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -2|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 1;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<1)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -2|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 1;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 1;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 2|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,2);
   $$pre$i$i$i = HEAP16[$34>>1]|0;
   $36 = $$pre$i$i$i;
  } else {
   $33 = HEAP16[$29>>1]|0;
   HEAP16[$34>>1] = $33;
   HEAP32[$1>>2] = $30;
   $36 = $33;
  }
  $35 = $36&65535;
  $37 = $35 << 8;
  $38 = $35 >>> 8;
  $39 = $37 | $38;
  $40 = $39&65535;
  HEAP16[$34>>1] = $40;
  $41 = (($34) + 2|0);
  $42 = ($41|0)==($26|0);
  if ($42) {
   break;
  } else {
   $34 = $41;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0;
 var $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 1;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<1)|0);
  $$idx = $sz << 1;
  $88 = $$idx >> 1;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $109 = 0;$111 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<1)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $109 = $93;$111 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<1)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = HEAP16[$102>>1]|0;
        HEAP16[$100>>1] = $101;
       }
       $103 = (($100) + 2|0);
       $104 = (($102) + 2|0);
       $105 = ($104|0)==($87|0);
       if ($105) {
        break;
       } else {
        $100 = $103;$102 = $104;
       }
      }
      $106 = $uglygep6$i$i >>> 1;
      $107 = (($106) + 1)|0;
      $scevgep8$i$i = (($93) + ($107<<1)|0);
      $109 = $93;$111 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $117 = ___cxa_find_matching_catch()|0;
    $118 = tempRet0;
    $$0 = $118;$$01 = $117;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $108 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $109;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $110 = (($v) + 8|0);
  HEAP32[$110>>2] = $111;
  $112 = ($108|0)==(0|0);
  if ($112) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($108|0),($$byval_copy7|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   ___cxa_call_unexpected(($115|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 1;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 1;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<1)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 1;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<1)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1843,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 1;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2894,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<1)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -2|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 1;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<1)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -2|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 1;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<1)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -2|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 1;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<1)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPtEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleItNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 1;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $34 = $2;
   $35 = (($34) - ($4))|0;
   $36 = $35 >> 1;
   _memmove(($9|0),($1|0),($35|0))|0;
   $37 = (($9) + ($36<<1)|0);
   $38 = HEAP32[$15>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $37;
   $scevgep$i$i = (($38) + -2|0);
   $40 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($40)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $41 = $uglygep3$i$i >>> 1;
   $42 = $41 ^ -1;
   $scevgep4$i$i = (($38) + ($42<<1)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<1)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -2|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 1;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = HEAP16[$29>>1]|0;
    HEAP16[$27>>1] = $28;
   }
   $30 = (($27) + 2|0);
   $31 = (($29) + 2|0);
   $32 = ($31|0)==($2|0);
   if ($32) {
    break;
   } else {
    $27 = $30;$29 = $31;
   }
  }
  $33 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($33<<1)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $43 = ($9|0)==(0|0);
 do {
  if ($43) {
   $56 = $8;
  } else {
   $44 = (($this) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==($9|0);
   if (!($46)) {
    $scevgep$i$i$i$i = (($45) + -2|0);
    $47 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($47)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $48 = $uglygep3$i$i$i$i >>> 1;
    $49 = $48 ^ -1;
    $scevgep4$i$i$i$i = (($45) + ($49<<1)|0);
    HEAP32[$44>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    ___cxa_call_unexpected(($52|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$44>>2] = 0;
    HEAP32[$this>>2] = 0;
    $56 = 0;
    break;
   }
  }
 } while(0);
 $54 = ($5|0)<(0);
 if ($54) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $55 = $56;
 $57 = $55 >> 1;
 $58 = ($57>>>0)<(1073741823);
 if ($58) {
  $59 = ($55>>>0)<($6>>>0);
  $60 = $59 ? $6 : $55;
  $61 = ($60|0)<(0);
  if ($61) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $60;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $62 = $$0$i37 << 1;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $63 = (__Z15malloc_internaljj10MemLabelIdiPKci($62,16,$$byval_copy1,0,630440,79)|0);
 $64 = (($this) + 4|0);
 HEAP32[$64>>2] = $63;
 HEAP32[$this>>2] = $63;
 $65 = (($63) + ($$0$i37<<1)|0);
 HEAP32[$7>>2] = $65;
 $66 = ($1|0)==($2|0);
 if ($66) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -2|0);
 $67 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($67)|0);
 $uglygep6$i = $uglygep$i;
 $68 = $uglygep6$i >>> 1;
 $70 = $63;$72 = $1;
 while(1) {
  $69 = ($70|0)==(0|0);
  if (!($69)) {
   $71 = HEAP16[$72>>1]|0;
   HEAP16[$70>>1] = $71;
  }
  $73 = (($70) + 2|0);
  $74 = (($72) + 2|0);
  $75 = ($74|0)==($2|0);
  if ($75) {
   break;
  } else {
   $70 = $73;$72 = $74;
  }
 }
 $76 = (($68) + 1)|0;
 $scevgep8$i = (($63) + ($76<<1)|0);
 HEAP32[$64>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1844,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 1;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),2)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<1)|0);
      $50 = HEAP16[$49>>1]|0;
      HEAP16[$45>>1] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -2|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 1;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<1)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -2|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 1;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 1;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 2|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,2);
   $$pre$i$i$i = HEAP16[$34>>1]|0;
   $36 = $$pre$i$i$i;
  } else {
   $33 = HEAP16[$29>>1]|0;
   HEAP16[$34>>1] = $33;
   HEAP32[$1>>2] = $30;
   $36 = $33;
  }
  $35 = $36&65535;
  $37 = $35 << 8;
  $38 = $35 >>> 8;
  $39 = $37 | $38;
  $40 = $39&65535;
  HEAP16[$34>>1] = $40;
  $41 = (($34) + 2|0);
  $42 = ($41|0)==($26|0);
  if ($42) {
   break;
  } else {
   $34 = $41;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre44 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $phitmp = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0;
 var $scevgep4$i$i$i$i$i24 = 0, $scevgep8$i$i = 0, $scevgep8$i$i42 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 1;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<1)|0);
  $$idx = $sz << 1;
  $88 = $$idx >> 1;
  $89 = ($88|0)==(0);
  do {
   if ($89) {
    $109 = 0;$111 = 0;$scevgep8$i$i42 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<1)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $109 = $93;$111 = $96;$scevgep8$i$i42 = $93;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($7) + ($$sum<<1)|0);
      $98 = (0 - ($9))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($98)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $100 = $93;$102 = $7;
      while(1) {
       $99 = ($100|0)==(0|0);
       if (!($99)) {
        $101 = HEAP16[$102>>1]|0;
        HEAP16[$100>>1] = $101;
       }
       $103 = (($100) + 2|0);
       $104 = (($102) + 2|0);
       $105 = ($104|0)==($87|0);
       if ($105) {
        break;
       } else {
        $100 = $103;$102 = $104;
       }
      }
      $106 = $uglygep6$i$i >>> 1;
      $107 = (($106) + 1)|0;
      $scevgep8$i$i = (($93) + ($107<<1)|0);
      $109 = $93;$111 = $96;$scevgep8$i$i42 = $scevgep8$i$i;
      break;
     }
    }
    $117 = ___cxa_find_matching_catch()|0;
    $118 = tempRet0;
    $$0 = $118;$$01 = $117;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $108 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $109;
  HEAP32[$5>>2] = $scevgep8$i$i42;
  $110 = (($v) + 8|0);
  HEAP32[$110>>2] = $111;
  $112 = ($108|0)==(0|0);
  if ($112) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($108|0),($$byval_copy7|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   ___cxa_call_unexpected(($115|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 1;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 1;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<1)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 1;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<1)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1845,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 1;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(2895,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre44 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre44;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<1)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -2|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 1;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<1)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i10 = $57;
     $scevgep$i$i$i$i$i11 = (($59) + -2|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i10))|0;
     $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($65)|0);
     $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
     $66 = $uglygep3$i$i$i$i$i14 >>> 1;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i15 = (($59) + ($67<<1)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i15;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i19 = $74;
  $scevgep$i$i$i$i$i20 = (($76) + -2|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i19))|0;
  $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($78)|0);
  $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
  $79 = $uglygep3$i$i$i$i$i23 >>> 1;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i24 = (($76) + ($80<<1)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i24;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPsEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIsNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$promoted$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i14 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i21 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i16 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 1;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $34 = $2;
   $35 = (($34) - ($4))|0;
   $36 = $35 >> 1;
   _memmove(($9|0),($1|0),($35|0))|0;
   $37 = (($9) + ($36<<1)|0);
   $38 = HEAP32[$15>>2]|0;
   $39 = ($38|0)==($37|0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $37;
   $scevgep$i$i = (($38) + -2|0);
   $40 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($40)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $41 = $uglygep3$i$i >>> 1;
   $42 = $41 ^ -1;
   $scevgep4$i$i = (($38) + ($42<<1)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + ($19<<1)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = $21;
  $$promoted$i12 = HEAP32[$15>>2]|0;
  $scevgep$i14 = (($2) + -2|0);
  $24 = (0 - ($23))|0;
  $uglygep$i16 = (($scevgep$i14) + ($24)|0);
  $uglygep6$i17 = $uglygep$i16;
  $25 = $uglygep6$i17 >>> 1;
  $27 = $$promoted$i12;$29 = $21;
  while(1) {
   $26 = ($27|0)==(0|0);
   if (!($26)) {
    $28 = HEAP16[$29>>1]|0;
    HEAP16[$27>>1] = $28;
   }
   $30 = (($27) + 2|0);
   $31 = (($29) + 2|0);
   $32 = ($31|0)==($2|0);
   if ($32) {
    break;
   } else {
    $27 = $30;$29 = $31;
   }
  }
  $33 = (($25) + 1)|0;
  $scevgep8$i21 = (($$promoted$i12) + ($33<<1)|0);
  HEAP32[$15>>2] = $scevgep8$i21;
  STACKTOP = sp;return;
 }
 $43 = ($9|0)==(0|0);
 do {
  if ($43) {
   $56 = $8;
  } else {
   $44 = (($this) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==($9|0);
   if (!($46)) {
    $scevgep$i$i$i$i = (($45) + -2|0);
    $47 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($47)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $48 = $uglygep3$i$i$i$i >>> 1;
    $49 = $48 ^ -1;
    $scevgep4$i$i$i$i = (($45) + ($49<<1)|0);
    HEAP32[$44>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    ___cxa_call_unexpected(($52|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$44>>2] = 0;
    HEAP32[$this>>2] = 0;
    $56 = 0;
    break;
   }
  }
 } while(0);
 $54 = ($5|0)<(0);
 if ($54) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $55 = $56;
 $57 = $55 >> 1;
 $58 = ($57>>>0)<(1073741823);
 if ($58) {
  $59 = ($55>>>0)<($6>>>0);
  $60 = $59 ? $6 : $55;
  $61 = ($60|0)<(0);
  if ($61) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $60;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $62 = $$0$i37 << 1;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $63 = (__Z15malloc_internaljj10MemLabelIdiPKci($62,16,$$byval_copy1,0,630440,79)|0);
 $64 = (($this) + 4|0);
 HEAP32[$64>>2] = $63;
 HEAP32[$this>>2] = $63;
 $65 = (($63) + ($$0$i37<<1)|0);
 HEAP32[$7>>2] = $65;
 $66 = ($1|0)==($2|0);
 if ($66) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($2) + -2|0);
 $67 = (0 - ($4))|0;
 $uglygep$i = (($scevgep$i) + ($67)|0);
 $uglygep6$i = $uglygep$i;
 $68 = $uglygep6$i >>> 1;
 $70 = $63;$72 = $1;
 while(1) {
  $69 = ($70|0)==(0|0);
  if (!($69)) {
   $71 = HEAP16[$72>>1]|0;
   HEAP16[$70>>1] = $71;
  }
  $73 = (($70) + 2|0);
  $74 = (($72) + 2|0);
  $75 = ($74|0)==($2|0);
  if ($75) {
   break;
  } else {
   $70 = $73;$72 = $74;
  }
 }
 $76 = (($68) + 1)|0;
 $scevgep8$i = (($63) + ($76<<1)|0);
 HEAP32[$64>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP16[$11>>1] = 0;
   }
   $12 = (($11) + 2|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<1)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 1;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 1;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = ($21>>>0)<($19>>>0);
  $25 = $24 ? $19 : $21;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 1;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($27,16,$$byval_copy1,0,630440,79)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($18<<1)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP16[$32>>1] = 0;
  }
  $33 = (($32) + 2|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<1)|0);
 $scevgep$i4 = (($30) + ($19<<1)|0);
 $37 = HEAP32[$this>>2]|0;
 $38 = HEAP32[$3>>2]|0;
 $39 = $38;
 $40 = $37;
 $41 = (($39) - ($40))|0;
 $42 = $41 >> 1;
 $$sum6 = (($18) - ($42))|0;
 $43 = (($30) + ($$sum6<<1)|0);
 _memcpy(($43|0),($37|0),($41|0))|0;
 $44 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $43;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $36;
 $45 = ($44|0)==(0|0);
 if ($45) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($44|0),($$byval_copy1|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIhEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, $index$01$i = 0, $index$08 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1846,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 5;
  } else {
   __THREW__ = 0;
   invoke_vi(3377,($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 5;
   } else {
    $23 = (($runtimeInfo) + 20|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($staticInfo) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$1>>2]|0;
    $28 = HEAP32[$buffer>>2]|0;
    $29 = $27;
    $30 = $28;
    $31 = (($29) - ($30))|0;
    $32 = (($24) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==($31|0);
    if (!($34)) {
     __THREW__ = 0;
     $35 = (invoke_ii(3288,($26|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 5;
      break;
     }
     __THREW__ = 0;
     $38 = (invoke_iiii(1554,($26|0),($35|0),($31|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 5;
      break;
     }
     HEAP32[$24>>2] = $38;
     HEAP32[$32>>2] = $31;
    }
    $41 = ($27|0)==($28|0);
    L9: do {
     if (!($41)) {
      $index$01$i = 0;
      while(1) {
       $42 = HEAP32[$24>>2]|0;
       __THREW__ = 0;
       $43 = (invoke_iiii(1555,($42|0),($index$01$i|0),1)|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
       $46 = HEAP32[$buffer>>2]|0;
       $47 = (($46) + ($index$01$i)|0);
       $48 = HEAP8[$47>>0]|0;
       HEAP8[$43>>0] = $48;
       $49 = (($index$01$i) + 1)|0;
       $50 = ($49|0)==($31|0);
       if ($50) {
        break L9;
       } else {
        $index$01$i = $49;
       }
      }
      $11 = ___cxa_find_matching_catch()|0;
      $12 = tempRet0;
      $lpad$phi$index = $11;$lpad$phi$index3 = $12;
      break L1;
     }
    } while(0);
    $51 = HEAP32[$23>>2]|0;
    $52 = (($51) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0);
    L16: do {
     if (!($54)) {
      $index$08 = 0;
      while(1) {
       __THREW__ = 0;
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
       $57 = (($index$08) + 1)|0;
       $58 = HEAP32[$23>>2]|0;
       $59 = (($58) + 4|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ($57|0)==($60|0);
       if ($61) {
        break L16;
       } else {
        $index$08 = $57;
       }
      }
      $9 = ___cxa_find_matching_catch()|0;
      $10 = tempRet0;
      $lpad$phi$index = $9;$lpad$phi$index3 = $10;
      break L1;
     }
    } while(0);
    $62 = HEAP32[$buffer>>2]|0;
    $63 = ($62|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = HEAP32[$1>>2]|0;
    $65 = ($64|0)==($62|0);
    if (!($65)) {
     HEAP32[$1>>2] = $62;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($62|0),($$byval_copy8|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     $68 = ___cxa_find_matching_catch()|0;
     $69 = tempRet0;
     ___cxa_call_unexpected(($68|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 }
 $15 = HEAP32[$buffer>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ($17|0)==($15|0);
 if (!($18)) {
  HEAP32[$1>>2] = $15;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($15|0),($$byval_copy8|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  ___cxa_call_unexpected(($21|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$20 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$20 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $22 = $$pre$i$i$i4;
 } else {
  $21 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $21;
  HEAP32[$1>>2] = $6;
  $22 = $21;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$size1>>2] = $23;
 __Z14resize_trimmedINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$23);
 $24 = (($data) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$data>>2]|0;
 $27 = ($26|0)==($25|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $33 = $26;
 }
 while(1) {
  $28 = HEAP32[$1>>2]|0;
  $29 = (($28) + 1|0);
  $30 = HEAP32[$7>>2]|0;
  $31 = ($29>>>0)>($30>>>0);
  if ($31) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$33,1);
  } else {
   $32 = HEAP8[$28>>0]|0;
   HEAP8[$33>>0] = $32;
   $34 = HEAP32[$1>>2]|0;
   $35 = (($34) + 1|0);
   HEAP32[$1>>2] = $35;
  }
  $36 = (($33) + 1|0);
  $37 = ($36|0)==($25|0);
  if ($37) {
   break;
  } else {
   $33 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre20 = 0, $$pre21 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $72 = ($10>>>0)>($sz>>>0);
  if (!($72)) {
   STACKTOP = sp;return;
  }
  $73 = (($7) + ($sz)|0);
  $74 = ($sz|0)==(0);
  do {
   if ($74) {
    $90 = 0;$91 = 0;$93 = 0;$95 = $7;
   } else {
    $75 = ($sz|0)<(0);
    if ($75) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if (!($77)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $78 = (invoke_iiiiiii(102,($sz|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      $82 = $78;$84 = $7;
      while(1) {
       $81 = ($82|0)==(0|0);
       if ($81) {
        $86 = 0;
       } else {
        $83 = HEAP8[$84>>0]|0;
        HEAP8[$82>>0] = $83;
        $86 = $82;
       }
       $85 = (($86) + 1|0);
       $87 = (($84) + 1|0);
       $88 = ($87|0)==($73|0);
       if ($88) {
        break;
       } else {
        $82 = $85;$84 = $87;
       }
      }
      $89 = (($78) + ($sz)|0);
      $$pre = HEAP32[$v>>2]|0;
      $90 = $78;$91 = $85;$93 = $89;$95 = $$pre;
      break;
     }
    }
    $100 = ___cxa_find_matching_catch()|0;
    $101 = tempRet0;
    $$0 = $101;$$01 = $100;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $90;
  HEAP32[$5>>2] = $91;
  $92 = (($v) + 8|0);
  HEAP32[$92>>2] = $93;
  $94 = ($95|0)==(0|0);
  if ($94) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($95|0),($$byval_copy7|0));
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   $98 = ___cxa_find_matching_catch()|0;
   $99 = tempRet0;
   ___cxa_call_unexpected(($98|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($9))|0;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $71 = (($sz) - ($10))|0;
  __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$71);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = ($sz|0)==(0);
 if ($19) {
  label = 8;
 } else {
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (invoke_iiiiiii(102,($sz|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$17>>2]|0;
   $phitmp = $$pre1$i;
   $23 = (($20) + ($sz)|0);
   $24 = $$pre$i;
   $25 = (($phitmp) - ($24))|0;
   $$sum$i = (0 - ($25))|0;
   $26 = (($20) + ($$sum$i)|0);
   _memcpy(($26|0),($$pre$i|0),($25|0))|0;
   $27 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $26;
   HEAP32[$17>>2] = $20;
   HEAP32[$18>>2] = $23;
   $28 = ($27|0)==(0|0);
   if ($28) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy7|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $33 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $33;
   $34 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $34;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1847,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    $37 = HEAP32[$17>>2]|0;
    $38 = HEAP32[$temp>>2]|0;
    $39 = $37;
    $40 = $38;
    $41 = (($39) - ($40))|0;
    $42 = ($41>>>0)<($sz>>>0);
    if ($42) {
     $43 = (($sz) - ($41))|0;
     __THREW__ = 0;
     invoke_vii(2896,($temp|0),($43|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     $$pre20 = HEAP32[$temp>>2]|0;
     $$pre21 = HEAP32[$17>>2]|0;
     $50 = $$pre20;$52 = $$pre21;
    } else {
     $46 = ($41>>>0)>($sz>>>0);
     if ($46) {
      $47 = (($38) + ($sz)|0);
      $48 = ($37|0)==($47|0);
      if ($48) {
       $50 = $38;$52 = $37;
      } else {
       HEAP32[$17>>2] = $47;
       $50 = $38;$52 = $47;
      }
     } else {
      $50 = $38;$52 = $37;
     }
    }
    $49 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $49;
    HEAP32[$v>>2] = $50;
    $51 = HEAP32[$5>>2]|0;
    HEAP32[$17>>2] = $51;
    HEAP32[$5>>2] = $52;
    $53 = HEAP32[$18>>2]|0;
    $54 = HEAP32[$12>>2]|0;
    HEAP32[$18>>2] = $54;
    HEAP32[$12>>2] = $53;
    $55 = ($49|0)==(0|0);
    if ($55) {
     STACKTOP = sp;return;
    }
    $56 = ($51|0)==($49|0);
    if (!($56)) {
     HEAP32[$17>>2] = $49;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($49|0),($$byval_copy7|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $59 = ___cxa_find_matching_catch()|0;
     $60 = tempRet0;
     ___cxa_call_unexpected(($59|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $61 = ___cxa_find_matching_catch()|0;
 $62 = tempRet0;
 $63 = HEAP32[$temp>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  $$0 = $62;$$01 = $61;
  ___resumeException($$01|0);
  // unreachable;
 }
 $65 = HEAP32[$17>>2]|0;
 $66 = ($65|0)==($63|0);
 if (!($66)) {
  HEAP32[$17>>2] = $63;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($63|0),($$byval_copy7|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  ___cxa_call_unexpected(($69|0));
  // unreachable;
 } else {
  $$0 = $62;$$01 = $61;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPhEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$byval_copy1 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = ($5>>>0)>($11>>>0);
 if (!($12)) {
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14;
  $16 = (($15) - ($10))|0;
  $17 = ($5>>>0)>($16>>>0);
  if (!($17)) {
   $28 = $2;
   $29 = (($28) - ($4))|0;
   _memmove(($8|0),($1|0),($29|0))|0;
   $30 = (($8) + ($29)|0);
   $31 = HEAP32[$13>>2]|0;
   $32 = ($31|0)==($30|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   HEAP32[$13>>2] = $30;
   STACKTOP = sp;return;
  }
  $18 = (($1) + ($16)|0);
  _memmove(($8|0),($1|0),($16|0))|0;
  $19 = ($18|0)==($2|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$13>>2]|0;
  $21 = $$pre$i12;$23 = $18;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $25 = 0;
   } else {
    $22 = HEAP8[$23>>0]|0;
    HEAP8[$21>>0] = $22;
    $$pre1$i14 = HEAP32[$13>>2]|0;
    $25 = $$pre1$i14;
   }
   $24 = (($25) + 1|0);
   HEAP32[$13>>2] = $24;
   $26 = (($23) + 1|0);
   $27 = ($26|0)==($2|0);
   if ($27) {
    break;
   } else {
    $21 = $24;$23 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 $33 = ($8|0)==(0|0);
 do {
  if ($33) {
   $43 = $7;
  } else {
   $34 = (($this) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($8|0);
   if (!($36)) {
    HEAP32[$34>>2] = $8;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy1|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    ___cxa_call_unexpected(($39|0));
    // unreachable;
   } else {
    HEAP32[$6>>2] = 0;
    HEAP32[$34>>2] = 0;
    HEAP32[$this>>2] = 0;
    $43 = 0;
    break;
   }
  }
 } while(0);
 $41 = ($5|0)<(0);
 if ($41) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $42 = ($43>>>0)<((1073741823)>>>0);
 if ($42) {
  $44 = $43;
  $45 = $44 << 1;
  $46 = ($45>>>0)<($5>>>0);
  $47 = $46 ? $5 : $45;
  $48 = ($47|0)<(0);
  if ($48) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i31 = $47;
  }
 } else {
  $$0$i31 = 2147483647;
 }
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $49 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i31,16,$$byval_copy1,0,630440,79)|0);
 $50 = (($this) + 4|0);
 HEAP32[$50>>2] = $49;
 HEAP32[$this>>2] = $49;
 $51 = (($49) + ($$0$i31)|0);
 HEAP32[$6>>2] = $51;
 $52 = ($1|0)==($2|0);
 if ($52) {
  STACKTOP = sp;return;
 } else {
  $54 = $49;$56 = $1;
 }
 while(1) {
  $53 = ($54|0)==(0|0);
  if ($53) {
   $58 = 0;
  } else {
   $55 = HEAP8[$56>>0]|0;
   HEAP8[$54>>0] = $55;
   $$pre1$i = HEAP32[$50>>2]|0;
   $58 = $$pre1$i;
  }
  $57 = (($58) + 1|0);
  HEAP32[$50>>2] = $57;
  $59 = (($56) + 1|0);
  $60 = ($59|0)==($2|0);
  if ($60) {
   break;
  } else {
   $54 = $57;$56 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $4;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    HEAP8[$10>>0] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 1|0);
   HEAP32[$3>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = (($17) + ($__n))|0;
 $19 = ($18|0)<(0);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($5) - ($16))|0;
 $21 = ($20>>>0)<(1073741823);
 if ($21) {
  $22 = $20 << 1;
  $23 = ($22>>>0)<($18>>>0);
  $24 = $23 ? $18 : $22;
  $25 = ($24|0)==(0);
  if ($25) {
   $$0$i57 = 0;$28 = 0;
  } else {
   $$0$i56 = $24;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i56,16,$$byval_copy1,0,630440,79)|0);
  $$0$i57 = $$0$i56;$28 = $26;
 }
 $27 = (($28) + ($17)|0);
 $$0$i2 = $__n;$30 = $27;
 while(1) {
  $29 = ($30|0)==(0|0);
  if ($29) {
   $32 = 0;
  } else {
   HEAP8[$30>>0] = 0;
   $32 = $30;
  }
  $31 = (($32) + 1|0);
  $33 = (($$0$i2) + -1)|0;
  $34 = ($33|0)==(0);
  if ($34) {
   break;
  } else {
   $$0$i2 = $33;$30 = $31;
  }
 }
 $35 = (($28) + ($$0$i57)|0);
 $36 = HEAP32[$this>>2]|0;
 $37 = HEAP32[$3>>2]|0;
 $38 = $37;
 $39 = $36;
 $40 = (($38) - ($39))|0;
 $$sum = (($17) - ($40))|0;
 $41 = (($28) + ($$sum)|0);
 _memcpy(($41|0),($36|0),($40|0))|0;
 $42 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $41;
 HEAP32[$3>>2] = $31;
 HEAP32[$1>>2] = $35;
 $43 = ($42|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($42|0),($$byval_copy1|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE19Converter_PrimitiveIaEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, $index$01$i = 0, $index$06 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1848,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $21 = (($runtimeInfo) + 20|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($staticInfo) + 28|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$1>>2]|0;
   $26 = HEAP32[$buffer>>2]|0;
   $27 = $25;
   $28 = $26;
   $29 = (($27) - ($28))|0;
   $30 = (($22) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($29|0);
   if (!($32)) {
    __THREW__ = 0;
    $33 = (invoke_ii(3288,($24|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $36 = (invoke_iiii(1554,($24|0),($33|0),($29|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 4;
     break;
    }
    HEAP32[$22>>2] = $36;
    HEAP32[$30>>2] = $29;
   }
   $39 = ($25|0)==($26|0);
   L8: do {
    if (!($39)) {
     $index$01$i = 0;
     while(1) {
      $40 = HEAP32[$22>>2]|0;
      __THREW__ = 0;
      $41 = (invoke_iiii(1555,($40|0),($index$01$i|0),1)|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      }
      $44 = HEAP32[$buffer>>2]|0;
      $45 = (($44) + ($index$01$i)|0);
      $46 = HEAP8[$45>>0]|0;
      HEAP8[$41>>0] = $46;
      $47 = (($index$01$i) + 1)|0;
      $48 = ($47|0)==($29|0);
      if ($48) {
       break L8;
      } else {
       $index$01$i = $47;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $49 = HEAP32[$21>>2]|0;
   $50 = (($49) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0);
   L15: do {
    if (!($52)) {
     $index$06 = 0;
     while(1) {
      __THREW__ = 0;
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = (($index$06) + 1)|0;
      $56 = HEAP32[$21>>2]|0;
      $57 = (($56) + 4|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($55|0)==($58|0);
      if ($59) {
       break L15;
      } else {
       $index$06 = $55;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $60 = HEAP32[$buffer>>2]|0;
   $61 = ($60|0)==(0|0);
   if ($61) {
    STACKTOP = sp;return;
   }
   $62 = HEAP32[$1>>2]|0;
   $63 = ($62|0)==($60|0);
   if (!($63)) {
    HEAP32[$1>>2] = $60;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy8|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $66 = ___cxa_find_matching_catch()|0;
    $67 = tempRet0;
    ___cxa_call_unexpected(($66|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  HEAP32[$1>>2] = $13;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  ___cxa_call_unexpected(($19|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$20 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$20 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $22 = $$pre$i$i$i4;
 } else {
  $21 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $21;
  HEAP32[$1>>2] = $6;
  $22 = $21;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$size1>>2] = $23;
 __Z14resize_trimmedINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$23);
 $24 = (($data) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$data>>2]|0;
 $27 = ($26|0)==($25|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $33 = $26;
 }
 while(1) {
  $28 = HEAP32[$1>>2]|0;
  $29 = (($28) + 1|0);
  $30 = HEAP32[$7>>2]|0;
  $31 = ($29>>>0)>($30>>>0);
  if ($31) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$33,1);
  } else {
   $32 = HEAP8[$28>>0]|0;
   HEAP8[$33>>0] = $32;
   $34 = HEAP32[$1>>2]|0;
   $35 = (($34) + 1|0);
   HEAP32[$1>>2] = $35;
  }
  $36 = (($33) + 1|0);
  $37 = ($36|0)==($25|0);
  if ($37) {
   break;
  } else {
   $33 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre20 = 0, $$pre21 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $72 = ($10>>>0)>($sz>>>0);
  if (!($72)) {
   STACKTOP = sp;return;
  }
  $73 = (($7) + ($sz)|0);
  $74 = ($sz|0)==(0);
  do {
   if ($74) {
    $90 = 0;$91 = 0;$93 = 0;$95 = $7;
   } else {
    $75 = ($sz|0)<(0);
    if ($75) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if (!($77)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $78 = (invoke_iiiiiii(102,($sz|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      $82 = $78;$84 = $7;
      while(1) {
       $81 = ($82|0)==(0|0);
       if ($81) {
        $86 = 0;
       } else {
        $83 = HEAP8[$84>>0]|0;
        HEAP8[$82>>0] = $83;
        $86 = $82;
       }
       $85 = (($86) + 1|0);
       $87 = (($84) + 1|0);
       $88 = ($87|0)==($73|0);
       if ($88) {
        break;
       } else {
        $82 = $85;$84 = $87;
       }
      }
      $89 = (($78) + ($sz)|0);
      $$pre = HEAP32[$v>>2]|0;
      $90 = $78;$91 = $85;$93 = $89;$95 = $$pre;
      break;
     }
    }
    $100 = ___cxa_find_matching_catch()|0;
    $101 = tempRet0;
    $$0 = $101;$$01 = $100;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $90;
  HEAP32[$5>>2] = $91;
  $92 = (($v) + 8|0);
  HEAP32[$92>>2] = $93;
  $94 = ($95|0)==(0|0);
  if ($94) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($95|0),($$byval_copy7|0));
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   $98 = ___cxa_find_matching_catch()|0;
   $99 = tempRet0;
   ___cxa_call_unexpected(($98|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($9))|0;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $71 = (($sz) - ($10))|0;
  __ZNSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEE8__appendEj($v,$71);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = ($sz|0)==(0);
 if ($19) {
  label = 8;
 } else {
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (invoke_iiiiiii(102,($sz|0),16,($$byval_copy7|0),0,(630440|0),79)|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$17>>2]|0;
   $phitmp = $$pre1$i;
   $23 = (($20) + ($sz)|0);
   $24 = $$pre$i;
   $25 = (($phitmp) - ($24))|0;
   $$sum$i = (0 - ($25))|0;
   $26 = (($20) + ($$sum$i)|0);
   _memcpy(($26|0),($$pre$i|0),($25|0))|0;
   $27 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $26;
   HEAP32[$17>>2] = $20;
   HEAP32[$18>>2] = $23;
   $28 = ($27|0)==(0|0);
   if ($28) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy7|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $33 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $33;
   $34 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $34;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1849,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    $37 = HEAP32[$17>>2]|0;
    $38 = HEAP32[$temp>>2]|0;
    $39 = $37;
    $40 = $38;
    $41 = (($39) - ($40))|0;
    $42 = ($41>>>0)<($sz>>>0);
    if ($42) {
     $43 = (($sz) - ($41))|0;
     __THREW__ = 0;
     invoke_vii(2897,($temp|0),($43|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     $$pre20 = HEAP32[$temp>>2]|0;
     $$pre21 = HEAP32[$17>>2]|0;
     $50 = $$pre20;$52 = $$pre21;
    } else {
     $46 = ($41>>>0)>($sz>>>0);
     if ($46) {
      $47 = (($38) + ($sz)|0);
      $48 = ($37|0)==($47|0);
      if ($48) {
       $50 = $38;$52 = $37;
      } else {
       HEAP32[$17>>2] = $47;
       $50 = $38;$52 = $47;
      }
     } else {
      $50 = $38;$52 = $37;
     }
    }
    $49 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $49;
    HEAP32[$v>>2] = $50;
    $51 = HEAP32[$5>>2]|0;
    HEAP32[$17>>2] = $51;
    HEAP32[$5>>2] = $52;
    $53 = HEAP32[$18>>2]|0;
    $54 = HEAP32[$12>>2]|0;
    HEAP32[$18>>2] = $54;
    HEAP32[$12>>2] = $53;
    $55 = ($49|0)==(0|0);
    if ($55) {
     STACKTOP = sp;return;
    }
    $56 = ($51|0)==($49|0);
    if (!($56)) {
     HEAP32[$17>>2] = $49;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($49|0),($$byval_copy7|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $59 = ___cxa_find_matching_catch()|0;
     $60 = tempRet0;
     ___cxa_call_unexpected(($59|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $61 = ___cxa_find_matching_catch()|0;
 $62 = tempRet0;
 $63 = HEAP32[$temp>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  $$0 = $62;$$01 = $61;
  ___resumeException($$01|0);
  // unreachable;
 }
 $65 = HEAP32[$17>>2]|0;
 $66 = ($65|0)==($63|0);
 if (!($66)) {
  HEAP32[$17>>2] = $63;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($63|0),($$byval_copy7|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  ___cxa_call_unexpected(($69|0));
  // unreachable;
 } else {
  $$0 = $62;$$01 = $61;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPaEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIaNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$byval_copy1 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = ($5>>>0)>($11>>>0);
 if (!($12)) {
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14;
  $16 = (($15) - ($10))|0;
  $17 = ($5>>>0)>($16>>>0);
  if (!($17)) {
   $28 = $2;
   $29 = (($28) - ($4))|0;
   _memmove(($8|0),($1|0),($29|0))|0;
   $30 = (($8) + ($29)|0);
   $31 = HEAP32[$13>>2]|0;
   $32 = ($31|0)==($30|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   HEAP32[$13>>2] = $30;
   STACKTOP = sp;return;
  }
  $18 = (($1) + ($16)|0);
  _memmove(($8|0),($1|0),($16|0))|0;
  $19 = ($18|0)==($2|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$13>>2]|0;
  $21 = $$pre$i12;$23 = $18;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $25 = 0;
   } else {
    $22 = HEAP8[$23>>0]|0;
    HEAP8[$21>>0] = $22;
    $$pre1$i14 = HEAP32[$13>>2]|0;
    $25 = $$pre1$i14;
   }
   $24 = (($25) + 1|0);
   HEAP32[$13>>2] = $24;
   $26 = (($23) + 1|0);
   $27 = ($26|0)==($2|0);
   if ($27) {
    break;
   } else {
    $21 = $24;$23 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 $33 = ($8|0)==(0|0);
 do {
  if ($33) {
   $43 = $7;
  } else {
   $34 = (($this) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($8|0);
   if (!($36)) {
    HEAP32[$34>>2] = $8;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy1|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    ___cxa_call_unexpected(($39|0));
    // unreachable;
   } else {
    HEAP32[$6>>2] = 0;
    HEAP32[$34>>2] = 0;
    HEAP32[$this>>2] = 0;
    $43 = 0;
    break;
   }
  }
 } while(0);
 $41 = ($5|0)<(0);
 if ($41) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $42 = ($43>>>0)<((1073741823)>>>0);
 if ($42) {
  $44 = $43;
  $45 = $44 << 1;
  $46 = ($45>>>0)<($5>>>0);
  $47 = $46 ? $5 : $45;
  $48 = ($47|0)<(0);
  if ($48) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i31 = $47;
  }
 } else {
  $$0$i31 = 2147483647;
 }
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $49 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i31,16,$$byval_copy1,0,630440,79)|0);
 $50 = (($this) + 4|0);
 HEAP32[$50>>2] = $49;
 HEAP32[$this>>2] = $49;
 $51 = (($49) + ($$0$i31)|0);
 HEAP32[$6>>2] = $51;
 $52 = ($1|0)==($2|0);
 if ($52) {
  STACKTOP = sp;return;
 } else {
  $54 = $49;$56 = $1;
 }
 while(1) {
  $53 = ($54|0)==(0|0);
  if ($53) {
   $58 = 0;
  } else {
   $55 = HEAP8[$56>>0]|0;
   HEAP8[$54>>0] = $55;
   $$pre1$i = HEAP32[$50>>2]|0;
   $58 = $$pre1$i;
  }
  $57 = (($58) + 1|0);
  HEAP32[$50>>2] = $57;
  $59 = (($56) + 1|0);
  $60 = ($59|0)==($2|0);
  if ($60) {
   break;
  } else {
   $54 = $57;$56 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $4;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    HEAP8[$10>>0] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 1|0);
   HEAP32[$3>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = (($17) + ($__n))|0;
 $19 = ($18|0)<(0);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($5) - ($16))|0;
 $21 = ($20>>>0)<(1073741823);
 if ($21) {
  $22 = $20 << 1;
  $23 = ($22>>>0)<($18>>>0);
  $24 = $23 ? $18 : $22;
  $25 = ($24|0)==(0);
  if ($25) {
   $$0$i57 = 0;$28 = 0;
  } else {
   $$0$i56 = $24;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i56,16,$$byval_copy1,0,630440,79)|0);
  $$0$i57 = $$0$i56;$28 = $26;
 }
 $27 = (($28) + ($17)|0);
 $$0$i2 = $__n;$30 = $27;
 while(1) {
  $29 = ($30|0)==(0|0);
  if ($29) {
   $32 = 0;
  } else {
   HEAP8[$30>>0] = 0;
   $32 = $30;
  }
  $31 = (($32) + 1|0);
  $33 = (($$0$i2) + -1)|0;
  $34 = ($33|0)==(0);
  if ($34) {
   break;
  } else {
   $$0$i2 = $33;$30 = $31;
  }
 }
 $35 = (($28) + ($$0$i57)|0);
 $36 = HEAP32[$this>>2]|0;
 $37 = HEAP32[$3>>2]|0;
 $38 = $37;
 $39 = $36;
 $40 = (($38) - ($39))|0;
 $$sum = (($17) - ($40))|0;
 $41 = (($28) + ($$sum)|0);
 _memcpy(($41|0),($36|0),($40|0))|0;
 $42 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $41;
 HEAP32[$3>>2] = $31;
 HEAP32[$1>>2] = $35;
 $43 = ($42|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($42|0),($$byval_copy1|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb1EE16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $index$01$i = 0, $index$013 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viii(1850,($5|0),($buffer|0),0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 4;
  } else {
   $36 = (($runtimeInfo) + 20|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($staticInfo) + 28|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$2>>2]|0;
   $41 = HEAP32[$buffer>>2]|0;
   $42 = $40;
   $43 = $41;
   $44 = (($42) - ($43))|0;
   $45 = (($44|0) / 12)&-1;
   $46 = (($37) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==($45|0);
   if (!($48)) {
    __THREW__ = 0;
    $49 = (invoke_ii(3288,($39|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $52 = (invoke_iiii(1554,($39|0),($49|0),($45|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 4;
     break;
    }
    HEAP32[$37>>2] = $52;
    HEAP32[$46>>2] = $45;
   }
   $55 = ($40|0)==($41|0);
   L8: do {
    if (!($55)) {
     $index$01$i = 0;
     while(1) {
      $56 = HEAP32[$37>>2]|0;
      __THREW__ = 0;
      $57 = (invoke_iii(2433,($56|0),($index$01$i|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      $60 = HEAP32[$buffer>>2]|0;
      $61 = (($60) + (($index$01$i*12)|0)|0);
      $62 = HEAP8[$61>>0]|0;
      $63 = $62 & 1;
      $64 = ($63<<24>>24)==(0);
      if ($64) {
       $67 = (($61) + 1|0);
       $68 = $67;
      } else {
       $65 = ((($60) + (($index$01$i*12)|0)|0) + 8|0);
       $66 = HEAP32[$65>>2]|0;
       $68 = $66;
      }
      __THREW__ = 0;
      $69 = (invoke_ii(3287,($68|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      HEAP32[$57>>2] = $69;
      $72 = (($index$01$i) + 1)|0;
      $73 = ($72|0)==($45|0);
      if ($73) {
       break L8;
      } else {
       $index$01$i = $72;
      }
     }
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index3 = $11;
     break L1;
    }
   } while(0);
   $74 = HEAP32[$36>>2]|0;
   $75 = (($74) + 4|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==(0);
   L20: do {
    if (!($77)) {
     $79 = $74;$index$013 = 0;
     while(1) {
      $78 = HEAP32[$79>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2433,($78|0),($index$013|0))|0);
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       break;
      }
      $82 = (($index$013) + 1)|0;
      $83 = HEAP32[$36>>2]|0;
      $84 = (($83) + 4|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ($82|0)==($85|0);
      if ($86) {
       break L20;
      } else {
       $79 = $83;$index$013 = $82;
      }
     }
     $8 = ___cxa_find_matching_catch()|0;
     $9 = tempRet0;
     $lpad$phi$index = $8;$lpad$phi$index3 = $9;
     break L1;
    }
   } while(0);
   $87 = HEAP32[$buffer>>2]|0;
   $88 = ($87|0)==(0|0);
   if ($88) {
    STACKTOP = sp;return;
   }
   $89 = HEAP32[$2>>2]|0;
   $90 = ($89|0)==($87|0);
   do {
    if ($90) {
     $104 = $87;
    } else {
     $92 = $89;
     while(1) {
      $91 = (($92) + -12|0);
      HEAP32[$2>>2] = $91;
      $93 = HEAP8[$91>>0]|0;
      $94 = $93 & 1;
      $95 = ($94<<24>>24)==(0);
      if ($95) {
       $97 = $91;
      } else {
       $98 = (($92) + -4|0);
       $99 = HEAP32[$98>>2]|0;
       HEAP32[$0>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($99|0),($$byval_copy10|0));
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        label = 38;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$2>>2]|0;
       $97 = $$pre$i$i$i$i$i$i$i;
      }
      $96 = ($97|0)==($87|0);
      if ($96) {
       label = 39;
       break;
      } else {
       $92 = $97;
      }
     }
     if ((label|0) == 38) {
      $102 = ___cxa_find_matching_catch()|0;
      $103 = tempRet0;
      ___cxa_call_unexpected(($102|0));
      // unreachable;
     }
     else if ((label|0) == 39) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $104 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($104|0),($$byval_copy10|0));
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    $107 = ___cxa_find_matching_catch()|0;
    $108 = tempRet0;
    ___cxa_call_unexpected(($107|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index3 = $13;
 }
 $14 = HEAP32[$buffer>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $16 = HEAP32[$2>>2]|0;
 $17 = ($16|0)==($14|0);
 do {
  if ($17) {
   $31 = $14;
  } else {
   $19 = $16;
   while(1) {
    $18 = (($19) + -12|0);
    HEAP32[$2>>2] = $18;
    $20 = HEAP8[$18>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $24 = $18;
    } else {
     $25 = (($19) + -4|0);
     $26 = HEAP32[$25>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($26|0),($$byval_copy10|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 12;
      break;
     }
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$2>>2]|0;
     $24 = $$pre$i$i$i$i$i$i$i3;
    }
    $23 = ($24|0)==($14|0);
    if ($23) {
     label = 13;
     break;
    } else {
     $19 = $24;
    }
   }
   if ((label|0) == 12) {
    $29 = ___cxa_find_matching_catch()|0;
    $30 = tempRet0;
    ___cxa_call_unexpected(($29|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $31 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy10|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN12NativeBufferI16Converter_StringE15SetupForWritingER9ArrayInfo($this,$inputArray) {
 $this = $this|0;
 $inputArray = $inputArray|0;
 var $$byval_copy = 0, $$pre$i$i$i = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($inputArray) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ($9>>>0)<($2>>>0);
 L1: do {
  if ($10) {
   $11 = (($2) - ($9))|0;
   __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE8__appendEj($this,$11);
  } else {
   $12 = ($9>>>0)>($2>>>0);
   if ($12) {
    $13 = (($5) + (($2*12)|0)|0);
    $14 = ($4|0)==($13|0);
    if (!($14)) {
     $16 = $4;
     while(1) {
      $15 = (($16) + -12|0);
      HEAP32[$3>>2] = $15;
      $17 = HEAP8[$15>>0]|0;
      $18 = $17 & 1;
      $19 = ($18<<24>>24)==(0);
      if ($19) {
       $21 = $15;
      } else {
       $23 = (($16) + -4|0);
       $24 = HEAP32[$23>>2]|0;
       HEAP32[$0>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($24|0),($$byval_copy|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       $$pre$i$i$i = HEAP32[$3>>2]|0;
       $21 = $$pre$i$i$i;
      }
      $20 = ($21|0)==($13|0);
      if ($20) {
       break L1;
      } else {
       $16 = $21;
      }
     }
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     ___cxa_call_unexpected(($27|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $22 = ($2|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $index$01 = 0;
 while(1) {
  $29 = HEAP32[$inputArray>>2]|0;
  $30 = (__ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi($29,$index$01)|0);
  $$val = HEAP32[$30>>2]|0;
  $31 = ($$val|0)==(0|0);
  if (!($31)) {
   $32 = HEAP32[$this>>2]|0;
   $33 = (($32) + (($index$01*12)|0)|0);
   __ZN16Converter_String17ScriptingToNativeEP15ScriptingObjectPNSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEE(0,$$val,$33);
  }
  $34 = (($index$01) + 1)|0;
  $35 = ($34|0)==($2|0);
  if ($35) {
   break;
  } else {
   $index$01 = $34;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorINS2_12basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES7_ISA_LS8_90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorINS0_12basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES5_IS8_LS6_90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$29,0);
   __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
   $30 = (($29) + 12|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorINS0_12basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES5_IS8_LS6_90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy24 = 0, $$idx = 0, $$pre = 0, $$pre$i$i$i$i$i14 = 0, $$pre$i$i$i$i$i22 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy24 = sp + 44|0;
 $$byval_copy = sp + 40|0;
 $0 = sp + 36|0;
 $1 = sp + 32|0;
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = sp + 16|0;
 $temp = sp + 4|0;
 $5 = sp;
 $6 = sp + 20|0;
 $7 = (($v) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$v>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($13>>>0)<($sz>>>0);
 if ($14) {
  $15 = (($v) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = (($18|0) / 12)&-1;
  $20 = ($19|0)==($sz|0);
  if ($20) {
   $105 = (($sz) - ($13))|0;
   __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE8__appendEj($v,$105);
   STACKTOP = sp;return;
  }
  HEAP32[$temp>>2] = 0;
  $21 = (($temp) + 4|0);
  HEAP32[$21>>2] = 0;
  $22 = (($temp) + 8|0);
  HEAP32[$22>>2] = 0;
  __THREW__ = 0;
  invoke_vii(2898,($temp|0),($sz|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  L7: do {
   if (!($24)) {
    $25 = HEAP32[$v>>2]|0;
    HEAP32[$5>>2] = $25;
    $26 = HEAP32[$7>>2]|0;
    HEAP32[$6>>2] = $26;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_viii(1851,($temp|0),($$byval_copy|0),($$byval_copy24|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = HEAP32[$21>>2]|0;
     $30 = HEAP32[$temp>>2]|0;
     $31 = $29;
     $32 = $30;
     $33 = (($31) - ($32))|0;
     $34 = (($33|0) / 12)&-1;
     $35 = ($34>>>0)<($sz>>>0);
     L10: do {
      if ($35) {
       $36 = (($sz) - ($34))|0;
       __THREW__ = 0;
       invoke_vii(2899,($temp|0),($36|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break L7;
       }
       $$pre = HEAP32[$21>>2]|0;
       $58 = $$pre;
      } else {
       $39 = ($34>>>0)>($sz>>>0);
       if ($39) {
        $40 = (($30) + (($sz*12)|0)|0);
        $41 = ($29|0)==($40|0);
        if ($41) {
         $58 = $29;
        } else {
         $43 = $29;
         while(1) {
          $42 = (($43) + -12|0);
          HEAP32[$21>>2] = $42;
          $44 = HEAP8[$42>>0]|0;
          $45 = $44 & 1;
          $46 = ($45<<24>>24)==(0);
          if ($46) {
           $48 = $42;
          } else {
           $49 = (($43) + -4|0);
           $50 = HEAP32[$49>>2]|0;
           HEAP32[$1>>2] = 90;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;
           invoke_vii(2591,($50|0),($$byval_copy24|0));
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if ($52) {
            break;
           }
           $$pre$i$i$i10 = HEAP32[$21>>2]|0;
           $48 = $$pre$i$i$i10;
          }
          $47 = ($48|0)==($40|0);
          if ($47) {
           $58 = $40;
           break L10;
          } else {
           $43 = $48;
          }
         }
         $53 = ___cxa_find_matching_catch()|0;
         $54 = tempRet0;
         ___cxa_call_unexpected(($53|0));
         // unreachable;
        }
       } else {
        $58 = $29;
       }
      }
     } while(0);
     $55 = HEAP32[$temp>>2]|0;
     $56 = HEAP32[$v>>2]|0;
     HEAP32[$temp>>2] = $56;
     HEAP32[$v>>2] = $55;
     $57 = HEAP32[$7>>2]|0;
     HEAP32[$21>>2] = $57;
     HEAP32[$7>>2] = $58;
     $59 = HEAP32[$22>>2]|0;
     $60 = HEAP32[$15>>2]|0;
     HEAP32[$22>>2] = $60;
     HEAP32[$15>>2] = $59;
     $61 = ($56|0)==(0|0);
     if ($61) {
      STACKTOP = sp;return;
     }
     $62 = ($57|0)==($56|0);
     do {
      if ($62) {
       $76 = $56;
      } else {
       $64 = $57;
       while(1) {
        $63 = (($64) + -12|0);
        HEAP32[$21>>2] = $63;
        $65 = HEAP8[$63>>0]|0;
        $66 = $65 & 1;
        $67 = ($66<<24>>24)==(0);
        if ($67) {
         $69 = $63;
        } else {
         $70 = (($64) + -4|0);
         $71 = HEAP32[$70>>2]|0;
         HEAP32[$$byval_copy>>2] = 90;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
         invoke_vii(2591,($71|0),($$byval_copy24|0));
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          label = 23;
          break;
         }
         $$pre$i$i$i$i$i14 = HEAP32[$21>>2]|0;
         $69 = $$pre$i$i$i$i$i14;
        }
        $68 = ($69|0)==($56|0);
        if ($68) {
         label = 24;
         break;
        } else {
         $64 = $69;
        }
       }
       if ((label|0) == 23) {
        $74 = ___cxa_find_matching_catch()|0;
        $75 = tempRet0;
        ___cxa_call_unexpected(($74|0));
        // unreachable;
       }
       else if ((label|0) == 24) {
        $$pre$i$i$i16 = HEAP32[$temp>>2]|0;
        $76 = $$pre$i$i$i16;
        break;
       }
      }
     } while(0);
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($76|0),($$byval_copy24|0));
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      $79 = ___cxa_find_matching_catch()|0;
      $80 = tempRet0;
      ___cxa_call_unexpected(($79|0));
      // unreachable;
     } else {
      STACKTOP = sp;return;
     }
    }
   }
  } while(0);
  $81 = ___cxa_find_matching_catch()|0;
  $82 = tempRet0;
  $83 = HEAP32[$temp>>2]|0;
  $84 = ($83|0)==(0|0);
  if ($84) {
   $$0 = $82;$$01 = $81;
   ___resumeException($$01|0);
   // unreachable;
  }
  $85 = HEAP32[$21>>2]|0;
  $86 = ($85|0)==($83|0);
  do {
   if ($86) {
    $100 = $83;
   } else {
    $88 = $85;
    while(1) {
     $87 = (($88) + -12|0);
     HEAP32[$21>>2] = $87;
     $89 = HEAP8[$87>>0]|0;
     $90 = $89 & 1;
     $91 = ($90<<24>>24)==(0);
     if ($91) {
      $93 = $87;
     } else {
      $94 = (($88) + -4|0);
      $95 = HEAP32[$94>>2]|0;
      HEAP32[$1>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($95|0),($$byval_copy24|0));
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       label = 34;
       break;
      }
      $$pre$i$i$i$i$i22 = HEAP32[$21>>2]|0;
      $93 = $$pre$i$i$i$i$i22;
     }
     $92 = ($93|0)==($83|0);
     if ($92) {
      label = 35;
      break;
     } else {
      $88 = $93;
     }
    }
    if ((label|0) == 34) {
     $98 = ___cxa_find_matching_catch()|0;
     $99 = tempRet0;
     ___cxa_call_unexpected(($98|0));
     // unreachable;
    }
    else if ((label|0) == 35) {
     $$pre$i$i$i24 = HEAP32[$temp>>2]|0;
     $100 = $$pre$i$i$i24;
     break;
    }
   }
  } while(0);
  HEAP32[$2>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($100|0),($$byval_copy24|0));
  $101 = __THREW__; __THREW__ = 0;
  $102 = $101&1;
  if ($102) {
   $103 = ___cxa_find_matching_catch()|0;
   $104 = tempRet0;
   ___cxa_call_unexpected(($103|0));
   // unreachable;
  } else {
   $$0 = $82;$$01 = $81;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $106 = ($13>>>0)>($sz>>>0);
 if (!($106)) {
  STACKTOP = sp;return;
 }
 $107 = (($9) + (($sz*12)|0)|0);
 $$idx = ($sz*12)|0;
 $108 = (($$idx|0) / 12)&-1;
 $109 = ($sz|0)==(0);
 L65: do {
  if ($109) {
   $171 = 0;$173 = 0;$175 = 0;
  } else {
   $110 = ($$idx|0)<(0);
   if ($110) {
    __THREW__ = 0;
    invoke_vi(3308,0);
    $111 = __THREW__; __THREW__ = 0;
    $112 = $111&1;
    if ($112) {
     label = 58;
    } else {
     // unreachable;
    }
   } else {
    HEAP32[$4>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$4+0>>2]|0;
    $113 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy24|0),0,(630440|0),79)|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     label = 58;
    } else {
     $116 = (($113) + (($108*12)|0)|0);
     $118 = $113;$120 = $9;
     L72: while(1) {
      $117 = ($118|0)==(0|0);
      do {
       if (!($117)) {
        $119 = HEAP8[$120>>0]|0;
        $121 = $119 & 1;
        $122 = ($121<<24>>24)==(0);
        if ($122) {
         ;HEAP32[$118+0>>2]=HEAP32[$120+0>>2]|0;HEAP32[$118+4>>2]=HEAP32[$120+4>>2]|0;HEAP32[$118+8>>2]=HEAP32[$120+8>>2]|0;
         break;
        }
        $123 = (($120) + 8|0);
        $124 = HEAP32[$123>>2]|0;
        $125 = (($120) + 4|0);
        $126 = HEAP32[$125>>2]|0;
        $127 = ($126>>>0)>(2147483631);
        if ($127) {
         label = 50;
         break L72;
        }
        $130 = ($126>>>0)<(11);
        if ($130) {
         $131 = $126 << 1;
         $132 = $131&255;
         HEAP8[$118>>0] = $132;
         $133 = (($118) + 1|0);
         $__p$0$i$i$i$i$i = $133;
        } else {
         $134 = (($126) + 16)|0;
         $135 = $134 & -16;
         HEAP32[$3>>2] = 90;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$3+0>>2]|0;
         $136 = (invoke_iiiiiii(102,($135|0),16,($$byval_copy24|0),0,(630440|0),79)|0);
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if ($138) {
          label = 59;
          break L72;
         }
         $139 = (($118) + 8|0);
         HEAP32[$139>>2] = $136;
         $140 = $135 | 1;
         HEAP32[$118>>2] = $140;
         $141 = (($118) + 4|0);
         HEAP32[$141>>2] = $126;
         $__p$0$i$i$i$i$i = $136;
        }
        _memcpy(($__p$0$i$i$i$i$i|0),($124|0),($126|0))|0;
        $142 = (($__p$0$i$i$i$i$i) + ($126)|0);
        HEAP8[$142>>0] = 0;
       }
      } while(0);
      $143 = (($118) + 12|0);
      $144 = (($120) + 12|0);
      $145 = ($144|0)==($107|0);
      if ($145) {
       $171 = $113;$173 = $143;$175 = $116;
       break L65;
      } else {
       $118 = $143;$120 = $144;
      }
     }
     do {
      if ((label|0) == 50) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        $150 = ___cxa_find_matching_catch()|0;
        $151 = tempRet0;
        $lpad$phi$index = $150;$lpad$phi$index2 = $151;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 59) {
       $148 = ___cxa_find_matching_catch()|0;
       $149 = tempRet0;
       $lpad$phi$index = $148;$lpad$phi$index2 = $149;
      }
     } while(0);
     $152 = ($113|0)==(0|0);
     if ($152) {
      $eh$lpad$body$index8Z2D = $lpad$phi$index2;$eh$lpad$body$indexZ2D = $lpad$phi$index;
     } else {
      $153 = ($118|0)==($113|0);
      L94: do {
       if (!($153)) {
        $155 = $118;
        while(1) {
         $154 = (($155) + -12|0);
         $156 = HEAP8[$154>>0]|0;
         $157 = $156 & 1;
         $158 = ($157<<24>>24)==(0);
         if (!($158)) {
          $160 = (($155) + -4|0);
          $161 = HEAP32[$160>>2]|0;
          HEAP32[$$byval_copy>>2] = 90;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
          invoke_vii(2591,($161|0),($$byval_copy24|0));
          $162 = __THREW__; __THREW__ = 0;
          $163 = $162&1;
          if ($163) {
           break;
          }
         }
         $159 = ($154|0)==($113|0);
         if ($159) {
          break L94;
         } else {
          $155 = $154;
         }
        }
        $164 = ___cxa_find_matching_catch()|0;
        $165 = tempRet0;
        ___cxa_call_unexpected(($164|0));
        // unreachable;
       }
      } while(0);
      HEAP32[$0>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($113|0),($$byval_copy24|0));
      $166 = __THREW__; __THREW__ = 0;
      $167 = $166&1;
      if ($167) {
       $168 = ___cxa_find_matching_catch()|0;
       $169 = tempRet0;
       ___cxa_call_unexpected(($168|0));
       // unreachable;
      } else {
       $eh$lpad$body$index8Z2D = $lpad$phi$index2;$eh$lpad$body$indexZ2D = $lpad$phi$index;
      }
     }
    }
   }
   if ((label|0) == 58) {
    $146 = ___cxa_find_matching_catch()|0;
    $147 = tempRet0;
    $eh$lpad$body$index8Z2D = $147;$eh$lpad$body$indexZ2D = $146;
   }
   $$0 = $eh$lpad$body$index8Z2D;$$01 = $eh$lpad$body$indexZ2D;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $170 = HEAP32[$v>>2]|0;
 HEAP32[$v>>2] = $171;
 $172 = HEAP32[$7>>2]|0;
 HEAP32[$7>>2] = $173;
 $174 = (($v) + 8|0);
 HEAP32[$174>>2] = $175;
 $176 = ($170|0)==(0|0);
 if ($176) {
  STACKTOP = sp;return;
 }
 $177 = ($172|0)==($170|0);
 L112: do {
  if (!($177)) {
   $179 = $172;
   while(1) {
    $178 = (($179) + -12|0);
    $180 = HEAP8[$178>>0]|0;
    $181 = $180 & 1;
    $182 = ($181<<24>>24)==(0);
    if (!($182)) {
     $184 = (($179) + -4|0);
     $185 = HEAP32[$184>>2]|0;
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($185|0),($$byval_copy24|0));
     $186 = __THREW__; __THREW__ = 0;
     $187 = $186&1;
     if ($187) {
      break;
     }
    }
    $183 = ($178|0)==($170|0);
    if ($183) {
     break L112;
    } else {
     $179 = $178;
    }
   }
   $188 = ___cxa_find_matching_catch()|0;
   $189 = tempRet0;
   ___cxa_call_unexpected(($188|0));
   // unreachable;
  }
 } while(0);
 HEAP32[$3>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($170|0),($$byval_copy24|0));
 $190 = __THREW__; __THREW__ = 0;
 $191 = $190&1;
 if ($191) {
  $192 = ___cxa_find_matching_catch()|0;
  $193 = tempRet0;
  ___cxa_call_unexpected(($192|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 8|0);
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($6))|0;
 $15 = (($14|0) / 12)&-1;
 $16 = (($__v) + 12|0);
 HEAP32[$16>>2] = 0;
 $17 = (($__v) + 16|0);
 HEAP32[$17>>2] = $10;
 $18 = ($__n|0)==(0);
 if ($18) {
  $21 = 0;
 } else {
  $19 = ($__n*12)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,16,$$byval_copy4,0,630440,79)|0);
  $21 = $20;
 }
 HEAP32[$__v>>2] = $21;
 $22 = (($21) + (($15*12)|0)|0);
 $23 = (($__v) + 8|0);
 HEAP32[$23>>2] = $22;
 $24 = (($__v) + 4|0);
 HEAP32[$24>>2] = $22;
 $25 = (($21) + (($__n*12)|0)|0);
 HEAP32[$16>>2] = $25;
 __THREW__ = 0;
 invoke_vii(2900,($this|0),($__v|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  $51 = HEAP32[$24>>2]|0;
  $52 = HEAP32[$23>>2]|0;
  $53 = ($52|0)==($51|0);
  L25: do {
   if (!($53)) {
    $55 = $52;
    while(1) {
     $54 = (($55) + -12|0);
     HEAP32[$23>>2] = $54;
     $56 = HEAP8[$54>>0]|0;
     $57 = $56 & 1;
     $58 = ($57<<24>>24)==(0);
     if (!($58)) {
      $60 = (($55) + -4|0);
      $61 = HEAP32[$60>>2]|0;
      HEAP32[$1>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($61|0),($$byval_copy4|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
     $59 = ($54|0)==($51|0);
     if ($59) {
      break L25;
     } else {
      $55 = $54;
     }
    }
    $64 = ___cxa_find_matching_catch()|0;
    $65 = tempRet0;
    ___cxa_call_unexpected(($64|0));
    // unreachable;
   }
  } while(0);
  $66 = HEAP32[$__v>>2]|0;
  $67 = ($66|0)==(0|0);
  if ($67) {
   ___resumeException($49|0);
   // unreachable;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($66|0),($$byval_copy4|0));
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   $70 = ___cxa_find_matching_catch()|0;
   $71 = tempRet0;
   ___cxa_call_unexpected(($70|0));
   // unreachable;
  } else {
   ___resumeException($49|0);
   // unreachable;
  }
 } else {
  $28 = HEAP32[$24>>2]|0;
  $29 = HEAP32[$23>>2]|0;
  $30 = ($29|0)==($28|0);
  L9: do {
   if (!($30)) {
    $32 = $29;
    while(1) {
     $31 = (($32) + -12|0);
     HEAP32[$23>>2] = $31;
     $33 = HEAP8[$31>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if (!($35)) {
      $37 = (($32) + -4|0);
      $38 = HEAP32[$37>>2]|0;
      HEAP32[$1>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($38|0),($$byval_copy4|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
     }
     $36 = ($31|0)==($28|0);
     if ($36) {
      break L9;
     } else {
      $32 = $31;
     }
    }
    $41 = ___cxa_find_matching_catch()|0;
    $42 = tempRet0;
    ___cxa_call_unexpected(($41|0));
    // unreachable;
   }
  } while(0);
  $43 = HEAP32[$__v>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($43|0),($$byval_copy4|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $47 = ___cxa_find_matching_catch()|0;
   $48 = tempRet0;
   ___cxa_call_unexpected(($47|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE6assignINS_11__wrap_iterIPS7_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS7_NS_15iterator_traitsISF_E9referenceEEE5valueEvE4typeESF_SF_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i10 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy6 = 0, $$byval_copy7 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy7 = sp + 24|0;
 $$byval_copy6 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = HEAP32[$__first>>2]|0;
 $6 = HEAP32[$__last>>2]|0;
 $7 = $6;
 $8 = $5;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$this>>2]|0;
 $14 = $12;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = ($10>>>0)>($17>>>0);
 if (!($18)) {
  $19 = (($this) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20;
  $22 = (($21) - ($15))|0;
  $23 = (($22|0) / 12)&-1;
  $24 = ($10>>>0)>($23>>>0);
  if ($24) {
   $25 = (($5) + (($23*12)|0)|0);
   $27 = $25;$__growing$0$off0 = 1;
  } else {
   $27 = $6;$__growing$0$off0 = 0;
  }
  $26 = ($5|0)==($27|0);
  if ($26) {
   $$0$lcssa$i$i = $13;
  } else {
   $scevgep$i = (($27) + -12|0);
   $28 = (0 - ($8))|0;
   $uglygep$i = (($scevgep$i) + ($28)|0);
   $uglygep16$i = $uglygep$i;
   $29 = (($uglygep16$i>>>0) / 12)&-1;
   $$01$i$i = $13;$30 = $5;
   while(1) {
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEaSERKS6_($$01$i$i,$30)|0);
    $31 = (($30) + 12|0);
    $32 = (($$01$i$i) + 12|0);
    $33 = ($31|0)==($27|0);
    if ($33) {
     break;
    } else {
     $$01$i$i = $32;$30 = $31;
    }
   }
   $34 = (($29) + 1)|0;
   $scevgep17$i = (($13) + (($34*12)|0)|0);
   $$0$lcssa$i$i = $scevgep17$i;
  }
  if ($__growing$0$off0) {
   HEAP32[$1>>2] = $27;
   HEAP32[$2>>2] = $6;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
   __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE18__construct_at_endINS_11__wrap_iterIPS7_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESF_SF_($this,$$byval_copy6,$$byval_copy7);
   STACKTOP = sp;return;
  }
  $35 = HEAP32[$19>>2]|0;
  $36 = ($35|0)==($$0$lcssa$i$i|0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $38 = $35;
  while(1) {
   $37 = (($38) + -12|0);
   HEAP32[$19>>2] = $37;
   $39 = HEAP8[$37>>0]|0;
   $40 = $39 & 1;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $43 = $37;
   } else {
    $44 = (($38) + -4|0);
    $45 = HEAP32[$44>>2]|0;
    HEAP32[$$byval_copy6>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy6+0>>2]|0;
    invoke_vii(2591,($45|0),($$byval_copy7|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 16;
     break;
    }
    $$pre$i$i = HEAP32[$19>>2]|0;
    $43 = $$pre$i$i;
   }
   $42 = ($43|0)==($$0$lcssa$i$i|0);
   if ($42) {
    label = 35;
    break;
   } else {
    $38 = $43;
   }
  }
  if ((label|0) == 16) {
   $48 = ___cxa_find_matching_catch()|0;
   $49 = tempRet0;
   ___cxa_call_unexpected(($48|0));
   // unreachable;
  }
  else if ((label|0) == 35) {
   STACKTOP = sp;return;
  }
 }
 $50 = ($13|0)==(0|0);
 do {
  if ($50) {
   $74 = $12;
  } else {
   $51 = (($this) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==($13|0);
   do {
    if ($53) {
     $67 = $13;
    } else {
     $55 = $52;
     while(1) {
      $54 = (($55) + -12|0);
      HEAP32[$51>>2] = $54;
      $56 = HEAP8[$54>>0]|0;
      $57 = $56 & 1;
      $58 = ($57<<24>>24)==(0);
      if ($58) {
       $60 = $54;
      } else {
       $61 = (($55) + -4|0);
       $62 = HEAP32[$61>>2]|0;
       HEAP32[$0>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($62|0),($$byval_copy7|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$51>>2]|0;
       $60 = $$pre$i$i$i$i;
      }
      $59 = ($60|0)==($13|0);
      if ($59) {
       label = 25;
       break;
      } else {
       $55 = $60;
      }
     }
     if ((label|0) == 24) {
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      ___cxa_call_unexpected(($65|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $67 = $$pre$i;
      break;
     }
    }
   } while(0);
   HEAP32[$$byval_copy6>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy6+0>>2]|0;
   invoke_vii(2591,($67|0),($$byval_copy7|0));
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    $70 = ___cxa_find_matching_catch()|0;
    $71 = tempRet0;
    ___cxa_call_unexpected(($70|0));
    // unreachable;
   } else {
    HEAP32[$11>>2] = 0;
    HEAP32[$51>>2] = 0;
    HEAP32[$this>>2] = 0;
    $74 = 0;
    break;
   }
  }
 } while(0);
 $72 = ($9|0)<(0);
 if ($72) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $73 = $74;
 $75 = (($73|0) / 12)&-1;
 $76 = ($75>>>0)<(1073741823);
 if ($76) {
  $77 = $75 << 1;
  $78 = ($77>>>0)<($10>>>0);
  $79 = $78 ? $10 : $77;
  $80 = ($79|0)<(0);
  if ($80) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i10 = $79;
  }
 } else {
  $$0$i10 = 2147483647;
 }
 $81 = ($$0$i10*12)|0;
 HEAP32[$$byval_copy6>>2] = 90;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy6+0>>2]|0;
 $82 = (__Z15malloc_internaljj10MemLabelIdiPKci($81,16,$$byval_copy7,0,630440,79)|0);
 $83 = (($this) + 4|0);
 HEAP32[$83>>2] = $82;
 HEAP32[$this>>2] = $82;
 $84 = (($82) + (($$0$i10*12)|0)|0);
 HEAP32[$11>>2] = $84;
 HEAP32[$3>>2] = $5;
 HEAP32[$4>>2] = $6;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
 __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE18__construct_at_endINS_11__wrap_iterIPS7_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESF_SF_($this,$$byval_copy6,$$byval_copy7);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE18__construct_at_endINS_11__wrap_iterIPS7_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESF_SF_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 L4: while(1) {
  $5 = ($6|0)==(0|0);
  do {
   if (!($5)) {
    $7 = HEAP8[$8>>0]|0;
    $9 = $7 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     ;HEAP32[$6+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$8+8>>2]|0;
     break;
    }
    $11 = (($8) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($8) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14>>>0)>(2147483631);
    if ($15) {
     label = 7;
     break L4;
    }
    $16 = ($14>>>0)<(11);
    if ($16) {
     $17 = $14 << 1;
     $18 = $17&255;
     HEAP8[$6>>0] = $18;
     $19 = (($6) + 1|0);
     $__p$0$i$i$i$i = $19;
    } else {
     $20 = (($14) + 16)|0;
     $21 = $20 & -16;
     HEAP32[$0>>2] = 90;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,16,$$byval_copy,0,630440,79)|0);
     $23 = (($6) + 8|0);
     HEAP32[$23>>2] = $22;
     $24 = $21 | 1;
     HEAP32[$6>>2] = $24;
     $25 = (($6) + 4|0);
     HEAP32[$25>>2] = $14;
     $__p$0$i$i$i$i = $22;
    }
    _memcpy(($__p$0$i$i$i$i|0),($12|0),($14|0))|0;
    $26 = (($__p$0$i$i$i$i) + ($14)|0);
    HEAP8[$26>>0] = 0;
   }
  } while(0);
  $27 = HEAP32[$4>>2]|0;
  $28 = (($27) + 12|0);
  HEAP32[$4>>2] = $28;
  $29 = (($8) + 12|0);
  HEAP32[$__first>>2] = $29;
  $30 = ($29|0)==($2|0);
  if ($30) {
   label = 13;
   break;
  } else {
   $6 = $28;$8 = $29;
  }
 }
 if ((label|0) == 7) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i114 = 0, $$0$i115 = 0, $$0$i9 = 0, $$byval_copy4 = 0, $$pre1$i = 0, $$pre1$i1113 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ($9>>>0)<($__n>>>0);
 if (!($10)) {
  $$0$i = $__n;$12 = $5;
  while(1) {
   $11 = ($12|0)==(0|0);
   if ($11) {
    $14 = 0;
   } else {
    ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
    $$pre1$i = HEAP32[$4>>2]|0;
    $14 = $$pre1$i;
   }
   $13 = (($14) + 12|0);
   HEAP32[$4>>2] = $13;
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$12 = $13;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = (($this) + 8|0);
 $18 = HEAP32[$this>>2]|0;
 $19 = $18;
 $20 = (($7) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($__n))|0;
 $23 = ($22|0)<(0);
 if ($23) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $24 = (($6) - ($19))|0;
 $25 = (($24|0) / 12)&-1;
 $26 = ($25>>>0)<(1073741823);
 if ($26) {
  $29 = $25 << 1;
  $30 = ($29>>>0)<($22>>>0);
  $31 = $30 ? $22 : $29;
  $32 = (($__v) + 12|0);
  HEAP32[$32>>2] = 0;
  $33 = (($__v) + 16|0);
  HEAP32[$33>>2] = $17;
  $34 = ($31|0)==(0);
  if ($34) {
   $$0$i115 = 0;$37 = 0;$42 = $32;
  } else {
   $$0$i114 = $31;$94 = $32;
   label = 10;
  }
 } else {
  $27 = (($__v) + 12|0);
  HEAP32[$27>>2] = 0;
  $28 = (($__v) + 16|0);
  HEAP32[$28>>2] = $17;
  $$0$i114 = 2147483647;$94 = $27;
  label = 10;
 }
 if ((label|0) == 10) {
  $35 = ($$0$i114*12)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $36 = (__Z15malloc_internaljj10MemLabelIdiPKci($35,16,$$byval_copy4,0,630440,79)|0);
  $$0$i115 = $$0$i114;$37 = $36;$42 = $94;
 }
 HEAP32[$__v>>2] = $37;
 $38 = (($37) + (($21*12)|0)|0);
 $39 = (($__v) + 8|0);
 HEAP32[$39>>2] = $38;
 $40 = (($__v) + 4|0);
 HEAP32[$40>>2] = $38;
 $41 = (($37) + (($$0$i115*12)|0)|0);
 HEAP32[$42>>2] = $41;
 $$0$i9 = $__n;$$pre1$i1113 = $38;
 while(1) {
  $43 = ($$pre1$i1113|0)==(0|0);
  if ($43) {
   $45 = 0;
  } else {
   ;HEAP32[$$pre1$i1113+0>>2]=0|0;HEAP32[$$pre1$i1113+4>>2]=0|0;HEAP32[$$pre1$i1113+8>>2]=0|0;
   $45 = $$pre1$i1113;
  }
  $44 = (($45) + 12|0);
  $46 = (($$0$i9) + -1)|0;
  $47 = ($46|0)==(0);
  if ($47) {
   break;
  } else {
   $$0$i9 = $46;$$pre1$i1113 = $44;
  }
 }
 HEAP32[$39>>2] = $44;
 __THREW__ = 0;
 invoke_vii(2900,($this|0),($__v|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  $73 = HEAP32[$40>>2]|0;
  $74 = HEAP32[$39>>2]|0;
  $75 = ($74|0)==($73|0);
  L26: do {
   if (!($75)) {
    $77 = $74;
    while(1) {
     $76 = (($77) + -12|0);
     HEAP32[$39>>2] = $76;
     $78 = HEAP8[$76>>0]|0;
     $79 = $78 & 1;
     $80 = ($79<<24>>24)==(0);
     if (!($80)) {
      $82 = (($77) + -4|0);
      $83 = HEAP32[$82>>2]|0;
      HEAP32[$1>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($83|0),($$byval_copy4|0));
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if ($85) {
       break;
      }
     }
     $81 = ($76|0)==($73|0);
     if ($81) {
      break L26;
     } else {
      $77 = $76;
     }
    }
    $86 = ___cxa_find_matching_catch()|0;
    $87 = tempRet0;
    ___cxa_call_unexpected(($86|0));
    // unreachable;
   }
  } while(0);
  $88 = HEAP32[$__v>>2]|0;
  $89 = ($88|0)==(0|0);
  if ($89) {
   ___resumeException($71|0);
   // unreachable;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($88|0),($$byval_copy4|0));
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   $92 = ___cxa_find_matching_catch()|0;
   $93 = tempRet0;
   ___cxa_call_unexpected(($92|0));
   // unreachable;
  } else {
   ___resumeException($71|0);
   // unreachable;
  }
 } else {
  $50 = HEAP32[$40>>2]|0;
  $51 = HEAP32[$39>>2]|0;
  $52 = ($51|0)==($50|0);
  L42: do {
   if (!($52)) {
    $54 = $51;
    while(1) {
     $53 = (($54) + -12|0);
     HEAP32[$39>>2] = $53;
     $55 = HEAP8[$53>>0]|0;
     $56 = $55 & 1;
     $57 = ($56<<24>>24)==(0);
     if (!($57)) {
      $59 = (($54) + -4|0);
      $60 = HEAP32[$59>>2]|0;
      HEAP32[$1>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($60|0),($$byval_copy4|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
     }
     $58 = ($53|0)==($50|0);
     if ($58) {
      break L42;
     } else {
      $54 = $53;
     }
    }
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    ___cxa_call_unexpected(($63|0));
    // unreachable;
   }
  } while(0);
  $65 = HEAP32[$__v>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($65|0),($$byval_copy4|0));
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if ($68) {
   $69 = ___cxa_find_matching_catch()|0;
   $70 = tempRet0;
   ___cxa_call_unexpected(($69|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS8_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__v) + 4|0);
 $5 = ($3|0)==($1|0);
 do {
  if ($5) {
   $$pre1 = HEAP32[$4>>2]|0;
   $31 = $$pre1;$32 = $1;
  } else {
   $$pre$i = HEAP32[$4>>2]|0;
   $$01$i = $3;$7 = $$pre$i;
   while(1) {
    $6 = (($7) + -12|0);
    $8 = (($$01$i) + -12|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9 & 1;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     ;HEAP32[$6+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$8+8>>2]|0;
    } else {
     $12 = (($$01$i) + -4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($$01$i) + -8|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15>>>0)>(2147483631);
     if ($16) {
      label = 7;
      break;
     }
     $17 = ($15>>>0)<(11);
     if ($17) {
      $18 = $15 << 1;
      $19 = $18&255;
      HEAP8[$6>>0] = $19;
      $20 = (($6) + 1|0);
      $__p$0$i$i$i$i$i = $20;
     } else {
      $21 = (($15) + 16)|0;
      $22 = $21 & -16;
      HEAP32[$0>>2] = 90;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,16,$$byval_copy,0,630440,79)|0);
      $24 = (($7) + -4|0);
      HEAP32[$24>>2] = $23;
      $25 = $22 | 1;
      HEAP32[$6>>2] = $25;
      $26 = (($7) + -8|0);
      HEAP32[$26>>2] = $15;
      $__p$0$i$i$i$i$i = $23;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($13|0),($15|0))|0;
     $27 = (($__p$0$i$i$i$i$i) + ($15)|0);
     HEAP8[$27>>0] = 0;
    }
    $28 = HEAP32[$4>>2]|0;
    $29 = (($28) + -12|0);
    HEAP32[$4>>2] = $29;
    $30 = ($8|0)==($1|0);
    if ($30) {
     label = 13;
     break;
    } else {
     $$01$i = $8;$7 = $29;
    }
   }
   if ((label|0) == 7) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre = HEAP32[$this>>2]|0;
    $31 = $29;$32 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $31;
 HEAP32[$4>>2] = $32;
 $33 = (($__v) + 8|0);
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$33>>2]|0;
 HEAP32[$2>>2] = $35;
 HEAP32[$33>>2] = $34;
 $36 = (($this) + 8|0);
 $37 = (($__v) + 12|0);
 $38 = HEAP32[$36>>2]|0;
 $39 = HEAP32[$37>>2]|0;
 HEAP32[$36>>2] = $39;
 HEAP32[$37>>2] = $38;
 $40 = HEAP32[$4>>2]|0;
 HEAP32[$__v>>2] = $40;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEaSERKS6_($this,$__str) {
 $this = $this|0;
 $__str = $__str|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==($__str|0);
 if ($0) {
  STACKTOP = sp;return ($this|0);
 }
 $1 = HEAP8[$__str>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $8 = (($__str) + 1|0);
  $9 = $1&255;
  $10 = $9 >>> 1;
  $19 = $10;$27 = $8;
 } else {
  $4 = (($__str) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($__str) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $19 = $7;$27 = $5;
 }
 $11 = HEAP8[$this>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $18 = 10;$21 = $11;
 } else {
  $14 = HEAP32[$this>>2]|0;
  $15 = $14 & -2;
  $phitmp$i$i$i = (($15) + -1)|0;
  $16 = $14&255;
  $18 = $phitmp$i$i$i;$21 = $16;
 }
 $17 = ($18>>>0)<($19>>>0);
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($17) {
  if ($22) {
   $37 = $21&255;
   $38 = $37 >>> 1;
   $40 = $38;
  } else {
   $35 = (($this) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $40 = $36;
  }
  $39 = (($19) - ($18))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE21__grow_by_and_replaceEjjjjjjPKc($this,$18,$39,$40,0,$40,$19,$27);
  STACKTOP = sp;return ($this|0);
 }
 if ($22) {
  $25 = (($this) + 1|0);
  $26 = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $26 = $24;
 }
 _memmove(($26|0),($27|0),($19|0))|0;
 $28 = (($26) + ($19)|0);
 HEAP8[$28>>0] = 0;
 $29 = HEAP8[$this>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $33 = $19 << 1;
  $34 = $33&255;
  HEAP8[$this>>0] = $34;
  STACKTOP = sp;return ($this|0);
 } else {
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $19;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __Z33EmitSerializationCommandsForFieldI14SafeBinaryReadEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$0$i$ph9 = 0, $$off = 0, $$ph = 0, $$ph8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $serializeFieldCommand = 0, $staticInfo$sroa$9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $staticInfo$sroa$9 = sp;
 $serializeFieldCommand = sp + 16|0;
 $1 = (($tfi) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z24scripting_class_get_typeP14ScriptingClass($2)|0);
 $4 = (__Z23scripting_type_get_typeP13ScriptingType($3)|0);
 $5 = ($4|0)==(29);
 if (!($5)) {
  $6 = (__ZN9Scripting30IsSystemCollectionsGenericListEP14ScriptingClass($2)|0);
  if (!($6)) {
   ;HEAP32[$staticInfo$sroa$9+0>>2]=0|0;HEAP32[$staticInfo$sroa$9+4>>2]=0|0;HEAP32[$staticInfo$sroa$9+8>>2]=0|0;
   $7 = HEAP32[$tfi>>2]|0;
   $8 = (__Z24scripting_field_get_nameP14ScriptingField($7)|0);
   $9 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $10 = (__Z25scripting_class_from_typeP13ScriptingType($9)|0);
   $11 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $12 = (__Z23scripting_type_get_typeP13ScriptingType($11)|0);
   $13 = (__Z26scripting_field_get_offsetP14ScriptingField($7)|0);
   $14 = (__Z24scripting_class_get_nameP14ScriptingClass($10)|0);
   $15 = (($tfi) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = (($tfi) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($tfi) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   L4: do {
    switch ($19|0) {
    case 9:  {
     $$0$i$ph = 2907;$$ph = $16;
     label = 47;
     break;
    }
    case 6:  {
     $$0$i$ph = 2905;$$ph = $16;
     label = 47;
     break;
    }
    case 12:  {
     $$0$i$ph = 2910;$$ph = $16;
     label = 47;
     break;
    }
    case 14:  {
     $$0$i$ph = 2901;$$ph = $16;
     label = 47;
     break;
    }
    case 4:  {
     $$0$i$ph = 2903;$$ph = $16;
     label = 47;
     break;
    }
    case 10:  {
     $$0$i$ph = 2908;$$ph = $16;
     label = 47;
     break;
    }
    case 2:  {
     $23 = $16 | 256;
     $$0$i$ph = 2904;$$ph = $23;
     label = 47;
     break;
    }
    case 13:  {
     $$0$i$ph = 2911;$$ph = $16;
     label = 47;
     break;
    }
    case 11:  {
     $$0$i$ph = 2909;$$ph = $16;
     label = 47;
     break;
    }
    case 5:  {
     $$0$i$ph = 2904;$$ph = $16;
     label = 47;
     break;
    }
    case 8:  {
     $$0$i$ph = 2906;$$ph = $16;
     label = 47;
     break;
    }
    case 7:  {
     $$0$i$ph = 2902;$$ph = $16;
     label = 47;
     break;
    }
    case 3:  {
     $22 = $16 | 33554432;
     $$0$i$ph = 2902;$$ph = $22;
     label = 47;
     break;
    }
    default: {
     $24 = (($21) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($17|0)==($25|0);
     if ($26) {
      $$0$i$ph = 2912;$$ph = $16;
      label = 47;
     } else {
      $27 = (($21) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($17|0)==($28|0);
      if ($29) {
       $$0$i$ph = 2913;$$ph = $16;
       label = 47;
      } else {
       $30 = (($21) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($17|0)==($31|0);
       if ($32) {
        $$0$i$ph = 2914;$$ph = $16;
        label = 47;
       } else {
        $33 = (($21) + 24|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = ($17|0)==($34|0);
        if ($35) {
         $$0$i$ph = 2915;$$ph = $16;
         label = 47;
        } else {
         $36 = (($21) + 32|0);
         $37 = HEAP32[$36>>2]|0;
         $38 = ($17|0)==($37|0);
         if ($38) {
          $$0$i$ph = 2916;$$ph = $16;
          label = 47;
         } else {
          $39 = (($21) + 36|0);
          $40 = HEAP32[$39>>2]|0;
          $41 = ($17|0)==($40|0);
          if ($41) {
           $$0$i$ph = 2917;$$ph = $16;
           label = 47;
          } else {
           $42 = (($21) + 40|0);
           $43 = HEAP32[$42>>2]|0;
           $44 = ($17|0)==($43|0);
           if ($44) {
            $$0$i$ph = 2918;$$ph = $16;
            label = 47;
           } else {
            $45 = (($21) + 52|0);
            $46 = HEAP32[$45>>2]|0;
            $47 = ($17|0)==($46|0);
            if ($47) {
             $$0$i$ph = 2919;$$ph = $16;
             label = 47;
            } else {
             $48 = (($21) + 56|0);
             $49 = HEAP32[$48>>2]|0;
             $50 = ($17|0)==($49|0);
             if ($50) {
              $$0$i$ph = 2920;$$ph = $16;
              label = 47;
             } else {
              $51 = (($21) + 88|0);
              $52 = HEAP32[$51>>2]|0;
              $53 = ($17|0)==($52|0);
              if ($53) {
               $$0$i$ph = 2921;$$ph = $16;
               label = 47;
              } else {
               $54 = (($21) + 492|0);
               $55 = HEAP32[$54>>2]|0;
               $56 = ($17|0)==($55|0);
               do {
                if (!($56)) {
                 $57 = (($21) + 496|0);
                 $58 = HEAP32[$57>>2]|0;
                 $59 = ($17|0)==($58|0);
                 if (!($59)) {
                  $60 = (__Z23scripting_class_is_enumP14ScriptingClass($17)|0);
                  if (!($60)) {
                   $85 = (($21) + 280|0);
                   $86 = HEAP32[$85>>2]|0;
                   $87 = ($17|0)==($86|0);
                   if ($87) {
                    $$0$i$ph = 2922;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $88 = (($21) + 504|0);
                   $89 = HEAP32[$88>>2]|0;
                   $90 = ($17|0)==($89|0);
                   if ($90) {
                    $$0$i$ph = 2923;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $91 = (($21) + 28|0);
                   $92 = HEAP32[$91>>2]|0;
                   $93 = ($17|0)==($92|0);
                   if ($93) {
                    $$0$i$ph = 2924;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $94 = (($21) + 272|0);
                   $95 = HEAP32[$94>>2]|0;
                   $96 = ($17|0)==($95|0);
                   if ($96) {
                    $$0$i$ph9 = 2925;$$ph8 = $16;
                    break L4;
                   }
                   $97 = ($19|0)==(18);
                   if (!($97)) {
                    break;
                   }
                   $98 = (($21) + 244|0);
                   $99 = HEAP32[$98>>2]|0;
                   $100 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($17,$99)|0);
                   if ($100) {
                    $$0$i$ph9 = 2926;$$ph8 = $16;
                    break L4;
                   } else {
                    break;
                   }
                  }
                  $61 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($17)|0);
                  $62 = (__Z23scripting_type_get_typeP13ScriptingType($61)|0);
                  if ((($62|0) == 8)) {
                   $$0$i$ph = 2906;$$ph = $16;
                   label = 47;
                   break L4;
                  } else if ((($62|0) == 5)) {
                   $$0$i$ph = 2904;$$ph = $16;
                   label = 47;
                   break L4;
                  }
                  $63 = HEAP32[$tfi>>2]|0;
                  __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$63);
                  $64 = HEAP8[$0>>0]|0;
                  $65 = $64 & 1;
                  $66 = ($65<<24>>24)==(0);
                  if ($66) {
                   $69 = (($0) + 1|0);
                   $70 = $69;
                  } else {
                   $67 = (($0) + 8|0);
                   $68 = HEAP32[$67>>2]|0;
                   $70 = $68;
                  }
                  __THREW__ = 0;
                  invoke_viiiiiiii(21,($70|0),0,(630440|0),188,1,0,0,(0|0));
                  $71 = __THREW__; __THREW__ = 0;
                  $72 = $71&1;
                  if (!($72)) {
                   $73 = HEAP8[$0>>0]|0;
                   $74 = $73 & 1;
                   $75 = ($74<<24>>24)==(0);
                   if ($75) {
                    break;
                   }
                   $76 = (($0) + 8|0);
                   $77 = HEAP32[$76>>2]|0;
                   __ZdlPv($77);
                   break;
                  }
                  $78 = ___cxa_find_matching_catch()|0;
                  $79 = tempRet0;
                  $80 = HEAP8[$0>>0]|0;
                  $81 = $80 & 1;
                  $82 = ($81<<24>>24)==(0);
                  if ($82) {
                   ___resumeException($78|0);
                   // unreachable;
                  }
                  $83 = (($0) + 8|0);
                  $84 = HEAP32[$83>>2]|0;
                  __ZdlPv($84);
                  ___resumeException($78|0);
                  // unreachable;
                 }
                }
               } while(0);
               $114 = HEAP32[$18>>2]|0;
               $$off = (($114) + -17)|0;
               $115 = ($$off>>>0)<(2);
               if (!($115)) {
                STACKTOP = sp;return;
               }
               __Z46EmitSerializationCommandsForManagedObjectFieldI14SafeBinaryReadEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
    }
   } while(0);
   if ((label|0) == 47) {
    $101 = (($tfi) + 25|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $$0$i$ph9 = $$0$i$ph;$$ph8 = $$ph;
    } else {
     STACKTOP = sp;return;
    }
   }
   dest=$serializeFieldCommand+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$serializeFieldCommand>>2] = $$0$i$ph9;
   $104 = (($serializeFieldCommand) + 4|0);
   HEAP32[$104>>2] = $7;
   $105 = (($serializeFieldCommand) + 8|0);
   HEAP32[$105>>2] = $8;
   $106 = (($serializeFieldCommand) + 12|0);
   HEAP32[$106>>2] = $14;
   $107 = (($serializeFieldCommand) + 16|0);
   HEAP32[$107>>2] = $10;
   $108 = (($serializeFieldCommand) + 20|0);
   HEAP32[$108>>2] = $12;
   $109 = (($serializeFieldCommand) + 24|0);
   HEAP32[$109>>2] = $13;
   $110 = (($serializeFieldCommand) + 28|0);
   HEAP32[$110>>2] = $$ph8;
   $111 = (($serializeFieldCommand) + 32|0);
   HEAP32[$111>>2] = $17;
   $112 = (($serializeFieldCommand) + 36|0);
   HEAP32[$112>>2] = $19;
   $113 = (($serializeFieldCommand) + 40|0);
   ;HEAP32[$113+0>>2]=HEAP32[$staticInfo$sroa$9+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[$staticInfo$sroa$9+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[$staticInfo$sroa$9+8>>2]|0;
   __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$serializeFieldCommand);
   STACKTOP = sp;return;
  }
 }
 __Z49EmitSerializationCommandsForLinearCollectionFieldI14SafeBinaryReadEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
 STACKTOP = sp;return;
}
function __ZL12InvokeMethodI14SafeBinaryReadEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $invocation = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $invocation = sp + 8|0;
 $0 = sp;
 $1 = (($args) + 56|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($args) + 48|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $15 = (($runtimeInfo) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($invocation) + 12|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP8[$runtimeInfo>>0]|0;
 $19 = (($invocation) + 24|0);
 HEAP8[$19>>0] = $18;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation)|0);
 STACKTOP = sp;return;
}
function __Z49EmitSerializationCommandsForLinearCollectionFieldI14SafeBinaryReadEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($info,$commandQueueBuilder,$nameConversions) {
 $info = $info|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$off = 0, $$ph = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $command = 0, $linearCollectionField = 0, $switch = 0, $tfi = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 184|0;
 $linearCollectionField = sp + 144|0;
 $1 = sp + 68|0;
 $tfi = sp;
 $command = sp + 80|0;
 $$sroa$9 = sp + 56|0;
 HEAP8[$1>>0] = 1;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$info>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$1,$4);
 dest=$tfi+0|0; src=$info+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = HEAP32[$info>>2]|0;
 HEAP32[$tfi>>2] = $5;
 $6 = (__ZN21LinearCollectionField15GetElementClassEv($linearCollectionField)|0);
 $7 = (($tfi) + 40|0);
 HEAP32[$7>>2] = $6;
 $8 = (__Z24scripting_class_get_typeP14ScriptingClass($6)|0);
 $9 = (__Z23scripting_type_get_typeP13ScriptingType($8)|0);
 $10 = (($tfi) + 44|0);
 HEAP32[$10>>2] = $9;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 dest=$command+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$command>>2] = 2927;
 ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
 $14 = (__Z24scripting_field_get_nameP14ScriptingField($5)|0);
 $15 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $16 = (__Z25scripting_class_from_typeP13ScriptingType($15)|0);
 $17 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $18 = (__Z23scripting_type_get_typeP13ScriptingType($17)|0);
 $19 = (__Z26scripting_field_get_offsetP14ScriptingField($5)|0);
 $20 = (__Z24scripting_class_get_nameP14ScriptingClass($16)|0);
 $21 = (($tfi) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($command) + 4|0);
 HEAP32[$23>>2] = $5;
 $24 = (($command) + 8|0);
 HEAP32[$24>>2] = $14;
 $25 = (($command) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($command) + 16|0);
 HEAP32[$26>>2] = $16;
 $27 = (($command) + 20|0);
 HEAP32[$27>>2] = $18;
 $28 = (($command) + 24|0);
 HEAP32[$28>>2] = $19;
 $29 = (($command) + 28|0);
 HEAP32[$29>>2] = $22;
 $30 = (($command) + 32|0);
 HEAP32[$30>>2] = $6;
 $31 = (($command) + 36|0);
 HEAP32[$31>>2] = $9;
 $32 = (($command) + 40|0);
 ;HEAP32[$32+0>>2]=HEAP32[$$sroa$9+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$$sroa$9+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$$sroa$9+8>>2]|0;
 $33 = (($tfi) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 L1: do {
  switch ($9|0) {
  case 13:  {
   $$0$i$ph = 2938;$$ph = 1;
   break;
  }
  case 3:  {
   $35 = $22 | 33554432;
   HEAP32[$29>>2] = $35;
   $$0$i$ph = 2929;$$ph = 1;
   break;
  }
  case 12:  {
   $$0$i$ph = 2937;$$ph = 1;
   break;
  }
  case 5:  {
   $$0$i$ph = 2931;$$ph = 1;
   break;
  }
  case 14:  {
   $$0$i$ph = 2928;$$ph = 1;
   break;
  }
  case 10:  {
   $$0$i$ph = 2935;$$ph = 1;
   break;
  }
  case 4:  {
   $$0$i$ph = 2930;$$ph = 1;
   break;
  }
  case 8:  {
   $$0$i$ph = 2933;$$ph = 1;
   break;
  }
  case 11:  {
   $$0$i$ph = 2936;$$ph = 1;
   break;
  }
  case 6:  {
   $$0$i$ph = 2932;$$ph = 1;
   break;
  }
  case 2:  {
   $36 = $22 | 256;
   HEAP32[$29>>2] = $36;
   $$0$i$ph = 2931;$$ph = 1;
   break;
  }
  case 7:  {
   $$0$i$ph = 2929;$$ph = 1;
   break;
  }
  case 9:  {
   $$0$i$ph = 2934;$$ph = 1;
   break;
  }
  default: {
   $37 = (($34) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($6|0)==($38|0);
   if ($39) {
    $$0$i$ph = 2939;$$ph = 1;
   } else {
    $40 = (($34) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($6|0)==($41|0);
    if ($42) {
     $$0$i$ph = 2940;$$ph = 1;
    } else {
     $43 = (($34) + 20|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($6|0)==($44|0);
     if ($45) {
      $$0$i$ph = 2941;$$ph = 1;
     } else {
      $46 = (($34) + 24|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($6|0)==($47|0);
      if ($48) {
       $$0$i$ph = 2942;$$ph = 1;
      } else {
       $49 = (($34) + 32|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($6|0)==($50|0);
       if ($51) {
        $$0$i$ph = 2943;$$ph = 1;
       } else {
        $52 = (($34) + 36|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($6|0)==($53|0);
        if ($54) {
         $$0$i$ph = 2944;$$ph = 1;
        } else {
         $55 = (($34) + 40|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($6|0)==($56|0);
         if ($57) {
          $$0$i$ph = 2945;$$ph = 1;
         } else {
          $58 = (($34) + 52|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = ($6|0)==($59|0);
          if ($60) {
           $$0$i$ph = 2946;$$ph = 1;
          } else {
           $61 = (($34) + 56|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = ($6|0)==($62|0);
           if ($63) {
            $$0$i$ph = 2947;$$ph = 1;
           } else {
            $64 = (($34) + 88|0);
            $65 = HEAP32[$64>>2]|0;
            $66 = ($6|0)==($65|0);
            if ($66) {
             $$0$i$ph = 2948;$$ph = 1;
            } else {
             $67 = (($34) + 492|0);
             $68 = HEAP32[$67>>2]|0;
             $69 = ($6|0)==($68|0);
             do {
              if ($69) {
               label = 44;
              } else {
               $70 = (($34) + 496|0);
               $71 = HEAP32[$70>>2]|0;
               $72 = ($6|0)==($71|0);
               if ($72) {
                label = 44;
               } else {
                $73 = (__Z23scripting_class_is_enumP14ScriptingClass($6)|0);
                if (!($73)) {
                 $97 = (($34) + 280|0);
                 $98 = HEAP32[$97>>2]|0;
                 $99 = ($6|0)==($98|0);
                 if ($99) {
                  $$0$i$ph = 2949;$$ph = 1;
                  break L1;
                 }
                 $100 = (($34) + 504|0);
                 $101 = HEAP32[$100>>2]|0;
                 $102 = ($6|0)==($101|0);
                 if ($102) {
                  $$0$i$ph = 2950;$$ph = 1;
                  break L1;
                 }
                 $103 = (($34) + 28|0);
                 $104 = HEAP32[$103>>2]|0;
                 $105 = ($6|0)==($104|0);
                 if ($105) {
                  $$0$i$ph = 2951;$$ph = 1;
                  break L1;
                 }
                 $106 = (($34) + 272|0);
                 $107 = HEAP32[$106>>2]|0;
                 $108 = ($6|0)==($107|0);
                 if ($108) {
                  $$0$i$ph = 2952;$$ph = 0;
                  break L1;
                 }
                 $109 = ($9|0)==(18);
                 if (!($109)) {
                  label = 44;
                  break;
                 }
                 $110 = (($34) + 244|0);
                 $111 = HEAP32[$110>>2]|0;
                 $112 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$111)|0);
                 if ($112) {
                  $$0$i$ph = 2953;$$ph = 0;
                  break L1;
                 } else {
                  break;
                 }
                }
                $74 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($6)|0);
                $75 = (__Z23scripting_type_get_typeP13ScriptingType($74)|0);
                if ((($75|0) == 8)) {
                 $$0$i$ph = 2933;$$ph = 1;
                 break L1;
                } else if ((($75|0) == 5)) {
                 $$0$i$ph = 2931;$$ph = 1;
                 break L1;
                }
                __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$5);
                $76 = HEAP8[$0>>0]|0;
                $77 = $76 & 1;
                $78 = ($77<<24>>24)==(0);
                if ($78) {
                 $81 = (($0) + 1|0);
                 $82 = $81;
                } else {
                 $79 = (($0) + 8|0);
                 $80 = HEAP32[$79>>2]|0;
                 $82 = $80;
                }
                __THREW__ = 0;
                invoke_viiiiiiii(21,($82|0),0,(630440|0),188,1,0,0,(0|0));
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if (!($84)) {
                 $85 = HEAP8[$0>>0]|0;
                 $86 = $85 & 1;
                 $87 = ($86<<24>>24)==(0);
                 if ($87) {
                  label = 44;
                  break;
                 }
                 $88 = (($0) + 8|0);
                 $89 = HEAP32[$88>>2]|0;
                 __ZdlPv($89);
                 label = 44;
                 break;
                }
                $90 = ___cxa_find_matching_catch()|0;
                $91 = tempRet0;
                $92 = HEAP8[$0>>0]|0;
                $93 = $92 & 1;
                $94 = ($93<<24>>24)==(0);
                if ($94) {
                 ___resumeException($90|0);
                 // unreachable;
                }
                $95 = (($0) + 8|0);
                $96 = HEAP32[$95>>2]|0;
                __ZdlPv($96);
                ___resumeException($90|0);
                // unreachable;
               }
              }
             } while(0);
             if ((label|0) == 44) {
              $$off = (($9) + -17)|0;
              $switch = ($$off>>>0)<(2);
              if (!($switch)) {
               STACKTOP = sp;return;
              }
             }
             __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI14SafeBinaryReadEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$command,$commandQueueBuilder,$nameConversions);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
  }
 } while(0);
 $113 = (($tfi) + 25|0);
 $114 = HEAP8[$113>>0]|0;
 $115 = $114 & $$ph;
 $116 = ($115<<24>>24)==(0);
 if (!($116)) {
  STACKTOP = sp;return;
 }
 $117 = (($command) + 44|0);
 HEAP32[$117>>2] = $$0$i$ph;
 __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$command);
 STACKTOP = sp;return;
}
function __Z46EmitSerializationCommandsForManagedObjectFieldI14SafeBinaryReadEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $args = 0, $newCommandQueueBuilder = 0, $serializeManagedObject = 0, $tfi$idx = 0, $tfi$idx$val = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy1 = sp + 124|0;
 $0 = sp + 120|0;
 $args = sp + 12|0;
 $newCommandQueueBuilder = sp + 32|0;
 $serializeManagedObject = sp + 56|0;
 $$sroa$9 = sp;
 $tfi$idx = (($tfi) + 4|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI18TransferField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$8>>2] = $13;
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 $14 = (($newCommandQueueBuilder) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($newCommandQueueBuilder) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($newCommandQueueBuilder) + 4|0);
 HEAP32[$16>>2] = 61;
 $17 = (($newCommandQueueBuilder) + 16|0);
 HEAP8[$17>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(385,($args|0),($newCommandQueueBuilder|0),($nameConversions|0),0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 do {
  if (!($19)) {
   $20 = (($tfi) + 25|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    label = 8;
   } else {
    $23 = HEAP32[$14>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    dest=$serializeManagedObject+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$serializeManagedObject>>2] = 2954;
    ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
    $33 = HEAP32[$tfi>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3280,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3276,($33|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3278,($37|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_ii(3276,($33|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    $46 = (invoke_ii(3277,($43|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    __THREW__ = 0;
    $49 = (invoke_ii(3283,($33|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    __THREW__ = 0;
    $52 = (invoke_ii(3284,($40|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    $55 = (($tfi) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$tfi$idx>>2]|0;
    $58 = (($tfi) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($serializeManagedObject) + 4|0);
    HEAP32[$60>>2] = $33;
    $61 = (($serializeManagedObject) + 8|0);
    HEAP32[$61>>2] = $34;
    $62 = (($serializeManagedObject) + 12|0);
    HEAP32[$62>>2] = $52;
    $63 = (($serializeManagedObject) + 16|0);
    HEAP32[$63>>2] = $40;
    $64 = (($serializeManagedObject) + 20|0);
    HEAP32[$64>>2] = $46;
    $65 = (($serializeManagedObject) + 24|0);
    HEAP32[$65>>2] = $49;
    $66 = (($serializeManagedObject) + 28|0);
    HEAP32[$66>>2] = $56;
    $67 = (($serializeManagedObject) + 32|0);
    HEAP32[$67>>2] = $57;
    $68 = (($serializeManagedObject) + 36|0);
    HEAP32[$68>>2] = $59;
    $69 = (($serializeManagedObject) + 40|0);
    $70 = $$sroa$9;
    $71 = $70;
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + 4)|0;
    $74 = $73;
    $75 = HEAP32[$74>>2]|0;
    $76 = $69;
    $77 = $76;
    HEAP32[$77>>2] = $72;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = $75;
    $80 = HEAP32[$14>>2]|0;
    $81 = (($serializeManagedObject) + 48|0);
    HEAP32[$81>>2] = $80;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($serializeManagedObject|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($newCommandQueueBuilder|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
   }
   $86 = HEAP32[$15>>2]|0;
   $87 = ($86|0)>(-1);
   if (!($87)) {
    STACKTOP = sp;return;
   }
   $88 = HEAP32[$newCommandQueueBuilder>>2]|0;
   $89 = HEAP32[$16>>2]|0;
   HEAP32[$0>>2] = $89;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($88,$$byval_copy1);
   HEAP32[$newCommandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$15>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$newCommandQueueBuilder>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $90 = ___cxa_find_matching_catch(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 }
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 ___resumeException($25|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, $managedObjectTransferer = 0, $newProvider = 0, $runtimeInfo$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $runtimeInfo$i$i$i = sp + 56|0;
 $converter$i = sp;
 $managedObjectTransferer = sp + 8|0;
 $0 = sp + 24|0;
 $newProvider = sp + 36|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP32[$managedObjectTransferer+0>>2]=0|0;HEAP32[$managedObjectTransferer+4>>2]=0|0;HEAP32[$managedObjectTransferer+8>>2]=0|0;
 $3 = (($managedObjectTransferer) + 4|0);
 HEAP8[$3>>0] = 1;
 $4 = (($managedObjectTransferer) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($managedObjectTransferer) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 $9 = (($args) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(17);
 do {
  if ($8) {
   $$pre$i = (($args) + 12|0);
   if ($11) {
    $16 = 0;
   } else {
    $12 = HEAP32[$$pre$i>>2]|0;
    $13 = (_il2cpp_object_new($12)|0);
    $16 = $13;
   }
   $14 = HEAP32[$$pre$i>>2]|0;
   HEAP8[$0>>0] = 1;
   $15 = (($0) + 4|0);
   HEAP32[$15>>2] = $16;
   $17 = (($0) + 8|0);
   HEAP32[$17>>2] = $14;
   $$pre$phiZ2D = $0;
  } else {
   if ($11) {
    $18 = (($args) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP8[$runtimeInfo>>0]|0;
    $21 = ($20<<24>>24)!=(0);
    $22 = (($19) + -8)|0;
    $23 = $21 ? $19 : $22;
    $24 = (($7) + ($23)|0);
    $25 = (($args) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP8[$0>>0] = 0;
    $27 = (($0) + 4|0);
    HEAP32[$27>>2] = $24;
    $28 = (($0) + 8|0);
    HEAP32[$28>>2] = $26;
    $$pre$phiZ2D = $0;
    break;
   } else {
    $29 = HEAP32[$args>>2]|0;
    __Z30GetOrCreateObjectStoredInFieldP14ScriptingFieldRK17GeneralMonoObjectb($0,$29,$runtimeInfo,1);
    $$pre$phiZ2D = $0;
    break;
   }
  }
 } while(0);
 ;HEAP32[$3+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
 $30 = (($runtimeInfo) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($args) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + ($33<<6)|0);
 HEAP32[$34>>2] = $36;
 $37 = (($newProvider) + 4|0);
 HEAP32[$37>>2] = $35;
 HEAP32[$newProvider>>2] = $35;
 $38 = (($newProvider) + 8|0);
 HEAP32[$38>>2] = $36;
 $$idx$i = $33 << 6;
 $39 = $$idx$i >> 6;
 $40 = (($newProvider) + 16|0);
 HEAP32[$40>>2] = $39;
 $41 = (($newProvider) + 12|0);
 HEAP32[$41>>2] = $39;
 HEAP32[$managedObjectTransferer>>2] = $newProvider;
 $42 = (($args) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($args) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($2,$43,$45,$converter$i,1)|0);
 $47 = ($46|0)==(0);
 if ($47) {
  STACKTOP = sp;return;
 }
 $48 = ($46|0)>(0);
 if ($48) {
  ;HEAP32[$runtimeInfo$i$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+20>>2]=0|0;
  $49 = (($runtimeInfo$i$i$i) + 16|0);
  HEAP32[$49>>2] = $2;
  ;HEAP32[$runtimeInfo$i$i$i+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=HEAP32[$3+8>>2]|0;
  $50 = (($runtimeInfo$i$i$i) + 12|0);
  HEAP32[$50>>2] = $newProvider;
  $51 = HEAP32[$37>>2]|0;
  $52 = HEAP32[$38>>2]|0;
  $53 = ($51|0)==($52|0);
  if (!($53)) {
   $55 = $51;$57 = $52;
   while(1) {
    $54 = (($55) + 64|0);
    HEAP32[$37>>2] = $54;
    $56 = $57;
    $58 = $54;
    $59 = (($56) - ($58))|0;
    $60 = $59 >> 6;
    HEAP32[$41>>2] = $60;
    $61 = HEAP32[$55>>2]|0;
    $62 = (($55) + 4|0);
    FUNCTION_TABLE_vii[$61 & 4095]($62,$runtimeInfo$i$i$i);
    $63 = HEAP32[$37>>2]|0;
    $64 = HEAP32[$38>>2]|0;
    $65 = ($63|0)==($64|0);
    if ($65) {
     break;
    } else {
     $55 = $63;$57 = $64;
    }
   }
  }
 } else {
  $66 = HEAP32[$converter$i>>2]|0;
  $67 = ($66|0)==(0|0);
  if (!($67)) {
   (FUNCTION_TABLE_iii[$66 & 4095]($managedObjectTransferer,$2)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($2);
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22TransferField_NonArrayI14SafeBinaryRead16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,0);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z16Transfer_BuiltinIa14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIh14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z16Transfer_BuiltinIh14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIs14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferIsEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferIyEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferIdEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[580776>>2]|0;
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($10,$12,$13,$converter$i$i,1)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ($14|0)>(0);
 if ($16) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($10,$8,630840,0);
  $$sum = (($5) + 4)|0;
  $17 = (($7) + ($$sum)|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($10,$17,630848,0);
  $$sum1 = (($5) + 8)|0;
  $18 = (($7) + ($$sum1)|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($10,$18,631088,0);
 } else {
  $19 = HEAP32[$converter$i$i>>2]|0;
  $20 = ($19|0)==(0|0);
  if (!($20)) {
   (FUNCTION_TABLE_iii[$19 & 4095]($8,$10)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[580768>>2]|0;
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($10,$12,$13,$converter$i$i,1)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ($14|0)>(0);
 if ($16) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($10,$8,630840,0);
  $$sum = (($5) + 4)|0;
  $17 = (($7) + ($$sum)|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($10,$17,630848,0);
 } else {
  $18 = HEAP32[$converter$i$i>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   (FUNCTION_TABLE_iii[$18 & 4095]($8,$10)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferI5RectTIfEEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($10,$12,631272,$converter$i$i,1)|0);
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = ($13|0)>(0);
 if ($15) {
  __ZN10Matrix4x4f8TransferI14SafeBinaryReadEEvRT_($8,$10);
 } else {
  $16 = HEAP32[$converter$i$i>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   (FUNCTION_TABLE_iii[$16 & 4095]($8,$10)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($10,$12,631264,$converter$i$i,1)|0);
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = ($13|0)>(0);
 if ($15) {
  __ZN4AABB8TransferI14SafeBinaryReadEEvRT_($8,$10);
 } else {
  $16 = HEAP32[$converter$i$i>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   (FUNCTION_TABLE_iii[$16 & 4095]($8,$10)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($10,$8,$12,0);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3214SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[580560>>2]|0;
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($10,$12,$13,$converter$i$i,1)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ($14|0)>(0);
 if ($16) {
  __ZN14SafeBinaryRead10SetVersionEi($10,2);
  $17 = HEAP32[$10>>2]|0;
  $18 = $17 & 512;
  $19 = ($18|0)==(0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($10,$8,631048,0);
  if (!($19)) {
   $20 = HEAP32[$8>>2]|0;
   $21 = (_llvm_bswap_i32(($20|0))|0);
   HEAP32[$8>>2] = $21;
  }
 } else {
  $22 = HEAP32[$converter$i$i>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   (FUNCTION_TABLE_iii[$22 & 4095]($8,$10)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($10,$12,631248,$converter$i$i,1)|0);
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = ($13|0)>(0);
 if ($15) {
  __ZN14SafeBinaryRead10SetVersionEi($10,2);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($10,$8,631040,0);
  $16 = (__ZN14SafeBinaryRead12IsOldVersionEi($10,1)|0);
  if ($16) {
   $17 = HEAP32[$8>>2]|0;
   $18 = $17 & 32;
   $19 = ($18|0)==(0);
   if (!($19)) {
    $20 = $17 | -65536;
    HEAP32[$8>>2] = $20;
   }
  }
 } else {
  $21 = HEAP32[$converter$i$i>>2]|0;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   (FUNCTION_TABLE_iii[$21 & 4095]($8,$10)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI14SafeBinaryRead17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI14SafeBinaryRead27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI14SafeBinaryRead11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI14SafeBinaryRead27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI14SafeBinaryRead10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$val$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$native$i$i+0>>2]=0|0;HEAP32[$native$i$i+4>>2]=0|0;HEAP32[$native$i$i+8>>2]=0|0;HEAP32[$native$i$i+12>>2]=0|0;
 $2 = (($runtimeInfo) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN14SafeBinaryRead8TransferI10RectOffsetEEvRT_PKc17TransferMetaFlags($3,$native$i$i,$5,0);
 $6 = (($3) + 136|0);
 $$idx$val$i$i = HEAP8[$6>>0]|0;
 $7 = ($$idx$val$i$i<<24>>24)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($args) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$runtimeInfo>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = (($9) + -8)|0;
 $13 = $11 ? $9 : $12;
 $14 = (($runtimeInfo) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($13)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $19 = (_il2cpp_object_new($1)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($19);
  $21 = $19;
 } else {
  $21 = $17;
 }
 $20 = (($21) + 8|0);
 $22 = HEAP32[$20>>2]|0;
 ;HEAP32[$22+0>>2]=HEAP32[$native$i$i+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$native$i$i+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$native$i$i+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$native$i$i+12>>2]|0;
 $23 = HEAP32[$8>>2]|0;
 $24 = HEAP8[$runtimeInfo>>0]|0;
 $25 = ($24<<24>>24)!=(0);
 $26 = (($23) + -8)|0;
 $27 = $25 ? $23 : $26;
 $28 = HEAP32[$14>>2]|0;
 $29 = (($28) + ($27)|0);
 HEAP32[$29>>2] = $21;
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI14SafeBinaryRead8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI14SafeBinaryRead27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$val$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$native$i$i>>2] = 0;
 $5 = (($native$i$i) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($native$i$i) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($args) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN14SafeBinaryRead8TransferI8MonoPPtrEEvRT_PKc17TransferMetaFlags($1,$native$i$i,$8,0);
 $9 = (($1) + 136|0);
 $$idx$val$i$i = HEAP8[$9>>0]|0;
 $10 = ($$idx$val$i$i<<24>>24)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$native$i$i>>2]|0;
 $12 = (__Z24TransferPPtrToMonoObjectiP14ScriptingClassP23DataToCreateNullWrapper24TransferInstructionFlags($11,$3,0,$4)|0);
 $13 = (($args) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP8[$runtimeInfo>>0]|0;
 $16 = ($15<<24>>24)!=(0);
 $17 = (($14) + -8)|0;
 $18 = $16 ? $14 : $17;
 $19 = (($runtimeInfo) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($18)|0);
 HEAP32[$21>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI8MonoPPtrEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$0$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0$lcssa$i$i = 0, $c$01$i$i = 0, $className$02$i$i = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0$i = 630432;
 } else {
  $4 = (($data) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($2) + 1|0);
  HEAP8[$2>>0] = 80;
  $7 = (($2) + 2|0);
  HEAP8[$6>>0] = 80;
  $8 = (($2) + 3|0);
  HEAP8[$7>>0] = 116;
  $9 = (($2) + 4|0);
  HEAP8[$8>>0] = 114;
  $10 = (($2) + 5|0);
  HEAP8[$9>>0] = 60;
  $11 = (($2) + 6|0);
  HEAP8[$10>>0] = 36;
  $12 = (__Z24scripting_class_get_nameP14ScriptingClass($5)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $c$0$lcssa$i$i = $11;
  } else {
   $15 = $13;$c$01$i$i = $11;$className$02$i$i = $12;
   while(1) {
    HEAP8[$c$01$i$i>>0] = $15;
    $16 = (($c$01$i$i) + 1|0);
    $17 = (($className$02$i$i) + 1|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     $c$0$lcssa$i$i = $16;
     break;
    } else {
     $15 = $18;$c$01$i$i = $16;$className$02$i$i = $17;
    }
   }
  }
  $20 = (($c$0$lcssa$i$i) + 1|0);
  HEAP8[$c$0$lcssa$i$i>>0] = 62;
  HEAP8[$20>>0] = 0;
  $$0$i = $2;
 }
 $21 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$$0$i,$converter$i,1)|0);
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = ($21|0)>(0);
 if ($23) {
  __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($data,$this);
 } else {
  $24 = HEAP32[$converter$i>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   (FUNCTION_TABLE_iii[$24 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __Z22TransferField_NonArrayI14SafeBinaryRead27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $converter$i$i = 0, $invocation$i = 0, $method$i = 0, $native = 0, $scripting1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy1 = sp + 352|0;
 $method$i = sp;
 $invocation$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 48|0;
 $converter$i$i = sp + 52|0;
 $native = sp + 56|0;
 $scripting1 = sp + 348|0;
 __ZN8GUIStyleC2Ev($native);
 $2 = (($runtimeInfo) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($staticInfo) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiiiii(192,($3|0),($5|0),(631120|0),($converter$i$i|0),1)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   $9 = ($6|0)==(0);
   if (!($9)) {
    $10 = ($6|0)>(0);
    if ($10) {
     __THREW__ = 0;
     invoke_vii(2955,($native|0),($3|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    } else {
     $13 = HEAP32[$converter$i$i>>2]|0;
     $14 = ($13|0)==(0|0);
     if (!($14)) {
      __THREW__ = 0;
      (invoke_iii($13|0,($native|0),($3|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($3|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
   }
   $30 = (($3) + 136|0);
   $$idx$val = HEAP8[$30>>0]|0;
   $31 = ($$idx$val<<24>>24)==(0);
   if (!($31)) {
    $32 = (($staticInfo) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP8[$runtimeInfo>>0]|0;
    $35 = ($34<<24>>24)!=(0);
    $36 = (($33) + -8)|0;
    $37 = $35 ? $33 : $36;
    $38 = (($runtimeInfo) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + ($37)|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$scripting1>>2] = $41;
    __THREW__ = 0;
    invoke_viii(1797,($converter|0),($native|0),($scripting1|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     break;
    }
    $44 = HEAP32[$32>>2]|0;
    $45 = HEAP8[$runtimeInfo>>0]|0;
    $46 = ($45<<24>>24)!=(0);
    $47 = (($44) + -8)|0;
    $48 = $46 ? $44 : $47;
    $49 = HEAP32[$38>>2]|0;
    $50 = (($49) + ($48)|0);
    $51 = HEAP32[$scripting1>>2]|0;
    HEAP32[$50>>2] = $51;
    __THREW__ = 0;
    $52 = (invoke_i(84)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    $55 = (($52) + 308|0);
    $56 = HEAP32[$55>>2]|0;
    __THREW__ = 0;
    invoke_viiii(388,($method$i|0),($56|0),(630336|0),1);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     break;
    }
    $59 = HEAP32[$method$i>>2]|0;
    $60 = ($59|0)==(0|0);
    if (!($60)) {
     $61 = $method$i;
     $62 = $61;
     $63 = HEAP32[$62>>2]|0;
     $64 = (($61) + 4)|0;
     $65 = $64;
     $66 = HEAP32[$65>>2]|0;
     $67 = $0;
     $68 = $67;
     HEAP32[$68>>2] = $63;
     $69 = (($67) + 4)|0;
     $70 = $69;
     HEAP32[$70>>2] = $66;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;
     invoke_vii(2863,($invocation$i|0),($$byval_copy1|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      break;
     }
     $73 = (($invocation$i) + 12|0);
     HEAP32[$73>>2] = $51;
     __THREW__ = 0;
     (invoke_ii(3285,($invocation$i|0))|0);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      break;
     }
    }
   }
   $76 = HEAP8[$native>>0]|0;
   $77 = $76 & 1;
   $78 = ($77<<24>>24)==(0);
   if ($78) {
    STACKTOP = sp;return;
   }
   $79 = (($native) + 8|0);
   $80 = HEAP32[$79>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy1|0));
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    $83 = ___cxa_find_matching_catch()|0;
    $84 = tempRet0;
    ___cxa_call_unexpected(($83|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $21 = HEAP8[$native>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  ___resumeException($19|0);
  // unreachable;
 }
 $24 = (($native) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy1|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  ___cxa_call_unexpected(($28|0));
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __ZN8GUIStyle8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i10 = 0, $$sum$i$i$i$i$i15 = 0, $$sum$i$i$i$i$i4 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i11 = 0, $$sum1$i$i$i$i$i16 = 0, $$sum1$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i14 = sp;
 $0 = HEAP32[580712>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,630448,$0,$converter$i$i14,0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i14>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($transfer,$6,630456,0);
 $7 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($transfer,$7,630472,0);
 $8 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($transfer,$8,630480,0);
 $9 = (($this) + 72|0);
 __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($transfer,$9,630496,0);
 $10 = (($this) + 92|0);
 __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($transfer,$10,630512,0);
 $11 = (($this) + 112|0);
 __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($transfer,$11,630528,0);
 $12 = (($this) + 132|0);
 __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($transfer,$12,630544,0);
 $13 = (($this) + 152|0);
 __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($transfer,$13,630560,0);
 $14 = (($this) + 172|0);
 __ZN14SafeBinaryRead8TransferI10RectOffsetEEvRT_PKc17TransferMetaFlags($transfer,$14,630576,0);
 $15 = (($this) + 188|0);
 __ZN14SafeBinaryRead8TransferI10RectOffsetEEvRT_PKc17TransferMetaFlags($transfer,$15,630592,0);
 $16 = (($this) + 204|0);
 __ZN14SafeBinaryRead8TransferI10RectOffsetEEvRT_PKc17TransferMetaFlags($transfer,$16,630608,0);
 $17 = (($this) + 220|0);
 __ZN14SafeBinaryRead8TransferI10RectOffsetEEvRT_PKc17TransferMetaFlags($transfer,$17,630624,0);
 $18 = (($this) + 236|0);
 $19 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,630640,631136,$converter$i$i14,1)|0);
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = ($19|0)>(0);
  if ($21) {
   __ZN4PPtrIN13TextRendering4FontEE8TransferI14SafeBinaryReadEEvRT_($18,$transfer);
  } else {
   $22 = HEAP32[$converter$i$i14>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    (FUNCTION_TABLE_iii[$22 & 4095]($18,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $24 = (($this) + 280|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$24,630648,0);
 $25 = (($this) + 284|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$25,630664,0);
 $26 = (($this) + 240|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$26,630680,0);
 $27 = (($this) + 244|0);
 $28 = HEAP32[580544>>2]|0;
 $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,630696,$28,$converter$i$i14,0)|0);
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = ($29|0)>(0);
  do {
   if ($31) {
    $32 = (($transfer) + 12|0);
    $33 = (($transfer) + 80|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($34) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($transfer) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($transfer) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($transfer) + 32|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = Math_imul($42, $40)|0;
    $$sum$i$i$i$i$i = (($36) - ($43))|0;
    $44 = (($38) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$32>>2] = $44;
    $45 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($45)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $46 = (($38) + ($$sum1$i$i$i$i$i)|0);
     $47 = (($transfer) + 20|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($46>>>0)>($48>>>0);
     if (!($49)) {
      $50 = HEAP8[$44>>0]|0;
      HEAP8[$27>>0] = $50;
      $51 = HEAP32[$32>>2]|0;
      $52 = (($51) + 1|0);
      HEAP32[$32>>2] = $52;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($32,$27,1);
   } else {
    $53 = HEAP32[$converter$i$i14>>2]|0;
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     (FUNCTION_TABLE_iii[$53 & 4095]($27,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $55 = (($this) + 245|0);
 $56 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,630712,$28,$converter$i$i14,0)|0);
 $57 = ($56|0)==(0);
 if (!($57)) {
  $58 = ($56|0)>(0);
  do {
   if ($58) {
    $59 = (($transfer) + 12|0);
    $60 = (($transfer) + 80|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61) + 12|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($transfer) + 16|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($transfer) + 28|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($transfer) + 32|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = Math_imul($69, $67)|0;
    $$sum$i$i$i$i$i4 = (($63) - ($70))|0;
    $71 = (($65) + ($$sum$i$i$i$i$i4)|0);
    HEAP32[$59>>2] = $71;
    $72 = ($$sum$i$i$i$i$i4|0)<(0);
    if (!($72)) {
     $$sum1$i$i$i$i$i5 = (($$sum$i$i$i$i$i4) + 1)|0;
     $73 = (($65) + ($$sum1$i$i$i$i$i5)|0);
     $74 = (($transfer) + 20|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = ($73>>>0)>($75>>>0);
     if (!($76)) {
      $77 = HEAP8[$71>>0]|0;
      HEAP8[$55>>0] = $77;
      $78 = HEAP32[$59>>2]|0;
      $79 = (($78) + 1|0);
      HEAP32[$59>>2] = $79;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($59,$55,1);
   } else {
    $80 = HEAP32[$converter$i$i14>>2]|0;
    $81 = ($80|0)==(0|0);
    if (!($81)) {
     (FUNCTION_TABLE_iii[$80 & 4095]($55,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $82 = (($this) + 248|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$82,630728,0);
 $83 = (($this) + 252|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$83,630744,0);
 $84 = (($this) + 256|0);
 $85 = HEAP32[580768>>2]|0;
 $86 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,630760,$85,$converter$i$i14,1)|0);
 $87 = ($86|0)==(0);
 if (!($87)) {
  $88 = ($86|0)>(0);
  if ($88) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$84,630840,0);
   $89 = (($this) + 260|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$89,630848,0);
  } else {
   $90 = HEAP32[$converter$i$i14>>2]|0;
   $91 = ($90|0)==(0|0);
   if (!($91)) {
    (FUNCTION_TABLE_iii[$90 & 4095]($84,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $92 = (($this) + 272|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$92,630776,0);
 $93 = (($this) + 276|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$93,630792,0);
 $94 = (($this) + 288|0);
 $95 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,630808,$28,$converter$i$i14,0)|0);
 $96 = ($95|0)==(0);
 if (!($96)) {
  $97 = ($95|0)>(0);
  do {
   if ($97) {
    $98 = (($transfer) + 12|0);
    $99 = (($transfer) + 80|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($100) + 12|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (($transfer) + 16|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($transfer) + 28|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = (($transfer) + 32|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = Math_imul($108, $106)|0;
    $$sum$i$i$i$i$i10 = (($102) - ($109))|0;
    $110 = (($104) + ($$sum$i$i$i$i$i10)|0);
    HEAP32[$98>>2] = $110;
    $111 = ($$sum$i$i$i$i$i10|0)<(0);
    if (!($111)) {
     $$sum1$i$i$i$i$i11 = (($$sum$i$i$i$i$i10) + 1)|0;
     $112 = (($104) + ($$sum1$i$i$i$i$i11)|0);
     $113 = (($transfer) + 20|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($112>>>0)>($114>>>0);
     if (!($115)) {
      $116 = HEAP8[$110>>0]|0;
      HEAP8[$94>>0] = $116;
      $117 = HEAP32[$98>>2]|0;
      $118 = (($117) + 1|0);
      HEAP32[$98>>2] = $118;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($98,$94,1);
   } else {
    $119 = HEAP32[$converter$i$i14>>2]|0;
    $120 = ($119|0)==(0|0);
    if (!($120)) {
     (FUNCTION_TABLE_iii[$119 & 4095]($94,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $121 = (($this) + 289|0);
 $122 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,630824,$28,$converter$i$i14,0)|0);
 $123 = ($122|0)==(0);
 if ($123) {
  STACKTOP = sp;return;
 }
 $124 = ($122|0)>(0);
 do {
  if ($124) {
   $125 = (($transfer) + 12|0);
   $126 = (($transfer) + 80|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($127) + 12|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = (($transfer) + 16|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = (($transfer) + 28|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = (($transfer) + 32|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = Math_imul($135, $133)|0;
   $$sum$i$i$i$i$i15 = (($129) - ($136))|0;
   $137 = (($131) + ($$sum$i$i$i$i$i15)|0);
   HEAP32[$125>>2] = $137;
   $138 = ($$sum$i$i$i$i$i15|0)<(0);
   if (!($138)) {
    $$sum1$i$i$i$i$i16 = (($$sum$i$i$i$i$i15) + 1)|0;
    $139 = (($131) + ($$sum1$i$i$i$i$i16)|0);
    $140 = (($transfer) + 20|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = ($139>>>0)>($141>>>0);
    if (!($142)) {
     $143 = HEAP8[$137>>0]|0;
     HEAP8[$121>>0] = $143;
     $144 = HEAP32[$125>>2]|0;
     $145 = (($144) + 1|0);
     HEAP32[$125>>2] = $145;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($125,$121,1);
  } else {
   $146 = HEAP32[$converter$i$i14>>2]|0;
   $147 = ($146|0)==(0|0);
   if (!($147)) {
    (FUNCTION_TABLE_iii[$146 & 4095]($121,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI13GUIStyleStateEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, $converter$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i$i = sp + 4|0;
 $converter$i = sp;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,631168,$converter$i,1)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ($1|0)>(0);
 if ($3) {
  $4 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630896,631184,$converter$i$i$i$i,1)|0);
  $5 = ($4|0)==(0);
  if (!($5)) {
   $6 = ($4|0)>(0);
   if ($6) {
    __ZN4PPtrI9Texture2DE8TransferI14SafeBinaryReadEEvRT_($data,$this);
   } else {
    $7 = HEAP32[$converter$i$i$i$i>>2]|0;
    $8 = ($7|0)==(0|0);
    if (!($8)) {
     (FUNCTION_TABLE_iii[$7 & 4095]($data,$this)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
  $9 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($this,$9,630912,0);
 } else {
  $10 = HEAP32[$converter$i>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   (FUNCTION_TABLE_iii[$10 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI10RectOffsetEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,631152,$converter$i,1)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ($1|0)>(0);
 if ($3) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$data,630856,0);
  $4 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$4,630864,0);
  $5 = (($data) + 8|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$5,630872,0);
  $6 = (($data) + 12|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$6,630880,0);
 } else {
  $7 = HEAP32[$converter$i>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   (FUNCTION_TABLE_iii[$7 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrIN13TextRendering4FontEE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,630400,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,630416,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,630400,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,630416,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __Z22TransferField_NonArrayI14SafeBinaryRead27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $native = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $converter$i$i = sp + 68|0;
 $native = sp;
 __ZN11GradientNEWC2Ev($native);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($staticInfo) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 $4 = (invoke_iiiiii(192,($1|0),($3|0),(631200|0),($converter$i$i|0),1)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   $7 = ($4|0)==(0);
   if (!($7)) {
    $8 = ($4|0)>(0);
    if ($8) {
     __THREW__ = 0;
     invoke_vii(2956,($native|0),($1|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    } else {
     $11 = HEAP32[$converter$i$i>>2]|0;
     $12 = ($11|0)==(0|0);
     if (!($12)) {
      __THREW__ = 0;
      (invoke_iii($11|0,($native|0),($1|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($1|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
   }
   $21 = (($1) + 136|0);
   $$idx$val = HEAP8[$21>>0]|0;
   $22 = ($$idx$val<<24>>24)==(0);
   if ($22) {
    STACKTOP = sp;return;
   }
   $23 = (($staticInfo) + 20|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP8[$runtimeInfo>>0]|0;
   $26 = ($25<<24>>24)!=(0);
   $27 = (($24) + -8)|0;
   $28 = $26 ? $24 : $27;
   $29 = (($runtimeInfo) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + ($28)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    $34 = HEAP32[$converter>>2]|0;
    __THREW__ = 0;
    $35 = (invoke_ii(3286,($34|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3549,($35|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    } else {
     $41 = $35;
    }
   } else {
    $41 = $32;
   }
   $40 = (($41) + 8|0);
   $42 = HEAP32[$40>>2]|0;
   $43 = HEAP32[$native>>2]|0;
   HEAP32[$42>>2] = $43;
   $44 = (($42) + 4|0);
   $45 = (($native) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   HEAP32[$44>>2] = $46;
   $47 = (($42) + 8|0);
   $48 = (($native) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   HEAP32[$47>>2] = $49;
   $50 = (($42) + 12|0);
   $51 = (($native) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$50>>2] = $52;
   $53 = (($42) + 16|0);
   $54 = (($native) + 16|0);
   $55 = HEAP32[$54>>2]|0;
   HEAP32[$53>>2] = $55;
   $56 = (($42) + 20|0);
   $57 = (($native) + 20|0);
   $58 = HEAP32[$57>>2]|0;
   HEAP32[$56>>2] = $58;
   $59 = (($42) + 24|0);
   $60 = (($native) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   HEAP32[$59>>2] = $61;
   $62 = (($42) + 28|0);
   $63 = (($native) + 28|0);
   $64 = HEAP32[$63>>2]|0;
   HEAP32[$62>>2] = $64;
   $65 = (($42) + 32|0);
   $66 = (($native) + 32|0);
   dest=$65+0|0; src=$66+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
   $67 = HEAP32[$23>>2]|0;
   $68 = HEAP8[$runtimeInfo>>0]|0;
   $69 = ($68<<24>>24)!=(0);
   $70 = (($67) + -8)|0;
   $71 = $69 ? $67 : $70;
   $72 = HEAP32[$29>>2]|0;
   $73 = (($72) + ($71)|0);
   HEAP32[$73>>2] = $41;
   STACKTOP = sp;return;
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $74 = ___cxa_find_matching_catch(0|0)|0;
  $75 = tempRet0;
  ___clang_call_terminate($74);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __Z22TransferField_NonArrayI14SafeBinaryRead27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $native = 0, $scripting1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 92|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $native = sp + 8|0;
 $scripting1 = sp + 88|0;
 $1 = (($native) + 4|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 HEAP32[$native>>2] = 0;
 $2 = (($native) + 8|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $3 = (($native) + 32|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($native) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($native) + 36|0);
 $6 = (($native) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($native) + 68|0);
 HEAP32[$7>>2] = 0;
 $8 = (($native) + 60|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$8>>2] = 61;
 $9 = (($native) + 76|0);
 HEAP32[$9>>2] = 2;
 $10 = (($native) + 72|0);
 HEAP32[$10>>2] = 2;
 $11 = (($runtimeInfo) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($staticInfo) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __THREW__ = 0;
 $15 = (invoke_iiiiii(192,($12|0),($14|0),(631216|0),($converter$i$i|0),1)|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if (!($17)) {
   $18 = ($15|0)==(0);
   if (!($18)) {
    $19 = ($15|0)>(0);
    if ($19) {
     __THREW__ = 0;
     invoke_vii(2957,($native|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
    } else {
     $22 = HEAP32[$converter$i$i>>2]|0;
     $23 = ($22|0)==(0|0);
     if (!($23)) {
      __THREW__ = 0;
      (invoke_iii($22|0,($native|0),($12|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($12|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
   }
   $37 = (($12) + 136|0);
   $$idx$val = HEAP8[$37>>0]|0;
   $38 = ($$idx$val<<24>>24)==(0);
   if (!($38)) {
    $39 = (($staticInfo) + 20|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = HEAP8[$runtimeInfo>>0]|0;
    $42 = ($41<<24>>24)!=(0);
    $43 = (($40) + -8)|0;
    $44 = $42 ? $40 : $43;
    $45 = (($runtimeInfo) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($46) + ($44)|0);
    $48 = HEAP32[$47>>2]|0;
    HEAP32[$scripting1>>2] = $48;
    __THREW__ = 0;
    invoke_viii(1798,($converter|0),($native|0),($scripting1|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    $51 = HEAP32[$39>>2]|0;
    $52 = HEAP8[$runtimeInfo>>0]|0;
    $53 = ($52<<24>>24)!=(0);
    $54 = (($51) + -8)|0;
    $55 = $53 ? $51 : $54;
    $56 = HEAP32[$45>>2]|0;
    $57 = (($56) + ($55)|0);
    $58 = HEAP32[$scripting1>>2]|0;
    HEAP32[$57>>2] = $58;
   }
   $59 = HEAP32[$7>>2]|0;
   $60 = ($59|0)>(-1);
   if (!($60)) {
    STACKTOP = sp;return;
   }
   $61 = (($native) + 56|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $63;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($62,$$byval_copy1);
   HEAP32[$61>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 $30 = HEAP32[$7>>2]|0;
 $31 = ($30|0)>(-1);
 if (!($31)) {
  ___resumeException($28|0);
  // unreachable;
 }
 $32 = (($native) + 56|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $34;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy1|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $64 = ___cxa_find_matching_catch(0|0)|0;
  $65 = tempRet0;
  ___clang_call_terminate($64);
  // unreachable;
 }
 HEAP32[$32>>2] = 0;
 ___resumeException($28|0);
 // unreachable;
}
function __ZN17AnimationCurveTplIfE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 56|0);
 $1 = HEAP32[580760>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,630960,$1,$converter$i$i,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplIfELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 72|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$7,630968,0);
 $8 = (($this) + 76|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$8,630984,0);
 __ZN17AnimationCurveTplIfE15InvalidateCacheEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplIfELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplIfELj4EEE19ResizeSTLStyleArrayERS3_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<4)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631232,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$01,631000,0);
       $48 = (($i$01) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$48,631008,0);
       $49 = (($i$01) + 8|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,631016,0);
       $50 = (($i$01) + 12|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,631024,0);
       $51 = (($i$01) + 16|0);
       $52 = ($51|0)==($11|0);
       if ($52) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $51;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $53 = HEAP32[$data>>2]|0;
   $54 = ($53|0)==($11|0);
   if (!($54)) {
    $i$12 = $53;
    while(1) {
     $55 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631232,$$byval_copy,1)|0);
     $56 = ($55|0)==(0);
     if (!($56)) {
      $57 = ($55|0)>(0);
      if ($57) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$12,631000,0);
       $58 = (($i$12) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$58,631008,0);
       $59 = (($i$12) + 8|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$59,631016,0);
       $60 = (($i$12) + 12|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$60,631024,0);
      } else {
       $61 = HEAP32[$$byval_copy>>2]|0;
       $62 = ($61|0)==(0|0);
       if (!($62)) {
        (FUNCTION_TABLE_iii[$61 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $63 = (($i$12) + 16|0);
     $64 = ($63|0)==($11|0);
     if ($64) {
      break;
     } else {
      $i$12 = $63;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580640>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$data,630840,0);
  $5 = (($data) + 4|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$5,630848,0);
  $6 = (($data) + 8|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$6,631088,0);
  $7 = (($data) + 12|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$7,631096,0);
 } else {
  $8 = HEAP32[$converter$i>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   (FUNCTION_TABLE_iii[$8 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferIdEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580568>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  $5 = (($this) + 12|0);
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $13)|0;
  $$sum$i$i$i = (($9) - ($16))|0;
  $17 = (($11) + ($$sum$i$i$i)|0);
  HEAP32[$5>>2] = $17;
  $18 = ($$sum$i$i$i|0)<(0);
  if ($18) {
   label = 6;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 8)|0;
   $19 = (($11) + ($$sum1$i$i$i)|0);
   $20 = (($this) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19>>>0)>($21>>>0);
   if ($22) {
    label = 6;
   } else {
    HEAP8[tempDoublePtr>>0]=HEAP8[$17>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$17+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$17+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$17+3>>0];HEAP8[tempDoublePtr+4>>0]=HEAP8[$17+4>>0];HEAP8[tempDoublePtr+5>>0]=HEAP8[$17+5>>0];HEAP8[tempDoublePtr+6>>0]=HEAP8[$17+6>>0];HEAP8[tempDoublePtr+7>>0]=HEAP8[$17+7>>0];$23 = +HEAPF64[tempDoublePtr>>3];
    HEAPF64[tempDoublePtr>>3]=$23;HEAP8[$data>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$data+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$data+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$data+3>>0]=HEAP8[tempDoublePtr+3>>0];HEAP8[$data+4>>0]=HEAP8[tempDoublePtr+4>>0];HEAP8[$data+5>>0]=HEAP8[tempDoublePtr+5>>0];HEAP8[$data+6>>0]=HEAP8[tempDoublePtr+6>>0];HEAP8[$data+7>>0]=HEAP8[tempDoublePtr+7>>0];
    $24 = HEAP32[$5>>2]|0;
    $25 = (($24) + 8|0);
    HEAP32[$5>>2] = $25;
   }
  }
  if ((label|0) == 6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,8);
  }
  $26 = HEAP32[$this>>2]|0;
  $27 = $26 & 512;
  $28 = ($27|0)==(0);
  if (!($28)) {
   $29 = HEAP32[$data>>2]|0;
   $30 = (_llvm_bswap_i32(($29|0))|0);
   $31 = (($data) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (_llvm_bswap_i32(($32|0))|0);
   HEAP32[$data>>2] = $33;
   HEAP32[$31>>2] = $30;
  }
 } else {
  $34 = HEAP32[$converter$i>>2]|0;
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   (FUNCTION_TABLE_iii[$34 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferIsEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 $1 = HEAP32[580672>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$1,$converter$i,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ($2|0)>(0);
 if ($4) {
  $5 = (($this) + 12|0);
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 32|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $13)|0;
  $$sum$i$i$i = (($9) - ($16))|0;
  $17 = (($11) + ($$sum$i$i$i)|0);
  HEAP32[$5>>2] = $17;
  $18 = ($$sum$i$i$i|0)<(0);
  if ($18) {
   label = 6;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 2)|0;
   $19 = (($11) + ($$sum1$i$i$i)|0);
   $20 = (($this) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19>>>0)>($21>>>0);
   if ($22) {
    label = 6;
   } else {
    $23 = HEAP16[$17>>1]|0;
    HEAP16[$data>>1] = $23;
    HEAP32[$5>>2] = $19;
   }
  }
  if ((label|0) == 6) {
   __ZN12CachedReader15UpdateReadCacheEPvj($5,$data,2);
  }
  $24 = HEAP32[$this>>2]|0;
  $25 = $24 & 512;
  $26 = ($25|0)==(0);
  if (!($26)) {
   $27 = HEAP16[$data>>1]|0;
   $28 = $27&65535;
   $29 = $28 << 8;
   $30 = $28 >>> 8;
   $31 = $29 | $30;
   $32 = $31&65535;
   HEAP16[$data>>1] = $32;
  }
 } else {
  $33 = HEAP32[$converter$i>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   (FUNCTION_TABLE_iii[$33 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIh14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[580744>>2]|0;
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($10,$12,$13,$converter$i$i,0)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ($14|0)>(0);
 do {
  if ($16) {
   $17 = (($10) + 12|0);
   $18 = (($10) + 80|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($10) + 16|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($10) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($10) + 32|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = Math_imul($27, $25)|0;
   $$sum$i$i$i$i$i = (($21) - ($28))|0;
   $29 = (($23) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$17>>2] = $29;
   $30 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($30)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $31 = (($23) + ($$sum1$i$i$i$i$i)|0);
    $32 = (($10) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($31>>>0)>($33>>>0);
    if (!($34)) {
     $35 = HEAP8[$29>>0]|0;
     HEAP8[$8>>0] = $35;
     $36 = HEAP32[$17>>2]|0;
     $37 = (($36) + 1|0);
     HEAP32[$17>>2] = $37;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($17,$8,1);
  } else {
   $38 = HEAP32[$converter$i$i>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    (FUNCTION_TABLE_iii[$38 & 4095]($8,$10)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIa14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[580696>>2]|0;
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($10,$12,$13,$converter$i$i,0)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ($14|0)>(0);
 do {
  if ($16) {
   $17 = (($10) + 12|0);
   $18 = (($10) + 80|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($10) + 16|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($10) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($10) + 32|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = Math_imul($27, $25)|0;
   $$sum$i$i$i$i$i = (($21) - ($28))|0;
   $29 = (($23) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$17>>2] = $29;
   $30 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($30)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $31 = (($23) + ($$sum1$i$i$i$i$i)|0);
    $32 = (($10) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($31>>>0)>($33>>>0);
    if (!($34)) {
     $35 = HEAP8[$29>>0]|0;
     HEAP8[$8>>0] = $35;
     $36 = HEAP32[$17>>2]|0;
     $37 = (($36) + 1|0);
     HEAP32[$17>>2] = $37;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($17,$8,1);
  } else {
   $38 = HEAP32[$converter$i$i>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    (FUNCTION_TABLE_iii[$38 & 4095]($8,$10)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z22TransferField_NonArrayI14SafeBinaryRead16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $converter$i$i = 0, $native = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $native = sp + 8|0;
 ;HEAP32[$native+0>>2]=0|0;HEAP32[$native+4>>2]=0|0;HEAP32[$native+8>>2]=0|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($staticInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[580712>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiiiii(192,($2|0),($4|0),($5|0),($converter$i$i|0),0)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   $9 = ($6|0)==(0);
   if (!($9)) {
    $10 = ($6|0)>(0);
    if ($10) {
     __THREW__ = 0;
     invoke_viii(1620,($2|0),($native|0),0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    } else {
     $13 = HEAP32[$converter$i$i>>2]|0;
     $14 = ($13|0)==(0|0);
     if (!($14)) {
      __THREW__ = 0;
      (invoke_iii($13|0,($native|0),($2|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($2|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
   }
   $30 = (($2) + 136|0);
   $$idx$val = HEAP8[$30>>0]|0;
   $31 = ($$idx$val<<24>>24)==(0);
   if (!($31)) {
    $32 = HEAP8[$native>>0]|0;
    $33 = $32 & 1;
    $34 = ($33<<24>>24)==(0);
    if ($34) {
     $37 = (($native) + 1|0);
     $38 = $37;
    } else {
     $35 = (($native) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $38 = $36;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3287,($38|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    $42 = (($staticInfo) + 20|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP8[$runtimeInfo>>0]|0;
    $45 = ($44<<24>>24)!=(0);
    $46 = (($43) + -8)|0;
    $47 = $45 ? $43 : $46;
    $48 = (($runtimeInfo) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($49) + ($47)|0);
    HEAP32[$50>>2] = $39;
   }
   $51 = HEAP8[$native>>0]|0;
   $52 = $51 & 1;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    STACKTOP = sp;return;
   }
   $54 = (($native) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($55|0),($$byval_copy1|0));
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    ___cxa_call_unexpected(($58|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $21 = HEAP8[$native>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  ___resumeException($19|0);
  // unreachable;
 }
 $24 = (($native) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy1|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  ___cxa_call_unexpected(($28|0));
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __Z30TransferField_LinearCollectionI14SafeBinaryReadEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $array = 0, $linearCollectionField = 0, $newRuntimeInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $linearCollectionField = sp + 40|0;
 $array = sp;
 $0 = sp + 8|0;
 $newRuntimeInfo = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$runtimeInfo,$1);
 HEAP32[$array>>2] = 0;
 $2 = (($array) + 4|0);
 HEAP32[$2>>2] = -1;
 $3 = (($runtimeInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $18 = 0;
 } else {
  __ZN21LinearCollectionField8GetArrayEv($0,$linearCollectionField);
  $6 = $0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $array;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  $$pre = HEAP32[$3>>2]|0;
  $18 = $$pre;
 }
 $16 = HEAP8[$runtimeInfo>>0]|0;
 HEAP8[$newRuntimeInfo>>0] = $16;
 $17 = (($newRuntimeInfo) + 4|0);
 HEAP32[$17>>2] = $18;
 $19 = (($newRuntimeInfo) + 8|0);
 $20 = (($runtimeInfo) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = (($newRuntimeInfo) + 12|0);
 $23 = (($runtimeInfo) + 12|0);
 $24 = $23;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $22;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (($newRuntimeInfo) + 20|0);
 HEAP32[$34>>2] = $array;
 $35 = (($args) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($args,$newRuntimeInfo);
 $37 = HEAP32[$2>>2]|0;
 $38 = ($37|0)==(-1);
 if ($38) {
  STACKTOP = sp;return;
 }
 __ZN21LinearCollectionField8SetArrayERK9ArrayInfo($linearCollectionField,$array);
 STACKTOP = sp;return;
}
function __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI14SafeBinaryReadEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$partiallySetuplinearCollectionCommand,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $partiallySetuplinearCollectionCommand = $partiallySetuplinearCollectionCommand|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandQueueForSingleElement = 0, $or$cond = 0, $tfi$idx = 0, $tfi$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 44|0;
 $0 = sp;
 $args = sp + 4|0;
 $commandQueueForSingleElement = sp + 24|0;
 $tfi$idx = (($tfi) + 40|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI23TransferArrayField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$8>>2] = $12;
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 $13 = (($commandQueueForSingleElement) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($commandQueueForSingleElement) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($commandQueueForSingleElement) + 4|0);
 HEAP32[$15>>2] = 61;
 $16 = (($commandQueueForSingleElement) + 16|0);
 HEAP8[$16>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(385,($args|0),($commandQueueForSingleElement|0),($nameConversions|0),0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = (($tfi) + 25|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)!=(0);
   $$pre = HEAP32[$13>>2]|0;
   $22 = ($$pre|0)==(0);
   $or$cond = $21 & $22;
   if (!($or$cond)) {
    $31 = (($partiallySetuplinearCollectionCommand) + 44|0);
    HEAP32[$31>>2] = 2958;
    $32 = (($partiallySetuplinearCollectionCommand) + 48|0);
    HEAP32[$32>>2] = $$pre;
    $33 = HEAP32[$tfi$idx>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3284,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = (($partiallySetuplinearCollectionCommand) + 40|0);
    HEAP32[$37>>2] = $34;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($partiallySetuplinearCollectionCommand|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($commandQueueForSingleElement|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
   }
   $42 = HEAP32[$14>>2]|0;
   $43 = ($42|0)>(-1);
   if (!($43)) {
    STACKTOP = sp;return;
   }
   $44 = HEAP32[$commandQueueForSingleElement>>2]|0;
   $45 = HEAP32[$15>>2]|0;
   HEAP32[$0>>2] = $45;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($44,$$byval_copy1);
   HEAP32[$commandQueueForSingleElement>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$14>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$commandQueueForSingleElement>>2]|0;
 $28 = HEAP32[$15>>2]|0;
 HEAP32[$0>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $46 = ___cxa_find_matching_catch(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 }
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arrayOfManagedObjectsTransferer = 0, $converter$i = 0, $newProvider = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $converter$i = sp + 32|0;
 $arrayOfManagedObjectsTransferer = sp;
 $newProvider = sp + 12|0;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$arrayOfManagedObjectsTransferer+0>>2]=0|0;HEAP32[$arrayOfManagedObjectsTransferer+4>>2]=0|0;HEAP32[$arrayOfManagedObjectsTransferer+8>>2]=0|0;
 $2 = (($runtimeInfo) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$arrayOfManagedObjectsTransferer>>2] = $3;
 $4 = (($args) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($arrayOfManagedObjectsTransferer) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = (($runtimeInfo) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($10<<6)|0);
 HEAP32[$11>>2] = $13;
 $14 = (($newProvider) + 4|0);
 HEAP32[$14>>2] = $12;
 HEAP32[$newProvider>>2] = $12;
 $15 = (($newProvider) + 8|0);
 HEAP32[$15>>2] = $13;
 $$idx$i = $10 << 6;
 $16 = $$idx$i >> 6;
 $17 = (($newProvider) + 16|0);
 HEAP32[$17>>2] = $16;
 $18 = (($newProvider) + 12|0);
 HEAP32[$18>>2] = $16;
 $19 = (($arrayOfManagedObjectsTransferer) + 8|0);
 HEAP32[$19>>2] = $newProvider;
 $20 = (($args) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($args) + 36|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($1,$21,$23,$converter$i,1)|0);
 $25 = ($24|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = ($24|0)>(0);
 if ($26) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($1,$arrayOfManagedObjectsTransferer,0);
 } else {
  $27 = HEAP32[$converter$i>>2]|0;
  $28 = ($27|0)==(0|0);
  if (!($28)) {
   (FUNCTION_TABLE_iii[$27 & 4095]($arrayOfManagedObjectsTransferer,$1)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($1);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$pre = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$sroa$1$i8 = 0, $$sroa$12$i7 = 0, $$sroa$2 = 0, $$sroa$214 = 0, $$sroa$8 = 0, $$sroa$820 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i = 0, $instance$0$i = 0, $instance$0$i4 = 0, $instance$0$i9 = 0, $runtimeInfo$i$i$i = 0, $size = 0, $storemerge = 0, $storemerge30 = 0, $storemerge31 = 0;
 var $storemerge32 = 0, $storemerge33 = 0, $storemerge34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$sroa$12$i7 = sp + 8|0;
 $$sroa$1$i8 = sp + 179|0;
 $runtimeInfo$i$i$i = sp + 152|0;
 $size = sp + 32|0;
 $i = sp + 40|0;
 $1 = sp + 96|0;
 $$sroa$214 = sp + 188|0;
 $$sroa$820 = sp + 176|0;
 $2 = sp;
 $$sroa$2 = sp + 182|0;
 $$sroa$8 = sp + 185|0;
 $3 = HEAP32[$data>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$size>>2] = $5;
 $6 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$size>>2]|0;
 $8 = HEAP32[$data>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($7|0);
 if ($11) {
  $26 = $7;$32 = $8;
 } else {
  $12 = (($data) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__Z34scripting_class_array_element_sizeP14ScriptingClass($13)|0);
  $15 = HEAP32[$12>>2]|0;
  $16 = (__Z19scripting_array_newP14ScriptingClassjj($15,$14,$7)|0);
  $17 = HEAP32[$data>>2]|0;
  HEAP32[$17>>2] = $16;
  $18 = HEAP32[$data>>2]|0;
  $19 = (($18) + 4|0);
  HEAP32[$19>>2] = $7;
  $$pre = HEAP32[$size>>2]|0;
  $26 = $$pre;$32 = $18;
 }
 $20 = (($i) + 24|0);
 HEAP8[$20>>0] = 1;
 $21 = (($i) + 28|0);
 HEAP32[$21>>2] = 0;
 $22 = (($i) + 32|0);
 HEAP32[$22>>2] = 0;
 $23 = (($i) + 40|0);
 HEAP32[$23>>2] = 0;
 $24 = (($i) + 44|0);
 HEAP32[$24>>2] = 0;
 $25 = ($26|0)==(0);
 L7: do {
  if (!($25)) {
   $27 = (($1) + 24|0);
   HEAP8[$27>>0] = 1;
   $28 = (($1) + 28|0);
   HEAP32[$28>>2] = 0;
   $29 = (($1) + 32|0);
   HEAP32[$29>>2] = 0;
   $30 = (($1) + 40|0);
   $31 = (($1) + 44|0);
   HEAP32[$1>>2] = $32;
   $33 = (($1) + 12|0);
   HEAP32[$33>>2] = 0;
   $34 = (($data) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($35)|0);
   $37 = (($1) + 4|0);
   $38 = $36&1;
   HEAP8[$37>>0] = $38;
   $39 = HEAP32[$data>>2]|0;
   $40 = HEAP32[$39>>2]|0;
   $41 = (__Z26scripting_object_get_classP15ScriptingObject($40)|0);
   $42 = (__Z28scripting_array_element_sizeP14ScriptingClass($41)|0);
   $43 = (($1) + 8|0);
   HEAP32[$43>>2] = $42;
   $44 = HEAP32[$34>>2]|0;
   $45 = (($1) + 16|0);
   HEAP32[$45>>2] = $44;
   $46 = (($data) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = HEAP32[$47>>2]|0;
   $49 = (($47) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($1) + 36|0);
   HEAP32[$51>>2] = $48;
   HEAP32[$31>>2] = $50;
   $52 = $50;
   $53 = $48;
   $54 = (($52) - ($53))|0;
   $55 = $54 >> 6;
   $56 = (($1) + 52|0);
   HEAP32[$56>>2] = $55;
   $57 = (($1) + 48|0);
   HEAP32[$57>>2] = $55;
   $58 = (($1) + 36|0);
   HEAP32[$30>>2] = $48;
   $59 = (($1) + 20|0);
   HEAP32[$59>>2] = $58;
   $60 = HEAP32[$1>>2]|0;
   $61 = HEAP32[$60>>2]|0;
   $62 = HEAP32[$33>>2]|0;
   $63 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($61,$62,$42)|0);
   $64 = HEAP8[$37>>0]|0;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    $68 = HEAP32[$63>>2]|0;
    $69 = ($68|0)==(0|0);
    if ($69) {
     $70 = HEAP32[$45>>2]|0;
     $71 = (_il2cpp_object_new($70)|0);
     __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($71);
     $72 = HEAP32[$1>>2]|0;
     $73 = HEAP32[$72>>2]|0;
     $74 = HEAP32[$33>>2]|0;
     __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($73,$74,$71);
     $instance$0$i = $71;
    } else {
     $instance$0$i = $68;
    }
    $75 = HEAP32[$45>>2]|0;
    HEAP8[$27>>0] = 1;
    $76 = (($1) + 25|0);
    ;HEAP8[$76+0>>0]=HEAP8[$$sroa$1$i8+0>>0]|0;HEAP8[$76+1>>0]=HEAP8[$$sroa$1$i8+1>>0]|0;HEAP8[$76+2>>0]=HEAP8[$$sroa$1$i8+2>>0]|0;
    $storemerge = $75;$storemerge34 = $instance$0$i;
   } else {
    $66 = HEAP32[$45>>2]|0;
    HEAP8[$27>>0] = 0;
    $67 = (($1) + 25|0);
    ;HEAP8[$67+0>>0]=HEAP8[$$sroa$12$i7+0>>0]|0;HEAP8[$67+1>>0]=HEAP8[$$sroa$12$i7+1>>0]|0;HEAP8[$67+2>>0]=HEAP8[$$sroa$12$i7+2>>0]|0;
    $storemerge = $66;$storemerge34 = $63;
   }
   HEAP32[$28>>2] = $storemerge34;
   HEAP32[$29>>2] = $storemerge;
   $77 = ($storemerge|0)==(0|0);
   if ($77) {
    $$0$i$i = 630384;
   } else {
    $78 = (__Z24scripting_class_get_nameP14ScriptingClass($storemerge)|0);
    $$0$i$i = $78;
   }
   $79 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$$0$i$i,0,1)|0);
   $80 = (($this) + 80|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (__ZNK16TypeTreeIterator7GetNodeEv($81)|0);
   $83 = (($82) + 12|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($this) + 84|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$86>>2] = 0;
   $87 = ($79|0)==(2);
   if ($87) {
    $88 = HEAP32[$80>>2]|0;
    $89 = (($88) + 12|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = HEAP32[$data>>2]|0;
    $92 = HEAP32[$34>>2]|0;
    $93 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($92)|0);
    $94 = $93&1;
    $95 = HEAP32[$data>>2]|0;
    $96 = HEAP32[$95>>2]|0;
    $97 = (__Z26scripting_object_get_classP15ScriptingObject($96)|0);
    $98 = (__Z28scripting_array_element_sizeP14ScriptingClass($97)|0);
    $99 = HEAP32[$34>>2]|0;
    $100 = HEAP32[$46>>2]|0;
    $101 = HEAP32[$100>>2]|0;
    $102 = (($100) + 8|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = $103;
    $105 = $101;
    $106 = (($104) - ($105))|0;
    $107 = $106 >> 6;
    HEAP32[$i>>2] = $91;
    $108 = (($i) + 4|0);
    HEAP8[$108>>0] = $94;
    $109 = (($i) + 5|0);
    ;HEAP8[$109+0>>0]=HEAP8[$$sroa$214+0>>0]|0;HEAP8[$109+1>>0]=HEAP8[$$sroa$214+1>>0]|0;HEAP8[$109+2>>0]=HEAP8[$$sroa$214+2>>0]|0;
    $110 = (($i) + 8|0);
    HEAP32[$110>>2] = $98;
    $111 = (($i) + 12|0);
    HEAP32[$111>>2] = 0;
    $112 = (($i) + 16|0);
    HEAP32[$112>>2] = $99;
    $113 = (($i) + 20|0);
    HEAP8[$20>>0] = 1;
    $114 = (($i) + 25|0);
    ;HEAP8[$114+0>>0]=HEAP8[$$sroa$820+0>>0]|0;HEAP8[$114+1>>0]=HEAP8[$$sroa$820+1>>0]|0;HEAP8[$114+2>>0]=HEAP8[$$sroa$820+2>>0]|0;
    HEAP32[$21>>2] = 0;
    HEAP32[$22>>2] = 0;
    $115 = (($i) + 36|0);
    HEAP32[$115>>2] = $101;
    HEAP32[$23>>2] = $101;
    HEAP32[$24>>2] = $103;
    $116 = (($i) + 48|0);
    HEAP32[$116>>2] = $107;
    $117 = (($i) + 52|0);
    HEAP32[$117>>2] = $107;
    $118 = ($7|0)==(0);
    if (!($118)) {
     $119 = (($i) + 36|0);
     $120 = (($$sroa$12$i7) + 16|0);
     $121 = (($$sroa$12$i7) + 12|0);
     while(1) {
      $122 = HEAP32[$85>>2]|0;
      $123 = HEAP32[$122>>2]|0;
      $124 = Math_imul($123, $84)|0;
      $125 = (($124) + ($90))|0;
      $126 = HEAP32[$80>>2]|0;
      $127 = (($126) + 20|0);
      HEAP32[$127>>2] = $125;
      $128 = (($126) + 12|0);
      HEAP32[$128>>2] = $125;
      $129 = (($126) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($2,$126);
      $130 = $2;
      $131 = $130;
      $132 = HEAP32[$131>>2]|0;
      $133 = (($130) + 4)|0;
      $134 = $133;
      $135 = HEAP32[$134>>2]|0;
      $136 = $129;
      $137 = $136;
      HEAP32[$137>>2] = $132;
      $138 = (($136) + 4)|0;
      $139 = $138;
      HEAP32[$139>>2] = $135;
      $140 = HEAP32[$85>>2]|0;
      $141 = HEAP32[$140>>2]|0;
      $142 = (($141) + 1)|0;
      HEAP32[$140>>2] = $142;
      $143 = HEAP32[$119>>2]|0;
      HEAP32[$23>>2] = $143;
      HEAP32[$113>>2] = $119;
      $144 = HEAP32[$i>>2]|0;
      $145 = HEAP32[$144>>2]|0;
      $146 = HEAP32[$111>>2]|0;
      $147 = HEAP32[$110>>2]|0;
      $148 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($145,$146,$147)|0);
      $149 = HEAP8[$108>>0]|0;
      $150 = ($149<<24>>24)==(0);
      if ($150) {
       $152 = HEAP32[$148>>2]|0;
       $153 = ($152|0)==(0|0);
       if ($153) {
        $154 = HEAP32[$112>>2]|0;
        $155 = (_il2cpp_object_new($154)|0);
        __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($155);
        $156 = HEAP32[$i>>2]|0;
        $157 = HEAP32[$156>>2]|0;
        $158 = HEAP32[$111>>2]|0;
        __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($157,$158,$155);
        $instance$0$i4 = $155;
       } else {
        $instance$0$i4 = $152;
       }
       $159 = HEAP32[$112>>2]|0;
       HEAP8[$20>>0] = 1;
       ;HEAP8[$114+0>>0]=HEAP8[$$sroa$1$i8+0>>0]|0;HEAP8[$114+1>>0]=HEAP8[$$sroa$1$i8+1>>0]|0;HEAP8[$114+2>>0]=HEAP8[$$sroa$1$i8+2>>0]|0;
       $storemerge32 = $159;$storemerge33 = $instance$0$i4;
      } else {
       $151 = HEAP32[$112>>2]|0;
       HEAP8[$20>>0] = 0;
       ;HEAP8[$114+0>>0]=HEAP8[$$sroa$12$i7+0>>0]|0;HEAP8[$114+1>>0]=HEAP8[$$sroa$12$i7+1>>0]|0;HEAP8[$114+2>>0]=HEAP8[$$sroa$12$i7+2>>0]|0;
       $storemerge32 = $151;$storemerge33 = $148;
      }
      HEAP32[$21>>2] = $storemerge33;
      HEAP32[$22>>2] = $storemerge32;
      $160 = HEAP32[$113>>2]|0;
      ;HEAP32[$$sroa$12$i7+0>>2]=0|0;HEAP32[$$sroa$12$i7+4>>2]=0|0;HEAP32[$$sroa$12$i7+8>>2]=0|0;HEAP32[$$sroa$12$i7+12>>2]=0|0;HEAP32[$$sroa$12$i7+16>>2]=0|0;HEAP32[$$sroa$12$i7+20>>2]=0|0;
      HEAP32[$120>>2] = $this;
      ;HEAP32[$$sroa$12$i7+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$$sroa$12$i7+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$$sroa$12$i7+8>>2]=HEAP32[$20+8>>2]|0;
      HEAP32[$121>>2] = $160;
      $161 = (($160) + 4|0);
      $162 = HEAP32[$161>>2]|0;
      $163 = (($160) + 8|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = ($162|0)==($164|0);
      if (!($165)) {
       $166 = (($160) + 12|0);
       $168 = $162;$170 = $164;
       while(1) {
        $167 = (($168) + 64|0);
        HEAP32[$161>>2] = $167;
        $169 = $170;
        $171 = $167;
        $172 = (($169) - ($171))|0;
        $173 = $172 >> 6;
        HEAP32[$166>>2] = $173;
        $174 = HEAP32[$168>>2]|0;
        $175 = (($168) + 4|0);
        FUNCTION_TABLE_vii[$174 & 4095]($175,$$sroa$12$i7);
        $176 = HEAP32[$161>>2]|0;
        $177 = HEAP32[$163>>2]|0;
        $178 = ($176|0)==($177|0);
        if ($178) {
         break;
        } else {
         $168 = $176;$170 = $177;
        }
       }
      }
      $179 = HEAP32[$111>>2]|0;
      $180 = (($179) + 1)|0;
      HEAP32[$111>>2] = $180;
      $181 = ($180|0)==($7|0);
      if ($181) {
       break;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $182 = HEAP32[$data>>2]|0;
   $183 = HEAP32[$34>>2]|0;
   $184 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($183)|0);
   $185 = $184&1;
   $186 = HEAP32[$data>>2]|0;
   $187 = HEAP32[$186>>2]|0;
   $188 = (__Z26scripting_object_get_classP15ScriptingObject($187)|0);
   $189 = (__Z28scripting_array_element_sizeP14ScriptingClass($188)|0);
   $190 = HEAP32[$34>>2]|0;
   $191 = HEAP32[$46>>2]|0;
   $192 = HEAP32[$191>>2]|0;
   $193 = (($191) + 8|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = $194;
   $196 = $192;
   $197 = (($195) - ($196))|0;
   $198 = $197 >> 6;
   HEAP32[$i>>2] = $182;
   $199 = (($i) + 4|0);
   HEAP8[$199>>0] = $185;
   $200 = (($i) + 5|0);
   ;HEAP8[$200+0>>0]=HEAP8[$$sroa$2+0>>0]|0;HEAP8[$200+1>>0]=HEAP8[$$sroa$2+1>>0]|0;HEAP8[$200+2>>0]=HEAP8[$$sroa$2+2>>0]|0;
   $201 = (($i) + 8|0);
   HEAP32[$201>>2] = $189;
   $202 = (($i) + 12|0);
   HEAP32[$202>>2] = 0;
   $203 = (($i) + 16|0);
   HEAP32[$203>>2] = $190;
   $204 = (($i) + 20|0);
   HEAP8[$20>>0] = 1;
   $205 = (($i) + 25|0);
   ;HEAP8[$205+0>>0]=HEAP8[$$sroa$8+0>>0]|0;HEAP8[$205+1>>0]=HEAP8[$$sroa$8+1>>0]|0;HEAP8[$205+2>>0]=HEAP8[$$sroa$8+2>>0]|0;
   HEAP32[$21>>2] = 0;
   HEAP32[$22>>2] = 0;
   $206 = (($i) + 36|0);
   HEAP32[$206>>2] = $192;
   HEAP32[$23>>2] = $192;
   HEAP32[$24>>2] = $194;
   $207 = (($i) + 48|0);
   HEAP32[$207>>2] = $198;
   $208 = (($i) + 52|0);
   HEAP32[$208>>2] = $198;
   $209 = ($7|0)==(0);
   if (!($209)) {
    $210 = (($i) + 36|0);
    $211 = (($i) + 20|0);
    $212 = (($runtimeInfo$i$i$i) + 16|0);
    $213 = (($runtimeInfo$i$i$i) + 12|0);
    $214 = $192;$216 = $182;$217 = 0;$218 = $189;
    while(1) {
     HEAP32[$23>>2] = $214;
     HEAP32[$204>>2] = $210;
     $215 = HEAP32[$216>>2]|0;
     $219 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($215,$217,$218)|0);
     $220 = HEAP8[$199>>0]|0;
     $221 = ($220<<24>>24)==(0);
     if ($221) {
      $223 = HEAP32[$219>>2]|0;
      $224 = ($223|0)==(0|0);
      if ($224) {
       $225 = HEAP32[$203>>2]|0;
       $226 = (_il2cpp_object_new($225)|0);
       __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($226);
       $227 = HEAP32[$i>>2]|0;
       $228 = HEAP32[$227>>2]|0;
       $229 = HEAP32[$202>>2]|0;
       __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($228,$229,$226);
       $instance$0$i9 = $226;
      } else {
       $instance$0$i9 = $223;
      }
      $230 = HEAP32[$203>>2]|0;
      HEAP8[$20>>0] = 1;
      ;HEAP8[$205+0>>0]=HEAP8[$$sroa$1$i8+0>>0]|0;HEAP8[$205+1>>0]=HEAP8[$$sroa$1$i8+1>>0]|0;HEAP8[$205+2>>0]=HEAP8[$$sroa$1$i8+2>>0]|0;
      $storemerge30 = $230;$storemerge31 = $instance$0$i9;
     } else {
      $222 = HEAP32[$203>>2]|0;
      HEAP8[$20>>0] = 0;
      ;HEAP8[$205+0>>0]=HEAP8[$$sroa$12$i7+0>>0]|0;HEAP8[$205+1>>0]=HEAP8[$$sroa$12$i7+1>>0]|0;HEAP8[$205+2>>0]=HEAP8[$$sroa$12$i7+2>>0]|0;
      $storemerge30 = $222;$storemerge31 = $219;
     }
     HEAP32[$21>>2] = $storemerge31;
     HEAP32[$22>>2] = $storemerge30;
     $231 = ($storemerge30|0)==(0|0);
     if ($231) {
      $$0$i$i$i = 630384;
     } else {
      $232 = (__Z24scripting_class_get_nameP14ScriptingClass($storemerge30)|0);
      $$0$i$i$i = $232;
     }
     $233 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$$0$i$i$i,$$sroa$12$i7,1)|0);
     $234 = ($233|0)==(0);
     if (!($234)) {
      $235 = ($233|0)>(0);
      if ($235) {
       $236 = HEAP32[$211>>2]|0;
       ;HEAP32[$runtimeInfo$i$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+20>>2]=0|0;
       HEAP32[$212>>2] = $this;
       ;HEAP32[$runtimeInfo$i$i$i+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=HEAP32[$20+8>>2]|0;
       HEAP32[$213>>2] = $236;
       $237 = (($236) + 4|0);
       $238 = HEAP32[$237>>2]|0;
       $239 = (($236) + 8|0);
       $240 = HEAP32[$239>>2]|0;
       $241 = ($238|0)==($240|0);
       if (!($241)) {
        $242 = (($236) + 12|0);
        $244 = $238;$246 = $240;
        while(1) {
         $243 = (($244) + 64|0);
         HEAP32[$237>>2] = $243;
         $245 = $246;
         $247 = $243;
         $248 = (($245) - ($247))|0;
         $249 = $248 >> 6;
         HEAP32[$242>>2] = $249;
         $250 = HEAP32[$244>>2]|0;
         $251 = (($244) + 4|0);
         FUNCTION_TABLE_vii[$250 & 4095]($251,$runtimeInfo$i$i$i);
         $252 = HEAP32[$237>>2]|0;
         $253 = HEAP32[$239>>2]|0;
         $254 = ($252|0)==($253|0);
         if ($254) {
          break;
         } else {
          $244 = $252;$246 = $253;
         }
        }
       }
      } else {
       $255 = HEAP32[$$sroa$12$i7>>2]|0;
       $256 = ($255|0)==(0|0);
       if (!($256)) {
        (FUNCTION_TABLE_iii[$255 & 4095]($211,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $257 = HEAP32[$202>>2]|0;
     $258 = (($257) + 1)|0;
     HEAP32[$202>>2] = $258;
     $259 = ($258|0)==($7|0);
     if ($259) {
      break L7;
     }
     $$pre37 = HEAP32[$210>>2]|0;
     $$pre38 = HEAP32[$i>>2]|0;
     $$pre39 = HEAP32[$201>>2]|0;
     $214 = $$pre37;$216 = $$pre38;$217 = $258;$218 = $$pre39;
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 HEAP8[$converter>>0] = 0;
 __Z19TransferField_ArrayI14SafeBinaryRead16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIaEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIh14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIhEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIs14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3214SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI14SafeBinaryRead17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI14SafeBinaryRead27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI14SafeBinaryRead11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI14SafeBinaryRead27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI14SafeBinaryRead10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI14SafeBinaryRead27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI14SafeBinaryRead8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI14SafeBinaryRead27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$converter>>2] = $3;
 $5 = (($converter) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($converter) + 8|0);
 HEAP32[$6>>2] = 0;
 __Z19TransferField_ArrayI14SafeBinaryRead27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$018 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 32|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 12|0);
 ;HEAP32[$3+0>>2]=HEAP32[$converter+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$converter+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$converter+8>>2]|0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($staticInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $9 = (invoke_iiiiii(192,($5|0),($7|0),($8|0),($converter$i$i|0),1)|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 10;
  } else {
   $12 = ($9|0)==(0);
   if (!($12)) {
    $13 = ($9|0)>(0);
    if ($13) {
     __THREW__ = 0;
     invoke_viii(1852,($5|0),($buffer|0),0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      label = 10;
      break;
     }
    } else {
     $16 = HEAP32[$converter$i$i>>2]|0;
     $17 = ($16|0)==(0|0);
     if (!($17)) {
      __THREW__ = 0;
      (invoke_iii($16|0,($buffer|0),($5|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($5|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 10;
     break;
    }
   }
   $39 = (($5) + 136|0);
   $$idx$val = HEAP8[$39>>0]|0;
   $40 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($40)) {
     $41 = (($runtimeInfo) + 20|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($staticInfo) + 28|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = HEAP32[$1>>2]|0;
     $46 = HEAP32[$buffer>>2]|0;
     $47 = $45;
     $48 = $46;
     $49 = (($47) - ($48))|0;
     $50 = (($49|0) / 12)&-1;
     $51 = (($42) + 4|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==($50|0);
     if (!($53)) {
      __THREW__ = 0;
      $54 = (invoke_ii(3288,($44|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1554,($44|0),($54|0),($50|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 10;
       break L1;
      }
      HEAP32[$42>>2] = $57;
      HEAP32[$51>>2] = $50;
     }
     $60 = ($45|0)==($46|0);
     L18: do {
      if (!($60)) {
       $61 = (($buffer) + 12|0);
       $62 = (($buffer) + 20|0);
       $63 = (($buffer) + 16|0);
       $index$01$i = 0;
       while(1) {
        $64 = HEAP32[$42>>2]|0;
        __THREW__ = 0;
        $65 = (invoke_iii(2433,($64|0),($index$01$i|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
        $68 = HEAP32[$buffer>>2]|0;
        $69 = (($68) + (($index$01$i*12)|0)|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = HEAP32[$61>>2]|0;
        $72 = HEAP32[$62>>2]|0;
        $73 = HEAP32[$63>>2]|0;
        __THREW__ = 0;
        $74 = (invoke_iiiii(245,($70|0),($71|0),($72|0),($73|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         break;
        }
        HEAP32[$65>>2] = $74;
        $77 = (($index$01$i) + 1)|0;
        $78 = ($77|0)==($50|0);
        if ($78) {
         break L18;
        } else {
         $index$01$i = $77;
        }
       }
       $24 = ___cxa_find_matching_catch()|0;
       $25 = tempRet0;
       $lpad$phi$index = $24;$lpad$phi$index3 = $25;
       break L1;
      }
     } while(0);
     $79 = HEAP32[$41>>2]|0;
     $80 = (($79) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = ($81|0)==(0);
     if (!($82)) {
      $84 = $79;$index$018 = 0;
      while(1) {
       $83 = HEAP32[$84>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($83|0),($index$018|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       $87 = (($index$018) + 1)|0;
       $88 = HEAP32[$41>>2]|0;
       $89 = (($88) + 4|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = ($87|0)==($90|0);
       if ($91) {
        break L11;
       } else {
        $84 = $88;$index$018 = $87;
       }
      }
      $22 = ___cxa_find_matching_catch()|0;
      $23 = tempRet0;
      $lpad$phi$index = $22;$lpad$phi$index3 = $23;
      break L1;
     }
    }
   } while(0);
   $92 = HEAP32[$buffer>>2]|0;
   $93 = ($92|0)==(0|0);
   if ($93) {
    STACKTOP = sp;return;
   }
   $94 = HEAP32[$1>>2]|0;
   $95 = ($94|0)==($92|0);
   if (!($95)) {
    $__new_last2$i$i$i$i$i$i$i = $92;
    $scevgep$i$i$i$i$i$i$i = (($94) + -12|0);
    $96 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($96)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $97 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $98 = $97 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($94) + (($98*12)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($92|0),($$byval_copy8|0));
   $99 = __THREW__; __THREW__ = 0;
   $100 = $99&1;
   if ($100) {
    $101 = ___cxa_find_matching_catch()|0;
    $102 = tempRet0;
    ___cxa_call_unexpected(($101|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $lpad$phi$index = $26;$lpad$phi$index3 = $27;
 }
 $28 = HEAP32[$buffer>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $30 = HEAP32[$1>>2]|0;
 $31 = ($30|0)==($28|0);
 if (!($31)) {
  $__new_last2$i$i$i$i$i$i$i4 = $28;
  $scevgep$i$i$i$i$i$i$i5 = (($30) + -12|0);
  $32 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($32)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $33 = (($uglygep3$i$i$i$i$i$i$i8>>>0) / 12)&-1;
  $34 = $33 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($30) + (($34*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($28|0),($$byval_copy8|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8MonoPPtr13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i = 0, $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0;
 var $c$0$lcssa$i$i = 0, $c$01$i$i = 0, $className$02$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI8MonoPPtr13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[$data>>2]|0;
   $15 = (($14) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $$0$i = 630432;
   } else {
    $18 = (($14) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($16) + 1|0);
    HEAP8[$16>>0] = 80;
    $21 = (($16) + 2|0);
    HEAP8[$20>>0] = 80;
    $22 = (($16) + 3|0);
    HEAP8[$21>>0] = 116;
    $23 = (($16) + 4|0);
    HEAP8[$22>>0] = 114;
    $24 = (($16) + 5|0);
    HEAP8[$23>>0] = 60;
    $25 = (($16) + 6|0);
    HEAP8[$24>>0] = 36;
    $26 = (__Z24scripting_class_get_nameP14ScriptingClass($19)|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $c$0$lcssa$i$i = $25;
    } else {
     $29 = $27;$c$01$i$i = $25;$className$02$i$i = $26;
     while(1) {
      HEAP8[$c$01$i$i>>0] = $29;
      $30 = (($c$01$i$i) + 1|0);
      $31 = (($className$02$i$i) + 1|0);
      $32 = HEAP8[$31>>0]|0;
      $33 = ($32<<24>>24)==(0);
      if ($33) {
       $c$0$lcssa$i$i = $30;
       break;
      } else {
       $29 = $32;$c$01$i$i = $30;$className$02$i$i = $31;
      }
     }
    }
    $34 = (($c$0$lcssa$i$i) + 1|0);
    HEAP8[$c$0$lcssa$i$i>>0] = 62;
    HEAP8[$34>>0] = 0;
    $$0$i = $16;
   }
   $35 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$$0$i,0,1)|0);
   $36 = (($this) + 80|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (__ZNK16TypeTreeIterator7GetNodeEv($37)|0);
   $39 = (($38) + 12|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($this) + 84|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$42>>2] = 0;
   $43 = ($35|0)==(2);
   if (!($43)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $72 = HEAP32[$data>>2]|0;
    $73 = ($72|0)==($11|0);
    if ($73) {
     break;
    } else {
     $74 = $72;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI8MonoPPtrEEvRT_PKc17TransferMetaFlags($this,$74,630376,0);
     $75 = (($74) + 12|0);
     $76 = ($75|0)==($11|0);
     if ($76) {
      break L4;
     } else {
      $74 = $75;
     }
    }
   }
   $44 = HEAP32[$36>>2]|0;
   $45 = (($44) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = HEAP32[$data>>2]|0;
   $48 = ($47|0)==($11|0);
   L18: do {
    if (!($48)) {
     $50 = 0;$53 = $44;$69 = $47;
     while(1) {
      $49 = Math_imul($50, $40)|0;
      $51 = (($49) + ($46))|0;
      $52 = (($53) + 20|0);
      HEAP32[$52>>2] = $51;
      $54 = (($53) + 12|0);
      HEAP32[$54>>2] = $51;
      $55 = (($53) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$53);
      $56 = $1;
      $57 = $56;
      $58 = HEAP32[$57>>2]|0;
      $59 = (($56) + 4)|0;
      $60 = $59;
      $61 = HEAP32[$60>>2]|0;
      $62 = $55;
      $63 = $62;
      HEAP32[$63>>2] = $58;
      $64 = (($62) + 4)|0;
      $65 = $64;
      HEAP32[$65>>2] = $61;
      $66 = HEAP32[$41>>2]|0;
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 1)|0;
      HEAP32[$66>>2] = $68;
      __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($69,$this);
      $70 = (($69) + 12|0);
      $71 = ($70|0)==($11|0);
      if ($71) {
       break L18;
      }
      $$pre = HEAP32[$41>>2]|0;
      $$pre9 = HEAP32[$$pre>>2]|0;
      $$pre10 = HEAP32[$36>>2]|0;
      $50 = $$pre9;$53 = $$pre10;$69 = $70;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$idx$val = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i6 = 0, $$pre$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$022 = 0, $invocation$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $method$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy10 = sp + 80|0;
 $method$i = sp;
 $invocation$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 48|0;
 $2 = sp + 52|0;
 $converter$i$i = sp + 56|0;
 $buffer = sp + 64|0;
 HEAP32[$buffer>>2] = 0;
 $3 = (($buffer) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($buffer) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[$converter>>2]|0;
 $6 = (($buffer) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (($runtimeInfo) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($staticInfo) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $12 = (invoke_iiiiii(192,($8|0),($10|0),($11|0),($converter$i$i|0),1)|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 L1: do {
  if ($14) {
   label = 10;
  } else {
   $15 = ($12|0)==(0);
   if (!($15)) {
    $16 = ($12|0)>(0);
    if ($16) {
     __THREW__ = 0;
     invoke_viii(1853,($8|0),($buffer|0),0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 10;
      break;
     }
    } else {
     $19 = HEAP32[$converter$i$i>>2]|0;
     $20 = ($19|0)==(0|0);
     if (!($20)) {
      __THREW__ = 0;
      (invoke_iii($19|0,($buffer|0),($8|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($8|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 10;
     break;
    }
   }
   $53 = (($8) + 136|0);
   $$idx$val = HEAP8[$53>>0]|0;
   $54 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($54)) {
     $55 = (($runtimeInfo) + 20|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($staticInfo) + 28|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = HEAP32[$3>>2]|0;
     $60 = HEAP32[$buffer>>2]|0;
     $61 = $59;
     $62 = $60;
     $63 = (($61) - ($62))|0;
     $64 = (($63|0) / 292)&-1;
     $65 = (($56) + 4|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ($66|0)==($64|0);
     if (!($67)) {
      __THREW__ = 0;
      $68 = (invoke_ii(3288,($58|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $71 = (invoke_iiii(1554,($58|0),($68|0),($64|0))|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       label = 10;
       break L1;
      }
      HEAP32[$56>>2] = $71;
      HEAP32[$65>>2] = $64;
     }
     $74 = ($59|0)==($60|0);
     L18: do {
      if (!($74)) {
       $75 = (($buffer) + 12|0);
       $index$01$i = 0;
       while(1) {
        $76 = HEAP32[$56>>2]|0;
        __THREW__ = 0;
        $77 = (invoke_iii(2433,($76|0),($index$01$i|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         break;
        }
        $80 = HEAP32[$buffer>>2]|0;
        $81 = (($80) + (($index$01$i*292)|0)|0);
        __THREW__ = 0;
        invoke_viii(1797,($75|0),($81|0),($77|0));
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         break;
        }
        $84 = (($index$01$i) + 1)|0;
        $85 = ($84|0)==($64|0);
        if ($85) {
         break L18;
        } else {
         $index$01$i = $84;
        }
       }
       $27 = ___cxa_find_matching_catch()|0;
       $28 = tempRet0;
       $lpad$phi$index = $27;$lpad$phi$index3 = $28;
       break L1;
      }
     } while(0);
     $86 = HEAP32[$55>>2]|0;
     $87 = (($86) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ($88|0)==(0);
     if (!($89)) {
      $90 = (($invocation$i) + 12|0);
      $92 = $86;$index$022 = 0;
      while(1) {
       $91 = HEAP32[$92>>2]|0;
       __THREW__ = 0;
       $93 = (invoke_iii(2433,($91|0),($index$022|0))|0);
       $94 = __THREW__; __THREW__ = 0;
       $95 = $94&1;
       if ($95) {
        break;
       }
       $96 = HEAP32[$93>>2]|0;
       __THREW__ = 0;
       $97 = (invoke_i(84)|0);
       $98 = __THREW__; __THREW__ = 0;
       $99 = $98&1;
       if ($99) {
        break;
       }
       $100 = (($97) + 308|0);
       $101 = HEAP32[$100>>2]|0;
       __THREW__ = 0;
       invoke_viiii(388,($method$i|0),($101|0),(630336|0),1);
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if ($103) {
        break;
       }
       $104 = HEAP32[$method$i>>2]|0;
       $105 = ($104|0)==(0|0);
       if (!($105)) {
        $106 = $method$i;
        $107 = $106;
        $108 = HEAP32[$107>>2]|0;
        $109 = (($106) + 4)|0;
        $110 = $109;
        $111 = HEAP32[$110>>2]|0;
        $112 = $0;
        $113 = $112;
        HEAP32[$113>>2] = $108;
        $114 = (($112) + 4)|0;
        $115 = $114;
        HEAP32[$115>>2] = $111;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy10+4>>2]=HEAP32[$0+4>>2]|0;
        invoke_vii(2863,($invocation$i|0),($$byval_copy10|0));
        $116 = __THREW__; __THREW__ = 0;
        $117 = $116&1;
        if ($117) {
         break;
        }
        HEAP32[$90>>2] = $96;
        __THREW__ = 0;
        (invoke_ii(3285,($invocation$i|0))|0);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         break;
        }
       }
       $120 = (($index$022) + 1)|0;
       $121 = HEAP32[$55>>2]|0;
       $122 = (($121) + 4|0);
       $123 = HEAP32[$122>>2]|0;
       $124 = ($120|0)==($123|0);
       if ($124) {
        break L11;
       } else {
        $92 = $121;$index$022 = $120;
       }
      }
      $25 = ___cxa_find_matching_catch()|0;
      $26 = tempRet0;
      $lpad$phi$index = $25;$lpad$phi$index3 = $26;
      break L1;
     }
    }
   } while(0);
   $125 = HEAP32[$buffer>>2]|0;
   $126 = ($125|0)==(0|0);
   if ($126) {
    STACKTOP = sp;return;
   }
   $127 = HEAP32[$3>>2]|0;
   $128 = ($127|0)==($125|0);
   do {
    if ($128) {
     $142 = $125;
    } else {
     $130 = $127;
     while(1) {
      $129 = (($130) + -292|0);
      HEAP32[$3>>2] = $129;
      $131 = HEAP8[$129>>0]|0;
      $132 = $131 & 1;
      $133 = ($132<<24>>24)==(0);
      if ($133) {
       $135 = $129;
      } else {
       $136 = (($130) + -284|0);
       $137 = HEAP32[$136>>2]|0;
       HEAP32[$method$i>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$method$i+0>>2]|0;
       invoke_vii(2591,($137|0),($$byval_copy10|0));
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if ($139) {
        label = 48;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$3>>2]|0;
       $135 = $$pre$i$i$i$i$i$i$i;
      }
      $134 = ($135|0)==($125|0);
      if ($134) {
       label = 49;
       break;
      } else {
       $130 = $135;
      }
     }
     if ((label|0) == 48) {
      $140 = ___cxa_find_matching_catch()|0;
      $141 = tempRet0;
      ___cxa_call_unexpected(($140|0));
      // unreachable;
     }
     else if ((label|0) == 49) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $142 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$invocation$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$invocation$i+0>>2]|0;
   invoke_vii(2591,($142|0),($$byval_copy10|0));
   $143 = __THREW__; __THREW__ = 0;
   $144 = $143&1;
   if ($144) {
    $145 = ___cxa_find_matching_catch()|0;
    $146 = tempRet0;
    ___cxa_call_unexpected(($145|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  $lpad$phi$index = $29;$lpad$phi$index3 = $30;
 }
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $33 = HEAP32[$3>>2]|0;
 $34 = ($33|0)==($31|0);
 do {
  if ($34) {
   $48 = $31;
  } else {
   $36 = $33;
   while(1) {
    $35 = (($36) + -292|0);
    HEAP32[$3>>2] = $35;
    $37 = HEAP8[$35>>0]|0;
    $38 = $37 & 1;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     $41 = $35;
    } else {
     $42 = (($36) + -284|0);
     $43 = HEAP32[$42>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($43|0),($$byval_copy10|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 18;
      break;
     }
     $$pre$i$i$i$i$i$i$i6 = HEAP32[$3>>2]|0;
     $41 = $$pre$i$i$i$i$i$i$i6;
    }
    $40 = ($41|0)==($31|0);
    if ($40) {
     label = 19;
     break;
    } else {
     $36 = $41;
    }
   }
   if ((label|0) == 18) {
    $46 = ___cxa_find_matching_catch()|0;
    $47 = tempRet0;
    ___cxa_call_unexpected(($46|0));
    // unreachable;
   }
   else if ((label|0) == 19) {
    $$pre$i$i$i$i$i8 = HEAP32[$buffer>>2]|0;
    $48 = $$pre$i$i$i$i$i8;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($48|0),($$byval_copy10|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8GUIStyle13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 292)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI8GUIStyle13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631120,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN8GUIStyle8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 292|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631120,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN8GUIStyle8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 292|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$014 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $10 = (invoke_iiiiii(192,($6|0),($8|0),($9|0),($converter$i$i|0),1)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   label = 9;
  } else {
   $13 = ($10|0)==(0);
   if (!($13)) {
    $14 = ($10|0)>(0);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(1854,($6|0),($buffer|0),0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 9;
      break;
     }
    } else {
     $17 = HEAP32[$converter$i$i>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      __THREW__ = 0;
      (invoke_iii($17|0,($buffer|0),($6|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 9;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($6|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 9;
     break;
    }
   }
   $38 = (($6) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     __THREW__ = 0;
     invoke_viii(1804,($buffer|0),($41|0),($43|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 9;
      break L1;
     }
     $46 = HEAP32[$40>>2]|0;
     $47 = (($46) + 4|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(0);
     if (!($49)) {
      $51 = $46;$index$014 = 0;
      while(1) {
       $50 = HEAP32[$51>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($50|0),($index$014|0))|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break;
       }
       $54 = (($index$014) + 1)|0;
       $55 = HEAP32[$40>>2]|0;
       $56 = (($55) + 4|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = ($54|0)==($57|0);
       if ($58) {
        break L11;
       } else {
        $51 = $55;$index$014 = $54;
       }
      }
      $23 = ___cxa_find_matching_catch()|0;
      $24 = tempRet0;
      $lpad$phi$index = $23;$lpad$phi$index2 = $24;
      break L1;
     }
    }
   } while(0);
   $59 = HEAP32[$buffer>>2]|0;
   $60 = ($59|0)==(0|0);
   if ($60) {
    STACKTOP = sp;return;
   }
   $61 = HEAP32[$1>>2]|0;
   $62 = ($61|0)==($59|0);
   if (!($62)) {
    $__new_last2$i$i$i$i$i$i$i = $59;
    $scevgep$i$i$i$i$i$i$i = (($61) + -16|0);
    $63 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($63)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $64 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $65 = $64 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($61) + ($65<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($59|0),($$byval_copy6|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    ___cxa_call_unexpected(($68|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index2 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy6|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI10RectOffset13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI10RectOffset13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631152,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if (!($22)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $54 = HEAP32[$data>>2]|0;
    $55 = ($54|0)==($11|0);
    if ($55) {
     break;
    } else {
     $56 = $54;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI10RectOffsetEEvRT_PKc17TransferMetaFlags($this,$56,630376,0);
     $57 = (($56) + 16|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break L4;
     } else {
      $56 = $57;
     }
    }
   }
   $23 = HEAP32[$15>>2]|0;
   $24 = (($23) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[$data>>2]|0;
   $27 = ($26|0)==($11|0);
   L11: do {
    if (!($27)) {
     $29 = 0;$32 = $23;$48 = $26;
     while(1) {
      $28 = Math_imul($29, $19)|0;
      $30 = (($28) + ($25))|0;
      $31 = (($32) + 20|0);
      HEAP32[$31>>2] = $30;
      $33 = (($32) + 12|0);
      HEAP32[$33>>2] = $30;
      $34 = (($32) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
      $35 = $1;
      $36 = $35;
      $37 = HEAP32[$36>>2]|0;
      $38 = (($35) + 4)|0;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = $34;
      $42 = $41;
      HEAP32[$42>>2] = $37;
      $43 = (($41) + 4)|0;
      $44 = $43;
      HEAP32[$44>>2] = $40;
      $45 = HEAP32[$20>>2]|0;
      $46 = HEAP32[$45>>2]|0;
      $47 = (($46) + 1)|0;
      HEAP32[$45>>2] = $47;
      __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$48,630856,0);
      $49 = (($48) + 4|0);
      __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$49,630864,0);
      $50 = (($48) + 8|0);
      __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$50,630872,0);
      $51 = (($48) + 12|0);
      __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$51,630880,0);
      $52 = (($48) + 16|0);
      $53 = ($52|0)==($11|0);
      if ($53) {
       break L11;
      }
      $$pre = HEAP32[$20>>2]|0;
      $$pre9 = HEAP32[$$pre>>2]|0;
      $$pre10 = HEAP32[$15>>2]|0;
      $29 = $$pre9;$32 = $$pre10;$48 = $52;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $buffer = 0, $converter$i$i = 0;
 var $index$09 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $10 = (invoke_iiiiii(192,($6|0),($8|0),($9|0),($converter$i$i|0),1)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   label = 9;
  } else {
   $13 = ($10|0)==(0);
   if (!($13)) {
    $14 = ($10|0)>(0);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(1855,($6|0),($buffer|0),0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 9;
      break;
     }
    } else {
     $17 = HEAP32[$converter$i$i>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      __THREW__ = 0;
      (invoke_iii($17|0,($buffer|0),($6|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 9;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($6|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 9;
     break;
    }
   }
   $41 = (($6) + 136|0);
   $$idx$val = HEAP8[$41>>0]|0;
   $42 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($42)) {
     $43 = (($runtimeInfo) + 20|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($staticInfo) + 28|0);
     $46 = HEAP32[$45>>2]|0;
     __THREW__ = 0;
     invoke_viii(1807,($buffer|0),($44|0),($46|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      label = 9;
      break L1;
     }
     $49 = HEAP32[$43>>2]|0;
     $50 = (($49) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0);
     if (!($52)) {
      $54 = $49;$index$09 = 0;
      while(1) {
       $53 = HEAP32[$54>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($53|0),($index$09|0))|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
       $57 = (($index$09) + 1)|0;
       $58 = HEAP32[$43>>2]|0;
       $59 = (($58) + 4|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ($57|0)==($60|0);
       if ($61) {
        break L11;
       } else {
        $54 = $58;$index$09 = $57;
       }
      }
      $23 = ___cxa_find_matching_catch()|0;
      $24 = tempRet0;
      $lpad$phi$index = $23;$lpad$phi$index2 = $24;
      break L1;
     }
    }
   } while(0);
   $62 = HEAP32[$buffer>>2]|0;
   $63 = ($62|0)==(0|0);
   if ($63) {
    STACKTOP = sp;return;
   }
   while(1) {
    $64 = HEAP32[$1>>2]|0;
    $65 = ($64|0)==($62|0);
    if ($65) {
     break;
    }
    $66 = (($64) + -68|0);
    HEAP32[$1>>2] = $66;
    __THREW__ = 0;
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     label = 24;
     break;
    }
   }
   if ((label|0) == 24) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    ___cxa_call_unexpected(($69|0));
    // unreachable;
   }
   $71 = HEAP32[$buffer>>2]|0;
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($71|0),($$byval_copy6|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index2 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = ($29|0)==($27|0);
  if ($30) {
   break;
  }
  $31 = (($29) + -68|0);
  HEAP32[$1>>2] = $31;
  __THREW__ = 0;
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 }
 $36 = HEAP32[$buffer>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($36|0),($$byval_copy6|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI11GradientNEW13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 68)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI11GradientNEW13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631200,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN11GradientNEW8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 68|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631200,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN11GradientNEW8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 68|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$idx$val = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i6 = 0, $$pre$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$018 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $10 = (invoke_iiiiii(192,($6|0),($8|0),($9|0),($converter$i$i|0),1)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   label = 10;
  } else {
   $13 = ($10|0)==(0);
   if (!($13)) {
    $14 = ($10|0)>(0);
    if ($14) {
     __THREW__ = 0;
     invoke_viii(1856,($6|0),($buffer|0),0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 10;
      break;
     }
    } else {
     $17 = HEAP32[$converter$i$i>>2]|0;
     $18 = ($17|0)==(0|0);
     if (!($18)) {
      __THREW__ = 0;
      (invoke_iii($17|0,($buffer|0),($6|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($6|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 10;
     break;
    }
   }
   $53 = (($6) + 136|0);
   $$idx$val = HEAP8[$53>>0]|0;
   $54 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($54)) {
     $55 = (($runtimeInfo) + 20|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($staticInfo) + 28|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = HEAP32[$1>>2]|0;
     $60 = HEAP32[$buffer>>2]|0;
     $61 = $59;
     $62 = $60;
     $63 = (($61) - ($62))|0;
     $64 = (($63|0) / 80)&-1;
     $65 = (($56) + 4|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ($66|0)==($64|0);
     if (!($67)) {
      __THREW__ = 0;
      $68 = (invoke_ii(3288,($58|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $71 = (invoke_iiii(1554,($58|0),($68|0),($64|0))|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       label = 10;
       break L1;
      }
      HEAP32[$56>>2] = $71;
      HEAP32[$65>>2] = $64;
     }
     $74 = ($59|0)==($60|0);
     L18: do {
      if (!($74)) {
       $75 = (($buffer) + 12|0);
       $index$01$i = 0;
       while(1) {
        $76 = HEAP32[$56>>2]|0;
        __THREW__ = 0;
        $77 = (invoke_iii(2433,($76|0),($index$01$i|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         break;
        }
        $80 = HEAP32[$buffer>>2]|0;
        $81 = (($80) + (($index$01$i*80)|0)|0);
        __THREW__ = 0;
        invoke_viii(1798,($75|0),($81|0),($77|0));
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         break;
        }
        $84 = (($index$01$i) + 1)|0;
        $85 = ($84|0)==($64|0);
        if ($85) {
         break L18;
        } else {
         $index$01$i = $84;
        }
       }
       $25 = ___cxa_find_matching_catch()|0;
       $26 = tempRet0;
       $lpad$phi$index = $25;$lpad$phi$index3 = $26;
       break L1;
      }
     } while(0);
     $86 = HEAP32[$55>>2]|0;
     $87 = (($86) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ($88|0)==(0);
     if (!($89)) {
      $91 = $86;$index$018 = 0;
      while(1) {
       $90 = HEAP32[$91>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($90|0),($index$018|0))|0);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        break;
       }
       $94 = (($index$018) + 1)|0;
       $95 = HEAP32[$55>>2]|0;
       $96 = (($95) + 4|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = ($94|0)==($97|0);
       if ($98) {
        break L11;
       } else {
        $91 = $95;$index$018 = $94;
       }
      }
      $23 = ___cxa_find_matching_catch()|0;
      $24 = tempRet0;
      $lpad$phi$index = $23;$lpad$phi$index3 = $24;
      break L1;
     }
    }
   } while(0);
   $99 = HEAP32[$buffer>>2]|0;
   $100 = ($99|0)==(0|0);
   if ($100) {
    STACKTOP = sp;return;
   }
   $101 = HEAP32[$1>>2]|0;
   $102 = ($101|0)==($99|0);
   do {
    if ($102) {
     $118 = $99;
    } else {
     $104 = $101;
     while(1) {
      $103 = (($104) + -80|0);
      HEAP32[$1>>2] = $103;
      $105 = (($104) + -12|0);
      $106 = HEAP32[$105>>2]|0;
      $107 = ($106|0)>(-1);
      if ($107) {
       $110 = (($104) + -24|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = (($104) + -20|0);
       $113 = HEAP32[$112>>2]|0;
       HEAP32[$0>>2] = $113;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($111|0),($$byval_copy10|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        label = 42;
        break;
       }
       HEAP32[$110>>2] = 0;
       $$pre$i$i$i$i$i$i$i = HEAP32[$1>>2]|0;
       $109 = $$pre$i$i$i$i$i$i$i;
      } else {
       $109 = $103;
      }
      $108 = ($109|0)==($99|0);
      if ($108) {
       label = 43;
       break;
      } else {
       $104 = $109;
      }
     }
     if ((label|0) == 42) {
      $116 = ___cxa_find_matching_catch()|0;
      $117 = tempRet0;
      ___cxa_call_unexpected(($116|0));
      // unreachable;
     }
     else if ((label|0) == 43) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $118 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($118|0),($$byval_copy10|0));
   $119 = __THREW__; __THREW__ = 0;
   $120 = $119&1;
   if ($120) {
    $121 = ___cxa_find_matching_catch()|0;
    $122 = tempRet0;
    ___cxa_call_unexpected(($121|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  $lpad$phi$index = $27;$lpad$phi$index3 = $28;
 }
 $29 = HEAP32[$buffer>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $31 = HEAP32[$1>>2]|0;
 $32 = ($31|0)==($29|0);
 do {
  if ($32) {
   $48 = $29;
  } else {
   $34 = $31;
   while(1) {
    $33 = (($34) + -80|0);
    HEAP32[$1>>2] = $33;
    $35 = (($34) + -12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)>(-1);
    if ($37) {
     $40 = (($34) + -24|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($34) + -20|0);
     $43 = HEAP32[$42>>2]|0;
     HEAP32[$0>>2] = $43;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($41|0),($$byval_copy10|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 18;
      break;
     }
     HEAP32[$40>>2] = 0;
     $$pre$i$i$i$i$i$i$i6 = HEAP32[$1>>2]|0;
     $39 = $$pre$i$i$i$i$i$i$i6;
    } else {
     $39 = $33;
    }
    $38 = ($39|0)==($29|0);
    if ($38) {
     label = 19;
     break;
    } else {
     $34 = $39;
    }
   }
   if ((label|0) == 18) {
    $46 = ___cxa_find_matching_catch()|0;
    $47 = tempRet0;
    ___cxa_call_unexpected(($46|0));
    // unreachable;
   }
   else if ((label|0) == 19) {
    $$pre$i$i$i$i$i8 = HEAP32[$buffer>>2]|0;
    $48 = $$pre$i$i$i$i$i8;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($48|0),($$byval_copy10|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 80)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631216,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN17AnimationCurveTplIfE8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 80|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631216,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN17AnimationCurveTplIfE8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 80|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1857,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 2;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),4)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<2)|0);
        $66 = HEAP32[$65>>2]|0;
        HEAP32[$61>>2] = $66;
        $67 = (($index$01$i) + 1)|0;
        $68 = ($67|0)==($49|0);
        if ($68) {
         break L18;
        } else {
         $index$01$i = $67;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0);
     if (!($72)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($index$017) + 1)|0;
       $76 = HEAP32[$40>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($75|0)==($78|0);
       if ($79) {
        break L11;
       } else {
        $index$017 = $75;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $80 = HEAP32[$buffer>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = HEAP32[$1>>2]|0;
   $83 = ($82|0)==($80|0);
   if (!($83)) {
    $__new_last2$i$i$i$i$i$i$i = $80;
    $scevgep$i$i$i$i$i$i$i = (($82) + -4|0);
    $84 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($84)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $85 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($82) + ($86<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8BitField13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI8BitField13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631248,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN14SafeBinaryRead10SetVersionEi($this,2);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$48,631040,0);
       $49 = (__ZN14SafeBinaryRead12IsOldVersionEi($this,1)|0);
       if ($49) {
        $50 = HEAP32[$48>>2]|0;
        $51 = $50 & 32;
        $52 = ($51|0)==(0);
        if (!($52)) {
         $53 = $50 | -65536;
         HEAP32[$48>>2] = $53;
        }
       }
       $54 = (($48) + 4|0);
       $55 = ($54|0)==($11|0);
       if ($55) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$15>>2]|0;
       $29 = $$pre8;$32 = $$pre9;$48 = $54;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $56 = HEAP32[$data>>2]|0;
   $57 = ($56|0)==($11|0);
   if (!($57)) {
    $61 = $56;
    while(1) {
     $58 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631248,$converter$i$i,1)|0);
     $59 = ($58|0)==(0);
     if (!($59)) {
      $60 = ($58|0)>(0);
      if ($60) {
       __ZN14SafeBinaryRead10SetVersionEi($this,2);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$61,631040,0);
       $62 = (__ZN14SafeBinaryRead12IsOldVersionEi($this,1)|0);
       if ($62) {
        $63 = HEAP32[$61>>2]|0;
        $64 = $63 & 32;
        $65 = ($64|0)==(0);
        if (!($65)) {
         $66 = $63 | -65536;
         HEAP32[$61>>2] = $66;
        }
       }
      } else {
       $67 = HEAP32[$converter$i$i>>2]|0;
       $68 = ($67|0)==(0|0);
       if (!($68)) {
        (FUNCTION_TABLE_iii[$67 & 4095]($61,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $69 = (($61) + 4|0);
     $70 = ($69|0)==($11|0);
     if ($70) {
      break;
     } else {
      $61 = $69;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last1$i$i$i$i$i$i$i = 0, $__new_last1$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$016 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep2$i$i$i$i$i$i$i = 0, $scevgep2$i$i$i$i$i$i$i6 = 0, $scevgep23$i$i$i$i$i$i$i = 0, $scevgep23$i$i$i$i$i$i$i7 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1858,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 2;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),4)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<2)|0);
        $66 = HEAP32[$65>>2]|0;
        HEAP32[$61>>2] = $66;
        $67 = (($index$01$i) + 1)|0;
        $68 = ($67|0)==($49|0);
        if ($68) {
         break L18;
        } else {
         $index$01$i = $67;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0);
     if (!($72)) {
      $index$016 = 0;
      while(1) {
       __THREW__ = 0;
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($index$016) + 1)|0;
       $76 = HEAP32[$40>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($75|0)==($78|0);
       if ($79) {
        break L11;
       } else {
        $index$016 = $75;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $80 = HEAP32[$buffer>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = HEAP32[$1>>2]|0;
   $83 = ($82|0)==($80|0);
   if (!($83)) {
    $__new_last1$i$i$i$i$i$i$i = $80;
    $scevgep$i$i$i$i$i$i$i = (($82) + -4|0);
    $84 = (0 - ($__new_last1$i$i$i$i$i$i$i))|0;
    $scevgep2$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($84)|0);
    $scevgep23$i$i$i$i$i$i$i = $scevgep2$i$i$i$i$i$i$i;
    $85 = $scevgep23$i$i$i$i$i$i$i >>> 2;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($82) + ($86<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last1$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -4|0);
  $31 = (0 - ($__new_last1$i$i$i$i$i$i$i4))|0;
  $scevgep2$i$i$i$i$i$i$i6 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $scevgep23$i$i$i$i$i$i$i7 = $scevgep2$i$i$i$i$i$i$i6;
  $32 = $scevgep23$i$i$i$i$i$i$i7 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i8 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i8;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI11ColorRGBA3213stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI11ColorRGBA3213stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580560>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$52 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead10SetVersionEi($this,2);
       $49 = HEAP32[$this>>2]|0;
       $50 = $49 & 512;
       $51 = ($50|0)==(0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$52,631048,0);
       if (!($51)) {
        $53 = HEAP32[$52>>2]|0;
        $54 = (_llvm_bswap_i32(($53|0))|0);
        HEAP32[$52>>2] = $54;
       }
       $55 = (($52) + 4|0);
       $56 = ($55|0)==($11|0);
       if ($56) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$16>>2]|0;
       $30 = $$pre8;$33 = $$pre9;$52 = $55;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $57 = HEAP32[$data>>2]|0;
   $58 = ($57|0)==($11|0);
   if (!($58)) {
    $65 = $57;
    while(1) {
     $59 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,$converter$i$i,1)|0);
     $60 = ($59|0)==(0);
     if (!($60)) {
      $61 = ($59|0)>(0);
      if ($61) {
       __ZN14SafeBinaryRead10SetVersionEi($this,2);
       $62 = HEAP32[$this>>2]|0;
       $63 = $62 & 512;
       $64 = ($63|0)==(0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$65,631048,0);
       if (!($64)) {
        $66 = HEAP32[$65>>2]|0;
        $67 = (_llvm_bswap_i32(($66|0))|0);
        HEAP32[$65>>2] = $67;
       }
      } else {
       $68 = HEAP32[$converter$i$i>>2]|0;
       $69 = ($68|0)==(0|0);
       if (!($69)) {
        (FUNCTION_TABLE_iii[$68 & 4095]($65,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $70 = (($65) + 4|0);
     $71 = ($70|0)==($11|0);
     if ($71) {
      break;
     } else {
      $65 = $70;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1859,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 4;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),16)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<4)|0);
        $66 = Math_fround(HEAPF32[$65>>2]);
        $67 = ((($64) + ($index$01$i<<4)|0) + 4|0);
        $68 = Math_fround(HEAPF32[$67>>2]);
        $69 = ((($64) + ($index$01$i<<4)|0) + 8|0);
        $70 = Math_fround(HEAPF32[$69>>2]);
        $71 = ((($64) + ($index$01$i<<4)|0) + 12|0);
        $72 = Math_fround(HEAPF32[$71>>2]);
        HEAPF32[$61>>2] = $66;
        $73 = (($61) + 4|0);
        HEAPF32[$73>>2] = $68;
        $74 = (($61) + 8|0);
        HEAPF32[$74>>2] = $70;
        $75 = (($61) + 12|0);
        HEAPF32[$75>>2] = $72;
        $76 = (($index$01$i) + 1)|0;
        $77 = ($76|0)==($49|0);
        if ($77) {
         break L18;
        } else {
         $index$01$i = $76;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $78 = HEAP32[$40>>2]|0;
     $79 = (($78) + 4|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==(0);
     if (!($81)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       $84 = (($index$017) + 1)|0;
       $85 = HEAP32[$40>>2]|0;
       $86 = (($85) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($84|0)==($87|0);
       if ($88) {
        break L11;
       } else {
        $index$017 = $84;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $89 = HEAP32[$buffer>>2]|0;
   $90 = ($89|0)==(0|0);
   if ($90) {
    STACKTOP = sp;return;
   }
   $91 = HEAP32[$1>>2]|0;
   $92 = ($91|0)==($89|0);
   if (!($92)) {
    $__new_last2$i$i$i$i$i$i$i = $89;
    $scevgep$i$i$i$i$i$i$i = (($91) + -16|0);
    $93 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($93)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $94 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $95 = $94 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($91) + ($95<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($89|0),($$byval_copy8|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $98 = ___cxa_find_matching_catch()|0;
    $99 = tempRet0;
    ___cxa_call_unexpected(($98|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI10ColorRGBAf13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI10ColorRGBAf13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580560>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $55 = HEAP32[$data>>2]|0;
    $56 = ($55|0)==($11|0);
    if ($56) {
     break;
    } else {
     $57 = $55;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI10ColorRGBAfEEvRT_PKc17TransferMetaFlags($this,$57,630376,0);
     $58 = (($57) + 16|0);
     $59 = ($58|0)==($11|0);
     if ($59) {
      break L4;
     } else {
      $57 = $58;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $30 = 0;$33 = $24;$49 = $27;
     while(1) {
      $29 = Math_imul($30, $20)|0;
      $31 = (($29) + ($26))|0;
      $32 = (($33) + 20|0);
      HEAP32[$32>>2] = $31;
      $34 = (($33) + 12|0);
      HEAP32[$34>>2] = $31;
      $35 = (($33) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
      $36 = $1;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      $42 = $35;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      $46 = HEAP32[$21>>2]|0;
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + 1)|0;
      HEAP32[$46>>2] = $48;
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,630928,0);
      $50 = (($49) + 4|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,630936,0);
      $51 = (($49) + 8|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$51,630944,0);
      $52 = (($49) + 12|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$52,630952,0);
      $53 = (($49) + 16|0);
      $54 = ($53|0)==($11|0);
      if ($54) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre9 = HEAP32[$$pre>>2]|0;
      $$pre10 = HEAP32[$16>>2]|0;
      $30 = $$pre9;$33 = $$pre10;$49 = $53;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1860,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = (($48|0) / 24)&-1;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($44|0)==($45|0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),24)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + (($index$01$i*24)|0)|0);
        ;HEAP32[$61+0>>2]=HEAP32[$65+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$65+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$65+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$65+12>>2]|0;HEAP32[$61+16>>2]=HEAP32[$65+16>>2]|0;HEAP32[$61+20>>2]=HEAP32[$65+20>>2]|0;
        $66 = (($index$01$i) + 1)|0;
        $67 = ($66|0)==($49|0);
        if ($67) {
         break L18;
        } else {
         $index$01$i = $66;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $68 = HEAP32[$40>>2]|0;
     $69 = (($68) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==(0);
     if (!($71)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = (($index$017) + 1)|0;
       $75 = HEAP32[$40>>2]|0;
       $76 = (($75) + 4|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($74|0)==($77|0);
       if ($78) {
        break L11;
       } else {
        $index$017 = $74;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $79 = HEAP32[$buffer>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    STACKTOP = sp;return;
   }
   $81 = HEAP32[$1>>2]|0;
   $82 = ($81|0)==($79|0);
   if (!($82)) {
    $__new_last2$i$i$i$i$i$i$i = $79;
    $scevgep$i$i$i$i$i$i$i = (($81) + -24|0);
    $83 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($83)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $84 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 24)&-1;
    $85 = $84 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($81) + (($85*24)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($79|0),($$byval_copy8|0));
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    ___cxa_call_unexpected(($88|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -24|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = (($uglygep3$i$i$i$i$i$i$i8>>>0) / 24)&-1;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + (($33*24)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4AABB13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 24)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4AABB13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631264,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4AABB8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 24|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631264,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4AABB8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 24|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1861,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 6;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),64)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<6)|0);
        dest=$61+0|0; src=$65+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $66 = (($index$01$i) + 1)|0;
        $67 = ($66|0)==($49|0);
        if ($67) {
         break L18;
        } else {
         $index$01$i = $66;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $68 = HEAP32[$40>>2]|0;
     $69 = (($68) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==(0);
     if (!($71)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = (($index$017) + 1)|0;
       $75 = HEAP32[$40>>2]|0;
       $76 = (($75) + 4|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($74|0)==($77|0);
       if ($78) {
        break L11;
       } else {
        $index$017 = $74;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $79 = HEAP32[$buffer>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    STACKTOP = sp;return;
   }
   $81 = HEAP32[$1>>2]|0;
   $82 = ($81|0)==($79|0);
   if (!($82)) {
    $__new_last2$i$i$i$i$i$i$i = $79;
    $scevgep$i$i$i$i$i$i$i = (($81) + -64|0);
    $83 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($83)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $84 = $uglygep3$i$i$i$i$i$i$i >>> 6;
    $85 = $84 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($81) + ($85<<6)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($79|0),($$byval_copy8|0));
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    ___cxa_call_unexpected(($88|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -64|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 6;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<6)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI10Matrix4x4f13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 6;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI10Matrix4x4f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631272,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN10Matrix4x4f8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 64|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,631272,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN10Matrix4x4f8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 64|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1862,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 4;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),16)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<4)|0);
        ;HEAP32[$61+0>>2]=HEAP32[$65+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$65+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$65+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$65+12>>2]|0;
        $66 = (($index$01$i) + 1)|0;
        $67 = ($66|0)==($49|0);
        if ($67) {
         break L18;
        } else {
         $index$01$i = $66;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $68 = HEAP32[$40>>2]|0;
     $69 = (($68) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==(0);
     if (!($71)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = (($index$017) + 1)|0;
       $75 = HEAP32[$40>>2]|0;
       $76 = (($75) + 4|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($74|0)==($77|0);
       if ($78) {
        break L11;
       } else {
        $index$017 = $74;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $79 = HEAP32[$buffer>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    STACKTOP = sp;return;
   }
   $81 = HEAP32[$1>>2]|0;
   $82 = ($81|0)==($79|0);
   if (!($82)) {
    $__new_last2$i$i$i$i$i$i$i = $79;
    $scevgep$i$i$i$i$i$i$i = (($81) + -16|0);
    $83 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($83)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $84 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $85 = $84 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($81) + ($85<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($79|0),($$byval_copy8|0));
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    ___cxa_call_unexpected(($88|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI11Quaternionf13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI11Quaternionf13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580640>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $55 = HEAP32[$data>>2]|0;
    $56 = ($55|0)==($11|0);
    if ($56) {
     break;
    } else {
     $57 = $55;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($this,$57,630376,0);
     $58 = (($57) + 16|0);
     $59 = ($58|0)==($11|0);
     if ($59) {
      break L4;
     } else {
      $57 = $58;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $30 = 0;$33 = $24;$49 = $27;
     while(1) {
      $29 = Math_imul($30, $20)|0;
      $31 = (($29) + ($26))|0;
      $32 = (($33) + 20|0);
      HEAP32[$32>>2] = $31;
      $34 = (($33) + 12|0);
      HEAP32[$34>>2] = $31;
      $35 = (($33) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
      $36 = $1;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      $42 = $35;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      $46 = HEAP32[$21>>2]|0;
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + 1)|0;
      HEAP32[$46>>2] = $48;
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,630840,0);
      $50 = (($49) + 4|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,630848,0);
      $51 = (($49) + 8|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$51,631088,0);
      $52 = (($49) + 12|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$52,631096,0);
      $53 = (($49) + 16|0);
      $54 = ($53|0)==($11|0);
      if ($54) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre9 = HEAP32[$$pre>>2]|0;
      $$pre10 = HEAP32[$16>>2]|0;
      $30 = $$pre9;$33 = $$pre10;$49 = $53;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1863,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 4;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),16)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<4)|0);
        ;HEAP32[$61+0>>2]=HEAP32[$65+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$65+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$65+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$65+12>>2]|0;
        $66 = (($index$01$i) + 1)|0;
        $67 = ($66|0)==($49|0);
        if ($67) {
         break L18;
        } else {
         $index$01$i = $66;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $68 = HEAP32[$40>>2]|0;
     $69 = (($68) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==(0);
     if (!($71)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = (($index$017) + 1)|0;
       $75 = HEAP32[$40>>2]|0;
       $76 = (($75) + 4|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($74|0)==($77|0);
       if ($78) {
        break L11;
       } else {
        $index$017 = $74;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $79 = HEAP32[$buffer>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    STACKTOP = sp;return;
   }
   $81 = HEAP32[$1>>2]|0;
   $82 = ($81|0)==($79|0);
   if (!($82)) {
    $__new_last2$i$i$i$i$i$i$i = $79;
    $scevgep$i$i$i$i$i$i$i = (($81) + -16|0);
    $83 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($83)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $84 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $85 = $84 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($81) + ($85<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($79|0),($$byval_copy8|0));
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    ___cxa_call_unexpected(($88|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI5RectTIfE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI5RectTIfE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580648>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $55 = HEAP32[$data>>2]|0;
    $56 = ($55|0)==($11|0);
    if ($56) {
     break;
    } else {
     $57 = $55;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI5RectTIfEEEvRT_PKc17TransferMetaFlags($this,$57,630376,0);
     $58 = (($57) + 16|0);
     $59 = ($58|0)==($11|0);
     if ($59) {
      break L4;
     } else {
      $57 = $58;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $30 = 0;$33 = $24;$49 = $27;
     while(1) {
      $29 = Math_imul($30, $20)|0;
      $31 = (($29) + ($26))|0;
      $32 = (($33) + 20|0);
      HEAP32[$32>>2] = $31;
      $34 = (($33) + 12|0);
      HEAP32[$34>>2] = $31;
      $35 = (($33) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
      $36 = $1;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      $42 = $35;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      $46 = HEAP32[$21>>2]|0;
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + 1)|0;
      HEAP32[$46>>2] = $48;
      __ZN14SafeBinaryRead10SetVersionEi($this,2);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,630840,0);
      $50 = (($49) + 4|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,630848,0);
      $51 = (($49) + 8|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$51,631104,0);
      $52 = (($49) + 12|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$52,631112,0);
      $53 = (($49) + 16|0);
      $54 = ($53|0)==($11|0);
      if ($54) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre9 = HEAP32[$$pre>>2]|0;
      $$pre10 = HEAP32[$16>>2]|0;
      $30 = $$pre9;$33 = $$pre10;$49 = $53;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1864,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 4;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),16)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<4)|0);
        ;HEAP32[$61+0>>2]=HEAP32[$65+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$65+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$65+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$65+12>>2]|0;
        $66 = (($index$01$i) + 1)|0;
        $67 = ($66|0)==($49|0);
        if ($67) {
         break L18;
        } else {
         $index$01$i = $66;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $68 = HEAP32[$40>>2]|0;
     $69 = (($68) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==(0);
     if (!($71)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = (($index$017) + 1)|0;
       $75 = HEAP32[$40>>2]|0;
       $76 = (($75) + 4|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($74|0)==($77|0);
       if ($78) {
        break L11;
       } else {
        $index$017 = $74;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $79 = HEAP32[$buffer>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    STACKTOP = sp;return;
   }
   $81 = HEAP32[$1>>2]|0;
   $82 = ($81|0)==($79|0);
   if (!($82)) {
    $__new_last2$i$i$i$i$i$i$i = $79;
    $scevgep$i$i$i$i$i$i$i = (($81) + -16|0);
    $83 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($83)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $84 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $85 = $84 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($81) + ($85<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($79|0),($$byval_copy8|0));
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    ___cxa_call_unexpected(($88|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8Vector4f13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI8Vector4f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580784>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $55 = HEAP32[$data>>2]|0;
    $56 = ($55|0)==($11|0);
    if ($56) {
     break;
    } else {
     $57 = $55;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($this,$57,630376,0);
     $58 = (($57) + 16|0);
     $59 = ($58|0)==($11|0);
     if ($59) {
      break L4;
     } else {
      $57 = $58;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $30 = 0;$33 = $24;$49 = $27;
     while(1) {
      $29 = Math_imul($30, $20)|0;
      $31 = (($29) + ($26))|0;
      $32 = (($33) + 20|0);
      HEAP32[$32>>2] = $31;
      $34 = (($33) + 12|0);
      HEAP32[$34>>2] = $31;
      $35 = (($33) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
      $36 = $1;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      $42 = $35;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      $46 = HEAP32[$21>>2]|0;
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + 1)|0;
      HEAP32[$46>>2] = $48;
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,630840,0);
      $50 = (($49) + 4|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,630848,0);
      $51 = (($49) + 8|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$51,631088,0);
      $52 = (($49) + 12|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$52,631096,0);
      $53 = (($49) + 16|0);
      $54 = ($53|0)==($11|0);
      if ($54) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre9 = HEAP32[$$pre>>2]|0;
      $$pre10 = HEAP32[$16>>2]|0;
      $30 = $$pre9;$33 = $$pre10;$49 = $53;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1865,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 3;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),8)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<3)|0);
        $66 = $65;
        $67 = $66;
        $68 = HEAP32[$67>>2]|0;
        $69 = (($66) + 4)|0;
        $70 = $69;
        $71 = HEAP32[$70>>2]|0;
        $72 = $61;
        $73 = $72;
        HEAP32[$73>>2] = $68;
        $74 = (($72) + 4)|0;
        $75 = $74;
        HEAP32[$75>>2] = $71;
        $76 = (($index$01$i) + 1)|0;
        $77 = ($76|0)==($49|0);
        if ($77) {
         break L18;
        } else {
         $index$01$i = $76;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $78 = HEAP32[$40>>2]|0;
     $79 = (($78) + 4|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==(0);
     if (!($81)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       $84 = (($index$017) + 1)|0;
       $85 = HEAP32[$40>>2]|0;
       $86 = (($85) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($84|0)==($87|0);
       if ($88) {
        break L11;
       } else {
        $index$017 = $84;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $89 = HEAP32[$buffer>>2]|0;
   $90 = ($89|0)==(0|0);
   if ($90) {
    STACKTOP = sp;return;
   }
   $91 = HEAP32[$1>>2]|0;
   $92 = ($91|0)==($89|0);
   if (!($92)) {
    $__new_last2$i$i$i$i$i$i$i = $89;
    $scevgep$i$i$i$i$i$i$i = (($91) + -8|0);
    $93 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($93)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $94 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $95 = $94 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($91) + ($95<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($89|0),($$byval_copy8|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $98 = ___cxa_find_matching_catch()|0;
    $99 = tempRet0;
    ___cxa_call_unexpected(($98|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -8|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 3;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8Vector2f13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI8Vector2f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580768>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$49 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,630840,0);
       $50 = (($49) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,630848,0);
       $51 = (($49) + 8|0);
       $52 = ($51|0)==($11|0);
       if ($52) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$16>>2]|0;
       $30 = $$pre9;$33 = $$pre10;$49 = $51;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $53 = HEAP32[$data>>2]|0;
   $54 = ($53|0)==($11|0);
   if (!($54)) {
    $58 = $53;
    while(1) {
     $55 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,$converter$i$i,1)|0);
     $56 = ($55|0)==(0);
     if (!($56)) {
      $57 = ($55|0)>(0);
      if ($57) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$58,630840,0);
       $59 = (($58) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$59,630848,0);
      } else {
       $60 = HEAP32[$converter$i$i>>2]|0;
       $61 = ($60|0)==(0|0);
       if (!($61)) {
        (FUNCTION_TABLE_iii[$60 & 4095]($58,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $62 = (($58) + 8|0);
     $63 = ($62|0)==($11|0);
     if ($63) {
      break;
     } else {
      $58 = $62;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1866,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = (($48|0) / 12)&-1;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($44|0)==($45|0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),12)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + (($index$01$i*12)|0)|0);
        ;HEAP32[$61+0>>2]=HEAP32[$65+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$65+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$65+8>>2]|0;
        $66 = (($index$01$i) + 1)|0;
        $67 = ($66|0)==($49|0);
        if ($67) {
         break L18;
        } else {
         $index$01$i = $66;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $68 = HEAP32[$40>>2]|0;
     $69 = (($68) + 4|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($70|0)==(0);
     if (!($71)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = (($index$017) + 1)|0;
       $75 = HEAP32[$40>>2]|0;
       $76 = (($75) + 4|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($74|0)==($77|0);
       if ($78) {
        break L11;
       } else {
        $index$017 = $74;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $79 = HEAP32[$buffer>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    STACKTOP = sp;return;
   }
   $81 = HEAP32[$1>>2]|0;
   $82 = ($81|0)==($79|0);
   if (!($82)) {
    $__new_last2$i$i$i$i$i$i$i = $79;
    $scevgep$i$i$i$i$i$i$i = (($81) + -12|0);
    $83 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($83)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $84 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $85 = $84 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($81) + (($85*12)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($79|0),($$byval_copy8|0));
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    ___cxa_call_unexpected(($88|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -12|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = (($uglygep3$i$i$i$i$i$i$i8>>>0) / 12)&-1;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + (($33*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8Vector3f13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI8Vector3f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580776>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$49 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$49,630840,0);
       $50 = (($49) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$50,630848,0);
       $51 = (($49) + 8|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$51,631088,0);
       $52 = (($49) + 12|0);
       $53 = ($52|0)==($11|0);
       if ($53) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$16>>2]|0;
       $30 = $$pre9;$33 = $$pre10;$49 = $52;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $54 = HEAP32[$data>>2]|0;
   $55 = ($54|0)==($11|0);
   if (!($55)) {
    $59 = $54;
    while(1) {
     $56 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,$converter$i$i,1)|0);
     $57 = ($56|0)==(0);
     if (!($57)) {
      $58 = ($56|0)>(0);
      if ($58) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$59,630840,0);
       $60 = (($59) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$60,630848,0);
       $61 = (($59) + 8|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$61,631088,0);
      } else {
       $62 = HEAP32[$converter$i$i>>2]|0;
       $63 = ($62|0)==(0|0);
       if (!($63)) {
        (FUNCTION_TABLE_iii[$62 & 4095]($59,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $64 = (($59) + 12|0);
     $65 = ($64|0)==($11|0);
     if ($65) {
      break;
     } else {
      $59 = $64;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1867,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 3;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),8)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<3)|0);
        $66 = +HEAPF64[$65>>3];
        HEAPF64[$61>>3] = $66;
        $67 = (($index$01$i) + 1)|0;
        $68 = ($67|0)==($49|0);
        if ($68) {
         break L18;
        } else {
         $index$01$i = $67;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0);
     if (!($72)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($index$017) + 1)|0;
       $76 = HEAP32[$40>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($75|0)==($78|0);
       if ($79) {
        break L11;
       } else {
        $index$017 = $75;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $80 = HEAP32[$buffer>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = HEAP32[$1>>2]|0;
   $83 = ($82|0)==($80|0);
   if (!($83)) {
    $__new_last2$i$i$i$i$i$i$i = $80;
    $scevgep$i$i$i$i$i$i$i = (($82) + -8|0);
    $84 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($84)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $85 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($82) + ($86<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -8|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 3;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580568>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $80 = HEAP32[$data>>2]|0;
    $81 = ($80|0)==($11|0);
    if ($81) {
     break;
    } else {
     $82 = $80;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIdEEvRT_PKc17TransferMetaFlags($this,$82,630376,0);
     $83 = (($82) + 8|0);
     $84 = ($83|0)==($11|0);
     if ($84) {
      break L4;
     } else {
      $82 = $83;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$67 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 8)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        HEAP8[tempDoublePtr>>0]=HEAP8[$61>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$61+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$61+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$61+3>>0];HEAP8[tempDoublePtr+4>>0]=HEAP8[$61+4>>0];HEAP8[tempDoublePtr+5>>0]=HEAP8[$61+5>>0];HEAP8[tempDoublePtr+6>>0]=HEAP8[$61+6>>0];HEAP8[tempDoublePtr+7>>0]=HEAP8[$61+7>>0];$66 = +HEAPF64[tempDoublePtr>>3];
        HEAPF64[tempDoublePtr>>3]=$66;HEAP8[$67>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$67+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$67+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$67+3>>0]=HEAP8[tempDoublePtr+3>>0];HEAP8[$67+4>>0]=HEAP8[tempDoublePtr+4>>0];HEAP8[$67+5>>0]=HEAP8[tempDoublePtr+5>>0];HEAP8[$67+6>>0]=HEAP8[tempDoublePtr+6>>0];HEAP8[$67+7>>0]=HEAP8[tempDoublePtr+7>>0];
        $68 = HEAP32[$29>>2]|0;
        $69 = (($68) + 8|0);
        HEAP32[$29>>2] = $69;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$67,8);
      }
      $70 = HEAP32[$this>>2]|0;
      $71 = $70 & 512;
      $72 = ($71|0)==(0);
      if (!($72)) {
       $73 = HEAP32[$67>>2]|0;
       $74 = (_llvm_bswap_i32(($73|0))|0);
       $75 = (($67) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = (_llvm_bswap_i32(($76|0))|0);
       HEAP32[$67>>2] = $77;
       HEAP32[$75>>2] = $74;
      }
      $78 = (($67) + 8|0);
      $79 = ($78|0)==($11|0);
      if ($79) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$67 = $78;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1868,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 2;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),4)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<2)|0);
        $66 = Math_fround(HEAPF32[$65>>2]);
        HEAPF32[$61>>2] = $66;
        $67 = (($index$01$i) + 1)|0;
        $68 = ($67|0)==($49|0);
        if ($68) {
         break L18;
        } else {
         $index$01$i = $67;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0);
     if (!($72)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($index$017) + 1)|0;
       $76 = HEAP32[$40>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($75|0)==($78|0);
       if ($79) {
        break L11;
       } else {
        $index$017 = $75;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $80 = HEAP32[$buffer>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = HEAP32[$1>>2]|0;
   $83 = ($82|0)==($80|0);
   if (!($83)) {
    $__new_last2$i$i$i$i$i$i$i = $80;
    $scevgep$i$i$i$i$i$i$i = (($82) + -4|0);
    $84 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($84)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $85 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($82) + ($86<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580584>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $75 = HEAP32[$data>>2]|0;
    $76 = ($75|0)==($11|0);
    if ($76) {
     break;
    } else {
     $77 = $75;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$77,630376,0);
     $78 = (($77) + 4|0);
     $79 = ($78|0)==($11|0);
     if ($79) {
      break L4;
     } else {
      $77 = $78;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$67 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = Math_fround(HEAPF32[$61>>2]);
        HEAPF32[$67>>2] = $66;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$67,4);
      }
      $68 = HEAP32[$this>>2]|0;
      $69 = $68 & 512;
      $70 = ($69|0)==(0);
      if (!($70)) {
       $71 = HEAP32[$67>>2]|0;
       $72 = (_llvm_bswap_i32(($71|0))|0);
       HEAP32[$67>>2] = $72;
      }
      $73 = (($67) + 4|0);
      $74 = ($73|0)==($11|0);
      if ($74) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$67 = $73;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1869,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 3;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),8)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<3)|0);
        $66 = $65;
        $67 = $66;
        $68 = HEAP32[$67>>2]|0;
        $69 = (($66) + 4)|0;
        $70 = $69;
        $71 = HEAP32[$70>>2]|0;
        $72 = $61;
        $73 = $72;
        HEAP32[$73>>2] = $68;
        $74 = (($72) + 4)|0;
        $75 = $74;
        HEAP32[$75>>2] = $71;
        $76 = (($index$01$i) + 1)|0;
        $77 = ($76|0)==($49|0);
        if ($77) {
         break L18;
        } else {
         $index$01$i = $76;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $78 = HEAP32[$40>>2]|0;
     $79 = (($78) + 4|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==(0);
     if (!($81)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       $84 = (($index$017) + 1)|0;
       $85 = HEAP32[$40>>2]|0;
       $86 = (($85) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($84|0)==($87|0);
       if ($88) {
        break L11;
       } else {
        $index$017 = $84;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $89 = HEAP32[$buffer>>2]|0;
   $90 = ($89|0)==(0|0);
   if ($90) {
    STACKTOP = sp;return;
   }
   $91 = HEAP32[$1>>2]|0;
   $92 = ($91|0)==($89|0);
   if (!($92)) {
    $__new_last2$i$i$i$i$i$i$i = $89;
    $scevgep$i$i$i$i$i$i$i = (($91) + -8|0);
    $93 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($93)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $94 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $95 = $94 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($91) + ($95<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($89|0),($$byval_copy8|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $98 = ___cxa_find_matching_catch()|0;
    $99 = tempRet0;
    ___cxa_call_unexpected(($98|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -8|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 3;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580736>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $87 = HEAP32[$data>>2]|0;
    $88 = ($87|0)==($11|0);
    if ($88) {
     break;
    } else {
     $89 = $87;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIyEEvRT_PKc17TransferMetaFlags($this,$89,630376,0);
     $90 = (($89) + 8|0);
     $91 = ($90|0)==($11|0);
     if ($91) {
      break L4;
     } else {
      $89 = $90;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$73 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 8)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = $61;
        $67 = $66;
        $68 = HEAP32[$67>>2]|0;
        $69 = (($66) + 4)|0;
        $70 = $69;
        $71 = HEAP32[$70>>2]|0;
        $72 = $73;
        $74 = $72;
        HEAP32[$74>>2] = $68;
        $75 = (($72) + 4)|0;
        $76 = $75;
        HEAP32[$76>>2] = $71;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$73,8);
      }
      $77 = HEAP32[$this>>2]|0;
      $78 = $77 & 512;
      $79 = ($78|0)==(0);
      if (!($79)) {
       $80 = HEAP32[$73>>2]|0;
       $81 = (_llvm_bswap_i32(($80|0))|0);
       $82 = (($73) + 4|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = (_llvm_bswap_i32(($83|0))|0);
       HEAP32[$73>>2] = $84;
       HEAP32[$82>>2] = $81;
      }
      $85 = (($73) + 8|0);
      $86 = ($85|0)==($11|0);
      if ($86) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$73 = $85;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1870,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 3;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),8)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<3)|0);
        $66 = $65;
        $67 = $66;
        $68 = HEAP32[$67>>2]|0;
        $69 = (($66) + 4)|0;
        $70 = $69;
        $71 = HEAP32[$70>>2]|0;
        $72 = $61;
        $73 = $72;
        HEAP32[$73>>2] = $68;
        $74 = (($72) + 4)|0;
        $75 = $74;
        HEAP32[$75>>2] = $71;
        $76 = (($index$01$i) + 1)|0;
        $77 = ($76|0)==($49|0);
        if ($77) {
         break L18;
        } else {
         $index$01$i = $76;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $78 = HEAP32[$40>>2]|0;
     $79 = (($78) + 4|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($80|0)==(0);
     if (!($81)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       $84 = (($index$017) + 1)|0;
       $85 = HEAP32[$40>>2]|0;
       $86 = (($85) + 4|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($84|0)==($87|0);
       if ($88) {
        break L11;
       } else {
        $index$017 = $84;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $89 = HEAP32[$buffer>>2]|0;
   $90 = ($89|0)==(0|0);
   if ($90) {
    STACKTOP = sp;return;
   }
   $91 = HEAP32[$1>>2]|0;
   $92 = ($91|0)==($89|0);
   if (!($92)) {
    $__new_last2$i$i$i$i$i$i$i = $89;
    $scevgep$i$i$i$i$i$i$i = (($91) + -8|0);
    $93 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($93)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $94 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $95 = $94 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($91) + ($95<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($89|0),($$byval_copy8|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $98 = ___cxa_find_matching_catch()|0;
    $99 = tempRet0;
    ___cxa_call_unexpected(($98|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -8|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 3;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580688>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $87 = HEAP32[$data>>2]|0;
    $88 = ($87|0)==($11|0);
    if ($88) {
     break;
    } else {
     $89 = $87;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($this,$89,630376,0);
     $90 = (($89) + 8|0);
     $91 = ($90|0)==($11|0);
     if ($91) {
      break L4;
     } else {
      $89 = $90;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$73 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 8)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = $61;
        $67 = $66;
        $68 = HEAP32[$67>>2]|0;
        $69 = (($66) + 4)|0;
        $70 = $69;
        $71 = HEAP32[$70>>2]|0;
        $72 = $73;
        $74 = $72;
        HEAP32[$74>>2] = $68;
        $75 = (($72) + 4)|0;
        $76 = $75;
        HEAP32[$76>>2] = $71;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$73,8);
      }
      $77 = HEAP32[$this>>2]|0;
      $78 = $77 & 512;
      $79 = ($78|0)==(0);
      if (!($79)) {
       $80 = HEAP32[$73>>2]|0;
       $81 = (_llvm_bswap_i32(($80|0))|0);
       $82 = (($73) + 4|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = (_llvm_bswap_i32(($83|0))|0);
       HEAP32[$73>>2] = $84;
       HEAP32[$82>>2] = $81;
      }
      $85 = (($73) + 8|0);
      $86 = ($85|0)==($11|0);
      if ($86) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$73 = $85;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1871,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 2;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),4)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<2)|0);
        $66 = HEAP32[$65>>2]|0;
        HEAP32[$61>>2] = $66;
        $67 = (($index$01$i) + 1)|0;
        $68 = ($67|0)==($49|0);
        if ($68) {
         break L18;
        } else {
         $index$01$i = $67;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0);
     if (!($72)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($index$017) + 1)|0;
       $76 = HEAP32[$40>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($75|0)==($78|0);
       if ($79) {
        break L11;
       } else {
        $index$017 = $75;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $80 = HEAP32[$buffer>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = HEAP32[$1>>2]|0;
   $83 = ($82|0)==($80|0);
   if (!($83)) {
    $__new_last2$i$i$i$i$i$i$i = $80;
    $scevgep$i$i$i$i$i$i$i = (($82) + -4|0);
    $84 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($84)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $85 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($82) + ($86<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580752>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $75 = HEAP32[$data>>2]|0;
    $76 = ($75|0)==($11|0);
    if ($76) {
     break;
    } else {
     $77 = $75;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$77,630376,0);
     $78 = (($77) + 4|0);
     $79 = ($78|0)==($11|0);
     if ($79) {
      break L4;
     } else {
      $77 = $78;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$67 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = HEAP32[$61>>2]|0;
        HEAP32[$67>>2] = $66;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$67,4);
      }
      $68 = HEAP32[$this>>2]|0;
      $69 = $68 & 512;
      $70 = ($69|0)==(0);
      if (!($70)) {
       $71 = HEAP32[$67>>2]|0;
       $72 = (_llvm_bswap_i32(($71|0))|0);
       HEAP32[$67>>2] = $72;
      }
      $73 = (($67) + 4|0);
      $74 = ($73|0)==($11|0);
      if ($74) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$67 = $73;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1872,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 2;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),4)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<2)|0);
        $66 = HEAP32[$65>>2]|0;
        HEAP32[$61>>2] = $66;
        $67 = (($index$01$i) + 1)|0;
        $68 = ($67|0)==($49|0);
        if ($68) {
         break L18;
        } else {
         $index$01$i = $67;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0);
     if (!($72)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($index$017) + 1)|0;
       $76 = HEAP32[$40>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($75|0)==($78|0);
       if ($79) {
        break L11;
       } else {
        $index$017 = $75;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $80 = HEAP32[$buffer>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = HEAP32[$1>>2]|0;
   $83 = ($82|0)==($80|0);
   if (!($83)) {
    $__new_last2$i$i$i$i$i$i$i = $80;
    $scevgep$i$i$i$i$i$i$i = (($82) + -4|0);
    $84 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($84)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $85 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($82) + ($86<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580592>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $75 = HEAP32[$data>>2]|0;
    $76 = ($75|0)==($11|0);
    if ($76) {
     break;
    } else {
     $77 = $75;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$77,630376,0);
     $78 = (($77) + 4|0);
     $79 = ($78|0)==($11|0);
     if ($79) {
      break L4;
     } else {
      $77 = $78;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$67 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = HEAP32[$61>>2]|0;
        HEAP32[$67>>2] = $66;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$67,4);
      }
      $68 = HEAP32[$this>>2]|0;
      $69 = $68 & 512;
      $70 = ($69|0)==(0);
      if (!($70)) {
       $71 = HEAP32[$67>>2]|0;
       $72 = (_llvm_bswap_i32(($71|0))|0);
       HEAP32[$67>>2] = $72;
      }
      $73 = (($67) + 4|0);
      $74 = ($73|0)==($11|0);
      if ($74) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$67 = $73;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1873,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 1;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),2)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<1)|0);
        $66 = HEAP16[$65>>1]|0;
        HEAP16[$61>>1] = $66;
        $67 = (($index$01$i) + 1)|0;
        $68 = ($67|0)==($49|0);
        if ($68) {
         break L18;
        } else {
         $index$01$i = $67;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0);
     if (!($72)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($index$017) + 1)|0;
       $76 = HEAP32[$40>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($75|0)==($78|0);
       if ($79) {
        break L11;
       } else {
        $index$017 = $75;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $80 = HEAP32[$buffer>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = HEAP32[$1>>2]|0;
   $83 = ($82|0)==($80|0);
   if (!($83)) {
    $__new_last2$i$i$i$i$i$i$i = $80;
    $scevgep$i$i$i$i$i$i$i = (($82) + -2|0);
    $84 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($84)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $85 = $uglygep3$i$i$i$i$i$i$i >>> 1;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($82) + ($86<<1)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -2|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 1;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580720>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $79 = HEAP32[$data>>2]|0;
    $80 = ($79|0)==($11|0);
    if ($80) {
     break;
    } else {
     $81 = $79;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($this,$81,630376,0);
     $82 = (($81) + 2|0);
     $83 = ($82|0)==($11|0);
     if ($83) {
      break L4;
     } else {
      $81 = $82;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$67 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 2)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = HEAP16[$61>>1]|0;
        HEAP16[$67>>1] = $66;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$67,2);
      }
      $68 = HEAP32[$this>>2]|0;
      $69 = $68 & 512;
      $70 = ($69|0)==(0);
      if (!($70)) {
       $71 = HEAP16[$67>>1]|0;
       $72 = $71&65535;
       $73 = $72 << 8;
       $74 = $72 >>> 8;
       $75 = $73 | $74;
       $76 = $75&65535;
       HEAP16[$67>>1] = $76;
      }
      $77 = (($67) + 2|0);
      $78 = ($77|0)==($11|0);
      if ($78) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$67 = $77;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i4 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$017 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1874,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $38 = (($4) + 136|0);
   $$idx$val = HEAP8[$38>>0]|0;
   $39 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($39)) {
     $40 = (($runtimeInfo) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($staticInfo) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = HEAP32[$buffer>>2]|0;
     $46 = $44;
     $47 = $45;
     $48 = (($46) - ($47))|0;
     $49 = $48 >> 1;
     $50 = (($41) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($49|0);
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3288,($43|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1554,($43|0),($53|0),($49|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 10;
       break L1;
      }
      HEAP32[$41>>2] = $56;
      HEAP32[$50>>2] = $49;
     }
     $59 = ($49|0)==(0);
     L18: do {
      if (!($59)) {
       $index$01$i = 0;
       while(1) {
        $60 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        $61 = (invoke_iiii(1555,($60|0),($index$01$i|0),2)|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$buffer>>2]|0;
        $65 = (($64) + ($index$01$i<<1)|0);
        $66 = HEAP16[$65>>1]|0;
        HEAP16[$61>>1] = $66;
        $67 = (($index$01$i) + 1)|0;
        $68 = ($67|0)==($49|0);
        if ($68) {
         break L18;
        } else {
         $index$01$i = $67;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $69 = HEAP32[$40>>2]|0;
     $70 = (($69) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($71|0)==(0);
     if (!($72)) {
      $index$017 = 0;
      while(1) {
       __THREW__ = 0;
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = (($index$017) + 1)|0;
       $76 = HEAP32[$40>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($75|0)==($78|0);
       if ($79) {
        break L11;
       } else {
        $index$017 = $75;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $80 = HEAP32[$buffer>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = HEAP32[$1>>2]|0;
   $83 = ($82|0)==($80|0);
   if (!($83)) {
    $__new_last2$i$i$i$i$i$i$i = $80;
    $scevgep$i$i$i$i$i$i$i = (($82) + -2|0);
    $84 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($84)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $85 = $uglygep3$i$i$i$i$i$i$i >>> 1;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($82) + ($86<<1)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    ___cxa_call_unexpected(($89|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i4 = $27;
  $scevgep$i$i$i$i$i$i$i5 = (($29) + -2|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i5) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i7;
  $32 = $uglygep3$i$i$i$i$i$i$i8 >>> 1;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i9 = (($29) + ($33<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i9;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580672>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $79 = HEAP32[$data>>2]|0;
    $80 = ($79|0)==($11|0);
    if ($80) {
     break;
    } else {
     $81 = $79;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIsEEvRT_PKc17TransferMetaFlags($this,$81,630376,0);
     $82 = (($81) + 2|0);
     $83 = ($82|0)==($11|0);
     if ($83) {
      break L4;
     } else {
      $81 = $82;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$67 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 2)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = HEAP16[$61>>1]|0;
        HEAP16[$67>>1] = $66;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$67,2);
      }
      $68 = HEAP32[$this>>2]|0;
      $69 = $68 & 512;
      $70 = ($69|0)==(0);
      if (!($70)) {
       $71 = HEAP16[$67>>1]|0;
       $72 = $71&65535;
       $73 = $72 << 8;
       $74 = $72 >>> 8;
       $75 = $73 | $74;
       $76 = $75&65535;
       HEAP16[$67>>1] = $76;
      }
      $77 = (($67) + 2|0);
      $78 = ($77|0)==($11|0);
      if ($78) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$67 = $77;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIhEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$011 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1875,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $35 = (($4) + 136|0);
   $$idx$val = HEAP8[$35>>0]|0;
   $36 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($36)) {
     $37 = (($runtimeInfo) + 20|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($staticInfo) + 28|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = HEAP32[$1>>2]|0;
     $42 = HEAP32[$buffer>>2]|0;
     $43 = $41;
     $44 = $42;
     $45 = (($43) - ($44))|0;
     $46 = (($38) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==($45|0);
     if (!($48)) {
      __THREW__ = 0;
      $49 = (invoke_ii(3288,($40|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $52 = (invoke_iiii(1554,($40|0),($49|0),($45|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 10;
       break L1;
      }
      HEAP32[$38>>2] = $52;
      HEAP32[$46>>2] = $45;
     }
     $55 = ($41|0)==($42|0);
     L18: do {
      if (!($55)) {
       $index$01$i = 0;
       while(1) {
        $56 = HEAP32[$38>>2]|0;
        __THREW__ = 0;
        $57 = (invoke_iiii(1555,($56|0),($index$01$i|0),1)|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
        $60 = HEAP32[$buffer>>2]|0;
        $61 = (($60) + ($index$01$i)|0);
        $62 = HEAP8[$61>>0]|0;
        HEAP8[$57>>0] = $62;
        $63 = (($index$01$i) + 1)|0;
        $64 = ($63|0)==($45|0);
        if ($64) {
         break L18;
        } else {
         $index$01$i = $63;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $65 = HEAP32[$37>>2]|0;
     $66 = (($65) + 4|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($67|0)==(0);
     if (!($68)) {
      $index$011 = 0;
      while(1) {
       __THREW__ = 0;
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break;
       }
       $71 = (($index$011) + 1)|0;
       $72 = HEAP32[$37>>2]|0;
       $73 = (($72) + 4|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($71|0)==($74|0);
       if ($75) {
        break L11;
       } else {
        $index$011 = $71;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $76 = HEAP32[$buffer>>2]|0;
   $77 = ($76|0)==(0|0);
   if ($77) {
    STACKTOP = sp;return;
   }
   $78 = HEAP32[$1>>2]|0;
   $79 = ($78|0)==($76|0);
   if (!($79)) {
    HEAP32[$1>>2] = $76;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($76|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  HEAP32[$1>>2] = $27;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  ___cxa_call_unexpected(($33|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 HEAP32[$size>>2] = $7;
 $8 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$9);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$size>>2]|0;
 $12 = ($11|0)==(0);
 do {
  if (!($12)) {
   $13 = HEAP32[580744>>2]|0;
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$13,0,0)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($10|0);
    L8: do {
     if (!($27)) {
      $28 = (($this) + 12|0);
      $29 = (($this) + 16|0);
      $30 = (($this) + 28|0);
      $31 = (($this) + 32|0);
      $32 = (($this) + 20|0);
      $34 = 0;$37 = $23;$66 = $26;
      while(1) {
       $33 = Math_imul($34, $19)|0;
       $35 = (($33) + ($25))|0;
       $36 = (($37) + 20|0);
       HEAP32[$36>>2] = $35;
       $38 = (($37) + 12|0);
       HEAP32[$38>>2] = $35;
       $39 = (($37) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$37);
       $40 = $1;
       $41 = $40;
       $42 = HEAP32[$41>>2]|0;
       $43 = (($40) + 4)|0;
       $44 = $43;
       $45 = HEAP32[$44>>2]|0;
       $46 = $39;
       $47 = $46;
       HEAP32[$47>>2] = $42;
       $48 = (($46) + 4)|0;
       $49 = $48;
       HEAP32[$49>>2] = $45;
       $50 = HEAP32[$20>>2]|0;
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 1)|0;
       HEAP32[$50>>2] = $52;
       $53 = HEAP32[$15>>2]|0;
       $54 = (($53) + 12|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = HEAP32[$29>>2]|0;
       $57 = HEAP32[$30>>2]|0;
       $58 = HEAP32[$31>>2]|0;
       $59 = Math_imul($58, $57)|0;
       $$sum$i$i$i = (($55) - ($59))|0;
       $60 = (($56) + ($$sum$i$i$i)|0);
       HEAP32[$28>>2] = $60;
       $61 = ($$sum$i$i$i|0)<(0);
       if ($61) {
        label = 9;
       } else {
        $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
        $62 = (($56) + ($$sum1$i$i$i)|0);
        $63 = HEAP32[$32>>2]|0;
        $64 = ($62>>>0)>($63>>>0);
        if ($64) {
         label = 9;
        } else {
         $65 = HEAP8[$60>>0]|0;
         HEAP8[$66>>0] = $65;
         $67 = HEAP32[$28>>2]|0;
         $68 = (($67) + 1|0);
         HEAP32[$28>>2] = $68;
        }
       }
       if ((label|0) == 9) {
        label = 0;
        __ZN12CachedReader15UpdateReadCacheEPvj($28,$66,1);
       }
       $69 = (($66) + 1|0);
       $70 = ($69|0)==($10|0);
       if ($70) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$15>>2]|0;
       $34 = $$pre8;$37 = $$pre9;$66 = $69;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $71 = HEAP32[$data>>2]|0;
   $72 = ($71|0)==($10|0);
   if (!($72)) {
    $73 = (($this) + 12|0);
    $74 = (($this) + 16|0);
    $75 = (($this) + 28|0);
    $76 = (($this) + 32|0);
    $77 = (($this) + 20|0);
    $94 = $71;
    while(1) {
     $78 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$13,$converter$i$i,0)|0);
     $79 = ($78|0)==(0);
     if (!($79)) {
      $80 = ($78|0)>(0);
      do {
       if ($80) {
        $81 = HEAP32[$15>>2]|0;
        $82 = (($81) + 12|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = HEAP32[$74>>2]|0;
        $85 = HEAP32[$75>>2]|0;
        $86 = HEAP32[$76>>2]|0;
        $87 = Math_imul($86, $85)|0;
        $$sum$i$i$i$i$i = (($83) - ($87))|0;
        $88 = (($84) + ($$sum$i$i$i$i$i)|0);
        HEAP32[$73>>2] = $88;
        $89 = ($$sum$i$i$i$i$i|0)<(0);
        if (!($89)) {
         $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
         $90 = (($84) + ($$sum1$i$i$i$i$i)|0);
         $91 = HEAP32[$77>>2]|0;
         $92 = ($90>>>0)>($91>>>0);
         if (!($92)) {
          $93 = HEAP8[$88>>0]|0;
          HEAP8[$94>>0] = $93;
          $95 = HEAP32[$73>>2]|0;
          $96 = (($95) + 1|0);
          HEAP32[$73>>2] = $96;
          break;
         }
        }
        __ZN12CachedReader15UpdateReadCacheEPvj($73,$94,1);
       } else {
        $97 = HEAP32[$converter$i$i>>2]|0;
        $98 = ($97|0)==(0|0);
        if (!($98)) {
         (FUNCTION_TABLE_iii[$97 & 4095]($94,$this)|0);
        }
       }
      } while(0);
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($94) + 1|0);
     $100 = ($99|0)==($10|0);
     if ($100) {
      break;
     } else {
      $94 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead19Converter_PrimitiveIaEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$011 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_iiiiii(192,($4|0),($6|0),($7|0),($converter$i$i|0),1)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 10;
  } else {
   $11 = ($8|0)==(0);
   if (!($11)) {
    $12 = ($8|0)>(0);
    if ($12) {
     __THREW__ = 0;
     invoke_viii(1876,($4|0),($buffer|0),0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break;
     }
    } else {
     $15 = HEAP32[$converter$i$i>>2]|0;
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii($15|0,($buffer|0),($4|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($4|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 10;
     break;
    }
   }
   $35 = (($4) + 136|0);
   $$idx$val = HEAP8[$35>>0]|0;
   $36 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($36)) {
     $37 = (($runtimeInfo) + 20|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($staticInfo) + 28|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = HEAP32[$1>>2]|0;
     $42 = HEAP32[$buffer>>2]|0;
     $43 = $41;
     $44 = $42;
     $45 = (($43) - ($44))|0;
     $46 = (($38) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==($45|0);
     if (!($48)) {
      __THREW__ = 0;
      $49 = (invoke_ii(3288,($40|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $52 = (invoke_iiii(1554,($40|0),($49|0),($45|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 10;
       break L1;
      }
      HEAP32[$38>>2] = $52;
      HEAP32[$46>>2] = $45;
     }
     $55 = ($41|0)==($42|0);
     L18: do {
      if (!($55)) {
       $index$01$i = 0;
       while(1) {
        $56 = HEAP32[$38>>2]|0;
        __THREW__ = 0;
        $57 = (invoke_iiii(1555,($56|0),($index$01$i|0),1)|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
        $60 = HEAP32[$buffer>>2]|0;
        $61 = (($60) + ($index$01$i)|0);
        $62 = HEAP8[$61>>0]|0;
        HEAP8[$57>>0] = $62;
        $63 = (($index$01$i) + 1)|0;
        $64 = ($63|0)==($45|0);
        if ($64) {
         break L18;
        } else {
         $index$01$i = $63;
        }
       }
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       break L1;
      }
     } while(0);
     $65 = HEAP32[$37>>2]|0;
     $66 = (($65) + 4|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($67|0)==(0);
     if (!($68)) {
      $index$011 = 0;
      while(1) {
       __THREW__ = 0;
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break;
       }
       $71 = (($index$011) + 1)|0;
       $72 = HEAP32[$37>>2]|0;
       $73 = (($72) + 4|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($71|0)==($74|0);
       if ($75) {
        break L11;
       } else {
        $index$011 = $71;
       }
      }
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L1;
     }
    }
   } while(0);
   $76 = HEAP32[$buffer>>2]|0;
   $77 = ($76|0)==(0|0);
   if ($77) {
    STACKTOP = sp;return;
   }
   $78 = HEAP32[$1>>2]|0;
   $79 = ($78|0)==($76|0);
   if (!($79)) {
    HEAP32[$1>>2] = $76;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($76|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  HEAP32[$1>>2] = $27;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  ___cxa_call_unexpected(($33|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 HEAP32[$size>>2] = $7;
 $8 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$9);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$size>>2]|0;
 $12 = ($11|0)==(0);
 do {
  if (!($12)) {
   $13 = HEAP32[580696>>2]|0;
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$13,0,0)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($10|0);
    L8: do {
     if (!($27)) {
      $28 = (($this) + 12|0);
      $29 = (($this) + 16|0);
      $30 = (($this) + 28|0);
      $31 = (($this) + 32|0);
      $32 = (($this) + 20|0);
      $34 = 0;$37 = $23;$66 = $26;
      while(1) {
       $33 = Math_imul($34, $19)|0;
       $35 = (($33) + ($25))|0;
       $36 = (($37) + 20|0);
       HEAP32[$36>>2] = $35;
       $38 = (($37) + 12|0);
       HEAP32[$38>>2] = $35;
       $39 = (($37) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$37);
       $40 = $1;
       $41 = $40;
       $42 = HEAP32[$41>>2]|0;
       $43 = (($40) + 4)|0;
       $44 = $43;
       $45 = HEAP32[$44>>2]|0;
       $46 = $39;
       $47 = $46;
       HEAP32[$47>>2] = $42;
       $48 = (($46) + 4)|0;
       $49 = $48;
       HEAP32[$49>>2] = $45;
       $50 = HEAP32[$20>>2]|0;
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 1)|0;
       HEAP32[$50>>2] = $52;
       $53 = HEAP32[$15>>2]|0;
       $54 = (($53) + 12|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = HEAP32[$29>>2]|0;
       $57 = HEAP32[$30>>2]|0;
       $58 = HEAP32[$31>>2]|0;
       $59 = Math_imul($58, $57)|0;
       $$sum$i$i$i = (($55) - ($59))|0;
       $60 = (($56) + ($$sum$i$i$i)|0);
       HEAP32[$28>>2] = $60;
       $61 = ($$sum$i$i$i|0)<(0);
       if ($61) {
        label = 9;
       } else {
        $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
        $62 = (($56) + ($$sum1$i$i$i)|0);
        $63 = HEAP32[$32>>2]|0;
        $64 = ($62>>>0)>($63>>>0);
        if ($64) {
         label = 9;
        } else {
         $65 = HEAP8[$60>>0]|0;
         HEAP8[$66>>0] = $65;
         $67 = HEAP32[$28>>2]|0;
         $68 = (($67) + 1|0);
         HEAP32[$28>>2] = $68;
        }
       }
       if ((label|0) == 9) {
        label = 0;
        __ZN12CachedReader15UpdateReadCacheEPvj($28,$66,1);
       }
       $69 = (($66) + 1|0);
       $70 = ($69|0)==($10|0);
       if ($70) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$15>>2]|0;
       $34 = $$pre8;$37 = $$pre9;$66 = $69;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $71 = HEAP32[$data>>2]|0;
   $72 = ($71|0)==($10|0);
   if (!($72)) {
    $73 = (($this) + 12|0);
    $74 = (($this) + 16|0);
    $75 = (($this) + 28|0);
    $76 = (($this) + 32|0);
    $77 = (($this) + 20|0);
    $94 = $71;
    while(1) {
     $78 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$13,$converter$i$i,0)|0);
     $79 = ($78|0)==(0);
     if (!($79)) {
      $80 = ($78|0)>(0);
      do {
       if ($80) {
        $81 = HEAP32[$15>>2]|0;
        $82 = (($81) + 12|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = HEAP32[$74>>2]|0;
        $85 = HEAP32[$75>>2]|0;
        $86 = HEAP32[$76>>2]|0;
        $87 = Math_imul($86, $85)|0;
        $$sum$i$i$i$i$i = (($83) - ($87))|0;
        $88 = (($84) + ($$sum$i$i$i$i$i)|0);
        HEAP32[$73>>2] = $88;
        $89 = ($$sum$i$i$i$i$i|0)<(0);
        if (!($89)) {
         $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
         $90 = (($84) + ($$sum1$i$i$i$i$i)|0);
         $91 = HEAP32[$77>>2]|0;
         $92 = ($90>>>0)>($91>>>0);
         if (!($92)) {
          $93 = HEAP8[$88>>0]|0;
          HEAP8[$94>>0] = $93;
          $95 = HEAP32[$73>>2]|0;
          $96 = (($95) + 1|0);
          HEAP32[$73>>2] = $96;
          break;
         }
        }
        __ZN12CachedReader15UpdateReadCacheEPvj($73,$94,1);
       } else {
        $97 = HEAP32[$converter$i$i>>2]|0;
        $98 = ($97|0)==(0|0);
        if (!($98)) {
         (FUNCTION_TABLE_iii[$97 & 4095]($94,$this)|0);
        }
       }
      } while(0);
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($94) + 1|0);
     $100 = ($99|0)==($10|0);
     if ($100) {
      break;
     } else {
      $94 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI14SafeBinaryRead16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$idx$val = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i6 = 0, $$pre$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $converter$i$i = 0, $index$01$i = 0, $index$018 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy10 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $converter$i$i = sp + 8|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($staticInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $9 = (invoke_iiiiii(192,($5|0),($7|0),($8|0),($converter$i$i|0),1)|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 10;
  } else {
   $12 = ($9|0)==(0);
   if (!($12)) {
    $13 = ($9|0)>(0);
    if ($13) {
     __THREW__ = 0;
     invoke_viii(1877,($5|0),($buffer|0),0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      label = 10;
      break;
     }
    } else {
     $16 = HEAP32[$converter$i$i>>2]|0;
     $17 = ($16|0)==(0|0);
     if (!($17)) {
      __THREW__ = 0;
      (invoke_iii($16|0,($buffer|0),($5|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       label = 10;
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($5|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 10;
     break;
    }
   }
   $50 = (($5) + 136|0);
   $$idx$val = HEAP8[$50>>0]|0;
   $51 = ($$idx$val<<24>>24)==(0);
   L11: do {
    if (!($51)) {
     $52 = (($runtimeInfo) + 20|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = (($staticInfo) + 28|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = HEAP32[$2>>2]|0;
     $57 = HEAP32[$buffer>>2]|0;
     $58 = $56;
     $59 = $57;
     $60 = (($58) - ($59))|0;
     $61 = (($60|0) / 12)&-1;
     $62 = (($53) + 4|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63|0)==($61|0);
     if (!($64)) {
      __THREW__ = 0;
      $65 = (invoke_ii(3288,($55|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 10;
       break L1;
      }
      __THREW__ = 0;
      $68 = (invoke_iiii(1554,($55|0),($65|0),($61|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 10;
       break L1;
      }
      HEAP32[$53>>2] = $68;
      HEAP32[$62>>2] = $61;
     }
     $71 = ($56|0)==($57|0);
     L18: do {
      if (!($71)) {
       $index$01$i = 0;
       while(1) {
        $72 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        $73 = (invoke_iii(2433,($72|0),($index$01$i|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        $76 = HEAP32[$buffer>>2]|0;
        $77 = (($76) + (($index$01$i*12)|0)|0);
        $78 = HEAP8[$77>>0]|0;
        $79 = $78 & 1;
        $80 = ($79<<24>>24)==(0);
        if ($80) {
         $83 = (($77) + 1|0);
         $84 = $83;
        } else {
         $81 = ((($76) + (($index$01$i*12)|0)|0) + 8|0);
         $82 = HEAP32[$81>>2]|0;
         $84 = $82;
        }
        __THREW__ = 0;
        $85 = (invoke_ii(3287,($84|0))|0);
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         break;
        }
        HEAP32[$73>>2] = $85;
        $88 = (($index$01$i) + 1)|0;
        $89 = ($88|0)==($61|0);
        if ($89) {
         break L18;
        } else {
         $index$01$i = $88;
        }
       }
       $24 = ___cxa_find_matching_catch()|0;
       $25 = tempRet0;
       $lpad$phi$index = $24;$lpad$phi$index3 = $25;
       break L1;
      }
     } while(0);
     $90 = HEAP32[$52>>2]|0;
     $91 = (($90) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($92|0)==(0);
     if (!($93)) {
      $95 = $90;$index$018 = 0;
      while(1) {
       $94 = HEAP32[$95>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($94|0),($index$018|0))|0);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if ($97) {
        break;
       }
       $98 = (($index$018) + 1)|0;
       $99 = HEAP32[$52>>2]|0;
       $100 = (($99) + 4|0);
       $101 = HEAP32[$100>>2]|0;
       $102 = ($98|0)==($101|0);
       if ($102) {
        break L11;
       } else {
        $95 = $99;$index$018 = $98;
       }
      }
      $22 = ___cxa_find_matching_catch()|0;
      $23 = tempRet0;
      $lpad$phi$index = $22;$lpad$phi$index3 = $23;
      break L1;
     }
    }
   } while(0);
   $103 = HEAP32[$buffer>>2]|0;
   $104 = ($103|0)==(0|0);
   if ($104) {
    STACKTOP = sp;return;
   }
   $105 = HEAP32[$2>>2]|0;
   $106 = ($105|0)==($103|0);
   do {
    if ($106) {
     $120 = $103;
    } else {
     $108 = $105;
     while(1) {
      $107 = (($108) + -12|0);
      HEAP32[$2>>2] = $107;
      $109 = HEAP8[$107>>0]|0;
      $110 = $109 & 1;
      $111 = ($110<<24>>24)==(0);
      if ($111) {
       $113 = $107;
      } else {
       $114 = (($108) + -4|0);
       $115 = HEAP32[$114>>2]|0;
       HEAP32[$0>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($115|0),($$byval_copy10|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 45;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$2>>2]|0;
       $113 = $$pre$i$i$i$i$i$i$i;
      }
      $112 = ($113|0)==($103|0);
      if ($112) {
       label = 46;
       break;
      } else {
       $108 = $113;
      }
     }
     if ((label|0) == 45) {
      $118 = ___cxa_find_matching_catch()|0;
      $119 = tempRet0;
      ___cxa_call_unexpected(($118|0));
      // unreachable;
     }
     else if ((label|0) == 46) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $120 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($120|0),($$byval_copy10|0));
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if ($122) {
    $123 = ___cxa_find_matching_catch()|0;
    $124 = tempRet0;
    ___cxa_call_unexpected(($123|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $lpad$phi$index = $26;$lpad$phi$index3 = $27;
 }
 $28 = HEAP32[$buffer>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $30 = HEAP32[$2>>2]|0;
 $31 = ($30|0)==($28|0);
 do {
  if ($31) {
   $45 = $28;
  } else {
   $33 = $30;
   while(1) {
    $32 = (($33) + -12|0);
    HEAP32[$2>>2] = $32;
    $34 = HEAP8[$32>>0]|0;
    $35 = $34 & 1;
    $36 = ($35<<24>>24)==(0);
    if ($36) {
     $38 = $32;
    } else {
     $39 = (($33) + -4|0);
     $40 = HEAP32[$39>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($40|0),($$byval_copy10|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 18;
      break;
     }
     $$pre$i$i$i$i$i$i$i6 = HEAP32[$2>>2]|0;
     $38 = $$pre$i$i$i$i$i$i$i6;
    }
    $37 = ($38|0)==($28|0);
    if ($37) {
     label = 19;
     break;
    } else {
     $33 = $38;
    }
   }
   if ((label|0) == 18) {
    $43 = ___cxa_find_matching_catch()|0;
    $44 = tempRet0;
    ___cxa_call_unexpected(($43|0));
    // unreachable;
   }
   else if ((label|0) == 19) {
    $$pre$i$i$i$i$i8 = HEAP32[$buffer>>2]|0;
    $45 = $$pre$i$i$i$i$i8;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($45|0),($$byval_copy10|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorINS1_12basic_stringIcNS1_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES6_IS9_LS7_90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,630368,630368,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorINS0_12basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES5_IS8_LS6_90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580712>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$49 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__112basic_stringIcNS1_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$49,0);
       $50 = (($49) + 12|0);
       $51 = ($50|0)==($11|0);
       if ($51) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$16>>2]|0;
       $30 = $$pre9;$33 = $$pre10;$49 = $50;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $52 = HEAP32[$data>>2]|0;
   $53 = ($52|0)==($11|0);
   if (!($53)) {
    $57 = $52;
    while(1) {
     $54 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,630376,$14,$converter$i$i,0)|0);
     $55 = ($54|0)==(0);
     if (!($55)) {
      $56 = ($54|0)>(0);
      if ($56) {
       __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__112basic_stringIcNS1_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$57,0);
      } else {
       $58 = HEAP32[$converter$i$i>>2]|0;
       $59 = ($58|0)==(0|0);
       if (!($59)) {
        (FUNCTION_TABLE_iii[$58 & 4095]($57,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $60 = (($57) + 12|0);
     $61 = ($60|0)==($11|0);
     if ($61) {
      break;
     } else {
      $57 = $60;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __Z33EmitSerializationCommandsForFieldI13ProxyTransferEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$0$i$ph9 = 0, $$off = 0, $$ph = 0, $$ph8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $serializeFieldCommand = 0, $staticInfo$sroa$9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $staticInfo$sroa$9 = sp;
 $serializeFieldCommand = sp + 16|0;
 $1 = (($tfi) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z24scripting_class_get_typeP14ScriptingClass($2)|0);
 $4 = (__Z23scripting_type_get_typeP13ScriptingType($3)|0);
 $5 = ($4|0)==(29);
 if (!($5)) {
  $6 = (__ZN9Scripting30IsSystemCollectionsGenericListEP14ScriptingClass($2)|0);
  if (!($6)) {
   ;HEAP32[$staticInfo$sroa$9+0>>2]=0|0;HEAP32[$staticInfo$sroa$9+4>>2]=0|0;HEAP32[$staticInfo$sroa$9+8>>2]=0|0;
   $7 = HEAP32[$tfi>>2]|0;
   $8 = (__Z24scripting_field_get_nameP14ScriptingField($7)|0);
   $9 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $10 = (__Z25scripting_class_from_typeP13ScriptingType($9)|0);
   $11 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $12 = (__Z23scripting_type_get_typeP13ScriptingType($11)|0);
   $13 = (__Z26scripting_field_get_offsetP14ScriptingField($7)|0);
   $14 = (__Z24scripting_class_get_nameP14ScriptingClass($10)|0);
   $15 = (($tfi) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = (($tfi) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($tfi) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   L4: do {
    switch ($19|0) {
    case 3:  {
     $22 = $16 | 33554432;
     $$0$i$ph = 2960;$$ph = $22;
     label = 47;
     break;
    }
    case 6:  {
     $$0$i$ph = 2963;$$ph = $16;
     label = 47;
     break;
    }
    case 13:  {
     $$0$i$ph = 2969;$$ph = $16;
     label = 47;
     break;
    }
    case 8:  {
     $$0$i$ph = 2964;$$ph = $16;
     label = 47;
     break;
    }
    case 7:  {
     $$0$i$ph = 2960;$$ph = $16;
     label = 47;
     break;
    }
    case 2:  {
     $23 = $16 | 256;
     $$0$i$ph = 2962;$$ph = $23;
     label = 47;
     break;
    }
    case 11:  {
     $$0$i$ph = 2967;$$ph = $16;
     label = 47;
     break;
    }
    case 9:  {
     $$0$i$ph = 2965;$$ph = $16;
     label = 47;
     break;
    }
    case 5:  {
     $$0$i$ph = 2962;$$ph = $16;
     label = 47;
     break;
    }
    case 14:  {
     $$0$i$ph = 2959;$$ph = $16;
     label = 47;
     break;
    }
    case 4:  {
     $$0$i$ph = 2961;$$ph = $16;
     label = 47;
     break;
    }
    case 10:  {
     $$0$i$ph = 2966;$$ph = $16;
     label = 47;
     break;
    }
    case 12:  {
     $$0$i$ph = 2968;$$ph = $16;
     label = 47;
     break;
    }
    default: {
     $24 = (($21) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($17|0)==($25|0);
     if ($26) {
      $$0$i$ph = 2970;$$ph = $16;
      label = 47;
     } else {
      $27 = (($21) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($17|0)==($28|0);
      if ($29) {
       $$0$i$ph = 2971;$$ph = $16;
       label = 47;
      } else {
       $30 = (($21) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($17|0)==($31|0);
       if ($32) {
        $$0$i$ph = 2972;$$ph = $16;
        label = 47;
       } else {
        $33 = (($21) + 24|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = ($17|0)==($34|0);
        if ($35) {
         $$0$i$ph = 2973;$$ph = $16;
         label = 47;
        } else {
         $36 = (($21) + 32|0);
         $37 = HEAP32[$36>>2]|0;
         $38 = ($17|0)==($37|0);
         if ($38) {
          $$0$i$ph = 2974;$$ph = $16;
          label = 47;
         } else {
          $39 = (($21) + 36|0);
          $40 = HEAP32[$39>>2]|0;
          $41 = ($17|0)==($40|0);
          if ($41) {
           $$0$i$ph = 2975;$$ph = $16;
           label = 47;
          } else {
           $42 = (($21) + 40|0);
           $43 = HEAP32[$42>>2]|0;
           $44 = ($17|0)==($43|0);
           if ($44) {
            $$0$i$ph = 2976;$$ph = $16;
            label = 47;
           } else {
            $45 = (($21) + 52|0);
            $46 = HEAP32[$45>>2]|0;
            $47 = ($17|0)==($46|0);
            if ($47) {
             $$0$i$ph = 2977;$$ph = $16;
             label = 47;
            } else {
             $48 = (($21) + 56|0);
             $49 = HEAP32[$48>>2]|0;
             $50 = ($17|0)==($49|0);
             if ($50) {
              $$0$i$ph = 2978;$$ph = $16;
              label = 47;
             } else {
              $51 = (($21) + 88|0);
              $52 = HEAP32[$51>>2]|0;
              $53 = ($17|0)==($52|0);
              if ($53) {
               $$0$i$ph = 2979;$$ph = $16;
               label = 47;
              } else {
               $54 = (($21) + 492|0);
               $55 = HEAP32[$54>>2]|0;
               $56 = ($17|0)==($55|0);
               do {
                if (!($56)) {
                 $57 = (($21) + 496|0);
                 $58 = HEAP32[$57>>2]|0;
                 $59 = ($17|0)==($58|0);
                 if (!($59)) {
                  $60 = (__Z23scripting_class_is_enumP14ScriptingClass($17)|0);
                  if (!($60)) {
                   $85 = (($21) + 280|0);
                   $86 = HEAP32[$85>>2]|0;
                   $87 = ($17|0)==($86|0);
                   if ($87) {
                    $$0$i$ph = 2980;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $88 = (($21) + 504|0);
                   $89 = HEAP32[$88>>2]|0;
                   $90 = ($17|0)==($89|0);
                   if ($90) {
                    $$0$i$ph = 2981;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $91 = (($21) + 28|0);
                   $92 = HEAP32[$91>>2]|0;
                   $93 = ($17|0)==($92|0);
                   if ($93) {
                    $$0$i$ph = 2982;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $94 = (($21) + 272|0);
                   $95 = HEAP32[$94>>2]|0;
                   $96 = ($17|0)==($95|0);
                   if ($96) {
                    $$0$i$ph9 = 2983;$$ph8 = $16;
                    break L4;
                   }
                   $97 = ($19|0)==(18);
                   if (!($97)) {
                    break;
                   }
                   $98 = (($21) + 244|0);
                   $99 = HEAP32[$98>>2]|0;
                   $100 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($17,$99)|0);
                   if ($100) {
                    $$0$i$ph9 = 2984;$$ph8 = $16;
                    break L4;
                   } else {
                    break;
                   }
                  }
                  $61 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($17)|0);
                  $62 = (__Z23scripting_type_get_typeP13ScriptingType($61)|0);
                  if ((($62|0) == 5)) {
                   $$0$i$ph = 2962;$$ph = $16;
                   label = 47;
                   break L4;
                  } else if ((($62|0) == 8)) {
                   $$0$i$ph = 2964;$$ph = $16;
                   label = 47;
                   break L4;
                  }
                  $63 = HEAP32[$tfi>>2]|0;
                  __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$63);
                  $64 = HEAP8[$0>>0]|0;
                  $65 = $64 & 1;
                  $66 = ($65<<24>>24)==(0);
                  if ($66) {
                   $69 = (($0) + 1|0);
                   $70 = $69;
                  } else {
                   $67 = (($0) + 8|0);
                   $68 = HEAP32[$67>>2]|0;
                   $70 = $68;
                  }
                  __THREW__ = 0;
                  invoke_viiiiiiii(21,($70|0),0,(630440|0),188,1,0,0,(0|0));
                  $71 = __THREW__; __THREW__ = 0;
                  $72 = $71&1;
                  if (!($72)) {
                   $73 = HEAP8[$0>>0]|0;
                   $74 = $73 & 1;
                   $75 = ($74<<24>>24)==(0);
                   if ($75) {
                    break;
                   }
                   $76 = (($0) + 8|0);
                   $77 = HEAP32[$76>>2]|0;
                   __ZdlPv($77);
                   break;
                  }
                  $78 = ___cxa_find_matching_catch()|0;
                  $79 = tempRet0;
                  $80 = HEAP8[$0>>0]|0;
                  $81 = $80 & 1;
                  $82 = ($81<<24>>24)==(0);
                  if ($82) {
                   ___resumeException($78|0);
                   // unreachable;
                  }
                  $83 = (($0) + 8|0);
                  $84 = HEAP32[$83>>2]|0;
                  __ZdlPv($84);
                  ___resumeException($78|0);
                  // unreachable;
                 }
                }
               } while(0);
               $114 = HEAP32[$18>>2]|0;
               $$off = (($114) + -17)|0;
               $115 = ($$off>>>0)<(2);
               if (!($115)) {
                STACKTOP = sp;return;
               }
               __Z46EmitSerializationCommandsForManagedObjectFieldI13ProxyTransferEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
    }
   } while(0);
   if ((label|0) == 47) {
    $101 = (($tfi) + 25|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $$0$i$ph9 = $$0$i$ph;$$ph8 = $$ph;
    } else {
     STACKTOP = sp;return;
    }
   }
   dest=$serializeFieldCommand+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$serializeFieldCommand>>2] = $$0$i$ph9;
   $104 = (($serializeFieldCommand) + 4|0);
   HEAP32[$104>>2] = $7;
   $105 = (($serializeFieldCommand) + 8|0);
   HEAP32[$105>>2] = $8;
   $106 = (($serializeFieldCommand) + 12|0);
   HEAP32[$106>>2] = $14;
   $107 = (($serializeFieldCommand) + 16|0);
   HEAP32[$107>>2] = $10;
   $108 = (($serializeFieldCommand) + 20|0);
   HEAP32[$108>>2] = $12;
   $109 = (($serializeFieldCommand) + 24|0);
   HEAP32[$109>>2] = $13;
   $110 = (($serializeFieldCommand) + 28|0);
   HEAP32[$110>>2] = $$ph8;
   $111 = (($serializeFieldCommand) + 32|0);
   HEAP32[$111>>2] = $17;
   $112 = (($serializeFieldCommand) + 36|0);
   HEAP32[$112>>2] = $19;
   $113 = (($serializeFieldCommand) + 40|0);
   ;HEAP32[$113+0>>2]=HEAP32[$staticInfo$sroa$9+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[$staticInfo$sroa$9+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[$staticInfo$sroa$9+8>>2]|0;
   __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$serializeFieldCommand);
   STACKTOP = sp;return;
  }
 }
 __Z49EmitSerializationCommandsForLinearCollectionFieldI13ProxyTransferEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
 STACKTOP = sp;return;
}
function __ZL12InvokeMethodI13ProxyTransferEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $invocation = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $invocation = sp + 8|0;
 $0 = sp;
 $1 = (($args) + 57|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($args) + 56|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($args) + 48|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $18 = (($runtimeInfo) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($invocation) + 12|0);
 HEAP32[$20>>2] = $19;
 $21 = HEAP8[$runtimeInfo>>0]|0;
 $22 = (($invocation) + 24|0);
 HEAP8[$22>>0] = $21;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation)|0);
 STACKTOP = sp;return;
}
function __Z49EmitSerializationCommandsForLinearCollectionFieldI13ProxyTransferEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($info,$commandQueueBuilder,$nameConversions) {
 $info = $info|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$off = 0, $$ph = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $command = 0, $linearCollectionField = 0, $switch = 0, $tfi = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 184|0;
 $linearCollectionField = sp + 144|0;
 $1 = sp + 68|0;
 $tfi = sp;
 $command = sp + 80|0;
 $$sroa$9 = sp + 56|0;
 HEAP8[$1>>0] = 1;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$info>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$1,$4);
 dest=$tfi+0|0; src=$info+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = HEAP32[$info>>2]|0;
 HEAP32[$tfi>>2] = $5;
 $6 = (__ZN21LinearCollectionField15GetElementClassEv($linearCollectionField)|0);
 $7 = (($tfi) + 40|0);
 HEAP32[$7>>2] = $6;
 $8 = (__Z24scripting_class_get_typeP14ScriptingClass($6)|0);
 $9 = (__Z23scripting_type_get_typeP13ScriptingType($8)|0);
 $10 = (($tfi) + 44|0);
 HEAP32[$10>>2] = $9;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 dest=$command+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$command>>2] = 2985;
 ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
 $14 = (__Z24scripting_field_get_nameP14ScriptingField($5)|0);
 $15 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $16 = (__Z25scripting_class_from_typeP13ScriptingType($15)|0);
 $17 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $18 = (__Z23scripting_type_get_typeP13ScriptingType($17)|0);
 $19 = (__Z26scripting_field_get_offsetP14ScriptingField($5)|0);
 $20 = (__Z24scripting_class_get_nameP14ScriptingClass($16)|0);
 $21 = (($tfi) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($command) + 4|0);
 HEAP32[$23>>2] = $5;
 $24 = (($command) + 8|0);
 HEAP32[$24>>2] = $14;
 $25 = (($command) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($command) + 16|0);
 HEAP32[$26>>2] = $16;
 $27 = (($command) + 20|0);
 HEAP32[$27>>2] = $18;
 $28 = (($command) + 24|0);
 HEAP32[$28>>2] = $19;
 $29 = (($command) + 28|0);
 HEAP32[$29>>2] = $22;
 $30 = (($command) + 32|0);
 HEAP32[$30>>2] = $6;
 $31 = (($command) + 36|0);
 HEAP32[$31>>2] = $9;
 $32 = (($command) + 40|0);
 ;HEAP32[$32+0>>2]=HEAP32[$$sroa$9+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$$sroa$9+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$$sroa$9+8>>2]|0;
 $33 = (($tfi) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 L1: do {
  switch ($9|0) {
  case 7:  {
   $$0$i$ph = 2987;$$ph = 1;
   break;
  }
  case 9:  {
   $$0$i$ph = 2992;$$ph = 1;
   break;
  }
  case 12:  {
   $$0$i$ph = 2995;$$ph = 1;
   break;
  }
  case 14:  {
   $$0$i$ph = 2986;$$ph = 1;
   break;
  }
  case 6:  {
   $$0$i$ph = 2990;$$ph = 1;
   break;
  }
  case 2:  {
   $36 = $22 | 256;
   HEAP32[$29>>2] = $36;
   $$0$i$ph = 2989;$$ph = 1;
   break;
  }
  case 4:  {
   $$0$i$ph = 2988;$$ph = 1;
   break;
  }
  case 8:  {
   $$0$i$ph = 2991;$$ph = 1;
   break;
  }
  case 5:  {
   $$0$i$ph = 2989;$$ph = 1;
   break;
  }
  case 13:  {
   $$0$i$ph = 2996;$$ph = 1;
   break;
  }
  case 10:  {
   $$0$i$ph = 2993;$$ph = 1;
   break;
  }
  case 11:  {
   $$0$i$ph = 2994;$$ph = 1;
   break;
  }
  case 3:  {
   $35 = $22 | 33554432;
   HEAP32[$29>>2] = $35;
   $$0$i$ph = 2987;$$ph = 1;
   break;
  }
  default: {
   $37 = (($34) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($6|0)==($38|0);
   if ($39) {
    $$0$i$ph = 2997;$$ph = 1;
   } else {
    $40 = (($34) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($6|0)==($41|0);
    if ($42) {
     $$0$i$ph = 2998;$$ph = 1;
    } else {
     $43 = (($34) + 20|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($6|0)==($44|0);
     if ($45) {
      $$0$i$ph = 2999;$$ph = 1;
     } else {
      $46 = (($34) + 24|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($6|0)==($47|0);
      if ($48) {
       $$0$i$ph = 3000;$$ph = 1;
      } else {
       $49 = (($34) + 32|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($6|0)==($50|0);
       if ($51) {
        $$0$i$ph = 3001;$$ph = 1;
       } else {
        $52 = (($34) + 36|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($6|0)==($53|0);
        if ($54) {
         $$0$i$ph = 3002;$$ph = 1;
        } else {
         $55 = (($34) + 40|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($6|0)==($56|0);
         if ($57) {
          $$0$i$ph = 3003;$$ph = 1;
         } else {
          $58 = (($34) + 52|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = ($6|0)==($59|0);
          if ($60) {
           $$0$i$ph = 3004;$$ph = 1;
          } else {
           $61 = (($34) + 56|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = ($6|0)==($62|0);
           if ($63) {
            $$0$i$ph = 3005;$$ph = 1;
           } else {
            $64 = (($34) + 88|0);
            $65 = HEAP32[$64>>2]|0;
            $66 = ($6|0)==($65|0);
            if ($66) {
             $$0$i$ph = 3006;$$ph = 1;
            } else {
             $67 = (($34) + 492|0);
             $68 = HEAP32[$67>>2]|0;
             $69 = ($6|0)==($68|0);
             do {
              if ($69) {
               label = 44;
              } else {
               $70 = (($34) + 496|0);
               $71 = HEAP32[$70>>2]|0;
               $72 = ($6|0)==($71|0);
               if ($72) {
                label = 44;
               } else {
                $73 = (__Z23scripting_class_is_enumP14ScriptingClass($6)|0);
                if (!($73)) {
                 $97 = (($34) + 280|0);
                 $98 = HEAP32[$97>>2]|0;
                 $99 = ($6|0)==($98|0);
                 if ($99) {
                  $$0$i$ph = 3007;$$ph = 1;
                  break L1;
                 }
                 $100 = (($34) + 504|0);
                 $101 = HEAP32[$100>>2]|0;
                 $102 = ($6|0)==($101|0);
                 if ($102) {
                  $$0$i$ph = 3008;$$ph = 1;
                  break L1;
                 }
                 $103 = (($34) + 28|0);
                 $104 = HEAP32[$103>>2]|0;
                 $105 = ($6|0)==($104|0);
                 if ($105) {
                  $$0$i$ph = 3009;$$ph = 1;
                  break L1;
                 }
                 $106 = (($34) + 272|0);
                 $107 = HEAP32[$106>>2]|0;
                 $108 = ($6|0)==($107|0);
                 if ($108) {
                  $$0$i$ph = 3010;$$ph = 0;
                  break L1;
                 }
                 $109 = ($9|0)==(18);
                 if (!($109)) {
                  label = 44;
                  break;
                 }
                 $110 = (($34) + 244|0);
                 $111 = HEAP32[$110>>2]|0;
                 $112 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$111)|0);
                 if ($112) {
                  $$0$i$ph = 3011;$$ph = 0;
                  break L1;
                 } else {
                  break;
                 }
                }
                $74 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($6)|0);
                $75 = (__Z23scripting_type_get_typeP13ScriptingType($74)|0);
                if ((($75|0) == 8)) {
                 $$0$i$ph = 2991;$$ph = 1;
                 break L1;
                } else if ((($75|0) == 5)) {
                 $$0$i$ph = 2989;$$ph = 1;
                 break L1;
                }
                __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$5);
                $76 = HEAP8[$0>>0]|0;
                $77 = $76 & 1;
                $78 = ($77<<24>>24)==(0);
                if ($78) {
                 $81 = (($0) + 1|0);
                 $82 = $81;
                } else {
                 $79 = (($0) + 8|0);
                 $80 = HEAP32[$79>>2]|0;
                 $82 = $80;
                }
                __THREW__ = 0;
                invoke_viiiiiiii(21,($82|0),0,(630440|0),188,1,0,0,(0|0));
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if (!($84)) {
                 $85 = HEAP8[$0>>0]|0;
                 $86 = $85 & 1;
                 $87 = ($86<<24>>24)==(0);
                 if ($87) {
                  label = 44;
                  break;
                 }
                 $88 = (($0) + 8|0);
                 $89 = HEAP32[$88>>2]|0;
                 __ZdlPv($89);
                 label = 44;
                 break;
                }
                $90 = ___cxa_find_matching_catch()|0;
                $91 = tempRet0;
                $92 = HEAP8[$0>>0]|0;
                $93 = $92 & 1;
                $94 = ($93<<24>>24)==(0);
                if ($94) {
                 ___resumeException($90|0);
                 // unreachable;
                }
                $95 = (($0) + 8|0);
                $96 = HEAP32[$95>>2]|0;
                __ZdlPv($96);
                ___resumeException($90|0);
                // unreachable;
               }
              }
             } while(0);
             if ((label|0) == 44) {
              $$off = (($9) + -17)|0;
              $switch = ($$off>>>0)<(2);
              if (!($switch)) {
               STACKTOP = sp;return;
              }
             }
             __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI13ProxyTransferEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$command,$commandQueueBuilder,$nameConversions);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
  }
 } while(0);
 $113 = (($tfi) + 25|0);
 $114 = HEAP8[$113>>0]|0;
 $115 = $114 & $$ph;
 $116 = ($115<<24>>24)==(0);
 if (!($116)) {
  STACKTOP = sp;return;
 }
 $117 = (($command) + 44|0);
 HEAP32[$117>>2] = $$0$i$ph;
 __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$command);
 STACKTOP = sp;return;
}
function __Z46EmitSerializationCommandsForManagedObjectFieldI13ProxyTransferEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $args = 0, $newCommandQueueBuilder = 0, $serializeManagedObject = 0, $tfi$idx = 0, $tfi$idx$val = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy1 = sp + 124|0;
 $0 = sp + 120|0;
 $args = sp + 12|0;
 $newCommandQueueBuilder = sp + 32|0;
 $serializeManagedObject = sp + 56|0;
 $$sroa$9 = sp;
 $tfi$idx = (($tfi) + 4|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI18TransferField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$8>>2] = $13;
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 $14 = (($newCommandQueueBuilder) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($newCommandQueueBuilder) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($newCommandQueueBuilder) + 4|0);
 HEAP32[$16>>2] = 61;
 $17 = (($newCommandQueueBuilder) + 16|0);
 HEAP8[$17>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(383,($args|0),($newCommandQueueBuilder|0),($nameConversions|0),0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 do {
  if (!($19)) {
   $20 = (($tfi) + 25|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    label = 8;
   } else {
    $23 = HEAP32[$14>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    dest=$serializeManagedObject+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$serializeManagedObject>>2] = 3012;
    ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
    $33 = HEAP32[$tfi>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3280,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3276,($33|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3278,($37|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_ii(3276,($33|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    $46 = (invoke_ii(3277,($43|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    __THREW__ = 0;
    $49 = (invoke_ii(3283,($33|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    __THREW__ = 0;
    $52 = (invoke_ii(3284,($40|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    $55 = (($tfi) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$tfi$idx>>2]|0;
    $58 = (($tfi) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($serializeManagedObject) + 4|0);
    HEAP32[$60>>2] = $33;
    $61 = (($serializeManagedObject) + 8|0);
    HEAP32[$61>>2] = $34;
    $62 = (($serializeManagedObject) + 12|0);
    HEAP32[$62>>2] = $52;
    $63 = (($serializeManagedObject) + 16|0);
    HEAP32[$63>>2] = $40;
    $64 = (($serializeManagedObject) + 20|0);
    HEAP32[$64>>2] = $46;
    $65 = (($serializeManagedObject) + 24|0);
    HEAP32[$65>>2] = $49;
    $66 = (($serializeManagedObject) + 28|0);
    HEAP32[$66>>2] = $56;
    $67 = (($serializeManagedObject) + 32|0);
    HEAP32[$67>>2] = $57;
    $68 = (($serializeManagedObject) + 36|0);
    HEAP32[$68>>2] = $59;
    $69 = (($serializeManagedObject) + 40|0);
    $70 = $$sroa$9;
    $71 = $70;
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + 4)|0;
    $74 = $73;
    $75 = HEAP32[$74>>2]|0;
    $76 = $69;
    $77 = $76;
    HEAP32[$77>>2] = $72;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = $75;
    $80 = HEAP32[$14>>2]|0;
    $81 = (($serializeManagedObject) + 48|0);
    HEAP32[$81>>2] = $80;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($serializeManagedObject|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($newCommandQueueBuilder|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
   }
   $86 = HEAP32[$15>>2]|0;
   $87 = ($86|0)>(-1);
   if (!($87)) {
    STACKTOP = sp;return;
   }
   $88 = HEAP32[$newCommandQueueBuilder>>2]|0;
   $89 = HEAP32[$16>>2]|0;
   HEAP32[$0>>2] = $89;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($88,$$byval_copy1);
   HEAP32[$newCommandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$15>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$newCommandQueueBuilder>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $90 = ___cxa_find_matching_catch(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 }
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 ___resumeException($25|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $managedObjectTransferer = 0, $newProvider = 0, $runtimeInfo$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $runtimeInfo$i$i$i = sp + 48|0;
 $managedObjectTransferer = sp;
 $0 = sp + 16|0;
 $newProvider = sp + 28|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP32[$managedObjectTransferer+0>>2]=0|0;HEAP32[$managedObjectTransferer+4>>2]=0|0;HEAP32[$managedObjectTransferer+8>>2]=0|0;
 $3 = (($managedObjectTransferer) + 4|0);
 HEAP8[$3>>0] = 1;
 $4 = (($managedObjectTransferer) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($managedObjectTransferer) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 $9 = (($args) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(17);
 do {
  if ($8) {
   $$pre$i = (($args) + 12|0);
   if ($11) {
    $16 = 0;
   } else {
    $12 = HEAP32[$$pre$i>>2]|0;
    $13 = (_il2cpp_object_new($12)|0);
    $16 = $13;
   }
   $14 = HEAP32[$$pre$i>>2]|0;
   HEAP8[$0>>0] = 1;
   $15 = (($0) + 4|0);
   HEAP32[$15>>2] = $16;
   $17 = (($0) + 8|0);
   HEAP32[$17>>2] = $14;
   $$pre$phiZ2D = $0;
  } else {
   if ($11) {
    $18 = (($args) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP8[$runtimeInfo>>0]|0;
    $21 = ($20<<24>>24)!=(0);
    $22 = (($19) + -8)|0;
    $23 = $21 ? $19 : $22;
    $24 = (($7) + ($23)|0);
    $25 = (($args) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP8[$0>>0] = 0;
    $27 = (($0) + 4|0);
    HEAP32[$27>>2] = $24;
    $28 = (($0) + 8|0);
    HEAP32[$28>>2] = $26;
    $$pre$phiZ2D = $0;
    break;
   } else {
    $29 = HEAP32[$args>>2]|0;
    __Z30GetOrCreateObjectStoredInFieldP14ScriptingFieldRK17GeneralMonoObjectb($0,$29,$runtimeInfo,1);
    $$pre$phiZ2D = $0;
    break;
   }
  }
 } while(0);
 ;HEAP32[$3+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
 $30 = (($runtimeInfo) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($args) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + ($33<<6)|0);
 HEAP32[$34>>2] = $36;
 $37 = (($newProvider) + 4|0);
 HEAP32[$37>>2] = $35;
 HEAP32[$newProvider>>2] = $35;
 $38 = (($newProvider) + 8|0);
 HEAP32[$38>>2] = $36;
 $$idx$i = $33 << 6;
 $39 = $$idx$i >> 6;
 $40 = (($newProvider) + 16|0);
 HEAP32[$40>>2] = $39;
 $41 = (($newProvider) + 12|0);
 HEAP32[$41>>2] = $39;
 HEAP32[$managedObjectTransferer>>2] = $newProvider;
 $42 = (($args) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($args) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($args) + 24|0);
 $47 = HEAP32[$46>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($2,$43,$45,$managedObjectTransferer,$47);
 $48 = HEAP32[$managedObjectTransferer>>2]|0;
 ;HEAP32[$runtimeInfo$i$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+20>>2]=0|0;
 $49 = (($runtimeInfo$i$i$i) + 16|0);
 HEAP32[$49>>2] = $2;
 ;HEAP32[$runtimeInfo$i$i$i+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=HEAP32[$3+8>>2]|0;
 $50 = (($runtimeInfo$i$i$i) + 12|0);
 HEAP32[$50>>2] = $48;
 $51 = (($48) + 4|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($48) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($52|0)==($54|0);
 if ($55) {
  __ZN13ProxyTransfer11EndTransferEv($2);
  STACKTOP = sp;return;
 }
 $56 = (($48) + 12|0);
 $58 = $52;$60 = $54;
 while(1) {
  $57 = (($58) + 64|0);
  HEAP32[$51>>2] = $57;
  $59 = $60;
  $61 = $57;
  $62 = (($59) - ($61))|0;
  $63 = $62 >> 6;
  HEAP32[$56>>2] = $63;
  $64 = HEAP32[$58>>2]|0;
  $65 = (($58) + 4|0);
  FUNCTION_TABLE_vii[$64 & 4095]($65,$runtimeInfo$i$i$i);
  $66 = HEAP32[$51>>2]|0;
  $67 = HEAP32[$53>>2]|0;
  $68 = ($66|0)==($67|0);
  if ($68) {
   break;
  } else {
   $58 = $66;$60 = $67;
  }
 }
 __ZN13ProxyTransfer11EndTransferEv($2);
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 24|0;
 $0 = sp + 16|0;
 $native$i$i = sp + 4|0;
 ;HEAP32[$native$i$i+0>>2]=0|0;HEAP32[$native$i$i+4>>2]=0|0;HEAP32[$native$i$i+8>>2]=0|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[580712>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($2|0),($4|0),($7|0),($native$i$i|0),($6|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  invoke_viiiii(87,($2|0),(630368|0),(630368|0),($size$i$i$i$i|0),1);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = HEAP32[580552>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($2|0),(630376|0),($12|0),($p$i$i$i|0),0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = (($2) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($2) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ((($17) + (($19*24)|0)|0) + 12|0);
    HEAP32[$20>>2] = 1;
    __THREW__ = 0;
    invoke_vi(3390,($2|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     invoke_vi(3391,($2|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      invoke_vi(3392,($2|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       invoke_vi(3390,($2|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $40 = HEAP8[$native$i$i>>0]|0;
        $41 = $40 & 1;
        $42 = ($41<<24>>24)==(0);
        if ($42) {
         STACKTOP = sp;return;
        }
        $43 = (($native$i$i) + 8|0);
        $44 = HEAP32[$43>>2]|0;
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($44|0),($$byval_copy1|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         $47 = ___cxa_find_matching_catch()|0;
         $48 = tempRet0;
         ___cxa_call_unexpected(($47|0));
         // unreachable;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP8[$native$i$i>>0]|0;
 $32 = $31 & 1;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  ___resumeException($29|0);
  // unreachable;
 }
 $34 = (($native$i$i) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z22Transfer_Builtin_AlignIa13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580696>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($10);
 $22 = HEAP32[$9>>2]|0;
 __ZN13ProxyTransfer5AlignEv($22);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIh13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($10);
 $22 = HEAP32[$9>>2]|0;
 __ZN13ProxyTransfer5AlignEv($22);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIs13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580672>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($10);
 $22 = HEAP32[$9>>2]|0;
 __ZN13ProxyTransfer5AlignEv($22);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580720>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($10);
 $22 = HEAP32[$9>>2]|0;
 __ZN13ProxyTransfer5AlignEv($22);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580736>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580568>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($10,$8,$12,$14);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580768>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 $16 = (($10) + 16|0);
 $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
 $18 = (($17) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 | 2097152;
 $21 = (($10) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($10) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($23) + (($25*24)|0)|0) + 20|0);
 HEAP32[$26>>2] = $20;
 $27 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,630840,$27,$8,0);
 $28 = HEAP32[$21>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$24>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($10);
 $$sum = (($5) + 4)|0;
 $32 = (($7) + ($$sum)|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,630848,$27,$32,0);
 $33 = HEAP32[$21>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$24>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($10);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580784>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($8,$10);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580648>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 __ZN5RectTIfE8TransferI13ProxyTransferEEvRT_($8,$10);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580640>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 __ZN11Quaternionf8TransferI13ProxyTransferEEvRT_($8,$10);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,631272,$8,$14);
 __ZN10Matrix4x4f8TransferI13ProxyTransferEEvRT_($8,$10);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,631264,$8,$14);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($10,$8,631056,0);
 $$sum = (($5) + 12)|0;
 $15 = (($7) + ($$sum)|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($10,$15,631072,0);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580560>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($8,$10);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3213ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[580560>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,$15,$8,$14);
 __ZN13ProxyTransfer10SetVersionEi($10,2);
 $16 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,631048,$16,$8,1);
 $17 = (($10) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($10) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($19) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($10);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,$12,631248,$8,$14);
 __ZN13ProxyTransfer10SetVersionEi($10,2);
 $15 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($10,631040,$15,$8,4194305);
 $16 = (($10) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($10) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($18) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($10);
 __ZN13ProxyTransfer11EndTransferEv($10);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI13ProxyTransfer17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 88|0;
 $0 = sp;
 $native$i$i = sp + 8|0;
 $1 = (($native$i$i) + 4|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 HEAP32[$native$i$i>>2] = 0;
 $2 = (($native$i$i) + 8|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $3 = (($native$i$i) + 32|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($native$i$i) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($native$i$i) + 36|0);
 $6 = (($native$i$i) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($native$i$i) + 68|0);
 HEAP32[$7>>2] = 0;
 $8 = (($native$i$i) + 60|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$8>>2] = 61;
 $9 = (($native$i$i) + 76|0);
 HEAP32[$9>>2] = 2;
 $10 = (($native$i$i) + 72|0);
 HEAP32[$10>>2] = 2;
 $11 = (($runtimeInfo) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($12|0),($14|0),(631216|0),($native$i$i|0),($16|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  __THREW__ = 0;
  invoke_vii(3013,($native$i$i|0),($12|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   __THREW__ = 0;
   invoke_vi(3390,($12|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $32 = HEAP32[$7>>2]|0;
    $33 = ($32|0)>(-1);
    if (!($33)) {
     STACKTOP = sp;return;
    }
    $34 = (($native$i$i) + 56|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = HEAP32[$8>>2]|0;
    HEAP32[$0>>2] = $36;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($35,$$byval_copy1);
    HEAP32[$34>>2] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$7>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = (($native$i$i) + 56|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $29;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($28|0),($$byval_copy1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $37 = ___cxa_find_matching_catch(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 }
 HEAP32[$27>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZL26Transfer_SimpleNativeClassI13ProxyTransfer11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $native$i$i = sp;
 __ZN11GradientNEWC2Ev($native$i$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($1|0),($3|0),(631200|0),($native$i$i|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  __THREW__ = 0;
  invoke_vii(3014,($native$i$i|0),($1|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   invoke_vi(3390,($1|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    STACKTOP = sp;return;
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __THREW__ = 0;
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  ___clang_call_terminate($16);
  // unreachable;
 } else {
  ___resumeException($12|0);
  // unreachable;
 }
}
function __ZL26Transfer_SimpleNativeClassI13ProxyTransfer10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 ;HEAP32[$native$i$i+0>>2]=0|0;HEAP32[$native$i$i+4>>2]=0|0;HEAP32[$native$i$i+8>>2]=0|0;HEAP32[$native$i$i+12>>2]=0|0;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($1,$3,631152,$native$i$i,$5);
 __ZN10RectOffset8TransferI13ProxyTransferEEvRT_($native$i$i,$1);
 __ZN13ProxyTransfer11EndTransferEv($1);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI13ProxyTransfer8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy1 = sp + 296|0;
 $0 = sp;
 $native$i$i = sp + 4|0;
 __ZN8GUIStyleC2Ev($native$i$i);
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($2|0),($4|0),(631120|0),($native$i$i|0),($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __THREW__ = 0;
  invoke_vii(3015,($native$i$i|0),($2|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   invoke_vi(3390,($2|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $24 = HEAP8[$native$i$i>>0]|0;
    $25 = $24 & 1;
    $26 = ($25<<24>>24)==(0);
    if ($26) {
     STACKTOP = sp;return;
    }
    $27 = (($native$i$i) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($28|0),($$byval_copy1|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $15 = HEAP8[$native$i$i>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  ___resumeException($13|0);
  // unreachable;
 }
 $18 = (($native$i$i) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($19|0),($$byval_copy1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
}
function __ZN8GUIStyle8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $localIdentifier$i$i$i = 0, $p$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i = sp;
 $p$i$i$i = sp + 16|0;
 $0 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630448,$0,$this,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,630368,630368,$localIdentifier$i$i$i,1);
 $1 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630376,$1,$p$i$i$i,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $8 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630456,631168,$8,0);
 __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($8,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630472,631168,$9,0);
 __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($9,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630480,631168,$10,0);
 __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($10,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $11 = (($this) + 72|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630496,631168,$11,0);
 __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($11,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 92|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630512,631168,$12,0);
 __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($12,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 112|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630528,631168,$13,0);
 __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($13,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($this) + 132|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630544,631168,$14,0);
 __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($14,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 152|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630560,631168,$15,0);
 __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($15,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 172|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630576,631152,$16,0);
 __ZN10RectOffset8TransferI13ProxyTransferEEvRT_($16,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 188|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630592,631152,$17,0);
 __ZN10RectOffset8TransferI13ProxyTransferEEvRT_($17,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 204|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630608,631152,$18,0);
 __ZN10RectOffset8TransferI13ProxyTransferEEvRT_($18,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 220|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630624,631152,$19,0);
 __ZN10RectOffset8TransferI13ProxyTransferEEvRT_($19,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 236|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630640,631136,$20,0);
 $21 = (($localIdentifier$i$i$i) + 8|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $26 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630400,$26,$20,1);
 $27 = HEAP32[$2>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$5>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $31 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630416,$31,$21,1);
 $32 = HEAP32[$2>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$5>>2]|0;
 $35 = ((($33) + (($34*24)|0)|0) + 12|0);
 HEAP32[$35>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $36 = (($this) + 280|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630648,$26,$36,0);
 $37 = HEAP32[$2>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$5>>2]|0;
 $40 = ((($38) + (($39*24)|0)|0) + 12|0);
 HEAP32[$40>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $41 = (($this) + 284|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630664,$26,$41,0);
 $42 = HEAP32[$2>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$5>>2]|0;
 $45 = ((($43) + (($44*24)|0)|0) + 12|0);
 HEAP32[$45>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $46 = (($this) + 240|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630680,$26,$46,0);
 $47 = HEAP32[$2>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$5>>2]|0;
 $50 = ((($48) + (($49*24)|0)|0) + 12|0);
 HEAP32[$50>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $51 = (($this) + 244|0);
 $52 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630696,$52,$51,0);
 $53 = HEAP32[$2>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$5>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $57 = (($this) + 245|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630712,$52,$57,0);
 $58 = HEAP32[$2>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$5>>2]|0;
 $61 = ((($59) + (($60*24)|0)|0) + 12|0);
 HEAP32[$61>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $62 = (($this) + 248|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630728,$26,$62,0);
 $63 = HEAP32[$2>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = HEAP32[$5>>2]|0;
 $66 = ((($64) + (($65*24)|0)|0) + 12|0);
 HEAP32[$66>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $67 = (($this) + 252|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630744,$26,$67,0);
 $68 = HEAP32[$2>>2]|0;
 $69 = HEAP32[$68>>2]|0;
 $70 = HEAP32[$5>>2]|0;
 $71 = ((($69) + (($70*24)|0)|0) + 12|0);
 HEAP32[$71>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $72 = (($this) + 256|0);
 $73 = HEAP32[580768>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630760,$73,$72,0);
 $74 = (($transfer) + 16|0);
 $75 = (__ZNK16TypeTreeIterator7GetNodeEv($74)|0);
 $76 = (($75) + 20|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = $77 | 2097152;
 $79 = HEAP32[$2>>2]|0;
 $80 = HEAP32[$79>>2]|0;
 $81 = HEAP32[$5>>2]|0;
 $82 = ((($80) + (($81*24)|0)|0) + 20|0);
 HEAP32[$82>>2] = $78;
 $83 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630840,$83,$72,0);
 $84 = HEAP32[$2>>2]|0;
 $85 = HEAP32[$84>>2]|0;
 $86 = HEAP32[$5>>2]|0;
 $87 = ((($85) + (($86*24)|0)|0) + 12|0);
 HEAP32[$87>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $88 = (($this) + 260|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630848,$83,$88,0);
 $89 = HEAP32[$2>>2]|0;
 $90 = HEAP32[$89>>2]|0;
 $91 = HEAP32[$5>>2]|0;
 $92 = ((($90) + (($91*24)|0)|0) + 12|0);
 HEAP32[$92>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $93 = (($this) + 272|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630776,$83,$93,0);
 $94 = HEAP32[$2>>2]|0;
 $95 = HEAP32[$94>>2]|0;
 $96 = HEAP32[$5>>2]|0;
 $97 = ((($95) + (($96*24)|0)|0) + 12|0);
 HEAP32[$97>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $98 = (($this) + 276|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630792,$83,$98,0);
 $99 = HEAP32[$2>>2]|0;
 $100 = HEAP32[$99>>2]|0;
 $101 = HEAP32[$5>>2]|0;
 $102 = ((($100) + (($101*24)|0)|0) + 12|0);
 HEAP32[$102>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $103 = (($this) + 288|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630808,$52,$103,0);
 $104 = HEAP32[$2>>2]|0;
 $105 = HEAP32[$104>>2]|0;
 $106 = HEAP32[$5>>2]|0;
 $107 = ((($105) + (($106*24)|0)|0) + 12|0);
 HEAP32[$107>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $108 = (($this) + 289|0);
 $109 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630824,$109,$108,0);
 $110 = HEAP32[$2>>2]|0;
 $111 = HEAP32[$110>>2]|0;
 $112 = HEAP32[$5>>2]|0;
 $113 = ((($111) + (($112*24)|0)|0) + 12|0);
 HEAP32[$113>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10RectOffset8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630856,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630864,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630872,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630880,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13GUIStyleState8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630896,631184,$this,0);
 $0 = (($localIdentifier$i$i$i) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $5 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630400,$5,$this,1);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($8) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630416,$12,$0,1);
 $13 = HEAP32[$6>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$9>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 4|0);
 $18 = HEAP32[580560>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630912,$18,$17,0);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($17,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplIfE8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i = sp + 16|0;
 $p$i$i$i = sp;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 56|0);
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630960,$1,$0,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,630368,630368,$size$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630376,631232,$p$i$i$i,0);
 __ZN11KeyframeTplIfE8TransferI13ProxyTransferEEvRT_($p$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($this) + 72|0);
 $3 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630968,$3,$2,1);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 76|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,630984,$3,$10,1);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$7>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11KeyframeTplIfE8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631000,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631008,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631016,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631024,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __Z30TransferField_LinearCollectionI13ProxyTransferEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $array = 0, $linearCollectionField = 0;
 var $newRuntimeInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $linearCollectionField = sp + 40|0;
 $array = sp;
 $0 = sp + 8|0;
 $newRuntimeInfo = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$runtimeInfo,$1);
 HEAP32[$array>>2] = 0;
 $2 = (($array) + 4|0);
 HEAP32[$2>>2] = -1;
 $3 = (($runtimeInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $18 = 0;
 } else {
  __ZN21LinearCollectionField8GetArrayEv($0,$linearCollectionField);
  $6 = $0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $array;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  $$pre = HEAP32[$3>>2]|0;
  $18 = $$pre;
 }
 $16 = HEAP8[$runtimeInfo>>0]|0;
 HEAP8[$newRuntimeInfo>>0] = $16;
 $17 = (($newRuntimeInfo) + 4|0);
 HEAP32[$17>>2] = $18;
 $19 = (($newRuntimeInfo) + 8|0);
 $20 = (($runtimeInfo) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = (($newRuntimeInfo) + 12|0);
 $23 = (($runtimeInfo) + 12|0);
 $24 = $23;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $22;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (($newRuntimeInfo) + 20|0);
 HEAP32[$34>>2] = $array;
 $35 = (($args) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($args,$newRuntimeInfo);
 STACKTOP = sp;return;
}
function __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI13ProxyTransferEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$partiallySetuplinearCollectionCommand,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $partiallySetuplinearCollectionCommand = $partiallySetuplinearCollectionCommand|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandQueueForSingleElement = 0, $or$cond = 0, $tfi$idx = 0, $tfi$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 44|0;
 $0 = sp;
 $args = sp + 4|0;
 $commandQueueForSingleElement = sp + 24|0;
 $tfi$idx = (($tfi) + 40|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI23TransferArrayField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$8>>2] = $12;
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 $13 = (($commandQueueForSingleElement) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($commandQueueForSingleElement) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($commandQueueForSingleElement) + 4|0);
 HEAP32[$15>>2] = 61;
 $16 = (($commandQueueForSingleElement) + 16|0);
 HEAP8[$16>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(383,($args|0),($commandQueueForSingleElement|0),($nameConversions|0),0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = (($tfi) + 25|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)!=(0);
   $$pre = HEAP32[$13>>2]|0;
   $22 = ($$pre|0)==(0);
   $or$cond = $21 & $22;
   if (!($or$cond)) {
    $31 = (($partiallySetuplinearCollectionCommand) + 44|0);
    HEAP32[$31>>2] = 3016;
    $32 = (($partiallySetuplinearCollectionCommand) + 48|0);
    HEAP32[$32>>2] = $$pre;
    $33 = HEAP32[$tfi$idx>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3284,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = (($partiallySetuplinearCollectionCommand) + 40|0);
    HEAP32[$37>>2] = $34;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($partiallySetuplinearCollectionCommand|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($commandQueueForSingleElement|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
   }
   $42 = HEAP32[$14>>2]|0;
   $43 = ($42|0)>(-1);
   if (!($43)) {
    STACKTOP = sp;return;
   }
   $44 = HEAP32[$commandQueueForSingleElement>>2]|0;
   $45 = HEAP32[$15>>2]|0;
   HEAP32[$0>>2] = $45;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($44,$$byval_copy1);
   HEAP32[$commandQueueForSingleElement>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$14>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$commandQueueForSingleElement>>2]|0;
 $28 = HEAP32[$15>>2]|0;
 HEAP32[$0>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $46 = ___cxa_find_matching_catch(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 }
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $$sroa$1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arrayOfManagedObjectsTransferer = 0, $managedObjectTransferer$i$i = 0, $newProvider = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $managedObjectTransferer$i$i = sp + 32|0;
 $$sroa$1$i$i = sp + 48|0;
 $arrayOfManagedObjectsTransferer = sp + 20|0;
 $newProvider = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$arrayOfManagedObjectsTransferer+0>>2]=0|0;HEAP32[$arrayOfManagedObjectsTransferer+4>>2]=0|0;HEAP32[$arrayOfManagedObjectsTransferer+8>>2]=0|0;
 $2 = (($runtimeInfo) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$arrayOfManagedObjectsTransferer>>2] = $3;
 $4 = (($args) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($arrayOfManagedObjectsTransferer) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = (($runtimeInfo) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 44|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($10<<6)|0);
 HEAP32[$11>>2] = $13;
 $14 = (($newProvider) + 4|0);
 HEAP32[$14>>2] = $12;
 HEAP32[$newProvider>>2] = $12;
 $15 = (($newProvider) + 8|0);
 HEAP32[$15>>2] = $13;
 $$idx$i = $10 << 6;
 $16 = $$idx$i >> 6;
 $17 = (($newProvider) + 16|0);
 HEAP32[$17>>2] = $16;
 $18 = (($newProvider) + 12|0);
 HEAP32[$18>>2] = $16;
 $19 = (($arrayOfManagedObjectsTransferer) + 8|0);
 HEAP32[$19>>2] = $newProvider;
 $20 = (($args) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($args) + 36|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($args) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($1,$21,$23,$arrayOfManagedObjectsTransferer,$25);
 $26 = (($managedObjectTransferer$i$i) + 4|0);
 $27 = (($managedObjectTransferer$i$i) + 8|0);
 $28 = (($managedObjectTransferer$i$i) + 12|0);
 HEAP8[$26>>0] = 1;
 $29 = (($managedObjectTransferer$i$i) + 5|0);
 ;HEAP8[$29+0>>0]=HEAP8[$$sroa$1$i$i+0>>0]|0;HEAP8[$29+1>>0]=HEAP8[$$sroa$1$i$i+1>>0]|0;HEAP8[$29+2>>0]=HEAP8[$$sroa$1$i$i+2>>0]|0;
 HEAP32[$27>>2] = 0;
 HEAP32[$28>>2] = 0;
 $30 = HEAP32[$19>>2]|0;
 HEAP32[$managedObjectTransferer$i$i>>2] = $30;
 __ZN13ProxyTransfer32TransferSTLStyleArrayWithElementI23ManagedObjectTransfererEEvRT_17TransferMetaFlags($1,$managedObjectTransferer$i$i,0);
 __ZN13ProxyTransfer11EndTransferEv($1);
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 HEAP8[$converter>>0] = 0;
 __Z19TransferField_ArrayI13ProxyTransfer16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 28|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 32|0;
 $0 = sp + 24|0;
 $buffer$i$i$i = sp + 8|0;
 HEAP32[$buffer$i$i$i>>2] = 0;
 $1 = (($buffer$i$i$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i$i$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i$i$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580696>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 1;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $39 = HEAP32[$buffer$i$i$i>>2]|0;
       $40 = ($39|0)==(0|0);
       if ($40) {
        $47 = HEAP32[$3>>2]|0;
        __ZN13ProxyTransfer5AlignEv($47);
        STACKTOP = sp;return;
       }
       $41 = HEAP32[$1>>2]|0;
       $42 = ($41|0)==($39|0);
       if (!($42)) {
        HEAP32[$1>>2] = $39;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($39|0),($$byval_copy1|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        $45 = ___cxa_find_matching_catch()|0;
        $46 = tempRet0;
        ___cxa_call_unexpected(($45|0));
        // unreachable;
       } else {
        $47 = HEAP32[$3>>2]|0;
        __ZN13ProxyTransfer5AlignEv($47);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer$i$i$i>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  HEAP32[$1>>2] = $31;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z22Transfer_Builtin_AlignIh13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer$i$i$i = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 28|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 32|0;
 $0 = sp + 24|0;
 $buffer$i$i$i = sp + 8|0;
 HEAP32[$buffer$i$i$i>>2] = 0;
 $1 = (($buffer$i$i$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i$i$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i$i$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580744>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 1;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3392,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3390,($4|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $41 = HEAP32[$buffer$i$i$i>>2]|0;
        $42 = ($41|0)==(0|0);
        if ($42) {
         $49 = HEAP32[$3>>2]|0;
         __ZN13ProxyTransfer5AlignEv($49);
         STACKTOP = sp;return;
        }
        $43 = HEAP32[$1>>2]|0;
        $44 = ($43|0)==($41|0);
        if (!($44)) {
         HEAP32[$1>>2] = $41;
        }
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($41|0),($$byval_copy1|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         $47 = ___cxa_find_matching_catch()|0;
         $48 = tempRet0;
         ___cxa_call_unexpected(($47|0));
         // unreachable;
        } else {
         $49 = HEAP32[$3>>2]|0;
         __ZN13ProxyTransfer5AlignEv($49);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $33 = HEAP32[$buffer$i$i$i>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  ___resumeException($31|0);
  // unreachable;
 }
 $35 = HEAP32[$1>>2]|0;
 $36 = ($35|0)==($33|0);
 if (!($36)) {
  HEAP32[$1>>2] = $33;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  ___resumeException($31|0);
  // unreachable;
 }
}
function __Z22Transfer_Builtin_AlignIs13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13ProxyTransfer5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN13ProxyTransfer5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3213ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI13ProxyTransfer17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI13ProxyTransfer27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI13ProxyTransfer11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI13ProxyTransfer27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI13ProxyTransfer10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI13ProxyTransfer27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI13ProxyTransfer8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI13ProxyTransfer27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI13ProxyTransfer27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy3 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$converter>>2]|0;
 $5 = (($buffer) + 12|0);
 HEAP32[$5>>2] = $4;
 $6 = (($runtimeInfo) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($staticInfo) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($staticInfo) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii(389,($7|0),($buffer|0),($9|0),($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $16 = HEAP32[$buffer>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   ___resumeException($14|0);
   // unreachable;
  }
  $18 = HEAP32[$2>>2]|0;
  $19 = ($18|0)==($16|0);
  do {
   if ($19) {
    $33 = $16;
   } else {
    $21 = $18;
    while(1) {
     $20 = (($21) + -292|0);
     HEAP32[$2>>2] = $20;
     $22 = HEAP8[$20>>0]|0;
     $23 = $22 & 1;
     $24 = ($23<<24>>24)==(0);
     if ($24) {
      $26 = $20;
     } else {
      $27 = (($21) + -284|0);
      $28 = HEAP32[$27>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($28|0),($$byval_copy3|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 9;
       break;
      }
      $$pre$i$i$i$i$i$i$i3 = HEAP32[$2>>2]|0;
      $26 = $$pre$i$i$i$i$i$i$i3;
     }
     $25 = ($26|0)==($16|0);
     if ($25) {
      label = 10;
      break;
     } else {
      $21 = $26;
     }
    }
    if ((label|0) == 9) {
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    }
    else if ((label|0) == 10) {
     $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
     $33 = $$pre$i$i$i$i$i5;
     break;
    }
   }
  } while(0);
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($33|0),($$byval_copy3|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $36 = ___cxa_find_matching_catch()|0;
   $37 = tempRet0;
   ___cxa_call_unexpected(($36|0));
   // unreachable;
  } else {
   ___resumeException($14|0);
   // unreachable;
  }
 } else {
  $38 = HEAP32[$buffer>>2]|0;
  $39 = ($38|0)==(0|0);
  if ($39) {
   STACKTOP = sp;return;
  }
  $40 = HEAP32[$2>>2]|0;
  $41 = ($40|0)==($38|0);
  do {
   if ($41) {
    $55 = $38;
   } else {
    $43 = $40;
    while(1) {
     $42 = (($43) + -292|0);
     HEAP32[$2>>2] = $42;
     $44 = HEAP8[$42>>0]|0;
     $45 = $44 & 1;
     $46 = ($45<<24>>24)==(0);
     if ($46) {
      $48 = $42;
     } else {
      $49 = (($43) + -284|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($50|0),($$byval_copy3|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 20;
       break;
      }
      $$pre$i$i$i$i$i$i$i = HEAP32[$2>>2]|0;
      $48 = $$pre$i$i$i$i$i$i$i;
     }
     $47 = ($48|0)==($38|0);
     if ($47) {
      label = 21;
      break;
     } else {
      $43 = $48;
     }
    }
    if ((label|0) == 20) {
     $53 = ___cxa_find_matching_catch()|0;
     $54 = tempRet0;
     ___cxa_call_unexpected(($53|0));
     // unreachable;
    }
    else if ((label|0) == 21) {
     $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
     $55 = $$pre$i$i$i$i$i;
     break;
    }
   }
  } while(0);
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($55|0),($$byval_copy3|0));
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   ___cxa_call_unexpected(($58|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorI8GUIStyle13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy1 = sp + 300|0;
 $0 = sp;
 $size$i$i$i = sp + 4|0;
 $p$i$i = sp + 8|0;
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$1,$data,$metaFlag);
 __ZN8GUIStyleC2Ev($p$i$i);
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(630368|0),(630368|0),($size$i$i$i|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(630376|0),(631120|0),($p$i$i|0),0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(3015,($p$i$i|0),($this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3390,($this|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3391,($this|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP8[$p$i$i>>0]|0;
      $13 = $12 & 1;
      $14 = ($13<<24>>24)==(0);
      if ($14) {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
      $15 = (($p$i$i) + 8|0);
      $16 = HEAP32[$15>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($16|0),($$byval_copy1|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       $19 = ___cxa_find_matching_catch()|0;
       $20 = tempRet0;
       ___cxa_call_unexpected(($19|0));
       // unreachable;
      } else {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $23 = HEAP8[$p$i$i>>0]|0;
 $24 = $23 & 1;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  ___resumeException($21|0);
  // unreachable;
 }
 $26 = (($p$i$i) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  ___cxa_call_unexpected(($30|0));
  // unreachable;
 } else {
  ___resumeException($21|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $0 = sp + 24|0;
 $buffer = sp + 32|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($staticInfo) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($6|0),($8|0),($11|0),($buffer|0),($10|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  ;HEAP32[$p$i$i$i+0>>2]=0|0;HEAP32[$p$i$i$i+4>>2]=0|0;HEAP32[$p$i$i$i+8>>2]=0|0;HEAP32[$p$i$i$i+12>>2]=0|0;
  __THREW__ = 0;
  invoke_viiiii(87,($6|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   __THREW__ = 0;
   invoke_viiiii(86,($6|0),(630376|0),(631152|0),($p$i$i$i|0),0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_vii(3017,($p$i$i$i|0),($6|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3390,($6|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3391,($6|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vi(3390,($6|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        $39 = HEAP32[$buffer>>2]|0;
        $40 = ($39|0)==(0|0);
        if ($40) {
         STACKTOP = sp;return;
        }
        $41 = HEAP32[$1>>2]|0;
        $42 = ($41|0)==($39|0);
        if (!($42)) {
         $__new_last2$i$i$i$i$i$i$i = $39;
         $scevgep$i$i$i$i$i$i$i = (($41) + -16|0);
         $43 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($43)|0);
         $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
         $44 = $uglygep3$i$i$i$i$i$i$i >>> 4;
         $45 = $44 ^ -1;
         $scevgep4$i$i$i$i$i$i$i = (($41) + ($45<<4)|0);
         HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
        }
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($39|0),($$byval_copy1|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         $48 = ___cxa_find_matching_catch()|0;
         $49 = tempRet0;
         ___cxa_call_unexpected(($48|0));
         // unreachable;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 $28 = HEAP32[$buffer>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  ___resumeException($26|0);
  // unreachable;
 }
 $30 = HEAP32[$1>>2]|0;
 $31 = ($30|0)==($28|0);
 if (!($31)) {
  $__new_last2$i$i$i$i$i$i$i1 = $28;
  $scevgep$i$i$i$i$i$i$i2 = (($30) + -16|0);
  $32 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($32)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $33 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $34 = $33 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($30) + ($34<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($28|0),($$byval_copy1|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($26|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy6 = sp + 96|0;
 $0 = sp;
 $size$i$i$i$i = sp + 4|0;
 $p$i$i$i = sp + 8|0;
 $buffer = sp + 80|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($staticInfo) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($6|0),($8|0),($11|0),($buffer|0),($10|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 do {
  if ($13) {
   label = 12;
  } else {
   __THREW__ = 0;
   invoke_vi(3551,($p$i$i$i|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 12;
   } else {
    __THREW__ = 0;
    invoke_viiiii(87,($6|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_viiiii(86,($6|0),(630376|0),(631200|0),($p$i$i$i|0),0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vii(3014,($p$i$i$i|0),($6|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       invoke_vi(3390,($6|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3391,($6|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          label = 12;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3390,($6|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          label = 12;
          break;
         }
         $52 = HEAP32[$buffer>>2]|0;
         $53 = ($52|0)==(0|0);
         if ($53) {
          STACKTOP = sp;return;
         }
         while(1) {
          $54 = HEAP32[$1>>2]|0;
          $55 = ($54|0)==($52|0);
          if ($55) {
           break;
          }
          $56 = (($54) + -68|0);
          HEAP32[$1>>2] = $56;
          __THREW__ = 0;
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if ($58) {
           label = 22;
           break;
          }
         }
         if ((label|0) == 22) {
          $59 = ___cxa_find_matching_catch()|0;
          $60 = tempRet0;
          ___cxa_call_unexpected(($59|0));
          // unreachable;
         }
         $61 = HEAP32[$buffer>>2]|0;
         HEAP32[$0>>2] = 90;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($61|0),($$byval_copy6|0));
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          $64 = ___cxa_find_matching_catch()|0;
          $65 = tempRet0;
          ___cxa_call_unexpected(($64|0));
          // unreachable;
         } else {
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
    $26 = ___cxa_find_matching_catch()|0;
    $27 = tempRet0;
    __THREW__ = 0;
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     $30 = ___cxa_find_matching_catch(0|0)|0;
     $31 = tempRet0;
     ___clang_call_terminate($30);
     // unreachable;
    } else {
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  $eh$lpad$body$index2Z2D = $37;$eh$lpad$body$indexZ2D = $36;
 }
 $38 = HEAP32[$buffer>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 while(1) {
  $40 = HEAP32[$1>>2]|0;
  $41 = ($40|0)==($38|0);
  if ($41) {
   break;
  }
  $42 = (($40) + -68|0);
  HEAP32[$1>>2] = $42;
  __THREW__ = 0;
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  ___cxa_call_unexpected(($45|0));
  // unreachable;
 }
 $47 = HEAP32[$buffer>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy6|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  ___cxa_call_unexpected(($50|0));
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy3 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($staticInfo) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 invoke_viiii(390,($6|0),($buffer|0),($8|0),($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP32[$buffer>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   ___resumeException($13|0);
   // unreachable;
  }
  $17 = HEAP32[$1>>2]|0;
  $18 = ($17|0)==($15|0);
  do {
   if ($18) {
    $34 = $15;
   } else {
    $20 = $17;
    while(1) {
     $19 = (($20) + -80|0);
     HEAP32[$1>>2] = $19;
     $21 = (($20) + -12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)>(-1);
     if ($23) {
      $26 = (($20) + -24|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = (($20) + -20|0);
      $29 = HEAP32[$28>>2]|0;
      HEAP32[$0>>2] = $29;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($27|0),($$byval_copy3|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 9;
       break;
      }
      HEAP32[$26>>2] = 0;
      $$pre$i$i$i$i$i$i$i3 = HEAP32[$1>>2]|0;
      $25 = $$pre$i$i$i$i$i$i$i3;
     } else {
      $25 = $19;
     }
     $24 = ($25|0)==($15|0);
     if ($24) {
      label = 10;
      break;
     } else {
      $20 = $25;
     }
    }
    if ((label|0) == 9) {
     $32 = ___cxa_find_matching_catch()|0;
     $33 = tempRet0;
     ___cxa_call_unexpected(($32|0));
     // unreachable;
    }
    else if ((label|0) == 10) {
     $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
     $34 = $$pre$i$i$i$i$i5;
     break;
    }
   }
  } while(0);
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($34|0),($$byval_copy3|0));
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if ($36) {
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   ___cxa_call_unexpected(($37|0));
   // unreachable;
  } else {
   ___resumeException($13|0);
   // unreachable;
  }
 } else {
  $39 = HEAP32[$buffer>>2]|0;
  $40 = ($39|0)==(0|0);
  if ($40) {
   STACKTOP = sp;return;
  }
  $41 = HEAP32[$1>>2]|0;
  $42 = ($41|0)==($39|0);
  do {
   if ($42) {
    $58 = $39;
   } else {
    $44 = $41;
    while(1) {
     $43 = (($44) + -80|0);
     HEAP32[$1>>2] = $43;
     $45 = (($44) + -12|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)>(-1);
     if ($47) {
      $50 = (($44) + -24|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = (($44) + -20|0);
      $53 = HEAP32[$52>>2]|0;
      HEAP32[$0>>2] = $53;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($51|0),($$byval_copy3|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 20;
       break;
      }
      HEAP32[$50>>2] = 0;
      $$pre$i$i$i$i$i$i$i = HEAP32[$1>>2]|0;
      $49 = $$pre$i$i$i$i$i$i$i;
     } else {
      $49 = $43;
     }
     $48 = ($49|0)==($39|0);
     if ($48) {
      label = 21;
      break;
     } else {
      $44 = $49;
     }
    }
    if ((label|0) == 20) {
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     ___cxa_call_unexpected(($56|0));
     // unreachable;
    }
    else if ((label|0) == 21) {
     $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
     $58 = $$pre$i$i$i$i$i;
     break;
    }
   }
  } while(0);
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($58|0),($$byval_copy3|0));
  $59 = __THREW__; __THREW__ = 0;
  $60 = $59&1;
  if ($60) {
   $61 = ___cxa_find_matching_catch()|0;
   $62 = tempRet0;
   ___cxa_call_unexpected(($61|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0;
 var $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 88|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $p$i$i = sp + 8|0;
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$1,$data,$metaFlag);
 $2 = (($p$i$i) + 4|0);
 HEAPF32[$2>>2] = Math_fround(inf);
 HEAP32[$p$i$i>>2] = 0;
 $3 = (($p$i$i) + 8|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;
 $4 = (($p$i$i) + 32|0);
 HEAPF32[$4>>2] = Math_fround(inf);
 $5 = (($p$i$i) + 28|0);
 HEAP32[$5>>2] = 0;
 $6 = (($p$i$i) + 36|0);
 $7 = (($p$i$i) + 64|0);
 HEAP32[$7>>2] = 0;
 $8 = (($p$i$i) + 68|0);
 HEAP32[$8>>2] = 0;
 $9 = (($p$i$i) + 60|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
 HEAP32[$9>>2] = 61;
 $10 = (($p$i$i) + 76|0);
 HEAP32[$10>>2] = 2;
 $11 = (($p$i$i) + 72|0);
 HEAP32[$11>>2] = 2;
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(630368|0),(630368|0),($size$i$i$i|0),0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(630376|0),(631216|0),($p$i$i|0),0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   __THREW__ = 0;
   invoke_vii(3013,($p$i$i|0),($this|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3390,($this|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3391,($this|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP32[$8>>2]|0;
      $23 = ($22|0)>(-1);
      if (!($23)) {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
      $24 = (($p$i$i) + 56|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = HEAP32[$9>>2]|0;
      HEAP32[$size$i$i$i>>2] = $26;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
      HEAP32[$24>>2] = 0;
      __ZN13ProxyTransfer11EndTransferEv($this);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $29 = HEAP32[$8>>2]|0;
 $30 = ($29|0)>(-1);
 if (!($30)) {
  ___resumeException($27|0);
  // unreachable;
 }
 $31 = (($p$i$i) + 56|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = $33;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch(0|0)|0;
  $37 = tempRet0;
  ___clang_call_terminate($36);
  // unreachable;
 }
 HEAP32[$31>>2] = 0;
 ___resumeException($27|0);
 // unreachable;
}
function __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $buffer$i = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = sp + 8|0;
 $buffer$i = sp + 16|0;
 HEAP32[$buffer$i>>2] = 0;
 $1 = (($buffer$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),(631248|0),($p$i$i$i|0),0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __THREW__ = 0;
    invoke_vii(3018,($4|0),2);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[580752>>2]|0;
     __THREW__ = 0;
     invoke_viiiii(86,($4|0),(631040|0),($18|0),($p$i$i$i|0),4194305);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($4) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = HEAP32[$22>>2]|0;
      $24 = (($4) + 20|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ((($23) + (($25*24)|0)|0) + 12|0);
      HEAP32[$26>>2] = 4;
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3390,($4|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        invoke_vi(3391,($4|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         __THREW__ = 0;
         invoke_vi(3390,($4|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          $48 = HEAP32[$buffer$i>>2]|0;
          $49 = ($48|0)==(0|0);
          if ($49) {
           STACKTOP = sp;return;
          }
          $50 = HEAP32[$1>>2]|0;
          $51 = ($50|0)==($48|0);
          if (!($51)) {
           $__new_last2$i$i$i$i$i$i$i$i = $48;
           $scevgep$i$i$i$i$i$i$i$i = (($50) + -4|0);
           $52 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
           $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($52)|0);
           $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
           $53 = $uglygep3$i$i$i$i$i$i$i$i >>> 2;
           $54 = $53 ^ -1;
           $scevgep4$i$i$i$i$i$i$i$i = (($50) + ($54<<2)|0);
           HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i;
          }
          HEAP32[$size$i$i$i$i>>2] = 90;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
          invoke_vii(2591,($48|0),($$byval_copy1|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           $57 = ___cxa_find_matching_catch()|0;
           $58 = tempRet0;
           ___cxa_call_unexpected(($57|0));
           // unreachable;
          } else {
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 $37 = HEAP32[$buffer$i>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  ___resumeException($35|0);
  // unreachable;
 }
 $39 = HEAP32[$1>>2]|0;
 $40 = ($39|0)==($37|0);
 if (!($40)) {
  $__new_last2$i$i$i$i$i$i$i1$i = $37;
  $scevgep$i$i$i$i$i$i$i2$i = (($39) + -4|0);
  $41 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($41)|0);
  $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
  $42 = $uglygep3$i$i$i$i$i$i$i5$i >>> 2;
  $43 = $42 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6$i = (($39) + ($43<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($37|0),($$byval_copy1|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  ___resumeException($35|0);
  // unreachable;
 }
}
function __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__new_last1$i$i$i$i$i$i$i$i = 0, $__new_last1$i$i$i$i$i$i$i1$i = 0, $buffer$i = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep2$i$i$i$i$i$i$i$i = 0, $scevgep2$i$i$i$i$i$i$i3$i = 0, $scevgep23$i$i$i$i$i$i$i$i = 0, $scevgep23$i$i$i$i$i$i$i4$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i5$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = sp + 8|0;
 $buffer$i = sp + 16|0;
 HEAP32[$buffer$i>>2] = 0;
 $1 = (($buffer$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580560>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_vii(3018,($4|0),2);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[580752>>2]|0;
     __THREW__ = 0;
     invoke_viiiii(86,($4|0),(631048|0),($19|0),($p$i$i$i|0),1);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = (($4) + 12|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = HEAP32[$23>>2]|0;
      $25 = (($4) + 20|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ((($24) + (($26*24)|0)|0) + 12|0);
      HEAP32[$27>>2] = 4;
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vi(3390,($4|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        __THREW__ = 0;
        invoke_vi(3391,($4|0));
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         __THREW__ = 0;
         invoke_vi(3390,($4|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if (!($35)) {
          $49 = HEAP32[$buffer$i>>2]|0;
          $50 = ($49|0)==(0|0);
          if ($50) {
           STACKTOP = sp;return;
          }
          $51 = HEAP32[$1>>2]|0;
          $52 = ($51|0)==($49|0);
          if (!($52)) {
           $__new_last1$i$i$i$i$i$i$i$i = $49;
           $scevgep$i$i$i$i$i$i$i$i = (($51) + -4|0);
           $53 = (0 - ($__new_last1$i$i$i$i$i$i$i$i))|0;
           $scevgep2$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($53)|0);
           $scevgep23$i$i$i$i$i$i$i$i = $scevgep2$i$i$i$i$i$i$i$i;
           $54 = $scevgep23$i$i$i$i$i$i$i$i >>> 2;
           $55 = $54 ^ -1;
           $scevgep4$i$i$i$i$i$i$i$i = (($51) + ($55<<2)|0);
           HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i;
          }
          HEAP32[$size$i$i$i$i>>2] = 90;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
          invoke_vii(2591,($49|0),($$byval_copy1|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           $58 = ___cxa_find_matching_catch()|0;
           $59 = tempRet0;
           ___cxa_call_unexpected(($58|0));
           // unreachable;
          } else {
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = HEAP32[$buffer$i>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  ___resumeException($36|0);
  // unreachable;
 }
 $40 = HEAP32[$1>>2]|0;
 $41 = ($40|0)==($38|0);
 if (!($41)) {
  $__new_last1$i$i$i$i$i$i$i1$i = $38;
  $scevgep$i$i$i$i$i$i$i2$i = (($40) + -4|0);
  $42 = (0 - ($__new_last1$i$i$i$i$i$i$i1$i))|0;
  $scevgep2$i$i$i$i$i$i$i3$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($42)|0);
  $scevgep23$i$i$i$i$i$i$i4$i = $scevgep2$i$i$i$i$i$i$i3$i;
  $43 = $scevgep23$i$i$i$i$i$i$i4$i >>> 2;
  $44 = $43 ^ -1;
  $scevgep4$i$i$i$i$i$i$i5$i = (($40) + ($44<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i5$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($38|0),($$byval_copy1|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $47 = ___cxa_find_matching_catch()|0;
  $48 = tempRet0;
  ___cxa_call_unexpected(($47|0));
  // unreachable;
 } else {
  ___resumeException($36|0);
  // unreachable;
 }
}
function __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $buffer$i = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $0 = sp + 24|0;
 $buffer$i = sp + 32|0;
 HEAP32[$buffer$i>>2] = 0;
 $1 = (($buffer$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580560>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_vii(3019,($p$i$i$i|0),($4|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     invoke_vi(3390,($4|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3391,($4|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3390,($4|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $38 = HEAP32[$buffer$i>>2]|0;
        $39 = ($38|0)==(0|0);
        if ($39) {
         STACKTOP = sp;return;
        }
        $40 = HEAP32[$1>>2]|0;
        $41 = ($40|0)==($38|0);
        if (!($41)) {
         $__new_last2$i$i$i$i$i$i$i$i = $38;
         $scevgep$i$i$i$i$i$i$i$i = (($40) + -16|0);
         $42 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($42)|0);
         $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
         $43 = $uglygep3$i$i$i$i$i$i$i$i >>> 4;
         $44 = $43 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i = (($40) + ($44<<4)|0);
         HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i;
        }
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($38|0),($$byval_copy1|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         $47 = ___cxa_find_matching_catch()|0;
         $48 = tempRet0;
         ___cxa_call_unexpected(($47|0));
         // unreachable;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$buffer$i>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i1$i = $27;
  $scevgep$i$i$i$i$i$i$i2$i = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
  $32 = $uglygep3$i$i$i$i$i$i$i5$i >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6$i = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
}
function __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $buffer$i = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0;
 var $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 56|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $0 = sp + 32|0;
 $buffer$i = sp + 40|0;
 HEAP32[$buffer$i>>2] = 0;
 $1 = (($buffer$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  ;HEAP32[$p$i$i$i+0>>2]=0|0;HEAP32[$p$i$i$i+4>>2]=0|0;HEAP32[$p$i$i$i+8>>2]=0|0;HEAP32[$p$i$i$i+12>>2]=0|0;HEAP32[$p$i$i$i+16>>2]=0|0;HEAP32[$p$i$i$i+20>>2]=0|0;
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),(631264|0),($p$i$i$i|0),0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __THREW__ = 0;
    invoke_viiii(391,($4|0),($p$i$i$i|0),(631056|0),0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = (($p$i$i$i) + 12|0);
     __THREW__ = 0;
     invoke_viiii(391,($4|0),($18|0),(631072|0),0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3391,($4|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        invoke_vi(3390,($4|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $40 = HEAP32[$buffer$i>>2]|0;
         $41 = ($40|0)==(0|0);
         if ($41) {
          STACKTOP = sp;return;
         }
         $42 = HEAP32[$1>>2]|0;
         $43 = ($42|0)==($40|0);
         if (!($43)) {
          $__new_last2$i$i$i$i$i$i$i$i = $40;
          $scevgep$i$i$i$i$i$i$i$i = (($42) + -24|0);
          $44 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
          $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($44)|0);
          $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
          $45 = (($uglygep3$i$i$i$i$i$i$i$i>>>0) / 24)&-1;
          $46 = $45 ^ -1;
          $scevgep4$i$i$i$i$i$i$i$i = (($42) + (($46*24)|0)|0);
          HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i;
         }
         HEAP32[$size$i$i$i$i>>2] = 90;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
         invoke_vii(2591,($40|0),($$byval_copy1|0));
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          $49 = ___cxa_find_matching_catch()|0;
          $50 = tempRet0;
          ___cxa_call_unexpected(($49|0));
          // unreachable;
         } else {
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $29 = HEAP32[$buffer$i>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  ___resumeException($27|0);
  // unreachable;
 }
 $31 = HEAP32[$1>>2]|0;
 $32 = ($31|0)==($29|0);
 if (!($32)) {
  $__new_last2$i$i$i$i$i$i$i1$i = $29;
  $scevgep$i$i$i$i$i$i$i2$i = (($31) + -24|0);
  $33 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($33)|0);
  $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
  $34 = (($uglygep3$i$i$i$i$i$i$i5$i>>>0) / 24)&-1;
  $35 = $34 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6$i = (($31) + (($35*24)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  ___resumeException($27|0);
  // unreachable;
 }
}
function __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $buffer$i = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4$i = 0;
 var $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp + 96|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $0 = sp + 72|0;
 $buffer$i = sp + 80|0;
 HEAP32[$buffer$i>>2] = 0;
 $1 = (($buffer$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),(631272|0),($p$i$i$i|0),0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __THREW__ = 0;
    invoke_vii(3020,($p$i$i$i|0),($4|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vi(3390,($4|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3391,($4|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       invoke_vi(3390,($4|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $37 = HEAP32[$buffer$i>>2]|0;
        $38 = ($37|0)==(0|0);
        if ($38) {
         STACKTOP = sp;return;
        }
        $39 = HEAP32[$1>>2]|0;
        $40 = ($39|0)==($37|0);
        if (!($40)) {
         $__new_last2$i$i$i$i$i$i$i$i = $37;
         $scevgep$i$i$i$i$i$i$i$i = (($39) + -64|0);
         $41 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($41)|0);
         $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
         $42 = $uglygep3$i$i$i$i$i$i$i$i >>> 6;
         $43 = $42 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i = (($39) + ($43<<6)|0);
         HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i;
        }
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($37|0),($$byval_copy1|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         $46 = ___cxa_find_matching_catch()|0;
         $47 = tempRet0;
         ___cxa_call_unexpected(($46|0));
         // unreachable;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $26 = HEAP32[$buffer$i>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$1>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $__new_last2$i$i$i$i$i$i$i1$i = $26;
  $scevgep$i$i$i$i$i$i$i2$i = (($28) + -64|0);
  $30 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($30)|0);
  $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
  $31 = $uglygep3$i$i$i$i$i$i$i5$i >>> 6;
  $32 = $31 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6$i = (($28) + ($32<<6)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($26|0),($$byval_copy1|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 } else {
  ___resumeException($24|0);
  // unreachable;
 }
}
function __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $buffer$i = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $0 = sp + 24|0;
 $buffer$i = sp + 32|0;
 HEAP32[$buffer$i>>2] = 0;
 $1 = (($buffer$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580640>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_vii(3021,($p$i$i$i|0),($4|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     invoke_vi(3390,($4|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3391,($4|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3390,($4|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $38 = HEAP32[$buffer$i>>2]|0;
        $39 = ($38|0)==(0|0);
        if ($39) {
         STACKTOP = sp;return;
        }
        $40 = HEAP32[$1>>2]|0;
        $41 = ($40|0)==($38|0);
        if (!($41)) {
         $__new_last2$i$i$i$i$i$i$i$i = $38;
         $scevgep$i$i$i$i$i$i$i$i = (($40) + -16|0);
         $42 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($42)|0);
         $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
         $43 = $uglygep3$i$i$i$i$i$i$i$i >>> 4;
         $44 = $43 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i = (($40) + ($44<<4)|0);
         HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i;
        }
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($38|0),($$byval_copy1|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         $47 = ___cxa_find_matching_catch()|0;
         $48 = tempRet0;
         ___cxa_call_unexpected(($47|0));
         // unreachable;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$buffer$i>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i1$i = $27;
  $scevgep$i$i$i$i$i$i$i2$i = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
  $32 = $uglygep3$i$i$i$i$i$i$i5$i >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6$i = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
}
function __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $buffer$i = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $0 = sp + 24|0;
 $buffer$i = sp + 32|0;
 HEAP32[$buffer$i>>2] = 0;
 $1 = (($buffer$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  ;HEAP32[$p$i$i$i+0>>2]=0|0;HEAP32[$p$i$i$i+4>>2]=0|0;HEAP32[$p$i$i$i+8>>2]=0|0;HEAP32[$p$i$i$i+12>>2]=0|0;
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580648>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_vii(3022,($p$i$i$i|0),($4|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     invoke_vi(3390,($4|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3391,($4|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3390,($4|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $38 = HEAP32[$buffer$i>>2]|0;
        $39 = ($38|0)==(0|0);
        if ($39) {
         STACKTOP = sp;return;
        }
        $40 = HEAP32[$1>>2]|0;
        $41 = ($40|0)==($38|0);
        if (!($41)) {
         $__new_last2$i$i$i$i$i$i$i$i = $38;
         $scevgep$i$i$i$i$i$i$i$i = (($40) + -16|0);
         $42 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($42)|0);
         $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
         $43 = $uglygep3$i$i$i$i$i$i$i$i >>> 4;
         $44 = $43 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i = (($40) + ($44<<4)|0);
         HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i;
        }
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($38|0),($$byval_copy1|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         $47 = ___cxa_find_matching_catch()|0;
         $48 = tempRet0;
         ___cxa_call_unexpected(($47|0));
         // unreachable;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$buffer$i>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i1$i = $27;
  $scevgep$i$i$i$i$i$i$i2$i = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
  $32 = $uglygep3$i$i$i$i$i$i$i5$i >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6$i = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
}
function __Z13TransferFieldI13ProxyTransferLb1E19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1$i = 0, $buffer$i = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6$i = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i4$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $0 = sp + 24|0;
 $buffer$i = sp + 32|0;
 HEAP32[$buffer$i>>2] = 0;
 $1 = (($buffer$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer$i|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580784>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_vii(3023,($p$i$i$i|0),($4|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     invoke_vi(3390,($4|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3391,($4|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3390,($4|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $38 = HEAP32[$buffer$i>>2]|0;
        $39 = ($38|0)==(0|0);
        if ($39) {
         STACKTOP = sp;return;
        }
        $40 = HEAP32[$1>>2]|0;
        $41 = ($40|0)==($38|0);
        if (!($41)) {
         $__new_last2$i$i$i$i$i$i$i$i = $38;
         $scevgep$i$i$i$i$i$i$i$i = (($40) + -16|0);
         $42 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($42)|0);
         $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
         $43 = $uglygep3$i$i$i$i$i$i$i$i >>> 4;
         $44 = $43 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i = (($40) + ($44<<4)|0);
         HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i$i;
        }
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($38|0),($$byval_copy1|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         $47 = ___cxa_find_matching_catch()|0;
         $48 = tempRet0;
         ___cxa_call_unexpected(($47|0));
         // unreachable;
        } else {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$buffer$i>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i1$i = $27;
  $scevgep$i$i$i$i$i$i$i2$i = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i$i$i2$i) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i5$i = $uglygep$i$i$i$i$i$i$i4$i;
  $32 = $uglygep3$i$i$i$i$i$i$i5$i >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6$i = (($29) + ($33<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6$i;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 40|0;
 $size$i = sp;
 $p$i$i$i = sp + 8|0;
 $0 = sp + 16|0;
 $buffer = sp + 24|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  HEAPF32[$p$i$i$i>>2] = Math_fround(0.0);
  $12 = (($p$i$i$i) + 4|0);
  HEAPF32[$12>>2] = Math_fround(0.0);
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i|0),0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = HEAP32[580768>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($15|0),($p$i$i$i|0),0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = (($4) + 16|0);
    __THREW__ = 0;
    $19 = (invoke_ii(3289,($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($19) + 20|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = $23 | 2097152;
     $25 = (($4) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     $28 = (($4) + 20|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ((($27) + (($29*24)|0)|0) + 20|0);
     HEAP32[$30>>2] = $24;
     $31 = HEAP32[580584>>2]|0;
     __THREW__ = 0;
     invoke_viiiii(86,($4|0),(630840|0),($31|0),($p$i$i$i|0),0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      $34 = HEAP32[$25>>2]|0;
      $35 = HEAP32[$34>>2]|0;
      $36 = HEAP32[$28>>2]|0;
      $37 = ((($35) + (($36*24)|0)|0) + 12|0);
      HEAP32[$37>>2] = 4;
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       __THREW__ = 0;
       invoke_viiiii(86,($4|0),(630848|0),($31|0),($12|0),0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        $42 = HEAP32[$25>>2]|0;
        $43 = HEAP32[$42>>2]|0;
        $44 = HEAP32[$28>>2]|0;
        $45 = ((($43) + (($44*24)|0)|0) + 12|0);
        HEAP32[$45>>2] = 4;
        __THREW__ = 0;
        invoke_vi(3390,($4|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if (!($47)) {
         __THREW__ = 0;
         invoke_vi(3390,($4|0));
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if (!($49)) {
          __THREW__ = 0;
          invoke_vi(3391,($4|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if (!($51)) {
           __THREW__ = 0;
           invoke_vi(3390,($4|0));
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if (!($53)) {
            $67 = HEAP32[$buffer>>2]|0;
            $68 = ($67|0)==(0|0);
            if ($68) {
             STACKTOP = sp;return;
            }
            $69 = HEAP32[$1>>2]|0;
            $70 = ($69|0)==($67|0);
            if (!($70)) {
             $__new_last2$i$i$i$i$i$i$i = $67;
             $scevgep$i$i$i$i$i$i$i = (($69) + -8|0);
             $71 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
             $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($71)|0);
             $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
             $72 = $uglygep3$i$i$i$i$i$i$i >>> 3;
             $73 = $72 ^ -1;
             $scevgep4$i$i$i$i$i$i$i = (($69) + ($73<<3)|0);
             HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
            }
            HEAP32[$size$i>>2] = 90;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i+0>>2]|0;
            invoke_vii(2591,($67|0),($$byval_copy1|0));
            $74 = __THREW__; __THREW__ = 0;
            $75 = $74&1;
            if ($75) {
             $76 = ___cxa_find_matching_catch()|0;
             $77 = tempRet0;
             ___cxa_call_unexpected(($76|0));
             // unreachable;
            } else {
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $54 = ___cxa_find_matching_catch()|0;
 $55 = tempRet0;
 $56 = HEAP32[$buffer>>2]|0;
 $57 = ($56|0)==(0|0);
 if ($57) {
  ___resumeException($54|0);
  // unreachable;
 }
 $58 = HEAP32[$1>>2]|0;
 $59 = ($58|0)==($56|0);
 if (!($59)) {
  $__new_last2$i$i$i$i$i$i$i1 = $56;
  $scevgep$i$i$i$i$i$i$i2 = (($58) + -8|0);
  $60 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($60)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $61 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $62 = $61 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($58) + ($62<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($56|0),($$byval_copy1|0));
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $65 = ___cxa_find_matching_catch()|0;
  $66 = tempRet0;
  ___cxa_call_unexpected(($65|0));
  // unreachable;
 } else {
  ___resumeException($54|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 40|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = sp + 16|0;
 $buffer = sp + 24|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  HEAPF32[$p$i$i$i>>2] = Math_fround(0.0);
  $12 = (($p$i$i$i) + 4|0);
  HEAPF32[$12>>2] = Math_fround(0.0);
  $13 = (($p$i$i$i) + 8|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   __THREW__ = 0;
   invoke_viiii(391,($4|0),($p$i$i$i|0),(630376|0),0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3391,($4|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3390,($4|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $35 = HEAP32[$buffer>>2]|0;
      $36 = ($35|0)==(0|0);
      if ($36) {
       STACKTOP = sp;return;
      }
      $37 = HEAP32[$1>>2]|0;
      $38 = ($37|0)==($35|0);
      if (!($38)) {
       $__new_last2$i$i$i$i$i$i$i = $35;
       $scevgep$i$i$i$i$i$i$i = (($37) + -12|0);
       $39 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($39)|0);
       $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
       $40 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
       $41 = $40 ^ -1;
       $scevgep4$i$i$i$i$i$i$i = (($37) + (($41*12)|0)|0);
       HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
      }
      HEAP32[$size$i$i$i$i>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
      invoke_vii(2591,($35|0),($$byval_copy1|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       $44 = ___cxa_find_matching_catch()|0;
       $45 = tempRet0;
       ___cxa_call_unexpected(($44|0));
       // unreachable;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $24 = HEAP32[$buffer>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  ___resumeException($22|0);
  // unreachable;
 }
 $26 = HEAP32[$1>>2]|0;
 $27 = ($26|0)==($24|0);
 if (!($27)) {
  $__new_last2$i$i$i$i$i$i$i1 = $24;
  $scevgep$i$i$i$i$i$i$i2 = (($26) + -12|0);
  $28 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($28)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $29 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 12)&-1;
  $30 = $29 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($26) + (($30*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($24|0),($$byval_copy1|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  ___cxa_call_unexpected(($33|0));
  // unreachable;
 } else {
  ___resumeException($22|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0;
 var $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i = sp + 8|0;
 $p$i$i$i = sp;
 $0 = sp + 12|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580568>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 8;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $42 = HEAP32[$buffer>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        STACKTOP = sp;return;
       }
       $44 = HEAP32[$1>>2]|0;
       $45 = ($44|0)==($42|0);
       if (!($45)) {
        $__new_last2$i$i$i$i$i$i$i = $42;
        $scevgep$i$i$i$i$i$i$i = (($44) + -8|0);
        $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
        $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
        $47 = $uglygep3$i$i$i$i$i$i$i >>> 3;
        $48 = $47 ^ -1;
        $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<3)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i1 = $31;
  $scevgep$i$i$i$i$i$i$i2 = (($33) + -8|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0;
 var $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = sp + 8|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580584>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 4;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $42 = HEAP32[$buffer>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        STACKTOP = sp;return;
       }
       $44 = HEAP32[$1>>2]|0;
       $45 = ($44|0)==($42|0);
       if (!($45)) {
        $__new_last2$i$i$i$i$i$i$i = $42;
        $scevgep$i$i$i$i$i$i$i = (($44) + -4|0);
        $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
        $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
        $47 = $uglygep3$i$i$i$i$i$i$i >>> 2;
        $48 = $47 ^ -1;
        $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<2)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i1 = $31;
  $scevgep$i$i$i$i$i$i$i2 = (($33) + -4|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0;
 var $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i = sp + 8|0;
 $p$i$i$i = sp;
 $0 = sp + 12|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580736>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 8;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $42 = HEAP32[$buffer>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        STACKTOP = sp;return;
       }
       $44 = HEAP32[$1>>2]|0;
       $45 = ($44|0)==($42|0);
       if (!($45)) {
        $__new_last2$i$i$i$i$i$i$i = $42;
        $scevgep$i$i$i$i$i$i$i = (($44) + -8|0);
        $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
        $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
        $47 = $uglygep3$i$i$i$i$i$i$i >>> 3;
        $48 = $47 ^ -1;
        $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<3)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i1 = $31;
  $scevgep$i$i$i$i$i$i$i2 = (($33) + -8|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0;
 var $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i = sp + 8|0;
 $p$i$i$i = sp;
 $0 = sp + 12|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580688>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 8;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $42 = HEAP32[$buffer>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        STACKTOP = sp;return;
       }
       $44 = HEAP32[$1>>2]|0;
       $45 = ($44|0)==($42|0);
       if (!($45)) {
        $__new_last2$i$i$i$i$i$i$i = $42;
        $scevgep$i$i$i$i$i$i$i = (($44) + -8|0);
        $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
        $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
        $47 = $uglygep3$i$i$i$i$i$i$i >>> 3;
        $48 = $47 ^ -1;
        $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<3)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i1 = $31;
  $scevgep$i$i$i$i$i$i$i2 = (($33) + -8|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0;
 var $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = sp + 8|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580752>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 4;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $42 = HEAP32[$buffer>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        STACKTOP = sp;return;
       }
       $44 = HEAP32[$1>>2]|0;
       $45 = ($44|0)==($42|0);
       if (!($45)) {
        $__new_last2$i$i$i$i$i$i$i = $42;
        $scevgep$i$i$i$i$i$i$i = (($44) + -4|0);
        $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
        $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
        $47 = $uglygep3$i$i$i$i$i$i$i >>> 2;
        $48 = $47 ^ -1;
        $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<2)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i1 = $31;
  $scevgep$i$i$i$i$i$i$i2 = (($33) + -4|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0;
 var $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 $0 = sp + 8|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580592>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 4;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $42 = HEAP32[$buffer>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        STACKTOP = sp;return;
       }
       $44 = HEAP32[$1>>2]|0;
       $45 = ($44|0)==($42|0);
       if (!($45)) {
        $__new_last2$i$i$i$i$i$i$i = $42;
        $scevgep$i$i$i$i$i$i$i = (($44) + -4|0);
        $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
        $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
        $47 = $uglygep3$i$i$i$i$i$i$i >>> 2;
        $48 = $47 ^ -1;
        $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<2)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i1 = $31;
  $scevgep$i$i$i$i$i$i$i2 = (($33) + -4|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0;
 var $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 28|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 32|0;
 $0 = sp + 24|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580720>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 2;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $42 = HEAP32[$buffer>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        STACKTOP = sp;return;
       }
       $44 = HEAP32[$1>>2]|0;
       $45 = ($44|0)==($42|0);
       if (!($45)) {
        $__new_last2$i$i$i$i$i$i$i = $42;
        $scevgep$i$i$i$i$i$i$i = (($44) + -2|0);
        $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
        $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
        $47 = $uglygep3$i$i$i$i$i$i$i >>> 1;
        $48 = $47 ^ -1;
        $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<1)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i1 = $31;
  $scevgep$i$i$i$i$i$i$i2 = (($33) + -2|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 1;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $p$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0;
 var $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 28|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 32|0;
 $0 = sp + 24|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($staticInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($staticInfo) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($4|0),($6|0),($9|0),($buffer|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiii(87,($4|0),(630368|0),(630368|0),($size$i$i$i$i|0),0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[580672>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($4|0),(630376|0),($14|0),($p$i$i$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($4) + 20|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19) + (($21*24)|0)|0) + 12|0);
    HEAP32[$22>>2] = 2;
    __THREW__ = 0;
    invoke_vi(3390,($4|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3391,($4|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3390,($4|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $42 = HEAP32[$buffer>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        STACKTOP = sp;return;
       }
       $44 = HEAP32[$1>>2]|0;
       $45 = ($44|0)==($42|0);
       if (!($45)) {
        $__new_last2$i$i$i$i$i$i$i = $42;
        $scevgep$i$i$i$i$i$i$i = (($44) + -2|0);
        $46 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($46)|0);
        $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
        $47 = $uglygep3$i$i$i$i$i$i$i >>> 1;
        $48 = $47 ^ -1;
        $scevgep4$i$i$i$i$i$i$i = (($44) + ($48<<1)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
       }
       HEAP32[$size$i$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($29|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i1 = $31;
  $scevgep$i$i$i$i$i$i$i2 = (($33) + -2|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $36 = $uglygep3$i$i$i$i$i$i$i5 >>> 1;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($33) + ($37<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($29|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI13ProxyTransfer16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy12 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i4 = 0, $$pre$i$i$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $p$i$i$i = 0, $p$i$i$i$i = 0, $size$i = 0;
 var $size$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy12 = sp + 60|0;
 $size$i$i$i$i$i = sp + 56|0;
 $p$i$i$i$i = sp + 52|0;
 $size$i = sp + 48|0;
 $0 = sp + 44|0;
 $1 = sp + 40|0;
 $2 = sp + 16|0;
 $3 = sp + 12|0;
 $p$i$i$i = sp;
 $buffer = sp + 24|0;
 HEAP32[$buffer>>2] = 0;
 $4 = (($buffer) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($buffer) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($staticInfo) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($staticInfo) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($7|0),($9|0),($12|0),($buffer|0),($11|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 do {
  if ($14) {
   label = 18;
  } else {
   ;HEAP32[$p$i$i$i+0>>2]=0|0;HEAP32[$p$i$i$i+4>>2]=0|0;HEAP32[$p$i$i$i+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viiiii(87,($7|0),(630368|0),(630368|0),($size$i|0),0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP32[580712>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($7|0),(630376|0),($17|0),($p$i$i$i|0),0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_viiiii(87,($7|0),(630368|0),(630368|0),($size$i$i$i$i$i|0),1);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP32[580552>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(86,($7|0),(630376|0),($22|0),($p$i$i$i$i|0),0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = (($7) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = HEAP32[$26>>2]|0;
       $28 = (($7) + 20|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ((($27) + (($29*24)|0)|0) + 12|0);
       HEAP32[$30>>2] = 1;
       __THREW__ = 0;
       invoke_vi(3390,($7|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        __THREW__ = 0;
        invoke_vi(3391,($7|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         __THREW__ = 0;
         invoke_vi(3392,($7|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          __THREW__ = 0;
          invoke_vi(3390,($7|0));
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if (!($38)) {
           __THREW__ = 0;
           invoke_vi(3391,($7|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            $41 = HEAP8[$p$i$i$i>>0]|0;
            $42 = $41 & 1;
            $43 = ($42<<24>>24)==(0);
            if (!($43)) {
             $44 = (($p$i$i$i) + 8|0);
             $45 = HEAP32[$44>>2]|0;
             HEAP32[$2>>2] = 90;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
             invoke_vii(2591,($45|0),($$byval_copy12|0));
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if ($47) {
              $48 = ___cxa_find_matching_catch()|0;
              $49 = tempRet0;
              ___cxa_call_unexpected(($48|0));
              // unreachable;
             }
            }
            __THREW__ = 0;
            invoke_vi(3390,($7|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             label = 18;
             break;
            }
            $87 = HEAP32[$buffer>>2]|0;
            $88 = ($87|0)==(0|0);
            if ($88) {
             STACKTOP = sp;return;
            }
            $89 = HEAP32[$4>>2]|0;
            $90 = ($89|0)==($87|0);
            do {
             if ($90) {
              $104 = $87;
             } else {
              $92 = $89;
              while(1) {
               $91 = (($92) + -12|0);
               HEAP32[$4>>2] = $91;
               $93 = HEAP8[$91>>0]|0;
               $94 = $93 & 1;
               $95 = ($94<<24>>24)==(0);
               if ($95) {
                $97 = $91;
               } else {
                $98 = (($92) + -4|0);
                $99 = HEAP32[$98>>2]|0;
                HEAP32[$size$i$i$i$i$i>>2] = 90;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$size$i$i$i$i$i+0>>2]|0;
                invoke_vii(2591,($99|0),($$byval_copy12|0));
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if ($101) {
                 label = 37;
                 break;
                }
                $$pre$i$i$i$i$i$i$i = HEAP32[$4>>2]|0;
                $97 = $$pre$i$i$i$i$i$i$i;
               }
               $96 = ($97|0)==($87|0);
               if ($96) {
                label = 38;
                break;
               } else {
                $92 = $97;
               }
              }
              if ((label|0) == 37) {
               $102 = ___cxa_find_matching_catch()|0;
               $103 = tempRet0;
               ___cxa_call_unexpected(($102|0));
               // unreachable;
              }
              else if ((label|0) == 38) {
               $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
               $104 = $$pre$i$i$i$i$i;
               break;
              }
             }
            } while(0);
            HEAP32[$p$i$i$i$i>>2] = 90;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$p$i$i$i$i+0>>2]|0;
            invoke_vii(2591,($104|0),($$byval_copy12|0));
            $105 = __THREW__; __THREW__ = 0;
            $106 = $105&1;
            if ($106) {
             $107 = ___cxa_find_matching_catch()|0;
             $108 = tempRet0;
             ___cxa_call_unexpected(($107|0));
             // unreachable;
            } else {
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
   $50 = ___cxa_find_matching_catch()|0;
   $51 = tempRet0;
   $52 = HEAP8[$p$i$i$i>>0]|0;
   $53 = $52 & 1;
   $54 = ($53<<24>>24)==(0);
   if ($54) {
    $eh$lpad$body$index3Z2D = $51;$eh$lpad$body$indexZ2D = $50;
   } else {
    $55 = (($p$i$i$i) + 8|0);
    $56 = HEAP32[$55>>2]|0;
    HEAP32[$3>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($56|0),($$byval_copy12|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $59 = ___cxa_find_matching_catch()|0;
     $60 = tempRet0;
     ___cxa_call_unexpected(($59|0));
     // unreachable;
    } else {
     $eh$lpad$body$index3Z2D = $51;$eh$lpad$body$indexZ2D = $50;
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $63 = ___cxa_find_matching_catch()|0;
  $64 = tempRet0;
  $eh$lpad$body$index3Z2D = $64;$eh$lpad$body$indexZ2D = $63;
 }
 $65 = HEAP32[$buffer>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $67 = HEAP32[$4>>2]|0;
 $68 = ($67|0)==($65|0);
 do {
  if ($68) {
   $82 = $65;
  } else {
   $70 = $67;
   while(1) {
    $69 = (($70) + -12|0);
    HEAP32[$4>>2] = $69;
    $71 = HEAP8[$69>>0]|0;
    $72 = $71 & 1;
    $73 = ($72<<24>>24)==(0);
    if ($73) {
     $75 = $69;
    } else {
     $76 = (($70) + -4|0);
     $77 = HEAP32[$76>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($77|0),($$byval_copy12|0));
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      label = 26;
      break;
     }
     $$pre$i$i$i$i$i$i$i4 = HEAP32[$4>>2]|0;
     $75 = $$pre$i$i$i$i$i$i$i4;
    }
    $74 = ($75|0)==($65|0);
    if ($74) {
     label = 27;
     break;
    } else {
     $70 = $75;
    }
   }
   if ((label|0) == 26) {
    $80 = ___cxa_find_matching_catch()|0;
    $81 = tempRet0;
    ___cxa_call_unexpected(($80|0));
    // unreachable;
   }
   else if ((label|0) == 27) {
    $$pre$i$i$i$i$i6 = HEAP32[$buffer>>2]|0;
    $82 = $$pre$i$i$i$i$i6;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($82|0),($$byval_copy12|0));
 $83 = __THREW__; __THREW__ = 0;
 $84 = $83&1;
 if ($84) {
  $85 = ___cxa_find_matching_catch()|0;
  $86 = tempRet0;
  ___cxa_call_unexpected(($85|0));
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __Z33EmitSerializationCommandsForFieldI17RemapPPtrTransferEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$0$i$ph9 = 0, $$off = 0, $$ph = 0, $$ph8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $serializeFieldCommand = 0, $staticInfo$sroa$9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $staticInfo$sroa$9 = sp;
 $serializeFieldCommand = sp + 16|0;
 $1 = (($tfi) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z24scripting_class_get_typeP14ScriptingClass($2)|0);
 $4 = (__Z23scripting_type_get_typeP13ScriptingType($3)|0);
 $5 = ($4|0)==(29);
 if (!($5)) {
  $6 = (__ZN9Scripting30IsSystemCollectionsGenericListEP14ScriptingClass($2)|0);
  if (!($6)) {
   ;HEAP32[$staticInfo$sroa$9+0>>2]=0|0;HEAP32[$staticInfo$sroa$9+4>>2]=0|0;HEAP32[$staticInfo$sroa$9+8>>2]=0|0;
   $7 = HEAP32[$tfi>>2]|0;
   $8 = (__Z24scripting_field_get_nameP14ScriptingField($7)|0);
   $9 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $10 = (__Z25scripting_class_from_typeP13ScriptingType($9)|0);
   $11 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $12 = (__Z23scripting_type_get_typeP13ScriptingType($11)|0);
   $13 = (__Z26scripting_field_get_offsetP14ScriptingField($7)|0);
   $14 = (__Z24scripting_class_get_nameP14ScriptingClass($10)|0);
   $15 = (($tfi) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = (($tfi) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($tfi) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   L4: do {
    switch ($19|0) {
    case 13:  {
     $$0$i$ph = 3034;$$ph = $16;
     label = 47;
     break;
    }
    case 8:  {
     $$0$i$ph = 3029;$$ph = $16;
     label = 47;
     break;
    }
    case 14:  {
     $$0$i$ph = 3024;$$ph = $16;
     label = 47;
     break;
    }
    case 5:  {
     $$0$i$ph = 3027;$$ph = $16;
     label = 47;
     break;
    }
    case 10:  {
     $$0$i$ph = 3031;$$ph = $16;
     label = 47;
     break;
    }
    case 11:  {
     $$0$i$ph = 3032;$$ph = $16;
     label = 47;
     break;
    }
    case 3:  {
     $22 = $16 | 33554432;
     $$0$i$ph = 3025;$$ph = $22;
     label = 47;
     break;
    }
    case 9:  {
     $$0$i$ph = 3030;$$ph = $16;
     label = 47;
     break;
    }
    case 4:  {
     $$0$i$ph = 3026;$$ph = $16;
     label = 47;
     break;
    }
    case 6:  {
     $$0$i$ph = 3028;$$ph = $16;
     label = 47;
     break;
    }
    case 2:  {
     $23 = $16 | 256;
     $$0$i$ph = 3027;$$ph = $23;
     label = 47;
     break;
    }
    case 12:  {
     $$0$i$ph = 3033;$$ph = $16;
     label = 47;
     break;
    }
    case 7:  {
     $$0$i$ph = 3025;$$ph = $16;
     label = 47;
     break;
    }
    default: {
     $24 = (($21) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($17|0)==($25|0);
     if ($26) {
      $$0$i$ph = 3035;$$ph = $16;
      label = 47;
     } else {
      $27 = (($21) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($17|0)==($28|0);
      if ($29) {
       $$0$i$ph = 3036;$$ph = $16;
       label = 47;
      } else {
       $30 = (($21) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($17|0)==($31|0);
       if ($32) {
        $$0$i$ph = 3037;$$ph = $16;
        label = 47;
       } else {
        $33 = (($21) + 24|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = ($17|0)==($34|0);
        if ($35) {
         $$0$i$ph = 3038;$$ph = $16;
         label = 47;
        } else {
         $36 = (($21) + 32|0);
         $37 = HEAP32[$36>>2]|0;
         $38 = ($17|0)==($37|0);
         if ($38) {
          $$0$i$ph = 3039;$$ph = $16;
          label = 47;
         } else {
          $39 = (($21) + 36|0);
          $40 = HEAP32[$39>>2]|0;
          $41 = ($17|0)==($40|0);
          if ($41) {
           $$0$i$ph = 3040;$$ph = $16;
           label = 47;
          } else {
           $42 = (($21) + 40|0);
           $43 = HEAP32[$42>>2]|0;
           $44 = ($17|0)==($43|0);
           if ($44) {
            $$0$i$ph = 3041;$$ph = $16;
            label = 47;
           } else {
            $45 = (($21) + 52|0);
            $46 = HEAP32[$45>>2]|0;
            $47 = ($17|0)==($46|0);
            if ($47) {
             $$0$i$ph = 3042;$$ph = $16;
             label = 47;
            } else {
             $48 = (($21) + 56|0);
             $49 = HEAP32[$48>>2]|0;
             $50 = ($17|0)==($49|0);
             if ($50) {
              $$0$i$ph = 3043;$$ph = $16;
              label = 47;
             } else {
              $51 = (($21) + 88|0);
              $52 = HEAP32[$51>>2]|0;
              $53 = ($17|0)==($52|0);
              if ($53) {
               $$0$i$ph = 3044;$$ph = $16;
               label = 47;
              } else {
               $54 = (($21) + 492|0);
               $55 = HEAP32[$54>>2]|0;
               $56 = ($17|0)==($55|0);
               do {
                if (!($56)) {
                 $57 = (($21) + 496|0);
                 $58 = HEAP32[$57>>2]|0;
                 $59 = ($17|0)==($58|0);
                 if (!($59)) {
                  $60 = (__Z23scripting_class_is_enumP14ScriptingClass($17)|0);
                  if (!($60)) {
                   $85 = (($21) + 280|0);
                   $86 = HEAP32[$85>>2]|0;
                   $87 = ($17|0)==($86|0);
                   if ($87) {
                    $$0$i$ph = 3045;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $88 = (($21) + 504|0);
                   $89 = HEAP32[$88>>2]|0;
                   $90 = ($17|0)==($89|0);
                   if ($90) {
                    $$0$i$ph = 3046;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $91 = (($21) + 28|0);
                   $92 = HEAP32[$91>>2]|0;
                   $93 = ($17|0)==($92|0);
                   if ($93) {
                    $$0$i$ph = 3047;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $94 = (($21) + 272|0);
                   $95 = HEAP32[$94>>2]|0;
                   $96 = ($17|0)==($95|0);
                   if ($96) {
                    $$0$i$ph9 = 3048;$$ph8 = $16;
                    break L4;
                   }
                   $97 = ($19|0)==(18);
                   if (!($97)) {
                    break;
                   }
                   $98 = (($21) + 244|0);
                   $99 = HEAP32[$98>>2]|0;
                   $100 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($17,$99)|0);
                   if ($100) {
                    $$0$i$ph9 = 3049;$$ph8 = $16;
                    break L4;
                   } else {
                    break;
                   }
                  }
                  $61 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($17)|0);
                  $62 = (__Z23scripting_type_get_typeP13ScriptingType($61)|0);
                  if ((($62|0) == 5)) {
                   $$0$i$ph = 3027;$$ph = $16;
                   label = 47;
                   break L4;
                  } else if ((($62|0) == 8)) {
                   $$0$i$ph = 3029;$$ph = $16;
                   label = 47;
                   break L4;
                  }
                  $63 = HEAP32[$tfi>>2]|0;
                  __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$63);
                  $64 = HEAP8[$0>>0]|0;
                  $65 = $64 & 1;
                  $66 = ($65<<24>>24)==(0);
                  if ($66) {
                   $69 = (($0) + 1|0);
                   $70 = $69;
                  } else {
                   $67 = (($0) + 8|0);
                   $68 = HEAP32[$67>>2]|0;
                   $70 = $68;
                  }
                  __THREW__ = 0;
                  invoke_viiiiiiii(21,($70|0),0,(630440|0),188,1,0,0,(0|0));
                  $71 = __THREW__; __THREW__ = 0;
                  $72 = $71&1;
                  if (!($72)) {
                   $73 = HEAP8[$0>>0]|0;
                   $74 = $73 & 1;
                   $75 = ($74<<24>>24)==(0);
                   if ($75) {
                    break;
                   }
                   $76 = (($0) + 8|0);
                   $77 = HEAP32[$76>>2]|0;
                   __ZdlPv($77);
                   break;
                  }
                  $78 = ___cxa_find_matching_catch()|0;
                  $79 = tempRet0;
                  $80 = HEAP8[$0>>0]|0;
                  $81 = $80 & 1;
                  $82 = ($81<<24>>24)==(0);
                  if ($82) {
                   ___resumeException($78|0);
                   // unreachable;
                  }
                  $83 = (($0) + 8|0);
                  $84 = HEAP32[$83>>2]|0;
                  __ZdlPv($84);
                  ___resumeException($78|0);
                  // unreachable;
                 }
                }
               } while(0);
               $114 = HEAP32[$18>>2]|0;
               $$off = (($114) + -17)|0;
               $115 = ($$off>>>0)<(2);
               if (!($115)) {
                STACKTOP = sp;return;
               }
               __Z46EmitSerializationCommandsForManagedObjectFieldI17RemapPPtrTransferEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
    }
   } while(0);
   if ((label|0) == 47) {
    $101 = (($tfi) + 25|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $$0$i$ph9 = $$0$i$ph;$$ph8 = $$ph;
    } else {
     STACKTOP = sp;return;
    }
   }
   dest=$serializeFieldCommand+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$serializeFieldCommand>>2] = $$0$i$ph9;
   $104 = (($serializeFieldCommand) + 4|0);
   HEAP32[$104>>2] = $7;
   $105 = (($serializeFieldCommand) + 8|0);
   HEAP32[$105>>2] = $8;
   $106 = (($serializeFieldCommand) + 12|0);
   HEAP32[$106>>2] = $14;
   $107 = (($serializeFieldCommand) + 16|0);
   HEAP32[$107>>2] = $10;
   $108 = (($serializeFieldCommand) + 20|0);
   HEAP32[$108>>2] = $12;
   $109 = (($serializeFieldCommand) + 24|0);
   HEAP32[$109>>2] = $13;
   $110 = (($serializeFieldCommand) + 28|0);
   HEAP32[$110>>2] = $$ph8;
   $111 = (($serializeFieldCommand) + 32|0);
   HEAP32[$111>>2] = $17;
   $112 = (($serializeFieldCommand) + 36|0);
   HEAP32[$112>>2] = $19;
   $113 = (($serializeFieldCommand) + 40|0);
   ;HEAP32[$113+0>>2]=HEAP32[$staticInfo$sroa$9+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[$staticInfo$sroa$9+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[$staticInfo$sroa$9+8>>2]|0;
   __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$serializeFieldCommand);
   STACKTOP = sp;return;
  }
 }
 __Z49EmitSerializationCommandsForLinearCollectionFieldI17RemapPPtrTransferEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
 STACKTOP = sp;return;
}
function __ZL12InvokeMethodI17RemapPPtrTransferEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $invocation = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $invocation = sp + 8|0;
 $0 = sp;
 $1 = (($args) + 57|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($runtimeInfo) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 32|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   STACKTOP = sp;return;
  }
 }
 $9 = (($args) + 48|0);
 $10 = $9;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $0;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $20 = (($runtimeInfo) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($invocation) + 12|0);
 HEAP32[$22>>2] = $21;
 $23 = HEAP8[$runtimeInfo>>0]|0;
 $24 = (($invocation) + 24|0);
 HEAP8[$24>>0] = $23;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation)|0);
 STACKTOP = sp;return;
}
function __Z49EmitSerializationCommandsForLinearCollectionFieldI17RemapPPtrTransferEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($info,$commandQueueBuilder,$nameConversions) {
 $info = $info|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$off = 0, $$ph = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $command = 0, $linearCollectionField = 0, $switch = 0, $tfi = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 184|0;
 $linearCollectionField = sp + 144|0;
 $1 = sp + 68|0;
 $tfi = sp;
 $command = sp + 80|0;
 $$sroa$9 = sp + 56|0;
 HEAP8[$1>>0] = 1;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$info>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$1,$4);
 dest=$tfi+0|0; src=$info+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = HEAP32[$info>>2]|0;
 HEAP32[$tfi>>2] = $5;
 $6 = (__ZN21LinearCollectionField15GetElementClassEv($linearCollectionField)|0);
 $7 = (($tfi) + 40|0);
 HEAP32[$7>>2] = $6;
 $8 = (__Z24scripting_class_get_typeP14ScriptingClass($6)|0);
 $9 = (__Z23scripting_type_get_typeP13ScriptingType($8)|0);
 $10 = (($tfi) + 44|0);
 HEAP32[$10>>2] = $9;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 dest=$command+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$command>>2] = 3050;
 ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
 $14 = (__Z24scripting_field_get_nameP14ScriptingField($5)|0);
 $15 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $16 = (__Z25scripting_class_from_typeP13ScriptingType($15)|0);
 $17 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $18 = (__Z23scripting_type_get_typeP13ScriptingType($17)|0);
 $19 = (__Z26scripting_field_get_offsetP14ScriptingField($5)|0);
 $20 = (__Z24scripting_class_get_nameP14ScriptingClass($16)|0);
 $21 = (($tfi) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($command) + 4|0);
 HEAP32[$23>>2] = $5;
 $24 = (($command) + 8|0);
 HEAP32[$24>>2] = $14;
 $25 = (($command) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($command) + 16|0);
 HEAP32[$26>>2] = $16;
 $27 = (($command) + 20|0);
 HEAP32[$27>>2] = $18;
 $28 = (($command) + 24|0);
 HEAP32[$28>>2] = $19;
 $29 = (($command) + 28|0);
 HEAP32[$29>>2] = $22;
 $30 = (($command) + 32|0);
 HEAP32[$30>>2] = $6;
 $31 = (($command) + 36|0);
 HEAP32[$31>>2] = $9;
 $32 = (($command) + 40|0);
 ;HEAP32[$32+0>>2]=HEAP32[$$sroa$9+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$$sroa$9+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$$sroa$9+8>>2]|0;
 $33 = (($tfi) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 L1: do {
  switch ($9|0) {
  case 12:  {
   $$0$i$ph = 3060;$$ph = 1;
   break;
  }
  case 7:  {
   $$0$i$ph = 3052;$$ph = 1;
   break;
  }
  case 2:  {
   $36 = $22 | 256;
   HEAP32[$29>>2] = $36;
   $$0$i$ph = 3054;$$ph = 1;
   break;
  }
  case 9:  {
   $$0$i$ph = 3057;$$ph = 1;
   break;
  }
  case 4:  {
   $$0$i$ph = 3053;$$ph = 1;
   break;
  }
  case 13:  {
   $$0$i$ph = 3061;$$ph = 1;
   break;
  }
  case 5:  {
   $$0$i$ph = 3054;$$ph = 1;
   break;
  }
  case 6:  {
   $$0$i$ph = 3055;$$ph = 1;
   break;
  }
  case 3:  {
   $35 = $22 | 33554432;
   HEAP32[$29>>2] = $35;
   $$0$i$ph = 3052;$$ph = 1;
   break;
  }
  case 10:  {
   $$0$i$ph = 3058;$$ph = 1;
   break;
  }
  case 11:  {
   $$0$i$ph = 3059;$$ph = 1;
   break;
  }
  case 14:  {
   $$0$i$ph = 3051;$$ph = 1;
   break;
  }
  case 8:  {
   $$0$i$ph = 3056;$$ph = 1;
   break;
  }
  default: {
   $37 = (($34) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($6|0)==($38|0);
   if ($39) {
    $$0$i$ph = 3062;$$ph = 1;
   } else {
    $40 = (($34) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($6|0)==($41|0);
    if ($42) {
     $$0$i$ph = 3063;$$ph = 1;
    } else {
     $43 = (($34) + 20|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($6|0)==($44|0);
     if ($45) {
      $$0$i$ph = 3064;$$ph = 1;
     } else {
      $46 = (($34) + 24|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($6|0)==($47|0);
      if ($48) {
       $$0$i$ph = 3065;$$ph = 1;
      } else {
       $49 = (($34) + 32|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($6|0)==($50|0);
       if ($51) {
        $$0$i$ph = 3066;$$ph = 1;
       } else {
        $52 = (($34) + 36|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($6|0)==($53|0);
        if ($54) {
         $$0$i$ph = 3067;$$ph = 1;
        } else {
         $55 = (($34) + 40|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($6|0)==($56|0);
         if ($57) {
          $$0$i$ph = 3068;$$ph = 1;
         } else {
          $58 = (($34) + 52|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = ($6|0)==($59|0);
          if ($60) {
           $$0$i$ph = 3069;$$ph = 1;
          } else {
           $61 = (($34) + 56|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = ($6|0)==($62|0);
           if ($63) {
            $$0$i$ph = 3070;$$ph = 1;
           } else {
            $64 = (($34) + 88|0);
            $65 = HEAP32[$64>>2]|0;
            $66 = ($6|0)==($65|0);
            if ($66) {
             $$0$i$ph = 3071;$$ph = 1;
            } else {
             $67 = (($34) + 492|0);
             $68 = HEAP32[$67>>2]|0;
             $69 = ($6|0)==($68|0);
             do {
              if ($69) {
               label = 44;
              } else {
               $70 = (($34) + 496|0);
               $71 = HEAP32[$70>>2]|0;
               $72 = ($6|0)==($71|0);
               if ($72) {
                label = 44;
               } else {
                $73 = (__Z23scripting_class_is_enumP14ScriptingClass($6)|0);
                if (!($73)) {
                 $97 = (($34) + 280|0);
                 $98 = HEAP32[$97>>2]|0;
                 $99 = ($6|0)==($98|0);
                 if ($99) {
                  $$0$i$ph = 3072;$$ph = 1;
                  break L1;
                 }
                 $100 = (($34) + 504|0);
                 $101 = HEAP32[$100>>2]|0;
                 $102 = ($6|0)==($101|0);
                 if ($102) {
                  $$0$i$ph = 3073;$$ph = 1;
                  break L1;
                 }
                 $103 = (($34) + 28|0);
                 $104 = HEAP32[$103>>2]|0;
                 $105 = ($6|0)==($104|0);
                 if ($105) {
                  $$0$i$ph = 3074;$$ph = 1;
                  break L1;
                 }
                 $106 = (($34) + 272|0);
                 $107 = HEAP32[$106>>2]|0;
                 $108 = ($6|0)==($107|0);
                 if ($108) {
                  $$0$i$ph = 3075;$$ph = 0;
                  break L1;
                 }
                 $109 = ($9|0)==(18);
                 if (!($109)) {
                  label = 44;
                  break;
                 }
                 $110 = (($34) + 244|0);
                 $111 = HEAP32[$110>>2]|0;
                 $112 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$111)|0);
                 if ($112) {
                  $$0$i$ph = 3076;$$ph = 0;
                  break L1;
                 } else {
                  break;
                 }
                }
                $74 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($6)|0);
                $75 = (__Z23scripting_type_get_typeP13ScriptingType($74)|0);
                if ((($75|0) == 8)) {
                 $$0$i$ph = 3056;$$ph = 1;
                 break L1;
                } else if ((($75|0) == 5)) {
                 $$0$i$ph = 3054;$$ph = 1;
                 break L1;
                }
                __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$5);
                $76 = HEAP8[$0>>0]|0;
                $77 = $76 & 1;
                $78 = ($77<<24>>24)==(0);
                if ($78) {
                 $81 = (($0) + 1|0);
                 $82 = $81;
                } else {
                 $79 = (($0) + 8|0);
                 $80 = HEAP32[$79>>2]|0;
                 $82 = $80;
                }
                __THREW__ = 0;
                invoke_viiiiiiii(21,($82|0),0,(630440|0),188,1,0,0,(0|0));
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if (!($84)) {
                 $85 = HEAP8[$0>>0]|0;
                 $86 = $85 & 1;
                 $87 = ($86<<24>>24)==(0);
                 if ($87) {
                  label = 44;
                  break;
                 }
                 $88 = (($0) + 8|0);
                 $89 = HEAP32[$88>>2]|0;
                 __ZdlPv($89);
                 label = 44;
                 break;
                }
                $90 = ___cxa_find_matching_catch()|0;
                $91 = tempRet0;
                $92 = HEAP8[$0>>0]|0;
                $93 = $92 & 1;
                $94 = ($93<<24>>24)==(0);
                if ($94) {
                 ___resumeException($90|0);
                 // unreachable;
                }
                $95 = (($0) + 8|0);
                $96 = HEAP32[$95>>2]|0;
                __ZdlPv($96);
                ___resumeException($90|0);
                // unreachable;
               }
              }
             } while(0);
             if ((label|0) == 44) {
              $$off = (($9) + -17)|0;
              $switch = ($$off>>>0)<(2);
              if (!($switch)) {
               STACKTOP = sp;return;
              }
             }
             __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI17RemapPPtrTransferEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$command,$commandQueueBuilder,$nameConversions);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
  }
 } while(0);
 $113 = (($tfi) + 25|0);
 $114 = HEAP8[$113>>0]|0;
 $115 = $114 & $$ph;
 $116 = ($115<<24>>24)==(0);
 if (!($116)) {
  STACKTOP = sp;return;
 }
 $117 = (($command) + 44|0);
 HEAP32[$117>>2] = $$0$i$ph;
 __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$command);
 STACKTOP = sp;return;
}
function __Z46EmitSerializationCommandsForManagedObjectFieldI17RemapPPtrTransferEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $args = 0, $newCommandQueueBuilder = 0, $serializeManagedObject = 0, $tfi$idx = 0, $tfi$idx$val = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy1 = sp + 124|0;
 $0 = sp + 120|0;
 $args = sp + 12|0;
 $newCommandQueueBuilder = sp + 32|0;
 $serializeManagedObject = sp + 56|0;
 $$sroa$9 = sp;
 $tfi$idx = (($tfi) + 4|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI18TransferField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$8>>2] = $13;
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 $14 = (($newCommandQueueBuilder) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($newCommandQueueBuilder) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($newCommandQueueBuilder) + 4|0);
 HEAP32[$16>>2] = 61;
 $17 = (($newCommandQueueBuilder) + 16|0);
 HEAP8[$17>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(384,($args|0),($newCommandQueueBuilder|0),($nameConversions|0),0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 do {
  if (!($19)) {
   $20 = (($tfi) + 25|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    label = 8;
   } else {
    $23 = HEAP32[$14>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    dest=$serializeManagedObject+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$serializeManagedObject>>2] = 3077;
    ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
    $33 = HEAP32[$tfi>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3280,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3276,($33|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3278,($37|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_ii(3276,($33|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    $46 = (invoke_ii(3277,($43|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    __THREW__ = 0;
    $49 = (invoke_ii(3283,($33|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    __THREW__ = 0;
    $52 = (invoke_ii(3284,($40|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    $55 = (($tfi) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$tfi$idx>>2]|0;
    $58 = (($tfi) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($serializeManagedObject) + 4|0);
    HEAP32[$60>>2] = $33;
    $61 = (($serializeManagedObject) + 8|0);
    HEAP32[$61>>2] = $34;
    $62 = (($serializeManagedObject) + 12|0);
    HEAP32[$62>>2] = $52;
    $63 = (($serializeManagedObject) + 16|0);
    HEAP32[$63>>2] = $40;
    $64 = (($serializeManagedObject) + 20|0);
    HEAP32[$64>>2] = $46;
    $65 = (($serializeManagedObject) + 24|0);
    HEAP32[$65>>2] = $49;
    $66 = (($serializeManagedObject) + 28|0);
    HEAP32[$66>>2] = $56;
    $67 = (($serializeManagedObject) + 32|0);
    HEAP32[$67>>2] = $57;
    $68 = (($serializeManagedObject) + 36|0);
    HEAP32[$68>>2] = $59;
    $69 = (($serializeManagedObject) + 40|0);
    $70 = $$sroa$9;
    $71 = $70;
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + 4)|0;
    $74 = $73;
    $75 = HEAP32[$74>>2]|0;
    $76 = $69;
    $77 = $76;
    HEAP32[$77>>2] = $72;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = $75;
    $80 = HEAP32[$14>>2]|0;
    $81 = (($serializeManagedObject) + 48|0);
    HEAP32[$81>>2] = $80;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($serializeManagedObject|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($newCommandQueueBuilder|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
   }
   $86 = HEAP32[$15>>2]|0;
   $87 = ($86|0)>(-1);
   if (!($87)) {
    STACKTOP = sp;return;
   }
   $88 = HEAP32[$newCommandQueueBuilder>>2]|0;
   $89 = HEAP32[$16>>2]|0;
   HEAP32[$0>>2] = $89;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($88,$$byval_copy1);
   HEAP32[$newCommandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$15>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$newCommandQueueBuilder>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $90 = ___cxa_find_matching_catch(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 }
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 ___resumeException($25|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $managedObjectTransferer = 0, $newProvider = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $managedObjectTransferer = sp + 32|0;
 $0 = sp;
 $newProvider = sp + 12|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP32[$managedObjectTransferer+0>>2]=0|0;HEAP32[$managedObjectTransferer+4>>2]=0|0;HEAP32[$managedObjectTransferer+8>>2]=0|0;
 $3 = (($managedObjectTransferer) + 4|0);
 HEAP8[$3>>0] = 1;
 $4 = (($managedObjectTransferer) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($managedObjectTransferer) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 $9 = (($args) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(17);
 do {
  if ($8) {
   $$pre$i = (($args) + 12|0);
   if ($11) {
    $16 = 0;
   } else {
    $12 = HEAP32[$$pre$i>>2]|0;
    $13 = (_il2cpp_object_new($12)|0);
    $16 = $13;
   }
   $14 = HEAP32[$$pre$i>>2]|0;
   HEAP8[$0>>0] = 1;
   $15 = (($0) + 4|0);
   HEAP32[$15>>2] = $16;
   $17 = (($0) + 8|0);
   HEAP32[$17>>2] = $14;
   $$pre$phiZ2D = $0;
  } else {
   if ($11) {
    $18 = (($args) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP8[$runtimeInfo>>0]|0;
    $21 = ($20<<24>>24)!=(0);
    $22 = (($19) + -8)|0;
    $23 = $21 ? $19 : $22;
    $24 = (($7) + ($23)|0);
    $25 = (($args) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP8[$0>>0] = 0;
    $27 = (($0) + 4|0);
    HEAP32[$27>>2] = $24;
    $28 = (($0) + 8|0);
    HEAP32[$28>>2] = $26;
    $$pre$phiZ2D = $0;
    break;
   } else {
    $29 = HEAP32[$args>>2]|0;
    __Z30GetOrCreateObjectStoredInFieldP14ScriptingFieldRK17GeneralMonoObjectb($0,$29,$runtimeInfo,1);
    $$pre$phiZ2D = $0;
    break;
   }
  }
 } while(0);
 ;HEAP32[$3+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
 $30 = (($runtimeInfo) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($args) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + ($33<<6)|0);
 HEAP32[$34>>2] = $36;
 $37 = (($newProvider) + 4|0);
 HEAP32[$37>>2] = $35;
 HEAP32[$newProvider>>2] = $35;
 $38 = (($newProvider) + 8|0);
 HEAP32[$38>>2] = $36;
 $$idx$i = $33 << 6;
 $39 = $$idx$i >> 6;
 $40 = (($newProvider) + 16|0);
 HEAP32[$40>>2] = $39;
 $41 = (($newProvider) + 12|0);
 HEAP32[$41>>2] = $39;
 HEAP32[$managedObjectTransferer>>2] = $newProvider;
 $42 = (($args) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 __ZN17RemapPPtrTransfer8TransferI23ManagedObjectTransfererEEvRT_PKc17TransferMetaFlags($2,$managedObjectTransferer,0,$43);
 STACKTOP = sp;return;
}
function __ZN17RemapPPtrTransfer8TransferI23ManagedObjectTransfererEEvRT_PKc17TransferMetaFlags($this,$data,$0,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $metaFlag = $metaFlag|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $runtimeInfo$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $runtimeInfo$i$i1 = sp;
 $1 = ($metaFlag|0)==(0);
 if ($1) {
  $24 = HEAP32[$data>>2]|0;
  ;HEAP32[$runtimeInfo$i$i1+0>>2]=0|0;HEAP32[$runtimeInfo$i$i1+4>>2]=0|0;HEAP32[$runtimeInfo$i$i1+8>>2]=0|0;HEAP32[$runtimeInfo$i$i1+12>>2]=0|0;HEAP32[$runtimeInfo$i$i1+16>>2]=0|0;HEAP32[$runtimeInfo$i$i1+20>>2]=0|0;
  $25 = (($runtimeInfo$i$i1) + 16|0);
  HEAP32[$25>>2] = $this;
  $26 = (($data) + 4|0);
  ;HEAP32[$runtimeInfo$i$i1+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$runtimeInfo$i$i1+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$runtimeInfo$i$i1+8>>2]=HEAP32[$26+8>>2]|0;
  $27 = (($runtimeInfo$i$i1) + 12|0);
  HEAP32[$27>>2] = $24;
  $28 = (($24) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($24) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($29|0)==($31|0);
  if ($32) {
   STACKTOP = sp;return;
  }
  $33 = (($24) + 12|0);
  $35 = $29;$37 = $31;
  while(1) {
   $34 = (($35) + 64|0);
   HEAP32[$28>>2] = $34;
   $36 = $37;
   $38 = $34;
   $39 = (($36) - ($38))|0;
   $40 = $39 >> 6;
   HEAP32[$33>>2] = $40;
   $41 = HEAP32[$35>>2]|0;
   $42 = (($35) + 4|0);
   FUNCTION_TABLE_vii[$41 & 4095]($42,$runtimeInfo$i$i1);
   $43 = HEAP32[$28>>2]|0;
   $44 = HEAP32[$30>>2]|0;
   $45 = ($43|0)==($44|0);
   if ($45) {
    break;
   } else {
    $35 = $43;$37 = $44;
   }
  }
  STACKTOP = sp;return;
 } else {
  __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($this,$metaFlag);
  $2 = HEAP32[$data>>2]|0;
  ;HEAP32[$runtimeInfo$i$i1+0>>2]=0|0;HEAP32[$runtimeInfo$i$i1+4>>2]=0|0;HEAP32[$runtimeInfo$i$i1+8>>2]=0|0;HEAP32[$runtimeInfo$i$i1+12>>2]=0|0;HEAP32[$runtimeInfo$i$i1+16>>2]=0|0;HEAP32[$runtimeInfo$i$i1+20>>2]=0|0;
  $3 = (($runtimeInfo$i$i1) + 16|0);
  HEAP32[$3>>2] = $this;
  $4 = (($data) + 4|0);
  ;HEAP32[$runtimeInfo$i$i1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$runtimeInfo$i$i1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$runtimeInfo$i$i1+8>>2]=HEAP32[$4+8>>2]|0;
  $5 = (($runtimeInfo$i$i1) + 12|0);
  HEAP32[$5>>2] = $2;
  $6 = (($2) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($2) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  if (!($10)) {
   $11 = (($2) + 12|0);
   $13 = $7;$15 = $9;
   while(1) {
    $12 = (($13) + 64|0);
    HEAP32[$6>>2] = $12;
    $14 = $15;
    $16 = $12;
    $17 = (($14) - ($16))|0;
    $18 = $17 >> 6;
    HEAP32[$11>>2] = $18;
    $19 = HEAP32[$13>>2]|0;
    $20 = (($13) + 4|0);
    FUNCTION_TABLE_vii[$19 & 4095]($20,$runtimeInfo$i$i1);
    $21 = HEAP32[$6>>2]|0;
    $22 = HEAP32[$8>>2]|0;
    $23 = ($21|0)==($22|0);
    if ($23) {
     break;
    } else {
     $13 = $21;$15 = $22;
    }
   }
  }
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($this);
  STACKTOP = sp;return;
 }
}
function __Z15Transfer_StringI17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIh17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIs17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3217RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($args) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP8[$runtimeInfo>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = (($6) + -8)|0;
 $10 = $8 ? $6 : $9;
 $11 = (($runtimeInfo) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($10)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($14)|0);
 $16 = (($args) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)!=(0);
 if ($18) {
  __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($1,$17);
 }
 $19 = (($1) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($1) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_iiii[$22 & 2047]($20,$15,$24)|0);
 $26 = (($1) + 32|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)==(0);
 $$$i = $28 ? $15 : $25;
 if ($18) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($1);
 }
 $29 = (__Z24TransferPPtrToMonoObjectiP14ScriptingClassP23DataToCreateNullWrapper24TransferInstructionFlags($$$i,$3,0,$4)|0);
 $30 = HEAP32[$5>>2]|0;
 $31 = HEAP8[$runtimeInfo>>0]|0;
 $32 = ($31<<24>>24)!=(0);
 $33 = (($30) + -8)|0;
 $34 = $32 ? $30 : $33;
 $35 = HEAP32[$11>>2]|0;
 $36 = (($35) + ($34)|0);
 HEAP32[$36>>2] = $29;
 STACKTOP = sp;return;
}
function __Z22TransferField_NonArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0);
 var $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0;
 var $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0);
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $invocation$i = 0, $method$i = 0, $native = 0, $scripting1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy1 = sp + 352|0;
 $method$i = sp;
 $invocation$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 48|0;
 $native = sp + 52|0;
 $scripting1 = sp + 344|0;
 __ZN8GUIStyleC2Ev($native);
 $2 = (($runtimeInfo) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($staticInfo) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$runtimeInfo>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (($5) + -8)|0;
 $9 = $7 ? $5 : $8;
 $10 = (($runtimeInfo) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = HEAP32[$converter>>2]|0;
  __THREW__ = 0;
  $16 = (invoke_ii(3286,($15|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   invoke_vi(3549,($16|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $22 = $16;
    label = 4;
   }
  }
 } else {
  $22 = $13;
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $21 = (($22) + 8|0);
   $23 = HEAP32[$21>>2]|0;
   __THREW__ = 0;
   (invoke_iii(2359,($native|0),($23|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $37 = (($23) + 12|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($native) + 12|0);
    HEAP32[$39>>2] = $38;
    $40 = (($23) + 16|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = (($23) + 20|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = (($23) + 24|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = (($23) + 28|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = (($native) + 16|0);
    HEAPF32[$48>>2] = $41;
    $49 = (($native) + 20|0);
    HEAPF32[$49>>2] = $43;
    $50 = (($native) + 24|0);
    HEAPF32[$50>>2] = $45;
    $51 = (($native) + 28|0);
    HEAPF32[$51>>2] = $47;
    $52 = (($23) + 32|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($native) + 32|0);
    HEAP32[$54>>2] = $53;
    $55 = (($23) + 36|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = (($23) + 40|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = (($23) + 44|0);
    $60 = Math_fround(HEAPF32[$59>>2]);
    $61 = (($23) + 48|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = (($native) + 36|0);
    HEAPF32[$63>>2] = $56;
    $64 = (($native) + 40|0);
    HEAPF32[$64>>2] = $58;
    $65 = (($native) + 44|0);
    HEAPF32[$65>>2] = $60;
    $66 = (($native) + 48|0);
    HEAPF32[$66>>2] = $62;
    $67 = (($23) + 52|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($native) + 52|0);
    HEAP32[$69>>2] = $68;
    $70 = (($23) + 56|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = (($23) + 60|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = (($23) + 64|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = (($23) + 68|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = (($native) + 56|0);
    HEAPF32[$78>>2] = $71;
    $79 = (($native) + 60|0);
    HEAPF32[$79>>2] = $73;
    $80 = (($native) + 64|0);
    HEAPF32[$80>>2] = $75;
    $81 = (($native) + 68|0);
    HEAPF32[$81>>2] = $77;
    $82 = (($23) + 72|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($native) + 72|0);
    HEAP32[$84>>2] = $83;
    $85 = (($23) + 76|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $87 = (($23) + 80|0);
    $88 = Math_fround(HEAPF32[$87>>2]);
    $89 = (($23) + 84|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = (($23) + 88|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = (($native) + 76|0);
    HEAPF32[$93>>2] = $86;
    $94 = (($native) + 80|0);
    HEAPF32[$94>>2] = $88;
    $95 = (($native) + 84|0);
    HEAPF32[$95>>2] = $90;
    $96 = (($native) + 88|0);
    HEAPF32[$96>>2] = $92;
    $97 = (($23) + 92|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (($native) + 92|0);
    HEAP32[$99>>2] = $98;
    $100 = (($23) + 96|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = (($23) + 100|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = (($23) + 104|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = (($23) + 108|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = (($native) + 96|0);
    HEAPF32[$108>>2] = $101;
    $109 = (($native) + 100|0);
    HEAPF32[$109>>2] = $103;
    $110 = (($native) + 104|0);
    HEAPF32[$110>>2] = $105;
    $111 = (($native) + 108|0);
    HEAPF32[$111>>2] = $107;
    $112 = (($23) + 112|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = (($native) + 112|0);
    HEAP32[$114>>2] = $113;
    $115 = (($23) + 116|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = (($23) + 120|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = (($23) + 124|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = (($23) + 128|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = (($native) + 116|0);
    HEAPF32[$123>>2] = $116;
    $124 = (($native) + 120|0);
    HEAPF32[$124>>2] = $118;
    $125 = (($native) + 124|0);
    HEAPF32[$125>>2] = $120;
    $126 = (($native) + 128|0);
    HEAPF32[$126>>2] = $122;
    $127 = (($23) + 132|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = (($native) + 132|0);
    HEAP32[$129>>2] = $128;
    $130 = (($23) + 136|0);
    $131 = Math_fround(HEAPF32[$130>>2]);
    $132 = (($23) + 140|0);
    $133 = Math_fround(HEAPF32[$132>>2]);
    $134 = (($23) + 144|0);
    $135 = Math_fround(HEAPF32[$134>>2]);
    $136 = (($23) + 148|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = (($native) + 136|0);
    HEAPF32[$138>>2] = $131;
    $139 = (($native) + 140|0);
    HEAPF32[$139>>2] = $133;
    $140 = (($native) + 144|0);
    HEAPF32[$140>>2] = $135;
    $141 = (($native) + 148|0);
    HEAPF32[$141>>2] = $137;
    $142 = (($23) + 152|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = (($native) + 152|0);
    HEAP32[$144>>2] = $143;
    $145 = (($23) + 156|0);
    $146 = Math_fround(HEAPF32[$145>>2]);
    $147 = (($23) + 160|0);
    $148 = Math_fround(HEAPF32[$147>>2]);
    $149 = (($23) + 164|0);
    $150 = Math_fround(HEAPF32[$149>>2]);
    $151 = (($23) + 168|0);
    $152 = Math_fround(HEAPF32[$151>>2]);
    $153 = (($native) + 156|0);
    HEAPF32[$153>>2] = $146;
    $154 = (($native) + 160|0);
    HEAPF32[$154>>2] = $148;
    $155 = (($native) + 164|0);
    HEAPF32[$155>>2] = $150;
    $156 = (($native) + 168|0);
    HEAPF32[$156>>2] = $152;
    $157 = (($native) + 172|0);
    $158 = (($23) + 172|0);
    dest=$157+0|0; src=$158+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $159 = (($23) + 236|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = (($native) + 236|0);
    HEAP32[$161>>2] = $160;
    $162 = (($native) + 240|0);
    $163 = (($23) + 240|0);
    dest=$162+0|0; src=$163+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[$162+48>>1]=HEAP16[$163+48>>1]|0;
    $164 = (($staticInfo) + 24|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = ($165|0)==(0);
    if ($166) {
     __THREW__ = 0;
     invoke_vii(3078,($native|0),($3|0));
     $173 = __THREW__; __THREW__ = 0;
     $174 = $173&1;
     if ($174) {
      break;
     }
    } else {
     __THREW__ = 0;
     invoke_vii(2669,($3|0),($165|0));
     $167 = __THREW__; __THREW__ = 0;
     $168 = $167&1;
     if ($168) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(3078,($native|0),($3|0));
     $169 = __THREW__; __THREW__ = 0;
     $170 = $169&1;
     if ($170) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3458,($3|0));
     $171 = __THREW__; __THREW__ = 0;
     $172 = $171&1;
     if ($172) {
      break;
     }
    }
    $175 = HEAP32[$4>>2]|0;
    $176 = HEAP8[$runtimeInfo>>0]|0;
    $177 = ($176<<24>>24)!=(0);
    $178 = (($175) + -8)|0;
    $179 = $177 ? $175 : $178;
    $180 = HEAP32[$10>>2]|0;
    $181 = (($180) + ($179)|0);
    $182 = HEAP32[$181>>2]|0;
    HEAP32[$scripting1>>2] = $182;
    __THREW__ = 0;
    invoke_viii(1797,($converter|0),($native|0),($scripting1|0));
    $183 = __THREW__; __THREW__ = 0;
    $184 = $183&1;
    if (!($184)) {
     $185 = HEAP32[$4>>2]|0;
     $186 = HEAP8[$runtimeInfo>>0]|0;
     $187 = ($186<<24>>24)!=(0);
     $188 = (($185) + -8)|0;
     $189 = $187 ? $185 : $188;
     $190 = HEAP32[$10>>2]|0;
     $191 = (($190) + ($189)|0);
     $192 = HEAP32[$scripting1>>2]|0;
     HEAP32[$191>>2] = $192;
     __THREW__ = 0;
     $193 = (invoke_i(84)|0);
     $194 = __THREW__; __THREW__ = 0;
     $195 = $194&1;
     if (!($195)) {
      $196 = (($193) + 308|0);
      $197 = HEAP32[$196>>2]|0;
      __THREW__ = 0;
      invoke_viiii(388,($method$i|0),($197|0),(630336|0),1);
      $198 = __THREW__; __THREW__ = 0;
      $199 = $198&1;
      if (!($199)) {
       $200 = HEAP32[$method$i>>2]|0;
       $201 = ($200|0)==(0|0);
       if (!($201)) {
        $202 = $method$i;
        $203 = $202;
        $204 = HEAP32[$203>>2]|0;
        $205 = (($202) + 4)|0;
        $206 = $205;
        $207 = HEAP32[$206>>2]|0;
        $208 = $0;
        $209 = $208;
        HEAP32[$209>>2] = $204;
        $210 = (($208) + 4)|0;
        $211 = $210;
        HEAP32[$211>>2] = $207;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;
        invoke_vii(2863,($invocation$i|0),($$byval_copy1|0));
        $212 = __THREW__; __THREW__ = 0;
        $213 = $212&1;
        if ($213) {
         break;
        }
        $214 = (($invocation$i) + 12|0);
        HEAP32[$214>>2] = $192;
        __THREW__ = 0;
        (invoke_ii(3285,($invocation$i|0))|0);
        $215 = __THREW__; __THREW__ = 0;
        $216 = $215&1;
        if ($216) {
         break;
        }
       }
       $217 = HEAP8[$native>>0]|0;
       $218 = $217 & 1;
       $219 = ($218<<24>>24)==(0);
       if ($219) {
        STACKTOP = sp;return;
       }
       $220 = (($native) + 8|0);
       $221 = HEAP32[$220>>2]|0;
       HEAP32[$method$i>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$method$i+0>>2]|0;
       invoke_vii(2591,($221|0),($$byval_copy1|0));
       $222 = __THREW__; __THREW__ = 0;
       $223 = $222&1;
       if ($223) {
        $224 = ___cxa_find_matching_catch()|0;
        $225 = tempRet0;
        ___cxa_call_unexpected(($224|0));
        // unreachable;
       } else {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 $28 = HEAP8[$native>>0]|0;
 $29 = $28 & 1;
 $30 = ($29<<24>>24)==(0);
 if ($30) {
  ___resumeException($26|0);
  // unreachable;
 }
 $31 = (($native) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy1|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 } else {
  ___resumeException($26|0);
  // unreachable;
 }
}
function __ZN8GUIStyle8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 $12 = (($this) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 $18 = (FUNCTION_TABLE_iiii[$16 & 2047]($14,$13,$17)|0);
 $19 = HEAP8[$9>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  HEAP32[$12>>2] = $18;
 }
 $21 = (($this) + 52|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$2>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$6>>2]|0;
 $27 = (FUNCTION_TABLE_iiii[$25 & 2047]($23,$22,$26)|0);
 $28 = HEAP8[$9>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  HEAP32[$21>>2] = $27;
 }
 $30 = (($this) + 72|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$2>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$6>>2]|0;
 $36 = (FUNCTION_TABLE_iiii[$34 & 2047]($32,$31,$35)|0);
 $37 = HEAP8[$9>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if (!($38)) {
  HEAP32[$30>>2] = $36;
 }
 $39 = (($this) + 92|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$2>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$6>>2]|0;
 $45 = (FUNCTION_TABLE_iiii[$43 & 2047]($41,$40,$44)|0);
 $46 = HEAP8[$9>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if (!($47)) {
  HEAP32[$39>>2] = $45;
 }
 $48 = (($this) + 112|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$2>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$6>>2]|0;
 $54 = (FUNCTION_TABLE_iiii[$52 & 2047]($50,$49,$53)|0);
 $55 = HEAP8[$9>>0]|0;
 $56 = ($55<<24>>24)==(0);
 if (!($56)) {
  HEAP32[$48>>2] = $54;
 }
 $57 = (($this) + 132|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = HEAP32[$2>>2]|0;
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$6>>2]|0;
 $63 = (FUNCTION_TABLE_iiii[$61 & 2047]($59,$58,$62)|0);
 $64 = HEAP8[$9>>0]|0;
 $65 = ($64<<24>>24)==(0);
 if (!($65)) {
  HEAP32[$57>>2] = $63;
 }
 $66 = (($this) + 152|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$2>>2]|0;
 $69 = HEAP32[$68>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$6>>2]|0;
 $72 = (FUNCTION_TABLE_iiii[$70 & 2047]($68,$67,$71)|0);
 $73 = HEAP8[$9>>0]|0;
 $74 = ($73<<24>>24)==(0);
 if (!($74)) {
  HEAP32[$66>>2] = $72;
 }
 $75 = (($this) + 236|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = HEAP32[$2>>2]|0;
 $78 = HEAP32[$77>>2]|0;
 $79 = HEAP32[$78>>2]|0;
 $80 = HEAP32[$6>>2]|0;
 $81 = (FUNCTION_TABLE_iiii[$79 & 2047]($77,$76,$80)|0);
 $82 = HEAP8[$9>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  STACKTOP = sp;return;
 }
 HEAP32[$75>>2] = $81;
 STACKTOP = sp;return;
}
function __Z22TransferField_NonArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $native = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native = sp;
 ;HEAP32[$native+0>>2]=0|0;HEAP32[$native+4>>2]=0|0;HEAP32[$native+8>>2]=0|0;HEAP32[$native+12>>2]=0|0;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($staticInfo) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$runtimeInfo>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = (($3) + -8)|0;
 $7 = $5 ? $3 : $6;
 $8 = (($runtimeInfo) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$converter>>2]|0;
  $14 = (_il2cpp_object_new($13)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($14);
  $16 = $14;
 } else {
  $16 = $11;
 }
 $15 = (($16) + 8|0);
 $17 = HEAP32[$15>>2]|0;
 ;HEAP32[$native+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$native+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$native+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$native+12>>2]=HEAP32[$17+12>>2]|0;
 $18 = (($staticInfo) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if (!($20)) {
  __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($1,$19);
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($1);
 }
 $21 = HEAP32[$2>>2]|0;
 $22 = HEAP8[$runtimeInfo>>0]|0;
 $23 = ($22<<24>>24)!=(0);
 $24 = (($21) + -8)|0;
 $25 = $23 ? $21 : $24;
 $26 = HEAP32[$8>>2]|0;
 $27 = (($26) + ($25)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $30 = HEAP32[$converter>>2]|0;
  $31 = (_il2cpp_object_new($30)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($31);
  $33 = $31;
 } else {
  $33 = $28;
 }
 $32 = (($33) + 8|0);
 $34 = HEAP32[$32>>2]|0;
 ;HEAP32[$34+0>>2]=HEAP32[$native+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$native+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$native+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$native+12>>2]|0;
 $35 = HEAP32[$2>>2]|0;
 $36 = HEAP8[$runtimeInfo>>0]|0;
 $37 = ($36<<24>>24)!=(0);
 $38 = (($35) + -8)|0;
 $39 = $37 ? $35 : $38;
 $40 = HEAP32[$8>>2]|0;
 $41 = (($40) + ($39)|0);
 HEAP32[$41>>2] = $33;
 STACKTOP = sp;return;
}
function __Z22TransferField_NonArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $native = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $native = sp;
 __ZN11GradientNEWC2Ev($native);
 $0 = (($staticInfo) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = HEAP32[$converter>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_ii(3286,($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   invoke_vi(3549,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $$pre = HEAP32[$0>>2]|0;
    $$pre4 = HEAP8[$runtimeInfo>>0]|0;
    $$pre5 = HEAP32[$6>>2]|0;
    $22 = $12;$49 = $$pre4;$51 = $$pre;$54 = $$pre5;
    label = 6;
   }
  }
 } else {
  $22 = $9;$49 = $2;$51 = $1;$54 = $7;
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   $21 = (($22) + 8|0);
   $23 = HEAP32[$21>>2]|0;
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$native>>2] = $24;
   $25 = (($native) + 4|0);
   $26 = (($23) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$25>>2] = $27;
   $28 = (($native) + 8|0);
   $29 = (($23) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$28>>2] = $30;
   $31 = (($native) + 12|0);
   $32 = (($23) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   HEAP32[$31>>2] = $33;
   $34 = (($native) + 16|0);
   $35 = (($23) + 16|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP32[$34>>2] = $36;
   $37 = (($native) + 20|0);
   $38 = (($23) + 20|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$37>>2] = $39;
   $40 = (($native) + 24|0);
   $41 = (($23) + 24|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$40>>2] = $42;
   $43 = (($native) + 28|0);
   $44 = (($23) + 28|0);
   $45 = HEAP32[$44>>2]|0;
   HEAP32[$43>>2] = $45;
   $46 = (($native) + 32|0);
   $47 = (($23) + 32|0);
   dest=$46+0|0; src=$47+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
   $48 = ($49<<24>>24)!=(0);
   $50 = (($51) + -8)|0;
   $52 = $48 ? $51 : $50;
   $53 = (($54) + ($52)|0);
   $55 = HEAP32[$53>>2]|0;
   $56 = ($55|0)==(0|0);
   if ($56) {
    $57 = HEAP32[$converter>>2]|0;
    __THREW__ = 0;
    $58 = (invoke_ii(3286,($57|0))|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3549,($58|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     break;
    }
    $$pre6 = HEAP32[$native>>2]|0;
    $64 = $58;$66 = $$pre6;
   } else {
    $64 = $55;$66 = $24;
   }
   $63 = (($64) + 8|0);
   $65 = HEAP32[$63>>2]|0;
   HEAP32[$65>>2] = $66;
   $67 = (($65) + 4|0);
   $68 = HEAP32[$25>>2]|0;
   HEAP32[$67>>2] = $68;
   $69 = (($65) + 8|0);
   $70 = HEAP32[$28>>2]|0;
   HEAP32[$69>>2] = $70;
   $71 = (($65) + 12|0);
   $72 = HEAP32[$31>>2]|0;
   HEAP32[$71>>2] = $72;
   $73 = (($65) + 16|0);
   $74 = HEAP32[$34>>2]|0;
   HEAP32[$73>>2] = $74;
   $75 = (($65) + 20|0);
   $76 = HEAP32[$37>>2]|0;
   HEAP32[$75>>2] = $76;
   $77 = (($65) + 24|0);
   $78 = HEAP32[$40>>2]|0;
   HEAP32[$77>>2] = $78;
   $79 = (($65) + 28|0);
   $80 = HEAP32[$43>>2]|0;
   HEAP32[$79>>2] = $80;
   $81 = (($65) + 32|0);
   dest=$81+0|0; src=$46+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
   $82 = HEAP32[$0>>2]|0;
   $83 = HEAP8[$runtimeInfo>>0]|0;
   $84 = ($83<<24>>24)!=(0);
   $85 = (($82) + -8)|0;
   $86 = $84 ? $82 : $85;
   $87 = HEAP32[$6>>2]|0;
   $88 = (($87) + ($86)|0);
   HEAP32[$88>>2] = $64;
   STACKTOP = sp;return;
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $89 = ___cxa_find_matching_catch(0|0)|0;
  $90 = tempRet0;
  ___clang_call_terminate($89);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __Z22TransferField_NonArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native = 0, $scripting = 0;
 var $scripting1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp + 96|0;
 $0 = sp;
 $native = sp + 8|0;
 $scripting = sp + 88|0;
 $scripting1 = sp + 92|0;
 $1 = (($native) + 4|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 HEAP32[$native>>2] = 0;
 $2 = (($native) + 8|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $3 = (($native) + 32|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($native) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($native) + 36|0);
 $6 = (($native) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($native) + 68|0);
 HEAP32[$7>>2] = 0;
 $8 = (($native) + 60|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$8>>2] = 61;
 $9 = (($native) + 76|0);
 HEAP32[$9>>2] = 2;
 $10 = (($native) + 72|0);
 HEAP32[$10>>2] = 2;
 $11 = (($staticInfo) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP8[$runtimeInfo>>0]|0;
 $14 = ($13<<24>>24)!=(0);
 $15 = (($12) + -8)|0;
 $16 = $14 ? $12 : $15;
 $17 = (($runtimeInfo) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + ($16)|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$scripting>>2] = $20;
 __THREW__ = 0;
 invoke_viii(1878,($converter|0),($scripting|0),($native|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if (!($22)) {
  $32 = HEAP32[$11>>2]|0;
  $33 = HEAP8[$runtimeInfo>>0]|0;
  $34 = ($33<<24>>24)!=(0);
  $35 = (($32) + -8)|0;
  $36 = $34 ? $32 : $35;
  $37 = HEAP32[$17>>2]|0;
  $38 = (($37) + ($36)|0);
  $39 = HEAP32[$38>>2]|0;
  HEAP32[$scripting1>>2] = $39;
  __THREW__ = 0;
  invoke_viii(1798,($converter|0),($native|0),($scripting1|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if (!($41)) {
   $42 = HEAP32[$11>>2]|0;
   $43 = HEAP8[$runtimeInfo>>0]|0;
   $44 = ($43<<24>>24)!=(0);
   $45 = (($42) + -8)|0;
   $46 = $44 ? $42 : $45;
   $47 = HEAP32[$17>>2]|0;
   $48 = (($47) + ($46)|0);
   $49 = HEAP32[$scripting1>>2]|0;
   HEAP32[$48>>2] = $49;
   $50 = HEAP32[$7>>2]|0;
   $51 = ($50|0)>(-1);
   if (!($51)) {
    STACKTOP = sp;return;
   }
   $52 = (($native) + 56|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $54;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($53,$$byval_copy1);
   HEAP32[$52>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$7>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = (($native) + 56|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $29;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($28|0),($$byval_copy1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $55 = ___cxa_find_matching_catch(0|0)|0;
  $56 = tempRet0;
  ___clang_call_terminate($55);
  // unreachable;
 }
 HEAP32[$27>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __Z30TransferField_LinearCollectionI17RemapPPtrTransferEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $array = 0, $linearCollectionField = 0, $newRuntimeInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $linearCollectionField = sp + 40|0;
 $array = sp;
 $0 = sp + 8|0;
 $newRuntimeInfo = sp + 16|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$args>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$runtimeInfo,$3);
 HEAP32[$array>>2] = 0;
 $4 = (($array) + 4|0);
 HEAP32[$4>>2] = -1;
 $5 = (($runtimeInfo) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  label = 3;
 } else {
  __ZN21LinearCollectionField8GetArrayEv($0,$linearCollectionField);
  $8 = $0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $array;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = (0)==(0);
  $19 = ($13|0)==(-1);
  $20 = $18 & $19;
  if ($20) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $21 = (__ZN21LinearCollectionField15GetElementClassEv($linearCollectionField)|0);
  $22 = (__Z34scripting_class_array_element_sizeP14ScriptingClass($21)|0);
  $23 = (__Z19scripting_array_newP14ScriptingClassjj($21,$22,0)|0);
  HEAP32[$array>>2] = $23;
  HEAP32[$4>>2] = 0;
 }
 $24 = HEAP8[$runtimeInfo>>0]|0;
 HEAP8[$newRuntimeInfo>>0] = $24;
 $25 = (($newRuntimeInfo) + 4|0);
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$25>>2] = $26;
 $27 = (($newRuntimeInfo) + 8|0);
 $28 = (($runtimeInfo) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$27>>2] = $29;
 $30 = (($newRuntimeInfo) + 12|0);
 $31 = (($runtimeInfo) + 12|0);
 $32 = $31;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $30;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = (($newRuntimeInfo) + 20|0);
 HEAP32[$42>>2] = $array;
 $43 = (($args) + 40|0);
 $44 = HEAP32[$43>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($args,$newRuntimeInfo);
 $45 = (($2) + 32|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if ($47) {
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$4>>2]|0;
 $49 = ($48|0)==(-1);
 if ($49) {
  STACKTOP = sp;return;
 }
 __ZN21LinearCollectionField8SetArrayERK9ArrayInfo($linearCollectionField,$array);
 STACKTOP = sp;return;
}
function __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI17RemapPPtrTransferEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$partiallySetuplinearCollectionCommand,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $partiallySetuplinearCollectionCommand = $partiallySetuplinearCollectionCommand|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandQueueForSingleElement = 0, $or$cond = 0, $tfi$idx = 0, $tfi$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 44|0;
 $0 = sp;
 $args = sp + 4|0;
 $commandQueueForSingleElement = sp + 24|0;
 $tfi$idx = (($tfi) + 40|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI23TransferArrayField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$8>>2] = $12;
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 $13 = (($commandQueueForSingleElement) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($commandQueueForSingleElement) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($commandQueueForSingleElement) + 4|0);
 HEAP32[$15>>2] = 61;
 $16 = (($commandQueueForSingleElement) + 16|0);
 HEAP8[$16>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(384,($args|0),($commandQueueForSingleElement|0),($nameConversions|0),0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = (($tfi) + 25|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)!=(0);
   $$pre = HEAP32[$13>>2]|0;
   $22 = ($$pre|0)==(0);
   $or$cond = $21 & $22;
   if (!($or$cond)) {
    $31 = (($partiallySetuplinearCollectionCommand) + 44|0);
    HEAP32[$31>>2] = 3079;
    $32 = (($partiallySetuplinearCollectionCommand) + 48|0);
    HEAP32[$32>>2] = $$pre;
    $33 = HEAP32[$tfi$idx>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3284,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = (($partiallySetuplinearCollectionCommand) + 40|0);
    HEAP32[$37>>2] = $34;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($partiallySetuplinearCollectionCommand|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($commandQueueForSingleElement|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
   }
   $42 = HEAP32[$14>>2]|0;
   $43 = ($42|0)>(-1);
   if (!($43)) {
    STACKTOP = sp;return;
   }
   $44 = HEAP32[$commandQueueForSingleElement>>2]|0;
   $45 = HEAP32[$15>>2]|0;
   HEAP32[$0>>2] = $45;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($44,$$byval_copy1);
   HEAP32[$commandQueueForSingleElement>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$14>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$commandQueueForSingleElement>>2]|0;
 $28 = HEAP32[$15>>2]|0;
 HEAP32[$0>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $46 = ___cxa_find_matching_catch(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 }
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arrayOfManagedObjectsTransferer = 0, $newProvider = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $arrayOfManagedObjectsTransferer = sp;
 $newProvider = sp + 12|0;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $arrayOfManagedObjectsTransferer;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$arrayOfManagedObjectsTransferer>>2] = $7;
 $8 = (($args) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($arrayOfManagedObjectsTransferer) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = (($runtimeInfo) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14<<6)|0);
 HEAP32[$15>>2] = $17;
 $18 = (($newProvider) + 4|0);
 HEAP32[$18>>2] = $16;
 HEAP32[$newProvider>>2] = $16;
 $19 = (($newProvider) + 8|0);
 HEAP32[$19>>2] = $17;
 $$idx$i = $14 << 6;
 $20 = $$idx$i >> 6;
 $21 = (($newProvider) + 16|0);
 HEAP32[$21>>2] = $20;
 $22 = (($newProvider) + 12|0);
 HEAP32[$22>>2] = $20;
 $23 = (($arrayOfManagedObjectsTransferer) + 8|0);
 HEAP32[$23>>2] = $newProvider;
 $24 = (($args) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  __ZN17RemapPPtrTransfer21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($1,$arrayOfManagedObjectsTransferer,0);
  STACKTOP = sp;return;
 } else {
  __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($1,$25);
  __ZN17RemapPPtrTransfer21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($1,$arrayOfManagedObjectsTransferer,0);
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($1);
  STACKTOP = sp;return;
 }
}
function __ZN17RemapPPtrTransfer21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($this,$data,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $metaFlag = $metaFlag|0;
 var $$pre = 0, $$pre2 = 0, $$sroa$1$i = 0, $$sroa$12$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i = 0, $instance$0$i = 0, $storemerge = 0, $storemerge1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$sroa$12$i = sp + 59|0;
 $$sroa$1$i = sp + 56|0;
 $i = sp;
 $0 = (($i) + 24|0);
 HEAP8[$0>>0] = 1;
 $1 = (($i) + 28|0);
 HEAP32[$1>>2] = 0;
 $2 = (($i) + 32|0);
 HEAP32[$2>>2] = 0;
 $3 = (($i) + 40|0);
 $4 = (($i) + 44|0);
 $5 = HEAP32[$data>>2]|0;
 HEAP32[$i>>2] = $5;
 $6 = (($i) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = (($data) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($8)|0);
 $10 = (($i) + 4|0);
 $11 = $9&1;
 HEAP8[$10>>0] = $11;
 $12 = HEAP32[$data>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (__Z26scripting_object_get_classP15ScriptingObject($13)|0);
 $15 = (__Z28scripting_array_element_sizeP14ScriptingClass($14)|0);
 $16 = (($i) + 8|0);
 HEAP32[$16>>2] = $15;
 $17 = HEAP32[$7>>2]|0;
 $18 = (($i) + 16|0);
 HEAP32[$18>>2] = $17;
 $19 = (($data) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($20) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$3>>2] = $21;
 $24 = (($i) + 36|0);
 HEAP32[$24>>2] = $21;
 HEAP32[$4>>2] = $23;
 $25 = $23;
 $26 = $21;
 $27 = (($25) - ($26))|0;
 $28 = $27 >> 6;
 $29 = (($i) + 52|0);
 HEAP32[$29>>2] = $28;
 $30 = (($i) + 48|0);
 HEAP32[$30>>2] = $28;
 $31 = HEAP32[$data>>2]|0;
 $32 = (($31) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$6>>2]|0;
 $35 = ($34|0)==($33|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (($i) + 36|0);
 $37 = (($i) + 20|0);
 $38 = (($i) + 25|0);
 $39 = (($i) + 20|0);
 $40 = $21;$43 = $34;$44 = $15;
 while(1) {
  HEAP32[$3>>2] = $40;
  HEAP32[$37>>2] = $36;
  $41 = HEAP32[$i>>2]|0;
  $42 = HEAP32[$41>>2]|0;
  $45 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($42,$43,$44)|0);
  $46 = HEAP8[$10>>0]|0;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   $49 = HEAP32[$45>>2]|0;
   $50 = ($49|0)==(0|0);
   if ($50) {
    $51 = HEAP32[$18>>2]|0;
    $52 = (_il2cpp_object_new($51)|0);
    __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($52);
    $53 = HEAP32[$i>>2]|0;
    $54 = HEAP32[$53>>2]|0;
    $55 = HEAP32[$6>>2]|0;
    __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($54,$55,$52);
    $instance$0$i = $52;
   } else {
    $instance$0$i = $49;
   }
   $56 = HEAP32[$18>>2]|0;
   HEAP8[$0>>0] = 1;
   ;HEAP8[$38+0>>0]=HEAP8[$$sroa$1$i+0>>0]|0;HEAP8[$38+1>>0]=HEAP8[$$sroa$1$i+1>>0]|0;HEAP8[$38+2>>0]=HEAP8[$$sroa$1$i+2>>0]|0;
   $storemerge = $56;$storemerge1 = $instance$0$i;
  } else {
   $48 = HEAP32[$18>>2]|0;
   HEAP8[$0>>0] = 0;
   ;HEAP8[$38+0>>0]=HEAP8[$$sroa$12$i+0>>0]|0;HEAP8[$38+1>>0]=HEAP8[$$sroa$12$i+1>>0]|0;HEAP8[$38+2>>0]=HEAP8[$$sroa$12$i+2>>0]|0;
   $storemerge = $48;$storemerge1 = $45;
  }
  HEAP32[$1>>2] = $storemerge1;
  HEAP32[$2>>2] = $storemerge;
  __ZN17RemapPPtrTransfer8TransferI23ManagedObjectTransfererEEvRT_PKc17TransferMetaFlags($this,$39,0,$metaFlag);
  $57 = HEAP32[$6>>2]|0;
  $58 = (($57) + 1)|0;
  HEAP32[$6>>2] = $58;
  $59 = ($58|0)==($33|0);
  if ($59) {
   break;
  }
  $$pre = HEAP32[$36>>2]|0;
  $$pre2 = HEAP32[$16>>2]|0;
  $40 = $$pre;$43 = $58;$44 = $$pre2;
 }
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIh17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIs17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3217RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$converter>>2] = $3;
 $5 = (($converter) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($converter) + 8|0);
 HEAP32[$6>>2] = 0;
 __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0;
 var $buffer = 0, $index$01$i = 0, $index$018 = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy12 = sp + 32|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 12|0);
 ;HEAP32[$3+0>>2]=HEAP32[$converter+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$converter+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$converter+8>>2]|0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_vii(3080,($buffer|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   label = 6;
  } else {
   $31 = (($staticInfo) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0);
   L3: do {
    if ($33) {
     $57 = HEAP32[$buffer>>2]|0;
     $58 = HEAP32[$1>>2]|0;
     $59 = ($57|0)==($58|0);
     if (!($59)) {
      $60 = (($5) + 12|0);
      $61 = (($5) + 28|0);
      $62 = (($5) + 32|0);
      $64 = $57;
      while(1) {
       $63 = HEAP32[$64>>2]|0;
       $65 = HEAP32[$60>>2]|0;
       $66 = HEAP32[$65>>2]|0;
       $67 = HEAP32[$66>>2]|0;
       $68 = HEAP32[$61>>2]|0;
       __THREW__ = 0;
       $69 = (invoke_iiii($67|0,($65|0),($63|0),($68|0))|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break;
       }
       $72 = HEAP8[$62>>0]|0;
       $73 = ($72<<24>>24)==(0);
       if (!($73)) {
        HEAP32[$64>>2] = $69;
       }
       $74 = (($64) + 12|0);
       $75 = ($74|0)==($58|0);
       if ($75) {
        break L3;
       } else {
        $64 = $74;
       }
      }
      $14 = ___cxa_find_matching_catch()|0;
      $15 = tempRet0;
      $lpad$phi$index = $14;$lpad$phi$index5 = $15;
      break L1;
     }
    } else {
     __THREW__ = 0;
     invoke_vii(2669,($5|0),($32|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 6;
      break L1;
     }
     $36 = HEAP32[$buffer>>2]|0;
     $37 = HEAP32[$1>>2]|0;
     $38 = ($36|0)==($37|0);
     L15: do {
      if (!($38)) {
       $39 = (($5) + 12|0);
       $40 = (($5) + 28|0);
       $41 = (($5) + 32|0);
       $43 = $36;
       while(1) {
        $42 = HEAP32[$43>>2]|0;
        $44 = HEAP32[$39>>2]|0;
        $45 = HEAP32[$44>>2]|0;
        $46 = HEAP32[$45>>2]|0;
        $47 = HEAP32[$40>>2]|0;
        __THREW__ = 0;
        $48 = (invoke_iiii($46|0,($44|0),($42|0),($47|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        $51 = HEAP8[$41>>0]|0;
        $52 = ($51<<24>>24)==(0);
        if (!($52)) {
         HEAP32[$43>>2] = $48;
        }
        $53 = (($43) + 12|0);
        $54 = ($53|0)==($37|0);
        if ($54) {
         break L15;
        } else {
         $43 = $53;
        }
       }
       $16 = ___cxa_find_matching_catch()|0;
       $17 = tempRet0;
       $lpad$phi$index = $16;$lpad$phi$index5 = $17;
       break L1;
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3458,($5|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 6;
      break L1;
     }
    }
   } while(0);
   $76 = HEAP32[$6>>2]|0;
   $77 = (($staticInfo) + 28|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = HEAP32[$1>>2]|0;
   $80 = HEAP32[$buffer>>2]|0;
   $81 = $79;
   $82 = $80;
   $83 = (($81) - ($82))|0;
   $84 = (($83|0) / 12)&-1;
   $85 = (($76) + 4|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ($86|0)==($84|0);
   if (!($87)) {
    __THREW__ = 0;
    $88 = (invoke_ii(3288,($78|0))|0);
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    $91 = (invoke_iiii(1554,($78|0),($88|0),($84|0))|0);
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     label = 6;
     break;
    }
    HEAP32[$76>>2] = $91;
    HEAP32[$85>>2] = $84;
   }
   $94 = ($79|0)==($80|0);
   L31: do {
    if (!($94)) {
     $95 = (($buffer) + 12|0);
     $96 = (($buffer) + 20|0);
     $97 = (($buffer) + 16|0);
     $index$01$i = 0;
     while(1) {
      $98 = HEAP32[$76>>2]|0;
      __THREW__ = 0;
      $99 = (invoke_iii(2433,($98|0),($index$01$i|0))|0);
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       break;
      }
      $102 = HEAP32[$buffer>>2]|0;
      $103 = (($102) + (($index$01$i*12)|0)|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = HEAP32[$95>>2]|0;
      $106 = HEAP32[$96>>2]|0;
      $107 = HEAP32[$97>>2]|0;
      __THREW__ = 0;
      $108 = (invoke_iiiii(245,($104|0),($105|0),($106|0),($107|0))|0);
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       break;
      }
      HEAP32[$99>>2] = $108;
      $111 = (($index$01$i) + 1)|0;
      $112 = ($111|0)==($84|0);
      if ($112) {
       break L31;
      } else {
       $index$01$i = $111;
      }
     }
     $12 = ___cxa_find_matching_catch()|0;
     $13 = tempRet0;
     $lpad$phi$index = $12;$lpad$phi$index5 = $13;
     break L1;
    }
   } while(0);
   $113 = HEAP32[$6>>2]|0;
   $114 = (($113) + 4|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ($115|0)==(0);
   L39: do {
    if (!($116)) {
     $118 = $113;$index$018 = 0;
     while(1) {
      $117 = HEAP32[$118>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2433,($117|0),($index$018|0))|0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       break;
      }
      $121 = (($index$018) + 1)|0;
      $122 = HEAP32[$6>>2]|0;
      $123 = (($122) + 4|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = ($121|0)==($124|0);
      if ($125) {
       break L39;
      } else {
       $118 = $122;$index$018 = $121;
      }
     }
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index5 = $11;
     break L1;
    }
   } while(0);
   $126 = HEAP32[$buffer>>2]|0;
   $127 = ($126|0)==(0|0);
   if ($127) {
    STACKTOP = sp;return;
   }
   $128 = HEAP32[$1>>2]|0;
   $129 = ($128|0)==($126|0);
   if (!($129)) {
    $__new_last2$i$i$i$i$i$i$i = $126;
    $scevgep$i$i$i$i$i$i$i = (($128) + -12|0);
    $130 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($130)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $131 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $132 = $131 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($128) + (($132*12)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($126|0),($$byval_copy12|0));
   $133 = __THREW__; __THREW__ = 0;
   $134 = $133&1;
   if ($134) {
    $135 = ___cxa_find_matching_catch()|0;
    $136 = tempRet0;
    ___cxa_call_unexpected(($135|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $lpad$phi$index = $18;$lpad$phi$index5 = $19;
 }
 $20 = HEAP32[$buffer>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $22 = HEAP32[$1>>2]|0;
 $23 = ($22|0)==($20|0);
 if (!($23)) {
  $__new_last2$i$i$i$i$i$i$i1 = $20;
  $scevgep$i$i$i$i$i$i$i2 = (($22) + -12|0);
  $24 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($24)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $25 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 12)&-1;
  $26 = $25 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($22) + (($26*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($20|0),($$byval_copy12|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  ___cxa_call_unexpected(($29|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy14 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $index$01$i = 0, $index$021 = 0, $invocation$i = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $method$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy14 = sp + 72|0;
 $method$i = sp;
 $invocation$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 48|0;
 $2 = sp + 52|0;
 $buffer = sp + 56|0;
 HEAP32[$buffer>>2] = 0;
 $3 = (($buffer) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($buffer) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[$converter>>2]|0;
 $6 = (($buffer) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (($runtimeInfo) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($runtimeInfo) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 invoke_vii(3081,($buffer|0),($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   label = 6;
  } else {
   $45 = (($staticInfo) + 24|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0);
   L3: do {
    if ($47) {
     $60 = HEAP32[$buffer>>2]|0;
     $61 = HEAP32[$3>>2]|0;
     $62 = ($60|0)==($61|0);
     if (!($62)) {
      $63 = $60;
      while(1) {
       __THREW__ = 0;
       invoke_vii(3078,($63|0),($8|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break;
       }
       $66 = (($63) + 292|0);
       $67 = ($66|0)==($61|0);
       if ($67) {
        break L3;
       } else {
        $63 = $66;
       }
      }
      $17 = ___cxa_find_matching_catch()|0;
      $18 = tempRet0;
      $lpad$phi$index = $17;$lpad$phi$index5 = $18;
      break L1;
     }
    } else {
     __THREW__ = 0;
     invoke_vii(2669,($8|0),($46|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      label = 6;
      break L1;
     }
     $50 = HEAP32[$buffer>>2]|0;
     $51 = HEAP32[$3>>2]|0;
     $52 = ($50|0)==($51|0);
     L6: do {
      if (!($52)) {
       $53 = $50;
       while(1) {
        __THREW__ = 0;
        invoke_vii(3078,($53|0),($8|0));
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         break;
        }
        $56 = (($53) + 292|0);
        $57 = ($56|0)==($51|0);
        if ($57) {
         break L6;
        } else {
         $53 = $56;
        }
       }
       $19 = ___cxa_find_matching_catch()|0;
       $20 = tempRet0;
       $lpad$phi$index = $19;$lpad$phi$index5 = $20;
       break L1;
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3458,($8|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      label = 6;
      break L1;
     }
    }
   } while(0);
   $68 = HEAP32[$9>>2]|0;
   $69 = (($staticInfo) + 28|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = HEAP32[$3>>2]|0;
   $72 = HEAP32[$buffer>>2]|0;
   $73 = $71;
   $74 = $72;
   $75 = (($73) - ($74))|0;
   $76 = (($75|0) / 292)&-1;
   $77 = (($68) + 4|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==($76|0);
   if (!($79)) {
    __THREW__ = 0;
    $80 = (invoke_ii(3288,($70|0))|0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    $83 = (invoke_iiii(1554,($70|0),($80|0),($76|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     label = 6;
     break;
    }
    HEAP32[$68>>2] = $83;
    HEAP32[$77>>2] = $76;
   }
   $86 = ($71|0)==($72|0);
   L23: do {
    if (!($86)) {
     $87 = (($buffer) + 12|0);
     $index$01$i = 0;
     while(1) {
      $88 = HEAP32[$68>>2]|0;
      __THREW__ = 0;
      $89 = (invoke_iii(2433,($88|0),($index$01$i|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      $92 = HEAP32[$buffer>>2]|0;
      $93 = (($92) + (($index$01$i*292)|0)|0);
      __THREW__ = 0;
      invoke_viii(1797,($87|0),($93|0),($89|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       break;
      }
      $96 = (($index$01$i) + 1)|0;
      $97 = ($96|0)==($76|0);
      if ($97) {
       break L23;
      } else {
       $index$01$i = $96;
      }
     }
     $15 = ___cxa_find_matching_catch()|0;
     $16 = tempRet0;
     $lpad$phi$index = $15;$lpad$phi$index5 = $16;
     break L1;
    }
   } while(0);
   $98 = HEAP32[$9>>2]|0;
   $99 = (($98) + 4|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==(0);
   L31: do {
    if (!($101)) {
     $102 = (($invocation$i) + 12|0);
     $104 = $98;$index$021 = 0;
     while(1) {
      $103 = HEAP32[$104>>2]|0;
      __THREW__ = 0;
      $105 = (invoke_iii(2433,($103|0),($index$021|0))|0);
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       break;
      }
      $108 = HEAP32[$105>>2]|0;
      __THREW__ = 0;
      $109 = (invoke_i(84)|0);
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       break;
      }
      $112 = (($109) + 308|0);
      $113 = HEAP32[$112>>2]|0;
      __THREW__ = 0;
      invoke_viiii(388,($method$i|0),($113|0),(630336|0),1);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       break;
      }
      $116 = HEAP32[$method$i>>2]|0;
      $117 = ($116|0)==(0|0);
      if (!($117)) {
       $118 = $method$i;
       $119 = $118;
       $120 = HEAP32[$119>>2]|0;
       $121 = (($118) + 4)|0;
       $122 = $121;
       $123 = HEAP32[$122>>2]|0;
       $124 = $0;
       $125 = $124;
       HEAP32[$125>>2] = $120;
       $126 = (($124) + 4)|0;
       $127 = $126;
       HEAP32[$127>>2] = $123;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy14+4>>2]=HEAP32[$0+4>>2]|0;
       invoke_vii(2863,($invocation$i|0),($$byval_copy14|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        break;
       }
       HEAP32[$102>>2] = $108;
       __THREW__ = 0;
       (invoke_ii(3285,($invocation$i|0))|0);
       $130 = __THREW__; __THREW__ = 0;
       $131 = $130&1;
       if ($131) {
        break;
       }
      }
      $132 = (($index$021) + 1)|0;
      $133 = HEAP32[$9>>2]|0;
      $134 = (($133) + 4|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ($132|0)==($135|0);
      if ($136) {
       break L31;
      } else {
       $104 = $133;$index$021 = $132;
      }
     }
     $13 = ___cxa_find_matching_catch()|0;
     $14 = tempRet0;
     $lpad$phi$index = $13;$lpad$phi$index5 = $14;
     break L1;
    }
   } while(0);
   $137 = HEAP32[$buffer>>2]|0;
   $138 = ($137|0)==(0|0);
   if ($138) {
    STACKTOP = sp;return;
   }
   $139 = HEAP32[$3>>2]|0;
   $140 = ($139|0)==($137|0);
   do {
    if ($140) {
     $154 = $137;
    } else {
     $142 = $139;
     while(1) {
      $141 = (($142) + -292|0);
      HEAP32[$3>>2] = $141;
      $143 = HEAP8[$141>>0]|0;
      $144 = $143 & 1;
      $145 = ($144<<24>>24)==(0);
      if ($145) {
       $147 = $141;
      } else {
       $148 = (($142) + -284|0);
       $149 = HEAP32[$148>>2]|0;
       HEAP32[$method$i>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$method$i+0>>2]|0;
       invoke_vii(2591,($149|0),($$byval_copy14|0));
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        label = 52;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$3>>2]|0;
       $147 = $$pre$i$i$i$i$i$i$i;
      }
      $146 = ($147|0)==($137|0);
      if ($146) {
       label = 53;
       break;
      } else {
       $142 = $147;
      }
     }
     if ((label|0) == 52) {
      $152 = ___cxa_find_matching_catch()|0;
      $153 = tempRet0;
      ___cxa_call_unexpected(($152|0));
      // unreachable;
     }
     else if ((label|0) == 53) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $154 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$invocation$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$invocation$i+0>>2]|0;
   invoke_vii(2591,($154|0),($$byval_copy14|0));
   $155 = __THREW__; __THREW__ = 0;
   $156 = $155&1;
   if ($156) {
    $157 = ___cxa_find_matching_catch()|0;
    $158 = tempRet0;
    ___cxa_call_unexpected(($157|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  $lpad$phi$index = $21;$lpad$phi$index5 = $22;
 }
 $23 = HEAP32[$buffer>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $25 = HEAP32[$3>>2]|0;
 $26 = ($25|0)==($23|0);
 do {
  if ($26) {
   $40 = $23;
  } else {
   $28 = $25;
   while(1) {
    $27 = (($28) + -292|0);
    HEAP32[$3>>2] = $27;
    $29 = HEAP8[$27>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if ($31) {
     $33 = $27;
    } else {
     $34 = (($28) + -284|0);
     $35 = HEAP32[$34>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($35|0),($$byval_copy14|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 14;
      break;
     }
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$3>>2]|0;
     $33 = $$pre$i$i$i$i$i$i$i3;
    }
    $32 = ($33|0)==($23|0);
    if ($32) {
     label = 15;
     break;
    } else {
     $28 = $33;
    }
   }
   if ((label|0) == 14) {
    $38 = ___cxa_find_matching_catch()|0;
    $39 = tempRet0;
    ___cxa_call_unexpected(($38|0));
    // unreachable;
   }
   else if ((label|0) == 15) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $40 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($40|0),($$byval_copy14|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  ___cxa_call_unexpected(($43|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$val$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$01$i = 0, $index$014 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($runtimeInfo) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 L1: do {
  if ($11) {
   label = 16;
  } else {
   __THREW__ = 0;
   invoke_vii(2873,($buffer|0),($10|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    label = 10;
   } else {
    $index$01$i = 0;
    while(1) {
     $14 = HEAP32[$8>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(2433,($14|0),($index$01$i|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     $$val$i = HEAP32[$15>>2]|0;
     $18 = ($$val$i|0)==(0|0);
     if (!($18)) {
      $19 = HEAP32[$buffer>>2]|0;
      $20 = (($19) + ($index$01$i<<4)|0);
      $21 = (($$val$i) + 8|0);
      $22 = HEAP32[$21>>2]|0;
      ;HEAP32[$20+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$22+12>>2]|0;
     }
     $23 = (($index$01$i) + 1)|0;
     $24 = ($23|0)==($10|0);
     if ($24) {
      label = 16;
      break L1;
     } else {
      $index$01$i = $23;
     }
    }
    $27 = ___cxa_find_matching_catch()|0;
    $28 = tempRet0;
    $lpad$phi$index = $27;$lpad$phi$index3 = $28;
   }
  }
 } while(0);
 L11: do {
  if ((label|0) == 16) {
   $42 = (($staticInfo) + 24|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0);
   if (!($44)) {
    __THREW__ = 0;
    invoke_vii(2669,($6|0),($43|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     label = 10;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3458,($6|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 10;
     break;
    }
   }
   $49 = HEAP32[$7>>2]|0;
   $50 = (($staticInfo) + 28|0);
   $51 = HEAP32[$50>>2]|0;
   __THREW__ = 0;
   invoke_viii(1804,($buffer|0),($49|0),($51|0));
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    label = 10;
   } else {
    $54 = HEAP32[$7>>2]|0;
    $55 = (($54) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($56|0)==(0);
    L18: do {
     if (!($57)) {
      $59 = $54;$index$014 = 0;
      while(1) {
       $58 = HEAP32[$59>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($58|0),($index$014|0))|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        break;
       }
       $62 = (($index$014) + 1)|0;
       $63 = HEAP32[$7>>2]|0;
       $64 = (($63) + 4|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = ($62|0)==($65|0);
       if ($66) {
        break L18;
       } else {
        $59 = $63;$index$014 = $62;
       }
      }
      $25 = ___cxa_find_matching_catch()|0;
      $26 = tempRet0;
      $lpad$phi$index = $25;$lpad$phi$index3 = $26;
      break L11;
     }
    } while(0);
    $67 = HEAP32[$buffer>>2]|0;
    $68 = ($67|0)==(0|0);
    if ($68) {
     STACKTOP = sp;return;
    }
    $69 = HEAP32[$1>>2]|0;
    $70 = ($69|0)==($67|0);
    if (!($70)) {
     $__new_last2$i$i$i$i$i$i$i = $67;
     $scevgep$i$i$i$i$i$i$i = (($69) + -16|0);
     $71 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($71)|0);
     $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
     $72 = $uglygep3$i$i$i$i$i$i$i >>> 4;
     $73 = $72 ^ -1;
     $scevgep4$i$i$i$i$i$i$i = (($69) + ($73<<4)|0);
     HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($67|0),($$byval_copy8|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     $76 = ___cxa_find_matching_catch()|0;
     $77 = tempRet0;
     ___cxa_call_unexpected(($76|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  $lpad$phi$index = $29;$lpad$phi$index3 = $30;
 }
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i2 = $31;
  $scevgep$i$i$i$i$i$i$i3 = (($33) + -16|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $36 = $uglygep3$i$i$i$i$i$i$i6 >>> 4;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($33) + ($37<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy8|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $buffer = 0, $index$04 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii(3082,($buffer|0),($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 3;
  } else {
   $27 = HEAP32[$5>>2]|0;
   $28 = (($staticInfo) + 28|0);
   $29 = HEAP32[$28>>2]|0;
   __THREW__ = 0;
   invoke_viii(1807,($buffer|0),($27|0),($29|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    label = 3;
   } else {
    $32 = HEAP32[$5>>2]|0;
    $33 = (($32) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0);
    L4: do {
     if (!($35)) {
      $37 = $32;$index$04 = 0;
      while(1) {
       $36 = HEAP32[$37>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($36|0),($index$04|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
       $40 = (($index$04) + 1)|0;
       $41 = HEAP32[$5>>2]|0;
       $42 = (($41) + 4|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = ($40|0)==($43|0);
       if ($44) {
        break L4;
       } else {
        $37 = $41;$index$04 = $40;
       }
      }
      $9 = ___cxa_find_matching_catch()|0;
      $10 = tempRet0;
      $lpad$phi$index = $9;$lpad$phi$index2 = $10;
      break L1;
     }
    } while(0);
    $45 = HEAP32[$buffer>>2]|0;
    $46 = ($45|0)==(0|0);
    if ($46) {
     STACKTOP = sp;return;
    }
    while(1) {
     $47 = HEAP32[$1>>2]|0;
     $48 = ($47|0)==($45|0);
     if ($48) {
      break;
     }
     $49 = (($47) + -68|0);
     HEAP32[$1>>2] = $49;
     __THREW__ = 0;
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 17;
      break;
     }
    }
    if ((label|0) == 17) {
     $52 = ___cxa_find_matching_catch()|0;
     $53 = tempRet0;
     ___cxa_call_unexpected(($52|0));
     // unreachable;
    }
    $54 = HEAP32[$buffer>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($54|0),($$byval_copy6|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     $57 = ___cxa_find_matching_catch()|0;
     $58 = tempRet0;
     ___cxa_call_unexpected(($57|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 while(1) {
  $15 = HEAP32[$1>>2]|0;
  $16 = ($15|0)==($13|0);
  if ($16) {
   break;
  }
  $17 = (($15) + -68|0);
  HEAP32[$1>>2] = $17;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  ___cxa_call_unexpected(($20|0));
  // unreachable;
 }
 $22 = HEAP32[$buffer>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($22|0),($$byval_copy6|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  ___cxa_call_unexpected(($25|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI17RemapPPtrTransfer27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $index$01$i = 0, $index$013 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii(3083,($buffer|0),($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 4;
  } else {
   $39 = HEAP32[$5>>2]|0;
   $40 = (($staticInfo) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = HEAP32[$1>>2]|0;
   $43 = HEAP32[$buffer>>2]|0;
   $44 = $42;
   $45 = $43;
   $46 = (($44) - ($45))|0;
   $47 = (($46|0) / 80)&-1;
   $48 = (($39) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==($47|0);
   if (!($50)) {
    __THREW__ = 0;
    $51 = (invoke_ii(3288,($41|0))|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $54 = (invoke_iiii(1554,($41|0),($51|0),($47|0))|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 4;
     break;
    }
    HEAP32[$39>>2] = $54;
    HEAP32[$48>>2] = $47;
   }
   $57 = ($42|0)==($43|0);
   L8: do {
    if (!($57)) {
     $58 = (($buffer) + 12|0);
     $index$01$i = 0;
     while(1) {
      $59 = HEAP32[$39>>2]|0;
      __THREW__ = 0;
      $60 = (invoke_iii(2433,($59|0),($index$01$i|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      $63 = HEAP32[$buffer>>2]|0;
      $64 = (($63) + (($index$01$i*80)|0)|0);
      __THREW__ = 0;
      invoke_viii(1798,($58|0),($64|0),($60|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
      $67 = (($index$01$i) + 1)|0;
      $68 = ($67|0)==($47|0);
      if ($68) {
       break L8;
      } else {
       $index$01$i = $67;
      }
     }
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index3 = $12;
     break L1;
    }
   } while(0);
   $69 = HEAP32[$5>>2]|0;
   $70 = (($69) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0);
   L16: do {
    if (!($72)) {
     $74 = $69;$index$013 = 0;
     while(1) {
      $73 = HEAP32[$74>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2433,($73|0),($index$013|0))|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       break;
      }
      $77 = (($index$013) + 1)|0;
      $78 = HEAP32[$5>>2]|0;
      $79 = (($78) + 4|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($77|0)==($80|0);
      if ($81) {
       break L16;
      } else {
       $74 = $78;$index$013 = $77;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $82 = HEAP32[$buffer>>2]|0;
   $83 = ($82|0)==(0|0);
   if ($83) {
    STACKTOP = sp;return;
   }
   $84 = HEAP32[$1>>2]|0;
   $85 = ($84|0)==($82|0);
   do {
    if ($85) {
     $101 = $82;
    } else {
     $87 = $84;
     while(1) {
      $86 = (($87) + -80|0);
      HEAP32[$1>>2] = $86;
      $88 = (($87) + -12|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($89|0)>(-1);
      if ($90) {
       $93 = (($87) + -24|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = (($87) + -20|0);
       $96 = HEAP32[$95>>2]|0;
       HEAP32[$0>>2] = $96;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($94|0),($$byval_copy10|0));
       $97 = __THREW__; __THREW__ = 0;
       $98 = $97&1;
       if ($98) {
        label = 35;
        break;
       }
       HEAP32[$93>>2] = 0;
       $$pre$i$i$i$i$i$i$i = HEAP32[$1>>2]|0;
       $92 = $$pre$i$i$i$i$i$i$i;
      } else {
       $92 = $86;
      }
      $91 = ($92|0)==($82|0);
      if ($91) {
       label = 36;
       break;
      } else {
       $87 = $92;
      }
     }
     if ((label|0) == 35) {
      $99 = ___cxa_find_matching_catch()|0;
      $100 = tempRet0;
      ___cxa_call_unexpected(($99|0));
      // unreachable;
     }
     else if ((label|0) == 36) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $101 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($101|0),($$byval_copy10|0));
   $102 = __THREW__; __THREW__ = 0;
   $103 = $102&1;
   if ($103) {
    $104 = ___cxa_find_matching_catch()|0;
    $105 = tempRet0;
    ___cxa_call_unexpected(($104|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 }
 $15 = HEAP32[$buffer>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ($17|0)==($15|0);
 do {
  if ($18) {
   $34 = $15;
  } else {
   $20 = $17;
   while(1) {
    $19 = (($20) + -80|0);
    HEAP32[$1>>2] = $19;
    $21 = (($20) + -12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)>(-1);
    if ($23) {
     $26 = (($20) + -24|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($20) + -20|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$0>>2] = $29;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($27|0),($$byval_copy10|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 12;
      break;
     }
     HEAP32[$26>>2] = 0;
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$1>>2]|0;
     $25 = $$pre$i$i$i$i$i$i$i3;
    } else {
     $25 = $19;
    }
    $24 = ($25|0)==($15|0);
    if ($24) {
     label = 13;
     break;
    } else {
     $20 = $25;
    }
   }
   if ((label|0) == 12) {
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $34 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy10|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z33EmitSerializationCommandsForFieldI18StreamedBinaryReadILb0EEEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$0$i$ph9 = 0, $$off = 0, $$ph = 0, $$ph8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $serializeFieldCommand = 0, $staticInfo$sroa$9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $staticInfo$sroa$9 = sp;
 $serializeFieldCommand = sp + 16|0;
 $1 = (($tfi) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z24scripting_class_get_typeP14ScriptingClass($2)|0);
 $4 = (__Z23scripting_type_get_typeP13ScriptingType($3)|0);
 $5 = ($4|0)==(29);
 if (!($5)) {
  $6 = (__ZN9Scripting30IsSystemCollectionsGenericListEP14ScriptingClass($2)|0);
  if (!($6)) {
   ;HEAP32[$staticInfo$sroa$9+0>>2]=0|0;HEAP32[$staticInfo$sroa$9+4>>2]=0|0;HEAP32[$staticInfo$sroa$9+8>>2]=0|0;
   $7 = HEAP32[$tfi>>2]|0;
   $8 = (__Z24scripting_field_get_nameP14ScriptingField($7)|0);
   $9 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $10 = (__Z25scripting_class_from_typeP13ScriptingType($9)|0);
   $11 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $12 = (__Z23scripting_type_get_typeP13ScriptingType($11)|0);
   $13 = (__Z26scripting_field_get_offsetP14ScriptingField($7)|0);
   $14 = (__Z24scripting_class_get_nameP14ScriptingClass($10)|0);
   $15 = (($tfi) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = (($tfi) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($tfi) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   L4: do {
    switch ($19|0) {
    case 2:  {
     $23 = $16 | 256;
     $$0$i$ph = 3087;$$ph = $23;
     label = 47;
     break;
    }
    case 8:  {
     $$0$i$ph = 3089;$$ph = $16;
     label = 47;
     break;
    }
    case 5:  {
     $$0$i$ph = 3087;$$ph = $16;
     label = 47;
     break;
    }
    case 14:  {
     $$0$i$ph = 3084;$$ph = $16;
     label = 47;
     break;
    }
    case 11:  {
     $$0$i$ph = 3092;$$ph = $16;
     label = 47;
     break;
    }
    case 3:  {
     $22 = $16 | 33554432;
     $$0$i$ph = 3085;$$ph = $22;
     label = 47;
     break;
    }
    case 4:  {
     $$0$i$ph = 3086;$$ph = $16;
     label = 47;
     break;
    }
    case 9:  {
     $$0$i$ph = 3090;$$ph = $16;
     label = 47;
     break;
    }
    case 10:  {
     $$0$i$ph = 3091;$$ph = $16;
     label = 47;
     break;
    }
    case 7:  {
     $$0$i$ph = 3085;$$ph = $16;
     label = 47;
     break;
    }
    case 13:  {
     $$0$i$ph = 3094;$$ph = $16;
     label = 47;
     break;
    }
    case 12:  {
     $$0$i$ph = 3093;$$ph = $16;
     label = 47;
     break;
    }
    case 6:  {
     $$0$i$ph = 3088;$$ph = $16;
     label = 47;
     break;
    }
    default: {
     $24 = (($21) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($17|0)==($25|0);
     if ($26) {
      $$0$i$ph = 3095;$$ph = $16;
      label = 47;
     } else {
      $27 = (($21) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($17|0)==($28|0);
      if ($29) {
       $$0$i$ph = 3096;$$ph = $16;
       label = 47;
      } else {
       $30 = (($21) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($17|0)==($31|0);
       if ($32) {
        $$0$i$ph = 3097;$$ph = $16;
        label = 47;
       } else {
        $33 = (($21) + 24|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = ($17|0)==($34|0);
        if ($35) {
         $$0$i$ph = 3098;$$ph = $16;
         label = 47;
        } else {
         $36 = (($21) + 32|0);
         $37 = HEAP32[$36>>2]|0;
         $38 = ($17|0)==($37|0);
         if ($38) {
          $$0$i$ph = 3099;$$ph = $16;
          label = 47;
         } else {
          $39 = (($21) + 36|0);
          $40 = HEAP32[$39>>2]|0;
          $41 = ($17|0)==($40|0);
          if ($41) {
           $$0$i$ph = 3100;$$ph = $16;
           label = 47;
          } else {
           $42 = (($21) + 40|0);
           $43 = HEAP32[$42>>2]|0;
           $44 = ($17|0)==($43|0);
           if ($44) {
            $$0$i$ph = 3101;$$ph = $16;
            label = 47;
           } else {
            $45 = (($21) + 52|0);
            $46 = HEAP32[$45>>2]|0;
            $47 = ($17|0)==($46|0);
            if ($47) {
             $$0$i$ph = 3102;$$ph = $16;
             label = 47;
            } else {
             $48 = (($21) + 56|0);
             $49 = HEAP32[$48>>2]|0;
             $50 = ($17|0)==($49|0);
             if ($50) {
              $$0$i$ph = 3103;$$ph = $16;
              label = 47;
             } else {
              $51 = (($21) + 88|0);
              $52 = HEAP32[$51>>2]|0;
              $53 = ($17|0)==($52|0);
              if ($53) {
               $$0$i$ph = 3104;$$ph = $16;
               label = 47;
              } else {
               $54 = (($21) + 492|0);
               $55 = HEAP32[$54>>2]|0;
               $56 = ($17|0)==($55|0);
               do {
                if (!($56)) {
                 $57 = (($21) + 496|0);
                 $58 = HEAP32[$57>>2]|0;
                 $59 = ($17|0)==($58|0);
                 if (!($59)) {
                  $60 = (__Z23scripting_class_is_enumP14ScriptingClass($17)|0);
                  if (!($60)) {
                   $85 = (($21) + 280|0);
                   $86 = HEAP32[$85>>2]|0;
                   $87 = ($17|0)==($86|0);
                   if ($87) {
                    $$0$i$ph = 3105;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $88 = (($21) + 504|0);
                   $89 = HEAP32[$88>>2]|0;
                   $90 = ($17|0)==($89|0);
                   if ($90) {
                    $$0$i$ph = 3106;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $91 = (($21) + 28|0);
                   $92 = HEAP32[$91>>2]|0;
                   $93 = ($17|0)==($92|0);
                   if ($93) {
                    $$0$i$ph = 3107;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $94 = (($21) + 272|0);
                   $95 = HEAP32[$94>>2]|0;
                   $96 = ($17|0)==($95|0);
                   if ($96) {
                    $$0$i$ph9 = 3108;$$ph8 = $16;
                    break L4;
                   }
                   $97 = ($19|0)==(18);
                   if (!($97)) {
                    break;
                   }
                   $98 = (($21) + 244|0);
                   $99 = HEAP32[$98>>2]|0;
                   $100 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($17,$99)|0);
                   if ($100) {
                    $$0$i$ph9 = 3109;$$ph8 = $16;
                    break L4;
                   } else {
                    break;
                   }
                  }
                  $61 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($17)|0);
                  $62 = (__Z23scripting_type_get_typeP13ScriptingType($61)|0);
                  if ((($62|0) == 8)) {
                   $$0$i$ph = 3089;$$ph = $16;
                   label = 47;
                   break L4;
                  } else if ((($62|0) == 5)) {
                   $$0$i$ph = 3087;$$ph = $16;
                   label = 47;
                   break L4;
                  }
                  $63 = HEAP32[$tfi>>2]|0;
                  __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$63);
                  $64 = HEAP8[$0>>0]|0;
                  $65 = $64 & 1;
                  $66 = ($65<<24>>24)==(0);
                  if ($66) {
                   $69 = (($0) + 1|0);
                   $70 = $69;
                  } else {
                   $67 = (($0) + 8|0);
                   $68 = HEAP32[$67>>2]|0;
                   $70 = $68;
                  }
                  __THREW__ = 0;
                  invoke_viiiiiiii(21,($70|0),0,(630440|0),188,1,0,0,(0|0));
                  $71 = __THREW__; __THREW__ = 0;
                  $72 = $71&1;
                  if (!($72)) {
                   $73 = HEAP8[$0>>0]|0;
                   $74 = $73 & 1;
                   $75 = ($74<<24>>24)==(0);
                   if ($75) {
                    break;
                   }
                   $76 = (($0) + 8|0);
                   $77 = HEAP32[$76>>2]|0;
                   __ZdlPv($77);
                   break;
                  }
                  $78 = ___cxa_find_matching_catch()|0;
                  $79 = tempRet0;
                  $80 = HEAP8[$0>>0]|0;
                  $81 = $80 & 1;
                  $82 = ($81<<24>>24)==(0);
                  if ($82) {
                   ___resumeException($78|0);
                   // unreachable;
                  }
                  $83 = (($0) + 8|0);
                  $84 = HEAP32[$83>>2]|0;
                  __ZdlPv($84);
                  ___resumeException($78|0);
                  // unreachable;
                 }
                }
               } while(0);
               $114 = HEAP32[$18>>2]|0;
               $$off = (($114) + -17)|0;
               $115 = ($$off>>>0)<(2);
               if (!($115)) {
                STACKTOP = sp;return;
               }
               __Z46EmitSerializationCommandsForManagedObjectFieldI18StreamedBinaryReadILb0EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
    }
   } while(0);
   if ((label|0) == 47) {
    $101 = (($tfi) + 25|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $$0$i$ph9 = $$0$i$ph;$$ph8 = $$ph;
    } else {
     STACKTOP = sp;return;
    }
   }
   dest=$serializeFieldCommand+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$serializeFieldCommand>>2] = $$0$i$ph9;
   $104 = (($serializeFieldCommand) + 4|0);
   HEAP32[$104>>2] = $7;
   $105 = (($serializeFieldCommand) + 8|0);
   HEAP32[$105>>2] = $8;
   $106 = (($serializeFieldCommand) + 12|0);
   HEAP32[$106>>2] = $14;
   $107 = (($serializeFieldCommand) + 16|0);
   HEAP32[$107>>2] = $10;
   $108 = (($serializeFieldCommand) + 20|0);
   HEAP32[$108>>2] = $12;
   $109 = (($serializeFieldCommand) + 24|0);
   HEAP32[$109>>2] = $13;
   $110 = (($serializeFieldCommand) + 28|0);
   HEAP32[$110>>2] = $$ph8;
   $111 = (($serializeFieldCommand) + 32|0);
   HEAP32[$111>>2] = $17;
   $112 = (($serializeFieldCommand) + 36|0);
   HEAP32[$112>>2] = $19;
   $113 = (($serializeFieldCommand) + 40|0);
   ;HEAP32[$113+0>>2]=HEAP32[$staticInfo$sroa$9+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[$staticInfo$sroa$9+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[$staticInfo$sroa$9+8>>2]|0;
   __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$serializeFieldCommand);
   STACKTOP = sp;return;
  }
 }
 __Z49EmitSerializationCommandsForLinearCollectionFieldI18StreamedBinaryReadILb0EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
 STACKTOP = sp;return;
}
function __ZL12InvokeMethodI18StreamedBinaryReadILb0EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $invocation = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $invocation = sp + 8|0;
 $0 = sp;
 $1 = (($args) + 56|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($args) + 48|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $15 = (($runtimeInfo) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($invocation) + 12|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP8[$runtimeInfo>>0]|0;
 $19 = (($invocation) + 24|0);
 HEAP8[$19>>0] = $18;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation)|0);
 STACKTOP = sp;return;
}
function __Z49EmitSerializationCommandsForLinearCollectionFieldI18StreamedBinaryReadILb0EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($info,$commandQueueBuilder,$nameConversions) {
 $info = $info|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$off = 0, $$ph = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $command = 0, $linearCollectionField = 0, $switch = 0, $tfi = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 184|0;
 $linearCollectionField = sp + 144|0;
 $1 = sp + 68|0;
 $tfi = sp;
 $command = sp + 80|0;
 $$sroa$9 = sp + 56|0;
 HEAP8[$1>>0] = 1;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$info>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$1,$4);
 dest=$tfi+0|0; src=$info+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = HEAP32[$info>>2]|0;
 HEAP32[$tfi>>2] = $5;
 $6 = (__ZN21LinearCollectionField15GetElementClassEv($linearCollectionField)|0);
 $7 = (($tfi) + 40|0);
 HEAP32[$7>>2] = $6;
 $8 = (__Z24scripting_class_get_typeP14ScriptingClass($6)|0);
 $9 = (__Z23scripting_type_get_typeP13ScriptingType($8)|0);
 $10 = (($tfi) + 44|0);
 HEAP32[$10>>2] = $9;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 dest=$command+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$command>>2] = 3110;
 ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
 $14 = (__Z24scripting_field_get_nameP14ScriptingField($5)|0);
 $15 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $16 = (__Z25scripting_class_from_typeP13ScriptingType($15)|0);
 $17 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $18 = (__Z23scripting_type_get_typeP13ScriptingType($17)|0);
 $19 = (__Z26scripting_field_get_offsetP14ScriptingField($5)|0);
 $20 = (__Z24scripting_class_get_nameP14ScriptingClass($16)|0);
 $21 = (($tfi) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($command) + 4|0);
 HEAP32[$23>>2] = $5;
 $24 = (($command) + 8|0);
 HEAP32[$24>>2] = $14;
 $25 = (($command) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($command) + 16|0);
 HEAP32[$26>>2] = $16;
 $27 = (($command) + 20|0);
 HEAP32[$27>>2] = $18;
 $28 = (($command) + 24|0);
 HEAP32[$28>>2] = $19;
 $29 = (($command) + 28|0);
 HEAP32[$29>>2] = $22;
 $30 = (($command) + 32|0);
 HEAP32[$30>>2] = $6;
 $31 = (($command) + 36|0);
 HEAP32[$31>>2] = $9;
 $32 = (($command) + 40|0);
 ;HEAP32[$32+0>>2]=HEAP32[$$sroa$9+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$$sroa$9+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$$sroa$9+8>>2]|0;
 $33 = (($tfi) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 L1: do {
  switch ($9|0) {
  case 12:  {
   $$0$i$ph = 3120;$$ph = 1;
   break;
  }
  case 13:  {
   $$0$i$ph = 3121;$$ph = 1;
   break;
  }
  case 2:  {
   $36 = $22 | 256;
   HEAP32[$29>>2] = $36;
   $$0$i$ph = 3114;$$ph = 1;
   break;
  }
  case 9:  {
   $$0$i$ph = 3117;$$ph = 1;
   break;
  }
  case 10:  {
   $$0$i$ph = 3118;$$ph = 1;
   break;
  }
  case 11:  {
   $$0$i$ph = 3119;$$ph = 1;
   break;
  }
  case 14:  {
   $$0$i$ph = 3111;$$ph = 1;
   break;
  }
  case 5:  {
   $$0$i$ph = 3114;$$ph = 1;
   break;
  }
  case 6:  {
   $$0$i$ph = 3115;$$ph = 1;
   break;
  }
  case 7:  {
   $$0$i$ph = 3112;$$ph = 1;
   break;
  }
  case 8:  {
   $$0$i$ph = 3116;$$ph = 1;
   break;
  }
  case 4:  {
   $$0$i$ph = 3113;$$ph = 1;
   break;
  }
  case 3:  {
   $35 = $22 | 33554432;
   HEAP32[$29>>2] = $35;
   $$0$i$ph = 3112;$$ph = 1;
   break;
  }
  default: {
   $37 = (($34) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($6|0)==($38|0);
   if ($39) {
    $$0$i$ph = 3122;$$ph = 1;
   } else {
    $40 = (($34) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($6|0)==($41|0);
    if ($42) {
     $$0$i$ph = 3123;$$ph = 1;
    } else {
     $43 = (($34) + 20|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($6|0)==($44|0);
     if ($45) {
      $$0$i$ph = 3124;$$ph = 1;
     } else {
      $46 = (($34) + 24|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($6|0)==($47|0);
      if ($48) {
       $$0$i$ph = 3125;$$ph = 1;
      } else {
       $49 = (($34) + 32|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($6|0)==($50|0);
       if ($51) {
        $$0$i$ph = 3126;$$ph = 1;
       } else {
        $52 = (($34) + 36|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($6|0)==($53|0);
        if ($54) {
         $$0$i$ph = 3127;$$ph = 1;
        } else {
         $55 = (($34) + 40|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($6|0)==($56|0);
         if ($57) {
          $$0$i$ph = 3128;$$ph = 1;
         } else {
          $58 = (($34) + 52|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = ($6|0)==($59|0);
          if ($60) {
           $$0$i$ph = 3129;$$ph = 1;
          } else {
           $61 = (($34) + 56|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = ($6|0)==($62|0);
           if ($63) {
            $$0$i$ph = 3130;$$ph = 1;
           } else {
            $64 = (($34) + 88|0);
            $65 = HEAP32[$64>>2]|0;
            $66 = ($6|0)==($65|0);
            if ($66) {
             $$0$i$ph = 3131;$$ph = 1;
            } else {
             $67 = (($34) + 492|0);
             $68 = HEAP32[$67>>2]|0;
             $69 = ($6|0)==($68|0);
             do {
              if ($69) {
               label = 44;
              } else {
               $70 = (($34) + 496|0);
               $71 = HEAP32[$70>>2]|0;
               $72 = ($6|0)==($71|0);
               if ($72) {
                label = 44;
               } else {
                $73 = (__Z23scripting_class_is_enumP14ScriptingClass($6)|0);
                if (!($73)) {
                 $97 = (($34) + 280|0);
                 $98 = HEAP32[$97>>2]|0;
                 $99 = ($6|0)==($98|0);
                 if ($99) {
                  $$0$i$ph = 3132;$$ph = 1;
                  break L1;
                 }
                 $100 = (($34) + 504|0);
                 $101 = HEAP32[$100>>2]|0;
                 $102 = ($6|0)==($101|0);
                 if ($102) {
                  $$0$i$ph = 3133;$$ph = 1;
                  break L1;
                 }
                 $103 = (($34) + 28|0);
                 $104 = HEAP32[$103>>2]|0;
                 $105 = ($6|0)==($104|0);
                 if ($105) {
                  $$0$i$ph = 3134;$$ph = 1;
                  break L1;
                 }
                 $106 = (($34) + 272|0);
                 $107 = HEAP32[$106>>2]|0;
                 $108 = ($6|0)==($107|0);
                 if ($108) {
                  $$0$i$ph = 3135;$$ph = 0;
                  break L1;
                 }
                 $109 = ($9|0)==(18);
                 if (!($109)) {
                  label = 44;
                  break;
                 }
                 $110 = (($34) + 244|0);
                 $111 = HEAP32[$110>>2]|0;
                 $112 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$111)|0);
                 if ($112) {
                  $$0$i$ph = 3136;$$ph = 0;
                  break L1;
                 } else {
                  break;
                 }
                }
                $74 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($6)|0);
                $75 = (__Z23scripting_type_get_typeP13ScriptingType($74)|0);
                if ((($75|0) == 8)) {
                 $$0$i$ph = 3116;$$ph = 1;
                 break L1;
                } else if ((($75|0) == 5)) {
                 $$0$i$ph = 3114;$$ph = 1;
                 break L1;
                }
                __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$5);
                $76 = HEAP8[$0>>0]|0;
                $77 = $76 & 1;
                $78 = ($77<<24>>24)==(0);
                if ($78) {
                 $81 = (($0) + 1|0);
                 $82 = $81;
                } else {
                 $79 = (($0) + 8|0);
                 $80 = HEAP32[$79>>2]|0;
                 $82 = $80;
                }
                __THREW__ = 0;
                invoke_viiiiiiii(21,($82|0),0,(630440|0),188,1,0,0,(0|0));
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if (!($84)) {
                 $85 = HEAP8[$0>>0]|0;
                 $86 = $85 & 1;
                 $87 = ($86<<24>>24)==(0);
                 if ($87) {
                  label = 44;
                  break;
                 }
                 $88 = (($0) + 8|0);
                 $89 = HEAP32[$88>>2]|0;
                 __ZdlPv($89);
                 label = 44;
                 break;
                }
                $90 = ___cxa_find_matching_catch()|0;
                $91 = tempRet0;
                $92 = HEAP8[$0>>0]|0;
                $93 = $92 & 1;
                $94 = ($93<<24>>24)==(0);
                if ($94) {
                 ___resumeException($90|0);
                 // unreachable;
                }
                $95 = (($0) + 8|0);
                $96 = HEAP32[$95>>2]|0;
                __ZdlPv($96);
                ___resumeException($90|0);
                // unreachable;
               }
              }
             } while(0);
             if ((label|0) == 44) {
              $$off = (($9) + -17)|0;
              $switch = ($$off>>>0)<(2);
              if (!($switch)) {
               STACKTOP = sp;return;
              }
             }
             __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI18StreamedBinaryReadILb0EEEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$command,$commandQueueBuilder,$nameConversions);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
  }
 } while(0);
 $113 = (($tfi) + 25|0);
 $114 = HEAP8[$113>>0]|0;
 $115 = $114 & $$ph;
 $116 = ($115<<24>>24)==(0);
 if (!($116)) {
  STACKTOP = sp;return;
 }
 $117 = (($command) + 44|0);
 HEAP32[$117>>2] = $$0$i$ph;
 __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$command);
 STACKTOP = sp;return;
}
function __Z46EmitSerializationCommandsForManagedObjectFieldI18StreamedBinaryReadILb0EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $args = 0, $newCommandQueueBuilder = 0, $serializeManagedObject = 0, $tfi$idx = 0, $tfi$idx$val = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy1 = sp + 124|0;
 $0 = sp + 120|0;
 $args = sp + 12|0;
 $newCommandQueueBuilder = sp + 32|0;
 $serializeManagedObject = sp + 56|0;
 $$sroa$9 = sp;
 $tfi$idx = (($tfi) + 4|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI18TransferField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$8>>2] = $13;
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 $14 = (($newCommandQueueBuilder) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($newCommandQueueBuilder) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($newCommandQueueBuilder) + 4|0);
 HEAP32[$16>>2] = 61;
 $17 = (($newCommandQueueBuilder) + 16|0);
 HEAP8[$17>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(381,($args|0),($newCommandQueueBuilder|0),($nameConversions|0),0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 do {
  if (!($19)) {
   $20 = (($tfi) + 25|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    label = 8;
   } else {
    $23 = HEAP32[$14>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    dest=$serializeManagedObject+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$serializeManagedObject>>2] = 3137;
    ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
    $33 = HEAP32[$tfi>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3280,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3276,($33|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3278,($37|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_ii(3276,($33|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    $46 = (invoke_ii(3277,($43|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    __THREW__ = 0;
    $49 = (invoke_ii(3283,($33|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    __THREW__ = 0;
    $52 = (invoke_ii(3284,($40|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    $55 = (($tfi) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$tfi$idx>>2]|0;
    $58 = (($tfi) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($serializeManagedObject) + 4|0);
    HEAP32[$60>>2] = $33;
    $61 = (($serializeManagedObject) + 8|0);
    HEAP32[$61>>2] = $34;
    $62 = (($serializeManagedObject) + 12|0);
    HEAP32[$62>>2] = $52;
    $63 = (($serializeManagedObject) + 16|0);
    HEAP32[$63>>2] = $40;
    $64 = (($serializeManagedObject) + 20|0);
    HEAP32[$64>>2] = $46;
    $65 = (($serializeManagedObject) + 24|0);
    HEAP32[$65>>2] = $49;
    $66 = (($serializeManagedObject) + 28|0);
    HEAP32[$66>>2] = $56;
    $67 = (($serializeManagedObject) + 32|0);
    HEAP32[$67>>2] = $57;
    $68 = (($serializeManagedObject) + 36|0);
    HEAP32[$68>>2] = $59;
    $69 = (($serializeManagedObject) + 40|0);
    $70 = $$sroa$9;
    $71 = $70;
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + 4)|0;
    $74 = $73;
    $75 = HEAP32[$74>>2]|0;
    $76 = $69;
    $77 = $76;
    HEAP32[$77>>2] = $72;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = $75;
    $80 = HEAP32[$14>>2]|0;
    $81 = (($serializeManagedObject) + 48|0);
    HEAP32[$81>>2] = $80;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($serializeManagedObject|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($newCommandQueueBuilder|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
   }
   $86 = HEAP32[$15>>2]|0;
   $87 = ($86|0)>(-1);
   if (!($87)) {
    STACKTOP = sp;return;
   }
   $88 = HEAP32[$newCommandQueueBuilder>>2]|0;
   $89 = HEAP32[$16>>2]|0;
   HEAP32[$0>>2] = $89;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($88,$$byval_copy1);
   HEAP32[$newCommandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$15>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$newCommandQueueBuilder>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $90 = ___cxa_find_matching_catch(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 }
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 ___resumeException($25|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $$phi$trans$insert1 = 0, $$phi$trans$insert3 = 0, $$pre = 0, $$pre$i = 0, $$pre2 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $managedObjectTransferer$sroa$2 = 0, $newProvider = 0, $runtimeInfo$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $runtimeInfo$i$i$i = sp + 32|0;
 $managedObjectTransferer$sroa$2 = sp + 56|0;
 $0 = sp + 20|0;
 $newProvider = sp;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP8[$managedObjectTransferer$sroa$2+0>>0]=0|0;HEAP8[$managedObjectTransferer$sroa$2+1>>0]=0|0;HEAP8[$managedObjectTransferer$sroa$2+2>>0]=0|0;
 $3 = (($runtimeInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = (($args) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(17);
 do {
  if ($5) {
   $$pre$i = (($args) + 12|0);
   if ($8) {
    $13 = 0;
   } else {
    $9 = HEAP32[$$pre$i>>2]|0;
    $10 = (_il2cpp_object_new($9)|0);
    $13 = $10;
   }
   $11 = HEAP32[$$pre$i>>2]|0;
   HEAP8[$0>>0] = 1;
   $12 = (($0) + 4|0);
   HEAP32[$12>>2] = $13;
   $14 = (($0) + 8|0);
   HEAP32[$14>>2] = $11;
   $41 = 1;$44 = $13;$46 = $11;
  } else {
   if ($8) {
    $15 = (($args) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP8[$runtimeInfo>>0]|0;
    $18 = ($17<<24>>24)!=(0);
    $19 = (($16) + -8)|0;
    $20 = $18 ? $16 : $19;
    $21 = (($4) + ($20)|0);
    $22 = (($args) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    HEAP8[$0>>0] = 0;
    $24 = (($0) + 4|0);
    HEAP32[$24>>2] = $21;
    $25 = (($0) + 8|0);
    HEAP32[$25>>2] = $23;
    $41 = 0;$44 = $21;$46 = $23;
    break;
   } else {
    $26 = HEAP32[$args>>2]|0;
    __Z30GetOrCreateObjectStoredInFieldP14ScriptingFieldRK17GeneralMonoObjectb($0,$26,$runtimeInfo,1);
    $$pre = HEAP8[$0>>0]|0;
    $$phi$trans$insert1 = (($0) + 4|0);
    $$pre2 = HEAP32[$$phi$trans$insert1>>2]|0;
    $$phi$trans$insert3 = (($0) + 8|0);
    $$pre4 = HEAP32[$$phi$trans$insert3>>2]|0;
    $41 = $$pre;$44 = $$pre2;$46 = $$pre4;
    break;
   }
  }
 } while(0);
 $27 = (($0) + 1|0);
 ;HEAP8[$managedObjectTransferer$sroa$2+0>>0]=HEAP8[$27+0>>0]|0;HEAP8[$managedObjectTransferer$sroa$2+1>>0]=HEAP8[$27+1>>0]|0;HEAP8[$managedObjectTransferer$sroa$2+2>>0]=HEAP8[$27+2>>0]|0;
 $28 = (($runtimeInfo) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($args) + 44|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + ($31<<6)|0);
 HEAP32[$32>>2] = $34;
 $35 = (($newProvider) + 4|0);
 HEAP32[$35>>2] = $33;
 HEAP32[$newProvider>>2] = $33;
 $36 = (($newProvider) + 8|0);
 HEAP32[$36>>2] = $34;
 $$idx$i = $31 << 6;
 $37 = $$idx$i >> 6;
 $38 = (($newProvider) + 16|0);
 HEAP32[$38>>2] = $37;
 $39 = (($newProvider) + 12|0);
 HEAP32[$39>>2] = $37;
 ;HEAP32[$runtimeInfo$i$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+20>>2]=0|0;
 $40 = (($runtimeInfo$i$i$i) + 16|0);
 HEAP32[$40>>2] = $2;
 HEAP8[$runtimeInfo$i$i$i>>0] = $41;
 $42 = (($runtimeInfo$i$i$i) + 1|0);
 ;HEAP8[$42+0>>0]=HEAP8[$managedObjectTransferer$sroa$2+0>>0]|0;HEAP8[$42+1>>0]=HEAP8[$managedObjectTransferer$sroa$2+1>>0]|0;HEAP8[$42+2>>0]=HEAP8[$managedObjectTransferer$sroa$2+2>>0]|0;
 $43 = (($runtimeInfo$i$i$i) + 4|0);
 HEAP32[$43>>2] = $44;
 $45 = (($runtimeInfo$i$i$i) + 8|0);
 HEAP32[$45>>2] = $46;
 $47 = (($runtimeInfo$i$i$i) + 12|0);
 HEAP32[$47>>2] = $newProvider;
 $48 = ($31|0)==(0);
 if ($48) {
  STACKTOP = sp;return;
 } else {
  $50 = $33;$52 = $34;
 }
 while(1) {
  $49 = (($50) + 64|0);
  HEAP32[$35>>2] = $49;
  $51 = $52;
  $53 = $49;
  $54 = (($51) - ($53))|0;
  $55 = $54 >> 6;
  HEAP32[$39>>2] = $55;
  $56 = HEAP32[$50>>2]|0;
  $57 = (($50) + 4|0);
  FUNCTION_TABLE_vii[$56 & 4095]($57,$runtimeInfo$i$i$i);
  $58 = HEAP32[$35>>2]|0;
  $59 = HEAP32[$36>>2]|0;
  $60 = ($58|0)==($59|0);
  if ($60) {
   break;
  } else {
   $50 = $58;$52 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 HEAP8[$converter>>0] = 0;
 __Z13TransferFieldI18StreamedBinaryReadILb0EELb0E16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,1);
  $20 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($20);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP8[$12>>0]|0;
  HEAP8[$8>>0] = $17;
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$11>>2] = $19;
  $20 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($20);
  STACKTOP = sp;return;
 }
}
function __Z22Transfer_Builtin_AlignIh18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,1);
  $20 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($20);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP8[$12>>0]|0;
  HEAP8[$8>>0] = $17;
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$11>>2] = $19;
  $20 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($20);
  STACKTOP = sp;return;
 }
}
function __Z22Transfer_Builtin_AlignIs18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 2|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,2);
  $18 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($18);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP16[$12>>1]|0;
  HEAP16[$8>>1] = $17;
  HEAP32[$11>>2] = $13;
  $18 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($18);
  STACKTOP = sp;return;
 }
}
function __Z22Transfer_Builtin_AlignIt18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 2|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,2);
  $18 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($18);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP16[$12>>1]|0;
  HEAP16[$8>>1] = $17;
  HEAP32[$11>>2] = $13;
  $18 = HEAP32[$9>>2]|0;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($18);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIi18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIj18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIx18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,8);
  STACKTOP = sp;return;
 } else {
  $17 = $12;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = $8;
  $24 = $23;
  HEAP32[$24>>2] = $19;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $22;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIy18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,8);
  STACKTOP = sp;return;
 } else {
  $17 = $12;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = $8;
  $24 = $23;
  HEAP32[$24>>2] = $19;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $22;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIf18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  STACKTOP = sp;return;
 } else {
  $17 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinId18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,8);
  STACKTOP = sp;return;
 } else {
  HEAP8[tempDoublePtr>>0]=HEAP8[$12>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$12+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$12+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$12+3>>0];HEAP8[tempDoublePtr+4>>0]=HEAP8[$12+4>>0];HEAP8[tempDoublePtr+5>>0]=HEAP8[$12+5>>0];HEAP8[tempDoublePtr+6>>0]=HEAP8[$12+6>>0];HEAP8[tempDoublePtr+7>>0]=HEAP8[$12+7>>0];$17 = +HEAPF64[tempDoublePtr>>3];
  HEAPF64[tempDoublePtr>>3]=$17;HEAP8[$8>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$8+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$8+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$8+3>>0]=HEAP8[tempDoublePtr+3>>0];HEAP8[$8+4>>0]=HEAP8[tempDoublePtr+4>>0];HEAP8[$8+5>>0]=HEAP8[tempDoublePtr+5>>0];HEAP8[$8+6>>0]=HEAP8[tempDoublePtr+6>>0];HEAP8[$8+7>>0]=HEAP8[tempDoublePtr+7>>0];
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 8|0);
  HEAP32[$11>>2] = $19;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8Vector3f18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $$pre3$i$i$i = HEAP32[$14>>2]|0;
  $20 = $$pre$i$i$i;$22 = $$pre3$i$i$i;
 } else {
  $17 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  $20 = $13;$22 = $15;
 }
 $$sum = (($5) + 4)|0;
 $18 = (($7) + ($$sum)|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)>($22>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$18,4);
  $$pre4$i$i$i = HEAP32[$11>>2]|0;
  $$pre5$i$i$i = HEAP32[$14>>2]|0;
  $26 = $$pre4$i$i$i;$28 = $$pre5$i$i$i;
 } else {
  $23 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$18>>2] = $23;
  HEAP32[$11>>2] = $19;
  $26 = $19;$28 = $22;
 }
 $$sum1 = (($5) + 8)|0;
 $24 = (($7) + ($$sum1)|0);
 $25 = (($26) + 4|0);
 $27 = ($25>>>0)>($28>>>0);
 if ($27) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$24,4);
  STACKTOP = sp;return;
 } else {
  $29 = Math_fround(HEAPF32[$26>>2]);
  HEAPF32[$24>>2] = $29;
  HEAP32[$11>>2] = $25;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8Vector2f18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $$pre2$i$i$i = HEAP32[$14>>2]|0;
  $20 = $$pre$i$i$i;$22 = $$pre2$i$i$i;
 } else {
  $17 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  $20 = $13;$22 = $15;
 }
 $$sum = (($5) + 4)|0;
 $18 = (($7) + ($$sum)|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)>($22>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$18,4);
  STACKTOP = sp;return;
 } else {
  $23 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$18>>2] = $23;
  HEAP32[$11>>2] = $19;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8Vector4f18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5RectTIfE8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN11Quaternionf8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN10Matrix4x4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN4AABB8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3218StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8BitField18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$8,4);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$8>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$native$i$i+0>>2]=0|0;HEAP32[$native$i$i+4>>2]=0|0;HEAP32[$native$i$i+8>>2]=0|0;HEAP32[$native$i$i+12>>2]=0|0;
 $2 = (($runtimeInfo) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb0EEEEvRT_($native$i$i,$3);
 $4 = (($args) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$runtimeInfo>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (($5) + -8)|0;
 $9 = $7 ? $5 : $8;
 $10 = (($runtimeInfo) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (_il2cpp_object_new($1)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($15);
  $17 = $15;
 } else {
  $17 = $13;
 }
 $16 = (($17) + 8|0);
 $18 = HEAP32[$16>>2]|0;
 ;HEAP32[$18+0>>2]=HEAP32[$native$i$i+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$native$i$i+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$native$i$i+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$native$i$i+12>>2]|0;
 $19 = HEAP32[$4>>2]|0;
 $20 = HEAP8[$runtimeInfo>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = (($19) + -8)|0;
 $23 = $21 ? $19 : $22;
 $24 = HEAP32[$10>>2]|0;
 $25 = (($24) + ($23)|0);
 HEAP32[$25>>2] = $17;
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$native$i$i>>2] = 0;
 $5 = (($native$i$i) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($native$i$i) + 8|0);
 HEAP32[$6>>2] = 0;
 __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($native$i$i,$1);
 $7 = HEAP32[$native$i$i>>2]|0;
 $8 = (__Z24TransferPPtrToMonoObjectiP14ScriptingClassP23DataToCreateNullWrapper24TransferInstructionFlags($7,$3,0,$4)|0);
 $9 = (($args) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP8[$runtimeInfo>>0]|0;
 $12 = ($11<<24>>24)!=(0);
 $13 = (($10) + -8)|0;
 $14 = $12 ? $10 : $13;
 $15 = (($runtimeInfo) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14)|0);
 HEAP32[$17>>2] = $8;
 STACKTOP = sp;return;
}
function __Z22TransferField_NonArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $invocation$i = 0, $method$i = 0, $native = 0, $scripting1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy1 = sp + 352|0;
 $method$i = sp;
 $invocation$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 48|0;
 $native = sp + 52|0;
 $scripting1 = sp + 344|0;
 __ZN8GUIStyleC2Ev($native);
 $2 = (($runtimeInfo) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vii(3138,($native|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $17 = (($staticInfo) + 20|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP8[$runtimeInfo>>0]|0;
   $20 = ($19<<24>>24)!=(0);
   $21 = (($18) + -8)|0;
   $22 = $20 ? $18 : $21;
   $23 = (($runtimeInfo) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + ($22)|0);
   $26 = HEAP32[$25>>2]|0;
   HEAP32[$scripting1>>2] = $26;
   __THREW__ = 0;
   invoke_viii(1797,($converter|0),($native|0),($scripting1|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[$17>>2]|0;
    $30 = HEAP8[$runtimeInfo>>0]|0;
    $31 = ($30<<24>>24)!=(0);
    $32 = (($29) + -8)|0;
    $33 = $31 ? $29 : $32;
    $34 = HEAP32[$23>>2]|0;
    $35 = (($34) + ($33)|0);
    $36 = HEAP32[$scripting1>>2]|0;
    HEAP32[$35>>2] = $36;
    __THREW__ = 0;
    $37 = (invoke_i(84)|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     $40 = (($37) + 308|0);
     $41 = HEAP32[$40>>2]|0;
     __THREW__ = 0;
     invoke_viiii(388,($method$i|0),($41|0),(630336|0),1);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      $44 = HEAP32[$method$i>>2]|0;
      $45 = ($44|0)==(0|0);
      if (!($45)) {
       $46 = $method$i;
       $47 = $46;
       $48 = HEAP32[$47>>2]|0;
       $49 = (($46) + 4)|0;
       $50 = $49;
       $51 = HEAP32[$50>>2]|0;
       $52 = $0;
       $53 = $52;
       HEAP32[$53>>2] = $48;
       $54 = (($52) + 4)|0;
       $55 = $54;
       HEAP32[$55>>2] = $51;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;
       invoke_vii(2863,($invocation$i|0),($$byval_copy1|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       $58 = (($invocation$i) + 12|0);
       HEAP32[$58>>2] = $36;
       __THREW__ = 0;
       (invoke_ii(3285,($invocation$i|0))|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
      }
      $61 = HEAP8[$native>>0]|0;
      $62 = $61 & 1;
      $63 = ($62<<24>>24)==(0);
      if ($63) {
       STACKTOP = sp;return;
      }
      $64 = (($native) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      HEAP32[$method$i>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$method$i+0>>2]|0;
      invoke_vii(2591,($65|0),($$byval_copy1|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       $68 = ___cxa_find_matching_catch()|0;
       $69 = tempRet0;
       ___cxa_call_unexpected(($68|0));
       // unreachable;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $8 = HEAP8[$native>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  ___resumeException($6|0);
  // unreachable;
 }
 $11 = (($native) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($12|0),($$byval_copy1|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  ___cxa_call_unexpected(($15|0));
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
}
function __ZN8GUIStyle8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre2$i$i$i = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre9 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 16|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($1,$transfer);
 $2 = (($this) + 32|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($2,$transfer);
 $3 = (($this) + 36|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($3,$transfer);
 $4 = (($this) + 52|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($4,$transfer);
 $5 = (($this) + 56|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($5,$transfer);
 $6 = (($this) + 72|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($6,$transfer);
 $7 = (($this) + 76|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($7,$transfer);
 $8 = (($this) + 92|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 96|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($9,$transfer);
 $10 = (($this) + 112|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 116|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($11,$transfer);
 $12 = (($this) + 132|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($12,$transfer);
 $13 = (($this) + 136|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($13,$transfer);
 $14 = (($this) + 152|0);
 __ZN4PPtrI9Texture2DE8TransferI18StreamedBinaryReadILb0EEEEvRT_($14,$transfer);
 $15 = (($this) + 156|0);
 __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($15,$transfer);
 $16 = (($this) + 172|0);
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb0EEEEvRT_($16,$transfer);
 $17 = (($this) + 188|0);
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb0EEEEvRT_($17,$transfer);
 $18 = (($this) + 204|0);
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb0EEEEvRT_($18,$transfer);
 $19 = (($this) + 220|0);
 __ZN10RectOffset8TransferI18StreamedBinaryReadILb0EEEEvRT_($19,$transfer);
 $20 = (($this) + 236|0);
 __ZN4PPtrIN13TextRendering4FontEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($20,$transfer);
 $21 = (($this) + 280|0);
 $22 = (($transfer) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 4|0);
 $25 = (($transfer) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24>>>0)>($26>>>0);
 if ($27) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$21,4);
  $$pre = HEAP32[$22>>2]|0;
  $$pre9 = HEAP32[$25>>2]|0;
  $31 = $$pre;$33 = $$pre9;
 } else {
  $28 = HEAP32[$23>>2]|0;
  HEAP32[$21>>2] = $28;
  HEAP32[$22>>2] = $24;
  $31 = $24;$33 = $26;
 }
 $29 = (($this) + 284|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$29,4);
  $$pre10 = HEAP32[$22>>2]|0;
  $$pre11 = HEAP32[$25>>2]|0;
  $37 = $$pre10;$39 = $$pre11;
 } else {
  $34 = HEAP32[$31>>2]|0;
  HEAP32[$29>>2] = $34;
  HEAP32[$22>>2] = $30;
  $37 = $30;$39 = $33;
 }
 $35 = (($this) + 240|0);
 $36 = (($37) + 4|0);
 $38 = ($36>>>0)>($39>>>0);
 if ($38) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$35,4);
  $$pre12 = HEAP32[$22>>2]|0;
  $$pre13 = HEAP32[$25>>2]|0;
  $43 = $$pre12;$45 = $$pre13;
 } else {
  $40 = HEAP32[$37>>2]|0;
  HEAP32[$35>>2] = $40;
  HEAP32[$22>>2] = $36;
  $43 = $36;$45 = $39;
 }
 $41 = (($this) + 244|0);
 $42 = (($43) + 1|0);
 $44 = ($42>>>0)>($45>>>0);
 if ($44) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$41,1);
  $$pre14 = HEAP32[$22>>2]|0;
  $51 = $$pre14;
 } else {
  $46 = HEAP8[$43>>0]|0;
  HEAP8[$41>>0] = $46;
  $47 = HEAP32[$22>>2]|0;
  $48 = (($47) + 1|0);
  HEAP32[$22>>2] = $48;
  $51 = $48;
 }
 $49 = (($this) + 245|0);
 $50 = (($51) + 1|0);
 $52 = HEAP32[$25>>2]|0;
 $53 = ($50>>>0)>($52>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$49,1);
 } else {
  $54 = HEAP8[$51>>0]|0;
  HEAP8[$49>>0] = $54;
  $55 = HEAP32[$22>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$22>>2] = $56;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $57 = (($this) + 248|0);
 $58 = HEAP32[$22>>2]|0;
 $59 = (($58) + 4|0);
 $60 = HEAP32[$25>>2]|0;
 $61 = ($59>>>0)>($60>>>0);
 if ($61) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$57,4);
  $$pre15 = HEAP32[$22>>2]|0;
  $$pre16 = HEAP32[$25>>2]|0;
  $65 = $$pre15;$67 = $$pre16;
 } else {
  $62 = HEAP32[$58>>2]|0;
  HEAP32[$57>>2] = $62;
  HEAP32[$22>>2] = $59;
  $65 = $59;$67 = $60;
 }
 $63 = (($this) + 252|0);
 $64 = (($65) + 4|0);
 $66 = ($64>>>0)>($67>>>0);
 if ($66) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$63,4);
  $$pre17 = HEAP32[$22>>2]|0;
  $$pre18 = HEAP32[$25>>2]|0;
  $71 = $$pre17;$73 = $$pre18;
 } else {
  $68 = HEAP32[$65>>2]|0;
  HEAP32[$63>>2] = $68;
  HEAP32[$22>>2] = $64;
  $71 = $64;$73 = $67;
 }
 $69 = (($this) + 256|0);
 $70 = (($71) + 4|0);
 $72 = ($70>>>0)>($73>>>0);
 if ($72) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$69,4);
  $$pre$i$i$i = HEAP32[$22>>2]|0;
  $$pre2$i$i$i = HEAP32[$25>>2]|0;
  $77 = $$pre$i$i$i;$79 = $$pre2$i$i$i;
 } else {
  $74 = Math_fround(HEAPF32[$71>>2]);
  HEAPF32[$69>>2] = $74;
  HEAP32[$22>>2] = $70;
  $77 = $70;$79 = $73;
 }
 $75 = (($this) + 260|0);
 $76 = (($77) + 4|0);
 $78 = ($76>>>0)>($79>>>0);
 if ($78) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$75,4);
  $$pre19 = HEAP32[$22>>2]|0;
  $$pre20 = HEAP32[$25>>2]|0;
  $83 = $$pre19;$85 = $$pre20;
 } else {
  $80 = Math_fround(HEAPF32[$77>>2]);
  HEAPF32[$75>>2] = $80;
  HEAP32[$22>>2] = $76;
  $83 = $76;$85 = $79;
 }
 $81 = (($this) + 272|0);
 $82 = (($83) + 4|0);
 $84 = ($82>>>0)>($85>>>0);
 if ($84) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$81,4);
  $$pre21 = HEAP32[$22>>2]|0;
  $$pre22 = HEAP32[$25>>2]|0;
  $89 = $$pre21;$91 = $$pre22;
 } else {
  $86 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$81>>2] = $86;
  HEAP32[$22>>2] = $82;
  $89 = $82;$91 = $85;
 }
 $87 = (($this) + 276|0);
 $88 = (($89) + 4|0);
 $90 = ($88>>>0)>($91>>>0);
 if ($90) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$87,4);
  $$pre23 = HEAP32[$22>>2]|0;
  $$pre24 = HEAP32[$25>>2]|0;
  $95 = $$pre23;$97 = $$pre24;
 } else {
  $92 = Math_fround(HEAPF32[$89>>2]);
  HEAPF32[$87>>2] = $92;
  HEAP32[$22>>2] = $88;
  $95 = $88;$97 = $91;
 }
 $93 = (($this) + 288|0);
 $94 = (($95) + 1|0);
 $96 = ($94>>>0)>($97>>>0);
 if ($96) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$93,1);
  $$pre25 = HEAP32[$22>>2]|0;
  $103 = $$pre25;
 } else {
  $98 = HEAP8[$95>>0]|0;
  HEAP8[$93>>0] = $98;
  $99 = HEAP32[$22>>2]|0;
  $100 = (($99) + 1|0);
  HEAP32[$22>>2] = $100;
  $103 = $100;
 }
 $101 = (($this) + 289|0);
 $102 = (($103) + 1|0);
 $104 = HEAP32[$25>>2]|0;
 $105 = ($102>>>0)>($104>>>0);
 if ($105) {
  __ZN12CachedReader15UpdateReadCacheEPvj($22,$101,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $106 = HEAP8[$103>>0]|0;
  HEAP8[$101>>0] = $106;
  $107 = HEAP32[$22>>2]|0;
  $108 = (($107) + 1|0);
  HEAP32[$22>>2] = $108;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrIN13TextRendering4FontEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN10RectOffset8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __Z22TransferField_NonArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $native = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $native = sp;
 __ZN11GradientNEWC2Ev($native);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(3139,($native|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $8 = (($staticInfo) + 20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP8[$runtimeInfo>>0]|0;
   $11 = ($10<<24>>24)!=(0);
   $12 = (($9) + -8)|0;
   $13 = $11 ? $9 : $12;
   $14 = (($runtimeInfo) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + ($13)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $19 = HEAP32[$converter>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_ii(3286,($19|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3549,($20|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    } else {
     $26 = $20;
    }
   } else {
    $26 = $17;
   }
   $25 = (($26) + 8|0);
   $27 = HEAP32[$25>>2]|0;
   $28 = HEAP32[$native>>2]|0;
   HEAP32[$27>>2] = $28;
   $29 = (($27) + 4|0);
   $30 = (($native) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[$29>>2] = $31;
   $32 = (($27) + 8|0);
   $33 = (($native) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   HEAP32[$32>>2] = $34;
   $35 = (($27) + 12|0);
   $36 = (($native) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$35>>2] = $37;
   $38 = (($27) + 16|0);
   $39 = (($native) + 16|0);
   $40 = HEAP32[$39>>2]|0;
   HEAP32[$38>>2] = $40;
   $41 = (($27) + 20|0);
   $42 = (($native) + 20|0);
   $43 = HEAP32[$42>>2]|0;
   HEAP32[$41>>2] = $43;
   $44 = (($27) + 24|0);
   $45 = (($native) + 24|0);
   $46 = HEAP32[$45>>2]|0;
   HEAP32[$44>>2] = $46;
   $47 = (($27) + 28|0);
   $48 = (($native) + 28|0);
   $49 = HEAP32[$48>>2]|0;
   HEAP32[$47>>2] = $49;
   $50 = (($27) + 32|0);
   $51 = (($native) + 32|0);
   dest=$50+0|0; src=$51+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
   $52 = HEAP32[$8>>2]|0;
   $53 = HEAP8[$runtimeInfo>>0]|0;
   $54 = ($53<<24>>24)!=(0);
   $55 = (($52) + -8)|0;
   $56 = $54 ? $52 : $55;
   $57 = HEAP32[$14>>2]|0;
   $58 = (($57) + ($56)|0);
   HEAP32[$58>>2] = $26;
   STACKTOP = sp;return;
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __THREW__ = 0;
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $59 = ___cxa_find_matching_catch(0|0)|0;
  $60 = tempRet0;
  ___clang_call_terminate($59);
  // unreachable;
 } else {
  ___resumeException($4|0);
  // unreachable;
 }
}
function __Z22TransferField_NonArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $native = 0, $scripting1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 92|0;
 $0 = sp;
 $native = sp + 8|0;
 $scripting1 = sp + 88|0;
 $1 = (($native) + 4|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 HEAP32[$native>>2] = 0;
 $2 = (($native) + 8|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $3 = (($native) + 32|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($native) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($native) + 36|0);
 $6 = (($native) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($native) + 68|0);
 HEAP32[$7>>2] = 0;
 $8 = (($native) + 60|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$8>>2] = 61;
 $9 = (($native) + 76|0);
 HEAP32[$9>>2] = 2;
 $10 = (($native) + 72|0);
 HEAP32[$10>>2] = 2;
 $11 = (($runtimeInfo) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($native) + 56|0);
 __THREW__ = 0;
 invoke_viii(1879,($12|0),($13|0),0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 do {
  if (!($15)) {
   $16 = (($12) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 4|0);
   $19 = (($12) + 20|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($18>>>0)>($20>>>0);
   if ($21) {
    __THREW__ = 0;
    invoke_viii(1748,($16|0),($10|0),4);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $$pre$i$i$i = HEAP32[$16>>2]|0;
    $$pre2$i$i$i = HEAP32[$19>>2]|0;
    $26 = $$pre$i$i$i;$28 = $$pre2$i$i$i;
   } else {
    $22 = HEAP32[$17>>2]|0;
    HEAP32[$10>>2] = $22;
    HEAP32[$16>>2] = $18;
    $26 = $18;$28 = $20;
   }
   $25 = (($26) + 4|0);
   $27 = ($25>>>0)>($28>>>0);
   if ($27) {
    __THREW__ = 0;
    invoke_viii(1748,($16|0),($9|0),4);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
   } else {
    $29 = HEAP32[$26>>2]|0;
    HEAP32[$9>>2] = $29;
    HEAP32[$16>>2] = $25;
   }
   __THREW__ = 0;
   invoke_vi(3552,($native|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    $43 = (($staticInfo) + 20|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = HEAP8[$runtimeInfo>>0]|0;
    $46 = ($45<<24>>24)!=(0);
    $47 = (($44) + -8)|0;
    $48 = $46 ? $44 : $47;
    $49 = (($runtimeInfo) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + ($48)|0);
    $52 = HEAP32[$51>>2]|0;
    HEAP32[$scripting1>>2] = $52;
    __THREW__ = 0;
    invoke_viii(1798,($converter|0),($native|0),($scripting1|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     $55 = HEAP32[$43>>2]|0;
     $56 = HEAP8[$runtimeInfo>>0]|0;
     $57 = ($56<<24>>24)!=(0);
     $58 = (($55) + -8)|0;
     $59 = $57 ? $55 : $58;
     $60 = HEAP32[$49>>2]|0;
     $61 = (($60) + ($59)|0);
     $62 = HEAP32[$scripting1>>2]|0;
     HEAP32[$61>>2] = $62;
     $63 = HEAP32[$7>>2]|0;
     $64 = ($63|0)>(-1);
     if (!($64)) {
      STACKTOP = sp;return;
     }
     $65 = (($native) + 56|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = HEAP32[$8>>2]|0;
     HEAP32[$0>>2] = $67;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($66,$$byval_copy1);
     HEAP32[$65>>2] = 0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 $36 = HEAP32[$7>>2]|0;
 $37 = ($36|0)>(-1);
 if (!($37)) {
  ___resumeException($34|0);
  // unreachable;
 }
 $38 = (($native) + 56|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $40;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($39|0),($$byval_copy1|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $68 = ___cxa_find_matching_catch(0|0)|0;
  $69 = tempRet0;
  ___clang_call_terminate($68);
  // unreachable;
 }
 HEAP32[$38>>2] = 0;
 ___resumeException($34|0);
 // unreachable;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplIfELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplIfELj4EEE19ResizeSTLStyleArrayERS3_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$size1>>2]|0;
  $36 = ($35|0)==(0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $37 = HEAP32[$data>>2]|0;
  $38 = $35 << 4;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$37,$38);
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre2 = HEAP32[$3>>2]|0;
  $$pre3 = HEAP32[$9>>2]|0;
  $14 = $$pre2;$16 = $$pre3;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre4 = HEAP32[$offset>>2]|0;
  $20 = $$pre4;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 4;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 4;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __Z13TransferFieldI18StreamedBinaryReadILb0EELb0E16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $native$i = sp + 4|0;
 ;HEAP32[$native$i+0>>2]=0|0;HEAP32[$native$i+4>>2]=0|0;HEAP32[$native$i+8>>2]=0|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_viii(1622,($2|0),($native$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3376,($2|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $18 = HEAP8[$native$i>>0]|0;
   $19 = $18 & 1;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $23 = (($native$i) + 1|0);
    $24 = $23;
   } else {
    $21 = (($native$i) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $24 = $22;
   }
   __THREW__ = 0;
   $25 = (invoke_ii(3287,($24|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = (($staticInfo) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = HEAP8[$runtimeInfo>>0]|0;
    $31 = ($30<<24>>24)!=(0);
    $32 = (($29) + -8)|0;
    $33 = $31 ? $29 : $32;
    $34 = (($runtimeInfo) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + ($33)|0);
    HEAP32[$36>>2] = $25;
    $37 = HEAP8[$native$i>>0]|0;
    $38 = $37 & 1;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     STACKTOP = sp;return;
    }
    $40 = (($native$i) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($41|0),($$byval_copy1|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     $44 = ___cxa_find_matching_catch()|0;
     $45 = tempRet0;
     ___cxa_call_unexpected(($44|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $9 = HEAP8[$native$i>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  ___resumeException($7|0);
  // unreachable;
 }
 $12 = (($native$i) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  ___cxa_call_unexpected(($16|0));
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __Z30TransferField_LinearCollectionI18StreamedBinaryReadILb0EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $array = 0, $linearCollectionField = 0, $newRuntimeInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $linearCollectionField = sp + 40|0;
 $array = sp;
 $0 = sp + 8|0;
 $newRuntimeInfo = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$runtimeInfo,$1);
 HEAP32[$array>>2] = 0;
 $2 = (($array) + 4|0);
 HEAP32[$2>>2] = -1;
 $3 = (($runtimeInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $18 = 0;
 } else {
  __ZN21LinearCollectionField8GetArrayEv($0,$linearCollectionField);
  $6 = $0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $array;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  $$pre = HEAP32[$3>>2]|0;
  $18 = $$pre;
 }
 $16 = HEAP8[$runtimeInfo>>0]|0;
 HEAP8[$newRuntimeInfo>>0] = $16;
 $17 = (($newRuntimeInfo) + 4|0);
 HEAP32[$17>>2] = $18;
 $19 = (($newRuntimeInfo) + 8|0);
 $20 = (($runtimeInfo) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = (($newRuntimeInfo) + 12|0);
 $23 = (($runtimeInfo) + 12|0);
 $24 = $23;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $22;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (($newRuntimeInfo) + 20|0);
 HEAP32[$34>>2] = $array;
 $35 = (($args) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($args,$newRuntimeInfo);
 $37 = HEAP32[$2>>2]|0;
 $38 = ($37|0)==(-1);
 if ($38) {
  STACKTOP = sp;return;
 }
 __ZN21LinearCollectionField8SetArrayERK9ArrayInfo($linearCollectionField,$array);
 STACKTOP = sp;return;
}
function __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI18StreamedBinaryReadILb0EEEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$partiallySetuplinearCollectionCommand,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $partiallySetuplinearCollectionCommand = $partiallySetuplinearCollectionCommand|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandQueueForSingleElement = 0, $or$cond = 0, $tfi$idx = 0, $tfi$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 44|0;
 $0 = sp;
 $args = sp + 4|0;
 $commandQueueForSingleElement = sp + 24|0;
 $tfi$idx = (($tfi) + 40|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI23TransferArrayField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$8>>2] = $12;
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 $13 = (($commandQueueForSingleElement) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($commandQueueForSingleElement) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($commandQueueForSingleElement) + 4|0);
 HEAP32[$15>>2] = 61;
 $16 = (($commandQueueForSingleElement) + 16|0);
 HEAP8[$16>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(381,($args|0),($commandQueueForSingleElement|0),($nameConversions|0),0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = (($tfi) + 25|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)!=(0);
   $$pre = HEAP32[$13>>2]|0;
   $22 = ($$pre|0)==(0);
   $or$cond = $21 & $22;
   if (!($or$cond)) {
    $31 = (($partiallySetuplinearCollectionCommand) + 44|0);
    HEAP32[$31>>2] = 3140;
    $32 = (($partiallySetuplinearCollectionCommand) + 48|0);
    HEAP32[$32>>2] = $$pre;
    $33 = HEAP32[$tfi$idx>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3284,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = (($partiallySetuplinearCollectionCommand) + 40|0);
    HEAP32[$37>>2] = $34;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($partiallySetuplinearCollectionCommand|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($commandQueueForSingleElement|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
   }
   $42 = HEAP32[$14>>2]|0;
   $43 = ($42|0)>(-1);
   if (!($43)) {
    STACKTOP = sp;return;
   }
   $44 = HEAP32[$commandQueueForSingleElement>>2]|0;
   $45 = HEAP32[$15>>2]|0;
   HEAP32[$0>>2] = $45;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($44,$$byval_copy1);
   HEAP32[$commandQueueForSingleElement>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$14>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$commandQueueForSingleElement>>2]|0;
 $28 = HEAP32[$15>>2]|0;
 HEAP32[$0>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $46 = ___cxa_find_matching_catch(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 }
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arrayOfManagedObjectsTransferer = 0, $newProvider = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $arrayOfManagedObjectsTransferer = sp;
 $newProvider = sp + 12|0;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $arrayOfManagedObjectsTransferer;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$arrayOfManagedObjectsTransferer>>2] = $7;
 $8 = (($args) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($arrayOfManagedObjectsTransferer) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = (($runtimeInfo) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14<<6)|0);
 HEAP32[$15>>2] = $17;
 $18 = (($newProvider) + 4|0);
 HEAP32[$18>>2] = $16;
 HEAP32[$newProvider>>2] = $16;
 $19 = (($newProvider) + 8|0);
 HEAP32[$19>>2] = $17;
 $$idx$i = $14 << 6;
 $20 = $$idx$i >> 6;
 $21 = (($newProvider) + 16|0);
 HEAP32[$21>>2] = $20;
 $22 = (($newProvider) + 12|0);
 HEAP32[$22>>2] = $20;
 $23 = (($arrayOfManagedObjectsTransferer) + 8|0);
 HEAP32[$23>>2] = $newProvider;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($1,$arrayOfManagedObjectsTransferer,0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $$sroa$1$i = 0, $$sroa$12$i = 0, $$sroa$2 = 0, $$sroa$8 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i = 0;
 var $instance$0$i = 0, $offset = 0, $size = 0, $size1 = 0, $storemerge = 0, $storemerge5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$sroa$12$i = sp + 72|0;
 $$sroa$1$i = sp + 102|0;
 $offset = sp + 56|0;
 $size = sp + 60|0;
 $size1 = sp + 64|0;
 $i = sp;
 $$sroa$2 = sp + 96|0;
 $$sroa$8 = sp + 99|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $24 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $24 = $19;
 }
 $20 = HEAP32[$data>>2]|0;
 $21 = (($20) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==($24|0);
 $$pre12 = (($data) + 4|0);
 if ($23) {
  $54 = $20;
 } else {
  $25 = HEAP32[$$pre12>>2]|0;
  $26 = (__Z34scripting_class_array_element_sizeP14ScriptingClass($25)|0);
  $27 = HEAP32[$$pre12>>2]|0;
  $28 = (__Z19scripting_array_newP14ScriptingClassjj($27,$26,$24)|0);
  $29 = HEAP32[$data>>2]|0;
  HEAP32[$29>>2] = $28;
  $30 = HEAP32[$data>>2]|0;
  $31 = (($30) + 4|0);
  HEAP32[$31>>2] = $24;
  $54 = $30;
 }
 $32 = (($i) + 24|0);
 HEAP8[$32>>0] = 1;
 $33 = (($i) + 28|0);
 HEAP32[$33>>2] = 0;
 $34 = (($i) + 32|0);
 HEAP32[$34>>2] = 0;
 $35 = (($i) + 40|0);
 HEAP32[$35>>2] = 0;
 $36 = (($i) + 44|0);
 HEAP32[$36>>2] = 0;
 $37 = HEAP32[$$pre12>>2]|0;
 $38 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($37)|0);
 $39 = $38&1;
 $40 = HEAP32[$data>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (__Z26scripting_object_get_classP15ScriptingObject($41)|0);
 $43 = (__Z28scripting_array_element_sizeP14ScriptingClass($42)|0);
 $44 = HEAP32[$$pre12>>2]|0;
 $45 = (($data) + 8|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($46) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49;
 $51 = $47;
 $52 = (($50) - ($51))|0;
 $53 = $52 >> 6;
 HEAP32[$i>>2] = $54;
 $55 = (($i) + 4|0);
 HEAP8[$55>>0] = $39;
 $56 = (($i) + 5|0);
 ;HEAP8[$56+0>>0]=HEAP8[$$sroa$2+0>>0]|0;HEAP8[$56+1>>0]=HEAP8[$$sroa$2+1>>0]|0;HEAP8[$56+2>>0]=HEAP8[$$sroa$2+2>>0]|0;
 $57 = (($i) + 8|0);
 HEAP32[$57>>2] = $43;
 $58 = (($i) + 12|0);
 HEAP32[$58>>2] = 0;
 $59 = (($i) + 16|0);
 HEAP32[$59>>2] = $44;
 $60 = (($i) + 20|0);
 HEAP8[$32>>0] = 1;
 $61 = (($i) + 25|0);
 ;HEAP8[$61+0>>0]=HEAP8[$$sroa$8+0>>0]|0;HEAP8[$61+1>>0]=HEAP8[$$sroa$8+1>>0]|0;HEAP8[$61+2>>0]=HEAP8[$$sroa$8+2>>0]|0;
 HEAP32[$33>>2] = 0;
 HEAP32[$34>>2] = 0;
 $62 = (($i) + 36|0);
 HEAP32[$62>>2] = $47;
 HEAP32[$35>>2] = $47;
 HEAP32[$36>>2] = $49;
 $63 = (($i) + 48|0);
 HEAP32[$63>>2] = $53;
 $64 = (($i) + 52|0);
 HEAP32[$64>>2] = $53;
 $65 = ($24|0)==(0);
 if ($65) {
  STACKTOP = sp;return;
 }
 $66 = (($i) + 36|0);
 $67 = (($$sroa$12$i) + 16|0);
 $68 = (($$sroa$12$i) + 12|0);
 $69 = $47;$71 = $54;$72 = 0;$73 = $43;
 while(1) {
  HEAP32[$35>>2] = $69;
  HEAP32[$60>>2] = $66;
  $70 = HEAP32[$71>>2]|0;
  $74 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($70,$72,$73)|0);
  $75 = HEAP8[$55>>0]|0;
  $76 = ($75<<24>>24)==(0);
  if ($76) {
   $78 = HEAP32[$74>>2]|0;
   $79 = ($78|0)==(0|0);
   if ($79) {
    $80 = HEAP32[$59>>2]|0;
    $81 = (_il2cpp_object_new($80)|0);
    __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($81);
    $82 = HEAP32[$i>>2]|0;
    $83 = HEAP32[$82>>2]|0;
    $84 = HEAP32[$58>>2]|0;
    __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($83,$84,$81);
    $instance$0$i = $81;
   } else {
    $instance$0$i = $78;
   }
   $85 = HEAP32[$59>>2]|0;
   HEAP8[$32>>0] = 1;
   ;HEAP8[$61+0>>0]=HEAP8[$$sroa$1$i+0>>0]|0;HEAP8[$61+1>>0]=HEAP8[$$sroa$1$i+1>>0]|0;HEAP8[$61+2>>0]=HEAP8[$$sroa$1$i+2>>0]|0;
   $storemerge = $85;$storemerge5 = $instance$0$i;
  } else {
   $77 = HEAP32[$59>>2]|0;
   HEAP8[$32>>0] = 0;
   ;HEAP8[$61+0>>0]=HEAP8[$$sroa$12$i+0>>0]|0;HEAP8[$61+1>>0]=HEAP8[$$sroa$12$i+1>>0]|0;HEAP8[$61+2>>0]=HEAP8[$$sroa$12$i+2>>0]|0;
   $storemerge = $77;$storemerge5 = $74;
  }
  HEAP32[$33>>2] = $storemerge5;
  HEAP32[$34>>2] = $storemerge;
  $86 = HEAP32[$60>>2]|0;
  ;HEAP32[$$sroa$12$i+0>>2]=0|0;HEAP32[$$sroa$12$i+4>>2]=0|0;HEAP32[$$sroa$12$i+8>>2]=0|0;HEAP32[$$sroa$12$i+12>>2]=0|0;HEAP32[$$sroa$12$i+16>>2]=0|0;HEAP32[$$sroa$12$i+20>>2]=0|0;
  HEAP32[$67>>2] = $this;
  ;HEAP32[$$sroa$12$i+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$$sroa$12$i+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$$sroa$12$i+8>>2]=HEAP32[$32+8>>2]|0;
  HEAP32[$68>>2] = $86;
  $87 = (($86) + 4|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($86) + 8|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($88|0)==($90|0);
  if (!($91)) {
   $92 = (($86) + 12|0);
   $94 = $88;$96 = $90;
   while(1) {
    $93 = (($94) + 64|0);
    HEAP32[$87>>2] = $93;
    $95 = $96;
    $97 = $93;
    $98 = (($95) - ($97))|0;
    $99 = $98 >> 6;
    HEAP32[$92>>2] = $99;
    $100 = HEAP32[$94>>2]|0;
    $101 = (($94) + 4|0);
    FUNCTION_TABLE_vii[$100 & 4095]($101,$$sroa$12$i);
    $102 = HEAP32[$87>>2]|0;
    $103 = HEAP32[$89>>2]|0;
    $104 = ($102|0)==($103|0);
    if ($104) {
     break;
    } else {
     $94 = $102;$96 = $103;
    }
   }
  }
  $105 = HEAP32[$58>>2]|0;
  $106 = (($105) + 1)|0;
  HEAP32[$58>>2] = $106;
  $107 = ($106|0)==($24|0);
  if ($107) {
   break;
  }
  $$pre9 = HEAP32[$66>>2]|0;
  $$pre10 = HEAP32[$i>>2]|0;
  $$pre11 = HEAP32[$57>>2]|0;
  $69 = $$pre9;$71 = $$pre10;$72 = $106;$73 = $$pre11;
 }
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 HEAP8[$converter>>0] = 0;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIaEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN18StreamedBinaryReadILb0EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIh18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIhEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN18StreamedBinaryReadILb0EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIs18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN18StreamedBinaryReadILb0EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN18StreamedBinaryReadILb0EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3218StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$converter>>2] = $3;
 $5 = (($converter) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($converter) + 8|0);
 HEAP32[$6>>2] = 0;
 __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$013 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 32|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 12|0);
 ;HEAP32[$3+0>>2]=HEAP32[$converter+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$converter+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$converter+8>>2]|0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viii(1880,($5|0),($buffer|0),0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 4;
  } else {
   $25 = (($runtimeInfo) + 20|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($staticInfo) + 28|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$1>>2]|0;
   $30 = HEAP32[$buffer>>2]|0;
   $31 = $29;
   $32 = $30;
   $33 = (($31) - ($32))|0;
   $34 = (($33|0) / 12)&-1;
   $35 = (($26) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==($34|0);
   if (!($37)) {
    __THREW__ = 0;
    $38 = (invoke_ii(3288,($28|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $41 = (invoke_iiii(1554,($28|0),($38|0),($34|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 4;
     break;
    }
    HEAP32[$26>>2] = $41;
    HEAP32[$35>>2] = $34;
   }
   $44 = ($29|0)==($30|0);
   L8: do {
    if (!($44)) {
     $45 = (($buffer) + 12|0);
     $46 = (($buffer) + 20|0);
     $47 = (($buffer) + 16|0);
     $index$01$i = 0;
     while(1) {
      $48 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      $49 = (invoke_iii(2433,($48|0),($index$01$i|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
      $52 = HEAP32[$buffer>>2]|0;
      $53 = (($52) + (($index$01$i*12)|0)|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = HEAP32[$45>>2]|0;
      $56 = HEAP32[$46>>2]|0;
      $57 = HEAP32[$47>>2]|0;
      __THREW__ = 0;
      $58 = (invoke_iiiii(245,($54|0),($55|0),($56|0),($57|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
      HEAP32[$49>>2] = $58;
      $61 = (($index$01$i) + 1)|0;
      $62 = ($61|0)==($34|0);
      if ($62) {
       break L8;
      } else {
       $index$01$i = $61;
      }
     }
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index3 = $11;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$25>>2]|0;
   $64 = (($63) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==(0);
   L16: do {
    if (!($66)) {
     $68 = $63;$index$013 = 0;
     while(1) {
      $67 = HEAP32[$68>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2433,($67|0),($index$013|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       break;
      }
      $71 = (($index$013) + 1)|0;
      $72 = HEAP32[$25>>2]|0;
      $73 = (($72) + 4|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($71|0)==($74|0);
      if ($75) {
       break L16;
      } else {
       $68 = $72;$index$013 = $71;
      }
     }
     $8 = ___cxa_find_matching_catch()|0;
     $9 = tempRet0;
     $lpad$phi$index = $8;$lpad$phi$index3 = $9;
     break L1;
    }
   } while(0);
   $76 = HEAP32[$buffer>>2]|0;
   $77 = ($76|0)==(0|0);
   if ($77) {
    STACKTOP = sp;return;
   }
   $78 = HEAP32[$1>>2]|0;
   $79 = ($78|0)==($76|0);
   if (!($79)) {
    $__new_last2$i$i$i$i$i$i$i = $76;
    $scevgep$i$i$i$i$i$i$i = (($78) + -12|0);
    $80 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($80)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $81 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $82 = $81 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($78) + (($82*12)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($76|0),($$byval_copy8|0));
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $85 = ___cxa_find_matching_catch()|0;
    $86 = tempRet0;
    ___cxa_call_unexpected(($85|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index3 = $13;
 }
 $14 = HEAP32[$buffer>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $16 = HEAP32[$1>>2]|0;
 $17 = ($16|0)==($14|0);
 if (!($17)) {
  $__new_last2$i$i$i$i$i$i$i1 = $14;
  $scevgep$i$i$i$i$i$i$i2 = (($16) + -12|0);
  $18 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($18)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $19 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 12)&-1;
  $20 = $19 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($16) + (($20*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($14|0),($$byval_copy8|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  ___cxa_call_unexpected(($23|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8MonoPPtr13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI8MonoPPtr13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 12|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $index$01$i = 0, $index$017 = 0, $invocation$i = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $method$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy10 = sp + 72|0;
 $method$i = sp;
 $invocation$i = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 48|0;
 $2 = sp + 52|0;
 $buffer = sp + 56|0;
 HEAP32[$buffer>>2] = 0;
 $3 = (($buffer) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($buffer) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[$converter>>2]|0;
 $6 = (($buffer) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (($runtimeInfo) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_viii(1881,($8|0),($buffer|0),0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 4;
  } else {
   $39 = (($runtimeInfo) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($staticInfo) + 28|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$3>>2]|0;
   $44 = HEAP32[$buffer>>2]|0;
   $45 = $43;
   $46 = $44;
   $47 = (($45) - ($46))|0;
   $48 = (($47|0) / 292)&-1;
   $49 = (($40) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==($48|0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_ii(3288,($42|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $55 = (invoke_iiii(1554,($42|0),($52|0),($48|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     label = 4;
     break;
    }
    HEAP32[$40>>2] = $55;
    HEAP32[$49>>2] = $48;
   }
   $58 = ($43|0)==($44|0);
   L8: do {
    if (!($58)) {
     $59 = (($buffer) + 12|0);
     $index$01$i = 0;
     while(1) {
      $60 = HEAP32[$40>>2]|0;
      __THREW__ = 0;
      $61 = (invoke_iii(2433,($60|0),($index$01$i|0))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
      $64 = HEAP32[$buffer>>2]|0;
      $65 = (($64) + (($index$01$i*292)|0)|0);
      __THREW__ = 0;
      invoke_viii(1797,($59|0),($65|0),($61|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$01$i) + 1)|0;
      $69 = ($68|0)==($48|0);
      if ($69) {
       break L8;
      } else {
       $index$01$i = $68;
      }
     }
     $13 = ___cxa_find_matching_catch()|0;
     $14 = tempRet0;
     $lpad$phi$index = $13;$lpad$phi$index3 = $14;
     break L1;
    }
   } while(0);
   $70 = HEAP32[$39>>2]|0;
   $71 = (($70) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0);
   L16: do {
    if (!($73)) {
     $74 = (($invocation$i) + 12|0);
     $76 = $70;$index$017 = 0;
     while(1) {
      $75 = HEAP32[$76>>2]|0;
      __THREW__ = 0;
      $77 = (invoke_iii(2433,($75|0),($index$017|0))|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       break;
      }
      $80 = HEAP32[$77>>2]|0;
      __THREW__ = 0;
      $81 = (invoke_i(84)|0);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      $84 = (($81) + 308|0);
      $85 = HEAP32[$84>>2]|0;
      __THREW__ = 0;
      invoke_viiii(388,($method$i|0),($85|0),(630336|0),1);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       break;
      }
      $88 = HEAP32[$method$i>>2]|0;
      $89 = ($88|0)==(0|0);
      if (!($89)) {
       $90 = $method$i;
       $91 = $90;
       $92 = HEAP32[$91>>2]|0;
       $93 = (($90) + 4)|0;
       $94 = $93;
       $95 = HEAP32[$94>>2]|0;
       $96 = $0;
       $97 = $96;
       HEAP32[$97>>2] = $92;
       $98 = (($96) + 4)|0;
       $99 = $98;
       HEAP32[$99>>2] = $95;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy10+4>>2]=HEAP32[$0+4>>2]|0;
       invoke_vii(2863,($invocation$i|0),($$byval_copy10|0));
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        break;
       }
       HEAP32[$74>>2] = $80;
       __THREW__ = 0;
       (invoke_ii(3285,($invocation$i|0))|0);
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if ($103) {
        break;
       }
      }
      $104 = (($index$017) + 1)|0;
      $105 = HEAP32[$39>>2]|0;
      $106 = (($105) + 4|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = ($104|0)==($107|0);
      if ($108) {
       break L16;
      } else {
       $76 = $105;$index$017 = $104;
      }
     }
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index3 = $12;
     break L1;
    }
   } while(0);
   $109 = HEAP32[$buffer>>2]|0;
   $110 = ($109|0)==(0|0);
   if ($110) {
    STACKTOP = sp;return;
   }
   $111 = HEAP32[$3>>2]|0;
   $112 = ($111|0)==($109|0);
   do {
    if ($112) {
     $126 = $109;
    } else {
     $114 = $111;
     while(1) {
      $113 = (($114) + -292|0);
      HEAP32[$3>>2] = $113;
      $115 = HEAP8[$113>>0]|0;
      $116 = $115 & 1;
      $117 = ($116<<24>>24)==(0);
      if ($117) {
       $119 = $113;
      } else {
       $120 = (($114) + -284|0);
       $121 = HEAP32[$120>>2]|0;
       HEAP32[$method$i>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$method$i+0>>2]|0;
       invoke_vii(2591,($121|0),($$byval_copy10|0));
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if ($123) {
        label = 41;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$3>>2]|0;
       $119 = $$pre$i$i$i$i$i$i$i;
      }
      $118 = ($119|0)==($109|0);
      if ($118) {
       label = 42;
       break;
      } else {
       $114 = $119;
      }
     }
     if ((label|0) == 41) {
      $124 = ___cxa_find_matching_catch()|0;
      $125 = tempRet0;
      ___cxa_call_unexpected(($124|0));
      // unreachable;
     }
     else if ((label|0) == 42) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $126 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$invocation$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$invocation$i+0>>2]|0;
   invoke_vii(2591,($126|0),($$byval_copy10|0));
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if ($128) {
    $129 = ___cxa_find_matching_catch()|0;
    $130 = tempRet0;
    ___cxa_call_unexpected(($129|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 }
 $17 = HEAP32[$buffer>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $19 = HEAP32[$3>>2]|0;
 $20 = ($19|0)==($17|0);
 do {
  if ($20) {
   $34 = $17;
  } else {
   $22 = $19;
   while(1) {
    $21 = (($22) + -292|0);
    HEAP32[$3>>2] = $21;
    $23 = HEAP8[$21>>0]|0;
    $24 = $23 & 1;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     $27 = $21;
    } else {
     $28 = (($22) + -284|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($29|0),($$byval_copy10|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 12;
      break;
     }
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$3>>2]|0;
     $27 = $$pre$i$i$i$i$i$i$i3;
    }
    $26 = ($27|0)==($17|0);
    if ($26) {
     label = 13;
     break;
    } else {
     $22 = $27;
    }
   }
   if ((label|0) == 12) {
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $34 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy10|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8GUIStyle13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI8GUIStyle13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN8GUIStyle8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 292|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*292)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$010 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viii(1882,($6|0),($buffer|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 3;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   __THREW__ = 0;
   invoke_viii(1804,($buffer|0),($25|0),($27|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    label = 3;
   } else {
    $30 = HEAP32[$24>>2]|0;
    $31 = (($30) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0);
    L4: do {
     if (!($33)) {
      $35 = $30;$index$010 = 0;
      while(1) {
       $34 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($34|0),($index$010|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
       $38 = (($index$010) + 1)|0;
       $39 = HEAP32[$24>>2]|0;
       $40 = (($39) + 4|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = ($38|0)==($41|0);
       if ($42) {
        break L4;
       } else {
        $35 = $39;$index$010 = $38;
       }
      }
      $9 = ___cxa_find_matching_catch()|0;
      $10 = tempRet0;
      $lpad$phi$index = $9;$lpad$phi$index2 = $10;
      break L1;
     }
    } while(0);
    $43 = HEAP32[$buffer>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     STACKTOP = sp;return;
    }
    $45 = HEAP32[$1>>2]|0;
    $46 = ($45|0)==($43|0);
    if (!($46)) {
     $__new_last2$i$i$i$i$i$i$i = $43;
     $scevgep$i$i$i$i$i$i$i = (($45) + -16|0);
     $47 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($47)|0);
     $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
     $48 = $uglygep3$i$i$i$i$i$i$i >>> 4;
     $49 = $48 ^ -1;
     $scevgep4$i$i$i$i$i$i$i = (($45) + ($49<<4)|0);
     HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($43|0),($$byval_copy6|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     $52 = ___cxa_find_matching_catch()|0;
     $53 = tempRet0;
     ___cxa_call_unexpected(($52|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy6|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI10RectOffset13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI10RectOffset13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN10RectOffset8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 16|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $buffer = 0, $index$04 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viii(1883,($6|0),($buffer|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 3;
  } else {
   $27 = (($runtimeInfo) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($staticInfo) + 28|0);
   $30 = HEAP32[$29>>2]|0;
   __THREW__ = 0;
   invoke_viii(1807,($buffer|0),($28|0),($30|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 3;
   } else {
    $33 = HEAP32[$27>>2]|0;
    $34 = (($33) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)==(0);
    L4: do {
     if (!($36)) {
      $38 = $33;$index$04 = 0;
      while(1) {
       $37 = HEAP32[$38>>2]|0;
       __THREW__ = 0;
       (invoke_iii(2433,($37|0),($index$04|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break;
       }
       $41 = (($index$04) + 1)|0;
       $42 = HEAP32[$27>>2]|0;
       $43 = (($42) + 4|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ($41|0)==($44|0);
       if ($45) {
        break L4;
       } else {
        $38 = $42;$index$04 = $41;
       }
      }
      $9 = ___cxa_find_matching_catch()|0;
      $10 = tempRet0;
      $lpad$phi$index = $9;$lpad$phi$index2 = $10;
      break L1;
     }
    } while(0);
    $46 = HEAP32[$buffer>>2]|0;
    $47 = ($46|0)==(0|0);
    if ($47) {
     STACKTOP = sp;return;
    }
    while(1) {
     $48 = HEAP32[$1>>2]|0;
     $49 = ($48|0)==($46|0);
     if ($49) {
      break;
     }
     $50 = (($48) + -68|0);
     HEAP32[$1>>2] = $50;
     __THREW__ = 0;
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 17;
      break;
     }
    }
    if ((label|0) == 17) {
     $53 = ___cxa_find_matching_catch()|0;
     $54 = tempRet0;
     ___cxa_call_unexpected(($53|0));
     // unreachable;
    }
    $55 = HEAP32[$buffer>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($55|0),($$byval_copy6|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     ___cxa_call_unexpected(($58|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 while(1) {
  $15 = HEAP32[$1>>2]|0;
  $16 = ($15|0)==($13|0);
  if ($16) {
   break;
  }
  $17 = (($15) + -68|0);
  HEAP32[$1>>2] = $17;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  ___cxa_call_unexpected(($20|0));
  // unreachable;
 }
 $22 = HEAP32[$buffer>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($22|0),($$byval_copy6|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  ___cxa_call_unexpected(($25|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI11GradientNEW13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI11GradientNEW13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN11GradientNEW8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 68|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*68)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $index$01$i = 0, $index$013 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viii(1884,($6|0),($buffer|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 4;
  } else {
   $39 = (($runtimeInfo) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($staticInfo) + 28|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$1>>2]|0;
   $44 = HEAP32[$buffer>>2]|0;
   $45 = $43;
   $46 = $44;
   $47 = (($45) - ($46))|0;
   $48 = (($47|0) / 80)&-1;
   $49 = (($40) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==($48|0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_ii(3288,($42|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $55 = (invoke_iiii(1554,($42|0),($52|0),($48|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     label = 4;
     break;
    }
    HEAP32[$40>>2] = $55;
    HEAP32[$49>>2] = $48;
   }
   $58 = ($43|0)==($44|0);
   L8: do {
    if (!($58)) {
     $59 = (($buffer) + 12|0);
     $index$01$i = 0;
     while(1) {
      $60 = HEAP32[$40>>2]|0;
      __THREW__ = 0;
      $61 = (invoke_iii(2433,($60|0),($index$01$i|0))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
      $64 = HEAP32[$buffer>>2]|0;
      $65 = (($64) + (($index$01$i*80)|0)|0);
      __THREW__ = 0;
      invoke_viii(1798,($59|0),($65|0),($61|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$01$i) + 1)|0;
      $69 = ($68|0)==($48|0);
      if ($69) {
       break L8;
      } else {
       $index$01$i = $68;
      }
     }
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index3 = $12;
     break L1;
    }
   } while(0);
   $70 = HEAP32[$39>>2]|0;
   $71 = (($70) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0);
   L16: do {
    if (!($73)) {
     $75 = $70;$index$013 = 0;
     while(1) {
      $74 = HEAP32[$75>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2433,($74|0),($index$013|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      $78 = (($index$013) + 1)|0;
      $79 = HEAP32[$39>>2]|0;
      $80 = (($79) + 4|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = ($78|0)==($81|0);
      if ($82) {
       break L16;
      } else {
       $75 = $79;$index$013 = $78;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $83 = HEAP32[$buffer>>2]|0;
   $84 = ($83|0)==(0|0);
   if ($84) {
    STACKTOP = sp;return;
   }
   $85 = HEAP32[$1>>2]|0;
   $86 = ($85|0)==($83|0);
   do {
    if ($86) {
     $102 = $83;
    } else {
     $88 = $85;
     while(1) {
      $87 = (($88) + -80|0);
      HEAP32[$1>>2] = $87;
      $89 = (($88) + -12|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = ($90|0)>(-1);
      if ($91) {
       $94 = (($88) + -24|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = (($88) + -20|0);
       $97 = HEAP32[$96>>2]|0;
       HEAP32[$0>>2] = $97;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($95|0),($$byval_copy10|0));
       $98 = __THREW__; __THREW__ = 0;
       $99 = $98&1;
       if ($99) {
        label = 35;
        break;
       }
       HEAP32[$94>>2] = 0;
       $$pre$i$i$i$i$i$i$i = HEAP32[$1>>2]|0;
       $93 = $$pre$i$i$i$i$i$i$i;
      } else {
       $93 = $87;
      }
      $92 = ($93|0)==($83|0);
      if ($92) {
       label = 36;
       break;
      } else {
       $88 = $93;
      }
     }
     if ((label|0) == 35) {
      $100 = ___cxa_find_matching_catch()|0;
      $101 = tempRet0;
      ___cxa_call_unexpected(($100|0));
      // unreachable;
     }
     else if ((label|0) == 36) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $102 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($102|0),($$byval_copy10|0));
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    $105 = ___cxa_find_matching_catch()|0;
    $106 = tempRet0;
    ___cxa_call_unexpected(($105|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 }
 $15 = HEAP32[$buffer>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ($17|0)==($15|0);
 do {
  if ($18) {
   $34 = $15;
  } else {
   $20 = $17;
   while(1) {
    $19 = (($20) + -80|0);
    HEAP32[$1>>2] = $19;
    $21 = (($20) + -12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)>(-1);
    if ($23) {
     $26 = (($20) + -24|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($20) + -20|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$0>>2] = $29;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($27|0),($$byval_copy10|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 12;
      break;
     }
     HEAP32[$26>>2] = 0;
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$1>>2]|0;
     $25 = $$pre$i$i$i$i$i$i$i3;
    } else {
     $25 = $19;
    }
    $24 = ($25|0)==($15|0);
    if ($24) {
     label = 13;
     break;
    } else {
     $20 = $25;
    }
   }
   if ((label|0) == 12) {
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $34 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy10|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = ($16*80)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $20 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $20 = $19;
 }
 __Z14resize_trimmedINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
 $21 = (($data) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$data>>2]|0;
 $24 = ($23|0)==($22|0);
 if ($24) {
  STACKTOP = sp;return;
 } else {
  $26 = $23;
 }
 while(1) {
  $25 = (($26) + 56|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplIfELj4EEEEvRT_17TransferMetaFlags($this,$25,0);
  $27 = (($26) + 72|0);
  $28 = HEAP32[$1>>2]|0;
  $29 = (($28) + 4|0);
  $30 = HEAP32[$7>>2]|0;
  $31 = ($29>>>0)>($30>>>0);
  if ($31) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$27,4);
   $$pre$i$i$i = HEAP32[$1>>2]|0;
   $$pre2$i$i$i = HEAP32[$7>>2]|0;
   $35 = $$pre$i$i$i;$37 = $$pre2$i$i$i;
  } else {
   $32 = HEAP32[$28>>2]|0;
   HEAP32[$27>>2] = $32;
   HEAP32[$1>>2] = $29;
   $35 = $29;$37 = $30;
  }
  $33 = (($26) + 76|0);
  $34 = (($35) + 4|0);
  $36 = ($34>>>0)>($37>>>0);
  if ($36) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$33,4);
  } else {
   $38 = HEAP32[$35>>2]|0;
   HEAP32[$33>>2] = $38;
   HEAP32[$1>>2] = $34;
  }
  __ZN17AnimationCurveTplIfE15InvalidateCacheEv($26);
  $39 = (($26) + 80|0);
  $40 = ($39|0)==($22|0);
  if ($40) {
   break;
  } else {
   $26 = $39;
  }
 }
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1885,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8BitField13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI8BitField13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last1$i$i$i$i$i$i$i = 0, $__new_last1$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$011 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep2$i$i$i$i$i$i$i = 0, $scevgep2$i$i$i$i$i$i$i3 = 0, $scevgep23$i$i$i$i$i$i$i = 0, $scevgep23$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1886,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$011 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$011) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$011 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last1$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last1$i$i$i$i$i$i$i))|0;
    $scevgep2$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $scevgep23$i$i$i$i$i$i$i = $scevgep2$i$i$i$i$i$i$i;
    $69 = $scevgep23$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last1$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last1$i$i$i$i$i$i$i1))|0;
  $scevgep2$i$i$i$i$i$i$i3 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $scevgep23$i$i$i$i$i$i$i4 = $scevgep2$i$i$i$i$i$i$i3;
  $18 = $scevgep23$i$i$i$i$i$i$i4 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i5 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i5;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI11ColorRGBA3213stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI11ColorRGBA3213stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1887,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 4;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),16)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<4)|0);
      $50 = Math_fround(HEAPF32[$49>>2]);
      $51 = ((($48) + ($index$01$i<<4)|0) + 4|0);
      $52 = Math_fround(HEAPF32[$51>>2]);
      $53 = ((($48) + ($index$01$i<<4)|0) + 8|0);
      $54 = Math_fround(HEAPF32[$53>>2]);
      $55 = ((($48) + ($index$01$i<<4)|0) + 12|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      HEAPF32[$45>>2] = $50;
      $57 = (($45) + 4|0);
      HEAPF32[$57>>2] = $52;
      $58 = (($45) + 8|0);
      HEAPF32[$58>>2] = $54;
      $59 = (($45) + 12|0);
      HEAPF32[$59>>2] = $56;
      $60 = (($index$01$i) + 1)|0;
      $61 = ($60|0)==($33|0);
      if ($61) {
       break L8;
      } else {
       $index$01$i = $60;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $62 = HEAP32[$24>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L15: do {
    if (!($65)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$012) + 1)|0;
      $69 = HEAP32[$24>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($68|0)==($71|0);
      if ($72) {
       break L15;
      } else {
       $index$012 = $68;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $73 = HEAP32[$buffer>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$1>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i$i$i = $73;
    $scevgep$i$i$i$i$i$i$i = (($75) + -16|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($77)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $78 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($75) + ($79<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($73|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI10ColorRGBAf13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI10ColorRGBAf13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 4;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1888,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = (($32|0) / 24)&-1;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($28|0)==($29|0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),24)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + (($index$01$i*24)|0)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$49+12>>2]|0;HEAP32[$45+16>>2]=HEAP32[$49+16>>2]|0;HEAP32[$45+20>>2]=HEAP32[$49+20>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -24|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 24)&-1;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + (($69*24)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -24|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 24)&-1;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + (($19*24)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4AABB13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4AABB13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = ($21*24)|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*24)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1889,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 6;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),64)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<6)|0);
      dest=$45+0|0; src=$49+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -64|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = $uglygep3$i$i$i$i$i$i$i >>> 6;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + ($69<<6)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -64|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 6;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<6)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI10Matrix4x4f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI10Matrix4x4f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN10Matrix4x4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 64|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 6;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1890,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 4;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),16)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<4)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$49+12>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -16|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + ($69<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI11Quaternionf13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI11Quaternionf13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 4;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1891,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 4;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),16)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<4)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$49+12>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -16|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + ($69<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI5RectTIfE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI5RectTIfE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 4;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1892,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 4;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),16)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<4)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$49+12>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -16|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + ($69<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector4f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI8Vector4f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 4;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 4;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1893,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),8)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<3)|0);
      $50 = $49;
      $51 = $50;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($50) + 4)|0;
      $54 = $53;
      $55 = HEAP32[$54>>2]|0;
      $56 = $45;
      $57 = $56;
      HEAP32[$57>>2] = $52;
      $58 = (($56) + 4)|0;
      $59 = $58;
      HEAP32[$59>>2] = $55;
      $60 = (($index$01$i) + 1)|0;
      $61 = ($60|0)==($33|0);
      if ($61) {
       break L8;
      } else {
       $index$01$i = $60;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $62 = HEAP32[$24>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L15: do {
    if (!($65)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$012) + 1)|0;
      $69 = HEAP32[$24>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($68|0)==($71|0);
      if ($72) {
       break L15;
      } else {
       $index$012 = $68;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $73 = HEAP32[$buffer>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$1>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i$i$i = $73;
    $scevgep$i$i$i$i$i$i$i = (($75) + -8|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($77)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $78 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($75) + ($79<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($73|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -8|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector2f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI8Vector2f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 3;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 3;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1894,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = (($32|0) / 12)&-1;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($28|0)==($29|0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),12)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + (($index$01$i*12)|0)|0);
      ;HEAP32[$45+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$49+8>>2]|0;
      $50 = (($index$01$i) + 1)|0;
      $51 = ($50|0)==($33|0);
      if ($51) {
       break L8;
      } else {
       $index$01$i = $50;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $52 = HEAP32[$24>>2]|0;
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   L15: do {
    if (!($55)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($index$012) + 1)|0;
      $59 = HEAP32[$24>>2]|0;
      $60 = (($59) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($58|0)==($61|0);
      if ($62) {
       break L15;
      } else {
       $index$012 = $58;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $63 = HEAP32[$buffer>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($63|0);
   if (!($66)) {
    $__new_last2$i$i$i$i$i$i$i = $63;
    $scevgep$i$i$i$i$i$i$i = (($65) + -12|0);
    $67 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($67)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $68 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $69 = $68 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($65) + (($69*12)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($63|0),($$byval_copy8|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if ($71) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    ___cxa_call_unexpected(($72|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -12|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 12)&-1;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + (($19*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector3f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI8Vector3f13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = ($21*12)|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1895,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),8)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<3)|0);
      $50 = +HEAPF64[$49>>3];
      HEAPF64[$45>>3] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -8|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -8|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 3;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 3;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1896,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = Math_fround(HEAPF32[$49>>2]);
      HEAPF32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1897,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),8)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<3)|0);
      $50 = $49;
      $51 = $50;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($50) + 4)|0;
      $54 = $53;
      $55 = HEAP32[$54>>2]|0;
      $56 = $45;
      $57 = $56;
      HEAP32[$57>>2] = $52;
      $58 = (($56) + 4)|0;
      $59 = $58;
      HEAP32[$59>>2] = $55;
      $60 = (($index$01$i) + 1)|0;
      $61 = ($60|0)==($33|0);
      if ($61) {
       break L8;
      } else {
       $index$01$i = $60;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $62 = HEAP32[$24>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L15: do {
    if (!($65)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$012) + 1)|0;
      $69 = HEAP32[$24>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($68|0)==($71|0);
      if ($72) {
       break L15;
      } else {
       $index$012 = $68;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $73 = HEAP32[$buffer>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$1>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i$i$i = $73;
    $scevgep$i$i$i$i$i$i$i = (($75) + -8|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($77)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $78 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($75) + ($79<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($73|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -8|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 3;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 3;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0, $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1898,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 3;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),8)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<3)|0);
      $50 = $49;
      $51 = $50;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($50) + 4)|0;
      $54 = $53;
      $55 = HEAP32[$54>>2]|0;
      $56 = $45;
      $57 = $56;
      HEAP32[$57>>2] = $52;
      $58 = (($56) + 4)|0;
      $59 = $58;
      HEAP32[$59>>2] = $55;
      $60 = (($index$01$i) + 1)|0;
      $61 = ($60|0)==($33|0);
      if ($61) {
       break L8;
      } else {
       $index$01$i = $60;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $62 = HEAP32[$24>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L15: do {
    if (!($65)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = (($index$012) + 1)|0;
      $69 = HEAP32[$24>>2]|0;
      $70 = (($69) + 4|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($68|0)==($71|0);
      if ($72) {
       break L15;
      } else {
       $index$012 = $68;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $73 = HEAP32[$buffer>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$1>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i$i$i = $73;
    $scevgep$i$i$i$i$i$i$i = (($75) + -8|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($77)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $78 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($75) + ($79<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($73|0),($$byval_copy8|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -8|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 3;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 3;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 3;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1899,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1900,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),4)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$45>>2] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -4|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1901,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 1;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),2)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<1)|0);
      $50 = HEAP16[$49>>1]|0;
      HEAP16[$45>>1] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -2|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 1;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<1)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -2|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 1;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 1;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 1;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $index$01$i = 0;
 var $index$012 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1902,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $24 = (($runtimeInfo) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($staticInfo) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$1>>2]|0;
   $29 = HEAP32[$buffer>>2]|0;
   $30 = $28;
   $31 = $29;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 1;
   $34 = (($25) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(3288,($27|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iiii(1554,($27|0),($37|0),($33|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 4;
     break;
    }
    HEAP32[$25>>2] = $40;
    HEAP32[$34>>2] = $33;
   }
   $43 = ($33|0)==(0);
   L8: do {
    if (!($43)) {
     $index$01$i = 0;
     while(1) {
      $44 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_iiii(1555,($44|0),($index$01$i|0),2)|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = HEAP32[$buffer>>2]|0;
      $49 = (($48) + ($index$01$i<<1)|0);
      $50 = HEAP16[$49>>1]|0;
      HEAP16[$45>>1] = $50;
      $51 = (($index$01$i) + 1)|0;
      $52 = ($51|0)==($33|0);
      if ($52) {
       break L8;
      } else {
       $index$01$i = $51;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $53 = HEAP32[$24>>2]|0;
   $54 = (($53) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   L15: do {
    if (!($56)) {
     $index$012 = 0;
     while(1) {
      __THREW__ = 0;
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = (($index$012) + 1)|0;
      $60 = HEAP32[$24>>2]|0;
      $61 = (($60) + 4|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = ($59|0)==($62|0);
      if ($63) {
       break L15;
      } else {
       $index$012 = $59;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $64 = HEAP32[$buffer>>2]|0;
   $65 = ($64|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($64|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $64;
    $scevgep$i$i$i$i$i$i$i = (($66) + -2|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 1;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<1)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -2|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 1;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 1;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 1;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIhEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, $index$01$i = 0, $index$08 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1903,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 5;
  } else {
   __THREW__ = 0;
   invoke_vi(3376,($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 5;
   } else {
    $23 = (($runtimeInfo) + 20|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($staticInfo) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$1>>2]|0;
    $28 = HEAP32[$buffer>>2]|0;
    $29 = $27;
    $30 = $28;
    $31 = (($29) - ($30))|0;
    $32 = (($24) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==($31|0);
    if (!($34)) {
     __THREW__ = 0;
     $35 = (invoke_ii(3288,($26|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 5;
      break;
     }
     __THREW__ = 0;
     $38 = (invoke_iiii(1554,($26|0),($35|0),($31|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 5;
      break;
     }
     HEAP32[$24>>2] = $38;
     HEAP32[$32>>2] = $31;
    }
    $41 = ($27|0)==($28|0);
    L9: do {
     if (!($41)) {
      $index$01$i = 0;
      while(1) {
       $42 = HEAP32[$24>>2]|0;
       __THREW__ = 0;
       $43 = (invoke_iiii(1555,($42|0),($index$01$i|0),1)|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
       $46 = HEAP32[$buffer>>2]|0;
       $47 = (($46) + ($index$01$i)|0);
       $48 = HEAP8[$47>>0]|0;
       HEAP8[$43>>0] = $48;
       $49 = (($index$01$i) + 1)|0;
       $50 = ($49|0)==($31|0);
       if ($50) {
        break L9;
       } else {
        $index$01$i = $49;
       }
      }
      $11 = ___cxa_find_matching_catch()|0;
      $12 = tempRet0;
      $lpad$phi$index = $11;$lpad$phi$index3 = $12;
      break L1;
     }
    } while(0);
    $51 = HEAP32[$23>>2]|0;
    $52 = (($51) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0);
    L16: do {
     if (!($54)) {
      $index$08 = 0;
      while(1) {
       __THREW__ = 0;
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
       $57 = (($index$08) + 1)|0;
       $58 = HEAP32[$23>>2]|0;
       $59 = (($58) + 4|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ($57|0)==($60|0);
       if ($61) {
        break L16;
       } else {
        $index$08 = $57;
       }
      }
      $9 = ___cxa_find_matching_catch()|0;
      $10 = tempRet0;
      $lpad$phi$index = $9;$lpad$phi$index3 = $10;
      break L1;
     }
    } while(0);
    $62 = HEAP32[$buffer>>2]|0;
    $63 = ($62|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = HEAP32[$1>>2]|0;
    $65 = ($64|0)==($62|0);
    if (!($65)) {
     HEAP32[$1>>2] = $62;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($62|0),($$byval_copy8|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     $68 = ___cxa_find_matching_catch()|0;
     $69 = tempRet0;
     ___cxa_call_unexpected(($68|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 }
 $15 = HEAP32[$buffer>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ($17|0)==($15|0);
 if (!($18)) {
  HEAP32[$1>>2] = $15;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($15|0),($$byval_copy8|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  ___cxa_call_unexpected(($21|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $19 = $$pre;
  } else {
   $18 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $18;
   HEAP32[$1>>2] = $6;
   $19 = $18;
  }
  __Z14resize_trimmedINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$19);
  $20 = HEAP32[$size1>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   STACKTOP = sp;return;
  }
  $22 = HEAP32[$data>>2]|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$22,$20);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $17 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $17 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$17,$16)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE19Converter_PrimitiveIaEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, $index$01$i = 0, $index$06 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(1904,($4|0),($buffer|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   label = 4;
  } else {
   $21 = (($runtimeInfo) + 20|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($staticInfo) + 28|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$1>>2]|0;
   $26 = HEAP32[$buffer>>2]|0;
   $27 = $25;
   $28 = $26;
   $29 = (($27) - ($28))|0;
   $30 = (($22) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==($29|0);
   if (!($32)) {
    __THREW__ = 0;
    $33 = (invoke_ii(3288,($24|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $36 = (invoke_iiii(1554,($24|0),($33|0),($29|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 4;
     break;
    }
    HEAP32[$22>>2] = $36;
    HEAP32[$30>>2] = $29;
   }
   $39 = ($25|0)==($26|0);
   L8: do {
    if (!($39)) {
     $index$01$i = 0;
     while(1) {
      $40 = HEAP32[$22>>2]|0;
      __THREW__ = 0;
      $41 = (invoke_iiii(1555,($40|0),($index$01$i|0),1)|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      }
      $44 = HEAP32[$buffer>>2]|0;
      $45 = (($44) + ($index$01$i)|0);
      $46 = HEAP8[$45>>0]|0;
      HEAP8[$41>>0] = $46;
      $47 = (($index$01$i) + 1)|0;
      $48 = ($47|0)==($29|0);
      if ($48) {
       break L8;
      } else {
       $index$01$i = $47;
      }
     }
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index3 = $10;
     break L1;
    }
   } while(0);
   $49 = HEAP32[$21>>2]|0;
   $50 = (($49) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0);
   L15: do {
    if (!($52)) {
     $index$06 = 0;
     while(1) {
      __THREW__ = 0;
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = (($index$06) + 1)|0;
      $56 = HEAP32[$21>>2]|0;
      $57 = (($56) + 4|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($55|0)==($58|0);
      if ($59) {
       break L15;
      } else {
       $index$06 = $55;
      }
     }
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index3 = $8;
     break L1;
    }
   } while(0);
   $60 = HEAP32[$buffer>>2]|0;
   $61 = ($60|0)==(0|0);
   if ($61) {
    STACKTOP = sp;return;
   }
   $62 = HEAP32[$1>>2]|0;
   $63 = ($62|0)==($60|0);
   if (!($63)) {
    HEAP32[$1>>2] = $60;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy8|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $66 = ___cxa_find_matching_catch()|0;
    $67 = tempRet0;
    ___cxa_call_unexpected(($66|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  HEAP32[$1>>2] = $13;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy8|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  ___cxa_call_unexpected(($19|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $19 = $$pre;
  } else {
   $18 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $18;
   HEAP32[$1>>2] = $6;
   $19 = $18;
  }
  __Z14resize_trimmedINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$19);
  $20 = HEAP32[$size1>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   STACKTOP = sp;return;
  }
  $22 = HEAP32[$data>>2]|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$22,$20);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $17 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $17 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$17,$16)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI18StreamedBinaryReadILb0EE16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy10 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buffer = 0, $index$01$i = 0, $index$013 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viii(1905,($5|0),($buffer|0),0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 4;
  } else {
   $36 = (($runtimeInfo) + 20|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($staticInfo) + 28|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$2>>2]|0;
   $41 = HEAP32[$buffer>>2]|0;
   $42 = $40;
   $43 = $41;
   $44 = (($42) - ($43))|0;
   $45 = (($44|0) / 12)&-1;
   $46 = (($37) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==($45|0);
   if (!($48)) {
    __THREW__ = 0;
    $49 = (invoke_ii(3288,($39|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $52 = (invoke_iiii(1554,($39|0),($49|0),($45|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 4;
     break;
    }
    HEAP32[$37>>2] = $52;
    HEAP32[$46>>2] = $45;
   }
   $55 = ($40|0)==($41|0);
   L8: do {
    if (!($55)) {
     $index$01$i = 0;
     while(1) {
      $56 = HEAP32[$37>>2]|0;
      __THREW__ = 0;
      $57 = (invoke_iii(2433,($56|0),($index$01$i|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      $60 = HEAP32[$buffer>>2]|0;
      $61 = (($60) + (($index$01$i*12)|0)|0);
      $62 = HEAP8[$61>>0]|0;
      $63 = $62 & 1;
      $64 = ($63<<24>>24)==(0);
      if ($64) {
       $67 = (($61) + 1|0);
       $68 = $67;
      } else {
       $65 = ((($60) + (($index$01$i*12)|0)|0) + 8|0);
       $66 = HEAP32[$65>>2]|0;
       $68 = $66;
      }
      __THREW__ = 0;
      $69 = (invoke_ii(3287,($68|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      HEAP32[$57>>2] = $69;
      $72 = (($index$01$i) + 1)|0;
      $73 = ($72|0)==($45|0);
      if ($73) {
       break L8;
      } else {
       $index$01$i = $72;
      }
     }
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index3 = $11;
     break L1;
    }
   } while(0);
   $74 = HEAP32[$36>>2]|0;
   $75 = (($74) + 4|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==(0);
   L20: do {
    if (!($77)) {
     $79 = $74;$index$013 = 0;
     while(1) {
      $78 = HEAP32[$79>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2433,($78|0),($index$013|0))|0);
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       break;
      }
      $82 = (($index$013) + 1)|0;
      $83 = HEAP32[$36>>2]|0;
      $84 = (($83) + 4|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ($82|0)==($85|0);
      if ($86) {
       break L20;
      } else {
       $79 = $83;$index$013 = $82;
      }
     }
     $8 = ___cxa_find_matching_catch()|0;
     $9 = tempRet0;
     $lpad$phi$index = $8;$lpad$phi$index3 = $9;
     break L1;
    }
   } while(0);
   $87 = HEAP32[$buffer>>2]|0;
   $88 = ($87|0)==(0|0);
   if ($88) {
    STACKTOP = sp;return;
   }
   $89 = HEAP32[$2>>2]|0;
   $90 = ($89|0)==($87|0);
   do {
    if ($90) {
     $104 = $87;
    } else {
     $92 = $89;
     while(1) {
      $91 = (($92) + -12|0);
      HEAP32[$2>>2] = $91;
      $93 = HEAP8[$91>>0]|0;
      $94 = $93 & 1;
      $95 = ($94<<24>>24)==(0);
      if ($95) {
       $97 = $91;
      } else {
       $98 = (($92) + -4|0);
       $99 = HEAP32[$98>>2]|0;
       HEAP32[$0>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($99|0),($$byval_copy10|0));
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        label = 38;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$2>>2]|0;
       $97 = $$pre$i$i$i$i$i$i$i;
      }
      $96 = ($97|0)==($87|0);
      if ($96) {
       label = 39;
       break;
      } else {
       $92 = $97;
      }
     }
     if ((label|0) == 38) {
      $102 = ___cxa_find_matching_catch()|0;
      $103 = tempRet0;
      ___cxa_call_unexpected(($102|0));
      // unreachable;
     }
     else if ((label|0) == 39) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $104 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($104|0),($$byval_copy10|0));
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    $107 = ___cxa_find_matching_catch()|0;
    $108 = tempRet0;
    ___cxa_call_unexpected(($107|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index3 = $13;
 }
 $14 = HEAP32[$buffer>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $16 = HEAP32[$2>>2]|0;
 $17 = ($16|0)==($14|0);
 do {
  if ($17) {
   $31 = $14;
  } else {
   $19 = $16;
   while(1) {
    $18 = (($19) + -12|0);
    HEAP32[$2>>2] = $18;
    $20 = HEAP8[$18>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $24 = $18;
    } else {
     $25 = (($19) + -4|0);
     $26 = HEAP32[$25>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($26|0),($$byval_copy10|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 12;
      break;
     }
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$2>>2]|0;
     $24 = $$pre$i$i$i$i$i$i$i3;
    }
    $23 = ($24|0)==($14|0);
    if ($23) {
     label = 13;
     break;
    } else {
     $19 = $24;
    }
   }
   if ((label|0) == 12) {
    $29 = ___cxa_find_matching_catch()|0;
    $30 = tempRet0;
    ___cxa_call_unexpected(($29|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $31 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy10|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorINS2_12basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES7_ISA_LS8_90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorINS0_12basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES5_IS8_LS6_90ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$25,0);
   __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
   $26 = (($25) + 12|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z33EmitSerializationCommandsForFieldI19StreamedBinaryWriteILb0EEEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$0$i$ph9 = 0, $$off = 0, $$ph = 0, $$ph8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $serializeFieldCommand = 0, $staticInfo$sroa$9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $staticInfo$sroa$9 = sp;
 $serializeFieldCommand = sp + 16|0;
 $1 = (($tfi) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z24scripting_class_get_typeP14ScriptingClass($2)|0);
 $4 = (__Z23scripting_type_get_typeP13ScriptingType($3)|0);
 $5 = ($4|0)==(29);
 if (!($5)) {
  $6 = (__ZN9Scripting30IsSystemCollectionsGenericListEP14ScriptingClass($2)|0);
  if (!($6)) {
   ;HEAP32[$staticInfo$sroa$9+0>>2]=0|0;HEAP32[$staticInfo$sroa$9+4>>2]=0|0;HEAP32[$staticInfo$sroa$9+8>>2]=0|0;
   $7 = HEAP32[$tfi>>2]|0;
   $8 = (__Z24scripting_field_get_nameP14ScriptingField($7)|0);
   $9 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $10 = (__Z25scripting_class_from_typeP13ScriptingType($9)|0);
   $11 = (__Z24scripting_field_get_typeP14ScriptingField($7)|0);
   $12 = (__Z23scripting_type_get_typeP13ScriptingType($11)|0);
   $13 = (__Z26scripting_field_get_offsetP14ScriptingField($7)|0);
   $14 = (__Z24scripting_class_get_nameP14ScriptingClass($10)|0);
   $15 = (($tfi) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = (($tfi) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($tfi) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   L4: do {
    switch ($19|0) {
    case 13:  {
     $$0$i$ph = 3151;$$ph = $16;
     label = 47;
     break;
    }
    case 2:  {
     $23 = $16 | 256;
     $$0$i$ph = 3144;$$ph = $23;
     label = 47;
     break;
    }
    case 3:  {
     $22 = $16 | 33554432;
     $$0$i$ph = 3142;$$ph = $22;
     label = 47;
     break;
    }
    case 5:  {
     $$0$i$ph = 3144;$$ph = $16;
     label = 47;
     break;
    }
    case 6:  {
     $$0$i$ph = 3145;$$ph = $16;
     label = 47;
     break;
    }
    case 12:  {
     $$0$i$ph = 3150;$$ph = $16;
     label = 47;
     break;
    }
    case 9:  {
     $$0$i$ph = 3147;$$ph = $16;
     label = 47;
     break;
    }
    case 4:  {
     $$0$i$ph = 3143;$$ph = $16;
     label = 47;
     break;
    }
    case 10:  {
     $$0$i$ph = 3148;$$ph = $16;
     label = 47;
     break;
    }
    case 11:  {
     $$0$i$ph = 3149;$$ph = $16;
     label = 47;
     break;
    }
    case 7:  {
     $$0$i$ph = 3142;$$ph = $16;
     label = 47;
     break;
    }
    case 8:  {
     $$0$i$ph = 3146;$$ph = $16;
     label = 47;
     break;
    }
    case 14:  {
     $$0$i$ph = 3141;$$ph = $16;
     label = 47;
     break;
    }
    default: {
     $24 = (($21) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($17|0)==($25|0);
     if ($26) {
      $$0$i$ph = 3152;$$ph = $16;
      label = 47;
     } else {
      $27 = (($21) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($17|0)==($28|0);
      if ($29) {
       $$0$i$ph = 3153;$$ph = $16;
       label = 47;
      } else {
       $30 = (($21) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($17|0)==($31|0);
       if ($32) {
        $$0$i$ph = 3154;$$ph = $16;
        label = 47;
       } else {
        $33 = (($21) + 24|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = ($17|0)==($34|0);
        if ($35) {
         $$0$i$ph = 3155;$$ph = $16;
         label = 47;
        } else {
         $36 = (($21) + 32|0);
         $37 = HEAP32[$36>>2]|0;
         $38 = ($17|0)==($37|0);
         if ($38) {
          $$0$i$ph = 3156;$$ph = $16;
          label = 47;
         } else {
          $39 = (($21) + 36|0);
          $40 = HEAP32[$39>>2]|0;
          $41 = ($17|0)==($40|0);
          if ($41) {
           $$0$i$ph = 3157;$$ph = $16;
           label = 47;
          } else {
           $42 = (($21) + 40|0);
           $43 = HEAP32[$42>>2]|0;
           $44 = ($17|0)==($43|0);
           if ($44) {
            $$0$i$ph = 3158;$$ph = $16;
            label = 47;
           } else {
            $45 = (($21) + 52|0);
            $46 = HEAP32[$45>>2]|0;
            $47 = ($17|0)==($46|0);
            if ($47) {
             $$0$i$ph = 3159;$$ph = $16;
             label = 47;
            } else {
             $48 = (($21) + 56|0);
             $49 = HEAP32[$48>>2]|0;
             $50 = ($17|0)==($49|0);
             if ($50) {
              $$0$i$ph = 3160;$$ph = $16;
              label = 47;
             } else {
              $51 = (($21) + 88|0);
              $52 = HEAP32[$51>>2]|0;
              $53 = ($17|0)==($52|0);
              if ($53) {
               $$0$i$ph = 3161;$$ph = $16;
               label = 47;
              } else {
               $54 = (($21) + 492|0);
               $55 = HEAP32[$54>>2]|0;
               $56 = ($17|0)==($55|0);
               do {
                if (!($56)) {
                 $57 = (($21) + 496|0);
                 $58 = HEAP32[$57>>2]|0;
                 $59 = ($17|0)==($58|0);
                 if (!($59)) {
                  $60 = (__Z23scripting_class_is_enumP14ScriptingClass($17)|0);
                  if (!($60)) {
                   $85 = (($21) + 280|0);
                   $86 = HEAP32[$85>>2]|0;
                   $87 = ($17|0)==($86|0);
                   if ($87) {
                    $$0$i$ph = 3162;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $88 = (($21) + 504|0);
                   $89 = HEAP32[$88>>2]|0;
                   $90 = ($17|0)==($89|0);
                   if ($90) {
                    $$0$i$ph = 3163;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $91 = (($21) + 28|0);
                   $92 = HEAP32[$91>>2]|0;
                   $93 = ($17|0)==($92|0);
                   if ($93) {
                    $$0$i$ph = 3164;$$ph = $16;
                    label = 47;
                    break L4;
                   }
                   $94 = (($21) + 272|0);
                   $95 = HEAP32[$94>>2]|0;
                   $96 = ($17|0)==($95|0);
                   if ($96) {
                    $$0$i$ph9 = 3165;$$ph8 = $16;
                    break L4;
                   }
                   $97 = ($19|0)==(18);
                   if (!($97)) {
                    break;
                   }
                   $98 = (($21) + 244|0);
                   $99 = HEAP32[$98>>2]|0;
                   $100 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($17,$99)|0);
                   if ($100) {
                    $$0$i$ph9 = 3166;$$ph8 = $16;
                    break L4;
                   } else {
                    break;
                   }
                  }
                  $61 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($17)|0);
                  $62 = (__Z23scripting_type_get_typeP13ScriptingType($61)|0);
                  if ((($62|0) == 5)) {
                   $$0$i$ph = 3144;$$ph = $16;
                   label = 47;
                   break L4;
                  } else if ((($62|0) == 8)) {
                   $$0$i$ph = 3146;$$ph = $16;
                   label = 47;
                   break L4;
                  }
                  $63 = HEAP32[$tfi>>2]|0;
                  __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$63);
                  $64 = HEAP8[$0>>0]|0;
                  $65 = $64 & 1;
                  $66 = ($65<<24>>24)==(0);
                  if ($66) {
                   $69 = (($0) + 1|0);
                   $70 = $69;
                  } else {
                   $67 = (($0) + 8|0);
                   $68 = HEAP32[$67>>2]|0;
                   $70 = $68;
                  }
                  __THREW__ = 0;
                  invoke_viiiiiiii(21,($70|0),0,(630440|0),188,1,0,0,(0|0));
                  $71 = __THREW__; __THREW__ = 0;
                  $72 = $71&1;
                  if (!($72)) {
                   $73 = HEAP8[$0>>0]|0;
                   $74 = $73 & 1;
                   $75 = ($74<<24>>24)==(0);
                   if ($75) {
                    break;
                   }
                   $76 = (($0) + 8|0);
                   $77 = HEAP32[$76>>2]|0;
                   __ZdlPv($77);
                   break;
                  }
                  $78 = ___cxa_find_matching_catch()|0;
                  $79 = tempRet0;
                  $80 = HEAP8[$0>>0]|0;
                  $81 = $80 & 1;
                  $82 = ($81<<24>>24)==(0);
                  if ($82) {
                   ___resumeException($78|0);
                   // unreachable;
                  }
                  $83 = (($0) + 8|0);
                  $84 = HEAP32[$83>>2]|0;
                  __ZdlPv($84);
                  ___resumeException($78|0);
                  // unreachable;
                 }
                }
               } while(0);
               $114 = HEAP32[$18>>2]|0;
               $$off = (($114) + -17)|0;
               $115 = ($$off>>>0)<(2);
               if (!($115)) {
                STACKTOP = sp;return;
               }
               __Z46EmitSerializationCommandsForManagedObjectFieldI19StreamedBinaryWriteILb0EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
    }
   } while(0);
   if ((label|0) == 47) {
    $101 = (($tfi) + 25|0);
    $102 = HEAP8[$101>>0]|0;
    $103 = ($102<<24>>24)==(0);
    if ($103) {
     $$0$i$ph9 = $$0$i$ph;$$ph8 = $$ph;
    } else {
     STACKTOP = sp;return;
    }
   }
   dest=$serializeFieldCommand+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$serializeFieldCommand>>2] = $$0$i$ph9;
   $104 = (($serializeFieldCommand) + 4|0);
   HEAP32[$104>>2] = $7;
   $105 = (($serializeFieldCommand) + 8|0);
   HEAP32[$105>>2] = $8;
   $106 = (($serializeFieldCommand) + 12|0);
   HEAP32[$106>>2] = $14;
   $107 = (($serializeFieldCommand) + 16|0);
   HEAP32[$107>>2] = $10;
   $108 = (($serializeFieldCommand) + 20|0);
   HEAP32[$108>>2] = $12;
   $109 = (($serializeFieldCommand) + 24|0);
   HEAP32[$109>>2] = $13;
   $110 = (($serializeFieldCommand) + 28|0);
   HEAP32[$110>>2] = $$ph8;
   $111 = (($serializeFieldCommand) + 32|0);
   HEAP32[$111>>2] = $17;
   $112 = (($serializeFieldCommand) + 36|0);
   HEAP32[$112>>2] = $19;
   $113 = (($serializeFieldCommand) + 40|0);
   ;HEAP32[$113+0>>2]=HEAP32[$staticInfo$sroa$9+0>>2]|0;HEAP32[$113+4>>2]=HEAP32[$staticInfo$sroa$9+4>>2]|0;HEAP32[$113+8>>2]=HEAP32[$staticInfo$sroa$9+8>>2]|0;
   __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$serializeFieldCommand);
   STACKTOP = sp;return;
  }
 }
 __Z49EmitSerializationCommandsForLinearCollectionFieldI19StreamedBinaryWriteILb0EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions);
 STACKTOP = sp;return;
}
function __ZL12InvokeMethodI19StreamedBinaryWriteILb0EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $invocation = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $invocation = sp + 8|0;
 $0 = sp;
 $1 = (($args) + 57|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($args) + 48|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $15 = (($runtimeInfo) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($invocation) + 12|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP8[$runtimeInfo>>0]|0;
 $19 = (($invocation) + 24|0);
 HEAP8[$19>>0] = $18;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation)|0);
 STACKTOP = sp;return;
}
function __Z49EmitSerializationCommandsForLinearCollectionFieldI19StreamedBinaryWriteILb0EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($info,$commandQueueBuilder,$nameConversions) {
 $info = $info|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$0$i$ph = 0, $$off = 0, $$ph = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $command = 0, $linearCollectionField = 0, $switch = 0, $tfi = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 184|0;
 $linearCollectionField = sp + 144|0;
 $1 = sp + 68|0;
 $tfi = sp;
 $command = sp + 80|0;
 $$sroa$9 = sp + 56|0;
 HEAP8[$1>>0] = 1;
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$info>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$1,$4);
 dest=$tfi+0|0; src=$info+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $5 = HEAP32[$info>>2]|0;
 HEAP32[$tfi>>2] = $5;
 $6 = (__ZN21LinearCollectionField15GetElementClassEv($linearCollectionField)|0);
 $7 = (($tfi) + 40|0);
 HEAP32[$7>>2] = $6;
 $8 = (__Z24scripting_class_get_typeP14ScriptingClass($6)|0);
 $9 = (__Z23scripting_type_get_typeP13ScriptingType($8)|0);
 $10 = (($tfi) + 44|0);
 HEAP32[$10>>2] = $9;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 dest=$command+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$command>>2] = 3167;
 ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
 $14 = (__Z24scripting_field_get_nameP14ScriptingField($5)|0);
 $15 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $16 = (__Z25scripting_class_from_typeP13ScriptingType($15)|0);
 $17 = (__Z24scripting_field_get_typeP14ScriptingField($5)|0);
 $18 = (__Z23scripting_type_get_typeP13ScriptingType($17)|0);
 $19 = (__Z26scripting_field_get_offsetP14ScriptingField($5)|0);
 $20 = (__Z24scripting_class_get_nameP14ScriptingClass($16)|0);
 $21 = (($tfi) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($command) + 4|0);
 HEAP32[$23>>2] = $5;
 $24 = (($command) + 8|0);
 HEAP32[$24>>2] = $14;
 $25 = (($command) + 12|0);
 HEAP32[$25>>2] = $20;
 $26 = (($command) + 16|0);
 HEAP32[$26>>2] = $16;
 $27 = (($command) + 20|0);
 HEAP32[$27>>2] = $18;
 $28 = (($command) + 24|0);
 HEAP32[$28>>2] = $19;
 $29 = (($command) + 28|0);
 HEAP32[$29>>2] = $22;
 $30 = (($command) + 32|0);
 HEAP32[$30>>2] = $6;
 $31 = (($command) + 36|0);
 HEAP32[$31>>2] = $9;
 $32 = (($command) + 40|0);
 ;HEAP32[$32+0>>2]=HEAP32[$$sroa$9+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$$sroa$9+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$$sroa$9+8>>2]|0;
 $33 = (($tfi) + 36|0);
 $34 = HEAP32[$33>>2]|0;
 L1: do {
  switch ($9|0) {
  case 6:  {
   $$0$i$ph = 3172;$$ph = 1;
   break;
  }
  case 14:  {
   $$0$i$ph = 3168;$$ph = 1;
   break;
  }
  case 3:  {
   $35 = $22 | 33554432;
   HEAP32[$29>>2] = $35;
   $$0$i$ph = 3169;$$ph = 1;
   break;
  }
  case 10:  {
   $$0$i$ph = 3175;$$ph = 1;
   break;
  }
  case 9:  {
   $$0$i$ph = 3174;$$ph = 1;
   break;
  }
  case 11:  {
   $$0$i$ph = 3176;$$ph = 1;
   break;
  }
  case 2:  {
   $36 = $22 | 256;
   HEAP32[$29>>2] = $36;
   $$0$i$ph = 3171;$$ph = 1;
   break;
  }
  case 7:  {
   $$0$i$ph = 3169;$$ph = 1;
   break;
  }
  case 12:  {
   $$0$i$ph = 3177;$$ph = 1;
   break;
  }
  case 13:  {
   $$0$i$ph = 3178;$$ph = 1;
   break;
  }
  case 8:  {
   $$0$i$ph = 3173;$$ph = 1;
   break;
  }
  case 5:  {
   $$0$i$ph = 3171;$$ph = 1;
   break;
  }
  case 4:  {
   $$0$i$ph = 3170;$$ph = 1;
   break;
  }
  default: {
   $37 = (($34) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($6|0)==($38|0);
   if ($39) {
    $$0$i$ph = 3179;$$ph = 1;
   } else {
    $40 = (($34) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($6|0)==($41|0);
    if ($42) {
     $$0$i$ph = 3180;$$ph = 1;
    } else {
     $43 = (($34) + 20|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($6|0)==($44|0);
     if ($45) {
      $$0$i$ph = 3181;$$ph = 1;
     } else {
      $46 = (($34) + 24|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($6|0)==($47|0);
      if ($48) {
       $$0$i$ph = 3182;$$ph = 1;
      } else {
       $49 = (($34) + 32|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($6|0)==($50|0);
       if ($51) {
        $$0$i$ph = 3183;$$ph = 1;
       } else {
        $52 = (($34) + 36|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($6|0)==($53|0);
        if ($54) {
         $$0$i$ph = 3184;$$ph = 1;
        } else {
         $55 = (($34) + 40|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($6|0)==($56|0);
         if ($57) {
          $$0$i$ph = 3185;$$ph = 1;
         } else {
          $58 = (($34) + 52|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = ($6|0)==($59|0);
          if ($60) {
           $$0$i$ph = 3186;$$ph = 1;
          } else {
           $61 = (($34) + 56|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = ($6|0)==($62|0);
           if ($63) {
            $$0$i$ph = 3187;$$ph = 1;
           } else {
            $64 = (($34) + 88|0);
            $65 = HEAP32[$64>>2]|0;
            $66 = ($6|0)==($65|0);
            if ($66) {
             $$0$i$ph = 3188;$$ph = 1;
            } else {
             $67 = (($34) + 492|0);
             $68 = HEAP32[$67>>2]|0;
             $69 = ($6|0)==($68|0);
             do {
              if ($69) {
               label = 44;
              } else {
               $70 = (($34) + 496|0);
               $71 = HEAP32[$70>>2]|0;
               $72 = ($6|0)==($71|0);
               if ($72) {
                label = 44;
               } else {
                $73 = (__Z23scripting_class_is_enumP14ScriptingClass($6)|0);
                if (!($73)) {
                 $97 = (($34) + 280|0);
                 $98 = HEAP32[$97>>2]|0;
                 $99 = ($6|0)==($98|0);
                 if ($99) {
                  $$0$i$ph = 3189;$$ph = 1;
                  break L1;
                 }
                 $100 = (($34) + 504|0);
                 $101 = HEAP32[$100>>2]|0;
                 $102 = ($6|0)==($101|0);
                 if ($102) {
                  $$0$i$ph = 3190;$$ph = 1;
                  break L1;
                 }
                 $103 = (($34) + 28|0);
                 $104 = HEAP32[$103>>2]|0;
                 $105 = ($6|0)==($104|0);
                 if ($105) {
                  $$0$i$ph = 3191;$$ph = 1;
                  break L1;
                 }
                 $106 = (($34) + 272|0);
                 $107 = HEAP32[$106>>2]|0;
                 $108 = ($6|0)==($107|0);
                 if ($108) {
                  $$0$i$ph = 3192;$$ph = 0;
                  break L1;
                 }
                 $109 = ($9|0)==(18);
                 if (!($109)) {
                  label = 44;
                  break;
                 }
                 $110 = (($34) + 244|0);
                 $111 = HEAP32[$110>>2]|0;
                 $112 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$111)|0);
                 if ($112) {
                  $$0$i$ph = 3193;$$ph = 0;
                  break L1;
                 } else {
                  break;
                 }
                }
                $74 = (__Z29scripting_class_enum_basetypeP14ScriptingClass($6)|0);
                $75 = (__Z23scripting_type_get_typeP13ScriptingType($74)|0);
                if ((($75|0) == 8)) {
                 $$0$i$ph = 3173;$$ph = 1;
                 break L1;
                } else if ((($75|0) == 5)) {
                 $$0$i$ph = 3171;$$ph = 1;
                 break L1;
                }
                __ZN9Scripting35ErrorMessageForUnsupportedEnumFieldEP14ScriptingField($0,$5);
                $76 = HEAP8[$0>>0]|0;
                $77 = $76 & 1;
                $78 = ($77<<24>>24)==(0);
                if ($78) {
                 $81 = (($0) + 1|0);
                 $82 = $81;
                } else {
                 $79 = (($0) + 8|0);
                 $80 = HEAP32[$79>>2]|0;
                 $82 = $80;
                }
                __THREW__ = 0;
                invoke_viiiiiiii(21,($82|0),0,(630440|0),188,1,0,0,(0|0));
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if (!($84)) {
                 $85 = HEAP8[$0>>0]|0;
                 $86 = $85 & 1;
                 $87 = ($86<<24>>24)==(0);
                 if ($87) {
                  label = 44;
                  break;
                 }
                 $88 = (($0) + 8|0);
                 $89 = HEAP32[$88>>2]|0;
                 __ZdlPv($89);
                 label = 44;
                 break;
                }
                $90 = ___cxa_find_matching_catch()|0;
                $91 = tempRet0;
                $92 = HEAP8[$0>>0]|0;
                $93 = $92 & 1;
                $94 = ($93<<24>>24)==(0);
                if ($94) {
                 ___resumeException($90|0);
                 // unreachable;
                }
                $95 = (($0) + 8|0);
                $96 = HEAP32[$95>>2]|0;
                __ZdlPv($96);
                ___resumeException($90|0);
                // unreachable;
               }
              }
             } while(0);
             if ((label|0) == 44) {
              $$off = (($9) + -17)|0;
              $switch = ($$off>>>0)<(2);
              if (!($switch)) {
               STACKTOP = sp;return;
              }
             }
             __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI19StreamedBinaryWriteILb0EEEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$command,$commandQueueBuilder,$nameConversions);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
  }
 } while(0);
 $113 = (($tfi) + 25|0);
 $114 = HEAP8[$113>>0]|0;
 $115 = $114 & $$ph;
 $116 = ($115<<24>>24)==(0);
 if (!($116)) {
  STACKTOP = sp;return;
 }
 $117 = (($command) + 44|0);
 HEAP32[$117>>2] = $$0$i$ph;
 __ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand($commandQueueBuilder,$command);
 STACKTOP = sp;return;
}
function __Z46EmitSerializationCommandsForManagedObjectFieldI19StreamedBinaryWriteILb0EEEvRK18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$sroa$9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $args = 0, $newCommandQueueBuilder = 0, $serializeManagedObject = 0, $tfi$idx = 0, $tfi$idx$val = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy1 = sp + 124|0;
 $0 = sp + 120|0;
 $args = sp + 12|0;
 $newCommandQueueBuilder = sp + 32|0;
 $serializeManagedObject = sp + 56|0;
 $$sroa$9 = sp;
 $tfi$idx = (($tfi) + 4|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI18TransferField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$8>>2] = $13;
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 $14 = (($newCommandQueueBuilder) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($newCommandQueueBuilder) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($newCommandQueueBuilder) + 4|0);
 HEAP32[$16>>2] = 61;
 $17 = (($newCommandQueueBuilder) + 16|0);
 HEAP8[$17>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(382,($args|0),($newCommandQueueBuilder|0),($nameConversions|0),0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 do {
  if (!($19)) {
   $20 = (($tfi) + 25|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    label = 8;
   } else {
    $23 = HEAP32[$14>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    dest=$serializeManagedObject+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$serializeManagedObject>>2] = 3194;
    ;HEAP32[$$sroa$9+0>>2]=0|0;HEAP32[$$sroa$9+4>>2]=0|0;HEAP32[$$sroa$9+8>>2]=0|0;
    $33 = HEAP32[$tfi>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3280,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3276,($33|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3278,($37|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_ii(3276,($33|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    $46 = (invoke_ii(3277,($43|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    __THREW__ = 0;
    $49 = (invoke_ii(3283,($33|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    __THREW__ = 0;
    $52 = (invoke_ii(3284,($40|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    $55 = (($tfi) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$tfi$idx>>2]|0;
    $58 = (($tfi) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($serializeManagedObject) + 4|0);
    HEAP32[$60>>2] = $33;
    $61 = (($serializeManagedObject) + 8|0);
    HEAP32[$61>>2] = $34;
    $62 = (($serializeManagedObject) + 12|0);
    HEAP32[$62>>2] = $52;
    $63 = (($serializeManagedObject) + 16|0);
    HEAP32[$63>>2] = $40;
    $64 = (($serializeManagedObject) + 20|0);
    HEAP32[$64>>2] = $46;
    $65 = (($serializeManagedObject) + 24|0);
    HEAP32[$65>>2] = $49;
    $66 = (($serializeManagedObject) + 28|0);
    HEAP32[$66>>2] = $56;
    $67 = (($serializeManagedObject) + 32|0);
    HEAP32[$67>>2] = $57;
    $68 = (($serializeManagedObject) + 36|0);
    HEAP32[$68>>2] = $59;
    $69 = (($serializeManagedObject) + 40|0);
    $70 = $$sroa$9;
    $71 = $70;
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + 4)|0;
    $74 = $73;
    $75 = HEAP32[$74>>2]|0;
    $76 = $69;
    $77 = $76;
    HEAP32[$77>>2] = $72;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = $75;
    $80 = HEAP32[$14>>2]|0;
    $81 = (($serializeManagedObject) + 48|0);
    HEAP32[$81>>2] = $80;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($serializeManagedObject|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($newCommandQueueBuilder|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
   }
   $86 = HEAP32[$15>>2]|0;
   $87 = ($86|0)>(-1);
   if (!($87)) {
    STACKTOP = sp;return;
   }
   $88 = HEAP32[$newCommandQueueBuilder>>2]|0;
   $89 = HEAP32[$16>>2]|0;
   HEAP32[$0>>2] = $89;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($88,$$byval_copy1);
   HEAP32[$newCommandQueueBuilder>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$15>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = HEAP32[$newCommandQueueBuilder>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $90 = ___cxa_find_matching_catch(0|0)|0;
  $91 = tempRet0;
  ___clang_call_terminate($90);
  // unreachable;
 }
 HEAP32[$newCommandQueueBuilder>>2] = 0;
 ___resumeException($25|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $$phi$trans$insert1 = 0, $$phi$trans$insert3 = 0, $$pre = 0, $$pre$i = 0, $$pre2 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $managedObjectTransferer$sroa$2 = 0, $newProvider = 0, $runtimeInfo$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $runtimeInfo$i$i$i = sp + 32|0;
 $managedObjectTransferer$sroa$2 = sp + 56|0;
 $0 = sp + 20|0;
 $newProvider = sp;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP8[$managedObjectTransferer$sroa$2+0>>0]=0|0;HEAP8[$managedObjectTransferer$sroa$2+1>>0]=0|0;HEAP8[$managedObjectTransferer$sroa$2+2>>0]=0|0;
 $3 = (($runtimeInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = (($args) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(17);
 do {
  if ($5) {
   $$pre$i = (($args) + 12|0);
   if ($8) {
    $13 = 0;
   } else {
    $9 = HEAP32[$$pre$i>>2]|0;
    $10 = (_il2cpp_object_new($9)|0);
    $13 = $10;
   }
   $11 = HEAP32[$$pre$i>>2]|0;
   HEAP8[$0>>0] = 1;
   $12 = (($0) + 4|0);
   HEAP32[$12>>2] = $13;
   $14 = (($0) + 8|0);
   HEAP32[$14>>2] = $11;
   $41 = 1;$44 = $13;$46 = $11;
  } else {
   if ($8) {
    $15 = (($args) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = HEAP8[$runtimeInfo>>0]|0;
    $18 = ($17<<24>>24)!=(0);
    $19 = (($16) + -8)|0;
    $20 = $18 ? $16 : $19;
    $21 = (($4) + ($20)|0);
    $22 = (($args) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    HEAP8[$0>>0] = 0;
    $24 = (($0) + 4|0);
    HEAP32[$24>>2] = $21;
    $25 = (($0) + 8|0);
    HEAP32[$25>>2] = $23;
    $41 = 0;$44 = $21;$46 = $23;
    break;
   } else {
    $26 = HEAP32[$args>>2]|0;
    __Z30GetOrCreateObjectStoredInFieldP14ScriptingFieldRK17GeneralMonoObjectb($0,$26,$runtimeInfo,1);
    $$pre = HEAP8[$0>>0]|0;
    $$phi$trans$insert1 = (($0) + 4|0);
    $$pre2 = HEAP32[$$phi$trans$insert1>>2]|0;
    $$phi$trans$insert3 = (($0) + 8|0);
    $$pre4 = HEAP32[$$phi$trans$insert3>>2]|0;
    $41 = $$pre;$44 = $$pre2;$46 = $$pre4;
    break;
   }
  }
 } while(0);
 $27 = (($0) + 1|0);
 ;HEAP8[$managedObjectTransferer$sroa$2+0>>0]=HEAP8[$27+0>>0]|0;HEAP8[$managedObjectTransferer$sroa$2+1>>0]=HEAP8[$27+1>>0]|0;HEAP8[$managedObjectTransferer$sroa$2+2>>0]=HEAP8[$27+2>>0]|0;
 $28 = (($runtimeInfo) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($args) + 44|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + ($31<<6)|0);
 HEAP32[$32>>2] = $34;
 $35 = (($newProvider) + 4|0);
 HEAP32[$35>>2] = $33;
 HEAP32[$newProvider>>2] = $33;
 $36 = (($newProvider) + 8|0);
 HEAP32[$36>>2] = $34;
 $$idx$i = $31 << 6;
 $37 = $$idx$i >> 6;
 $38 = (($newProvider) + 16|0);
 HEAP32[$38>>2] = $37;
 $39 = (($newProvider) + 12|0);
 HEAP32[$39>>2] = $37;
 ;HEAP32[$runtimeInfo$i$i$i+0>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+4>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+8>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+12>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+16>>2]=0|0;HEAP32[$runtimeInfo$i$i$i+20>>2]=0|0;
 $40 = (($runtimeInfo$i$i$i) + 16|0);
 HEAP32[$40>>2] = $2;
 HEAP8[$runtimeInfo$i$i$i>>0] = $41;
 $42 = (($runtimeInfo$i$i$i) + 1|0);
 ;HEAP8[$42+0>>0]=HEAP8[$managedObjectTransferer$sroa$2+0>>0]|0;HEAP8[$42+1>>0]=HEAP8[$managedObjectTransferer$sroa$2+1>>0]|0;HEAP8[$42+2>>0]=HEAP8[$managedObjectTransferer$sroa$2+2>>0]|0;
 $43 = (($runtimeInfo$i$i$i) + 4|0);
 HEAP32[$43>>2] = $44;
 $45 = (($runtimeInfo$i$i$i) + 8|0);
 HEAP32[$45>>2] = $46;
 $47 = (($runtimeInfo$i$i$i) + 12|0);
 HEAP32[$47>>2] = $newProvider;
 $48 = ($31|0)==(0);
 if ($48) {
  STACKTOP = sp;return;
 } else {
  $50 = $33;$52 = $34;
 }
 while(1) {
  $49 = (($50) + 64|0);
  HEAP32[$35>>2] = $49;
  $51 = $52;
  $53 = $49;
  $54 = (($51) - ($53))|0;
  $55 = $54 >> 6;
  HEAP32[$39>>2] = $55;
  $56 = HEAP32[$50>>2]|0;
  $57 = (($50) + 4|0);
  FUNCTION_TABLE_vii[$56 & 4095]($57,$runtimeInfo$i$i$i);
  $58 = HEAP32[$35>>2]|0;
  $59 = HEAP32[$36>>2]|0;
  $60 = ($58|0)==($59|0);
  if ($60) {
   break;
  } else {
   $50 = $58;$52 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $native$i$i = sp + 4|0;
 ;HEAP32[$native$i$i+0>>2]=0|0;HEAP32[$native$i$i+4>>2]=0|0;HEAP32[$native$i$i+8>>2]=0|0;
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$runtimeInfo>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($4) + -8)|0;
 $8 = $6 ? $4 : $7;
 $9 = (($runtimeInfo) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($8)|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 invoke_viii(1906,0,($12|0),($native$i$i|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  __THREW__ = 0;
  invoke_viii(1624,($2|0),($native$i$i|0),0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   __THREW__ = 0;
   invoke_vi(3378,($2|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    $30 = HEAP8[$native$i$i>>0]|0;
    $31 = $30 & 1;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     STACKTOP = sp;return;
    }
    $33 = (($native$i$i) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($34|0),($$byval_copy1|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     $37 = ___cxa_find_matching_catch()|0;
     $38 = tempRet0;
     ___cxa_call_unexpected(($37|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $17 = HEAP8[$native$i$i>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  ___resumeException($15|0);
  // unreachable;
 }
 $20 = (($native$i$i) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($21|0),($$byval_copy1|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  ___cxa_call_unexpected(($24|0));
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __Z22Transfer_Builtin_AlignIa19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP8[$8>>0]|0;
  HEAP8[$12>>0] = $17;
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$11>>2] = $19;
  $20 = HEAP32[$9>>2]|0;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($20);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,1);
  $20 = HEAP32[$9>>2]|0;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($20);
  STACKTOP = sp;return;
 }
}
function __Z22Transfer_Builtin_AlignIh19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP8[$8>>0]|0;
  HEAP8[$12>>0] = $17;
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$11>>2] = $19;
  $20 = HEAP32[$9>>2]|0;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($20);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,1);
  $20 = HEAP32[$9>>2]|0;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($20);
  STACKTOP = sp;return;
 }
}
function __Z22Transfer_Builtin_AlignIs19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 2|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP16[$8>>1]|0;
  HEAP16[$12>>1] = $17;
  HEAP32[$11>>2] = $13;
  $18 = HEAP32[$9>>2]|0;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($18);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,2);
  $18 = HEAP32[$9>>2]|0;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($18);
  STACKTOP = sp;return;
 }
}
function __Z22Transfer_Builtin_AlignIt19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 2|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP16[$8>>1]|0;
  HEAP16[$12>>1] = $17;
  HEAP32[$11>>2] = $13;
  $18 = HEAP32[$9>>2]|0;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($18);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,2);
  $18 = HEAP32[$9>>2]|0;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($18);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIi19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP32[$8>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,4);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIj19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP32[$8>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,4);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIx19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = $8;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = $12;
  $24 = $23;
  HEAP32[$24>>2] = $19;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $22;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,8);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIy19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = $8;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = $12;
  $24 = $23;
  HEAP32[$24>>2] = $19;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $22;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,8);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinIf19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$12>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,4);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinId19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = $8;
  $18 = $17;
  $19 = HEAPU8[$18>>0]|(HEAPU8[$18+1>>0]<<8)|(HEAPU8[$18+2>>0]<<16)|(HEAPU8[$18+3>>0]<<24);
  $20 = (($17) + 4)|0;
  $21 = $20;
  $22 = HEAPU8[$21>>0]|(HEAPU8[$21+1>>0]<<8)|(HEAPU8[$21+2>>0]<<16)|(HEAPU8[$21+3>>0]<<24);
  $23 = $12;
  $24 = $23;
  HEAP8[$24>>0]=$19&255;HEAP8[$24+1>>0]=($19>>8)&255;HEAP8[$24+2>>0]=($19>>16)&255;HEAP8[$24+3>>0]=$19>>24;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP8[$26>>0]=$22&255;HEAP8[$26+1>>0]=($22>>8)&255;HEAP8[$26+2>>0]=($22>>16)&255;HEAP8[$26+3>>0]=$22>>24;
  $27 = HEAP32[$11>>2]|0;
  $28 = (($27) + 8|0);
  HEAP32[$11>>2] = $28;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,8);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8Vector3f19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5$i$i$i = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$12>>2] = $17;
  HEAP32[$11>>2] = $13;
  $20 = $13;$22 = $15;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $$pre3$i$i$i = HEAP32[$14>>2]|0;
  $20 = $$pre$i$i$i;$22 = $$pre3$i$i$i;
 }
 $$sum = (($5) + 4)|0;
 $18 = (($7) + ($$sum)|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)<($22>>>0);
 if ($21) {
  $23 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$20>>2] = $23;
  HEAP32[$11>>2] = $19;
  $26 = $19;$28 = $22;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$18,4);
  $$pre4$i$i$i = HEAP32[$11>>2]|0;
  $$pre5$i$i$i = HEAP32[$14>>2]|0;
  $26 = $$pre4$i$i$i;$28 = $$pre5$i$i$i;
 }
 $$sum1 = (($5) + 8)|0;
 $24 = (($7) + ($$sum1)|0);
 $25 = (($26) + 4|0);
 $27 = ($25>>>0)<($28>>>0);
 if ($27) {
  $29 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$26>>2] = $29;
  HEAP32[$11>>2] = $25;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$24,4);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8Vector2f19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$12>>2] = $17;
  HEAP32[$11>>2] = $13;
  $20 = $13;$22 = $15;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $$pre2$i$i$i = HEAP32[$14>>2]|0;
  $20 = $$pre$i$i$i;$22 = $$pre2$i$i$i;
 }
 $$sum = (($5) + 4)|0;
 $18 = (($7) + ($$sum)|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)<($22>>>0);
 if ($21) {
  $23 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$20>>2] = $23;
  HEAP32[$11>>2] = $19;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$18,4);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8Vector4f19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN5RectTIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN11Quaternionf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN10Matrix4x4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN4AABB8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$10);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3219StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP32[$8>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,4);
  STACKTOP = sp;return;
 }
}
function __Z16Transfer_BuiltinI8BitField19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($args) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP8[$runtimeInfo>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($1) + -8)|0;
 $5 = $3 ? $1 : $4;
 $6 = (($runtimeInfo) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5)|0);
 $9 = (($runtimeInfo) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($10) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP32[$8>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$11>>2] = $13;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($11,$8,4);
  STACKTOP = sp;return;
 }
}
function __ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z13TransferFieldI19StreamedBinaryWriteILb0EELb0E27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z13TransferFieldI19StreamedBinaryWriteILb0EELb0E27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$native$i$i+0>>2]=0|0;HEAP32[$native$i$i+4>>2]=0|0;HEAP32[$native$i$i+8>>2]=0|0;HEAP32[$native$i$i+12>>2]=0|0;
 $2 = (($runtimeInfo) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$runtimeInfo>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (($5) + -8)|0;
 $9 = $7 ? $5 : $8;
 $10 = (($runtimeInfo) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (_il2cpp_object_new($1)|0);
  __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($15);
  $17 = $15;
 } else {
  $17 = $13;
 }
 $16 = (($17) + 8|0);
 $18 = HEAP32[$16>>2]|0;
 ;HEAP32[$native$i$i+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$native$i$i+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$native$i$i+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$native$i$i+12>>2]=HEAP32[$18+12>>2]|0;
 __ZN10RectOffset8TransferI19StreamedBinaryWriteILb0EEEEvRT_($native$i$i,$3);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z22TransferField_NonArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $native$i$i = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = (($native$i$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($native$i$i) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($args) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$runtimeInfo>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (($5) + -8)|0;
 $9 = $7 ? $5 : $8;
 $10 = (($runtimeInfo) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($13)|0);
 HEAP32[$native$i$i>>2] = $14;
 __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($native$i$i,$3);
 STACKTOP = sp;return;
}
function __Z22TransferField_NonArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0;
 var $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0);
 var $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $native = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy1 = sp + 296|0;
 $0 = sp;
 $native = sp + 4|0;
 __ZN8GUIStyleC2Ev($native);
 $1 = (($runtimeInfo) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($staticInfo) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$runtimeInfo>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($4) + -8)|0;
 $8 = $6 ? $4 : $7;
 $9 = (($runtimeInfo) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($8)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $14 = HEAP32[$converter>>2]|0;
  __THREW__ = 0;
  $15 = (invoke_ii(3286,($14|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   invoke_vi(3549,($15|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $21 = $15;
    label = 4;
   }
  }
 } else {
  $21 = $12;
  label = 4;
 }
 if ((label|0) == 4) {
  $20 = (($21) + 8|0);
  $22 = HEAP32[$20>>2]|0;
  __THREW__ = 0;
  (invoke_iii(2359,($native|0),($22|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   $36 = (($22) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($native) + 12|0);
   HEAP32[$38>>2] = $37;
   $39 = (($22) + 16|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = (($22) + 20|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = (($22) + 24|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($22) + 28|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($native) + 16|0);
   HEAPF32[$47>>2] = $40;
   $48 = (($native) + 20|0);
   HEAPF32[$48>>2] = $42;
   $49 = (($native) + 24|0);
   HEAPF32[$49>>2] = $44;
   $50 = (($native) + 28|0);
   HEAPF32[$50>>2] = $46;
   $51 = (($22) + 32|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($native) + 32|0);
   HEAP32[$53>>2] = $52;
   $54 = (($22) + 36|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = (($22) + 40|0);
   $57 = Math_fround(HEAPF32[$56>>2]);
   $58 = (($22) + 44|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = (($22) + 48|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = (($native) + 36|0);
   HEAPF32[$62>>2] = $55;
   $63 = (($native) + 40|0);
   HEAPF32[$63>>2] = $57;
   $64 = (($native) + 44|0);
   HEAPF32[$64>>2] = $59;
   $65 = (($native) + 48|0);
   HEAPF32[$65>>2] = $61;
   $66 = (($22) + 52|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($native) + 52|0);
   HEAP32[$68>>2] = $67;
   $69 = (($22) + 56|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = (($22) + 60|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = (($22) + 64|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = (($22) + 68|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = (($native) + 56|0);
   HEAPF32[$77>>2] = $70;
   $78 = (($native) + 60|0);
   HEAPF32[$78>>2] = $72;
   $79 = (($native) + 64|0);
   HEAPF32[$79>>2] = $74;
   $80 = (($native) + 68|0);
   HEAPF32[$80>>2] = $76;
   $81 = (($22) + 72|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($native) + 72|0);
   HEAP32[$83>>2] = $82;
   $84 = (($22) + 76|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = (($22) + 80|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   $88 = (($22) + 84|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = (($22) + 88|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = (($native) + 76|0);
   HEAPF32[$92>>2] = $85;
   $93 = (($native) + 80|0);
   HEAPF32[$93>>2] = $87;
   $94 = (($native) + 84|0);
   HEAPF32[$94>>2] = $89;
   $95 = (($native) + 88|0);
   HEAPF32[$95>>2] = $91;
   $96 = (($22) + 92|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (($native) + 92|0);
   HEAP32[$98>>2] = $97;
   $99 = (($22) + 96|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = (($22) + 100|0);
   $102 = Math_fround(HEAPF32[$101>>2]);
   $103 = (($22) + 104|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = (($22) + 108|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = (($native) + 96|0);
   HEAPF32[$107>>2] = $100;
   $108 = (($native) + 100|0);
   HEAPF32[$108>>2] = $102;
   $109 = (($native) + 104|0);
   HEAPF32[$109>>2] = $104;
   $110 = (($native) + 108|0);
   HEAPF32[$110>>2] = $106;
   $111 = (($22) + 112|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = (($native) + 112|0);
   HEAP32[$113>>2] = $112;
   $114 = (($22) + 116|0);
   $115 = Math_fround(HEAPF32[$114>>2]);
   $116 = (($22) + 120|0);
   $117 = Math_fround(HEAPF32[$116>>2]);
   $118 = (($22) + 124|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = (($22) + 128|0);
   $121 = Math_fround(HEAPF32[$120>>2]);
   $122 = (($native) + 116|0);
   HEAPF32[$122>>2] = $115;
   $123 = (($native) + 120|0);
   HEAPF32[$123>>2] = $117;
   $124 = (($native) + 124|0);
   HEAPF32[$124>>2] = $119;
   $125 = (($native) + 128|0);
   HEAPF32[$125>>2] = $121;
   $126 = (($22) + 132|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($native) + 132|0);
   HEAP32[$128>>2] = $127;
   $129 = (($22) + 136|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = (($22) + 140|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $133 = (($22) + 144|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = (($22) + 148|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = (($native) + 136|0);
   HEAPF32[$137>>2] = $130;
   $138 = (($native) + 140|0);
   HEAPF32[$138>>2] = $132;
   $139 = (($native) + 144|0);
   HEAPF32[$139>>2] = $134;
   $140 = (($native) + 148|0);
   HEAPF32[$140>>2] = $136;
   $141 = (($22) + 152|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = (($native) + 152|0);
   HEAP32[$143>>2] = $142;
   $144 = (($22) + 156|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = (($22) + 160|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = (($22) + 164|0);
   $149 = Math_fround(HEAPF32[$148>>2]);
   $150 = (($22) + 168|0);
   $151 = Math_fround(HEAPF32[$150>>2]);
   $152 = (($native) + 156|0);
   HEAPF32[$152>>2] = $145;
   $153 = (($native) + 160|0);
   HEAPF32[$153>>2] = $147;
   $154 = (($native) + 164|0);
   HEAPF32[$154>>2] = $149;
   $155 = (($native) + 168|0);
   HEAPF32[$155>>2] = $151;
   $156 = (($native) + 172|0);
   $157 = (($22) + 172|0);
   dest=$156+0|0; src=$157+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $158 = (($22) + 236|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($native) + 236|0);
   HEAP32[$160>>2] = $159;
   $161 = (($native) + 240|0);
   $162 = (($22) + 240|0);
   dest=$161+0|0; src=$162+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[$161+48>>1]=HEAP16[$162+48>>1]|0;
   __THREW__ = 0;
   invoke_vii(3195,($native|0),($2|0));
   $163 = __THREW__; __THREW__ = 0;
   $164 = $163&1;
   if (!($164)) {
    $165 = HEAP8[$native>>0]|0;
    $166 = $165 & 1;
    $167 = ($166<<24>>24)==(0);
    if ($167) {
     STACKTOP = sp;return;
    }
    $168 = (($native) + 8|0);
    $169 = HEAP32[$168>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($169|0),($$byval_copy1|0));
    $170 = __THREW__; __THREW__ = 0;
    $171 = $170&1;
    if ($171) {
     $172 = ___cxa_find_matching_catch()|0;
     $173 = tempRet0;
     ___cxa_call_unexpected(($172|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP8[$native>>0]|0;
 $28 = $27 & 1;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  ___resumeException($25|0);
  // unreachable;
 }
 $30 = (($native) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy1|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
}
function __ZN8GUIStyle8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre2$i$i$i = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre9 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $0 = (($this) + 12|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 16|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($1,$transfer);
 $2 = (($this) + 32|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($2,$transfer);
 $3 = (($this) + 36|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($3,$transfer);
 $4 = (($this) + 52|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($4,$transfer);
 $5 = (($this) + 56|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($5,$transfer);
 $6 = (($this) + 72|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($6,$transfer);
 $7 = (($this) + 76|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($7,$transfer);
 $8 = (($this) + 92|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 96|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($9,$transfer);
 $10 = (($this) + 112|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 116|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($11,$transfer);
 $12 = (($this) + 132|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($12,$transfer);
 $13 = (($this) + 136|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($13,$transfer);
 $14 = (($this) + 152|0);
 __ZN4PPtrI9Texture2DE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($14,$transfer);
 $15 = (($this) + 156|0);
 __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($15,$transfer);
 $16 = (($this) + 172|0);
 __ZN10RectOffset8TransferI19StreamedBinaryWriteILb0EEEEvRT_($16,$transfer);
 $17 = (($this) + 188|0);
 __ZN10RectOffset8TransferI19StreamedBinaryWriteILb0EEEEvRT_($17,$transfer);
 $18 = (($this) + 204|0);
 __ZN10RectOffset8TransferI19StreamedBinaryWriteILb0EEEEvRT_($18,$transfer);
 $19 = (($this) + 220|0);
 __ZN10RectOffset8TransferI19StreamedBinaryWriteILb0EEEEvRT_($19,$transfer);
 $20 = (($this) + 236|0);
 __ZN4PPtrIN13TextRendering4FontEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($20,$transfer);
 $21 = (($this) + 280|0);
 $22 = (($transfer) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 4|0);
 $25 = (($transfer) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24>>>0)<($26>>>0);
 if ($27) {
  $28 = HEAP32[$21>>2]|0;
  HEAP32[$23>>2] = $28;
  HEAP32[$22>>2] = $24;
  $31 = $24;$33 = $26;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$21,4);
  $$pre = HEAP32[$22>>2]|0;
  $$pre9 = HEAP32[$25>>2]|0;
  $31 = $$pre;$33 = $$pre9;
 }
 $29 = (($this) + 284|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)<($33>>>0);
 if ($32) {
  $34 = HEAP32[$29>>2]|0;
  HEAP32[$31>>2] = $34;
  HEAP32[$22>>2] = $30;
  $37 = $30;$39 = $33;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$29,4);
  $$pre10 = HEAP32[$22>>2]|0;
  $$pre11 = HEAP32[$25>>2]|0;
  $37 = $$pre10;$39 = $$pre11;
 }
 $35 = (($this) + 240|0);
 $36 = (($37) + 4|0);
 $38 = ($36>>>0)<($39>>>0);
 if ($38) {
  $40 = HEAP32[$35>>2]|0;
  HEAP32[$37>>2] = $40;
  HEAP32[$22>>2] = $36;
  $43 = $36;$45 = $39;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$35,4);
  $$pre12 = HEAP32[$22>>2]|0;
  $$pre13 = HEAP32[$25>>2]|0;
  $43 = $$pre12;$45 = $$pre13;
 }
 $41 = (($this) + 244|0);
 $42 = (($43) + 1|0);
 $44 = ($42>>>0)<($45>>>0);
 if ($44) {
  $46 = HEAP8[$41>>0]|0;
  HEAP8[$43>>0] = $46;
  $47 = HEAP32[$22>>2]|0;
  $48 = (($47) + 1|0);
  HEAP32[$22>>2] = $48;
  $51 = $48;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$41,1);
  $$pre14 = HEAP32[$22>>2]|0;
  $51 = $$pre14;
 }
 $49 = (($this) + 245|0);
 $50 = (($51) + 1|0);
 $52 = HEAP32[$25>>2]|0;
 $53 = ($50>>>0)<($52>>>0);
 if ($53) {
  $54 = HEAP8[$49>>0]|0;
  HEAP8[$51>>0] = $54;
  $55 = HEAP32[$22>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$22>>2] = $56;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$49,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $57 = (($this) + 248|0);
 $58 = HEAP32[$22>>2]|0;
 $59 = (($58) + 4|0);
 $60 = HEAP32[$25>>2]|0;
 $61 = ($59>>>0)<($60>>>0);
 if ($61) {
  $62 = HEAP32[$57>>2]|0;
  HEAP32[$58>>2] = $62;
  HEAP32[$22>>2] = $59;
  $65 = $59;$67 = $60;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$57,4);
  $$pre15 = HEAP32[$22>>2]|0;
  $$pre16 = HEAP32[$25>>2]|0;
  $65 = $$pre15;$67 = $$pre16;
 }
 $63 = (($this) + 252|0);
 $64 = (($65) + 4|0);
 $66 = ($64>>>0)<($67>>>0);
 if ($66) {
  $68 = HEAP32[$63>>2]|0;
  HEAP32[$65>>2] = $68;
  HEAP32[$22>>2] = $64;
  $71 = $64;$73 = $67;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$63,4);
  $$pre17 = HEAP32[$22>>2]|0;
  $$pre18 = HEAP32[$25>>2]|0;
  $71 = $$pre17;$73 = $$pre18;
 }
 $69 = (($this) + 256|0);
 $70 = (($71) + 4|0);
 $72 = ($70>>>0)<($73>>>0);
 if ($72) {
  $74 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$71>>2] = $74;
  HEAP32[$22>>2] = $70;
  $77 = $70;$79 = $73;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$69,4);
  $$pre$i$i$i = HEAP32[$22>>2]|0;
  $$pre2$i$i$i = HEAP32[$25>>2]|0;
  $77 = $$pre$i$i$i;$79 = $$pre2$i$i$i;
 }
 $75 = (($this) + 260|0);
 $76 = (($77) + 4|0);
 $78 = ($76>>>0)<($79>>>0);
 if ($78) {
  $80 = Math_fround(HEAPF32[$75>>2]);
  HEAPF32[$77>>2] = $80;
  HEAP32[$22>>2] = $76;
  $83 = $76;$85 = $79;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$75,4);
  $$pre19 = HEAP32[$22>>2]|0;
  $$pre20 = HEAP32[$25>>2]|0;
  $83 = $$pre19;$85 = $$pre20;
 }
 $81 = (($this) + 272|0);
 $82 = (($83) + 4|0);
 $84 = ($82>>>0)<($85>>>0);
 if ($84) {
  $86 = Math_fround(HEAPF32[$81>>2]);
  HEAPF32[$83>>2] = $86;
  HEAP32[$22>>2] = $82;
  $89 = $82;$91 = $85;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$81,4);
  $$pre21 = HEAP32[$22>>2]|0;
  $$pre22 = HEAP32[$25>>2]|0;
  $89 = $$pre21;$91 = $$pre22;
 }
 $87 = (($this) + 276|0);
 $88 = (($89) + 4|0);
 $90 = ($88>>>0)<($91>>>0);
 if ($90) {
  $92 = Math_fround(HEAPF32[$87>>2]);
  HEAPF32[$89>>2] = $92;
  HEAP32[$22>>2] = $88;
  $95 = $88;$97 = $91;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$87,4);
  $$pre23 = HEAP32[$22>>2]|0;
  $$pre24 = HEAP32[$25>>2]|0;
  $95 = $$pre23;$97 = $$pre24;
 }
 $93 = (($this) + 288|0);
 $94 = (($95) + 1|0);
 $96 = ($94>>>0)<($97>>>0);
 if ($96) {
  $98 = HEAP8[$93>>0]|0;
  HEAP8[$95>>0] = $98;
  $99 = HEAP32[$22>>2]|0;
  $100 = (($99) + 1|0);
  HEAP32[$22>>2] = $100;
  $103 = $100;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$93,1);
  $$pre25 = HEAP32[$22>>2]|0;
  $103 = $$pre25;
 }
 $101 = (($this) + 289|0);
 $102 = (($103) + 1|0);
 $104 = HEAP32[$25>>2]|0;
 $105 = ($102>>>0)<($104>>>0);
 if ($105) {
  $106 = HEAP8[$101>>0]|0;
  HEAP8[$103>>0] = $106;
  $107 = HEAP32[$22>>2]|0;
  $108 = (($107) + 1|0);
  HEAP32[$22>>2] = $108;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$101,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrIN13TextRendering4FontEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN10RectOffset8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$13>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __Z13TransferFieldI19StreamedBinaryWriteILb0EELb0E27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $native$i = sp;
 __ZN11GradientNEWC2Ev($native$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($staticInfo) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$runtimeInfo>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = (($3) + -8)|0;
 $7 = $5 ? $3 : $6;
 $8 = (($runtimeInfo) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$converter>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_ii(3286,($13|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   invoke_vi(3549,($14|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $24 = $14;
    label = 5;
   }
  }
 } else {
  $24 = $11;
  label = 5;
 }
 if ((label|0) == 5) {
  $23 = (($24) + 8|0);
  $25 = HEAP32[$23>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  HEAP32[$native$i>>2] = $26;
  $27 = (($native$i) + 4|0);
  $28 = (($25) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$27>>2] = $29;
  $30 = (($native$i) + 8|0);
  $31 = (($25) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  HEAP32[$30>>2] = $32;
  $33 = (($native$i) + 12|0);
  $34 = (($25) + 12|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$33>>2] = $35;
  $36 = (($native$i) + 16|0);
  $37 = (($25) + 16|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$36>>2] = $38;
  $39 = (($native$i) + 20|0);
  $40 = (($25) + 20|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$39>>2] = $41;
  $42 = (($native$i) + 24|0);
  $43 = (($25) + 24|0);
  $44 = HEAP32[$43>>2]|0;
  HEAP32[$42>>2] = $44;
  $45 = (($native$i) + 28|0);
  $46 = (($25) + 28|0);
  $47 = HEAP32[$46>>2]|0;
  HEAP32[$45>>2] = $47;
  $48 = (($native$i) + 32|0);
  $49 = (($25) + 32|0);
  dest=$48+0|0; src=$49+0|0; stop=dest+34|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
  __THREW__ = 0;
  invoke_vii(3196,($native$i|0),($1|0));
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if (!($51)) {
   STACKTOP = sp;return;
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __THREW__ = 0;
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $52 = ___cxa_find_matching_catch(0|0)|0;
  $53 = tempRet0;
  ___clang_call_terminate($52);
  // unreachable;
 } else {
  ___resumeException($19|0);
  // unreachable;
 }
}
function __Z13TransferFieldI19StreamedBinaryWriteILb0EELb0E27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT1_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $native$i = 0, $scripting$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 92|0;
 $0 = sp;
 $native$i = sp + 8|0;
 $scripting$i = sp + 88|0;
 $1 = (($native$i) + 4|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 HEAP32[$native$i>>2] = 0;
 $2 = (($native$i) + 8|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $3 = (($native$i) + 32|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($native$i) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($native$i) + 36|0);
 $6 = (($native$i) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($native$i) + 68|0);
 HEAP32[$7>>2] = 0;
 $8 = (($native$i) + 60|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$8>>2] = 61;
 $9 = (($native$i) + 76|0);
 HEAP32[$9>>2] = 2;
 $10 = (($native$i) + 72|0);
 HEAP32[$10>>2] = 2;
 $11 = (($runtimeInfo) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($staticInfo) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP8[$runtimeInfo>>0]|0;
 $16 = ($15<<24>>24)!=(0);
 $17 = (($14) + -8)|0;
 $18 = $16 ? $14 : $17;
 $19 = (($runtimeInfo) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($18)|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$scripting$i>>2] = $22;
 __THREW__ = 0;
 invoke_viii(1878,($converter|0),($scripting$i|0),($native$i|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if (!($24)) {
  __THREW__ = 0;
  invoke_vii(3197,($native$i|0),($12|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if (!($35)) {
   $36 = HEAP32[$7>>2]|0;
   $37 = ($36|0)>(-1);
   if (!($37)) {
    STACKTOP = sp;return;
   }
   $38 = (($native$i) + 56|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $40;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($39,$$byval_copy1);
   HEAP32[$38>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $27 = HEAP32[$7>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  ___resumeException($25|0);
  // unreachable;
 }
 $29 = (($native$i) + 56|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $31;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($30|0),($$byval_copy1|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 }
 HEAP32[$29>>2] = 0;
 ___resumeException($25|0);
 // unreachable;
}
function __ZN17AnimationCurveTplIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i,4);
 }
 $8 = (($this) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = (($9) + ($10<<4)|0);
 $12 = ($10|0)==(0);
 if (!($12)) {
  $i$01$i$i$i = $9;
  while(1) {
   __ZN11KeyframeTplIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $13 = (($i$01$i$i$i) + 16|0);
   $14 = ($13|0)==($11|0);
   if ($14) {
    break;
   } else {
    $i$01$i$i$i = $13;
   }
  }
 }
 $15 = (($this) + 72|0);
 $16 = HEAP32[$2>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$5>>2]|0;
 $19 = ($17>>>0)<($18>>>0);
 if ($19) {
  $20 = HEAP32[$15>>2]|0;
  HEAP32[$16>>2] = $20;
  HEAP32[$2>>2] = $17;
  $23 = $17;$25 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$15,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre2 = HEAP32[$5>>2]|0;
  $23 = $$pre;$25 = $$pre2;
 }
 $21 = (($this) + 76|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)<($25>>>0);
 if ($24) {
  $26 = HEAP32[$21>>2]|0;
  HEAP32[$23>>2] = $26;
  HEAP32[$2>>2] = $22;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$21,4);
  STACKTOP = sp;return;
 }
}
function __ZN11KeyframeTplIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __Z30TransferField_LinearCollectionI19StreamedBinaryWriteILb0EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $array = 0, $linearCollectionField = 0, $newRuntimeInfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $linearCollectionField = sp + 40|0;
 $array = sp;
 $0 = sp + 8|0;
 $newRuntimeInfo = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($linearCollectionField,$runtimeInfo,$1);
 HEAP32[$array>>2] = 0;
 $2 = (($array) + 4|0);
 HEAP32[$2>>2] = -1;
 $3 = (($runtimeInfo) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 3;
 } else {
  __ZN21LinearCollectionField8GetArrayEv($0,$linearCollectionField);
  $6 = $0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $array;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  $16 = (0)==(0);
  $17 = ($11|0)==(-1);
  $18 = $16 & $17;
  if ($18) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $19 = (__ZN21LinearCollectionField15GetElementClassEv($linearCollectionField)|0);
  $20 = (__Z34scripting_class_array_element_sizeP14ScriptingClass($19)|0);
  $21 = (__Z19scripting_array_newP14ScriptingClassjj($19,$20,0)|0);
  HEAP32[$array>>2] = $21;
  HEAP32[$2>>2] = 0;
 }
 $22 = HEAP8[$runtimeInfo>>0]|0;
 HEAP8[$newRuntimeInfo>>0] = $22;
 $23 = (($newRuntimeInfo) + 4|0);
 $24 = HEAP32[$3>>2]|0;
 HEAP32[$23>>2] = $24;
 $25 = (($newRuntimeInfo) + 8|0);
 $26 = (($runtimeInfo) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$25>>2] = $27;
 $28 = (($newRuntimeInfo) + 12|0);
 $29 = (($runtimeInfo) + 12|0);
 $30 = $29;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = $28;
 $37 = $36;
 HEAP32[$37>>2] = $32;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = $35;
 $40 = (($newRuntimeInfo) + 20|0);
 HEAP32[$40>>2] = $array;
 $41 = (($args) + 40|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vii[$42 & 4095]($args,$newRuntimeInfo);
 STACKTOP = sp;return;
}
function __Z65EmitSerializationCommandsForLinearCollectionOfManagedOjbectsFieldI19StreamedBinaryWriteILb0EEEvRK23TransferArrayField_InfoR20SerializationCommandR32SerializationCommandQueueBuilderRP20AllowNameConversions($tfi,$partiallySetuplinearCollectionCommand,$commandQueueBuilder,$nameConversions) {
 $tfi = $tfi|0;
 $partiallySetuplinearCollectionCommand = $partiallySetuplinearCollectionCommand|0;
 $commandQueueBuilder = $commandQueueBuilder|0;
 $nameConversions = $nameConversions|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $commandQueueForSingleElement = 0, $or$cond = 0, $tfi$idx = 0, $tfi$idx$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 44|0;
 $0 = sp;
 $args = sp + 4|0;
 $commandQueueForSingleElement = sp + 24|0;
 $tfi$idx = (($tfi) + 40|0);
 $tfi$idx$val = HEAP32[$tfi$idx>>2]|0;
 $1 = (__ZL29CanTransferTypeAsNestedObjectI23TransferArrayField_InfoEbRKT_($tfi$idx$val)|0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$tfi$idx>>2]|0;
 $3 = (($tfi) + 24|0);
 HEAP32[$args>>2] = $2;
 $4 = (($args) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = (($args) + 8|0);
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 36|0);
 HEAP32[$5>>2] = $7;
 $8 = (($args) + 12|0);
 $9 = (($args) + 16|0);
 $10 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8);
 HEAP16[$9>>1] = $10;
 $11 = (($tfi) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$8>>2] = $12;
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 $13 = (($commandQueueForSingleElement) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($commandQueueForSingleElement) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($commandQueueForSingleElement) + 4|0);
 HEAP32[$15>>2] = 61;
 $16 = (($commandQueueForSingleElement) + 16|0);
 HEAP8[$16>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(382,($args|0),($commandQueueForSingleElement|0),($nameConversions|0),0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = (($tfi) + 25|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = ($20<<24>>24)!=(0);
   $$pre = HEAP32[$13>>2]|0;
   $22 = ($$pre|0)==(0);
   $or$cond = $21 & $22;
   if (!($or$cond)) {
    $31 = (($partiallySetuplinearCollectionCommand) + 44|0);
    HEAP32[$31>>2] = 3198;
    $32 = (($partiallySetuplinearCollectionCommand) + 48|0);
    HEAP32[$32>>2] = $$pre;
    $33 = HEAP32[$tfi$idx>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_ii(3284,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = (($partiallySetuplinearCollectionCommand) + 40|0);
    HEAP32[$37>>2] = $34;
    __THREW__ = 0;
    invoke_vii(2801,($commandQueueBuilder|0),($partiallySetuplinearCollectionCommand|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2861,($commandQueueBuilder|0),($commandQueueForSingleElement|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
   }
   $42 = HEAP32[$14>>2]|0;
   $43 = ($42|0)>(-1);
   if (!($43)) {
    STACKTOP = sp;return;
   }
   $44 = HEAP32[$commandQueueForSingleElement>>2]|0;
   $45 = HEAP32[$15>>2]|0;
   HEAP32[$0>>2] = $45;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($44,$$byval_copy1);
   HEAP32[$commandQueueForSingleElement>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$14>>2]|0;
 $26 = ($25|0)>(-1);
 if (!($26)) {
  ___resumeException($23|0);
  // unreachable;
 }
 $27 = HEAP32[$commandQueueForSingleElement>>2]|0;
 $28 = HEAP32[$15>>2]|0;
 HEAP32[$0>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $46 = ___cxa_find_matching_catch(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 }
 HEAP32[$commandQueueForSingleElement>>2] = 0;
 ___resumeException($23|0);
 // unreachable;
}
function __ZL22Transfer_ManagedObjectI19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $$idx$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arrayOfManagedObjectsTransferer = 0, $newProvider = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $arrayOfManagedObjectsTransferer = sp;
 $newProvider = sp + 12|0;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $arrayOfManagedObjectsTransferer;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$arrayOfManagedObjectsTransferer>>2] = $7;
 $8 = (($args) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($arrayOfManagedObjectsTransferer) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = (($runtimeInfo) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14<<6)|0);
 HEAP32[$15>>2] = $17;
 $18 = (($newProvider) + 4|0);
 HEAP32[$18>>2] = $16;
 HEAP32[$newProvider>>2] = $16;
 $19 = (($newProvider) + 8|0);
 HEAP32[$19>>2] = $17;
 $$idx$i = $14 << 6;
 $20 = $$idx$i >> 6;
 $21 = (($newProvider) + 16|0);
 HEAP32[$21>>2] = $20;
 $22 = (($newProvider) + 12|0);
 HEAP32[$22>>2] = $20;
 $23 = (($arrayOfManagedObjectsTransferer) + 8|0);
 HEAP32[$23>>2] = $newProvider;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($1,$arrayOfManagedObjectsTransferer,0);
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI31ArrayOfManagedObjectsTransfererEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre2 = 0, $$sroa$1$i = 0, $$sroa$12$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $i = 0, $instance$0$i = 0, $size = 0, $storemerge = 0, $storemerge1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$sroa$12$i = sp + 64|0;
 $$sroa$1$i = sp + 88|0;
 $size = sp + 56|0;
 $i = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($i) + 24|0);
 HEAP8[$13>>0] = 1;
 $14 = (($i) + 28|0);
 HEAP32[$14>>2] = 0;
 $15 = (($i) + 32|0);
 HEAP32[$15>>2] = 0;
 $16 = (($i) + 40|0);
 $17 = (($i) + 44|0);
 HEAP32[$i>>2] = $10;
 $18 = (($i) + 12|0);
 HEAP32[$18>>2] = 0;
 $19 = (($data) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (__Z28scripting_class_is_valuetypeP14ScriptingClass($20)|0);
 $22 = (($i) + 4|0);
 $23 = $21&1;
 HEAP8[$22>>0] = $23;
 $24 = HEAP32[$data>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (__Z26scripting_object_get_classP15ScriptingObject($25)|0);
 $27 = (__Z28scripting_array_element_sizeP14ScriptingClass($26)|0);
 $28 = (($i) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[$19>>2]|0;
 $30 = (($i) + 16|0);
 HEAP32[$30>>2] = $29;
 $31 = (($data) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($32) + 8|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$16>>2] = $33;
 $36 = (($i) + 36|0);
 HEAP32[$36>>2] = $33;
 HEAP32[$17>>2] = $35;
 $37 = $35;
 $38 = $33;
 $39 = (($37) - ($38))|0;
 $40 = $39 >> 6;
 $41 = (($i) + 52|0);
 HEAP32[$41>>2] = $40;
 $42 = (($i) + 48|0);
 HEAP32[$42>>2] = $40;
 $43 = HEAP32[$18>>2]|0;
 $44 = ($43|0)==($12|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = (($i) + 36|0);
 $46 = (($i) + 20|0);
 $47 = (($i) + 25|0);
 $48 = (($$sroa$12$i) + 16|0);
 $49 = (($$sroa$12$i) + 12|0);
 $50 = $33;$53 = $43;$54 = $27;
 while(1) {
  HEAP32[$16>>2] = $50;
  HEAP32[$46>>2] = $45;
  $51 = HEAP32[$i>>2]|0;
  $52 = HEAP32[$51>>2]|0;
  $55 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($52,$53,$54)|0);
  $56 = HEAP8[$22>>0]|0;
  $57 = ($56<<24>>24)==(0);
  if ($57) {
   $59 = HEAP32[$55>>2]|0;
   $60 = ($59|0)==(0|0);
   if ($60) {
    $61 = HEAP32[$30>>2]|0;
    $62 = (_il2cpp_object_new($61)|0);
    __ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject($62);
    $63 = HEAP32[$i>>2]|0;
    $64 = HEAP32[$63>>2]|0;
    $65 = HEAP32[$18>>2]|0;
    __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($64,$65,$62);
    $instance$0$i = $62;
   } else {
    $instance$0$i = $59;
   }
   $66 = HEAP32[$30>>2]|0;
   HEAP8[$13>>0] = 1;
   ;HEAP8[$47+0>>0]=HEAP8[$$sroa$1$i+0>>0]|0;HEAP8[$47+1>>0]=HEAP8[$$sroa$1$i+1>>0]|0;HEAP8[$47+2>>0]=HEAP8[$$sroa$1$i+2>>0]|0;
   $storemerge = $66;$storemerge1 = $instance$0$i;
  } else {
   $58 = HEAP32[$30>>2]|0;
   HEAP8[$13>>0] = 0;
   ;HEAP8[$47+0>>0]=HEAP8[$$sroa$12$i+0>>0]|0;HEAP8[$47+1>>0]=HEAP8[$$sroa$12$i+1>>0]|0;HEAP8[$47+2>>0]=HEAP8[$$sroa$12$i+2>>0]|0;
   $storemerge = $58;$storemerge1 = $55;
  }
  HEAP32[$14>>2] = $storemerge1;
  HEAP32[$15>>2] = $storemerge;
  $67 = HEAP32[$46>>2]|0;
  ;HEAP32[$$sroa$12$i+0>>2]=0|0;HEAP32[$$sroa$12$i+4>>2]=0|0;HEAP32[$$sroa$12$i+8>>2]=0|0;HEAP32[$$sroa$12$i+12>>2]=0|0;HEAP32[$$sroa$12$i+16>>2]=0|0;HEAP32[$$sroa$12$i+20>>2]=0|0;
  HEAP32[$48>>2] = $this;
  ;HEAP32[$$sroa$12$i+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$$sroa$12$i+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$$sroa$12$i+8>>2]=HEAP32[$13+8>>2]|0;
  HEAP32[$49>>2] = $67;
  $68 = (($67) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($67) + 8|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($69|0)==($71|0);
  if (!($72)) {
   $73 = (($67) + 12|0);
   $75 = $69;$77 = $71;
   while(1) {
    $74 = (($75) + 64|0);
    HEAP32[$68>>2] = $74;
    $76 = $77;
    $78 = $74;
    $79 = (($76) - ($78))|0;
    $80 = $79 >> 6;
    HEAP32[$73>>2] = $80;
    $81 = HEAP32[$75>>2]|0;
    $82 = (($75) + 4|0);
    FUNCTION_TABLE_vii[$81 & 4095]($82,$$sroa$12$i);
    $83 = HEAP32[$68>>2]|0;
    $84 = HEAP32[$70>>2]|0;
    $85 = ($83|0)==($84|0);
    if ($85) {
     break;
    } else {
     $75 = $83;$77 = $84;
    }
   }
  }
  $86 = HEAP32[$18>>2]|0;
  $87 = (($86) + 1)|0;
  HEAP32[$18>>2] = $87;
  $88 = ($87|0)==($12|0);
  if ($88) {
   break;
  }
  $$pre = HEAP32[$45>>2]|0;
  $$pre2 = HEAP32[$28>>2]|0;
  $50 = $$pre;$53 = $87;$54 = $$pre2;
 }
 STACKTOP = sp;return;
}
function __Z15Transfer_StringI19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 HEAP8[$converter>>0] = 0;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIa19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIaEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIh19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIhEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIs19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z22Transfer_Builtin_AlignIt19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter$i);
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($1);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIi19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIj19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIx19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIy19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinIf19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinId19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector3f19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector2f19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8Vector4f19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI5RectTIfE19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11Quaternionf19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10Matrix4x4f19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI4AABB19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI10ColorRGBAf19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI11ColorRGBA3219StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z16Transfer_BuiltinI8BitField19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($args) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$converter>>2] = $1;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z26Transfer_UnityEngineObjectI19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo($args,$runtimeInfo) {
 $args = $args|0;
 $runtimeInfo = $runtimeInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $converter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter = sp;
 $0 = (($runtimeInfo) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 HEAP32[$converter>>2] = $3;
 $5 = (($converter) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($converter) + 8|0);
 HEAP32[$6>>2] = 0;
 __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($args,$runtimeInfo,$converter);
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_UnityEngineObjectEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp + 32|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 12|0);
 ;HEAP32[$3+0>>2]=HEAP32[$converter+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$converter+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$converter+8>>2]|0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_vii(3080,($buffer|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   label = 3;
  } else {
   $25 = HEAP32[$1>>2]|0;
   $26 = HEAP32[$buffer>>2]|0;
   $27 = $25;
   $28 = $26;
   $29 = (($27) - ($28))|0;
   $30 = (($29|0) / 12)&-1;
   HEAP32[$size$i$i$i>>2] = $30;
   $31 = (($5) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 4|0);
   $34 = (($5) + 20|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($33>>>0)<($35>>>0);
   if ($36) {
    HEAP32[$32>>2] = $30;
    HEAP32[$31>>2] = $33;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($31|0),($size$i$i$i|0),4);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 3;
     break;
    }
   }
   $39 = HEAP32[$1>>2]|0;
   $40 = HEAP32[$buffer>>2]|0;
   $41 = ($40|0)==($39|0);
   do {
    if ($41) {
     $48 = $39;
    } else {
     $42 = $40;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3199,($42|0),($5|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 2;
       break;
      }
      $45 = (($42) + 12|0);
      $46 = ($45|0)==($39|0);
      if ($46) {
       label = 15;
       break;
      } else {
       $42 = $45;
      }
     }
     if ((label|0) == 2) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      break L1;
     }
     else if ((label|0) == 15) {
      $$pre = HEAP32[$buffer>>2]|0;
      $48 = $$pre;
      break;
     }
    }
   } while(0);
   $47 = ($48|0)==(0|0);
   if ($47) {
    STACKTOP = sp;return;
   }
   $49 = HEAP32[$1>>2]|0;
   $50 = ($49|0)==($48|0);
   if (!($50)) {
    $__new_last2$i$i$i$i$i$i$i = $48;
    $scevgep$i$i$i$i$i$i$i = (($49) + -12|0);
    $51 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($51)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $52 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $53 = $52 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($49) + (($53*12)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($48|0),($$byval_copy6|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    $56 = ___cxa_find_matching_catch()|0;
    $57 = tempRet0;
    ___cxa_call_unexpected(($56|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 }
 $14 = HEAP32[$buffer>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $16 = HEAP32[$1>>2]|0;
 $17 = ($16|0)==($14|0);
 if (!($17)) {
  $__new_last2$i$i$i$i$i$i$i1 = $14;
  $scevgep$i$i$i$i$i$i$i2 = (($16) + -12|0);
  $18 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($18)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $19 = (($uglygep3$i$i$i$i$i$i$i5>>>0) / 12)&-1;
  $20 = $19 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($16) + (($20*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($14|0),($$byval_copy6|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  ___cxa_call_unexpected(($23|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI8GUIStyleEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $buffer = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 32|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$converter>>2]|0;
 $5 = (($buffer) + 12|0);
 HEAP32[$5>>2] = $4;
 $6 = (($runtimeInfo) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($runtimeInfo) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 __THREW__ = 0;
 invoke_vii(3081,($buffer|0),($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 3;
  } else {
   $38 = HEAP32[$2>>2]|0;
   $39 = HEAP32[$buffer>>2]|0;
   $40 = $38;
   $41 = $39;
   $42 = (($40) - ($41))|0;
   $43 = (($42|0) / 292)&-1;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($7) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($7) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 3;
     break;
    }
   }
   $52 = HEAP32[$2>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $61 = $52;
    } else {
     $55 = $53;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3195,($55|0),($7|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 2;
       break;
      }
      $58 = (($55) + 292|0);
      $59 = ($58|0)==($52|0);
      if ($59) {
       label = 21;
       break;
      } else {
       $55 = $58;
      }
     }
     if ((label|0) == 2) {
      $12 = ___cxa_find_matching_catch()|0;
      $13 = tempRet0;
      $lpad$phi$index = $12;$lpad$phi$index2 = $13;
      break L1;
     }
     else if ((label|0) == 21) {
      $$pre = HEAP32[$buffer>>2]|0;
      $61 = $$pre;
      break;
     }
    }
   } while(0);
   $60 = ($61|0)==(0|0);
   if ($60) {
    STACKTOP = sp;return;
   }
   $62 = HEAP32[$2>>2]|0;
   $63 = ($62|0)==($61|0);
   do {
    if ($63) {
     $77 = $61;
    } else {
     $65 = $62;
     while(1) {
      $64 = (($65) + -292|0);
      HEAP32[$2>>2] = $64;
      $66 = HEAP8[$64>>0]|0;
      $67 = $66 & 1;
      $68 = ($67<<24>>24)==(0);
      if ($68) {
       $70 = $64;
      } else {
       $71 = (($65) + -284|0);
       $72 = HEAP32[$71>>2]|0;
       HEAP32[$size$i$i$i>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
       invoke_vii(2591,($72|0),($$byval_copy8|0));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 29;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$2>>2]|0;
       $70 = $$pre$i$i$i$i$i$i$i;
      }
      $69 = ($70|0)==($61|0);
      if ($69) {
       label = 30;
       break;
      } else {
       $65 = $70;
      }
     }
     if ((label|0) == 29) {
      $75 = ___cxa_find_matching_catch()|0;
      $76 = tempRet0;
      ___cxa_call_unexpected(($75|0));
      // unreachable;
     }
     else if ((label|0) == 30) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $77 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($77|0),($$byval_copy8|0));
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $80 = ___cxa_find_matching_catch()|0;
    $81 = tempRet0;
    ___cxa_call_unexpected(($80|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 }
 $16 = HEAP32[$buffer>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $18 = HEAP32[$2>>2]|0;
 $19 = ($18|0)==($16|0);
 do {
  if ($19) {
   $33 = $16;
  } else {
   $21 = $18;
   while(1) {
    $20 = (($21) + -292|0);
    HEAP32[$2>>2] = $20;
    $22 = HEAP8[$20>>0]|0;
    $23 = $22 & 1;
    $24 = ($23<<24>>24)==(0);
    if ($24) {
     $26 = $20;
    } else {
     $27 = (($21) + -284|0);
     $28 = HEAP32[$27>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($28|0),($$byval_copy8|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      label = 11;
      break;
     }
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$2>>2]|0;
     $26 = $$pre$i$i$i$i$i$i$i3;
    }
    $25 = ($26|0)==($16|0);
    if ($25) {
     label = 12;
     break;
    } else {
     $21 = $26;
    }
   }
   if ((label|0) == 11) {
    $31 = ___cxa_find_matching_catch()|0;
    $32 = tempRet0;
    ___cxa_call_unexpected(($31|0));
    // unreachable;
   }
   else if ((label|0) == 12) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $33 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI10RectOffsetEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$val$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0;
 var $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($runtimeInfo) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 L1: do {
  if ($11) {
   label = 16;
  } else {
   __THREW__ = 0;
   invoke_vii(2873,($buffer|0),($10|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    label = 10;
   } else {
    $index$01$i = 0;
    while(1) {
     $14 = HEAP32[$8>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(2433,($14|0),($index$01$i|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     $$val$i = HEAP32[$15>>2]|0;
     $18 = ($$val$i|0)==(0|0);
     if (!($18)) {
      $19 = HEAP32[$buffer>>2]|0;
      $20 = (($19) + ($index$01$i<<4)|0);
      $21 = (($$val$i) + 8|0);
      $22 = HEAP32[$21>>2]|0;
      ;HEAP32[$20+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$22+12>>2]|0;
     }
     $23 = (($index$01$i) + 1)|0;
     $24 = ($23|0)==($10|0);
     if ($24) {
      label = 16;
      break L1;
     } else {
      $index$01$i = $23;
     }
    }
    $27 = ___cxa_find_matching_catch()|0;
    $28 = tempRet0;
    $lpad$phi$index = $27;$lpad$phi$index3 = $28;
   }
  }
 } while(0);
 L11: do {
  if ((label|0) == 16) {
   $42 = HEAP32[$1>>2]|0;
   $43 = HEAP32[$buffer>>2]|0;
   $44 = $42;
   $45 = $43;
   $46 = (($44) - ($45))|0;
   $47 = $46 >> 4;
   HEAP32[$size$i$i$i>>2] = $47;
   $48 = (($6) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + 4|0);
   $51 = (($6) + 20|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($50>>>0)<($52>>>0);
   if ($53) {
    HEAP32[$49>>2] = $47;
    HEAP32[$48>>2] = $50;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($48|0),($size$i$i$i|0),4);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 10;
     break;
    }
   }
   $56 = HEAP32[$1>>2]|0;
   $57 = HEAP32[$buffer>>2]|0;
   $58 = ($57|0)==($56|0);
   do {
    if ($58) {
     $65 = $56;
    } else {
     $59 = $57;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3200,($59|0),($6|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       label = 8;
       break;
      }
      $62 = (($59) + 16|0);
      $63 = ($62|0)==($56|0);
      if ($63) {
       label = 22;
       break;
      } else {
       $59 = $62;
      }
     }
     if ((label|0) == 8) {
      $25 = ___cxa_find_matching_catch()|0;
      $26 = tempRet0;
      $lpad$phi$index = $25;$lpad$phi$index3 = $26;
      break L11;
     }
     else if ((label|0) == 22) {
      $$pre = HEAP32[$buffer>>2]|0;
      $65 = $$pre;
      break;
     }
    }
   } while(0);
   $64 = ($65|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$1>>2]|0;
   $67 = ($66|0)==($65|0);
   if (!($67)) {
    $__new_last2$i$i$i$i$i$i$i = $65;
    $scevgep$i$i$i$i$i$i$i = (($66) + -16|0);
    $68 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($68)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $69 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($66) + ($70<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($65|0),($$byval_copy8|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    ___cxa_call_unexpected(($73|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  $lpad$phi$index = $29;$lpad$phi$index3 = $30;
 }
 $31 = HEAP32[$buffer>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $33 = HEAP32[$1>>2]|0;
 $34 = ($33|0)==($31|0);
 if (!($34)) {
  $__new_last2$i$i$i$i$i$i$i2 = $31;
  $scevgep$i$i$i$i$i$i$i3 = (($33) + -16|0);
  $35 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($35)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $36 = $uglygep3$i$i$i$i$i$i$i6 >>> 4;
  $37 = $36 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($33) + ($37<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy8|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  ___cxa_call_unexpected(($40|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI11GradientNEWEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($runtimeInfo) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_vii(3082,($buffer|0),($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 3;
  } else {
   $29 = HEAP32[$1>>2]|0;
   $30 = HEAP32[$buffer>>2]|0;
   $31 = $29;
   $32 = $30;
   $33 = (($31) - ($32))|0;
   $34 = (($33|0) / 68)&-1;
   HEAP32[$size$i$i$i>>2] = $34;
   $35 = (($6) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 4|0);
   $38 = (($6) + 20|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($37>>>0)<($39>>>0);
   if ($40) {
    HEAP32[$36>>2] = $34;
    HEAP32[$35>>2] = $37;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($35|0),($size$i$i$i|0),4);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 3;
     break;
    }
   }
   $43 = HEAP32[$1>>2]|0;
   $44 = HEAP32[$buffer>>2]|0;
   $45 = ($44|0)==($43|0);
   do {
    if ($45) {
     $52 = $43;
    } else {
     $46 = $44;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3196,($46|0),($6|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 2;
       break;
      }
      $49 = (($46) + 68|0);
      $50 = ($49|0)==($43|0);
      if ($50) {
       label = 16;
       break;
      } else {
       $46 = $49;
      }
     }
     if ((label|0) == 2) {
      $11 = ___cxa_find_matching_catch()|0;
      $12 = tempRet0;
      $lpad$phi$index = $11;$lpad$phi$index2 = $12;
      break L1;
     }
     else if ((label|0) == 16) {
      $$pre = HEAP32[$buffer>>2]|0;
      $52 = $$pre;
      break;
     }
    }
   } while(0);
   $51 = ($52|0)==(0|0);
   if ($51) {
    STACKTOP = sp;return;
   }
   while(1) {
    $53 = HEAP32[$1>>2]|0;
    $54 = ($53|0)==($52|0);
    if ($54) {
     break;
    }
    $55 = (($53) + -68|0);
    HEAP32[$1>>2] = $55;
    __THREW__ = 0;
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     label = 20;
     break;
    }
   }
   if ((label|0) == 20) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    ___cxa_call_unexpected(($58|0));
    // unreachable;
   }
   $60 = HEAP32[$buffer>>2]|0;
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy6|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    ___cxa_call_unexpected(($63|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index2 = $14;
 }
 $15 = HEAP32[$buffer>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 while(1) {
  $17 = HEAP32[$1>>2]|0;
  $18 = ($17|0)==($15|0);
  if ($18) {
   break;
  }
  $19 = (($17) + -68|0);
  HEAP32[$1>>2] = $19;
  __THREW__ = 0;
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 }
 $24 = HEAP32[$buffer>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($24|0),($$byval_copy6|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  ___cxa_call_unexpected(($27|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE27Converter_SimpleNativeClassI17AnimationCurveTplIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $buffer = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$converter>>2]|0;
 $4 = (($buffer) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = (($runtimeInfo) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($runtimeInfo) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_vii(3083,($buffer|0),($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   label = 3;
  } else {
   $39 = HEAP32[$1>>2]|0;
   $40 = HEAP32[$buffer>>2]|0;
   $41 = $39;
   $42 = $40;
   $43 = (($41) - ($42))|0;
   $44 = (($43|0) / 80)&-1;
   HEAP32[$size$i$i$i>>2] = $44;
   $45 = (($6) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($46) + 4|0);
   $48 = (($6) + 20|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($47>>>0)<($49>>>0);
   if ($50) {
    HEAP32[$46>>2] = $44;
    HEAP32[$45>>2] = $47;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($45|0),($size$i$i$i|0),4);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     label = 3;
     break;
    }
   }
   $53 = HEAP32[$1>>2]|0;
   $54 = HEAP32[$buffer>>2]|0;
   $55 = ($54|0)==($53|0);
   do {
    if ($55) {
     $62 = $53;
    } else {
     $56 = $54;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3197,($56|0),($6|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 2;
       break;
      }
      $59 = (($56) + 80|0);
      $60 = ($59|0)==($53|0);
      if ($60) {
       label = 21;
       break;
      } else {
       $56 = $59;
      }
     }
     if ((label|0) == 2) {
      $11 = ___cxa_find_matching_catch()|0;
      $12 = tempRet0;
      $lpad$phi$index = $11;$lpad$phi$index2 = $12;
      break L1;
     }
     else if ((label|0) == 21) {
      $$pre = HEAP32[$buffer>>2]|0;
      $62 = $$pre;
      break;
     }
    }
   } while(0);
   $61 = ($62|0)==(0|0);
   if ($61) {
    STACKTOP = sp;return;
   }
   $63 = HEAP32[$1>>2]|0;
   $64 = ($63|0)==($62|0);
   do {
    if ($64) {
     $80 = $62;
    } else {
     $66 = $63;
     while(1) {
      $65 = (($66) + -80|0);
      HEAP32[$1>>2] = $65;
      $67 = (($66) + -12|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = ($68|0)>(-1);
      if ($69) {
       $72 = (($66) + -24|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = (($66) + -20|0);
       $75 = HEAP32[$74>>2]|0;
       HEAP32[$size$i$i$i>>2] = $75;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
       invoke_vii(2591,($73|0),($$byval_copy8|0));
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        label = 29;
        break;
       }
       HEAP32[$72>>2] = 0;
       $$pre$i$i$i$i$i$i$i = HEAP32[$1>>2]|0;
       $71 = $$pre$i$i$i$i$i$i$i;
      } else {
       $71 = $65;
      }
      $70 = ($71|0)==($62|0);
      if ($70) {
       label = 30;
       break;
      } else {
       $66 = $71;
      }
     }
     if ((label|0) == 29) {
      $78 = ___cxa_find_matching_catch()|0;
      $79 = tempRet0;
      ___cxa_call_unexpected(($78|0));
      // unreachable;
     }
     else if ((label|0) == 30) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $80 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($80|0),($$byval_copy8|0));
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    $83 = ___cxa_find_matching_catch()|0;
    $84 = tempRet0;
    ___cxa_call_unexpected(($83|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index2 = $14;
 }
 $15 = HEAP32[$buffer>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $17 = HEAP32[$1>>2]|0;
 $18 = ($17|0)==($15|0);
 do {
  if ($18) {
   $34 = $15;
  } else {
   $20 = $17;
   while(1) {
    $19 = (($20) + -80|0);
    HEAP32[$1>>2] = $19;
    $21 = (($20) + -12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)>(-1);
    if ($23) {
     $26 = (($20) + -24|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($20) + -20|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$0>>2] = $29;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($27|0),($$byval_copy8|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 11;
      break;
     }
     HEAP32[$26>>2] = 0;
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$1>>2]|0;
     $25 = $$pre$i$i$i$i$i$i$i3;
    } else {
     $25 = $19;
    }
    $24 = ($25|0)==($15|0);
    if ($24) {
     label = 12;
     break;
    } else {
     $20 = $25;
    }
   }
   if ((label|0) == 11) {
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
   else if ((label|0) == 12) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $34 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy8|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI8BitFieldEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$03$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $41 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2878,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$03$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$03$i|0),4)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP32[$13>>2]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$03$i<<2)|0);
     HEAP32[$18>>2] = $16;
     $19 = (($index$03$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      $41 = $17;
      label = 15;
      break L1;
     } else {
      $index$03$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $38 = HEAP32[$1>>2]|0;
   $39 = $38;
   $40 = $41;
   $42 = (($39) - ($40))|0;
   $43 = $42 >> 2;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($4) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($4) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 9;
     break;
    }
   }
   $52 = HEAP32[$1>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $66 = $52;
    } else {
     $60 = $53;
     while(1) {
      $55 = HEAP32[$44>>2]|0;
      $56 = (($55) + 4|0);
      $57 = HEAP32[$47>>2]|0;
      $58 = ($56>>>0)<($57>>>0);
      if ($58) {
       $59 = HEAP32[$60>>2]|0;
       HEAP32[$55>>2] = $59;
       HEAP32[$44>>2] = $56;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($44|0),($60|0),4);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 7;
        break;
       }
      }
      $63 = (($60) + 4|0);
      $64 = ($63|0)==($52|0);
      if ($64) {
       label = 23;
       break;
      } else {
       $60 = $63;
      }
     }
     if ((label|0) == 7) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $66 = $$pre;
      break;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $67 = HEAP32[$1>>2]|0;
   $68 = ($67|0)==($66|0);
   if (!($68)) {
    $__new_last2$i$i$i$i$i$i$i = $66;
    $scevgep$i$i$i$i$i$i$i = (($67) + -4|0);
    $69 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($69)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $70 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $71 = $70 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($67) + ($71<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy8|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI11ColorRGBA32EEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last1$i$i$i$i$i$i$i = 0;
 var $__new_last1$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$03$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep2$i$i$i$i$i$i$i = 0, $scevgep2$i$i$i$i$i$i$i4 = 0, $scevgep23$i$i$i$i$i$i$i = 0, $scevgep23$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre16 = HEAP32[$buffer>>2]|0;
   $41 = $$pre16;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2879,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$03$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$03$i|0),4)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP32[$13>>2]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$03$i<<2)|0);
     HEAP32[$18>>2] = $16;
     $19 = (($index$03$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      $41 = $17;
      label = 15;
      break L1;
     } else {
      $index$03$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $38 = HEAP32[$1>>2]|0;
   $39 = $38;
   $40 = $41;
   $42 = (($39) - ($40))|0;
   $43 = $42 >> 2;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($4) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($4) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 9;
     break;
    }
   }
   $52 = HEAP32[$1>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $66 = $52;
    } else {
     $60 = $53;
     while(1) {
      $55 = HEAP32[$44>>2]|0;
      $56 = (($55) + 4|0);
      $57 = HEAP32[$47>>2]|0;
      $58 = ($56>>>0)<($57>>>0);
      if ($58) {
       $59 = HEAP32[$60>>2]|0;
       HEAP32[$55>>2] = $59;
       HEAP32[$44>>2] = $56;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($44|0),($60|0),4);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 7;
        break;
       }
      }
      $63 = (($60) + 4|0);
      $64 = ($63|0)==($52|0);
      if ($64) {
       label = 23;
       break;
      } else {
       $60 = $63;
      }
     }
     if ((label|0) == 7) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $66 = $$pre;
      break;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $67 = HEAP32[$1>>2]|0;
   $68 = ($67|0)==($66|0);
   if (!($68)) {
    $__new_last1$i$i$i$i$i$i$i = $66;
    $scevgep$i$i$i$i$i$i$i = (($67) + -4|0);
    $69 = (0 - ($__new_last1$i$i$i$i$i$i$i))|0;
    $scevgep2$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($69)|0);
    $scevgep23$i$i$i$i$i$i$i = $scevgep2$i$i$i$i$i$i$i;
    $70 = $scevgep23$i$i$i$i$i$i$i >>> 2;
    $71 = $70 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($67) + ($71<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy8|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last1$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -4|0);
  $31 = (0 - ($__new_last1$i$i$i$i$i$i$i2))|0;
  $scevgep2$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $scevgep23$i$i$i$i$i$i$i5 = $scevgep2$i$i$i$i$i$i$i4;
  $32 = $scevgep23$i$i$i$i$i$i$i5 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI10ColorRGBAfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i1 = 0, $buffer = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii(3201,($buffer|0),($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L1: do {
  if ($8) {
   label = 3;
  } else {
   $24 = HEAP32[$1>>2]|0;
   $25 = HEAP32[$buffer>>2]|0;
   $26 = $24;
   $27 = $25;
   $28 = (($26) - ($27))|0;
   $29 = $28 >> 4;
   HEAP32[$size$i$i$i>>2] = $29;
   $30 = (($4) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + 4|0);
   $33 = (($4) + 20|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($32>>>0)<($34>>>0);
   if ($35) {
    HEAP32[$31>>2] = $29;
    HEAP32[$30>>2] = $32;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($30|0),($size$i$i$i|0),4);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 3;
     break;
    }
   }
   $38 = HEAP32[$1>>2]|0;
   $39 = HEAP32[$buffer>>2]|0;
   $40 = ($39|0)==($38|0);
   do {
    if ($40) {
     $47 = $38;
    } else {
     $41 = $39;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3202,($41|0),($4|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       label = 2;
       break;
      }
      $44 = (($41) + 16|0);
      $45 = ($44|0)==($38|0);
      if ($45) {
       label = 15;
       break;
      } else {
       $41 = $44;
      }
     }
     if ((label|0) == 2) {
      $9 = ___cxa_find_matching_catch()|0;
      $10 = tempRet0;
      $lpad$phi$index = $9;$lpad$phi$index2 = $10;
      break L1;
     }
     else if ((label|0) == 15) {
      $$pre = HEAP32[$buffer>>2]|0;
      $47 = $$pre;
      break;
     }
    }
   } while(0);
   $46 = ($47|0)==(0|0);
   if ($46) {
    STACKTOP = sp;return;
   }
   $48 = HEAP32[$1>>2]|0;
   $49 = ($48|0)==($47|0);
   if (!($49)) {
    $__new_last2$i$i$i$i$i$i$i = $47;
    $scevgep$i$i$i$i$i$i$i = (($48) + -16|0);
    $50 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($50)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $51 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $52 = $51 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($48) + ($52<<4)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($47|0),($$byval_copy6|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    ___cxa_call_unexpected(($55|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 }
 $13 = HEAP32[$buffer>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==($13|0);
 if (!($16)) {
  $__new_last2$i$i$i$i$i$i$i1 = $13;
  $scevgep$i$i$i$i$i$i$i2 = (($15) + -16|0);
  $17 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($17)|0);
  $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
  $18 = $uglygep3$i$i$i$i$i$i$i5 >>> 4;
  $19 = $18 ^ -1;
  $scevgep4$i$i$i$i$i$i$i6 = (($15) + ($19<<4)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy6|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  ___cxa_call_unexpected(($22|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI4AABBEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$02$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre18 = HEAP32[$buffer>>2]|0;
   $40 = $$pre18;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2881,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$02$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$02$i|0),24)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP32[$buffer>>2]|0;
     $17 = (($16) + (($index$02$i*24)|0)|0);
     _memmove(($17|0),($13|0),24)|0;
     $18 = (($index$02$i) + 1)|0;
     $19 = ($18|0)==($8|0);
     if ($19) {
      $40 = $16;
      label = 15;
      break L1;
     } else {
      $index$02$i = $18;
     }
    }
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $lpad$phi$index = $22;$lpad$phi$index3 = $23;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $37 = HEAP32[$1>>2]|0;
   $38 = $37;
   $39 = $40;
   $41 = (($38) - ($39))|0;
   $42 = (($41|0) / 24)&-1;
   HEAP32[$size$i$i$i>>2] = $42;
   $43 = (($4) + 12|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 4|0);
   $46 = (($4) + 20|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($45>>>0)<($47>>>0);
   if ($48) {
    HEAP32[$44>>2] = $42;
    HEAP32[$43>>2] = $45;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($43|0),($size$i$i$i|0),4);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 9;
     break;
    }
   }
   $51 = HEAP32[$1>>2]|0;
   $52 = HEAP32[$buffer>>2]|0;
   $53 = ($52|0)==($51|0);
   do {
    if ($53) {
     $60 = $51;
    } else {
     $54 = $52;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3203,($54|0),($4|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 7;
       break;
      }
      $57 = (($54) + 24|0);
      $58 = ($57|0)==($51|0);
      if ($58) {
       label = 21;
       break;
      } else {
       $54 = $57;
      }
     }
     if ((label|0) == 7) {
      $20 = ___cxa_find_matching_catch()|0;
      $21 = tempRet0;
      $lpad$phi$index = $20;$lpad$phi$index3 = $21;
      break L9;
     }
     else if ((label|0) == 21) {
      $$pre = HEAP32[$buffer>>2]|0;
      $60 = $$pre;
      break;
     }
    }
   } while(0);
   $59 = ($60|0)==(0|0);
   if ($59) {
    STACKTOP = sp;return;
   }
   $61 = HEAP32[$1>>2]|0;
   $62 = ($61|0)==($60|0);
   if (!($62)) {
    $__new_last2$i$i$i$i$i$i$i = $60;
    $scevgep$i$i$i$i$i$i$i = (($61) + -24|0);
    $63 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($63)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $64 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 24)&-1;
    $65 = $64 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($61) + (($65*24)|0)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy8|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    ___cxa_call_unexpected(($68|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  $lpad$phi$index = $24;$lpad$phi$index3 = $25;
 }
 $26 = HEAP32[$buffer>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $28 = HEAP32[$1>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $__new_last2$i$i$i$i$i$i$i2 = $26;
  $scevgep$i$i$i$i$i$i$i3 = (($28) + -24|0);
  $30 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($30)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $31 = (($uglygep3$i$i$i$i$i$i$i6>>>0) / 24)&-1;
  $32 = $31 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($28) + (($32*24)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($26|0),($$byval_copy8|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI10Matrix4x4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$03$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre18 = HEAP32[$buffer>>2]|0;
   $40 = $$pre18;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2882,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$03$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$03$i|0),64)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP32[$buffer>>2]|0;
     $17 = (($16) + ($index$03$i<<6)|0);
     _memmove(($17|0),($13|0),64)|0;
     $18 = (($index$03$i) + 1)|0;
     $19 = ($18|0)==($8|0);
     if ($19) {
      $40 = $16;
      label = 15;
      break L1;
     } else {
      $index$03$i = $18;
     }
    }
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $lpad$phi$index = $22;$lpad$phi$index3 = $23;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $37 = HEAP32[$1>>2]|0;
   $38 = $37;
   $39 = $40;
   $41 = (($38) - ($39))|0;
   $42 = $41 >> 6;
   HEAP32[$size$i$i$i>>2] = $42;
   $43 = (($4) + 12|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($44) + 4|0);
   $46 = (($4) + 20|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($45>>>0)<($47>>>0);
   if ($48) {
    HEAP32[$44>>2] = $42;
    HEAP32[$43>>2] = $45;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($43|0),($size$i$i$i|0),4);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 9;
     break;
    }
   }
   $51 = HEAP32[$1>>2]|0;
   $52 = HEAP32[$buffer>>2]|0;
   $53 = ($52|0)==($51|0);
   do {
    if ($53) {
     $60 = $51;
    } else {
     $54 = $52;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3204,($54|0),($4|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 7;
       break;
      }
      $57 = (($54) + 64|0);
      $58 = ($57|0)==($51|0);
      if ($58) {
       label = 21;
       break;
      } else {
       $54 = $57;
      }
     }
     if ((label|0) == 7) {
      $20 = ___cxa_find_matching_catch()|0;
      $21 = tempRet0;
      $lpad$phi$index = $20;$lpad$phi$index3 = $21;
      break L9;
     }
     else if ((label|0) == 21) {
      $$pre = HEAP32[$buffer>>2]|0;
      $60 = $$pre;
      break;
     }
    }
   } while(0);
   $59 = ($60|0)==(0|0);
   if ($59) {
    STACKTOP = sp;return;
   }
   $61 = HEAP32[$1>>2]|0;
   $62 = ($61|0)==($60|0);
   if (!($62)) {
    $__new_last2$i$i$i$i$i$i$i = $60;
    $scevgep$i$i$i$i$i$i$i = (($61) + -64|0);
    $63 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($63)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $64 = $uglygep3$i$i$i$i$i$i$i >>> 6;
    $65 = $64 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($61) + ($65<<6)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy8|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    ___cxa_call_unexpected(($68|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  $lpad$phi$index = $24;$lpad$phi$index3 = $25;
 }
 $26 = HEAP32[$buffer>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $28 = HEAP32[$1>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $__new_last2$i$i$i$i$i$i$i2 = $26;
  $scevgep$i$i$i$i$i$i$i3 = (($28) + -64|0);
  $30 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($30)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $31 = $uglygep3$i$i$i$i$i$i$i6 >>> 6;
  $32 = $31 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($28) + ($32<<6)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($26|0),($$byval_copy8|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI11QuaternionfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$02$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 40|0;
 $size$i$i$i = sp + 20|0;
 $0 = sp + 16|0;
 $1 = sp;
 $buffer = sp + 24|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 L1: do {
  if ($10) {
   label = 14;
  } else {
   __THREW__ = 0;
   invoke_vii(2883,($buffer|0),($9|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 8;
   } else {
    $index$02$i = 0;
    while(1) {
     $13 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     $14 = (invoke_iiii(1555,($13|0),($index$02$i|0),16)|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     ;HEAP32[$1+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$14+12>>2]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$02$i<<4)|0);
     ;HEAP32[$18+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$1+12>>2]|0;
     $19 = (($index$02$i) + 1)|0;
     $20 = ($19|0)==($9|0);
     if ($20) {
      label = 14;
      break L1;
     } else {
      $index$02$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L8: do {
  if ((label|0) == 14) {
   $38 = HEAP32[$2>>2]|0;
   $39 = HEAP32[$buffer>>2]|0;
   $40 = $38;
   $41 = $39;
   $42 = (($40) - ($41))|0;
   $43 = $42 >> 4;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($5) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($5) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 8;
     break;
    }
   }
   $52 = HEAP32[$2>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $61 = $52;
    } else {
     $55 = $53;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3205,($55|0),($5|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 6;
       break;
      }
      $58 = (($55) + 16|0);
      $59 = ($58|0)==($52|0);
      if ($59) {
       label = 20;
       break;
      } else {
       $55 = $58;
      }
     }
     if ((label|0) == 6) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L8;
     }
     else if ((label|0) == 20) {
      $$pre = HEAP32[$buffer>>2]|0;
      $61 = $$pre;
      break;
     }
    }
   } while(0);
   $60 = ($61|0)==(0|0);
   if ($60) {
    STACKTOP = sp;return;
   }
   $62 = HEAP32[$2>>2]|0;
   $63 = ($62|0)==($61|0);
   if (!($63)) {
    $__new_last2$i$i$i$i$i$i$i = $61;
    $scevgep$i$i$i$i$i$i$i = (($62) + -16|0);
    $64 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($64)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $65 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $66 = $65 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($62) + ($66<<4)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($61|0),($$byval_copy8|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    ___cxa_call_unexpected(($69|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$2>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<4)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI5RectTIfEEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$02$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 40|0;
 $size$i$i$i = sp + 20|0;
 $0 = sp + 16|0;
 $1 = sp;
 $buffer = sp + 24|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 L1: do {
  if ($10) {
   label = 14;
  } else {
   __THREW__ = 0;
   invoke_vii(2884,($buffer|0),($9|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 8;
   } else {
    $index$02$i = 0;
    while(1) {
     $13 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     $14 = (invoke_iiii(1555,($13|0),($index$02$i|0),16)|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     ;HEAP32[$1+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$14+12>>2]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$02$i<<4)|0);
     ;HEAP32[$18+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$1+12>>2]|0;
     $19 = (($index$02$i) + 1)|0;
     $20 = ($19|0)==($9|0);
     if ($20) {
      label = 14;
      break L1;
     } else {
      $index$02$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L8: do {
  if ((label|0) == 14) {
   $38 = HEAP32[$2>>2]|0;
   $39 = HEAP32[$buffer>>2]|0;
   $40 = $38;
   $41 = $39;
   $42 = (($40) - ($41))|0;
   $43 = $42 >> 4;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($5) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($5) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 8;
     break;
    }
   }
   $52 = HEAP32[$2>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $61 = $52;
    } else {
     $55 = $53;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3206,($55|0),($5|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 6;
       break;
      }
      $58 = (($55) + 16|0);
      $59 = ($58|0)==($52|0);
      if ($59) {
       label = 20;
       break;
      } else {
       $55 = $58;
      }
     }
     if ((label|0) == 6) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L8;
     }
     else if ((label|0) == 20) {
      $$pre = HEAP32[$buffer>>2]|0;
      $61 = $$pre;
      break;
     }
    }
   } while(0);
   $60 = ($61|0)==(0|0);
   if ($60) {
    STACKTOP = sp;return;
   }
   $62 = HEAP32[$2>>2]|0;
   $63 = ($62|0)==($61|0);
   if (!($63)) {
    $__new_last2$i$i$i$i$i$i$i = $61;
    $scevgep$i$i$i$i$i$i$i = (($62) + -16|0);
    $64 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($64)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $65 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $66 = $65 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($62) + ($66<<4)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($61|0),($$byval_copy8|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    ___cxa_call_unexpected(($69|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$2>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<4)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI8Vector4fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$02$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 40|0;
 $size$i$i$i = sp + 20|0;
 $0 = sp + 16|0;
 $1 = sp;
 $buffer = sp + 24|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 L1: do {
  if ($10) {
   label = 14;
  } else {
   __THREW__ = 0;
   invoke_vii(2885,($buffer|0),($9|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 8;
   } else {
    $index$02$i = 0;
    while(1) {
     $13 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     $14 = (invoke_iiii(1555,($13|0),($index$02$i|0),16)|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     ;HEAP32[$1+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$14+12>>2]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$02$i<<4)|0);
     ;HEAP32[$18+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$1+12>>2]|0;
     $19 = (($index$02$i) + 1)|0;
     $20 = ($19|0)==($9|0);
     if ($20) {
      label = 14;
      break L1;
     } else {
      $index$02$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L8: do {
  if ((label|0) == 14) {
   $38 = HEAP32[$2>>2]|0;
   $39 = HEAP32[$buffer>>2]|0;
   $40 = $38;
   $41 = $39;
   $42 = (($40) - ($41))|0;
   $43 = $42 >> 4;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($5) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($5) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 8;
     break;
    }
   }
   $52 = HEAP32[$2>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $61 = $52;
    } else {
     $55 = $53;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3207,($55|0),($5|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 6;
       break;
      }
      $58 = (($55) + 16|0);
      $59 = ($58|0)==($52|0);
      if ($59) {
       label = 20;
       break;
      } else {
       $55 = $58;
      }
     }
     if ((label|0) == 6) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L8;
     }
     else if ((label|0) == 20) {
      $$pre = HEAP32[$buffer>>2]|0;
      $61 = $$pre;
      break;
     }
    }
   } while(0);
   $60 = ($61|0)==(0|0);
   if ($60) {
    STACKTOP = sp;return;
   }
   $62 = HEAP32[$2>>2]|0;
   $63 = ($62|0)==($61|0);
   if (!($63)) {
    $__new_last2$i$i$i$i$i$i$i = $61;
    $scevgep$i$i$i$i$i$i$i = (($62) + -16|0);
    $64 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($64)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $65 = $uglygep3$i$i$i$i$i$i$i >>> 4;
    $66 = $65 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($62) + ($66<<4)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($61|0),($$byval_copy8|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    ___cxa_call_unexpected(($69|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$2>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -16|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 4;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<4)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI8Vector2fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$03$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   label = 13;
  } else {
   __THREW__ = 0;
   invoke_vii(2886,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 7;
   } else {
    $index$03$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$03$i|0),8)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = $13;
     $17 = $16;
     $18 = HEAP32[$17>>2]|0;
     $19 = (($16) + 4)|0;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$buffer>>2]|0;
     $23 = (($22) + ($index$03$i<<3)|0);
     $24 = $23;
     $25 = $24;
     HEAP32[$25>>2] = $18;
     $26 = (($24) + 4)|0;
     $27 = $26;
     HEAP32[$27>>2] = $21;
     $28 = (($index$03$i) + 1)|0;
     $29 = ($28|0)==($8|0);
     if ($29) {
      label = 13;
      break L1;
     } else {
      $index$03$i = $28;
     }
    }
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    $lpad$phi$index = $30;$lpad$phi$index2 = $31;
   }
  }
 } while(0);
 if ((label|0) == 13) {
  __THREW__ = 0;
  invoke_viii(1907,($4|0),($buffer|0),0);
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   label = 7;
  } else {
   $47 = HEAP32[$buffer>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    STACKTOP = sp;return;
   }
   $49 = HEAP32[$1>>2]|0;
   $50 = ($49|0)==($47|0);
   if (!($50)) {
    $__new_last2$i$i$i$i$i$i$i = $47;
    $scevgep$i$i$i$i$i$i$i = (($49) + -8|0);
    $51 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($51)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $52 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $53 = $52 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($49) + ($53<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($47|0),($$byval_copy6|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    $56 = ___cxa_find_matching_catch()|0;
    $57 = tempRet0;
    ___cxa_call_unexpected(($56|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 7) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  $lpad$phi$index = $32;$lpad$phi$index2 = $33;
 }
 $34 = HEAP32[$buffer>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $36 = HEAP32[$1>>2]|0;
 $37 = ($36|0)==($34|0);
 if (!($37)) {
  $__new_last2$i$i$i$i$i$i$i2 = $34;
  $scevgep$i$i$i$i$i$i$i3 = (($36) + -8|0);
  $38 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($38)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $39 = $uglygep3$i$i$i$i$i$i$i6 >>> 3;
  $40 = $39 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($36) + ($40<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy6|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  ___cxa_call_unexpected(($43|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector2f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$data>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 HEAP32[$size>>2] = $7;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size,4);
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$data>>2]|0;
 $16 = ($15|0)==($14|0);
 if ($16) {
  STACKTOP = sp;return;
 } else {
  $22 = $15;
 }
 while(1) {
  $17 = HEAP32[$8>>2]|0;
  $18 = (($17) + 4|0);
  $19 = HEAP32[$11>>2]|0;
  $20 = ($18>>>0)<($19>>>0);
  if ($20) {
   $21 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$17>>2] = $21;
   HEAP32[$8>>2] = $18;
   $25 = $18;$27 = $19;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$22,4);
   $$pre$i$i$i = HEAP32[$8>>2]|0;
   $$pre2$i$i$i = HEAP32[$11>>2]|0;
   $25 = $$pre$i$i$i;$27 = $$pre2$i$i$i;
  }
  $23 = (($22) + 4|0);
  $24 = (($25) + 4|0);
  $26 = ($24>>>0)<($27>>>0);
  if ($26) {
   $28 = Math_fround(HEAPF32[$23>>2]);
   HEAPF32[$25>>2] = $28;
   HEAP32[$8>>2] = $24;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$23,4);
  }
  $29 = (($22) + 8|0);
  $30 = ($29|0)==($14|0);
  if ($30) {
   break;
  } else {
   $22 = $29;
  }
 }
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveI8Vector3fEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$02$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0;
 var $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 L1: do {
  if ($10) {
   label = 13;
  } else {
   __THREW__ = 0;
   invoke_vii(2887,($buffer|0),($9|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 7;
   } else {
    $index$02$i = 0;
    while(1) {
     $13 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     $14 = (invoke_iiii(1555,($13|0),($index$02$i|0),12)|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     ;HEAP32[$1+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$14+8>>2]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + (($index$02$i*12)|0)|0);
     ;HEAP32[$18+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$1+8>>2]|0;
     $19 = (($index$02$i) + 1)|0;
     $20 = ($19|0)==($9|0);
     if ($20) {
      label = 13;
      break L1;
     } else {
      $index$02$i = $19;
     }
    }
    $21 = ___cxa_find_matching_catch()|0;
    $22 = tempRet0;
    $lpad$phi$index = $21;$lpad$phi$index2 = $22;
   }
  }
 } while(0);
 if ((label|0) == 13) {
  __THREW__ = 0;
  invoke_viii(1908,($5|0),($buffer|0),0);
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   label = 7;
  } else {
   $38 = HEAP32[$buffer>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $40 = HEAP32[$2>>2]|0;
   $41 = ($40|0)==($38|0);
   if (!($41)) {
    $__new_last2$i$i$i$i$i$i$i = $38;
    $scevgep$i$i$i$i$i$i$i = (($40) + -12|0);
    $42 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($42)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $43 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 12)&-1;
    $44 = $43 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($40) + (($44*12)|0)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($38|0),($$byval_copy6|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $47 = ___cxa_find_matching_catch()|0;
    $48 = tempRet0;
    ___cxa_call_unexpected(($47|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 7) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  $lpad$phi$index = $23;$lpad$phi$index2 = $24;
 }
 $25 = HEAP32[$buffer>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $27 = HEAP32[$2>>2]|0;
 $28 = ($27|0)==($25|0);
 if (!($28)) {
  $__new_last2$i$i$i$i$i$i$i2 = $25;
  $scevgep$i$i$i$i$i$i$i3 = (($27) + -12|0);
  $29 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($29)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $30 = (($uglygep3$i$i$i$i$i$i$i6>>>0) / 12)&-1;
  $31 = $30 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($27) + (($31*12)|0)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($25|0),($$byval_copy6|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector3f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$data>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 HEAP32[$size>>2] = $7;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size,4);
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$data>>2]|0;
 $16 = ($15|0)==($14|0);
 if ($16) {
  STACKTOP = sp;return;
 } else {
  $22 = $15;
 }
 while(1) {
  $17 = HEAP32[$8>>2]|0;
  $18 = (($17) + 4|0);
  $19 = HEAP32[$11>>2]|0;
  $20 = ($18>>>0)<($19>>>0);
  if ($20) {
   $21 = Math_fround(HEAPF32[$22>>2]);
   HEAPF32[$17>>2] = $21;
   HEAP32[$8>>2] = $18;
   $25 = $18;$27 = $19;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$22,4);
   $$pre$i$i$i = HEAP32[$8>>2]|0;
   $$pre3$i$i$i = HEAP32[$11>>2]|0;
   $25 = $$pre$i$i$i;$27 = $$pre3$i$i$i;
  }
  $23 = (($22) + 4|0);
  $24 = (($25) + 4|0);
  $26 = ($24>>>0)<($27>>>0);
  if ($26) {
   $28 = Math_fround(HEAPF32[$23>>2]);
   HEAPF32[$25>>2] = $28;
   HEAP32[$8>>2] = $24;
   $31 = $24;$33 = $27;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$23,4);
   $$pre4$i$i$i = HEAP32[$8>>2]|0;
   $$pre5$i$i$i = HEAP32[$11>>2]|0;
   $31 = $$pre4$i$i$i;$33 = $$pre5$i$i$i;
  }
  $29 = (($22) + 8|0);
  $30 = (($31) + 4|0);
  $32 = ($30>>>0)<($33>>>0);
  if ($32) {
   $34 = Math_fround(HEAPF32[$29>>2]);
   HEAPF32[$31>>2] = $34;
   HEAP32[$8>>2] = $30;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$29,4);
  }
  $35 = (($22) + 12|0);
  $36 = ($35|0)==($14|0);
  if ($36) {
   break;
  } else {
   $22 = $35;
  }
 }
 STACKTOP = sp;return;
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIdEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0;
 var $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $41 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2888,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),8)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = +HEAPF64[$13>>3];
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$01$i<<3)|0);
     HEAPF64[$18>>3] = $16;
     $19 = (($index$01$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      $41 = $17;
      label = 15;
      break L1;
     } else {
      $index$01$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $38 = HEAP32[$1>>2]|0;
   $39 = $38;
   $40 = $41;
   $42 = (($39) - ($40))|0;
   $43 = $42 >> 3;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($4) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($4) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 9;
     break;
    }
   }
   $52 = HEAP32[$1>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $77 = $52;
    } else {
     $60 = $53;
     while(1) {
      $55 = HEAP32[$44>>2]|0;
      $56 = (($55) + 8|0);
      $57 = HEAP32[$47>>2]|0;
      $58 = ($56>>>0)<($57>>>0);
      if ($58) {
       $59 = $60;
       $61 = $59;
       $62 = HEAPU8[$61>>0]|(HEAPU8[$61+1>>0]<<8)|(HEAPU8[$61+2>>0]<<16)|(HEAPU8[$61+3>>0]<<24);
       $63 = (($59) + 4)|0;
       $64 = $63;
       $65 = HEAPU8[$64>>0]|(HEAPU8[$64+1>>0]<<8)|(HEAPU8[$64+2>>0]<<16)|(HEAPU8[$64+3>>0]<<24);
       $66 = $55;
       $67 = $66;
       HEAP8[$67>>0]=$62&255;HEAP8[$67+1>>0]=($62>>8)&255;HEAP8[$67+2>>0]=($62>>16)&255;HEAP8[$67+3>>0]=$62>>24;
       $68 = (($66) + 4)|0;
       $69 = $68;
       HEAP8[$69>>0]=$65&255;HEAP8[$69+1>>0]=($65>>8)&255;HEAP8[$69+2>>0]=($65>>16)&255;HEAP8[$69+3>>0]=$65>>24;
       $70 = HEAP32[$44>>2]|0;
       $71 = (($70) + 8|0);
       HEAP32[$44>>2] = $71;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($44|0),($60|0),8);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        label = 7;
        break;
       }
      }
      $74 = (($60) + 8|0);
      $75 = ($74|0)==($52|0);
      if ($75) {
       label = 23;
       break;
      } else {
       $60 = $74;
      }
     }
     if ((label|0) == 7) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $77 = $$pre;
      break;
     }
    }
   } while(0);
   $76 = ($77|0)==(0|0);
   if ($76) {
    STACKTOP = sp;return;
   }
   $78 = HEAP32[$1>>2]|0;
   $79 = ($78|0)==($77|0);
   if (!($79)) {
    $__new_last2$i$i$i$i$i$i$i = $77;
    $scevgep$i$i$i$i$i$i$i = (($78) + -8|0);
    $80 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($80)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $81 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $82 = $81 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($78) + ($82<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($77|0),($$byval_copy8|0));
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $85 = ___cxa_find_matching_catch()|0;
    $86 = tempRet0;
    ___cxa_call_unexpected(($85|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -8|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 3;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIfEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $41 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2889,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),4)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = Math_fround(HEAPF32[$13>>2]);
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$01$i<<2)|0);
     HEAPF32[$18>>2] = $16;
     $19 = (($index$01$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      $41 = $17;
      label = 15;
      break L1;
     } else {
      $index$01$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $38 = HEAP32[$1>>2]|0;
   $39 = $38;
   $40 = $41;
   $42 = (($39) - ($40))|0;
   $43 = $42 >> 2;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($4) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($4) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 9;
     break;
    }
   }
   $52 = HEAP32[$1>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $66 = $52;
    } else {
     $60 = $53;
     while(1) {
      $55 = HEAP32[$44>>2]|0;
      $56 = (($55) + 4|0);
      $57 = HEAP32[$47>>2]|0;
      $58 = ($56>>>0)<($57>>>0);
      if ($58) {
       $59 = Math_fround(HEAPF32[$60>>2]);
       HEAPF32[$55>>2] = $59;
       HEAP32[$44>>2] = $56;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($44|0),($60|0),4);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 7;
        break;
       }
      }
      $63 = (($60) + 4|0);
      $64 = ($63|0)==($52|0);
      if ($64) {
       label = 23;
       break;
      } else {
       $60 = $63;
      }
     }
     if ((label|0) == 7) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $66 = $$pre;
      break;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $67 = HEAP32[$1>>2]|0;
   $68 = ($67|0)==($66|0);
   if (!($68)) {
    $__new_last2$i$i$i$i$i$i$i = $66;
    $scevgep$i$i$i$i$i$i$i = (($67) + -4|0);
    $69 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($69)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $70 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $71 = $70 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($67) + ($71<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy8|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIyEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0;
 var $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $50 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2890,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),8)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = $13;
     $17 = $16;
     $18 = HEAP32[$17>>2]|0;
     $19 = (($16) + 4)|0;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$buffer>>2]|0;
     $23 = (($22) + ($index$01$i<<3)|0);
     $24 = $23;
     $25 = $24;
     HEAP32[$25>>2] = $18;
     $26 = (($24) + 4)|0;
     $27 = $26;
     HEAP32[$27>>2] = $21;
     $28 = (($index$01$i) + 1)|0;
     $29 = ($28|0)==($8|0);
     if ($29) {
      $50 = $22;
      label = 15;
      break L1;
     } else {
      $index$01$i = $28;
     }
    }
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    $lpad$phi$index = $32;$lpad$phi$index3 = $33;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $47 = HEAP32[$1>>2]|0;
   $48 = $47;
   $49 = $50;
   $51 = (($48) - ($49))|0;
   $52 = $51 >> 3;
   HEAP32[$size$i$i$i>>2] = $52;
   $53 = (($4) + 12|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 4|0);
   $56 = (($4) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($55>>>0)<($57>>>0);
   if ($58) {
    HEAP32[$54>>2] = $52;
    HEAP32[$53>>2] = $55;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($53|0),($size$i$i$i|0),4);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 9;
     break;
    }
   }
   $61 = HEAP32[$1>>2]|0;
   $62 = HEAP32[$buffer>>2]|0;
   $63 = ($62|0)==($61|0);
   do {
    if ($63) {
     $84 = $61;
    } else {
     $69 = $62;
     while(1) {
      $64 = HEAP32[$53>>2]|0;
      $65 = (($64) + 8|0);
      $66 = HEAP32[$56>>2]|0;
      $67 = ($65>>>0)<($66>>>0);
      if ($67) {
       $68 = $69;
       $70 = $68;
       $71 = HEAP32[$70>>2]|0;
       $72 = (($68) + 4)|0;
       $73 = $72;
       $74 = HEAP32[$73>>2]|0;
       $75 = $64;
       $76 = $75;
       HEAP32[$76>>2] = $71;
       $77 = (($75) + 4)|0;
       $78 = $77;
       HEAP32[$78>>2] = $74;
       HEAP32[$53>>2] = $65;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($53|0),($69|0),8);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        label = 7;
        break;
       }
      }
      $81 = (($69) + 8|0);
      $82 = ($81|0)==($61|0);
      if ($82) {
       label = 23;
       break;
      } else {
       $69 = $81;
      }
     }
     if ((label|0) == 7) {
      $30 = ___cxa_find_matching_catch()|0;
      $31 = tempRet0;
      $lpad$phi$index = $30;$lpad$phi$index3 = $31;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $84 = $$pre;
      break;
     }
    }
   } while(0);
   $83 = ($84|0)==(0|0);
   if ($83) {
    STACKTOP = sp;return;
   }
   $85 = HEAP32[$1>>2]|0;
   $86 = ($85|0)==($84|0);
   if (!($86)) {
    $__new_last2$i$i$i$i$i$i$i = $84;
    $scevgep$i$i$i$i$i$i$i = (($85) + -8|0);
    $87 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($87)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $88 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $89 = $88 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($85) + ($89<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($84|0),($$byval_copy8|0));
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    $92 = ___cxa_find_matching_catch()|0;
    $93 = tempRet0;
    ___cxa_call_unexpected(($92|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  $lpad$phi$index = $34;$lpad$phi$index3 = $35;
 }
 $36 = HEAP32[$buffer>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $38 = HEAP32[$1>>2]|0;
 $39 = ($38|0)==($36|0);
 if (!($39)) {
  $__new_last2$i$i$i$i$i$i$i2 = $36;
  $scevgep$i$i$i$i$i$i$i3 = (($38) + -8|0);
  $40 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($40)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $41 = $uglygep3$i$i$i$i$i$i$i6 >>> 3;
  $42 = $41 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($38) + ($42<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($36|0),($$byval_copy8|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  ___cxa_call_unexpected(($45|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIxEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0;
 var $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $50 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2891,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),8)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = $13;
     $17 = $16;
     $18 = HEAP32[$17>>2]|0;
     $19 = (($16) + 4)|0;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$buffer>>2]|0;
     $23 = (($22) + ($index$01$i<<3)|0);
     $24 = $23;
     $25 = $24;
     HEAP32[$25>>2] = $18;
     $26 = (($24) + 4)|0;
     $27 = $26;
     HEAP32[$27>>2] = $21;
     $28 = (($index$01$i) + 1)|0;
     $29 = ($28|0)==($8|0);
     if ($29) {
      $50 = $22;
      label = 15;
      break L1;
     } else {
      $index$01$i = $28;
     }
    }
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    $lpad$phi$index = $32;$lpad$phi$index3 = $33;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $47 = HEAP32[$1>>2]|0;
   $48 = $47;
   $49 = $50;
   $51 = (($48) - ($49))|0;
   $52 = $51 >> 3;
   HEAP32[$size$i$i$i>>2] = $52;
   $53 = (($4) + 12|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 4|0);
   $56 = (($4) + 20|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($55>>>0)<($57>>>0);
   if ($58) {
    HEAP32[$54>>2] = $52;
    HEAP32[$53>>2] = $55;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($53|0),($size$i$i$i|0),4);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 9;
     break;
    }
   }
   $61 = HEAP32[$1>>2]|0;
   $62 = HEAP32[$buffer>>2]|0;
   $63 = ($62|0)==($61|0);
   do {
    if ($63) {
     $84 = $61;
    } else {
     $69 = $62;
     while(1) {
      $64 = HEAP32[$53>>2]|0;
      $65 = (($64) + 8|0);
      $66 = HEAP32[$56>>2]|0;
      $67 = ($65>>>0)<($66>>>0);
      if ($67) {
       $68 = $69;
       $70 = $68;
       $71 = HEAP32[$70>>2]|0;
       $72 = (($68) + 4)|0;
       $73 = $72;
       $74 = HEAP32[$73>>2]|0;
       $75 = $64;
       $76 = $75;
       HEAP32[$76>>2] = $71;
       $77 = (($75) + 4)|0;
       $78 = $77;
       HEAP32[$78>>2] = $74;
       HEAP32[$53>>2] = $65;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($53|0),($69|0),8);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        label = 7;
        break;
       }
      }
      $81 = (($69) + 8|0);
      $82 = ($81|0)==($61|0);
      if ($82) {
       label = 23;
       break;
      } else {
       $69 = $81;
      }
     }
     if ((label|0) == 7) {
      $30 = ___cxa_find_matching_catch()|0;
      $31 = tempRet0;
      $lpad$phi$index = $30;$lpad$phi$index3 = $31;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $84 = $$pre;
      break;
     }
    }
   } while(0);
   $83 = ($84|0)==(0|0);
   if ($83) {
    STACKTOP = sp;return;
   }
   $85 = HEAP32[$1>>2]|0;
   $86 = ($85|0)==($84|0);
   if (!($86)) {
    $__new_last2$i$i$i$i$i$i$i = $84;
    $scevgep$i$i$i$i$i$i$i = (($85) + -8|0);
    $87 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($87)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $88 = $uglygep3$i$i$i$i$i$i$i >>> 3;
    $89 = $88 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($85) + ($89<<3)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($84|0),($$byval_copy8|0));
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    $92 = ___cxa_find_matching_catch()|0;
    $93 = tempRet0;
    ___cxa_call_unexpected(($92|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  $lpad$phi$index = $34;$lpad$phi$index3 = $35;
 }
 $36 = HEAP32[$buffer>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $38 = HEAP32[$1>>2]|0;
 $39 = ($38|0)==($36|0);
 if (!($39)) {
  $__new_last2$i$i$i$i$i$i$i2 = $36;
  $scevgep$i$i$i$i$i$i$i3 = (($38) + -8|0);
  $40 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($40)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $41 = $uglygep3$i$i$i$i$i$i$i6 >>> 3;
  $42 = $41 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($38) + ($42<<3)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($36|0),($$byval_copy8|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  ___cxa_call_unexpected(($45|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIjEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $41 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2892,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),4)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP32[$13>>2]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$01$i<<2)|0);
     HEAP32[$18>>2] = $16;
     $19 = (($index$01$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      $41 = $17;
      label = 15;
      break L1;
     } else {
      $index$01$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $38 = HEAP32[$1>>2]|0;
   $39 = $38;
   $40 = $41;
   $42 = (($39) - ($40))|0;
   $43 = $42 >> 2;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($4) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($4) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 9;
     break;
    }
   }
   $52 = HEAP32[$1>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $66 = $52;
    } else {
     $60 = $53;
     while(1) {
      $55 = HEAP32[$44>>2]|0;
      $56 = (($55) + 4|0);
      $57 = HEAP32[$47>>2]|0;
      $58 = ($56>>>0)<($57>>>0);
      if ($58) {
       $59 = HEAP32[$60>>2]|0;
       HEAP32[$55>>2] = $59;
       HEAP32[$44>>2] = $56;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($44|0),($60|0),4);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 7;
        break;
       }
      }
      $63 = (($60) + 4|0);
      $64 = ($63|0)==($52|0);
      if ($64) {
       label = 23;
       break;
      } else {
       $60 = $63;
      }
     }
     if ((label|0) == 7) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $66 = $$pre;
      break;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $67 = HEAP32[$1>>2]|0;
   $68 = ($67|0)==($66|0);
   if (!($68)) {
    $__new_last2$i$i$i$i$i$i$i = $66;
    $scevgep$i$i$i$i$i$i$i = (($67) + -4|0);
    $69 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($69)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $70 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $71 = $70 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($67) + ($71<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy8|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIiEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $41 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2893,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),4)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP32[$13>>2]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$01$i<<2)|0);
     HEAP32[$18>>2] = $16;
     $19 = (($index$01$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      $41 = $17;
      label = 15;
      break L1;
     } else {
      $index$01$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $38 = HEAP32[$1>>2]|0;
   $39 = $38;
   $40 = $41;
   $42 = (($39) - ($40))|0;
   $43 = $42 >> 2;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($4) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($4) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 9;
     break;
    }
   }
   $52 = HEAP32[$1>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $66 = $52;
    } else {
     $60 = $53;
     while(1) {
      $55 = HEAP32[$44>>2]|0;
      $56 = (($55) + 4|0);
      $57 = HEAP32[$47>>2]|0;
      $58 = ($56>>>0)<($57>>>0);
      if ($58) {
       $59 = HEAP32[$60>>2]|0;
       HEAP32[$55>>2] = $59;
       HEAP32[$44>>2] = $56;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($44|0),($60|0),4);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 7;
        break;
       }
      }
      $63 = (($60) + 4|0);
      $64 = ($63|0)==($52|0);
      if ($64) {
       label = 23;
       break;
      } else {
       $60 = $63;
      }
     }
     if ((label|0) == 7) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $66 = $$pre;
      break;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $67 = HEAP32[$1>>2]|0;
   $68 = ($67|0)==($66|0);
   if (!($68)) {
    $__new_last2$i$i$i$i$i$i$i = $66;
    $scevgep$i$i$i$i$i$i$i = (($67) + -4|0);
    $69 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($69)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $70 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $71 = $70 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($67) + ($71<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy8|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveItEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $41 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2894,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),2)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP16[$13>>1]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$01$i<<1)|0);
     HEAP16[$18>>1] = $16;
     $19 = (($index$01$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      $41 = $17;
      label = 15;
      break L1;
     } else {
      $index$01$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $38 = HEAP32[$1>>2]|0;
   $39 = $38;
   $40 = $41;
   $42 = (($39) - ($40))|0;
   $43 = $42 >> 1;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($4) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($4) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 9;
     break;
    }
   }
   $52 = HEAP32[$1>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $66 = $52;
    } else {
     $60 = $53;
     while(1) {
      $55 = HEAP32[$44>>2]|0;
      $56 = (($55) + 2|0);
      $57 = HEAP32[$47>>2]|0;
      $58 = ($56>>>0)<($57>>>0);
      if ($58) {
       $59 = HEAP16[$60>>1]|0;
       HEAP16[$55>>1] = $59;
       HEAP32[$44>>2] = $56;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($44|0),($60|0),2);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 7;
        break;
       }
      }
      $63 = (($60) + 2|0);
      $64 = ($63|0)==($52|0);
      if ($64) {
       label = 23;
       break;
      } else {
       $60 = $63;
      }
     }
     if ((label|0) == 7) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $66 = $$pre;
      break;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $67 = HEAP32[$1>>2]|0;
   $68 = ($67|0)==($66|0);
   if (!($68)) {
    $__new_last2$i$i$i$i$i$i$i = $66;
    $scevgep$i$i$i$i$i$i$i = (($67) + -2|0);
    $69 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($69)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $70 = $uglygep3$i$i$i$i$i$i$i >>> 1;
    $71 = $70 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($67) + ($71<<1)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy8|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -2|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 1;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIsEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i2 = 0, $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i7 = 0, $size$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   $$pre17 = HEAP32[$buffer>>2]|0;
   $41 = $$pre17;
   label = 15;
  } else {
   __THREW__ = 0;
   invoke_vii(2895,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 9;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),2)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP16[$13>>1]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$01$i<<1)|0);
     HEAP16[$18>>1] = $16;
     $19 = (($index$01$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      $41 = $17;
      label = 15;
      break L1;
     } else {
      $index$01$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L9: do {
  if ((label|0) == 15) {
   $38 = HEAP32[$1>>2]|0;
   $39 = $38;
   $40 = $41;
   $42 = (($39) - ($40))|0;
   $43 = $42 >> 1;
   HEAP32[$size$i$i$i>>2] = $43;
   $44 = (($4) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 4|0);
   $47 = (($4) + 20|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($46>>>0)<($48>>>0);
   if ($49) {
    HEAP32[$45>>2] = $43;
    HEAP32[$44>>2] = $46;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($44|0),($size$i$i$i|0),4);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 9;
     break;
    }
   }
   $52 = HEAP32[$1>>2]|0;
   $53 = HEAP32[$buffer>>2]|0;
   $54 = ($53|0)==($52|0);
   do {
    if ($54) {
     $66 = $52;
    } else {
     $60 = $53;
     while(1) {
      $55 = HEAP32[$44>>2]|0;
      $56 = (($55) + 2|0);
      $57 = HEAP32[$47>>2]|0;
      $58 = ($56>>>0)<($57>>>0);
      if ($58) {
       $59 = HEAP16[$60>>1]|0;
       HEAP16[$55>>1] = $59;
       HEAP32[$44>>2] = $56;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($44|0),($60|0),2);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 7;
        break;
       }
      }
      $63 = (($60) + 2|0);
      $64 = ($63|0)==($52|0);
      if ($64) {
       label = 23;
       break;
      } else {
       $60 = $63;
      }
     }
     if ((label|0) == 7) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L9;
     }
     else if ((label|0) == 23) {
      $$pre = HEAP32[$buffer>>2]|0;
      $66 = $$pre;
      break;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   $67 = HEAP32[$1>>2]|0;
   $68 = ($67|0)==($66|0);
   if (!($68)) {
    $__new_last2$i$i$i$i$i$i$i = $66;
    $scevgep$i$i$i$i$i$i$i = (($67) + -2|0);
    $69 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($69)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $70 = $uglygep3$i$i$i$i$i$i$i >>> 1;
    $71 = $70 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($67) + ($71<<1)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy8|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i$i$i2 = $27;
  $scevgep$i$i$i$i$i$i$i3 = (($29) + -2|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i3) + ($31)|0);
  $uglygep3$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i5;
  $32 = $uglygep3$i$i$i$i$i$i$i6 >>> 1;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i$i7 = (($29) + ($33<<1)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i$i$i7;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIhEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $size$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   label = 14;
  } else {
   __THREW__ = 0;
   invoke_vii(2896,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 8;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),1)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP8[$13>>0]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$01$i)|0);
     HEAP8[$18>>0] = $16;
     $19 = (($index$01$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      label = 14;
      break L1;
     } else {
      $index$01$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L8: do {
  if ((label|0) == 14) {
   $35 = HEAP32[$1>>2]|0;
   $36 = HEAP32[$buffer>>2]|0;
   $37 = $35;
   $38 = $36;
   $39 = (($37) - ($38))|0;
   HEAP32[$size$i$i$i>>2] = $39;
   $40 = (($4) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 4|0);
   $43 = (($4) + 20|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($42>>>0)<($44>>>0);
   if ($45) {
    HEAP32[$41>>2] = $39;
    HEAP32[$40>>2] = $42;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($40|0),($size$i$i$i|0),4);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 8;
     break;
    }
   }
   $48 = HEAP32[$1>>2]|0;
   $49 = HEAP32[$buffer>>2]|0;
   $50 = ($49|0)==($48|0);
   L14: do {
    if (!($50)) {
     $56 = $49;
     while(1) {
      $51 = HEAP32[$40>>2]|0;
      $52 = (($51) + 1|0);
      $53 = HEAP32[$43>>2]|0;
      $54 = ($52>>>0)<($53>>>0);
      if ($54) {
       $55 = HEAP8[$56>>0]|0;
       HEAP8[$51>>0] = $55;
       $57 = HEAP32[$40>>2]|0;
       $58 = (($57) + 1|0);
       HEAP32[$40>>2] = $58;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($40|0),($56|0),1);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
      }
      $61 = (($56) + 1|0);
      $62 = ($61|0)==($48|0);
      if ($62) {
       break L14;
      } else {
       $56 = $61;
      }
     }
     $21 = ___cxa_find_matching_catch()|0;
     $22 = tempRet0;
     $lpad$phi$index = $21;$lpad$phi$index3 = $22;
     break L8;
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3378,($4|0));
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    label = 8;
   } else {
    $65 = HEAP32[$buffer>>2]|0;
    $66 = ($65|0)==(0|0);
    if ($66) {
     STACKTOP = sp;return;
    }
    $67 = HEAP32[$1>>2]|0;
    $68 = ($67|0)==($65|0);
    if (!($68)) {
     HEAP32[$1>>2] = $65;
    }
    HEAP32[$size$i$i$i>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
    invoke_vii(2591,($65|0),($$byval_copy8|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     $71 = ___cxa_find_matching_catch()|0;
     $72 = tempRet0;
     ___cxa_call_unexpected(($71|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  HEAP32[$1>>2] = $27;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  ___cxa_call_unexpected(($33|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE19Converter_PrimitiveIaEEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $buffer = 0, $index$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $buffer = sp + 8|0;
 HEAP32[$buffer>>2] = 0;
 $1 = (($buffer) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buffer) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($runtimeInfo) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($runtimeInfo) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 L1: do {
  if ($9) {
   label = 14;
  } else {
   __THREW__ = 0;
   invoke_vii(2897,($buffer|0),($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 8;
   } else {
    $index$01$i = 0;
    while(1) {
     $12 = HEAP32[$6>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(1555,($12|0),($index$01$i|0),1)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP8[$13>>0]|0;
     $17 = HEAP32[$buffer>>2]|0;
     $18 = (($17) + ($index$01$i)|0);
     HEAP8[$18>>0] = $16;
     $19 = (($index$01$i) + 1)|0;
     $20 = ($19|0)==($8|0);
     if ($20) {
      label = 14;
      break L1;
     } else {
      $index$01$i = $19;
     }
    }
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $lpad$phi$index = $23;$lpad$phi$index3 = $24;
   }
  }
 } while(0);
 L8: do {
  if ((label|0) == 14) {
   $35 = HEAP32[$1>>2]|0;
   $36 = HEAP32[$buffer>>2]|0;
   $37 = $35;
   $38 = $36;
   $39 = (($37) - ($38))|0;
   HEAP32[$size$i$i$i>>2] = $39;
   $40 = (($4) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 4|0);
   $43 = (($4) + 20|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($42>>>0)<($44>>>0);
   if ($45) {
    HEAP32[$41>>2] = $39;
    HEAP32[$40>>2] = $42;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($40|0),($size$i$i$i|0),4);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 8;
     break;
    }
   }
   $48 = HEAP32[$1>>2]|0;
   $49 = HEAP32[$buffer>>2]|0;
   $50 = ($49|0)==($48|0);
   do {
    if ($50) {
     $64 = $48;
    } else {
     $56 = $49;
     while(1) {
      $51 = HEAP32[$40>>2]|0;
      $52 = (($51) + 1|0);
      $53 = HEAP32[$43>>2]|0;
      $54 = ($52>>>0)<($53>>>0);
      if ($54) {
       $55 = HEAP8[$56>>0]|0;
       HEAP8[$51>>0] = $55;
       $57 = HEAP32[$40>>2]|0;
       $58 = (($57) + 1|0);
       HEAP32[$40>>2] = $58;
      } else {
       __THREW__ = 0;
       invoke_viii(1640,($40|0),($56|0),1);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        label = 6;
        break;
       }
      }
      $61 = (($56) + 1|0);
      $62 = ($61|0)==($48|0);
      if ($62) {
       label = 22;
       break;
      } else {
       $56 = $61;
      }
     }
     if ((label|0) == 6) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $lpad$phi$index = $21;$lpad$phi$index3 = $22;
      break L8;
     }
     else if ((label|0) == 22) {
      $$pre = HEAP32[$buffer>>2]|0;
      $64 = $$pre;
      break;
     }
    }
   } while(0);
   $63 = ($64|0)==(0|0);
   if ($63) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[$1>>2]|0;
   $66 = ($65|0)==($64|0);
   if (!($66)) {
    HEAP32[$1>>2] = $64;
   }
   HEAP32[$size$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy8|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    ___cxa_call_unexpected(($69|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index3 = $26;
 }
 $27 = HEAP32[$buffer>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  HEAP32[$1>>2] = $27;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($27|0),($$byval_copy8|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  ___cxa_call_unexpected(($33|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __Z19TransferField_ArrayI19StreamedBinaryWriteILb0EE16Converter_StringEvRK23StaticTransferFieldInfoR31RuntimeSerializationCommandInfoRT0_($staticInfo,$runtimeInfo,$converter) {
 $staticInfo = $staticInfo|0;
 $runtimeInfo = $runtimeInfo|0;
 $converter = $converter|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i3 = 0, $$pre$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $buffer = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 32|0;
 $size$i$i$i = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $buffer = sp + 16|0;
 HEAP32[$buffer>>2] = 0;
 $2 = (($buffer) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buffer) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($runtimeInfo) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($runtimeInfo) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_vii(3208,($buffer|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   label = 3;
  } else {
   $36 = HEAP32[$2>>2]|0;
   $37 = HEAP32[$buffer>>2]|0;
   $38 = $36;
   $39 = $37;
   $40 = (($38) - ($39))|0;
   $41 = (($40|0) / 12)&-1;
   HEAP32[$size$i$i$i>>2] = $41;
   $42 = (($5) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($43) + 4|0);
   $45 = (($5) + 20|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($44>>>0)<($46>>>0);
   if ($47) {
    HEAP32[$43>>2] = $41;
    HEAP32[$42>>2] = $44;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($42|0),($size$i$i$i|0),4);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 3;
     break;
    }
   }
   $50 = HEAP32[$2>>2]|0;
   $51 = HEAP32[$buffer>>2]|0;
   $52 = ($51|0)==($50|0);
   do {
    if ($52) {
     $61 = $50;
    } else {
     $53 = $51;
     while(1) {
      __THREW__ = 0;
      invoke_viii(1624,($5|0),($53|0),0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 2;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3378,($5|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 2;
       break;
      }
      $58 = (($53) + 12|0);
      $59 = ($58|0)==($50|0);
      if ($59) {
       label = 22;
       break;
      } else {
       $53 = $58;
      }
     }
     if ((label|0) == 2) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      break L1;
     }
     else if ((label|0) == 22) {
      $$pre = HEAP32[$buffer>>2]|0;
      $61 = $$pre;
      break;
     }
    }
   } while(0);
   $60 = ($61|0)==(0|0);
   if ($60) {
    STACKTOP = sp;return;
   }
   $62 = HEAP32[$2>>2]|0;
   $63 = ($62|0)==($61|0);
   do {
    if ($63) {
     $77 = $61;
    } else {
     $65 = $62;
     while(1) {
      $64 = (($65) + -12|0);
      HEAP32[$2>>2] = $64;
      $66 = HEAP8[$64>>0]|0;
      $67 = $66 & 1;
      $68 = ($67<<24>>24)==(0);
      if ($68) {
       $70 = $64;
      } else {
       $71 = (($65) + -4|0);
       $72 = HEAP32[$71>>2]|0;
       HEAP32[$size$i$i$i>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$size$i$i$i+0>>2]|0;
       invoke_vii(2591,($72|0),($$byval_copy8|0));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 30;
        break;
       }
       $$pre$i$i$i$i$i$i$i = HEAP32[$2>>2]|0;
       $70 = $$pre$i$i$i$i$i$i$i;
      }
      $69 = ($70|0)==($61|0);
      if ($69) {
       label = 31;
       break;
      } else {
       $65 = $70;
      }
     }
     if ((label|0) == 30) {
      $75 = ___cxa_find_matching_catch()|0;
      $76 = tempRet0;
      ___cxa_call_unexpected(($75|0));
      // unreachable;
     }
     else if ((label|0) == 31) {
      $$pre$i$i$i$i$i = HEAP32[$buffer>>2]|0;
      $77 = $$pre$i$i$i$i$i;
      break;
     }
    }
   } while(0);
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($77|0),($$byval_copy8|0));
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $80 = ___cxa_find_matching_catch()|0;
    $81 = tempRet0;
    ___cxa_call_unexpected(($80|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 }
 $14 = HEAP32[$buffer>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $16 = HEAP32[$2>>2]|0;
 $17 = ($16|0)==($14|0);
 do {
  if ($17) {
   $31 = $14;
  } else {
   $19 = $16;
   while(1) {
    $18 = (($19) + -12|0);
    HEAP32[$2>>2] = $18;
    $20 = HEAP8[$18>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $24 = $18;
    } else {
     $25 = (($19) + -4|0);
     $26 = HEAP32[$25>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($26|0),($$byval_copy8|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 11;
      break;
     }
     $$pre$i$i$i$i$i$i$i3 = HEAP32[$2>>2]|0;
     $24 = $$pre$i$i$i$i$i$i$i3;
    }
    $23 = ($24|0)==($14|0);
    if ($23) {
     label = 12;
     break;
    } else {
     $19 = $24;
    }
   }
   if ((label|0) == 11) {
    $29 = ___cxa_find_matching_catch()|0;
    $30 = tempRet0;
    ___cxa_call_unexpected(($29|0));
    // unreachable;
   }
   else if ((label|0) == 12) {
    $$pre$i$i$i$i$i5 = HEAP32[$buffer>>2]|0;
    $31 = $$pre$i$i$i$i$i5;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy8|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN13dynamic_arrayI20SerializationCommandLj4EEaSERKS1_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$byval_copy1 = 0, $$idx = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = ($other|0)==($this|0);
 if ($1) {
  STACKTOP = sp;return ($this|0);
 }
 $2 = HEAP32[$other>>2]|0;
 $3 = (($other) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $$idx = $4 << 6;
 $5 = $$idx >> 6;
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9>>>0)<($5>>>0);
 do {
  if ($10) {
   $11 = ($8|0)>(-1);
   if ($11) {
    HEAP32[$7>>2] = $5;
    $12 = HEAP32[$this>>2]|0;
    $13 = (($this) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$0>>2] = $14;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $15 = (__Z16realloc_internalPvji10MemLabelIdiPKci($12,$$idx,4,$$byval_copy1,0,630440,370)|0);
    HEAP32[$this>>2] = $15;
    $24 = $15;
    break;
   } else {
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx,4,$$byval_copy1,0,630440,352)|0);
    $19 = HEAP32[$this>>2]|0;
    $20 = HEAP32[$6>>2]|0;
    $21 = $20 << 6;
    _memcpy(($18|0),($19|0),($21|0))|0;
    HEAP32[$7>>2] = $5;
    HEAP32[$this>>2] = $18;
    $24 = $18;
    break;
   }
  } else {
   $$pre$i = HEAP32[$this>>2]|0;
   $24 = $$pre$i;
  }
 } while(0);
 $22 = HEAP32[$6>>2]|0;
 $23 = $22 << 6;
 _memcpy(($24|0),($2|0),($23|0))|0;
 STACKTOP = sp;return ($this|0);
}
function __ZN21LinearCollectionFieldC2ERK17GeneralMonoObjectP14ScriptingField($this,$instance,$field) {
 $this = $this|0;
 $instance = $instance|0;
 $field = $field|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$this>>2] = 0;
 $1 = (($this) + 4|0);
 HEAP8[$1>>0] = 1;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 28|0);
 HEAP8[$4>>0] = 1;
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 36|0);
 HEAP32[$6>>2] = 0;
 $7 = (__Z24scripting_field_get_typeP14ScriptingField($field)|0);
 $8 = (__Z23scripting_type_get_typeP13ScriptingType($7)|0);
 $9 = ($8|0)==(29);
 $10 = (($this) + 20|0);
 $11 = $9&1;
 HEAP8[$10>>0] = $11;
 if ($9) {
  HEAP32[$this>>2] = $field;
  ;HEAP32[$1+0>>2]=HEAP32[$instance+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$instance+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$instance+8>>2]|0;
  $12 = (__Z41scripting_type_get_class_or_element_classP13ScriptingType($7)|0);
  $13 = (($this) + 16|0);
  HEAP32[$13>>2] = $12;
  STACKTOP = sp;return;
 }
 $14 = (__Z25scripting_class_from_typeP13ScriptingType($7)|0);
 $15 = (__ZN9Scripting27BackingArrayFieldForListOfTEP14ScriptingClass($14)|0);
 HEAP32[$this>>2] = $15;
 __Z30GetOrCreateObjectStoredInFieldP14ScriptingFieldRK17GeneralMonoObjectb($0,$field,$instance,0);
 ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;
 $16 = HEAP32[$2>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  (_il2cpp_object_new($14)|0);
 }
 $18 = (($this) + 24|0);
 HEAP32[$18>>2] = $field;
 ;HEAP32[$4+0>>2]=HEAP32[$instance+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$instance+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$instance+8>>2]|0;
 $19 = HEAP32[$this>>2]|0;
 $20 = (__Z24scripting_field_get_typeP14ScriptingField($19)|0);
 $21 = (__Z41scripting_type_get_class_or_element_classP13ScriptingType($20)|0);
 $22 = (($this) + 16|0);
 HEAP32[$22>>2] = $21;
 STACKTOP = sp;return;
}
function __ZN21LinearCollectionField8GetArrayEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 4|0);
 HEAP32[$0>>2] = -1;
 $1 = HEAP32[$this>>2]|0;
 $2 = (__Z26scripting_field_get_offsetP14ScriptingField($1)|0);
 $3 = (($this) + 4|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = (($2) + -8)|0;
 $7 = $5 ? $2 : $6;
 $8 = (($this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7)|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$agg$result>>2] = $11;
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 20|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $17 = (($9) + 12|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18;
 } else {
  $16 = (__Z22scripting_array_lengthP14ScriptingArray($11)|0);
  $19 = $16;
 }
 HEAP32[$0>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN21LinearCollectionField8SetArrayERK9ArrayInfo($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__Z26scripting_field_get_offsetP14ScriptingField($0)|0);
 $2 = (($this) + 4|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (($1) + -8)|0;
 $6 = $4 ? $1 : $5;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6)|0);
 $10 = HEAP32[$value>>2]|0;
 HEAP32[$9>>2] = $10;
 $11 = (($this) + 20|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($value) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$7>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $15;
 $18 = (($this) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__Z26scripting_field_get_offsetP14ScriptingField($19)|0);
 $21 = (($this) + 28|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)!=(0);
 $24 = (($20) + -8)|0;
 $25 = $23 ? $20 : $24;
 $26 = (($this) + 32|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + ($25)|0);
 HEAP32[$28>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN21LinearCollectionField15GetElementClassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9CoroutineC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 16|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 24|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 52|0);
 HEAP8[$4>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9Coroutine17SetMoveNextMethodE21ScriptingMethodIl2Cpp($this,$method) {
 $this = $this|0;
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 ;HEAP32[$0+0>>2]=HEAP32[$method+0>>2]|0;HEAP8[$0+4>>0]=HEAP8[$method+4>>0]|0;
 STACKTOP = sp;return;
}
function __ZN9Coroutine16SetCurrentMethodE21ScriptingMethodIl2Cpp($this,$method) {
 $this = $this|0;
 $method = $method|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 ;HEAP32[$0+0>>2]=HEAP32[$method+0>>2]|0;HEAP8[$0+4>>0]=HEAP8[$method+4>>0]|0;
 STACKTOP = sp;return;
}
function __ZN9Coroutine17ContinueCoroutineEP6ObjectPv($o,$userData) {
 $o = $o|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($userData) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($o|0);
 if ($2) {
  __ZN9Coroutine3RunEv($userData);
  STACKTOP = sp;return;
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(631424,0,631456,65,1,0,0,0);
  STACKTOP = sp;return;
 }
}
function __ZN9Coroutine3RunEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exception = 0, $invocation$i = 0, $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$i$byval_copy = sp + 216|0;
 $invocation$i = sp;
 $0 = sp + 200|0;
 $exception = sp + 208|0;
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 HEAP32[$exception>>2] = 0;
 $4 = (($this) + 24|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i,$tmpcast$i$byval_copy);
 $15 = (($this) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($invocation$i) + 12|0);
 HEAP32[$17>>2] = $16;
 $18 = (($this) + 40|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__ZNK13MonoBehaviour8GetClassEv($19)|0);
 $21 = (($invocation$i) + 20|0);
 HEAP32[$21>>2] = $20;
 $22 = HEAP32[$18>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($invocation$i) + 16|0);
 HEAP32[$25>>2] = $24;
 $26 = (__ZN19ScriptingInvocation6InvokeIbEET_PP18ScriptingException($invocation$i,$exception)|0);
 if ($26) {
  $27 = HEAP32[$exception>>2]|0;
  $28 = ($27|0)==(0|0);
  $42 = $28;
 } else {
  $42 = 0;
 }
 $29 = HEAP32[$1>>2]|0;
 $30 = ($29|0)==(1);
 $31 = (($this) + 56|0);
 __ZN9Coroutine16CleanupCoroutineEPv($this);
 if ($30) {
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$exception>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 if ($42) {
  $40 = HEAP32[$18>>2]|0;
  $41 = ($40|0)==(0|0);
  if ($41) {
   STACKTOP = sp;return;
  }
  __ZN9Coroutine23ProcessCoroutineCurrentEv($this);
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$31>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (($34) + 60|0);
 HEAP32[$36>>2] = 0;
 HEAP32[$31>>2] = 0;
 $37 = (($34) + 40|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  __ZN9Coroutine3RunEv($34);
 }
 __ZN9Coroutine16CleanupCoroutineEPv($34);
 STACKTOP = sp;return;
}
function __ZN9Coroutine16CleanupCoroutineEPv($userData) {
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($userData) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 $3 = ($2|0)>(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($userData) + 52|0);
 HEAP8[$4>>0] = 1;
 $5 = (($userData) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __ZN9Coroutine16CleanupCoroutineEPv($6);
  HEAP32[$5>>2] = 0;
 }
 $8 = (($userData) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = (($9) + 56|0);
  HEAP32[$11>>2] = 0;
 }
 $12 = HEAP32[$userData>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = (($userData) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($12) + 4|0);
  HEAP32[$16>>2] = $15;
  $17 = HEAP32[$userData>>2]|0;
  $18 = HEAP32[$14>>2]|0;
  HEAP32[$18>>2] = $17;
  HEAP32[$userData>>2] = 0;
  HEAP32[$14>>2] = 0;
 }
 $19 = (($userData) + 64|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  __ZN14AsyncOperation20SetCoroutineCallbackEPFvP6ObjectPvES1_S2_PFvS2_E($20,0,0,0,0);
  $22 = HEAP32[$19>>2]|0;
  __ZN14AsyncOperation7ReleaseEv($22);
  HEAP32[$19>>2] = 0;
 }
 $23 = (($userData) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 __Z23scripting_gchandle_freei($24);
 HEAP32[$23>>2] = 0;
 $25 = (($userData) + 48|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)!=(0);
 $28 = ($userData|0)==(0|0);
 $or$cond = $27 | $28;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 __ZdlPv($userData);
 STACKTOP = sp;return;
}
function __ZN9Coroutine18CleanupCoroutineGCEPv($userData) {
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($userData) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($userData) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$userData>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(631464,0,631456,151,1,0,0,0);
 }
 $8 = ($userData|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 __ZdlPv($userData);
 STACKTOP = sp;return;
}
function __ZN9Coroutine23ProcessCoroutineCurrentEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exception = 0, $invocation = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$byval_copy = sp + 216|0;
 $exception = sp + 208|0;
 $invocation = sp;
 $0 = sp + 200|0;
 $1 = sp + 212|0;
 HEAP32[$exception>>2] = 0;
 $2 = (($this) + 32|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($invocation) + 12|0);
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 40|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($invocation) + 16|0);
 HEAP32[$20>>2] = $19;
 $21 = (__ZNK13MonoBehaviour8GetClassEv($17)|0);
 $22 = (($invocation) + 20|0);
 HEAP32[$22>>2] = $21;
 $23 = (__ZN19ScriptingInvocation6InvokeEPP18ScriptingException($invocation,$exception)|0);
 $24 = HEAP32[$exception>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $26 = ($23|0)==(0|0);
 if (!($26)) {
  __ZN9Coroutine35HandleIEnumerableCurrentReturnValueEP15ScriptingObject($this,$23);
  STACKTOP = sp;return;
 }
 $27 = (($this) + 44|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $30 = HEAP32[$16>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  HEAP32[$1>>2] = 0;
 } else {
  $32 = (($30) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$1>>2] = $33;
 }
 __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(3209,$1,Math_fround(0.0),$this,Math_fround(0.0),3553,10);
 STACKTOP = sp;return;
}
function __ZN9Coroutine35HandleIEnumerableCurrentReturnValueEP15ScriptingObject($this,$monoWait) {
 $this = $this|0;
 $monoWait = $monoWait|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = sp + 8|0;
 $4 = sp + 12|0;
 $5 = sp + 16|0;
 $6 = (__Z26scripting_object_get_classP15ScriptingObject($monoWait)|0);
 $7 = (__Z14GetMonoManagerv()|0);
 $8 = (($7) + 216|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$9)|0);
 if ($10) {
  $11 = (($this) + 44|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$11>>2] = $13;
  $14 = (($monoWait) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($this) + 40|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   HEAP32[$0>>2] = 0;
  } else {
   $19 = (($17) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[$0>>2] = $20;
  }
  __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(3209,$0,$15,$this,Math_fround(0.0),3553,10);
  STACKTOP = sp;return;
 }
 $21 = (($7) + 220|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$22)|0);
 if ($23) {
  $24 = (($this) + 44|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 1)|0;
  HEAP32[$24>>2] = $26;
  $27 = (($this) + 40|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if ($29) {
   HEAP32[$1>>2] = 0;
  } else {
   $30 = (($28) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[$1>>2] = $31;
  }
  __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(3209,$1,Math_fround(0.0),$this,Math_fround(0.0),3553,1);
  STACKTOP = sp;return;
 }
 $32 = (($7) + 224|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$33)|0);
 if ($34) {
  $35 = (($this) + 44|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 1)|0;
  HEAP32[$35>>2] = $37;
  $38 = (($this) + 40|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  if ($40) {
   HEAP32[$2>>2] = 0;
  } else {
   $41 = (($39) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$2>>2] = $42;
  }
  __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(3209,$2,Math_fround(-1.0),$this,Math_fround(0.0),3553,32);
  STACKTOP = sp;return;
 }
 $43 = (($7) + 252|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$44)|0);
 if ($45) {
  $46 = (($monoWait) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + 52|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = ($49<<24>>24)==(0);
  if (!($50)) {
   __ZN9Coroutine3RunEv($this);
   STACKTOP = sp;return;
  }
  $51 = (($47) + 56|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   $60 = (($this) + 44|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($61) + 1)|0;
   HEAP32[$60>>2] = $62;
   HEAP32[$51>>2] = $this;
   $63 = (($this) + 60|0);
   HEAP32[$63>>2] = $47;
   STACKTOP = sp;return;
  }
  $54 = (($this) + 40|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0|0);
  if ($56) {
   $59 = 0;
  } else {
   $57 = (($55) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = $58;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(631488,0,631456,336,4,$59,0,0);
  STACKTOP = sp;return;
 }
 $64 = (($7) + 244|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if (!($66)) {
  $67 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$65)|0);
  if ($67) {
   $68 = (($monoWait) + 8|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0|0);
   if ($70) {
    STACKTOP = sp;return;
   }
   $71 = (($this) + 44|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($72) + 1)|0;
   HEAP32[$71>>2] = $73;
   $74 = (($this) + 40|0);
   $75 = HEAP32[$74>>2]|0;
   __ZN3WWW12CallWhenDoneEPFvP6ObjectPvES1_S2_PFvS2_E($69,3209,$75,$this,3553);
   STACKTOP = sp;return;
  }
 }
 $76 = (($7) + 476|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($6,$77)|0);
 $$not = $78 ^ 1;
 $79 = ($monoWait|0)==(0|0);
 $or$cond = $79 | $$not;
 if (!($or$cond)) {
  $80 = (($monoWait) + 8|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)==(0|0);
  if (!($82)) {
   $83 = (($this) + 44|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($84) + 1)|0;
   HEAP32[$83>>2] = $85;
   $86 = HEAP32[$81>>2]|0;
   $87 = (($86) + 8|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (FUNCTION_TABLE_ii[$88 & 4095]($81)|0);
   if ($89) {
    $90 = (($this) + 40|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($91|0)==(0|0);
    if ($92) {
     HEAP32[$3>>2] = 0;
    } else {
     $93 = (($91) + 4|0);
     $94 = HEAP32[$93>>2]|0;
     HEAP32[$3>>2] = $94;
    }
    __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(3209,$3,Math_fround(0.0),$this,Math_fround(0.0),3553,10);
    STACKTOP = sp;return;
   }
   $95 = (($81) + 8|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0|0);
   if ($97) {
    $103 = (($this) + 40|0);
    $104 = HEAP32[$103>>2]|0;
    __ZN14AsyncOperation20SetCoroutineCallbackEPFvP6ObjectPvES1_S2_PFvS2_E($81,3209,$104,$this,3553);
    $105 = (($this) + 64|0);
    HEAP32[$105>>2] = $81;
    __ZN14AsyncOperation6RetainEv($81);
    STACKTOP = sp;return;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(631608,0,631456,376,1,0,0,0);
   $98 = (($this) + 40|0);
   $99 = HEAP32[$98>>2]|0;
   $100 = ($99|0)==(0|0);
   if ($100) {
    HEAP32[$4>>2] = 0;
   } else {
    $101 = (($99) + 4|0);
    $102 = HEAP32[$101>>2]|0;
    HEAP32[$4>>2] = $102;
   }
   __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(3209,$4,Math_fround(0.0),$this,Math_fround(0.0),3553,10);
   STACKTOP = sp;return;
  }
 }
 $106 = (($this) + 44|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($107) + 1)|0;
 HEAP32[$106>>2] = $108;
 $109 = (($this) + 40|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = ($110|0)==(0|0);
 if ($111) {
  HEAP32[$5>>2] = 0;
 } else {
  $112 = (($110) + 4|0);
  $113 = HEAP32[$112>>2]|0;
  HEAP32[$5>>2] = $113;
 }
 __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(3209,$5,Math_fround(0.0),$this,Math_fround(0.0),3553,10);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour18TransferEngineDataI13ProxyTransferEE4PPtrI10MonoScriptERT_($agg$result,$this,$transfer) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, $p$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i = sp;
 $p$i$i$i = sp + 16|0;
 __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631744,631824,$agg$result,0);
 $2 = (($localIdentifier$i$i$i) + 8|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $7 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631784,$7,$agg$result,1);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($10) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631800,$14,$2,1);
 $15 = HEAP32[$8>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$11>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 36|0);
 $20 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631760,$20,$19,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,631816,631816,$localIdentifier$i$i$i,1);
 $21 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631776,$21,$p$i$i$i,0);
 $22 = HEAP32[$8>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$11>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $newScript = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newScript = sp;
 (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,631768,631848,0,1)|0);
 __ZN13MonoBehaviour18TransferEngineDataI14SafeBinaryReadEE4PPtrI10MonoScriptERT_($newScript,$this,$transfer);
 __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($this,$newScript,0);
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
  STACKTOP = sp;return;
 }
 $3 = (__ZNK13MonoBehaviour8GetClassEv($this)|0);
 $4 = (__Z24scripting_class_get_nameP14ScriptingClass($3)|0);
 __ZN14SafeBinaryRead20OverrideRootTypeNameEPKc($transfer,$4);
 $5 = HEAP32[$0>>2]|0;
 $6 = (__ZNK13MonoBehaviour8GetClassEv($this)|0);
 $7 = (($this) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 __Z23TransferScriptingObjectI14SafeBinaryReadEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$5,$6,$8);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour18TransferEngineDataI14SafeBinaryReadEE4PPtrI10MonoScriptERT_($agg$result,$this,$transfer) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,631744,631824,$converter$i$i1,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN4PPtrI10MonoScriptE8TransferI14SafeBinaryReadEEvRT_($agg$result,$transfer);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($agg$result,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 36|0);
 $8 = HEAP32[580712>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,631760,$8,$converter$i$i1,0)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 if ($11) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$7,0);
 } else {
  $12 = HEAP32[$converter$i$i1>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   (FUNCTION_TABLE_iii[$12 & 4095]($7,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MonoBehaviour25TransferEngineAndInstanceI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour25TransferEngineAndInstanceI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $newScript = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newScript = sp;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$newScript>>2] = $1;
 __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb1EEEEvRT_($newScript,$transfer);
 $2 = (($this) + 36|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$2,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($this,$newScript,0);
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (__ZNK13MonoBehaviour8GetClassEv($this)|0);
 $7 = (($this) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 __Z23TransferScriptingObjectI18StreamedBinaryReadILb1EEEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$4,$6,$8);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MonoBehaviour25TransferEngineAndInstanceI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour25TransferEngineAndInstanceI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $newScript = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newScript = sp;
 __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$newScript>>2] = $1;
 __ZN4PPtrI10MonoScriptE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($newScript,$transfer);
 $2 = (($this) + 36|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$2,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (__ZNK13MonoBehaviour8GetClassEv($this)|0);
 $7 = (($this) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 __Z23TransferScriptingObjectI19StreamedBinaryWriteILb0EEEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$4,$6,$8);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MonoBehaviour25TransferEngineAndInstanceI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour25TransferEngineAndInstanceI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $newScript = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newScript = sp;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$newScript>>2] = $1;
 __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb0EEEEvRT_($newScript,$transfer);
 $2 = (($this) + 36|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$2,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($this,$newScript,0);
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (__ZNK13MonoBehaviour8GetClassEv($this)|0);
 $7 = (($this) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 __Z23TransferScriptingObjectI18StreamedBinaryReadILb0EEEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$4,$6,$8);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $newScript$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newScript$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,631768,631848,0,0);
 __ZN13MonoBehaviour18TransferEngineDataI13ProxyTransferEE4PPtrI10MonoScriptERT_($newScript$i,$this,$transfer);
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  STACKTOP = sp;return;
 }
 $3 = (__ZNK13MonoBehaviour8GetClassEv($this)|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 __Z23TransferScriptingObjectI13ProxyTransferEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$1,$3,$5);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newScript$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newScript$i = sp;
 __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$newScript$i>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$newScript$i>>2] = $8;
  __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($this,$newScript$i,0);
 }
 $12 = (($this) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (__ZNK13MonoBehaviour8GetClassEv($this)|0);
 $16 = (($this) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 __Z23TransferScriptingObjectI17RemapPPtrTransferEvRT_P15ScriptingObjectP14ScriptingClassPK15MonoScriptCache($transfer,$13,$15,$17);
 STACKTOP = sp;return;
}
function __Z24TransferPPtrToMonoObjectiP14ScriptingClassP23DataToCreateNullWrapper24TransferInstructionFlags($instanceID,$klass,$_,$loadingFlags) {
 $instanceID = $instanceID|0;
 $klass = $klass|0;
 $_ = $_|0;
 $loadingFlags = $loadingFlags|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z33TransferPPtrToMonoObjectUnCheckedi24TransferInstructionFlags($instanceID,$loadingFlags)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z33TransferPPtrToMonoObjectUnCheckedi24TransferInstructionFlags($instanceID,$loadingFlags) {
 $instanceID = $instanceID|0;
 $loadingFlags = $loadingFlags|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($loadingFlags|0)==(0);
 do {
  if ($0) {
   $1 = (__ZN9Scripting32GetScriptingWrapperForInstanceIDEi($instanceID)|0);
   $$0 = $1;
  } else {
   $2 = ($instanceID|0)==(0);
   if ($2) {
    $$0 = 0;
   } else {
    $3 = (__ZN6Object24IDToPointerNoThreadCheckEi($instanceID)|0);
    $4 = ($3|0)==(0|0);
    if (!($4)) {
     $5 = (__ZN9Scripting19ScriptingWrapperForEP6Object($3)|0);
     $$0 = $5;
     break;
    }
    $6 = (__Z20GetPersistentManagerv()|0);
    $7 = (__ZN17PersistentManager25PreallocateObjectThreadedEi($6,$instanceID)|0);
    $8 = ($7|0)==(0|0);
    if ($8) {
     $$0 = 0;
    } else {
     $9 = (__ZN9Scripting19ScriptingWrapperForEP6Object($7)|0);
     $$0 = $9;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z27RegisterClass_MonoBehaviourv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(114,176,177,0,178);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 13;
 dest=$3+0|0; src=631864+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 13|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,114,8,($0|0),136,(2434|0),0,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN13MonoBehaviour15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject26RegisterAllMessagesHandlerEiPFvPviR11MessageDataEPFbS1_iS3_E(114,1909,1556);
 __Z27RegisterAllowNameConversionPKcS0_S0_(632472,632480,632496);
 __Z27RegisterAllowNameConversionPKcS0_S0_(631864,632512,632536);
 __Z48InitializeMonoBehaviourAnimationBindingInterfacev();
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z45CleanupMonoBehaviourAnimationBindingInterfacev();
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy2,1,16,632120,57)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = (($3) + 28|0);
  HEAP8[$6>>0] = 1;
  $7 = (($3) + 29|0);
  HEAP8[$7>>0] = 0;
  HEAP32[$3>>2] = ((631880 + 8|0));
  $8 = (($3) + 32|0);
  $9 = (($3) + 56|0);
  $10 = (($3) + 60|0);
  ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
  HEAP32[$9>>2] = $9;
  HEAP32[$10>>2] = $9;
  $11 = (($3) + 64|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 68|0);
  HEAP32[$12>>2] = 0;
  $13 = (($3) + 72|0);
  HEAP32[$13>>2] = $3;
  $14 = (($3) + 76|0);
  HEAP32[$14>>2] = 0;
  $15 = (($3) + 80|0);
  HEAP32[$15>>2] = 0;
  $16 = (($3) + 84|0);
  HEAP32[$16>>2] = $3;
  $17 = (($3) + 88|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 92|0);
  HEAP32[$18>>2] = 0;
  $19 = (($3) + 96|0);
  HEAP32[$19>>2] = $3;
  $20 = (($3) + 100|0);
  HEAP32[$20>>2] = 0;
  $21 = (($3) + 104|0);
  HEAP32[$21>>2] = 0;
  $22 = (($3) + 108|0);
  HEAP32[$22>>2] = $3;
  $23 = (($3) + 112|0);
  HEAP32[$23>>2] = 0;
  $24 = (($3) + 116|0);
  HEAP32[$24>>2] = 0;
  $25 = (($3) + 120|0);
  HEAP32[$25>>2] = $3;
  $26 = (($3) + 52|0);
  HEAP32[$26>>2] = 0;
  $27 = (($3) + 48|0);
  HEAP32[$27>>2] = 0;
  $28 = (($3) + 131|0);
  HEAP8[$28>>0] = 0;
  $29 = (($3) + 129|0);
  HEAP8[$29>>0] = 0;
  $30 = (($3) + 128|0);
  HEAP8[$30>>0] = 0;
  $31 = (($3) + 130|0);
  HEAP8[$31>>0] = 1;
  $32 = (($3) + 124|0);
  HEAP32[$32>>2] = 0;
  $33 = (($3) + 132|0);
  HEAP32[$33>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(632120|0),57);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch(0|0)|0;
  $39 = tempRet0;
  ___clang_call_terminate($38);
  // unreachable;
 } else {
  ___resumeException($34|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK13MonoBehaviour25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 114;
}
function __ZN13MonoBehaviourC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 $2 = (($this) + 28|0);
 HEAP8[$2>>0] = 1;
 $3 = (($this) + 29|0);
 HEAP8[$3>>0] = 0;
 HEAP32[$this>>2] = ((631880 + 8|0));
 $4 = (($this) + 32|0);
 $5 = (($this) + 56|0);
 $6 = (($this) + 60|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 HEAP32[$5>>2] = $5;
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 64|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 68|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 72|0);
 HEAP32[$9>>2] = $this;
 $10 = (($this) + 76|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 80|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 84|0);
 HEAP32[$12>>2] = $this;
 $13 = (($this) + 88|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 92|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 96|0);
 HEAP32[$15>>2] = $this;
 $16 = (($this) + 100|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 104|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 108|0);
 HEAP32[$18>>2] = $this;
 $19 = (($this) + 112|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 116|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 120|0);
 HEAP32[$21>>2] = $this;
 $22 = (($this) + 52|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 48|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 131|0);
 HEAP8[$24>>0] = 0;
 $25 = (($this) + 129|0);
 HEAP8[$25>>0] = 0;
 $26 = (($this) + 128|0);
 HEAP8[$26>>0] = 0;
 $27 = (($this) + 130|0);
 HEAP8[$27>>0] = 1;
 $28 = (($this) + 124|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 132|0);
 HEAP32[$29>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 68|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (($this) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = (($this) + 80|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($9) + 4|0);
  HEAP32[$13>>2] = $12;
  $14 = HEAP32[$8>>2]|0;
  $15 = HEAP32[$11>>2]|0;
  HEAP32[$15>>2] = $14;
  HEAP32[$8>>2] = 0;
  HEAP32[$11>>2] = 0;
 }
 $16 = (($this) + 88|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (($this) + 92|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($17) + 4|0);
  HEAP32[$21>>2] = $20;
  $22 = HEAP32[$16>>2]|0;
  $23 = HEAP32[$19>>2]|0;
  HEAP32[$23>>2] = $22;
  HEAP32[$16>>2] = 0;
  HEAP32[$19>>2] = 0;
 }
 $24 = (($this) + 100|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (($this) + 104|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($25) + 4|0);
  HEAP32[$29>>2] = $28;
  $30 = HEAP32[$24>>2]|0;
  $31 = HEAP32[$27>>2]|0;
  HEAP32[$31>>2] = $30;
  HEAP32[$24>>2] = 0;
  HEAP32[$27>>2] = 0;
 }
 $32 = (($this) + 112|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = (($this) + 116|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($33) + 4|0);
  HEAP32[$37>>2] = $36;
  $38 = HEAP32[$32>>2]|0;
  $39 = HEAP32[$35>>2]|0;
  HEAP32[$39>>2] = $38;
  HEAP32[$32>>2] = 0;
  HEAP32[$35>>2] = 0;
 }
 $40 = (__Z9GetIAudiov()|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 48|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 132|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$43 & 4095]($40,$45);
 $46 = (($this) + 48|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZNK15MonoScriptCache7ReleaseEv($47);
 HEAP32[$46>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour17GetObjectGUIStateEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__Znwj(44)|0);
 __THREW__ = 0;
 invoke_vi(3554,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZdlPv($3);
  ___resumeException($6|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $3;
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MonoBehaviour26WillUnloadScriptableObjectEv($this) {
 $this = $this|0;
 var $$0 = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $invocation$i10 = 0, $or$cond = 0, $phitmp$i = 0, $temp$0$i = 0, $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$i$byval_copy = sp + 216|0;
 $invocation$i10 = sp;
 $0 = sp + 200|0;
 $1 = sp + 208|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $3;
 $5 = HEAP32[560624>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 10;
 } else {
  $7 = (($5) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  do {
   if ($11) {
    $12 = (($5) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($5) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + ($15<<3)|0);
    $32 = $16;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast$i$byval_copy,$5,$1);
    $17 = HEAP32[$tmpcast$i$byval_copy>>2]|0;
    $18 = ($17|0)==(-1);
    $19 = (($5) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    if ($18) {
     $21 = (($5) + 32|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + ($22<<3)|0);
     $32 = $23;
     break;
    } else {
     $24 = (($20) + ($17<<3)|0);
     $32 = $24;
     break;
    }
   }
  } while(0);
  $25 = HEAP32[560624>>2]|0;
  $26 = (($25) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 32|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + ($29<<3)|0);
  $31 = ($32|0)==($30|0);
  if ($31) {
   label = 10;
  } else {
   $33 = (($32) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    label = 10;
   } else {
    $temp$0$i = $34;
   }
  }
 }
 if ((label|0) == 10) {
  $36 = HEAP32[$2>>2]|0;
  $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
  $temp$0$i = $37;
 }
 $38 = (($this) + 20|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 $41 = ($temp$0$i|0)==(0|0);
 $or$cond = $40 | $41;
 if ($or$cond) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = (($this) + 48|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 do {
  if (!($44)) {
   $45 = (($43) + 32|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = ($46<<24>>24)==(0);
   if ($47) {
    $51 = (($43) + 24|0);
    $52 = HEAP32[$51>>2]|0;
    $$off$i$i = (($52) + -1)|0;
    $53 = ($$off$i$i>>>0)<(2);
    if (!($53)) {
     break;
    }
   } else {
    $48 = (($43) + 33|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = ($49<<24>>24)==(0);
    if ($50) {
     $54 = (($this) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = $55 & 1048576;
     $phitmp$i = ($56|0)==(0);
     if (!($phitmp$i)) {
      break;
     }
    }
   }
   $57 = (($this) + 52|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($58) + 64|0);
   $60 = $59;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = (($60) + 4)|0;
   $64 = $63;
   $65 = HEAP32[$64>>2]|0;
   $66 = ($62|0)==(0);
   if (!($66)) {
    $67 = $0;
    $68 = $67;
    HEAP32[$68>>2] = $62;
    $69 = (($67) + 4)|0;
    $70 = $69;
    HEAP32[$70>>2] = $65;
    ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
    __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i10,$tmpcast$i$byval_copy);
    $71 = (($invocation$i10) + 12|0);
    HEAP32[$71>>2] = $39;
    $72 = (($invocation$i10) + 25|0);
    HEAP8[$72>>0] = 1;
    $73 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($39)|0);
    $74 = (($invocation$i10) + 16|0);
    HEAP32[$74>>2] = $73;
    __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i10);
    (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i10)|0);
   }
   $75 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($39)|0);
   $76 = ($75|0)==(0|0);
   if (!($76)) {
    $77 = HEAP32[$57>>2]|0;
    $78 = (($77) + 72|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($79|0)==(0|0);
    if (!($80)) {
     $81 = (($77) + 76|0);
     $82 = HEAP8[$81>>0]|0;
     $83 = $65 & -256;
     $84 = $82&255;
     $85 = $84 | $83;
     $86 = $79;
     $87 = HEAP32[$38>>2]|0;
     $88 = $0;
     $89 = $88;
     HEAP32[$89>>2] = $86;
     $90 = (($88) + 4)|0;
     $91 = $90;
     HEAP32[$91>>2] = $85;
     ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i10,$tmpcast$i$byval_copy);
     $92 = (($invocation$i10) + 12|0);
     HEAP32[$92>>2] = $87;
     $93 = (($invocation$i10) + 25|0);
     HEAP8[$93>>0] = 1;
     $94 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($87)|0);
     $95 = (($invocation$i10) + 16|0);
     HEAP32[$95>>2] = $94;
     __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i10);
     (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i10)|0);
    }
   }
  }
 } while(0);
 $96 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($39)|0);
 $97 = ($96|0)!=(0|0);
 $$0 = $97;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MonoBehaviour20WillDestroyComponentEv($this) {
 $this = $this|0;
 var $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $invocation$i18 = 0, $tmpcast$i$byval_copy = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$i$byval_copy = sp + 208|0;
 $invocation$i18 = sp;
 $0 = sp + 200|0;
 $1 = (($this) + 131|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(632024,0,632120,248,1,0,0,0);
  STACKTOP = sp;return;
 }
 HEAP8[$1>>0] = 1;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 128|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $64 = 0;
 } else {
  $13 = (($11) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $$off$i = (($14) + -1)|0;
  $15 = ($$off$i>>>0)<(2);
  if ($15) {
   $16 = (($this) + 52|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 64|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + 68|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21&255;
   $23 = ($19|0)==(0|0);
   if (!($23)) {
    $24 = $19;
    $25 = $21&255;
    $26 = $0;
    $27 = $26;
    HEAP32[$27>>2] = $24;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = $25;
    ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
    __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i18,$tmpcast$i$byval_copy);
    $30 = (($invocation$i18) + 12|0);
    HEAP32[$30>>2] = $5;
    $31 = (($invocation$i18) + 25|0);
    HEAP8[$31>>0] = 1;
    $32 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($5)|0);
    $33 = (($invocation$i18) + 16|0);
    HEAP32[$33>>2] = $32;
    __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i18);
    (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i18)|0);
   }
   $34 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($5)|0);
   $35 = ($34|0)==(0|0);
   if ($35) {
    $64 = $22;
   } else {
    $36 = HEAP32[$16>>2]|0;
    $37 = (($36) + 72|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 76|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = $40&255;
    $42 = ($38|0)==(0|0);
    if ($42) {
     $64 = $41;
    } else {
     $43 = $38;
     $44 = $40&255;
     $45 = HEAP32[$4>>2]|0;
     $46 = $0;
     $47 = $46;
     HEAP32[$47>>2] = $43;
     $48 = (($46) + 4)|0;
     $49 = $48;
     HEAP32[$49>>2] = $44;
     ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i18,$tmpcast$i$byval_copy);
     $50 = (($invocation$i18) + 12|0);
     HEAP32[$50>>2] = $45;
     $51 = (($invocation$i18) + 25|0);
     HEAP8[$51>>0] = 1;
     $52 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($45)|0);
     $53 = (($invocation$i18) + 16|0);
     HEAP32[$53>>2] = $52;
     __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i18);
     (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i18)|0);
     $64 = $41;
    }
   }
  } else {
   $64 = 0;
  }
 }
 $54 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($5)|0);
 $55 = ($54|0)==(0|0);
 if ($55) {
  STACKTOP = sp;return;
 }
 $56 = (($this) + 52|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 128|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0|0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $61 = (($57) + 132|0);
 $62 = HEAP8[$61>>0]|0;
 $63 = $64 & -256;
 $65 = $62&255;
 $66 = $65 | $63;
 $67 = $59;
 $68 = HEAP32[$4>>2]|0;
 $69 = $0;
 $70 = $69;
 HEAP32[$70>>2] = $67;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $66;
 ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i18,$tmpcast$i$byval_copy);
 $73 = (($invocation$i18) + 12|0);
 HEAP32[$73>>2] = $68;
 $74 = (($invocation$i18) + 25|0);
 HEAP8[$74>>0] = 1;
 $75 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($68)|0);
 $76 = (($invocation$i18) + 16|0);
 HEAP32[$76>>2] = $75;
 __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i18);
 (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i18)|0);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $filter = 0, $invocation$i22 = 0, $phitmp$i = 0;
 var $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $tmpcast$i$byval_copy = sp + 224|0;
 $invocation$i22 = sp;
 $0 = sp + 200|0;
 $filter = sp + 208|0;
 $1 = sp + 220|0;
 $2 = (($this) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($this) + 68|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  HEAP32[$7>>2] = $6;
  $8 = HEAP32[$2>>2]|0;
  $9 = HEAP32[$5>>2]|0;
  HEAP32[$9>>2] = $8;
  HEAP32[$2>>2] = 0;
  HEAP32[$5>>2] = 0;
 }
 $10 = (($this) + 76|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = (($this) + 80|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($11) + 4|0);
  HEAP32[$15>>2] = $14;
  $16 = HEAP32[$10>>2]|0;
  $17 = HEAP32[$13>>2]|0;
  HEAP32[$17>>2] = $16;
  HEAP32[$10>>2] = 0;
  HEAP32[$13>>2] = 0;
 }
 $18 = (($this) + 88|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = (($this) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($19) + 4|0);
  HEAP32[$23>>2] = $22;
  $24 = HEAP32[$18>>2]|0;
  $25 = HEAP32[$21>>2]|0;
  HEAP32[$25>>2] = $24;
  HEAP32[$18>>2] = 0;
  HEAP32[$21>>2] = 0;
 }
 $26 = (($this) + 100|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = (($this) + 104|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($27) + 4|0);
  HEAP32[$31>>2] = $30;
  $32 = HEAP32[$26>>2]|0;
  $33 = HEAP32[$29>>2]|0;
  HEAP32[$33>>2] = $32;
  HEAP32[$26>>2] = 0;
  HEAP32[$29>>2] = 0;
 }
 $34 = (($this) + 112|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 if (!($36)) {
  $37 = (($this) + 116|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($35) + 4|0);
  HEAP32[$39>>2] = $38;
  $40 = HEAP32[$34>>2]|0;
  $41 = HEAP32[$37>>2]|0;
  HEAP32[$41>>2] = $40;
  HEAP32[$34>>2] = 0;
  HEAP32[$37>>2] = 0;
 }
 $42 = (($this) + 20|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = (($this) + 52|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + 96|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==(0|0);
  if (!($49)) {
   $50 = (($this) + 24|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($51,20)|0);
   $53 = ($52|0)==(0|0);
   if (!($53)) {
    HEAP32[$filter>>2] = $this;
    $54 = (($filter) + 4|0);
    HEAP32[$54>>2] = 1910;
    $55 = (($filter) + 8|0);
    HEAP8[$55>>0] = 0;
    $56 = (($filter) + 9|0);
    HEAP8[$56>>0] = 0;
    __ZN6Camera17RemoveImageFilterERK11ImageFilter($52,$filter);
   }
  }
 }
 $57 = (($this) + 48|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0|0);
 if (!($59)) {
  $60 = (($58) + 32|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if (!($62)) {
   $63 = (($58) + 33|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    $66 = (($this) + 8|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = $67 & 1048576;
    $phitmp$i = ($68|0)==(0);
    if (!($phitmp$i)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $69 = HEAP32[$42>>2]|0;
 $70 = ($69|0)==(0|0);
 if ($70) {
  STACKTOP = sp;return;
 }
 $71 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($69)|0);
 $72 = ($71|0)==(0|0);
 if (!($72)) {
  $73 = (($this) + 52|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($74) + 64|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0|0);
  if (!($77)) {
   $78 = (($this) + 128|0);
   $79 = HEAP8[$78>>0]|0;
   $80 = ($79<<24>>24)==(0);
   if (!($80)) {
    $81 = $75;
    $82 = $81;
    $83 = HEAP32[$82>>2]|0;
    $84 = (($81) + 4)|0;
    $85 = $84;
    $86 = HEAP32[$85>>2]|0;
    $87 = HEAP32[$42>>2]|0;
    $88 = $0;
    $89 = $88;
    HEAP32[$89>>2] = $83;
    $90 = (($88) + 4)|0;
    $91 = $90;
    HEAP32[$91>>2] = $86;
    ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
    __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i22,$tmpcast$i$byval_copy);
    $92 = (($invocation$i22) + 12|0);
    HEAP32[$92>>2] = $87;
    $93 = (($invocation$i22) + 25|0);
    HEAP8[$93>>0] = 1;
    $94 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($87)|0);
    $95 = (($invocation$i22) + 16|0);
    HEAP32[$95>>2] = $94;
    __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i22);
    (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i22)|0);
   }
  }
 }
 $96 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($69)|0);
 $97 = ($96|0)==(0|0);
 if (!($97)) {
  $98 = (($this) + 52|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = (($99) + 72|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = ($101|0)==(0|0);
  if (!($102)) {
   $103 = (($this) + 128|0);
   $104 = HEAP8[$103>>0]|0;
   $105 = ($104<<24>>24)==(0);
   if (!($105)) {
    $106 = $100;
    $107 = $106;
    $108 = HEAP32[$107>>2]|0;
    $109 = (($106) + 4)|0;
    $110 = $109;
    $111 = HEAP32[$110>>2]|0;
    $112 = HEAP32[$42>>2]|0;
    $113 = $0;
    $114 = $113;
    HEAP32[$114>>2] = $108;
    $115 = (($113) + 4)|0;
    $116 = $115;
    HEAP32[$116>>2] = $111;
    ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
    __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i22,$tmpcast$i$byval_copy);
    $117 = (($invocation$i22) + 12|0);
    HEAP32[$117>>2] = $112;
    $118 = (($invocation$i22) + 25|0);
    HEAP8[$118>>0] = 1;
    $119 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($112)|0);
    $120 = (($invocation$i22) + 16|0);
    HEAP32[$120>>2] = $119;
    __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i22);
    (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i22)|0);
   }
  }
 }
 $121 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($69)|0);
 $122 = ($121|0)==(0|0);
 do {
  if (!($122)) {
   $123 = (($this) + 52|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = (($124) + 80|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($126|0)==(0|0);
   if ($127) {
    $128 = (($124) + 88|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = ($129|0)==(0|0);
    if ($130) {
     break;
    }
   }
   $131 = (__Z21GetDelayedCallManagerv()|0);
   $132 = ($this|0)==(0|0);
   if ($132) {
    HEAP32[$1>>2] = 0;
   } else {
    $133 = (($this) + 4|0);
    $134 = HEAP32[$133>>2]|0;
    HEAP32[$1>>2] = $134;
   }
   __ZN18DelayedCallManager17CancelCallDelayedE4PPtrI6ObjectEPFvPS1_PvEPFbS4_S4_ES4_($131,$1,3210,0,0);
  }
 } while(0);
 $135 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($69)|0);
 $136 = ($135|0)==(0|0);
 if ($136) {
  STACKTOP = sp;return;
 }
 __ZN13MonoBehaviour14SetByPassOnDSPEb($this,1);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour17RenderImageFilterEPN5Unity9ComponentEP13RenderTextureS4_($component,$source,$destination) {
 $component = $component|0;
 $source = $source|0;
 $destination = $destination|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phi3Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast1$byval_copy = sp + 216|0;
 $0 = sp;
 $1 = sp + 200|0;
 $2 = sp + 208|0;
 $3 = (($component) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($4) + 32|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   $9 = (($4) + 33|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)==(0);
   if ($11) {
    $12 = (($component) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = $13 & 1048576;
    $phitmp$i = ($14|0)==(0);
    if (!($phitmp$i)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = (($component) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = (($component) + 129|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  HEAP8[$18>>0] = 1;
  $21 = (($component) + 52|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 88|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $35 = $22;
  } else {
   $26 = (($22) + 92|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $24;
   $29 = $27&255;
   $30 = $0;
   $31 = $30;
   HEAP32[$31>>2] = $28;
   $32 = (($30) + 4)|0;
   $33 = $32;
   HEAP32[$33>>2] = $29;
   ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($component,$tmpcast1$byval_copy,0)|0);
   $$pre$i = HEAP32[$21>>2]|0;
   $35 = $$pre$i;
  }
  $34 = (($35) + 80|0);
  $36 = HEAP32[$34>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   $$pre$phi3Z2D = $21;
  } else {
   $38 = (($35) + 84|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = $36;
   $41 = $39&255;
   $42 = $1;
   $43 = $42;
   HEAP32[$43>>2] = $40;
   $44 = (($42) + 4)|0;
   $45 = $44;
   HEAP32[$45>>2] = $41;
   ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
   (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($component,$tmpcast1$byval_copy,0)|0);
   $$pre$phi3Z2D = $21;
  }
 } else {
  $$pre = (($component) + 52|0);
  $$pre$phi3Z2D = $$pre;
 }
 $46 = HEAP32[$$pre$phi3Z2D>>2]|0;
 $47 = (($46) + 96|0);
 $48 = $47;
 $49 = $48;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($48) + 4)|0;
 $52 = $51;
 $53 = HEAP32[$52>>2]|0;
 $54 = ($50|0)==(0);
 if ($54) {
  STACKTOP = sp;return;
 }
 $55 = HEAP32[$15>>2]|0;
 $56 = $2;
 $57 = $56;
 HEAP32[$57>>2] = $50;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = $53;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($0,$tmpcast1$byval_copy);
 $60 = (($0) + 12|0);
 HEAP32[$60>>2] = $55;
 $61 = (__ZN9Scripting19ScriptingWrapperForEP6Object($source)|0);
 $62 = (($0) + 32|0);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($62,$61);
 $63 = (__ZN9Scripting19ScriptingWrapperForEP6Object($destination)|0);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($62,$63);
 $64 = (($component) + 4|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($0) + 16|0);
 HEAP32[$66>>2] = $65;
 (__ZN19ScriptingInvocation6InvokeEv($0)|0);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour16DelayedStartCallEP6ObjectPv($o,$userData) {
 $o = $o|0;
 $userData = $userData|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast2$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast2$i$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($o) + 129|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP8[$2>>0] = 1;
 $5 = (($o) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 88|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $19 = $6;
 } else {
  $10 = (($6) + 92|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $8;
  $13 = $11&255;
  $14 = $0;
  $15 = $14;
  HEAP32[$15>>2] = $12;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  ;HEAP32[$tmpcast2$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast2$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($o,$tmpcast2$i$byval_copy,0)|0);
  $$pre$i = HEAP32[$5>>2]|0;
  $19 = $$pre$i;
 }
 $18 = (($19) + 80|0);
 $20 = HEAP32[$18>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($19) + 84|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $20;
 $25 = $23&255;
 $26 = $1;
 $27 = $26;
 HEAP32[$27>>2] = $24;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 ;HEAP32[$tmpcast2$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($o,$tmpcast2$i$byval_copy,0)|0);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour14SetByPassOnDSPEb($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z9GetIAudiov()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (__Z9GetIAudiov()|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 132|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $7 = (($this) + 52|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    STACKTOP = sp;return;
   }
   $10 = (($8) + 136|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    STACKTOP = sp;return;
   }
   $13 = (($this) + 24|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    STACKTOP = sp;return;
   }
   $16 = (__ZNK5Unity10GameObject8IsActiveEv($14)|0);
   if ($16) {
    $17 = HEAP32[$2>>2]|0;
    $18 = (($17) + 44|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_iii[$19 & 4095]($2,$this)|0);
    HEAP32[$4>>2] = $20;
    $24 = $20;
    break;
   } else {
    STACKTOP = sp;return;
   }
  } else {
   $24 = $5;
  }
 } while(0);
 $21 = HEAP32[$2>>2]|0;
 $22 = (($21) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $25 = (FUNCTION_TABLE_iii[$23 & 4095]($2,$24)|0);
 $26 = ($25|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$0>>2]|0;
 $28 = (($27) + 56|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_viii[$29 & 4095]($0,$25,$state);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour18CallMethodInactiveEPKc($this,$methodName) {
 $this = $this|0;
 $methodName = $methodName|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $invocation$i = 0, $method = 0, $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$i$byval_copy = sp + 216|0;
 $invocation$i = sp;
 $0 = sp + 200|0;
 $method = sp + 208|0;
 $1 = (($this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0$i = 0;
 } else {
  $4 = (($2) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $$0$i = $5;
 }
 __ZN9Scripting26GetMethodWithSearchOptionsEP14ScriptingClassPKci($method,$$0$i,$methodName,4);
 $6 = HEAP32[$method>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = $method;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $0;
 $17 = $16;
 HEAP32[$17>>2] = $10;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $13;
 ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i,$tmpcast$i$byval_copy);
 $20 = (($invocation$i) + 12|0);
 HEAP32[$20>>2] = $15;
 $21 = (($invocation$i) + 25|0);
 HEAP8[$21>>0] = 1;
 $22 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($15)|0);
 $23 = (($invocation$i) + 16|0);
 HEAP32[$23>>2] = $22;
 __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i);
 (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK13MonoBehaviour8GetClassEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (($1) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $$0 = $4;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MonoBehaviour5DoGUIENS_13GUILayoutTypeEi($this,$layoutType,$skin) {
 $this = $this|0;
 $layoutType = $layoutType|0;
 $skin = $skin|0;
 var $$0 = 0, $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $exception = 0, $tmpcast2$i$byval_copy = 0, $userOnGUIInvocation = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 448|0;
 $tmpcast2$i$byval_copy = sp + 208|0;
 $0 = sp;
 $1 = sp + 200|0;
 $exception = sp + 440|0;
 $userOnGUIInvocation = sp + 408|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 112|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $10;
 $15 = ($10|0)==(0);
 if ($15) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = (($this) + 129|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  HEAP8[$16>>0] = 1;
  $19 = (($6) + 88|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if ($21) {
   $31 = $6;
  } else {
   $22 = (($6) + 92|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = $20;
   $25 = $23&255;
   $26 = $0;
   $27 = $26;
   HEAP32[$27>>2] = $24;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   ;HEAP32[$tmpcast2$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast2$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($this,$tmpcast2$i$byval_copy,0)|0);
   $$pre$i = HEAP32[$5>>2]|0;
   $31 = $$pre$i;
  }
  $30 = (($31) + 80|0);
  $32 = HEAP32[$30>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $34 = (($31) + 84|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $32;
   $37 = $35&255;
   $38 = $1;
   $39 = $38;
   HEAP32[$39>>2] = $36;
   $40 = (($38) + 4)|0;
   $41 = $40;
   HEAP32[$41>>2] = $37;
   ;HEAP32[$tmpcast2$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
   (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($this,$tmpcast2$i$byval_copy,0)|0);
  }
 }
 $42 = HEAP32[$2>>2]|0;
 $43 = (($this) + 4|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (__Z11GetGUIStatev()|0);
 $46 = (($45) + 96|0);
 $47 = (($45) + 280|0);
 $48 = HEAP32[$47>>2]|0;
 __ZN12GUIClipState10BeginOnGUIER10InputEvent($46,$48);
 $49 = (($this) + 124|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 do {
  if ($51) {
   $52 = (__Znwj(44)|0);
   __THREW__ = 0;
   invoke_vi(3554,($52|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    __ZdlPv($52);
    ___resumeException($55|0);
    // unreachable;
   } else {
    HEAP32[$49>>2] = $52;
    $$0$i = $52;
    break;
   }
  } else {
   $$0$i = $50;
  }
 } while(0);
 __ZN8GUIState10BeginOnGUIER14ObjectGUIState($45,$$0$i);
 __ZN19ScriptingInvocationC2Ev($tmpcast2$i$byval_copy);
 $57 = (($tmpcast2$i$byval_copy) + 32|0);
 __ZN18ScriptingArguments6AddIntEi($57,$skin);
 __ZN18ScriptingArguments6AddIntEi($57,$44);
 __ZN18ScriptingArguments6AddIntEi($57,$layoutType);
 $58 = (($tmpcast2$i$byval_copy) + 4|0);
 $59 = (__Z19GetScriptingManagerv()|0);
 $60 = (($59) + 424|0);
 ;HEAP32[$58+0>>2]=HEAP32[$60+0>>2]|0;HEAP8[$58+4>>0]=HEAP8[$60+4>>0]|0;
 (__ZN19ScriptingInvocation6InvokeEv($tmpcast2$i$byval_copy)|0);
 $61 = (($tmpcast2$i$byval_copy) + 28|0);
 $62 = HEAP32[$61>>2]|0;
 HEAP32[$exception>>2] = $62;
 __ZN25ScriptingInvocationNoArgsC2Ev($userOnGUIInvocation);
 $63 = (($userOnGUIInvocation) + 4|0);
 HEAP32[$63>>2] = $14;
 $64 = (($userOnGUIInvocation) + 8|0);
 $65 = $13&255;
 HEAP8[$64>>0] = $65;
 $66 = (($userOnGUIInvocation) + 12|0);
 HEAP32[$66>>2] = $42;
 $67 = (($userOnGUIInvocation) + 25|0);
 HEAP8[$67>>0] = 0;
 (__ZN25ScriptingInvocationNoArgs6InvokeEPP18ScriptingException($userOnGUIInvocation,$exception)|0);
 $68 = HEAP32[$exception>>2]|0;
 $69 = ($68|0)==(0|0);
 if ($69) {
  __ZN19ScriptingInvocationC2Ev($0);
  $70 = (($0) + 4|0);
  $71 = (__Z19GetScriptingManagerv()|0);
  $72 = (($71) + 432|0);
  ;HEAP32[$70+0>>2]=HEAP32[$72+0>>2]|0;HEAP8[$70+4>>0]=HEAP8[$72+4>>0]|0;
  $73 = (($0) + 32|0);
  __ZN18ScriptingArguments6AddIntEi($73,$layoutType);
  (__ZN19ScriptingInvocation6InvokeEv($0)|0);
  __ZN8GUIState8EndOnGUIEv($45);
  $74 = HEAP32[$47>>2]|0;
  __ZN12GUIClipState8EndOnGUIER10InputEvent($46,$74);
 }
 $75 = HEAP32[$47>>2]|0;
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(12);
 $$0 = $77;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MonoBehaviour15GetUseGUILayoutEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 130|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN13MonoBehaviour14GetOrCreateDSPEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z9GetIAudiov()|0);
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $$0 = 0;
  } else {
   $2 = (($this) + 132|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    $5 = (($this) + 52|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)==(0|0);
    if ($7) {
     $$0 = 0;
     break;
    }
    $8 = (($6) + 136|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $$0 = 0;
     break;
    }
    $11 = (($this) + 24|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0 = 0;
     break;
    }
    $14 = (__ZNK5Unity10GameObject8IsActiveEv($12)|0);
    if (!($14)) {
     $$0 = 0;
     break;
    }
    $15 = HEAP32[$0>>2]|0;
    $16 = (($15) + 44|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (FUNCTION_TABLE_iii[$17 & 4095]($0,$this)|0);
    HEAP32[$2>>2] = $18;
    $22 = $18;
   } else {
    $22 = $3;
   }
   $19 = HEAP32[$0>>2]|0;
   $20 = (($19) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   $23 = (FUNCTION_TABLE_iii[$21 & 4095]($0,$22)|0);
   $$0 = $23;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNK13MonoBehaviour6GetDSPEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z9GetIAudiov()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = (($this) + 132|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0 = 0;
  } else {
   $5 = HEAP32[$0>>2]|0;
   $6 = (($5) + 52|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (FUNCTION_TABLE_iii[$7 & 4095]($0,$3)|0);
   $$0 = $8;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MonoBehaviour16CallUpdateMethodEi($this,$methodIndex) {
 $this = $this|0;
 $methodIndex = $methodIndex|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $invocation$i = 0, $phitmp$i = 0, $tmpcast1$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast1$i$byval_copy = sp + 56|0;
 $0 = sp;
 $1 = sp + 8|0;
 $invocation$i = sp + 24|0;
 $2 = sp + 16|0;
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($4) + 32|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   $9 = (($4) + 33|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)==(0);
   if ($11) {
    $12 = (($this) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = $13 & 1048576;
    $phitmp$i = ($14|0)==(0);
    if (!($phitmp$i)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = (($this) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 }
 $18 = (($this) + 129|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  HEAP8[$18>>0] = 1;
  $21 = (($this) + 52|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 88|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $35 = $22;
  } else {
   $26 = (($22) + 92|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $24;
   $29 = $27&255;
   $30 = $0;
   $31 = $30;
   HEAP32[$31>>2] = $28;
   $32 = (($30) + 4)|0;
   $33 = $32;
   HEAP32[$33>>2] = $29;
   ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($this,$tmpcast1$i$byval_copy,0)|0);
   $$pre$i = HEAP32[$21>>2]|0;
   $35 = $$pre$i;
  }
  $34 = (($35) + 80|0);
  $36 = HEAP32[$34>>2]|0;
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $38 = (($35) + 84|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = $36;
   $41 = $39&255;
   $42 = $1;
   $43 = $42;
   HEAP32[$43>>2] = $40;
   $44 = (($42) + 4)|0;
   $45 = $44;
   HEAP32[$45>>2] = $41;
   ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
   (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($this,$tmpcast1$i$byval_copy,0)|0);
  }
 }
 $46 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($16)|0);
 $47 = ($46|0)==(0|0);
 if ($47) {
  STACKTOP = sp;return;
 }
 $48 = (($this) + 52|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + ($methodIndex<<3)|0);
 $51 = $50;
 $52 = $51;
 $53 = HEAP32[$52>>2]|0;
 $54 = (($51) + 4)|0;
 $55 = $54;
 $56 = HEAP32[$55>>2]|0;
 $57 = ($53|0)==(0);
 if ($57) {
  STACKTOP = sp;return;
 }
 $58 = (($this) + 24|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0|0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $61 = (__ZNK5Unity10GameObject8IsActiveEv($59)|0);
 if (!($61)) {
  STACKTOP = sp;return;
 }
 $62 = $2;
 $63 = $62;
 HEAP32[$63>>2] = $53;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = $56;
 ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation$i,$tmpcast1$i$byval_copy);
 $66 = (($this) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($invocation$i) + 16|0);
 HEAP32[$68>>2] = $67;
 $69 = HEAP32[$15>>2]|0;
 $70 = (($invocation$i) + 12|0);
 HEAP32[$70>>2] = $69;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation$i)|0);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour6UpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MonoBehaviour16CallUpdateMethodEi($this,0);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour10LateUpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MonoBehaviour16CallUpdateMethodEi($this,1);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour11FixedUpdateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MonoBehaviour16CallUpdateMethodEi($this,2);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour10FindMethodEPKc($agg$result,$this,$name) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = 599912;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $agg$result;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  STACKTOP = sp;return;
 } else {
  $13 = (($this) + 48|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  __ZN9Scripting26GetMethodWithSearchOptionsEP14ScriptingClassPKci($agg$result,$16,$name,1);
  STACKTOP = sp;return;
 }
}
function __ZN13MonoBehaviour20InvokeOnRenderObjectEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast1$i$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$i$byval_copy = sp + 40|0;
 $0 = sp;
 $1 = sp + 32|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 129|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  HEAP8[$5>>0] = 1;
  $8 = (($this) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 88|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $22 = $9;
  } else {
   $13 = (($9) + 92|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $11;
   $16 = $14&255;
   $17 = $0;
   $18 = $17;
   HEAP32[$18>>2] = $15;
   $19 = (($17) + 4)|0;
   $20 = $19;
   HEAP32[$20>>2] = $16;
   ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($this,$tmpcast1$i$byval_copy,0)|0);
   $$pre$i = HEAP32[$8>>2]|0;
   $22 = $$pre$i;
  }
  $21 = (($22) + 80|0);
  $23 = HEAP32[$21>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $$pre$phiZ2D = $8;
  } else {
   $25 = (($22) + 84|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = $23;
   $28 = $26&255;
   $29 = $1;
   $30 = $29;
   HEAP32[$30>>2] = $27;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = $28;
   ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
   (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($this,$tmpcast1$i$byval_copy,0)|0);
   $$pre$phiZ2D = $8;
  }
 } else {
  $$pre = (($this) + 52|0);
  $$pre$phiZ2D = $$pre;
 }
 $33 = HEAP32[$$pre$phiZ2D>>2]|0;
 $34 = (($33) + 48|0);
 $35 = $34;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + 4)|0;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = ($37|0)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($this) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = (__ZNK5Unity10GameObject8IsActiveEv($43)|0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 $46 = $1;
 $47 = $46;
 HEAP32[$47>>2] = $37;
 $48 = (($46) + 4)|0;
 $49 = $48;
 HEAP32[$49>>2] = $40;
 ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($0,$tmpcast1$i$byval_copy);
 $50 = (($this) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($0) + 16|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$2>>2]|0;
 $54 = (($0) + 12|0);
 HEAP32[$54>>2] = $53;
 (__ZN25ScriptingInvocationNoArgs6InvokeEv($0)|0);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour15CreateCoroutineEP15ScriptingObject21ScriptingMethodIl2Cpp($this,$userCoroutine,$method) {
 $this = $this|0;
 $userCoroutine = $userCoroutine|0;
 $method = $method|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$02 = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $current = 0, $message = 0, $moveNext = 0, $tmpcast6$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast6$byval_copy = sp + 56|0;
 $moveNext = sp + 48|0;
 $0 = sp + 40|0;
 $current = sp + 32|0;
 $1 = sp + 24|0;
 $message = sp + 64|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = sp + 16|0;
 $5 = (__Z19GetScriptingManagerv()|0);
 $6 = (($5) + 376|0);
 $7 = $6;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $0;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($moveNext,$userCoroutine,$tmpcast6$byval_copy);
 $17 = (__Z19GetScriptingManagerv()|0);
 $18 = (($17) + 392|0);
 $19 = $18;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $1;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 __Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp($current,$userCoroutine,$tmpcast6$byval_copy);
 $29 = HEAP32[$current>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = HEAP32[$moveNext>>2]|0;
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   $75 = (__Znwj(68)|0);
   __THREW__ = 0;
   invoke_vi(3555,($75|0));
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    __ZdlPv($75);
    $$01 = $122;$$02 = $123;
    ___resumeException($$01|0);
    // unreachable;
   }
   $78 = (__Z22scripting_gchandle_newP15ScriptingObject($userCoroutine)|0);
   $79 = (($75) + 12|0);
   HEAP32[$79>>2] = $78;
   $80 = (($75) + 8|0);
   HEAP32[$80>>2] = $userCoroutine;
   $81 = (($75) + 16|0);
   ;HEAP32[$81+0>>2]=HEAP32[$method+0>>2]|0;HEAP8[$81+4>>0]=HEAP8[$method+4>>0]|0;
   $82 = $moveNext;
   $83 = $82;
   $84 = HEAP32[$83>>2]|0;
   $85 = (($82) + 4)|0;
   $86 = $85;
   $87 = HEAP32[$86>>2]|0;
   $88 = $3;
   $89 = $88;
   HEAP32[$89>>2] = $84;
   $90 = (($88) + 4)|0;
   $91 = $90;
   HEAP32[$91>>2] = $87;
   ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
   __ZN9Coroutine17SetMoveNextMethodE21ScriptingMethodIl2Cpp($75,$tmpcast6$byval_copy);
   $92 = $current;
   $93 = $92;
   $94 = HEAP32[$93>>2]|0;
   $95 = (($92) + 4)|0;
   $96 = $95;
   $97 = HEAP32[$96>>2]|0;
   $98 = $4;
   $99 = $98;
   HEAP32[$99>>2] = $94;
   $100 = (($98) + 4)|0;
   $101 = $100;
   HEAP32[$101>>2] = $97;
   ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
   __ZN9Coroutine16SetCurrentMethodE21ScriptingMethodIl2Cpp($75,$tmpcast6$byval_copy);
   $102 = (($75) + 40|0);
   HEAP32[$102>>2] = $this;
   $103 = (($75) + 56|0);
   HEAP32[$103>>2] = 0;
   $104 = (($75) + 60|0);
   HEAP32[$104>>2] = 0;
   $105 = (($75) + 64|0);
   HEAP32[$105>>2] = 0;
   $106 = (($75) + 44|0);
   HEAP32[$106>>2] = 1;
   $107 = (($75) + 48|0);
   HEAP32[$107>>2] = 0;
   $108 = (($this) + 56|0);
   $109 = ($75|0)==($108|0);
   if ($109) {
    $$pre$phiZ2D = $108;
   } else {
    $110 = HEAP32[$75>>2]|0;
    $111 = ($110|0)==(0|0);
    $$pre$i$i = (($75) + 4|0);
    if (!($111)) {
     $112 = HEAP32[$$pre$i$i>>2]|0;
     $113 = (($110) + 4|0);
     HEAP32[$113>>2] = $112;
     $114 = HEAP32[$75>>2]|0;
     $115 = HEAP32[$$pre$i$i>>2]|0;
     HEAP32[$115>>2] = $114;
     HEAP32[$75>>2] = 0;
     HEAP32[$$pre$i$i>>2] = 0;
    }
    $116 = HEAP32[$108>>2]|0;
    HEAP32[$75>>2] = $116;
    HEAP32[$$pre$i$i>>2] = $108;
    $117 = (($116) + 4|0);
    HEAP32[$117>>2] = $75;
    $118 = HEAP32[$$pre$i$i>>2]|0;
    HEAP32[$118>>2] = $75;
    $$pre$phiZ2D = $108;
   }
   $119 = HEAP32[$$pre$phiZ2D>>2]|0;
   __ZN9Coroutine3RunEv($119);
   $120 = HEAP32[$106>>2]|0;
   $121 = ($120|0)<(2);
   __ZN9Coroutine16CleanupCoroutineEPv($75);
   $$ = $121 ? 0 : $75;
   $$0 = $$;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $33 = HEAP32[$method>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  $46 = (__Znwj(32)|0);
  $47 = (($message) + 8|0);
  HEAP32[$47>>2] = $46;
  HEAP32[$message>>2] = 33;
  $48 = (($message) + 4|0);
  HEAP32[$48>>2] = 30;
  dest=$46+0|0; src=632168+0|0; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $49 = (($46) + 30|0);
  HEAP8[$49>>0] = 0;
 } else {
  $35 = $method;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + 4)|0;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = $2;
  $42 = $41;
  HEAP32[$42>>2] = $37;
  $43 = (($41) + 4)|0;
  $44 = $43;
  HEAP32[$44>>2] = $40;
  ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
  $45 = (__Z25scripting_method_get_name21ScriptingMethodIl2Cpp($tmpcast6$byval_copy)|0);
  HEAP32[$tmpcast6$byval_copy>>2] = $45;
  __Z6FormatPKcz($message,632128,$tmpcast6$byval_copy);
 }
 $50 = ($this|0)==(0|0);
 if ($50) {
  $60 = 0;
 } else {
  $51 = (($this) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $60 = $52;
 }
 $53 = HEAP8[$message>>0]|0;
 $54 = $53 & 1;
 $55 = ($54<<24>>24)==(0);
 if ($55) {
  $58 = (($message) + 1|0);
  $59 = $58;
 } else {
  $56 = (($message) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  $59 = $57;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($59|0),0,(632120|0),738,4,($60|0),0,(0|0));
 $61 = __THREW__; __THREW__ = 0;
 $62 = $61&1;
 if ($62) {
  $68 = ___cxa_find_matching_catch()|0;
  $69 = tempRet0;
  $70 = HEAP8[$message>>0]|0;
  $71 = $70 & 1;
  $72 = ($71<<24>>24)==(0);
  if ($72) {
   $$01 = $68;$$02 = $69;
   ___resumeException($$01|0);
   // unreachable;
  }
  $73 = (($message) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  __ZdlPv($74);
  $$01 = $68;$$02 = $69;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $63 = HEAP8[$message>>0]|0;
  $64 = $63 & 1;
  $65 = ($64<<24>>24)==(0);
  if ($65) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $66 = (($message) + 8|0);
  $67 = HEAP32[$66>>2]|0;
  __ZdlPv($67);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN13MonoBehaviour22StartCoroutineManaged2EP15ScriptingObject($this,$enumerator) {
 $this = $this|0;
 $enumerator = $enumerator|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (__ZNK5Unity10GameObject8IsActiveEv($3)|0);
  if ($5) {
   $33 = 599912;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) + 4)|0;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = $1;
   $40 = $39;
   HEAP32[$40>>2] = $35;
   $41 = (($39) + 4)|0;
   $42 = $41;
   HEAP32[$42>>2] = $38;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
   $43 = (__ZN13MonoBehaviour15CreateCoroutineEP15ScriptingObject21ScriptingMethodIl2Cpp($this,$enumerator,$tmpcast$byval_copy)|0);
   $44 = ($43|0)==(0|0);
   if ($44) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $45 = (($43) + 48|0);
   HEAP32[$45>>2] = 1;
   $46 = (__Z14GetMonoManagerv()|0);
   $47 = (($46) + 252|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (__Z20scripting_object_newP14ScriptingClass($48)|0);
   $50 = (($49) + 8|0);
   HEAP32[$50>>2] = $43;
   $$0 = $49;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($this)|0);
 HEAP32[$tmpcast$byval_copy>>2] = $9;
 __Z6FormatPKcz($0,632200,$tmpcast$byval_copy);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP8[$0>>0]|0;
 $13 = $12 & 1;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $17 = (($0) + 1|0);
  $18 = $17;
 } else {
  $15 = (($0) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $18 = $16;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($18|0),0,(632120|0),801,1,($11|0),0,(0|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $28 = HEAP8[$0>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   ___resumeException($26|0);
   // unreachable;
  }
  $31 = (($0) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  __ZdlPv($32);
  ___resumeException($26|0);
  // unreachable;
 } else {
  $21 = HEAP8[$0>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $24 = (($0) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  __ZdlPv($25);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN13MonoBehaviour26HandleCoroutineReturnValueE21ScriptingMethodIl2CppP15ScriptingObject($this,$method,$returnValue) {
 $this = $this|0;
 $method = $method|0;
 $returnValue = $returnValue|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast1$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = $method;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (__Z14GetMonoManagerv()|0);
 $9 = (($8) + 140|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $7 & 255;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $4;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $16 = (__Z31scripting_method_get_returntype21ScriptingMethodIl2Cpp($tmpcast1$byval_copy)|0);
 $17 = (__Z25scripting_class_from_typeP13ScriptingType($16)|0);
 $18 = ($17|0)==($10|0);
 if (!($18)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = $1;
 $20 = $19;
 HEAP32[$20>>2] = $4;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $7;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $23 = (__ZN13MonoBehaviour15CreateCoroutineEP15ScriptingObject21ScriptingMethodIl2Cpp($this,$returnValue,$tmpcast1$byval_copy)|0);
 $$0 = $23;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObjectPP18ScriptingException($this,$scriptingMethod,$value,$exception) {
 $this = $this|0;
 $scriptingMethod = $scriptingMethod|0;
 $value = $value|0;
 $exception = $exception|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0.0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0.0, $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0.0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = Math_fround(0), $278 = 0.0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error = 0, $error1 = 0, $invocation = 0, $tmpcast7$byval_copy = 0, $type$off$i = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0;
 $tmpcast7$byval_copy = sp + 208|0;
 $0 = sp + 272|0;
 $1 = sp + 472|0;
 $2 = sp + 488|0;
 $3 = sp + 528|0;
 $4 = sp + 264|0;
 $invocation = sp + 8|0;
 $5 = sp;
 $error = sp + 544|0;
 $6 = sp + 216|0;
 $7 = sp + 504|0;
 $8 = sp + 532|0;
 $9 = sp + 224|0;
 $error1 = sp + 516|0;
 $10 = sp + 232|0;
 $11 = sp + 492|0;
 $12 = sp + 476|0;
 $13 = sp + 240|0;
 $14 = sp + 248|0;
 $15 = sp + 256|0;
 $16 = $scriptingMethod;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $4;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
 $26 = (__Z35scripting_method_get_argument_count21ScriptingMethodIl2Cpp($tmpcast7$byval_copy)|0);
 $27 = $5;
 $28 = $27;
 HEAP32[$28>>2] = $18;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $21;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast7$byval_copy);
 $31 = (($this) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($invocation) + 12|0);
 HEAP32[$33>>2] = $32;
 $34 = (($invocation) + 25|0);
 HEAP8[$34>>0] = 0;
 $35 = ($26|0)==(0);
 if ($35) {
  $36 = (__ZN19ScriptingInvocation6InvokeEPP18ScriptingException($invocation,$exception)|0);
  $$0 = $36;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = ($value|0)==(0|0);
 if ($37) {
  $38 = $6;
  $39 = $38;
  HEAP32[$39>>2] = $18;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $21;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
  $42 = (__Z25scripting_method_get_name21ScriptingMethodIl2Cpp($tmpcast7$byval_copy)|0);
  __ZN13MonoBehaviour18GetScriptClassNameEv($7,$this);
  $43 = HEAP8[$7>>0]|0;
  $44 = $43 & 1;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   $48 = (($7) + 1|0);
   $49 = $48;
  } else {
   $46 = (($7) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   $49 = $47;
  }
  __THREW__ = 0;
  HEAP32[$tmpcast7$byval_copy>>2] = $42;
  $vararg_ptr1 = (($tmpcast7$byval_copy) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $49;
  invoke_viii(1617,($error|0),(632280|0),($tmpcast7$byval_copy|0));
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   $107 = ___cxa_find_matching_catch()|0;
   $108 = tempRet0;
   $109 = HEAP8[$7>>0]|0;
   $110 = $109 & 1;
   $111 = ($110<<24>>24)==(0);
   if ($111) {
    $$2 = $107;$$24 = $108;
    ___resumeException($$2|0);
    // unreachable;
   }
   $112 = (($7) + 8|0);
   $113 = HEAP32[$112>>2]|0;
   HEAP32[$2>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($113|0),($tmpcast7$byval_copy|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if ($115) {
    $116 = ___cxa_find_matching_catch()|0;
    $117 = tempRet0;
    ___cxa_call_unexpected(($116|0));
    // unreachable;
   } else {
    $$2 = $107;$$24 = $108;
    ___resumeException($$2|0);
    // unreachable;
   }
  }
  $52 = HEAP8[$7>>0]|0;
  $53 = $52 & 1;
  $54 = ($53<<24>>24)==(0);
  if (!($54)) {
   $55 = (($7) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   HEAP32[$3>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($56|0),($tmpcast7$byval_copy|0));
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    ___cxa_call_unexpected(($59|0));
    // unreachable;
   }
  }
  $61 = $9;
  $62 = $61;
  HEAP32[$62>>2] = $18;
  $63 = (($61) + 4)|0;
  $64 = $63;
  HEAP32[$64>>2] = $21;
  __THREW__ = 0;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
  $65 = (invoke_ii(3290,($tmpcast7$byval_copy|0))|0);
  $66 = __THREW__; __THREW__ = 0;
  $67 = $66&1;
  do {
   if ($67) {
    label = 30;
   } else {
    __THREW__ = 0;
    HEAP32[$tmpcast7$byval_copy>>2] = $65;
    $vararg_ptr5 = (($tmpcast7$byval_copy) + 4|0);
    HEAP32[$vararg_ptr5>>2] = $26;
    invoke_viii(1617,($8|0),(632320|0),($tmpcast7$byval_copy|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     label = 30;
    } else {
     $70 = HEAP8[$8>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $77 = (($8) + 1|0);
      $78 = $70&255;
      $79 = $78 >>> 1;
      $80 = $77;$81 = $79;
     } else {
      $73 = (($8) + 8|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = (($8) + 4|0);
      $76 = HEAP32[$75>>2]|0;
      $80 = $74;$81 = $76;
     }
     __THREW__ = 0;
     (invoke_iiii(1480,($error|0),($80|0),($81|0))|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      $120 = ___cxa_find_matching_catch()|0;
      $121 = tempRet0;
      $122 = HEAP8[$8>>0]|0;
      $123 = $122 & 1;
      $124 = ($123<<24>>24)==(0);
      if ($124) {
       $$01 = $120;$$02 = $121;
       break;
      }
      $125 = (($8) + 8|0);
      $126 = HEAP32[$125>>2]|0;
      __ZdlPv($126);
      $$01 = $120;$$02 = $121;
      break;
     }
     $84 = HEAP8[$8>>0]|0;
     $85 = $84 & 1;
     $86 = ($85<<24>>24)==(0);
     if (!($86)) {
      $87 = (($8) + 8|0);
      $88 = HEAP32[$87>>2]|0;
      __ZdlPv($88);
     }
     $89 = ($this|0)==(0|0);
     if ($89) {
      $99 = 0;
     } else {
      $90 = (($this) + 4|0);
      $91 = HEAP32[$90>>2]|0;
      $99 = $91;
     }
     $92 = HEAP8[$error>>0]|0;
     $93 = $92 & 1;
     $94 = ($93<<24>>24)==(0);
     if ($94) {
      $97 = (($error) + 1|0);
      $98 = $97;
     } else {
      $95 = (($error) + 8|0);
      $96 = HEAP32[$95>>2]|0;
      $98 = $96;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($98|0),0,(632120|0),845,1,($99|0),0,(0|0));
     $100 = __THREW__; __THREW__ = 0;
     $101 = $100&1;
     if ($101) {
      label = 30;
     } else {
      $102 = HEAP8[$error>>0]|0;
      $103 = $102 & 1;
      $104 = ($103<<24>>24)==(0);
      if ($104) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      $105 = (($error) + 8|0);
      $106 = HEAP32[$105>>2]|0;
      __ZdlPv($106);
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  } while(0);
  if ((label|0) == 30) {
   $118 = ___cxa_find_matching_catch()|0;
   $119 = tempRet0;
   $$01 = $118;$$02 = $119;
  }
  $127 = HEAP8[$error>>0]|0;
  $128 = $127 & 1;
  $129 = ($128<<24>>24)==(0);
  if ($129) {
   $$2 = $$01;$$24 = $$02;
   ___resumeException($$2|0);
   // unreachable;
  }
  $130 = (($error) + 8|0);
  $131 = HEAP32[$130>>2]|0;
  __ZdlPv($131);
  $$2 = $$01;$$24 = $$02;
  ___resumeException($$2|0);
  // unreachable;
 }
 $132 = ($26|0)==(1);
 if ($132) {
  $227 = (__Z26scripting_object_get_classP15ScriptingObject($value)|0);
  $228 = $18;
  $229 = (_il2cpp_method_get_param($228,0)|0);
  $230 = (__Z25scripting_class_from_typeP13ScriptingType($229)|0);
  $231 = (__Z23scripting_type_get_typeP13ScriptingType($229)|0);
  $type$off$i = (($231) + -2)|0;
  $232 = ($type$off$i>>>0)<(12);
  L60: do {
   if ($232) {
    $233 = (__Z26scripting_object_get_classP15ScriptingObject($value)|0);
    $234 = (__Z24scripting_class_get_typeP14ScriptingClass($233)|0);
    $235 = (__Z23scripting_type_get_typeP13ScriptingType($234)|0);
    $236 = ($235|0)==($231|0);
    do {
     if ($236) {
      $$0$i = $value;
     } else {
      $237 = (__Z14GetMonoManagerv()|0);
      if ((($231|0) == 8)) {
       if ((($235|0) == 12)) {
        $238 = (($237) + 200|0);
        $239 = HEAP32[$238>>2]|0;
        $240 = (__Z20scripting_object_newP14ScriptingClass($239)|0);
        $241 = (($value) + 8|0);
        $242 = Math_fround(HEAPF32[$241>>2]);
        $243 = (~~(($242)));
        $244 = (($240) + 8|0);
        HEAP32[$244>>2] = $243;
        $$0$i = $240;
        break;
       } else if ((($235|0) == 13)) {
        $245 = (($237) + 200|0);
        $246 = HEAP32[$245>>2]|0;
        $247 = (__Z20scripting_object_newP14ScriptingClass($246)|0);
        $248 = (($value) + 8|0);
        $249 = +HEAPF64[$248>>3];
        $250 = (~~(($249)));
        $251 = (($247) + 8|0);
        HEAP32[$251>>2] = $250;
        $$0$i = $247;
        break;
       } else {
        break L60;
       }
      } else if ((($231|0) == 12)) {
       if ((($235|0) == 13)) {
        $259 = (($237) + 208|0);
        $260 = HEAP32[$259>>2]|0;
        $261 = (__Z20scripting_object_newP14ScriptingClass($260)|0);
        $262 = (($value) + 8|0);
        $263 = +HEAPF64[$262>>3];
        $264 = Math_fround($263);
        $265 = (($261) + 8|0);
        HEAPF32[$265>>2] = $264;
        $$0$i = $261;
        break;
       } else if ((($235|0) == 8)) {
        $252 = (($237) + 208|0);
        $253 = HEAP32[$252>>2]|0;
        $254 = (__Z20scripting_object_newP14ScriptingClass($253)|0);
        $255 = (($value) + 8|0);
        $256 = HEAP32[$255>>2]|0;
        $257 = (Math_fround(($256|0)));
        $258 = (($254) + 8|0);
        HEAPF32[$258>>2] = $257;
        $$0$i = $254;
        break;
       } else {
        break L60;
       }
      } else if ((($231|0) == 13)) {
       if ((($235|0) == 12)) {
        $273 = (($237) + 212|0);
        $274 = HEAP32[$273>>2]|0;
        $275 = (__Z20scripting_object_newP14ScriptingClass($274)|0);
        $276 = (($value) + 8|0);
        $277 = Math_fround(HEAPF32[$276>>2]);
        $278 = +$277;
        $279 = (($275) + 8|0);
        HEAPF64[$279>>3] = $278;
        $$0$i = $275;
        break;
       } else if ((($235|0) == 8)) {
        $266 = (($237) + 212|0);
        $267 = HEAP32[$266>>2]|0;
        $268 = (__Z20scripting_object_newP14ScriptingClass($267)|0);
        $269 = (($value) + 8|0);
        $270 = HEAP32[$269>>2]|0;
        $271 = (+($270|0));
        $272 = (($268) + 8|0);
        HEAPF64[$272>>3] = $271;
        $$0$i = $268;
        break;
       } else {
        break L60;
       }
      } else {
       break L60;
      }
     }
    } while(0);
    $280 = ($$0$i|0)==(0|0);
    if (!($280)) {
     $281 = (($$0$i) + 8|0);
     $282 = (($invocation) + 32|0);
     __ZN18ScriptingArguments9AddStructEPv($282,$281);
    }
   } else {
    if ((($231|0) == 18)) {
     $286 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($227,$230)|0);
     if (!($286)) {
      break;
     }
     $287 = (($invocation) + 32|0);
     __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($287,$value);
     break;
    } else if ((($231|0) == 14)) {
     $288 = (__Z24scripting_class_get_typeP14ScriptingClass($227)|0);
     $289 = (__Z23scripting_type_get_typeP13ScriptingType($288)|0);
     $290 = ($289|0)==(14);
     if (!($290)) {
      break;
     }
     $291 = (($invocation) + 32|0);
     __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($291,$value);
     break;
    } else if ((($231|0) == 17)) {
     $283 = ($227|0)==($230|0);
     if (!($283)) {
      break;
     }
     $284 = (($value) + 8|0);
     $285 = (($invocation) + 32|0);
     __ZN18ScriptingArguments9AddStructEPv($285,$284);
     break;
    } else if ((($231|0) == 28)) {
     $292 = (($invocation) + 32|0);
     __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($292,$value);
     break;
    } else {
     break;
    }
   }
  } while(0);
  $293 = (($invocation) + 32|0);
  $294 = (__ZN18ScriptingArguments8GetCountEv($293)|0);
  $295 = ($294|0)==(1);
  if ($295) {
   $296 = (__ZN19ScriptingInvocation6InvokeEPP18ScriptingExceptionb($invocation,$exception,0)|0);
   $$0 = $296;
   STACKTOP = sp;return ($$0|0);
  } else {
   $297 = (__Z14GetMonoManagerv()|0);
   $298 = (($297) + 328|0);
   $299 = $298;
   $300 = $299;
   $301 = HEAP32[$300>>2]|0;
   $302 = (($299) + 4)|0;
   $303 = $302;
   $304 = HEAP32[$303>>2]|0;
   $305 = $14;
   $306 = $305;
   HEAP32[$306>>2] = $301;
   $307 = (($305) + 4)|0;
   $308 = $307;
   HEAP32[$308>>2] = $304;
   ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$14+4>>2]|0;
   __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($0,$tmpcast7$byval_copy);
   $309 = (($0) + 25|0);
   HEAP8[$309>>0] = 0;
   $310 = HEAP32[$31>>2]|0;
   $311 = (($0) + 32|0);
   __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($311,$310);
   $312 = $15;
   $313 = $312;
   HEAP32[$313>>2] = $18;
   $314 = (($312) + 4)|0;
   $315 = $314;
   HEAP32[$315>>2] = $21;
   ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$15+4>>2]|0;
   $316 = (__Z25scripting_method_get_name21ScriptingMethodIl2Cpp($tmpcast7$byval_copy)|0);
   __ZN18ScriptingArguments9AddStringEPKc($311,$316);
   __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($311,$value);
   $317 = (__ZN19ScriptingInvocation6InvokeEPP18ScriptingExceptionb($0,$exception,0)|0);
   $$0 = $317;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $133 = $10;
 $134 = $133;
 HEAP32[$134>>2] = $18;
 $135 = (($133) + 4)|0;
 $136 = $135;
 HEAP32[$136>>2] = $21;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$10+4>>2]|0;
 $137 = (__Z25scripting_method_get_name21ScriptingMethodIl2Cpp($tmpcast7$byval_copy)|0);
 __ZN13MonoBehaviour18GetScriptClassNameEv($11,$this);
 $138 = HEAP8[$11>>0]|0;
 $139 = $138 & 1;
 $140 = ($139<<24>>24)==(0);
 if ($140) {
  $143 = (($11) + 1|0);
  $144 = $143;
 } else {
  $141 = (($11) + 8|0);
  $142 = HEAP32[$141>>2]|0;
  $144 = $142;
 }
 __THREW__ = 0;
 HEAP32[$tmpcast7$byval_copy>>2] = $137;
 $vararg_ptr9 = (($tmpcast7$byval_copy) + 4|0);
 HEAP32[$vararg_ptr9>>2] = $144;
 invoke_viii(1617,($error1|0),(632280|0),($tmpcast7$byval_copy|0));
 $145 = __THREW__; __THREW__ = 0;
 $146 = $145&1;
 if ($146) {
  $202 = ___cxa_find_matching_catch()|0;
  $203 = tempRet0;
  $204 = HEAP8[$11>>0]|0;
  $205 = $204 & 1;
  $206 = ($205<<24>>24)==(0);
  if ($206) {
   $$2 = $202;$$24 = $203;
   ___resumeException($$2|0);
   // unreachable;
  }
  $207 = (($11) + 8|0);
  $208 = HEAP32[$207>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($208|0),($tmpcast7$byval_copy|0));
  $209 = __THREW__; __THREW__ = 0;
  $210 = $209&1;
  if ($210) {
   $211 = ___cxa_find_matching_catch()|0;
   $212 = tempRet0;
   ___cxa_call_unexpected(($211|0));
   // unreachable;
  } else {
   $$2 = $202;$$24 = $203;
   ___resumeException($$2|0);
   // unreachable;
  }
 }
 $147 = HEAP8[$11>>0]|0;
 $148 = $147 & 1;
 $149 = ($148<<24>>24)==(0);
 if (!($149)) {
  $150 = (($11) + 8|0);
  $151 = HEAP32[$150>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($151|0),($tmpcast7$byval_copy|0));
  $152 = __THREW__; __THREW__ = 0;
  $153 = $152&1;
  if ($153) {
   $154 = ___cxa_find_matching_catch()|0;
   $155 = tempRet0;
   ___cxa_call_unexpected(($154|0));
   // unreachable;
  }
 }
 $156 = $13;
 $157 = $156;
 HEAP32[$157>>2] = $18;
 $158 = (($156) + 4)|0;
 $159 = $158;
 HEAP32[$159>>2] = $21;
 __THREW__ = 0;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$13+4>>2]|0;
 $160 = (invoke_ii(3290,($tmpcast7$byval_copy|0))|0);
 $161 = __THREW__; __THREW__ = 0;
 $162 = $161&1;
 do {
  if ($162) {
   label = 62;
  } else {
   __THREW__ = 0;
   HEAP32[$tmpcast7$byval_copy>>2] = $160;
   $vararg_ptr13 = (($tmpcast7$byval_copy) + 4|0);
   HEAP32[$vararg_ptr13>>2] = $26;
   invoke_viii(1617,($12|0),(632392|0),($tmpcast7$byval_copy|0));
   $163 = __THREW__; __THREW__ = 0;
   $164 = $163&1;
   if ($164) {
    label = 62;
   } else {
    $165 = HEAP8[$12>>0]|0;
    $166 = $165 & 1;
    $167 = ($166<<24>>24)==(0);
    if ($167) {
     $172 = (($12) + 1|0);
     $173 = $165&255;
     $174 = $173 >>> 1;
     $175 = $172;$176 = $174;
    } else {
     $168 = (($12) + 8|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = (($12) + 4|0);
     $171 = HEAP32[$170>>2]|0;
     $175 = $169;$176 = $171;
    }
    __THREW__ = 0;
    (invoke_iiii(1480,($error1|0),($175|0),($176|0))|0);
    $177 = __THREW__; __THREW__ = 0;
    $178 = $177&1;
    if ($178) {
     $215 = ___cxa_find_matching_catch()|0;
     $216 = tempRet0;
     $217 = HEAP8[$12>>0]|0;
     $218 = $217 & 1;
     $219 = ($218<<24>>24)==(0);
     if ($219) {
      $$1 = $215;$$13 = $216;
      break;
     }
     $220 = (($12) + 8|0);
     $221 = HEAP32[$220>>2]|0;
     __ZdlPv($221);
     $$1 = $215;$$13 = $216;
     break;
    }
    $179 = HEAP8[$12>>0]|0;
    $180 = $179 & 1;
    $181 = ($180<<24>>24)==(0);
    if (!($181)) {
     $182 = (($12) + 8|0);
     $183 = HEAP32[$182>>2]|0;
     __ZdlPv($183);
    }
    $184 = ($this|0)==(0|0);
    if ($184) {
     $194 = 0;
    } else {
     $185 = (($this) + 4|0);
     $186 = HEAP32[$185>>2]|0;
     $194 = $186;
    }
    $187 = HEAP8[$error1>>0]|0;
    $188 = $187 & 1;
    $189 = ($188<<24>>24)==(0);
    if ($189) {
     $192 = (($error1) + 1|0);
     $193 = $192;
    } else {
     $190 = (($error1) + 8|0);
     $191 = HEAP32[$190>>2]|0;
     $193 = $191;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($193|0),0,(632120|0),851,1,($194|0),0,(0|0));
    $195 = __THREW__; __THREW__ = 0;
    $196 = $195&1;
    if ($196) {
     label = 62;
    } else {
     $197 = HEAP8[$error1>>0]|0;
     $198 = $197 & 1;
     $199 = ($198<<24>>24)==(0);
     if ($199) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $200 = (($error1) + 8|0);
     $201 = HEAP32[$200>>2]|0;
     __ZdlPv($201);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 62) {
  $213 = ___cxa_find_matching_catch()|0;
  $214 = tempRet0;
  $$1 = $213;$$13 = $214;
 }
 $222 = HEAP8[$error1>>0]|0;
 $223 = $222 & 1;
 $224 = ($223<<24>>24)==(0);
 if ($224) {
  $$2 = $$1;$$24 = $$13;
  ___resumeException($$2|0);
  // unreachable;
 }
 $225 = (($error1) + 8|0);
 $226 = HEAP32[$225>>2]|0;
 __ZdlPv($226);
 $$2 = $$1;$$24 = $$13;
 ___resumeException($$2|0);
 // unreachable;
 return 0|0;
}
function __ZN13MonoBehaviour18GetScriptClassNameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN6Object21IDToPointerThreadSafeEi($2)|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 >>> 21;
  $8 = HEAP32[560640>>2]|0;
  $9 = Math_imul($8, $7)|0;
  $10 = (($9) + 115)|0;
  $11 = $10 >> 5;
  $12 = $11 << 5;
  $13 = (($10) - ($12))|0;
  $14 = HEAP32[560632>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = 1 << $13;
  $18 = $17 & $16;
  $19 = ($18|0)==(0);
  if (!($19)) {
   $20 = HEAP32[$3>>2]|0;
   $21 = (($20) + 100|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (FUNCTION_TABLE_ii[$22 & 4095]($3)|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24 & 1;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    $31 = (($23) + 1|0);
    $32 = $24&255;
    $33 = $32 >>> 1;
    $35 = $33;$46 = $31;
   } else {
    $27 = (($23) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($23) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    $35 = $30;$46 = $28;
   }
   $34 = ($35>>>0)>(2147483631);
   if ($34) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $36 = ($35>>>0)<(11);
   if ($36) {
    $37 = $35 << 1;
    $38 = $37&255;
    HEAP8[$agg$result>>0] = $38;
    $39 = (($agg$result) + 1|0);
    $__p$0$i$i$i$i3 = $39;
   } else {
    $40 = (($35) + 16)|0;
    $41 = $40 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($41,16,$$byval_copy1,0,632120,79)|0);
    $43 = (($agg$result) + 8|0);
    HEAP32[$43>>2] = $42;
    $44 = $41 | 1;
    HEAP32[$agg$result>>2] = $44;
    $45 = (($agg$result) + 4|0);
    HEAP32[$45>>2] = $35;
    $__p$0$i$i$i$i3 = $42;
   }
   _memcpy(($__p$0$i$i$i$i3|0),($46|0),($35|0))|0;
   $47 = (($__p$0$i$i$i$i3) + ($35)|0);
   HEAP8[$47>>0] = 0;
   STACKTOP = sp;return;
  }
 }
 $48 = (($this) + 48|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = (($49) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(0|0);
  if (!($53)) {
   $54 = (__Z24scripting_class_get_nameP14ScriptingClass($52)|0);
   $55 = (_strlen(($54|0))|0);
   $56 = ($55>>>0)>(2147483631);
   if ($56) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $57 = ($55>>>0)<(11);
   if ($57) {
    $58 = $55 << 1;
    $59 = $58&255;
    HEAP8[$agg$result>>0] = $59;
    $60 = (($agg$result) + 1|0);
    $__p$0$i$i$i$i = $60;
   } else {
    $61 = (($55) + 16)|0;
    $62 = $61 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $63 = (__Z15malloc_internaljj10MemLabelIdiPKci($62,16,$$byval_copy1,0,632120,79)|0);
    $64 = (($agg$result) + 8|0);
    HEAP32[$64>>2] = $63;
    $65 = $62 | 1;
    HEAP32[$agg$result>>2] = $65;
    $66 = (($agg$result) + 4|0);
    HEAP32[$66>>2] = $55;
    $__p$0$i$i$i$i = $63;
   }
   _memcpy(($__p$0$i$i$i$i|0),($54|0),($55|0))|0;
   $67 = (($__p$0$i$i$i$i) + ($55)|0);
   HEAP8[$67>>0] = 0;
   STACKTOP = sp;return;
  }
 }
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($this,$method,$value) {
 $this = $this|0;
 $method = $method|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exception = 0, $or$cond = 0, $tmpcast1$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$i$byval_copy = sp + 40|0;
 $0 = sp;
 $1 = sp + 8|0;
 $exception = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$exception>>2] = 0;
 $6 = $method;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $2;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 $16 = (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObjectPP18ScriptingException($this,$tmpcast1$i$byval_copy,$value,$exception)|0);
 $17 = ($16|0)!=(0|0);
 $18 = HEAP32[$exception>>2]|0;
 $19 = ($18|0)==(0|0);
 $or$cond = $17 & $19;
 if ($or$cond) {
  $20 = (__Z14GetMonoManagerv()|0);
  $21 = (($20) + 140|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $11 & 255;
  $24 = $0;
  $25 = $24;
  HEAP32[$25>>2] = $8;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $23;
  ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  $28 = (__Z31scripting_method_get_returntype21ScriptingMethodIl2Cpp($tmpcast1$i$byval_copy)|0);
  $29 = (__Z25scripting_class_from_typeP13ScriptingType($28)|0);
  $30 = ($29|0)==($22|0);
  if (!($30)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $31 = $1;
  $32 = $31;
  HEAP32[$32>>2] = $8;
  $33 = (($31) + 4)|0;
  $34 = $33;
  HEAP32[$34>>2] = $11;
  ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
  $35 = (__ZN13MonoBehaviour15CreateCoroutineEP15ScriptingObject21ScriptingMethodIl2Cpp($this,$16,$tmpcast1$i$byval_copy)|0);
  $$0 = $35;
  STACKTOP = sp;return ($$0|0);
 }
 if ($19) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($5)|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1731,($18|0),($36|0),($3|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $46 = HEAP8[$3>>0]|0;
  $47 = $46 & 1;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   ___resumeException($44|0);
   // unreachable;
  }
  $49 = (($3) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  __ZdlPv($50);
  ___resumeException($44|0);
  // unreachable;
 } else {
  $39 = HEAP8[$3>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $42 = (($3) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  __ZdlPv($43);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN13MonoBehaviour17StopAllCoroutinesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 56|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__Z21GetDelayedCallManagerv()|0);
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 __ZN18DelayedCallManager18CancelCallDelayed2E4PPtrI6ObjectEPFvPS1_PvES6_($5,$0,3209,2660);
 $8 = HEAP32[$1>>2]|0;
 $9 = ($8|0)==($3|0);
 if ($9) {
  STACKTOP = sp;return;
 } else {
  $11 = $8;
 }
 while(1) {
  $10 = HEAP32[$11>>2]|0;
  $12 = ($10|0)==(0|0);
  if (!($12)) {
   $13 = (($11) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($10) + 4|0);
   HEAP32[$15>>2] = $14;
   $16 = HEAP32[$11>>2]|0;
   $17 = HEAP32[$13>>2]|0;
   HEAP32[$17>>2] = $16;
   HEAP32[$11>>2] = 0;
   HEAP32[$13>>2] = 0;
  }
  $18 = (($11) + 40|0);
  HEAP32[$18>>2] = 0;
  $19 = (($11) + 60|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if ($21) {
   $25 = (($11) + 64|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    __ZN9Coroutine16CleanupCoroutineEPv($11);
   }
  } else {
   $22 = (($20) + 56|0);
   HEAP32[$22>>2] = 0;
   HEAP32[$19>>2] = 0;
   __ZN9Coroutine16CleanupCoroutineEPv($11);
  }
  $23 = HEAP32[$1>>2]|0;
  $24 = ($23|0)==($3|0);
  if ($24) {
   break;
  } else {
   $11 = $23;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour10SmartResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__Z14IsWorldPlayingv()|0);
  if (!($3)) {
   (__ZN13MonoBehaviour18CallMethodInactiveEPKc($this,632464)|0);
  }
 }
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour19HandleNotificationsEPviR11MessageData($receiver,$messageIndex,$data) {
 $receiver = $receiver|0;
 $messageIndex = $messageIndex|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exception = 0, $invocation = 0;
 var $message$i = 0, $or$cond = 0, $phitmp$i = 0, $tmpcast1$i$byval_copy = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $tmpcast1$i$byval_copy = sp + 232|0;
 $0 = sp;
 $message$i = sp + 256|0;
 $1 = sp + 16|0;
 $2 = sp + 24|0;
 $invocation = sp + 32|0;
 $3 = sp + 8|0;
 $exception = sp + 252|0;
 $4 = (($receiver) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($5) + 32|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if (!($9)) {
   $10 = (($5) + 33|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    $13 = (($receiver) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 & 1048576;
    $phitmp$i = ($15|0)==(0);
    if (!($phitmp$i)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $16 = (($receiver) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($messageIndex) + 26)|0;
 $20 = (($receiver) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19<<3)|0);
 $23 = $22;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = ($25|0)==(0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($receiver) + 28|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  $33 = (__ZN5Unity10GameObject17GetMessageHandlerEv()|0);
  __ZN14MessageHandler28MessageIDToMessageIdentifierEi($tmpcast1$i$byval_copy,$33,$messageIndex);
  $34 = (($tmpcast1$i$byval_copy) + 16|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = $35 & 4;
  $37 = ($36|0)==(0);
  if (!($37)) {
   STACKTOP = sp;return;
  }
 }
 $38 = $3;
 $39 = $38;
 HEAP32[$39>>2] = $25;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $28;
 ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast1$i$byval_copy);
 $42 = HEAP32[$16>>2]|0;
 $43 = (($invocation) + 12|0);
 HEAP32[$43>>2] = $42;
 $44 = (($receiver) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($invocation) + 16|0);
 HEAP32[$46>>2] = $45;
 $47 = (($invocation) + 32|0);
 $48 = HEAP32[$data>>2]|0;
 if ((($48|0) == 100000)) {
  $49 = (($data) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  __ZN18ScriptingArguments6AddIntEi($47,$50);
 } else if ((($48|0) == 100007)) {
  $64 = (__Z13GetIPhysics2Dv()|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($65) + 16|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($data) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (FUNCTION_TABLE_iii[$67 & 4095]($64,$69)|0);
  __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($47,$70);
 } else if ((($48|0) == 100002)) {
  $51 = (($data) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (Math_fround(($52|0)));
  __ZN18ScriptingArguments8AddFloatEf($47,$53);
 } else if ((($48|0) == 100004)) {
  $57 = (__Z11GetIPhysicsv()|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + 20|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($data) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_iii[$60 & 4095]($57,$62)|0);
  __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($47,$63);
 } else if ((($48|0) == 100003)) {
  $71 = (($data) + 8|0);
  $72 = HEAP32[$71>>2]|0;
  __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($47,$72);
  $73 = ($72|0)==(0|0);
  if (!($73)) {
   $74 = $28 & 255;
   $75 = $0;
   $76 = $75;
   HEAP32[$76>>2] = $25;
   $77 = (($75) + 4)|0;
   $78 = $77;
   HEAP32[$78>>2] = $74;
   ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   $79 = (__Z37scripting_method_get_nth_argumenttype21ScriptingMethodIl2Cppi($tmpcast1$i$byval_copy,0)|0);
   $80 = ($79|0)==(0|0);
   if (!($80)) {
    $81 = (__Z25scripting_class_from_typeP13ScriptingType($79)|0);
    $82 = ($81|0)==(0|0);
    if (!($82)) {
     $83 = (__Z26scripting_object_get_classP15ScriptingObject($72)|0);
     $84 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($83,$81)|0);
     if (!($84)) {
      $85 = $1;
      $86 = $85;
      HEAP32[$86>>2] = $25;
      $87 = (($85) + 4)|0;
      $88 = $87;
      HEAP32[$88>>2] = $74;
      ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
      $89 = (__Z25scripting_method_get_name21ScriptingMethodIl2Cpp($tmpcast1$i$byval_copy)|0);
      $90 = (__Z24scripting_class_get_nameP14ScriptingClass($81)|0);
      $91 = (__Z24scripting_class_get_nameP14ScriptingClass($83)|0);
      HEAP32[$tmpcast1$i$byval_copy>>2] = $89;
      $vararg_ptr1 = (($tmpcast1$i$byval_copy) + 4|0);
      HEAP32[$vararg_ptr1>>2] = $90;
      $vararg_ptr2 = (($tmpcast1$i$byval_copy) + 8|0);
      HEAP32[$vararg_ptr2>>2] = $91;
      __Z6FormatPKcz($message$i,632880,$tmpcast1$i$byval_copy);
      $92 = ($receiver|0)==(0|0);
      if ($92) {
       $101 = 0;
      } else {
       $93 = HEAP32[$44>>2]|0;
       $101 = $93;
      }
      $94 = HEAP8[$message$i>>0]|0;
      $95 = $94 & 1;
      $96 = ($95<<24>>24)==(0);
      if ($96) {
       $99 = (($message$i) + 1|0);
       $100 = $99;
      } else {
       $97 = (($message$i) + 8|0);
       $98 = HEAP32[$97>>2]|0;
       $100 = $98;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($100|0),0,(632120|0),1178,1,($101|0),0,(0|0));
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       $109 = ___cxa_find_matching_catch()|0;
       $110 = tempRet0;
       $111 = HEAP8[$message$i>>0]|0;
       $112 = $111 & 1;
       $113 = ($112<<24>>24)==(0);
       if ($113) {
        ___resumeException($109|0);
        // unreachable;
       }
       $114 = (($message$i) + 8|0);
       $115 = HEAP32[$114>>2]|0;
       __ZdlPv($115);
       ___resumeException($109|0);
       // unreachable;
      } else {
       $104 = HEAP8[$message$i>>0]|0;
       $105 = $104 & 1;
       $106 = ($105<<24>>24)==(0);
       if ($106) {
        STACKTOP = sp;return;
       }
       $107 = (($message$i) + 8|0);
       $108 = HEAP32[$107>>2]|0;
       __ZdlPv($108);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } else if ((($48|0) == 100001)) {
  $54 = (($data) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)!=(0);
  __ZN18ScriptingArguments10AddBooleanEb($47,$56);
 } else if (!((($48|0) == 0))) {
  $116 = (($data) + 4|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = (__ZN9Scripting19ScriptingWrapperForEP6Object($117)|0);
  __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($47,$118);
 }
 HEAP32[$exception>>2] = 0;
 $119 = (__ZN19ScriptingInvocation6InvokeEPP18ScriptingException($invocation,$exception)|0);
 $120 = HEAP32[$exception>>2]|0;
 $121 = ($120|0)!=(0|0);
 $122 = ($119|0)==(0|0);
 $or$cond = $121 | $122;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $123 = (__Z14GetMonoManagerv()|0);
 $124 = (($123) + 140|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = $28 & 255;
 $127 = $0;
 $128 = $127;
 HEAP32[$128>>2] = $25;
 $129 = (($127) + 4)|0;
 $130 = $129;
 HEAP32[$130>>2] = $126;
 ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $131 = (__Z31scripting_method_get_returntype21ScriptingMethodIl2Cpp($tmpcast1$i$byval_copy)|0);
 $132 = (__Z25scripting_class_from_typeP13ScriptingType($131)|0);
 $133 = ($132|0)==($125|0);
 if (!($133)) {
  STACKTOP = sp;return;
 }
 $134 = $2;
 $135 = $134;
 HEAP32[$135>>2] = $25;
 $136 = (($134) + 4)|0;
 $137 = $136;
 HEAP32[$137>>2] = $28;
 ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 (__ZN13MonoBehaviour15CreateCoroutineEP15ScriptingObject21ScriptingMethodIl2Cpp($receiver,$119,$tmpcast1$i$byval_copy)|0);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour22CanHandleNotificationsEPviR11MessageData($receiver,$messageIndex,$data) {
 $receiver = $receiver|0;
 $messageIndex = $messageIndex|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($receiver) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $9 = 0;
  STACKTOP = sp;return ($9|0);
 }
 $3 = (($messageIndex) + 26)|0;
 $4 = (($receiver) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($3<<3)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)!=(0|0);
 $9 = $8;
 STACKTOP = sp;return ($9|0);
}
function __ZN13MonoBehaviour26CalculateSupportedMessagesEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mask$1 = 0, $mask$1$ = 0, $mask$3 = 0, $mask$3$ = 0;
 var $mask$5 = 0, $mask$5$ = 0, $mask$7 = 0, $mask$7$ = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[((563664 + 8|0))>>2]|0;
 $4 = (($3) + 26)|0;
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<3)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 $$ = $9 ? 0 : 2;
 $10 = HEAP32[((563712 + 8|0))>>2]|0;
 $11 = (($10) + 26)|0;
 $12 = (($6) + ($11<<3)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 $mask$1 = $14 ? $$ : 2;
 $15 = HEAP32[((563752 + 8|0))>>2]|0;
 $16 = (($15) + 26)|0;
 $17 = (($6) + ($16<<3)|0);
 $18 = HEAP32[$17>>2]|0;
 $not$ = ($18|0)!=(0|0);
 $19 = $not$&1;
 $mask$1$ = $19 | $mask$1;
 $20 = HEAP32[((564776 + 8|0))>>2]|0;
 $21 = (($20) + 26)|0;
 $22 = (($6) + ($21<<3)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 $25 = $mask$1$ | 16;
 $mask$3 = $24 ? $mask$1$ : $25;
 $26 = HEAP32[((564992 + 8|0))>>2]|0;
 $27 = (($26) + 26)|0;
 $28 = (($6) + ($27<<3)|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 $31 = $mask$3 | 64;
 $mask$3$ = $30 ? $mask$3 : $31;
 $32 = HEAP32[((565080 + 8|0))>>2]|0;
 $33 = (($32) + 26)|0;
 $34 = (($6) + ($33<<3)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0|0);
 $37 = $mask$3$ | 128;
 $mask$5 = $36 ? $mask$3$ : $37;
 $38 = HEAP32[((563792 + 8|0))>>2]|0;
 $39 = (($38) + 26)|0;
 $40 = (($6) + ($39<<3)|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 $43 = $mask$5 | 256;
 $mask$5$ = $42 ? $mask$5 : $43;
 $44 = HEAP32[((563840 + 8|0))>>2]|0;
 $45 = (($44) + 26)|0;
 $46 = (($6) + ($45<<3)|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 $mask$7 = $48 ? $mask$5$ : $43;
 $49 = HEAP32[((563888 + 8|0))>>2]|0;
 $50 = (($49) + 26)|0;
 $51 = (($6) + ($50<<3)|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0|0);
 $mask$7$ = $53 ? $mask$7 : $43;
 $$0 = $mask$7$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13MonoBehaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$off$i$i = 0, $$off0 = 0, $$off031 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $invocation$i$i = 0, $invocation$i6 = 0, $phitmp$i = 0, $phitmp$i16 = 0, $phitmp$i26 = 0, $phitmp$i9 = 0;
 var $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $tmpcast$i$byval_copy = sp + 248|0;
 $invocation$i$i = sp;
 $0 = sp + 200|0;
 $invocation$i6 = sp + 216|0;
 $1 = sp + 208|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZN5Unity10GameObject25SetSupportedMessagesDirtyEv($3);
 }
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
  STACKTOP = sp;return;
 }
 $8 = $awakeMode & 16;
 $9 = ($8|0)==(0);
 do {
  if (!($9)) {
   $10 = HEAP32[$2>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = (__ZNK5Unity10GameObject8IsActiveEv($10)|0);
    if ($12) {
     $13 = (($this) + 48|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0|0);
     if (!($15)) {
      $16 = (($14) + 32|0);
      $17 = HEAP8[$16>>0]|0;
      $18 = ($17<<24>>24)==(0);
      if (!($18)) {
       $19 = (($14) + 33|0);
       $20 = HEAP8[$19>>0]|0;
       $21 = ($20<<24>>24)==(0);
       if ($21) {
        $22 = (($this) + 8|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = $23 & 1048576;
        $phitmp$i = ($24|0)==(0);
        if (!($phitmp$i)) {
         break;
        }
       }
      }
     }
     $25 = (($this) + 52|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($26) + 144|0);
     $28 = $27;
     $29 = $28;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + 4)|0;
     $32 = $31;
     $33 = HEAP32[$32>>2]|0;
     $34 = ($30|0)==(0);
     if (!($34)) {
      $35 = HEAP32[$2>>2]|0;
      $36 = ($35|0)==(0|0);
      if (!($36)) {
       $37 = (__ZNK5Unity10GameObject8IsActiveEv($35)|0);
       if ($37) {
        $38 = $1;
        $39 = $38;
        HEAP32[$39>>2] = $30;
        $40 = (($38) + 4)|0;
        $41 = $40;
        HEAP32[$41>>2] = $33;
        ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
        __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation$i6,$tmpcast$i$byval_copy);
        $42 = (($this) + 4|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = (($invocation$i6) + 16|0);
        HEAP32[$44>>2] = $43;
        $45 = HEAP32[$5>>2]|0;
        $46 = (($invocation$i6) + 12|0);
        HEAP32[$46>>2] = $45;
        (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation$i6)|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $47 = (($this) + 48|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  label = 20;
 } else {
  $50 = (($48) + 32|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = ($51<<24>>24)==(0);
  if ($52) {
   label = 20;
  } else {
   $53 = (($48) + 33|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = ($54<<24>>24)==(0);
   if ($55) {
    $56 = (($this) + 8|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = $57 & 1048576;
    $phitmp$i9 = ($58|0)==(0);
    if ($phitmp$i9) {
     label = 20;
    } else {
     $66 = $48;
    }
   } else {
    label = 20;
   }
  }
 }
 do {
  if ((label|0) == 20) {
   $59 = (($this) + 28|0);
   $60 = HEAP8[$59>>0]|0;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    $66 = $48;
   } else {
    $62 = HEAP32[$2>>2]|0;
    $63 = ($62|0)==(0|0);
    if ($63) {
     $66 = $48;
    } else {
     $64 = (__ZNK5Unity10GameObject8IsActiveEv($62)|0);
     if (!($64)) {
      $$pre = HEAP32[$47>>2]|0;
      $66 = $$pre;
      break;
     }
     __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $65 = ($66|0)==(0|0);
 if ($65) {
  label = 30;
 } else {
  $67 = (($66) + 32|0);
  $68 = HEAP8[$67>>0]|0;
  $69 = ($68<<24>>24)==(0);
  if ($69) {
   label = 30;
  } else {
   $70 = (($66) + 33|0);
   $71 = HEAP8[$70>>0]|0;
   $72 = ($71<<24>>24)==(0);
   if ($72) {
    $73 = (($this) + 8|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = $74 & 1048576;
    $phitmp$i16 = ($75|0)==(0);
    if ($phitmp$i16) {
     label = 30;
    } else {
     $$pre33 = (($this) + 128|0);
     $$pre$phiZ2D = $$pre33;$98 = 0;
    }
   } else {
    label = 30;
   }
  }
 }
 if ((label|0) == 30) {
  $76 = (($this) + 128|0);
  $77 = HEAP8[$76>>0]|0;
  $78 = ($77<<24>>24)==(0);
  if ($78) {
   $79 = HEAP32[$2>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    $$pre$phiZ2D = $76;$98 = 0;
   } else {
    $81 = (__ZNK5Unity10GameObject8IsActiveEv($79)|0);
    $$pre$phiZ2D = $76;$98 = $81;
   }
  } else {
   $$pre$phiZ2D = $76;$98 = 0;
  }
 }
 $82 = HEAP8[$$pre$phiZ2D>>0]|0;
 $83 = ($82<<24>>24)==(0);
 do {
  if ($83) {
   $84 = HEAP32[$47>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $$off0 = 0;
    label = 39;
   } else {
    $86 = (($84) + 32|0);
    $87 = HEAP8[$86>>0]|0;
    $88 = ($87<<24>>24)==(0);
    if ($88) {
     $95 = (($84) + 24|0);
     $96 = HEAP32[$95>>2]|0;
     $$off$i$i = (($96) + -1)|0;
     $97 = ($$off$i$i>>>0)<(2);
     $$off0 = $97;
     label = 39;
     break;
    }
    $89 = (($84) + 33|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = ($90<<24>>24)==(0);
    if ($91) {
     $92 = (($this) + 8|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = $93 & 1048576;
     $phitmp$i26 = ($94|0)==(0);
     $$off0 = $phitmp$i26;
     label = 39;
    } else {
     $$off031 = 1;
     label = 40;
    }
   }
  } else {
   $$off0 = 0;
   label = 39;
  }
 } while(0);
 if ((label|0) == 39) {
  $brmerge = $98 | $$off0;
  if ($brmerge) {
   $$off031 = $$off0;
   label = 40;
  }
 }
 if ((label|0) == 40) {
  HEAP8[$$pre$phiZ2D>>0] = 1;
  $99 = (($this) + 52|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($100) + 24|0);
  $102 = $101;
  $103 = $102;
  $104 = HEAP32[$103>>2]|0;
  $105 = (($102) + 4)|0;
  $106 = $105;
  $107 = HEAP32[$106>>2]|0;
  $108 = ($104|0)==(0);
  if (!($108)) {
   $109 = HEAP32[$5>>2]|0;
   $110 = $0;
   $111 = $110;
   HEAP32[$111>>2] = $104;
   $112 = (($110) + 4)|0;
   $113 = $112;
   HEAP32[$113>>2] = $107;
   ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i$i,$tmpcast$i$byval_copy);
   $114 = (($invocation$i$i) + 12|0);
   HEAP32[$114>>2] = $109;
   $115 = (($invocation$i$i) + 25|0);
   HEAP8[$115>>0] = 1;
   $116 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($109)|0);
   $117 = (($invocation$i$i) + 16|0);
   HEAP32[$117>>2] = $116;
   __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i$i);
   (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i$i)|0);
   $118 = (($invocation$i$i) + 28|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = ($119|0)==(0|0);
   if (!($120)) {
    $121 = HEAP32[$this>>2]|0;
    $122 = (($121) + 120|0);
    $123 = HEAP32[$122>>2]|0;
    FUNCTION_TABLE_vii[$123 & 4095]($this,0);
   }
  }
  $124 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($6)|0);
  $125 = ($124|0)==(0|0);
  if ($125) {
   STACKTOP = sp;return;
  }
  if ($$off031) {
   $126 = (($this) + 52|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($127) + 56|0);
   $129 = $128;
   $130 = $129;
   $131 = HEAP32[$130>>2]|0;
   $132 = (($129) + 4)|0;
   $133 = $132;
   $134 = HEAP32[$133>>2]|0;
   $135 = ($131|0)==(0);
   if (!($135)) {
    $136 = HEAP32[$5>>2]|0;
    $137 = $0;
    $138 = $137;
    HEAP32[$138>>2] = $131;
    $139 = (($137) + 4)|0;
    $140 = $139;
    HEAP32[$140>>2] = $134;
    ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
    __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i$i,$tmpcast$i$byval_copy);
    $141 = (($invocation$i$i) + 12|0);
    HEAP32[$141>>2] = $136;
    $142 = (($invocation$i$i) + 25|0);
    HEAP8[$142>>0] = 1;
    $143 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($136)|0);
    $144 = (($invocation$i$i) + 16|0);
    HEAP32[$144>>2] = $143;
    __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i$i);
    (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i$i)|0);
    $145 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($6)|0);
    $146 = ($145|0)==(0|0);
    if ($146) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour40AddExternalDependencyCallbacksToManagersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $filter = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$byval_copy = sp + 32|0;
 $0 = sp;
 $1 = sp + 8|0;
 $filter = sp + 16|0;
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 96|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  __ZN13MonoBehaviour14SetByPassOnDSPEb($this,0);
  STACKTOP = sp;return;
 }
 $7 = (($this) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($8,20)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  __ZN13MonoBehaviour14SetByPassOnDSPEb($this,0);
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$2>>2]|0;
 $12 = (($11) + 96|0);
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $0;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 $23 = (__Z19GetScriptingManagerv()|0);
 $24 = (($23) + 492|0);
 $25 = HEAP32[$24>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $26 = (__Z30scripting_method_has_attribute21ScriptingMethodIl2CppP14ScriptingClass($tmpcast1$byval_copy,$25)|0);
 $27 = HEAP32[$2>>2]|0;
 $28 = (($27) + 96|0);
 $29 = $28;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $1;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = (__Z19GetScriptingManagerv()|0);
 $40 = (($39) + 500|0);
 $41 = HEAP32[$40>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $42 = (__Z30scripting_method_has_attribute21ScriptingMethodIl2CppP14ScriptingClass($tmpcast1$byval_copy,$41)|0);
 HEAP32[$filter>>2] = $this;
 $43 = (($filter) + 4|0);
 HEAP32[$43>>2] = 1910;
 $44 = (($filter) + 8|0);
 $45 = $42&1;
 HEAP8[$44>>0] = $45;
 $46 = (($filter) + 9|0);
 $47 = $26&1;
 HEAP8[$46>>0] = $47;
 __ZN6Camera14AddImageFilterERK11ImageFilter($9,$filter);
 __ZN13MonoBehaviour14SetByPassOnDSPEb($this,0);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour31AddBehaviourCallbacksToManagersEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $46 = 0;
  } else {
   HEAP32[$0>>2] = $2;
   $4 = HEAP32[560624>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    label = 10;
   } else {
    $6 = (($4) + 36|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($4) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($7|0)==($9|0);
    do {
     if ($10) {
      $11 = (($4) + 28|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = (($4) + 32|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($12) + ($14<<3)|0);
      $31 = $15;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
      $16 = HEAP32[$pos$i$i$i$i>>2]|0;
      $17 = ($16|0)==(-1);
      $18 = (($4) + 28|0);
      $19 = HEAP32[$18>>2]|0;
      if ($17) {
       $20 = (($4) + 32|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($19) + ($21<<3)|0);
       $31 = $22;
       break;
      } else {
       $23 = (($19) + ($16<<3)|0);
       $31 = $23;
       break;
      }
     }
    } while(0);
    $24 = HEAP32[560624>>2]|0;
    $25 = (($24) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + 32|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + ($28<<3)|0);
    $30 = ($31|0)==($29|0);
    if ($30) {
     label = 10;
    } else {
     $32 = (($31) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      label = 10;
     } else {
      $temp$0$i4 = $33;
     }
    }
   }
   if ((label|0) == 10) {
    $35 = HEAP32[$1>>2]|0;
    $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
    $37 = ($36|0)==(0|0);
    if ($37) {
     $46 = 0;
     break;
    } else {
     $temp$0$i4 = $36;
    }
   }
   $38 = (($temp$0$i4) + 52|0);
   $39 = HEAP32[$38>>2]|0;
   $46 = $39;
  }
 } while(0);
 $40 = (($this) + 52|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $48 = $41;
 } else {
  $44 = (__Z19GetBehaviourManagerv()|0);
  $45 = (($this) + 64|0);
  __ZN20BaseBehaviourManager12AddBehaviourER8ListNodeI9BehaviourEi($44,$45,$46);
  $$pre = HEAP32[$40>>2]|0;
  $48 = $$pre;
 }
 $47 = (($48) + 16|0);
 $49 = HEAP32[$47>>2]|0;
 $50 = ($49|0)==(0|0);
 if ($50) {
  $54 = $48;
 } else {
  $51 = (__Z24GetFixedBehaviourManagerv()|0);
  $52 = (($this) + 76|0);
  __ZN20BaseBehaviourManager12AddBehaviourER8ListNodeI9BehaviourEi($51,$52,$46);
  $$pre1 = HEAP32[$40>>2]|0;
  $54 = $$pre1;
 }
 $53 = (($54) + 8|0);
 $55 = HEAP32[$53>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  $60 = $54;
 } else {
  $57 = (__Z23GetLateBehaviourManagerv()|0);
  $58 = (($this) + 88|0);
  __ZN20BaseBehaviourManager12AddBehaviourER8ListNodeI9BehaviourEi($57,$58,$46);
  $$pre2 = HEAP32[$40>>2]|0;
  $60 = $$pre2;
 }
 $59 = (($60) + 48|0);
 $61 = HEAP32[$59>>2]|0;
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  $63 = (__Z16GetRenderManagerv()|0);
  $64 = (($this) + 112|0);
  $65 = (($63) + 100|0);
  $66 = ($64|0)==($65|0);
  if (!($66)) {
   $67 = HEAP32[$64>>2]|0;
   $68 = ($67|0)==(0|0);
   $$pre$i$i$i = (($this) + 116|0);
   if (!($68)) {
    $69 = HEAP32[$$pre$i$i$i>>2]|0;
    $70 = (($67) + 4|0);
    HEAP32[$70>>2] = $69;
    $71 = HEAP32[$64>>2]|0;
    $72 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$72>>2] = $71;
    HEAP32[$64>>2] = 0;
    HEAP32[$$pre$i$i$i>>2] = 0;
   }
   $73 = HEAP32[$65>>2]|0;
   HEAP32[$64>>2] = $73;
   HEAP32[$$pre$i$i$i>>2] = $65;
   $74 = (($73) + 4|0);
   HEAP32[$74>>2] = $64;
   $75 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$75>>2] = $64;
  }
 }
 $76 = HEAP32[$40>>2]|0;
 $77 = (($76) + 112|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0|0);
 if ($79) {
  STACKTOP = sp;return;
 }
 $80 = (__Z13GetGUIManagerv()|0);
 $81 = (($this) + 100|0);
 __ZN10GUIManager12AddGUIScriptER8ListNodeI13MonoBehaviourE($80,$81);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour12AddToManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $invocation$i$i = 0, $phitmp$i = 0, $tmpcast1$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast1$i$byval_copy = sp + 216|0;
 $invocation$i$i = sp;
 $0 = sp + 200|0;
 $1 = sp + 208|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($6) + 32|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)==(0);
  if (!($10)) {
   $11 = (($6) + 33|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    $14 = (($this) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $15 & 1048576;
    $phitmp$i = ($16|0)==(0);
    if (!($phitmp$i)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = (($this) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 80|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $22 = (($18) + 88|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  $25 = ($this|0)==(0|0);
  if ($25) {
   HEAP32[$1>>2] = 0;
  } else {
   $26 = (($this) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
  }
  __Z11CallDelayedPFvP6ObjectPvE4PPtrIS_EfS1_fPFvS1_EN18DelayedCallManager15DelayedCallModeE(3210,$1,Math_fround(-10.0),0,Math_fround(0.0),0,7);
 }
 __ZN13MonoBehaviour31AddBehaviourCallbacksToManagersEv($this);
 $28 = (($this) + 128|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if ($30) {
  HEAP8[$28>>0] = 1;
  $31 = HEAP32[$17>>2]|0;
  $32 = (($31) + 24|0);
  $33 = $32;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + 4)|0;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = ($35|0)==(0);
  if (!($39)) {
   $40 = HEAP32[$2>>2]|0;
   $41 = $0;
   $42 = $41;
   HEAP32[$42>>2] = $35;
   $43 = (($41) + 4)|0;
   $44 = $43;
   HEAP32[$44>>2] = $38;
   ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i$i,$tmpcast1$i$byval_copy);
   $45 = (($invocation$i$i) + 12|0);
   HEAP32[$45>>2] = $40;
   $46 = (($invocation$i$i) + 25|0);
   HEAP8[$46>>0] = 1;
   $47 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($40)|0);
   $48 = (($invocation$i$i) + 16|0);
   HEAP32[$48>>2] = $47;
   __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($invocation$i$i);
   (__ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($invocation$i$i)|0);
   $49 = (($invocation$i$i) + 28|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if (!($51)) {
    $52 = HEAP32[$this>>2]|0;
    $53 = (($52) + 120|0);
    $54 = HEAP32[$53>>2]|0;
    FUNCTION_TABLE_vii[$54 & 4095]($this,0);
   }
  }
  $55 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($3)|0);
  $56 = ($55|0)==(0|0);
  if ($56) {
   STACKTOP = sp;return;
  }
  $57 = (($this) + 28|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = ($58<<24>>24)==(0);
  if ($59) {
   STACKTOP = sp;return;
  }
 }
 $60 = HEAP32[$17>>2]|0;
 $61 = (($60) + 56|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0|0);
 if (!($63)) {
  $64 = (($60) + 56|0);
  $65 = $64;
  $66 = $65;
  $67 = HEAP32[$66>>2]|0;
  $68 = (($65) + 4)|0;
  $69 = $68;
  $70 = HEAP32[$69>>2]|0;
  $71 = ($67|0)==(0);
  if (!($71)) {
   $72 = (($this) + 24|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0|0);
   if (!($74)) {
    $75 = (__ZNK5Unity10GameObject8IsActiveEv($73)|0);
    if ($75) {
     $76 = $0;
     $77 = $76;
     HEAP32[$77>>2] = $67;
     $78 = (($76) + 4)|0;
     $79 = $78;
     HEAP32[$79>>2] = $70;
     ;HEAP32[$tmpcast1$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast1$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($invocation$i$i,$tmpcast1$i$byval_copy);
     $80 = (($this) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($invocation$i$i) + 16|0);
     HEAP32[$82>>2] = $81;
     $83 = HEAP32[$2>>2]|0;
     $84 = (($invocation$i$i) + 12|0);
     HEAP32[$84>>2] = $83;
     (__ZN25ScriptingInvocationNoArgs6InvokeEv($invocation$i$i)|0);
    }
   }
  }
  $85 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($3)|0);
  $86 = ($85|0)==(0|0);
  if ($86) {
   STACKTOP = sp;return;
  }
  $87 = (($this) + 28|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = ($88<<24>>24)==(0);
  if ($89) {
   STACKTOP = sp;return;
  }
 }
 __ZN13MonoBehaviour40AddExternalDependencyCallbacksToManagersEv($this);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour10DeactivateEN5Unity19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MonoBehaviour17StopAllCoroutinesEv($this);
 __ZN9Behaviour10DeactivateEN5Unity19DeactivateOperationE($this,$operation);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour19RebuildMonoInstanceEP14ScriptingClassP15ScriptingObjectP10MonoScript($this,$klass,$instance,$script) {
 $this = $this|0;
 $klass = $klass|0;
 $instance = $instance|0;
 $script = $script|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $exception = 0, $fullClassName = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy3 = sp;
 $0 = sp + 76|0;
 $1 = sp + 72|0;
 $2 = sp + 68|0;
 $3 = sp + 56|0;
 $4 = sp + 80|0;
 $5 = sp + 28|0;
 $fullClassName = sp + 16|0;
 $6 = sp + 4|0;
 $exception = sp + 40|0;
 $7 = sp + 44|0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$this>>2]|0;
  $12 = (($11) + 56|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($this,0);
 }
 $14 = (($this) + 52|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  __ZNK15MonoScriptCache7ReleaseEv($16);
  HEAP32[$15>>2] = 0;
 }
 $18 = ($script|0)==(0|0);
 do {
  if ($18) {
   $24 = ($klass|0)==(0|0);
   if ($24) {
    $26 = (__Z27FindOrCreateMonoScriptCacheP14ScriptingClass22InitScriptingCacheTypeP6Object(0,2,$this)|0);
    HEAP32[$15>>2] = $26;
    $27 = $26;
    break;
   } else {
    $25 = (__Z27FindOrCreateMonoScriptCacheP14ScriptingClass22InitScriptingCacheTypeP6Object($klass,2,$this)|0);
    HEAP32[$15>>2] = $25;
    $27 = $25;
    break;
   }
  } else {
   $19 = (($script) + 112|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20&255;
   $22 = (__ZN10MonoScript8GetClassEv($script)|0);
   $23 = (__Z27FindOrCreateMonoScriptCacheP14ScriptingClass22InitScriptingCacheTypeP6Object($22,$21,$this)|0);
   HEAP32[$15>>2] = $23;
   $27 = $23;
  }
 } while(0);
 __ZNK15MonoScriptCache6RetainEv($27);
 $28 = HEAP32[$15>>2]|0;
 $29 = (($28) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (__Z14IsWorldPlayingv()|0);
 L14: do {
  if ($31) {
   $32 = (__Z17IsValidScriptType14MonoScriptType($30)|0);
   if (!($32)) {
    __ZN13MonoBehaviour22GetScriptFullClassNameEv($5,$this);
    $33 = HEAP8[$5>>0]|0;
    $34 = $33 & 1;
    $35 = ($34<<24>>24)==(0);
    if ($35) {
     $36 = (($5) + 1|0);
     $37 = $33&255;
     $38 = $37 >>> 1;
     $47 = $38;$59 = $36;
     label = 17;
    } else {
     $39 = (($5) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($5) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42>>>0)>(4294967279);
     if ($43) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 35;
      } else {
       // unreachable;
      }
     } else {
      $47 = $42;$59 = $40;
      label = 17;
     }
    }
    do {
     if ((label|0) == 17) {
      $46 = ($47>>>0)<(11);
      if ($46) {
       $48 = $47 << 1;
       $49 = $48&255;
       HEAP8[$4>>0] = $49;
       $50 = (($4) + 1|0);
       $__p$0$i$i$i$i = $50;
      } else {
       $51 = (($47) + 16)|0;
       $52 = $51 & -16;
       __THREW__ = 0;
       $53 = (invoke_ii(2988,($52|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 35;
        break;
       }
       $56 = (($4) + 8|0);
       HEAP32[$56>>2] = $53;
       $57 = $52 | 1;
       HEAP32[$4>>2] = $57;
       $58 = (($4) + 4|0);
       HEAP32[$58>>2] = $47;
       $__p$0$i$i$i$i = $53;
      }
      _memcpy(($__p$0$i$i$i$i|0),($59|0),($47|0))|0;
      $60 = (($__p$0$i$i$i$i) + ($47)|0);
      HEAP8[$60>>0] = 0;
      __THREW__ = 0;
      invoke_viii(1911,($3|0),($30|0),($4|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      do {
       if ($62) {
        $97 = ___cxa_find_matching_catch()|0;
        $98 = tempRet0;
        $$0 = $97;$$01 = $98;
       } else {
        $63 = ($this|0)==(0|0);
        if ($63) {
         $73 = 0;
        } else {
         $64 = (($this) + 4|0);
         $65 = HEAP32[$64>>2]|0;
         $73 = $65;
        }
        $66 = HEAP8[$3>>0]|0;
        $67 = $66 & 1;
        $68 = ($67<<24>>24)==(0);
        if ($68) {
         $71 = (($3) + 1|0);
         $72 = $71;
        } else {
         $69 = (($3) + 8|0);
         $70 = HEAP32[$69>>2]|0;
         $72 = $70;
        }
        __THREW__ = 0;
        invoke_viiiiiiii(21,($72|0),0,(632120|0),1506,512,($73|0),0,(0|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         $99 = ___cxa_find_matching_catch()|0;
         $100 = tempRet0;
         $101 = HEAP8[$3>>0]|0;
         $102 = $101 & 1;
         $103 = ($102<<24>>24)==(0);
         if ($103) {
          $$0 = $99;$$01 = $100;
          break;
         }
         $104 = (($3) + 8|0);
         $105 = HEAP32[$104>>2]|0;
         __ZdlPv($105);
         $$0 = $99;$$01 = $100;
         break;
        }
        $76 = HEAP8[$3>>0]|0;
        $77 = $76 & 1;
        $78 = ($77<<24>>24)==(0);
        if (!($78)) {
         $79 = (($3) + 8|0);
         $80 = HEAP32[$79>>2]|0;
         __ZdlPv($80);
        }
        $81 = HEAP8[$4>>0]|0;
        $82 = $81 & 1;
        $83 = ($82<<24>>24)==(0);
        if (!($83)) {
         $84 = (($4) + 8|0);
         $85 = HEAP32[$84>>2]|0;
         __ZdlPv($85);
        }
        $86 = HEAP8[$5>>0]|0;
        $87 = $86 & 1;
        $88 = ($87<<24>>24)==(0);
        if ($88) {
         break L14;
        }
        $89 = (($5) + 8|0);
        $90 = HEAP32[$89>>2]|0;
        HEAP32[$2>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($90|0),($$byval_copy3|0));
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if (!($92)) {
         break L14;
        }
        $93 = ___cxa_find_matching_catch()|0;
        $94 = tempRet0;
        ___cxa_call_unexpected(($93|0));
        // unreachable;
       }
      } while(0);
      $106 = HEAP8[$4>>0]|0;
      $107 = $106 & 1;
      $108 = ($107<<24>>24)==(0);
      if ($108) {
       $$1 = $$0;$$12 = $$01;
      } else {
       $109 = (($4) + 8|0);
       $110 = HEAP32[$109>>2]|0;
       __ZdlPv($110);
       $$1 = $$0;$$12 = $$01;
      }
     }
    } while(0);
    if ((label|0) == 35) {
     $95 = ___cxa_find_matching_catch()|0;
     $96 = tempRet0;
     $$1 = $95;$$12 = $96;
    }
    $111 = HEAP8[$5>>0]|0;
    $112 = $111 & 1;
    $113 = ($112<<24>>24)==(0);
    if ($113) {
     $$3 = $$1;$$34 = $$12;
     ___resumeException($$3|0);
     // unreachable;
    }
    $114 = (($5) + 8|0);
    $115 = HEAP32[$114>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($115|0),($$byval_copy3|0));
    $116 = __THREW__; __THREW__ = 0;
    $117 = $116&1;
    if ($117) {
     $118 = ___cxa_find_matching_catch()|0;
     $119 = tempRet0;
     ___cxa_call_unexpected(($118|0));
     // unreachable;
    } else {
     $$3 = $$1;$$34 = $$12;
     ___resumeException($$3|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $120 = (__Z17IsValidScriptType14MonoScriptType($30)|0);
 if (!($120)) {
  STACKTOP = sp;return;
 }
 $121 = HEAP32[$15>>2]|0;
 $122 = (($121) + 8|0);
 $123 = HEAP32[$122>>2]|0;
 HEAP32[$14>>2] = $123;
 $124 = ($instance|0)==(0|0);
 if (!($124)) {
  (__ZN9Scripting31ConnectScriptingWrapperToObjectEP15ScriptingObjectP6Object($instance,$this)|0);
  STACKTOP = sp;return;
 }
 $125 = (($121) + 4|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (__Z20scripting_object_newP14ScriptingClass($126)|0);
 $128 = ($127|0)==(0|0);
 if (!($128)) {
  (__ZN9Scripting31ConnectScriptingWrapperToObjectEP15ScriptingObjectP6Object($127,$this)|0);
  $184 = HEAP32[632568>>2]|0;
  $185 = $184;
  $186 = (($185) + 1)|0;
  $187 = $186;
  HEAP32[632568>>2] = $187;
  HEAP32[$exception>>2] = 0;
  $188 = HEAP32[$8>>2]|0;
  __Z43scripting_object_invoke_default_constructorP15ScriptingObjectPP18ScriptingException($188,$exception);
  HEAP32[632568>>2] = $184;
  $189 = HEAP32[$exception>>2]|0;
  $190 = ($189|0)==(0|0);
  if ($190) {
   STACKTOP = sp;return;
  }
  $191 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($127)|0);
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  __THREW__ = 0;
  invoke_viii(1731,($189|0),($191|0),($7|0));
  $192 = __THREW__; __THREW__ = 0;
  $193 = $192&1;
  if ($193) {
   $199 = ___cxa_find_matching_catch()|0;
   $200 = tempRet0;
   $201 = HEAP8[$7>>0]|0;
   $202 = $201 & 1;
   $203 = ($202<<24>>24)==(0);
   if ($203) {
    $$3 = $199;$$34 = $200;
    ___resumeException($$3|0);
    // unreachable;
   }
   $204 = (($7) + 8|0);
   $205 = HEAP32[$204>>2]|0;
   __ZdlPv($205);
   $$3 = $199;$$34 = $200;
   ___resumeException($$3|0);
   // unreachable;
  } else {
   $194 = HEAP8[$7>>0]|0;
   $195 = $194 & 1;
   $196 = ($195<<24>>24)==(0);
   if ($196) {
    STACKTOP = sp;return;
   }
   $197 = (($7) + 8|0);
   $198 = HEAP32[$197>>2]|0;
   __ZdlPv($198);
   STACKTOP = sp;return;
  }
 }
 $129 = (__Z14IsWorldPlayingv()|0);
 if (!($129)) {
  STACKTOP = sp;return;
 }
 __ZN13MonoBehaviour22GetScriptFullClassNameEv($fullClassName,$this);
 $130 = HEAP8[$fullClassName>>0]|0;
 $131 = $130 & 1;
 $132 = ($131<<24>>24)==(0);
 if ($132) {
  $135 = (($fullClassName) + 1|0);
  $136 = $135;
 } else {
  $133 = (($fullClassName) + 8|0);
  $134 = HEAP32[$133>>2]|0;
  $136 = $134;
 }
 __THREW__ = 0;
 HEAP32[$$byval_copy3>>2] = $136;
 invoke_viii(1617,($6|0),(632576|0),($$byval_copy3|0));
 $137 = __THREW__; __THREW__ = 0;
 $138 = $137&1;
 do {
  if ($138) {
   $166 = ___cxa_find_matching_catch()|0;
   $167 = tempRet0;
   $$2 = $166;$$23 = $167;
  } else {
   $139 = ($this|0)==(0|0);
   if ($139) {
    $149 = 0;
   } else {
    $140 = (($this) + 4|0);
    $141 = HEAP32[$140>>2]|0;
    $149 = $141;
   }
   $142 = HEAP8[$6>>0]|0;
   $143 = $142 & 1;
   $144 = ($143<<24>>24)==(0);
   if ($144) {
    $147 = (($6) + 1|0);
    $148 = $147;
   } else {
    $145 = (($6) + 8|0);
    $146 = HEAP32[$145>>2]|0;
    $148 = $146;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($148|0),0,(632120|0),1530,512,($149|0),0,(0|0));
   $150 = __THREW__; __THREW__ = 0;
   $151 = $150&1;
   if ($151) {
    $168 = ___cxa_find_matching_catch()|0;
    $169 = tempRet0;
    $170 = HEAP8[$6>>0]|0;
    $171 = $170 & 1;
    $172 = ($171<<24>>24)==(0);
    if ($172) {
     $$2 = $168;$$23 = $169;
     break;
    }
    $173 = (($6) + 8|0);
    $174 = HEAP32[$173>>2]|0;
    __ZdlPv($174);
    $$2 = $168;$$23 = $169;
    break;
   }
   $152 = HEAP8[$6>>0]|0;
   $153 = $152 & 1;
   $154 = ($153<<24>>24)==(0);
   if (!($154)) {
    $155 = (($6) + 8|0);
    $156 = HEAP32[$155>>2]|0;
    __ZdlPv($156);
   }
   $157 = HEAP8[$fullClassName>>0]|0;
   $158 = $157 & 1;
   $159 = ($158<<24>>24)==(0);
   if ($159) {
    STACKTOP = sp;return;
   }
   $160 = (($fullClassName) + 8|0);
   $161 = HEAP32[$160>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($161|0),($$byval_copy3|0));
   $162 = __THREW__; __THREW__ = 0;
   $163 = $162&1;
   if ($163) {
    $164 = ___cxa_find_matching_catch()|0;
    $165 = tempRet0;
    ___cxa_call_unexpected(($164|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $175 = HEAP8[$fullClassName>>0]|0;
 $176 = $175 & 1;
 $177 = ($176<<24>>24)==(0);
 if ($177) {
  $$3 = $$2;$$34 = $$23;
  ___resumeException($$3|0);
  // unreachable;
 }
 $178 = (($fullClassName) + 8|0);
 $179 = HEAP32[$178>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($179|0),($$byval_copy3|0));
 $180 = __THREW__; __THREW__ = 0;
 $181 = $180&1;
 if ($181) {
  $182 = ___cxa_find_matching_catch()|0;
  $183 = tempRet0;
  ___cxa_call_unexpected(($182|0));
  // unreachable;
 } else {
  $$3 = $$2;$$34 = $$23;
  ___resumeException($$3|0);
  // unreachable;
 }
}
function __ZN13MonoBehaviour22GetScriptFullClassNameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy11 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i12 = 0, $__p$0$i$i$i$i18 = 0, $__p$0$i$i$i$i7 = 0, $klass = 0, $ns = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy11 = sp + 76|0;
 $0 = sp + 72|0;
 $1 = sp + 68|0;
 $2 = sp + 64|0;
 $3 = sp + 60|0;
 $4 = sp + 56|0;
 $5 = sp + 52|0;
 $6 = sp + 36|0;
 $ns = sp + 24|0;
 $klass = sp + 12|0;
 $7 = sp;
 $8 = sp + 40|0;
 $9 = (($this) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__ZN6Object21IDToPointerThreadSafeEi($10)|0);
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = (($11) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 >>> 21;
  $16 = HEAP32[560640>>2]|0;
  $17 = Math_imul($16, $15)|0;
  $18 = (($17) + 115)|0;
  $19 = $18 >> 5;
  $20 = $19 << 5;
  $21 = (($18) - ($20))|0;
  $22 = HEAP32[560632>>2]|0;
  $23 = (($22) + ($19<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = 1 << $21;
  $26 = $25 & $24;
  $27 = ($26|0)==(0);
  if (!($27)) {
   __ZNK10MonoScript22GetScriptFullClassNameEv($agg$result,$11);
   STACKTOP = sp;return;
  }
 }
 $28 = (($this) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (($29) + 4|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $34 = (__Z29scripting_class_get_namespaceP14ScriptingClass($32)|0);
   $35 = (_strlen(($34|0))|0);
   $36 = ($35>>>0)>(2147483631);
   if ($36) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $37 = ($35>>>0)<(11);
   if ($37) {
    $38 = $35 << 1;
    $39 = $38&255;
    HEAP8[$ns>>0] = $39;
    $40 = (($ns) + 1|0);
    $74 = $39;$__p$0$i$i$i$i = $40;
   } else {
    $41 = (($35) + 16)|0;
    $42 = $41 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    $43 = (__Z15malloc_internaljj10MemLabelIdiPKci($42,16,$$byval_copy11,0,632120,79)|0);
    $44 = (($ns) + 8|0);
    HEAP32[$44>>2] = $43;
    $45 = $42 | 1;
    HEAP32[$ns>>2] = $45;
    $46 = (($ns) + 4|0);
    HEAP32[$46>>2] = $35;
    $47 = $45&255;
    $74 = $47;$__p$0$i$i$i$i = $43;
   }
   _memcpy(($__p$0$i$i$i$i|0),($34|0),($35|0))|0;
   $48 = (($__p$0$i$i$i$i) + ($35)|0);
   HEAP8[$48>>0] = 0;
   $49 = HEAP32[$28>>2]|0;
   $50 = (($49) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   __THREW__ = 0;
   $52 = (invoke_ii(3284,($51|0))|0);
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   do {
    if ($54) {
     label = 35;
    } else {
     $55 = (_strlen(($52|0))|0);
     $56 = ($55>>>0)>(2147483631);
     if ($56) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 35;
       break;
      }
      // unreachable;
     }
     $59 = ($55>>>0)<(11);
     if ($59) {
      $60 = $55 << 1;
      $61 = $60&255;
      HEAP8[$klass>>0] = $61;
      $62 = (($klass) + 1|0);
      $83 = $61;$__p$0$i$i$i$i7 = $62;
     } else {
      $63 = (($55) + 16)|0;
      $64 = $63 & -16;
      HEAP32[$4>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$4+0>>2]|0;
      $65 = (invoke_iiiiiii(102,($64|0),16,($$byval_copy11|0),0,(632120|0),79)|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 35;
       break;
      }
      $68 = (($klass) + 8|0);
      HEAP32[$68>>2] = $65;
      $69 = $64 | 1;
      HEAP32[$klass>>2] = $69;
      $70 = (($klass) + 4|0);
      HEAP32[$70>>2] = $55;
      $71 = $69&255;
      $83 = $71;$__p$0$i$i$i$i7 = $65;
     }
     _memcpy(($__p$0$i$i$i$i7|0),($52|0),($55|0))|0;
     $72 = (($__p$0$i$i$i$i7) + ($55)|0);
     HEAP8[$72>>0] = 0;
     $73 = $74 & 1;
     $75 = ($73<<24>>24)==(0);
     if ($75) {
      $78 = $74&255;
      $79 = $78 >>> 1;
      $81 = $79;
     } else {
      $76 = (($ns) + 4|0);
      $77 = HEAP32[$76>>2]|0;
      $81 = $77;
     }
     $80 = ($81|0)==(0);
     L31: do {
      if ($80) {
       $82 = $83 & 1;
       $84 = ($82<<24>>24)==(0);
       if ($84) {
        $89 = (($klass) + 1|0);
        $90 = $83&255;
        $91 = $90 >>> 1;
        $108 = $89;$93 = $91;
       } else {
        $85 = (($klass) + 8|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = (($klass) + 4|0);
        $88 = HEAP32[$87>>2]|0;
        $108 = $86;$93 = $88;
       }
       $92 = ($93>>>0)>(2147483631);
       if ($92) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $94 = __THREW__; __THREW__ = 0;
        $95 = $94&1;
        if ($95) {
         label = 36;
         break;
        }
        // unreachable;
       }
       $96 = ($93>>>0)<(11);
       if ($96) {
        $97 = $93 << 1;
        $98 = $97&255;
        HEAP8[$agg$result>>0] = $98;
        $99 = (($agg$result) + 1|0);
        $__p$0$i$i$i$i12 = $99;
       } else {
        $100 = (($93) + 16)|0;
        $101 = $100 & -16;
        HEAP32[$3>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
        $102 = (invoke_iiiiiii(102,($101|0),16,($$byval_copy11|0),0,(632120|0),79)|0);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 36;
         break;
        }
        $105 = (($agg$result) + 8|0);
        HEAP32[$105>>2] = $102;
        $106 = $101 | 1;
        HEAP32[$agg$result>>2] = $106;
        $107 = (($agg$result) + 4|0);
        HEAP32[$107>>2] = $93;
        $__p$0$i$i$i$i12 = $102;
       }
       _memcpy(($__p$0$i$i$i$i12|0),($108|0),($93|0))|0;
       $109 = (($__p$0$i$i$i$i12) + ($93)|0);
       HEAP8[$109>>0] = 0;
       label = 62;
      } else {
       __THREW__ = 0;
       invoke_viii(1912,($8|0),($ns|0),(632688|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        label = 36;
       } else {
        __THREW__ = 0;
        invoke_viii(1913,($7|0),($8|0),($klass|0));
        $116 = __THREW__; __THREW__ = 0;
        $117 = $116&1;
        if ($117) {
         $164 = ___cxa_find_matching_catch()|0;
         $165 = tempRet0;
         $$0 = $165;$$01 = $164;
        } else {
         $118 = HEAP8[$7>>0]|0;
         $119 = $118 & 1;
         $120 = ($119<<24>>24)==(0);
         if ($120) {
          $125 = (($7) + 1|0);
          $126 = $118&255;
          $127 = $126 >>> 1;
          $129 = $127;$144 = $125;
         } else {
          $121 = (($7) + 8|0);
          $122 = HEAP32[$121>>2]|0;
          $123 = (($7) + 4|0);
          $124 = HEAP32[$123>>2]|0;
          $129 = $124;$144 = $122;
         }
         $128 = ($129>>>0)>(2147483631);
         do {
          if ($128) {
           __THREW__ = 0;
           invoke_vi(3309,0);
           $130 = __THREW__; __THREW__ = 0;
           $131 = $130&1;
           if (!($131)) {
            // unreachable;
           }
          } else {
           $132 = ($129>>>0)<(11);
           if ($132) {
            $133 = $129 << 1;
            $134 = $133&255;
            HEAP8[$agg$result>>0] = $134;
            $135 = (($agg$result) + 1|0);
            $__p$0$i$i$i$i18 = $135;
           } else {
            $136 = (($129) + 16)|0;
            $137 = $136 & -16;
            HEAP32[$2>>2] = 59;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
            $138 = (invoke_iiiiiii(102,($137|0),16,($$byval_copy11|0),0,(632120|0),79)|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             break;
            }
            $141 = (($agg$result) + 8|0);
            HEAP32[$141>>2] = $138;
            $142 = $137 | 1;
            HEAP32[$agg$result>>2] = $142;
            $143 = (($agg$result) + 4|0);
            HEAP32[$143>>2] = $129;
            $__p$0$i$i$i$i18 = $138;
           }
           _memcpy(($__p$0$i$i$i$i18|0),($144|0),($129|0))|0;
           $145 = (($__p$0$i$i$i$i18) + ($129)|0);
           HEAP8[$145>>0] = 0;
           $146 = HEAP8[$7>>0]|0;
           $147 = $146 & 1;
           $148 = ($147<<24>>24)==(0);
           do {
            if (!($148)) {
             $149 = (($7) + 8|0);
             $150 = HEAP32[$149>>2]|0;
             HEAP32[$3>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
             invoke_vii(2591,($150|0),($$byval_copy11|0));
             $151 = __THREW__; __THREW__ = 0;
             $152 = $151&1;
             if (!($152)) {
              break;
             }
             $153 = ___cxa_find_matching_catch()|0;
             $154 = tempRet0;
             ___cxa_call_unexpected(($153|0));
             // unreachable;
            }
           } while(0);
           $155 = HEAP8[$8>>0]|0;
           $156 = $155 & 1;
           $157 = ($156<<24>>24)==(0);
           if ($157) {
            label = 62;
            break L31;
           }
           $158 = (($8) + 8|0);
           $159 = HEAP32[$158>>2]|0;
           HEAP32[$2>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
           invoke_vii(2591,($159|0),($$byval_copy11|0));
           $160 = __THREW__; __THREW__ = 0;
           $161 = $160&1;
           if (!($161)) {
            label = 62;
            break L31;
           }
           $162 = ___cxa_find_matching_catch()|0;
           $163 = tempRet0;
           ___cxa_call_unexpected(($162|0));
           // unreachable;
          }
         } while(0);
         $166 = ___cxa_find_matching_catch()|0;
         $167 = tempRet0;
         $168 = HEAP8[$7>>0]|0;
         $169 = $168 & 1;
         $170 = ($169<<24>>24)==(0);
         if ($170) {
          $$0 = $167;$$01 = $166;
         } else {
          $171 = (($7) + 8|0);
          $172 = HEAP32[$171>>2]|0;
          HEAP32[$1>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
          invoke_vii(2591,($172|0),($$byval_copy11|0));
          $173 = __THREW__; __THREW__ = 0;
          $174 = $173&1;
          if ($174) {
           $175 = ___cxa_find_matching_catch()|0;
           $176 = tempRet0;
           ___cxa_call_unexpected(($175|0));
           // unreachable;
          } else {
           $$0 = $167;$$01 = $166;
          }
         }
        }
        $177 = HEAP8[$8>>0]|0;
        $178 = $177 & 1;
        $179 = ($178<<24>>24)==(0);
        if ($179) {
         $$1 = $$0;$$12 = $$01;
        } else {
         $180 = (($8) + 8|0);
         $181 = HEAP32[$180>>2]|0;
         HEAP32[$0>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($181|0),($$byval_copy11|0));
         $182 = __THREW__; __THREW__ = 0;
         $183 = $182&1;
         if ($183) {
          $184 = ___cxa_find_matching_catch()|0;
          $185 = tempRet0;
          ___cxa_call_unexpected(($184|0));
          // unreachable;
         } else {
          $$1 = $$0;$$12 = $$01;
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 36) {
      $112 = ___cxa_find_matching_catch()|0;
      $113 = tempRet0;
      $$1 = $113;$$12 = $112;
     }
     else if ((label|0) == 62) {
      $186 = HEAP8[$klass>>0]|0;
      $187 = $186 & 1;
      $188 = ($187<<24>>24)==(0);
      if (!($188)) {
       $189 = (($klass) + 8|0);
       $190 = HEAP32[$189>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($190|0),($$byval_copy11|0));
       $191 = __THREW__; __THREW__ = 0;
       $192 = $191&1;
       if ($192) {
        $193 = ___cxa_find_matching_catch()|0;
        $194 = tempRet0;
        ___cxa_call_unexpected(($193|0));
        // unreachable;
       }
      }
      $195 = HEAP8[$ns>>0]|0;
      $196 = $195 & 1;
      $197 = ($196<<24>>24)==(0);
      if ($197) {
       STACKTOP = sp;return;
      }
      $198 = (($ns) + 8|0);
      $199 = HEAP32[$198>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($199|0),($$byval_copy11|0));
      $200 = __THREW__; __THREW__ = 0;
      $201 = $200&1;
      if ($201) {
       $202 = ___cxa_find_matching_catch()|0;
       $203 = tempRet0;
       ___cxa_call_unexpected(($202|0));
       // unreachable;
      } else {
       STACKTOP = sp;return;
      }
     }
     $204 = HEAP8[$klass>>0]|0;
     $205 = $204 & 1;
     $206 = ($205<<24>>24)==(0);
     if ($206) {
      $$2 = $$1;$$23 = $$12;$$pre$phiZ2D = $ns;
     } else {
      $207 = (($klass) + 8|0);
      $208 = HEAP32[$207>>2]|0;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_vii(2591,($208|0),($$byval_copy11|0));
      $209 = __THREW__; __THREW__ = 0;
      $210 = $209&1;
      if ($210) {
       $211 = ___cxa_find_matching_catch()|0;
       $212 = tempRet0;
       ___cxa_call_unexpected(($211|0));
       // unreachable;
      } else {
       $$2 = $$1;$$23 = $$12;$$pre$phiZ2D = $ns;
      }
     }
    }
   } while(0);
   if ((label|0) == 35) {
    $110 = ___cxa_find_matching_catch()|0;
    $111 = tempRet0;
    $$2 = $111;$$23 = $110;$$pre$phiZ2D = $ns;
   }
   $213 = HEAP8[$$pre$phiZ2D>>0]|0;
   $214 = $213 & 1;
   $215 = ($214<<24>>24)==(0);
   if ($215) {
    ___resumeException($$23|0);
    // unreachable;
   }
   $216 = (($ns) + 8|0);
   $217 = HEAP32[$216>>2]|0;
   HEAP32[$6>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$6+0>>2]|0;
   invoke_vii(2591,($217|0),($$byval_copy11|0));
   $218 = __THREW__; __THREW__ = 0;
   $219 = $218&1;
   if ($219) {
    $220 = ___cxa_find_matching_catch()|0;
    $221 = tempRet0;
    ___cxa_call_unexpected(($220|0));
    // unreachable;
   } else {
    ___resumeException($$23|0);
    // unreachable;
   }
  }
 }
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour35RebuildMonoInstanceFromScriptChangeEP14ScriptingClassP15ScriptingObject($this,$klass,$instance) {
 $this = $this|0;
 $klass = $klass|0;
 $instance = $instance|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 29|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 128|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($this);
 }
 $7 = (($this) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $8;
  $10 = HEAP32[560624>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   label = 12;
  } else {
   $12 = (($10) + 36|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($10) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($13|0)==($15|0);
   do {
    if ($16) {
     $17 = (($10) + 28|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($10) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $37 = $21;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$10,$0);
     $22 = HEAP32[$pos$i$i$i$i>>2]|0;
     $23 = ($22|0)==(-1);
     $24 = (($10) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     if ($23) {
      $26 = (($10) + 32|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = (($25) + ($27<<3)|0);
      $37 = $28;
      break;
     } else {
      $29 = (($25) + ($22<<3)|0);
      $37 = $29;
      break;
     }
    }
   } while(0);
   $30 = HEAP32[560624>>2]|0;
   $31 = (($30) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 32|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + ($34<<3)|0);
   $36 = ($37|0)==($35|0);
   if ($36) {
    label = 12;
   } else {
    $38 = (($37) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     label = 12;
    } else {
     $temp$0$i = $39;
    }
   }
  }
  if ((label|0) == 12) {
   $41 = HEAP32[$7>>2]|0;
   $42 = (__Z31ReadObjectFromPersistentManageri($41)|0);
   $temp$0$i = $42;
  }
  $$0$i = $temp$0$i;
 }
 __ZN13MonoBehaviour19RebuildMonoInstanceEP14ScriptingClassP15ScriptingObjectP10MonoScript($this,$klass,$instance,$$0$i);
 $43 = HEAP8[$1>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$this>>2]|0;
 $46 = (($45) + 124|0);
 $47 = HEAP32[$46>>2]|0;
 FUNCTION_TABLE_vi[$47 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($this,$newScript,$instance) {
 $this = $this|0;
 $newScript = $newScript|0;
 $instance = $instance|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$newScript>>2]|0;
 $4 = ($2|0)==($3|0);
 if ($4) {
  $5 = (($this) + 48|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (($6) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    STACKTOP = sp;return;
   }
  }
  $11 = (__Z14IsWorldPlayingv()|0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
  $12 = ($this|0)==(0|0);
  if ($12) {
   $15 = 0;
  } else {
   $13 = (($this) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = $14;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(632632,0,632120,1659,512,$15,0,0);
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $3;
 $16 = HEAP32[$newScript>>2]|0;
 $17 = ($16|0)==(0);
 do {
  if ($17) {
   $53 = 0;
  } else {
   HEAP32[$0>>2] = $16;
   $18 = HEAP32[560624>>2]|0;
   $19 = ($18|0)==(0|0);
   if ($19) {
    label = 17;
   } else {
    $20 = (($18) + 36|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($18) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($21|0)==($23|0);
    do {
     if ($24) {
      $25 = (($18) + 28|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($18) + 32|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($26) + ($28<<3)|0);
      $45 = $29;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$18,$0);
      $30 = HEAP32[$pos$i$i$i$i>>2]|0;
      $31 = ($30|0)==(-1);
      $32 = (($18) + 28|0);
      $33 = HEAP32[$32>>2]|0;
      if ($31) {
       $34 = (($18) + 32|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = (($33) + ($35<<3)|0);
       $45 = $36;
       break;
      } else {
       $37 = (($33) + ($30<<3)|0);
       $45 = $37;
       break;
      }
     }
    } while(0);
    $38 = HEAP32[560624>>2]|0;
    $39 = (($38) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($38) + 32|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($40) + ($42<<3)|0);
    $44 = ($45|0)==($43|0);
    if ($44) {
     label = 17;
    } else {
     $46 = (($45) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==(0|0);
     if ($48) {
      label = 17;
     } else {
      $temp$0$i2 = $47;
     }
    }
   }
   if ((label|0) == 17) {
    $49 = HEAP32[$newScript>>2]|0;
    $50 = (__Z31ReadObjectFromPersistentManageri($49)|0);
    $51 = ($50|0)==(0|0);
    if ($51) {
     $53 = 0;
     break;
    } else {
     $temp$0$i2 = $50;
    }
   }
   $52 = (__ZN10MonoScript8GetClassEv($temp$0$i2)|0);
   $53 = $52;
  }
 } while(0);
 __ZN13MonoBehaviour35RebuildMonoInstanceFromScriptChangeEP14ScriptingClassP15ScriptingObject($this,$53,$instance);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour8SetClassEP14ScriptingClassP15ScriptingObject($this,$klass,$instance) {
 $this = $this|0;
 $klass = $klass|0;
 $instance = $instance|0;
 var $$0$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer1 = sp;
 $0 = sp + 20|0;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = ($klass|0)==(0|0);
 if ($3) {
  $4 = (($this) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = (($5) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    STACKTOP = sp;return;
   }
  }
  $10 = (__Z14IsWorldPlayingv()|0);
  if (!($10)) {
   STACKTOP = sp;return;
  }
  $11 = ($this|0)==(0|0);
  if ($11) {
   $14 = 0;
  } else {
   $12 = (($this) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(632632,0,632120,1659,512,$14,0,0);
  STACKTOP = sp;return;
 }
 $15 = (__Z19GetScriptingManagerv()|0);
 $16 = (($15) + 24|0);
 $17 = (__ZN17MonoScriptManager17FindRuntimeScriptEP14ScriptingClass($16,$klass)|0);
 $18 = ($17|0)==(0|0);
 do {
  if ($18) {
   (__Z19GetScriptingManagerv()|0);
  } else {
   $19 = (__ZNK10MonoScript13GetScriptTypeEv($17)|0);
   $20 = ($19|0)==(0);
   if (!($20)) {
    $21 = (__ZNK10MonoScript13GetScriptTypeEv($17)|0);
    $22 = ($21|0)==(1);
    if (!($22)) {
     $23 = (__ZNK10MonoScript13GetScriptTypeEv($17)|0);
     $24 = ($23|0)==(2);
     if (!($24)) {
      $25 = (__Z24scripting_class_get_nameP14ScriptingClass($klass)|0);
      HEAP32[$vararg_buffer1>>2] = $25;
      __Z6FormatPKcz($0,632696,$vararg_buffer1);
      $26 = HEAP8[$0>>0]|0;
      $27 = $26 & 1;
      $28 = ($27<<24>>24)==(0);
      if ($28) {
       $31 = (($0) + 1|0);
       $32 = $31;
      } else {
       $29 = (($0) + 8|0);
       $30 = HEAP32[$29>>2]|0;
       $32 = $30;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($32|0),0,(632120|0),1601,1,0,0,(0|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       $35 = HEAP8[$0>>0]|0;
       $36 = $35 & 1;
       $37 = ($36<<24>>24)==(0);
       if ($37) {
        break;
       }
       $38 = (($0) + 8|0);
       $39 = HEAP32[$38>>2]|0;
       __ZdlPv($39);
       break;
      }
      $40 = ___cxa_find_matching_catch()|0;
      $41 = tempRet0;
      $42 = HEAP8[$0>>0]|0;
      $43 = $42 & 1;
      $44 = ($43<<24>>24)==(0);
      if ($44) {
       $$0$i = $41;$$01$i = $40;
       ___resumeException($$01$i|0);
       // unreachable;
      }
      $45 = (($0) + 8|0);
      $46 = HEAP32[$45>>2]|0;
      __ZdlPv($46);
      $$0$i = $41;$$01$i = $40;
      ___resumeException($$01$i|0);
      // unreachable;
     }
    }
   }
   $47 = (__ZN10MonoScript8GetClassEv($17)|0);
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    $71 = (($17) + 4|0);
    $72 = HEAP32[$71>>2]|0;
    HEAP32[$2>>2] = $72;
    __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($this,$2,$instance);
    STACKTOP = sp;return;
   }
   $49 = (__Z24scripting_class_get_nameP14ScriptingClass($klass)|0);
   HEAP32[$vararg_buffer1>>2] = $49;
   __Z6FormatPKcz($1,632792,$vararg_buffer1);
   $50 = HEAP8[$1>>0]|0;
   $51 = $50 & 1;
   $52 = ($51<<24>>24)==(0);
   if ($52) {
    $55 = (($1) + 1|0);
    $56 = $55;
   } else {
    $53 = (($1) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    $56 = $54;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($56|0),0,(632120|0),1607,1,0,0,(0|0));
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if (!($58)) {
    $59 = HEAP8[$1>>0]|0;
    $60 = $59 & 1;
    $61 = ($60<<24>>24)==(0);
    if ($61) {
     break;
    }
    $62 = (($1) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    __ZdlPv($63);
    break;
   }
   $64 = ___cxa_find_matching_catch()|0;
   $65 = tempRet0;
   $66 = HEAP8[$1>>0]|0;
   $67 = $66 & 1;
   $68 = ($67<<24>>24)==(0);
   if ($68) {
    $$0$i = $65;$$01$i = $64;
    ___resumeException($$01$i|0);
    // unreachable;
   }
   $69 = (($1) + 8|0);
   $70 = HEAP32[$69>>2]|0;
   __ZdlPv($70);
   $$0$i = $65;$$01$i = $64;
   ___resumeException($$01$i|0);
   // unreachable;
  }
 } while(0);
 __ZN13MonoBehaviour35RebuildMonoInstanceFromScriptChangeEP14ScriptingClassP15ScriptingObject($this,$klass,$instance);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviour20SetScriptingDataFromERKS_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($other) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if (!($4)) {
   HEAP32[$0>>2] = $3;
   $5 = HEAP32[560624>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    label = 10;
   } else {
    $7 = (($5) + 36|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($5) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    do {
     if ($11) {
      $12 = (($5) + 28|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($5) + 32|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($13) + ($15<<3)|0);
      $32 = $16;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$0);
      $17 = HEAP32[$pos$i$i$i$i>>2]|0;
      $18 = ($17|0)==(-1);
      $19 = (($5) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      if ($18) {
       $21 = (($5) + 32|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + ($22<<3)|0);
       $32 = $23;
       break;
      } else {
       $24 = (($20) + ($17<<3)|0);
       $32 = $24;
       break;
      }
     }
    } while(0);
    $25 = HEAP32[560624>>2]|0;
    $26 = (($25) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + ($29<<3)|0);
    $31 = ($32|0)==($30|0);
    if ($31) {
     label = 10;
    } else {
     $33 = (($32) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      label = 10;
     }
    }
   }
   if ((label|0) == 10) {
    $36 = (__Z31ReadObjectFromPersistentManageri($3)|0);
    $37 = ($36|0)==(0|0);
    if ($37) {
     break;
    }
   }
   $38 = HEAP32[$2>>2]|0;
   HEAP32[$1>>2] = $38;
   __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($this,$1,0);
   STACKTOP = sp;return;
  }
 } while(0);
 $39 = (($other) + 48|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  $$0$i1 = 0;
 } else {
  $42 = (($40) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $$0$i1 = $43;
 }
 __ZN13MonoBehaviour8SetClassEP14ScriptingClassP15ScriptingObject($this,$$0$i1,0);
 STACKTOP = sp;return;
}
function __ZNK13MonoBehaviour7GetNameEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 36|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $13 = (($7) + 1|0);
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 } else {
  $11 = (($this) + 44|0);
  $12 = HEAP32[$11>>2]|0;
  $$0 = $12;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN13MonoBehaviour7SetNameEPKc($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 4095]($3,$name);
  STACKTOP = sp;return;
 }
 $8 = (_strlen(($name|0))|0);
 $9 = ($8>>>0)>(2147483631);
 if ($9) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = ($8>>>0)<(11);
 if ($10) {
  $11 = $8 << 1;
  $12 = $11&255;
  HEAP8[$1>>0] = $12;
  $13 = (($1) + 1|0);
  $__p$0$i$i$i$i = $13;
 } else {
  $14 = (($8) + 16)|0;
  $15 = $14 & -16;
  HEAP32[$0>>2] = 59;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy2,0,632120,79)|0);
  $17 = (($1) + 8|0);
  HEAP32[$17>>2] = $16;
  $18 = $15 | 1;
  HEAP32[$1>>2] = $18;
  $19 = (($1) + 4|0);
  HEAP32[$19>>2] = $8;
  $__p$0$i$i$i$i = $16;
 }
 _memcpy(($__p$0$i$i$i$i|0),($name|0),($8|0))|0;
 $20 = (($__p$0$i$i$i$i) + ($8)|0);
 HEAP8[$20>>0] = 0;
 $21 = (($this) + 36|0);
 __THREW__ = 0;
 (invoke_iii(2359,($21|0),($1|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $35 = HEAP8[$1>>0]|0;
  $36 = $35 & 1;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   ___resumeException($33|0);
   // unreachable;
  }
  $38 = (($1) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($39|0),($$byval_copy2|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   $42 = ___cxa_find_matching_catch()|0;
   $43 = tempRet0;
   ___cxa_call_unexpected(($42|0));
   // unreachable;
  } else {
   ___resumeException($33|0);
   // unreachable;
  }
 } else {
  $24 = HEAP8[$1>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   STACKTOP = sp;return;
  }
  $27 = (($1) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($28|0),($$byval_copy2|0));
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   ___cxa_call_unexpected(($31|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__1plIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEENS_12basic_stringIT_T0_T1_EERKSA_SC_($agg$result,$__lhs,$__rhs) {
 $agg$result = $agg$result|0;
 $__lhs = $__lhs|0;
 $__rhs = $__rhs|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $2 = HEAP8[$__lhs>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = $2&255;
  $8 = $7 >>> 1;
  $21 = $8;
 } else {
  $5 = (($__lhs) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $21 = $6;
 }
 $9 = HEAP8[$__rhs>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $14 = $9&255;
  $15 = $14 >>> 1;
  $20 = $15;
 } else {
  $12 = (($__rhs) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $20 = $13;
 }
 if ($4) {
  $18 = (($__lhs) + 1|0);
  $37 = $18;
 } else {
  $16 = (($__lhs) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $37 = $17;
 }
 $19 = (($20) + ($21))|0;
 $22 = ($19>>>0)>(2147483631);
 do {
  if ($22) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    // unreachable;
   }
  } else {
   $25 = ($19>>>0)<(11);
   if ($25) {
    $26 = $21 << 1;
    $27 = $26&255;
    HEAP8[$agg$result>>0] = $27;
    $28 = (($agg$result) + 1|0);
    $__p$0$i = $28;
   } else {
    $29 = (($19) + 16)|0;
    $30 = $29 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $31 = (invoke_iiiiiii(102,($30|0),16,($$byval_copy1|0),0,(632120|0),79)|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($agg$result) + 8|0);
    HEAP32[$34>>2] = $31;
    $35 = $30 | 1;
    HEAP32[$agg$result>>2] = $35;
    $36 = (($agg$result) + 4|0);
    HEAP32[$36>>2] = $21;
    $__p$0$i = $31;
   }
   _memcpy(($__p$0$i|0),($37|0),($21|0))|0;
   $38 = (($__p$0$i) + ($21)|0);
   HEAP8[$38>>0] = 0;
   $39 = HEAP8[$__rhs>>0]|0;
   $40 = $39 & 1;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $44 = (($__rhs) + 1|0);
    $45 = $44;
   } else {
    $42 = (($__rhs) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $45 = $43;
   }
   __THREW__ = 0;
   (invoke_iiii(1548,($agg$result|0),($45|0),($20|0))|0);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if (!($47)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $48 = ___cxa_find_matching_catch()|0;
 $49 = tempRet0;
 $50 = HEAP8[$agg$result>>0]|0;
 $51 = $50 & 1;
 $52 = ($51<<24>>24)==(0);
 if ($52) {
  ___resumeException($48|0);
  // unreachable;
 }
 $53 = (($agg$result) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($54|0),($$byval_copy1|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  ___cxa_call_unexpected(($57|0));
  // unreachable;
 } else {
  ___resumeException($48|0);
  // unreachable;
 }
}
function __Z20RequiredComponentsOfP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $invocation = 0, $tmpcast$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast$byval_copy = sp + 208|0;
 $invocation = sp;
 $0 = sp + 200|0;
 $1 = (__Z26scripting_class_get_objectP14ScriptingClass($klass)|0);
 $2 = (__Z14GetMonoManagerv()|0);
 $3 = (($2) + 408|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $14 = (($invocation) + 32|0);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($14,$1);
 $15 = (__ZN19ScriptingInvocation6InvokeEv($invocation)|0);
 $16 = (__Z30scripting_cast_object_to_arrayP15ScriptingObject($15)|0);
 STACKTOP = sp;return ($16|0);
}
function __Z48ResetAndApplyDefaultReferencesOnNewMonoBehaviourR13MonoBehaviour($behaviour) {
 $behaviour = $behaviour|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$behaviour>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($behaviour);
 $3 = HEAP32[$behaviour>>2]|0;
 $4 = (($3) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($behaviour);
 $6 = HEAP32[$behaviour>>2]|0;
 $7 = (($6) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095]($behaviour,4);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviourD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13MonoBehaviourD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN13MonoBehaviourD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3556,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK13MonoBehaviour25GetNeedsPerObjectTypeTreeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN13MonoBehaviourD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((631880 + 8|0));
 $1 = (($this) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if (!($3)) {
   __THREW__ = 0;
   invoke_vi(3507,($2|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __ZdlPv($2);
    break;
   }
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   __ZdlPv($2);
   $20 = (($this) + 60|0);
   HEAP32[$20>>2] = 0;
   $21 = (($this) + 56|0);
   HEAP32[$21>>2] = 0;
   $22 = (($this) + 36|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = $23 & 1;
   $25 = ($24<<24>>24)==(0);
   if (!($25)) {
    $26 = (($this) + 44|0);
    $27 = HEAP32[$26>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy1|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     $30 = ___cxa_find_matching_catch()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_vi(3410,($this|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $34 = ___cxa_find_matching_catch(0|0)|0;
    $35 = tempRet0;
    ___clang_call_terminate($34);
    // unreachable;
   } else {
    ___resumeException($18|0);
    // unreachable;
   }
  }
 } while(0);
 $6 = (($this) + 60|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 56|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 36|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  __ZN9BehaviourD2Ev($this);
  STACKTOP = sp;return;
 }
 $12 = (($this) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy1|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  ___cxa_call_unexpected(($16|0));
  // unreachable;
 } else {
  __ZN9BehaviourD2Ev($this);
  STACKTOP = sp;return;
 }
}
function __ZN17MonoScriptManager17FindRuntimeScriptERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$className) {
 $this = $this|0;
 $className = $className|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $filter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $filter = sp;
 $0 = HEAP8[$className>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($className) + 1|0);
  $6 = $5;
 } else {
  $3 = (($className) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 HEAP32[$filter>>2] = $6;
 $7 = (__Z10FindScriptI23MatchScriptByNameFilterEP10MonoScriptRNSt3__13setI4PPtrIS1_ENS3_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier69ELi16EEEERT_($this,$filter)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z10FindScriptI23MatchScriptByNameFilterEP10MonoScriptRNSt3__13setI4PPtrIS1_ENS3_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier69ELi16EEEERT_($scripts,$filter) {
 $scripts = $scripts|0;
 $filter = $filter|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i2 = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy = 0, $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $temp$0$i16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$scripts>>2]|0;
 $3 = (($scripts) + 4|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($scripts) + 8|0);
 $6 = (($scripts) + 4|0);
 $8 = $2;
 L4: while(1) {
  $7 = (($8) + 4|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$01$i$i$i = $8;
   while(1) {
    $13 = (($$01$i$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i$i|0);
    if ($16) {
     $$0$i$i$i = $14;
     break;
    } else {
     $$01$i$i$i = $14;
    }
   }
  } else {
   $$0$i$i$i$i = $9;
   while(1) {
    $11 = HEAP32[$$0$i$i$i$i>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $11;
    }
   }
  }
  $17 = (($8) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  do {
   if ($19) {
    $55 = $9;
    label = 19;
   } else {
    HEAP32[$0>>2] = $18;
    $20 = HEAP32[560624>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     label = 17;
    } else {
     $22 = (($20) + 36|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($20) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($23|0)==($25|0);
     do {
      if ($26) {
       $27 = (($20) + 28|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = (($20) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = (($28) + ($30<<3)|0);
       $47 = $31;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$20,$0);
       $32 = HEAP32[$$byval_copy>>2]|0;
       $33 = ($32|0)==(-1);
       $34 = (($20) + 28|0);
       $35 = HEAP32[$34>>2]|0;
       if ($33) {
        $36 = (($20) + 32|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = (($35) + ($37<<3)|0);
        $47 = $38;
        break;
       } else {
        $39 = (($35) + ($32<<3)|0);
        $47 = $39;
        break;
       }
      }
     } while(0);
     $40 = HEAP32[560624>>2]|0;
     $41 = (($40) + 28|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($40) + 32|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + ($44<<3)|0);
     $46 = ($47|0)==($45|0);
     if ($46) {
      label = 17;
     } else {
      $48 = (($47) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       label = 17;
      } else {
       $$in = $49;$temp$0$i16 = $49;
      }
     }
    }
    if ((label|0) == 17) {
     label = 0;
     $51 = HEAP32[$17>>2]|0;
     $52 = (__Z31ReadObjectFromPersistentManageri($51)|0);
     $53 = ($52|0)==(0|0);
     if ($53) {
      $$pre = HEAP32[$7>>2]|0;
      $55 = $$pre;
      label = 19;
      break;
     } else {
      $$in = $52;$temp$0$i16 = $52;
     }
    }
    $71 = HEAP32[$temp$0$i16>>2]|0;
    $72 = (($71) + 100|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (FUNCTION_TABLE_ii[$73 & 4095]($$in)|0);
    $75 = HEAP32[$filter>>2]|0;
    $76 = (_strlen(($75|0))|0);
    $77 = HEAP8[$74>>0]|0;
    $78 = $77 & 1;
    $79 = ($78<<24>>24)==(0);
    if ($79) {
     $82 = $77&255;
     $83 = $82 >>> 1;
     $91 = $83;
    } else {
     $80 = (($74) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     $91 = $81;
    }
    $84 = ($76|0)==(-1);
    if ($84) {
     label = 31;
     break L4;
    }
    if ($79) {
     $89 = (($74) + 1|0);
     $93 = $89;
    } else {
     $87 = (($74) + 8|0);
     $88 = HEAP32[$87>>2]|0;
     $93 = $88;
    }
    $90 = ($91>>>0)>($76>>>0);
    $92 = $90 ? $76 : $91;
    $94 = (_memcmp($93,$75,$92)|0);
    $95 = ($94|0)==(0);
    if ($95) {
     $98 = $90 ^ 1;
     $not$ = ($91>>>0)>=($76>>>0);
     $99 = $not$ & $98;
     if ($99) {
      $$0 = $$in;
      label = 40;
      break L4;
     }
    }
   }
  } while(0);
  if ((label|0) == 19) {
   label = 0;
   $54 = ($55|0)==(0|0);
   if ($54) {
    $$01$i$i$i$i = $8;
    while(1) {
     $58 = (($$01$i$i$i$i) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==($$01$i$i$i$i|0);
     if ($61) {
      $$0$i$i$i$i2 = $59;
      break;
     } else {
      $$01$i$i$i$i = $59;
     }
    }
   } else {
    $$0$i$i$i$i$i = $55;
    while(1) {
     $56 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $57 = ($56|0)==(0|0);
     if ($57) {
      $$0$i$i$i$i2 = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $56;
     }
    }
   }
   $62 = HEAP32[$scripts>>2]|0;
   $63 = ($62|0)==($8|0);
   if ($63) {
    HEAP32[$scripts>>2] = $$0$i$i$i$i2;
   }
   $64 = HEAP32[$5>>2]|0;
   $65 = (($64) + -1)|0;
   HEAP32[$5>>2] = $65;
   $66 = HEAP32[$6>>2]|0;
   __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($66,$8);
   HEAP32[$1>>2] = 69;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 26;
    break;
   }
  }
  $100 = ($$0$i$i$i|0)==($3|0);
  if ($100) {
   $$0 = 0;
   label = 40;
   break;
  } else {
   $8 = $$0$i$i$i;
  }
 }
 if ((label|0) == 26) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  ___cxa_call_unexpected(($69|0));
  // unreachable;
 }
 else if ((label|0) == 31) {
  __THREW__ = 0;
  invoke_vi(3304,0);
  $85 = __THREW__; __THREW__ = 0;
  $86 = $85&1;
  if ($86) {
   $96 = ___cxa_find_matching_catch()|0;
   $97 = tempRet0;
   ___cxa_call_unexpected(($96|0));
   // unreachable;
  } else {
   // unreachable;
  }
 }
 else if ((label|0) == 40) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN17MonoScriptManager17FindRuntimeScriptEP14ScriptingClass($this,$klass) {
 $this = $this|0;
 $klass = $klass|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $filter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $filter$i = sp;
 $0 = ($klass|0)==(0|0);
 if ($0) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$filter$i>>2] = $klass;
 $1 = (__Z10FindScriptI24MatchScriptByClassFilterEP10MonoScriptRNSt3__13setI4PPtrIS1_ENS3_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier69ELi16EEEERT_($this,$filter$i)|0);
 $$0$i = $1;
 STACKTOP = sp;return ($$0$i|0);
}
function __Z10FindScriptI24MatchScriptByClassFilterEP10MonoScriptRNSt3__13setI4PPtrIS1_ENS3_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier69ELi16EEEERT_($scripts,$filter) {
 $scripts = $scripts|0;
 $filter = $filter|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i2 = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy = 0, $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$scripts>>2]|0;
 $3 = (($scripts) + 4|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($scripts) + 8|0);
 $6 = (($scripts) + 4|0);
 $8 = $2;
 L4: while(1) {
  $7 = (($8) + 4|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$01$i$i$i = $8;
   while(1) {
    $13 = (($$01$i$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i$i|0);
    if ($16) {
     $$0$i$i$i = $14;
     break;
    } else {
     $$01$i$i$i = $14;
    }
   }
  } else {
   $$0$i$i$i$i2 = $9;
   while(1) {
    $11 = HEAP32[$$0$i$i$i$i2>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i$i = $$0$i$i$i$i2;
     break;
    } else {
     $$0$i$i$i$i2 = $11;
    }
   }
  }
  $17 = (($8) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  do {
   if ($19) {
    $55 = $9;
    label = 19;
   } else {
    HEAP32[$0>>2] = $18;
    $20 = HEAP32[560624>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     label = 17;
    } else {
     $22 = (($20) + 36|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($20) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($23|0)==($25|0);
     do {
      if ($26) {
       $27 = (($20) + 28|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = (($20) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = (($28) + ($30<<3)|0);
       $47 = $31;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$20,$0);
       $32 = HEAP32[$$byval_copy>>2]|0;
       $33 = ($32|0)==(-1);
       $34 = (($20) + 28|0);
       $35 = HEAP32[$34>>2]|0;
       if ($33) {
        $36 = (($20) + 32|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = (($35) + ($37<<3)|0);
        $47 = $38;
        break;
       } else {
        $39 = (($35) + ($32<<3)|0);
        $47 = $39;
        break;
       }
      }
     } while(0);
     $40 = HEAP32[560624>>2]|0;
     $41 = (($40) + 28|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($40) + 32|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + ($44<<3)|0);
     $46 = ($47|0)==($45|0);
     if ($46) {
      label = 17;
     } else {
      $48 = (($47) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       label = 17;
      } else {
       $$in = $49;
      }
     }
    }
    if ((label|0) == 17) {
     label = 0;
     $51 = HEAP32[$17>>2]|0;
     $52 = (__Z31ReadObjectFromPersistentManageri($51)|0);
     $53 = ($52|0)==(0|0);
     if ($53) {
      $$pre = HEAP32[$7>>2]|0;
      $55 = $$pre;
      label = 19;
      break;
     } else {
      $$in = $52;
     }
    }
    $71 = (__ZN10MonoScript8GetClassEv($$in)|0);
    $72 = HEAP32[$filter>>2]|0;
    $73 = ($71|0)==($72|0);
    if ($73) {
     $$0 = $$in;
     label = 29;
     break L4;
    }
   }
  } while(0);
  if ((label|0) == 19) {
   label = 0;
   $54 = ($55|0)==(0|0);
   if ($54) {
    $$01$i$i$i$i = $8;
    while(1) {
     $58 = (($$01$i$i$i$i) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==($$01$i$i$i$i|0);
     if ($61) {
      $$0$i$i$i$i = $59;
      break;
     } else {
      $$01$i$i$i$i = $59;
     }
    }
   } else {
    $$0$i$i$i$i$i = $55;
    while(1) {
     $56 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $57 = ($56|0)==(0|0);
     if ($57) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $56;
     }
    }
   }
   $62 = HEAP32[$scripts>>2]|0;
   $63 = ($62|0)==($8|0);
   if ($63) {
    HEAP32[$scripts>>2] = $$0$i$i$i$i;
   }
   $64 = HEAP32[$5>>2]|0;
   $65 = (($64) + -1)|0;
   HEAP32[$5>>2] = $65;
   $66 = HEAP32[$6>>2]|0;
   __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($66,$8);
   HEAP32[$1>>2] = 69;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 26;
    break;
   }
  }
  $74 = ($$0$i$i$i|0)==($3|0);
  if ($74) {
   $$0 = 0;
   label = 29;
   break;
  } else {
   $8 = $$0$i$i$i;
  }
 }
 if ((label|0) == 26) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  ___cxa_call_unexpected(($69|0));
  // unreachable;
 }
 else if ((label|0) == 29) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9TextAssetD2Ev($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((637792 + 8|0));
 __THREW__ = 0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($this) + 40|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   $8 = (($this) + 48|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy3|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $12 = ___cxa_find_matching_catch()|0;
    $13 = tempRet0;
    ___cxa_call_unexpected(($12|0));
    // unreachable;
   }
  }
  $14 = (($this) + 28|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
  $18 = (($this) + 36|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($19|0),($$byval_copy3|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $22 = ___cxa_find_matching_catch()|0;
   $23 = tempRet0;
   ___cxa_call_unexpected(($22|0));
   // unreachable;
  } else {
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $26 = (($this) + 40|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27 & 1;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  $30 = (($this) + 48|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($31|0),($$byval_copy3|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $34 = ___cxa_find_matching_catch()|0;
   $35 = tempRet0;
   ___cxa_call_unexpected(($34|0));
   // unreachable;
  }
 }
 $36 = (($this) + 28|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37 & 1;
 $39 = ($38<<24>>24)==(0);
 if (!($39)) {
  $40 = (($this) + 36|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($41|0),($$byval_copy3|0));
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   ___cxa_call_unexpected(($44|0));
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($24|0);
  // unreachable;
 }
}
function __ZN10MonoScript17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZNK15MonoScriptCache7ReleaseEv($1);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK10MonoScript22GetScriptFullClassNameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp + 36|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 24|0;
 $5 = (($this) + 88|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $11 = $6&255;
  $12 = $11 >>> 1;
  $14 = $12;
 } else {
  $9 = (($this) + 92|0);
  $10 = HEAP32[$9>>2]|0;
  $14 = $10;
 }
 $13 = ($14|0)==(0);
 if ($13) {
  $15 = (($this) + 76|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $23 = (($15) + 1|0);
   $24 = $16&255;
   $25 = $24 >>> 1;
   $27 = $25;$38 = $23;
  } else {
   $19 = (($this) + 84|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 80|0);
   $22 = HEAP32[$21>>2]|0;
   $27 = $22;$38 = $20;
  }
  $26 = ($27>>>0)>(2147483631);
  if ($26) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $28 = ($27>>>0)<(11);
  if ($28) {
   $29 = $27 << 1;
   $30 = $29&255;
   HEAP8[$agg$result>>0] = $30;
   $31 = (($agg$result) + 1|0);
   $__p$0$i$i$i$i = $31;
  } else {
   $32 = (($27) + 16)|0;
   $33 = $32 & -16;
   HEAP32[$0>>2] = 59;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   $34 = (__Z15malloc_internaljj10MemLabelIdiPKci($33,16,$$byval_copy5,0,633080,79)|0);
   $35 = (($agg$result) + 8|0);
   HEAP32[$35>>2] = $34;
   $36 = $33 | 1;
   HEAP32[$agg$result>>2] = $36;
   $37 = (($agg$result) + 4|0);
   HEAP32[$37>>2] = $27;
   $__p$0$i$i$i$i = $34;
  }
  _memcpy(($__p$0$i$i$i$i|0),($38|0),($27|0))|0;
  $39 = (($__p$0$i$i$i$i) + ($27)|0);
  HEAP8[$39>>0] = 0;
  STACKTOP = sp;return;
 }
 __ZNSt3__1plIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEENS_12basic_stringIT_T0_T1_EERKSA_PKS7_($4,$5,633072);
 $40 = (($this) + 76|0);
 __THREW__ = 0;
 invoke_viii(1913,($3|0),($4|0),($40|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $89 = ___cxa_find_matching_catch()|0;
  $90 = tempRet0;
  $$0 = $90;$$01 = $89;
 } else {
  $43 = HEAP8[$3>>0]|0;
  $44 = $43 & 1;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   $50 = (($3) + 1|0);
   $51 = $43&255;
   $52 = $51 >>> 1;
   $54 = $52;$69 = $50;
  } else {
   $46 = (($3) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($3) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $54 = $49;$69 = $47;
  }
  $53 = ($54>>>0)>(2147483631);
  do {
   if ($53) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     // unreachable;
    }
   } else {
    $57 = ($54>>>0)<(11);
    if ($57) {
     $58 = $54 << 1;
     $59 = $58&255;
     HEAP8[$agg$result>>0] = $59;
     $60 = (($agg$result) + 1|0);
     $__p$0$i$i$i$i5 = $60;
    } else {
     $61 = (($54) + 16)|0;
     $62 = $61 & -16;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
     $63 = (invoke_iiiiiii(102,($62|0),16,($$byval_copy5|0),0,(633080|0),79)|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     $66 = (($agg$result) + 8|0);
     HEAP32[$66>>2] = $63;
     $67 = $62 | 1;
     HEAP32[$agg$result>>2] = $67;
     $68 = (($agg$result) + 4|0);
     HEAP32[$68>>2] = $54;
     $__p$0$i$i$i$i5 = $63;
    }
    _memcpy(($__p$0$i$i$i$i5|0),($69|0),($54|0))|0;
    $70 = (($__p$0$i$i$i$i5) + ($54)|0);
    HEAP8[$70>>0] = 0;
    $71 = HEAP8[$3>>0]|0;
    $72 = $71 & 1;
    $73 = ($72<<24>>24)==(0);
    if (!($73)) {
     $74 = (($3) + 8|0);
     $75 = HEAP32[$74>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($75|0),($$byval_copy5|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      $78 = ___cxa_find_matching_catch()|0;
      $79 = tempRet0;
      ___cxa_call_unexpected(($78|0));
      // unreachable;
     }
    }
    $80 = HEAP8[$4>>0]|0;
    $81 = $80 & 1;
    $82 = ($81<<24>>24)==(0);
    if ($82) {
     STACKTOP = sp;return;
    }
    $83 = (($4) + 8|0);
    $84 = HEAP32[$83>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($84|0),($$byval_copy5|0));
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     $87 = ___cxa_find_matching_catch()|0;
     $88 = tempRet0;
     ___cxa_call_unexpected(($87|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  } while(0);
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  $93 = HEAP8[$3>>0]|0;
  $94 = $93 & 1;
  $95 = ($94<<24>>24)==(0);
  if ($95) {
   $$0 = $92;$$01 = $91;
  } else {
   $96 = (($3) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($97|0),($$byval_copy5|0));
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if ($99) {
    $100 = ___cxa_find_matching_catch()|0;
    $101 = tempRet0;
    ___cxa_call_unexpected(($100|0));
    // unreachable;
   } else {
    $$0 = $92;$$01 = $91;
   }
  }
 }
 $102 = HEAP8[$4>>0]|0;
 $103 = $102 & 1;
 $104 = ($103<<24>>24)==(0);
 if ($104) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $105 = (($4) + 8|0);
 $106 = HEAP32[$105>>2]|0;
 HEAP32[$2>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($106|0),($$byval_copy5|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch()|0;
  $110 = tempRet0;
  ___cxa_call_unexpected(($109|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN10MonoScript8GetClassEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (($1) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $$0 = $4;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK10MonoScript13GetScriptTypeEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = -1;
 } else {
  $3 = (($1) + 24|0);
  $4 = HEAP32[$3>>2]|0;
  $$0 = $4;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN10MonoScript16RebuildFromAwakeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $24 = $6;
 } else {
  $4 = (($this) + 108|0);
  $5 = HEAP32[$4>>2]|0;
  $24 = $5;
 }
 $7 = (($this) + 88|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $13 = (($7) + 1|0);
  $25 = $13;
 } else {
  $11 = (($this) + 96|0);
  $12 = HEAP32[$11>>2]|0;
  $25 = $12;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 100|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095]($this)|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  $23 = (($17) + 1|0);
  $26 = $23;
 } else {
  $21 = (($17) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $26 = $22;
 }
 $27 = (__Z29scripting_class_from_fullnamePKcS0_S0_($24,$25,$26)|0);
 $28 = (($this) + 72|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  __ZNK15MonoScriptCache7ReleaseEv($29);
  HEAP32[$28>>2] = 0;
 }
 $31 = (($this) + 112|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = (__Z27FindOrCreateMonoScriptCacheP14ScriptingClass22InitScriptingCacheTypeP6Object($27,$33,$this)|0);
 HEAP32[$28>>2] = $34;
 __ZNK15MonoScriptCache6RetainEv($34);
 STACKTOP = sp;return;
}
function __ZN10MonoScript13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $awakeMode & 2;
 $1 = ($0|0)==(0);
 if ($1) {
  __ZN10MonoScript16RebuildFromAwakeEv($this);
 }
 STACKTOP = sp;return;
}
function __ZN10MonoScript21AwakeFromLoadThreadedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10MonoScript16RebuildFromAwakeEv($this);
 STACKTOP = sp;return;
}
function __ZN10MonoScript39ShouldIgnoreInGarbageDependencyTrackingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __Z18BuildScriptClassIdRKP14ScriptingClass($agg$result,$klass) {
 $agg$result = $agg$result|0;
 $klass = $klass|0;
 var $$0 = 0, $$01 = 0, $$byval_copy14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i12 = 0, $__p$0$i$i$i$i21 = 0, $assembly = 0, $clazz = 0, $ns = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy14 = sp + 120|0;
 $0 = sp + 116|0;
 $1 = sp + 112|0;
 $2 = sp + 108|0;
 $3 = sp + 104|0;
 $4 = sp + 100|0;
 $5 = sp + 96|0;
 $6 = sp + 92|0;
 $7 = sp + 88|0;
 $8 = sp + 84|0;
 $9 = sp + 20|0;
 $10 = sp;
 $11 = sp + 4|0;
 $clazz = sp + 8|0;
 $ns = sp + 24|0;
 $assembly = sp + 36|0;
 $12 = sp + 48|0;
 $13 = sp + 60|0;
 $14 = sp + 72|0;
 ;HEAP32[$clazz+0>>2]=0|0;HEAP32[$clazz+4>>2]=0|0;HEAP32[$clazz+8>>2]=0|0;
 ;HEAP32[$ns+0>>2]=0|0;HEAP32[$ns+4>>2]=0|0;HEAP32[$ns+8>>2]=0|0;
 ;HEAP32[$assembly+0>>2]=0|0;HEAP32[$assembly+4>>2]=0|0;HEAP32[$assembly+8>>2]=0|0;
 $15 = HEAP32[$klass>>2]|0;
 __THREW__ = 0;
 $16 = (invoke_ii(3284,($15|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if ($18) {
   label = 41;
  } else {
   $19 = (_strlen(($16|0))|0);
   $20 = ($19>>>0)>(2147483631);
   if ($20) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 41;
     break;
    }
    // unreachable;
   }
   $23 = ($19>>>0)<(11);
   if ($23) {
    $24 = $19 << 1;
    $25 = $24&255;
    HEAP8[$12>>0] = $25;
    $26 = (($12) + 1|0);
    $__p$0$i$i$i$i = $26;
   } else {
    $27 = (($19) + 16)|0;
    $28 = $27 & -16;
    HEAP32[$9>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$9+0>>2]|0;
    $29 = (invoke_iiiiiii(102,($28|0),16,($$byval_copy14|0),0,(633080|0),79)|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     label = 41;
     break;
    }
    $32 = (($12) + 8|0);
    HEAP32[$32>>2] = $29;
    $33 = $28 | 1;
    HEAP32[$12>>2] = $33;
    $34 = (($12) + 4|0);
    HEAP32[$34>>2] = $19;
    $__p$0$i$i$i$i = $29;
   }
   _memcpy(($__p$0$i$i$i$i|0),($16|0),($19|0))|0;
   $35 = (($__p$0$i$i$i$i) + ($19)|0);
   HEAP8[$35>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($clazz|0),($12|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    $124 = ___cxa_find_matching_catch()|0;
    $125 = tempRet0;
    $126 = HEAP8[$12>>0]|0;
    $127 = $126 & 1;
    $128 = ($127<<24>>24)==(0);
    if ($128) {
     $$0 = $124;$$01 = $125;
     break;
    }
    $129 = (($12) + 8|0);
    $130 = HEAP32[$129>>2]|0;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($130|0),($$byval_copy14|0));
    $131 = __THREW__; __THREW__ = 0;
    $132 = $131&1;
    if (!($132)) {
     $$0 = $124;$$01 = $125;
     break;
    }
    $133 = ___cxa_find_matching_catch()|0;
    $134 = tempRet0;
    ___cxa_call_unexpected(($133|0));
    // unreachable;
   }
   $38 = HEAP8[$12>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if (!($40)) {
    $41 = (($12) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    HEAP32[$8>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$8+0>>2]|0;
    invoke_vii(2591,($42|0),($$byval_copy14|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     $45 = ___cxa_find_matching_catch()|0;
     $46 = tempRet0;
     ___cxa_call_unexpected(($45|0));
     // unreachable;
    }
   }
   $47 = HEAP32[$klass>>2]|0;
   __THREW__ = 0;
   $48 = (invoke_ii(3291,($47|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    label = 41;
   } else {
    $51 = (_strlen(($48|0))|0);
    $52 = ($51>>>0)>(2147483631);
    if ($52) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      label = 41;
      break;
     }
     // unreachable;
    }
    $55 = ($51>>>0)<(11);
    if ($55) {
     $56 = $51 << 1;
     $57 = $56&255;
     HEAP8[$13>>0] = $57;
     $58 = (($13) + 1|0);
     $__p$0$i$i$i$i12 = $58;
    } else {
     $59 = (($51) + 16)|0;
     $60 = $59 & -16;
     HEAP32[$7>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$7+0>>2]|0;
     $61 = (invoke_iiiiiii(102,($60|0),16,($$byval_copy14|0),0,(633080|0),79)|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      label = 41;
      break;
     }
     $64 = (($13) + 8|0);
     HEAP32[$64>>2] = $61;
     $65 = $60 | 1;
     HEAP32[$13>>2] = $65;
     $66 = (($13) + 4|0);
     HEAP32[$66>>2] = $51;
     $__p$0$i$i$i$i12 = $61;
    }
    _memcpy(($__p$0$i$i$i$i12|0),($48|0),($51|0))|0;
    $67 = (($__p$0$i$i$i$i12) + ($51)|0);
    HEAP8[$67>>0] = 0;
    __THREW__ = 0;
    (invoke_iii(2359,($ns|0),($13|0))|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $135 = ___cxa_find_matching_catch()|0;
     $136 = tempRet0;
     $137 = HEAP8[$13>>0]|0;
     $138 = $137 & 1;
     $139 = ($138<<24>>24)==(0);
     if ($139) {
      $$0 = $135;$$01 = $136;
      break;
     }
     $140 = (($13) + 8|0);
     $141 = HEAP32[$140>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($141|0),($$byval_copy14|0));
     $142 = __THREW__; __THREW__ = 0;
     $143 = $142&1;
     if (!($143)) {
      $$0 = $135;$$01 = $136;
      break;
     }
     $144 = ___cxa_find_matching_catch()|0;
     $145 = tempRet0;
     ___cxa_call_unexpected(($144|0));
     // unreachable;
    }
    $70 = HEAP8[$13>>0]|0;
    $71 = $70 & 1;
    $72 = ($71<<24>>24)==(0);
    if (!($72)) {
     $73 = (($13) + 8|0);
     $74 = HEAP32[$73>>2]|0;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($74|0),($$byval_copy14|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      $77 = ___cxa_find_matching_catch()|0;
      $78 = tempRet0;
      ___cxa_call_unexpected(($77|0));
      // unreachable;
     }
    }
    $79 = HEAP32[$klass>>2]|0;
    __THREW__ = 0;
    $80 = (invoke_ii(3292,($79|0))|0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     label = 41;
    } else {
     $83 = (_strlen(($80|0))|0);
     $84 = ($83>>>0)>(2147483631);
     if ($84) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if ($86) {
       label = 41;
       break;
      }
      // unreachable;
     }
     $87 = ($83>>>0)<(11);
     if ($87) {
      $88 = $83 << 1;
      $89 = $88&255;
      HEAP8[$14>>0] = $89;
      $90 = (($14) + 1|0);
      $__p$0$i$i$i$i21 = $90;
     } else {
      $91 = (($83) + 16)|0;
      $92 = $91 & -16;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
      $93 = (invoke_iiiiiii(102,($92|0),16,($$byval_copy14|0),0,(633080|0),79)|0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       label = 41;
       break;
      }
      $96 = (($14) + 8|0);
      HEAP32[$96>>2] = $93;
      $97 = $92 | 1;
      HEAP32[$14>>2] = $97;
      $98 = (($14) + 4|0);
      HEAP32[$98>>2] = $83;
      $__p$0$i$i$i$i21 = $93;
     }
     _memcpy(($__p$0$i$i$i$i21|0),($80|0),($83|0))|0;
     $99 = (($__p$0$i$i$i$i21) + ($83)|0);
     HEAP8[$99>>0] = 0;
     __THREW__ = 0;
     (invoke_iii(2359,($assembly|0),($14|0))|0);
     $100 = __THREW__; __THREW__ = 0;
     $101 = $100&1;
     if ($101) {
      $146 = ___cxa_find_matching_catch()|0;
      $147 = tempRet0;
      $148 = HEAP8[$14>>0]|0;
      $149 = $148 & 1;
      $150 = ($149<<24>>24)==(0);
      if ($150) {
       $$0 = $146;$$01 = $147;
       break;
      }
      $151 = (($14) + 8|0);
      $152 = HEAP32[$151>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($152|0),($$byval_copy14|0));
      $153 = __THREW__; __THREW__ = 0;
      $154 = $153&1;
      if (!($154)) {
       $$0 = $146;$$01 = $147;
       break;
      }
      $155 = ___cxa_find_matching_catch()|0;
      $156 = tempRet0;
      ___cxa_call_unexpected(($155|0));
      // unreachable;
     }
     $102 = HEAP8[$14>>0]|0;
     $103 = $102 & 1;
     $104 = ($103<<24>>24)==(0);
     if (!($104)) {
      $105 = (($14) + 8|0);
      $106 = HEAP32[$105>>2]|0;
      HEAP32[$4>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($106|0),($$byval_copy14|0));
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       $109 = ___cxa_find_matching_catch()|0;
       $110 = tempRet0;
       ___cxa_call_unexpected(($109|0));
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_viiii(392,($agg$result|0),($assembly|0),($ns|0),($clazz|0));
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      label = 41;
     } else {
      $113 = HEAP8[$assembly>>0]|0;
      $114 = $113 & 1;
      $115 = ($114<<24>>24)==(0);
      if (!($115)) {
       $116 = (($assembly) + 8|0);
       $117 = HEAP32[$116>>2]|0;
       HEAP32[$2>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
       invoke_vii(2591,($117|0),($$byval_copy14|0));
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        $120 = ___cxa_find_matching_catch()|0;
        $121 = tempRet0;
        ___cxa_call_unexpected(($120|0));
        // unreachable;
       }
      }
      $157 = HEAP8[$ns>>0]|0;
      $158 = $157 & 1;
      $159 = ($158<<24>>24)==(0);
      do {
       if (!($159)) {
        $160 = (($ns) + 8|0);
        $161 = HEAP32[$160>>2]|0;
        HEAP32[$1>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($161|0),($$byval_copy14|0));
        $162 = __THREW__; __THREW__ = 0;
        $163 = $162&1;
        if (!($163)) {
         break;
        }
        $164 = ___cxa_find_matching_catch()|0;
        $165 = tempRet0;
        ___cxa_call_unexpected(($164|0));
        // unreachable;
       }
      } while(0);
      $175 = HEAP8[$clazz>>0]|0;
      $176 = $175 & 1;
      $177 = ($176<<24>>24)==(0);
      if ($177) {
       STACKTOP = sp;return;
      }
      $178 = (($clazz) + 8|0);
      $179 = HEAP32[$178>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($179|0),($$byval_copy14|0));
      $180 = __THREW__; __THREW__ = 0;
      $181 = $180&1;
      if ($181) {
       $182 = ___cxa_find_matching_catch()|0;
       $183 = tempRet0;
       ___cxa_call_unexpected(($182|0));
       // unreachable;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 41) {
  $122 = ___cxa_find_matching_catch()|0;
  $123 = tempRet0;
  $$0 = $122;$$01 = $123;
 }
 $166 = HEAP8[$assembly>>0]|0;
 $167 = $166 & 1;
 $168 = ($167<<24>>24)==(0);
 if (!($168)) {
  $169 = (($assembly) + 8|0);
  $170 = HEAP32[$169>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($170|0),($$byval_copy14|0));
  $171 = __THREW__; __THREW__ = 0;
  $172 = $171&1;
  if ($172) {
   $173 = ___cxa_find_matching_catch()|0;
   $174 = tempRet0;
   ___cxa_call_unexpected(($173|0));
   // unreachable;
  }
 }
 $184 = HEAP8[$ns>>0]|0;
 $185 = $184 & 1;
 $186 = ($185<<24>>24)==(0);
 if (!($186)) {
  $187 = (($ns) + 8|0);
  $188 = HEAP32[$187>>2]|0;
  HEAP32[$10>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$10+0>>2]|0;
  invoke_vii(2591,($188|0),($$byval_copy14|0));
  $189 = __THREW__; __THREW__ = 0;
  $190 = $189&1;
  if ($190) {
   $191 = ___cxa_find_matching_catch()|0;
   $192 = tempRet0;
   ___cxa_call_unexpected(($191|0));
   // unreachable;
  }
 }
 $193 = HEAP8[$clazz>>0]|0;
 $194 = $193 & 1;
 $195 = ($194<<24>>24)==(0);
 if ($195) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $196 = (($clazz) + 8|0);
 $197 = HEAP32[$196>>2]|0;
 HEAP32[$11>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$11+0>>2]|0;
 invoke_vii(2591,($197|0),($$byval_copy14|0));
 $198 = __THREW__; __THREW__ = 0;
 $199 = $198&1;
 if ($199) {
  $200 = ___cxa_find_matching_catch()|0;
  $201 = tempRet0;
  ___cxa_call_unexpected(($200|0));
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __Z18BuildScriptClassIdRK8UnityStrS1_S1_($agg$result,$assemblyNoDll,$ns,$klass) {
 $agg$result = $agg$result|0;
 $assemblyNoDll = $assemblyNoDll|0;
 $ns = $ns|0;
 $klass = $klass|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp;
 $0 = sp + 24|0;
 $1 = sp + 12|0;
 $2 = HEAP8[$assemblyNoDll>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = (($assemblyNoDll) + 1|0);
  $20 = $7;
 } else {
  $5 = (($assemblyNoDll) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $20 = $6;
 }
 $8 = HEAP8[$ns>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $13 = (($ns) + 1|0);
  $21 = $13;
 } else {
  $11 = (($ns) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $21 = $12;
 }
 $14 = HEAP8[$klass>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $19 = (($klass) + 1|0);
  $22 = $19;
 } else {
  $17 = (($klass) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $22 = $18;
 }
 HEAP32[$$byval_copy>>2] = $20;
 $vararg_ptr1 = (($$byval_copy) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $21;
 $vararg_ptr2 = (($$byval_copy) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $22;
 __Z6FormatPKcz($1,633088,$$byval_copy);
 $23 = HEAP8[$1>>0]|0;
 $24 = $23 & 1;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  $30 = (($1) + 1|0);
  $31 = $23&255;
  $32 = $31 >>> 1;
  $34 = $32;$49 = $30;
 } else {
  $26 = (($1) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($1) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $34 = $29;$49 = $27;
 }
 $33 = ($34>>>0)>(2147483631);
 do {
  if ($33) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    // unreachable;
   }
  } else {
   $37 = ($34>>>0)<(11);
   if ($37) {
    $38 = $34 << 1;
    $39 = $38&255;
    HEAP8[$agg$result>>0] = $39;
    $40 = (($agg$result) + 1|0);
    $__p$0$i$i$i$i = $40;
   } else {
    $41 = (($34) + 16)|0;
    $42 = $41 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $43 = (invoke_iiiiiii(102,($42|0),16,($$byval_copy|0),0,(633080|0),79)|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    $46 = (($agg$result) + 8|0);
    HEAP32[$46>>2] = $43;
    $47 = $42 | 1;
    HEAP32[$agg$result>>2] = $47;
    $48 = (($agg$result) + 4|0);
    HEAP32[$48>>2] = $34;
    $__p$0$i$i$i$i = $43;
   }
   _memcpy(($__p$0$i$i$i$i|0),($49|0),($34|0))|0;
   $50 = (($__p$0$i$i$i$i) + ($34)|0);
   HEAP8[$50>>0] = 0;
   $51 = HEAP8[$1>>0]|0;
   $52 = $51 & 1;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    STACKTOP = sp;return;
   }
   $54 = (($1) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   __ZdlPv($55);
   STACKTOP = sp;return;
  }
 } while(0);
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 $58 = HEAP8[$1>>0]|0;
 $59 = $58 & 1;
 $60 = ($59<<24>>24)==(0);
 if ($60) {
  ___resumeException($56|0);
  // unreachable;
 }
 $61 = (($1) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 __ZdlPv($62);
 ___resumeException($56|0);
 // unreachable;
}
function __Z24RegisterClass_MonoScriptv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(115,179,0,0,0);
 STACKTOP = sp;return;
}
function __ZN10MonoScript13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(49)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9TextAsset13RegisterClassEv();
 }
 HEAP8[$0>>0] = 20;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=633104+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 11|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,115,49,($0|0),120,(2435|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN10MonoScript7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(120,$$byval_copy2,1,16,633080,20)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1914,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((632960 + 8|0));
  $6 = (($3) + 52|0);
  dest=$6+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$6+60>>0]=0|0;
  STACKTOP = sp;return ($3|0);
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(633080|0),20);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK10MonoScript25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 115;
}
function __ZN10MonoScript23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633120,633104,$this,0);
 __ZN10MonoScript8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10MonoScript23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,633120,633104,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN10MonoScript8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10MonoScript23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10MonoScript8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10MonoScript23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10MonoScript8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10MonoScript23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10MonoScript8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10MonoScript23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10MonoScriptD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10MonoScriptD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN10MonoScriptD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3557,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK10MonoScript18GetScriptClassNameEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__1plIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEENS_12basic_stringIT_T0_T1_EEPKS7_RKSA_($agg$result,$__lhs,$__rhs) {
 $agg$result = $agg$result|0;
 $__lhs = $__lhs|0;
 $__rhs = $__rhs|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $2 = (_strlen(($__lhs|0))|0);
 $3 = HEAP8[$__rhs>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = $3&255;
  $9 = $8 >>> 1;
  $11 = $9;
 } else {
  $6 = (($__rhs) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $11 = $7;
 }
 $10 = (($11) + ($2))|0;
 $12 = ($10>>>0)>(2147483631);
 do {
  if ($12) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    // unreachable;
   }
  } else {
   $15 = ($10>>>0)<(11);
   if ($15) {
    $16 = $2 << 1;
    $17 = $16&255;
    HEAP8[$agg$result>>0] = $17;
    $18 = (($agg$result) + 1|0);
    $__p$0$i = $18;
   } else {
    $19 = (($10) + 16)|0;
    $20 = $19 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (invoke_iiiiiii(102,($20|0),16,($$byval_copy1|0),0,(633080|0),79)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = (($agg$result) + 8|0);
    HEAP32[$24>>2] = $21;
    $25 = $20 | 1;
    HEAP32[$agg$result>>2] = $25;
    $26 = (($agg$result) + 4|0);
    HEAP32[$26>>2] = $2;
    $__p$0$i = $21;
   }
   _memcpy(($__p$0$i|0),($__lhs|0),($2|0))|0;
   $27 = (($__p$0$i) + ($2)|0);
   HEAP8[$27>>0] = 0;
   $28 = HEAP8[$__rhs>>0]|0;
   $29 = $28 & 1;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $33 = (($__rhs) + 1|0);
    $34 = $33;
   } else {
    $31 = (($__rhs) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $34 = $32;
   }
   __THREW__ = 0;
   (invoke_iiii(1548,($agg$result|0),($34|0),($11|0))|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 $39 = HEAP8[$agg$result>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  ___resumeException($37|0);
  // unreachable;
 }
 $42 = (($agg$result) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($43|0),($$byval_copy1|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  ___resumeException($37|0);
  // unreachable;
 }
}
function __ZN10MonoScript8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 52|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
 }
 $8 = (($this) + 56|0);
 __ZN7Hash1288TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 76|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$9,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $10 = (($this) + 88|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$10,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $11 = (($this) + 100|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$11,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $12 = (($this) + 112|0);
 $13 = HEAP32[$1>>2]|0;
 $14 = (($13) + 1|0);
 $15 = HEAP32[$4>>2]|0;
 $16 = ($14>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP8[$12>>0]|0;
  HEAP8[$13>>0] = $17;
  $18 = HEAP32[$1>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$1>>2] = $19;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$12,1);
  STACKTOP = sp;return;
 }
}
function __ZN10MonoScript8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 52|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $8 = $$pre$i$i$i;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 56|0);
 __ZN7Hash1288TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 $11 = (($this) + 76|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$11,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $12 = (($this) + 88|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$12,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $13 = (($this) + 100|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$13,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $14 = (($this) + 112|0);
 $15 = HEAP32[$1>>2]|0;
 $16 = (($15) + 1|0);
 $17 = HEAP32[$4>>2]|0;
 $18 = ($16>>>0)>($17>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,1);
  STACKTOP = sp;return;
 } else {
  $19 = HEAP8[$15>>0]|0;
  HEAP8[$14>>0] = $19;
  $20 = HEAP32[$1>>2]|0;
  $21 = (($20) + 1|0);
  HEAP32[$1>>2] = $21;
  STACKTOP = sp;return;
 }
}
function __ZN10MonoScript8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 52|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
 }
 $8 = (($this) + 56|0);
 __ZN7Hash1288TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 76|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$9,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $10 = (($this) + 88|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$10,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $11 = (($this) + 100|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$11,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $12 = (($this) + 112|0);
 $13 = HEAP32[$1>>2]|0;
 $14 = (($13) + 1|0);
 $15 = HEAP32[$4>>2]|0;
 $16 = ($14>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$12,1);
  STACKTOP = sp;return;
 } else {
  $17 = HEAP8[$13>>0]|0;
  HEAP8[$12>>0] = $17;
  $18 = HEAP32[$1>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$1>>2] = $19;
  STACKTOP = sp;return;
 }
}
function __ZN10MonoScript8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy15 = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $not$41 = 0, $phitmp$i$i = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy15 = sp + 104|0;
 $0 = sp + 100|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 88|0;
 $4 = sp + 84|0;
 $5 = sp + 80|0;
 $6 = sp + 76|0;
 $7 = sp + 60|0;
 $8 = sp + 48|0;
 $9 = sp + 36|0;
 $10 = sp + 24|0;
 $11 = sp + 12|0;
 $12 = sp;
 $13 = sp + 64|0;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,4);
 $14 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$14,633128,0);
 $15 = (($this) + 56|0);
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,633392,633424,$$byval_copy15,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  if ($18) {
   __ZN7Hash1288TransferI14SafeBinaryReadEEvRT_($15,$transfer);
  } else {
   $19 = HEAP32[$$byval_copy15>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($15,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (($this) + 76|0);
 $22 = HEAP32[580712>>2]|0;
 $23 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,633152,$22,$$byval_copy15,0)|0);
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = ($23|0)>(0);
  if ($25) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$21,0);
  } else {
   $26 = HEAP32[$$byval_copy15>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    (FUNCTION_TABLE_iii[$26 & 4095]($21,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $28 = (($this) + 88|0);
 $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,633168,$22,$$byval_copy15,0)|0);
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = ($29|0)>(0);
  if ($31) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$28,0);
  } else {
   $32 = HEAP32[$$byval_copy15>>2]|0;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    (FUNCTION_TABLE_iii[$32 & 4095]($28,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $34 = (($this) + 100|0);
 $35 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,633184,$22,$$byval_copy15,0)|0);
 $36 = ($35|0)==(0);
 if (!($36)) {
  $37 = ($35|0)>(0);
  if ($37) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$34,0);
  } else {
   $38 = HEAP32[$$byval_copy15>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    (FUNCTION_TABLE_iii[$38 & 4095]($34,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $40 = (($this) + 112|0);
 $41 = HEAP32[580544>>2]|0;
 $42 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,633200,$41,$$byval_copy15,0)|0);
 $43 = ($42|0)==(0);
 if (!($43)) {
  $44 = ($42|0)>(0);
  do {
   if ($44) {
    $45 = (($transfer) + 12|0);
    $46 = (($transfer) + 80|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + 12|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($transfer) + 16|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($transfer) + 28|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($transfer) + 32|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = Math_imul($55, $53)|0;
    $$sum$i$i$i$i$i = (($49) - ($56))|0;
    $57 = (($51) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$45>>2] = $57;
    $58 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($58)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $59 = (($51) + ($$sum1$i$i$i$i$i)|0);
     $60 = (($transfer) + 20|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($59>>>0)>($61>>>0);
     if (!($62)) {
      $63 = HEAP8[$57>>0]|0;
      HEAP8[$40>>0] = $63;
      $64 = HEAP32[$45>>2]|0;
      $65 = (($64) + 1|0);
      HEAP32[$45>>2] = $65;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($45,$40,1);
   } else {
    $66 = HEAP32[$$byval_copy15>>2]|0;
    $67 = ($66|0)==(0|0);
    if (!($67)) {
     (FUNCTION_TABLE_iii[$66 & 4095]($40,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $68 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 if (!($68)) {
  STACKTOP = sp;return;
 }
 $69 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,633224,$22,$$byval_copy15,0)|0);
 $70 = ($69|0)==(0);
 if (!($70)) {
  $71 = ($69|0)>(0);
  if ($71) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$34,0);
  } else {
   $72 = HEAP32[$$byval_copy15>>2]|0;
   $73 = ($72|0)==(0|0);
   if (!($73)) {
    (FUNCTION_TABLE_iii[$72 & 4095]($34,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $74 = HEAP8[$34>>0]|0;
 $75 = $74 & 1;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  $81 = $74&255;
  $82 = $81 >>> 1;
  $83 = (($34) + 1|0);
  $85 = $82;$87 = $83;
 } else {
  $77 = (($this) + 104|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($this) + 108|0);
  $80 = HEAP32[$79>>2]|0;
  $85 = $78;$87 = $80;
 }
 $84 = ($85>>>0)>(20);
 $86 = $84 ? 20 : $85;
 $88 = (_memcmp($87,633248,$86)|0);
 $89 = ($88|0)==(0);
 if ($89) {
  $90 = $84 ^ 1;
  $not$41 = ($85>>>0)>(19);
  $91 = $not$41 & $90;
  if ($91) {
   HEAP32[$0>>2] = 59;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
   $92 = (__Z15malloc_internaljj10MemLabelIdiPKci(16,16,$$byval_copy15,0,633080,79)|0);
   $93 = (($8) + 8|0);
   HEAP32[$93>>2] = $92;
   HEAP32[$8>>2] = 17;
   $94 = (($8) + 4|0);
   HEAP32[$94>>2] = 15;
   dest=$92+0|0; src=633272+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $95 = (($92) + 15|0);
   HEAP8[$95>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($34|0),($8|0))|0);
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    $120 = ___cxa_find_matching_catch()|0;
    $121 = tempRet0;
    $122 = HEAP8[$8>>0]|0;
    $123 = $122 & 1;
    $124 = ($123<<24>>24)==(0);
    if ($124) {
     $$1 = $121;$$12 = $120;
     ___resumeException($$12|0);
     // unreachable;
    }
    $125 = HEAP32[$93>>2]|0;
    HEAP32[$6>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_vii(2591,($125|0),($$byval_copy15|0));
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if ($127) {
     $128 = ___cxa_find_matching_catch()|0;
     $129 = tempRet0;
     ___cxa_call_unexpected(($128|0));
     // unreachable;
    } else {
     $$1 = $121;$$12 = $120;
     ___resumeException($$12|0);
     // unreachable;
    }
   }
   $98 = HEAP8[$8>>0]|0;
   $99 = $98 & 1;
   $100 = ($99<<24>>24)==(0);
   if (!($100)) {
    $101 = HEAP32[$93>>2]|0;
    HEAP32[$7>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$7+0>>2]|0;
    invoke_vii(2591,($101|0),($$byval_copy15|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     $104 = ___cxa_find_matching_catch()|0;
     $105 = tempRet0;
     ___cxa_call_unexpected(($104|0));
     // unreachable;
    }
   }
   HEAP32[$0>>2] = 59;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
   $106 = (__Z15malloc_internaljj10MemLabelIdiPKci(16,16,$$byval_copy15,0,633080,79)|0);
   $107 = (($9) + 8|0);
   HEAP32[$107>>2] = $106;
   HEAP32[$9>>2] = 17;
   $108 = (($9) + 4|0);
   HEAP32[$108>>2] = 11;
   dest=$106+0|0; src=633288+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $109 = (($106) + 11|0);
   HEAP8[$109>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($28|0),($9|0))|0);
   $110 = __THREW__; __THREW__ = 0;
   $111 = $110&1;
   if ($111) {
    $130 = ___cxa_find_matching_catch()|0;
    $131 = tempRet0;
    $132 = HEAP8[$9>>0]|0;
    $133 = $132 & 1;
    $134 = ($133<<24>>24)==(0);
    if ($134) {
     $$1 = $131;$$12 = $130;
     ___resumeException($$12|0);
     // unreachable;
    }
    $135 = HEAP32[$107>>2]|0;
    HEAP32[$5>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($135|0),($$byval_copy15|0));
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if ($137) {
     $138 = ___cxa_find_matching_catch()|0;
     $139 = tempRet0;
     ___cxa_call_unexpected(($138|0));
     // unreachable;
    } else {
     $$1 = $131;$$12 = $130;
     ___resumeException($$12|0);
     // unreachable;
    }
   } else {
    $112 = HEAP8[$9>>0]|0;
    $113 = $112 & 1;
    $114 = ($113<<24>>24)==(0);
    if ($114) {
     STACKTOP = sp;return;
    }
    $115 = HEAP32[$107>>2]|0;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($115|0),($$byval_copy15|0));
    $116 = __THREW__; __THREW__ = 0;
    $117 = $116&1;
    if ($117) {
     $118 = ___cxa_find_matching_catch()|0;
     $119 = tempRet0;
     ___cxa_call_unexpected(($118|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 if ($76) {
  $144 = $74&255;
  $145 = $144 >>> 1;
  $146 = (($34) + 1|0);
  $148 = $145;$150 = $146;
 } else {
  $140 = (($this) + 104|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = (($this) + 108|0);
  $143 = HEAP32[$142>>2]|0;
  $148 = $141;$150 = $143;
 }
 $147 = ($148>>>0)>(20);
 $149 = $147 ? 20 : $148;
 $151 = (_memcmp($150,633304,$149)|0);
 $152 = ($151|0)==(0);
 if ($152) {
  $153 = $147 ^ 1;
  $not$ = ($148>>>0)>(19);
  $154 = $not$ & $153;
  if ($154) {
   HEAP32[$0>>2] = 59;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
   $155 = (__Z15malloc_internaljj10MemLabelIdiPKci(16,16,$$byval_copy15,0,633080,79)|0);
   $156 = (($10) + 8|0);
   HEAP32[$156>>2] = $155;
   HEAP32[$10>>2] = 17;
   $157 = (($10) + 4|0);
   HEAP32[$157>>2] = 15;
   dest=$155+0|0; src=633328+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $158 = (($155) + 15|0);
   HEAP8[$158>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($34|0),($10|0))|0);
   $159 = __THREW__; __THREW__ = 0;
   $160 = $159&1;
   if ($160) {
    $183 = ___cxa_find_matching_catch()|0;
    $184 = tempRet0;
    $185 = HEAP8[$10>>0]|0;
    $186 = $185 & 1;
    $187 = ($186<<24>>24)==(0);
    if ($187) {
     $$1 = $184;$$12 = $183;
     ___resumeException($$12|0);
     // unreachable;
    }
    $188 = HEAP32[$156>>2]|0;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($188|0),($$byval_copy15|0));
    $189 = __THREW__; __THREW__ = 0;
    $190 = $189&1;
    if ($190) {
     $191 = ___cxa_find_matching_catch()|0;
     $192 = tempRet0;
     ___cxa_call_unexpected(($191|0));
     // unreachable;
    } else {
     $$1 = $184;$$12 = $183;
     ___resumeException($$12|0);
     // unreachable;
    }
   }
   $161 = HEAP8[$10>>0]|0;
   $162 = $161 & 1;
   $163 = ($162<<24>>24)==(0);
   if (!($163)) {
    $164 = HEAP32[$156>>2]|0;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($164|0),($$byval_copy15|0));
    $165 = __THREW__; __THREW__ = 0;
    $166 = $165&1;
    if ($166) {
     $167 = ___cxa_find_matching_catch()|0;
     $168 = tempRet0;
     ___cxa_call_unexpected(($167|0));
     // unreachable;
    }
   }
   HEAP32[$0>>2] = 59;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
   $169 = (__Z15malloc_internaljj10MemLabelIdiPKci(16,16,$$byval_copy15,0,633080,79)|0);
   $170 = (($11) + 8|0);
   HEAP32[$170>>2] = $169;
   HEAP32[$11>>2] = 17;
   $171 = (($11) + 4|0);
   HEAP32[$171>>2] = 11;
   dest=$169+0|0; src=633344+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $172 = (($169) + 11|0);
   HEAP8[$172>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($28|0),($11|0))|0);
   $173 = __THREW__; __THREW__ = 0;
   $174 = $173&1;
   if ($174) {
    $193 = ___cxa_find_matching_catch()|0;
    $194 = tempRet0;
    $195 = HEAP8[$11>>0]|0;
    $196 = $195 & 1;
    $197 = ($196<<24>>24)==(0);
    if ($197) {
     $$1 = $194;$$12 = $193;
     ___resumeException($$12|0);
     // unreachable;
    }
    $198 = HEAP32[$170>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($198|0),($$byval_copy15|0));
    $199 = __THREW__; __THREW__ = 0;
    $200 = $199&1;
    if ($200) {
     $201 = ___cxa_find_matching_catch()|0;
     $202 = tempRet0;
     ___cxa_call_unexpected(($201|0));
     // unreachable;
    } else {
     $$1 = $194;$$12 = $193;
     ___resumeException($$12|0);
     // unreachable;
    }
   } else {
    $175 = HEAP8[$11>>0]|0;
    $176 = $175 & 1;
    $177 = ($176<<24>>24)==(0);
    if ($177) {
     STACKTOP = sp;return;
    }
    $178 = HEAP32[$170>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($178|0),($$byval_copy15|0));
    $179 = __THREW__; __THREW__ = 0;
    $180 = $179&1;
    if ($180) {
     $181 = ___cxa_find_matching_catch()|0;
     $182 = tempRet0;
     ___cxa_call_unexpected(($181|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 }
 __ZNSt3__1plIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEENS_12basic_stringIT_T0_T1_EEPKS7_RKSA_($13,633360,$34);
 __THREW__ = 0;
 invoke_viii(1912,($12|0),($13|0),(633376|0));
 $203 = __THREW__; __THREW__ = 0;
 $204 = $203&1;
 L128: do {
  if ($204) {
   $265 = ___cxa_find_matching_catch()|0;
   $266 = tempRet0;
   $$0 = $266;$$01 = $265;
  } else {
   $205 = HEAP8[$12>>0]|0;
   $206 = $205 & 1;
   $207 = ($206<<24>>24)==(0);
   if ($207) {
    $212 = (($12) + 1|0);
    $213 = $205&255;
    $214 = $213 >>> 1;
    $223 = $214;$231 = $212;
   } else {
    $208 = (($12) + 8|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = (($12) + 4|0);
    $211 = HEAP32[$210>>2]|0;
    $223 = $211;$231 = $209;
   }
   $215 = HEAP8[$34>>0]|0;
   $216 = $215 & 1;
   $217 = ($216<<24>>24)==(0);
   if ($217) {
    $222 = 10;$225 = $215;
   } else {
    $218 = HEAP32[$34>>2]|0;
    $219 = $218 & -2;
    $phitmp$i$i = (($219) + -1)|0;
    $220 = $218&255;
    $222 = $phitmp$i$i;$225 = $220;
   }
   $221 = ($222>>>0)<($223>>>0);
   $224 = $225 & 1;
   $226 = ($224<<24>>24)==(0);
   do {
    if ($221) {
     if ($226) {
      $241 = $225&255;
      $242 = $241 >>> 1;
      $244 = $242;
     } else {
      $239 = (($this) + 104|0);
      $240 = HEAP32[$239>>2]|0;
      $244 = $240;
     }
     $243 = (($223) - ($222))|0;
     __THREW__ = 0;
     invoke_viiiiiiii(22,($34|0),($222|0),($243|0),($244|0),0,($244|0),($223|0),($231|0));
     $245 = __THREW__; __THREW__ = 0;
     $246 = $245&1;
     if ($246) {
      $267 = ___cxa_find_matching_catch()|0;
      $268 = tempRet0;
      $269 = HEAP8[$12>>0]|0;
      $270 = $269 & 1;
      $271 = ($270<<24>>24)==(0);
      if ($271) {
       $$0 = $268;$$01 = $267;
       break L128;
      }
      $272 = (($12) + 8|0);
      $273 = HEAP32[$272>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($273|0),($$byval_copy15|0));
      $274 = __THREW__; __THREW__ = 0;
      $275 = $274&1;
      if (!($275)) {
       $$0 = $268;$$01 = $267;
       break L128;
      }
      $276 = ___cxa_find_matching_catch()|0;
      $277 = tempRet0;
      ___cxa_call_unexpected(($276|0));
      // unreachable;
     }
    } else {
     if ($226) {
      $229 = (($34) + 1|0);
      $230 = $229;
     } else {
      $227 = (($this) + 108|0);
      $228 = HEAP32[$227>>2]|0;
      $230 = $228;
     }
     _memmove(($230|0),($231|0),($223|0))|0;
     $232 = (($230) + ($223)|0);
     HEAP8[$232>>0] = 0;
     $233 = HEAP8[$34>>0]|0;
     $234 = $233 & 1;
     $235 = ($234<<24>>24)==(0);
     if ($235) {
      $237 = $223 << 1;
      $238 = $237&255;
      HEAP8[$34>>0] = $238;
      break;
     } else {
      $236 = (($this) + 104|0);
      HEAP32[$236>>2] = $223;
      break;
     }
    }
   } while(0);
   $247 = HEAP8[$12>>0]|0;
   $248 = $247 & 1;
   $249 = ($248<<24>>24)==(0);
   if (!($249)) {
    $250 = (($12) + 8|0);
    $251 = HEAP32[$250>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($251|0),($$byval_copy15|0));
    $252 = __THREW__; __THREW__ = 0;
    $253 = $252&1;
    if ($253) {
     $254 = ___cxa_find_matching_catch()|0;
     $255 = tempRet0;
     ___cxa_call_unexpected(($254|0));
     // unreachable;
    }
   }
   $256 = HEAP8[$13>>0]|0;
   $257 = $256 & 1;
   $258 = ($257<<24>>24)==(0);
   if ($258) {
    STACKTOP = sp;return;
   }
   $259 = (($13) + 8|0);
   $260 = HEAP32[$259>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($260|0),($$byval_copy15|0));
   $261 = __THREW__; __THREW__ = 0;
   $262 = $261&1;
   if ($262) {
    $263 = ___cxa_find_matching_catch()|0;
    $264 = tempRet0;
    ___cxa_call_unexpected(($263|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $278 = HEAP8[$13>>0]|0;
 $279 = $278 & 1;
 $280 = ($279<<24>>24)==(0);
 if ($280) {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$12|0);
  // unreachable;
 }
 $281 = (($13) + 8|0);
 $282 = HEAP32[$281>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($282|0),($$byval_copy15|0));
 $283 = __THREW__; __THREW__ = 0;
 $284 = $283&1;
 if ($284) {
  $285 = ___cxa_find_matching_catch()|0;
  $286 = tempRet0;
  ___cxa_call_unexpected(($285|0));
  // unreachable;
 } else {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZN10MonoScript8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i6 = 0, $size$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i5 = sp;
 $p$i$i$i6 = sp + 4|0;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,4);
 $0 = (($this) + 52|0);
 $1 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633128,$1,$0,16);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633392,633424,$8,16);
 __ZN7Hash1288TransferI13ProxyTransferEEvRT_($8,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($this) + 76|0);
 $10 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633152,$10,$9,16);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,633416,633416,$size$i$i$i$i5,1);
 $11 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633384,$11,$p$i$i$i6,0);
 $12 = HEAP32[$2>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$5>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 88|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633168,$10,$16,16);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,633416,633416,$size$i$i$i$i5,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633384,$11,$p$i$i$i6,0);
 $17 = HEAP32[$2>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$5>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $21 = (($this) + 100|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633184,$10,$21,16);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,633416,633416,$size$i$i$i$i5,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633384,$11,$p$i$i$i6,0);
 $22 = HEAP32[$2>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$5>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $26 = (($this) + 112|0);
 $27 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,633200,$27,$26,1);
 $28 = HEAP32[$2>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$5>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10MonoScriptD2Ev($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((632960 + 8|0));
 $3 = (($this) + 100|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = (($this) + 108|0);
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($8|0),($$byval_copy2|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   ___cxa_call_unexpected(($11|0));
   // unreachable;
  }
 }
 $13 = (($this) + 88|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if (!($16)) {
  $17 = (($this) + 96|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($18|0),($$byval_copy2|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   ___cxa_call_unexpected(($21|0));
   // unreachable;
  }
 }
 $23 = (($this) + 76|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24 & 1;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  __ZN9TextAssetD2Ev($this);
  STACKTOP = sp;return;
 }
 $27 = (($this) + 84|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($28|0),($$byval_copy2|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  ___cxa_call_unexpected(($31|0));
  // unreachable;
 } else {
  __ZN9TextAssetD2Ev($this);
  STACKTOP = sp;return;
 }
}
function __ZN9TextAssetD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9TextAssetD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN9TextAssetD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3558,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK15MonoScriptCache7ReleaseEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + -1)|0;
 HEAP32[$this>>2] = $3;
 $4 = HEAP32[$this>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $14 = (__Z19GetScriptingManagerv()|0);
  $15 = (($this) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  __ZN16ScriptingManager24NotifyScriptCacheReleaseEj($14,$16);
  STACKTOP = sp;return;
 }
 $6 = HEAP32[628496>>2]|0;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)>(-1);
 if ($9) {
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$0>>2] = $13;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($11,$$byval_copy1);
  HEAP32[$10>>2] = 0;
 }
 HEAP32[$1>>2] = $6;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($this,$$byval_copy1);
 STACKTOP = sp;return;
}
function __ZNK15MonoScriptCache6RetainEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[$this>>2] = $1;
 $2 = HEAP32[$this>>2]|0;
 $3 = (__Z19GetScriptingManagerv()|0);
 __ZN16ScriptingManager19RegisterScriptCacheEP15MonoScriptCache($3,$this);
 STACKTOP = sp;return;
}
function __ZNK15MonoScriptCache8RefCountEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z27FindOrCreateMonoScriptCacheP14ScriptingClass22InitScriptingCacheTypeP6Object($klass,$scriptType,$errorContext) {
 $klass = $klass|0;
 $scriptType = $scriptType|0;
 $errorContext = $errorContext|0;
 var $$$i$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$ph5$i$i$i$i$i = 0, $$0$ph5$i$i$i116$i$i = 0, $$0$ph7$i$i$i$i$i = 0, $$0$ph7$i$i$i110$i$i = 0, $$01 = 0, $$01$i$i$i$i = 0, $$01$ph6$i$in$i$i$i$i = 0, $$01$ph6$i$in$i$i111$i$i = 0, $$013$i$in$i$i$i$i = 0, $$013$i$in$i$i113$i$i = 0, $$014$i$i = 0, $$02 = 0, $$04$i$i$i = 0, $$05$i$i$i = 0, $$1$i$i = 0, $$1$i$i$i = 0;
 var $$115$i$i = 0, $$16$i$i$i = 0, $$2$i$i = 0, $$2$i$i$i = 0, $$216$i$i = 0, $$27$i$i$i = 0, $$3$i$i = 0, $$3$i$i$i = 0, $$317$i$i = 0, $$38$i$i$i = 0, $$4$i$i = 0, $$4$i$i$i = 0, $$418$i$i = 0, $$436$i$i = 0, $$437$i$i = 0, $$438$i$i = 0, $$439$i$i = 0, $$440$i$i = 0, $$49$i$i$i = 0, $$5$i$i = 0;
 var $$5$i$i$i = 0, $$510$i$i$i = 0, $$519$i$i = 0, $$6$i$i = 0, $$6$i$i$i = 0, $$611$i$i$i = 0, $$620$i$i = 0, $$7$i$i = 0, $$7$i$i$i = 0, $$712$i$i$i = 0, $$721$i$i = 0, $$8$i$i = 0, $$8$i$i$i = 0, $$813$i$i$i = 0, $$822$i$i = 0, $$9$i$i = 0, $$923$i$i = 0, $$byval_copy39 = 0, $$in414$i$i = 0, $$old1$i$i$i = 0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0;
 var $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0;
 var $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0;
 var $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0;
 var $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0;
 var $1087 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0;
 var $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0;
 var $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0;
 var $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0;
 var $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0;
 var $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0;
 var $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0;
 var $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0;
 var $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0;
 var $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0;
 var $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0;
 var $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0;
 var $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0;
 var $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0;
 var $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0;
 var $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0;
 var $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0;
 var $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0;
 var $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0;
 var $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0;
 var $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0;
 var $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0;
 var $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0;
 var $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0;
 var $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0;
 var $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0;
 var $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i36$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i16$i$i$i = 0, $allMethods$i$i = 0, $currentClass$0$i$i = 0, $currentClass$0$i$i$i = 0, $currentClass$0$i64$i$i = 0, $eh$lpad$body$i$i$index12Z2D = 0, $eh$lpad$body$i$i$indexZ2D = 0;
 var $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $formattedMsgParameter$0$i$i$i = 0, $formattedMsgParameter$1$i$i$i = 0, $i$0$off$i$i = 0, $i$0$off29$i$i = 0, $i$0411$i$i = 0, $i3$0379$i$i = 0, $identifier = 0, $klassArray$i$i$i = 0, $klassArray$i60$i$i = 0, $lpad$phi170$i$i$index = 0, $lpad$phi170$i$i$index27 = 0, $lpad$phi175$i$i$index = 0, $lpad$phi175$i$i$index22 = 0, $messageName$i$i$i = 0, $methodMap$i$i = 0, $msg$i$i$i = 0, $or$cond$i$i$i = 0, $or$cond$i57$i$i = 0;
 var $or$cond$i65$i$i = 0, $or$cond3$i$i$i = 0, $or$cond5$i$i$i = 0, $postfix$i$i$i = 0, $prefix$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i37$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i41$i$i = 0, $storemerge$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i39$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i40$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $$byval_copy39 = sp + 496|0;
 $0 = sp + 488|0;
 $1 = sp + 40|0;
 $2 = sp + 480|0;
 $klassArray$i60$i$i = sp + 464|0;
 $3 = sp + 456|0;
 $klassArray$i$i$i = sp + 448|0;
 $messageName$i$i$i = sp + 436|0;
 $prefix$i$i$i = sp + 424|0;
 $4 = sp + 412|0;
 $5 = sp + 400|0;
 $postfix$i$i$i = sp + 388|0;
 $6 = sp + 24|0;
 $7 = sp + 376|0;
 $8 = sp + 364|0;
 $9 = sp + 352|0;
 $10 = sp + 340|0;
 $11 = sp;
 $msg$i$i$i = sp + 320|0;
 $12 = sp + 308|0;
 $13 = sp + 296|0;
 $14 = sp + 284|0;
 $15 = sp + 272|0;
 $16 = sp + 268|0;
 $17 = sp + 264|0;
 $18 = sp + 124|0;
 $19 = sp + 128|0;
 $allMethods$i$i = sp + 132|0;
 $methodMap$i$i = sp + 112|0;
 $20 = sp + 32|0;
 $21 = sp + 8|0;
 $22 = sp + 108|0;
 $23 = sp + 16|0;
 $24 = sp + 72|0;
 $25 = sp + 84|0;
 $26 = sp + 96|0;
 $27 = sp + 60|0;
 $28 = sp + 48|0;
 $29 = sp + 144|0;
 $30 = sp + 156|0;
 $31 = sp + 168|0;
 $32 = sp + 180|0;
 $33 = sp + 192|0;
 $34 = sp + 204|0;
 $35 = sp + 224|0;
 $36 = sp + 228|0;
 $37 = sp + 232|0;
 $38 = sp + 236|0;
 $identifier = sp + 240|0;
 $39 = sp + 252|0;
 HEAP32[$38>>2] = $klass;
 HEAP32[$0>>2] = 59;
 ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$0+0>>2]|0;
 $40 = (__Z15malloc_internaljj10MemLabelIdiPKci(16,16,$$byval_copy39,0,634408,79)|0);
 $41 = (($identifier) + 8|0);
 HEAP32[$41>>2] = $40;
 HEAP32[$identifier>>2] = 17;
 $42 = (($identifier) + 4|0);
 HEAP32[$42>>2] = 13;
 dest=$40+0|0; src=633936+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $43 = (($40) + 13|0);
 HEAP8[$43>>0] = 0;
 $44 = HEAP32[$38>>2]|0;
 $45 = ($44|0)==(0|0);
 do {
  if ($45) {
   label = 12;
  } else {
   __THREW__ = 0;
   invoke_vii(3211,($39|0),($38|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    label = 7;
   } else {
    __THREW__ = 0;
    (invoke_iii(2359,($identifier|0),($39|0))|0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     $61 = ___cxa_find_matching_catch()|0;
     $62 = tempRet0;
     $63 = HEAP8[$39>>0]|0;
     $64 = $63 & 1;
     $65 = ($64<<24>>24)==(0);
     if ($65) {
      $$01 = $61;$$02 = $62;
      break;
     }
     $66 = (($39) + 8|0);
     $67 = HEAP32[$66>>2]|0;
     HEAP32[$36>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$36+0>>2]|0;
     invoke_vii(2591,($67|0),($$byval_copy39|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if (!($69)) {
      $$01 = $61;$$02 = $62;
      break;
     }
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     $50 = HEAP8[$39>>0]|0;
     $51 = $50 & 1;
     $52 = ($51<<24>>24)==(0);
     if ($52) {
      label = 12;
      break;
     }
     $53 = (($39) + 8|0);
     $54 = HEAP32[$53>>2]|0;
     HEAP32[$37>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$37+0>>2]|0;
     invoke_vii(2591,($54|0),($$byval_copy39|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      label = 12;
      break;
     }
     $57 = ___cxa_find_matching_catch()|0;
     $58 = tempRet0;
     ___cxa_call_unexpected(($57|0));
     // unreachable;
    }
   }
  }
 } while(0);
 L11: do {
  if ((label|0) == 12) {
   __THREW__ = 0;
   $72 = (invoke_i(84)|0);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    label = 7;
   } else {
    $75 = HEAP8[$identifier>>0]|0;
    $76 = $75 & 1;
    $77 = ($76<<24>>24)==(0);
    if ($77) {
     $80 = (($identifier) + 1|0);
     $81 = $75&255;
     $82 = $81 >>> 1;
     $83 = $80;$84 = $82;
    } else {
     $78 = HEAP32[$41>>2]|0;
     $79 = HEAP32[$42>>2]|0;
     $83 = $78;$84 = $79;
    }
    __THREW__ = 0;
    $85 = (invoke_iiii(1557,($83|0),($84|0),-804401139)|0);
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     label = 7;
    } else {
     __THREW__ = 0;
     $88 = (invoke_iii(2436,($72|0),($85|0))|0);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 7;
     } else {
      $91 = ($88|0)==(0|0);
      L20: do {
       if ($91) {
        $92 = HEAP32[$38>>2]|0;
        $93 = HEAP32[628496>>2]|0;
        HEAP32[$35>>2] = $93;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$35+0>>2]|0;
        $94 = (invoke_iiiiiii(103,40,($$byval_copy39|0),0,16,(634408|0),530)|0);
        $95 = __THREW__; __THREW__ = 0;
        $96 = $95&1;
        if ($96) {
         label = 7;
         break L11;
        }
        HEAP32[$94>>2] = 1;
        $97 = (($94) + 8|0);
        HEAP32[$97>>2] = 0;
        $98 = (($94) + 16|0);
        HEAP32[$98>>2] = 0;
        $99 = (($94) + 20|0);
        HEAP32[$99>>2] = 0;
        $100 = (($94) + 12|0);
        HEAP32[$100>>2] = 61;
        $101 = (($94) + 24|0);
        HEAP32[$101>>2] = -1;
        $102 = (($94) + 4|0);
        HEAP32[$102>>2] = 0;
        $103 = (($94) + 28|0);
        HEAP32[$103>>2] = 0;
        $104 = (($94) + 36|0);
        HEAP32[$104>>2] = 0;
        $105 = (($94) + 32|0);
        HEAP8[$105>>0] = 0;
        $106 = (($94) + 33|0);
        HEAP8[$106>>0] = 0;
        HEAP32[$102>>2] = $92;
        $107 = HEAP8[$identifier>>0]|0;
        $108 = $107 & 1;
        $109 = ($108<<24>>24)==(0);
        if ($109) {
         $112 = (($identifier) + 1|0);
         $113 = $107&255;
         $114 = $113 >>> 1;
         $115 = $112;$116 = $114;
        } else {
         $110 = HEAP32[$41>>2]|0;
         $111 = HEAP32[$42>>2]|0;
         $115 = $110;$116 = $111;
        }
        __THREW__ = 0;
        $117 = (invoke_iiii(1557,($115|0),($116|0),-804401139)|0);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         label = 7;
         break L11;
        }
        HEAP32[$103>>2] = $117;
        $120 = ($92|0)==(0|0);
        if ($120) {
         HEAP32[$101>>2] = -7;
         $$0 = $94;
         break;
        }
        __THREW__ = 0;
        $121 = (invoke_ii(3293,($92|0))|0);
        $122 = __THREW__; __THREW__ = 0;
        $123 = $122&1;
        if ($123) {
         label = 7;
         break L11;
        }
        if ($121) {
         HEAP32[$101>>2] = -4;
         $$0 = $94;
         break;
        }
        __THREW__ = 0;
        $124 = (invoke_ii(3294,($92|0))|0);
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         label = 7;
         break L11;
        }
        if ($124) {
         HEAP32[$101>>2] = -6;
         $$0 = $94;
         break;
        }
        __THREW__ = 0;
        $127 = (invoke_i(102)|0);
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if ($129) {
         label = 7;
         break L11;
        }
        $130 = (($127) + 36|0);
        $131 = HEAP32[$130>>2]|0;
        __THREW__ = 0;
        $132 = (invoke_iii(2432,($92|0),($131|0))|0);
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         label = 7;
         break L11;
        }
        do {
         if ($132) {
          $storemerge$i = 0;
         } else {
          $135 = (($127) + 44|0);
          $136 = HEAP32[$135>>2]|0;
          __THREW__ = 0;
          $137 = (invoke_iii(2432,($92|0),($136|0))|0);
          $138 = __THREW__; __THREW__ = 0;
          $139 = $138&1;
          if ($139) {
           label = 7;
           break L11;
          }
          if ($137) {
           $storemerge$i = 1;
           break;
          }
          HEAP32[$101>>2] = -2;
          $$0 = $94;
          break L20;
         }
        } while(0);
        HEAP32[$101>>2] = $storemerge$i;
        $140 = HEAP32[$102>>2]|0;
        __THREW__ = 0;
        $141 = (invoke_i(103)|0);
        $142 = __THREW__; __THREW__ = 0;
        $143 = $142&1;
        if ($143) {
         label = 7;
         break L11;
        }
        $144 = (($141) + 32|0);
        $145 = HEAP32[$144>>2]|0;
        $146 = (($145) + 26)|0;
        $147 = HEAP32[$99>>2]|0;
        $148 = $147 & 2147483647;
        $149 = ($148>>>0)<($146>>>0);
        do {
         if ($149) {
          $150 = ($147|0)>(-1);
          if ($150) {
           HEAP32[$99>>2] = $146;
           $151 = HEAP32[$97>>2]|0;
           $152 = $146 << 3;
           $153 = HEAP32[$100>>2]|0;
           HEAP32[$17>>2] = $153;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$17+0>>2]|0;
           $154 = (invoke_iiiiiiii(108,($151|0),($152|0),4,($$byval_copy39|0),0,(634408|0),370)|0);
           $155 = __THREW__; __THREW__ = 0;
           $156 = $155&1;
           if ($156) {
            label = 7;
            break L11;
           }
           HEAP32[$97>>2] = $154;
           break;
          } else {
           $157 = $146 << 3;
           $158 = HEAP32[$100>>2]|0;
           HEAP32[$18>>2] = $158;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$18+0>>2]|0;
           $159 = (invoke_iiiiiii(102,($157|0),4,($$byval_copy39|0),0,(634408|0),352)|0);
           $160 = __THREW__; __THREW__ = 0;
           $161 = $160&1;
           if ($161) {
            label = 7;
            break L11;
           }
           $162 = HEAP32[$97>>2]|0;
           $163 = HEAP32[$98>>2]|0;
           $164 = $163 << 3;
           _memcpy(($159|0),($162|0),($164|0))|0;
           HEAP32[$99>>2] = $146;
           HEAP32[$97>>2] = $159;
           break;
          }
         }
        } while(0);
        $165 = HEAP32[$98>>2]|0;
        $166 = ($165>>>0)<($146>>>0);
        do {
         if ($166) {
          $167 = HEAP32[$97>>2]|0;
          $168 = (($167) + ($146<<3)|0);
          $169 = ($165|0)==($146|0);
          if ($169) {
           break;
          }
          $170 = (($167) + ($165<<3)|0);
          $$01$i$i$i$i = $170;
          while(1) {
           $171 = ($$01$i$i$i$i|0)==(0|0);
           if (!($171)) {
            $172 = 599912;
            $173 = $172;
            $174 = HEAP32[$173>>2]|0;
            $175 = (($172) + 4)|0;
            $176 = $175;
            $177 = HEAP32[$176>>2]|0;
            $178 = $$01$i$i$i$i;
            $179 = $178;
            HEAP32[$179>>2] = $174;
            $180 = (($178) + 4)|0;
            $181 = $180;
            HEAP32[$181>>2] = $177;
           }
           $182 = (($$01$i$i$i$i) + 8|0);
           $183 = ($182|0)==($168|0);
           if ($183) {
            break;
           } else {
            $$01$i$i$i$i = $182;
           }
          }
         }
        } while(0);
        HEAP32[$98>>2] = $146;
        __THREW__ = 0;
        $184 = (invoke_i(84)|0);
        $185 = __THREW__; __THREW__ = 0;
        $186 = $185&1;
        if ($186) {
         label = 7;
         break L11;
        }
        $187 = (($184) + 280|0);
        $188 = HEAP32[$187>>2]|0;
        HEAP32[$allMethods$i$i>>2] = 0;
        $189 = (($allMethods$i$i) + 4|0);
        HEAP32[$189>>2] = 0;
        $190 = (($allMethods$i$i) + 8|0);
        HEAP32[$190>>2] = 0;
        $191 = HEAP32[$102>>2]|0;
        $currentClass$0$i$i = $191;
        while(1) {
         $192 = ($currentClass$0$i$i|0)==(0|0);
         if ($192) {
          label = 58;
          break;
         }
         __THREW__ = 0;
         invoke_vii(3212,($currentClass$0$i$i|0),($allMethods$i$i|0));
         $193 = __THREW__; __THREW__ = 0;
         $194 = $193&1;
         if ($194) {
          label = 56;
          break;
         }
         $195 = ($currentClass$0$i$i|0)==($188|0);
         if ($195) {
          label = 58;
          break;
         }
         __THREW__ = 0;
         $198 = (invoke_ii(3295,($currentClass$0$i$i|0))|0);
         $199 = __THREW__; __THREW__ = 0;
         $200 = $199&1;
         if ($200) {
          label = 56;
          break;
         } else {
          $currentClass$0$i$i = $198;
         }
        }
        if ((label|0) == 56) {
         $196 = ___cxa_find_matching_catch()|0;
         $197 = tempRet0;
         $$9$i$i = $196;$$923$i$i = $197;
        }
        else if ((label|0) == 58) {
         $201 = (($methodMap$i$i) + 4|0);
         HEAP32[$201>>2] = 0;
         $202 = (($methodMap$i$i) + 8|0);
         HEAP32[$202>>2] = 0;
         $203 = (($methodMap$i$i) + 4|0);
         HEAP32[$methodMap$i$i>>2] = $203;
         $204 = HEAP32[$189>>2]|0;
         $205 = HEAP32[$allMethods$i$i>>2]|0;
         $206 = ($204|0)==($205|0);
         L73: do {
          if ($206) {
           label = 59;
          } else {
           $$in414$i$i = $204;
           while(1) {
            $228 = (($$in414$i$i) + -8|0);
            $229 = $228;
            $230 = $229;
            $231 = HEAP32[$230>>2]|0;
            $232 = (($229) + 4)|0;
            $233 = $232;
            $234 = HEAP32[$233>>2]|0;
            $235 = $20;
            $236 = $235;
            HEAP32[$236>>2] = $231;
            $237 = (($235) + 4)|0;
            $238 = $237;
            HEAP32[$238>>2] = $234;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$$byval_copy39+4>>2]=HEAP32[$20+4>>2]|0;
            $239 = (invoke_ii(3296,($$byval_copy39|0))|0);
            $240 = __THREW__; __THREW__ = 0;
            $241 = $240&1;
            if ($241) {
             break;
            }
            if ($239) {
             $243 = $228;
             $244 = $243;
             $245 = HEAP32[$244>>2]|0;
             $246 = (($243) + 4)|0;
             $247 = $246;
             $248 = HEAP32[$247>>2]|0;
             $249 = $21;
             $250 = $249;
             HEAP32[$250>>2] = $245;
             $251 = (($249) + 4)|0;
             $252 = $251;
             HEAP32[$252>>2] = $248;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$$byval_copy39+4>>2]=HEAP32[$21+4>>2]|0;
             $253 = (invoke_ii(3290,($$byval_copy39|0))|0);
             $254 = __THREW__; __THREW__ = 0;
             $255 = $254&1;
             if ($255) {
              break;
             }
             HEAP32[$22>>2] = $253;
             __THREW__ = 0;
             $256 = (invoke_iii(2437,($methodMap$i$i|0),($22|0))|0);
             $257 = __THREW__; __THREW__ = 0;
             $258 = $257&1;
             if ($258) {
              break;
             }
             ;HEAP32[$256+0>>2]=HEAP32[$228+0>>2]|0;HEAP8[$256+4>>0]=HEAP8[$228+4>>0]|0;
            }
            $242 = ($228|0)==($205|0);
            if ($242) {
             label = 59;
             break L73;
            } else {
             $$in414$i$i = $228;
            }
           }
           $267 = ___cxa_find_matching_catch()|0;
           $268 = tempRet0;
           $eh$lpad$body$i$i$index12Z2D = $268;$eh$lpad$body$i$i$indexZ2D = $267;
           label = 72;
          }
         } while(0);
         L83: do {
          if ((label|0) == 59) {
           $$old1$i$i$i = ($140|0)==(0|0);
           $207 = (($klassArray$i60$i$i) + 4|0);
           $208 = (($klassArray$i60$i$i) + 8|0);
           $209 = (($3) + 4|0);
           $210 = (($klassArray$i$i$i) + 4|0);
           $211 = (($2) + 4|0);
           $212 = (($33) + 8|0);
           $213 = (($33) + 4|0);
           $214 = ($errorContext|0)==(0|0);
           $215 = (($29) + 1|0);
           $216 = (($32) + 8|0);
           $217 = (($31) + 8|0);
           $218 = (($30) + 8|0);
           $219 = (($29) + 8|0);
           $220 = (($errorContext) + 4|0);
           $221 = (($28) + 8|0);
           $222 = (($28) + 4|0);
           $223 = (($24) + 1|0);
           $224 = (($27) + 8|0);
           $225 = (($26) + 8|0);
           $226 = (($25) + 8|0);
           $227 = (($24) + 8|0);
           $i$0411$i$i = 0;
           L85: while(1) {
            $298 = (633824 + ($i$0411$i$i<<2)|0);
            $299 = HEAP32[$201>>2]|0;
            $300 = ($299|0)==(0|0);
            do {
             if ($300) {
              $318 = 599912;
             } else {
              $301 = HEAP32[$298>>2]|0;
              $$0$ph7$i$i$i$i$i = $203;$$01$ph6$i$in$i$i$i$i = $299;
              L89: while(1) {
               $$013$i$in$i$i$i$i = $$01$ph6$i$in$i$i$i$i;
               while(1) {
                $302 = (($$013$i$in$i$i$i$i) + 16|0);
                $303 = HEAP32[$302>>2]|0;
                $304 = (_strcmp($303,$301)|0);
                $305 = ($304|0)<(0);
                if (!($305)) {
                 break;
                }
                $308 = (($$013$i$in$i$i$i$i) + 4|0);
                $309 = HEAP32[$308>>2]|0;
                $310 = ($309|0)==(0|0);
                if ($310) {
                 $$0$ph5$i$i$i$i$i = $$0$ph7$i$i$i$i$i;
                 break L89;
                } else {
                 $$013$i$in$i$i$i$i = $309;
                }
               }
               $306 = HEAP32[$$013$i$in$i$i$i$i>>2]|0;
               $307 = ($306|0)==(0|0);
               if ($307) {
                $$0$ph5$i$i$i$i$i = $$013$i$in$i$i$i$i;
                break;
               } else {
                $$0$ph7$i$i$i$i$i = $$013$i$in$i$i$i$i;$$01$ph6$i$in$i$i$i$i = $306;
               }
              }
              $311 = ($$0$ph5$i$i$i$i$i|0)==($203|0);
              if ($311) {
               $318 = 599912;
               break;
              }
              $312 = (($$0$ph5$i$i$i$i$i) + 16|0);
              $313 = HEAP32[$312>>2]|0;
              $314 = (_strcmp($301,$313)|0);
              $315 = ($314|0)<(0);
              if ($315) {
               $318 = 599912;
               break;
              }
              $316 = (($$0$ph5$i$i$i$i$i) + 20|0);
              $318 = $316;
             }
            } while(0);
            $317 = $318;
            $319 = $317;
            $320 = HEAP32[$319>>2]|0;
            $321 = (($317) + 4)|0;
            $322 = $321;
            $323 = HEAP32[$322>>2]|0;
            $324 = $320;
            $325 = $323&255;
            __THREW__ = 0;
            $326 = (invoke_i(102)|0);
            $327 = __THREW__; __THREW__ = 0;
            $328 = $327&1;
            if ($328) {
             label = 69;
             break;
            }
            $329 = ($320|0)==(0);
            L100: do {
             if ($329) {
              $608 = 0;$610 = $325;
             } else {
              $330 = $23;
              $331 = $330;
              HEAP32[$331>>2] = $320;
              $332 = (($330) + 4)|0;
              $333 = $332;
              HEAP32[$333>>2] = $323;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$$byval_copy39+4>>2]=HEAP32[$23+4>>2]|0;
              $334 = (invoke_ii(3297,($$byval_copy39|0))|0);
              $335 = __THREW__; __THREW__ = 0;
              $336 = $335&1;
              if ($336) {
               label = 69;
               break L85;
              }
              if ((($i$0411$i$i|0) == 12)) {
               $337 = (($326) + 120|0);
               $338 = HEAP32[$337>>2]|0;
               HEAP32[$klassArray$i$i$i>>2] = $338;
               HEAP32[$210>>2] = $338;
               __THREW__ = 0;
               $339 = (invoke_iiiiiiii(112,($324|0),($325|0),($140|0),($klassArray$i$i$i|0),2,($errorContext|0),($326|0))|0);
               $340 = __THREW__; __THREW__ = 0;
               $341 = $340&1;
               if ($341) {
                label = 69;
                break L85;
               }
               if ($339) {
                $608 = $324;$610 = $325;
                break;
               }
               $342 = HEAP32[599912>>2]|0;
               $343 = HEAP8[((599912 + 4|0))>>0]|0;
               $608 = $342;$610 = $343;
               break;
              } else if ((($i$0411$i$i|0) == 17)) {
               $344 = (($326) + 568|0);
               $345 = HEAP32[$344>>2]|0;
               $346 = (($326) + 200|0);
               $347 = HEAP32[$346>>2]|0;
               HEAP32[$klassArray$i$i$i>>2] = $345;
               HEAP32[$210>>2] = $347;
               __THREW__ = 0;
               $348 = (invoke_iiiiiiii(112,($324|0),($325|0),($140|0),($klassArray$i$i$i|0),2,($errorContext|0),($326|0))|0);
               $349 = __THREW__; __THREW__ = 0;
               $350 = $349&1;
               if ($350) {
                label = 69;
                break L85;
               }
               if ($348) {
                $608 = $324;$610 = $325;
                break;
               }
               $351 = HEAP32[599912>>2]|0;
               $352 = HEAP8[((599912 + 4|0))>>0]|0;
               $608 = $351;$610 = $352;
               break;
              } else {
               $i$0$off$i$i = (($i$0411$i$i) + -19)|0;
               $353 = ($i$0$off$i$i>>>0)<(5);
               if ($353) {
                $354 = HEAP32[$298>>2]|0;
                __THREW__ = 0;
                $355 = (invoke_i(84)|0);
                $356 = __THREW__; __THREW__ = 0;
                $357 = $356&1;
                if ($357) {
                 label = 69;
                 break L85;
                }
                $358 = (($355) + 584|0);
                $359 = HEAP32[$358>>2]|0;
                $360 = 599912;
                $361 = $360;
                $362 = HEAP32[$361>>2]|0;
                $363 = (($360) + 4)|0;
                $364 = $363;
                $365 = HEAP32[$364>>2]|0;
                L114: do {
                 if ($$old1$i$i$i) {
                  $376 = $362;
                  $377 = $365&255;
                  $378 = ($362|0)==(0);
                  if ($378) {
                   $608 = 0;$610 = $377;
                   break L100;
                  } else {
                   $385 = $376;$386 = $377;
                  }
                 } else {
                  $currentClass$0$i$i$i = $140;
                  while(1) {
                   __THREW__ = 0;
                   invoke_viiii(393,($3|0),($140|0),($354|0),-1);
                   $366 = __THREW__; __THREW__ = 0;
                   $367 = $366&1;
                   if ($367) {
                    label = 68;
                    break L85;
                   }
                   $368 = HEAP32[$3>>2]|0;
                   $369 = HEAP8[$209>>0]|0;
                   $370 = ($368|0)==(0|0);
                   if (!($370)) {
                    $385 = $368;$386 = $369;
                    break L114;
                   }
                   __THREW__ = 0;
                   $371 = (invoke_ii(3295,($currentClass$0$i$i$i|0))|0);
                   $372 = __THREW__; __THREW__ = 0;
                   $373 = $372&1;
                   if ($373) {
                    label = 68;
                    break L85;
                   }
                   $374 = ($371|0)!=($359|0);
                   $375 = ($371|0)!=(0|0);
                   $or$cond$i57$i$i = $374 & $375;
                   if ($or$cond$i57$i$i) {
                    $currentClass$0$i$i$i = $371;
                   } else {
                    $608 = 0;$610 = $369;
                    break L100;
                   }
                  }
                 }
                } while(0);
                $379 = (($326) + 552|0);
                $380 = HEAP32[$379>>2]|0;
                $381 = (($326) + 556|0);
                $382 = HEAP32[$381>>2]|0;
                $383 = (($326) + 200|0);
                $384 = HEAP32[$383>>2]|0;
                HEAP32[$klassArray$i60$i$i>>2] = $380;
                HEAP32[$207>>2] = $382;
                HEAP32[$208>>2] = $384;
                __THREW__ = 0;
                $387 = (invoke_iiiiiiii(112,($385|0),($386|0),($140|0),($klassArray$i60$i$i|0),3,($errorContext|0),($326|0))|0);
                $388 = __THREW__; __THREW__ = 0;
                $389 = $388&1;
                if ($389) {
                 label = 69;
                 break L85;
                }
                if ($387) {
                 $608 = $385;$610 = $386;
                 break;
                }
                $390 = HEAP32[599912>>2]|0;
                $391 = HEAP8[((599912 + 4|0))>>0]|0;
                $608 = $390;$610 = $391;
                break;
               }
               $392 = $i$0411$i$i & -2;
               $393 = ($392|0)==(24);
               if ($393) {
                $394 = HEAP32[$298>>2]|0;
                __THREW__ = 0;
                $395 = (invoke_i(84)|0);
                $396 = __THREW__; __THREW__ = 0;
                $397 = $396&1;
                if ($397) {
                 label = 69;
                 break L85;
                }
                $398 = (($395) + 584|0);
                $399 = HEAP32[$398>>2]|0;
                $400 = 599912;
                $401 = $400;
                $402 = HEAP32[$401>>2]|0;
                $403 = (($400) + 4)|0;
                $404 = $403;
                $405 = HEAP32[$404>>2]|0;
                L128: do {
                 if ($$old1$i$i$i) {
                  $416 = $402;
                  $417 = $405&255;
                  $418 = ($402|0)==(0);
                  if ($418) {
                   $608 = 0;$610 = $417;
                   break L100;
                  } else {
                   $423 = $416;$424 = $417;
                  }
                 } else {
                  $currentClass$0$i64$i$i = $140;
                  while(1) {
                   __THREW__ = 0;
                   invoke_viiii(393,($2|0),($140|0),($394|0),-1);
                   $406 = __THREW__; __THREW__ = 0;
                   $407 = $406&1;
                   if ($407) {
                    label = 67;
                    break L85;
                   }
                   $408 = HEAP32[$2>>2]|0;
                   $409 = HEAP8[$211>>0]|0;
                   $410 = ($408|0)==(0|0);
                   if (!($410)) {
                    $423 = $408;$424 = $409;
                    break L128;
                   }
                   __THREW__ = 0;
                   $411 = (invoke_ii(3295,($currentClass$0$i64$i$i|0))|0);
                   $412 = __THREW__; __THREW__ = 0;
                   $413 = $412&1;
                   if ($413) {
                    label = 67;
                    break L85;
                   }
                   $414 = ($411|0)!=($399|0);
                   $415 = ($411|0)!=(0|0);
                   $or$cond$i65$i$i = $414 & $415;
                   if ($or$cond$i65$i$i) {
                    $currentClass$0$i64$i$i = $411;
                   } else {
                    $608 = 0;$610 = $409;
                    break L100;
                   }
                  }
                 }
                } while(0);
                $419 = (($326) + 552|0);
                $420 = HEAP32[$419>>2]|0;
                $421 = (($326) + 200|0);
                $422 = HEAP32[$421>>2]|0;
                HEAP32[$klassArray$i$i$i>>2] = $420;
                HEAP32[$210>>2] = $422;
                __THREW__ = 0;
                $425 = (invoke_iiiiiiii(112,($423|0),($424|0),($140|0),($klassArray$i$i$i|0),2,($errorContext|0),($326|0))|0);
                $426 = __THREW__; __THREW__ = 0;
                $427 = $426&1;
                if ($427) {
                 label = 69;
                 break L85;
                }
                if ($425) {
                 $608 = $423;$610 = $424;
                 break;
                }
                $428 = HEAP32[599912>>2]|0;
                $429 = HEAP8[((599912 + 4|0))>>0]|0;
                $608 = $428;$610 = $429;
                break;
               }
               $430 = ($334|0)==(0);
               if (!($430)) {
                $431 = HEAP32[599912>>2]|0;
                $432 = HEAP8[((599912 + 4|0))>>0]|0;
                __THREW__ = 0;
                $433 = (invoke_ii(3284,($140|0))|0);
                $434 = __THREW__; __THREW__ = 0;
                $435 = $434&1;
                if ($435) {
                 label = 69;
                 break L85;
                }
                __THREW__ = 0;
                $436 = (invoke_ii(2988,16)|0);
                $437 = __THREW__; __THREW__ = 0;
                $438 = $437&1;
                if ($438) {
                 label = 69;
                 break L85;
                }
                HEAP32[$221>>2] = $436;
                HEAP32[$28>>2] = 17;
                HEAP32[$222>>2] = 14;
                dest=$436+0|0; src=634416+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                $439 = (($436) + 14|0);
                HEAP8[$439>>0] = 0;
                __THREW__ = 0;
                invoke_viii(1627,($27|0),($28|0),($433|0));
                $440 = __THREW__; __THREW__ = 0;
                $441 = $440&1;
                if ($441) {
                 label = 136;
                 break L85;
                }
                __THREW__ = 0;
                invoke_viii(1627,($26|0),($27|0),(634432|0));
                $442 = __THREW__; __THREW__ = 0;
                $443 = $442&1;
                if ($443) {
                 label = 137;
                 break L85;
                }
                $444 = HEAP32[$298>>2]|0;
                __THREW__ = 0;
                invoke_viii(1627,($25|0),($26|0),($444|0));
                $445 = __THREW__; __THREW__ = 0;
                $446 = $445&1;
                if ($446) {
                 label = 138;
                 break L85;
                }
                __THREW__ = 0;
                invoke_viii(1627,($24|0),($25|0),(634440|0));
                $447 = __THREW__; __THREW__ = 0;
                $448 = $447&1;
                if ($448) {
                 label = 139;
                 break L85;
                }
                if ($214) {
                 $456 = 0;
                } else {
                 $449 = HEAP32[$220>>2]|0;
                 $456 = $449;
                }
                $450 = (($326) + 4|0);
                $451 = HEAP32[$450>>2]|0;
                $452 = HEAP8[$24>>0]|0;
                $453 = $452 & 1;
                $454 = ($453<<24>>24)==(0);
                $455 = HEAP32[$227>>2]|0;
                $$$i$i = $454 ? $223 : $455;
                __THREW__ = 0;
                invoke_viiiiiiii(21,($$$i$i|0),0,(634472|0),391,2052,($456|0),($451|0),(0|0));
                $457 = __THREW__; __THREW__ = 0;
                $458 = $457&1;
                if ($458) {
                 label = 140;
                 break L85;
                }
                $459 = HEAP8[$24>>0]|0;
                $460 = $459 & 1;
                $461 = ($460<<24>>24)==(0);
                if (!($461)) {
                 $462 = HEAP32[$227>>2]|0;
                 __ZdlPv($462);
                }
                $463 = HEAP8[$25>>0]|0;
                $464 = $463 & 1;
                $465 = ($464<<24>>24)==(0);
                if (!($465)) {
                 $466 = HEAP32[$226>>2]|0;
                 __ZdlPv($466);
                }
                $467 = HEAP8[$26>>0]|0;
                $468 = $467 & 1;
                $469 = ($468<<24>>24)==(0);
                if (!($469)) {
                 $470 = HEAP32[$225>>2]|0;
                 __ZdlPv($470);
                }
                $471 = HEAP8[$27>>0]|0;
                $472 = $471 & 1;
                $473 = ($472<<24>>24)==(0);
                if (!($473)) {
                 $474 = HEAP32[$224>>2]|0;
                 __ZdlPv($474);
                }
                $475 = HEAP8[$28>>0]|0;
                $476 = $475 & 1;
                $477 = ($476<<24>>24)==(0);
                if ($477) {
                 $608 = $431;$610 = $432;
                 break;
                }
                $478 = HEAP32[$221>>2]|0;
                __ZdlPv($478);
                $608 = $431;$610 = $432;
                break;
               }
               $509 = $323 & 255;
               $510 = $1;
               $511 = $510;
               HEAP32[$511>>2] = $320;
               $512 = (($510) + 4)|0;
               $513 = $512;
               HEAP32[$513>>2] = $509;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy39+4>>2]=HEAP32[$1+4>>2]|0;
               $514 = (invoke_ii(3298,($$byval_copy39|0))|0);
               $515 = __THREW__; __THREW__ = 0;
               $516 = $515&1;
               if ($516) {
                label = 69;
                break L85;
               }
               $517 = ($514|0)==(0|0);
               if ($517) {
                $608 = $324;$610 = $325;
                break;
               }
               __THREW__ = 0;
               $518 = (invoke_ii(3278,($514|0))|0);
               $519 = __THREW__; __THREW__ = 0;
               $520 = $519&1;
               if ($520) {
                label = 69;
                break L85;
               }
               $521 = (($326) + 140|0);
               $522 = HEAP32[$521>>2]|0;
               $523 = ($518|0)==($522|0);
               if (!($523)) {
                $608 = $324;$610 = $325;
                break;
               }
               $524 = ($392|0)==(4);
               if ($524) {
                $525 = HEAP32[599912>>2]|0;
                $526 = HEAP8[((599912 + 4|0))>>0]|0;
                $608 = $525;$610 = $526;
                break;
               }
               $i$0$off29$i$i = (($i$0411$i$i) + -10)|0;
               $527 = ($i$0$off29$i$i>>>0)>(1);
               if (!($527)) {
                $608 = $324;$610 = $325;
                break;
               }
               $528 = HEAP32[599912>>2]|0;
               $529 = HEAP8[((599912 + 4|0))>>0]|0;
               __THREW__ = 0;
               $530 = (invoke_ii(3284,($140|0))|0);
               $531 = __THREW__; __THREW__ = 0;
               $532 = $531&1;
               if ($532) {
                label = 69;
                break L85;
               }
               __THREW__ = 0;
               $533 = (invoke_ii(2988,16)|0);
               $534 = __THREW__; __THREW__ = 0;
               $535 = $534&1;
               if ($535) {
                label = 69;
                break L85;
               }
               HEAP32[$212>>2] = $533;
               HEAP32[$33>>2] = 17;
               HEAP32[$213>>2] = 14;
               dest=$533+0|0; src=634416+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
               $536 = (($533) + 14|0);
               HEAP8[$536>>0] = 0;
               __THREW__ = 0;
               invoke_viii(1627,($32|0),($33|0),($530|0));
               $537 = __THREW__; __THREW__ = 0;
               $538 = $537&1;
               if ($538) {
                label = 176;
                break L85;
               }
               __THREW__ = 0;
               invoke_viii(1627,($31|0),($32|0),(634432|0));
               $539 = __THREW__; __THREW__ = 0;
               $540 = $539&1;
               if ($540) {
                label = 177;
                break L85;
               }
               $541 = HEAP32[$298>>2]|0;
               __THREW__ = 0;
               invoke_viii(1627,($30|0),($31|0),($541|0));
               $542 = __THREW__; __THREW__ = 0;
               $543 = $542&1;
               if ($543) {
                label = 178;
                break L85;
               }
               __THREW__ = 0;
               invoke_viii(1627,($29|0),($30|0),(634552|0));
               $544 = __THREW__; __THREW__ = 0;
               $545 = $544&1;
               if ($545) {
                label = 179;
                break L85;
               }
               if ($214) {
                $553 = 0;
               } else {
                $546 = HEAP32[$220>>2]|0;
                $553 = $546;
               }
               $547 = (($326) + 4|0);
               $548 = HEAP32[$547>>2]|0;
               $549 = HEAP8[$29>>0]|0;
               $550 = $549 & 1;
               $551 = ($550<<24>>24)==(0);
               $552 = HEAP32[$219>>2]|0;
               $$436$i$i = $551 ? $215 : $552;
               __THREW__ = 0;
               invoke_viiiiiiii(21,($$436$i$i|0),0,(634472|0),401,2052,($553|0),($548|0),(0|0));
               $554 = __THREW__; __THREW__ = 0;
               $555 = $554&1;
               if ($555) {
                label = 180;
                break L85;
               }
               $556 = HEAP8[$29>>0]|0;
               $557 = $556 & 1;
               $558 = ($557<<24>>24)==(0);
               if (!($558)) {
                $559 = HEAP32[$219>>2]|0;
                __ZdlPv($559);
               }
               $560 = HEAP8[$30>>0]|0;
               $561 = $560 & 1;
               $562 = ($561<<24>>24)==(0);
               if (!($562)) {
                $563 = HEAP32[$218>>2]|0;
                __ZdlPv($563);
               }
               $564 = HEAP8[$31>>0]|0;
               $565 = $564 & 1;
               $566 = ($565<<24>>24)==(0);
               if (!($566)) {
                $567 = HEAP32[$217>>2]|0;
                __ZdlPv($567);
               }
               $568 = HEAP8[$32>>0]|0;
               $569 = $568 & 1;
               $570 = ($569<<24>>24)==(0);
               if (!($570)) {
                $571 = HEAP32[$216>>2]|0;
                __ZdlPv($571);
               }
               $572 = HEAP8[$33>>0]|0;
               $573 = $572 & 1;
               $574 = ($573<<24>>24)==(0);
               if ($574) {
                $608 = $528;$610 = $529;
                break;
               }
               $575 = HEAP32[$212>>2]|0;
               __ZdlPv($575);
               $608 = $528;$610 = $529;
               break;
              }
             }
            } while(0);
            $606 = HEAP32[$97>>2]|0;
            $607 = (($606) + ($i$0411$i$i<<3)|0);
            HEAP32[$607>>2] = $608;
            $609 = ((($606) + ($i$0411$i$i<<3)|0) + 4|0);
            HEAP8[$609>>0] = $610;
            $611 = (($i$0411$i$i) + 1)|0;
            $612 = ($611|0)<(26);
            if ($612) {
             $i$0411$i$i = $611;
            } else {
             label = 73;
             break;
            }
           }
           switch (label|0) {
            case 67: {
             $261 = ___cxa_find_matching_catch()|0;
             $262 = tempRet0;
             $eh$lpad$body$i$i$index12Z2D = $262;$eh$lpad$body$i$i$indexZ2D = $261;
             label = 72;
             break L83;
             break;
            }
            case 68: {
             $263 = ___cxa_find_matching_catch()|0;
             $264 = tempRet0;
             $eh$lpad$body$i$i$index12Z2D = $264;$eh$lpad$body$i$i$indexZ2D = $263;
             label = 72;
             break L83;
             break;
            }
            case 69: {
             $265 = ___cxa_find_matching_catch()|0;
             $266 = tempRet0;
             $eh$lpad$body$i$i$index12Z2D = $266;$eh$lpad$body$i$i$indexZ2D = $265;
             label = 72;
             break L83;
             break;
            }
            case 73: {
             $271 = ($145|0)>(0);
             L201: do {
              if ($271) {
               $272 = (($34) + 16|0);
               $273 = (($messageName$i$i$i) + 1|0);
               $274 = (($4) + 1|0);
               $275 = (($5) + 1|0);
               $276 = (($postfix$i$i$i) + 8|0);
               $277 = (($postfix$i$i$i) + 4|0);
               $278 = (($7) + 1|0);
               $279 = (($8) + 8|0);
               $280 = (($7) + 8|0);
               $281 = (($messageName$i$i$i) + 8|0);
               $282 = (($prefix$i$i$i) + 8|0);
               $283 = (($9) + 1|0);
               $284 = (($10) + 8|0);
               $285 = (($9) + 8|0);
               $286 = (($msg$i$i$i) + 4|0);
               $287 = (($msg$i$i$i) + 12|0);
               $288 = (($12) + 1|0);
               $289 = (($15) + 8|0);
               $290 = (($14) + 8|0);
               $291 = (($13) + 8|0);
               $292 = (($12) + 8|0);
               $293 = (($5) + 8|0);
               $294 = (($4) + 8|0);
               $295 = (($4) + 4|0);
               $296 = (($5) + 4|0);
               $297 = (($messageName$i$i$i) + 4|0);
               $i3$0379$i$i = 0;
               L203: while(1) {
                __THREW__ = 0;
                $613 = (invoke_i(103)|0);
                $614 = __THREW__; __THREW__ = 0;
                $615 = $614&1;
                if ($615) {
                 label = 66;
                 break;
                }
                __THREW__ = 0;
                invoke_viii(1915,($34|0),($613|0),($i3$0379$i$i|0));
                $616 = __THREW__; __THREW__ = 0;
                $617 = $616&1;
                if ($617) {
                 label = 66;
                 break;
                }
                $618 = HEAP32[$272>>2]|0;
                $619 = $618 & 1;
                $620 = ($619|0)==(0);
                if (!($620)) {
                 __THREW__ = 0;
                 $621 = (invoke_iii(2438,($613|0),($i3$0379$i$i|0))|0);
                 $622 = __THREW__; __THREW__ = 0;
                 $623 = $622&1;
                 if ($623) {
                  label = 66;
                  break;
                 }
                 $624 = HEAP32[$201>>2]|0;
                 $625 = ($624|0)==(0|0);
                 do {
                  if ($625) {
                   $642 = 599912;
                  } else {
                   $$0$ph7$i$i$i110$i$i = $203;$$01$ph6$i$in$i$i111$i$i = $624;
                   L211: while(1) {
                    $$013$i$in$i$i113$i$i = $$01$ph6$i$in$i$i111$i$i;
                    while(1) {
                     $626 = (($$013$i$in$i$i113$i$i) + 16|0);
                     $627 = HEAP32[$626>>2]|0;
                     $628 = (_strcmp($627,$621)|0);
                     $629 = ($628|0)<(0);
                     if (!($629)) {
                      break;
                     }
                     $632 = (($$013$i$in$i$i113$i$i) + 4|0);
                     $633 = HEAP32[$632>>2]|0;
                     $634 = ($633|0)==(0|0);
                     if ($634) {
                      $$0$ph5$i$i$i116$i$i = $$0$ph7$i$i$i110$i$i;
                      break L211;
                     } else {
                      $$013$i$in$i$i113$i$i = $633;
                     }
                    }
                    $630 = HEAP32[$$013$i$in$i$i113$i$i>>2]|0;
                    $631 = ($630|0)==(0|0);
                    if ($631) {
                     $$0$ph5$i$i$i116$i$i = $$013$i$in$i$i113$i$i;
                     break;
                    } else {
                     $$0$ph7$i$i$i110$i$i = $$013$i$in$i$i113$i$i;$$01$ph6$i$in$i$i111$i$i = $630;
                    }
                   }
                   $635 = ($$0$ph5$i$i$i116$i$i|0)==($203|0);
                   if ($635) {
                    $642 = 599912;
                    break;
                   }
                   $636 = (($$0$ph5$i$i$i116$i$i) + 16|0);
                   $637 = HEAP32[$636>>2]|0;
                   $638 = (_strcmp($621,$637)|0);
                   $639 = ($638|0)<(0);
                   if ($639) {
                    $642 = 599912;
                    break;
                   }
                   $640 = (($$0$ph5$i$i$i116$i$i) + 20|0);
                   $642 = $640;
                  }
                 } while(0);
                 $641 = $642;
                 $643 = $641;
                 $644 = HEAP32[$643>>2]|0;
                 $645 = (($641) + 4)|0;
                 $646 = $645;
                 $647 = HEAP32[$646>>2]|0;
                 $648 = $644;
                 $649 = ($644|0)==(0);
                 do {
                  if ($649) {
                   $1023 = 0;$1026 = $647;
                  } else {
                   __THREW__ = 0;
                   $650 = (invoke_i(102)|0);
                   $651 = __THREW__; __THREW__ = 0;
                   $652 = $651&1;
                   if ($652) {
                    label = 66;
                    break L203;
                   }
                   __THREW__ = 0;
                   $653 = (invoke_i(103)|0);
                   $654 = __THREW__; __THREW__ = 0;
                   $655 = $654&1;
                   if ($655) {
                    label = 66;
                    break L203;
                   }
                   __THREW__ = 0;
                   $656 = (invoke_iii(2438,($653|0),($i3$0379$i$i|0))|0);
                   $657 = __THREW__; __THREW__ = 0;
                   $658 = $657&1;
                   if ($658) {
                    label = 66;
                    break L203;
                   }
                   $659 = (_strlen(($656|0))|0);
                   $660 = ($659>>>0)>(4294967279);
                   if ($660) {
                    label = 208;
                    break L203;
                   }
                   $663 = ($659>>>0)<(11);
                   if ($663) {
                    $664 = $659 << 1;
                    $665 = $664&255;
                    HEAP8[$messageName$i$i$i>>0] = $665;
                    $675 = $665;$__p$0$i$i$i$i$i$i = $273;
                   } else {
                    $666 = (($659) + 16)|0;
                    $667 = $666 & -16;
                    __THREW__ = 0;
                    $668 = (invoke_ii(2988,($667|0))|0);
                    $669 = __THREW__; __THREW__ = 0;
                    $670 = $669&1;
                    if ($670) {
                     label = 66;
                     break L203;
                    }
                    HEAP32[$281>>2] = $668;
                    $671 = $667 | 1;
                    HEAP32[$messageName$i$i$i>>2] = $671;
                    HEAP32[$297>>2] = $659;
                    $672 = $671&255;
                    $675 = $672;$__p$0$i$i$i$i$i$i = $668;
                   }
                   _memcpy(($__p$0$i$i$i$i$i$i|0),($656|0),($659|0))|0;
                   $673 = (($__p$0$i$i$i$i$i$i) + ($659)|0);
                   HEAP8[$673>>0] = 0;
                   $674 = $675 & 1;
                   $676 = ($674<<24>>24)==(0);
                   if ($676) {
                    ;HEAP32[$5+0>>2]=HEAP32[$messageName$i$i$i+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$messageName$i$i$i+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$messageName$i$i$i+8>>2]|0;
                    $$pre$i$i$i = HEAP8[$5>>0]|0;
                    $694 = $$pre$i$i$i;
                   } else {
                    $677 = HEAP32[$281>>2]|0;
                    $678 = HEAP32[$297>>2]|0;
                    $679 = ($678>>>0)>(4294967279);
                    if ($679) {
                     label = 217;
                     break L203;
                    }
                    $682 = ($678>>>0)<(11);
                    if ($682) {
                     $683 = $678 << 1;
                     $684 = $683&255;
                     HEAP8[$5>>0] = $684;
                     $1087 = $684;$__p$0$i$i$i16$i$i$i = $275;
                    } else {
                     $685 = (($678) + 16)|0;
                     $686 = $685 & -16;
                     __THREW__ = 0;
                     $687 = (invoke_ii(2988,($686|0))|0);
                     $688 = __THREW__; __THREW__ = 0;
                     $689 = $688&1;
                     if ($689) {
                      label = 256;
                      break L203;
                     }
                     HEAP32[$293>>2] = $687;
                     $690 = $686 | 1;
                     HEAP32[$5>>2] = $690;
                     HEAP32[$296>>2] = $678;
                     $691 = $690&255;
                     $1087 = $691;$__p$0$i$i$i16$i$i$i = $687;
                    }
                    _memcpy(($__p$0$i$i$i16$i$i$i|0),($677|0),($678|0))|0;
                    $692 = (($__p$0$i$i$i16$i$i$i) + ($678)|0);
                    HEAP8[$692>>0] = 0;
                    $694 = $1087;
                   }
                   ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
                   $693 = $694 & 1;
                   $695 = ($693<<24>>24)==(0);
                   if ($695) {
                    $697 = $694&255;
                    $698 = $697 >>> 1;
                    $700 = $698;
                   } else {
                    $696 = HEAP32[$296>>2]|0;
                    $700 = $696;
                   }
                   $699 = (($700) + 14)|0;
                   $701 = ($699>>>0)>(4294967279);
                   if ($701) {
                    label = 228;
                    break L203;
                   }
                   $704 = ($699>>>0)<(11);
                   if ($704) {
                    HEAP8[$4>>0] = 28;
                    $__p$0$i$i$i$i$i = $274;
                   } else {
                    $705 = (($700) + 30)|0;
                    $706 = $705 & -16;
                    __THREW__ = 0;
                    $707 = (invoke_ii(2988,($706|0))|0);
                    $708 = __THREW__; __THREW__ = 0;
                    $709 = $708&1;
                    if ($709) {
                     label = 235;
                     break L203;
                    }
                    HEAP32[$294>>2] = $707;
                    $710 = $706 | 1;
                    HEAP32[$4>>2] = $710;
                    HEAP32[$295>>2] = 14;
                    $__p$0$i$i$i$i$i = $707;
                   }
                   dest=$__p$0$i$i$i$i$i+0|0; src=634584+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $711 = (($__p$0$i$i$i$i$i) + 14|0);
                   HEAP8[$711>>0] = 0;
                   $712 = HEAP32[$293>>2]|0;
                   $$437$i$i = $695 ? $275 : $712;
                   __THREW__ = 0;
                   (invoke_iiii(1480,($4|0),($$437$i$i|0),($700|0))|0);
                   $713 = __THREW__; __THREW__ = 0;
                   $714 = $713&1;
                   if ($714) {
                    label = 235;
                    break L203;
                   }
                   __THREW__ = 0;
                   invoke_viii(1627,($prefix$i$i$i|0),($4|0),(634600|0));
                   $723 = __THREW__; __THREW__ = 0;
                   $724 = $723&1;
                   if ($724) {
                    label = 260;
                    break L203;
                   }
                   $725 = HEAP8[$4>>0]|0;
                   $726 = $725 & 1;
                   $727 = ($726<<24>>24)==(0);
                   if (!($727)) {
                    $728 = HEAP32[$294>>2]|0;
                    __ZdlPv($728);
                   }
                   $729 = HEAP8[$5>>0]|0;
                   $730 = $729 & 1;
                   $731 = ($730<<24>>24)==(0);
                   if (!($731)) {
                    $732 = HEAP32[$293>>2]|0;
                    __ZdlPv($732);
                   }
                   __THREW__ = 0;
                   $733 = (invoke_ii(2988,32)|0);
                   $734 = __THREW__; __THREW__ = 0;
                   $735 = $734&1;
                   if ($735) {
                    label = 264;
                    break L203;
                   }
                   HEAP32[$276>>2] = $733;
                   HEAP32[$postfix$i$i$i>>2] = 33;
                   HEAP32[$277>>2] = 28;
                   dest=$733+0|0; src=634608+0|0; stop=dest+28|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
                   $736 = (($733) + 28|0);
                   HEAP8[$736>>0] = 0;
                   $737 = $647 & 255;
                   $738 = $6;
                   $739 = $738;
                   HEAP32[$739>>2] = $644;
                   $740 = (($738) + 4)|0;
                   $741 = $740;
                   HEAP32[$741>>2] = $737;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$$byval_copy39+4>>2]=HEAP32[$6+4>>2]|0;
                   $742 = (invoke_ii(3297,($$byval_copy39|0))|0);
                   $743 = __THREW__; __THREW__ = 0;
                   $744 = $743&1;
                   if ($744) {
                    label = 265;
                    break L203;
                   }
                   $745 = ($742>>>0)>(1);
                   L262: do {
                    if ($745) {
                     __THREW__ = 0;
                     invoke_viii(1627,($8|0),($prefix$i$i$i|0),(634640|0));
                     $746 = __THREW__; __THREW__ = 0;
                     $747 = $746&1;
                     if ($747) {
                      label = 265;
                      break L203;
                     }
                     __THREW__ = 0;
                     invoke_viii(1774,($7|0),($8|0),($postfix$i$i$i|0));
                     $748 = __THREW__; __THREW__ = 0;
                     $749 = $748&1;
                     if ($749) {
                      label = 266;
                      break L203;
                     }
                     if ($214) {
                      $757 = 0;
                     } else {
                      $750 = HEAP32[$220>>2]|0;
                      $757 = $750;
                     }
                     $751 = (($650) + 4|0);
                     $752 = HEAP32[$751>>2]|0;
                     $753 = HEAP8[$7>>0]|0;
                     $754 = $753 & 1;
                     $755 = ($754<<24>>24)==(0);
                     $756 = HEAP32[$280>>2]|0;
                     $$438$i$i = $755 ? $278 : $756;
                     __THREW__ = 0;
                     invoke_viiiiiiii(21,($$438$i$i|0),0,(634472|0),164,2052,($757|0),($752|0),(0|0));
                     $758 = __THREW__; __THREW__ = 0;
                     $759 = $758&1;
                     if ($759) {
                      label = 267;
                      break L203;
                     }
                     $760 = HEAP8[$7>>0]|0;
                     $761 = $760 & 1;
                     $762 = ($761<<24>>24)==(0);
                     if (!($762)) {
                      $763 = HEAP32[$280>>2]|0;
                      __ZdlPv($763);
                     }
                     $764 = HEAP8[$8>>0]|0;
                     $765 = $764 & 1;
                     $766 = ($765<<24>>24)==(0);
                     if ($766) {
                      $$0$i$i$i = 0;
                      break;
                     }
                     $767 = HEAP32[$279>>2]|0;
                     __ZdlPv($767);
                     $$0$i$i$i = 0;
                    } else {
                     __THREW__ = 0;
                     $798 = (invoke_i(84)|0);
                     $799 = __THREW__; __THREW__ = 0;
                     $800 = $799&1;
                     if ($800) {
                      label = 265;
                      break L203;
                     }
                     $801 = (($798) + 144|0);
                     $802 = HEAP32[$801>>2]|0;
                     __THREW__ = 0;
                     $803 = (invoke_i(84)|0);
                     $804 = __THREW__; __THREW__ = 0;
                     $805 = $804&1;
                     if ($805) {
                      label = 265;
                      break L203;
                     }
                     $806 = (($803) + 132|0);
                     $807 = HEAP32[$806>>2]|0;
                     $808 = ($742|0)==(1);
                     if (!($808)) {
                      $$0$i$i$i = 1;
                      break;
                     }
                     __THREW__ = 0;
                     $809 = (invoke_iii(2439,($653|0),($i3$0379$i$i|0))|0);
                     $810 = __THREW__; __THREW__ = 0;
                     $811 = $810&1;
                     if ($811) {
                      label = 265;
                      break L203;
                     }
                     $812 = ($809|0)==(0);
                     if ($812) {
                      __THREW__ = 0;
                      invoke_viii(1627,($10|0),($prefix$i$i$i|0),(634688|0));
                      $813 = __THREW__; __THREW__ = 0;
                      $814 = $813&1;
                      if ($814) {
                       label = 265;
                       break L203;
                      }
                      __THREW__ = 0;
                      invoke_viii(1774,($9|0),($10|0),($postfix$i$i$i|0));
                      $815 = __THREW__; __THREW__ = 0;
                      $816 = $815&1;
                      if ($816) {
                       label = 285;
                       break L203;
                      }
                      if ($214) {
                       $824 = 0;
                      } else {
                       $817 = HEAP32[$220>>2]|0;
                       $824 = $817;
                      }
                      $818 = (($650) + 4|0);
                      $819 = HEAP32[$818>>2]|0;
                      $820 = HEAP8[$9>>0]|0;
                      $821 = $820 & 1;
                      $822 = ($821<<24>>24)==(0);
                      $823 = HEAP32[$285>>2]|0;
                      $$439$i$i = $822 ? $283 : $823;
                      __THREW__ = 0;
                      invoke_viiiiiiii(21,($$439$i$i|0),0,(634472|0),177,2052,($824|0),($819|0),(0|0));
                      $825 = __THREW__; __THREW__ = 0;
                      $826 = $825&1;
                      if ($826) {
                       label = 286;
                       break L203;
                      }
                      $827 = HEAP8[$9>>0]|0;
                      $828 = $827 & 1;
                      $829 = ($828<<24>>24)==(0);
                      if (!($829)) {
                       $830 = HEAP32[$285>>2]|0;
                       __ZdlPv($830);
                      }
                      $831 = HEAP8[$10>>0]|0;
                      $832 = $831 & 1;
                      $833 = ($832<<24>>24)==(0);
                      if ($833) {
                       $$0$i$i$i = 0;
                       break;
                      }
                      $834 = HEAP32[$284>>2]|0;
                      __ZdlPv($834);
                      $$0$i$i$i = 0;
                      break;
                     }
                     $847 = $11;
                     $848 = $847;
                     HEAP32[$848>>2] = $644;
                     $849 = (($847) + 4)|0;
                     $850 = $849;
                     HEAP32[$850>>2] = $737;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$$byval_copy39+4>>2]=HEAP32[$11+4>>2]|0;
                     $851 = (invoke_iii(2440,($$byval_copy39|0),0)|0);
                     $852 = __THREW__; __THREW__ = 0;
                     $853 = $852&1;
                     if ($853) {
                      label = 265;
                      break L203;
                     }
                     __THREW__ = 0;
                     $854 = (invoke_ii(3278,($851|0))|0);
                     $855 = __THREW__; __THREW__ = 0;
                     $856 = $855&1;
                     if ($856) {
                      label = 265;
                      break L203;
                     }
                     __THREW__ = 0;
                     invoke_viii(1915,($msg$i$i$i|0),($653|0),($i3$0379$i$i|0));
                     $857 = __THREW__; __THREW__ = 0;
                     $858 = $857&1;
                     if ($858) {
                      label = 265;
                      break L203;
                     }
                     $859 = HEAP32[$286>>2]|0;
                     $860 = ($859|0)==(0|0);
                     if ($860) {
                      $formattedMsgParameter$0$i$i$i = 634408;
                     } else {
                      __THREW__ = 0;
                      $861 = (invoke_iiii(1558,($807|0),(634736|0),($859|0))|0);
                      $862 = __THREW__; __THREW__ = 0;
                      $863 = $862&1;
                      if ($863) {
                       label = 265;
                       break L203;
                      }
                      $864 = ($854|0)==($861|0);
                      $865 = ($861|0)!=(0|0);
                      $or$cond3$i$i$i = $864 & $865;
                      if ($or$cond3$i$i$i) {
                       $$0$i$i$i = 1;
                       break;
                      }
                      $866 = HEAP32[$286>>2]|0;
                      $formattedMsgParameter$0$i$i$i = $866;
                     }
                     $867 = ($854|0)==($802|0);
                     if ($867) {
                      $$0$i$i$i = 1;
                      break;
                     }
                     $868 = HEAP32[$287>>2]|0;
                     do {
                      if ((($868|0) == 100004)) {
                       $869 = (($650) + 256|0);
                       $870 = HEAP32[$869>>2]|0;
                       $871 = ($854|0)==($870|0);
                       if ($871) {
                        $$0$i$i$i = 1;
                        break L262;
                       } else {
                        $formattedMsgParameter$1$i$i$i = 634752;
                       }
                      } else if ((($868|0) == 100007)) {
                       $872 = (($650) + 268|0);
                       $873 = HEAP32[$872>>2]|0;
                       $874 = ($854|0)==($873|0);
                       if ($874) {
                        $$0$i$i$i = 1;
                        break L262;
                       } else {
                        $formattedMsgParameter$1$i$i$i = 634768;
                       }
                      } else {
                       $875 = ($868|0)>(-1);
                       $876 = HEAP32[560640>>2]|0;
                       $877 = ($876|0)>($868|0);
                       $or$cond$i$i$i = $875 & $877;
                       if (!($or$cond$i$i$i)) {
                        $formattedMsgParameter$1$i$i$i = $formattedMsgParameter$0$i$i$i;
                        break;
                       }
                       $878 = ($854|0)==(0|0);
                       do {
                        if ($878) {
                         $897 = $868;
                        } else {
                         __THREW__ = 0;
                         $879 = (invoke_ii(3299,($854|0))|0);
                         $880 = __THREW__; __THREW__ = 0;
                         $881 = $880&1;
                         if ($881) {
                          label = 265;
                          break L203;
                         }
                         $882 = ($879|0)>(-1);
                         $883 = HEAP32[560640>>2]|0;
                         $884 = ($883|0)>($879|0);
                         $or$cond5$i$i$i = $882 & $884;
                         $885 = HEAP32[$287>>2]|0;
                         if (!($or$cond5$i$i$i)) {
                          $897 = $885;
                          break;
                         }
                         $886 = Math_imul($885, $883)|0;
                         $887 = (($886) + ($879))|0;
                         $888 = $887 >> 5;
                         $889 = $888 << 5;
                         $890 = (($887) - ($889))|0;
                         $891 = HEAP32[560632>>2]|0;
                         $892 = (($891) + ($888<<2)|0);
                         $893 = HEAP32[$892>>2]|0;
                         $894 = 1 << $890;
                         $895 = $893 & $894;
                         $896 = ($895|0)==(0);
                         if ($896) {
                          $897 = $885;
                         } else {
                          $$0$i$i$i = 1;
                          break L262;
                         }
                        }
                       } while(0);
                       __THREW__ = 0;
                       $898 = (invoke_ii(3216,($897|0))|0);
                       $899 = __THREW__; __THREW__ = 0;
                       $900 = $899&1;
                       if ($900) {
                        label = 265;
                        break L203;
                       }
                       $901 = HEAP8[$898>>0]|0;
                       $902 = $901 & 1;
                       $903 = ($902<<24>>24)==(0);
                       if ($903) {
                        $906 = (($898) + 1|0);
                        $formattedMsgParameter$1$i$i$i = $906;
                        break;
                       } else {
                        $904 = (($898) + 8|0);
                        $905 = HEAP32[$904>>2]|0;
                        $formattedMsgParameter$1$i$i$i = $905;
                        break;
                       }
                      }
                     } while(0);
                     $907 = HEAP32[$287>>2]|0;
                     $908 = ($907|0)==(100003);
                     if ($908) {
                      $$0$i$i$i = 1;
                      break;
                     }
                     __THREW__ = 0;
                     $909 = (invoke_i(84)|0);
                     $910 = __THREW__; __THREW__ = 0;
                     $911 = $910&1;
                     if ($911) {
                      label = 265;
                      break L203;
                     }
                     $912 = (($909) + 168|0);
                     $913 = HEAP32[$912>>2]|0;
                     $914 = ($854|0)==($913|0);
                     if ($914) {
                      $915 = HEAP32[$287>>2]|0;
                      $916 = ($915|0)==(100001);
                      if ($916) {
                       $$0$i$i$i = 1;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     $917 = (invoke_i(84)|0);
                     $918 = __THREW__; __THREW__ = 0;
                     $919 = $918&1;
                     if ($919) {
                      label = 265;
                      break L203;
                     }
                     $920 = (($917) + 200|0);
                     $921 = HEAP32[$920>>2]|0;
                     $922 = ($854|0)==($921|0);
                     if ($922) {
                      $923 = HEAP32[$287>>2]|0;
                      $924 = ($923|0)==(100000);
                      if ($924) {
                       $$0$i$i$i = 1;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     $925 = (invoke_i(84)|0);
                     $926 = __THREW__; __THREW__ = 0;
                     $927 = $926&1;
                     if ($927) {
                      label = 265;
                      break L203;
                     }
                     $928 = (($925) + 208|0);
                     $929 = HEAP32[$928>>2]|0;
                     $930 = ($854|0)==($929|0);
                     if ($930) {
                      $931 = HEAP32[$287>>2]|0;
                      $932 = ($931|0)==(100002);
                      if ($932) {
                       $$0$i$i$i = 1;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     invoke_viii(1627,($15|0),($prefix$i$i$i|0),(634784|0));
                     $933 = __THREW__; __THREW__ = 0;
                     $934 = $933&1;
                     if ($934) {
                      label = 265;
                      break L203;
                     }
                     __THREW__ = 0;
                     invoke_viii(1627,($14|0),($15|0),($formattedMsgParameter$1$i$i$i|0));
                     $935 = __THREW__; __THREW__ = 0;
                     $936 = $935&1;
                     if ($936) {
                      label = 335;
                      break L203;
                     }
                     __THREW__ = 0;
                     invoke_viii(1627,($13|0),($14|0),(634600|0));
                     $937 = __THREW__; __THREW__ = 0;
                     $938 = $937&1;
                     if ($938) {
                      label = 336;
                      break L203;
                     }
                     __THREW__ = 0;
                     invoke_viii(1774,($12|0),($13|0),($postfix$i$i$i|0));
                     $939 = __THREW__; __THREW__ = 0;
                     $940 = $939&1;
                     if ($940) {
                      label = 337;
                      break L203;
                     }
                     if ($214) {
                      $948 = 0;
                     } else {
                      $941 = HEAP32[$220>>2]|0;
                      $948 = $941;
                     }
                     $942 = (($650) + 4|0);
                     $943 = HEAP32[$942>>2]|0;
                     $944 = HEAP8[$12>>0]|0;
                     $945 = $944 & 1;
                     $946 = ($945<<24>>24)==(0);
                     $947 = HEAP32[$292>>2]|0;
                     $$440$i$i = $946 ? $288 : $947;
                     __THREW__ = 0;
                     invoke_viiiiiiii(21,($$440$i$i|0),0,(634472|0),247,2052,($948|0),($943|0),(0|0));
                     $949 = __THREW__; __THREW__ = 0;
                     $950 = $949&1;
                     if ($950) {
                      label = 338;
                      break L203;
                     }
                     $951 = HEAP8[$12>>0]|0;
                     $952 = $951 & 1;
                     $953 = ($952<<24>>24)==(0);
                     if (!($953)) {
                      $954 = HEAP32[$292>>2]|0;
                      __ZdlPv($954);
                     }
                     $955 = HEAP8[$13>>0]|0;
                     $956 = $955 & 1;
                     $957 = ($956<<24>>24)==(0);
                     if (!($957)) {
                      $958 = HEAP32[$291>>2]|0;
                      __ZdlPv($958);
                     }
                     $959 = HEAP8[$14>>0]|0;
                     $960 = $959 & 1;
                     $961 = ($960<<24>>24)==(0);
                     if (!($961)) {
                      $962 = HEAP32[$290>>2]|0;
                      __ZdlPv($962);
                     }
                     $963 = HEAP8[$15>>0]|0;
                     $964 = $963 & 1;
                     $965 = ($964<<24>>24)==(0);
                     if ($965) {
                      $$0$i$i$i = 0;
                      break;
                     }
                     $966 = HEAP32[$289>>2]|0;
                     __ZdlPv($966);
                     $$0$i$i$i = 0;
                    }
                   } while(0);
                   $991 = HEAP8[$postfix$i$i$i>>0]|0;
                   $992 = $991 & 1;
                   $993 = ($992<<24>>24)==(0);
                   if (!($993)) {
                    $994 = HEAP32[$276>>2]|0;
                    __ZdlPv($994);
                   }
                   $995 = HEAP8[$prefix$i$i$i>>0]|0;
                   $996 = $995 & 1;
                   $997 = ($996<<24>>24)==(0);
                   if (!($997)) {
                    $998 = HEAP32[$282>>2]|0;
                    __ZdlPv($998);
                   }
                   $1003 = HEAP8[$messageName$i$i$i>>0]|0;
                   $1004 = $1003 & 1;
                   $1005 = ($1004<<24>>24)==(0);
                   if (!($1005)) {
                    $1006 = HEAP32[$281>>2]|0;
                    __ZdlPv($1006);
                   }
                   if ($$0$i$i$i) {
                    $1023 = $648;$1026 = $647;
                    break;
                   }
                   $1015 = HEAP32[599912>>2]|0;
                   $1016 = HEAP8[((599912 + 4|0))>>0]|0;
                   $1017 = $1016&255;
                   $1018 = $647 & -256;
                   $1019 = $1017 | $1018;
                   $1023 = $1015;$1026 = $1019;
                  }
                 } while(0);
                 $1020 = (($i3$0379$i$i) + 26)|0;
                 $1021 = HEAP32[$97>>2]|0;
                 $1022 = (($1021) + ($1020<<3)|0);
                 HEAP32[$1022>>2] = $1023;
                 $1024 = ((($1021) + ($1020<<3)|0) + 4|0);
                 $1025 = $1026&255;
                 HEAP8[$1024>>0] = $1025;
                }
                $1027 = (($i3$0379$i$i) + 1)|0;
                $1028 = ($1027|0)<($145|0);
                if ($1028) {
                 $i3$0379$i$i = $1027;
                } else {
                 break L201;
                }
               }
               switch (label|0) {
                case 66: {
                 $259 = ___cxa_find_matching_catch()|0;
                 $260 = tempRet0;
                 $eh$lpad$body$i$i$index12Z2D = $260;$eh$lpad$body$i$i$indexZ2D = $259;
                 label = 72;
                 break L83;
                 break;
                }
                case 208: {
                 __THREW__ = 0;
                 invoke_vi(3309,0);
                 $661 = __THREW__; __THREW__ = 0;
                 $662 = $661&1;
                 if ($662) {
                  $269 = ___cxa_find_matching_catch()|0;
                  $270 = tempRet0;
                  $eh$lpad$body$i$i$index12Z2D = $270;$eh$lpad$body$i$i$indexZ2D = $269;
                  label = 72;
                  break L83;
                 } else {
                  // unreachable;
                 }
                 break;
                }
                case 217: {
                 __THREW__ = 0;
                 invoke_vi(3309,0);
                 $680 = __THREW__; __THREW__ = 0;
                 $681 = $680&1;
                 if ($681) {
                  $770 = ___cxa_find_matching_catch()|0;
                  $771 = tempRet0;
                  $lpad$phi170$i$i$index = $770;$lpad$phi170$i$i$index27 = $771;
                  label = 258;
                  break;
                 } else {
                  // unreachable;
                 }
                 break;
                }
                case 228: {
                 __THREW__ = 0;
                 invoke_vi(3309,0);
                 $702 = __THREW__; __THREW__ = 0;
                 $703 = $702&1;
                 if ($703) {
                  $717 = ___cxa_find_matching_catch()|0;
                  $718 = tempRet0;
                  $lpad$phi175$i$i$index = $717;$lpad$phi175$i$i$index22 = $718;
                  label = 237;
                  break;
                 } else {
                  // unreachable;
                 }
                 break;
                }
                case 235: {
                 $715 = ___cxa_find_matching_catch()|0;
                 $716 = tempRet0;
                 $lpad$phi175$i$i$index = $715;$lpad$phi175$i$i$index22 = $716;
                 label = 237;
                 break;
                }
                case 256: {
                 $768 = ___cxa_find_matching_catch()|0;
                 $769 = tempRet0;
                 $lpad$phi170$i$i$index = $768;$lpad$phi170$i$i$index27 = $769;
                 label = 258;
                 break;
                }
                case 260: {
                 $772 = ___cxa_find_matching_catch()|0;
                 $773 = tempRet0;
                 $774 = HEAP8[$4>>0]|0;
                 $775 = $774 & 1;
                 $776 = ($775<<24>>24)==(0);
                 if ($776) {
                  $$04$i$i$i = $772;$$05$i$i$i = $773;
                  label = 262;
                  break;
                 }
                 $777 = HEAP32[$294>>2]|0;
                 __ZdlPv($777);
                 $$04$i$i$i = $772;$$05$i$i$i = $773;
                 label = 262;
                 break;
                }
                case 264: {
                 $782 = ___cxa_find_matching_catch()|0;
                 $783 = tempRet0;
                 $$7$i$i$i = $782;$$712$i$i$i = $783;
                 label = 354;
                 break;
                }
                case 265: {
                 $784 = ___cxa_find_matching_catch()|0;
                 $785 = tempRet0;
                 $$6$i$i$i = $784;$$611$i$i$i = $785;
                 label = 350;
                 break;
                }
                case 266: {
                 $786 = ___cxa_find_matching_catch()|0;
                 $787 = tempRet0;
                 $$1$i$i$i = $786;$$16$i$i$i = $787;
                 label = 269;
                 break;
                }
                case 267: {
                 $788 = ___cxa_find_matching_catch()|0;
                 $789 = tempRet0;
                 $790 = HEAP8[$7>>0]|0;
                 $791 = $790 & 1;
                 $792 = ($791<<24>>24)==(0);
                 if ($792) {
                  $$1$i$i$i = $788;$$16$i$i$i = $789;
                  label = 269;
                  break;
                 }
                 $793 = HEAP32[$280>>2]|0;
                 __ZdlPv($793);
                 $$1$i$i$i = $788;$$16$i$i$i = $789;
                 label = 269;
                 break;
                }
                case 285: {
                 $835 = ___cxa_find_matching_catch()|0;
                 $836 = tempRet0;
                 $$2$i$i$i = $835;$$27$i$i$i = $836;
                 label = 288;
                 break;
                }
                case 286: {
                 $837 = ___cxa_find_matching_catch()|0;
                 $838 = tempRet0;
                 $839 = HEAP8[$9>>0]|0;
                 $840 = $839 & 1;
                 $841 = ($840<<24>>24)==(0);
                 if ($841) {
                  $$2$i$i$i = $837;$$27$i$i$i = $838;
                  label = 288;
                  break;
                 }
                 $842 = HEAP32[$285>>2]|0;
                 __ZdlPv($842);
                 $$2$i$i$i = $837;$$27$i$i$i = $838;
                 label = 288;
                 break;
                }
                case 335: {
                 $967 = ___cxa_find_matching_catch()|0;
                 $968 = tempRet0;
                 $$5$i$i$i = $967;$$510$i$i$i = $968;
                 label = 344;
                 break;
                }
                case 336: {
                 $969 = ___cxa_find_matching_catch()|0;
                 $970 = tempRet0;
                 $$4$i$i$i = $969;$$49$i$i$i = $970;
                 label = 342;
                 break;
                }
                case 337: {
                 $971 = ___cxa_find_matching_catch()|0;
                 $972 = tempRet0;
                 $$3$i$i$i = $971;$$38$i$i$i = $972;
                 label = 340;
                 break;
                }
                case 338: {
                 $973 = ___cxa_find_matching_catch()|0;
                 $974 = tempRet0;
                 $975 = HEAP8[$12>>0]|0;
                 $976 = $975 & 1;
                 $977 = ($976<<24>>24)==(0);
                 if ($977) {
                  $$3$i$i$i = $973;$$38$i$i$i = $974;
                  label = 340;
                  break;
                 }
                 $978 = HEAP32[$292>>2]|0;
                 __ZdlPv($978);
                 $$3$i$i$i = $973;$$38$i$i$i = $974;
                 label = 340;
                 break;
                }
               }
               do {
                if ((label|0) == 237) {
                 $719 = HEAP8[$4>>0]|0;
                 $720 = $719 & 1;
                 $721 = ($720<<24>>24)==(0);
                 if (!($721)) {
                  $722 = HEAP32[$294>>2]|0;
                  __ZdlPv($722);
                 }
                 $$04$i$i$i = $lpad$phi175$i$i$index;$$05$i$i$i = $lpad$phi175$i$i$index22;
                 label = 262;
                }
                else if ((label|0) == 258) {
                 $$8$i$i$i = $lpad$phi170$i$i$index;$$813$i$i$i = $lpad$phi170$i$i$index27;
                }
                else if ((label|0) == 269) {
                 $794 = HEAP8[$8>>0]|0;
                 $795 = $794 & 1;
                 $796 = ($795<<24>>24)==(0);
                 if ($796) {
                  $$6$i$i$i = $$1$i$i$i;$$611$i$i$i = $$16$i$i$i;
                  label = 350;
                  break;
                 }
                 $797 = HEAP32[$279>>2]|0;
                 __ZdlPv($797);
                 $$6$i$i$i = $$1$i$i$i;$$611$i$i$i = $$16$i$i$i;
                 label = 350;
                }
                else if ((label|0) == 288) {
                 $843 = HEAP8[$10>>0]|0;
                 $844 = $843 & 1;
                 $845 = ($844<<24>>24)==(0);
                 if ($845) {
                  $$6$i$i$i = $$2$i$i$i;$$611$i$i$i = $$27$i$i$i;
                  label = 350;
                  break;
                 }
                 $846 = HEAP32[$284>>2]|0;
                 __ZdlPv($846);
                 $$6$i$i$i = $$2$i$i$i;$$611$i$i$i = $$27$i$i$i;
                 label = 350;
                }
                else if ((label|0) == 340) {
                 $979 = HEAP8[$13>>0]|0;
                 $980 = $979 & 1;
                 $981 = ($980<<24>>24)==(0);
                 if ($981) {
                  $$4$i$i$i = $$3$i$i$i;$$49$i$i$i = $$38$i$i$i;
                  label = 342;
                  break;
                 }
                 $982 = HEAP32[$291>>2]|0;
                 __ZdlPv($982);
                 $$4$i$i$i = $$3$i$i$i;$$49$i$i$i = $$38$i$i$i;
                 label = 342;
                }
               } while(0);
               do {
                if ((label|0) == 262) {
                 $778 = HEAP8[$5>>0]|0;
                 $779 = $778 & 1;
                 $780 = ($779<<24>>24)==(0);
                 if ($780) {
                  $$8$i$i$i = $$04$i$i$i;$$813$i$i$i = $$05$i$i$i;
                  break;
                 }
                 $781 = HEAP32[$293>>2]|0;
                 __ZdlPv($781);
                 $$8$i$i$i = $$04$i$i$i;$$813$i$i$i = $$05$i$i$i;
                }
                else if ((label|0) == 342) {
                 $983 = HEAP8[$14>>0]|0;
                 $984 = $983 & 1;
                 $985 = ($984<<24>>24)==(0);
                 if ($985) {
                  $$5$i$i$i = $$4$i$i$i;$$510$i$i$i = $$49$i$i$i;
                  label = 344;
                  break;
                 }
                 $986 = HEAP32[$290>>2]|0;
                 __ZdlPv($986);
                 $$5$i$i$i = $$4$i$i$i;$$510$i$i$i = $$49$i$i$i;
                 label = 344;
                }
               } while(0);
               do {
                if ((label|0) == 344) {
                 $987 = HEAP8[$15>>0]|0;
                 $988 = $987 & 1;
                 $989 = ($988<<24>>24)==(0);
                 if ($989) {
                  $$6$i$i$i = $$5$i$i$i;$$611$i$i$i = $$510$i$i$i;
                  label = 350;
                  break;
                 }
                 $990 = HEAP32[$289>>2]|0;
                 __ZdlPv($990);
                 $$6$i$i$i = $$5$i$i$i;$$611$i$i$i = $$510$i$i$i;
                 label = 350;
                }
               } while(0);
               do {
                if ((label|0) == 350) {
                 $999 = HEAP8[$postfix$i$i$i>>0]|0;
                 $1000 = $999 & 1;
                 $1001 = ($1000<<24>>24)==(0);
                 if ($1001) {
                  $$7$i$i$i = $$6$i$i$i;$$712$i$i$i = $$611$i$i$i;
                  label = 354;
                  break;
                 }
                 $1002 = HEAP32[$276>>2]|0;
                 __ZdlPv($1002);
                 $$7$i$i$i = $$6$i$i$i;$$712$i$i$i = $$611$i$i$i;
                 label = 354;
                }
               } while(0);
               do {
                if ((label|0) == 354) {
                 $1007 = HEAP8[$prefix$i$i$i>>0]|0;
                 $1008 = $1007 & 1;
                 $1009 = ($1008<<24>>24)==(0);
                 if ($1009) {
                  $$8$i$i$i = $$7$i$i$i;$$813$i$i$i = $$712$i$i$i;
                  break;
                 }
                 $1010 = HEAP32[$282>>2]|0;
                 __ZdlPv($1010);
                 $$8$i$i$i = $$7$i$i$i;$$813$i$i$i = $$712$i$i$i;
                }
               } while(0);
               $1011 = HEAP8[$messageName$i$i$i>>0]|0;
               $1012 = $1011 & 1;
               $1013 = ($1012<<24>>24)==(0);
               if (!($1013)) {
                $1014 = HEAP32[$281>>2]|0;
                __ZdlPv($1014);
               }
               $eh$lpad$body$i$i$index12Z2D = $$813$i$i$i;$eh$lpad$body$i$i$indexZ2D = $$8$i$i$i;
               label = 72;
               break L83;
              }
             } while(0);
             $1029 = HEAP32[$201>>2]|0;
             __ZNSt3__16__treeINS_12__value_typeIPKc21ScriptingMethodIl2CppEENS_19__map_value_compareIS3_S5_14CStringCompareLb1EEE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($methodMap$i$i,$1029);
             $1030 = HEAP32[$allMethods$i$i>>2]|0;
             $1031 = ($1030|0)==(0|0);
             do {
              if (!($1031)) {
               $1032 = HEAP32[$189>>2]|0;
               $1033 = ($1032|0)==($1030|0);
               if (!($1033)) {
                $__new_last2$i$i$i$i$i36$i$i = $1030;
                $scevgep$i$i$i$i$i37$i$i = (($1032) + -8|0);
                $1034 = (0 - ($__new_last2$i$i$i$i$i36$i$i))|0;
                $uglygep$i$i$i$i$i39$i$i = (($scevgep$i$i$i$i$i37$i$i) + ($1034)|0);
                $uglygep3$i$i$i$i$i40$i$i = $uglygep$i$i$i$i$i39$i$i;
                $1035 = $uglygep3$i$i$i$i$i40$i$i >>> 3;
                $1036 = $1035 ^ -1;
                $scevgep4$i$i$i$i$i41$i$i = (($1032) + ($1036<<3)|0);
                HEAP32[$189>>2] = $scevgep4$i$i$i$i$i41$i$i;
               }
               HEAP32[$16>>2] = 90;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$16+0>>2]|0;
               invoke_vii(2591,($1030|0),($$byval_copy39|0));
               $1037 = __THREW__; __THREW__ = 0;
               $1038 = $1037&1;
               if (!($1038)) {
                break;
               }
               $1039 = ___cxa_find_matching_catch()|0;
               $1040 = tempRet0;
               ___cxa_call_unexpected(($1039|0));
               // unreachable;
              }
             } while(0);
             __THREW__ = 0;
             $1053 = (invoke_i(84)|0);
             $1054 = __THREW__; __THREW__ = 0;
             $1055 = $1054&1;
             if ($1055) {
              label = 7;
              break L11;
             }
             $1056 = (($1053) + 584|0);
             $1057 = HEAP32[$1056>>2]|0;
             __THREW__ = 0;
             $1058 = (invoke_iii(2432,($92|0),($1057|0))|0);
             $1059 = __THREW__; __THREW__ = 0;
             $1060 = $1059&1;
             if ($1060) {
              label = 7;
              break L11;
             }
             $1061 = $1058&1;
             HEAP8[$105>>0] = $1061;
             __THREW__ = 0;
             $1062 = (invoke_i(84)|0);
             $1063 = __THREW__; __THREW__ = 0;
             $1064 = $1063&1;
             if ($1064) {
              label = 7;
              break L11;
             }
             $1065 = (($1062) + 580|0);
             $1066 = HEAP32[$1065>>2]|0;
             __THREW__ = 0;
             $1067 = (invoke_iii(2441,($92|0),($1066|0))|0);
             $1068 = __THREW__; __THREW__ = 0;
             $1069 = $1068&1;
             if ($1069) {
              label = 7;
              break L11;
             }
             $1070 = $1067&1;
             HEAP8[$106>>0] = $1070;
             $$0 = $94;
             break L20;
             break;
            }
            case 136: {
             $479 = ___cxa_find_matching_catch()|0;
             $480 = tempRet0;
             $$3$i$i = $479;$$317$i$i = $480;
             label = 148;
             break;
            }
            case 137: {
             $481 = ___cxa_find_matching_catch()|0;
             $482 = tempRet0;
             $$2$i$i = $481;$$216$i$i = $482;
             label = 146;
             break;
            }
            case 138: {
             $483 = ___cxa_find_matching_catch()|0;
             $484 = tempRet0;
             $$1$i$i = $483;$$115$i$i = $484;
             label = 144;
             break;
            }
            case 139: {
             $485 = ___cxa_find_matching_catch()|0;
             $486 = tempRet0;
             $$0$i$i = $485;$$014$i$i = $486;
             label = 142;
             break;
            }
            case 140: {
             $487 = ___cxa_find_matching_catch()|0;
             $488 = tempRet0;
             $489 = HEAP8[$24>>0]|0;
             $490 = $489 & 1;
             $491 = ($490<<24>>24)==(0);
             if ($491) {
              $$0$i$i = $487;$$014$i$i = $488;
              label = 142;
              break;
             }
             $492 = HEAP32[$227>>2]|0;
             __ZdlPv($492);
             $$0$i$i = $487;$$014$i$i = $488;
             label = 142;
             break;
            }
            case 176: {
             $576 = ___cxa_find_matching_catch()|0;
             $577 = tempRet0;
             $$7$i$i = $576;$$721$i$i = $577;
             label = 188;
             break;
            }
            case 177: {
             $578 = ___cxa_find_matching_catch()|0;
             $579 = tempRet0;
             $$6$i$i = $578;$$620$i$i = $579;
             label = 186;
             break;
            }
            case 178: {
             $580 = ___cxa_find_matching_catch()|0;
             $581 = tempRet0;
             $$5$i$i = $580;$$519$i$i = $581;
             label = 184;
             break;
            }
            case 179: {
             $582 = ___cxa_find_matching_catch()|0;
             $583 = tempRet0;
             $$4$i$i = $582;$$418$i$i = $583;
             label = 182;
             break;
            }
            case 180: {
             $584 = ___cxa_find_matching_catch()|0;
             $585 = tempRet0;
             $586 = HEAP8[$29>>0]|0;
             $587 = $586 & 1;
             $588 = ($587<<24>>24)==(0);
             if ($588) {
              $$4$i$i = $584;$$418$i$i = $585;
              label = 182;
              break;
             }
             $589 = HEAP32[$219>>2]|0;
             __ZdlPv($589);
             $$4$i$i = $584;$$418$i$i = $585;
             label = 182;
             break;
            }
           }
           do {
            if ((label|0) == 142) {
             $493 = HEAP8[$25>>0]|0;
             $494 = $493 & 1;
             $495 = ($494<<24>>24)==(0);
             if ($495) {
              $$1$i$i = $$0$i$i;$$115$i$i = $$014$i$i;
              label = 144;
              break;
             }
             $496 = HEAP32[$226>>2]|0;
             __ZdlPv($496);
             $$1$i$i = $$0$i$i;$$115$i$i = $$014$i$i;
             label = 144;
            }
            else if ((label|0) == 182) {
             $590 = HEAP8[$30>>0]|0;
             $591 = $590 & 1;
             $592 = ($591<<24>>24)==(0);
             if ($592) {
              $$5$i$i = $$4$i$i;$$519$i$i = $$418$i$i;
              label = 184;
              break;
             }
             $593 = HEAP32[$218>>2]|0;
             __ZdlPv($593);
             $$5$i$i = $$4$i$i;$$519$i$i = $$418$i$i;
             label = 184;
            }
           } while(0);
           do {
            if ((label|0) == 144) {
             $497 = HEAP8[$26>>0]|0;
             $498 = $497 & 1;
             $499 = ($498<<24>>24)==(0);
             if ($499) {
              $$2$i$i = $$1$i$i;$$216$i$i = $$115$i$i;
              label = 146;
              break;
             }
             $500 = HEAP32[$225>>2]|0;
             __ZdlPv($500);
             $$2$i$i = $$1$i$i;$$216$i$i = $$115$i$i;
             label = 146;
            }
            else if ((label|0) == 184) {
             $594 = HEAP8[$31>>0]|0;
             $595 = $594 & 1;
             $596 = ($595<<24>>24)==(0);
             if ($596) {
              $$6$i$i = $$5$i$i;$$620$i$i = $$519$i$i;
              label = 186;
              break;
             }
             $597 = HEAP32[$217>>2]|0;
             __ZdlPv($597);
             $$6$i$i = $$5$i$i;$$620$i$i = $$519$i$i;
             label = 186;
            }
           } while(0);
           do {
            if ((label|0) == 146) {
             $501 = HEAP8[$27>>0]|0;
             $502 = $501 & 1;
             $503 = ($502<<24>>24)==(0);
             if ($503) {
              $$3$i$i = $$2$i$i;$$317$i$i = $$216$i$i;
              label = 148;
              break;
             }
             $504 = HEAP32[$224>>2]|0;
             __ZdlPv($504);
             $$3$i$i = $$2$i$i;$$317$i$i = $$216$i$i;
             label = 148;
            }
            else if ((label|0) == 186) {
             $598 = HEAP8[$32>>0]|0;
             $599 = $598 & 1;
             $600 = ($599<<24>>24)==(0);
             if ($600) {
              $$7$i$i = $$6$i$i;$$721$i$i = $$620$i$i;
              label = 188;
              break;
             }
             $601 = HEAP32[$216>>2]|0;
             __ZdlPv($601);
             $$7$i$i = $$6$i$i;$$721$i$i = $$620$i$i;
             label = 188;
            }
           } while(0);
           if ((label|0) == 148) {
            $505 = HEAP8[$28>>0]|0;
            $506 = $505 & 1;
            $507 = ($506<<24>>24)==(0);
            if ($507) {
             $$8$i$i = $$3$i$i;$$822$i$i = $$317$i$i;
             break;
            }
            $508 = HEAP32[$221>>2]|0;
            __ZdlPv($508);
            $$8$i$i = $$3$i$i;$$822$i$i = $$317$i$i;
            break;
           }
           else if ((label|0) == 188) {
            $602 = HEAP8[$33>>0]|0;
            $603 = $602 & 1;
            $604 = ($603<<24>>24)==(0);
            if ($604) {
             $$8$i$i = $$7$i$i;$$822$i$i = $$721$i$i;
             break;
            }
            $605 = HEAP32[$212>>2]|0;
            __ZdlPv($605);
            $$8$i$i = $$7$i$i;$$822$i$i = $$721$i$i;
            break;
           }
          }
         } while(0);
         if ((label|0) == 72) {
          $$8$i$i = $eh$lpad$body$i$i$indexZ2D;$$822$i$i = $eh$lpad$body$i$i$index12Z2D;
         }
         $1041 = HEAP32[$201>>2]|0;
         __ZNSt3__16__treeINS_12__value_typeIPKc21ScriptingMethodIl2CppEENS_19__map_value_compareIS3_S5_14CStringCompareLb1EEE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($methodMap$i$i,$1041);
         $$9$i$i = $$8$i$i;$$923$i$i = $$822$i$i;
        }
        $1042 = HEAP32[$allMethods$i$i>>2]|0;
        $1043 = ($1042|0)==(0|0);
        do {
         if (!($1043)) {
          $1044 = HEAP32[$189>>2]|0;
          $1045 = ($1044|0)==($1042|0);
          if (!($1045)) {
           $__new_last2$i$i$i$i$i$i$i = $1042;
           $scevgep$i$i$i$i$i$i$i = (($1044) + -8|0);
           $1046 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
           $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($1046)|0);
           $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
           $1047 = $uglygep3$i$i$i$i$i$i$i >>> 3;
           $1048 = $1047 ^ -1;
           $scevgep4$i$i$i$i$i$i$i = (($1044) + ($1048<<3)|0);
           HEAP32[$189>>2] = $scevgep4$i$i$i$i$i$i$i;
          }
          HEAP32[$19>>2] = 90;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$19+0>>2]|0;
          invoke_vii(2591,($1042|0),($$byval_copy39|0));
          $1049 = __THREW__; __THREW__ = 0;
          $1050 = $1049&1;
          if (!($1050)) {
           break;
          }
          $1051 = ___cxa_find_matching_catch()|0;
          $1052 = tempRet0;
          ___cxa_call_unexpected(($1051|0));
          // unreachable;
         }
        } while(0);
        $eh$lpad$body$index2Z2D = $$923$i$i;$eh$lpad$body$indexZ2D = $$9$i$i;
        label = 8;
        break L11;
       } else {
        $$0 = $88;
       }
      } while(0);
      $1071 = HEAP8[$identifier>>0]|0;
      $1072 = $1071 & 1;
      $1073 = ($1072<<24>>24)==(0);
      if ($1073) {
       STACKTOP = sp;return ($$0|0);
      }
      $1074 = HEAP32[$41>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($1074|0),($$byval_copy39|0));
      $1075 = __THREW__; __THREW__ = 0;
      $1076 = $1075&1;
      if ($1076) {
       $1077 = ___cxa_find_matching_catch()|0;
       $1078 = tempRet0;
       ___cxa_call_unexpected(($1077|0));
       // unreachable;
      } else {
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $eh$lpad$body$index2Z2D = $60;$eh$lpad$body$indexZ2D = $59;
  label = 8;
 }
 if ((label|0) == 8) {
  $$01 = $eh$lpad$body$indexZ2D;$$02 = $eh$lpad$body$index2Z2D;
 }
 $1079 = HEAP8[$identifier>>0]|0;
 $1080 = $1079 & 1;
 $1081 = ($1080<<24>>24)==(0);
 if ($1081) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $1082 = HEAP32[$41>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy39+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($1082|0),($$byval_copy39|0));
 $1083 = __THREW__; __THREW__ = 0;
 $1084 = $1083&1;
 if ($1084) {
  $1085 = ___cxa_find_matching_catch()|0;
  $1086 = tempRet0;
  ___cxa_call_unexpected(($1085|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
 return 0|0;
}
function __Z17IsValidScriptType14MonoScriptType($type) {
 $type = $type|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $type & -3;
 $1 = ($0|0)==(0);
 $2 = ($type|0)==(1);
 $$ = $1 | $2;
 STACKTOP = sp;return ($$|0);
}
function __Z21FormatScriptTypeError14MonoScriptTypeRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($agg$result,$type,$passedClassName) {
 $agg$result = $agg$result|0;
 $type = $type|0;
 $passedClassName = $passedClassName|0;
 var $$0 = 0, $$01 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre23$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $className = 0, $vararg_buffer13 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer13 = sp;
 $className = sp + 16|0;
 $0 = sp + 4|0;
 $1 = HEAP8[$passedClassName>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  ;HEAP32[$className+0>>2]=HEAP32[$passedClassName+0>>2]|0;HEAP32[$className+4>>2]=HEAP32[$passedClassName+4>>2]|0;HEAP32[$className+8>>2]=HEAP32[$passedClassName+8>>2]|0;
  $$pre = HEAP8[$className>>0]|0;
  $$pre$phiZ2D = $className;$22 = $$pre;
 } else {
  $4 = (($passedClassName) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($passedClassName) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7>>>0)>(4294967279);
  if ($8) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $9 = ($7>>>0)<(11);
  if ($9) {
   $10 = $7 << 1;
   $11 = $10&255;
   HEAP8[$className>>0] = $11;
   $12 = (($className) + 1|0);
   $$pre23$pre$phiZZ2D = $className;$117 = $11;$__p$0$i$i$i = $12;
  } else {
   $13 = (($7) + 16)|0;
   $14 = $13 & -16;
   $15 = (__Znwj($14)|0);
   $16 = (($className) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = $14 | 1;
   HEAP32[$className>>2] = $17;
   $18 = (($className) + 4|0);
   HEAP32[$18>>2] = $7;
   $19 = $17&255;
   $$pre23$pre$phiZZ2D = $className;$117 = $19;$__p$0$i$i$i = $15;
  }
  _memcpy(($__p$0$i$i$i|0),($5|0),($7|0))|0;
  $20 = (($__p$0$i$i$i) + ($7)|0);
  HEAP8[$20>>0] = 0;
  $$pre$phiZ2D = $$pre23$pre$phiZZ2D;$22 = $117;
 }
 $21 = $22 & 1;
 $23 = ($21<<24>>24)==(0);
 if ($23) {
  $26 = $22&255;
  $27 = $26 >>> 1;
  $29 = $27;
 } else {
  $24 = (($className) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $29 = $25;
 }
 $28 = ($29|0)==(0);
 do {
  if ($28) {
   HEAP8[$0>>0] = 14;
   $30 = (($0) + 1|0);
   ;HEAP8[$30+0>>0]=HEAP8[633952+0>>0]|0;HEAP8[$30+1>>0]=HEAP8[633952+1>>0]|0;HEAP8[$30+2>>0]=HEAP8[633952+2>>0]|0;HEAP8[$30+3>>0]=HEAP8[633952+3>>0]|0;HEAP8[$30+4>>0]=HEAP8[633952+4>>0]|0;HEAP8[$30+5>>0]=HEAP8[633952+5>>0]|0;HEAP8[$30+6>>0]=HEAP8[633952+6>>0]|0;
   $31 = (($0) + 8|0);
   HEAP8[$31>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2233,($className|0),($0|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $40 = ___cxa_find_matching_catch()|0;
    $41 = tempRet0;
    $42 = HEAP8[$0>>0]|0;
    $43 = $42 & 1;
    $44 = ($43<<24>>24)==(0);
    if ($44) {
     $$0 = $41;$$01 = $40;
     break;
    }
    $45 = HEAP32[$31>>2]|0;
    __ZdlPv($45);
    $$0 = $41;$$01 = $40;
    break;
   } else {
    $34 = HEAP8[$0>>0]|0;
    $35 = $34 & 1;
    $36 = ($35<<24>>24)==(0);
    if ($36) {
     label = 19;
     break;
    }
    $37 = HEAP32[$31>>2]|0;
    __ZdlPv($37);
    label = 19;
    break;
   }
  } else {
   label = 19;
  }
 } while(0);
 do {
  if ((label|0) == 19) {
   switch ($type|0) {
   case -3:  {
    $46 = HEAP8[$$pre$phiZ2D>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if ($48) {
     $51 = (($className) + 1|0);
     $52 = $51;
    } else {
     $49 = (($className) + 8|0);
     $50 = HEAP32[$49>>2]|0;
     $52 = $50;
    }
    __THREW__ = 0;
    HEAP32[$vararg_buffer13>>2] = $52;
    invoke_viii(1617,($agg$result|0),(633960|0),($vararg_buffer13|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 16;
    }
    break;
   }
   case -2:  {
    $55 = HEAP8[$$pre$phiZ2D>>0]|0;
    $56 = $55 & 1;
    $57 = ($56<<24>>24)==(0);
    if ($57) {
     $60 = (($className) + 1|0);
     $61 = $60;
    } else {
     $58 = (($className) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     $61 = $59;
    }
    __THREW__ = 0;
    HEAP32[$vararg_buffer13>>2] = $61;
    invoke_viii(1617,($agg$result|0),(634000|0),($vararg_buffer13|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 16;
    }
    break;
   }
   case -4:  {
    $64 = HEAP8[$$pre$phiZ2D>>0]|0;
    $65 = $64 & 1;
    $66 = ($65<<24>>24)==(0);
    if ($66) {
     $69 = (($className) + 1|0);
     $70 = $69;
    } else {
     $67 = (($className) + 8|0);
     $68 = HEAP32[$67>>2]|0;
     $70 = $68;
    }
    __THREW__ = 0;
    HEAP32[$vararg_buffer13>>2] = $70;
    invoke_viii(1617,($agg$result|0),(634080|0),($vararg_buffer13|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     label = 16;
    }
    break;
   }
   case -5:  {
    $73 = HEAP8[$$pre$phiZ2D>>0]|0;
    $74 = $73 & 1;
    $75 = ($74<<24>>24)==(0);
    if ($75) {
     $78 = (($className) + 1|0);
     $79 = $78;
    } else {
     $76 = (($className) + 8|0);
     $77 = HEAP32[$76>>2]|0;
     $79 = $77;
    }
    __THREW__ = 0;
    HEAP32[$vararg_buffer13>>2] = $79;
    invoke_viii(1617,($agg$result|0),(634152|0),($vararg_buffer13|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 16;
    }
    break;
   }
   case -1:  {
    $91 = HEAP8[$$pre$phiZ2D>>0]|0;
    $92 = $91 & 1;
    $93 = ($92<<24>>24)==(0);
    if ($93) {
     $96 = (($className) + 1|0);
     $97 = $96;
    } else {
     $94 = (($className) + 8|0);
     $95 = HEAP32[$94>>2]|0;
     $97 = $95;
    }
    __THREW__ = 0;
    HEAP32[$vararg_buffer13>>2] = $97;
    invoke_viii(1617,($agg$result|0),(634304|0),($vararg_buffer13|0));
    $98 = __THREW__; __THREW__ = 0;
    $99 = $98&1;
    if ($99) {
     label = 16;
    }
    break;
   }
   case -7:  {
    __THREW__ = 0;
    $100 = (invoke_ii(2988,64)|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     label = 16;
    } else {
     $103 = (($agg$result) + 8|0);
     HEAP32[$103>>2] = $100;
     HEAP32[$agg$result>>2] = 65;
     $104 = (($agg$result) + 4|0);
     HEAP32[$104>>2] = 51;
     dest=$100+0|0; src=634352+0|0; stop=dest+51|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $105 = (($100) + 51|0);
     HEAP8[$105>>0] = 0;
    }
    break;
   }
   case -6:  {
    $82 = HEAP8[$$pre$phiZ2D>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if ($84) {
     $87 = (($className) + 1|0);
     $88 = $87;
    } else {
     $85 = (($className) + 8|0);
     $86 = HEAP32[$85>>2]|0;
     $88 = $86;
    }
    __THREW__ = 0;
    HEAP32[$vararg_buffer13>>2] = $88;
    invoke_viii(1617,($agg$result|0),(634224|0),($vararg_buffer13|0));
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     label = 16;
    }
    break;
   }
   default: {
    HEAP8[$agg$result>>0] = 0;
    $106 = (($agg$result) + 1|0);
    HEAP8[$106>>0] = 0;
   }
   }
   if ((label|0) == 16) {
    $38 = ___cxa_find_matching_catch()|0;
    $39 = tempRet0;
    $$0 = $39;$$01 = $38;
    break;
   }
   $107 = HEAP8[$$pre$phiZ2D>>0]|0;
   $108 = $107 & 1;
   $109 = ($108<<24>>24)==(0);
   if ($109) {
    STACKTOP = sp;return;
   }
   $110 = (($className) + 8|0);
   $111 = HEAP32[$110>>2]|0;
   __ZdlPv($111);
   STACKTOP = sp;return;
  }
 } while(0);
 $112 = HEAP8[$$pre$phiZ2D>>0]|0;
 $113 = $112 & 1;
 $114 = ($113<<24>>24)==(0);
 if ($114) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $115 = (($className) + 8|0);
 $116 = HEAP32[$115>>2]|0;
 __ZdlPv($116);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZNSt3__13mapIPKc21ScriptingMethodIl2Cpp14CStringCompare13stl_allocatorINS_4pairIS2_S3_EEL18MemLabelIdentifier90ELi16EEEixERKS2_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0;
 var $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $16 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $16;
   $$0$i = $16;$25 = $16;
  } else {
   $4 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (_strcmp($4,$6)|0);
    $8 = ($7|0)<(0);
    if ($8) {
     $9 = HEAP32[$__nd$0$in$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $9;
      continue;
     }
    }
    $11 = (_strcmp($6,$4)|0);
    $12 = ($11|0)<(0);
    if (!($12)) {
     label = 9;
     break;
    }
    $13 = (($__nd$0$in$i) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $14;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$25 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $13;$25 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$25 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $17 = HEAP32[$$0$i>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $__r$0 = $17;
  $34 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($34|0);
 }
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $19 = (__Z15malloc_internaljj10MemLabelIdiPKci(28,16,$$byval_copy,0,634408,79)|0);
 $20 = (($19) + 16|0);
 $21 = HEAP32[$__k>>2]|0;
 HEAP32[$20>>2] = $21;
 $22 = (($19) + 20|0);
 HEAP32[$22>>2] = 0;
 HEAP32[$19>>2] = 0;
 $23 = (($19) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = (($19) + 8|0);
 HEAP32[$24>>2] = $25;
 HEAP32[$$0$i>>2] = $19;
 $26 = HEAP32[$this>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $30 = $19;
 } else {
  HEAP32[$this>>2] = $27;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $30 = $$pre$i;
 }
 $29 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($29,$30);
 $31 = (($this) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 1)|0;
 HEAP32[$31>>2] = $33;
 $__r$0 = $19;
 $34 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($34|0);
}
function __ZNSt3__16__treeINS_12__value_typeIPKc21ScriptingMethodIl2CppEENS_19__map_value_compareIS3_S5_14CStringCompareLb1EEE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIPKc21ScriptingMethodIl2CppEENS_19__map_value_compareIS3_S5_14CStringCompareLb1EEE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIPKc21ScriptingMethodIl2CppEENS_19__map_value_compareIS3_S5_14CStringCompareLb1EEE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$4);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  ___cxa_call_unexpected(($7|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZL21CheckMethodParameters21ScriptingMethodIl2CppP14ScriptingClassPS1_jP6ObjectR11MonoManager($method$0,$method$1,$klass,$klassArray,$numParams,$errorContext,$manager) {
 $method$0 = $method$0|0;
 $method$1 = $method$1|0;
 $klass = $klass|0;
 $klassArray = $klassArray|0;
 $numParams = $numParams|0;
 $errorContext = $errorContext|0;
 $manager = $manager|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $$5 = 0, $$57 = 0, $$7 = 0, $$79 = 0, $$8 = 0, $$810 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$06 = 0, $i5$05 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $message = 0, $message4 = 0, $postfix = 0;
 var $postfix3 = 0, $prefix = 0, $prefix2 = 0, $tmpcast11$byval_copy = 0, $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr15 = 0, $vararg_ptr6 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $tmpcast11$byval_copy = sp + 32|0;
 $0 = sp;
 $prefix = sp + 140|0;
 $1 = sp + 16|0;
 $postfix = sp + 128|0;
 $message = sp + 116|0;
 $2 = sp + 8|0;
 $prefix2 = sp + 152|0;
 $3 = sp + 24|0;
 $postfix3 = sp + 68|0;
 $message4 = sp + 44|0;
 $4 = sp + 104|0;
 $5 = sp + 80|0;
 $6 = sp + 92|0;
 $7 = sp + 56|0;
 $8 = $method$0;
 $9 = $method$1&255;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $8;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 ;HEAP32[$tmpcast11$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast11$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $14 = (__Z35scripting_method_get_argument_count21ScriptingMethodIl2Cpp($tmpcast11$byval_copy)|0);
 $15 = ($14|0)==($numParams|0);
 if (!($15)) {
  $17 = (__Z24scripting_class_get_nameP14ScriptingClass($klass)|0);
  $18 = $1;
  $19 = $18;
  HEAP32[$19>>2] = $8;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $9;
  ;HEAP32[$tmpcast11$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast11$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
  $22 = (__Z25scripting_method_get_name21ScriptingMethodIl2Cpp($tmpcast11$byval_copy)|0);
  HEAP32[$tmpcast11$byval_copy>>2] = $17;
  $vararg_ptr6 = (($tmpcast11$byval_copy) + 4|0);
  HEAP32[$vararg_ptr6>>2] = $22;
  __Z6FormatPKcz($prefix,634832,$tmpcast11$byval_copy);
  __THREW__ = 0;
  $23 = (invoke_ii(2988,32)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $$1 = $58;$$13 = $59;$$pre$phiZ2D = $prefix;
  } else {
   $26 = (($postfix) + 8|0);
   HEAP32[$26>>2] = $23;
   HEAP32[$postfix>>2] = 33;
   $27 = (($postfix) + 4|0);
   HEAP32[$27>>2] = 29;
   dest=$23+0|0; src=634856+0|0; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $28 = (($23) + 29|0);
   HEAP8[$28>>0] = 0;
   $29 = HEAP8[$prefix>>0]|0;
   $30 = $29 & 1;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $34 = (($prefix) + 1|0);
    $35 = $34;
   } else {
    $32 = (($prefix) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $35 = $33;
   }
   __THREW__ = 0;
   HEAP32[$tmpcast11$byval_copy>>2] = $35;
   $vararg_ptr10 = (($tmpcast11$byval_copy) + 4|0);
   HEAP32[$vararg_ptr10>>2] = $numParams;
   $vararg_ptr11 = (($tmpcast11$byval_copy) + 8|0);
   HEAP32[$vararg_ptr11>>2] = $23;
   invoke_viii(1617,($message|0),(634888|0),($tmpcast11$byval_copy|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   do {
    if ($37) {
     $60 = ___cxa_find_matching_catch()|0;
     $61 = tempRet0;
     $$01 = $60;$$02 = $61;
    } else {
     $38 = ($errorContext|0)==(0|0);
     if ($38) {
      $50 = 0;
     } else {
      $39 = (($errorContext) + 4|0);
      $40 = HEAP32[$39>>2]|0;
      $50 = $40;
     }
     $41 = (($manager) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = HEAP8[$message>>0]|0;
     $44 = $43 & 1;
     $45 = ($44<<24>>24)==(0);
     if ($45) {
      $48 = (($message) + 1|0);
      $49 = $48;
     } else {
      $46 = (($message) + 8|0);
      $47 = HEAP32[$46>>2]|0;
      $49 = $47;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($49|0),0,(634472|0),85,2052,($50|0),($42|0),(0|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      $62 = ___cxa_find_matching_catch()|0;
      $63 = tempRet0;
      $64 = HEAP8[$message>>0]|0;
      $65 = $64 & 1;
      $66 = ($65<<24>>24)==(0);
      if ($66) {
       $$01 = $62;$$02 = $63;
       break;
      }
      $67 = (($message) + 8|0);
      $68 = HEAP32[$67>>2]|0;
      __ZdlPv($68);
      $$01 = $62;$$02 = $63;
      break;
     }
     $53 = HEAP8[$message>>0]|0;
     $54 = $53 & 1;
     $55 = ($54<<24>>24)==(0);
     if (!($55)) {
      $56 = (($message) + 8|0);
      $57 = HEAP32[$56>>2]|0;
      __ZdlPv($57);
     }
     $69 = HEAP8[$postfix>>0]|0;
     $70 = $69 & 1;
     $71 = ($70<<24>>24)==(0);
     if (!($71)) {
      $72 = HEAP32[$26>>2]|0;
      __ZdlPv($72);
     }
     $73 = HEAP8[$prefix>>0]|0;
     $74 = $73 & 1;
     $75 = ($74<<24>>24)==(0);
     if ($75) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $76 = (($prefix) + 8|0);
     $77 = HEAP32[$76>>2]|0;
     __ZdlPv($77);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $78 = HEAP8[$postfix>>0]|0;
   $79 = $78 & 1;
   $80 = ($79<<24>>24)==(0);
   if ($80) {
    $$1 = $$01;$$13 = $$02;$$pre$phiZ2D = $prefix;
   } else {
    $81 = HEAP32[$26>>2]|0;
    __ZdlPv($81);
    $$1 = $$01;$$13 = $$02;$$pre$phiZ2D = $prefix;
   }
  }
  $82 = HEAP8[$$pre$phiZ2D>>0]|0;
  $83 = $82 & 1;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $$8 = $$1;$$810 = $$13;
   ___resumeException($$8|0);
   // unreachable;
  }
  $85 = (($prefix) + 8|0);
  $86 = HEAP32[$85>>2]|0;
  __ZdlPv($86);
  $$8 = $$1;$$810 = $$13;
  ___resumeException($$8|0);
  // unreachable;
 }
 $16 = ($numParams|0)==(0);
 if ($16) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$06 = 0;
 }
 while(1) {
  $87 = $2;
  $88 = $87;
  HEAP32[$88>>2] = $8;
  $89 = (($87) + 4)|0;
  $90 = $89;
  HEAP32[$90>>2] = $9;
  ;HEAP32[$tmpcast11$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast11$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
  $91 = (__Z37scripting_method_get_nth_argumenttype21ScriptingMethodIl2Cppi($tmpcast11$byval_copy,$i$06)|0);
  $92 = (__Z25scripting_class_from_typeP13ScriptingType($91)|0);
  $93 = (__Z19GetScriptingManagerv()|0);
  $94 = (($93) + 144|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ($92|0)==($95|0);
  if (!($96)) {
   $97 = (($klassArray) + ($i$06<<2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($98,$92)|0);
   if (!($99)) {
    break;
   }
  }
  $100 = (($i$06) + 1)|0;
  $101 = ($100>>>0)<($numParams>>>0);
  if ($101) {
   $i$06 = $100;
  } else {
   $$0 = 1;
   label = 82;
   break;
  }
 }
 if ((label|0) == 82) {
  STACKTOP = sp;return ($$0|0);
 }
 $102 = (__Z24scripting_class_get_nameP14ScriptingClass($klass)|0);
 $103 = $3;
 $104 = $103;
 HEAP32[$104>>2] = $8;
 $105 = (($103) + 4)|0;
 $106 = $105;
 HEAP32[$106>>2] = $9;
 ;HEAP32[$tmpcast11$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast11$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
 $107 = (__Z25scripting_method_get_name21ScriptingMethodIl2Cpp($tmpcast11$byval_copy)|0);
 HEAP32[$tmpcast11$byval_copy>>2] = $102;
 $vararg_ptr15 = (($tmpcast11$byval_copy) + 4|0);
 HEAP32[$vararg_ptr15>>2] = $107;
 __Z6FormatPKcz($prefix2,634944,$tmpcast11$byval_copy);
 __THREW__ = 0;
 $108 = (invoke_ii(2988,32)|0);
 $109 = __THREW__; __THREW__ = 0;
 $110 = $109&1;
 if ($110) {
  $130 = ___cxa_find_matching_catch()|0;
  $131 = tempRet0;
  $$7 = $130;$$79 = $131;
 } else {
  $111 = (($postfix3) + 8|0);
  HEAP32[$111>>2] = $108;
  HEAP32[$postfix3>>2] = 33;
  $112 = (($postfix3) + 4|0);
  HEAP32[$112>>2] = 29;
  dest=$108+0|0; src=634856+0|0; stop=dest+29|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $113 = (($108) + 29|0);
  HEAP8[$113>>0] = 0;
  ;HEAP32[$message4+0>>2]=0|0;HEAP32[$message4+4>>2]=0|0;HEAP32[$message4+8>>2]=0|0;
  $114 = (($numParams) + -1)|0;
  $i5$05 = 0;
  while(1) {
   $115 = (($klassArray) + ($i5$05<<2)|0);
   $116 = HEAP32[$115>>2]|0;
   __THREW__ = 0;
   $117 = (invoke_ii(3284,($116|0))|0);
   $118 = __THREW__; __THREW__ = 0;
   $119 = $118&1;
   if ($119) {
    label = 38;
    break;
   }
   $120 = (_strlen(($117|0))|0);
   __THREW__ = 0;
   (invoke_iiii(1480,($message4|0),($117|0),($120|0))|0);
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if ($122) {
    label = 38;
    break;
   }
   $123 = ($i5$05>>>0)<($114>>>0);
   $124 = $123 ? 634968 : 634976;
   $125 = (_strlen(($124|0))|0);
   __THREW__ = 0;
   (invoke_iiii(1480,($message4|0),($124|0),($125|0))|0);
   $126 = __THREW__; __THREW__ = 0;
   $127 = $126&1;
   if ($127) {
    label = 38;
    break;
   }
   $128 = (($i5$05) + 1)|0;
   $129 = ($128>>>0)<($numParams>>>0);
   if ($129) {
    $i5$05 = $128;
   } else {
    label = 41;
    break;
   }
  }
  do {
   if ((label|0) == 38) {
    $132 = ___cxa_find_matching_catch()|0;
    $133 = tempRet0;
    $lpad$phi$index = $132;$lpad$phi$index2 = $133;
    label = 40;
   }
   else if ((label|0) == 41) {
    __THREW__ = 0;
    invoke_viii(1627,($7|0),($prefix2|0),(634984|0));
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if ($137) {
     $134 = ___cxa_find_matching_catch()|0;
     $135 = tempRet0;
     $lpad$phi$index = $134;$lpad$phi$index2 = $135;
     label = 40;
     break;
    }
    __THREW__ = 0;
    invoke_viii(1774,($6|0),($7|0),($message4|0));
    $138 = __THREW__; __THREW__ = 0;
    $139 = $138&1;
    if ($139) {
     $184 = ___cxa_find_matching_catch()|0;
     $185 = tempRet0;
     $$4 = $184;$$46 = $185;
    } else {
     __THREW__ = 0;
     invoke_viii(1627,($5|0),($6|0),(634600|0));
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if ($141) {
      $186 = ___cxa_find_matching_catch()|0;
      $187 = tempRet0;
      $$3 = $186;$$35 = $187;
     } else {
      __THREW__ = 0;
      invoke_viii(1774,($4|0),($5|0),($postfix3|0));
      $142 = __THREW__; __THREW__ = 0;
      $143 = $142&1;
      do {
       if ($143) {
        $188 = ___cxa_find_matching_catch()|0;
        $189 = tempRet0;
        $$2 = $188;$$24 = $189;
       } else {
        $144 = ($errorContext|0)==(0|0);
        if ($144) {
         $156 = 0;
        } else {
         $145 = (($errorContext) + 4|0);
         $146 = HEAP32[$145>>2]|0;
         $156 = $146;
        }
        $147 = (($manager) + 4|0);
        $148 = HEAP32[$147>>2]|0;
        $149 = HEAP8[$4>>0]|0;
        $150 = $149 & 1;
        $151 = ($150<<24>>24)==(0);
        if ($151) {
         $154 = (($4) + 1|0);
         $155 = $154;
        } else {
         $152 = (($4) + 8|0);
         $153 = HEAP32[$152>>2]|0;
         $155 = $153;
        }
        __THREW__ = 0;
        invoke_viiiiiiii(21,($155|0),0,(634472|0),114,2052,($156|0),($148|0),(0|0));
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         $190 = ___cxa_find_matching_catch()|0;
         $191 = tempRet0;
         $192 = HEAP8[$4>>0]|0;
         $193 = $192 & 1;
         $194 = ($193<<24>>24)==(0);
         if ($194) {
          $$2 = $190;$$24 = $191;
          break;
         }
         $195 = (($4) + 8|0);
         $196 = HEAP32[$195>>2]|0;
         __ZdlPv($196);
         $$2 = $190;$$24 = $191;
         break;
        }
        $159 = HEAP8[$4>>0]|0;
        $160 = $159 & 1;
        $161 = ($160<<24>>24)==(0);
        if (!($161)) {
         $162 = (($4) + 8|0);
         $163 = HEAP32[$162>>2]|0;
         __ZdlPv($163);
        }
        $164 = HEAP8[$5>>0]|0;
        $165 = $164 & 1;
        $166 = ($165<<24>>24)==(0);
        if (!($166)) {
         $167 = (($5) + 8|0);
         $168 = HEAP32[$167>>2]|0;
         __ZdlPv($168);
        }
        $169 = HEAP8[$6>>0]|0;
        $170 = $169 & 1;
        $171 = ($170<<24>>24)==(0);
        if (!($171)) {
         $172 = (($6) + 8|0);
         $173 = HEAP32[$172>>2]|0;
         __ZdlPv($173);
        }
        $174 = HEAP8[$7>>0]|0;
        $175 = $174 & 1;
        $176 = ($175<<24>>24)==(0);
        if (!($176)) {
         $177 = (($7) + 8|0);
         $178 = HEAP32[$177>>2]|0;
         __ZdlPv($178);
        }
        $179 = HEAP8[$message4>>0]|0;
        $180 = $179 & 1;
        $181 = ($180<<24>>24)==(0);
        if (!($181)) {
         $182 = (($message4) + 8|0);
         $183 = HEAP32[$182>>2]|0;
         __ZdlPv($183);
        }
        $212 = HEAP8[$postfix3>>0]|0;
        $213 = $212 & 1;
        $214 = ($213<<24>>24)==(0);
        if (!($214)) {
         $215 = HEAP32[$111>>2]|0;
         __ZdlPv($215);
        }
        $221 = HEAP8[$prefix2>>0]|0;
        $222 = $221 & 1;
        $223 = ($222<<24>>24)==(0);
        if ($223) {
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
        $224 = (($prefix2) + 8|0);
        $225 = HEAP32[$224>>2]|0;
        __ZdlPv($225);
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $197 = HEAP8[$5>>0]|0;
      $198 = $197 & 1;
      $199 = ($198<<24>>24)==(0);
      if ($199) {
       $$3 = $$2;$$35 = $$24;
      } else {
       $200 = (($5) + 8|0);
       $201 = HEAP32[$200>>2]|0;
       __ZdlPv($201);
       $$3 = $$2;$$35 = $$24;
      }
     }
     $202 = HEAP8[$6>>0]|0;
     $203 = $202 & 1;
     $204 = ($203<<24>>24)==(0);
     if ($204) {
      $$4 = $$3;$$46 = $$35;
     } else {
      $205 = (($6) + 8|0);
      $206 = HEAP32[$205>>2]|0;
      __ZdlPv($206);
      $$4 = $$3;$$46 = $$35;
     }
    }
    $207 = HEAP8[$7>>0]|0;
    $208 = $207 & 1;
    $209 = ($208<<24>>24)==(0);
    if ($209) {
     $$5 = $$4;$$57 = $$46;
    } else {
     $210 = (($7) + 8|0);
     $211 = HEAP32[$210>>2]|0;
     __ZdlPv($211);
     $$5 = $$4;$$57 = $$46;
    }
   }
  } while(0);
  if ((label|0) == 40) {
   $$5 = $lpad$phi$index;$$57 = $lpad$phi$index2;
  }
  $216 = HEAP8[$message4>>0]|0;
  $217 = $216 & 1;
  $218 = ($217<<24>>24)==(0);
  if (!($218)) {
   $219 = (($message4) + 8|0);
   $220 = HEAP32[$219>>2]|0;
   __ZdlPv($220);
  }
  $226 = HEAP8[$postfix3>>0]|0;
  $227 = $226 & 1;
  $228 = ($227<<24>>24)==(0);
  if ($228) {
   $$7 = $$5;$$79 = $$57;
  } else {
   $229 = HEAP32[$111>>2]|0;
   __ZdlPv($229);
   $$7 = $$5;$$79 = $$57;
  }
 }
 $230 = HEAP8[$prefix2>>0]|0;
 $231 = $230 & 1;
 $232 = ($231<<24>>24)==(0);
 if ($232) {
  $$8 = $$7;$$810 = $$79;
  ___resumeException($$8|0);
  // unreachable;
 }
 $233 = (($prefix2) + 8|0);
 $234 = HEAP32[$233>>2]|0;
 __ZdlPv($234);
 $$8 = $$7;$$810 = $$79;
 ___resumeException($$8|0);
 // unreachable;
 return 0|0;
}
function __Z48InitializeMonoBehaviourAnimationBindingInterfacev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z13GetIAnimationv()|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $4 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy,0,16,635032,59)|0);
 HEAP32[$4>>2] = ((635048 + 8|0));
 HEAP32[635040>>2] = $4;
 $5 = (__Z13GetIAnimationv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[635040>>2]|0;
 FUNCTION_TABLE_viiii[$8 & 511]($5,114,24,$9);
 STACKTOP = sp;return;
}
function __Z45CleanupMonoBehaviourAnimationBindingInterfacev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[635040>>2]|0;
 $2 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[635040>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK28MonoBehaviourPropertyBinding13GetFloatValueERKN11UnityEngine9Animation10BoundCurveE($this,$bind) {
 $this = $this|0;
 $bind = $bind|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bind) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = $4 ? Math_fround(1.0) : Math_fround(0.0);
 STACKTOP = sp;return (Math_fround($5));
}
function __ZNK28MonoBehaviourPropertyBinding13SetFloatValueERKN11UnityEngine9Animation10BoundCurveEf($this,$bind,$value) {
 $this = $this|0;
 $bind = $bind|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bind) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $value > Math_fround(0.00100000004749745130539);
 if ($5) {
  $7 = 1;
 } else {
  $6 = $value < Math_fround(-0.00100000004749745130539);
  $7 = $6;
 }
 FUNCTION_TABLE_vii[$4 & 4095]($1,$7);
 STACKTOP = sp;return;
}
function __ZNK28MonoBehaviourPropertyBinding12SetPPtrValueERKN11UnityEngine9Animation10BoundCurveEi($this,$bound,$value) {
 $this = $this|0;
 $bound = $bound|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK28MonoBehaviourPropertyBinding12GetPPtrValueERKN11UnityEngine9Animation10BoundCurveE($this,$bound) {
 $this = $this|0;
 $bound = $bound|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK28MonoBehaviourPropertyBinding15GenerateBindingERK8UnityStrbRN11UnityEngine9Animation14GenericBindingE($this,$attribute,$pptrCurve,$outputBinding) {
 $this = $this|0;
 $attribute = $attribute|0;
 $pptrCurve = $pptrCurve|0;
 $outputBinding = $outputBinding|0;
 var $$ = 0, $$$$i$i$i = 0, $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$attribute>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = $0&255;
  $8 = $7 >>> 1;
  $9 = (($attribute) + 1|0);
  $11 = $8;$13 = $9;
 } else {
  $3 = (($attribute) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($attribute) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $11 = $4;$13 = $6;
 }
 $10 = ($11>>>0)>(9);
 $12 = $10 ? 9 : $11;
 $14 = (_memcmp($13,635088,$12)|0);
 $15 = ($14|0)==(0);
 if (!($15)) {
  $18 = $14;
  $17 = ($18|0)==(0);
  $19 = $pptrCurve ^ 1;
  $$ = $17 & $19;
  STACKTOP = sp;return ($$|0);
 }
 $16 = ($11>>>0)<(9);
 $$$i$i$i = $10&1;
 $$$$i$i$i = $16 ? -1 : $$$i$i$i;
 $18 = $$$$i$i$i;
 $17 = ($18|0)==(0);
 $19 = $pptrCurve ^ 1;
 $$ = $17 & $19;
 STACKTOP = sp;return ($$|0);
}
function __ZNK28MonoBehaviourPropertyBinding9BindValueER6ObjectRKN11UnityEngine9Animation14GenericBindingERNS3_10BoundCurveE($this,$target,$inputBinding,$bound) {
 $this = $this|0;
 $target = $target|0;
 $inputBinding = $inputBinding|0;
 $bound = $bound|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 100001;
}
function __ZN18ScriptingArgumentsC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _memset(($this|0),0,164)|0;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments10AddBooleanEb($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $value&1;
 $1 = (($this) + 160|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2<<2)|0);
 HEAP32[$3>>2] = $0;
 $4 = HEAP32[$1>>2]|0;
 $5 = (($this) + ($4<<2)|0);
 $6 = ((($this) + ($4<<2)|0) + 80|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = ((($this) + ($7<<2)|0) + 120|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$1>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments6AddIntEi($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + ($1<<2)|0);
 HEAP32[$2>>2] = $value;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($this) + ($3<<2)|0);
 $5 = ((($this) + ($3<<2)|0) + 80|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($this) + ($6<<2)|0) + 120|0);
 HEAP32[$7>>2] = 1;
 $8 = HEAP32[$0>>2]|0;
 $9 = (($8) + 1)|0;
 HEAP32[$0>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments8AddFloatEf($this,$value) {
 $this = $this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + ($1<<2)|0);
 HEAPF32[$2>>2] = $value;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($this) + ($3<<2)|0);
 $5 = ((($this) + ($3<<2)|0) + 80|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = ((($this) + ($6<<2)|0) + 120|0);
 HEAP32[$7>>2] = 2;
 $8 = HEAP32[$0>>2]|0;
 $9 = (($8) + 1)|0;
 HEAP32[$0>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments9AddStringEPKc($this,$str) {
 $this = $this|0;
 $str = $str|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20scripting_string_newPKc($str)|0);
 $1 = (($this) + 160|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($this) + ($2<<2)|0) + 80|0);
 HEAP32[$3>>2] = $0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($this) + ($4<<2)|0) + 120|0);
 HEAP32[$5>>2] = 3;
 $6 = HEAP32[$1>>2]|0;
 $7 = (($6) + 1)|0;
 HEAP32[$1>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($this,$scriptingObject) {
 $this = $this|0;
 $scriptingObject = $scriptingObject|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($this) + ($1<<2)|0) + 80|0);
 HEAP32[$2>>2] = $scriptingObject;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($this) + ($3<<2)|0) + 120|0);
 HEAP32[$4>>2] = 4;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments9AddStructEPv($this,$pointerToStruct) {
 $this = $this|0;
 $pointerToStruct = $pointerToStruct|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($this) + ($1<<2)|0) + 80|0);
 HEAP32[$2>>2] = $pointerToStruct;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($this) + ($3<<2)|0) + 120|0);
 HEAP32[$4>>2] = 5;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments8AddArrayEP14ScriptingArray($this,$arr) {
 $this = $this|0;
 $arr = $arr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($this) + ($1<<2)|0) + 80|0);
 HEAP32[$2>>2] = $arr;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($this) + ($3<<2)|0) + 120|0);
 HEAP32[$4>>2] = 6;
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments8GetCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 160|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN18ScriptingArguments28AdjustArgumentsToMatchMethodE21ScriptingMethodIl2Cpp($this,$method) {
 $this = $this|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $method;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (__Z35scripting_method_get_argument_count21ScriptingMethodIl2Cpp($tmpcast$byval_copy)|0);
 $12 = (($this) + 160|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)<($13|0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 HEAP32[$12>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN18ScriptingArguments27CheckArgumentsAgainstMethodE21ScriptingMethodIl2Cpp($this,$method) {
 $this = $this|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $method;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (__Z35scripting_method_get_argument_count21ScriptingMethodIl2Cpp($tmpcast$byval_copy)|0);
 $12 = (($this) + 160|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)==($13|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN19ScriptingInvocationC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN25ScriptingInvocationNoArgsC2Ev($this);
 HEAP32[$this>>2] = ((635104 + 8|0));
 $0 = (($this) + 32|0);
 __ZN18ScriptingArgumentsC2Ev($0);
 STACKTOP = sp;return;
}
function __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($this,$in_method) {
 $this = $this|0;
 $in_method = $in_method|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $in_method;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($this,$tmpcast$byval_copy);
 HEAP32[$this>>2] = ((635104 + 8|0));
 $11 = (($this) + 32|0);
 __ZN18ScriptingArgumentsC2Ev($11);
 STACKTOP = sp;return;
}
function __ZN19ScriptingInvocation5CheckEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (__ZN25ScriptingInvocationNoArgs5CheckEv($this)|0);
 if (!($1)) {
  $15 = 0;
  STACKTOP = sp;return ($15|0);
 }
 $2 = (($this) + 32|0);
 $3 = (($this) + 4|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $14 = (__ZN18ScriptingArguments27CheckArgumentsAgainstMethodE21ScriptingMethodIl2Cpp($2,$tmpcast$byval_copy)|0);
 $15 = $14;
 STACKTOP = sp;return ($15|0);
}
function __ZN19ScriptingInvocation6InvokeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $ex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ex = sp;
 HEAP32[$ex>>2] = 0;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 4095]($this,$ex)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN19ScriptingInvocation6InvokeIbEET_PP18ScriptingException($this,$exception) {
 $this = $this|0;
 $exception = $exception|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 4095]($this,$exception)|0);
 $3 = HEAP32[$exception>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($2) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN19ScriptingInvocation6InvokeEPP18ScriptingException($this,$exception) {
 $this = $this|0;
 $exception = $exception|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $tmpcast$i$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$i$byval_copy = sp + 24|0;
 $0 = sp;
 $1 = sp + 8|0;
 HEAP32[$exception>>2] = 0;
 $2 = (($this) + 4|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 32|0);
 ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $16 = (__Z20il2cpp_invoke_method21ScriptingMethodIl2CppP15ScriptingObjectP18ScriptingArgumentsPP18ScriptingExceptionb($tmpcast$i$byval_copy,$14,$15,$exception,0)|0);
 $17 = HEAP32[$exception>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $$0$i = $16;
  STACKTOP = sp;return ($$0$i|0);
 }
 $19 = (($this) + 28|0);
 HEAP32[$19>>2] = $17;
 $20 = (($this) + 25|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $23 = HEAP32[$exception>>2]|0;
 $24 = (($this) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1731,($23|0),($25|0),($1|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $35 = HEAP8[$1>>0]|0;
  $36 = $35 & 1;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   ___resumeException($33|0);
   // unreachable;
  }
  $38 = (($1) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  __ZdlPv($39);
  ___resumeException($33|0);
  // unreachable;
 } else {
  $28 = HEAP8[$1>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $$0$i = 0;
   STACKTOP = sp;return ($$0$i|0);
  }
  $31 = (($1) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  __ZdlPv($32);
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN19ScriptingInvocation6InvokeEPP18ScriptingExceptionb($this,$exception,$convertArguments) {
 $this = $this|0;
 $exception = $exception|0;
 $convertArguments = $convertArguments|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 24|0;
 $0 = sp;
 $1 = sp + 8|0;
 HEAP32[$exception>>2] = 0;
 $2 = (($this) + 4|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 32|0);
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $16 = (__Z20il2cpp_invoke_method21ScriptingMethodIl2CppP15ScriptingObjectP18ScriptingArgumentsPP18ScriptingExceptionb($tmpcast$byval_copy,$14,$15,$exception,$convertArguments)|0);
 $17 = HEAP32[$exception>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = (($this) + 28|0);
 HEAP32[$19>>2] = $17;
 $20 = (($this) + 25|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = HEAP32[$exception>>2]|0;
 $24 = (($this) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1731,($23|0),($25|0),($1|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $35 = HEAP8[$1>>0]|0;
  $36 = $35 & 1;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   ___resumeException($33|0);
   // unreachable;
  }
  $38 = (($1) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  __ZdlPv($39);
  ___resumeException($33|0);
  // unreachable;
 } else {
  $28 = HEAP8[$1>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $31 = (($1) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  __ZdlPv($32);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN19ScriptingInvocation28AdjustArgumentsToMatchMethodEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = (($this) + 4|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN18ScriptingArguments28AdjustArgumentsToMatchMethodE21ScriptingMethodIl2Cpp($1,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __ZN25ScriptingInvocationNoArgsC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((635120 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 ;HEAP32[$0+0>>2]=HEAP32[599912+0>>2]|0;HEAP8[$0+4>>0]=HEAP8[599912+4>>0]|0;
 $2 = (($this) + 20|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 24|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 25|0);
 HEAP8[$4>>0] = 1;
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp($this,$in_method) {
 $this = $this|0;
 $in_method = $in_method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((635120 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 20|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 24|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 25|0);
 HEAP8[$4>>0] = 1;
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = 0;
 ;HEAP32[$0+0>>2]=HEAP32[$in_method+0>>2]|0;HEAP8[$0+4>>0]=HEAP8[$in_method+4>>0]|0;
 STACKTOP = sp;return;
}
function __ZN25ScriptingInvocationNoArgs5CheckEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN25ScriptingInvocationNoArgs6InvokeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $ex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ex = sp;
 HEAP32[$ex>>2] = 0;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 4095]($this,$ex)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN25ScriptingInvocationNoArgs6InvokeEPP18ScriptingException($this,$exception) {
 $this = $this|0;
 $exception = $exception|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $arguments = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $tmpcast$byval_copy = sp + 192|0;
 $arguments = sp;
 $0 = sp + 168|0;
 $1 = sp + 176|0;
 HEAP32[$exception>>2] = 0;
 __ZN18ScriptingArgumentsC2Ev($arguments);
 $2 = (($this) + 4|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $15 = (__Z23scripting_method_invoke21ScriptingMethodIl2CppP15ScriptingObjectR18ScriptingArgumentsPP18ScriptingException($tmpcast$byval_copy,$14,$arguments,$exception)|0);
 $16 = HEAP32[$exception>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($this) + 28|0);
 HEAP32[$18>>2] = $16;
 $19 = (($this) + 25|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = HEAP32[$exception>>2]|0;
 $23 = (($this) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1731,($22|0),($24|0),($1|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  $34 = HEAP8[$1>>0]|0;
  $35 = $34 & 1;
  $36 = ($35<<24>>24)==(0);
  if ($36) {
   ___resumeException($32|0);
   // unreachable;
  }
  $37 = (($1) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  __ZdlPv($38);
  ___resumeException($32|0);
  // unreachable;
 } else {
  $27 = HEAP8[$1>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $30 = (($1) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  __ZdlPv($31);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN25ScriptingInvocationNoArgs13InvokeCheckedEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ex$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ex$i = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$ex$i>>2] = 0;
 $4 = HEAP32[$this>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iii[$5 & 4095]($this,$ex$i)|0);
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __Z42ScriptingGetComponentsOfTypeFromGameObjectRK26ScriptingGetComponentsArgs($args) {
 $args = $args|0;
 var $$0 = 0, $$byval_copy16 = 0, $$c$i$i = 0, $$c$i$i15 = 0, $$c$i$i26 = 0, $$c$i$i59 = 0, $$in$i = 0, $$in$i27 = 0, $$not$i = 0, $$not$i28 = 0, $$not5$i = 0, $$not5$i38 = 0, $$pr87 = 0, $$pre = 0, $$pre$i = 0, $$pre136 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $compareParameters$i = 0, $compareParameters$i12 = 0;
 var $compareParameters$i24 = 0, $compareParameters$i56 = 0, $exitcond$i = 0, $exitcond$i$i = 0, $i$0$idx$val$i$i = 0, $i$0$idx$val$i$i35 = 0, $i$0$lcssa$i = 0, $i$0$lcssa$i$i = 0, $i$02$i$i = 0, $i$02$i$i33 = 0, $i$03$i = 0, $i$03$i$i = 0, $i$03$i$i41 = 0, $i$03$i$i71 = 0, $i$11$i = 0, $i$11$i$i = 0, $j$02$i = 0, $j$02$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0;
 var $or$cond$i = 0, $or$cond$i29 = 0, $or$cond1$i = 0, $or$cond1$i31 = 0, $or$cond6$i = 0, $or$cond6$i39 = 0, $or$cond7$i = 0, $or$cond7$i40 = 0, $result = 0, $resultComponent = 0, $resultComponents = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy16 = sp + 8|0;
 $0 = sp + 68|0;
 $compareParameters$i56 = sp + 32|0;
 $compareParameters$i24 = sp + 16|0;
 $compareParameters$i12 = sp + 24|0;
 $compareParameters$i = sp;
 $result = sp + 40|0;
 $resultComponents = sp + 48|0;
 $resultComponent = sp + 64|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(635136,$$byval_copy16);
  // unreachable;
 }
 $4 = HEAP32[628512>>2]|0;
 HEAP32[$resultComponents>>2] = 0;
 $5 = (($resultComponents) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($resultComponents) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($resultComponents) + 12|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$resultComponent>>2] = 0;
 $8 = (($args) + 13|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $11 = $resultComponents;
 } else {
  $11 = $resultComponent;
 }
 HEAP32[$result>>2] = $11;
 $12 = (($args) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 L7: do {
  if ((($13|0) == 1)) {
   if ($10) {
    $130 = $compareParameters$i12;
    $131 = $130;
    HEAP32[$131>>2] = 0;
    $132 = (($130) + 4)|0;
    $133 = $132;
    HEAP32[$133>>2] = 0;
    __THREW__ = 0;
    $134 = (invoke_i(84)|0);
    $135 = __THREW__; __THREW__ = 0;
    $136 = $135&1;
    if ($136) {
     label = 47;
     break;
    }
    __THREW__ = 0;
    $137 = (invoke_ii(3300,($2|0))|0);
    $138 = __THREW__; __THREW__ = 0;
    $139 = $138&1;
    if ($139) {
     label = 47;
     break;
    }
    __THREW__ = 0;
    $140 = (invoke_iii(2442,($134|0),($137|0))|0);
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if ($142) {
     label = 47;
     break;
    }
    $143 = ($140|0)==(-1);
    if (!($143)) {
     $144 = (($compareParameters$i12) + 4|0);
     HEAP32[$144>>2] = $140;
     HEAP32[$compareParameters$i12>>2] = 0;
     $145 = (($args) + 12|0);
     $146 = HEAP8[$145>>0]|0;
     $147 = ($146<<24>>24)==(0);
     $148 = HEAP32[$args>>2]|0;
     $149 = (($args) + 14|0);
     $150 = HEAP8[$149>>0]|0;
     $151 = ($150<<24>>24)!=(0);
     if ($147) {
      __THREW__ = 0;
      (invoke_iiiii(248,($148|0),($151|0),($compareParameters$i12|0),($result|0))|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       label = 47;
       break;
      } else {
       label = 108;
       break;
      }
     } else {
      __THREW__ = 0;
      invoke_viiii(394,($148|0),($151|0),($compareParameters$i12|0),($result|0));
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       label = 47;
       break;
      } else {
       label = 108;
       break;
      }
     }
    }
    HEAP32[$compareParameters$i12>>2] = 2;
    __THREW__ = 0;
    $156 = (invoke_ii(3300,($2|0))|0);
    $157 = __THREW__; __THREW__ = 0;
    $158 = $157&1;
    if ($158) {
     label = 47;
     break;
    }
    $159 = (($compareParameters$i12) + 4|0);
    $$c$i$i15 = $156;
    HEAP32[$159>>2] = $$c$i$i15;
    $160 = (($args) + 12|0);
    $161 = HEAP8[$160>>0]|0;
    $162 = ($161<<24>>24)==(0);
    $163 = HEAP32[$args>>2]|0;
    $164 = (($args) + 14|0);
    $165 = HEAP8[$164>>0]|0;
    $166 = ($165<<24>>24)!=(0);
    if ($162) {
     __THREW__ = 0;
     (invoke_iiiii(249,($163|0),($166|0),($compareParameters$i12|0),($result|0))|0);
     $169 = __THREW__; __THREW__ = 0;
     $170 = $169&1;
     if ($170) {
      label = 47;
      break;
     } else {
      label = 108;
      break;
     }
    } else {
     __THREW__ = 0;
     invoke_viiii(395,($163|0),($166|0),($compareParameters$i12|0),($result|0));
     $167 = __THREW__; __THREW__ = 0;
     $168 = $167&1;
     if ($168) {
      label = 47;
      break;
     } else {
      label = 108;
      break;
     }
    }
   }
   $14 = $compareParameters$i;
   $15 = $14;
   HEAP32[$15>>2] = 0;
   $16 = (($14) + 4)|0;
   $17 = $16;
   HEAP32[$17>>2] = 0;
   __THREW__ = 0;
   $18 = (invoke_i(84)|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 47;
   } else {
    __THREW__ = 0;
    $21 = (invoke_ii(3300,($2|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 47;
    } else {
     __THREW__ = 0;
     $24 = (invoke_iii(2442,($18|0),($21|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 47;
     } else {
      $27 = ($24|0)==(-1);
      if ($27) {
       HEAP32[$compareParameters$i>>2] = 2;
       __THREW__ = 0;
       $28 = (invoke_ii(3300,($2|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        label = 47;
        break;
       }
       $31 = (($compareParameters$i) + 4|0);
       $$c$i$i = $28;
       HEAP32[$31>>2] = $$c$i$i;
       $$in$i = $$c$i$i;$37 = 2;
      } else {
       $32 = (($compareParameters$i) + 4|0);
       HEAP32[$32>>2] = $24;
       HEAP32[$compareParameters$i>>2] = 0;
       $$in$i = $24;$37 = 0;
      }
      $33 = $$in$i;
      $34 = (($args) + 12|0);
      $35 = HEAP8[$34>>0]|0;
      $36 = ($37|0)==(0);
      $$not$i = $36 ^ 1;
      $38 = ($35<<24>>24)==(0);
      $or$cond$i = $38 | $$not$i;
      if (!($or$cond$i)) {
       $39 = HEAP32[$args>>2]|0;
       $40 = (($args) + 14|0);
       $41 = HEAP8[$40>>0]|0;
       $42 = ($41<<24>>24)!=(0);
       __THREW__ = 0;
       (invoke_iiiii(246,($39|0),($42|0),($compareParameters$i|0),($result|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 47;
        break;
       } else {
        label = 108;
        break;
       }
      }
      $or$cond1$i = $36 & $38;
      if ($or$cond1$i) {
       $45 = HEAP32[$args>>2]|0;
       $46 = (($args) + 14|0);
       $47 = HEAP8[$46>>0]|0;
       $48 = ($47<<24>>24)==(0);
       HEAP32[$11>>2] = 0;
       if ($48) {
        __THREW__ = 0;
        $49 = (invoke_ii(3251,($45|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 47;
         break;
        }
        if (!($49)) {
         label = 108;
         break;
        }
       }
       $52 = (($45) + 24|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (($45) + 32|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = (($53) + ($55<<3)|0);
       $57 = ($55|0)==(0);
       if ($57) {
        label = 108;
        break;
       }
       $58 = HEAP32[560640>>2]|0;
       $59 = HEAP32[560632>>2]|0;
       $i$02$i$i = $53;
       while(1) {
        $i$0$idx$val$i$i = HEAP32[$i$02$i$i>>2]|0;
        $62 = ($i$0$idx$val$i$i|0)==($$in$i|0);
        if ($62) {
         break;
        }
        $63 = Math_imul($i$0$idx$val$i$i, $58)|0;
        $64 = (($63) + ($$in$i))|0;
        $65 = $64 >> 5;
        $66 = $65 << 5;
        $67 = (($64) - ($66))|0;
        $68 = (($59) + ($65<<2)|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = 1 << $67;
        $71 = $69 & $70;
        $72 = ($71|0)==(0);
        $61 = (($i$02$i$i) + 8|0);
        if (!($72)) {
         break;
        }
        $60 = ($61|0)==($56|0);
        if ($60) {
         label = 108;
         break L7;
        } else {
         $i$02$i$i = $61;
        }
       }
       $73 = (($i$02$i$i) + 4|0);
       $74 = HEAP32[$73>>2]|0;
       HEAP32[$11>>2] = $74;
       label = 108;
       break;
      }
      $75 = ($37|0)==(2);
      $$not5$i = $75 ^ 1;
      $or$cond6$i = $38 | $$not5$i;
      if (!($or$cond6$i)) {
       $76 = HEAP32[$args>>2]|0;
       $77 = (($args) + 14|0);
       $78 = HEAP8[$77>>0]|0;
       $79 = ($78<<24>>24)!=(0);
       __THREW__ = 0;
       (invoke_iiiii(247,($76|0),($79|0),($compareParameters$i|0),($result|0))|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        label = 47;
        break;
       } else {
        label = 108;
        break;
       }
      }
      $or$cond7$i = $75 & $38;
      if ($or$cond7$i) {
       $82 = HEAP32[$args>>2]|0;
       $83 = (($args) + 14|0);
       $84 = HEAP8[$83>>0]|0;
       $85 = ($84<<24>>24)==(0);
       HEAP32[$11>>2] = 0;
       if ($85) {
        __THREW__ = 0;
        $86 = (invoke_ii(3251,($82|0))|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         label = 47;
         break;
        }
        if (!($86)) {
         label = 108;
         break;
        }
       }
       $89 = (($82) + 24|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = (($82) + 32|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = (($90) + ($92<<3)|0);
       $94 = ($92|0)==(0);
       if ($94) {
        label = 108;
       } else {
        $i$03$i$i = $90;
        while(1) {
         $95 = HEAP32[$i$03$i$i>>2]|0;
         $96 = ($95|0)==(114);
         if ($96) {
          $97 = (($i$03$i$i) + 4|0);
          $98 = HEAP32[$97>>2]|0;
          __THREW__ = 0;
          $99 = (invoke_ii(3301,($98|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           label = 46;
           break;
          }
          $102 = ($99|0)==(0|0);
          if (!($102)) {
           $103 = ($99|0)==($33|0);
           if ($103) {
            label = 39;
            break;
           }
           __THREW__ = 0;
           $104 = (invoke_iii(2432,($99|0),($33|0))|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            label = 46;
            break;
           }
           if ($104) {
            label = 39;
            break;
           }
          }
         }
         $108 = (($i$03$i$i) + 8|0);
         $109 = ($108|0)==($93|0);
         if ($109) {
          label = 108;
          break L7;
         } else {
          $i$03$i$i = $108;
         }
        }
        if ((label|0) == 39) {
         $107 = HEAP32[$97>>2]|0;
         HEAP32[$11>>2] = $107;
         label = 108;
         break;
        }
        else if ((label|0) == 46) {
         $120 = ___cxa_find_matching_catch()|0;
         $121 = tempRet0;
         $lpad$phi$index = $120;$lpad$phi$index7 = $121;
         break;
        }
       }
      } else {
       label = 108;
      }
     }
    }
   }
  } else if ((($13|0) == 0)) {
   if ($10) {
    $267 = $compareParameters$i56;
    $268 = $267;
    HEAP32[$268>>2] = 0;
    $269 = (($267) + 4)|0;
    $270 = $269;
    HEAP32[$270>>2] = 0;
    __THREW__ = 0;
    $271 = (invoke_i(84)|0);
    $272 = __THREW__; __THREW__ = 0;
    $273 = $272&1;
    if ($273) {
     label = 47;
     break;
    }
    __THREW__ = 0;
    $274 = (invoke_ii(3300,($2|0))|0);
    $275 = __THREW__; __THREW__ = 0;
    $276 = $275&1;
    if ($276) {
     label = 47;
     break;
    }
    __THREW__ = 0;
    $277 = (invoke_iii(2442,($271|0),($274|0))|0);
    $278 = __THREW__; __THREW__ = 0;
    $279 = $278&1;
    if ($279) {
     label = 47;
     break;
    }
    $280 = ($277|0)==(-1);
    if (!($280)) {
     $281 = (($compareParameters$i56) + 4|0);
     HEAP32[$281>>2] = $277;
     HEAP32[$compareParameters$i56>>2] = 0;
     $282 = (($args) + 12|0);
     $283 = HEAP8[$282>>0]|0;
     $284 = ($283<<24>>24)==(0);
     $285 = HEAP32[$args>>2]|0;
     $286 = (($args) + 14|0);
     $287 = HEAP8[$286>>0]|0;
     $288 = ($287<<24>>24)!=(0);
     if ($284) {
      __THREW__ = 0;
      (invoke_iiiii(248,($285|0),($288|0),($compareParameters$i56|0),($result|0))|0);
      $291 = __THREW__; __THREW__ = 0;
      $292 = $291&1;
      if ($292) {
       label = 47;
       break;
      } else {
       label = 108;
       break;
      }
     } else {
      __THREW__ = 0;
      invoke_viiii(396,($285|0),($288|0),($compareParameters$i56|0),($result|0));
      $289 = __THREW__; __THREW__ = 0;
      $290 = $289&1;
      if ($290) {
       label = 47;
       break;
      } else {
       label = 108;
       break;
      }
     }
    }
    HEAP32[$compareParameters$i56>>2] = 2;
    __THREW__ = 0;
    $293 = (invoke_ii(3300,($2|0))|0);
    $294 = __THREW__; __THREW__ = 0;
    $295 = $294&1;
    if ($295) {
     label = 47;
     break;
    }
    $296 = (($compareParameters$i56) + 4|0);
    $$c$i$i59 = $293;
    HEAP32[$296>>2] = $$c$i$i59;
    $297 = (($args) + 12|0);
    $298 = HEAP8[$297>>0]|0;
    $299 = ($298<<24>>24)==(0);
    $300 = HEAP32[$args>>2]|0;
    $301 = (($args) + 14|0);
    $302 = HEAP8[$301>>0]|0;
    $303 = ($302<<24>>24)!=(0);
    if ($299) {
     __THREW__ = 0;
     (invoke_iiiii(249,($300|0),($303|0),($compareParameters$i56|0),($result|0))|0);
     $306 = __THREW__; __THREW__ = 0;
     $307 = $306&1;
     if ($307) {
      label = 47;
      break;
     } else {
      label = 108;
      break;
     }
    } else {
     __THREW__ = 0;
     invoke_viiii(397,($300|0),($303|0),($compareParameters$i56|0),($result|0));
     $304 = __THREW__; __THREW__ = 0;
     $305 = $304&1;
     if ($305) {
      label = 47;
      break;
     } else {
      label = 108;
      break;
     }
    }
   }
   $171 = $compareParameters$i24;
   $172 = $171;
   HEAP32[$172>>2] = 0;
   $173 = (($171) + 4)|0;
   $174 = $173;
   HEAP32[$174>>2] = 0;
   __THREW__ = 0;
   $175 = (invoke_i(84)|0);
   $176 = __THREW__; __THREW__ = 0;
   $177 = $176&1;
   if ($177) {
    label = 47;
   } else {
    __THREW__ = 0;
    $178 = (invoke_ii(3300,($2|0))|0);
    $179 = __THREW__; __THREW__ = 0;
    $180 = $179&1;
    if ($180) {
     label = 47;
    } else {
     __THREW__ = 0;
     $181 = (invoke_iii(2442,($175|0),($178|0))|0);
     $182 = __THREW__; __THREW__ = 0;
     $183 = $182&1;
     if ($183) {
      label = 47;
     } else {
      $184 = ($181|0)==(-1);
      if ($184) {
       HEAP32[$compareParameters$i24>>2] = 2;
       __THREW__ = 0;
       $185 = (invoke_ii(3300,($2|0))|0);
       $186 = __THREW__; __THREW__ = 0;
       $187 = $186&1;
       if ($187) {
        label = 47;
        break;
       }
       $188 = (($compareParameters$i24) + 4|0);
       $$c$i$i26 = $185;
       HEAP32[$188>>2] = $$c$i$i26;
       $$in$i27 = $$c$i$i26;$194 = 2;
      } else {
       $189 = (($compareParameters$i24) + 4|0);
       HEAP32[$189>>2] = $181;
       HEAP32[$compareParameters$i24>>2] = 0;
       $$in$i27 = $181;$194 = 0;
      }
      $190 = $$in$i27;
      $191 = (($args) + 12|0);
      $192 = HEAP8[$191>>0]|0;
      $193 = ($194|0)==(0);
      $$not$i28 = $193 ^ 1;
      $195 = ($192<<24>>24)==(0);
      $or$cond$i29 = $195 | $$not$i28;
      if (!($or$cond$i29)) {
       $196 = HEAP32[$args>>2]|0;
       $197 = (($args) + 14|0);
       $198 = HEAP8[$197>>0]|0;
       $199 = ($198<<24>>24)!=(0);
       __THREW__ = 0;
       (invoke_iiiii(250,($196|0),($199|0),($compareParameters$i24|0),($result|0))|0);
       $200 = __THREW__; __THREW__ = 0;
       $201 = $200&1;
       if ($201) {
        label = 47;
        break;
       } else {
        label = 108;
        break;
       }
      }
      $or$cond1$i31 = $193 & $195;
      if ($or$cond1$i31) {
       $202 = HEAP32[$args>>2]|0;
       $203 = (($args) + 14|0);
       $204 = HEAP8[$203>>0]|0;
       $205 = ($204<<24>>24)==(0);
       HEAP32[$11>>2] = 0;
       if ($205) {
        __THREW__ = 0;
        $206 = (invoke_ii(3251,($202|0))|0);
        $207 = __THREW__; __THREW__ = 0;
        $208 = $207&1;
        if ($208) {
         label = 47;
         break;
        }
        if (!($206)) {
         label = 108;
         break;
        }
       }
       $209 = (($202) + 24|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = (($202) + 32|0);
       $212 = HEAP32[$211>>2]|0;
       $213 = (($210) + ($212<<3)|0);
       $214 = ($212|0)==(0);
       if ($214) {
        label = 108;
        break;
       }
       $215 = HEAP32[560640>>2]|0;
       $216 = HEAP32[560632>>2]|0;
       $i$02$i$i33 = $210;
       while(1) {
        $i$0$idx$val$i$i35 = HEAP32[$i$02$i$i33>>2]|0;
        $219 = ($i$0$idx$val$i$i35|0)==($$in$i27|0);
        if ($219) {
         break;
        }
        $220 = Math_imul($i$0$idx$val$i$i35, $215)|0;
        $221 = (($220) + ($$in$i27))|0;
        $222 = $221 >> 5;
        $223 = $222 << 5;
        $224 = (($221) - ($223))|0;
        $225 = (($216) + ($222<<2)|0);
        $226 = HEAP32[$225>>2]|0;
        $227 = 1 << $224;
        $228 = $226 & $227;
        $229 = ($228|0)==(0);
        $218 = (($i$02$i$i33) + 8|0);
        if (!($229)) {
         break;
        }
        $217 = ($218|0)==($213|0);
        if ($217) {
         label = 108;
         break L7;
        } else {
         $i$02$i$i33 = $218;
        }
       }
       $230 = (($i$02$i$i33) + 4|0);
       $231 = HEAP32[$230>>2]|0;
       HEAP32[$11>>2] = $231;
       label = 108;
       break;
      }
      $232 = ($194|0)==(2);
      $$not5$i38 = $232 ^ 1;
      $or$cond6$i39 = $195 | $$not5$i38;
      if (!($or$cond6$i39)) {
       $233 = HEAP32[$args>>2]|0;
       $234 = (($args) + 14|0);
       $235 = HEAP8[$234>>0]|0;
       $236 = ($235<<24>>24)!=(0);
       __THREW__ = 0;
       (invoke_iiiii(251,($233|0),($236|0),($compareParameters$i24|0),($result|0))|0);
       $237 = __THREW__; __THREW__ = 0;
       $238 = $237&1;
       if ($238) {
        label = 47;
        break;
       } else {
        label = 108;
        break;
       }
      }
      $or$cond7$i40 = $232 & $195;
      if ($or$cond7$i40) {
       $239 = HEAP32[$args>>2]|0;
       $240 = (($args) + 14|0);
       $241 = HEAP8[$240>>0]|0;
       $242 = ($241<<24>>24)==(0);
       HEAP32[$11>>2] = 0;
       if ($242) {
        __THREW__ = 0;
        $243 = (invoke_ii(3251,($239|0))|0);
        $244 = __THREW__; __THREW__ = 0;
        $245 = $244&1;
        if ($245) {
         label = 47;
         break;
        }
        if (!($243)) {
         label = 108;
         break;
        }
       }
       $246 = (($239) + 24|0);
       $247 = HEAP32[$246>>2]|0;
       $248 = (($239) + 32|0);
       $249 = HEAP32[$248>>2]|0;
       $250 = (($247) + ($249<<3)|0);
       $251 = ($249|0)==(0);
       if ($251) {
        label = 108;
       } else {
        $i$03$i$i41 = $247;
        while(1) {
         $252 = HEAP32[$i$03$i$i41>>2]|0;
         $253 = ($252|0)==(114);
         if ($253) {
          $254 = (($i$03$i$i41) + 4|0);
          $255 = HEAP32[$254>>2]|0;
          __THREW__ = 0;
          $256 = (invoke_ii(3301,($255|0))|0);
          $257 = __THREW__; __THREW__ = 0;
          $258 = $257&1;
          if ($258) {
           label = 45;
           break;
          }
          $259 = ($256|0)==(0|0);
          if (!($259)) {
           $260 = ($256|0)==($190|0);
           if ($260) {
            label = 95;
            break;
           }
           __THREW__ = 0;
           $261 = (invoke_iii(2432,($256|0),($190|0))|0);
           $262 = __THREW__; __THREW__ = 0;
           $263 = $262&1;
           if ($263) {
            label = 45;
            break;
           }
           if ($261) {
            label = 95;
            break;
           }
          }
         }
         $265 = (($i$03$i$i41) + 8|0);
         $266 = ($265|0)==($250|0);
         if ($266) {
          label = 108;
          break L7;
         } else {
          $i$03$i$i41 = $265;
         }
        }
        if ((label|0) == 45) {
         $118 = ___cxa_find_matching_catch()|0;
         $119 = tempRet0;
         $lpad$phi$index = $118;$lpad$phi$index7 = $119;
         break;
        }
        else if ((label|0) == 95) {
         $264 = HEAP32[$254>>2]|0;
         HEAP32[$11>>2] = $264;
         label = 108;
         break;
        }
       }
      } else {
       label = 108;
      }
     }
    }
   }
  } else {
   label = 108;
  }
 } while(0);
 L130: do {
  if ((label|0) == 108) {
   $$pr87 = HEAP8[$8>>0]|0;
   $308 = ($$pr87<<24>>24)==(0);
   do {
    if ($308) {
     $313 = (($args) + 20|0);
     $314 = HEAP8[$313>>0]|0;
     $315 = ($314<<24>>24)==(0);
     if ($315) {
      __THREW__ = 0;
      $320 = (invoke_i(84)|0);
      $321 = __THREW__; __THREW__ = 0;
      $322 = $321&1;
      if ($322) {
       label = 47;
       break L130;
      }
      $323 = (($320) + 40|0);
      $324 = HEAP32[$323>>2]|0;
      $335 = $324;
     } else {
      $316 = HEAP32[$1>>2]|0;
      __THREW__ = 0;
      $317 = (invoke_ii(3300,($316|0))|0);
      $318 = __THREW__; __THREW__ = 0;
      $319 = $318&1;
      if ($319) {
       label = 47;
       break L130;
      } else {
       $335 = $317;
      }
     }
     $325 = (($args) + 8|0);
     $326 = HEAP32[$325>>2]|0;
     $327 = ($326|0)==(0|0);
     if ($327) {
      $368 = HEAP32[$6>>2]|0;
      __THREW__ = 0;
      $369 = (invoke_iiii(1554,($335|0),4,($368|0))|0);
      $370 = __THREW__; __THREW__ = 0;
      $371 = $370&1;
      if ($371) {
       label = 47;
       break L130;
      }
      __THREW__ = 0;
      $372 = (invoke_ii(3303,($369|0))|0);
      $373 = __THREW__; __THREW__ = 0;
      $374 = $373&1;
      if ($374) {
       label = 47;
       break L130;
      }
      $375 = HEAP32[$6>>2]|0;
      $376 = ($375|0)==(0);
      L145: do {
       if ($376) {
        $i$0$lcssa$i$i = 0;
       } else {
        $377 = HEAP32[$resultComponents>>2]|0;
        $i$03$i$i71 = 0;$j$02$i$i = $377;
        while(1) {
         $379 = HEAP32[$j$02$i$i>>2]|0;
         __THREW__ = 0;
         $380 = (invoke_ii(3302,($379|0))|0);
         $381 = __THREW__; __THREW__ = 0;
         $382 = $381&1;
         if ($382) {
          break;
         }
         __THREW__ = 0;
         invoke_viii(1916,($369|0),($i$03$i$i71|0),($380|0));
         $383 = __THREW__; __THREW__ = 0;
         $384 = $383&1;
         if ($384) {
          break;
         }
         $385 = (($i$03$i$i71) + 1)|0;
         $386 = (($j$02$i$i) + 4|0);
         $387 = HEAP32[$resultComponents>>2]|0;
         $388 = HEAP32[$6>>2]|0;
         $389 = (($387) + ($388<<2)|0);
         $390 = ($386|0)==($389|0);
         if ($390) {
          $i$0$lcssa$i$i = $385;
          break L145;
         } else {
          $i$03$i$i71 = $385;$j$02$i$i = $386;
         }
        }
        $112 = ___cxa_find_matching_catch()|0;
        $113 = tempRet0;
        $lpad$phi$index = $112;$lpad$phi$index7 = $113;
        break L130;
       }
      } while(0);
      $378 = ($i$0$lcssa$i$i|0)<($372|0);
      L153: do {
       if ($378) {
        $i$11$i$i = $i$0$lcssa$i$i;
        while(1) {
         __THREW__ = 0;
         $391 = (invoke_iiii(1555,($369|0),($i$11$i$i|0),4)|0);
         $392 = __THREW__; __THREW__ = 0;
         $393 = $392&1;
         if ($393) {
          break;
         }
         HEAP32[$391>>2] = 0;
         $394 = (($i$11$i$i) + 1)|0;
         $exitcond$i$i = ($394|0)==($372|0);
         if ($exitcond$i$i) {
          break L153;
         } else {
          $i$11$i$i = $394;
         }
        }
        $110 = ___cxa_find_matching_catch()|0;
        $111 = tempRet0;
        $lpad$phi$index = $110;$lpad$phi$index7 = $111;
        break L130;
       }
      } while(0);
      $$0 = $369;
      break;
     }
     $328 = (($326) + 8|0);
     $329 = HEAP32[$328>>2]|0;
     __THREW__ = 0;
     $330 = (invoke_ii(3303,($329|0))|0);
     $331 = __THREW__; __THREW__ = 0;
     $332 = $331&1;
     if ($332) {
      label = 47;
      break L130;
     }
     $333 = HEAP32[$6>>2]|0;
     $334 = ($330>>>0)<($333>>>0);
     if ($334) {
      __THREW__ = 0;
      $336 = (invoke_iiii(1554,($335|0),4,($333|0))|0);
      $337 = __THREW__; __THREW__ = 0;
      $338 = $337&1;
      if ($338) {
       label = 47;
       break L130;
      }
      HEAP32[$328>>2] = $336;
      $339 = $336;
     } else {
      $$pre$i = HEAP32[$328>>2]|0;
      $339 = $$pre$i;
     }
     __THREW__ = 0;
     $340 = (invoke_ii(3303,($339|0))|0);
     $341 = __THREW__; __THREW__ = 0;
     $342 = $341&1;
     if ($342) {
      label = 47;
      break L130;
     }
     $343 = HEAP32[$6>>2]|0;
     $344 = ($343|0)==(0);
     L167: do {
      if ($344) {
       $401 = 0;$i$0$lcssa$i = 0;
      } else {
       $345 = HEAP32[$resultComponents>>2]|0;
       $i$03$i = 0;$j$02$i = $345;
       while(1) {
        $347 = HEAP32[$j$02$i>>2]|0;
        __THREW__ = 0;
        $348 = (invoke_ii(3302,($347|0))|0);
        $349 = __THREW__; __THREW__ = 0;
        $350 = $349&1;
        if ($350) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(1916,($339|0),($i$03$i|0),($348|0));
        $351 = __THREW__; __THREW__ = 0;
        $352 = $351&1;
        if ($352) {
         break;
        }
        $353 = (($i$03$i) + 1)|0;
        $354 = (($j$02$i) + 4|0);
        $355 = HEAP32[$resultComponents>>2]|0;
        $356 = HEAP32[$6>>2]|0;
        $357 = (($355) + ($356<<2)|0);
        $358 = ($354|0)==($357|0);
        if ($358) {
         $401 = $356;$i$0$lcssa$i = $353;
         break L167;
        } else {
         $i$03$i = $353;$j$02$i = $354;
        }
       }
       $116 = ___cxa_find_matching_catch()|0;
       $117 = tempRet0;
       $lpad$phi$index = $116;$lpad$phi$index7 = $117;
       break L130;
      }
     } while(0);
     $346 = ($i$0$lcssa$i|0)<($340|0);
     do {
      if ($346) {
       $i$11$i = $i$0$lcssa$i;
       while(1) {
        __THREW__ = 0;
        $359 = (invoke_iiii(1555,($339|0),($i$11$i|0),4)|0);
        $360 = __THREW__; __THREW__ = 0;
        $361 = $360&1;
        if ($361) {
         label = 43;
         break;
        }
        HEAP32[$359>>2] = 0;
        $362 = (($i$11$i) + 1)|0;
        $exitcond$i = ($362|0)==($340|0);
        if ($exitcond$i) {
         label = 130;
         break;
        } else {
         $i$11$i = $362;
        }
       }
       if ((label|0) == 43) {
        $114 = ___cxa_find_matching_catch()|0;
        $115 = tempRet0;
        $lpad$phi$index = $114;$lpad$phi$index7 = $115;
        break L130;
       }
       else if ((label|0) == 130) {
        $$pre = HEAP32[$6>>2]|0;
        $364 = $$pre;
        break;
       }
      } else {
       $364 = $401;
      }
     } while(0);
     $363 = (($326) + 12|0);
     HEAP32[$363>>2] = $364;
     $365 = (($326) + 16|0);
     $366 = HEAP32[$365>>2]|0;
     $367 = (($366) + 1)|0;
     HEAP32[$365>>2] = $367;
     $$0 = 0;
    } else {
     $$pre136 = HEAP32[$resultComponent>>2]|0;
     $309 = ($$pre136|0)==(0|0);
     if ($309) {
      $$0 = 0;
     } else {
      __THREW__ = 0;
      $310 = (invoke_ii(3302,($$pre136|0))|0);
      $311 = __THREW__; __THREW__ = 0;
      $312 = $311&1;
      if ($312) {
       label = 47;
       break L130;
      } else {
       $$0 = $310;
      }
     }
    }
   } while(0);
   $395 = HEAP32[$7>>2]|0;
   $396 = ($395|0)>(-1);
   if (!($396)) {
    STACKTOP = sp;return ($$0|0);
   }
   $397 = HEAP32[$resultComponents>>2]|0;
   $398 = HEAP32[$5>>2]|0;
   HEAP32[$0>>2] = $398;
   ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($397,$$byval_copy16);
   HEAP32[$resultComponents>>2] = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 if ((label|0) == 47) {
  $122 = ___cxa_find_matching_catch()|0;
  $123 = tempRet0;
  $lpad$phi$index = $122;$lpad$phi$index7 = $123;
 }
 $124 = HEAP32[$7>>2]|0;
 $125 = ($124|0)>(-1);
 if (!($125)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $126 = HEAP32[$resultComponents>>2]|0;
 $127 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $127;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($126|0),($$byval_copy16|0));
 $128 = __THREW__; __THREW__ = 0;
 $129 = $128&1;
 if ($129) {
  $399 = ___cxa_find_matching_catch(0|0)|0;
  $400 = tempRet0;
  ___clang_call_terminate($399);
  // unreachable;
 }
 HEAP32[$resultComponents>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL34GetComponentsImplementationRecurseILb0ELi0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZL27GetComponentsImplementationILb0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result)|0);
 $0 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $1 = (($0) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($0) + 140|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($i$01<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZL34GetComponentsImplementationRecurseILb0ELi0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($9,$includeInactive,$compareParameters,$result);
  $10 = (($i$01) + 1)|0;
  $exitcond = ($10|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27GetComponentsImplementationILb0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $component = 0, $foundAtLeastOne$0$off02 = 0, $foundAtLeastOne$1$off0 = 0, $i$0$idx$val = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $component = sp + 4|0;
 if (!($includeInactive)) {
  $1 = (__ZNK5Unity10GameObject8IsActiveEv($go)|0);
  if (!($1)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $2 = (($compareParameters) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($go) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($go) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($7<<3)|0);
 $9 = ($7|0)==(0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $foundAtLeastOne$0$off02 = 0;$i$03 = $5;
 while(1) {
  $i$0$idx$val = HEAP32[$i$03>>2]|0;
  $10 = ($i$0$idx$val|0)==($3|0);
  if ($10) {
   label = 7;
  } else {
   $11 = HEAP32[560640>>2]|0;
   $12 = Math_imul($11, $i$0$idx$val)|0;
   $13 = (($12) + ($3))|0;
   $14 = $13 >> 5;
   $15 = $14 << 5;
   $16 = (($13) - ($15))|0;
   $17 = HEAP32[560632>>2]|0;
   $18 = (($17) + ($14<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = 1 << $16;
   $21 = $20 & $19;
   $22 = ($21|0)==(0);
   if ($22) {
    $foundAtLeastOne$1$off0 = $foundAtLeastOne$0$off02;
   } else {
    label = 7;
   }
  }
  if ((label|0) == 7) {
   label = 0;
   $23 = (($i$03) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$component>>2] = $24;
   $25 = HEAP32[$result>>2]|0;
   $26 = (($25) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0);
   do {
    if ($28) {
     $29 = (($25) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = $30 & 2147483646;
     $32 = ($31>>>0)<(10);
     if ($32) {
      $33 = ($30|0)>(-1);
      if ($33) {
       HEAP32[$29>>2] = 10;
       $34 = HEAP32[$25>>2]|0;
       $35 = (($25) + 4|0);
       $36 = HEAP32[$35>>2]|0;
       HEAP32[$0>>2] = $36;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       $37 = (__Z16realloc_internalPvji10MemLabelIdiPKci($34,40,4,$$byval_copy1,0,635160,370)|0);
       HEAP32[$25>>2] = $37;
       break;
      } else {
       $38 = (($25) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       HEAP32[$0>>2] = $39;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       $40 = (__Z15malloc_internaljj10MemLabelIdiPKci(40,4,$$byval_copy1,0,635160,352)|0);
       $41 = HEAP32[$25>>2]|0;
       $42 = HEAP32[$26>>2]|0;
       $43 = $42 << 2;
       _memcpy(($40|0),($41|0),($43|0))|0;
       HEAP32[$29>>2] = 10;
       HEAP32[$25>>2] = $40;
       break;
      }
     }
    }
   } while(0);
   __ZN13dynamic_arrayIPN5Unity9ComponentELj4EE9push_backERKS2_($25,$component);
   $foundAtLeastOne$1$off0 = 1;
  }
  $44 = (($i$03) + 8|0);
  $45 = ($44|0)==($8|0);
  if ($45) {
   $$0 = $foundAtLeastOne$1$off0;
   break;
  } else {
   $foundAtLeastOne$0$off02 = $foundAtLeastOne$1$off0;$i$03 = $44;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL34GetComponentsImplementationRecurseILb0ELi0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZL27GetComponentsImplementationILb0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result)|0);
 $0 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $1 = (($0) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($0) + 140|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($i$01<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZL34GetComponentsImplementationRecurseILb0ELi0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($9,$includeInactive,$compareParameters,$result);
  $10 = (($i$01) + 1)|0;
  $exitcond = ($10|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27GetComponentsImplementationILb0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $component = 0, $foundAtLeastOne$0$off03 = 0, $foundAtLeastOne$1$off0 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $component = sp + 4|0;
 if (!($includeInactive)) {
  $1 = (__ZNK5Unity10GameObject8IsActiveEv($go)|0);
  if (!($1)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $2 = (($go) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($go) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5<<3)|0);
 $7 = ($5|0)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($compareParameters) + 4|0);
 $foundAtLeastOne$0$off03 = 0;$i$04 = $3;
 while(1) {
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$i$04>>2]|0;
  $11 = ($10|0)==(114);
  do {
   if ($11) {
    $12 = (($i$04) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (__ZNK13MonoBehaviour8GetClassEv($13)|0);
    $15 = ($14|0)==(0|0);
    if ($15) {
     $foundAtLeastOne$1$off0 = $foundAtLeastOne$0$off03;
    } else {
     $16 = ($14|0)==($9|0);
     if (!($16)) {
      $17 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($14,$9)|0);
      if (!($17)) {
       $foundAtLeastOne$1$off0 = $foundAtLeastOne$0$off03;
       break;
      }
     }
     $18 = HEAP32[$12>>2]|0;
     HEAP32[$component>>2] = $18;
     $19 = HEAP32[$result>>2]|0;
     $20 = (($19) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0);
     do {
      if ($22) {
       $23 = (($19) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = $24 & 2147483646;
       $26 = ($25>>>0)<(10);
       if ($26) {
        $27 = ($24|0)>(-1);
        if ($27) {
         HEAP32[$23>>2] = 10;
         $28 = HEAP32[$19>>2]|0;
         $29 = (($19) + 4|0);
         $30 = HEAP32[$29>>2]|0;
         HEAP32[$0>>2] = $30;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         $31 = (__Z16realloc_internalPvji10MemLabelIdiPKci($28,40,4,$$byval_copy1,0,635160,370)|0);
         HEAP32[$19>>2] = $31;
         break;
        } else {
         $32 = (($19) + 4|0);
         $33 = HEAP32[$32>>2]|0;
         HEAP32[$0>>2] = $33;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         $34 = (__Z15malloc_internaljj10MemLabelIdiPKci(40,4,$$byval_copy1,0,635160,352)|0);
         $35 = HEAP32[$19>>2]|0;
         $36 = HEAP32[$20>>2]|0;
         $37 = $36 << 2;
         _memcpy(($34|0),($35|0),($37|0))|0;
         HEAP32[$23>>2] = 10;
         HEAP32[$19>>2] = $34;
         break;
        }
       }
      }
     } while(0);
     __ZN13dynamic_arrayIPN5Unity9ComponentELj4EE9push_backERKS2_($19,$component);
     $foundAtLeastOne$1$off0 = 1;
    }
   } else {
    $foundAtLeastOne$1$off0 = $foundAtLeastOne$0$off03;
   }
  } while(0);
  $38 = (($i$04) + 8|0);
  $39 = ($38|0)==($6|0);
  if ($39) {
   $$0 = $foundAtLeastOne$1$off0;
   break;
  } else {
   $foundAtLeastOne$0$off03 = $foundAtLeastOne$1$off0;$i$04 = $38;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL34GetComponentsImplementationRecurseILb1ELi0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$0$idx$val$i = 0, $i$01 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$result>>2]|0;
 HEAP32[$0>>2] = 0;
 if ($includeInactive) {
  label = 3;
 } else {
  $1 = (__ZNK5Unity10GameObject8IsActiveEv($go)|0);
  if ($1) {
   label = 3;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   $2 = (($compareParameters) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($go) + 24|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($go) + 32|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($5) + ($7<<3)|0);
   $9 = ($7|0)==(0);
   if (!($9)) {
    $10 = HEAP32[560640>>2]|0;
    $11 = HEAP32[560632>>2]|0;
    $i$02$i = $5;
    while(1) {
     $i$0$idx$val$i = HEAP32[$i$02$i>>2]|0;
     $14 = ($i$0$idx$val$i|0)==($3|0);
     if ($14) {
      break;
     }
     $15 = Math_imul($i$0$idx$val$i, $10)|0;
     $16 = (($15) + ($3))|0;
     $17 = $16 >> 5;
     $18 = $17 << 5;
     $19 = (($16) - ($18))|0;
     $20 = (($11) + ($17<<2)|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = 1 << $19;
     $23 = $21 & $22;
     $24 = ($23|0)==(0);
     $13 = (($i$02$i) + 8|0);
     if (!($24)) {
      break;
     }
     $12 = ($13|0)==($8|0);
     if ($12) {
      break L3;
     } else {
      $i$02$i = $13;
     }
    }
    $25 = (($i$02$i) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$result>>2]|0;
    HEAP32[$27>>2] = $26;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $28 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $29 = (($28) + 148|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(0);
 if (!($31)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = (($28) + 140|0);
 $i$01 = 0;
 while(1) {
  $35 = HEAP32[$32>>2]|0;
  $36 = (($35) + ($i$01<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 24|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (__ZL34GetComponentsImplementationRecurseILb1ELi0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($39,$includeInactive,$compareParameters,$result)|0);
  $34 = (($i$01) + 1)|0;
  if ($40) {
   $$0 = 1;
   label = 13;
   break;
  }
  $33 = ($34|0)<($30|0);
  if ($33) {
   $i$01 = $34;
  } else {
   $$0 = 0;
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL34GetComponentsImplementationRecurseILb1ELi0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$result>>2]|0;
 HEAP32[$0>>2] = 0;
 if ($includeInactive) {
  label = 3;
 } else {
  $1 = (__ZNK5Unity10GameObject8IsActiveEv($go)|0);
  if ($1) {
   label = 3;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   $2 = (($go) + 24|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($go) + 32|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($3) + ($5<<3)|0);
   $7 = ($5|0)==(0);
   if (!($7)) {
    $8 = (($compareParameters) + 4|0);
    $i$03$i = $3;
    while(1) {
     $9 = HEAP32[$8>>2]|0;
     $10 = HEAP32[$i$03$i>>2]|0;
     $11 = ($10|0)==(114);
     if ($11) {
      $12 = (($i$03$i) + 4|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (__ZNK13MonoBehaviour8GetClassEv($13)|0);
      $15 = ($14|0)==(0|0);
      if (!($15)) {
       $16 = ($14|0)==($9|0);
       if ($16) {
        break;
       }
       $17 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($14,$9)|0);
       if ($17) {
        break;
       }
      }
     }
     $18 = (($i$03$i) + 8|0);
     $19 = ($18|0)==($6|0);
     if ($19) {
      break L3;
     } else {
      $i$03$i = $18;
     }
    }
    $20 = HEAP32[$12>>2]|0;
    $21 = HEAP32[$result>>2]|0;
    HEAP32[$21>>2] = $20;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $22 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $23 = (($22) + 148|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(0);
 if (!($25)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = (($22) + 140|0);
 $i$01 = 0;
 while(1) {
  $29 = HEAP32[$26>>2]|0;
  $30 = (($29) + ($i$01<<2)|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 24|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (__ZL34GetComponentsImplementationRecurseILb1ELi0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($33,$includeInactive,$compareParameters,$result)|0);
  $28 = (($i$01) + 1)|0;
  if ($34) {
   $$0 = 1;
   label = 15;
   break;
  }
  $27 = ($28|0)<($24|0);
  if ($27) {
   $i$01 = $28;
  } else {
   $$0 = 0;
   label = 15;
   break;
  }
 }
 if ((label|0) == 15) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL34GetComponentsImplementationRecurseILb0ELi1ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZL27GetComponentsImplementationILb0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result)|0);
 $0 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $1 = (($0) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 __ZL34GetComponentsImplementationRecurseILb0ELi1ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($5,$includeInactive,$compareParameters,$result);
 STACKTOP = sp;return;
}
function __ZL34GetComponentsImplementationRecurseILb0ELi1ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZL27GetComponentsImplementationILb0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result)|0);
 $0 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $1 = (($0) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 __ZL34GetComponentsImplementationRecurseILb0ELi1ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($5,$includeInactive,$compareParameters,$result);
 STACKTOP = sp;return;
}
function __ZL34GetComponentsImplementationRecurseILb1ELi1ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$idx$val$i = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$result>>2]|0;
 HEAP32[$0>>2] = 0;
 if ($includeInactive) {
  label = 3;
 } else {
  $1 = (__ZNK5Unity10GameObject8IsActiveEv($go)|0);
  if ($1) {
   label = 3;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   $2 = (($compareParameters) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($go) + 24|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($go) + 32|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($5) + ($7<<3)|0);
   $9 = ($7|0)==(0);
   if (!($9)) {
    $10 = HEAP32[560640>>2]|0;
    $11 = HEAP32[560632>>2]|0;
    $i$02$i = $5;
    while(1) {
     $i$0$idx$val$i = HEAP32[$i$02$i>>2]|0;
     $14 = ($i$0$idx$val$i|0)==($3|0);
     if ($14) {
      break;
     }
     $15 = Math_imul($i$0$idx$val$i, $10)|0;
     $16 = (($15) + ($3))|0;
     $17 = $16 >> 5;
     $18 = $17 << 5;
     $19 = (($16) - ($18))|0;
     $20 = (($11) + ($17<<2)|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = 1 << $19;
     $23 = $21 & $22;
     $24 = ($23|0)==(0);
     $13 = (($i$02$i) + 8|0);
     if (!($24)) {
      break;
     }
     $12 = ($13|0)==($8|0);
     if ($12) {
      break L3;
     } else {
      $i$02$i = $13;
     }
    }
    $25 = (($i$02$i) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$result>>2]|0;
    HEAP32[$27>>2] = $26;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $28 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $29 = (($28) + 156|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = (($30) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (__ZL34GetComponentsImplementationRecurseILb1ELi1ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($33,$includeInactive,$compareParameters,$result)|0);
 $$0 = $34;
 STACKTOP = sp;return ($$0|0);
}
function __ZL34GetComponentsImplementationRecurseILb1ELi1ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($go,$includeInactive,$compareParameters,$result) {
 $go = $go|0;
 $includeInactive = $includeInactive|0;
 $compareParameters = $compareParameters|0;
 $result = $result|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$result>>2]|0;
 HEAP32[$0>>2] = 0;
 if ($includeInactive) {
  label = 3;
 } else {
  $1 = (__ZNK5Unity10GameObject8IsActiveEv($go)|0);
  if ($1) {
   label = 3;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   $2 = (($go) + 24|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($go) + 32|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($3) + ($5<<3)|0);
   $7 = ($5|0)==(0);
   if (!($7)) {
    $8 = (($compareParameters) + 4|0);
    $i$03$i = $3;
    while(1) {
     $9 = HEAP32[$8>>2]|0;
     $10 = HEAP32[$i$03$i>>2]|0;
     $11 = ($10|0)==(114);
     if ($11) {
      $12 = (($i$03$i) + 4|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (__ZNK13MonoBehaviour8GetClassEv($13)|0);
      $15 = ($14|0)==(0|0);
      if (!($15)) {
       $16 = ($14|0)==($9|0);
       if ($16) {
        break;
       }
       $17 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($14,$9)|0);
       if ($17) {
        break;
       }
      }
     }
     $18 = (($i$03$i) + 8|0);
     $19 = ($18|0)==($6|0);
     if ($19) {
      break L3;
     } else {
      $i$03$i = $18;
     }
    }
    $20 = HEAP32[$12>>2]|0;
    $21 = HEAP32[$result>>2]|0;
    HEAP32[$21>>2] = $20;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $22 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $23 = (($22) + 156|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = (($24) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (__ZL34GetComponentsImplementationRecurseILb1ELi1ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue($27,$includeInactive,$compareParameters,$result)|0);
 $$0 = $28;
 STACKTOP = sp;return ($$0|0);
}
function __Z26FillCommonScriptingClassesR22CommonScriptingClasses($commonScriptingClasses) {
 $commonScriptingClasses = $commonScriptingClasses|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0;
 var $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0;
 var $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0;
 var $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0;
 var $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0;
 var $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0;
 var $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0;
 var $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0;
 var $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0;
 var $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0;
 var $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0;
 var $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0;
 var $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0;
 var $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0;
 var $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0;
 var $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0;
 var $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0;
 var $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0;
 var $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0;
 var $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0;
 var $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0;
 var $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0;
 var $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0;
 var $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0;
 var $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0;
 var $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0;
 var $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0;
 var $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0;
 var $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0;
 var $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0;
 var $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0;
 var $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0;
 var $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0;
 var $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0;
 var $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0;
 var $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0;
 var $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0;
 var $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0;
 var $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0;
 var $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0;
 var $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0;
 var $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0;
 var $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0;
 var $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0;
 var $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0;
 var $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0;
 var $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0;
 var $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0;
 var $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0;
 var $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0;
 var $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0;
 var $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0;
 var $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0;
 var $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0;
 var $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0;
 var $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0;
 var $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0;
 var $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0;
 var $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0;
 var $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0;
 var $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0;
 var $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0;
 var $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0;
 var $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0;
 var $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0;
 var $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0;
 var $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0;
 var $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0;
 var $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0;
 var $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0;
 var $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0;
 var $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0;
 var $998 = 0, $999 = 0, $vararg_buffer368 = 0, $vararg_ptr1 = 0, $vararg_ptr101 = 0, $vararg_ptr102 = 0, $vararg_ptr106 = 0, $vararg_ptr107 = 0, $vararg_ptr11 = 0, $vararg_ptr111 = 0, $vararg_ptr112 = 0, $vararg_ptr116 = 0, $vararg_ptr117 = 0, $vararg_ptr12 = 0, $vararg_ptr121 = 0, $vararg_ptr122 = 0, $vararg_ptr126 = 0, $vararg_ptr127 = 0, $vararg_ptr131 = 0, $vararg_ptr132 = 0;
 var $vararg_ptr136 = 0, $vararg_ptr137 = 0, $vararg_ptr141 = 0, $vararg_ptr142 = 0, $vararg_ptr146 = 0, $vararg_ptr147 = 0, $vararg_ptr151 = 0, $vararg_ptr152 = 0, $vararg_ptr156 = 0, $vararg_ptr157 = 0, $vararg_ptr16 = 0, $vararg_ptr161 = 0, $vararg_ptr162 = 0, $vararg_ptr166 = 0, $vararg_ptr167 = 0, $vararg_ptr17 = 0, $vararg_ptr171 = 0, $vararg_ptr172 = 0, $vararg_ptr176 = 0, $vararg_ptr177 = 0;
 var $vararg_ptr181 = 0, $vararg_ptr182 = 0, $vararg_ptr186 = 0, $vararg_ptr187 = 0, $vararg_ptr191 = 0, $vararg_ptr192 = 0, $vararg_ptr196 = 0, $vararg_ptr197 = 0, $vararg_ptr2 = 0, $vararg_ptr201 = 0, $vararg_ptr202 = 0, $vararg_ptr206 = 0, $vararg_ptr207 = 0, $vararg_ptr21 = 0, $vararg_ptr211 = 0, $vararg_ptr212 = 0, $vararg_ptr216 = 0, $vararg_ptr217 = 0, $vararg_ptr22 = 0, $vararg_ptr221 = 0;
 var $vararg_ptr222 = 0, $vararg_ptr226 = 0, $vararg_ptr227 = 0, $vararg_ptr231 = 0, $vararg_ptr232 = 0, $vararg_ptr236 = 0, $vararg_ptr237 = 0, $vararg_ptr241 = 0, $vararg_ptr242 = 0, $vararg_ptr246 = 0, $vararg_ptr247 = 0, $vararg_ptr251 = 0, $vararg_ptr252 = 0, $vararg_ptr256 = 0, $vararg_ptr257 = 0, $vararg_ptr26 = 0, $vararg_ptr261 = 0, $vararg_ptr262 = 0, $vararg_ptr266 = 0, $vararg_ptr267 = 0;
 var $vararg_ptr27 = 0, $vararg_ptr271 = 0, $vararg_ptr272 = 0, $vararg_ptr276 = 0, $vararg_ptr277 = 0, $vararg_ptr281 = 0, $vararg_ptr282 = 0, $vararg_ptr286 = 0, $vararg_ptr287 = 0, $vararg_ptr291 = 0, $vararg_ptr292 = 0, $vararg_ptr296 = 0, $vararg_ptr297 = 0, $vararg_ptr301 = 0, $vararg_ptr302 = 0, $vararg_ptr306 = 0, $vararg_ptr307 = 0, $vararg_ptr31 = 0, $vararg_ptr311 = 0, $vararg_ptr312 = 0;
 var $vararg_ptr316 = 0, $vararg_ptr317 = 0, $vararg_ptr32 = 0, $vararg_ptr321 = 0, $vararg_ptr322 = 0, $vararg_ptr326 = 0, $vararg_ptr327 = 0, $vararg_ptr331 = 0, $vararg_ptr332 = 0, $vararg_ptr336 = 0, $vararg_ptr337 = 0, $vararg_ptr341 = 0, $vararg_ptr342 = 0, $vararg_ptr346 = 0, $vararg_ptr347 = 0, $vararg_ptr351 = 0, $vararg_ptr352 = 0, $vararg_ptr356 = 0, $vararg_ptr357 = 0, $vararg_ptr36 = 0;
 var $vararg_ptr361 = 0, $vararg_ptr362 = 0, $vararg_ptr366 = 0, $vararg_ptr367 = 0, $vararg_ptr37 = 0, $vararg_ptr371 = 0, $vararg_ptr372 = 0, $vararg_ptr41 = 0, $vararg_ptr42 = 0, $vararg_ptr46 = 0, $vararg_ptr47 = 0, $vararg_ptr51 = 0, $vararg_ptr52 = 0, $vararg_ptr56 = 0, $vararg_ptr57 = 0, $vararg_ptr6 = 0, $vararg_ptr61 = 0, $vararg_ptr62 = 0, $vararg_ptr66 = 0, $vararg_ptr67 = 0;
 var $vararg_ptr7 = 0, $vararg_ptr71 = 0, $vararg_ptr72 = 0, $vararg_ptr76 = 0, $vararg_ptr77 = 0, $vararg_ptr81 = 0, $vararg_ptr82 = 0, $vararg_ptr86 = 0, $vararg_ptr87 = 0, $vararg_ptr91 = 0, $vararg_ptr92 = 0, $vararg_ptr96 = 0, $vararg_ptr97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $vararg_buffer368 = sp;
 $0 = sp + 224|0;
 $1 = sp + 216|0;
 $2 = sp + 208|0;
 $3 = sp + 200|0;
 $4 = sp + 192|0;
 $5 = sp + 184|0;
 $6 = sp + 176|0;
 $7 = sp + 168|0;
 $8 = sp + 160|0;
 $9 = sp + 152|0;
 $10 = sp + 144|0;
 $11 = sp + 136|0;
 $12 = sp + 128|0;
 $13 = sp + 240|0;
 $14 = sp + 56|0;
 $15 = sp + 48|0;
 $16 = sp + 16|0;
 $17 = sp + 24|0;
 $18 = sp + 32|0;
 $19 = sp + 40|0;
 $20 = sp + 112|0;
 $21 = sp + 64|0;
 $22 = sp + 72|0;
 $23 = sp + 80|0;
 $24 = sp + 88|0;
 $25 = sp + 96|0;
 $26 = sp + 104|0;
 $27 = sp + 120|0;
 $28 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635168)|0);
 $29 = ($28|0)==(0|0);
 do {
  if ($29) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr1 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr1>>2] = 637608;
   $vararg_ptr2 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr2>>2] = 635168;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $30 = HEAP8[$0>>0]|0;
   $31 = $30 & 1;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $35 = (($0) + 1|0);
    $36 = $35;
   } else {
    $33 = (($0) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $36 = $34;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($36|0),0,(637528|0),32,1,0,0,(0|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if (!($38)) {
    $39 = HEAP8[$0>>0]|0;
    $40 = $39 & 1;
    $41 = ($40<<24>>24)==(0);
    if ($41) {
     break;
    }
    $42 = (($0) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    __ZdlPv($43);
    break;
   }
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   $46 = HEAP8[$0>>0]|0;
   $47 = $46 & 1;
   $48 = ($47<<24>>24)==(0);
   if ($48) {
    ___resumeException($44|0);
    // unreachable;
   }
   $49 = (($0) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   __ZdlPv($50);
   ___resumeException($44|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$commonScriptingClasses>>2] = $28;
 $51 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635184)|0);
 $52 = ($51|0)==(0|0);
 do {
  if ($52) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr6 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr6>>2] = 637608;
   $vararg_ptr7 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr7>>2] = 635184;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $53 = HEAP8[$0>>0]|0;
   $54 = $53 & 1;
   $55 = ($54<<24>>24)==(0);
   if ($55) {
    $58 = (($0) + 1|0);
    $59 = $58;
   } else {
    $56 = (($0) + 8|0);
    $57 = HEAP32[$56>>2]|0;
    $59 = $57;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($59|0),0,(637528|0),32,1,0,0,(0|0));
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if (!($61)) {
    $62 = HEAP8[$0>>0]|0;
    $63 = $62 & 1;
    $64 = ($63<<24>>24)==(0);
    if ($64) {
     break;
    }
    $65 = (($0) + 8|0);
    $66 = HEAP32[$65>>2]|0;
    __ZdlPv($66);
    break;
   }
   $67 = ___cxa_find_matching_catch()|0;
   $68 = tempRet0;
   $69 = HEAP8[$0>>0]|0;
   $70 = $69 & 1;
   $71 = ($70<<24>>24)==(0);
   if ($71) {
    ___resumeException($67|0);
    // unreachable;
   }
   $72 = (($0) + 8|0);
   $73 = HEAP32[$72>>2]|0;
   __ZdlPv($73);
   ___resumeException($67|0);
   // unreachable;
  }
 } while(0);
 $74 = (($commonScriptingClasses) + 4|0);
 HEAP32[$74>>2] = $51;
 $75 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635200)|0);
 $76 = ($75|0)==(0|0);
 do {
  if ($76) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr11 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr11>>2] = 637608;
   $vararg_ptr12 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr12>>2] = 635200;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $77 = HEAP8[$0>>0]|0;
   $78 = $77 & 1;
   $79 = ($78<<24>>24)==(0);
   if ($79) {
    $82 = (($0) + 1|0);
    $83 = $82;
   } else {
    $80 = (($0) + 8|0);
    $81 = HEAP32[$80>>2]|0;
    $83 = $81;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($83|0),0,(637528|0),32,1,0,0,(0|0));
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   if (!($85)) {
    $86 = HEAP8[$0>>0]|0;
    $87 = $86 & 1;
    $88 = ($87<<24>>24)==(0);
    if ($88) {
     break;
    }
    $89 = (($0) + 8|0);
    $90 = HEAP32[$89>>2]|0;
    __ZdlPv($90);
    break;
   }
   $91 = ___cxa_find_matching_catch()|0;
   $92 = tempRet0;
   $93 = HEAP8[$0>>0]|0;
   $94 = $93 & 1;
   $95 = ($94<<24>>24)==(0);
   if ($95) {
    ___resumeException($91|0);
    // unreachable;
   }
   $96 = (($0) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   __ZdlPv($97);
   ___resumeException($91|0);
   // unreachable;
  }
 } while(0);
 $98 = (($commonScriptingClasses) + 8|0);
 HEAP32[$98>>2] = $75;
 $99 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635224)|0);
 $100 = ($99|0)==(0|0);
 do {
  if ($100) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr16 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr16>>2] = 637608;
   $vararg_ptr17 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr17>>2] = 635224;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $101 = HEAP8[$0>>0]|0;
   $102 = $101 & 1;
   $103 = ($102<<24>>24)==(0);
   if ($103) {
    $106 = (($0) + 1|0);
    $107 = $106;
   } else {
    $104 = (($0) + 8|0);
    $105 = HEAP32[$104>>2]|0;
    $107 = $105;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($107|0),0,(637528|0),32,1,0,0,(0|0));
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if (!($109)) {
    $110 = HEAP8[$0>>0]|0;
    $111 = $110 & 1;
    $112 = ($111<<24>>24)==(0);
    if ($112) {
     break;
    }
    $113 = (($0) + 8|0);
    $114 = HEAP32[$113>>2]|0;
    __ZdlPv($114);
    break;
   }
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   $117 = HEAP8[$0>>0]|0;
   $118 = $117 & 1;
   $119 = ($118<<24>>24)==(0);
   if ($119) {
    ___resumeException($115|0);
    // unreachable;
   }
   $120 = (($0) + 8|0);
   $121 = HEAP32[$120>>2]|0;
   __ZdlPv($121);
   ___resumeException($115|0);
   // unreachable;
  }
 } while(0);
 $122 = (($commonScriptingClasses) + 12|0);
 HEAP32[$122>>2] = $99;
 $123 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635232)|0);
 $124 = ($123|0)==(0|0);
 do {
  if ($124) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr21 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr21>>2] = 637608;
   $vararg_ptr22 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr22>>2] = 635232;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $125 = HEAP8[$0>>0]|0;
   $126 = $125 & 1;
   $127 = ($126<<24>>24)==(0);
   if ($127) {
    $130 = (($0) + 1|0);
    $131 = $130;
   } else {
    $128 = (($0) + 8|0);
    $129 = HEAP32[$128>>2]|0;
    $131 = $129;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($131|0),0,(637528|0),32,1,0,0,(0|0));
   $132 = __THREW__; __THREW__ = 0;
   $133 = $132&1;
   if (!($133)) {
    $134 = HEAP8[$0>>0]|0;
    $135 = $134 & 1;
    $136 = ($135<<24>>24)==(0);
    if ($136) {
     break;
    }
    $137 = (($0) + 8|0);
    $138 = HEAP32[$137>>2]|0;
    __ZdlPv($138);
    break;
   }
   $139 = ___cxa_find_matching_catch()|0;
   $140 = tempRet0;
   $141 = HEAP8[$0>>0]|0;
   $142 = $141 & 1;
   $143 = ($142<<24>>24)==(0);
   if ($143) {
    ___resumeException($139|0);
    // unreachable;
   }
   $144 = (($0) + 8|0);
   $145 = HEAP32[$144>>2]|0;
   __ZdlPv($145);
   ___resumeException($139|0);
   // unreachable;
  }
 } while(0);
 $146 = (($commonScriptingClasses) + 16|0);
 HEAP32[$146>>2] = $123;
 $147 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635240)|0);
 $148 = ($147|0)==(0|0);
 do {
  if ($148) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr26 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr26>>2] = 637608;
   $vararg_ptr27 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr27>>2] = 635240;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $149 = HEAP8[$0>>0]|0;
   $150 = $149 & 1;
   $151 = ($150<<24>>24)==(0);
   if ($151) {
    $154 = (($0) + 1|0);
    $155 = $154;
   } else {
    $152 = (($0) + 8|0);
    $153 = HEAP32[$152>>2]|0;
    $155 = $153;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($155|0),0,(637528|0),32,1,0,0,(0|0));
   $156 = __THREW__; __THREW__ = 0;
   $157 = $156&1;
   if (!($157)) {
    $158 = HEAP8[$0>>0]|0;
    $159 = $158 & 1;
    $160 = ($159<<24>>24)==(0);
    if ($160) {
     break;
    }
    $161 = (($0) + 8|0);
    $162 = HEAP32[$161>>2]|0;
    __ZdlPv($162);
    break;
   }
   $163 = ___cxa_find_matching_catch()|0;
   $164 = tempRet0;
   $165 = HEAP8[$0>>0]|0;
   $166 = $165 & 1;
   $167 = ($166<<24>>24)==(0);
   if ($167) {
    ___resumeException($163|0);
    // unreachable;
   }
   $168 = (($0) + 8|0);
   $169 = HEAP32[$168>>2]|0;
   __ZdlPv($169);
   ___resumeException($163|0);
   // unreachable;
  }
 } while(0);
 $170 = (($commonScriptingClasses) + 20|0);
 HEAP32[$170>>2] = $147;
 $171 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635248)|0);
 $172 = ($171|0)==(0|0);
 do {
  if ($172) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr31 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr31>>2] = 637608;
   $vararg_ptr32 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr32>>2] = 635248;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $173 = HEAP8[$0>>0]|0;
   $174 = $173 & 1;
   $175 = ($174<<24>>24)==(0);
   if ($175) {
    $178 = (($0) + 1|0);
    $179 = $178;
   } else {
    $176 = (($0) + 8|0);
    $177 = HEAP32[$176>>2]|0;
    $179 = $177;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($179|0),0,(637528|0),32,1,0,0,(0|0));
   $180 = __THREW__; __THREW__ = 0;
   $181 = $180&1;
   if (!($181)) {
    $182 = HEAP8[$0>>0]|0;
    $183 = $182 & 1;
    $184 = ($183<<24>>24)==(0);
    if ($184) {
     break;
    }
    $185 = (($0) + 8|0);
    $186 = HEAP32[$185>>2]|0;
    __ZdlPv($186);
    break;
   }
   $187 = ___cxa_find_matching_catch()|0;
   $188 = tempRet0;
   $189 = HEAP8[$0>>0]|0;
   $190 = $189 & 1;
   $191 = ($190<<24>>24)==(0);
   if ($191) {
    ___resumeException($187|0);
    // unreachable;
   }
   $192 = (($0) + 8|0);
   $193 = HEAP32[$192>>2]|0;
   __ZdlPv($193);
   ___resumeException($187|0);
   // unreachable;
  }
 } while(0);
 $194 = (($commonScriptingClasses) + 24|0);
 HEAP32[$194>>2] = $171;
 $195 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635256)|0);
 $196 = ($195|0)==(0|0);
 do {
  if ($196) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr36 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr36>>2] = 637608;
   $vararg_ptr37 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr37>>2] = 635256;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $197 = HEAP8[$0>>0]|0;
   $198 = $197 & 1;
   $199 = ($198<<24>>24)==(0);
   if ($199) {
    $202 = (($0) + 1|0);
    $203 = $202;
   } else {
    $200 = (($0) + 8|0);
    $201 = HEAP32[$200>>2]|0;
    $203 = $201;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($203|0),0,(637528|0),32,1,0,0,(0|0));
   $204 = __THREW__; __THREW__ = 0;
   $205 = $204&1;
   if (!($205)) {
    $206 = HEAP8[$0>>0]|0;
    $207 = $206 & 1;
    $208 = ($207<<24>>24)==(0);
    if ($208) {
     break;
    }
    $209 = (($0) + 8|0);
    $210 = HEAP32[$209>>2]|0;
    __ZdlPv($210);
    break;
   }
   $211 = ___cxa_find_matching_catch()|0;
   $212 = tempRet0;
   $213 = HEAP8[$0>>0]|0;
   $214 = $213 & 1;
   $215 = ($214<<24>>24)==(0);
   if ($215) {
    ___resumeException($211|0);
    // unreachable;
   }
   $216 = (($0) + 8|0);
   $217 = HEAP32[$216>>2]|0;
   __ZdlPv($217);
   ___resumeException($211|0);
   // unreachable;
  }
 } while(0);
 $218 = (($commonScriptingClasses) + 28|0);
 HEAP32[$218>>2] = $195;
 $219 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635272)|0);
 $220 = ($219|0)==(0|0);
 do {
  if ($220) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr41 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr41>>2] = 637608;
   $vararg_ptr42 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr42>>2] = 635272;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $221 = HEAP8[$0>>0]|0;
   $222 = $221 & 1;
   $223 = ($222<<24>>24)==(0);
   if ($223) {
    $226 = (($0) + 1|0);
    $227 = $226;
   } else {
    $224 = (($0) + 8|0);
    $225 = HEAP32[$224>>2]|0;
    $227 = $225;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($227|0),0,(637528|0),32,1,0,0,(0|0));
   $228 = __THREW__; __THREW__ = 0;
   $229 = $228&1;
   if (!($229)) {
    $230 = HEAP8[$0>>0]|0;
    $231 = $230 & 1;
    $232 = ($231<<24>>24)==(0);
    if ($232) {
     break;
    }
    $233 = (($0) + 8|0);
    $234 = HEAP32[$233>>2]|0;
    __ZdlPv($234);
    break;
   }
   $235 = ___cxa_find_matching_catch()|0;
   $236 = tempRet0;
   $237 = HEAP8[$0>>0]|0;
   $238 = $237 & 1;
   $239 = ($238<<24>>24)==(0);
   if ($239) {
    ___resumeException($235|0);
    // unreachable;
   }
   $240 = (($0) + 8|0);
   $241 = HEAP32[$240>>2]|0;
   __ZdlPv($241);
   ___resumeException($235|0);
   // unreachable;
  }
 } while(0);
 $242 = (($commonScriptingClasses) + 32|0);
 HEAP32[$242>>2] = $219;
 $243 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635288)|0);
 $244 = ($243|0)==(0|0);
 do {
  if ($244) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr46 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr46>>2] = 637608;
   $vararg_ptr47 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr47>>2] = 635288;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $245 = HEAP8[$0>>0]|0;
   $246 = $245 & 1;
   $247 = ($246<<24>>24)==(0);
   if ($247) {
    $250 = (($0) + 1|0);
    $251 = $250;
   } else {
    $248 = (($0) + 8|0);
    $249 = HEAP32[$248>>2]|0;
    $251 = $249;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($251|0),0,(637528|0),32,1,0,0,(0|0));
   $252 = __THREW__; __THREW__ = 0;
   $253 = $252&1;
   if (!($253)) {
    $254 = HEAP8[$0>>0]|0;
    $255 = $254 & 1;
    $256 = ($255<<24>>24)==(0);
    if ($256) {
     break;
    }
    $257 = (($0) + 8|0);
    $258 = HEAP32[$257>>2]|0;
    __ZdlPv($258);
    break;
   }
   $259 = ___cxa_find_matching_catch()|0;
   $260 = tempRet0;
   $261 = HEAP8[$0>>0]|0;
   $262 = $261 & 1;
   $263 = ($262<<24>>24)==(0);
   if ($263) {
    ___resumeException($259|0);
    // unreachable;
   }
   $264 = (($0) + 8|0);
   $265 = HEAP32[$264>>2]|0;
   __ZdlPv($265);
   ___resumeException($259|0);
   // unreachable;
  }
 } while(0);
 $266 = (($commonScriptingClasses) + 36|0);
 HEAP32[$266>>2] = $243;
 $267 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635304)|0);
 $268 = ($267|0)==(0|0);
 do {
  if ($268) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr51 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr51>>2] = 637608;
   $vararg_ptr52 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr52>>2] = 635304;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $269 = HEAP8[$0>>0]|0;
   $270 = $269 & 1;
   $271 = ($270<<24>>24)==(0);
   if ($271) {
    $274 = (($0) + 1|0);
    $275 = $274;
   } else {
    $272 = (($0) + 8|0);
    $273 = HEAP32[$272>>2]|0;
    $275 = $273;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($275|0),0,(637528|0),32,1,0,0,(0|0));
   $276 = __THREW__; __THREW__ = 0;
   $277 = $276&1;
   if (!($277)) {
    $278 = HEAP8[$0>>0]|0;
    $279 = $278 & 1;
    $280 = ($279<<24>>24)==(0);
    if ($280) {
     break;
    }
    $281 = (($0) + 8|0);
    $282 = HEAP32[$281>>2]|0;
    __ZdlPv($282);
    break;
   }
   $283 = ___cxa_find_matching_catch()|0;
   $284 = tempRet0;
   $285 = HEAP8[$0>>0]|0;
   $286 = $285 & 1;
   $287 = ($286<<24>>24)==(0);
   if ($287) {
    ___resumeException($283|0);
    // unreachable;
   }
   $288 = (($0) + 8|0);
   $289 = HEAP32[$288>>2]|0;
   __ZdlPv($289);
   ___resumeException($283|0);
   // unreachable;
  }
 } while(0);
 $290 = (($commonScriptingClasses) + 40|0);
 HEAP32[$290>>2] = $267;
 $291 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635312)|0);
 $292 = ($291|0)==(0|0);
 do {
  if ($292) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr56 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr56>>2] = 637608;
   $vararg_ptr57 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr57>>2] = 635312;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $293 = HEAP8[$0>>0]|0;
   $294 = $293 & 1;
   $295 = ($294<<24>>24)==(0);
   if ($295) {
    $298 = (($0) + 1|0);
    $299 = $298;
   } else {
    $296 = (($0) + 8|0);
    $297 = HEAP32[$296>>2]|0;
    $299 = $297;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($299|0),0,(637528|0),32,1,0,0,(0|0));
   $300 = __THREW__; __THREW__ = 0;
   $301 = $300&1;
   if (!($301)) {
    $302 = HEAP8[$0>>0]|0;
    $303 = $302 & 1;
    $304 = ($303<<24>>24)==(0);
    if ($304) {
     break;
    }
    $305 = (($0) + 8|0);
    $306 = HEAP32[$305>>2]|0;
    __ZdlPv($306);
    break;
   }
   $307 = ___cxa_find_matching_catch()|0;
   $308 = tempRet0;
   $309 = HEAP8[$0>>0]|0;
   $310 = $309 & 1;
   $311 = ($310<<24>>24)==(0);
   if ($311) {
    ___resumeException($307|0);
    // unreachable;
   }
   $312 = (($0) + 8|0);
   $313 = HEAP32[$312>>2]|0;
   __ZdlPv($313);
   ___resumeException($307|0);
   // unreachable;
  }
 } while(0);
 $314 = (($commonScriptingClasses) + 44|0);
 HEAP32[$314>>2] = $291;
 $315 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635328)|0);
 $316 = ($315|0)==(0|0);
 do {
  if ($316) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr61 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr61>>2] = 637608;
   $vararg_ptr62 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr62>>2] = 635328;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $317 = HEAP8[$0>>0]|0;
   $318 = $317 & 1;
   $319 = ($318<<24>>24)==(0);
   if ($319) {
    $322 = (($0) + 1|0);
    $323 = $322;
   } else {
    $320 = (($0) + 8|0);
    $321 = HEAP32[$320>>2]|0;
    $323 = $321;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($323|0),0,(637528|0),32,1,0,0,(0|0));
   $324 = __THREW__; __THREW__ = 0;
   $325 = $324&1;
   if (!($325)) {
    $326 = HEAP8[$0>>0]|0;
    $327 = $326 & 1;
    $328 = ($327<<24>>24)==(0);
    if ($328) {
     break;
    }
    $329 = (($0) + 8|0);
    $330 = HEAP32[$329>>2]|0;
    __ZdlPv($330);
    break;
   }
   $331 = ___cxa_find_matching_catch()|0;
   $332 = tempRet0;
   $333 = HEAP8[$0>>0]|0;
   $334 = $333 & 1;
   $335 = ($334<<24>>24)==(0);
   if ($335) {
    ___resumeException($331|0);
    // unreachable;
   }
   $336 = (($0) + 8|0);
   $337 = HEAP32[$336>>2]|0;
   __ZdlPv($337);
   ___resumeException($331|0);
   // unreachable;
  }
 } while(0);
 $338 = (($commonScriptingClasses) + 48|0);
 HEAP32[$338>>2] = $315;
 $339 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635344)|0);
 $340 = ($339|0)==(0|0);
 do {
  if ($340) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr66 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr66>>2] = 637608;
   $vararg_ptr67 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr67>>2] = 635344;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $341 = HEAP8[$0>>0]|0;
   $342 = $341 & 1;
   $343 = ($342<<24>>24)==(0);
   if ($343) {
    $346 = (($0) + 1|0);
    $347 = $346;
   } else {
    $344 = (($0) + 8|0);
    $345 = HEAP32[$344>>2]|0;
    $347 = $345;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($347|0),0,(637528|0),32,1,0,0,(0|0));
   $348 = __THREW__; __THREW__ = 0;
   $349 = $348&1;
   if (!($349)) {
    $350 = HEAP8[$0>>0]|0;
    $351 = $350 & 1;
    $352 = ($351<<24>>24)==(0);
    if ($352) {
     break;
    }
    $353 = (($0) + 8|0);
    $354 = HEAP32[$353>>2]|0;
    __ZdlPv($354);
    break;
   }
   $355 = ___cxa_find_matching_catch()|0;
   $356 = tempRet0;
   $357 = HEAP8[$0>>0]|0;
   $358 = $357 & 1;
   $359 = ($358<<24>>24)==(0);
   if ($359) {
    ___resumeException($355|0);
    // unreachable;
   }
   $360 = (($0) + 8|0);
   $361 = HEAP32[$360>>2]|0;
   __ZdlPv($361);
   ___resumeException($355|0);
   // unreachable;
  }
 } while(0);
 $362 = (($commonScriptingClasses) + 52|0);
 HEAP32[$362>>2] = $339;
 $363 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635352)|0);
 $364 = ($363|0)==(0|0);
 do {
  if ($364) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr71 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr71>>2] = 637608;
   $vararg_ptr72 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr72>>2] = 635352;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $365 = HEAP8[$0>>0]|0;
   $366 = $365 & 1;
   $367 = ($366<<24>>24)==(0);
   if ($367) {
    $370 = (($0) + 1|0);
    $371 = $370;
   } else {
    $368 = (($0) + 8|0);
    $369 = HEAP32[$368>>2]|0;
    $371 = $369;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($371|0),0,(637528|0),32,1,0,0,(0|0));
   $372 = __THREW__; __THREW__ = 0;
   $373 = $372&1;
   if (!($373)) {
    $374 = HEAP8[$0>>0]|0;
    $375 = $374 & 1;
    $376 = ($375<<24>>24)==(0);
    if ($376) {
     break;
    }
    $377 = (($0) + 8|0);
    $378 = HEAP32[$377>>2]|0;
    __ZdlPv($378);
    break;
   }
   $379 = ___cxa_find_matching_catch()|0;
   $380 = tempRet0;
   $381 = HEAP8[$0>>0]|0;
   $382 = $381 & 1;
   $383 = ($382<<24>>24)==(0);
   if ($383) {
    ___resumeException($379|0);
    // unreachable;
   }
   $384 = (($0) + 8|0);
   $385 = HEAP32[$384>>2]|0;
   __ZdlPv($385);
   ___resumeException($379|0);
   // unreachable;
  }
 } while(0);
 $386 = (($commonScriptingClasses) + 56|0);
 HEAP32[$386>>2] = $363;
 $387 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635360)|0);
 $388 = (($commonScriptingClasses) + 64|0);
 HEAP32[$388>>2] = $387;
 $389 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635376)|0);
 $390 = (($commonScriptingClasses) + 68|0);
 HEAP32[$390>>2] = $389;
 $391 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635392)|0);
 $392 = (($commonScriptingClasses) + 72|0);
 HEAP32[$392>>2] = $391;
 $393 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635408)|0);
 $394 = (($commonScriptingClasses) + 76|0);
 HEAP32[$394>>2] = $393;
 $395 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635424)|0);
 $396 = ($395|0)==(0|0);
 do {
  if ($396) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr76 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr76>>2] = 637608;
   $vararg_ptr77 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr77>>2] = 635424;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $397 = HEAP8[$0>>0]|0;
   $398 = $397 & 1;
   $399 = ($398<<24>>24)==(0);
   if ($399) {
    $402 = (($0) + 1|0);
    $403 = $402;
   } else {
    $400 = (($0) + 8|0);
    $401 = HEAP32[$400>>2]|0;
    $403 = $401;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($403|0),0,(637528|0),32,1,0,0,(0|0));
   $404 = __THREW__; __THREW__ = 0;
   $405 = $404&1;
   if (!($405)) {
    $406 = HEAP8[$0>>0]|0;
    $407 = $406 & 1;
    $408 = ($407<<24>>24)==(0);
    if ($408) {
     break;
    }
    $409 = (($0) + 8|0);
    $410 = HEAP32[$409>>2]|0;
    __ZdlPv($410);
    break;
   }
   $411 = ___cxa_find_matching_catch()|0;
   $412 = tempRet0;
   $413 = HEAP8[$0>>0]|0;
   $414 = $413 & 1;
   $415 = ($414<<24>>24)==(0);
   if ($415) {
    ___resumeException($411|0);
    // unreachable;
   }
   $416 = (($0) + 8|0);
   $417 = HEAP32[$416>>2]|0;
   __ZdlPv($417);
   ___resumeException($411|0);
   // unreachable;
  }
 } while(0);
 $418 = (($commonScriptingClasses) + 80|0);
 HEAP32[$418>>2] = $395;
 $419 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635432)|0);
 $420 = ($419|0)==(0|0);
 do {
  if ($420) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr81 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr81>>2] = 637608;
   $vararg_ptr82 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr82>>2] = 635432;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $421 = HEAP8[$0>>0]|0;
   $422 = $421 & 1;
   $423 = ($422<<24>>24)==(0);
   if ($423) {
    $426 = (($0) + 1|0);
    $427 = $426;
   } else {
    $424 = (($0) + 8|0);
    $425 = HEAP32[$424>>2]|0;
    $427 = $425;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($427|0),0,(637528|0),32,1,0,0,(0|0));
   $428 = __THREW__; __THREW__ = 0;
   $429 = $428&1;
   if (!($429)) {
    $430 = HEAP8[$0>>0]|0;
    $431 = $430 & 1;
    $432 = ($431<<24>>24)==(0);
    if ($432) {
     break;
    }
    $433 = (($0) + 8|0);
    $434 = HEAP32[$433>>2]|0;
    __ZdlPv($434);
    break;
   }
   $435 = ___cxa_find_matching_catch()|0;
   $436 = tempRet0;
   $437 = HEAP8[$0>>0]|0;
   $438 = $437 & 1;
   $439 = ($438<<24>>24)==(0);
   if ($439) {
    ___resumeException($435|0);
    // unreachable;
   }
   $440 = (($0) + 8|0);
   $441 = HEAP32[$440>>2]|0;
   __ZdlPv($441);
   ___resumeException($435|0);
   // unreachable;
  }
 } while(0);
 $442 = (($commonScriptingClasses) + 84|0);
 HEAP32[$442>>2] = $419;
 $443 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635448)|0);
 $444 = ($443|0)==(0|0);
 do {
  if ($444) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr86 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr86>>2] = 637608;
   $vararg_ptr87 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr87>>2] = 635448;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $445 = HEAP8[$0>>0]|0;
   $446 = $445 & 1;
   $447 = ($446<<24>>24)==(0);
   if ($447) {
    $450 = (($0) + 1|0);
    $451 = $450;
   } else {
    $448 = (($0) + 8|0);
    $449 = HEAP32[$448>>2]|0;
    $451 = $449;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($451|0),0,(637528|0),32,1,0,0,(0|0));
   $452 = __THREW__; __THREW__ = 0;
   $453 = $452&1;
   if (!($453)) {
    $454 = HEAP8[$0>>0]|0;
    $455 = $454 & 1;
    $456 = ($455<<24>>24)==(0);
    if ($456) {
     break;
    }
    $457 = (($0) + 8|0);
    $458 = HEAP32[$457>>2]|0;
    __ZdlPv($458);
    break;
   }
   $459 = ___cxa_find_matching_catch()|0;
   $460 = tempRet0;
   $461 = HEAP8[$0>>0]|0;
   $462 = $461 & 1;
   $463 = ($462<<24>>24)==(0);
   if ($463) {
    ___resumeException($459|0);
    // unreachable;
   }
   $464 = (($0) + 8|0);
   $465 = HEAP32[$464>>2]|0;
   __ZdlPv($465);
   ___resumeException($459|0);
   // unreachable;
  }
 } while(0);
 $466 = (($commonScriptingClasses) + 88|0);
 HEAP32[$466>>2] = $443;
 $467 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635464)|0);
 $468 = ($467|0)==(0|0);
 do {
  if ($468) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr91 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr91>>2] = 637608;
   $vararg_ptr92 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr92>>2] = 635464;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $469 = HEAP8[$0>>0]|0;
   $470 = $469 & 1;
   $471 = ($470<<24>>24)==(0);
   if ($471) {
    $474 = (($0) + 1|0);
    $475 = $474;
   } else {
    $472 = (($0) + 8|0);
    $473 = HEAP32[$472>>2]|0;
    $475 = $473;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($475|0),0,(637528|0),32,1,0,0,(0|0));
   $476 = __THREW__; __THREW__ = 0;
   $477 = $476&1;
   if (!($477)) {
    $478 = HEAP8[$0>>0]|0;
    $479 = $478 & 1;
    $480 = ($479<<24>>24)==(0);
    if ($480) {
     break;
    }
    $481 = (($0) + 8|0);
    $482 = HEAP32[$481>>2]|0;
    __ZdlPv($482);
    break;
   }
   $483 = ___cxa_find_matching_catch()|0;
   $484 = tempRet0;
   $485 = HEAP8[$0>>0]|0;
   $486 = $485 & 1;
   $487 = ($486<<24>>24)==(0);
   if ($487) {
    ___resumeException($483|0);
    // unreachable;
   }
   $488 = (($0) + 8|0);
   $489 = HEAP32[$488>>2]|0;
   __ZdlPv($489);
   ___resumeException($483|0);
   // unreachable;
  }
 } while(0);
 $490 = (($commonScriptingClasses) + 180|0);
 HEAP32[$490>>2] = $467;
 $491 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635480)|0);
 $492 = ($491|0)==(0|0);
 do {
  if ($492) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr96 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr96>>2] = 637608;
   $vararg_ptr97 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr97>>2] = 635480;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $493 = HEAP8[$0>>0]|0;
   $494 = $493 & 1;
   $495 = ($494<<24>>24)==(0);
   if ($495) {
    $498 = (($0) + 1|0);
    $499 = $498;
   } else {
    $496 = (($0) + 8|0);
    $497 = HEAP32[$496>>2]|0;
    $499 = $497;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($499|0),0,(637528|0),32,1,0,0,(0|0));
   $500 = __THREW__; __THREW__ = 0;
   $501 = $500&1;
   if (!($501)) {
    $502 = HEAP8[$0>>0]|0;
    $503 = $502 & 1;
    $504 = ($503<<24>>24)==(0);
    if ($504) {
     break;
    }
    $505 = (($0) + 8|0);
    $506 = HEAP32[$505>>2]|0;
    __ZdlPv($506);
    break;
   }
   $507 = ___cxa_find_matching_catch()|0;
   $508 = tempRet0;
   $509 = HEAP8[$0>>0]|0;
   $510 = $509 & 1;
   $511 = ($510<<24>>24)==(0);
   if ($511) {
    ___resumeException($507|0);
    // unreachable;
   }
   $512 = (($0) + 8|0);
   $513 = HEAP32[$512>>2]|0;
   __ZdlPv($513);
   ___resumeException($507|0);
   // unreachable;
  }
 } while(0);
 $514 = (($commonScriptingClasses) + 184|0);
 HEAP32[$514>>2] = $491;
 $515 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635504)|0);
 $516 = ($515|0)==(0|0);
 do {
  if ($516) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr101 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr101>>2] = 637608;
   $vararg_ptr102 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr102>>2] = 635504;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $517 = HEAP8[$0>>0]|0;
   $518 = $517 & 1;
   $519 = ($518<<24>>24)==(0);
   if ($519) {
    $522 = (($0) + 1|0);
    $523 = $522;
   } else {
    $520 = (($0) + 8|0);
    $521 = HEAP32[$520>>2]|0;
    $523 = $521;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($523|0),0,(637528|0),32,1,0,0,(0|0));
   $524 = __THREW__; __THREW__ = 0;
   $525 = $524&1;
   if (!($525)) {
    $526 = HEAP8[$0>>0]|0;
    $527 = $526 & 1;
    $528 = ($527<<24>>24)==(0);
    if ($528) {
     break;
    }
    $529 = (($0) + 8|0);
    $530 = HEAP32[$529>>2]|0;
    __ZdlPv($530);
    break;
   }
   $531 = ___cxa_find_matching_catch()|0;
   $532 = tempRet0;
   $533 = HEAP8[$0>>0]|0;
   $534 = $533 & 1;
   $535 = ($534<<24>>24)==(0);
   if ($535) {
    ___resumeException($531|0);
    // unreachable;
   }
   $536 = (($0) + 8|0);
   $537 = HEAP32[$536>>2]|0;
   __ZdlPv($537);
   ___resumeException($531|0);
   // unreachable;
  }
 } while(0);
 $538 = (($commonScriptingClasses) + 188|0);
 HEAP32[$538>>2] = $515;
 $539 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635528)|0);
 $540 = ($539|0)==(0|0);
 do {
  if ($540) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr106 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr106>>2] = 637608;
   $vararg_ptr107 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr107>>2] = 635528;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $541 = HEAP8[$0>>0]|0;
   $542 = $541 & 1;
   $543 = ($542<<24>>24)==(0);
   if ($543) {
    $546 = (($0) + 1|0);
    $547 = $546;
   } else {
    $544 = (($0) + 8|0);
    $545 = HEAP32[$544>>2]|0;
    $547 = $545;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($547|0),0,(637528|0),32,1,0,0,(0|0));
   $548 = __THREW__; __THREW__ = 0;
   $549 = $548&1;
   if (!($549)) {
    $550 = HEAP8[$0>>0]|0;
    $551 = $550 & 1;
    $552 = ($551<<24>>24)==(0);
    if ($552) {
     break;
    }
    $553 = (($0) + 8|0);
    $554 = HEAP32[$553>>2]|0;
    __ZdlPv($554);
    break;
   }
   $555 = ___cxa_find_matching_catch()|0;
   $556 = tempRet0;
   $557 = HEAP8[$0>>0]|0;
   $558 = $557 & 1;
   $559 = ($558<<24>>24)==(0);
   if ($559) {
    ___resumeException($555|0);
    // unreachable;
   }
   $560 = (($0) + 8|0);
   $561 = HEAP32[$560>>2]|0;
   __ZdlPv($561);
   ___resumeException($555|0);
   // unreachable;
  }
 } while(0);
 $562 = (($commonScriptingClasses) + 192|0);
 HEAP32[$562>>2] = $539;
 $563 = (($commonScriptingClasses) + 196|0);
 __ZL13RequireMethodPKcS0_S0_S0_($1,637592,637608,635544,635552);
 ;HEAP32[$563+0>>2]=HEAP32[$1+0>>2]|0;HEAP8[$563+4>>0]=HEAP8[$1+4>>0]|0;
 $564 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635600)|0);
 $565 = (($commonScriptingClasses) + 208|0);
 HEAP32[$565>>2] = $564;
 $566 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635608)|0);
 $567 = (($commonScriptingClasses) + 212|0);
 HEAP32[$567>>2] = $566;
 $568 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635616)|0);
 $569 = ($568|0)==(0|0);
 do {
  if ($569) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr111 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr111>>2] = 637608;
   $vararg_ptr112 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr112>>2] = 635616;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $570 = HEAP8[$0>>0]|0;
   $571 = $570 & 1;
   $572 = ($571<<24>>24)==(0);
   if ($572) {
    $575 = (($0) + 1|0);
    $576 = $575;
   } else {
    $573 = (($0) + 8|0);
    $574 = HEAP32[$573>>2]|0;
    $576 = $574;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($576|0),0,(637528|0),32,1,0,0,(0|0));
   $577 = __THREW__; __THREW__ = 0;
   $578 = $577&1;
   if (!($578)) {
    $579 = HEAP8[$0>>0]|0;
    $580 = $579 & 1;
    $581 = ($580<<24>>24)==(0);
    if ($581) {
     break;
    }
    $582 = (($0) + 8|0);
    $583 = HEAP32[$582>>2]|0;
    __ZdlPv($583);
    break;
   }
   $584 = ___cxa_find_matching_catch()|0;
   $585 = tempRet0;
   $586 = HEAP8[$0>>0]|0;
   $587 = $586 & 1;
   $588 = ($587<<24>>24)==(0);
   if ($588) {
    ___resumeException($584|0);
    // unreachable;
   }
   $589 = (($0) + 8|0);
   $590 = HEAP32[$589>>2]|0;
   __ZdlPv($590);
   ___resumeException($584|0);
   // unreachable;
  }
 } while(0);
 $591 = (($commonScriptingClasses) + 216|0);
 HEAP32[$591>>2] = $568;
 $592 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635632)|0);
 $593 = (($commonScriptingClasses) + 220|0);
 HEAP32[$593>>2] = $592;
 $594 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635648)|0);
 $595 = (($commonScriptingClasses) + 224|0);
 HEAP32[$595>>2] = $594;
 $596 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635664)|0);
 $597 = (($commonScriptingClasses) + 228|0);
 HEAP32[$597>>2] = $596;
 $598 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635688)|0);
 $599 = (($commonScriptingClasses) + 232|0);
 HEAP32[$599>>2] = $598;
 $600 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635704)|0);
 $601 = (($commonScriptingClasses) + 236|0);
 HEAP32[$601>>2] = $600;
 $602 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635720)|0);
 $603 = ($602|0)==(0|0);
 do {
  if ($603) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr116 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr116>>2] = 637608;
   $vararg_ptr117 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr117>>2] = 635720;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $604 = HEAP8[$0>>0]|0;
   $605 = $604 & 1;
   $606 = ($605<<24>>24)==(0);
   if ($606) {
    $609 = (($0) + 1|0);
    $610 = $609;
   } else {
    $607 = (($0) + 8|0);
    $608 = HEAP32[$607>>2]|0;
    $610 = $608;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($610|0),0,(637528|0),32,1,0,0,(0|0));
   $611 = __THREW__; __THREW__ = 0;
   $612 = $611&1;
   if (!($612)) {
    $613 = HEAP8[$0>>0]|0;
    $614 = $613 & 1;
    $615 = ($614<<24>>24)==(0);
    if ($615) {
     break;
    }
    $616 = (($0) + 8|0);
    $617 = HEAP32[$616>>2]|0;
    __ZdlPv($617);
    break;
   }
   $618 = ___cxa_find_matching_catch()|0;
   $619 = tempRet0;
   $620 = HEAP8[$0>>0]|0;
   $621 = $620 & 1;
   $622 = ($621<<24>>24)==(0);
   if ($622) {
    ___resumeException($618|0);
    // unreachable;
   }
   $623 = (($0) + 8|0);
   $624 = HEAP32[$623>>2]|0;
   __ZdlPv($624);
   ___resumeException($618|0);
   // unreachable;
  }
 } while(0);
 $625 = (($commonScriptingClasses) + 244|0);
 HEAP32[$625>>2] = $602;
 $626 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635728)|0);
 $627 = ($626|0)==(0|0);
 do {
  if ($627) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr121 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr121>>2] = 637608;
   $vararg_ptr122 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr122>>2] = 635728;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $628 = HEAP8[$0>>0]|0;
   $629 = $628 & 1;
   $630 = ($629<<24>>24)==(0);
   if ($630) {
    $633 = (($0) + 1|0);
    $634 = $633;
   } else {
    $631 = (($0) + 8|0);
    $632 = HEAP32[$631>>2]|0;
    $634 = $632;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($634|0),0,(637528|0),32,1,0,0,(0|0));
   $635 = __THREW__; __THREW__ = 0;
   $636 = $635&1;
   if (!($636)) {
    $637 = HEAP8[$0>>0]|0;
    $638 = $637 & 1;
    $639 = ($638<<24>>24)==(0);
    if ($639) {
     break;
    }
    $640 = (($0) + 8|0);
    $641 = HEAP32[$640>>2]|0;
    __ZdlPv($641);
    break;
   }
   $642 = ___cxa_find_matching_catch()|0;
   $643 = tempRet0;
   $644 = HEAP8[$0>>0]|0;
   $645 = $644 & 1;
   $646 = ($645<<24>>24)==(0);
   if ($646) {
    ___resumeException($642|0);
    // unreachable;
   }
   $647 = (($0) + 8|0);
   $648 = HEAP32[$647>>2]|0;
   __ZdlPv($648);
   ___resumeException($642|0);
   // unreachable;
  }
 } while(0);
 $649 = (($commonScriptingClasses) + 240|0);
 HEAP32[$649>>2] = $626;
 $650 = (__Z24GetBuiltinScriptingClassPKcb(635736,0)|0);
 $651 = (($commonScriptingClasses) + 248|0);
 HEAP32[$651>>2] = $650;
 $652 = HEAP32[$625>>2]|0;
 $653 = (__Z25scripting_class_get_imageP14ScriptingClass($652)|0);
 $654 = (($commonScriptingClasses) + 96|0);
 HEAP32[$654>>2] = $653;
 $655 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635768)|0);
 $656 = ($655|0)==(0|0);
 do {
  if ($656) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr126 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr126>>2] = 637608;
   $vararg_ptr127 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr127>>2] = 635768;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $657 = HEAP8[$0>>0]|0;
   $658 = $657 & 1;
   $659 = ($658<<24>>24)==(0);
   if ($659) {
    $662 = (($0) + 1|0);
    $663 = $662;
   } else {
    $660 = (($0) + 8|0);
    $661 = HEAP32[$660>>2]|0;
    $663 = $661;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($663|0),0,(637528|0),32,1,0,0,(0|0));
   $664 = __THREW__; __THREW__ = 0;
   $665 = $664&1;
   if (!($665)) {
    $666 = HEAP8[$0>>0]|0;
    $667 = $666 & 1;
    $668 = ($667<<24>>24)==(0);
    if ($668) {
     break;
    }
    $669 = (($0) + 8|0);
    $670 = HEAP32[$669>>2]|0;
    __ZdlPv($670);
    break;
   }
   $671 = ___cxa_find_matching_catch()|0;
   $672 = tempRet0;
   $673 = HEAP8[$0>>0]|0;
   $674 = $673 & 1;
   $675 = ($674<<24>>24)==(0);
   if ($675) {
    ___resumeException($671|0);
    // unreachable;
   }
   $676 = (($0) + 8|0);
   $677 = HEAP32[$676>>2]|0;
   __ZdlPv($677);
   ___resumeException($671|0);
   // unreachable;
  }
 } while(0);
 $678 = (($commonScriptingClasses) + 92|0);
 HEAP32[$678>>2] = $655;
 $679 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635784)|0);
 $680 = ($679|0)==(0|0);
 do {
  if ($680) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr131 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr131>>2] = 637608;
   $vararg_ptr132 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr132>>2] = 635784;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $681 = HEAP8[$0>>0]|0;
   $682 = $681 & 1;
   $683 = ($682<<24>>24)==(0);
   if ($683) {
    $686 = (($0) + 1|0);
    $687 = $686;
   } else {
    $684 = (($0) + 8|0);
    $685 = HEAP32[$684>>2]|0;
    $687 = $685;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($687|0),0,(637528|0),32,1,0,0,(0|0));
   $688 = __THREW__; __THREW__ = 0;
   $689 = $688&1;
   if (!($689)) {
    $690 = HEAP8[$0>>0]|0;
    $691 = $690 & 1;
    $692 = ($691<<24>>24)==(0);
    if ($692) {
     break;
    }
    $693 = (($0) + 8|0);
    $694 = HEAP32[$693>>2]|0;
    __ZdlPv($694);
    break;
   }
   $695 = ___cxa_find_matching_catch()|0;
   $696 = tempRet0;
   $697 = HEAP8[$0>>0]|0;
   $698 = $697 & 1;
   $699 = ($698<<24>>24)==(0);
   if ($699) {
    ___resumeException($695|0);
    // unreachable;
   }
   $700 = (($0) + 8|0);
   $701 = HEAP32[$700>>2]|0;
   __ZdlPv($701);
   ___resumeException($695|0);
   // unreachable;
  }
 } while(0);
 $702 = (($commonScriptingClasses) + 252|0);
 HEAP32[$702>>2] = $679;
 $703 = (($commonScriptingClasses) + 256|0);
 __ZL13RequireMethodPKcS0_S0_S0_($2,637592,637608,635784,635816);
 ;HEAP32[$703+0>>2]=HEAP32[$2+0>>2]|0;HEAP8[$703+4>>0]=HEAP8[$2+4>>0]|0;
 $704 = (($commonScriptingClasses) + 264|0);
 __ZL13RequireMethodPKcS0_S0_S0_($3,637592,637608,635784,635840);
 ;HEAP32[$704+0>>2]=HEAP32[$3+0>>2]|0;HEAP8[$704+4>>0]=HEAP8[$3+4>>0]|0;
 $705 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635864)|0);
 $706 = ($705|0)==(0|0);
 do {
  if ($706) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr136 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr136>>2] = 637608;
   $vararg_ptr137 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr137>>2] = 635864;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $707 = HEAP8[$0>>0]|0;
   $708 = $707 & 1;
   $709 = ($708<<24>>24)==(0);
   if ($709) {
    $712 = (($0) + 1|0);
    $713 = $712;
   } else {
    $710 = (($0) + 8|0);
    $711 = HEAP32[$710>>2]|0;
    $713 = $711;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($713|0),0,(637528|0),32,1,0,0,(0|0));
   $714 = __THREW__; __THREW__ = 0;
   $715 = $714&1;
   if (!($715)) {
    $716 = HEAP8[$0>>0]|0;
    $717 = $716 & 1;
    $718 = ($717<<24>>24)==(0);
    if ($718) {
     break;
    }
    $719 = (($0) + 8|0);
    $720 = HEAP32[$719>>2]|0;
    __ZdlPv($720);
    break;
   }
   $721 = ___cxa_find_matching_catch()|0;
   $722 = tempRet0;
   $723 = HEAP8[$0>>0]|0;
   $724 = $723 & 1;
   $725 = ($724<<24>>24)==(0);
   if ($725) {
    ___resumeException($721|0);
    // unreachable;
   }
   $726 = (($0) + 8|0);
   $727 = HEAP32[$726>>2]|0;
   __ZdlPv($727);
   ___resumeException($721|0);
   // unreachable;
  }
 } while(0);
 $728 = (($commonScriptingClasses) + 272|0);
 HEAP32[$728>>2] = $705;
 $729 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635880)|0);
 $730 = ($729|0)==(0|0);
 do {
  if ($730) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr141 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr141>>2] = 637608;
   $vararg_ptr142 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr142>>2] = 635880;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $731 = HEAP8[$0>>0]|0;
   $732 = $731 & 1;
   $733 = ($732<<24>>24)==(0);
   if ($733) {
    $736 = (($0) + 1|0);
    $737 = $736;
   } else {
    $734 = (($0) + 8|0);
    $735 = HEAP32[$734>>2]|0;
    $737 = $735;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($737|0),0,(637528|0),32,1,0,0,(0|0));
   $738 = __THREW__; __THREW__ = 0;
   $739 = $738&1;
   if (!($739)) {
    $740 = HEAP8[$0>>0]|0;
    $741 = $740 & 1;
    $742 = ($741<<24>>24)==(0);
    if ($742) {
     break;
    }
    $743 = (($0) + 8|0);
    $744 = HEAP32[$743>>2]|0;
    __ZdlPv($744);
    break;
   }
   $745 = ___cxa_find_matching_catch()|0;
   $746 = tempRet0;
   $747 = HEAP8[$0>>0]|0;
   $748 = $747 & 1;
   $749 = ($748<<24>>24)==(0);
   if ($749) {
    ___resumeException($745|0);
    // unreachable;
   }
   $750 = (($0) + 8|0);
   $751 = HEAP32[$750>>2]|0;
   __ZdlPv($751);
   ___resumeException($745|0);
   // unreachable;
  }
 } while(0);
 $752 = (($commonScriptingClasses) + 276|0);
 HEAP32[$752>>2] = $729;
 $753 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635896)|0);
 $754 = ($753|0)==(0|0);
 do {
  if ($754) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr146 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr146>>2] = 637608;
   $vararg_ptr147 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr147>>2] = 635896;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $755 = HEAP8[$0>>0]|0;
   $756 = $755 & 1;
   $757 = ($756<<24>>24)==(0);
   if ($757) {
    $760 = (($0) + 1|0);
    $761 = $760;
   } else {
    $758 = (($0) + 8|0);
    $759 = HEAP32[$758>>2]|0;
    $761 = $759;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($761|0),0,(637528|0),32,1,0,0,(0|0));
   $762 = __THREW__; __THREW__ = 0;
   $763 = $762&1;
   if (!($763)) {
    $764 = HEAP8[$0>>0]|0;
    $765 = $764 & 1;
    $766 = ($765<<24>>24)==(0);
    if ($766) {
     break;
    }
    $767 = (($0) + 8|0);
    $768 = HEAP32[$767>>2]|0;
    __ZdlPv($768);
    break;
   }
   $769 = ___cxa_find_matching_catch()|0;
   $770 = tempRet0;
   $771 = HEAP8[$0>>0]|0;
   $772 = $771 & 1;
   $773 = ($772<<24>>24)==(0);
   if ($773) {
    ___resumeException($769|0);
    // unreachable;
   }
   $774 = (($0) + 8|0);
   $775 = HEAP32[$774>>2]|0;
   __ZdlPv($775);
   ___resumeException($769|0);
   // unreachable;
  }
 } while(0);
 $776 = (($commonScriptingClasses) + 280|0);
 HEAP32[$776>>2] = $753;
 $777 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635912)|0);
 $778 = ($777|0)==(0|0);
 do {
  if ($778) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr151 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr151>>2] = 637608;
   $vararg_ptr152 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr152>>2] = 635912;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $779 = HEAP8[$0>>0]|0;
   $780 = $779 & 1;
   $781 = ($780<<24>>24)==(0);
   if ($781) {
    $784 = (($0) + 1|0);
    $785 = $784;
   } else {
    $782 = (($0) + 8|0);
    $783 = HEAP32[$782>>2]|0;
    $785 = $783;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($785|0),0,(637528|0),32,1,0,0,(0|0));
   $786 = __THREW__; __THREW__ = 0;
   $787 = $786&1;
   if (!($787)) {
    $788 = HEAP8[$0>>0]|0;
    $789 = $788 & 1;
    $790 = ($789<<24>>24)==(0);
    if ($790) {
     break;
    }
    $791 = (($0) + 8|0);
    $792 = HEAP32[$791>>2]|0;
    __ZdlPv($792);
    break;
   }
   $793 = ___cxa_find_matching_catch()|0;
   $794 = tempRet0;
   $795 = HEAP8[$0>>0]|0;
   $796 = $795 & 1;
   $797 = ($796<<24>>24)==(0);
   if ($797) {
    ___resumeException($793|0);
    // unreachable;
   }
   $798 = (($0) + 8|0);
   $799 = HEAP32[$798>>2]|0;
   __ZdlPv($799);
   ___resumeException($793|0);
   // unreachable;
  }
 } while(0);
 $800 = (($commonScriptingClasses) + 288|0);
 HEAP32[$800>>2] = $777;
 $801 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635928)|0);
 $802 = (($commonScriptingClasses) + 412|0);
 HEAP32[$802>>2] = $801;
 $803 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635936)|0);
 $804 = (($commonScriptingClasses) + 416|0);
 HEAP32[$804>>2] = $803;
 $805 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635952)|0);
 $806 = (($commonScriptingClasses) + 420|0);
 HEAP32[$806>>2] = $805;
 $807 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635968)|0);
 $808 = (($commonScriptingClasses) + 424|0);
 HEAP32[$808>>2] = $807;
 $809 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635984)|0);
 $810 = (($commonScriptingClasses) + 428|0);
 HEAP32[$810>>2] = $809;
 $811 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636000)|0);
 $812 = ($811|0)==(0|0);
 do {
  if ($812) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr156 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr156>>2] = 637608;
   $vararg_ptr157 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr157>>2] = 636000;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $813 = HEAP8[$0>>0]|0;
   $814 = $813 & 1;
   $815 = ($814<<24>>24)==(0);
   if ($815) {
    $818 = (($0) + 1|0);
    $819 = $818;
   } else {
    $816 = (($0) + 8|0);
    $817 = HEAP32[$816>>2]|0;
    $819 = $817;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($819|0),0,(637528|0),32,1,0,0,(0|0));
   $820 = __THREW__; __THREW__ = 0;
   $821 = $820&1;
   if (!($821)) {
    $822 = HEAP8[$0>>0]|0;
    $823 = $822 & 1;
    $824 = ($823<<24>>24)==(0);
    if ($824) {
     break;
    }
    $825 = (($0) + 8|0);
    $826 = HEAP32[$825>>2]|0;
    __ZdlPv($826);
    break;
   }
   $827 = ___cxa_find_matching_catch()|0;
   $828 = tempRet0;
   $829 = HEAP8[$0>>0]|0;
   $830 = $829 & 1;
   $831 = ($830<<24>>24)==(0);
   if ($831) {
    ___resumeException($827|0);
    // unreachable;
   }
   $832 = (($0) + 8|0);
   $833 = HEAP32[$832>>2]|0;
   __ZdlPv($833);
   ___resumeException($827|0);
   // unreachable;
  }
 } while(0);
 $834 = (($commonScriptingClasses) + 432|0);
 HEAP32[$834>>2] = $811;
 $835 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636016)|0);
 $836 = ($835|0)==(0|0);
 do {
  if ($836) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr161 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr161>>2] = 637608;
   $vararg_ptr162 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr162>>2] = 636016;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $837 = HEAP8[$0>>0]|0;
   $838 = $837 & 1;
   $839 = ($838<<24>>24)==(0);
   if ($839) {
    $842 = (($0) + 1|0);
    $843 = $842;
   } else {
    $840 = (($0) + 8|0);
    $841 = HEAP32[$840>>2]|0;
    $843 = $841;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($843|0),0,(637528|0),32,1,0,0,(0|0));
   $844 = __THREW__; __THREW__ = 0;
   $845 = $844&1;
   if (!($845)) {
    $846 = HEAP8[$0>>0]|0;
    $847 = $846 & 1;
    $848 = ($847<<24>>24)==(0);
    if ($848) {
     break;
    }
    $849 = (($0) + 8|0);
    $850 = HEAP32[$849>>2]|0;
    __ZdlPv($850);
    break;
   }
   $851 = ___cxa_find_matching_catch()|0;
   $852 = tempRet0;
   $853 = HEAP8[$0>>0]|0;
   $854 = $853 & 1;
   $855 = ($854<<24>>24)==(0);
   if ($855) {
    ___resumeException($851|0);
    // unreachable;
   }
   $856 = (($0) + 8|0);
   $857 = HEAP32[$856>>2]|0;
   __ZdlPv($857);
   ___resumeException($851|0);
   // unreachable;
  }
 } while(0);
 $858 = (($commonScriptingClasses) + 436|0);
 HEAP32[$858>>2] = $835;
 $859 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636040)|0);
 $860 = ($859|0)==(0|0);
 do {
  if ($860) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr166 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr166>>2] = 637608;
   $vararg_ptr167 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr167>>2] = 636040;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $861 = HEAP8[$0>>0]|0;
   $862 = $861 & 1;
   $863 = ($862<<24>>24)==(0);
   if ($863) {
    $866 = (($0) + 1|0);
    $867 = $866;
   } else {
    $864 = (($0) + 8|0);
    $865 = HEAP32[$864>>2]|0;
    $867 = $865;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($867|0),0,(637528|0),32,1,0,0,(0|0));
   $868 = __THREW__; __THREW__ = 0;
   $869 = $868&1;
   if (!($869)) {
    $870 = HEAP8[$0>>0]|0;
    $871 = $870 & 1;
    $872 = ($871<<24>>24)==(0);
    if ($872) {
     break;
    }
    $873 = (($0) + 8|0);
    $874 = HEAP32[$873>>2]|0;
    __ZdlPv($874);
    break;
   }
   $875 = ___cxa_find_matching_catch()|0;
   $876 = tempRet0;
   $877 = HEAP8[$0>>0]|0;
   $878 = $877 & 1;
   $879 = ($878<<24>>24)==(0);
   if ($879) {
    ___resumeException($875|0);
    // unreachable;
   }
   $880 = (($0) + 8|0);
   $881 = HEAP32[$880>>2]|0;
   __ZdlPv($881);
   ___resumeException($875|0);
   // unreachable;
  }
 } while(0);
 $882 = (($commonScriptingClasses) + 440|0);
 HEAP32[$882>>2] = $859;
 $883 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636056)|0);
 $884 = ($883|0)==(0|0);
 do {
  if ($884) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr171 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr171>>2] = 637608;
   $vararg_ptr172 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr172>>2] = 636056;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $885 = HEAP8[$0>>0]|0;
   $886 = $885 & 1;
   $887 = ($886<<24>>24)==(0);
   if ($887) {
    $890 = (($0) + 1|0);
    $891 = $890;
   } else {
    $888 = (($0) + 8|0);
    $889 = HEAP32[$888>>2]|0;
    $891 = $889;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($891|0),0,(637528|0),32,1,0,0,(0|0));
   $892 = __THREW__; __THREW__ = 0;
   $893 = $892&1;
   if (!($893)) {
    $894 = HEAP8[$0>>0]|0;
    $895 = $894 & 1;
    $896 = ($895<<24>>24)==(0);
    if ($896) {
     break;
    }
    $897 = (($0) + 8|0);
    $898 = HEAP32[$897>>2]|0;
    __ZdlPv($898);
    break;
   }
   $899 = ___cxa_find_matching_catch()|0;
   $900 = tempRet0;
   $901 = HEAP8[$0>>0]|0;
   $902 = $901 & 1;
   $903 = ($902<<24>>24)==(0);
   if ($903) {
    ___resumeException($899|0);
    // unreachable;
   }
   $904 = (($0) + 8|0);
   $905 = HEAP32[$904>>2]|0;
   __ZdlPv($905);
   ___resumeException($899|0);
   // unreachable;
  }
 } while(0);
 $906 = (($commonScriptingClasses) + 204|0);
 HEAP32[$906>>2] = $883;
 $907 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636088)|0);
 $908 = ($907|0)==(0|0);
 do {
  if ($908) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr176 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr176>>2] = 637608;
   $vararg_ptr177 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr177>>2] = 636088;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $909 = HEAP8[$0>>0]|0;
   $910 = $909 & 1;
   $911 = ($910<<24>>24)==(0);
   if ($911) {
    $914 = (($0) + 1|0);
    $915 = $914;
   } else {
    $912 = (($0) + 8|0);
    $913 = HEAP32[$912>>2]|0;
    $915 = $913;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($915|0),0,(637528|0),32,1,0,0,(0|0));
   $916 = __THREW__; __THREW__ = 0;
   $917 = $916&1;
   if (!($917)) {
    $918 = HEAP8[$0>>0]|0;
    $919 = $918 & 1;
    $920 = ($919<<24>>24)==(0);
    if ($920) {
     break;
    }
    $921 = (($0) + 8|0);
    $922 = HEAP32[$921>>2]|0;
    __ZdlPv($922);
    break;
   }
   $923 = ___cxa_find_matching_catch()|0;
   $924 = tempRet0;
   $925 = HEAP8[$0>>0]|0;
   $926 = $925 & 1;
   $927 = ($926<<24>>24)==(0);
   if ($927) {
    ___resumeException($923|0);
    // unreachable;
   }
   $928 = (($0) + 8|0);
   $929 = HEAP32[$928>>2]|0;
   __ZdlPv($929);
   ___resumeException($923|0);
   // unreachable;
  }
 } while(0);
 $930 = (($commonScriptingClasses) + 444|0);
 HEAP32[$930>>2] = $907;
 $931 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636104)|0);
 $932 = (($commonScriptingClasses) + 448|0);
 HEAP32[$932>>2] = $931;
 $933 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636120)|0);
 $934 = ($933|0)==(0|0);
 do {
  if ($934) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr181 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr181>>2] = 637608;
   $vararg_ptr182 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr182>>2] = 636120;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $935 = HEAP8[$0>>0]|0;
   $936 = $935 & 1;
   $937 = ($936<<24>>24)==(0);
   if ($937) {
    $940 = (($0) + 1|0);
    $941 = $940;
   } else {
    $938 = (($0) + 8|0);
    $939 = HEAP32[$938>>2]|0;
    $941 = $939;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($941|0),0,(637528|0),32,1,0,0,(0|0));
   $942 = __THREW__; __THREW__ = 0;
   $943 = $942&1;
   if (!($943)) {
    $944 = HEAP8[$0>>0]|0;
    $945 = $944 & 1;
    $946 = ($945<<24>>24)==(0);
    if ($946) {
     break;
    }
    $947 = (($0) + 8|0);
    $948 = HEAP32[$947>>2]|0;
    __ZdlPv($948);
    break;
   }
   $949 = ___cxa_find_matching_catch()|0;
   $950 = tempRet0;
   $951 = HEAP8[$0>>0]|0;
   $952 = $951 & 1;
   $953 = ($952<<24>>24)==(0);
   if ($953) {
    ___resumeException($949|0);
    // unreachable;
   }
   $954 = (($0) + 8|0);
   $955 = HEAP32[$954>>2]|0;
   __ZdlPv($955);
   ___resumeException($949|0);
   // unreachable;
  }
 } while(0);
 $956 = (($commonScriptingClasses) + 284|0);
 HEAP32[$956>>2] = $933;
 $957 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,635728)|0);
 $958 = ($957|0)==(0|0);
 do {
  if ($958) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr186 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr186>>2] = 637608;
   $vararg_ptr187 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr187>>2] = 635728;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $959 = HEAP8[$0>>0]|0;
   $960 = $959 & 1;
   $961 = ($960<<24>>24)==(0);
   if ($961) {
    $964 = (($0) + 1|0);
    $965 = $964;
   } else {
    $962 = (($0) + 8|0);
    $963 = HEAP32[$962>>2]|0;
    $965 = $963;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($965|0),0,(637528|0),32,1,0,0,(0|0));
   $966 = __THREW__; __THREW__ = 0;
   $967 = $966&1;
   if (!($967)) {
    $968 = HEAP8[$0>>0]|0;
    $969 = $968 & 1;
    $970 = ($969<<24>>24)==(0);
    if ($970) {
     break;
    }
    $971 = (($0) + 8|0);
    $972 = HEAP32[$971>>2]|0;
    __ZdlPv($972);
    break;
   }
   $973 = ___cxa_find_matching_catch()|0;
   $974 = tempRet0;
   $975 = HEAP8[$0>>0]|0;
   $976 = $975 & 1;
   $977 = ($976<<24>>24)==(0);
   if ($977) {
    ___resumeException($973|0);
    // unreachable;
   }
   $978 = (($0) + 8|0);
   $979 = HEAP32[$978>>2]|0;
   __ZdlPv($979);
   ___resumeException($973|0);
   // unreachable;
  }
 } while(0);
 $980 = (($commonScriptingClasses) + 452|0);
 HEAP32[$980>>2] = $957;
 $981 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636136)|0);
 $982 = (($commonScriptingClasses) + 456|0);
 HEAP32[$982>>2] = $981;
 $983 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,636160,636184)|0);
 $984 = (($commonScriptingClasses) + 460|0);
 HEAP32[$984>>2] = $983;
 $985 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,636200)|0);
 $986 = (($commonScriptingClasses) + 464|0);
 HEAP32[$986>>2] = $985;
 $987 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636232,636256)|0);
 $988 = ($987|0)==(0|0);
 do {
  if ($988) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr191 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr191>>2] = 636232;
   $vararg_ptr192 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr192>>2] = 636256;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $989 = HEAP8[$0>>0]|0;
   $990 = $989 & 1;
   $991 = ($990<<24>>24)==(0);
   if ($991) {
    $994 = (($0) + 1|0);
    $995 = $994;
   } else {
    $992 = (($0) + 8|0);
    $993 = HEAP32[$992>>2]|0;
    $995 = $993;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($995|0),0,(637528|0),32,1,0,0,(0|0));
   $996 = __THREW__; __THREW__ = 0;
   $997 = $996&1;
   if (!($997)) {
    $998 = HEAP8[$0>>0]|0;
    $999 = $998 & 1;
    $1000 = ($999<<24>>24)==(0);
    if ($1000) {
     break;
    }
    $1001 = (($0) + 8|0);
    $1002 = HEAP32[$1001>>2]|0;
    __ZdlPv($1002);
    break;
   }
   $1003 = ___cxa_find_matching_catch()|0;
   $1004 = tempRet0;
   $1005 = HEAP8[$0>>0]|0;
   $1006 = $1005 & 1;
   $1007 = ($1006<<24>>24)==(0);
   if ($1007) {
    ___resumeException($1003|0);
    // unreachable;
   }
   $1008 = (($0) + 8|0);
   $1009 = HEAP32[$1008>>2]|0;
   __ZdlPv($1009);
   ___resumeException($1003|0);
   // unreachable;
  }
 } while(0);
 $1010 = (($commonScriptingClasses) + 104|0);
 HEAP32[$1010>>2] = $987;
 $1011 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,635720)|0);
 $1012 = ($1011|0)==(0|0);
 do {
  if ($1012) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr196 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr196>>2] = 636272;
   $vararg_ptr197 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr197>>2] = 635720;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1013 = HEAP8[$0>>0]|0;
   $1014 = $1013 & 1;
   $1015 = ($1014<<24>>24)==(0);
   if ($1015) {
    $1018 = (($0) + 1|0);
    $1019 = $1018;
   } else {
    $1016 = (($0) + 8|0);
    $1017 = HEAP32[$1016>>2]|0;
    $1019 = $1017;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1019|0),0,(637528|0),32,1,0,0,(0|0));
   $1020 = __THREW__; __THREW__ = 0;
   $1021 = $1020&1;
   if (!($1021)) {
    $1022 = HEAP8[$0>>0]|0;
    $1023 = $1022 & 1;
    $1024 = ($1023<<24>>24)==(0);
    if ($1024) {
     break;
    }
    $1025 = (($0) + 8|0);
    $1026 = HEAP32[$1025>>2]|0;
    __ZdlPv($1026);
    break;
   }
   $1027 = ___cxa_find_matching_catch()|0;
   $1028 = tempRet0;
   $1029 = HEAP8[$0>>0]|0;
   $1030 = $1029 & 1;
   $1031 = ($1030<<24>>24)==(0);
   if ($1031) {
    ___resumeException($1027|0);
    // unreachable;
   }
   $1032 = (($0) + 8|0);
   $1033 = HEAP32[$1032>>2]|0;
   __ZdlPv($1033);
   ___resumeException($1027|0);
   // unreachable;
  }
 } while(0);
 $1034 = (($commonScriptingClasses) + 108|0);
 HEAP32[$1034>>2] = $1011;
 $1035 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636280)|0);
 $1036 = ($1035|0)==(0|0);
 do {
  if ($1036) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr201 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr201>>2] = 636272;
   $vararg_ptr202 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr202>>2] = 636280;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1037 = HEAP8[$0>>0]|0;
   $1038 = $1037 & 1;
   $1039 = ($1038<<24>>24)==(0);
   if ($1039) {
    $1042 = (($0) + 1|0);
    $1043 = $1042;
   } else {
    $1040 = (($0) + 8|0);
    $1041 = HEAP32[$1040>>2]|0;
    $1043 = $1041;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1043|0),0,(637528|0),32,1,0,0,(0|0));
   $1044 = __THREW__; __THREW__ = 0;
   $1045 = $1044&1;
   if (!($1045)) {
    $1046 = HEAP8[$0>>0]|0;
    $1047 = $1046 & 1;
    $1048 = ($1047<<24>>24)==(0);
    if ($1048) {
     break;
    }
    $1049 = (($0) + 8|0);
    $1050 = HEAP32[$1049>>2]|0;
    __ZdlPv($1050);
    break;
   }
   $1051 = ___cxa_find_matching_catch()|0;
   $1052 = tempRet0;
   $1053 = HEAP8[$0>>0]|0;
   $1054 = $1053 & 1;
   $1055 = ($1054<<24>>24)==(0);
   if ($1055) {
    ___resumeException($1051|0);
    // unreachable;
   }
   $1056 = (($0) + 8|0);
   $1057 = HEAP32[$1056>>2]|0;
   __ZdlPv($1057);
   ___resumeException($1051|0);
   // unreachable;
  }
 } while(0);
 $1058 = (($commonScriptingClasses) + 168|0);
 HEAP32[$1058>>2] = $1035;
 $1059 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636288)|0);
 $1060 = ($1059|0)==(0|0);
 do {
  if ($1060) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr206 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr206>>2] = 636272;
   $vararg_ptr207 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr207>>2] = 636288;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1061 = HEAP8[$0>>0]|0;
   $1062 = $1061 & 1;
   $1063 = ($1062<<24>>24)==(0);
   if ($1063) {
    $1066 = (($0) + 1|0);
    $1067 = $1066;
   } else {
    $1064 = (($0) + 8|0);
    $1065 = HEAP32[$1064>>2]|0;
    $1067 = $1065;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1067|0),0,(637528|0),32,1,0,0,(0|0));
   $1068 = __THREW__; __THREW__ = 0;
   $1069 = $1068&1;
   if (!($1069)) {
    $1070 = HEAP8[$0>>0]|0;
    $1071 = $1070 & 1;
    $1072 = ($1071<<24>>24)==(0);
    if ($1072) {
     break;
    }
    $1073 = (($0) + 8|0);
    $1074 = HEAP32[$1073>>2]|0;
    __ZdlPv($1074);
    break;
   }
   $1075 = ___cxa_find_matching_catch()|0;
   $1076 = tempRet0;
   $1077 = HEAP8[$0>>0]|0;
   $1078 = $1077 & 1;
   $1079 = ($1078<<24>>24)==(0);
   if ($1079) {
    ___resumeException($1075|0);
    // unreachable;
   }
   $1080 = (($0) + 8|0);
   $1081 = HEAP32[$1080>>2]|0;
   __ZdlPv($1081);
   ___resumeException($1075|0);
   // unreachable;
  }
 } while(0);
 $1082 = (($commonScriptingClasses) + 164|0);
 HEAP32[$1082>>2] = $1059;
 $1083 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636296)|0);
 $1084 = ($1083|0)==(0|0);
 do {
  if ($1084) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr211 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr211>>2] = 636272;
   $vararg_ptr212 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr212>>2] = 636296;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1085 = HEAP8[$0>>0]|0;
   $1086 = $1085 & 1;
   $1087 = ($1086<<24>>24)==(0);
   if ($1087) {
    $1090 = (($0) + 1|0);
    $1091 = $1090;
   } else {
    $1088 = (($0) + 8|0);
    $1089 = HEAP32[$1088>>2]|0;
    $1091 = $1089;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1091|0),0,(637528|0),32,1,0,0,(0|0));
   $1092 = __THREW__; __THREW__ = 0;
   $1093 = $1092&1;
   if (!($1093)) {
    $1094 = HEAP8[$0>>0]|0;
    $1095 = $1094 & 1;
    $1096 = ($1095<<24>>24)==(0);
    if ($1096) {
     break;
    }
    $1097 = (($0) + 8|0);
    $1098 = HEAP32[$1097>>2]|0;
    __ZdlPv($1098);
    break;
   }
   $1099 = ___cxa_find_matching_catch()|0;
   $1100 = tempRet0;
   $1101 = HEAP8[$0>>0]|0;
   $1102 = $1101 & 1;
   $1103 = ($1102<<24>>24)==(0);
   if ($1103) {
    ___resumeException($1099|0);
    // unreachable;
   }
   $1104 = (($0) + 8|0);
   $1105 = HEAP32[$1104>>2]|0;
   __ZdlPv($1105);
   ___resumeException($1099|0);
   // unreachable;
  }
 } while(0);
 $1106 = (($commonScriptingClasses) + 172|0);
 HEAP32[$1106>>2] = $1083;
 $1107 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636304)|0);
 $1108 = ($1107|0)==(0|0);
 do {
  if ($1108) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr216 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr216>>2] = 636272;
   $vararg_ptr217 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr217>>2] = 636304;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1109 = HEAP8[$0>>0]|0;
   $1110 = $1109 & 1;
   $1111 = ($1110<<24>>24)==(0);
   if ($1111) {
    $1114 = (($0) + 1|0);
    $1115 = $1114;
   } else {
    $1112 = (($0) + 8|0);
    $1113 = HEAP32[$1112>>2]|0;
    $1115 = $1113;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1115|0),0,(637528|0),32,1,0,0,(0|0));
   $1116 = __THREW__; __THREW__ = 0;
   $1117 = $1116&1;
   if (!($1117)) {
    $1118 = HEAP8[$0>>0]|0;
    $1119 = $1118 & 1;
    $1120 = ($1119<<24>>24)==(0);
    if ($1120) {
     break;
    }
    $1121 = (($0) + 8|0);
    $1122 = HEAP32[$1121>>2]|0;
    __ZdlPv($1122);
    break;
   }
   $1123 = ___cxa_find_matching_catch()|0;
   $1124 = tempRet0;
   $1125 = HEAP8[$0>>0]|0;
   $1126 = $1125 & 1;
   $1127 = ($1126<<24>>24)==(0);
   if ($1127) {
    ___resumeException($1123|0);
    // unreachable;
   }
   $1128 = (($0) + 8|0);
   $1129 = HEAP32[$1128>>2]|0;
   __ZdlPv($1129);
   ___resumeException($1123|0);
   // unreachable;
  }
 } while(0);
 $1130 = (($commonScriptingClasses) + 176|0);
 HEAP32[$1130>>2] = $1107;
 $1131 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636312)|0);
 $1132 = ($1131|0)==(0|0);
 do {
  if ($1132) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr221 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr221>>2] = 636272;
   $vararg_ptr222 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr222>>2] = 636312;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1133 = HEAP8[$0>>0]|0;
   $1134 = $1133 & 1;
   $1135 = ($1134<<24>>24)==(0);
   if ($1135) {
    $1138 = (($0) + 1|0);
    $1139 = $1138;
   } else {
    $1136 = (($0) + 8|0);
    $1137 = HEAP32[$1136>>2]|0;
    $1139 = $1137;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1139|0),0,(637528|0),32,1,0,0,(0|0));
   $1140 = __THREW__; __THREW__ = 0;
   $1141 = $1140&1;
   if (!($1141)) {
    $1142 = HEAP8[$0>>0]|0;
    $1143 = $1142 & 1;
    $1144 = ($1143<<24>>24)==(0);
    if ($1144) {
     break;
    }
    $1145 = (($0) + 8|0);
    $1146 = HEAP32[$1145>>2]|0;
    __ZdlPv($1146);
    break;
   }
   $1147 = ___cxa_find_matching_catch()|0;
   $1148 = tempRet0;
   $1149 = HEAP8[$0>>0]|0;
   $1150 = $1149 & 1;
   $1151 = ($1150<<24>>24)==(0);
   if ($1151) {
    ___resumeException($1147|0);
    // unreachable;
   }
   $1152 = (($0) + 8|0);
   $1153 = HEAP32[$1152>>2]|0;
   __ZdlPv($1153);
   ___resumeException($1147|0);
   // unreachable;
  }
 } while(0);
 $1154 = (($commonScriptingClasses) + 160|0);
 HEAP32[$1154>>2] = $1131;
 $1155 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636320)|0);
 $1156 = ($1155|0)==(0|0);
 do {
  if ($1156) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr226 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr226>>2] = 636272;
   $vararg_ptr227 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr227>>2] = 636320;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1157 = HEAP8[$0>>0]|0;
   $1158 = $1157 & 1;
   $1159 = ($1158<<24>>24)==(0);
   if ($1159) {
    $1162 = (($0) + 1|0);
    $1163 = $1162;
   } else {
    $1160 = (($0) + 8|0);
    $1161 = HEAP32[$1160>>2]|0;
    $1163 = $1161;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1163|0),0,(637528|0),32,1,0,0,(0|0));
   $1164 = __THREW__; __THREW__ = 0;
   $1165 = $1164&1;
   if (!($1165)) {
    $1166 = HEAP8[$0>>0]|0;
    $1167 = $1166 & 1;
    $1168 = ($1167<<24>>24)==(0);
    if ($1168) {
     break;
    }
    $1169 = (($0) + 8|0);
    $1170 = HEAP32[$1169>>2]|0;
    __ZdlPv($1170);
    break;
   }
   $1171 = ___cxa_find_matching_catch()|0;
   $1172 = tempRet0;
   $1173 = HEAP8[$0>>0]|0;
   $1174 = $1173 & 1;
   $1175 = ($1174<<24>>24)==(0);
   if ($1175) {
    ___resumeException($1171|0);
    // unreachable;
   }
   $1176 = (($0) + 8|0);
   $1177 = HEAP32[$1176>>2]|0;
   __ZdlPv($1177);
   ___resumeException($1171|0);
   // unreachable;
  }
 } while(0);
 $1178 = (($commonScriptingClasses) + 112|0);
 HEAP32[$1178>>2] = $1155;
 $1179 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636328)|0);
 $1180 = ($1179|0)==(0|0);
 do {
  if ($1180) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr231 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr231>>2] = 636272;
   $vararg_ptr232 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr232>>2] = 636328;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1181 = HEAP8[$0>>0]|0;
   $1182 = $1181 & 1;
   $1183 = ($1182<<24>>24)==(0);
   if ($1183) {
    $1186 = (($0) + 1|0);
    $1187 = $1186;
   } else {
    $1184 = (($0) + 8|0);
    $1185 = HEAP32[$1184>>2]|0;
    $1187 = $1185;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1187|0),0,(637528|0),32,1,0,0,(0|0));
   $1188 = __THREW__; __THREW__ = 0;
   $1189 = $1188&1;
   if (!($1189)) {
    $1190 = HEAP8[$0>>0]|0;
    $1191 = $1190 & 1;
    $1192 = ($1191<<24>>24)==(0);
    if ($1192) {
     break;
    }
    $1193 = (($0) + 8|0);
    $1194 = HEAP32[$1193>>2]|0;
    __ZdlPv($1194);
    break;
   }
   $1195 = ___cxa_find_matching_catch()|0;
   $1196 = tempRet0;
   $1197 = HEAP8[$0>>0]|0;
   $1198 = $1197 & 1;
   $1199 = ($1198<<24>>24)==(0);
   if ($1199) {
    ___resumeException($1195|0);
    // unreachable;
   }
   $1200 = (($0) + 8|0);
   $1201 = HEAP32[$1200>>2]|0;
   __ZdlPv($1201);
   ___resumeException($1195|0);
   // unreachable;
  }
 } while(0);
 $1202 = (($commonScriptingClasses) + 116|0);
 HEAP32[$1202>>2] = $1179;
 $1203 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636336)|0);
 $1204 = ($1203|0)==(0|0);
 do {
  if ($1204) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr236 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr236>>2] = 636272;
   $vararg_ptr237 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr237>>2] = 636336;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1205 = HEAP8[$0>>0]|0;
   $1206 = $1205 & 1;
   $1207 = ($1206<<24>>24)==(0);
   if ($1207) {
    $1210 = (($0) + 1|0);
    $1211 = $1210;
   } else {
    $1208 = (($0) + 8|0);
    $1209 = HEAP32[$1208>>2]|0;
    $1211 = $1209;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1211|0),0,(637528|0),32,1,0,0,(0|0));
   $1212 = __THREW__; __THREW__ = 0;
   $1213 = $1212&1;
   if (!($1213)) {
    $1214 = HEAP8[$0>>0]|0;
    $1215 = $1214 & 1;
    $1216 = ($1215<<24>>24)==(0);
    if ($1216) {
     break;
    }
    $1217 = (($0) + 8|0);
    $1218 = HEAP32[$1217>>2]|0;
    __ZdlPv($1218);
    break;
   }
   $1219 = ___cxa_find_matching_catch()|0;
   $1220 = tempRet0;
   $1221 = HEAP8[$0>>0]|0;
   $1222 = $1221 & 1;
   $1223 = ($1222<<24>>24)==(0);
   if ($1223) {
    ___resumeException($1219|0);
    // unreachable;
   }
   $1224 = (($0) + 8|0);
   $1225 = HEAP32[$1224>>2]|0;
   __ZdlPv($1225);
   ___resumeException($1219|0);
   // unreachable;
  }
 } while(0);
 $1226 = (($commonScriptingClasses) + 120|0);
 HEAP32[$1226>>2] = $1203;
 $1227 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636344)|0);
 $1228 = ($1227|0)==(0|0);
 do {
  if ($1228) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr241 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr241>>2] = 636272;
   $vararg_ptr242 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr242>>2] = 636344;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1229 = HEAP8[$0>>0]|0;
   $1230 = $1229 & 1;
   $1231 = ($1230<<24>>24)==(0);
   if ($1231) {
    $1234 = (($0) + 1|0);
    $1235 = $1234;
   } else {
    $1232 = (($0) + 8|0);
    $1233 = HEAP32[$1232>>2]|0;
    $1235 = $1233;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1235|0),0,(637528|0),32,1,0,0,(0|0));
   $1236 = __THREW__; __THREW__ = 0;
   $1237 = $1236&1;
   if (!($1237)) {
    $1238 = HEAP8[$0>>0]|0;
    $1239 = $1238 & 1;
    $1240 = ($1239<<24>>24)==(0);
    if ($1240) {
     break;
    }
    $1241 = (($0) + 8|0);
    $1242 = HEAP32[$1241>>2]|0;
    __ZdlPv($1242);
    break;
   }
   $1243 = ___cxa_find_matching_catch()|0;
   $1244 = tempRet0;
   $1245 = HEAP8[$0>>0]|0;
   $1246 = $1245 & 1;
   $1247 = ($1246<<24>>24)==(0);
   if ($1247) {
    ___resumeException($1243|0);
    // unreachable;
   }
   $1248 = (($0) + 8|0);
   $1249 = HEAP32[$1248>>2]|0;
   __ZdlPv($1249);
   ___resumeException($1243|0);
   // unreachable;
  }
 } while(0);
 $1250 = (($commonScriptingClasses) + 124|0);
 HEAP32[$1250>>2] = $1227;
 $1251 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636352)|0);
 $1252 = ($1251|0)==(0|0);
 do {
  if ($1252) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr246 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr246>>2] = 636272;
   $vararg_ptr247 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr247>>2] = 636352;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1253 = HEAP8[$0>>0]|0;
   $1254 = $1253 & 1;
   $1255 = ($1254<<24>>24)==(0);
   if ($1255) {
    $1258 = (($0) + 1|0);
    $1259 = $1258;
   } else {
    $1256 = (($0) + 8|0);
    $1257 = HEAP32[$1256>>2]|0;
    $1259 = $1257;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1259|0),0,(637528|0),32,1,0,0,(0|0));
   $1260 = __THREW__; __THREW__ = 0;
   $1261 = $1260&1;
   if (!($1261)) {
    $1262 = HEAP8[$0>>0]|0;
    $1263 = $1262 & 1;
    $1264 = ($1263<<24>>24)==(0);
    if ($1264) {
     break;
    }
    $1265 = (($0) + 8|0);
    $1266 = HEAP32[$1265>>2]|0;
    __ZdlPv($1266);
    break;
   }
   $1267 = ___cxa_find_matching_catch()|0;
   $1268 = tempRet0;
   $1269 = HEAP8[$0>>0]|0;
   $1270 = $1269 & 1;
   $1271 = ($1270<<24>>24)==(0);
   if ($1271) {
    ___resumeException($1267|0);
    // unreachable;
   }
   $1272 = (($0) + 8|0);
   $1273 = HEAP32[$1272>>2]|0;
   __ZdlPv($1273);
   ___resumeException($1267|0);
   // unreachable;
  }
 } while(0);
 $1274 = (($commonScriptingClasses) + 128|0);
 HEAP32[$1274>>2] = $1251;
 $1275 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636360)|0);
 $1276 = ($1275|0)==(0|0);
 do {
  if ($1276) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr251 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr251>>2] = 636272;
   $vararg_ptr252 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr252>>2] = 636360;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1277 = HEAP8[$0>>0]|0;
   $1278 = $1277 & 1;
   $1279 = ($1278<<24>>24)==(0);
   if ($1279) {
    $1282 = (($0) + 1|0);
    $1283 = $1282;
   } else {
    $1280 = (($0) + 8|0);
    $1281 = HEAP32[$1280>>2]|0;
    $1283 = $1281;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1283|0),0,(637528|0),32,1,0,0,(0|0));
   $1284 = __THREW__; __THREW__ = 0;
   $1285 = $1284&1;
   if (!($1285)) {
    $1286 = HEAP8[$0>>0]|0;
    $1287 = $1286 & 1;
    $1288 = ($1287<<24>>24)==(0);
    if ($1288) {
     break;
    }
    $1289 = (($0) + 8|0);
    $1290 = HEAP32[$1289>>2]|0;
    __ZdlPv($1290);
    break;
   }
   $1291 = ___cxa_find_matching_catch()|0;
   $1292 = tempRet0;
   $1293 = HEAP8[$0>>0]|0;
   $1294 = $1293 & 1;
   $1295 = ($1294<<24>>24)==(0);
   if ($1295) {
    ___resumeException($1291|0);
    // unreachable;
   }
   $1296 = (($0) + 8|0);
   $1297 = HEAP32[$1296>>2]|0;
   __ZdlPv($1297);
   ___resumeException($1291|0);
   // unreachable;
  }
 } while(0);
 $1298 = (($commonScriptingClasses) + 132|0);
 HEAP32[$1298>>2] = $1275;
 $1299 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636368)|0);
 $1300 = ($1299|0)==(0|0);
 do {
  if ($1300) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr256 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr256>>2] = 636272;
   $vararg_ptr257 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr257>>2] = 636368;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1301 = HEAP8[$0>>0]|0;
   $1302 = $1301 & 1;
   $1303 = ($1302<<24>>24)==(0);
   if ($1303) {
    $1306 = (($0) + 1|0);
    $1307 = $1306;
   } else {
    $1304 = (($0) + 8|0);
    $1305 = HEAP32[$1304>>2]|0;
    $1307 = $1305;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1307|0),0,(637528|0),32,1,0,0,(0|0));
   $1308 = __THREW__; __THREW__ = 0;
   $1309 = $1308&1;
   if (!($1309)) {
    $1310 = HEAP8[$0>>0]|0;
    $1311 = $1310 & 1;
    $1312 = ($1311<<24>>24)==(0);
    if ($1312) {
     break;
    }
    $1313 = (($0) + 8|0);
    $1314 = HEAP32[$1313>>2]|0;
    __ZdlPv($1314);
    break;
   }
   $1315 = ___cxa_find_matching_catch()|0;
   $1316 = tempRet0;
   $1317 = HEAP8[$0>>0]|0;
   $1318 = $1317 & 1;
   $1319 = ($1318<<24>>24)==(0);
   if ($1319) {
    ___resumeException($1315|0);
    // unreachable;
   }
   $1320 = (($0) + 8|0);
   $1321 = HEAP32[$1320>>2]|0;
   __ZdlPv($1321);
   ___resumeException($1315|0);
   // unreachable;
  }
 } while(0);
 $1322 = (($commonScriptingClasses) + 136|0);
 HEAP32[$1322>>2] = $1299;
 $1323 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636232,636392)|0);
 $1324 = ($1323|0)==(0|0);
 do {
  if ($1324) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr261 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr261>>2] = 636232;
   $vararg_ptr262 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr262>>2] = 636392;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1325 = HEAP8[$0>>0]|0;
   $1326 = $1325 & 1;
   $1327 = ($1326<<24>>24)==(0);
   if ($1327) {
    $1330 = (($0) + 1|0);
    $1331 = $1330;
   } else {
    $1328 = (($0) + 8|0);
    $1329 = HEAP32[$1328>>2]|0;
    $1331 = $1329;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1331|0),0,(637528|0),32,1,0,0,(0|0));
   $1332 = __THREW__; __THREW__ = 0;
   $1333 = $1332&1;
   if (!($1333)) {
    $1334 = HEAP8[$0>>0]|0;
    $1335 = $1334 & 1;
    $1336 = ($1335<<24>>24)==(0);
    if ($1336) {
     break;
    }
    $1337 = (($0) + 8|0);
    $1338 = HEAP32[$1337>>2]|0;
    __ZdlPv($1338);
    break;
   }
   $1339 = ___cxa_find_matching_catch()|0;
   $1340 = tempRet0;
   $1341 = HEAP8[$0>>0]|0;
   $1342 = $1341 & 1;
   $1343 = ($1342<<24>>24)==(0);
   if ($1343) {
    ___resumeException($1339|0);
    // unreachable;
   }
   $1344 = (($0) + 8|0);
   $1345 = HEAP32[$1344>>2]|0;
   __ZdlPv($1345);
   ___resumeException($1339|0);
   // unreachable;
  }
 } while(0);
 $1346 = (($commonScriptingClasses) + 140|0);
 HEAP32[$1346>>2] = $1323;
 $1347 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636232,636408)|0);
 $1348 = ($1347|0)==(0|0);
 do {
  if ($1348) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr266 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr266>>2] = 636232;
   $vararg_ptr267 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr267>>2] = 636408;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1349 = HEAP8[$0>>0]|0;
   $1350 = $1349 & 1;
   $1351 = ($1350<<24>>24)==(0);
   if ($1351) {
    $1354 = (($0) + 1|0);
    $1355 = $1354;
   } else {
    $1352 = (($0) + 8|0);
    $1353 = HEAP32[$1352>>2]|0;
    $1355 = $1353;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1355|0),0,(637528|0),32,1,0,0,(0|0));
   $1356 = __THREW__; __THREW__ = 0;
   $1357 = $1356&1;
   if (!($1357)) {
    $1358 = HEAP8[$0>>0]|0;
    $1359 = $1358 & 1;
    $1360 = ($1359<<24>>24)==(0);
    if ($1360) {
     break;
    }
    $1361 = (($0) + 8|0);
    $1362 = HEAP32[$1361>>2]|0;
    __ZdlPv($1362);
    break;
   }
   $1363 = ___cxa_find_matching_catch()|0;
   $1364 = tempRet0;
   $1365 = HEAP8[$0>>0]|0;
   $1366 = $1365 & 1;
   $1367 = ($1366<<24>>24)==(0);
   if ($1367) {
    ___resumeException($1363|0);
    // unreachable;
   }
   $1368 = (($0) + 8|0);
   $1369 = HEAP32[$1368>>2]|0;
   __ZdlPv($1369);
   ___resumeException($1363|0);
   // unreachable;
  }
 } while(0);
 $1370 = (($commonScriptingClasses) + 144|0);
 HEAP32[$1370>>2] = $1347;
 $1371 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636232,636424)|0);
 $1372 = ($1371|0)==(0|0);
 do {
  if ($1372) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr271 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr271>>2] = 636232;
   $vararg_ptr272 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr272>>2] = 636424;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1373 = HEAP8[$0>>0]|0;
   $1374 = $1373 & 1;
   $1375 = ($1374<<24>>24)==(0);
   if ($1375) {
    $1378 = (($0) + 1|0);
    $1379 = $1378;
   } else {
    $1376 = (($0) + 8|0);
    $1377 = HEAP32[$1376>>2]|0;
    $1379 = $1377;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1379|0),0,(637528|0),32,1,0,0,(0|0));
   $1380 = __THREW__; __THREW__ = 0;
   $1381 = $1380&1;
   if (!($1381)) {
    $1382 = HEAP8[$0>>0]|0;
    $1383 = $1382 & 1;
    $1384 = ($1383<<24>>24)==(0);
    if ($1384) {
     break;
    }
    $1385 = (($0) + 8|0);
    $1386 = HEAP32[$1385>>2]|0;
    __ZdlPv($1386);
    break;
   }
   $1387 = ___cxa_find_matching_catch()|0;
   $1388 = tempRet0;
   $1389 = HEAP8[$0>>0]|0;
   $1390 = $1389 & 1;
   $1391 = ($1390<<24>>24)==(0);
   if ($1391) {
    ___resumeException($1387|0);
    // unreachable;
   }
   $1392 = (($0) + 8|0);
   $1393 = HEAP32[$1392>>2]|0;
   __ZdlPv($1393);
   ___resumeException($1387|0);
   // unreachable;
  }
 } while(0);
 $1394 = (($commonScriptingClasses) + 156|0);
 HEAP32[$1394>>2] = $1371;
 $1395 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636232,636432)|0);
 $1396 = ($1395|0)==(0|0);
 do {
  if ($1396) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr276 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr276>>2] = 636232;
   $vararg_ptr277 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr277>>2] = 636432;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1397 = HEAP8[$0>>0]|0;
   $1398 = $1397 & 1;
   $1399 = ($1398<<24>>24)==(0);
   if ($1399) {
    $1402 = (($0) + 1|0);
    $1403 = $1402;
   } else {
    $1400 = (($0) + 8|0);
    $1401 = HEAP32[$1400>>2]|0;
    $1403 = $1401;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1403|0),0,(637528|0),32,1,0,0,(0|0));
   $1404 = __THREW__; __THREW__ = 0;
   $1405 = $1404&1;
   if (!($1405)) {
    $1406 = HEAP8[$0>>0]|0;
    $1407 = $1406 & 1;
    $1408 = ($1407<<24>>24)==(0);
    if ($1408) {
     break;
    }
    $1409 = (($0) + 8|0);
    $1410 = HEAP32[$1409>>2]|0;
    __ZdlPv($1410);
    break;
   }
   $1411 = ___cxa_find_matching_catch()|0;
   $1412 = tempRet0;
   $1413 = HEAP8[$0>>0]|0;
   $1414 = $1413 & 1;
   $1415 = ($1414<<24>>24)==(0);
   if ($1415) {
    ___resumeException($1411|0);
    // unreachable;
   }
   $1416 = (($0) + 8|0);
   $1417 = HEAP32[$1416>>2]|0;
   __ZdlPv($1417);
   ___resumeException($1411|0);
   // unreachable;
  }
 } while(0);
 $1418 = (($commonScriptingClasses) + 152|0);
 HEAP32[$1418>>2] = $1395;
 $1419 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,636448)|0);
 $1420 = ($1419|0)==(0|0);
 do {
  if ($1420) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr281 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr281>>2] = 636272;
   $vararg_ptr282 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr282>>2] = 636448;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1421 = HEAP8[$0>>0]|0;
   $1422 = $1421 & 1;
   $1423 = ($1422<<24>>24)==(0);
   if ($1423) {
    $1426 = (($0) + 1|0);
    $1427 = $1426;
   } else {
    $1424 = (($0) + 8|0);
    $1425 = HEAP32[$1424>>2]|0;
    $1427 = $1425;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1427|0),0,(637528|0),32,1,0,0,(0|0));
   $1428 = __THREW__; __THREW__ = 0;
   $1429 = $1428&1;
   if (!($1429)) {
    $1430 = HEAP8[$0>>0]|0;
    $1431 = $1430 & 1;
    $1432 = ($1431<<24>>24)==(0);
    if ($1432) {
     break;
    }
    $1433 = (($0) + 8|0);
    $1434 = HEAP32[$1433>>2]|0;
    __ZdlPv($1434);
    break;
   }
   $1435 = ___cxa_find_matching_catch()|0;
   $1436 = tempRet0;
   $1437 = HEAP8[$0>>0]|0;
   $1438 = $1437 & 1;
   $1439 = ($1438<<24>>24)==(0);
   if ($1439) {
    ___resumeException($1435|0);
    // unreachable;
   }
   $1440 = (($0) + 8|0);
   $1441 = HEAP32[$1440>>2]|0;
   __ZdlPv($1441);
   ___resumeException($1435|0);
   // unreachable;
  }
 } while(0);
 $1442 = (($commonScriptingClasses) + 148|0);
 HEAP32[$1442>>2] = $1419;
 $1443 = (($commonScriptingClasses) + 372|0);
 __ZL13RequireMethodPKcS0_S0_S0_($4,637592,637608,636464,636488);
 ;HEAP32[$1443+0>>2]=HEAP32[$4+0>>2]|0;HEAP8[$1443+4>>0]=HEAP8[$4+4>>0]|0;
 $1444 = (($commonScriptingClasses) + 380|0);
 __ZL13RequireMethodPKcS0_S0_S0_($5,637592,637608,636464,636512);
 ;HEAP32[$1444+0>>2]=HEAP32[$5+0>>2]|0;HEAP8[$1444+4>>0]=HEAP8[$5+4>>0]|0;
 $1445 = (($commonScriptingClasses) + 292|0);
 __ZL13RequireMethodPKcS0_S0_S0_($6,637592,637608,636560,636576);
 ;HEAP32[$1445+0>>2]=HEAP32[$6+0>>2]|0;HEAP8[$1445+4>>0]=HEAP8[$6+4>>0]|0;
 $1446 = (($commonScriptingClasses) + 300|0);
 __ZL13RequireMethodPKcS0_S0_S0_($7,637592,637608,636560,636592);
 ;HEAP32[$1446+0>>2]=HEAP32[$7+0>>2]|0;HEAP8[$1446+4>>0]=HEAP8[$7+4>>0]|0;
 $1447 = (($commonScriptingClasses) + 308|0);
 __ZL13RequireMethodPKcS0_S0_S0_($8,637592,637608,636464,636608);
 ;HEAP32[$1447+0>>2]=HEAP32[$8+0>>2]|0;HEAP8[$1447+4>>0]=HEAP8[$8+4>>0]|0;
 $1448 = (($commonScriptingClasses) + 316|0);
 __ZL13RequireMethodPKcS0_S0_S0_($9,637592,637608,636632,636656);
 ;HEAP32[$1448+0>>2]=HEAP32[$9+0>>2]|0;HEAP8[$1448+4>>0]=HEAP8[$9+4>>0]|0;
 $1449 = (($commonScriptingClasses) + 324|0);
 __ZL13RequireMethodPKcS0_S0_S0_($10,637592,637608,636632,636680);
 ;HEAP32[$1449+0>>2]=HEAP32[$10+0>>2]|0;HEAP8[$1449+4>>0]=HEAP8[$10+4>>0]|0;
 $1450 = (($commonScriptingClasses) + 332|0);
 __ZL13RequireMethodPKcS0_S0_S0_($11,637592,637608,636632,636720);
 ;HEAP32[$1450+0>>2]=HEAP32[$11+0>>2]|0;HEAP8[$1450+4>>0]=HEAP8[$11+4>>0]|0;
 $1451 = (($commonScriptingClasses) + 340|0);
 __ZL13RequireMethodPKcS0_S0_S0_($12,637576,636232,636256,636744);
 ;HEAP32[$1451+0>>2]=HEAP32[$12+0>>2]|0;HEAP8[$1451+4>>0]=HEAP8[$12+4>>0]|0;
 $1452 = (($commonScriptingClasses) + 348|0);
 __ZL13RequireMethodPKcS0_S0_S0_($13,637592,637608,636760,636776);
 ;HEAP32[$1452+0>>2]=HEAP32[$13+0>>2]|0;HEAP8[$1452+4>>0]=HEAP8[$13+4>>0]|0;
 $1453 = (($commonScriptingClasses) + 356|0);
 __ZL13RequireMethodPKcS0_S0_S0_($14,637576,636232,636256,636792);
 ;HEAP32[$1453+0>>2]=HEAP32[$14+0>>2]|0;HEAP8[$1453+4>>0]=HEAP8[$14+4>>0]|0;
 $1454 = (($commonScriptingClasses) + 364|0);
 __ZL13RequireMethodPKcS0_S0_S0_($15,637576,636272,636808,636824);
 ;HEAP32[$1454+0>>2]=HEAP32[$15+0>>2]|0;HEAP8[$1454+4>>0]=HEAP8[$15+4>>0]|0;
 $1455 = (($commonScriptingClasses) + 388|0);
 __ZL13RequireMethodPKcS0_S0_S0_($16,637592,637608,636832,636848);
 ;HEAP32[$1455+0>>2]=HEAP32[$16+0>>2]|0;HEAP8[$1455+4>>0]=HEAP8[$16+4>>0]|0;
 $1456 = (($commonScriptingClasses) + 396|0);
 __ZL13RequireMethodPKcS0_S0_S0_($17,637592,637608,636832,636864);
 ;HEAP32[$1456+0>>2]=HEAP32[$17+0>>2]|0;HEAP8[$1456+4>>0]=HEAP8[$17+4>>0]|0;
 $1457 = (($commonScriptingClasses) + 404|0);
 __ZL13RequireMethodPKcS0_S0_S0_($18,637592,637608,636872,636880);
 ;HEAP32[$1457+0>>2]=HEAP32[$18+0>>2]|0;HEAP8[$1457+4>>0]=HEAP8[$18+4>>0]|0;
 $1458 = (($commonScriptingClasses) + 468|0);
 __ZL13RequireMethodPKcS0_S0_S0_($19,637592,637608,635728,636904);
 ;HEAP32[$1458+0>>2]=HEAP32[$19+0>>2]|0;HEAP8[$1458+4>>0]=HEAP8[$19+4>>0]|0;
 $1459 = (($commonScriptingClasses) + 476|0);
 __ZL13RequireMethodPKcS0_S0_S0_($20,637592,637608,636936,636952);
 ;HEAP32[$1459+0>>2]=HEAP32[$20+0>>2]|0;HEAP8[$1459+4>>0]=HEAP8[$20+4>>0]|0;
 $1460 = (($commonScriptingClasses) + 484|0);
 __ZL13RequireMethodPKcS0_S0_S0_($21,637592,637608,636632,636976);
 ;HEAP32[$1460+0>>2]=HEAP32[$21+0>>2]|0;HEAP8[$1460+4>>0]=HEAP8[$21+4>>0]|0;
 $1461 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637576,636272,637000)|0);
 $1462 = ($1461|0)==(0|0);
 do {
  if ($1462) {
   HEAP32[$vararg_buffer368>>2] = 637576;
   $vararg_ptr286 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr286>>2] = 636272;
   $vararg_ptr287 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr287>>2] = 637000;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1463 = HEAP8[$0>>0]|0;
   $1464 = $1463 & 1;
   $1465 = ($1464<<24>>24)==(0);
   if ($1465) {
    $1468 = (($0) + 1|0);
    $1469 = $1468;
   } else {
    $1466 = (($0) + 8|0);
    $1467 = HEAP32[$1466>>2]|0;
    $1469 = $1467;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1469|0),0,(637528|0),32,1,0,0,(0|0));
   $1470 = __THREW__; __THREW__ = 0;
   $1471 = $1470&1;
   if (!($1471)) {
    $1472 = HEAP8[$0>>0]|0;
    $1473 = $1472 & 1;
    $1474 = ($1473<<24>>24)==(0);
    if ($1474) {
     break;
    }
    $1475 = (($0) + 8|0);
    $1476 = HEAP32[$1475>>2]|0;
    __ZdlPv($1476);
    break;
   }
   $1477 = ___cxa_find_matching_catch()|0;
   $1478 = tempRet0;
   $1479 = HEAP8[$0>>0]|0;
   $1480 = $1479 & 1;
   $1481 = ($1480<<24>>24)==(0);
   if ($1481) {
    ___resumeException($1477|0);
    // unreachable;
   }
   $1482 = (($0) + 8|0);
   $1483 = HEAP32[$1482>>2]|0;
   __ZdlPv($1483);
   ___resumeException($1477|0);
   // unreachable;
  }
 } while(0);
 $1484 = (($commonScriptingClasses) + 100|0);
 HEAP32[$1484>>2] = $1461;
 $1485 = HEAP32[$1106>>2]|0;
 $1486 = (__Z25scripting_array_class_getP14ScriptingClassj($1485,1)|0);
 $1487 = (($commonScriptingClasses) + 532|0);
 HEAP32[$1487>>2] = $1486;
 $1488 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637008)|0);
 $1489 = ($1488|0)==(0|0);
 do {
  if ($1489) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr291 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr291>>2] = 637608;
   $vararg_ptr292 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr292>>2] = 637008;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1490 = HEAP8[$0>>0]|0;
   $1491 = $1490 & 1;
   $1492 = ($1491<<24>>24)==(0);
   if ($1492) {
    $1495 = (($0) + 1|0);
    $1496 = $1495;
   } else {
    $1493 = (($0) + 8|0);
    $1494 = HEAP32[$1493>>2]|0;
    $1496 = $1494;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1496|0),0,(637528|0),32,1,0,0,(0|0));
   $1497 = __THREW__; __THREW__ = 0;
   $1498 = $1497&1;
   if (!($1498)) {
    $1499 = HEAP8[$0>>0]|0;
    $1500 = $1499 & 1;
    $1501 = ($1500<<24>>24)==(0);
    if ($1501) {
     break;
    }
    $1502 = (($0) + 8|0);
    $1503 = HEAP32[$1502>>2]|0;
    __ZdlPv($1503);
    break;
   }
   $1504 = ___cxa_find_matching_catch()|0;
   $1505 = tempRet0;
   $1506 = HEAP8[$0>>0]|0;
   $1507 = $1506 & 1;
   $1508 = ($1507<<24>>24)==(0);
   if ($1508) {
    ___resumeException($1504|0);
    // unreachable;
   }
   $1509 = (($0) + 8|0);
   $1510 = HEAP32[$1509>>2]|0;
   __ZdlPv($1510);
   ___resumeException($1504|0);
   // unreachable;
  }
 } while(0);
 $1511 = (($commonScriptingClasses) + 500|0);
 HEAP32[$1511>>2] = $1488;
 $1512 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637040)|0);
 $1513 = ($1512|0)==(0|0);
 do {
  if ($1513) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr296 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr296>>2] = 637608;
   $vararg_ptr297 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr297>>2] = 637040;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1514 = HEAP8[$0>>0]|0;
   $1515 = $1514 & 1;
   $1516 = ($1515<<24>>24)==(0);
   if ($1516) {
    $1519 = (($0) + 1|0);
    $1520 = $1519;
   } else {
    $1517 = (($0) + 8|0);
    $1518 = HEAP32[$1517>>2]|0;
    $1520 = $1518;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1520|0),0,(637528|0),32,1,0,0,(0|0));
   $1521 = __THREW__; __THREW__ = 0;
   $1522 = $1521&1;
   if (!($1522)) {
    $1523 = HEAP8[$0>>0]|0;
    $1524 = $1523 & 1;
    $1525 = ($1524<<24>>24)==(0);
    if ($1525) {
     break;
    }
    $1526 = (($0) + 8|0);
    $1527 = HEAP32[$1526>>2]|0;
    __ZdlPv($1527);
    break;
   }
   $1528 = ___cxa_find_matching_catch()|0;
   $1529 = tempRet0;
   $1530 = HEAP8[$0>>0]|0;
   $1531 = $1530 & 1;
   $1532 = ($1531<<24>>24)==(0);
   if ($1532) {
    ___resumeException($1528|0);
    // unreachable;
   }
   $1533 = (($0) + 8|0);
   $1534 = HEAP32[$1533>>2]|0;
   __ZdlPv($1534);
   ___resumeException($1528|0);
   // unreachable;
  }
 } while(0);
 $1535 = (($commonScriptingClasses) + 504|0);
 HEAP32[$1535>>2] = $1512;
 $1536 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637056)|0);
 $1537 = ($1536|0)==(0|0);
 do {
  if ($1537) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr301 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr301>>2] = 637608;
   $vararg_ptr302 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr302>>2] = 637056;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1538 = HEAP8[$0>>0]|0;
   $1539 = $1538 & 1;
   $1540 = ($1539<<24>>24)==(0);
   if ($1540) {
    $1543 = (($0) + 1|0);
    $1544 = $1543;
   } else {
    $1541 = (($0) + 8|0);
    $1542 = HEAP32[$1541>>2]|0;
    $1544 = $1542;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1544|0),0,(637528|0),32,1,0,0,(0|0));
   $1545 = __THREW__; __THREW__ = 0;
   $1546 = $1545&1;
   if (!($1546)) {
    $1547 = HEAP8[$0>>0]|0;
    $1548 = $1547 & 1;
    $1549 = ($1548<<24>>24)==(0);
    if ($1549) {
     break;
    }
    $1550 = (($0) + 8|0);
    $1551 = HEAP32[$1550>>2]|0;
    __ZdlPv($1551);
    break;
   }
   $1552 = ___cxa_find_matching_catch()|0;
   $1553 = tempRet0;
   $1554 = HEAP8[$0>>0]|0;
   $1555 = $1554 & 1;
   $1556 = ($1555<<24>>24)==(0);
   if ($1556) {
    ___resumeException($1552|0);
    // unreachable;
   }
   $1557 = (($0) + 8|0);
   $1558 = HEAP32[$1557>>2]|0;
   __ZdlPv($1558);
   ___resumeException($1552|0);
   // unreachable;
  }
 } while(0);
 $1559 = (($commonScriptingClasses) + 508|0);
 HEAP32[$1559>>2] = $1536;
 $1560 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637080)|0);
 $1561 = ($1560|0)==(0|0);
 do {
  if ($1561) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr306 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr306>>2] = 637608;
   $vararg_ptr307 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr307>>2] = 637080;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1562 = HEAP8[$0>>0]|0;
   $1563 = $1562 & 1;
   $1564 = ($1563<<24>>24)==(0);
   if ($1564) {
    $1567 = (($0) + 1|0);
    $1568 = $1567;
   } else {
    $1565 = (($0) + 8|0);
    $1566 = HEAP32[$1565>>2]|0;
    $1568 = $1566;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1568|0),0,(637528|0),32,1,0,0,(0|0));
   $1569 = __THREW__; __THREW__ = 0;
   $1570 = $1569&1;
   if (!($1570)) {
    $1571 = HEAP8[$0>>0]|0;
    $1572 = $1571 & 1;
    $1573 = ($1572<<24>>24)==(0);
    if ($1573) {
     break;
    }
    $1574 = (($0) + 8|0);
    $1575 = HEAP32[$1574>>2]|0;
    __ZdlPv($1575);
    break;
   }
   $1576 = ___cxa_find_matching_catch()|0;
   $1577 = tempRet0;
   $1578 = HEAP8[$0>>0]|0;
   $1579 = $1578 & 1;
   $1580 = ($1579<<24>>24)==(0);
   if ($1580) {
    ___resumeException($1576|0);
    // unreachable;
   }
   $1581 = (($0) + 8|0);
   $1582 = HEAP32[$1581>>2]|0;
   __ZdlPv($1582);
   ___resumeException($1576|0);
   // unreachable;
  }
 } while(0);
 $1583 = (($commonScriptingClasses) + 512|0);
 HEAP32[$1583>>2] = $1560;
 $1584 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637104)|0);
 $1585 = ($1584|0)==(0|0);
 do {
  if ($1585) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr311 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr311>>2] = 637608;
   $vararg_ptr312 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr312>>2] = 637104;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1586 = HEAP8[$0>>0]|0;
   $1587 = $1586 & 1;
   $1588 = ($1587<<24>>24)==(0);
   if ($1588) {
    $1591 = (($0) + 1|0);
    $1592 = $1591;
   } else {
    $1589 = (($0) + 8|0);
    $1590 = HEAP32[$1589>>2]|0;
    $1592 = $1590;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1592|0),0,(637528|0),32,1,0,0,(0|0));
   $1593 = __THREW__; __THREW__ = 0;
   $1594 = $1593&1;
   if (!($1594)) {
    $1595 = HEAP8[$0>>0]|0;
    $1596 = $1595 & 1;
    $1597 = ($1596<<24>>24)==(0);
    if ($1597) {
     break;
    }
    $1598 = (($0) + 8|0);
    $1599 = HEAP32[$1598>>2]|0;
    __ZdlPv($1599);
    break;
   }
   $1600 = ___cxa_find_matching_catch()|0;
   $1601 = tempRet0;
   $1602 = HEAP8[$0>>0]|0;
   $1603 = $1602 & 1;
   $1604 = ($1603<<24>>24)==(0);
   if ($1604) {
    ___resumeException($1600|0);
    // unreachable;
   }
   $1605 = (($0) + 8|0);
   $1606 = HEAP32[$1605>>2]|0;
   __ZdlPv($1606);
   ___resumeException($1600|0);
   // unreachable;
  }
 } while(0);
 $1607 = (($commonScriptingClasses) + 516|0);
 HEAP32[$1607>>2] = $1584;
 $1608 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637120)|0);
 $1609 = ($1608|0)==(0|0);
 do {
  if ($1609) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr316 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr316>>2] = 637608;
   $vararg_ptr317 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr317>>2] = 637120;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1610 = HEAP8[$0>>0]|0;
   $1611 = $1610 & 1;
   $1612 = ($1611<<24>>24)==(0);
   if ($1612) {
    $1615 = (($0) + 1|0);
    $1616 = $1615;
   } else {
    $1613 = (($0) + 8|0);
    $1614 = HEAP32[$1613>>2]|0;
    $1616 = $1614;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1616|0),0,(637528|0),32,1,0,0,(0|0));
   $1617 = __THREW__; __THREW__ = 0;
   $1618 = $1617&1;
   if (!($1618)) {
    $1619 = HEAP8[$0>>0]|0;
    $1620 = $1619 & 1;
    $1621 = ($1620<<24>>24)==(0);
    if ($1621) {
     break;
    }
    $1622 = (($0) + 8|0);
    $1623 = HEAP32[$1622>>2]|0;
    __ZdlPv($1623);
    break;
   }
   $1624 = ___cxa_find_matching_catch()|0;
   $1625 = tempRet0;
   $1626 = HEAP8[$0>>0]|0;
   $1627 = $1626 & 1;
   $1628 = ($1627<<24>>24)==(0);
   if ($1628) {
    ___resumeException($1624|0);
    // unreachable;
   }
   $1629 = (($0) + 8|0);
   $1630 = HEAP32[$1629>>2]|0;
   __ZdlPv($1630);
   ___resumeException($1624|0);
   // unreachable;
  }
 } while(0);
 $1631 = (($commonScriptingClasses) + 520|0);
 HEAP32[$1631>>2] = $1608;
 $1632 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637144)|0);
 $1633 = ($1632|0)==(0|0);
 do {
  if ($1633) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr321 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr321>>2] = 637608;
   $vararg_ptr322 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr322>>2] = 637144;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1634 = HEAP8[$0>>0]|0;
   $1635 = $1634 & 1;
   $1636 = ($1635<<24>>24)==(0);
   if ($1636) {
    $1639 = (($0) + 1|0);
    $1640 = $1639;
   } else {
    $1637 = (($0) + 8|0);
    $1638 = HEAP32[$1637>>2]|0;
    $1640 = $1638;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1640|0),0,(637528|0),32,1,0,0,(0|0));
   $1641 = __THREW__; __THREW__ = 0;
   $1642 = $1641&1;
   if (!($1642)) {
    $1643 = HEAP8[$0>>0]|0;
    $1644 = $1643 & 1;
    $1645 = ($1644<<24>>24)==(0);
    if ($1645) {
     break;
    }
    $1646 = (($0) + 8|0);
    $1647 = HEAP32[$1646>>2]|0;
    __ZdlPv($1647);
    break;
   }
   $1648 = ___cxa_find_matching_catch()|0;
   $1649 = tempRet0;
   $1650 = HEAP8[$0>>0]|0;
   $1651 = $1650 & 1;
   $1652 = ($1651<<24>>24)==(0);
   if ($1652) {
    ___resumeException($1648|0);
    // unreachable;
   }
   $1653 = (($0) + 8|0);
   $1654 = HEAP32[$1653>>2]|0;
   __ZdlPv($1654);
   ___resumeException($1648|0);
   // unreachable;
  }
 } while(0);
 $1655 = (($commonScriptingClasses) + 524|0);
 HEAP32[$1655>>2] = $1632;
 $1656 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637168)|0);
 $1657 = ($1656|0)==(0|0);
 do {
  if ($1657) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr326 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr326>>2] = 637608;
   $vararg_ptr327 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr327>>2] = 637168;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1658 = HEAP8[$0>>0]|0;
   $1659 = $1658 & 1;
   $1660 = ($1659<<24>>24)==(0);
   if ($1660) {
    $1663 = (($0) + 1|0);
    $1664 = $1663;
   } else {
    $1661 = (($0) + 8|0);
    $1662 = HEAP32[$1661>>2]|0;
    $1664 = $1662;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1664|0),0,(637528|0),32,1,0,0,(0|0));
   $1665 = __THREW__; __THREW__ = 0;
   $1666 = $1665&1;
   if (!($1666)) {
    $1667 = HEAP8[$0>>0]|0;
    $1668 = $1667 & 1;
    $1669 = ($1668<<24>>24)==(0);
    if ($1669) {
     break;
    }
    $1670 = (($0) + 8|0);
    $1671 = HEAP32[$1670>>2]|0;
    __ZdlPv($1671);
    break;
   }
   $1672 = ___cxa_find_matching_catch()|0;
   $1673 = tempRet0;
   $1674 = HEAP8[$0>>0]|0;
   $1675 = $1674 & 1;
   $1676 = ($1675<<24>>24)==(0);
   if ($1676) {
    ___resumeException($1672|0);
    // unreachable;
   }
   $1677 = (($0) + 8|0);
   $1678 = HEAP32[$1677>>2]|0;
   __ZdlPv($1678);
   ___resumeException($1672|0);
   // unreachable;
  }
 } while(0);
 $1679 = (($commonScriptingClasses) + 528|0);
 HEAP32[$1679>>2] = $1656;
 $1680 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637192)|0);
 $1681 = ($1680|0)==(0|0);
 do {
  if ($1681) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr331 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr331>>2] = 637608;
   $vararg_ptr332 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr332>>2] = 637192;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1682 = HEAP8[$0>>0]|0;
   $1683 = $1682 & 1;
   $1684 = ($1683<<24>>24)==(0);
   if ($1684) {
    $1687 = (($0) + 1|0);
    $1688 = $1687;
   } else {
    $1685 = (($0) + 8|0);
    $1686 = HEAP32[$1685>>2]|0;
    $1688 = $1686;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1688|0),0,(637528|0),32,1,0,0,(0|0));
   $1689 = __THREW__; __THREW__ = 0;
   $1690 = $1689&1;
   if (!($1690)) {
    $1691 = HEAP8[$0>>0]|0;
    $1692 = $1691 & 1;
    $1693 = ($1692<<24>>24)==(0);
    if ($1693) {
     break;
    }
    $1694 = (($0) + 8|0);
    $1695 = HEAP32[$1694>>2]|0;
    __ZdlPv($1695);
    break;
   }
   $1696 = ___cxa_find_matching_catch()|0;
   $1697 = tempRet0;
   $1698 = HEAP8[$0>>0]|0;
   $1699 = $1698 & 1;
   $1700 = ($1699<<24>>24)==(0);
   if ($1700) {
    ___resumeException($1696|0);
    // unreachable;
   }
   $1701 = (($0) + 8|0);
   $1702 = HEAP32[$1701>>2]|0;
   __ZdlPv($1702);
   ___resumeException($1696|0);
   // unreachable;
  }
 } while(0);
 $1703 = (($commonScriptingClasses) + 536|0);
 HEAP32[$1703>>2] = $1680;
 $1704 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637208)|0);
 $1705 = ($1704|0)==(0|0);
 do {
  if ($1705) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr336 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr336>>2] = 637608;
   $vararg_ptr337 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr337>>2] = 637208;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1706 = HEAP8[$0>>0]|0;
   $1707 = $1706 & 1;
   $1708 = ($1707<<24>>24)==(0);
   if ($1708) {
    $1711 = (($0) + 1|0);
    $1712 = $1711;
   } else {
    $1709 = (($0) + 8|0);
    $1710 = HEAP32[$1709>>2]|0;
    $1712 = $1710;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1712|0),0,(637528|0),32,1,0,0,(0|0));
   $1713 = __THREW__; __THREW__ = 0;
   $1714 = $1713&1;
   if (!($1714)) {
    $1715 = HEAP8[$0>>0]|0;
    $1716 = $1715 & 1;
    $1717 = ($1716<<24>>24)==(0);
    if ($1717) {
     break;
    }
    $1718 = (($0) + 8|0);
    $1719 = HEAP32[$1718>>2]|0;
    __ZdlPv($1719);
    break;
   }
   $1720 = ___cxa_find_matching_catch()|0;
   $1721 = tempRet0;
   $1722 = HEAP8[$0>>0]|0;
   $1723 = $1722 & 1;
   $1724 = ($1723<<24>>24)==(0);
   if ($1724) {
    ___resumeException($1720|0);
    // unreachable;
   }
   $1725 = (($0) + 8|0);
   $1726 = HEAP32[$1725>>2]|0;
   __ZdlPv($1726);
   ___resumeException($1720|0);
   // unreachable;
  }
 } while(0);
 $1727 = (($commonScriptingClasses) + 540|0);
 HEAP32[$1727>>2] = $1704;
 $1728 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637224)|0);
 $1729 = ($1728|0)==(0|0);
 do {
  if ($1729) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr341 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr341>>2] = 637608;
   $vararg_ptr342 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr342>>2] = 637224;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1730 = HEAP8[$0>>0]|0;
   $1731 = $1730 & 1;
   $1732 = ($1731<<24>>24)==(0);
   if ($1732) {
    $1735 = (($0) + 1|0);
    $1736 = $1735;
   } else {
    $1733 = (($0) + 8|0);
    $1734 = HEAP32[$1733>>2]|0;
    $1736 = $1734;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1736|0),0,(637528|0),32,1,0,0,(0|0));
   $1737 = __THREW__; __THREW__ = 0;
   $1738 = $1737&1;
   if (!($1738)) {
    $1739 = HEAP8[$0>>0]|0;
    $1740 = $1739 & 1;
    $1741 = ($1740<<24>>24)==(0);
    if ($1741) {
     break;
    }
    $1742 = (($0) + 8|0);
    $1743 = HEAP32[$1742>>2]|0;
    __ZdlPv($1743);
    break;
   }
   $1744 = ___cxa_find_matching_catch()|0;
   $1745 = tempRet0;
   $1746 = HEAP8[$0>>0]|0;
   $1747 = $1746 & 1;
   $1748 = ($1747<<24>>24)==(0);
   if ($1748) {
    ___resumeException($1744|0);
    // unreachable;
   }
   $1749 = (($0) + 8|0);
   $1750 = HEAP32[$1749>>2]|0;
   __ZdlPv($1750);
   ___resumeException($1744|0);
   // unreachable;
  }
 } while(0);
 $1751 = (($commonScriptingClasses) + 544|0);
 HEAP32[$1751>>2] = $1728;
 $1752 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637256)|0);
 $1753 = ($1752|0)==(0|0);
 do {
  if ($1753) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr346 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr346>>2] = 637608;
   $vararg_ptr347 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr347>>2] = 637256;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1754 = HEAP8[$0>>0]|0;
   $1755 = $1754 & 1;
   $1756 = ($1755<<24>>24)==(0);
   if ($1756) {
    $1759 = (($0) + 1|0);
    $1760 = $1759;
   } else {
    $1757 = (($0) + 8|0);
    $1758 = HEAP32[$1757>>2]|0;
    $1760 = $1758;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1760|0),0,(637528|0),32,1,0,0,(0|0));
   $1761 = __THREW__; __THREW__ = 0;
   $1762 = $1761&1;
   if (!($1762)) {
    $1763 = HEAP8[$0>>0]|0;
    $1764 = $1763 & 1;
    $1765 = ($1764<<24>>24)==(0);
    if ($1765) {
     break;
    }
    $1766 = (($0) + 8|0);
    $1767 = HEAP32[$1766>>2]|0;
    __ZdlPv($1767);
    break;
   }
   $1768 = ___cxa_find_matching_catch()|0;
   $1769 = tempRet0;
   $1770 = HEAP8[$0>>0]|0;
   $1771 = $1770 & 1;
   $1772 = ($1771<<24>>24)==(0);
   if ($1772) {
    ___resumeException($1768|0);
    // unreachable;
   }
   $1773 = (($0) + 8|0);
   $1774 = HEAP32[$1773>>2]|0;
   __ZdlPv($1774);
   ___resumeException($1768|0);
   // unreachable;
  }
 } while(0);
 $1775 = (($commonScriptingClasses) + 548|0);
 HEAP32[$1775>>2] = $1752;
 $1776 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637280)|0);
 $1777 = ($1776|0)==(0|0);
 do {
  if ($1777) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr351 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr351>>2] = 637608;
   $vararg_ptr352 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr352>>2] = 637280;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1778 = HEAP8[$0>>0]|0;
   $1779 = $1778 & 1;
   $1780 = ($1779<<24>>24)==(0);
   if ($1780) {
    $1783 = (($0) + 1|0);
    $1784 = $1783;
   } else {
    $1781 = (($0) + 8|0);
    $1782 = HEAP32[$1781>>2]|0;
    $1784 = $1782;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1784|0),0,(637528|0),32,1,0,0,(0|0));
   $1785 = __THREW__; __THREW__ = 0;
   $1786 = $1785&1;
   if (!($1786)) {
    $1787 = HEAP8[$0>>0]|0;
    $1788 = $1787 & 1;
    $1789 = ($1788<<24>>24)==(0);
    if ($1789) {
     break;
    }
    $1790 = (($0) + 8|0);
    $1791 = HEAP32[$1790>>2]|0;
    __ZdlPv($1791);
    break;
   }
   $1792 = ___cxa_find_matching_catch()|0;
   $1793 = tempRet0;
   $1794 = HEAP8[$0>>0]|0;
   $1795 = $1794 & 1;
   $1796 = ($1795<<24>>24)==(0);
   if ($1796) {
    ___resumeException($1792|0);
    // unreachable;
   }
   $1797 = (($0) + 8|0);
   $1798 = HEAP32[$1797>>2]|0;
   __ZdlPv($1798);
   ___resumeException($1792|0);
   // unreachable;
  }
 } while(0);
 $1799 = (($commonScriptingClasses) + 552|0);
 HEAP32[$1799>>2] = $1776;
 $1800 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637296)|0);
 $1801 = ($1800|0)==(0|0);
 do {
  if ($1801) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr356 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr356>>2] = 637608;
   $vararg_ptr357 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr357>>2] = 637296;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1802 = HEAP8[$0>>0]|0;
   $1803 = $1802 & 1;
   $1804 = ($1803<<24>>24)==(0);
   if ($1804) {
    $1807 = (($0) + 1|0);
    $1808 = $1807;
   } else {
    $1805 = (($0) + 8|0);
    $1806 = HEAP32[$1805>>2]|0;
    $1808 = $1806;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1808|0),0,(637528|0),32,1,0,0,(0|0));
   $1809 = __THREW__; __THREW__ = 0;
   $1810 = $1809&1;
   if (!($1810)) {
    $1811 = HEAP8[$0>>0]|0;
    $1812 = $1811 & 1;
    $1813 = ($1812<<24>>24)==(0);
    if ($1813) {
     break;
    }
    $1814 = (($0) + 8|0);
    $1815 = HEAP32[$1814>>2]|0;
    __ZdlPv($1815);
    break;
   }
   $1816 = ___cxa_find_matching_catch()|0;
   $1817 = tempRet0;
   $1818 = HEAP8[$0>>0]|0;
   $1819 = $1818 & 1;
   $1820 = ($1819<<24>>24)==(0);
   if ($1820) {
    ___resumeException($1816|0);
    // unreachable;
   }
   $1821 = (($0) + 8|0);
   $1822 = HEAP32[$1821>>2]|0;
   __ZdlPv($1822);
   ___resumeException($1816|0);
   // unreachable;
  }
 } while(0);
 $1823 = (($commonScriptingClasses) + 556|0);
 HEAP32[$1823>>2] = $1800;
 $1824 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637312)|0);
 $1825 = ($1824|0)==(0|0);
 do {
  if ($1825) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr361 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr361>>2] = 637608;
   $vararg_ptr362 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr362>>2] = 637312;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1826 = HEAP8[$0>>0]|0;
   $1827 = $1826 & 1;
   $1828 = ($1827<<24>>24)==(0);
   if ($1828) {
    $1831 = (($0) + 1|0);
    $1832 = $1831;
   } else {
    $1829 = (($0) + 8|0);
    $1830 = HEAP32[$1829>>2]|0;
    $1832 = $1830;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1832|0),0,(637528|0),32,1,0,0,(0|0));
   $1833 = __THREW__; __THREW__ = 0;
   $1834 = $1833&1;
   if (!($1834)) {
    $1835 = HEAP8[$0>>0]|0;
    $1836 = $1835 & 1;
    $1837 = ($1836<<24>>24)==(0);
    if ($1837) {
     break;
    }
    $1838 = (($0) + 8|0);
    $1839 = HEAP32[$1838>>2]|0;
    __ZdlPv($1839);
    break;
   }
   $1840 = ___cxa_find_matching_catch()|0;
   $1841 = tempRet0;
   $1842 = HEAP8[$0>>0]|0;
   $1843 = $1842 & 1;
   $1844 = ($1843<<24>>24)==(0);
   if ($1844) {
    ___resumeException($1840|0);
    // unreachable;
   }
   $1845 = (($0) + 8|0);
   $1846 = HEAP32[$1845>>2]|0;
   __ZdlPv($1846);
   ___resumeException($1840|0);
   // unreachable;
  }
 } while(0);
 $1847 = (($commonScriptingClasses) + 560|0);
 HEAP32[$1847>>2] = $1824;
 $1848 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637328)|0);
 $1849 = ($1848|0)==(0|0);
 do {
  if ($1849) {
   HEAP32[$vararg_buffer368>>2] = 637592;
   $vararg_ptr366 = (($vararg_buffer368) + 4|0);
   HEAP32[$vararg_ptr366>>2] = 637608;
   $vararg_ptr367 = (($vararg_buffer368) + 8|0);
   HEAP32[$vararg_ptr367>>2] = 637328;
   __Z6FormatPKcz($0,637496,$vararg_buffer368);
   $1850 = HEAP8[$0>>0]|0;
   $1851 = $1850 & 1;
   $1852 = ($1851<<24>>24)==(0);
   if ($1852) {
    $1855 = (($0) + 1|0);
    $1856 = $1855;
   } else {
    $1853 = (($0) + 8|0);
    $1854 = HEAP32[$1853>>2]|0;
    $1856 = $1854;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($1856|0),0,(637528|0),32,1,0,0,(0|0));
   $1857 = __THREW__; __THREW__ = 0;
   $1858 = $1857&1;
   if (!($1858)) {
    $1859 = HEAP8[$0>>0]|0;
    $1860 = $1859 & 1;
    $1861 = ($1860<<24>>24)==(0);
    if ($1861) {
     break;
    }
    $1862 = (($0) + 8|0);
    $1863 = HEAP32[$1862>>2]|0;
    __ZdlPv($1863);
    break;
   }
   $1864 = ___cxa_find_matching_catch()|0;
   $1865 = tempRet0;
   $1866 = HEAP8[$0>>0]|0;
   $1867 = $1866 & 1;
   $1868 = ($1867<<24>>24)==(0);
   if ($1868) {
    ___resumeException($1864|0);
    // unreachable;
   }
   $1869 = (($0) + 8|0);
   $1870 = HEAP32[$1869>>2]|0;
   __ZdlPv($1870);
   ___resumeException($1864|0);
   // unreachable;
  }
 } while(0);
 $1871 = (($commonScriptingClasses) + 564|0);
 HEAP32[$1871>>2] = $1848;
 $1872 = (($commonScriptingClasses) + 568|0);
 __ZL13RequireMethodPKcS0_S0_S0_($22,637592,637608,637328,637336);
 ;HEAP32[$1872+0>>2]=HEAP32[$22+0>>2]|0;HEAP8[$1872+4>>0]=HEAP8[$22+4>>0]|0;
 $1873 = (($commonScriptingClasses) + 576|0);
 __ZL13RequireMethodPKcS0_S0_S0_($23,637592,637608,637328,637360);
 ;HEAP32[$1873+0>>2]=HEAP32[$23+0>>2]|0;HEAP8[$1873+4>>0]=HEAP8[$23+4>>0]|0;
 $1874 = (($commonScriptingClasses) + 584|0);
 __ZL13RequireMethodPKcS0_S0_S0_($24,637592,637608,637328,637384);
 ;HEAP32[$1874+0>>2]=HEAP32[$24+0>>2]|0;HEAP8[$1874+4>>0]=HEAP8[$24+4>>0]|0;
 $1875 = (($commonScriptingClasses) + 592|0);
 __ZL13RequireMethodPKcS0_S0_S0_($25,637592,637608,635424,637408);
 ;HEAP32[$1875+0>>2]=HEAP32[$25+0>>2]|0;HEAP8[$1875+4>>0]=HEAP8[$25+4>>0]|0;
 $1876 = (($commonScriptingClasses) + 600|0);
 __ZL13RequireMethodPKcS0_S0_S0_($26,637592,637608,635424,637424);
 ;HEAP32[$1876+0>>2]=HEAP32[$26+0>>2]|0;HEAP8[$1876+4>>0]=HEAP8[$26+4>>0]|0;
 $1877 = (($commonScriptingClasses) + 608|0);
 __ZL13RequireMethodPKcS0_S0_S0_($27,637592,637608,635424,637440);
 ;HEAP32[$1877+0>>2]=HEAP32[$27+0>>2]|0;HEAP8[$1877+4>>0]=HEAP8[$27+4>>0]|0;
 $1878 = (__Z29scripting_class_from_fullnamePKcS0_S0_(637592,637608,637464)|0);
 $1879 = ($1878|0)==(0|0);
 if (!($1879)) {
  $1901 = (($commonScriptingClasses) + 616|0);
  HEAP32[$1901>>2] = $1878;
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer368>>2] = 637592;
 $vararg_ptr371 = (($vararg_buffer368) + 4|0);
 HEAP32[$vararg_ptr371>>2] = 637608;
 $vararg_ptr372 = (($vararg_buffer368) + 8|0);
 HEAP32[$vararg_ptr372>>2] = 637464;
 __Z6FormatPKcz($0,637496,$vararg_buffer368);
 $1880 = HEAP8[$0>>0]|0;
 $1881 = $1880 & 1;
 $1882 = ($1881<<24>>24)==(0);
 if ($1882) {
  $1885 = (($0) + 1|0);
  $1886 = $1885;
 } else {
  $1883 = (($0) + 8|0);
  $1884 = HEAP32[$1883>>2]|0;
  $1886 = $1884;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($1886|0),0,(637528|0),32,1,0,0,(0|0));
 $1887 = __THREW__; __THREW__ = 0;
 $1888 = $1887&1;
 if ($1888) {
  $1894 = ___cxa_find_matching_catch()|0;
  $1895 = tempRet0;
  $1896 = HEAP8[$0>>0]|0;
  $1897 = $1896 & 1;
  $1898 = ($1897<<24>>24)==(0);
  if ($1898) {
   ___resumeException($1894|0);
   // unreachable;
  }
  $1899 = (($0) + 8|0);
  $1900 = HEAP32[$1899>>2]|0;
  __ZdlPv($1900);
  ___resumeException($1894|0);
  // unreachable;
 } else {
  $1889 = HEAP8[$0>>0]|0;
  $1890 = $1889 & 1;
  $1891 = ($1890<<24>>24)==(0);
  if ($1891) {
   $1901 = (($commonScriptingClasses) + 616|0);
   HEAP32[$1901>>2] = $1878;
   STACKTOP = sp;return;
  }
  $1892 = (($0) + 8|0);
  $1893 = HEAP32[$1892>>2]|0;
  __ZdlPv($1893);
  $1901 = (($commonScriptingClasses) + 616|0);
  HEAP32[$1901>>2] = $1878;
  STACKTOP = sp;return;
 }
}
function __ZL13RequireMethodPKcS0_S0_S0_($agg$result,$assembly,$namespaze,$klass,$name) {
 $agg$result = $agg$result|0;
 $assembly = $assembly|0;
 $namespaze = $namespaze|0;
 $klass = $klass|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 16|0;
 __ZN9Scripting9GetMethodEPKcS1_S1_S1_($agg$result,$assembly,$namespaze,$klass,$name);
 $1 = HEAP32[$agg$result>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer>>2] = $name;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $assembly;
 $vararg_ptr2 = (($vararg_buffer) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $namespaze;
 $vararg_ptr3 = (($vararg_buffer) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $klass;
 __Z6FormatPKcz($0,637536,$vararg_buffer);
 $3 = HEAP8[$0>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($0) + 1|0);
  $9 = $8;
 } else {
  $6 = (($0) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $9 = $7;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($9|0),0,(637528|0),18,1,0,0,(0|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  $19 = HEAP8[$0>>0]|0;
  $20 = $19 & 1;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   ___resumeException($17|0);
   // unreachable;
  }
  $22 = (($0) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  __ZdlPv($23);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $12 = HEAP8[$0>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   STACKTOP = sp;return;
  }
  $15 = (($0) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  __ZdlPv($16);
  STACKTOP = sp;return;
 }
}
function __ZN16ScriptingManagerC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((637656 + 8|0));
 $2 = (($this) + 24|0);
 $3 = (($this) + 28|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 32|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 28|0);
 HEAP32[$2>>2] = $5;
 $6 = (($this) + 232|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 292|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 300|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 328|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 336|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 344|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 352|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 360|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 368|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 376|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 384|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 392|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 400|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 408|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 416|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 424|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 432|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 440|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 504|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 512|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 520|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 604|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 612|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 620|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 628|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 636|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 644|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 656|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 660|0);
 HEAP32[$34>>2] = 0;
 $35 = (($this) + 664|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 668|0);
 $37 = (($this) + 672|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 676|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 672|0);
 HEAP32[$36>>2] = $39;
 $40 = (($this) + 684|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 688|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 692|0);
 HEAP32[$42>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2599,5,($this|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if (!($44)) {
  STACKTOP = sp;return;
 }
 $45 = ___cxa_find_matching_catch()|0;
 $46 = tempRet0;
 $47 = HEAP32[$40>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = HEAP32[$41>>2]|0;
  $50 = ($49|0)==($47|0);
  if (!($50)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $47;
   $scevgep$i$i$i$i$i$i$i$i$i = (($49) + -8|0);
   $51 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($51)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $52 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
   $53 = $52 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($49) + ($53<<3)|0);
   HEAP32[$41>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($47);
 }
 $54 = HEAP32[$37>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiP15MonoScriptCacheEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($36,$54);
 $55 = HEAP32[$33>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = HEAP32[$34>>2]|0;
  $58 = ($57|0)==($55|0);
  if (!($58)) {
   $__new_last2$i$i$i$i$i = $55;
   $scevgep$i$i$i$i$i = (($57) + -4|0);
   $59 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($59)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $60 = $uglygep3$i$i$i$i$i >>> 2;
   $61 = $60 ^ -1;
   $scevgep4$i$i$i$i$i = (($57) + ($61<<2)|0);
   HEAP32[$34>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($55);
 }
 $62 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$62);
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $75 = ___cxa_find_matching_catch(0|0)|0;
  $76 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $77 = __THREW__; __THREW__ = 0;
  $78 = $77&1;
  if ($78) {
   $81 = ___cxa_find_matching_catch(0|0)|0;
   $82 = tempRet0;
   __THREW__ = 0;
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $85 = ___cxa_find_matching_catch(0|0)|0;
    $86 = tempRet0;
    ___clang_call_terminate($85);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $81;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if (!($80)) {
   $eh$lpad$body$indexZ2D = $75;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
  $87 = ___cxa_find_matching_catch(0|0)|0;
  $88 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $87;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if ($66) {
   $67 = ___cxa_find_matching_catch(0|0)|0;
   $68 = tempRet0;
   __THREW__ = 0;
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    $71 = ___cxa_find_matching_catch(0|0)|0;
    $72 = tempRet0;
    ___clang_call_terminate($71);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $67;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $73 = __THREW__; __THREW__ = 0;
  $74 = $73&1;
  if (!($74)) {
   ___resumeException($45|0);
   // unreachable;
  }
  $89 = ___cxa_find_matching_catch(0|0)|0;
  $90 = tempRet0;
  $eh$lpad$body$indexZ2D = $89;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __ZN16ScriptingManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1151,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN16ScriptingManagerD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$i$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((637656 + 8|0));
 $0 = (($this) + 684|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 688|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if (!($5)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $1;
   $scevgep$i$i$i$i$i$i$i$i$i = (($4) + -8|0);
   $6 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($6)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $7 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
   $8 = $7 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($4) + ($8<<3)|0);
   HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($1);
 }
 $9 = (($this) + 668|0);
 $10 = (($this) + 672|0);
 $11 = HEAP32[$10>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiP15MonoScriptCacheEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($9,$11);
 $12 = (($this) + 656|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($this) + 660|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($13|0);
  if (!($17)) {
   $__new_last2$i$i$i$i$i = $13;
   $scevgep$i$i$i$i$i = (($16) + -4|0);
   $18 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($18)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $19 = $uglygep3$i$i$i$i$i >>> 2;
   $20 = $19 ^ -1;
   $scevgep4$i$i$i$i$i = (($16) + ($20<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($13);
 }
 $21 = (($this) + 24|0);
 $22 = (($this) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNSt3__16__treeI4PPtrI10MonoScriptENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($21,$23);
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   STACKTOP = sp;return;
  }
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  __THREW__ = 0;
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch(0|0)|0;
   $33 = tempRet0;
   ___clang_call_terminate($32);
   // unreachable;
  } else {
   ___resumeException($28|0);
   // unreachable;
  }
 }
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $40 = ___cxa_find_matching_catch(0|0)|0;
  $41 = tempRet0;
  __THREW__ = 0;
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   $44 = ___cxa_find_matching_catch(0|0)|0;
   $45 = tempRet0;
   ___clang_call_terminate($44);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $40;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if (!($39)) {
  ___resumeException($34|0);
  // unreachable;
 }
 $46 = ___cxa_find_matching_catch(0|0)|0;
 $47 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $46;
 ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
 // unreachable;
}
function __ZN16ScriptingManager30RebuildClassIDToScriptingClassEv($this) {
 $this = $this|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$0$i30 = 0, $$pre = 0, $$pre$i = 0, $$pre44 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $__new_last2$i$i$i$i$i23 = 0, $__new_last2$i$i$i11 = 0, $allEngineClasses = 0, $classID$tr$i = 0, $i$040 = 0, $i1$039 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $phitmp = 0, $result$01$i = 0, $result$01$i$i = 0;
 var $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i24 = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep$i$i$i12 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i28 = 0, $scevgep4$i$i$i$i$i7 = 0, $scevgep4$i$i$i16 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i26 = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep$i$i$i14 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i27 = 0, $uglygep3$i$i$i$i$i6 = 0, $uglygep3$i$i$i15 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $allEngineClasses = sp + 4|0;
 $0 = sp;
 HEAP32[$allEngineClasses>>2] = 0;
 $1 = (($allEngineClasses) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($allEngineClasses) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_viii(1628,0,($allEngineClasses|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   label = 7;
  } else {
   $5 = HEAP32[$1>>2]|0;
   $6 = HEAP32[$allEngineClasses>>2]|0;
   $7 = ($5|0)==($6|0);
   if ($7) {
    $45 = 1;
   } else {
    $8 = $5;
    $9 = $6;
    $10 = (($8) - ($9))|0;
    $11 = $10 >> 2;
    $15 = 0;$i$040 = 0;
    while(1) {
     $12 = (($6) + ($i$040<<2)|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)<($15|0);
     $16 = $14 ? $15 : $13;
     $17 = (($i$040) + 1)|0;
     $18 = ($17>>>0)<($11>>>0);
     if ($18) {
      $15 = $16;$i$040 = $17;
     } else {
      break;
     }
    }
    $phitmp = (($16) + 1)|0;
    $45 = $phitmp;
   }
   $32 = (($this) + 656|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($this) + 660|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($33|0);
   $$pre44 = $33;
   if ($36) {
    $41 = $33;
   } else {
    $scevgep$i$i$i = (($35) + -4|0);
    $37 = (0 - ($$pre44))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($37)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $38 = $uglygep3$i$i$i >>> 2;
    $39 = $38 ^ -1;
    $scevgep4$i$i$i = (($35) + ($39<<2)|0);
    HEAP32[$34>>2] = $scevgep4$i$i$i;
    $41 = $scevgep4$i$i$i;
   }
   HEAP32[$0>>2] = 0;
   $40 = $41;
   $42 = (($40) - ($$pre44))|0;
   $43 = $42 >> 2;
   $44 = ($43>>>0)<($45>>>0);
   if ($44) {
    $46 = (($45) - ($43))|0;
    __THREW__ = 0;
    invoke_viii(1917,($32|0),($46|0),($0|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 7;
     break;
    }
    $$pre = HEAP32[$32>>2]|0;
    $56 = $$pre;
   } else {
    $49 = ($43>>>0)>($45>>>0);
    if ($49) {
     $50 = (($33) + ($45<<2)|0);
     $51 = ($41|0)==($50|0);
     if ($51) {
      $56 = $33;
     } else {
      $__new_last2$i$i$i11 = $50;
      $scevgep$i$i$i12 = (($41) + -4|0);
      $52 = (0 - ($__new_last2$i$i$i11))|0;
      $uglygep$i$i$i14 = (($scevgep$i$i$i12) + ($52)|0);
      $uglygep3$i$i$i15 = $uglygep$i$i$i14;
      $53 = $uglygep3$i$i$i15 >>> 2;
      $54 = $53 ^ -1;
      $scevgep4$i$i$i16 = (($41) + ($54<<2)|0);
      HEAP32[$34>>2] = $scevgep4$i$i$i16;
      $56 = $33;
     }
    } else {
     $56 = $33;
    }
   }
   $55 = HEAP32[$56>>2]|0;
   HEAP32[637648>>2] = $55;
   $57 = (($this) + 684|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($this) + 688|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==($58|0);
   if (!($61)) {
    $__new_last2$i$i$i$i$i23 = $58;
    $scevgep$i$i$i$i$i24 = (($60) + -8|0);
    $62 = (0 - ($__new_last2$i$i$i$i$i23))|0;
    $uglygep$i$i$i$i$i26 = (($scevgep$i$i$i$i$i24) + ($62)|0);
    $uglygep3$i$i$i$i$i27 = $uglygep$i$i$i$i$i26;
    $63 = $uglygep3$i$i$i$i$i27 >>> 3;
    $64 = $63 ^ -1;
    $scevgep4$i$i$i$i$i28 = (($60) + ($64<<3)|0);
    HEAP32[$59>>2] = $scevgep4$i$i$i$i$i28;
   }
   __THREW__ = 0;
   $65 = (invoke_iiii(1559,(637592|0),(637608|0),(637776|0))|0);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 7;
   } else {
    $68 = HEAP32[$1>>2]|0;
    $69 = HEAP32[$allEngineClasses>>2]|0;
    $70 = ($68|0)==($69|0);
    L23: do {
     if (!($70)) {
      $71 = (($this) + 692|0);
      $73 = $69;$i1$039 = 0;
      L25: while(1) {
       $72 = (($73) + ($i1$039<<2)|0);
       $74 = HEAP32[$72>>2]|0;
       $classID$tr$i = $74;
       while(1) {
        __THREW__ = 0;
        $75 = (invoke_ii(3216,($classID$tr$i|0))|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 5;
         break L25;
        }
        $78 = HEAP8[$75>>0]|0;
        $79 = $78 & 1;
        $80 = ($79<<24>>24)==(0);
        if ($80) {
         $83 = (($75) + 1|0);
         $84 = $83;
        } else {
         $81 = (($75) + 8|0);
         $82 = HEAP32[$81>>2]|0;
         $84 = $82;
        }
        __THREW__ = 0;
        $85 = (invoke_iiii(1559,(637592|0),(637608|0),($84|0))|0);
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         label = 5;
         break L25;
        }
        $88 = ($85|0)==(0|0);
        if ($88) {
         __THREW__ = 0;
         $89 = (invoke_iiii(1559,(637592|0),(637624|0),($84|0))|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          label = 5;
          break L25;
         }
         $92 = ($89|0)==(0|0);
         if (!($92)) {
          $result$01$i$i = $89;
          label = 35;
         }
        } else {
         $result$01$i$i = $85;
         label = 35;
        }
        if ((label|0) == 35) {
         label = 0;
         __THREW__ = 0;
         $93 = (invoke_iii(2432,($result$01$i$i|0),($65|0))|0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          label = 5;
          break L25;
         }
         if ($93) {
          $$0$i30 = $result$01$i$i;
          break;
         }
        }
        $96 = ($classID$tr$i|0)==(0);
        if ($96) {
         $$0$i30 = 0;
         break;
        }
        __THREW__ = 0;
        $97 = (invoke_ii(3214,($classID$tr$i|0))|0);
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         label = 5;
         break L25;
        } else {
         $classID$tr$i = $97;
        }
       }
       $100 = HEAP32[$32>>2]|0;
       $101 = (($100) + ($74<<2)|0);
       HEAP32[$101>>2] = $$0$i30;
       __THREW__ = 0;
       $102 = (invoke_ii(3216,($74|0))|0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        label = 6;
        break;
       }
       $105 = HEAP8[$102>>0]|0;
       $106 = $105 & 1;
       $107 = ($106<<24>>24)==(0);
       if ($107) {
        $110 = (($102) + 1|0);
        $111 = $110;
       } else {
        $108 = (($102) + 8|0);
        $109 = HEAP32[$108>>2]|0;
        $111 = $109;
       }
       __THREW__ = 0;
       $112 = (invoke_iiii(1559,(637592|0),(637608|0),($111|0))|0);
       $113 = __THREW__; __THREW__ = 0;
       $114 = $113&1;
       if ($114) {
        label = 6;
        break;
       }
       $115 = ($112|0)==(0|0);
       if ($115) {
        __THREW__ = 0;
        $116 = (invoke_iiii(1559,(637592|0),(637624|0),($111|0))|0);
        $117 = __THREW__; __THREW__ = 0;
        $118 = $117&1;
        if ($118) {
         label = 6;
         break;
        }
        $119 = ($116|0)==(0|0);
        if (!($119)) {
         $result$01$i = $116;
         label = 47;
        }
       } else {
        $result$01$i = $112;
        label = 47;
       }
       do {
        if ((label|0) == 47) {
         label = 0;
         __THREW__ = 0;
         $120 = (invoke_iii(2432,($result$01$i|0),($65|0))|0);
         $121 = __THREW__; __THREW__ = 0;
         $122 = $121&1;
         if ($122) {
          label = 6;
          break L25;
         }
         if ($120) {
          $123 = HEAP32[$59>>2]|0;
          $124 = HEAP32[$71>>2]|0;
          $125 = ($123|0)==($124|0);
          if (!($125)) {
           $126 = ($123|0)==(0|0);
           if ($126) {
            $133 = 0;
           } else {
            $127 = $result$01$i;
            $128 = $123;
            $129 = $128;
            HEAP32[$129>>2] = $127;
            $130 = (($128) + 4)|0;
            $131 = $130;
            HEAP32[$131>>2] = $74;
            $$pre$i = HEAP32[$59>>2]|0;
            $133 = $$pre$i;
           }
           $132 = (($133) + 8|0);
           HEAP32[$59>>2] = $132;
           break;
          }
          $134 = HEAP32[$57>>2]|0;
          $135 = $123;
          $136 = $134;
          $137 = (($135) - ($136))|0;
          $138 = $137 >> 3;
          $139 = (($138) + 1)|0;
          $140 = ($139>>>0)>(536870911);
          if ($140) {
           label = 54;
           break L25;
          }
          $143 = ($138>>>0)<(268435455);
          if ($143) {
           $144 = $137 >> 2;
           $145 = ($144>>>0)<($139>>>0);
           $146 = $145 ? $139 : $144;
           $147 = ($146|0)==(0);
           if ($147) {
            $$0$i3$i$i = 0;$153 = 0;
           } else {
            $$0$i2$i$i = $146;
            label = 58;
           }
          } else {
           $$0$i2$i$i = 536870911;
           label = 58;
          }
          if ((label|0) == 58) {
           label = 0;
           $148 = $$0$i2$i$i << 3;
           __THREW__ = 0;
           $149 = (invoke_ii(2988,($148|0))|0);
           $150 = __THREW__; __THREW__ = 0;
           $151 = $150&1;
           if ($151) {
            label = 6;
            break L25;
           }
           $$0$i3$i$i = $$0$i2$i$i;$153 = $149;
          }
          $152 = (($153) + ($138<<3)|0);
          $154 = (($153) + ($$0$i3$i$i<<3)|0);
          $155 = ($152|0)==(0|0);
          if (!($155)) {
           $156 = $result$01$i;
           $157 = $152;
           $158 = $157;
           HEAP32[$158>>2] = $156;
           $159 = (($157) + 4)|0;
           $160 = $159;
           HEAP32[$160>>2] = $74;
          }
          $161 = (($153) + ($139<<3)|0);
          _memcpy(($153|0),($134|0),($137|0))|0;
          HEAP32[$57>>2] = $153;
          HEAP32[$59>>2] = $161;
          HEAP32[$71>>2] = $154;
          $162 = ($134|0)==(0|0);
          if ($162) {
           break;
          }
          __ZdlPv($134);
         }
        }
       } while(0);
       $163 = (($i1$039) + 1)|0;
       $164 = HEAP32[$1>>2]|0;
       $165 = HEAP32[$allEngineClasses>>2]|0;
       $166 = $164;
       $167 = $165;
       $168 = (($166) - ($167))|0;
       $169 = $168 >> 2;
       $170 = ($163>>>0)<($169>>>0);
       if ($170) {
        $73 = $165;$i1$039 = $163;
       } else {
        break L23;
       }
      }
      if ((label|0) == 5) {
       $19 = ___cxa_find_matching_catch()|0;
       $20 = tempRet0;
       $lpad$phi$index = $19;$lpad$phi$index3 = $20;
       break L1;
      }
      else if ((label|0) == 6) {
       $21 = ___cxa_find_matching_catch()|0;
       $22 = tempRet0;
       $lpad$phi$index = $21;$lpad$phi$index3 = $22;
       break L1;
      }
      else if ((label|0) == 54) {
       __THREW__ = 0;
       invoke_vi(3308,0);
       $141 = __THREW__; __THREW__ = 0;
       $142 = $141&1;
       if ($142) {
        label = 7;
        break L1;
       }
       // unreachable;
      }
     }
    } while(0);
    $171 = (($this) + 680|0);
    __THREW__ = 0;
    invoke_vi(3559,($171|0));
    $172 = __THREW__; __THREW__ = 0;
    $173 = $172&1;
    if ($173) {
     label = 7;
    } else {
     $174 = HEAP32[$allEngineClasses>>2]|0;
     $175 = ($174|0)==(0|0);
     if ($175) {
      STACKTOP = sp;return;
     }
     $176 = HEAP32[$1>>2]|0;
     $177 = ($176|0)==($174|0);
     if (!($177)) {
      $__new_last2$i$i$i$i$i = $174;
      $scevgep$i$i$i$i$i = (($176) + -4|0);
      $178 = (0 - ($__new_last2$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($178)|0);
      $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
      $179 = $uglygep3$i$i$i$i$i >>> 2;
      $180 = $179 ^ -1;
      $scevgep4$i$i$i$i$i = (($176) + ($180<<2)|0);
      HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
     }
     __ZdlPv($174);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  $lpad$phi$index = $23;$lpad$phi$index3 = $24;
 }
 $25 = HEAP32[$allEngineClasses>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $27 = HEAP32[$1>>2]|0;
 $28 = ($27|0)==($25|0);
 if (!($28)) {
  $__new_last2$i$i$i$i$i2 = $25;
  $scevgep$i$i$i$i$i3 = (($27) + -4|0);
  $29 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($29)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $30 = $uglygep3$i$i$i$i$i6 >>> 2;
  $31 = $30 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($27) + ($31<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i7;
 }
 __ZdlPv($25);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN16ScriptingManager23ClassIDToScriptingClassEi($this,$classID) {
 $this = $this|0;
 $classID = $classID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 656|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($classID<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN16ScriptingManager24ClassIDForScriptingClassEP14ScriptingClass($this,$klass) {
 $this = $this|0;
 $klass = $klass|0;
 var $$ = 0, $$0 = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 684|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 688|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3;
 $5 = $1;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = ($7|0)==(0);
 if ($8) {
  $18 = $1;
 } else {
  $11 = $1;$__len$03$i$i$i$i$i = $7;
  while(1) {
   $9 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $10 = (($11) + ($9<<3)|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12>>>0)<($klass>>>0);
   if ($13) {
    $$sum$i$i$i$i$i = (($9) + 1)|0;
    $14 = (($11) + ($$sum$i$i$i$i$i<<3)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $15 = (($$neg2$i$i$i$i$i) - ($9))|0;
    $24 = $14;$__len$0$be$i$i$i$i$i = $15;
   } else {
    $24 = $11;$__len$0$be$i$i$i$i$i = $9;
   }
   $16 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($16) {
    $18 = $24;
    break;
   } else {
    $11 = $24;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $17 = ($18|0)==($3|0);
 if ($17) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19>>>0)>($klass>>>0);
 $$ = $20 ? $3 : $18;
 $21 = ($$|0)==($3|0);
 if ($21) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = (($$) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $$0 = $23;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16ScriptingManager18GetMonoScriptCacheEj($this,$hash) {
 $this = $this|0;
 $hash = $hash|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 672|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 672|0);
 $3 = ($1|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$ph7$i$i$i = $2;$$01$ph6$i$in$i$i = $1;
 }
 L3: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $4 = (($$013$i$in$i$i) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)<($hash|0);
   if (!($6)) {
    break;
   }
   $9 = (($$013$i$in$i$i) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L3;
   } else {
    $$013$i$in$i$i = $10;
   }
  }
  $7 = HEAP32[$$013$i$in$i$i>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $7;
  }
 }
 $12 = ($$0$ph5$i$i$i|0)==($2|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($$0$ph5$i$i$i) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>($hash|0);
 if ($15) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = (($$0$ph5$i$i$i) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $$0 = $17;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16ScriptingManager19RegisterScriptCacheEP15MonoScriptCache($this,$msc) {
 $this = $this|0;
 $msc = $msc|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($msc) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 672|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 672|0);
 $6 = ($4|0)==(0|0);
 if (!($6)) {
  $$0$ph7$i$i$i$i = $5;$$01$ph6$i$in$i$i$i = $4;
  L2: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i$i) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<($2|0);
    if (!($9)) {
     break;
    }
    $12 = (($$013$i$in$i$i$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i$i = $13;
    }
   }
   $10 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $10;
   }
  }
  $15 = ($$0$ph5$i$i$i$i|0)==($5|0);
  if (!($15)) {
   $16 = (($$0$ph5$i$i$i$i) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>($2|0);
   if (!($18)) {
    $19 = (($$0$ph5$i$i$i$i) + 20|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $22 = (($this) + 668|0);
 HEAP32[$0>>2] = $2;
 $23 = (__ZNSt3__13mapIiP15MonoScriptCacheNS_4lessIiEE13stl_allocatorINS_4pairIKiS2_EEL18MemLabelIdentifier69ELi16EEEixERS7_($22,$0)|0);
 HEAP32[$23>>2] = $msc;
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIiP15MonoScriptCacheNS_4lessIiEE13stl_allocatorINS_4pairIKiS2_EEL18MemLabelIdentifier69ELi16EEEixERS7_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$23 = $14;
  } else {
   $4 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)<($6|0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6|0)<($4|0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$23 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $__r$0 = $15;
  $32 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($32|0);
 }
 HEAP32[$0>>2] = 69;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $17 = (__Z15malloc_internaljj10MemLabelIdiPKci(24,16,$$byval_copy,0,637784,79)|0);
 $18 = (($17) + 16|0);
 $19 = HEAP32[$__k>>2]|0;
 HEAP32[$18>>2] = $19;
 $20 = (($17) + 20|0);
 HEAP32[$20>>2] = 0;
 HEAP32[$17>>2] = 0;
 $21 = (($17) + 4|0);
 HEAP32[$21>>2] = 0;
 $22 = (($17) + 8|0);
 HEAP32[$22>>2] = $23;
 HEAP32[$$0$i>>2] = $17;
 $24 = HEAP32[$this>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $28 = $17;
 } else {
  HEAP32[$this>>2] = $25;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $28 = $$pre$i;
 }
 $27 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 $__r$0 = $17;
 $32 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($32|0);
}
function __ZN16ScriptingManager24NotifyScriptCacheReleaseEj($this,$hash) {
 $this = $this|0;
 $hash = $hash|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 672|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 672|0);
 $4 = ($2|0)==(0|0);
 if ($4) {
  label = 8;
 } else {
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $5 = (($$013$i$in$i$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<($hash|0);
    if (!($7)) {
     break;
    }
    $10 = (($$013$i$in$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $11;
    }
   }
   $8 = HEAP32[$$013$i$in$i$i>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $8;
   }
  }
  $13 = ($$0$ph5$i$i$i|0)==($3|0);
  if ($13) {
   label = 8;
  } else {
   $14 = (($$0$ph5$i$i$i) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>($hash|0);
   if ($16) {
    label = 8;
   } else {
    $18 = $$0$ph5$i$i$i;
   }
  }
 }
 if ((label|0) == 8) {
  $18 = $3;
 }
 $17 = (($18) + 20|0);
 $19 = HEAP32[$17>>2]|0;
 $20 = (__ZNK15MonoScriptCache8RefCountEv($19)|0);
 $21 = ($20|0)>(1);
 if ($21) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $hash;
 $22 = (($this) + 668|0);
 (__ZNSt3__16__treeINS_12__value_typeIiP15MonoScriptCacheEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier69ELi16EEE14__erase_uniqueIiEEjRKT_($22,$0)|0);
 __ZNK15MonoScriptCache7ReleaseEv($19);
 STACKTOP = sp;return;
}
function __Z19GetScriptingManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(5)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__16__treeINS_12__value_typeIiP15MonoScriptCacheEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier69ELi16EEE14__erase_uniqueIiEEjRKT_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$ph5$i$i = 0, $$0$ph7$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i = 0, $$013$i$in$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = ($2|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$__k>>2]|0;
 $$0$ph7$i$i = $3;$$01$ph6$i$in$i = $2;
 L4: while(1) {
  $$013$i$in$i = $$01$ph6$i$in$i;
  while(1) {
   $6 = (($$013$i$in$i) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)<($5|0);
   if (!($8)) {
    break;
   }
   $11 = (($$013$i$in$i) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$ph5$i$i = $$0$ph7$i$i;
    break L4;
   } else {
    $$013$i$in$i = $12;
   }
  }
  $9 = HEAP32[$$013$i$in$i>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$0$ph5$i$i = $$013$i$in$i;
   break;
  } else {
   $$0$ph7$i$i = $$013$i$in$i;$$01$ph6$i$in$i = $9;
  }
 }
 $14 = ($$0$ph5$i$i|0)==($3|0);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($$0$ph5$i$i) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($5|0)<($16|0);
 if ($17) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($$0$ph5$i$i) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $$01$i$i$i = $$0$ph5$i$i;
  while(1) {
   $23 = (($$01$i$i$i) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==($$01$i$i$i|0);
   if ($26) {
    $$0$i$i$i = $24;
    break;
   } else {
    $$01$i$i$i = $24;
   }
  }
 } else {
  $$0$i$i$i$i = $19;
  while(1) {
   $21 = HEAP32[$$0$i$i$i$i>>2]|0;
   $22 = ($21|0)==(0|0);
   if ($22) {
    $$0$i$i$i = $$0$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i = $21;
   }
  }
 }
 $27 = HEAP32[$this>>2]|0;
 $28 = ($27|0)==($$0$ph5$i$i|0);
 if ($28) {
  HEAP32[$this>>2] = $$0$i$i$i;
 }
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + -1)|0;
 HEAP32[$29>>2] = $31;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($2,$$0$ph5$i$i);
 HEAP32[$0>>2] = 69;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($$0$ph5$i$i|0),($$byval_copy|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  ___cxa_call_unexpected(($34|0));
  // unreachable;
 } else {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN13sorted_vectorINSt3__14pairIP14ScriptingClassiEEN10vector_mapIS3_iNS0_4lessIS3_EENS0_9allocatorIS4_EEE13value_compareES9_E21sort_clear_duplicatesEv($this) {
 $this = $this|0;
 var $$0$lcssa$i$i$i = 0, $$012$i$i$i = 0, $$02$i$i = 0, $$03$i$i$i = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre45 = 0, $$pre47 = 0, $$sum$i = 0, $$sum5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $__first5$i$i$i = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i1$i = 0, $scevgep4$i$i$i = 0, $scevgep7$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i3$i = 0, $uglygep3$i$i$i = 0, $uglygep6$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp + 12|0;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP8[$this>>0]|0;
 HEAP8[$2>>0] = $8;
 $9 = $6;
 $10 = $4;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 3;
 $13 = ($11|0)>(0);
 L4: do {
  if ($13) {
   $$02$i$i = $12;
   while(1) {
    $14 = $$02$i$i << 3;
    $15 = (__ZnwjRKSt9nothrow_t($14,3106360)|0);
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     $22 = $15;$23 = $$02$i$i;
     break L4;
    }
    $17 = (($$02$i$i|0) / 2)&-1;
    $18 = ($$02$i$i|0)>(1);
    if ($18) {
     $$02$i$i = $17;
    } else {
     $22 = $15;$23 = 0;
     break;
    }
   }
  } else {
   $22 = 0;$23 = 0;
  }
 } while(0);
 HEAP32[$0>>2] = $4;
 HEAP32[$1>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(127,($$byval_copy|0),($$byval_copy1|0),($2|0),($12|0),($22|0),($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = ($22|0)==(0|0);
  if ($21) {
   ___resumeException($19|0);
   // unreachable;
  }
  __ZdlPv($22);
  ___resumeException($19|0);
  // unreachable;
 }
 $26 = ($22|0)==(0|0);
 if (!($26)) {
  __ZdlPv($22);
 }
 $27 = HEAP32[$3>>2]|0;
 $28 = HEAP32[$5>>2]|0;
 $29 = ($27|0)==($28|0);
 if ($29) {
  STACKTOP = sp;return;
 } else {
  $31 = $27;
 }
 while(1) {
  $30 = (($31) + 8|0);
  $32 = ($30|0)==($28|0);
  if ($32) {
   label = 26;
   break;
  }
  $33 = HEAP32[$31>>2]|0;
  $34 = HEAP32[$30>>2]|0;
  $35 = ($33>>>0)<($34>>>0);
  if ($35) {
   $31 = $30;
  } else {
   break;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return;
 }
 $36 = ($31|0)==($28|0);
 if ($36) {
  STACKTOP = sp;return;
 } else {
  $38 = $33;$39 = $34;$40 = $30;$42 = $30;$48 = $31;
 }
 while(1) {
  $37 = ($38>>>0)<($39>>>0);
  if ($37) {
   HEAP32[$40>>2] = $39;
   $41 = (($42) + 4|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = (($40) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (($40) + 8|0);
   $51 = $45;
  } else {
   $51 = $40;
  }
  $46 = (($42) + 8|0);
  $47 = (($48) + 8|0);
  $49 = ($46|0)==($28|0);
  if ($49) {
   break;
  }
  $$pre45 = HEAP32[$47>>2]|0;
  $$pre47 = HEAP32[$46>>2]|0;
  $38 = $$pre45;$39 = $$pre47;$40 = $51;$42 = $46;$48 = $47;
 }
 $$pre = HEAP32[$5>>2]|0;
 $50 = ($51|0)==($$pre|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 $52 = HEAP32[$3>>2]|0;
 $53 = $51;
 $54 = $52;
 $55 = (($53) - ($54))|0;
 $56 = $55 >> 3;
 $57 = (($52) + ($56<<3)|0);
 $58 = $$pre;
 $59 = (($58) - ($53))|0;
 $60 = $59 >> 3;
 $$sum$i = (($56) + ($60))|0;
 $61 = (($52) + ($$sum$i<<3)|0);
 $62 = ($61|0)==($$pre|0);
 if ($62) {
  $$0$lcssa$i$i$i = $57;$74 = $$pre;
 } else {
  $__first5$i$i$i = $61;
  $scevgep$i$i1$i = (($$pre) + -8|0);
  $63 = (0 - ($__first5$i$i$i))|0;
  $uglygep$i$i3$i = (($scevgep$i$i1$i) + ($63)|0);
  $$012$i$i$i = $61;$$03$i$i$i = $57;
  while(1) {
   $64 = HEAP32[$$012$i$i$i>>2]|0;
   HEAP32[$$03$i$i$i>>2] = $64;
   $65 = (($$012$i$i$i) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($$03$i$i$i) + 4|0);
   HEAP32[$67>>2] = $66;
   $68 = (($$012$i$i$i) + 8|0);
   $69 = (($$03$i$i$i) + 8|0);
   $70 = ($68|0)==($$pre|0);
   if ($70) {
    break;
   } else {
    $$012$i$i$i = $68;$$03$i$i$i = $69;
   }
  }
  $uglygep6$i$i$i = $uglygep$i$i3$i;
  $71 = $uglygep6$i$i$i >>> 3;
  $72 = (($56) + 1)|0;
  $$sum5$i = (($72) + ($71))|0;
  $scevgep7$i$i$i = (($52) + ($$sum5$i<<3)|0);
  $$pre$i = HEAP32[$5>>2]|0;
  $$0$lcssa$i$i$i = $scevgep7$i$i$i;$74 = $$pre$i;
 }
 $73 = ($74|0)==($$0$lcssa$i$i$i|0);
 if ($73) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i = $$0$lcssa$i$i$i;
 $scevgep$i$i$i = (($74) + -8|0);
 $75 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($75)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $76 = $uglygep3$i$i$i >>> 3;
 $77 = $76 ^ -1;
 $scevgep4$i$i$i = (($74) + ($77<<3)|0);
 HEAP32[$5>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __ZNSt3__113__stable_sortIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeEi($__first,$__last,$__comp,$__len,$__buff,$__buff_size) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len = $__len|0;
 $__buff = $__buff|0;
 $__buff_size = $__buff_size|0;
 var $$01$lcssa$i = 0, $$0111$i = 0, $$012$i = 0, $$12$i = 0, $$17$i = 0, $$2$i = 0, $$234$i = 0, $$byval_copy10 = 0, $$byval_copy8 = 0, $$byval_copy9 = 0, $$lcssa$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $__len$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy10 = sp + 52|0;
 $$byval_copy9 = sp + 48|0;
 $$byval_copy8 = sp + 44|0;
 $0 = sp + 40|0;
 $1 = sp + 36|0;
 $2 = sp + 32|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = sp + 20|0;
 if ((($__len|0) == 2)) {
  $11 = HEAP32[$__last>>2]|0;
  $12 = (($11) + -8|0);
  HEAP32[$__last>>2] = $12;
  $13 = HEAP32[$__first>>2]|0;
  $14 = HEAP32[$12>>2]|0;
  $15 = HEAP32[$13>>2]|0;
  $16 = ($14>>>0)<($15>>>0);
  if (!($16)) {
   STACKTOP = sp;return;
  }
  HEAP32[$13>>2] = $14;
  HEAP32[$12>>2] = $15;
  $17 = (($13) + 4|0);
  $18 = (($11) + -4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$18>>2]|0;
  HEAP32[$17>>2] = $20;
  HEAP32[$18>>2] = $19;
  STACKTOP = sp;return;
 } else if ((($__len|0) == 1) | (($__len|0) == 0)) {
  STACKTOP = sp;return;
 } else {
  $21 = ($__len|0)<(1);
  if ($21) {
   $22 = HEAP32[$__first>>2]|0;
   $23 = HEAP32[$__last>>2]|0;
   $24 = ($22|0)==($23|0);
   if ($24) {
    STACKTOP = sp;return;
   }
   $25 = (($22) + 8|0);
   $26 = ($25|0)==($23|0);
   if ($26) {
    STACKTOP = sp;return;
   } else {
    $28 = $25;
   }
   while(1) {
    $27 = $28;
    $29 = $27;
    $30 = HEAP32[$29>>2]|0;
    $31 = (($27) + 4)|0;
    $32 = $31;
    $33 = HEAP32[$32>>2]|0;
    $34 = $30;
    $35 = ($28|0)==($22|0);
    L17: do {
     if ($35) {
      $$lcssa$i = $22;
     } else {
      $37 = $28;
      while(1) {
       $36 = (($37) + -8|0);
       $38 = HEAP32[$36>>2]|0;
       $39 = ($34>>>0)<($38>>>0);
       if (!($39)) {
        $$lcssa$i = $37;
        break L17;
       }
       HEAP32[$37>>2] = $38;
       $40 = (($37) + -4|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = (($37) + 4|0);
       HEAP32[$42>>2] = $41;
       $43 = ($36|0)==($22|0);
       if ($43) {
        $$lcssa$i = $22;
        break;
       } else {
        $37 = $36;
       }
      }
     }
    } while(0);
    HEAP32[$$lcssa$i>>2] = $34;
    $44 = (($$lcssa$i) + 4|0);
    HEAP32[$44>>2] = $33;
    $45 = (($28) + 8|0);
    $46 = ($45|0)==($23|0);
    if ($46) {
     break;
    } else {
     $28 = $45;
    }
   }
   STACKTOP = sp;return;
  }
  $47 = (($__len|0) / 2)&-1;
  $48 = HEAP32[$__first>>2]|0;
  $49 = (($48) + ($47<<3)|0);
  $50 = ($__len|0)>($__buff_size|0);
  if ($50) {
   HEAP32[$4>>2] = $48;
   HEAP32[$5>>2] = $49;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$5+0>>2]|0;
   __ZNSt3__113__stable_sortIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeEi($$byval_copy9,$$byval_copy10,$__comp,$47,$__buff,$__buff_size);
   HEAP32[$6>>2] = $49;
   $89 = HEAP32[$__last>>2]|0;
   HEAP32[$7>>2] = $89;
   $90 = (($__len) - ($47))|0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$6+0>>2]|0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$7+0>>2]|0;
   __ZNSt3__113__stable_sortIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeEi($$byval_copy9,$$byval_copy10,$__comp,$90,$__buff,$__buff_size);
   HEAP32[$8>>2] = $48;
   HEAP32[$9>>2] = $49;
   HEAP32[$10>>2] = $89;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$8+0>>2]|0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$9+0>>2]|0;
   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$10+0>>2]|0;
   __ZNSt3__115__inplace_mergeIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_SG_T_NS_15iterator_traitsISG_E15difference_typeESK_PNSJ_10value_typeEi($$byval_copy8,$$byval_copy9,$$byval_copy10,$__comp,$47,$90,$__buff,$__buff_size);
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $48;
  HEAP32[$1>>2] = $49;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__118__stable_sort_moveIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeE($$byval_copy9,$$byval_copy10,$__comp,$47,$__buff);
  HEAP32[$2>>2] = $49;
  $51 = HEAP32[$__last>>2]|0;
  HEAP32[$3>>2] = $51;
  $52 = (($__len) - ($47))|0;
  $53 = (($__buff) + ($47<<3)|0);
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
  ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
  __ZNSt3__118__stable_sort_moveIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeE($$byval_copy9,$$byval_copy10,$__comp,$52,$53);
  $54 = (($__buff) + ($__len<<3)|0);
  $__len$off = (($__len) + 1)|0;
  $55 = ($__len$off>>>0)<(3);
  L28: do {
   if ($55) {
    $$01$lcssa$i = $53;$91 = $48;
   } else {
    $$0111$i = $53;$$012$i = $__buff;$70 = $48;
    while(1) {
     $57 = ($$0111$i|0)==($54|0);
     if ($57) {
      break;
     }
     $67 = HEAP32[$$0111$i>>2]|0;
     $68 = HEAP32[$$012$i>>2]|0;
     $69 = ($67>>>0)<($68>>>0);
     if ($69) {
      HEAP32[$70>>2] = $67;
      $71 = (($$0111$i) + 4|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($70) + 4|0);
      HEAP32[$73>>2] = $72;
      $74 = (($$0111$i) + 8|0);
      $$12$i = $74;$$2$i = $$012$i;
     } else {
      HEAP32[$70>>2] = $68;
      $75 = (($$012$i) + 4|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = (($70) + 4|0);
      HEAP32[$77>>2] = $76;
      $78 = (($$012$i) + 8|0);
      $$12$i = $$0111$i;$$2$i = $78;
     }
     $79 = (($70) + 8|0);
     $80 = ($$2$i|0)==($53|0);
     if ($80) {
      $$01$lcssa$i = $$12$i;$91 = $79;
      break L28;
     } else {
      $$0111$i = $$12$i;$$012$i = $$2$i;$70 = $79;
     }
    }
    $58 = ($$012$i|0)==($53|0);
    if ($58) {
     STACKTOP = sp;return;
    } else {
     $$17$i = $$012$i;$60 = $70;
    }
    while(1) {
     $59 = HEAP32[$$17$i>>2]|0;
     HEAP32[$60>>2] = $59;
     $61 = (($$17$i) + 4|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($60) + 4|0);
     HEAP32[$63>>2] = $62;
     $64 = (($$17$i) + 8|0);
     $65 = (($60) + 8|0);
     $66 = ($64|0)==($53|0);
     if ($66) {
      break;
     } else {
      $$17$i = $64;$60 = $65;
     }
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $56 = ($$01$lcssa$i|0)==($54|0);
  if ($56) {
   STACKTOP = sp;return;
  } else {
   $$234$i = $$01$lcssa$i;$82 = $91;
  }
  while(1) {
   $81 = HEAP32[$$234$i>>2]|0;
   HEAP32[$82>>2] = $81;
   $83 = (($$234$i) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($82) + 4|0);
   HEAP32[$85>>2] = $84;
   $86 = (($$234$i) + 8|0);
   $87 = (($82) + 8|0);
   $88 = ($86|0)==($54|0);
   if ($88) {
    break;
   } else {
    $$234$i = $86;$82 = $87;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__118__stable_sort_moveIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeE($__first1,$__last1,$__comp,$__len,$__first2) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__comp = $__comp|0;
 $__len = $__len|0;
 $__first2 = $__first2|0;
 var $$0$lcssa$i = 0, $$013$i = 0, $$11$i = 0, $$24$i = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $$promoted6$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__first2$pn$ph$i = 0, $__first2$pn$ph$pn$i = 0, $__i2$02$i = 0, $__j2$0$lcssa$i = 0, $__last2$05$i = 0, $__len$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 20|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 if ((($__len|0) == 1)) {
  $4 = ($__first2|0)==(0|0);
  if ($4) {
   STACKTOP = sp;return;
  }
  $5 = HEAP32[$__first1>>2]|0;
  $6 = $5;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $__first2;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  STACKTOP = sp;return;
 } else if ((($__len|0) == 2)) {
  $16 = HEAP32[$__last1>>2]|0;
  $17 = (($16) + -8|0);
  HEAP32[$__last1>>2] = $17;
  $18 = HEAP32[$__first1>>2]|0;
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$18>>2]|0;
  $21 = ($19>>>0)<($20>>>0);
  $22 = ($__first2|0)==(0|0);
  if ($21) {
   if (!($22)) {
    $23 = $17;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 4)|0;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = $__first2;
    $30 = $29;
    HEAP32[$30>>2] = $25;
    $31 = (($29) + 4)|0;
    $32 = $31;
    HEAP32[$32>>2] = $28;
   }
   $33 = (($__first2) + 8|0);
   $34 = $18;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $33;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   STACKTOP = sp;return;
  } else {
   if (!($22)) {
    $44 = $18;
    $45 = $44;
    $46 = HEAP32[$45>>2]|0;
    $47 = (($44) + 4)|0;
    $48 = $47;
    $49 = HEAP32[$48>>2]|0;
    $50 = $__first2;
    $51 = $50;
    HEAP32[$51>>2] = $46;
    $52 = (($50) + 4)|0;
    $53 = $52;
    HEAP32[$53>>2] = $49;
   }
   $54 = (($__first2) + 8|0);
   $55 = $17;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = (($55) + 4)|0;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = $54;
   $62 = $61;
   HEAP32[$62>>2] = $57;
   $63 = (($61) + 4)|0;
   $64 = $63;
   HEAP32[$64>>2] = $60;
   STACKTOP = sp;return;
  }
 } else if ((($__len|0) == 0)) {
  STACKTOP = sp;return;
 } else {
  $65 = ($__len|0)<(9);
  if ($65) {
   $66 = HEAP32[$__first1>>2]|0;
   $67 = HEAP32[$__last1>>2]|0;
   $68 = ($66|0)==($67|0);
   if ($68) {
    STACKTOP = sp;return;
   }
   $69 = ($__first2|0)==(0|0);
   if ($69) {
    $__first2$pn$ph$i = 0;
   } else {
    $70 = $66;
    $71 = $70;
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + 4)|0;
    $74 = $73;
    $75 = HEAP32[$74>>2]|0;
    $76 = $__first2;
    $77 = $76;
    HEAP32[$77>>2] = $72;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = $75;
    $__first2$pn$ph$i = $__first2;
   }
   $80 = (($66) + 8|0);
   $81 = ($80|0)==($67|0);
   if ($81) {
    STACKTOP = sp;return;
   } else {
    $83 = $80;$__first2$pn$ph$pn$i = $__first2$pn$ph$i;
   }
   while(1) {
    $__last2$05$i = (($__first2$pn$ph$pn$i) + 8|0);
    $82 = HEAP32[$83>>2]|0;
    $84 = HEAP32[$__first2$pn$ph$pn$i>>2]|0;
    $85 = ($82>>>0)<($84>>>0);
    if ($85) {
     $86 = $__first2$pn$ph$pn$i;
     $87 = $86;
     $88 = HEAP32[$87>>2]|0;
     $89 = (($86) + 4)|0;
     $90 = $89;
     $91 = HEAP32[$90>>2]|0;
     $92 = $__last2$05$i;
     $93 = $92;
     HEAP32[$93>>2] = $88;
     $94 = (($92) + 4)|0;
     $95 = $94;
     HEAP32[$95>>2] = $91;
     $96 = ($__first2$pn$ph$pn$i|0)==($__first2|0);
     L34: do {
      if ($96) {
       $__j2$0$lcssa$i = $__first2;
      } else {
       $__i2$02$i = $__first2$pn$ph$pn$i;
       while(1) {
        $97 = (($__i2$02$i) + -8|0);
        $98 = HEAP32[$83>>2]|0;
        $99 = HEAP32[$97>>2]|0;
        $100 = ($98>>>0)<($99>>>0);
        if (!($100)) {
         $__j2$0$lcssa$i = $__i2$02$i;
         break L34;
        }
        HEAP32[$__i2$02$i>>2] = $99;
        $101 = (($__i2$02$i) + -4|0);
        $102 = HEAP32[$101>>2]|0;
        $103 = (($__i2$02$i) + 4|0);
        HEAP32[$103>>2] = $102;
        $104 = ($97|0)==($__first2|0);
        if ($104) {
         $__j2$0$lcssa$i = $__first2;
         break;
        } else {
         $__i2$02$i = $97;
        }
       }
      }
     } while(0);
     $105 = HEAP32[$83>>2]|0;
     HEAP32[$__j2$0$lcssa$i>>2] = $105;
     $106 = (($83) + 4|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = (($__j2$0$lcssa$i) + 4|0);
     HEAP32[$108>>2] = $107;
    } else {
     $111 = $83;
     $112 = $111;
     $113 = HEAP32[$112>>2]|0;
     $114 = (($111) + 4)|0;
     $115 = $114;
     $116 = HEAP32[$115>>2]|0;
     $117 = $__last2$05$i;
     $118 = $117;
     HEAP32[$118>>2] = $113;
     $119 = (($117) + 4)|0;
     $120 = $119;
     HEAP32[$120>>2] = $116;
    }
    $109 = (($83) + 8|0);
    $110 = ($109|0)==($67|0);
    if ($110) {
     break;
    } else {
     $83 = $109;$__first2$pn$ph$pn$i = $__last2$05$i;
    }
   }
   STACKTOP = sp;return;
  }
  $121 = (($__len|0) / 2)&-1;
  $122 = HEAP32[$__first1>>2]|0;
  $123 = (($122) + ($121<<3)|0);
  HEAP32[$0>>2] = $122;
  HEAP32[$1>>2] = $123;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__113__stable_sortIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeEi($$byval_copy2,$$byval_copy3,$__comp,$121,$__first2,$121);
  HEAP32[$2>>2] = $123;
  $124 = HEAP32[$__last1>>2]|0;
  HEAP32[$3>>2] = $124;
  $125 = (($__len) - ($121))|0;
  $126 = (($__first2) + ($121<<3)|0);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
  __ZNSt3__113__stable_sortIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeEi($$byval_copy2,$$byval_copy3,$__comp,$125,$126,$125);
  $__len$off = (($__len) + 1)|0;
  $127 = ($__len$off>>>0)<(3);
  L43: do {
   if ($127) {
    $$0$lcssa$i = $__first2;$129 = $122;
   } else {
    $$013$i = $__first2;$$promoted6$i = $122;$146 = $123;
    while(1) {
     $145 = ($146|0)==($124|0);
     if ($145) {
      break;
     }
     $163 = HEAP32[$146>>2]|0;
     $164 = HEAP32[$$promoted6$i>>2]|0;
     $165 = ($163>>>0)<($164>>>0);
     $166 = ($$013$i|0)==(0|0);
     if ($165) {
      if (!($166)) {
       $167 = $146;
       $168 = $167;
       $169 = HEAP32[$168>>2]|0;
       $170 = (($167) + 4)|0;
       $171 = $170;
       $172 = HEAP32[$171>>2]|0;
       $173 = $$013$i;
       $174 = $173;
       HEAP32[$174>>2] = $169;
       $175 = (($173) + 4)|0;
       $176 = $175;
       HEAP32[$176>>2] = $172;
      }
      $177 = (($146) + 8|0);
      $191 = $$promoted6$i;$192 = $177;
     } else {
      if (!($166)) {
       $178 = $$promoted6$i;
       $179 = $178;
       $180 = HEAP32[$179>>2]|0;
       $181 = (($178) + 4)|0;
       $182 = $181;
       $183 = HEAP32[$182>>2]|0;
       $184 = $$013$i;
       $185 = $184;
       HEAP32[$185>>2] = $180;
       $186 = (($184) + 4)|0;
       $187 = $186;
       HEAP32[$187>>2] = $183;
      }
      $188 = (($$promoted6$i) + 8|0);
      $191 = $188;$192 = $146;
     }
     $189 = (($$013$i) + 8|0);
     $190 = ($191|0)==($123|0);
     if ($190) {
      $$0$lcssa$i = $189;$129 = $192;
      break L43;
     } else {
      $$013$i = $189;$$promoted6$i = $191;$146 = $192;
     }
    }
    $147 = ($$promoted6$i|0)==($123|0);
    if ($147) {
     STACKTOP = sp;return;
    } else {
     $$24$i = $$013$i;$150 = $$promoted6$i;
    }
    while(1) {
     $148 = ($$24$i|0)==(0|0);
     if (!($148)) {
      $149 = $150;
      $151 = $149;
      $152 = HEAP32[$151>>2]|0;
      $153 = (($149) + 4)|0;
      $154 = $153;
      $155 = HEAP32[$154>>2]|0;
      $156 = $$24$i;
      $157 = $156;
      HEAP32[$157>>2] = $152;
      $158 = (($156) + 4)|0;
      $159 = $158;
      HEAP32[$159>>2] = $155;
     }
     $160 = (($150) + 8|0);
     $161 = (($$24$i) + 8|0);
     $162 = ($160|0)==($123|0);
     if ($162) {
      break;
     } else {
      $$24$i = $161;$150 = $160;
     }
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $128 = ($129|0)==($124|0);
  if ($128) {
   STACKTOP = sp;return;
  } else {
   $$11$i = $$0$lcssa$i;$132 = $129;
  }
  while(1) {
   $130 = ($$11$i|0)==(0|0);
   if (!($130)) {
    $131 = $132;
    $133 = $131;
    $134 = HEAP32[$133>>2]|0;
    $135 = (($131) + 4)|0;
    $136 = $135;
    $137 = HEAP32[$136>>2]|0;
    $138 = $$11$i;
    $139 = $138;
    HEAP32[$139>>2] = $134;
    $140 = (($138) + 4)|0;
    $141 = $140;
    HEAP32[$141>>2] = $137;
   }
   $142 = (($132) + 8|0);
   $143 = (($$11$i) + 8|0);
   $144 = ($142|0)==($124|0);
   if ($144) {
    break;
   } else {
    $$11$i = $143;$132 = $142;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__115__inplace_mergeIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_SG_T_NS_15iterator_traitsISG_E15difference_typeESK_PNSJ_10value_typeEi($__first,$__middle,$__last,$__comp,$__len1,$__len2,$__buff,$__buff_size) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len1 = $__len1|0;
 $__len2 = $__len2|0;
 $__buff = $__buff|0;
 $__buff_size = $__buff_size|0;
 var $$$i$i = 0, $$0$be = 0, $$01$be = 0, $$0172 = 0, $$073 = 0, $$11$i$i = 0, $$150 = 0, $$byval_copy6 = 0, $$byval_copy7 = 0, $$byval_copy8 = 0, $$neg2$i = 0, $$neg2$i18 = 0, $$ph$i$i = 0, $$ph12$i$i = 0, $$ph13$i$i = 0, $$pre = 0, $$sum$i = 0, $$sum$i17 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__len$0$be$i = 0, $__len$0$be$i19 = 0, $__len$03$i = 0, $__len$03$i16 = 0, $__len11$0 = 0, $__len21$0 = 0, $or$cond = 0, $scevgep$i$i = 0, $scevgep28$i$i = 0, $storemerge = 0, $uglygep$i$i = 0, $uglygep27$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 44|0;
 $$byval_copy7 = sp + 40|0;
 $$byval_copy6 = sp + 36|0;
 $0 = sp + 32|0;
 $1 = sp + 28|0;
 $2 = sp + 24|0;
 $3 = sp + 20|0;
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = sp + 16|0;
 $9 = ($__len2|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $$0172 = $__len2;$$073 = $__len1;
 L4: while(1) {
  $10 = ($$073|0)==(0);
  if ($10) {
   label = 39;
   break;
  }
  $11 = HEAP32[$__middle>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $$pre = HEAP32[$__first>>2]|0;
  $$150 = $$073;$14 = $$pre;
  while(1) {
   $13 = HEAP32[$14>>2]|0;
   $15 = ($12>>>0)<($13>>>0);
   if ($15) {
    break;
   }
   $16 = (($14) + 8|0);
   HEAP32[$__first>>2] = $16;
   $17 = (($$150) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    label = 39;
    break L4;
   } else {
    $$150 = $17;$14 = $16;
   }
  }
  $19 = ($$150|0)>($__buff_size|0);
  $20 = ($$0172|0)>($__buff_size|0);
  $or$cond = $19 & $20;
  if (!($or$cond)) {
   label = 8;
   break;
  }
  $22 = ($$150|0)<($$0172|0);
  if ($22) {
   $23 = (($$0172|0) / 2)&-1;
   $24 = (($11) + ($23<<3)|0);
   $25 = $11;
   $26 = $14;
   $27 = (($25) - ($26))|0;
   $28 = $27 >> 3;
   $29 = ($28|0)==(0);
   if ($29) {
    $40 = $14;
   } else {
    $30 = HEAP32[$24>>2]|0;
    $33 = $14;$__len$03$i16 = $28;
    while(1) {
     $31 = (($__len$03$i16|0) / 2)&-1;
     $32 = (($33) + ($31<<3)|0);
     $34 = HEAP32[$32>>2]|0;
     $35 = ($30>>>0)<($34>>>0);
     if ($35) {
      $122 = $33;$__len$0$be$i19 = $31;
     } else {
      $$sum$i17 = (($31) + 1)|0;
      $36 = (($33) + ($$sum$i17<<3)|0);
      $$neg2$i18 = (($__len$03$i16) + -1)|0;
      $37 = (($$neg2$i18) - ($31))|0;
      $122 = $36;$__len$0$be$i19 = $37;
     }
     $38 = ($__len$0$be$i19|0)==(0);
     if ($38) {
      $40 = $122;
      break;
     } else {
      $33 = $122;$__len$03$i16 = $__len$0$be$i19;
     }
    }
   }
   $39 = $40;
   $41 = (($39) - ($26))|0;
   $42 = $41 >> 3;
   $72 = $40;$74 = $24;$__len11$0 = $42;$__len21$0 = $23;
  } else {
   $43 = ($$150|0)==(1);
   if ($43) {
    label = 17;
    break;
   }
   $48 = (($$150|0) / 2)&-1;
   $49 = (($14) + ($48<<3)|0);
   $50 = HEAP32[$__last>>2]|0;
   $51 = $50;
   $52 = $11;
   $53 = (($51) - ($52))|0;
   $54 = $53 >> 3;
   $55 = ($54|0)==(0);
   if ($55) {
    $66 = $11;
   } else {
    $56 = HEAP32[$49>>2]|0;
    $59 = $11;$__len$03$i = $54;
    while(1) {
     $57 = (($__len$03$i|0) / 2)&-1;
     $58 = (($59) + ($57<<3)|0);
     $60 = HEAP32[$58>>2]|0;
     $61 = ($60>>>0)<($56>>>0);
     if ($61) {
      $$sum$i = (($57) + 1)|0;
      $62 = (($59) + ($$sum$i<<3)|0);
      $$neg2$i = (($__len$03$i) + -1)|0;
      $63 = (($$neg2$i) - ($57))|0;
      $123 = $62;$__len$0$be$i = $63;
     } else {
      $123 = $59;$__len$0$be$i = $57;
     }
     $64 = ($__len$0$be$i|0)==(0);
     if ($64) {
      $66 = $123;
      break;
     } else {
      $59 = $123;$__len$03$i = $__len$0$be$i;
     }
    }
   }
   $65 = $66;
   $67 = (($65) - ($52))|0;
   $68 = $67 >> 3;
   $72 = $49;$74 = $66;$__len11$0 = $48;$__len21$0 = $68;
  }
  $69 = (($$150) - ($__len11$0))|0;
  $70 = (($$0172) - ($__len21$0))|0;
  $71 = ($72|0)==($11|0);
  L33: do {
   if ($71) {
    $115 = $74;
   } else {
    $73 = ($11|0)==($74|0);
    if ($73) {
     $115 = $72;
    } else {
     $75 = HEAP32[$72>>2]|0;
     HEAP32[$72>>2] = $12;
     HEAP32[$11>>2] = $75;
     $76 = (($72) + 4|0);
     $77 = (($11) + 4|0);
     $78 = HEAP32[$76>>2]|0;
     $79 = HEAP32[$77>>2]|0;
     HEAP32[$76>>2] = $79;
     HEAP32[$77>>2] = $78;
     $80 = (($72) + 8|0);
     $81 = (($11) + 8|0);
     $82 = ($81|0)==($74|0);
     if ($82) {
      $101 = $80;$102 = $11;
     } else {
      $83 = $11;
      $scevgep$i$i = (($74) + -16|0);
      $84 = (0 - ($83))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($84)|0);
      $uglygep27$i$i = $uglygep$i$i;
      $86 = $80;$87 = $11;$88 = $81;
      while(1) {
       $85 = ($86|0)==($87|0);
       $$$i$i = $85 ? $88 : $87;
       $89 = HEAP32[$86>>2]|0;
       $90 = HEAP32[$88>>2]|0;
       HEAP32[$86>>2] = $90;
       HEAP32[$88>>2] = $89;
       $91 = (($86) + 4|0);
       $92 = (($88) + 4|0);
       $93 = HEAP32[$91>>2]|0;
       $94 = HEAP32[$92>>2]|0;
       HEAP32[$91>>2] = $94;
       HEAP32[$92>>2] = $93;
       $95 = (($86) + 8|0);
       $96 = (($88) + 8|0);
       $97 = ($96|0)==($74|0);
       if ($97) {
        break;
       } else {
        $86 = $95;$87 = $$$i$i;$88 = $96;
       }
      }
      $98 = $uglygep27$i$i >>> 3;
      $99 = (($98) + 2)|0;
      $scevgep28$i$i = (($72) + ($99<<3)|0);
      $101 = $scevgep28$i$i;$102 = $$$i$i;
     }
     $100 = ($101|0)==($102|0);
     if ($100) {
      $115 = $102;
     } else {
      $$ph$i$i = $102;$$ph12$i$i = $101;$$ph13$i$i = $102;
      while(1) {
       $104 = $$ph12$i$i;$106 = $$ph13$i$i;
       while(1) {
        $103 = HEAP32[$104>>2]|0;
        $105 = HEAP32[$106>>2]|0;
        HEAP32[$104>>2] = $105;
        HEAP32[$106>>2] = $103;
        $107 = (($104) + 4|0);
        $108 = (($106) + 4|0);
        $109 = HEAP32[$107>>2]|0;
        $110 = HEAP32[$108>>2]|0;
        HEAP32[$107>>2] = $110;
        HEAP32[$108>>2] = $109;
        $111 = (($104) + 8|0);
        $112 = (($106) + 8|0);
        $113 = ($112|0)==($74|0);
        $114 = ($111|0)==($$ph$i$i|0);
        if (!($113)) {
         break;
        }
        if ($114) {
         $115 = $101;
         break L33;
        } else {
         $104 = $111;$106 = $$ph$i$i;
        }
       }
       $$11$i$i = $114 ? $112 : $$ph$i$i;
       $$ph$i$i = $$11$i$i;$$ph12$i$i = $111;$$ph13$i$i = $112;
      }
     }
    }
   }
  } while(0);
  HEAP32[$__middle>>2] = $115;
  $116 = (($__len21$0) + ($__len11$0))|0;
  $117 = (($70) + ($69))|0;
  $118 = ($116|0)<($117|0);
  if ($118) {
   $119 = HEAP32[$__first>>2]|0;
   HEAP32[$3>>2] = $119;
   HEAP32[$4>>2] = $72;
   HEAP32[$5>>2] = $115;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$5+0>>2]|0;
   __ZNSt3__115__inplace_mergeIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_SG_T_NS_15iterator_traitsISG_E15difference_typeESK_PNSJ_10value_typeEi($$byval_copy6,$$byval_copy7,$$byval_copy8,$__comp,$__len11$0,$__len21$0,$__buff,$__buff_size);
   HEAP32[$__first>>2] = $115;
   $$0$be = $69;$$01$be = $70;$storemerge = $74;
  } else {
   HEAP32[$6>>2] = $115;
   HEAP32[$7>>2] = $74;
   $120 = HEAP32[$__last>>2]|0;
   HEAP32[$8>>2] = $120;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$6+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$7+0>>2]|0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$8+0>>2]|0;
   __ZNSt3__115__inplace_mergeIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_SG_T_NS_15iterator_traitsISG_E15difference_typeESK_PNSJ_10value_typeEi($$byval_copy6,$$byval_copy7,$$byval_copy8,$__comp,$69,$70,$__buff,$__buff_size);
   HEAP32[$__last>>2] = $115;
   $$0$be = $__len11$0;$$01$be = $__len21$0;$storemerge = $72;
  }
  HEAP32[$__middle>>2] = $storemerge;
  $121 = ($$01$be|0)==(0);
  if ($121) {
   label = 39;
   break;
  } else {
   $$0172 = $$01$be;$$073 = $$0$be;
  }
 }
 if ((label|0) == 8) {
  HEAP32[$0>>2] = $14;
  HEAP32[$1>>2] = $11;
  $21 = HEAP32[$__last>>2]|0;
  HEAP32[$2>>2] = $21;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
  __ZNSt3__124__buffered_inplace_mergeIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_SG_T_NS_15iterator_traitsISG_E15difference_typeESK_PNSJ_10value_typeE($$byval_copy6,$$byval_copy7,$$byval_copy8,$__comp,$$150,$$0172,$__buff);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 17) {
  HEAP32[$14>>2] = $12;
  HEAP32[$11>>2] = $13;
  $44 = (($14) + 4|0);
  $45 = (($11) + 4|0);
  $46 = HEAP32[$44>>2]|0;
  $47 = HEAP32[$45>>2]|0;
  HEAP32[$44>>2] = $47;
  HEAP32[$45>>2] = $46;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 39) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__124__buffered_inplace_mergeIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_SG_T_NS_15iterator_traitsISG_E15difference_typeESK_PNSJ_10value_typeE($__first,$__middle,$__last,$__comp,$__len1,$__len2,$__buff) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len1 = $__len1|0;
 $__len2 = $__len2|0;
 $__buff = $__buff|0;
 var $$c$i$i = 0, $$c$i$i$i$i = 0, $$c$i$i$i$i$i = 0, $$c$i$i$i24$i = 0, $$c$i$i14$i = 0, $$lcssa$i = 0, $$lcssa109 = 0, $$lcssa35$off32$i = 0, $$off32$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0121 = 0, $__p1$0$lcssa = 0, $__p1$0110 = 0, $scevgep = 0, $scevgep137 = 0, $scevgep145 = 0;
 var $scevgep149 = 0, $uglygep = 0, $uglygep136 = 0, $uglygep147 = 0, $uglygep147148 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__len1|0)>($__len2|0);
 if ($0) {
  $65 = HEAP32[$__middle>>2]|0;
  $66 = $65;
  $67 = HEAP32[$__last>>2]|0;
  $68 = ($65|0)==($67|0);
  if ($68) {
   $$lcssa109 = $65;$__p1$0$lcssa = $__buff;
  } else {
   $scevgep = (($67) + -8|0);
   $69 = (0 - ($66))|0;
   $uglygep = (($scevgep) + ($69)|0);
   $uglygep136 = $uglygep;
   $70 = $uglygep136 >>> 3;
   $71 = (($70) + 1)|0;
   $74 = $65;$__p1$0110 = $__buff;
   while(1) {
    $72 = ($__p1$0110|0)==(0|0);
    if (!($72)) {
     $73 = $74;
     $75 = $73;
     $76 = HEAP32[$75>>2]|0;
     $77 = (($73) + 4)|0;
     $78 = $77;
     $79 = HEAP32[$78>>2]|0;
     $80 = $__p1$0110;
     $81 = $80;
     HEAP32[$81>>2] = $76;
     $82 = (($80) + 4)|0;
     $83 = $82;
     HEAP32[$83>>2] = $79;
    }
    $84 = (($74) + 8|0);
    $85 = (($__p1$0110) + 8|0);
    $86 = ($84|0)==($67|0);
    if ($86) {
     break;
    } else {
     $74 = $84;$__p1$0110 = $85;
    }
   }
   $scevgep137 = (($__buff) + ($71<<3)|0);
   $$lcssa109 = $67;$__p1$0$lcssa = $scevgep137;
  }
  $87 = HEAP32[$__first>>2]|0;
  $88 = $$lcssa109;
  $89 = ($65|0)==($87|0);
  $90 = $__p1$0$lcssa;
  L12: do {
   if ($89) {
    $$lcssa35$off32$i = $90;$144 = $88;
   } else {
    $$off32$i = $90;$108 = $__p1$0$lcssa;$109 = $66;$114 = $88;$94 = $65;
    while(1) {
     $91 = $$off32$i;
     $92 = ($91|0)==($__buff|0);
     if ($92) {
      break;
     }
     $107 = (($108) + -8|0);
     $$c$i$i14$i = $109;
     $110 = (($$c$i$i14$i) + -8|0);
     $111 = HEAP32[$107>>2]|0;
     $112 = HEAP32[$110>>2]|0;
     $113 = ($111>>>0)<($112>>>0);
     $$c$i$i = $114;
     $115 = (($$c$i$i) + -8|0);
     if ($113) {
      HEAP32[$115>>2] = $112;
      $119 = (($$c$i$i14$i) + -4|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = (($$c$i$i) + -4|0);
      HEAP32[$121>>2] = $120;
      $122 = $110;
      $125 = $122;$128 = $108;
     } else {
      HEAP32[$115>>2] = $111;
      $116 = (($108) + -4|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = (($$c$i$i) + -4|0);
      HEAP32[$118>>2] = $117;
      $125 = $109;$128 = $107;
     }
     $123 = $115;
     $124 = $125;
     $126 = ($124|0)==($87|0);
     $127 = $128;
     if ($126) {
      $$lcssa35$off32$i = $127;$144 = $123;
      break L12;
     } else {
      $$off32$i = $127;$108 = $128;$109 = $125;$114 = $123;$94 = $124;
     }
    }
    $93 = ($94|0)==($87|0);
    if ($93) {
     STACKTOP = sp;return;
    } else {
     $95 = $114;$97 = $109;
    }
    while(1) {
     $$c$i$i$i24$i = $95;
     $96 = (($$c$i$i$i24$i) + -8|0);
     $$c$i$i$i$i$i = $97;
     $98 = (($$c$i$i$i$i$i) + -8|0);
     $99 = HEAP32[$98>>2]|0;
     HEAP32[$96>>2] = $99;
     $100 = (($$c$i$i$i$i$i) + -4|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (($$c$i$i$i24$i) + -4|0);
     HEAP32[$102>>2] = $101;
     $103 = (($$c$i$i$i$i$i) + -8|0);
     $104 = $103;
     $105 = $96;
     $106 = ($103|0)==($87|0);
     if ($106) {
      break;
     } else {
      $95 = $105;$97 = $104;
     }
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $129 = $$lcssa35$off32$i;
  $130 = ($129|0)==($__buff|0);
  if ($130) {
   STACKTOP = sp;return;
  } else {
   $131 = $144;$134 = $129;
  }
  while(1) {
   $$c$i$i$i$i = $131;
   $132 = (($$c$i$i$i$i) + -8|0);
   $133 = (($134) + -8|0);
   $135 = HEAP32[$133>>2]|0;
   HEAP32[$132>>2] = $135;
   $136 = (($134) + -4|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = (($$c$i$i$i$i) + -4|0);
   HEAP32[$138>>2] = $137;
   $139 = (($134) + -8|0);
   $140 = $132;
   $141 = ($139|0)==($__buff|0);
   if ($141) {
    break;
   } else {
    $131 = $140;$134 = $139;
   }
  }
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__first>>2]|0;
  $2 = HEAP32[$__middle>>2]|0;
  $3 = ($1|0)==($2|0);
  L33: do {
   if ($3) {
    $4 = HEAP32[$__last>>2]|0;
    $$lcssa$i = $1;$142 = $1;$55 = $4;
   } else {
    $5 = $1;
    $scevgep145 = (($2) + -8|0);
    $6 = (0 - ($5))|0;
    $uglygep147 = (($scevgep145) + ($6)|0);
    $uglygep147148 = $uglygep147;
    $7 = $uglygep147148 >>> 3;
    $8 = (($7) + 1)|0;
    $11 = $1;$__p$0121 = $__buff;
    while(1) {
     $9 = ($__p$0121|0)==(0|0);
     if (!($9)) {
      $10 = $11;
      $12 = $10;
      $13 = HEAP32[$12>>2]|0;
      $14 = (($10) + 4)|0;
      $15 = $14;
      $16 = HEAP32[$15>>2]|0;
      $17 = $__p$0121;
      $18 = $17;
      HEAP32[$18>>2] = $13;
      $19 = (($17) + 4)|0;
      $20 = $19;
      HEAP32[$20>>2] = $16;
     }
     $21 = (($11) + 8|0);
     $22 = (($__p$0121) + 8|0);
     $23 = ($21|0)==($2|0);
     if ($23) {
      break;
     } else {
      $11 = $21;$__p$0121 = $22;
     }
    }
    $scevgep149 = (($__buff) + ($8<<3)|0);
    $24 = HEAP32[$__last>>2]|0;
    $25 = ($scevgep149|0)==($__buff|0);
    if ($25) {
     $$lcssa$i = $2;$142 = $1;$55 = $24;
    } else {
     $27 = $2;$29 = $__buff;$42 = $1;
     while(1) {
      $26 = ($27|0)==($24|0);
      if ($26) {
       break;
      }
      $39 = HEAP32[$27>>2]|0;
      $40 = HEAP32[$29>>2]|0;
      $41 = ($39>>>0)<($40>>>0);
      if ($41) {
       HEAP32[$42>>2] = $39;
       $43 = (($27) + 4|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = (($42) + 4|0);
       HEAP32[$45>>2] = $44;
       $46 = (($27) + 8|0);
       $143 = $46;$53 = $29;
      } else {
       HEAP32[$42>>2] = $40;
       $47 = (($29) + 4|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = (($42) + 4|0);
       HEAP32[$49>>2] = $48;
       $50 = (($29) + 8|0);
       $143 = $27;$53 = $50;
      }
      $51 = (($42) + 8|0);
      $52 = ($53|0)==($scevgep149|0);
      if ($52) {
       $$lcssa$i = $143;$142 = $51;$55 = $24;
       break L33;
      } else {
       $27 = $143;$29 = $53;$42 = $51;
      }
     }
     $28 = ($29|0)==($scevgep149|0);
     if ($28) {
      STACKTOP = sp;return;
     } else {
      $31 = $29;$32 = $42;
     }
     while(1) {
      $30 = HEAP32[$31>>2]|0;
      HEAP32[$32>>2] = $30;
      $33 = (($31) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($32) + 4|0);
      HEAP32[$35>>2] = $34;
      $36 = (($31) + 8|0);
      $37 = (($32) + 8|0);
      $38 = ($36|0)==($scevgep149|0);
      if ($38) {
       break;
      } else {
       $31 = $36;$32 = $37;
      }
     }
     STACKTOP = sp;return;
    }
   }
  } while(0);
  $54 = ($$lcssa$i|0)==($55|0);
  if ($54) {
   STACKTOP = sp;return;
  } else {
   $57 = $$lcssa$i;$58 = $142;
  }
  while(1) {
   $56 = HEAP32[$57>>2]|0;
   HEAP32[$58>>2] = $56;
   $59 = (($57) + 4|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($58) + 4|0);
   HEAP32[$61>>2] = $60;
   $62 = (($57) + 8|0);
   $63 = (($58) + 8|0);
   $64 = ($62|0)==($55|0);
   if ($64) {
    break;
   } else {
    $57 = $62;$58 = $63;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIP14ScriptingClassNS_9allocatorIS2_EEE8__appendEjRKS2_($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $13 = 0;
   } else {
    $11 = HEAP32[$__x>>2]|0;
    HEAP32[$10>>2] = $11;
    $$pre1$i = HEAP32[$2>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 4|0);
   HEAP32[$2>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$10 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($5) - ($17))|0;
 $19 = $18 >> 2;
 $20 = (($19) + ($__n))|0;
 $21 = ($20>>>0)>(1073741823);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($4) - ($17))|0;
 $23 = $22 >> 2;
 $24 = ($23>>>0)<(536870911);
 if ($24) {
  $25 = $22 >> 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 1073741823;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = $$0$i56 << 2;
  $30 = (__Znwj($29)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + ($19<<2)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $37 = 0;
  } else {
   $35 = HEAP32[$__x>>2]|0;
   HEAP32[$34>>2] = $35;
   $37 = $34;
  }
  $36 = (($37) + 4|0);
  $38 = (($$0$i2) + -1)|0;
  $39 = ($38|0)==(0);
  if ($39) {
   break;
  } else {
   $$0$i2 = $38;$34 = $36;
  }
 }
 $40 = (($32) + ($$0$i57<<2)|0);
 $41 = HEAP32[$this>>2]|0;
 $42 = HEAP32[$2>>2]|0;
 $43 = $42;
 $44 = $41;
 $45 = (($43) - ($44))|0;
 $46 = $45 >> 2;
 $$sum = (($19) - ($46))|0;
 $47 = (($32) + ($$sum<<2)|0);
 _memcpy(($47|0),($41|0),($45|0))|0;
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $36;
 HEAP32[$0>>2] = $40;
 $48 = ($41|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($41);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIiP15MonoScriptCacheEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiP15MonoScriptCacheEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiP15MonoScriptCacheEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier69ELi16EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$4);
 HEAP32[$0>>2] = 69;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  ___cxa_call_unexpected(($7|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN9TextAssetC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((637792 + 8|0));
 $2 = (($this) + 28|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN9TextAsset15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9TextAsset13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9TextAsset18SetScriptDontDirtyERK8UnityStr($this,$script) {
 $this = $this|0;
 $script = $script|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($0,$script)|0);
 STACKTOP = sp;return;
}
function __ZN9TextAsset9SetScriptERK8UnityStr($this,$script) {
 $this = $this|0;
 $script = $script|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 2047]($this,$script,0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN9TextAsset9SetScriptERK8UnityStrb($this,$script,$actuallyContainsBinaryData) {
 $this = $this|0;
 $script = $script|0;
 $actuallyContainsBinaryData = $actuallyContainsBinaryData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($0,$script)|0);
 STACKTOP = sp;return 1;
}
function __ZNK9TextAsset18GetScriptClassNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[637920>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (637904|0);
 }
 ;HEAP32[637904+0>>2]=0|0;HEAP32[637904+4>>2]=0|0;HEAP32[637904+8>>2]=0|0;
 HEAP8[637920>>0] = 1;
 STACKTOP = sp;return (637904|0);
}
function __Z23RegisterClass_TextAssetv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(49,180,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9TextAsset13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=637928+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,49,130,($0|0),52,(2443|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN9TextAsset7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(52,$$byval_copy2,1,16,637992,14)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1685,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((637792 + 8|0));
  $6 = (($3) + 28|0);
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;
  STACKTOP = sp;return ($3|0);
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(637992|0),14);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK9TextAsset25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 49;
}
function __ZN9TextAsset23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,637944,637928,$this,0);
 __ZN9TextAsset8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,637944,637928,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9TextAsset8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $1 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $1 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $1 = (($this) + 28|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i2 = 0, $size$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i1 = sp;
 $p$i$i$i2 = sp + 4|0;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,637952,$1,$0,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,638000,638000,$size$i$i$i$i1,1);
 $2 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,637984,$2,$p$i$i$i2,0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,637968,$1,$9,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,638000,638000,$size$i$i$i$i1,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,637984,$2,$p$i$i$i2,0);
 $10 = HEAP32[$3>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$6>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = HEAP32[580712>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,637952,$1,$converter$i$i1,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 28|0);
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,637968,$1,$converter$i$i1,0)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$7,0);
 } else {
  $11 = HEAP32[$converter$i$i1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (FUNCTION_TABLE_iii[$11 & 4095]($7,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $1 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $1 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $1 = (($this) + 28|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9TextAsset8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Scripting19ScriptingWrapperForEP6Object($o) {
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($o|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (($o) + 20|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    $4 = (($o) + 8|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = $5 >>> 21;
    $7 = ($6|0)==(114);
    if ($7) {
     $$0 = 0;
    } else {
     $8 = (__ZN9Scripting37InstantiateScriptingWrapperForClassIDEi($6)|0);
     $9 = ($8|0)==(0|0);
     if ($9) {
      $$0 = 0;
     } else {
      $10 = HEAP32[$1>>2]|0;
      $11 = ($10|0)==(0|0);
      if ($11) {
       __ZN9Scripting30SetCachedPtrOnScriptingWrapperEP15ScriptingObjectPv($8,$o);
       $12 = (($o) + 4|0);
       $13 = HEAP32[$12>>2]|0;
       __ZN9Scripting31SetInstanceIDOnScriptingWrapperEP15ScriptingObjecti($8,$13);
       $14 = HEAP32[$o>>2]|0;
       $15 = (($14) + 56|0);
       $16 = HEAP32[$15>>2]|0;
       FUNCTION_TABLE_vii[$16 & 4095]($o,$8);
       $$0 = $8;
       break;
      } else {
       $$0 = $10;
       break;
      }
     }
    }
   } else {
    $$0 = $2;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Scripting31ConnectScriptingWrapperToObjectEP15ScriptingObjectP6Object($object,$ptr) {
 $object = $object|0;
 $ptr = $ptr|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ptr) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Scripting30SetCachedPtrOnScriptingWrapperEP15ScriptingObjectPv($object,$ptr);
  $3 = (($ptr) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __ZN9Scripting31SetInstanceIDOnScriptingWrapperEP15ScriptingObjecti($object,$4);
  $5 = HEAP32[$ptr>>2]|0;
  $6 = (($5) + 56|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 4095]($ptr,$object);
  $$0 = $object;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9Scripting9GetMethodEPKcS1_S1_S1_($agg$result,$assembly,$namespaze,$klassName,$methodName) {
 $agg$result = $agg$result|0;
 $assembly = $assembly|0;
 $namespaze = $namespaze|0;
 $klassName = $klassName|0;
 $methodName = $methodName|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z29scripting_class_from_fullnamePKcS0_S0_($assembly,$namespaze,$klassName)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = 599912;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $agg$result;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  STACKTOP = sp;return;
 } else {
  __Z36scripting_class_get_method_from_nameP14ScriptingClassPKci($agg$result,$0,$methodName,-1);
  STACKTOP = sp;return;
 }
}
function __ZN9Scripting26GetMethodWithSearchOptionsEP14ScriptingClassPKci($agg$result,$klass,$methodName,$searchFilter) {
 $agg$result = $agg$result|0;
 $klass = $klass|0;
 $methodName = $methodName|0;
 $searchFilter = $searchFilter|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scriptingMethod = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scriptingMethod = sp;
 $0 = sp + 8|0;
 $1 = ($klass|0)==(0|0);
 if ($1) {
  $2 = 599912;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $agg$result;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  STACKTOP = sp;return;
 }
 __Z43scripting_class_get_method_from_name_filterP14ScriptingClassPKcii($scriptingMethod,$klass,$methodName,-1,$searchFilter);
 $12 = HEAP32[$scriptingMethod>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $14 = $searchFilter & 8;
  $15 = ($14|0)==(0);
  if ($15) {
   $16 = (__Z26scripting_class_get_parentP14ScriptingClass($klass)|0);
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    __ZN9Scripting26GetMethodWithSearchOptionsEP14ScriptingClassPKci($0,$16,$methodName,$searchFilter);
    ;HEAP32[$scriptingMethod+0>>2]=HEAP32[$0+0>>2]|0;HEAP8[$scriptingMethod+4>>0]=HEAP8[$0+4>>0]|0;
   }
  }
 }
 $18 = $scriptingMethod;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $agg$result;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN9Scripting20SendScriptingMessageERN5Unity10GameObjectEPKcP15ScriptingObject($go,$name,$param) {
 $go = $go|0;
 $name = $name|0;
 $param = $param|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $didSend$0$off07 = 0, $didSend$1$off0 = 0, $i$06 = 0, $i$06$us = 0, $method = 0, $tmpcast$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy1 = sp + 24|0;
 $0 = sp + 16|0;
 $method = sp;
 $1 = sp + 8|0;
 $2 = (__ZNK5Unity10GameObject8IsActiveEv($go)|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($go) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($go) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(0);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($go) + 24|0);
 $9 = ($4|0)==(0);
 if ($9) {
  $i$06$us = 0;
  while(1) {
   $10 = HEAP32[$8>>2]|0;
   $11 = (($10) + ($i$06$us<<3)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(114);
   if ($13) {
    $14 = ((($10) + ($i$06$us<<3)|0) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($15) + 20|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if (!($18)) {
     __ZN13MonoBehaviour10FindMethodEPKc($method,$15,$name);
     $19 = HEAP32[$method>>2]|0;
     $20 = ($19|0)==(0|0);
     if (!($20)) {
      break;
     }
    }
   }
   $21 = (($i$06$us) + 1)|0;
   $22 = HEAP32[$5>>2]|0;
   $23 = ($21|0)<($22|0);
   if ($23) {
    $i$06$us = $21;
   } else {
    $$0 = 0;
    label = 22;
    break;
   }
  }
  if ((label|0) == 22) {
   STACKTOP = sp;return ($$0|0);
  }
  $24 = $method;
  $25 = $24;
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 4)|0;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = $1;
  $31 = $30;
  HEAP32[$31>>2] = $26;
  $32 = (($30) + 4)|0;
  $33 = $32;
  HEAP32[$33>>2] = $29;
  ;HEAP32[$tmpcast$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
  (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($15,$tmpcast$byval_copy1,$param)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $didSend$0$off07 = 0;$i$06 = 0;
 }
 L18: while(1) {
  $34 = HEAP32[$8>>2]|0;
  $35 = (($34) + ($i$06<<3)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(114);
  do {
   if ($37) {
    $38 = ((($34) + ($i$06<<3)|0) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     $didSend$1$off0 = $didSend$0$off07;
    } else {
     __ZN13MonoBehaviour10FindMethodEPKc($method,$39,$name);
     $43 = HEAP32[$method>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      $didSend$1$off0 = $didSend$0$off07;
     } else {
      $45 = $method;
      $46 = $45;
      $47 = HEAP32[$46>>2]|0;
      $48 = (($45) + 4)|0;
      $49 = $48;
      $50 = HEAP32[$49>>2]|0;
      $51 = $1;
      $52 = $51;
      HEAP32[$52>>2] = $47;
      $53 = (($51) + 4)|0;
      $54 = $53;
      HEAP32[$54>>2] = $50;
      ;HEAP32[$tmpcast$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
      (__ZN13MonoBehaviour30InvokeMethodOrCoroutineCheckedE21ScriptingMethodIl2CppP15ScriptingObject($39,$tmpcast$byval_copy1,$param)|0);
      HEAP32[$0>>2] = $4;
      $55 = HEAP32[560624>>2]|0;
      $56 = ($55|0)==(0|0);
      if (!($56)) {
       $57 = (($55) + 36|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($55) + 4|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ($58|0)==($60|0);
       do {
        if ($61) {
         $62 = (($55) + 28|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = (($55) + 32|0);
         $65 = HEAP32[$64>>2]|0;
         $66 = (($63) + ($65<<3)|0);
         $82 = $66;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast$byval_copy1,$55,$0);
         $67 = HEAP32[$tmpcast$byval_copy1>>2]|0;
         $68 = ($67|0)==(-1);
         $69 = (($55) + 28|0);
         $70 = HEAP32[$69>>2]|0;
         if ($68) {
          $71 = (($55) + 32|0);
          $72 = HEAP32[$71>>2]|0;
          $73 = (($70) + ($72<<3)|0);
          $82 = $73;
          break;
         } else {
          $74 = (($70) + ($67<<3)|0);
          $82 = $74;
          break;
         }
        }
       } while(0);
       $75 = HEAP32[560624>>2]|0;
       $76 = (($75) + 28|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = (($75) + 32|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = (($77) + ($79<<3)|0);
       $81 = ($82|0)==($80|0);
       if (!($81)) {
        $83 = (($82) + 4|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = ($84|0)==(0|0);
        if (!($85)) {
         $didSend$1$off0 = 1;
         break;
        }
       }
      }
      $86 = (__Z31ReadObjectFromPersistentManageri($4)|0);
      $87 = ($86|0)==(0|0);
      if ($87) {
       $$0 = 1;
       label = 22;
       break L18;
      } else {
       $didSend$1$off0 = 1;
      }
     }
    }
   } else {
    $didSend$1$off0 = $didSend$0$off07;
   }
  } while(0);
  $88 = (($i$06) + 1)|0;
  $89 = HEAP32[$5>>2]|0;
  $90 = ($88|0)<($89|0);
  if ($90) {
   $didSend$0$off07 = $didSend$1$off0;$i$06 = $88;
  } else {
   $$0 = $didSend$1$off0;
   label = 22;
   break;
  }
 }
 if ((label|0) == 22) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9Scripting20SendScriptingMessageERN5Unity10GameObjectERKNSt3__112basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEEP15ScriptingObjecti($go,$methodName,$param,$options) {
 $go = $go|0;
 $methodName = $methodName|0;
 $param = $param|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$methodName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($methodName) + 1|0);
  $6 = $5;
 } else {
  $3 = (($methodName) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 $7 = (__ZN9Scripting20SendScriptingMessageERN5Unity10GameObjectEPKcP15ScriptingObject($go,$6,$param)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN9Scripting26DestroyObjectFromScriptingE4PPtrI6ObjectEf($object,$t) {
 $object = $object|0;
 $t = Math_fround($t);
 var $$0$i5 = 0, $$pre = 0, $$pre$i = 0, $$pre$i10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $childIndex$014 = 0, $compI$01$i = 0, $compI$01$i8 = 0, $pos$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (__Z14IsWorldPlayingv()|0);
 if (!($2)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(638008,0,638200,298,1,0,0,0);
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$object>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $3;
 $5 = HEAP32[560624>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 12;
 } else {
  $7 = (($5) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  do {
   if ($11) {
    $12 = (($5) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($5) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + ($15<<3)|0);
    $32 = $16;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$5,$1);
    $17 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $18 = ($17|0)==(-1);
    $19 = (($5) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    if ($18) {
     $21 = (($5) + 32|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + ($22<<3)|0);
     $32 = $23;
     break;
    } else {
     $24 = (($20) + ($17<<3)|0);
     $32 = $24;
     break;
    }
   }
  } while(0);
  $25 = HEAP32[560624>>2]|0;
  $26 = (($25) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 32|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + ($29<<3)|0);
  $31 = ($32|0)==($30|0);
  if ($31) {
   label = 12;
  } else {
   $33 = (($32) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    label = 12;
   }
  }
 }
 if ((label|0) == 12) {
  $36 = HEAP32[$object>>2]|0;
  $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   STACKTOP = sp;return;
  }
 }
 $39 = !($t <= Math_fround(0.0));
 if (!($39)) {
  $40 = (__Z17dynamic_pptr_castIP9Behaviour6ObjectET_RK4PPtrIT0_E($object)|0);
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   $42 = HEAP32[$40>>2]|0;
   $43 = (($42) + 120|0);
   $44 = HEAP32[$43>>2]|0;
   FUNCTION_TABLE_vii[$44 & 4095]($40,0);
  }
  $45 = (__Z17dynamic_pptr_castIPN5Unity10GameObjectE6ObjectET_RK4PPtrIT0_E($object)|0);
  $46 = ($45|0)==(0|0);
  if (!($46)) {
   $47 = (($45) + 32|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0);
   if (!($49)) {
    $50 = (($45) + 24|0);
    $153 = $48;$compI$01$i = 0;
    while(1) {
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($51) + ($compI$01$i<<3)|0) + 4|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)==(0|0);
     if ($54) {
      $75 = $153;
     } else {
      $55 = (($53) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = $56 >>> 21;
      $58 = HEAP32[560640>>2]|0;
      $59 = Math_imul($58, $57)|0;
      $60 = (($59) + 8)|0;
      $61 = $60 >> 5;
      $62 = $61 << 5;
      $63 = (($60) - ($62))|0;
      $64 = HEAP32[560632>>2]|0;
      $65 = (($64) + ($61<<2)|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = 1 << $63;
      $68 = $67 & $66;
      $69 = ($68|0)==(0);
      if ($69) {
       $75 = $153;
      } else {
       $70 = HEAP32[$53>>2]|0;
       $71 = (($70) + 120|0);
       $72 = HEAP32[$71>>2]|0;
       FUNCTION_TABLE_vii[$72 & 4095]($53,0);
       $$pre$i = HEAP32[$47>>2]|0;
       $75 = $$pre$i;
      }
     }
     $73 = (($compI$01$i) + 1)|0;
     $74 = ($73>>>0)<($75>>>0);
     if ($74) {
      $153 = $75;$compI$01$i = $73;
     } else {
      break;
     }
    }
   }
   $76 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($45)|0);
   $77 = (($76) + 148|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)>(0);
   if ($79) {
    $80 = (($76) + 140|0);
    $154 = $78;$childIndex$014 = 0;
    while(1) {
     $81 = HEAP32[$80>>2]|0;
     $82 = (($81) + ($childIndex$014<<2)|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (($83) + 24|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = (($85) + 32|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = ($87|0)==(0);
     if ($88) {
      $117 = $154;
     } else {
      $89 = (($85) + 24|0);
      $155 = $87;$compI$01$i8 = 0;
      while(1) {
       $90 = HEAP32[$89>>2]|0;
       $91 = ((($90) + ($compI$01$i8<<3)|0) + 4|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = ($92|0)==(0|0);
       if ($93) {
        $114 = $155;
       } else {
        $94 = (($92) + 8|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = $95 >>> 21;
        $97 = HEAP32[560640>>2]|0;
        $98 = Math_imul($97, $96)|0;
        $99 = (($98) + 8)|0;
        $100 = $99 >> 5;
        $101 = $100 << 5;
        $102 = (($99) - ($101))|0;
        $103 = HEAP32[560632>>2]|0;
        $104 = (($103) + ($100<<2)|0);
        $105 = HEAP32[$104>>2]|0;
        $106 = 1 << $102;
        $107 = $106 & $105;
        $108 = ($107|0)==(0);
        if ($108) {
         $114 = $155;
        } else {
         $109 = HEAP32[$92>>2]|0;
         $110 = (($109) + 120|0);
         $111 = HEAP32[$110>>2]|0;
         FUNCTION_TABLE_vii[$111 & 4095]($92,0);
         $$pre$i10 = HEAP32[$86>>2]|0;
         $114 = $$pre$i10;
        }
       }
       $112 = (($compI$01$i8) + 1)|0;
       $113 = ($112>>>0)<($114>>>0);
       if ($113) {
        $155 = $114;$compI$01$i8 = $112;
       } else {
        break;
       }
      }
      $$pre = HEAP32[$77>>2]|0;
      $117 = $$pre;
     }
     $115 = (($childIndex$014) + 1)|0;
     $116 = ($115|0)<($117|0);
     if ($116) {
      $154 = $117;$childIndex$014 = $115;
     } else {
      break;
     }
    }
   }
  }
 }
 $118 = HEAP32[$object>>2]|0;
 $119 = ($118|0)==(0);
 do {
  if ($119) {
   $$0$i5 = 0;
  } else {
   HEAP32[$0>>2] = $118;
   $120 = HEAP32[560624>>2]|0;
   $121 = ($120|0)==(0|0);
   if (!($121)) {
    $122 = (($120) + 36|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = (($120) + 4|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ($123|0)==($125|0);
    do {
     if ($126) {
      $127 = (($120) + 28|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = (($120) + 32|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = (($128) + ($130<<3)|0);
      $147 = $131;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$120,$0);
      $132 = HEAP32[$pos$i$i$i$i1>>2]|0;
      $133 = ($132|0)==(-1);
      $134 = (($120) + 28|0);
      $135 = HEAP32[$134>>2]|0;
      if ($133) {
       $136 = (($120) + 32|0);
       $137 = HEAP32[$136>>2]|0;
       $138 = (($135) + ($137<<3)|0);
       $147 = $138;
       break;
      } else {
       $139 = (($135) + ($132<<3)|0);
       $147 = $139;
       break;
      }
     }
    } while(0);
    $140 = HEAP32[560624>>2]|0;
    $141 = (($140) + 28|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = (($140) + 32|0);
    $144 = HEAP32[$143>>2]|0;
    $145 = (($142) + ($144<<3)|0);
    $146 = ($147|0)==($145|0);
    if (!($146)) {
     $148 = (($147) + 4|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ($149|0)==(0|0);
     if (!($150)) {
      $$0$i5 = $149;
      break;
     }
    }
   }
   $151 = HEAP32[$object>>2]|0;
   $152 = (__Z31ReadObjectFromPersistentManageri($151)|0);
   $$0$i5 = $152;
  }
 } while(0);
 __Z20DestroyObjectDelayedP6Objectf($$0$i5,$t);
 STACKTOP = sp;return;
}
function __Z17dynamic_pptr_castIP9Behaviour6ObjectET_RK4PPtrIT0_E($ptr) {
 $ptr = $ptr|0;
 var $$0$i1 = 0, $$0$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$ptr>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if (!($2)) {
   HEAP32[$0>>2] = $1;
   $3 = HEAP32[560624>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    label = 10;
   } else {
    $5 = (($3) + 36|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($3) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($6|0)==($8|0);
    do {
     if ($9) {
      $10 = (($3) + 28|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (($3) + 32|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($11) + ($13<<3)|0);
      $30 = $14;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
      $15 = HEAP32[$pos$i$i$i$i>>2]|0;
      $16 = ($15|0)==(-1);
      $17 = (($3) + 28|0);
      $18 = HEAP32[$17>>2]|0;
      if ($16) {
       $19 = (($3) + 32|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($18) + ($20<<3)|0);
       $30 = $21;
       break;
      } else {
       $22 = (($18) + ($15<<3)|0);
       $30 = $22;
       break;
      }
     }
    } while(0);
    $23 = HEAP32[560624>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + ($27<<3)|0);
    $29 = ($30|0)==($28|0);
    if ($29) {
     label = 10;
    } else {
     $31 = (($30) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      label = 10;
     } else {
      $$0$i3 = $32;
     }
    }
   }
   if ((label|0) == 10) {
    $34 = HEAP32[$ptr>>2]|0;
    $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
    $36 = ($35|0)==(0|0);
    if ($36) {
     break;
    } else {
     $$0$i3 = $35;
    }
   }
   $37 = (($$0$i3) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38 >>> 21;
   $40 = HEAP32[560640>>2]|0;
   $41 = Math_imul($40, $39)|0;
   $42 = (($41) + 8)|0;
   $43 = $42 >> 5;
   $44 = $43 << 5;
   $45 = (($42) - ($44))|0;
   $46 = HEAP32[560632>>2]|0;
   $47 = (($46) + ($43<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = 1 << $45;
   $50 = $49 & $48;
   $51 = ($50|0)==(0);
   if (!($51)) {
    $$0$i1 = $$0$i3;
    STACKTOP = sp;return ($$0$i1|0);
   }
  }
 } while(0);
 $$0$i1 = 0;
 STACKTOP = sp;return ($$0$i1|0);
}
function __Z17dynamic_pptr_castIPN5Unity10GameObjectE6ObjectET_RK4PPtrIT0_E($ptr) {
 $ptr = $ptr|0;
 var $$0$i1 = 0, $$0$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$ptr>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if (!($2)) {
   HEAP32[$0>>2] = $1;
   $3 = HEAP32[560624>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    label = 10;
   } else {
    $5 = (($3) + 36|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($3) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($6|0)==($8|0);
    do {
     if ($9) {
      $10 = (($3) + 28|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (($3) + 32|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($11) + ($13<<3)|0);
      $30 = $14;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
      $15 = HEAP32[$pos$i$i$i$i>>2]|0;
      $16 = ($15|0)==(-1);
      $17 = (($3) + 28|0);
      $18 = HEAP32[$17>>2]|0;
      if ($16) {
       $19 = (($3) + 32|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($18) + ($20<<3)|0);
       $30 = $21;
       break;
      } else {
       $22 = (($18) + ($15<<3)|0);
       $30 = $22;
       break;
      }
     }
    } while(0);
    $23 = HEAP32[560624>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + ($27<<3)|0);
    $29 = ($30|0)==($28|0);
    if ($29) {
     label = 10;
    } else {
     $31 = (($30) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      label = 10;
     } else {
      $$0$i3 = $32;
     }
    }
   }
   if ((label|0) == 10) {
    $34 = HEAP32[$ptr>>2]|0;
    $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
    $36 = ($35|0)==(0|0);
    if ($36) {
     break;
    } else {
     $$0$i3 = $35;
    }
   }
   $37 = (($$0$i3) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38 >>> 21;
   $40 = HEAP32[560640>>2]|0;
   $41 = Math_imul($40, $39)|0;
   $42 = (($41) + 1)|0;
   $43 = $42 >> 5;
   $44 = $43 << 5;
   $45 = (($42) - ($44))|0;
   $46 = HEAP32[560632>>2]|0;
   $47 = (($46) + ($43<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = 1 << $45;
   $50 = $49 & $48;
   $51 = ($50|0)==(0);
   if (!($51)) {
    $$0$i1 = $$0$i3;
    STACKTOP = sp;return ($$0$i1|0);
   }
  }
 } while(0);
 $$0$i1 = 0;
 STACKTOP = sp;return ($$0$i1|0);
}
function __ZN9Scripting30CreateScriptableObjectWithTypeEP15ScriptingObject($systemTypeInstance) {
 $systemTypeInstance = $systemTypeInstance|0;
 var $$0 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (__Z39scripting_class_from_systemtypeinstanceP15ScriptingObject($systemTypeInstance)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy2,1,16,638200,391)|0);
 $6 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1918,($5|0),($$byval_copy2|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($5)|0);
  __ZN13MonoBehaviour8SetClassEP14ScriptingClassP15ScriptingObject($9,$2,0);
  __Z48ResetAndApplyDefaultReferencesOnNewMonoBehaviourR13MonoBehaviour($9);
  $10 = (($9) + 20|0);
  $11 = HEAP32[$10>>2]|0;
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($5|0),($$byval_copy2|0),1,16,(638200|0),391);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  ___clang_call_terminate($16);
  // unreachable;
 } else {
  ___resumeException($12|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN9Scripting22CreateScriptableObjectERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($name) {
 $name = $name|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy8 = sp;
 $0 = sp + 40|0;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = sp + 36|0;
 $6 = (__Z19GetScriptingManagerv()|0);
 $7 = (($6) + 24|0);
 $8 = (__ZN17MonoScriptManager17FindRuntimeScriptERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($7,$name)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = HEAP8[$name>>0]|0;
  $11 = $10 & 1;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $15 = (($name) + 1|0);
   $16 = $15;
  } else {
   $13 = (($name) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $16 = $14;
  }
  HEAP32[$$byval_copy8>>2] = $16;
  __Z6FormatPKcz($0,638208,$$byval_copy8);
  $17 = HEAP8[$0>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $22 = (($0) + 1|0);
   $23 = $22;
  } else {
   $20 = (($0) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $23 = $21;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($23|0),0,(638200|0),427,1,0,0,(0|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   $33 = HEAP8[$0>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    $$01 = $32;$$02 = $31;
    ___resumeException($$02|0);
    // unreachable;
   }
   $36 = (($0) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   __ZdlPv($37);
   $$01 = $32;$$02 = $31;
   ___resumeException($$02|0);
   // unreachable;
  } else {
   $26 = HEAP8[$0>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $29 = (($0) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   __ZdlPv($30);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $38 = (__ZNK10MonoScript13GetScriptTypeEv($8)|0);
 $39 = ($38|0)==(1);
 if (!($39)) {
  $40 = HEAP8[$name>>0]|0;
  $41 = $40 & 1;
  $42 = ($41<<24>>24)==(0);
  if ($42) {
   $45 = (($name) + 1|0);
   $46 = $45;
  } else {
   $43 = (($name) + 8|0);
   $44 = HEAP32[$43>>2]|0;
   $46 = $44;
  }
  HEAP32[$$byval_copy8>>2] = $46;
  __Z6FormatPKcz($1,638288,$$byval_copy8);
  $47 = HEAP8[$1>>0]|0;
  $48 = $47 & 1;
  $49 = ($48<<24>>24)==(0);
  if ($49) {
   $52 = (($1) + 1|0);
   $53 = $52;
  } else {
   $50 = (($1) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   $53 = $51;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($53|0),0,(638200|0),438,1,0,0,(0|0));
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if ($55) {
   $61 = ___cxa_find_matching_catch()|0;
   $62 = tempRet0;
   $63 = HEAP8[$1>>0]|0;
   $64 = $63 & 1;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    $$01 = $62;$$02 = $61;
    ___resumeException($$02|0);
    // unreachable;
   }
   $66 = (($1) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   __ZdlPv($67);
   $$01 = $62;$$02 = $61;
   ___resumeException($$02|0);
   // unreachable;
  } else {
   $56 = HEAP8[$1>>0]|0;
   $57 = $56 & 1;
   $58 = ($57<<24>>24)==(0);
   if ($58) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $59 = (($1) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   __ZdlPv($60);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $68 = (__ZN10MonoScript8GetClassEv($8)|0);
 $69 = ($68|0)==(0|0);
 if (!($69)) {
  $98 = HEAP32[628384>>2]|0;
  HEAP32[$3>>2] = $98;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
  $99 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy8,1,16,638200,448)|0);
  $100 = HEAP32[628384>>2]|0;
  HEAP32[$4>>2] = $100;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_viii(1918,($99|0),($$byval_copy8|0),0);
  $101 = __THREW__; __THREW__ = 0;
  $102 = $101&1;
  if (!($102)) {
   $103 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($99)|0);
   $104 = (($8) + 4|0);
   $105 = HEAP32[$104>>2]|0;
   HEAP32[$5>>2] = $105;
   __ZN13MonoBehaviour9SetScriptERK4PPtrI10MonoScriptEP15ScriptingObject($103,$5,0);
   __Z48ResetAndApplyDefaultReferencesOnNewMonoBehaviourR13MonoBehaviour($103);
   $106 = (($103) + 20|0);
   $107 = HEAP32[$106>>2]|0;
   $$0 = $107;
   STACKTOP = sp;return ($$0|0);
  }
  $108 = ___cxa_find_matching_catch()|0;
  $109 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_viiiiii(97,($99|0),($$byval_copy8|0),1,16,(638200|0),448);
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if ($111) {
   $112 = ___cxa_find_matching_catch(0|0)|0;
   $113 = tempRet0;
   ___clang_call_terminate($112);
   // unreachable;
  } else {
   $$01 = $109;$$02 = $108;
   ___resumeException($$02|0);
   // unreachable;
  }
 }
 $70 = HEAP8[$name>>0]|0;
 $71 = $70 & 1;
 $72 = ($71<<24>>24)==(0);
 if ($72) {
  $75 = (($name) + 1|0);
  $76 = $75;
 } else {
  $73 = (($name) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  $76 = $74;
 }
 HEAP32[$$byval_copy8>>2] = $76;
 __Z6FormatPKcz($2,638384,$$byval_copy8);
 $77 = HEAP8[$2>>0]|0;
 $78 = $77 & 1;
 $79 = ($78<<24>>24)==(0);
 if ($79) {
  $82 = (($2) + 1|0);
  $83 = $82;
 } else {
  $80 = (($2) + 8|0);
  $81 = HEAP32[$80>>2]|0;
  $83 = $81;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($83|0),0,(638200|0),444,1,0,0,(0|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  $93 = HEAP8[$2>>0]|0;
  $94 = $93 & 1;
  $95 = ($94<<24>>24)==(0);
  if ($95) {
   $$01 = $92;$$02 = $91;
   ___resumeException($$02|0);
   // unreachable;
  }
  $96 = (($2) + 8|0);
  $97 = HEAP32[$96>>2]|0;
  __ZdlPv($97);
  $$01 = $92;$$02 = $91;
  ___resumeException($$02|0);
  // unreachable;
 } else {
  $86 = HEAP8[$2>>0]|0;
  $87 = $86 & 1;
  $88 = ($87<<24>>24)==(0);
  if ($88) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $89 = (($2) + 8|0);
  $90 = HEAP32[$89>>2]|0;
  __ZdlPv($90);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9Scripting28CreateEngineScriptableObjectEP15ScriptingObject($object) {
 $object = $object|0;
 var $$0 = 0, $$01 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp;
 $0 = sp + 24|0;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 $3 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($object)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (__Z26scripting_object_get_classP15ScriptingObject($object)|0);
 $6 = (__Z29scripting_class_get_namespaceP14ScriptingClass($5)|0);
 $7 = (__Z24scripting_class_get_nameP14ScriptingClass($5)|0);
 $8 = HEAP8[$6>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 $10 = $9 ? 638568 : 638200;
 HEAP32[$$byval_copy5>>2] = $6;
 $vararg_ptr1 = (($$byval_copy5) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $10;
 $vararg_ptr2 = (($$byval_copy5) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $7;
 $vararg_ptr3 = (($$byval_copy5) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $7;
 __Z6FormatPKcz($0,638472,$$byval_copy5);
 $11 = HEAP8[$0>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $16 = (($0) + 1|0);
  $17 = $16;
 } else {
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $17 = $15;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($17|0),0,(638200|0),472,512,0,0,(0|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $33 = HEAP8[$0>>0]|0;
  $34 = $33 & 1;
  $35 = ($34<<24>>24)==(0);
  if ($35) {
   $$0 = $31;$$01 = $32;
   ___resumeException($$0|0);
   // unreachable;
  }
  $36 = (($0) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  __ZdlPv($37);
  $$0 = $31;$$01 = $32;
  ___resumeException($$0|0);
  // unreachable;
 }
 $20 = HEAP8[$0>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if (!($22)) {
  $23 = (($0) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  __ZdlPv($24);
 }
 $25 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $25;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 $26 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy5,1,16,638200,474)|0);
 $27 = HEAP32[628384>>2]|0;
 HEAP32[$2>>2] = $27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_viii(1918,($26|0),($$byval_copy5|0),0);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  $30 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($26)|0);
  __ZN13MonoBehaviour8SetClassEP14ScriptingClassP15ScriptingObject($30,$5,$object);
  __Z48ResetAndApplyDefaultReferencesOnNewMonoBehaviourR13MonoBehaviour($30);
  STACKTOP = sp;return;
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($26|0),($$byval_copy5|0),1,16,(638200|0),474);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  $$0 = $38;$$01 = $39;
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN9Scripting32GetScriptingWrapperForInstanceIDEi($instanceID) {
 $instanceID = $instanceID|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = ($instanceID|0)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $instanceID;
 $2 = HEAP32[560624>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 10;
 } else {
  $4 = (($2) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($2) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  do {
   if ($8) {
    $9 = (($2) + 28|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($2) + 32|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + ($12<<3)|0);
    $29 = $13;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$2,$0);
    $14 = HEAP32[$pos$i$i$i$i>>2]|0;
    $15 = ($14|0)==(-1);
    $16 = (($2) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    if ($15) {
     $18 = (($2) + 32|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($17) + ($19<<3)|0);
     $29 = $20;
     break;
    } else {
     $21 = (($17) + ($14<<3)|0);
     $29 = $21;
     break;
    }
   }
  } while(0);
  $22 = HEAP32[560624>>2]|0;
  $23 = (($22) + 28|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($22) + 32|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + ($26<<3)|0);
  $28 = ($29|0)==($27|0);
  if ($28) {
   label = 10;
  } else {
   $30 = (($29) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 10;
   } else {
    $$0$i = $31;
   }
  }
 }
 if ((label|0) == 10) {
  $33 = (__Z31ReadObjectFromPersistentManageri($instanceID)|0);
  $$0$i = $33;
 }
 $34 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i)|0);
 $$0 = $34;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Scripting28GetClassIDFromScriptingClassEP14ScriptingClass($klass) {
 $klass = $klass|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $classID$0 = 0, $className$0 = 0, $klass$tr = 0, $or$cond = 0, $or$cond5 = 0, $or$cond6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $klass$tr = $klass;
 while(1) {
  $0 = (__Z19GetScriptingManagerv()|0);
  $1 = (($0) + 280|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($klass$tr,$2)|0);
  if (!($3)) {
   $$0 = -1;
   label = 11;
   break;
  }
  $4 = (__Z24scripting_class_get_nameP14ScriptingClass($klass$tr)|0);
  $5 = (__Z29scripting_class_get_namespaceP14ScriptingClass($klass$tr)|0);
  $6 = (_strcmp($4,638592)|0);
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (_strcmp($5,638576)|0);
   $9 = ($8|0)==(0);
   $$ = $9 ? 638616 : $4;
   $className$0 = $$;
  } else {
   $className$0 = $4;
  }
  $10 = (__ZN6Object15StringToClassIDEPKc($className$0)|0);
  $11 = (__Z19GetScriptingManagerv()|0);
  $12 = (($11) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($klass$tr,$13)|0);
  if ($14) {
   $34 = 1;
  } else {
   $15 = (__Z19GetScriptingManagerv()|0);
   $16 = (($15) + 44|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($klass$tr,$17)|0);
   $34 = $18;
  }
  $19 = ($10|0)>(-1);
  $20 = HEAP32[560640>>2]|0;
  $21 = ($20|0)>($10|0);
  $or$cond6 = $19 & $21;
  if ($or$cond6) {
   $22 = Math_imul($20, $10)|0;
   $23 = (($22) + 114)|0;
   $24 = $23 >> 5;
   $25 = $24 << 5;
   $26 = (($23) - ($25))|0;
   $27 = HEAP32[560632>>2]|0;
   $28 = (($27) + ($24<<2)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = 1 << $26;
   $31 = $30 & $29;
   $32 = ($31|0)!=(0);
   $35 = $32;$36 = 1;
  } else {
   $35 = 0;$36 = 0;
  }
  $33 = $34 ^ $35;
  $or$cond = $36 & $33;
  $classID$0 = $or$cond ? -1 : $10;
  $37 = ($classID$0|0)>(-1);
  $38 = ($20|0)>($classID$0|0);
  $or$cond5 = $37 & $38;
  if ($or$cond5) {
   $$0 = $classID$0;
   label = 11;
   break;
  }
  $39 = (__Z26scripting_class_get_parentP14ScriptingClass($klass$tr)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $$0 = $classID$0;
   label = 11;
   break;
  } else {
   $klass$tr = $39;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9Scripting12LogExceptionEP18ScriptingExceptioniRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($exception,$instanceID,$error) {
 $exception = $exception|0;
 $instanceID = $instanceID|0;
 $error = $error|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $info = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $info = sp + 16|0;
 $0 = sp;
 $1 = (($info) + 40|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 dest=$info+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vii(3213,($exception|0),($info|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if ($3) {
   label = 10;
  } else {
   $4 = HEAP8[$error>>0]|0;
   $5 = $4 & 1;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $9 = $4&255;
    $10 = $9 >>> 1;
    $12 = $10;
   } else {
    $7 = (($error) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $12 = $8;
   }
   $11 = ($12|0)==(0);
   do {
    if (!($11)) {
     __THREW__ = 0;
     invoke_viii(1774,($0|0),($error|0),($info|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 10;
      break L1;
     }
     __THREW__ = 0;
     (invoke_iii(2233,($info|0),($0|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      $24 = ___cxa_find_matching_catch()|0;
      $25 = tempRet0;
      $26 = HEAP8[$0>>0]|0;
      $27 = $26 & 1;
      $28 = ($27<<24>>24)==(0);
      if ($28) {
       $$0 = $25;$$01 = $24;
       break L1;
      }
      $29 = (($0) + 8|0);
      $30 = HEAP32[$29>>2]|0;
      __ZdlPv($30);
      $$0 = $25;$$01 = $24;
      break L1;
     } else {
      $17 = HEAP8[$0>>0]|0;
      $18 = $17 & 1;
      $19 = ($18<<24>>24)==(0);
      if ($19) {
       break;
      }
      $20 = (($0) + 8|0);
      $21 = HEAP32[$20>>2]|0;
      __ZdlPv($21);
      break;
     }
    }
   } while(0);
   $31 = HEAP8[$info>>0]|0;
   $32 = $31 & 1;
   $33 = ($32<<24>>24)==(0);
   if ($33) {
    $36 = (($info) + 1|0);
    $61 = $36;
   } else {
    $34 = (($info) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    $61 = $35;
   }
   $37 = (($info) + 12|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    $43 = (($37) + 1|0);
    $62 = $43;
   } else {
    $41 = (($info) + 20|0);
    $42 = HEAP32[$41>>2]|0;
    $62 = $42;
   }
   $44 = (($info) + 24|0);
   $45 = HEAP8[$44>>0]|0;
   $46 = $45 & 1;
   $47 = ($46<<24>>24)==(0);
   if ($47) {
    $50 = (($44) + 1|0);
    $63 = $50;
   } else {
    $48 = (($info) + 32|0);
    $49 = HEAP32[$48>>2]|0;
    $63 = $49;
   }
   $51 = (($info) + 36|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP8[$1>>0]|0;
   $54 = $53 & 1;
   $55 = ($54<<24>>24)==(0);
   if ($55) {
    $58 = (($1) + 1|0);
    $64 = $58;
   } else {
    $56 = (($info) + 48|0);
    $57 = HEAP32[$56>>2]|0;
    $64 = $57;
   }
   $59 = (($info) + 52|0);
   $60 = HEAP32[$59>>2]|0;
   __THREW__ = 0;
   invoke_viiiiiiiiii(9,($61|0),($62|0),($63|0),($52|0),($64|0),($60|0),131332,($instanceID|0),0,(0|0));
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if ($66) {
    label = 10;
   } else {
    $67 = HEAP8[$1>>0]|0;
    $68 = $67 & 1;
    $69 = ($68<<24>>24)==(0);
    if (!($69)) {
     $70 = (($info) + 48|0);
     $71 = HEAP32[$70>>2]|0;
     __ZdlPv($71);
    }
    $72 = HEAP8[$44>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    if (!($74)) {
     $75 = (($info) + 32|0);
     $76 = HEAP32[$75>>2]|0;
     __ZdlPv($76);
    }
    $77 = HEAP8[$37>>0]|0;
    $78 = $77 & 1;
    $79 = ($78<<24>>24)==(0);
    if (!($79)) {
     $80 = (($info) + 20|0);
     $81 = HEAP32[$80>>2]|0;
     __ZdlPv($81);
    }
    $82 = HEAP8[$info>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if ($84) {
     STACKTOP = sp;return;
    }
    $85 = (($info) + 8|0);
    $86 = HEAP32[$85>>2]|0;
    __ZdlPv($86);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $$0 = $23;$$01 = $22;
 }
 $87 = HEAP8[$1>>0]|0;
 $88 = $87 & 1;
 $89 = ($88<<24>>24)==(0);
 if (!($89)) {
  $90 = (($info) + 48|0);
  $91 = HEAP32[$90>>2]|0;
  __ZdlPv($91);
 }
 $92 = (($info) + 24|0);
 $93 = HEAP8[$92>>0]|0;
 $94 = $93 & 1;
 $95 = ($94<<24>>24)==(0);
 if (!($95)) {
  $96 = (($info) + 32|0);
  $97 = HEAP32[$96>>2]|0;
  __ZdlPv($97);
 }
 $98 = (($info) + 12|0);
 $99 = HEAP8[$98>>0]|0;
 $100 = $99 & 1;
 $101 = ($100<<24>>24)==(0);
 if (!($101)) {
  $102 = (($info) + 20|0);
  $103 = HEAP32[$102>>2]|0;
  __ZdlPv($103);
 }
 $104 = HEAP8[$info>>0]|0;
 $105 = $104 & 1;
 $106 = ($105<<24>>24)==(0);
 if ($106) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $107 = (($info) + 8|0);
 $108 = HEAP32[$107>>2]|0;
 __ZdlPv($108);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN9Scripting41TrackedReferenceBaseToScriptingObjectImplEP20TrackedReferenceBaseP14ScriptingClass($base,$klass) {
 $base = $base|0;
 $klass = $klass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($base|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$base>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if (!($2)) {
   $3 = (__Z29scripting_gchandle_get_targeti($1)|0);
   $4 = ($3|0)==(0|0);
   if ($4) {
    $5 = HEAP32[$base>>2]|0;
    __Z23scripting_gchandle_freei($5);
    HEAP32[$base>>2] = 0;
    break;
   } else {
    $$0 = $3;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $6 = (__Z20scripting_object_newP14ScriptingClass($klass)|0);
 $7 = (__Z22scripting_gchandle_newP15ScriptingObject($6)|0);
 HEAP32[$base>>2] = $7;
 $8 = (($6) + 8|0);
 HEAP32[$8>>2] = $base;
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN24ScriptingMethodFiltering36MethodDescriptionMatchesSearchFilterEibi($searchFilter,$isInstance,$argCount) {
 $searchFilter = $searchFilter|0;
 $isInstance = $isInstance|0;
 $argCount = $argCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $brmerge = 0, $brmerge1 = 0, $isInstance$not = 0, $not$or$cond = 0, $notlhs = 0, $notrhs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $searchFilter & 2;
 $1 = ($0|0)==(0);
 $isInstance$not = $isInstance ^ 1;
 $brmerge = $1 | $isInstance$not;
 if (!($brmerge)) {
  STACKTOP = sp;return 0;
 }
 $2 = $searchFilter & 1;
 $3 = ($2|0)==(0);
 $brmerge1 = $3 | $isInstance;
 if ($brmerge1) {
  $4 = $searchFilter & 4;
  $notlhs = ($4|0)==(0);
  $notrhs = ($argCount|0)<(1);
  $not$or$cond = $notrhs | $notlhs;
  STACKTOP = sp;return ($not$or$cond|0);
 } else {
  STACKTOP = sp;return 0;
 }
 return 0|0;
}
function __Z14GetProfileTimey($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 tempRet0 = $1;
 STACKTOP = sp;return ($0|0);
}
function __ZN13ProxyTransferC2ER8TypeTree24TransferInstructionFlagsPvi($this,$t,$options,$objectPtr,$objectSize) {
 $this = $this|0;
 $t = $t|0;
 $options = $options|0;
 $objectPtr = $objectPtr|0;
 $objectSize = $objectSize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = $t;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 20|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$this>>2] = $options;
 $4 = (($this) + 40|0);
 $5 = (($this) + 24|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP16[$4+8>>1]=0|0;
 HEAP32[$5>>2] = $objectPtr;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = $objectSize;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer18SetScriptingObjectEPvi($this,$scriptingObjectPtr,$scriptingObjectSize) {
 $this = $this|0;
 $scriptingObjectPtr = $scriptingObjectPtr|0;
 $scriptingObjectSize = $scriptingObjectSize|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 HEAP32[$0>>2] = $scriptingObjectPtr;
 $1 = (($this) + 36|0);
 HEAP32[$1>>2] = $scriptingObjectSize;
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,$name,$typeString,$size,$metaFlag) {
 $this = $this|0;
 $name = $name|0;
 $typeString = $typeString|0;
 $size = $size|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$typeString,0,$metaFlag);
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($2) + (($4*24)|0)|0) + 3|0);
 HEAP8[$5>>0] = 1;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,638632,$6,$size,0);
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$3>>2]|0;
 $10 = ((($8) + (($9*24)|0)|0) + 12|0);
 HEAP32[$10>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$typeString,$dataPtr,$metaFlag) {
 $this = $this|0;
 $name = $name|0;
 $typeString = $typeString|0;
 $dataPtr = $dataPtr|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $9 = 0, $or$cond = 0, $type = 0, $typeTreeNode$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $type = sp + 8|0;
 $0 = sp;
 HEAP32[$type>>2] = 0;
 $1 = (($type) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 if ($4) {
  $26 = $6;
  $27 = $type;
  $28 = $27;
  HEAP32[$28>>2] = $26;
  $29 = (($27) + 4)|0;
  $30 = $29;
  HEAP32[$30>>2] = 0;
  $31 = HEAP32[$6>>2]|0;
  $32 = (($31) + 20|0);
  HEAP32[$32>>2] = $metaFlag;
  $typeTreeNode$0 = $31;
 } else {
  __ZN8TypeTree8AddChildERK16TypeTreeIterator($0,$6,$2);
  $7 = $0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = $type;
  $14 = $13;
  HEAP32[$14>>2] = $9;
  $15 = (($13) + 4)|0;
  $16 = $15;
  HEAP32[$16>>2] = $12;
  $17 = HEAP32[$5>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + (($12*24)|0)|0);
  $20 = (__ZNK16TypeTreeIterator7GetNodeEv($2)|0);
  $21 = (($20) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $22 | $metaFlag;
  $24 = ((($18) + (($12*24)|0)|0) + 20|0);
  $25 = $23 & -32769;
  HEAP32[$24>>2] = $25;
  $typeTreeNode$0 = $19;
 }
 $33 = HEAP32[$5>>2]|0;
 __ZN8TypeTree16AssignTypeStringERK16TypeTreeIteratorPKc($33,$type,$typeString);
 $34 = HEAP32[$5>>2]|0;
 __ZN8TypeTree16AssignNameStringERK16TypeTreeIteratorPKc($34,$type,$name);
 $35 = (($typeTreeNode$0) + 12|0);
 HEAP32[$35>>2] = 0;
 $36 = (__ZNK16TypeTreeIterator7GetNodeEv($type)|0);
 $37 = (($36) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 4096;
 $40 = ($39|0)==(0);
 if ($40) {
  label = 6;
 } else {
  $41 = HEAP32[$this>>2]|0;
  $42 = $41 & 32;
  $43 = ($42|0)==(0);
  if ($43) {
   label = 6;
  } else {
   $48 = -1;
  }
 }
 if ((label|0) == 6) {
  $44 = (($this) + 40|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 1)|0;
  HEAP32[$44>>2] = $46;
  $48 = $45;
 }
 $47 = (($typeTreeNode$0) + 16|0);
 HEAP32[$47>>2] = $48;
 $49 = (($this) + 24|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 $52 = ($dataPtr|0)==(0|0);
 $or$cond = $51 | $52;
 do {
  if (!($or$cond)) {
   $53 = $dataPtr;
   $54 = $50;
   $55 = (($53) - ($54))|0;
   $56 = ($55|0)>(-1);
   if ($56) {
    $57 = (($this) + 28|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($55|0)<($58|0);
    if ($59) {
     $60 = HEAP32[$5>>2]|0;
     __ZN8TypeTree16AssignByteOffsetERK16TypeTreeIteratorj($60,$type,$55);
     break;
    }
   }
   $61 = (($this) + 32|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = $62;
   $64 = (($53) - ($63))|0;
   $65 = ($64|0)>(-1);
   if ($65) {
    $66 = (($this) + 36|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($64|0)<($67|0);
    if ($68) {
     $69 = HEAP32[$5>>2]|0;
     $70 = $64 | -2147483648;
     __ZN8TypeTree16AssignByteOffsetERK16TypeTreeIteratorj($69,$type,$70);
    }
   }
  }
 } while(0);
 $71 = $type;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($71) + 4)|0;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = $2;
 $78 = $77;
 HEAP32[$78>>2] = $73;
 $79 = (($77) + 4)|0;
 $80 = $79;
 HEAP32[$80>>2] = $76;
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer11EndTransferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $current = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $current = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $current;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 __ZNK16TypeTreeIterator6FatherEv($0,$1);
 $12 = $0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $14;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 $22 = ($14|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (__ZNK16TypeTreeIterator7GetNodeEv($current)|0);
 $24 = (($23) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(-1);
 if ($26) {
  $44 = -1;
 } else {
  $27 = (__ZNK16TypeTreeIterator7GetNodeEv($1)|0);
  $28 = (($27) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(-1);
  if ($30) {
   $44 = -1;
  } else {
   $31 = (__ZNK16TypeTreeIterator7GetNodeEv($1)|0);
   $32 = (($31) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (__ZNK16TypeTreeIterator7GetNodeEv($current)|0);
   $35 = (($34) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + ($33))|0;
   $44 = $37;
  }
 }
 $38 = (($this) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 20|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($40) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = $44;
 $45 = (__ZNK16TypeTreeIterator7GetNodeEv($current)|0);
 $46 = (($45) + 20|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 & 32768;
 $49 = ($48|0)==(0);
 if ($49) {
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$38>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = HEAP32[$41>>2]|0;
 $53 = ((($51) + (($52*24)|0)|0) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 | 32768;
 HEAP32[$53>>2] = $55;
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer16EndArrayTransferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($2) + (($4*24)|0)|0) + 12|0);
 HEAP32[$5>>2] = -1;
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer10SetVersionEi($this,$version) {
 $this = $this|0;
 $version = $version|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $version&65535;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + (($5*24)|0)|0);
 HEAP16[$6>>1] = $0;
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer16TransferTypelessEPjPKc17TransferMetaFlags($this,$byteSize,$name,$metaFlag) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = sp + 8|0;
 $size = sp + 16|0;
 $temp = sp + 32|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,638640,0,$metaFlag);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 3|0);
 HEAP8[$8>>0] = 1;
 $9 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,638632,$9,$size,0);
 $10 = HEAP32[$3>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$6>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $14 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,638656,$14,$temp,$metaFlag);
 $15 = HEAP32[$3>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $19 = (($this) + 49|0);
 HEAP8[$19>>0] = 1;
 $20 = HEAP32[$3>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$6>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = -1;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $24 = (($this) + 44|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 3)|0;
 $27 = $26 & -4;
 HEAP32[$24>>2] = $27;
 $28 = (($this) + 16|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 __ZNK16TypeTreeIterator8ChildrenEv($0,$28);
 $31 = HEAP32[$0>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$3>>2]|0;
 __ZNK16TypeTreeIterator8ChildrenEv($2,$28);
 __ZNK16TypeTreeIterator4LastEv($1,$2);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($1) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($34) + (($36*24)|0)|0) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 | 16384;
 HEAP32[$37>>2] = $39;
 $40 = HEAP32[$3>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$6>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 | 32768;
 HEAP32[$43>>2] = $45;
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer5AlignEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = sp + 8|0;
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 3)|0;
 $6 = $5 & -4;
 HEAP32[$3>>2] = $6;
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 __ZNK16TypeTreeIterator8ChildrenEv($0,$7);
 $10 = HEAP32[$0>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNK16TypeTreeIterator8ChildrenEv($2,$7);
 __ZNK16TypeTreeIterator4LastEv($1,$2);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($1) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($14) + (($16*24)|0)|0) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 | 16384;
 HEAP32[$17>>2] = $19;
 $20 = HEAP32[$12>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($21) + (($23*24)|0)|0) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 | 32768;
 HEAP32[$24>>2] = $26;
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer20TransferTypelessDataEjPvi($this,$byteSize,$copyData,$metaData) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $copyData = $copyData|0;
 $metaData = $metaData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 49|0);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN17RemapPPtrTransferC2E24TransferInstructionFlagsb($this,$flags,$readPPtrs) {
 $this = $this|0;
 $flags = $flags|0;
 $readPPtrs = $readPPtrs|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre2 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 4|0);
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 24|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 32|0);
 $9 = $readPPtrs&1;
 HEAP8[$8>>0] = $9;
 HEAP32[$this>>2] = $flags;
 HEAP32[$4>>2] = 0;
 $10 = (($this) + 12|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $11 = (invoke_iiiiiii(102,16,16,($$byval_copy2|0),0,(638664|0),79)|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 do {
  if (!($13)) {
   $$pre$i = HEAP32[$5>>2]|0;
   $$pre1$i = HEAP32[$6>>2]|0;
   $14 = (($11) + 16|0);
   $15 = $$pre1$i;
   $16 = $$pre$i;
   $17 = (($15) - ($16))|0;
   $18 = $17 >> 2;
   $$sum$i = (0 - ($18))|0;
   $19 = (($11) + ($$sum$i<<2)|0);
   _memcpy(($19|0),($$pre$i|0),($17|0))|0;
   $20 = HEAP32[$5>>2]|0;
   HEAP32[$5>>2] = $19;
   HEAP32[$6>>2] = $11;
   HEAP32[$7>>2] = $14;
   $21 = ($20|0)==(0|0);
   if ($21) {
    HEAP32[$3>>2] = 0;
    $28 = $11;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($20|0),($$byval_copy2|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $24 = ___cxa_find_matching_catch()|0;
     $25 = tempRet0;
     ___cxa_call_unexpected(($24|0));
     // unreachable;
    }
    $$pre = HEAP32[$6>>2]|0;
    $$pre2 = HEAP32[$7>>2]|0;
    HEAP32[$3>>2] = 0;
    $26 = ($$pre|0)==($$pre2|0);
    if ($26) {
     __THREW__ = 0;
     invoke_vii(3214,($5|0),($3|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     $32 = (($this) + 28|0);
     HEAP32[$32>>2] = 0;
     STACKTOP = sp;return;
    } else {
     $28 = $$pre;
    }
   }
   $27 = ($28|0)==(0|0);
   if (!($27)) {
    HEAP32[$28>>2] = 0;
   }
   $29 = (($28) + 4|0);
   HEAP32[$6>>2] = $29;
   $32 = (($this) + 28|0);
   HEAP32[$32>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 $35 = HEAP32[$5>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  ___resumeException($33|0);
  // unreachable;
 }
 $37 = HEAP32[$6>>2]|0;
 $38 = ($37|0)==($35|0);
 if (!($38)) {
  $__new_last2$i$i$i$i$i = $35;
  $scevgep$i$i$i$i$i = (($37) + -4|0);
  $39 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($39)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $40 = $uglygep3$i$i$i$i$i >>> 2;
  $41 = $40 ^ -1;
  $scevgep4$i$i$i$i$i = (($37) + ($41<<2)|0);
  HEAP32[$6>>2] = $scevgep4$i$i$i$i$i;
 }
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy2|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 } else {
  ___resumeException($33|0);
  // unreachable;
 }
}
function __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 | $flag;
 HEAP32[$0>>2] = $5;
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($2|0)==($7|0);
 if ($8) {
  $11 = (($this) + 16|0);
  __ZNSt3__16vectorI17TransferMetaFlags13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($11,$0);
  $$pre = HEAP32[$1>>2]|0;
  $13 = $$pre;
  $12 = (($13) + -4|0);
  $14 = HEAP32[$12>>2]|0;
  $15 = (($this) + 28|0);
  HEAP32[$15>>2] = $14;
  STACKTOP = sp;return;
 }
 $9 = ($2|0)==(0|0);
 if (!($9)) {
  HEAP32[$2>>2] = $5;
 }
 $10 = (($2) + 4|0);
 HEAP32[$1>>2] = $10;
 $13 = $10;
 $12 = (($13) + -4|0);
 $14 = HEAP32[$12>>2]|0;
 $15 = (($this) + 28|0);
 HEAP32[$15>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN17RemapPPtrTransfer11PopMetaFlagEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__new_last2$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$sum = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -4|0);
 $__new_last2$i$i$i = $2;
 $3 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($2) + ($3)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $4 = $uglygep3$i$i$i >>> 2;
 $5 = $4 ^ -1;
 $scevgep4$i$i$i = (($1) + ($5<<2)|0);
 HEAP32[$0>>2] = $scevgep4$i$i$i;
 $scevgep4$i$i$i$sum = (-2 - ($4))|0;
 $6 = (($1) + ($scevgep4$i$i$i$sum<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 28|0);
 HEAP32[$8>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI17TransferMetaFlags13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,638664,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<2)|0);
 $24 = (($23) + ($$0$i3<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$__x>>2]|0;
  HEAP32[$22>>2] = $26;
 }
 $27 = (($23) + ($8<<2)|0);
 $28 = HEAP32[$this>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = $29;
 $31 = $28;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $$sum1 = (($7) - ($33))|0;
 $34 = (($23) + ($$sum1<<2)|0);
 _memcpy(($34|0),($28|0),($32|0))|0;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $34;
 HEAP32[$1>>2] = $27;
 HEAP32[$10>>2] = $24;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN21SafeBinaryReadManagerL16StaticInitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628360>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,638712,21)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[638672>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN21SafeBinaryReadManagerL13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[638672>>2]|0;
 $2 = HEAP32[628360>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EEPFbPvR14SafeBinaryReadEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_S5_EE($1,$5);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[638672>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($oldType,$newType,$converter) {
 $oldType = $oldType|0;
 $newType = $newType|0;
 $converter = $converter|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__parent$i = 0, $__r$0$i = 0, $arg = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent$i = sp + 8|0;
 $arg = sp;
 HEAP32[$arg>>2] = $oldType;
 $0 = (($arg) + 4|0);
 HEAP32[$0>>2] = $newType;
 $1 = HEAP32[638672>>2]|0;
 $2 = (__ZNSt3__13mapINS_4pairIPcS2_EEPFbPvR14SafeBinaryReadE20smaller_cstring_pairNS_9allocatorINS1_IKS3_S8_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIS4_EERSB_($1,$__parent$i,$arg)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $__r$0$i = $3;
  $30 = (($__r$0$i) + 24|0);
  HEAP32[$30>>2] = $converter;
  STACKTOP = sp;return;
 }
 $5 = (__Znwj(28)|0);
 $6 = (($5) + 16|0);
 $7 = $arg;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $6;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = (($5) + 24|0);
 HEAP32[$17>>2] = 0;
 $18 = HEAP32[$__parent$i>>2]|0;
 HEAP32[$5>>2] = 0;
 $19 = (($5) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($5) + 8|0);
 HEAP32[$20>>2] = $18;
 HEAP32[$2>>2] = $5;
 $21 = HEAP32[$1>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $26 = $5;
 } else {
  HEAP32[$1>>2] = $22;
  $$pre$i$i = HEAP32[$2>>2]|0;
  $26 = $$pre$i$i;
 }
 $24 = (($1) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($1) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $__r$0$i = $5;
 $30 = (($__r$0$i) + 24|0);
 HEAP32[$30>>2] = $converter;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21CleanupConverterTableEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[638672>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EEPFbPvR14SafeBinaryReadEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_S5_EE($0,$2);
 $3 = (($0) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($0) + 4|0);
 HEAP32[$0>>2] = $4;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead4InitERK16TypeTreeIteratorii24TransferInstructionFlags10MemLabelId($this,$oldBase,$bytePosition,$byteSize,$flags,$label) {
 $this = $this|0;
 $oldBase = $oldBase|0;
 $bytePosition = $bytePosition|0;
 $byteSize = $byteSize|0;
 $flags = $flags|0;
 $label = $label|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = $oldBase;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 $11 = (($this) + 64|0);
 HEAP32[$11>>2] = $bytePosition;
 $12 = HEAP32[$label>>2]|0;
 $13 = (($this) + 8|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 68|0);
 HEAP32[$14>>2] = $byteSize;
 HEAP32[$this>>2] = $flags;
 $15 = (($this) + 4|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 136|0);
 HEAP8[$16>>0] = 0;
 $17 = (($this) + 140|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 12|0);
 STACKTOP = sp;return ($18|0);
}
function __ZN14SafeBinaryReadD2Ev($this) {
 $this = $this|0;
 var $$lcssa$i = 0, $$ph$i = 0, $$ph1$i = 0, $$pre$i$i$i$i$i = 0, $$pre2$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$01$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 128|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3>>>0) / 341)&-1;
 $5 = (($1) + ($4<<2)|0);
 $6 = (($this) + 120|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if ($8) {
  $9 = (($this) + 132|0);
  $23 = 0;$32 = $9;$62 = 0;
 } else {
  $10 = HEAP32[$5>>2]|0;
  $11 = (($3>>>0) % 341)&-1;
  $12 = (($10) + (($11*12)|0)|0);
  $13 = (($this) + 132|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($3))|0;
  $16 = (($15>>>0) / 341)&-1;
  $17 = (($1) + ($16<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($15>>>0) % 341)&-1;
  $20 = (($18) + (($19*12)|0)|0);
  $23 = $20;$32 = $13;$62 = $12;
 }
 $$ph$i = $62;$$ph1$i = $5;
 L5: while(1) {
  $22 = $$ph$i;
  while(1) {
   $21 = ($22|0)==($23|0);
   if ($21) {
    break L5;
   }
   $24 = (($22) + 12|0);
   $25 = HEAP32[$$ph1$i>>2]|0;
   $26 = $24;
   $27 = $25;
   $28 = (($26) - ($27))|0;
   $29 = ($28|0)==(4092);
   if ($29) {
    break;
   } else {
    $22 = $24;
   }
  }
  $30 = (($$ph1$i) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $$ph$i = $31;$$ph1$i = $30;
 }
 HEAP32[$32>>2] = 0;
 $33 = $7;
 $34 = $1;
 $35 = (($33) - ($34))|0;
 $36 = $35 >> 2;
 $37 = ($36>>>0)>(2);
 if ($37) {
  $39 = $1;
  while(1) {
   $38 = HEAP32[$39>>2]|0;
   __ZdlPv($38);
   $40 = HEAP32[$0>>2]|0;
   $41 = (($40) + 4|0);
   HEAP32[$0>>2] = $41;
   $42 = HEAP32[$6>>2]|0;
   $43 = $42;
   $44 = $41;
   $45 = (($43) - ($44))|0;
   $46 = $45 >> 2;
   $47 = ($46>>>0)>(2);
   if ($47) {
    $39 = $41;
   } else {
    $$lcssa$i = $46;
    break;
   }
  }
 } else {
  $$lcssa$i = $36;
 }
 if ((($$lcssa$i|0) == 1)) {
  HEAP32[$2>>2] = 170;
 } else if ((($$lcssa$i|0) == 2)) {
  HEAP32[$2>>2] = 341;
 }
 $48 = HEAP32[$0>>2]|0;
 $49 = HEAP32[$6>>2]|0;
 $50 = ($48|0)==($49|0);
 if (!($50)) {
  $__i$01$i$i$i$i$i = $48;
  while(1) {
   $51 = HEAP32[$__i$01$i$i$i$i$i>>2]|0;
   __ZdlPv($51);
   $52 = (($__i$01$i$i$i$i$i) + 4|0);
   $53 = ($52|0)==($49|0);
   if ($53) {
    break;
   } else {
    $__i$01$i$i$i$i$i = $52;
   }
  }
  $$pre$i$i$i$i$i = HEAP32[$0>>2]|0;
  $$pre2$i$i$i$i$i = HEAP32[$6>>2]|0;
  $54 = ($$pre2$i$i$i$i$i|0)==($$pre$i$i$i$i$i|0);
  if (!($54)) {
   $__new_last2$i$i$i$i$i$i$i$i$i$i = $$pre$i$i$i$i$i;
   $scevgep$i$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i$i) + -4|0);
   $55 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i) + ($55)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i;
   $56 = $uglygep3$i$i$i$i$i$i$i$i$i$i >>> 2;
   $57 = $56 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i$i) + ($57<<2)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i;
  }
 }
 $58 = (($this) + 112|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0|0);
 if ($60) {
  $61 = (($this) + 88|0);
  __ZNSt3__15stackIN14SafeBinaryRead11StackedInfoENS_5dequeIS2_NS_9allocatorIS2_EEEEED1Ev($61);
  STACKTOP = sp;return;
 }
 __ZdlPv($59);
 $61 = (($this) + 88|0);
 __ZNSt3__15stackIN14SafeBinaryRead11StackedInfoENS_5dequeIS2_NS_9allocatorIS2_EEEEED1Ev($61);
 STACKTOP = sp;return;
}
function __ZNSt3__15stackIN14SafeBinaryRead11StackedInfoENS_5dequeIS2_NS_9allocatorIS2_EEEEED1Ev($this) {
 $this = $this|0;
 var $$lcssa$i = 0, $$ph$i = 0, $$ph1$i = 0, $$pre$i$i$i$i = 0, $$pre2$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$01$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 7;
 $5 = (($1) + ($4<<2)|0);
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if ($8) {
  $9 = (($this) + 20|0);
  $23 = 0;$32 = $9;$60 = 0;
 } else {
  $10 = HEAP32[$5>>2]|0;
  $11 = $3 & 127;
  $12 = (($10) + ($11<<5)|0);
  $13 = (($this) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($3))|0;
  $16 = $15 >>> 7;
  $17 = (($1) + ($16<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $15 & 127;
  $20 = (($18) + ($19<<5)|0);
  $23 = $20;$32 = $13;$60 = $12;
 }
 $$ph$i = $60;$$ph1$i = $5;
 L5: while(1) {
  $22 = $$ph$i;
  while(1) {
   $21 = ($22|0)==($23|0);
   if ($21) {
    break L5;
   }
   $24 = (($22) + 32|0);
   $25 = HEAP32[$$ph1$i>>2]|0;
   $26 = $24;
   $27 = $25;
   $28 = (($26) - ($27))|0;
   $29 = ($28|0)==(4096);
   if ($29) {
    break;
   } else {
    $22 = $24;
   }
  }
  $30 = (($$ph1$i) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $$ph$i = $31;$$ph1$i = $30;
 }
 HEAP32[$32>>2] = 0;
 $33 = $7;
 $34 = $1;
 $35 = (($33) - ($34))|0;
 $36 = $35 >> 2;
 $37 = ($36>>>0)>(2);
 if ($37) {
  $39 = $1;
  while(1) {
   $38 = HEAP32[$39>>2]|0;
   __ZdlPv($38);
   $40 = HEAP32[$0>>2]|0;
   $41 = (($40) + 4|0);
   HEAP32[$0>>2] = $41;
   $42 = HEAP32[$6>>2]|0;
   $43 = $42;
   $44 = $41;
   $45 = (($43) - ($44))|0;
   $46 = $45 >> 2;
   $47 = ($46>>>0)>(2);
   if ($47) {
    $39 = $41;
   } else {
    $$lcssa$i = $46;
    break;
   }
  }
 } else {
  $$lcssa$i = $36;
 }
 if ((($$lcssa$i|0) == 1)) {
  HEAP32[$2>>2] = 64;
 } else if ((($$lcssa$i|0) == 2)) {
  HEAP32[$2>>2] = 128;
 }
 $48 = HEAP32[$0>>2]|0;
 $49 = HEAP32[$6>>2]|0;
 $50 = ($48|0)==($49|0);
 if (!($50)) {
  $__i$01$i$i$i$i = $48;
  while(1) {
   $51 = HEAP32[$__i$01$i$i$i$i>>2]|0;
   __ZdlPv($51);
   $52 = (($__i$01$i$i$i$i) + 4|0);
   $53 = ($52|0)==($49|0);
   if ($53) {
    break;
   } else {
    $__i$01$i$i$i$i = $52;
   }
  }
  $$pre$i$i$i$i = HEAP32[$0>>2]|0;
  $$pre2$i$i$i$i = HEAP32[$6>>2]|0;
  $54 = ($$pre2$i$i$i$i|0)==($$pre$i$i$i$i|0);
  if (!($54)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $$pre$i$i$i$i;
   $scevgep$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i) + -4|0);
   $55 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($55)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $56 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 2;
   $57 = $56 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i) + ($57<<2)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
 }
 $58 = HEAP32[$this>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  STACKTOP = sp;return;
 }
 __ZdlPv($58);
 STACKTOP = sp;return;
}
function __ZL4WalkRK16TypeTreeIteratorR12CachedReaderPib($type,$cache,$bytePosition,$endianSwap) {
 $type = $type|0;
 $cache = $cache|0;
 $bytePosition = $bytePosition|0;
 $endianSwap = $endianSwap|0;
 var $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $9 = 0, $arraySize = 0, $elementTypeTree = 0, $i$03 = 0, $i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $arraySize = sp + 32|0;
 $elementTypeTree = sp + 24|0;
 $0 = sp + 16|0;
 $i1 = sp;
 $1 = sp + 8|0;
 $2 = (__ZNK16TypeTreeIterator7GetNodeEv($type)|0);
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 if ($5) {
  label = 4;
 } else {
  $6 = (__ZNK16TypeTreeIterator7GetNodeEv($type)|0);
  $7 = (($6) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 32768;
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = (__ZNK16TypeTreeIterator7GetNodeEv($type)|0);
   $12 = (($11) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$bytePosition>>2]|0;
   $15 = (($14) + ($13))|0;
   HEAP32[$bytePosition>>2] = $15;
  } else {
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $16 = (__ZNK16TypeTreeIterator7GetNodeEv($type)|0);
   $17 = (($16) + 3|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    __ZNK16TypeTreeIterator8ChildrenEv($i1,$type);
    $60 = HEAP32[$i1>>2]|0;
    $61 = ($60|0)==(0|0);
    if ($61) {
     break;
    }
    while(1) {
     __ZL4WalkRK16TypeTreeIteratorR12CachedReaderPib($i1,$cache,$bytePosition,$endianSwap);
     __ZNK16TypeTreeIterator4NextEv($1,$i1);
     $62 = $1;
     $63 = $62;
     $64 = HEAP32[$63>>2]|0;
     $65 = (($62) + 4)|0;
     $66 = $65;
     $67 = HEAP32[$66>>2]|0;
     $68 = $i1;
     $69 = $68;
     HEAP32[$69>>2] = $64;
     $70 = (($68) + 4)|0;
     $71 = $70;
     HEAP32[$71>>2] = $67;
     $72 = ($64|0)==(0);
     if ($72) {
      break L4;
     }
    }
   }
   $20 = HEAP32[$bytePosition>>2]|0;
   $21 = (($cache) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($cache) + 16|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($cache) + 20|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = Math_imul($26, $24)|0;
   $$sum$i = (($20) - ($27))|0;
   $28 = (($22) + ($$sum$i)|0);
   HEAP32[$cache>>2] = $28;
   $29 = ($$sum$i|0)<(0);
   if ($29) {
    label = 8;
   } else {
    $$sum1$i = (($$sum$i) + 4)|0;
    $30 = (($22) + ($$sum1$i)|0);
    $31 = (($cache) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($30>>>0)>($32>>>0);
    if ($33) {
     label = 8;
    } else {
     $34 = HEAP32[$28>>2]|0;
     HEAP32[$arraySize>>2] = $34;
     HEAP32[$cache>>2] = $30;
    }
   }
   if ((label|0) == 8) {
    __ZN12CachedReader15UpdateReadCacheEPvj($cache,$arraySize,4);
   }
   if ($endianSwap) {
    $35 = HEAP32[$arraySize>>2]|0;
    $36 = (_llvm_bswap_i32(($35|0))|0);
    HEAP32[$arraySize>>2] = $36;
   }
   $37 = HEAP32[$bytePosition>>2]|0;
   $38 = (($37) + 4)|0;
   HEAP32[$bytePosition>>2] = $38;
   __ZNK16TypeTreeIterator8ChildrenEv($0,$type);
   __ZNK16TypeTreeIterator4NextEv($elementTypeTree,$0);
   $39 = (__ZNK16TypeTreeIterator7GetNodeEv($elementTypeTree)|0);
   $40 = (($39) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(-1);
   if (!($42)) {
    $43 = (__ZNK16TypeTreeIterator7GetNodeEv($elementTypeTree)|0);
    $44 = (($43) + 20|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = $45 & 49152;
    $47 = ($46|0)==(0);
    if ($47) {
     $50 = HEAP32[$arraySize>>2]|0;
     $51 = (__ZNK16TypeTreeIterator7GetNodeEv($elementTypeTree)|0);
     $52 = (($51) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = Math_imul($53, $50)|0;
     $55 = HEAP32[$bytePosition>>2]|0;
     $56 = (($55) + ($54))|0;
     HEAP32[$bytePosition>>2] = $56;
     break;
    }
   }
   $48 = HEAP32[$arraySize>>2]|0;
   $49 = ($48|0)>(0);
   if ($49) {
    $i$03 = 0;
    while(1) {
     __ZL4WalkRK16TypeTreeIteratorR12CachedReaderPib($elementTypeTree,$cache,$bytePosition,$endianSwap);
     $57 = (($i$03) + 1)|0;
     $58 = HEAP32[$arraySize>>2]|0;
     $59 = ($57|0)<($58|0);
     if ($59) {
      $i$03 = $57;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 $73 = (__ZNK16TypeTreeIterator7GetNodeEv($type)|0);
 $74 = (($73) + 20|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = $75 & 16384;
 $77 = ($76|0)==(0);
 if ($77) {
  STACKTOP = sp;return;
 }
 $78 = HEAP32[$bytePosition>>2]|0;
 $79 = (($78) + 3)|0;
 $80 = $79 & -4;
 HEAP32[$bytePosition>>2] = $80;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead20OverrideRootTypeNameEPKc($this,$typeString) {
 $this = $this|0;
 $typeString = $typeString|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + -1)|0;
 $5 = (($4) + ($3))|0;
 $6 = (($this) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5 >>> 7;
 $9 = (($7) + ($8<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $5 & 127;
 $12 = ((($10) + ($11<<5)|0) + 8|0);
 HEAP32[$12>>2] = $typeString;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$typeString,$converter,$allowTypeConversion) {
 $this = $this|0;
 $name = $name|0;
 $typeString = $typeString|0;
 $converter = $converter|0;
 $allowTypeConversion = $allowTypeConversion|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$0$i6 = 0, $$neg2$i$i$i = 0, $$neg2$i$i$i7 = 0, $$pr = 0, $$pr47 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i9 = 0, $$pre1$i$i = 0, $$pre1$i$i10 = 0, $$pre2$i$i = 0, $$pre2$i$i11 = 0, $$pre3$i$i = 0, $$pre3$i$i12 = 0, $$pre4$i$i = 0, $$pre4$i$i14 = 0, $$pre59 = 0;
 var $$pre66 = 0, $$pre67 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__rt$0$in$i$i$i = 0, $__rt$0$in$i$i$i$us = 0, $__rt$0$in$i$i$i38 = 0, $__rt$0$in$i$i$i38$us = 0, $__rt$0$in$in$be$i$i$i = 0, $__rt$0$in$in$be$i$i$i$us = 0, $__rt$0$in$in$be$i$i$i37 = 0, $__rt$0$in$in$be$i$i$i37$us = 0;
 var $__rt$0$in1$i$i$i = 0, $__rt$0$in1$i$i$i$us = 0, $__rt$0$in1$i$i$i34 = 0, $__rt$0$in1$i$i$i34$us = 0, $__rt$0$in2$i$i$i = 0, $__rt$0$in2$i$i$i$us = 0, $__rt$0$in2$i$i$i35 = 0, $__rt$0$in2$i$i$i35$us = 0, $arg$i = 0, $brmerge = 0, $brmerge70 = 0, $brmerge71 = 0, $c = 0, $children = 0, $exitcond = 0, $found$i = 0, $i$0$ph = 0, $i$048 = 0, $newBytePosition = 0, $newInfo = 0;
 var $newInfo1 = 0, $notlhs = 0, $notlhs72 = 0, $notlhs74 = 0, $notlhs76 = 0, $notrhs = 0, $notrhs73 = 0, $notrhs75 = 0, $notrhs77 = 0, $or$cond$i = 0, $or$cond$i$i$i = 0, $or$cond$i19$not = 0, $or$cond$i28$not = 0, $or$cond5$i = 0, $or$cond5$i$i$i = 0, $or$cond5$i20$not = 0, $or$cond5$i29$not = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $arg$i = sp + 120|0;
 $found$i = sp + 112|0;
 $newInfo = sp + 80|0;
 $0 = sp + 72|0;
 $c = sp + 64|0;
 $children = sp + 56|0;
 $newBytePosition = sp + 128|0;
 $1 = sp + 40|0;
 $2 = sp + 32|0;
 $newInfo1 = sp;
 $3 = sp + 48|0;
 $4 = ($converter|0)!=(0|0);
 if ($4) {
  HEAP32[$converter>>2] = 0;
 }
 $5 = (($this) + 136|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 88|0);
 $7 = (($this) + 108|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = (($this) + 72|0);
  $11 = (__ZNK16TypeTreeIterator4NameEv($10)|0);
  $12 = ($name|0)==(0|0);
  do {
   if ($12) {
    $15 = $11;
    label = 6;
   } else {
    $13 = ($11|0)==(0|0);
    if ($13) {
     $15 = 0;
     label = 6;
    } else {
     $16 = HEAP32[580528>>2]|0;
     $17 = ($16>>>0)<=($11>>>0);
     $18 = HEAP32[580536>>2]|0;
     $19 = ($18>>>0)>($11>>>0);
     $or$cond$i$i$i = $17 & $19;
     if ($or$cond$i$i$i) {
      $20 = ($16>>>0)<=($name>>>0);
      $21 = ($18>>>0)>($name>>>0);
      $or$cond5$i$i$i = $20 & $21;
      if ($or$cond5$i$i$i) {
       $22 = ($11|0)==($name|0);
       if ($22) {
        break;
       } else {
        label = 11;
        break;
       }
      }
     }
     $23 = (_strcmp($name,$11)|0);
     $24 = ($23|0)==(0);
     if (!($24)) {
      label = 11;
     }
    }
   }
  } while(0);
  if ((label|0) == 6) {
   $14 = ($15|0)==($name|0);
   if (!($14)) {
    label = 11;
   }
  }
  if ((label|0) == 11) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(638680,0,638712,166,1,0,0,0);
  }
  $25 = (($newInfo) + 24|0);
  HEAP32[$25>>2] = 0;
  $26 = (($newInfo) + 28|0);
  HEAP32[$26>>2] = 0;
  $27 = $10;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 4)|0;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = $newInfo;
  $34 = $33;
  HEAP32[$34>>2] = $29;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = $32;
  $37 = (($this) + 64|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($newInfo) + 12|0);
  HEAP32[$39>>2] = $38;
  $40 = (($newInfo) + 16|0);
  HEAP32[$40>>2] = 1;
  $41 = (($newInfo) + 8|0);
  HEAP32[$41>>2] = $typeString;
  $42 = (($newInfo) + 24|0);
  __ZNK16TypeTreeIterator8ChildrenEv($0,$newInfo);
  $43 = $0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = (($43) + 4)|0;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = $42;
  $50 = $49;
  HEAP32[$50>>2] = $45;
  $51 = (($49) + 4)|0;
  $52 = $51;
  HEAP32[$52>>2] = $48;
  $53 = HEAP32[$37>>2]|0;
  $54 = (($newInfo) + 20|0);
  HEAP32[$54>>2] = $53;
  $55 = (($this) + 96|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($this) + 92|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($56|0)==($58|0);
  if ($59) {
   $68 = 0;
  } else {
   $60 = $56;
   $61 = $58;
   $62 = (($60) - ($61))|0;
   $63 = $62 << 5;
   $64 = (($63) + -1)|0;
   $68 = $64;
  }
  $65 = (($this) + 104|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = HEAP32[$7>>2]|0;
  $$neg2$i$i$i = (($68) - ($66))|0;
  $69 = ($$neg2$i$i$i|0)==($67|0);
  if ($69) {
   __ZNSt3__15dequeIN14SafeBinaryRead11StackedInfoENS_9allocatorIS2_EEE19__add_back_capacityEv($6);
   $$pre$i$i = HEAP32[$7>>2]|0;
   $$pre1$i$i = HEAP32[$65>>2]|0;
   $$pre2$i$i = HEAP32[$57>>2]|0;
   $$pre3$i$i = HEAP32[$55>>2]|0;
   $71 = $$pre$i$i;$72 = $$pre1$i$i;$74 = $$pre3$i$i;$75 = $$pre2$i$i;
  } else {
   $71 = $67;$72 = $66;$74 = $56;$75 = $58;
  }
  $70 = (($71) + ($72))|0;
  $73 = ($74|0)==($75|0);
  if ($73) {
   $83 = $71;$85 = $72;$88 = $74;
  } else {
   $76 = $70 >>> 7;
   $77 = (($75) + ($76<<2)|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = $70 & 127;
   $80 = (($78) + ($79<<5)|0);
   $81 = ($80|0)==(0|0);
   if ($81) {
    $83 = $71;$85 = $72;$88 = $75;
   } else {
    ;HEAP32[$80+0>>2]=HEAP32[$newInfo+0>>2]|0;HEAP32[$80+4>>2]=HEAP32[$newInfo+4>>2]|0;HEAP32[$80+8>>2]=HEAP32[$newInfo+8>>2]|0;HEAP32[$80+12>>2]=HEAP32[$newInfo+12>>2]|0;HEAP32[$80+16>>2]=HEAP32[$newInfo+16>>2]|0;HEAP32[$80+20>>2]=HEAP32[$newInfo+20>>2]|0;HEAP32[$80+24>>2]=HEAP32[$newInfo+24>>2]|0;HEAP32[$80+28>>2]=HEAP32[$newInfo+28>>2]|0;
    $$pre4$i$i = HEAP32[$7>>2]|0;
    $$pre = HEAP32[$65>>2]|0;
    $$pre59 = HEAP32[$57>>2]|0;
    $83 = $$pre4$i$i;$85 = $$pre;$88 = $$pre59;
   }
  }
  $82 = (($83) + 1)|0;
  HEAP32[$7>>2] = $82;
  $84 = (($85) + ($83))|0;
  $86 = $84 >>> 7;
  $87 = (($88) + ($86<<2)|0);
  $89 = HEAP32[$87>>2]|0;
  $90 = $84 & 127;
  $91 = (($89) + ($90<<5)|0);
  $92 = (($this) + 80|0);
  HEAP32[$92>>2] = $91;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$c>>2] = 0;
 $93 = (($c) + 4|0);
 HEAP32[$93>>2] = 0;
 $94 = (($this) + 80|0);
 $95 = HEAP32[$94>>2]|0;
 __ZNK16TypeTreeIterator8ChildrenEv($children,$95);
 $96 = (($95) + 20|0);
 $97 = HEAP32[$96>>2]|0;
 HEAP32[$newBytePosition>>2] = $97;
 $98 = (($95) + 24|0);
 $99 = $98;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = (($99) + 4)|0;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = $c;
 $106 = $105;
 HEAP32[$106>>2] = $101;
 $107 = (($105) + 4)|0;
 $108 = $107;
 HEAP32[$108>>2] = $104;
 $109 = ($101|0)==(0);
 L30: do {
  if ($109) {
   label = 30;
  } else {
   $110 = ($name|0)==(0|0);
   $111 = (($this) + 12|0);
   $112 = HEAP32[580528>>2]|0;
   $113 = HEAP32[580536>>2]|0;
   L32: while(1) {
    $114 = (__ZNK16TypeTreeIterator4NameEv($c)|0);
    do {
     if ($110) {
      $117 = $114;
      label = 24;
     } else {
      $115 = ($114|0)==(0|0);
      if ($115) {
       $117 = 0;
       label = 24;
      } else {
       $notlhs = ($112>>>0)>($114>>>0);
       $notrhs = ($113>>>0)<=($114>>>0);
       $or$cond$i19$not = $notrhs | $notlhs;
       $notlhs72 = ($112>>>0)>($name>>>0);
       $notrhs73 = ($113>>>0)<=($name>>>0);
       $or$cond5$i20$not = $notrhs73 | $notlhs72;
       $brmerge70 = $or$cond$i19$not | $or$cond5$i20$not;
       if ($brmerge70) {
        $119 = (_strcmp($name,$114)|0);
        $120 = ($119|0)==(0);
        if ($120) {
         break L32;
        } else {
         break;
        }
       } else {
        $118 = ($114|0)==($name|0);
        if ($118) {
         break L32;
        } else {
         break;
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 24) {
     label = 0;
     $116 = ($117|0)==($name|0);
     if ($116) {
      break;
     }
    }
    $121 = HEAP32[$this>>2]|0;
    $122 = $121 & 512;
    $123 = ($122|0)!=(0);
    __ZL4WalkRK16TypeTreeIteratorR12CachedReaderPib($c,$111,$newBytePosition,$123);
    __ZNK16TypeTreeIterator4NextEv($1,$c);
    $124 = $1;
    $125 = $124;
    $126 = HEAP32[$125>>2]|0;
    $127 = (($124) + 4)|0;
    $128 = $127;
    $129 = HEAP32[$128>>2]|0;
    $130 = $c;
    $131 = $130;
    HEAP32[$131>>2] = $126;
    $132 = (($130) + 4)|0;
    $133 = $132;
    HEAP32[$133>>2] = $129;
    $134 = ($126|0)==(0);
    if ($134) {
     label = 30;
     break L30;
    }
   }
   $$pr = HEAP32[$c>>2]|0;
   $135 = ($$pr|0)==(0|0);
   if ($135) {
    label = 30;
   } else {
    $382 = $112;$384 = $113;
   }
  }
 } while(0);
 if ((label|0) == 30) {
  $136 = (__Z29GetGlobalAllowNameConversionsv()|0);
  $137 = (($95) + 8|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = (__Z23GetAllowNameConversionsPK20AllowNameConversionsPKcS3_($136,$138,$name)|0);
  $140 = (($this) + 140|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = HEAP32[$137>>2]|0;
  $143 = (__Z23GetAllowNameConversionsPK20AllowNameConversionsPKcS3_($141,$142,$name)|0);
  $144 = (($95) + 12|0);
  $145 = HEAP32[$144>>2]|0;
  HEAP32[$newBytePosition>>2] = $145;
  $146 = $children;
  $147 = $146;
  $148 = HEAP32[$147>>2]|0;
  $149 = (($146) + 4)|0;
  $150 = $149;
  $151 = HEAP32[$150>>2]|0;
  $152 = $c;
  $153 = $152;
  HEAP32[$153>>2] = $148;
  $154 = (($152) + 4)|0;
  $155 = $154;
  HEAP32[$155>>2] = $151;
  $156 = ($148|0)==(0);
  if ($156) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $157 = ($name|0)==(0|0);
  $158 = ($143|0)==(0|0);
  $159 = ($139|0)==(0|0);
  $160 = (($this) + 12|0);
  $161 = (($139) + 4|0);
  $162 = (($143) + 4|0);
  $163 = HEAP32[580528>>2]|0;
  $164 = HEAP32[580536>>2]|0;
  L49: do {
   if ($157) {
    while(1) {
     $165 = (__ZNK16TypeTreeIterator4NameEv($c)|0);
     $166 = ($165|0)==(0|0);
     if ($166) {
      break L49;
     }
     $167 = (__ZNK16TypeTreeIterator4NameEv($c)|0);
     if (!($158)) {
      $__rt$0$in1$i$i$i$us = HEAP32[$162>>2]|0;
      $168 = ($__rt$0$in1$i$i$i$us|0)==(0|0);
      if (!($168)) {
       $__rt$0$in2$i$i$i$us = $__rt$0$in1$i$i$i$us;
       while(1) {
        $169 = (($__rt$0$in2$i$i$i$us) + 16|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = (_strcmp($167,$170)|0);
        $172 = ($171|0)<(0);
        if ($172) {
         $__rt$0$in$in$be$i$i$i$us = $__rt$0$in2$i$i$i$us;
        } else {
         $173 = (_strcmp($170,$167)|0);
         $174 = ($173|0)<(0);
         if (!($174)) {
          break L49;
         }
         $175 = (($__rt$0$in2$i$i$i$us) + 4|0);
         $__rt$0$in$in$be$i$i$i$us = $175;
        }
        $__rt$0$in$i$i$i$us = HEAP32[$__rt$0$in$in$be$i$i$i$us>>2]|0;
        $176 = ($__rt$0$in$i$i$i$us|0)==(0|0);
        if ($176) {
         break;
        } else {
         $__rt$0$in2$i$i$i$us = $__rt$0$in$i$i$i$us;
        }
       }
      }
     }
     $177 = (__ZNK16TypeTreeIterator4NameEv($c)|0);
     if (!($159)) {
      $__rt$0$in1$i$i$i34$us = HEAP32[$161>>2]|0;
      $178 = ($__rt$0$in1$i$i$i34$us|0)==(0|0);
      if (!($178)) {
       $__rt$0$in2$i$i$i35$us = $__rt$0$in1$i$i$i34$us;
       while(1) {
        $179 = (($__rt$0$in2$i$i$i35$us) + 16|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = (_strcmp($177,$180)|0);
        $182 = ($181|0)<(0);
        if ($182) {
         $__rt$0$in$in$be$i$i$i37$us = $__rt$0$in2$i$i$i35$us;
        } else {
         $183 = (_strcmp($180,$177)|0);
         $184 = ($183|0)<(0);
         if (!($184)) {
          break L49;
         }
         $185 = (($__rt$0$in2$i$i$i35$us) + 4|0);
         $__rt$0$in$in$be$i$i$i37$us = $185;
        }
        $__rt$0$in$i$i$i38$us = HEAP32[$__rt$0$in$in$be$i$i$i37$us>>2]|0;
        $186 = ($__rt$0$in$i$i$i38$us|0)==(0|0);
        if ($186) {
         break;
        } else {
         $__rt$0$in2$i$i$i35$us = $__rt$0$in$i$i$i38$us;
        }
       }
      }
     }
     $187 = HEAP32[$this>>2]|0;
     $188 = $187 & 512;
     $189 = ($188|0)!=(0);
     __ZL4WalkRK16TypeTreeIteratorR12CachedReaderPib($c,$160,$newBytePosition,$189);
     __ZNK16TypeTreeIterator4NextEv($2,$c);
     $190 = $2;
     $191 = $190;
     $192 = HEAP32[$191>>2]|0;
     $193 = (($190) + 4)|0;
     $194 = $193;
     $195 = HEAP32[$194>>2]|0;
     $196 = $c;
     $197 = $196;
     HEAP32[$197>>2] = $192;
     $198 = (($196) + 4)|0;
     $199 = $198;
     HEAP32[$199>>2] = $195;
     $200 = ($192|0)==(0);
     if ($200) {
      $$0 = 0;
      break;
     }
    }
    STACKTOP = sp;return ($$0|0);
   } else {
    while(1) {
     $201 = (__ZNK16TypeTreeIterator4NameEv($c)|0);
     $202 = ($201|0)==(0|0);
     do {
      if ($202) {
       $203 = ($name|0)==(0|0);
       if ($203) {
        break L49;
       }
      } else {
       $notlhs74 = ($163>>>0)>($201>>>0);
       $notrhs75 = ($164>>>0)<=($201>>>0);
       $or$cond$i28$not = $notrhs75 | $notlhs74;
       $notlhs76 = ($163>>>0)>($name>>>0);
       $notrhs77 = ($164>>>0)<=($name>>>0);
       $or$cond5$i29$not = $notrhs77 | $notlhs76;
       $brmerge71 = $or$cond$i28$not | $or$cond5$i29$not;
       if ($brmerge71) {
        $205 = (_strcmp($name,$201)|0);
        $206 = ($205|0)==(0);
        if ($206) {
         break L49;
        } else {
         break;
        }
       } else {
        $204 = ($201|0)==($name|0);
        if ($204) {
         break L49;
        } else {
         break;
        }
       }
      }
     } while(0);
     $207 = (__ZNK16TypeTreeIterator4NameEv($c)|0);
     if (!($158)) {
      $__rt$0$in1$i$i$i = HEAP32[$162>>2]|0;
      $208 = ($__rt$0$in1$i$i$i|0)==(0|0);
      if (!($208)) {
       $__rt$0$in2$i$i$i = $__rt$0$in1$i$i$i;
       while(1) {
        $209 = (($__rt$0$in2$i$i$i) + 16|0);
        $210 = HEAP32[$209>>2]|0;
        $211 = (_strcmp($207,$210)|0);
        $212 = ($211|0)<(0);
        if ($212) {
         $__rt$0$in$in$be$i$i$i = $__rt$0$in2$i$i$i;
        } else {
         $213 = (_strcmp($210,$207)|0);
         $214 = ($213|0)<(0);
         if (!($214)) {
          break L49;
         }
         $215 = (($__rt$0$in2$i$i$i) + 4|0);
         $__rt$0$in$in$be$i$i$i = $215;
        }
        $__rt$0$in$i$i$i = HEAP32[$__rt$0$in$in$be$i$i$i>>2]|0;
        $216 = ($__rt$0$in$i$i$i|0)==(0|0);
        if ($216) {
         break;
        } else {
         $__rt$0$in2$i$i$i = $__rt$0$in$i$i$i;
        }
       }
      }
     }
     $217 = (__ZNK16TypeTreeIterator4NameEv($c)|0);
     if (!($159)) {
      $__rt$0$in1$i$i$i34 = HEAP32[$161>>2]|0;
      $218 = ($__rt$0$in1$i$i$i34|0)==(0|0);
      if (!($218)) {
       $__rt$0$in2$i$i$i35 = $__rt$0$in1$i$i$i34;
       while(1) {
        $219 = (($__rt$0$in2$i$i$i35) + 16|0);
        $220 = HEAP32[$219>>2]|0;
        $221 = (_strcmp($217,$220)|0);
        $222 = ($221|0)<(0);
        if ($222) {
         $__rt$0$in$in$be$i$i$i37 = $__rt$0$in2$i$i$i35;
        } else {
         $223 = (_strcmp($220,$217)|0);
         $224 = ($223|0)<(0);
         if (!($224)) {
          break L49;
         }
         $225 = (($__rt$0$in2$i$i$i35) + 4|0);
         $__rt$0$in$in$be$i$i$i37 = $225;
        }
        $__rt$0$in$i$i$i38 = HEAP32[$__rt$0$in$in$be$i$i$i37>>2]|0;
        $226 = ($__rt$0$in$i$i$i38|0)==(0|0);
        if ($226) {
         break;
        } else {
         $__rt$0$in2$i$i$i35 = $__rt$0$in$i$i$i38;
        }
       }
      }
     }
     $227 = HEAP32[$this>>2]|0;
     $228 = $227 & 512;
     $229 = ($228|0)!=(0);
     __ZL4WalkRK16TypeTreeIteratorR12CachedReaderPib($c,$160,$newBytePosition,$229);
     __ZNK16TypeTreeIterator4NextEv($2,$c);
     $230 = $2;
     $231 = $230;
     $232 = HEAP32[$231>>2]|0;
     $233 = (($230) + 4)|0;
     $234 = $233;
     $235 = HEAP32[$234>>2]|0;
     $236 = $c;
     $237 = $236;
     HEAP32[$237>>2] = $232;
     $238 = (($236) + 4)|0;
     $239 = $238;
     HEAP32[$239>>2] = $235;
     $240 = ($232|0)==(0);
     if ($240) {
      $$0 = 0;
      break;
     }
    }
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $$pr47 = HEAP32[$c>>2]|0;
  $241 = ($$pr47|0)==(0|0);
  if ($241) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $382 = $163;$384 = $164;
  }
 }
 $242 = $c;
 $243 = $242;
 $244 = HEAP32[$243>>2]|0;
 $245 = (($242) + 4)|0;
 $246 = $245;
 $247 = HEAP32[$246>>2]|0;
 $248 = $98;
 $249 = $248;
 HEAP32[$249>>2] = $244;
 $250 = (($248) + 4)|0;
 $251 = $250;
 HEAP32[$251>>2] = $247;
 $252 = HEAP32[$newBytePosition>>2]|0;
 HEAP32[$96>>2] = $252;
 $253 = (__ZNK16TypeTreeIterator7GetNodeEv($95)|0);
 $254 = (($253) + 3|0);
 $255 = HEAP8[$254>>0]|0;
 $256 = ($255<<24>>24)==(0);
 do {
  if (!($256)) {
   $257 = HEAP32[$c>>2]|0;
   $258 = HEAP32[$children>>2]|0;
   $259 = ($257|0)==($258|0);
   if ($259) {
    $260 = HEAP32[$93>>2]|0;
    $261 = (($children) + 4|0);
    $262 = HEAP32[$261>>2]|0;
    $phitmp$i = ($260|0)==($262|0);
    if ($phitmp$i) {
     break;
    }
   }
   $263 = (($this) + 84|0);
   $264 = HEAP32[$263>>2]|0;
   $265 = HEAP32[$264>>2]|0;
   $266 = (__ZNK16TypeTreeIterator7GetNodeEv($c)|0);
   $267 = (($266) + 12|0);
   $268 = HEAP32[$267>>2]|0;
   $269 = ($268|0)==(-1);
   if ($269) {
    label = 75;
   } else {
    $270 = (__ZNK16TypeTreeIterator7GetNodeEv($c)|0);
    $271 = (($270) + 20|0);
    $272 = HEAP32[$271>>2]|0;
    $273 = $272 & 49152;
    $274 = ($273|0)==(0);
    if ($274) {
     $275 = (__ZNK16TypeTreeIterator7GetNodeEv($c)|0);
     $276 = (($275) + 12|0);
     $277 = HEAP32[$276>>2]|0;
     $278 = Math_imul($277, $265)|0;
     $279 = HEAP32[$newBytePosition>>2]|0;
     $280 = (($279) + ($278))|0;
     HEAP32[$newBytePosition>>2] = $280;
    } else {
     label = 75;
    }
   }
   if ((label|0) == 75) {
    $281 = (($this) + 132|0);
    $282 = HEAP32[$281>>2]|0;
    $283 = (($this) + 128|0);
    $284 = HEAP32[$283>>2]|0;
    $285 = (($282) + -1)|0;
    $286 = (($285) + ($284))|0;
    $287 = (($this) + 116|0);
    $288 = HEAP32[$287>>2]|0;
    $289 = (($286>>>0) / 341)&-1;
    $290 = (($288) + ($289<<2)|0);
    $291 = HEAP32[$290>>2]|0;
    $292 = (($286>>>0) % 341)&-1;
    $293 = ((($291) + (($292*12)|0)|0) + 8|0);
    $294 = HEAP32[$293>>2]|0;
    $295 = ($294|0)>($265|0);
    if ($295) {
     $i$0$ph = 0;
    } else {
     $296 = ((($291) + (($292*12)|0)|0) + 4|0);
     $297 = HEAP32[$296>>2]|0;
     HEAP32[$newBytePosition>>2] = $297;
     $298 = HEAP32[$293>>2]|0;
     $i$0$ph = $298;
    }
    $299 = ($i$0$ph|0)<($265|0);
    if ($299) {
     $300 = (($this) + 12|0);
     $i$048 = $i$0$ph;
     while(1) {
      $301 = HEAP32[$this>>2]|0;
      $302 = $301 & 512;
      $303 = ($302|0)!=(0);
      __ZL4WalkRK16TypeTreeIteratorR12CachedReaderPib($c,$300,$newBytePosition,$303);
      $304 = (($i$048) + 1)|0;
      $exitcond = ($304|0)==($265|0);
      if ($exitcond) {
       break;
      } else {
       $i$048 = $304;
      }
     }
    }
    HEAP32[$293>>2] = $265;
    $305 = HEAP32[$newBytePosition>>2]|0;
    $306 = ((($291) + (($292*12)|0)|0) + 4|0);
    HEAP32[$306>>2] = $305;
   }
   $307 = HEAP32[$263>>2]|0;
   $308 = HEAP32[$307>>2]|0;
   $309 = (($308) + 1)|0;
   HEAP32[$307>>2] = $309;
  }
 } while(0);
 $310 = (($newInfo1) + 24|0);
 HEAP32[$310>>2] = 0;
 $311 = (($newInfo1) + 28|0);
 HEAP32[$311>>2] = 0;
 $312 = $c;
 $313 = $312;
 $314 = HEAP32[$313>>2]|0;
 $315 = (($312) + 4)|0;
 $316 = $315;
 $317 = HEAP32[$316>>2]|0;
 $318 = $newInfo1;
 $319 = $318;
 HEAP32[$319>>2] = $314;
 $320 = (($318) + 4)|0;
 $321 = $320;
 HEAP32[$321>>2] = $317;
 $322 = HEAP32[$newBytePosition>>2]|0;
 $323 = (($newInfo1) + 12|0);
 HEAP32[$323>>2] = $322;
 $324 = (($newInfo1) + 16|0);
 HEAP32[$324>>2] = 1;
 $325 = (($newInfo1) + 24|0);
 __ZNK16TypeTreeIterator8ChildrenEv($3,$newInfo1);
 $326 = $3;
 $327 = $326;
 $328 = HEAP32[$327>>2]|0;
 $329 = (($326) + 4)|0;
 $330 = $329;
 $331 = HEAP32[$330>>2]|0;
 $332 = $325;
 $333 = $332;
 HEAP32[$333>>2] = $328;
 $334 = (($332) + 4)|0;
 $335 = $334;
 HEAP32[$335>>2] = $331;
 $336 = HEAP32[$newBytePosition>>2]|0;
 $337 = (($newInfo1) + 20|0);
 HEAP32[$337>>2] = $336;
 $338 = (($newInfo1) + 8|0);
 HEAP32[$338>>2] = $typeString;
 $339 = (($this) + 96|0);
 $340 = HEAP32[$339>>2]|0;
 $341 = (($this) + 92|0);
 $342 = HEAP32[$341>>2]|0;
 $343 = ($340|0)==($342|0);
 if ($343) {
  $352 = 0;
 } else {
  $344 = $340;
  $345 = $342;
  $346 = (($344) - ($345))|0;
  $347 = $346 << 5;
  $348 = (($347) + -1)|0;
  $352 = $348;
 }
 $349 = (($this) + 104|0);
 $350 = HEAP32[$349>>2]|0;
 $351 = HEAP32[$7>>2]|0;
 $$neg2$i$i$i7 = (($352) - ($350))|0;
 $353 = ($$neg2$i$i$i7|0)==($351|0);
 if ($353) {
  __ZNSt3__15dequeIN14SafeBinaryRead11StackedInfoENS_9allocatorIS2_EEE19__add_back_capacityEv($6);
  $$pre$i$i9 = HEAP32[$7>>2]|0;
  $$pre1$i$i10 = HEAP32[$349>>2]|0;
  $$pre2$i$i11 = HEAP32[$341>>2]|0;
  $$pre3$i$i12 = HEAP32[$339>>2]|0;
  $355 = $$pre$i$i9;$356 = $$pre1$i$i10;$358 = $$pre3$i$i12;$359 = $$pre2$i$i11;
 } else {
  $355 = $351;$356 = $350;$358 = $340;$359 = $342;
 }
 $354 = (($355) + ($356))|0;
 $357 = ($358|0)==($359|0);
 if ($357) {
  $367 = $355;$369 = $356;$372 = $358;
 } else {
  $360 = $354 >>> 7;
  $361 = (($359) + ($360<<2)|0);
  $362 = HEAP32[$361>>2]|0;
  $363 = $354 & 127;
  $364 = (($362) + ($363<<5)|0);
  $365 = ($364|0)==(0|0);
  if ($365) {
   $367 = $355;$369 = $356;$372 = $359;
  } else {
   ;HEAP32[$364+0>>2]=HEAP32[$newInfo1+0>>2]|0;HEAP32[$364+4>>2]=HEAP32[$newInfo1+4>>2]|0;HEAP32[$364+8>>2]=HEAP32[$newInfo1+8>>2]|0;HEAP32[$364+12>>2]=HEAP32[$newInfo1+12>>2]|0;HEAP32[$364+16>>2]=HEAP32[$newInfo1+16>>2]|0;HEAP32[$364+20>>2]=HEAP32[$newInfo1+20>>2]|0;HEAP32[$364+24>>2]=HEAP32[$newInfo1+24>>2]|0;HEAP32[$364+28>>2]=HEAP32[$newInfo1+28>>2]|0;
   $$pre4$i$i14 = HEAP32[$7>>2]|0;
   $$pre66 = HEAP32[$349>>2]|0;
   $$pre67 = HEAP32[$341>>2]|0;
   $367 = $$pre4$i$i14;$369 = $$pre66;$372 = $$pre67;
  }
 }
 $366 = (($367) + 1)|0;
 HEAP32[$7>>2] = $366;
 $368 = (($369) + ($367))|0;
 $370 = $368 >>> 7;
 $371 = (($372) + ($370<<2)|0);
 $373 = HEAP32[$371>>2]|0;
 $374 = $368 & 127;
 $375 = (($373) + ($374<<5)|0);
 HEAP32[$94>>2] = $375;
 $376 = (__ZNK16TypeTreeIterator4TypeEv($c)|0);
 $377 = ($typeString|0)==(0|0);
 do {
  if ($377) {
   $380 = $376;
   label = 91;
  } else {
   $378 = ($376|0)==(0|0);
   if ($378) {
    $380 = 0;
    label = 91;
   } else {
    $381 = ($382>>>0)<=($376>>>0);
    $383 = ($384>>>0)>($376>>>0);
    $or$cond$i = $381 & $383;
    if ($or$cond$i) {
     $385 = ($382>>>0)<=($typeString>>>0);
     $386 = ($384>>>0)>($typeString>>>0);
     $or$cond5$i = $385 & $386;
     if ($or$cond5$i) {
      $387 = ($376|0)==($typeString|0);
      $$0$i6 = $387;
      break;
     }
    }
    $388 = (_strcmp($typeString,$376)|0);
    $389 = ($388|0)==(0);
    $$0$i6 = $389;
   }
  }
 } while(0);
 if ((label|0) == 91) {
  $379 = ($380|0)==($typeString|0);
  $$0$i6 = $379;
 }
 $brmerge = $$0$i6 | $allowTypeConversion;
 if (!($brmerge)) {
  $390 = HEAP32[$7>>2]|0;
  $391 = ($390|0)==(1);
  if (!($391)) {
   if (!($4)) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $401 = (__ZNK16TypeTreeIterator4TypeEv($c)|0);
   HEAP32[$arg$i>>2] = $401;
   $402 = (($arg$i) + 4|0);
   HEAP32[$402>>2] = $typeString;
   $403 = HEAP32[638672>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EEPFbPvR14SafeBinaryReadEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS_9allocatorISA_EEE4findIS4_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_S5_EEiEERKT_($found$i,$403,$arg$i);
   $404 = HEAP32[638672>>2]|0;
   $405 = (($404) + 4|0);
   $406 = HEAP32[$found$i>>2]|0;
   $407 = ($406|0)==($405|0);
   if ($407) {
    $$0$i = 0;
   } else {
    $408 = (($406) + 24|0);
    $409 = HEAP32[$408>>2]|0;
    $$0$i = $409;
   }
   HEAP32[$converter>>2] = $$0$i;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $392 = (__ZNK16TypeTreeIterator7GetNodeEv($c)|0);
 $393 = (($392) + 12|0);
 $394 = HEAP32[$393>>2]|0;
 $395 = ($394|0)==(-1);
 if ($395) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $396 = (__ZNK16TypeTreeIterator7GetNodeEv($c)|0);
  $397 = (($396) + 20|0);
  $398 = HEAP32[$397>>2]|0;
  $399 = $398 & 49152;
  $400 = ($399|0)==(0);
  $$ = $400 ? 2 : 1;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function __ZN14SafeBinaryRead10SetVersionEi($this,$version) {
 $this = $this|0;
 $version = $version|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 HEAP32[$2>>2] = $version;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead11EndTransferEv($this) {
 $this = $this|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 104|0);
 $3 = (($1) + -1)|0;
 HEAP32[$0>>2] = $3;
 $4 = (($this) + 96|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 if ($8) {
  $15 = 0;
 } else {
  $9 = $5;
  $10 = $7;
  $11 = (($9) - ($10))|0;
  $12 = $11 << 5;
  $13 = (($12) + -1)|0;
  $15 = $13;
 }
 $14 = HEAP32[$2>>2]|0;
 $$neg1$i = (1 - ($1))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($15))|0;
 $16 = (($$neg2$i$i$i) - ($14))|0;
 $17 = ($16>>>0)>(255);
 if ($17) {
  $18 = (($5) + -4|0);
  $19 = HEAP32[$18>>2]|0;
  __ZdlPv($19);
  $20 = HEAP32[$4>>2]|0;
  $21 = (($20) + -4|0);
  $__new_last2$i$i$i$i$i = $21;
  $22 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($21) + ($22)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $23 = $uglygep3$i$i$i$i$i >>> 2;
  $24 = $23 ^ -1;
  $scevgep4$i$i$i$i$i = (($20) + ($24<<2)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i$i$i;
  $$pre = HEAP32[$0>>2]|0;
  $26 = $$pre;
 } else {
  $26 = $3;
 }
 $25 = ($26|0)==(0);
 if ($25) {
  $37 = (($this) + 80|0);
  HEAP32[$37>>2] = 0;
  $38 = (($this) + 136|0);
  HEAP8[$38>>0] = 1;
  STACKTOP = sp;return;
 } else {
  $27 = HEAP32[$2>>2]|0;
  $28 = (($26) + -1)|0;
  $29 = (($28) + ($27))|0;
  $30 = HEAP32[$6>>2]|0;
  $31 = $29 >>> 7;
  $32 = (($30) + ($31<<2)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $29 & 127;
  $35 = (($33) + ($34<<5)|0);
  $36 = (($this) + 80|0);
  HEAP32[$36>>2] = $35;
  $38 = (($this) + 136|0);
  HEAP8[$38>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,$name,$typeString,$size) {
 $this = $this|0;
 $name = $name|0;
 $typeString = $typeString|0;
 $size = $size|0;
 var $$0 = 0, $$neg2$i$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre1 = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $$pre3$i$i = 0, $$pre4$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,$typeString,0,0)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$size,638720,0);
 $2 = (($this) + 112|0);
 $3 = (($this) + 120|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 116|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10|0)==(0);
 if ($11) {
  $18 = 0;
 } else {
  $12 = ($10*341)|0;
  $13 = (($12) + -1)|0;
  $18 = $13;
 }
 $14 = (($this) + 128|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 132|0);
 $17 = HEAP32[$16>>2]|0;
 $$neg2$i$i$i = (($18) - ($15))|0;
 $19 = ($$neg2$i$i$i|0)==($17|0);
 if ($19) {
  __ZNSt3__15dequeIN14SafeBinaryRead17ArrayPositionInfoENS_9allocatorIS2_EEE19__add_back_capacityEv($2);
  $$pre$i$i = HEAP32[$16>>2]|0;
  $$pre1$i$i = HEAP32[$14>>2]|0;
  $$pre2$i$i = HEAP32[$5>>2]|0;
  $$pre3$i$i = HEAP32[$3>>2]|0;
  $21 = $$pre$i$i;$22 = $$pre1$i$i;$24 = $$pre3$i$i;$25 = $$pre2$i$i;
 } else {
  $21 = $17;$22 = $15;$24 = $4;$25 = $6;
 }
 $20 = (($21) + ($22))|0;
 $23 = ($24|0)==($25|0);
 if ($23) {
  $35 = $21;$37 = $22;$40 = $24;
 } else {
  $26 = (($20>>>0) / 341)&-1;
  $27 = (($25) + ($26<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($20>>>0) % 341)&-1;
  $30 = (($28) + (($29*12)|0)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $35 = $21;$37 = $22;$40 = $25;
  } else {
   HEAP32[$30>>2] = 0;
   $32 = ((($28) + (($29*12)|0)|0) + 4|0);
   HEAP32[$32>>2] = -1;
   $33 = ((($28) + (($29*12)|0)|0) + 8|0);
   HEAP32[$33>>2] = 2147483647;
   $$pre4$i$i = HEAP32[$16>>2]|0;
   $$pre = HEAP32[$14>>2]|0;
   $$pre1 = HEAP32[$5>>2]|0;
   $35 = $$pre4$i$i;$37 = $$pre;$40 = $$pre1;
  }
 }
 $34 = (($35) + 1)|0;
 HEAP32[$16>>2] = $34;
 $36 = (($37) + ($35))|0;
 $38 = (($36>>>0) / 341)&-1;
 $39 = (($40) + ($38<<2)|0);
 $41 = HEAP32[$39>>2]|0;
 $42 = (($36>>>0) % 341)&-1;
 $43 = (($41) + (($42*12)|0)|0);
 $44 = (($this) + 84|0);
 HEAP32[$44>>2] = $43;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14SafeBinaryRead16EndArrayTransferEv($this) {
 $this = $this|0;
 var $$neg1$i = 0, $$neg1$i$i = 0, $$neg2$i$i$i = 0, $$neg2$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 128|0);
 $3 = (($1) + -1)|0;
 HEAP32[$0>>2] = $3;
 $4 = (($this) + 120|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = ($11|0)==(0);
 if ($12) {
  $16 = 0;
 } else {
  $13 = ($11*341)|0;
  $14 = (($13) + -1)|0;
  $16 = $14;
 }
 $15 = HEAP32[$2>>2]|0;
 $$neg1$i = (1 - ($1))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($16))|0;
 $17 = (($$neg2$i$i$i) - ($15))|0;
 $18 = ($17>>>0)>(681);
 if ($18) {
  $19 = (($5) + -4|0);
  $20 = HEAP32[$19>>2]|0;
  __ZdlPv($20);
  $21 = HEAP32[$4>>2]|0;
  $22 = (($21) + -4|0);
  $__new_last2$i$i$i$i$i = $22;
  $23 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($22) + ($23)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $24 = $uglygep3$i$i$i$i$i >>> 2;
  $25 = $24 ^ -1;
  $scevgep4$i$i$i$i$i = (($21) + ($25<<2)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i$i$i;
  $$pre = HEAP32[$0>>2]|0;
  $27 = $$pre;
 } else {
  $27 = $3;
 }
 $26 = ($27|0)==(0);
 if ($26) {
  $38 = (($this) + 84|0);
  HEAP32[$38>>2] = 0;
 } else {
  $28 = HEAP32[$2>>2]|0;
  $29 = (($27) + -1)|0;
  $30 = (($29) + ($28))|0;
  $31 = HEAP32[$6>>2]|0;
  $32 = (($30>>>0) / 341)&-1;
  $33 = (($31) + ($32<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($30>>>0) % 341)&-1;
  $36 = (($34) + (($35*12)|0)|0);
  $37 = (($this) + 84|0);
  HEAP32[$37>>2] = $36;
 }
 $39 = (($this) + 108|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 104|0);
 $42 = (($40) + -1)|0;
 HEAP32[$39>>2] = $42;
 $43 = (($this) + 96|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 92|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($44|0)==($46|0);
 if ($47) {
  $54 = 0;
 } else {
  $48 = $44;
  $49 = $46;
  $50 = (($48) - ($49))|0;
  $51 = $50 << 5;
  $52 = (($51) + -1)|0;
  $54 = $52;
 }
 $53 = HEAP32[$41>>2]|0;
 $$neg1$i$i = (1 - ($40))|0;
 $$neg2$i$i$i$i = (($$neg1$i$i) + ($54))|0;
 $55 = (($$neg2$i$i$i$i) - ($53))|0;
 $56 = ($55>>>0)>(255);
 if ($56) {
  $57 = (($44) + -4|0);
  $58 = HEAP32[$57>>2]|0;
  __ZdlPv($58);
  $59 = HEAP32[$43>>2]|0;
  $60 = (($59) + -4|0);
  $__new_last2$i$i$i$i$i$i = $60;
  $61 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($60) + ($61)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $62 = $uglygep3$i$i$i$i$i$i >>> 2;
  $63 = $62 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($59) + ($63<<2)|0);
  HEAP32[$43>>2] = $scevgep4$i$i$i$i$i$i;
  $$pre$i = HEAP32[$39>>2]|0;
  $65 = $$pre$i;
 } else {
  $65 = $42;
 }
 $64 = ($65|0)==(0);
 if ($64) {
  $76 = (($this) + 80|0);
  HEAP32[$76>>2] = 0;
  $77 = (($this) + 136|0);
  HEAP8[$77>>0] = 1;
  STACKTOP = sp;return;
 } else {
  $66 = HEAP32[$41>>2]|0;
  $67 = (($65) + -1)|0;
  $68 = (($67) + ($66))|0;
  $69 = HEAP32[$45>>2]|0;
  $70 = $68 >>> 7;
  $71 = (($69) + ($70<<2)|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = $68 & 127;
  $74 = (($72) + ($73<<5)|0);
  $75 = (($this) + 80|0);
  HEAP32[$75>>2] = $74;
  $77 = (($this) + 136|0);
  HEAP8[$77>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead16IsCurrentVersionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK16TypeTreeIterator7GetNodeEv($1)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 << 16 >> 16;
 $7 = ($3|0)==($6|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN14SafeBinaryRead12IsOldVersionEi($this,$version) {
 $this = $this|0;
 $version = $version|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK16TypeTreeIterator7GetNodeEv($1)|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 << 16 >> 16;
 $5 = ($4|0)==($version|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($this,$version) {
 $this = $this|0;
 $version = $version|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK16TypeTreeIterator7GetNodeEv($1)|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 << 16 >> 16;
 $5 = ($4|0)<=($version|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN14SafeBinaryRead16TransferTypelessEPjPKc17TransferMetaFlags($this,$byteSize,$name,$metaflag) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $name = $name|0;
 $metaflag = $metaflag|0;
 var $0 = 0, $1 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $0 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,$name,638728,$size)|0);
 if ($0) {
  $1 = HEAP32[$size>>2]|0;
  HEAP32[$byteSize>>2] = $1;
  __ZN14SafeBinaryRead16EndArrayTransferEv($this);
  STACKTOP = sp;return;
 } else {
  HEAP32[$byteSize>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead20TransferTypelessDataEjPvi($this,$byteSize,$copyData,$metaData) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $copyData = $copyData|0;
 $metaData = $metaData|0;
 var $0 = 0, $1 = 0, $2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($copyData|0)==(0|0);
 $1 = ($byteSize|0)==(0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 12|0);
 __ZN12CachedReader4ReadEPvj($2,$copyData,$byteSize);
 STACKTOP = sp;return;
}
function __ZNSt3__15dequeIN14SafeBinaryRead17ArrayPositionInfoENS_9allocatorIS2_EEE19__add_back_capacityEv($this) {
 $this = $this|0;
 var $$0153 = 0, $$055 = 0, $$pr$pre$i = 0, $$pr$pre$i36 = 0, $$pre = 0, $$pre$i = 0, $$pre$i33 = 0, $$pre50 = 0, $$pre8$i = 0, $$pre8$i19 = 0, $$pre8$i28 = 0, $$pre8$i38 = 0, $$sum = 0, $$sum$i = 0, $$sum$i30 = 0, $$sum41 = 0, $$sum42 = 0, $$sum43 = 0, $$sum51 = 0, $$sum52 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__buf = 0, $__i$0 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $__buf = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>(340);
 if ($3) {
  $4 = (($2) + -341)|0;
  HEAP32[$1>>2] = $4;
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($6) + 4|0);
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  do {
   if ($13) {
    $14 = HEAP32[$this>>2]|0;
    $15 = ($8>>>0)>($14>>>0);
    if ($15) {
     $16 = $8;
     $17 = $14;
     $18 = (($16) - ($17))|0;
     $19 = $18 >> 2;
     $20 = (($19) + 1)|0;
     $21 = (($20|0) / -2)&-1;
     $$sum42 = (($21) + 1)|0;
     $22 = (($6) + ($$sum42<<2)|0);
     $23 = $10;
     $24 = (($23) - ($16))|0;
     $25 = $24 >> 2;
     _memmove(($22|0),($8|0),($24|0))|0;
     $$sum$i = (($25) + 1)|0;
     $$sum43 = (($$sum$i) + ($21))|0;
     $26 = (($6) + ($$sum43<<2)|0);
     HEAP32[$9>>2] = $26;
     $27 = HEAP32[$5>>2]|0;
     $28 = (($27) + ($21<<2)|0);
     HEAP32[$5>>2] = $28;
     $54 = $26;
     label = 13;
     break;
    }
    $29 = $10;
    $30 = $14;
    $31 = (($29) - ($30))|0;
    $32 = $31 >> 1;
    $33 = ($32|0)==(0);
    $34 = $33 ? 1 : $32;
    $35 = $34 >>> 2;
    $36 = $34 << 2;
    $37 = (__Znwj($36)|0);
    $38 = (($37) + ($35<<2)|0);
    $39 = (($37) + ($34<<2)|0);
    $40 = ($8|0)==($10|0);
    if ($40) {
     $49 = $38;$51 = $14;
    } else {
     $42 = $38;$44 = $8;
     while(1) {
      $41 = ($42|0)==(0|0);
      if ($41) {
       $46 = 0;
      } else {
       $43 = HEAP32[$44>>2]|0;
       HEAP32[$42>>2] = $43;
       $46 = $42;
      }
      $45 = (($46) + 4|0);
      $47 = (($44) + 4|0);
      $48 = ($47|0)==($10|0);
      if ($48) {
       break;
      } else {
       $42 = $45;$44 = $47;
      }
     }
     $$pre$i = HEAP32[$this>>2]|0;
     $49 = $45;$51 = $$pre$i;
    }
    HEAP32[$this>>2] = $37;
    HEAP32[$5>>2] = $38;
    HEAP32[$9>>2] = $49;
    HEAP32[$11>>2] = $39;
    $50 = ($51|0)==(0|0);
    if ($50) {
     $53 = $49;
     label = 12;
    } else {
     __ZdlPv($51);
     $$pr$pre$i = HEAP32[$9>>2]|0;
     $53 = $$pr$pre$i;
     label = 12;
    }
   } else {
    $53 = $10;
    label = 12;
   }
  } while(0);
  if ((label|0) == 12) {
   $52 = ($53|0)==(0|0);
   if ($52) {
    $56 = 0;
   } else {
    $54 = $53;
    label = 13;
   }
  }
  if ((label|0) == 13) {
   HEAP32[$54>>2] = $7;
   $$pre8$i = HEAP32[$9>>2]|0;
   $56 = $$pre8$i;
  }
  $55 = (($56) + 4|0);
  HEAP32[$9>>2] = $55;
  STACKTOP = sp;return;
 }
 $57 = (($this) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $58;
 $62 = $60;
 $63 = (($61) - ($62))|0;
 $64 = $63 >> 2;
 $65 = (($this) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$this>>2]|0;
 $68 = $66;
 $69 = $67;
 $70 = (($68) - ($69))|0;
 $71 = $70 >> 2;
 $72 = ($64>>>0)<($71>>>0);
 if ($72) {
  $73 = ($66|0)==($58|0);
  $74 = (__Znwj(4092)|0);
  if (!($73)) {
   $75 = ($58|0)==(0|0);
   if ($75) {
    $77 = 0;
   } else {
    HEAP32[$58>>2] = $74;
    $$pre8$i28 = HEAP32[$57>>2]|0;
    $77 = $$pre8$i28;
   }
   $76 = (($77) + 4|0);
   HEAP32[$57>>2] = $76;
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $74;
  __ZNSt3__114__split_bufferIPN14SafeBinaryRead17ArrayPositionInfoENS_9allocatorIS3_EEE10push_frontERKS3_($this,$0);
  $78 = HEAP32[$59>>2]|0;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($78) + 4|0);
  HEAP32[$59>>2] = $80;
  $81 = HEAP32[$57>>2]|0;
  $82 = HEAP32[$65>>2]|0;
  $83 = ($81|0)==($82|0);
  do {
   if ($83) {
    $84 = HEAP32[$this>>2]|0;
    $85 = ($80>>>0)>($84>>>0);
    if ($85) {
     $86 = $80;
     $87 = $84;
     $88 = (($86) - ($87))|0;
     $89 = $88 >> 2;
     $90 = (($89) + 1)|0;
     $91 = (($90|0) / -2)&-1;
     $$sum = (($91) + 1)|0;
     $92 = (($78) + ($$sum<<2)|0);
     $93 = $81;
     $94 = (($93) - ($86))|0;
     $95 = $94 >> 2;
     _memmove(($92|0),($80|0),($94|0))|0;
     $$sum$i30 = (($95) + 1)|0;
     $$sum41 = (($$sum$i30) + ($91))|0;
     $96 = (($78) + ($$sum41<<2)|0);
     HEAP32[$57>>2] = $96;
     $97 = HEAP32[$59>>2]|0;
     $98 = (($97) + ($91<<2)|0);
     HEAP32[$59>>2] = $98;
     $124 = $96;
     label = 31;
     break;
    }
    $99 = $81;
    $100 = $84;
    $101 = (($99) - ($100))|0;
    $102 = $101 >> 1;
    $103 = ($102|0)==(0);
    $104 = $103 ? 1 : $102;
    $105 = $104 >>> 2;
    $106 = $104 << 2;
    $107 = (__Znwj($106)|0);
    $108 = (($107) + ($105<<2)|0);
    $109 = (($107) + ($104<<2)|0);
    $110 = ($80|0)==($81|0);
    if ($110) {
     $119 = $108;$121 = $84;
    } else {
     $112 = $108;$114 = $80;
     while(1) {
      $111 = ($112|0)==(0|0);
      if ($111) {
       $116 = 0;
      } else {
       $113 = HEAP32[$114>>2]|0;
       HEAP32[$112>>2] = $113;
       $116 = $112;
      }
      $115 = (($116) + 4|0);
      $117 = (($114) + 4|0);
      $118 = ($117|0)==($81|0);
      if ($118) {
       break;
      } else {
       $112 = $115;$114 = $117;
      }
     }
     $$pre$i33 = HEAP32[$this>>2]|0;
     $119 = $115;$121 = $$pre$i33;
    }
    HEAP32[$this>>2] = $107;
    HEAP32[$59>>2] = $108;
    HEAP32[$57>>2] = $119;
    HEAP32[$65>>2] = $109;
    $120 = ($121|0)==(0|0);
    if ($120) {
     $123 = $119;
     label = 30;
    } else {
     __ZdlPv($121);
     $$pr$pre$i36 = HEAP32[$57>>2]|0;
     $123 = $$pr$pre$i36;
     label = 30;
    }
   } else {
    $123 = $81;
    label = 30;
   }
  } while(0);
  if ((label|0) == 30) {
   $122 = ($123|0)==(0|0);
   if ($122) {
    $126 = 0;
   } else {
    $124 = $123;
    label = 31;
   }
  }
  if ((label|0) == 31) {
   HEAP32[$124>>2] = $79;
   $$pre8$i38 = HEAP32[$57>>2]|0;
   $126 = $$pre8$i38;
  }
  $125 = (($126) + 4|0);
  HEAP32[$57>>2] = $125;
  STACKTOP = sp;return;
 }
 $127 = $70 >> 1;
 $128 = ($127|0)==(0);
 $129 = $128 ? 1 : $127;
 $130 = (($this) + 12|0);
 $131 = (($__buf) + 12|0);
 $132 = (($__buf) + 16|0);
 HEAP32[$132>>2] = $130;
 $133 = $129 << 2;
 $134 = (__Znwj($133)|0);
 HEAP32[$__buf>>2] = $134;
 $135 = (($134) + ($64<<2)|0);
 $136 = (($__buf) + 8|0);
 HEAP32[$136>>2] = $135;
 $137 = (($__buf) + 4|0);
 HEAP32[$137>>2] = $135;
 $138 = (($134) + ($129<<2)|0);
 HEAP32[$131>>2] = $138;
 __THREW__ = 0;
 $139 = (invoke_ii(2988,4092)|0);
 $140 = __THREW__; __THREW__ = 0;
 $141 = $140&1;
 L54: do {
  if ($141) {
   label = 42;
  } else {
   $142 = ($64|0)==($129|0);
   do {
    if ($142) {
     $143 = ($135>>>0)>($134>>>0);
     $144 = $135;
     $145 = $134;
     $146 = (($144) - ($145))|0;
     if ($143) {
      $147 = $146 >> 2;
      $148 = (($147) + 1)|0;
      $149 = (($148|0) / -2)&-1;
      $$sum52 = (($64) + ($149))|0;
      $150 = (($134) + ($$sum52<<2)|0);
      HEAP32[$136>>2] = $150;
      HEAP32[$137>>2] = $150;
      $163 = $150;
      break;
     }
     $151 = $146 >> 1;
     $152 = ($151|0)==(0);
     $153 = $152 ? 1 : $151;
     $154 = $153 << 2;
     __THREW__ = 0;
     $155 = (invoke_ii(2988,($154|0))|0);
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if ($157) {
      label = 42;
      break L54;
     }
     $158 = $153 >>> 2;
     $159 = (($155) + ($158<<2)|0);
     $160 = (($155) + ($153<<2)|0);
     HEAP32[$__buf>>2] = $155;
     HEAP32[$137>>2] = $159;
     HEAP32[$136>>2] = $159;
     HEAP32[$131>>2] = $160;
     $161 = ($134|0)==(0|0);
     if ($161) {
      $163 = $159;
     } else {
      __ZdlPv($134);
      $163 = $159;
     }
    } else {
     $163 = $135;
    }
   } while(0);
   $162 = ($163|0)==(0|0);
   if ($162) {
    $175 = 0;
   } else {
    HEAP32[$163>>2] = $139;
    $$pre8$i19 = HEAP32[$136>>2]|0;
    $175 = $$pre8$i19;
   }
   $174 = (($175) + 4|0);
   HEAP32[$136>>2] = $174;
   $176 = HEAP32[$57>>2]|0;
   $__i$0 = $176;
   while(1) {
    $177 = HEAP32[$59>>2]|0;
    $178 = ($__i$0|0)==($177|0);
    if ($178) {
     break;
    }
    $179 = (($__i$0) + -4|0);
    __THREW__ = 0;
    invoke_vii(3215,($__buf|0),($179|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if ($181) {
     label = 51;
     break;
    } else {
     $__i$0 = $179;
    }
   }
   if ((label|0) == 51) {
    $194 = ___cxa_find_matching_catch()|0;
    $195 = tempRet0;
    $$pre = HEAP32[$137>>2]|0;
    $$pre50 = HEAP32[$136>>2]|0;
    $196 = ($$pre50|0)==($$pre|0);
    if ($196) {
     $$0153 = $194;$$055 = $195;
     break;
    }
    $__new_last2$i$i$i$i$i = $$pre;
    $scevgep$i$i$i$i$i = (($$pre50) + -4|0);
    $197 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($197)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $198 = $uglygep3$i$i$i$i$i >>> 2;
    $199 = $198 ^ -1;
    $scevgep4$i$i$i$i$i = (($$pre50) + ($199<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i;
    $$0153 = $194;$$055 = $195;
    break;
   }
   $182 = HEAP32[$this>>2]|0;
   $183 = HEAP32[$__buf>>2]|0;
   HEAP32[$this>>2] = $183;
   HEAP32[$__buf>>2] = $182;
   $184 = HEAP32[$137>>2]|0;
   HEAP32[$59>>2] = $184;
   HEAP32[$137>>2] = $__i$0;
   $185 = HEAP32[$57>>2]|0;
   $186 = HEAP32[$136>>2]|0;
   HEAP32[$57>>2] = $186;
   HEAP32[$136>>2] = $185;
   $187 = HEAP32[$65>>2]|0;
   $188 = HEAP32[$131>>2]|0;
   HEAP32[$65>>2] = $188;
   HEAP32[$131>>2] = $187;
   $189 = ($185|0)==($__i$0|0);
   if (!($189)) {
    $__new_last2$i$i$i$i$i2 = $__i$0;
    $scevgep$i$i$i$i$i3 = (($185) + -4|0);
    $190 = (0 - ($__new_last2$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($190)|0);
    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
    $191 = $uglygep3$i$i$i$i$i6 >>> 2;
    $192 = $191 ^ -1;
    $scevgep4$i$i$i$i$i7 = (($185) + ($192<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i7;
   }
   $193 = ($182|0)==(0|0);
   if ($193) {
    STACKTOP = sp;return;
   }
   __ZdlPv($182);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 42) {
  $164 = ___cxa_find_matching_catch(0|0)|0;
  $165 = tempRet0;
  (___cxa_begin_catch(($164|0))|0);
  $$sum51 = (($64) + -1)|0;
  $166 = (($134) + ($$sum51<<2)|0);
  $167 = HEAP32[$166>>2]|0;
  __ZdlPv($167);
  __THREW__ = 0;
  invoke_v(140);
  $168 = __THREW__; __THREW__ = 0;
  $169 = $168&1;
  if (!($169)) {
   // unreachable;
  }
  $170 = ___cxa_find_matching_catch()|0;
  $171 = tempRet0;
  __THREW__ = 0;
  invoke_v(66);
  $172 = __THREW__; __THREW__ = 0;
  $173 = $172&1;
  if ($173) {
   $202 = ___cxa_find_matching_catch(0|0)|0;
   $203 = tempRet0;
   ___clang_call_terminate($202);
   // unreachable;
  } else {
   $$0153 = $170;$$055 = $171;
  }
 }
 $200 = HEAP32[$__buf>>2]|0;
 $201 = ($200|0)==(0|0);
 if ($201) {
  ___resumeException($$0153|0);
  // unreachable;
 }
 __ZdlPv($200);
 ___resumeException($$0153|0);
 // unreachable;
}
function __ZNSt3__114__split_bufferIPN14SafeBinaryRead17ArrayPositionInfoENS_9allocatorIS3_EEE10push_frontERKS3_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIPN14SafeBinaryRead17ArrayPositionInfoERNS_9allocatorIS3_EEE10push_frontERKS3_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZNSt3__15dequeIN14SafeBinaryRead11StackedInfoENS_9allocatorIS2_EEE19__add_back_capacityEv($this) {
 $this = $this|0;
 var $$0153 = 0, $$055 = 0, $$pr$pre$i = 0, $$pr$pre$i36 = 0, $$pre = 0, $$pre$i = 0, $$pre$i33 = 0, $$pre50 = 0, $$pre8$i = 0, $$pre8$i19 = 0, $$pre8$i28 = 0, $$pre8$i38 = 0, $$sum = 0, $$sum$i = 0, $$sum$i30 = 0, $$sum41 = 0, $$sum42 = 0, $$sum43 = 0, $$sum51 = 0, $$sum52 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__buf = 0, $__i$0 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $__buf = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>(127);
 if ($3) {
  $4 = (($2) + -128)|0;
  HEAP32[$1>>2] = $4;
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($6) + 4|0);
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  do {
   if ($13) {
    $14 = HEAP32[$this>>2]|0;
    $15 = ($8>>>0)>($14>>>0);
    if ($15) {
     $16 = $8;
     $17 = $14;
     $18 = (($16) - ($17))|0;
     $19 = $18 >> 2;
     $20 = (($19) + 1)|0;
     $21 = (($20|0) / -2)&-1;
     $$sum42 = (($21) + 1)|0;
     $22 = (($6) + ($$sum42<<2)|0);
     $23 = $10;
     $24 = (($23) - ($16))|0;
     $25 = $24 >> 2;
     _memmove(($22|0),($8|0),($24|0))|0;
     $$sum$i = (($25) + 1)|0;
     $$sum43 = (($$sum$i) + ($21))|0;
     $26 = (($6) + ($$sum43<<2)|0);
     HEAP32[$9>>2] = $26;
     $27 = HEAP32[$5>>2]|0;
     $28 = (($27) + ($21<<2)|0);
     HEAP32[$5>>2] = $28;
     $54 = $26;
     label = 13;
     break;
    }
    $29 = $10;
    $30 = $14;
    $31 = (($29) - ($30))|0;
    $32 = $31 >> 1;
    $33 = ($32|0)==(0);
    $34 = $33 ? 1 : $32;
    $35 = $34 >>> 2;
    $36 = $34 << 2;
    $37 = (__Znwj($36)|0);
    $38 = (($37) + ($35<<2)|0);
    $39 = (($37) + ($34<<2)|0);
    $40 = ($8|0)==($10|0);
    if ($40) {
     $49 = $38;$51 = $14;
    } else {
     $42 = $38;$44 = $8;
     while(1) {
      $41 = ($42|0)==(0|0);
      if ($41) {
       $46 = 0;
      } else {
       $43 = HEAP32[$44>>2]|0;
       HEAP32[$42>>2] = $43;
       $46 = $42;
      }
      $45 = (($46) + 4|0);
      $47 = (($44) + 4|0);
      $48 = ($47|0)==($10|0);
      if ($48) {
       break;
      } else {
       $42 = $45;$44 = $47;
      }
     }
     $$pre$i = HEAP32[$this>>2]|0;
     $49 = $45;$51 = $$pre$i;
    }
    HEAP32[$this>>2] = $37;
    HEAP32[$5>>2] = $38;
    HEAP32[$9>>2] = $49;
    HEAP32[$11>>2] = $39;
    $50 = ($51|0)==(0|0);
    if ($50) {
     $53 = $49;
     label = 12;
    } else {
     __ZdlPv($51);
     $$pr$pre$i = HEAP32[$9>>2]|0;
     $53 = $$pr$pre$i;
     label = 12;
    }
   } else {
    $53 = $10;
    label = 12;
   }
  } while(0);
  if ((label|0) == 12) {
   $52 = ($53|0)==(0|0);
   if ($52) {
    $56 = 0;
   } else {
    $54 = $53;
    label = 13;
   }
  }
  if ((label|0) == 13) {
   HEAP32[$54>>2] = $7;
   $$pre8$i = HEAP32[$9>>2]|0;
   $56 = $$pre8$i;
  }
  $55 = (($56) + 4|0);
  HEAP32[$9>>2] = $55;
  STACKTOP = sp;return;
 }
 $57 = (($this) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $58;
 $62 = $60;
 $63 = (($61) - ($62))|0;
 $64 = $63 >> 2;
 $65 = (($this) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$this>>2]|0;
 $68 = $66;
 $69 = $67;
 $70 = (($68) - ($69))|0;
 $71 = $70 >> 2;
 $72 = ($64>>>0)<($71>>>0);
 if ($72) {
  $73 = ($66|0)==($58|0);
  $74 = (__Znwj(4096)|0);
  if (!($73)) {
   $75 = ($58|0)==(0|0);
   if ($75) {
    $77 = 0;
   } else {
    HEAP32[$58>>2] = $74;
    $$pre8$i28 = HEAP32[$57>>2]|0;
    $77 = $$pre8$i28;
   }
   $76 = (($77) + 4|0);
   HEAP32[$57>>2] = $76;
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $74;
  __ZNSt3__114__split_bufferIPN14SafeBinaryRead11StackedInfoENS_9allocatorIS3_EEE10push_frontERKS3_($this,$0);
  $78 = HEAP32[$59>>2]|0;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($78) + 4|0);
  HEAP32[$59>>2] = $80;
  $81 = HEAP32[$57>>2]|0;
  $82 = HEAP32[$65>>2]|0;
  $83 = ($81|0)==($82|0);
  do {
   if ($83) {
    $84 = HEAP32[$this>>2]|0;
    $85 = ($80>>>0)>($84>>>0);
    if ($85) {
     $86 = $80;
     $87 = $84;
     $88 = (($86) - ($87))|0;
     $89 = $88 >> 2;
     $90 = (($89) + 1)|0;
     $91 = (($90|0) / -2)&-1;
     $$sum = (($91) + 1)|0;
     $92 = (($78) + ($$sum<<2)|0);
     $93 = $81;
     $94 = (($93) - ($86))|0;
     $95 = $94 >> 2;
     _memmove(($92|0),($80|0),($94|0))|0;
     $$sum$i30 = (($95) + 1)|0;
     $$sum41 = (($$sum$i30) + ($91))|0;
     $96 = (($78) + ($$sum41<<2)|0);
     HEAP32[$57>>2] = $96;
     $97 = HEAP32[$59>>2]|0;
     $98 = (($97) + ($91<<2)|0);
     HEAP32[$59>>2] = $98;
     $124 = $96;
     label = 31;
     break;
    }
    $99 = $81;
    $100 = $84;
    $101 = (($99) - ($100))|0;
    $102 = $101 >> 1;
    $103 = ($102|0)==(0);
    $104 = $103 ? 1 : $102;
    $105 = $104 >>> 2;
    $106 = $104 << 2;
    $107 = (__Znwj($106)|0);
    $108 = (($107) + ($105<<2)|0);
    $109 = (($107) + ($104<<2)|0);
    $110 = ($80|0)==($81|0);
    if ($110) {
     $119 = $108;$121 = $84;
    } else {
     $112 = $108;$114 = $80;
     while(1) {
      $111 = ($112|0)==(0|0);
      if ($111) {
       $116 = 0;
      } else {
       $113 = HEAP32[$114>>2]|0;
       HEAP32[$112>>2] = $113;
       $116 = $112;
      }
      $115 = (($116) + 4|0);
      $117 = (($114) + 4|0);
      $118 = ($117|0)==($81|0);
      if ($118) {
       break;
      } else {
       $112 = $115;$114 = $117;
      }
     }
     $$pre$i33 = HEAP32[$this>>2]|0;
     $119 = $115;$121 = $$pre$i33;
    }
    HEAP32[$this>>2] = $107;
    HEAP32[$59>>2] = $108;
    HEAP32[$57>>2] = $119;
    HEAP32[$65>>2] = $109;
    $120 = ($121|0)==(0|0);
    if ($120) {
     $123 = $119;
     label = 30;
    } else {
     __ZdlPv($121);
     $$pr$pre$i36 = HEAP32[$57>>2]|0;
     $123 = $$pr$pre$i36;
     label = 30;
    }
   } else {
    $123 = $81;
    label = 30;
   }
  } while(0);
  if ((label|0) == 30) {
   $122 = ($123|0)==(0|0);
   if ($122) {
    $126 = 0;
   } else {
    $124 = $123;
    label = 31;
   }
  }
  if ((label|0) == 31) {
   HEAP32[$124>>2] = $79;
   $$pre8$i38 = HEAP32[$57>>2]|0;
   $126 = $$pre8$i38;
  }
  $125 = (($126) + 4|0);
  HEAP32[$57>>2] = $125;
  STACKTOP = sp;return;
 }
 $127 = $70 >> 1;
 $128 = ($127|0)==(0);
 $129 = $128 ? 1 : $127;
 $130 = (($this) + 12|0);
 $131 = (($__buf) + 12|0);
 $132 = (($__buf) + 16|0);
 HEAP32[$132>>2] = $130;
 $133 = $129 << 2;
 $134 = (__Znwj($133)|0);
 HEAP32[$__buf>>2] = $134;
 $135 = (($134) + ($64<<2)|0);
 $136 = (($__buf) + 8|0);
 HEAP32[$136>>2] = $135;
 $137 = (($__buf) + 4|0);
 HEAP32[$137>>2] = $135;
 $138 = (($134) + ($129<<2)|0);
 HEAP32[$131>>2] = $138;
 __THREW__ = 0;
 $139 = (invoke_ii(2988,4096)|0);
 $140 = __THREW__; __THREW__ = 0;
 $141 = $140&1;
 L54: do {
  if ($141) {
   label = 42;
  } else {
   $142 = ($64|0)==($129|0);
   do {
    if ($142) {
     $143 = ($135>>>0)>($134>>>0);
     $144 = $135;
     $145 = $134;
     $146 = (($144) - ($145))|0;
     if ($143) {
      $147 = $146 >> 2;
      $148 = (($147) + 1)|0;
      $149 = (($148|0) / -2)&-1;
      $$sum52 = (($64) + ($149))|0;
      $150 = (($134) + ($$sum52<<2)|0);
      HEAP32[$136>>2] = $150;
      HEAP32[$137>>2] = $150;
      $163 = $150;
      break;
     }
     $151 = $146 >> 1;
     $152 = ($151|0)==(0);
     $153 = $152 ? 1 : $151;
     $154 = $153 << 2;
     __THREW__ = 0;
     $155 = (invoke_ii(2988,($154|0))|0);
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if ($157) {
      label = 42;
      break L54;
     }
     $158 = $153 >>> 2;
     $159 = (($155) + ($158<<2)|0);
     $160 = (($155) + ($153<<2)|0);
     HEAP32[$__buf>>2] = $155;
     HEAP32[$137>>2] = $159;
     HEAP32[$136>>2] = $159;
     HEAP32[$131>>2] = $160;
     $161 = ($134|0)==(0|0);
     if ($161) {
      $163 = $159;
     } else {
      __ZdlPv($134);
      $163 = $159;
     }
    } else {
     $163 = $135;
    }
   } while(0);
   $162 = ($163|0)==(0|0);
   if ($162) {
    $175 = 0;
   } else {
    HEAP32[$163>>2] = $139;
    $$pre8$i19 = HEAP32[$136>>2]|0;
    $175 = $$pre8$i19;
   }
   $174 = (($175) + 4|0);
   HEAP32[$136>>2] = $174;
   $176 = HEAP32[$57>>2]|0;
   $__i$0 = $176;
   while(1) {
    $177 = HEAP32[$59>>2]|0;
    $178 = ($__i$0|0)==($177|0);
    if ($178) {
     break;
    }
    $179 = (($__i$0) + -4|0);
    __THREW__ = 0;
    invoke_vii(3216,($__buf|0),($179|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if ($181) {
     label = 51;
     break;
    } else {
     $__i$0 = $179;
    }
   }
   if ((label|0) == 51) {
    $194 = ___cxa_find_matching_catch()|0;
    $195 = tempRet0;
    $$pre = HEAP32[$137>>2]|0;
    $$pre50 = HEAP32[$136>>2]|0;
    $196 = ($$pre50|0)==($$pre|0);
    if ($196) {
     $$0153 = $194;$$055 = $195;
     break;
    }
    $__new_last2$i$i$i$i$i = $$pre;
    $scevgep$i$i$i$i$i = (($$pre50) + -4|0);
    $197 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($197)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $198 = $uglygep3$i$i$i$i$i >>> 2;
    $199 = $198 ^ -1;
    $scevgep4$i$i$i$i$i = (($$pre50) + ($199<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i;
    $$0153 = $194;$$055 = $195;
    break;
   }
   $182 = HEAP32[$this>>2]|0;
   $183 = HEAP32[$__buf>>2]|0;
   HEAP32[$this>>2] = $183;
   HEAP32[$__buf>>2] = $182;
   $184 = HEAP32[$137>>2]|0;
   HEAP32[$59>>2] = $184;
   HEAP32[$137>>2] = $__i$0;
   $185 = HEAP32[$57>>2]|0;
   $186 = HEAP32[$136>>2]|0;
   HEAP32[$57>>2] = $186;
   HEAP32[$136>>2] = $185;
   $187 = HEAP32[$65>>2]|0;
   $188 = HEAP32[$131>>2]|0;
   HEAP32[$65>>2] = $188;
   HEAP32[$131>>2] = $187;
   $189 = ($185|0)==($__i$0|0);
   if (!($189)) {
    $__new_last2$i$i$i$i$i2 = $__i$0;
    $scevgep$i$i$i$i$i3 = (($185) + -4|0);
    $190 = (0 - ($__new_last2$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($190)|0);
    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
    $191 = $uglygep3$i$i$i$i$i6 >>> 2;
    $192 = $191 ^ -1;
    $scevgep4$i$i$i$i$i7 = (($185) + ($192<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i7;
   }
   $193 = ($182|0)==(0|0);
   if ($193) {
    STACKTOP = sp;return;
   }
   __ZdlPv($182);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 42) {
  $164 = ___cxa_find_matching_catch(0|0)|0;
  $165 = tempRet0;
  (___cxa_begin_catch(($164|0))|0);
  $$sum51 = (($64) + -1)|0;
  $166 = (($134) + ($$sum51<<2)|0);
  $167 = HEAP32[$166>>2]|0;
  __ZdlPv($167);
  __THREW__ = 0;
  invoke_v(140);
  $168 = __THREW__; __THREW__ = 0;
  $169 = $168&1;
  if (!($169)) {
   // unreachable;
  }
  $170 = ___cxa_find_matching_catch()|0;
  $171 = tempRet0;
  __THREW__ = 0;
  invoke_v(66);
  $172 = __THREW__; __THREW__ = 0;
  $173 = $172&1;
  if ($173) {
   $202 = ___cxa_find_matching_catch(0|0)|0;
   $203 = tempRet0;
   ___clang_call_terminate($202);
   // unreachable;
  } else {
   $$0153 = $170;$$055 = $171;
  }
 }
 $200 = HEAP32[$__buf>>2]|0;
 $201 = ($200|0)==(0|0);
 if ($201) {
  ___resumeException($$0153|0);
  // unreachable;
 }
 __ZdlPv($200);
 ___resumeException($$0153|0);
 // unreachable;
}
function __ZNSt3__114__split_bufferIPN14SafeBinaryRead11StackedInfoENS_9allocatorIS3_EEE10push_frontERKS3_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIPN14SafeBinaryRead11StackedInfoERNS_9allocatorIS3_EEE10push_frontERKS3_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EEPFbPvR14SafeBinaryReadEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_S5_EE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EEPFbPvR14SafeBinaryReadEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_S5_EE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EEPFbPvR14SafeBinaryReadEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS_9allocatorISA_EEE7destroyEPNS_11__tree_nodeISA_S5_EE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__13mapINS_4pairIPcS2_EEPFbPvR14SafeBinaryReadE20smaller_cstring_pairNS_9allocatorINS1_IKS3_S8_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIS4_EERSB_($this,$__parent,$__k) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__k = $__k|0;
 var $$0 = 0, $$0$i = 0, $$0$i5 = 0, $$0$in$i = 0, $$0$in$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $32 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $32;
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = $__k;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $5;
 $10 = $8;
 $__nd$0$in = $1;
 while(1) {
  $11 = (($__nd$0$in) + 16|0);
  $12 = $11;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $14;
  $19 = (_strcmp($9,$18)|0);
  $20 = ($19|0)==(0);
  if ($20) {
   $21 = $17;
   $22 = (_strcmp($10,$21)|0);
   $$0$in$i4 = $22;
  } else {
   $$0$in$i4 = $19;
  }
  $$0$i5 = ($$0$in$i4|0)<(0);
  if ($$0$i5) {
   $23 = HEAP32[$__nd$0$in>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    label = 7;
    break;
   } else {
    $__nd$0$in = $23;
    continue;
   }
  }
  $25 = (_strcmp($18,$9)|0);
  $26 = ($25|0)==(0);
  if ($26) {
   $27 = $17;
   $28 = (_strcmp($27,$10)|0);
   $$0$in$i = $28;
  } else {
   $$0$in$i = $25;
  }
  $$0$i = ($$0$in$i|0)<(0);
  if (!($$0$i)) {
   label = 13;
   break;
  }
  $29 = (($__nd$0$in) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   label = 12;
   break;
  } else {
   $__nd$0$in = $30;
  }
 }
 if ((label|0) == 7) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 12) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $29;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 13) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EEPFbPvR14SafeBinaryReadEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS_9allocatorISA_EEE4findIS4_EENS_15__tree_iteratorISA_PNS_11__tree_nodeISA_S5_EEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$in$i$i = 0, $$0$in$i$i$i = 0, $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = $__v;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $6;
  $11 = $9;
  $$0$ph7$i = $2;$$01$ph6$i$in = $1;
  L3: while(1) {
   $$013$i$in = $$01$ph6$i$in;
   while(1) {
    $12 = (($$013$i$in) + 16|0);
    $13 = $12;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + 4)|0;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = $15;
    $20 = (_strcmp($19,$10)|0);
    $21 = ($20|0)==(0);
    if ($21) {
     $22 = $18;
     $23 = (_strcmp($22,$11)|0);
     $$0$in$i$i$i = $23;
    } else {
     $$0$in$i$i$i = $20;
    }
    $$0$i$i$i = ($$0$in$i$i$i|0)<(0);
    if (!($$0$i$i$i)) {
     break;
    }
    $26 = (($$013$i$in) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     $$0$ph5$i = $$0$ph7$i;
     break L3;
    } else {
     $$013$i$in = $27;
    }
   }
   $24 = HEAP32[$$013$i$in>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    $$0$ph5$i = $$013$i$in;
    break;
   } else {
    $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $24;
   }
  }
  $29 = ($$0$ph5$i|0)==($2|0);
  if (!($29)) {
   $30 = (($$0$ph5$i) + 16|0);
   $31 = $30;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 4)|0;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = $33;
   $38 = (_strcmp($10,$37)|0);
   $39 = ($38|0)==(0);
   if ($39) {
    $40 = $36;
    $41 = (_strcmp($11,$40)|0);
    $$0$in$i$i = $41;
   } else {
    $$0$in$i$i = $38;
   }
   $$0$i$i = ($$0$in$i$i|0)<(0);
   if (!($$0$i$i)) {
    HEAP32[$agg$result>>2] = $$0$ph5$i;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$data,$byteSize) {
 $this = $this|0;
 $data = $data|0;
 $byteSize = $byteSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN12CachedReader4ReadEPvj($0,$data,$byteSize);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE5AlignEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN12CachedReader10Align4ReadEv($0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE5AlignEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN12CachedReader10Align4ReadEv($0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE20TransferTypelessDataEjPvi($this,$byteSize,$copyData,$metaData) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $copyData = $copyData|0;
 $metaData = $metaData|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($byteSize|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = ($copyData|0)==(0|0);
 $2 = (($this) + 12|0);
 if ($1) {
  __ZN12CachedReader4SkipEi($2,$byteSize);
 } else {
  __ZN12CachedReader4ReadEPvj($2,$copyData,$byteSize);
 }
 __ZN12CachedReader10Align4ReadEv($2);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE20TransferTypelessDataEjPvi($this,$byteSize,$copyData,$metaData) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $copyData = $copyData|0;
 $metaData = $metaData|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($byteSize|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = ($copyData|0)==(0|0);
 $2 = (($this) + 12|0);
 if ($1) {
  __ZN12CachedReader4SkipEi($2,$byteSize);
 } else {
  __ZN12CachedReader4ReadEPvj($2,$copyData,$byteSize);
 }
 __ZN12CachedReader10Align4ReadEv($2);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE16TransferTypelessEPjPKc17TransferMetaFlags($this,$byteSize,$0,$1) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i$i = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $9 = $$pre$i$i$i;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$size>>2] = $8;
  HEAP32[$2>>2] = $4;
  $9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$byteSize>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE16TransferTypelessEPjPKc17TransferMetaFlags($this,$byteSize,$0,$1) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$size,4);
  $$pre = HEAP32[$size>>2]|0;
  $9 = $$pre;
  HEAP32[$byteSize>>2] = $9;
  STACKTOP = sp;return;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$size>>2] = $8;
  HEAP32[$2>>2] = $4;
  $9 = $8;
  HEAP32[$byteSize>>2] = $9;
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE4InitE24TransferInstructionFlags20BuildTargetSelection($this,$flags,$target) {
 $this = $this|0;
 $flags = $flags|0;
 $target = $target|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $flags;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 32|0);
 $2 = $target;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $1;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = (($this) + 12|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN19StreamedBinaryWriteILb0EE5AlignEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN12CachedWriter11Align4WriteEv($0);
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE16TransferTypelessEPjPKc17TransferMetaFlags($this,$byteSize,$0,$1) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $2 = HEAP32[$byteSize>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size,4);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE20TransferTypelessDataEjPvi($this,$byteSize,$copyData,$0) {
 $this = $this|0;
 $byteSize = $byteSize|0;
 $copyData = $copyData|0;
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 12|0);
 __ZN12CachedWriter5WriteEPKvj($1,$copyData,$byteSize);
 __ZN12CachedWriter11Align4WriteEv($1);
 STACKTOP = sp;return;
}
function __Z23GetAllowNameConversionsPK20AllowNameConversionsPKcS3_($AllowNameConversions,$type,$name) {
 $AllowNameConversions = $AllowNameConversions|0;
 $type = $type|0;
 $name = $name|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $foundNameConversion = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $foundNameConversion = sp + 8|0;
 $0 = sp;
 $1 = ($AllowNameConversions|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return (0|0);
 } else {
  HEAP32[$0>>2] = $type;
  $2 = (($0) + 4|0);
  HEAP32[$2>>2] = $name;
  __ZNKSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EENS_3setIS3_15smaller_cstringNS_9allocatorIS3_EEEEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS7_ISA_EEE4findIS4_EENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_($foundNameConversion,$AllowNameConversions,$0);
  $3 = (($AllowNameConversions) + 4|0);
  $4 = HEAP32[$foundNameConversion>>2]|0;
  $5 = ($4|0)==($3|0);
  $6 = (($4) + 24|0);
  $$ = $5 ? 0 : $6;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function __Z27RegisterAllowNameConversionR20AllowNameConversionsPKcS2_S2_($nameConversions,$type,$oldName,$newName) {
 $nameConversions = $nameConversions|0;
 $type = $type|0;
 $oldName = $oldName|0;
 $newName = $newName|0;
 var $$0 = 0, $$byval_copy = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = (($nameConversions) + 12|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $$0 = $oldName;
 } else {
  $6 = (_strlen(($oldName|0))|0);
  $7 = (($6) + 1)|0;
  $8 = HEAP32[628360>>2]|0;
  HEAP32[$0>>2] = $8;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $9 = (__Z15malloc_internaljj10MemLabelIdiPKci($7,16,$$byval_copy,0,638744,37)|0);
  (_strncpy(($9|0),($oldName|0),($6|0))|0);
  $10 = (($9) + ($6)|0);
  HEAP8[$10>>0] = 0;
  $$0 = $9;
 }
 HEAP32[$1>>2] = $type;
 $11 = (($1) + 4|0);
 HEAP32[$11>>2] = $newName;
 $12 = (__ZNSt3__13mapINS_4pairIPcS2_EENS_3setIS2_15smaller_cstringNS_9allocatorIS2_EEEE20smaller_cstring_pairNS6_INS1_IKS3_S8_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERSA_($nameConversions,$$byval_copy,$1)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $__r$0$i = $13;
  HEAP32[$2>>2] = $$0;
  $42 = (($__r$0$i) + 24|0);
  __ZNSt3__16__treeIPc15smaller_cstringNS_9allocatorIS1_EEE15__insert_uniqueERKS1_($$byval_copy,$42,$2);
  STACKTOP = sp;return;
 }
 $15 = (__Znwj(36)|0);
 $16 = (($15) + 16|0);
 $17 = $1;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $16;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 $27 = (($15) + 24|0);
 $28 = (($15) + 28|0);
 HEAP32[$28>>2] = 0;
 $29 = (($15) + 32|0);
 HEAP32[$29>>2] = 0;
 HEAP32[$27>>2] = $28;
 $30 = HEAP32[$$byval_copy>>2]|0;
 HEAP32[$15>>2] = 0;
 $31 = (($15) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = (($15) + 8|0);
 HEAP32[$32>>2] = $30;
 HEAP32[$12>>2] = $15;
 $33 = HEAP32[$nameConversions>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $38 = $15;
 } else {
  HEAP32[$nameConversions>>2] = $34;
  $$pre$i$i = HEAP32[$12>>2]|0;
  $38 = $$pre$i$i;
 }
 $36 = (($nameConversions) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$38);
 $39 = (($nameConversions) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 1)|0;
 HEAP32[$39>>2] = $41;
 $__r$0$i = $15;
 HEAP32[$2>>2] = $$0;
 $42 = (($__r$0$i) + 24|0);
 __ZNSt3__16__treeIPc15smaller_cstringNS_9allocatorIS1_EEE15__insert_uniqueERKS1_($$byval_copy,$42,$2);
 STACKTOP = sp;return;
}
function __Z27RegisterAllowNameConversionPKcS0_S0_($type,$oldName,$newName) {
 $type = $type|0;
 $oldName = $oldName|0;
 $newName = $newName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[638752>>2]|0;
 __Z27RegisterAllowNameConversionR20AllowNameConversionsPKcS2_S2_($0,$type,$oldName,$newName);
 STACKTOP = sp;return;
}
function __Z29GetGlobalAllowNameConversionsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[638752>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZL30InitializeGlobalNameConversionv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628360>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy,1,16,638744,85)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$2>>2] = $3;
 $5 = (($2) + 12|0);
 HEAP8[$5>>0] = 0;
 HEAP32[638752>>2] = $2;
 STACKTOP = sp;return;
}
function __ZL27CleanupGlobalNameConversionv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[638752>>2]|0;
 $2 = HEAP32[628360>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EENS_3setIS3_15smaller_cstringNS_9allocatorIS3_EEEEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($1,$5);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[638752>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EENS_3setIS3_15smaller_cstringNS_9allocatorIS3_EEEEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EENS_3setIS3_15smaller_cstringNS_9allocatorIS3_EEEEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EENS_3setIS3_15smaller_cstringNS_9allocatorIS3_EEEEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS7_ISA_EEE7destroyEPNS_11__tree_nodeISA_PvEE($this,$3);
  $4 = (($__nd) + 24|0);
  $5 = (($__nd) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  __ZNSt3__16__treeIPc15smaller_cstringNS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($4,$6);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIPc15smaller_cstringNS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeIPc15smaller_cstringNS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeIPc15smaller_cstringNS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIPc15smaller_cstringNS_9allocatorIS1_EEE15__insert_uniqueERKS1_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $15 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $15;
   $$0$i = $15;$23 = $15;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (_strcmp($3,$5)|0);
    $7 = ($6|0)<(0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = (_strcmp($5,$3)|0);
    $11 = ($10|0)<(0);
    if (!($11)) {
     label = 9;
     break;
    }
    $12 = (($__nd$0$in$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $13;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $12;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$23 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $16 = HEAP32[$$0$i>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $33 = 0;$__r$0 = $16;
  HEAP32[$agg$result>>2] = $__r$0;
  $32 = (($agg$result) + 4|0);
  HEAP8[$32>>0] = $33;
  STACKTOP = sp;return;
 }
 $18 = (__Znwj(20)|0);
 $19 = (($18) + 16|0);
 $20 = HEAP32[$__v>>2]|0;
 HEAP32[$19>>2] = $20;
 HEAP32[$18>>2] = 0;
 $21 = (($18) + 4|0);
 HEAP32[$21>>2] = 0;
 $22 = (($18) + 8|0);
 HEAP32[$22>>2] = $23;
 HEAP32[$$0$i>>2] = $18;
 $24 = HEAP32[$this>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $28 = $18;
 } else {
  HEAP32[$this>>2] = $25;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $28 = $$pre$i;
 }
 $27 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 $33 = 1;$__r$0 = $18;
 HEAP32[$agg$result>>2] = $__r$0;
 $32 = (($agg$result) + 4|0);
 HEAP8[$32>>0] = $33;
 STACKTOP = sp;return;
}
function __ZNSt3__13mapINS_4pairIPcS2_EENS_3setIS2_15smaller_cstringNS_9allocatorIS2_EEEE20smaller_cstring_pairNS6_INS1_IKS3_S8_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERSA_($this,$__parent,$__k) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__k = $__k|0;
 var $$0 = 0, $$0$i = 0, $$0$i5 = 0, $$0$in$i = 0, $$0$in$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $32 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $32;
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = $__k;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $5;
 $10 = $8;
 $__nd$0$in = $1;
 while(1) {
  $11 = (($__nd$0$in) + 16|0);
  $12 = $11;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $14;
  $19 = (_strcmp($9,$18)|0);
  $20 = ($19|0)==(0);
  if ($20) {
   $21 = $17;
   $22 = (_strcmp($10,$21)|0);
   $$0$in$i4 = $22;
  } else {
   $$0$in$i4 = $19;
  }
  $$0$i5 = ($$0$in$i4|0)<(0);
  if ($$0$i5) {
   $23 = HEAP32[$__nd$0$in>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    label = 7;
    break;
   } else {
    $__nd$0$in = $23;
    continue;
   }
  }
  $25 = (_strcmp($18,$9)|0);
  $26 = ($25|0)==(0);
  if ($26) {
   $27 = $17;
   $28 = (_strcmp($27,$10)|0);
   $$0$in$i = $28;
  } else {
   $$0$in$i = $25;
  }
  $$0$i = ($$0$in$i|0)<(0);
  if (!($$0$i)) {
   label = 13;
   break;
  }
  $29 = (($__nd$0$in) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   label = 12;
   break;
  } else {
   $__nd$0$in = $30;
  }
 }
 if ((label|0) == 7) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 12) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $29;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 13) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNKSt3__16__treeINS_12__value_typeINS_4pairIPcS3_EENS_3setIS3_15smaller_cstringNS_9allocatorIS3_EEEEEENS_19__map_value_compareIS4_SA_20smaller_cstring_pairLb1EEENS7_ISA_EEE4findIS4_EENS_21__tree_const_iteratorISA_PNS_11__tree_nodeISA_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$in$i$i = 0, $$0$in$i$i$i = 0, $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = $__v;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $6;
  $11 = $9;
  $$0$ph7$i = $2;$$01$ph6$i$in = $1;
  L3: while(1) {
   $$013$i$in = $$01$ph6$i$in;
   while(1) {
    $12 = (($$013$i$in) + 16|0);
    $13 = $12;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + 4)|0;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = $15;
    $20 = (_strcmp($19,$10)|0);
    $21 = ($20|0)==(0);
    if ($21) {
     $22 = $18;
     $23 = (_strcmp($22,$11)|0);
     $$0$in$i$i$i = $23;
    } else {
     $$0$in$i$i$i = $20;
    }
    $$0$i$i$i = ($$0$in$i$i$i|0)<(0);
    if (!($$0$i$i$i)) {
     break;
    }
    $26 = (($$013$i$in) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     $$0$ph5$i = $$0$ph7$i;
     break L3;
    } else {
     $$013$i$in = $27;
    }
   }
   $24 = HEAP32[$$013$i$in>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    $$0$ph5$i = $$013$i$in;
    break;
   } else {
    $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $24;
   }
  }
  $29 = ($$0$ph5$i|0)==($2|0);
  if (!($29)) {
   $30 = (($$0$ph5$i) + 16|0);
   $31 = $30;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 4)|0;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = $33;
   $38 = (_strcmp($10,$37)|0);
   $39 = ($38|0)==(0);
   if ($39) {
    $40 = $36;
    $41 = (_strcmp($11,$40)|0);
    $$0$in$i$i = $41;
   } else {
    $$0$in$i$i = $38;
   }
   $$0$i$i = ($$0$in$i$i|0)<(0);
   if (!($$0$i$i)) {
    HEAP32[$agg$result>>2] = $$0$ph5$i;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueueC2E10MemLabelId($this,$label) {
 $this = $this|0;
 $label = $label|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 24|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 40|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 44|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 48|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 56|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 60|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 64|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 72|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 76|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 80|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 88|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 92|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 96|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 104|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 108|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 112|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 120|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 124|0);
 HEAP32[$22>>2] = 0;
 $23 = HEAP32[$label>>2]|0;
 $24 = (($this) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 20|0);
 HEAP32[$25>>2] = $23;
 $26 = (($this) + 36|0);
 HEAP32[$26>>2] = $23;
 $27 = (($this) + 52|0);
 HEAP32[$27>>2] = $23;
 $28 = (($this) + 68|0);
 HEAP32[$28>>2] = $23;
 $29 = (($this) + 84|0);
 HEAP32[$29>>2] = $23;
 $30 = (($this) + 100|0);
 HEAP32[$30>>2] = $23;
 $31 = (($this) + 116|0);
 HEAP32[$31>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue7ReserveEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = ($size*12)|0;
 $i$01 = 0;
 while(1) {
  $2 = ($i$01|0)==(0);
  if ($2) {
   $3 = (($i$01) + 1)|0;
   $i$01 = $3;
   continue;
  }
  $4 = (($this) + ($i$01<<4)|0);
  $5 = ((($this) + ($i$01<<4)|0) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 & 2147483647;
  $8 = ($7>>>0)<($size>>>0);
  do {
   if ($8) {
    $9 = ($6|0)>(-1);
    if ($9) {
     HEAP32[$5>>2] = $size;
     $10 = HEAP32[$4>>2]|0;
     $11 = ((($this) + ($i$01<<4)|0) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     HEAP32[$0>>2] = $12;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($10,$1,4,$$byval_copy1,0,638760,370)|0);
     HEAP32[$4>>2] = $13;
     break;
    } else {
     $14 = ((($this) + ($i$01<<4)|0) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$0>>2] = $15;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($1,4,$$byval_copy1,0,638760,352)|0);
     $17 = HEAP32[$4>>2]|0;
     $18 = ((($this) + ($i$01<<4)|0) + 8|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19*12)|0;
     _memcpy(($16|0),($17|0),($20|0))|0;
     HEAP32[$5>>2] = $size;
     HEAP32[$4>>2] = $16;
     break;
    }
   }
  } while(0);
  $21 = (($i$01) + 1)|0;
  $exitcond = ($21|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $21;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue25RegisterObjectInstanceIDsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i$1 = 0, $exitcond$i$2 = 0, $exitcond$i$3 = 0, $exitcond$i$4 = 0, $exitcond$i$5 = 0, $exitcond$i$6 = 0, $exitcond$i$7 = 0, $i$01$i = 0, $i$01$i$1 = 0, $i$01$i$2 = 0, $i$01$i$3 = 0, $i$01$i$4 = 0, $i$01$i$5 = 0, $i$01$i$6 = 0, $i$01$i$7 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $i$01$i = 0;
  while(1) {
   $4 = (($0) + (($i$01$i*12)|0)|0);
   $5 = HEAP32[$4>>2]|0;
   __ZN6Object24RegisterInstanceIDNoLockEPS_($5);
   $6 = (($i$01$i) + 1)|0;
   $exitcond$i = ($6|0)==($2|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $6;
   }
  }
 }
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $i$01$i$1 = 0;
  while(1) {
   $12 = (($8) + (($i$01$i$1*12)|0)|0);
   $13 = HEAP32[$12>>2]|0;
   __ZN6Object24RegisterInstanceIDNoLockEPS_($13);
   $14 = (($i$01$i$1) + 1)|0;
   $exitcond$i$1 = ($14|0)==($10|0);
   if ($exitcond$i$1) {
    break;
   } else {
    $i$01$i$1 = $14;
   }
  }
 }
 $15 = (($this) + 32|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 40|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 if (!($19)) {
  $i$01$i$2 = 0;
  while(1) {
   $20 = (($16) + (($i$01$i$2*12)|0)|0);
   $21 = HEAP32[$20>>2]|0;
   __ZN6Object24RegisterInstanceIDNoLockEPS_($21);
   $22 = (($i$01$i$2) + 1)|0;
   $exitcond$i$2 = ($22|0)==($18|0);
   if ($exitcond$i$2) {
    break;
   } else {
    $i$01$i$2 = $22;
   }
  }
 }
 $23 = (($this) + 48|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 56|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0);
 if (!($27)) {
  $i$01$i$3 = 0;
  while(1) {
   $28 = (($24) + (($i$01$i$3*12)|0)|0);
   $29 = HEAP32[$28>>2]|0;
   __ZN6Object24RegisterInstanceIDNoLockEPS_($29);
   $30 = (($i$01$i$3) + 1)|0;
   $exitcond$i$3 = ($30|0)==($26|0);
   if ($exitcond$i$3) {
    break;
   } else {
    $i$01$i$3 = $30;
   }
  }
 }
 $31 = (($this) + 64|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($this) + 72|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $i$01$i$4 = 0;
  while(1) {
   $36 = (($32) + (($i$01$i$4*12)|0)|0);
   $37 = HEAP32[$36>>2]|0;
   __ZN6Object24RegisterInstanceIDNoLockEPS_($37);
   $38 = (($i$01$i$4) + 1)|0;
   $exitcond$i$4 = ($38|0)==($34|0);
   if ($exitcond$i$4) {
    break;
   } else {
    $i$01$i$4 = $38;
   }
  }
 }
 $39 = (($this) + 80|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($this) + 88|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if (!($43)) {
  $i$01$i$5 = 0;
  while(1) {
   $44 = (($40) + (($i$01$i$5*12)|0)|0);
   $45 = HEAP32[$44>>2]|0;
   __ZN6Object24RegisterInstanceIDNoLockEPS_($45);
   $46 = (($i$01$i$5) + 1)|0;
   $exitcond$i$5 = ($46|0)==($42|0);
   if ($exitcond$i$5) {
    break;
   } else {
    $i$01$i$5 = $46;
   }
  }
 }
 $47 = (($this) + 96|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($this) + 104|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0);
 if (!($51)) {
  $i$01$i$6 = 0;
  while(1) {
   $52 = (($48) + (($i$01$i$6*12)|0)|0);
   $53 = HEAP32[$52>>2]|0;
   __ZN6Object24RegisterInstanceIDNoLockEPS_($53);
   $54 = (($i$01$i$6) + 1)|0;
   $exitcond$i$6 = ($54|0)==($50|0);
   if ($exitcond$i$6) {
    break;
   } else {
    $i$01$i$6 = $54;
   }
  }
 }
 $55 = (($this) + 112|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($this) + 120|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0);
 if ($59) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$7 = 0;
 }
 while(1) {
  $60 = (($56) + (($i$01$i$7*12)|0)|0);
  $61 = HEAP32[$60>>2]|0;
  __ZN6Object24RegisterInstanceIDNoLockEPS_($61);
  $62 = (($i$01$i$7) + 1)|0;
  $exitcond$i$7 = ($62|0)==($58|0);
  if ($exitcond$i$7) {
   break;
  } else {
   $i$01$i$7 = $62;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue3AddER6ObjectPK8TypeTreeb17AwakeFromLoadMode($this,$target,$oldType,$safeBinaryLoaded,$awakeOverride) {
 $this = $this|0;
 $target = $target|0;
 $oldType = $oldType|0;
 $safeBinaryLoaded = $safeBinaryLoaded|0;
 $awakeOverride = $awakeOverride|0;
 var $$$i = 0, $$0$i = 0, $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = ($target|0)==(0|0);
 if ($1) {
  $59 = 0;
 } else {
  $2 = (($target) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $59 = $3;
 }
 $4 = (($target) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 >>> 21;
 do {
  if ((($6|0) == 156)) {
   $$0$i = 6;
  } else if ((($6|0) == 114)) {
   $$0$i = 7;
  } else if ((($6|0) == 95)) {
   $$0$i = 5;
  } else {
   $7 = $6 & 2043;
   $8 = ($7|0)==(50);
   if ($8) {
    $$0$i = 2;
   } else {
    if ((($6|0) == 223)) {
     $$0$i = 3;
     break;
    } else if (!((($6|0) == 1))) {
     $9 = HEAP32[560640>>2]|0;
     $10 = Math_imul($9, $6)|0;
     $11 = (($10) + 2)|0;
     $12 = $11 >> 5;
     $13 = $12 << 5;
     $14 = (($11) - ($13))|0;
     $15 = HEAP32[560632>>2]|0;
     $16 = (($15) + ($12<<2)|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = 1 << $14;
     $19 = $18 & $17;
     $20 = ($19|0)==(0);
     if ($20) {
      $21 = (($10) + 9)|0;
      $22 = $21 >> 5;
      $23 = $22 << 5;
      $24 = (($21) - ($23))|0;
      $25 = (($15) + ($22<<2)|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = 1 << $24;
      $28 = $26 & $27;
      $not$$i = ($28|0)==(0);
      $$$i = $not$$i&1;
      $$0$i = $$$i;
      break;
     }
    }
    $$0$i = 4;
   }
  }
 } while(0);
 $29 = (($this) + ($$0$i<<4)|0);
 $30 = ((($this) + ($$0$i<<4)|0) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 1)|0;
 HEAP32[$30>>2] = $32;
 $33 = ((($this) + ($$0$i<<4)|0) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 2147483647;
 $36 = ($32>>>0)>($35>>>0);
 if (!($36)) {
  $55 = $32;
  $54 = (($55) + -1)|0;
  $56 = HEAP32[$29>>2]|0;
  $57 = (($56) + (($54*12)|0)|0);
  HEAP32[$57>>2] = $target;
  $58 = ((($56) + (($54*12)|0)|0) + 4|0);
  HEAP32[$58>>2] = $59;
  $60 = ((($56) + (($54*12)|0)|0) + 8|0);
  HEAP32[$60>>2] = $6;
  STACKTOP = sp;return;
 }
 $37 = $34 << 1;
 $38 = ($37|0)==(0);
 $39 = $38 ? 1 : $37;
 $40 = ($35>>>0)<($39>>>0);
 do {
  if ($40) {
   $41 = ($34|0)>(-1);
   if ($41) {
    HEAP32[$33>>2] = $39;
    $42 = HEAP32[$29>>2]|0;
    $43 = ($39*12)|0;
    $44 = ((($this) + ($$0$i<<4)|0) + 4|0);
    $45 = HEAP32[$44>>2]|0;
    HEAP32[$0>>2] = $45;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $46 = (__Z16realloc_internalPvji10MemLabelIdiPKci($42,$43,4,$$byval_copy1,0,638760,370)|0);
    HEAP32[$29>>2] = $46;
    break;
   } else {
    $47 = ($39*12)|0;
    $48 = ((($this) + ($$0$i<<4)|0) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    HEAP32[$0>>2] = $49;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $50 = (__Z15malloc_internaljj10MemLabelIdiPKci($47,4,$$byval_copy1,0,638760,352)|0);
    $51 = HEAP32[$29>>2]|0;
    $52 = HEAP32[$30>>2]|0;
    $53 = ($52*12)|0;
    _memcpy(($50|0),($51|0),($53|0))|0;
    HEAP32[$33>>2] = $39;
    HEAP32[$29>>2] = $50;
    break;
   }
  }
 } while(0);
 $$pre$i$i = HEAP32[$30>>2]|0;
 $55 = $$pre$i$i;
 $54 = (($55) + -1)|0;
 $56 = HEAP32[$29>>2]|0;
 $57 = (($56) + (($54*12)|0)|0);
 HEAP32[$57>>2] = $target;
 $58 = ((($56) + (($54*12)|0)|0) + 4|0);
 HEAP32[$58>>2] = $59;
 $60 = ((($56) + (($54*12)|0)|0) + 8|0);
 HEAP32[$60>>2] = $6;
 STACKTOP = sp;return;
}
function __Z20SortItemByInstanceIDRKN18AwakeFromLoadQueue4ItemES2_($lhs,$rhs) {
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($lhs) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($rhs) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 STACKTOP = sp;return ($4|0);
}
function __Z49SortBehaviourByExecutionOrderAndReverseInstanceIDii($lhs,$rhs) {
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $$0 = 0, $$0$i = 0, $$0$i1526 = 0, $$0$i2 = 0, $$0$i2028 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $pos$i$i$i$i16 = 0, $temp$0$i29 = 0, $temp$0$i830 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i16 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = ($lhs|0)==(0);
 do {
  if ($4) {
   $$0$i = 0;
  } else {
   HEAP32[$1>>2] = $lhs;
   $5 = HEAP32[560624>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    label = 10;
   } else {
    $7 = (($5) + 36|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($5) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    do {
     if ($11) {
      $12 = (($5) + 28|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($5) + 32|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($13) + ($15<<3)|0);
      $32 = $16;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i16,$5,$1);
      $17 = HEAP32[$pos$i$i$i$i16>>2]|0;
      $18 = ($17|0)==(-1);
      $19 = (($5) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      if ($18) {
       $21 = (($5) + 32|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + ($22<<3)|0);
       $32 = $23;
       break;
      } else {
       $24 = (($20) + ($17<<3)|0);
       $32 = $24;
       break;
      }
     }
    } while(0);
    $25 = HEAP32[560624>>2]|0;
    $26 = (($25) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + ($29<<3)|0);
    $31 = ($32|0)==($30|0);
    if ($31) {
     label = 10;
    } else {
     $33 = (($32) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      label = 10;
     } else {
      $$0$i1526 = $34;
     }
    }
   }
   if ((label|0) == 10) {
    $36 = (__Z31ReadObjectFromPersistentManageri($lhs)|0);
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$0$i = 0;
     break;
    } else {
     $$0$i1526 = $36;
    }
   }
   $38 = (($$0$i1526) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = $39 >>> 21;
   $41 = HEAP32[560640>>2]|0;
   $42 = Math_imul($41, $40)|0;
   $43 = (($42) + 114)|0;
   $44 = $43 >> 5;
   $45 = $44 << 5;
   $46 = (($43) - ($45))|0;
   $47 = HEAP32[560632>>2]|0;
   $48 = (($47) + ($44<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = 1 << $46;
   $51 = $50 & $49;
   $52 = ($51|0)==(0);
   if ($52) {
    $$0$i = 0;
   } else {
    $53 = (($$0$i1526) + 32|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)==(0);
    if ($55) {
     $$0$i = 0;
    } else {
     HEAP32[$3>>2] = $54;
     $56 = HEAP32[560624>>2]|0;
     $57 = ($56|0)==(0|0);
     if ($57) {
      label = 21;
     } else {
      $58 = (($56) + 36|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = (($56) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($59|0)==($61|0);
      do {
       if ($62) {
        $63 = (($56) + 28|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = (($56) + 32|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($64) + ($66<<3)|0);
        $83 = $67;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i16,$56,$3);
        $68 = HEAP32[$pos$i$i$i$i16>>2]|0;
        $69 = ($68|0)==(-1);
        $70 = (($56) + 28|0);
        $71 = HEAP32[$70>>2]|0;
        if ($69) {
         $72 = (($56) + 32|0);
         $73 = HEAP32[$72>>2]|0;
         $74 = (($71) + ($73<<3)|0);
         $83 = $74;
         break;
        } else {
         $75 = (($71) + ($68<<3)|0);
         $83 = $75;
         break;
        }
       }
      } while(0);
      $76 = HEAP32[560624>>2]|0;
      $77 = (($76) + 28|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($76) + 32|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($78) + ($80<<3)|0);
      $82 = ($83|0)==($81|0);
      if ($82) {
       label = 21;
      } else {
       $84 = (($83) + 4|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = ($85|0)==(0|0);
       if ($86) {
        label = 21;
       } else {
        $temp$0$i29 = $85;
       }
      }
     }
     if ((label|0) == 21) {
      $87 = (__Z31ReadObjectFromPersistentManageri($54)|0);
      $88 = ($87|0)==(0|0);
      if ($88) {
       $$0$i = 0;
       break;
      } else {
       $temp$0$i29 = $87;
      }
     }
     $89 = (($temp$0$i29) + 52|0);
     $90 = HEAP32[$89>>2]|0;
     $$0$i = $90;
    }
   }
  }
 } while(0);
 $91 = ($rhs|0)==(0);
 if ($91) {
  $$0$i2 = 0;
  $178 = ($$0$i|0)==($$0$i2|0);
  $179 = ($$0$i|0)<($$0$i2|0);
  $180 = ($lhs|0)>($rhs|0);
  $$0 = $178 ? $180 : $179;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $rhs;
 $92 = HEAP32[560624>>2]|0;
 $93 = ($92|0)==(0|0);
 if ($93) {
  label = 32;
 } else {
  $94 = (($92) + 36|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($92) + 4|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = ($95|0)==($97|0);
  do {
   if ($98) {
    $99 = (($92) + 28|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($92) + 32|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (($100) + ($102<<3)|0);
    $119 = $103;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i16,$92,$0);
    $104 = HEAP32[$pos$i$i$i$i16>>2]|0;
    $105 = ($104|0)==(-1);
    $106 = (($92) + 28|0);
    $107 = HEAP32[$106>>2]|0;
    if ($105) {
     $108 = (($92) + 32|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = (($107) + ($109<<3)|0);
     $119 = $110;
     break;
    } else {
     $111 = (($107) + ($104<<3)|0);
     $119 = $111;
     break;
    }
   }
  } while(0);
  $112 = HEAP32[560624>>2]|0;
  $113 = (($112) + 28|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = (($112) + 32|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($114) + ($116<<3)|0);
  $118 = ($119|0)==($117|0);
  if ($118) {
   label = 32;
  } else {
   $120 = (($119) + 4|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($121|0)==(0|0);
   if ($122) {
    label = 32;
   } else {
    $$0$i2028 = $121;
   }
  }
 }
 if ((label|0) == 32) {
  $123 = (__Z31ReadObjectFromPersistentManageri($rhs)|0);
  $124 = ($123|0)==(0|0);
  if ($124) {
   $$0$i2 = 0;
   $178 = ($$0$i|0)==($$0$i2|0);
   $179 = ($$0$i|0)<($$0$i2|0);
   $180 = ($lhs|0)>($rhs|0);
   $$0 = $178 ? $180 : $179;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0$i2028 = $123;
  }
 }
 $125 = (($$0$i2028) + 8|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = $126 >>> 21;
 $128 = HEAP32[560640>>2]|0;
 $129 = Math_imul($128, $127)|0;
 $130 = (($129) + 114)|0;
 $131 = $130 >> 5;
 $132 = $131 << 5;
 $133 = (($130) - ($132))|0;
 $134 = HEAP32[560632>>2]|0;
 $135 = (($134) + ($131<<2)|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = 1 << $133;
 $138 = $137 & $136;
 $139 = ($138|0)==(0);
 if ($139) {
  $$0$i2 = 0;
  $178 = ($$0$i|0)==($$0$i2|0);
  $179 = ($$0$i|0)<($$0$i2|0);
  $180 = ($lhs|0)>($rhs|0);
  $$0 = $178 ? $180 : $179;
  STACKTOP = sp;return ($$0|0);
 }
 $140 = (($$0$i2028) + 32|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = ($141|0)==(0);
 if ($142) {
  $$0$i2 = 0;
  $178 = ($$0$i|0)==($$0$i2|0);
  $179 = ($$0$i|0)<($$0$i2|0);
  $180 = ($lhs|0)>($rhs|0);
  $$0 = $178 ? $180 : $179;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$2>>2] = $141;
 $143 = HEAP32[560624>>2]|0;
 $144 = ($143|0)==(0|0);
 if ($144) {
  label = 43;
 } else {
  $145 = (($143) + 36|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = (($143) + 4|0);
  $148 = HEAP32[$147>>2]|0;
  $149 = ($146|0)==($148|0);
  do {
   if ($149) {
    $150 = (($143) + 28|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = (($143) + 32|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = (($151) + ($153<<3)|0);
    $170 = $154;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i16,$143,$2);
    $155 = HEAP32[$pos$i$i$i$i16>>2]|0;
    $156 = ($155|0)==(-1);
    $157 = (($143) + 28|0);
    $158 = HEAP32[$157>>2]|0;
    if ($156) {
     $159 = (($143) + 32|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = (($158) + ($160<<3)|0);
     $170 = $161;
     break;
    } else {
     $162 = (($158) + ($155<<3)|0);
     $170 = $162;
     break;
    }
   }
  } while(0);
  $163 = HEAP32[560624>>2]|0;
  $164 = (($163) + 28|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = (($163) + 32|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = (($165) + ($167<<3)|0);
  $169 = ($170|0)==($168|0);
  if ($169) {
   label = 43;
  } else {
   $171 = (($170) + 4|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = ($172|0)==(0|0);
   if ($173) {
    label = 43;
   } else {
    $temp$0$i830 = $172;
   }
  }
 }
 if ((label|0) == 43) {
  $174 = (__Z31ReadObjectFromPersistentManageri($141)|0);
  $175 = ($174|0)==(0|0);
  if ($175) {
   $$0$i2 = 0;
   $178 = ($$0$i|0)==($$0$i2|0);
   $179 = ($$0$i|0)<($$0$i2|0);
   $180 = ($lhs|0)>($rhs|0);
   $$0 = $178 ? $180 : $179;
   STACKTOP = sp;return ($$0|0);
  } else {
   $temp$0$i830 = $174;
  }
 }
 $176 = (($temp$0$i830) + 52|0);
 $177 = HEAP32[$176>>2]|0;
 $$0$i2 = $177;
 $178 = ($$0$i|0)==($$0$i2|0);
 $179 = ($$0$i|0)<($$0$i2|0);
 $180 = ($lhs|0)>($rhs|0);
 $$0 = $178 ? $180 : $179;
 STACKTOP = sp;return ($$0|0);
}
function __ZN18AwakeFromLoadQueue30PersistentManagerAwakeFromLoadEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + (($3*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($1,$4,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($1,$3,3);
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + (($8*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($6,$9,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($6,$8,3);
 $10 = (($this) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + (($13*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($11,$14,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($11,$13,3);
 $15 = (($this) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 56|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + (($18*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($16,$19,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($16,$18,3);
 $20 = (($this) + 64|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 72|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + (($23*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($21,$24,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($21,$23,3);
 $25 = (($this) + 80|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 88|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + (($28*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($26,$29,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($26,$28,3);
 $30 = (($this) + 96|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 104|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + (($33*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($31,$34,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($31,$33,3);
 $35 = (($this) + 112|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 120|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + (($38*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($36,$39,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($36,$38,3);
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue30PersistentManagerAwakeFromLoadEi17AwakeFromLoadMode($this,$queueIndex,$mode) {
 $this = $this|0;
 $queueIndex = $queueIndex|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + ($queueIndex<<4)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($this) + ($queueIndex<<4)|0) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + (($4*12)|0)|0);
 HEAP32[$0>>2] = 2444;
 __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($2,$5,$0);
 __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($2,$4,$mode);
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue10ClearQueueEi($this,$queueIndex) {
 $this = $this|0;
 $queueIndex = $queueIndex|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ((($this) + ($queueIndex<<4)|0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (($this) + ($queueIndex<<4)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($this) + ($queueIndex<<4)|0) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy);
  HEAP32[$4>>2] = 0;
 }
 $8 = ((($this) + ($queueIndex<<4)|0) + 8|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue5ClearEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $i$01 = 0;
 while(1) {
  $1 = ((($this) + ($i$01<<4)|0) + 12|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)>(-1);
  if ($3) {
   $4 = (($this) + ($i$01<<4)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($this) + ($i$01<<4)|0) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   HEAP32[$0>>2] = $7;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy);
   HEAP32[$4>>2] = 0;
  }
  $8 = ((($this) + ($i$01<<4)|0) + 8|0);
  HEAP32[$8>>2] = 0;
  HEAP32[$1>>2] = 0;
  $9 = (($i$01) + 1)|0;
  $exitcond = ($9|0)==(8);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue28InvokePersistentManagerAwakeEPNS_4ItemEj17AwakeFromLoadMode($objects,$size,$awakeMode) {
 $objects = $objects|0;
 $size = $size|0;
 $awakeMode = $awakeMode|0;
 var $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = ($size|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $i$03 = 0;
 while(1) {
  $2 = ((($objects) + (($i$03*12)|0)|0) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0);
  do {
   if (!($4)) {
    HEAP32[$0>>2] = $3;
    $5 = HEAP32[560624>>2]|0;
    $6 = ($5|0)==(0|0);
    if ($6) {
     label = 12;
    } else {
     $7 = (($5) + 36|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = (($5) + 4|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = ($8|0)==($10|0);
     do {
      if ($11) {
       $12 = (($5) + 28|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = (($5) + 32|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($13) + ($15<<3)|0);
       $32 = $16;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$0);
       $17 = HEAP32[$pos$i$i$i$i>>2]|0;
       $18 = ($17|0)==(-1);
       $19 = (($5) + 28|0);
       $20 = HEAP32[$19>>2]|0;
       if ($18) {
        $21 = (($5) + 32|0);
        $22 = HEAP32[$21>>2]|0;
        $23 = (($20) + ($22<<3)|0);
        $32 = $23;
        break;
       } else {
        $24 = (($20) + ($17<<3)|0);
        $32 = $24;
        break;
       }
      }
     } while(0);
     $25 = HEAP32[560624>>2]|0;
     $26 = (($25) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($25) + 32|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + ($29<<3)|0);
     $31 = ($32|0)==($30|0);
     if ($31) {
      label = 12;
     } else {
      $33 = (($32) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==(0|0);
      if ($35) {
       label = 12;
      } else {
       $$0$i2 = $34;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $36 = HEAP32[$2>>2]|0;
     $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
     $38 = ($37|0)==(0|0);
     if ($38) {
      break;
     } else {
      $$0$i2 = $37;
     }
    }
    $39 = HEAP32[$$0$i2>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    FUNCTION_TABLE_vii[$41 & 4095]($$0$i2,$awakeMode);
   }
  } while(0);
  $42 = (($i$03) + 1)|0;
  $exitcond = ($42|0)==($size|0);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue13AwakeFromLoadE17AwakeFromLoadModeb($this,$mode,$checkConsistencyFirst) {
 $this = $this|0;
 $mode = $mode|0;
 $checkConsistencyFirst = $checkConsistencyFirst|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond2 = 0, $i$01 = 0, $i$01$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 if ($checkConsistencyFirst) {
  $i$01$us = 0;
  while(1) {
   $1 = ($i$01$us|0)==(7);
   if ($1) {
    $2 = (($this) + 112|0);
    $3 = HEAP32[$2>>2]|0;
    $4 = (($this) + 120|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (($3) + (($5*12)|0)|0);
    HEAP32[$0>>2] = 2445;
    __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($3,$6,$0);
   }
   $7 = (($this) + ($i$01$us<<4)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ((($this) + ($i$01$us<<4)|0) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   __ZN18AwakeFromLoadQueue22InvokeCheckConsistencyEPNS_4ItemEj($8,$10);
   __ZN18AwakeFromLoadQueue19InvokeAwakeFromLoadEPNS_4ItemEj17AwakeFromLoadMode($8,$10,$mode);
   $11 = (($i$01$us) + 1)|0;
   $exitcond2 = ($11|0)==(8);
   if ($exitcond2) {
    break;
   } else {
    $i$01$us = $11;
   }
  }
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
  while(1) {
   $12 = ($i$01|0)==(7);
   if ($12) {
    $13 = (($this) + 112|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($this) + 120|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + (($16*12)|0)|0);
    HEAP32[$0>>2] = 2445;
    __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($14,$17,$0);
   }
   $18 = (($this) + ($i$01<<4)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($this) + ($i$01<<4)|0) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   __ZN18AwakeFromLoadQueue19InvokeAwakeFromLoadEPNS_4ItemEj17AwakeFromLoadMode($19,$21,$mode);
   $22 = (($i$01) + 1)|0;
   $exitcond = ($22|0)==(8);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $22;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZL53SortBehaviourItemByExecutionOrderAndReverseInstanceIDRKN18AwakeFromLoadQueue4ItemES2_($lhs,$rhs) {
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($lhs) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($rhs) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z49SortBehaviourByExecutionOrderAndReverseInstanceIDii($1,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN18AwakeFromLoadQueue22InvokeCheckConsistencyEPNS_4ItemEj($objects,$size) {
 $objects = $objects|0;
 $size = $size|0;
 var $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = ($size|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $i$03 = 0;
 while(1) {
  $2 = ((($objects) + (($i$03*12)|0)|0) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0);
  do {
   if (!($4)) {
    HEAP32[$0>>2] = $3;
    $5 = HEAP32[560624>>2]|0;
    $6 = ($5|0)==(0|0);
    if ($6) {
     label = 12;
    } else {
     $7 = (($5) + 36|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = (($5) + 4|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = ($8|0)==($10|0);
     do {
      if ($11) {
       $12 = (($5) + 28|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = (($5) + 32|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($13) + ($15<<3)|0);
       $32 = $16;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$0);
       $17 = HEAP32[$pos$i$i$i$i>>2]|0;
       $18 = ($17|0)==(-1);
       $19 = (($5) + 28|0);
       $20 = HEAP32[$19>>2]|0;
       if ($18) {
        $21 = (($5) + 32|0);
        $22 = HEAP32[$21>>2]|0;
        $23 = (($20) + ($22<<3)|0);
        $32 = $23;
        break;
       } else {
        $24 = (($20) + ($17<<3)|0);
        $32 = $24;
        break;
       }
      }
     } while(0);
     $25 = HEAP32[560624>>2]|0;
     $26 = (($25) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($25) + 32|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + ($29<<3)|0);
     $31 = ($32|0)==($30|0);
     if ($31) {
      label = 12;
     } else {
      $33 = (($32) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==(0|0);
      if ($35) {
       label = 12;
      } else {
       $$0$i2 = $34;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $36 = HEAP32[$2>>2]|0;
     $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
     $38 = ($37|0)==(0|0);
     if ($38) {
      break;
     } else {
      $$0$i2 = $37;
     }
    }
    $39 = HEAP32[$$0$i2>>2]|0;
    $40 = (($39) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    FUNCTION_TABLE_vi[$41 & 4095]($$0$i2);
   }
  } while(0);
  $42 = (($i$03) + 1)|0;
  $exitcond = ($42|0)==($size|0);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue19InvokeAwakeFromLoadEPNS_4ItemEj17AwakeFromLoadMode($objects,$size,$mode) {
 $objects = $objects|0;
 $size = $size|0;
 $mode = $mode|0;
 var $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = ($size|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $i$03 = 0;
 while(1) {
  $2 = ((($objects) + (($i$03*12)|0)|0) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0);
  do {
   if (!($4)) {
    HEAP32[$0>>2] = $3;
    $5 = HEAP32[560624>>2]|0;
    $6 = ($5|0)==(0|0);
    if ($6) {
     label = 12;
    } else {
     $7 = (($5) + 36|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = (($5) + 4|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = ($8|0)==($10|0);
     do {
      if ($11) {
       $12 = (($5) + 28|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = (($5) + 32|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($13) + ($15<<3)|0);
       $32 = $16;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$0);
       $17 = HEAP32[$pos$i$i$i$i>>2]|0;
       $18 = ($17|0)==(-1);
       $19 = (($5) + 28|0);
       $20 = HEAP32[$19>>2]|0;
       if ($18) {
        $21 = (($5) + 32|0);
        $22 = HEAP32[$21>>2]|0;
        $23 = (($20) + ($22<<3)|0);
        $32 = $23;
        break;
       } else {
        $24 = (($20) + ($17<<3)|0);
        $32 = $24;
        break;
       }
      }
     } while(0);
     $25 = HEAP32[560624>>2]|0;
     $26 = (($25) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($25) + 32|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + ($29<<3)|0);
     $31 = ($32|0)==($30|0);
     if ($31) {
      label = 12;
     } else {
      $33 = (($32) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==(0|0);
      if ($35) {
       label = 12;
      } else {
       $$0$i2 = $34;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $36 = HEAP32[$2>>2]|0;
     $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
     $38 = ($37|0)==(0|0);
     if ($38) {
      break;
     } else {
      $$0$i2 = $37;
     }
    }
    $39 = HEAP32[$$0$i2>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    FUNCTION_TABLE_vii[$41 & 4095]($$0$i2,$mode);
   }
  } while(0);
  $42 = (($i$03) + 1)|0;
  $exitcond = ($42|0)==($size|0);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $42;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AwakeFromLoadQueue34PersistentManagerAwakeSingleObjectER6Object17AwakeFromLoadMode($o,$awakeMode) {
 $o = $o|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$o>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($o,$awakeMode);
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$010 = 0, $__i$04$i = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$03$i = 0, $__j$03$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__k$0$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -12|0);
  $2 = (($$01$ph) + -8|0);
  $3 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $4 = $$0;
   $5 = (($0) - ($4))|0;
   $6 = (($5|0) / 12)&-1;
   switch ($6|0) {
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 52;
    break L1;
    break;
   }
   default: {
   }
   }
   $23 = ($5|0)<(84);
   if ($23) {
    label = 10;
    break L1;
   }
   $53 = ($5|0)>(11988);
   $54 = (($5|0) / 24)&-1;
   $55 = (($$0) + (($54*12)|0)|0);
   if ($53) {
    $56 = (($5|0) / 48)&-1;
    $57 = (($$0) + (($56*12)|0)|0);
    $$sum = (($56) + ($54))|0;
    $58 = (($$0) + (($$sum*12)|0)|0);
    $59 = (__ZNSt3__17__sort5IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_S9_S9_T_($$0,$57,$55,$58,$1,$__comp)|0);
    $__n_swaps$0 = $59;
   } else {
    $60 = (__ZNSt3__17__sort3IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_T_($$0,$55,$1,$__comp)|0);
    $__n_swaps$0 = $60;
   }
   $61 = HEAP32[$__comp>>2]|0;
   $62 = (FUNCTION_TABLE_iii[$61 & 4095]($$0,$55)|0);
   do {
    if ($62) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $63 = (($__j$0) + -12|0);
      $64 = ($$0|0)==($63|0);
      if ($64) {
       break;
      }
      $99 = HEAP32[$__comp>>2]|0;
      $100 = (FUNCTION_TABLE_iii[$99 & 4095]($63,$55)|0);
      if ($100) {
       label = 35;
       break;
      } else {
       $__j$0 = $63;
      }
     }
     if ((label|0) == 35) {
      label = 0;
      $101 = HEAP32[$$0>>2]|0;
      $102 = (($$0) + 4|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = (($$0) + 8|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = HEAP32[$63>>2]|0;
      HEAP32[$$0>>2] = $106;
      $107 = (($__j$0) + -8|0);
      $108 = HEAP32[$107>>2]|0;
      HEAP32[$102>>2] = $108;
      $109 = (($__j$0) + -4|0);
      $110 = HEAP32[$109>>2]|0;
      HEAP32[$104>>2] = $110;
      HEAP32[$63>>2] = $101;
      HEAP32[$107>>2] = $103;
      HEAP32[$109>>2] = $105;
      $111 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $63;$__n_swaps$3 = $111;
      break;
     }
     $65 = (($$0) + 12|0);
     $66 = HEAP32[$__comp>>2]|0;
     $67 = (FUNCTION_TABLE_iii[$66 & 4095]($$0,$1)|0);
     if ($67) {
      $__i$1 = $65;
     } else {
      $68 = ($65|0)==($1|0);
      if ($68) {
       label = 52;
       break L1;
      } else {
       $__i$010 = $65;
      }
      while(1) {
       $71 = HEAP32[$__comp>>2]|0;
       $72 = (FUNCTION_TABLE_iii[$71 & 4095]($$0,$__i$010)|0);
       $70 = (($__i$010) + 12|0);
       if ($72) {
        break;
       }
       $69 = ($70|0)==($1|0);
       if ($69) {
        label = 52;
        break L1;
       } else {
        $__i$010 = $70;
       }
      }
      $73 = HEAP32[$__i$010>>2]|0;
      $74 = (($__i$010) + 4|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (($__i$010) + 8|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = HEAP32[$1>>2]|0;
      HEAP32[$__i$010>>2] = $78;
      $79 = HEAP32[$2>>2]|0;
      HEAP32[$74>>2] = $79;
      $80 = HEAP32[$3>>2]|0;
      HEAP32[$76>>2] = $80;
      HEAP32[$1>>2] = $73;
      HEAP32[$2>>2] = $75;
      HEAP32[$3>>2] = $77;
      $__i$1 = $70;
     }
     $81 = ($__i$1|0)==($1|0);
     if ($81) {
      label = 52;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $82 = HEAP32[$__comp>>2]|0;
       $83 = (FUNCTION_TABLE_iii[$82 & 4095]($$0,$__i$2)|0);
       $84 = (($__i$2) + 12|0);
       if ($83) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $84;
       }
      }
      while(1) {
       $85 = HEAP32[$__comp>>2]|0;
       $86 = (($__j$2) + -12|0);
       $87 = (FUNCTION_TABLE_iii[$85 & 4095]($$0,$86)|0);
       if ($87) {
        $__j$2 = $86;
       } else {
        break;
       }
      }
      $88 = ($__i$2>>>0)<($86>>>0);
      if (!($88)) {
       $$0 = $__i$2;
       continue L3;
      }
      $89 = HEAP32[$__i$2>>2]|0;
      $90 = (($__i$2) + 4|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($__i$2) + 8|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = HEAP32[$86>>2]|0;
      HEAP32[$__i$2>>2] = $94;
      $95 = (($__j$2) + -8|0);
      $96 = HEAP32[$95>>2]|0;
      HEAP32[$90>>2] = $96;
      $97 = (($__j$2) + -4|0);
      $98 = HEAP32[$97>>2]|0;
      HEAP32[$92>>2] = $98;
      HEAP32[$86>>2] = $89;
      HEAP32[$95>>2] = $91;
      HEAP32[$97>>2] = $93;
      $__i$2$ph = $84;$__j$1$ph = $86;
     }
    }
   } while(0);
   $112 = (($$0) + 12|0);
   $113 = ($112>>>0)<($__j$3>>>0);
   L34: do {
    if ($113) {
     $__i$3$ph = $112;$__j$4$ph = $__j$3;$__m$0$ph = $55;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $114 = HEAP32[$__comp>>2]|0;
       $115 = (FUNCTION_TABLE_iii[$114 & 4095]($__i$3,$__m$0$ph)|0);
       $116 = (($__i$3) + 12|0);
       if ($115) {
        $__i$3 = $116;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $117 = HEAP32[$__comp>>2]|0;
       $118 = (($__j$5) + -12|0);
       $119 = (FUNCTION_TABLE_iii[$117 & 4095]($118,$__m$0$ph)|0);
       if ($119) {
        break;
       } else {
        $__j$5 = $118;
       }
      }
      $120 = ($__i$3>>>0)>($118>>>0);
      if ($120) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $121 = HEAP32[$__i$3>>2]|0;
      $122 = (($__i$3) + 4|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = (($__i$3) + 8|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = HEAP32[$118>>2]|0;
      HEAP32[$__i$3>>2] = $126;
      $127 = (($__j$5) + -8|0);
      $128 = HEAP32[$127>>2]|0;
      HEAP32[$122>>2] = $128;
      $129 = (($__j$5) + -4|0);
      $130 = HEAP32[$129>>2]|0;
      HEAP32[$124>>2] = $130;
      HEAP32[$118>>2] = $121;
      HEAP32[$127>>2] = $123;
      HEAP32[$129>>2] = $125;
      $131 = (($__n_swaps$4$ph) + 1)|0;
      $132 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $132 ? $118 : $__m$0$ph;
      $__i$3$ph = $116;$__j$4$ph = $118;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $131;
     }
    } else {
     $__i$4 = $112;$__m$2 = $55;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $133 = ($__i$4|0)==($__m$2|0);
   if ($133) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $134 = HEAP32[$__comp>>2]|0;
    $135 = (FUNCTION_TABLE_iii[$134 & 4095]($__m$2,$__i$4)|0);
    if ($135) {
     $136 = HEAP32[$__i$4>>2]|0;
     $137 = (($__i$4) + 4|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = (($__i$4) + 8|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = HEAP32[$__m$2>>2]|0;
     HEAP32[$__i$4>>2] = $141;
     $142 = (($__m$2) + 4|0);
     $143 = HEAP32[$142>>2]|0;
     HEAP32[$137>>2] = $143;
     $144 = (($__m$2) + 8|0);
     $145 = HEAP32[$144>>2]|0;
     HEAP32[$139>>2] = $145;
     HEAP32[$__m$2>>2] = $136;
     HEAP32[$142>>2] = $138;
     HEAP32[$144>>2] = $140;
     $146 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $146;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $147 = ($__n_swaps$6|0)==(0);
   if ($147) {
    $148 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEbT0_S9_T_($$0,$__i$4,$__comp)|0);
    $149 = (($__i$4) + 12|0);
    $150 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEbT0_S9_T_($149,$$01$ph,$__comp)|0);
    if ($150) {
     label = 47;
     break;
    }
    if ($148) {
     $$0 = $149;
     continue;
    }
   }
   $151 = $__i$4;
   $152 = (($151) - ($4))|0;
   $153 = (($0) - ($151))|0;
   $154 = ($152|0)<($153|0);
   if (!($154)) {
    label = 51;
    break;
   }
   __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($$0,$__i$4,$__comp);
   $155 = (($__i$4) + 12|0);
   $$0 = $155;
  }
  if ((label|0) == 47) {
   label = 0;
   if ($148) {
    label = 52;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 51) {
   label = 0;
   $156 = (($__i$4) + 12|0);
   __ZNSt3__16__sortIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEvT0_S9_T_($156,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $7 = HEAP32[$__comp>>2]|0;
  $8 = (FUNCTION_TABLE_iii[$7 & 4095]($1,$$0)|0);
  if (!($8)) {
   STACKTOP = sp;return;
  }
  $9 = HEAP32[$$0>>2]|0;
  $10 = (($$0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($$0) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$1>>2]|0;
  HEAP32[$$0>>2] = $14;
  $15 = HEAP32[$2>>2]|0;
  HEAP32[$10>>2] = $15;
  $16 = HEAP32[$3>>2]|0;
  HEAP32[$12>>2] = $16;
  HEAP32[$1>>2] = $9;
  HEAP32[$2>>2] = $11;
  HEAP32[$3>>2] = $13;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $17 = (($$0) + 12|0);
  (__ZNSt3__17__sort3IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_T_($$0,$17,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $18 = (($$0) + 12|0);
  $19 = (($$0) + 24|0);
  (__ZNSt3__17__sort4IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_S9_T_($$0,$18,$19,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $20 = (($$0) + 12|0);
  $21 = (($$0) + 24|0);
  $22 = (($$0) + 36|0);
  (__ZNSt3__17__sort5IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_S9_S9_T_($$0,$20,$21,$22,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  $24 = (($$0) + 24|0);
  $25 = (($$0) + 12|0);
  (__ZNSt3__17__sort3IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_T_($$0,$25,$24,$__comp)|0);
  $26 = (($$0) + 36|0);
  $27 = ($26|0)==($$01$ph|0);
  if ($27) {
   STACKTOP = sp;return;
  }
  $28 = (($__t$i) + 4|0);
  $29 = (($__t$i) + 8|0);
  $__i$04$i = $26;$__j$03$i = $24;
  while(1) {
   $30 = HEAP32[$__comp>>2]|0;
   $31 = (FUNCTION_TABLE_iii[$30 & 4095]($__i$04$i,$__j$03$i)|0);
   if ($31) {
    $32 = HEAP32[$__i$04$i>>2]|0;
    HEAP32[$__t$i>>2] = $32;
    $33 = (($__i$04$i) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$28>>2] = $34;
    $35 = (($__i$04$i) + 8|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$29>>2] = $36;
    $__j$1$i = $__i$04$i;$__k$0$i = $__j$03$i;
    while(1) {
     $37 = HEAP32[$__k$0$i>>2]|0;
     HEAP32[$__j$1$i>>2] = $37;
     $38 = (($__k$0$i) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($__j$1$i) + 4|0);
     HEAP32[$40>>2] = $39;
     $41 = (($__k$0$i) + 8|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($__j$1$i) + 8|0);
     HEAP32[$43>>2] = $42;
     $44 = ($__k$0$i|0)==($$0|0);
     if ($44) {
      break;
     }
     $45 = HEAP32[$__comp>>2]|0;
     $46 = (($__k$0$i) + -12|0);
     $47 = (FUNCTION_TABLE_iii[$45 & 4095]($__t$i,$46)|0);
     if ($47) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $46;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $48 = HEAP32[$__t$i>>2]|0;
    HEAP32[$__k$0$i>>2] = $48;
    $49 = HEAP32[$28>>2]|0;
    HEAP32[$38>>2] = $49;
    $50 = HEAP32[$29>>2]|0;
    HEAP32[$41>>2] = $50;
   }
   $51 = (($__i$04$i) + 12|0);
   $52 = ($51|0)==($$01$ph|0);
   if ($52) {
    break;
   } else {
    $__j$03$i$phi = $__i$04$i;$__i$04$i = $51;$__j$03$i = $__j$03$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 52) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__c>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$0 & 4095]($__y,$__x)|0);
 $2 = HEAP32[$__c>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 4095]($__z,$__y)|0);
 if (!($1)) {
  if (!($3)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $4 = HEAP32[$__y>>2]|0;
  $5 = (($__y) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($__y) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$__z>>2]|0;
  HEAP32[$__y>>2] = $9;
  $10 = (($__z) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$5>>2] = $11;
  $12 = (($__z) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$7>>2] = $13;
  HEAP32[$__z>>2] = $4;
  HEAP32[$10>>2] = $6;
  HEAP32[$12>>2] = $8;
  $14 = HEAP32[$__c>>2]|0;
  $15 = (FUNCTION_TABLE_iii[$14 & 4095]($__y,$__x)|0);
  if (!($15)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $16 = HEAP32[$__x>>2]|0;
  $17 = (($__x) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($__x) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$__y>>2]|0;
  HEAP32[$__x>>2] = $21;
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$17>>2] = $22;
  $23 = HEAP32[$7>>2]|0;
  HEAP32[$19>>2] = $23;
  HEAP32[$__y>>2] = $16;
  HEAP32[$5>>2] = $18;
  HEAP32[$7>>2] = $20;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = HEAP32[$__x>>2]|0;
 $25 = (($__x) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($__x) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 if ($3) {
  $29 = HEAP32[$__z>>2]|0;
  HEAP32[$__x>>2] = $29;
  $30 = (($__z) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$25>>2] = $31;
  $32 = (($__z) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$27>>2] = $33;
  HEAP32[$__z>>2] = $24;
  HEAP32[$30>>2] = $26;
  HEAP32[$32>>2] = $28;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = HEAP32[$__y>>2]|0;
 HEAP32[$__x>>2] = $34;
 $35 = (($__y) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 HEAP32[$25>>2] = $36;
 $37 = (($__y) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$27>>2] = $38;
 HEAP32[$__y>>2] = $24;
 HEAP32[$35>>2] = $26;
 HEAP32[$37>>2] = $28;
 $39 = HEAP32[$__c>>2]|0;
 $40 = (FUNCTION_TABLE_iii[$39 & 4095]($__z,$__y)|0);
 if (!($40)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = HEAP32[$__y>>2]|0;
 $42 = HEAP32[$35>>2]|0;
 $43 = HEAP32[$37>>2]|0;
 $44 = HEAP32[$__z>>2]|0;
 HEAP32[$__y>>2] = $44;
 $45 = (($__z) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$35>>2] = $46;
 $47 = (($__z) + 8|0);
 $48 = HEAP32[$47>>2]|0;
 HEAP32[$37>>2] = $48;
 HEAP32[$__z>>2] = $41;
 HEAP32[$45>>2] = $42;
 HEAP32[$47>>2] = $43;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_S9_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 4095]($__x4,$__x3)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = HEAP32[$__x3>>2]|0;
 $4 = (($__x3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($__x3) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$__x4>>2]|0;
 HEAP32[$__x3>>2] = $8;
 $9 = (($__x4) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$4>>2] = $10;
 $11 = (($__x4) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$6>>2] = $12;
 HEAP32[$__x4>>2] = $3;
 HEAP32[$9>>2] = $5;
 HEAP32[$11>>2] = $7;
 $13 = (($0) + 1)|0;
 $14 = HEAP32[$__c>>2]|0;
 $15 = (FUNCTION_TABLE_iii[$14 & 4095]($__x3,$__x2)|0);
 if (!($15)) {
  $__r$0 = $13;
  STACKTOP = sp;return ($__r$0|0);
 }
 $16 = HEAP32[$__x2>>2]|0;
 $17 = (($__x2) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($__x2) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$__x3>>2]|0;
 HEAP32[$__x2>>2] = $21;
 $22 = HEAP32[$4>>2]|0;
 HEAP32[$17>>2] = $22;
 $23 = HEAP32[$6>>2]|0;
 HEAP32[$19>>2] = $23;
 HEAP32[$__x3>>2] = $16;
 HEAP32[$4>>2] = $18;
 HEAP32[$6>>2] = $20;
 $24 = (($0) + 2)|0;
 $25 = HEAP32[$__c>>2]|0;
 $26 = (FUNCTION_TABLE_iii[$25 & 4095]($__x2,$__x1)|0);
 if (!($26)) {
  $__r$0 = $24;
  STACKTOP = sp;return ($__r$0|0);
 }
 $27 = HEAP32[$__x1>>2]|0;
 $28 = (($__x1) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($__x1) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$__x2>>2]|0;
 HEAP32[$__x1>>2] = $32;
 $33 = HEAP32[$17>>2]|0;
 HEAP32[$28>>2] = $33;
 $34 = HEAP32[$19>>2]|0;
 HEAP32[$30>>2] = $34;
 HEAP32[$__x2>>2] = $27;
 HEAP32[$17>>2] = $29;
 HEAP32[$19>>2] = $31;
 $35 = (($0) + 3)|0;
 $__r$0 = $35;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_S9_S9_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_S9_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 4095]($__x5,$__x4)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = HEAP32[$__x4>>2]|0;
 $4 = (($__x4) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($__x4) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$__x5>>2]|0;
 HEAP32[$__x4>>2] = $8;
 $9 = (($__x5) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$4>>2] = $10;
 $11 = (($__x5) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$6>>2] = $12;
 HEAP32[$__x5>>2] = $3;
 HEAP32[$9>>2] = $5;
 HEAP32[$11>>2] = $7;
 $13 = (($0) + 1)|0;
 $14 = HEAP32[$__c>>2]|0;
 $15 = (FUNCTION_TABLE_iii[$14 & 4095]($__x4,$__x3)|0);
 if (!($15)) {
  $__r$0 = $13;
  STACKTOP = sp;return ($__r$0|0);
 }
 $16 = HEAP32[$__x3>>2]|0;
 $17 = (($__x3) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($__x3) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$__x4>>2]|0;
 HEAP32[$__x3>>2] = $21;
 $22 = HEAP32[$4>>2]|0;
 HEAP32[$17>>2] = $22;
 $23 = HEAP32[$6>>2]|0;
 HEAP32[$19>>2] = $23;
 HEAP32[$__x4>>2] = $16;
 HEAP32[$4>>2] = $18;
 HEAP32[$6>>2] = $20;
 $24 = (($0) + 2)|0;
 $25 = HEAP32[$__c>>2]|0;
 $26 = (FUNCTION_TABLE_iii[$25 & 4095]($__x3,$__x2)|0);
 if (!($26)) {
  $__r$0 = $24;
  STACKTOP = sp;return ($__r$0|0);
 }
 $27 = HEAP32[$__x2>>2]|0;
 $28 = (($__x2) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($__x2) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$__x3>>2]|0;
 HEAP32[$__x2>>2] = $32;
 $33 = HEAP32[$17>>2]|0;
 HEAP32[$28>>2] = $33;
 $34 = HEAP32[$19>>2]|0;
 HEAP32[$30>>2] = $34;
 HEAP32[$__x3>>2] = $27;
 HEAP32[$17>>2] = $29;
 HEAP32[$19>>2] = $31;
 $35 = (($0) + 3)|0;
 $36 = HEAP32[$__c>>2]|0;
 $37 = (FUNCTION_TABLE_iii[$36 & 4095]($__x2,$__x1)|0);
 if (!($37)) {
  $__r$0 = $35;
  STACKTOP = sp;return ($__r$0|0);
 }
 $38 = HEAP32[$__x1>>2]|0;
 $39 = (($__x1) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($__x1) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$__x2>>2]|0;
 HEAP32[$__x1>>2] = $43;
 $44 = HEAP32[$28>>2]|0;
 HEAP32[$39>>2] = $44;
 $45 = HEAP32[$30>>2]|0;
 HEAP32[$41>>2] = $45;
 HEAP32[$__x2>>2] = $38;
 HEAP32[$28>>2] = $40;
 HEAP32[$30>>2] = $42;
 $46 = (($0) + 4)|0;
 $__r$0 = $46;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEbT0_S9_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__count$05 = 0, $__count$1 = 0, $__i$06 = 0, $__j$04 = 0, $__j$04$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 12)&-1;
 switch ($3|0) {
 case 5:  {
  $22 = (($__first) + 12|0);
  $23 = (($__first) + 24|0);
  $24 = (($__first) + 36|0);
  $25 = (($__last) + -12|0);
  (__ZNSt3__17__sort5IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_S9_S9_T_($__first,$22,$23,$24,$25,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $19 = (($__first) + 12|0);
  $20 = (($__first) + 24|0);
  $21 = (($__last) + -12|0);
  (__ZNSt3__17__sort4IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_S9_T_($__first,$19,$20,$21,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $17 = (($__first) + 12|0);
  $18 = (($__last) + -12|0);
  (__ZNSt3__17__sort3IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_T_($__first,$17,$18,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (($__last) + -12|0);
  $6 = (FUNCTION_TABLE_iii[$4 & 4095]($5,$__first)|0);
  if (!($6)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $7 = HEAP32[$__first>>2]|0;
  $8 = (($__first) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($__first) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$5>>2]|0;
  HEAP32[$__first>>2] = $12;
  $13 = (($__last) + -8|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$8>>2] = $14;
  $15 = (($__last) + -4|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$10>>2] = $16;
  HEAP32[$5>>2] = $7;
  HEAP32[$13>>2] = $9;
  HEAP32[$15>>2] = $11;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $26 = (($__first) + 24|0);
  $27 = (($__first) + 12|0);
  (__ZNSt3__17__sort3IRPFbRKN18AwakeFromLoadQueue4ItemES4_EPS2_EEjT0_S9_S9_T_($__first,$27,$26,$__comp)|0);
  $28 = (($__first) + 36|0);
  $29 = ($28|0)==($__last|0);
  if ($29) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $30 = (($__t) + 4|0);
  $31 = (($__t) + 8|0);
  $__count$05 = 0;$__i$06 = $28;$__j$04 = $26;
  while(1) {
   $32 = HEAP32[$__comp>>2]|0;
   $33 = (FUNCTION_TABLE_iii[$32 & 4095]($__i$06,$__j$04)|0);
   if ($33) {
    $34 = HEAP32[$__i$06>>2]|0;
    HEAP32[$__t>>2] = $34;
    $35 = (($__i$06) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$30>>2] = $36;
    $37 = (($__i$06) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$31>>2] = $38;
    $__j$1 = $__i$06;$__k$0 = $__j$04;
    while(1) {
     $39 = HEAP32[$__k$0>>2]|0;
     HEAP32[$__j$1>>2] = $39;
     $40 = (($__k$0) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($__j$1) + 4|0);
     HEAP32[$42>>2] = $41;
     $43 = (($__k$0) + 8|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($__j$1) + 8|0);
     HEAP32[$45>>2] = $44;
     $46 = ($__k$0|0)==($__first|0);
     if ($46) {
      break;
     }
     $47 = HEAP32[$__comp>>2]|0;
     $48 = (($__k$0) + -12|0);
     $49 = (FUNCTION_TABLE_iii[$47 & 4095]($__t,$48)|0);
     if ($49) {
      $__j$1$phi = $__k$0;$__k$0 = $48;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $50 = HEAP32[$__t>>2]|0;
    HEAP32[$__k$0>>2] = $50;
    $51 = HEAP32[$30>>2]|0;
    HEAP32[$40>>2] = $51;
    $52 = HEAP32[$31>>2]|0;
    HEAP32[$43>>2] = $52;
    $53 = (($__count$05) + 1)|0;
    $54 = ($53|0)==(8);
    if ($54) {
     break;
    } else {
     $__count$1 = $53;
    }
   } else {
    $__count$1 = $__count$05;
   }
   $57 = (($__i$06) + 12|0);
   $58 = ($57|0)==($__last|0);
   if ($58) {
    $$0 = 1;
    label = 16;
    break;
   } else {
    $__j$04$phi = $__i$06;$__count$05 = $__count$1;$__i$06 = $57;$__j$04 = $__j$04$phi;
   }
  }
  if ((label|0) == 16) {
   STACKTOP = sp;return ($$0|0);
  }
  $55 = (($__i$06) + 12|0);
  $56 = ($55|0)==($__last|0);
  $$0 = $56;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN25PathNamePersistentManager22InsertPathNameInternalERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEb($this,$pathname,$create) {
 $this = $this|0;
 $pathname = $pathname|0;
 $create = $create|0;
 var $$0 = 0, $$01 = 0, $$04 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$pre = 0, $$pre$phi30Z2D = 0, $$pre$phi32Z2D = 0, $$pre$phiZ2D = 0, $$pre25 = 0, $$pre27 = 0, $$pre28$pre$phiZZ2D = 0, $$pre29$pre$phiZZ2D = 0, $$pre31$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0;
 var $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i16 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $found = 0, $lowerCasePathName = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $1 = sp;
 $lowerCasePathName = sp + 16|0;
 $found = sp + 28|0;
 $2 = sp + 32|0;
 $3 = sp + 48|0;
 $4 = sp + 64|0;
 __Z7ToLowerINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_($lowerCasePathName,$pathname);
 $5 = (($this) + 172|0);
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($found,$5,$lowerCasePathName);
 $6 = (($this) + 176|0);
 $7 = HEAP32[$found>>2]|0;
 $8 = ($7|0)==($6|0);
 L1: do {
  if ($8) {
   if ($create) {
    $13 = HEAP8[$lowerCasePathName>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    do {
     if ($15) {
      ;HEAP32[$4+0>>2]=HEAP32[$lowerCasePathName+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$lowerCasePathName+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$lowerCasePathName+8>>2]|0;
      $$pre = HEAP8[$4>>0]|0;
      $$pre$phiZ2D = $4;$46 = $$pre;
      label = 15;
     } else {
      $16 = (($lowerCasePathName) + 8|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($lowerCasePathName) + 4|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = ($19>>>0)>(4294967279);
      if ($20) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        label = 3;
        break;
       }
       // unreachable;
      }
      $23 = ($19>>>0)<(11);
      if ($23) {
       $24 = $19 << 1;
       $25 = $24&255;
       HEAP8[$4>>0] = $25;
       $26 = (($4) + 1|0);
       $$pre28$pre$phiZZ2D = $4;$220 = $25;$__p$0$i$i$i = $26;
      } else {
       $27 = (($19) + 16)|0;
       $28 = $27 & -16;
       __THREW__ = 0;
       $29 = (invoke_ii(2988,($28|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 3;
        break;
       }
       $32 = (($4) + 8|0);
       HEAP32[$32>>2] = $29;
       $33 = $28 | 1;
       HEAP32[$4>>2] = $33;
       $34 = (($4) + 4|0);
       HEAP32[$34>>2] = $19;
       $35 = $33&255;
       $$pre28$pre$phiZZ2D = $4;$220 = $35;$__p$0$i$i$i = $29;
      }
      _memcpy(($__p$0$i$i$i|0),($17|0),($19|0))|0;
      $36 = (($__p$0$i$i$i) + ($19)|0);
      HEAP8[$36>>0] = 0;
      $$pre$phiZ2D = $$pre28$pre$phiZZ2D;$46 = $220;
      label = 15;
     }
    } while(0);
    L16: do {
     if ((label|0) == 15) {
      $37 = (($this) + 184|0);
      $38 = (($this) + 188|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = HEAP32[$37>>2]|0;
      $41 = $39;
      $42 = $40;
      $43 = (($41) - ($42))|0;
      $44 = (($43|0) / 12)&-1;
      $45 = $46 & 1;
      $47 = ($45<<24>>24)==(0);
      L18: do {
       if ($47) {
        ;HEAP32[$3+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
        $$pre25 = HEAP8[$3>>0]|0;
        $$pre$phi30Z2D = $3;$71 = $$pre25;
        label = 25;
       } else {
        $48 = (($4) + 8|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = (($4) + 4|0);
        $51 = HEAP32[$50>>2]|0;
        $52 = ($51>>>0)>(4294967279);
        do {
         if ($52) {
          __THREW__ = 0;
          invoke_vi(3309,0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           // unreachable;
          }
         } else {
          $55 = ($51>>>0)<(11);
          if ($55) {
           $56 = $51 << 1;
           $57 = $56&255;
           HEAP8[$3>>0] = $57;
           $58 = (($3) + 1|0);
           $$pre29$pre$phiZZ2D = $3;$221 = $57;$__p$0$i$i$i$i$i$i = $58;
          } else {
           $59 = (($51) + 16)|0;
           $60 = $59 & -16;
           __THREW__ = 0;
           $61 = (invoke_ii(2988,($60|0))|0);
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if ($63) {
            break;
           }
           $64 = (($3) + 8|0);
           HEAP32[$64>>2] = $61;
           $65 = $60 | 1;
           HEAP32[$3>>2] = $65;
           $66 = (($3) + 4|0);
           HEAP32[$66>>2] = $51;
           $67 = $65&255;
           $$pre29$pre$phiZZ2D = $3;$221 = $67;$__p$0$i$i$i$i$i$i = $61;
          }
          _memcpy(($__p$0$i$i$i$i$i$i|0),($49|0),($51|0))|0;
          $68 = (($__p$0$i$i$i$i$i$i) + ($51)|0);
          HEAP8[$68>>0] = 0;
          $$pre$phi30Z2D = $$pre29$pre$phiZZ2D;$71 = $221;
          label = 25;
          break L18;
         }
        } while(0);
        $189 = ___cxa_find_matching_catch()|0;
        $190 = tempRet0;
        $$1 = $190;$$12 = $189;
       }
      } while(0);
      if ((label|0) == 25) {
       $69 = (($3) + 12|0);
       HEAP32[$69>>2] = $44;
       $70 = $71 & 1;
       $72 = ($70<<24>>24)==(0);
       L33: do {
        if ($72) {
         ;HEAP32[$2+0>>2]=HEAP32[$$pre$phi30Z2D+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$$pre$phi30Z2D+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$$pre$phi30Z2D+8>>2]|0;
         $$pre27 = HEAP8[$2>>0]|0;
         $$pre$phi32Z2D = $2;$96 = $$pre27;
         label = 35;
        } else {
         $73 = (($3) + 8|0);
         $74 = HEAP32[$73>>2]|0;
         $75 = (($3) + 4|0);
         $76 = HEAP32[$75>>2]|0;
         $77 = ($76>>>0)>(4294967279);
         do {
          if ($77) {
           __THREW__ = 0;
           invoke_vi(3309,0);
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if (!($79)) {
            // unreachable;
           }
          } else {
           $80 = ($76>>>0)<(11);
           if ($80) {
            $81 = $76 << 1;
            $82 = $81&255;
            HEAP8[$2>>0] = $82;
            $83 = (($2) + 1|0);
            $$pre31$pre$phiZZ2D = $2;$222 = $82;$__p$0$i$i$i$i$i = $83;
           } else {
            $84 = (($76) + 16)|0;
            $85 = $84 & -16;
            __THREW__ = 0;
            $86 = (invoke_ii(2988,($85|0))|0);
            $87 = __THREW__; __THREW__ = 0;
            $88 = $87&1;
            if ($88) {
             break;
            }
            $89 = (($2) + 8|0);
            HEAP32[$89>>2] = $86;
            $90 = $85 | 1;
            HEAP32[$2>>2] = $90;
            $91 = (($2) + 4|0);
            HEAP32[$91>>2] = $76;
            $92 = $90&255;
            $$pre31$pre$phiZZ2D = $2;$222 = $92;$__p$0$i$i$i$i$i = $86;
           }
           _memcpy(($__p$0$i$i$i$i$i|0),($74|0),($76|0))|0;
           $93 = (($__p$0$i$i$i$i$i) + ($76)|0);
           HEAP8[$93>>0] = 0;
           $$pre$phi32Z2D = $$pre31$pre$phiZZ2D;$96 = $222;
           label = 35;
           break L33;
          }
         } while(0);
         $191 = ___cxa_find_matching_catch()|0;
         $192 = tempRet0;
         $$0 = $192;$$01 = $191;
        }
       } while(0);
       if ((label|0) == 35) {
        $94 = (($2) + 12|0);
        HEAP32[$94>>2] = $44;
        $95 = $96 & 1;
        $97 = ($95<<24>>24)==(0);
        L48: do {
         if ($97) {
          ;HEAP32[$1+0>>2]=HEAP32[$$pre$phi32Z2D+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$pre$phi32Z2D+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$pre$phi32Z2D+8>>2]|0;
          label = 45;
         } else {
          $98 = (($2) + 8|0);
          $99 = HEAP32[$98>>2]|0;
          $100 = (($2) + 4|0);
          $101 = HEAP32[$100>>2]|0;
          $102 = ($101>>>0)>(4294967279);
          do {
           if ($102) {
            __THREW__ = 0;
            invoke_vi(3309,0);
            $103 = __THREW__; __THREW__ = 0;
            $104 = $103&1;
            if (!($104)) {
             // unreachable;
            }
           } else {
            $105 = ($101>>>0)<(11);
            if ($105) {
             $106 = $101 << 1;
             $107 = $106&255;
             HEAP8[$1>>0] = $107;
             $108 = (($1) + 1|0);
             $__p$0$i$i$i$i$i$i$i$i = $108;
            } else {
             $109 = (($101) + 16)|0;
             $110 = $109 & -16;
             __THREW__ = 0;
             $111 = (invoke_ii(2988,($110|0))|0);
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if ($113) {
              break;
             }
             $114 = (($1) + 8|0);
             HEAP32[$114>>2] = $111;
             $115 = $110 | 1;
             HEAP32[$1>>2] = $115;
             $116 = (($1) + 4|0);
             HEAP32[$116>>2] = $101;
             $__p$0$i$i$i$i$i$i$i$i = $111;
            }
            _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($99|0),($101|0))|0;
            $117 = (($__p$0$i$i$i$i$i$i$i$i) + ($101)|0);
            HEAP8[$117>>0] = 0;
            label = 45;
            break L48;
           }
          } while(0);
          $193 = ___cxa_find_matching_catch()|0;
          $194 = tempRet0;
          $eh$lpad$body$index3Z2D = $194;$eh$lpad$body$indexZ2D = $193;
         }
        } while(0);
        do {
         if ((label|0) == 45) {
          $118 = (($1) + 12|0);
          HEAP32[$118>>2] = $44;
          __THREW__ = 0;
          invoke_viii(1919,($0|0),($5|0),($1|0));
          $119 = __THREW__; __THREW__ = 0;
          $120 = $119&1;
          if ($120) {
           $126 = ___cxa_find_matching_catch()|0;
           $127 = tempRet0;
           $128 = HEAP8[$1>>0]|0;
           $129 = $128 & 1;
           $130 = ($129<<24>>24)==(0);
           if ($130) {
            $eh$lpad$body$index3Z2D = $127;$eh$lpad$body$indexZ2D = $126;
            break;
           }
           $131 = (($1) + 8|0);
           $132 = HEAP32[$131>>2]|0;
           __ZdlPv($132);
           $eh$lpad$body$index3Z2D = $127;$eh$lpad$body$indexZ2D = $126;
           break;
          }
          $121 = HEAP8[$1>>0]|0;
          $122 = $121 & 1;
          $123 = ($122<<24>>24)==(0);
          if (!($123)) {
           $124 = (($1) + 8|0);
           $125 = HEAP32[$124>>2]|0;
           __ZdlPv($125);
          }
          $133 = HEAP8[$$pre$phi32Z2D>>0]|0;
          $134 = $133 & 1;
          $135 = ($134<<24>>24)==(0);
          if (!($135)) {
           $136 = (($2) + 8|0);
           $137 = HEAP32[$136>>2]|0;
           __ZdlPv($137);
          }
          $138 = HEAP8[$$pre$phi30Z2D>>0]|0;
          $139 = $138 & 1;
          $140 = ($139<<24>>24)==(0);
          if (!($140)) {
           $141 = (($3) + 8|0);
           $142 = HEAP32[$141>>2]|0;
           __ZdlPv($142);
          }
          $143 = HEAP8[$$pre$phiZ2D>>0]|0;
          $144 = $143 & 1;
          $145 = ($144<<24>>24)==(0);
          if (!($145)) {
           $146 = (($4) + 8|0);
           $147 = HEAP32[$146>>2]|0;
           __ZdlPv($147);
          }
          $148 = HEAP32[$38>>2]|0;
          $149 = (($this) + 192|0);
          $150 = HEAP32[$149>>2]|0;
          $151 = ($148|0)==($150|0);
          if ($151) {
           __THREW__ = 0;
           invoke_vii(2523,($37|0),($pathname|0));
           $178 = __THREW__; __THREW__ = 0;
           $179 = $178&1;
           if ($179) {
            label = 3;
            break L16;
           }
          } else {
           $152 = ($148|0)==(0|0);
           do {
            if (!($152)) {
             $153 = HEAP8[$pathname>>0]|0;
             $154 = $153 & 1;
             $155 = ($154<<24>>24)==(0);
             if ($155) {
              ;HEAP32[$148+0>>2]=HEAP32[$pathname+0>>2]|0;HEAP32[$148+4>>2]=HEAP32[$pathname+4>>2]|0;HEAP32[$148+8>>2]=HEAP32[$pathname+8>>2]|0;
              break;
             }
             $156 = (($pathname) + 8|0);
             $157 = HEAP32[$156>>2]|0;
             $158 = (($pathname) + 4|0);
             $159 = HEAP32[$158>>2]|0;
             $160 = ($159>>>0)>(4294967279);
             if ($160) {
              __THREW__ = 0;
              invoke_vi(3309,0);
              $161 = __THREW__; __THREW__ = 0;
              $162 = $161&1;
              if ($162) {
               label = 3;
               break L16;
              }
              // unreachable;
             }
             $163 = ($159>>>0)<(11);
             if ($163) {
              $164 = $159 << 1;
              $165 = $164&255;
              HEAP8[$148>>0] = $165;
              $166 = (($148) + 1|0);
              $__p$0$i$i$i$i$i16 = $166;
             } else {
              $167 = (($159) + 16)|0;
              $168 = $167 & -16;
              __THREW__ = 0;
              $169 = (invoke_ii(2988,($168|0))|0);
              $170 = __THREW__; __THREW__ = 0;
              $171 = $170&1;
              if ($171) {
               label = 3;
               break L16;
              }
              $172 = (($148) + 8|0);
              HEAP32[$172>>2] = $169;
              $173 = $168 | 1;
              HEAP32[$148>>2] = $173;
              $174 = (($148) + 4|0);
              HEAP32[$174>>2] = $159;
              $__p$0$i$i$i$i$i16 = $169;
             }
             _memcpy(($__p$0$i$i$i$i$i16|0),($157|0),($159|0))|0;
             $175 = (($__p$0$i$i$i$i$i16) + ($159)|0);
             HEAP8[$175>>0] = 0;
            }
           } while(0);
           $176 = HEAP32[$38>>2]|0;
           $177 = (($176) + 12|0);
           HEAP32[$38>>2] = $177;
          }
          __THREW__ = 0;
          invoke_vi(3560,($this|0));
          $180 = __THREW__; __THREW__ = 0;
          $181 = $180&1;
          if ($181) {
           label = 3;
           break L16;
          }
          $182 = HEAP32[$38>>2]|0;
          $183 = HEAP32[$37>>2]|0;
          $184 = $182;
          $185 = $183;
          $186 = (($184) - ($185))|0;
          $187 = (($186|0) / 12)&-1;
          $188 = (($187) + -1)|0;
          $$04 = $188;
          break L1;
         }
        } while(0);
        $195 = HEAP8[$$pre$phi32Z2D>>0]|0;
        $196 = $195 & 1;
        $197 = ($196<<24>>24)==(0);
        if ($197) {
         $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
        } else {
         $198 = (($2) + 8|0);
         $199 = HEAP32[$198>>2]|0;
         __ZdlPv($199);
         $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
        }
       }
       $200 = HEAP8[$$pre$phi30Z2D>>0]|0;
       $201 = $200 & 1;
       $202 = ($201<<24>>24)==(0);
       if ($202) {
        $$1 = $$0;$$12 = $$01;
       } else {
        $203 = (($3) + 8|0);
        $204 = HEAP32[$203>>2]|0;
        __ZdlPv($204);
        $$1 = $$0;$$12 = $$01;
       }
      }
      $205 = HEAP8[$$pre$phiZ2D>>0]|0;
      $206 = $205 & 1;
      $207 = ($206<<24>>24)==(0);
      if ($207) {
       $$2 = $$1;$$23 = $$12;
      } else {
       $208 = (($4) + 8|0);
       $209 = HEAP32[$208>>2]|0;
       __ZdlPv($209);
       $$2 = $$1;$$23 = $$12;
      }
     }
    } while(0);
    if ((label|0) == 3) {
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $$2 = $12;$$23 = $11;
    }
    $215 = HEAP8[$lowerCasePathName>>0]|0;
    $216 = $215 & 1;
    $217 = ($216<<24>>24)==(0);
    if ($217) {
     ___resumeException($$23|0);
     // unreachable;
    }
    $218 = (($lowerCasePathName) + 8|0);
    $219 = HEAP32[$218>>2]|0;
    __ZdlPv($219);
    ___resumeException($$23|0);
    // unreachable;
   } else {
    $$04 = -1;
   }
  } else {
   $9 = (($7) + 28|0);
   $10 = HEAP32[$9>>2]|0;
   $$04 = $10;
  }
 } while(0);
 $210 = HEAP8[$lowerCasePathName>>0]|0;
 $211 = $210 & 1;
 $212 = ($211<<24>>24)==(0);
 if ($212) {
  STACKTOP = sp;return ($$04|0);
 }
 $213 = (($lowerCasePathName) + 8|0);
 $214 = HEAP32[$213>>2]|0;
 __ZdlPv($214);
 STACKTOP = sp;return ($$04|0);
}
function __ZN25PathNamePersistentManager28InsertFileIdentifierInternalE14FileIdentifierb($this,$file,$create) {
 $this = $this|0;
 $file = $file|0;
 $create = $create|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$file>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = (($file) + 1|0);
  $8 = $4&255;
  $9 = $8 >>> 1;
  $16 = $9;$26 = $7;
 } else {
  $10 = (($file) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($file) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13>>>0)>(4294967279);
  if ($14) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $16 = $13;$26 = $11;
  }
 }
 $15 = ($16>>>0)<(11);
 if ($15) {
  $17 = $16 << 1;
  $18 = $17&255;
  HEAP8[$0>>0] = $18;
  $19 = (($0) + 1|0);
  $__p$0$i$i$i$i = $19;
 } else {
  $20 = (($16) + 16)|0;
  $21 = $20 & -16;
  $22 = (__Znwj($21)|0);
  $23 = (($0) + 8|0);
  HEAP32[$23>>2] = $22;
  $24 = $21 | 1;
  HEAP32[$0>>2] = $24;
  $25 = (($0) + 4|0);
  HEAP32[$25>>2] = $16;
  $__p$0$i$i$i$i = $22;
 }
 _memcpy(($__p$0$i$i$i$i|0),($26|0),($16|0))|0;
 $27 = (($__p$0$i$i$i$i) + ($16)|0);
 HEAP8[$27>>0] = 0;
 __THREW__ = 0;
 $28 = (invoke_iiii($3|0,($this|0),($0|0),($create|0))|0);
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  $38 = HEAP8[$0>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if ($40) {
   ___resumeException($36|0);
   // unreachable;
  }
  $41 = (($0) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  __ZdlPv($42);
  ___resumeException($36|0);
  // unreachable;
 } else {
  $31 = HEAP8[$0>>0]|0;
  $32 = $31 & 1;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   STACKTOP = sp;return ($28|0);
  }
  $34 = (($0) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  __ZdlPv($35);
  STACKTOP = sp;return ($28|0);
 }
 return 0|0;
}
function __ZN25PathNamePersistentManager30PathIDToFileIdentifierInternalEi($agg$result,$this,$pathID) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $pathID = $pathID|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;HEAP32[$agg$result+28>>2]=0|0;
 $1 = (($this) + 184|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($pathID*12)|0)|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $11 = (($3) + 1|0);
  $12 = $4&255;
  $13 = $12 >>> 1;
  $15 = $13;$17 = $11;
 } else {
  $7 = ((($2) + (($pathID*12)|0)|0) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($2) + (($pathID*12)|0)|0) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $15 = $10;$17 = $8;
 }
 $14 = ($15>>>0)>(10);
 if (!($14)) {
  $16 = (($agg$result) + 1|0);
  _memmove(($16|0),($17|0),($15|0))|0;
  $18 = ((($agg$result) + ($15)|0) + 1|0);
  HEAP8[$18>>0] = 0;
  $19 = HEAP8[$agg$result>>0]|0;
  $20 = $19 & 1;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   $23 = $15 << 1;
   $24 = $23&255;
   HEAP8[$agg$result>>0] = $24;
   STACKTOP = sp;return;
  } else {
   $22 = (($agg$result) + 4|0);
   HEAP32[$22>>2] = $15;
   STACKTOP = sp;return;
  }
 }
 $25 = (($15) + -10)|0;
 __THREW__ = 0;
 invoke_viiiiiiii(22,($agg$result|0),10,($25|0),0,0,0,($15|0),($17|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if (!($27)) {
  STACKTOP = sp;return;
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 $30 = HEAP8[$agg$result>>0]|0;
 $31 = $30 & 1;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  ___resumeException($28|0);
  // unreachable;
 }
 $33 = (($agg$result) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  ___cxa_call_unexpected(($37|0));
  // unreachable;
 } else {
  ___resumeException($28|0);
  // unreachable;
 }
}
function __ZN25PathNamePersistentManager24PathIDToPathNameInternalEi($agg$result,$this,$pathID) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $pathID = $pathID|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 184|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($pathID*12)|0)|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$2+8>>2]|0;
  STACKTOP = sp;return;
 }
 $6 = ((($1) + (($pathID*12)|0)|0) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($1) + (($pathID*12)|0)|0) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9>>>0)>(4294967279);
 if ($10) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $11 = ($9>>>0)<(11);
 if ($11) {
  $12 = $9 << 1;
  $13 = $12&255;
  HEAP8[$agg$result>>0] = $13;
  $14 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $14;
 } else {
  $15 = (($9) + 16)|0;
  $16 = $15 & -16;
  $17 = (__Znwj($16)|0);
  $18 = (($agg$result) + 8|0);
  HEAP32[$18>>2] = $17;
  $19 = $16 | 1;
  HEAP32[$agg$result>>2] = $19;
  $20 = (($agg$result) + 4|0);
  HEAP32[$20>>2] = $9;
  $__p$0$i$i$i = $17;
 }
 _memcpy(($__p$0$i$i$i|0),($7|0),($9|0))|0;
 $21 = (($__p$0$i$i$i) + ($9)|0);
 HEAP8[$21>>0] = 0;
 STACKTOP = sp;return;
}
function __Z29InitPathNamePersistentManagerv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628240>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(196,$$byval_copy1,1,16,638768,49)|0);
 __THREW__ = 0;
 invoke_viii(1920,($2|0),0,2);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  HEAP32[$2>>2] = ((638776 + 8|0));
  $5 = (($2) + 176|0);
  HEAP32[$5>>2] = 0;
  $6 = (($2) + 180|0);
  HEAP32[$6>>2] = 0;
  $7 = (($2) + 172|0);
  HEAP32[$7>>2] = $5;
  $8 = (($2) + 184|0);
  HEAP32[$8>>2] = 0;
  $9 = (($2) + 188|0);
  HEAP32[$9>>2] = 0;
  $10 = (($2) + 192|0);
  HEAP32[$10>>2] = 0;
  STACKTOP = sp;return;
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($2|0),($$byval_copy1|0),1,16,(638768|0),49);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZN25PathNamePersistentManagerD1Ev($this) {
 $this = $this|0;
 var $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((638776 + 8|0));
 $0 = (($this) + 184|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 188|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if ($5) {
   $15 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = (($7) + -12|0);
    HEAP32[$3>>2] = $6;
    $8 = HEAP8[$6>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $12 = $6;
    } else {
     $13 = (($7) + -4|0);
     $14 = HEAP32[$13>>2]|0;
     __ZdlPv($14);
     $$pre$i$i$i$i$i$i = HEAP32[$3>>2]|0;
     $12 = $$pre$i$i$i$i$i$i;
    }
    $11 = ($12|0)==($1|0);
    if ($11) {
     break;
    } else {
     $7 = $12;
    }
   }
   $$pre$i$i$i$i = HEAP32[$0>>2]|0;
   $15 = $$pre$i$i$i$i;
  }
  __ZdlPv($15);
 }
 $16 = (($this) + 172|0);
 $17 = (($this) + 176|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($16,$18);
 __ZN17PersistentManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN25PathNamePersistentManagerD0Ev($this) {
 $this = $this|0;
 var $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((638776 + 8|0));
 $0 = (($this) + 184|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 188|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if ($5) {
   $15 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = (($7) + -12|0);
    HEAP32[$3>>2] = $6;
    $8 = HEAP8[$6>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $12 = $6;
    } else {
     $13 = (($7) + -4|0);
     $14 = HEAP32[$13>>2]|0;
     __ZdlPv($14);
     $$pre$i$i$i$i$i$i$i = HEAP32[$3>>2]|0;
     $12 = $$pre$i$i$i$i$i$i$i;
    }
    $11 = ($12|0)==($1|0);
    if ($11) {
     break;
    } else {
     $7 = $12;
    }
   }
   $$pre$i$i$i$i$i = HEAP32[$0>>2]|0;
   $15 = $$pre$i$i$i$i$i;
  }
  __ZdlPv($15);
 }
 $16 = (($this) + 172|0);
 $17 = (($this) + 176|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE7destroyEPNS_11__tree_nodeIS8_PvEE($16,$18);
 __THREW__ = 0;
 invoke_vi(1157,($this|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  __ZdlPv($this);
  ___resumeException($21|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE15__insert_uniqueERKS8_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS8_EERPNS_16__tree_node_baseIPvEESK_RKT_($this,$__parent,$__v)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $47 = 0;$__r$0 = $1;
  HEAP32[$agg$result>>2] = $__r$0;
  $46 = (($agg$result) + 4|0);
  HEAP8[$46>>0] = $47;
  STACKTOP = sp;return;
 }
 $3 = (__Znwj(32)|0);
 $4 = (($3) + 16|0);
 $5 = HEAP8[$__v>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 L4: do {
  if ($7) {
   ;HEAP32[$4+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__v+8>>2]|0;
  } else {
   $8 = (($__v) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($__v) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11>>>0)>(4294967279);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    } else {
     $15 = ($11>>>0)<(11);
     if ($15) {
      $16 = $11 << 1;
      $17 = $16&255;
      HEAP8[$4>>0] = $17;
      $18 = (($3) + 17|0);
      $__p$0$i$i$i$i$i$i$i$i$i = $18;
     } else {
      $19 = (($11) + 16)|0;
      $20 = $19 & -16;
      __THREW__ = 0;
      $21 = (invoke_ii(2988,($20|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      $24 = (($3) + 24|0);
      HEAP32[$24>>2] = $21;
      $25 = $20 | 1;
      HEAP32[$4>>2] = $25;
      $26 = (($3) + 20|0);
      HEAP32[$26>>2] = $11;
      $__p$0$i$i$i$i$i$i$i$i$i = $21;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($9|0),($11|0))|0;
     $27 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($11)|0);
     HEAP8[$27>>0] = 0;
     break L4;
    }
   } while(0);
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = ($3|0)==(0|0);
   if ($30) {
    ___resumeException($28|0);
    // unreachable;
   }
   __ZdlPv($3);
   ___resumeException($28|0);
   // unreachable;
  }
 } while(0);
 $31 = (($3) + 28|0);
 $32 = (($__v) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$31>>2] = $33;
 $34 = HEAP32[$__parent>>2]|0;
 HEAP32[$3>>2] = 0;
 $35 = (($3) + 4|0);
 HEAP32[$35>>2] = 0;
 $36 = (($3) + 8|0);
 HEAP32[$36>>2] = $34;
 HEAP32[$0>>2] = $3;
 $37 = HEAP32[$this>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $42 = $3;
 } else {
  HEAP32[$this>>2] = $38;
  $$pre$i = HEAP32[$0>>2]|0;
  $42 = $$pre$i;
 }
 $40 = (($this) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($41,$42);
 $43 = (($this) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 1)|0;
 HEAP32[$43>>2] = $45;
 $47 = 1;$__r$0 = $3;
 HEAP32[$agg$result>>2] = $__r$0;
 $46 = (($agg$result) + 4|0);
 HEAP8[$46>>0] = $47;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE12__find_equalIS8_EERPNS_16__tree_node_baseIPvEESK_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $60 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $60;
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 $__nd$0$in = $1;
 while(1) {
  $11 = (($__nd$0$in) + 16|0);
  if ($5) {
   $26 = $7;
  } else {
   $12 = HEAP32[$10>>2]|0;
   $26 = $12;
  }
  $13 = HEAP8[$11>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $25 = $19;
  } else {
   $16 = (($__nd$0$in) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $25 = $17;
  }
  if ($5) {
   $28 = $8;
  } else {
   $20 = HEAP32[$9>>2]|0;
   $28 = $20;
  }
  if ($15) {
   $23 = (($11) + 1|0);
   $29 = $23;
  } else {
   $21 = (($__nd$0$in) + 24|0);
   $22 = HEAP32[$21>>2]|0;
   $29 = $22;
  }
  $24 = ($25>>>0)<($26>>>0);
  $27 = $24 ? $25 : $26;
  $30 = (_memcmp($28,$29,$27)|0);
  $31 = ($30|0)==(0);
  if ($31) {
   $32 = ($26>>>0)<($25>>>0);
   $$$i$i$i$i4 = $24&1;
   $$$$i$i$i$i5 = $32 ? -1 : $$$i$i$i$i4;
   $34 = $$$$i$i$i$i5;
  } else {
   $34 = $30;
  }
  $33 = ($34|0)<(0);
  if ($33) {
   $35 = HEAP32[$__nd$0$in>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 17;
    break;
   } else {
    $__nd$0$in = $35;
    continue;
   }
  }
  if ($15) {
   $39 = $13&255;
   $40 = $39 >>> 1;
   $48 = $40;
  } else {
   $37 = (($__nd$0$in) + 20|0);
   $38 = HEAP32[$37>>2]|0;
   $48 = $38;
  }
  if ($5) {
   $47 = $7;
  } else {
   $41 = HEAP32[$10>>2]|0;
   $47 = $41;
  }
  if ($15) {
   $44 = (($11) + 1|0);
   $50 = $44;
  } else {
   $42 = (($__nd$0$in) + 24|0);
   $43 = HEAP32[$42>>2]|0;
   $50 = $43;
  }
  if ($5) {
   $51 = $8;
  } else {
   $45 = HEAP32[$9>>2]|0;
   $51 = $45;
  }
  $46 = ($47>>>0)<($48>>>0);
  $49 = $46 ? $47 : $48;
  $52 = (_memcmp($50,$51,$49)|0);
  $53 = ($52|0)==(0);
  if ($53) {
   $54 = ($48>>>0)<($47>>>0);
   $$$i$i$i$i = $46&1;
   $$$$i$i$i$i = $54 ? -1 : $$$i$i$i$i;
   $56 = $$$$i$i$i$i;
  } else {
   $56 = $52;
  }
  $55 = ($56|0)<(0);
  if (!($55)) {
   label = 33;
   break;
  }
  $57 = (($__nd$0$in) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   label = 32;
   break;
  } else {
   $__nd$0$in = $58;
  }
 }
 if ((label|0) == 17) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $57;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN17PersistentManager38InstanceIDToSerializedObjectIdentifierEiR26SerializedObjectIdentifier($this,$instanceID,$identifier) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 $identifier = $identifier|0;
 var $$0$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if (!($4)) {
  $5 = (($1) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>($instanceID|0);
  if (!($7)) {
   $8 = (($1) + 32|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)<($instanceID|0);
   if (!($10)) {
    HEAP32[$identifier>>2] = $3;
    $11 = HEAP32[$5>>2]|0;
    $12 = (($instanceID) - ($11))|0;
    $13 = (($12|0) / 2)&-1;
    $14 = ($13|0)<(0);
    $15 = $14 << 31 >> 31;
    $16 = (($identifier) + 8|0);
    $17 = $16;
    $18 = $17;
    HEAP32[$18>>2] = $13;
    $19 = (($17) + 4)|0;
    $20 = $19;
    HEAP32[$20>>2] = $15;
    $$0$i = 1;
    STACKTOP = sp;return ($$0$i|0);
   }
  }
 }
 $21 = (($1) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($1) + 16|0);
 $24 = ($22|0)==(0|0);
 if (!($24)) {
  $$0$ph7$i$i$i$i = $23;$$01$ph6$i$in$i$i$i = $22;
  L8: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $25 = (($$013$i$in$i$i$i) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)<($instanceID|0);
    if (!($27)) {
     break;
    }
    $30 = (($$013$i$in$i$i$i) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L8;
    } else {
     $$013$i$in$i$i$i = $31;
    }
   }
   $28 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $29 = ($28|0)==(0|0);
   if ($29) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $28;
   }
  }
  $33 = ($$0$ph5$i$i$i$i|0)==($23|0);
  if (!($33)) {
   $34 = (($$0$ph5$i$i$i$i) + 16|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)>($instanceID|0);
   if (!($36)) {
    $42 = (($$0$ph5$i$i$i$i) + 24|0);
    ;HEAP32[$identifier+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$identifier+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$identifier+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$identifier+12>>2]=HEAP32[$42+12>>2]|0;
    $$0$i = 1;
    STACKTOP = sp;return ($$0$i|0);
   }
  }
 }
 HEAP32[$identifier>>2] = -1;
 $37 = (($identifier) + 8|0);
 $38 = $37;
 $39 = $38;
 HEAP32[$39>>2] = 0;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = 0;
 $$0$i = 0;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx($this,$path,$0,$1) {
 $this = $this|0;
 $path = $path|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $2 = sp + 24|0;
 $3 = sp;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$6 & 2047]($this,$path,1)|0);
 $8 = (($this) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==(-1);
 if ($10) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $11 = (($9) + 36|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)!=(-1);
 $14 = ($12|0)==($7|0);
 $or$cond$i = $13 & $14;
 if ($or$cond$i) {
  $15 = (_bitshift64Shl(($0|0),($1|0),1)|0);
  $16 = tempRet0;
  $17 = (($9) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (_i64Add(($18|0),0,($15|0),($16|0))|0);
  $20 = tempRet0;
  $$0$i = $19;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$3>>2] = $7;
 $21 = (($3) + 8|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = $0;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $1;
 $26 = (($3) + 16|0);
 HEAP32[$26>>2] = 0;
 __ZNSt3__16__treeINS_12__value_typeI26SerializedObjectIdentifieriEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_($2,$9,$3);
 $27 = HEAP32[$2>>2]|0;
 $28 = (($2) + 4|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if ($30) {
  $42 = (($27) + 32|0);
  $43 = HEAP32[$42>>2]|0;
  $$0$i = $43;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $31 = (($9) + 24|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 2)|0;
  HEAP32[$31>>2] = $33;
  $34 = (($27) + 32|0);
  HEAP32[$34>>2] = $33;
  $35 = (($9) + 12|0);
  HEAP32[$3>>2] = $33;
  $36 = (($3) + 8|0);
  HEAP32[$36>>2] = $7;
  $37 = (($3) + 16|0);
  $38 = $37;
  $39 = $38;
  HEAP32[$39>>2] = $0;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $1;
  __ZNSt3__16__treeINS_12__value_typeIi26SerializedObjectIdentifierEENS_19__map_value_compareIiS3_NS_4lessIiEELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_($2,$35,$3);
  $$0$i = $33;
  STACKTOP = sp;return ($$0$i|0);
 }
 return 0|0;
}
function __ZN17PersistentManager20GetSerializedClassIDEi($this,$instanceID) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 var $$0 = 0, $$0$lcssa$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  label = 5;
 } else {
  $5 = (($1) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>($instanceID|0);
  if ($7) {
   label = 5;
  } else {
   $8 = (($1) + 32|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)<($instanceID|0);
   if ($10) {
    label = 5;
   } else {
    $11 = (($instanceID) - ($6))|0;
    $12 = (($11|0) / 2)&-1;
    $13 = ($12|0)<(0);
    $14 = $13 << 31 >> 31;
    $41 = $3;$45 = $12;$46 = $14;
   }
  }
 }
 do {
  if ((label|0) == 5) {
   $15 = (($1) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($1) + 16|0);
   $18 = ($16|0)==(0|0);
   if ($18) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$0$ph7$i$i$i$i = $17;$$01$ph6$i$in$i$i$i = $16;
   }
   L9: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $19 = (($$013$i$in$i$i$i) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)<($instanceID|0);
     if (!($21)) {
      break;
     }
     $24 = (($$013$i$in$i$i$i) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     if ($26) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L9;
     } else {
      $$013$i$in$i$i$i = $25;
     }
    }
    $22 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $22;
    }
   }
   $27 = ($$0$ph5$i$i$i$i|0)==($17|0);
   if ($27) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $28 = (($$0$ph5$i$i$i$i) + 16|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>($instanceID|0);
   if ($30) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $31 = (($$0$ph5$i$i$i$i) + 24|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($$0$ph5$i$i$i$i) + 32|0);
    $34 = $33;
    $35 = $34;
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + 4)|0;
    $38 = $37;
    $39 = HEAP32[$38>>2]|0;
    $41 = $32;$45 = $36;$46 = $39;
    break;
   }
  }
 } while(0);
 $40 = ($41|0)==(-1);
 if ($40) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = (__ZN17PersistentManager26GetStreamNameSpaceInternalEi($this,$41)|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $47 = (__ZNK14SerializedFile11IsAvailableEx($43,$45,$46)|0);
 if (!($47)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $48 = (($42) + 16|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 L32: do {
  if (!($50)) {
   $51 = HEAP32[$49>>2]|0;
   $52 = (($49) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($51) + ($53<<3)|0);
   $55 = ($53|0)==(0);
   L34: do {
    if ($55) {
     $$0$lcssa$i$i$i = $51;
    } else {
     $$01$i$i$i = $51;
     while(1) {
      $58 = $$01$i$i$i;
      $59 = $58;
      $60 = HEAP32[$59>>2]|0;
      $61 = (($58) + 4)|0;
      $62 = $61;
      $63 = HEAP32[$62>>2]|0;
      $64 = ($60|0)==($45|0);
      $65 = ($63|0)==($46|0);
      $66 = $64 & $65;
      $57 = (($$01$i$i$i) + 8|0);
      if ($66) {
       $$0$lcssa$i$i$i = $$01$i$i$i;
       break L34;
      }
      $56 = ($57|0)==($54|0);
      if ($56) {
       break L32;
      } else {
       $$01$i$i$i = $57;
      }
     }
    }
   } while(0);
   $67 = ($$0$lcssa$i$i$i|0)==($54|0);
   if (!($67)) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $68 = HEAP32[$42>>2]|0;
 $69 = ($68|0)==(0|0);
 if ($69) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $70 = (__ZNK14SerializedFile10GetClassIDEx($68,$45,$46)|0);
 $$0 = $70;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17PersistentManager13GetAllFileIDsERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER13dynamic_arrayIxLj8EE($this,$pathName,$fileIDs) {
 $this = $this|0;
 $pathName = $pathName|0;
 $fileIDs = $fileIDs|0;
 var $$0$lcssa$i$i = 0, $$01$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $it$0$ph6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 2047]($this,$pathName,1)|0);
 $4 = ($3|0)==(-1);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__ZN17PersistentManager26GetStreamNameSpaceInternalEi($this,$3)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 __ZNK14SerializedFile13GetAllFileIDsER13dynamic_arrayIxLj8EE($7,$fileIDs);
 $9 = (($fileIDs) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$fileIDs>>2]|0;
 $13 = (($5) + 16|0);
 $53 = $10;$54 = $12;$it$0$ph6 = $12;
 L13: while(1) {
  $14 = (($it$0$ph6) + 8|0);
  $15 = $14;
  $42 = $54;$43 = $53;
  L15: while(1) {
   $16 = $it$0$ph6;
   $17 = $16;
   $18 = HEAP32[$17>>2]|0;
   $19 = (($16) + 4)|0;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$13>>2]|0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    break;
   }
   $24 = HEAP32[$22>>2]|0;
   $25 = (($22) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + ($26<<3)|0);
   $28 = ($26|0)==(0);
   L18: do {
    if ($28) {
     $$0$lcssa$i$i = $24;
    } else {
     $$01$i$i = $24;
     while(1) {
      $31 = $$01$i$i;
      $32 = $31;
      $33 = HEAP32[$32>>2]|0;
      $34 = (($31) + 4)|0;
      $35 = $34;
      $36 = HEAP32[$35>>2]|0;
      $37 = ($33|0)==($18|0);
      $38 = ($36|0)==($21|0);
      $39 = $37 & $38;
      $30 = (($$01$i$i) + 8|0);
      if ($39) {
       $$0$lcssa$i$i = $$01$i$i;
       break L18;
      }
      $29 = ($30|0)==($27|0);
      if ($29) {
       break L15;
      } else {
       $$01$i$i = $30;
      }
     }
    }
   } while(0);
   $40 = ($$0$lcssa$i$i|0)==($27|0);
   if ($40) {
    break;
   }
   $41 = (($42) + ($43<<3)|0);
   $44 = $41;
   $45 = (($44) - ($15))|0;
   _memmove(($it$0$ph6|0),($14|0),($45|0))|0;
   $46 = HEAP32[$9>>2]|0;
   $47 = (($46) + -1)|0;
   HEAP32[$9>>2] = $47;
   $48 = HEAP32[$fileIDs>>2]|0;
   $49 = (($48) + ($47<<3)|0);
   $50 = ($it$0$ph6|0)==($49|0);
   if ($50) {
    label = 14;
    break L13;
   } else {
    $42 = $48;$43 = $47;
   }
  }
  $51 = (($42) + ($43<<3)|0);
  $52 = ($14|0)==($51|0);
  if ($52) {
   label = 14;
   break;
  } else {
   $53 = $43;$54 = $42;$it$0$ph6 = $14;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZN17PersistentManager32GetAllFileIDsAndClassIDsFromPathERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER13dynamic_arrayIxLj8EERS9_IiLj4EE($this,$path,$fileIDs,$classIDs) {
 $this = $this|0;
 $path = $path|0;
 $fileIDs = $fileIDs|0;
 $classIDs = $classIDs|0;
 var $$0 = 0, $$0$lcssa$i$i = 0, $$01 = 0, $$01$i$i = 0, $$byval_copy14 = 0, $$lcssa = 0, $$pr = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i16 = 0, $$pre29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $it$025 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $sourceFileIDs = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy14 = sp + 52|0;
 $0 = sp + 48|0;
 $1 = sp + 44|0;
 $2 = sp + 40|0;
 $3 = sp + 36|0;
 $4 = sp + 32|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 $sourceFileIDs = sp + 16|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = (($9) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 $12 = (invoke_iiii($11|0,($this|0),($path|0),1)|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 L1: do {
  if (!($14)) {
   $15 = ($12|0)==(-1);
   if ($15) {
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   $16 = (invoke_iii(2446,($this|0),($12|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = ($16|0)==(0|0);
    if ($19) {
     STACKTOP = sp;return;
    }
    $20 = HEAP32[$16>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     STACKTOP = sp;return;
    }
    $24 = HEAP32[628512>>2]|0;
    HEAP32[$sourceFileIDs>>2] = 0;
    $25 = (($sourceFileIDs) + 4|0);
    HEAP32[$25>>2] = $24;
    $26 = (($sourceFileIDs) + 8|0);
    HEAP32[$26>>2] = 0;
    $27 = (($sourceFileIDs) + 12|0);
    HEAP32[$27>>2] = 0;
    $28 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_vii(3217,($28|0),($sourceFileIDs|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    L13: do {
     if ($30) {
      label = 29;
     } else {
      $31 = HEAP32[$26>>2]|0;
      $32 = (($fileIDs) + 12|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = $33 & 2147483647;
      $35 = ($34>>>0)<($31>>>0);
      do {
       if ($35) {
        $36 = ($33|0)>(-1);
        if ($36) {
         HEAP32[$32>>2] = $31;
         $37 = HEAP32[$fileIDs>>2]|0;
         $38 = $31 << 3;
         $39 = (($fileIDs) + 4|0);
         $40 = HEAP32[$39>>2]|0;
         HEAP32[$7>>2] = $40;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$7+0>>2]|0;
         $41 = (invoke_iiiiiiii(108,($37|0),($38|0),8,($$byval_copy14|0),0,(638872|0),370)|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 29;
          break L13;
         }
         HEAP32[$fileIDs>>2] = $41;
         break;
        } else {
         $44 = $31 << 3;
         $45 = (($fileIDs) + 4|0);
         $46 = HEAP32[$45>>2]|0;
         HEAP32[$8>>2] = $46;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$8+0>>2]|0;
         $47 = (invoke_iiiiiii(102,($44|0),8,($$byval_copy14|0),0,(638872|0),352)|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          label = 29;
          break L13;
         }
         $50 = HEAP32[$fileIDs>>2]|0;
         $51 = (($fileIDs) + 8|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = $52 << 3;
         _memcpy(($47|0),($50|0),($53|0))|0;
         HEAP32[$32>>2] = $31;
         HEAP32[$fileIDs>>2] = $47;
         break;
        }
       }
      } while(0);
      $54 = HEAP32[$26>>2]|0;
      $55 = (($classIDs) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = $56 & 2147483647;
      $58 = ($57>>>0)<($54>>>0);
      if ($58) {
       $59 = ($56|0)>(-1);
       if ($59) {
        HEAP32[$55>>2] = $54;
        $60 = HEAP32[$classIDs>>2]|0;
        $61 = $54 << 2;
        $62 = (($classIDs) + 4|0);
        $63 = HEAP32[$62>>2]|0;
        HEAP32[$5>>2] = $63;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
        $64 = (invoke_iiiiiiii(108,($60|0),($61|0),4,($$byval_copy14|0),0,(638872|0),370)|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 29;
         break;
        }
        HEAP32[$classIDs>>2] = $64;
       } else {
        $67 = $54 << 2;
        $68 = (($classIDs) + 4|0);
        $69 = HEAP32[$68>>2]|0;
        HEAP32[$6>>2] = $69;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$6+0>>2]|0;
        $70 = (invoke_iiiiiii(102,($67|0),4,($$byval_copy14|0),0,(638872|0),352)|0);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 29;
         break;
        }
        $73 = HEAP32[$classIDs>>2]|0;
        $74 = (($classIDs) + 8|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = $75 << 2;
        _memcpy(($70|0),($73|0),($76|0))|0;
        HEAP32[$55>>2] = $54;
        HEAP32[$classIDs>>2] = $70;
       }
       $$pr = HEAP32[$26>>2]|0;
       $79 = $$pr;
      } else {
       $79 = $54;
      }
      $77 = HEAP32[$sourceFileIDs>>2]|0;
      $78 = ($79|0)==(0);
      L32: do {
       if ($78) {
        $$lcssa = $77;
       } else {
        $80 = (($16) + 16|0);
        $81 = (($fileIDs) + 8|0);
        $82 = (($fileIDs) + 4|0);
        $83 = (($classIDs) + 8|0);
        $84 = (($classIDs) + 4|0);
        $202 = $79;$203 = $77;$it$025 = $77;
        L34: while(1) {
         $85 = $it$025;
         $86 = $85;
         $87 = HEAP32[$86>>2]|0;
         $88 = (($85) + 4)|0;
         $89 = $88;
         $90 = HEAP32[$89>>2]|0;
         $91 = HEAP32[$80>>2]|0;
         $92 = ($91|0)==(0|0);
         L36: do {
          if ($92) {
           label = 33;
          } else {
           $93 = HEAP32[$91>>2]|0;
           $94 = (($91) + 8|0);
           $95 = HEAP32[$94>>2]|0;
           $96 = (($93) + ($95<<3)|0);
           $97 = ($95|0)==(0);
           L38: do {
            if ($97) {
             $$0$lcssa$i$i = $93;
            } else {
             $$01$i$i = $93;
             while(1) {
              $100 = $$01$i$i;
              $101 = $100;
              $102 = HEAP32[$101>>2]|0;
              $103 = (($100) + 4)|0;
              $104 = $103;
              $105 = HEAP32[$104>>2]|0;
              $106 = ($102|0)==($87|0);
              $107 = ($105|0)==($90|0);
              $108 = $106 & $107;
              $99 = (($$01$i$i) + 8|0);
              if ($108) {
               $$0$lcssa$i$i = $$01$i$i;
               break L38;
              }
              $98 = ($99|0)==($96|0);
              if ($98) {
               label = 33;
               break L36;
              } else {
               $$01$i$i = $99;
              }
             }
            }
           } while(0);
           $109 = ($$0$lcssa$i$i|0)==($96|0);
           if ($109) {
            label = 33;
           } else {
            $192 = $203;$193 = $202;
           }
          }
         } while(0);
         if ((label|0) == 33) {
          label = 0;
          $120 = HEAP32[$81>>2]|0;
          $121 = (($120) + 1)|0;
          HEAP32[$81>>2] = $121;
          $122 = HEAP32[$32>>2]|0;
          $123 = $122 & 2147483647;
          $124 = ($121>>>0)>($123>>>0);
          if ($124) {
           $125 = $122 << 1;
           $126 = ($125|0)==(0);
           $127 = $126 ? 1 : $125;
           $128 = ($123>>>0)<($127>>>0);
           do {
            if ($128) {
             $129 = ($122|0)>(-1);
             if ($129) {
              HEAP32[$32>>2] = $127;
              $130 = HEAP32[$fileIDs>>2]|0;
              $131 = $127 << 3;
              $132 = HEAP32[$82>>2]|0;
              HEAP32[$0>>2] = $132;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
              $133 = (invoke_iiiiiiii(108,($130|0),($131|0),8,($$byval_copy14|0),0,(638872|0),370)|0);
              $134 = __THREW__; __THREW__ = 0;
              $135 = $134&1;
              if ($135) {
               break L34;
              }
              HEAP32[$fileIDs>>2] = $133;
              break;
             } else {
              $136 = $127 << 3;
              $137 = HEAP32[$82>>2]|0;
              HEAP32[$1>>2] = $137;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
              $138 = (invoke_iiiiiii(102,($136|0),8,($$byval_copy14|0),0,(638872|0),352)|0);
              $139 = __THREW__; __THREW__ = 0;
              $140 = $139&1;
              if ($140) {
               break L34;
              }
              $141 = HEAP32[$fileIDs>>2]|0;
              $142 = HEAP32[$81>>2]|0;
              $143 = $142 << 3;
              _memcpy(($138|0),($141|0),($143|0))|0;
              HEAP32[$32>>2] = $127;
              HEAP32[$fileIDs>>2] = $138;
              break;
             }
            }
           } while(0);
           $$pre$i$i16 = HEAP32[$81>>2]|0;
           $145 = $$pre$i$i16;
          } else {
           $145 = $121;
          }
          $144 = (($145) + -1)|0;
          $146 = HEAP32[$fileIDs>>2]|0;
          $147 = (($146) + ($144<<3)|0);
          $148 = $147;
          $149 = $148;
          HEAP32[$149>>2] = $87;
          $150 = (($148) + 4)|0;
          $151 = $150;
          HEAP32[$151>>2] = $90;
          $152 = HEAP32[$16>>2]|0;
          $153 = $it$025;
          $154 = $153;
          $155 = HEAP32[$154>>2]|0;
          $156 = (($153) + 4)|0;
          $157 = $156;
          $158 = HEAP32[$157>>2]|0;
          __THREW__ = 0;
          $159 = (invoke_iiii(1560,($152|0),($155|0),($158|0))|0);
          $160 = __THREW__; __THREW__ = 0;
          $161 = $160&1;
          if ($161) {
           break;
          }
          $162 = HEAP32[$83>>2]|0;
          $163 = (($162) + 1)|0;
          HEAP32[$83>>2] = $163;
          $164 = HEAP32[$55>>2]|0;
          $165 = $164 & 2147483647;
          $166 = ($163>>>0)>($165>>>0);
          if ($166) {
           $167 = $164 << 1;
           $168 = ($167|0)==(0);
           $169 = $168 ? 1 : $167;
           $170 = ($165>>>0)<($169>>>0);
           do {
            if ($170) {
             $171 = ($164|0)>(-1);
             if ($171) {
              HEAP32[$55>>2] = $169;
              $172 = HEAP32[$classIDs>>2]|0;
              $173 = $169 << 2;
              $174 = HEAP32[$84>>2]|0;
              HEAP32[$3>>2] = $174;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
              $175 = (invoke_iiiiiiii(108,($172|0),($173|0),4,($$byval_copy14|0),0,(638872|0),370)|0);
              $176 = __THREW__; __THREW__ = 0;
              $177 = $176&1;
              if ($177) {
               break L34;
              }
              HEAP32[$classIDs>>2] = $175;
              break;
             } else {
              $178 = $169 << 2;
              $179 = HEAP32[$84>>2]|0;
              HEAP32[$4>>2] = $179;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$4+0>>2]|0;
              $180 = (invoke_iiiiiii(102,($178|0),4,($$byval_copy14|0),0,(638872|0),352)|0);
              $181 = __THREW__; __THREW__ = 0;
              $182 = $181&1;
              if ($182) {
               break L34;
              }
              $183 = HEAP32[$classIDs>>2]|0;
              $184 = HEAP32[$83>>2]|0;
              $185 = $184 << 2;
              _memcpy(($180|0),($183|0),($185|0))|0;
              HEAP32[$55>>2] = $169;
              HEAP32[$classIDs>>2] = $180;
              break;
             }
            }
           } while(0);
           $$pre$i$i = HEAP32[$83>>2]|0;
           $187 = $$pre$i$i;
          } else {
           $187 = $163;
          }
          $186 = (($187) + -1)|0;
          $188 = HEAP32[$classIDs>>2]|0;
          $189 = (($188) + ($186<<2)|0);
          HEAP32[$189>>2] = $159;
          $$pre = HEAP32[$sourceFileIDs>>2]|0;
          $$pre29 = HEAP32[$26>>2]|0;
          $192 = $$pre;$193 = $$pre29;
         }
         $190 = (($it$025) + 8|0);
         $191 = (($192) + ($193<<3)|0);
         $194 = ($190|0)==($191|0);
         if ($194) {
          $$lcssa = $192;
          break L32;
         } else {
          $202 = $193;$203 = $192;$it$025 = $190;
         }
        }
        $110 = ___cxa_find_matching_catch()|0;
        $111 = tempRet0;
        $lpad$phi$index = $110;$lpad$phi$index2 = $111;
        break L13;
       }
      } while(0);
      $195 = HEAP32[$27>>2]|0;
      $196 = ($195|0)>(-1);
      if (!($196)) {
       STACKTOP = sp;return;
      }
      $197 = HEAP32[$25>>2]|0;
      HEAP32[$2>>2] = $197;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($$lcssa|0),($$byval_copy14|0));
      $198 = __THREW__; __THREW__ = 0;
      $199 = $198&1;
      if ($199) {
       break L1;
      }
      HEAP32[$sourceFileIDs>>2] = 0;
      STACKTOP = sp;return;
     }
    } while(0);
    if ((label|0) == 29) {
     $112 = ___cxa_find_matching_catch()|0;
     $113 = tempRet0;
     $lpad$phi$index = $112;$lpad$phi$index2 = $113;
    }
    $114 = HEAP32[$27>>2]|0;
    $115 = ($114|0)>(-1);
    if (!($115)) {
     $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
     ___resumeException($$01|0);
     // unreachable;
    }
    $116 = HEAP32[$sourceFileIDs>>2]|0;
    $117 = HEAP32[$25>>2]|0;
    HEAP32[$2>>2] = $117;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($116|0),($$byval_copy14|0));
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     $200 = ___cxa_find_matching_catch(0|0)|0;
     $201 = tempRet0;
     ___clang_call_terminate($200);
     // unreachable;
    }
    HEAP32[$sourceFileIDs>>2] = 0;
    $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $$0 = $23;$$01 = $22;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN17PersistentManager22MakeObjectUnpersistentEi13UnpersistMode($this,$memoryID,$mode) {
 $this = $this|0;
 $memoryID = $memoryID|0;
 $mode = $mode|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 HEAP32[$0>>2] = $memoryID;
 $1 = HEAP32[560624>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0$i1 = 0;$39 = 0;
 } else {
  $3 = (($1) + 36|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  do {
   if ($7) {
    $8 = (($1) + 28|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($1) + 32|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($9) + ($11<<3)|0);
    $28 = $12;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$1,$0);
    $13 = HEAP32[$pos$i$i$i>>2]|0;
    $14 = ($13|0)==(-1);
    $15 = (($1) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    if ($14) {
     $17 = (($1) + 32|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($16) + ($18<<3)|0);
     $28 = $19;
     break;
    } else {
     $20 = (($16) + ($13<<3)|0);
     $28 = $20;
     break;
    }
   }
  } while(0);
  $21 = HEAP32[560624>>2]|0;
  $22 = (($21) + 28|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21) + 32|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + ($25<<3)|0);
  $27 = ($28|0)==($26|0);
  if ($27) {
   $$0$i1 = 0;$39 = 0;
  } else {
   $29 = (($28) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $$0$i1 = 0;$39 = 0;
   } else {
    $32 = (($30) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = $33 & 1048576;
    $35 = ($34|0)==(0);
    if ($35) {
     STACKTOP = sp;return;
    } else {
     $$0$i1 = $30;$39 = 1;
    }
   }
  }
 }
 $36 = ($mode|0)==(1);
 if ($36) {
  __ZN17PersistentManager23DestroyFromFileInternalEi($this,$memoryID);
 }
 $37 = (($this) + 44|0);
 $38 = HEAP32[$37>>2]|0;
 __ZN8Remapper6RemoveEi($38,$memoryID);
 if (!($39)) {
  STACKTOP = sp;return;
 }
 __ZN6Object15SetIsPersistentEb($$0$i1,0);
 STACKTOP = sp;return;
}
function __ZN17PersistentManager23DestroyFromFileInternalEi($this,$memoryID) {
 $this = $this|0;
 $memoryID = $memoryID|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy2 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(-1);
 if ($6) {
  label = 5;
 } else {
  $7 = (($3) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)>($memoryID|0);
  if ($9) {
   label = 5;
  } else {
   $10 = (($3) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)<($memoryID|0);
   if ($12) {
    label = 5;
   } else {
    $13 = (($memoryID) - ($8))|0;
    $14 = (($13|0) / 2)&-1;
    $15 = ($14|0)<(0);
    $16 = $15 << 31 >> 31;
    $43 = $5;$86 = $14;$89 = $16;
   }
  }
 }
 do {
  if ((label|0) == 5) {
   $17 = (($3) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($3) + 16|0);
   $20 = ($18|0)==(0|0);
   if ($20) {
    STACKTOP = sp;return;
   } else {
    $$0$ph7$i$i$i$i = $19;$$01$ph6$i$in$i$i$i = $18;
   }
   L9: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $21 = (($$013$i$in$i$i$i) + 16|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)<($memoryID|0);
     if (!($23)) {
      break;
     }
     $26 = (($$013$i$in$i$i$i) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==(0|0);
     if ($28) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L9;
     } else {
      $$013$i$in$i$i$i = $27;
     }
    }
    $24 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $25 = ($24|0)==(0|0);
    if ($25) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $24;
    }
   }
   $29 = ($$0$ph5$i$i$i$i|0)==($19|0);
   if ($29) {
    STACKTOP = sp;return;
   }
   $30 = (($$0$ph5$i$i$i$i) + 16|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)>($memoryID|0);
   if ($32) {
    STACKTOP = sp;return;
   } else {
    $33 = (($$0$ph5$i$i$i$i) + 24|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($$0$ph5$i$i$i$i) + 32|0);
    $36 = $35;
    $37 = $36;
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 4)|0;
    $40 = $39;
    $41 = HEAP32[$40>>2]|0;
    $43 = $34;$86 = $38;$89 = $41;
    break;
   }
  }
 } while(0);
 $42 = ($43|0)==(-1);
 if ($42) {
  STACKTOP = sp;return;
 }
 $44 = (__ZN17PersistentManager26GetStreamNameSpaceInternalEi($this,$43)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = (($44) + 16|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  $50 = HEAP32[628360>>2]|0;
  HEAP32[$1>>2] = $50;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $51 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy2,1,16,638872,73)|0);
  HEAP32[$51>>2] = 0;
  $52 = (($51) + 8|0);
  HEAP32[$52>>2] = 0;
  $53 = (($51) + 12|0);
  HEAP32[$53>>2] = 0;
  $54 = (($51) + 4|0);
  HEAP32[$54>>2] = 61;
  HEAP32[$47>>2] = $51;
  $56 = $51;
 } else {
  $56 = $48;
 }
 $55 = (($56) + 8|0);
 $57 = HEAP32[$55>>2]|0;
 $58 = (($57) + 1)|0;
 HEAP32[$55>>2] = $58;
 $59 = (($56) + 12|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $60 & 2147483647;
 $62 = ($58>>>0)>($61>>>0);
 if ($62) {
  $63 = $60 << 1;
  $64 = ($63|0)==(0);
  $65 = $64 ? 1 : $63;
  $66 = ($61>>>0)<($65>>>0);
  do {
   if ($66) {
    $67 = ($60|0)>(-1);
    if ($67) {
     HEAP32[$59>>2] = $65;
     $68 = HEAP32[$56>>2]|0;
     $69 = $65 << 3;
     $70 = (($56) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     HEAP32[$0>>2] = $71;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $72 = (__Z16realloc_internalPvji10MemLabelIdiPKci($68,$69,8,$$byval_copy2,0,638872,370)|0);
     HEAP32[$56>>2] = $72;
     break;
    } else {
     $73 = $65 << 3;
     $74 = (($56) + 4|0);
     $75 = HEAP32[$74>>2]|0;
     HEAP32[$0>>2] = $75;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $76 = (__Z15malloc_internaljj10MemLabelIdiPKci($73,8,$$byval_copy2,0,638872,352)|0);
     $77 = HEAP32[$56>>2]|0;
     $78 = HEAP32[$55>>2]|0;
     $79 = $78 << 3;
     _memcpy(($76|0),($77|0),($79|0))|0;
     HEAP32[$59>>2] = $65;
     HEAP32[$56>>2] = $76;
     break;
    }
   }
  } while(0);
  $$pre$i$i$i = HEAP32[$55>>2]|0;
  $81 = $$pre$i$i$i;
 } else {
  $81 = $58;
 }
 $80 = (($81) + -1)|0;
 $82 = HEAP32[$56>>2]|0;
 $83 = (($82) + ($80<<3)|0);
 $84 = $83;
 $85 = $84;
 HEAP32[$85>>2] = $86;
 $87 = (($84) + 4)|0;
 $88 = $87;
 HEAP32[$88>>2] = $89;
 STACKTOP = sp;return;
}
function __ZN8Remapper6RemoveEi($this,$memoryID) {
 $this = $this|0;
 $memoryID = $memoryID|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i7 = 0, $$0$i$i$i$i11 = 0, $$0$ph5$i$i$i = 0, $$0$ph6$i$i$i = 0, $$0$ph7$i$i$i = 0, $$0$ph8$i$i$i = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i9 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph7$i$in$i$i = 0, $$013$i$in$i$i = 0, $$014$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = ($1|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $$0$ph7$i$i$i = $2;$$01$ph6$i$in$i$i = $1;
 }
 L3: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $4 = (($$013$i$in$i$i) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)<($memoryID|0);
   if (!($6)) {
    break;
   }
   $9 = (($$013$i$in$i$i) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L3;
   } else {
    $$013$i$in$i$i = $10;
   }
  }
  $7 = HEAP32[$$013$i$in$i$i>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $7;
  }
 }
 $12 = ($$0$ph5$i$i$i|0)==($2|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($$0$ph5$i$i$i) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>($memoryID|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 4|0);
 $19 = ($17|0)==(0|0);
 if ($19) {
  label = 20;
 } else {
  $20 = (($$0$ph5$i$i$i) + 24|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($$0$ph5$i$i$i) + 32|0);
  $$0$ph8$i$i$i = $18;$$01$ph7$i$in$i$i = $17;
  L18: while(1) {
   $$014$i$in$i$i = $$01$ph7$i$in$i$i;
   while(1) {
    $23 = (($$014$i$in$i$i) + 16|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)<($21|0);
    if (!($25)) {
     $26 = ($24|0)>($21|0);
     if ($26) {
      break;
     }
     $27 = (($$014$i$in$i$i) + 24|0);
     $28 = $27;
     $29 = $28;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + 4)|0;
     $32 = $31;
     $33 = HEAP32[$32>>2]|0;
     $34 = $22;
     $35 = $34;
     $36 = HEAP32[$35>>2]|0;
     $37 = (($34) + 4)|0;
     $38 = $37;
     $39 = HEAP32[$38>>2]|0;
     $40 = ($33|0)<($39|0);
     $41 = ($33|0)==($39|0);
     $42 = ($30>>>0)<($36>>>0);
     $43 = $41 & $42;
     $44 = $40 | $43;
     if (!($44)) {
      break;
     }
    }
    $47 = (($$014$i$in$i$i) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     $$0$ph6$i$i$i = $$0$ph8$i$i$i;
     break L18;
    } else {
     $$014$i$in$i$i = $48;
    }
   }
   $45 = HEAP32[$$014$i$in$i$i>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $$0$ph6$i$i$i = $$014$i$in$i$i;
    break;
   } else {
    $$0$ph8$i$i$i = $$014$i$in$i$i;$$01$ph7$i$in$i$i = $45;
   }
  }
  $50 = ($$0$ph6$i$i$i|0)==($18|0);
  if ($50) {
   label = 20;
  } else {
   $51 = (($$0$ph6$i$i$i) + 16|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($21|0)<($52|0);
   if ($53) {
    label = 20;
   } else {
    $54 = ($21|0)>($52|0);
    if ($54) {
     $89 = $$0$ph6$i$i$i;
    } else {
     $55 = $22;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = (($55) + 4)|0;
     $59 = $58;
     $60 = HEAP32[$59>>2]|0;
     $61 = (($$0$ph6$i$i$i) + 24|0);
     $62 = $61;
     $63 = $62;
     $64 = HEAP32[$63>>2]|0;
     $65 = (($62) + 4)|0;
     $66 = $65;
     $67 = HEAP32[$66>>2]|0;
     $68 = ($60|0)<($67|0);
     $69 = ($60|0)==($67|0);
     $70 = ($57>>>0)<($64>>>0);
     $71 = $69 & $70;
     $72 = $68 | $71;
     if ($72) {
      label = 20;
     } else {
      $89 = $$0$ph6$i$i$i;
     }
    }
   }
  }
 }
 if ((label|0) == 20) {
  $89 = $18;
 }
 $73 = (($$0$ph5$i$i$i) + 4|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$01$i$i$i$i9 = $$0$ph5$i$i$i;
  while(1) {
   $78 = (($$01$i$i$i$i9) + 8|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==($$01$i$i$i$i9|0);
   if ($81) {
    $$0$i$i$i$i11 = $79;
    break;
   } else {
    $$01$i$i$i$i9 = $79;
   }
  }
 } else {
  $$0$i$i$i$i$i7 = $74;
  while(1) {
   $76 = HEAP32[$$0$i$i$i$i$i7>>2]|0;
   $77 = ($76|0)==(0|0);
   if ($77) {
    $$0$i$i$i$i11 = $$0$i$i$i$i$i7;
    break;
   } else {
    $$0$i$i$i$i$i7 = $76;
   }
  }
 }
 $82 = (($this) + 12|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($83|0)==($$0$ph5$i$i$i|0);
 if ($84) {
  HEAP32[$82>>2] = $$0$i$i$i$i11;
 }
 $85 = (($this) + 20|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + -1)|0;
 HEAP32[$85>>2] = $87;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($1,$$0$ph5$i$i$i);
 __ZdlPv($$0$ph5$i$i$i);
 $88 = (($89) + 4|0);
 $90 = HEAP32[$88>>2]|0;
 $91 = ($90|0)==(0|0);
 if ($91) {
  $$01$i$i$i$i = $89;
  while(1) {
   $94 = (($$01$i$i$i$i) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==($$01$i$i$i$i|0);
   if ($97) {
    $$0$i$i$i$i = $95;
    break;
   } else {
    $$01$i$i$i$i = $95;
   }
  }
 } else {
  $$0$i$i$i$i$i = $90;
  while(1) {
   $92 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $93 = ($92|0)==(0|0);
   if ($93) {
    $$0$i$i$i$i = $$0$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i = $92;
   }
  }
 }
 $98 = HEAP32[$this>>2]|0;
 $99 = ($98|0)==($89|0);
 if ($99) {
  HEAP32[$this>>2] = $$0$i$i$i$i;
 }
 $100 = (($this) + 8|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = (($101) + -1)|0;
 HEAP32[$100>>2] = $102;
 $103 = HEAP32[$16>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($103,$89);
 __ZdlPv($89);
 STACKTOP = sp;return;
}
function __ZN17PersistentManager51LocalSerializedObjectIdentifierToInstanceIDInternalERK31LocalSerializedObjectIdentifierRi($this,$localIdentifier,$outInstanceID) {
 $this = $this|0;
 $localIdentifier = $localIdentifier|0;
 $outInstanceID = $outInstanceID|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN17PersistentManager51LocalSerializedObjectIdentifierToInstanceIDInternalEiRK31LocalSerializedObjectIdentifierRi($this,$1,$localIdentifier,$outInstanceID);
 STACKTOP = sp;return;
}
function __ZN17PersistentManager51LocalSerializedObjectIdentifierToInstanceIDInternalEiRK31LocalSerializedObjectIdentifierRi($this,$activeNameSpace,$localIdentifier,$outInstanceID) {
 $this = $this|0;
 $activeNameSpace = $activeNameSpace|0;
 $localIdentifier = $localIdentifier|0;
 $outInstanceID = $outInstanceID|0;
 var $$ = 0, $$0$i = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $globalFileIndex$0 = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = (($localIdentifier) + 8|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$localIdentifier>>2]|0;
 $10 = ($5|0)==(0);
 $11 = ($8|0)==(0);
 $12 = $10 & $11;
 if ($12) {
  HEAP32[$outInstanceID>>2] = 0;
  STACKTOP = sp;return;
 }
 $13 = ($9|0)==(0);
 do {
  if ($13) {
   $globalFileIndex$0 = $activeNameSpace;
  } else {
   $14 = (($this) + 32|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($15) + ($activeNameSpace<<4)|0) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($15) + ($activeNameSpace<<4)|0) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = $19;
   $21 = $17;
   $22 = (($20) - ($21))|0;
   $23 = $22 >> 3;
   $24 = ($23|0)==(0);
   if ($24) {
    $34 = $17;
   } else {
    $27 = $17;$__len$03$i$i$i$i$i = $23;
    while(1) {
     $25 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
     $26 = (($27) + ($25<<3)|0);
     $28 = HEAP32[$26>>2]|0;
     $29 = ($28|0)<($9|0);
     if ($29) {
      $$sum$i$i$i$i$i = (($25) + 1)|0;
      $30 = (($27) + ($$sum$i$i$i$i$i<<3)|0);
      $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
      $31 = (($$neg2$i$i$i$i$i) - ($25))|0;
      $80 = $30;$__len$0$be$i$i$i$i$i = $31;
     } else {
      $80 = $27;$__len$0$be$i$i$i$i$i = $25;
     }
     $32 = ($__len$0$be$i$i$i$i$i|0)==(0);
     if ($32) {
      $34 = $80;
      break;
     } else {
      $27 = $80;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
     }
    }
   }
   $33 = ($34|0)==($19|0);
   if (!($33)) {
    $35 = HEAP32[$34>>2]|0;
    $36 = ($9|0)<($35|0);
    $$ = $36 ? $19 : $34;
    $37 = ($$|0)==($19|0);
    if (!($37)) {
     $38 = (($$) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $globalFileIndex$0 = $39;
     break;
    }
   }
   HEAP32[$outInstanceID>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $40 = (($this) + 44|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($globalFileIndex$0|0)==(-1);
 if ($42) {
  HEAP32[$outInstanceID>>2] = 0;
  STACKTOP = sp;return;
 }
 $43 = (($41) + 36|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)!=(-1);
 $46 = ($44|0)==($globalFileIndex$0|0);
 $or$cond$i = $45 & $46;
 do {
  if ($or$cond$i) {
   $47 = (_bitshift64Shl(($5|0),($8|0),1)|0);
   $48 = tempRet0;
   $49 = (($41) + 28|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (_i64Add(($50|0),0,($47|0),($48|0))|0);
   $52 = tempRet0;
   $$0$i = $51;
  } else {
   HEAP32[$1>>2] = $globalFileIndex$0;
   $53 = (($1) + 8|0);
   $54 = $53;
   $55 = $54;
   HEAP32[$55>>2] = $5;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $8;
   $58 = (($1) + 16|0);
   HEAP32[$58>>2] = 0;
   __ZNSt3__16__treeINS_12__value_typeI26SerializedObjectIdentifieriEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_($0,$41,$1);
   $59 = HEAP32[$0>>2]|0;
   $60 = (($0) + 4|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = ($61<<24>>24)==(0);
   if ($62) {
    $74 = (($59) + 32|0);
    $75 = HEAP32[$74>>2]|0;
    $$0$i = $75;
    break;
   } else {
    $63 = (($41) + 24|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($64) + 2)|0;
    HEAP32[$63>>2] = $65;
    $66 = (($59) + 32|0);
    HEAP32[$66>>2] = $65;
    $67 = (($41) + 12|0);
    HEAP32[$1>>2] = $65;
    $68 = (($1) + 8|0);
    HEAP32[$68>>2] = $globalFileIndex$0;
    $69 = (($1) + 16|0);
    $70 = $69;
    $71 = $70;
    HEAP32[$71>>2] = $5;
    $72 = (($70) + 4)|0;
    $73 = $72;
    HEAP32[$73>>2] = $8;
    __ZNSt3__16__treeINS_12__value_typeIi26SerializedObjectIdentifierEENS_19__map_value_compareIiS3_NS_4lessIiEELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_($0,$67,$1);
    $$0$i = $65;
    break;
   }
  }
 } while(0);
 HEAP32[$outInstanceID>>2] = $$0$i;
 $76 = (($this) + 95|0);
 $77 = HEAP8[$76>>0]|0;
 $78 = ($77<<24>>24)==(0);
 $79 = ($$0$i|0)==(0);
 $or$cond = $78 | $79;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 (__Z38PreallocateObjectFromPersistentManagerib($$0$i,1)|0);
 STACKTOP = sp;return;
}
function __ZN17PersistentManager40GlobalToLocalSerializedFileIndexInternalERK26SerializedObjectIdentifier($agg$result,$this,$globalIdentifier) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $globalIdentifier = $globalIdentifier|0;
 var $$ = 0, $$byval_copy3 = 0, $$neg2$i$i$i$i$i = 0, $$neg2$i$i$i$i$i12 = 0, $$neg2$i$i$i$i$i5 = 0, $$pn$i$i = 0, $$pn$i$i18 = 0, $$pre$i$i16 = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i11 = 0, $$sum$i$i$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i13 = 0, $__len$0$be$i$i$i$i$i6 = 0, $__len$03$i$i$i$i$i = 0, $__len$03$i$i$i$i$i10 = 0, $__len$03$i$i$i$i$i3 = 0, $fileIdentifier = 0, $storemerge$i$i = 0;
 var $storemerge$i$i19 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy3 = sp + 68|0;
 $0 = sp + 64|0;
 $1 = sp + 56|0;
 $2 = sp + 52|0;
 $3 = sp + 48|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $fileIdentifier = sp + 16|0;
 $7 = (($globalIdentifier) + 8|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 72|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($17) + ($15<<4)|0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($17) + ($15<<4)|0) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23;
 $25 = $21;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 3;
 $28 = ($27|0)==(0);
 if ($28) {
  $39 = $21;
 } else {
  $29 = HEAP32[$globalIdentifier>>2]|0;
  $32 = $21;$__len$03$i$i$i$i$i = $27;
  while(1) {
   $30 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $31 = (($32) + ($30<<3)|0);
   $33 = HEAP32[$31>>2]|0;
   $34 = ($33|0)<($29|0);
   if ($34) {
    $$sum$i$i$i$i$i = (($30) + 1)|0;
    $35 = (($32) + ($$sum$i$i$i$i$i<<3)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $36 = (($$neg2$i$i$i$i$i) - ($30))|0;
    $138 = $35;$__len$0$be$i$i$i$i$i = $36;
   } else {
    $138 = $32;$__len$0$be$i$i$i$i$i = $30;
   }
   $37 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($37) {
    $39 = $138;
    break;
   } else {
    $32 = $138;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $38 = ($39|0)==($23|0);
 if (!($38)) {
  $40 = HEAP32[$globalIdentifier>>2]|0;
  $41 = HEAP32[$39>>2]|0;
  $42 = ($40|0)<($41|0);
  $$ = $42 ? $23 : $39;
  $43 = ($$|0)==($23|0);
  if (!($43)) {
   $130 = (($$) + 4|0);
   $131 = HEAP32[$130>>2]|0;
   $133 = $131;
   $132 = (($agg$result) + 8|0);
   HEAP32[$agg$result>>2] = $133;
   $134 = $132;
   $135 = $134;
   HEAP32[$135>>2] = $10;
   $136 = (($134) + 4)|0;
   $137 = $136;
   HEAP32[$137>>2] = $13;
   STACKTOP = sp;return;
  }
 }
 $44 = (($this) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + (($15*24)|0)|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$this>>2]|0;
 $49 = (($48) + 20|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$globalIdentifier>>2]|0;
 FUNCTION_TABLE_viii[$50 & 4095]($fileIdentifier,$this,$51);
 __THREW__ = 0;
 invoke_vii(3218,($47|0),($fileIdentifier|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 do {
  if (!($53)) {
   $54 = (($47) + 84|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = HEAP32[$20>>2]|0;
   $57 = HEAP32[$22>>2]|0;
   $58 = $57;
   $59 = $56;
   $60 = (($58) - ($59))|0;
   $61 = $60 >> 3;
   $62 = ($61|0)==(0);
   if ($62) {
    $73 = $56;
   } else {
    $63 = HEAP32[$globalIdentifier>>2]|0;
    $66 = $56;$__len$03$i$i$i$i$i10 = $61;
    while(1) {
     $64 = (($__len$03$i$i$i$i$i10|0) / 2)&-1;
     $65 = (($66) + ($64<<3)|0);
     $67 = HEAP32[$65>>2]|0;
     $68 = ($67|0)<($63|0);
     if ($68) {
      $$sum$i$i$i$i$i11 = (($64) + 1)|0;
      $69 = (($66) + ($$sum$i$i$i$i$i11<<3)|0);
      $$neg2$i$i$i$i$i12 = (($__len$03$i$i$i$i$i10) + -1)|0;
      $70 = (($$neg2$i$i$i$i$i12) - ($64))|0;
      $139 = $69;$__len$0$be$i$i$i$i$i13 = $70;
     } else {
      $139 = $66;$__len$0$be$i$i$i$i$i13 = $64;
     }
     $71 = ($__len$0$be$i$i$i$i$i13|0)==(0);
     if ($71) {
      $73 = $139;
      break;
     } else {
      $66 = $139;$__len$03$i$i$i$i$i10 = $__len$0$be$i$i$i$i$i13;
     }
    }
   }
   $72 = ($73|0)==($57|0);
   if ($72) {
    $$pre$i$i16 = HEAP32[$globalIdentifier>>2]|0;
    $78 = $$pre$i$i16;
    label = 17;
   } else {
    $74 = HEAP32[$globalIdentifier>>2]|0;
    $75 = HEAP32[$73>>2]|0;
    $76 = ($74|0)<($75|0);
    if ($76) {
     $78 = $74;
     label = 17;
    } else {
     $$pn$i$i18 = $73;
    }
   }
   if ((label|0) == 17) {
    $77 = ((($17) + ($15<<4)|0) + 4|0);
    HEAP32[$0>>2] = $73;
    HEAP32[$1>>2] = $78;
    $79 = (($1) + 4|0);
    HEAP32[$79>>2] = 0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viiii(398,($2|0),($77|0),($$byval_copy3|0),($1|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     break;
    }
    $82 = HEAP32[$2>>2]|0;
    $$pn$i$i18 = $82;
   }
   $storemerge$i$i19 = (($$pn$i$i18) + 4|0);
   HEAP32[$storemerge$i$i19>>2] = $55;
   $83 = HEAP32[$globalIdentifier>>2]|0;
   $84 = ((($19) + ($15<<4)|0) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ((($19) + ($15<<4)|0) + 8|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = $87;
   $89 = $85;
   $90 = (($88) - ($89))|0;
   $91 = $90 >> 3;
   $92 = ($91|0)==(0);
   if ($92) {
    $102 = $85;
   } else {
    $95 = $85;$__len$03$i$i$i$i$i3 = $91;
    while(1) {
     $93 = (($__len$03$i$i$i$i$i3|0) / 2)&-1;
     $94 = (($95) + ($93<<3)|0);
     $96 = HEAP32[$94>>2]|0;
     $97 = ($96|0)<($55|0);
     if ($97) {
      $$sum$i$i$i$i$i4 = (($93) + 1)|0;
      $98 = (($95) + ($$sum$i$i$i$i$i4<<3)|0);
      $$neg2$i$i$i$i$i5 = (($__len$03$i$i$i$i$i3) + -1)|0;
      $99 = (($$neg2$i$i$i$i$i5) - ($93))|0;
      $140 = $98;$__len$0$be$i$i$i$i$i6 = $99;
     } else {
      $140 = $95;$__len$0$be$i$i$i$i$i6 = $93;
     }
     $100 = ($__len$0$be$i$i$i$i$i6|0)==(0);
     if ($100) {
      $102 = $140;
      break;
     } else {
      $95 = $140;$__len$03$i$i$i$i$i3 = $__len$0$be$i$i$i$i$i6;
     }
    }
   }
   $101 = ($102|0)==($87|0);
   if ($101) {
    label = 25;
   } else {
    $103 = HEAP32[$102>>2]|0;
    $104 = ($55|0)<($103|0);
    if ($104) {
     label = 25;
    } else {
     $$pn$i$i = $102;
    }
   }
   if ((label|0) == 25) {
    $105 = ((($19) + ($15<<4)|0) + 4|0);
    HEAP32[$3>>2] = $102;
    HEAP32[$4>>2] = $55;
    $106 = (($4) + 4|0);
    HEAP32[$106>>2] = 0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_viiii(398,($5|0),($105|0),($$byval_copy3|0),($4|0));
    $107 = __THREW__; __THREW__ = 0;
    $108 = $107&1;
    if ($108) {
     break;
    }
    $109 = HEAP32[$5>>2]|0;
    $$pn$i$i = $109;
   }
   $storemerge$i$i = (($$pn$i$i) + 4|0);
   HEAP32[$storemerge$i$i>>2] = $83;
   $110 = HEAP8[$fileIdentifier>>0]|0;
   $111 = $110 & 1;
   $112 = ($111<<24>>24)==(0);
   if ($112) {
    $133 = $55;
    $132 = (($agg$result) + 8|0);
    HEAP32[$agg$result>>2] = $133;
    $134 = $132;
    $135 = $134;
    HEAP32[$135>>2] = $10;
    $136 = (($134) + 4)|0;
    $137 = $136;
    HEAP32[$137>>2] = $13;
    STACKTOP = sp;return;
   }
   $113 = (($fileIdentifier) + 8|0);
   $114 = HEAP32[$113>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($114|0),($$byval_copy3|0));
   $115 = __THREW__; __THREW__ = 0;
   $116 = $115&1;
   if ($116) {
    $117 = ___cxa_find_matching_catch()|0;
    $118 = tempRet0;
    ___cxa_call_unexpected(($117|0));
    // unreachable;
   } else {
    $133 = $55;
    $132 = (($agg$result) + 8|0);
    HEAP32[$agg$result>>2] = $133;
    $134 = $132;
    $135 = $134;
    HEAP32[$135>>2] = $10;
    $136 = (($134) + 4)|0;
    $137 = $136;
    HEAP32[$137>>2] = $13;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $119 = ___cxa_find_matching_catch()|0;
 $120 = tempRet0;
 $121 = HEAP8[$fileIdentifier>>0]|0;
 $122 = $121 & 1;
 $123 = ($122<<24>>24)==(0);
 if ($123) {
  ___resumeException($119|0);
  // unreachable;
 }
 $124 = (($fileIdentifier) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 HEAP32[$6>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_vii(2591,($125|0),($$byval_copy3|0));
 $126 = __THREW__; __THREW__ = 0;
 $127 = $126&1;
 if ($127) {
  $128 = ___cxa_find_matching_catch()|0;
  $129 = tempRet0;
  ___cxa_call_unexpected(($128|0));
  // unreachable;
 } else {
  ___resumeException($119|0);
  // unreachable;
 }
}
function __ZN17PersistentManager51InstanceIDToLocalSerializedObjectIdentifierInternalEiR31LocalSerializedObjectIdentifier($this,$instanceID,$localIdentifier) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 $localIdentifier = $localIdentifier|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $globalIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $globalIdentifier = sp + 16|0;
 $0 = sp;
 $1 = ($instanceID|0)==(0);
 if ($1) {
  HEAP32[$localIdentifier>>2] = 0;
  $2 = (($localIdentifier) + 8|0);
  $3 = $2;
  $4 = $3;
  HEAP32[$4>>2] = 0;
  $5 = (($3) + 4)|0;
  $6 = $5;
  HEAP32[$6>>2] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$globalIdentifier>>2] = 0;
 $7 = (($globalIdentifier) + 8|0);
 $8 = $7;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 36|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(-1);
 if ($16) {
  label = 7;
 } else {
  $17 = (($13) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)>($instanceID|0);
  if ($19) {
   label = 7;
  } else {
   $20 = (($13) + 32|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)<($instanceID|0);
   if ($22) {
    label = 7;
   } else {
    HEAP32[$globalIdentifier>>2] = $15;
    $23 = (($instanceID) - ($18))|0;
    $24 = (($23|0) / 2)&-1;
    $25 = ($24|0)<(0);
    $26 = $25 << 31 >> 31;
    $27 = $7;
    $28 = $27;
    HEAP32[$28>>2] = $24;
    $29 = (($27) + 4)|0;
    $30 = $29;
    HEAP32[$30>>2] = $26;
   }
  }
 }
 do {
  if ((label|0) == 7) {
   $31 = (($13) + 16|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($13) + 16|0);
   $34 = ($32|0)==(0|0);
   if (!($34)) {
    $$0$ph7$i$i$i$i = $33;$$01$ph6$i$in$i$i$i = $32;
    L12: while(1) {
     $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
     while(1) {
      $35 = (($$013$i$in$i$i$i) + 16|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($36|0)<($instanceID|0);
      if (!($37)) {
       break;
      }
      $40 = (($$013$i$in$i$i$i) + 4|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41|0)==(0|0);
      if ($42) {
       $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
       break L12;
      } else {
       $$013$i$in$i$i$i = $41;
      }
     }
     $38 = HEAP32[$$013$i$in$i$i$i>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
      break;
     } else {
      $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $38;
     }
    }
    $43 = ($$0$ph5$i$i$i$i|0)==($33|0);
    if (!($43)) {
     $44 = (($$0$ph5$i$i$i$i) + 16|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45|0)>($instanceID|0);
     if (!($46)) {
      $47 = (($$0$ph5$i$i$i$i) + 24|0);
      ;HEAP32[$globalIdentifier+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$globalIdentifier+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$globalIdentifier+8>>2]=HEAP32[$47+8>>2]|0;HEAP32[$globalIdentifier+12>>2]=HEAP32[$47+12>>2]|0;
      break;
     }
    }
   }
   HEAP32[$globalIdentifier>>2] = -1;
   $48 = $7;
   $49 = $48;
   HEAP32[$49>>2] = 0;
   $50 = (($48) + 4)|0;
   $51 = $50;
   HEAP32[$51>>2] = 0;
   HEAP32[$localIdentifier>>2] = 0;
   $52 = (($localIdentifier) + 8|0);
   $53 = $52;
   $54 = $53;
   HEAP32[$54>>2] = 0;
   $55 = (($53) + 4)|0;
   $56 = $55;
   HEAP32[$56>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 __ZN17PersistentManager40GlobalToLocalSerializedFileIndexInternalERK26SerializedObjectIdentifier($0,$this,$globalIdentifier);
 ;HEAP32[$localIdentifier+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$localIdentifier+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$localIdentifier+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$localIdentifier+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN17PersistentManager27IntegrateAllThreadedObjectsEv($this) {
 $this = $this|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $awakeQueue = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy4 = sp + 140|0;
 $0 = sp;
 $1 = sp + 4|0;
 $awakeQueue = sp + 8|0;
 $2 = sp + 136|0;
 $3 = HEAP32[628512>>2]|0;
 HEAP32[$2>>2] = $3;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN18AwakeFromLoadQueueC2E10MemLabelId($awakeQueue,$$byval_copy4);
 __THREW__ = 0;
 invoke_vii(3219,($this|0),($awakeQueue|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  invoke_vi(3561,($awakeQueue|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(3546,($awakeQueue|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($awakeQueue) + 128|0);
    $12 = $10;
    while(1) {
     $11 = (($12) + -16|0);
     $13 = (($12) + -4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)>(-1);
     if ($15) {
      $16 = HEAP32[$11>>2]|0;
      $17 = (($12) + -12|0);
      $18 = HEAP32[$17>>2]|0;
      HEAP32[$1>>2] = $18;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($16|0),($$byval_copy4|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      HEAP32[$11>>2] = 0;
     }
     $21 = ($11|0)==($awakeQueue|0);
     if ($21) {
      label = 17;
      break;
     } else {
      $12 = $11;
     }
    }
    if ((label|0) == 17) {
     STACKTOP = sp;return;
    }
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $24 = ($awakeQueue|0)==($11|0);
    if ($24) {
     ___resumeException($22|0);
     // unreachable;
    }
    $26 = $11;
    while(1) {
     $25 = (($26) + -16|0);
     $27 = (($26) + -4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)>(-1);
     if ($29) {
      $30 = HEAP32[$25>>2]|0;
      $31 = (($26) + -12|0);
      $32 = HEAP32[$31>>2]|0;
      HEAP32[$0>>2] = $32;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($30|0),($$byval_copy4|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 16;
       break;
      }
      HEAP32[$25>>2] = 0;
     }
     $35 = ($25|0)==($awakeQueue|0);
     if ($35) {
      label = 15;
      break;
     } else {
      $26 = $25;
     }
    }
    if ((label|0) == 15) {
     ___resumeException($22|0);
     // unreachable;
    }
    else if ((label|0) == 16) {
     $36 = ___cxa_find_matching_catch(0|0)|0;
     $37 = tempRet0;
     ___clang_call_terminate($36);
     // unreachable;
    }
   }
  }
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 $40 = (($awakeQueue) + 128|0);
 $42 = $40;
 while(1) {
  $41 = (($42) + -16|0);
  $43 = (($42) + -4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)>(-1);
  if ($45) {
   $46 = HEAP32[$41>>2]|0;
   $47 = (($42) + -12|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$1>>2] = $48;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($46|0),($$byval_copy4|0));
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    break;
   }
   HEAP32[$41>>2] = 0;
  }
  $51 = ($41|0)==($awakeQueue|0);
  if ($51) {
   label = 30;
   break;
  } else {
   $42 = $41;
  }
 }
 if ((label|0) == 30) {
  ___resumeException($38|0);
  // unreachable;
 }
 $52 = ___cxa_find_matching_catch(0|0)|0;
 $53 = tempRet0;
 $54 = ($awakeQueue|0)==($41|0);
 if ($54) {
  ___clang_call_terminate($52);
  // unreachable;
 }
 $56 = $41;
 while(1) {
  $55 = (($56) + -16|0);
  $57 = (($56) + -4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)>(-1);
  if ($59) {
   $60 = HEAP32[$55>>2]|0;
   $61 = (($56) + -12|0);
   $62 = HEAP32[$61>>2]|0;
   HEAP32[$0>>2] = $62;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy4|0));
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    label = 29;
    break;
   }
   HEAP32[$55>>2] = 0;
  }
  $65 = ($55|0)==($awakeQueue|0);
  if ($65) {
   label = 31;
   break;
  } else {
   $56 = $55;
  }
 }
 if ((label|0) == 29) {
  $66 = ___cxa_find_matching_catch(0|0)|0;
  $67 = tempRet0;
  ___clang_call_terminate($66);
  // unreachable;
 }
 else if ((label|0) == 31) {
  ___clang_call_terminate($52);
  // unreachable;
 }
}
function __ZN17PersistentManager25ExtractAwakeFromLoadQueueER18AwakeFromLoadQueue($this,$awakeQueue) {
 $this = $this|0;
 $awakeQueue = $awakeQueue|0;
 var $$01$i$i$i$i = 0, $$ph2 = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($3))|0;
 __ZN18AwakeFromLoadQueue7ReserveEj($awakeQueue,$4);
 $5 = (($this) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 152|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + (($8*20)|0)|0);
 $10 = ($8|0)==(0);
 L1: do {
  if ($10) {
   $$ph2 = $6;
   label = 8;
  } else {
   $11 = (($this) + 128|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 104|0);
   $14 = (($this) + 108|0);
   $16 = $6;
   while(1) {
    $15 = HEAP32[$16>>2]|0;
    $17 = ($12|0)==($15|0);
    if (!($17)) {
     $18 = HEAP8[$13>>0]|0;
     $19 = ($18<<24>>24)==(0);
     if ($19) {
      $$ph2 = $16;
      label = 8;
      break L1;
     }
     $20 = HEAP32[$2>>2]|0;
     $21 = ($20|0)==(0);
     if ($21) {
      $$ph2 = $16;
      label = 8;
      break L1;
     }
     $22 = HEAP32[$14>>2]|0;
     $23 = ($22|0)==($15|0);
     if (!($23)) {
      $$ph2 = $16;
      label = 8;
      break L1;
     }
    }
    $24 = (($16) + 20|0);
    $25 = ($24|0)==($9|0);
    if ($25) {
     $59 = $6;
     break;
    } else {
     $16 = $24;
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $26 = ($$ph2|0)==($9|0);
  if ($26) {
   $59 = $6;
  } else {
   $27 = (($this) + 128|0);
   $28 = (($this) + 104|0);
   $29 = (($this) + 108|0);
   $31 = $$ph2;
   L13: while(1) {
    $30 = (($31) + 12|0);
    $32 = HEAP32[$30>>2]|0;
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     $34 = (($31) + 8|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($31) + 16|0);
     $37 = HEAP8[$36>>0]|0;
     $38 = ($37<<24>>24)!=(0);
     __ZN18AwakeFromLoadQueue3AddER6ObjectPK8TypeTreeb17AwakeFromLoadMode($awakeQueue,$32,$35,$38,-1);
    }
    $39 = (($31) + 20|0);
    $40 = ($39|0)==($9|0);
    if ($40) {
     break;
    }
    $43 = HEAP32[$27>>2]|0;
    $42 = $39;
    while(1) {
     $44 = HEAP32[$42>>2]|0;
     $45 = ($43|0)==($44|0);
     if (!($45)) {
      $46 = HEAP8[$28>>0]|0;
      $47 = ($46<<24>>24)==(0);
      if ($47) {
       break;
      }
      $48 = HEAP32[$2>>2]|0;
      $49 = ($48|0)==(0);
      if ($49) {
       break;
      }
      $50 = HEAP32[$29>>2]|0;
      $51 = ($50|0)==($44|0);
      if (!($51)) {
       break;
      }
     }
     $52 = (($42) + 20|0);
     $53 = ($52|0)==($9|0);
     if ($53) {
      break L13;
     } else {
      $42 = $52;
     }
    }
    $41 = ($42|0)==($9|0);
    if ($41) {
     break;
    } else {
     $31 = $42;
    }
   }
   $$pre = HEAP32[$5>>2]|0;
   $59 = $$pre;
  }
 }
 HEAP32[$7>>2] = 32;
 $54 = (($this) + 164|0);
 HEAP32[$54>>2] = 16;
 $55 = (($this) + 160|0);
 HEAP32[$55>>2] = 6;
 $56 = (($this) + 168|0);
 HEAP8[$56>>0] = 0;
 $57 = (__Znwj(640)|0);
 $58 = ($59|0)==(0|0);
 if ($58) {
  $61 = 32;
 } else {
  __ZdlPv($59);
  $$pre$i$i = HEAP32[$7>>2]|0;
  $61 = $$pre$i$i;
 }
 HEAP32[$5>>2] = $57;
 $60 = (($57) + (($61*20)|0)|0);
 $62 = ($57|0)==($60|0);
 if ($62) {
  HEAP32[$0>>2] = 0;
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $63 = (($this) + 128|0);
 $$01$i$i$i$i = $57;
 while(1) {
  $64 = ($$01$i$i$i$i|0)==(0|0);
  if (!($64)) {
   ;HEAP32[$$01$i$i$i$i+0>>2]=HEAP32[$63+0>>2]|0;HEAP32[$$01$i$i$i$i+4>>2]=HEAP32[$63+4>>2]|0;HEAP32[$$01$i$i$i$i+8>>2]=HEAP32[$63+8>>2]|0;HEAP32[$$01$i$i$i$i+12>>2]=HEAP32[$63+12>>2]|0;HEAP32[$$01$i$i$i$i+16>>2]=HEAP32[$63+16>>2]|0;
  }
  $65 = (($$01$i$i$i$i) + 20|0);
  $66 = ($65|0)==($60|0);
  if ($66) {
   break;
  } else {
   $$01$i$i$i$i = $65;
  }
 }
 HEAP32[$0>>2] = 0;
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17PersistentManager25ExtractAwakeFromLoadQueueEPKijR18AwakeFromLoadQueue($this,$instanceIDs,$size,$awakeQueue) {
 $this = $this|0;
 $instanceIDs = $instanceIDs|0;
 $size = $size|0;
 $awakeQueue = $awakeQueue|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$08 = 0, $instanceID = 0, $phitmp$i$i$i = 0, $pos$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i = sp + 8|0;
 $instanceID = sp;
 __ZN18AwakeFromLoadQueue7ReserveEj($awakeQueue,$size);
 $0 = ($size|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 156|0);
 $2 = (($this) + 100|0);
 $3 = (($this) + 148|0);
 $4 = (($this) + 152|0);
 $5 = (($this) + 104|0);
 $6 = (($this) + 168|0);
 $7 = (($this) + 108|0);
 $8 = (($this) + 108|0);
 $9 = (($this) + 96|0);
 $i$08 = 0;
 while(1) {
  $10 = (($instanceIDs) + ($i$08<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$instanceID>>2] = $11;
  $12 = HEAP32[$1>>2]|0;
  $13 = HEAP32[$2>>2]|0;
  $14 = ($12|0)==($13|0);
  do {
   if ($14) {
    $15 = HEAP32[$3>>2]|0;
    $16 = HEAP32[$4>>2]|0;
    $17 = (($15) + (($16*20)|0)|0);
    $25 = $15;$26 = $16;$28 = $17;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($pos$i$i,$9,$instanceID);
    $18 = HEAP32[$pos$i$i>>2]|0;
    $19 = ($18|0)==(-1);
    $20 = HEAP32[$3>>2]|0;
    if ($19) {
     $21 = HEAP32[$4>>2]|0;
     $22 = (($20) + (($21*20)|0)|0);
     $25 = $20;$26 = $21;$28 = $22;
     break;
    } else {
     $23 = (($20) + (($18*20)|0)|0);
     $$pre = HEAP32[$4>>2]|0;
     $25 = $20;$26 = $$pre;$28 = $23;
     break;
    }
   }
  } while(0);
  $24 = (($25) + (($26*20)|0)|0);
  $27 = ($28|0)==($24|0);
  if (!($27)) {
   $29 = (($28) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $38 = $25;$39 = $26;
   } else {
    $32 = (($28) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($28) + 16|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = ($35<<24>>24)!=(0);
    __ZN18AwakeFromLoadQueue3AddER6ObjectPK8TypeTreeb17AwakeFromLoadMode($awakeQueue,$30,$33,$36,-1);
    $$pre9 = HEAP32[$3>>2]|0;
    $$pre10 = HEAP32[$4>>2]|0;
    $38 = $$pre9;$39 = $$pre10;
   }
   $37 = (($38) + (($39*20)|0)|0);
   $40 = ($28|0)==($37|0);
   if (!($40)) {
    $41 = HEAP8[$5>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if ($42) {
     $51 = 1;
    } else {
     $43 = HEAP32[$2>>2]|0;
     $44 = ($43|0)==(0);
     if ($44) {
      $51 = 1;
     } else {
      $45 = HEAP32[$8>>2]|0;
      $46 = HEAP32[$28>>2]|0;
      $phitmp$i$i$i = ($45|0)!=($46|0);
      $51 = $phitmp$i$i$i;
     }
    }
    $47 = ($28|0)==(0|0);
    if (!($47)) {
     ;HEAP32[$28+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$28+16>>2]=HEAP32[$7+16>>2]|0;
    }
    if ($51) {
     $48 = HEAP32[$2>>2]|0;
     $49 = (($48) + 1)|0;
     HEAP32[$2>>2] = $49;
     HEAP8[$6>>0] = 1;
    }
   }
  }
  $50 = (($i$08) + 1)|0;
  $exitcond = ($50|0)==($size|0);
  if ($exitcond) {
   break;
  } else {
   $i$08 = $50;
  }
 }
 STACKTOP = sp;return;
}
function __ZN17PersistentManager14ReloadFromDiskER6Object($this,$obj) {
 $this = $this|0;
 $obj = $obj|0;
 var $$0 = 0, $$0$lcssa$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $didTypeTreeChange = 0, $oldType = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldType = sp;
 $didTypeTreeChange = sp + 4|0;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($obj) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(-1);
 if ($6) {
  label = 5;
 } else {
  $7 = (($1) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)>($3|0);
  if ($9) {
   label = 5;
  } else {
   $10 = (($1) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)<($3|0);
   if ($12) {
    label = 5;
   } else {
    $13 = (($3) - ($8))|0;
    $14 = (($13|0) / 2)&-1;
    $15 = ($14|0)<(0);
    $16 = $15 << 31 >> 31;
    $43 = $5;$47 = $14;$48 = $16;
   }
  }
 }
 do {
  if ((label|0) == 5) {
   $17 = (($1) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($1) + 16|0);
   $20 = ($18|0)==(0|0);
   if (!($20)) {
    $$0$ph7$i$i$i$i = $19;$$01$ph6$i$in$i$i$i = $18;
    L8: while(1) {
     $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
     while(1) {
      $21 = (($$013$i$in$i$i$i) + 16|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22|0)<($3|0);
      if (!($23)) {
       break;
      }
      $26 = (($$013$i$in$i$i$i) + 4|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==(0|0);
      if ($28) {
       $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
       break L8;
      } else {
       $$013$i$in$i$i$i = $27;
      }
     }
     $24 = HEAP32[$$013$i$in$i$i$i>>2]|0;
     $25 = ($24|0)==(0|0);
     if ($25) {
      $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
      break;
     } else {
      $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $24;
     }
    }
    $29 = ($$0$ph5$i$i$i$i|0)==($19|0);
    if (!($29)) {
     $30 = (($$0$ph5$i$i$i$i) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)>($3|0);
     if (!($32)) {
      $33 = (($$0$ph5$i$i$i$i) + 24|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($$0$ph5$i$i$i$i) + 32|0);
      $36 = $35;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      $43 = $34;$47 = $38;$48 = $41;
      break;
     }
    }
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(638808,0,638872,951,1,0,0,0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $42 = ($43|0)==(-1);
 L20: do {
  if (!($42)) {
   $44 = (__ZN17PersistentManager26GetStreamNameSpaceInternalEi($this,$43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $49 = (__ZNK14SerializedFile11IsAvailableEx($45,$47,$48)|0);
    if ($49) {
     $50 = (($44) + 16|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     L24: do {
      if (!($52)) {
       $53 = HEAP32[$51>>2]|0;
       $54 = (($51) + 8|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = (($53) + ($55<<3)|0);
       $57 = ($55|0)==(0);
       L26: do {
        if ($57) {
         $$0$lcssa$i$i$i = $53;
        } else {
         $$01$i$i$i = $53;
         while(1) {
          $60 = $$01$i$i$i;
          $61 = $60;
          $62 = HEAP32[$61>>2]|0;
          $63 = (($60) + 4)|0;
          $64 = $63;
          $65 = HEAP32[$64>>2]|0;
          $66 = ($62|0)==($47|0);
          $67 = ($65|0)==($48|0);
          $68 = $66 & $67;
          $59 = (($$01$i$i$i) + 8|0);
          if ($68) {
           $$0$lcssa$i$i$i = $$01$i$i$i;
           break L26;
          }
          $58 = ($59|0)==($56|0);
          if ($58) {
           break L24;
          } else {
           $$01$i$i$i = $59;
          }
         }
        }
       } while(0);
       $69 = ($$0$lcssa$i$i$i|0)==($56|0);
       if (!($69)) {
        break L20;
       }
      }
     } while(0);
     $70 = HEAP32[$44>>2]|0;
     $71 = ($70|0)==(0|0);
     if (!($71)) {
      $72 = (($this) + 68|0);
      HEAP32[$72>>2] = $43;
      __ZN14SerializedFile10ReadObjectEx18ObjectCreationModebPPK8TypeTreePbR6Object($70,$47,$48,1,1,$oldType,$didTypeTreeChange,$obj);
      $73 = HEAP32[$obj>>2]|0;
      $74 = (($73) + 16|0);
      $75 = HEAP32[$74>>2]|0;
      FUNCTION_TABLE_vi[$75 & 4095]($obj);
      HEAP32[$72>>2] = -1;
      __ZN18AwakeFromLoadQueue34PersistentManagerAwakeSingleObjectER6Object17AwakeFromLoadMode($obj,3);
      $76 = (($this) + 156|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($this) + 100|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = ($77|0)==($79|0);
      if ($80) {
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
      while(1) {
       __ZN17PersistentManager40LoadRemainingPreallocatedObjectsInternalEv($this);
       __ZN17PersistentManager27IntegrateAllThreadedObjectsEv($this);
       $81 = HEAP32[$76>>2]|0;
       $82 = HEAP32[$78>>2]|0;
       $83 = ($81|0)==($82|0);
       if ($83) {
        $$0 = 1;
        break;
       }
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(638880,0,638872,958,1,0,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17PersistentManager40LoadRemainingPreallocatedObjectsInternalEv($this) {
 $this = $this|0;
 var $$0 = 0, $$be = 0, $$byval_copy14 = 0, $$lcssa2137 = 0, $$lcssa38 = 0, $$ph17 = 0, $$sink$index7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i1$026 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy14 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = HEAP32[628512>>2]|0;
 HEAP32[$3>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
 $5 = (invoke_iiiiiiii(108,(0|0),400,4,($$byval_copy14|0),0,(638872|0),370)|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if ($7) {
   $61 = ___cxa_find_matching_catch()|0;
   $62 = tempRet0;
   $105 = 100;$106 = 0;$lpad$phi$index = $61;$lpad$phi$index2 = $62;
   label = 22;
  } else {
   $8 = (($this) + 148|0);
   $9 = (($this) + 152|0);
   $10 = (($this) + 128|0);
   $11 = (($this) + 104|0);
   $12 = (($this) + 100|0);
   $13 = (($this) + 108|0);
   $100 = 100;$101 = $5;
   L3: while(1) {
    $14 = HEAP32[$8>>2]|0;
    $15 = HEAP32[$9>>2]|0;
    $16 = (($14) + (($15*20)|0)|0);
    $17 = ($15|0)==(0);
    L5: do {
     if ($17) {
      $$ph17 = $14;
     } else {
      $18 = HEAP32[$10>>2]|0;
      $20 = $14;
      while(1) {
       $19 = HEAP32[$20>>2]|0;
       $21 = ($18|0)==($19|0);
       if (!($21)) {
        $22 = HEAP8[$11>>0]|0;
        $23 = ($22<<24>>24)==(0);
        if ($23) {
         $$ph17 = $20;
         break L5;
        }
        $24 = HEAP32[$12>>2]|0;
        $25 = ($24|0)==(0);
        if ($25) {
         $$ph17 = $20;
         break L5;
        }
        $26 = HEAP32[$13>>2]|0;
        $27 = ($26|0)==($19|0);
        if (!($27)) {
         $$ph17 = $20;
         break L5;
        }
       }
       $28 = (($20) + 20|0);
       $29 = ($28|0)==($16|0);
       if ($29) {
        $$lcssa2137 = $101;$$lcssa38 = $100;
        label = 33;
        break L3;
       } else {
        $20 = $28;
       }
      }
     }
    } while(0);
    $30 = ($$ph17|0)==($16|0);
    if ($30) {
     $$lcssa2137 = $101;$$lcssa38 = $100;
     label = 33;
     break;
    } else {
     $32 = $$ph17;$38 = 0;$40 = $100;$48 = $101;
    }
    while(1) {
     $31 = (($32) + 18|0);
     $33 = HEAP8[$31>>0]|0;
     $34 = ($33<<24>>24)==(0);
     if ($34) {
      $35 = (($32) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($38) + 1)|0;
      $39 = $40 & 2147483647;
      $41 = ($37>>>0)>($39>>>0);
      do {
       if ($41) {
        $42 = $40 << 1;
        $43 = ($42|0)==(0);
        $44 = $43 ? 1 : $42;
        $45 = ($39>>>0)<($44>>>0);
        if ($45) {
         $46 = ($40|0)>(-1);
         if ($46) {
          $47 = $44 << 2;
          HEAP32[$0>>2] = $4;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
          $49 = (invoke_iiiiiiii(108,($48|0),($47|0),4,($$byval_copy14|0),0,(638872|0),370)|0);
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           $104 = $44;
           label = 23;
           break L3;
          }
          $103 = $44;$58 = $49;
          break;
         } else {
          $52 = $44 << 2;
          HEAP32[$1>>2] = $4;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
          $53 = (invoke_iiiiiii(102,($52|0),4,($$byval_copy14|0),0,(638872|0),352)|0);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           $104 = $40;
           label = 23;
           break L3;
          }
          $56 = $37 << 2;
          _memcpy(($53|0),($48|0),($56|0))|0;
          $103 = $44;$58 = $53;
          break;
         }
        } else {
         $103 = $40;$58 = $48;
        }
       } else {
        $103 = $40;$58 = $48;
       }
      } while(0);
      $57 = (($58) + ($38<<2)|0);
      HEAP32[$57>>2] = $36;
      $102 = $103;$84 = $37;$87 = $58;
     } else {
      $102 = $40;$84 = $38;$87 = $48;
     }
     $65 = (($32) + 20|0);
     $66 = ($65|0)==($16|0);
     L29: do {
      if ($66) {
       $$be = $16;
      } else {
       $71 = HEAP32[$10>>2]|0;
       $73 = $65;
       while(1) {
        $72 = HEAP32[$73>>2]|0;
        $74 = ($71|0)==($72|0);
        if (!($74)) {
         $75 = HEAP8[$11>>0]|0;
         $76 = ($75<<24>>24)==(0);
         if ($76) {
          $$be = $73;
          break L29;
         }
         $77 = HEAP32[$12>>2]|0;
         $78 = ($77|0)==(0);
         if ($78) {
          $$be = $73;
          break L29;
         }
         $79 = HEAP32[$13>>2]|0;
         $80 = ($79|0)==($72|0);
         if (!($80)) {
          $$be = $73;
          break L29;
         }
        }
        $81 = (($73) + 20|0);
        $82 = ($81|0)==($16|0);
        if ($82) {
         $$be = $16;
         break;
        } else {
         $73 = $81;
        }
       }
      }
     } while(0);
     $67 = HEAP32[$8>>2]|0;
     $68 = HEAP32[$9>>2]|0;
     $69 = (($67) + (($68*20)|0)|0);
     $70 = ($$be|0)==($69|0);
     if ($70) {
      break;
     } else {
      $32 = $$be;$38 = $84;$40 = $102;$48 = $87;
     }
    }
    $83 = ($84|0)==(0);
    if ($83) {
     $$lcssa2137 = $87;$$lcssa38 = $102;
     label = 33;
     break;
    } else {
     $i1$026 = 0;
    }
    while(1) {
     $86 = (($87) + ($i1$026<<2)|0);
     $88 = HEAP32[$86>>2]|0;
     __THREW__ = 0;
     (invoke_iii(2447,($this|0),($88|0))|0);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 20;
      break L3;
     }
     $91 = (($i1$026) + 1)|0;
     $92 = ($91>>>0)<($84>>>0);
     if ($92) {
      $i1$026 = $91;
     } else {
      $100 = $102;$101 = $87;
      continue L3;
     }
    }
   }
   if ((label|0) == 20) {
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    $105 = $102;$106 = $87;$lpad$phi$index = $59;$lpad$phi$index2 = $60;
    label = 22;
    break;
   }
   else if ((label|0) == 23) {
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    $$0 = $63;$$sink$index7 = $64;$94 = $104;$95 = $48;
    break;
   }
   else if ((label|0) == 33) {
    $85 = ($$lcssa38|0)>(-1);
    if (!($85)) {
     STACKTOP = sp;return;
    }
    HEAP32[$0>>2] = $4;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($$lcssa2137,$$byval_copy14);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $$0 = $lpad$phi$index;$$sink$index7 = $lpad$phi$index2;$94 = $105;$95 = $106;
 }
 $93 = ($94|0)>(-1);
 if (!($93)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 HEAP32[$2>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($95|0),($$byval_copy14|0));
 $96 = __THREW__; __THREW__ = 0;
 $97 = $96&1;
 if ($97) {
  $98 = ___cxa_find_matching_catch(0|0)|0;
  $99 = tempRet0;
  ___clang_call_terminate($98);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN17PersistentManager48IntegrateObjectAndUnlockIntegrationMutexInternalEi($this,$instanceID) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i$i$i = 0, $pos$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i = sp + 8|0;
 $0 = sp;
 HEAP32[$0>>2] = $instanceID;
 $1 = (($this) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   $6 = (($this) + 148|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($this) + 152|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($7) + (($9*20)|0)|0);
   $22 = $7;$23 = $9;$25 = $10;
  } else {
   $11 = (($this) + 96|0);
   __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($pos$i$i,$11,$0);
   $12 = HEAP32[$pos$i$i>>2]|0;
   $13 = ($12|0)==(-1);
   $14 = (($this) + 148|0);
   $15 = HEAP32[$14>>2]|0;
   if ($13) {
    $16 = (($this) + 152|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + (($17*20)|0)|0);
    $22 = $15;$23 = $17;$25 = $18;
    break;
   } else {
    $19 = (($15) + (($12*20)|0)|0);
    $$phi$trans$insert = (($this) + 152|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $22 = $15;$23 = $$pre;$25 = $19;
    break;
   }
  }
 } while(0);
 $20 = (($this) + 152|0);
 $21 = (($22) + (($23*20)|0)|0);
 $24 = ($25|0)==($21|0);
 if ($24) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = (($25) + 17|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($25) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$20>>2]|0;
 $32 = (($22) + (($31*20)|0)|0);
 $33 = ($25|0)==($32|0);
 if (!($33)) {
  $34 = (($this) + 104|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ($35<<24>>24)==(0);
  if ($36) {
   $47 = 1;
  } else {
   $37 = HEAP32[$3>>2]|0;
   $38 = ($37|0)==(0);
   if ($38) {
    $47 = 1;
   } else {
    $39 = (($this) + 108|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = HEAP32[$25>>2]|0;
    $phitmp$i$i$i = ($40|0)!=($41|0);
    $47 = $phitmp$i$i$i;
   }
  }
  $42 = ($25|0)==(0|0);
  if (!($42)) {
   $43 = (($this) + 108|0);
   ;HEAP32[$25+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$43+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$43+16>>2]|0;
  }
  if ($47) {
   $44 = HEAP32[$3>>2]|0;
   $45 = (($44) + 1)|0;
   HEAP32[$3>>2] = $45;
   $46 = (($this) + 168|0);
   HEAP8[$46>>0] = 1;
  }
 }
 __ZN6Object18RegisterInstanceIDEPS_($30);
 __ZN18AwakeFromLoadQueue34PersistentManagerAwakeSingleObjectER6Object17AwakeFromLoadMode($30,3);
 $$0 = $30;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17PersistentManager10ReadObjectEi($this,$instanceID) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN17PersistentManager48IntegrateObjectAndUnlockIntegrationMutexInternalEi($this,$instanceID)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$1 = $0;
  STACKTOP = sp;return ($$1|0);
 }
 $2 = (($this) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if (!($4)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(638936,0,638872,1037,1,0,0,0);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $5 = (__ZN17PersistentManager18ReadObjectThreadedEi($this,$instanceID)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $7 = (($this) + 156|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  $$1 = $5;
  STACKTOP = sp;return ($$1|0);
 }
 while(1) {
  __ZN17PersistentManager40LoadRemainingPreallocatedObjectsInternalEv($this);
  __ZN17PersistentManager27IntegrateAllThreadedObjectsEv($this);
  $12 = HEAP32[$7>>2]|0;
  $13 = HEAP32[$9>>2]|0;
  $14 = ($12|0)==($13|0);
  if ($14) {
   $$1 = $5;
   break;
  }
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZN17PersistentManager18ReadObjectThreadedEi($this,$instanceID) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 var $$0$lcssa$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$1 = 0, $$byval_copy = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $didTypeTreeChange = 0, $oldType = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $0 = sp + 40|0;
 $1 = sp + 32|0;
 $2 = sp;
 $oldType = sp + 36|0;
 $didTypeTreeChange = sp + 44|0;
 HEAP32[$1>>2] = $instanceID;
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 100|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 do {
  if ($7) {
   $8 = (($this) + 148|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 152|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + (($11*20)|0)|0);
   $25 = $9;$26 = $11;$28 = $12;
  } else {
   $13 = (($this) + 96|0);
   __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($$byval_copy,$13,$1);
   $14 = HEAP32[$$byval_copy>>2]|0;
   $15 = ($14|0)==(-1);
   $16 = (($this) + 148|0);
   $17 = HEAP32[$16>>2]|0;
   if ($15) {
    $18 = (($this) + 152|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($17) + (($19*20)|0)|0);
    $25 = $17;$26 = $19;$28 = $20;
    break;
   } else {
    $21 = (($17) + (($14*20)|0)|0);
    $$phi$trans$insert = (($this) + 152|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $25 = $17;$26 = $$pre;$28 = $21;
    break;
   }
  }
 } while(0);
 $22 = (($this) + 148|0);
 $23 = (($this) + 152|0);
 $24 = (($25) + (($26*20)|0)|0);
 $27 = ($28|0)==($24|0);
 if (!($27)) {
  $29 = (($28) + 18|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if (!($31)) {
   $32 = (($28) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   $$1 = $33;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $34 = (($this) + 44|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$1>>2]|0;
 $37 = (($35) + 36|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(-1);
 if ($39) {
  label = 13;
 } else {
  $40 = (($35) + 28|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)>($36|0);
  if ($42) {
   label = 13;
  } else {
   $43 = (($35) + 32|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)<($36|0);
   if ($45) {
    label = 13;
   } else {
    $46 = (($36) - ($41))|0;
    $47 = (($46|0) / 2)&-1;
    $48 = ($47|0)<(0);
    $49 = $48 << 31 >> 31;
    $109 = 0;$79 = $38;$83 = $47;$84 = $49;
   }
  }
 }
 do {
  if ((label|0) == 13) {
   $50 = (($35) + 16|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($35) + 16|0);
   $53 = ($51|0)==(0|0);
   if ($53) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   } else {
    $$0$ph7$i$i$i$i = $52;$$01$ph6$i$in$i$i$i = $51;
   }
   L21: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $54 = (($$013$i$in$i$i$i) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)<($36|0);
     if (!($56)) {
      break;
     }
     $59 = (($$013$i$in$i$i$i) + 4|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==(0|0);
     if ($61) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L21;
     } else {
      $$013$i$in$i$i$i = $60;
     }
    }
    $57 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $58 = ($57|0)==(0|0);
    if ($58) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $57;
    }
   }
   $62 = ($$0$ph5$i$i$i$i|0)==($52|0);
   if ($62) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $63 = (($$0$ph5$i$i$i$i) + 16|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)>($36|0);
   if ($65) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   } else {
    $66 = (($$0$ph5$i$i$i$i) + 24|0);
    $67 = (($$0$ph5$i$i$i$i) + 24|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($$0$ph5$i$i$i$i) + 32|0);
    $72 = $71;
    $73 = $72;
    $74 = HEAP32[$73>>2]|0;
    $75 = (($72) + 4)|0;
    $76 = $75;
    $77 = HEAP32[$76>>2]|0;
    $109 = $70;$79 = $68;$83 = $74;$84 = $77;
    break;
   }
  }
 } while(0);
 $78 = ($79|0)==(-1);
 if ($78) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $80 = (__ZN17PersistentManager26GetStreamNameSpaceInternalEi($this,$79)|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = ($81|0)==(0|0);
 if ($82) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $85 = (__ZNK14SerializedFile11IsAvailableEx($81,$83,$84)|0);
 if (!($85)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $86 = (($80) + 16|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(0|0);
 L44: do {
  if (!($88)) {
   $89 = HEAP32[$87>>2]|0;
   $90 = (($87) + 8|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($89) + ($91<<3)|0);
   $93 = ($91|0)==(0);
   L46: do {
    if ($93) {
     $$0$lcssa$i$i$i = $89;
    } else {
     $$01$i$i$i = $89;
     while(1) {
      $96 = $$01$i$i$i;
      $97 = $96;
      $98 = HEAP32[$97>>2]|0;
      $99 = (($96) + 4)|0;
      $100 = $99;
      $101 = HEAP32[$100>>2]|0;
      $102 = ($98|0)==($83|0);
      $103 = ($101|0)==($84|0);
      $104 = $102 & $103;
      $95 = (($$01$i$i$i) + 8|0);
      if ($104) {
       $$0$lcssa$i$i$i = $$01$i$i$i;
       break L46;
      }
      $94 = ($95|0)==($92|0);
      if ($94) {
       break L44;
      } else {
       $$01$i$i$i = $95;
      }
     }
    }
   } while(0);
   $105 = ($$0$lcssa$i$i$i|0)==($92|0);
   if (!($105)) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 $106 = HEAP32[$80>>2]|0;
 $107 = ($106|0)==(0|0);
 if ($107) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 HEAP32[$2>>2] = $79;
 $108 = (($2) + 4|0);
 HEAP32[$108>>2] = $109;
 $110 = (($2) + 8|0);
 $111 = $110;
 $112 = $111;
 HEAP32[$112>>2] = $83;
 $113 = (($111) + 4)|0;
 $114 = $113;
 HEAP32[$114>>2] = $84;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;
 $115 = (__ZN17PersistentManager32CreateThreadActivationQueueEntryER14SerializedFile26SerializedObjectIdentifierib($this,$106,$$byval_copy,$36,1)|0);
 $116 = ($115|0)==(0|0);
 if ($116) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $117 = (($this) + 68|0);
 HEAP32[$117>>2] = $79;
 $118 = (($115) + 8|0);
 $119 = HEAP32[$118>>2]|0;
 __ZN14SerializedFile10ReadObjectEx18ObjectCreationModebPPK8TypeTreePbR6Object($106,$83,$84,1,1,$oldType,$didTypeTreeChange,$119);
 HEAP32[$117>>2] = -1;
 $120 = HEAP32[$oldType>>2]|0;
 $121 = HEAP8[$didTypeTreeChange>>0]|0;
 HEAP32[$0>>2] = $36;
 $122 = HEAP32[$3>>2]|0;
 $123 = HEAP32[$5>>2]|0;
 $124 = ($122|0)==($123|0);
 do {
  if ($124) {
   $125 = HEAP32[$22>>2]|0;
   $126 = HEAP32[$23>>2]|0;
   $127 = (($125) + (($126*20)|0)|0);
   $136 = $127;
  } else {
   $128 = (($this) + 96|0);
   __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($$byval_copy,$128,$0);
   $129 = HEAP32[$$byval_copy>>2]|0;
   $130 = ($129|0)==(-1);
   $131 = HEAP32[$22>>2]|0;
   if ($130) {
    $132 = HEAP32[$23>>2]|0;
    $133 = (($131) + (($132*20)|0)|0);
    $136 = $133;
    break;
   } else {
    $134 = (($131) + (($129*20)|0)|0);
    $136 = $134;
    break;
   }
  }
 } while(0);
 $135 = (($136) + 12|0);
 $137 = HEAP32[$135>>2]|0;
 $138 = HEAP32[$137>>2]|0;
 $139 = (($138) + 16|0);
 $140 = HEAP32[$139>>2]|0;
 FUNCTION_TABLE_vi[$140 & 4095]($137);
 $141 = (($136) + 8|0);
 HEAP32[$141>>2] = $120;
 $142 = (($136) + 16|0);
 HEAP8[$142>>0] = $121;
 $143 = (($136) + 17|0);
 HEAP8[$143>>0] = 1;
 $$1 = $119;
 STACKTOP = sp;return ($$1|0);
}
function __ZN17PersistentManager32CreateThreadActivationQueueEntryER14SerializedFile26SerializedObjectIdentifierib($this,$file,$identifier,$instanceID,$loadStarted) {
 $this = $this|0;
 $file = $file|0;
 $identifier = $identifier|0;
 $instanceID = $instanceID|0;
 $loadStarted = $loadStarted|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $identifier$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $identifier$byval_copy = sp;
 $0 = sp + 56|0;
 $1 = sp + 16|0;
 $2 = sp + 40|0;
 HEAP32[$0>>2] = $instanceID;
 $3 = (($this) + 96|0);
 $4 = (($this) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 100|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 do {
  if ($8) {
   $9 = (($this) + 148|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 152|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($10) + (($12*20)|0)|0);
   $23 = $10;$24 = $12;$26 = $13;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($identifier$byval_copy,$3,$0);
   $14 = HEAP32[$identifier$byval_copy>>2]|0;
   $15 = ($14|0)==(-1);
   $16 = (($this) + 148|0);
   $17 = HEAP32[$16>>2]|0;
   if ($15) {
    $18 = (($this) + 152|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($17) + (($19*20)|0)|0);
    $23 = $17;$24 = $19;$26 = $20;
    break;
   } else {
    $21 = (($17) + (($14*20)|0)|0);
    $$phi$trans$insert = (($this) + 152|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $23 = $17;$24 = $$pre;$26 = $21;
    break;
   }
  }
 } while(0);
 $22 = (($23) + (($24*20)|0)|0);
 $25 = ($26|0)==($22|0);
 if ($25) {
  $29 = HEAP32[$0>>2]|0;
  ;HEAP32[$identifier$byval_copy+0>>2]=HEAP32[$identifier+0>>2]|0;HEAP32[$identifier$byval_copy+4>>2]=HEAP32[$identifier+4>>2]|0;HEAP32[$identifier$byval_copy+8>>2]=HEAP32[$identifier+8>>2]|0;HEAP32[$identifier$byval_copy+12>>2]=HEAP32[$identifier+12>>2]|0;
  $30 = (__ZN17PersistentManager21ProduceObjectInternalER14SerializedFile26SerializedObjectIdentifierii($this,$file,$identifier$byval_copy,$29,1)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $32 = $loadStarted&1;
  HEAP32[$1>>2] = $29;
  $33 = (($1) + 4|0);
  HEAP32[$33>>2] = $29;
  $34 = (($1) + 8|0);
  HEAP32[$34>>2] = 0;
  $35 = (($1) + 12|0);
  HEAP32[$35>>2] = $30;
  $36 = (($1) + 16|0);
  HEAP8[$36>>0] = 0;
  $37 = (($1) + 17|0);
  HEAP8[$37>>0] = 0;
  $38 = (($1) + 18|0);
  HEAP8[$38>>0] = $32;
  __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E6insertERKS4_($2,$3,$1);
  $39 = (($2) + 4|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 4|0);
  $$0 = $41;
  STACKTOP = sp;return ($$0|0);
 } else {
  $27 = (($26) + 4|0);
  if (!($loadStarted)) {
   $$0 = $27;
   STACKTOP = sp;return ($$0|0);
  }
  $28 = (($26) + 18|0);
  HEAP8[$28>>0] = 1;
  $$0 = $27;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN17PersistentManager21ProduceObjectInternalER14SerializedFile26SerializedObjectIdentifierii($this,$file,$identifier,$instanceID,$objectCreationMode) {
 $this = $this|0;
 $file = $file|0;
 $identifier = $identifier|0;
 $instanceID = $instanceID|0;
 $objectCreationMode = $objectCreationMode|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $classID = 0, $memoryLabel = 0, $script$010 = 0, $script$012$in = 0, $scriptInstanceID = 0, $scriptReference = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy = sp + 64|0;
 $0 = sp + 56|0;
 $classID = sp + 52|0;
 $scriptReference = sp;
 $memoryLabel = sp + 40|0;
 $1 = sp + 44|0;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 $scriptInstanceID = sp + 48|0;
 $4 = (($scriptReference) + 8|0);
 $5 = $4;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 HEAP32[$scriptReference>>2] = 0;
 $9 = (($identifier) + 8|0);
 $10 = $9;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (__ZN14SerializedFile14GetProduceDataExRiR31LocalSerializedObjectIdentifierR18MemLabelIdentifier($file,$12,$15,$classID,$scriptReference,$memoryLabel)|0);
 if (!($16)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = HEAP32[$classID>>2]|0;
 $18 = HEAP32[$memoryLabel>>2]|0;
 HEAP32[$1>>2] = $18;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 $19 = (__ZN6Object7ProduceEii10MemLabelId18ObjectCreationMode($17,$instanceID,$$byval_copy,$objectCreationMode)|0);
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $89 = $4;
  $90 = $89;
  $91 = HEAP32[$90>>2]|0;
  $92 = (($89) + 4)|0;
  $93 = $92;
  $94 = HEAP32[$93>>2]|0;
  $95 = ($91|0)==(0);
  $96 = ($94|0)==(0);
  $97 = $95 & $96;
  if ($97) {
   $$0 = $19;
   STACKTOP = sp;return ($$0|0);
  }
  $98 = (($19) + 8|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = $99 >>> 21;
  $101 = HEAP32[560640>>2]|0;
  $102 = Math_imul($101, $100)|0;
  $103 = (($102) + 114)|0;
  $104 = $103 >> 5;
  $105 = $104 << 5;
  $106 = (($103) - ($105))|0;
  $107 = HEAP32[560632>>2]|0;
  $108 = (($107) + ($104<<2)|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = 1 << $106;
  $111 = $110 & $109;
  $112 = ($111|0)==(0);
  if ($112) {
   $$0 = $19;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$scriptInstanceID>>2] = 0;
  $113 = HEAP32[$identifier>>2]|0;
  __ZN17PersistentManager51LocalSerializedObjectIdentifierToInstanceIDInternalEiRK31LocalSerializedObjectIdentifierRi($this,$113,$scriptReference,$scriptInstanceID);
  $114 = HEAP32[$scriptInstanceID>>2]|0;
  HEAP32[$0>>2] = $114;
  $115 = (($this) + 156|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($this) + 100|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ($116|0)==($118|0);
  do {
   if ($119) {
    $120 = (($this) + 148|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = (($this) + 152|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = (($121) + (($123*20)|0)|0);
    $135 = $121;$136 = $123;$138 = $124;
   } else {
    $125 = (($this) + 96|0);
    __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($$byval_copy,$125,$0);
    $126 = HEAP32[$$byval_copy>>2]|0;
    $127 = ($126|0)==(-1);
    $128 = (($this) + 148|0);
    $129 = HEAP32[$128>>2]|0;
    if ($127) {
     $130 = (($this) + 152|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = (($129) + (($131*20)|0)|0);
     $135 = $129;$136 = $131;$138 = $132;
     break;
    } else {
     $133 = (($129) + (($126*20)|0)|0);
     $$phi$trans$insert$i = (($this) + 152|0);
     $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $135 = $129;$136 = $$pre$i;$138 = $133;
     break;
    }
   }
  } while(0);
  $134 = (($135) + (($136*20)|0)|0);
  $137 = ($138|0)==($134|0);
  if ($137) {
   label = 43;
  } else {
   $139 = (($138) + 12|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = ($140|0)==(0|0);
   if ($141) {
    label = 43;
   } else {
    $142 = (($140) + 8|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = $143 >>> 21;
    $145 = HEAP32[560640>>2]|0;
    $146 = Math_imul($145, $144)|0;
    $147 = (($146) + 115)|0;
    $148 = $147 >> 5;
    $149 = $148 << 5;
    $150 = (($147) - ($149))|0;
    $151 = HEAP32[560632>>2]|0;
    $152 = (($151) + ($148<<2)|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = 1 << $150;
    $155 = $154 & $153;
    $156 = ($155|0)==(0);
    if ($156) {
     label = 43;
    } else {
     $157 = (($19) + 32|0);
     HEAP32[$157>>2] = $114;
     $script$012$in = $140;
     label = 47;
    }
   }
  }
  do {
   if ((label|0) == 43) {
    $158 = (__ZN6Object21IDToPointerThreadSafeEi($114)|0);
    $159 = ($158|0)==(0|0);
    if (!($159)) {
     $160 = (($158) + 8|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = $161 >>> 21;
     $163 = HEAP32[560640>>2]|0;
     $164 = Math_imul($163, $162)|0;
     $165 = (($164) + 115)|0;
     $166 = $165 >> 5;
     $167 = $166 << 5;
     $168 = (($165) - ($167))|0;
     $169 = HEAP32[560632>>2]|0;
     $170 = (($169) + ($166<<2)|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = 1 << $168;
     $173 = $172 & $171;
     $174 = ($173|0)==(0);
     if (!($174)) {
      $176 = (($19) + 32|0);
      HEAP32[$176>>2] = $114;
      $script$012$in = $158;
      label = 47;
      break;
     }
    }
    $175 = (($19) + 32|0);
    HEAP32[$175>>2] = $114;
    $178 = 0;$script$010 = 0;
   }
  } while(0);
  if ((label|0) == 47) {
   $177 = (__ZN10MonoScript8GetClassEv($script$012$in)|0);
   $178 = $177;$script$010 = $script$012$in;
  }
  __ZN13MonoBehaviour19RebuildMonoInstanceEP14ScriptingClassP15ScriptingObjectP10MonoScript($19,$178,0,$script$010);
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = HEAP32[$classID>>2]|0;
 __Z11IntToStringi($3,$21);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 $22 = HEAP8[$3>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $27 = $22&255;
  $28 = $27 >>> 1;
  $30 = $28;
 } else {
  $25 = (($3) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $30 = $26;
 }
 $29 = (($30) + 32)|0;
 $31 = ($29>>>0)>(4294967279);
 do {
  if ($31) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    label = 17;
   } else {
    // unreachable;
   }
  } else {
   $34 = ($29>>>0)<(11);
   if ($34) {
    HEAP8[$2>>0] = 64;
    $35 = (($2) + 1|0);
    $__p$0$i$i = $35;
   } else {
    $36 = (($30) + 48)|0;
    $37 = $36 & -16;
    __THREW__ = 0;
    $38 = (invoke_ii(2988,($37|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 17;
     break;
    }
    $41 = (($2) + 8|0);
    HEAP32[$41>>2] = $38;
    $42 = $37 | 1;
    HEAP32[$2>>2] = $42;
    $43 = (($2) + 4|0);
    HEAP32[$43>>2] = 32;
    $__p$0$i$i = $38;
   }
   dest=$__p$0$i$i+0|0; src=639160+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $44 = (($__p$0$i$i) + 32|0);
   HEAP8[$44>>0] = 0;
   if ($24) {
    $47 = (($3) + 1|0);
    $48 = $47;
   } else {
    $45 = (($3) + 8|0);
    $46 = HEAP32[$45>>2]|0;
    $48 = $46;
   }
   __THREW__ = 0;
   (invoke_iiii(1480,($2|0),($48|0),($30|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    label = 17;
   } else {
    $58 = HEAP8[$2>>0]|0;
    $59 = $58 & 1;
    $60 = ($59<<24>>24)==(0);
    if ($60) {
     $63 = (($2) + 1|0);
     $64 = $63;
    } else {
     $61 = (($2) + 8|0);
     $62 = HEAP32[$61>>2]|0;
     $64 = $62;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($64|0),0,(638872|0),1166,1,0,0,(0|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     $77 = ___cxa_find_matching_catch()|0;
     $78 = tempRet0;
     $79 = HEAP8[$2>>0]|0;
     $80 = $79 & 1;
     $81 = ($80<<24>>24)==(0);
     if ($81) {
      $$01 = $78;$$02 = $77;
      break;
     }
     $82 = (($2) + 8|0);
     $83 = HEAP32[$82>>2]|0;
     __ZdlPv($83);
     $$01 = $78;$$02 = $77;
     break;
    }
    $67 = HEAP8[$2>>0]|0;
    $68 = $67 & 1;
    $69 = ($68<<24>>24)==(0);
    if (!($69)) {
     $70 = (($2) + 8|0);
     $71 = HEAP32[$70>>2]|0;
     __ZdlPv($71);
    }
    $72 = HEAP8[$3>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    if ($74) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $75 = (($3) + 8|0);
    $76 = HEAP32[$75>>2]|0;
    __ZdlPv($76);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $53 = HEAP8[$2>>0]|0;
  $54 = $53 & 1;
  $55 = ($54<<24>>24)==(0);
  if (!($55)) {
   $56 = (($2) + 8|0);
   $57 = HEAP32[$56>>2]|0;
   __ZdlPv($57);
  }
  $$01 = $52;$$02 = $51;
 }
 $84 = HEAP8[$3>>0]|0;
 $85 = $84 & 1;
 $86 = ($85<<24>>24)==(0);
 if ($86) {
  ___resumeException($$02|0);
  // unreachable;
 }
 $87 = (($3) + 8|0);
 $88 = HEAP32[$87>>2]|0;
 __ZdlPv($88);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN17PersistentManager22CheckInstanceIDsLoadedEPii($this,$heapIDs,$size) {
 $this = $this|0;
 $heapIDs = $heapIDs|0;
 $size = $size|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$index = 0, $$index8 = 0, $$lcssa21 = 0, $$lcssa24 = 0, $$neg2$i$i$i$i$i = 0, $$ph20 = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $exitcond = 0, $exitcond34 = 0, $j$019 = 0, $j$019$us = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$$i$i = 0, $not$$i$i$us = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) - ($4))|0;
 $6 = ($2|0)==($4|0);
 do {
  if ($6) {
   $125 = 0;$126 = 0;
  } else {
   $7 = $5 << 2;
   __THREW__ = 0;
   $8 = (invoke_ii(2988,($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $13 = (($8) + ($5<<2)|0);
    $125 = $13;$126 = $8;
    break;
   }
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   $$index = $11;$$index8 = $12;
   ___resumeException($$index|0);
   // unreachable;
  }
 } while(0);
 $14 = (($this) + 148|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 152|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + (($17*20)|0)|0);
 $19 = ($17|0)==(0);
 L8: do {
  if ($19) {
   $$ph20 = $15;
   label = 11;
  } else {
   $20 = (($this) + 128|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($this) + 104|0);
   $23 = (($this) + 108|0);
   $25 = $15;
   while(1) {
    $24 = HEAP32[$25>>2]|0;
    $26 = ($21|0)==($24|0);
    if (!($26)) {
     $27 = HEAP8[$22>>0]|0;
     $28 = ($27<<24>>24)==(0);
     $29 = ($4|0)==(0);
     $or$cond = $28 | $29;
     if ($or$cond) {
      $$ph20 = $25;
      label = 11;
      break L8;
     }
     $30 = HEAP32[$23>>2]|0;
     $31 = ($30|0)==($24|0);
     if (!($31)) {
      $$ph20 = $25;
      label = 11;
      break L8;
     }
    }
    $32 = (($25) + 20|0);
    $33 = ($32|0)==($18|0);
    if ($33) {
     $$lcssa21 = $126;$$lcssa24 = $126;
     label = 40;
     break;
    } else {
     $25 = $32;
    }
   }
  }
 } while(0);
 L16: do {
  if ((label|0) == 11) {
   $34 = ($$ph20|0)==($18|0);
   if ($34) {
    $$lcssa21 = $126;$$lcssa24 = $126;
    label = 40;
   } else {
    $35 = (($this) + 128|0);
    $36 = (($this) + 104|0);
    $37 = (($this) + 108|0);
    $39 = $$ph20;$41 = $126;$42 = $125;$48 = $126;
    while(1) {
     $38 = (($39) + 4|0);
     $40 = ($41|0)==($42|0);
     if ($40) {
      $46 = $41;
      $47 = $48;
      $49 = (($46) - ($47))|0;
      $50 = $49 >> 2;
      $51 = (($50) + 1)|0;
      $52 = ($51>>>0)>(1073741823);
      if ($52) {
       break;
      }
      $55 = ($50>>>0)<(536870911);
      if ($55) {
       $56 = $49 >> 1;
       $57 = ($56>>>0)<($51>>>0);
       $58 = $57 ? $51 : $56;
       $59 = ($58|0)==(0);
       if ($59) {
        $$0$i3$i$i = 0;$65 = 0;
       } else {
        $$0$i2$i$i = $58;
        label = 22;
       }
      } else {
       $$0$i2$i$i = 1073741823;
       label = 22;
      }
      if ((label|0) == 22) {
       label = 0;
       $60 = $$0$i2$i$i << 2;
       __THREW__ = 0;
       $61 = (invoke_ii(2988,($60|0))|0);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        label = 36;
        break;
       }
       $$0$i3$i$i = $$0$i2$i$i;$65 = $61;
      }
      $64 = (($65) + ($50<<2)|0);
      $66 = (($65) + ($$0$i3$i$i<<2)|0);
      $67 = ($64|0)==(0|0);
      if (!($67)) {
       $68 = HEAP32[$38>>2]|0;
       HEAP32[$64>>2] = $68;
      }
      $69 = (($65) + ($51<<2)|0);
      _memcpy(($65|0),($48|0),($49|0))|0;
      $70 = ($48|0)==(0|0);
      if ($70) {
       $127 = $66;$128 = $69;$129 = $65;
      } else {
       __ZdlPv($48);
       $127 = $66;$128 = $69;$129 = $65;
      }
     } else {
      $43 = ($41|0)==(0|0);
      if (!($43)) {
       $44 = HEAP32[$38>>2]|0;
       HEAP32[$41>>2] = $44;
      }
      $45 = (($41) + 4|0);
      $127 = $42;$128 = $45;$129 = $48;
     }
     $71 = (($39) + 20|0);
     $72 = ($71|0)==($18|0);
     if ($72) {
      $$lcssa21 = $128;$$lcssa24 = $129;
      label = 40;
      break L16;
     }
     $75 = HEAP32[$35>>2]|0;
     $74 = $71;
     while(1) {
      $76 = HEAP32[$74>>2]|0;
      $77 = ($75|0)==($76|0);
      if (!($77)) {
       $78 = HEAP8[$36>>0]|0;
       $79 = ($78<<24>>24)==(0);
       if ($79) {
        break;
       }
       $80 = HEAP32[$3>>2]|0;
       $81 = ($80|0)==(0);
       if ($81) {
        break;
       }
       $82 = HEAP32[$37>>2]|0;
       $83 = ($82|0)==($76|0);
       if (!($83)) {
        break;
       }
      }
      $84 = (($74) + 20|0);
      $85 = ($84|0)==($18|0);
      if ($85) {
       $$lcssa21 = $128;$$lcssa24 = $129;
       label = 40;
       break L16;
      } else {
       $74 = $84;
      }
     }
     $73 = ($74|0)==($18|0);
     if ($73) {
      $$lcssa21 = $128;$$lcssa24 = $129;
      label = 40;
      break L16;
     } else {
      $39 = $74;$41 = $128;$42 = $127;$48 = $129;
     }
    }
    if ((label|0) == 36) {
     $86 = ___cxa_find_matching_catch()|0;
     $87 = tempRet0;
     $91 = $48;$lpad$phi$index = $86;$lpad$phi$index2 = $87;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3308,0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     $130 = $48;
     label = 37;
    } else {
     // unreachable;
    }
   }
  }
 } while(0);
 if ((label|0) == 40) {
  __ZNSt3__16__sortIRNS_4lessIiEEPiEEvT0_S5_T_($$lcssa24,$$lcssa21,$0);
  $92 = ($size|0)>(0);
  L54: do {
   if ($92) {
    $93 = $$lcssa21;
    $94 = $$lcssa24;
    $95 = (($93) - ($94))|0;
    $96 = $95 >> 2;
    $97 = ($96|0)==(0);
    if ($97) {
     $j$019$us = 0;
     while(1) {
      $98 = (($heapIDs) + ($j$019$us<<2)|0);
      $99 = ($$lcssa24|0)==($$lcssa21|0);
      if (!($99)) {
       $100 = HEAP32[$98>>2]|0;
       $101 = HEAP32[$$lcssa24>>2]|0;
       $not$$i$i$us = ($100|0)<($101|0);
       if (!($not$$i$i$us)) {
        HEAP32[$98>>2] = 0;
       }
      }
      $102 = (($j$019$us) + 1)|0;
      $exitcond34 = ($102|0)==($size|0);
      if ($exitcond34) {
       break L54;
      } else {
       $j$019$us = $102;
      }
     }
    } else {
     $j$019 = 0;
    }
    while(1) {
     $103 = (($heapIDs) + ($j$019<<2)|0);
     $104 = HEAP32[$103>>2]|0;
     $107 = $$lcssa24;$__len$03$i$i$i$i$i = $96;
     while(1) {
      $105 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
      $106 = (($107) + ($105<<2)|0);
      $108 = HEAP32[$106>>2]|0;
      $109 = ($108|0)<($104|0);
      if ($109) {
       $$sum$i$i$i$i$i = (($105) + 1)|0;
       $110 = (($107) + ($$sum$i$i$i$i$i<<2)|0);
       $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
       $111 = (($$neg2$i$i$i$i$i) - ($105))|0;
       $114 = $110;$__len$0$be$i$i$i$i$i = $111;
      } else {
       $114 = $107;$__len$0$be$i$i$i$i$i = $105;
      }
      $112 = ($__len$0$be$i$i$i$i$i|0)==(0);
      if ($112) {
       break;
      } else {
       $107 = $114;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
      }
     }
     $113 = ($114|0)==($$lcssa21|0);
     if (!($113)) {
      $115 = HEAP32[$103>>2]|0;
      $116 = HEAP32[$114>>2]|0;
      $not$$i$i = ($115|0)<($116|0);
      if (!($not$$i$i)) {
       HEAP32[$103>>2] = 0;
      }
     }
     $117 = (($j$019) + 1)|0;
     $exitcond = ($117|0)==($size|0);
     if ($exitcond) {
      break;
     } else {
      $j$019 = $117;
     }
    }
   }
  } while(0);
  __THREW__ = 0;
  $118 = __THREW__; __THREW__ = 0;
  $119 = $118&1;
  if ($119) {
   $130 = $$lcssa24;
   label = 37;
  } else {
   __THREW__ = 0;
   invoke_vii(3220,($heapIDs|0),($size|0));
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    $130 = $$lcssa24;
    label = 37;
   } else {
    __THREW__ = 0;
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if ($123) {
     $130 = $$lcssa24;
     label = 37;
    } else {
     $124 = ($$lcssa24|0)==(0|0);
     if ($124) {
      STACKTOP = sp;return;
     }
     __ZdlPv($$lcssa24);
     STACKTOP = sp;return;
    }
   }
  }
 }
 if ((label|0) == 37) {
  $88 = ___cxa_find_matching_catch()|0;
  $89 = tempRet0;
  $91 = $130;$lpad$phi$index = $88;$lpad$phi$index2 = $89;
 }
 $90 = ($91|0)==(0|0);
 if ($90) {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;
  ___resumeException($$index|0);
  // unreachable;
 }
 __ZdlPv($91);
 $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;
 ___resumeException($$index|0);
 // unreachable;
}
function __ZN17PersistentManager25PreallocateObjectThreadedEi($this,$instanceID) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 var $$0$lcssa$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01 = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$1 = 0, $$byval_copy = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $$sink$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $0 = sp + 32|0;
 $1 = sp;
 __THREW__ = 0;
 $2 = (invoke_ii(3304,($instanceID|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $$01 = $6;$$sink$index2 = $7;
  ___resumeException($$01|0);
  // unreachable;
 }
 $5 = ($2|0)==(0|0);
 if (!($5)) {
  $$1 = $2;
  STACKTOP = sp;return ($$1|0);
 }
 HEAP32[$0>>2] = $instanceID;
 $8 = (($this) + 156|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 100|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 do {
  if ($12) {
   $13 = (($this) + 148|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($this) + 152|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + (($16*20)|0)|0);
   $28 = $14;$29 = $16;$31 = $17;
  } else {
   $18 = (($this) + 96|0);
   __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($$byval_copy,$18,$0);
   $19 = HEAP32[$$byval_copy>>2]|0;
   $20 = ($19|0)==(-1);
   $21 = (($this) + 148|0);
   $22 = HEAP32[$21>>2]|0;
   if ($20) {
    $23 = (($this) + 152|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($22) + (($24*20)|0)|0);
    $28 = $22;$29 = $24;$31 = $25;
    break;
   } else {
    $26 = (($22) + (($19*20)|0)|0);
    $$phi$trans$insert$i = (($this) + 152|0);
    $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $28 = $22;$29 = $$pre$i;$31 = $26;
    break;
   }
  }
 } while(0);
 $27 = (($28) + (($29*20)|0)|0);
 $30 = ($31|0)==($27|0);
 if (!($30)) {
  $32 = (($31) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if (!($34)) {
   $$1 = $33;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $35 = (($this) + 44|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 36|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(-1);
 if ($39) {
  label = 15;
 } else {
  $40 = (($36) + 28|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)>($instanceID|0);
  if ($42) {
   label = 15;
  } else {
   $43 = (($36) + 32|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)<($instanceID|0);
   if ($45) {
    label = 15;
   } else {
    $46 = (($instanceID) - ($41))|0;
    $47 = (($46|0) / 2)&-1;
    $48 = ($47|0)<(0);
    $49 = $48 << 31 >> 31;
    $115 = 0;$81 = $38;$87 = $47;$88 = $49;
   }
  }
 }
 do {
  if ((label|0) == 15) {
   $50 = (($36) + 16|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($36) + 16|0);
   $53 = ($51|0)==(0|0);
   if ($53) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   } else {
    $$0$ph7$i$i$i$i = $52;$$01$ph6$i$in$i$i$i = $51;
   }
   L27: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $54 = (($$013$i$in$i$i$i) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)<($instanceID|0);
     if (!($56)) {
      break;
     }
     $59 = (($$013$i$in$i$i$i) + 4|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==(0|0);
     if ($61) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L27;
     } else {
      $$013$i$in$i$i$i = $60;
     }
    }
    $57 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $58 = ($57|0)==(0|0);
    if ($58) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $57;
    }
   }
   $62 = ($$0$ph5$i$i$i$i|0)==($52|0);
   if ($62) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $63 = (($$0$ph5$i$i$i$i) + 16|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)>($instanceID|0);
   if ($65) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   } else {
    $66 = (($$0$ph5$i$i$i$i) + 24|0);
    $67 = (($$0$ph5$i$i$i$i) + 24|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + 4|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($$0$ph5$i$i$i$i) + 32|0);
    $72 = $71;
    $73 = $72;
    $74 = HEAP32[$73>>2]|0;
    $75 = (($72) + 4)|0;
    $76 = $75;
    $77 = HEAP32[$76>>2]|0;
    $115 = $70;$81 = $68;$87 = $74;$88 = $77;
    break;
   }
  }
 } while(0);
 $80 = ($81|0)==(-1);
 if ($80) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 __THREW__ = 0;
 $82 = (invoke_iii(2446,($this|0),($81|0))|0);
 $83 = __THREW__; __THREW__ = 0;
 $84 = $83&1;
 if (!($84)) {
  $85 = HEAP32[$82>>2]|0;
  $86 = ($85|0)==(0|0);
  if ($86) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  __THREW__ = 0;
  $89 = (invoke_iiii(1561,($85|0),($87|0),($88|0))|0);
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if (!($91)) {
   if (!($89)) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $92 = (($82) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0|0);
   L53: do {
    if (!($94)) {
     $95 = HEAP32[$93>>2]|0;
     $96 = (($93) + 8|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = (($95) + ($97<<3)|0);
     $99 = ($97|0)==(0);
     L55: do {
      if ($99) {
       $$0$lcssa$i$i$i = $95;
      } else {
       $$01$i$i$i = $95;
       while(1) {
        $102 = $$01$i$i$i;
        $103 = $102;
        $104 = HEAP32[$103>>2]|0;
        $105 = (($102) + 4)|0;
        $106 = $105;
        $107 = HEAP32[$106>>2]|0;
        $108 = ($104|0)==($87|0);
        $109 = ($107|0)==($88|0);
        $110 = $108 & $109;
        $101 = (($$01$i$i$i) + 8|0);
        if ($110) {
         $$0$lcssa$i$i$i = $$01$i$i$i;
         break L55;
        }
        $100 = ($101|0)==($98|0);
        if ($100) {
         break L53;
        } else {
         $$01$i$i$i = $101;
        }
       }
      }
     } while(0);
     $111 = ($$0$lcssa$i$i$i|0)==($98|0);
     if (!($111)) {
      $$1 = 0;
      STACKTOP = sp;return ($$1|0);
     }
    }
   } while(0);
   $112 = HEAP32[$82>>2]|0;
   $113 = ($112|0)==(0|0);
   if ($113) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   HEAP32[$1>>2] = $81;
   $114 = (($1) + 4|0);
   HEAP32[$114>>2] = $115;
   $116 = (($1) + 8|0);
   $117 = $116;
   $118 = $117;
   HEAP32[$118>>2] = $87;
   $119 = (($117) + 4)|0;
   $120 = $119;
   HEAP32[$120>>2] = $88;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
   $121 = (invoke_iiiiii(203,($this|0),($112|0),($$byval_copy|0),($instanceID|0),0)|0);
   $122 = __THREW__; __THREW__ = 0;
   $123 = $122&1;
   if (!($123)) {
    $124 = ($121|0)==(0|0);
    if ($124) {
     $$1 = 0;
     STACKTOP = sp;return ($$1|0);
    }
    $125 = (($121) + 8|0);
    $126 = HEAP32[$125>>2]|0;
    $$1 = $126;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $78 = ___cxa_find_matching_catch()|0;
 $79 = tempRet0;
 $$01 = $78;$$sink$index2 = $79;
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __ZN17PersistentManager19LoadObjectsThreadedEPiiR12LoadProgress($this,$heapIDs,$size,$loadProgress) {
 $this = $this|0;
 $heapIDs = $heapIDs|0;
 $size = $size|0;
 $loadProgress = $loadProgress|0;
 var $$0$lcssa$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0);
 var $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i3 = 0, $didTypeTreeChange = 0, $heapIDsCopy = 0, $i$020 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $oldType = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 16|0;
 $0 = sp + 48|0;
 $heapIDsCopy = sp + 32|0;
 $1 = sp;
 $oldType = sp + 44|0;
 $didTypeTreeChange = sp + 52|0;
 $2 = ($size|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$heapIDsCopy>>2] = 0;
 $3 = (($heapIDsCopy) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($heapIDsCopy) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($heapIDs) + ($size<<2)|0);
 __THREW__ = 0;
 invoke_viii(1921,($heapIDsCopy|0),($heapIDs|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L4: do {
  if ($7) {
   label = 12;
  } else {
   $8 = HEAP32[$heapIDsCopy>>2]|0;
   __THREW__ = 0;
   invoke_viii(1922,($this|0),($8|0),($size|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 12;
   } else {
    $11 = ($size|0)>(0);
    L7: do {
     if ($11) {
      $12 = (($loadProgress) + 8|0);
      $13 = (($loadProgress) + 12|0);
      $14 = (($this) + 44|0);
      $15 = (($1) + 4|0);
      $16 = (($1) + 8|0);
      $17 = (($this) + 68|0);
      $18 = (($this) + 156|0);
      $19 = (($this) + 100|0);
      $20 = (($this) + 148|0);
      $21 = (($this) + 152|0);
      $22 = (($loadProgress) + 20|0);
      $23 = (($loadProgress) + 16|0);
      $24 = (($this) + 96|0);
      $25 = (($loadProgress) + 4|0);
      $183 = $8;$184 = 0;$i$020 = 0;
      L9: while(1) {
       $26 = Math_fround(HEAPF32[$13>>2]);
       $27 = Math_fround($26 + Math_fround(1.0));
       $28 = Math_fround(HEAPF32[$12>>2]);
       $29 = $27 < $28;
       $30 = $29 ? $27 : $28;
       HEAPF32[$13>>2] = $30;
       $31 = HEAP32[$loadProgress>>2]|0;
       $32 = ($31|0)==(0|0);
       if ($32) {
        $39 = $183;
       } else {
        $33 = $28 == Math_fround(0.0);
        if ($33) {
         $37 = Math_fround(1.0);
        } else {
         $34 = Math_fround(HEAPF32[$25>>2]);
         $35 = Math_fround($30 * $34);
         $36 = Math_fround($35 / $28);
         $37 = $36;
        }
        HEAPF32[$31>>2] = $37;
        $$pre = HEAP32[$heapIDsCopy>>2]|0;
        $39 = $$pre;
       }
       $38 = (($39) + ($i$020<<2)|0);
       $40 = HEAP32[$38>>2]|0;
       $41 = ($40|0)==(0);
       L17: do {
        if ($41) {
         $185 = $184;
        } else {
         $53 = HEAP32[$14>>2]|0;
         $54 = (($53) + 36|0);
         $55 = HEAP32[$54>>2]|0;
         $56 = ($55|0)==(-1);
         if ($56) {
          label = 21;
         } else {
          $57 = (($53) + 28|0);
          $58 = HEAP32[$57>>2]|0;
          $59 = ($58|0)>($40|0);
          if ($59) {
           label = 21;
          } else {
           $60 = (($53) + 32|0);
           $61 = HEAP32[$60>>2]|0;
           $62 = ($61|0)<($40|0);
           if ($62) {
            label = 21;
           } else {
            $63 = (($40) - ($58))|0;
            $64 = (($63|0) / 2)&-1;
            $65 = ($64|0)<(0);
            $66 = $65 << 31 >> 31;
            $102 = $64;$103 = $66;$129 = $184;$96 = $55;
           }
          }
         }
         if ((label|0) == 21) {
          label = 0;
          $67 = (($53) + 16|0);
          $68 = HEAP32[$67>>2]|0;
          $69 = (($53) + 16|0);
          $70 = ($68|0)==(0|0);
          if ($70) {
           $185 = $184;
           break;
          } else {
           $$0$ph7$i$i$i$i = $69;$$01$ph6$i$in$i$i$i = $68;
          }
          L25: while(1) {
           $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
           while(1) {
            $71 = (($$013$i$in$i$i$i) + 16|0);
            $72 = HEAP32[$71>>2]|0;
            $73 = ($72|0)<($40|0);
            if (!($73)) {
             break;
            }
            $76 = (($$013$i$in$i$i$i) + 4|0);
            $77 = HEAP32[$76>>2]|0;
            $78 = ($77|0)==(0|0);
            if ($78) {
             $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
             break L25;
            } else {
             $$013$i$in$i$i$i = $77;
            }
           }
           $74 = HEAP32[$$013$i$in$i$i$i>>2]|0;
           $75 = ($74|0)==(0|0);
           if ($75) {
            $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
            break;
           } else {
            $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $74;
           }
          }
          $79 = ($$0$ph5$i$i$i$i|0)==($69|0);
          if ($79) {
           $185 = $184;
           break;
          }
          $80 = (($$0$ph5$i$i$i$i) + 16|0);
          $81 = HEAP32[$80>>2]|0;
          $82 = ($81|0)>($40|0);
          if ($82) {
           $185 = $184;
           break;
          }
          $83 = (($$0$ph5$i$i$i$i) + 24|0);
          $84 = (($$0$ph5$i$i$i$i) + 24|0);
          $85 = HEAP32[$84>>2]|0;
          $86 = (($83) + 4|0);
          $87 = HEAP32[$86>>2]|0;
          $88 = (($$0$ph5$i$i$i$i) + 32|0);
          $89 = $88;
          $90 = $89;
          $91 = HEAP32[$90>>2]|0;
          $92 = (($89) + 4)|0;
          $93 = $92;
          $94 = HEAP32[$93>>2]|0;
          $102 = $91;$103 = $94;$129 = $87;$96 = $85;
         }
         $95 = ($96|0)==(-1);
         if ($95) {
          $185 = $129;
         } else {
          __THREW__ = 0;
          $97 = (invoke_iii(2446,($this|0),($96|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break L9;
          }
          $100 = HEAP32[$97>>2]|0;
          $101 = ($100|0)==(0|0);
          if ($101) {
           $185 = $129;
          } else {
           __THREW__ = 0;
           $104 = (invoke_iiii(1561,($100|0),($102|0),($103|0))|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            break L9;
           }
           if ($104) {
            $107 = (($97) + 16|0);
            $108 = HEAP32[$107>>2]|0;
            $109 = ($108|0)==(0|0);
            L40: do {
             if (!($109)) {
              $110 = HEAP32[$108>>2]|0;
              $111 = (($108) + 8|0);
              $112 = HEAP32[$111>>2]|0;
              $113 = (($110) + ($112<<3)|0);
              $114 = ($112|0)==(0);
              L42: do {
               if ($114) {
                $$0$lcssa$i$i$i = $110;
               } else {
                $$01$i$i$i = $110;
                while(1) {
                 $117 = $$01$i$i$i;
                 $118 = $117;
                 $119 = HEAP32[$118>>2]|0;
                 $120 = (($117) + 4)|0;
                 $121 = $120;
                 $122 = HEAP32[$121>>2]|0;
                 $123 = ($119|0)==($102|0);
                 $124 = ($122|0)==($103|0);
                 $125 = $123 & $124;
                 $116 = (($$01$i$i$i) + 8|0);
                 if ($125) {
                  $$0$lcssa$i$i$i = $$01$i$i$i;
                  break L42;
                 }
                 $115 = ($116|0)==($113|0);
                 if ($115) {
                  break L40;
                 } else {
                  $$01$i$i$i = $116;
                 }
                }
               }
              } while(0);
              $126 = ($$0$lcssa$i$i$i|0)==($113|0);
              if (!($126)) {
               $185 = $129;
               break L17;
              }
             }
            } while(0);
            $127 = HEAP32[$97>>2]|0;
            $128 = ($127|0)==(0|0);
            if ($128) {
             $185 = $129;
            } else {
             HEAP32[$1>>2] = $96;
             HEAP32[$15>>2] = $129;
             $130 = $16;
             $131 = $130;
             HEAP32[$131>>2] = $102;
             $132 = (($130) + 4)|0;
             $133 = $132;
             HEAP32[$133>>2] = $103;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
             $134 = (invoke_iiiiii(203,($this|0),($127|0),($$byval_copy|0),($40|0),1)|0);
             $135 = __THREW__; __THREW__ = 0;
             $136 = $135&1;
             if ($136) {
              break L9;
             }
             $137 = ($134|0)==(0|0);
             if ($137) {
              $185 = $129;
             } else {
              HEAP32[$17>>2] = $96;
              $138 = (($134) + 8|0);
              $139 = HEAP32[$138>>2]|0;
              __THREW__ = 0;
              invoke_viiiiiiii(28,($127|0),($102|0),($103|0),1,1,($oldType|0),($didTypeTreeChange|0),($139|0));
              $140 = __THREW__; __THREW__ = 0;
              $141 = $140&1;
              if ($141) {
               break L9;
              }
              $142 = HEAP32[$oldType>>2]|0;
              $143 = HEAP8[$didTypeTreeChange>>0]|0;
              HEAP32[$0>>2] = $40;
              $144 = HEAP32[$18>>2]|0;
              $145 = HEAP32[$19>>2]|0;
              $146 = ($144|0)==($145|0);
              do {
               if ($146) {
                $147 = HEAP32[$20>>2]|0;
                $148 = HEAP32[$21>>2]|0;
                $149 = (($147) + (($148*20)|0)|0);
                $157 = $149;
               } else {
                __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($$byval_copy,$24,$0);
                $150 = HEAP32[$$byval_copy>>2]|0;
                $151 = ($150|0)==(-1);
                $152 = HEAP32[$20>>2]|0;
                if ($151) {
                 $153 = HEAP32[$21>>2]|0;
                 $154 = (($152) + (($153*20)|0)|0);
                 $157 = $154;
                 break;
                } else {
                 $155 = (($152) + (($150*20)|0)|0);
                 $157 = $155;
                 break;
                }
               }
              } while(0);
              $156 = (($157) + 12|0);
              $158 = HEAP32[$156>>2]|0;
              $159 = HEAP32[$158>>2]|0;
              $160 = (($159) + 16|0);
              $161 = HEAP32[$160>>2]|0;
              __THREW__ = 0;
              invoke_vi($161|0,($158|0));
              $162 = __THREW__; __THREW__ = 0;
              $163 = $162&1;
              if ($163) {
               break L9;
              }
              $164 = (($157) + 8|0);
              HEAP32[$164>>2] = $142;
              $165 = (($157) + 16|0);
              HEAP8[$165>>0] = $143;
              $166 = (($157) + 17|0);
              HEAP8[$166>>0] = 1;
              HEAP32[$17>>2] = -1;
              $167 = HEAP32[$22>>2]|0;
              $168 = ($167|0)==(0|0);
              if ($168) {
               $185 = $129;
               break;
              }
              $169 = HEAP32[$23>>2]|0;
              __THREW__ = 0;
              invoke_vii($167|0,($139|0),($169|0));
              $170 = __THREW__; __THREW__ = 0;
              $171 = $170&1;
              if ($171) {
               break L9;
              } else {
               $185 = $129;
              }
             }
            }
           } else {
            $185 = $129;
           }
          }
         }
        }
       } while(0);
       $172 = (($i$020) + 1)|0;
       $173 = ($172|0)<($size|0);
       if ($173) {
        $183 = $39;$184 = $185;$i$020 = $172;
       } else {
        $177 = $39;
        break L7;
       }
      }
      $42 = ___cxa_find_matching_catch()|0;
      $43 = tempRet0;
      $47 = $39;$lpad$phi$index = $42;$lpad$phi$index2 = $43;
      break L4;
     } else {
      $177 = $8;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vi(3562,($this|0));
    $174 = __THREW__; __THREW__ = 0;
    $175 = $174&1;
    if ($175) {
     label = 12;
    } else {
     $176 = ($177|0)==(0|0);
     if ($176) {
      STACKTOP = sp;return;
     }
     $178 = HEAP32[$3>>2]|0;
     $179 = ($178|0)==($177|0);
     if (!($179)) {
      $__new_last2$i$i$i$i$i = $177;
      $scevgep$i$i$i$i$i = (($178) + -4|0);
      $180 = (0 - ($__new_last2$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($180)|0);
      $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
      $181 = $uglygep3$i$i$i$i$i >>> 2;
      $182 = $181 ^ -1;
      $scevgep4$i$i$i$i$i = (($178) + ($182<<2)|0);
      HEAP32[$3>>2] = $scevgep4$i$i$i$i$i;
     }
     __ZdlPv($177);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $$pre25 = HEAP32[$heapIDsCopy>>2]|0;
  $47 = $$pre25;$lpad$phi$index = $44;$lpad$phi$index2 = $45;
 }
 $46 = ($47|0)==(0|0);
 if ($46) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $48 = HEAP32[$3>>2]|0;
 $49 = ($48|0)==($47|0);
 if (!($49)) {
  $__new_last2$i$i$i$i$i3 = $47;
  $scevgep$i$i$i$i$i4 = (($48) + -4|0);
  $50 = (0 - ($__new_last2$i$i$i$i$i3))|0;
  $uglygep$i$i$i$i$i6 = (($scevgep$i$i$i$i$i4) + ($50)|0);
  $uglygep3$i$i$i$i$i7 = $uglygep$i$i$i$i$i6;
  $51 = $uglygep3$i$i$i$i$i7 >>> 2;
  $52 = $51 ^ -1;
  $scevgep4$i$i$i$i$i8 = (($48) + ($52<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i8;
 }
 __ZdlPv($47);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN17PersistentManager34ExtractTimeSliceAwakeFromLoadQueueER27TimeSliceAwakeFromLoadQueue($this,$queue) {
 $this = $this|0;
 $queue = $queue|0;
 var $$ph1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + (($4*20)|0)|0);
 $6 = ($4|0)==(0);
 L1: do {
  if ($6) {
   $$ph1 = $2;
  } else {
   $7 = (($this) + 128|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 104|0);
   $10 = (($this) + 100|0);
   $11 = (($this) + 108|0);
   $13 = $2;
   while(1) {
    $12 = HEAP32[$13>>2]|0;
    $14 = ($8|0)==($12|0);
    if (!($14)) {
     $15 = HEAP8[$9>>0]|0;
     $16 = ($15<<24>>24)==(0);
     if ($16) {
      $$ph1 = $13;
      break L1;
     }
     $17 = HEAP32[$10>>2]|0;
     $18 = ($17|0)==(0);
     if ($18) {
      $$ph1 = $13;
      break L1;
     }
     $19 = HEAP32[$11>>2]|0;
     $20 = ($19|0)==($12|0);
     if (!($20)) {
      $$ph1 = $13;
      break L1;
     }
    }
    $21 = (($13) + 20|0);
    $22 = ($21|0)==($5|0);
    if ($22) {
     break;
    } else {
     $13 = $21;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = ($$ph1|0)==($5|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 128|0);
 $25 = (($this) + 104|0);
 $26 = (($this) + 100|0);
 $27 = (($this) + 108|0);
 $29 = $$ph1;
 L15: while(1) {
  $28 = HEAP32[$29>>2]|0;
  HEAP32[$0>>2] = $28;
  (__ZN19RingbufferTemplates17WriteToRingBufferIi17GrowingRingbufferEEbRT0_RKT_($queue,$0)|0);
  $30 = (($29) + 20|0);
  $31 = ($30|0)==($5|0);
  if ($31) {
   label = 18;
   break;
  }
  $34 = HEAP32[$24>>2]|0;
  $33 = $30;
  while(1) {
   $35 = HEAP32[$33>>2]|0;
   $36 = ($34|0)==($35|0);
   if (!($36)) {
    $37 = HEAP8[$25>>0]|0;
    $38 = ($37<<24>>24)==(0);
    if ($38) {
     break;
    }
    $39 = HEAP32[$26>>2]|0;
    $40 = ($39|0)==(0);
    if ($40) {
     break;
    }
    $41 = HEAP32[$27>>2]|0;
    $42 = ($41|0)==($35|0);
    if (!($42)) {
     break;
    }
   }
   $43 = (($33) + 20|0);
   $44 = ($43|0)==($5|0);
   if ($44) {
    label = 18;
    break L15;
   } else {
    $33 = $43;
   }
  }
  $32 = ($33|0)==($5|0);
  if ($32) {
   label = 18;
   break;
  } else {
   $29 = $33;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return;
 }
}
function __ZN17PersistentManager26LoadFileCompletelyThreadedERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPxPiibR12LoadProgress($this,$pathname,$fileIDs,$instanceIDs,$size,$loadScene,$loadProgress) {
 $this = $this|0;
 $pathname = $pathname|0;
 $fileIDs = $fileIDs|0;
 $instanceIDs = $instanceIDs|0;
 $size = $size|0;
 $loadScene = $loadScene|0;
 $loadProgress = $loadProgress|0;
 var $$0 = 0, $$0$i21 = 0, $$01 = 0, $$01$i$i = 0, $$02 = 0, $$03 = 0, $$04 = 0, $$05 = 0, $$1 = 0, $$16 = 0, $$byval_copy12 = 0, $$ph$ph = 0, $$ph30$ph = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0);
 var $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $didTypeTreeChange = 0, $exitcond = 0, $exitcond46 = 0, $fileIDsVector = 0, $i$036 = 0, $i1$033 = 0, $i2$043 = 0, $i4$031 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $oldType = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy12 = sp;
 $0 = sp + 128|0;
 $1 = sp + 16|0;
 $2 = sp + 120|0;
 $3 = sp + 56|0;
 $4 = sp + 116|0;
 $5 = sp + 112|0;
 $6 = sp + 100|0;
 $7 = sp + 104|0;
 $8 = sp + 96|0;
 $fileIDsVector = sp + 80|0;
 $9 = sp + 40|0;
 $oldType = sp + 108|0;
 $didTypeTreeChange = sp + 136|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 $13 = (invoke_iiii($12|0,($this|0),($pathname|0),1)|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 L1: do {
  if (!($15)) {
   $16 = ($13|0)==(-1);
   if ($16) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $17 = (invoke_iii(2446,($this|0),($13|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP32[$17>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $24 = HEAP32[628512>>2]|0;
    HEAP32[$fileIDsVector>>2] = 0;
    $25 = (($fileIDsVector) + 4|0);
    HEAP32[$25>>2] = $24;
    $26 = (($fileIDsVector) + 8|0);
    HEAP32[$26>>2] = 0;
    $27 = (($fileIDsVector) + 12|0);
    HEAP32[$27>>2] = 0;
    $28 = ($size|0)==(-1);
    do {
     if ($28) {
      __THREW__ = 0;
      invoke_viii(1923,($this|0),($pathname|0),($fileIDsVector|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       $31 = ___cxa_find_matching_catch()|0;
       $32 = tempRet0;
       $268 = $32;$269 = $31;$58 = 0;
       label = 20;
       break;
      }
      $33 = HEAP32[$fileIDsVector>>2]|0;
      $34 = HEAP32[$26>>2]|0;
      $35 = (Math_fround(($34|0)));
      $36 = (($loadProgress) + 8|0);
      $37 = Math_fround(HEAPF32[$36>>2]);
      $38 = Math_fround($37 + $35);
      HEAPF32[$36>>2] = $38;
      $39 = ($34|0)==(0);
      if ($39) {
       $$01 = $33;$$02 = 0;$$03 = 0;$250 = 0;$251 = 0;
       label = 21;
      } else {
       $40 = $34 << 2;
       HEAP32[$6>>2] = $24;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$6+0>>2]|0;
       $41 = (invoke_iiiiiiii(108,(0|0),($40|0),4,($$byval_copy12|0),0,(638872|0),370)|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        $$ph$ph = $34;$$ph30$ph = 0;
        label = 18;
       } else {
        $44 = (($41) + ($34<<2)|0);
        $$01$i$i = $41;
        while(1) {
         $45 = ($$01$i$i|0)==(0|0);
         if (!($45)) {
          HEAP32[$$01$i$i>>2] = 0;
         }
         $46 = (($$01$i$i) + 4|0);
         $47 = ($46|0)==($44|0);
         if ($47) {
          $$01 = $33;$$02 = $41;$$03 = $34;$250 = $34;$251 = $41;
          label = 21;
          break;
         } else {
          $$01$i$i = $46;
         }
        }
       }
      }
     } else {
      $$01 = $fileIDs;$$02 = $instanceIDs;$$03 = $size;$250 = 0;$251 = 0;
      label = 21;
     }
    } while(0);
    L22: do {
     if ((label|0) == 21) {
      $61 = ($$03|0)>(0);
      L24: do {
       if ($loadScene) {
        if ($61) {
         $76 = 0;$79 = 0;$i$036 = 0;
         while(1) {
          $68 = (($$01) + ($i$036<<3)|0);
          $69 = $68;
          $70 = $69;
          $71 = HEAP32[$70>>2]|0;
          $72 = (($69) + 4)|0;
          $73 = $72;
          $74 = HEAP32[$73>>2]|0;
          $75 = ($76|0)<($74|0);
          $77 = ($76|0)==($74|0);
          $78 = ($79>>>0)<($71>>>0);
          $80 = $77 & $78;
          $81 = $75 | $80;
          $82 = $81 ? $71 : $79;
          $83 = $81 ? $74 : $76;
          $84 = (($i$036) + 1)|0;
          $exitcond46 = ($84|0)==($$03|0);
          if ($exitcond46) {
           break;
          } else {
           $76 = $83;$79 = $82;$i$036 = $84;
          }
         }
         $85 = (_bitshift64Shl(($82|0),($83|0),1)|0);
         $86 = tempRet0;
         $93 = $85;$94 = $86;
        } else {
         $93 = 0;$94 = 0;
        }
        $87 = (($this) + 44|0);
        $88 = HEAP32[$87>>2]|0;
        $89 = (($88) + 24|0);
        $90 = HEAP32[$89>>2]|0;
        $91 = (($90) + 2)|0;
        $92 = (($88) + 28|0);
        HEAP32[$92>>2] = $91;
        $95 = (_i64Add(($91|0),0,($93|0),($94|0))|0);
        $96 = tempRet0;
        HEAP32[$89>>2] = $95;
        $97 = (($88) + 32|0);
        HEAP32[$97>>2] = $95;
        $98 = (($88) + 36|0);
        HEAP32[$98>>2] = $13;
        if ($61) {
         $109 = $91;$i1$033 = 0;
        } else {
         $99 = (($this) + 68|0);
         HEAP32[$99>>2] = $13;
         $241 = $99;
         break;
        }
        while(1) {
         $100 = (($$01) + ($i1$033<<3)|0);
         $101 = $100;
         $102 = $101;
         $103 = HEAP32[$102>>2]|0;
         $104 = (($101) + 4)|0;
         $105 = $104;
         $106 = HEAP32[$105>>2]|0;
         $107 = (_bitshift64Shl(($103|0),($106|0),1)|0);
         $108 = tempRet0;
         $110 = (_i64Add(($109|0),0,($107|0),($108|0))|0);
         $111 = tempRet0;
         $112 = (($$02) + ($i1$033<<2)|0);
         HEAP32[$112>>2] = $110;
         $113 = (($i1$033) + 1)|0;
         $exitcond = ($113|0)==($$03|0);
         if ($exitcond) {
          label = 39;
          break L24;
         }
         $$pre = HEAP32[$92>>2]|0;
         $109 = $$pre;$i1$033 = $113;
        }
       } else {
        L26: do {
         if ($61) {
          $62 = (($this) + 44|0);
          $63 = (($1) + 8|0);
          $64 = (($1) + 16|0);
          $65 = (($0) + 4|0);
          $66 = (($3) + 8|0);
          $67 = (($3) + 16|0);
          $i2$043 = 0;
          L28: while(1) {
           $114 = (($$01) + ($i2$043<<3)|0);
           $115 = $114;
           $116 = $115;
           $117 = HEAP32[$116>>2]|0;
           $118 = (($115) + 4)|0;
           $119 = $118;
           $120 = HEAP32[$119>>2]|0;
           $121 = HEAP32[$62>>2]|0;
           $122 = (($121) + 36|0);
           $123 = HEAP32[$122>>2]|0;
           $124 = ($123|0)!=(-1);
           $125 = ($123|0)==($13|0);
           $or$cond$i = $124 & $125;
           do {
            if ($or$cond$i) {
             $126 = (_bitshift64Shl(($117|0),($120|0),1)|0);
             $127 = tempRet0;
             $128 = (($121) + 28|0);
             $129 = HEAP32[$128>>2]|0;
             $130 = (_i64Add(($129|0),0,($126|0),($127|0))|0);
             $131 = tempRet0;
             $$0$i21 = $130;
            } else {
             HEAP32[$1>>2] = $13;
             $132 = $63;
             $133 = $132;
             HEAP32[$133>>2] = $117;
             $134 = (($132) + 4)|0;
             $135 = $134;
             HEAP32[$135>>2] = $120;
             HEAP32[$64>>2] = 0;
             __THREW__ = 0;
             invoke_viii(1924,($0|0),($121|0),($1|0));
             $136 = __THREW__; __THREW__ = 0;
             $137 = $136&1;
             if ($137) {
              break L28;
             }
             $138 = HEAP32[$0>>2]|0;
             $139 = HEAP8[$65>>0]|0;
             $140 = ($139<<24>>24)==(0);
             if ($140) {
              $152 = (($138) + 32|0);
              $153 = HEAP32[$152>>2]|0;
              $$0$i21 = $153;
              break;
             } else {
              $141 = (($121) + 24|0);
              $142 = HEAP32[$141>>2]|0;
              $143 = (($142) + 2)|0;
              HEAP32[$141>>2] = $143;
              $144 = (($138) + 32|0);
              HEAP32[$144>>2] = $143;
              $145 = (($121) + 12|0);
              HEAP32[$3>>2] = $143;
              HEAP32[$66>>2] = $13;
              $146 = $67;
              $147 = $146;
              HEAP32[$147>>2] = $117;
              $148 = (($146) + 4)|0;
              $149 = $148;
              HEAP32[$149>>2] = $120;
              __THREW__ = 0;
              invoke_viii(1925,($2|0),($145|0),($3|0));
              $150 = __THREW__; __THREW__ = 0;
              $151 = $150&1;
              if ($151) {
               break L28;
              } else {
               $$0$i21 = $143;
               break;
              }
             }
            }
           } while(0);
           $154 = (($$02) + ($i2$043<<2)|0);
           HEAP32[$154>>2] = $$0$i21;
           $155 = (($i2$043) + 1)|0;
           $156 = ($155|0)<($$03|0);
           if ($156) {
            $i2$043 = $155;
           } else {
            break L26;
           }
          }
          $52 = ___cxa_find_matching_catch()|0;
          $53 = tempRet0;
          $270 = $251;$57 = $250;$lpad$phi$index = $52;$lpad$phi$index3 = $53;
          label = 19;
          break L22;
         }
        } while(0);
        __THREW__ = 0;
        invoke_viii(1922,($this|0),($$02|0),($$03|0));
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         $$ph$ph = $250;$$ph30$ph = $251;
         label = 18;
         break L22;
        } else {
         label = 39;
        }
       }
      } while(0);
      L51: do {
       if ((label|0) == 39) {
        $159 = (($this) + 68|0);
        HEAP32[$159>>2] = $13;
        $160 = ($$03|0)>(0);
        if ($160) {
         $161 = (($loadProgress) + 8|0);
         $162 = (($loadProgress) + 12|0);
         $163 = (($9) + 8|0);
         $164 = $loadScene ^ 1;
         $165 = (($this) + 156|0);
         $166 = (($this) + 100|0);
         $167 = (($this) + 148|0);
         $168 = (($this) + 152|0);
         $169 = (($loadProgress) + 20|0);
         $170 = (($loadProgress) + 16|0);
         $171 = (($this) + 96|0);
         $172 = (($loadProgress) + 4|0);
         $i4$031 = 0;
         while(1) {
          $173 = Math_fround(HEAPF32[$162>>2]);
          $174 = Math_fround($173 + Math_fround(1.0));
          $175 = Math_fround(HEAPF32[$161>>2]);
          $176 = $174 < $175;
          $177 = $176 ? $174 : $175;
          HEAPF32[$162>>2] = $177;
          $178 = HEAP32[$loadProgress>>2]|0;
          $179 = ($178|0)==(0|0);
          if (!($179)) {
           $180 = $175 == Math_fround(0.0);
           if ($180) {
            $184 = Math_fround(1.0);
           } else {
            $181 = Math_fround(HEAPF32[$172>>2]);
            $182 = Math_fround($177 * $181);
            $183 = Math_fround($182 / $175);
            $184 = $183;
           }
           HEAPF32[$178>>2] = $184;
          }
          $185 = (($$02) + ($i4$031<<2)|0);
          $186 = HEAP32[$185>>2]|0;
          $187 = ($186|0)==(0);
          if (!($187)) {
           $188 = (($$01) + ($i4$031<<3)|0);
           $189 = $188;
           $190 = $189;
           $191 = HEAP32[$190>>2]|0;
           $192 = (($189) + 4)|0;
           $193 = $192;
           $194 = HEAP32[$193>>2]|0;
           $195 = (_bitshift64Ashr(0,($191|0),32)|0);
           $196 = tempRet0;
           HEAP32[$9>>2] = $13;
           $197 = $163;
           $198 = $197;
           HEAP32[$198>>2] = $195;
           $199 = (($197) + 4)|0;
           $200 = $199;
           HEAP32[$200>>2] = $196;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$$byval_copy12+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$$byval_copy12+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$$byval_copy12+12>>2]=HEAP32[$9+12>>2]|0;
           $201 = (invoke_iiiiii(203,($this|0),($20|0),($$byval_copy12|0),($186|0),1)|0);
           $202 = __THREW__; __THREW__ = 0;
           $203 = $202&1;
           if ($203) {
            break;
           }
           $204 = ($201|0)==(0|0);
           if (!($204)) {
            $205 = (($201) + 8|0);
            $206 = HEAP32[$205>>2]|0;
            __THREW__ = 0;
            invoke_viiiiiiii(28,($20|0),($195|0),($196|0),1,($164|0),($oldType|0),($didTypeTreeChange|0),($206|0));
            $207 = __THREW__; __THREW__ = 0;
            $208 = $207&1;
            if ($208) {
             break;
            }
            $209 = HEAP32[$oldType>>2]|0;
            $210 = HEAP8[$didTypeTreeChange>>0]|0;
            HEAP32[$4>>2] = $186;
            $211 = HEAP32[$165>>2]|0;
            $212 = HEAP32[$166>>2]|0;
            $213 = ($211|0)==($212|0);
            do {
             if ($213) {
              $214 = HEAP32[$167>>2]|0;
              $215 = HEAP32[$168>>2]|0;
              $216 = (($214) + (($215*20)|0)|0);
              $224 = $216;
             } else {
              __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($$byval_copy12,$171,$4);
              $217 = HEAP32[$$byval_copy12>>2]|0;
              $218 = ($217|0)==(-1);
              $219 = HEAP32[$167>>2]|0;
              if ($218) {
               $220 = HEAP32[$168>>2]|0;
               $221 = (($219) + (($220*20)|0)|0);
               $224 = $221;
               break;
              } else {
               $222 = (($219) + (($217*20)|0)|0);
               $224 = $222;
               break;
              }
             }
            } while(0);
            $223 = (($224) + 12|0);
            $225 = HEAP32[$223>>2]|0;
            $226 = HEAP32[$225>>2]|0;
            $227 = (($226) + 16|0);
            $228 = HEAP32[$227>>2]|0;
            __THREW__ = 0;
            invoke_vi($228|0,($225|0));
            $229 = __THREW__; __THREW__ = 0;
            $230 = $229&1;
            if ($230) {
             break;
            }
            $231 = (($224) + 8|0);
            HEAP32[$231>>2] = $209;
            $232 = (($224) + 16|0);
            HEAP8[$232>>0] = $210;
            $233 = (($224) + 17|0);
            HEAP8[$233>>0] = 1;
            $234 = HEAP32[$169>>2]|0;
            $235 = ($234|0)==(0|0);
            if (!($235)) {
             $236 = HEAP32[$170>>2]|0;
             __THREW__ = 0;
             invoke_vii($234|0,($206|0),($236|0));
             $237 = __THREW__; __THREW__ = 0;
             $238 = $237&1;
             if ($238) {
              break;
             }
            }
           }
          }
          $239 = (($i4$031) + 1)|0;
          $240 = ($239|0)<($$03|0);
          if ($240) {
           $i4$031 = $239;
          } else {
           $241 = $159;
           break L51;
          }
         }
         $50 = ___cxa_find_matching_catch()|0;
         $51 = tempRet0;
         $270 = $251;$57 = $250;$lpad$phi$index = $50;$lpad$phi$index3 = $51;
         label = 19;
         break L22;
        } else {
         $241 = $159;
        }
       }
      } while(0);
      HEAP32[$241>>2] = -1;
      __THREW__ = 0;
      invoke_vi(3562,($this|0));
      $242 = __THREW__; __THREW__ = 0;
      $243 = $242&1;
      if ($243) {
       $$ph$ph = $250;$$ph30$ph = $251;
       label = 18;
      } else {
       if ($loadScene) {
        $244 = (($this) + 44|0);
        $245 = HEAP32[$244>>2]|0;
        $246 = (($245) + 28|0);
        HEAP32[$246>>2] = 0;
        $247 = (($245) + 32|0);
        HEAP32[$247>>2] = 0;
        $248 = (($245) + 36|0);
        HEAP32[$248>>2] = -1;
       }
       $249 = ($250|0)>(-1);
       if ($249) {
        HEAP32[$7>>2] = $24;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$7+0>>2]|0;
        invoke_vii(2591,($251|0),($$byval_copy12|0));
        $252 = __THREW__; __THREW__ = 0;
        $253 = $252&1;
        if ($253) {
         $48 = ___cxa_find_matching_catch()|0;
         $49 = tempRet0;
         $$04 = $48;$$05 = $49;
         break;
        }
       }
       $254 = HEAP32[$27>>2]|0;
       $255 = ($254|0)>(-1);
       if (!($255)) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       $256 = HEAP32[$fileIDsVector>>2]|0;
       $257 = HEAP32[$25>>2]|0;
       HEAP32[$8>>2] = $257;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$8+0>>2]|0;
       invoke_vii(2591,($256|0),($$byval_copy12|0));
       $258 = __THREW__; __THREW__ = 0;
       $259 = $258&1;
       if ($259) {
        break L1;
       }
       HEAP32[$fileIDsVector>>2] = 0;
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
    } while(0);
    if ((label|0) == 18) {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     $270 = $$ph30$ph;$57 = $$ph$ph;$lpad$phi$index = $54;$lpad$phi$index3 = $55;
     label = 19;
    }
    if ((label|0) == 19) {
     $56 = ($57|0)>(-1);
     if ($56) {
      $268 = $lpad$phi$index3;$269 = $lpad$phi$index;$58 = $270;
      label = 20;
     } else {
      $$04 = $lpad$phi$index;$$05 = $lpad$phi$index3;
     }
    }
    if ((label|0) == 20) {
     HEAP32[$5>>2] = $24;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($58|0),($$byval_copy12|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      $266 = ___cxa_find_matching_catch(0|0)|0;
      $267 = tempRet0;
      ___clang_call_terminate($266);
      // unreachable;
     } else {
      $$04 = $269;$$05 = $268;
     }
    }
    $260 = HEAP32[$27>>2]|0;
    $261 = ($260|0)>(-1);
    if (!($261)) {
     $$1 = $$04;$$16 = $$05;
     ___resumeException($$1|0);
     // unreachable;
    }
    $262 = HEAP32[$fileIDsVector>>2]|0;
    $263 = HEAP32[$25>>2]|0;
    HEAP32[$8>>2] = $263;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$8+0>>2]|0;
    invoke_vii(2591,($262|0),($$byval_copy12|0));
    $264 = __THREW__; __THREW__ = 0;
    $265 = $264&1;
    if ($265) {
     $266 = ___cxa_find_matching_catch(0|0)|0;
     $267 = tempRet0;
     ___clang_call_terminate($266);
     // unreachable;
    }
    HEAP32[$fileIDsVector>>2] = 0;
    $$1 = $$04;$$16 = $$05;
    ___resumeException($$1|0);
    // unreachable;
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $$1 = $22;$$16 = $23;
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __ZN17PersistentManager17IsObjectAvailableEi($this,$heapID) {
 $this = $this|0;
 $heapID = $heapID|0;
 var $$0 = 0, $$0$lcssa$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  label = 5;
 } else {
  $5 = (($1) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>($heapID|0);
  if ($7) {
   label = 5;
  } else {
   $8 = (($1) + 32|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)<($heapID|0);
   if ($10) {
    label = 5;
   } else {
    $11 = (($heapID) - ($6))|0;
    $12 = (($11|0) / 2)&-1;
    $13 = ($12|0)<(0);
    $14 = $13 << 31 >> 31;
    $41 = $3;$45 = $12;$46 = $14;
   }
  }
 }
 do {
  if ((label|0) == 5) {
   $15 = (($1) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($1) + 16|0);
   $18 = ($16|0)==(0|0);
   if ($18) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$0$ph7$i$i$i$i = $17;$$01$ph6$i$in$i$i$i = $16;
   }
   L9: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $19 = (($$013$i$in$i$i$i) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)<($heapID|0);
     if (!($21)) {
      break;
     }
     $24 = (($$013$i$in$i$i$i) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(0|0);
     if ($26) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L9;
     } else {
      $$013$i$in$i$i$i = $25;
     }
    }
    $22 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $22;
    }
   }
   $27 = ($$0$ph5$i$i$i$i|0)==($17|0);
   if ($27) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $28 = (($$0$ph5$i$i$i$i) + 16|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>($heapID|0);
   if ($30) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $31 = (($$0$ph5$i$i$i$i) + 24|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($$0$ph5$i$i$i$i) + 32|0);
    $34 = $33;
    $35 = $34;
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + 4)|0;
    $38 = $37;
    $39 = HEAP32[$38>>2]|0;
    $41 = $32;$45 = $36;$46 = $39;
    break;
   }
  }
 } while(0);
 $40 = ($41|0)==(-1);
 if ($40) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = (__ZN17PersistentManager26GetStreamNameSpaceInternalEi($this,$41)|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $47 = (__ZNK14SerializedFile11IsAvailableEx($43,$45,$46)|0);
 if (!($47)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $48 = (($42) + 16|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 L32: do {
  if (!($50)) {
   $51 = HEAP32[$49>>2]|0;
   $52 = (($49) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($51) + ($53<<3)|0);
   $55 = ($53|0)==(0);
   L34: do {
    if ($55) {
     $$0$lcssa$i$i$i = $51;
    } else {
     $$01$i$i$i = $51;
     while(1) {
      $58 = $$01$i$i$i;
      $59 = $58;
      $60 = HEAP32[$59>>2]|0;
      $61 = (($58) + 4)|0;
      $62 = $61;
      $63 = HEAP32[$62>>2]|0;
      $64 = ($60|0)==($45|0);
      $65 = ($63|0)==($46|0);
      $66 = $64 & $65;
      $57 = (($$01$i$i$i) + 8|0);
      if ($66) {
       $$0$lcssa$i$i$i = $$01$i$i$i;
       break L34;
      }
      $56 = ($57|0)==($54|0);
      if ($56) {
       break L32;
      } else {
       $$01$i$i$i = $57;
      }
     }
    }
   } while(0);
   $67 = ($$0$lcssa$i$i$i|0)==($54|0);
   if (!($67)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $68 = HEAP32[$42>>2]|0;
 $69 = ($68|0)==(0|0);
 if ($69) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $70 = (__ZNK14SerializedFile10GetClassIDEx($68,$45,$46)|0);
 $71 = (__ZN6Object13ClassIDToRTTIEi($70)|0);
 $72 = ($71|0)==(0|0);
 if (!($72)) {
  $73 = (($71) + 28|0);
  $74 = HEAP8[$73>>0]|0;
  $75 = ($74<<24>>24)==(0);
  if ($75) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17PersistentManager4LockEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17PersistentManager6UnlockEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17PersistentManager19DoneLoadingManagersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)<(10000);
 if ($4) {
  HEAP32[$2>>2] = 10000;
 }
 __ZN6Object19DoneLoadingManagersEv();
 STACKTOP = sp;return;
}
function __Z20GetPersistentManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[639200>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN17PersistentManagerC2Eii($this,$options,$cacheCount) {
 $this = $this|0;
 $options = $options|0;
 $cacheCount = $cacheCount|0;
 var $$01$i$i$i$i = 0, $$byval_copy6 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i17 = 0, $$pre$i$i$i19 = 0, $$sroa$1$i = 0, $$sroa$1$i24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i9 = 0, $scevgep = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i10 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i14 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i12 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i13 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy6 = sp + 60|0;
 $0 = sp + 56|0;
 $$sroa$1$i24 = sp;
 $$sroa$1$i = sp + 16|0;
 $1 = sp + 52|0;
 $2 = sp + 40|0;
 $3 = sp + 44|0;
 $4 = sp + 36|0;
 $5 = sp + 32|0;
 $6 = sp + 48|0;
 HEAP32[$this>>2] = ((639208 + 8|0));
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 8|0);
 HEAP32[$10>>2] = 61;
 $11 = (($this) + 20|0);
 $12 = (($this) + 24|0);
 $13 = (($this) + 32|0);
 $14 = (($this) + 36|0);
 $15 = (($this) + 52|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 56|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 60|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 80|0);
 $19 = (($this) + 84|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 88|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 84|0);
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;
 HEAP32[$18>>2] = $21;
 $22 = (($this) + 100|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 104|0);
 HEAP8[$23>>0] = 0;
 $24 = (($this) + 105|0);
 HEAP8[$24>>0] = 0;
 $25 = (($this) + 108|0);
 dest=$25+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $26 = (($this) + 152|0);
 HEAP32[$26>>2] = 32;
 $27 = (($this) + 156|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 164|0);
 HEAP32[$28>>2] = 16;
 $29 = (($this) + 160|0);
 HEAP32[$29>>2] = 6;
 $30 = (($this) + 168|0);
 HEAP8[$30>>0] = 0;
 HEAP32[639200>>2] = $this;
 $31 = (($this) + 76|0);
 HEAP32[$31>>2] = $options;
 $32 = (($this) + 64|0);
 HEAP32[$32>>2] = $cacheCount;
 $33 = (($this) + 95|0);
 HEAP8[$33>>0] = 0;
 $scevgep = (($this) + 68|0);
 $34 = $scevgep;
 $35 = $34;
 HEAP32[$35>>2] = -1;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = -1;
 $38 = HEAP32[628360>>2]|0;
 HEAP32[$6>>2] = $38;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$6+0>>2]|0;
 $39 = (invoke_iiiiiii(103,40,($$byval_copy6|0),1,16,(638872|0),1770)|0);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if (!($41)) {
  $42 = (($39) + 4|0);
  HEAP32[$42>>2] = 0;
  $43 = (($39) + 8|0);
  HEAP32[$43>>2] = 0;
  HEAP32[$39>>2] = $42;
  $44 = (($39) + 16|0);
  HEAP32[$44>>2] = 0;
  $45 = (($39) + 20|0);
  HEAP32[$45>>2] = 0;
  $46 = (($39) + 12|0);
  HEAP32[$46>>2] = $44;
  $47 = (($39) + 24|0);
  HEAP32[$47>>2] = 0;
  $48 = (($39) + 28|0);
  HEAP32[$48>>2] = 0;
  $49 = (($39) + 32|0);
  HEAP32[$49>>2] = 0;
  $50 = (($39) + 36|0);
  HEAP32[$50>>2] = -1;
  $51 = (($this) + 44|0);
  HEAP32[$51>>2] = $39;
  ;HEAP32[$$sroa$1$i+0>>2]=0|0;HEAP32[$$sroa$1$i+4>>2]=0|0;HEAP32[$$sroa$1$i+8>>2]=0|0;HEAP32[$$sroa$1$i+12>>2]=0|0;
  HEAP8[$24>>0] = 1;
  $52 = (($this) + 128|0);
  $53 = (($this) + 128|0);
  HEAP32[$53>>2] = -1;
  $54 = (($this) + 132|0);
  ;HEAP32[$54+0>>2]=HEAP32[$$sroa$1$i+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$$sroa$1$i+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$$sroa$1$i+8>>2]|0;HEAP32[$54+12>>2]=HEAP32[$$sroa$1$i+12>>2]|0;
  $55 = HEAP32[$26>>2]|0;
  $56 = ($55*20)|0;
  __THREW__ = 0;
  $57 = (invoke_ii(2988,($56|0))|0);
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if (!($59)) {
   $60 = (($this) + 148|0);
   HEAP32[$60>>2] = $57;
   $61 = (($57) + (($55*20)|0)|0);
   $62 = ($57|0)==($61|0);
   if (!($62)) {
    $$01$i$i$i$i = $57;
    while(1) {
     $63 = ($$01$i$i$i$i|0)==(0|0);
     if (!($63)) {
      ;HEAP32[$$01$i$i$i$i+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$$01$i$i$i$i+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$$01$i$i$i$i+8>>2]=HEAP32[$52+8>>2]|0;HEAP32[$$01$i$i$i$i+12>>2]=HEAP32[$52+12>>2]|0;HEAP32[$$01$i$i$i$i+16>>2]=HEAP32[$52+16>>2]|0;
     }
     $64 = (($$01$i$i$i$i) + 20|0);
     $65 = ($64|0)==($61|0);
     if ($65) {
      break;
     } else {
      $$01$i$i$i$i = $64;
     }
    }
   }
   $66 = (($this) + 96|0);
   ;HEAP32[$$sroa$1$i24+0>>2]=0|0;HEAP32[$$sroa$1$i24+4>>2]=0|0;HEAP32[$$sroa$1$i24+8>>2]=0|0;HEAP32[$$sroa$1$i24+12>>2]=0|0;
   __THREW__ = 0;
   invoke_vi(3563,($66|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if (!($68)) {
    HEAP8[$23>>0] = 1;
    $69 = (($this) + 108|0);
    HEAP32[$69>>2] = -2;
    $70 = (($this) + 112|0);
    ;HEAP32[$70+0>>2]=HEAP32[$$sroa$1$i24+0>>2]|0;HEAP32[$70+4>>2]=HEAP32[$$sroa$1$i24+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$$sroa$1$i24+8>>2]|0;HEAP32[$70+12>>2]=HEAP32[$$sroa$1$i24+12>>2]|0;
    __THREW__ = 0;
    invoke_v(181);
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if (!($72)) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 $73 = ___cxa_find_matching_catch()|0;
 $74 = tempRet0;
 $75 = (($this) + 148|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0|0);
 if (!($77)) {
  __ZdlPv($76);
 }
 $78 = HEAP32[$19>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($18,$78);
 $79 = HEAP32[$15>>2]|0;
 $80 = ($79|0)==(0|0);
 if (!($80)) {
  $81 = HEAP32[$16>>2]|0;
  $82 = ($81|0)==($79|0);
  if ($82) {
   $98 = $79;
  } else {
   $84 = $81;
   while(1) {
    $83 = (($84) + -24|0);
    HEAP32[$16>>2] = $83;
    $85 = (($84) + -12|0);
    $86 = HEAP8[$85>>0]|0;
    $87 = $86 & 1;
    $88 = ($87<<24>>24)==(0);
    if (!($88)) {
     $89 = (($84) + -4|0);
     $90 = HEAP32[$89>>2]|0;
     __ZdlPv($90);
    }
    $91 = HEAP8[$83>>0]|0;
    $92 = $91 & 1;
    $93 = ($92<<24>>24)==(0);
    if (!($93)) {
     $96 = (($84) + -16|0);
     $97 = HEAP32[$96>>2]|0;
     __ZdlPv($97);
    }
    $94 = HEAP32[$16>>2]|0;
    $95 = ($94|0)==($79|0);
    if ($95) {
     break;
    } else {
     $84 = $94;
    }
   }
   $$pre$i$i$i$i$i$i$i = HEAP32[$15>>2]|0;
   $98 = $$pre$i$i$i$i$i$i$i;
  }
  HEAP32[$0>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($98|0),($$byval_copy6|0));
  $99 = __THREW__; __THREW__ = 0;
  $100 = $99&1;
  if ($100) {
   $101 = ___cxa_find_matching_catch()|0;
   $102 = tempRet0;
   ___cxa_call_unexpected(($101|0));
   // unreachable;
  }
 }
 $103 = HEAP32[$13>>2]|0;
 $104 = ($103|0)==(0|0);
 if (!($104)) {
  $105 = HEAP32[$14>>2]|0;
  $106 = ($105|0)==($103|0);
  do {
   if ($106) {
    $124 = $103;
   } else {
    $108 = $105;
    while(1) {
     $107 = (($108) + -16|0);
     HEAP32[$14>>2] = $107;
     $109 = (($108) + -12|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0|0);
     if ($111) {
      $113 = $107;
     } else {
      $114 = (($108) + -8|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ($115|0)==($110|0);
      if (!($116)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i9 = $110;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i10 = (($115) + -8|0);
       $117 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i9))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i12 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i10) + ($117)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i13 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i12;
       $118 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i13 >>> 3;
       $119 = $118 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i14 = (($115) + ($119<<3)|0);
       HEAP32[$114>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i14;
      }
      HEAP32[$1>>2] = 30;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($110|0),($$byval_copy6|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       label = 31;
       break;
      }
      $$pre$i$i$i$i$i17 = HEAP32[$14>>2]|0;
      $113 = $$pre$i$i$i$i$i17;
     }
     $112 = ($113|0)==($103|0);
     if ($112) {
      label = 32;
      break;
     } else {
      $108 = $113;
     }
    }
    if ((label|0) == 31) {
     $122 = ___cxa_find_matching_catch()|0;
     $123 = tempRet0;
     ___cxa_call_unexpected(($122|0));
     // unreachable;
    }
    else if ((label|0) == 32) {
     $$pre$i$i$i19 = HEAP32[$13>>2]|0;
     $124 = $$pre$i$i$i19;
     break;
    }
   }
  } while(0);
  HEAP32[$2>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($124|0),($$byval_copy6|0));
  $125 = __THREW__; __THREW__ = 0;
  $126 = $125&1;
  if ($126) {
   $127 = ___cxa_find_matching_catch()|0;
   $128 = tempRet0;
   ___cxa_call_unexpected(($127|0));
   // unreachable;
  }
 }
 $129 = HEAP32[$11>>2]|0;
 $130 = ($129|0)==(0|0);
 if (!($130)) {
  $131 = HEAP32[$12>>2]|0;
  $132 = ($131|0)==($129|0);
  do {
   if ($132) {
    $150 = $129;
   } else {
    $134 = $131;
    while(1) {
     $133 = (($134) + -16|0);
     HEAP32[$12>>2] = $133;
     $135 = (($134) + -12|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = ($136|0)==(0|0);
     if ($137) {
      $139 = $133;
     } else {
      $140 = (($134) + -8|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = ($141|0)==($136|0);
      if (!($142)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $136;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($141) + -8|0);
       $143 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($143)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
       $144 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 3;
       $145 = $144 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($141) + ($145<<3)|0);
       HEAP32[$140>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      }
      HEAP32[$3>>2] = 30;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($136|0),($$byval_copy6|0));
      $146 = __THREW__; __THREW__ = 0;
      $147 = $146&1;
      if ($147) {
       label = 44;
       break;
      }
      $$pre$i$i$i$i$i = HEAP32[$12>>2]|0;
      $139 = $$pre$i$i$i$i$i;
     }
     $138 = ($139|0)==($129|0);
     if ($138) {
      label = 45;
      break;
     } else {
      $134 = $139;
     }
    }
    if ((label|0) == 44) {
     $148 = ___cxa_find_matching_catch()|0;
     $149 = tempRet0;
     ___cxa_call_unexpected(($148|0));
     // unreachable;
    }
    else if ((label|0) == 45) {
     $$pre$i$i$i = HEAP32[$11>>2]|0;
     $150 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  HEAP32[$4>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($150|0),($$byval_copy6|0));
  $151 = __THREW__; __THREW__ = 0;
  $152 = $151&1;
  if ($152) {
   $153 = ___cxa_find_matching_catch()|0;
   $154 = tempRet0;
   ___cxa_call_unexpected(($153|0));
   // unreachable;
  }
 }
 $155 = HEAP32[$9>>2]|0;
 $156 = ($155|0)>(-1);
 if (!($156)) {
  ___resumeException($73|0);
  // unreachable;
 }
 $157 = HEAP32[$7>>2]|0;
 $158 = HEAP32[$10>>2]|0;
 HEAP32[$5>>2] = $158;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
 invoke_vii(2591,($157|0),($$byval_copy6|0));
 $159 = __THREW__; __THREW__ = 0;
 $160 = $159&1;
 if ($160) {
  $161 = ___cxa_find_matching_catch(0|0)|0;
  $162 = tempRet0;
  ___clang_call_terminate($161);
  // unreachable;
 }
 HEAP32[$7>>2] = 0;
 ___resumeException($73|0);
 // unreachable;
}
function __ZN17PersistentManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1157,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN17PersistentManagerD2Ev($this) {
 $this = $this|0;
 var $$byval_copy19 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i$i49 = 0, $$pre$i$i$i$i$i22 = 0, $$pre$i$i$i$i$i38 = 0, $$pre$i$i$i$i$i63 = 0, $$pre$i$i$i24 = 0, $$pre$i$i$i40 = 0, $$pre$i$i$i65 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i14 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i30 = 0;
 var $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i55 = 0, $i1$070 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i15 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i31 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i56 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i19 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i35 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i60 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i17 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i58 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i18 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i34 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i59 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy19 = sp + 36|0;
 $0 = sp + 32|0;
 $1 = sp + 28|0;
 $2 = sp + 24|0;
 $3 = sp + 20|0;
 $4 = sp + 16|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $8 = sp + 12|0;
 HEAP32[$this>>2] = ((639208 + 8|0));
 $9 = (($this) + 4|0);
 $10 = (($this) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 L1: do {
  if ($12) {
   label = 12;
  } else {
   $13 = HEAP32[$9>>2]|0;
   $i1$070 = $13;
   while(1) {
    $14 = (($i1$070) + 16|0);
    $15 = HEAP32[$14>>2]|0;
    HEAP32[$14>>2] = 0;
    $16 = HEAP32[628360>>2]|0;
    $17 = ($15|0)==(0|0);
    if (!($17)) {
     $18 = (($15) + 12|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)>(-1);
     if ($20) {
      $21 = HEAP32[$15>>2]|0;
      $22 = (($15) + 4|0);
      $23 = HEAP32[$22>>2]|0;
      HEAP32[$4>>2] = $23;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($21|0),($$byval_copy19|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      HEAP32[$15>>2] = 0;
     }
    }
    HEAP32[$5>>2] = $16;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($15|0),($$byval_copy19|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = HEAP32[$i1$070>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     __THREW__ = 0;
     invoke_vi(3564,($28|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     HEAP32[$i1$070>>2] = 0;
    }
    $32 = (($i1$070) + 24|0);
    $33 = HEAP32[$9>>2]|0;
    $34 = HEAP32[$10>>2]|0;
    $35 = (($33) + (($34*24)|0)|0);
    $36 = ($32|0)==($35|0);
    if ($36) {
     label = 12;
     break L1;
    } else {
     $i1$070 = $32;
    }
   }
   $144 = ___cxa_find_matching_catch()|0;
   $145 = tempRet0;
   $lpad$phi$index = $144;$lpad$phi$index2 = $145;
  }
 } while(0);
 if ((label|0) == 12) {
  $37 = (($this) + 44|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[628360>>2]|0;
  $40 = ($38|0)==(0|0);
  if (!($40)) {
   $41 = (($38) + 12|0);
   $42 = (($38) + 16|0);
   $43 = HEAP32[$42>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIi26SerializedObjectIdentifierEENS_19__map_value_compareIiS3_NS_4lessIiEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($41,$43);
   $44 = (($38) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeI26SerializedObjectIdentifieriEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($38,$45);
  }
  HEAP32[$3>>2] = $39;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($38|0),($$byval_copy19|0));
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if (!($47)) {
   HEAP32[$37>>2] = 0;
   __THREW__ = 0;
   invoke_v(182);
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    $50 = (($this) + 148|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)==(0|0);
    if (!($52)) {
     __ZdlPv($51);
    }
    $53 = (($this) + 80|0);
    $54 = (($this) + 84|0);
    $55 = HEAP32[$54>>2]|0;
    __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($53,$55);
    $56 = (($this) + 52|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ($57|0)==(0|0);
    if (!($58)) {
     $59 = (($this) + 56|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==($57|0);
     if ($61) {
      $77 = $57;
     } else {
      $63 = $60;
      while(1) {
       $62 = (($63) + -24|0);
       HEAP32[$59>>2] = $62;
       $64 = (($63) + -12|0);
       $65 = HEAP8[$64>>0]|0;
       $66 = $65 & 1;
       $67 = ($66<<24>>24)==(0);
       if (!($67)) {
        $68 = (($63) + -4|0);
        $69 = HEAP32[$68>>2]|0;
        __ZdlPv($69);
       }
       $70 = HEAP8[$62>>0]|0;
       $71 = $70 & 1;
       $72 = ($71<<24>>24)==(0);
       if (!($72)) {
        $75 = (($63) + -16|0);
        $76 = HEAP32[$75>>2]|0;
        __ZdlPv($76);
       }
       $73 = HEAP32[$59>>2]|0;
       $74 = ($73|0)==($57|0);
       if ($74) {
        break;
       } else {
        $63 = $73;
       }
      }
      $$pre$i$i$i$i$i$i$i = HEAP32[$56>>2]|0;
      $77 = $$pre$i$i$i$i$i$i$i;
     }
     HEAP32[$5>>2] = 30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($77|0),($$byval_copy19|0));
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      $80 = ___cxa_find_matching_catch()|0;
      $81 = tempRet0;
      ___cxa_call_unexpected(($80|0));
      // unreachable;
     }
    }
    $82 = (($this) + 32|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($83|0)==(0|0);
    if (!($84)) {
     $85 = (($this) + 36|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86|0)==($83|0);
     do {
      if ($87) {
       $105 = $83;
      } else {
       $89 = $86;
       while(1) {
        $88 = (($89) + -16|0);
        HEAP32[$85>>2] = $88;
        $90 = (($89) + -12|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = ($91|0)==(0|0);
        if ($92) {
         $94 = $88;
        } else {
         $95 = (($89) + -8|0);
         $96 = HEAP32[$95>>2]|0;
         $97 = ($96|0)==($91|0);
         if (!($97)) {
          $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i14 = $91;
          $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i15 = (($96) + -8|0);
          $98 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i14))|0;
          $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i17 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i15) + ($98)|0);
          $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i18 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i17;
          $99 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i18 >>> 3;
          $100 = $99 ^ -1;
          $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i19 = (($96) + ($100<<3)|0);
          HEAP32[$95>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i19;
         }
         HEAP32[$3>>2] = 30;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
         invoke_vii(2591,($91|0),($$byval_copy19|0));
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          label = 37;
          break;
         }
         $$pre$i$i$i$i$i22 = HEAP32[$85>>2]|0;
         $94 = $$pre$i$i$i$i$i22;
        }
        $93 = ($94|0)==($83|0);
        if ($93) {
         label = 38;
         break;
        } else {
         $89 = $94;
        }
       }
       if ((label|0) == 37) {
        $103 = ___cxa_find_matching_catch()|0;
        $104 = tempRet0;
        ___cxa_call_unexpected(($103|0));
        // unreachable;
       }
       else if ((label|0) == 38) {
        $$pre$i$i$i24 = HEAP32[$82>>2]|0;
        $105 = $$pre$i$i$i24;
        break;
       }
      }
     } while(0);
     HEAP32[$4>>2] = 30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($105|0),($$byval_copy19|0));
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if ($107) {
      $108 = ___cxa_find_matching_catch()|0;
      $109 = tempRet0;
      ___cxa_call_unexpected(($108|0));
      // unreachable;
     }
    }
    $110 = (($this) + 20|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = ($111|0)==(0|0);
    if (!($112)) {
     $113 = (($this) + 24|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)==($111|0);
     do {
      if ($115) {
       $133 = $111;
      } else {
       $117 = $114;
       while(1) {
        $116 = (($117) + -16|0);
        HEAP32[$113>>2] = $116;
        $118 = (($117) + -12|0);
        $119 = HEAP32[$118>>2]|0;
        $120 = ($119|0)==(0|0);
        if ($120) {
         $122 = $116;
        } else {
         $123 = (($117) + -8|0);
         $124 = HEAP32[$123>>2]|0;
         $125 = ($124|0)==($119|0);
         if (!($125)) {
          $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i30 = $119;
          $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i31 = (($124) + -8|0);
          $126 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i30))|0;
          $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i33 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i31) + ($126)|0);
          $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i34 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i33;
          $127 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i34 >>> 3;
          $128 = $127 ^ -1;
          $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i35 = (($124) + ($128<<3)|0);
          HEAP32[$123>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i35;
         }
         HEAP32[$1>>2] = 30;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
         invoke_vii(2591,($119|0),($$byval_copy19|0));
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          label = 50;
          break;
         }
         $$pre$i$i$i$i$i38 = HEAP32[$113>>2]|0;
         $122 = $$pre$i$i$i$i$i38;
        }
        $121 = ($122|0)==($111|0);
        if ($121) {
         label = 51;
         break;
        } else {
         $117 = $122;
        }
       }
       if ((label|0) == 50) {
        $131 = ___cxa_find_matching_catch()|0;
        $132 = tempRet0;
        ___cxa_call_unexpected(($131|0));
        // unreachable;
       }
       else if ((label|0) == 51) {
        $$pre$i$i$i40 = HEAP32[$110>>2]|0;
        $133 = $$pre$i$i$i40;
        break;
       }
      }
     } while(0);
     HEAP32[$2>>2] = 30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($133|0),($$byval_copy19|0));
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      $136 = ___cxa_find_matching_catch()|0;
      $137 = tempRet0;
      ___cxa_call_unexpected(($136|0));
      // unreachable;
     }
    }
    $138 = (($this) + 16|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = ($139|0)>(-1);
    if (!($140)) {
     STACKTOP = sp;return;
    }
    $141 = HEAP32[$9>>2]|0;
    $142 = (($this) + 8|0);
    $143 = HEAP32[$142>>2]|0;
    HEAP32[$0>>2] = $143;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($141,$$byval_copy19);
    HEAP32[$9>>2] = 0;
    STACKTOP = sp;return;
   }
  }
  $146 = ___cxa_find_matching_catch()|0;
  $147 = tempRet0;
  $lpad$phi$index = $146;$lpad$phi$index2 = $147;
 }
 $148 = (($this) + 148|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = ($149|0)==(0|0);
 if (!($150)) {
  __ZdlPv($149);
 }
 $151 = (($this) + 80|0);
 $152 = (($this) + 84|0);
 $153 = HEAP32[$152>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($151,$153);
 $154 = (($this) + 52|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = ($155|0)==(0|0);
 if (!($156)) {
  $157 = (($this) + 56|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = ($158|0)==($155|0);
  if ($159) {
   $175 = $155;
  } else {
   $161 = $158;
   while(1) {
    $160 = (($161) + -24|0);
    HEAP32[$157>>2] = $160;
    $162 = (($161) + -12|0);
    $163 = HEAP8[$162>>0]|0;
    $164 = $163 & 1;
    $165 = ($164<<24>>24)==(0);
    if (!($165)) {
     $166 = (($161) + -4|0);
     $167 = HEAP32[$166>>2]|0;
     __ZdlPv($167);
    }
    $168 = HEAP8[$160>>0]|0;
    $169 = $168 & 1;
    $170 = ($169<<24>>24)==(0);
    if (!($170)) {
     $173 = (($161) + -16|0);
     $174 = HEAP32[$173>>2]|0;
     __ZdlPv($174);
    }
    $171 = HEAP32[$157>>2]|0;
    $172 = ($171|0)==($155|0);
    if ($172) {
     break;
    } else {
     $161 = $171;
    }
   }
   $$pre$i$i$i$i$i$i$i49 = HEAP32[$154>>2]|0;
   $175 = $$pre$i$i$i$i$i$i$i49;
  }
  HEAP32[$2>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($175|0),($$byval_copy19|0));
  $176 = __THREW__; __THREW__ = 0;
  $177 = $176&1;
  if ($177) {
   $178 = ___cxa_find_matching_catch()|0;
   $179 = tempRet0;
   ___cxa_call_unexpected(($178|0));
   // unreachable;
  }
 }
 $180 = (($this) + 32|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ($181|0)==(0|0);
 if (!($182)) {
  $183 = (($this) + 36|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ($184|0)==($181|0);
  do {
   if ($185) {
    $203 = $181;
   } else {
    $187 = $184;
    while(1) {
     $186 = (($187) + -16|0);
     HEAP32[$183>>2] = $186;
     $188 = (($187) + -12|0);
     $189 = HEAP32[$188>>2]|0;
     $190 = ($189|0)==(0|0);
     if ($190) {
      $192 = $186;
     } else {
      $193 = (($187) + -8|0);
      $194 = HEAP32[$193>>2]|0;
      $195 = ($194|0)==($189|0);
      if (!($195)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i55 = $189;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i56 = (($194) + -8|0);
       $196 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i55))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i58 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i56) + ($196)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i59 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i58;
       $197 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i59 >>> 3;
       $198 = $197 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i60 = (($194) + ($198<<3)|0);
       HEAP32[$193>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i60;
      }
      HEAP32[$0>>2] = 30;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($189|0),($$byval_copy19|0));
      $199 = __THREW__; __THREW__ = 0;
      $200 = $199&1;
      if ($200) {
       label = 80;
       break;
      }
      $$pre$i$i$i$i$i63 = HEAP32[$183>>2]|0;
      $192 = $$pre$i$i$i$i$i63;
     }
     $191 = ($192|0)==($181|0);
     if ($191) {
      label = 81;
      break;
     } else {
      $187 = $192;
     }
    }
    if ((label|0) == 80) {
     $201 = ___cxa_find_matching_catch()|0;
     $202 = tempRet0;
     ___cxa_call_unexpected(($201|0));
     // unreachable;
    }
    else if ((label|0) == 81) {
     $$pre$i$i$i65 = HEAP32[$180>>2]|0;
     $203 = $$pre$i$i$i65;
     break;
    }
   }
  } while(0);
  HEAP32[$1>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($203|0),($$byval_copy19|0));
  $204 = __THREW__; __THREW__ = 0;
  $205 = $204&1;
  if ($205) {
   $206 = ___cxa_find_matching_catch()|0;
   $207 = tempRet0;
   ___cxa_call_unexpected(($206|0));
   // unreachable;
  }
 }
 $208 = (($this) + 20|0);
 $209 = HEAP32[$208>>2]|0;
 $210 = ($209|0)==(0|0);
 if (!($210)) {
  $211 = (($this) + 24|0);
  $212 = HEAP32[$211>>2]|0;
  $213 = ($212|0)==($209|0);
  do {
   if ($213) {
    $231 = $209;
   } else {
    $215 = $212;
    while(1) {
     $214 = (($215) + -16|0);
     HEAP32[$211>>2] = $214;
     $216 = (($215) + -12|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = ($217|0)==(0|0);
     if ($218) {
      $220 = $214;
     } else {
      $221 = (($215) + -8|0);
      $222 = HEAP32[$221>>2]|0;
      $223 = ($222|0)==($217|0);
      if (!($223)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $217;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($222) + -8|0);
       $224 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($224)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
       $225 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 3;
       $226 = $225 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($222) + ($226<<3)|0);
       HEAP32[$221>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      }
      HEAP32[$6>>2] = 30;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$6+0>>2]|0;
      invoke_vii(2591,($217|0),($$byval_copy19|0));
      $227 = __THREW__; __THREW__ = 0;
      $228 = $227&1;
      if ($228) {
       label = 93;
       break;
      }
      $$pre$i$i$i$i$i = HEAP32[$211>>2]|0;
      $220 = $$pre$i$i$i$i$i;
     }
     $219 = ($220|0)==($209|0);
     if ($219) {
      label = 94;
      break;
     } else {
      $215 = $220;
     }
    }
    if ((label|0) == 93) {
     $229 = ___cxa_find_matching_catch()|0;
     $230 = tempRet0;
     ___cxa_call_unexpected(($229|0));
     // unreachable;
    }
    else if ((label|0) == 94) {
     $$pre$i$i$i = HEAP32[$208>>2]|0;
     $231 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  HEAP32[$7>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$7+0>>2]|0;
  invoke_vii(2591,($231|0),($$byval_copy19|0));
  $232 = __THREW__; __THREW__ = 0;
  $233 = $232&1;
  if ($233) {
   $234 = ___cxa_find_matching_catch()|0;
   $235 = tempRet0;
   ___cxa_call_unexpected(($234|0));
   // unreachable;
  }
 }
 $236 = (($this) + 16|0);
 $237 = HEAP32[$236>>2]|0;
 $238 = ($237|0)>(-1);
 if (!($238)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $239 = HEAP32[$9>>2]|0;
 $240 = (($this) + 8|0);
 $241 = HEAP32[$240>>2]|0;
 HEAP32[$8>>2] = $241;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$8+0>>2]|0;
 invoke_vii(2591,($239|0),($$byval_copy19|0));
 $242 = __THREW__; __THREW__ = 0;
 $243 = $242&1;
 if ($243) {
  $244 = ___cxa_find_matching_catch(0|0)|0;
  $245 = tempRet0;
  ___clang_call_terminate($244);
  // unreachable;
 }
 HEAP32[$9>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN17PersistentManager26GetStreamNameSpaceInternalEi($this,$nameSpaceID) {
 $this = $this|0;
 $nameSpaceID = $nameSpaceID|0;
 var $$0 = 0, $$01 = 0, $$01$i = 0, $$02$i = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $$2 = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $absolutePath = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $group = 0, $pathName = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy6 = sp + 52|0;
 $pathName = sp;
 $absolutePath = sp + 12|0;
 $0 = sp + 24|0;
 $group = sp + 28|0;
 $1 = sp + 40|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + (($nameSpaceID*24)|0)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $$2 = $4;
  STACKTOP = sp;return ($$2|0);
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viii[$9 & 4095]($pathName,$this,$nameSpaceID);
 $10 = HEAP8[$pathName>>0]|0;
 $11 = $10 & 1;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $15 = $10&255;
  $16 = $15 >>> 1;
  $18 = $16;
 } else {
  $13 = (($pathName) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $18 = $14;
 }
 $17 = ($18|0)==(0);
 L8: do {
  if ($17) {
   $$14 = $4;
  } else {
   __THREW__ = 0;
   invoke_viii(1926,($absolutePath|0),($this|0),($pathName|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    $$1 = $25;$$12 = $24;
   } else {
    __THREW__ = 0;
    $21 = (invoke_ii(3266,($absolutePath|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    L13: do {
     if ($23) {
      label = 10;
     } else {
      L15: do {
       if ($21) {
        __THREW__ = 0;
        $28 = (invoke_ii(2988,32)|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 10;
         break L13;
        }
        dest=$28+0|0; src=639360+0|0; stop=dest+31|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $31 = (($28) + 31|0);
        HEAP8[$31>>0] = 0;
        $32 = HEAP8[$pathName>>0]|0;
        $33 = $32 & 1;
        $34 = ($33<<24>>24)==(0);
        if ($34) {
         $37 = (($pathName) + 1|0);
         $38 = $37;
        } else {
         $35 = (($pathName) + 8|0);
         $36 = HEAP32[$35>>2]|0;
         $38 = $36;
        }
        __THREW__ = 0;
        $39 = (invoke_iii(2448,($38|0),($28|0))|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        L22: do {
         if ($41) {
          label = 24;
         } else {
          $42 = ($39|0)==(0);
          do {
           if ($42) {
            __ZdlPv($28);
            label = 28;
           } else {
            __THREW__ = 0;
            $43 = (invoke_ii(2988,32)|0);
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if ($45) {
             label = 24;
             break L22;
            }
            dest=$43+0|0; src=639392+0|0; stop=dest+30|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
            $46 = (($43) + 30|0);
            HEAP8[$46>>0] = 0;
            $47 = HEAP8[$pathName>>0]|0;
            $48 = $47 & 1;
            $49 = ($48<<24>>24)==(0);
            if ($49) {
             $52 = (($pathName) + 1|0);
             $53 = $52;
            } else {
             $50 = (($pathName) + 8|0);
             $51 = HEAP32[$50>>2]|0;
             $53 = $51;
            }
            __THREW__ = 0;
            $54 = (invoke_iii(2448,($53|0),($43|0))|0);
            $55 = __THREW__; __THREW__ = 0;
            $56 = $55&1;
            if ($56) {
             $59 = ___cxa_find_matching_catch()|0;
             $60 = tempRet0;
             __ZdlPv($43);
             $$01$i = $60;$$02$i = $59;
             break L22;
            } else {
             $61 = ($54|0)==(0);
             __ZdlPv($43);
             __ZdlPv($28);
             if ($61) {
              label = 28;
              break;
             } else {
              $73 = 0;
              break;
             }
            }
           }
          } while(0);
          if ((label|0) == 28) {
           $73 = 16777216;
          }
          $62 = HEAP32[628360>>2]|0;
          HEAP32[$0>>2] = $62;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
          $63 = (invoke_iiiiiii(103,128,($$byval_copy6|0),1,16,(638872|0),1887)|0);
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           label = 10;
           break L13;
          }
          __THREW__ = 0;
          invoke_vi(3565,($63|0));
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           $86 = ___cxa_find_matching_catch()|0;
           $87 = tempRet0;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_viiiiii(97,($63|0),($$byval_copy6|0),1,16,(638872|0),1887);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if (!($89)) {
            $$0 = $87;$$01 = $86;
            break L13;
           }
           $121 = ___cxa_find_matching_catch(0|0)|0;
           $122 = tempRet0;
           ___clang_call_terminate($121);
           // unreachable;
          }
          HEAP32[$4>>2] = $63;
          ;HEAP32[$group+0>>2]=0|0;HEAP32[$group+4>>2]=0|0;HEAP32[$group+8>>2]=0|0;
          $68 = HEAP32[$4>>2]|0;
          __THREW__ = 0;
          invoke_viii(1926,($1|0),($this|0),($pathName|0));
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           label = 10;
           break L13;
          }
          $71 = (($this) + 64|0);
          $72 = HEAP32[$71>>2]|0;
          __THREW__ = 0;
          $74 = (invoke_iiiiiiiii(40,($68|0),($1|0),($group|0),7168,($72|0),($73|0),0,-1)|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           $90 = ___cxa_find_matching_catch()|0;
           $91 = tempRet0;
           $92 = HEAP8[$1>>0]|0;
           $93 = $92 & 1;
           $94 = ($93<<24>>24)==(0);
           if ($94) {
            $$0 = $91;$$01 = $90;
            break L13;
           }
           $95 = (($1) + 8|0);
           $96 = HEAP32[$95>>2]|0;
           __ZdlPv($96);
           $$0 = $91;$$01 = $90;
           break L13;
          }
          $77 = HEAP8[$1>>0]|0;
          $78 = $77 & 1;
          $79 = ($78<<24>>24)==(0);
          if (!($79)) {
           $80 = (($1) + 8|0);
           $81 = HEAP32[$80>>2]|0;
           __ZdlPv($81);
          }
          if ($74) {
           __THREW__ = 0;
           invoke_viii(1927,($this|0),($4|0),($nameSpaceID|0));
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if ($98) {
            label = 10;
            break L13;
           }
           $99 = HEAP32[$2>>2]|0;
           $100 = (($99) + (($nameSpaceID*24)|0)|0);
           $$03 = $100;
           break L15;
          }
          $82 = HEAP32[$4>>2]|0;
          $83 = ($82|0)==(0|0);
          if ($83) {
           $$03 = $4;
           break L15;
          }
          __THREW__ = 0;
          invoke_vi(3564,($82|0));
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if ($85) {
           label = 10;
           break L13;
          }
          HEAP32[$4>>2] = 0;
          $$03 = $4;
          break L15;
         }
        } while(0);
        if ((label|0) == 24) {
         $57 = ___cxa_find_matching_catch()|0;
         $58 = tempRet0;
         $$01$i = $58;$$02$i = $57;
        }
        __ZdlPv($28);
        $eh$lpad$body$index2Z2D = $$01$i;$eh$lpad$body$indexZ2D = $$02$i;
        label = 11;
        break L13;
       } else {
        $$03 = $4;
       }
      } while(0);
      $101 = HEAP8[$absolutePath>>0]|0;
      $102 = $101 & 1;
      $103 = ($102<<24>>24)==(0);
      if ($103) {
       $$14 = $$03;
       break L8;
      }
      $104 = (($absolutePath) + 8|0);
      $105 = HEAP32[$104>>2]|0;
      __ZdlPv($105);
      $$14 = $$03;
      break L8;
     }
    } while(0);
    if ((label|0) == 10) {
     $26 = ___cxa_find_matching_catch()|0;
     $27 = tempRet0;
     $eh$lpad$body$index2Z2D = $27;$eh$lpad$body$indexZ2D = $26;
     label = 11;
    }
    if ((label|0) == 11) {
     $$0 = $eh$lpad$body$index2Z2D;$$01 = $eh$lpad$body$indexZ2D;
    }
    $106 = HEAP8[$absolutePath>>0]|0;
    $107 = $106 & 1;
    $108 = ($107<<24>>24)==(0);
    if ($108) {
     $$1 = $$0;$$12 = $$01;
    } else {
     $109 = (($absolutePath) + 8|0);
     $110 = HEAP32[$109>>2]|0;
     __ZdlPv($110);
     $$1 = $$0;$$12 = $$01;
    }
   }
   $116 = HEAP8[$pathName>>0]|0;
   $117 = $116 & 1;
   $118 = ($117<<24>>24)==(0);
   if ($118) {
    ___resumeException($$12|0);
    // unreachable;
   }
   $119 = (($pathName) + 8|0);
   $120 = HEAP32[$119>>2]|0;
   __ZdlPv($120);
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $111 = HEAP8[$pathName>>0]|0;
 $112 = $111 & 1;
 $113 = ($112<<24>>24)==(0);
 if ($113) {
  $$2 = $$14;
  STACKTOP = sp;return ($$2|0);
 }
 $114 = (($pathName) + 8|0);
 $115 = HEAP32[$114>>2]|0;
 __ZdlPv($115);
 $$2 = $$14;
 STACKTOP = sp;return ($$2|0);
}
function __ZN17PersistentManager19RemapToAbsolutePathERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($agg$result,$this,$path) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $path = $path|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $found = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $found = sp;
 $0 = (($this) + 48|0);
 __ZN13sorted_vectorINSt3__14pairINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES7_EEN10vector_mapIS7_S7_26compare_string_insensitive13stl_allocatorIS8_L18MemLabelIdentifier30ELi16EEE13value_compareESD_E4findIS7_EENS0_11__wrap_iterIPS8_EERKT_($found,$0,$path);
 $1 = (($this) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$found>>2]|0;
 $4 = ($3|0)==($2|0);
 if ($4) {
  __Z18PathToAbsolutePathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$path);
  STACKTOP = sp;return;
 }
 $5 = (($3) + 12|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$5+8>>2]|0;
  STACKTOP = sp;return;
 }
 $9 = (($3) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($3) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12>>>0)>(4294967279);
 if ($13) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $14 = ($12>>>0)<(11);
 if ($14) {
  $15 = $12 << 1;
  $16 = $15&255;
  HEAP8[$agg$result>>0] = $16;
  $17 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $17;
 } else {
  $18 = (($12) + 16)|0;
  $19 = $18 & -16;
  $20 = (__Znwj($19)|0);
  $21 = (($agg$result) + 8|0);
  HEAP32[$21>>2] = $20;
  $22 = $19 | 1;
  HEAP32[$agg$result>>2] = $22;
  $23 = (($agg$result) + 4|0);
  HEAP32[$23>>2] = $12;
  $__p$0$i$i$i = $20;
 }
 _memcpy(($__p$0$i$i$i|0),($10|0),($12|0))|0;
 $24 = (($__p$0$i$i$i) + ($12)|0);
 HEAP8[$24>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN17PersistentManager23PostLoadStreamNameSpaceER15StreamNameSpacei($this,$nameSpace,$nameSpaceID) {
 $this = $this|0;
 $nameSpace = $nameSpace|0;
 $nameSpaceID = $nameSpaceID|0;
 var $$byval_copy6 = 0, $$neg2$i$i$i$i$i = 0, $$neg2$i$i$i$i$i17 = 0, $$neg2$i$i$i$i$i29 = 0, $$neg2$i$i$i$i$i4 = 0, $$pn$i$i = 0, $$pn$i$i10 = 0, $$pn$i$i23 = 0, $$pn$i$i35 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i16 = 0, $$sum$i$i$i$i$i28 = 0, $$sum$i$i$i$i$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i18 = 0, $__len$0$be$i$i$i$i$i30 = 0, $__len$0$be$i$i$i$i$i5 = 0, $__len$03$i$i$i$i$i = 0;
 var $__len$03$i$i$i$i$i15 = 0, $__len$03$i$i$i$i$i2 = 0, $__len$03$i$i$i$i$i27 = 0, $__p$0$i$i$i$i$i$i = 0, $i$044 = 0, $storemerge$i$i = 0, $storemerge$i$i11 = 0, $storemerge$i$i24 = 0, $storemerge$i$i36 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy6 = sp + 56|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 16|0;
 $3 = sp + 20|0;
 $4 = sp + 24|0;
 $5 = (($nameSpace) + 8|0);
 $6 = HEAP32[$nameSpace>>2]|0;
 $7 = (__ZNK14SerializedFile12GetHighestIDEv($6)|0);
 $8 = tempRet0;
 $9 = $5;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)<($8|0);
 $16 = ($14|0)==($8|0);
 $17 = ($11>>>0)<($7>>>0);
 $18 = $16 & $17;
 $19 = $15 | $18;
 $20 = $19 ? $7 : $11;
 $21 = $19 ? $8 : $14;
 $22 = $5;
 $23 = $22;
 HEAP32[$23>>2] = $20;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 $26 = HEAP32[$nameSpace>>2]|0;
 $27 = (($26) + 84|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0);
 L1: do {
  if ($29) {
   $$pre = (($this) + 20|0);
   $$pre$phiZ2D = $$pre;
  } else {
   $30 = (($26) + 80|0);
   $31 = (($26) + 92|0);
   $32 = (($4) + 1|0);
   $33 = (($4) + 12|0);
   $34 = (($this) + 20|0);
   $35 = (($1) + 4|0);
   $36 = (($this) + 32|0);
   $37 = (($1) + 4|0);
   $38 = (($4) + 8|0);
   $39 = (($4) + 4|0);
   $i$044 = 0;
   while(1) {
    $40 = HEAP32[$this>>2]|0;
    $41 = (($40) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = HEAP32[$30>>2]|0;
    $44 = (($i$044>>>0) / ($43>>>0))&-1;
    $45 = HEAP32[$31>>2]|0;
    $46 = (($45) + ($44<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($i$044>>>0) % ($43>>>0))&-1;
    $49 = HEAP32[$47>>2]|0;
    $50 = (($49) + ($48<<5)|0);
    $51 = HEAP8[$50>>0]|0;
    $52 = $51 & 1;
    $53 = ($52<<24>>24)==(0);
    if ($53) {
     $58 = (($50) + 1|0);
     $59 = $51&255;
     $60 = $59 >>> 1;
     $62 = $60;$70 = $58;
    } else {
     $54 = ((($49) + ($48<<5)|0) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ((($49) + ($48<<5)|0) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $62 = $57;$70 = $55;
    }
    $61 = ($62>>>0)>(2147483631);
    if ($61) {
     label = 8;
     break;
    }
    $63 = ($62>>>0)<(11);
    if ($63) {
     $64 = $62 << 1;
     $65 = $64&255;
     HEAP8[$4>>0] = $65;
     $__p$0$i$i$i$i$i$i = $32;
    } else {
     $66 = (($62) + 16)|0;
     $67 = $66 & -16;
     HEAP32[$0>>2] = 59;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     $68 = (__Z15malloc_internaljj10MemLabelIdiPKci($67,16,$$byval_copy6,0,638872,79)|0);
     HEAP32[$38>>2] = $68;
     $69 = $67 | 1;
     HEAP32[$4>>2] = $69;
     HEAP32[$39>>2] = $62;
     $__p$0$i$i$i$i$i$i = $68;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($70|0),($62|0))|0;
    $71 = (($__p$0$i$i$i$i$i$i) + ($62)|0);
    HEAP8[$71>>0] = 0;
    $72 = ((($49) + ($48<<5)|0) + 12|0);
    ;HEAP32[$33+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$72+12>>2]|0;HEAP32[$33+16>>2]=HEAP32[$72+16>>2]|0;
    __THREW__ = 0;
    $73 = (invoke_iiii($42|0,($this|0),($4|0),1)|0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     label = 31;
     break;
    }
    $76 = HEAP8[$4>>0]|0;
    $77 = $76 & 1;
    $78 = ($77<<24>>24)==(0);
    if (!($78)) {
     $79 = HEAP32[$38>>2]|0;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($79|0),($$byval_copy6|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      label = 15;
      break;
     }
    }
    $84 = (($i$044) + 1)|0;
    $85 = HEAP32[$34>>2]|0;
    $86 = ((($85) + ($nameSpaceID<<4)|0) + 4|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ((($85) + ($nameSpaceID<<4)|0) + 8|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = $89;
    $91 = $87;
    $92 = (($90) - ($91))|0;
    $93 = $92 >> 3;
    $94 = ($93|0)==(0);
    if ($94) {
     $104 = $87;
    } else {
     $97 = $87;$__len$03$i$i$i$i$i15 = $93;
     while(1) {
      $95 = (($__len$03$i$i$i$i$i15|0) / 2)&-1;
      $96 = (($97) + ($95<<3)|0);
      $98 = HEAP32[$96>>2]|0;
      $99 = ($98|0)<($73|0);
      if ($99) {
       $$sum$i$i$i$i$i16 = (($95) + 1)|0;
       $100 = (($97) + ($$sum$i$i$i$i$i16<<3)|0);
       $$neg2$i$i$i$i$i17 = (($__len$03$i$i$i$i$i15) + -1)|0;
       $101 = (($$neg2$i$i$i$i$i17) - ($95))|0;
       $196 = $100;$__len$0$be$i$i$i$i$i18 = $101;
      } else {
       $196 = $97;$__len$0$be$i$i$i$i$i18 = $95;
      }
      $102 = ($__len$0$be$i$i$i$i$i18|0)==(0);
      if ($102) {
       $104 = $196;
       break;
      } else {
       $97 = $196;$__len$03$i$i$i$i$i15 = $__len$0$be$i$i$i$i$i18;
      }
     }
    }
    $103 = ($104|0)==($89|0);
    if ($103) {
     label = 22;
    } else {
     $105 = HEAP32[$104>>2]|0;
     $106 = ($73|0)<($105|0);
     if ($106) {
      label = 22;
     } else {
      $$pn$i$i23 = $104;
     }
    }
    if ((label|0) == 22) {
     label = 0;
     $107 = ((($85) + ($nameSpaceID<<4)|0) + 4|0);
     HEAP32[$0>>2] = $104;
     HEAP32[$1>>2] = $73;
     HEAP32[$35>>2] = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier30ELi16EEE6insertENS_11__wrap_iterIPKS2_EERS8_($2,$107,$$byval_copy6,$1);
     $108 = HEAP32[$2>>2]|0;
     $$pn$i$i23 = $108;
    }
    $storemerge$i$i24 = (($$pn$i$i23) + 4|0);
    HEAP32[$storemerge$i$i24>>2] = $84;
    $109 = HEAP32[$36>>2]|0;
    $110 = ((($109) + ($nameSpaceID<<4)|0) + 4|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = ((($109) + ($nameSpaceID<<4)|0) + 8|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = $113;
    $115 = $111;
    $116 = (($114) - ($115))|0;
    $117 = $116 >> 3;
    $118 = ($117|0)==(0);
    if ($118) {
     $128 = $111;
    } else {
     $121 = $111;$__len$03$i$i$i$i$i27 = $117;
     while(1) {
      $119 = (($__len$03$i$i$i$i$i27|0) / 2)&-1;
      $120 = (($121) + ($119<<3)|0);
      $122 = HEAP32[$120>>2]|0;
      $123 = ($122|0)<($84|0);
      if ($123) {
       $$sum$i$i$i$i$i28 = (($119) + 1)|0;
       $124 = (($121) + ($$sum$i$i$i$i$i28<<3)|0);
       $$neg2$i$i$i$i$i29 = (($__len$03$i$i$i$i$i27) + -1)|0;
       $125 = (($$neg2$i$i$i$i$i29) - ($119))|0;
       $197 = $124;$__len$0$be$i$i$i$i$i30 = $125;
      } else {
       $197 = $121;$__len$0$be$i$i$i$i$i30 = $119;
      }
      $126 = ($__len$0$be$i$i$i$i$i30|0)==(0);
      if ($126) {
       $128 = $197;
       break;
      } else {
       $121 = $197;$__len$03$i$i$i$i$i27 = $__len$0$be$i$i$i$i$i30;
      }
     }
    }
    $127 = ($128|0)==($113|0);
    if ($127) {
     label = 29;
    } else {
     $129 = HEAP32[$128>>2]|0;
     $130 = ($84|0)<($129|0);
     if ($130) {
      label = 29;
     } else {
      $$pn$i$i35 = $128;
     }
    }
    if ((label|0) == 29) {
     label = 0;
     $131 = ((($109) + ($nameSpaceID<<4)|0) + 4|0);
     HEAP32[$0>>2] = $128;
     HEAP32[$1>>2] = $84;
     HEAP32[$37>>2] = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier30ELi16EEE6insertENS_11__wrap_iterIPKS2_EERS8_($2,$131,$$byval_copy6,$1);
     $132 = HEAP32[$2>>2]|0;
     $$pn$i$i35 = $132;
    }
    $storemerge$i$i36 = (($$pn$i$i35) + 4|0);
    HEAP32[$storemerge$i$i36>>2] = $73;
    $133 = HEAP32[$27>>2]|0;
    $134 = ($84|0)==($133|0);
    if ($134) {
     $$pre$phiZ2D = $34;
     break L1;
    } else {
     $i$044 = $84;
    }
   }
   if ((label|0) == 8) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 15) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   }
   else if ((label|0) == 31) {
    $135 = ___cxa_find_matching_catch()|0;
    $136 = tempRet0;
    $137 = HEAP8[$4>>0]|0;
    $138 = $137 & 1;
    $139 = ($138<<24>>24)==(0);
    if ($139) {
     ___resumeException($135|0);
     // unreachable;
    }
    $140 = HEAP32[$38>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($140|0),($$byval_copy6|0));
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if ($142) {
     $143 = ___cxa_find_matching_catch()|0;
     $144 = tempRet0;
     ___cxa_call_unexpected(($143|0));
     // unreachable;
    } else {
     ___resumeException($135|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $145 = HEAP32[$$pre$phiZ2D>>2]|0;
 $146 = ((($145) + ($nameSpaceID<<4)|0) + 4|0);
 $147 = HEAP32[$146>>2]|0;
 $148 = ((($145) + ($nameSpaceID<<4)|0) + 8|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = $149;
 $151 = $147;
 $152 = (($150) - ($151))|0;
 $153 = $152 >> 3;
 $154 = ($153|0)==(0);
 if ($154) {
  $164 = $147;
 } else {
  $157 = $147;$__len$03$i$i$i$i$i2 = $153;
  while(1) {
   $155 = (($__len$03$i$i$i$i$i2|0) / 2)&-1;
   $156 = (($157) + ($155<<3)|0);
   $158 = HEAP32[$156>>2]|0;
   $159 = ($158|0)<($nameSpaceID|0);
   if ($159) {
    $$sum$i$i$i$i$i3 = (($155) + 1)|0;
    $160 = (($157) + ($$sum$i$i$i$i$i3<<3)|0);
    $$neg2$i$i$i$i$i4 = (($__len$03$i$i$i$i$i2) + -1)|0;
    $161 = (($$neg2$i$i$i$i$i4) - ($155))|0;
    $198 = $160;$__len$0$be$i$i$i$i$i5 = $161;
   } else {
    $198 = $157;$__len$0$be$i$i$i$i$i5 = $155;
   }
   $162 = ($__len$0$be$i$i$i$i$i5|0)==(0);
   if ($162) {
    $164 = $198;
    break;
   } else {
    $157 = $198;$__len$03$i$i$i$i$i2 = $__len$0$be$i$i$i$i$i5;
   }
  }
 }
 $163 = ($164|0)==($149|0);
 if ($163) {
  label = 40;
 } else {
  $165 = HEAP32[$164>>2]|0;
  $166 = ($165|0)>($nameSpaceID|0);
  if ($166) {
   label = 40;
  } else {
   $$pn$i$i10 = $164;
  }
 }
 if ((label|0) == 40) {
  $167 = ((($145) + ($nameSpaceID<<4)|0) + 4|0);
  HEAP32[$0>>2] = $164;
  HEAP32[$1>>2] = $nameSpaceID;
  $168 = (($1) + 4|0);
  HEAP32[$168>>2] = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier30ELi16EEE6insertENS_11__wrap_iterIPKS2_EERS8_($2,$167,$$byval_copy6,$1);
  $169 = HEAP32[$2>>2]|0;
  $$pn$i$i10 = $169;
 }
 $storemerge$i$i11 = (($$pn$i$i10) + 4|0);
 HEAP32[$storemerge$i$i11>>2] = 0;
 $170 = (($this) + 32|0);
 $171 = HEAP32[$170>>2]|0;
 $172 = ((($171) + ($nameSpaceID<<4)|0) + 4|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = ((($171) + ($nameSpaceID<<4)|0) + 8|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = $175;
 $177 = $173;
 $178 = (($176) - ($177))|0;
 $179 = $178 >> 3;
 $180 = ($179|0)==(0);
 if ($180) {
  $190 = $173;
 } else {
  $183 = $173;$__len$03$i$i$i$i$i = $179;
  while(1) {
   $181 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $182 = (($183) + ($181<<3)|0);
   $184 = HEAP32[$182>>2]|0;
   $185 = ($184|0)<(0);
   if ($185) {
    $$sum$i$i$i$i$i = (($181) + 1)|0;
    $186 = (($183) + ($$sum$i$i$i$i$i<<3)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $187 = (($$neg2$i$i$i$i$i) - ($181))|0;
    $199 = $186;$__len$0$be$i$i$i$i$i = $187;
   } else {
    $199 = $183;$__len$0$be$i$i$i$i$i = $181;
   }
   $188 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($188) {
    $190 = $199;
    break;
   } else {
    $183 = $199;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $189 = ($190|0)==($175|0);
 if (!($189)) {
  $191 = HEAP32[$190>>2]|0;
  $192 = ($191|0)>(0);
  if (!($192)) {
   $$pn$i$i = $190;
   $storemerge$i$i = (($$pn$i$i) + 4|0);
   HEAP32[$storemerge$i$i>>2] = $nameSpaceID;
   STACKTOP = sp;return;
  }
 }
 $193 = ((($171) + ($nameSpaceID<<4)|0) + 4|0);
 HEAP32[$0>>2] = $190;
 HEAP32[$1>>2] = 0;
 $194 = (($1) + 4|0);
 HEAP32[$194>>2] = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier30ELi16EEE6insertENS_11__wrap_iterIPKS2_EERS8_($2,$193,$$byval_copy6,$1);
 $195 = HEAP32[$2>>2]|0;
 $$pn$i$i = $195;
 $storemerge$i$i = (($$pn$i$i) + 4|0);
 HEAP32[$storemerge$i$i>>2] = $nameSpaceID;
 STACKTOP = sp;return;
}
function __ZN17PersistentManager14LoadFileStreamERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_24TransferInstructionFlagsii($this,$path,$actualAbsolutePath,$flags,$readOffset,$readEndOffset) {
 $this = $this|0;
 $path = $path|0;
 $actualAbsolutePath = $actualAbsolutePath|0;
 $flags = $flags|0;
 $readOffset = $readOffset|0;
 $readEndOffset = $readEndOffset|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy1 = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $group = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 28|0;
 $0 = sp;
 $group = sp + 12|0;
 $1 = sp + 24|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iiii($4|0,($this|0),($path|0),1)|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if (!($7)) {
   $8 = ($5|0)==(-1);
   if ($8) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $11 = (($this) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + (($5*24)|0)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_viiiiiiii(21,(639240|0),0,(638872|0),1935,1,0,0,(0|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    } else {
     $$0 = 0;
    }
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $18 = (invoke_ii(3266,($actualAbsolutePath|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    if (!($18)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    ;HEAP32[$group+0>>2]=0|0;HEAP32[$group+4>>2]=0|0;HEAP32[$group+8>>2]=0|0;
    $21 = HEAP32[628360>>2]|0;
    HEAP32[$1>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $22 = (invoke_iiiiiii(103,128,($$byval_copy1|0),1,16,(638872|0),1944)|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(3565,($22|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      $36 = ___cxa_find_matching_catch()|0;
      $37 = tempRet0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_viiiiii(97,($22|0),($$byval_copy1|0),1,16,(638872|0),1944);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       $64 = ___cxa_find_matching_catch(0|0)|0;
       $65 = tempRet0;
       ___clang_call_terminate($64);
       // unreachable;
      } else {
       $$01 = $37;$$02 = $36;
       ___resumeException($$02|0);
       // unreachable;
      }
     }
     HEAP32[$13>>2] = $22;
     $27 = (($this) + 64|0);
     $28 = HEAP32[$27>>2]|0;
     __THREW__ = 0;
     $29 = (invoke_iiiiiiiii(40,($22|0),($actualAbsolutePath|0),($group|0),7168,($28|0),($flags|0),($readOffset|0),($readEndOffset|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      $32 = HEAP32[$13>>2]|0;
      if (!($29)) {
       $33 = ($32|0)==(0|0);
       if ($33) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3564,($32|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
       HEAP32[$13>>2] = 0;
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
      $40 = (($32) + 38|0);
      HEAP8[$40>>0] = 1;
      __THREW__ = 0;
      invoke_viii(1927,($this|0),($13|0),($5|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       $43 = (($this) + 80|0);
       $44 = (__ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEESI_RKT_($43,$$byval_copy1,$path)|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = ($45|0)==(0|0);
       if (!($46)) {
        $$0 = 1;
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_viii(1928,($0|0),($43|0),($path|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        $62 = ___cxa_find_matching_catch()|0;
        $63 = tempRet0;
        $$01 = $63;$$02 = $62;
        ___resumeException($$02|0);
        // unreachable;
       }
       $49 = HEAP32[$0>>2]|0;
       HEAP32[$0>>2] = 0;
       $50 = HEAP32[$$byval_copy1>>2]|0;
       HEAP32[$49>>2] = 0;
       $51 = (($49) + 4|0);
       HEAP32[$51>>2] = 0;
       $52 = (($49) + 8|0);
       HEAP32[$52>>2] = $50;
       HEAP32[$44>>2] = $49;
       $53 = HEAP32[$43>>2]|0;
       $54 = HEAP32[$53>>2]|0;
       $55 = ($54|0)==(0|0);
       if ($55) {
        $58 = $49;
       } else {
        HEAP32[$43>>2] = $54;
        $$pre$i$i$i = HEAP32[$44>>2]|0;
        $58 = $$pre$i$i$i;
       }
       $56 = (($this) + 84|0);
       $57 = HEAP32[$56>>2]|0;
       __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($57,$58);
       $59 = (($this) + 88|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = (($60) + 1)|0;
       HEAP32[$59>>2] = $61;
       $$0 = 1;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $$01 = $10;$$02 = $9;
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN17PersistentManager21UnloadNonDirtyStreamsEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $i$011 = 0, $loadedStreams$0$lcssa = 0, $loadedStreams$014 = 0, $loadedStreams$1 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, $unloadedStreams$0$lcssa = 0, $unloadedStreams$013 = 0, $unloadedStreams$1 = 0;
 var $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp;
 $0 = sp + 12|0;
 $1 = sp + 8|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $loadedStreams$0$lcssa = 0;$unloadedStreams$0$lcssa = 0;
  HEAP32[$$byval_copy2>>2] = $unloadedStreams$0$lcssa;
  $vararg_ptr1 = (($$byval_copy2) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $loadedStreams$0$lcssa;
  _printf_console(639288,$$byval_copy2);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = (($this) + 20|0);
 $7 = (($this) + 32|0);
 $60 = $3;$i$011 = 0;$loadedStreams$014 = 0;$unloadedStreams$013 = 0;
 while(1) {
  $8 = HEAP32[$5>>2]|0;
  $9 = (($8) + (($i$011*24)|0)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  do {
   if ($11) {
    $59 = $60;$loadedStreams$1 = $loadedStreams$014;$unloadedStreams$1 = $unloadedStreams$013;
   } else {
    $12 = (($10) + 37|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     $15 = (($10) + 38|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = ($16<<24>>24)==(0);
     if ($17) {
      $19 = ((($8) + (($i$011*24)|0)|0) + 16|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       HEAP32[$19>>2] = 0;
       $22 = HEAP32[628360>>2]|0;
       $34 = $22;$35 = 0;
      } else {
       $23 = (($20) + 8|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($24|0)==(0);
       if (!($25)) {
        $26 = (($loadedStreams$014) + 1)|0;
        $59 = $60;$loadedStreams$1 = $26;$unloadedStreams$1 = $unloadedStreams$013;
        break;
       }
       HEAP32[$19>>2] = 0;
       $27 = HEAP32[628360>>2]|0;
       $28 = (($20) + 12|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29|0)>(-1);
       if ($30) {
        $31 = HEAP32[$20>>2]|0;
        $32 = (($20) + 4|0);
        $33 = HEAP32[$32>>2]|0;
        HEAP32[$0>>2] = $33;
        ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
        __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy2);
        HEAP32[$20>>2] = 0;
        $34 = $27;$35 = $20;
       } else {
        $34 = $27;$35 = $20;
       }
      }
      HEAP32[$1>>2] = $34;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($35,$$byval_copy2);
      $36 = HEAP32[$9>>2]|0;
      $37 = ($36|0)==(0|0);
      if (!($37)) {
       __ZN14SerializedFile7ReleaseEv($36);
       HEAP32[$9>>2] = 0;
      }
      $38 = HEAP32[$6>>2]|0;
      $39 = ((($38) + ($i$011<<4)|0) + 4|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ((($38) + ($i$011<<4)|0) + 8|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==($40|0);
      if (!($43)) {
       $__new_last2$i$i$i$i$i1 = $40;
       $scevgep$i$i$i$i$i2 = (($42) + -8|0);
       $44 = (0 - ($__new_last2$i$i$i$i$i1))|0;
       $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($44)|0);
       $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
       $45 = $uglygep3$i$i$i$i$i5 >>> 3;
       $46 = $45 ^ -1;
       $scevgep4$i$i$i$i$i6 = (($42) + ($46<<3)|0);
       HEAP32[$41>>2] = $scevgep4$i$i$i$i$i6;
      }
      $47 = HEAP32[$7>>2]|0;
      $48 = ((($47) + ($i$011<<4)|0) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ((($47) + ($i$011<<4)|0) + 8|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($51|0)==($49|0);
      if (!($52)) {
       $__new_last2$i$i$i$i$i = $49;
       $scevgep$i$i$i$i$i = (($51) + -8|0);
       $53 = (0 - ($__new_last2$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($53)|0);
       $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
       $54 = $uglygep3$i$i$i$i$i >>> 3;
       $55 = $54 ^ -1;
       $scevgep4$i$i$i$i$i = (($51) + ($55<<3)|0);
       HEAP32[$50>>2] = $scevgep4$i$i$i$i$i;
      }
      $56 = (($unloadedStreams$013) + 1)|0;
      $$pre = HEAP32[$2>>2]|0;
      $59 = $$pre;$loadedStreams$1 = $loadedStreams$014;$unloadedStreams$1 = $56;
      break;
     }
    }
    $18 = (($loadedStreams$014) + 1)|0;
    $59 = $60;$loadedStreams$1 = $18;$unloadedStreams$1 = $unloadedStreams$013;
   }
  } while(0);
  $57 = (($i$011) + 1)|0;
  $58 = ($57>>>0)<($59>>>0);
  if ($58) {
   $60 = $59;$i$011 = $57;$loadedStreams$014 = $loadedStreams$1;$unloadedStreams$013 = $unloadedStreams$1;
  } else {
   $loadedStreams$0$lcssa = $loadedStreams$1;$unloadedStreams$0$lcssa = $unloadedStreams$1;
   break;
  }
 }
 HEAP32[$$byval_copy2>>2] = $unloadedStreams$0$lcssa;
 $vararg_ptr1 = (($$byval_copy2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $loadedStreams$0$lcssa;
 _printf_console(639288,$$byval_copy2);
 STACKTOP = sp;return;
}
function __ZN17PersistentManager12UnloadStreamERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEb($this,$pathName,$unloadDestroyedList) {
 $this = $this|0;
 $pathName = $pathName|0;
 $unloadDestroyedList = $unloadDestroyedList|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__i$i$i = 0;
 var $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i4 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__i$i$i = sp + 8|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$4 & 2047]($this,$pathName,0)|0);
 $6 = ($5|0)==(-1);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + (($5*24)|0)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 if ($unloadDestroyedList) {
  $12 = ((($8) + (($5*24)|0)|0) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$12>>2] = 0;
  $14 = HEAP32[628360>>2]|0;
  $15 = ($13|0)==(0|0);
  if (!($15)) {
   $16 = (($13) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>(-1);
   if ($18) {
    $19 = HEAP32[$13>>2]|0;
    $20 = (($13) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy2);
    HEAP32[$13>>2] = 0;
   }
  }
  HEAP32[$1>>2] = $14;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($13,$$byval_copy2);
  $$pre = HEAP32[$9>>2]|0;
  $22 = ($$pre|0)==(0|0);
  if (!($22)) {
   $23 = $$pre;
   label = 8;
  }
 } else {
  $23 = $10;
  label = 8;
 }
 if ((label|0) == 8) {
  __ZN14SerializedFile7ReleaseEv($23);
  HEAP32[$9>>2] = 0;
 }
 $24 = (($this) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ((($25) + ($5<<4)|0) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ((($25) + ($5<<4)|0) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $__new_last2$i$i$i$i$i = $27;
  $scevgep$i$i$i$i$i = (($29) + -8|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($31)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $32 = $uglygep3$i$i$i$i$i >>> 3;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i = (($29) + ($33<<3)|0);
  HEAP32[$28>>2] = $scevgep4$i$i$i$i$i;
 }
 $34 = (($this) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($35) + ($5<<4)|0) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($35) + ($5<<4)|0) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==($37|0);
 if (!($40)) {
  $__new_last2$i$i$i$i$i4 = $37;
  $scevgep$i$i$i$i$i5 = (($39) + -8|0);
  $41 = (0 - ($__new_last2$i$i$i$i$i4))|0;
  $uglygep$i$i$i$i$i7 = (($scevgep$i$i$i$i$i5) + ($41)|0);
  $uglygep3$i$i$i$i$i8 = $uglygep$i$i$i$i$i7;
  $42 = $uglygep3$i$i$i$i$i8 >>> 3;
  $43 = $42 ^ -1;
  $scevgep4$i$i$i$i$i9 = (($39) + ($43<<3)|0);
  HEAP32[$38>>2] = $scevgep4$i$i$i$i$i9;
 }
 $44 = (($this) + 80|0);
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE4findIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_($__i$i$i,$44,$pathName);
 $45 = (($this) + 84|0);
 $46 = HEAP32[$__i$i$i>>2]|0;
 $47 = ($46|0)==($45|0);
 if ($47) {
  STACKTOP = sp;return;
 }
 $48 = (($46) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if ($50) {
  $$01$i$i$i$i = $46;
  while(1) {
   $53 = (($$01$i$i$i$i) + 8|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==($$01$i$i$i$i|0);
   if ($56) {
    $$0$i$i$i$i = $54;
    break;
   } else {
    $$01$i$i$i$i = $54;
   }
  }
 } else {
  $$0$i$i$i$i$i = $49;
  while(1) {
   $51 = HEAP32[$$0$i$i$i$i$i>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    $$0$i$i$i$i = $$0$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i = $51;
   }
  }
 }
 $57 = HEAP32[$44>>2]|0;
 $58 = ($57|0)==($46|0);
 if ($58) {
  HEAP32[$44>>2] = $$0$i$i$i$i;
 }
 $59 = (($this) + 88|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + -1)|0;
 HEAP32[$59>>2] = $61;
 $62 = (($46) + 16|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = $63 & 1;
 $65 = ($64<<24>>24)==(0);
 if (!($65)) {
  $66 = (($46) + 24|0);
  $67 = HEAP32[$66>>2]|0;
  __ZdlPv($67);
 }
 $68 = (($this) + 84|0);
 $69 = HEAP32[$68>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($69,$46);
 HEAP32[$0>>2] = 30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($46|0),($$byval_copy2|0));
 $70 = __THREW__; __THREW__ = 0;
 $71 = $70&1;
 if ($71) {
  $72 = ___cxa_find_matching_catch()|0;
  $73 = tempRet0;
  ___cxa_call_unexpected(($72|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN17PersistentManager31HasMemoryOrCachedSerializedFileERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = (__ZNKSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE14__count_uniqueIS6_EEjRKT_($0,$path)|0);
 $2 = ($1|0)==(1);
 STACKTOP = sp;return ($2|0);
}
function __ZN17PersistentManager14IsStreamLoadedERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$pathName) {
 $this = $this|0;
 $pathName = $pathName|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$2 & 2047]($this,$pathName,0)|0);
 $4 = ($3|0)==(-1);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + (($3*24)|0)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)!=(0|0);
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17PersistentManager9AddStreamEv($this) {
 $this = $this|0;
 var $$2 = 0, $$23 = 0, $$byval_copy5 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i14 = 0, $__new_last2$i$i$i$i$i$i$i$i$i28 = 0, $__new_last2$i$i$i$i$i$i$i$i$i5 = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i15 = 0, $scevgep$i$i$i$i$i$i$i$i$i29 = 0, $scevgep$i$i$i$i$i$i$i$i$i6 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i10 = 0;
 var $scevgep4$i$i$i$i$i$i$i$i$i19 = 0, $scevgep4$i$i$i$i$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i17 = 0, $uglygep$i$i$i$i$i$i$i$i$i31 = 0, $uglygep$i$i$i$i$i$i$i$i$i8 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i18 = 0, $uglygep3$i$i$i$i$i$i$i$i$i32 = 0, $uglygep3$i$i$i$i$i$i$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy5 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 16|0;
 $4 = sp + 32|0;
 $5 = (($this) + 4|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 HEAP32[$6>>2] = $8;
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($8>>>0)>($11>>>0);
 if ($12) {
  $13 = $10 << 1;
  $14 = ($13|0)==(0);
  $15 = $14 ? 1 : $13;
  $16 = ($11>>>0)<($15>>>0);
  do {
   if ($16) {
    $17 = ($10|0)>(-1);
    if ($17) {
     HEAP32[$9>>2] = $15;
     $18 = HEAP32[$5>>2]|0;
     $19 = ($15*24)|0;
     $20 = (($this) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     HEAP32[$0>>2] = $21;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($18,$19,8,$$byval_copy5,0,638872,370)|0);
     HEAP32[$5>>2] = $22;
     break;
    } else {
     $23 = ($15*24)|0;
     $24 = (($this) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$0>>2] = $25;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,8,$$byval_copy5,0,638872,352)|0);
     $27 = HEAP32[$5>>2]|0;
     $28 = HEAP32[$6>>2]|0;
     $29 = ($28*24)|0;
     _memcpy(($26|0),($27|0),($29|0))|0;
     HEAP32[$9>>2] = $15;
     HEAP32[$5>>2] = $26;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$6>>2]|0;
  $31 = $$pre$i$i;
 } else {
  $31 = $8;
 }
 $30 = (($31) + -1)|0;
 $32 = HEAP32[$5>>2]|0;
 $33 = (($32) + (($30*24)|0)|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($32) + (($30*24)|0)|0) + 8|0);
 $35 = $34;
 $36 = $35;
 HEAP32[$36>>2] = 0;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = 0;
 $39 = ((($32) + (($30*24)|0)|0) + 16|0);
 HEAP32[$39>>2] = 0;
 $40 = (($3) + 4|0);
 HEAP32[$40>>2] = 0;
 $41 = (($3) + 8|0);
 HEAP32[$41>>2] = 0;
 $42 = (($3) + 12|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 24|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 28|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($44|0)==($46|0);
 do {
  if ($47) {
   $55 = (($this) + 20|0);
   __THREW__ = 0;
   invoke_vii(3222,($55|0),($3|0));
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    label = 30;
   }
  } else {
   $48 = ($44|0)==(0|0);
   if ($48) {
    $54 = 0;
   } else {
    $49 = (($44) + 4|0);
    $50 = (($3) + 4|0);
    __THREW__ = 0;
    invoke_vii(3221,($49|0),($50|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     label = 30;
     break;
    }
    $$pre$i = HEAP32[$43>>2]|0;
    $54 = $$pre$i;
   }
   $53 = (($54) + 16|0);
   HEAP32[$43>>2] = $53;
  }
 } while(0);
 if ((label|0) == 30) {
  $98 = ___cxa_find_matching_catch()|0;
  $99 = tempRet0;
  $100 = HEAP32[$40>>2]|0;
  $101 = ($100|0)==(0|0);
  if ($101) {
   $$2 = $99;$$23 = $98;
   ___resumeException($$23|0);
   // unreachable;
  }
  $102 = HEAP32[$41>>2]|0;
  $103 = ($102|0)==($100|0);
  if (!($103)) {
   $__new_last2$i$i$i$i$i$i$i$i$i14 = $100;
   $scevgep$i$i$i$i$i$i$i$i$i15 = (($102) + -8|0);
   $104 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i14))|0;
   $uglygep$i$i$i$i$i$i$i$i$i17 = (($scevgep$i$i$i$i$i$i$i$i$i15) + ($104)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i18 = $uglygep$i$i$i$i$i$i$i$i$i17;
   $105 = $uglygep3$i$i$i$i$i$i$i$i$i18 >>> 3;
   $106 = $105 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i19 = (($102) + ($106<<3)|0);
   HEAP32[$41>>2] = $scevgep4$i$i$i$i$i$i$i$i$i19;
  }
  HEAP32[$0>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($100|0),($$byval_copy5|0));
  $107 = __THREW__; __THREW__ = 0;
  $108 = $107&1;
  if ($108) {
   $109 = ___cxa_find_matching_catch()|0;
   $110 = tempRet0;
   ___cxa_call_unexpected(($109|0));
   // unreachable;
  } else {
   $$2 = $99;$$23 = $98;
   ___resumeException($$23|0);
   // unreachable;
  }
 }
 $58 = HEAP32[$40>>2]|0;
 $59 = ($58|0)==(0|0);
 if (!($59)) {
  $60 = HEAP32[$41>>2]|0;
  $61 = ($60|0)==($58|0);
  if (!($61)) {
   $__new_last2$i$i$i$i$i$i$i$i$i5 = $58;
   $scevgep$i$i$i$i$i$i$i$i$i6 = (($60) + -8|0);
   $62 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i5))|0;
   $uglygep$i$i$i$i$i$i$i$i$i8 = (($scevgep$i$i$i$i$i$i$i$i$i6) + ($62)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i9 = $uglygep$i$i$i$i$i$i$i$i$i8;
   $63 = $uglygep3$i$i$i$i$i$i$i$i$i9 >>> 3;
   $64 = $63 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i10 = (($60) + ($64<<3)|0);
   HEAP32[$41>>2] = $scevgep4$i$i$i$i$i$i$i$i$i10;
  }
  HEAP32[$1>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($58|0),($$byval_copy5|0));
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if ($66) {
   $67 = ___cxa_find_matching_catch()|0;
   $68 = tempRet0;
   ___cxa_call_unexpected(($67|0));
   // unreachable;
  }
 }
 $69 = (($4) + 4|0);
 HEAP32[$69>>2] = 0;
 $70 = (($4) + 8|0);
 HEAP32[$70>>2] = 0;
 $71 = (($4) + 12|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 36|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($this) + 40|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($73|0)==($75|0);
 do {
  if ($76) {
   $84 = (($this) + 32|0);
   __THREW__ = 0;
   invoke_vii(3222,($84|0),($4|0));
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    label = 35;
   } else {
    label = 24;
   }
  } else {
   $77 = ($73|0)==(0|0);
   if ($77) {
    $83 = 0;
   } else {
    $78 = (($73) + 4|0);
    $79 = (($4) + 4|0);
    __THREW__ = 0;
    invoke_vii(3221,($78|0),($79|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 35;
     break;
    }
    $$pre$i23 = HEAP32[$72>>2]|0;
    $83 = $$pre$i23;
   }
   $82 = (($83) + 16|0);
   HEAP32[$72>>2] = $82;
   label = 24;
  }
 } while(0);
 if ((label|0) == 24) {
  $87 = HEAP32[$69>>2]|0;
  $88 = ($87|0)==(0|0);
  if ($88) {
   STACKTOP = sp;return;
  }
  $89 = HEAP32[$70>>2]|0;
  $90 = ($89|0)==($87|0);
  if (!($90)) {
   $__new_last2$i$i$i$i$i$i$i$i$i28 = $87;
   $scevgep$i$i$i$i$i$i$i$i$i29 = (($89) + -8|0);
   $91 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i28))|0;
   $uglygep$i$i$i$i$i$i$i$i$i31 = (($scevgep$i$i$i$i$i$i$i$i$i29) + ($91)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i32 = $uglygep$i$i$i$i$i$i$i$i$i31;
   $92 = $uglygep3$i$i$i$i$i$i$i$i$i32 >>> 3;
   $93 = $92 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i33 = (($89) + ($93<<3)|0);
   HEAP32[$70>>2] = $scevgep4$i$i$i$i$i$i$i$i$i33;
  }
  HEAP32[$0>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($87|0),($$byval_copy5|0));
  $94 = __THREW__; __THREW__ = 0;
  $95 = $94&1;
  if ($95) {
   $96 = ___cxa_find_matching_catch()|0;
   $97 = tempRet0;
   ___cxa_call_unexpected(($96|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 else if ((label|0) == 35) {
  $111 = ___cxa_find_matching_catch()|0;
  $112 = tempRet0;
  $113 = HEAP32[$69>>2]|0;
  $114 = ($113|0)==(0|0);
  if ($114) {
   $$2 = $112;$$23 = $111;
   ___resumeException($$23|0);
   // unreachable;
  }
  $115 = HEAP32[$70>>2]|0;
  $116 = ($115|0)==($113|0);
  if (!($116)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $113;
   $scevgep$i$i$i$i$i$i$i$i$i = (($115) + -8|0);
   $117 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($117)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $118 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
   $119 = $118 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($115) + ($119<<3)|0);
   HEAP32[$70>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
  HEAP32[$2>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($113|0),($$byval_copy5|0));
  $120 = __THREW__; __THREW__ = 0;
  $121 = $120&1;
  if ($121) {
   $122 = ___cxa_find_matching_catch()|0;
   $123 = tempRet0;
   ___cxa_call_unexpected(($122|0));
   // unreachable;
  } else {
   $$2 = $112;$$23 = $111;
   ___resumeException($$23|0);
   // unreachable;
  }
 }
}
function __ZN17PersistentManager12SetPathRemapERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_($this,$path,$absoluteRemappedPath) {
 $this = $this|0;
 $path = $path|0;
 $absoluteRemappedPath = $absoluteRemappedPath|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$pre = 0, $$pre$pre = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i2$i$i$i = 0, $__p$0$i$i$i4 = 0;
 var $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = HEAP8[$absoluteRemappedPath>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $9 = $4&255;
  $10 = $9 >>> 1;
  $12 = $10;
 } else {
  $7 = (($absoluteRemappedPath) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $12 = $8;
 }
 $11 = ($12|0)==(0);
 $13 = (($this) + 48|0);
 if ($11) {
  (__ZN13sorted_vectorINSt3__14pairINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES7_EEN10vector_mapIS7_S7_26compare_string_insensitive13stl_allocatorIS8_L18MemLabelIdentifier30ELi16EEE13value_compareESD_E9erase_oneIS7_EEjRKT_($13,$path)|0);
  STACKTOP = sp;return;
 }
 $14 = HEAP8[$path>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  ;HEAP32[$1+0>>2]=HEAP32[$path+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$path+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$path+8>>2]|0;
 } else {
  $17 = (($path) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($path) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20>>>0)>(4294967279);
  if ($21) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $22 = ($20>>>0)<(11);
  if ($22) {
   $23 = $20 << 1;
   $24 = $23&255;
   HEAP8[$1>>0] = $24;
   $25 = (($1) + 1|0);
   $__p$0$i$i$i = $25;
  } else {
   $26 = (($20) + 16)|0;
   $27 = $26 & -16;
   $28 = (__Znwj($27)|0);
   $29 = (($1) + 8|0);
   HEAP32[$29>>2] = $28;
   $30 = $27 | 1;
   HEAP32[$1>>2] = $30;
   $31 = (($1) + 4|0);
   HEAP32[$31>>2] = $20;
   $__p$0$i$i$i = $28;
  }
  _memcpy(($__p$0$i$i$i|0),($18|0),($20|0))|0;
  $32 = (($__p$0$i$i$i) + ($20)|0);
  HEAP8[$32>>0] = 0;
 }
 L20: do {
  if ($6) {
   ;HEAP32[$2+0>>2]=HEAP32[$absoluteRemappedPath+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$absoluteRemappedPath+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$absoluteRemappedPath+8>>2]|0;
   label = 23;
  } else {
   $33 = (($absoluteRemappedPath) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($absoluteRemappedPath) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36>>>0)>(4294967279);
   do {
    if ($37) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      // unreachable;
     }
    } else {
     $40 = ($36>>>0)<(11);
     if ($40) {
      $41 = $36 << 1;
      $42 = $41&255;
      HEAP8[$2>>0] = $42;
      $43 = (($2) + 1|0);
      $__p$0$i$i$i4 = $43;
     } else {
      $44 = (($36) + 16)|0;
      $45 = $44 & -16;
      __THREW__ = 0;
      $46 = (invoke_ii(2988,($45|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = (($2) + 8|0);
      HEAP32[$49>>2] = $46;
      $50 = $45 | 1;
      HEAP32[$2>>2] = $50;
      $51 = (($2) + 4|0);
      HEAP32[$51>>2] = $36;
      $__p$0$i$i$i4 = $46;
     }
     _memcpy(($__p$0$i$i$i4|0),($34|0),($36|0))|0;
     $52 = (($__p$0$i$i$i4) + ($36)|0);
     HEAP8[$52>>0] = 0;
     label = 23;
     break L20;
    }
   } while(0);
   $123 = ___cxa_find_matching_catch()|0;
   $124 = tempRet0;
   $$pre18 = HEAP8[$1>>0]|0;
   $$1 = $124;$$12 = $123;$145 = $$pre18;
  }
 } while(0);
 if ((label|0) == 23) {
  $53 = HEAP8[$1>>0]|0;
  $54 = $53 & 1;
  $55 = ($54<<24>>24)==(0);
  L35: do {
   if ($55) {
    ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
    label = 33;
   } else {
    $56 = (($1) + 8|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($1) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59>>>0)>(4294967279);
    do {
     if ($60) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if (!($62)) {
       // unreachable;
      }
     } else {
      $63 = ($59>>>0)<(11);
      if ($63) {
       $64 = $59 << 1;
       $65 = $64&255;
       HEAP8[$0>>0] = $65;
       $66 = (($0) + 1|0);
       $__p$0$i$i$i$i$i$i = $66;
      } else {
       $67 = (($59) + 16)|0;
       $68 = $67 & -16;
       __THREW__ = 0;
       $69 = (invoke_ii(2988,($68|0))|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break;
       }
       $72 = (($0) + 8|0);
       HEAP32[$72>>2] = $69;
       $73 = $68 | 1;
       HEAP32[$0>>2] = $73;
       $74 = (($0) + 4|0);
       HEAP32[$74>>2] = $59;
       $__p$0$i$i$i$i$i$i = $69;
      }
      _memcpy(($__p$0$i$i$i$i$i$i|0),($57|0),($59|0))|0;
      $75 = (($__p$0$i$i$i$i$i$i) + ($59)|0);
      HEAP8[$75>>0] = 0;
      label = 33;
      break L35;
     }
    } while(0);
    $125 = ___cxa_find_matching_catch()|0;
    $126 = tempRet0;
    $$pre$pre = HEAP8[$2>>0]|0;
    $$pre = $$pre$pre;$eh$lpad$body$index3Z2D = $126;$eh$lpad$body$indexZ2D = $125;
    label = 56;
   }
  } while(0);
  L48: do {
   if ((label|0) == 33) {
    $76 = (($0) + 12|0);
    $77 = HEAP8[$2>>0]|0;
    $78 = $77 & 1;
    $79 = ($78<<24>>24)==(0);
    L50: do {
     if ($79) {
      ;HEAP32[$76+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$2+8>>2]|0;
     } else {
      $80 = (($2) + 8|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = (($2) + 4|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = ($83>>>0)>(4294967279);
      do {
       if ($84) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if (!($86)) {
         // unreachable;
        }
       } else {
        $87 = ($83>>>0)<(11);
        if ($87) {
         $88 = $83 << 1;
         $89 = $88&255;
         HEAP8[$76>>0] = $89;
         $90 = (($76) + 1|0);
         $__p$0$i$i$i2$i$i$i = $90;
        } else {
         $91 = (($83) + 16)|0;
         $92 = $91 & -16;
         __THREW__ = 0;
         $93 = (invoke_ii(2988,($92|0))|0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         $96 = (($0) + 20|0);
         HEAP32[$96>>2] = $93;
         $97 = $92 | 1;
         HEAP32[$76>>2] = $97;
         $98 = (($0) + 16|0);
         HEAP32[$98>>2] = $83;
         $__p$0$i$i$i2$i$i$i = $93;
        }
        _memcpy(($__p$0$i$i$i2$i$i$i|0),($81|0),($83|0))|0;
        $99 = (($__p$0$i$i$i2$i$i$i) + ($83)|0);
        HEAP8[$99>>0] = 0;
        break L50;
       }
      } while(0);
      $100 = ___cxa_find_matching_catch()|0;
      $101 = tempRet0;
      $102 = HEAP8[$0>>0]|0;
      $103 = $102 & 1;
      $104 = ($103<<24>>24)==(0);
      if ($104) {
       $$pre = $77;$eh$lpad$body$index3Z2D = $101;$eh$lpad$body$indexZ2D = $100;
       label = 56;
       break L48;
      }
      $105 = (($0) + 8|0);
      $106 = HEAP32[$105>>2]|0;
      __ZdlPv($106);
      $$pre = $77;$eh$lpad$body$index3Z2D = $101;$eh$lpad$body$indexZ2D = $100;
      label = 56;
      break L48;
     }
    } while(0);
    __THREW__ = 0;
    invoke_viii(1929,($3|0),($13|0),($0|0));
    $107 = __THREW__; __THREW__ = 0;
    $108 = $107&1;
    if ($108) {
     $127 = ___cxa_find_matching_catch()|0;
     $128 = tempRet0;
     $129 = HEAP8[$76>>0]|0;
     $130 = $129 & 1;
     $131 = ($130<<24>>24)==(0);
     if (!($131)) {
      $132 = (($0) + 20|0);
      $133 = HEAP32[$132>>2]|0;
      __ZdlPv($133);
     }
     $134 = HEAP8[$0>>0]|0;
     $135 = $134 & 1;
     $136 = ($135<<24>>24)==(0);
     if ($136) {
      $$0 = $128;$$01 = $127;$140 = $77;
      break;
     }
     $137 = (($0) + 8|0);
     $138 = HEAP32[$137>>2]|0;
     __ZdlPv($138);
     $$0 = $128;$$01 = $127;$140 = $77;
     break;
    }
    $109 = HEAP8[$76>>0]|0;
    $110 = $109 & 1;
    $111 = ($110<<24>>24)==(0);
    if (!($111)) {
     $112 = (($0) + 20|0);
     $113 = HEAP32[$112>>2]|0;
     __ZdlPv($113);
    }
    $114 = HEAP8[$0>>0]|0;
    $115 = $114 & 1;
    $116 = ($115<<24>>24)==(0);
    if (!($116)) {
     $117 = (($0) + 8|0);
     $118 = HEAP32[$117>>2]|0;
     __ZdlPv($118);
    }
    if (!($79)) {
     $119 = (($2) + 8|0);
     $120 = HEAP32[$119>>2]|0;
     __ZdlPv($120);
    }
    if ($55) {
     STACKTOP = sp;return;
    }
    $121 = (($1) + 8|0);
    $122 = HEAP32[$121>>2]|0;
    __ZdlPv($122);
    STACKTOP = sp;return;
   }
  } while(0);
  if ((label|0) == 56) {
   $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;$140 = $$pre;
  }
  $139 = $140 & 1;
  $141 = ($139<<24>>24)==(0);
  if ($141) {
   $$1 = $$0;$$12 = $$01;$145 = $53;
  } else {
   $142 = (($2) + 8|0);
   $143 = HEAP32[$142>>2]|0;
   __ZdlPv($143);
   $$1 = $$0;$$12 = $$01;$145 = $53;
  }
 }
 $144 = $145 & 1;
 $146 = ($144<<24>>24)==(0);
 if ($146) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $147 = (($1) + 8|0);
 $148 = HEAP32[$147>>2]|0;
 __ZdlPv($148);
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN13sorted_vectorINSt3__14pairINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES7_EEN10vector_mapIS7_S7_26compare_string_insensitive13stl_allocatorIS8_L18MemLabelIdentifier30ELi16EEE13value_compareESD_E9erase_oneIS7_EEjRKT_($this,$x) {
 $this = $this|0;
 $x = $x|0;
 var $$0 = 0, $$0$lcssa$i$i$i = 0, $$012$i$i$i = 0, $$03$i$i$i = 0, $$neg2$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$sum$i = 0, $$sum$i$i$i = 0, $$sum2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__first5$i$i$i = 0, $__len$0$be$i$i$i = 0, $__len$03$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep7$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep6$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = $1;
 $6 = $3;
 $7 = (($6) - ($5))|0;
 $8 = (($7|0) / 24)&-1;
 $9 = (($x) + 1|0);
 $10 = (($x) + 8|0);
 $13 = $1;$__len$03$i$i$i = $8;
 while(1) {
  $11 = (($__len$03$i$i$i|0) / 2)&-1;
  $12 = (($13) + (($11*24)|0)|0);
  $14 = HEAP8[$12>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $19 = (($12) + 1|0);
   $24 = $19;
  } else {
   $17 = ((($13) + (($11*24)|0)|0) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $24 = $18;
  }
  $20 = HEAP8[$x>>0]|0;
  $21 = $20 & 1;
  $22 = ($21<<24>>24)==(0);
  if ($22) {
   $25 = $9;
  } else {
   $23 = HEAP32[$10>>2]|0;
   $25 = $23;
  }
  $26 = (__Z7StrICmpPKcS0_($24,$25)|0);
  $27 = ($26|0)<(0);
  if ($27) {
   $$sum$i$i$i = (($11) + 1)|0;
   $28 = (($13) + (($$sum$i$i$i*24)|0)|0);
   $$neg2$i$i$i = (($__len$03$i$i$i) + -1)|0;
   $29 = (($$neg2$i$i$i) - ($11))|0;
   $32 = $28;$__len$0$be$i$i$i = $29;
  } else {
   $32 = $13;$__len$0$be$i$i$i = $11;
  }
  $30 = ($__len$0$be$i$i$i|0)==(0);
  if ($30) {
   break;
  } else {
   $13 = $32;$__len$03$i$i$i = $__len$0$be$i$i$i;
  }
 }
 $$pre = HEAP32[$2>>2]|0;
 $31 = ($32|0)==($$pre|0);
 if ($31) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP8[$x>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $38 = (($x) + 1|0);
  $45 = $38;
 } else {
  $36 = (($x) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $45 = $37;
 }
 $39 = HEAP8[$32>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  $44 = (($32) + 1|0);
  $46 = $44;
 } else {
  $42 = (($32) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $46 = $43;
 }
 $47 = (__Z7StrICmpPKcS0_($45,$46)|0);
 $48 = ($47|0)<(0);
 if ($48) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = HEAP32[$0>>2]|0;
 $50 = $32;
 $51 = $49;
 $52 = (($50) - ($51))|0;
 $53 = (($52|0) / 24)&-1;
 $54 = (($49) + (($53*24)|0)|0);
 $$sum$i = (($53) + 1)|0;
 $55 = (($49) + (($$sum$i*24)|0)|0);
 $56 = HEAP32[$2>>2]|0;
 $57 = ($55|0)==($56|0);
 if ($57) {
  $$0$lcssa$i$i$i = $54;$66 = $55;
 } else {
  $__first5$i$i$i = $55;
  $scevgep$i$i$i = (($56) + -24|0);
  $58 = (0 - ($__first5$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($58)|0);
  $$012$i$i$i = $55;$$03$i$i$i = $54;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($$03$i$i$i,$$012$i$i$i)|0);
   $59 = (($$03$i$i$i) + 12|0);
   $60 = (($$012$i$i$i) + 12|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($59,$60)|0);
   $61 = (($$012$i$i$i) + 24|0);
   $62 = (($$03$i$i$i) + 24|0);
   $63 = ($61|0)==($56|0);
   if ($63) {
    break;
   } else {
    $$012$i$i$i = $61;$$03$i$i$i = $62;
   }
  }
  $uglygep6$i$i$i = $uglygep$i$i$i;
  $64 = (($uglygep6$i$i$i>>>0) / 24)&-1;
  $$sum2$i = (($64) + ($$sum$i))|0;
  $scevgep7$i$i$i = (($49) + (($$sum2$i*24)|0)|0);
  $$pre$i = HEAP32[$2>>2]|0;
  $$0$lcssa$i$i$i = $scevgep7$i$i$i;$66 = $$pre$i;
 }
 $65 = ($66|0)==($$0$lcssa$i$i$i|0);
 if ($65) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $68 = $66;
 }
 while(1) {
  $67 = (($68) + -24|0);
  HEAP32[$2>>2] = $67;
  $69 = (($68) + -12|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = $70 & 1;
  $72 = ($71<<24>>24)==(0);
  if (!($72)) {
   $73 = (($68) + -4|0);
   $74 = HEAP32[$73>>2]|0;
   __ZdlPv($74);
  }
  $75 = HEAP8[$67>>0]|0;
  $76 = $75 & 1;
  $77 = ($76<<24>>24)==(0);
  if (!($77)) {
   $80 = (($68) + -16|0);
   $81 = HEAP32[$80>>2]|0;
   __ZdlPv($81);
  }
  $78 = HEAP32[$2>>2]|0;
  $79 = ($78|0)==($$0$lcssa$i$i$i|0);
  if ($79) {
   $$0 = 1;
   break;
  } else {
   $68 = $78;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN13sorted_vectorINSt3__14pairINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES7_EEN10vector_mapIS7_S7_26compare_string_insensitive13stl_allocatorIS8_L18MemLabelIdentifier30ELi16EEE13value_compareESD_E10insert_oneERKS8_($agg$result,$this,$x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $x = $x|0;
 var $$byval_copy = 0, $$c$i$i$i4 = 0, $$neg2$i$i$i = 0, $$pre = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__len$0$be$i$i$i = 0, $__len$03$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 if ($6) {
  $52 = $3;
 } else {
  $7 = $3;
  $8 = $5;
  $9 = (($8) - ($7))|0;
  $10 = (($9|0) / 24)&-1;
  $11 = (($x) + 1|0);
  $12 = (($x) + 8|0);
  $15 = $3;$__len$03$i$i$i = $10;
  while(1) {
   $13 = (($__len$03$i$i$i|0) / 2)&-1;
   $14 = (($15) + (($13*24)|0)|0);
   $16 = HEAP8[$14>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    $21 = (($14) + 1|0);
    $26 = $21;
   } else {
    $19 = ((($15) + (($13*24)|0)|0) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $26 = $20;
   }
   $22 = HEAP8[$x>>0]|0;
   $23 = $22 & 1;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    $27 = $11;
   } else {
    $25 = HEAP32[$12>>2]|0;
    $27 = $25;
   }
   $28 = (__Z7StrICmpPKcS0_($26,$27)|0);
   $29 = ($28|0)<(0);
   if ($29) {
    $$sum$i$i$i = (($13) + 1)|0;
    $30 = (($15) + (($$sum$i$i$i*24)|0)|0);
    $$neg2$i$i$i = (($__len$03$i$i$i) + -1)|0;
    $31 = (($$neg2$i$i$i) - ($13))|0;
    $34 = $30;$__len$0$be$i$i$i = $31;
   } else {
    $34 = $15;$__len$0$be$i$i$i = $13;
   }
   $32 = ($__len$0$be$i$i$i|0)==(0);
   if ($32) {
    break;
   } else {
    $15 = $34;$__len$03$i$i$i = $__len$0$be$i$i$i;
   }
  }
  $$pre = HEAP32[$4>>2]|0;
  $33 = ($34|0)==($$pre|0);
  if ($33) {
   $52 = $34;
  } else {
   $35 = HEAP8[$x>>0]|0;
   $36 = $35 & 1;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    $40 = (($x) + 1|0);
    $47 = $40;
   } else {
    $38 = (($x) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $47 = $39;
   }
   $41 = HEAP8[$34>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $46 = (($34) + 1|0);
    $48 = $46;
   } else {
    $44 = (($34) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $48 = $45;
   }
   $49 = (__Z7StrICmpPKcS0_($47,$48)|0);
   $50 = ($49|0)<(0);
   if ($50) {
    $52 = $34;
   } else {
    HEAP32[$agg$result>>2] = $34;
    $55 = (($agg$result) + 4|0);
    HEAP8[$55>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 $51 = (($this) + 4|0);
 HEAP32[$1>>2] = $52;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__16vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EE13stl_allocatorIS8_L18MemLabelIdentifier30ELi16EEE6insertENS_11__wrap_iterIPKS8_EERSE_($0,$51,$$byval_copy,$x);
 $53 = HEAP32[$0>>2]|0;
 $$c$i$i$i4 = $53;
 HEAP32[$agg$result>>2] = $$c$i$i$i4;
 $54 = (($agg$result) + 4|0);
 HEAP8[$54>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EE13stl_allocatorIS8_L18MemLabelIdentifier30ELi16EEE6insertENS_11__wrap_iterIPKS8_EERSE_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i19 = 0, $$0$i20 = 0, $$01$i$i = 0, $$01$i3$i = 0, $$012$i$i$i = 0, $$03$i$i$i = 0, $$byval_copy18 = 0, $$pre = 0, $$pre$i = 0, $$pre40 = 0, $$sum = 0, $$sum24 = 0, $$sum25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, $eh$lpad$body21$index9Z2D = 0, $eh$lpad$body21$indexZ2D = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy18 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$__position>>2]|0;
 $5 = $4;
 $6 = $3;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 24)&-1;
 $9 = (($3) + (($8*24)|0)|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $15 = ($9|0)==($11|0);
  if ($15) {
   $16 = ($9|0)==(0|0);
   if ($16) {
    $18 = 0;
   } else {
    __ZNSt3__14pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_EC2ERKS7_($9,$__x);
    $$pre = HEAP32[$10>>2]|0;
    $18 = $$pre;
   }
   $17 = (($18) + 24|0);
   HEAP32[$10>>2] = $17;
   $__p$0 = $9;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($8) + 1)|0;
  $19 = (($3) + (($$sum*24)|0)|0);
  $20 = $11;
  $21 = $19;
  $22 = (($20) - ($21))|0;
  $23 = (($22|0) / 24)&-1;
  $$sum25 = (($23) + ($8))|0;
  $24 = (($3) + (($$sum25*24)|0)|0);
  $25 = ($24>>>0)<($11>>>0);
  if ($25) {
   $27 = $11;$__i$01$i = $24;
   while(1) {
    $26 = ($27|0)==(0|0);
    if ($26) {
     $30 = 0;
    } else {
     __ZNSt3__14pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_EC2ERKS7_($27,$__i$01$i);
     $$pre$i = HEAP32[$10>>2]|0;
     $30 = $$pre$i;
    }
    $28 = (($__i$01$i) + 24|0);
    $29 = (($30) + 24|0);
    HEAP32[$10>>2] = $29;
    $31 = ($28>>>0)<($11>>>0);
    if ($31) {
     $27 = $29;$__i$01$i = $28;
    } else {
     break;
    }
   }
  }
  $32 = ($11|0)==($19|0);
  if (!($32)) {
   $$012$i$i$i = $24;$$03$i$i$i = $11;
   while(1) {
    $33 = (($$03$i$i$i) + -24|0);
    $34 = (($$012$i$i$i) + -24|0);
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($33,$34)|0);
    $35 = (($$03$i$i$i) + -12|0);
    $36 = (($$012$i$i$i) + -12|0);
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($35,$36)|0);
    $37 = ($34|0)==($9|0);
    if ($37) {
     break;
    } else {
     $$012$i$i$i = $34;$$03$i$i$i = $33;
    }
   }
  }
  $38 = ($9>>>0)>($__x>>>0);
  if ($38) {
   $__xr$0 = $__x;
  } else {
   $39 = HEAP32[$10>>2]|0;
   $40 = ($39>>>0)>($__x>>>0);
   $41 = (($__x) + 24|0);
   $$ = $40 ? $41 : $__x;
   $__xr$0 = $$;
  }
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($9,$__xr$0)|0);
  $42 = ((($3) + (($8*24)|0)|0) + 12|0);
  $43 = (($__xr$0) + 12|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($42,$43)|0);
  $__p$0 = $9;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $44 = $11;
 $45 = (($44) - ($6))|0;
 $46 = (($45|0) / 24)&-1;
 $47 = (($46) + 1)|0;
 $48 = ($47|0)<(0);
 if ($48) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $49 = $13;
 $50 = (($49) - ($6))|0;
 $51 = (($50|0) / 24)&-1;
 $52 = ($51>>>0)<(1073741823);
 if ($52) {
  $54 = $51 << 1;
  $55 = ($54>>>0)<($47>>>0);
  $56 = $55 ? $47 : $54;
  $57 = (($7|0) / 24)&-1;
  $58 = ($56|0)==(0);
  if ($58) {
   $$0$i20 = 0;$62 = 0;$63 = $57;
  } else {
   $$0$i19 = $56;$164 = $57;
   label = 20;
  }
 } else {
  $53 = (($7|0) / 24)&-1;
  $$0$i19 = 2147483647;$164 = $53;
  label = 20;
 }
 if ((label|0) == 20) {
  $59 = ($$0$i19*24)|0;
  HEAP32[$0>>2] = 30;
  ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
  $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy18,0,638872,79)|0);
  $$0$i20 = $$0$i19;$62 = $60;$63 = $164;
 }
 $61 = (($62) + (($63*24)|0)|0);
 $64 = (($62) + (($$0$i20*24)|0)|0);
 $65 = ($63|0)==($$0$i20|0);
 do {
  if ($65) {
   $66 = ($63|0)>(0);
   $67 = (($7|0) / 24)&-1;
   if ($66) {
    $68 = (($67) + 1)|0;
    $69 = (($68|0) / -2)&-1;
    $$sum24 = (($69) + ($63))|0;
    $70 = (($62) + (($$sum24*24)|0)|0);
    $111 = $64;$165 = $62;$87 = $70;
    label = 28;
    break;
   }
   $71 = $67 << 1;
   $72 = ($71|0)==(0);
   $73 = $72 ? 1 : $71;
   $74 = ($73*24)|0;
   HEAP32[$1>>2] = 30;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$1+0>>2]|0;
   $75 = (invoke_iiiiiii(102,($74|0),16,($$byval_copy18|0),0,(638872|0),79)|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    $133 = ___cxa_find_matching_catch()|0;
    $134 = tempRet0;
    $159 = $62;$eh$lpad$body21$index9Z2D = $134;$eh$lpad$body21$indexZ2D = $133;
    break;
   }
   $78 = $73 >>> 2;
   $79 = (($75) + (($78*24)|0)|0);
   $80 = (($75) + (($73*24)|0)|0);
   $81 = ($62|0)==(0|0);
   if ($81) {
    $111 = $80;$165 = $75;$87 = $79;
    label = 28;
   } else {
    HEAP32[$0>>2] = 30;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($62|0),($$byval_copy18|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     $84 = ___cxa_find_matching_catch()|0;
     $85 = tempRet0;
     ___cxa_call_unexpected(($84|0));
     // unreachable;
    } else {
     $111 = $80;$165 = $75;$87 = $79;
     label = 28;
    }
   }
  } else {
   $111 = $64;$165 = $62;$87 = $61;
   label = 28;
  }
 } while(0);
 do {
  if ((label|0) == 28) {
   $86 = ($87|0)==(0|0);
   if ($86) {
    $91 = 0;
   } else {
    __THREW__ = 0;
    invoke_vii(3223,($87|0),($__x|0));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     $139 = ___cxa_find_matching_catch()|0;
     $140 = tempRet0;
     $159 = $165;$eh$lpad$body21$index9Z2D = $140;$eh$lpad$body21$indexZ2D = $139;
     break;
    } else {
     $91 = $87;
    }
   }
   $90 = (($91) + 24|0);
   $92 = HEAP32[$this>>2]|0;
   $93 = ($92|0)==($9|0);
   L51: do {
    if ($93) {
     $109 = $87;
     label = 33;
    } else {
     $$01$i3$i = $9;$95 = $87;
     while(1) {
      $94 = (($95) + -24|0);
      $96 = (($$01$i3$i) + -24|0);
      __THREW__ = 0;
      invoke_vii(3223,($94|0),($96|0));
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       break;
      }
      $99 = ($96|0)==($92|0);
      if ($99) {
       $109 = $94;
       label = 33;
       break L51;
      } else {
       $$01$i3$i = $96;$95 = $94;
      }
     }
     $137 = ___cxa_find_matching_catch()|0;
     $138 = tempRet0;
     $142 = $90;$143 = $95;$lpad$phi$index = $137;$lpad$phi$index2 = $138;
    }
   } while(0);
   L56: do {
    if ((label|0) == 33) {
     $100 = HEAP32[$10>>2]|0;
     $101 = ($100|0)==($9|0);
     do {
      if ($101) {
       $110 = $90;$113 = $9;
      } else {
       $$01$i$i = $9;$102 = $90;
       while(1) {
        __THREW__ = 0;
        invoke_vii(3223,($102|0),($$01$i$i|0));
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 47;
         break;
        }
        $105 = (($$01$i$i) + 24|0);
        $106 = (($102) + 24|0);
        $107 = ($105|0)==($100|0);
        if ($107) {
         label = 36;
         break;
        } else {
         $$01$i$i = $105;$102 = $106;
        }
       }
       if ((label|0) == 36) {
        $$pre40 = HEAP32[$10>>2]|0;
        $110 = $106;$113 = $$pre40;
        break;
       }
       else if ((label|0) == 47) {
        $135 = ___cxa_find_matching_catch()|0;
        $136 = tempRet0;
        $142 = $102;$143 = $109;$lpad$phi$index = $135;$lpad$phi$index2 = $136;
        break L56;
       }
      }
     } while(0);
     $108 = HEAP32[$this>>2]|0;
     HEAP32[$this>>2] = $109;
     HEAP32[$10>>2] = $110;
     HEAP32[$12>>2] = $111;
     $112 = ($113|0)==($108|0);
     if (!($112)) {
      $115 = $113;
      while(1) {
       $114 = (($115) + -24|0);
       $116 = (($115) + -12|0);
       $117 = HEAP8[$116>>0]|0;
       $118 = $117 & 1;
       $119 = ($118<<24>>24)==(0);
       if (!($119)) {
        $120 = (($115) + -4|0);
        $121 = HEAP32[$120>>2]|0;
        __ZdlPv($121);
       }
       $122 = HEAP8[$114>>0]|0;
       $123 = $122 & 1;
       $124 = ($123<<24>>24)==(0);
       if (!($124)) {
        $126 = (($115) + -16|0);
        $127 = HEAP32[$126>>2]|0;
        __ZdlPv($127);
       }
       $125 = ($114|0)==($108|0);
       if ($125) {
        break;
       } else {
        $115 = $114;
       }
      }
     }
     $128 = ($108|0)==(0|0);
     if ($128) {
      $__p$0 = $87;
      HEAP32[$agg$result>>2] = $__p$0;
      STACKTOP = sp;return;
     }
     HEAP32[$1>>2] = 30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($108|0),($$byval_copy18|0));
     $129 = __THREW__; __THREW__ = 0;
     $130 = $129&1;
     if ($130) {
      $131 = ___cxa_find_matching_catch()|0;
      $132 = tempRet0;
      ___cxa_call_unexpected(($131|0));
      // unreachable;
     } else {
      $__p$0 = $87;
      HEAP32[$agg$result>>2] = $__p$0;
      STACKTOP = sp;return;
     }
    }
   } while(0);
   $141 = ($142|0)==($143|0);
   if ($141) {
    $159 = $165;$eh$lpad$body21$index9Z2D = $lpad$phi$index2;$eh$lpad$body21$indexZ2D = $lpad$phi$index;
   } else {
    $145 = $142;
    while(1) {
     $144 = (($145) + -24|0);
     $146 = (($145) + -12|0);
     $147 = HEAP8[$146>>0]|0;
     $148 = $147 & 1;
     $149 = ($148<<24>>24)==(0);
     if (!($149)) {
      $150 = (($145) + -4|0);
      $151 = HEAP32[$150>>2]|0;
      __ZdlPv($151);
     }
     $152 = HEAP8[$144>>0]|0;
     $153 = $152 & 1;
     $154 = ($153<<24>>24)==(0);
     if (!($154)) {
      $156 = (($145) + -16|0);
      $157 = HEAP32[$156>>2]|0;
      __ZdlPv($157);
     }
     $155 = ($144|0)==($143|0);
     if ($155) {
      $159 = $165;$eh$lpad$body21$index9Z2D = $lpad$phi$index2;$eh$lpad$body21$indexZ2D = $lpad$phi$index;
      break;
     } else {
      $145 = $144;
     }
    }
   }
  }
 } while(0);
 $158 = ($159|0)==(0|0);
 if ($158) {
  ___resumeException($eh$lpad$body21$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$2>>2] = 30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($159|0),($$byval_copy18|0));
 $160 = __THREW__; __THREW__ = 0;
 $161 = $160&1;
 if ($161) {
  $162 = ___cxa_find_matching_catch()|0;
  $163 = tempRet0;
  ___cxa_call_unexpected(($162|0));
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body21$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__14pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_EC2ERKS7_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  ;HEAP32[$this+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$0+8>>2]|0;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($0) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7>>>0)>(4294967279);
  if ($8) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $9 = ($7>>>0)<(11);
  if ($9) {
   $10 = $7 << 1;
   $11 = $10&255;
   HEAP8[$this>>0] = $11;
   $12 = (($this) + 1|0);
   $__p$0$i$i$i = $12;
  } else {
   $13 = (($7) + 16)|0;
   $14 = $13 & -16;
   $15 = (__Znwj($14)|0);
   $16 = (($this) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = $14 | 1;
   HEAP32[$this>>2] = $17;
   $18 = (($this) + 4|0);
   HEAP32[$18>>2] = $7;
   $__p$0$i$i$i = $15;
  }
  _memcpy(($__p$0$i$i$i|0),($5|0),($7|0))|0;
  $19 = (($__p$0$i$i$i) + ($7)|0);
  HEAP8[$19>>0] = 0;
 }
 $20 = (($this) + 12|0);
 $21 = (($0) + 12|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  ;HEAP32[$20+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$21+8>>2]|0;
  STACKTOP = sp;return;
 }
 $25 = (($0) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($0) + 16|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28>>>0)>(4294967279);
 do {
  if ($29) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    // unreachable;
   }
  } else {
   $32 = ($28>>>0)<(11);
   if ($32) {
    $33 = $28 << 1;
    $34 = $33&255;
    HEAP8[$20>>0] = $34;
    $35 = (($20) + 1|0);
    $__p$0$i$i$i2 = $35;
   } else {
    $36 = (($28) + 16)|0;
    $37 = $36 & -16;
    __THREW__ = 0;
    $38 = (invoke_ii(2988,($37|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    $41 = (($this) + 20|0);
    HEAP32[$41>>2] = $38;
    $42 = $37 | 1;
    HEAP32[$20>>2] = $42;
    $43 = (($this) + 16|0);
    HEAP32[$43>>2] = $28;
    $__p$0$i$i$i2 = $38;
   }
   _memcpy(($__p$0$i$i$i2|0),($26|0),($28|0))|0;
   $44 = (($__p$0$i$i$i2) + ($28)|0);
   HEAP8[$44>>0] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $45 = ___cxa_find_matching_catch()|0;
 $46 = tempRet0;
 $47 = HEAP8[$this>>0]|0;
 $48 = $47 & 1;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  ___resumeException($45|0);
  // unreachable;
 }
 $50 = (($this) + 8|0);
 $51 = HEAP32[$50>>2]|0;
 __ZdlPv($51);
 ___resumeException($45|0);
 // unreachable;
}
function __ZN13sorted_vectorINSt3__14pairINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES7_EEN10vector_mapIS7_S7_26compare_string_insensitive13stl_allocatorIS8_L18MemLabelIdentifier30ELi16EEE13value_compareESD_E4findIS7_EENS0_11__wrap_iterIPS8_EERKT_($agg$result,$this,$x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $x = $x|0;
 var $$neg2$i$i$i = 0, $$pre = 0, $$pre1 = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i = 0, $__len$03$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 do {
  if ($4) {
   $49 = $1;
  } else {
   $5 = $1;
   $6 = $3;
   $7 = (($6) - ($5))|0;
   $8 = (($7|0) / 24)&-1;
   $9 = (($x) + 1|0);
   $10 = (($x) + 8|0);
   $13 = $1;$__len$03$i$i$i = $8;
   while(1) {
    $11 = (($__len$03$i$i$i|0) / 2)&-1;
    $12 = (($13) + (($11*24)|0)|0);
    $14 = HEAP8[$12>>0]|0;
    $15 = $14 & 1;
    $16 = ($15<<24>>24)==(0);
    if ($16) {
     $19 = (($12) + 1|0);
     $24 = $19;
    } else {
     $17 = ((($13) + (($11*24)|0)|0) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     $24 = $18;
    }
    $20 = HEAP8[$x>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $25 = $9;
    } else {
     $23 = HEAP32[$10>>2]|0;
     $25 = $23;
    }
    $26 = (__Z7StrICmpPKcS0_($24,$25)|0);
    $27 = ($26|0)<(0);
    if ($27) {
     $$sum$i$i$i = (($11) + 1)|0;
     $28 = (($13) + (($$sum$i$i$i*24)|0)|0);
     $$neg2$i$i$i = (($__len$03$i$i$i) + -1)|0;
     $29 = (($$neg2$i$i$i) - ($11))|0;
     $32 = $28;$__len$0$be$i$i$i = $29;
    } else {
     $32 = $13;$__len$0$be$i$i$i = $11;
    }
    $30 = ($__len$0$be$i$i$i|0)==(0);
    if ($30) {
     break;
    } else {
     $13 = $32;$__len$03$i$i$i = $__len$0$be$i$i$i;
    }
   }
   $$pre = HEAP32[$2>>2]|0;
   $31 = ($32|0)==($$pre|0);
   if ($31) {
    $49 = $$pre;
   } else {
    $33 = HEAP8[$x>>0]|0;
    $34 = $33 & 1;
    $35 = ($34<<24>>24)==(0);
    if ($35) {
     $38 = (($x) + 1|0);
     $45 = $38;
    } else {
     $36 = (($x) + 8|0);
     $37 = HEAP32[$36>>2]|0;
     $45 = $37;
    }
    $39 = HEAP8[$32>>0]|0;
    $40 = $39 & 1;
    $41 = ($40<<24>>24)==(0);
    if ($41) {
     $44 = (($32) + 1|0);
     $46 = $44;
    } else {
     $42 = (($32) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $46 = $43;
    }
    $47 = (__Z7StrICmpPKcS0_($45,$46)|0);
    $48 = ($47|0)<(0);
    if ($48) {
     $$pre1 = HEAP32[$2>>2]|0;
     $49 = $$pre1;
     break;
    }
    HEAP32[$agg$result>>2] = $32;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 HEAP32[$agg$result>>2] = $49;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier30ELi16EEES4_IS9_LS7_30ELi16EEE21__push_back_slow_pathIKS9_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i20 = 0, $$0$i21 = 0, $$01$i$i = 0, $$byval_copy11 = 0, $$index = 0, $$index3 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i3 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy11 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 4;
 $9 = (($8) + 1)|0;
 $10 = ($9|0)<(0);
 if ($10) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($6))|0;
 $15 = $14 >> 4;
 $16 = ($15>>>0)<(1073741823);
 if ($16) {
  $17 = $14 >> 3;
  $18 = ($17>>>0)<($9>>>0);
  $19 = $18 ? $9 : $17;
  $20 = ($19|0)==(0);
  if ($20) {
   $$0$i21 = 0;$24 = 0;
  } else {
   $$0$i20 = $19;
   label = 5;
  }
 } else {
  $$0$i20 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $21 = $$0$i20 << 4;
  HEAP32[$0>>2] = 30;
  ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
  $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,16,$$byval_copy11,0,638872,79)|0);
  $$0$i21 = $$0$i20;$24 = $22;
 }
 $23 = (($24) + ($8<<4)|0);
 $25 = (($24) + ($$0$i21<<4)|0);
 $26 = ($23|0)==(0|0);
 if ($26) {
  label = 9;
 } else {
  $27 = HEAP8[$__x>>0]|0;
  HEAP8[$23>>0] = $27;
  $28 = ((($24) + ($8<<4)|0) + 4|0);
  $29 = (($__x) + 4|0);
  __THREW__ = 0;
  invoke_vii(3221,($28|0),($29|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   $$index = $32;$$index3 = $33;
  } else {
   label = 9;
  }
 }
 L12: do {
  if ((label|0) == 9) {
   $34 = (($24) + ($9<<4)|0);
   $35 = HEAP32[$this>>2]|0;
   $36 = HEAP32[$2>>2]|0;
   $37 = ($36|0)==($35|0);
   L14: do {
    if ($37) {
     HEAP32[$this>>2] = $23;
     HEAP32[$2>>2] = $34;
     HEAP32[$11>>2] = $25;
     $66 = $35;
    } else {
     $$01$i$i = $36;$40 = $23;
     while(1) {
      $38 = (($$01$i$i) + -16|0);
      $39 = (($40) + -16|0);
      $41 = HEAP8[$38>>0]|0;
      HEAP8[$39>>0] = $41;
      $42 = (($40) + -12|0);
      $43 = (($$01$i$i) + -12|0);
      __THREW__ = 0;
      invoke_vii(3221,($42|0),($43|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 25;
       break;
      }
      $46 = (($40) + -16|0);
      $47 = ($38|0)==($35|0);
      if ($47) {
       label = 13;
       break;
      } else {
       $$01$i$i = $38;$40 = $46;
      }
     }
     if ((label|0) == 13) {
      $$pre$i = HEAP32[$this>>2]|0;
      $$pre = HEAP32[$2>>2]|0;
      HEAP32[$this>>2] = $46;
      HEAP32[$2>>2] = $34;
      HEAP32[$11>>2] = $25;
      $48 = ($$pre|0)==($$pre$i|0);
      if ($48) {
       $66 = $$pre$i;
       break;
      }
      $50 = $$pre;
      while(1) {
       $49 = (($50) + -16|0);
       $51 = (($50) + -12|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52|0)==(0|0);
       if (!($53)) {
        $55 = (($50) + -8|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = ($56|0)==($52|0);
        if (!($57)) {
         $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i3 = $52;
         $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = (($56) + -8|0);
         $58 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i3))|0;
         $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i6 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4) + ($58)|0);
         $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i6;
         $59 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 >>> 3;
         $60 = $59 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = (($56) + ($60<<3)|0);
         HEAP32[$55>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8;
        }
        HEAP32[$1>>2] = 30;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($52|0),($$byval_copy11|0));
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         break;
        }
       }
       $54 = ($49|0)==($$pre$i|0);
       if ($54) {
        $66 = $$pre$i;
        break L14;
       } else {
        $50 = $49;
       }
      }
      $63 = ___cxa_find_matching_catch()|0;
      $64 = tempRet0;
      ___cxa_call_unexpected(($63|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $71 = ___cxa_find_matching_catch()|0;
      $72 = tempRet0;
      $73 = ($34|0)==($40|0);
      if ($73) {
       $$index = $71;$$index3 = $72;
       break L12;
      }
      $75 = $34;
      while(1) {
       $74 = (($75) + -16|0);
       $76 = (($75) + -12|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($77|0)==(0|0);
       if (!($78)) {
        $80 = (($75) + -8|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = ($81|0)==($77|0);
        if (!($82)) {
         $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $77;
         $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($81) + -8|0);
         $83 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($83)|0);
         $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
         $84 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i >>> 3;
         $85 = $84 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($81) + ($85<<3)|0);
         HEAP32[$80>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
        }
        HEAP32[$1>>2] = 30;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($77|0),($$byval_copy11|0));
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         break;
        }
       }
       $79 = ($74|0)==($40|0);
       if ($79) {
        $$index = $71;$$index3 = $72;
        break L12;
       } else {
        $75 = $74;
       }
      }
      $88 = ___cxa_find_matching_catch()|0;
      $89 = tempRet0;
      ___cxa_call_unexpected(($88|0));
      // unreachable;
     }
    }
   } while(0);
   $65 = ($66|0)==(0|0);
   if ($65) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = 30;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy11|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    ___cxa_call_unexpected(($69|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $90 = ($24|0)==(0|0);
 if ($90) {
  ___resumeException($$index|0);
  // unreachable;
 }
 HEAP32[$0>>2] = 30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($24|0),($$byval_copy11|0));
 $91 = __THREW__; __THREW__ = 0;
 $92 = $91&1;
 if ($92) {
  $93 = ___cxa_find_matching_catch()|0;
  $94 = tempRet0;
  ___cxa_call_unexpected(($93|0));
  // unreachable;
 } else {
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier30ELi16EEEC2ERKS6_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$01$i = 0, $$byval_copy1 = 0, $$pre2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($__x) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$__x>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 3;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($9|0)<(0);
 if ($12) {
  __THREW__ = 0;
  invoke_vi(3308,0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   // unreachable;
  }
 } else {
  HEAP32[$0>>2] = 30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $15 = (invoke_iiiiiii(102,($9|0),16,($$byval_copy1|0),0,(638872|0),79)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   HEAP32[$2>>2] = $15;
   HEAP32[$this>>2] = $15;
   $18 = (($15) + ($10<<3)|0);
   HEAP32[$3>>2] = $18;
   $19 = HEAP32[$__x>>2]|0;
   $20 = HEAP32[$4>>2]|0;
   $21 = ($19|0)==($20|0);
   if ($21) {
    STACKTOP = sp;return;
   } else {
    $$01$i = $19;$23 = $15;
   }
   while(1) {
    $22 = ($23|0)==(0|0);
    if ($22) {
     $35 = 0;
    } else {
     $24 = $$01$i;
     $25 = $24;
     $26 = HEAP32[$25>>2]|0;
     $27 = (($24) + 4)|0;
     $28 = $27;
     $29 = HEAP32[$28>>2]|0;
     $30 = $23;
     $31 = $30;
     HEAP32[$31>>2] = $26;
     $32 = (($30) + 4)|0;
     $33 = $32;
     HEAP32[$33>>2] = $29;
     $$pre2$i = HEAP32[$2>>2]|0;
     $35 = $$pre2$i;
    }
    $34 = (($35) + 8|0);
    HEAP32[$2>>2] = $34;
    $36 = (($$01$i) + 8|0);
    $37 = ($36|0)==($20|0);
    if ($37) {
     break;
    } else {
     $$01$i = $36;$23 = $34;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 $40 = HEAP32[$this>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  ___resumeException($38|0);
  // unreachable;
 }
 $42 = HEAP32[$2>>2]|0;
 $43 = ($42|0)==($40|0);
 if (!($43)) {
  $__new_last2$i$i$i = $40;
  $scevgep$i$i$i = (($42) + -8|0);
  $44 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($44)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $45 = $uglygep3$i$i$i >>> 3;
  $46 = $45 ^ -1;
  $scevgep4$i$i$i = (($42) + ($46<<3)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i;
 }
 HEAP32[$1>>2] = 30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($40|0),($$byval_copy1|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 } else {
  ___resumeException($38|0);
  // unreachable;
 }
}
function __ZNKSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE14__count_uniqueIS6_EEjRKT_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$$$i$i$i = 0, $$$$i$i$i5 = 0, $$$i$i$i = 0, $$$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__rt$0$in = 0, $__rt$0$in$in$be = 0, $__rt$0$in7 = 0, $__rt$0$in8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $__rt$0$in7 = HEAP32[$0>>2]|0;
 $1 = ($__rt$0$in7|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP8[$__k>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 $5 = $2&255;
 $6 = $5 >>> 1;
 $7 = (($__k) + 1|0);
 $8 = (($__k) + 8|0);
 $9 = (($__k) + 4|0);
 $__rt$0$in8 = $__rt$0$in7;
 while(1) {
  $10 = (($__rt$0$in8) + 16|0);
  if ($4) {
   $25 = $6;
  } else {
   $11 = HEAP32[$9>>2]|0;
   $25 = $11;
  }
  $12 = HEAP8[$10>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $17 = $12&255;
   $18 = $17 >>> 1;
   $24 = $18;
  } else {
   $15 = (($__rt$0$in8) + 20|0);
   $16 = HEAP32[$15>>2]|0;
   $24 = $16;
  }
  if ($4) {
   $27 = $7;
  } else {
   $19 = HEAP32[$8>>2]|0;
   $27 = $19;
  }
  if ($14) {
   $22 = (($10) + 1|0);
   $28 = $22;
  } else {
   $20 = (($__rt$0$in8) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $28 = $21;
  }
  $23 = ($24>>>0)<($25>>>0);
  $26 = $23 ? $24 : $25;
  $29 = (_memcmp($27,$28,$26)|0);
  $30 = ($29|0)==(0);
  if ($30) {
   $31 = ($25>>>0)<($24>>>0);
   $$$i$i$i4 = $23&1;
   $$$$i$i$i5 = $31 ? -1 : $$$i$i$i4;
   $33 = $$$$i$i$i5;
  } else {
   $33 = $29;
  }
  $32 = ($33|0)<(0);
  if ($32) {
   $__rt$0$in$in$be = $__rt$0$in8;
  } else {
   if ($14) {
    $36 = $12&255;
    $37 = $36 >>> 1;
    $45 = $37;
   } else {
    $34 = (($__rt$0$in8) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $45 = $35;
   }
   if ($4) {
    $44 = $6;
   } else {
    $38 = HEAP32[$9>>2]|0;
    $44 = $38;
   }
   if ($14) {
    $41 = (($10) + 1|0);
    $47 = $41;
   } else {
    $39 = (($__rt$0$in8) + 24|0);
    $40 = HEAP32[$39>>2]|0;
    $47 = $40;
   }
   if ($4) {
    $48 = $7;
   } else {
    $42 = HEAP32[$8>>2]|0;
    $48 = $42;
   }
   $43 = ($44>>>0)<($45>>>0);
   $46 = $43 ? $44 : $45;
   $49 = (_memcmp($47,$48,$46)|0);
   $50 = ($49|0)==(0);
   if ($50) {
    $51 = ($45>>>0)<($44>>>0);
    $$$i$i$i = $43&1;
    $$$$i$i$i = $51 ? -1 : $$$i$i$i;
    $53 = $$$$i$i$i;
   } else {
    $53 = $49;
   }
   $52 = ($53|0)<(0);
   if (!($52)) {
    $$0 = 1;
    label = 32;
    break;
   }
   $54 = (($__rt$0$in8) + 4|0);
   $__rt$0$in$in$be = $54;
  }
  $__rt$0$in = HEAP32[$__rt$0$in$in$be>>2]|0;
  $55 = ($__rt$0$in|0)==(0|0);
  if ($55) {
   $$0 = 0;
   label = 32;
   break;
  } else {
   $__rt$0$in8 = $__rt$0$in;
  }
 }
 if ((label|0) == 32) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE4findIS6_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i = 0, $$$$i$i$i$i = 0, $$$i$i$i = 0, $$$i$i$i$i = 0, $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = HEAP8[$__v>>0]|0;
  $5 = $4 & 1;
  $6 = ($5<<24>>24)==(0);
  $7 = $4&255;
  $8 = $7 >>> 1;
  $9 = (($__v) + 1|0);
  $10 = (($__v) + 8|0);
  $11 = (($__v) + 4|0);
  $$0$ph7$i = $2;$$01$ph6$i$in = $1;
  L3: while(1) {
   $$013$i$in = $$01$ph6$i$in;
   while(1) {
    $12 = (($$013$i$in) + 16|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     $18 = $13&255;
     $19 = $18 >>> 1;
     $27 = $19;
    } else {
     $16 = (($$013$i$in) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $27 = $17;
    }
    if ($6) {
     $26 = $8;
    } else {
     $20 = HEAP32[$11>>2]|0;
     $26 = $20;
    }
    if ($15) {
     $23 = (($12) + 1|0);
     $29 = $23;
    } else {
     $21 = (($$013$i$in) + 24|0);
     $22 = HEAP32[$21>>2]|0;
     $29 = $22;
    }
    if ($6) {
     $30 = $9;
    } else {
     $24 = HEAP32[$10>>2]|0;
     $30 = $24;
    }
    $25 = ($26>>>0)<($27>>>0);
    $28 = $25 ? $26 : $27;
    $31 = (_memcmp($29,$30,$28)|0);
    $32 = ($31|0)==(0);
    if ($32) {
     $33 = ($27>>>0)<($26>>>0);
     $$$i$i$i$i = $25&1;
     $$$$i$i$i$i = $33 ? -1 : $$$i$i$i$i;
     $35 = $$$$i$i$i$i;
    } else {
     $35 = $31;
    }
    $34 = ($35|0)<(0);
    if (!($34)) {
     break;
    }
    $38 = (($$013$i$in) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$0$ph5$i = $$0$ph7$i;
     break L3;
    } else {
     $$013$i$in = $39;
    }
   }
   $36 = HEAP32[$$013$i$in>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    $$0$ph5$i = $$013$i$in;
    break;
   } else {
    $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $36;
   }
  }
  $41 = ($$0$ph5$i|0)==($2|0);
  if (!($41)) {
   $42 = (($$0$ph5$i) + 16|0);
   if ($6) {
    $57 = $8;
   } else {
    $43 = HEAP32[$11>>2]|0;
    $57 = $43;
   }
   $44 = HEAP8[$42>>0]|0;
   $45 = $44 & 1;
   $46 = ($45<<24>>24)==(0);
   if ($46) {
    $49 = $44&255;
    $50 = $49 >>> 1;
    $56 = $50;
   } else {
    $47 = (($$0$ph5$i) + 20|0);
    $48 = HEAP32[$47>>2]|0;
    $56 = $48;
   }
   if ($6) {
    $59 = $9;
   } else {
    $51 = HEAP32[$10>>2]|0;
    $59 = $51;
   }
   if ($46) {
    $54 = (($42) + 1|0);
    $60 = $54;
   } else {
    $52 = (($$0$ph5$i) + 24|0);
    $53 = HEAP32[$52>>2]|0;
    $60 = $53;
   }
   $55 = ($56>>>0)<($57>>>0);
   $58 = $55 ? $56 : $57;
   $61 = (_memcmp($59,$60,$58)|0);
   $62 = ($61|0)==(0);
   if ($62) {
    $63 = ($57>>>0)<($56>>>0);
    $$$i$i$i = $55&1;
    $$$$i$i$i = $63 ? -1 : $$$i$i$i;
    $65 = $$$$i$i$i;
   } else {
    $65 = $61;
   }
   $64 = ($65|0)<(0);
   if (!($64)) {
    HEAP32[$agg$result>>2] = $$0$ph5$i;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$4);
 $5 = (($__nd) + 16|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 HEAP32[$0>>2] = 30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_call_unexpected(($13|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEESI_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i = 0, $$$$i$i$i5 = 0, $$$i$i$i = 0, $$$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $60 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $60;
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 $__nd$0$in = $1;
 while(1) {
  $11 = (($__nd$0$in) + 16|0);
  if ($5) {
   $26 = $7;
  } else {
   $12 = HEAP32[$10>>2]|0;
   $26 = $12;
  }
  $13 = HEAP8[$11>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $25 = $19;
  } else {
   $16 = (($__nd$0$in) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $25 = $17;
  }
  if ($5) {
   $28 = $8;
  } else {
   $20 = HEAP32[$9>>2]|0;
   $28 = $20;
  }
  if ($15) {
   $23 = (($11) + 1|0);
   $29 = $23;
  } else {
   $21 = (($__nd$0$in) + 24|0);
   $22 = HEAP32[$21>>2]|0;
   $29 = $22;
  }
  $24 = ($25>>>0)<($26>>>0);
  $27 = $24 ? $25 : $26;
  $30 = (_memcmp($28,$29,$27)|0);
  $31 = ($30|0)==(0);
  if ($31) {
   $32 = ($26>>>0)<($25>>>0);
   $$$i$i$i4 = $24&1;
   $$$$i$i$i5 = $32 ? -1 : $$$i$i$i4;
   $34 = $$$$i$i$i5;
  } else {
   $34 = $30;
  }
  $33 = ($34|0)<(0);
  if ($33) {
   $35 = HEAP32[$__nd$0$in>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 17;
    break;
   } else {
    $__nd$0$in = $35;
    continue;
   }
  }
  if ($15) {
   $39 = $13&255;
   $40 = $39 >>> 1;
   $48 = $40;
  } else {
   $37 = (($__nd$0$in) + 20|0);
   $38 = HEAP32[$37>>2]|0;
   $48 = $38;
  }
  if ($5) {
   $47 = $7;
  } else {
   $41 = HEAP32[$10>>2]|0;
   $47 = $41;
  }
  if ($15) {
   $44 = (($11) + 1|0);
   $50 = $44;
  } else {
   $42 = (($__nd$0$in) + 24|0);
   $43 = HEAP32[$42>>2]|0;
   $50 = $43;
  }
  if ($5) {
   $51 = $8;
  } else {
   $45 = HEAP32[$9>>2]|0;
   $51 = $45;
  }
  $46 = ($47>>>0)<($48>>>0);
  $49 = $46 ? $47 : $48;
  $52 = (_memcmp($50,$51,$49)|0);
  $53 = ($52|0)==(0);
  if ($53) {
   $54 = ($48>>>0)<($47>>>0);
   $$$i$i$i = $46&1;
   $$$$i$i$i = $54 ? -1 : $$$i$i$i;
   $56 = $$$$i$i$i;
  } else {
   $56 = $52;
  }
  $55 = ($56|0)<(0);
  if (!($55)) {
   label = 33;
   break;
  }
  $57 = (($__nd$0$in) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   label = 32;
   break;
  } else {
   $__nd$0$in = $58;
  }
 }
 if ((label|0) == 17) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $57;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE16__construct_nodeERKS6_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP32[$0>>2] = 30;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Z15malloc_internaljj10MemLabelIdiPKci(28,16,$$byval_copy1,0,638872,79)|0);
 $3 = $1;
 $4 = (($2) + 16|0);
 $5 = HEAP8[$__v>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  ;HEAP32[$4+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__v+8>>2]|0;
  HEAP32[$agg$result>>2] = $2;
  $28 = (($agg$result) + 4|0);
  $29 = $28;
  $30 = $29;
  HEAP32[$30>>2] = $3;
  $31 = (($29) + 4)|0;
  $32 = $31;
  HEAP32[$32>>2] = 1;
  STACKTOP = sp;return;
 }
 $8 = (($__v) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__v) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11>>>0)>(4294967279);
 do {
  if ($12) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    // unreachable;
   }
  } else {
   $15 = ($11>>>0)<(11);
   if ($15) {
    $16 = $11 << 1;
    $17 = $16&255;
    HEAP8[$4>>0] = $17;
    $18 = (($2) + 17|0);
    $__p$0$i$i$i$i = $18;
   } else {
    $19 = (($11) + 16)|0;
    $20 = $19 & -16;
    __THREW__ = 0;
    $21 = (invoke_ii(2988,($20|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = (($2) + 24|0);
    HEAP32[$24>>2] = $21;
    $25 = $20 | 1;
    HEAP32[$4>>2] = $25;
    $26 = (($2) + 20|0);
    HEAP32[$26>>2] = $11;
    $__p$0$i$i$i$i = $21;
   }
   _memcpy(($__p$0$i$i$i$i|0),($9|0),($11|0))|0;
   $27 = (($__p$0$i$i$i$i) + ($11)|0);
   HEAP8[$27>>0] = 0;
   HEAP32[$agg$result>>2] = $2;
   $28 = (($agg$result) + 4|0);
   $29 = $28;
   $30 = $29;
   HEAP32[$30>>2] = $3;
   $31 = (($29) + 4)|0;
   $32 = $31;
   HEAP32[$32>>2] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 $35 = ($2|0)==(0|0);
 if ($35) {
  ___resumeException($33|0);
  // unreachable;
 }
 HEAP32[$0>>2] = 30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($2|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  ___resumeException($33|0);
  // unreachable;
 }
}
function __ZNSt3__16__treeINS_12__value_typeI26SerializedObjectIdentifieriEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI26SerializedObjectIdentifieriEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI26SerializedObjectIdentifieriEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIi26SerializedObjectIdentifierEENS_19__map_value_compareIiS3_NS_4lessIiEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIi26SerializedObjectIdentifierEENS_19__map_value_compareIiS3_NS_4lessIiEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIi26SerializedObjectIdentifierEENS_19__map_value_compareIiS3_NS_4lessIiEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E14squash_deletedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp$i = 0, $tmp1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $tmp$i = sp + 96|0;
 $tmp1$i = sp;
 $tmp = sp + 20|0;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($tmp) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tmp) + 8|0);
 $5 = (($this) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 HEAP8[$4>>0] = $6;
 $7 = (($tmp) + 9|0);
 $8 = (($this) + 9|0);
 $9 = HEAP8[$8>>0]|0;
 HEAP8[$7>>0] = $9;
 $10 = (($tmp) + 12|0);
 $11 = (($this) + 12|0);
 ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$10+16>>2]=HEAP32[$11+16>>2]|0;
 $12 = (($tmp) + 32|0);
 $13 = (($this) + 32|0);
 ;HEAP32[$12+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$13+16>>2]|0;
 $14 = (($tmp) + 52|0);
 ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;HEAP32[$14+16>>2]=0|0;HEAP8[$14+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E9copy_fromERKSD_j($tmp,$this,0);
 $15 = HEAP32[$0>>2]|0;
 $16 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $16;
 HEAP32[$3>>2] = $15;
 $17 = HEAP8[$5>>0]|0;
 $18 = HEAP16[$4>>1]|0;
 $19 = $18&255;
 HEAP8[$5>>0] = $19;
 HEAP8[$4>>0] = $17;
 $20 = HEAP8[$8>>0]|0;
 $21 = ($18&65535) >>> 8;
 $22 = $21&255;
 HEAP8[$8>>0] = $22;
 HEAP8[$7>>0] = $20;
 ;HEAP32[$tmp$i+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$tmp$i+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$tmp$i+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$tmp$i+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$tmp$i+16>>2]=HEAP32[$11+16>>2]|0;
 ;HEAP32[$11+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$11+16>>2]=HEAP32[$10+16>>2]|0;
 ;HEAP32[$10+0>>2]=HEAP32[$tmp$i+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$tmp$i+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$tmp$i+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$tmp$i+12>>2]|0;HEAP32[$10+16>>2]=HEAP32[$tmp$i+16>>2]|0;
 ;HEAP32[$tmp1$i+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$tmp1$i+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$tmp1$i+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$tmp1$i+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$tmp1$i+16>>2]=HEAP32[$13+16>>2]|0;
 ;HEAP32[$13+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$13+16>>2]=HEAP32[$12+16>>2]|0;
 ;HEAP32[$12+0>>2]=HEAP32[$tmp1$i+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$tmp1$i+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$tmp1$i+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$tmp1$i+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$tmp1$i+16>>2]|0;
 $23 = (($this) + 52|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$14>>2]|0;
 HEAP32[$23>>2] = $25;
 HEAP32[$14>>2] = $24;
 $26 = (($this) + 56|0);
 $27 = (($tmp) + 56|0);
 $28 = HEAP32[$26>>2]|0;
 $29 = HEAP32[$27>>2]|0;
 HEAP32[$26>>2] = $29;
 HEAP32[$27>>2] = $28;
 $30 = (($this) + 60|0);
 $31 = (($tmp) + 60|0);
 $32 = HEAP32[$30>>2]|0;
 $33 = HEAP32[$31>>2]|0;
 HEAP32[$30>>2] = $33;
 HEAP32[$31>>2] = $32;
 $34 = (Math_fround(($29>>>0)));
 $35 = Math_fround($34 * Math_fround(0.5));
 $36 = (~~(($35))>>>0);
 $37 = (($this) + 68|0);
 HEAP32[$37>>2] = $36;
 $38 = Math_fround($34 * Math_fround(0.20000000298023223877));
 $39 = (~~(($38))>>>0);
 $40 = (($this) + 64|0);
 HEAP32[$40>>2] = $39;
 $41 = (($this) + 72|0);
 HEAP8[$41>>0] = 0;
 $42 = (Math_fround(($28>>>0)));
 $43 = Math_fround($42 * Math_fround(0.5));
 $44 = (~~(($43))>>>0);
 $45 = (($tmp) + 68|0);
 HEAP32[$45>>2] = $44;
 $46 = Math_fround($42 * Math_fround(0.20000000298023223877));
 $47 = (~~(($46))>>>0);
 $48 = (($tmp) + 64|0);
 HEAP32[$48>>2] = $47;
 $49 = (($tmp) + 72|0);
 HEAP8[$49>>0] = 0;
 $50 = ($24|0)==(0|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 __ZdlPv($24);
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E9copy_fromERKSD_j($this,$ht,$min_buckets_wanted) {
 $this = $this|0;
 $ht = $ht|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$01$i$i$i = 0, $$01$i$i$i5 = 0, $$012$i$i = 0, $$03$i$i = 0, $$be = 0, $$ph12 = 0, $$pre = 0, $$pre$i = 0, $$pre$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $bucknum$0 = 0, $bucknum$0$lcssa = 0, $bucknum$010 = 0, $bucknum$08 = 0, $num_probes$09 = 0, $sz$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = (($this) + 56|0);
 HEAP32[$1>>2] = 32;
 $2 = (($this) + 68|0);
 HEAP32[$2>>2] = 16;
 $3 = (($this) + 64|0);
 HEAP32[$3>>2] = 6;
 $4 = (($this) + 72|0);
 HEAP8[$4>>0] = 0;
 $5 = (__Znwj(640)|0);
 $6 = HEAP32[$0>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $9 = 32;
 } else {
  __ZdlPv($6);
  $$pre$i = HEAP32[$1>>2]|0;
  $9 = $$pre$i;
 }
 HEAP32[$0>>2] = $5;
 $8 = (($5) + (($9*20)|0)|0);
 $10 = ($5|0)==($8|0);
 if (!($10)) {
  $11 = (($this) + 32|0);
  $$01$i$i$i = $5;
  while(1) {
   $12 = ($$01$i$i$i|0)==(0|0);
   if (!($12)) {
    ;HEAP32[$$01$i$i$i+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$$01$i$i$i+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$$01$i$i$i+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$$01$i$i$i+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$$01$i$i$i+16>>2]=HEAP32[$11+16>>2]|0;
   }
   $13 = (($$01$i$i$i) + 20|0);
   $14 = ($13|0)==($8|0);
   if ($14) {
    break;
   } else {
    $$01$i$i$i = $13;
   }
  }
 }
 $15 = (($this) + 60|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($ht) + 60|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($ht) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) - ($20))|0;
 $22 = (Math_fround(($21>>>0)));
 $sz$0$i = 32;
 while(1) {
  $23 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($23)) {
   $24 = (Math_fround(($sz$0$i>>>0)));
   $25 = Math_fround($24 * Math_fround(0.5));
   $26 = !($22 >= $25);
   if ($26) {
    break;
   }
  }
  $27 = $sz$0$i << 1;
  $sz$0$i = $27;
 }
 $28 = HEAP32[$1>>2]|0;
 $29 = ($sz$0$i>>>0)>($28>>>0);
 if ($29) {
  $30 = ($sz$0$i*20)|0;
  $31 = (__Znwj($30)|0);
  $32 = HEAP32[$0>>2]|0;
  $33 = ($28>>>0)>($sz$0$i>>>0);
  $34 = $33 ? $sz$0$i : $28;
  $35 = (($32) + (($34*20)|0)|0);
  $36 = ($34|0)==(0);
  if ($36) {
   $43 = $28;
  } else {
   $$012$i$i = $31;$$03$i$i = $32;
   while(1) {
    $37 = ($$012$i$i|0)==(0|0);
    if (!($37)) {
     ;HEAP32[$$012$i$i+0>>2]=HEAP32[$$03$i$i+0>>2]|0;HEAP32[$$012$i$i+4>>2]=HEAP32[$$03$i$i+4>>2]|0;HEAP32[$$012$i$i+8>>2]=HEAP32[$$03$i$i+8>>2]|0;HEAP32[$$012$i$i+12>>2]=HEAP32[$$03$i$i+12>>2]|0;HEAP32[$$012$i$i+16>>2]=HEAP32[$$03$i$i+16>>2]|0;
    }
    $38 = (($$03$i$i) + 20|0);
    $39 = (($$012$i$i) + 20|0);
    $40 = ($38|0)==($35|0);
    if ($40) {
     break;
    } else {
     $$012$i$i = $39;$$03$i$i = $38;
    }
   }
   $$pre$i3 = HEAP32[$1>>2]|0;
   $43 = $$pre$i3;
  }
  $41 = (($31) + (($sz$0$i*20)|0)|0);
  $42 = ($43|0)==($sz$0$i|0);
  if (!($42)) {
   $44 = (($31) + (($43*20)|0)|0);
   $45 = (($this) + 32|0);
   $$01$i$i$i5 = $44;
   while(1) {
    $46 = ($$01$i$i$i5|0)==(0|0);
    if (!($46)) {
     ;HEAP32[$$01$i$i$i5+0>>2]=HEAP32[$45+0>>2]|0;HEAP32[$$01$i$i$i5+4>>2]=HEAP32[$45+4>>2]|0;HEAP32[$$01$i$i$i5+8>>2]=HEAP32[$45+8>>2]|0;HEAP32[$$01$i$i$i5+12>>2]=HEAP32[$45+12>>2]|0;HEAP32[$$01$i$i$i5+16>>2]=HEAP32[$45+16>>2]|0;
    }
    $47 = (($$01$i$i$i5) + 20|0);
    $48 = ($47|0)==($41|0);
    if ($48) {
     break;
    } else {
     $$01$i$i$i5 = $47;
    }
   }
  }
  $49 = HEAP32[$0>>2]|0;
  __ZdlPv($49);
  HEAP32[$0>>2] = $31;
  HEAP32[$1>>2] = $sz$0$i;
  $50 = (~~(($25))>>>0);
  HEAP32[$2>>2] = $50;
  $51 = Math_fround($24 * Math_fround(0.20000000298023223877));
  $52 = (~~(($51))>>>0);
  HEAP32[$3>>2] = $52;
  HEAP8[$4>>0] = 0;
  $133 = $sz$0$i;
 } else {
  $133 = $28;
 }
 $53 = (($ht) + 52|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($ht) + 56|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($54) + (($56*20)|0)|0);
 $58 = ($56|0)==(0);
 L37: do {
  if ($58) {
   $$ph12 = $54;
  } else {
   $59 = (($ht) + 32|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($ht) + 8|0);
   $62 = (($ht) + 12|0);
   $64 = $54;
   while(1) {
    $63 = HEAP32[$64>>2]|0;
    $65 = ($60|0)==($63|0);
    if (!($65)) {
     $66 = HEAP8[$61>>0]|0;
     $67 = ($66<<24>>24)==(0);
     if ($67) {
      $$ph12 = $64;
      break L37;
     }
     $68 = HEAP32[$19>>2]|0;
     $69 = ($68|0)==(0);
     if ($69) {
      $$ph12 = $64;
      break L37;
     }
     $70 = HEAP32[$62>>2]|0;
     $71 = ($70|0)==($63|0);
     if (!($71)) {
      $$ph12 = $64;
      break L37;
     }
    }
    $72 = (($64) + 20|0);
    $73 = ($72|0)==($57|0);
    if ($73) {
     break;
    } else {
     $64 = $72;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $74 = ($$ph12|0)==($57|0);
 if ($74) {
  STACKTOP = sp;return;
 }
 $75 = (($this) + 32|0);
 $76 = (($ht) + 32|0);
 $77 = (($ht) + 8|0);
 $78 = (($ht) + 12|0);
 $80 = $133;$82 = $$ph12;
 while(1) {
  $79 = (($80) + -1)|0;
  $81 = HEAP32[$82>>2]|0;
  $83 = (($81) + 2127912214)|0;
  $84 = $81 << 12;
  $85 = (($83) + ($84))|0;
  $86 = $85 ^ -949894596;
  $87 = $85 >>> 19;
  $88 = $86 ^ $87;
  $89 = (($88) + 374761393)|0;
  $90 = $88 << 5;
  $91 = (($89) + ($90))|0;
  $92 = (($91) + -744332180)|0;
  $93 = $91 << 9;
  $94 = $92 ^ $93;
  $95 = (($94) + -42973499)|0;
  $96 = $94 << 3;
  $97 = (($95) + ($96))|0;
  $98 = $97 ^ -1252372727;
  $99 = $97 >>> 16;
  $100 = $98 ^ $99;
  $bucknum$08 = $100 & $79;
  $101 = HEAP32[$0>>2]|0;
  $102 = (($101) + (($bucknum$08*20)|0)|0);
  $103 = HEAP32[$75>>2]|0;
  $104 = HEAP32[$102>>2]|0;
  $105 = ($103|0)==($104|0);
  if ($105) {
   $bucknum$0$lcssa = $bucknum$08;
  } else {
   $bucknum$010 = $bucknum$08;$num_probes$09 = 0;
   while(1) {
    $106 = (($num_probes$09) + 1)|0;
    $107 = (($106) + ($bucknum$010))|0;
    $bucknum$0 = $107 & $79;
    $108 = (($101) + (($bucknum$0*20)|0)|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($103|0)==($109|0);
    if ($110) {
     $bucknum$0$lcssa = $bucknum$0;
     break;
    } else {
     $bucknum$010 = $bucknum$0;$num_probes$09 = $106;
    }
   }
  }
  $111 = (($101) + (($bucknum$0$lcssa*20)|0)|0);
  $112 = ($111|0)==(0|0);
  if (!($112)) {
   ;HEAP32[$111+0>>2]=HEAP32[$82+0>>2]|0;HEAP32[$111+4>>2]=HEAP32[$82+4>>2]|0;HEAP32[$111+8>>2]=HEAP32[$82+8>>2]|0;HEAP32[$111+12>>2]=HEAP32[$82+12>>2]|0;HEAP32[$111+16>>2]=HEAP32[$82+16>>2]|0;
  }
  $113 = HEAP32[$15>>2]|0;
  $114 = (($113) + 1)|0;
  HEAP32[$15>>2] = $114;
  $115 = (($82) + 20|0);
  $116 = ($115|0)==($57|0);
  L60: do {
   if ($116) {
    $$be = $57;
   } else {
    $121 = HEAP32[$76>>2]|0;
    $123 = $115;
    while(1) {
     $122 = HEAP32[$123>>2]|0;
     $124 = ($121|0)==($122|0);
     if (!($124)) {
      $125 = HEAP8[$77>>0]|0;
      $126 = ($125<<24>>24)==(0);
      if ($126) {
       $$be = $123;
       break L60;
      }
      $127 = HEAP32[$19>>2]|0;
      $128 = ($127|0)==(0);
      if ($128) {
       $$be = $123;
       break L60;
      }
      $129 = HEAP32[$78>>2]|0;
      $130 = ($129|0)==($122|0);
      if (!($130)) {
       $$be = $123;
       break L60;
      }
     }
     $131 = (($123) + 20|0);
     $132 = ($131|0)==($57|0);
     if ($132) {
      $$be = $57;
      break;
     } else {
      $123 = $131;
     }
    }
   }
  } while(0);
  $117 = HEAP32[$53>>2]|0;
  $118 = HEAP32[$55>>2]|0;
  $119 = (($117) + (($118*20)|0)|0);
  $120 = ($$be|0)==($119|0);
  if ($120) {
   break;
  }
  $$pre = HEAP32[$1>>2]|0;
  $80 = $$pre;$82 = $$be;
 }
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E6insertERKS4_($agg$result,$this,$obj) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $obj = $obj|0;
 var $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i = sp;
 __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E12resize_deltaEjj($this,1,0);
 __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($pos$i,$this,$obj);
 $0 = HEAP32[$pos$i>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  $2 = (($this) + 52|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + (($0*20)|0)|0);
  $5 = (($this) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + (($6*20)|0)|0);
  HEAP32[$agg$result>>2] = $this;
  $8 = (($agg$result) + 4|0);
  HEAP32[$8>>2] = $4;
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $7;
  $10 = (($agg$result) + 12|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($pos$i) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  label = 7;
 } else {
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if ($18) {
   label = 7;
  } else {
   $19 = (($this) + 12|0);
   $20 = (($this) + 52|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + (($12*20)|0)|0);
   $23 = HEAP32[$19>>2]|0;
   $24 = HEAP32[$22>>2]|0;
   $25 = ($23|0)==($24|0);
   if ($25) {
    $26 = (($17) + -1)|0;
    HEAP32[$16>>2] = $26;
    $31 = $21;
   } else {
    label = 7;
   }
  }
 }
 if ((label|0) == 7) {
  $27 = (($this) + 60|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 1)|0;
  HEAP32[$27>>2] = $29;
  $$phi$trans$insert$i = (($this) + 52|0);
  $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
  $31 = $$pre$i;
 }
 $30 = (($31) + (($12*20)|0)|0);
 $32 = ($30|0)==(0|0);
 if ($32) {
  $35 = $31;
 } else {
  $33 = (($this) + 52|0);
  ;HEAP32[$30+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$obj+12>>2]|0;HEAP32[$30+16>>2]=HEAP32[$obj+16>>2]|0;
  $$pre = HEAP32[$33>>2]|0;
  $35 = $$pre;
 }
 $34 = (($35) + (($12*20)|0)|0);
 $36 = (($this) + 56|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + (($37*20)|0)|0);
 HEAP32[$agg$result>>2] = $this;
 $39 = (($agg$result) + 4|0);
 HEAP32[$39>>2] = $34;
 $40 = (($agg$result) + 8|0);
 HEAP32[$40>>2] = $38;
 $41 = (($agg$result) + 12|0);
 HEAP8[$41>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E12resize_deltaEjj($this,$delta,$min_buckets_wanted) {
 $this = $this|0;
 $delta = $delta|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $sz$0$i = 0, $sz$0$i1 = 0, $tmp = 0, $tmp$i = 0, $tmp1$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $tmp$i = sp + 96|0;
 $tmp1$i = sp;
 $tmp = sp + 20|0;
 $0 = (($this) + 72|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E12maybe_shrinkEv($this);
 }
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>($min_buckets_wanted>>>0);
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 if ($5) {
  $8 = (($7) + ($delta))|0;
  $9 = (($this) + 68|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8>>>0)>($10>>>0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
 }
 $12 = (($this) + 60|0);
 $13 = (($7) + ($delta))|0;
 $14 = (Math_fround(($13>>>0)));
 $sz$0$i = 32;
 while(1) {
  $15 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($15)) {
   $16 = (Math_fround(($sz$0$i>>>0)));
   $17 = Math_fround($16 * Math_fround(0.5));
   $18 = !($14 >= $17);
   if ($18) {
    break;
   }
  }
  $19 = $sz$0$i << 1;
  $sz$0$i = $19;
 }
 $20 = ($sz$0$i>>>0)>($4>>>0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($13) - ($22))|0;
 $24 = (Math_fround(($23>>>0)));
 $sz$0$i1 = 32;
 while(1) {
  $25 = ($sz$0$i1>>>0)<($min_buckets_wanted>>>0);
  if (!($25)) {
   $26 = (Math_fround(($sz$0$i1>>>0)));
   $27 = Math_fround($26 * Math_fround(0.5));
   $28 = !($24 >= $27);
   if ($28) {
    break;
   }
  }
  $29 = $sz$0$i1 << 1;
  $sz$0$i1 = $29;
 }
 $30 = (($tmp) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = (($tmp) + 8|0);
 $32 = (($this) + 8|0);
 $33 = HEAP8[$32>>0]|0;
 HEAP8[$31>>0] = $33;
 $34 = (($tmp) + 9|0);
 $35 = (($this) + 9|0);
 $36 = HEAP8[$35>>0]|0;
 HEAP8[$34>>0] = $36;
 $37 = (($tmp) + 12|0);
 $38 = (($this) + 12|0);
 ;HEAP32[$37+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$38+12>>2]|0;HEAP32[$37+16>>2]=HEAP32[$38+16>>2]|0;
 $39 = (($tmp) + 32|0);
 $40 = (($this) + 32|0);
 ;HEAP32[$39+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$40+16>>2]|0;
 $41 = (($tmp) + 52|0);
 ;HEAP32[$41+0>>2]=0|0;HEAP32[$41+4>>2]=0|0;HEAP32[$41+8>>2]=0|0;HEAP32[$41+12>>2]=0|0;HEAP32[$41+16>>2]=0|0;HEAP8[$41+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E9copy_fromERKSD_j($tmp,$this,$sz$0$i1);
 $42 = HEAP32[$21>>2]|0;
 $43 = HEAP32[$30>>2]|0;
 HEAP32[$21>>2] = $43;
 HEAP32[$30>>2] = $42;
 $44 = HEAP8[$32>>0]|0;
 $45 = HEAP16[$31>>1]|0;
 $46 = $45&255;
 HEAP8[$32>>0] = $46;
 HEAP8[$31>>0] = $44;
 $47 = HEAP8[$35>>0]|0;
 $48 = ($45&65535) >>> 8;
 $49 = $48&255;
 HEAP8[$35>>0] = $49;
 HEAP8[$34>>0] = $47;
 ;HEAP32[$tmp$i+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$tmp$i+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$tmp$i+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$tmp$i+12>>2]=HEAP32[$38+12>>2]|0;HEAP32[$tmp$i+16>>2]=HEAP32[$38+16>>2]|0;
 ;HEAP32[$38+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$37+12>>2]|0;HEAP32[$38+16>>2]=HEAP32[$37+16>>2]|0;
 ;HEAP32[$37+0>>2]=HEAP32[$tmp$i+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$tmp$i+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$tmp$i+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$tmp$i+12>>2]|0;HEAP32[$37+16>>2]=HEAP32[$tmp$i+16>>2]|0;
 ;HEAP32[$tmp1$i+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$tmp1$i+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$tmp1$i+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$tmp1$i+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$tmp1$i+16>>2]=HEAP32[$40+16>>2]|0;
 ;HEAP32[$40+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$39+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$39+16>>2]|0;
 ;HEAP32[$39+0>>2]=HEAP32[$tmp1$i+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$tmp1$i+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$tmp1$i+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$tmp1$i+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$tmp1$i+16>>2]|0;
 $50 = (($this) + 52|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = HEAP32[$41>>2]|0;
 HEAP32[$50>>2] = $52;
 HEAP32[$41>>2] = $51;
 $53 = (($tmp) + 56|0);
 $54 = HEAP32[$3>>2]|0;
 $55 = HEAP32[$53>>2]|0;
 HEAP32[$3>>2] = $55;
 HEAP32[$53>>2] = $54;
 $56 = (($tmp) + 60|0);
 $57 = HEAP32[$12>>2]|0;
 $58 = HEAP32[$56>>2]|0;
 HEAP32[$12>>2] = $58;
 HEAP32[$56>>2] = $57;
 $59 = (Math_fround(($55>>>0)));
 $60 = Math_fround($59 * Math_fround(0.5));
 $61 = (~~(($60))>>>0);
 $62 = (($this) + 68|0);
 HEAP32[$62>>2] = $61;
 $63 = Math_fround($59 * Math_fround(0.20000000298023223877));
 $64 = (~~(($63))>>>0);
 $65 = (($this) + 64|0);
 HEAP32[$65>>2] = $64;
 HEAP8[$0>>0] = 0;
 $66 = (Math_fround(($54>>>0)));
 $67 = Math_fround($66 * Math_fround(0.5));
 $68 = (~~(($67))>>>0);
 $69 = (($tmp) + 68|0);
 HEAP32[$69>>2] = $68;
 $70 = Math_fround($66 * Math_fround(0.20000000298023223877));
 $71 = (~~(($70))>>>0);
 $72 = (($tmp) + 64|0);
 HEAP32[$72>>2] = $71;
 $73 = (($tmp) + 72|0);
 HEAP8[$73>>0] = 0;
 $74 = ($51|0)==(0|0);
 if ($74) {
  STACKTOP = sp;return;
 }
 __ZdlPv($51);
 STACKTOP = sp;return;
}
function __ZNK15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E13find_positionERS2_($agg$result,$this,$key) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $key = $key|0;
 var $$ = 0, $$lcssa2$ph = 0, $$lcssa214 = 0, $$lcssa3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $num_probes$04 = 0, $num_probes$04$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$key>>2]|0;
 $4 = (($3) + 2127912214)|0;
 $5 = $3 << 12;
 $6 = (($4) + ($5))|0;
 $7 = $6 ^ -949894596;
 $8 = $6 >>> 19;
 $9 = $7 ^ $8;
 $10 = (($9) + 374761393)|0;
 $11 = $9 << 5;
 $12 = (($10) + ($11))|0;
 $13 = (($12) + -744332180)|0;
 $14 = $12 << 9;
 $15 = $13 ^ $14;
 $16 = (($15) + -42973499)|0;
 $17 = $15 << 3;
 $18 = (($16) + ($17))|0;
 $19 = $18 ^ -1252372727;
 $20 = $18 >>> 16;
 $21 = $19 ^ $20;
 $22 = $21 & $2;
 $23 = (($this) + 32|0);
 $24 = (($this) + 52|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + (($22*20)|0)|0);
 $27 = HEAP32[$23>>2]|0;
 $28 = HEAP32[$26>>2]|0;
 $29 = ($27|0)==($28|0);
 L1: do {
  if ($29) {
   $$lcssa2$ph = $22;
   label = 5;
  } else {
   $30 = (($this) + 8|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   $33 = (($this) + 4|0);
   $34 = (($this) + 12|0);
   L3: do {
    if ($32) {
     $36 = $28;$39 = $22;$num_probes$04$us = 0;
     while(1) {
      $35 = ($3|0)==($36|0);
      if ($35) {
       $$lcssa3 = $39;
       break L3;
      }
      $37 = (($num_probes$04$us) + 1)|0;
      $38 = (($37) + ($39))|0;
      $40 = $38 & $2;
      $41 = (($25) + (($40*20)|0)|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($27|0)==($42|0);
      if ($43) {
       $$lcssa2$ph = $40;
       label = 5;
       break L1;
      } else {
       $36 = $42;$39 = $40;$num_probes$04$us = $37;
      }
     }
    } else {
     $53 = $28;$55 = -1;$56 = $22;$num_probes$04 = 0;
     while(1) {
      $49 = HEAP32[$33>>2]|0;
      $50 = ($49|0)==(0);
      if ($50) {
       label = 12;
      } else {
       $51 = HEAP32[$34>>2]|0;
       $52 = ($51|0)==($53|0);
       if ($52) {
        $54 = ($55|0)==(-1);
        $$ = $54 ? $56 : $55;
        $46 = $$;
       } else {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       label = 0;
       $57 = ($3|0)==($53|0);
       if ($57) {
        $$lcssa3 = $56;
        break L3;
       } else {
        $46 = $55;
       }
      }
      $59 = (($num_probes$04) + 1)|0;
      $60 = (($59) + ($56))|0;
      $61 = $60 & $2;
      $62 = (($25) + (($61*20)|0)|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($27|0)==($63|0);
      if ($64) {
       break;
      } else {
       $53 = $63;$55 = $46;$56 = $61;$num_probes$04 = $59;
      }
     }
     $45 = ($46|0)==(-1);
     HEAP32[$agg$result>>2] = -1;
     $47 = (($agg$result) + 4|0);
     if ($45) {
      $$lcssa214 = $61;$48 = $47;
      break L1;
     }
     HEAP32[$47>>2] = $46;
     STACKTOP = sp;return;
    }
   } while(0);
   HEAP32[$agg$result>>2] = $$lcssa3;
   $58 = (($agg$result) + 4|0);
   HEAP32[$58>>2] = -1;
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 5) {
  HEAP32[$agg$result>>2] = -1;
  $44 = (($agg$result) + 4|0);
  $$lcssa214 = $$lcssa2$ph;$48 = $44;
 }
 HEAP32[$48>>2] = $$lcssa214;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E12maybe_shrinkEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $sz$0 = 0, $sz$0$in = 0, $tmp = 0, $tmp$i = 0, $tmp1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $tmp$i = sp + 96|0;
 $tmp1$i = sp;
 $tmp = sp + 20|0;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($3))|0;
 $5 = (($this) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if (!($7)) {
  $61 = (($this) + 72|0);
  HEAP8[$61>>0] = 0;
  STACKTOP = sp;return;
 }
 $8 = (($this) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9>>>0)>(32);
 if ($10) {
  $sz$0$in = $9;
 } else {
  $61 = (($this) + 72|0);
  HEAP8[$61>>0] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $sz$0 = $sz$0$in >>> 1;
  $11 = ($sz$0$in>>>0)<(66);
  if ($11) {
   break;
  }
  $12 = (Math_fround(($4>>>0)));
  $13 = (Math_fround(($sz$0>>>0)));
  $14 = Math_fround($13 * Math_fround(0.20000000298023223877));
  $15 = $12 < $14;
  if ($15) {
   $sz$0$in = $sz$0;
  } else {
   break;
  }
 }
 $16 = (($tmp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($tmp) + 8|0);
 $18 = (($this) + 8|0);
 $19 = HEAP8[$18>>0]|0;
 HEAP8[$17>>0] = $19;
 $20 = (($tmp) + 9|0);
 $21 = (($this) + 9|0);
 $22 = HEAP8[$21>>0]|0;
 HEAP8[$20>>0] = $22;
 $23 = (($tmp) + 12|0);
 $24 = (($this) + 12|0);
 ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$24+16>>2]|0;
 $25 = (($tmp) + 32|0);
 $26 = (($this) + 32|0);
 ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$26+16>>2]|0;
 $27 = (($tmp) + 52|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;HEAP32[$27+16>>2]=0|0;HEAP8[$27+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E9copy_fromERKSD_j($tmp,$this,$sz$0);
 $28 = HEAP32[$2>>2]|0;
 $29 = HEAP32[$16>>2]|0;
 HEAP32[$2>>2] = $29;
 HEAP32[$16>>2] = $28;
 $30 = HEAP8[$18>>0]|0;
 $31 = HEAP16[$17>>1]|0;
 $32 = $31&255;
 HEAP8[$18>>0] = $32;
 HEAP8[$17>>0] = $30;
 $33 = HEAP8[$21>>0]|0;
 $34 = ($31&65535) >>> 8;
 $35 = $34&255;
 HEAP8[$21>>0] = $35;
 HEAP8[$20>>0] = $33;
 ;HEAP32[$tmp$i+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$tmp$i+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$tmp$i+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$tmp$i+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$tmp$i+16>>2]=HEAP32[$24+16>>2]|0;
 ;HEAP32[$24+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$23+16>>2]|0;
 ;HEAP32[$23+0>>2]=HEAP32[$tmp$i+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$tmp$i+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$tmp$i+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$tmp$i+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$tmp$i+16>>2]|0;
 ;HEAP32[$tmp1$i+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$tmp1$i+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$tmp1$i+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$tmp1$i+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$tmp1$i+16>>2]=HEAP32[$26+16>>2]|0;
 ;HEAP32[$26+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$25+16>>2]|0;
 ;HEAP32[$25+0>>2]=HEAP32[$tmp1$i+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$tmp1$i+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$tmp1$i+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$tmp1$i+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$tmp1$i+16>>2]|0;
 $36 = (($this) + 52|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$27>>2]|0;
 HEAP32[$36>>2] = $38;
 HEAP32[$27>>2] = $37;
 $39 = (($tmp) + 56|0);
 $40 = HEAP32[$8>>2]|0;
 $41 = HEAP32[$39>>2]|0;
 HEAP32[$8>>2] = $41;
 HEAP32[$39>>2] = $40;
 $42 = (($tmp) + 60|0);
 $43 = HEAP32[$0>>2]|0;
 $44 = HEAP32[$42>>2]|0;
 HEAP32[$0>>2] = $44;
 HEAP32[$42>>2] = $43;
 $45 = (Math_fround(($41>>>0)));
 $46 = Math_fround($45 * Math_fround(0.5));
 $47 = (~~(($46))>>>0);
 $48 = (($this) + 68|0);
 HEAP32[$48>>2] = $47;
 $49 = Math_fround($45 * Math_fround(0.20000000298023223877));
 $50 = (~~(($49))>>>0);
 HEAP32[$5>>2] = $50;
 $51 = (($this) + 72|0);
 HEAP8[$51>>0] = 0;
 $52 = (Math_fround(($40>>>0)));
 $53 = Math_fround($52 * Math_fround(0.5));
 $54 = (~~(($53))>>>0);
 $55 = (($tmp) + 68|0);
 HEAP32[$55>>2] = $54;
 $56 = Math_fround($52 * Math_fround(0.20000000298023223877));
 $57 = (~~(($56))>>>0);
 $58 = (($tmp) + 64|0);
 HEAP32[$58>>2] = $57;
 $59 = (($tmp) + 72|0);
 HEAP8[$59>>0] = 0;
 $60 = ($37|0)==(0|0);
 if ($60) {
  $61 = (($this) + 72|0);
  HEAP8[$61>>0] = 0;
  STACKTOP = sp;return;
 }
 __ZdlPv($37);
 $61 = (($this) + 72|0);
 HEAP8[$61>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier30ELi16EEE6insertENS_11__wrap_iterIPKS2_EERS8_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i14 = 0, $$0$i15 = 0, $$012$i$i$i12 = 0, $$03$i$i$i11 = 0, $$byval_copy4 = 0, $$pre = 0, $$pre$i10 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = HEAP32[$__position>>2]|0;
 $4 = $3;
 $5 = $2;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = (($2) + ($7<<3)|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = ($8|0)==($10|0);
  if ($14) {
   $15 = ($8|0)==(0|0);
   if ($15) {
    $27 = 0;
   } else {
    $16 = $__x;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 4)|0;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    $22 = $8;
    $23 = $22;
    HEAP32[$23>>2] = $18;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP32[$25>>2] = $21;
    $$pre = HEAP32[$9>>2]|0;
    $27 = $$pre;
   }
   $26 = (($27) + 8|0);
   HEAP32[$9>>2] = $26;
   $__p$0 = $8;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($7) + 1)|0;
  $28 = (($2) + ($$sum<<3)|0);
  $29 = $10;
  $30 = $28;
  $31 = (($29) - ($30))|0;
  $32 = $31 >> 3;
  $$sum18 = (($32) + ($7))|0;
  $33 = (($2) + ($$sum18<<3)|0);
  $34 = ($33>>>0)<($10>>>0);
  if ($34) {
   $36 = $10;$__i$01$i = $33;
   while(1) {
    $35 = ($36|0)==(0|0);
    if ($35) {
     $49 = 0;
    } else {
     $37 = $__i$01$i;
     $38 = $37;
     $39 = HEAP32[$38>>2]|0;
     $40 = (($37) + 4)|0;
     $41 = $40;
     $42 = HEAP32[$41>>2]|0;
     $43 = $36;
     $44 = $43;
     HEAP32[$44>>2] = $39;
     $45 = (($43) + 4)|0;
     $46 = $45;
     HEAP32[$46>>2] = $42;
     $$pre$i10 = HEAP32[$9>>2]|0;
     $49 = $$pre$i10;
    }
    $47 = (($__i$01$i) + 8|0);
    $48 = (($49) + 8|0);
    HEAP32[$9>>2] = $48;
    $50 = ($47>>>0)<($10>>>0);
    if ($50) {
     $36 = $48;$__i$01$i = $47;
    } else {
     $61 = $48;
     break;
    }
   }
  } else {
   $61 = $10;
  }
  $51 = ($32|0)==(0);
  if (!($51)) {
   $$012$i$i$i12 = $33;$$03$i$i$i11 = $10;
   while(1) {
    $52 = (($$03$i$i$i11) + -8|0);
    $53 = (($$012$i$i$i12) + -8|0);
    $54 = HEAP32[$53>>2]|0;
    HEAP32[$52>>2] = $54;
    $55 = (($$012$i$i$i12) + -4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($$03$i$i$i11) + -4|0);
    HEAP32[$57>>2] = $56;
    $58 = ($53|0)==($8|0);
    if ($58) {
     break;
    } else {
     $$012$i$i$i12 = $53;$$03$i$i$i11 = $52;
    }
   }
  }
  $59 = ($8>>>0)>($__x>>>0);
  if ($59) {
   $__xr$0 = $__x;
  } else {
   $60 = ($61>>>0)>($__x>>>0);
   $62 = (($__x) + 8|0);
   $$ = $60 ? $62 : $__x;
   $__xr$0 = $$;
  }
  $63 = HEAP32[$__xr$0>>2]|0;
  HEAP32[$8>>2] = $63;
  $64 = (($__xr$0) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($2) + ($7<<3)|0) + 4|0);
  HEAP32[$66>>2] = $65;
  $__p$0 = $8;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $67 = $10;
 $68 = (($67) - ($5))|0;
 $69 = $68 >> 3;
 $70 = (($69) + 1)|0;
 $71 = ($70|0)<(0);
 if ($71) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $72 = $12;
 $73 = (($72) - ($5))|0;
 $74 = $73 >> 3;
 $75 = ($74>>>0)<(1073741823);
 if ($75) {
  $78 = $73 >> 2;
  $79 = ($78>>>0)<($70>>>0);
  $80 = $79 ? $70 : $78;
  $81 = $8;
  $82 = $6 >> 3;
  $83 = ($80|0)==(0);
  if ($83) {
   $$0$i15 = 0;$127 = $81;$87 = 0;$88 = $82;
  } else {
   $$0$i14 = $80;$150 = $82;$151 = $81;
   label = 20;
  }
 } else {
  $76 = $8;
  $77 = $6 >> 3;
  $$0$i14 = 2147483647;$150 = $77;$151 = $76;
  label = 20;
 }
 if ((label|0) == 20) {
  $84 = $$0$i14 << 3;
  HEAP32[$0>>2] = 30;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $85 = (__Z15malloc_internaljj10MemLabelIdiPKci($84,16,$$byval_copy4,0,638872,79)|0);
  $$0$i15 = $$0$i14;$127 = $151;$87 = $85;$88 = $150;
 }
 $86 = (($87) + ($88<<3)|0);
 $89 = (($87) + ($$0$i15<<3)|0);
 $90 = ($88|0)==($$0$i15|0);
 do {
  if ($90) {
   $91 = ($88|0)>(0);
   if ($91) {
    $92 = (($88) + 1)|0;
    $93 = (($92|0) / -2)&-1;
    $$sum17 = (($93) + ($88))|0;
    $94 = (($87) + ($$sum17<<3)|0);
    $111 = $94;$137 = $89;
    break;
   }
   $95 = $88 << 1;
   $96 = ($88|0)==(0);
   $97 = $96 ? 1 : $95;
   $98 = $97 << 3;
   HEAP32[$0>>2] = 30;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   $99 = (invoke_iiiiiii(102,($98|0),16,($$byval_copy4|0),0,(638872|0),79)|0);
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if (!($101)) {
    $102 = $97 >>> 2;
    $103 = (($99) + ($102<<3)|0);
    $104 = (($99) + ($97<<3)|0);
    $105 = ($87|0)==(0|0);
    if ($105) {
     $111 = $103;$137 = $104;
     break;
    }
    HEAP32[$0>>2] = 30;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($87|0),($$byval_copy4|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if (!($107)) {
     $111 = $103;$137 = $104;
     break;
    }
    $108 = ___cxa_find_matching_catch()|0;
    $109 = tempRet0;
    ___cxa_call_unexpected(($108|0));
    // unreachable;
   }
   $143 = ___cxa_find_matching_catch()|0;
   $144 = tempRet0;
   $145 = ($87|0)==(0|0);
   if ($145) {
    ___resumeException($143|0);
    // unreachable;
   }
   HEAP32[$1>>2] = 30;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($87|0),($$byval_copy4|0));
   $146 = __THREW__; __THREW__ = 0;
   $147 = $146&1;
   if ($147) {
    $148 = ___cxa_find_matching_catch()|0;
    $149 = tempRet0;
    ___cxa_call_unexpected(($148|0));
    // unreachable;
   } else {
    ___resumeException($143|0);
    // unreachable;
   }
  } else {
   $111 = $86;$137 = $89;
  }
 } while(0);
 $110 = ($111|0)==(0|0);
 if ($110) {
  $123 = 0;
 } else {
  $112 = $__x;
  $113 = $112;
  $114 = HEAP32[$113>>2]|0;
  $115 = (($112) + 4)|0;
  $116 = $115;
  $117 = HEAP32[$116>>2]|0;
  $118 = $111;
  $119 = $118;
  HEAP32[$119>>2] = $114;
  $120 = (($118) + 4)|0;
  $121 = $120;
  HEAP32[$121>>2] = $117;
  $123 = $111;
 }
 $122 = (($123) + 8|0);
 $124 = HEAP32[$this>>2]|0;
 $125 = $124;
 $126 = (($127) - ($125))|0;
 $128 = $126 >> 3;
 $129 = (0 - ($128))|0;
 $130 = (($111) + ($129<<3)|0);
 _memcpy(($130|0),($124|0),($126|0))|0;
 $131 = HEAP32[$9>>2]|0;
 $132 = $131;
 $133 = (($132) - ($127))|0;
 $134 = $133 >> 3;
 _memcpy(($122|0),($8|0),($133|0))|0;
 $$sum16 = (($134) + 1)|0;
 $135 = (($123) + ($$sum16<<3)|0);
 $136 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $130;
 HEAP32[$9>>2] = $135;
 HEAP32[$11>>2] = $137;
 $138 = ($136|0)==(0|0);
 if ($138) {
  $__p$0 = $111;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($136|0),($$byval_copy4|0));
 $139 = __THREW__; __THREW__ = 0;
 $140 = $139&1;
 if ($140) {
  $141 = ___cxa_find_matching_catch()|0;
  $142 = tempRet0;
  ___cxa_call_unexpected(($141|0));
  // unreachable;
 } else {
  $__p$0 = $111;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIi26SerializedObjectIdentifierEENS_19__map_value_compareIiS3_NS_4lessIiEELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$20 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $30 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(40)|0);
 $17 = (($16) + 16|0);
 ;HEAP32[$17+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$__v+16>>2]|0;HEAP32[$17+20>>2]=HEAP32[$__v+20>>2]|0;
 HEAP32[$16>>2] = 0;
 $18 = (($16) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $16;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $16;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI26SerializedObjectIdentifieriEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $37 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $37;
   $$0$i = $37;$44 = $37;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $4 = (($__v) + 8|0);
   $__nd$0$in$i = $1;
   L3: while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($3|0)<($6|0);
    do {
     if (!($7)) {
      $8 = ($3|0)>($6|0);
      if (!($8)) {
       $9 = $4;
       $10 = $9;
       $11 = HEAP32[$10>>2]|0;
       $12 = (($9) + 4)|0;
       $13 = $12;
       $14 = HEAP32[$13>>2]|0;
       $15 = (($__nd$0$in$i) + 24|0);
       $16 = $15;
       $17 = $16;
       $18 = HEAP32[$17>>2]|0;
       $19 = (($16) + 4)|0;
       $20 = $19;
       $21 = HEAP32[$20>>2]|0;
       $22 = ($14|0)<($21|0);
       $23 = ($14|0)==($21|0);
       $24 = ($11>>>0)<($18>>>0);
       $25 = $23 & $24;
       $26 = $22 | $25;
       if ($26) {
        break;
       }
       $29 = ($21|0)<($14|0);
       $30 = ($21|0)==($14|0);
       $31 = ($18>>>0)<($11>>>0);
       $32 = $30 & $31;
       $33 = $29 | $32;
       if (!($33)) {
        label = 11;
        break L3;
       }
      }
      $34 = (($__nd$0$in$i) + 4|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==(0|0);
      if ($36) {
       label = 10;
       break L3;
      } else {
       $__nd$0$in$i = $35;
       continue L3;
      }
     }
    } while(0);
    $27 = HEAP32[$__nd$0$in$i>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     label = 7;
     break;
    } else {
     $__nd$0$in$i = $27;
    }
   }
   if ((label|0) == 7) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$44 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 10) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $34;$44 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 11) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$44 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $38 = HEAP32[$$0$i>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $54 = 0;$__r$0 = $38;
  HEAP32[$agg$result>>2] = $__r$0;
  $53 = (($agg$result) + 4|0);
  HEAP8[$53>>0] = $54;
  STACKTOP = sp;return;
 }
 $40 = (__Znwj(40)|0);
 $41 = (($40) + 16|0);
 ;HEAP32[$41+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$41+16>>2]=HEAP32[$__v+16>>2]|0;HEAP32[$41+20>>2]=HEAP32[$__v+20>>2]|0;
 HEAP32[$40>>2] = 0;
 $42 = (($40) + 4|0);
 HEAP32[$42>>2] = 0;
 $43 = (($40) + 8|0);
 HEAP32[$43>>2] = $44;
 HEAP32[$$0$i>>2] = $40;
 $45 = HEAP32[$this>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 if ($47) {
  $49 = $40;
 } else {
  HEAP32[$this>>2] = $46;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $49 = $$pre$i;
 }
 $48 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($48,$49);
 $50 = (($this) + 8|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 1)|0;
 HEAP32[$50>>2] = $52;
 $54 = 1;$__r$0 = $40;
 HEAP32[$agg$result>>2] = $__r$0;
 $53 = (($agg$result) + 4|0);
 HEAP8[$53>>0] = $54;
 STACKTOP = sp;return;
}
function __ZN14SerializedFileC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP32[$this>>2] = $2;
 $3 = (($this) + 24|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 72|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 76|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 68|0);
 HEAP32[$9>>2] = 61;
 $10 = HEAP32[628360>>2]|0;
 $11 = (($this) + 80|0);
 HEAP32[$11>>2] = 1024;
 $12 = (($this) + 84|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 88|0);
 HEAP32[$13>>2] = $10;
 $14 = (($this) + 92|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 100|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 104|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 96|0);
 HEAP32[$17>>2] = 61;
 $18 = (($this) + 112|0);
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;
 $19 = (($this) + 124|0);
 HEAP32[$19>>2] = 1;
 $20 = (($this) + 12|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 16|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 56|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 37|0);
 HEAP8[$23>>0] = 0;
 $24 = (($this) + 39|0);
 HEAP8[$24>>0] = 0;
 $25 = (($this) + 38|0);
 HEAP8[$25>>0] = 0;
 $26 = (($this) + 48|0);
 HEAP32[$26>>2] = -2;
 $27 = (($this) + 52|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 44|0);
 HEAP8[$28>>0] = 0;
 $29 = (($this) + 60|0);
 HEAP32[$29>>2] = 42;
 $30 = (($this) + 108|0);
 HEAP32[$30>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14SerializedFile14InitializeReadERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER18ResourceImageGroupjj24TransferInstructionFlagsii($this,$path,$resourceImage,$cacheSize,$cacheCount,$options,$readOffset,$readEndOffset) {
 $this = $this|0;
 $path = $path|0;
 $resourceImage = $resourceImage|0;
 $cacheSize = $cacheSize|0;
 $cacheCount = $cacheCount|0;
 $options = $options|0;
 $readOffset = $readOffset|0;
 $readEndOffset = $readEndOffset|0;
 var $$$i = 0, $$0$i = 0, $$byval_copy1 = 0, $$lobit$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = $readOffset;
 $2 = HEAP32[628408>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(156,$$byval_copy1,0,16,639432,272)|0);
 __THREW__ = 0;
 invoke_viiii(399,($3|0),($path|0),($cacheSize|0),($cacheCount|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy1|0),0,16,(639432|0),272);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $26 = ___cxa_find_matching_catch(0|0)|0;
   $27 = tempRet0;
   ___clang_call_terminate($26);
   // unreachable;
  } else {
   ___resumeException($22|0);
   // unreachable;
  }
 }
 $6 = (($this) + 108|0);
 HEAP32[$6>>2] = $3;
 $7 = ($readEndOffset|0)==(-1);
 if ($7) {
  $8 = HEAP32[$3>>2]|0;
  $9 = (($8) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_ii[$10 & 4095]($3)|0);
  $$pre = HEAP32[$6>>2]|0;
  $13 = $11;$20 = $$pre;
 } else {
  $13 = $readEndOffset;$20 = $3;
 }
 $12 = (($this) + 16|0);
 HEAP32[$12>>2] = $13;
 $14 = (($this) + 112|0);
 ;HEAP32[$14+0>>2]=HEAP32[$resourceImage+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$resourceImage+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$resourceImage+8>>2]|0;
 $15 = (($this) + 40|0);
 $16 = $options | 256;
 HEAP32[$15>>2] = $16;
 $17 = (($this) + 36|0);
 $18 = $options >>> 9;
 $$lobit$i = $18 & 1;
 $$$i = $$lobit$i&255;
 HEAP8[$17>>0] = $$$i;
 $19 = ($20|0)==(0|0);
 if ($19) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $21 = (__ZN14SerializedFile10ReadHeaderEv($this)|0);
 $$0$i = $21;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN14SerializedFile10ReadHeaderEv($this) {
 $this = $this|0;
 var $$0 = 0, $$1 = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $dataEnd$0 = 0, $dataOffset$0 = 0, $header = 0, $metadataOffset$0 = 0, $metadataSize$0 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond8 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $header = sp + 8|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)<(20);
 if ($4) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $5 = (($this) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 __Z13ReadFileCacheR15CacheReaderBasePvjj($6,$header,$8,20);
 $9 = HEAP32[$header>>2]|0;
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$header>>2] = $10;
 $11 = (($header) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (_llvm_bswap_i32(($12|0))|0);
 HEAP32[$11>>2] = $13;
 $14 = (($header) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$14>>2] = $16;
 $17 = (($header) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$17>>2] = $19;
 $20 = ($9|0)==(-1);
 if ($20) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $21 = ($15|0)==(16777216);
 $22 = ($16>>>0)>(14);
 $or$cond1 = $21 | $22;
 if ($or$cond1) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $23 = ($16>>>0)>(8);
 do {
  if ($23) {
   $24 = HEAP32[$7>>2]|0;
   $25 = (($13) + ($24))|0;
   $26 = HEAP32[$2>>2]|0;
   $27 = ($25>>>0)>($26>>>0);
   $28 = ($19>>>0)>($13>>>0);
   $or$cond8 = $27 | $28;
   if ($or$cond8) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   } else {
    $29 = (($header) + 16|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = (($this) + 36|0);
    HEAP8[$31>>0] = $30;
    $45 = $30;$dataEnd$0 = $13;$dataOffset$0 = $19;$metadataOffset$0 = 20;$metadataSize$0 = $10;
    break;
   }
  } else {
   $32 = (($13) - ($10))|0;
   $33 = (($32) + 1)|0;
   $34 = (($10) + -1)|0;
   $35 = ($9|0)==(0);
   if ($35) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $36 = HEAP32[$7>>2]|0;
   $37 = (($36) + ($13))|0;
   $38 = HEAP32[$2>>2]|0;
   $39 = ($37>>>0)>($38>>>0);
   $40 = ($32>>>0)>($13>>>0);
   $or$cond = $39 | $40;
   if ($or$cond) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   } else {
    $41 = HEAP32[$5>>2]|0;
    $42 = (($this) + 36|0);
    $43 = (($36) + ($32))|0;
    __Z13ReadFileCacheR15CacheReaderBasePvjj($41,$42,$43,1);
    $$pre = HEAP8[$42>>0]|0;
    $45 = $$pre;$dataEnd$0 = $32;$dataOffset$0 = 0;$metadataOffset$0 = $33;$metadataSize$0 = $34;
    break;
   }
  }
 } while(0);
 $44 = (($this) + 36|0);
 $switch = ($45&255)<(2);
 if (!($switch)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $46 = HEAP32[628360>>2]|0;
 $47 = ($metadataSize$0|0)==(0);
 if ($47) {
  $54 = 0;$81 = 0;
  label = 13;
 } else {
  HEAP32[$1>>2] = $46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $48 = (invoke_iiiiiiii(108,(0|0),($metadataSize$0|0),1,($$byval_copy2|0),0,(639432|0),370)|0);
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if ($50) {
   $66 = $metadataSize$0;$67 = 0;
  } else {
   $54 = $48;$81 = $metadataSize$0;
   label = 13;
  }
 }
 L28: do {
  if ((label|0) == 13) {
   $51 = HEAP32[$5>>2]|0;
   $52 = HEAP32[$7>>2]|0;
   $53 = (($52) + ($metadataOffset$0))|0;
   __THREW__ = 0;
   invoke_viiii(400,($51|0),($54|0),($53|0),($metadataSize$0|0));
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if ($56) {
    $66 = $81;$67 = $54;
   } else {
    $57 = HEAP8[$44>>0]|0;
    $58 = ($57<<24>>24)==(0);
    $59 = HEAP32[$14>>2]|0;
    if ($58) {
     __THREW__ = 0;
     $60 = (invoke_iiiiiii(105,($this|0),($59|0),($dataOffset$0|0),($54|0),($metadataSize$0|0),($dataEnd$0|0))|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      $66 = $81;$67 = $54;
      break;
     }
     if ($60) {
      label = 21;
     } else {
      $$0 = 0;
     }
    } else {
     __THREW__ = 0;
     $70 = (invoke_iiiiiii(106,($this|0),($59|0),($dataOffset$0|0),($54|0),($metadataSize$0|0),($dataEnd$0|0))|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      $66 = $81;$67 = $54;
      break;
     }
     if ($70) {
      label = 21;
     } else {
      $$0 = 0;
     }
    }
    do {
     if ((label|0) == 21) {
      $73 = HEAP32[$14>>2]|0;
      $74 = ($73|0)>(10);
      if (!($74)) {
       __THREW__ = 0;
       $75 = (invoke_ii(3305,($this|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        $66 = $81;$67 = $54;
        break L28;
       }
       if (!($75)) {
        $$0 = 0;
        break;
       }
      }
      __THREW__ = 0;
      invoke_vi(3566,($this|0));
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       $66 = $81;$67 = $54;
       break L28;
      } else {
       $$0 = 1;
      }
     }
    } while(0);
    $80 = ($81|0)>(-1);
    if (!($80)) {
     $$1 = $$0;
     STACKTOP = sp;return ($$1|0);
    }
    HEAP32[$0>>2] = $46;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($54,$$byval_copy2);
    $$1 = $$0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 $63 = ___cxa_find_matching_catch()|0;
 $64 = tempRet0;
 $65 = ($66|0)>(-1);
 if (!($65)) {
  ___resumeException($63|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($67|0),($$byval_copy2|0));
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $82 = ___cxa_find_matching_catch(0|0)|0;
  $83 = tempRet0;
  ___clang_call_terminate($82);
  // unreachable;
 } else {
  ___resumeException($63|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN14SerializedFileD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i16 = 0, $eh$lpad$body$index3Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, $eh$lpad$body12$indexZ2D = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i17 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i21 = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy20 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 108|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[628408>>2]|0;
 $7 = ($5|0)==(0|0);
 if ($7) {
  label = 3;
 } else {
  $8 = HEAP32[$5>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  __THREW__ = 0;
  invoke_vi($9|0,($5|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   label = 20;
  } else {
   label = 3;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   HEAP32[$3>>2] = $6;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($5|0),($$byval_copy20|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    label = 20;
   } else {
    HEAP32[$4>>2] = 0;
    $14 = (($this) + 80|0);
    __THREW__ = 0;
    invoke_vi(3567,($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    L6: do {
     if ($16) {
      $26 = ___cxa_find_matching_catch()|0;
      $27 = tempRet0;
      $28 = (($this) + 104|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)>(-1);
      if ($30) {
       $31 = (($this) + 92|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($this) + 96|0);
       $34 = HEAP32[$33>>2]|0;
       HEAP32[$0>>2] = $34;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($32|0),($$byval_copy20|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        $37 = ___cxa_find_matching_catch(0|0)|0;
        $38 = tempRet0;
        ___clang_call_terminate($37);
        // unreachable;
       } else {
        HEAP32[$31>>2] = 0;
        $eh$lpad$body$index3Z2D = $27;$eh$lpad$body$indexZ2D = $26;
        break;
       }
      } else {
       $eh$lpad$body$index3Z2D = $27;$eh$lpad$body$indexZ2D = $26;
      }
     } else {
      $17 = (($this) + 104|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)>(-1);
      do {
       if ($19) {
        $20 = (($this) + 92|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = (($this) + 96|0);
        $23 = HEAP32[$22>>2]|0;
        HEAP32[$2>>2] = $23;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($21|0),($$byval_copy20|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         $86 = ___cxa_find_matching_catch()|0;
         $87 = tempRet0;
         $eh$lpad$body$index3Z2D = $87;$eh$lpad$body$indexZ2D = $86;
         break L6;
        } else {
         HEAP32[$20>>2] = 0;
         break;
        }
       }
      } while(0);
      $39 = (($this) + 76|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)>(-1);
      do {
       if ($41) {
        $42 = (($this) + 64|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = (($this) + 68|0);
        $45 = HEAP32[$44>>2]|0;
        HEAP32[$0>>2] = $45;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($43|0),($$byval_copy20|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         $88 = ___cxa_find_matching_catch()|0;
         $89 = tempRet0;
         $$1 = $89;$$12 = $88;
         break L3;
        } else {
         HEAP32[$42>>2] = 0;
         break;
        }
       }
      } while(0);
      $48 = (($this) + 24|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       $57 = (($this) + 4|0);
       $58 = HEAP32[$57>>2]|0;
       __ZNSt3__16__treeINS_12__value_typeIiN14SerializedFile4TypeEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$58);
       STACKTOP = sp;return;
      }
      $51 = (($this) + 28|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = ($52|0)==($49|0);
      if (!($53)) {
       $__new_last2$i$i$i$i$i$i$i$i$i = $49;
       $scevgep$i$i$i$i$i$i$i$i$i = (($52) + -24|0);
       $54 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
       $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($54)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
       $55 = (($uglygep3$i$i$i$i$i$i$i$i$i>>>0) / 24)&-1;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i = (($52) + (($56*24)|0)|0);
       HEAP32[$51>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
      }
      __ZdlPv($49);
      $57 = (($this) + 4|0);
      $58 = HEAP32[$57>>2]|0;
      __ZNSt3__16__treeINS_12__value_typeIiN14SerializedFile4TypeEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$58);
      STACKTOP = sp;return;
     }
    } while(0);
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
    label = 31;
   }
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   $59 = ___cxa_find_matching_catch()|0;
   $60 = tempRet0;
   $61 = (($this) + 80|0);
   __THREW__ = 0;
   invoke_vi(3567,($61|0));
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if (!($63)) {
    $64 = (($this) + 104|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($65|0)>(-1);
    if (!($66)) {
     $$0 = $60;$$01 = $59;
     label = 31;
     break;
    }
    $67 = (($this) + 92|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($this) + 96|0);
    $70 = HEAP32[$69>>2]|0;
    HEAP32[$1>>2] = $70;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($68|0),($$byval_copy20|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     label = 39;
     break;
    }
    HEAP32[$67>>2] = 0;
    $$0 = $60;$$01 = $59;
    label = 31;
    break;
   }
   $73 = ___cxa_find_matching_catch(0|0)|0;
   $74 = tempRet0;
   $75 = (($this) + 104|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)>(-1);
   if (!($77)) {
    $eh$lpad$body12$indexZ2D = $73;
    ___clang_call_terminate($eh$lpad$body12$indexZ2D);
    // unreachable;
   }
   $78 = (($this) + 92|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($this) + 96|0);
   $81 = HEAP32[$80>>2]|0;
   HEAP32[$0>>2] = $81;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($79|0),($$byval_copy20|0));
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $84 = ___cxa_find_matching_catch(0|0)|0;
    $85 = tempRet0;
    ___clang_call_terminate($84);
    // unreachable;
   }
   HEAP32[$78>>2] = 0;
   $eh$lpad$body12$indexZ2D = $73;
   ___clang_call_terminate($eh$lpad$body12$indexZ2D);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 31) {
  $90 = (($this) + 76|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($91|0)>(-1);
  if ($92) {
   $93 = (($this) + 64|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($this) + 68|0);
   $96 = HEAP32[$95>>2]|0;
   HEAP32[$0>>2] = $96;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($94|0),($$byval_copy20|0));
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   if ($98) {
    label = 39;
   } else {
    HEAP32[$93>>2] = 0;
    $$1 = $$0;$$12 = $$01;
   }
  } else {
   $$1 = $$0;$$12 = $$01;
  }
 }
 if ((label|0) == 39) {
  $110 = ___cxa_find_matching_catch(0|0)|0;
  $111 = tempRet0;
  $eh$lpad$body12$indexZ2D = $110;
  ___clang_call_terminate($eh$lpad$body12$indexZ2D);
  // unreachable;
 }
 $99 = (($this) + 24|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = ($100|0)==(0|0);
 if ($101) {
  $108 = (($this) + 4|0);
  $109 = HEAP32[$108>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiN14SerializedFile4TypeEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$109);
  ___resumeException($$12|0);
  // unreachable;
 }
 $102 = (($this) + 28|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ($103|0)==($100|0);
 if (!($104)) {
  $__new_last2$i$i$i$i$i$i$i$i$i16 = $100;
  $scevgep$i$i$i$i$i$i$i$i$i17 = (($103) + -24|0);
  $105 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i16))|0;
  $uglygep$i$i$i$i$i$i$i$i$i19 = (($scevgep$i$i$i$i$i$i$i$i$i17) + ($105)|0);
  $uglygep3$i$i$i$i$i$i$i$i$i20 = $uglygep$i$i$i$i$i$i$i$i$i19;
  $106 = (($uglygep3$i$i$i$i$i$i$i$i$i20>>>0) / 24)&-1;
  $107 = $106 ^ -1;
  $scevgep4$i$i$i$i$i$i$i$i$i21 = (($103) + (($107*24)|0)|0);
  HEAP32[$102>>2] = $scevgep4$i$i$i$i$i$i$i$i$i21;
 }
 __ZdlPv($100);
 $108 = (($this) + 4|0);
 $109 = HEAP32[$108>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN14SerializedFile4TypeEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$109);
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN14SerializedFile7ReleaseEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -1)|0;
 HEAP32[$1>>2] = $3;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[628360>>2]|0;
 __ZN14SerializedFileD2Ev($this);
 HEAP32[$0>>2] = $6;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN14SerializedFile12ReadMetadataILb0EEEbijPKhjj($this,$version,$dataOffset,$data,$length,$dataFileEnd) {
 $this = $this|0;
 $version = $version|0;
 $dataOffset = $dataOffset|0;
 $data = $data|0;
 $length = $length|0;
 $dataFileEnd = $dataFileEnd|0;
 var $$$$i$i$i45 = 0, $$$i$i$i44 = 0, $$03 = 0, $$05 = 0, $$14 = 0, $$16 = 0, $$5 = 0, $$byval_copy31 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $$pre119 = 0, $$pre130 = 0, $$pre132 = 0, $$pre133 = 0, $$pre134 = 0, $$sum = 0, $$sum$i = 0, $$sum$i$i$i = 0, $$sum$i24$us = 0;
 var $$sum137 = 0, $$sum62 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$lcssa$i$i$i = 0, $__p$0$ph$i$i$i = 0, $__p$02$i$i$i = 0, $exitcond = 0, $exitcond118 = 0, $i$097 = 0, $i1$0107 = 0, $i4$091 = 0;
 var $i5$085 = 0, $i5$085$us = 0, $i6$074 = 0, $i6$074$us = 0, $iterator = 0, $lpad$phi$index = 0, $lpad$phi$index8 = 0, $not$ = 0, $or$cond61 = 0, $phitmp = 0, $phitmp135 = 0, $phitmp136 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $scevgep8$i$i = 0, $storemerge = 0, $tempEmpty = 0, $typeID = 0, $typeID2 = 0, $unityVersion = 0;
 var $userInformation = 0, $vararg_ptr21 = 0, $version$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy31 = sp + 24|0;
 $0 = sp;
 $1 = sp + 144|0;
 $2 = sp + 140|0;
 $3 = sp + 136|0;
 $4 = sp + 132|0;
 $5 = sp + 128|0;
 $6 = sp + 124|0;
 $7 = sp + 120|0;
 $iterator = sp + 116|0;
 $unityVersion = sp + 148|0;
 $8 = sp + 44|0;
 $typeID = sp + 40|0;
 $typeID2 = sp + 32|0;
 $9 = sp + 36|0;
 $10 = sp + 92|0;
 $11 = sp + 56|0;
 $12 = sp + 68|0;
 $tempEmpty = sp + 80|0;
 $userInformation = sp + 104|0;
 HEAP32[$iterator>>2] = $data;
 $13 = (($data) + ($length)|0);
 ;HEAP32[$unityVersion+0>>2]=0|0;HEAP32[$unityVersion+4>>2]=0|0;HEAP32[$unityVersion+8>>2]=0|0;
 $14 = ($version|0)>(6);
 L1: do {
  if ($14) {
   __THREW__ = 0;
   $15 = (invoke_iiii(1562,($unityVersion|0),($iterator|0),($13|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    label = 10;
   } else {
    if ($15) {
     $32 = ($version|0)>(7);
     if (!($32)) {
      $$pre132 = HEAP32[$iterator>>2]|0;
      $82 = $$pre132;
      label = 32;
      break;
     }
     $33 = (($this) + 48|0);
     $34 = HEAP32[$iterator>>2]|0;
     $35 = HEAPU8[$34>>0]|(HEAPU8[$34+1>>0]<<8)|(HEAPU8[$34+2>>0]<<16)|(HEAPU8[$34+3>>0]<<24);
     HEAP8[$33>>0]=$35&255;HEAP8[$33+1>>0]=($35>>8)&255;HEAP8[$33+2>>0]=($35>>16)&255;HEAP8[$33+3>>0]=$35>>24;
     $36 = (($34) + 4|0);
     HEAP32[$iterator>>2] = $36;
     $37 = ($35|0)==(20);
     if ($37) {
      $61 = ($version|0)>(12);
      if (!($61)) {
       $82 = $36;
       label = 32;
       break;
      }
      $62 = (($this) + 44|0);
      $63 = HEAP8[$36>>0]|0;
      HEAP8[$62>>0] = $63;
      $64 = (($34) + 5|0);
      HEAP32[$iterator>>2] = $64;
      $65 = HEAPU8[$64>>0]|(HEAPU8[$64+1>>0]<<8)|(HEAPU8[$64+2>>0]<<16)|(HEAPU8[$64+3>>0]<<24);
      $66 = (($34) + 9|0);
      HEAP32[$iterator>>2] = $66;
      $67 = ($65|0)>(0);
      if (!($67)) {
       label = 46;
       break;
      }
      $70 = $66;$i$097 = 1;
      while(1) {
       $69 = HEAPU8[$70>>0]|(HEAPU8[$70+1>>0]<<8)|(HEAPU8[$70+2>>0]<<16)|(HEAPU8[$70+3>>0]<<24);
       HEAP32[$typeID>>2] = $69;
       $71 = (($70) + 4|0);
       HEAP32[$iterator>>2] = $71;
       __THREW__ = 0;
       $72 = (invoke_iii(2449,($this|0),($typeID|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = HEAP8[$62>>0]|0;
       $76 = ($75<<24>>24)!=(0);
       $77 = HEAP32[$typeID>>2]|0;
       __THREW__ = 0;
       $78 = (invoke_iiiiiii(107,($72|0),($version|0),($76|0),($77|0),($iterator|0),($13|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        break;
       }
       if (!($78)) {
        $$5 = 0;
        label = 182;
        break L1;
       }
       $68 = ($i$097|0)<($65|0);
       if (!($68)) {
        label = 46;
        break L1;
       }
       $$pre130 = HEAP32[$iterator>>2]|0;
       $phitmp136 = (($i$097) + 1)|0;
       $70 = $$pre130;$i$097 = $phitmp136;
      }
      $26 = ___cxa_find_matching_catch()|0;
      $27 = tempRet0;
      $lpad$phi$index = $26;$lpad$phi$index8 = $27;
      label = 11;
      break;
     } else {
      __THREW__ = 0;
      HEAP32[$$byval_copy31>>2] = $35;
      invoke_viii(1617,($8|0),(639504|0),($$byval_copy31|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 10;
       break;
      }
      $40 = HEAP8[$8>>0]|0;
      $41 = $40 & 1;
      $42 = ($41<<24>>24)==(0);
      if ($42) {
       $45 = (($8) + 1|0);
       $46 = $45;
      } else {
       $43 = (($8) + 8|0);
       $44 = HEAP32[$43>>2]|0;
       $46 = $44;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($46|0),0,(639432|0),852,1,0,0,(0|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       $54 = ___cxa_find_matching_catch()|0;
       $55 = tempRet0;
       $56 = HEAP8[$8>>0]|0;
       $57 = $56 & 1;
       $58 = ($57<<24>>24)==(0);
       if ($58) {
        $$14 = $54;$$16 = $55;
        break;
       }
       $59 = (($8) + 8|0);
       $60 = HEAP32[$59>>2]|0;
       __ZdlPv($60);
       $$14 = $54;$$16 = $55;
       break;
      } else {
       $49 = HEAP8[$8>>0]|0;
       $50 = $49 & 1;
       $51 = ($50<<24>>24)==(0);
       if ($51) {
        $$5 = 0;
        label = 182;
        break;
       }
       $52 = (($8) + 8|0);
       $53 = HEAP32[$52>>2]|0;
       __ZdlPv($53);
       $$5 = 0;
       label = 182;
       break;
      }
     }
    } else {
     $$5 = 0;
     label = 182;
    }
   }
  } else {
   $82 = $data;
   label = 32;
  }
 } while(0);
 L30: do {
  if ((label|0) == 32) {
   $81 = HEAPU8[$82>>0]|(HEAPU8[$82+1>>0]<<8)|(HEAPU8[$82+2>>0]<<16)|(HEAPU8[$82+3>>0]<<24);
   $83 = (($82) + 4|0);
   HEAP32[$iterator>>2] = $83;
   $84 = ($81|0)>(0);
   $85 = (($this) + 44|0);
   $86 = $84&1;
   HEAP8[$85>>0] = $86;
   if ($84) {
    $88 = $83;$i1$0107 = 1;
    while(1) {
     $87 = HEAPU8[$88>>0]|(HEAPU8[$88+1>>0]<<8)|(HEAPU8[$88+2>>0]<<16)|(HEAPU8[$88+3>>0]<<24);
     HEAP32[$typeID2>>2] = $87;
     $89 = (($88) + 4|0);
     HEAP32[$iterator>>2] = $89;
     $90 = HEAP32[628488>>2]|0;
     HEAP32[$9>>2] = $90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$9+0>>2]|0;
     $91 = (invoke_iiiiiii(103,48,($$byval_copy31|0),0,16,(639432|0),902)|0);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      label = 9;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3568,($91|0));
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      label = 41;
      break;
     }
     __THREW__ = 0;
     $96 = (invoke_iiiiii(204,($91|0),($iterator|0),($13|0),($version|0),0)|0);
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      label = 9;
      break;
     }
     if (!($96)) {
      label = 38;
      break;
     }
     __THREW__ = 0;
     $109 = (invoke_iii(2449,($this|0),($typeID2|0))|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if ($111) {
      label = 9;
      break;
     }
     $112 = (($109) + 36|0);
     HEAP32[$112>>2] = $91;
     $113 = ($i1$0107|0)<($81|0);
     if (!($113)) {
      label = 46;
      break L30;
     }
     $$pre133 = HEAP32[$iterator>>2]|0;
     $phitmp135 = (($i1$0107) + 1)|0;
     $88 = $$pre133;$i1$0107 = $phitmp135;
    }
    if ((label|0) == 9) {
     $28 = ___cxa_find_matching_catch()|0;
     $29 = tempRet0;
     $lpad$phi$index = $28;$lpad$phi$index8 = $29;
     label = 11;
     break;
    }
    else if ((label|0) == 38) {
     $99 = HEAP32[628488>>2]|0;
     $100 = ($91|0)==(0|0);
     if (!($100)) {
      __THREW__ = 0;
      invoke_vi(3569,($91|0));
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       label = 10;
       break;
      }
     }
     HEAP32[$5>>2] = $99;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($91|0),($$byval_copy31|0));
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 10;
      break;
     } else {
      $$5 = 0;
      label = 182;
      break;
     }
    }
    else if ((label|0) == 41) {
     $105 = ___cxa_find_matching_catch()|0;
     $106 = tempRet0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$9+0>>2]|0;
     invoke_viiiiii(97,($91|0),($$byval_copy31|0),0,16,(639432|0),902);
     $107 = __THREW__; __THREW__ = 0;
     $108 = $107&1;
     if ($108) {
      $608 = ___cxa_find_matching_catch(0|0)|0;
      $609 = tempRet0;
      ___clang_call_terminate($608);
      // unreachable;
     } else {
      $$14 = $105;$$16 = $106;
      break;
     }
    }
   } else {
    label = 46;
   }
  }
 } while(0);
 L51: do {
  if ((label|0) == 46) {
   $version$off = (($version) + -7)|0;
   $114 = ($version$off>>>0)<(7);
   $115 = HEAP32[$iterator>>2]|0;
   if ($114) {
    $116 = (($115) + 4|0);
    HEAP32[$iterator>>2] = $116;
    $118 = $116;
   } else {
    $118 = $115;
   }
   $117 = HEAPU8[$118>>0]|(HEAPU8[$118+1>>0]<<8)|(HEAPU8[$118+2>>0]<<16)|(HEAPU8[$118+3>>0]<<24);
   $119 = (($118) + 4|0);
   HEAP32[$iterator>>2] = $119;
   $120 = (($this) + 32|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = (($this) + 24|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = $121;
   $125 = $123;
   $126 = (($124) - ($125))|0;
   $127 = (($126|0) / 24)&-1;
   $128 = ($127>>>0)<($117>>>0);
   if ($128) {
    $129 = (($this) + 28|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = $130;
    $132 = (($131) - ($125))|0;
    $133 = (($132|0) / 24)&-1;
    $134 = ($117|0)==(0);
    if ($134) {
     $140 = 0;
    } else {
     $135 = ($117*24)|0;
     __THREW__ = 0;
     $136 = (invoke_ii(2988,($135|0))|0);
     $137 = __THREW__; __THREW__ = 0;
     $138 = $137&1;
     if ($138) {
      label = 10;
      break;
     }
     $140 = $136;
    }
    $139 = (($140) + (($133*24)|0)|0);
    $141 = (($140) + (($117*24)|0)|0);
    $142 = (($132|0) / -24)&-1;
    $$sum$i$i$i = (($142) + ($133))|0;
    $143 = (($140) + (($$sum$i$i$i*24)|0)|0);
    _memcpy(($143|0),($123|0),($132|0))|0;
    HEAP32[$122>>2] = $143;
    HEAP32[$129>>2] = $139;
    HEAP32[$120>>2] = $141;
    $144 = ($123|0)==(0|0);
    if (!($144)) {
     __ZdlPv($123);
    }
   }
   $145 = ($117|0)>(0);
   L64: do {
    if ($145) {
     $146 = ($version|0)>(13);
     $147 = $data;
     $148 = (3 - ($147))|0;
     $149 = ($version|0)<(11);
     $150 = (($0) + 8|0);
     $151 = (($0) + 12|0);
     $152 = (($0) + 16|0);
     $153 = (($0) + 20|0);
     $154 = (($0) + 22|0);
     $155 = (($this) + 28|0);
     $156 = (($this) + 24|0);
     $i4$091 = 1;
     while(1) {
      $157 = HEAP32[$iterator>>2]|0;
      if ($146) {
       $158 = $157;
       $159 = (($148) + ($158))|0;
       $160 = $159 & -4;
       $161 = (($data) + ($160)|0);
       $162 = $161;
       $163 = $162;
       $164 = HEAPU8[$163>>0]|(HEAPU8[$163+1>>0]<<8)|(HEAPU8[$163+2>>0]<<16)|(HEAPU8[$163+3>>0]<<24);
       $165 = (($162) + 4)|0;
       $166 = $165;
       $167 = HEAPU8[$166>>0]|(HEAPU8[$166+1>>0]<<8)|(HEAPU8[$166+2>>0]<<16)|(HEAPU8[$166+3>>0]<<24);
       $$sum$i = (($160) + 8)|0;
       $168 = (($data) + ($$sum$i)|0);
       HEAP32[$iterator>>2] = $168;
       $174 = $168;$190 = $164;$193 = $167;
      } else {
       $169 = HEAPU8[$157>>0]|(HEAPU8[$157+1>>0]<<8)|(HEAPU8[$157+2>>0]<<16)|(HEAPU8[$157+3>>0]<<24);
       $170 = (($157) + 4|0);
       HEAP32[$iterator>>2] = $170;
       $171 = ($169|0)<(0);
       $172 = $171 << 31 >> 31;
       $174 = $170;$190 = $169;$193 = $172;
      }
      $173 = HEAPU8[$174>>0]|(HEAPU8[$174+1>>0]<<8)|(HEAPU8[$174+2>>0]<<16)|(HEAPU8[$174+3>>0]<<24);
      $175 = (($174) + 4|0);
      HEAP32[$iterator>>2] = $175;
      $176 = HEAPU8[$175>>0]|(HEAPU8[$175+1>>0]<<8)|(HEAPU8[$175+2>>0]<<16)|(HEAPU8[$175+3>>0]<<24);
      $177 = (($174) + 8|0);
      HEAP32[$iterator>>2] = $177;
      $178 = HEAPU8[$177>>0]|(HEAPU8[$177+1>>0]<<8)|(HEAPU8[$177+2>>0]<<16)|(HEAPU8[$177+3>>0]<<24);
      $179 = (($174) + 12|0);
      HEAP32[$iterator>>2] = $179;
      $180 = HEAPU8[$179>>0]|(HEAPU8[$179+1>>0]<<8);
      $181 = (($174) + 14|0);
      HEAP32[$iterator>>2] = $181;
      if ($149) {
       $194 = -1;
      } else {
       $182 = HEAPU8[$181>>0]|(HEAPU8[$181+1>>0]<<8);
       $194 = $182;
      }
      $storemerge = (($174) + 16|0);
      HEAP32[$iterator>>2] = $storemerge;
      $183 = (($173) + ($dataOffset))|0;
      $184 = $183 | $176;
      $185 = ($184|0)<(0);
      $186 = (($183) + ($176))|0;
      $187 = ($186|0)>($dataFileEnd|0);
      $or$cond61 = $185 | $187;
      if ($or$cond61) {
       $$5 = 0;
       label = 182;
       break L51;
      }
      $188 = $0;
      $189 = $188;
      HEAP32[$189>>2] = $190;
      $191 = (($188) + 4)|0;
      $192 = $191;
      HEAP32[$192>>2] = $193;
      HEAP32[$150>>2] = $183;
      HEAP32[$151>>2] = $176;
      HEAP32[$152>>2] = $178;
      HEAP16[$153>>1] = $180;
      HEAP16[$154>>1] = $194;
      $195 = HEAP32[$155>>2]|0;
      $196 = HEAP32[$120>>2]|0;
      $197 = ($195|0)==($196|0);
      if ($197) {
       __THREW__ = 0;
       invoke_vii(3224,($156|0),($0|0));
       $201 = __THREW__; __THREW__ = 0;
       $202 = $201&1;
       if ($202) {
        break;
       }
      } else {
       $198 = ($195|0)==(0|0);
       if ($198) {
        $200 = 0;
       } else {
        ;HEAP32[$195+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$195+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$195+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$195+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$195+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$195+20>>2]=HEAP32[$0+20>>2]|0;
        $$pre$i$i = HEAP32[$155>>2]|0;
        $200 = $$pre$i$i;
       }
       $199 = (($200) + 24|0);
       HEAP32[$155>>2] = $199;
      }
      $203 = ($i4$091|0)<($117|0);
      if (!($203)) {
       $$pre$phiZ2D = $155;
       break L64;
      }
      $phitmp = (($i4$091) + 1)|0;
      $i4$091 = $phitmp;
     }
     $24 = ___cxa_find_matching_catch()|0;
     $25 = tempRet0;
     $lpad$phi$index = $24;$lpad$phi$index8 = $25;
     label = 11;
     break L51;
    } else {
     $$pre134 = (($this) + 28|0);
     $$pre$phiZ2D = $$pre134;
    }
   } while(0);
   $204 = HEAP32[$122>>2]|0;
   $205 = HEAP32[$$pre$phiZ2D>>2]|0;
   $206 = ($204|0)==($205|0);
   L87: do {
    if (!($206)) {
     $207 = (($this) + 44|0);
     $208 = HEAP8[$207>>0]|0;
     $209 = ($208<<24>>24)==(0);
     if ($209) {
      $210 = (($this) + 40|0);
      $211 = HEAP32[$210>>2]|0;
      $212 = $211 & 16777216;
      $213 = ($212|0)==(0);
      if ($213) {
       $214 = HEAP8[$unityVersion>>0]|0;
       $215 = $214 & 1;
       $216 = ($215<<24>>24)==(0);
       if ($216) {
        $219 = $214&255;
        $220 = $219 >>> 1;
        $222 = $220;
       } else {
        $217 = (($unityVersion) + 4|0);
        $218 = HEAP32[$217>>2]|0;
        $222 = $218;
       }
       $221 = ($222|0)==(0);
       do {
        if ($221) {
         label = 82;
        } else {
         if ($216) {
          $225 = (($unityVersion) + 1|0);
          $226 = $225;
         } else {
          $223 = (($unityVersion) + 8|0);
          $224 = HEAP32[$223>>2]|0;
          $226 = $224;
         }
         $227 = (_memchr($226,10,$222)|0);
         $228 = ($227|0)==(0|0);
         if ($228) {
          label = 82;
         } else {
          $229 = $227;
          $230 = $226;
          $231 = (($229) - ($230))|0;
          $232 = ($231|0)==(-1);
          if ($232) {
           label = 82;
          } else {
           if ($216) {
            $$sum137 = (($231) + 1)|0;
            $253 = ((($unityVersion) + ($$sum137)|0) + 1|0);
            $254 = (($unityVersion) + 1|0);
            $255 = $214&255;
            $256 = $255 >>> 1;
            $258 = $254;$259 = $256;$261 = $253;
           } else {
            $248 = (($unityVersion) + 8|0);
            $249 = HEAP32[$248>>2]|0;
            $$sum = (($231) + 1)|0;
            $250 = (($249) + ($$sum)|0);
            $251 = (($unityVersion) + 4|0);
            $252 = HEAP32[$251>>2]|0;
            $258 = $249;$259 = $252;$261 = $250;
           }
           $257 = (($258) + ($259)|0);
           $260 = $261;
           $262 = $257;
           $263 = (($262) - ($260))|0;
           $264 = ($263>>>0)>(4294967279);
           if ($264) {
            __THREW__ = 0;
            invoke_vi(3309,0);
            $265 = __THREW__; __THREW__ = 0;
            $266 = $265&1;
            if ($266) {
             label = 10;
             break L51;
            }
            // unreachable;
           }
           $267 = ($263>>>0)<(11);
           if ($267) {
            $268 = $263 << 1;
            $269 = $268&255;
            HEAP8[$10>>0] = $269;
            $270 = (($10) + 1|0);
            $__p$0$ph$i$i$i = $270;
           } else {
            $271 = (($263) + 16)|0;
            $272 = $271 & -16;
            __THREW__ = 0;
            $273 = (invoke_ii(2988,($272|0))|0);
            $274 = __THREW__; __THREW__ = 0;
            $275 = $274&1;
            if ($275) {
             label = 10;
             break L51;
            }
            $276 = (($10) + 8|0);
            HEAP32[$276>>2] = $273;
            $277 = $272 | 1;
            HEAP32[$10>>2] = $277;
            $278 = (($10) + 4|0);
            HEAP32[$278>>2] = $263;
            $__p$0$ph$i$i$i = $273;
           }
           $279 = ($261|0)==($257|0);
           if ($279) {
            $__p$0$lcssa$i$i$i = $__p$0$ph$i$i$i;
           } else {
            $$sum62 = (($259) - ($260))|0;
            $281 = $261;$__p$02$i$i$i = $__p$0$ph$i$i$i;
            while(1) {
             $280 = HEAP8[$281>>0]|0;
             HEAP8[$__p$02$i$i$i>>0] = $280;
             $282 = (($281) + 1|0);
             $283 = (($__p$02$i$i$i) + 1|0);
             $284 = ($282|0)==($257|0);
             if ($284) {
              break;
             } else {
              $281 = $282;$__p$02$i$i$i = $283;
             }
            }
            $scevgep$i$i = (($258) + ($$sum62)|0);
            $scevgep7$i$i = $scevgep$i$i;
            $scevgep8$i$i = (($__p$0$ph$i$i$i) + ($scevgep7$i$i)|0);
            $__p$0$lcssa$i$i$i = $scevgep8$i$i;
           }
           HEAP8[$__p$0$lcssa$i$i$i>>0] = 0;
           $285 = (_strlen((639424|0))|0);
           $286 = HEAP8[$10>>0]|0;
           $287 = $286 & 1;
           $288 = ($287<<24>>24)==(0);
           if ($288) {
            $291 = $286&255;
            $292 = $291 >>> 1;
            $300 = $292;
           } else {
            $289 = (($10) + 4|0);
            $290 = HEAP32[$289>>2]|0;
            $300 = $290;
           }
           $293 = ($285|0)==(-1);
           if ($293) {
            __THREW__ = 0;
            invoke_vi(3304,0);
            $294 = __THREW__; __THREW__ = 0;
            $295 = $294&1;
            if ($295) {
             $306 = ___cxa_find_matching_catch()|0;
             $307 = tempRet0;
             ___cxa_call_unexpected(($306|0));
             // unreachable;
            } else {
             // unreachable;
            }
           }
           if ($288) {
            $298 = (($10) + 1|0);
            $302 = $298;
           } else {
            $296 = (($10) + 8|0);
            $297 = HEAP32[$296>>2]|0;
            $302 = $297;
           }
           $299 = ($300>>>0)>($285>>>0);
           $301 = $299 ? $285 : $300;
           $303 = (_memcmp($302,639424,$301)|0);
           $304 = ($303|0)==(0);
           if ($304) {
            $305 = ($300>>>0)<($285>>>0);
            $$$i$i$i44 = $299&1;
            $$$$i$i$i45 = $305 ? -1 : $$$i$i$i44;
            $309 = $$$$i$i$i45;
           } else {
            $309 = $303;
           }
           $308 = ($309|0)==(0);
           if ($288) {
            if ($308) {
             break L87;
            } else {
             break;
            }
           } else {
            $310 = (($10) + 8|0);
            $311 = HEAP32[$310>>2]|0;
            __ZdlPv($311);
            if ($308) {
             break L87;
            } else {
             break;
            }
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 82) {
        if ($216) {
         $237 = $214&255;
         $238 = $237 >>> 1;
         $239 = (($unityVersion) + 1|0);
         $241 = $238;$243 = $239;
        } else {
         $233 = (($unityVersion) + 4|0);
         $234 = HEAP32[$233>>2]|0;
         $235 = (($unityVersion) + 8|0);
         $236 = HEAP32[$235>>2]|0;
         $241 = $234;$243 = $236;
        }
        $240 = ($241>>>0)>(8);
        $242 = $240 ? 8 : $241;
        $244 = (_memcmp($243,639744,$242)|0);
        $245 = ($244|0)==(0);
        if ($245) {
         $246 = $240 ^ 1;
         $not$ = ($241>>>0)>(7);
         $247 = $not$ & $246;
         if ($247) {
          break;
         }
        }
       }
       $312 = (($this) + 108|0);
       $313 = HEAP32[$312>>2]|0;
       $314 = HEAP32[$313>>2]|0;
       $315 = (($314) + 24|0);
       $316 = HEAP32[$315>>2]|0;
       __THREW__ = 0;
       invoke_vii($316|0,($12|0),($313|0));
       $317 = __THREW__; __THREW__ = 0;
       $318 = $317&1;
       if ($318) {
        label = 10;
        break L51;
       }
       $319 = HEAP8[$12>>0]|0;
       $320 = $319 & 1;
       $321 = ($320<<24>>24)==(0);
       if ($321) {
        $324 = (($12) + 1|0);
        $331 = $324;
       } else {
        $322 = (($12) + 8|0);
        $323 = HEAP32[$322>>2]|0;
        $331 = $323;
       }
       $325 = HEAP8[$unityVersion>>0]|0;
       $326 = $325 & 1;
       $327 = ($326<<24>>24)==(0);
       if ($327) {
        $330 = (($unityVersion) + 1|0);
        $332 = $330;
       } else {
        $328 = (($unityVersion) + 8|0);
        $329 = HEAP32[$328>>2]|0;
        $332 = $329;
       }
       __THREW__ = 0;
       HEAP32[$$byval_copy31>>2] = $331;
       $vararg_ptr21 = (($$byval_copy31) + 4|0);
       HEAP32[$vararg_ptr21>>2] = $332;
       invoke_viii(1617,($11|0),(639760|0),($$byval_copy31|0));
       $333 = __THREW__; __THREW__ = 0;
       $334 = $333&1;
       do {
        if ($334) {
         $354 = ___cxa_find_matching_catch()|0;
         $355 = tempRet0;
         $$03 = $354;$$05 = $355;
        } else {
         $335 = HEAP8[$11>>0]|0;
         $336 = $335 & 1;
         $337 = ($336<<24>>24)==(0);
         if ($337) {
          $340 = (($11) + 1|0);
          $341 = $340;
         } else {
          $338 = (($11) + 8|0);
          $339 = HEAP32[$338>>2]|0;
          $341 = $339;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,($341|0),0,(639432|0),989,1,0,0,(0|0));
         $342 = __THREW__; __THREW__ = 0;
         $343 = $342&1;
         if ($343) {
          $356 = ___cxa_find_matching_catch()|0;
          $357 = tempRet0;
          $358 = HEAP8[$11>>0]|0;
          $359 = $358 & 1;
          $360 = ($359<<24>>24)==(0);
          if ($360) {
           $$03 = $356;$$05 = $357;
           break;
          }
          $361 = (($11) + 8|0);
          $362 = HEAP32[$361>>2]|0;
          __ZdlPv($362);
          $$03 = $356;$$05 = $357;
          break;
         }
         $344 = HEAP8[$11>>0]|0;
         $345 = $344 & 1;
         $346 = ($345<<24>>24)==(0);
         if (!($346)) {
          $347 = (($11) + 8|0);
          $348 = HEAP32[$347>>2]|0;
          __ZdlPv($348);
         }
         $349 = HEAP8[$12>>0]|0;
         $350 = $349 & 1;
         $351 = ($350<<24>>24)==(0);
         if ($351) {
          $$5 = 0;
          label = 182;
          break L51;
         }
         $352 = (($12) + 8|0);
         $353 = HEAP32[$352>>2]|0;
         __ZdlPv($353);
         $$5 = 0;
         label = 182;
         break L51;
        }
       } while(0);
       $363 = HEAP8[$12>>0]|0;
       $364 = $363 & 1;
       $365 = ($364<<24>>24)==(0);
       if ($365) {
        $$14 = $$03;$$16 = $$05;
        break L51;
       }
       $366 = (($12) + 8|0);
       $367 = HEAP32[$366>>2]|0;
       __ZdlPv($367);
       $$14 = $$03;$$16 = $$05;
       break L51;
      }
     }
    }
   } while(0);
   $368 = ($version|0)>(10);
   if ($368) {
    $369 = HEAP32[$iterator>>2]|0;
    $370 = HEAPU8[$369>>0]|(HEAPU8[$369+1>>0]<<8)|(HEAPU8[$369+2>>0]<<16)|(HEAPU8[$369+3>>0]<<24);
    $371 = (($369) + 4|0);
    HEAP32[$iterator>>2] = $371;
    $372 = (($this) + 64|0);
    $373 = (($this) + 72|0);
    HEAP32[$373>>2] = $370;
    $374 = (($this) + 76|0);
    $375 = HEAP32[$374>>2]|0;
    $376 = $375 & 2147483647;
    $377 = ($376>>>0)<($370>>>0);
    do {
     if ($377) {
      $378 = ($375|0)>(-1);
      if ($378) {
       HEAP32[$374>>2] = $370;
       $379 = HEAP32[$372>>2]|0;
       $380 = $370 << 4;
       $381 = (($this) + 68|0);
       $382 = HEAP32[$381>>2]|0;
       HEAP32[$1>>2] = $382;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$1+0>>2]|0;
       $383 = (invoke_iiiiiiii(108,($379|0),($380|0),8,($$byval_copy31|0),0,(639432|0),370)|0);
       $384 = __THREW__; __THREW__ = 0;
       $385 = $384&1;
       if ($385) {
        label = 10;
        break L51;
       }
       HEAP32[$372>>2] = $383;
       break;
      } else {
       $386 = $370 << 4;
       $387 = (($this) + 68|0);
       $388 = HEAP32[$387>>2]|0;
       HEAP32[$2>>2] = $388;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$2+0>>2]|0;
       $389 = (invoke_iiiiiii(102,($386|0),8,($$byval_copy31|0),0,(639432|0),352)|0);
       $390 = __THREW__; __THREW__ = 0;
       $391 = $390&1;
       if ($391) {
        label = 10;
        break L51;
       }
       $392 = HEAP32[$372>>2]|0;
       $393 = HEAP32[$373>>2]|0;
       $394 = $393 << 4;
       _memcpy(($389|0),($392|0),($394|0))|0;
       HEAP32[$374>>2] = $370;
       HEAP32[$372>>2] = $389;
       break;
      }
     }
    } while(0);
    $395 = ($370|0)>(0);
    if ($395) {
     $396 = ($version|0)>(13);
     $397 = $data;
     $398 = (3 - ($397))|0;
     $$pre = HEAP32[$372>>2]|0;
     $$pre119 = HEAP32[$iterator>>2]|0;
     if ($396) {
      $400 = $$pre;$402 = $$pre119;$i5$085$us = 0;
      while(1) {
       $399 = (($400) + ($i5$085$us<<4)|0);
       $401 = HEAPU8[$402>>0]|(HEAPU8[$402+1>>0]<<8)|(HEAPU8[$402+2>>0]<<16)|(HEAPU8[$402+3>>0]<<24);
       HEAP8[$399>>0]=$401&255;HEAP8[$399+1>>0]=($401>>8)&255;HEAP8[$399+2>>0]=($401>>16)&255;HEAP8[$399+3>>0]=$401>>24;
       $403 = HEAP32[$iterator>>2]|0;
       $404 = (($403) + 4|0);
       $405 = $404;
       $406 = (($398) + ($405))|0;
       $407 = $406 & -4;
       $408 = (($data) + ($407)|0);
       $409 = $408;
       $410 = $409;
       $411 = HEAPU8[$410>>0]|(HEAPU8[$410+1>>0]<<8)|(HEAPU8[$410+2>>0]<<16)|(HEAPU8[$410+3>>0]<<24);
       $412 = (($409) + 4)|0;
       $413 = $412;
       $414 = HEAPU8[$413>>0]|(HEAPU8[$413+1>>0]<<8)|(HEAPU8[$413+2>>0]<<16)|(HEAPU8[$413+3>>0]<<24);
       $$sum$i24$us = (($407) + 8)|0;
       $415 = (($data) + ($$sum$i24$us)|0);
       HEAP32[$iterator>>2] = $415;
       $416 = HEAP32[$372>>2]|0;
       $417 = ((($416) + ($i5$085$us<<4)|0) + 8|0);
       $418 = $417;
       $419 = $418;
       HEAP32[$419>>2] = $411;
       $420 = (($418) + 4)|0;
       $421 = $420;
       HEAP32[$421>>2] = $414;
       $422 = (($i5$085$us) + 1)|0;
       $exitcond118 = ($422|0)==($370|0);
       if ($exitcond118) {
        break;
       } else {
        $400 = $416;$402 = $415;$i5$085$us = $422;
       }
      }
     } else {
      $424 = $$pre;$426 = $$pre119;$i5$085 = 0;
      while(1) {
       $423 = (($424) + ($i5$085<<4)|0);
       $425 = HEAPU8[$426>>0]|(HEAPU8[$426+1>>0]<<8)|(HEAPU8[$426+2>>0]<<16)|(HEAPU8[$426+3>>0]<<24);
       HEAP8[$423>>0]=$425&255;HEAP8[$423+1>>0]=($425>>8)&255;HEAP8[$423+2>>0]=($425>>16)&255;HEAP8[$423+3>>0]=$425>>24;
       $427 = HEAP32[$iterator>>2]|0;
       $428 = (($427) + 4|0);
       HEAP32[$iterator>>2] = $428;
       $429 = HEAPU8[$428>>0]|(HEAPU8[$428+1>>0]<<8)|(HEAPU8[$428+2>>0]<<16)|(HEAPU8[$428+3>>0]<<24);
       $430 = (($427) + 8|0);
       HEAP32[$iterator>>2] = $430;
       $431 = ($429|0)<(0);
       $432 = $431 << 31 >> 31;
       $433 = HEAP32[$372>>2]|0;
       $434 = ((($433) + ($i5$085<<4)|0) + 8|0);
       $435 = $434;
       $436 = $435;
       HEAP32[$436>>2] = $429;
       $437 = (($435) + 4)|0;
       $438 = $437;
       HEAP32[$438>>2] = $432;
       $439 = (($i5$085) + 1)|0;
       $exitcond = ($439|0)==($370|0);
       if ($exitcond) {
        break;
       } else {
        $424 = $433;$426 = $430;$i5$085 = $439;
       }
      }
     }
    }
   }
   $440 = HEAP32[$iterator>>2]|0;
   $441 = HEAPU8[$440>>0]|(HEAPU8[$440+1>>0]<<8)|(HEAPU8[$440+2>>0]<<16)|(HEAPU8[$440+3>>0]<<24);
   $442 = (($440) + 4|0);
   HEAP32[$iterator>>2] = $442;
   $443 = (($this) + 80|0);
   $444 = (($this) + 84|0);
   $445 = HEAP32[$444>>2]|0;
   $446 = ($445>>>0)<($441>>>0);
   L194: do {
    if ($446) {
     while(1) {
      __THREW__ = 0;
      invoke_vi(3570,($443|0));
      $449 = __THREW__; __THREW__ = 0;
      $450 = $449&1;
      if ($450) {
       break;
      }
      $451 = HEAP32[$444>>2]|0;
      $452 = ($451>>>0)<($441>>>0);
      if (!($452)) {
       $448 = $451;
       break L194;
      }
     }
     $22 = ___cxa_find_matching_catch()|0;
     $23 = tempRet0;
     $lpad$phi$index = $22;$lpad$phi$index8 = $23;
     label = 11;
     break L51;
    } else {
     $448 = $445;
    }
   } while(0);
   $447 = ($448>>>0)>($441>>>0);
   L200: do {
    if ($447) {
     while(1) {
      __THREW__ = 0;
      invoke_vi(3571,($443|0));
      $453 = __THREW__; __THREW__ = 0;
      $454 = $453&1;
      if ($454) {
       break;
      }
      $455 = HEAP32[$444>>2]|0;
      $456 = ($455>>>0)>($441>>>0);
      if (!($456)) {
       break L200;
      }
     }
     $20 = ___cxa_find_matching_catch()|0;
     $21 = tempRet0;
     $lpad$phi$index = $20;$lpad$phi$index8 = $21;
     label = 11;
     break L51;
    }
   } while(0);
   $457 = ($441|0)>(0);
   $458 = ($version|0)>(4);
   L206: do {
    if ($457) {
     $459 = ($version|0)>(5);
     $460 = (($tempEmpty) + 8|0);
     $461 = (($this) + 92|0);
     if ($458) {
      $i6$074$us = 0;
     } else {
      $i6$074 = 0;
      while(1) {
       $554 = HEAP32[$443>>2]|0;
       $555 = (($i6$074>>>0) / ($554>>>0))&-1;
       $556 = HEAP32[$461>>2]|0;
       $557 = (($556) + ($555<<2)|0);
       $558 = HEAP32[$557>>2]|0;
       $559 = (($i6$074>>>0) % ($554>>>0))&-1;
       $560 = HEAP32[$558>>2]|0;
       $561 = (($560) + ($559<<5)|0);
       __THREW__ = 0;
       $562 = (invoke_iiii(1562,($561|0),($iterator|0),($13|0))|0);
       $563 = __THREW__; __THREW__ = 0;
       $564 = $563&1;
       if ($564) {
        break;
       }
       if (!($562)) {
        $$5 = 0;
        label = 182;
        break L51;
       }
       $565 = (($i6$074) + 1)|0;
       $566 = ($565|0)<($441|0);
       if ($566) {
        $i6$074 = $565;
       } else {
        break L206;
       }
      }
      $18 = ___cxa_find_matching_catch()|0;
      $19 = tempRet0;
      $lpad$phi$index = $18;$lpad$phi$index8 = $19;
      label = 11;
      break L51;
     }
     while(1) {
      if ($459) {
       ;HEAP32[$tempEmpty+0>>2]=0|0;HEAP32[$tempEmpty+4>>2]=0|0;HEAP32[$tempEmpty+8>>2]=0|0;
       __THREW__ = 0;
       $462 = (invoke_iiii(1562,($tempEmpty|0),($iterator|0),($13|0))|0);
       $463 = __THREW__; __THREW__ = 0;
       $464 = $463&1;
       if ($464) {
        label = 166;
        break;
       }
       $465 = HEAP8[$tempEmpty>>0]|0;
       $466 = $465 & 1;
       $467 = ($466<<24>>24)==(0);
       if (!($467)) {
        $468 = HEAP32[$460>>2]|0;
        HEAP32[$3>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($468|0),($$byval_copy31|0));
        $469 = __THREW__; __THREW__ = 0;
        $470 = $469&1;
        if ($470) {
         label = 165;
         break;
        }
       }
       if (!($462)) {
        $$5 = 0;
        label = 182;
        break L51;
       }
      }
      $473 = HEAP32[$443>>2]|0;
      $474 = (($i6$074$us>>>0) / ($473>>>0))&-1;
      $475 = HEAP32[$461>>2]|0;
      $476 = (($475) + ($474<<2)|0);
      $477 = HEAP32[$476>>2]|0;
      $478 = (($i6$074$us>>>0) % ($473>>>0))&-1;
      $479 = HEAP32[$477>>2]|0;
      $480 = ((($479) + ($478<<5)|0) + 16|0);
      $481 = HEAP32[$iterator>>2]|0;
      $482 = HEAPU8[$481>>0]|(HEAPU8[$481+1>>0]<<8)|(HEAPU8[$481+2>>0]<<16)|(HEAPU8[$481+3>>0]<<24);
      HEAP8[$480>>0]=$482&255;HEAP8[$480+1>>0]=($482>>8)&255;HEAP8[$480+2>>0]=($482>>16)&255;HEAP8[$480+3>>0]=$482>>24;
      $483 = HEAP32[$iterator>>2]|0;
      $484 = (($483) + 4|0);
      HEAP32[$iterator>>2] = $484;
      $485 = HEAP32[$443>>2]|0;
      $486 = (($i6$074$us>>>0) / ($485>>>0))&-1;
      $487 = HEAP32[$461>>2]|0;
      $488 = (($487) + ($486<<2)|0);
      $489 = HEAP32[$488>>2]|0;
      $490 = (($i6$074$us>>>0) % ($485>>>0))&-1;
      $491 = HEAP32[$489>>2]|0;
      $492 = ((($491) + ($490<<5)|0) + 20|0);
      $493 = HEAPU8[$484>>0]|(HEAPU8[$484+1>>0]<<8)|(HEAPU8[$484+2>>0]<<16)|(HEAPU8[$484+3>>0]<<24);
      HEAP8[$492>>0]=$493&255;HEAP8[$492+1>>0]=($493>>8)&255;HEAP8[$492+2>>0]=($493>>16)&255;HEAP8[$492+3>>0]=$493>>24;
      $494 = HEAP32[$iterator>>2]|0;
      $495 = (($494) + 4|0);
      HEAP32[$iterator>>2] = $495;
      $496 = HEAP32[$443>>2]|0;
      $497 = (($i6$074$us>>>0) / ($496>>>0))&-1;
      $498 = HEAP32[$461>>2]|0;
      $499 = (($498) + ($497<<2)|0);
      $500 = HEAP32[$499>>2]|0;
      $501 = (($i6$074$us>>>0) % ($496>>>0))&-1;
      $502 = HEAP32[$500>>2]|0;
      $503 = ((($502) + ($501<<5)|0) + 24|0);
      $504 = HEAPU8[$495>>0]|(HEAPU8[$495+1>>0]<<8)|(HEAPU8[$495+2>>0]<<16)|(HEAPU8[$495+3>>0]<<24);
      HEAP8[$503>>0]=$504&255;HEAP8[$503+1>>0]=($504>>8)&255;HEAP8[$503+2>>0]=($504>>16)&255;HEAP8[$503+3>>0]=$504>>24;
      $505 = HEAP32[$iterator>>2]|0;
      $506 = (($505) + 4|0);
      HEAP32[$iterator>>2] = $506;
      $507 = HEAP32[$443>>2]|0;
      $508 = (($i6$074$us>>>0) / ($507>>>0))&-1;
      $509 = HEAP32[$461>>2]|0;
      $510 = (($509) + ($508<<2)|0);
      $511 = HEAP32[$510>>2]|0;
      $512 = (($i6$074$us>>>0) % ($507>>>0))&-1;
      $513 = HEAP32[$511>>2]|0;
      $514 = ((($513) + ($512<<5)|0) + 28|0);
      $515 = HEAPU8[$506>>0]|(HEAPU8[$506+1>>0]<<8)|(HEAPU8[$506+2>>0]<<16)|(HEAPU8[$506+3>>0]<<24);
      HEAP8[$514>>0]=$515&255;HEAP8[$514+1>>0]=($515>>8)&255;HEAP8[$514+2>>0]=($515>>16)&255;HEAP8[$514+3>>0]=$515>>24;
      $516 = HEAP32[$iterator>>2]|0;
      $517 = (($516) + 4|0);
      HEAP32[$iterator>>2] = $517;
      $518 = HEAP32[$443>>2]|0;
      $519 = (($i6$074$us>>>0) / ($518>>>0))&-1;
      $520 = HEAP32[$461>>2]|0;
      $521 = (($520) + ($519<<2)|0);
      $522 = HEAP32[$521>>2]|0;
      $523 = (($i6$074$us>>>0) % ($518>>>0))&-1;
      $524 = HEAP32[$522>>2]|0;
      $525 = ((($524) + ($523<<5)|0) + 12|0);
      $526 = HEAPU8[$517>>0]|(HEAPU8[$517+1>>0]<<8)|(HEAPU8[$517+2>>0]<<16)|(HEAPU8[$517+3>>0]<<24);
      HEAP8[$525>>0]=$526&255;HEAP8[$525+1>>0]=($526>>8)&255;HEAP8[$525+2>>0]=($526>>16)&255;HEAP8[$525+3>>0]=$526>>24;
      $527 = HEAP32[$iterator>>2]|0;
      $528 = (($527) + 4|0);
      HEAP32[$iterator>>2] = $528;
      $529 = HEAP32[$443>>2]|0;
      $530 = (($i6$074$us>>>0) / ($529>>>0))&-1;
      $531 = HEAP32[$461>>2]|0;
      $532 = (($531) + ($530<<2)|0);
      $533 = HEAP32[$532>>2]|0;
      $534 = (($i6$074$us>>>0) % ($529>>>0))&-1;
      $535 = HEAP32[$533>>2]|0;
      $536 = (($535) + ($534<<5)|0);
      __THREW__ = 0;
      $537 = (invoke_iiii(1562,($536|0),($iterator|0),($13|0))|0);
      $538 = __THREW__; __THREW__ = 0;
      $539 = $538&1;
      if ($539) {
       label = 164;
       break;
      }
      if (!($537)) {
       $$5 = 0;
       label = 182;
       break L51;
      }
      $471 = (($i6$074$us) + 1)|0;
      $472 = ($471|0)<($441|0);
      if ($472) {
       $i6$074$us = $471;
      } else {
       break L206;
      }
     }
     if ((label|0) == 164) {
      $540 = ___cxa_find_matching_catch()|0;
      $541 = tempRet0;
      $lpad$phi$index = $540;$lpad$phi$index8 = $541;
      label = 11;
      break L51;
     }
     else if ((label|0) == 165) {
      $542 = ___cxa_find_matching_catch()|0;
      $543 = tempRet0;
      ___cxa_call_unexpected(($542|0));
      // unreachable;
     }
     else if ((label|0) == 166) {
      $544 = ___cxa_find_matching_catch()|0;
      $545 = tempRet0;
      $546 = HEAP8[$tempEmpty>>0]|0;
      $547 = $546 & 1;
      $548 = ($547<<24>>24)==(0);
      if ($548) {
       $$14 = $544;$$16 = $545;
       break L51;
      }
      $549 = HEAP32[$460>>2]|0;
      HEAP32[$4>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($549|0),($$byval_copy31|0));
      $550 = __THREW__; __THREW__ = 0;
      $551 = $550&1;
      if (!($551)) {
       $$14 = $544;$$16 = $545;
       break L51;
      }
      $552 = ___cxa_find_matching_catch()|0;
      $553 = tempRet0;
      ___cxa_call_unexpected(($552|0));
      // unreachable;
     }
    }
   } while(0);
   if ($458) {
    ;HEAP32[$userInformation+0>>2]=0|0;HEAP32[$userInformation+4>>2]=0|0;HEAP32[$userInformation+8>>2]=0|0;
    __THREW__ = 0;
    $567 = (invoke_iiii(1562,($userInformation|0),($iterator|0),($13|0))|0);
    $568 = __THREW__; __THREW__ = 0;
    $569 = $568&1;
    if ($569) {
     $579 = ___cxa_find_matching_catch()|0;
     $580 = tempRet0;
     $581 = HEAP8[$userInformation>>0]|0;
     $582 = $581 & 1;
     $583 = ($582<<24>>24)==(0);
     if ($583) {
      $$14 = $579;$$16 = $580;
      break;
     }
     $584 = (($userInformation) + 8|0);
     $585 = HEAP32[$584>>2]|0;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($585|0),($$byval_copy31|0));
     $586 = __THREW__; __THREW__ = 0;
     $587 = $586&1;
     if (!($587)) {
      $$14 = $579;$$16 = $580;
      break;
     }
     $588 = ___cxa_find_matching_catch()|0;
     $589 = tempRet0;
     ___cxa_call_unexpected(($588|0));
     // unreachable;
    }
    $570 = HEAP8[$userInformation>>0]|0;
    $571 = $570 & 1;
    $572 = ($571<<24>>24)==(0);
    if (!($572)) {
     $573 = (($userInformation) + 8|0);
     $574 = HEAP32[$573>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($574|0),($$byval_copy31|0));
     $575 = __THREW__; __THREW__ = 0;
     $576 = $575&1;
     if ($576) {
      $577 = ___cxa_find_matching_catch()|0;
      $578 = tempRet0;
      ___cxa_call_unexpected(($577|0));
      // unreachable;
     }
    }
    if (!($567)) {
     $$5 = 0;
     label = 182;
     break;
    }
   }
   $$5 = 1;
   label = 182;
  }
 } while(0);
 if ((label|0) == 10) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $lpad$phi$index = $30;$lpad$phi$index8 = $31;
  label = 11;
 }
 else if ((label|0) == 182) {
  $590 = HEAP8[$unityVersion>>0]|0;
  $591 = $590 & 1;
  $592 = ($591<<24>>24)==(0);
  if ($592) {
   STACKTOP = sp;return ($$5|0);
  }
  $593 = (($unityVersion) + 8|0);
  $594 = HEAP32[$593>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($594|0),($$byval_copy31|0));
  $595 = __THREW__; __THREW__ = 0;
  $596 = $595&1;
  if ($596) {
   $597 = ___cxa_find_matching_catch()|0;
   $598 = tempRet0;
   ___cxa_call_unexpected(($597|0));
   // unreachable;
  } else {
   STACKTOP = sp;return ($$5|0);
  }
 }
 if ((label|0) == 11) {
  $$14 = $lpad$phi$index;$$16 = $lpad$phi$index8;
 }
 $599 = HEAP8[$unityVersion>>0]|0;
 $600 = $599 & 1;
 $601 = ($600<<24>>24)==(0);
 if ($601) {
  ___resumeException($$14|0);
  // unreachable;
 }
 $602 = (($unityVersion) + 8|0);
 $603 = HEAP32[$602>>2]|0;
 HEAP32[$7>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$7+0>>2]|0;
 invoke_vii(2591,($603|0),($$byval_copy31|0));
 $604 = __THREW__; __THREW__ = 0;
 $605 = $604&1;
 if ($605) {
  $606 = ___cxa_find_matching_catch()|0;
  $607 = tempRet0;
  ___cxa_call_unexpected(($606|0));
  // unreachable;
 } else {
  ___resumeException($$14|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN14SerializedFile12ReadMetadataILb1EEEbijPKhjj($this,$version,$dataOffset,$data,$length,$dataFileEnd) {
 $this = $this|0;
 $version = $version|0;
 $dataOffset = $dataOffset|0;
 $data = $data|0;
 $length = $length|0;
 $dataFileEnd = $dataFileEnd|0;
 var $$$$i$i$i46 = 0, $$$i$i$i45 = 0, $$03 = 0, $$05 = 0, $$14 = 0, $$16 = 0, $$5 = 0, $$byval_copy29 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $$pre115 = 0, $$pre124 = 0, $$pre126 = 0, $$pre127 = 0, $$pre128 = 0, $$sum = 0, $$sum$i = 0, $$sum$i$i$i = 0, $$sum$i25 = 0;
 var $$sum131 = 0, $$sum63 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$lcssa$i$i$i = 0, $__p$0$ph$i$i$i = 0;
 var $__p$02$i$i$i = 0, $exitcond = 0, $i$096 = 0, $i1$0106 = 0, $i4$090 = 0, $i5$084 = 0, $i6$075 = 0, $iterator = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0, $not$ = 0, $or$cond62 = 0, $phitmp = 0, $phitmp129 = 0, $phitmp130 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $scevgep8$i$i = 0, $storemerge = 0, $tempEmpty = 0;
 var $typeID = 0, $typeID2 = 0, $unityVersion = 0, $userInformation = 0, $vararg_ptr19 = 0, $version$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy29 = sp + 24|0;
 $0 = sp;
 $1 = sp + 144|0;
 $2 = sp + 140|0;
 $3 = sp + 136|0;
 $4 = sp + 132|0;
 $5 = sp + 128|0;
 $6 = sp + 124|0;
 $7 = sp + 120|0;
 $iterator = sp + 116|0;
 $unityVersion = sp + 148|0;
 $8 = sp + 44|0;
 $typeID = sp + 40|0;
 $typeID2 = sp + 32|0;
 $9 = sp + 36|0;
 $10 = sp + 92|0;
 $11 = sp + 56|0;
 $12 = sp + 68|0;
 $tempEmpty = sp + 80|0;
 $userInformation = sp + 104|0;
 HEAP32[$iterator>>2] = $data;
 $13 = (($data) + ($length)|0);
 ;HEAP32[$unityVersion+0>>2]=0|0;HEAP32[$unityVersion+4>>2]=0|0;HEAP32[$unityVersion+8>>2]=0|0;
 $14 = ($version|0)>(6);
 L1: do {
  if ($14) {
   __THREW__ = 0;
   $15 = (invoke_iiii(1562,($unityVersion|0),($iterator|0),($13|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    label = 10;
   } else {
    if ($15) {
     $32 = ($version|0)>(7);
     if (!($32)) {
      $$pre126 = HEAP32[$iterator>>2]|0;
      $85 = $$pre126;
      label = 32;
      break;
     }
     $33 = (($this) + 48|0);
     $34 = HEAP32[$iterator>>2]|0;
     $35 = HEAPU8[$34>>0]|(HEAPU8[$34+1>>0]<<8)|(HEAPU8[$34+2>>0]<<16)|(HEAPU8[$34+3>>0]<<24);
     $36 = (_llvm_bswap_i32(($35|0))|0);
     HEAP32[$33>>2] = $36;
     $37 = (($34) + 4|0);
     HEAP32[$iterator>>2] = $37;
     $38 = ($35|0)==(335544320);
     if ($38) {
      $62 = ($version|0)>(12);
      if (!($62)) {
       $85 = $37;
       label = 32;
       break;
      }
      $63 = (($this) + 44|0);
      $64 = HEAP8[$37>>0]|0;
      HEAP8[$63>>0] = $64;
      $65 = (($34) + 5|0);
      HEAP32[$iterator>>2] = $65;
      $66 = HEAPU8[$65>>0]|(HEAPU8[$65+1>>0]<<8)|(HEAPU8[$65+2>>0]<<16)|(HEAPU8[$65+3>>0]<<24);
      $67 = (_llvm_bswap_i32(($66|0))|0);
      $68 = (($34) + 9|0);
      HEAP32[$iterator>>2] = $68;
      $69 = ($67|0)>(0);
      if (!($69)) {
       label = 46;
       break;
      }
      $72 = $68;$i$096 = 1;
      while(1) {
       $71 = HEAPU8[$72>>0]|(HEAPU8[$72+1>>0]<<8)|(HEAPU8[$72+2>>0]<<16)|(HEAPU8[$72+3>>0]<<24);
       $73 = (_llvm_bswap_i32(($71|0))|0);
       HEAP32[$typeID>>2] = $73;
       $74 = (($72) + 4|0);
       HEAP32[$iterator>>2] = $74;
       __THREW__ = 0;
       $75 = (invoke_iii(2449,($this|0),($typeID|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
       $78 = HEAP8[$63>>0]|0;
       $79 = ($78<<24>>24)!=(0);
       $80 = HEAP32[$typeID>>2]|0;
       __THREW__ = 0;
       $81 = (invoke_iiiiiii(108,($75|0),($version|0),($79|0),($80|0),($iterator|0),($13|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       if (!($81)) {
        $$5 = 0;
        label = 183;
        break L1;
       }
       $70 = ($i$096|0)<($67|0);
       if (!($70)) {
        label = 46;
        break L1;
       }
       $$pre124 = HEAP32[$iterator>>2]|0;
       $phitmp130 = (($i$096) + 1)|0;
       $72 = $$pre124;$i$096 = $phitmp130;
      }
      $26 = ___cxa_find_matching_catch()|0;
      $27 = tempRet0;
      $lpad$phi$index = $26;$lpad$phi$index7 = $27;
      label = 11;
      break;
     } else {
      __THREW__ = 0;
      HEAP32[$$byval_copy29>>2] = $36;
      invoke_viii(1617,($8|0),(639504|0),($$byval_copy29|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 10;
       break;
      }
      $41 = HEAP8[$8>>0]|0;
      $42 = $41 & 1;
      $43 = ($42<<24>>24)==(0);
      if ($43) {
       $46 = (($8) + 1|0);
       $47 = $46;
      } else {
       $44 = (($8) + 8|0);
       $45 = HEAP32[$44>>2]|0;
       $47 = $45;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($47|0),0,(639432|0),852,1,0,0,(0|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       $55 = ___cxa_find_matching_catch()|0;
       $56 = tempRet0;
       $57 = HEAP8[$8>>0]|0;
       $58 = $57 & 1;
       $59 = ($58<<24>>24)==(0);
       if ($59) {
        $$14 = $55;$$16 = $56;
        break;
       }
       $60 = (($8) + 8|0);
       $61 = HEAP32[$60>>2]|0;
       __ZdlPv($61);
       $$14 = $55;$$16 = $56;
       break;
      } else {
       $50 = HEAP8[$8>>0]|0;
       $51 = $50 & 1;
       $52 = ($51<<24>>24)==(0);
       if ($52) {
        $$5 = 0;
        label = 183;
        break;
       }
       $53 = (($8) + 8|0);
       $54 = HEAP32[$53>>2]|0;
       __ZdlPv($54);
       $$5 = 0;
       label = 183;
       break;
      }
     }
    } else {
     $$5 = 0;
     label = 183;
    }
   }
  } else {
   $85 = $data;
   label = 32;
  }
 } while(0);
 L30: do {
  if ((label|0) == 32) {
   $84 = HEAPU8[$85>>0]|(HEAPU8[$85+1>>0]<<8)|(HEAPU8[$85+2>>0]<<16)|(HEAPU8[$85+3>>0]<<24);
   $86 = (_llvm_bswap_i32(($84|0))|0);
   $87 = (($85) + 4|0);
   HEAP32[$iterator>>2] = $87;
   $88 = ($86|0)>(0);
   $89 = (($this) + 44|0);
   $90 = $88&1;
   HEAP8[$89>>0] = $90;
   if ($88) {
    $92 = $87;$i1$0106 = 1;
    while(1) {
     $91 = HEAPU8[$92>>0]|(HEAPU8[$92+1>>0]<<8)|(HEAPU8[$92+2>>0]<<16)|(HEAPU8[$92+3>>0]<<24);
     $93 = (_llvm_bswap_i32(($91|0))|0);
     HEAP32[$typeID2>>2] = $93;
     $94 = (($92) + 4|0);
     HEAP32[$iterator>>2] = $94;
     $95 = HEAP32[628488>>2]|0;
     HEAP32[$9>>2] = $95;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$9+0>>2]|0;
     $96 = (invoke_iiiiiii(103,48,($$byval_copy29|0),0,16,(639432|0),902)|0);
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      label = 9;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3568,($96|0));
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      label = 41;
      break;
     }
     __THREW__ = 0;
     $101 = (invoke_iiiiii(204,($96|0),($iterator|0),($13|0),($version|0),1)|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 9;
      break;
     }
     if (!($101)) {
      label = 38;
      break;
     }
     __THREW__ = 0;
     $114 = (invoke_iii(2449,($this|0),($typeID2|0))|0);
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     if ($116) {
      label = 9;
      break;
     }
     $117 = (($114) + 36|0);
     HEAP32[$117>>2] = $96;
     $118 = ($i1$0106|0)<($86|0);
     if (!($118)) {
      label = 46;
      break L30;
     }
     $$pre127 = HEAP32[$iterator>>2]|0;
     $phitmp129 = (($i1$0106) + 1)|0;
     $92 = $$pre127;$i1$0106 = $phitmp129;
    }
    if ((label|0) == 9) {
     $28 = ___cxa_find_matching_catch()|0;
     $29 = tempRet0;
     $lpad$phi$index = $28;$lpad$phi$index7 = $29;
     label = 11;
     break;
    }
    else if ((label|0) == 38) {
     $104 = HEAP32[628488>>2]|0;
     $105 = ($96|0)==(0|0);
     if (!($105)) {
      __THREW__ = 0;
      invoke_vi(3569,($96|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       label = 10;
       break;
      }
     }
     HEAP32[$5>>2] = $104;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($96|0),($$byval_copy29|0));
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if ($109) {
      label = 10;
      break;
     } else {
      $$5 = 0;
      label = 183;
      break;
     }
    }
    else if ((label|0) == 41) {
     $110 = ___cxa_find_matching_catch()|0;
     $111 = tempRet0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$9+0>>2]|0;
     invoke_viiiiii(97,($96|0),($$byval_copy29|0),0,16,(639432|0),902);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      $613 = ___cxa_find_matching_catch(0|0)|0;
      $614 = tempRet0;
      ___clang_call_terminate($613);
      // unreachable;
     } else {
      $$14 = $110;$$16 = $111;
      break;
     }
    }
   } else {
    label = 46;
   }
  }
 } while(0);
 L51: do {
  if ((label|0) == 46) {
   $version$off = (($version) + -7)|0;
   $119 = ($version$off>>>0)<(7);
   $120 = HEAP32[$iterator>>2]|0;
   if ($119) {
    $121 = (($120) + 4|0);
    HEAP32[$iterator>>2] = $121;
    $123 = $121;
   } else {
    $123 = $120;
   }
   $122 = HEAPU8[$123>>0]|(HEAPU8[$123+1>>0]<<8)|(HEAPU8[$123+2>>0]<<16)|(HEAPU8[$123+3>>0]<<24);
   $124 = (_llvm_bswap_i32(($122|0))|0);
   $125 = (($123) + 4|0);
   HEAP32[$iterator>>2] = $125;
   $126 = (($this) + 32|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = (($this) + 24|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = $127;
   $131 = $129;
   $132 = (($130) - ($131))|0;
   $133 = (($132|0) / 24)&-1;
   $134 = ($133>>>0)<($124>>>0);
   if ($134) {
    $135 = (($this) + 28|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = $136;
    $138 = (($137) - ($131))|0;
    $139 = (($138|0) / 24)&-1;
    $140 = ($122|0)==(0);
    if ($140) {
     $146 = 0;
    } else {
     $141 = ($124*24)|0;
     __THREW__ = 0;
     $142 = (invoke_ii(2988,($141|0))|0);
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if ($144) {
      label = 10;
      break;
     }
     $146 = $142;
    }
    $145 = (($146) + (($139*24)|0)|0);
    $147 = (($146) + (($124*24)|0)|0);
    $148 = (($138|0) / -24)&-1;
    $$sum$i$i$i = (($148) + ($139))|0;
    $149 = (($146) + (($$sum$i$i$i*24)|0)|0);
    _memcpy(($149|0),($129|0),($138|0))|0;
    HEAP32[$128>>2] = $149;
    HEAP32[$135>>2] = $145;
    HEAP32[$126>>2] = $147;
    $150 = ($129|0)==(0|0);
    if (!($150)) {
     __ZdlPv($129);
    }
   }
   $151 = ($124|0)>(0);
   L64: do {
    if ($151) {
     $152 = ($version|0)>(13);
     $153 = $data;
     $154 = (3 - ($153))|0;
     $155 = ($version|0)<(11);
     $156 = (($0) + 8|0);
     $157 = (($0) + 12|0);
     $158 = (($0) + 16|0);
     $159 = (($0) + 20|0);
     $160 = (($0) + 22|0);
     $161 = (($this) + 28|0);
     $162 = (($this) + 24|0);
     $i4$090 = 1;
     while(1) {
      $163 = HEAP32[$iterator>>2]|0;
      if ($152) {
       $164 = $163;
       $165 = (($154) + ($164))|0;
       $166 = $165 & -4;
       $167 = (($data) + ($166)|0);
       $168 = $167;
       $169 = $168;
       $170 = HEAPU8[$169>>0]|(HEAPU8[$169+1>>0]<<8)|(HEAPU8[$169+2>>0]<<16)|(HEAPU8[$169+3>>0]<<24);
       $171 = (($168) + 4)|0;
       $172 = $171;
       $173 = HEAPU8[$172>>0]|(HEAPU8[$172+1>>0]<<8)|(HEAPU8[$172+2>>0]<<16)|(HEAPU8[$172+3>>0]<<24);
       $174 = (_llvm_bswap_i32(($170|0))|0);
       $175 = (_llvm_bswap_i32(($173|0))|0);
       $$sum$i = (($166) + 8)|0;
       $176 = (($data) + ($$sum$i)|0);
       HEAP32[$iterator>>2] = $176;
       $183 = $176;$212 = $175;$215 = $174;
      } else {
       $177 = HEAPU8[$163>>0]|(HEAPU8[$163+1>>0]<<8)|(HEAPU8[$163+2>>0]<<16)|(HEAPU8[$163+3>>0]<<24);
       $178 = (_llvm_bswap_i32(($177|0))|0);
       $179 = (($163) + 4|0);
       HEAP32[$iterator>>2] = $179;
       $180 = ($178|0)<(0);
       $181 = $180 << 31 >> 31;
       $183 = $179;$212 = $178;$215 = $181;
      }
      $182 = HEAPU8[$183>>0]|(HEAPU8[$183+1>>0]<<8)|(HEAPU8[$183+2>>0]<<16)|(HEAPU8[$183+3>>0]<<24);
      $184 = (_llvm_bswap_i32(($182|0))|0);
      $185 = (($183) + 4|0);
      HEAP32[$iterator>>2] = $185;
      $186 = HEAPU8[$185>>0]|(HEAPU8[$185+1>>0]<<8)|(HEAPU8[$185+2>>0]<<16)|(HEAPU8[$185+3>>0]<<24);
      $187 = (_llvm_bswap_i32(($186|0))|0);
      $188 = (($183) + 8|0);
      HEAP32[$iterator>>2] = $188;
      $189 = HEAPU8[$188>>0]|(HEAPU8[$188+1>>0]<<8)|(HEAPU8[$188+2>>0]<<16)|(HEAPU8[$188+3>>0]<<24);
      $190 = (_llvm_bswap_i32(($189|0))|0);
      $191 = (($183) + 12|0);
      HEAP32[$iterator>>2] = $191;
      $192 = HEAPU8[$191>>0]|(HEAPU8[$191+1>>0]<<8);
      $193 = $192&65535;
      $194 = $193 << 8;
      $195 = $193 >>> 8;
      $196 = $194 | $195;
      $197 = $196&65535;
      $198 = (($183) + 14|0);
      HEAP32[$iterator>>2] = $198;
      if ($155) {
       $216 = -1;
      } else {
       $199 = HEAPU8[$198>>0]|(HEAPU8[$198+1>>0]<<8);
       $200 = $199&65535;
       $201 = $200 << 8;
       $202 = $200 >>> 8;
       $203 = $201 | $202;
       $204 = $203&65535;
       $216 = $204;
      }
      $storemerge = (($183) + 16|0);
      HEAP32[$iterator>>2] = $storemerge;
      $205 = (($184) + ($dataOffset))|0;
      $206 = $187 | $205;
      $207 = ($206|0)<(0);
      $208 = (($187) + ($205))|0;
      $209 = ($208|0)>($dataFileEnd|0);
      $or$cond62 = $207 | $209;
      if ($or$cond62) {
       $$5 = 0;
       label = 183;
       break L51;
      }
      $210 = $0;
      $211 = $210;
      HEAP32[$211>>2] = $212;
      $213 = (($210) + 4)|0;
      $214 = $213;
      HEAP32[$214>>2] = $215;
      HEAP32[$156>>2] = $205;
      HEAP32[$157>>2] = $187;
      HEAP32[$158>>2] = $190;
      HEAP16[$159>>1] = $197;
      HEAP16[$160>>1] = $216;
      $217 = HEAP32[$161>>2]|0;
      $218 = HEAP32[$126>>2]|0;
      $219 = ($217|0)==($218|0);
      if ($219) {
       __THREW__ = 0;
       invoke_vii(3224,($162|0),($0|0));
       $223 = __THREW__; __THREW__ = 0;
       $224 = $223&1;
       if ($224) {
        break;
       }
      } else {
       $220 = ($217|0)==(0|0);
       if ($220) {
        $222 = 0;
       } else {
        ;HEAP32[$217+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$217+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$217+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$217+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$217+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$217+20>>2]=HEAP32[$0+20>>2]|0;
        $$pre$i$i = HEAP32[$161>>2]|0;
        $222 = $$pre$i$i;
       }
       $221 = (($222) + 24|0);
       HEAP32[$161>>2] = $221;
      }
      $225 = ($i4$090|0)<($124|0);
      if (!($225)) {
       $$pre$phiZ2D = $161;
       break L64;
      }
      $phitmp = (($i4$090) + 1)|0;
      $i4$090 = $phitmp;
     }
     $24 = ___cxa_find_matching_catch()|0;
     $25 = tempRet0;
     $lpad$phi$index = $24;$lpad$phi$index7 = $25;
     label = 11;
     break L51;
    } else {
     $$pre128 = (($this) + 28|0);
     $$pre$phiZ2D = $$pre128;
    }
   } while(0);
   $226 = HEAP32[$128>>2]|0;
   $227 = HEAP32[$$pre$phiZ2D>>2]|0;
   $228 = ($226|0)==($227|0);
   L87: do {
    if (!($228)) {
     $229 = (($this) + 44|0);
     $230 = HEAP8[$229>>0]|0;
     $231 = ($230<<24>>24)==(0);
     if ($231) {
      $232 = (($this) + 40|0);
      $233 = HEAP32[$232>>2]|0;
      $234 = $233 & 16777216;
      $235 = ($234|0)==(0);
      if ($235) {
       $236 = HEAP8[$unityVersion>>0]|0;
       $237 = $236 & 1;
       $238 = ($237<<24>>24)==(0);
       if ($238) {
        $241 = $236&255;
        $242 = $241 >>> 1;
        $244 = $242;
       } else {
        $239 = (($unityVersion) + 4|0);
        $240 = HEAP32[$239>>2]|0;
        $244 = $240;
       }
       $243 = ($244|0)==(0);
       do {
        if ($243) {
         label = 82;
        } else {
         if ($238) {
          $247 = (($unityVersion) + 1|0);
          $248 = $247;
         } else {
          $245 = (($unityVersion) + 8|0);
          $246 = HEAP32[$245>>2]|0;
          $248 = $246;
         }
         $249 = (_memchr($248,10,$244)|0);
         $250 = ($249|0)==(0|0);
         if ($250) {
          label = 82;
         } else {
          $251 = $249;
          $252 = $248;
          $253 = (($251) - ($252))|0;
          $254 = ($253|0)==(-1);
          if ($254) {
           label = 82;
          } else {
           if ($238) {
            $$sum131 = (($253) + 1)|0;
            $275 = ((($unityVersion) + ($$sum131)|0) + 1|0);
            $276 = (($unityVersion) + 1|0);
            $277 = $236&255;
            $278 = $277 >>> 1;
            $280 = $276;$281 = $278;$283 = $275;
           } else {
            $270 = (($unityVersion) + 8|0);
            $271 = HEAP32[$270>>2]|0;
            $$sum = (($253) + 1)|0;
            $272 = (($271) + ($$sum)|0);
            $273 = (($unityVersion) + 4|0);
            $274 = HEAP32[$273>>2]|0;
            $280 = $271;$281 = $274;$283 = $272;
           }
           $279 = (($280) + ($281)|0);
           $282 = $283;
           $284 = $279;
           $285 = (($284) - ($282))|0;
           $286 = ($285>>>0)>(4294967279);
           if ($286) {
            __THREW__ = 0;
            invoke_vi(3309,0);
            $287 = __THREW__; __THREW__ = 0;
            $288 = $287&1;
            if ($288) {
             label = 10;
             break L51;
            }
            // unreachable;
           }
           $289 = ($285>>>0)<(11);
           if ($289) {
            $290 = $285 << 1;
            $291 = $290&255;
            HEAP8[$10>>0] = $291;
            $292 = (($10) + 1|0);
            $__p$0$ph$i$i$i = $292;
           } else {
            $293 = (($285) + 16)|0;
            $294 = $293 & -16;
            __THREW__ = 0;
            $295 = (invoke_ii(2988,($294|0))|0);
            $296 = __THREW__; __THREW__ = 0;
            $297 = $296&1;
            if ($297) {
             label = 10;
             break L51;
            }
            $298 = (($10) + 8|0);
            HEAP32[$298>>2] = $295;
            $299 = $294 | 1;
            HEAP32[$10>>2] = $299;
            $300 = (($10) + 4|0);
            HEAP32[$300>>2] = $285;
            $__p$0$ph$i$i$i = $295;
           }
           $301 = ($283|0)==($279|0);
           if ($301) {
            $__p$0$lcssa$i$i$i = $__p$0$ph$i$i$i;
           } else {
            $$sum63 = (($281) - ($282))|0;
            $303 = $283;$__p$02$i$i$i = $__p$0$ph$i$i$i;
            while(1) {
             $302 = HEAP8[$303>>0]|0;
             HEAP8[$__p$02$i$i$i>>0] = $302;
             $304 = (($303) + 1|0);
             $305 = (($__p$02$i$i$i) + 1|0);
             $306 = ($304|0)==($279|0);
             if ($306) {
              break;
             } else {
              $303 = $304;$__p$02$i$i$i = $305;
             }
            }
            $scevgep$i$i = (($280) + ($$sum63)|0);
            $scevgep7$i$i = $scevgep$i$i;
            $scevgep8$i$i = (($__p$0$ph$i$i$i) + ($scevgep7$i$i)|0);
            $__p$0$lcssa$i$i$i = $scevgep8$i$i;
           }
           HEAP8[$__p$0$lcssa$i$i$i>>0] = 0;
           $307 = (_strlen((639424|0))|0);
           $308 = HEAP8[$10>>0]|0;
           $309 = $308 & 1;
           $310 = ($309<<24>>24)==(0);
           if ($310) {
            $313 = $308&255;
            $314 = $313 >>> 1;
            $322 = $314;
           } else {
            $311 = (($10) + 4|0);
            $312 = HEAP32[$311>>2]|0;
            $322 = $312;
           }
           $315 = ($307|0)==(-1);
           if ($315) {
            __THREW__ = 0;
            invoke_vi(3304,0);
            $316 = __THREW__; __THREW__ = 0;
            $317 = $316&1;
            if ($317) {
             $328 = ___cxa_find_matching_catch()|0;
             $329 = tempRet0;
             ___cxa_call_unexpected(($328|0));
             // unreachable;
            } else {
             // unreachable;
            }
           }
           if ($310) {
            $320 = (($10) + 1|0);
            $324 = $320;
           } else {
            $318 = (($10) + 8|0);
            $319 = HEAP32[$318>>2]|0;
            $324 = $319;
           }
           $321 = ($322>>>0)>($307>>>0);
           $323 = $321 ? $307 : $322;
           $325 = (_memcmp($324,639424,$323)|0);
           $326 = ($325|0)==(0);
           if ($326) {
            $327 = ($322>>>0)<($307>>>0);
            $$$i$i$i45 = $321&1;
            $$$$i$i$i46 = $327 ? -1 : $$$i$i$i45;
            $331 = $$$$i$i$i46;
           } else {
            $331 = $325;
           }
           $330 = ($331|0)==(0);
           if ($310) {
            if ($330) {
             break L87;
            } else {
             break;
            }
           } else {
            $332 = (($10) + 8|0);
            $333 = HEAP32[$332>>2]|0;
            __ZdlPv($333);
            if ($330) {
             break L87;
            } else {
             break;
            }
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 82) {
        if ($238) {
         $259 = $236&255;
         $260 = $259 >>> 1;
         $261 = (($unityVersion) + 1|0);
         $263 = $260;$265 = $261;
        } else {
         $255 = (($unityVersion) + 4|0);
         $256 = HEAP32[$255>>2]|0;
         $257 = (($unityVersion) + 8|0);
         $258 = HEAP32[$257>>2]|0;
         $263 = $256;$265 = $258;
        }
        $262 = ($263>>>0)>(8);
        $264 = $262 ? 8 : $263;
        $266 = (_memcmp($265,639744,$264)|0);
        $267 = ($266|0)==(0);
        if ($267) {
         $268 = $262 ^ 1;
         $not$ = ($263>>>0)>(7);
         $269 = $not$ & $268;
         if ($269) {
          break;
         }
        }
       }
       $334 = (($this) + 108|0);
       $335 = HEAP32[$334>>2]|0;
       $336 = HEAP32[$335>>2]|0;
       $337 = (($336) + 24|0);
       $338 = HEAP32[$337>>2]|0;
       __THREW__ = 0;
       invoke_vii($338|0,($12|0),($335|0));
       $339 = __THREW__; __THREW__ = 0;
       $340 = $339&1;
       if ($340) {
        label = 10;
        break L51;
       }
       $341 = HEAP8[$12>>0]|0;
       $342 = $341 & 1;
       $343 = ($342<<24>>24)==(0);
       if ($343) {
        $346 = (($12) + 1|0);
        $353 = $346;
       } else {
        $344 = (($12) + 8|0);
        $345 = HEAP32[$344>>2]|0;
        $353 = $345;
       }
       $347 = HEAP8[$unityVersion>>0]|0;
       $348 = $347 & 1;
       $349 = ($348<<24>>24)==(0);
       if ($349) {
        $352 = (($unityVersion) + 1|0);
        $354 = $352;
       } else {
        $350 = (($unityVersion) + 8|0);
        $351 = HEAP32[$350>>2]|0;
        $354 = $351;
       }
       __THREW__ = 0;
       HEAP32[$$byval_copy29>>2] = $353;
       $vararg_ptr19 = (($$byval_copy29) + 4|0);
       HEAP32[$vararg_ptr19>>2] = $354;
       invoke_viii(1617,($11|0),(639760|0),($$byval_copy29|0));
       $355 = __THREW__; __THREW__ = 0;
       $356 = $355&1;
       do {
        if ($356) {
         $376 = ___cxa_find_matching_catch()|0;
         $377 = tempRet0;
         $$03 = $376;$$05 = $377;
        } else {
         $357 = HEAP8[$11>>0]|0;
         $358 = $357 & 1;
         $359 = ($358<<24>>24)==(0);
         if ($359) {
          $362 = (($11) + 1|0);
          $363 = $362;
         } else {
          $360 = (($11) + 8|0);
          $361 = HEAP32[$360>>2]|0;
          $363 = $361;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,($363|0),0,(639432|0),989,1,0,0,(0|0));
         $364 = __THREW__; __THREW__ = 0;
         $365 = $364&1;
         if ($365) {
          $378 = ___cxa_find_matching_catch()|0;
          $379 = tempRet0;
          $380 = HEAP8[$11>>0]|0;
          $381 = $380 & 1;
          $382 = ($381<<24>>24)==(0);
          if ($382) {
           $$03 = $378;$$05 = $379;
           break;
          }
          $383 = (($11) + 8|0);
          $384 = HEAP32[$383>>2]|0;
          __ZdlPv($384);
          $$03 = $378;$$05 = $379;
          break;
         }
         $366 = HEAP8[$11>>0]|0;
         $367 = $366 & 1;
         $368 = ($367<<24>>24)==(0);
         if (!($368)) {
          $369 = (($11) + 8|0);
          $370 = HEAP32[$369>>2]|0;
          __ZdlPv($370);
         }
         $371 = HEAP8[$12>>0]|0;
         $372 = $371 & 1;
         $373 = ($372<<24>>24)==(0);
         if ($373) {
          $$5 = 0;
          label = 183;
          break L51;
         }
         $374 = (($12) + 8|0);
         $375 = HEAP32[$374>>2]|0;
         __ZdlPv($375);
         $$5 = 0;
         label = 183;
         break L51;
        }
       } while(0);
       $385 = HEAP8[$12>>0]|0;
       $386 = $385 & 1;
       $387 = ($386<<24>>24)==(0);
       if ($387) {
        $$14 = $$03;$$16 = $$05;
        break L51;
       }
       $388 = (($12) + 8|0);
       $389 = HEAP32[$388>>2]|0;
       __ZdlPv($389);
       $$14 = $$03;$$16 = $$05;
       break L51;
      }
     }
    }
   } while(0);
   $390 = ($version|0)>(10);
   if ($390) {
    $391 = HEAP32[$iterator>>2]|0;
    $392 = HEAPU8[$391>>0]|(HEAPU8[$391+1>>0]<<8)|(HEAPU8[$391+2>>0]<<16)|(HEAPU8[$391+3>>0]<<24);
    $393 = (_llvm_bswap_i32(($392|0))|0);
    $394 = (($391) + 4|0);
    HEAP32[$iterator>>2] = $394;
    $395 = (($this) + 64|0);
    $396 = (($this) + 72|0);
    HEAP32[$396>>2] = $393;
    $397 = (($this) + 76|0);
    $398 = HEAP32[$397>>2]|0;
    $399 = $398 & 2147483647;
    $400 = ($399>>>0)<($393>>>0);
    do {
     if ($400) {
      $401 = ($398|0)>(-1);
      if ($401) {
       HEAP32[$397>>2] = $393;
       $402 = HEAP32[$395>>2]|0;
       $403 = $393 << 4;
       $404 = (($this) + 68|0);
       $405 = HEAP32[$404>>2]|0;
       HEAP32[$1>>2] = $405;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$1+0>>2]|0;
       $406 = (invoke_iiiiiiii(108,($402|0),($403|0),8,($$byval_copy29|0),0,(639432|0),370)|0);
       $407 = __THREW__; __THREW__ = 0;
       $408 = $407&1;
       if ($408) {
        label = 10;
        break L51;
       }
       HEAP32[$395>>2] = $406;
       break;
      } else {
       $409 = $393 << 4;
       $410 = (($this) + 68|0);
       $411 = HEAP32[$410>>2]|0;
       HEAP32[$2>>2] = $411;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$2+0>>2]|0;
       $412 = (invoke_iiiiiii(102,($409|0),8,($$byval_copy29|0),0,(639432|0),352)|0);
       $413 = __THREW__; __THREW__ = 0;
       $414 = $413&1;
       if ($414) {
        label = 10;
        break L51;
       }
       $415 = HEAP32[$395>>2]|0;
       $416 = HEAP32[$396>>2]|0;
       $417 = $416 << 4;
       _memcpy(($412|0),($415|0),($417|0))|0;
       HEAP32[$397>>2] = $393;
       HEAP32[$395>>2] = $412;
       break;
      }
     }
    } while(0);
    $418 = ($393|0)>(0);
    if ($418) {
     $419 = ($version|0)>(13);
     $420 = $data;
     $421 = (3 - ($420))|0;
     $$pre = HEAP32[$395>>2]|0;
     $$pre115 = HEAP32[$iterator>>2]|0;
     $424 = $$pre115;$i5$084 = 0;
     while(1) {
      $422 = (($$pre) + ($i5$084<<4)|0);
      $423 = HEAPU8[$424>>0]|(HEAPU8[$424+1>>0]<<8)|(HEAPU8[$424+2>>0]<<16)|(HEAPU8[$424+3>>0]<<24);
      $425 = (_llvm_bswap_i32(($423|0))|0);
      HEAP32[$422>>2] = $425;
      $426 = (($424) + 4|0);
      HEAP32[$iterator>>2] = $426;
      if ($419) {
       $427 = $426;
       $428 = (($421) + ($427))|0;
       $429 = $428 & -4;
       $430 = (($data) + ($429)|0);
       $431 = $430;
       $432 = $431;
       $433 = HEAPU8[$432>>0]|(HEAPU8[$432+1>>0]<<8)|(HEAPU8[$432+2>>0]<<16)|(HEAPU8[$432+3>>0]<<24);
       $434 = (($431) + 4)|0;
       $435 = $434;
       $436 = HEAPU8[$435>>0]|(HEAPU8[$435+1>>0]<<8)|(HEAPU8[$435+2>>0]<<16)|(HEAPU8[$435+3>>0]<<24);
       $437 = (_llvm_bswap_i32(($433|0))|0);
       $438 = (_llvm_bswap_i32(($436|0))|0);
       $$sum$i25 = (($429) + 8)|0;
       $439 = (($data) + ($$sum$i25)|0);
       HEAP32[$iterator>>2] = $439;
       $448 = $438;$451 = $437;$615 = $439;
      } else {
       $440 = HEAPU8[$426>>0]|(HEAPU8[$426+1>>0]<<8)|(HEAPU8[$426+2>>0]<<16)|(HEAPU8[$426+3>>0]<<24);
       $441 = (_llvm_bswap_i32(($440|0))|0);
       $442 = (($424) + 8|0);
       HEAP32[$iterator>>2] = $442;
       $443 = ($441|0)<(0);
       $444 = $443 << 31 >> 31;
       $448 = $441;$451 = $444;$615 = $442;
      }
      $445 = ((($$pre) + ($i5$084<<4)|0) + 8|0);
      $446 = $445;
      $447 = $446;
      HEAP32[$447>>2] = $448;
      $449 = (($446) + 4)|0;
      $450 = $449;
      HEAP32[$450>>2] = $451;
      $452 = (($i5$084) + 1)|0;
      $exitcond = ($452|0)==($393|0);
      if ($exitcond) {
       break;
      } else {
       $424 = $615;$i5$084 = $452;
      }
     }
    }
   }
   $453 = HEAP32[$iterator>>2]|0;
   $454 = HEAPU8[$453>>0]|(HEAPU8[$453+1>>0]<<8)|(HEAPU8[$453+2>>0]<<16)|(HEAPU8[$453+3>>0]<<24);
   $455 = (_llvm_bswap_i32(($454|0))|0);
   $456 = (($453) + 4|0);
   HEAP32[$iterator>>2] = $456;
   $457 = (($this) + 80|0);
   $458 = (($this) + 84|0);
   $459 = HEAP32[$458>>2]|0;
   $460 = ($459>>>0)<($455>>>0);
   L195: do {
    if ($460) {
     while(1) {
      __THREW__ = 0;
      invoke_vi(3570,($457|0));
      $463 = __THREW__; __THREW__ = 0;
      $464 = $463&1;
      if ($464) {
       break;
      }
      $465 = HEAP32[$458>>2]|0;
      $466 = ($465>>>0)<($455>>>0);
      if (!($466)) {
       $462 = $465;
       break L195;
      }
     }
     $22 = ___cxa_find_matching_catch()|0;
     $23 = tempRet0;
     $lpad$phi$index = $22;$lpad$phi$index7 = $23;
     label = 11;
     break L51;
    } else {
     $462 = $459;
    }
   } while(0);
   $461 = ($462>>>0)>($455>>>0);
   L201: do {
    if ($461) {
     while(1) {
      __THREW__ = 0;
      invoke_vi(3571,($457|0));
      $467 = __THREW__; __THREW__ = 0;
      $468 = $467&1;
      if ($468) {
       break;
      }
      $469 = HEAP32[$458>>2]|0;
      $470 = ($469>>>0)>($455>>>0);
      if (!($470)) {
       break L201;
      }
     }
     $20 = ___cxa_find_matching_catch()|0;
     $21 = tempRet0;
     $lpad$phi$index = $20;$lpad$phi$index7 = $21;
     label = 11;
     break L51;
    }
   } while(0);
   $471 = ($455|0)>(0);
   $472 = ($version|0)>(4);
   L207: do {
    if ($471) {
     $473 = ($version|0)>(5);
     $474 = (($tempEmpty) + 8|0);
     $475 = (($this) + 92|0);
     $i6$075 = 0;
     while(1) {
      if ($472) {
       if ($473) {
        ;HEAP32[$tempEmpty+0>>2]=0|0;HEAP32[$tempEmpty+4>>2]=0|0;HEAP32[$tempEmpty+8>>2]=0|0;
        __THREW__ = 0;
        $476 = (invoke_iiii(1562,($tempEmpty|0),($iterator|0),($13|0))|0);
        $477 = __THREW__; __THREW__ = 0;
        $478 = $477&1;
        if ($478) {
         label = 164;
         break;
        }
        $479 = HEAP8[$tempEmpty>>0]|0;
        $480 = $479 & 1;
        $481 = ($480<<24>>24)==(0);
        if (!($481)) {
         $482 = HEAP32[$474>>2]|0;
         HEAP32[$3>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$3+0>>2]|0;
         invoke_vii(2591,($482|0),($$byval_copy29|0));
         $483 = __THREW__; __THREW__ = 0;
         $484 = $483&1;
         if ($484) {
          label = 163;
          break;
         }
        }
        if (!($476)) {
         $$5 = 0;
         label = 183;
         break L51;
        }
       }
       $497 = HEAP32[$457>>2]|0;
       $498 = (($i6$075>>>0) / ($497>>>0))&-1;
       $499 = HEAP32[$475>>2]|0;
       $500 = (($499) + ($498<<2)|0);
       $501 = HEAP32[$500>>2]|0;
       $502 = (($i6$075>>>0) % ($497>>>0))&-1;
       $503 = HEAP32[$501>>2]|0;
       $504 = ((($503) + ($502<<5)|0) + 16|0);
       $505 = HEAP32[$iterator>>2]|0;
       $506 = HEAPU8[$505>>0]|(HEAPU8[$505+1>>0]<<8)|(HEAPU8[$505+2>>0]<<16)|(HEAPU8[$505+3>>0]<<24);
       $507 = (_llvm_bswap_i32(($506|0))|0);
       HEAP32[$504>>2] = $507;
       $508 = (($505) + 4|0);
       HEAP32[$iterator>>2] = $508;
       $509 = HEAP32[$457>>2]|0;
       $510 = (($i6$075>>>0) / ($509>>>0))&-1;
       $511 = (($499) + ($510<<2)|0);
       $512 = HEAP32[$511>>2]|0;
       $513 = (($i6$075>>>0) % ($509>>>0))&-1;
       $514 = HEAP32[$512>>2]|0;
       $515 = ((($514) + ($513<<5)|0) + 20|0);
       $516 = HEAPU8[$508>>0]|(HEAPU8[$508+1>>0]<<8)|(HEAPU8[$508+2>>0]<<16)|(HEAPU8[$508+3>>0]<<24);
       $517 = (_llvm_bswap_i32(($516|0))|0);
       HEAP32[$515>>2] = $517;
       $518 = (($505) + 8|0);
       HEAP32[$iterator>>2] = $518;
       $519 = HEAP32[$457>>2]|0;
       $520 = (($i6$075>>>0) / ($519>>>0))&-1;
       $521 = (($499) + ($520<<2)|0);
       $522 = HEAP32[$521>>2]|0;
       $523 = (($i6$075>>>0) % ($519>>>0))&-1;
       $524 = HEAP32[$522>>2]|0;
       $525 = ((($524) + ($523<<5)|0) + 24|0);
       $526 = HEAPU8[$518>>0]|(HEAPU8[$518+1>>0]<<8)|(HEAPU8[$518+2>>0]<<16)|(HEAPU8[$518+3>>0]<<24);
       $527 = (_llvm_bswap_i32(($526|0))|0);
       HEAP32[$525>>2] = $527;
       $528 = (($505) + 12|0);
       HEAP32[$iterator>>2] = $528;
       $529 = HEAP32[$457>>2]|0;
       $530 = (($i6$075>>>0) / ($529>>>0))&-1;
       $531 = (($499) + ($530<<2)|0);
       $532 = HEAP32[$531>>2]|0;
       $533 = (($i6$075>>>0) % ($529>>>0))&-1;
       $534 = HEAP32[$532>>2]|0;
       $535 = ((($534) + ($533<<5)|0) + 28|0);
       $536 = HEAPU8[$528>>0]|(HEAPU8[$528+1>>0]<<8)|(HEAPU8[$528+2>>0]<<16)|(HEAPU8[$528+3>>0]<<24);
       $537 = (_llvm_bswap_i32(($536|0))|0);
       HEAP32[$535>>2] = $537;
       $538 = (($505) + 16|0);
       HEAP32[$iterator>>2] = $538;
       $539 = HEAP32[$457>>2]|0;
       $540 = (($i6$075>>>0) / ($539>>>0))&-1;
       $541 = (($499) + ($540<<2)|0);
       $542 = HEAP32[$541>>2]|0;
       $543 = (($i6$075>>>0) % ($539>>>0))&-1;
       $544 = HEAP32[$542>>2]|0;
       $545 = ((($544) + ($543<<5)|0) + 12|0);
       $546 = HEAPU8[$538>>0]|(HEAPU8[$538+1>>0]<<8)|(HEAPU8[$538+2>>0]<<16)|(HEAPU8[$538+3>>0]<<24);
       $547 = (_llvm_bswap_i32(($546|0))|0);
       HEAP32[$545>>2] = $547;
       $548 = (($505) + 20|0);
       HEAP32[$iterator>>2] = $548;
       $549 = HEAP32[$457>>2]|0;
       $550 = (($i6$075>>>0) / ($549>>>0))&-1;
       $551 = (($499) + ($550<<2)|0);
       $552 = HEAP32[$551>>2]|0;
       $553 = (($i6$075>>>0) % ($549>>>0))&-1;
       $554 = HEAP32[$552>>2]|0;
       $555 = (($554) + ($553<<5)|0);
       __THREW__ = 0;
       $556 = (invoke_iiii(1562,($555|0),($iterator|0),($13|0))|0);
       $557 = __THREW__; __THREW__ = 0;
       $558 = $557&1;
       if ($558) {
        label = 4;
        break;
       }
       if (!($556)) {
        $$5 = 0;
        label = 183;
        break L51;
       }
      } else {
       $559 = HEAP32[$457>>2]|0;
       $560 = (($i6$075>>>0) / ($559>>>0))&-1;
       $561 = HEAP32[$475>>2]|0;
       $562 = (($561) + ($560<<2)|0);
       $563 = HEAP32[$562>>2]|0;
       $564 = (($i6$075>>>0) % ($559>>>0))&-1;
       $565 = HEAP32[$563>>2]|0;
       $566 = (($565) + ($564<<5)|0);
       __THREW__ = 0;
       $567 = (invoke_iiii(1562,($566|0),($iterator|0),($13|0))|0);
       $568 = __THREW__; __THREW__ = 0;
       $569 = $568&1;
       if ($569) {
        label = 4;
        break;
       }
       if (!($567)) {
        $$5 = 0;
        label = 183;
        break L51;
       }
      }
      $570 = (($i6$075) + 1)|0;
      $571 = ($570|0)<($455|0);
      if ($571) {
       $i6$075 = $570;
      } else {
       break L207;
      }
     }
     if ((label|0) == 4) {
      $18 = ___cxa_find_matching_catch()|0;
      $19 = tempRet0;
      $lpad$phi$index = $18;$lpad$phi$index7 = $19;
      label = 11;
      break L51;
     }
     else if ((label|0) == 163) {
      $485 = ___cxa_find_matching_catch()|0;
      $486 = tempRet0;
      ___cxa_call_unexpected(($485|0));
      // unreachable;
     }
     else if ((label|0) == 164) {
      $487 = ___cxa_find_matching_catch()|0;
      $488 = tempRet0;
      $489 = HEAP8[$tempEmpty>>0]|0;
      $490 = $489 & 1;
      $491 = ($490<<24>>24)==(0);
      if ($491) {
       $$14 = $487;$$16 = $488;
       break L51;
      }
      $492 = HEAP32[$474>>2]|0;
      HEAP32[$4>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($492|0),($$byval_copy29|0));
      $493 = __THREW__; __THREW__ = 0;
      $494 = $493&1;
      if (!($494)) {
       $$14 = $487;$$16 = $488;
       break L51;
      }
      $495 = ___cxa_find_matching_catch()|0;
      $496 = tempRet0;
      ___cxa_call_unexpected(($495|0));
      // unreachable;
     }
    }
   } while(0);
   if ($472) {
    ;HEAP32[$userInformation+0>>2]=0|0;HEAP32[$userInformation+4>>2]=0|0;HEAP32[$userInformation+8>>2]=0|0;
    __THREW__ = 0;
    $572 = (invoke_iiii(1562,($userInformation|0),($iterator|0),($13|0))|0);
    $573 = __THREW__; __THREW__ = 0;
    $574 = $573&1;
    if ($574) {
     $584 = ___cxa_find_matching_catch()|0;
     $585 = tempRet0;
     $586 = HEAP8[$userInformation>>0]|0;
     $587 = $586 & 1;
     $588 = ($587<<24>>24)==(0);
     if ($588) {
      $$14 = $584;$$16 = $585;
      break;
     }
     $589 = (($userInformation) + 8|0);
     $590 = HEAP32[$589>>2]|0;
     HEAP32[$6>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($590|0),($$byval_copy29|0));
     $591 = __THREW__; __THREW__ = 0;
     $592 = $591&1;
     if (!($592)) {
      $$14 = $584;$$16 = $585;
      break;
     }
     $593 = ___cxa_find_matching_catch()|0;
     $594 = tempRet0;
     ___cxa_call_unexpected(($593|0));
     // unreachable;
    }
    $575 = HEAP8[$userInformation>>0]|0;
    $576 = $575 & 1;
    $577 = ($576<<24>>24)==(0);
    if (!($577)) {
     $578 = (($userInformation) + 8|0);
     $579 = HEAP32[$578>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($579|0),($$byval_copy29|0));
     $580 = __THREW__; __THREW__ = 0;
     $581 = $580&1;
     if ($581) {
      $582 = ___cxa_find_matching_catch()|0;
      $583 = tempRet0;
      ___cxa_call_unexpected(($582|0));
      // unreachable;
     }
    }
    if (!($572)) {
     $$5 = 0;
     label = 183;
     break;
    }
   }
   $$5 = 1;
   label = 183;
  }
 } while(0);
 if ((label|0) == 10) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $lpad$phi$index = $30;$lpad$phi$index7 = $31;
  label = 11;
 }
 else if ((label|0) == 183) {
  $595 = HEAP8[$unityVersion>>0]|0;
  $596 = $595 & 1;
  $597 = ($596<<24>>24)==(0);
  if ($597) {
   STACKTOP = sp;return ($$5|0);
  }
  $598 = (($unityVersion) + 8|0);
  $599 = HEAP32[$598>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($599|0),($$byval_copy29|0));
  $600 = __THREW__; __THREW__ = 0;
  $601 = $600&1;
  if ($601) {
   $602 = ___cxa_find_matching_catch()|0;
   $603 = tempRet0;
   ___cxa_call_unexpected(($602|0));
   // unreachable;
  } else {
   STACKTOP = sp;return ($$5|0);
  }
 }
 if ((label|0) == 11) {
  $$14 = $lpad$phi$index;$$16 = $lpad$phi$index7;
 }
 $604 = HEAP8[$unityVersion>>0]|0;
 $605 = $604 & 1;
 $606 = ($605<<24>>24)==(0);
 if ($606) {
  ___resumeException($$14|0);
  // unreachable;
 }
 $607 = (($unityVersion) + 8|0);
 $608 = HEAP32[$607>>2]|0;
 HEAP32[$7>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy29+0>>2]=HEAP32[$7+0>>2]|0;
 invoke_vii(2591,($608|0),($$byval_copy29|0));
 $609 = __THREW__; __THREW__ = 0;
 $610 = $609&1;
 if ($610) {
  $611 = ___cxa_find_matching_catch()|0;
  $612 = tempRet0;
  ___cxa_call_unexpected(($611|0));
  // unreachable;
 } else {
  ___resumeException($$14|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN14SerializedFile29ExtractLegacyScriptReferencesEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy1 = 0, $$neg2$i$i$i$i$i$i = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre7$i = 0, $$sum$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__len$0$be$i$i$i$i$i$i = 0, $__len$03$i$i$i$i$i$i = 0, $brmerge$i = 0, $notlhs$i = 0, $notlhs8$i = 0, $notrhs$i = 0, $notrhs9$i = 0, $offset$03$i = 0, $offset$1$i = 0, $or$cond$i$not$i = 0, $or$cond5$i$not$i = 0, $serializedData$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $serializedData$i = sp + 24|0;
 $1 = sp + 16|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 4|0);
 $8 = (($this) + 4|0);
 $9 = (($this) + 72|0);
 $10 = (($this) + 76|0);
 $11 = (($this) + 64|0);
 $12 = (($this) + 68|0);
 $13 = (($1) + 4|0);
 $14 = (($this) + 12|0);
 $15 = (($this) + 108|0);
 $16 = (($this) + 36|0);
 $17 = HEAP32[580528>>2]|0;
 $18 = HEAP32[580536>>2]|0;
 $notlhs8$i = ($17>>>0)>(640152>>>0);
 $notrhs9$i = ($18>>>0)<=(640152>>>0);
 $or$cond5$i$not$i = $notrhs9$i | $notlhs8$i;
 $$phi$trans$insert$i = (($serializedData$i) + 4|0);
 $20 = $3;$31 = $5;
 L4: while(1) {
  $19 = (($20) + 20|0);
  $21 = HEAP16[$19>>1]|0;
  $22 = ($21<<16>>16)==(114);
  if ($22) {
   $23 = $20;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + 4)|0;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = HEAP32[$2>>2]|0;
   $30 = ($31|0)==($29|0);
   if ($30) {
    label = 20;
    break;
   }
   $32 = $29;
   $33 = $31;
   $34 = (($33) - ($32))|0;
   $35 = (($34|0) / 24)&-1;
   $38 = $29;$__len$03$i$i$i$i$i$i = $35;
   while(1) {
    $36 = (($__len$03$i$i$i$i$i$i|0) / 2)&-1;
    $37 = (($38) + (($36*24)|0)|0);
    $39 = $37;
    $40 = $39;
    $41 = HEAP32[$40>>2]|0;
    $42 = (($39) + 4)|0;
    $43 = $42;
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)<($28|0);
    $46 = ($44|0)==($28|0);
    $47 = ($41>>>0)<($25>>>0);
    $48 = $46 & $47;
    $49 = $45 | $48;
    if ($49) {
     $$sum$i$i$i$i$i$i = (($36) + 1)|0;
     $50 = (($38) + (($$sum$i$i$i$i$i$i*24)|0)|0);
     $$neg2$i$i$i$i$i$i = (($__len$03$i$i$i$i$i$i) + -1)|0;
     $51 = (($$neg2$i$i$i$i$i$i) - ($36))|0;
     $54 = $50;$__len$0$be$i$i$i$i$i$i = $51;
    } else {
     $54 = $38;$__len$0$be$i$i$i$i$i$i = $36;
    }
    $52 = ($__len$0$be$i$i$i$i$i$i|0)==(0);
    if ($52) {
     break;
    } else {
     $38 = $54;$__len$03$i$i$i$i$i$i = $__len$0$be$i$i$i$i$i$i;
    }
   }
   $53 = ($54|0)==($31|0);
   if ($53) {
    label = 20;
    break;
   }
   $55 = $54;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = (($55) + 4)|0;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)>($28|0);
   $62 = ($60|0)==($28|0);
   $63 = ($57>>>0)>($25>>>0);
   $64 = $62 & $63;
   $65 = $61 | $64;
   $$$i = $65 ? $31 : $54;
   $66 = ($$$i|0)==($31|0);
   if ($66) {
    label = 20;
    break;
   }
   $67 = HEAP32[$7>>2]|0;
   $68 = ($67|0)==(0|0);
   if ($68) {
    label = 20;
    break;
   }
   $69 = (($$$i) + 16|0);
   $70 = HEAP32[$69>>2]|0;
   $$0$ph7$i$i$i$i = $8;$$01$ph6$i$in$i$i$i = $67;
   L18: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $71 = (($$013$i$in$i$i$i) + 16|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)<($70|0);
     if (!($73)) {
      break;
     }
     $76 = (($$013$i$in$i$i$i) + 4|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L18;
     } else {
      $$013$i$in$i$i$i = $77;
     }
    }
    $74 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $75 = ($74|0)==(0|0);
    if ($75) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $74;
    }
   }
   $79 = ($$0$ph5$i$i$i$i|0)==($8|0);
   if ($79) {
    label = 20;
    break;
   }
   $80 = (($$0$ph5$i$i$i$i) + 16|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = ($70|0)<($81|0);
   if ($82) {
    label = 20;
    break;
   }
   $83 = (($$0$ph5$i$i$i$i) + 60|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    label = 20;
    break;
   }
   $86 = HEAP32[$9>>2]|0;
   $87 = $86&65535;
   $88 = (($20) + 22|0);
   HEAP16[$88>>1] = $87;
   $89 = (($86) + 1)|0;
   HEAP32[$9>>2] = $89;
   $90 = HEAP32[$10>>2]|0;
   $91 = $90 & 2147483647;
   $92 = ($89>>>0)>($91>>>0);
   do {
    if ($92) {
     $93 = $90 << 1;
     $94 = ($93|0)==(0);
     $95 = $94 ? 1 : $93;
     $96 = ($91>>>0)<($95>>>0);
     if ($96) {
      $97 = ($90|0)>(-1);
      if ($97) {
       HEAP32[$10>>2] = $95;
       $98 = HEAP32[$11>>2]|0;
       $99 = $95 << 4;
       $100 = HEAP32[$12>>2]|0;
       HEAP32[$0>>2] = $100;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       $101 = (__Z16realloc_internalPvji10MemLabelIdiPKci($98,$99,8,$$byval_copy1,0,639432,370)|0);
       HEAP32[$11>>2] = $101;
       break;
      } else {
       $102 = $95 << 4;
       $103 = HEAP32[$12>>2]|0;
       HEAP32[$0>>2] = $103;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       $104 = (__Z15malloc_internaljj10MemLabelIdiPKci($102,8,$$byval_copy1,0,639432,352)|0);
       $105 = HEAP32[$11>>2]|0;
       $106 = HEAP32[$9>>2]|0;
       $107 = $106 << 4;
       _memcpy(($104|0),($105|0),($107|0))|0;
       HEAP32[$10>>2] = $95;
       HEAP32[$11>>2] = $104;
       break;
      }
     }
    }
   } while(0);
   HEAP32[$1>>2] = $84;
   HEAP32[$13>>2] = 0;
   $108 = (($20) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = HEAP32[$14>>2]|0;
   $111 = (($110) + ($109))|0;
   $112 = HEAP32[$15>>2]|0;
   $113 = HEAP8[$16>>0]|0;
   $114 = ($113<<24>>24)==(0);
   $115 = HEAP32[$9>>2]|0;
   $116 = (($115) + -1)|0;
   $117 = HEAP32[$11>>2]|0;
   __ZNK16TypeTreeIterator8ChildrenEv($$byval_copy1,$1);
   $118 = HEAP32[$$byval_copy1>>2]|0;
   $119 = ($118|0)==(0|0);
   if ($119) {
    label = 39;
    break;
   } else {
    $offset$03$i = 0;
   }
   L35: while(1) {
    $120 = (__ZNK16TypeTreeIterator7GetNodeEv($$byval_copy1)|0);
    $121 = (($120) + 12|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = ($122|0)==(-1);
    if ($123) {
     label = 39;
     break L4;
    }
    $124 = (__ZNK16TypeTreeIterator4NameEv($$byval_copy1)|0);
    $125 = ($124|0)==(0|0);
    do {
     if (!($125)) {
      $notlhs$i = ($17>>>0)>($124>>>0);
      $notrhs$i = ($18>>>0)<=($124>>>0);
      $or$cond$i$not$i = $notrhs$i | $notlhs$i;
      $brmerge$i = $or$cond$i$not$i | $or$cond5$i$not$i;
      if ($brmerge$i) {
       $127 = (_strcmp(640152,$124)|0);
       $128 = ($127|0)==(0);
       if ($128) {
        break L35;
       } else {
        break;
       }
      } else {
       $126 = ($124|0)==(640152|0);
       if ($126) {
        break L35;
       } else {
        break;
       }
      }
     }
    } while(0);
    $129 = (__ZNK16TypeTreeIterator7GetNodeEv($$byval_copy1)|0);
    $130 = (($129) + 12|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($131) + ($offset$03$i))|0;
    $133 = (__ZNK16TypeTreeIterator7GetNodeEv($$byval_copy1)|0);
    $134 = (($133) + 20|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = $135 & 16384;
    $137 = ($136|0)==(0);
    if ($137) {
     $offset$1$i = $132;
    } else {
     $138 = (($132) + 3)|0;
     $139 = $138 & -4;
     $offset$1$i = $139;
    }
    __ZNK16TypeTreeIterator4NextEv($0,$$byval_copy1);
    $140 = $0;
    $141 = $140;
    $142 = HEAP32[$141>>2]|0;
    $143 = (($140) + 4)|0;
    $144 = $143;
    $145 = HEAP32[$144>>2]|0;
    $146 = $$byval_copy1;
    $147 = $146;
    HEAP32[$147>>2] = $142;
    $148 = (($146) + 4)|0;
    $149 = $148;
    HEAP32[$149>>2] = $145;
    $150 = ($142|0)==(0);
    if ($150) {
     label = 39;
     break L4;
    } else {
     $offset$03$i = $offset$1$i;
    }
   }
   $151 = (($111) + ($offset$03$i))|0;
   __Z13ReadFileCacheR15CacheReaderBasePvjj($112,$serializedData$i,$151,8);
   $152 = HEAP32[$serializedData$i>>2]|0;
   if ($114) {
    $$pre7$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $157 = $152;$159 = $$pre7$i;
   } else {
    $153 = (_llvm_bswap_i32(($152|0))|0);
    HEAP32[$serializedData$i>>2] = $153;
    $154 = HEAP32[$$phi$trans$insert$i>>2]|0;
    $155 = (_llvm_bswap_i32(($154|0))|0);
    HEAP32[$$phi$trans$insert$i>>2] = $155;
    $157 = $153;$159 = $155;
   }
   $156 = (($117) + ($116<<4)|0);
   HEAP32[$156>>2] = $157;
   $158 = ($159|0)<(0);
   $160 = $158 << 31 >> 31;
   $161 = ((($117) + ($116<<4)|0) + 8|0);
   $162 = $161;
   $163 = $162;
   HEAP32[$163>>2] = $159;
   $164 = (($162) + 4)|0;
   $165 = $164;
   HEAP32[$165>>2] = $160;
   $$pre = HEAP32[$4>>2]|0;
   $168 = $$pre;
  } else {
   $168 = $31;
  }
  $166 = (($20) + 24|0);
  $167 = ($166|0)==($168|0);
  if ($167) {
   $$0 = 1;
   label = 41;
   break;
  } else {
   $20 = $166;$31 = $168;
  }
 }
 if ((label|0) == 20) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(639440,0,639432,1261,1,0,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 39) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(639440,0,639432,1269,1,0,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 41) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN14SerializedFile27PatchRemapDeprecatedClassesEv($this) {
 $this = $this|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 64|0);
 $6 = (($this) + 80|0);
 $7 = (($this) + 92|0);
 $9 = $1;
 while(1) {
  $8 = (($9) + 20|0);
  $10 = HEAP16[$8>>1]|0;
  $11 = ($10<<16>>16)==(114);
  if ($11) {
   $13 = (($9) + 22|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = ($14<<16>>16)==(-1);
   if (!($15)) {
    $16 = $14 << 16 >> 16;
    $17 = HEAP32[$5>>2]|0;
    $18 = (($17) + ($16<<4)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<(1);
    if (!($20)) {
     $21 = ((($17) + ($16<<4)|0) + 8|0);
     $22 = $21;
     $23 = $22;
     $24 = HEAP32[$23>>2]|0;
     $25 = (($22) + 4)|0;
     $26 = $25;
     $27 = HEAP32[$26>>2]|0;
     $28 = (($19) + -1)|0;
     $29 = HEAP32[$6>>2]|0;
     $30 = (($28>>>0) / ($29>>>0))&-1;
     $31 = HEAP32[$7>>2]|0;
     $32 = (($31) + ($30<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($28>>>0) % ($29>>>0))&-1;
     $35 = HEAP32[$33>>2]|0;
     $36 = (($35) + ($34<<5)|0);
     $37 = HEAP8[$36>>0]|0;
     $38 = $37 & 1;
     $39 = ($38<<24>>24)==(0);
     if ($39) {
      $42 = (($36) + 1|0);
      $43 = $42;
     } else {
      $40 = ((($35) + ($34<<5)|0) + 8|0);
      $41 = HEAP32[$40>>2]|0;
      $43 = $41;
     }
     $44 = (__Z6StrCmpPKcS0_($43,639472)|0);
     $45 = ($44|0)==(0);
     $46 = ($24|0)==(12000);
     $47 = ($27|0)==(0);
     $48 = $46 & $47;
     if ($48) {
      $49 = ((($35) + ($34<<5)|0) + 16|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50|0)==(0);
      if ($51) {
       $52 = ((($35) + ($34<<5)|0) + 20|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($53|0)==(0);
       if ($54) {
        $55 = ((($35) + ($34<<5)|0) + 24|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = ($56|0)==(14);
        if ($57) {
         $58 = ((($35) + ($34<<5)|0) + 28|0);
         $59 = HEAP32[$58>>2]|0;
         $60 = ($59|0)==(0);
         $61 = $60;
        } else {
         $61 = 0;
        }
       } else {
        $61 = 0;
       }
      } else {
       $61 = 0;
      }
      $brmerge$i = $61 | $45;
      if ($brmerge$i) {
       HEAP16[$8>>1] = 218;
       HEAP16[$13>>1] = -1;
      }
     }
    }
   }
  } else {
   $12 = $10 << 16 >> 16;
   if ((($12|0) == 243)) {
    $$0$i1 = 273;
   } else if ((($12|0) == 1012)) {
    $$0$i1 = 1011;
   } else if ((($12|0) == 245)) {
    $$0$i1 = 272;
   } else if ((($12|0) == 241)) {
    $$0$i1 = 240;
   } else {
    $$0$i1 = $10;
   }
   HEAP16[$8>>1] = $$0$i1;
  }
  $62 = (($9) + 24|0);
  $63 = HEAP32[$2>>2]|0;
  $64 = ($62|0)==($63|0);
  if ($64) {
   break;
  } else {
   $9 = $62;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK14SerializedFile11IsAvailableEx($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 if ($6) {
  $29 = $3;
 } else {
  $7 = $3;
  $8 = $5;
  $9 = (($8) - ($7))|0;
  $10 = (($9|0) / 24)&-1;
  $13 = $3;$__len$03$i$i$i$i$i = $10;
  while(1) {
   $11 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $12 = (($13) + (($11*24)|0)|0);
   $14 = $12;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)<($1|0);
   $21 = ($19|0)==($1|0);
   $22 = ($16>>>0)<($0>>>0);
   $23 = $21 & $22;
   $24 = $20 | $23;
   if ($24) {
    $$sum$i$i$i$i$i = (($11) + 1)|0;
    $25 = (($13) + (($$sum$i$i$i$i$i*24)|0)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $26 = (($$neg2$i$i$i$i$i) - ($11))|0;
    $42 = $25;$__len$0$be$i$i$i$i$i = $26;
   } else {
    $42 = $13;$__len$0$be$i$i$i$i$i = $11;
   }
   $27 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($27) {
    $29 = $42;
    break;
   } else {
    $13 = $42;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $28 = ($29|0)==($5|0);
 if ($28) {
  $41 = $5;
  $not$ = ($41|0)!=($5|0);
  STACKTOP = sp;return ($not$|0);
 }
 $30 = $29;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)>($1|0);
 $37 = ($35|0)==($1|0);
 $38 = ($32>>>0)>($0>>>0);
 $39 = $37 & $38;
 $40 = $36 | $39;
 $$1 = $40 ? $5 : $29;
 $41 = $$1;
 $not$ = ($41|0)!=($5|0);
 STACKTOP = sp;return ($not$|0);
}
function __ZNK14SerializedFile10GetClassIDEx($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 if ($6) {
  $29 = $3;
 } else {
  $7 = $3;
  $8 = $5;
  $9 = (($8) - ($7))|0;
  $10 = (($9|0) / 24)&-1;
  $13 = $3;$__len$03$i$i$i$i$i = $10;
  while(1) {
   $11 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $12 = (($13) + (($11*24)|0)|0);
   $14 = $12;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)<($1|0);
   $21 = ($19|0)==($1|0);
   $22 = ($16>>>0)<($0>>>0);
   $23 = $21 & $22;
   $24 = $20 | $23;
   if ($24) {
    $$sum$i$i$i$i$i = (($11) + 1)|0;
    $25 = (($13) + (($$sum$i$i$i$i$i*24)|0)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $26 = (($$neg2$i$i$i$i$i) - ($11))|0;
    $45 = $25;$__len$0$be$i$i$i$i$i = $26;
   } else {
    $45 = $13;$__len$0$be$i$i$i$i$i = $11;
   }
   $27 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($27) {
    $29 = $45;
    break;
   } else {
    $13 = $45;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $28 = ($29|0)==($5|0);
 if ($28) {
  $42 = $5;
  $41 = (($42) + 20|0);
  $43 = HEAP16[$41>>1]|0;
  $44 = $43 << 16 >> 16;
  STACKTOP = sp;return ($44|0);
 }
 $30 = $29;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)>($1|0);
 $37 = ($35|0)==($1|0);
 $38 = ($32>>>0)>($0>>>0);
 $39 = $37 & $38;
 $40 = $36 | $39;
 $$ = $40 ? $5 : $29;
 $42 = $$;
 $41 = (($42) + 20|0);
 $43 = HEAP16[$41>>1]|0;
 $44 = $43 << 16 >> 16;
 STACKTOP = sp;return ($44|0);
}
function __ZNK14SerializedFile13GetAllFileIDsER13dynamic_arrayIxLj8EE($this,$objects) {
 $this = $this|0;
 $objects = $objects|0;
 var $$byval_copy3 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 24)&-1;
 $9 = (($objects) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11>>>0)<($8>>>0);
 do {
  if ($12) {
   $13 = ($10|0)>(-1);
   if ($13) {
    HEAP32[$9>>2] = $8;
    $14 = HEAP32[$objects>>2]|0;
    $15 = $8 << 3;
    $16 = (($objects) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,8,$$byval_copy3,0,639432,370)|0);
    HEAP32[$objects>>2] = $18;
    break;
   } else {
    $19 = $8 << 3;
    $20 = (($objects) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,8,$$byval_copy3,0,639432,352)|0);
    $23 = HEAP32[$objects>>2]|0;
    $24 = (($objects) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = $25 << 3;
    _memcpy(($22|0),($23|0),($26|0))|0;
    HEAP32[$9>>2] = $8;
    HEAP32[$objects>>2] = $22;
    break;
   }
  }
 } while(0);
 $27 = HEAP32[$3>>2]|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = ($27|0)==($28|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($objects) + 8|0);
 $31 = (($objects) + 4|0);
 $33 = $27;
 while(1) {
  $32 = (($33) + 20|0);
  $34 = HEAP16[$32>>1]|0;
  $35 = $34 << 16 >> 16;
  $36 = (__ZN6Object13ClassIDToRTTIEi($35)|0);
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $38 = (($36) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    $41 = $33;
    $42 = $41;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($41) + 4)|0;
    $45 = $44;
    $46 = HEAP32[$45>>2]|0;
    $47 = HEAP32[$30>>2]|0;
    $48 = (($47) + 1)|0;
    HEAP32[$30>>2] = $48;
    $49 = HEAP32[$9>>2]|0;
    $50 = $49 & 2147483647;
    $51 = ($48>>>0)>($50>>>0);
    if ($51) {
     $52 = $49 << 1;
     $53 = ($52|0)==(0);
     $54 = $53 ? 1 : $52;
     $55 = ($50>>>0)<($54>>>0);
     do {
      if ($55) {
       $56 = ($49|0)>(-1);
       if ($56) {
        HEAP32[$9>>2] = $54;
        $57 = HEAP32[$objects>>2]|0;
        $58 = $54 << 3;
        $59 = HEAP32[$31>>2]|0;
        HEAP32[$0>>2] = $59;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
        $60 = (__Z16realloc_internalPvji10MemLabelIdiPKci($57,$58,8,$$byval_copy3,0,639432,370)|0);
        HEAP32[$objects>>2] = $60;
        break;
       } else {
        $61 = $54 << 3;
        $62 = HEAP32[$31>>2]|0;
        HEAP32[$0>>2] = $62;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
        $63 = (__Z15malloc_internaljj10MemLabelIdiPKci($61,8,$$byval_copy3,0,639432,352)|0);
        $64 = HEAP32[$objects>>2]|0;
        $65 = HEAP32[$30>>2]|0;
        $66 = $65 << 3;
        _memcpy(($63|0),($64|0),($66|0))|0;
        HEAP32[$9>>2] = $54;
        HEAP32[$objects>>2] = $63;
        break;
       }
      }
     } while(0);
     $$pre$i$i = HEAP32[$30>>2]|0;
     $68 = $$pre$i$i;
    } else {
     $68 = $48;
    }
    $67 = (($68) + -1)|0;
    $69 = HEAP32[$objects>>2]|0;
    $70 = (($69) + ($67<<3)|0);
    $71 = $70;
    $72 = $71;
    HEAP32[$72>>2] = $43;
    $73 = (($71) + 4)|0;
    $74 = $73;
    HEAP32[$74>>2] = $46;
   }
  }
  $75 = (($33) + 24|0);
  $76 = HEAP32[$1>>2]|0;
  $77 = ($75|0)==($76|0);
  if ($77) {
   break;
  } else {
   $33 = $75;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK14SerializedFile12GetHighestIDEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $12 = 0;$13 = 0;
  tempRet0 = $12;
  STACKTOP = sp;return ($13|0);
 }
 $5 = (($3) + -24|0);
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;$13 = $8;
 tempRet0 = $12;
 STACKTOP = sp;return ($13|0);
}
function __ZN14SerializedFile14GetProduceDataExRiR31LocalSerializedObjectIdentifierR18MemLabelIdentifier($this,$0,$1,$classID,$scriptTypeReference,$memLabel) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $classID = $classID|0;
 $scriptTypeReference = $scriptTypeReference|0;
 $memLabel = $memLabel|0;
 var $$ = 0, $$0 = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($3|0);
 if ($6) {
  $29 = $3;
 } else {
  $7 = $3;
  $8 = $5;
  $9 = (($8) - ($7))|0;
  $10 = (($9|0) / 24)&-1;
  $13 = $3;$__len$03$i$i$i$i$i = $10;
  while(1) {
   $11 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $12 = (($13) + (($11*24)|0)|0);
   $14 = $12;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)<($1|0);
   $21 = ($19|0)==($1|0);
   $22 = ($16>>>0)<($0>>>0);
   $23 = $21 & $22;
   $24 = $20 | $23;
   if ($24) {
    $$sum$i$i$i$i$i = (($11) + 1)|0;
    $25 = (($13) + (($$sum$i$i$i$i$i*24)|0)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $26 = (($$neg2$i$i$i$i$i) - ($11))|0;
    $59 = $25;$__len$0$be$i$i$i$i$i = $26;
   } else {
    $59 = $13;$__len$0$be$i$i$i$i$i = $11;
   }
   $27 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($27) {
    $29 = $59;
    break;
   } else {
    $13 = $59;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $28 = ($29|0)==($5|0);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = $29;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)>($1|0);
 $37 = ($35|0)==($1|0);
 $38 = ($32>>>0)>($0>>>0);
 $39 = $37 & $38;
 $40 = $36 | $39;
 $$ = $40 ? $5 : $29;
 $41 = ($$|0)==($5|0);
 if ($41) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = (($$) + 20|0);
 $43 = HEAP16[$42>>1]|0;
 $44 = $43 << 16 >> 16;
 HEAP32[$classID>>2] = $44;
 $45 = (($scriptTypeReference) + 8|0);
 $46 = $45;
 $47 = $46;
 HEAP32[$47>>2] = 0;
 $48 = (($46) + 4)|0;
 $49 = $48;
 HEAP32[$49>>2] = 0;
 HEAP32[$scriptTypeReference>>2] = -1;
 $50 = (($$) + 22|0);
 $51 = HEAP16[$50>>1]|0;
 $52 = ($51<<16>>16)==(-1);
 if (!($52)) {
  $53 = $51 << 16 >> 16;
  $54 = (($this) + 64|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + ($53<<4)|0);
  ;HEAP32[$scriptTypeReference+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$scriptTypeReference+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$scriptTypeReference+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$scriptTypeReference+12>>2]=HEAP32[$56+12>>2]|0;
 }
 $57 = (($this) + 60|0);
 $58 = HEAP32[$57>>2]|0;
 HEAP32[$memLabel>>2] = $58;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14SerializedFile10ReadObjectEx18ObjectCreationModebPPK8TypeTreePbR6Object($this,$0,$1,$mode,$isPersistent,$oldTypeTree,$safeLoaded,$object) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $mode = $mode|0;
 $isPersistent = $isPersistent|0;
 $oldTypeTree = $oldTypeTree|0;
 $safeLoaded = $safeLoaded|0;
 $object = $object|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$13 = 0, $$13$v = 0, $$byval_copy3 = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $or$cond = 0, $or$cond$i = 0, $readStream4 = 0, $storemerge = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy3 = sp + 232|0;
 $2 = sp;
 $3 = sp + 144|0;
 $4 = sp + 152|0;
 $5 = sp + 160|0;
 $readStream4 = sp + 168|0;
 HEAP8[$safeLoaded>>0] = 0;
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($7|0);
 if ($10) {
  $33 = $7;
 } else {
  $11 = $7;
  $12 = $9;
  $13 = (($12) - ($11))|0;
  $14 = (($13|0) / 24)&-1;
  $17 = $7;$__len$03$i$i$i$i$i = $14;
  while(1) {
   $15 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $16 = (($17) + (($15*24)|0)|0);
   $18 = $16;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)<($1|0);
   $25 = ($23|0)==($1|0);
   $26 = ($20>>>0)<($0>>>0);
   $27 = $25 & $26;
   $28 = $24 | $27;
   if ($28) {
    $$sum$i$i$i$i$i = (($15) + 1)|0;
    $29 = (($17) + (($$sum$i$i$i$i$i*24)|0)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $30 = (($$neg2$i$i$i$i$i) - ($15))|0;
    $223 = $29;$__len$0$be$i$i$i$i$i = $30;
   } else {
    $223 = $17;$__len$0$be$i$i$i$i$i = $15;
   }
   $31 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($31) {
    $33 = $223;
    break;
   } else {
    $17 = $223;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $32 = ($33|0)==($9|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $34 = $33;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)>($1|0);
 $41 = ($39|0)==($1|0);
 $42 = ($36>>>0)>($0>>>0);
 $43 = $41 & $42;
 $44 = $40 | $43;
 $$ = $44 ? $9 : $33;
 $45 = ($$|0)==($9|0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $46 = (($$) + 16|0);
 $47 = (__ZNSt3__13mapIiN14SerializedFile4TypeENS_4lessIiEENS_9allocatorINS_4pairIKiS2_EEEEEixERS7_($this,$46)|0);
 $48 = (($this) + 44|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = ($49<<24>>24)==(0);
 if (!($50)) {
  $51 = (($object) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 >>> 21;
  $54 = HEAP32[$46>>2]|0;
  $55 = (($47) + 40|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(-1);
  $58 = ($53|0)==($54|0);
  $or$cond = $57 & $58;
  if ($or$cond) {
   $59 = HEAP32[628488>>2]|0;
   HEAP32[$3>>2] = $59;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
   $60 = (__Znwj10MemLabelIdbiPKci(48,$$byval_copy3,0,16,639432,1651)|0);
   __THREW__ = 0;
   invoke_vi(3568,($60|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_viiiiii(97,($60|0),($$byval_copy3|0),0,16,(639432|0),1651);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     $221 = ___cxa_find_matching_catch(0|0)|0;
     $222 = tempRet0;
     ___clang_call_terminate($221);
     // unreachable;
    } else {
     $$0 = $74;$$01 = $75;
     ___resumeException($$0|0);
     // unreachable;
    }
   }
   $63 = (($this) + 40|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = $64 | 8192;
   __Z16GenerateTypeTreeR6ObjectP8TypeTree24TransferInstructionFlags($object,$60,$65);
   $66 = (($47) + 36|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(0|0);
   $69 = ($60|0)==(0|0);
   $or$cond$i = $68 | $69;
   if ($or$cond$i) {
    label = 13;
   } else {
    HEAP32[$$byval_copy3>>2] = $67;
    $70 = (($$byval_copy3) + 4|0);
    HEAP32[$70>>2] = 0;
    HEAP32[$2>>2] = $60;
    $71 = (($2) + 4|0);
    HEAP32[$71>>2] = 0;
    $72 = (__Z26IsStreamedBinaryCompatibleRK16TypeTreeIteratorS1_($$byval_copy3,$2)|0);
    if ($72) {
     $storemerge = 0;
    } else {
     label = 13;
    }
   }
   if ((label|0) == 13) {
    $storemerge = 1;
   }
   HEAP32[$55>>2] = $storemerge;
   $73 = HEAP32[628488>>2]|0;
   if (!($69)) {
    __ZN8TypeTreeD2Ev($60);
   }
   HEAP32[$2>>2] = $73;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($60,$$byval_copy3);
  }
 }
 $78 = (($this) + 40|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($this) + 36|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = ($81<<24>>24)!=(0);
 $$13$v = $82 ? 513 : 1;
 $$13 = $$13$v | $79;
 $83 = ($mode|0)==(1);
 $84 = $$13 | 8388608;
 $85 = $83 ? $84 : $$13;
 __ZN6Object15SetIsPersistentEb($object,$isPersistent);
 $86 = (($$) + 8|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($this) + 12|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($89) + ($87))|0;
 $91 = (($47) + 36|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0|0);
 L33: do {
  if ($93) {
   label = 30;
  } else {
   $94 = (($47) + 40|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)==(0);
   if ($96) {
    label = 30;
   } else {
    HEAP32[$2>>2] = 0;
    $97 = (($2) + 4|0);
    HEAP32[$97>>2] = 0;
    $98 = (($2) + 12|0);
    __ZN12CachedReaderC2Ev($98);
    $99 = (($2) + 72|0);
    HEAP32[$99>>2] = 0;
    $100 = (($2) + 76|0);
    HEAP32[$100>>2] = 0;
    $101 = (($2) + 88|0);
    dest=$101+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $102 = HEAP32[$91>>2]|0;
    HEAP32[$4>>2] = $102;
    $103 = (($4) + 4|0);
    HEAP32[$103>>2] = 0;
    $104 = (($$) + 12|0);
    $105 = HEAP32[$104>>2]|0;
    __THREW__ = 0;
    $106 = (invoke_ii(3223,($object|0))|0);
    $107 = __THREW__; __THREW__ = 0;
    $108 = $107&1;
    do {
     if (!($108)) {
      HEAP32[$5>>2] = $106;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$5+0>>2]|0;
      $109 = (invoke_iiiiiii(109,($2|0),($4|0),($90|0),($105|0),($85|0),($$byval_copy3|0))|0);
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if (!($111)) {
       $112 = (($this) + 108|0);
       $113 = HEAP32[$112>>2]|0;
       $114 = HEAP32[$104>>2]|0;
       __THREW__ = 0;
       invoke_viiii(364,($109|0),($113|0),($90|0),($114|0));
       $115 = __THREW__; __THREW__ = 0;
       $116 = $115&1;
       if (!($116)) {
        $117 = HEAP32[$object>>2]|0;
        $118 = (($117) + 24|0);
        $119 = HEAP32[$118>>2]|0;
        __THREW__ = 0;
        invoke_vi($119|0,($object|0));
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if (!($121)) {
         $122 = HEAP32[$object>>2]|0;
         $123 = (($122) + 84|0);
         $124 = HEAP32[$123>>2]|0;
         __THREW__ = 0;
         invoke_vii($124|0,($object|0),($2|0));
         $125 = __THREW__; __THREW__ = 0;
         $126 = $125&1;
         if (!($126)) {
          __THREW__ = 0;
          $127 = (invoke_ii(3238,($109|0))|0);
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if (!($129)) {
           $130 = (($127) - ($90))|0;
           $131 = HEAP32[$104>>2]|0;
           $132 = ($130|0)>($131|0);
           if ($132) {
            $133 = (($$) + 20|0);
            $134 = HEAP16[$133>>1]|0;
            $135 = $134 << 16 >> 16;
            __THREW__ = 0;
            invoke_viii(1930,($135|0),($131|0),($130|0));
            $136 = __THREW__; __THREW__ = 0;
            $137 = $136&1;
            if ($137) {
             break;
            }
           }
           HEAP8[$safeLoaded>>0] = 1;
           __ZN14SafeBinaryReadD2Ev($2);
           break L33;
          }
         }
        }
       }
      }
     }
    } while(0);
    $138 = ___cxa_find_matching_catch()|0;
    $139 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3548,($2|0));
    $140 = __THREW__; __THREW__ = 0;
    $141 = $140&1;
    if ($141) {
     $221 = ___cxa_find_matching_catch(0|0)|0;
     $222 = tempRet0;
     ___clang_call_terminate($221);
     // unreachable;
    } else {
     $$0 = $138;$$01 = $139;
     ___resumeException($$0|0);
     // unreachable;
    }
   }
  }
 } while(0);
 L50: do {
  if ((label|0) == 30) {
   $142 = HEAP8[$80>>0]|0;
   $143 = ($142<<24>>24)==(0);
   if (!($143)) {
    HEAP32[$readStream4>>2] = 0;
    $182 = (($readStream4) + 4|0);
    HEAP32[$182>>2] = 0;
    $183 = (($readStream4) + 12|0);
    __ZN12CachedReaderC2Ev($183);
    __THREW__ = 0;
    $184 = (invoke_ii(3223,($object|0))|0);
    $185 = __THREW__; __THREW__ = 0;
    $186 = $185&1;
    do {
     if (!($186)) {
      $187 = (($readStream4) + 8|0);
      HEAP32[$187>>2] = $184;
      HEAP32[$182>>2] = 0;
      HEAP32[$readStream4>>2] = $85;
      $188 = (($this) + 108|0);
      $189 = HEAP32[$188>>2]|0;
      $190 = (($$) + 12|0);
      $191 = HEAP32[$190>>2]|0;
      __THREW__ = 0;
      invoke_viiii(364,($183|0),($189|0),($90|0),($191|0));
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if (!($193)) {
       $194 = HEAP32[$object>>2]|0;
       $195 = (($194) + 80|0);
       $196 = HEAP32[$195>>2]|0;
       __THREW__ = 0;
       invoke_vii($196|0,($object|0),($readStream4|0));
       $197 = __THREW__; __THREW__ = 0;
       $198 = $197&1;
       if (!($198)) {
        __THREW__ = 0;
        $199 = (invoke_ii(3238,($183|0))|0);
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if (!($201)) {
         $202 = (($199) - ($90))|0;
         $203 = HEAP32[$190>>2]|0;
         $204 = ($202|0)==($203|0);
         if (!($204)) {
          $205 = (($$) + 20|0);
          $206 = HEAP16[$205>>1]|0;
          $207 = $206 << 16 >> 16;
          __THREW__ = 0;
          invoke_viii(1930,($207|0),($203|0),($202|0));
          $208 = __THREW__; __THREW__ = 0;
          $209 = $208&1;
          if ($209) {
           break;
          }
         }
         break L50;
        }
       }
      }
     }
    } while(0);
    $210 = ___cxa_find_matching_catch()|0;
    $211 = tempRet0;
    __THREW__ = 0;
    $212 = __THREW__; __THREW__ = 0;
    $213 = $212&1;
    if ($213) {
     $221 = ___cxa_find_matching_catch(0|0)|0;
     $222 = tempRet0;
     ___clang_call_terminate($221);
     // unreachable;
    } else {
     $$0 = $210;$$01 = $211;
     ___resumeException($$0|0);
     // unreachable;
    }
   }
   HEAP32[$$byval_copy3>>2] = 0;
   $144 = (($$byval_copy3) + 4|0);
   HEAP32[$144>>2] = 0;
   $145 = (($$byval_copy3) + 12|0);
   __ZN12CachedReaderC2Ev($145);
   __THREW__ = 0;
   $146 = (invoke_ii(3223,($object|0))|0);
   $147 = __THREW__; __THREW__ = 0;
   $148 = $147&1;
   do {
    if (!($148)) {
     $149 = (($$byval_copy3) + 8|0);
     HEAP32[$149>>2] = $146;
     HEAP32[$144>>2] = 0;
     HEAP32[$$byval_copy3>>2] = $85;
     $150 = (($this) + 108|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = HEAP32[$86>>2]|0;
     $153 = HEAP32[$88>>2]|0;
     $154 = (($153) + ($152))|0;
     $155 = (($$) + 12|0);
     $156 = HEAP32[$155>>2]|0;
     __THREW__ = 0;
     invoke_viiii(364,($145|0),($151|0),($154|0),($156|0));
     $157 = __THREW__; __THREW__ = 0;
     $158 = $157&1;
     if (!($158)) {
      $159 = (($this) + 112|0);
      __THREW__ = 0;
      invoke_vii(3225,($145|0),($159|0));
      $160 = __THREW__; __THREW__ = 0;
      $161 = $160&1;
      if (!($161)) {
       $162 = HEAP32[$object>>2]|0;
       $163 = (($162) + 68|0);
       $164 = HEAP32[$163>>2]|0;
       __THREW__ = 0;
       invoke_vii($164|0,($object|0),($$byval_copy3|0));
       $165 = __THREW__; __THREW__ = 0;
       $166 = $165&1;
       if (!($166)) {
        __THREW__ = 0;
        $167 = (invoke_ii(3238,($145|0))|0);
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if (!($169)) {
         $170 = (($167) - ($90))|0;
         $171 = HEAP32[$155>>2]|0;
         $172 = ($170|0)==($171|0);
         if (!($172)) {
          $173 = (($$) + 20|0);
          $174 = HEAP16[$173>>1]|0;
          $175 = $174 << 16 >> 16;
          __THREW__ = 0;
          invoke_viii(1930,($175|0),($171|0),($170|0));
          $176 = __THREW__; __THREW__ = 0;
          $177 = $176&1;
          if ($177) {
           break;
          }
         }
         break L50;
        }
       }
      }
     }
    }
   } while(0);
   $178 = ___cxa_find_matching_catch()|0;
   $179 = tempRet0;
   __THREW__ = 0;
   $180 = __THREW__; __THREW__ = 0;
   $181 = $180&1;
   if ($181) {
    $221 = ___cxa_find_matching_catch(0|0)|0;
    $222 = tempRet0;
    ___clang_call_terminate($221);
    // unreachable;
   } else {
    $$0 = $178;$$01 = $179;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $214 = HEAP32[$91>>2]|0;
 HEAP32[$oldTypeTree>>2] = $214;
 $215 = HEAP32[$78>>2]|0;
 $216 = $215 & 16777216;
 $217 = ($216|0)==(0);
 if ($217) {
  STACKTOP = sp;return;
 }
 $218 = (($object) + 8|0);
 $219 = HEAP32[$218>>2]|0;
 $220 = $219 | 1032192;
 HEAP32[$218>>2] = $220;
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIiN14SerializedFile4TypeENS_4lessIiEENS_9allocatorINS_4pairIKiS2_EEEEEixERS7_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$23 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$23 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $32 = (($__r$0) + 24|0);
  STACKTOP = sp;return ($32|0);
 }
 $16 = (__Znwj(72)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 24|0);
 $20 = (($16) + 64|0);
 dest=$19+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$20>>2] = -1;
 HEAP32[$16>>2] = 0;
 $21 = (($16) + 4|0);
 HEAP32[$21>>2] = 0;
 $22 = (($16) + 8|0);
 HEAP32[$22>>2] = $23;
 HEAP32[$$0$i>>2] = $16;
 $24 = HEAP32[$this>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  $28 = $16;
 } else {
  HEAP32[$this>>2] = $25;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $28 = $$pre$i;
 }
 $27 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 $__r$0 = $16;
 $32 = (($__r$0) + 24|0);
 STACKTOP = sp;return ($32|0);
}
function __ZL23OutOfBoundsReadingErroriii($classID,$expected,$was) {
 $classID = $classID|0;
 $expected = $expected|0;
 $was = $was|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer2 = sp;
 $0 = sp + 24|0;
 $1 = sp + 12|0;
 $2 = ($classID|0)==(114);
 if ($2) {
  HEAP32[$vararg_buffer2>>2] = $was;
  $vararg_ptr1 = (($vararg_buffer2) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $expected;
  __Z6FormatPKcz($0,639856,$vararg_buffer2);
  $3 = HEAP8[$0>>0]|0;
  $4 = $3 & 1;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   $8 = (($0) + 1|0);
   $9 = $8;
  } else {
   $6 = (($0) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $9 = $7;
  }
  __THREW__ = 0;
  invoke_viiiiiiii(21,($9|0),0,(639432|0),1579,1,0,0,(0|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $17 = ___cxa_find_matching_catch()|0;
   $18 = tempRet0;
   $19 = HEAP8[$0>>0]|0;
   $20 = $19 & 1;
   $21 = ($20<<24>>24)==(0);
   if ($21) {
    $$0 = $18;$$01 = $17;
    ___resumeException($$01|0);
    // unreachable;
   }
   $22 = (($0) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   __ZdlPv($23);
   $$0 = $18;$$01 = $17;
   ___resumeException($$01|0);
   // unreachable;
  } else {
   $12 = HEAP8[$0>>0]|0;
   $13 = $12 & 1;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    STACKTOP = sp;return;
   }
   $15 = (($0) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   __ZdlPv($16);
   STACKTOP = sp;return;
  }
 }
 $24 = (__ZN6Object15ClassIDToStringEi($classID)|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25 & 1;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $30 = (($24) + 1|0);
  $31 = $30;
 } else {
  $28 = (($24) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $31 = $29;
 }
 HEAP32[$vararg_buffer2>>2] = $31;
 $vararg_ptr5 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr5>>2] = $was;
 $vararg_ptr6 = (($vararg_buffer2) + 8|0);
 HEAP32[$vararg_ptr6>>2] = $expected;
 __Z6FormatPKcz($1,640056,$vararg_buffer2);
 $32 = HEAP8[$1>>0]|0;
 $33 = $32 & 1;
 $34 = ($33<<24>>24)==(0);
 if ($34) {
  $37 = (($1) + 1|0);
  $38 = $37;
 } else {
  $35 = (($1) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $38 = $36;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($38|0),0,(639432|0),1583,1,0,0,(0|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $48 = HEAP8[$1>>0]|0;
  $49 = $48 & 1;
  $50 = ($49<<24>>24)==(0);
  if ($50) {
   $$0 = $47;$$01 = $46;
   ___resumeException($$01|0);
   // unreachable;
  }
  $51 = (($1) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  __ZdlPv($52);
  $$0 = $47;$$01 = $46;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $41 = HEAP8[$1>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   STACKTOP = sp;return;
  }
  $44 = (($1) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  __ZdlPv($45);
  STACKTOP = sp;return;
 }
}
function __ZN14SerializedFile14AddExternalRefERK14FileIdentifier($this,$pathName) {
 $this = $this|0;
 $pathName = $pathName|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 __ZN20dynamic_block_vectorI14FileIdentifierE9push_backERKS0_($0,$pathName);
 STACKTOP = sp;return;
}
function __ZN20dynamic_block_vectorI14FileIdentifierE9push_backERKS0_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy5 = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__p$0$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($3>>>0) / ($4>>>0))&-1;
 $6 = (($3>>>0) % ($4>>>0))&-1;
 $7 = (($this) + 12|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($5|0)==($9|0);
 if ($10) {
  $11 = (($this) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  HEAP32[$1>>2] = $12;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
  $13 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy5,0,16,639432,102)|0);
  $14 = HEAP32[$this>>2]|0;
  $15 = HEAP32[$11>>2]|0;
  $16 = (($13) + 4|0);
  HEAP32[$16>>2] = $15;
  $17 = (($13) + 8|0);
  HEAP32[$17>>2] = $14;
  $18 = (($13) + 12|0);
  HEAP32[$18>>2] = $14;
  $19 = $14 << 5;
  HEAP32[$0>>2] = $15;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (invoke_iiiiiii(102,($19|0),4,($$byval_copy5|0),0,(639432|0),352)|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $50 = ___cxa_find_matching_catch()|0;
   $51 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(97,($13|0),($$byval_copy5|0),0,16,(639432|0),102);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $88 = ___cxa_find_matching_catch(0|0)|0;
    $89 = tempRet0;
    ___clang_call_terminate($88);
    // unreachable;
   } else {
    ___resumeException($50|0);
    // unreachable;
   }
  }
  HEAP32[$13>>2] = $20;
  $23 = HEAP32[$8>>2]|0;
  $24 = (($23) + 1)|0;
  HEAP32[$8>>2] = $24;
  $25 = (($this) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26 & 2147483647;
  $28 = ($24>>>0)>($27>>>0);
  if ($28) {
   $29 = $26 << 1;
   $30 = ($29|0)==(0);
   $31 = $30 ? 1 : $29;
   $32 = ($27>>>0)<($31>>>0);
   do {
    if ($32) {
     $33 = ($26|0)>(-1);
     if ($33) {
      HEAP32[$25>>2] = $31;
      $34 = HEAP32[$7>>2]|0;
      $35 = $31 << 2;
      $36 = (($this) + 16|0);
      $37 = HEAP32[$36>>2]|0;
      HEAP32[$0>>2] = $37;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      $38 = (__Z16realloc_internalPvji10MemLabelIdiPKci($34,$35,4,$$byval_copy5,0,639432,370)|0);
      HEAP32[$7>>2] = $38;
      break;
     } else {
      $39 = $31 << 2;
      $40 = (($this) + 16|0);
      $41 = HEAP32[$40>>2]|0;
      HEAP32[$0>>2] = $41;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($39,4,$$byval_copy5,0,639432,352)|0);
      $43 = HEAP32[$7>>2]|0;
      $44 = HEAP32[$8>>2]|0;
      $45 = $44 << 2;
      _memcpy(($42|0),($43|0),($45|0))|0;
      HEAP32[$25>>2] = $31;
      HEAP32[$7>>2] = $42;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$8>>2]|0;
   $47 = $$pre$i$i;
  } else {
   $47 = $24;
  }
  $46 = (($47) + -1)|0;
  $48 = HEAP32[$7>>2]|0;
  $49 = (($48) + ($46<<2)|0);
  HEAP32[$49>>2] = $13;
  $$pre$phiZ2D = $7;
 } else {
  $$pre$phiZ2D = $7;
 }
 $54 = HEAP32[$$pre$phiZ2D>>2]|0;
 $55 = (($54) + ($5<<2)|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($6<<5)|0);
 $59 = ($58|0)==(0|0);
 if ($59) {
  $86 = HEAP32[$2>>2]|0;
  $87 = (($86) + 1)|0;
  HEAP32[$2>>2] = $87;
  STACKTOP = sp;return;
 }
 $60 = HEAP8[$t>>0]|0;
 $61 = $60 & 1;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $67 = (($t) + 1|0);
  $68 = $60&255;
  $69 = $68 >>> 1;
  $71 = $69;$82 = $67;
 } else {
  $63 = (($t) + 8|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($t) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $71 = $66;$82 = $64;
 }
 $70 = ($71>>>0)>(2147483631);
 if ($70) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $72 = ($71>>>0)<(11);
 if ($72) {
  $73 = $71 << 1;
  $74 = $73&255;
  HEAP8[$58>>0] = $74;
  $75 = (($58) + 1|0);
  $__p$0$i$i$i$i$i$i = $75;
 } else {
  $76 = (($71) + 16)|0;
  $77 = $76 & -16;
  HEAP32[$0>>2] = 59;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  $78 = (__Z15malloc_internaljj10MemLabelIdiPKci($77,16,$$byval_copy5,0,639432,79)|0);
  $79 = ((($57) + ($6<<5)|0) + 8|0);
  HEAP32[$79>>2] = $78;
  $80 = $77 | 1;
  HEAP32[$58>>2] = $80;
  $81 = ((($57) + ($6<<5)|0) + 4|0);
  HEAP32[$81>>2] = $71;
  $__p$0$i$i$i$i$i$i = $78;
 }
 _memcpy(($__p$0$i$i$i$i$i$i|0),($82|0),($71|0))|0;
 $83 = (($__p$0$i$i$i$i$i$i) + ($71)|0);
 HEAP8[$83>>0] = 0;
 $84 = ((($57) + ($6<<5)|0) + 12|0);
 $85 = (($t) + 12|0);
 ;HEAP32[$84+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$85+8>>2]|0;HEAP32[$84+12>>2]=HEAP32[$85+12>>2]|0;HEAP32[$84+16>>2]=HEAP32[$85+16>>2]|0;
 $86 = HEAP32[$2>>2]|0;
 $87 = (($86) + 1)|0;
 HEAP32[$2>>2] = $87;
 STACKTOP = sp;return;
}
function __Z23InitializeStdConvertersv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580584>>2]|0;
 $1 = HEAP32[580568>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($0,$1,2450);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($1,$0,2451);
 $2 = HEAP32[580592>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$0,2452);
 $3 = HEAP32[580736>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$3,2453);
 $4 = HEAP32[580688>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$4,2454);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$2,2455);
 $5 = HEAP32[580752>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$5,2456);
 $6 = HEAP32[580720>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$6,2457);
 $7 = HEAP32[580672>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$7,2458);
 $8 = HEAP32[580744>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$8,2459);
 $9 = HEAP32[580696>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$9,2460);
 $10 = HEAP32[580544>>2]|0;
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($3,$10,2461);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$3,2462);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$4,2463);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$2,2464);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$5,2465);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$6,2466);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$7,2467);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$8,2468);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$9,2469);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($2,$10,2470);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$3,2471);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$4,2472);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$2,2473);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$5,2474);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$6,2475);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$7,2476);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$8,2477);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$9,2478);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($5,$10,2479);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$3,2480);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$4,2481);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$2,2482);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$5,2483);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$6,2484);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$7,2485);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$8,2486);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$9,2487);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($6,$10,2488);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$3,2489);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$4,2490);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$2,2491);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$5,2492);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$6,2493);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$7,2494);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$8,2495);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$9,2496);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($7,$10,2497);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$3,2498);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$4,2499);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$2,2500);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$5,2501);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$6,2502);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$7,2503);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$8,2504);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$9,2505);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($8,$10,2506);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$3,2507);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$4,2508);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$2,2509);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$5,2510);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$6,2511);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$7,2512);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$8,2513);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$9,2514);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($9,$10,2515);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$3,2516);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$4,2517);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$2,2518);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$5,2519);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$6,2520);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$7,2521);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$8,2522);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$9,2523);
 __ZN14SafeBinaryRead17RegisterConverterEPKcS1_PFbPvRS_E($10,$10,2524);
 STACKTOP = sp;return;
}
function __Z29StdTemplateConversionFunctionIfdEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = Math_fround(0), $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = Math_fround(0), $25 = 0.0, $26 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = Math_fround(HEAPF32[$12>>2]);
   HEAPF32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 if ($21) {
  $$pre = Math_fround(HEAPF32[$oldData>>2]);
  $26 = $$pre;
  $25 = +$26;
  HEAPF64[$inData>>3] = $25;
  STACKTOP = sp;return 1;
 } else {
  $22 = HEAP32[$oldData>>2]|0;
  $23 = (_llvm_bswap_i32(($22|0))|0);
  HEAP32[$oldData>>2] = $23;
  $24 = (HEAP32[tempDoublePtr>>2]=$23,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $26 = $24;
  $25 = +$26;
  HEAPF64[$inData>>3] = $25;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __Z29StdTemplateConversionFunctionIdfEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   HEAP8[tempDoublePtr>>0]=HEAP8[$12>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$12+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$12+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$12+3>>0];HEAP8[tempDoublePtr+4>>0]=HEAP8[$12+4>>0];HEAP8[tempDoublePtr+5>>0]=HEAP8[$12+5>>0];HEAP8[tempDoublePtr+6>>0]=HEAP8[$12+6>>0];HEAP8[tempDoublePtr+7>>0]=HEAP8[$12+7>>0];$18 = +HEAPF64[tempDoublePtr>>3];
   HEAPF64[$oldData>>3] = $18;
   $$sum = (($$sum$i$i) + 8)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $20 = HEAP32[$transfer>>2]|0;
 $21 = $20 & 512;
 $22 = ($21|0)==(0);
 if ($22) {
  $28 = +HEAPF64[$oldData>>3];
  $29 = Math_fround($28);
  HEAPF32[$inData>>2] = $29;
  STACKTOP = sp;return 1;
 }
 $23 = HEAP32[$oldData>>2]|0;
 $24 = (_llvm_bswap_i32(($23|0))|0);
 $25 = (($oldData) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$oldData>>2] = $27;
 HEAP32[$25>>2] = $24;
 $28 = +HEAPF64[$oldData>>3];
 $29 = Math_fround($28);
 HEAPF32[$inData>>2] = $29;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIifEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = (Math_fround(($24|0)));
  HEAPF32[$inData>>2] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = (Math_fround(($24|0)));
 HEAPF32[$inData>>2] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIyyEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $inData;
  $43 = $42;
  HEAP32[$43>>2] = $38;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $41;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $inData;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIyxEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $inData;
  $43 = $42;
  HEAP32[$43>>2] = $38;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $41;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $inData;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIyiEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$inData>>2] = $38;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$inData>>2] = $38;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIyjEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$inData>>2] = $38;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$inData>>2] = $38;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIytEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $38&65535;
  HEAP16[$inData>>1] = $42;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $38&65535;
 HEAP16[$inData>>1] = $42;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIysEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $38&65535;
  HEAP16[$inData>>1] = $42;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $38&65535;
 HEAP16[$inData>>1] = $42;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIyhEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $38&255;
  HEAP8[$inData>>0] = $42;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $38&255;
 HEAP8[$inData>>0] = $42;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIyaEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $38&255;
  HEAP8[$inData>>0] = $42;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $38&255;
 HEAP8[$inData>>0] = $42;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIybEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 8)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = $12;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $oldData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,8);
 }
 $28 = HEAP32[$transfer>>2]|0;
 $29 = $28 & 512;
 $30 = ($29|0)==(0);
 if ($30) {
  $36 = $oldData;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = ($38|0)!=(0);
  $43 = ($41|0)!=(0);
  $44 = $42 | $43;
  $45 = $44&1;
  HEAP8[$inData>>0] = $45;
  STACKTOP = sp;return 1;
 }
 $31 = HEAP32[$oldData>>2]|0;
 $32 = (_llvm_bswap_i32(($31|0))|0);
 $33 = (($oldData) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$oldData>>2] = $35;
 HEAP32[$33>>2] = $32;
 $36 = $oldData;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = ($38|0)!=(0);
 $43 = ($41|0)!=(0);
 $44 = $42 | $43;
 $45 = $44&1;
 HEAP8[$inData>>0] = $45;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIiyEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = ($24|0)<(0);
  $25 = $23 << 31 >> 31;
  $26 = $inData;
  $27 = $26;
  HEAP32[$27>>2] = $24;
  $28 = (($26) + 4)|0;
  $29 = $28;
  HEAP32[$29>>2] = $25;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = ($24|0)<(0);
 $25 = $23 << 31 >> 31;
 $26 = $inData;
 $27 = $26;
 HEAP32[$27>>2] = $24;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIixEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = ($24|0)<(0);
  $25 = $23 << 31 >> 31;
  $26 = $inData;
  $27 = $26;
  HEAP32[$27>>2] = $24;
  $28 = (($26) + 4)|0;
  $29 = $28;
  HEAP32[$29>>2] = $25;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = ($24|0)<(0);
 $25 = $23 << 31 >> 31;
 $26 = $inData;
 $27 = $26;
 HEAP32[$27>>2] = $24;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIiiEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $23 = $$pre;
  HEAP32[$inData>>2] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $23 = $22;
 HEAP32[$inData>>2] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIijEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $23 = $$pre;
  HEAP32[$inData>>2] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $23 = $22;
 HEAP32[$inData>>2] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIitEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = $24&65535;
  HEAP16[$inData>>1] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = $24&65535;
 HEAP16[$inData>>1] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIisEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = $24&65535;
  HEAP16[$inData>>1] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = $24&65535;
 HEAP16[$inData>>1] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIihEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = $24&255;
  HEAP8[$inData>>0] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = $24&255;
 HEAP8[$inData>>0] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIiaEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = $24&255;
  HEAP8[$inData>>0] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = $24&255;
 HEAP8[$inData>>0] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIibEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = ($24|0)!=(0);
  $25 = $23&1;
  HEAP8[$inData>>0] = $25;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = ($24|0)!=(0);
 $25 = $23&1;
 HEAP8[$inData>>0] = $25;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjyEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $25 = $$pre;
  $23 = $inData;
  $24 = $23;
  HEAP32[$24>>2] = $25;
  $26 = (($23) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = 0;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $25 = $22;
 $23 = $inData;
 $24 = $23;
 HEAP32[$24>>2] = $25;
 $26 = (($23) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjxEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $25 = $$pre;
  $23 = $inData;
  $24 = $23;
  HEAP32[$24>>2] = $25;
  $26 = (($23) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = 0;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $25 = $22;
 $23 = $inData;
 $24 = $23;
 HEAP32[$24>>2] = $25;
 $26 = (($23) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjiEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $23 = $$pre;
  HEAP32[$inData>>2] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $23 = $22;
 HEAP32[$inData>>2] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjjEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $23 = $$pre;
  HEAP32[$inData>>2] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $23 = $22;
 HEAP32[$inData>>2] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjtEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = $24&65535;
  HEAP16[$inData>>1] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = $24&65535;
 HEAP16[$inData>>1] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjsEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = $24&65535;
  HEAP16[$inData>>1] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = $24&65535;
 HEAP16[$inData>>1] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjhEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = $24&255;
  HEAP8[$inData>>0] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = $24&255;
 HEAP8[$inData>>0] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjaEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = $24&255;
  HEAP8[$inData>>0] = $23;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = $24&255;
 HEAP8[$inData>>0] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIjbEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 4)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$oldData>>2] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,4);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP32[$oldData>>2]|0;
 if ($21) {
  $24 = $$pre;
  $23 = ($24|0)!=(0);
  $25 = $23&1;
  HEAP8[$inData>>0] = $25;
  STACKTOP = sp;return 1;
 }
 $22 = (_llvm_bswap_i32(($$pre|0))|0);
 HEAP32[$oldData>>2] = $22;
 $24 = $22;
 $23 = ($24|0)!=(0);
 $25 = $23&1;
 HEAP8[$inData>>0] = $25;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionItyEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = $28&65535;
  $29 = $inData;
  $30 = $29;
  HEAP32[$30>>2] = $27;
  $31 = (($29) + 4)|0;
  $32 = $31;
  HEAP32[$32>>2] = 0;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = $28&65535;
 $29 = $inData;
 $30 = $29;
 HEAP32[$30>>2] = $27;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = 0;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionItxEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = $28&65535;
  $29 = $inData;
  $30 = $29;
  HEAP32[$30>>2] = $27;
  $31 = (($29) + 4)|0;
  $32 = $31;
  HEAP32[$32>>2] = 0;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = $28&65535;
 $29 = $inData;
 $30 = $29;
 HEAP32[$30>>2] = $27;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = 0;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionItiEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = $28&65535;
  HEAP32[$inData>>2] = $27;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = $28&65535;
 HEAP32[$inData>>2] = $27;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionItjEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = $28&65535;
  HEAP32[$inData>>2] = $27;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = $28&65535;
 HEAP32[$inData>>2] = $27;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIttEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $27 = $$pre;
  HEAP16[$inData>>1] = $27;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $27 = $26;
 HEAP16[$inData>>1] = $27;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionItsEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $27 = $$pre;
  HEAP16[$inData>>1] = $27;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $27 = $26;
 HEAP16[$inData>>1] = $27;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIthEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$off0 = 0, $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $extract$t = 0, $extract$t1 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $extract$t = $$pre&255;
  $$off0 = $extract$t;
  HEAP8[$inData>>0] = $$off0;
  STACKTOP = sp;return 1;
 } else {
  $22 = $$pre&65535;
  $23 = $22 << 8;
  $24 = $22 >>> 8;
  $25 = $23 | $24;
  $26 = $25&65535;
  HEAP16[$oldData>>1] = $26;
  $extract$t1 = $24&255;
  $$off0 = $extract$t1;
  HEAP8[$inData>>0] = $$off0;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __Z29StdTemplateConversionFunctionItaEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$off0 = 0, $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $extract$t = 0, $extract$t1 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $extract$t = $$pre&255;
  $$off0 = $extract$t;
  HEAP8[$inData>>0] = $$off0;
  STACKTOP = sp;return 1;
 } else {
  $22 = $$pre&65535;
  $23 = $22 << 8;
  $24 = $22 >>> 8;
  $25 = $23 | $24;
  $26 = $25&65535;
  HEAP16[$oldData>>1] = $26;
  $extract$t1 = $24&255;
  $$off0 = $extract$t1;
  HEAP8[$inData>>0] = $$off0;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __Z29StdTemplateConversionFunctionItbEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = ($28<<16>>16)!=(0);
  $29 = $27&1;
  HEAP8[$inData>>0] = $29;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = ($28<<16>>16)!=(0);
 $29 = $27&1;
 HEAP8[$inData>>0] = $29;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIsyEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = $28 << 16 >> 16;
  $29 = ($27|0)<(0);
  $30 = $29 << 31 >> 31;
  $31 = $inData;
  $32 = $31;
  HEAP32[$32>>2] = $27;
  $33 = (($31) + 4)|0;
  $34 = $33;
  HEAP32[$34>>2] = $30;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = $28 << 16 >> 16;
 $29 = ($27|0)<(0);
 $30 = $29 << 31 >> 31;
 $31 = $inData;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIsxEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = $28 << 16 >> 16;
  $29 = ($27|0)<(0);
  $30 = $29 << 31 >> 31;
  $31 = $inData;
  $32 = $31;
  HEAP32[$32>>2] = $27;
  $33 = (($31) + 4)|0;
  $34 = $33;
  HEAP32[$34>>2] = $30;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = $28 << 16 >> 16;
 $29 = ($27|0)<(0);
 $30 = $29 << 31 >> 31;
 $31 = $inData;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIsiEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = $28 << 16 >> 16;
  HEAP32[$inData>>2] = $27;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = $28 << 16 >> 16;
 HEAP32[$inData>>2] = $27;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIsjEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = $28 << 16 >> 16;
  HEAP32[$inData>>2] = $27;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = $28 << 16 >> 16;
 HEAP32[$inData>>2] = $27;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIstEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $27 = $$pre;
  HEAP16[$inData>>1] = $27;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $27 = $26;
 HEAP16[$inData>>1] = $27;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIssEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $27 = $$pre;
  HEAP16[$inData>>1] = $27;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $27 = $26;
 HEAP16[$inData>>1] = $27;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIshEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$off0 = 0, $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $extract$t = 0, $extract$t1 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $extract$t = $$pre&255;
  $$off0 = $extract$t;
  HEAP8[$inData>>0] = $$off0;
  STACKTOP = sp;return 1;
 } else {
  $22 = $$pre&65535;
  $23 = $22 << 8;
  $24 = $22 >>> 8;
  $25 = $23 | $24;
  $26 = $25&65535;
  HEAP16[$oldData>>1] = $26;
  $extract$t1 = $24&255;
  $$off0 = $extract$t1;
  HEAP8[$inData>>0] = $$off0;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __Z29StdTemplateConversionFunctionIsaEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$off0 = 0, $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $extract$t = 0, $extract$t1 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $extract$t = $$pre&255;
  $$off0 = $extract$t;
  HEAP8[$inData>>0] = $$off0;
  STACKTOP = sp;return 1;
 } else {
  $22 = $$pre&65535;
  $23 = $22 << 8;
  $24 = $22 >>> 8;
  $25 = $23 | $24;
  $26 = $25&65535;
  HEAP16[$oldData>>1] = $26;
  $extract$t1 = $24&255;
  $$off0 = $extract$t1;
  HEAP8[$inData>>0] = $$off0;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __Z29StdTemplateConversionFunctionIsbEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if ($13) {
  label = 4;
 } else {
  $$sum1$i$i = (($$sum$i$i) + 2)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if ($17) {
   label = 4;
  } else {
   $18 = HEAP16[$12>>1]|0;
   HEAP16[$oldData>>1] = $18;
   HEAP32[$0>>2] = $14;
  }
 }
 if ((label|0) == 4) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,2);
 }
 $19 = HEAP32[$transfer>>2]|0;
 $20 = $19 & 512;
 $21 = ($20|0)==(0);
 $$pre = HEAP16[$oldData>>1]|0;
 if ($21) {
  $28 = $$pre;
  $27 = ($28<<16>>16)!=(0);
  $29 = $27&1;
  HEAP8[$inData>>0] = $29;
  STACKTOP = sp;return 1;
 }
 $22 = $$pre&65535;
 $23 = $22 << 8;
 $24 = $22 >>> 8;
 $25 = $23 | $24;
 $26 = $25&65535;
 HEAP16[$oldData>>1] = $26;
 $28 = $26;
 $27 = ($28<<16>>16)!=(0);
 $29 = $27&1;
 HEAP8[$inData>>0] = $29;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhyEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21&255;
   $22 = $inData;
   $23 = $22;
   HEAP32[$23>>2] = $20;
   $24 = (($22) + 4)|0;
   $25 = $24;
   HEAP32[$25>>2] = 0;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21&255;
 $22 = $inData;
 $23 = $22;
 HEAP32[$23>>2] = $20;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhxEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21&255;
   $22 = $inData;
   $23 = $22;
   HEAP32[$23>>2] = $20;
   $24 = (($22) + 4)|0;
   $25 = $24;
   HEAP32[$25>>2] = 0;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21&255;
 $22 = $inData;
 $23 = $22;
 HEAP32[$23>>2] = $20;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhiEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21&255;
   HEAP32[$inData>>2] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21&255;
 HEAP32[$inData>>2] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhjEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21&255;
   HEAP32[$inData>>2] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21&255;
 HEAP32[$inData>>2] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhtEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21&255;
   HEAP16[$inData>>1] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21&255;
 HEAP16[$inData>>1] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhsEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21&255;
   HEAP16[$inData>>1] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21&255;
 HEAP16[$inData>>1] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhhEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $20 = $18;
   HEAP8[$inData>>0] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 HEAP8[$inData>>0] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhaEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $20 = $18;
   HEAP8[$inData>>0] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 HEAP8[$inData>>0] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIhbEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = ($21<<24>>24)!=(0);
   $22 = $20&1;
   HEAP8[$inData>>0] = $22;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = ($21<<24>>24)!=(0);
 $22 = $20&1;
 HEAP8[$inData>>0] = $22;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIayEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21 << 24 >> 24;
   $22 = ($20|0)<(0);
   $23 = $22 << 31 >> 31;
   $24 = $inData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21 << 24 >> 24;
 $22 = ($20|0)<(0);
 $23 = $22 << 31 >> 31;
 $24 = $inData;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIaxEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21 << 24 >> 24;
   $22 = ($20|0)<(0);
   $23 = $22 << 31 >> 31;
   $24 = $inData;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21 << 24 >> 24;
 $22 = ($20|0)<(0);
 $23 = $22 << 31 >> 31;
 $24 = $inData;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIaiEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21 << 24 >> 24;
   HEAP32[$inData>>2] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21 << 24 >> 24;
 HEAP32[$inData>>2] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIajEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21 << 24 >> 24;
   HEAP32[$inData>>2] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21 << 24 >> 24;
 HEAP32[$inData>>2] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIatEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21 << 24 >> 24;
   HEAP16[$inData>>1] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21 << 24 >> 24;
 HEAP16[$inData>>1] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIasEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = $21 << 24 >> 24;
   HEAP16[$inData>>1] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = $21 << 24 >> 24;
 HEAP16[$inData>>1] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIahEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $20 = $18;
   HEAP8[$inData>>0] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 HEAP8[$inData>>0] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIaaEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $20 = $18;
   HEAP8[$inData>>0] = $20;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 HEAP8[$inData>>0] = $20;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIabEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   $$sum = (($$sum$i$i) + 1)|0;
   $19 = (($6) + ($$sum)|0);
   HEAP32[$0>>2] = $19;
   $21 = $18;
   $20 = ($21<<24>>24)!=(0);
   $22 = $20&1;
   HEAP8[$inData>>0] = $22;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $21 = $$pre;
 $20 = ($21<<24>>24)!=(0);
 $22 = $20&1;
 HEAP8[$inData>>0] = $22;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbyEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $20 = $18;
   $19 = $20&255;
   $21 = $inData;
   $22 = $21;
   HEAP32[$22>>2] = $19;
   $23 = (($21) + 4)|0;
   $24 = $23;
   HEAP32[$24>>2] = 0;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 $19 = $20&255;
 $21 = $inData;
 $22 = $21;
 HEAP32[$22>>2] = $19;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = 0;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbxEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $20 = $18;
   $19 = $20&255;
   $21 = $inData;
   $22 = $21;
   HEAP32[$22>>2] = $19;
   $23 = (($21) + 4)|0;
   $24 = $23;
   HEAP32[$24>>2] = 0;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 $19 = $20&255;
 $21 = $inData;
 $22 = $21;
 HEAP32[$22>>2] = $19;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = 0;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbiEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $20 = $18;
   $19 = $20&255;
   HEAP32[$inData>>2] = $19;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 $19 = $20&255;
 HEAP32[$inData>>2] = $19;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbjEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $20 = $18;
   $19 = $20&255;
   HEAP32[$inData>>2] = $19;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 $19 = $20&255;
 HEAP32[$inData>>2] = $19;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbtEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $20 = $18;
   $19 = $20&255;
   HEAP16[$inData>>1] = $19;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 $19 = $20&255;
 HEAP16[$inData>>1] = $19;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbsEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $20 = $18;
   $19 = $20&255;
   HEAP16[$inData>>1] = $19;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $20 = $$pre;
 $19 = $20&255;
 HEAP16[$inData>>1] = $19;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbhEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $19 = $18;
   HEAP8[$inData>>0] = $19;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $19 = $$pre;
 HEAP8[$inData>>0] = $19;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbaEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $19 = $18;
   HEAP8[$inData>>0] = $19;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $19 = $$pre;
 HEAP8[$inData>>0] = $19;
 STACKTOP = sp;return 1;
}
function __Z29StdTemplateConversionFunctionIbbEbPvR14SafeBinaryRead($inData,$transfer) {
 $inData = $inData|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $oldData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $oldData = sp;
 $0 = (($transfer) + 12|0);
 $1 = (($transfer) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $$sum$i$i = (($4) - ($11))|0;
 $12 = (($6) + ($$sum$i$i)|0);
 HEAP32[$0>>2] = $12;
 $13 = ($$sum$i$i|0)<(0);
 if (!($13)) {
  $$sum1$i$i = (($$sum$i$i) + 1)|0;
  $14 = (($6) + ($$sum1$i$i)|0);
  $15 = (($transfer) + 20|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14>>>0)>($16>>>0);
  if (!($17)) {
   $18 = HEAP8[$12>>0]|0;
   HEAP8[$oldData>>0] = $18;
   HEAP32[$0>>2] = $14;
   $19 = $18;
   HEAP8[$inData>>0] = $19;
   STACKTOP = sp;return 1;
  }
 }
 __ZN12CachedReader15UpdateReadCacheEPvj($0,$oldData,1);
 $$pre = HEAP8[$oldData>>0]|0;
 $19 = $$pre;
 HEAP8[$inData>>0] = $19;
 STACKTOP = sp;return 1;
}
function __Z20CleanupStdConvertersv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14SafeBinaryRead21CleanupConverterTableEv();
 STACKTOP = sp;return;
}
function __ZN8TypeTreeD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(-1);
 do {
  if ($6) {
   $7 = (($this) + 32|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 36|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$3>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy4|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    HEAP32[$7>>2] = 0;
    label = 4;
    break;
   }
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = (($this) + 28|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)>(-1);
   if ($32) {
    $33 = (($this) + 16|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($this) + 20|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$1>>2] = $36;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($34|0),($$byval_copy4|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $49 = ___cxa_find_matching_catch(0|0)|0;
     $50 = tempRet0;
     ___clang_call_terminate($49);
     // unreachable;
    } else {
     HEAP32[$33>>2] = 0;
     $$0 = $29;$$01 = $28;
     break;
    }
   } else {
    $$0 = $29;$$01 = $28;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $13 = (($this) + 28|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)>(-1);
   do {
    if ($15) {
     $16 = (($this) + 16|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($this) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$2>>2] = $19;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($17|0),($$byval_copy4|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      $39 = ___cxa_find_matching_catch()|0;
      $40 = tempRet0;
      $$0 = $40;$$01 = $39;
      break L10;
     } else {
      HEAP32[$16>>2] = 0;
      break;
     }
    }
   } while(0);
   $22 = (($this) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)>(-1);
   if (!($24)) {
    STACKTOP = sp;return;
   }
   $25 = HEAP32[$this>>2]|0;
   $26 = (($this) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$0>>2] = $27;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy4);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $41 = (($this) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)>(-1);
 if (!($43)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $44 = HEAP32[$this>>2]|0;
 $45 = (($this) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$0>>2] = $46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($44|0),($$byval_copy4|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN14SerializedFile4Type8ReadTypeILb1EEEbibiRPKhS3_($this,$version,$enableTypeTree,$typeID,$iterator,$end) {
 $this = $this|0;
 $version = $version|0;
 $enableTypeTree = $enableTypeTree|0;
 $typeID = $typeID|0;
 $iterator = $iterator|0;
 $end = $end|0;
 var $$0 = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($typeID|0)<(0);
 if ($2) {
  $3 = HEAP32[$iterator>>2]|0;
  $4 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8)|(HEAPU8[$3+2>>0]<<16)|(HEAPU8[$3+3>>0]<<24);
  $5 = (_llvm_bswap_i32(($4|0))|0);
  HEAP32[$this>>2] = $5;
  $6 = (($3) + 4|0);
  HEAP32[$iterator>>2] = $6;
  $7 = (($this) + 4|0);
  $8 = HEAPU8[$6>>0]|(HEAPU8[$6+1>>0]<<8)|(HEAPU8[$6+2>>0]<<16)|(HEAPU8[$6+3>>0]<<24);
  $9 = (_llvm_bswap_i32(($8|0))|0);
  HEAP32[$7>>2] = $9;
  $10 = (($3) + 8|0);
  HEAP32[$iterator>>2] = $10;
  $11 = (($this) + 8|0);
  $12 = HEAPU8[$10>>0]|(HEAPU8[$10+1>>0]<<8)|(HEAPU8[$10+2>>0]<<16)|(HEAPU8[$10+3>>0]<<24);
  $13 = (_llvm_bswap_i32(($12|0))|0);
  HEAP32[$11>>2] = $13;
  $14 = (($3) + 12|0);
  HEAP32[$iterator>>2] = $14;
  $15 = (($this) + 12|0);
  $16 = HEAPU8[$14>>0]|(HEAPU8[$14+1>>0]<<8)|(HEAPU8[$14+2>>0]<<16)|(HEAPU8[$14+3>>0]<<24);
  $17 = (_llvm_bswap_i32(($16|0))|0);
  HEAP32[$15>>2] = $17;
  $18 = (($3) + 16|0);
  HEAP32[$iterator>>2] = $18;
  $21 = $18;
 } else {
  $$pre = HEAP32[$iterator>>2]|0;
  $21 = $$pre;
 }
 $19 = (($this) + 16|0);
 $20 = HEAPU8[$21>>0]|(HEAPU8[$21+1>>0]<<8)|(HEAPU8[$21+2>>0]<<16)|(HEAPU8[$21+3>>0]<<24);
 $22 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$19>>2] = $22;
 $23 = (($21) + 4|0);
 HEAP32[$iterator>>2] = $23;
 $24 = (($19) + 4|0);
 $25 = HEAPU8[$23>>0]|(HEAPU8[$23+1>>0]<<8)|(HEAPU8[$23+2>>0]<<16)|(HEAPU8[$23+3>>0]<<24);
 $26 = (_llvm_bswap_i32(($25|0))|0);
 HEAP32[$24>>2] = $26;
 $27 = (($21) + 8|0);
 HEAP32[$iterator>>2] = $27;
 $28 = (($this) + 24|0);
 $29 = HEAPU8[$27>>0]|(HEAPU8[$27+1>>0]<<8)|(HEAPU8[$27+2>>0]<<16)|(HEAPU8[$27+3>>0]<<24);
 $30 = (_llvm_bswap_i32(($29|0))|0);
 HEAP32[$28>>2] = $30;
 $31 = (($21) + 12|0);
 HEAP32[$iterator>>2] = $31;
 $32 = (($19) + 12|0);
 $33 = HEAPU8[$31>>0]|(HEAPU8[$31+1>>0]<<8)|(HEAPU8[$31+2>>0]<<16)|(HEAPU8[$31+3>>0]<<24);
 $34 = (_llvm_bswap_i32(($33|0))|0);
 HEAP32[$32>>2] = $34;
 $35 = (($21) + 16|0);
 HEAP32[$iterator>>2] = $35;
 if (!($enableTypeTree)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = HEAP32[628488>>2]|0;
 HEAP32[$1>>2] = $36;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $37 = (__Znwj10MemLabelIdbiPKci(48,$$byval_copy2,0,16,639432,195)|0);
 __THREW__ = 0;
 invoke_vi(3568,($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viiiiii(97,($37|0),($$byval_copy2|0),0,16,(639432|0),195);
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $48 = ___cxa_find_matching_catch(0|0)|0;
   $49 = tempRet0;
   ___clang_call_terminate($48);
   // unreachable;
  } else {
   ___resumeException($43|0);
   // unreachable;
  }
 }
 $40 = (__Z12ReadTypeTreeR8TypeTreeRPKhS2_ib($37,$iterator,$end,$version,1)|0);
 if ($40) {
  $47 = (($this) + 36|0);
  HEAP32[$47>>2] = $37;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = HEAP32[628488>>2]|0;
 $42 = ($37|0)==(0|0);
 if (!($42)) {
  __ZN8TypeTreeD2Ev($37);
 }
 HEAP32[$0>>2] = $41;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy2);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20dynamic_block_vectorI14FileIdentifierE9push_backEv($this) {
 $this = $this|0;
 var $$byval_copy4 = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($3>>>0) / ($4>>>0))&-1;
 $6 = (($3>>>0) % ($4>>>0))&-1;
 $7 = (($this) + 12|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($5|0)==($9|0);
 if ($10) {
  $11 = (($this) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  HEAP32[$1>>2] = $12;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  $13 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy4,0,16,639432,90)|0);
  $14 = HEAP32[$this>>2]|0;
  $15 = HEAP32[$11>>2]|0;
  $16 = (($13) + 4|0);
  HEAP32[$16>>2] = $15;
  $17 = (($13) + 8|0);
  HEAP32[$17>>2] = $14;
  $18 = (($13) + 12|0);
  HEAP32[$18>>2] = $14;
  $19 = $14 << 5;
  HEAP32[$0>>2] = $15;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (invoke_iiiiiii(102,($19|0),4,($$byval_copy4|0),0,(639432|0),352)|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $50 = ___cxa_find_matching_catch()|0;
   $51 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(97,($13|0),($$byval_copy4|0),0,16,(639432|0),90);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $62 = ___cxa_find_matching_catch(0|0)|0;
    $63 = tempRet0;
    ___clang_call_terminate($62);
    // unreachable;
   } else {
    ___resumeException($50|0);
    // unreachable;
   }
  }
  HEAP32[$13>>2] = $20;
  $23 = HEAP32[$8>>2]|0;
  $24 = (($23) + 1)|0;
  HEAP32[$8>>2] = $24;
  $25 = (($this) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26 & 2147483647;
  $28 = ($24>>>0)>($27>>>0);
  if ($28) {
   $29 = $26 << 1;
   $30 = ($29|0)==(0);
   $31 = $30 ? 1 : $29;
   $32 = ($27>>>0)<($31>>>0);
   do {
    if ($32) {
     $33 = ($26|0)>(-1);
     if ($33) {
      HEAP32[$25>>2] = $31;
      $34 = HEAP32[$7>>2]|0;
      $35 = $31 << 2;
      $36 = (($this) + 16|0);
      $37 = HEAP32[$36>>2]|0;
      HEAP32[$0>>2] = $37;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
      $38 = (__Z16realloc_internalPvji10MemLabelIdiPKci($34,$35,4,$$byval_copy4,0,639432,370)|0);
      HEAP32[$7>>2] = $38;
      break;
     } else {
      $39 = $31 << 2;
      $40 = (($this) + 16|0);
      $41 = HEAP32[$40>>2]|0;
      HEAP32[$0>>2] = $41;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
      $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($39,4,$$byval_copy4,0,639432,352)|0);
      $43 = HEAP32[$7>>2]|0;
      $44 = HEAP32[$8>>2]|0;
      $45 = $44 << 2;
      _memcpy(($42|0),($43|0),($45|0))|0;
      HEAP32[$25>>2] = $31;
      HEAP32[$7>>2] = $42;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$8>>2]|0;
   $47 = $$pre$i$i;
  } else {
   $47 = $24;
  }
  $46 = (($47) + -1)|0;
  $48 = HEAP32[$7>>2]|0;
  $49 = (($48) + ($46<<2)|0);
  HEAP32[$49>>2] = $13;
  $$pre$phiZ2D = $7;
 } else {
  $$pre$phiZ2D = $7;
 }
 $54 = HEAP32[$$pre$phiZ2D>>2]|0;
 $55 = (($54) + ($5<<2)|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($6<<5)|0);
 $59 = ($58|0)==(0|0);
 if ($59) {
  $60 = HEAP32[$2>>2]|0;
  $61 = (($60) + 1)|0;
  HEAP32[$2>>2] = $61;
  STACKTOP = sp;return;
 }
 ;HEAP32[$58+0>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;HEAP32[$58+12>>2]=0|0;HEAP32[$58+16>>2]=0|0;HEAP32[$58+20>>2]=0|0;HEAP32[$58+24>>2]=0|0;HEAP32[$58+28>>2]=0|0;
 $60 = HEAP32[$2>>2]|0;
 $61 = (($60) + 1)|0;
 HEAP32[$2>>2] = $61;
 STACKTOP = sp;return;
}
function __ZN20dynamic_block_vectorI14FileIdentifierE8pop_backEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + -1)|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($5>>>0) / ($6>>>0))&-1;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($5>>>0) % ($6>>>0))&-1;
 $13 = HEAP32[$11>>2]|0;
 $14 = (($13) + ($12<<5)|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 do {
  if ($17) {
   $25 = $4;$27 = $6;
  } else {
   $18 = ((($13) + ($12<<5)|0) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($19|0),($$byval_copy2|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    ___cxa_call_unexpected(($22|0));
    // unreachable;
   } else {
    $$pre = HEAP32[$3>>2]|0;
    $$pre3 = HEAP32[$this>>2]|0;
    $25 = $$pre;$27 = $$pre3;
    break;
   }
  }
 } while(0);
 $24 = (($25) + -1)|0;
 HEAP32[$3>>2] = $24;
 $26 = (($24>>>0) / ($27>>>0))&-1;
 $28 = (($26) + 1)|0;
 $29 = (($this) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($28>>>0)<($30>>>0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = (($30) + -1)|0;
 $33 = HEAP32[$8>>2]|0;
 $34 = (($33) + ($32<<2)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($this) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($35|0)==(0|0);
 if (!($38)) {
  $39 = (($35) + 12|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)>(-1);
  if ($41) {
   $42 = HEAP32[$35>>2]|0;
   $43 = (($35) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   HEAP32[$1>>2] = $44;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($42,$$byval_copy2);
   HEAP32[$35>>2] = 0;
  }
 }
 HEAP32[$2>>2] = $37;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($35,$$byval_copy2);
 $45 = HEAP32[$29>>2]|0;
 $46 = (($45) + -1)|0;
 $47 = HEAP32[$8>>2]|0;
 $48 = (($47) + ($46<<2)|0);
 HEAP32[$48>>2] = 0;
 HEAP32[$29>>2] = $46;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_4pairIxN14SerializedFile10ObjectInfoEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 24)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(178956970);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 24)&-1;
 $14 = ($13>>>0)<(89478485);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 178956970;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*24)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*24)|0)|0);
 $23 = (($22) + (($$0$i3*24)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  ;HEAP32[$21+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$21+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$21+20>>2]=HEAP32[$__x+20>>2]|0;
 }
 $25 = (($22) + (($7*24)|0)|0);
 $26 = (($5|0) / -24)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*24)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN14SerializedFile4Type8ReadTypeILb0EEEbibiRPKhS3_($this,$version,$enableTypeTree,$typeID,$iterator,$end) {
 $this = $this|0;
 $version = $version|0;
 $enableTypeTree = $enableTypeTree|0;
 $typeID = $typeID|0;
 $iterator = $iterator|0;
 $end = $end|0;
 var $$0 = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($typeID|0)<(0);
 if ($2) {
  $3 = HEAP32[$iterator>>2]|0;
  $4 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8)|(HEAPU8[$3+2>>0]<<16)|(HEAPU8[$3+3>>0]<<24);
  HEAP8[$this>>0]=$4&255;HEAP8[$this+1>>0]=($4>>8)&255;HEAP8[$this+2>>0]=($4>>16)&255;HEAP8[$this+3>>0]=$4>>24;
  $5 = HEAP32[$iterator>>2]|0;
  $6 = (($5) + 4|0);
  HEAP32[$iterator>>2] = $6;
  $7 = (($this) + 4|0);
  $8 = HEAPU8[$6>>0]|(HEAPU8[$6+1>>0]<<8)|(HEAPU8[$6+2>>0]<<16)|(HEAPU8[$6+3>>0]<<24);
  HEAP8[$7>>0]=$8&255;HEAP8[$7+1>>0]=($8>>8)&255;HEAP8[$7+2>>0]=($8>>16)&255;HEAP8[$7+3>>0]=$8>>24;
  $9 = HEAP32[$iterator>>2]|0;
  $10 = (($9) + 4|0);
  HEAP32[$iterator>>2] = $10;
  $11 = (($this) + 8|0);
  $12 = HEAPU8[$10>>0]|(HEAPU8[$10+1>>0]<<8)|(HEAPU8[$10+2>>0]<<16)|(HEAPU8[$10+3>>0]<<24);
  HEAP8[$11>>0]=$12&255;HEAP8[$11+1>>0]=($12>>8)&255;HEAP8[$11+2>>0]=($12>>16)&255;HEAP8[$11+3>>0]=$12>>24;
  $13 = HEAP32[$iterator>>2]|0;
  $14 = (($13) + 4|0);
  HEAP32[$iterator>>2] = $14;
  $15 = (($this) + 12|0);
  $16 = HEAPU8[$14>>0]|(HEAPU8[$14+1>>0]<<8)|(HEAPU8[$14+2>>0]<<16)|(HEAPU8[$14+3>>0]<<24);
  HEAP8[$15>>0]=$16&255;HEAP8[$15+1>>0]=($16>>8)&255;HEAP8[$15+2>>0]=($16>>16)&255;HEAP8[$15+3>>0]=$16>>24;
  $17 = HEAP32[$iterator>>2]|0;
  $18 = (($17) + 4|0);
  HEAP32[$iterator>>2] = $18;
  $21 = $18;
 } else {
  $$pre = HEAP32[$iterator>>2]|0;
  $21 = $$pre;
 }
 $19 = (($this) + 16|0);
 $20 = HEAPU8[$21>>0]|(HEAPU8[$21+1>>0]<<8)|(HEAPU8[$21+2>>0]<<16)|(HEAPU8[$21+3>>0]<<24);
 HEAP8[$19>>0]=$20&255;HEAP8[$19+1>>0]=($20>>8)&255;HEAP8[$19+2>>0]=($20>>16)&255;HEAP8[$19+3>>0]=$20>>24;
 $22 = HEAP32[$iterator>>2]|0;
 $23 = (($22) + 4|0);
 HEAP32[$iterator>>2] = $23;
 $24 = (($19) + 4|0);
 $25 = HEAPU8[$23>>0]|(HEAPU8[$23+1>>0]<<8)|(HEAPU8[$23+2>>0]<<16)|(HEAPU8[$23+3>>0]<<24);
 HEAP8[$24>>0]=$25&255;HEAP8[$24+1>>0]=($25>>8)&255;HEAP8[$24+2>>0]=($25>>16)&255;HEAP8[$24+3>>0]=$25>>24;
 $26 = HEAP32[$iterator>>2]|0;
 $27 = (($26) + 4|0);
 HEAP32[$iterator>>2] = $27;
 $28 = (($this) + 24|0);
 $29 = HEAPU8[$27>>0]|(HEAPU8[$27+1>>0]<<8)|(HEAPU8[$27+2>>0]<<16)|(HEAPU8[$27+3>>0]<<24);
 HEAP8[$28>>0]=$29&255;HEAP8[$28+1>>0]=($29>>8)&255;HEAP8[$28+2>>0]=($29>>16)&255;HEAP8[$28+3>>0]=$29>>24;
 $30 = HEAP32[$iterator>>2]|0;
 $31 = (($30) + 4|0);
 HEAP32[$iterator>>2] = $31;
 $32 = (($19) + 12|0);
 $33 = HEAPU8[$31>>0]|(HEAPU8[$31+1>>0]<<8)|(HEAPU8[$31+2>>0]<<16)|(HEAPU8[$31+3>>0]<<24);
 HEAP8[$32>>0]=$33&255;HEAP8[$32+1>>0]=($33>>8)&255;HEAP8[$32+2>>0]=($33>>16)&255;HEAP8[$32+3>>0]=$33>>24;
 $34 = HEAP32[$iterator>>2]|0;
 $35 = (($34) + 4|0);
 HEAP32[$iterator>>2] = $35;
 if (!($enableTypeTree)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = HEAP32[628488>>2]|0;
 HEAP32[$1>>2] = $36;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $37 = (__Znwj10MemLabelIdbiPKci(48,$$byval_copy2,0,16,639432,195)|0);
 __THREW__ = 0;
 invoke_vi(3568,($37|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viiiiii(97,($37|0),($$byval_copy2|0),0,16,(639432|0),195);
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $48 = ___cxa_find_matching_catch(0|0)|0;
   $49 = tempRet0;
   ___clang_call_terminate($48);
   // unreachable;
  } else {
   ___resumeException($43|0);
   // unreachable;
  }
 }
 $40 = (__Z12ReadTypeTreeR8TypeTreeRPKhS2_ib($37,$iterator,$end,$version,0)|0);
 if ($40) {
  $47 = (($this) + 36|0);
  HEAP32[$47>>2] = $37;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = HEAP32[628488>>2]|0;
 $42 = ($37|0)==(0|0);
 if (!($42)) {
  __ZN8TypeTreeD2Ev($37);
 }
 HEAP32[$0>>2] = $41;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy2);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20dynamic_block_vectorI14FileIdentifierE5clearEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$08 = 0, $i1$04 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 L1: do {
  if (!($5)) {
   $6 = (($this) + 12|0);
   $54 = $4;$i$08 = 0;
   while(1) {
    $12 = HEAP32[$this>>2]|0;
    $13 = (($i$08>>>0) / ($12>>>0))&-1;
    $14 = HEAP32[$6>>2]|0;
    $15 = (($14) + ($13<<2)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($i$08>>>0) % ($12>>>0))&-1;
    $18 = HEAP32[$16>>2]|0;
    $19 = (($18) + ($17<<5)|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $31 = $54;
    } else {
     $23 = ((($18) + ($17<<5)|0) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($24|0),($$byval_copy3|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $$pre = HEAP32[$3>>2]|0;
     $31 = $$pre;
    }
    $29 = (($i$08) + 1)|0;
    $30 = ($29>>>0)<($31>>>0);
    if ($30) {
     $54 = $31;$i$08 = $29;
    } else {
     break L1;
    }
   }
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   ___cxa_call_unexpected(($27|0));
   // unreachable;
  }
 } while(0);
 $7 = (($this) + 12|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (($this) + 8|0);
  $i1$04 = 0;
  while(1) {
   $32 = HEAP32[$7>>2]|0;
   $33 = (($32) + ($i1$04<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$11>>2]|0;
   $36 = ($34|0)==(0|0);
   if (!($36)) {
    $37 = (($34) + 12|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)>(-1);
    if ($39) {
     $40 = HEAP32[$34>>2]|0;
     $41 = (($34) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     HEAP32[$0>>2] = $42;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($40,$$byval_copy3);
     HEAP32[$34>>2] = 0;
    }
   }
   HEAP32[$1>>2] = $35;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($34,$$byval_copy3);
   $43 = HEAP32[$7>>2]|0;
   $44 = (($43) + ($i1$04<<2)|0);
   HEAP32[$44>>2] = 0;
   $45 = (($i1$04) + 1)|0;
   $46 = HEAP32[$8>>2]|0;
   $47 = ($45>>>0)<($46>>>0);
   if ($47) {
    $i1$04 = $45;
   } else {
    break;
   }
  }
 }
 $48 = (($this) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)>(-1);
 if (!($50)) {
  HEAP32[$8>>2] = 0;
  HEAP32[$48>>2] = 0;
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 }
 $51 = HEAP32[$7>>2]|0;
 $52 = (($this) + 16|0);
 $53 = HEAP32[$52>>2]|0;
 HEAP32[$0>>2] = $53;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($51,$$byval_copy3);
 HEAP32[$7>>2] = 0;
 HEAP32[$8>>2] = 0;
 HEAP32[$48>>2] = 0;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIiN14SerializedFile4TypeEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN14SerializedFile4TypeEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN14SerializedFile4TypeEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$4);
 $5 = (($__nd) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[628488>>2]|0;
 $8 = ($6|0)==(0|0);
 if (!($8)) {
  __THREW__ = 0;
  invoke_vi(3569,($6|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 HEAP32[$0>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($6|0),($$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_call_unexpected(($13|0));
  // unreachable;
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __Z31FindAttributeInTypeTreeNoArraysRK16TypeTreeIteratorPKc($agg$result,$type,$path) {
 $agg$result = $agg$result|0;
 $type = $type|0;
 $path = $path|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $i = sp + 8|0;
 $0 = sp;
 $1 = (__Z21FindTypeTreeSeperatorPKc($path)|0);
 __ZNK16TypeTreeIterator8ChildrenEv($i,$type);
 $2 = HEAP32[$i>>2]|0;
 $3 = ($2|0)==(0|0);
 L1: do {
  if (!($3)) {
   while(1) {
    $4 = (__ZNK16TypeTreeIterator4NameEv($i)|0);
    $5 = (_strncmp($4,$path,$1)|0);
    $6 = ($5|0)==(0);
    if ($6) {
     $7 = (__ZNK16TypeTreeIterator4NameEv($i)|0);
     $8 = (($7) + ($1)|0);
     $9 = HEAP8[$8>>0]|0;
     $10 = ($9<<24>>24)==(0);
     if ($10) {
      break;
     }
    }
    __ZNK16TypeTreeIterator4NextEv($0,$i);
    $25 = $0;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 4)|0;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = $i;
    $32 = $31;
    HEAP32[$32>>2] = $27;
    $33 = (($31) + 4)|0;
    $34 = $33;
    HEAP32[$34>>2] = $30;
    $35 = ($27|0)==(0);
    if ($35) {
     break L1;
    }
   }
   $11 = (($path) + ($1)|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    $14 = $i;
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + 4)|0;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = $agg$result;
    $21 = $20;
    HEAP32[$21>>2] = $16;
    $22 = (($20) + 4)|0;
    $23 = $22;
    HEAP32[$23>>2] = $19;
    STACKTOP = sp;return;
   } else {
    $$sum = (($1) + 1)|0;
    $24 = (($path) + ($$sum)|0);
    __Z31FindAttributeInTypeTreeNoArraysRK16TypeTreeIteratorPKc($agg$result,$i,$24);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 HEAP32[$agg$result>>2] = 0;
 $36 = (($agg$result) + 4|0);
 HEAP32[$36>>2] = 0;
 STACKTOP = sp;return;
}
function __Z16GenerateTypeTreeR6ObjectP8TypeTree24TransferInstructionFlags($object,$typeTree,$options) {
 $object = $object|0;
 $typeTree = $typeTree|0;
 $options = $options|0;
 var $$0$i = 0, $$01$i = 0, $$01$i11 = 0, $$byval_copy20 = 0, $$idx = 0, $$idx26 = 0, $$mask = 0, $$pre$i = 0, $$pre$i19 = 0, $$pre$i23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy20 = sp + 88|0;
 $0 = sp + 84|0;
 $1 = sp + 80|0;
 $2 = sp + 76|0;
 $3 = sp + 72|0;
 $4 = sp + 68|0;
 $5 = sp + 64|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = sp + 16|0;
 __ZN8TypeTreeC2Ev($10);
 $11 = ($10|0)==($typeTree|0);
 L1: do {
  if (!($11)) {
   $12 = HEAP32[$10>>2]|0;
   $13 = (($10) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $$idx = ($14*24)|0;
   $15 = (($$idx|0) / 24)&-1;
   $16 = (($typeTree) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = (($typeTree) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = $18 & 2147483647;
   $20 = ($19>>>0)<($15>>>0);
   do {
    if ($20) {
     $21 = ($18|0)>(-1);
     if ($21) {
      HEAP32[$17>>2] = $15;
      $22 = HEAP32[$typeTree>>2]|0;
      $23 = (($typeTree) + 4|0);
      $24 = HEAP32[$23>>2]|0;
      HEAP32[$2>>2] = $24;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$2+0>>2]|0;
      $25 = (invoke_iiiiiiii(108,($22|0),($$idx|0),4,($$byval_copy20|0),0,(640168|0),370)|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      HEAP32[$typeTree>>2] = $25;
      $38 = $25;
      label = 9;
      break;
     } else {
      $28 = (($typeTree) + 4|0);
      $29 = HEAP32[$28>>2]|0;
      HEAP32[$3>>2] = $29;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$3+0>>2]|0;
      $30 = (invoke_iiiiiii(102,($$idx|0),4,($$byval_copy20|0),0,(640168|0),352)|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      $33 = HEAP32[$typeTree>>2]|0;
      $34 = HEAP32[$16>>2]|0;
      $35 = ($34*24)|0;
      _memcpy(($30|0),($33|0),($35|0))|0;
      HEAP32[$17>>2] = $15;
      HEAP32[$typeTree>>2] = $30;
      $38 = $30;
      label = 9;
      break;
     }
    } else {
     $$pre$i19 = HEAP32[$typeTree>>2]|0;
     $38 = $$pre$i19;
     label = 9;
    }
   } while(0);
   L11: do {
    if ((label|0) == 9) {
     $36 = HEAP32[$16>>2]|0;
     $37 = ($36*24)|0;
     _memcpy(($38|0),($12|0),($37|0))|0;
     $39 = (($typeTree) + 16|0);
     $40 = (($10) + 16|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($10) + 24|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($typeTree) + 24|0);
     HEAP32[$44>>2] = $43;
     $45 = (($typeTree) + 28|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = $46 & 2147483647;
     $48 = ($47>>>0)<($43>>>0);
     do {
      if ($48) {
       $49 = ($46|0)>(-1);
       if ($49) {
        HEAP32[$45>>2] = $43;
        $50 = HEAP32[$39>>2]|0;
        $51 = (($typeTree) + 20|0);
        $52 = HEAP32[$51>>2]|0;
        HEAP32[$0>>2] = $52;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
        $53 = (invoke_iiiiiiii(108,($50|0),($43|0),1,($$byval_copy20|0),0,(640168|0),370)|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         break L11;
        }
        HEAP32[$39>>2] = $53;
        $64 = $53;
        break;
       } else {
        $56 = (($typeTree) + 20|0);
        $57 = HEAP32[$56>>2]|0;
        HEAP32[$1>>2] = $57;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$1+0>>2]|0;
        $58 = (invoke_iiiiiii(102,($43|0),1,($$byval_copy20|0),0,(640168|0),352)|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break L11;
        }
        $61 = HEAP32[$39>>2]|0;
        $62 = HEAP32[$44>>2]|0;
        _memcpy(($58|0),($61|0),($62|0))|0;
        HEAP32[$45>>2] = $43;
        HEAP32[$39>>2] = $58;
        $64 = $58;
        break;
       }
      } else {
       $$pre$i23 = HEAP32[$39>>2]|0;
       $64 = $$pre$i23;
      }
     } while(0);
     $63 = HEAP32[$44>>2]|0;
     _memcpy(($64|0),($41|0),($63|0))|0;
     $65 = (($typeTree) + 32|0);
     $66 = (($10) + 32|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($10) + 40|0);
     $69 = HEAP32[$68>>2]|0;
     $$idx26 = $69 << 2;
     $70 = $$idx26 >> 2;
     $71 = (($typeTree) + 40|0);
     HEAP32[$71>>2] = $70;
     $72 = (($typeTree) + 44|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = $73 & 2147483647;
     $75 = ($74>>>0)<($70>>>0);
     do {
      if ($75) {
       $76 = ($73|0)>(-1);
       if ($76) {
        HEAP32[$72>>2] = $70;
        $77 = HEAP32[$65>>2]|0;
        $78 = (($typeTree) + 36|0);
        $79 = HEAP32[$78>>2]|0;
        HEAP32[$8>>2] = $79;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$8+0>>2]|0;
        $80 = (invoke_iiiiiiii(108,($77|0),($$idx26|0),4,($$byval_copy20|0),0,(640168|0),370)|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         break L11;
        }
        HEAP32[$65>>2] = $80;
        $93 = $80;
        break;
       } else {
        $83 = (($typeTree) + 36|0);
        $84 = HEAP32[$83>>2]|0;
        HEAP32[$9>>2] = $84;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$9+0>>2]|0;
        $85 = (invoke_iiiiiii(102,($$idx26|0),4,($$byval_copy20|0),0,(640168|0),352)|0);
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         break L11;
        }
        $88 = HEAP32[$65>>2]|0;
        $89 = HEAP32[$71>>2]|0;
        $90 = $89 << 2;
        _memcpy(($85|0),($88|0),($90|0))|0;
        HEAP32[$72>>2] = $70;
        HEAP32[$65>>2] = $85;
        $93 = $85;
        break;
       }
      } else {
       $$pre$i = HEAP32[$65>>2]|0;
       $93 = $$pre$i;
      }
     } while(0);
     $91 = HEAP32[$71>>2]|0;
     $92 = $91 << 2;
     _memcpy(($93|0),($67|0),($92|0))|0;
     break L1;
    }
   } while(0);
   $155 = ___cxa_find_matching_catch()|0;
   $156 = tempRet0;
   $157 = (($10) + 44|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = ($158|0)>(-1);
   do {
    if ($159) {
     $160 = (($10) + 32|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = (($10) + 36|0);
     $163 = HEAP32[$162>>2]|0;
     HEAP32[$7>>2] = $163;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$7+0>>2]|0;
     invoke_vii(2591,($161|0),($$byval_copy20|0));
     $164 = __THREW__; __THREW__ = 0;
     $165 = $164&1;
     if (!($165)) {
      HEAP32[$160>>2] = 0;
      label = 48;
      break;
     }
     $183 = ___cxa_find_matching_catch(0|0)|0;
     $184 = tempRet0;
     $185 = (($10) + 28|0);
     $186 = HEAP32[$185>>2]|0;
     $187 = ($186|0)>(-1);
     if ($187) {
      $188 = (($10) + 16|0);
      $189 = HEAP32[$188>>2]|0;
      $190 = (($10) + 20|0);
      $191 = HEAP32[$190>>2]|0;
      HEAP32[$5>>2] = $191;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_vii(2591,($189|0),($$byval_copy20|0));
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if ($193) {
       $204 = ___cxa_find_matching_catch(0|0)|0;
       $205 = tempRet0;
       ___clang_call_terminate($204);
       // unreachable;
      } else {
       HEAP32[$188>>2] = 0;
       $$01$i11 = $183;
       break;
      }
     } else {
      $$01$i11 = $183;
     }
    } else {
     label = 48;
    }
   } while(0);
   L41: do {
    if ((label|0) == 48) {
     $166 = (($10) + 28|0);
     $167 = HEAP32[$166>>2]|0;
     $168 = ($167|0)>(-1);
     do {
      if ($168) {
       $169 = (($10) + 16|0);
       $170 = HEAP32[$169>>2]|0;
       $171 = (($10) + 20|0);
       $172 = HEAP32[$171>>2]|0;
       HEAP32[$6>>2] = $172;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$6+0>>2]|0;
       invoke_vii(2591,($170|0),($$byval_copy20|0));
       $173 = __THREW__; __THREW__ = 0;
       $174 = $173&1;
       if ($174) {
        $194 = ___cxa_find_matching_catch(0|0)|0;
        $195 = tempRet0;
        $$01$i11 = $194;
        break L41;
       } else {
        HEAP32[$169>>2] = 0;
        break;
       }
      }
     } while(0);
     $175 = (($10) + 12|0);
     $176 = HEAP32[$175>>2]|0;
     $177 = ($176|0)>(-1);
     if (!($177)) {
      ___resumeException($155|0);
      // unreachable;
     }
     $178 = HEAP32[$10>>2]|0;
     $179 = (($10) + 4|0);
     $180 = HEAP32[$179>>2]|0;
     HEAP32[$4>>2] = $180;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($178|0),($$byval_copy20|0));
     $181 = __THREW__; __THREW__ = 0;
     $182 = $181&1;
     if ($182) {
      $209 = ___cxa_find_matching_catch(0|0)|0;
      $210 = tempRet0;
      $eh$lpad$body$indexZ2D = $209;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     } else {
      HEAP32[$10>>2] = 0;
      ___resumeException($155|0);
      // unreachable;
     }
    }
   } while(0);
   $196 = (($10) + 12|0);
   $197 = HEAP32[$196>>2]|0;
   $198 = ($197|0)>(-1);
   do {
    if ($198) {
     $199 = HEAP32[$10>>2]|0;
     $200 = (($10) + 4|0);
     $201 = HEAP32[$200>>2]|0;
     HEAP32[$4>>2] = $201;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($199|0),($$byval_copy20|0));
     $202 = __THREW__; __THREW__ = 0;
     $203 = $202&1;
     if ($203) {
      $204 = ___cxa_find_matching_catch(0|0)|0;
      $205 = tempRet0;
      ___clang_call_terminate($204);
      // unreachable;
     } else {
      HEAP32[$10>>2] = 0;
      break;
     }
    }
   } while(0);
   $eh$lpad$body$indexZ2D = $$01$i11;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 $94 = (($10) + 44|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)>(-1);
 do {
  if ($96) {
   $97 = (($10) + 32|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($10) + 36|0);
   $100 = HEAP32[$99>>2]|0;
   HEAP32[$3>>2] = $100;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($98|0),($$byval_copy20|0));
   $101 = __THREW__; __THREW__ = 0;
   $102 = $101&1;
   if (!($102)) {
    HEAP32[$97>>2] = 0;
    label = 27;
    break;
   }
   $118 = ___cxa_find_matching_catch()|0;
   $119 = tempRet0;
   $120 = (($10) + 28|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($121|0)>(-1);
   if ($122) {
    $123 = (($10) + 16|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (($10) + 20|0);
    $126 = HEAP32[$125>>2]|0;
    HEAP32[$1>>2] = $126;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($124|0),($$byval_copy20|0));
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     $139 = ___cxa_find_matching_catch(0|0)|0;
     $140 = tempRet0;
     ___clang_call_terminate($139);
     // unreachable;
    } else {
     HEAP32[$123>>2] = 0;
     $$0$i = $119;$$01$i = $118;
     break;
    }
   } else {
    $$0$i = $119;$$01$i = $118;
   }
  } else {
   label = 27;
  }
 } while(0);
 L75: do {
  if ((label|0) == 27) {
   $103 = (($10) + 28|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = ($104|0)>(-1);
   do {
    if ($105) {
     $106 = (($10) + 16|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = (($10) + 20|0);
     $109 = HEAP32[$108>>2]|0;
     HEAP32[$2>>2] = $109;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($107|0),($$byval_copy20|0));
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if ($111) {
      $129 = ___cxa_find_matching_catch()|0;
      $130 = tempRet0;
      $$0$i = $130;$$01$i = $129;
      break L75;
     } else {
      HEAP32[$106>>2] = 0;
      break;
     }
    }
   } while(0);
   $112 = (($10) + 12|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)>(-1);
   if ($114) {
    $115 = HEAP32[$10>>2]|0;
    $116 = (($10) + 4|0);
    $117 = HEAP32[$116>>2]|0;
    HEAP32[$0>>2] = $117;
    ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($115,$$byval_copy20);
    HEAP32[$10>>2] = 0;
   }
   $141 = (($object) + 8|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = $142 >>> 21;
   $144 = (__ZN6Object13ClassIDToRTTIEi($143)|0);
   $145 = (($144) + 24|0);
   $146 = HEAP32[$145>>2]|0;
   __ZN13ProxyTransferC2ER8TypeTree24TransferInstructionFlagsPvi($$byval_copy20,$typeTree,$options,$object,$146);
   $147 = HEAP32[$141>>2]|0;
   $$mask = $147 & -2097152;
   $148 = ($$mask|0)==(239075328);
   if (!($148)) {
    $206 = HEAP32[$object>>2]|0;
    $207 = (($206) + 76|0);
    $208 = HEAP32[$207>>2]|0;
    FUNCTION_TABLE_vii[$208 & 4095]($object,$$byval_copy20);
    STACKTOP = sp;return;
   }
   $149 = (($object) + 20|0);
   $150 = HEAP32[$149>>2]|0;
   $151 = ($150|0)==(0|0);
   if ($151) {
    $154 = 0;
   } else {
    $152 = (__Z26scripting_object_get_classP15ScriptingObject($150)|0);
    $153 = (__Z29scripting_class_instance_sizeP14ScriptingClass($152)|0);
    $154 = $153;
   }
   __ZN13ProxyTransfer18SetScriptingObjectEPvi($$byval_copy20,$150,$154);
   $206 = HEAP32[$object>>2]|0;
   $207 = (($206) + 76|0);
   $208 = HEAP32[$207>>2]|0;
   FUNCTION_TABLE_vii[$208 & 4095]($object,$$byval_copy20);
   STACKTOP = sp;return;
  }
 } while(0);
 $131 = (($10) + 12|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($132|0)>(-1);
 if (!($133)) {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 $134 = HEAP32[$10>>2]|0;
 $135 = (($10) + 4|0);
 $136 = HEAP32[$135>>2]|0;
 HEAP32[$0>>2] = $136;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy20+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($134|0),($$byval_copy20|0));
 $137 = __THREW__; __THREW__ = 0;
 $138 = $137&1;
 if ($138) {
  $139 = ___cxa_find_matching_catch(0|0)|0;
  $140 = tempRet0;
  ___clang_call_terminate($139);
  // unreachable;
 }
 HEAP32[$10>>2] = 0;
 ___resumeException($$01$i|0);
 // unreachable;
}
function __Z10ReadStringR8UnityStrRPKhS2_($s,$iterator,$end) {
 $s = $s|0;
 $iterator = $iterator|0;
 $end = $end|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$iterator>>2]|0;
 $1 = ($0>>>0)<($end>>>0);
 L1: do {
  if ($1) {
   $3 = $0;
   while(1) {
    $2 = HEAP8[$3>>0]|0;
    $4 = ($2<<24>>24)==(0);
    if ($4) {
     $7 = $3;
     break L1;
    }
    $5 = (($3) + 1|0);
    HEAP32[$iterator>>2] = $5;
    $6 = ($5>>>0)<($end>>>0);
    if ($6) {
     $3 = $5;
    } else {
     $7 = $5;
     break;
    }
   }
  } else {
   $7 = $0;
  }
 } while(0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6assignIPKhEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS6_E4typeESB_SB_($s,$0,$7)|0);
 $8 = HEAP32[$iterator>>2]|0;
 $9 = (($8) + 1|0);
 HEAP32[$iterator>>2] = $9;
 STACKTOP = sp;return 1;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6assignIPKhEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS6_E4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p$0$lcssa = 0, $__p$0$ph = 0, $__p$02 = 0, $phitmp$i = 0, $scevgep = 0, $scevgep3 = 0, $scevgep4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__first;
 $1 = $__last;
 $2 = (($1) - ($0))|0;
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $10 = 10;$12 = $3;
 } else {
  $6 = HEAP32[$this>>2]|0;
  $7 = $6 & -2;
  $phitmp$i = (($7) + -1)|0;
  $8 = $6&255;
  $10 = $phitmp$i;$12 = $8;
 }
 $9 = ($10>>>0)<($2>>>0);
 if ($9) {
  $11 = $12 & 1;
  $13 = ($11<<24>>24)==(0);
  if ($13) {
   $16 = $12&255;
   $17 = $16 >>> 1;
   $19 = $17;
  } else {
   $14 = (($this) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $19 = $15;
  }
  $18 = (($2) - ($10))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE9__grow_byEjjjjjj($this,$10,$18,$19,0,$19,0);
  $$pre = HEAP8[$this>>0]|0;
  $21 = $$pre;
 } else {
  $21 = $12;
 }
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($22) {
  $25 = (($this) + 1|0);
  $__p$0$ph = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $__p$0$ph = $24;
 }
 $26 = ($__first|0)==($__last|0);
 if ($26) {
  $__p$0$lcssa = $__p$0$ph;
 } else {
  $27 = (0 - ($0))|0;
  $scevgep = (($__last) + ($27)|0);
  $scevgep3 = $scevgep;
  $$01 = $__first;$__p$02 = $__p$0$ph;
  while(1) {
   $28 = HEAP8[$$01>>0]|0;
   HEAP8[$__p$02>>0] = $28;
   $29 = (($$01) + 1|0);
   $30 = (($__p$02) + 1|0);
   $31 = ($29|0)==($__last|0);
   if ($31) {
    break;
   } else {
    $$01 = $29;$__p$02 = $30;
   }
  }
  $scevgep4 = (($__p$0$ph) + ($scevgep3)|0);
  $__p$0$lcssa = $scevgep4;
 }
 HEAP8[$__p$0$lcssa>>0] = 0;
 $32 = HEAP8[$this>>0]|0;
 $33 = $32 & 1;
 $34 = ($33<<24>>24)==(0);
 if ($34) {
  $36 = $2 << 1;
  $37 = $36&255;
  HEAP8[$this>>0] = $37;
  STACKTOP = sp;return ($this|0);
 } else {
  $35 = (($this) + 4|0);
  HEAP32[$35>>2] = $2;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __Z12CollectPPtrsR6ObjectPNSt3__13setIiNS1_4lessIiEENS1_9allocatorIiEEEE($object,$collectedPtrs) {
 $object = $object|0;
 $collectedPtrs = $collectedPtrs|0;
 var $0 = 0, $1 = 0, $2 = 0, $collectFunctor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $collectFunctor = sp;
 HEAP32[$collectFunctor>>2] = ((640176 + 8|0));
 $0 = (($collectFunctor) + 4|0);
 HEAP32[$0>>2] = $collectedPtrs;
 $1 = (($object) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 (__ZN18IDCollectorFunctor18GenerateInstanceIDEi17TransferMetaFlags($collectFunctor,$2,64)|0);
 STACKTOP = sp;return;
}
function __ZN18IDCollectorFunctor18GenerateInstanceIDEi17TransferMetaFlags($this,$oldInstanceID,$metaFlag) {
 $this = $this|0;
 $oldInstanceID = $oldInstanceID|0;
 $metaFlag = $metaFlag|0;
 var $$0 = 0, $$0$i12 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i1 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i6 = 0, $transferFunction = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $transferFunction = sp + 12|0;
 HEAP32[$2>>2] = $oldInstanceID;
 $3 = $metaFlag & 64;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = $oldInstanceID;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($oldInstanceID|0)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $oldInstanceID;
 $6 = HEAP32[560624>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  label = 11;
 } else {
  $8 = (($6) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  do {
   if ($12) {
    $13 = (($6) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($6) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + ($16<<3)|0);
    $33 = $17;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$6,$1);
    $18 = HEAP32[$$byval_copy1>>2]|0;
    $19 = ($18|0)==(-1);
    $20 = (($6) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    if ($19) {
     $22 = (($6) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($21) + ($23<<3)|0);
     $33 = $24;
     break;
    } else {
     $25 = (($21) + ($18<<3)|0);
     $33 = $25;
     break;
    }
   }
  } while(0);
  $26 = HEAP32[560624>>2]|0;
  $27 = (($26) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + ($30<<3)|0);
  $32 = ($33|0)==($31|0);
  if ($32) {
   label = 11;
  } else {
   $34 = (($33) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 11;
   } else {
    $$0$i12 = $35;
   }
  }
 }
 if ((label|0) == 11) {
  $37 = (__Z31ReadObjectFromPersistentManageri($oldInstanceID)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   $$0 = $oldInstanceID;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0$i12 = $37;
  }
 }
 $39 = (($this) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 __ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE15__insert_uniqueERKi($$byval_copy1,$40,$2);
 $41 = (($$byval_copy1) + 4|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  $44 = HEAP32[$2>>2]|0;
  $$0 = $44;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN17RemapPPtrTransferC2E24TransferInstructionFlagsb($transferFunction,0,0);
 $45 = (($transferFunction) + 12|0);
 HEAP32[$45>>2] = $this;
 $46 = HEAP32[$$0$i12>>2]|0;
 $47 = (($46) + 72|0);
 $48 = HEAP32[$47>>2]|0;
 __THREW__ = 0;
 invoke_vii($48|0,($$0$i12|0),($transferFunction|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $65 = ___cxa_find_matching_catch()|0;
  $66 = tempRet0;
  $67 = (($transferFunction) + 16|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ($68|0)==(0|0);
  if ($69) {
   ___resumeException($65|0);
   // unreachable;
  }
  $70 = (($transferFunction) + 20|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==($68|0);
  if (!($72)) {
   $__new_last2$i$i$i$i$i$i$i = $68;
   $scevgep$i$i$i$i$i$i$i = (($71) + -4|0);
   $73 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($73)|0);
   $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
   $74 = $uglygep3$i$i$i$i$i$i$i >>> 2;
   $75 = $74 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($71) + ($75<<2)|0);
   HEAP32[$70>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($68|0),($$byval_copy1|0));
  $76 = __THREW__; __THREW__ = 0;
  $77 = $76&1;
  if ($77) {
   $78 = ___cxa_find_matching_catch()|0;
   $79 = tempRet0;
   ___cxa_call_unexpected(($78|0));
   // unreachable;
  } else {
   ___resumeException($65|0);
   // unreachable;
  }
 } else {
  $51 = HEAP32[$2>>2]|0;
  $52 = (($transferFunction) + 16|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $$0 = $51;
   STACKTOP = sp;return ($$0|0);
  }
  $55 = (($transferFunction) + 20|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==($53|0);
  if (!($57)) {
   $__new_last2$i$i$i$i$i$i$i1 = $53;
   $scevgep$i$i$i$i$i$i$i2 = (($56) + -4|0);
   $58 = (0 - ($__new_last2$i$i$i$i$i$i$i1))|0;
   $uglygep$i$i$i$i$i$i$i4 = (($scevgep$i$i$i$i$i$i$i2) + ($58)|0);
   $uglygep3$i$i$i$i$i$i$i5 = $uglygep$i$i$i$i$i$i$i4;
   $59 = $uglygep3$i$i$i$i$i$i$i5 >>> 2;
   $60 = $59 ^ -1;
   $scevgep4$i$i$i$i$i$i$i6 = (($56) + ($60<<2)|0);
   HEAP32[$55>>2] = $scevgep4$i$i$i$i$i$i$i6;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($53|0),($$byval_copy1|0));
  $61 = __THREW__; __THREW__ = 0;
  $62 = $61&1;
  if ($62) {
   $63 = ___cxa_find_matching_catch()|0;
   $64 = tempRet0;
   ___cxa_call_unexpected(($63|0));
   // unreachable;
  } else {
   $$0 = $51;
   STACKTOP = sp;return ($$0|0);
  }
 }
 return 0|0;
}
function __ZN18IDCollectorFunctorD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18IDCollectorFunctorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK16TypeTreeIterator7GetNodeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + (($2*24)|0)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK16TypeTreeIterator4NameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3) + (($2*24)|0)|0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)<(0);
 $9 = HEAP32[580528>>2]|0;
 $10 = $8 ? $9 : $7;
 $11 = $5 & 2147483647;
 $12 = (($10) + ($11)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZNK16TypeTreeIterator4TypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3) + (($2*24)|0)|0) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($0) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)<(0);
 $9 = HEAP32[580528>>2]|0;
 $10 = $8 ? $9 : $7;
 $11 = $5 & 2147483647;
 $12 = (($10) + ($11)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZNK16TypeTreeIterator8ChildrenEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $$sum = (($2) + 1)|0;
 $6 = ($$sum|0)<($5|0);
 if ($6) {
  $7 = ((($3) + (($$sum*24)|0)|0) + 2|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = $8&255;
  $10 = ((($3) + (($2*24)|0)|0) + 2|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = (($12) + 1)|0;
  $14 = ($9|0)==($13|0);
  if ($14) {
   HEAP32[$agg$result>>2] = $0;
   $15 = (($agg$result) + 4|0);
   HEAP32[$15>>2] = $$sum;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$agg$result>>2] = 0;
 $16 = (($agg$result) + 4|0);
 HEAP32[$16>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK16TypeTreeIterator4NextEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + (($2*24)|0)|0);
 $5 = ((($3) + (($2*24)|0)|0) + 2|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = (($0) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($3) + (($8*24)|0)|0);
 $$pn = $4;
 while(1) {
  $p$0 = (($$pn) + 24|0);
  $10 = ($p$0>>>0)<($9>>>0);
  if (!($10)) {
   label = 7;
   break;
  }
  $11 = (($$pn) + 26|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12&255)>($6&255);
  if ($13) {
   $$pn = $p$0;
  } else {
   break;
  }
 }
 if ((label|0) == 7) {
  HEAP32[$agg$result>>2] = 0;
  $21 = (($agg$result) + 4|0);
  HEAP32[$21>>2] = 0;
  STACKTOP = sp;return;
 }
 $14 = ($12<<24>>24)==($6<<24>>24);
 if ($14) {
  $15 = $p$0;
  $16 = $3;
  $17 = (($15) - ($16))|0;
  $18 = (($17|0) / 24)&-1;
  HEAP32[$agg$result>>2] = $0;
  $19 = (($agg$result) + 4|0);
  HEAP32[$19>>2] = $18;
  STACKTOP = sp;return;
 } else {
  HEAP32[$agg$result>>2] = 0;
  $20 = (($agg$result) + 4|0);
  HEAP32[$20>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNK16TypeTreeIterator6FatherEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + (($2*24)|0)|0);
 $5 = ((($3) + (($2*24)|0)|0) + 2|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = (($7) + -1)|0;
 $$pn = $4;
 while(1) {
  $p$0 = (($$pn) + -24|0);
  $9 = ($p$0>>>0)<($3>>>0);
  if ($9) {
   label = 5;
   break;
  }
  $10 = (($$pn) + -22|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = ($12|0)==($8|0);
  if ($13) {
   label = 4;
   break;
  } else {
   $$pn = $p$0;
  }
 }
 if ((label|0) == 4) {
  $14 = $p$0;
  $15 = $3;
  $16 = (($14) - ($15))|0;
  $17 = (($16|0) / 24)&-1;
  HEAP32[$agg$result>>2] = $0;
  $18 = (($agg$result) + 4|0);
  HEAP32[$18>>2] = $17;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 5) {
  HEAP32[$agg$result>>2] = 0;
  $19 = (($agg$result) + 4|0);
  HEAP32[$19>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNK16TypeTreeIterator4LastEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$pn$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $8$phi = 0, $9 = 0, $inttoptr = 0, $p$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $11 = $5;$8 = $2;
 L1: while(1) {
  $6 = $agg$result;
  $7 = $6;
  HEAP32[$7>>2] = $8;
  $9 = (($6) + 4)|0;
  $10 = $9;
  HEAP32[$10>>2] = $11;
  $inttoptr = $8;
  $12 = HEAP32[$inttoptr>>2]|0;
  $13 = (($12) + (($11*24)|0)|0);
  $14 = ((($12) + (($11*24)|0)|0) + 2|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = (($inttoptr) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($12) + (($17*24)|0)|0);
  $$pn$i = $13;
  while(1) {
   $p$0$i = (($$pn$i) + 24|0);
   $19 = ($p$0$i>>>0)<($18>>>0);
   if (!($19)) {
    label = 7;
    break L1;
   }
   $20 = (($$pn$i) + 26|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21&255)>($15&255);
   if ($22) {
    $$pn$i = $p$0$i;
   } else {
    break;
   }
  }
  $23 = ($21<<24>>24)==($15<<24>>24);
  if (!($23)) {
   label = 7;
   break;
  }
  $24 = $p$0$i;
  $25 = $12;
  $26 = (($24) - ($25))|0;
  $27 = (($26|0) / 24)&-1;
  $28 = ($8|0)==(0);
  $29 = (0)==(0);
  $30 = $28 & $29;
  if ($30) {
   label = 7;
   break;
  } else {
   $8$phi = $8;$11 = $27;$8 = $8$phi;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return;
 }
}
function __ZNK16TypeTreeIterator10ByteOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($1>>>0)<($4>>>0);
 if (!($5)) {
  $10 = -1;
  STACKTOP = sp;return ($10|0);
 }
 $6 = (($2) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 STACKTOP = sp;return ($10|0);
}
function __ZN8TypeTreeC2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628488>>2]|0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 1;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = 1;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__Z15malloc_internaljj10MemLabelIdiPKci(24,4,$$byval_copy,0,640264,352)|0);
 HEAP32[$this>>2] = $5;
 $6 = HEAP32[628488>>2]|0;
 $7 = (($this) + 16|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 20|0);
 HEAP32[$8>>2] = $6;
 $9 = (($this) + 24|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 28|0);
 HEAP32[$10>>2] = 0;
 $11 = HEAP32[628488>>2]|0;
 $12 = (($this) + 32|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 36|0);
 HEAP32[$13>>2] = $11;
 $14 = (($this) + 40|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 44|0);
 HEAP32[$15>>2] = 0;
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + -1)|0;
 $18 = ((($5) + (($17*24)|0)|0) + 2|0);
 HEAP8[$18>>0] = 0;
 $19 = ((($5) + (($17*24)|0)|0) + 8|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($5) + (($17*24)|0)|0) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($5) + (($17*24)|0)|0) + 16|0);
 HEAP32[$21>>2] = -1;
 $22 = ((($5) + (($17*24)|0)|0) + 3|0);
 HEAP8[$22>>0] = 0;
 $23 = (($5) + (($17*24)|0)|0);
 HEAP16[$23>>1] = 1;
 $24 = ((($5) + (($17*24)|0)|0) + 20|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($5) + (($17*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN8TypeTree8AddChildERK16TypeTreeIterator($agg$result,$this,$father) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $father = $father|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($father) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN8TypeTree8AddChildEj($this,$1);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[$agg$result>>2] = $this;
 $5 = (($agg$result) + 4|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN8TypeTree8AddChildEj($this,$father) {
 $this = $this|0;
 $father = $father|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = $5 << 1;
  $9 = ($8|0)==(0);
  $10 = $9 ? 1 : $8;
  $11 = ($6>>>0)<($10>>>0);
  do {
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*24)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,640264,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*24)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,640264,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*24)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$1>>2]|0;
  $26 = $$pre$i;
 } else {
  $26 = $3;
 }
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = ((($27) + (($father*24)|0)|0) + 2|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = (($30) + 1)|0;
 $32 = $31&255;
 $33 = ((($27) + (($25*24)|0)|0) + 2|0);
 HEAP8[$33>>0] = $32;
 $34 = ((($27) + (($25*24)|0)|0) + 8|0);
 HEAP32[$34>>2] = 0;
 $35 = ((($27) + (($25*24)|0)|0) + 4|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($27) + (($25*24)|0)|0) + 16|0);
 HEAP32[$36>>2] = -1;
 $37 = ((($27) + (($25*24)|0)|0) + 3|0);
 HEAP8[$37>>0] = 0;
 $38 = (($27) + (($25*24)|0)|0);
 HEAP16[$38>>1] = 1;
 $39 = ((($27) + (($25*24)|0)|0) + 20|0);
 HEAP32[$39>>2] = 0;
 $40 = ((($27) + (($25*24)|0)|0) + 12|0);
 HEAP32[$40>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN8TypeTree16AssignTypeStringERK16TypeTreeIteratorPKc($this,$i,$content) {
 $this = $this|0;
 $i = $i|0;
 $content = $content|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($i) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ((($2) + (($1*24)|0)|0) + 4|0);
 $4 = (($this) + 16|0);
 __ZL12CreateStringPjR13dynamic_arrayIcLj1EEPKc($3,$4,$content);
 STACKTOP = sp;return;
}
function __ZL12CreateStringPjR13dynamic_arrayIcLj1EEPKc($strOffset,$stringBuffer,$content) {
 $strOffset = $strOffset|0;
 $stringBuffer = $stringBuffer|0;
 $content = $content|0;
 var $$byval_copy1 = 0, $$neg1 = 0, $$offs = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (__Z20GetCommonStringTablev()|0);
 $2 = (__ZNK17CommonStringTable16FindCommonStringEPKc($1,$content)|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[580528>>2]|0;
  $5 = $2;
  $6 = $4;
  $7 = (($5) - ($6))|0;
  $8 = $7 | -2147483648;
  HEAP32[$strOffset>>2] = $8;
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$stringBuffer>>2]|0;
 $10 = (($stringBuffer) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + ($11)|0);
 $13 = ($11|0)>(0);
 L5: do {
  if ($13) {
   $p$03 = $9;
   while(1) {
    $14 = (_strcmp($p$03,$content)|0);
    $15 = ($14|0)==(0);
    if ($15) {
     break;
    }
    $19 = (_strlen(($p$03|0))|0);
    $$sum = (($19) + 1)|0;
    $20 = (($p$03) + ($$sum)|0);
    $21 = ($20>>>0)<($12>>>0);
    if ($21) {
     $p$03 = $20;
    } else {
     break L5;
    }
   }
   $16 = $p$03;
   $17 = $9;
   $18 = (($16) - ($17))|0;
   HEAP32[$strOffset>>2] = $18;
   STACKTOP = sp;return;
  }
 } while(0);
 $22 = (_strlen(($content|0))|0);
 $$offs = (($22) + 1)|0;
 $23 = (($11) + ($$offs))|0;
 HEAP32[$10>>2] = $23;
 $24 = (($stringBuffer) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($26>>>0)<($23>>>0);
 do {
  if ($27) {
   $28 = ($25|0)>(-1);
   if ($28) {
    HEAP32[$24>>2] = $23;
    $29 = (($stringBuffer) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    HEAP32[$0>>2] = $30;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $31 = (__Z16realloc_internalPvji10MemLabelIdiPKci($9,$23,1,$$byval_copy1,0,640264,370)|0);
    HEAP32[$stringBuffer>>2] = $31;
    $38 = $31;
    break;
   } else {
    $32 = (($stringBuffer) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    HEAP32[$0>>2] = $33;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $34 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,1,$$byval_copy1,0,640264,352)|0);
    $35 = HEAP32[$stringBuffer>>2]|0;
    $36 = HEAP32[$10>>2]|0;
    _memcpy(($34|0),($35|0),($36|0))|0;
    HEAP32[$24>>2] = $23;
    HEAP32[$stringBuffer>>2] = $34;
    $38 = $34;
    break;
   }
  } else {
   $38 = $9;
  }
 } while(0);
 $37 = (($38) + ($11)|0);
 _memcpy(($37|0),($content|0),($$offs|0))|0;
 $39 = HEAP32[$10>>2]|0;
 $$neg1 = $22 ^ -1;
 $40 = (($39) + ($$neg1))|0;
 HEAP32[$strOffset>>2] = $40;
 STACKTOP = sp;return;
}
function __ZN8TypeTree16AssignNameStringERK16TypeTreeIteratorPKc($this,$i,$content) {
 $this = $this|0;
 $i = $i|0;
 $content = $content|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($i) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ((($2) + (($1*24)|0)|0) + 8|0);
 $4 = (($this) + 16|0);
 __ZL12CreateStringPjR13dynamic_arrayIcLj1EEPKc($3,$4,$content);
 STACKTOP = sp;return;
}
function __ZN8TypeTree16AssignByteOffsetERK16TypeTreeIteratorj($this,$i,$offset) {
 $this = $this|0;
 $i = $i|0;
 $offset = $offset|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$size$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($i) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 32|0);
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($2>>>0)<($5>>>0);
 if ($6) {
  $39 = $2;
  $37 = HEAP32[$3>>2]|0;
  $38 = (($37) + ($39<<2)|0);
  HEAP32[$38>>2] = $offset;
  STACKTOP = sp;return;
 }
 $7 = (($2) + 1)|0;
 $8 = (($this) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($10>>>0)<($7>>>0);
 do {
  if ($11) {
   $12 = $9 << 1;
   $13 = ($12>>>0)>($7>>>0);
   $$size$i = $13 ? $12 : $7;
   $14 = ($10>>>0)<($$size$i>>>0);
   if ($14) {
    $15 = ($9|0)>(-1);
    if ($15) {
     HEAP32[$8>>2] = $$size$i;
     $16 = HEAP32[$3>>2]|0;
     $17 = $$size$i << 2;
     $18 = (($this) + 36|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$0>>2] = $19;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($16,$17,4,$$byval_copy1,0,640264,370)|0);
     HEAP32[$3>>2] = $20;
     break;
    } else {
     $21 = $$size$i << 2;
     $22 = (($this) + 36|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,4,$$byval_copy1,0,640264,352)|0);
     $25 = HEAP32[$3>>2]|0;
     $26 = HEAP32[$4>>2]|0;
     $27 = $26 << 2;
     _memcpy(($24|0),($25|0),($27|0))|0;
     HEAP32[$8>>2] = $$size$i;
     HEAP32[$3>>2] = $24;
     break;
    }
   }
  }
 } while(0);
 $28 = HEAP32[$4>>2]|0;
 $29 = ($28>>>0)<($7>>>0);
 if ($29) {
  $30 = HEAP32[$3>>2]|0;
  $31 = (($30) + ($7<<2)|0);
  $32 = ($28|0)==($7|0);
  if (!($32)) {
   $33 = (($30) + ($28<<2)|0);
   $$01$i$i = $33;
   while(1) {
    $34 = ($$01$i$i|0)==(0|0);
    if (!($34)) {
     HEAP32[$$01$i$i>>2] = -1;
    }
    $35 = (($$01$i$i) + 4|0);
    $36 = ($35|0)==($31|0);
    if ($36) {
     break;
    } else {
     $$01$i$i = $35;
    }
   }
  }
 }
 HEAP32[$4>>2] = $7;
 $$pre = HEAP32[$1>>2]|0;
 $39 = $$pre;
 $37 = HEAP32[$3>>2]|0;
 $38 = (($37) + ($39<<2)|0);
 HEAP32[$38>>2] = $offset;
 STACKTOP = sp;return;
}
function __ZN8TypeTree8BlobReadERPKhS1_ib($this,$iterator,$end,$version,$swapByteOrder) {
 $this = $this|0;
 $iterator = $iterator|0;
 $end = $end|0;
 $version = $version|0;
 $swapByteOrder = $swapByteOrder|0;
 var $$0 = 0, $$byval_copy3 = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $or$cond = 0, $swapByteOrder$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$iterator>>2]|0;
 $2 = HEAPU8[$1>>0]|(HEAPU8[$1+1>>0]<<8)|(HEAPU8[$1+2>>0]<<16)|(HEAPU8[$1+3>>0]<<24);
 $3 = (($1) + 4|0);
 HEAP32[$iterator>>2] = $3;
 $4 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8)|(HEAPU8[$3+2>>0]<<16)|(HEAPU8[$3+3>>0]<<24);
 $5 = (($1) + 8|0);
 HEAP32[$iterator>>2] = $5;
 if ($swapByteOrder) {
  $6 = (_llvm_bswap_i32(($2|0))|0);
  $7 = (_llvm_bswap_i32(($4|0))|0);
  $10 = $7;$9 = $6;
 } else {
  $10 = $4;$9 = $2;
 }
 $8 = ($9*24)|0;
 $$sum = (($8) + ($10))|0;
 $$sum2 = (($$sum) + 8)|0;
 $11 = (($1) + ($$sum2)|0);
 $12 = ($11>>>0)>($end>>>0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($this) + 8|0);
 HEAP32[$13>>2] = $9;
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($9>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $9;
    $19 = HEAP32[$this>>2]|0;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($19,$8,4,$$byval_copy3,0,640264,370)|0);
    HEAP32[$this>>2] = $22;
    break;
   } else {
    $23 = (($this) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = $24;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($8,4,$$byval_copy3,0,640264,352)|0);
    $26 = HEAP32[$this>>2]|0;
    $27 = HEAP32[$13>>2]|0;
    $28 = ($27*24)|0;
    _memcpy(($25|0),($26|0),($28|0))|0;
    HEAP32[$14>>2] = $9;
    HEAP32[$this>>2] = $25;
    break;
   }
  }
 } while(0);
 $29 = (($this) + 16|0);
 $30 = (($this) + 24|0);
 HEAP32[$30>>2] = $10;
 $31 = (($this) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 & 2147483647;
 $34 = ($33>>>0)<($10>>>0);
 do {
  if ($34) {
   $35 = ($32|0)>(-1);
   if ($35) {
    HEAP32[$31>>2] = $10;
    $36 = HEAP32[$29>>2]|0;
    $37 = (($this) + 20|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$0>>2] = $38;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $39 = (__Z16realloc_internalPvji10MemLabelIdiPKci($36,$10,1,$$byval_copy3,0,640264,370)|0);
    HEAP32[$29>>2] = $39;
    $$pre$phiZ2D = $29;
    break;
   } else {
    $40 = (($this) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$0>>2] = $41;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($10,1,$$byval_copy3,0,640264,352)|0);
    $43 = HEAP32[$29>>2]|0;
    $44 = HEAP32[$30>>2]|0;
    _memcpy(($42|0),($43|0),($44|0))|0;
    HEAP32[$31>>2] = $10;
    HEAP32[$29>>2] = $42;
    $$pre$phiZ2D = $29;
    break;
   }
  } else {
   $$pre$phiZ2D = $29;
  }
 } while(0);
 $45 = HEAP32[$this>>2]|0;
 $46 = HEAP32[$iterator>>2]|0;
 _memcpy(($45|0),($46|0),($8|0))|0;
 $47 = HEAP32[$iterator>>2]|0;
 $48 = (($47) + ($8)|0);
 HEAP32[$iterator>>2] = $48;
 $49 = HEAP32[$$pre$phiZ2D>>2]|0;
 _memcpy(($49|0),($48|0),($10|0))|0;
 $50 = HEAP32[$iterator>>2]|0;
 $51 = (($50) + ($10)|0);
 HEAP32[$iterator>>2] = $51;
 $swapByteOrder$not = $swapByteOrder ^ 1;
 $52 = ($9|0)==(0);
 $or$cond = $52 | $swapByteOrder$not;
 if ($or$cond) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $53 = HEAP32[$this>>2]|0;
 $i$01 = 0;
 while(1) {
  $54 = (($53) + (($i$01*24)|0)|0);
  $55 = HEAP16[$54>>1]|0;
  $56 = $55&65535;
  $57 = $56 << 8;
  $58 = $56 >>> 8;
  $59 = $57 | $58;
  $60 = $59&65535;
  HEAP16[$54>>1] = $60;
  $61 = ((($53) + (($i$01*24)|0)|0) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (_llvm_bswap_i32(($62|0))|0);
  HEAP32[$61>>2] = $63;
  $64 = ((($53) + (($i$01*24)|0)|0) + 8|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (_llvm_bswap_i32(($65|0))|0);
  HEAP32[$64>>2] = $66;
  $67 = ((($53) + (($i$01*24)|0)|0) + 12|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (_llvm_bswap_i32(($68|0))|0);
  HEAP32[$67>>2] = $69;
  $70 = ((($53) + (($i$01*24)|0)|0) + 16|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (_llvm_bswap_i32(($71|0))|0);
  HEAP32[$70>>2] = $72;
  $73 = ((($53) + (($i$01*24)|0)|0) + 20|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (_llvm_bswap_i32(($74|0))|0);
  HEAP32[$73>>2] = $75;
  $76 = (($i$01) + 1)|0;
  $exitcond = ($76|0)==($9|0);
  if ($exitcond) {
   $$0 = 1;
   break;
  } else {
   $i$01 = $76;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL16ReadTypeTreeImplILb1EEbR8TypeTreeRK16TypeTreeIteratorRPKhS6_i($type,$t,$iterator,$end,$version) {
 $type = $type|0;
 $t = $t|0;
 $iterator = $iterator|0;
 $end = $end|0;
 $version = $version|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$04 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$type>>2]|0;
 $2 = (($t) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + (($3*24)|0)|0);
 $5 = HEAP32[$iterator>>2]|0;
 $7 = $5;
 while(1) {
  $6 = ($7>>>0)<($end>>>0);
  if (!($6)) {
   label = 4;
   break;
  }
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = (($7) + 1|0);
  HEAP32[$iterator>>2] = $10;
  if ($9) {
   break;
  } else {
   $7 = $10;
  }
 }
 if ((label|0) == 4) {
  $11 = (($7) + 1|0);
  HEAP32[$iterator>>2] = $11;
 }
 $12 = ($5|0)==(0|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[$type>>2]|0;
 $14 = ((($13) + (($3*24)|0)|0) + 4|0);
 $15 = (($type) + 16|0);
 __ZL12CreateStringPjR13dynamic_arrayIcLj1EEPKc($14,$15,$5);
 $16 = ((($1) + (($3*24)|0)|0) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>(-1);
 do {
  if (!($18)) {
   $19 = HEAP32[580528>>2]|0;
   $20 = $17 & 2147483647;
   $21 = (($19) + ($20)|0);
   $22 = HEAP32[580680>>2]|0;
   $23 = ($21|0)==($22|0);
   if ($23) {
    $24 = HEAP32[580592>>2]|0;
    $25 = $24;
    $26 = $19;
    $27 = (($25) - ($26))|0;
    $28 = $27 | -2147483648;
    HEAP32[$16>>2] = $28;
    break;
   }
   $29 = HEAP32[580728>>2]|0;
   $30 = ($21|0)==($29|0);
   if ($30) {
    $31 = HEAP32[580752>>2]|0;
    $32 = $31;
    $33 = $19;
    $34 = (($32) - ($33))|0;
    $35 = $34 | -2147483648;
    HEAP32[$16>>2] = $35;
   }
  }
 } while(0);
 $36 = HEAP32[$iterator>>2]|0;
 $38 = $36;
 while(1) {
  $37 = ($38>>>0)<($end>>>0);
  if (!($37)) {
   label = 14;
   break;
  }
  $39 = HEAP8[$38>>0]|0;
  $40 = ($39<<24>>24)==(0);
  $41 = (($38) + 1|0);
  HEAP32[$iterator>>2] = $41;
  if ($40) {
   break;
  } else {
   $38 = $41;
  }
 }
 if ((label|0) == 14) {
  $42 = (($38) + 1|0);
  HEAP32[$iterator>>2] = $42;
 }
 $43 = ($36|0)==(0|0);
 if ($43) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = HEAP32[$2>>2]|0;
 $45 = HEAP32[$type>>2]|0;
 $46 = ((($45) + (($44*24)|0)|0) + 8|0);
 __ZL12CreateStringPjR13dynamic_arrayIcLj1EEPKc($46,$15,$36);
 $47 = ((($1) + (($3*24)|0)|0) + 12|0);
 $48 = HEAP32[$iterator>>2]|0;
 $49 = HEAPU8[$48>>0]|(HEAPU8[$48+1>>0]<<8)|(HEAPU8[$48+2>>0]<<16)|(HEAPU8[$48+3>>0]<<24);
 $50 = (_llvm_bswap_i32(($49|0))|0);
 HEAP32[$47>>2] = $50;
 $51 = (($48) + 4|0);
 HEAP32[$iterator>>2] = $51;
 if ((($version|0) == 2)) {
  $52 = (($48) + 8|0);
  HEAP32[$iterator>>2] = $52;
  $55 = $52;
  label = 18;
 } else if ((($version|0) == 3)) {
  $72 = HEAPU8[$51>>0]|(HEAPU8[$51+1>>0]<<8)|(HEAPU8[$51+2>>0]<<16)|(HEAPU8[$51+3>>0]<<24);
  $73 = $72 >>> 24;
  $74 = (($48) + 8|0);
  HEAP32[$iterator>>2] = $74;
  $75 = $73&255;
  $76 = ((($1) + (($3*24)|0)|0) + 3|0);
  HEAP8[$76>>0] = $75;
  $77 = HEAP32[$iterator>>2]|0;
  $78 = HEAPU8[$77>>0]|(HEAPU8[$77+1>>0]<<8)|(HEAPU8[$77+2>>0]<<16)|(HEAPU8[$77+3>>0]<<24);
  $79 = (_llvm_bswap_i32(($78|0))|0);
  $80 = (($77) + 4|0);
  HEAP32[$iterator>>2] = $80;
  $81 = $79&65535;
  HEAP16[$4>>1] = $81;
  $83 = $80;
 } else {
  $55 = $51;
  label = 18;
 }
 if ((label|0) == 18) {
  $53 = ((($1) + (($3*24)|0)|0) + 16|0);
  $54 = HEAPU8[$55>>0]|(HEAPU8[$55+1>>0]<<8)|(HEAPU8[$55+2>>0]<<16)|(HEAPU8[$55+3>>0]<<24);
  $56 = (_llvm_bswap_i32(($54|0))|0);
  HEAP32[$53>>2] = $56;
  $57 = (($55) + 4|0);
  HEAP32[$iterator>>2] = $57;
  $58 = HEAPU8[$57>>0]|(HEAPU8[$57+1>>0]<<8)|(HEAPU8[$57+2>>0]<<16)|(HEAPU8[$57+3>>0]<<24);
  $59 = $58 >>> 24;
  $60 = (($55) + 8|0);
  HEAP32[$iterator>>2] = $60;
  $61 = $59&255;
  $62 = ((($1) + (($3*24)|0)|0) + 3|0);
  HEAP8[$62>>0] = $61;
  $63 = HEAP32[$iterator>>2]|0;
  $64 = HEAPU8[$63>>0]|(HEAPU8[$63+1>>0]<<8)|(HEAPU8[$63+2>>0]<<16)|(HEAPU8[$63+3>>0]<<24);
  $65 = (_llvm_bswap_i32(($64|0))|0);
  $66 = (($63) + 4|0);
  HEAP32[$iterator>>2] = $66;
  $67 = $65&65535;
  HEAP16[$4>>1] = $67;
  $68 = ((($1) + (($3*24)|0)|0) + 20|0);
  $69 = HEAPU8[$66>>0]|(HEAPU8[$66+1>>0]<<8)|(HEAPU8[$66+2>>0]<<16)|(HEAPU8[$66+3>>0]<<24);
  $70 = (_llvm_bswap_i32(($69|0))|0);
  HEAP32[$68>>2] = $70;
  $71 = (($63) + 8|0);
  HEAP32[$iterator>>2] = $71;
  $83 = $71;
 }
 $82 = HEAPU8[$83>>0]|(HEAPU8[$83+1>>0]<<8)|(HEAPU8[$83+2>>0]<<16)|(HEAPU8[$83+3>>0]<<24);
 $84 = (_llvm_bswap_i32(($82|0))|0);
 $85 = (($83) + 4|0);
 HEAP32[$iterator>>2] = $85;
 $86 = HEAP32[640272>>2]|0;
 $87 = (($86) + 1)|0;
 HEAP32[640272>>2] = $87;
 $88 = ($86|0)>(49);
 $89 = ($84>>>0)>(5000);
 $or$cond = $88 | $89;
 if ($or$cond) {
  HEAP32[640272>>2] = $86;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(640208,0,640264,540,1,0,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $90 = ($84|0)>(0);
 do {
  if ($90) {
   $91 = (($type) + 8|0);
   $92 = (($0) + 4|0);
   $i$04 = 0;
   while(1) {
    $95 = HEAP32[$2>>2]|0;
    __ZN8TypeTree8AddChildEj($type,$95);
    $96 = HEAP32[$91>>2]|0;
    $97 = (($96) + -1)|0;
    HEAP32[$0>>2] = $type;
    HEAP32[$92>>2] = $97;
    $98 = (__ZL16ReadTypeTreeImplILb1EEbR8TypeTreeRK16TypeTreeIteratorRPKhS6_i($type,$0,$iterator,$end,$version)|0);
    $94 = (($i$04) + 1)|0;
    if (!($98)) {
     break;
    }
    $93 = ($94|0)<($84|0);
    if ($93) {
     $i$04 = $94;
    } else {
     label = 27;
     break;
    }
   }
   if ((label|0) == 27) {
    $$pre = HEAP32[640272>>2]|0;
    $102 = $$pre;
    break;
   }
   $99 = HEAP32[640272>>2]|0;
   $100 = (($99) + -1)|0;
   HEAP32[640272>>2] = $100;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $102 = $87;
  }
 } while(0);
 $101 = (($102) + -1)|0;
 HEAP32[640272>>2] = $101;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZL16ReadTypeTreeImplILb0EEbR8TypeTreeRK16TypeTreeIteratorRPKhS6_i($type,$t,$iterator,$end,$version) {
 $type = $type|0;
 $t = $t|0;
 $iterator = $iterator|0;
 $end = $end|0;
 $version = $version|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $i$04 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$type>>2]|0;
 $2 = (($t) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + (($3*24)|0)|0);
 $5 = HEAP32[$iterator>>2]|0;
 $7 = $5;
 while(1) {
  $6 = ($7>>>0)<($end>>>0);
  if (!($6)) {
   label = 4;
   break;
  }
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = (($7) + 1|0);
  HEAP32[$iterator>>2] = $10;
  if ($9) {
   break;
  } else {
   $7 = $10;
  }
 }
 if ((label|0) == 4) {
  $11 = (($7) + 1|0);
  HEAP32[$iterator>>2] = $11;
 }
 $12 = ($5|0)==(0|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[$type>>2]|0;
 $14 = ((($13) + (($3*24)|0)|0) + 4|0);
 $15 = (($type) + 16|0);
 __ZL12CreateStringPjR13dynamic_arrayIcLj1EEPKc($14,$15,$5);
 $16 = ((($1) + (($3*24)|0)|0) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>(-1);
 do {
  if (!($18)) {
   $19 = HEAP32[580528>>2]|0;
   $20 = $17 & 2147483647;
   $21 = (($19) + ($20)|0);
   $22 = HEAP32[580680>>2]|0;
   $23 = ($21|0)==($22|0);
   if ($23) {
    $24 = HEAP32[580592>>2]|0;
    $25 = $24;
    $26 = $19;
    $27 = (($25) - ($26))|0;
    $28 = $27 | -2147483648;
    HEAP32[$16>>2] = $28;
    break;
   }
   $29 = HEAP32[580728>>2]|0;
   $30 = ($21|0)==($29|0);
   if ($30) {
    $31 = HEAP32[580752>>2]|0;
    $32 = $31;
    $33 = $19;
    $34 = (($32) - ($33))|0;
    $35 = $34 | -2147483648;
    HEAP32[$16>>2] = $35;
   }
  }
 } while(0);
 $36 = HEAP32[$iterator>>2]|0;
 $38 = $36;
 while(1) {
  $37 = ($38>>>0)<($end>>>0);
  if (!($37)) {
   label = 14;
   break;
  }
  $39 = HEAP8[$38>>0]|0;
  $40 = ($39<<24>>24)==(0);
  $41 = (($38) + 1|0);
  HEAP32[$iterator>>2] = $41;
  if ($40) {
   break;
  } else {
   $38 = $41;
  }
 }
 if ((label|0) == 14) {
  $42 = (($38) + 1|0);
  HEAP32[$iterator>>2] = $42;
 }
 $43 = ($36|0)==(0|0);
 if ($43) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = HEAP32[$2>>2]|0;
 $45 = HEAP32[$type>>2]|0;
 $46 = ((($45) + (($44*24)|0)|0) + 8|0);
 __ZL12CreateStringPjR13dynamic_arrayIcLj1EEPKc($46,$15,$36);
 $47 = ((($1) + (($3*24)|0)|0) + 12|0);
 $48 = HEAP32[$iterator>>2]|0;
 $49 = HEAPU8[$48>>0]|(HEAPU8[$48+1>>0]<<8)|(HEAPU8[$48+2>>0]<<16)|(HEAPU8[$48+3>>0]<<24);
 HEAP8[$47>>0]=$49&255;HEAP8[$47+1>>0]=($49>>8)&255;HEAP8[$47+2>>0]=($49>>16)&255;HEAP8[$47+3>>0]=$49>>24;
 $50 = HEAP32[$iterator>>2]|0;
 $51 = (($50) + 4|0);
 HEAP32[$iterator>>2] = $51;
 if ((($version|0) == 3)) {
  $70 = HEAPU8[$51>>0]|(HEAPU8[$51+1>>0]<<8)|(HEAPU8[$51+2>>0]<<16)|(HEAPU8[$51+3>>0]<<24);
  $71 = (($50) + 8|0);
  HEAP32[$iterator>>2] = $71;
  $72 = $70&255;
  $73 = ((($1) + (($3*24)|0)|0) + 3|0);
  HEAP8[$73>>0] = $72;
  $74 = HEAP32[$iterator>>2]|0;
  $75 = HEAPU8[$74>>0]|(HEAPU8[$74+1>>0]<<8)|(HEAPU8[$74+2>>0]<<16)|(HEAPU8[$74+3>>0]<<24);
  $76 = (($74) + 4|0);
  HEAP32[$iterator>>2] = $76;
  $77 = $75&65535;
  HEAP16[$4>>1] = $77;
  $79 = $76;
 } else if ((($version|0) == 2)) {
  $52 = (($50) + 8|0);
  HEAP32[$iterator>>2] = $52;
  $55 = $52;
  label = 18;
 } else {
  $55 = $51;
  label = 18;
 }
 if ((label|0) == 18) {
  $53 = ((($1) + (($3*24)|0)|0) + 16|0);
  $54 = HEAPU8[$55>>0]|(HEAPU8[$55+1>>0]<<8)|(HEAPU8[$55+2>>0]<<16)|(HEAPU8[$55+3>>0]<<24);
  HEAP8[$53>>0]=$54&255;HEAP8[$53+1>>0]=($54>>8)&255;HEAP8[$53+2>>0]=($54>>16)&255;HEAP8[$53+3>>0]=$54>>24;
  $56 = HEAP32[$iterator>>2]|0;
  $57 = (($56) + 4|0);
  HEAP32[$iterator>>2] = $57;
  $58 = HEAPU8[$57>>0]|(HEAPU8[$57+1>>0]<<8)|(HEAPU8[$57+2>>0]<<16)|(HEAPU8[$57+3>>0]<<24);
  $59 = (($56) + 8|0);
  HEAP32[$iterator>>2] = $59;
  $60 = $58&255;
  $61 = ((($1) + (($3*24)|0)|0) + 3|0);
  HEAP8[$61>>0] = $60;
  $62 = HEAP32[$iterator>>2]|0;
  $63 = HEAPU8[$62>>0]|(HEAPU8[$62+1>>0]<<8)|(HEAPU8[$62+2>>0]<<16)|(HEAPU8[$62+3>>0]<<24);
  $64 = (($62) + 4|0);
  HEAP32[$iterator>>2] = $64;
  $65 = $63&65535;
  HEAP16[$4>>1] = $65;
  $66 = ((($1) + (($3*24)|0)|0) + 20|0);
  $67 = HEAPU8[$64>>0]|(HEAPU8[$64+1>>0]<<8)|(HEAPU8[$64+2>>0]<<16)|(HEAPU8[$64+3>>0]<<24);
  HEAP8[$66>>0]=$67&255;HEAP8[$66+1>>0]=($67>>8)&255;HEAP8[$66+2>>0]=($67>>16)&255;HEAP8[$66+3>>0]=$67>>24;
  $68 = HEAP32[$iterator>>2]|0;
  $69 = (($68) + 4|0);
  HEAP32[$iterator>>2] = $69;
  $79 = $69;
 }
 $78 = HEAPU8[$79>>0]|(HEAPU8[$79+1>>0]<<8)|(HEAPU8[$79+2>>0]<<16)|(HEAPU8[$79+3>>0]<<24);
 $80 = (($79) + 4|0);
 HEAP32[$iterator>>2] = $80;
 $81 = HEAP32[640200>>2]|0;
 $82 = (($81) + 1)|0;
 HEAP32[640200>>2] = $82;
 $83 = ($81|0)>(49);
 $84 = ($78>>>0)>(5000);
 $or$cond = $83 | $84;
 if ($or$cond) {
  HEAP32[640200>>2] = $81;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(640208,0,640264,540,1,0,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $85 = ($78|0)>(0);
 do {
  if ($85) {
   $86 = (($type) + 8|0);
   $87 = (($0) + 4|0);
   $i$04 = 0;
   while(1) {
    $90 = HEAP32[$2>>2]|0;
    __ZN8TypeTree8AddChildEj($type,$90);
    $91 = HEAP32[$86>>2]|0;
    $92 = (($91) + -1)|0;
    HEAP32[$0>>2] = $type;
    HEAP32[$87>>2] = $92;
    $93 = (__ZL16ReadTypeTreeImplILb0EEbR8TypeTreeRK16TypeTreeIteratorRPKhS6_i($type,$0,$iterator,$end,$version)|0);
    $89 = (($i$04) + 1)|0;
    if (!($93)) {
     break;
    }
    $88 = ($89|0)<($78|0);
    if ($88) {
     $i$04 = $89;
    } else {
     label = 27;
     break;
    }
   }
   if ((label|0) == 27) {
    $$pre = HEAP32[640200>>2]|0;
    $97 = $$pre;
    break;
   }
   $94 = HEAP32[640200>>2]|0;
   $95 = (($94) + -1)|0;
   HEAP32[640200>>2] = $95;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $97 = $82;
  }
 } while(0);
 $96 = (($97) + -1)|0;
 HEAP32[640200>>2] = $96;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __Z12ReadTypeTreeR8TypeTreeRPKhS2_ib($t,$iterator,$end,$version,$swapEndian) {
 $t = $t|0;
 $iterator = $iterator|0;
 $end = $end|0;
 $version = $version|0;
 $swapEndian = $swapEndian|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = ($version|0)>(11);
 $3 = ($version|0)==(10);
 $or$cond = $2 | $3;
 if ($or$cond) {
  $4 = (__ZN8TypeTree8BlobReadERPKhS1_ib($t,$iterator,$end,0,$swapEndian)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 if ($swapEndian) {
  HEAP32[$0>>2] = $t;
  $5 = (($0) + 4|0);
  HEAP32[$5>>2] = 0;
  $6 = (__ZL16ReadTypeTreeImplILb1EEbR8TypeTreeRK16TypeTreeIteratorRPKhS6_i($t,$0,$iterator,$end,$version)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$1>>2] = $t;
  $7 = (($1) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (__ZL16ReadTypeTreeImplILb0EEbR8TypeTreeRK16TypeTreeIteratorRPKhS6_i($t,$1,$iterator,$end,$version)|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z26IsStreamedBinaryCompatibleRK16TypeTreeIteratorS1_($lhs,$rhs) {
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $$0 = 0, $$pn$i = 0, $$pn$i4 = 0, $$pr = 0, $$sum$i = 0, $$sum$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i = 0, $j = 0, $or$cond$i$i$i = 0, $or$cond$i$i$i12 = 0, $or$cond5$i$i$i = 0, $or$cond5$i$i$i13 = 0, $p$0$i = 0, $p$0$i5 = 0;
 var $phitmp25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $i = sp + 8|0;
 $j = sp;
 $0 = HEAP32[$lhs>>2]|0;
 $1 = (($lhs) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3) + (($2*24)|0)|0) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$rhs>>2]|0;
 $7 = (($rhs) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$6>>2]|0;
 $10 = ((($9) + (($8*24)|0)|0) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)==($11|0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($3) + (($2*24)|0)|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = (($9) + (($8*24)|0)|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = ($14<<16>>16)==($16<<16>>16);
 if (!($17)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = ((($3) + (($2*24)|0)|0) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($0) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19|0)<(0);
 $23 = HEAP32[580528>>2]|0;
 $24 = $22 ? $23 : $21;
 $25 = $19 & 2147483647;
 $26 = (($24) + ($25)|0);
 $27 = ((($9) + (($8*24)|0)|0) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($6) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($28|0)<(0);
 $32 = $31 ? $23 : $30;
 $33 = $28 & 2147483647;
 $34 = (($32) + ($33)|0);
 $35 = ($34|0)==(0|0);
 do {
  if ($35) {
   $38 = $26;
   label = 5;
  } else {
   $36 = ($26|0)==(0|0);
   if ($36) {
    $38 = 0;
    label = 5;
   } else {
    $39 = ($23>>>0)<=($26>>>0);
    $40 = HEAP32[580536>>2]|0;
    $41 = ($40>>>0)>($26>>>0);
    $or$cond$i$i$i12 = $39 & $41;
    if ($or$cond$i$i$i12) {
     $42 = ($23>>>0)<=($34>>>0);
     $43 = ($40>>>0)>($34>>>0);
     $or$cond5$i$i$i13 = $42 & $43;
     if ($or$cond5$i$i$i13) {
      $44 = ($26|0)==($34|0);
      if ($44) {
       break;
      } else {
       $$0 = 0;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $45 = (_strcmp($34,$26)|0);
    $46 = ($45|0)==(0);
    if (!($46)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $37 = ($38|0)==($34|0);
  if (!($37)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $47 = ((($3) + (($2*24)|0)|0) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)<(0);
 $50 = $49 ? $23 : $21;
 $51 = $48 & 2147483647;
 $52 = (($50) + ($51)|0);
 $53 = ((($9) + (($8*24)|0)|0) + 4|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)<(0);
 $56 = $55 ? $23 : $30;
 $57 = $54 & 2147483647;
 $58 = (($56) + ($57)|0);
 $59 = ($58|0)==(0|0);
 do {
  if ($59) {
   $62 = $52;
   label = 12;
  } else {
   $60 = ($52|0)==(0|0);
   if ($60) {
    $62 = 0;
    label = 12;
   } else {
    $63 = ($23>>>0)<=($52>>>0);
    $64 = HEAP32[580536>>2]|0;
    $65 = ($64>>>0)>($52>>>0);
    $or$cond$i$i$i = $63 & $65;
    if ($or$cond$i$i$i) {
     $66 = ($23>>>0)<=($58>>>0);
     $67 = ($64>>>0)>($58>>>0);
     $or$cond5$i$i$i = $66 & $67;
     if ($or$cond5$i$i$i) {
      $68 = ($52|0)==($58|0);
      if ($68) {
       break;
      } else {
       $$0 = 0;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $69 = (_strcmp($58,$52)|0);
    $70 = ($69|0)==(0);
    if (!($70)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $61 = ($62|0)==($58|0);
  if (!($61)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $71 = ((($3) + (($2*24)|0)|0) + 20|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($9) + (($8*24)|0)|0) + 20|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $74 ^ $72;
 $76 = $75 & 16384;
 $77 = ($76|0)==(0);
 if (!($77)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = (($0) + 8|0);
 $79 = HEAP32[$78>>2]|0;
 $$sum$i7 = (($2) + 1)|0;
 $80 = ($$sum$i7|0)<($79|0);
 if ($80) {
  $81 = ((($3) + (($$sum$i7*24)|0)|0) + 2|0);
  $82 = HEAP8[$81>>0]|0;
  $83 = $82&255;
  $84 = ((($3) + (($2*24)|0)|0) + 2|0);
  $85 = HEAP8[$84>>0]|0;
  $86 = $85&255;
  $87 = (($86) + 1)|0;
  $88 = ($83|0)==($87|0);
  if ($88) {
   HEAP32[$i>>2] = $0;
   $89 = (($i) + 4|0);
   HEAP32[$89>>2] = $$sum$i7;
   $164 = $$sum$i7;$165 = $0;
  } else {
   label = 21;
  }
 } else {
  label = 21;
 }
 if ((label|0) == 21) {
  HEAP32[$i>>2] = 0;
  $90 = (($i) + 4|0);
  HEAP32[$90>>2] = 0;
  $164 = 0;$165 = 0;
 }
 $91 = (($6) + 8|0);
 $92 = HEAP32[$91>>2]|0;
 $$sum$i = (($8) + 1)|0;
 $93 = ($$sum$i|0)<($92|0);
 if ($93) {
  $94 = ((($9) + (($$sum$i*24)|0)|0) + 2|0);
  $95 = HEAP8[$94>>0]|0;
  $96 = $95&255;
  $97 = ((($9) + (($8*24)|0)|0) + 2|0);
  $98 = HEAP8[$97>>0]|0;
  $99 = $98&255;
  $100 = (($99) + 1)|0;
  $101 = ($96|0)==($100|0);
  if ($101) {
   HEAP32[$j>>2] = $6;
   $102 = (($j) + 4|0);
   HEAP32[$102>>2] = $$sum$i;
   $$pr = $165;$106 = $6;$112 = $164;$138 = $$sum$i;
  } else {
   label = 25;
  }
 } else {
  label = 25;
 }
 if ((label|0) == 25) {
  HEAP32[$j>>2] = 0;
  $103 = (($j) + 4|0);
  HEAP32[$103>>2] = 0;
  $$pr = $165;$106 = 0;$112 = $164;$138 = 0;
 }
 while(1) {
  $104 = ($$pr|0)==(0|0);
  if ($104) {
   $105 = ($106|0)==(0|0);
   if ($105) {
    $$0 = 1;
    label = 42;
    break;
   }
   $107 = ($$pr|0)==(0|0);
   if ($107) {
    $$0 = 0;
    label = 42;
    break;
   }
  }
  $108 = ($106|0)==(0|0);
  if ($108) {
   $$0 = 0;
   label = 42;
   break;
  }
  $109 = (__Z26IsStreamedBinaryCompatibleRK16TypeTreeIteratorS1_($i,$j)|0);
  if (!($109)) {
   $$0 = 0;
   label = 42;
   break;
  }
  $110 = HEAP32[$$pr>>2]|0;
  $111 = (($110) + (($112*24)|0)|0);
  $113 = ((($110) + (($112*24)|0)|0) + 2|0);
  $114 = HEAP8[$113>>0]|0;
  $115 = (($$pr) + 8|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($110) + (($116*24)|0)|0);
  $$pn$i = $111;
  while(1) {
   $p$0$i = (($$pn$i) + 24|0);
   $118 = ($p$0$i>>>0)<($117>>>0);
   if (!($118)) {
    $128 = 0;$130 = 0;$135 = 0;
    break;
   }
   $119 = (($$pn$i) + 26|0);
   $120 = HEAP8[$119>>0]|0;
   $121 = ($120&255)>($114&255);
   if ($121) {
    $$pn$i = $p$0$i;
   } else {
    label = 34;
    break;
   }
  }
  if ((label|0) == 34) {
   label = 0;
   $122 = ($120<<24>>24)==($114<<24>>24);
   if ($122) {
    $123 = $p$0$i;
    $124 = $110;
    $125 = (($123) - ($124))|0;
    $126 = (($125|0) / 24)&-1;
    $128 = $$pr;$130 = 0;$135 = $126;
   } else {
    $128 = 0;$130 = 0;$135 = 0;
   }
  }
  $127 = $128;
  $129 = $127 | $130;
  $131 = $i;
  $132 = $131;
  HEAP32[$132>>2] = $129;
  $133 = (($131) + 4)|0;
  $134 = $133;
  HEAP32[$134>>2] = $135;
  $136 = HEAP32[$106>>2]|0;
  $137 = (($136) + (($138*24)|0)|0);
  $139 = ((($136) + (($138*24)|0)|0) + 2|0);
  $140 = HEAP8[$139>>0]|0;
  $141 = (($106) + 8|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = (($136) + (($142*24)|0)|0);
  $$pn$i4 = $137;
  while(1) {
   $p$0$i5 = (($$pn$i4) + 24|0);
   $144 = ($p$0$i5>>>0)<($143>>>0);
   if (!($144)) {
    $154 = 0;$155 = 0;$157 = 0;$158 = 0;
    break;
   }
   $145 = (($$pn$i4) + 26|0);
   $146 = HEAP8[$145>>0]|0;
   $147 = ($146&255)>($140&255);
   if ($147) {
    $$pn$i4 = $p$0$i5;
   } else {
    label = 39;
    break;
   }
  }
  if ((label|0) == 39) {
   label = 0;
   $148 = ($146<<24>>24)==($140<<24>>24);
   if ($148) {
    $149 = $p$0$i5;
    $150 = $136;
    $151 = (($149) - ($150))|0;
    $152 = (($151|0) / 24)&-1;
    $phitmp25 = $106;
    $154 = $phitmp25;$155 = 0;$157 = 0;$158 = $152;
   } else {
    $154 = 0;$155 = 0;$157 = 0;$158 = 0;
   }
  }
  $153 = $154 | $155;
  $156 = $157 | $158;
  $159 = $j;
  $160 = $159;
  HEAP32[$160>>2] = $153;
  $161 = (($159) + 4)|0;
  $162 = $161;
  HEAP32[$162>>2] = $156;
  $163 = $154;
  $$pr = $128;$106 = $163;$112 = $135;$138 = $158;
 }
 if ((label|0) == 42) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z21FindTypeTreeSeperatorPKc($in) {
 $in = $in|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $c$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $c$0 = $in;
 while(1) {
  $0 = HEAP8[$c$0>>0]|0;
  if ((($0<<24>>24) == 0) | (($0<<24>>24) == 46)) {
   break;
  }
  $1 = (($c$0) + 1|0);
  $c$0 = $1;
 }
 $2 = $c$0;
 $3 = $in;
 $4 = (($2) - ($3))|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN12CachedReaderC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = -1;
 $3 = (($this) + 32|0);
 HEAP8[$3>>0] = 0;
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12CachedReader8InitReadER15CacheReaderBasejj($this,$cacher,$position,$readSize) {
 $this = $this|0;
 $cacher = $cacher|0;
 $position = $position|0;
 $readSize = $readSize|0;
 var $$pre$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $cacher;
 $1 = HEAP32[$cacher>>2]|0;
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($cacher)|0);
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = $4;
 $6 = (($position>>>0) / ($4>>>0))&-1;
 $7 = (($this) + 16|0);
 HEAP32[$7>>2] = $6;
 $8 = (($readSize) + ($position))|0;
 $9 = (($this) + 28|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 24|0);
 HEAP32[$10>>2] = $position;
 $11 = HEAP32[$0>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 4|0);
 $16 = (($this) + 8|0);
 FUNCTION_TABLE_viiii[$14 & 511]($11,$6,$15,$16);
 $17 = HEAP32[$9>>2]|0;
 $18 = HEAP32[$7>>2]|0;
 $19 = HEAP32[$5>>2]|0;
 $20 = Math_imul($19, $18)|0;
 $21 = (($17) - ($20))|0;
 $22 = HEAP32[$15>>2]|0;
 $23 = (($22) + ($21)|0);
 $24 = HEAP32[$16>>2]|0;
 $25 = ($23>>>0)<($24>>>0);
 $26 = $25 ? $23 : $24;
 HEAP32[$16>>2] = $26;
 __ZN12CachedReader16OutOfBoundsErrorEjj($this,$position,0);
 $27 = (($this) + 32|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  STACKTOP = sp;return;
 }
 $30 = HEAP32[$5>>2]|0;
 $31 = (($position>>>0) / ($30>>>0))&-1;
 $32 = HEAP32[$7>>2]|0;
 $33 = ($31|0)==($32|0);
 if ($33) {
  $45 = $31;$46 = $30;
 } else {
  $34 = HEAP32[$0>>2]|0;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  FUNCTION_TABLE_vii[$37 & 4095]($34,$32);
  $38 = HEAP32[$5>>2]|0;
  $39 = (($position>>>0) / ($38>>>0))&-1;
  HEAP32[$7>>2] = $39;
  $40 = HEAP32[$0>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 12|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_viiii[$43 & 511]($40,$39,$15,$16);
  $$pre$i = HEAP32[$7>>2]|0;
  $$pre1$i = HEAP32[$5>>2]|0;
  $45 = $$pre$i;$46 = $$pre1$i;
 }
 $44 = Math_imul($45, $46)|0;
 $47 = (($position) - ($44))|0;
 $48 = HEAP32[$15>>2]|0;
 $49 = (($48) + ($47)|0);
 HEAP32[$this>>2] = $49;
 STACKTOP = sp;return;
}
function __ZN12CachedReader18InitResourceImagesER18ResourceImageGroup($this,$resourceImageGroup) {
 $this = $this|0;
 $resourceImageGroup = $resourceImageGroup|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 ;HEAP32[$0+0>>2]=HEAP32[$resourceImageGroup+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$resourceImageGroup+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$resourceImageGroup+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN12CachedReader3EndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $0;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_imul($9, $7)|0;
 $11 = (($10) + ($5))|0;
 __ZN12CachedReader16OutOfBoundsErrorEjj($this,$11,0);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($13,$17);
 HEAP32[$6>>2] = -1;
 STACKTOP = sp;return ($11|0);
}
function __ZN12CachedReader16OutOfBoundsErrorEjj($this,$position,$size) {
 $this = $this|0;
 $position = $position|0;
 $size = $size|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$5 = 0, $$56 = 0, $$6 = 0, $$67 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i18 = 0, $__p$0$i$i37 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 96|0;
 $1 = sp + 84|0;
 $2 = sp + 72|0;
 $3 = sp + 60|0;
 $4 = sp + 48|0;
 $5 = sp + 24|0;
 $6 = sp + 12|0;
 $7 = sp;
 $8 = sp + 36|0;
 $9 = (($this) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($size) + ($position))|0;
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($14)|0);
 $19 = ($12>>>0)>($18>>>0);
 L4: do {
  if ($19) {
   $20 = HEAP32[$13>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 24|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vii[$23 & 4095]($2,$20);
   ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
   $24 = HEAP8[$2>>0]|0;
   $25 = $24 & 1;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    $29 = $24&255;
    $30 = $29 >>> 1;
    $32 = $30;
   } else {
    $27 = (($2) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $32 = $28;
   }
   $31 = (($32) + 10)|0;
   $33 = ($31>>>0)>(4294967279);
   do {
    if ($33) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 17;
     } else {
      // unreachable;
     }
    } else {
     $36 = ($31>>>0)<(11);
     if ($36) {
      HEAP8[$1>>0] = 20;
      $37 = (($1) + 1|0);
      $__p$0$i$i = $37;
     } else {
      $38 = (($32) + 26)|0;
      $39 = $38 & -16;
      __THREW__ = 0;
      $40 = (invoke_ii(2988,($39|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 17;
       break;
      }
      $43 = (($1) + 8|0);
      HEAP32[$43>>2] = $40;
      $44 = $39 | 1;
      HEAP32[$1>>2] = $44;
      $45 = (($1) + 4|0);
      HEAP32[$45>>2] = 10;
      $__p$0$i$i = $40;
     }
     dest=$__p$0$i$i+0|0; src=640336+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $46 = (($__p$0$i$i) + 10|0);
     HEAP8[$46>>0] = 0;
     if ($26) {
      $49 = (($2) + 1|0);
      $50 = $49;
     } else {
      $47 = (($2) + 8|0);
      $48 = HEAP32[$47>>2]|0;
      $50 = $48;
     }
     __THREW__ = 0;
     (invoke_iiii(1480,($1|0),($50|0),($32|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 17;
     } else {
      __THREW__ = 0;
      invoke_viii(1627,($0|0),($1|0),(640352|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      do {
       if ($61) {
        $86 = ___cxa_find_matching_catch()|0;
        $87 = tempRet0;
        $$0 = $87;$$01 = $86;
       } else {
        $62 = HEAP8[$0>>0]|0;
        $63 = $62 & 1;
        $64 = ($63<<24>>24)==(0);
        if ($64) {
         $67 = (($0) + 1|0);
         $68 = $67;
        } else {
         $65 = (($0) + 8|0);
         $66 = HEAP32[$65>>2]|0;
         $68 = $66;
        }
        __THREW__ = 0;
        invoke_viiiiiiii(21,($68|0),0,(640280|0),234,32785,0,0,(0|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         $88 = ___cxa_find_matching_catch()|0;
         $89 = tempRet0;
         $90 = HEAP8[$0>>0]|0;
         $91 = $90 & 1;
         $92 = ($91<<24>>24)==(0);
         if ($92) {
          $$0 = $89;$$01 = $88;
          break;
         }
         $93 = (($0) + 8|0);
         $94 = HEAP32[$93>>2]|0;
         __ZdlPv($94);
         $$0 = $89;$$01 = $88;
         break;
        }
        $71 = HEAP8[$0>>0]|0;
        $72 = $71 & 1;
        $73 = ($72<<24>>24)==(0);
        if (!($73)) {
         $74 = (($0) + 8|0);
         $75 = HEAP32[$74>>2]|0;
         __ZdlPv($75);
        }
        $76 = HEAP8[$1>>0]|0;
        $77 = $76 & 1;
        $78 = ($77<<24>>24)==(0);
        if (!($78)) {
         $79 = (($1) + 8|0);
         $80 = HEAP32[$79>>2]|0;
         __ZdlPv($80);
        }
        $81 = HEAP8[$2>>0]|0;
        $82 = $81 & 1;
        $83 = ($82<<24>>24)==(0);
        if (!($83)) {
         $84 = (($2) + 8|0);
         $85 = HEAP32[$84>>2]|0;
         __ZdlPv($85);
        }
        HEAP8[$9>>0] = 1;
        break L4;
       }
      } while(0);
      $95 = HEAP8[$1>>0]|0;
      $96 = $95 & 1;
      $97 = ($96<<24>>24)==(0);
      if ($97) {
       $$1 = $$0;$$12 = $$01;
      } else {
       $98 = (($1) + 8|0);
       $99 = HEAP32[$98>>2]|0;
       __ZdlPv($99);
       $$1 = $$0;$$12 = $$01;
      }
     }
    }
   } while(0);
   if ((label|0) == 17) {
    $53 = ___cxa_find_matching_catch()|0;
    $54 = tempRet0;
    $55 = HEAP8[$1>>0]|0;
    $56 = $55 & 1;
    $57 = ($56<<24>>24)==(0);
    if (!($57)) {
     $58 = (($1) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     __ZdlPv($59);
    }
    $$1 = $54;$$12 = $53;
   }
   $100 = HEAP8[$2>>0]|0;
   $101 = $100 & 1;
   $102 = ($101<<24>>24)==(0);
   if ($102) {
    $$6 = $$1;$$67 = $$12;
    ___resumeException($$67|0);
    // unreachable;
   }
   $103 = (($2) + 8|0);
   $104 = HEAP32[$103>>2]|0;
   __ZdlPv($104);
   $$6 = $$1;$$67 = $$12;
   ___resumeException($$67|0);
   // unreachable;
  }
 } while(0);
 $105 = (($this) + 28|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($12>>>0)>($106>>>0);
 L57: do {
  if ($107) {
   $108 = HEAP32[$13>>2]|0;
   $109 = HEAP32[$108>>2]|0;
   $110 = (($109) + 24|0);
   $111 = HEAP32[$110>>2]|0;
   FUNCTION_TABLE_vii[$111 & 4095]($5,$108);
   ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
   $112 = HEAP8[$5>>0]|0;
   $113 = $112 & 1;
   $114 = ($113<<24>>24)==(0);
   if ($114) {
    $117 = $112&255;
    $118 = $117 >>> 1;
    $120 = $118;
   } else {
    $115 = (($5) + 4|0);
    $116 = HEAP32[$115>>2]|0;
    $120 = $116;
   }
   $119 = (($120) + 10)|0;
   $121 = ($119>>>0)>(4294967279);
   do {
    if ($121) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $122 = __THREW__; __THREW__ = 0;
     $123 = $122&1;
     if ($123) {
      label = 54;
     } else {
      // unreachable;
     }
    } else {
     $124 = ($119>>>0)<(11);
     if ($124) {
      HEAP8[$4>>0] = 20;
      $125 = (($4) + 1|0);
      $__p$0$i$i18 = $125;
     } else {
      $126 = (($120) + 26)|0;
      $127 = $126 & -16;
      __THREW__ = 0;
      $128 = (invoke_ii(2988,($127|0))|0);
      $129 = __THREW__; __THREW__ = 0;
      $130 = $129&1;
      if ($130) {
       label = 54;
       break;
      }
      $131 = (($4) + 8|0);
      HEAP32[$131>>2] = $128;
      $132 = $127 | 1;
      HEAP32[$4>>2] = $132;
      $133 = (($4) + 4|0);
      HEAP32[$133>>2] = 10;
      $__p$0$i$i18 = $128;
     }
     dest=$__p$0$i$i18+0|0; src=640336+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $134 = (($__p$0$i$i18) + 10|0);
     HEAP8[$134>>0] = 0;
     if ($114) {
      $137 = (($5) + 1|0);
      $138 = $137;
     } else {
      $135 = (($5) + 8|0);
      $136 = HEAP32[$135>>2]|0;
      $138 = $136;
     }
     __THREW__ = 0;
     (invoke_iiii(1480,($4|0),($138|0),($120|0))|0);
     $139 = __THREW__; __THREW__ = 0;
     $140 = $139&1;
     if ($140) {
      label = 54;
     } else {
      __THREW__ = 0;
      invoke_viii(1627,($3|0),($4|0),(640352|0));
      $148 = __THREW__; __THREW__ = 0;
      $149 = $148&1;
      do {
       if ($149) {
        $174 = ___cxa_find_matching_catch()|0;
        $175 = tempRet0;
        $$2 = $175;$$23 = $174;
       } else {
        $150 = HEAP8[$3>>0]|0;
        $151 = $150 & 1;
        $152 = ($151<<24>>24)==(0);
        if ($152) {
         $155 = (($3) + 1|0);
         $156 = $155;
        } else {
         $153 = (($3) + 8|0);
         $154 = HEAP32[$153>>2]|0;
         $156 = $154;
        }
        __THREW__ = 0;
        invoke_viiiiiiii(21,($156|0),0,(640280|0),240,32785,0,0,(0|0));
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         $176 = ___cxa_find_matching_catch()|0;
         $177 = tempRet0;
         $178 = HEAP8[$3>>0]|0;
         $179 = $178 & 1;
         $180 = ($179<<24>>24)==(0);
         if ($180) {
          $$2 = $177;$$23 = $176;
          break;
         }
         $181 = (($3) + 8|0);
         $182 = HEAP32[$181>>2]|0;
         __ZdlPv($182);
         $$2 = $177;$$23 = $176;
         break;
        }
        $159 = HEAP8[$3>>0]|0;
        $160 = $159 & 1;
        $161 = ($160<<24>>24)==(0);
        if (!($161)) {
         $162 = (($3) + 8|0);
         $163 = HEAP32[$162>>2]|0;
         __ZdlPv($163);
        }
        $164 = HEAP8[$4>>0]|0;
        $165 = $164 & 1;
        $166 = ($165<<24>>24)==(0);
        if (!($166)) {
         $167 = (($4) + 8|0);
         $168 = HEAP32[$167>>2]|0;
         __ZdlPv($168);
        }
        $169 = HEAP8[$5>>0]|0;
        $170 = $169 & 1;
        $171 = ($170<<24>>24)==(0);
        if (!($171)) {
         $172 = (($5) + 8|0);
         $173 = HEAP32[$172>>2]|0;
         __ZdlPv($173);
        }
        HEAP8[$9>>0] = 1;
        break L57;
       }
      } while(0);
      $183 = HEAP8[$4>>0]|0;
      $184 = $183 & 1;
      $185 = ($184<<24>>24)==(0);
      if ($185) {
       $$3 = $$2;$$34 = $$23;
      } else {
       $186 = (($4) + 8|0);
       $187 = HEAP32[$186>>2]|0;
       __ZdlPv($187);
       $$3 = $$2;$$34 = $$23;
      }
     }
    }
   } while(0);
   if ((label|0) == 54) {
    $141 = ___cxa_find_matching_catch()|0;
    $142 = tempRet0;
    $143 = HEAP8[$4>>0]|0;
    $144 = $143 & 1;
    $145 = ($144<<24>>24)==(0);
    if (!($145)) {
     $146 = (($4) + 8|0);
     $147 = HEAP32[$146>>2]|0;
     __ZdlPv($147);
    }
    $$3 = $142;$$34 = $141;
   }
   $188 = HEAP8[$5>>0]|0;
   $189 = $188 & 1;
   $190 = ($189<<24>>24)==(0);
   if ($190) {
    $$6 = $$3;$$67 = $$34;
    ___resumeException($$67|0);
    // unreachable;
   }
   $191 = (($5) + 8|0);
   $192 = HEAP32[$191>>2]|0;
   __ZdlPv($192);
   $$6 = $$3;$$67 = $$34;
   ___resumeException($$67|0);
   // unreachable;
  }
 } while(0);
 $193 = (($this) + 24|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194>>>0)>($position>>>0);
 if (!($195)) {
  STACKTOP = sp;return;
 }
 $196 = HEAP32[$13>>2]|0;
 $197 = HEAP32[$196>>2]|0;
 $198 = (($197) + 24|0);
 $199 = HEAP32[$198>>2]|0;
 FUNCTION_TABLE_vii[$199 & 4095]($8,$196);
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
 $200 = HEAP8[$8>>0]|0;
 $201 = $200 & 1;
 $202 = ($201<<24>>24)==(0);
 if ($202) {
  $205 = $200&255;
  $206 = $205 >>> 1;
  $208 = $206;
 } else {
  $203 = (($8) + 4|0);
  $204 = HEAP32[$203>>2]|0;
  $208 = $204;
 }
 $207 = (($208) + 10)|0;
 $209 = ($207>>>0)>(4294967279);
 do {
  if ($209) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $210 = __THREW__; __THREW__ = 0;
   $211 = $210&1;
   if ($211) {
    label = 91;
   } else {
    // unreachable;
   }
  } else {
   $212 = ($207>>>0)<(11);
   if ($212) {
    HEAP8[$7>>0] = 20;
    $213 = (($7) + 1|0);
    $__p$0$i$i37 = $213;
   } else {
    $214 = (($208) + 26)|0;
    $215 = $214 & -16;
    __THREW__ = 0;
    $216 = (invoke_ii(2988,($215|0))|0);
    $217 = __THREW__; __THREW__ = 0;
    $218 = $217&1;
    if ($218) {
     label = 91;
     break;
    }
    $219 = (($7) + 8|0);
    HEAP32[$219>>2] = $216;
    $220 = $215 | 1;
    HEAP32[$7>>2] = $220;
    $221 = (($7) + 4|0);
    HEAP32[$221>>2] = 10;
    $__p$0$i$i37 = $216;
   }
   dest=$__p$0$i$i37+0|0; src=640336+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $222 = (($__p$0$i$i37) + 10|0);
   HEAP8[$222>>0] = 0;
   if ($202) {
    $225 = (($8) + 1|0);
    $226 = $225;
   } else {
    $223 = (($8) + 8|0);
    $224 = HEAP32[$223>>2]|0;
    $226 = $224;
   }
   __THREW__ = 0;
   (invoke_iiii(1480,($7|0),($226|0),($208|0))|0);
   $227 = __THREW__; __THREW__ = 0;
   $228 = $227&1;
   if ($228) {
    label = 91;
   } else {
    __THREW__ = 0;
    invoke_viii(1627,($6|0),($7|0),(640352|0));
    $236 = __THREW__; __THREW__ = 0;
    $237 = $236&1;
    do {
     if ($237) {
      $262 = ___cxa_find_matching_catch()|0;
      $263 = tempRet0;
      $$4 = $263;$$45 = $262;
     } else {
      $238 = HEAP8[$6>>0]|0;
      $239 = $238 & 1;
      $240 = ($239<<24>>24)==(0);
      if ($240) {
       $243 = (($6) + 1|0);
       $244 = $243;
      } else {
       $241 = (($6) + 8|0);
       $242 = HEAP32[$241>>2]|0;
       $244 = $242;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($244|0),0,(640280|0),246,32785,0,0,(0|0));
      $245 = __THREW__; __THREW__ = 0;
      $246 = $245&1;
      if ($246) {
       $264 = ___cxa_find_matching_catch()|0;
       $265 = tempRet0;
       $266 = HEAP8[$6>>0]|0;
       $267 = $266 & 1;
       $268 = ($267<<24>>24)==(0);
       if ($268) {
        $$4 = $265;$$45 = $264;
        break;
       }
       $269 = (($6) + 8|0);
       $270 = HEAP32[$269>>2]|0;
       __ZdlPv($270);
       $$4 = $265;$$45 = $264;
       break;
      }
      $247 = HEAP8[$6>>0]|0;
      $248 = $247 & 1;
      $249 = ($248<<24>>24)==(0);
      if (!($249)) {
       $250 = (($6) + 8|0);
       $251 = HEAP32[$250>>2]|0;
       __ZdlPv($251);
      }
      $252 = HEAP8[$7>>0]|0;
      $253 = $252 & 1;
      $254 = ($253<<24>>24)==(0);
      if (!($254)) {
       $255 = (($7) + 8|0);
       $256 = HEAP32[$255>>2]|0;
       __ZdlPv($256);
      }
      $257 = HEAP8[$8>>0]|0;
      $258 = $257 & 1;
      $259 = ($258<<24>>24)==(0);
      if (!($259)) {
       $260 = (($8) + 8|0);
       $261 = HEAP32[$260>>2]|0;
       __ZdlPv($261);
      }
      HEAP8[$9>>0] = 1;
      STACKTOP = sp;return;
     }
    } while(0);
    $271 = HEAP8[$7>>0]|0;
    $272 = $271 & 1;
    $273 = ($272<<24>>24)==(0);
    if ($273) {
     $$5 = $$4;$$56 = $$45;
    } else {
     $274 = (($7) + 8|0);
     $275 = HEAP32[$274>>2]|0;
     __ZdlPv($275);
     $$5 = $$4;$$56 = $$45;
    }
   }
  }
 } while(0);
 if ((label|0) == 91) {
  $229 = ___cxa_find_matching_catch()|0;
  $230 = tempRet0;
  $231 = HEAP8[$7>>0]|0;
  $232 = $231 & 1;
  $233 = ($232<<24>>24)==(0);
  if (!($233)) {
   $234 = (($7) + 8|0);
   $235 = HEAP32[$234>>2]|0;
   __ZdlPv($235);
  }
  $$5 = $230;$$56 = $229;
 }
 $276 = HEAP8[$8>>0]|0;
 $277 = $276 & 1;
 $278 = ($277<<24>>24)==(0);
 if ($278) {
  $$6 = $$5;$$67 = $$56;
  ___resumeException($$67|0);
  // unreachable;
 }
 $279 = (($8) + 8|0);
 $280 = HEAP32[$279>>2]|0;
 __ZdlPv($280);
 $$6 = $$5;$$67 = $$56;
 ___resumeException($$67|0);
 // unreachable;
}
function __ZN12CachedReaderD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12CachedReader22FetchResourceImageDataEjj($this,$offset,$size) {
 $this = $this|0;
 $offset = $offset|0;
 $size = $size|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $__p$0$i$i = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $92 = HEAP32[$4>>2]|0;
  $93 = (($92) + ($offset)|0);
  $$03 = $93;
  STACKTOP = sp;return ($$03|0);
 }
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 4095]($2,$7);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $11 = HEAP8[$2>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $16 = $11&255;
  $17 = $16 >>> 1;
  $19 = $17;
 } else {
  $14 = (($2) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $19 = $15;
 }
 $18 = (($19) + 20)|0;
 $20 = ($18>>>0)>(4294967279);
 do {
  if ($20) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 16;
   } else {
    // unreachable;
   }
  } else {
   $23 = ($18>>>0)<(11);
   if ($23) {
    HEAP8[$1>>0] = 40;
    $24 = (($1) + 1|0);
    $__p$0$i$i = $24;
   } else {
    $25 = (($19) + 36)|0;
    $26 = $25 & -16;
    __THREW__ = 0;
    $27 = (invoke_ii(2988,($26|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 16;
     break;
    }
    $30 = (($1) + 8|0);
    HEAP32[$30>>2] = $27;
    $31 = $26 | 1;
    HEAP32[$1>>2] = $31;
    $32 = (($1) + 4|0);
    HEAP32[$32>>2] = 20;
    $__p$0$i$i = $27;
   }
   dest=$__p$0$i$i+0|0; src=640288+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $33 = (($__p$0$i$i) + 20|0);
   HEAP8[$33>>0] = 0;
   if ($13) {
    $36 = (($2) + 1|0);
    $37 = $36;
   } else {
    $34 = (($2) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    $37 = $35;
   }
   __THREW__ = 0;
   (invoke_iiii(1480,($1|0),($37|0),($19|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    label = 16;
   } else {
    __THREW__ = 0;
    invoke_viii(1627,($0|0),($1|0),(640312|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    do {
     if ($48) {
      $73 = ___cxa_find_matching_catch()|0;
      $74 = tempRet0;
      $$0 = $74;$$01 = $73;
     } else {
      $49 = HEAP8[$0>>0]|0;
      $50 = $49 & 1;
      $51 = ($50<<24>>24)==(0);
      if ($51) {
       $54 = (($0) + 1|0);
       $55 = $54;
      } else {
       $52 = (($0) + 8|0);
       $53 = HEAP32[$52>>2]|0;
       $55 = $53;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($55|0),0,(640280|0),106,1,0,0,(0|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       $75 = ___cxa_find_matching_catch()|0;
       $76 = tempRet0;
       $77 = HEAP8[$0>>0]|0;
       $78 = $77 & 1;
       $79 = ($78<<24>>24)==(0);
       if ($79) {
        $$0 = $76;$$01 = $75;
        break;
       }
       $80 = (($0) + 8|0);
       $81 = HEAP32[$80>>2]|0;
       __ZdlPv($81);
       $$0 = $76;$$01 = $75;
       break;
      }
      $58 = HEAP8[$0>>0]|0;
      $59 = $58 & 1;
      $60 = ($59<<24>>24)==(0);
      if (!($60)) {
       $61 = (($0) + 8|0);
       $62 = HEAP32[$61>>2]|0;
       __ZdlPv($62);
      }
      $63 = HEAP8[$1>>0]|0;
      $64 = $63 & 1;
      $65 = ($64<<24>>24)==(0);
      if (!($65)) {
       $66 = (($1) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       __ZdlPv($67);
      }
      $68 = HEAP8[$2>>0]|0;
      $69 = $68 & 1;
      $70 = ($69<<24>>24)==(0);
      if ($70) {
       $$03 = 0;
       STACKTOP = sp;return ($$03|0);
      }
      $71 = (($2) + 8|0);
      $72 = HEAP32[$71>>2]|0;
      __ZdlPv($72);
      $$03 = 0;
      STACKTOP = sp;return ($$03|0);
     }
    } while(0);
    $82 = HEAP8[$1>>0]|0;
    $83 = $82 & 1;
    $84 = ($83<<24>>24)==(0);
    if ($84) {
     $$1 = $$0;$$12 = $$01;
    } else {
     $85 = (($1) + 8|0);
     $86 = HEAP32[$85>>2]|0;
     __ZdlPv($86);
     $$1 = $$0;$$12 = $$01;
    }
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  $42 = HEAP8[$1>>0]|0;
  $43 = $42 & 1;
  $44 = ($43<<24>>24)==(0);
  if (!($44)) {
   $45 = (($1) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   __ZdlPv($46);
  }
  $$1 = $41;$$12 = $40;
 }
 $87 = HEAP8[$2>>0]|0;
 $88 = $87 & 1;
 $89 = ($88<<24>>24)==(0);
 if ($89) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $90 = (($2) + 8|0);
 $91 = HEAP32[$90>>2]|0;
 __ZdlPv($91);
 ___resumeException($$12|0);
 // unreachable;
 return 0|0;
}
function __ZN12CachedReader4ReadEPvj($this,$data,$size) {
 $this = $this|0;
 $data = $data|0;
 $size = $size|0;
 var $$0 = 0, $$01 = 0, $$1$ph = 0, $$12$ph = 0, $$123 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $position$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + ($size)|0);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)>($3>>>0);
 if (!($4)) {
  _memcpy(($data|0),($0|0),($size|0))|0;
  $5 = HEAP32[$this>>2]|0;
  $6 = (($5) + ($size)|0);
  HEAP32[$this>>2] = $6;
  STACKTOP = sp;return;
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = (($this) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = Math_imul($15, $13)|0;
 $17 = (($16) + ($11))|0;
 __ZN12CachedReader16OutOfBoundsErrorEjj($this,$17,$size);
 $18 = (($this) + 32|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  _memset(($data|0),0,($size|0))|0;
  STACKTOP = sp;return;
 }
 $21 = HEAP32[$14>>2]|0;
 $22 = (($17>>>0) % ($21>>>0))&-1;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0 = $data;$$01 = $size;$position$0 = $17;
 } else {
  $24 = (($17>>>0) / ($21>>>0))&-1;
  $25 = (($24) + 1)|0;
  $26 = Math_imul($25, $21)|0;
  $27 = (($26) - ($17))|0;
  $28 = ($27|0)<($size|0);
  $29 = $28 ? $27 : $size;
  __ZN12CachedReader15UpdateReadCacheEPvj($this,$data,$29);
  $30 = (($data) + ($29)|0);
  $31 = (($size) - ($29))|0;
  $32 = (($29) + ($17))|0;
  $$0 = $30;$$01 = $31;$position$0 = $32;
 }
 $33 = (($$01) + ($position$0))|0;
 $34 = (($this) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 28|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_ii[$38 & 4095]($35)|0);
 $40 = ($39>>>0)<($33>>>0);
 $41 = $40 ? $39 : $33;
 $42 = (($41) - ($position$0))|0;
 $43 = HEAP32[$14>>2]|0;
 $44 = (($42>>>0) / ($43>>>0))&-1;
 $45 = ($44|0)>(0);
 if ($45) {
  $46 = Math_imul($44, $43)|0;
  $47 = HEAP32[$34>>2]|0;
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_viiii[$50 & 511]($47,$$0,$position$0,$46);
  $51 = HEAP32[$this>>2]|0;
  $52 = (($51) + ($46)|0);
  HEAP32[$this>>2] = $52;
  $53 = (($$0) + ($46)|0);
  $54 = (($$01) - ($46))|0;
  $$1$ph = $53;$$12$ph = $54;
 } else {
  $$1$ph = $$0;$$12$ph = $$01;
 }
 $55 = ($$12$ph|0)==(0);
 if ($55) {
  STACKTOP = sp;return;
 } else {
  $$123 = $$12$ph;$$14 = $$1$ph;
 }
 while(1) {
  $56 = HEAP32[$14>>2]|0;
  $57 = ($56|0)<($$123|0);
  $58 = $57 ? $56 : $$123;
  __ZN12CachedReader15UpdateReadCacheEPvj($this,$$14,$58);
  $59 = ($$123|0)==($58|0);
  if ($59) {
   break;
  }
  $60 = (($$123) - ($58))|0;
  $61 = (($$14) + ($58)|0);
  $$123 = $60;$$14 = $61;
 }
 STACKTOP = sp;return;
}
function __ZN12CachedReader15UpdateReadCacheEPvj($this,$data,$size) {
 $this = $this|0;
 $data = $data|0;
 $size = $size|0;
 var $$$i$i = 0, $$$i$i7 = 0, $$$i1$i = 0, $$$i1$i10 = 0, $$0$i$i = 0, $$0$i$i8 = 0, $$0$i2$i = 0, $$0$i2$i11 = 0, $$pre = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre1$i = 0, $$pre1$i4 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$sum = 0, $$sum13 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $0;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_imul($9, $7)|0;
 $11 = (($10) + ($5))|0;
 __ZN12CachedReader16OutOfBoundsErrorEjj($this,$11,$size);
 $12 = (($this) + 32|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  _memset(($data|0),0,($size|0))|0;
  STACKTOP = sp;return;
 }
 __ZN12CachedReader16OutOfBoundsErrorEjj($this,$11,0);
 $15 = HEAP8[$12>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $17 = HEAP32[$8>>2]|0;
  $18 = (($11>>>0) / ($17>>>0))&-1;
  $19 = HEAP32[$6>>2]|0;
  $20 = ($18|0)==($19|0);
  if ($20) {
   $34 = $18;$35 = $17;
  } else {
   $21 = (($this) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vii[$25 & 4095]($22,$19);
   $26 = HEAP32[$8>>2]|0;
   $27 = (($11>>>0) / ($26>>>0))&-1;
   HEAP32[$6>>2] = $27;
   $28 = HEAP32[$21>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($this) + 8|0);
   FUNCTION_TABLE_viiii[$31 & 511]($28,$27,$1,$32);
   $$pre$i3 = HEAP32[$6>>2]|0;
   $$pre1$i4 = HEAP32[$8>>2]|0;
   $34 = $$pre$i3;$35 = $$pre1$i4;
  }
  $33 = Math_imul($34, $35)|0;
  $36 = (($11) - ($33))|0;
  $37 = HEAP32[$1>>2]|0;
  $38 = (($37) + ($36)|0);
  HEAP32[$this>>2] = $38;
  $42 = $38;$43 = $37;
 } else {
  $$pre = HEAP32[$this>>2]|0;
  $$pre14 = HEAP32[$1>>2]|0;
  $42 = $$pre;$43 = $$pre14;
 }
 $39 = (($this) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($42>>>0)<($43>>>0);
 if ($41) {
  $$0$i$i8 = $43;
 } else {
  $44 = ($42>>>0)>($40>>>0);
  $$$i$i7 = $44 ? $40 : $42;
  $$0$i$i8 = $$$i$i7;
 }
 $45 = (($42) + ($size)|0);
 $46 = ($45>>>0)<($43>>>0);
 if ($46) {
  $$0$i2$i11 = $43;
 } else {
  $47 = ($45>>>0)>($40>>>0);
  $$$i1$i10 = $47 ? $40 : $45;
  $$0$i2$i11 = $$$i1$i10;
 }
 $48 = $$0$i$i8;
 $49 = $42;
 $50 = (($48) - ($49))|0;
 $51 = $$0$i2$i11;
 $52 = (($51) - ($48))|0;
 $53 = (($data) + ($50)|0);
 $54 = (($42) + ($50)|0);
 _memcpy(($53|0),($54|0),($52|0))|0;
 $55 = HEAP32[$this>>2]|0;
 $56 = (($55) + ($size)|0);
 $57 = HEAP32[$39>>2]|0;
 $58 = ($56>>>0)>($57>>>0);
 if (!($58)) {
  HEAP32[$this>>2] = $56;
  STACKTOP = sp;return;
 }
 $59 = (($11) + ($size))|0;
 __ZN12CachedReader16OutOfBoundsErrorEjj($this,$59,0);
 $60 = HEAP8[$12>>0]|0;
 $61 = ($60<<24>>24)==(0);
 if ($61) {
  $62 = HEAP32[$8>>2]|0;
  $63 = (($59>>>0) / ($62>>>0))&-1;
  $64 = HEAP32[$6>>2]|0;
  $65 = ($63|0)==($64|0);
  if ($65) {
   $78 = $63;$79 = $62;
  } else {
   $66 = (($this) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + 16|0);
   $70 = HEAP32[$69>>2]|0;
   FUNCTION_TABLE_vii[$70 & 4095]($67,$64);
   $71 = HEAP32[$8>>2]|0;
   $72 = (($59>>>0) / ($71>>>0))&-1;
   HEAP32[$6>>2] = $72;
   $73 = HEAP32[$66>>2]|0;
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + 12|0);
   $76 = HEAP32[$75>>2]|0;
   FUNCTION_TABLE_viiii[$76 & 511]($73,$72,$1,$39);
   $$pre$i = HEAP32[$6>>2]|0;
   $$pre1$i = HEAP32[$8>>2]|0;
   $78 = $$pre$i;$79 = $$pre1$i;
  }
  $77 = Math_imul($78, $79)|0;
  $80 = (($59) - ($77))|0;
  $81 = HEAP32[$1>>2]|0;
  $82 = (($81) + ($80)|0);
  HEAP32[$this>>2] = $82;
  $84 = $79;$85 = $78;$88 = $81;
 } else {
  $$pre15 = HEAP32[$6>>2]|0;
  $$pre16 = HEAP32[$8>>2]|0;
  $$pre17 = HEAP32[$1>>2]|0;
  $84 = $$pre16;$85 = $$pre15;$88 = $$pre17;
 }
 $83 = Math_imul($84, $85)|0;
 $86 = (($11) - ($83))|0;
 $87 = (($88) + ($86)|0);
 $89 = HEAP32[$39>>2]|0;
 $90 = ($86|0)<(0);
 if ($90) {
  $$0$i$i = $88;
 } else {
  $91 = ($87>>>0)>($89>>>0);
  $$$i$i = $91 ? $89 : $87;
  $$0$i$i = $$$i$i;
 }
 $$sum = (($86) + ($size))|0;
 $92 = (($88) + ($$sum)|0);
 $93 = ($$sum|0)<(0);
 if ($93) {
  $$0$i2$i = $88;
 } else {
  $94 = ($92>>>0)>($89>>>0);
  $$$i1$i = $94 ? $89 : $92;
  $$0$i2$i = $$$i1$i;
 }
 $95 = $$0$i$i;
 $96 = $87;
 $97 = (($95) - ($96))|0;
 $98 = $$0$i2$i;
 $99 = (($98) - ($95))|0;
 $100 = (($data) + ($97)|0);
 $$sum13 = (($97) + ($86))|0;
 $101 = (($88) + ($$sum13)|0);
 _memcpy(($100|0),($101|0),($99|0))|0;
 STACKTOP = sp;return;
}
function __ZN12CachedReader4SkipEi($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$pre$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + ($size)|0);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)>($3>>>0);
 if (!($4)) {
  HEAP32[$this>>2] = $1;
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $6;
 $9 = (($this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = Math_imul($12, $10)|0;
 $14 = (($7) + ($size))|0;
 $15 = (($14) - ($8))|0;
 $16 = (($15) + ($13))|0;
 __ZN12CachedReader16OutOfBoundsErrorEjj($this,$16,0);
 $17 = (($this) + 32|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$11>>2]|0;
 $21 = (($16>>>0) / ($20>>>0))&-1;
 $22 = HEAP32[$9>>2]|0;
 $23 = ($21|0)==($22|0);
 if ($23) {
  $36 = $21;$37 = $20;
 } else {
  $24 = (($this) + 12|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 16|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vii[$28 & 4095]($25,$22);
  $29 = HEAP32[$11>>2]|0;
  $30 = (($16>>>0) / ($29>>>0))&-1;
  HEAP32[$9>>2] = $30;
  $31 = HEAP32[$24>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viiii[$34 & 511]($31,$30,$5,$2);
  $$pre$i = HEAP32[$9>>2]|0;
  $$pre1$i = HEAP32[$11>>2]|0;
  $36 = $$pre$i;$37 = $$pre1$i;
 }
 $35 = Math_imul($36, $37)|0;
 $38 = (($16) - ($35))|0;
 $39 = HEAP32[$5>>2]|0;
 $40 = (($39) + ($38)|0);
 HEAP32[$this>>2] = $40;
 STACKTOP = sp;return;
}
function __ZN12CachedReader10Align4ReadEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $0;
 $4 = $2;
 $5 = (($3) + 3)|0;
 $6 = (($5) - ($4))|0;
 $7 = $6 & -4;
 $8 = (($2) + ($7)|0);
 HEAP32[$this>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN12CachedWriter11Align4WriteEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, $phitmp = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $0;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5) + 3)|0;
 $7 = $6 & -4;
 $8 = (($7) - ($5))|0;
 HEAP8[$value>>0] = 0;
 $9 = ($7|0)==($5|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 8|0);
 $12 = $0;$i$01 = 1;
 while(1) {
  $11 = (($12) + 1|0);
  $13 = HEAP32[$10>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP8[$value>>0]|0;
   HEAP8[$12>>0] = $15;
   $16 = HEAP32[$this>>2]|0;
   $17 = (($16) + 1|0);
   HEAP32[$this>>2] = $17;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($this,$value,1);
  }
  $18 = ($i$01>>>0)<($8>>>0);
  if (!($18)) {
   break;
  }
  $$pre = HEAP32[$this>>2]|0;
  $phitmp = (($i$01) + 1)|0;
  $12 = $$pre;$i$01 = $phitmp;
 }
 STACKTOP = sp;return;
}
function __ZN12CachedWriter5WriteEPKvj($this,$data,$size) {
 $this = $this|0;
 $data = $data|0;
 $size = $size|0;
 var $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + ($size)|0);
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  _memcpy(($0|0),($data|0),($size|0))|0;
  $7 = HEAP32[$this>>2]|0;
  $8 = (($7) + ($size)|0);
  HEAP32[$this>>2] = $8;
  STACKTOP = sp;return;
 }
 $5 = ($size|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 16|0);
 $$01 = $data;$15 = $size;
 while(1) {
  $9 = HEAP32[$6>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
  $14 = ($13>>>0)<($15>>>0);
  $16 = $14 ? $13 : $15;
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($this,$$01,$16);
  $17 = (($$01) + ($16)|0);
  $18 = (($15) - ($16))|0;
  $19 = ($15|0)==($16|0);
  if ($19) {
   break;
  } else {
   $$01 = $17;$15 = $18;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12CachedWriter16UpdateWriteCacheEPKvj($this,$data,$size) {
 $this = $this|0;
 $data = $data|0;
 $size = $size|0;
 var $$$i$i = 0, $$$i$i1 = 0, $$$i1$i = 0, $$$i1$i4 = 0, $$0$i$i = 0, $$0$i$i2 = 0, $$0$i2$i = 0, $$0$i2$i5 = 0, $$pre = 0, $$pre$i = 0, $$sum = 0, $$sum7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = ($5>>>0)<($size>>>0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$0>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 4095]($15)|0);
 $20 = Math_imul($19, $14)|0;
 $21 = (($20) + ($12))|0;
 $22 = HEAP32[$0>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 4095]($22)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$8>>2]|0;
 $29 = (($this) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($27>>>0)<($28>>>0);
 if ($31) {
  $$0$i$i = $28;
 } else {
  $32 = ($27>>>0)>($30>>>0);
  $$$i$i = $32 ? $30 : $27;
  $$0$i$i = $$$i$i;
 }
 $33 = (($27) + ($size)|0);
 $34 = ($33>>>0)<($28>>>0);
 if ($34) {
  $$0$i2$i = $28;
 } else {
  $35 = ($33>>>0)>($30>>>0);
  $$$i1$i = $35 ? $30 : $33;
  $$0$i2$i = $$$i1$i;
 }
 $36 = $$0$i$i;
 $37 = $27;
 $38 = (($36) - ($37))|0;
 $39 = $$0$i2$i;
 $40 = (($39) - ($36))|0;
 $41 = (($27) + ($38)|0);
 $42 = (($data) + ($38)|0);
 _memcpy(($41|0),($42|0),($40|0))|0;
 $43 = (($21) + ($size))|0;
 $44 = HEAP32[$0>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 24|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (FUNCTION_TABLE_ii[$47 & 4095]($44)|0);
 $49 = (($43>>>0) / ($48>>>0))&-1;
 $50 = HEAP32[$13>>2]|0;
 $51 = ($49|0)==($50|0);
 do {
  if ($51) {
   $63 = $49;
   label = 10;
  } else {
   $52 = (($50) + 1)|0;
   $53 = ($49|0)==($52|0);
   if ($53) {
    $54 = HEAP32[$0>>2]|0;
    $55 = HEAP32[$54>>2]|0;
    $56 = (($55) + 20|0);
    $57 = HEAP32[$56>>2]|0;
    FUNCTION_TABLE_vii[$57 & 4095]($54,$50);
    HEAP32[$13>>2] = $49;
    $58 = HEAP32[$0>>2]|0;
    $59 = HEAP32[$58>>2]|0;
    $60 = (($59) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    FUNCTION_TABLE_viiii[$61 & 511]($58,$49,$8,$29);
    $$pre$i = HEAP32[$13>>2]|0;
    $63 = $$pre$i;
    label = 10;
    break;
   } else {
    $$pre = HEAP32[$8>>2]|0;
    $68 = $50;$71 = $$pre;
    break;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $62 = Math_imul($63, $48)|0;
  $64 = (($43) - ($62))|0;
  $65 = HEAP32[$8>>2]|0;
  $66 = (($65) + ($64)|0);
  HEAP32[$this>>2] = $66;
  $68 = $63;$71 = $65;
 }
 $67 = Math_imul($68, $26)|0;
 $69 = (($21) - ($67))|0;
 $70 = (($71) + ($69)|0);
 $72 = HEAP32[$29>>2]|0;
 $73 = ($69|0)<(0);
 if ($73) {
  $$0$i$i2 = $71;
 } else {
  $74 = ($70>>>0)>($72>>>0);
  $$$i$i1 = $74 ? $72 : $70;
  $$0$i$i2 = $$$i$i1;
 }
 $$sum = (($69) + ($size))|0;
 $75 = (($71) + ($$sum)|0);
 $76 = ($$sum|0)<(0);
 if ($76) {
  $$0$i2$i5 = $71;
 } else {
  $77 = ($75>>>0)>($72>>>0);
  $$$i1$i4 = $77 ? $72 : $75;
  $$0$i2$i5 = $$$i1$i4;
 }
 $78 = $$0$i$i2;
 $79 = $70;
 $80 = (($78) - ($79))|0;
 $81 = $$0$i2$i5;
 $82 = (($81) - ($78))|0;
 $$sum7 = (($80) + ($69))|0;
 $83 = (($71) + ($$sum7)|0);
 $84 = (($data) + ($80)|0);
 _memcpy(($83|0),($84|0),($82|0))|0;
 STACKTOP = sp;return;
}
function __ZNK12CachedWriter11GetPositionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $0;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
 $14 = Math_imul($13, $7)|0;
 $15 = (($5) + ($14))|0;
 STACKTOP = sp;return ($15|0);
}
function __ZN12CachedWriter15CompleteWritingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($1,$6);
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = HEAP32[$5>>2]|0;
 $18 = (($8) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_ii[$19 & 4095]($7)|0);
 $21 = Math_imul($20, $17)|0;
 $22 = (($16) + ($21))|0;
 $23 = (FUNCTION_TABLE_iii[$10 & 4095]($7,$22)|0);
 STACKTOP = sp;return ($23|0);
}
function __ZN12CachedWriter9InitWriteER15CacheWriterBase($this,$cacher) {
 $this = $this|0;
 $cacher = $cacher|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = $cacher;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = HEAP32[$cacher>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 $6 = (($this) + 8|0);
 FUNCTION_TABLE_viiii[$4 & 511]($cacher,0,$5,$6);
 $7 = HEAP32[$5>>2]|0;
 HEAP32[$this>>2] = $7;
 STACKTOP = sp;return;
}
function __ZN15CacheReaderBaseD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15CacheReaderBase18GetAddressOfMemoryEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(640432,0,640504,9,1,0,0,0);
 STACKTOP = sp;return (0|0);
}
function __ZN15CacheWriterBaseD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15CacheWriterBase23WriteHeaderAndCloseFileEPvjj($this,$data,$position,$size) {
 $this = $this|0;
 $data = $data|0;
 $position = $position|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN15CacheWriterBase18GetAddressOfMemoryEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(640512,0,640584,17,1,0,0,0);
 STACKTOP = sp;return (0|0);
}
function __ZN14FileCacherReadC2ERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEjj($this,$pathName,$cacheSize,$cacheCount) {
 $this = $this|0;
 $pathName = $pathName|0;
 $cacheSize = $cacheSize|0;
 $cacheCount = $cacheCount|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $fsEntry = 0;
 var $i$011 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1088|0;
 $$byval_copy = sp + 1072|0;
 $0 = sp;
 $1 = sp + 4|0;
 $fsEntry = sp + 16|0;
 HEAP32[$this>>2] = ((640592 + 8|0));
 $2 = (($this) + 12|0);
 $3 = (($this) + 28|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 HEAP32[$3>>2] = -1;
 $4 = (($this) + 32|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 40|0);
 HEAP32[$6>>2] = -1;
 $7 = (($this) + 44|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 48|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
 $9 = (($this) + 72|0);
 HEAP32[$9>>2] = 3;
 $10 = (($this) + 76|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 80|0);
 HEAP8[$11>>0] = 0;
 $12 = (($this) + 84|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
 $13 = (($this) + 108|0);
 HEAP32[$13>>2] = 3;
 $14 = (($this) + 112|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 116|0);
 HEAP8[$15>>0] = 0;
 $16 = (($this) + 120|0);
 ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;
 $17 = (($this) + 144|0);
 HEAP32[$17>>2] = 3;
 $18 = (($this) + 148|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 152|0);
 HEAP8[$19>>0] = 0;
 __THREW__ = 0;
 invoke_vii(3226,($1|0),($pathName|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L1: do {
  if ($21) {
   label = 13;
  } else {
   __THREW__ = 0;
   (invoke_iii(2233,($2|0),($1|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    $57 = HEAP8[$1>>0]|0;
    $58 = $57 & 1;
    $59 = ($58<<24>>24)==(0);
    if ($59) {
     $$0 = $56;$$01 = $55;
     break;
    }
    $60 = (($1) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    __ZdlPv($61);
    $$0 = $56;$$01 = $55;
    break;
   }
   $24 = HEAP8[$1>>0]|0;
   $25 = $24 & 1;
   $26 = ($25<<24>>24)==(0);
   if (!($26)) {
    $27 = (($1) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    __ZdlPv($28);
   }
   $29 = (($this) + 4|0);
   HEAP32[$29>>2] = $cacheSize;
   $30 = HEAP8[$2>>0]|0;
   $31 = $30 & 1;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $35 = (($2) + 1|0);
    $36 = $35;
   } else {
    $33 = (($this) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $36 = $34;
   }
   __THREW__ = 0;
   invoke_vii(3227,($fsEntry|0),($36|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 13;
   } else {
    __THREW__ = 0;
    $39 = (invoke_ii(3306,($fsEntry|0))|0);
    $40 = tempRet0;
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    do {
     if ($42) {
      $64 = ___cxa_find_matching_catch()|0;
      $65 = tempRet0;
      $lpad$phi$index = $64;$lpad$phi$index2 = $65;
     } else {
      $43 = (($this) + 8|0);
      HEAP32[$43>>2] = $39;
      $i$011 = 0;
      while(1) {
       $44 = HEAP32[$29>>2]|0;
       $45 = HEAP32[628408>>2]|0;
       HEAP32[$0>>2] = $45;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       $46 = (invoke_iiiiiii(102,($44|0),16,($$byval_copy|0),0,(640640|0),30)|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        label = 16;
        break;
       }
       $49 = ((($this) + (($i$011*12)|0)|0) + 24|0);
       HEAP32[$49>>2] = $46;
       $50 = ((($this) + (($i$011*12)|0)|0) + 28|0);
       HEAP32[$50>>2] = -1;
       $51 = (($i$011) + 1)|0;
       $52 = ($51|0)<(2);
       if ($52) {
        $i$011 = $51;
       } else {
        break;
       }
      }
      if ((label|0) == 16) {
       $62 = ___cxa_find_matching_catch()|0;
       $63 = tempRet0;
       $lpad$phi$index = $62;$lpad$phi$index2 = $63;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3572,($fsEntry|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 13;
       break L1;
      }
      STACKTOP = sp;return;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vi(3572,($fsEntry|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     $89 = ___cxa_find_matching_catch(0|0)|0;
     $90 = tempRet0;
     ___clang_call_terminate($89);
     // unreachable;
    } else {
     $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  $$0 = $54;$$01 = $53;
 }
 $70 = HEAP8[$16>>0]|0;
 $71 = $70 & 1;
 $72 = ($71<<24>>24)==(0);
 if (!($72)) {
  $73 = (($this) + 128|0);
  $74 = HEAP32[$73>>2]|0;
  __ZdlPv($74);
 }
 $75 = (($this) + 84|0);
 $76 = HEAP8[$75>>0]|0;
 $77 = $76 & 1;
 $78 = ($77<<24>>24)==(0);
 if (!($78)) {
  $79 = (($this) + 92|0);
  $80 = HEAP32[$79>>2]|0;
  __ZdlPv($80);
 }
 $81 = (($this) + 48|0);
 $82 = HEAP8[$81>>0]|0;
 $83 = $82 & 1;
 $84 = ($83<<24>>24)==(0);
 if (!($84)) {
  $91 = (($this) + 56|0);
  $92 = HEAP32[$91>>2]|0;
  __ZdlPv($92);
 }
 $93 = HEAP8[$2>>0]|0;
 $94 = $93 & 1;
 $95 = ($94<<24>>24)==(0);
 if (!($95)) {
  $85 = (($this) + 20|0);
  $86 = HEAP32[$85>>2]|0;
  __ZdlPv($86);
 }
 __THREW__ = 0;
 $87 = __THREW__; __THREW__ = 0;
 $88 = $87&1;
 if ($88) {
  $89 = ___cxa_find_matching_catch(0|0)|0;
  $90 = tempRet0;
  ___clang_call_terminate($89);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN14FileCacherReadD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1161,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN14FileCacherReadD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $i$09 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((640592 + 8|0));
 $i$09 = 0;
 while(1) {
  __THREW__ = 0;
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if ($2) {
   label = 5;
   break;
  }
  $3 = ((($this) + (($i$09*12)|0)|0) + 24|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[628408>>2]|0;
  HEAP32[$0>>2] = $5;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($4|0),($$byval_copy|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 5;
   break;
  }
  HEAP32[$3>>2] = 0;
  $8 = (($i$09) + 1)|0;
  $9 = ($8|0)<(2);
  if ($9) {
   $i$09 = $8;
  } else {
   label = 9;
   break;
  }
 }
 do {
  if ((label|0) == 5) {
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   $lpad$phi$index = $10;$lpad$phi$index2 = $11;
  }
  else if ((label|0) == 9) {
   $20 = (($this) + 12|0);
   __THREW__ = 0;
   invoke_vi(3573,($20|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    $12 = ___cxa_find_matching_catch()|0;
    $13 = tempRet0;
    $lpad$phi$index = $12;$lpad$phi$index2 = $13;
    break;
   }
   $23 = (($this) + 120|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24 & 1;
   $26 = ($25<<24>>24)==(0);
   if (!($26)) {
    $27 = (($this) + 128|0);
    $28 = HEAP32[$27>>2]|0;
    __ZdlPv($28);
   }
   $29 = (($this) + 84|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = $30 & 1;
   $32 = ($31<<24>>24)==(0);
   if (!($32)) {
    $33 = (($this) + 92|0);
    $34 = HEAP32[$33>>2]|0;
    __ZdlPv($34);
   }
   $35 = (($this) + 48|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = $36 & 1;
   $38 = ($37<<24>>24)==(0);
   if (!($38)) {
    $63 = (($this) + 56|0);
    $64 = HEAP32[$63>>2]|0;
    __ZdlPv($64);
   }
   $65 = HEAP8[$20>>0]|0;
   $66 = $65 & 1;
   $67 = ($66<<24>>24)==(0);
   if ($67) {
    STACKTOP = sp;return;
   }
   $39 = (($this) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   __ZdlPv($40);
   STACKTOP = sp;return;
  }
 } while(0);
 $14 = (($this) + 120|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if (!($17)) {
  $18 = (($this) + 128|0);
  $19 = HEAP32[$18>>2]|0;
  __ZdlPv($19);
 }
 $41 = (($this) + 84|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = $42 & 1;
 $44 = ($43<<24>>24)==(0);
 if (!($44)) {
  $45 = (($this) + 92|0);
  $46 = HEAP32[$45>>2]|0;
  __ZdlPv($46);
 }
 $47 = (($this) + 48|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48 & 1;
 $50 = ($49<<24>>24)==(0);
 if (!($50)) {
  $57 = (($this) + 56|0);
  $58 = HEAP32[$57>>2]|0;
  __ZdlPv($58);
 }
 $59 = (($this) + 12|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = $60 & 1;
 $62 = ($61<<24>>24)==(0);
 if (!($62)) {
  $51 = (($this) + 20|0);
  $52 = HEAP32[$51>>2]|0;
  __ZdlPv($52);
 }
 __THREW__ = 0;
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 if ($54) {
  $55 = ___cxa_find_matching_catch(0|0)|0;
  $56 = tempRet0;
  ___clang_call_terminate($55);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14FileCacherRead10DirectReadEPvjj($this,$data,$position,$size) {
 $this = $this|0;
 $data = $data|0;
 $position = $position|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($position))|0;
 $3 = ($2>>>0)<($size>>>0);
 if ($3) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(640648,0,640640,73,32785,0,0,0);
 }
 $4 = (($this) + 120|0);
 $5 = (($this) + 12|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($4,$5)|0);
 $6 = (($this) + 132|0);
 HEAP32[$6>>2] = $data;
 $7 = (($this) + 136|0);
 HEAP32[$7>>2] = $size;
 $8 = (($this) + 140|0);
 HEAP32[$8>>2] = $position;
 __Z16AsyncReadRequestP16AsyncReadCommand($4);
 STACKTOP = sp;return;
}
function __ZN14FileCacherRead12RequestBlockEi($this,$block) {
 $this = $this|0;
 $block = $block|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0;
 var $indexToLoad$0$i1$0 = 0, $indexToLoad$0$i1$0$1 = 0, $indexToLoad$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$04 = 0;
 while(1) {
  $9 = ((($this) + (($i$04*12)|0)|0) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($block|0);
  $1 = (($i$04) + 1)|0;
  if ($11) {
   $$0 = $i$04;
   label = 8;
   break;
  }
  $0 = ($1|0)<(2);
  if ($0) {
   $i$04 = $1;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($this) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1);
 $indexToLoad$0$i1$0 = $4 << 31 >> 31;
 $5 = (($this) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(1);
 $indexToLoad$0$i1$0$1 = $7 ? $indexToLoad$0$i1$0 : 1;
 $8 = ($indexToLoad$0$i1$0$1|0)==(-1);
 if ($8) {
  $indexToLoad$2 = 0;
 } else {
  $indexToLoad$2 = $indexToLoad$0$i1$0$1;
 }
 $12 = ((($this) + (($indexToLoad$2*36)|0)|0) + 48|0);
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($this)|0);
 $19 = Math_imul($18, $block)|0;
 $20 = (($14) - ($19))|0;
 $21 = HEAP32[$this>>2]|0;
 $22 = (($21) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_ii[$23 & 4095]($this)|0);
 $25 = ($24|0)<($20|0);
 $26 = $25 ? $24 : $20;
 $27 = ($26|0)<(1);
 if ($27) {
  $$0 = $indexToLoad$2;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = (($this) + 12|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($12,$28)|0);
 $29 = ((($this) + (($indexToLoad$2*12)|0)|0) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($this) + (($indexToLoad$2*36)|0)|0) + 60|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($this) + (($indexToLoad$2*36)|0)|0) + 64|0);
 HEAP32[$32>>2] = $26;
 $33 = (($this) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = Math_imul($34, $block)|0;
 $36 = ((($this) + (($indexToLoad$2*36)|0)|0) + 68|0);
 HEAP32[$36>>2] = $35;
 $37 = ((($this) + (($indexToLoad$2*12)|0)|0) + 28|0);
 HEAP32[$37>>2] = $block;
 __Z16AsyncReadRequestP16AsyncReadCommand($12);
 $$0 = $indexToLoad$2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14FileCacherRead14LockCacheBlockEjPPhS1_($this,$block,$startPos,$endPos) {
 $this = $this|0;
 $block = $block|0;
 $startPos = $startPos|0;
 $endPos = $endPos|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN14FileCacherRead12RequestBlockEi($this,$block)|0);
 $1 = ($0|0)==(0);
 $2 = $1&1;
 $3 = (($block) + 1)|0;
 $4 = ((($this) + (($2*36)|0)|0) + 48|0);
 $5 = ((($this) + (($2*36)|0)|0) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(1);
 if (!($7)) {
  $8 = ((($this) + (($2*12)|0)|0) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($3|0);
  if (!($10)) {
   $11 = (($this) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = HEAP32[$this>>2]|0;
   $14 = (($13) + 20|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (FUNCTION_TABLE_ii[$15 & 4095]($this)|0);
   $17 = Math_imul($16, $3)|0;
   $18 = (($12) - ($17))|0;
   $19 = HEAP32[$this>>2]|0;
   $20 = (($19) + 20|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (FUNCTION_TABLE_ii[$21 & 4095]($this)|0);
   $23 = ($22|0)<($18|0);
   $24 = $23 ? $22 : $18;
   $25 = ($24|0)<(1);
   if (!($25)) {
    $26 = (($this) + 12|0);
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($4,$26)|0);
    $27 = ((($this) + (($2*12)|0)|0) + 24|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ((($this) + (($2*36)|0)|0) + 60|0);
    HEAP32[$29>>2] = $28;
    $30 = ((($this) + (($2*36)|0)|0) + 64|0);
    HEAP32[$30>>2] = $24;
    $31 = (($this) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = Math_imul($32, $3)|0;
    $34 = ((($this) + (($2*36)|0)|0) + 68|0);
    HEAP32[$34>>2] = $33;
    HEAP32[$8>>2] = $3;
    __Z16AsyncReadRequestP16AsyncReadCommand($4);
   }
  }
 }
 $35 = ((($this) + (($0*12)|0)|0) + 32|0);
 HEAP32[$35>>2] = 1;
 $36 = ((($this) + (($0*12)|0)|0) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$startPos>>2] = $37;
 $38 = HEAP32[$36>>2]|0;
 $39 = ((($this) + (($0*36)|0)|0) + 64|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + ($40)|0);
 HEAP32[$endPos>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN14FileCacherRead16UnlockCacheBlockEj($this,$block) {
 $this = $this|0;
 $block = $block|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$02 = 0;
 while(1) {
  $0 = ((($this) + (($i$02*12)|0)|0) + 28|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==($block|0);
  if ($2) {
   $3 = ((($this) + (($i$02*12)|0)|0) + 32|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(1);
   if ($5) {
    break;
   }
  }
  $6 = (($i$02) + 1)|0;
  $7 = ($6|0)<(2);
  if ($7) {
   $i$02 = $6;
  } else {
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14FileCacherRead11GetPathNameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7>>>0)>(4294967279);
 if ($8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = ($7>>>0)<(11);
 if ($9) {
  $10 = $7 << 1;
  $11 = $10&255;
  HEAP8[$agg$result>>0] = $11;
  $12 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $12;
 } else {
  $13 = (($7) + 16)|0;
  $14 = $13 & -16;
  $15 = (__Znwj($14)|0);
  $16 = (($agg$result) + 8|0);
  HEAP32[$16>>2] = $15;
  $17 = $14 | 1;
  HEAP32[$agg$result>>2] = $17;
  $18 = (($agg$result) + 4|0);
  HEAP32[$18>>2] = $7;
  $__p$0$i$i$i = $15;
 }
 _memcpy(($__p$0$i$i$i|0),($5|0),($7|0))|0;
 $19 = (($__p$0$i$i$i) + ($7)|0);
 HEAP8[$19>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN14FileCacherRead12GetCacheSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN14FileCacherRead13GetFileLengthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z13ReadFileCacheR15CacheReaderBasePvjj($cacher,$data,$position,$size) {
 $cacher = $cacher|0;
 $data = $data|0;
 $position = $position|0;
 $size = $size|0;
 var $$$i = 0, $$$i1 = 0, $$0$i = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$04 = 0, $cacheEnd = 0, $cacheStart = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $cacheStart = sp + 4|0;
 $cacheEnd = sp;
 $0 = HEAP32[$cacher>>2]|0;
 $1 = (($0) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($cacher)|0);
 $4 = (($position>>>0) / ($3>>>0))&-1;
 $5 = (($size) + ($position))|0;
 $6 = (($5) + -1)|0;
 $7 = HEAP32[$cacher>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($cacher)|0);
 $11 = (($6>>>0) / ($10>>>0))&-1;
 $12 = ($4|0)>($11|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $block$04 = $4;
 while(1) {
  $13 = HEAP32[$cacher>>2]|0;
  $14 = (($13) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_viiii[$15 & 511]($cacher,$block$04,$cacheStart,$cacheEnd);
  $16 = HEAP32[$cacheStart>>2]|0;
  $17 = HEAP32[$cacher>>2]|0;
  $18 = (($17) + 20|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_ii[$19 & 4095]($cacher)|0);
  $21 = Math_imul($20, $block$04)|0;
  $22 = (($position) - ($21))|0;
  $23 = (($16) + ($22)|0);
  $24 = HEAP32[$cacheStart>>2]|0;
  $25 = ($23>>>0)<($24>>>0);
  if ($25) {
   $$0$i = $24;
  } else {
   $26 = HEAP32[$cacheEnd>>2]|0;
   $27 = ($23>>>0)>($26>>>0);
   $$$i = $27 ? $26 : $23;
   $$0$i = $$$i;
  }
  $28 = HEAP32[$cacher>>2]|0;
  $29 = (($28) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 4095]($cacher)|0);
  $32 = Math_imul($31, $block$04)|0;
  $33 = (($5) - ($32))|0;
  $34 = (($24) + ($33)|0);
  $35 = HEAP32[$cacheStart>>2]|0;
  $36 = ($34>>>0)<($35>>>0);
  if ($36) {
   $$0$i2 = $35;
  } else {
   $37 = HEAP32[$cacheEnd>>2]|0;
   $38 = ($34>>>0)>($37>>>0);
   $$$i1 = $38 ? $37 : $34;
   $$0$i2 = $$$i1;
  }
  $39 = $$0$i;
  $40 = $23;
  $41 = (($39) - ($40))|0;
  $42 = (($data) + ($41)|0);
  $43 = $$0$i2;
  $44 = (($43) - ($39))|0;
  _memcpy(($42|0),($$0$i|0),($44|0))|0;
  $45 = HEAP32[$cacher>>2]|0;
  $46 = (($45) + 16|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_vii[$47 & 4095]($cacher,$block$04);
  $48 = (($block$04) + 1)|0;
  $49 = ($block$04|0)<($11|0);
  if ($49) {
   $block$04 = $48;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN22MemoryCacherReadBlocksC2EPPhij($this,$blocks,$size,$cacheBlockSize) {
 $this = $this|0;
 $blocks = $blocks|0;
 $size = $size|0;
 $cacheBlockSize = $cacheBlockSize|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((640680 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $blocks;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $size;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $cacheBlockSize;
 STACKTOP = sp;return;
}
function __ZN22MemoryCacherReadBlocksD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN22MemoryCacherReadBlocksD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN22MemoryCacherReadBlocks14LockCacheBlockEjPPhS1_($this,$block,$startPos,$endPos) {
 $this = $this|0;
 $block = $block|0;
 $startPos = $startPos|0;
 $endPos = $endPos|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($block<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$startPos>>2] = $3;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_imul($9, $block)|0;
 $11 = (($7) - ($10))|0;
 $12 = ($9|0)<($11|0);
 $13 = $12 ? $9 : $11;
 $14 = (($3) + ($13)|0);
 HEAP32[$endPos>>2] = $14;
 STACKTOP = sp;return;
}
function __ZN22MemoryCacherReadBlocks10DirectReadEPvjj($this,$data,$position,$size) {
 $this = $this|0;
 $data = $data|0;
 $position = $position|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z13ReadFileCacheR15CacheReaderBasePvjj($this,$data,$position,$size);
 STACKTOP = sp;return;
}
function __ZN22MemoryCacherReadBlocks16UnlockCacheBlockEj($this,$block) {
 $this = $this|0;
 $block = $block|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN22MemoryCacherReadBlocks12GetCacheSizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN22MemoryCacherReadBlocks11GetPathNameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0] = 8;
 $0 = (($agg$result) + 1|0);
 HEAP8[$0>>0]=1701736302&255;HEAP8[$0+1>>0]=(1701736302>>8)&255;HEAP8[$0+2>>0]=(1701736302>>16)&255;HEAP8[$0+3>>0]=1701736302>>24;
 $1 = (($agg$result) + 5|0);
 HEAP8[$1>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN22MemoryCacherReadBlocks13GetFileLengthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN22MemoryCacherReadBlocks18GetAddressOfMemoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN9BlobWriteC2ER13dynamic_arrayIhLj16EE24TransferInstructionFlags19BuildTargetPlatform($this,$blob,$flags,$targetPlatform) {
 $this = $this|0;
 $blob = $blob|0;
 $flags = $flags|0;
 $targetPlatform = $targetPlatform|0;
 var $$lcssa$i = 0, $$lobit = 0, $$ph$i = 0, $$ph1$i = 0, $$pre$i$i$i$i$i = 0, $$pre2$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $8 = 0, $9 = 0, $__i$01$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = $blob;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = $targetPlatform;
 $3 = (($this) + 20|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 21|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 24|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$this>>2] = $flags;
 $6 = (($this) + 23|0);
 $7 = $flags >>> 9;
 $$lobit = $7 & 1;
 $8 = $$lobit&255;
 HEAP8[$6>>0] = $8;
 __THREW__ = 0;
 $9 = (invoke_ii(3307,($targetPlatform|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = (($this) + 22|0);
  $13 = $9&1;
  HEAP8[$12>>0] = $13;
  STACKTOP = sp;return;
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 40|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = $19 >>> 8;
 $21 = (($17) + ($20<<2)|0);
 $22 = (($this) + 32|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==($17|0);
 if ($24) {
  $25 = (($this) + 44|0);
  $39 = 0;$48 = $25;$76 = 0;
 } else {
  $26 = HEAP32[$21>>2]|0;
  $27 = $19 & 255;
  $28 = (($26) + ($27<<4)|0);
  $29 = (($this) + 44|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + ($19))|0;
  $32 = $31 >>> 8;
  $33 = (($17) + ($32<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $31 & 255;
  $36 = (($34) + ($35<<4)|0);
  $39 = $36;$48 = $29;$76 = $28;
 }
 $$ph$i = $76;$$ph1$i = $21;
 L8: while(1) {
  $38 = $$ph$i;
  while(1) {
   $37 = ($38|0)==($39|0);
   if ($37) {
    break L8;
   }
   $40 = (($38) + 16|0);
   $41 = HEAP32[$$ph1$i>>2]|0;
   $42 = $40;
   $43 = $41;
   $44 = (($42) - ($43))|0;
   $45 = ($44|0)==(4096);
   if ($45) {
    break;
   } else {
    $38 = $40;
   }
  }
  $46 = (($$ph1$i) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $$ph$i = $47;$$ph1$i = $46;
 }
 HEAP32[$48>>2] = 0;
 $49 = $23;
 $50 = $17;
 $51 = (($49) - ($50))|0;
 $52 = $51 >> 2;
 $53 = ($52>>>0)>(2);
 if ($53) {
  $55 = $17;
  while(1) {
   $54 = HEAP32[$55>>2]|0;
   __ZdlPv($54);
   $56 = HEAP32[$16>>2]|0;
   $57 = (($56) + 4|0);
   HEAP32[$16>>2] = $57;
   $58 = HEAP32[$22>>2]|0;
   $59 = $58;
   $60 = $57;
   $61 = (($59) - ($60))|0;
   $62 = $61 >> 2;
   $63 = ($62>>>0)>(2);
   if ($63) {
    $55 = $57;
   } else {
    $$lcssa$i = $62;
    break;
   }
  }
 } else {
  $$lcssa$i = $52;
 }
 if ((($$lcssa$i|0) == 1)) {
  HEAP32[$18>>2] = 128;
 } else if ((($$lcssa$i|0) == 2)) {
  HEAP32[$18>>2] = 256;
 }
 $64 = HEAP32[$16>>2]|0;
 $65 = HEAP32[$22>>2]|0;
 $66 = ($64|0)==($65|0);
 if (!($66)) {
  $__i$01$i$i$i$i$i = $64;
  while(1) {
   $67 = HEAP32[$__i$01$i$i$i$i$i>>2]|0;
   __ZdlPv($67);
   $68 = (($__i$01$i$i$i$i$i) + 4|0);
   $69 = ($68|0)==($65|0);
   if ($69) {
    break;
   } else {
    $__i$01$i$i$i$i$i = $68;
   }
  }
  $$pre$i$i$i$i$i = HEAP32[$16>>2]|0;
  $$pre2$i$i$i$i$i = HEAP32[$22>>2]|0;
  $70 = ($$pre2$i$i$i$i$i|0)==($$pre$i$i$i$i$i|0);
  if (!($70)) {
   $__new_last2$i$i$i$i$i$i$i$i$i$i = $$pre$i$i$i$i$i;
   $scevgep$i$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i$i) + -4|0);
   $71 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i) + ($71)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i;
   $72 = $uglygep3$i$i$i$i$i$i$i$i$i$i >>> 2;
   $73 = $72 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i$i) + ($73<<2)|0);
   HEAP32[$22>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i;
  }
 }
 $74 = HEAP32[$5>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  ___resumeException($14|0);
  // unreachable;
 }
 __ZdlPv($74);
 ___resumeException($14|0);
 // unreachable;
}
function __ZN9BlobWrite4PushEjPKvj($this,$size,$srcDataPtr,$align) {
 $this = $this|0;
 $size = $size|0;
 $srcDataPtr = $srcDataPtr|0;
 $align = $align|0;
 var $$neg2$i$i$i = 0, $$pre$i$i = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $$pre3$i$i = 0, $$pre4$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (0 - ($4))|0;
 $6 = (($align) + -1)|0;
 $7 = $6 & $5;
 $8 = (($7) + ($4))|0;
 $9 = (($this) + 24|0);
 $10 = (($this) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)==($13|0);
 if ($14) {
  $24 = 0;
 } else {
  $15 = $11;
  $16 = $13;
  $17 = (($15) - ($16))|0;
  $18 = $17 << 6;
  $19 = (($18) + -1)|0;
  $24 = $19;
 }
 $20 = (($this) + 40|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 44|0);
 $23 = HEAP32[$22>>2]|0;
 $$neg2$i$i$i = (($24) - ($21))|0;
 $25 = ($$neg2$i$i$i|0)==($23|0);
 if ($25) {
  __ZNSt3__15dequeIN9BlobWrite11TypeContextENS_9allocatorIS2_EEE19__add_back_capacityEv($9);
  $$pre$i$i = HEAP32[$22>>2]|0;
  $$pre1$i$i = HEAP32[$20>>2]|0;
  $$pre2$i$i = HEAP32[$12>>2]|0;
  $$pre3$i$i = HEAP32[$10>>2]|0;
  $27 = $$pre$i$i;$28 = $$pre1$i$i;$30 = $$pre3$i$i;$31 = $$pre2$i$i;
 } else {
  $27 = $23;$28 = $21;$30 = $11;$31 = $13;
 }
 $26 = (($27) + ($28))|0;
 $29 = ($30|0)==($31|0);
 if ($29) {
  $42 = $27;
 } else {
  $32 = $26 >>> 8;
  $33 = (($31) + ($32<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $26 & 255;
  $36 = (($34) + ($35<<4)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   $42 = $27;
  } else {
   HEAP32[$36>>2] = $8;
   $38 = ((($34) + ($35<<4)|0) + 4|0);
   HEAP32[$38>>2] = 0;
   $39 = ((($34) + ($35<<4)|0) + 8|0);
   HEAP32[$39>>2] = $srcDataPtr;
   $40 = ((($34) + ($35<<4)|0) + 12|0);
   HEAP32[$40>>2] = $size;
   $$pre4$i$i = HEAP32[$22>>2]|0;
   $42 = $$pre4$i$i;
  }
 }
 $41 = (($42) + 1)|0;
 HEAP32[$22>>2] = $41;
 $43 = HEAP32[$1>>2]|0;
 $44 = (($8) + ($size))|0;
 HEAP8[$0>>0] = 0;
 __ZN13dynamic_arrayIhLj16EE18resize_initializedEjRKhb($43,$44,$0,0);
 $45 = (($this) + 20|0);
 HEAP8[$45>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIhLj16EE18resize_initializedEjRKhb($this,$size,$t,$double_on_resize) {
 $this = $this|0;
 $size = $size|0;
 $t = $t|0;
 $double_on_resize = $double_on_resize|0;
 var $$01$i = 0, $$byval_copy1 = 0, $$size = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $requested_size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)<($size>>>0);
 do {
  if ($4) {
   if ($double_on_resize) {
    $5 = $2 << 1;
    $6 = ($5>>>0)>($size>>>0);
    $$size = $6 ? $5 : $size;
    $requested_size$0 = $$size;
   } else {
    $requested_size$0 = $size;
   }
   $7 = ($3>>>0)<($requested_size$0>>>0);
   if ($7) {
    $8 = ($2|0)>(-1);
    if ($8) {
     HEAP32[$1>>2] = $requested_size$0;
     $9 = HEAP32[$this>>2]|0;
     $10 = (($this) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     HEAP32[$0>>2] = $11;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $12 = (__Z16realloc_internalPvji10MemLabelIdiPKci($9,$requested_size$0,16,$$byval_copy1,0,640728,370)|0);
     HEAP32[$this>>2] = $12;
     break;
    } else {
     $13 = (($this) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     HEAP32[$0>>2] = $14;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $15 = (__Z15malloc_internaljj10MemLabelIdiPKci($requested_size$0,16,$$byval_copy1,0,640728,352)|0);
     $16 = HEAP32[$this>>2]|0;
     $17 = (($this) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     _memcpy(($15|0),($16|0),($18|0))|0;
     HEAP32[$1>>2] = $requested_size$0;
     HEAP32[$this>>2] = $15;
     break;
    }
   }
  }
 } while(0);
 $19 = (($this) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20>>>0)<($size>>>0);
 if (!($21)) {
  HEAP32[$19>>2] = $size;
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$this>>2]|0;
 $23 = (($22) + ($size)|0);
 $24 = ($20|0)==($size|0);
 if ($24) {
  HEAP32[$19>>2] = $size;
  STACKTOP = sp;return;
 }
 $25 = (($22) + ($20)|0);
 $$01$i = $25;
 while(1) {
  $26 = ($$01$i|0)==(0|0);
  if (!($26)) {
   $27 = HEAP8[$t>>0]|0;
   HEAP8[$$01$i>>0] = $27;
  }
  $28 = (($$01$i) + 1|0);
  $29 = ($28|0)==($23|0);
  if ($29) {
   break;
  } else {
   $$01$i = $28;
  }
 }
 HEAP32[$19>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$isValidPtr,$reduceCopyData,$alignOfT) {
 $this = $this|0;
 $isValidPtr = $isValidPtr|0;
 $reduceCopyData = $reduceCopyData|0;
 $alignOfT = $alignOfT|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = $isValidPtr&1;
 HEAP8[$0>>0] = $1;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (0 - ($5))|0;
 $7 = (($alignOfT) + -1)|0;
 $8 = $7 & $6;
 $9 = (($8) + ($5))|0;
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (($9) - ($26))|0;
 $28 = (($this) + 22|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)==(0);
 $31 = $isValidPtr ? $27 : 0;
 $32 = (($this) + 23|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 if ($30) {
  if ($34) {
   $49 = $31;
  } else {
   $46 = (_llvm_bswap_i32(($31|0))|0);
   $49 = $46;
  }
  $47 = HEAP32[$3>>2]|0;
  $48 = (($47) + ($26)|0);
  HEAP8[$48>>0]=$49&255;HEAP8[$48+1>>0]=($49>>8)&255;HEAP8[$48+2>>0]=($49>>16)&255;HEAP8[$48+3>>0]=$49>>24;
 } else {
  if ($34) {
   $39 = $31;$40 = 0;$45 = 0;
  } else {
   $35 = (_llvm_bswap_i32(($31|0))|0);
   $39 = 0;$40 = 0;$45 = $35;
  }
  $36 = HEAP32[$3>>2]|0;
  $37 = (($36) + ($26)|0);
  $38 = $39 | $40;
  $41 = $37;
  $42 = $41;
  HEAP8[$42>>0]=$38&255;HEAP8[$42+1>>0]=($38>>8)&255;HEAP8[$42+2>>0]=($38>>16)&255;HEAP8[$42+3>>0]=$38>>24;
  $43 = (($41) + 4)|0;
  $44 = $43;
  HEAP8[$44>>0]=$45&255;HEAP8[$44+1>>0]=($45>>8)&255;HEAP8[$44+2>>0]=($45>>16)&255;HEAP8[$44+3>>0]=$45>>24;
 }
 $50 = ($reduceCopyData|0)==(0|0);
 do {
  if (!($50)) {
   if ($isValidPtr) {
    $51 = HEAP32[$10>>2]|0;
    $52 = HEAP32[$12>>2]|0;
    $53 = (($51) + -1)|0;
    $54 = (($53) + ($52))|0;
    $55 = HEAP32[$16>>2]|0;
    $56 = $54 >>> 8;
    $57 = (($55) + ($56<<2)|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = $54 & 255;
    $60 = (($58) + ($59<<4)|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ((($58) + ($59<<4)|0) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($63) + ($61))|0;
    HEAP32[$reduceCopyData>>2] = $64;
    $65 = (($reduceCopyData) + 4|0);
    HEAP32[$65>>2] = $9;
    $66 = HEAP32[$2>>2]|0;
    $67 = (($66) + 8|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($reduceCopyData) + 8|0);
    HEAP32[$69>>2] = $68;
    break;
   } else {
    HEAP32[$reduceCopyData>>2] = 1048575;
    $70 = (($reduceCopyData) + 4|0);
    HEAP32[$70>>2] = 1048575;
    $71 = (($reduceCopyData) + 8|0);
    HEAP32[$71>>2] = 1048575;
    break;
   }
  }
 } while(0);
 $72 = HEAP8[$28>>0]|0;
 $73 = ($72<<24>>24)!=(0);
 $74 = $73 ? 8 : 4;
 $75 = HEAP32[$10>>2]|0;
 $76 = HEAP32[$12>>2]|0;
 $77 = (($75) + -1)|0;
 $78 = (($77) + ($76))|0;
 $79 = HEAP32[$16>>2]|0;
 $80 = $78 >>> 8;
 $81 = (($79) + ($80<<2)|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = $78 & 255;
 $84 = ((($82) + ($83<<4)|0) + 4|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($85) + ($74))|0;
 HEAP32[$84>>2] = $86;
 $87 = (($this) + 16|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(-2);
 if (!($89)) {
  STACKTOP = sp;return;
 }
 $90 = HEAP32[$10>>2]|0;
 $91 = HEAP32[$12>>2]|0;
 $92 = (($90) + -1)|0;
 $93 = (($92) + ($91))|0;
 $94 = $93 >>> 8;
 $95 = (($79) + ($94<<2)|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = $93 & 255;
 $98 = ((($96) + ($97<<4)|0) + 4|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = (($99) + 4)|0;
 HEAP32[$98>>2] = $100;
 STACKTOP = sp;return;
}
function __ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 STACKTOP = sp;return ($2|0);
}
function __ZN9BlobWrite24ValidateSerializedLayoutEPKvPKc($this,$srcData,$name) {
 $this = $this|0;
 $srcData = $srcData|0;
 $name = $name|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduce,$alignOfT) {
 $this = $this|0;
 $reduce = $reduce|0;
 $alignOfT = $alignOfT|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 21|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($reduce) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(1048575);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) - ($5))|0;
 $12 = ($5|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$8>>2]|0;
 $i$03 = 0;
 while(1) {
  $16 = (($13) + ($i$03)|0);
  $17 = (($13) + ($5)|0);
  $18 = (_memcmp($16,$17,$11)|0);
  $19 = ($18|0)==(0);
  $15 = (($i$03) + ($alignOfT))|0;
  if ($19) {
   break;
  }
  $14 = ($15>>>0)<($5>>>0);
  if ($14) {
   $i$03 = $15;
  } else {
   label = 15;
   break;
  }
 }
 if ((label|0) == 15) {
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$reduce>>2]|0;
 $21 = (($i$03) - ($20))|0;
 $22 = (($this) + 22|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 $25 = (($this) + 23|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if ($24) {
  if ($27) {
   $40 = $21;
  } else {
   $38 = (_llvm_bswap_i32(($21|0))|0);
   $40 = $38;
  }
  $39 = (($13) + ($20)|0);
  HEAP8[$39>>0]=$40&255;HEAP8[$39+1>>0]=($40>>8)&255;HEAP8[$39+2>>0]=($40>>16)&255;HEAP8[$39+3>>0]=$40>>24;
 } else {
  if ($27) {
   $31 = $21;$32 = 0;$37 = 0;
  } else {
   $28 = (_llvm_bswap_i32(($21|0))|0);
   $31 = 0;$32 = 0;$37 = $28;
  }
  $29 = (($13) + ($20)|0);
  $30 = $31 | $32;
  $33 = $29;
  $34 = $33;
  HEAP8[$34>>0]=$30&255;HEAP8[$34+1>>0]=($30>>8)&255;HEAP8[$34+2>>0]=($30>>16)&255;HEAP8[$34+3>>0]=$30>>24;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP8[$36>>0]=$37&255;HEAP8[$36+1>>0]=($37>>8)&255;HEAP8[$36+2>>0]=($37>>16)&255;HEAP8[$36+3>>0]=$37>>24;
 }
 $41 = HEAP32[$7>>2]|0;
 $42 = (($reduce) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP8[$0>>0] = 0;
 __ZN13dynamic_arrayIhLj16EE18resize_initializedEjRKhb($41,$43,$0,0);
 STACKTOP = sp;return;
}
function __ZNSt3__15dequeIN9BlobWrite11TypeContextENS_9allocatorIS2_EEE19__add_back_capacityEv($this) {
 $this = $this|0;
 var $$0153 = 0, $$055 = 0, $$pr$pre$i = 0, $$pr$pre$i36 = 0, $$pre = 0, $$pre$i = 0, $$pre$i33 = 0, $$pre50 = 0, $$pre8$i = 0, $$pre8$i19 = 0, $$pre8$i28 = 0, $$pre8$i38 = 0, $$sum = 0, $$sum$i = 0, $$sum$i30 = 0, $$sum41 = 0, $$sum42 = 0, $$sum43 = 0, $$sum51 = 0, $$sum52 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__buf = 0, $__i$0 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $__buf = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>(255);
 if ($3) {
  $4 = (($2) + -256)|0;
  HEAP32[$1>>2] = $4;
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($6) + 4|0);
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  do {
   if ($13) {
    $14 = HEAP32[$this>>2]|0;
    $15 = ($8>>>0)>($14>>>0);
    if ($15) {
     $16 = $8;
     $17 = $14;
     $18 = (($16) - ($17))|0;
     $19 = $18 >> 2;
     $20 = (($19) + 1)|0;
     $21 = (($20|0) / -2)&-1;
     $$sum42 = (($21) + 1)|0;
     $22 = (($6) + ($$sum42<<2)|0);
     $23 = $10;
     $24 = (($23) - ($16))|0;
     $25 = $24 >> 2;
     _memmove(($22|0),($8|0),($24|0))|0;
     $$sum$i = (($25) + 1)|0;
     $$sum43 = (($$sum$i) + ($21))|0;
     $26 = (($6) + ($$sum43<<2)|0);
     HEAP32[$9>>2] = $26;
     $27 = HEAP32[$5>>2]|0;
     $28 = (($27) + ($21<<2)|0);
     HEAP32[$5>>2] = $28;
     $54 = $26;
     label = 13;
     break;
    }
    $29 = $10;
    $30 = $14;
    $31 = (($29) - ($30))|0;
    $32 = $31 >> 1;
    $33 = ($32|0)==(0);
    $34 = $33 ? 1 : $32;
    $35 = $34 >>> 2;
    $36 = $34 << 2;
    $37 = (__Znwj($36)|0);
    $38 = (($37) + ($35<<2)|0);
    $39 = (($37) + ($34<<2)|0);
    $40 = ($8|0)==($10|0);
    if ($40) {
     $49 = $38;$51 = $14;
    } else {
     $42 = $38;$44 = $8;
     while(1) {
      $41 = ($42|0)==(0|0);
      if ($41) {
       $46 = 0;
      } else {
       $43 = HEAP32[$44>>2]|0;
       HEAP32[$42>>2] = $43;
       $46 = $42;
      }
      $45 = (($46) + 4|0);
      $47 = (($44) + 4|0);
      $48 = ($47|0)==($10|0);
      if ($48) {
       break;
      } else {
       $42 = $45;$44 = $47;
      }
     }
     $$pre$i = HEAP32[$this>>2]|0;
     $49 = $45;$51 = $$pre$i;
    }
    HEAP32[$this>>2] = $37;
    HEAP32[$5>>2] = $38;
    HEAP32[$9>>2] = $49;
    HEAP32[$11>>2] = $39;
    $50 = ($51|0)==(0|0);
    if ($50) {
     $53 = $49;
     label = 12;
    } else {
     __ZdlPv($51);
     $$pr$pre$i = HEAP32[$9>>2]|0;
     $53 = $$pr$pre$i;
     label = 12;
    }
   } else {
    $53 = $10;
    label = 12;
   }
  } while(0);
  if ((label|0) == 12) {
   $52 = ($53|0)==(0|0);
   if ($52) {
    $56 = 0;
   } else {
    $54 = $53;
    label = 13;
   }
  }
  if ((label|0) == 13) {
   HEAP32[$54>>2] = $7;
   $$pre8$i = HEAP32[$9>>2]|0;
   $56 = $$pre8$i;
  }
  $55 = (($56) + 4|0);
  HEAP32[$9>>2] = $55;
  STACKTOP = sp;return;
 }
 $57 = (($this) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $58;
 $62 = $60;
 $63 = (($61) - ($62))|0;
 $64 = $63 >> 2;
 $65 = (($this) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$this>>2]|0;
 $68 = $66;
 $69 = $67;
 $70 = (($68) - ($69))|0;
 $71 = $70 >> 2;
 $72 = ($64>>>0)<($71>>>0);
 if ($72) {
  $73 = ($66|0)==($58|0);
  $74 = (__Znwj(4096)|0);
  if (!($73)) {
   $75 = ($58|0)==(0|0);
   if ($75) {
    $77 = 0;
   } else {
    HEAP32[$58>>2] = $74;
    $$pre8$i28 = HEAP32[$57>>2]|0;
    $77 = $$pre8$i28;
   }
   $76 = (($77) + 4|0);
   HEAP32[$57>>2] = $76;
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $74;
  __ZNSt3__114__split_bufferIPN9BlobWrite11TypeContextENS_9allocatorIS3_EEE10push_frontERKS3_($this,$0);
  $78 = HEAP32[$59>>2]|0;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($78) + 4|0);
  HEAP32[$59>>2] = $80;
  $81 = HEAP32[$57>>2]|0;
  $82 = HEAP32[$65>>2]|0;
  $83 = ($81|0)==($82|0);
  do {
   if ($83) {
    $84 = HEAP32[$this>>2]|0;
    $85 = ($80>>>0)>($84>>>0);
    if ($85) {
     $86 = $80;
     $87 = $84;
     $88 = (($86) - ($87))|0;
     $89 = $88 >> 2;
     $90 = (($89) + 1)|0;
     $91 = (($90|0) / -2)&-1;
     $$sum = (($91) + 1)|0;
     $92 = (($78) + ($$sum<<2)|0);
     $93 = $81;
     $94 = (($93) - ($86))|0;
     $95 = $94 >> 2;
     _memmove(($92|0),($80|0),($94|0))|0;
     $$sum$i30 = (($95) + 1)|0;
     $$sum41 = (($$sum$i30) + ($91))|0;
     $96 = (($78) + ($$sum41<<2)|0);
     HEAP32[$57>>2] = $96;
     $97 = HEAP32[$59>>2]|0;
     $98 = (($97) + ($91<<2)|0);
     HEAP32[$59>>2] = $98;
     $124 = $96;
     label = 31;
     break;
    }
    $99 = $81;
    $100 = $84;
    $101 = (($99) - ($100))|0;
    $102 = $101 >> 1;
    $103 = ($102|0)==(0);
    $104 = $103 ? 1 : $102;
    $105 = $104 >>> 2;
    $106 = $104 << 2;
    $107 = (__Znwj($106)|0);
    $108 = (($107) + ($105<<2)|0);
    $109 = (($107) + ($104<<2)|0);
    $110 = ($80|0)==($81|0);
    if ($110) {
     $119 = $108;$121 = $84;
    } else {
     $112 = $108;$114 = $80;
     while(1) {
      $111 = ($112|0)==(0|0);
      if ($111) {
       $116 = 0;
      } else {
       $113 = HEAP32[$114>>2]|0;
       HEAP32[$112>>2] = $113;
       $116 = $112;
      }
      $115 = (($116) + 4|0);
      $117 = (($114) + 4|0);
      $118 = ($117|0)==($81|0);
      if ($118) {
       break;
      } else {
       $112 = $115;$114 = $117;
      }
     }
     $$pre$i33 = HEAP32[$this>>2]|0;
     $119 = $115;$121 = $$pre$i33;
    }
    HEAP32[$this>>2] = $107;
    HEAP32[$59>>2] = $108;
    HEAP32[$57>>2] = $119;
    HEAP32[$65>>2] = $109;
    $120 = ($121|0)==(0|0);
    if ($120) {
     $123 = $119;
     label = 30;
    } else {
     __ZdlPv($121);
     $$pr$pre$i36 = HEAP32[$57>>2]|0;
     $123 = $$pr$pre$i36;
     label = 30;
    }
   } else {
    $123 = $81;
    label = 30;
   }
  } while(0);
  if ((label|0) == 30) {
   $122 = ($123|0)==(0|0);
   if ($122) {
    $126 = 0;
   } else {
    $124 = $123;
    label = 31;
   }
  }
  if ((label|0) == 31) {
   HEAP32[$124>>2] = $79;
   $$pre8$i38 = HEAP32[$57>>2]|0;
   $126 = $$pre8$i38;
  }
  $125 = (($126) + 4|0);
  HEAP32[$57>>2] = $125;
  STACKTOP = sp;return;
 }
 $127 = $70 >> 1;
 $128 = ($127|0)==(0);
 $129 = $128 ? 1 : $127;
 $130 = (($this) + 12|0);
 $131 = (($__buf) + 12|0);
 $132 = (($__buf) + 16|0);
 HEAP32[$132>>2] = $130;
 $133 = $129 << 2;
 $134 = (__Znwj($133)|0);
 HEAP32[$__buf>>2] = $134;
 $135 = (($134) + ($64<<2)|0);
 $136 = (($__buf) + 8|0);
 HEAP32[$136>>2] = $135;
 $137 = (($__buf) + 4|0);
 HEAP32[$137>>2] = $135;
 $138 = (($134) + ($129<<2)|0);
 HEAP32[$131>>2] = $138;
 __THREW__ = 0;
 $139 = (invoke_ii(2988,4096)|0);
 $140 = __THREW__; __THREW__ = 0;
 $141 = $140&1;
 L54: do {
  if ($141) {
   label = 42;
  } else {
   $142 = ($64|0)==($129|0);
   do {
    if ($142) {
     $143 = ($135>>>0)>($134>>>0);
     $144 = $135;
     $145 = $134;
     $146 = (($144) - ($145))|0;
     if ($143) {
      $147 = $146 >> 2;
      $148 = (($147) + 1)|0;
      $149 = (($148|0) / -2)&-1;
      $$sum52 = (($64) + ($149))|0;
      $150 = (($134) + ($$sum52<<2)|0);
      HEAP32[$136>>2] = $150;
      HEAP32[$137>>2] = $150;
      $163 = $150;
      break;
     }
     $151 = $146 >> 1;
     $152 = ($151|0)==(0);
     $153 = $152 ? 1 : $151;
     $154 = $153 << 2;
     __THREW__ = 0;
     $155 = (invoke_ii(2988,($154|0))|0);
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if ($157) {
      label = 42;
      break L54;
     }
     $158 = $153 >>> 2;
     $159 = (($155) + ($158<<2)|0);
     $160 = (($155) + ($153<<2)|0);
     HEAP32[$__buf>>2] = $155;
     HEAP32[$137>>2] = $159;
     HEAP32[$136>>2] = $159;
     HEAP32[$131>>2] = $160;
     $161 = ($134|0)==(0|0);
     if ($161) {
      $163 = $159;
     } else {
      __ZdlPv($134);
      $163 = $159;
     }
    } else {
     $163 = $135;
    }
   } while(0);
   $162 = ($163|0)==(0|0);
   if ($162) {
    $175 = 0;
   } else {
    HEAP32[$163>>2] = $139;
    $$pre8$i19 = HEAP32[$136>>2]|0;
    $175 = $$pre8$i19;
   }
   $174 = (($175) + 4|0);
   HEAP32[$136>>2] = $174;
   $176 = HEAP32[$57>>2]|0;
   $__i$0 = $176;
   while(1) {
    $177 = HEAP32[$59>>2]|0;
    $178 = ($__i$0|0)==($177|0);
    if ($178) {
     break;
    }
    $179 = (($__i$0) + -4|0);
    __THREW__ = 0;
    invoke_vii(3228,($__buf|0),($179|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if ($181) {
     label = 51;
     break;
    } else {
     $__i$0 = $179;
    }
   }
   if ((label|0) == 51) {
    $194 = ___cxa_find_matching_catch()|0;
    $195 = tempRet0;
    $$pre = HEAP32[$137>>2]|0;
    $$pre50 = HEAP32[$136>>2]|0;
    $196 = ($$pre50|0)==($$pre|0);
    if ($196) {
     $$0153 = $194;$$055 = $195;
     break;
    }
    $__new_last2$i$i$i$i$i = $$pre;
    $scevgep$i$i$i$i$i = (($$pre50) + -4|0);
    $197 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($197)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $198 = $uglygep3$i$i$i$i$i >>> 2;
    $199 = $198 ^ -1;
    $scevgep4$i$i$i$i$i = (($$pre50) + ($199<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i;
    $$0153 = $194;$$055 = $195;
    break;
   }
   $182 = HEAP32[$this>>2]|0;
   $183 = HEAP32[$__buf>>2]|0;
   HEAP32[$this>>2] = $183;
   HEAP32[$__buf>>2] = $182;
   $184 = HEAP32[$137>>2]|0;
   HEAP32[$59>>2] = $184;
   HEAP32[$137>>2] = $__i$0;
   $185 = HEAP32[$57>>2]|0;
   $186 = HEAP32[$136>>2]|0;
   HEAP32[$57>>2] = $186;
   HEAP32[$136>>2] = $185;
   $187 = HEAP32[$65>>2]|0;
   $188 = HEAP32[$131>>2]|0;
   HEAP32[$65>>2] = $188;
   HEAP32[$131>>2] = $187;
   $189 = ($185|0)==($__i$0|0);
   if (!($189)) {
    $__new_last2$i$i$i$i$i2 = $__i$0;
    $scevgep$i$i$i$i$i3 = (($185) + -4|0);
    $190 = (0 - ($__new_last2$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($190)|0);
    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
    $191 = $uglygep3$i$i$i$i$i6 >>> 2;
    $192 = $191 ^ -1;
    $scevgep4$i$i$i$i$i7 = (($185) + ($192<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i7;
   }
   $193 = ($182|0)==(0|0);
   if ($193) {
    STACKTOP = sp;return;
   }
   __ZdlPv($182);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 42) {
  $164 = ___cxa_find_matching_catch(0|0)|0;
  $165 = tempRet0;
  (___cxa_begin_catch(($164|0))|0);
  $$sum51 = (($64) + -1)|0;
  $166 = (($134) + ($$sum51<<2)|0);
  $167 = HEAP32[$166>>2]|0;
  __ZdlPv($167);
  __THREW__ = 0;
  invoke_v(140);
  $168 = __THREW__; __THREW__ = 0;
  $169 = $168&1;
  if (!($169)) {
   // unreachable;
  }
  $170 = ___cxa_find_matching_catch()|0;
  $171 = tempRet0;
  __THREW__ = 0;
  invoke_v(66);
  $172 = __THREW__; __THREW__ = 0;
  $173 = $172&1;
  if ($173) {
   $202 = ___cxa_find_matching_catch(0|0)|0;
   $203 = tempRet0;
   ___clang_call_terminate($202);
   // unreachable;
  } else {
   $$0153 = $170;$$055 = $171;
  }
 }
 $200 = HEAP32[$__buf>>2]|0;
 $201 = ($200|0)==(0|0);
 if ($201) {
  ___resumeException($$0153|0);
  // unreachable;
 }
 __ZdlPv($200);
 ___resumeException($$0153|0);
 // unreachable;
}
function __ZNSt3__114__split_bufferIPN9BlobWrite11TypeContextENS_9allocatorIS3_EEE10push_frontERKS3_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIPN9BlobWrite11TypeContextERNS_9allocatorIS3_EEE10push_frontERKS3_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __Z22IsBuildTarget64BitBlob19BuildTargetPlatform($target) {
 $target = $target|0;
 var $$0 = 0, $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($target|0) == -2)) {
  $$0 = 0;
 } else if ((($target|0) == 25) | (($target|0) == 19) | (($target|0) == 24)) {
  $0 = 1;
  label = 3;
 } else {
  $0 = 0;
  label = 3;
 }
 if ((label|0) == 3) {
  $$0 = $0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab16ParserSubProgram14AddBufferParamEiPKc($this,$index,$name) {
 $this = $this|0;
 $index = $index|0;
 $name = $name|0;
 var $$0 = 0, $$01 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (_strlen(($name|0))|0);
 $3 = ($2>>>0)>(4294967279);
 if ($3) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $4 = ($2>>>0)<(11);
 if ($4) {
  $5 = $2 << 1;
  $6 = $5&255;
  HEAP8[$1>>0] = $6;
  $7 = (($1) + 1|0);
  $$pre$phiZ2D = $1;$17 = $6;$__p$0$i$i$i = $7;
 } else {
  $8 = (($2) + 16)|0;
  $9 = $8 & -16;
  $10 = (__Znwj($9)|0);
  $11 = (($1) + 8|0);
  HEAP32[$11>>2] = $10;
  $12 = $9 | 1;
  HEAP32[$1>>2] = $12;
  $13 = (($1) + 4|0);
  HEAP32[$13>>2] = $2;
  $14 = $12&255;
  $$pre$phiZ2D = $1;$17 = $14;$__p$0$i$i$i = $10;
 }
 _memcpy(($__p$0$i$i$i|0),($name|0),($2|0))|0;
 $15 = (($__p$0$i$i$i) + ($2)|0);
 HEAP8[$15>>0] = 0;
 $16 = $17 & 1;
 $18 = ($16<<24>>24)==(0);
 L8: do {
  if ($18) {
   ;HEAP32[$0+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
   label = 16;
  } else {
   $19 = (($1) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($1) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22>>>0)>(4294967279);
   do {
    if ($23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      // unreachable;
     }
    } else {
     $26 = ($22>>>0)<(11);
     if ($26) {
      $27 = $22 << 1;
      $28 = $27&255;
      HEAP8[$0>>0] = $28;
      $29 = (($0) + 1|0);
      $__p$0$i$i$i$i$i = $29;
     } else {
      $30 = (($22) + 16)|0;
      $31 = $30 & -16;
      __THREW__ = 0;
      $32 = (invoke_ii(2988,($31|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = (($0) + 8|0);
      HEAP32[$35>>2] = $32;
      $36 = $31 | 1;
      HEAP32[$0>>2] = $36;
      $37 = (($0) + 4|0);
      HEAP32[$37>>2] = $22;
      $__p$0$i$i$i$i$i = $32;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($20|0),($22|0))|0;
     $38 = (($__p$0$i$i$i$i$i) + ($22)|0);
     HEAP8[$38>>0] = 0;
     label = 16;
     break L8;
    }
   } while(0);
   $84 = ___cxa_find_matching_catch()|0;
   $85 = tempRet0;
   $$0 = $85;$$01 = $84;
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   $39 = (($0) + 12|0);
   HEAP32[$39>>2] = $index;
   $40 = (($this) + 188|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($this) + 192|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($41|0)==($43|0);
   do {
    if ($44) {
     $72 = (($this) + 184|0);
     __THREW__ = 0;
     invoke_vii(3229,($72|0),($0|0));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      label = 37;
     }
    } else {
     $45 = ($41|0)==(0|0);
     if ($45) {
      $71 = 0;
     } else {
      $46 = HEAP8[$0>>0]|0;
      $47 = $46 & 1;
      $48 = ($47<<24>>24)==(0);
      if ($48) {
       ;HEAP32[$41+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$0+8>>2]|0;
      } else {
       $49 = (($0) + 8|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = (($0) + 4|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52>>>0)>(4294967279);
       if ($53) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 37;
         break;
        }
        // unreachable;
       }
       $56 = ($52>>>0)<(11);
       if ($56) {
        $57 = $52 << 1;
        $58 = $57&255;
        HEAP8[$41>>0] = $58;
        $59 = (($41) + 1|0);
        $__p$0$i$i$i$i$i$i$i = $59;
       } else {
        $60 = (($52) + 16)|0;
        $61 = $60 & -16;
        __THREW__ = 0;
        $62 = (invoke_ii(2988,($61|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 37;
         break;
        }
        $65 = (($41) + 8|0);
        HEAP32[$65>>2] = $62;
        $66 = $61 | 1;
        HEAP32[$41>>2] = $66;
        $67 = (($41) + 4|0);
        HEAP32[$67>>2] = $52;
        $__p$0$i$i$i$i$i$i$i = $62;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i|0),($50|0),($52|0))|0;
       $68 = (($__p$0$i$i$i$i$i$i$i) + ($52)|0);
       HEAP8[$68>>0] = 0;
      }
      $69 = (($41) + 12|0);
      HEAP32[$69>>2] = $index;
      $$pre$i = HEAP32[$40>>2]|0;
      $71 = $$pre$i;
     }
     $70 = (($71) + 16|0);
     HEAP32[$40>>2] = $70;
    }
   } while(0);
   if ((label|0) == 37) {
    $86 = ___cxa_find_matching_catch()|0;
    $87 = tempRet0;
    $88 = HEAP8[$0>>0]|0;
    $89 = $88 & 1;
    $90 = ($89<<24>>24)==(0);
    if ($90) {
     $$0 = $87;$$01 = $86;
     break;
    }
    $91 = (($0) + 8|0);
    $92 = HEAP32[$91>>2]|0;
    __ZdlPv($92);
    $$0 = $87;$$01 = $86;
    break;
   }
   $75 = HEAP8[$0>>0]|0;
   $76 = $75 & 1;
   $77 = ($76<<24>>24)==(0);
   if (!($77)) {
    $78 = (($0) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    __ZdlPv($79);
   }
   $80 = $17 & 1;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = (($1) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   __ZdlPv($83);
   STACKTOP = sp;return;
  }
 } while(0);
 $93 = $17 & 1;
 $94 = ($93<<24>>24)==(0);
 if ($94) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $95 = (($1) + 8|0);
 $96 = HEAP32[$95>>2]|0;
 __ZdlPv($96);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN9ShaderLab16ParserSubProgramD2Ev($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i14 = 0, $$pre$i$i$i$i$i17 = 0, $$pre$i$i$i$i$i20 = 0, $$pre$i$i$i$i$i8 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i21 = 0, $$pre$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 208|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 212|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if ($5) {
   $15 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = (($7) + -16|0);
    HEAP32[$3>>2] = $6;
    $8 = HEAP8[$6>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $12 = $6;
    } else {
     $13 = (($7) + -8|0);
     $14 = HEAP32[$13>>2]|0;
     __ZdlPv($14);
     $$pre$i$i$i$i$i = HEAP32[$3>>2]|0;
     $12 = $$pre$i$i$i$i$i;
    }
    $11 = ($12|0)==($1|0);
    if ($11) {
     break;
    } else {
     $7 = $12;
    }
   }
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $15 = $$pre$i$i$i;
  }
  __ZdlPv($15);
 }
 $16 = (($this) + 196|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 do {
  if (!($18)) {
   $19 = (($this) + 200|0);
   while(1) {
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==($17|0);
    if ($21) {
     label = 13;
     break;
    }
    $22 = (($20) + -40|0);
    HEAP32[$19>>2] = $22;
    __THREW__ = 0;
    invoke_vi(3574,($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 12;
     break;
    }
   }
   if ((label|0) == 12) {
    $25 = ___cxa_find_matching_catch()|0;
    $26 = tempRet0;
    ___cxa_call_unexpected(($25|0));
    // unreachable;
   }
   else if ((label|0) == 13) {
    $27 = HEAP32[$16>>2]|0;
    __ZdlPv($27);
    break;
   }
  }
 } while(0);
 $28 = (($this) + 184|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = (($this) + 188|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==($29|0);
  if ($33) {
   $43 = $29;
  } else {
   $35 = $32;
   while(1) {
    $34 = (($35) + -16|0);
    HEAP32[$31>>2] = $34;
    $36 = HEAP8[$34>>0]|0;
    $37 = $36 & 1;
    $38 = ($37<<24>>24)==(0);
    if ($38) {
     $40 = $34;
    } else {
     $41 = (($35) + -8|0);
     $42 = HEAP32[$41>>2]|0;
     __ZdlPv($42);
     $$pre$i$i$i$i$i8 = HEAP32[$31>>2]|0;
     $40 = $$pre$i$i$i$i$i8;
    }
    $39 = ($40|0)==($29|0);
    if ($39) {
     break;
    } else {
     $35 = $40;
    }
   }
   $$pre$i$i$i9 = HEAP32[$28>>2]|0;
   $43 = $$pre$i$i$i9;
  }
  __ZdlPv($43);
 }
 $44 = (($this) + 172|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = (($this) + 176|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48|0)==($45|0);
  if ($49) {
   $59 = $45;
  } else {
   $51 = $48;
   while(1) {
    $50 = (($51) + -24|0);
    HEAP32[$47>>2] = $50;
    $52 = HEAP8[$50>>0]|0;
    $53 = $52 & 1;
    $54 = ($53<<24>>24)==(0);
    if ($54) {
     $56 = $50;
    } else {
     $57 = (($51) + -16|0);
     $58 = HEAP32[$57>>2]|0;
     __ZdlPv($58);
     $$pre$i$i$i$i$i14 = HEAP32[$47>>2]|0;
     $56 = $$pre$i$i$i$i$i14;
    }
    $55 = ($56|0)==($45|0);
    if ($55) {
     break;
    } else {
     $51 = $56;
    }
   }
   $$pre$i$i$i15 = HEAP32[$44>>2]|0;
   $59 = $$pre$i$i$i15;
  }
  __ZdlPv($59);
 }
 $60 = (($this) + 160|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  $63 = (($this) + 164|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = ($64|0)==($61|0);
  if ($65) {
   $75 = $61;
  } else {
   $67 = $64;
   while(1) {
    $66 = (($67) + -24|0);
    HEAP32[$63>>2] = $66;
    $68 = HEAP8[$66>>0]|0;
    $69 = $68 & 1;
    $70 = ($69<<24>>24)==(0);
    if ($70) {
     $72 = $66;
    } else {
     $73 = (($67) + -16|0);
     $74 = HEAP32[$73>>2]|0;
     __ZdlPv($74);
     $$pre$i$i$i$i$i17 = HEAP32[$63>>2]|0;
     $72 = $$pre$i$i$i$i$i17;
    }
    $71 = ($72|0)==($61|0);
    if ($71) {
     break;
    } else {
     $67 = $72;
    }
   }
   $$pre$i$i$i18 = HEAP32[$60>>2]|0;
   $75 = $$pre$i$i$i18;
  }
  __ZdlPv($75);
 }
 $76 = (($this) + 148|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $79 = (($this) + 152|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==($77|0);
  if ($81) {
   $91 = $77;
  } else {
   $83 = $80;
   while(1) {
    $82 = (($83) + -24|0);
    HEAP32[$79>>2] = $82;
    $84 = HEAP8[$82>>0]|0;
    $85 = $84 & 1;
    $86 = ($85<<24>>24)==(0);
    if ($86) {
     $88 = $82;
    } else {
     $89 = (($83) + -16|0);
     $90 = HEAP32[$89>>2]|0;
     __ZdlPv($90);
     $$pre$i$i$i$i$i20 = HEAP32[$79>>2]|0;
     $88 = $$pre$i$i$i$i$i20;
    }
    $87 = ($88|0)==($77|0);
    if ($87) {
     break;
    } else {
     $83 = $88;
    }
   }
   $$pre$i$i$i21 = HEAP32[$76>>2]|0;
   $91 = $$pre$i$i$i21;
  }
  __ZdlPv($91);
 }
 $92 = HEAP8[$this>>0]|0;
 $93 = $92 & 1;
 $94 = ($93<<24>>24)==(0);
 if ($94) {
  STACKTOP = sp;return;
 }
 $95 = (($this) + 8|0);
 $96 = HEAP32[$95>>2]|0;
 __ZdlPv($96);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab16ParserSubProgram14ConstantBufferD2Ev($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i3 = 0, $$pre$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if ($5) {
   $15 = $1;
  } else {
   $7 = $4;
   while(1) {
    $6 = (($7) + -24|0);
    HEAP32[$3>>2] = $6;
    $8 = HEAP8[$6>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $12 = $6;
    } else {
     $13 = (($7) + -16|0);
     $14 = HEAP32[$13>>2]|0;
     __ZdlPv($14);
     $$pre$i$i$i$i$i = HEAP32[$3>>2]|0;
     $12 = $$pre$i$i$i$i$i;
    }
    $11 = ($12|0)==($1|0);
    if ($11) {
     break;
    } else {
     $7 = $12;
    }
   }
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $15 = $$pre$i$i$i;
  }
  __ZdlPv($15);
 }
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = (($this) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==($17|0);
  if ($21) {
   $31 = $17;
  } else {
   $23 = $20;
   while(1) {
    $22 = (($23) + -24|0);
    HEAP32[$19>>2] = $22;
    $24 = HEAP8[$22>>0]|0;
    $25 = $24 & 1;
    $26 = ($25<<24>>24)==(0);
    if ($26) {
     $28 = $22;
    } else {
     $29 = (($23) + -16|0);
     $30 = HEAP32[$29>>2]|0;
     __ZdlPv($30);
     $$pre$i$i$i$i$i3 = HEAP32[$19>>2]|0;
     $28 = $$pre$i$i$i$i$i3;
    }
    $27 = ($28|0)==($17|0);
    if ($27) {
     break;
    } else {
     $23 = $28;
    }
   }
   $$pre$i$i$i4 = HEAP32[$16>>2]|0;
   $31 = $$pre$i$i$i4;
  }
  __ZdlPv($31);
 }
 $32 = HEAP8[$this>>0]|0;
 $33 = $32 & 1;
 $34 = ($33<<24>>24)==(0);
 if ($34) {
  STACKTOP = sp;return;
 }
 $35 = (($this) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 __ZdlPv($36);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram13BufferBindingENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i8 = 0, $$0$i9 = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $__p$0$i$i$i$i$i$i = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(268435455);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 4;
 $15 = ($14>>>0)<(134217727);
 if ($15) {
  $18 = $13 >> 3;
  $19 = ($18>>>0)<($8>>>0);
  $20 = $19 ? $8 : $18;
  $21 = (($__v) + 12|0);
  HEAP32[$21>>2] = 0;
  $22 = (($__v) + 16|0);
  HEAP32[$22>>2] = $0;
  $23 = ($20|0)==(0);
  if ($23) {
   $$0$i9 = 0;$26 = 0;$31 = $21;
  } else {
   $$0$i8 = $20;$91 = $21;
   label = 6;
  }
 } else {
  $16 = (($__v) + 12|0);
  HEAP32[$16>>2] = 0;
  $17 = (($__v) + 16|0);
  HEAP32[$17>>2] = $0;
  $$0$i8 = 268435455;$91 = $16;
  label = 6;
 }
 if ((label|0) == 6) {
  $24 = $$0$i8 << 4;
  $25 = (__Znwj($24)|0);
  $$0$i9 = $$0$i8;$26 = $25;$31 = $91;
 }
 HEAP32[$__v>>2] = $26;
 $27 = (($26) + ($7<<4)|0);
 $28 = (($__v) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = (($__v) + 4|0);
 HEAP32[$29>>2] = $27;
 $30 = (($26) + ($$0$i9<<4)|0);
 HEAP32[$31>>2] = $30;
 $32 = ($27|0)==(0|0);
 do {
  if ($32) {
   $60 = 0;
   label = 19;
  } else {
   $33 = HEAP8[$__x>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    ;HEAP32[$27+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__x+8>>2]|0;
    $$pre = $27;
   } else {
    $36 = (($__x) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($__x) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39>>>0)>(4294967279);
    if ($40) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     // unreachable;
    }
    $43 = ($39>>>0)<(11);
    if ($43) {
     $44 = $39 << 1;
     $45 = $44&255;
     HEAP8[$27>>0] = $45;
     $46 = (($27) + 1|0);
     $__p$0$i$i$i$i$i$i = $46;
    } else {
     $47 = (($39) + 16)|0;
     $48 = $47 & -16;
     __THREW__ = 0;
     $49 = (invoke_ii(2988,($48|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = ((($26) + ($7<<4)|0) + 8|0);
     HEAP32[$52>>2] = $49;
     $53 = $48 | 1;
     HEAP32[$27>>2] = $53;
     $54 = ((($26) + ($7<<4)|0) + 4|0);
     HEAP32[$54>>2] = $39;
     $__p$0$i$i$i$i$i$i = $49;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($37|0),($39|0))|0;
    $55 = (($__p$0$i$i$i$i$i$i) + ($39)|0);
    HEAP8[$55>>0] = 0;
    $$pre$pre = HEAP32[$28>>2]|0;
    $$pre = $$pre$pre;
   }
   $56 = ((($26) + ($7<<4)|0) + 12|0);
   $57 = (($__x) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   HEAP32[$56>>2] = $58;
   $60 = $$pre;
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  $59 = (($60) + 16|0);
  HEAP32[$28>>2] = $59;
  __THREW__ = 0;
  invoke_vii(3230,($this|0),($__v|0));
  $61 = __THREW__; __THREW__ = 0;
  $62 = $61&1;
  if (!($62)) {
   $63 = HEAP32[$29>>2]|0;
   $64 = HEAP32[$28>>2]|0;
   $65 = ($64|0)==($63|0);
   if (!($65)) {
    $67 = $64;
    while(1) {
     $66 = (($67) + -16|0);
     HEAP32[$28>>2] = $66;
     $68 = HEAP8[$66>>0]|0;
     $69 = $68 & 1;
     $70 = ($69<<24>>24)==(0);
     if (!($70)) {
      $72 = (($67) + -8|0);
      $73 = HEAP32[$72>>2]|0;
      __ZdlPv($73);
     }
     $71 = ($66|0)==($63|0);
     if ($71) {
      break;
     } else {
      $67 = $66;
     }
    }
   }
   $74 = HEAP32[$__v>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    STACKTOP = sp;return;
   }
   __ZdlPv($74);
   STACKTOP = sp;return;
  }
 }
 $76 = ___cxa_find_matching_catch()|0;
 $77 = tempRet0;
 $78 = HEAP32[$29>>2]|0;
 $79 = HEAP32[$28>>2]|0;
 $80 = ($79|0)==($78|0);
 if (!($80)) {
  $82 = $79;
  while(1) {
   $81 = (($82) + -16|0);
   HEAP32[$28>>2] = $81;
   $83 = HEAP8[$81>>0]|0;
   $84 = $83 & 1;
   $85 = ($84<<24>>24)==(0);
   if (!($85)) {
    $87 = (($82) + -8|0);
    $88 = HEAP32[$87>>2]|0;
    __ZdlPv($88);
   }
   $86 = ($81|0)==($78|0);
   if ($86) {
    break;
   } else {
    $82 = $81;
   }
  }
 }
 $89 = HEAP32[$__v>>2]|0;
 $90 = ($89|0)==(0|0);
 if ($90) {
  ___resumeException($76|0);
  // unreachable;
 }
 __ZdlPv($89);
 ___resumeException($76|0);
 // unreachable;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram13BufferBindingENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__v) + 4|0);
 $4 = ($2|0)==($0|0);
 $$pre1 = HEAP32[$3>>2]|0;
 do {
  if ($4) {
   $33 = $$pre1;$34 = $0;
  } else {
   $$01$i = $2;$6 = $$pre1;
   while(1) {
    $5 = (($6) + -16|0);
    $7 = (($$01$i) + -16|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     ;HEAP32[$5+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$7+8>>2]|0;
    } else {
     $11 = (($$01$i) + -8|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($$01$i) + -12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14>>>0)>(4294967279);
     if ($15) {
      label = 5;
      break;
     }
     $16 = ($14>>>0)<(11);
     if ($16) {
      $17 = $14 << 1;
      $18 = $17&255;
      HEAP8[$5>>0] = $18;
      $19 = (($5) + 1|0);
      $__p$0$i$i$i$i$i$i$i = $19;
     } else {
      $20 = (($14) + 16)|0;
      $21 = $20 & -16;
      $22 = (__Znwj($21)|0);
      $23 = (($6) + -8|0);
      HEAP32[$23>>2] = $22;
      $24 = $21 | 1;
      HEAP32[$5>>2] = $24;
      $25 = (($6) + -12|0);
      HEAP32[$25>>2] = $14;
      $__p$0$i$i$i$i$i$i$i = $22;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($12|0),($14|0))|0;
     $26 = (($__p$0$i$i$i$i$i$i$i) + ($14)|0);
     HEAP8[$26>>0] = 0;
    }
    $27 = (($6) + -4|0);
    $28 = (($$01$i) + -4|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$27>>2] = $29;
    $30 = HEAP32[$3>>2]|0;
    $31 = (($30) + -16|0);
    HEAP32[$3>>2] = $31;
    $32 = ($7|0)==($0|0);
    if ($32) {
     label = 11;
     break;
    } else {
     $$01$i = $7;$6 = $31;
    }
   }
   if ((label|0) == 5) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 11) {
    $$pre = HEAP32[$this>>2]|0;
    $33 = $31;$34 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $33;
 HEAP32[$3>>2] = $34;
 $35 = (($__v) + 8|0);
 $36 = HEAP32[$1>>2]|0;
 $37 = HEAP32[$35>>2]|0;
 HEAP32[$1>>2] = $37;
 HEAP32[$35>>2] = $36;
 $38 = (($this) + 8|0);
 $39 = (($__v) + 12|0);
 $40 = HEAP32[$38>>2]|0;
 $41 = HEAP32[$39>>2]|0;
 HEAP32[$38>>2] = $41;
 HEAP32[$39>>2] = $40;
 $42 = HEAP32[$3>>2]|0;
 HEAP32[$__v>>2] = $42;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab16ParserSubProgramC2Ev($this) {
 $this = $this|0;
 var $$5 = 0, $$56 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i11 = 0, $$pre$i$i$i$i$i14 = 0, $$pre$i$i$i$i$i18 = 0, $$pre$i$i$i$i$i8 = 0, $$pre$i$i$i12 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;
 $0 = (($this) + 12|0);
 __THREW__ = 0;
 invoke_vi(3575,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $$5 = $23;$$56 = $22;
 } else {
  $3 = (($this) + 132|0);
  $4 = (($this) + 148|0);
  $5 = (($this) + 152|0);
  $6 = (($this) + 160|0);
  $7 = (($this) + 164|0);
  $8 = (($this) + 172|0);
  $9 = (($this) + 176|0);
  $10 = (($this) + 184|0);
  $11 = (($this) + 188|0);
  $12 = (($this) + 196|0);
  $13 = (($this) + 200|0);
  $14 = (($this) + 208|0);
  $15 = (($this) + 212|0);
  dest=$3+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  __THREW__ = 0;
  invoke_vii(3231,($4|0),8);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   invoke_vii(3232,($6|0),4);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    invoke_vii(3233,($8|0),4);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     STACKTOP = sp;return;
    }
   }
  }
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  $26 = HEAP32[$14>>2]|0;
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   $28 = HEAP32[$15>>2]|0;
   $29 = ($28|0)==($26|0);
   if ($29) {
    $39 = $26;
   } else {
    $31 = $28;
    while(1) {
     $30 = (($31) + -16|0);
     HEAP32[$15>>2] = $30;
     $32 = HEAP8[$30>>0]|0;
     $33 = $32 & 1;
     $34 = ($33<<24>>24)==(0);
     if ($34) {
      $36 = $30;
     } else {
      $37 = (($31) + -8|0);
      $38 = HEAP32[$37>>2]|0;
      __ZdlPv($38);
      $$pre$i$i$i$i$i18 = HEAP32[$15>>2]|0;
      $36 = $$pre$i$i$i$i$i18;
     }
     $35 = ($36|0)==($26|0);
     if ($35) {
      break;
     } else {
      $31 = $36;
     }
    }
    $$pre$i$i$i19 = HEAP32[$14>>2]|0;
    $39 = $$pre$i$i$i19;
   }
   __ZdlPv($39);
  }
  $40 = HEAP32[$12>>2]|0;
  $41 = ($40|0)==(0|0);
  do {
   if (!($41)) {
    while(1) {
     $42 = HEAP32[$13>>2]|0;
     $43 = ($42|0)==($40|0);
     if ($43) {
      label = 18;
      break;
     }
     $44 = (($42) + -40|0);
     HEAP32[$13>>2] = $44;
     __THREW__ = 0;
     invoke_vi(3574,($44|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 17;
      break;
     }
    }
    if ((label|0) == 17) {
     $47 = ___cxa_find_matching_catch()|0;
     $48 = tempRet0;
     ___cxa_call_unexpected(($47|0));
     // unreachable;
    }
    else if ((label|0) == 18) {
     $49 = HEAP32[$12>>2]|0;
     __ZdlPv($49);
     break;
    }
   }
  } while(0);
  $50 = HEAP32[$10>>2]|0;
  $51 = ($50|0)==(0|0);
  if (!($51)) {
   $52 = HEAP32[$11>>2]|0;
   $53 = ($52|0)==($50|0);
   if ($53) {
    $63 = $50;
   } else {
    $55 = $52;
    while(1) {
     $54 = (($55) + -16|0);
     HEAP32[$11>>2] = $54;
     $56 = HEAP8[$54>>0]|0;
     $57 = $56 & 1;
     $58 = ($57<<24>>24)==(0);
     if ($58) {
      $60 = $54;
     } else {
      $61 = (($55) + -8|0);
      $62 = HEAP32[$61>>2]|0;
      __ZdlPv($62);
      $$pre$i$i$i$i$i14 = HEAP32[$11>>2]|0;
      $60 = $$pre$i$i$i$i$i14;
     }
     $59 = ($60|0)==($50|0);
     if ($59) {
      break;
     } else {
      $55 = $60;
     }
    }
    $$pre$i$i$i15 = HEAP32[$10>>2]|0;
    $63 = $$pre$i$i$i15;
   }
   __ZdlPv($63);
  }
  $64 = HEAP32[$8>>2]|0;
  $65 = ($64|0)==(0|0);
  if (!($65)) {
   $66 = HEAP32[$9>>2]|0;
   $67 = ($66|0)==($64|0);
   if ($67) {
    $77 = $64;
   } else {
    $69 = $66;
    while(1) {
     $68 = (($69) + -24|0);
     HEAP32[$9>>2] = $68;
     $70 = HEAP8[$68>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $74 = $68;
     } else {
      $75 = (($69) + -16|0);
      $76 = HEAP32[$75>>2]|0;
      __ZdlPv($76);
      $$pre$i$i$i$i$i11 = HEAP32[$9>>2]|0;
      $74 = $$pre$i$i$i$i$i11;
     }
     $73 = ($74|0)==($64|0);
     if ($73) {
      break;
     } else {
      $69 = $74;
     }
    }
    $$pre$i$i$i12 = HEAP32[$8>>2]|0;
    $77 = $$pre$i$i$i12;
   }
   __ZdlPv($77);
  }
  $78 = HEAP32[$6>>2]|0;
  $79 = ($78|0)==(0|0);
  if (!($79)) {
   $80 = HEAP32[$7>>2]|0;
   $81 = ($80|0)==($78|0);
   if ($81) {
    $91 = $78;
   } else {
    $83 = $80;
    while(1) {
     $82 = (($83) + -24|0);
     HEAP32[$7>>2] = $82;
     $84 = HEAP8[$82>>0]|0;
     $85 = $84 & 1;
     $86 = ($85<<24>>24)==(0);
     if ($86) {
      $88 = $82;
     } else {
      $89 = (($83) + -16|0);
      $90 = HEAP32[$89>>2]|0;
      __ZdlPv($90);
      $$pre$i$i$i$i$i8 = HEAP32[$7>>2]|0;
      $88 = $$pre$i$i$i$i$i8;
     }
     $87 = ($88|0)==($78|0);
     if ($87) {
      break;
     } else {
      $83 = $88;
     }
    }
    $$pre$i$i$i9 = HEAP32[$6>>2]|0;
    $91 = $$pre$i$i$i9;
   }
   __ZdlPv($91);
  }
  $92 = HEAP32[$4>>2]|0;
  $93 = ($92|0)==(0|0);
  if ($93) {
   $$5 = $25;$$56 = $24;
  } else {
   $94 = HEAP32[$5>>2]|0;
   $95 = ($94|0)==($92|0);
   if ($95) {
    $105 = $92;
   } else {
    $97 = $94;
    while(1) {
     $96 = (($97) + -24|0);
     HEAP32[$5>>2] = $96;
     $98 = HEAP8[$96>>0]|0;
     $99 = $98 & 1;
     $100 = ($99<<24>>24)==(0);
     if ($100) {
      $102 = $96;
     } else {
      $103 = (($97) + -16|0);
      $104 = HEAP32[$103>>2]|0;
      __ZdlPv($104);
      $$pre$i$i$i$i$i = HEAP32[$5>>2]|0;
      $102 = $$pre$i$i$i$i$i;
     }
     $101 = ($102|0)==($92|0);
     if ($101) {
      break;
     } else {
      $97 = $102;
     }
    }
    $$pre$i$i$i = HEAP32[$4>>2]|0;
    $105 = $$pre$i$i$i;
   }
   __ZdlPv($105);
   $$5 = $25;$$56 = $24;
  }
 }
 $106 = HEAP8[$this>>0]|0;
 $107 = $106 & 1;
 $108 = ($107<<24>>24)==(0);
 if ($108) {
  ___resumeException($$56|0);
  // unreachable;
 }
 $109 = (($this) + 8|0);
 $110 = HEAP32[$109>>2]|0;
 __ZdlPv($110);
 ___resumeException($$56|0);
 // unreachable;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15VectorParameterENS_9allocatorIS3_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 24)&-1;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 8|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 24)&-1;
 $14 = (($__v) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($__v) + 16|0);
 HEAP32[$15>>2] = $8;
 $16 = ($__n|0)==(0);
 if ($16) {
  $19 = 0;
 } else {
  $17 = ($__n*24)|0;
  $18 = (__Znwj($17)|0);
  $19 = $18;
 }
 HEAP32[$__v>>2] = $19;
 $20 = (($19) + (($13*24)|0)|0);
 $21 = (($__v) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = (($__v) + 4|0);
 HEAP32[$22>>2] = $20;
 $23 = (($19) + (($__n*24)|0)|0);
 HEAP32[$14>>2] = $23;
 __THREW__ = 0;
 invoke_vii(3234,($this|0),($__v|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  $41 = HEAP32[$22>>2]|0;
  $42 = HEAP32[$21>>2]|0;
  $43 = ($42|0)==($41|0);
  if (!($43)) {
   $45 = $42;
   while(1) {
    $44 = (($45) + -24|0);
    HEAP32[$21>>2] = $44;
    $46 = HEAP8[$44>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if (!($48)) {
     $50 = (($45) + -16|0);
     $51 = HEAP32[$50>>2]|0;
     __ZdlPv($51);
    }
    $49 = ($44|0)==($41|0);
    if ($49) {
     break;
    } else {
     $45 = $44;
    }
   }
  }
  $52 = HEAP32[$__v>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   ___resumeException($39|0);
   // unreachable;
  }
  __ZdlPv($52);
  ___resumeException($39|0);
  // unreachable;
 } else {
  $26 = HEAP32[$22>>2]|0;
  $27 = HEAP32[$21>>2]|0;
  $28 = ($27|0)==($26|0);
  if (!($28)) {
   $30 = $27;
   while(1) {
    $29 = (($30) + -24|0);
    HEAP32[$21>>2] = $29;
    $31 = HEAP8[$29>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if (!($33)) {
     $35 = (($30) + -16|0);
     $36 = HEAP32[$35>>2]|0;
     __ZdlPv($36);
    }
    $34 = ($29|0)==($26|0);
    if ($34) {
     break;
    } else {
     $30 = $29;
    }
   }
  }
  $37 = HEAP32[$__v>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  __ZdlPv($37);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS_9allocatorIS3_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 24)&-1;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 8|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 24)&-1;
 $14 = (($__v) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($__v) + 16|0);
 HEAP32[$15>>2] = $8;
 $16 = ($__n|0)==(0);
 if ($16) {
  $19 = 0;
 } else {
  $17 = ($__n*24)|0;
  $18 = (__Znwj($17)|0);
  $19 = $18;
 }
 HEAP32[$__v>>2] = $19;
 $20 = (($19) + (($13*24)|0)|0);
 $21 = (($__v) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = (($__v) + 4|0);
 HEAP32[$22>>2] = $20;
 $23 = (($19) + (($__n*24)|0)|0);
 HEAP32[$14>>2] = $23;
 __THREW__ = 0;
 invoke_vii(3235,($this|0),($__v|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  $41 = HEAP32[$22>>2]|0;
  $42 = HEAP32[$21>>2]|0;
  $43 = ($42|0)==($41|0);
  if (!($43)) {
   $45 = $42;
   while(1) {
    $44 = (($45) + -24|0);
    HEAP32[$21>>2] = $44;
    $46 = HEAP8[$44>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if (!($48)) {
     $50 = (($45) + -16|0);
     $51 = HEAP32[$50>>2]|0;
     __ZdlPv($51);
    }
    $49 = ($44|0)==($41|0);
    if ($49) {
     break;
    } else {
     $45 = $44;
    }
   }
  }
  $52 = HEAP32[$__v>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   ___resumeException($39|0);
   // unreachable;
  }
  __ZdlPv($52);
  ___resumeException($39|0);
  // unreachable;
 } else {
  $26 = HEAP32[$22>>2]|0;
  $27 = HEAP32[$21>>2]|0;
  $28 = ($27|0)==($26|0);
  if (!($28)) {
   $30 = $27;
   while(1) {
    $29 = (($30) + -24|0);
    HEAP32[$21>>2] = $29;
    $31 = HEAP8[$29>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if (!($33)) {
     $35 = (($30) + -16|0);
     $36 = HEAP32[$35>>2]|0;
     __ZdlPv($36);
    }
    $34 = ($29|0)==($26|0);
    if ($34) {
     break;
    } else {
     $30 = $29;
    }
   }
  }
  $37 = HEAP32[$__v>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  __ZdlPv($37);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram16TextureParameterENS_9allocatorIS3_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 24)&-1;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 8|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 24)&-1;
 $14 = (($__v) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($__v) + 16|0);
 HEAP32[$15>>2] = $8;
 $16 = ($__n|0)==(0);
 if ($16) {
  $19 = 0;
 } else {
  $17 = ($__n*24)|0;
  $18 = (__Znwj($17)|0);
  $19 = $18;
 }
 HEAP32[$__v>>2] = $19;
 $20 = (($19) + (($13*24)|0)|0);
 $21 = (($__v) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = (($__v) + 4|0);
 HEAP32[$22>>2] = $20;
 $23 = (($19) + (($__n*24)|0)|0);
 HEAP32[$14>>2] = $23;
 __THREW__ = 0;
 invoke_vii(3236,($this|0),($__v|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  $41 = HEAP32[$22>>2]|0;
  $42 = HEAP32[$21>>2]|0;
  $43 = ($42|0)==($41|0);
  if (!($43)) {
   $45 = $42;
   while(1) {
    $44 = (($45) + -24|0);
    HEAP32[$21>>2] = $44;
    $46 = HEAP8[$44>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if (!($48)) {
     $50 = (($45) + -16|0);
     $51 = HEAP32[$50>>2]|0;
     __ZdlPv($51);
    }
    $49 = ($44|0)==($41|0);
    if ($49) {
     break;
    } else {
     $45 = $44;
    }
   }
  }
  $52 = HEAP32[$__v>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   ___resumeException($39|0);
   // unreachable;
  }
  __ZdlPv($52);
  ___resumeException($39|0);
  // unreachable;
 } else {
  $26 = HEAP32[$22>>2]|0;
  $27 = HEAP32[$21>>2]|0;
  $28 = ($27|0)==($26|0);
  if (!($28)) {
   $30 = $27;
   while(1) {
    $29 = (($30) + -24|0);
    HEAP32[$21>>2] = $29;
    $31 = HEAP8[$29>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if (!($33)) {
     $35 = (($30) + -16|0);
     $36 = HEAP32[$35>>2]|0;
     __ZdlPv($36);
    }
    $34 = ($29|0)==($26|0);
    if ($34) {
     break;
    } else {
     $30 = $29;
    }
   }
  }
  $37 = HEAP32[$__v>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  __ZdlPv($37);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram16TextureParameterENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__v) + 4|0);
 $4 = ($2|0)==($0|0);
 $$pre1 = HEAP32[$3>>2]|0;
 do {
  if ($4) {
   $32 = $$pre1;$33 = $0;
  } else {
   $$01$i = $2;$6 = $$pre1;
   while(1) {
    $5 = (($6) + -24|0);
    $7 = (($$01$i) + -24|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     ;HEAP32[$5+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$7+8>>2]|0;
    } else {
     $11 = (($$01$i) + -16|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($$01$i) + -20|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14>>>0)>(4294967279);
     if ($15) {
      label = 5;
      break;
     }
     $16 = ($14>>>0)<(11);
     if ($16) {
      $17 = $14 << 1;
      $18 = $17&255;
      HEAP8[$5>>0] = $18;
      $19 = (($5) + 1|0);
      $__p$0$i$i$i$i$i$i$i = $19;
     } else {
      $20 = (($14) + 16)|0;
      $21 = $20 & -16;
      $22 = (__Znwj($21)|0);
      $23 = (($6) + -16|0);
      HEAP32[$23>>2] = $22;
      $24 = $21 | 1;
      HEAP32[$5>>2] = $24;
      $25 = (($6) + -20|0);
      HEAP32[$25>>2] = $14;
      $__p$0$i$i$i$i$i$i$i = $22;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($12|0),($14|0))|0;
     $26 = (($__p$0$i$i$i$i$i$i$i) + ($14)|0);
     HEAP8[$26>>0] = 0;
    }
    $27 = (($6) + -12|0);
    $28 = (($$01$i) + -12|0);
    ;HEAP32[$27+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$28+8>>2]|0;
    $29 = HEAP32[$3>>2]|0;
    $30 = (($29) + -24|0);
    HEAP32[$3>>2] = $30;
    $31 = ($7|0)==($0|0);
    if ($31) {
     label = 11;
     break;
    } else {
     $$01$i = $7;$6 = $30;
    }
   }
   if ((label|0) == 5) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 11) {
    $$pre = HEAP32[$this>>2]|0;
    $32 = $30;$33 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $32;
 HEAP32[$3>>2] = $33;
 $34 = (($__v) + 8|0);
 $35 = HEAP32[$1>>2]|0;
 $36 = HEAP32[$34>>2]|0;
 HEAP32[$1>>2] = $36;
 HEAP32[$34>>2] = $35;
 $37 = (($this) + 8|0);
 $38 = (($__v) + 12|0);
 $39 = HEAP32[$37>>2]|0;
 $40 = HEAP32[$38>>2]|0;
 HEAP32[$37>>2] = $40;
 HEAP32[$38>>2] = $39;
 $41 = HEAP32[$3>>2]|0;
 HEAP32[$__v>>2] = $41;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__v) + 4|0);
 $4 = ($2|0)==($0|0);
 $$pre1 = HEAP32[$3>>2]|0;
 do {
  if ($4) {
   $32 = $$pre1;$33 = $0;
  } else {
   $$01$i = $2;$6 = $$pre1;
   while(1) {
    $5 = (($6) + -24|0);
    $7 = (($$01$i) + -24|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     ;HEAP32[$5+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$7+8>>2]|0;
    } else {
     $11 = (($$01$i) + -16|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($$01$i) + -20|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14>>>0)>(4294967279);
     if ($15) {
      label = 5;
      break;
     }
     $16 = ($14>>>0)<(11);
     if ($16) {
      $17 = $14 << 1;
      $18 = $17&255;
      HEAP8[$5>>0] = $18;
      $19 = (($5) + 1|0);
      $__p$0$i$i$i$i$i$i$i = $19;
     } else {
      $20 = (($14) + 16)|0;
      $21 = $20 & -16;
      $22 = (__Znwj($21)|0);
      $23 = (($6) + -16|0);
      HEAP32[$23>>2] = $22;
      $24 = $21 | 1;
      HEAP32[$5>>2] = $24;
      $25 = (($6) + -20|0);
      HEAP32[$25>>2] = $14;
      $__p$0$i$i$i$i$i$i$i = $22;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($12|0),($14|0))|0;
     $26 = (($__p$0$i$i$i$i$i$i$i) + ($14)|0);
     HEAP8[$26>>0] = 0;
    }
    $27 = (($6) + -12|0);
    $28 = (($$01$i) + -12|0);
    ;HEAP32[$27+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$28+8>>2]|0;
    $29 = HEAP32[$3>>2]|0;
    $30 = (($29) + -24|0);
    HEAP32[$3>>2] = $30;
    $31 = ($7|0)==($0|0);
    if ($31) {
     label = 11;
     break;
    } else {
     $$01$i = $7;$6 = $30;
    }
   }
   if ((label|0) == 5) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 11) {
    $$pre = HEAP32[$this>>2]|0;
    $32 = $30;$33 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $32;
 HEAP32[$3>>2] = $33;
 $34 = (($__v) + 8|0);
 $35 = HEAP32[$1>>2]|0;
 $36 = HEAP32[$34>>2]|0;
 HEAP32[$1>>2] = $36;
 HEAP32[$34>>2] = $35;
 $37 = (($this) + 8|0);
 $38 = (($__v) + 12|0);
 $39 = HEAP32[$37>>2]|0;
 $40 = HEAP32[$38>>2]|0;
 HEAP32[$37>>2] = $40;
 HEAP32[$38>>2] = $39;
 $41 = HEAP32[$3>>2]|0;
 HEAP32[$__v>>2] = $41;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15VectorParameterENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__v) + 4|0);
 $4 = ($2|0)==($0|0);
 $$pre1 = HEAP32[$3>>2]|0;
 do {
  if ($4) {
   $32 = $$pre1;$33 = $0;
  } else {
   $$01$i = $2;$6 = $$pre1;
   while(1) {
    $5 = (($6) + -24|0);
    $7 = (($$01$i) + -24|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     ;HEAP32[$5+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$7+8>>2]|0;
    } else {
     $11 = (($$01$i) + -16|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($$01$i) + -20|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14>>>0)>(4294967279);
     if ($15) {
      label = 5;
      break;
     }
     $16 = ($14>>>0)<(11);
     if ($16) {
      $17 = $14 << 1;
      $18 = $17&255;
      HEAP8[$5>>0] = $18;
      $19 = (($5) + 1|0);
      $__p$0$i$i$i$i$i$i$i = $19;
     } else {
      $20 = (($14) + 16)|0;
      $21 = $20 & -16;
      $22 = (__Znwj($21)|0);
      $23 = (($6) + -16|0);
      HEAP32[$23>>2] = $22;
      $24 = $21 | 1;
      HEAP32[$5>>2] = $24;
      $25 = (($6) + -20|0);
      HEAP32[$25>>2] = $14;
      $__p$0$i$i$i$i$i$i$i = $22;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($12|0),($14|0))|0;
     $26 = (($__p$0$i$i$i$i$i$i$i) + ($14)|0);
     HEAP8[$26>>0] = 0;
    }
    $27 = (($6) + -12|0);
    $28 = (($$01$i) + -12|0);
    ;HEAP32[$27+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$28+8>>2]|0;
    $29 = HEAP32[$3>>2]|0;
    $30 = (($29) + -24|0);
    HEAP32[$3>>2] = $30;
    $31 = ($7|0)==($0|0);
    if ($31) {
     label = 11;
     break;
    } else {
     $$01$i = $7;$6 = $30;
    }
   }
   if ((label|0) == 5) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 11) {
    $$pre = HEAP32[$this>>2]|0;
    $32 = $30;$33 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $32;
 HEAP32[$3>>2] = $33;
 $34 = (($__v) + 8|0);
 $35 = HEAP32[$1>>2]|0;
 $36 = HEAP32[$34>>2]|0;
 HEAP32[$1>>2] = $36;
 HEAP32[$34>>2] = $35;
 $37 = (($this) + 8|0);
 $38 = (($__v) + 12|0);
 $39 = HEAP32[$37>>2]|0;
 $40 = HEAP32[$38>>2]|0;
 HEAP32[$37>>2] = $40;
 HEAP32[$38>>2] = $39;
 $41 = HEAP32[$3>>2]|0;
 HEAP32[$__v>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN23ShaderVariantCollection13WarmupShadersEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $saveMVPMatrices = 0, $savedKeywords$sroa$0 = 0, $vbPtr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $vbPtr$i = sp + 208|0;
 $saveMVPMatrices = sp;
 $savedKeywords$sroa$0 = sp + 192|0;
 $0 = (($this) + 40|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 1;
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (__Z12GetGfxDevicev()|0);
 $7 = (($6) + 5784|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $10 = HEAP32[$6>>2]|0;
  $11 = (($10) + 504|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($6);
  $13 = HEAP32[$6>>2]|0;
  $14 = (($13) + 516|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_ii[$15 & 4095]($6)|0);
  if ($16) {
   $51 = 1;
   label = 6;
  }
 } else {
  $51 = 0;
  label = 6;
 }
 L9: do {
  if ((label|0) == 6) {
   __THREW__ = 0;
   $19 = (invoke_i(59)|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   L11: do {
    if ($21) {
     label = 5;
    } else {
     __THREW__ = 0;
     $22 = (invoke_ii(3308,($19|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 5;
     } else {
      $25 = HEAP32[$22>>2]|0;
      $26 = (($25) + 8|0);
      $27 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      $28 = (invoke_iiiiiiii($27|0,($22|0),60,3,0,1,($vbPtr$i|0),(0|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 5;
      } else {
       do {
        if ($28) {
         $31 = HEAP32[$vbPtr$i>>2]|0;
         _memset(($31|0),0,180)|0;
         $32 = HEAP32[$22>>2]|0;
         $33 = (($32) + 12|0);
         $34 = HEAP32[$33>>2]|0;
         __THREW__ = 0;
         invoke_viii($34|0,($22|0),3,0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          label = 5;
          break L11;
         }
         $37 = ($22|0)==(0|0);
         if (!($37)) {
          __THREW__ = 0;
          invoke_vi(3405,($saveMVPMatrices|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           label = 5;
           break L11;
          }
          __THREW__ = 0;
          invoke_vffi(1,-1.0,100.0,0);
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if (!($41)) {
           $42 = HEAP32[652824>>2]|0;
           $43 = (($42) + 4|0);
           ;HEAP32[$savedKeywords$sroa$0+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$savedKeywords$sroa$0+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$savedKeywords$sroa$0+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$savedKeywords$sroa$0+12>>2]=HEAP32[$43+12>>2]|0;
           __THREW__ = 0;
           invoke_viiii(401,($this|0),(128|0),($22|0),(0|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if (!($45)) {
            $46 = HEAP32[652824>>2]|0;
            $47 = (($46) + 4|0);
            ;HEAP32[$47+0>>2]=HEAP32[$savedKeywords$sroa$0+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$savedKeywords$sroa$0+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$savedKeywords$sroa$0+8>>2]|0;HEAP32[$47+12>>2]=HEAP32[$savedKeywords$sroa$0+12>>2]|0;
            __THREW__ = 0;
            invoke_vi(3375,($saveMVPMatrices|0));
            $48 = __THREW__; __THREW__ = 0;
            $49 = $48&1;
            if ($49) {
             label = 5;
             break L11;
            } else {
             break;
            }
           }
          }
          $56 = ___cxa_find_matching_catch()|0;
          $57 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3375,($saveMVPMatrices|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           $$0 = $56;$$01 = $57;
           break L11;
          }
          $69 = ___cxa_find_matching_catch(0|0)|0;
          $70 = tempRet0;
          ___clang_call_terminate($69);
          // unreachable;
         }
        }
       } while(0);
       $50 = ($51<<24>>24)==(0);
       if (!($50)) {
        break L9;
       }
       STACKTOP = sp;return;
      }
     }
    }
   } while(0);
   if ((label|0) == 5) {
    $17 = ___cxa_find_matching_catch()|0;
    $18 = tempRet0;
    $$0 = $17;$$01 = $18;
   }
   $60 = ($51<<24>>24)==(0);
   if ($60) {
    ___resumeException($$0|0);
    // unreachable;
   }
   __THREW__ = 0;
   $61 = (invoke_i(59)|0);
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if ($63) {
    $69 = ___cxa_find_matching_catch(0|0)|0;
    $70 = tempRet0;
    ___clang_call_terminate($69);
    // unreachable;
   }
   $64 = HEAP32[$61>>2]|0;
   $65 = (($64) + 508|0);
   $66 = HEAP32[$65>>2]|0;
   __THREW__ = 0;
   invoke_vi($66|0,($61|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $69 = ___cxa_find_matching_catch(0|0)|0;
    $70 = tempRet0;
    ___clang_call_terminate($69);
    // unreachable;
   } else {
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $52 = (__Z12GetGfxDevicev()|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + 508|0);
 $55 = HEAP32[$54>>2]|0;
 FUNCTION_TABLE_vi[$55 & 4095]($52);
 STACKTOP = sp;return;
}
function __ZN23ShaderVariantCollection17WarmupShadersImplEPFvP6ShaderiPN9ShaderLab4PassERK16ShaderKeywordSetP10DynamicVBOPvES9_SA_($this,$warmupFunction,$vboChunk,$userData) {
 $this = $this|0;
 $warmupFunction = $warmupFunction|0;
 $vboChunk = $vboChunk|0;
 $userData = $userData|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$in = 0, $$pre = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $idx$05 = 0, $ip$02$i = 0, $iss$05$i = 0, $pos$i$i$i$i = 0, $temp$0$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 32|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $6 = $2;
 while(1) {
  $5 = (($6) + 16|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(0);
  L6: do {
   if (!($8)) {
    HEAP32[$0>>2] = $7;
    $9 = HEAP32[560624>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     label = 13;
    } else {
     $11 = (($9) + 36|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($9) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($12|0)==($14|0);
     do {
      if ($15) {
       $16 = (($9) + 28|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = (($9) + 32|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($17) + ($19<<3)|0);
       $36 = $20;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$9,$0);
       $21 = HEAP32[$pos$i$i$i$i>>2]|0;
       $22 = ($21|0)==(-1);
       $23 = (($9) + 28|0);
       $24 = HEAP32[$23>>2]|0;
       if ($22) {
        $25 = (($9) + 32|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = (($24) + ($26<<3)|0);
        $36 = $27;
        break;
       } else {
        $28 = (($24) + ($21<<3)|0);
        $36 = $28;
        break;
       }
      }
     } while(0);
     $29 = HEAP32[560624>>2]|0;
     $30 = (($29) + 28|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($29) + 32|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + ($33<<3)|0);
     $35 = ($36|0)==($34|0);
     if ($35) {
      label = 13;
     } else {
      $37 = (($36) + 4|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38|0)==(0|0);
      if ($39) {
       label = 13;
      } else {
       $$in = $38;$temp$0$i15 = $38;
      }
     }
    }
    if ((label|0) == 13) {
     label = 0;
     $40 = HEAP32[$5>>2]|0;
     $41 = (__Z31ReadObjectFromPersistentManageri($40)|0);
     $42 = ($41|0)==(0|0);
     if ($42) {
      break;
     } else {
      $$in = $41;$temp$0$i15 = $41;
     }
    }
    $43 = (($temp$0$i15) + 52|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     $46 = (($6) + 20|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (($6) + 24|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($47|0)==($49|0);
     if (!($50)) {
      $51 = $49;
      $52 = $47;
      $53 = (($51) - ($52))|0;
      $54 = (($53|0) / 20)&-1;
      $56 = $47;$61 = $44;$idx$05 = 0;
      while(1) {
       $55 = ((($56) + (($idx$05*20)|0)|0) + 16|0);
       $57 = HEAP32[$55>>2]|0;
       $58 = ($57>>>0)>(10);
       L26: do {
        if (!($58)) {
         $59 = (__ZN6Shader25GetGlobalMaximumShaderLODEv()|0);
         $60 = (($61) + 4|0);
         $62 = HEAP32[$60>>2]|0;
         $63 = HEAP32[$61>>2]|0;
         $64 = $62;
         $65 = $63;
         $66 = (($64) - ($65))|0;
         $67 = $66 >> 2;
         $68 = ($67|0)==(0);
         if (!($68)) {
          $iss$05$i = 0;
          L28: while(1) {
           $69 = (($63) + ($iss$05$i<<2)|0);
           $70 = HEAP32[$69>>2]|0;
           $71 = (($70) + 32|0);
           $72 = HEAP32[$71>>2]|0;
           $73 = ($72|0)>($59|0);
           if (!($73)) {
            $74 = (($70) + 16|0);
            $75 = HEAP32[$74>>2]|0;
            $76 = ($75|0)==(0);
            if (!($76)) {
             $77 = HEAP32[$70>>2]|0;
             $ip$02$i = 0;
             while(1) {
              $80 = (($77) + ($ip$02$i<<2)|0);
              $81 = HEAP32[$80>>2]|0;
              $82 = (($81) + 584|0);
              $83 = HEAP32[$82>>2]|0;
              $84 = ($83|0)==($57|0);
              $79 = (($ip$02$i) + 1)|0;
              if ($84) {
               break L28;
              }
              $78 = ($79|0)==($75|0);
              if ($78) {
               break;
              } else {
               $ip$02$i = $79;
              }
             }
            }
           }
           $85 = (($iss$05$i) + 1)|0;
           $86 = ($85|0)==($67|0);
           if ($86) {
            break L26;
           } else {
            $iss$05$i = $85;
           }
          }
          $87 = ($81|0)==(0|0);
          if (!($87)) {
           $88 = (($81) + 640|0);
           $89 = HEAP32[$88>>2]|0;
           $90 = ($89|0)==(0);
           if ($90) {
            $91 = (($56) + (($idx$05*20)|0)|0);
            FUNCTION_TABLE_viiiiii[$warmupFunction & 255]($$in,$iss$05$i,$81,$91,$vboChunk,$userData);
           }
          }
         }
        }
       } while(0);
       $92 = (($idx$05) + 1)|0;
       $93 = ($92|0)==($54|0);
       if ($93) {
        break L6;
       }
       $$pre = HEAP32[$46>>2]|0;
       $$pre13 = HEAP32[$43>>2]|0;
       $56 = $$pre;$61 = $$pre13;$idx$05 = $92;
      }
     }
    }
   }
  } while(0);
  $94 = (($6) + 4|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ($95|0)==(0|0);
  if ($96) {
   $$01$i$i$i = $6;
   while(1) {
    $99 = (($$01$i$i$i) + 8|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = HEAP32[$100>>2]|0;
    $102 = ($101|0)==($$01$i$i$i|0);
    if ($102) {
     $$0$i$i$i = $100;
     break;
    } else {
     $$01$i$i$i = $100;
    }
   }
  } else {
   $$0$i$i$i$i = $95;
   while(1) {
    $97 = HEAP32[$$0$i$i$i$i>>2]|0;
    $98 = ($97|0)==(0|0);
    if ($98) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $97;
    }
   }
  }
  $103 = ($$0$i$i$i|0)==($3|0);
  if ($103) {
   break;
  } else {
   $6 = $$0$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZL20ShaderWarmupFuncImplP6ShaderiPN9ShaderLab4PassERK16ShaderKeywordSetP10DynamicVBOPv($shader,$subShaderIndex,$pass,$kwmask,$vboChunk,$userData) {
 $shader = $shader|0;
 $subShaderIndex = $subShaderIndex|0;
 $pass = $pass|0;
 $kwmask = $kwmask|0;
 $vboChunk = $vboChunk|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[652824>>2]|0;
 $1 = (($0) + 4|0);
 ;HEAP32[$1+0>>2]=HEAP32[$kwmask+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$kwmask+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$kwmask+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$kwmask+12>>2]|0;
 $2 = (($shader) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[652824>>2]|0;
 $7 = (__ZN9ShaderLab4Pass9ApplyPassEjPKNS_13PropertySheetERKNS_17ShaderPassContextEP6Shaderi($pass,0,$5,$6,$shader,0)|0);
 $8 = HEAP32[$vboChunk>>2]|0;
 $9 = (($8) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($7) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[640736>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $17 = $13;
  $18 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($17,$12,0)|0);
  FUNCTION_TABLE_viii[$10 & 4095]($vboChunk,$7,$18);
  STACKTOP = sp;return;
 }
 $15 = (__Z26GetMeshVertexFormatManagerv()|0);
 $16 = (__ZN23MeshVertexFormatManager10GetDefaultEj($15,159)|0);
 HEAP32[640736>>2] = $16;
 $17 = $16;
 $18 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($17,$12,0)|0);
 FUNCTION_TABLE_viii[$10 & 4095]($vboChunk,$7,$18);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab16FastPropertyName8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $converter$i$i = sp + 4|0;
 $name = sp + 8|0;
 ;HEAP32[$name+0>>2]=0|0;HEAP32[$name+4>>2]=0|0;HEAP32[$name+8>>2]=0|0;
 $1 = HEAP32[580712>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiiiii(192,($transfer|0),(640752|0),($1|0),($converter$i$i|0),0)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($2|0)==(0);
   if (!($5)) {
    $6 = ($2|0)>(0);
    if ($6) {
     __THREW__ = 0;
     invoke_viii(1620,($transfer|0),($name|0),0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
    } else {
     $9 = HEAP32[$converter$i$i>>2]|0;
     $10 = ($9|0)==(0|0);
     if (!($10)) {
      __THREW__ = 0;
      (invoke_iii($9|0,($name|0),($transfer|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($transfer|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
   }
   $26 = (($transfer) + 136|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)==(0);
   if (!($28)) {
    $29 = HEAP8[$name>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if ($31) {
     $34 = (($name) + 1|0);
     $35 = $34;
    } else {
     $32 = (($name) + 8|0);
     $33 = HEAP32[$32>>2]|0;
     $35 = $33;
    }
    __THREW__ = 0;
    invoke_vii(2618,($this|0),($35|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
   }
   $38 = HEAP8[$name>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    STACKTOP = sp;return;
   }
   $41 = (($name) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($42|0),($$byval_copy1|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $45 = ___cxa_find_matching_catch()|0;
    $46 = tempRet0;
    ___cxa_call_unexpected(($45|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $17 = HEAP8[$name>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  ___resumeException($15|0);
  // unreachable;
 }
 $20 = (($name) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($21|0),($$byval_copy1|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  ___cxa_call_unexpected(($24|0));
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer8TransferIN9ShaderLab16FastPropertyNameEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $name$i$i = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 24|0;
 $0 = sp + 16|0;
 $name$i$i = sp + 4|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,640768,$data,$metaFlag);
 ;HEAP32[$name$i$i+0>>2]=0|0;HEAP32[$name$i$i+4>>2]=0|0;HEAP32[$name$i$i+8>>2]=0|0;
 $1 = HEAP32[580712>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($this|0),(640752|0),($1|0),($name$i$i|0),0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiiii(87,($this|0),(640760|0),(640760|0),($size$i$i$i$i|0),1);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[580552>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($this|0),(640744|0),($6|0),($p$i$i$i|0),0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = (($this) + 12|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = HEAP32[$10>>2]|0;
    $12 = (($this) + 20|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ((($11) + (($13*24)|0)|0) + 12|0);
    HEAP32[$14>>2] = 1;
    __THREW__ = 0;
    invoke_vi(3390,($this|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(3391,($this|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      invoke_vi(3392,($this|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3390,($this|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $34 = HEAP8[$name$i$i>>0]|0;
        $35 = $34 & 1;
        $36 = ($35<<24>>24)==(0);
        if ($36) {
         __ZN13ProxyTransfer11EndTransferEv($this);
         STACKTOP = sp;return;
        }
        $37 = (($name$i$i) + 8|0);
        $38 = HEAP32[$37>>2]|0;
        HEAP32[$size$i$i$i$i>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i+0>>2]|0;
        invoke_vii(2591,($38|0),($$byval_copy1|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         $41 = ___cxa_find_matching_catch()|0;
         $42 = tempRet0;
         ___cxa_call_unexpected(($41|0));
         // unreachable;
        } else {
         __ZN13ProxyTransfer11EndTransferEv($this);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP8[$name$i$i>>0]|0;
 $26 = $25 & 1;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  ___resumeException($23|0);
  // unreachable;
 }
 $28 = (($name$i$i) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  ___cxa_call_unexpected(($32|0));
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZNK12GraphicsCaps17CheckGPUSupportedEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0] = 0;
 $0 = (($agg$result) + 1|0);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN12GraphicsCaps24SharedCapsPostInitializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN10systeminfo19GetPhysicalMemoryMBEv()|0);
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(29);
 if ($2) {
  $3 = (($this) + 241|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   label = 5;
  } else {
   $6 = (($this) + 202|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    label = 5;
   } else {
    $9 = (($this) + 246|0);
    $10 = HEAP8[$9>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     label = 5;
    } else {
     $13 = (($this) + 253|0);
     $14 = HEAP8[$13>>0]|0;
     $15 = (($this) + 263|0);
     HEAP8[$15>>0] = $14;
     $16 = ($14<<24>>24)==(0);
     if ($16) {
      $21 = 0;
     } else {
      $17 = (($this) + 120|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)>(3);
      $phitmp = $19&1;
      $21 = $phitmp;
     }
    }
   }
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $12 = (($this) + 263|0);
  HEAP8[$12>>0] = 0;
  $21 = 0;
 }
 $20 = (($this) + 264|0);
 HEAP8[$20>>0] = $21;
 STACKTOP = sp;return;
}
function __Z14QueryExtensionPKc($ext) {
 $ext = $ext|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $start$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[641168>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (1147664 + 232|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (FUNCTION_TABLE_ii[$3 & 4095](7939)|0);
  HEAP32[641168>>2] = $4;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 0;
  } else {
   $11 = $4;
   label = 3;
  }
 } else {
  $11 = $0;
  label = 3;
 }
 L3: do {
  if ((label|0) == 3) {
   $6 = ($ext|0)==(0|0);
   if ($6) {
    $$0 = 0;
   } else {
    $7 = HEAP8[$ext>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     $$0 = 0;
    } else {
     $9 = (_strchr($ext,32)|0);
     $10 = ($9|0)==(0|0);
     if ($10) {
      $12 = (_strstr($11,$ext)|0);
      $13 = ($12|0)==(0|0);
      if ($13) {
       $$0 = 0;
      } else {
       $14 = (_strlen(($ext|0))|0);
       $16 = $12;$start$01$i = $11;
       while(1) {
        $15 = (($16) + ($14)|0);
        $17 = ($16|0)==($start$01$i|0);
        if ($17) {
         label = 10;
        } else {
         $18 = (($16) + -1|0);
         $19 = HEAP8[$18>>0]|0;
         $20 = ($19<<24>>24)==(32);
         if ($20) {
          label = 10;
         }
        }
        if ((label|0) == 10) {
         label = 0;
         $21 = HEAP8[$15>>0]|0;
         if ((($21<<24>>24) == 0) | (($21<<24>>24) == 32)) {
          $$0 = 1;
          break L3;
         }
        }
        $22 = (_strstr($15,$ext)|0);
        $23 = ($22|0)==(0|0);
        if ($23) {
         $$0 = 0;
         break;
        } else {
         $16 = $22;$start$01$i = $15;
        }
       }
      }
     } else {
      $$0 = 0;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __GLOBAL__I_a8226() {
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 _memset((640792|0),0,376)|0;
 dest=((640792 + 141|0))+0|0; stop=dest+22|0; do { HEAP8[dest>>0]=1|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 HEAP8[((640792 + 208|0))>>0] = 1;
 HEAP8[((640792 + 210|0))>>0] = 1;
 dest=640792+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[((640792 + 68|0))>>2] = 20;
 HEAP32[((640792 + 76|0))>>2] = 4;
 HEAPF32[((640792 + 80|0))>>2] = Math_fround(16.0);
 HEAP32[((640792 + 88|0))>>2] = 8;
 HEAP32[((640792 + 92|0))>>2] = 1;
 HEAP32[((640792 + 96|0))>>2] = 8;
 HEAP32[((640792 + 100|0))>>2] = 1;
 HEAP32[((640792 + 104|0))>>2] = 1;
 HEAP32[((640792 + 108|0))>>2] = 256;
 HEAP32[((640792 + 112|0))>>2] = 64;
 HEAP32[((640792 + 116|0))>>2] = 128;
 HEAP32[((640792 + 120|0))>>2] = 1;
 HEAP8[((640792 + 124|0))>>0] = 0;
 HEAP8[((640792 + 128|0))>>0] = 1;
 HEAP32[((640792 + 228|0))>>2] = 0;
 HEAP32[((640792 + 232|0))>>2] = 0;
 HEAP8[((640792 + 236|0))>>0] = 0;
 HEAP8[((640792 + 240|0))>>0] = 1;
 HEAP8[((640792 + 250|0))>>0] = 1;
 HEAP8[((640792 + 254|0))>>0] = 1;
 HEAP8[((640792 + 245|0))>>0] = 1;
 HEAP8[((640792 + 261|0))>>0] = 1;
 HEAP32[((640792 + 268|0))>>2] = 0;
 HEAP32[((640792 + 72|0))>>2] = 14;
 HEAP8[((640792 + 131|0))>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK5Unity8Material16MarkDependenciesER27GarbageCollectorThreadState($this,$gc) {
 $this = $this|0;
 $gc = $gc|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($1,$gc);
 $2 = (($this) + 76|0);
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $7 = $4;
 }
 while(1) {
  $6 = (($7) + 36|0);
  $8 = HEAP32[$6>>2]|0;
  __Z20MarkInstanceIDAsRootiR27GarbageCollectorThreadState($8,$gc);
  $9 = (($7) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $$01$i$i$i$i = $7;
   while(1) {
    $14 = (($$01$i$i$i$i) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($$01$i$i$i$i|0);
    if ($17) {
     $$0$i$i$i$i = $15;
     break;
    } else {
     $$01$i$i$i$i = $15;
    }
   }
  } else {
   $$0$i$i$i$i$i = $10;
   while(1) {
    $12 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $12;
    }
   }
  }
  $18 = ($$0$i$i$i$i|0)==($2|0);
  if ($18) {
   break;
  } else {
   $7 = $$0$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity8Material5ResetEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
  __ZN5Unity8Material15ResetWithShaderEP6Shader($this,$$0$i);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $$0$i = $temp$0$i;
 __ZN5Unity8Material15ResetWithShaderEP6Shader($this,$$0$i);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material15ResetWithShaderEP6Shader($this,$shader) {
 $this = $this|0;
 $shader = $shader|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 40|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 64|0);
 HEAP32[$2>>2] = -1;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[628272>>2]|0;
  $7 = (($4) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + -1)|0;
  HEAP32[$7>>2] = $9;
  $10 = HEAP32[$7>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   $12 = HEAP32[$4>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vi[$13 & 4095]($4);
   HEAP32[$0>>2] = $6;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($4,$$byval_copy);
  }
  HEAP32[$3>>2] = 0;
 }
 $14 = (($this) + 36|0);
 HEAP8[$14>>0] = 1;
 $15 = (($this) + 72|0);
 $16 = (($1) + 4|0);
 $17 = (($1) + 4|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;HEAP32[$1+28>>2]=0|0;
 HEAP32[$1>>2] = $17;
 $18 = (($1) + 16|0);
 HEAP32[$18>>2] = 0;
 $19 = (($1) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($1) + 16|0);
 $21 = (($1) + 12|0);
 HEAP32[$21>>2] = $20;
 $22 = (($1) + 28|0);
 HEAP32[$22>>2] = 0;
 $23 = (($1) + 32|0);
 HEAP32[$23>>2] = 0;
 $24 = (($1) + 28|0);
 $25 = (($1) + 24|0);
 HEAP32[$25>>2] = $24;
 __THREW__ = 0;
 (invoke_iii(2388,($15|0),($1|0))|0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  $43 = (($1) + 24|0);
  $44 = HEAP32[$22>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($43,$44);
  $45 = (($1) + 12|0);
  $46 = HEAP32[$18>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($45,$46);
  $47 = HEAP32[$16>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($1,$47);
  ___resumeException($41|0);
  // unreachable;
 }
 $28 = (($1) + 24|0);
 $29 = HEAP32[$22>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($28,$29);
 $30 = (($1) + 12|0);
 $31 = HEAP32[$18>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($30,$31);
 $32 = HEAP32[$16>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($1,$32);
 $33 = (($this) + 28|0);
 $34 = ($shader|0)==(0|0);
 if ($34) {
  HEAP32[$33>>2] = 0;
  $37 = (__ZN6Shader10GetDefaultEv()|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   STACKTOP = sp;return;
  }
 } else {
  $35 = (($shader) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$33>>2] = $36;
 }
 $39 = (($this) + 108|0);
 $40 = (($this) + 120|0);
 __ZN8keywords18StringToKeywordSetERK8UnityStrR16ShaderKeywordSet($39,$40);
 __ZN5Unity8Material15BuildPropertiesEv($this);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material15ClearPropertiesEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $12 = (($this) + 36|0);
  HEAP8[$12>>0] = 1;
  STACKTOP = sp;return;
 }
 $4 = HEAP32[628272>>2]|0;
 $5 = (($2) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 HEAP32[$5>>2] = $7;
 $8 = HEAP32[$5>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = HEAP32[$2>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($2);
  HEAP32[$0>>2] = $4;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
 }
 HEAP32[$1>>2] = 0;
 $12 = (($this) + 36|0);
 HEAP8[$12>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN5Unity8Material15BuildPropertiesEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $shader$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[628272>>2]|0;
  $5 = (($2) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + -1)|0;
  HEAP32[$5>>2] = $7;
  $8 = HEAP32[$5>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vi[$11 & 4095]($2);
   HEAP32[$0>>2] = $4;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
  }
  HEAP32[$1>>2] = 0;
 }
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 do {
  if ($14) {
   label = 16;
  } else {
   HEAP32[$0>>2] = $13;
   $15 = HEAP32[560624>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = (($15) + 36|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    do {
     if ($21) {
      $22 = (($15) + 28|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = (($15) + 32|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($23) + ($25<<3)|0);
      $42 = $26;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$15,$0);
      $27 = HEAP32[$$byval_copy>>2]|0;
      $28 = ($27|0)==(-1);
      $29 = (($15) + 28|0);
      $30 = HEAP32[$29>>2]|0;
      if ($28) {
       $31 = (($15) + 32|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($30) + ($32<<3)|0);
       $42 = $33;
       break;
      } else {
       $34 = (($30) + ($27<<3)|0);
       $42 = $34;
       break;
      }
     }
    } while(0);
    $35 = HEAP32[560624>>2]|0;
    $36 = (($35) + 28|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($35) + 32|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($37) + ($39<<3)|0);
    $41 = ($42|0)==($40|0);
    if (!($41)) {
     $43 = (($42) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==(0|0);
     if (!($45)) {
      $shader$0 = $44;
      break;
     }
    }
   }
   $46 = HEAP32[$12>>2]|0;
   $47 = (__Z31ReadObjectFromPersistentManageri($46)|0);
   $48 = ($47|0)==(0|0);
   if ($48) {
    label = 16;
   } else {
    $shader$0 = $47;
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $49 = (__ZN6Shader10GetDefaultEv()|0);
  $shader$0 = $49;
 }
 $50 = (($shader$0) + 52|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = (__ZNK6Shader14MakePropertiesEv($shader$0)|0);
 HEAP32[$1>>2] = $53;
 $54 = (($53) + 80|0);
 HEAP32[$54>>2] = $this;
 $55 = (($this) + 72|0);
 $56 = HEAP32[$50>>2]|0;
 $57 = (($56) + 68|0);
 $58 = HEAP32[$57>>2]|0;
 (__ZN18UnityPropertySheet20AddNewShaderlabPropsERKN9ShaderLab13PropertySheetE($55,$58)|0);
 $59 = HEAP32[$1>>2]|0;
 __ZN18UnityPropertySheet25AssignDefinedPropertiesToERN9ShaderLab13PropertySheetE($55,$59);
 __ZN5Unity8Material12UpdateHashesEv($this);
 STACKTOP = sp;return;
}
function __ZNK5Unity8Material20GetActualRenderQueueEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(-1);
 if ($2) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZNK5Unity8Material9GetShaderEv($this)|0);
 $4 = (($3) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5Unity8Material9GetShaderEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
     $16 = HEAP32[$pos$i$i$i$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if (!($30)) {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     $$0 = $33;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $$0 = $36;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $38 = (__ZN6Shader10GetDefaultEv()|0);
 $$0 = $38;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity8Material12UpdateHashesEv($this) {
 $this = $this|0;
 var $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 136|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 140|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $4;
 $6 = HEAP32[560624>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  label = 11;
 } else {
  $8 = (($6) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  do {
   if ($12) {
    $13 = (($6) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($6) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + ($16<<3)|0);
    $33 = $17;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$6,$0);
    $18 = HEAP32[$pos$i$i$i$i>>2]|0;
    $19 = ($18|0)==(-1);
    $20 = (($6) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    if ($19) {
     $22 = (($6) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($21) + ($23<<3)|0);
     $33 = $24;
     break;
    } else {
     $25 = (($21) + ($18<<3)|0);
     $33 = $25;
     break;
    }
   }
  } while(0);
  $26 = HEAP32[560624>>2]|0;
  $27 = (($26) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + ($30<<3)|0);
  $32 = ($33|0)==($31|0);
  if ($32) {
   label = 11;
  } else {
   $34 = (($33) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 11;
   } else {
    $$in = $35;$temp$0$i2 = $35;
   }
  }
 }
 if ((label|0) == 11) {
  $37 = HEAP32[$3>>2]|0;
  $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
  $39 = ($38|0)==(0|0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $$in = $38;$temp$0$i2 = $38;
  }
 }
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = HEAP32[652824>>2]|0;
 $44 = (($temp$0$i2) + 56|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  $52 = $41;
 } else {
  $47 = (($this) + 120|0);
  $48 = (__ZN9ShaderLab4Pass21ComputePassValuesHashERK16ShaderKeywordSetPKNS_13PropertySheetERKNS_17ShaderPassContextEP6Shader($45,$47,$41,$43,$$in)|0);
  HEAP32[$1>>2] = $48;
  $$pre = HEAP32[$40>>2]|0;
  $52 = $$pre;
 }
 $49 = (($temp$0$i2) + 52|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 52|0);
 $53 = (__ZN9ShaderLab27ComputeStateBlockValuesHashERK13dynamic_arrayIiLj4EEPKNS_13PropertySheetERKNS_17ShaderPassContextE($51,$52,$43)|0);
 HEAP32[$2>>2] = $53;
 $54 = HEAP32[$49>>2]|0;
 $55 = HEAP32[$40>>2]|0;
 __ZN9ShaderLab9IntShader23CreateStateBlocksForKeyEjPKNS_13PropertySheetERKNS_17ShaderPassContextE($54,$53,$55,$43);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$$i = 0, $$0$lcssa$i = 0, $$01$i = 0, $$in = 0, $$neg2$i$i$i$i$i$i = 0, $$sum$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__len$0$be$i$i$i$i$i$i = 0, $__len$03$i$i$i$i$i$i = 0, $pos$i$i$i$i = 0;
 var $temp$0$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 11;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 11;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 11;
   } else {
    $$in = $33;$temp$0$i3 = $33;
   }
  }
 }
 if ((label|0) == 11) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   STACKTOP = sp;return;
  } else {
   $$in = $36;$temp$0$i3 = $36;
  }
 }
 $38 = (($this) + 32|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = HEAP32[652824>>2]|0;
 $42 = (($temp$0$i3) + 56|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = HEAP32[$name>>2]|0;
  $46 = (($43) + 680|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($43) + 684|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = $49;
  $51 = $47;
  $52 = (($50) - ($51))|0;
  $53 = $52 >> 2;
  $54 = ($53|0)==(0);
  if ($54) {
   $64 = $47;
  } else {
   $57 = $47;$__len$03$i$i$i$i$i$i = $53;
   while(1) {
    $55 = (($__len$03$i$i$i$i$i$i|0) / 2)&-1;
    $56 = (($57) + ($55<<2)|0);
    $58 = HEAP32[$56>>2]|0;
    $59 = ($58|0)<($45|0);
    if ($59) {
     $$sum$i$i$i$i$i$i = (($55) + 1)|0;
     $60 = (($57) + ($$sum$i$i$i$i$i$i<<2)|0);
     $$neg2$i$i$i$i$i$i = (($__len$03$i$i$i$i$i$i) + -1)|0;
     $61 = (($$neg2$i$i$i$i$i$i) - ($55))|0;
     $90 = $60;$__len$0$be$i$i$i$i$i$i = $61;
    } else {
     $90 = $57;$__len$0$be$i$i$i$i$i$i = $55;
    }
    $62 = ($__len$0$be$i$i$i$i$i$i|0)==(0);
    if ($62) {
     $64 = $90;
     break;
    } else {
     $57 = $90;$__len$03$i$i$i$i$i$i = $__len$0$be$i$i$i$i$i$i;
    }
   }
  }
  $63 = ($64|0)==($49|0);
  if (!($63)) {
   $65 = HEAP32[$64>>2]|0;
   $66 = ($45|0)<($65|0);
   $$$i = $66 ? $49 : $64;
   $67 = ($$$i|0)==($49|0);
   if (!($67)) {
    $68 = (($this) + 120|0);
    $69 = (__ZN9ShaderLab4Pass21ComputePassValuesHashERK16ShaderKeywordSetPKNS_13PropertySheetERKNS_17ShaderPassContextEP6Shader($43,$68,$39,$41,$$in)|0);
    $70 = (($this) + 136|0);
    HEAP32[$70>>2] = $69;
   }
  }
 }
 $71 = (($temp$0$i3) + 52|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($72) + 52|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($72) + 60|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($74) + ($76<<2)|0);
 $78 = ($76|0)==(0);
 L34: do {
  if ($78) {
   $$0$lcssa$i = $74;
  } else {
   $79 = HEAP32[$name>>2]|0;
   $$01$i = $74;
   while(1) {
    $82 = HEAP32[$$01$i>>2]|0;
    $83 = ($82|0)==($79|0);
    $81 = (($$01$i) + 4|0);
    if ($83) {
     $$0$lcssa$i = $$01$i;
     break L34;
    }
    $80 = ($81|0)==($77|0);
    if ($80) {
     break;
    } else {
     $$01$i = $81;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $84 = ($$0$lcssa$i|0)==($77|0);
 if ($84) {
  STACKTOP = sp;return;
 }
 $85 = HEAP32[$38>>2]|0;
 $86 = (__ZN9ShaderLab27ComputeStateBlockValuesHashERK13dynamic_arrayIiLj4EEPKNS_13PropertySheetERKNS_17ShaderPassContextE($73,$85,$41)|0);
 $87 = (($this) + 140|0);
 HEAP32[$87>>2] = $86;
 $88 = HEAP32[$71>>2]|0;
 $89 = HEAP32[$38>>2]|0;
 __ZN9ShaderLab9IntShader23CreateStateBlocksForKeyEjPKNS_13PropertySheetERKNS_17ShaderPassContextE($88,$86,$89,$41);
 STACKTOP = sp;return;
}
function __ZNK5Unity8Material10ComputeCRCEv($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i2 = 0, $$0$i$i$i$i8 = 0, $$0$i$i$i12 = 0, $$0$i$i$i6 = 0, $$01$i$i$i = 0, $$01$i$i$i10 = 0, $$01$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $crc$0$lcssa = 0, $crc$026 = 0, $crc$1$lcssa = 0, $crc$119 = 0;
 var $crc$2$lcssa = 0, $crc$216 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $2 = (__Z8CRCBeginv()|0);
 $3 = (($this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = (__Z7CRCFeedjPKhj($2,$0,4)|0);
 $6 = (($this) + 120|0);
 $7 = (__Z7CRCFeedjPKhj($5,$6,16)|0);
 $8 = (($this) + 72|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 76|0);
 $11 = ($9|0)==($10|0);
 if ($11) {
  $crc$0$lcssa = $7;
 } else {
  $13 = $9;$crc$026 = $7;
  while(1) {
   $12 = (($13) + 16|0);
   $14 = (__Z7CRCFeedjPKhj($crc$026,$12,4)|0);
   $15 = (($13) + 20|0);
   $16 = (__Z7CRCFeedjPKhj($14,$15,8)|0);
   $17 = (($13) + 28|0);
   $18 = (__Z7CRCFeedjPKhj($16,$17,8)|0);
   $19 = (($13) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[$1>>2] = $20;
   $21 = (__Z7CRCFeedjPKhj($18,$1,4)|0);
   $22 = (($13) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $$01$i$i$i10 = $13;
    while(1) {
     $27 = (($$01$i$i$i10) + 8|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $30 = ($29|0)==($$01$i$i$i10|0);
     if ($30) {
      $$0$i$i$i12 = $28;
      break;
     } else {
      $$01$i$i$i10 = $28;
     }
    }
   } else {
    $$0$i$i$i$i8 = $23;
    while(1) {
     $25 = HEAP32[$$0$i$i$i$i8>>2]|0;
     $26 = ($25|0)==(0|0);
     if ($26) {
      $$0$i$i$i12 = $$0$i$i$i$i8;
      break;
     } else {
      $$0$i$i$i$i8 = $25;
     }
    }
   }
   $31 = ($$0$i$i$i12|0)==($10|0);
   if ($31) {
    $crc$0$lcssa = $21;
    break;
   } else {
    $13 = $$0$i$i$i12;$crc$026 = $21;
   }
  }
 }
 $32 = (($this) + 84|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 88|0);
 $35 = ($33|0)==($34|0);
 if ($35) {
  $crc$1$lcssa = $crc$0$lcssa;
 } else {
  $37 = $33;$crc$119 = $crc$0$lcssa;
  while(1) {
   $36 = (($37) + 16|0);
   $38 = (__Z7CRCFeedjPKhj($crc$119,$36,8)|0);
   $39 = (($37) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    $$01$i$i$i4 = $37;
    while(1) {
     $44 = (($$01$i$i$i4) + 8|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==($$01$i$i$i4|0);
     if ($47) {
      $$0$i$i$i6 = $45;
      break;
     } else {
      $$01$i$i$i4 = $45;
     }
    }
   } else {
    $$0$i$i$i$i2 = $40;
    while(1) {
     $42 = HEAP32[$$0$i$i$i$i2>>2]|0;
     $43 = ($42|0)==(0|0);
     if ($43) {
      $$0$i$i$i6 = $$0$i$i$i$i2;
      break;
     } else {
      $$0$i$i$i$i2 = $42;
     }
    }
   }
   $48 = ($$0$i$i$i6|0)==($34|0);
   if ($48) {
    $crc$1$lcssa = $38;
    break;
   } else {
    $37 = $$0$i$i$i6;$crc$119 = $38;
   }
  }
 }
 $49 = (($this) + 96|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($this) + 100|0);
 $52 = ($50|0)==($51|0);
 if ($52) {
  $crc$2$lcssa = $crc$1$lcssa;
  $66 = (__Z7CRCDonej($crc$2$lcssa)|0);
  STACKTOP = sp;return ($66|0);
 } else {
  $54 = $50;$crc$216 = $crc$1$lcssa;
 }
 while(1) {
  $53 = (($54) + 16|0);
  $55 = (__Z7CRCFeedjPKhj($crc$216,$53,20)|0);
  $56 = (($54) + 4|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if ($58) {
   $$01$i$i$i = $54;
   while(1) {
    $61 = (($$01$i$i$i) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = HEAP32[$62>>2]|0;
    $64 = ($63|0)==($$01$i$i$i|0);
    if ($64) {
     $$0$i$i$i = $62;
     break;
    } else {
     $$01$i$i$i = $62;
    }
   }
  } else {
   $$0$i$i$i$i = $57;
   while(1) {
    $59 = HEAP32[$$0$i$i$i$i>>2]|0;
    $60 = ($59|0)==(0|0);
    if ($60) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $59;
    }
   }
  }
  $65 = ($$0$i$i$i|0)==($51|0);
  if ($65) {
   $crc$2$lcssa = $55;
   break;
  } else {
   $54 = $$0$i$i$i;$crc$216 = $55;
  }
 }
 $66 = (__Z7CRCDonej($crc$2$lcssa)|0);
 STACKTOP = sp;return ($66|0);
}
function __ZN5Unity8Material13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 108|0);
 $2 = (($this) + 120|0);
 __ZN8keywords18StringToKeywordSetERK8UnityStrR16ShaderKeywordSet($1,$2);
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $14 = (($this) + 36|0);
  HEAP8[$14>>0] = 1;
  __ZN5Unity8Material15BuildPropertiesEv($this);
  STACKTOP = sp;return;
 }
 $6 = HEAP32[628272>>2]|0;
 $7 = (($4) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + -1)|0;
 HEAP32[$7>>2] = $9;
 $10 = HEAP32[$7>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = HEAP32[$4>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($4);
  HEAP32[$0>>2] = $6;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($4,$$byval_copy);
 }
 HEAP32[$3>>2] = 0;
 $14 = (($this) + 36|0);
 HEAP8[$14>>0] = 1;
 __ZN5Unity8Material15BuildPropertiesEv($this);
 STACKTOP = sp;return;
}
function __ZN5Unity8MaterialC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((641176 + 8|0));
 $2 = (($this) + 28|0);
 $3 = (($this) + 40|0);
 $4 = (($this) + 60|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;
 HEAP32[$4>>2] = $this;
 $5 = (($this) + 68|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 76|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 80|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 76|0);
 $9 = (($this) + 72|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 88|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 92|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 88|0);
 $13 = (($this) + 84|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 100|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 104|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 100|0);
 $17 = (($this) + 96|0);
 HEAP32[$17>>2] = $16;
 $18 = (($this) + 108|0);
 $19 = (($this) + 32|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 36|0);
 HEAP8[$20>>0] = 0;
 HEAP32[$2>>2] = 0;
 $21 = (($this) + 64|0);
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;HEAP32[$18+24>>2]=0|0;
 HEAP32[$21>>2] = -1;
 $22 = (($this) + 136|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 140|0);
 HEAP32[$23>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity8Material15ThreadedCleanupEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 __ZN5Unity8Material22InvalidateDisplayListsEv($this);
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[628272>>2]|0;
 $5 = (($2) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 HEAP32[$5>>2] = $7;
 $8 = HEAP32[$5>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $10 = HEAP32[$2>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($2);
  HEAP32[$0>>2] = $4;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
 }
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity8Material22InvalidateDisplayListsEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond = 0, $i$04 = 0, $j$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 44)&-1;
 $8 = ($6|0)>(0);
 if ($8) {
  $10 = $3;$i$04 = 0;
 } else {
  $40 = (($this) + 36|0);
  HEAP8[$40>>0] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $9 = ((($10) + (($i$04*44)|0)|0) + 8|0);
  $11 = HEAP32[$9>>2]|0;
  $12 = ($11|0)>(0);
  if ($12) {
   $13 = (($10) + (($i$04*44)|0)|0);
   $j$03 = 0;
   while(1) {
    $14 = HEAP32[$13>>2]|0;
    $15 = (($14) + (($j$03*28)|0)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if (!($17)) {
     $18 = (($16) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($19) + -1)|0;
     HEAP32[$18>>2] = $20;
     $21 = HEAP32[$18>>2]|0;
     $22 = ($21|0)==(0);
     if ($22) {
      $23 = HEAP32[$16>>2]|0;
      $24 = (($23) + 4|0);
      $25 = HEAP32[$24>>2]|0;
      FUNCTION_TABLE_vi[$25 & 4095]($16);
     }
     HEAP32[$15>>2] = 0;
    }
    $26 = (($j$03) + 1)|0;
    $exitcond = ($26|0)==($11|0);
    if ($exitcond) {
     break;
    } else {
     $j$03 = $26;
    }
   }
  }
  $27 = ((($10) + (($i$04*44)|0)|0) + 16|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = (($28) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($31) + -1)|0;
   HEAP32[$30>>2] = $32;
   $33 = HEAP32[$30>>2]|0;
   $34 = ($33|0)==(0);
   if ($34) {
    $35 = HEAP32[$28>>2]|0;
    $36 = (($35) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    FUNCTION_TABLE_vi[$37 & 4095]($28);
   }
   HEAP32[$27>>2] = 0;
  }
  $38 = (($i$04) + 1)|0;
  $39 = ($38|0)<($7|0);
  if (!($39)) {
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $10 = $$pre;$i$04 = $38;
 }
 $40 = (($this) + 36|0);
 HEAP8[$40>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity8Material17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN9ShaderLab13PropertySheet17MainThreadCleanupEv($1);
 }
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 56|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$6>>2]|0;
 HEAP32[$10>>2] = $9;
 HEAP32[$3>>2] = 0;
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity8Material9SetShaderEP6Shader($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = ($s|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $2 = (($s) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $3;
  __ZN5Unity8Material15BuildPropertiesEv($this);
  __ZN5Unity8Material22InvalidateDisplayListsEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN5Unity8Material14CreateMaterialER6Shaderib($shader,$hideFlags,$scriptingObjectIsBeingCreated) {
 $shader = $shader|0;
 $hideFlags = $hideFlags|0;
 $scriptingObjectIsBeingCreated = $scriptingObjectIsBeingCreated|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Z20CreateObjectFromCodeIN5Unity8MaterialEEPT_17AwakeFromLoadMode10MemLabelId(4,$$byval_copy)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($2,$hideFlags);
 $6 = HEAP32[$2>>2]|0;
 $7 = (($6) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$shader>>2]|0;
 $10 = (($9) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($shader)|0);
 FUNCTION_TABLE_vii[$8 & 4095]($2,$12);
 $13 = (($2) + 28|0);
 $14 = ($shader|0)==(0|0);
 if ($14) {
  HEAP32[$13>>2] = 0;
  __ZN5Unity8Material15BuildPropertiesEv($2);
  STACKTOP = sp;return ($2|0);
 } else {
  $15 = (($shader) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $16;
  __ZN5Unity8Material15BuildPropertiesEv($2);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z20CreateObjectFromCodeIN5Unity8MaterialEEPT_17AwakeFromLoadMode10MemLabelId($awakeMode,$label) {
 $awakeMode = $awakeMode|0;
 $label = $label|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(144,$$byval_copy2,1,16,641280,1111)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1685,($3|0),($$byval_copy2|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((641176 + 8|0));
  $6 = (($3) + 28|0);
  $7 = (($3) + 40|0);
  $8 = (($3) + 60|0);
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;
  HEAP32[$8>>2] = $3;
  $9 = (($3) + 68|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 76|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 80|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 72|0);
  HEAP32[$12>>2] = $10;
  $13 = (($3) + 88|0);
  HEAP32[$13>>2] = 0;
  $14 = (($3) + 92|0);
  HEAP32[$14>>2] = 0;
  $15 = (($3) + 84|0);
  HEAP32[$15>>2] = $13;
  $16 = (($3) + 100|0);
  HEAP32[$16>>2] = 0;
  $17 = (($3) + 104|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 96|0);
  HEAP32[$18>>2] = $16;
  $19 = (($3) + 108|0);
  $20 = (($3) + 32|0);
  HEAP32[$20>>2] = 0;
  $21 = (($3) + 36|0);
  HEAP8[$21>>0] = 0;
  HEAP32[$6>>2] = 0;
  $22 = (($3) + 64|0);
  ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;HEAP32[$19+16>>2]=0|0;HEAP32[$19+20>>2]=0|0;HEAP32[$19+24>>2]=0|0;
  HEAP32[$22>>2] = -1;
  $23 = (($3) + 136|0);
  HEAP32[$23>>2] = 0;
  $24 = (($3) + 140|0);
  HEAP32[$24>>2] = 0;
  $25 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 24|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vi[$28 & 4095]($25);
  $29 = HEAP32[$25>>2]|0;
  $30 = (($29) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 4095]($25,$awakeMode);
  STACKTOP = sp;return ($25|0);
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(641280|0),1111);
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch(0|0)|0;
  $37 = tempRet0;
  ___clang_call_terminate($36);
  // unreachable;
 } else {
  ___resumeException($32|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN5Unity8Material10GetDefaultEv() {
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[641288>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $8 = $1;
  STACKTOP = sp;return ($8|0);
 }
 $3 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $4 = (__Z20CreateObjectFromCodeIN5Unity8MaterialEEPT_17AwakeFromLoadMode10MemLabelId(4,$$byval_copy)|0);
 HEAP32[641288>>2] = $4;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($4,61);
 $$pre = HEAP32[641288>>2]|0;
 $8 = $$pre;
 STACKTOP = sp;return ($8|0);
}
function __ZN5Unity8Material25GetDefaultDiffuseMaterialEv() {
 var $$0$i = 0, $$byval_copy = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $phitmp$i = 0, $shader$0 = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP8[641304>>0]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   HEAP32[641296>>2] = 0;
   HEAP8[641304>>0] = 1;
   label = 13;
  } else {
   $$pre = HEAP32[641296>>2]|0;
   $5 = ($$pre|0)==(0);
   if ($5) {
    label = 13;
   } else {
    HEAP32[$1>>2] = $$pre;
    $6 = HEAP32[560624>>2]|0;
    $7 = ($6|0)==(0|0);
    if ($7) {
     label = 12;
    } else {
     $8 = (($6) + 36|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($6) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($9|0)==($11|0);
     do {
      if ($12) {
       $13 = (($6) + 28|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = (($6) + 32|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = (($14) + ($16<<3)|0);
       $33 = $17;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$6,$1);
       $18 = HEAP32[$$byval_copy>>2]|0;
       $19 = ($18|0)==(-1);
       $20 = (($6) + 28|0);
       $21 = HEAP32[$20>>2]|0;
       if ($19) {
        $22 = (($6) + 32|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = (($21) + ($23<<3)|0);
        $33 = $24;
        break;
       } else {
        $25 = (($21) + ($18<<3)|0);
        $33 = $25;
        break;
       }
      }
     } while(0);
     $26 = HEAP32[560624>>2]|0;
     $27 = (($26) + 28|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($26) + 32|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + ($30<<3)|0);
     $32 = ($33|0)==($31|0);
     if ($32) {
      label = 12;
     } else {
      $34 = (($33) + 4|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==(0|0);
      if ($36) {
       label = 12;
      }
     }
    }
    if ((label|0) == 12) {
     $37 = HEAP32[641296>>2]|0;
     $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
     $phitmp$i = ($38|0)==(0|0);
     if ($phitmp$i) {
      label = 13;
      break;
     }
    }
    $$pr = HEAP32[641296>>2]|0;
    $83 = $$pr;
   }
  }
 } while(0);
 do {
  if ((label|0) == 13) {
   $39 = (__Z15GetScriptMapperv()|0);
   HEAP8[$2>>0] = 16;
   $40 = (($2) + 1|0);
   $41 = $40;
   $42 = $41;
   HEAP8[$42>>0]=1851880531&255;HEAP8[$42+1>>0]=(1851880531>>8)&255;HEAP8[$42+2>>0]=(1851880531>>16)&255;HEAP8[$42+3>>0]=1851880531>>24;
   $43 = (($41) + 4)|0;
   $44 = $43;
   HEAP8[$44>>0]=1685217636&255;HEAP8[$44+1>>0]=(1685217636>>8)&255;HEAP8[$44+2>>0]=(1685217636>>16)&255;HEAP8[$44+3>>0]=1685217636>>24;
   $45 = (($2) + 9|0);
   HEAP8[$45>>0] = 0;
   __THREW__ = 0;
   $46 = (invoke_iii(2366,($39|0),($2|0))|0);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    $56 = ___cxa_find_matching_catch()|0;
    $57 = tempRet0;
    $58 = HEAP8[$2>>0]|0;
    $59 = $58 & 1;
    $60 = ($59<<24>>24)==(0);
    if ($60) {
     ___resumeException($56|0);
     // unreachable;
    }
    $61 = (($2) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    __ZdlPv($62);
    ___resumeException($56|0);
    // unreachable;
   }
   $49 = HEAP8[$2>>0]|0;
   $50 = $49 & 1;
   $51 = ($50<<24>>24)==(0);
   if (!($51)) {
    $52 = (($2) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    __ZdlPv($53);
   }
   $54 = ($46|0)==(0|0);
   if ($54) {
    $55 = (__ZN6Shader10GetDefaultEv()|0);
    $shader$0 = $55;
   } else {
    $shader$0 = $46;
   }
   $63 = HEAP32[628384>>2]|0;
   HEAP32[$0>>2] = $63;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $64 = (__Z20CreateObjectFromCodeIN5Unity8MaterialEEPT_17AwakeFromLoadMode10MemLabelId(4,$$byval_copy)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($65) + 44|0);
   $67 = HEAP32[$66>>2]|0;
   FUNCTION_TABLE_vii[$67 & 4095]($64,61);
   $68 = HEAP32[$64>>2]|0;
   $69 = (($68) + 36|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = HEAP32[$shader$0>>2]|0;
   $72 = (($71) + 32|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (FUNCTION_TABLE_ii[$73 & 4095]($shader$0)|0);
   FUNCTION_TABLE_vii[$70 & 4095]($64,$74);
   $75 = (($64) + 28|0);
   $76 = ($shader$0|0)==(0|0);
   if ($76) {
    HEAP32[$75>>2] = 0;
   } else {
    $77 = (($shader$0) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    HEAP32[$75>>2] = $78;
   }
   __ZN5Unity8Material15BuildPropertiesEv($64);
   $79 = ($64|0)==(0|0);
   if (!($79)) {
    $80 = (($64) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    HEAP32[641296>>2] = $81;
    $83 = $81;
    break;
   }
   HEAP32[641296>>2] = 0;
   $$0$i = 0;
   STACKTOP = sp;return ($$0$i|0);
  }
 } while(0);
 $82 = ($83|0)==(0);
 if ($82) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $83;
 $84 = HEAP32[560624>>2]|0;
 $85 = ($84|0)==(0|0);
 if ($85) {
  label = 36;
 } else {
  $86 = (($84) + 36|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (($84) + 4|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($87|0)==($89|0);
  do {
   if ($90) {
    $91 = (($84) + 28|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = (($84) + 32|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($92) + ($94<<3)|0);
    $111 = $95;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$84,$0);
    $96 = HEAP32[$$byval_copy>>2]|0;
    $97 = ($96|0)==(-1);
    $98 = (($84) + 28|0);
    $99 = HEAP32[$98>>2]|0;
    if ($97) {
     $100 = (($84) + 32|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (($99) + ($101<<3)|0);
     $111 = $102;
     break;
    } else {
     $103 = (($99) + ($96<<3)|0);
     $111 = $103;
     break;
    }
   }
  } while(0);
  $104 = HEAP32[560624>>2]|0;
  $105 = (($104) + 28|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($104) + 32|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = (($106) + ($108<<3)|0);
  $110 = ($111|0)==($109|0);
  if ($110) {
   label = 36;
  } else {
   $112 = (($111) + 4|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)==(0|0);
   if ($114) {
    label = 36;
   } else {
    $temp$0$i = $113;
   }
  }
 }
 if ((label|0) == 36) {
  $115 = HEAP32[641296>>2]|0;
  $116 = (__Z31ReadObjectFromPersistentManageri($115)|0);
  $temp$0$i = $116;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($this,$passNo,$passContext,$subshaderIndex,$allowRecording) {
 $this = $this|0;
 $passNo = $passNo|0;
 $passContext = $passContext|0;
 $subshaderIndex = $subshaderIndex|0;
 $allowRecording = $allowRecording|0;
 var $$0 = 0, $$01$i$i = 0, $$byval_copy2 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $applyKeywords = 0, $cachedPass$014 = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $i$01$i$i10 = 0, $recording$0$off0 = 0, $shader$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy2 = sp;
 $0 = sp + 72|0;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 $applyKeywords = sp + 24|0;
 $3 = sp + 44|0;
 $4 = (($this) + 120|0);
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy2+12>>2]=HEAP32[$4+12>>2]|0;
 $5 = (($applyKeywords) + 16|0);
 HEAP32[$5>>2] = $passContext;
 $6 = (($passContext) + 4|0);
 ;HEAP32[$applyKeywords+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$applyKeywords+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$applyKeywords+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$applyKeywords+12>>2]=HEAP32[$6+12>>2]|0;
 $7 = HEAP32[$passContext>>2]|0;
 $8 = ($7|0)>(0);
 if ($8) {
  $i$01$i$i = 0;
  while(1) {
   $9 = (($applyKeywords) + ($i$01$i$i<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($$byval_copy2) + ($i$01$i$i<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = $12 | $10;
   $14 = ((($passContext) + ($i$01$i$i<<2)|0) + 4|0);
   HEAP32[$14>>2] = $13;
   $15 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($15|0)==($7|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $15;
   }
  }
 }
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 do {
  if ($18) {
   label = 15;
  } else {
   HEAP32[$2>>2] = $17;
   $19 = HEAP32[560624>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    $21 = (($19) + 36|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($19) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($22|0)==($24|0);
    do {
     if ($25) {
      $26 = (($19) + 28|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = (($19) + 32|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($27) + ($29<<3)|0);
      $46 = $30;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$19,$2);
      $31 = HEAP32[$$byval_copy2>>2]|0;
      $32 = ($31|0)==(-1);
      $33 = (($19) + 28|0);
      $34 = HEAP32[$33>>2]|0;
      if ($32) {
       $35 = (($19) + 32|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = (($34) + ($36<<3)|0);
       $46 = $37;
       break;
      } else {
       $38 = (($34) + ($31<<3)|0);
       $46 = $38;
       break;
      }
     }
    } while(0);
    $39 = HEAP32[560624>>2]|0;
    $40 = (($39) + 28|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($39) + 32|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($41) + ($43<<3)|0);
    $45 = ($46|0)==($44|0);
    if (!($45)) {
     $47 = (($46) + 4|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(0|0);
     if (!($49)) {
      $shader$0 = $48;
      label = 16;
      break;
     }
    }
   }
   $50 = HEAP32[$16>>2]|0;
   __THREW__ = 0;
   $51 = (invoke_ii(3215,($50|0))|0);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if (!($53)) {
    $54 = ($51|0)==(0|0);
    if ($54) {
     label = 15;
    } else {
     $shader$0 = $51;
     label = 16;
    }
   }
  }
 } while(0);
 if ((label|0) == 15) {
  __THREW__ = 0;
  $55 = (invoke_i(104)|0);
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if (!($57)) {
   $shader$0 = $55;
   label = 16;
  }
 }
 L22: do {
  if ((label|0) == 16) {
   $58 = (($this) + 32|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0|0);
   if ($60) {
    __THREW__ = 0;
    invoke_vi(3433,($this|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     break;
    }
   }
   $63 = (($this) + 36|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = ($64<<24>>24)==(0);
   if (!($65)) {
    __THREW__ = 0;
    invoke_vi(3576,($this|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     break;
    }
   }
   __THREW__ = 0;
   $68 = (invoke_i(59)|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    if ($allowRecording) {
     $71 = HEAP8[$63>>0]|0;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $73 = (($this) + 40|0);
      $74 = (($this) + 44|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = HEAP32[$73>>2]|0;
      $77 = $75;
      $78 = $76;
      $79 = (($77) - ($78))|0;
      $80 = (($79|0) / 44)&-1;
      $81 = ($80>>>0)>($subshaderIndex>>>0);
      L34: do {
       if (!($81)) {
        $82 = (($subshaderIndex) + 1)|0;
        $83 = ($80>>>0)<($82>>>0);
        if ($83) {
         $84 = (($82) - ($80))|0;
         __THREW__ = 0;
         invoke_vii(3237,($73|0),($84|0));
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          break L22;
         } else {
          break;
         }
        }
        $87 = ($80>>>0)>($82>>>0);
        if ($87) {
         $88 = (($76) + (($82*44)|0)|0);
         $89 = ($75|0)==($88|0);
         if (!($89)) {
          $91 = $75;
          while(1) {
           $90 = (($91) + -44|0);
           HEAP32[$74>>2] = $90;
           $92 = (($91) + -32|0);
           $93 = HEAP32[$92>>2]|0;
           $94 = ($93|0)>(-1);
           if ($94) {
            $97 = HEAP32[$90>>2]|0;
            $98 = (($91) + -40|0);
            $99 = HEAP32[$98>>2]|0;
            HEAP32[$0>>2] = $99;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
            invoke_vii(2591,($97|0),($$byval_copy2|0));
            $100 = __THREW__; __THREW__ = 0;
            $101 = $100&1;
            if ($101) {
             break;
            }
            HEAP32[$90>>2] = 0;
            $$pre$i$i$i4 = HEAP32[$74>>2]|0;
            $96 = $$pre$i$i$i4;
           } else {
            $96 = $90;
           }
           $95 = ($96|0)==($88|0);
           if ($95) {
            break L34;
           } else {
            $91 = $96;
           }
          }
          $102 = ___cxa_find_matching_catch()|0;
          $103 = tempRet0;
          ___cxa_call_unexpected(($102|0));
          // unreachable;
         }
        }
       }
      } while(0);
      $104 = HEAP32[$73>>2]|0;
      $105 = (($104) + (($subshaderIndex*44)|0)|0);
      $106 = ((($104) + (($subshaderIndex*44)|0)|0) + 8|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = ($107>>>0)>($passNo>>>0);
      if (!($108)) {
       ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;HEAP32[$3+24>>2]=0|0;
       $109 = (($passNo) + 1)|0;
       $110 = ((($104) + (($subshaderIndex*44)|0)|0) + 12|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = $111 & 2147483647;
       $113 = ($112>>>0)<($109>>>0);
       do {
        if ($113) {
         $114 = ($111|0)>(-1);
         if ($114) {
          HEAP32[$110>>2] = $109;
          $115 = HEAP32[$105>>2]|0;
          $116 = ($109*28)|0;
          $117 = ((($104) + (($subshaderIndex*44)|0)|0) + 4|0);
          $118 = HEAP32[$117>>2]|0;
          HEAP32[$0>>2] = $118;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
          $119 = (invoke_iiiiiiii(108,($115|0),($116|0),4,($$byval_copy2|0),0,(641280|0),370)|0);
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           break L22;
          }
          HEAP32[$105>>2] = $119;
          break;
         } else {
          $122 = ($109*28)|0;
          $123 = ((($104) + (($subshaderIndex*44)|0)|0) + 4|0);
          $124 = HEAP32[$123>>2]|0;
          HEAP32[$1>>2] = $124;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
          $125 = (invoke_iiiiiii(102,($122|0),4,($$byval_copy2|0),0,(641280|0),352)|0);
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           break L22;
          }
          $128 = HEAP32[$105>>2]|0;
          $129 = HEAP32[$106>>2]|0;
          $130 = ($129*28)|0;
          _memcpy(($125|0),($128|0),($130|0))|0;
          HEAP32[$110>>2] = $109;
          HEAP32[$105>>2] = $125;
          break;
         }
        }
       } while(0);
       $131 = HEAP32[$106>>2]|0;
       $132 = ($131>>>0)<($109>>>0);
       if ($132) {
        $133 = HEAP32[$105>>2]|0;
        $134 = (($133) + (($109*28)|0)|0);
        $135 = ($131|0)==($109|0);
        if (!($135)) {
         $136 = (($133) + (($131*28)|0)|0);
         $$01$i$i = $136;
         while(1) {
          $137 = ($$01$i$i|0)==(0|0);
          if (!($137)) {
           ;HEAP32[$$01$i$i+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$01$i$i+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$$01$i$i+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$$01$i$i+20>>2]=HEAP32[$3+20>>2]|0;HEAP32[$$01$i$i+24>>2]=HEAP32[$3+24>>2]|0;
          }
          $138 = (($$01$i$i) + 28|0);
          $139 = ($138|0)==($134|0);
          if ($139) {
           break;
          } else {
           $$01$i$i = $138;
          }
         }
        }
       }
       HEAP32[$106>>2] = $109;
      }
      $140 = HEAP32[$105>>2]|0;
      $141 = (($140) + (($passNo*28)|0)|0);
      $142 = ($141|0)==(0|0);
      if ($142) {
       $cachedPass$014 = 0;$recording$0$off0 = 0;
      } else {
       $143 = HEAP32[$141>>2]|0;
       $144 = ($143|0)==(0|0);
       if (!($144)) {
        $i$01$i$i10 = 0;
        while(1) {
         $147 = (((($140) + (($passNo*28)|0)|0) + ($i$01$i$i10<<2)|0) + 8|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ((($passContext) + ($i$01$i$i10<<2)|0) + 4|0);
         $150 = HEAP32[$149>>2]|0;
         $151 = ($148|0)==($150|0);
         $146 = (($i$01$i$i10) + 1)|0;
         if (!($151)) {
          break;
         }
         $145 = ($146|0)<(4);
         if ($145) {
          $i$01$i$i10 = $146;
         } else {
          label = 52;
          break;
         }
        }
        if ((label|0) == 52) {
         $152 = ((($140) + (($passNo*28)|0)|0) + 24|0);
         $153 = HEAP32[$152>>2]|0;
         $154 = HEAP32[678896>>2]|0;
         $155 = ($153|0)==($154|0);
         if ($155) {
          $156 = HEAP32[$143>>2]|0;
          $157 = (($156) + 8|0);
          $158 = HEAP32[$157>>2]|0;
          __THREW__ = 0;
          invoke_vii($158|0,($143|0),($passContext|0));
          $159 = __THREW__; __THREW__ = 0;
          $160 = $159&1;
          if ($160) {
           break;
          }
          $161 = ((($140) + (($passNo*28)|0)|0) + 4|0);
          $162 = HEAP32[$161>>2]|0;
          $$0 = $162;
          $210 = HEAP32[$5>>2]|0;
          $211 = (($210) + 4|0);
          ;HEAP32[$211+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$211+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$211+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$211+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
          STACKTOP = sp;return ($$0|0);
         }
        }
        $163 = (($143) + 4|0);
        $164 = HEAP32[$163>>2]|0;
        $165 = (($164) + -1)|0;
        HEAP32[$163>>2] = $165;
        $166 = HEAP32[$163>>2]|0;
        $167 = ($166|0)==(0);
        if ($167) {
         $168 = HEAP32[$143>>2]|0;
         $169 = (($168) + 4|0);
         $170 = HEAP32[$169>>2]|0;
         __THREW__ = 0;
         invoke_vi($170|0,($143|0));
         $171 = __THREW__; __THREW__ = 0;
         $172 = $171&1;
         if ($172) {
          break;
         }
        }
        HEAP32[$141>>2] = 0;
       }
       __THREW__ = 0;
       $173 = (invoke_iiii(1563,($shader$0|0),($subshaderIndex|0),($passNo|0))|0);
       $174 = __THREW__; __THREW__ = 0;
       $175 = $174&1;
       if ($175) {
        break;
       }
       if ($173) {
        $176 = HEAP32[$68>>2]|0;
        $177 = (($176) + 588|0);
        $178 = HEAP32[$177>>2]|0;
        __THREW__ = 0;
        $179 = (invoke_ii($178|0,($68|0))|0);
        $180 = __THREW__; __THREW__ = 0;
        $181 = $180&1;
        if ($181) {
         break;
        } else {
         $cachedPass$014 = $141;$recording$0$off0 = $179;
        }
       } else {
        $cachedPass$014 = $141;$recording$0$off0 = 0;
       }
      }
     } else {
      $cachedPass$014 = 0;$recording$0$off0 = 0;
     }
    } else {
     $cachedPass$014 = 0;$recording$0$off0 = 0;
    }
    $182 = (($this) + 140|0);
    $183 = HEAP32[$182>>2]|0;
    $184 = HEAP32[$58>>2]|0;
    $185 = ($184|0)==(0|0);
    if ($185) {
     __THREW__ = 0;
     invoke_vi(3433,($this|0));
     $186 = __THREW__; __THREW__ = 0;
     $187 = $186&1;
     if ($187) {
      break;
     }
     $$pre$i = HEAP32[$58>>2]|0;
     $188 = $$pre$i;
    } else {
     $188 = $184;
    }
    __THREW__ = 0;
    $189 = (invoke_iiiiiii(110,($shader$0|0),($subshaderIndex|0),($passNo|0),($183|0),($188|0),($passContext|0))|0);
    $190 = __THREW__; __THREW__ = 0;
    $191 = $190&1;
    if (!($191)) {
     if (!($recording$0$off0)) {
      $$0 = $189;
      $210 = HEAP32[$5>>2]|0;
      $211 = (($210) + 4|0);
      ;HEAP32[$211+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$211+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$211+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$211+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
      STACKTOP = sp;return ($$0|0);
     }
     $192 = HEAP32[$68>>2]|0;
     $193 = (($192) + 592|0);
     $194 = HEAP32[$193>>2]|0;
     __THREW__ = 0;
     $195 = (invoke_iiii($194|0,($68|0),($cachedPass$014|0),($passContext|0))|0);
     $196 = __THREW__; __THREW__ = 0;
     $197 = $196&1;
     if (!($197)) {
      if (!($195)) {
       $$0 = $189;
       $210 = HEAP32[$5>>2]|0;
       $211 = (($210) + 4|0);
       ;HEAP32[$211+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$211+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$211+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$211+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
       STACKTOP = sp;return ($$0|0);
      }
      $198 = (($cachedPass$014) + 4|0);
      HEAP32[$198>>2] = $189;
      $199 = (($cachedPass$014) + 8|0);
      ;HEAP32[$199+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$199+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$199+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$199+12>>2]=HEAP32[$6+12>>2]|0;
      $200 = HEAP32[678896>>2]|0;
      $201 = (($cachedPass$014) + 24|0);
      HEAP32[$201>>2] = $200;
      $202 = (($this) + 52|0);
      $203 = HEAP32[$202>>2]|0;
      $204 = ($203|0)==(0|0);
      if (!($204)) {
       $$0 = $189;
       $210 = HEAP32[$5>>2]|0;
       $211 = (($210) + 4|0);
       ;HEAP32[$211+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$211+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$211+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$211+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
       STACKTOP = sp;return ($$0|0);
      }
      $205 = HEAP32[((641504 + 4|0))>>2]|0;
      $206 = ($202|0)==($205|0);
      if ($206) {
       $$0 = $189;
       $210 = HEAP32[$5>>2]|0;
       $211 = (($210) + 4|0);
       ;HEAP32[$211+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$211+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$211+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$211+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
       STACKTOP = sp;return ($$0|0);
      }
      $$pre$i$i$i = (($this) + 56|0);
      $207 = HEAP32[$205>>2]|0;
      HEAP32[$202>>2] = $207;
      HEAP32[$$pre$i$i$i>>2] = $205;
      $208 = (($207) + 4|0);
      HEAP32[$208>>2] = $202;
      $209 = HEAP32[$$pre$i$i$i>>2]|0;
      HEAP32[$209>>2] = $202;
      $$0 = $189;
      $210 = HEAP32[$5>>2]|0;
      $211 = (($210) + 4|0);
      ;HEAP32[$211+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$211+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$211+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$211+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $212 = ___cxa_find_matching_catch()|0;
 $213 = tempRet0;
 $214 = HEAP32[$5>>2]|0;
 $215 = (($214) + 4|0);
 ;HEAP32[$215+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$215+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$215+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$215+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
 ___resumeException($212|0);
 // unreachable;
 return 0|0;
}
function __ZN5Unity8Material17SetPassWithShaderEiP6ShaderRN9ShaderLab17ShaderPassContextEi($this,$passNo,$shader,$passContext,$subshaderIndex) {
 $this = $this|0;
 $passNo = $passNo|0;
 $shader = $shader|0;
 $passContext = $passContext|0;
 $subshaderIndex = $subshaderIndex|0;
 var $$0 = 0, $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $applyKeywords = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $mask1$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $mask1$i = sp;
 $0 = sp + 36|0;
 $applyKeywords = sp + 16|0;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   label = 10;
  } else {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($mask1$i,$4,$0);
     $16 = HEAP32[$mask1$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if ($30) {
    label = 10;
   } else {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     label = 10;
    } else {
     $temp$0$i = $33;
    }
   }
  }
  if ((label|0) == 10) {
   $35 = HEAP32[$1>>2]|0;
   $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
   $temp$0$i = $36;
  }
  $$0$i = $temp$0$i;
 }
 $37 = ($$0$i|0)==($shader|0);
 if ($37) {
  $38 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($this,$passNo,$passContext,$subshaderIndex,1)|0);
  $$0 = $38;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = (($this) + 120|0);
 ;HEAP32[$mask1$i+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$mask1$i+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$mask1$i+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$mask1$i+12>>2]=HEAP32[$39+12>>2]|0;
 $40 = (($applyKeywords) + 16|0);
 HEAP32[$40>>2] = $passContext;
 $41 = (($passContext) + 4|0);
 ;HEAP32[$applyKeywords+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$applyKeywords+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$applyKeywords+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$applyKeywords+12>>2]=HEAP32[$41+12>>2]|0;
 $42 = HEAP32[$passContext>>2]|0;
 $43 = ($42|0)>(0);
 if ($43) {
  $i$01$i$i = 0;
  while(1) {
   $44 = (($applyKeywords) + ($i$01$i$i<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($mask1$i) + ($i$01$i$i<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | $45;
   $49 = ((($passContext) + ($i$01$i$i<<2)|0) + 4|0);
   HEAP32[$49>>2] = $48;
   $50 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($50|0)==($42|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $50;
   }
  }
 }
 $51 = (($this) + 140|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0|0);
 do {
  if ($55) {
   __THREW__ = 0;
   invoke_vi(3433,($this|0));
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    $62 = ___cxa_find_matching_catch()|0;
    $63 = tempRet0;
    ;HEAP32[$41+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
    ___resumeException($62|0);
    // unreachable;
   } else {
    $$pre$i = HEAP32[$53>>2]|0;
    $58 = $$pre$i;
    break;
   }
  } else {
   $58 = $54;
  }
 } while(0);
 __THREW__ = 0;
 $59 = (invoke_iiiiiii(110,($shader|0),($subshaderIndex|0),($passNo|0),($52|0),($58|0),($passContext|0))|0);
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 if ($61) {
  $62 = ___cxa_find_matching_catch()|0;
  $63 = tempRet0;
  ;HEAP32[$41+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
  ___resumeException($62|0);
  // unreachable;
 }
 ;HEAP32[$41+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
 $$0 = $59;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity8Material29SetShadowCasterPassWithShaderEP6ShaderRN9ShaderLab17ShaderPassContextEi($this,$shader,$passContext,$subshaderIndex) {
 $this = $this|0;
 $shader = $shader|0;
 $passContext = $passContext|0;
 $subshaderIndex = $subshaderIndex|0;
 var $$0 = 0, $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $applyKeywords = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $mask1$i = 0, $passIndex = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $mask1$i = sp;
 $0 = sp + 40|0;
 $applyKeywords = sp + 16|0;
 $passIndex = sp + 36|0;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   label = 10;
  } else {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($mask1$i,$4,$0);
     $16 = HEAP32[$mask1$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if ($30) {
    label = 10;
   } else {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     label = 10;
    } else {
     $temp$0$i = $33;
    }
   }
  }
  if ((label|0) == 10) {
   $35 = HEAP32[$1>>2]|0;
   $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
   $temp$0$i = $36;
  }
  $$0$i = $temp$0$i;
 }
 $37 = ($$0$i|0)==($shader|0);
 if ($37) {
  $38 = (__ZN5Unity8Material19SetShadowCasterPassEiRN9ShaderLab17ShaderPassContextE($this,$subshaderIndex,$passContext)|0);
  $$0 = $38;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = (($this) + 120|0);
 ;HEAP32[$mask1$i+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$mask1$i+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$mask1$i+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$mask1$i+12>>2]=HEAP32[$39+12>>2]|0;
 $40 = (($applyKeywords) + 16|0);
 HEAP32[$40>>2] = $passContext;
 $41 = (($passContext) + 4|0);
 ;HEAP32[$applyKeywords+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$applyKeywords+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$applyKeywords+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$applyKeywords+12>>2]=HEAP32[$41+12>>2]|0;
 $42 = HEAP32[$passContext>>2]|0;
 $43 = ($42|0)>(0);
 if ($43) {
  $i$01$i$i = 0;
  while(1) {
   $44 = (($applyKeywords) + ($i$01$i$i<<2)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($mask1$i) + ($i$01$i$i<<2)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = $47 | $45;
   $49 = ((($passContext) + ($i$01$i$i<<2)|0) + 4|0);
   HEAP32[$49>>2] = $48;
   $50 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($50|0)==($42|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $50;
   }
  }
 }
 __THREW__ = 0;
 $51 = (invoke_iiii(1537,($shader|0),($subshaderIndex|0),($passIndex|0))|0);
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $66 = ___cxa_find_matching_catch()|0;
  $67 = tempRet0;
  ;HEAP32[$41+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
  ___resumeException($66|0);
  // unreachable;
 }
 $54 = (($this) + 140|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($this) + 32|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 do {
  if ($58) {
   __THREW__ = 0;
   invoke_vi(3433,($this|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if ($60) {
    $66 = ___cxa_find_matching_catch()|0;
    $67 = tempRet0;
    ;HEAP32[$41+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
    ___resumeException($66|0);
    // unreachable;
   } else {
    $$pre$i = HEAP32[$56>>2]|0;
    $62 = $$pre$i;
    break;
   }
  } else {
   $62 = $57;
  }
 } while(0);
 $61 = HEAP32[$passIndex>>2]|0;
 __THREW__ = 0;
 $63 = (invoke_iiiiiii(111,($51|0),($55|0),($62|0),($passContext|0),($shader|0),($61|0))|0);
 $64 = __THREW__; __THREW__ = 0;
 $65 = $64&1;
 if ($65) {
  $66 = ___cxa_find_matching_catch()|0;
  $67 = tempRet0;
  ;HEAP32[$41+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
  ___resumeException($66|0);
  // unreachable;
 }
 ;HEAP32[$41+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
 $$0 = $63;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity8Material19SetShadowCasterPassEiRN9ShaderLab17ShaderPassContextE($this,$subshaderIndex,$passContext) {
 $this = $this|0;
 $subshaderIndex = $subshaderIndex|0;
 $passContext = $passContext|0;
 var $$0 = 0, $$byval_copy = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $applyKeywords = 0, $cachedPass$0 = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $i$01$i$i5 = 0, $not$$i = 0, $passIndex = 0, $recording$0$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp;
 $0 = sp + 40|0;
 $applyKeywords = sp + 16|0;
 $passIndex = sp + 36|0;
 $1 = (($this) + 120|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($applyKeywords) + 16|0);
 HEAP32[$2>>2] = $passContext;
 $3 = (($passContext) + 4|0);
 ;HEAP32[$applyKeywords+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$applyKeywords+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$applyKeywords+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$applyKeywords+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = HEAP32[$passContext>>2]|0;
 $5 = ($4|0)>(0);
 if ($5) {
  $i$01$i$i = 0;
  while(1) {
   $6 = (($applyKeywords) + ($i$01$i$i<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($$byval_copy) + ($i$01$i$i<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 | $7;
   $11 = ((($passContext) + ($i$01$i$i<<2)|0) + 4|0);
   HEAP32[$11>>2] = $10;
   $12 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($12|0)==($4|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $12;
   }
  }
 }
 __THREW__ = 0;
 $13 = (invoke_ii(3221,($this|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 L5: do {
  if (!($15)) {
   __THREW__ = 0;
   $16 = (invoke_iiii(1537,($13|0),($subshaderIndex|0),($passIndex|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = (($this) + 32|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     __THREW__ = 0;
     invoke_vi(3433,($this|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
    }
    $24 = (($this) + 36|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = ($25<<24>>24)==(0);
    if (!($26)) {
     __THREW__ = 0;
     invoke_vi(3576,($this|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
    }
    __THREW__ = 0;
    $29 = (invoke_i(59)|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = HEAP8[$24>>0]|0;
     $33 = ($32<<24>>24)==(0);
     do {
      if ($33) {
       $34 = (($this) + 40|0);
       $35 = (($this) + 44|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = HEAP32[$34>>2]|0;
       $38 = $36;
       $39 = $37;
       $40 = (($38) - ($39))|0;
       $41 = (($40|0) / 44)&-1;
       $42 = ($41>>>0)>($subshaderIndex>>>0);
       L17: do {
        if (!($42)) {
         $43 = (($subshaderIndex) + 1)|0;
         $44 = ($41>>>0)<($43>>>0);
         if ($44) {
          $45 = (($43) - ($41))|0;
          __THREW__ = 0;
          invoke_vii(3237,($34|0),($45|0));
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break L5;
          } else {
           break;
          }
         }
         $48 = ($41>>>0)>($43>>>0);
         if ($48) {
          $49 = (($37) + (($43*44)|0)|0);
          $50 = ($36|0)==($49|0);
          if (!($50)) {
           $52 = $36;
           while(1) {
            $51 = (($52) + -44|0);
            HEAP32[$35>>2] = $51;
            $53 = (($52) + -32|0);
            $54 = HEAP32[$53>>2]|0;
            $55 = ($54|0)>(-1);
            if ($55) {
             $58 = HEAP32[$51>>2]|0;
             $59 = (($52) + -40|0);
             $60 = HEAP32[$59>>2]|0;
             HEAP32[$0>>2] = $60;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
             invoke_vii(2591,($58|0),($$byval_copy|0));
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              break;
             }
             HEAP32[$51>>2] = 0;
             $$pre$i$i$i3 = HEAP32[$35>>2]|0;
             $57 = $$pre$i$i$i3;
            } else {
             $57 = $51;
            }
            $56 = ($57|0)==($49|0);
            if ($56) {
             break L17;
            } else {
             $52 = $57;
            }
           }
           $63 = ___cxa_find_matching_catch()|0;
           $64 = tempRet0;
           ___cxa_call_unexpected(($63|0));
           // unreachable;
          }
         }
        }
       } while(0);
       $65 = HEAP32[$34>>2]|0;
       $66 = ((($65) + (($subshaderIndex*44)|0)|0) + 16|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = ($67|0)==(0|0);
       if (!($68)) {
        $i$01$i$i5 = 0;
        while(1) {
         $71 = (((($65) + (($subshaderIndex*44)|0)|0) + ($i$01$i$i5<<2)|0) + 24|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = ((($passContext) + ($i$01$i$i5<<2)|0) + 4|0);
         $74 = HEAP32[$73>>2]|0;
         $75 = ($72|0)==($74|0);
         $70 = (($i$01$i$i5) + 1)|0;
         if (!($75)) {
          break;
         }
         $69 = ($70|0)<(4);
         if ($69) {
          $i$01$i$i5 = $70;
         } else {
          label = 25;
          break;
         }
        }
        if ((label|0) == 25) {
         $76 = HEAP32[$67>>2]|0;
         $77 = (($76) + 8|0);
         $78 = HEAP32[$77>>2]|0;
         __THREW__ = 0;
         invoke_vii($78|0,($67|0),($passContext|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break L5;
         }
         $81 = ((($65) + (($subshaderIndex*44)|0)|0) + 20|0);
         $82 = HEAP32[$81>>2]|0;
         $$0 = $82;
         break;
        }
        $83 = (($67) + 4|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = (($84) + -1)|0;
        HEAP32[$83>>2] = $85;
        $86 = HEAP32[$83>>2]|0;
        $87 = ($86|0)==(0);
        if ($87) {
         $88 = HEAP32[$67>>2]|0;
         $89 = (($88) + 4|0);
         $90 = HEAP32[$89>>2]|0;
         __THREW__ = 0;
         invoke_vi($90|0,($67|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break L5;
         }
        }
        HEAP32[$66>>2] = 0;
       }
       $93 = (($16) + 640|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = ($94|0)==(2);
       if ($95) {
        $cachedPass$0 = $66;$recording$0$off0 = 0;
        label = 33;
       } else {
        $96 = (($16) + 356|0);
        $97 = HEAP8[$96>>0]|0;
        $not$$i = ($97<<24>>24)==(0);
        if ($not$$i) {
         $98 = HEAP32[$29>>2]|0;
         $99 = (($98) + 588|0);
         $100 = HEAP32[$99>>2]|0;
         __THREW__ = 0;
         $101 = (invoke_ii($100|0,($29|0))|0);
         $102 = __THREW__; __THREW__ = 0;
         $103 = $102&1;
         if ($103) {
          break L5;
         } else {
          $cachedPass$0 = $66;$recording$0$off0 = $101;
          label = 33;
         }
        } else {
         $cachedPass$0 = $66;$recording$0$off0 = 0;
         label = 33;
        }
       }
      } else {
       $cachedPass$0 = 0;$recording$0$off0 = 0;
       label = 33;
      }
     } while(0);
     if ((label|0) == 33) {
      $104 = (($this) + 140|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = HEAP32[$19>>2]|0;
      $107 = ($106|0)==(0|0);
      if ($107) {
       __THREW__ = 0;
       invoke_vi(3433,($this|0));
       $108 = __THREW__; __THREW__ = 0;
       $109 = $108&1;
       if ($109) {
        break;
       }
       $$pre$i = HEAP32[$19>>2]|0;
       $111 = $$pre$i;
      } else {
       $111 = $106;
      }
      $110 = HEAP32[$passIndex>>2]|0;
      __THREW__ = 0;
      $112 = (invoke_iiiiiii(111,($16|0),($105|0),($111|0),($passContext|0),($13|0),($110|0))|0);
      $113 = __THREW__; __THREW__ = 0;
      $114 = $113&1;
      if ($114) {
       break;
      }
      if ($recording$0$off0) {
       $115 = HEAP32[$29>>2]|0;
       $116 = (($115) + 592|0);
       $117 = HEAP32[$116>>2]|0;
       __THREW__ = 0;
       $118 = (invoke_iiii($117|0,($29|0),($cachedPass$0|0),($passContext|0))|0);
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        break;
       }
       if ($118) {
        $121 = (($cachedPass$0) + 4|0);
        HEAP32[$121>>2] = $112;
        $122 = (($cachedPass$0) + 8|0);
        ;HEAP32[$122+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$122+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$122+12>>2]=HEAP32[$3+12>>2]|0;
        $123 = (($this) + 52|0);
        $124 = HEAP32[$123>>2]|0;
        $125 = ($124|0)==(0|0);
        if ($125) {
         $126 = HEAP32[((641504 + 4|0))>>2]|0;
         $127 = ($123|0)==($126|0);
         if ($127) {
          $$0 = $112;
         } else {
          $$pre$i$i$i = (($this) + 56|0);
          $128 = HEAP32[$126>>2]|0;
          HEAP32[$123>>2] = $128;
          HEAP32[$$pre$i$i$i>>2] = $126;
          $129 = (($128) + 4|0);
          HEAP32[$129>>2] = $123;
          $130 = HEAP32[$$pre$i$i$i>>2]|0;
          HEAP32[$130>>2] = $123;
          $$0 = $112;
         }
        } else {
         $$0 = $112;
        }
       } else {
        $$0 = $112;
       }
      } else {
       $$0 = $112;
      }
     }
     $131 = HEAP32[$2>>2]|0;
     $132 = (($131) + 4|0);
     ;HEAP32[$132+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$132+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $133 = ___cxa_find_matching_catch()|0;
 $134 = tempRet0;
 $135 = HEAP32[$2>>2]|0;
 $136 = (($135) + 4|0);
 ;HEAP32[$136+0>>2]=HEAP32[$applyKeywords+0>>2]|0;HEAP32[$136+4>>2]=HEAP32[$applyKeywords+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$applyKeywords+8>>2]|0;HEAP32[$136+12>>2]=HEAP32[$applyKeywords+12>>2]|0;
 ___resumeException($133|0);
 // unreachable;
 return 0|0;
}
function __ZN5Unity8Material9GetShaderEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  HEAP32[$0>>2] = $2;
  $4 = HEAP32[560624>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($4) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   do {
    if ($10) {
     $11 = (($4) + 28|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($4) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($12) + ($14<<3)|0);
     $31 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
     $16 = HEAP32[$pos$i$i$i$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = (($4) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     if ($17) {
      $20 = (($4) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $31 = $22;
      break;
     } else {
      $23 = (($19) + ($16<<3)|0);
      $31 = $23;
      break;
     }
    }
   } while(0);
   $24 = HEAP32[560624>>2]|0;
   $25 = (($24) + 28|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + 32|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + ($28<<3)|0);
   $30 = ($31|0)==($29|0);
   if (!($30)) {
    $32 = (($31) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     $$0 = $33;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $$0 = $36;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $38 = (__ZN6Shader10GetDefaultEv()|0);
 $$0 = $38;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK5Unity8Material6GetTagERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEbS9_($agg$result,$this,$tag,$currentSubShaderOnly,$defaultValue) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $tag = $tag|0;
 $currentSubShaderOnly = $currentSubShaderOnly|0;
 $defaultValue = $defaultValue|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9ShaderLab14GetShaderTagIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($tag)|0);
 $1 = (__ZNK5Unity8Material6GetTagEib($this,$0,$currentSubShaderOnly)|0);
 $2 = ($1|0)<(0);
 if (!($2)) {
  __ZN9ShaderLab16GetShaderTagNameEi($agg$result,$1);
  STACKTOP = sp;return;
 }
 $3 = HEAP8[$defaultValue>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$defaultValue+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$defaultValue+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$defaultValue+8>>2]|0;
  STACKTOP = sp;return;
 }
 $6 = (($defaultValue) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($defaultValue) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9>>>0)>(4294967279);
 if ($10) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $11 = ($9>>>0)<(11);
 if ($11) {
  $12 = $9 << 1;
  $13 = $12&255;
  HEAP8[$agg$result>>0] = $13;
  $14 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $14;
 } else {
  $15 = (($9) + 16)|0;
  $16 = $15 & -16;
  $17 = (__Znwj($16)|0);
  $18 = (($agg$result) + 8|0);
  HEAP32[$18>>2] = $17;
  $19 = $16 | 1;
  HEAP32[$agg$result>>2] = $19;
  $20 = (($agg$result) + 4|0);
  HEAP32[$20>>2] = $9;
  $__p$0$i$i$i = $17;
 }
 _memcpy(($__p$0$i$i$i|0),($7|0),($9|0))|0;
 $21 = (($__p$0$i$i$i) + ($9)|0);
 HEAP8[$21>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK5Unity8Material6GetTagEib($this,$tag,$currentSubShaderOnly) {
 $this = $this|0;
 $tag = $tag|0;
 $currentSubShaderOnly = $currentSubShaderOnly|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i2 = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $temp$0$i2 = $36;
  }
 }
 $38 = (($temp$0$i2) + 52|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (__ZNK9ShaderLab9IntShader6GetTagEib($39,$tag,$currentSubShaderOnly)|0);
 $$0 = $40;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity8Material12GetPassCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $shader$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   label = 12;
  } else {
   HEAP32[$0>>2] = $2;
   $4 = HEAP32[560624>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = (($4) + 36|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($4) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($7|0)==($9|0);
    do {
     if ($10) {
      $11 = (($4) + 28|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = (($4) + 32|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($12) + ($14<<3)|0);
      $31 = $15;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
      $16 = HEAP32[$pos$i$i$i$i>>2]|0;
      $17 = ($16|0)==(-1);
      $18 = (($4) + 28|0);
      $19 = HEAP32[$18>>2]|0;
      if ($17) {
       $20 = (($4) + 32|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($19) + ($21<<3)|0);
       $31 = $22;
       break;
      } else {
       $23 = (($19) + ($16<<3)|0);
       $31 = $23;
       break;
      }
     }
    } while(0);
    $24 = HEAP32[560624>>2]|0;
    $25 = (($24) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + 32|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + ($28<<3)|0);
    $30 = ($31|0)==($29|0);
    if (!($30)) {
     $32 = (($31) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if (!($34)) {
      $shader$0 = $33;
      break;
     }
    }
   }
   $35 = HEAP32[$1>>2]|0;
   $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
   $37 = ($36|0)==(0|0);
   if ($37) {
    label = 12;
   } else {
    $shader$0 = $36;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $38 = (__ZN6Shader10GetDefaultEv()|0);
  $shader$0 = $38;
 }
 $39 = (($shader$0) + 52|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 32|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$40>>2]|0;
 $44 = (($43) + ($42<<2)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 16|0);
 $47 = HEAP32[$46>>2]|0;
 STACKTOP = sp;return ($47|0);
}
function __ZN5Unity8Material23GetInstantiatedMaterialEPS0_R6Objectb($material,$renderer,$allowInEditMode) {
 $material = $material|0;
 $renderer = $renderer|0;
 $allowInEditMode = $allowInEditMode|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $$byval_copy3 = 0, $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $instance$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 20|0;
 $4 = ($material|0)==(0|0);
 if ($4) {
  $5 = (__ZN5Unity8Material25GetDefaultDiffuseMaterialEv()|0);
  $$03 = $5;
 } else {
  $$03 = $material;
 }
 $6 = ($renderer|0)==(0|0);
 if ($6) {
  $12 = 0;
 } else {
  $7 = (($renderer) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $12 = $8;
 }
 $9 = (($$03) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($12|0);
 if ($11) {
  $$02 = $$03;
  STACKTOP = sp;return ($$02|0);
 }
 if (!($allowInEditMode)) {
  $13 = (__Z14IsWorldPlayingv()|0);
  if (!($13)) {
   if ($6) {
    $16 = 0;
   } else {
    $14 = (($renderer) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $15;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(641312,0,641280,645,1,$16,0,0);
  }
 }
 $17 = (($$03) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $$mask = $18 & -2097152;
 $19 = ($$mask|0)==(387973120);
 if ($19) {
  $20 = (__ZN18ProceduralMaterial5CloneEv($$03)|0);
  $instance$0 = $20;
 } else {
  $21 = HEAP32[628384>>2]|0;
  HEAP32[$1>>2] = $21;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  $22 = (__Z20CreateObjectFromCodeIN5Unity8MaterialEEPT_17AwakeFromLoadMode10MemLabelId(4,$$byval_copy3)|0);
  $instance$0 = $22;
 }
 $23 = HEAP32[$$03>>2]|0;
 $24 = (($23) + 32|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 4095]($$03)|0);
 __Z6AppendPKcS0_($2,$26,641488);
 $27 = HEAP32[$instance$0>>2]|0;
 $28 = (($27) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP8[$2>>0]|0;
 $31 = $30 & 1;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  $35 = (($2) + 1|0);
  $36 = $35;
 } else {
  $33 = (($2) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $36 = $34;
 }
 __THREW__ = 0;
 invoke_vii($29|0,($instance$0|0),($36|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $64 = ___cxa_find_matching_catch()|0;
  $65 = tempRet0;
  $66 = HEAP8[$2>>0]|0;
  $67 = $66 & 1;
  $68 = ($67<<24>>24)==(0);
  if ($68) {
   $$0 = $65;$$01 = $64;
   ___resumeException($$01|0);
   // unreachable;
  }
  $69 = (($2) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  __ZdlPv($70);
  $$0 = $65;$$01 = $64;
  ___resumeException($$01|0);
  // unreachable;
 }
 $39 = HEAP8[$2>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if (!($41)) {
  $42 = (($2) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  __ZdlPv($43);
 }
 $44 = (($$03) + 28|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($instance$0) + 28|0);
 HEAP32[$46>>2] = $45;
 $47 = (($instance$0) + 68|0);
 if ($6) {
  HEAP32[$47>>2] = 0;
 } else {
  $48 = (($renderer) + 4|0);
  $49 = HEAP32[$48>>2]|0;
  HEAP32[$47>>2] = $49;
 }
 $50 = (($$03) + 32|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 do {
  if (!($52)) {
   $53 = (($instance$0) + 32|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if (!($55)) {
    $56 = HEAP32[628272>>2]|0;
    $57 = (($54) + 4|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($58) + -1)|0;
    HEAP32[$57>>2] = $59;
    $60 = HEAP32[$57>>2]|0;
    $61 = ($60|0)==(0);
    if ($61) {
     $62 = HEAP32[$54>>2]|0;
     $63 = HEAP32[$62>>2]|0;
     FUNCTION_TABLE_vi[$63 & 4095]($54);
     HEAP32[$0>>2] = $56;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($54,$$byval_copy3);
    }
    HEAP32[$53>>2] = 0;
   }
   $71 = HEAP32[628272>>2]|0;
   HEAP32[$3>>2] = $71;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
   $72 = (__Znwj10MemLabelIdbiPKci(84,$$byval_copy3,0,16,641280,664)|0);
   $73 = HEAP32[$50>>2]|0;
   __THREW__ = 0;
   invoke_vii(3238,($72|0),($73|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if (!($75)) {
    HEAP32[$53>>2] = $72;
    $76 = (($72) + 80|0);
    HEAP32[$76>>2] = $instance$0;
    break;
   }
   $77 = ___cxa_find_matching_catch()|0;
   $78 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viiiiii(97,($72|0),($$byval_copy3|0),0,16,(641280|0),664);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    $96 = ___cxa_find_matching_catch(0|0)|0;
    $97 = tempRet0;
    ___clang_call_terminate($96);
    // unreachable;
   } else {
    $$0 = $78;$$01 = $77;
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $81 = (($$03) + 64|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($instance$0) + 64|0);
 HEAP32[$83>>2] = $82;
 $84 = (($instance$0) + 72|0);
 $85 = (($$03) + 72|0);
 (__ZN18UnityPropertySheetaSERKS_($84,$85)|0);
 $86 = (($instance$0) + 108|0);
 $87 = (($$03) + 108|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($86,$87)|0);
 $88 = (($instance$0) + 120|0);
 $89 = (($$03) + 120|0);
 ;HEAP32[$88+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$89+12>>2]|0;
 $90 = (($$03) + 136|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (($instance$0) + 136|0);
 HEAP32[$92>>2] = $91;
 $93 = (($$03) + 140|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($instance$0) + 140|0);
 HEAP32[$95>>2] = $94;
 $$02 = $instance$0;
 STACKTOP = sp;return ($$02|0);
}
function __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($this,$name,$col) {
 $this = $this|0;
 $name = $name|0;
 $col = $col|0;
 var $$0$i$i$i = Math_fround(0), $$0$i1$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0);
 var $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = (($this) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 100|0);
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$name>>2]|0;
  $$0$ph7$i$i$i = $4;$$01$ph6$i$in$i$i = $3;
  L3: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<($6|0);
    if (!($9)) {
     break;
    }
    $12 = (($$013$i$in$i$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L3;
    } else {
     $$013$i$in$i$i = $13;
    }
   }
   $10 = HEAP32[$$013$i$in$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $10;
   }
  }
  $15 = ($$0$ph5$i$i$i|0)==($4|0);
  if (!($15)) {
   $16 = (($$0$ph5$i$i$i) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($6|0)<($17|0);
   if (!($18)) {
    $19 = Math_fround(HEAPF32[$col>>2]);
    $20 = (($col) + 4|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = (($col) + 8|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = (($col) + 12|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = (($$0$ph5$i$i$i) + 20|0);
    HEAPF32[$26>>2] = $19;
    $27 = (($$0$ph5$i$i$i) + 24|0);
    HEAPF32[$27>>2] = $21;
    $28 = (($$0$ph5$i$i$i) + 28|0);
    HEAPF32[$28>>2] = $23;
    $29 = (($$0$ph5$i$i$i) + 32|0);
    HEAPF32[$29>>2] = $25;
   }
  }
 }
 $30 = (($this) + 32|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre$i = HEAP32[$30>>2]|0;
  $34 = $$pre$i;
 } else {
  $34 = $31;
 }
 $33 = (($this) + 36|0);
 HEAP8[$33>>0] = 1;
 $35 = (__ZNK9ShaderLab13PropertySheet11GetColorTagERKNS_16FastPropertyNameE($34,$name)|0);
 if (!($35)) {
  __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($34,$name,$col);
  $69 = HEAP32[$name>>2]|0;
  HEAP32[$1>>2] = $69;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
  STACKTOP = sp;return;
 }
 $36 = (__Z19GetActiveColorSpacev()|0);
 $37 = ($36|0)==(1);
 if ($37) {
  $38 = Math_fround(HEAPF32[$col>>2]);
  $39 = !($38 <= Math_fround(0.0404499992728233337402));
  do {
   if ($39) {
    $41 = $38 < Math_fround(1.0);
    if ($41) {
     $42 = Math_fround($38 + Math_fround(0.054999999701976776123));
     $43 = Math_fround($42 / Math_fround(1.05499994754791259766));
     $44 = (Math_fround(+(Math_pow((+$43),2.40000009536743164063))));
     $$0$i$i$i = $44;
     break;
    } else {
     $45 = (Math_fround(+(Math_pow((+$38),2.40000009536743164063))));
     $$0$i$i$i = $45;
     break;
    }
   } else {
    $40 = Math_fround($38 / Math_fround(12.9200000762939453125));
    $$0$i$i$i = $40;
   }
  } while(0);
  $46 = (($col) + 4|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = !($47 <= Math_fround(0.0404499992728233337402));
  do {
   if ($48) {
    $50 = $47 < Math_fround(1.0);
    if ($50) {
     $51 = Math_fround($47 + Math_fround(0.054999999701976776123));
     $52 = Math_fround($51 / Math_fround(1.05499994754791259766));
     $53 = (Math_fround(+(Math_pow((+$52),2.40000009536743164063))));
     $$0$i3$i$i = $53;
     break;
    } else {
     $54 = (Math_fround(+(Math_pow((+$47),2.40000009536743164063))));
     $$0$i3$i$i = $54;
     break;
    }
   } else {
    $49 = Math_fround($47 / Math_fround(12.9200000762939453125));
    $$0$i3$i$i = $49;
   }
  } while(0);
  $55 = (($col) + 8|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = !($56 <= Math_fround(0.0404499992728233337402));
  do {
   if ($57) {
    $59 = $56 < Math_fround(1.0);
    if ($59) {
     $60 = Math_fround($56 + Math_fround(0.054999999701976776123));
     $61 = Math_fround($60 / Math_fround(1.05499994754791259766));
     $62 = (Math_fround(+(Math_pow((+$61),2.40000009536743164063))));
     $$0$i1$i$i = $62;
     break;
    } else {
     $63 = (Math_fround(+(Math_pow((+$56),2.40000009536743164063))));
     $$0$i1$i$i = $63;
     break;
    }
   } else {
    $58 = Math_fround($56 / Math_fround(12.9200000762939453125));
    $$0$i1$i$i = $58;
   }
  } while(0);
  $64 = (($col) + 12|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  HEAPF32[$0>>2] = $$0$i$i$i;
  $66 = (($0) + 4|0);
  HEAPF32[$66>>2] = $$0$i3$i$i;
  $67 = (($0) + 8|0);
  HEAPF32[$67>>2] = $$0$i1$i$i;
  $68 = (($0) + 12|0);
  HEAPF32[$68>>2] = $65;
 } else {
  ;HEAP32[$0+0>>2]=HEAP32[$col+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$col+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$col+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$col+12>>2]|0;
 }
 __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($34,$name,$0);
 $69 = HEAP32[$name>>2]|0;
 HEAP32[$1>>2] = $69;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material15SetColorIndexedEN9ShaderLab16FastPropertyNameEif($this,$name,$index,$value) {
 $this = $this|0;
 $name = $name|0;
 $index = $index|0;
 $value = Math_fround($value);
 var $$0$i = Math_fround(0), $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 100|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$name>>2]|0;
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L3: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $6 = (($$013$i$in$i$i) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)<($5|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L3;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($3|0);
  if (!($14)) {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($5|0)<($16|0);
   if (!($17)) {
    $18 = (($$0$ph5$i$i$i) + 20|0);
    $19 = (($18) + ($index<<2)|0);
    HEAPF32[$19>>2] = $value;
   }
  }
 }
 $20 = (($this) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre$i = HEAP32[$20>>2]|0;
  $24 = $$pre$i;
 } else {
  $24 = $21;
 }
 $23 = (($this) + 36|0);
 HEAP8[$23>>0] = 1;
 $25 = (__ZNK9ShaderLab13PropertySheet11GetColorTagERKNS_16FastPropertyNameE($24,$name)|0);
 if (!($25)) {
  __ZN9ShaderLab13PropertySheet16SetVectorIndexedERKNS_16FastPropertyNameEif($24,$name,$index,$value);
  $35 = HEAP32[$name>>2]|0;
  HEAP32[$0>>2] = $35;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
  STACKTOP = sp;return;
 }
 $26 = (__Z19GetActiveColorSpacev()|0);
 $27 = ($26|0)==(1);
 do {
  if ($27) {
   $28 = !($value <= Math_fround(0.0404499992728233337402));
   if (!($28)) {
    $29 = Math_fround($value / Math_fround(12.9200000762939453125));
    $$0$i = $29;
    break;
   }
   $30 = $value < Math_fround(1.0);
   if ($30) {
    $31 = Math_fround($value + Math_fround(0.054999999701976776123));
    $32 = Math_fround($31 / Math_fround(1.05499994754791259766));
    $33 = (Math_fround(+(Math_pow((+$32),2.40000009536743164063))));
    $$0$i = $33;
    break;
   } else {
    $34 = (Math_fround(+(Math_pow((+$value),2.40000009536743164063))));
    $$0$i = $34;
    break;
   }
  } else {
   $$0$i = $value;
  }
 } while(0);
 __ZN9ShaderLab13PropertySheet16SetVectorIndexedERKNS_16FastPropertyNameEif($24,$name,$index,$$0$i);
 $35 = HEAP32[$name>>2]|0;
 HEAP32[$0>>2] = $35;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material8GetColorEN9ShaderLab16FastPropertyNameE($agg$result,$this,$name) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $name = $name|0;
 var $$$i = 0, $$0$i$i$i = Math_fround(0), $$0$i1$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre = HEAP32[$0>>2]|0;
  $4 = $$pre;
 } else {
  $4 = $1;
 }
 $3 = (($4) + 24|0);
 $5 = HEAP32[$3>>2]|0;
 $6 = (($4) + 24|0);
 $7 = ($5|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$name>>2]|0;
  $$0$ph7$i$i$i$i = $6;$$01$ph6$i$in$i$i$i = $5;
  L6: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $9 = (($$013$i$in$i$i$i) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)<($8|0);
    if (!($11)) {
     break;
    }
    $14 = (($$013$i$in$i$i$i) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L6;
    } else {
     $$013$i$in$i$i$i = $15;
    }
   }
   $12 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $12;
   }
  }
  $17 = ($$0$ph5$i$i$i$i|0)==($6|0);
  if (!($17)) {
   $18 = (($$0$ph5$i$i$i$i) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($8|0)<($19|0);
   $21 = (($$0$ph5$i$i$i$i) + 20|0);
   $$$i = $20 ? 0 : $21;
   if (!($20)) {
    $22 = Math_fround(HEAPF32[$$$i>>2]);
    $23 = (($$$i) + 4|0);
    $24 = Math_fround(HEAPF32[$23>>2]);
    $25 = (($$$i) + 8|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = (($$$i) + 12|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = (__ZNK9ShaderLab13PropertySheet11GetColorTagERKNS_16FastPropertyNameE($4,$name)|0);
    if (!($29)) {
     HEAPF32[$agg$result>>2] = $22;
     $59 = (($agg$result) + 4|0);
     HEAPF32[$59>>2] = $24;
     $60 = (($agg$result) + 8|0);
     HEAPF32[$60>>2] = $26;
     $61 = (($agg$result) + 12|0);
     HEAPF32[$61>>2] = $28;
     STACKTOP = sp;return;
    }
    $30 = (__Z19GetActiveColorSpacev()|0);
    $31 = ($30|0)==(1);
    if (!($31)) {
     HEAPF32[$agg$result>>2] = $22;
     $56 = (($agg$result) + 4|0);
     HEAPF32[$56>>2] = $24;
     $57 = (($agg$result) + 8|0);
     HEAPF32[$57>>2] = $26;
     $58 = (($agg$result) + 12|0);
     HEAPF32[$58>>2] = $28;
     STACKTOP = sp;return;
    }
    $32 = !($22 <= Math_fround(0.0));
    do {
     if ($32) {
      $33 = !($22 <= Math_fround(0.0031308000907301902771));
      if (!($33)) {
       $34 = Math_fround($22 * Math_fround(12.9200000762939453125));
       $$0$i$i$i = $34;
       break;
      }
      $35 = !($22 <= Math_fround(1.0));
      $36 = (Math_fround(+(Math_pow((+$22),0.416660010814666748047))));
      if ($35) {
       $$0$i$i$i = $36;
      } else {
       $37 = Math_fround($36 * Math_fround(1.05499994754791259766));
       $38 = Math_fround($37 + Math_fround(-0.054999999701976776123));
       $$0$i$i$i = $38;
      }
     } else {
      $$0$i$i$i = Math_fround(0.0);
     }
    } while(0);
    $39 = !($24 <= Math_fround(0.0));
    do {
     if ($39) {
      $40 = !($24 <= Math_fround(0.0031308000907301902771));
      if (!($40)) {
       $41 = Math_fround($24 * Math_fround(12.9200000762939453125));
       $$0$i3$i$i = $41;
       break;
      }
      $42 = !($24 <= Math_fround(1.0));
      $43 = (Math_fround(+(Math_pow((+$24),0.416660010814666748047))));
      if ($42) {
       $$0$i3$i$i = $43;
      } else {
       $44 = Math_fround($43 * Math_fround(1.05499994754791259766));
       $45 = Math_fround($44 + Math_fround(-0.054999999701976776123));
       $$0$i3$i$i = $45;
      }
     } else {
      $$0$i3$i$i = Math_fround(0.0);
     }
    } while(0);
    $46 = !($26 <= Math_fround(0.0));
    do {
     if ($46) {
      $47 = !($26 <= Math_fround(0.0031308000907301902771));
      if (!($47)) {
       $48 = Math_fround($26 * Math_fround(12.9200000762939453125));
       $$0$i1$i$i = $48;
       break;
      }
      $49 = !($26 <= Math_fround(1.0));
      $50 = (Math_fround(+(Math_pow((+$26),0.416660010814666748047))));
      if ($49) {
       $$0$i1$i$i = $50;
      } else {
       $51 = Math_fround($50 * Math_fround(1.05499994754791259766));
       $52 = Math_fround($51 + Math_fround(-0.054999999701976776123));
       $$0$i1$i$i = $52;
      }
     } else {
      $$0$i1$i$i = Math_fround(0.0);
     }
    } while(0);
    HEAPF32[$agg$result>>2] = $$0$i$i$i;
    $53 = (($agg$result) + 4|0);
    HEAPF32[$53>>2] = $$0$i3$i$i;
    $54 = (($agg$result) + 8|0);
    HEAPF32[$54>>2] = $$0$i1$i$i;
    $55 = (($agg$result) + 12|0);
    HEAPF32[$55>>2] = $28;
    STACKTOP = sp;return;
   }
  }
 }
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5Unity8Material8SetFloatEN9ShaderLab16FastPropertyNameEf($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = Math_fround($val);
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 88|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$name>>2]|0;
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L3: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $6 = (($$013$i$in$i$i) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)<($5|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L3;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($3|0);
  if (!($14)) {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($5|0)<($16|0);
   if (!($17)) {
    $18 = (($$0$ph5$i$i$i) + 20|0);
    HEAPF32[$18>>2] = $val;
   }
  }
 }
 $19 = (($this) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre$i = HEAP32[$19>>2]|0;
  $23 = $$pre$i;
 } else {
  $23 = $20;
 }
 $22 = (($this) + 36|0);
 HEAP8[$22>>0] = 1;
 __ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf($23,$name,$val);
 $24 = HEAP32[$name>>2]|0;
 HEAP32[$0>>2] = $24;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material8GetFloatEN9ShaderLab16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = Math_fround(0), $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre = HEAP32[$0>>2]|0;
  $4 = $$pre;
 } else {
  $4 = $1;
 }
 $3 = (($4) + 12|0);
 $5 = HEAP32[$3>>2]|0;
 $6 = (($4) + 12|0);
 $7 = ($5|0)==(0|0);
 if ($7) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $8 = HEAP32[$name>>2]|0;
 $$0$ph7$i$i$i$i = $6;$$01$ph6$i$in$i$i$i = $5;
 L7: while(1) {
  $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
  while(1) {
   $9 = (($$013$i$in$i$i$i) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)<($8|0);
   if (!($11)) {
    break;
   }
   $14 = (($$013$i$in$i$i$i) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
    break L7;
   } else {
    $$013$i$in$i$i$i = $15;
   }
  }
  $12 = HEAP32[$$013$i$in$i$i$i>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
   break;
  } else {
   $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $12;
  }
 }
 $17 = ($$0$ph5$i$i$i$i|0)==($6|0);
 if ($17) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $18 = (($$0$ph5$i$i$i$i) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($8|0)<($19|0);
 if ($20) {
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $21 = (($$0$ph5$i$i$i$i) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $$0 = $22;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre = HEAP32[$0>>2]|0;
  $3 = $$pre;
 } else {
  $3 = $1;
 }
 $4 = (__ZNK9ShaderLab13PropertySheet11HasPropertyERKNS_16FastPropertyNameE($3,$name)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN5Unity8Material9SetMatrixEN9ShaderLab16FastPropertyNameERK10Matrix4x4f($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = $val|0;
 var $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre$i = HEAP32[$1>>2]|0;
  $5 = $$pre$i;
 } else {
  $5 = $2;
 }
 $4 = (($this) + 36|0);
 HEAP8[$4>>0] = 1;
 __ZN9ShaderLab13PropertySheet9SetMatrixERKNS_16FastPropertyNameERK10Matrix4x4f($5,$name,$val);
 $6 = HEAP32[$name>>2]|0;
 HEAP32[$0>>2] = $6;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = $val|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 76|0);
 $6 = ($4|0)==(0|0);
 do {
  if (!($6)) {
   $7 = HEAP32[$name>>2]|0;
   $$0$ph7$i$i$i = $5;$$01$ph6$i$in$i$i = $4;
   L3: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $8 = (($$013$i$in$i$i) + 16|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ($9|0)<($7|0);
     if (!($10)) {
      break;
     }
     $13 = (($$013$i$in$i$i) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L3;
     } else {
      $$013$i$in$i$i = $14;
     }
    }
    $11 = HEAP32[$$013$i$in$i$i>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $11;
    }
   }
   $16 = ($$0$ph5$i$i$i|0)==($5|0);
   if (!($16)) {
    $17 = (($$0$ph5$i$i$i) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($7|0)<($18|0);
    if (!($19)) {
     $20 = (($$0$ph5$i$i$i) + 36|0);
     $21 = ($val|0)==(0|0);
     if ($21) {
      HEAP32[$20>>2] = 0;
      break;
     } else {
      $22 = (($val) + 4|0);
      $23 = HEAP32[$22>>2]|0;
      HEAP32[$20>>2] = $23;
      break;
     }
    }
   }
  }
 } while(0);
 $24 = (($this) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  $103 = HEAP32[$name>>2]|0;
  HEAP32[$2>>2] = $103;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $25;
 $27 = HEAP32[560624>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  label = 21;
 } else {
  $29 = (($27) + 36|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($27) + 4|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($30|0)==($32|0);
  do {
   if ($33) {
    $34 = (($27) + 28|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($27) + 32|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($35) + ($37<<3)|0);
    $54 = $38;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$27,$0);
    $39 = HEAP32[$$byval_copy>>2]|0;
    $40 = ($39|0)==(-1);
    $41 = (($27) + 28|0);
    $42 = HEAP32[$41>>2]|0;
    if ($40) {
     $43 = (($27) + 32|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + ($44<<3)|0);
     $54 = $45;
     break;
    } else {
     $46 = (($42) + ($39<<3)|0);
     $54 = $46;
     break;
    }
   }
  } while(0);
  $47 = HEAP32[560624>>2]|0;
  $48 = (($47) + 28|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($47) + 32|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + ($51<<3)|0);
  $53 = ($54|0)==($52|0);
  if ($53) {
   label = 21;
  } else {
   $55 = (($54) + 4|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==(0|0);
   if ($57) {
    label = 21;
   }
  }
 }
 if ((label|0) == 21) {
  $58 = HEAP32[$24>>2]|0;
  $59 = (__Z31ReadObjectFromPersistentManageri($58)|0);
  $60 = ($59|0)==(0|0);
  if ($60) {
   $103 = HEAP32[$name>>2]|0;
   HEAP32[$2>>2] = $103;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
   STACKTOP = sp;return;
  }
 }
 $61 = HEAP32[$24>>2]|0;
 HEAP32[$1>>2] = $61;
 $62 = HEAP32[560624>>2]|0;
 $63 = ($62|0)==(0|0);
 if ($63) {
  label = 30;
 } else {
  $64 = (($62) + 36|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($62) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($65|0)==($67|0);
  do {
   if ($68) {
    $69 = (($62) + 28|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($62) + 32|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + ($72<<3)|0);
    $89 = $73;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$62,$1);
    $74 = HEAP32[$$byval_copy>>2]|0;
    $75 = ($74|0)==(-1);
    $76 = (($62) + 28|0);
    $77 = HEAP32[$76>>2]|0;
    if ($75) {
     $78 = (($62) + 32|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($77) + ($79<<3)|0);
     $89 = $80;
     break;
    } else {
     $81 = (($77) + ($74<<3)|0);
     $89 = $81;
     break;
    }
   }
  } while(0);
  $82 = HEAP32[560624>>2]|0;
  $83 = (($82) + 28|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($82) + 32|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (($84) + ($86<<3)|0);
  $88 = ($89|0)==($87|0);
  if ($88) {
   label = 30;
  } else {
   $90 = (($89) + 4|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)==(0|0);
   if ($92) {
    label = 30;
   } else {
    $temp$0$i = $91;
   }
  }
 }
 if ((label|0) == 30) {
  $93 = HEAP32[$24>>2]|0;
  $94 = (__Z31ReadObjectFromPersistentManageri($93)|0);
  $temp$0$i = $94;
 }
 $95 = (($temp$0$i) + 52|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96|0)==(0|0);
 if ($97) {
  $103 = HEAP32[$name>>2]|0;
  HEAP32[$2>>2] = $103;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
  STACKTOP = sp;return;
 }
 $98 = (($this) + 32|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($99|0)==(0|0);
 if ($100) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre$i = HEAP32[$98>>2]|0;
  $102 = $$pre$i;
 } else {
  $102 = $99;
 }
 $101 = (($this) + 36|0);
 HEAP8[$101>>0] = 1;
 (__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($102,$name,$val)|0);
 $103 = HEAP32[$name>>2]|0;
 HEAP32[$2>>2] = $103;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material10GetTextureEN9ShaderLab16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
 }
 $4 = (($this) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 76|0);
 $7 = ($5|0)==(0|0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP32[$name>>2]|0;
 $$0$ph7$i$i$i = $6;$$01$ph6$i$in$i$i = $5;
 L7: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $9 = (($$013$i$in$i$i) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)<($8|0);
   if (!($11)) {
    break;
   }
   $14 = (($$013$i$in$i$i) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L7;
   } else {
    $$013$i$in$i$i = $15;
   }
  }
  $12 = HEAP32[$$013$i$in$i$i>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $12;
  }
 }
 $17 = ($$0$ph5$i$i$i|0)==($6|0);
 if ($17) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($$0$ph5$i$i$i) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($8|0)<($19|0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($$0$ph5$i$i$i) + 36|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $22;
 $24 = HEAP32[560624>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  label = 20;
 } else {
  $26 = (($24) + 36|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($24) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($27|0)==($29|0);
  do {
   if ($30) {
    $31 = (($24) + 28|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($24) + 32|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($32) + ($34<<3)|0);
    $51 = $35;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$24,$0);
    $36 = HEAP32[$pos$i$i$i$i>>2]|0;
    $37 = ($36|0)==(-1);
    $38 = (($24) + 28|0);
    $39 = HEAP32[$38>>2]|0;
    if ($37) {
     $40 = (($24) + 32|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($39) + ($41<<3)|0);
     $51 = $42;
     break;
    } else {
     $43 = (($39) + ($36<<3)|0);
     $51 = $43;
     break;
    }
   }
  } while(0);
  $44 = HEAP32[560624>>2]|0;
  $45 = (($44) + 28|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($44) + 32|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) + ($48<<3)|0);
  $50 = ($51|0)==($49|0);
  if ($50) {
   label = 20;
  } else {
   $52 = (($51) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(0|0);
   if ($54) {
    label = 20;
   } else {
    $temp$0$i = $53;
   }
  }
 }
 if ((label|0) == 20) {
  $55 = (__Z31ReadObjectFromPersistentManageri($22)|0);
  $temp$0$i = $55;
 }
 $$0 = $temp$0$i;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity8Material16SetTextureOffsetEN9ShaderLab16FastPropertyNameERK8Vector2f($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = $val|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 76|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$name>>2]|0;
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L3: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $6 = (($$013$i$in$i$i) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)<($5|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L3;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($3|0);
  if (!($14)) {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($5|0)<($16|0);
   if (!($17)) {
    $18 = Math_fround(HEAPF32[$val>>2]);
    $19 = (($val) + 4|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = (($$0$ph5$i$i$i) + 28|0);
    HEAPF32[$21>>2] = $18;
    $22 = (($$0$ph5$i$i$i) + 32|0);
    HEAPF32[$22>>2] = $20;
   }
  }
 }
 $23 = (($this) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre$i = HEAP32[$23>>2]|0;
  $30 = $$pre$i;
 } else {
  $30 = $24;
 }
 $26 = (($this) + 36|0);
 HEAP8[$26>>0] = 1;
 $27 = Math_fround(HEAPF32[$val>>2]);
 $28 = (($val) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 __ZN9ShaderLab13PropertySheet16SetTextureOffsetERKNS_16FastPropertyNameEff($30,$name,$27,$29);
 $31 = HEAP32[$name>>2]|0;
 HEAP32[$0>>2] = $31;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material15SetTextureScaleEN9ShaderLab16FastPropertyNameERK8Vector2f($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = $val|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 76|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$name>>2]|0;
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L3: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $6 = (($$013$i$in$i$i) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)<($5|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L3;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($3|0);
  if (!($14)) {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($5|0)<($16|0);
   if (!($17)) {
    $18 = Math_fround(HEAPF32[$val>>2]);
    $19 = (($val) + 4|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = (($$0$ph5$i$i$i) + 20|0);
    HEAPF32[$21>>2] = $18;
    $22 = (($$0$ph5$i$i$i) + 24|0);
    HEAPF32[$22>>2] = $20;
   }
  }
 }
 $23 = (($this) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre$i = HEAP32[$23>>2]|0;
  $30 = $$pre$i;
 } else {
  $30 = $24;
 }
 $26 = (($this) + 36|0);
 HEAP8[$26>>0] = 1;
 $27 = Math_fround(HEAPF32[$val>>2]);
 $28 = (($val) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 __ZN9ShaderLab13PropertySheet15SetTextureScaleERKNS_16FastPropertyNameEff($30,$name,$27,$29);
 $31 = HEAP32[$name>>2]|0;
 HEAP32[$0>>2] = $31;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material31SetTextureScaleAndOffsetIndexedEN9ShaderLab16FastPropertyNameEif($this,$name,$index,$value) {
 $this = $this|0;
 $name = $name|0;
 $index = $index|0;
 $value = Math_fround($value);
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 76|0);
 $4 = ($2|0)==(0|0);
 do {
  if (!($4)) {
   $5 = HEAP32[$name>>2]|0;
   $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
   L3: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $6 = (($$013$i$in$i$i) + 16|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = ($7|0)<($5|0);
     if (!($8)) {
      break;
     }
     $11 = (($$013$i$in$i$i) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L3;
     } else {
      $$013$i$in$i$i = $12;
     }
    }
    $9 = HEAP32[$$013$i$in$i$i>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
    }
   }
   $14 = ($$0$ph5$i$i$i|0)==($3|0);
   if (!($14)) {
    $15 = (($$0$ph5$i$i$i) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($5|0)<($16|0);
    if (!($17)) {
     $18 = ($index|0)<(2);
     if ($18) {
      $19 = (($$0$ph5$i$i$i) + 20|0);
      $20 = (($19) + ($index<<2)|0);
      HEAPF32[$20>>2] = $value;
      break;
     } else {
      $21 = (($index) + -2)|0;
      $22 = (($$0$ph5$i$i$i) + 28|0);
      $23 = (($22) + ($21<<2)|0);
      HEAPF32[$23>>2] = $value;
      break;
     }
    }
   }
  }
 } while(0);
 $24 = (($this) + 32|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  __ZN5Unity8Material15BuildPropertiesEv($this);
  $$pre$i = HEAP32[$24>>2]|0;
  $28 = $$pre$i;
 } else {
  $28 = $25;
 }
 $27 = (($this) + 36|0);
 HEAP8[$27>>0] = 1;
 __ZN9ShaderLab13PropertySheet31SetTextureScaleAndOffsetIndexedERKNS_16FastPropertyNameEif($28,$name,$index,$value);
 $29 = HEAP32[$name>>2]|0;
 HEAP32[$0>>2] = $29;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity8Material28UpdateHashesOnPropertyChangeEN9ShaderLab16FastPropertyNameE($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material26CopyPropertiesFromMaterialERS0_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$byval_copy2 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 72|0);
 $3 = (($other) + 72|0);
 (__ZN18UnityPropertySheetaSERKS_($2,$3)|0);
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[628272>>2]|0;
  $8 = (($5) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + -1)|0;
  HEAP32[$8>>2] = $10;
  $11 = HEAP32[$8>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $13 = HEAP32[$5>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   FUNCTION_TABLE_vi[$14 & 4095]($5);
   HEAP32[$0>>2] = $7;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy2);
  }
  HEAP32[$4>>2] = 0;
 }
 $15 = HEAP32[628272>>2]|0;
 HEAP32[$1>>2] = $15;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $16 = (__Znwj10MemLabelIdbiPKci(84,$$byval_copy2,0,16,641280,1050)|0);
 $17 = (($other) + 32|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  __THREW__ = 0;
  invoke_vi(3433,($other|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   $$pre$i = HEAP32[$17>>2]|0;
   $22 = $$pre$i;
   label = 8;
  }
 } else {
  $22 = $18;
  label = 8;
 }
 if ((label|0) == 8) {
  __THREW__ = 0;
  invoke_vii(3238,($16|0),($22|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   HEAP32[$4>>2] = $16;
   $25 = (($16) + 80|0);
   HEAP32[$25>>2] = $this;
   $26 = (($this) + 36|0);
   HEAP8[$26>>0] = 1;
   $27 = (($this) + 28|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==(0);
   if (!($29)) {
    HEAP32[$0>>2] = $28;
    $30 = HEAP32[560624>>2]|0;
    $31 = ($30|0)==(0|0);
    if (!($31)) {
     $32 = (($30) + 36|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($30) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($33|0)==($35|0);
     do {
      if ($36) {
       $37 = (($30) + 28|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = (($30) + 32|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = (($38) + ($40<<3)|0);
       $57 = $41;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$30,$0);
       $42 = HEAP32[$$byval_copy2>>2]|0;
       $43 = ($42|0)==(-1);
       $44 = (($30) + 28|0);
       $45 = HEAP32[$44>>2]|0;
       if ($43) {
        $46 = (($30) + 32|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = (($45) + ($47<<3)|0);
        $57 = $48;
        break;
       } else {
        $49 = (($45) + ($42<<3)|0);
        $57 = $49;
        break;
       }
      }
     } while(0);
     $50 = HEAP32[560624>>2]|0;
     $51 = (($50) + 28|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (($50) + 32|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + ($54<<3)|0);
     $56 = ($57|0)==($55|0);
     if (!($56)) {
      $58 = (($57) + 4|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($59|0)==(0|0);
      if (!($60)) {
       __ZN5Unity8Material12UpdateHashesEv($this);
       STACKTOP = sp;return;
      }
     }
    }
    $61 = HEAP32[$27>>2]|0;
    $62 = (__Z31ReadObjectFromPersistentManageri($61)|0);
    $63 = ($62|0)==(0|0);
    if (!($63)) {
     __ZN5Unity8Material12UpdateHashesEv($this);
     STACKTOP = sp;return;
    }
   }
   (__ZN6Shader10GetDefaultEv()|0);
   __ZN5Unity8Material12UpdateHashesEv($this);
   STACKTOP = sp;return;
  }
 }
 $64 = ___cxa_find_matching_catch()|0;
 $65 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($16|0),($$byval_copy2|0),0,16,(641280|0),1050);
 $66 = __THREW__; __THREW__ = 0;
 $67 = $66&1;
 if ($67) {
  $68 = ___cxa_find_matching_catch(0|0)|0;
  $69 = tempRet0;
  ___clang_call_terminate($68);
  // unreachable;
 } else {
  ___resumeException($64|0);
  // unreachable;
 }
}
function __ZNK5Unity8Material20GetRuntimeMemorySizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6Object20GetRuntimeMemorySizeEv($this)|0);
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $size$0 = $0;
  STACKTOP = sp;return ($size$0|0);
 }
 $4 = (__ZNK9ShaderLab13PropertySheet14GetMemoryUsageEv($2)|0);
 $5 = (($4) + ($0))|0;
 $size$0 = $5;
 STACKTOP = sp;return ($size$0|0);
}
function __ZN5Unity8Material29ResetAllMaterialsCachedPassesEv() {
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 L1: while(1) {
  $$pr = HEAP32[((641504 + 4|0))>>2]|0;
  $1 = $$pr;
  while(1) {
   $0 = ($1|0)==(641504|0);
   if ($0) {
    break L1;
   }
   $2 = (($1) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   __ZN5Unity8Material22InvalidateDisplayListsEv($3);
   $4 = HEAP32[((641504 + 4|0))>>2]|0;
   $5 = ($4|0)==(641504|0);
   if ($5) {
    $1 = 641504;
   } else {
    break;
   }
  }
  $6 = HEAP32[$4>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   continue;
  }
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 4|0);
  HEAP32[$10>>2] = $9;
  $11 = HEAP32[$4>>2]|0;
  $12 = HEAP32[$8>>2]|0;
  HEAP32[$12>>2] = $11;
  HEAP32[$4>>2] = 0;
  HEAP32[$8>>2] = 0;
 }
 STACKTOP = sp;return;
}
function __ZN5Unity8Material13EnableKeywordERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($this,$keyStr) {
 $this = $this|0;
 $keyStr = $keyStr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$keyStr>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($keyStr) + 1|0);
  $6 = $5;
 } else {
  $3 = (($keyStr) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 $7 = (__ZN8keywords6CreateEPKc($6)|0);
 $8 = $7 >>> 5;
 $9 = ((($this) + ($8<<2)|0) + 120|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $7 & 31;
 $12 = 1 << $11;
 $13 = $12 & $10;
 $14 = ($13|0)==(0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 120|0);
 $16 = $12 | $10;
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 108|0);
 __ZN8keywords18KeywordSetToStringERK16ShaderKeywordSetR8UnityStr($15,$17);
 __ZN5Unity8Material12UpdateHashesEv($this);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material14DisableKeywordERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($this,$keyStr) {
 $this = $this|0;
 $keyStr = $keyStr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$keyStr>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($keyStr) + 1|0);
  $6 = $5;
 } else {
  $3 = (($keyStr) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 $7 = (__ZN8keywords6CreateEPKc($6)|0);
 $8 = $7 >>> 5;
 $9 = ((($this) + ($8<<2)|0) + 120|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $7 & 31;
 $12 = 1 << $11;
 $13 = $12 & $10;
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 120|0);
 $16 = $12 ^ -1;
 $17 = $10 & $16;
 HEAP32[$9>>2] = $17;
 $18 = (($this) + 108|0);
 __ZN8keywords18KeywordSetToStringERK16ShaderKeywordSetR8UnityStr($15,$18);
 __ZN5Unity8Material12UpdateHashesEv($this);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material17SetShaderKeywordsERK8UnityStr($this,$keywords) {
 $this = $this|0;
 $keywords = $keywords|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $i$01$i$i$i = 0, $keywordsSet = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $keywordsSet = sp;
 ;HEAP32[$keywordsSet+0>>2]=0|0;HEAP32[$keywordsSet+4>>2]=0|0;HEAP32[$keywordsSet+8>>2]=0|0;HEAP32[$keywordsSet+12>>2]=0|0;
 __ZN8keywords18StringToKeywordSetERK8UnityStrR16ShaderKeywordSet($keywords,$keywordsSet);
 $0 = (($this) + 120|0);
 $i$01$i$i$i = 0;
 while(1) {
  $3 = ((($this) + ($i$01$i$i$i<<2)|0) + 120|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($keywordsSet) + ($i$01$i$i$i<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  $2 = (($i$01$i$i$i) + 1)|0;
  if (!($7)) {
   break;
  }
  $1 = ($2|0)<(4);
  if ($1) {
   $i$01$i$i$i = $2;
  } else {
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$0+0>>2]=HEAP32[$keywordsSet+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$keywordsSet+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$keywordsSet+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$keywordsSet+12>>2]|0;
 $8 = (($this) + 108|0);
 __ZN8keywords18KeywordSetToStringERK16ShaderKeywordSetR8UnityStr($0,$8);
 __ZN5Unity8Material12UpdateHashesEv($this);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material20SetCustomRenderQueueEi($this,$q) {
 $this = $this|0;
 $q = $q|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($q|0);
 if (!($2)) {
  HEAP32[$0>>2] = $q;
 }
 STACKTOP = sp;return;
}
function __Z22RegisterClass_Materialv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(21,183,0,0,0);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 HEAP8[$0>>0] = 16;
 $3 = (($0) + 1|0);
 $4 = $3;
 $5 = $4;
 HEAP8[$5>>0]=1702125901&255;HEAP8[$5+1>>0]=(1702125901>>8)&255;HEAP8[$5+2>>0]=(1702125901>>16)&255;HEAP8[$5+3>>0]=1702125901>>24;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP8[$7>>0]=1818323314&255;HEAP8[$7+1>>0]=(1818323314>>8)&255;HEAP8[$7+2>>0]=(1818323314>>16)&255;HEAP8[$7+3>>0]=1818323314>>24;
 $8 = (($0) + 9|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,21,130,($0|0),144,(2525|0),0,0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return;
 }
}
function __ZN5Unity8Material7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(144,$$byval_copy2,1,16,641280,36)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1685,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((641176 + 8|0));
  $6 = (($3) + 28|0);
  $7 = (($3) + 40|0);
  $8 = (($3) + 60|0);
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;
  HEAP32[$8>>2] = $3;
  $9 = (($3) + 68|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 76|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 80|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 72|0);
  HEAP32[$12>>2] = $10;
  $13 = (($3) + 88|0);
  HEAP32[$13>>2] = 0;
  $14 = (($3) + 92|0);
  HEAP32[$14>>2] = 0;
  $15 = (($3) + 84|0);
  HEAP32[$15>>2] = $13;
  $16 = (($3) + 100|0);
  HEAP32[$16>>2] = 0;
  $17 = (($3) + 104|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 96|0);
  HEAP32[$18>>2] = $16;
  $19 = (($3) + 108|0);
  $20 = (($3) + 32|0);
  HEAP32[$20>>2] = 0;
  $21 = (($3) + 36|0);
  HEAP8[$21>>0] = 0;
  HEAP32[$6>>2] = 0;
  $22 = (($3) + 64|0);
  ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;HEAP32[$19+16>>2]=0|0;HEAP32[$19+20>>2]=0|0;HEAP32[$19+24>>2]=0|0;
  HEAP32[$22>>2] = -1;
  $23 = (($3) + 136|0);
  HEAP32[$23>>2] = 0;
  $24 = (($3) + 140|0);
  HEAP32[$24>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(641280|0),36);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch(0|0)|0;
  $30 = tempRet0;
  ___clang_call_terminate($29);
  // unreachable;
 } else {
  ___resumeException($25|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK5Unity8Material25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 21;
}
function __ZN5Unity8Material23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641528,641512,$this,0);
 __ZN5Unity8Material8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641528,641512,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN5Unity8Material8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity8Material8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity8Material8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity8Material8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$us$i$i$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$us$i$i$i$i$i$i$i$i$i = 0, $$01$i$i$i$i$us$i$i$i$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 $12 = (($this) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 76|0);
 $15 = ($13|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $17 = $13;
 while(1) {
  $16 = (($17) + 36|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = HEAP32[$2>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$6>>2]|0;
  $23 = (FUNCTION_TABLE_iiii[$21 & 2047]($19,$18,$22)|0);
  $24 = HEAP8[$9>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if (!($25)) {
   HEAP32[$16>>2] = $23;
  }
  $26 = (($17) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   $$01$i$i$i$i$us$i$i$i$i$i$i$i$i$i = $17;
   while(1) {
    $31 = (($$01$i$i$i$i$us$i$i$i$i$i$i$i$i$i) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==($$01$i$i$i$i$us$i$i$i$i$i$i$i$i$i|0);
    if ($34) {
     $$0$i$i$i$i$us$i$i$i$i$i$i$i$i$i = $32;
     break;
    } else {
     $$01$i$i$i$i$us$i$i$i$i$i$i$i$i$i = $32;
    }
   }
  } else {
   $$0$i$i$i$i$i$us$i$i$i$i$i$i$i$i$i = $27;
   while(1) {
    $29 = HEAP32[$$0$i$i$i$i$i$us$i$i$i$i$i$i$i$i$i>>2]|0;
    $30 = ($29|0)==(0|0);
    if ($30) {
     $$0$i$i$i$i$us$i$i$i$i$i$i$i$i$i = $$0$i$i$i$i$i$us$i$i$i$i$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i$us$i$i$i$i$i$i$i$i$i = $29;
    }
   }
  }
  $35 = ($$0$i$i$i$i$us$i$i$i$i$i$i$i$i$i|0)==($14|0);
  if ($35) {
   break;
  } else {
   $17 = $$0$i$i$i$i$us$i$i$i$i$i$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5Unity8Material8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i3 = 0, $size$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $size$i$i$i2 = sp;
 $p$i$i$i3 = sp + 16|0;
 __ZN13ProxyTransfer10SetVersionEi($transfer,4);
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641536,641888,$0,0);
 $1 = (($size$i$i$i2) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$size$i$i$i2>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641768,$6,$0,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641784,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 108|0);
 $19 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641552,$19,$18,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,641800,641800,$size$i$i$i2,1);
 $20 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641624,$20,$p$i$i$i3,0);
 $21 = HEAP32[$7>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$10>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $25 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641576,$6,$25,0);
 $26 = HEAP32[$7>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$10>>2]|0;
 $29 = ((($27) + (($28*24)|0)|0) + 12|0);
 HEAP32[$29>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $30 = (($this) + 72|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641600,641808,$30,0);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $31 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641632,$31,$30,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,641800,641800,$size$i$i$i2,0);
 HEAP32[$p$i$i$i3>>2] = -1;
 $32 = (($p$i$i$i3) + 4|0);
 __ZN18UnityPropertySheet11UnityTexEnvC2Ev($32);
 $33 = HEAP32[580608>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641624,$33,$p$i$i$i3,0);
 $34 = HEAP32[580576>>2]|0;
 __ZN13ProxyTransfer8TransferIN9ShaderLab16FastPropertyNameEEEvRT_PKc17TransferMetaFlags($transfer,$p$i$i$i3,$34,0);
 $35 = HEAP32[580656>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$35,641856,$32,0);
 __ZN15SerializeTraitsIN18UnityPropertySheet11UnityTexEnvEE8TransferI13ProxyTransferEEvRS1_RT_($32,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $36 = (($this) + 84|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641648,$31,$36,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,641800,641800,$size$i$i$i2,0);
 HEAP32[$p$i$i$i3>>2] = -1;
 $37 = (($p$i$i$i3) + 4|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641624,$33,$p$i$i$i3,0);
 __ZN13ProxyTransfer8TransferIN9ShaderLab16FastPropertyNameEEEvRT_PKc17TransferMetaFlags($transfer,$p$i$i$i3,$34,0);
 $38 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$35,$38,$37,0);
 $39 = HEAP32[$7>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$10>>2]|0;
 $42 = ((($40) + (($41*24)|0)|0) + 12|0);
 HEAP32[$42>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $43 = (($this) + 96|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641664,$31,$43,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,641800,641800,$size$i$i$i2,0);
 HEAP32[$p$i$i$i3>>2] = -1;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641624,$33,$p$i$i$i3,0);
 __ZN13ProxyTransfer8TransferIN9ShaderLab16FastPropertyNameEEEvRT_PKc17TransferMetaFlags($transfer,$p$i$i$i3,$34,0);
 $44 = (($p$i$i$i3) + 4|0);
 $45 = HEAP32[580560>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$35,$45,$44,0);
 __ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_($44,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i5 = 0, $$pre$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $8 = 0, $9 = 0, $converter$i$i11 = 0, $shaderKeywords$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $converter$i$i11 = sp;
 $0 = sp + 4|0;
 $shaderKeywords$i = sp + 8|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,4);
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $1 = (($this) + 28|0);
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641536,641888,$$byval_copy1,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN4PPtrI6ShaderE8TransferI14SafeBinaryReadEEvRT_($1,$transfer);
  } else {
   $5 = HEAP32[$$byval_copy1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 108|0);
 $8 = HEAP32[580712>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641552,$8,$$byval_copy1,0)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = ($9|0)>(0);
  if ($11) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$7,0);
  } else {
   $12 = HEAP32[$$byval_copy1>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    (FUNCTION_TABLE_iii[$12 & 4095]($7,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $14 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$14,641576,0);
 $15 = (($this) + 72|0);
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641600,641808,$$byval_copy1,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  if ($18) {
   __ZN18UnityPropertySheet8TransferI14SafeBinaryReadEEvRT_($15,$transfer);
  } else {
   $19 = HEAP32[$$byval_copy1>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($15,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,3)|0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 HEAP32[$shaderKeywords$i>>2] = 0;
 $22 = (($shaderKeywords$i) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = (($shaderKeywords$i) + 8|0);
 HEAP32[$23>>2] = 0;
 $24 = HEAP32[580760>>2]|0;
 __THREW__ = 0;
 $25 = (invoke_iiiiii(192,($transfer|0),(641552|0),($24|0),($converter$i$i11|0),1)|0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 do {
  if (!($27)) {
   $28 = ($25|0)==(0);
   if (!($28)) {
    $29 = ($25|0)>(0);
    if ($29) {
     __THREW__ = 0;
     invoke_viii(1651,($transfer|0),($shaderKeywords$i|0),0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
    } else {
     $32 = HEAP32[$converter$i$i11>>2]|0;
     $33 = ($32|0)==(0|0);
     if (!($33)) {
      __THREW__ = 0;
      (invoke_iii($32|0,($shaderKeywords$i|0),($transfer|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
     }
    }
    __THREW__ = 0;
    invoke_vi(3389,($transfer|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_vii(3239,($shaderKeywords$i|0),($7|0));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    $40 = HEAP32[$shaderKeywords$i>>2]|0;
    $41 = ($40|0)==(0|0);
    if ($41) {
     STACKTOP = sp;return;
    }
    $42 = HEAP32[$22>>2]|0;
    $43 = ($42|0)==($40|0);
    do {
     if ($43) {
      $57 = $40;
     } else {
      $45 = $42;
      while(1) {
       $44 = (($45) + -12|0);
       HEAP32[$22>>2] = $44;
       $46 = HEAP8[$44>>0]|0;
       $47 = $46 & 1;
       $48 = ($47<<24>>24)==(0);
       if ($48) {
        $50 = $44;
       } else {
        $51 = (($45) + -4|0);
        $52 = HEAP32[$51>>2]|0;
        HEAP32[$converter$i$i11>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$converter$i$i11+0>>2]|0;
        invoke_vii(2591,($52|0),($$byval_copy1|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 35;
         break;
        }
        $$pre$i$i$i$i$i = HEAP32[$22>>2]|0;
        $50 = $$pre$i$i$i$i$i;
       }
       $49 = ($50|0)==($40|0);
       if ($49) {
        label = 36;
        break;
       } else {
        $45 = $50;
       }
      }
      if ((label|0) == 35) {
       $55 = ___cxa_find_matching_catch()|0;
       $56 = tempRet0;
       ___cxa_call_unexpected(($55|0));
       // unreachable;
      }
      else if ((label|0) == 36) {
       $$pre$i$i$i = HEAP32[$shaderKeywords$i>>2]|0;
       $57 = $$pre$i$i$i;
       break;
      }
     }
    } while(0);
    __ZdlPv($57);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $58 = ___cxa_find_matching_catch()|0;
 $59 = tempRet0;
 $60 = HEAP32[$shaderKeywords$i>>2]|0;
 $61 = ($60|0)==(0|0);
 if ($61) {
  ___resumeException($58|0);
  // unreachable;
 }
 $62 = HEAP32[$22>>2]|0;
 $63 = ($62|0)==($60|0);
 do {
  if ($63) {
   $77 = $60;
  } else {
   $65 = $62;
   while(1) {
    $64 = (($65) + -12|0);
    HEAP32[$22>>2] = $64;
    $66 = HEAP8[$64>>0]|0;
    $67 = $66 & 1;
    $68 = ($67<<24>>24)==(0);
    if ($68) {
     $70 = $64;
    } else {
     $71 = (($65) + -4|0);
     $72 = HEAP32[$71>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($72|0),($$byval_copy1|0));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      label = 45;
      break;
     }
     $$pre$i$i$i$i$i5 = HEAP32[$22>>2]|0;
     $70 = $$pre$i$i$i$i$i5;
    }
    $69 = ($70|0)==($60|0);
    if ($69) {
     label = 46;
     break;
    } else {
     $65 = $70;
    }
   }
   if ((label|0) == 45) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    ___cxa_call_unexpected(($75|0));
    // unreachable;
   }
   else if ((label|0) == 46) {
    $$pre$i$i$i7 = HEAP32[$shaderKeywords$i>>2]|0;
    $77 = $$pre$i$i$i7;
    break;
   }
  }
 } while(0);
 __ZdlPv($77);
 ___resumeException($58|0);
 // unreachable;
}
function __ZN5Unity8Material8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 108|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $2 = (($this) + 64|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
 }
 $10 = (($this) + 72|0);
 __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$10,0);
 $11 = (($this) + 84|0);
 __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_fEEEEEEEEvRT_17TransferMetaFlags($transfer,$11,0);
 $12 = (($this) + 96|0);
 __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($transfer,$12,0);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($this) + 108|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $2 = (($this) + 64|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $10 = $$pre$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$2>>2] = $11;
 $12 = (($this) + 72|0);
 __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$12,0);
 $13 = (($this) + 84|0);
 __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_fEEEEEEEEvRT_17TransferMetaFlags($transfer,$13,0);
 $14 = (($this) + 96|0);
 __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($transfer,$14,0);
 STACKTOP = sp;return;
}
function __ZN5Unity8Material8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN4PPtrI6ShaderE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 108|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $2 = (($this) + 64|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = HEAP32[$2>>2]|0;
  HEAP32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = (($this) + 72|0);
  __ZN18UnityPropertySheet8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
  $10 = (($this) + 72|0);
  __ZN18UnityPropertySheet8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN5Unity8Material8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$us$i$i$i$i$i$i = 0, $$0$i$i$i$i$us$i$i$i$i$i$i = 0, $$01$i$i$i$i$us$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 $12 = (($this) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 76|0);
 $15 = ($13|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $17 = $13;
 while(1) {
  $16 = (($17) + 36|0);
  $18 = HEAP32[$16>>2]|0;
  $19 = HEAP32[$2>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$6>>2]|0;
  $23 = (FUNCTION_TABLE_iiii[$21 & 2047]($19,$18,$22)|0);
  $24 = HEAP8[$9>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if (!($25)) {
   HEAP32[$16>>2] = $23;
  }
  $26 = (($17) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   $$01$i$i$i$i$us$i$i$i$i$i$i = $17;
   while(1) {
    $31 = (($$01$i$i$i$i$us$i$i$i$i$i$i) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==($$01$i$i$i$i$us$i$i$i$i$i$i|0);
    if ($34) {
     $$0$i$i$i$i$us$i$i$i$i$i$i = $32;
     break;
    } else {
     $$01$i$i$i$i$us$i$i$i$i$i$i = $32;
    }
   }
  } else {
   $$0$i$i$i$i$i$us$i$i$i$i$i$i = $27;
   while(1) {
    $29 = HEAP32[$$0$i$i$i$i$i$us$i$i$i$i$i$i>>2]|0;
    $30 = ($29|0)==(0|0);
    if ($30) {
     $$0$i$i$i$i$us$i$i$i$i$i$i = $$0$i$i$i$i$i$us$i$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i$us$i$i$i$i$i$i = $29;
    }
   }
  }
  $35 = ($$0$i$i$i$i$us$i$i$i$i$i$i|0)==($14|0);
  if ($35) {
   break;
  } else {
   $17 = $$0$i$i$i$i$us$i$i$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18UnityPropertySheet8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$01$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$this,0);
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i,4);
 }
 $8 = (($this) + 16|0);
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($8|0);
 if ($11) {
  $24 = (($this) + 24|0);
  __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($transfer,$24,0);
  STACKTOP = sp;return;
 }
 $13 = $10;
 while(1) {
  $12 = (($13) + 16|0);
  __ZN19StreamedBinaryWriteILb0EE8TransferINSt3__14pairIN9ShaderLab16FastPropertyNameEfEEEEvRT_PKc17TransferMetaFlags($transfer,$12,0,0);
  $14 = (($13) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$01$i$i$i$i$i$i = $13;
   while(1) {
    $19 = (($$01$i$i$i$i$i$i) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($$01$i$i$i$i$i$i|0);
    if ($22) {
     $$0$i$i$i$i$i$i = $20;
     break;
    } else {
     $$01$i$i$i$i$i$i = $20;
    }
   }
  } else {
   $$0$i$i$i$i$i$i$i = $15;
   while(1) {
    $17 = HEAP32[$$0$i$i$i$i$i$i$i>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$0$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i$i$i = $17;
    }
   }
  }
  $23 = ($$0$i$i$i$i$i$i|0)==($8|0);
  if ($23) {
   break;
  } else {
   $13 = $$0$i$i$i$i$i$i;
  }
 }
 $24 = (($this) + 24|0);
 __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($transfer,$24,0);
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$byval_copy1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $name$i$i$i$i$i = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $1 = sp;
 $2 = sp + 4|0;
 $name$i$i$i$i$i = sp + 8|0;
 $size = sp + 20|0;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)<($9>>>0);
 if ($10) {
  HEAP32[$6>>2] = $4;
  HEAP32[$5>>2] = $7;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($5,$size,4);
 }
 $11 = (($data) + 4|0);
 $12 = HEAP32[$data>>2]|0;
 $13 = ($12|0)==($11|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($name$i$i$i$i$i) + 8|0);
 $16 = $12;
 while(1) {
  $15 = (($16) + 16|0);
  ;HEAP32[$name$i$i$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i$i$i+8>>2]=0|0;
  __THREW__ = 0;
  $17 = (invoke_ii(3309,($15|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  (invoke_iii(2353,($name$i$i$i$i$i|0),($17|0))|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  invoke_viii(1624,($this|0),($name$i$i$i$i$i|0),0);
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3378,($this|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 8;
   break;
  }
  $36 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  if (!($38)) {
   $39 = HEAP32[$14>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($39|0),($$byval_copy1|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    label = 15;
    break;
   }
  }
  $44 = (($16) + 20|0);
  __ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($44,$this);
  $45 = (($16) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if ($47) {
   $$01$i$i$i = $16;
   while(1) {
    $50 = (($$01$i$i$i) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==($$01$i$i$i|0);
    if ($53) {
     $$0$i$i$i = $51;
     break;
    } else {
     $$01$i$i$i = $51;
    }
   }
  } else {
   $$0$i$i$i$i = $46;
   while(1) {
    $48 = HEAP32[$$0$i$i$i$i>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $48;
    }
   }
  }
  $54 = ($$0$i$i$i|0)==($11|0);
  if ($54) {
   label = 22;
   break;
  } else {
   $16 = $$0$i$i$i;
  }
 }
 if ((label|0) == 8) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $24 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   ___resumeException($22|0);
   // unreachable;
  }
  $27 = HEAP32[$14>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($27|0),($$byval_copy1|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   ___cxa_call_unexpected(($30|0));
   // unreachable;
  } else {
   ___resumeException($22|0);
   // unreachable;
  }
 }
 else if ((label|0) == 15) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  ___cxa_call_unexpected(($42|0));
  // unreachable;
 }
 else if ((label|0) == 22) {
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE8TransferINSt3__14pairIN9ShaderLab16FastPropertyNameEfEEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $name$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $2 = sp;
 $name$i$i$i$i = sp + 4|0;
 ;HEAP32[$name$i$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i$i+8>>2]=0|0;
 __THREW__ = 0;
 $3 = (invoke_ii(3309,($data|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  (invoke_iii(2353,($name$i$i$i$i|0),($3|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_viii(1624,($this|0),($name$i$i$i$i|0),0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    invoke_vi(3378,($this|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP8[$name$i$i$i$i>>0]|0;
     $24 = $23 & 1;
     $25 = ($24<<24>>24)==(0);
     if (!($25)) {
      $26 = (($name$i$i$i$i) + 8|0);
      $27 = HEAP32[$26>>2]|0;
      HEAP32[$2>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($27|0),($$byval_copy1|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       $30 = ___cxa_find_matching_catch()|0;
       $31 = tempRet0;
       ___cxa_call_unexpected(($30|0));
       // unreachable;
      }
     }
     $32 = (($data) + 4|0);
     $33 = (($this) + 12|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 4|0);
     $36 = (($this) + 20|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($35>>>0)<($37>>>0);
     if ($38) {
      $39 = Math_fround(HEAPF32[$32>>2]);
      HEAPF32[$34>>2] = $39;
      HEAP32[$33>>2] = $35;
      STACKTOP = sp;return;
     } else {
      __ZN12CachedWriter16UpdateWriteCacheEPKvj($33,$32,4);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $10 = HEAP8[$name$i$i$i$i>>0]|0;
 $11 = $10 & 1;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  ___resumeException($8|0);
  // unreachable;
 }
 $13 = (($name$i$i$i$i) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($14|0),($$byval_copy1|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  ___cxa_call_unexpected(($17|0));
  // unreachable;
 } else {
  ___resumeException($8|0);
  // unreachable;
 }
}
function __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$byval_copy1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $name$i$i$i$i$i = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $1 = sp;
 $2 = sp + 4|0;
 $name$i$i$i$i$i = sp + 8|0;
 $size = sp + 20|0;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)<($9>>>0);
 if ($10) {
  HEAP32[$6>>2] = $4;
  HEAP32[$5>>2] = $7;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($5,$size,4);
 }
 $11 = (($data) + 4|0);
 $12 = HEAP32[$data>>2]|0;
 $13 = ($12|0)==($11|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($name$i$i$i$i$i) + 8|0);
 $16 = $12;
 while(1) {
  $15 = (($16) + 16|0);
  ;HEAP32[$name$i$i$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i$i$i+8>>2]=0|0;
  __THREW__ = 0;
  $17 = (invoke_ii(3309,($15|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  (invoke_iii(2353,($name$i$i$i$i$i|0),($17|0))|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  invoke_viii(1624,($this|0),($name$i$i$i$i$i|0),0);
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3378,($this|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 8;
   break;
  }
  $36 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  if (!($38)) {
   $39 = HEAP32[$14>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($39|0),($$byval_copy1|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    label = 15;
    break;
   }
  }
  $44 = (($16) + 20|0);
  __ZN18UnityPropertySheet11UnityTexEnv8TransferI19StreamedBinaryWriteILb0EEEEvRT_($44,$this);
  $45 = (($16) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if ($47) {
   $$01$i$i$i = $16;
   while(1) {
    $50 = (($$01$i$i$i) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==($$01$i$i$i|0);
    if ($53) {
     $$0$i$i$i = $51;
     break;
    } else {
     $$01$i$i$i = $51;
    }
   }
  } else {
   $$0$i$i$i$i = $46;
   while(1) {
    $48 = HEAP32[$$0$i$i$i$i>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $48;
    }
   }
  }
  $54 = ($$0$i$i$i|0)==($11|0);
  if ($54) {
   label = 22;
   break;
  } else {
   $16 = $$0$i$i$i;
  }
 }
 if ((label|0) == 8) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $24 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   ___resumeException($22|0);
   // unreachable;
  }
  $27 = HEAP32[$14>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($27|0),($$byval_copy1|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   ___cxa_call_unexpected(($30|0));
   // unreachable;
  } else {
   ___resumeException($22|0);
   // unreachable;
  }
 }
 else if ((label|0) == 15) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  ___cxa_call_unexpected(($42|0));
  // unreachable;
 }
 else if ((label|0) == 22) {
  STACKTOP = sp;return;
 }
}
function __ZN18UnityPropertySheet11UnityTexEnv8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre2$i$i$i = 0, $$pre2$i$i$i2 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN4PPtrI7TextureE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$this,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre2$i$i$i = HEAP32[$4>>2]|0;
  $10 = $$pre$i$i$i;$12 = $$pre2$i$i$i;
 }
 $8 = (($this) + 4|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$4>>2]|0;
  $16 = $$pre;$18 = $$pre5;
 }
 $14 = (($this) + 8|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre$i$i$i1 = HEAP32[$1>>2]|0;
  $$pre2$i$i$i2 = HEAP32[$4>>2]|0;
  $22 = $$pre$i$i$i1;$24 = $$pre2$i$i$i2;
 }
 $20 = (($this) + 12|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$22>>2] = $25;
  HEAP32[$1>>2] = $21;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,4);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ = 0, $$byval_copy1 = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $name$i$i$i$i$i = 0, $p = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 64|0;
 $1 = sp;
 $2 = sp + 20|0;
 $name$i$i$i$i$i = sp + 24|0;
 $size = sp + 36|0;
 $p = sp + 40|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $10 = $$pre$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$size>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$size>>2] = $11;
 HEAP32[$p>>2] = -1;
 $12 = (($data) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($data,$13);
 $14 = (($data) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($data) + 4|0);
 HEAP32[$data>>2] = $15;
 HEAP32[$15>>2] = 0;
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16|0)>(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($name$i$i$i$i$i) + 1|0);
 $19 = (($p) + 4|0);
 $20 = (($1) + 4|0);
 $21 = (($name$i$i$i$i$i) + 8|0);
 $i$04 = 0;
 while(1) {
  ;HEAP32[$name$i$i$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i$i$i+8>>2]=0|0;
  __THREW__ = 0;
  invoke_viii(1623,($this|0),($name$i$i$i$i$i|0),0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3377,($this|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 8;
   break;
  }
  $36 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  $39 = HEAP32[$21>>2]|0;
  $$ = $38 ? $18 : $39;
  __THREW__ = 0;
  invoke_vii(2618,($p|0),($$|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   label = 8;
   break;
  }
  $42 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $43 = $42 & 1;
  $44 = ($43<<24>>24)==(0);
  if (!($44)) {
   $45 = HEAP32[$21>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($45|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    label = 14;
    break;
   }
  }
  __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb1EEEEvRT_($19,$this);
  $50 = HEAP32[$p>>2]|0;
  HEAP32[$1>>2] = $50;
  ;HEAP32[$20+0>>2]=HEAP32[$19+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$19+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$19+12>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($$byval_copy1,$data,$1);
  $51 = (($i$04) + 1)|0;
  $52 = HEAP32[$size>>2]|0;
  $53 = ($51|0)<($52|0);
  if ($53) {
   $i$04 = $51;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 8) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $28 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   ___resumeException($26|0);
   // unreachable;
  }
  $31 = HEAP32[$21>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($31|0),($$byval_copy1|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $34 = ___cxa_find_matching_catch()|0;
   $35 = tempRet0;
   ___cxa_call_unexpected(($34|0));
   // unreachable;
  } else {
   ___resumeException($26|0);
   // unreachable;
  }
 }
 else if ((label|0) == 14) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$20 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $30 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(36)|0);
 $17 = (($16) + 16|0);
 ;HEAP32[$17+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$__v+16>>2]|0;
 HEAP32[$16>>2] = 0;
 $18 = (($16) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $16;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $16;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_fEEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $1 = sp + 24|0;
 $2 = sp;
 $size = sp + 8|0;
 $p = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $10 = $$pre$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$size>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$size>>2] = $11;
 HEAP32[$p>>2] = -1;
 $12 = (($p) + 4|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($data) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($data,$14);
 $15 = (($data) + 8|0);
 HEAP32[$15>>2] = 0;
 $16 = (($data) + 4|0);
 HEAP32[$data>>2] = $16;
 HEAP32[$16>>2] = 0;
 $17 = HEAP32[$size>>2]|0;
 $18 = ($17|0)>(0);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $i$03 = 0;
 while(1) {
  __ZN15SerializeTraitsINSt3__14pairIN9ShaderLab16FastPropertyNameEfEEE8TransferI18StreamedBinaryReadILb1EEEEvRS4_RT_($p,$this);
  $19 = HEAP32[$p>>2]|0;
  $20 = Math_fround(HEAPF32[$12>>2]);
  $21 = (HEAPF32[tempDoublePtr>>2]=$20,HEAP32[tempDoublePtr>>2]|0);
  $22 = $2;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $21;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($1,$data,$2);
  $26 = (($i$03) + 1)|0;
  $27 = HEAP32[$size>>2]|0;
  $28 = ($26|0)<($27|0);
  if ($28) {
   $i$03 = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$30 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$30 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$30 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$30 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $40 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $39 = (($agg$result) + 4|0);
  HEAP8[$39>>0] = $40;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(24)|0);
 $17 = (($16) + 16|0);
 $18 = $__v;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $17;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 HEAP32[$16>>2] = 0;
 $28 = (($16) + 4|0);
 HEAP32[$28>>2] = 0;
 $29 = (($16) + 8|0);
 HEAP32[$29>>2] = $30;
 HEAP32[$$0$i>>2] = $16;
 $31 = HEAP32[$this>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $35 = $16;
 } else {
  HEAP32[$this>>2] = $32;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $35 = $$pre$i;
 }
 $34 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($34,$35);
 $36 = (($this) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 $40 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $39 = (($agg$result) + 4|0);
 HEAP8[$39>>0] = $40;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairIN9ShaderLab16FastPropertyNameEfEEE8TransferI18StreamedBinaryReadILb1EEEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $$pre$i$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $name$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $name$i$i$i = sp + 4|0;
 ;HEAP32[$name$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1623,($transfer|0),($name$i$i$i|0),0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3377,($transfer|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $16 = HEAP8[$name$i$i$i>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    $21 = (($name$i$i$i) + 1|0);
    $22 = $21;
   } else {
    $19 = (($name$i$i$i) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $22 = $20;
   }
   __THREW__ = 0;
   invoke_vii(2618,($data|0),($22|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP8[$name$i$i$i>>0]|0;
    $26 = $25 & 1;
    $27 = ($26<<24>>24)==(0);
    if (!($27)) {
     $28 = (($name$i$i$i) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($29|0),($$byval_copy1|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $32 = ___cxa_find_matching_catch()|0;
      $33 = tempRet0;
      ___cxa_call_unexpected(($32|0));
      // unreachable;
     }
    }
    $34 = (($data) + 4|0);
    $35 = (($transfer) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($36) + 4|0);
    $38 = (($transfer) + 20|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($37>>>0)>($39>>>0);
    if ($40) {
     __ZN12CachedReader15UpdateReadCacheEPvj($35,$34,4);
     $$pre$i$i$i = HEAP32[$34>>2]|0;
     $$pre$phi$i$i$iZ2D = $34;$43 = $$pre$i$i$i;
     $44 = (_llvm_bswap_i32(($43|0))|0);
     HEAP32[$$pre$phi$i$i$iZ2D>>2] = $44;
     STACKTOP = sp;return;
    } else {
     $41 = Math_fround(HEAPF32[$36>>2]);
     HEAPF32[$34>>2] = $41;
     HEAP32[$35>>2] = $37;
     $42 = (HEAPF32[tempDoublePtr>>2]=$41,HEAP32[tempDoublePtr>>2]|0);
     $$pre$phi$i$i$iZ2D = $34;$43 = $42;
     $44 = (_llvm_bswap_i32(($43|0))|0);
     HEAP32[$$pre$phi$i$i$iZ2D>>2] = $44;
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $7 = HEAP8[$name$i$i$i>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  ___resumeException($5|0);
  // unreachable;
 }
 $10 = (($name$i$i$i) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($11|0),($$byval_copy1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  ___cxa_call_unexpected(($14|0));
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ = 0, $$byval_copy1 = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0;
 var $name$i$i$i$i$i = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 72|0;
 $1 = sp;
 $2 = sp + 24|0;
 $name$i$i$i$i$i = sp + 28|0;
 $size = sp + 40|0;
 $p = sp + 48|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $10 = $$pre$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$size>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$size>>2] = $11;
 HEAP32[$p>>2] = -1;
 $12 = (($p) + 4|0);
 __ZN18UnityPropertySheet11UnityTexEnvC2Ev($12);
 $13 = (($data) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$14);
 $15 = (($data) + 8|0);
 HEAP32[$15>>2] = 0;
 $16 = (($data) + 4|0);
 HEAP32[$data>>2] = $16;
 HEAP32[$16>>2] = 0;
 $17 = HEAP32[$size>>2]|0;
 $18 = ($17|0)>(0);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $19 = (($name$i$i$i$i$i) + 1|0);
 $20 = (($p) + 20|0);
 $21 = (($1) + 4|0);
 $22 = (($1) + 20|0);
 $23 = (($name$i$i$i$i$i) + 8|0);
 $i$04 = 0;
 while(1) {
  ;HEAP32[$name$i$i$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i$i$i+8>>2]=0|0;
  __THREW__ = 0;
  invoke_viii(1623,($this|0),($name$i$i$i$i$i|0),0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3377,($this|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   label = 8;
   break;
  }
  $38 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  $41 = HEAP32[$23>>2]|0;
  $$ = $40 ? $19 : $41;
  __THREW__ = 0;
  invoke_vii(2618,($p|0),($$|0));
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   label = 8;
   break;
  }
  $44 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $45 = $44 & 1;
  $46 = ($45<<24>>24)==(0);
  if (!($46)) {
   $47 = HEAP32[$23>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($47|0),($$byval_copy1|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    label = 14;
    break;
   }
  }
  __ZN18UnityPropertySheet11UnityTexEnv8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$this);
  $52 = HEAP32[$p>>2]|0;
  $53 = HEAP32[$20>>2]|0;
  ;HEAP32[$21+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$12+12>>2]|0;
  HEAP32[$22>>2] = $53;
  HEAP32[$1>>2] = $52;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_($$byval_copy1,$data,$1);
  $54 = (($i$04) + 1)|0;
  $55 = HEAP32[$size>>2]|0;
  $56 = ($54|0)<($55|0);
  if ($56) {
   $i$04 = $54;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 8) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  $30 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $31 = $30 & 1;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   ___resumeException($28|0);
   // unreachable;
  }
  $33 = HEAP32[$23>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($33|0),($$byval_copy1|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $36 = ___cxa_find_matching_catch()|0;
   $37 = tempRet0;
   ___cxa_call_unexpected(($36|0));
   // unreachable;
  } else {
   ___resumeException($28|0);
   // unreachable;
  }
 }
 else if ((label|0) == 14) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  ___cxa_call_unexpected(($50|0));
  // unreachable;
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0;
 var $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$26 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$26 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$26 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$26 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $36 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $35 = (($agg$result) + 4|0);
  HEAP8[$35>>0] = $36;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(40)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__v>>2]|0;
 $19 = (($16) + 20|0);
 $20 = (($__v) + 4|0);
 ;HEAP32[$19+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$20+12>>2]|0;
 $21 = (($__v) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($16) + 36|0);
 HEAP32[$23>>2] = $22;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $24 = (($16) + 4|0);
 HEAP32[$24>>2] = 0;
 $25 = (($16) + 8|0);
 HEAP32[$25>>2] = $26;
 HEAP32[$$0$i>>2] = $16;
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $31 = $16;
 } else {
  HEAP32[$this>>2] = $28;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $31 = $$pre$i;
 }
 $30 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($30,$31);
 $32 = (($this) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + 1)|0;
 HEAP32[$32>>2] = $34;
 $36 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $35 = (($agg$result) + 4|0);
 HEAP8[$35>>0] = $36;
 STACKTOP = sp;return;
}
function __ZN18UnityPropertySheet11UnityTexEnv8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i10 = 0, $$pre$i$i$i3$i$i$i = 0, $$pre$i$i$i3$i$i$i3 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$i$i$i$i$i11Z2D = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$i4$i$i$i6Z2D = 0, $$pre$phi$i$i$i4$i$i$iZ2D = 0, $$pre13 = 0, $$pre6$i$i$i = 0, $$pre6$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN4PPtrI7TextureE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$this,4);
  $$pre$i$i$i3$i$i$i = HEAP32[$this>>2]|0;
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre6$i$i$i = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i4$i$i$iZ2D = $this;$13 = $$pre$i$i$i;$15 = $$pre6$i$i$i;$9 = $$pre$i$i$i3$i$i$i;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$this>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4$i$i$iZ2D = $this;$13 = $3;$15 = $5;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$$pre$phi$i$i$i4$i$i$iZ2D>>2] = $10;
 $11 = (($this) + 4|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i$i$i$i = HEAP32[$11>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i$i$i$iZ2D = $11;$18 = $$pre$i$i$i$i$i$i;$22 = $$pre;$24 = $$pre13;
 } else {
  $16 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$1>>2] = $12;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i$i$i$iZ2D = $11;$18 = $17;$22 = $12;$24 = $15;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $19;
 $20 = (($this) + 8|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre$i$i$i3$i$i$i3 = HEAP32[$20>>2]|0;
  $$pre$i$i$i4 = HEAP32[$1>>2]|0;
  $$pre6$i$i$i5 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i4$i$i$i6Z2D = $20;$27 = $$pre$i$i$i3$i$i$i3;$31 = $$pre$i$i$i4;$33 = $$pre6$i$i$i5;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $26 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4$i$i$i6Z2D = $20;$27 = $26;$31 = $21;$33 = $24;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$$pre$phi$i$i$i4$i$i$i6Z2D>>2] = $28;
 $29 = (($this) + 12|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$29,4);
  $$pre$i$i$i$i$i$i10 = HEAP32[$29>>2]|0;
  $$pre$phi$i$i$i$i$i$i11Z2D = $29;$36 = $$pre$i$i$i$i$i$i10;
  $37 = (_llvm_bswap_i32(($36|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$i$i11Z2D>>2] = $37;
  STACKTOP = sp;return;
 } else {
  $34 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$29>>2] = $34;
  HEAP32[$1>>2] = $30;
  $35 = (HEAPF32[tempDoublePtr>>2]=$34,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i$i$i$i11Z2D = $29;$36 = $35;
  $37 = (_llvm_bswap_i32(($36|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$i$i11Z2D>>2] = $37;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ = 0, $$byval_copy1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $name$i$i$i$i$i = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 64|0;
 $1 = sp;
 $2 = sp + 20|0;
 $name$i$i$i$i$i = sp + 24|0;
 $size = sp + 36|0;
 $p = sp + 40|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$size>>2] = $9;
  HEAP32[$3>>2] = $5;
 }
 HEAP32[$p>>2] = -1;
 $10 = (($data) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($data,$11);
 $12 = (($data) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = (($data) + 4|0);
 HEAP32[$data>>2] = $13;
 HEAP32[$13>>2] = 0;
 $14 = HEAP32[$size>>2]|0;
 $15 = ($14|0)>(0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = (($name$i$i$i$i$i) + 1|0);
 $17 = (($p) + 4|0);
 $18 = (($1) + 4|0);
 $19 = (($name$i$i$i$i$i) + 8|0);
 $i$04 = 0;
 while(1) {
  ;HEAP32[$name$i$i$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i$i$i+8>>2]=0|0;
  __THREW__ = 0;
  invoke_viii(1622,($this|0),($name$i$i$i$i$i|0),0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3376,($this|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 8;
   break;
  }
  $34 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $35 = $34 & 1;
  $36 = ($35<<24>>24)==(0);
  $37 = HEAP32[$19>>2]|0;
  $$ = $36 ? $16 : $37;
  __THREW__ = 0;
  invoke_vii(2618,($p|0),($$|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   label = 8;
   break;
  }
  $40 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $41 = $40 & 1;
  $42 = ($41<<24>>24)==(0);
  if (!($42)) {
   $43 = HEAP32[$19>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($43|0),($$byval_copy1|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    label = 14;
    break;
   }
  }
  __ZN10ColorRGBAf8TransferI18StreamedBinaryReadILb0EEEEvRT_($17,$this);
  $48 = HEAP32[$p>>2]|0;
  HEAP32[$1>>2] = $48;
  ;HEAP32[$18+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$17+12>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($$byval_copy1,$data,$1);
  $49 = (($i$04) + 1)|0;
  $50 = HEAP32[$size>>2]|0;
  $51 = ($49|0)<($50|0);
  if ($51) {
   $i$04 = $49;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 8) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  $26 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   ___resumeException($24|0);
   // unreachable;
  }
  $29 = HEAP32[$19>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($29|0),($$byval_copy1|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   ___cxa_call_unexpected(($32|0));
   // unreachable;
  } else {
   ___resumeException($24|0);
   // unreachable;
  }
 }
 else if ((label|0) == 14) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEfNS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_fEEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $1 = sp + 24|0;
 $2 = sp;
 $size = sp + 8|0;
 $p = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$size>>2] = $9;
  HEAP32[$3>>2] = $5;
 }
 HEAP32[$p>>2] = -1;
 $10 = (($p) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($data) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($data,$12);
 $13 = (($data) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($data) + 4|0);
 HEAP32[$data>>2] = $14;
 HEAP32[$14>>2] = 0;
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)>(0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $i$03 = 0;
 while(1) {
  __ZN15SerializeTraitsINSt3__14pairIN9ShaderLab16FastPropertyNameEfEEE8TransferI18StreamedBinaryReadILb0EEEEvRS4_RT_($p,$this);
  $17 = HEAP32[$p>>2]|0;
  $18 = Math_fround(HEAPF32[$10>>2]);
  $19 = (HEAPF32[tempDoublePtr>>2]=$18,HEAP32[tempDoublePtr>>2]|0);
  $20 = $2;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($1,$data,$2);
  $24 = (($i$03) + 1)|0;
  $25 = HEAP32[$size>>2]|0;
  $26 = ($24|0)<($25|0);
  if ($26) {
   $i$03 = $24;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairIN9ShaderLab16FastPropertyNameEfEEE8TransferI18StreamedBinaryReadILb0EEEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $name$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $name$i$i$i = sp + 4|0;
 ;HEAP32[$name$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1622,($transfer|0),($name$i$i$i|0),0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3376,($transfer|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $16 = HEAP8[$name$i$i$i>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    $21 = (($name$i$i$i) + 1|0);
    $22 = $21;
   } else {
    $19 = (($name$i$i$i) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $22 = $20;
   }
   __THREW__ = 0;
   invoke_vii(2618,($data|0),($22|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP8[$name$i$i$i>>0]|0;
    $26 = $25 & 1;
    $27 = ($26<<24>>24)==(0);
    if (!($27)) {
     $28 = (($name$i$i$i) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     HEAP32[$0>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($29|0),($$byval_copy1|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      $32 = ___cxa_find_matching_catch()|0;
      $33 = tempRet0;
      ___cxa_call_unexpected(($32|0));
      // unreachable;
     }
    }
    $34 = (($data) + 4|0);
    $35 = (($transfer) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($36) + 4|0);
    $38 = (($transfer) + 20|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($37>>>0)>($39>>>0);
    if ($40) {
     __ZN12CachedReader15UpdateReadCacheEPvj($35,$34,4);
     STACKTOP = sp;return;
    } else {
     $41 = Math_fround(HEAPF32[$36>>2]);
     HEAPF32[$34>>2] = $41;
     HEAP32[$35>>2] = $37;
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $7 = HEAP8[$name$i$i$i>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  ___resumeException($5|0);
  // unreachable;
 }
 $10 = (($name$i$i$i) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($11|0),($$byval_copy1|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  ___cxa_call_unexpected(($14|0));
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS2_4lessIS5_EENS2_9allocatorINS2_4pairIKS5_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$ = 0, $$byval_copy1 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $name$i$i$i$i$i = 0, $p = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 72|0;
 $1 = sp;
 $2 = sp + 24|0;
 $name$i$i$i$i$i = sp + 28|0;
 $size = sp + 40|0;
 $p = sp + 48|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$size>>2] = $9;
  HEAP32[$3>>2] = $5;
 }
 HEAP32[$p>>2] = -1;
 $10 = (($p) + 4|0);
 __ZN18UnityPropertySheet11UnityTexEnvC2Ev($10);
 $11 = (($data) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$12);
 $13 = (($data) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = (($data) + 4|0);
 HEAP32[$data>>2] = $14;
 HEAP32[$14>>2] = 0;
 $15 = HEAP32[$size>>2]|0;
 $16 = ($15|0)>(0);
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $17 = (($name$i$i$i$i$i) + 1|0);
 $18 = (($p) + 20|0);
 $19 = (($1) + 4|0);
 $20 = (($1) + 20|0);
 $21 = (($name$i$i$i$i$i) + 8|0);
 $i$04 = 0;
 while(1) {
  ;HEAP32[$name$i$i$i$i$i+0>>2]=0|0;HEAP32[$name$i$i$i$i$i+4>>2]=0|0;HEAP32[$name$i$i$i$i$i+8>>2]=0|0;
  __THREW__ = 0;
  invoke_viii(1622,($this|0),($name$i$i$i$i$i|0),0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3376,($this|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 8;
   break;
  }
  $36 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  $39 = HEAP32[$21>>2]|0;
  $$ = $38 ? $17 : $39;
  __THREW__ = 0;
  invoke_vii(2618,($p|0),($$|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   label = 8;
   break;
  }
  $42 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $43 = $42 & 1;
  $44 = ($43<<24>>24)==(0);
  if (!($44)) {
   $45 = HEAP32[$21>>2]|0;
   HEAP32[$2>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($45|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    label = 14;
    break;
   }
  }
  __ZN18UnityPropertySheet11UnityTexEnv8TransferI18StreamedBinaryReadILb0EEEEvRT_($10,$this);
  $50 = HEAP32[$p>>2]|0;
  $51 = HEAP32[$18>>2]|0;
  ;HEAP32[$19+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$10+12>>2]|0;
  HEAP32[$20>>2] = $51;
  HEAP32[$1>>2] = $50;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_($$byval_copy1,$data,$1);
  $52 = (($i$04) + 1)|0;
  $53 = HEAP32[$size>>2]|0;
  $54 = ($52|0)<($53|0);
  if ($54) {
   $i$04 = $52;
  } else {
   label = 17;
   break;
  }
 }
 if ((label|0) == 8) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $28 = HEAP8[$name$i$i$i$i$i>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   ___resumeException($26|0);
   // unreachable;
  }
  $31 = HEAP32[$21>>2]|0;
  HEAP32[$1>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($31|0),($$byval_copy1|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $34 = ___cxa_find_matching_catch()|0;
   $35 = tempRet0;
   ___cxa_call_unexpected(($34|0));
   // unreachable;
  } else {
   ___resumeException($26|0);
   // unreachable;
  }
 }
 else if ((label|0) == 14) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  ___cxa_call_unexpected(($48|0));
  // unreachable;
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZN18UnityPropertySheet11UnityTexEnv8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre2$i$i$i = 0, $$pre2$i$i$i2 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZN4PPtrI7TextureE8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$this,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre2$i$i$i = HEAP32[$4>>2]|0;
  $10 = $$pre$i$i$i;$12 = $$pre2$i$i$i;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$this>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 4|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$4>>2]|0;
  $16 = $$pre;$18 = $$pre5;
 } else {
  $13 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 8|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  $$pre$i$i$i1 = HEAP32[$1>>2]|0;
  $$pre2$i$i$i2 = HEAP32[$4>>2]|0;
  $22 = $$pre$i$i$i1;$24 = $$pre2$i$i$i2;
 } else {
  $19 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 }
 $20 = (($this) + 12|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  STACKTOP = sp;return;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  STACKTOP = sp;return;
 }
}
function __ZN18UnityPropertySheet8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i2 = sp;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = HEAP32[580600>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641632,$0,$converter$i$i2,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S6_EEEEEEEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i2>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 12|0);
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641648,$0,$converter$i$i2,1)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  if ($9) {
   __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEfNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_fEEEEEEEEvRT_17TransferMetaFlags($transfer,$6,0);
  } else {
   $10 = HEAP32[$converter$i$i2>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    (FUNCTION_TABLE_iii[$10 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $12 = (($this) + 24|0);
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641664,$0,$converter$i$i2,1)|0);
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = ($13|0)>(0);
 if ($15) {
  __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEEEEvRT_17TransferMetaFlags($transfer,$12,0);
 } else {
  $16 = HEAP32[$converter$i$i2>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   (FUNCTION_TABLE_iii[$16 & 4095]($12,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $converter$i$i = 0, $i$03 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $converter$i$i = sp + 48|0;
 $1 = sp;
 $size = sp + 20|0;
 $p = sp + 24|0;
 $2 = (($data) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,641800,641800,$size)|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$p>>2] = -1;
 $5 = (($data) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($data,$6);
 HEAP32[$2>>2] = 0;
 $7 = (($data) + 4|0);
 HEAP32[$data>>2] = $7;
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[$size>>2]|0;
 $9 = ($8|0)>(0);
 if ($9) {
  $10 = HEAP32[580608>>2]|0;
  $11 = (($p) + 4|0);
  $12 = (($1) + 4|0);
  $i$03 = 0;
  while(1) {
   $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,641624,$10,$converter$i$i,1)|0);
   $14 = ($13|0)==(0);
   if (!($14)) {
    $15 = ($13|0)>(0);
    if ($15) {
     __ZN15SerializeTraitsINSt3__14pairIN9ShaderLab16FastPropertyNameE10ColorRGBAfEEE8TransferI14SafeBinaryReadEEvRS5_RT_($p,$this);
    } else {
     $16 = HEAP32[$converter$i$i>>2]|0;
     $17 = ($16|0)==(0|0);
     if (!($17)) {
      (FUNCTION_TABLE_iii[$16 & 4095]($p,$this)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
   }
   $18 = HEAP32[$p>>2]|0;
   HEAP32[$1>>2] = $18;
   ;HEAP32[$12+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$11+12>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($converter$i$i,$data,$1);
   $19 = (($i$03) + 1)|0;
   $20 = HEAP32[$size>>2]|0;
   $21 = ($19|0)<($20|0);
   if ($21) {
    $i$03 = $19;
   } else {
    break;
   }
  }
 }
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairIN9ShaderLab16FastPropertyNameE10ColorRGBAfEEE8TransferI14SafeBinaryReadEEvRS5_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580576>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$0,641832,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN9ShaderLab16FastPropertyName8TransferI14SafeBinaryReadEEvRT_($data,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($data) + 4|0);
 $7 = HEAP32[580656>>2]|0;
 $8 = HEAP32[580560>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$7,$8,$converter$i$i1,1)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 if ($11) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,641680,0);
  $12 = (($data) + 8|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,641688,0);
  $13 = (($data) + 12|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,641696,0);
  $14 = (($data) + 16|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$14,641704,0);
 } else {
  $15 = HEAP32[$converter$i$i1>>2]|0;
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   (FUNCTION_TABLE_iii[$15 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEfNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_fEEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i$i = 0, $i$03 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i = sp + 24|0;
 $converter$i$i = sp;
 $size = sp + 8|0;
 $p = sp + 16|0;
 $1 = (($data) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,641800,641800,$size)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 HEAP32[$p>>2] = -1;
 $4 = (($p) + 4|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($data) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($data,$6);
 HEAP32[$1>>2] = 0;
 $7 = (($data) + 4|0);
 HEAP32[$data>>2] = $7;
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[$size>>2]|0;
 $9 = ($8|0)>(0);
 if ($9) {
  $10 = HEAP32[580608>>2]|0;
  $11 = HEAP32[580576>>2]|0;
  $12 = HEAP32[580656>>2]|0;
  $i$03 = 0;
  while(1) {
   $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,641624,$10,$converter$i$i,1)|0);
   $14 = ($13|0)==(0);
   if (!($14)) {
    $15 = ($13|0)>(0);
    if ($15) {
     $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$11,641832,$converter$i$i$i,1)|0);
     $17 = ($16|0)==(0);
     if (!($17)) {
      $18 = ($16|0)>(0);
      if ($18) {
       __ZN9ShaderLab16FastPropertyName8TransferI14SafeBinaryReadEEvRT_($p,$this);
      } else {
       $19 = HEAP32[$converter$i$i$i>>2]|0;
       $20 = ($19|0)==(0|0);
       if (!($20)) {
        (FUNCTION_TABLE_iii[$19 & 4095]($p,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$4,$12,0);
    } else {
     $21 = HEAP32[$converter$i$i>>2]|0;
     $22 = ($21|0)==(0|0);
     if (!($22)) {
      (FUNCTION_TABLE_iii[$21 & 4095]($p,$this)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
   }
   $23 = HEAP32[$p>>2]|0;
   $24 = Math_fround(HEAPF32[$4>>2]);
   $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
   $26 = $converter$i$i;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($converter$i$i$i,$data,$converter$i$i);
   $30 = (($i$03) + 1)|0;
   $31 = HEAP32[$size>>2]|0;
   $32 = ($30|0)<($31|0);
   if ($32) {
    $i$03 = $30;
   } else {
    break;
   }
  }
 }
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $i$03 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $converter$i$i = sp + 56|0;
 $1 = sp;
 $size = sp + 24|0;
 $p = sp + 32|0;
 $2 = (($data) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,641800,641800,$size)|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$p>>2] = -1;
 $5 = (($p) + 4|0);
 __ZN18UnityPropertySheet11UnityTexEnvC2Ev($5);
 $6 = (($data) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$7);
 HEAP32[$2>>2] = 0;
 $8 = (($data) + 4|0);
 HEAP32[$data>>2] = $8;
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$size>>2]|0;
 $10 = ($9|0)>(0);
 if ($10) {
  $11 = HEAP32[580608>>2]|0;
  $12 = (($p) + 20|0);
  $13 = (($1) + 4|0);
  $14 = (($1) + 20|0);
  $i$03 = 0;
  while(1) {
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,641624,$11,$converter$i$i,1)|0);
   $16 = ($15|0)==(0);
   if (!($16)) {
    $17 = ($15|0)>(0);
    if ($17) {
     __ZN15SerializeTraitsINSt3__14pairIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEEE8TransferI14SafeBinaryReadEEvRS6_RT_($p,$this);
    } else {
     $18 = HEAP32[$converter$i$i>>2]|0;
     $19 = ($18|0)==(0|0);
     if (!($19)) {
      (FUNCTION_TABLE_iii[$18 & 4095]($p,$this)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
   }
   $20 = HEAP32[$p>>2]|0;
   $21 = HEAP32[$12>>2]|0;
   ;HEAP32[$13+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$5+12>>2]|0;
   HEAP32[$14>>2] = $21;
   HEAP32[$1>>2] = $20;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_($converter$i$i,$data,$1);
   $22 = (($i$03) + 1)|0;
   $23 = HEAP32[$size>>2]|0;
   $24 = ($22|0)<($23|0);
   if ($24) {
    $i$03 = $22;
   } else {
    break;
   }
  }
 }
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvEEEE8TransferI14SafeBinaryReadEEvRS6_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580576>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$0,641832,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN9ShaderLab16FastPropertyName8TransferI14SafeBinaryReadEEvRT_($data,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($data) + 4|0);
 $7 = HEAP32[580656>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$7,641856,$converter$i$i1,1)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  __ZN18UnityPropertySheet11UnityTexEnv8TransferI14SafeBinaryReadEEvRT_($6,$transfer);
 } else {
  $11 = HEAP32[$converter$i$i1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (FUNCTION_TABLE_iii[$11 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18UnityPropertySheet11UnityTexEnv8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $converter$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i2 = sp;
 $0 = (($this) + 16|0);
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641712,641872,$converter$i$i2,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN4PPtrI7TextureE8TransferI14SafeBinaryReadEEvRT_($0,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i2>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = HEAP32[580768>>2]|0;
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641728,$6,$converter$i$i2,1)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  if ($9) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$this,641752,0);
   $10 = (($this) + 4|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$10,641760,0);
  } else {
   $11 = HEAP32[$converter$i$i2>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    (FUNCTION_TABLE_iii[$11 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $13 = (($this) + 8|0);
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,641736,$6,$converter$i$i2,1)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ($14|0)>(0);
 if ($16) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,641752,0);
  $17 = (($this) + 12|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$17,641760,0);
 } else {
  $18 = HEAP32[$converter$i$i2>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   (FUNCTION_TABLE_iii[$18 & 4095]($13,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsIN18UnityPropertySheet11UnityTexEnvEE8TransferI13ProxyTransferEEvRS1_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 $0 = (($data) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641712,641872,$0,0);
 $1 = (($localIdentifier$i$i$i) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641768,$6,$0,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641784,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = HEAP32[580768>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641728,$18,$data,0);
 $19 = (($transfer) + 16|0);
 $20 = (__ZNK16TypeTreeIterator7GetNodeEv($19)|0);
 $21 = (($20) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 | 2097152;
 $24 = HEAP32[$7>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$10>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 20|0);
 HEAP32[$27>>2] = $23;
 $28 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641752,$28,$data,0);
 $29 = HEAP32[$7>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$10>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = (($data) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641760,$28,$33,0);
 $34 = HEAP32[$7>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$10>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($data) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641736,$18,$38,0);
 $39 = (__ZNK16TypeTreeIterator7GetNodeEv($19)|0);
 $40 = (($39) + 20|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 | 2097152;
 $43 = HEAP32[$7>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$10>>2]|0;
 $46 = ((($44) + (($45*24)|0)|0) + 20|0);
 HEAP32[$46>>2] = $42;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641752,$28,$38,0);
 $47 = HEAP32[$7>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$10>>2]|0;
 $50 = ((($48) + (($49*24)|0)|0) + 12|0);
 HEAP32[$50>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $51 = (($data) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,641760,$28,$51,0);
 $52 = HEAP32[$7>>2]|0;
 $53 = HEAP32[$52>>2]|0;
 $54 = HEAP32[$10>>2]|0;
 $55 = ((($53) + (($54*24)|0)|0) + 12|0);
 HEAP32[$55>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN5Unity8Material15CachedSubShaderENS_9allocatorIS3_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i720 = 0, $$0$i721 = 0, $$0$i9 = 0, $$01$i$i = 0, $$byval_copy2 = 0, $$idx$i$i$i$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i13 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 44)&-1;
 $10 = ($9>>>0)<($__n>>>0);
 if (!($10)) {
  $$0$i = $__n;$12 = $5;
  while(1) {
   $11 = ($12|0)==(0|0);
   if ($11) {
    $18 = 0;
   } else {
    HEAP32[$12>>2] = 0;
    $13 = (($12) + 8|0);
    HEAP32[$13>>2] = 0;
    $14 = (($12) + 12|0);
    HEAP32[$14>>2] = 0;
    $15 = (($12) + 4|0);
    HEAP32[$15>>2] = 61;
    $16 = (($12) + 16|0);
    ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;HEAP32[$16+24>>2]=0|0;
    $$pre1$i = HEAP32[$4>>2]|0;
    $18 = $$pre1$i;
   }
   $17 = (($18) + 44|0);
   HEAP32[$4>>2] = $17;
   $19 = (($$0$i) + -1)|0;
   $20 = ($19|0)==(0);
   if ($20) {
    break;
   } else {
    $$0$i = $19;$12 = $17;
   }
  }
  STACKTOP = sp;return;
 }
 $21 = HEAP32[$this>>2]|0;
 $22 = $21;
 $23 = (($7) - ($22))|0;
 $24 = (($23|0) / 44)&-1;
 $25 = (($24) + ($__n))|0;
 $26 = ($25>>>0)>(97612893);
 if ($26) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $27 = (($6) - ($22))|0;
 $28 = (($27|0) / 44)&-1;
 $29 = ($28>>>0)<(48806446);
 if ($29) {
  $30 = $28 << 1;
  $31 = ($30>>>0)<($25>>>0);
  $32 = $31 ? $25 : $30;
  $33 = ($32|0)==(0);
  if ($33) {
   $$0$i721 = 0;$37 = 0;
  } else {
   $$0$i720 = $32;
   label = 9;
  }
 } else {
  $$0$i720 = 97612893;
  label = 9;
 }
 if ((label|0) == 9) {
  $34 = ($$0$i720*44)|0;
  $35 = (__Znwj($34)|0);
  $$0$i721 = $$0$i720;$37 = $35;
 }
 $36 = (($37) + (($24*44)|0)|0);
 $$0$i9 = $__n;$39 = $36;
 while(1) {
  $38 = ($39|0)==(0|0);
  if ($38) {
   $45 = 0;
  } else {
   HEAP32[$39>>2] = 0;
   $40 = (($39) + 8|0);
   HEAP32[$40>>2] = 0;
   $41 = (($39) + 12|0);
   HEAP32[$41>>2] = 0;
   $42 = (($39) + 4|0);
   HEAP32[$42>>2] = 61;
   $43 = (($39) + 16|0);
   ;HEAP32[$43+0>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;HEAP32[$43+16>>2]=0|0;HEAP32[$43+20>>2]=0|0;HEAP32[$43+24>>2]=0|0;
   $45 = $39;
  }
  $44 = (($45) + 44|0);
  $46 = (($$0$i9) + -1)|0;
  $47 = ($46|0)==(0);
  if ($47) {
   break;
  } else {
   $$0$i9 = $46;$39 = $44;
  }
 }
 $48 = (($37) + (($$0$i721*44)|0)|0);
 $49 = HEAP32[$this>>2]|0;
 $50 = HEAP32[$4>>2]|0;
 $51 = ($50|0)==($49|0);
 L23: do {
  if ($51) {
   HEAP32[$this>>2] = $36;
   HEAP32[$4>>2] = $44;
   HEAP32[$2>>2] = $48;
   $90 = $49;
  } else {
   $$01$i$i = $50;$56 = $36;
   while(1) {
    $52 = (($$01$i$i) + -44|0);
    $53 = (($$01$i$i) + -40|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($56) + -40|0);
    HEAP32[$55>>2] = $54;
    $57 = (($56) + -36|0);
    HEAP32[$57>>2] = 0;
    $58 = (($56) + -32|0);
    HEAP32[$58>>2] = 0;
    $59 = (($56) + -44|0);
    HEAP32[$59>>2] = 0;
    $60 = HEAP32[$52>>2]|0;
    $61 = (($$01$i$i) + -36|0);
    $62 = HEAP32[$61>>2]|0;
    $$idx$i$i$i$i$i$i$i = ($62*28)|0;
    $63 = (($$idx$i$i$i$i$i$i$i|0) / 28)&-1;
    HEAP32[$57>>2] = $63;
    $64 = ($$idx$i$i$i$i$i$i$i|0)==(0);
    if ($64) {
     $69 = $63;$70 = 0;
    } else {
     HEAP32[$58>>2] = $63;
     HEAP32[$0>>2] = $54;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $65 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i$i$i$i|0),4,($$byval_copy2|0),0,(641280|0),370)|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     HEAP32[$59>>2] = $65;
     $$pre$i$i$i$i$i$i = HEAP32[$57>>2]|0;
     $69 = $$pre$i$i$i$i$i$i;$70 = $65;
    }
    $68 = ($69*28)|0;
    _memcpy(($70|0),($60|0),($68|0))|0;
    $71 = (($56) + -28|0);
    $72 = (($$01$i$i) + -28|0);
    ;HEAP32[$71+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$71+12>>2]=HEAP32[$72+12>>2]|0;HEAP32[$71+16>>2]=HEAP32[$72+16>>2]|0;HEAP32[$71+20>>2]=HEAP32[$72+20>>2]|0;HEAP32[$71+24>>2]=HEAP32[$72+24>>2]|0;
    $73 = (($56) + -44|0);
    $74 = ($52|0)==($49|0);
    if ($74) {
     label = 21;
     break;
    } else {
     $$01$i$i = $52;$56 = $73;
    }
   }
   if ((label|0) == 21) {
    $$pre$i13 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$4>>2]|0;
    HEAP32[$this>>2] = $73;
    HEAP32[$4>>2] = $44;
    HEAP32[$2>>2] = $48;
    $75 = ($$pre|0)==($$pre$i13|0);
    if ($75) {
     $90 = $$pre$i13;
     break;
    }
    $77 = $$pre;
    while(1) {
     $76 = (($77) + -44|0);
     $78 = (($77) + -32|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)>(-1);
     if ($80) {
      $82 = HEAP32[$76>>2]|0;
      $83 = (($77) + -40|0);
      $84 = HEAP32[$83>>2]|0;
      HEAP32[$0>>2] = $84;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($82|0),($$byval_copy2|0));
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if ($86) {
       break;
      }
      HEAP32[$76>>2] = 0;
     }
     $81 = ($76|0)==($$pre$i13|0);
     if ($81) {
      $90 = $$pre$i13;
      break L23;
     } else {
      $77 = $76;
     }
    }
    $87 = ___cxa_find_matching_catch()|0;
    $88 = tempRet0;
    ___cxa_call_unexpected(($87|0));
    // unreachable;
   }
   $91 = ___cxa_find_matching_catch()|0;
   $92 = tempRet0;
   $93 = ($44|0)==($56|0);
   L43: do {
    if (!($93)) {
     $95 = $44;
     while(1) {
      $94 = (($95) + -44|0);
      $96 = (($95) + -32|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = ($97|0)>(-1);
      if ($98) {
       $100 = HEAP32[$94>>2]|0;
       $101 = (($95) + -40|0);
       $102 = HEAP32[$101>>2]|0;
       HEAP32[$1>>2] = $102;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($100|0),($$byval_copy2|0));
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        break;
       }
       HEAP32[$94>>2] = 0;
      }
      $99 = ($94|0)==($56|0);
      if ($99) {
       break L43;
      } else {
       $95 = $94;
      }
     }
     $105 = ___cxa_find_matching_catch()|0;
     $106 = tempRet0;
     ___cxa_call_unexpected(($105|0));
     // unreachable;
    }
   } while(0);
   $107 = ($37|0)==(0|0);
   if ($107) {
    ___resumeException($91|0);
    // unreachable;
   }
   __ZdlPv($37);
   ___resumeException($91|0);
   // unreachable;
  }
 } while(0);
 $89 = ($90|0)==(0|0);
 if ($89) {
  STACKTOP = sp;return;
 }
 __ZdlPv($90);
 STACKTOP = sp;return;
}
function __ZN21MaterialPropertyBlockC2EPNS_8PropertyEjPfj($this,$props,$propCount,$buffer,$bufSize) {
 $this = $this|0;
 $props = $props|0;
 $propCount = $propCount|0;
 $buffer = $buffer|0;
 $bufSize = $bufSize|0;
 var $$byval_copy3 = 0, $$idx = 0, $$idx5 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 HEAP32[$this>>2] = 0;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = 61;
 $7 = (($this) + 16|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 24|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 28|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 20|0);
 HEAP32[$10>>2] = 61;
 $11 = (($this) + 32|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$2>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy3|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  $$pre = HEAP32[$9>>2]|0;
  $phitmp = ($$pre|0)>(-1);
  $$idx = $propCount << 4;
  $14 = $$idx >> 4;
  HEAP32[$4>>2] = $14;
  $15 = $14 | -2147483648;
  HEAP32[$5>>2] = $15;
  HEAP32[$this>>2] = $props;
  if (!($phitmp)) {
   $$idx5 = $bufSize << 2;
   $20 = $$idx5 >> 2;
   HEAP32[$8>>2] = $20;
   $21 = $20 | -2147483648;
   HEAP32[$9>>2] = $21;
   HEAP32[$7>>2] = $buffer;
   STACKTOP = sp;return;
  }
  $16 = HEAP32[$7>>2]|0;
  $17 = HEAP32[$10>>2]|0;
  HEAP32[$1>>2] = $17;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($16|0),($$byval_copy3|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   HEAP32[$7>>2] = 0;
   $$idx5 = $bufSize << 2;
   $20 = $$idx5 >> 2;
   HEAP32[$8>>2] = $20;
   $21 = $20 | -2147483648;
   HEAP32[$9>>2] = $21;
   HEAP32[$7>>2] = $buffer;
   STACKTOP = sp;return;
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $24 = HEAP32[$9>>2]|0;
 $25 = ($24|0)>(-1);
 do {
  if ($25) {
   $26 = HEAP32[$7>>2]|0;
   $27 = HEAP32[$10>>2]|0;
   HEAP32[$0>>2] = $27;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($26|0),($$byval_copy3|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $36 = ___cxa_find_matching_catch(0|0)|0;
    $37 = tempRet0;
    ___clang_call_terminate($36);
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    break;
   }
  }
 } while(0);
 $30 = HEAP32[$5>>2]|0;
 $31 = ($30|0)>(-1);
 if (!($31)) {
  ___resumeException($22|0);
  // unreachable;
 }
 $32 = HEAP32[$this>>2]|0;
 $33 = HEAP32[$6>>2]|0;
 HEAP32[$3>>2] = $33;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy3|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch(0|0)|0;
  $37 = tempRet0;
  ___clang_call_terminate($36);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($22|0);
 // unreachable;
}
function __ZN21MaterialPropertyBlock11AddPropertyERKN9ShaderLab16FastPropertyNameEPKfhhj($this,$name,$data,$rows,$cols,$arraySize) {
 $this = $this|0;
 $name = $name|0;
 $data = $data|0;
 $rows = $rows|0;
 $cols = $cols|0;
 $arraySize = $arraySize|0;
 var $$byval_copy3 = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$name>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1)|0;
 HEAP32[$5>>2] = $7;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 2147483647;
 $11 = ($7>>>0)>($10>>>0);
 if ($11) {
  $12 = $9 << 1;
  $13 = ($12|0)==(0);
  $14 = $13 ? 1 : $12;
  $15 = ($10>>>0)<($14>>>0);
  do {
   if ($15) {
    $16 = ($9|0)>(-1);
    if ($16) {
     HEAP32[$8>>2] = $14;
     $17 = HEAP32[$this>>2]|0;
     $18 = $14 << 4;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z16realloc_internalPvji10MemLabelIdiPKci($17,$18,4,$$byval_copy3,0,641984,370)|0);
     HEAP32[$this>>2] = $21;
     break;
    } else {
     $22 = $14 << 4;
     $23 = (($this) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     HEAP32[$0>>2] = $24;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,4,$$byval_copy3,0,641984,352)|0);
     $26 = HEAP32[$this>>2]|0;
     $27 = HEAP32[$5>>2]|0;
     $28 = $27 << 4;
     _memcpy(($25|0),($26|0),($28|0))|0;
     HEAP32[$8>>2] = $14;
     HEAP32[$this>>2] = $25;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$5>>2]|0;
  $30 = $$pre$i$i;
 } else {
  $30 = $7;
 }
 $29 = (($30) + -1)|0;
 $31 = HEAP32[$this>>2]|0;
 $32 = (($31) + ($29<<4)|0);
 HEAP32[$32>>2] = $4;
 $33 = ((($31) + ($29<<4)|0) + 4|0);
 HEAP8[$33>>0] = $rows;
 $34 = ((($31) + ($29<<4)|0) + 5|0);
 HEAP8[$34>>0] = $cols;
 $35 = ((($31) + ($29<<4)|0) + 6|0);
 HEAP8[$35>>0] = 0;
 $36 = ((($31) + ($29<<4)|0) + 8|0);
 HEAP32[$36>>2] = $arraySize;
 $37 = ((($31) + ($29<<4)|0) + 12|0);
 HEAP32[$37>>2] = $3;
 $38 = $rows&255;
 $39 = $cols&255;
 $40 = Math_imul($39, $38)|0;
 $41 = Math_imul($40, $arraySize)|0;
 $42 = (($3) + ($41))|0;
 HEAP32[$2>>2] = $42;
 $43 = (($this) + 28|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 & 2147483647;
 $46 = ($45>>>0)<($42>>>0);
 if (!($46)) {
  $$pre = HEAP32[$1>>2]|0;
  $61 = $$pre;
  $60 = (($61) + ($3<<2)|0);
  $62 = $41 << 2;
  _memcpy(($60|0),($data|0),($62|0))|0;
  STACKTOP = sp;return;
 }
 $47 = ($44|0)>(-1);
 if ($47) {
  HEAP32[$43>>2] = $42;
  $48 = HEAP32[$1>>2]|0;
  $49 = $42 << 2;
  $50 = (($this) + 20|0);
  $51 = HEAP32[$50>>2]|0;
  HEAP32[$0>>2] = $51;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $52 = (__Z16realloc_internalPvji10MemLabelIdiPKci($48,$49,4,$$byval_copy3,0,641984,370)|0);
  HEAP32[$1>>2] = $52;
  $61 = $52;
  $60 = (($61) + ($3<<2)|0);
  $62 = $41 << 2;
  _memcpy(($60|0),($data|0),($62|0))|0;
  STACKTOP = sp;return;
 } else {
  $53 = $42 << 2;
  $54 = (($this) + 20|0);
  $55 = HEAP32[$54>>2]|0;
  HEAP32[$0>>2] = $55;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $56 = (__Z15malloc_internaljj10MemLabelIdiPKci($53,4,$$byval_copy3,0,641984,352)|0);
  $57 = HEAP32[$1>>2]|0;
  $58 = HEAP32[$2>>2]|0;
  $59 = $58 << 2;
  _memcpy(($56|0),($57|0),($59|0))|0;
  HEAP32[$43>>2] = $42;
  HEAP32[$1>>2] = $56;
  $61 = $56;
  $60 = (($61) + ($3<<2)|0);
  $62 = $41 << 2;
  _memcpy(($60|0),($data|0),($62|0))|0;
  STACKTOP = sp;return;
 }
}
function __ZN21MaterialPropertyBlock18AddPropertyTextureERKN9ShaderLab16FastPropertyNameE16TextureDimension9TextureID($this,$name,$dim,$tid) {
 $this = $this|0;
 $name = $name|0;
 $dim = $dim|0;
 $tid = $tid|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN21MaterialPropertyBlock11AddPropertyERKN9ShaderLab16FastPropertyNameEPKfhhj($this,$name,$tid,1,1,1);
 $0 = $dim&255;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -1)|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = ((($4) + ($3<<4)|0) + 6|0);
 HEAP8[$5>>0] = $0;
 STACKTOP = sp;return;
}
function __ZN21MaterialPropertyBlock16AddPropertyFloatERKN9ShaderLab16FastPropertyNameEf($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = Math_fround($val);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAPF32[$0>>2] = $val;
 __ZN21MaterialPropertyBlock11AddPropertyERKN9ShaderLab16FastPropertyNameEPKfhhj($this,$name,$0,1,1,1);
 STACKTOP = sp;return;
}
function __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($this,$name,$vec) {
 $this = $this|0;
 $name = $name|0;
 $vec = $vec|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN21MaterialPropertyBlock11AddPropertyERKN9ShaderLab16FastPropertyNameEPKfhhj($this,$name,$vec,1,4,1);
 STACKTOP = sp;return;
}
function __ZN21MaterialPropertyBlock16AddPropertyColorERKN9ShaderLab16FastPropertyNameERK10ColorRGBAf($this,$name,$col) {
 $this = $this|0;
 $name = $name|0;
 $col = $col|0;
 var $$0$i$i$i = Math_fround(0), $$0$i1$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $converted = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converted = sp;
 $0 = (__Z19GetActiveColorSpacev()|0);
 $1 = ($0|0)==(1);
 if (!($1)) {
  ;HEAP32[$converted+0>>2]=HEAP32[$col+0>>2]|0;HEAP32[$converted+4>>2]=HEAP32[$col+4>>2]|0;HEAP32[$converted+8>>2]=HEAP32[$col+8>>2]|0;HEAP32[$converted+12>>2]=HEAP32[$col+12>>2]|0;
  $$pre$phiZ2D = $converted;
  __ZN21MaterialPropertyBlock11AddPropertyERKN9ShaderLab16FastPropertyNameEPKfhhj($this,$name,$$pre$phiZ2D,1,4,1);
  STACKTOP = sp;return;
 }
 $2 = Math_fround(HEAPF32[$col>>2]);
 $3 = !($2 <= Math_fround(0.0404499992728233337402));
 do {
  if ($3) {
   $5 = $2 < Math_fround(1.0);
   if ($5) {
    $6 = Math_fround($2 + Math_fround(0.054999999701976776123));
    $7 = Math_fround($6 / Math_fround(1.05499994754791259766));
    $8 = (Math_fround(+(Math_pow((+$7),2.40000009536743164063))));
    $$0$i$i$i = $8;
    break;
   } else {
    $9 = (Math_fround(+(Math_pow((+$2),2.40000009536743164063))));
    $$0$i$i$i = $9;
    break;
   }
  } else {
   $4 = Math_fround($2 / Math_fround(12.9200000762939453125));
   $$0$i$i$i = $4;
  }
 } while(0);
 $10 = (($col) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = !($11 <= Math_fround(0.0404499992728233337402));
 do {
  if ($12) {
   $14 = $11 < Math_fround(1.0);
   if ($14) {
    $15 = Math_fround($11 + Math_fround(0.054999999701976776123));
    $16 = Math_fround($15 / Math_fround(1.05499994754791259766));
    $17 = (Math_fround(+(Math_pow((+$16),2.40000009536743164063))));
    $$0$i3$i$i = $17;
    break;
   } else {
    $18 = (Math_fround(+(Math_pow((+$11),2.40000009536743164063))));
    $$0$i3$i$i = $18;
    break;
   }
  } else {
   $13 = Math_fround($11 / Math_fround(12.9200000762939453125));
   $$0$i3$i$i = $13;
  }
 } while(0);
 $19 = (($col) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = !($20 <= Math_fround(0.0404499992728233337402));
 do {
  if ($21) {
   $23 = $20 < Math_fround(1.0);
   if ($23) {
    $24 = Math_fround($20 + Math_fround(0.054999999701976776123));
    $25 = Math_fround($24 / Math_fround(1.05499994754791259766));
    $26 = (Math_fround(+(Math_pow((+$25),2.40000009536743164063))));
    $$0$i1$i$i = $26;
    break;
   } else {
    $27 = (Math_fround(+(Math_pow((+$20),2.40000009536743164063))));
    $$0$i1$i$i = $27;
    break;
   }
  } else {
   $22 = Math_fround($20 / Math_fround(12.9200000762939453125));
   $$0$i1$i$i = $22;
  }
 } while(0);
 $28 = (($col) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$converted>>2] = $$0$i$i$i;
 $30 = (($converted) + 4|0);
 HEAPF32[$30>>2] = $$0$i3$i$i;
 $31 = (($converted) + 8|0);
 HEAPF32[$31>>2] = $$0$i1$i$i;
 $32 = (($converted) + 12|0);
 HEAPF32[$32>>2] = $29;
 $$pre$phiZ2D = $converted;
 __ZN21MaterialPropertyBlock11AddPropertyERKN9ShaderLab16FastPropertyNameEPKfhhj($this,$name,$$pre$phiZ2D,1,4,1);
 STACKTOP = sp;return;
}
function __ZN21MaterialPropertyBlock17AddPropertyMatrixERKN9ShaderLab16FastPropertyNameERK10Matrix4x4f($this,$name,$mat) {
 $this = $this|0;
 $name = $name|0;
 $mat = $mat|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN21MaterialPropertyBlock11AddPropertyERKN9ShaderLab16FastPropertyNameEPKfhhj($this,$name,$mat,4,4,1);
 STACKTOP = sp;return;
}
function __ZN21MaterialPropertyBlock20ReplacePropertyFloatERKN9ShaderLab16FastPropertyNameEf($this,$name,$data) {
 $this = $this|0;
 $name = $name|0;
 $data = Math_fround($data);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN21MaterialPropertyBlock27ReplacePartialFloatPropertyERKN9ShaderLab16FastPropertyNameEfhh($this,$name,$data,1,0);
 STACKTOP = sp;return;
}
function __ZN21MaterialPropertyBlock27ReplacePartialFloatPropertyERKN9ShaderLab16FastPropertyNameEfhh($this,$name,$data,$cols,$colIndex) {
 $this = $this|0;
 $name = $name|0;
 $data = Math_fround($data);
 $cols = $cols|0;
 $colIndex = $colIndex|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $prop = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $prop = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = HEAP32[$this>>2]|0;
   $4 = HEAP32[$name>>2]|0;
   $i$01$i = 0;
   while(1) {
    $7 = (($3) + ($i$01$i<<4)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==($4|0);
    $6 = (($i$01$i) + 1)|0;
    if ($9) {
     break;
    }
    $5 = ($6>>>0)<($1>>>0);
    if ($5) {
     $i$01$i = $6;
    } else {
     break L1;
    }
   }
   $10 = ($i$01$i|0)==(-1);
   if (!($10)) {
    $13 = ((($3) + ($i$01$i<<4)|0) + 4|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = ($14<<24>>24)==(1);
    if ($15) {
     $16 = ((($3) + ($i$01$i<<4)|0) + 5|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = ($17<<24>>24)==($cols<<24>>24);
     if ($18) {
      $19 = ((($3) + ($i$01$i<<4)|0) + 8|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = ($20|0)==(1);
      if ($21) {
       $22 = ((($3) + ($i$01$i<<4)|0) + 12|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = (($this) + 16|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = $colIndex&255;
       $$sum = (($23) + ($26))|0;
       $27 = (($25) + ($$sum<<2)|0);
       HEAPF32[$27>>2] = $data;
       STACKTOP = sp;return;
      }
     }
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(641912,0,641984,161,1,0,0,0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 ;HEAP32[$prop+0>>2]=0|0;HEAP32[$prop+4>>2]=0|0;HEAP32[$prop+8>>2]=0|0;HEAP32[$prop+12>>2]=0|0;
 $11 = $colIndex&255;
 $12 = (($prop) + ($11<<2)|0);
 HEAPF32[$12>>2] = $data;
 __ZN21MaterialPropertyBlock11AddPropertyERKN9ShaderLab16FastPropertyNameEPKfhhj($this,$name,$prop,1,$cols,1);
 STACKTOP = sp;return;
}
function __ZN21MaterialPropertyBlock32ReplacePartialFloatColorPropertyERKN9ShaderLab16FastPropertyNameEfhh($this,$name,$data,$cols,$colIndex) {
 $this = $this|0;
 $name = $name|0;
 $data = Math_fround($data);
 $cols = $cols|0;
 $colIndex = $colIndex|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetActiveColorSpacev()|0);
 $1 = ($0|0)==(1);
 do {
  if ($1) {
   $2 = !($data <= Math_fround(0.0404499992728233337402));
   if (!($2)) {
    $3 = Math_fround($data / Math_fround(12.9200000762939453125));
    $$0$i = $3;
    break;
   }
   $4 = $data < Math_fround(1.0);
   if ($4) {
    $5 = Math_fround($data + Math_fround(0.054999999701976776123));
    $6 = Math_fround($5 / Math_fround(1.05499994754791259766));
    $7 = (Math_fround(+(Math_pow((+$6),2.40000009536743164063))));
    $$0$i = $7;
    break;
   } else {
    $8 = (Math_fround(+(Math_pow((+$data),2.40000009536743164063))));
    $$0$i = $8;
    break;
   }
  } else {
   $$0$i = $data;
  }
 } while(0);
 __ZN21MaterialPropertyBlock27ReplacePartialFloatPropertyERKN9ShaderLab16FastPropertyNameEfhh($this,$name,$$0$i,$cols,$colIndex);
 STACKTOP = sp;return;
}
function __ZNK21MaterialPropertyBlock9FindFloatERKN9ShaderLab16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$name>>2]|0;
 $i$02$i = 0;
 while(1) {
  $5 = (($3) + ($i$02$i<<4)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  if ($7) {
   $8 = ((($3) + ($i$02$i<<4)|0) + 5|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)==(1);
   if ($10) {
    $11 = ((($3) + ($i$02$i<<4)|0) + 4|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = ($12<<24>>24)==(1);
    if ($13) {
     break;
    }
   }
  }
  $19 = (($i$02$i) + 1)|0;
  $20 = ($19|0)==($1|0);
  if ($20) {
   $$0$i = 0;
   label = 8;
   break;
  } else {
   $i$02$i = $19;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0$i|0);
 }
 $14 = ((($3) + ($i$02$i<<4)|0) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($15<<2)|0);
 $$0$i = $18;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK21MaterialPropertyBlock10FindVectorERKN9ShaderLab16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$name>>2]|0;
 $i$02$i = 0;
 while(1) {
  $5 = (($3) + ($i$02$i<<4)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  if ($7) {
   $8 = ((($3) + ($i$02$i<<4)|0) + 5|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)==(4);
   if ($10) {
    $11 = ((($3) + ($i$02$i<<4)|0) + 4|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = ($12<<24>>24)==(1);
    if ($13) {
     break;
    }
   }
  }
  $19 = (($i$02$i) + 1)|0;
  $20 = ($19|0)==($1|0);
  if ($20) {
   $$0$i = 0;
   label = 8;
   break;
  } else {
   $i$02$i = $19;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0$i|0);
 }
 $14 = ((($3) + ($i$02$i<<4)|0) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($15<<2)|0);
 $$0$i = $18;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK21MaterialPropertyBlock8GetColorERKN9ShaderLab16FastPropertyNameER10ColorRGBAf($this,$name,$outColor) {
 $this = $this|0;
 $name = $name|0;
 $outColor = $outColor|0;
 var $$0 = 0, $$0$i$i$i = Math_fround(0), $$0$i$i$i1 = Math_fround(0), $$0$i1$i$i3 = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$i3$i$i2 = Math_fround(0), $$in = 0, $$sum = 0, $$sum4 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0);
 var $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0);
 var $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = HEAP32[$name>>2]|0;
 $i$02$i = 0;
 while(1) {
  $5 = (($3) + ($i$02$i<<4)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  if ($7) {
   $8 = ((($3) + ($i$02$i<<4)|0) + 5|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)==(4);
   if ($10) {
    $11 = ((($3) + ($i$02$i<<4)|0) + 4|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = ($12<<24>>24)==(1);
    if ($13) {
     break;
    }
   }
  }
  $14 = (($i$02$i) + 1)|0;
  $15 = ($14|0)==($1|0);
  if ($15) {
   $$0 = 0;
   label = 26;
   break;
  } else {
   $i$02$i = $14;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return ($$0|0);
 }
 $16 = ((($3) + ($i$02$i<<4)|0) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($17<<2)|0);
 $21 = ($20|0)==(0|0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = (__Z19GetActiveColorSpacev()|0);
 $23 = ($22|0)==(1);
 $24 = Math_fround(HEAPF32[$20>>2]);
 do {
  if ($23) {
   $25 = !($24 <= Math_fround(0.0));
   do {
    if ($25) {
     $26 = !($24 <= Math_fround(0.0031308000907301902771));
     if (!($26)) {
      $27 = Math_fround($24 * Math_fround(12.9200000762939453125));
      $$0$i$i$i = $27;
      break;
     }
     $28 = !($24 <= Math_fround(1.0));
     $29 = (Math_fround(+(Math_pow((+$24),0.416660010814666748047))));
     if ($28) {
      $$0$i$i$i = $29;
     } else {
      $30 = Math_fround($29 * Math_fround(1.05499994754791259766));
      $31 = Math_fround($30 + Math_fround(-0.054999999701976776123));
      $$0$i$i$i = $31;
     }
    } else {
     $$0$i$i$i = Math_fround(0.0);
    }
   } while(0);
   $$sum6 = (($17) + 1)|0;
   $32 = (($19) + ($$sum6<<2)|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = !($33 <= Math_fround(0.0));
   do {
    if ($34) {
     $35 = !($33 <= Math_fround(0.0031308000907301902771));
     if (!($35)) {
      $36 = Math_fround($33 * Math_fround(12.9200000762939453125));
      $$0$i3$i$i = $36;
      break;
     }
     $37 = !($33 <= Math_fround(1.0));
     $38 = (Math_fround(+(Math_pow((+$33),0.416660010814666748047))));
     if ($37) {
      $$0$i3$i$i = $38;
     } else {
      $39 = Math_fround($38 * Math_fround(1.05499994754791259766));
      $40 = Math_fround($39 + Math_fround(-0.054999999701976776123));
      $$0$i3$i$i = $40;
     }
    } else {
     $$0$i3$i$i = Math_fround(0.0);
    }
   } while(0);
   $$sum7 = (($17) + 2)|0;
   $41 = (($19) + ($$sum7<<2)|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = !($42 <= Math_fround(0.0));
   if ($43) {
    $44 = !($42 <= Math_fround(0.0031308000907301902771));
    if (!($44)) {
     $45 = Math_fround($42 * Math_fround(12.9200000762939453125));
     $$0$i$i$i1 = $$0$i$i$i;$$0$i1$i$i3 = $45;$$0$i3$i$i2 = $$0$i3$i$i;
     break;
    }
    $46 = !($42 <= Math_fround(1.0));
    $47 = (Math_fround(+(Math_pow((+$42),0.416660010814666748047))));
    if ($46) {
     $$0$i$i$i1 = $$0$i$i$i;$$0$i1$i$i3 = $47;$$0$i3$i$i2 = $$0$i3$i$i;
    } else {
     $48 = Math_fround($47 * Math_fround(1.05499994754791259766));
     $49 = Math_fround($48 + Math_fround(-0.054999999701976776123));
     $$0$i$i$i1 = $$0$i$i$i;$$0$i1$i$i3 = $49;$$0$i3$i$i2 = $$0$i3$i$i;
    }
   } else {
    $$0$i$i$i1 = $$0$i$i$i;$$0$i1$i$i3 = Math_fround(0.0);$$0$i3$i$i2 = $$0$i3$i$i;
   }
  } else {
   $$sum = (($17) + 1)|0;
   $50 = (($19) + ($$sum<<2)|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $$sum4 = (($17) + 2)|0;
   $52 = (($19) + ($$sum4<<2)|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $$0$i$i$i1 = $24;$$0$i1$i$i3 = $53;$$0$i3$i$i2 = $51;
  }
 } while(0);
 $$sum8$pn = (($17) + 3)|0;
 $$in = (($19) + ($$sum8$pn<<2)|0);
 $54 = Math_fround(HEAPF32[$$in>>2]);
 HEAPF32[$outColor>>2] = $$0$i$i$i1;
 $55 = (($outColor) + 4|0);
 HEAPF32[$55>>2] = $$0$i3$i$i2;
 $56 = (($outColor) + 8|0);
 HEAPF32[$56>>2] = $$0$i1$i$i3;
 $57 = (($outColor) + 12|0);
 HEAPF32[$57>>2] = $54;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN21MaterialPropertyBlock11ComputeHashEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 2;
 $5 = (__Z12MurmurHash2APKvij($1,$4,-1756908916)|0);
 $6 = (($this) + 32|0);
 HEAP32[$6>>2] = $5;
 STACKTOP = sp;return;
}
function __ZL22StaticInitializeShaderv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL19StaticDestroyShaderv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[((642000 + 12|0))>>2]|0;
 $2 = ($1|0)>(-1);
 if ($2) {
  $3 = HEAP32[642000>>2]|0;
  $4 = HEAP32[((642000 + 4|0))>>2]|0;
  HEAP32[$0>>2] = $4;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy1);
  HEAP32[642000>>2] = 0;
 }
 HEAP32[((642000 + 8|0))>>2] = 0;
 HEAP32[((642000 + 12|0))>>2] = 0;
 $5 = HEAP32[((642016 + 12|0))>>2]|0;
 $6 = ($5|0)>(-1);
 if (!($6)) {
  HEAP32[((642016 + 8|0))>>2] = 0;
  HEAP32[((642016 + 12|0))>>2] = 0;
  STACKTOP = sp;return;
 }
 $7 = HEAP32[642016>>2]|0;
 $8 = HEAP32[((642016 + 4|0))>>2]|0;
 HEAP32[$0>>2] = $8;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy1);
 HEAP32[642016>>2] = 0;
 HEAP32[((642016 + 8|0))>>2] = 0;
 HEAP32[((642016 + 12|0))>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6ShaderC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$label>>2]|0;
 HEAP32[$2>>2] = $3;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 __ZN9TextAssetC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy2,$mode);
 HEAP32[$this>>2] = ((642032 + 8|0));
 $4 = (($this) + 64|0);
 $5 = (($this) + 76|0);
 $6 = (($this) + 80|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP8[$4+24>>0]=0|0;
 $7 = HEAP32[642144>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = HEAP32[628272>>2]|0;
  HEAP32[$1>>2] = $9;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $10 = (invoke_iiiiiii(103,4,($$byval_copy2|0),1,16,(642424|0),599)|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   HEAP32[641992>>2] = $10;
   __THREW__ = 0;
   invoke_v(184);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $$pre = HEAP32[642144>>2]|0;
    $16 = $$pre;
    label = 5;
   }
  }
 } else {
  $16 = $7;
  label = 5;
 }
 if ((label|0) == 5) {
  $15 = (($this) + 52|0);
  HEAP32[$15>>2] = $16;
  $17 = (($this) + 56|0);
  HEAP32[$17>>2] = 0;
  $18 = (($this) + 60|0);
  HEAP32[$18>>2] = 0;
  $19 = (($this) + 89|0);
  HEAP8[$19>>0] = 0;
  $20 = ($mode|0)==(1);
  if ($20) {
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  invoke_vi(3577,($this|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   STACKTOP = sp;return;
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$5>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = HEAP32[$6>>2]|0;
  $28 = ($27|0)==($25|0);
  if (!($28)) {
   $__new_last2$i$i$i$i$i = $25;
   $scevgep$i$i$i$i$i = (($27) + -4|0);
   $29 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($29)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $30 = $uglygep3$i$i$i$i$i >>> 2;
   $31 = $30 ^ -1;
   $scevgep4$i$i$i$i$i = (($27) + ($31<<2)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($25);
 }
 $32 = HEAP8[$4>>0]|0;
 $33 = $32 & 1;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  $35 = (($this) + 72|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($36|0),($$byval_copy2|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   ___cxa_call_unexpected(($39|0));
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3558,($this|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZN6Shader8PostLoadEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$02$i = 0, $$03$i = 0, $$05$i = 0, $$14$i = 0, $$16$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i7$i = 0, $i$023$i = 0, $lpad$phi$i$index = 0;
 var $lpad$phi$i$index2 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($this) + 56|0);
  HEAP32[$6>>2] = 0;
  $7 = (($this) + 60|0);
  HEAP32[$7>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZN9ShaderLab9IntShader8PostLoadEv($4);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($this) + 60|0);
 $10 = HEAP8[642552>>0]|0;
 $11 = ($10<<24>>24)==(0);
 do {
  if ($11) {
   HEAP8[$0>>0] = 18;
   $12 = (($0) + 1|0);
   dest=$12+0|0; src=642560+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $13 = (($0) + 10|0);
   HEAP8[$13>>0] = 0;
   __THREW__ = 0;
   $14 = (invoke_ii(3224,($0|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP8[$0>>0]|0;
    $18 = $17 & 1;
    $19 = ($18<<24>>24)==(0);
    if (!($19)) {
     $20 = (($0) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     __ZdlPv($21);
    }
    HEAP32[642544>>2] = $14;
    HEAP8[642552>>0] = 1;
    break;
   }
   $97 = ___cxa_find_matching_catch()|0;
   $98 = tempRet0;
   $99 = HEAP8[$0>>0]|0;
   $100 = $99 & 1;
   $101 = ($100<<24>>24)==(0);
   if ($101) {
    $$14$i = $97;$$16$i = $98;
    ___resumeException($$14$i|0);
    // unreachable;
   }
   $102 = (($0) + 8|0);
   $103 = HEAP32[$102>>2]|0;
   __ZdlPv($103);
   $$14$i = $97;$$16$i = $98;
   ___resumeException($$14$i|0);
   // unreachable;
  }
 } while(0);
 $22 = HEAP32[$8>>2]|0;
 $23 = (($8) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22|0)==($24|0);
 L18: do {
  if ($25) {
   label = 46;
  } else {
   $26 = (($2) + 1|0);
   $27 = (($1) + 1|0);
   $28 = (($1) + 8|0);
   $29 = (($2) + 8|0);
   $30 = (($2) + 4|0);
   $125 = $24;$32 = $22;
   L20: while(1) {
    $31 = HEAP32[$32>>2]|0;
    $33 = (($31) + 16|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)>(0);
    if ($35) {
     $i$023$i = 0;
     while(1) {
      $36 = HEAP32[$31>>2]|0;
      $37 = (($36) + ($i$023$i<<2)|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($38) + 668|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($38) + 668|0);
      $42 = ($40|0)==(0|0);
      do {
       if (!($42)) {
        $43 = HEAP32[642544>>2]|0;
        $$0$ph7$i$i$i$i = $41;$$01$ph6$i$in$i$i$i = $40;
        L28: while(1) {
         $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
         while(1) {
          $44 = (($$013$i$in$i$i$i) + 16|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = ($45|0)<($43|0);
          if (!($46)) {
           break;
          }
          $49 = (($$013$i$in$i$i$i) + 4|0);
          $50 = HEAP32[$49>>2]|0;
          $51 = ($50|0)==(0|0);
          if ($51) {
           $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
           break L28;
          } else {
           $$013$i$in$i$i$i = $50;
          }
         }
         $47 = HEAP32[$$013$i$in$i$i$i>>2]|0;
         $48 = ($47|0)==(0|0);
         if ($48) {
          $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
          break;
         } else {
          $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $47;
         }
        }
        $52 = ($$0$ph5$i$i$i$i|0)==($41|0);
        if (!($52)) {
         $53 = (($$0$ph5$i$i$i$i) + 16|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = ($43|0)<($54|0);
         if (!($55)) {
          $56 = (($$0$ph5$i$i$i$i) + 20|0);
          $57 = HEAP32[$56>>2]|0;
          __ZN9ShaderLab16GetShaderTagNameEi($1,$57);
          $58 = (_strlen((653424|0))|0);
          $59 = ($58>>>0)>(4294967279);
          if ($59) {
           label = 21;
           break L20;
          }
          $62 = ($58>>>0)<(11);
          if ($62) {
           $63 = $58 << 1;
           $64 = $63&255;
           HEAP8[$2>>0] = $64;
           $78 = $64;$__p$0$i$i$i7$i = $26;
          } else {
           $65 = (($58) + 16)|0;
           $66 = $65 & -16;
           __THREW__ = 0;
           $67 = (invoke_ii(2988,($66|0))|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            label = 36;
            break L20;
           }
           HEAP32[$29>>2] = $67;
           $70 = $66 | 1;
           HEAP32[$2>>2] = $70;
           HEAP32[$30>>2] = $58;
           $71 = $70&255;
           $78 = $71;$__p$0$i$i$i7$i = $67;
          }
          _memcpy(($__p$0$i$i$i7$i|0),(653424|0),($58|0))|0;
          $72 = (($__p$0$i$i$i7$i) + ($58)|0);
          HEAP8[$72>>0] = 0;
          $73 = HEAP8[$1>>0]|0;
          $74 = $73 & 1;
          $75 = ($74<<24>>24)==(0);
          $76 = HEAP32[$28>>2]|0;
          $$$i = $75 ? $27 : $76;
          $77 = $78 & 1;
          $79 = ($77<<24>>24)==(0);
          $80 = HEAP32[$29>>2]|0;
          $81 = $79 ? $26 : $80;
          __THREW__ = 0;
          $82 = (invoke_iii(2448,($$$i|0),($81|0))|0);
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           label = 39;
           break L20;
          }
          $85 = ($82|0)==(0);
          $86 = HEAP8[$2>>0]|0;
          $87 = $86 & 1;
          $88 = ($87<<24>>24)==(0);
          if (!($88)) {
           $89 = HEAP32[$29>>2]|0;
           __ZdlPv($89);
          }
          $90 = HEAP8[$1>>0]|0;
          $91 = $90 & 1;
          $92 = ($91<<24>>24)==(0);
          if ($92) {
           if ($85) {
            label = 33;
            break L20;
           } else {
            break;
           }
          } else {
           $93 = HEAP32[$28>>2]|0;
           __ZdlPv($93);
           if ($85) {
            label = 33;
            break L20;
           } else {
            break;
           }
          }
         }
        }
       }
      } while(0);
      $118 = (($i$023$i) + 1)|0;
      $119 = HEAP32[$33>>2]|0;
      $120 = ($118|0)<($119|0);
      if ($120) {
       $i$023$i = $118;
      } else {
       break;
      }
     }
     $$pre$i = HEAP32[$23>>2]|0;
     $123 = $$pre$i;
    } else {
     $123 = $125;
    }
    $121 = (($32) + 4|0);
    $122 = ($121|0)==($123|0);
    if ($122) {
     label = 46;
     break L18;
    } else {
     $125 = $123;$32 = $121;
    }
   }
   do {
    if ((label|0) == 21) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      $106 = ___cxa_find_matching_catch()|0;
      $107 = tempRet0;
      $lpad$phi$i$index = $106;$lpad$phi$i$index2 = $107;
      label = 38;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 33) {
     HEAP32[$9>>2] = $i$023$i;
     $94 = HEAP32[$31>>2]|0;
     $95 = (($94) + ($i$023$i<<2)|0);
     $96 = HEAP32[$95>>2]|0;
     $$02$i = $96;
     break L18;
    }
    else if ((label|0) == 36) {
     $104 = ___cxa_find_matching_catch()|0;
     $105 = tempRet0;
     $lpad$phi$i$index = $104;$lpad$phi$i$index2 = $105;
     label = 38;
    }
    else if ((label|0) == 39) {
     $108 = ___cxa_find_matching_catch()|0;
     $109 = tempRet0;
     $110 = HEAP8[$2>>0]|0;
     $111 = $110 & 1;
     $112 = ($111<<24>>24)==(0);
     if ($112) {
      $$03$i = $108;$$05$i = $109;
     } else {
      $113 = HEAP32[$29>>2]|0;
      __ZdlPv($113);
      $$03$i = $108;$$05$i = $109;
     }
    }
   } while(0);
   if ((label|0) == 38) {
    $$03$i = $lpad$phi$i$index;$$05$i = $lpad$phi$i$index2;
   }
   $114 = HEAP8[$1>>0]|0;
   $115 = $114 & 1;
   $116 = ($115<<24>>24)==(0);
   if ($116) {
    $$14$i = $$03$i;$$16$i = $$05$i;
    ___resumeException($$14$i|0);
    // unreachable;
   }
   $117 = HEAP32[$28>>2]|0;
   __ZdlPv($117);
   $$14$i = $$03$i;$$16$i = $$05$i;
   ___resumeException($$14$i|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 46) {
  HEAP32[$9>>2] = 0;
  $$02$i = 0;
 }
 $124 = (($this) + 56|0);
 HEAP32[$124>>2] = $$02$i;
 STACKTOP = sp;return;
}
function __ZN6Shader10GetDefaultEv() {
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[642152>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $27 = $1;
  STACKTOP = sp;return ($27|0);
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 27;
 dest=$3+0|0; src=642160+0|0; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 27|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 $7 = (invoke_i(58)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  $10 = (invoke_iiii(1532,($7|0),48,($0|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   HEAP32[642152>>2] = $10;
   $13 = HEAP8[$0>>0]|0;
   $14 = $13 & 1;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $18 = $10;
   } else {
    $16 = HEAP32[$4>>2]|0;
    __ZdlPv($16);
    $$pr = HEAP32[642152>>2]|0;
    $18 = $$pr;
   }
   $17 = ($18|0)==(0|0);
   if ($17) {
    $27 = 0;
    STACKTOP = sp;return ($27|0);
   }
   $19 = (($18) + 52|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[642144>>2] = $20;
   $27 = $18;
   STACKTOP = sp;return ($27|0);
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $23 = HEAP8[$0>>0]|0;
 $24 = $23 & 1;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  ___resumeException($21|0);
  // unreachable;
 }
 $26 = HEAP32[$4>>2]|0;
 __ZdlPv($26);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZN6Shader18LoadDefaultShadersEv() {
 var $$pr$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[642152>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 27;
 dest=$3+0|0; src=642160+0|0; stop=dest+27|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 27|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 $7 = (invoke_i(58)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  $10 = (invoke_iiii(1532,($7|0),48,($0|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   HEAP32[642152>>2] = $10;
   $13 = HEAP8[$0>>0]|0;
   $14 = $13 & 1;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $18 = $10;
   } else {
    $16 = HEAP32[$4>>2]|0;
    __ZdlPv($16);
    $$pr$i = HEAP32[642152>>2]|0;
    $18 = $$pr$i;
   }
   $17 = ($18|0)==(0|0);
   if ($17) {
    STACKTOP = sp;return;
   }
   $19 = (($18) + 52|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[642144>>2] = $20;
   STACKTOP = sp;return;
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $23 = HEAP8[$0>>0]|0;
 $24 = $23 & 1;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  ___resumeException($21|0);
  // unreachable;
 }
 $26 = HEAP32[$4>>2]|0;
 __ZdlPv($26);
 ___resumeException($21|0);
 // unreachable;
}
function __ZN6Shader17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($this|0)==(0|0);
 if (!($1)) {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0);
  if ($4) {
  }
 }
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[642144>>2]|0;
 $8 = ($6|0)==($7|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[628272>>2]|0;
 $10 = ($6|0)==(0|0);
 if (!($10)) {
  __ZN9ShaderLab9IntShaderD2Ev($6);
 }
 HEAP32[$0>>2] = $9;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy);
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK6Shader14MakePropertiesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK9ShaderLab9IntShader14MakePropertiesEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN6Shader7SetPassEiijPKN9ShaderLab13PropertySheetERKNS0_17ShaderPassContextE($this,$subshaderIndex,$passNo,$stateKey,$props,$passContext) {
 $this = $this|0;
 $subshaderIndex = $subshaderIndex|0;
 $passNo = $passNo|0;
 $stateKey = $stateKey|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($subshaderIndex<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($passNo<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN9ShaderLab4Pass9ApplyPassEjPKNS_13PropertySheetERKNS_17ShaderPassContextEP6Shaderi($7,$stateKey,$props,$passContext,$this,$passNo)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZNK6Shader17CanPassBeRecordedEii($this,$subshaderIndex,$passNo) {
 $this = $this|0;
 $subshaderIndex = $subshaderIndex|0;
 $passNo = $passNo|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($subshaderIndex<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($passNo<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 640|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(2);
 if ($10) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $11 = (($7) + 356|0);
 $12 = HEAP8[$11>>0]|0;
 $not$$i = ($12<<24>>24)==(0);
 $$0$i = $not$$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN6Shader24GetShadowCasterPassToUseEiRi($this,$subshaderIndex,$outPassIndex) {
 $this = $this|0;
 $subshaderIndex = $subshaderIndex|0;
 $outPassIndex = $outPassIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$outPassIndex>>2] = 0;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($subshaderIndex<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 43|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($4) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(-1);
 if ($10) {
  HEAP32[$outPassIndex>>2] = $9;
  $11 = HEAP32[$4>>2]|0;
  $12 = (($11) + ($9<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 } else {
  $14 = (($this) + 60|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$outPassIndex>>2] = $15;
  $16 = (($this) + 56|0);
  $17 = HEAP32[$16>>2]|0;
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK6Shader23GetActiveSubShaderIndexEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN6Shader9SetScriptERK8UnityStr($this,$script) {
 $this = $this|0;
 $script = $script|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity8Material29ResetAllMaterialsCachedPassesEv();
 __ZN9TextAsset18SetScriptDontDirtyERK8UnityStr($this,$script);
 $0 = (($this) + 56|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 60|0);
 HEAP32[$1>>2] = 0;
 $2 = HEAP8[$script>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $9 = (($script) + 1|0);
  $10 = $2&255;
  $11 = $10 >>> 1;
  $12 = $9;$13 = $11;
 } else {
  $5 = (($script) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($script) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $12 = $6;$13 = $8;
 }
 __ZN6Shader5ParseEPKcj($this,$12,$13);
 __ZN6Shader8PostLoadEv($this);
 $14 = (($this) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[642144>>2]|0;
 $17 = ($15|0)!=($16|0);
 STACKTOP = sp;return ($17|0);
}
function __ZN6Shader5ParseEPKcj($this,$str,$strLength) {
 $this = $this|0;
 $str = $str|0;
 $strLength = $strLength|0;
 var $$byval_copy17 = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf = 0, $errors = 0, $or$cond = 0, $parsedForm = 0, $phitmp$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy17 = sp;
 $0 = sp + 24|0;
 $1 = sp + 4|0;
 $errors = sp + 8|0;
 $parsedForm = sp + 20|0;
 $buf = sp + 32|0;
 $2 = (($this) + 89|0);
 HEAP8[$2>>0] = 0;
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[642144>>2]|0;
 $6 = ($4|0)==($5|0);
 if (!($6)) {
  $7 = (($this) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $$pre = HEAP32[$3>>2]|0;
   $12 = $$pre;
  } else {
   $12 = $4;
  }
  $10 = HEAP32[628272>>2]|0;
  $11 = ($12|0)==(0|0);
  if (!($11)) {
   __ZN9ShaderLab9IntShaderD2Ev($12);
  }
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($12,$$byval_copy17);
  HEAP32[$3>>2] = 0;
 }
 $13 = (($errors) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($errors) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($errors) + 4|0);
 HEAP32[$errors>>2] = $15;
 HEAP32[$parsedForm>>2] = 0;
 $16 = (($this) + 88|0);
 $17 = HEAP8[$16>>0]|0;
 __THREW__ = 0;
 $18 = (invoke_i(59)|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 L10: do {
  if (!($20)) {
   $21 = ($17<<24>>24)!=(0);
   $22 = (($this) + 76|0);
   $23 = (($18) + 5928|0);
   $24 = HEAP32[$23>>2]|0;
   __THREW__ = 0;
   $25 = (invoke_iiiiiiiii(41,($str|0),($strLength|0),($22|0),($21|0),($parsedForm|0),($errors|0),($24|0),($this|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    HEAP32[$3>>2] = $25;
    $28 = HEAP32[$parsedForm>>2]|0;
    $29 = HEAP32[628272>>2]|0;
    $30 = ($28|0)==(0|0);
    if (!($30)) {
     __THREW__ = 0;
     invoke_vi(3578,($28|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
    }
    HEAP32[$0>>2] = $29;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($28|0),($$byval_copy17|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     HEAP32[$parsedForm>>2] = 0;
     $35 = (($this) + 56|0);
     HEAP32[$35>>2] = 0;
     $36 = (($this) + 60|0);
     HEAP32[$36>>2] = 0;
     $37 = (($this) + 64|0);
     $38 = HEAP8[674240>>0]|0;
     $39 = $38 & 1;
     $40 = ($39<<24>>24)==(0);
     if ($40) {
      $43 = $38&255;
      $44 = $43 >>> 1;
      $53 = $44;$61 = ((674240 + 1|0));
     } else {
      $41 = HEAP32[((674240 + 8|0))>>2]|0;
      $42 = HEAP32[((674240 + 4|0))>>2]|0;
      $53 = $42;$61 = $41;
     }
     $45 = HEAP8[$37>>0]|0;
     $46 = $45 & 1;
     $47 = ($46<<24>>24)==(0);
     if ($47) {
      $52 = 10;$55 = $45;
     } else {
      $48 = HEAP32[$37>>2]|0;
      $49 = $48 & -2;
      $phitmp$i$i = (($49) + -1)|0;
      $50 = $48&255;
      $52 = $phitmp$i$i;$55 = $50;
     }
     $51 = ($52>>>0)<($53>>>0);
     $54 = $55 & 1;
     $56 = ($54<<24>>24)==(0);
     do {
      if ($51) {
       if ($56) {
        $71 = $55&255;
        $72 = $71 >>> 1;
        $74 = $72;
       } else {
        $69 = (($this) + 68|0);
        $70 = HEAP32[$69>>2]|0;
        $74 = $70;
       }
       $73 = (($53) - ($52))|0;
       __THREW__ = 0;
       invoke_viiiiiiii(22,($37|0),($52|0),($73|0),($74|0),0,($74|0),($53|0),($61|0));
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        break L10;
       }
      } else {
       if ($56) {
        $59 = (($37) + 1|0);
        $60 = $59;
       } else {
        $57 = (($this) + 72|0);
        $58 = HEAP32[$57>>2]|0;
        $60 = $58;
       }
       _memmove(($60|0),($61|0),($53|0))|0;
       $62 = (($60) + ($53)|0);
       HEAP8[$62>>0] = 0;
       $63 = HEAP8[$37>>0]|0;
       $64 = $63 & 1;
       $65 = ($64<<24>>24)==(0);
       if ($65) {
        $67 = $53 << 1;
        $68 = $67&255;
        HEAP8[$37>>0] = $68;
        break;
       } else {
        $66 = (($this) + 68|0);
        HEAP32[$66>>2] = $53;
        break;
       }
      }
     } while(0);
     $77 = HEAP8[((640792 + 128|0))>>0]|0;
     $78 = ($77<<24>>24)==(0);
     if ($78) {
      $79 = HEAP32[$3>>2]|0;
      $80 = ($79|0)!=(0|0);
      $81 = HEAP32[642144>>2]|0;
      $82 = ($81|0)!=(0|0);
      $or$cond = $80 & $82;
      if ($or$cond) {
       $83 = (($79) + 32|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = HEAP32[$79>>2]|0;
       $86 = (($85) + ($84<<2)|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = (($87) + 42|0);
       $89 = HEAP8[$88>>0]|0;
       $90 = ($89<<24>>24)==(0);
       if ($90) {
        label = 37;
       } else {
        __THREW__ = 0;
        invoke_vii(2587,(642192|0),($$byval_copy17|0));
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         break;
        }
        $93 = HEAP8[$37>>0]|0;
        $94 = $93 & 1;
        $95 = ($94<<24>>24)==(0);
        if ($95) {
         $98 = (($37) + 1|0);
         $99 = $98;
        } else {
         $96 = (($this) + 72|0);
         $97 = HEAP32[$96>>2]|0;
         $99 = $97;
        }
        __THREW__ = 0;
        HEAP32[$$byval_copy17>>2] = $99;
        invoke_vii(2587,(642216|0),($$byval_copy17|0));
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         break;
        }
        $102 = HEAP32[642144>>2]|0;
        $103 = (($102) + 32|0);
        $104 = HEAP32[$103>>2]|0;
        $105 = HEAP32[$102>>2]|0;
        $106 = (($105) + ($104<<2)|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = HEAP32[$107>>2]|0;
        $109 = HEAP32[$108>>2]|0;
        __THREW__ = 0;
        invoke_vii(3240,($87|0),($109|0));
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         break;
        } else {
         label = 37;
        }
       }
      } else {
       $113 = $79;
      }
     } else {
      label = 37;
     }
     if ((label|0) == 37) {
      $$pr = HEAP32[$3>>2]|0;
      $113 = $$pr;
     }
     $112 = ($113|0)==(0|0);
     if ($112) {
      __THREW__ = 0;
      invoke_vii(2587,(642192|0),($$byval_copy17|0));
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       break;
      }
      $116 = HEAP8[$37>>0]|0;
      $117 = $116 & 1;
      $118 = ($117<<24>>24)==(0);
      if ($118) {
       $121 = (($37) + 1|0);
       $122 = $121;
      } else {
       $119 = (($this) + 72|0);
       $120 = HEAP32[$119>>2]|0;
       $122 = $120;
      }
      __THREW__ = 0;
      HEAP32[$$byval_copy17>>2] = $122;
      invoke_vii(2587,(642264|0),($$byval_copy17|0));
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       break;
      }
      $125 = HEAP32[642144>>2]|0;
      HEAP32[$3>>2] = $125;
      $168 = HEAP32[$13>>2]|0;
      __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($errors,$168);
      STACKTOP = sp;return;
     }
     $126 = HEAP32[$113>>2]|0;
     $127 = (($113) + 4|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = ($126|0)==($128|0);
     if (!($129)) {
      $168 = HEAP32[$13>>2]|0;
      __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($errors,$168);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vii(2587,(642312|0),($$byval_copy17|0));
     $130 = __THREW__; __THREW__ = 0;
     $131 = $130&1;
     if (!($131)) {
      $132 = HEAP8[$37>>0]|0;
      $133 = $132 & 1;
      $134 = ($133<<24>>24)==(0);
      if ($134) {
       $137 = (($37) + 1|0);
       $138 = $137;
      } else {
       $135 = (($this) + 72|0);
       $136 = HEAP32[$135>>2]|0;
       $138 = $136;
      }
      __THREW__ = 0;
      HEAP32[$$byval_copy17>>2] = $138;
      invoke_vii(2587,(642328|0),($$byval_copy17|0));
      $139 = __THREW__; __THREW__ = 0;
      $140 = $139&1;
      if (!($140)) {
       $141 = HEAP32[$this>>2]|0;
       $142 = (($141) + 100|0);
       $143 = HEAP32[$142>>2]|0;
       __THREW__ = 0;
       $144 = (invoke_ii($143|0,($this|0))|0);
       $145 = __THREW__; __THREW__ = 0;
       $146 = $145&1;
       if (!($146)) {
        $147 = HEAP8[$144>>0]|0;
        $148 = $147 & 1;
        $149 = ($148<<24>>24)==(0);
        if ($149) {
         $152 = (($144) + 1|0);
         $153 = $152;
        } else {
         $150 = (($144) + 8|0);
         $151 = HEAP32[$150>>2]|0;
         $153 = $151;
        }
        HEAP32[$$byval_copy17>>2] = $153;
        (_snprintf($buf,255,642384,$$byval_copy17)|0);
        $154 = ($this|0)==(0|0);
        if ($154) {
         $157 = 0;
        } else {
         $155 = (($this) + 4|0);
         $156 = HEAP32[$155>>2]|0;
         $157 = $156;
        }
        __THREW__ = 0;
        invoke_viiiiiiii(21,($buf|0),0,(642424|0),433,1,($157|0),0,(0|0));
        $158 = __THREW__; __THREW__ = 0;
        $159 = $158&1;
        if (!($159)) {
         $160 = HEAP32[$3>>2]|0;
         $161 = HEAP32[628272>>2]|0;
         $162 = ($160|0)==(0|0);
         if (!($162)) {
          __THREW__ = 0;
          invoke_vi(3579,($160|0));
          $163 = __THREW__; __THREW__ = 0;
          $164 = $163&1;
          if ($164) {
           break;
          }
         }
         HEAP32[$1>>2] = $161;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$1+0>>2]|0;
         invoke_vii(2591,($160|0),($$byval_copy17|0));
         $165 = __THREW__; __THREW__ = 0;
         $166 = $165&1;
         if ($166) {
          break;
         }
         HEAP32[$3>>2] = 0;
         $167 = HEAP32[642144>>2]|0;
         HEAP32[$3>>2] = $167;
         $168 = HEAP32[$13>>2]|0;
         __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($errors,$168);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $169 = ___cxa_find_matching_catch()|0;
 $170 = tempRet0;
 $171 = HEAP32[$13>>2]|0;
 __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($errors,$171);
 ___resumeException($169|0);
 // unreachable;
}
function __ZN6Shader13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $8 = (($0) + 1|0);
  $9 = $1&255;
  $10 = $9 >>> 1;
  $11 = $8;$12 = $10;
 } else {
  $4 = (($this) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  $11 = $5;$12 = $7;
 }
 __ZN6Shader5ParseEPKcj($this,$11,$12);
 __ZN6Shader8PostLoadEv($this);
 STACKTOP = sp;return;
}
function __ZN6Shader21AwakeFromLoadThreadedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[642144>>2]|0;
 $3 = ($1|0)==($2|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 0;
 $4 = (($this) + 56|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 60|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 89|0);
 HEAP8[$6>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK6Shader7GetNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $9 = (($3) + 1|0);
  $10 = $9;
  STACKTOP = sp;return ($10|0);
 } else {
  $7 = (($3) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $10 = $8;
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __ZNK6Shader11IsSupportedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[642144>>2]|0;
 $3 = ($1|0)!=($2|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNK6Shader24GetSubShaderWithTagValueEii($this,$tagNameID,$tagValueID) {
 $this = $this|0;
 $tagNameID = $tagNameID|0;
 $tagValueID = $tagValueID|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($1) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $7 = $2;$idx$06 = 0;
 }
 while(1) {
  $6 = HEAP32[$7>>2]|0;
  $8 = (($6) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 24|0);
  $11 = ($9|0)==(0|0);
  if (!($11)) {
   $$0$ph7$i$i$i = $10;$$01$ph6$i$in$i$i = $9;
   L6: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $12 = (($$013$i$in$i$i) + 16|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)<($tagNameID|0);
     if (!($14)) {
      break;
     }
     $17 = (($$013$i$in$i$i) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L6;
     } else {
      $$013$i$in$i$i = $18;
     }
    }
    $15 = HEAP32[$$013$i$in$i$i>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $15;
    }
   }
   $20 = ($$0$ph5$i$i$i|0)==($10|0);
   if (!($20)) {
    $21 = (($$0$ph5$i$i$i) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)>($tagNameID|0);
    if (!($23)) {
     $24 = (($$0$ph5$i$i$i) + 20|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($tagValueID|0);
     if ($26) {
      $$0 = $idx$06;
      label = 11;
      break;
     }
    }
   }
  }
  $27 = (($idx$06) + 1)|0;
  $28 = (($7) + 4|0);
  $29 = ($28|0)==($4|0);
  if ($29) {
   $$0 = -1;
   label = 11;
   break;
  } else {
   $7 = $28;$idx$06 = $27;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN6Shader13GetDependencyERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZNK9ShaderLab9IntShader13GetDependencyERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($1,$name)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP8[$3>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = $5&255;
  $11 = $10 >>> 1;
  $13 = $11;
 } else {
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $13 = $9;
 }
 $12 = ($13|0)==(0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($this) + 76|0);
 $15 = (($this) + 88|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (__Z19FindShaderLabShaderRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_6vectorI4PPtrI6ShaderENS3_ISB_EEEEb($3,$14,$17)|0);
 $$0 = $18;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6Shader16DeleteAllShadersERNSt3__16vectorIiNS0_9allocatorIiEEEE($outShaderObjects) {
 $outShaderObjects = $outShaderObjects|0;
 var $$0$i = 0, $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $temp$0$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$outShaderObjects>>2]|0;
 $3 = (($outShaderObjects) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $__new_last2$i$i$i = $2;
  $scevgep$i$i$i = (($4) + -4|0);
  $6 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($6)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $7 = $uglygep3$i$i$i >>> 2;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i = (($4) + ($8<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i;
 }
 (__ZN6Object21FindAllDerivedObjectsEiPNSt3__16vectorIiNS0_9allocatorIiEEEEb(48,$outShaderObjects,0)|0);
 $9 = HEAP32[$outShaderObjects>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = ($9|0)==($10|0);
 if ($11) {
  __ZN5Unity8Material29ResetAllMaterialsCachedPassesEv();
  STACKTOP = sp;return;
 }
 $13 = $9;
 while(1) {
  $12 = HEAP32[$13>>2]|0;
  $14 = ($12|0)==(0);
  if ($14) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $12;
   $15 = HEAP32[560624>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    label = 14;
   } else {
    $17 = (($15) + 36|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    do {
     if ($21) {
      $22 = (($15) + 28|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = (($15) + 32|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($23) + ($25<<3)|0);
      $42 = $26;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$15,$0);
      $27 = HEAP32[$$byval_copy>>2]|0;
      $28 = ($27|0)==(-1);
      $29 = (($15) + 28|0);
      $30 = HEAP32[$29>>2]|0;
      if ($28) {
       $31 = (($15) + 32|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($30) + ($32<<3)|0);
       $42 = $33;
       break;
      } else {
       $34 = (($30) + ($27<<3)|0);
       $42 = $34;
       break;
      }
     }
    } while(0);
    $35 = HEAP32[560624>>2]|0;
    $36 = (($35) + 28|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($35) + 32|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($37) + ($39<<3)|0);
    $41 = ($42|0)==($40|0);
    if ($41) {
     label = 14;
    } else {
     $43 = (($42) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==(0|0);
     if ($45) {
      label = 14;
     } else {
      $temp$0$i = $44;
     }
    }
   }
   if ((label|0) == 14) {
    label = 0;
    $46 = (__Z31ReadObjectFromPersistentManageri($12)|0);
    $temp$0$i = $46;
   }
   $$0$i = $temp$0$i;
  }
  $47 = (($$0$i) + 52|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = HEAP32[642144>>2]|0;
  $50 = ($48|0)==($49|0);
  if (!($50)) {
   $51 = ($$0$i|0)==(0|0);
   if ($51) {
    $57 = $48;
   } else {
    $52 = (($$0$i) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0);
    if ($54) {
     $$pre = HEAP32[$47>>2]|0;
     $57 = $$pre;
    } else {
     $57 = $48;
    }
   }
   $55 = HEAP32[628272>>2]|0;
   $56 = ($57|0)==(0|0);
   if (!($56)) {
    __ZN9ShaderLab9IntShaderD2Ev($57);
   }
   HEAP32[$1>>2] = $55;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($57,$$byval_copy);
   HEAP32[$47>>2] = 0;
   $58 = (($$0$i) + 56|0);
   HEAP32[$58>>2] = 0;
   $59 = (($$0$i) + 60|0);
   HEAP32[$59>>2] = 0;
   $60 = (($$0$i) + 89|0);
   HEAP8[$60>>0] = 1;
  }
  $61 = (($13) + 4|0);
  $62 = HEAP32[$3>>2]|0;
  $63 = ($61|0)==($62|0);
  if ($63) {
   break;
  } else {
   $13 = $61;
  }
 }
 __ZN5Unity8Material29ResetAllMaterialsCachedPassesEv();
 STACKTOP = sp;return;
}
function __ZN6Shader18RecreateAllShadersERKNSt3__16vectorIiNS0_9allocatorIiEEEE($shaderObjects) {
 $shaderObjects = $shaderObjects|0;
 var $$0$i = 0, $$lcssa$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1$i = 0, $allMaterials$i = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index2 = 0, $pos$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2$i = 0, $scevgep4$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6$i = 0, $temp$0$i = 0;
 var $temp$0$i15$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4$i = 0, $uglygep3$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $allMaterials$i = sp + 8|0;
 $2 = HEAP32[$shaderObjects>>2]|0;
 $3 = (($shaderObjects) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  $7 = $2;
  while(1) {
   $6 = HEAP32[$7>>2]|0;
   $8 = ($6|0)==(0);
   if ($8) {
    $$0$i = 0;
   } else {
    HEAP32[$0>>2] = $6;
    $9 = HEAP32[560624>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     label = 12;
    } else {
     $11 = (($9) + 36|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($9) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($12|0)==($14|0);
     do {
      if ($15) {
       $16 = (($9) + 28|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = (($9) + 32|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($17) + ($19<<3)|0);
       $36 = $20;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$9,$0);
       $21 = HEAP32[$pos$i$i$i$i>>2]|0;
       $22 = ($21|0)==(-1);
       $23 = (($9) + 28|0);
       $24 = HEAP32[$23>>2]|0;
       if ($22) {
        $25 = (($9) + 32|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = (($24) + ($26<<3)|0);
        $36 = $27;
        break;
       } else {
        $28 = (($24) + ($21<<3)|0);
        $36 = $28;
        break;
       }
      }
     } while(0);
     $29 = HEAP32[560624>>2]|0;
     $30 = (($29) + 28|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($29) + 32|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + ($33<<3)|0);
     $35 = ($36|0)==($34|0);
     if ($35) {
      label = 12;
     } else {
      $37 = (($36) + 4|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38|0)==(0|0);
      if ($39) {
       label = 12;
      } else {
       $temp$0$i = $38;
      }
     }
    }
    if ((label|0) == 12) {
     label = 0;
     $40 = (__Z31ReadObjectFromPersistentManageri($6)|0);
     $temp$0$i = $40;
    }
    $$0$i = $temp$0$i;
   }
   $41 = HEAP32[642152>>2]|0;
   $42 = ($$0$i|0)==($41|0);
   if (!($42)) {
    $43 = (($$0$i) + 40|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = $44 & 1;
    $46 = ($45<<24>>24)==(0);
    if ($46) {
     $51 = (($43) + 1|0);
     $52 = $44&255;
     $53 = $52 >>> 1;
     $54 = $51;$55 = $53;
    } else {
     $47 = (($$0$i) + 48|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($$0$i) + 44|0);
     $50 = HEAP32[$49>>2]|0;
     $54 = $48;$55 = $50;
    }
    __ZN6Shader5ParseEPKcj($$0$i,$54,$55);
    __ZN6Shader8PostLoadEv($$0$i);
   }
   $56 = (($7) + 4|0);
   $57 = HEAP32[$3>>2]|0;
   $58 = ($56|0)==($57|0);
   if ($58) {
    break;
   } else {
    $7 = $56;
   }
  }
 }
 HEAP32[$allMaterials$i>>2] = 0;
 $59 = (($allMaterials$i) + 4|0);
 HEAP32[$59>>2] = 0;
 $60 = (($allMaterials$i) + 8|0);
 HEAP32[$60>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1536,21,($allMaterials$i|0),0)|0);
 $61 = __THREW__; __THREW__ = 0;
 $62 = $61&1;
 L29: do {
  if ($62) {
   $108 = ___cxa_find_matching_catch()|0;
   $109 = tempRet0;
   $lpad$phi$i$index = $108;$lpad$phi$i$index2 = $109;
  } else {
   $63 = HEAP32[$allMaterials$i>>2]|0;
   $64 = HEAP32[$59>>2]|0;
   $65 = ($63|0)==($64|0);
   do {
    if ($65) {
     $$lcssa$i = $63;$121 = $63;
    } else {
     $67 = $63;
     L33: while(1) {
      $66 = HEAP32[$67>>2]|0;
      $68 = ($66|0)==(0);
      do {
       if (!($68)) {
        HEAP32[$1>>2] = $66;
        $69 = HEAP32[560624>>2]|0;
        $70 = ($69|0)==(0|0);
        if ($70) {
         label = 32;
        } else {
         $71 = (($69) + 36|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = (($69) + 4|0);
         $74 = HEAP32[$73>>2]|0;
         $75 = ($72|0)==($74|0);
         do {
          if ($75) {
           $76 = (($69) + 28|0);
           $77 = HEAP32[$76>>2]|0;
           $78 = (($69) + 32|0);
           $79 = HEAP32[$78>>2]|0;
           $80 = (($77) + ($79<<3)|0);
           $96 = $80;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$69,$1);
           $81 = HEAP32[$pos$i$i$i$i>>2]|0;
           $82 = ($81|0)==(-1);
           $83 = (($69) + 28|0);
           $84 = HEAP32[$83>>2]|0;
           if ($82) {
            $85 = (($69) + 32|0);
            $86 = HEAP32[$85>>2]|0;
            $87 = (($84) + ($86<<3)|0);
            $96 = $87;
            break;
           } else {
            $88 = (($84) + ($81<<3)|0);
            $96 = $88;
            break;
           }
          }
         } while(0);
         $89 = HEAP32[560624>>2]|0;
         $90 = (($89) + 28|0);
         $91 = HEAP32[$90>>2]|0;
         $92 = (($89) + 32|0);
         $93 = HEAP32[$92>>2]|0;
         $94 = (($91) + ($93<<3)|0);
         $95 = ($96|0)==($94|0);
         if ($95) {
          label = 32;
         } else {
          $97 = (($96) + 4|0);
          $98 = HEAP32[$97>>2]|0;
          $99 = ($98|0)==(0|0);
          if ($99) {
           label = 32;
          } else {
           $temp$0$i15$i = $98;
          }
         }
        }
        if ((label|0) == 32) {
         label = 0;
         __THREW__ = 0;
         $100 = (invoke_ii(3215,($66|0))|0);
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          label = 35;
          break L33;
         }
         $103 = ($100|0)==(0|0);
         if ($103) {
          break;
         } else {
          $temp$0$i15$i = $100;
         }
        }
        __THREW__ = 0;
        invoke_vi(3580,($temp$0$i15$i|0));
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if ($105) {
         label = 35;
         break L33;
        }
       }
      } while(0);
      $117 = (($67) + 4|0);
      $118 = HEAP32[$59>>2]|0;
      $119 = ($117|0)==($118|0);
      if ($119) {
       label = 42;
       break;
      } else {
       $67 = $117;
      }
     }
     if ((label|0) == 35) {
      $106 = ___cxa_find_matching_catch()|0;
      $107 = tempRet0;
      $lpad$phi$i$index = $106;$lpad$phi$i$index2 = $107;
      break L29;
     }
     else if ((label|0) == 42) {
      $$pre$i = HEAP32[$allMaterials$i>>2]|0;
      $$lcssa$i = $117;$121 = $$pre$i;
      break;
     }
    }
   } while(0);
   $120 = ($121|0)==(0|0);
   if ($120) {
    STACKTOP = sp;return;
   }
   $122 = ($$lcssa$i|0)==($121|0);
   if (!($122)) {
    $__new_last2$i$i$i$i$i$i = $121;
    $scevgep$i$i$i$i$i$i = (($$lcssa$i) + -4|0);
    $123 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($123)|0);
    $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
    $124 = $uglygep3$i$i$i$i$i$i >>> 2;
    $125 = $124 ^ -1;
    $scevgep4$i$i$i$i$i$i = (($$lcssa$i) + ($125<<2)|0);
    HEAP32[$59>>2] = $scevgep4$i$i$i$i$i$i;
   }
   __ZdlPv($121);
   STACKTOP = sp;return;
  }
 } while(0);
 $110 = HEAP32[$allMaterials$i>>2]|0;
 $111 = ($110|0)==(0|0);
 if ($111) {
  ___resumeException($lpad$phi$i$index|0);
  // unreachable;
 }
 $112 = HEAP32[$59>>2]|0;
 $113 = ($112|0)==($110|0);
 if (!($113)) {
  $__new_last2$i$i$i$i$i1$i = $110;
  $scevgep$i$i$i$i$i2$i = (($112) + -4|0);
  $114 = (0 - ($__new_last2$i$i$i$i$i1$i))|0;
  $uglygep$i$i$i$i$i4$i = (($scevgep$i$i$i$i$i2$i) + ($114)|0);
  $uglygep3$i$i$i$i$i5$i = $uglygep$i$i$i$i$i4$i;
  $115 = $uglygep3$i$i$i$i$i5$i >>> 2;
  $116 = $115 ^ -1;
  $scevgep4$i$i$i$i$i6$i = (($112) + ($116<<2)|0);
  HEAP32[$59>>2] = $scevgep4$i$i$i$i$i6$i;
 }
 __ZdlPv($110);
 ___resumeException($lpad$phi$i$index|0);
 // unreachable;
}
function __ZN6Shader16ReloadAllShadersEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $derivedObjects = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $derivedObjects = sp;
 HEAP32[$derivedObjects>>2] = 0;
 $0 = (($derivedObjects) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($derivedObjects) + 8|0);
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vi(3581,($derivedObjects|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3582,($derivedObjects|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[$derivedObjects>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    STACKTOP = sp;return;
   }
   $8 = HEAP32[$0>>2]|0;
   $9 = ($8|0)==($6|0);
   if (!($9)) {
    $__new_last2$i$i$i$i$i1 = $6;
    $scevgep$i$i$i$i$i2 = (($8) + -4|0);
    $10 = (0 - ($__new_last2$i$i$i$i$i1))|0;
    $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($10)|0);
    $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
    $11 = $uglygep3$i$i$i$i$i5 >>> 2;
    $12 = $11 ^ -1;
    $scevgep4$i$i$i$i$i6 = (($8) + ($12<<2)|0);
    HEAP32[$0>>2] = $scevgep4$i$i$i$i$i6;
   }
   __ZdlPv($6);
   STACKTOP = sp;return;
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $15 = HEAP32[$derivedObjects>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  ___resumeException($13|0);
  // unreachable;
 }
 $17 = HEAP32[$0>>2]|0;
 $18 = ($17|0)==($15|0);
 if (!($18)) {
  $__new_last2$i$i$i$i$i = $15;
  $scevgep$i$i$i$i$i = (($17) + -4|0);
  $19 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($19)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $20 = $uglygep3$i$i$i$i$i >>> 2;
  $21 = $20 ^ -1;
  $scevgep4$i$i$i$i$i = (($17) + ($21<<2)|0);
  HEAP32[$0>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($15);
 ___resumeException($13|0);
 // unreachable;
}
function __ZN6Shader25GetGlobalMaximumShaderLODEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2147483647;
}
function __ZN6Shader19MarkShaderHasErrorsEPS_($shader) {
 $shader = $shader|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($shader|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 0;
 } else {
  $2 = (($shader) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $3;
 }
 __ZN13dynamic_arrayI4PPtrI6ShaderELj4EE9push_backERKS2_(642000,$0);
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI4PPtrI6ShaderELj4EE9push_backERKS2_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if (!($7)) {
  $26 = $3;
  $25 = (($26) + -1)|0;
  $27 = HEAP32[$this>>2]|0;
  $28 = HEAP32[$t>>2]|0;
  $29 = (($27) + ($25<<2)|0);
  HEAP32[$29>>2] = $28;
  STACKTOP = sp;return;
 }
 $8 = $5 << 1;
 $9 = ($8|0)==(0);
 $10 = $9 ? 1 : $8;
 $11 = ($6>>>0)<($10>>>0);
 do {
  if ($11) {
   $12 = ($5|0)>(-1);
   if ($12) {
    HEAP32[$4>>2] = $10;
    $13 = HEAP32[$this>>2]|0;
    $14 = $10 << 2;
    $15 = (($this) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,642424,370)|0);
    HEAP32[$this>>2] = $17;
    break;
   } else {
    $18 = $10 << 2;
    $19 = (($this) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,642424,352)|0);
    $22 = HEAP32[$this>>2]|0;
    $23 = HEAP32[$1>>2]|0;
    $24 = $23 << 2;
    _memcpy(($21|0),($22|0),($24|0))|0;
    HEAP32[$4>>2] = $10;
    HEAP32[$this>>2] = $21;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$1>>2]|0;
 $26 = $$pre$i;
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$t>>2]|0;
 $29 = (($27) + ($25<<2)|0);
 HEAP32[$29>>2] = $28;
 STACKTOP = sp;return;
}
function __ZN6Shader27MarkShaderStateNotSupportedEPS_($shader) {
 $shader = $shader|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($shader|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 0;
 } else {
  $2 = (($shader) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $3;
 }
 __ZN13dynamic_arrayI4PPtrI6ShaderELj4EE9push_backERKS2_(642016,$0);
 STACKTOP = sp;return;
}
function __ZN6Shader23HandleShadersWithErrorsEv() {
 var $$byval_copy2 = 0, $$c = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$013 = 0, $i1$012 = 0, $temp$0$i20 = 0, $temp$0$i618 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = HEAP32[((642000 + 8|0))>>2]|0;
 $5 = HEAP32[((642016 + 8|0))>>2]|0;
 $6 = $5 | $4;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = ($5|0)==(0);
 if (!($8)) {
  $i$013 = 0;
  while(1) {
   $9 = HEAP32[642016>>2]|0;
   $10 = (($9) + ($i$013<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0);
   do {
    if (!($12)) {
     HEAP32[$1>>2] = $11;
     $13 = HEAP32[560624>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      label = 13;
     } else {
      $15 = (($13) + 36|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($13) + 4|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($16|0)==($18|0);
      do {
       if ($19) {
        $20 = (($13) + 28|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = (($13) + 32|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = (($21) + ($23<<3)|0);
        $40 = $24;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$13,$1);
        $25 = HEAP32[$$byval_copy2>>2]|0;
        $26 = ($25|0)==(-1);
        $27 = (($13) + 28|0);
        $28 = HEAP32[$27>>2]|0;
        if ($26) {
         $29 = (($13) + 32|0);
         $30 = HEAP32[$29>>2]|0;
         $31 = (($28) + ($30<<3)|0);
         $40 = $31;
         break;
        } else {
         $32 = (($28) + ($25<<3)|0);
         $40 = $32;
         break;
        }
       }
      } while(0);
      $33 = HEAP32[560624>>2]|0;
      $34 = (($33) + 28|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = (($33) + 32|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($35) + ($37<<3)|0);
      $39 = ($40|0)==($38|0);
      if ($39) {
       label = 13;
      } else {
       $41 = (($40) + 4|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42|0)==(0|0);
       if ($43) {
        label = 13;
       } else {
        $temp$0$i618 = $42;
       }
      }
     }
     if ((label|0) == 13) {
      label = 0;
      $44 = HEAP32[$10>>2]|0;
      $45 = (__Z31ReadObjectFromPersistentManageri($44)|0);
      $46 = ($45|0)==(0|0);
      if ($46) {
       break;
      } else {
       $temp$0$i618 = $45;
      }
     }
     $47 = (($temp$0$i618) + 52|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = HEAP32[642144>>2]|0;
     $50 = ($48|0)==($49|0);
     if (!($50)) {
      __ZN9ShaderLab9IntShader27RemoveUnsupportedSubShadersEv($48);
      $51 = HEAP32[$47>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($51) + 4|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($52|0)==($54|0);
      if ($55) {
       $56 = (($temp$0$i618) + 4|0);
       $57 = HEAP32[$56>>2]|0;
       HEAP32[$3>>2] = $57;
       __ZN13dynamic_arrayI4PPtrI6ShaderELj4EE9push_backERKS2_(642000,$3);
      }
     }
    }
   } while(0);
   $58 = (($i$013) + 1)|0;
   $59 = ($58|0)==($5|0);
   if ($59) {
    break;
   } else {
    $i$013 = $58;
   }
  }
 }
 $60 = HEAP32[((642016 + 12|0))>>2]|0;
 $61 = ($60|0)>(-1);
 if ($61) {
  $62 = HEAP32[642016>>2]|0;
  $63 = HEAP32[((642016 + 4|0))>>2]|0;
  HEAP32[$0>>2] = $63;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($62,$$byval_copy2);
  HEAP32[642016>>2] = 0;
 }
 HEAP32[((642016 + 8|0))>>2] = 0;
 HEAP32[((642016 + 12|0))>>2] = 0;
 $64 = HEAP32[((642000 + 8|0))>>2]|0;
 $65 = ($64|0)==(0);
 if (!($65)) {
  $i1$012 = 0;
  while(1) {
   $66 = HEAP32[642000>>2]|0;
   $67 = (($66) + ($i1$012<<2)|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(0);
   do {
    if (!($69)) {
     HEAP32[$0>>2] = $68;
     $70 = HEAP32[560624>>2]|0;
     $71 = ($70|0)==(0|0);
     if ($71) {
      label = 31;
     } else {
      $72 = (($70) + 36|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($70) + 4|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($73|0)==($75|0);
      do {
       if ($76) {
        $77 = (($70) + 28|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = (($70) + 32|0);
        $80 = HEAP32[$79>>2]|0;
        $81 = (($78) + ($80<<3)|0);
        $97 = $81;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$70,$0);
        $82 = HEAP32[$$byval_copy2>>2]|0;
        $83 = ($82|0)==(-1);
        $84 = (($70) + 28|0);
        $85 = HEAP32[$84>>2]|0;
        if ($83) {
         $86 = (($70) + 32|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = (($85) + ($87<<3)|0);
         $97 = $88;
         break;
        } else {
         $89 = (($85) + ($82<<3)|0);
         $97 = $89;
         break;
        }
       }
      } while(0);
      $90 = HEAP32[560624>>2]|0;
      $91 = (($90) + 28|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($90) + 32|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (($92) + ($94<<3)|0);
      $96 = ($97|0)==($95|0);
      if ($96) {
       label = 31;
      } else {
       $98 = (($97) + 4|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = ($99|0)==(0|0);
       if ($100) {
        label = 31;
       } else {
        $temp$0$i20 = $99;
       }
      }
     }
     if ((label|0) == 31) {
      label = 0;
      $101 = HEAP32[$67>>2]|0;
      $102 = (__Z31ReadObjectFromPersistentManageri($101)|0);
      $103 = ($102|0)==(0|0);
      if ($103) {
       break;
      } else {
       $temp$0$i20 = $102;
      }
     }
     $104 = (($temp$0$i20) + 52|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = HEAP32[642144>>2]|0;
     $107 = ($105|0)==($106|0);
     if (!($107)) {
      $108 = (($temp$0$i20) + 4|0);
      $109 = HEAP32[$108>>2]|0;
      $110 = ($109|0)==(0);
      if ($110) {
       $$pre = HEAP32[$104>>2]|0;
       $113 = $$pre;
      } else {
       $113 = $105;
      }
      $111 = HEAP32[628272>>2]|0;
      $112 = ($113|0)==(0|0);
      if (!($112)) {
       __ZN9ShaderLab9IntShaderD2Ev($113);
      }
      HEAP32[$2>>2] = $111;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($113,$$byval_copy2);
      HEAP32[$104>>2] = 0;
      $114 = HEAP32[642144>>2]|0;
      $$c = $114;
      HEAP32[$104>>2] = $$c;
      $115 = (($temp$0$i20) + 56|0);
      HEAP32[$115>>2] = 0;
      $116 = (($temp$0$i20) + 60|0);
      HEAP32[$116>>2] = 0;
     }
    }
   } while(0);
   $117 = (($i1$012) + 1)|0;
   $118 = ($117|0)==($64|0);
   if ($118) {
    break;
   } else {
    $i1$012 = $117;
   }
  }
 }
 $119 = HEAP32[((642000 + 12|0))>>2]|0;
 $120 = ($119|0)>(-1);
 if ($120) {
  $121 = HEAP32[642000>>2]|0;
  $122 = HEAP32[((642000 + 4|0))>>2]|0;
  HEAP32[$2>>2] = $122;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($121,$$byval_copy2);
  HEAP32[642000>>2] = 0;
 }
 HEAP32[((642000 + 8|0))>>2] = 0;
 HEAP32[((642000 + 12|0))>>2] = 0;
 __ZN5Unity8Material29ResetAllMaterialsCachedPassesEv();
 STACKTOP = sp;return;
}
function __Z20RegisterClass_Shaderv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(48,185,0,0,0);
 STACKTOP = sp;return;
}
function __ZN6Shader13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(49)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9TextAsset13RegisterClassEv();
 }
 HEAP8[$0>>0] = 12;
 $3 = (($0) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[642432+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[642432+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[642432+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[642432+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[642432+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[642432+5>>0]|0;
 $4 = (($0) + 7|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,48,49,($0|0),92,(2526|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN6Shader7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(92,$$byval_copy2,1,16,642424,34)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1931,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(642424|0),34);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK6Shader25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 48;
}
function __ZN6Shader23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i$i = 0, $p$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 $size$i$i$i = sp + 20|0;
 $p$i$i = sp + 16|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642440,642432,$this,0);
 __ZN9TextAsset8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 76|0);
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642448,$1,$0,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,642520,642520,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642480,642528,$p$i$i,0);
 $2 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $7 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642488,$7,$p$i$i,1);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($10) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642504,$14,$2,1);
 $15 = HEAP32[$8>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$11>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 88|0);
 $20 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642464,$20,$19,0);
 $21 = HEAP32[$8>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$11>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN6Shader23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,642440,642432,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN6Shader8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN6Shader23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9TextAsset8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 76|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 88|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $8 = HEAP8[$3>>0]|0;
  HEAP8[$1>>0] = $8;
  $9 = HEAP32[$2>>2]|0;
  $10 = (($9) + 1|0);
  HEAP32[$2>>2] = $10;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN6Shader23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9TextAsset8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 76|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 88|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $8 = HEAP8[$3>>0]|0;
  HEAP8[$1>>0] = $8;
  $9 = HEAP32[$2>>2]|0;
  $10 = (($9) + 1|0);
  HEAP32[$2>>2] = $10;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN6Shader23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6Shader8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN6Shader23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN9TextAsset8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($transfer) + 12|0);
 $6 = (($transfer) + 28|0);
 $7 = (($transfer) + 32|0);
 $9 = $1;
 while(1) {
  $8 = HEAP32[$9>>2]|0;
  $10 = HEAP32[$5>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$6>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($10,$8,$13)|0);
  $15 = HEAP8[$7>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   HEAP32[$9>>2] = $14;
  }
  $17 = (($9) + 4|0);
  $18 = ($17|0)==($3|0);
  if ($18) {
   break;
  } else {
   $9 = $17;
  }
 }
 STACKTOP = sp;return;
}
function __Z22ShaderDisablesBatchingP6Shaderf($shader,$lodFade) {
 $shader = $shader|0;
 $lodFade = Math_fround($lodFade);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($shader) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 if ((($3|0) == 1)) {
  $$0 = 1;
 } else if ((($3|0) == 2)) {
  $4 = $lodFade != Math_fround(0.0);
  $$0 = $4;
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN6ShaderD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((642032 + 8|0));
 $1 = HEAP32[642152>>2]|0;
 $2 = ($1|0)==($this|0);
 if ($2) {
  HEAP32[642152>>2] = 0;
 }
 $3 = (($this) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $__new_last2$i$i$i$i$i$i = $4;
   $scevgep$i$i$i$i$i$i = (($7) + -4|0);
   $9 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($9)|0);
   $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
   $10 = $uglygep3$i$i$i$i$i$i >>> 2;
   $11 = $10 ^ -1;
   $scevgep4$i$i$i$i$i$i = (($7) + ($11<<2)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 $12 = (($this) + 64|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  __ZN9TextAssetD2Ev($this);
  STACKTOP = sp;return;
 }
 $16 = (($this) + 72|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($17|0),($$byval_copy|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  ___cxa_call_unexpected(($20|0));
  // unreachable;
 } else {
  __ZN9TextAssetD2Ev($this);
  STACKTOP = sp;return;
 }
}
function __ZN6ShaderD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((642032 + 8|0));
 $1 = HEAP32[642152>>2]|0;
 $2 = ($1|0)==($this|0);
 if ($2) {
  HEAP32[642152>>2] = 0;
 }
 $3 = (($this) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $__new_last2$i$i$i$i$i$i$i = $4;
   $scevgep$i$i$i$i$i$i$i = (($7) + -4|0);
   $9 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($9)|0);
   $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
   $10 = $uglygep3$i$i$i$i$i$i$i >>> 2;
   $11 = $10 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($7) + ($11<<2)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 $12 = (($this) + 64|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  $16 = (($this) + 72|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($17|0),($$byval_copy|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   ___cxa_call_unexpected(($20|0));
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3558,($this|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  __ZdlPv($this);
  ___resumeException($24|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK6Shader18GetScriptClassNameEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN6Shader8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $shaderIsBaked = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 $shaderIsBaked = sp + 4|0;
 __ZN9TextAsset8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 HEAP32[$size$i$i$i>>2] = $7;
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i,4);
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==($14|0);
 if (!($16)) {
  $17 = $15;
  while(1) {
   __ZN4PPtrI6ShaderE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($17,$transfer);
   $18 = (($17) + 4|0);
   $19 = ($18|0)==($14|0);
   if ($19) {
    break;
   } else {
    $17 = $18;
   }
  }
 }
 HEAP8[$shaderIsBaked>>0] = 1;
 $20 = HEAP32[$8>>2]|0;
 $21 = (($20) + 1|0);
 $22 = HEAP32[$11>>2]|0;
 $23 = ($21>>>0)<($22>>>0);
 if ($23) {
  HEAP8[$20>>0] = 1;
  $24 = HEAP32[$8>>2]|0;
  $25 = (($24) + 1|0);
  HEAP32[$8>>2] = $25;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$shaderIsBaked,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4PPtrI6ShaderENS0_9allocatorIS4_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI4PPtrI6ShaderENS0_9allocatorIS4_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$idx = 0, $$pre54 = 0, $$pre55 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i30 = 0, $__new_last2$i$i$i$i$i39 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i31 = 0, $scevgep$i$i$i$i$i40 = 0, $scevgep$i$i$i17 = 0, $scevgep4$i$i$i$i$i35 = 0, $scevgep4$i$i$i$i$i44 = 0;
 var $scevgep4$i$i$i19 = 0, $scevgep8$i$i$i = 0, $scevgep8$i$i$i52 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i42 = 0, $uglygep$i$i$i18 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i34 = 0, $uglygep3$i$i$i$i$i43 = 0, $uglygep6$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($sz>>>0);
 if (!($9)) {
  $63 = ($8>>>0)>($sz>>>0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  $64 = (($4) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $65 = $$idx >> 2;
  $66 = ($65|0)==(0);
  if ($66) {
   $81 = 0;$83 = 0;$scevgep8$i$i$i52 = 0;
  } else {
   $67 = ($65>>>0)>(1073741823);
   if ($67) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $68 = (__Znwj($$idx)|0);
   $69 = (($68) + ($65<<2)|0);
   $70 = ($sz|0)==(0);
   if ($70) {
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $68;
   } else {
    $$sum = (($sz) + -1)|0;
    $scevgep$i$i$i = (($4) + ($$sum<<2)|0);
    $71 = (0 - ($6))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($71)|0);
    $73 = $68;$75 = $4;
    while(1) {
     $72 = ($73|0)==(0|0);
     if (!($72)) {
      $74 = HEAP32[$75>>2]|0;
      HEAP32[$73>>2] = $74;
     }
     $76 = (($73) + 4|0);
     $77 = (($75) + 4|0);
     $78 = ($77|0)==($64|0);
     if ($78) {
      break;
     } else {
      $73 = $76;$75 = $77;
     }
    }
    $uglygep6$i$i$i = $uglygep$i$i$i;
    $79 = $uglygep6$i$i$i >>> 2;
    $80 = (($79) + 1)|0;
    $scevgep8$i$i$i = (($68) + ($80<<2)|0);
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $scevgep8$i$i$i;
   }
  }
  HEAP32[$v>>2] = $81;
  HEAP32[$2>>2] = $scevgep8$i$i$i52;
  $82 = (($v) + 8|0);
  HEAP32[$82>>2] = $83;
  $84 = ($4|0)==(0|0);
  if ($84) {
   STACKTOP = sp;return;
  }
  __ZdlPv($4);
  STACKTOP = sp;return;
 }
 $10 = (($v) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($6))|0;
 $14 = $13 >> 2;
 $15 = ($14|0)==($sz|0);
 if ($15) {
  $62 = (($sz) - ($8))|0;
  __ZNSt3__16vectorI4PPtrI6ShaderENS_9allocatorIS3_EEE8__appendEj($v,$62);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $16 = (($temp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($temp) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = ($sz|0)==(0);
 if ($18) {
  label = 6;
 } else {
  $19 = $sz << 2;
  __THREW__ = 0;
  $20 = (invoke_ii(2988,($19|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $23 = (($20) + ($sz<<2)|0);
   HEAP32[$temp>>2] = $20;
   HEAP32[$16>>2] = $20;
   HEAP32[$17>>2] = $23;
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$0>>2] = $4;
   HEAP32[$1>>2] = $3;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1932,($temp|0),($$byval_copy|0),($$byval_copy1|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$16>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = $30 >> 2;
    $32 = ($31>>>0)<($sz>>>0);
    if ($32) {
     $33 = (($sz) - ($31))|0;
     __THREW__ = 0;
     invoke_vii(3241,($temp|0),($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $$pre54 = HEAP32[$temp>>2]|0;
     $$pre55 = HEAP32[$16>>2]|0;
     $43 = $$pre54;$45 = $$pre55;
    } else {
     $36 = ($31>>>0)>($sz>>>0);
     if ($36) {
      $37 = (($27) + ($sz<<2)|0);
      $38 = ($26|0)==($37|0);
      if ($38) {
       $43 = $27;$45 = $26;
      } else {
       $__new_last2$i$i$i = $37;
       $scevgep$i$i$i17 = (($26) + -4|0);
       $39 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i18 = (($scevgep$i$i$i17) + ($39)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i18;
       $40 = $uglygep3$i$i$i >>> 2;
       $41 = $40 ^ -1;
       $scevgep4$i$i$i19 = (($26) + ($41<<2)|0);
       HEAP32[$16>>2] = $scevgep4$i$i$i19;
       $43 = $27;$45 = $scevgep4$i$i$i19;
      }
     } else {
      $43 = $27;$45 = $26;
     }
    }
    $42 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $42;
    HEAP32[$v>>2] = $43;
    $44 = HEAP32[$2>>2]|0;
    HEAP32[$16>>2] = $44;
    HEAP32[$2>>2] = $45;
    $46 = HEAP32[$17>>2]|0;
    $47 = HEAP32[$10>>2]|0;
    HEAP32[$17>>2] = $47;
    HEAP32[$10>>2] = $46;
    $48 = ($42|0)==(0|0);
    if ($48) {
     STACKTOP = sp;return;
    }
    $49 = ($44|0)==($42|0);
    if (!($49)) {
     $__new_last2$i$i$i$i$i30 = $42;
     $scevgep$i$i$i$i$i31 = (($44) + -4|0);
     $50 = (0 - ($__new_last2$i$i$i$i$i30))|0;
     $uglygep$i$i$i$i$i33 = (($scevgep$i$i$i$i$i31) + ($50)|0);
     $uglygep3$i$i$i$i$i34 = $uglygep$i$i$i$i$i33;
     $51 = $uglygep3$i$i$i$i$i34 >>> 2;
     $52 = $51 ^ -1;
     $scevgep4$i$i$i$i$i35 = (($44) + ($52<<2)|0);
     HEAP32[$16>>2] = $scevgep4$i$i$i$i$i35;
    }
    __ZdlPv($42);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $53 = ___cxa_find_matching_catch()|0;
 $54 = tempRet0;
 $55 = HEAP32[$temp>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($53|0);
  // unreachable;
 }
 $57 = HEAP32[$16>>2]|0;
 $58 = ($57|0)==($55|0);
 if (!($58)) {
  $__new_last2$i$i$i$i$i39 = $55;
  $scevgep$i$i$i$i$i40 = (($57) + -4|0);
  $59 = (0 - ($__new_last2$i$i$i$i$i39))|0;
  $uglygep$i$i$i$i$i42 = (($scevgep$i$i$i$i$i40) + ($59)|0);
  $uglygep3$i$i$i$i$i43 = $uglygep$i$i$i$i$i42;
  $60 = $uglygep3$i$i$i$i$i43 >>> 2;
  $61 = $60 ^ -1;
  $scevgep4$i$i$i$i$i44 = (($57) + ($61<<2)|0);
  HEAP32[$16>>2] = $scevgep4$i$i$i$i$i44;
 }
 __ZdlPv($55);
 ___resumeException($53|0);
 // unreachable;
}
function __ZNSt3__16vectorI4PPtrI6ShaderENS_9allocatorIS3_EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$promoted15$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0;
 var $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i24 = 0, $scevgep$i10 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i17 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i25 = 0, $uglygep$i12 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0;
 var $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $46 = ($8|0)==(0|0);
  if ($46) {
   $55 = $7;
  } else {
   $47 = (($this) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($8|0);
   if (!($49)) {
    $scevgep$i$i$i$i = (($48) + -4|0);
    $50 = (0 - ($10))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($50)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $51 = $uglygep3$i$i$i$i >>> 2;
    $52 = $51 ^ -1;
    $scevgep4$i$i$i$i = (($48) + ($52<<2)|0);
    HEAP32[$47>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($8);
   HEAP32[$6>>2] = 0;
   HEAP32[$47>>2] = 0;
   HEAP32[$this>>2] = 0;
   $55 = 0;
  }
  $53 = ($5>>>0)>(1073741823);
  if ($53) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $54 = $55;
  $56 = $54 >> 2;
  $57 = ($56>>>0)<(536870911);
  if ($57) {
   $58 = $54 >> 1;
   $59 = ($58>>>0)<($5>>>0);
   $60 = $59 ? $5 : $58;
   $61 = ($60>>>0)>(1073741823);
   if ($61) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $60;
   }
  } else {
   $$0$i40 = 1073741823;
  }
  $62 = $$0$i40 << 2;
  $63 = (__Znwj($62)|0);
  $64 = (($this) + 4|0);
  HEAP32[$64>>2] = $63;
  HEAP32[$this>>2] = $63;
  $65 = (($63) + ($$0$i40<<2)|0);
  HEAP32[$6>>2] = $65;
  $66 = ($0|0)==($1|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($1) + -4|0);
  $67 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($67)|0);
  $uglygep6$i = $uglygep$i;
  $68 = $uglygep6$i >>> 2;
  $70 = $63;$72 = $0;
  while(1) {
   $69 = ($70|0)==(0|0);
   if (!($69)) {
    $71 = HEAP32[$72>>2]|0;
    HEAP32[$70>>2] = $71;
   }
   $73 = (($70) + 4|0);
   $74 = (($72) + 4|0);
   $75 = ($74|0)==($1|0);
   if ($75) {
    break;
   } else {
    $70 = $73;$72 = $74;
   }
  }
  $76 = (($68) + 1)|0;
  $scevgep8$i = (($63) + ($76<<2)|0);
  HEAP32[$64>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 2;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<2)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i24 = (($22) + -4|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i25 = (($scevgep$i$i24) + ($23)|0);
  $uglygep5$i$i = $uglygep$i$i25;
  $24 = $uglygep5$i$i >>> 2;
  $$01$i$i = $8;$26 = $0;
  while(1) {
   $25 = HEAP32[$26>>2]|0;
   HEAP32[$$01$i$i>>2] = $25;
   $27 = (($26) + 4|0);
   $28 = (($$01$i$i) + 4|0);
   $29 = ($27|0)==($22|0);
   if ($29) {
    break;
   } else {
    $$01$i$i = $28;$26 = $27;
   }
  }
  $30 = (($24) + 1)|0;
  $scevgep6$i$i = (($8) + ($30<<2)|0);
  $$0$lcssa$i$i = $scevgep6$i$i;
 }
 if (!($__growing$0$off0)) {
  $42 = ($15|0)==($$0$lcssa$i$i|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($15) + -4|0);
  $43 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($43)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $44 = $uglygep3$i$i >>> 2;
  $45 = $44 ^ -1;
  $scevgep4$i$i = (($15) + ($45<<2)|0);
  HEAP32[$14>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $31 = ($22|0)==($1|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $$promoted15$i9 = $22;
 $scevgep$i10 = (($1) + -4|0);
 $32 = (0 - ($$promoted15$i9))|0;
 $uglygep$i12 = (($scevgep$i10) + ($32)|0);
 $uglygep6$i13 = $uglygep$i12;
 $33 = $uglygep6$i13 >>> 2;
 $35 = $15;$37 = $22;
 while(1) {
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   $36 = HEAP32[$37>>2]|0;
   HEAP32[$35>>2] = $36;
  }
  $38 = (($35) + 4|0);
  $39 = (($37) + 4|0);
  $40 = ($39|0)==($1|0);
  if ($40) {
   break;
  } else {
   $35 = $38;$37 = $39;
  }
 }
 $41 = (($33) + 1)|0;
 $scevgep8$i17 = (($15) + ($41<<2)|0);
 HEAP32[$14>>2] = $scevgep8$i17;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI4PPtrI6ShaderENS_9allocatorIS3_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0;
 var $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
   }
   $11 = (($10) + 4|0);
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$10 = $11;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($__n))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 if ($22) {
  $23 = $20 >> 1;
  $24 = ($23>>>0)<($18>>>0);
  $25 = $24 ? $18 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 2;
  $28 = (__Znwj($27)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($17<<2)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP32[$32>>2] = 0;
  }
  $33 = (($32) + 4|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($30) + ($18<<2)|0);
 $37 = ($3|0)==($14|0);
 if ($37) {
  $47 = $29;$49 = $3;
 } else {
  $scevgep$i$i = (($3) + -4|0);
  $38 = (0 - ($15))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($38)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $3;$42 = $29;
  while(1) {
   $39 = (($$01$i$i) + -4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($42) + -4|0);
   HEAP32[$41>>2] = $40;
   $43 = (($42) + -4|0);
   $44 = ($39|0)==($14|0);
   if ($44) {
    break;
   } else {
    $$01$i$i = $39;$42 = $43;
   }
  }
  $45 = $uglygep4$i$i >>> 2;
  $46 = $45 ^ -1;
  $$sum6 = (($17) + ($46))|0;
  $scevgep5$i$i = (($30) + ($$sum6<<2)|0);
  $47 = $scevgep5$i$i;$49 = $14;
 }
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $36;
 $48 = ($49|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($49);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderENS2_9allocatorIS6_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4PPtrI6ShaderENS0_9allocatorIS4_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN6Shader8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN9TextAsset8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 76|0);
 $1 = HEAP32[580760>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,642448,$1,$converter$i$i1,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderENS1_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 88|0);
 $8 = HEAP32[580544>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,642464,$8,$converter$i$i1,0)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 do {
  if ($11) {
   $12 = (($transfer) + 12|0);
   $13 = (($transfer) + 80|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($transfer) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($transfer) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($transfer) + 32|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = Math_imul($22, $20)|0;
   $$sum$i$i$i$i$i = (($16) - ($23))|0;
   $24 = (($18) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$12>>2] = $24;
   $25 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($25)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $26 = (($18) + ($$sum1$i$i$i$i$i)|0);
    $27 = (($transfer) + 20|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($26>>>0)>($28>>>0);
    if (!($29)) {
     $30 = HEAP8[$24>>0]|0;
     HEAP8[$7>>0] = $30;
     $31 = HEAP32[$12>>2]|0;
     $32 = (($31) + 1|0);
     HEAP32[$12>>2] = $32;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($12,$7,1);
  } else {
   $33 = HEAP32[$converter$i$i1>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    (FUNCTION_TABLE_iii[$33 & 4095]($7,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI6ShaderENS1_9allocatorIS5_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,642520,642520,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4PPtrI6ShaderENS0_9allocatorIS4_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,642480,642528,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4PPtrI6ShaderE8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 4|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,642480,642528,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4PPtrI6ShaderE8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 4|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = ($__nd|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$4);
 $5 = (($__nd) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$6);
 $7 = (($__nd) + 16|0);
 $8 = (($__nd) + 40|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = (($__nd) + 48|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($13|0),($$byval_copy2|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   ___cxa_call_unexpected(($16|0));
   // unreachable;
  }
 }
 $18 = (($__nd) + 28|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  $22 = (($__nd) + 36|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($23|0),($$byval_copy2|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $26 = ___cxa_find_matching_catch()|0;
   $27 = tempRet0;
   ___cxa_call_unexpected(($26|0));
   // unreachable;
  }
 }
 $28 = HEAP8[$7>>0]|0;
 $29 = $28 & 1;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = (($__nd) + 24|0);
  $32 = HEAP32[$31>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($32|0),($$byval_copy2|0));
  $33 = __THREW__; __THREW__ = 0;
  $34 = $33&1;
  if ($34) {
   $35 = ___cxa_find_matching_catch()|0;
   $36 = tempRet0;
   ___cxa_call_unexpected(($35|0));
   // unreachable;
  }
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper10FindShaderERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = 0, $$lcssa$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $i$01$i = 0, $i$01$us$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = (__ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE4FindERKNS1_12basic_stringIcNS1_11char_traitsIcEENS8_IcEEEE($1,$name)|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP8[$name>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 $7 = (($name) + 1|0);
 L4: do {
  if ($6) {
   $i$01$us$i = 0;
   while(1) {
    $12 = $i$01$us$i << 1;
    $13 = (642856 + ($12<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (_strcmp($14,$7)|0);
    $16 = ($15|0)==(0);
    $11 = (($i$01$us$i) + 1)|0;
    if ($16) {
     $$lcssa$i = $12;
     break L4;
    }
    $10 = ($11|0)<(77);
    if ($10) {
     $i$01$us$i = $11;
    } else {
     $$0 = 0;
     break;
    }
   }
   STACKTOP = sp;return ($$0|0);
  } else {
   $8 = (($name) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $i$01$i = 0;
   while(1) {
    $19 = $i$01$i << 1;
    $20 = (642856 + ($19<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (_strcmp($21,$9)|0);
    $23 = ($22|0)==(0);
    $18 = (($i$01$i) + 1)|0;
    if ($23) {
     $$lcssa$i = $19;
     break L4;
    }
    $17 = ($18|0)<(77);
    if ($17) {
     $i$01$i = $18;
    } else {
     $$0 = 0;
     break;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $24 = $$lcssa$i | 1;
 $25 = (642856 + ($24<<2)|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (_strlen(($26|0))|0);
 $28 = ($27>>>0)>(4294967279);
 if ($28) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $29 = ($27>>>0)<(11);
 if ($29) {
  $30 = $27 << 1;
  $31 = $30&255;
  HEAP8[$0>>0] = $31;
  $32 = (($0) + 1|0);
  $__p$0$i$i$i = $32;
 } else {
  $33 = (($27) + 16)|0;
  $34 = $33 & -16;
  $35 = (__Znwj($34)|0);
  $36 = (($0) + 8|0);
  HEAP32[$36>>2] = $35;
  $37 = $34 | 1;
  HEAP32[$0>>2] = $37;
  $38 = (($0) + 4|0);
  HEAP32[$38>>2] = $27;
  $__p$0$i$i$i = $35;
 }
 _memcpy(($__p$0$i$i$i|0),($26|0),($27|0))|0;
 $39 = (($__p$0$i$i$i) + ($27)|0);
 HEAP8[$39>>0] = 0;
 __THREW__ = 0;
 $40 = (invoke_iii(2527,($1|0),($0|0))|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $50 = HEAP8[$0>>0]|0;
  $51 = $50 & 1;
  $52 = ($51<<24>>24)==(0);
  if ($52) {
   ___resumeException($48|0);
   // unreachable;
  }
  $53 = (($0) + 8|0);
  $54 = HEAP32[$53>>2]|0;
  __ZdlPv($54);
  ___resumeException($48|0);
  // unreachable;
 } else {
  $43 = HEAP8[$0>>0]|0;
  $44 = $43 & 1;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   $$0 = $40;
   STACKTOP = sp;return ($$0|0);
  }
  $46 = (($0) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  __ZdlPv($47);
  $$0 = $40;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE4FindERKNS1_12basic_stringIcNS1_11char_traitsIcEENS8_IcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy1 = 0, $$in = 0, $$ph7 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $__p$0$i$i$i$i = 0, $found$0$ph6 = 0, $found$0$ph8 = 0, $temp$0$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP8[$name>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $10 = (($name) + 1|0);
  $11 = $3&255;
  $12 = $11 >>> 1;
  $14 = $12;$25 = $10;
 } else {
  $6 = (($name) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($name) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $14 = $9;$25 = $7;
 }
 $13 = ($14>>>0)>(2147483631);
 if ($13) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $15 = ($14>>>0)<(11);
 if ($15) {
  $16 = $14 << 1;
  $17 = $16&255;
  HEAP8[$2>>0] = $17;
  $18 = (($2) + 1|0);
  $$pre$phiZ2D = $2;$__p$0$i$i$i$i = $18;
 } else {
  $19 = (($14) + 16)|0;
  $20 = $19 & -16;
  HEAP32[$0>>2] = 59;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,642768,79)|0);
  $22 = (($2) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = $20 | 1;
  HEAP32[$2>>2] = $23;
  $24 = (($2) + 4|0);
  HEAP32[$24>>2] = $14;
  $$pre$phiZ2D = $2;$__p$0$i$i$i$i = $21;
 }
 _memcpy(($__p$0$i$i$i$i|0),($25|0),($14|0))|0;
 $26 = (($__p$0$i$i$i$i) + ($14)|0);
 HEAP8[$26>>0] = 0;
 $27 = (($this) + 12|0);
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE19__equal_range_multiIS2_EENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEESL_EERKT_($$byval_copy1,$27,$2);
 $28 = HEAP32[$$byval_copy1>>2]|0;
 $29 = (($$byval_copy1) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP8[$$pre$phiZ2D>>0]|0;
 $32 = $31 & 1;
 $33 = ($32<<24>>24)==(0);
 if (!($33)) {
  $34 = (($2) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($35|0),($$byval_copy1|0));
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   ___cxa_call_unexpected(($39|0));
   // unreachable;
  }
 }
 $38 = ($28|0)==($30|0);
 if ($38) {
  $found$0$ph6 = 0;
  STACKTOP = sp;return ($found$0$ph6|0);
 }
 $$ph7 = $28;$found$0$ph8 = 0;
 L19: while(1) {
  $94 = ($found$0$ph8|0)==(0|0);
  $42 = $$ph7;
  L21: while(1) {
   $41 = (($42) + 4|0);
   $43 = HEAP32[$41>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    $$01$i$i$i$i = $42;
    while(1) {
     $47 = (($$01$i$i$i$i) + 8|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==($$01$i$i$i$i|0);
     if ($50) {
      $$0$i$i$i$i = $48;
      break;
     } else {
      $$01$i$i$i$i = $48;
     }
    }
   } else {
    $$0$i$i$i$i$i = $43;
    while(1) {
     $45 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $45;
     }
    }
   }
   $51 = (($42) + 28|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0);
   do {
    if (!($53)) {
     HEAP32[$0>>2] = $52;
     $54 = HEAP32[560624>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      label = 28;
     } else {
      $56 = (($54) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($54) + 4|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($57|0)==($59|0);
      do {
       if ($60) {
        $61 = (($54) + 28|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = (($54) + 32|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = (($62) + ($64<<3)|0);
        $81 = $65;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$54,$0);
        $66 = HEAP32[$$byval_copy1>>2]|0;
        $67 = ($66|0)==(-1);
        $68 = (($54) + 28|0);
        $69 = HEAP32[$68>>2]|0;
        if ($67) {
         $70 = (($54) + 32|0);
         $71 = HEAP32[$70>>2]|0;
         $72 = (($69) + ($71<<3)|0);
         $81 = $72;
         break;
        } else {
         $73 = (($69) + ($66<<3)|0);
         $81 = $73;
         break;
        }
       }
      } while(0);
      $74 = HEAP32[560624>>2]|0;
      $75 = (($74) + 28|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = (($74) + 32|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($76) + ($78<<3)|0);
      $80 = ($81|0)==($79|0);
      if ($80) {
       label = 28;
      } else {
       $82 = (($81) + 4|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = ($83|0)==(0|0);
       if ($84) {
        label = 28;
       } else {
        $$in = $83;$temp$0$i13 = $83;
       }
      }
     }
     if ((label|0) == 28) {
      label = 0;
      $85 = HEAP32[$51>>2]|0;
      $86 = (__Z31ReadObjectFromPersistentManageri($85)|0);
      $87 = ($86|0)==(0|0);
      if ($87) {
       break;
      } else {
       $$in = $86;$temp$0$i13 = $86;
      }
     }
     if ($94) {
      break L21;
     }
     $89 = (($temp$0$i13) + 8|0);
     $90 = HEAP32[$89>>2]|0;
     $91 = $90 & 999424;
     $92 = ($91|0)==(999424);
     if (!($92)) {
      break L21;
     }
    }
   } while(0);
   $88 = ($$0$i$i$i$i|0)==($30|0);
   if ($88) {
    $found$0$ph6 = $found$0$ph8;
    label = 34;
    break L19;
   } else {
    $42 = $$0$i$i$i$i;
   }
  }
  $93 = ($$0$i$i$i$i|0)==($30|0);
  if ($93) {
   $found$0$ph6 = $$in;
   label = 34;
   break;
  } else {
   $$ph7 = $$0$i$i$i$i;$found$0$ph8 = $$in;
  }
 }
 if ((label|0) == 34) {
  STACKTOP = sp;return ($found$0$ph6|0);
 }
 return 0|0;
}
function __Z26RegisterClass_ScriptMapperv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(94,186,0,0,0);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 12;
 dest=$3+0|0; src=642688+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 12|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,94,6,($0|0),56,(2528|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN12ScriptMapper7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(56,$$byval_copy2,1,16,642768,19)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1678,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((642576 + 8|0));
  $6 = (($3) + 32|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 36|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 28|0);
  HEAP32[$8>>2] = $6;
  $9 = (($3) + 44|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 48|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 40|0);
  HEAP32[$11>>2] = $9;
  $12 = (($3) + 52|0);
  HEAP32[$12>>2] = $3;
  $13 = (($3) + 24|0);
  HEAP8[$13>>0] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(642768|0),19);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK12ScriptMapper25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 94;
}
function __ZN12ScriptMapper23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642704,642688,$this,0);
 __ZN12ScriptMapper8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp + 4|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,642704,642688,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 do {
  if ($2) {
   __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
   $3 = HEAP32[$transfer>>2]|0;
   $4 = $3 & 33554432;
   $5 = ($4|0)==(0);
   if (!($5)) {
    $6 = (($this) + 24|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     break;
    }
    $9 = (($this) + 28|0);
    __ZN14SafeBinaryRead8TransferI15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS2_E8UnityStrNS3_4lessIS6_EENS3_9allocatorINS3_4pairIKS6_S7_EEEEEENS3_8multimapIS7_S6_NS8_IS7_EENSA_INSB_IKS7_S6_EEEEEEEEEvRT_PKc17TransferMetaFlags($transfer,$9,642712,0);
    break;
   }
   $10 = (($this) + 28|0);
   __ZN14SafeBinaryRead8TransferI15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS2_E8UnityStrNS3_4lessIS6_EENS3_9allocatorINS3_4pairIKS6_S7_EEEEEENS3_8multimapIS7_S6_NS8_IS7_EENSA_INSB_IKS7_S6_EEEEEEEEEvRT_PKc17TransferMetaFlags($transfer,$10,642712,0);
   $11 = (($this) + 24|0);
   $12 = HEAP32[580544>>2]|0;
   $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,642728,$12,$converter$i$i1,0)|0);
   $14 = ($13|0)==(0);
   if (!($14)) {
    $15 = ($13|0)>(0);
    do {
     if ($15) {
      $16 = (($transfer) + 12|0);
      $17 = (($transfer) + 80|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($18) + 12|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($transfer) + 16|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($transfer) + 28|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($transfer) + 32|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = Math_imul($26, $24)|0;
      $$sum$i$i$i$i$i = (($20) - ($27))|0;
      $28 = (($22) + ($$sum$i$i$i$i$i)|0);
      HEAP32[$16>>2] = $28;
      $29 = ($$sum$i$i$i$i$i|0)<(0);
      if (!($29)) {
       $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
       $30 = (($22) + ($$sum1$i$i$i$i$i)|0);
       $31 = (($transfer) + 20|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = ($30>>>0)>($32>>>0);
       if (!($33)) {
        $34 = HEAP8[$28>>0]|0;
        HEAP8[$11>>0] = $34;
        $35 = HEAP32[$16>>2]|0;
        $36 = (($35) + 1|0);
        HEAP32[$16>>2] = $36;
        break;
       }
      }
      __ZN12CachedReader15UpdateReadCacheEPvj($16,$11,1);
     } else {
      $37 = HEAP32[$converter$i$i1>>2]|0;
      $38 = ($37|0)==(0|0);
      if (!($38)) {
       (FUNCTION_TABLE_iii[$37 & 4095]($11,$transfer)|0);
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
  } else {
   $39 = HEAP32[$converter$i$i>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    (FUNCTION_TABLE_iii[$39 & 4095]($this,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12ScriptMapper8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12ScriptMapper8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 33554432;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 24|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   STACKTOP = sp;return;
  }
  $6 = (($this) + 28|0);
  __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$6,0);
  STACKTOP = sp;return;
 }
 $7 = (($this) + 28|0);
 __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$7,0);
 $8 = (($this) + 24|0);
 $9 = (($transfer) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 1|0);
 $12 = (($transfer) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  $15 = HEAP8[$8>>0]|0;
  HEAP8[$10>>0] = $15;
  $16 = HEAP32[$9>>2]|0;
  $17 = (($16) + 1|0);
  HEAP32[$9>>2] = $17;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$8,1);
  STACKTOP = sp;return;
 }
}
function __ZN12ScriptMapper23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12ScriptMapper8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z15GetScriptMapperv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(4)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z19FindShaderLabShaderRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_6vectorI4PPtrI6ShaderENS3_ISB_EEEEb($name,$shaderLookup,$useLookup) {
 $name = $name|0;
 $shaderLookup = $shaderLookup|0;
 $useLookup = $useLookup|0;
 var $$ = 0, $$0 = 0, $$0$i16 = 0, $$01 = 0, $$1 = 0, $$14 = 0, $$86 = 0, $$in = 0, $$lcssa$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__lhs_sz$05$i = 0, $__lp$03$i = 0;
 var $__p$0$i$i$i = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i13 = 0, $__p$0$i$i$i33 = 0, $__p$0$i$i$i47 = 0, $__rp$04$i = 0, $cond = 0, $eh$lpad$body$index6Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$01$i = 0, $i$01$us$i = 0, $i$077 = 0, $lpad$phi69$index = 0, $lpad$phi69$index15 = 0, $saveShaderName = 0, $saveShaderName$i = 0, $saveShaderName$i23 = 0, $shader$078 = 0, $shader$1 = 0, $shader$2 = 0;
 var $shader$3 = 0, $shaderPtr = 0, $temp$0$i83 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $saveShaderName$i23 = sp + 56|0;
 $saveShaderName$i = sp;
 $0 = sp + 12|0;
 $saveShaderName = sp + 16|0;
 $1 = sp + 28|0;
 $2 = sp + 40|0;
 $shaderPtr = sp + 52|0;
 $3 = HEAP8[674240>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  ;HEAP32[$saveShaderName+0>>2]=HEAP32[674240+0>>2]|0;HEAP32[$saveShaderName+4>>2]=HEAP32[674240+4>>2]|0;HEAP32[$saveShaderName+8>>2]=HEAP32[674240+8>>2]|0;
 } else {
  $6 = HEAP32[((674240 + 8|0))>>2]|0;
  $7 = HEAP32[((674240 + 4|0))>>2]|0;
  $8 = ($7>>>0)>(4294967279);
  if ($8) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $9 = ($7>>>0)<(11);
  if ($9) {
   $10 = $7 << 1;
   $11 = $10&255;
   HEAP8[$saveShaderName>>0] = $11;
   $12 = (($saveShaderName) + 1|0);
   $__p$0$i$i$i = $12;
  } else {
   $13 = (($7) + 16)|0;
   $14 = $13 & -16;
   $15 = (__Znwj($14)|0);
   $16 = (($saveShaderName) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = $14 | 1;
   HEAP32[$saveShaderName>>2] = $17;
   $18 = (($saveShaderName) + 4|0);
   HEAP32[$18>>2] = $7;
   $__p$0$i$i$i = $15;
  }
  _memcpy(($__p$0$i$i$i|0),($6|0),($7|0))|0;
  $19 = (($__p$0$i$i$i) + ($7)|0);
  HEAP8[$19>>0] = 0;
 }
 L12: do {
  if ($useLookup) {
   $20 = (($shaderLookup) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$shaderLookup>>2]|0;
   $23 = ($21|0)==($22|0);
   if ($23) {
    $shader$3 = 0;
    label = 103;
   } else {
    $24 = (($1) + 1|0);
    $25 = (($name) + 1|0);
    $26 = (($name) + 8|0);
    $27 = (($1) + 8|0);
    $28 = (($2) + 1|0);
    $29 = (($2) + 8|0);
    $30 = (($2) + 4|0);
    $31 = (($name) + 4|0);
    $32 = (($1) + 4|0);
    $33 = (($saveShaderName$i) + 8|0);
    $34 = (($saveShaderName$i) + 1|0);
    $35 = (($saveShaderName$i) + 4|0);
    $37 = $22;$i$077 = 0;$shader$078 = 0;
    L15: while(1) {
     $36 = (($37) + ($i$077<<2)|0);
     $38 = HEAP32[$36>>2]|0;
     $39 = ($38|0)==(0);
     do {
      if ($39) {
       $shader$2 = $shader$078;
      } else {
       HEAP32[$0>>2] = $38;
       $40 = HEAP32[560624>>2]|0;
       $41 = ($40|0)==(0|0);
       if ($41) {
        label = 22;
       } else {
        $42 = (($40) + 36|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = (($40) + 4|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ($43|0)==($45|0);
        do {
         if ($46) {
          $47 = (($40) + 28|0);
          $48 = HEAP32[$47>>2]|0;
          $49 = (($40) + 32|0);
          $50 = HEAP32[$49>>2]|0;
          $51 = (($48) + ($50<<3)|0);
          $67 = $51;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($saveShaderName$i23,$40,$0);
          $52 = HEAP32[$saveShaderName$i23>>2]|0;
          $53 = ($52|0)==(-1);
          $54 = (($40) + 28|0);
          $55 = HEAP32[$54>>2]|0;
          if ($53) {
           $56 = (($40) + 32|0);
           $57 = HEAP32[$56>>2]|0;
           $58 = (($55) + ($57<<3)|0);
           $67 = $58;
           break;
          } else {
           $59 = (($55) + ($52<<3)|0);
           $67 = $59;
           break;
          }
         }
        } while(0);
        $60 = HEAP32[560624>>2]|0;
        $61 = (($60) + 28|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = (($60) + 32|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = (($62) + ($64<<3)|0);
        $66 = ($67|0)==($65|0);
        if ($66) {
         label = 22;
        } else {
         $68 = (($67) + 4|0);
         $69 = HEAP32[$68>>2]|0;
         $70 = ($69|0)==(0|0);
         if ($70) {
          label = 22;
         } else {
          $$in = $69;$temp$0$i83 = $69;
         }
        }
       }
       if ((label|0) == 22) {
        label = 0;
        $71 = HEAP32[$36>>2]|0;
        __THREW__ = 0;
        $72 = (invoke_ii(3215,($71|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 24;
         break L15;
        }
        $75 = ($72|0)==(0|0);
        if ($75) {
         $shader$2 = $shader$078;
         break;
        } else {
         $$in = $72;$temp$0$i83 = $72;
        }
       }
       $80 = (($$in) + 89|0);
       $81 = HEAP8[$80>>0]|0;
       $82 = ($81<<24>>24)==(0);
       if (!($82)) {
        $83 = HEAP8[674240>>0]|0;
        $84 = $83 & 1;
        $85 = ($84<<24>>24)==(0);
        if ($85) {
         ;HEAP32[$saveShaderName$i+0>>2]=HEAP32[674240+0>>2]|0;HEAP32[$saveShaderName$i+4>>2]=HEAP32[674240+4>>2]|0;HEAP32[$saveShaderName$i+8>>2]=HEAP32[674240+8>>2]|0;
        } else {
         $86 = HEAP32[((674240 + 8|0))>>2]|0;
         $87 = HEAP32[((674240 + 4|0))>>2]|0;
         $88 = ($87>>>0)>(4294967279);
         if ($88) {
          label = 31;
          break L15;
         }
         $91 = ($87>>>0)<(11);
         if ($91) {
          $92 = $87 << 1;
          $93 = $92&255;
          HEAP8[$saveShaderName$i>>0] = $93;
          $__p$0$i$i$i47 = $34;
         } else {
          $94 = (($87) + 16)|0;
          $95 = $94 & -16;
          __THREW__ = 0;
          $96 = (invoke_ii(2988,($95|0))|0);
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           label = 24;
           break L15;
          }
          HEAP32[$33>>2] = $96;
          $99 = $95 | 1;
          HEAP32[$saveShaderName$i>>2] = $99;
          HEAP32[$35>>2] = $87;
          $__p$0$i$i$i47 = $96;
         }
         _memcpy(($__p$0$i$i$i47|0),($86|0),($87|0))|0;
         $100 = (($__p$0$i$i$i47) + ($87)|0);
         HEAP8[$100>>0] = 0;
        }
        $101 = (($temp$0$i83) + 40|0);
        $102 = HEAP8[$101>>0]|0;
        $103 = $102 & 1;
        $104 = ($103<<24>>24)==(0);
        if ($104) {
         $109 = (($101) + 1|0);
         $110 = $102&255;
         $111 = $110 >>> 1;
         $112 = $109;$113 = $111;
        } else {
         $105 = (($temp$0$i83) + 48|0);
         $106 = HEAP32[$105>>2]|0;
         $107 = (($temp$0$i83) + 44|0);
         $108 = HEAP32[$107>>2]|0;
         $112 = $106;$113 = $108;
        }
        __THREW__ = 0;
        invoke_viii(1933,($$in|0),($112|0),($113|0));
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if ($115) {
         label = 46;
         break L15;
        }
        __THREW__ = 0;
        invoke_vi(3577,($$in|0));
        $116 = __THREW__; __THREW__ = 0;
        $117 = $116&1;
        if ($117) {
         label = 46;
         break L15;
        }
        __THREW__ = 0;
        (invoke_iii(2233,(674240|0),($saveShaderName$i|0))|0);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         label = 46;
         break L15;
        }
        $120 = HEAP8[$saveShaderName$i>>0]|0;
        $121 = $120 & 1;
        $122 = ($121<<24>>24)==(0);
        if (!($122)) {
         $123 = HEAP32[$33>>2]|0;
         __ZdlPv($123);
        }
       }
       $130 = HEAP32[$temp$0$i83>>2]|0;
       $131 = (($130) + 100|0);
       $132 = HEAP32[$131>>2]|0;
       __THREW__ = 0;
       $133 = (invoke_ii($132|0,($$in|0))|0);
       $134 = __THREW__; __THREW__ = 0;
       $135 = $134&1;
       if ($135) {
        label = 24;
        break L15;
       }
       $136 = HEAP8[$133>>0]|0;
       $137 = $136 & 1;
       $138 = ($137<<24>>24)==(0);
       if ($138) {
        $139 = (($133) + 1|0);
        $140 = $136&255;
        $141 = $140 >>> 1;
        $150 = $141;$160 = $139;
       } else {
        $142 = (($133) + 8|0);
        $143 = HEAP32[$142>>2]|0;
        $144 = (($133) + 4|0);
        $145 = HEAP32[$144>>2]|0;
        $146 = ($145>>>0)>(4294967279);
        if ($146) {
         label = 52;
         break L15;
        } else {
         $150 = $145;$160 = $143;
        }
       }
       $149 = ($150>>>0)<(11);
       if ($149) {
        $151 = $150 << 1;
        $152 = $151&255;
        HEAP8[$1>>0] = $152;
        $163 = $152;$__p$0$i$i$i$i = $24;
       } else {
        $153 = (($150) + 16)|0;
        $154 = $153 & -16;
        __THREW__ = 0;
        $155 = (invoke_ii(2988,($154|0))|0);
        $156 = __THREW__; __THREW__ = 0;
        $157 = $156&1;
        if ($157) {
         label = 24;
         break L15;
        }
        HEAP32[$27>>2] = $155;
        $158 = $154 | 1;
        HEAP32[$1>>2] = $158;
        HEAP32[$32>>2] = $150;
        $159 = $158&255;
        $163 = $159;$__p$0$i$i$i$i = $155;
       }
       _memcpy(($__p$0$i$i$i$i|0),($160|0),($150|0))|0;
       $161 = (($__p$0$i$i$i$i) + ($150)|0);
       HEAP8[$161>>0] = 0;
       $162 = $163 & 1;
       $164 = ($162<<24>>24)==(0);
       if ($164) {
        $166 = $163&255;
        $167 = $166 >>> 1;
        $175 = $167;
       } else {
        $165 = HEAP32[$32>>2]|0;
        $175 = $165;
       }
       $168 = HEAP8[$name>>0]|0;
       $169 = $168 & 1;
       $170 = ($169<<24>>24)==(0);
       if ($170) {
        $172 = $168&255;
        $173 = $172 >>> 1;
        $176 = $173;
       } else {
        $171 = HEAP32[$31>>2]|0;
        $176 = $171;
       }
       $174 = ($175|0)==($176|0);
       L73: do {
        if ($174) {
         $177 = HEAP32[$27>>2]|0;
         $$ = $164 ? $24 : $177;
         if ($170) {
          $187 = $25;
         } else {
          $178 = HEAP32[$26>>2]|0;
          $187 = $178;
         }
         if (!($164)) {
          $188 = (_memcmp($$,$187,$175)|0);
          $189 = ($188|0)==(0);
          if ($189) {
           $$01 = 4;$shader$1 = $$in;
           break;
          } else {
           label = 72;
           break;
          }
         }
         $179 = ($175|0)==(0);
         if ($179) {
          $$01 = 4;$shader$1 = $$in;
         } else {
          $__lhs_sz$05$i = $175;$__lp$03$i = $$;$__rp$04$i = $187;
          while(1) {
           $180 = HEAP8[$__lp$03$i>>0]|0;
           $181 = HEAP8[$__rp$04$i>>0]|0;
           $182 = ($180<<24>>24)==($181<<24>>24);
           if (!($182)) {
            label = 72;
            break L73;
           }
           $183 = (($__lhs_sz$05$i) + -1)|0;
           $184 = (($__lp$03$i) + 1|0);
           $185 = (($__rp$04$i) + 1|0);
           $186 = ($183|0)==(0);
           if ($186) {
            $$01 = 4;$shader$1 = $$in;
            break;
           } else {
            $__lhs_sz$05$i = $183;$__lp$03$i = $184;$__rp$04$i = $185;
           }
          }
         }
        } else {
         label = 72;
        }
       } while(0);
       do {
        if ((label|0) == 72) {
         label = 0;
         if ($170) {
          $191 = $25;
         } else {
          $190 = HEAP32[$26>>2]|0;
          $191 = $190;
         }
         $192 = (_strlen(($191|0))|0);
         $193 = ($192>>>0)>(4294967279);
         if ($193) {
          label = 75;
          break L15;
         }
         $196 = ($192>>>0)<(11);
         if ($196) {
          $197 = $192 << 1;
          $198 = $197&255;
          HEAP8[$2>>0] = $198;
          $208 = $198;$__p$0$i$i$i13 = $28;
         } else {
          $199 = (($192) + 16)|0;
          $200 = $199 & -16;
          __THREW__ = 0;
          $201 = (invoke_ii(2988,($200|0))|0);
          $202 = __THREW__; __THREW__ = 0;
          $203 = $202&1;
          if ($203) {
           label = 97;
           break L15;
          }
          HEAP32[$29>>2] = $201;
          $204 = $200 | 1;
          HEAP32[$2>>2] = $204;
          HEAP32[$30>>2] = $192;
          $205 = $204&255;
          $208 = $205;$__p$0$i$i$i13 = $201;
         }
         _memcpy(($__p$0$i$i$i13|0),($191|0),($192|0))|0;
         $206 = (($__p$0$i$i$i13) + ($192)|0);
         HEAP8[$206>>0] = 0;
         $207 = $208 & 1;
         $209 = ($207<<24>>24)==(0);
         L95: do {
          if ($209) {
           $i$01$us$i = 0;
           while(1) {
            $213 = $i$01$us$i << 1;
            $214 = (642856 + ($213<<2)|0);
            $215 = HEAP32[$214>>2]|0;
            $216 = (_strcmp($215,$28)|0);
            $217 = ($216|0)==(0);
            $212 = (($i$01$us$i) + 1)|0;
            if ($217) {
             $$lcssa$i = $213;
             label = 87;
             break L95;
            }
            $211 = ($212|0)<(77);
            if ($211) {
             $i$01$us$i = $212;
            } else {
             $$0$i16 = 0;
             break;
            }
           }
          } else {
           $210 = HEAP32[$29>>2]|0;
           $i$01$i = 0;
           while(1) {
            $220 = $i$01$i << 1;
            $221 = (642856 + ($220<<2)|0);
            $222 = HEAP32[$221>>2]|0;
            $223 = (_strcmp($222,$210)|0);
            $224 = ($223|0)==(0);
            $219 = (($i$01$i) + 1)|0;
            if ($224) {
             $$lcssa$i = $220;
             label = 87;
             break L95;
            }
            $218 = ($219|0)<(77);
            if ($218) {
             $i$01$i = $219;
            } else {
             $$0$i16 = 0;
             break;
            }
           }
          }
         } while(0);
         if ((label|0) == 87) {
          label = 0;
          $225 = $$lcssa$i | 1;
          $226 = (642856 + ($225<<2)|0);
          $227 = HEAP32[$226>>2]|0;
          $$0$i16 = $227;
         }
         $228 = $208 & 1;
         $229 = ($228<<24>>24)==(0);
         if (!($229)) {
          $230 = HEAP32[$29>>2]|0;
          __ZdlPv($230);
         }
         $231 = ($$0$i16|0)==(0|0);
         if (!($231)) {
          $232 = $163 & 1;
          $233 = ($232<<24>>24)==(0);
          $234 = HEAP32[$27>>2]|0;
          $$86 = $233 ? $24 : $234;
          $235 = (_strcmp($$86,$$0$i16)|0);
          $236 = ($235|0)==(0);
          if ($236) {
           $$01 = 4;$shader$1 = $$in;
           break;
          }
         }
         $$01 = 0;$shader$1 = $shader$078;
        }
       } while(0);
       $237 = $163 & 1;
       $238 = ($237<<24>>24)==(0);
       if (!($238)) {
        $239 = HEAP32[$27>>2]|0;
        __ZdlPv($239);
       }
       $cond = ($$01|0)==(4);
       if ($cond) {
        $shader$3 = $shader$1;
        label = 103;
        break L12;
       } else {
        $shader$2 = $shader$1;
       }
      }
     } while(0);
     $240 = (($i$077) + 1)|0;
     $241 = HEAP32[$20>>2]|0;
     $242 = HEAP32[$shaderLookup>>2]|0;
     $243 = $241;
     $244 = $242;
     $245 = (($243) - ($244))|0;
     $246 = $245 >> 2;
     $247 = ($240>>>0)<($246>>>0);
     if ($247) {
      $37 = $242;$i$077 = $240;$shader$078 = $shader$2;
     } else {
      $shader$3 = $shader$2;
      label = 103;
      break L12;
     }
    }
    do {
     if ((label|0) == 24) {
      $76 = ___cxa_find_matching_catch()|0;
      $77 = tempRet0;
      $eh$lpad$body$index6Z2D = $77;$eh$lpad$body$indexZ2D = $76;
      label = 26;
      break L12;
     }
     else if ((label|0) == 31) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      if ($90) {
       label = 25;
       break L12;
      }
      // unreachable;
     }
     else if ((label|0) == 46) {
      $124 = ___cxa_find_matching_catch()|0;
      $125 = tempRet0;
      $126 = HEAP8[$saveShaderName$i>>0]|0;
      $127 = $126 & 1;
      $128 = ($127<<24>>24)==(0);
      if ($128) {
       $eh$lpad$body$index6Z2D = $125;$eh$lpad$body$indexZ2D = $124;
       label = 26;
       break L12;
      }
      $129 = HEAP32[$33>>2]|0;
      __ZdlPv($129);
      $eh$lpad$body$index6Z2D = $125;$eh$lpad$body$indexZ2D = $124;
      label = 26;
      break L12;
     }
     else if ((label|0) == 52) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $147 = __THREW__; __THREW__ = 0;
      $148 = $147&1;
      if ($148) {
       label = 25;
       break L12;
      }
      // unreachable;
     }
     else if ((label|0) == 75) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $194 = __THREW__; __THREW__ = 0;
      $195 = $194&1;
      if ($195) {
       $250 = ___cxa_find_matching_catch()|0;
       $251 = tempRet0;
       $lpad$phi69$index = $250;$lpad$phi69$index15 = $251;
       break;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 97) {
      $248 = ___cxa_find_matching_catch()|0;
      $249 = tempRet0;
      $lpad$phi69$index = $248;$lpad$phi69$index15 = $249;
     }
    } while(0);
    $252 = $163 & 1;
    $253 = ($252<<24>>24)==(0);
    if ($253) {
     $$1 = $lpad$phi69$index15;$$14 = $lpad$phi69$index;
    } else {
     $254 = HEAP32[$27>>2]|0;
     __ZdlPv($254);
     $$1 = $lpad$phi69$index15;$$14 = $lpad$phi69$index;
    }
   }
  } else {
   __THREW__ = 0;
   $255 = (invoke_ii(3310,4)|0);
   $256 = __THREW__; __THREW__ = 0;
   $257 = $256&1;
   if ($257) {
    label = 25;
   } else {
    __THREW__ = 0;
    $258 = (invoke_iii(2366,($255|0),($name|0))|0);
    $259 = __THREW__; __THREW__ = 0;
    $260 = $259&1;
    if ($260) {
     label = 25;
    } else {
     $shader$3 = $258;
     label = 103;
    }
   }
  }
 } while(0);
 L134: do {
  if ((label|0) == 103) {
   __THREW__ = 0;
   (invoke_iii(2233,(674240|0),($saveShaderName|0))|0);
   $261 = __THREW__; __THREW__ = 0;
   $262 = $261&1;
   if ($262) {
    label = 25;
   } else {
    $263 = ($shader$3|0)==(0|0);
    L137: do {
     if ($263) {
      $$0 = 0;
     } else {
      $264 = (($shader$3) + 89|0);
      $265 = HEAP8[$264>>0]|0;
      $266 = ($265<<24>>24)==(0);
      do {
       if (!($266)) {
        $267 = HEAP8[674240>>0]|0;
        $268 = $267 & 1;
        $269 = ($268<<24>>24)==(0);
        if ($269) {
         ;HEAP32[$saveShaderName$i23+0>>2]=HEAP32[674240+0>>2]|0;HEAP32[$saveShaderName$i23+4>>2]=HEAP32[674240+4>>2]|0;HEAP32[$saveShaderName$i23+8>>2]=HEAP32[674240+8>>2]|0;
        } else {
         $270 = HEAP32[((674240 + 8|0))>>2]|0;
         $271 = HEAP32[((674240 + 4|0))>>2]|0;
         $272 = ($271>>>0)>(4294967279);
         if ($272) {
          __THREW__ = 0;
          invoke_vi(3309,0);
          $273 = __THREW__; __THREW__ = 0;
          $274 = $273&1;
          if ($274) {
           label = 25;
           break L134;
          }
          // unreachable;
         }
         $275 = ($271>>>0)<(11);
         if ($275) {
          $276 = $271 << 1;
          $277 = $276&255;
          HEAP8[$saveShaderName$i23>>0] = $277;
          $278 = (($saveShaderName$i23) + 1|0);
          $__p$0$i$i$i33 = $278;
         } else {
          $279 = (($271) + 16)|0;
          $280 = $279 & -16;
          __THREW__ = 0;
          $281 = (invoke_ii(2988,($280|0))|0);
          $282 = __THREW__; __THREW__ = 0;
          $283 = $282&1;
          if ($283) {
           label = 25;
           break L134;
          }
          $284 = (($saveShaderName$i23) + 8|0);
          HEAP32[$284>>2] = $281;
          $285 = $280 | 1;
          HEAP32[$saveShaderName$i23>>2] = $285;
          $286 = (($saveShaderName$i23) + 4|0);
          HEAP32[$286>>2] = $271;
          $__p$0$i$i$i33 = $281;
         }
         _memcpy(($__p$0$i$i$i33|0),($270|0),($271|0))|0;
         $287 = (($__p$0$i$i$i33) + ($271)|0);
         HEAP8[$287>>0] = 0;
        }
        $288 = (($shader$3) + 40|0);
        $289 = HEAP8[$288>>0]|0;
        $290 = $289 & 1;
        $291 = ($290<<24>>24)==(0);
        if ($291) {
         $296 = (($288) + 1|0);
         $297 = $289&255;
         $298 = $297 >>> 1;
         $299 = $296;$300 = $298;
        } else {
         $292 = (($shader$3) + 48|0);
         $293 = HEAP32[$292>>2]|0;
         $294 = (($shader$3) + 44|0);
         $295 = HEAP32[$294>>2]|0;
         $299 = $293;$300 = $295;
        }
        __THREW__ = 0;
        invoke_viii(1933,($shader$3|0),($299|0),($300|0));
        $301 = __THREW__; __THREW__ = 0;
        $302 = $301&1;
        if (!($302)) {
         __THREW__ = 0;
         invoke_vi(3577,($shader$3|0));
         $303 = __THREW__; __THREW__ = 0;
         $304 = $303&1;
         if (!($304)) {
          __THREW__ = 0;
          (invoke_iii(2233,(674240|0),($saveShaderName$i23|0))|0);
          $305 = __THREW__; __THREW__ = 0;
          $306 = $305&1;
          if (!($306)) {
           $307 = HEAP8[$saveShaderName$i23>>0]|0;
           $308 = $307 & 1;
           $309 = ($308<<24>>24)==(0);
           if ($309) {
            break;
           }
           $310 = (($saveShaderName$i23) + 8|0);
           $311 = HEAP32[$310>>2]|0;
           __ZdlPv($311);
           break;
          }
         }
        }
        $312 = ___cxa_find_matching_catch()|0;
        $313 = tempRet0;
        $314 = HEAP8[$saveShaderName$i23>>0]|0;
        $315 = $314 & 1;
        $316 = ($315<<24>>24)==(0);
        if ($316) {
         $eh$lpad$body$index6Z2D = $313;$eh$lpad$body$indexZ2D = $312;
         label = 26;
         break L134;
        }
        $317 = (($saveShaderName$i23) + 8|0);
        $318 = HEAP32[$317>>2]|0;
        __ZdlPv($318);
        $eh$lpad$body$index6Z2D = $313;$eh$lpad$body$indexZ2D = $312;
        label = 26;
        break L134;
       }
      } while(0);
      if ($useLookup) {
       $$0 = $shader$3;
      } else {
       $319 = (($shader$3) + 4|0);
       $320 = HEAP32[$319>>2]|0;
       HEAP32[$shaderPtr>>2] = $320;
       $321 = HEAP32[$shaderLookup>>2]|0;
       $322 = (($shaderLookup) + 4|0);
       $323 = HEAP32[$322>>2]|0;
       $324 = ($321|0)==($323|0);
       L167: do {
        if ($324) {
         $334 = $321;
        } else {
         $326 = $321;
         while(1) {
          $325 = HEAP32[$326>>2]|0;
          $327 = ($325|0)==($320|0);
          if ($327) {
           break;
          }
          $328 = (($326) + 4|0);
          $329 = ($328|0)==($323|0);
          if ($329) {
           $334 = $323;
           break L167;
          } else {
           $326 = $328;
          }
         }
         $330 = ($326|0)==($323|0);
         if ($330) {
          $334 = $323;
         } else {
          $$0 = $shader$3;
          break L137;
         }
        }
       } while(0);
       $331 = (($shaderLookup) + 8|0);
       $332 = HEAP32[$331>>2]|0;
       $333 = ($334|0)==($332|0);
       if ($333) {
        __THREW__ = 0;
        invoke_vii(3242,($shaderLookup|0),($shaderPtr|0));
        $337 = __THREW__; __THREW__ = 0;
        $338 = $337&1;
        if ($338) {
         label = 25;
         break L134;
        } else {
         $$0 = $shader$3;
         break;
        }
       }
       $335 = ($334|0)==(0|0);
       if (!($335)) {
        HEAP32[$334>>2] = $320;
       }
       $336 = (($334) + 4|0);
       HEAP32[$322>>2] = $336;
       $$0 = $shader$3;
      }
     }
    } while(0);
    $339 = HEAP8[$saveShaderName>>0]|0;
    $340 = $339 & 1;
    $341 = ($340<<24>>24)==(0);
    if ($341) {
     STACKTOP = sp;return ($$0|0);
    }
    $342 = (($saveShaderName) + 8|0);
    $343 = HEAP32[$342>>2]|0;
    __ZdlPv($343);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 if ((label|0) == 25) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  $eh$lpad$body$index6Z2D = $79;$eh$lpad$body$indexZ2D = $78;
  label = 26;
 }
 if ((label|0) == 26) {
  $$1 = $eh$lpad$body$index6Z2D;$$14 = $eh$lpad$body$indexZ2D;
 }
 $344 = HEAP8[$saveShaderName>>0]|0;
 $345 = $344 & 1;
 $346 = ($345<<24>>24)==(0);
 if ($346) {
  ___resumeException($$14|0);
  // unreachable;
 }
 $347 = (($saveShaderName) + 8|0);
 $348 = HEAP32[$347>>2]|0;
 __ZdlPv($348);
 ___resumeException($$14|0);
 // unreachable;
 return 0|0;
}
function __ZN12ScriptMapperD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12ScriptMapperD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapperD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3583,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrI6ShaderENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$01$i$i = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = $12 >> 2;
 $14 = ($13>>>0)<(536870911);
 if ($14) {
  $15 = $12 >> 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 1073741823;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = $$0$i2 << 2;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + ($6<<2)|0);
 $23 = (($22) + ($$0$i3<<2)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  $25 = HEAP32[$__x>>2]|0;
  HEAP32[$21>>2] = $25;
 }
 $26 = (($22) + ($7<<2)|0);
 $27 = ($1|0)==($2|0);
 if ($27) {
  $37 = $21;$39 = $1;
 } else {
  $scevgep$i$i = (($1) + -4|0);
  $28 = (0 - ($4))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($28)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $1;$32 = $21;
  while(1) {
   $29 = (($$01$i$i) + -4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($32) + -4|0);
   HEAP32[$31>>2] = $30;
   $33 = (($32) + -4|0);
   $34 = ($29|0)==($2|0);
   if ($34) {
    break;
   } else {
    $$01$i$i = $29;$32 = $33;
   }
  }
  $35 = $uglygep4$i$i >>> 2;
  $36 = $35 ^ -1;
  $$sum1 = (($6) + ($36))|0;
  $scevgep5$i$i = (($22) + ($$sum1<<2)|0);
  $37 = $scevgep5$i$i;$39 = $2;
 }
 HEAP32[$this>>2] = $37;
 HEAP32[$0>>2] = $26;
 HEAP32[$9>>2] = $23;
 $38 = ($39|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 __ZdlPv($39);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0$i$i$i$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i$i$i$i$i1 = 0, $$01$i$i$i$i$i$i$i$i$i$i = 0, $$01$i$i$i$i$i$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 33554432;
 $2 = ($1|0)==(0);
 if ($2) {
  $33 = (($this) + 28|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($this) + 32|0);
  $36 = ($34|0)==($35|0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $37 = (($transfer) + 12|0);
  $38 = (($transfer) + 28|0);
  $39 = (($transfer) + 32|0);
  $41 = $34;
  while(1) {
   $40 = (($41) + 16|0);
   $42 = HEAP32[$40>>2]|0;
   $43 = HEAP32[$37>>2]|0;
   $44 = HEAP32[$43>>2]|0;
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$38>>2]|0;
   $47 = (FUNCTION_TABLE_iiii[$45 & 2047]($43,$42,$46)|0);
   $48 = HEAP8[$39>>0]|0;
   $49 = ($48<<24>>24)==(0);
   if (!($49)) {
    HEAP32[$40>>2] = $47;
   }
   $50 = (($41) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    $$01$i$i$i$i$i$i$i$i$i$i = $41;
    while(1) {
     $55 = (($$01$i$i$i$i$i$i$i$i$i$i) + 8|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==($$01$i$i$i$i$i$i$i$i$i$i|0);
     if ($58) {
      $$0$i$i$i$i$i$i$i$i$i$i = $56;
      break;
     } else {
      $$01$i$i$i$i$i$i$i$i$i$i = $56;
     }
    }
   } else {
    $$0$i$i$i$i$i$i$i$i$i$i$i = $51;
    while(1) {
     $53 = HEAP32[$$0$i$i$i$i$i$i$i$i$i$i$i>>2]|0;
     $54 = ($53|0)==(0|0);
     if ($54) {
      $$0$i$i$i$i$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i$i$i$i$i$i = $53;
     }
    }
   }
   $59 = ($$0$i$i$i$i$i$i$i$i$i$i|0)==($35|0);
   if ($59) {
    break;
   } else {
    $41 = $$0$i$i$i$i$i$i$i$i$i$i;
   }
  }
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 32|0);
 $9 = ($7|0)==($8|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($transfer) + 12|0);
 $11 = (($transfer) + 28|0);
 $12 = (($transfer) + 32|0);
 $14 = $7;
 while(1) {
  $13 = (($14) + 16|0);
  $15 = HEAP32[$13>>2]|0;
  $16 = HEAP32[$10>>2]|0;
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$11>>2]|0;
  $20 = (FUNCTION_TABLE_iiii[$18 & 2047]($16,$15,$19)|0);
  $21 = HEAP8[$12>>0]|0;
  $22 = ($21<<24>>24)==(0);
  if (!($22)) {
   HEAP32[$13>>2] = $20;
  }
  $23 = (($14) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $$01$i$i$i$i$i$i$i$i$i$i$i = $14;
   while(1) {
    $28 = (($$01$i$i$i$i$i$i$i$i$i$i$i) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==($$01$i$i$i$i$i$i$i$i$i$i$i|0);
    if ($31) {
     $$0$i$i$i$i$i$i$i$i$i$i$i1 = $29;
     break;
    } else {
     $$01$i$i$i$i$i$i$i$i$i$i$i = $29;
    }
   }
  } else {
   $$0$i$i$i$i$i$i$i$i$i$i$i$i = $24;
   while(1) {
    $26 = HEAP32[$$0$i$i$i$i$i$i$i$i$i$i$i$i>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     $$0$i$i$i$i$i$i$i$i$i$i$i1 = $$0$i$i$i$i$i$i$i$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i$i$i$i$i$i$i$i = $26;
    }
   }
  }
  $32 = ($$0$i$i$i$i$i$i$i$i$i$i$i1|0)==($8|0);
  if ($32) {
   break;
  } else {
   $14 = $$0$i$i$i$i$i$i$i$i$i$i$i1;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE7RebuildEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01 = 0, $$01$i$i$i$i = 0, $$1 = 0, $$12 = 0, $$byval_copy43 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i$i$i = 0, $__parent$i$i = 0, $eh$lpad$body$i$index8Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index26Z2D = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$index = 0;
 var $lpad$phi$index14 = 0, $lpad$phi20$index = 0, $lpad$phi20$index19 = 0, $lpad$phi30$index = 0, $lpad$phi30$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy43 = sp + 112|0;
 $0 = sp + 108|0;
 $1 = sp + 104|0;
 $2 = sp + 100|0;
 $3 = sp + 96|0;
 $4 = sp + 92|0;
 $5 = sp + 88|0;
 $__parent$i$i = sp + 84|0;
 $6 = sp + 80|0;
 $7 = sp + 64|0;
 $8 = sp + 48|0;
 $9 = sp + 44|0;
 $10 = sp + 40|0;
 $11 = sp + 36|0;
 $12 = sp + 32|0;
 $13 = sp + 16|0;
 $14 = sp;
 $15 = sp + 52|0;
 $16 = (($this) + 12|0);
 $17 = (($this) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($16,$18);
 $19 = (($this) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 16|0);
 HEAP32[$16>>2] = $20;
 HEAP32[$20>>2] = 0;
 $21 = HEAP32[$this>>2]|0;
 $22 = (($this) + 4|0);
 $23 = ($21|0)==($22|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($15) + 1|0);
 $25 = (($14) + 1|0);
 $26 = (($14) + 12|0);
 $27 = (($13) + 1|0);
 $28 = (($13) + 12|0);
 $29 = (($7) + 1|0);
 $30 = (($7) + 12|0);
 $31 = (($15) + 8|0);
 $32 = (($14) + 8|0);
 $33 = (($13) + 8|0);
 $34 = (($7) + 8|0);
 $35 = (($7) + 4|0);
 $36 = (($13) + 4|0);
 $37 = (($14) + 4|0);
 $38 = (($15) + 4|0);
 $40 = $21;
 while(1) {
  $39 = (($40) + 20|0);
  $41 = HEAP8[$39>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   $48 = (($39) + 1|0);
   $49 = $41&255;
   $50 = $49 >>> 1;
   $52 = $50;$61 = $48;
  } else {
   $44 = (($40) + 28|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($40) + 24|0);
   $47 = HEAP32[$46>>2]|0;
   $52 = $47;$61 = $45;
  }
  $51 = ($52>>>0)>(2147483631);
  if ($51) {
   label = 7;
   break;
  }
  $53 = ($52>>>0)<(11);
  if ($53) {
   $54 = $52 << 1;
   $55 = $54&255;
   HEAP8[$15>>0] = $55;
   $66 = $55;$__p$0$i$i$i$i = $24;
  } else {
   $56 = (($52) + 16)|0;
   $57 = $56 & -16;
   HEAP32[$3>>2] = 59;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$3+0>>2]|0;
   $58 = (__Z15malloc_internaljj10MemLabelIdiPKci($57,16,$$byval_copy43,0,642768,79)|0);
   HEAP32[$31>>2] = $58;
   $59 = $57 | 1;
   HEAP32[$15>>2] = $59;
   HEAP32[$38>>2] = $52;
   $60 = $59&255;
   $66 = $60;$__p$0$i$i$i$i = $58;
  }
  _memcpy(($__p$0$i$i$i$i|0),($61|0),($52|0))|0;
  $62 = (($__p$0$i$i$i$i) + ($52)|0);
  HEAP8[$62>>0] = 0;
  $63 = (($40) + 16|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = $66 & 1;
  $67 = ($65<<24>>24)==(0);
  if ($67) {
   $70 = $66&255;
   $71 = $70 >>> 1;
   $73 = $71;$86 = $24;
  } else {
   $68 = HEAP32[$31>>2]|0;
   $69 = HEAP32[$38>>2]|0;
   $73 = $69;$86 = $68;
  }
  $72 = ($73>>>0)>(2147483631);
  if ($72) {
   label = 15;
   break;
  }
  $76 = ($73>>>0)<(11);
  if ($76) {
   $77 = $73 << 1;
   $78 = $77&255;
   HEAP8[$14>>0] = $78;
   $89 = $78;$__p$0$i$i$i$i$i$i$i = $25;
  } else {
   $79 = (($73) + 16)|0;
   $80 = $79 & -16;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$9+0>>2]|0;
   $81 = (invoke_iiiiiii(102,($80|0),16,($$byval_copy43|0),0,(642768|0),79)|0);
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    label = 79;
    break;
   }
   HEAP32[$32>>2] = $81;
   $84 = $80 | 1;
   HEAP32[$14>>2] = $84;
   HEAP32[$37>>2] = $73;
   $85 = $84&255;
   $89 = $85;$__p$0$i$i$i$i$i$i$i = $81;
  }
  _memcpy(($__p$0$i$i$i$i$i$i$i|0),($86|0),($73|0))|0;
  $87 = (($__p$0$i$i$i$i$i$i$i) + ($73)|0);
  HEAP8[$87>>0] = 0;
  HEAP32[$26>>2] = $64;
  $88 = $89 & 1;
  $90 = ($88<<24>>24)==(0);
  if ($90) {
   $93 = $89&255;
   $94 = $93 >>> 1;
   $109 = $25;$96 = $94;
  } else {
   $91 = HEAP32[$32>>2]|0;
   $92 = HEAP32[$37>>2]|0;
   $109 = $91;$96 = $92;
  }
  $95 = ($96>>>0)>(2147483631);
  if ($95) {
   label = 25;
   break;
  }
  $99 = ($96>>>0)<(11);
  if ($99) {
   $100 = $96 << 1;
   $101 = $100&255;
   HEAP8[$13>>0] = $101;
   $112 = $101;$__p$0$i$i$i$i$i$i = $27;
  } else {
   $102 = (($96) + 16)|0;
   $103 = $102 & -16;
   HEAP32[$8>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$8+0>>2]|0;
   $104 = (invoke_iiiiiii(102,($103|0),16,($$byval_copy43|0),0,(642768|0),79)|0);
   $105 = __THREW__; __THREW__ = 0;
   $106 = $105&1;
   if ($106) {
    label = 82;
    break;
   }
   HEAP32[$33>>2] = $104;
   $107 = $103 | 1;
   HEAP32[$13>>2] = $107;
   HEAP32[$36>>2] = $96;
   $108 = $107&255;
   $112 = $108;$__p$0$i$i$i$i$i$i = $104;
  }
  _memcpy(($__p$0$i$i$i$i$i$i|0),($109|0),($96|0))|0;
  $110 = (($__p$0$i$i$i$i$i$i) + ($96)|0);
  HEAP8[$110>>0] = 0;
  HEAP32[$28>>2] = $64;
  $111 = $112 & 1;
  $113 = ($111<<24>>24)==(0);
  if ($113) {
   $116 = $112&255;
   $117 = $116 >>> 1;
   $119 = $117;$131 = $27;
  } else {
   $114 = HEAP32[$33>>2]|0;
   $115 = HEAP32[$36>>2]|0;
   $119 = $115;$131 = $114;
  }
  $118 = ($119>>>0)>(2147483631);
  if ($118) {
   label = 35;
   break;
  }
  $122 = ($119>>>0)<(11);
  if ($122) {
   $123 = $119 << 1;
   $124 = $123&255;
   HEAP8[$7>>0] = $124;
   $__p$0$i$i$i$i$i$i$i$i$i = $29;
  } else {
   $125 = (($119) + 16)|0;
   $126 = $125 & -16;
   HEAP32[$6>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$6+0>>2]|0;
   $127 = (invoke_iiiiiii(102,($126|0),16,($$byval_copy43|0),0,(642768|0),79)|0);
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    label = 85;
    break;
   }
   HEAP32[$34>>2] = $127;
   $130 = $126 | 1;
   HEAP32[$7>>2] = $130;
   HEAP32[$35>>2] = $119;
   $__p$0$i$i$i$i$i$i$i$i$i = $127;
  }
  _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($131|0),($119|0))|0;
  $132 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($119)|0);
  HEAP8[$132>>0] = 0;
  HEAP32[$30>>2] = $64;
  $133 = (__ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS6_($16,$__parent$i$i,$7)|0);
  __THREW__ = 0;
  $134 = (invoke_ii(2988,32)|0);
  $135 = __THREW__; __THREW__ = 0;
  $136 = $135&1;
  if ($136) {
   label = 61;
   break;
  }
  $137 = (($134) + 16|0);
  $138 = HEAP8[$7>>0]|0;
  $139 = $138 & 1;
  $140 = ($139<<24>>24)==(0);
  if ($140) {
   $143 = $138&255;
   $144 = $143 >>> 1;
   $146 = $144;$166 = $29;
  } else {
   $141 = HEAP32[$34>>2]|0;
   $142 = HEAP32[$35>>2]|0;
   $146 = $142;$166 = $141;
  }
  $145 = ($146>>>0)>(2147483631);
  if ($145) {
   label = 46;
   break;
  }
  $149 = ($146>>>0)<(11);
  if ($149) {
   $150 = $146 << 1;
   $151 = $150&255;
   HEAP8[$137>>0] = $151;
   $152 = (($134) + 17|0);
   $__p$0$i$i$i$i$i$i$i$i$i$i$i = $152;
  } else {
   $153 = (($146) + 16)|0;
   $154 = $153 & -16;
   HEAP32[$5>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$5+0>>2]|0;
   $155 = (invoke_iiiiiii(102,($154|0),16,($$byval_copy43|0),0,(642768|0),79)|0);
   $156 = __THREW__; __THREW__ = 0;
   $157 = $156&1;
   if ($157) {
    label = 52;
    break;
   }
   $158 = (($134) + 24|0);
   HEAP32[$158>>2] = $155;
   $159 = $154 | 1;
   HEAP32[$137>>2] = $159;
   $160 = (($134) + 20|0);
   HEAP32[$160>>2] = $146;
   $__p$0$i$i$i$i$i$i$i$i$i$i$i = $155;
  }
  _memcpy(($__p$0$i$i$i$i$i$i$i$i$i$i$i|0),($166|0),($146|0))|0;
  $167 = (($__p$0$i$i$i$i$i$i$i$i$i$i$i) + ($146)|0);
  HEAP8[$167>>0] = 0;
  $168 = HEAP32[$30>>2]|0;
  $169 = (($134) + 28|0);
  HEAP32[$169>>2] = $168;
  $170 = HEAP32[$__parent$i$i>>2]|0;
  HEAP32[$134>>2] = 0;
  $171 = (($134) + 4|0);
  HEAP32[$171>>2] = 0;
  $172 = (($134) + 8|0);
  HEAP32[$172>>2] = $170;
  HEAP32[$133>>2] = $134;
  $173 = HEAP32[$16>>2]|0;
  $174 = HEAP32[$173>>2]|0;
  $175 = ($174|0)==(0|0);
  if ($175) {
   $177 = $134;
  } else {
   HEAP32[$16>>2] = $174;
   $$pre$i$i$i = HEAP32[$133>>2]|0;
   $177 = $$pre$i$i$i;
  }
  $176 = HEAP32[$17>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($176,$177);
  $178 = HEAP32[$19>>2]|0;
  $179 = (($178) + 1)|0;
  HEAP32[$19>>2] = $179;
  if (!($140)) {
   $180 = HEAP32[$34>>2]|0;
   HEAP32[$4>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($180|0),($$byval_copy43|0));
   $181 = __THREW__; __THREW__ = 0;
   $182 = $181&1;
   if ($182) {
    label = 60;
    break;
   }
  }
  $195 = $112 & 1;
  $196 = ($195<<24>>24)==(0);
  if (!($196)) {
   $197 = HEAP32[$33>>2]|0;
   HEAP32[$2>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($197|0),($$byval_copy43|0));
   $198 = __THREW__; __THREW__ = 0;
   $199 = $198&1;
   if ($199) {
    label = 67;
    break;
   }
  }
  $202 = $89 & 1;
  $203 = ($202<<24>>24)==(0);
  if (!($203)) {
   $204 = HEAP32[$32>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($204|0),($$byval_copy43|0));
   $205 = __THREW__; __THREW__ = 0;
   $206 = $205&1;
   if ($206) {
    label = 70;
    break;
   }
  }
  $209 = $66 & 1;
  $210 = ($209<<24>>24)==(0);
  if (!($210)) {
   $211 = HEAP32[$31>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($211|0),($$byval_copy43|0));
   $212 = __THREW__; __THREW__ = 0;
   $213 = $212&1;
   if ($213) {
    label = 73;
    break;
   }
  }
  $216 = (($40) + 4|0);
  $217 = HEAP32[$216>>2]|0;
  $218 = ($217|0)==(0|0);
  if ($218) {
   $$01$i$i$i$i = $40;
   while(1) {
    $221 = (($$01$i$i$i$i) + 8|0);
    $222 = HEAP32[$221>>2]|0;
    $223 = HEAP32[$222>>2]|0;
    $224 = ($223|0)==($$01$i$i$i$i|0);
    if ($224) {
     $$0$i$i$i$i = $222;
     break;
    } else {
     $$01$i$i$i$i = $222;
    }
   }
  } else {
   $$0$i$i$i$i$i = $217;
   while(1) {
    $219 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $220 = ($219|0)==(0|0);
    if ($220) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $219;
    }
   }
  }
  $225 = ($$0$i$i$i$i|0)==($22|0);
  if ($225) {
   label = 96;
   break;
  } else {
   $40 = $$0$i$i$i$i;
  }
 }
 switch (label|0) {
  case 7: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 15: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    $228 = ___cxa_find_matching_catch()|0;
    $229 = tempRet0;
    $lpad$phi$index = $228;$lpad$phi$index14 = $229;
    label = 81;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 25: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   if ($98) {
    $232 = ___cxa_find_matching_catch()|0;
    $233 = tempRet0;
    $lpad$phi20$index = $232;$lpad$phi20$index19 = $233;
    label = 84;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 35: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    $236 = ___cxa_find_matching_catch()|0;
    $237 = tempRet0;
    $eh$lpad$body$index26Z2D = $237;$eh$lpad$body$indexZ2D = $236;
    label = 87;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 46: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $147 = __THREW__; __THREW__ = 0;
   $148 = $147&1;
   if ($148) {
    $163 = ___cxa_find_matching_catch()|0;
    $164 = tempRet0;
    $lpad$phi30$index = $163;$lpad$phi30$index2 = $164;
    label = 54;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 52: {
   $161 = ___cxa_find_matching_catch()|0;
   $162 = tempRet0;
   $lpad$phi30$index = $161;$lpad$phi30$index2 = $162;
   label = 54;
   break;
  }
  case 60: {
   $183 = ___cxa_find_matching_catch()|0;
   $184 = tempRet0;
   ___cxa_call_unexpected(($183|0));
   // unreachable;
   break;
  }
  case 61: {
   $185 = ___cxa_find_matching_catch()|0;
   $186 = tempRet0;
   $$pre$i = HEAP8[$7>>0]|0;
   $188 = $$pre$i;$eh$lpad$body$i$index8Z2D = $186;$eh$lpad$body$i$indexZ2D = $185;
   label = 62;
   break;
  }
  case 67: {
   $200 = ___cxa_find_matching_catch()|0;
   $201 = tempRet0;
   ___cxa_call_unexpected(($200|0));
   // unreachable;
   break;
  }
  case 70: {
   $207 = ___cxa_find_matching_catch()|0;
   $208 = tempRet0;
   ___cxa_call_unexpected(($207|0));
   // unreachable;
   break;
  }
  case 73: {
   $214 = ___cxa_find_matching_catch()|0;
   $215 = tempRet0;
   ___cxa_call_unexpected(($214|0));
   // unreachable;
   break;
  }
  case 79: {
   $226 = ___cxa_find_matching_catch()|0;
   $227 = tempRet0;
   $lpad$phi$index = $226;$lpad$phi$index14 = $227;
   label = 81;
   break;
  }
  case 82: {
   $230 = ___cxa_find_matching_catch()|0;
   $231 = tempRet0;
   $lpad$phi20$index = $230;$lpad$phi20$index19 = $231;
   label = 84;
   break;
  }
  case 85: {
   $234 = ___cxa_find_matching_catch()|0;
   $235 = tempRet0;
   $eh$lpad$body$index26Z2D = $235;$eh$lpad$body$indexZ2D = $234;
   label = 87;
   break;
  }
  case 96: {
   STACKTOP = sp;return;
   break;
  }
 }
 if ((label|0) == 54) {
  $165 = ($134|0)==(0|0);
  if ($165) {
   $188 = $138;$eh$lpad$body$i$index8Z2D = $lpad$phi30$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi30$index;
   label = 62;
  } else {
   __ZdlPv($134);
   $188 = $138;$eh$lpad$body$i$index8Z2D = $lpad$phi30$index2;$eh$lpad$body$i$indexZ2D = $lpad$phi30$index;
   label = 62;
  }
 }
 else if ((label|0) == 81) {
  $$1 = $lpad$phi$index14;$$12 = $lpad$phi$index;
 }
 else if ((label|0) == 84) {
  $$0 = $lpad$phi20$index19;$$01 = $lpad$phi20$index;
  label = 90;
 }
 if ((label|0) == 62) {
  $187 = $188 & 1;
  $189 = ($187<<24>>24)==(0);
  if ($189) {
   $eh$lpad$body$index26Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
   label = 87;
  } else {
   $190 = HEAP32[$34>>2]|0;
   HEAP32[$3>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($190|0),($$byval_copy43|0));
   $191 = __THREW__; __THREW__ = 0;
   $192 = $191&1;
   if ($192) {
    $193 = ___cxa_find_matching_catch()|0;
    $194 = tempRet0;
    ___cxa_call_unexpected(($193|0));
    // unreachable;
   } else {
    $eh$lpad$body$index26Z2D = $eh$lpad$body$i$index8Z2D;$eh$lpad$body$indexZ2D = $eh$lpad$body$i$indexZ2D;
    label = 87;
   }
  }
 }
 if ((label|0) == 87) {
  $238 = $112 & 1;
  $239 = ($238<<24>>24)==(0);
  if ($239) {
   $$0 = $eh$lpad$body$index26Z2D;$$01 = $eh$lpad$body$indexZ2D;
   label = 90;
  } else {
   $240 = HEAP32[$33>>2]|0;
   HEAP32[$10>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$10+0>>2]|0;
   invoke_vii(2591,($240|0),($$byval_copy43|0));
   $241 = __THREW__; __THREW__ = 0;
   $242 = $241&1;
   if ($242) {
    $243 = ___cxa_find_matching_catch()|0;
    $244 = tempRet0;
    ___cxa_call_unexpected(($243|0));
    // unreachable;
   } else {
    $$0 = $eh$lpad$body$index26Z2D;$$01 = $eh$lpad$body$indexZ2D;
    label = 90;
   }
  }
 }
 if ((label|0) == 90) {
  $245 = $89 & 1;
  $246 = ($245<<24>>24)==(0);
  if ($246) {
   $$1 = $$0;$$12 = $$01;
  } else {
   $247 = HEAP32[$32>>2]|0;
   HEAP32[$11>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$11+0>>2]|0;
   invoke_vii(2591,($247|0),($$byval_copy43|0));
   $248 = __THREW__; __THREW__ = 0;
   $249 = $248&1;
   if ($249) {
    $250 = ___cxa_find_matching_catch()|0;
    $251 = tempRet0;
    ___cxa_call_unexpected(($250|0));
    // unreachable;
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 }
 $252 = $66 & 1;
 $253 = ($252<<24>>24)==(0);
 if ($253) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $254 = HEAP32[$31>>2]|0;
 HEAP32[$12>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$12+0>>2]|0;
 invoke_vii(2591,($254|0),($$byval_copy43|0));
 $255 = __THREW__; __THREW__ = 0;
 $256 = $255&1;
 if ($256) {
  $257 = ___cxa_find_matching_catch()|0;
  $258 = tempRet0;
  ___cxa_call_unexpected(($257|0));
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE16__find_leaf_highERPNS_16__tree_node_baseIPvEERKS6_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0 = 0, $$lcssa = 0, $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, $__nd$0$in$lcssa = 0, $__nd$0$in$lcssa1 = 0, $__nd$0$in$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $63 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $63;
  $$0 = $63;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 if ($5) {
  $__nd$0$in$us = $1;
  while(1) {
   $11 = (($__nd$0$in$us) + 16|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = $12 & 1;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $19 = $12&255;
    $20 = $19 >>> 1;
    $21 = (($11) + 1|0);
    $23 = $20;$25 = $21;
   } else {
    $15 = (($__nd$0$in$us) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($__nd$0$in$us) + 24|0);
    $18 = HEAP32[$17>>2]|0;
    $23 = $16;$25 = $18;
   }
   $22 = ($23>>>0)<($7>>>0);
   $24 = $22 ? $23 : $7;
   $26 = (_memcmp($8,$25,$24)|0);
   $27 = ($26|0)==(0);
   if ($27) {
    $28 = ($7>>>0)<($23>>>0);
    $$$i$i$i$i$us = $22&1;
    $$$$i$i$i$i$us = $28 ? -1 : $$$i$i$i$i$us;
    $30 = $$$$i$i$i$i$us;
   } else {
    $30 = $26;
   }
   $29 = ($30|0)<(0);
   if ($29) {
    $34 = HEAP32[$__nd$0$in$us>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     $$lcssa2 = $__nd$0$in$us;$__nd$0$in$lcssa1 = $__nd$0$in$us;
     label = 18;
     break;
    } else {
     $__nd$0$in$us = $34;
     continue;
    }
   } else {
    $31 = (($__nd$0$in$us) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     $$lcssa = $31;$__nd$0$in$lcssa = $__nd$0$in$us;
     label = 20;
     break;
    } else {
     $__nd$0$in$us = $32;
     continue;
    }
   }
  }
 } else {
  $__nd$0$in = $1;
  while(1) {
   $36 = (($__nd$0$in) + 16|0);
   $37 = HEAP32[$10>>2]|0;
   $38 = HEAP8[$36>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    $45 = $38&255;
    $46 = $45 >>> 1;
    $47 = (($36) + 1|0);
    $50 = $46;$52 = $47;
   } else {
    $41 = (($__nd$0$in) + 20|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($__nd$0$in) + 24|0);
    $44 = HEAP32[$43>>2]|0;
    $50 = $42;$52 = $44;
   }
   $48 = HEAP32[$9>>2]|0;
   $49 = ($50>>>0)<($37>>>0);
   $51 = $49 ? $50 : $37;
   $53 = (_memcmp($48,$52,$51)|0);
   $54 = ($53|0)==(0);
   if ($54) {
    $55 = ($37>>>0)<($50>>>0);
    $$$i$i$i$i = $49&1;
    $$$$i$i$i$i = $55 ? -1 : $$$i$i$i$i;
    $57 = $$$$i$i$i$i;
   } else {
    $57 = $53;
   }
   $56 = ($57|0)<(0);
   if ($56) {
    $58 = HEAP32[$__nd$0$in>>2]|0;
    $59 = ($58|0)==(0|0);
    if ($59) {
     $$lcssa2 = $__nd$0$in;$__nd$0$in$lcssa1 = $__nd$0$in;
     label = 18;
     break;
    } else {
     $__nd$0$in = $58;
     continue;
    }
   } else {
    $60 = (($__nd$0$in) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)==(0|0);
    if ($62) {
     $$lcssa = $60;$__nd$0$in$lcssa = $__nd$0$in;
     label = 20;
     break;
    } else {
     $__nd$0$in = $61;
     continue;
    }
   }
  }
 }
 if ((label|0) == 18) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa1;
  $$0 = $$lcssa2;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 20) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa;
  $$0 = $$lcssa;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$4);
 $5 = (($__nd) + 16|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($10|0),($$byval_copy|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size,4);
 }
 $9 = (($data) + 4|0);
 $10 = HEAP32[$data>>2]|0;
 $11 = ($10|0)==($9|0);
 if ($11) {
  STACKTOP = sp;return;
 } else {
  $13 = $10;
 }
 while(1) {
  $12 = (($13) + 16|0);
  __ZN4PPtrI6ShaderE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($12,$this);
  $14 = (($13) + 20|0);
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$14,0);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($this);
  $15 = (($13) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   $$01$i$i$i = $13;
   while(1) {
    $20 = (($$01$i$i$i) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($$01$i$i$i|0);
    if ($23) {
     $$0$i$i$i = $21;
     break;
    } else {
     $$01$i$i$i = $21;
    }
   }
  } else {
   $$0$i$i$i$i = $16;
   while(1) {
    $18 = HEAP32[$$0$i$i$i$i>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $18;
    }
   }
  }
  $24 = ($$0$i$i$i|0)==($9|0);
  if ($24) {
   break;
  } else {
   $13 = $$0$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 33554432;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 24|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   STACKTOP = sp;return;
  }
  $6 = (($this) + 28|0);
  __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$6,0);
  __ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE7RebuildEv($6);
  STACKTOP = sp;return;
 }
 $7 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$7,0);
 __ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE7RebuildEv($7);
 $8 = (($this) + 24|0);
 $9 = (($transfer) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 1|0);
 $12 = (($transfer) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($9,$8,1);
  STACKTOP = sp;return;
 } else {
  $15 = HEAP8[$10>>0]|0;
  HEAP8[$8>>0] = $15;
  $16 = HEAP32[$9>>2]|0;
  $17 = (($16) + 1|0);
  HEAP32[$9>>2] = $17;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy21 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$phi25Z2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$023 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $p = 0;
 var $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy21 = sp + 92|0;
 $1 = sp + 88|0;
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 72|0;
 $6 = sp + 64|0;
 $7 = sp + 32|0;
 $8 = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 48|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$size>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = $17;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$size>>2] = $19;
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$21);
 $22 = (($data) + 8|0);
 HEAP32[$22>>2] = 0;
 $23 = (($data) + 4|0);
 HEAP32[$data>>2] = $23;
 HEAP32[$23>>2] = 0;
 $24 = HEAP32[$size>>2]|0;
 $25 = ($24|0)>(0);
 L5: do {
  if ($25) {
   $26 = (($p) + 4|0);
   $27 = (($10) + 4|0);
   $28 = (($26) + 1|0);
   $29 = (($27) + 1|0);
   $30 = (($7) + 4|0);
   $31 = (($30) + 1|0);
   $32 = (($10) + 12|0);
   $33 = (($7) + 12|0);
   $34 = (($7) + 8|0);
   $35 = (($10) + 8|0);
   $36 = (($p) + 12|0);
   $37 = (($p) + 8|0);
   $i$023 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vii(3243,($p|0),($this|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 41;
     break;
    }
    __THREW__ = 0;
    invoke_viii(1765,($this|0),($26|0),0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 41;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3377,($this|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 41;
     break;
    }
    $44 = HEAP32[$p>>2]|0;
    HEAP32[$10>>2] = $44;
    $45 = HEAP8[$26>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $50 = $45&255;
     $51 = $50 >>> 1;
     $53 = $51;$65 = $28;
    } else {
     $48 = HEAP32[$36>>2]|0;
     $49 = HEAP32[$37>>2]|0;
     $53 = $49;$65 = $48;
    }
    $52 = ($53>>>0)>(2147483631);
    if ($52) {
     label = 14;
     break;
    }
    $56 = ($53>>>0)<(11);
    if ($56) {
     $57 = $53 << 1;
     $58 = $57&255;
     HEAP8[$27>>0] = $58;
     $__p$0$i$i$i$i$i$i = $29;
    } else {
     $59 = (($53) + 16)|0;
     $60 = $59 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$8+0>>2]|0;
     $61 = (invoke_iiiiiii(102,($60|0),16,($$byval_copy21|0),0,(642768|0),79)|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      label = 41;
      break;
     }
     HEAP32[$32>>2] = $61;
     $64 = $60 | 1;
     HEAP32[$27>>2] = $64;
     HEAP32[$35>>2] = $53;
     $__p$0$i$i$i$i$i$i = $61;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($65|0),($53|0))|0;
    $66 = (($__p$0$i$i$i$i$i$i) + ($53)|0);
    HEAP8[$66>>0] = 0;
    HEAP32[$7>>2] = $44;
    $67 = HEAP8[$27>>0]|0;
    $68 = $67 & 1;
    $69 = ($68<<24>>24)==(0);
    if ($69) {
     $72 = $67&255;
     $73 = $72 >>> 1;
     $75 = $73;$87 = $29;
    } else {
     $70 = HEAP32[$32>>2]|0;
     $71 = HEAP32[$35>>2]|0;
     $75 = $71;$87 = $70;
    }
    $74 = ($75>>>0)>(2147483631);
    if ($74) {
     label = 24;
     break;
    }
    $78 = ($75>>>0)<(11);
    if ($78) {
     $79 = $75 << 1;
     $80 = $79&255;
     HEAP8[$30>>0] = $80;
     $__p$0$i$i$i$i$i$i$i$i$i = $31;
    } else {
     $81 = (($75) + 16)|0;
     $82 = $81 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$5+0>>2]|0;
     $83 = (invoke_iiiiiii(102,($82|0),16,($$byval_copy21|0),0,(642768|0),79)|0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if ($85) {
      label = 44;
      break;
     }
     HEAP32[$33>>2] = $83;
     $86 = $82 | 1;
     HEAP32[$30>>2] = $86;
     HEAP32[$34>>2] = $75;
     $__p$0$i$i$i$i$i$i$i$i$i = $83;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($87|0),($75|0))|0;
    $88 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($75)|0);
    HEAP8[$88>>0] = 0;
    __THREW__ = 0;
    invoke_viii(1934,($6|0),($data|0),($7|0));
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     label = 34;
     break;
    }
    $91 = HEAP8[$30>>0]|0;
    $92 = $91 & 1;
    $93 = ($92<<24>>24)==(0);
    if (!($93)) {
     $94 = HEAP32[$33>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($94|0),($$byval_copy21|0));
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      label = 33;
      break;
     }
    }
    if (!($69)) {
     $109 = HEAP32[$32>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($109|0),($$byval_copy21|0));
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if ($111) {
      label = 39;
      break;
     }
    }
    $114 = (($i$023) + 1)|0;
    $115 = HEAP32[$size>>2]|0;
    $116 = ($114|0)<($115|0);
    if ($116) {
     $i$023 = $114;
    } else {
     $$pre$phi25Z2D = $26;
     break L5;
    }
   }
   do {
    if ((label|0) == 14) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      $119 = ___cxa_find_matching_catch()|0;
      $120 = tempRet0;
      $lpad$phi$index = $119;$lpad$phi$index2 = $120;
      label = 43;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 24) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      $123 = ___cxa_find_matching_catch()|0;
      $124 = tempRet0;
      $eh$lpad$body$index9Z2D = $124;$eh$lpad$body$indexZ2D = $123;
      label = 46;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 33) {
     $97 = ___cxa_find_matching_catch()|0;
     $98 = tempRet0;
     ___cxa_call_unexpected(($97|0));
     // unreachable;
    }
    else if ((label|0) == 34) {
     $99 = ___cxa_find_matching_catch()|0;
     $100 = tempRet0;
     $101 = HEAP8[$30>>0]|0;
     $102 = $101 & 1;
     $103 = ($102<<24>>24)==(0);
     if ($103) {
      $eh$lpad$body$index9Z2D = $100;$eh$lpad$body$indexZ2D = $99;
      label = 46;
     } else {
      $104 = HEAP32[$33>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($104|0),($$byval_copy21|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       $107 = ___cxa_find_matching_catch()|0;
       $108 = tempRet0;
       ___cxa_call_unexpected(($107|0));
       // unreachable;
      } else {
       $eh$lpad$body$index9Z2D = $100;$eh$lpad$body$indexZ2D = $99;
       label = 46;
      }
     }
    }
    else if ((label|0) == 39) {
     $112 = ___cxa_find_matching_catch()|0;
     $113 = tempRet0;
     ___cxa_call_unexpected(($112|0));
     // unreachable;
    }
    else if ((label|0) == 41) {
     $117 = ___cxa_find_matching_catch()|0;
     $118 = tempRet0;
     $lpad$phi$index = $117;$lpad$phi$index2 = $118;
     label = 43;
    }
    else if ((label|0) == 44) {
     $121 = ___cxa_find_matching_catch()|0;
     $122 = tempRet0;
     $eh$lpad$body$index9Z2D = $122;$eh$lpad$body$indexZ2D = $121;
     label = 46;
    }
   } while(0);
   if ((label|0) == 43) {
    $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
   }
   else if ((label|0) == 46) {
    if ($69) {
     $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;
    } else {
     $125 = HEAP32[$32>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($125|0),($$byval_copy21|0));
     $126 = __THREW__; __THREW__ = 0;
     $127 = $126&1;
     if ($127) {
      $128 = ___cxa_find_matching_catch()|0;
      $129 = tempRet0;
      ___cxa_call_unexpected(($128|0));
      // unreachable;
     } else {
      $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
    }
   }
   $139 = HEAP8[$26>>0]|0;
   $140 = $139 & 1;
   $141 = ($140<<24>>24)==(0);
   if ($141) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $142 = HEAP32[$36>>2]|0;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($142|0),($$byval_copy21|0));
   $143 = __THREW__; __THREW__ = 0;
   $144 = $143&1;
   if ($144) {
    $145 = ___cxa_find_matching_catch()|0;
    $146 = tempRet0;
    ___cxa_call_unexpected(($145|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  } else {
   $$pre = (($p) + 4|0);
   $$pre$phi25Z2D = $$pre;
  }
 } while(0);
 $130 = HEAP8[$$pre$phi25Z2D>>0]|0;
 $131 = $130 & 1;
 $132 = ($131<<24>>24)==(0);
 if ($132) {
  STACKTOP = sp;return;
 }
 $133 = (($p) + 12|0);
 $134 = HEAP32[$133>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($134|0),($$byval_copy21|0));
 $135 = __THREW__; __THREW__ = 0;
 $136 = $135&1;
 if ($136) {
  $137 = ___cxa_find_matching_catch()|0;
  $138 = tempRet0;
  ___cxa_call_unexpected(($137|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp + 12|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$20 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)<($6|0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6|0)<($4|0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $30 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE16__construct_nodeERKS6_($0,$this,$__v);
 $17 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$17>>2] = 0;
 $18 = (($17) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $17;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $17;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $17;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE16__construct_nodeERKS6_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (__Znwj(32)|0);
 $3 = $1;
 $4 = (($2) + 16|0);
 $5 = HEAP32[$__v>>2]|0;
 HEAP32[$4>>2] = $5;
 $6 = (($2) + 20|0);
 $7 = (($__v) + 4|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $15 = (($7) + 1|0);
  $16 = $8&255;
  $17 = $16 >>> 1;
  $19 = $17;$34 = $15;
 } else {
  $11 = (($__v) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($__v) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $19 = $14;$34 = $12;
 }
 $18 = ($19>>>0)>(2147483631);
 do {
  if ($18) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    // unreachable;
   }
  } else {
   $22 = ($19>>>0)<(11);
   if ($22) {
    $23 = $19 << 1;
    $24 = $23&255;
    HEAP8[$6>>0] = $24;
    $25 = (($2) + 21|0);
    $__p$0$i$i$i$i$i$i$i$i$i = $25;
   } else {
    $26 = (($19) + 16)|0;
    $27 = $26 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $28 = (invoke_iiiiiii(102,($27|0),16,($$byval_copy|0),0,(642768|0),79)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    $31 = (($2) + 28|0);
    HEAP32[$31>>2] = $28;
    $32 = $27 | 1;
    HEAP32[$6>>2] = $32;
    $33 = (($2) + 24|0);
    HEAP32[$33>>2] = $19;
    $__p$0$i$i$i$i$i$i$i$i$i = $28;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($34|0),($19|0))|0;
   $35 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($19)|0);
   HEAP8[$35>>0] = 0;
   HEAP32[$agg$result>>2] = $2;
   $36 = (($agg$result) + 4|0);
   $37 = $36;
   $38 = $37;
   HEAP32[$38>>2] = $3;
   $39 = (($37) + 4)|0;
   $40 = $39;
   HEAP32[$40>>2] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 $43 = ($2|0)==(0|0);
 if ($43) {
  ___resumeException($41|0);
  // unreachable;
 }
 __ZdlPv($2);
 ___resumeException($41|0);
 // unreachable;
}
function __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$4);
 $5 = (($__nd) + 20|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($10|0),($$byval_copy|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 33554432;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($this) + 24|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   STACKTOP = sp;return;
  }
  $6 = (($this) + 28|0);
  __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$6,0);
  __ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE7RebuildEv($6);
  STACKTOP = sp;return;
 }
 $7 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($transfer,$7,0);
 __ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE7RebuildEv($7);
 $8 = (($this) + 24|0);
 $9 = (($transfer) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 1|0);
 $12 = (($transfer) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($9,$8,1);
  STACKTOP = sp;return;
 } else {
  $15 = HEAP8[$10>>0]|0;
  HEAP8[$8>>0] = $15;
  $16 = HEAP32[$9>>2]|0;
  $17 = (($16) + 1|0);
  HEAP32[$9>>2] = $17;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS2_4lessIS6_EENS2_9allocatorINS2_4pairIKS6_S7_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy21 = 0, $$pre = 0, $$pre$phi25Z2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$023 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy21 = sp + 92|0;
 $1 = sp + 88|0;
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 72|0;
 $6 = sp + 64|0;
 $7 = sp + 32|0;
 $8 = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 48|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$size,4);
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$size>>2] = $17;
  HEAP32[$11>>2] = $13;
 }
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $18 = (($data) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$19);
 $20 = (($data) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = (($data) + 4|0);
 HEAP32[$data>>2] = $21;
 HEAP32[$21>>2] = 0;
 $22 = HEAP32[$size>>2]|0;
 $23 = ($22|0)>(0);
 L5: do {
  if ($23) {
   $24 = (($p) + 4|0);
   $25 = (($10) + 4|0);
   $26 = (($24) + 1|0);
   $27 = (($25) + 1|0);
   $28 = (($7) + 4|0);
   $29 = (($28) + 1|0);
   $30 = (($10) + 12|0);
   $31 = (($7) + 12|0);
   $32 = (($7) + 8|0);
   $33 = (($10) + 8|0);
   $34 = (($p) + 12|0);
   $35 = (($p) + 8|0);
   $i$023 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vii(3244,($p|0),($this|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 41;
     break;
    }
    __THREW__ = 0;
    invoke_viii(1767,($this|0),($24|0),0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 41;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3376,($this|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 41;
     break;
    }
    $42 = HEAP32[$p>>2]|0;
    HEAP32[$10>>2] = $42;
    $43 = HEAP8[$24>>0]|0;
    $44 = $43 & 1;
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     $48 = $43&255;
     $49 = $48 >>> 1;
     $51 = $49;$63 = $26;
    } else {
     $46 = HEAP32[$34>>2]|0;
     $47 = HEAP32[$35>>2]|0;
     $51 = $47;$63 = $46;
    }
    $50 = ($51>>>0)>(2147483631);
    if ($50) {
     label = 14;
     break;
    }
    $54 = ($51>>>0)<(11);
    if ($54) {
     $55 = $51 << 1;
     $56 = $55&255;
     HEAP8[$25>>0] = $56;
     $__p$0$i$i$i$i$i$i = $27;
    } else {
     $57 = (($51) + 16)|0;
     $58 = $57 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$8+0>>2]|0;
     $59 = (invoke_iiiiiii(102,($58|0),16,($$byval_copy21|0),0,(642768|0),79)|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 41;
      break;
     }
     HEAP32[$30>>2] = $59;
     $62 = $58 | 1;
     HEAP32[$25>>2] = $62;
     HEAP32[$33>>2] = $51;
     $__p$0$i$i$i$i$i$i = $59;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($63|0),($51|0))|0;
    $64 = (($__p$0$i$i$i$i$i$i) + ($51)|0);
    HEAP8[$64>>0] = 0;
    HEAP32[$7>>2] = $42;
    $65 = HEAP8[$25>>0]|0;
    $66 = $65 & 1;
    $67 = ($66<<24>>24)==(0);
    if ($67) {
     $70 = $65&255;
     $71 = $70 >>> 1;
     $73 = $71;$85 = $27;
    } else {
     $68 = HEAP32[$30>>2]|0;
     $69 = HEAP32[$33>>2]|0;
     $73 = $69;$85 = $68;
    }
    $72 = ($73>>>0)>(2147483631);
    if ($72) {
     label = 24;
     break;
    }
    $76 = ($73>>>0)<(11);
    if ($76) {
     $77 = $73 << 1;
     $78 = $77&255;
     HEAP8[$28>>0] = $78;
     $__p$0$i$i$i$i$i$i$i$i$i = $29;
    } else {
     $79 = (($73) + 16)|0;
     $80 = $79 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$5+0>>2]|0;
     $81 = (invoke_iiiiiii(102,($80|0),16,($$byval_copy21|0),0,(642768|0),79)|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      label = 44;
      break;
     }
     HEAP32[$31>>2] = $81;
     $84 = $80 | 1;
     HEAP32[$28>>2] = $84;
     HEAP32[$32>>2] = $73;
     $__p$0$i$i$i$i$i$i$i$i$i = $81;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($85|0),($73|0))|0;
    $86 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($73)|0);
    HEAP8[$86>>0] = 0;
    __THREW__ = 0;
    invoke_viii(1934,($6|0),($data|0),($7|0));
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     label = 34;
     break;
    }
    $89 = HEAP8[$28>>0]|0;
    $90 = $89 & 1;
    $91 = ($90<<24>>24)==(0);
    if (!($91)) {
     $92 = HEAP32[$31>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($92|0),($$byval_copy21|0));
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      label = 33;
      break;
     }
    }
    if (!($67)) {
     $107 = HEAP32[$30>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($107|0),($$byval_copy21|0));
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if ($109) {
      label = 39;
      break;
     }
    }
    $112 = (($i$023) + 1)|0;
    $113 = HEAP32[$size>>2]|0;
    $114 = ($112|0)<($113|0);
    if ($114) {
     $i$023 = $112;
    } else {
     $$pre$phi25Z2D = $24;
     break L5;
    }
   }
   do {
    if ((label|0) == 14) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $117 = ___cxa_find_matching_catch()|0;
      $118 = tempRet0;
      $lpad$phi$index = $117;$lpad$phi$index2 = $118;
      label = 43;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 24) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      $121 = ___cxa_find_matching_catch()|0;
      $122 = tempRet0;
      $eh$lpad$body$index9Z2D = $122;$eh$lpad$body$indexZ2D = $121;
      label = 46;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 33) {
     $95 = ___cxa_find_matching_catch()|0;
     $96 = tempRet0;
     ___cxa_call_unexpected(($95|0));
     // unreachable;
    }
    else if ((label|0) == 34) {
     $97 = ___cxa_find_matching_catch()|0;
     $98 = tempRet0;
     $99 = HEAP8[$28>>0]|0;
     $100 = $99 & 1;
     $101 = ($100<<24>>24)==(0);
     if ($101) {
      $eh$lpad$body$index9Z2D = $98;$eh$lpad$body$indexZ2D = $97;
      label = 46;
     } else {
      $102 = HEAP32[$31>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($102|0),($$byval_copy21|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       $105 = ___cxa_find_matching_catch()|0;
       $106 = tempRet0;
       ___cxa_call_unexpected(($105|0));
       // unreachable;
      } else {
       $eh$lpad$body$index9Z2D = $98;$eh$lpad$body$indexZ2D = $97;
       label = 46;
      }
     }
    }
    else if ((label|0) == 39) {
     $110 = ___cxa_find_matching_catch()|0;
     $111 = tempRet0;
     ___cxa_call_unexpected(($110|0));
     // unreachable;
    }
    else if ((label|0) == 41) {
     $115 = ___cxa_find_matching_catch()|0;
     $116 = tempRet0;
     $lpad$phi$index = $115;$lpad$phi$index2 = $116;
     label = 43;
    }
    else if ((label|0) == 44) {
     $119 = ___cxa_find_matching_catch()|0;
     $120 = tempRet0;
     $eh$lpad$body$index9Z2D = $120;$eh$lpad$body$indexZ2D = $119;
     label = 46;
    }
   } while(0);
   if ((label|0) == 43) {
    $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
   }
   else if ((label|0) == 46) {
    if ($67) {
     $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;
    } else {
     $123 = HEAP32[$30>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($123|0),($$byval_copy21|0));
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     if ($125) {
      $126 = ___cxa_find_matching_catch()|0;
      $127 = tempRet0;
      ___cxa_call_unexpected(($126|0));
      // unreachable;
     } else {
      $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
    }
   }
   $137 = HEAP8[$24>>0]|0;
   $138 = $137 & 1;
   $139 = ($138<<24>>24)==(0);
   if ($139) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $140 = HEAP32[$34>>2]|0;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($140|0),($$byval_copy21|0));
   $141 = __THREW__; __THREW__ = 0;
   $142 = $141&1;
   if ($142) {
    $143 = ___cxa_find_matching_catch()|0;
    $144 = tempRet0;
    ___cxa_call_unexpected(($143|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  } else {
   $$pre = (($p) + 4|0);
   $$pre$phi25Z2D = $$pre;
  }
 } while(0);
 $128 = HEAP8[$$pre$phi25Z2D>>0]|0;
 $129 = $128 & 1;
 $130 = ($129<<24>>24)==(0);
 if ($130) {
  STACKTOP = sp;return;
 }
 $131 = (($p) + 12|0);
 $132 = HEAP32[$131>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($132|0),($$byval_copy21|0));
 $133 = __THREW__; __THREW__ = 0;
 $134 = $133&1;
 if ($134) {
  $135 = ___cxa_find_matching_catch()|0;
  $136 = tempRet0;
  ___cxa_call_unexpected(($135|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead8TransferI15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS2_E8UnityStrNS3_4lessIS6_EENS3_9allocatorINS3_4pairIKS6_S7_EEEEEENS3_8multimapIS7_S6_NS8_IS7_EENSA_INSB_IKS7_S6_EEEEEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i = 0, $converter$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i$i = sp + 4|0;
 $converter$i = sp;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,642816,$converter$i,1)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ($1|0)>(0);
 if ($3) {
  $4 = HEAP32[580600>>2]|0;
  $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,642752,$4,$converter$i$i$i$i,1)|0);
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = ($5|0)>(0);
   if ($7) {
    __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS1_4lessIS5_EENS1_9allocatorINS1_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,0);
   } else {
    $8 = HEAP32[$converter$i$i$i$i>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     (FUNCTION_TABLE_iii[$8 & 4095]($data,$this)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
  __ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE7RebuildEv($data);
 } else {
  $10 = HEAP32[$converter$i>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   (FUNCTION_TABLE_iii[$10 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapI4PPtrI6ShaderE8UnityStrNS1_4lessIS5_EENS1_9allocatorINS1_4pairIKS5_S6_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy21 = 0, $$pre$phi26Z2D = 0, $$pre$pre = 0, $$pre25$pre$phiZZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $converter$i$i = 0;
 var $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$024 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy21 = sp + 92|0;
 $1 = sp + 88|0;
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 72|0;
 $6 = sp + 64|0;
 $7 = sp + 48|0;
 $8 = sp + 28|0;
 $converter$i$i = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 32|0;
 $11 = (($data) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$size>>2] = $12;
 $13 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,642832,642832,$size)|0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $14 = (($data) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($data,$15);
 HEAP32[$11>>2] = 0;
 $16 = (($data) + 4|0);
 HEAP32[$data>>2] = $16;
 HEAP32[$16>>2] = 0;
 $17 = HEAP32[$size>>2]|0;
 $18 = ($17|0)>(0);
 L4: do {
  if ($18) {
   $19 = HEAP32[580608>>2]|0;
   $20 = (($10) + 4|0);
   $21 = (($p) + 4|0);
   $22 = (($21) + 1|0);
   $23 = (($20) + 1|0);
   $24 = (($7) + 4|0);
   $25 = (($24) + 1|0);
   $26 = (($10) + 12|0);
   $27 = (($7) + 12|0);
   $28 = (($7) + 8|0);
   $29 = (($10) + 8|0);
   $30 = (($p) + 12|0);
   $31 = (($p) + 8|0);
   $i$024 = 0;
   while(1) {
    __THREW__ = 0;
    $32 = (invoke_iiiiii(192,($this|0),(642776|0),($19|0),($converter$i$i|0),1)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     label = 42;
     break;
    }
    $35 = ($32|0)==(0);
    if (!($35)) {
     $36 = ($32|0)>(0);
     if ($36) {
      __THREW__ = 0;
      invoke_vii(3245,($p|0),($this|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 42;
       break;
      }
     } else {
      $39 = HEAP32[$converter$i$i>>2]|0;
      $40 = ($39|0)==(0|0);
      if (!($40)) {
       __THREW__ = 0;
       (invoke_iii($39|0,($p|0),($this|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 42;
        break;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3389,($this|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 42;
      break;
     }
    }
    $45 = HEAP32[$p>>2]|0;
    HEAP32[$10>>2] = $45;
    $46 = HEAP8[$21>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if ($48) {
     $51 = $46&255;
     $52 = $51 >>> 1;
     $54 = $52;$66 = $22;
    } else {
     $49 = HEAP32[$30>>2]|0;
     $50 = HEAP32[$31>>2]|0;
     $54 = $50;$66 = $49;
    }
    $53 = ($54>>>0)>(2147483631);
    if ($53) {
     label = 15;
     break;
    }
    $57 = ($54>>>0)<(11);
    if ($57) {
     $58 = $54 << 1;
     $59 = $58&255;
     HEAP8[$20>>0] = $59;
     $__p$0$i$i$i$i$i$i = $23;
    } else {
     $60 = (($54) + 16)|0;
     $61 = $60 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$8+0>>2]|0;
     $62 = (invoke_iiiiiii(102,($61|0),16,($$byval_copy21|0),0,(642768|0),79)|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      label = 42;
      break;
     }
     HEAP32[$26>>2] = $62;
     $65 = $61 | 1;
     HEAP32[$20>>2] = $65;
     HEAP32[$29>>2] = $54;
     $__p$0$i$i$i$i$i$i = $62;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($66|0),($54|0))|0;
    $67 = (($__p$0$i$i$i$i$i$i) + ($54)|0);
    HEAP8[$67>>0] = 0;
    HEAP32[$7>>2] = $45;
    $68 = HEAP8[$20>>0]|0;
    $69 = $68 & 1;
    $70 = ($69<<24>>24)==(0);
    if ($70) {
     $73 = $68&255;
     $74 = $73 >>> 1;
     $76 = $74;$88 = $23;
    } else {
     $71 = HEAP32[$26>>2]|0;
     $72 = HEAP32[$29>>2]|0;
     $76 = $72;$88 = $71;
    }
    $75 = ($76>>>0)>(2147483631);
    if ($75) {
     label = 25;
     break;
    }
    $79 = ($76>>>0)<(11);
    if ($79) {
     $80 = $76 << 1;
     $81 = $80&255;
     HEAP8[$24>>0] = $81;
     $__p$0$i$i$i$i$i$i$i$i$i = $25;
    } else {
     $82 = (($76) + 16)|0;
     $83 = $82 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$5+0>>2]|0;
     $84 = (invoke_iiiiiii(102,($83|0),16,($$byval_copy21|0),0,(642768|0),79)|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      label = 45;
      break;
     }
     HEAP32[$27>>2] = $84;
     $87 = $83 | 1;
     HEAP32[$24>>2] = $87;
     HEAP32[$28>>2] = $76;
     $__p$0$i$i$i$i$i$i$i$i$i = $84;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($88|0),($76|0))|0;
    $89 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($76)|0);
    HEAP8[$89>>0] = 0;
    __THREW__ = 0;
    invoke_viii(1934,($6|0),($data|0),($7|0));
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if ($91) {
     label = 35;
     break;
    }
    $92 = HEAP8[$24>>0]|0;
    $93 = $92 & 1;
    $94 = ($93<<24>>24)==(0);
    if (!($94)) {
     $95 = HEAP32[$27>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($95|0),($$byval_copy21|0));
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      label = 34;
      break;
     }
    }
    if (!($70)) {
     $110 = HEAP32[$26>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($110|0),($$byval_copy21|0));
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      label = 40;
      break;
     }
    }
    $115 = (($i$024) + 1)|0;
    $116 = HEAP32[$size>>2]|0;
    $117 = ($115|0)<($116|0);
    if ($117) {
     $i$024 = $115;
    } else {
     label = 50;
     break L4;
    }
   }
   do {
    if ((label|0) == 15) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 43;
      break L4;
     }
     // unreachable;
    }
    else if ((label|0) == 25) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      $124 = ___cxa_find_matching_catch()|0;
      $125 = tempRet0;
      $eh$lpad$body$index9Z2D = $125;$eh$lpad$body$indexZ2D = $124;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 34) {
     $98 = ___cxa_find_matching_catch()|0;
     $99 = tempRet0;
     ___cxa_call_unexpected(($98|0));
     // unreachable;
    }
    else if ((label|0) == 35) {
     $100 = ___cxa_find_matching_catch()|0;
     $101 = tempRet0;
     $102 = HEAP8[$24>>0]|0;
     $103 = $102 & 1;
     $104 = ($103<<24>>24)==(0);
     if ($104) {
      $eh$lpad$body$index9Z2D = $101;$eh$lpad$body$indexZ2D = $100;
     } else {
      $105 = HEAP32[$27>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($105|0),($$byval_copy21|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       $108 = ___cxa_find_matching_catch()|0;
       $109 = tempRet0;
       ___cxa_call_unexpected(($108|0));
       // unreachable;
      } else {
       $eh$lpad$body$index9Z2D = $101;$eh$lpad$body$indexZ2D = $100;
      }
     }
    }
    else if ((label|0) == 40) {
     $113 = ___cxa_find_matching_catch()|0;
     $114 = tempRet0;
     ___cxa_call_unexpected(($113|0));
     // unreachable;
    }
    else if ((label|0) == 42) {
     $118 = ___cxa_find_matching_catch()|0;
     $119 = tempRet0;
     $$pre25$pre$phiZZ2D = $21;$lpad$phi$index = $118;$lpad$phi$index2 = $119;
     label = 44;
     break L4;
    }
    else if ((label|0) == 45) {
     $122 = ___cxa_find_matching_catch()|0;
     $123 = tempRet0;
     $eh$lpad$body$index9Z2D = $123;$eh$lpad$body$indexZ2D = $122;
    }
   } while(0);
   if ($70) {
    $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;$$pre$phi26Z2D = $21;
   } else {
    $126 = HEAP32[$26>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($126|0),($$byval_copy21|0));
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     $129 = ___cxa_find_matching_catch()|0;
     $130 = tempRet0;
     ___cxa_call_unexpected(($129|0));
     // unreachable;
    } else {
     $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;$$pre$phi26Z2D = $21;
    }
   }
  } else {
   label = 50;
  }
 } while(0);
 if ((label|0) == 50) {
  __THREW__ = 0;
  invoke_vi(3513,($this|0));
  $131 = __THREW__; __THREW__ = 0;
  $132 = $131&1;
  if ($132) {
   label = 43;
  } else {
   $133 = (($p) + 4|0);
   $134 = HEAP8[$133>>0]|0;
   $135 = $134 & 1;
   $136 = ($135<<24>>24)==(0);
   if ($136) {
    STACKTOP = sp;return;
   }
   $137 = (($p) + 12|0);
   $138 = HEAP32[$137>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($138|0),($$byval_copy21|0));
   $139 = __THREW__; __THREW__ = 0;
   $140 = $139&1;
   if ($140) {
    $141 = ___cxa_find_matching_catch()|0;
    $142 = tempRet0;
    ___cxa_call_unexpected(($141|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 43) {
  $120 = ___cxa_find_matching_catch()|0;
  $121 = tempRet0;
  $$pre$pre = (($p) + 4|0);
  $$pre25$pre$phiZZ2D = $$pre$pre;$lpad$phi$index = $120;$lpad$phi$index2 = $121;
  label = 44;
 }
 if ((label|0) == 44) {
  $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;$$pre$phi26Z2D = $$pre25$pre$phiZZ2D;
 }
 $143 = HEAP8[$$pre$phi26Z2D>>0]|0;
 $144 = $143 & 1;
 $145 = ($144<<24>>24)==(0);
 if ($145) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $146 = (($p) + 12|0);
 $147 = HEAP32[$146>>2]|0;
 HEAP32[$9>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$9+0>>2]|0;
 invoke_vii(2591,($147|0),($$byval_copy21|0));
 $148 = __THREW__; __THREW__ = 0;
 $149 = $148&1;
 if ($149) {
  $150 = ___cxa_find_matching_catch()|0;
  $151 = tempRet0;
  ___cxa_call_unexpected(($150|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN15SerializeTraitsINSt3__14pairI4PPtrI6ShaderE8UnityStrEEE8TransferI14SafeBinaryReadEEvRS6_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580576>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$0,642840,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN4PPtrI6ShaderE8TransferI14SafeBinaryReadEEvRT_($data,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($data) + 4|0);
 $7 = HEAP32[580656>>2]|0;
 $8 = HEAP32[580712>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$7,$8,$converter$i$i1,0)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 if ($11) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$6,0);
 } else {
  $12 = HEAP32[$converter$i$i1>>2]|0;
  $13 = ($12|0)==(0|0);
  if (!($13)) {
   (FUNCTION_TABLE_iii[$12 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12ScriptMapper8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = HEAP32[$transfer>>2]|0;
 $1 = $0 & 33554432;
 $2 = ($1|0)==(0);
 if ($2) {
  $7 = (($this) + 28|0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642712,642816,$7,0);
  __ZN13ProxyTransfer8TransferINSt3__13mapI4PPtrI6ShaderE8UnityStrNS1_4lessIS5_EENS1_9allocatorINS1_4pairIKS5_S6_EEEEEEEEvRT_PKc17TransferMetaFlags($transfer,$7,642752,0);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $8 = (($this) + 24|0);
  $9 = HEAP32[580544>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642728,$9,$8,0);
  $10 = (($transfer) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($transfer) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($12) + (($14*24)|0)|0) + 12|0);
  HEAP32[$15>>2] = 1;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642712,642816,$6,0);
 __ZN13ProxyTransfer8TransferINSt3__13mapI4PPtrI6ShaderE8UnityStrNS1_4lessIS5_EENS1_9allocatorINS1_4pairIKS5_S6_EEEEEEEEvRT_PKc17TransferMetaFlags($transfer,$6,642752,0);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferINSt3__13mapI4PPtrI6ShaderE8UnityStrNS1_4lessIS5_EENS1_9allocatorINS1_4pairIKS5_S6_EEEEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $size$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $size$i$i = sp + 4|0;
 $p$i$i = sp + 8|0;
 $1 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$1,$data,$metaFlag);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,642832,642832,$size$i$i,0);
 ;HEAP32[$p$i$i+0>>2]=0|0;HEAP32[$p$i$i+4>>2]=0|0;HEAP32[$p$i$i+8>>2]=0|0;HEAP32[$p$i$i+12>>2]=0|0;
 $2 = HEAP32[580608>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($this|0),(642776|0),($2|0),($p$i$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vii(3246,($p$i$i|0),($this|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_vi(3390,($this|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(3391,($this|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($p$i$i) + 4|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = $12 & 1;
     $14 = ($13<<24>>24)==(0);
     if ($14) {
      __ZN13ProxyTransfer11EndTransferEv($this);
      STACKTOP = sp;return;
     }
     $15 = (($p$i$i) + 12|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($16|0),($$byval_copy1|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      $19 = ___cxa_find_matching_catch()|0;
      $20 = tempRet0;
      ___cxa_call_unexpected(($19|0));
      // unreachable;
     } else {
      __ZN13ProxyTransfer11EndTransferEv($this);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $23 = (($p$i$i) + 4|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24 & 1;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  ___resumeException($21|0);
  // unreachable;
 }
 $27 = (($p$i$i) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($28|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  ___cxa_call_unexpected(($31|0));
  // unreachable;
 } else {
  ___resumeException($21|0);
  // unreachable;
 }
}
function __ZN15SerializeTraitsINSt3__14pairI4PPtrI6ShaderE8UnityStrEEE8TransferI13ProxyTransferEEvRS6_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 16|0;
 $0 = HEAP32[580576>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$0,642840,$data,0);
 $1 = (($size$i$i$i$i) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$size$i$i$i$i>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642784,$6,$data,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642800,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($data) + 4|0);
 $19 = HEAP32[580656>>2]|0;
 $20 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$19,$20,$18,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,642832,642832,$size$i$i$i$i,1);
 $21 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,642776,$21,$p$i$i$i,0);
 $22 = HEAP32[$7>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$10>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE19__equal_range_multiIS2_EENS_4pairINS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEESL_EERKT_($agg$result,$this,$__k) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__k = $__k|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$i = 0, $$$$i$i$i$i6 = 0, $$$i$i$i$i = 0, $$$i$i$i$i$i = 0, $$$i$i$i$i5 = 0, $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $$c$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__result$0$ph24 = 0, $__result$0$ph27 = 0, $__rt$0$in = 0, $__rt$0$in18 = 0, $__rt$0$in1825 = 0, $__rt$01929$in = 0, $__rt$021$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 4|0);
 $__rt$0$in1825 = HEAP32[$2>>2]|0;
 $3 = ($__rt$0$in1825|0)==(0|0);
 L1: do {
  if ($3) {
   $__result$0$ph24 = $1;
  } else {
   $4 = HEAP8[$__k>>0]|0;
   $5 = $4 & 1;
   $6 = ($5<<24>>24)==(0);
   $7 = $4&255;
   $8 = $7 >>> 1;
   $9 = (($__k) + 1|0);
   $10 = (($__k) + 8|0);
   $11 = (($__k) + 4|0);
   $__result$0$ph27 = $1;$__rt$01929$in = $__rt$0$in1825;
   L3: while(1) {
    $__rt$021$in = $__rt$01929$in;
    while(1) {
     $14 = (($__rt$021$in) + 16|0);
     if ($6) {
      $29 = $8;
     } else {
      $15 = HEAP32[$11>>2]|0;
      $29 = $15;
     }
     $16 = HEAP8[$14>>0]|0;
     $17 = $16 & 1;
     $18 = ($17<<24>>24)==(0);
     if ($18) {
      $21 = $16&255;
      $22 = $21 >>> 1;
      $28 = $22;
     } else {
      $19 = (($__rt$021$in) + 20|0);
      $20 = HEAP32[$19>>2]|0;
      $28 = $20;
     }
     if ($6) {
      $31 = $9;
     } else {
      $23 = HEAP32[$10>>2]|0;
      $31 = $23;
     }
     if ($18) {
      $26 = (($14) + 1|0);
      $32 = $26;
     } else {
      $24 = (($__rt$021$in) + 24|0);
      $25 = HEAP32[$24>>2]|0;
      $32 = $25;
     }
     $27 = ($28>>>0)<($29>>>0);
     $30 = $27 ? $28 : $29;
     $33 = (_memcmp($31,$32,$30)|0);
     $34 = ($33|0)==(0);
     if ($34) {
      $35 = ($29>>>0)<($28>>>0);
      $$$i$i$i$i5 = $27&1;
      $$$$i$i$i$i6 = $35 ? -1 : $$$i$i$i$i5;
      $37 = $$$$i$i$i$i6;
     } else {
      $37 = $33;
     }
     $36 = ($37|0)<(0);
     if ($36) {
      break;
     }
     if ($18) {
      $41 = $16&255;
      $42 = $41 >>> 1;
      $50 = $42;
     } else {
      $39 = (($__rt$021$in) + 20|0);
      $40 = HEAP32[$39>>2]|0;
      $50 = $40;
     }
     if ($6) {
      $49 = $8;
     } else {
      $43 = HEAP32[$11>>2]|0;
      $49 = $43;
     }
     if ($18) {
      $46 = (($14) + 1|0);
      $52 = $46;
     } else {
      $44 = (($__rt$021$in) + 24|0);
      $45 = HEAP32[$44>>2]|0;
      $52 = $45;
     }
     if ($6) {
      $53 = $9;
     } else {
      $47 = HEAP32[$10>>2]|0;
      $53 = $47;
     }
     $48 = ($49>>>0)<($50>>>0);
     $51 = $48 ? $49 : $50;
     $54 = (_memcmp($52,$53,$51)|0);
     $55 = ($54|0)==(0);
     if ($55) {
      $56 = ($50>>>0)<($49>>>0);
      $$$i$i$i$i = $48&1;
      $$$$i$i$i$i = $56 ? -1 : $$$i$i$i$i;
      $58 = $$$$i$i$i$i;
     } else {
      $58 = $54;
     }
     $57 = ($58|0)<(0);
     if (!($57)) {
      break L3;
     }
     $12 = (($__rt$021$in) + 4|0);
     $__rt$0$in = HEAP32[$12>>2]|0;
     $13 = ($__rt$0$in|0)==(0|0);
     if ($13) {
      $__result$0$ph24 = $__result$0$ph27;
      break L1;
     } else {
      $__rt$021$in = $__rt$0$in;
     }
    }
    $__rt$0$in18 = HEAP32[$__rt$021$in>>2]|0;
    $38 = ($__rt$0$in18|0)==(0|0);
    if ($38) {
     $__result$0$ph24 = $__rt$021$in;
     break L1;
    } else {
     $__result$0$ph27 = $__rt$021$in;$__rt$01929$in = $__rt$0$in18;
    }
   }
   $59 = HEAP32[$__rt$021$in>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_($0,$this,$__k,$59,$__rt$021$in);
   $60 = (($__rt$021$in) + 4|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==(0|0);
   L45: do {
    if ($62) {
     $$0$ph5$i = $__result$0$ph27;
    } else {
     $63 = HEAP8[$__k>>0]|0;
     $64 = $63 & 1;
     $65 = ($64<<24>>24)==(0);
     $66 = $63&255;
     $67 = $66 >>> 1;
     $$0$ph7$i = $__result$0$ph27;$$01$ph6$i$in = $61;
     while(1) {
      $$013$i$in = $$01$ph6$i$in;
      while(1) {
       $68 = (($$013$i$in) + 16|0);
       if ($65) {
        $83 = $67;
       } else {
        $69 = HEAP32[$11>>2]|0;
        $83 = $69;
       }
       $70 = HEAP8[$68>>0]|0;
       $71 = $70 & 1;
       $72 = ($71<<24>>24)==(0);
       if ($72) {
        $75 = $70&255;
        $76 = $75 >>> 1;
        $82 = $76;
       } else {
        $73 = (($$013$i$in) + 20|0);
        $74 = HEAP32[$73>>2]|0;
        $82 = $74;
       }
       if ($65) {
        $85 = $9;
       } else {
        $77 = HEAP32[$10>>2]|0;
        $85 = $77;
       }
       if ($72) {
        $80 = (($68) + 1|0);
        $86 = $80;
       } else {
        $78 = (($$013$i$in) + 24|0);
        $79 = HEAP32[$78>>2]|0;
        $86 = $79;
       }
       $81 = ($82>>>0)<($83>>>0);
       $84 = $81 ? $82 : $83;
       $87 = (_memcmp($85,$86,$84)|0);
       $88 = ($87|0)==(0);
       if ($88) {
        $89 = ($83>>>0)<($82>>>0);
        $$$i$i$i$i$i = $81&1;
        $$$$i$i$i$i$i = $89 ? -1 : $$$i$i$i$i$i;
        $91 = $$$$i$i$i$i$i;
       } else {
        $91 = $87;
       }
       $90 = ($91|0)<(0);
       if ($90) {
        break;
       }
       $94 = (($$013$i$in) + 4|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = ($95|0)==(0|0);
       if ($96) {
        $$0$ph5$i = $$0$ph7$i;
        break L45;
       } else {
        $$013$i$in = $95;
       }
      }
      $92 = HEAP32[$$013$i$in>>2]|0;
      $93 = ($92|0)==(0|0);
      if ($93) {
       $$0$ph5$i = $$013$i$in;
       break;
      } else {
       $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $92;
      }
     }
    }
   } while(0);
   $97 = HEAP32[$0>>2]|0;
   $$c$i$i1 = $97;
   HEAP32[$agg$result>>2] = $$c$i$i1;
   $98 = (($agg$result) + 4|0);
   HEAP32[$98>>2] = $$0$ph5$i;
   STACKTOP = sp;return;
  }
 } while(0);
 HEAP32[$agg$result>>2] = $__result$0$ph24;
 $99 = (($agg$result) + 4|0);
 HEAP32[$99>>2] = $__result$0$ph24;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE13__lower_boundIS2_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SJ_SJ_($agg$result,$this,$__v,$__root,$__result) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 $__root = $__root|0;
 $__result = $__result|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0$ph6 = 0, $$0$ph9 = 0, $$01$lcssa2 = 0, $$01$ph8 = 0, $$013 = 0, $$013$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__root|0)==(0|0);
 if ($0) {
  $$0$ph6 = $__result;
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
 $1 = HEAP8[$__v>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 $4 = $1&255;
 $5 = $4 >>> 1;
 $6 = (($__v) + 1|0);
 $7 = (($__v) + 8|0);
 $8 = (($__v) + 4|0);
 $$0$ph9 = $__result;$$01$ph8 = $__root;
 L4: while(1) {
  L6: do {
   if ($3) {
    $$013$us = $$01$ph8;
    while(1) {
     $9 = (($$013$us) + 16|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 & 1;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $17 = $10&255;
      $18 = $17 >>> 1;
      $19 = (($9) + 1|0);
      $21 = $18;$23 = $19;
     } else {
      $13 = (($$013$us) + 20|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($$013$us) + 24|0);
      $16 = HEAP32[$15>>2]|0;
      $21 = $14;$23 = $16;
     }
     $20 = ($5>>>0)<($21>>>0);
     $22 = $20 ? $5 : $21;
     $24 = (_memcmp($23,$6,$22)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = ($21>>>0)<($5>>>0);
      $$$i$i$i$i$us = $20&1;
      $$$$i$i$i$i$us = $26 ? -1 : $$$i$i$i$i$us;
      $28 = $$$$i$i$i$i$us;
     } else {
      $28 = $24;
     }
     $27 = ($28|0)<(0);
     if (!($27)) {
      $$01$lcssa2 = $$013$us;
      break L6;
     }
     $29 = (($$013$us) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013$us = $30;
     }
    }
   } else {
    $$013 = $$01$ph8;
    while(1) {
     $32 = (($$013) + 16|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if ($35) {
      $40 = $33&255;
      $41 = $40 >>> 1;
      $42 = (($32) + 1|0);
      $46 = $41;$48 = $42;
     } else {
      $36 = (($$013) + 20|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($$013) + 24|0);
      $39 = HEAP32[$38>>2]|0;
      $46 = $37;$48 = $39;
     }
     $43 = HEAP32[$8>>2]|0;
     $44 = HEAP32[$7>>2]|0;
     $45 = ($43>>>0)<($46>>>0);
     $47 = $45 ? $43 : $46;
     $49 = (_memcmp($48,$44,$47)|0);
     $50 = ($49|0)==(0);
     if ($50) {
      $51 = ($46>>>0)<($43>>>0);
      $$$i$i$i$i = $45&1;
      $$$$i$i$i$i = $51 ? -1 : $$$i$i$i$i;
      $53 = $$$$i$i$i$i;
     } else {
      $53 = $49;
     }
     $52 = ($53|0)<(0);
     if (!($52)) {
      $$01$lcssa2 = $$013;
      break L6;
     }
     $56 = (($$013) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013 = $57;
     }
    }
   }
  } while(0);
  $54 = HEAP32[$$01$lcssa2>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$0$ph6 = $$01$lcssa2;
   label = 19;
   break;
  } else {
   $$0$ph9 = $$01$lcssa2;$$01$ph8 = $54;
  }
 }
 if ((label|0) == 19) {
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
}
function __ZN12ScriptMapperD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((642576 + 8|0));
 $0 = (($this) + 40|0);
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI8UnityStr4PPtrI6ShaderEEENS_19__map_value_compareIS2_S6_NS_4lessIS2_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$2);
 $3 = (($this) + 28|0);
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($3,$5);
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   STACKTOP = sp;return;
  }
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __THREW__ = 0;
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $14 = ___cxa_find_matching_catch(0|0)|0;
   $15 = tempRet0;
   ___clang_call_terminate($14);
   // unreachable;
  } else {
   ___resumeException($10|0);
   // unreachable;
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 HEAP32[$this>>2] = ((561376 + 8|0));
 __THREW__ = 0;
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  __THREW__ = 0;
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $26 = ___cxa_find_matching_catch(0|0)|0;
   $27 = tempRet0;
   ___clang_call_terminate($26);
   // unreachable;
  } else {
   $eh$lpad$body$i$indexZ2D = $22;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  ___resumeException($16|0);
  // unreachable;
 }
 $28 = ___cxa_find_matching_catch(0|0)|0;
 $29 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $28;
 ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
 // unreachable;
}
function __ZN8keywords10InitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,647320,15)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[647328>>2] = $2;
 (__ZN8keywords6CreateEPKc(647336)|0);
 (__ZN8keywords6CreateEPKc(647344)|0);
 (__ZN8keywords6CreateEPKc(647360)|0);
 (__ZN8keywords6CreateEPKc(647384)|0);
 (__ZN8keywords6CreateEPKc(647392)|0);
 (__ZN8keywords6CreateEPKc(647408)|0);
 (__ZN8keywords6CreateEPKc(647424)|0);
 (__ZN8keywords6CreateEPKc(647440)|0);
 (__ZN8keywords6CreateEPKc(647456)|0);
 (__ZN8keywords6CreateEPKc(647472)|0);
 (__ZN8keywords6CreateEPKc(647488)|0);
 (__ZN8keywords6CreateEPKc(647512)|0);
 (__ZN8keywords6CreateEPKc(647528)|0);
 (__ZN8keywords6CreateEPKc(647552)|0);
 (__ZN8keywords6CreateEPKc(647568)|0);
 (__ZN8keywords6CreateEPKc(647584)|0);
 (__ZN8keywords6CreateEPKc(647600)|0);
 (__ZN8keywords6CreateEPKc(647624)|0);
 (__ZN8keywords6CreateEPKc(647648)|0);
 (__ZN8keywords6CreateEPKc(647672)|0);
 (__ZN8keywords6CreateEPKc(647696)|0);
 (__ZN8keywords6CreateEPKc(647712)|0);
 (__ZN8keywords6CreateEPKc(647720)|0);
 (__ZN8keywords6CreateEPKc(647736)|0);
 (__ZN8keywords6CreateEPKc(647752)|0);
 (__ZN8keywords6CreateEPKc(647776)|0);
 (__ZN8keywords6CreateEPKc(647792)|0);
 (__ZN8keywords6CreateEPKc(647816)|0);
 STACKTOP = sp;return;
}
function __ZN8keywords6CreateEPKc($name) {
 $name = $name|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = HEAP32[647328>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN8keywords10InitializeEv();
  $$pre = HEAP32[647328>>2]|0;
  $5 = $$pre;
 } else {
  $5 = $2;
 }
 $4 = (($5) + 4|0);
 $6 = HEAP32[$4>>2]|0;
 $7 = (($5) + 4|0);
 $8 = ($6|0)==(0|0);
 if (!($8)) {
  $$0$ph7$i$i$i = $7;$$01$ph6$i$in$i$i = $6;
  L5: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $9 = (($$013$i$in$i$i) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (_strcmp($10,$name)|0);
    $12 = ($11|0)<(0);
    if (!($12)) {
     break;
    }
    $15 = (($$013$i$in$i$i) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L5;
    } else {
     $$013$i$in$i$i = $16;
    }
   }
   $13 = HEAP32[$$013$i$in$i$i>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $13;
   }
  }
  $18 = ($$0$ph5$i$i$i|0)==($7|0);
  if (!($18)) {
   $19 = (($$0$ph5$i$i$i) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (_strcmp($name,$20)|0);
   $22 = ($21|0)<(0);
   $23 = ($$0$ph5$i$i$i|0)==($7|0);
   $or$cond = $22 | $23;
   if (!($or$cond)) {
    $24 = (($$0$ph5$i$i$i) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    $$0 = $25;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $26 = (($5) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)>(127);
 if ($28) {
  $$0 = $27;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (_strlen(($name|0))|0);
 $30 = (($29) + 1)|0;
 $31 = HEAP32[628272>>2]|0;
 HEAP32[$1>>2] = $31;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 $32 = (__Z15malloc_internaljj10MemLabelIdiPKci($30,16,$$byval_copy,0,647320,95)|0);
 _memcpy(($32|0),($name|0),($30|0))|0;
 $33 = HEAP32[647328>>2]|0;
 $34 = $32;
 $35 = $0;
 $36 = $35;
 HEAP32[$36>>2] = $34;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $27;
 __ZNSt3__16__treeINS_12__value_typeIPKciEENS_19__map_value_compareIS3_S4_15smaller_cstringLb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($$byval_copy,$33,$0);
 $39 = (($27|0) / 32)&-1;
 $40 = (($39) + 1)|0;
 $41 = HEAP32[652824>>2]|0;
 HEAP32[$41>>2] = $40;
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function __ZN8keywords18StringToKeywordSetERK8UnityStrR16ShaderKeywordSet($s,$res) {
 $s = $s|0;
 $res = $res|0;
 var $$0$i314 = 0, $$0$i36 = 0, $$byval_copy9 = 0, $$index = 0, $$index3 = 0, $$pn15 = 0, $$pn8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $8 = 0, $9 = 0, $allocPtr$0 = 0, $length$0 = 0, $length$010 = 0, $length$013 = 0, $length$016 = 0, $length$05 = 0, $pos$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy9 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 ;HEAP32[$res+0>>2]=0|0;HEAP32[$res+4>>2]=0|0;HEAP32[$res+8>>2]=0|0;HEAP32[$res+12>>2]=0|0;
 $2 = HEAP8[$s>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = $2&255;
  $8 = $7 >>> 1;
  $10 = $8;
 } else {
  $5 = (($s) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $10 = $6;
 }
 $9 = (($10) + 16)|0;
 $11 = ($9>>>0)<(2000);
 if ($11) {
  $12 = ($10|0)==(-1);
  if ($12) {
   $23 = 0;$allocPtr$0 = 0;
  } else {
   $13 = STACKTOP; STACKTOP = STACKTOP + ((((1*$9)|0)+15)&-16)|0;;
   $23 = 0;$allocPtr$0 = $13;
  }
 } else {
  $14 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $14;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
  $15 = (invoke_iiiiiii(102,($9|0),16,($$byval_copy9|0),0,(647320|0),137)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   $$index = $18;$$index3 = $19;$74 = $0;
   ___resumeException($$index|0);
   // unreachable;
  } else {
   $23 = $15;$allocPtr$0 = $15;
  }
 }
 $27 = $allocPtr$0;
 $28 = (($27) + 15)|0;
 $29 = $28 & -16;
 $30 = $29;
 $31 = (($s) + 1|0);
 $32 = (($s) + 8|0);
 $33 = (($s) + 4|0);
 $pos$0 = 0;
 while(1) {
  $34 = HEAP8[$s>>0]|0;
  $35 = $34 & 1;
  $36 = ($35<<24>>24)==(0);
  if ($36) {
   $38 = $34&255;
   $39 = $38 >>> 1;
   $41 = $39;
  } else {
   $37 = HEAP32[$33>>2]|0;
   $41 = $37;
  }
  $40 = ($41>>>0)>($pos$0>>>0);
  if ($40) {
   if ($36) {
    $44 = $31;
   } else {
    $42 = HEAP32[$32>>2]|0;
    $44 = $42;
   }
   $43 = (($44) + ($pos$0)|0);
   $45 = (($41) - ($pos$0))|0;
   $46 = (_memchr($43,32,$45)|0);
   $47 = ($46|0)==(0|0);
   if ($47) {
    label = 20;
   } else {
    $48 = $46;
    $49 = $44;
    $50 = (($48) - ($49))|0;
    $51 = ($50|0)==(-1);
    if ($51) {
     label = 20;
    } else {
     $length$0 = (($50) - ($pos$0))|0;
     if ($36) {
      $$0$i36 = $50;$$pn8 = $50;$57 = $31;$76 = 0;$length$010 = $length$0;
     } else {
      $$0$i314 = $50;$$pn15 = $50;$75 = 0;$length$016 = $length$0;
      label = 24;
     }
    }
   }
  } else {
   label = 20;
  }
  do {
   if ((label|0) == 20) {
    label = 0;
    if ($36) {
     $53 = $34&255;
     $54 = $53 >>> 1;
     $length$05 = (($54) - ($pos$0))|0;
     $$0$i36 = -1;$$pn8 = $54;$57 = $31;$76 = 1;$length$010 = $length$05;
     break;
    } else {
     $52 = HEAP32[$33>>2]|0;
     $length$013 = (($52) - ($pos$0))|0;
     $$0$i314 = -1;$$pn15 = $52;$75 = 1;$length$016 = $length$013;
     label = 24;
     break;
    }
   }
  } while(0);
  if ((label|0) == 24) {
   label = 0;
   $55 = HEAP32[$32>>2]|0;
   $$0$i36 = $$0$i314;$$pn8 = $$pn15;$57 = $55;$76 = $75;$length$010 = $length$016;
  }
  $56 = (($57) + ($pos$0)|0);
  _memcpy(($30|0),($56|0),($length$010|0))|0;
  $58 = (($30) + ($length$010)|0);
  HEAP8[$58>>0] = 0;
  $59 = ($$pn8|0)==($pos$0|0);
  if (!($59)) {
   __THREW__ = 0;
   $60 = (invoke_ii(3311,($30|0))|0);
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    break;
   }
   $63 = $60 & 31;
   $64 = 1 << $63;
   $65 = $60 >>> 5;
   $66 = (($res) + ($65<<2)|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = $67 | $64;
   HEAP32[$66>>2] = $68;
  }
  if ($76) {
   label = 30;
   break;
  }
  $69 = (($$0$i36) + 1)|0;
  $pos$0 = $69;
 }
 if ((label|0) == 30) {
  $70 = ($23|0)==(0|0);
  if ($70) {
   STACKTOP = sp;return;
  }
  $71 = HEAP32[628512>>2]|0;
  HEAP32[$0>>2] = $71;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($23,$$byval_copy9);
  STACKTOP = sp;return;
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $22 = ($23|0)==(0|0);
 if ($22) {
  $$index = $20;$$index3 = $21;$74 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $24 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $24;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($23|0),($$byval_copy9|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $72 = ___cxa_find_matching_catch(0|0)|0;
  $73 = tempRet0;
  ___clang_call_terminate($72);
  // unreachable;
 } else {
  $$index = $20;$$index3 = $21;$74 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __ZN8keywords24KeywordSetToKeywordNamesERK16ShaderKeywordSetRNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEE($keywords,$outNames) {
 $keywords = $keywords|0;
 $outNames = $outNames|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre21 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $count$0$lcssa$i = 0, $count$01$i = 0, $exitcond$i = 0, $i$02$i = 0, $kw$014 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$outNames>>2]|0;
 $3 = (($outNames) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $7 = $4;
  while(1) {
   $6 = (($7) + -12|0);
   HEAP32[$3>>2] = $6;
   $8 = HEAP8[$6>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $12 = $6;
   } else {
    $13 = (($7) + -4|0);
    $14 = HEAP32[$13>>2]|0;
    __ZdlPv($14);
    $$pre$i$i$i = HEAP32[$3>>2]|0;
    $12 = $$pre$i$i$i;
   }
   $11 = ($12|0)==($2|0);
   if ($11) {
    break;
   } else {
    $7 = $12;
   }
  }
 }
 $15 = HEAP32[652824>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)>(0);
 if ($17) {
  $count$01$i = 0;$i$02$i = 0;
  while(1) {
   $18 = (($keywords) + ($i$02$i<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = $19 >>> 1;
   $21 = $20 & 1431655765;
   $22 = (($19) - ($21))|0;
   $23 = $22 & 858993459;
   $24 = $22 >>> 2;
   $25 = $24 & 858993459;
   $26 = (($25) + ($23))|0;
   $27 = $26 >>> 4;
   $28 = (($27) + ($26))|0;
   $29 = $28 & 252645135;
   $30 = Math_imul($29, 16843009)|0;
   $31 = $30 >>> 24;
   $32 = (($31) + ($count$01$i))|0;
   $33 = (($i$02$i) + 1)|0;
   $exitcond$i = ($33|0)==($16|0);
   if ($exitcond$i) {
    $count$0$lcssa$i = $32;
    break;
   } else {
    $count$01$i = $32;$i$02$i = $33;
   }
  }
 } else {
  $count$0$lcssa$i = 0;
 }
 __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE7reserveEj($outNames,$count$0$lcssa$i);
 $34 = (($1) + 1|0);
 $35 = (($outNames) + 8|0);
 $36 = (($1) + 8|0);
 $37 = (($1) + 4|0);
 $kw$014 = 0;
 L12: while(1) {
  $38 = $kw$014 >>> 5;
  $39 = (($keywords) + ($38<<2)|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $kw$014 & 31;
  $42 = 1 << $41;
  $43 = $40 & $42;
  $44 = ($43|0)==(0);
  if (!($44)) {
   $45 = HEAP32[647328>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    __ZN8keywords10InitializeEv();
    $$pre$i = HEAP32[647328>>2]|0;
    $48 = $$pre$i;
   } else {
    $48 = $45;
   }
   $47 = HEAP32[$48>>2]|0;
   $49 = (($48) + 4|0);
   $50 = ($47|0)==($49|0);
   L19: do {
    if ($50) {
     $$0$i = 647320;
    } else {
     $52 = $47;
     while(1) {
      $51 = (($52) + 20|0);
      $53 = HEAP32[$51>>2]|0;
      $54 = ($53|0)==($kw$014|0);
      if ($54) {
       break;
      }
      $57 = (($52) + 4|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($58|0)==(0|0);
      if ($59) {
       $$01$i$i$i$i = $52;
       while(1) {
        $62 = (($$01$i$i$i$i) + 8|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = HEAP32[$63>>2]|0;
        $65 = ($64|0)==($$01$i$i$i$i|0);
        if ($65) {
         $$0$i$i$i$i = $63;
         break;
        } else {
         $$01$i$i$i$i = $63;
        }
       }
      } else {
       $$0$i$i$i$i$i = $58;
       while(1) {
        $60 = HEAP32[$$0$i$i$i$i$i>>2]|0;
        $61 = ($60|0)==(0|0);
        if ($61) {
         $$0$i$i$i$i = $$0$i$i$i$i$i;
         break;
        } else {
         $$0$i$i$i$i$i = $60;
        }
       }
      }
      $66 = ($$0$i$i$i$i|0)==($49|0);
      if ($66) {
       $$0$i = 647320;
       break L19;
      } else {
       $52 = $$0$i$i$i$i;
      }
     }
     $55 = (($52) + 16|0);
     $56 = HEAP32[$55>>2]|0;
     $$0$i = $56;
    }
   } while(0);
   $67 = (_strlen(($$0$i|0))|0);
   $68 = ($67>>>0)>(4294967279);
   if ($68) {
    label = 21;
    break;
   }
   $69 = ($67>>>0)<(11);
   if ($69) {
    $70 = $67 << 1;
    $71 = $70&255;
    HEAP8[$1>>0] = $71;
    $83 = $71;$__p$0$i$i$i = $34;
   } else {
    $72 = (($67) + 16)|0;
    $73 = $72 & -16;
    $74 = (__Znwj($73)|0);
    HEAP32[$36>>2] = $74;
    $75 = $73 | 1;
    HEAP32[$1>>2] = $75;
    HEAP32[$37>>2] = $67;
    $76 = $75&255;
    $83 = $76;$__p$0$i$i$i = $74;
   }
   _memcpy(($__p$0$i$i$i|0),($$0$i|0),($67|0))|0;
   $77 = (($__p$0$i$i$i) + ($67)|0);
   HEAP8[$77>>0] = 0;
   $78 = HEAP32[$3>>2]|0;
   $79 = HEAP32[$35>>2]|0;
   $80 = ($78|0)==($79|0);
   if ($80) {
    __THREW__ = 0;
    invoke_vii(2523,($outNames|0),($1|0));
    $105 = __THREW__; __THREW__ = 0;
    $106 = $105&1;
    if ($106) {
     label = 42;
     break;
    }
    $$pre21 = HEAP8[$1>>0]|0;
    $108 = $$pre21;
   } else {
    $81 = ($78|0)==(0|0);
    do {
     if (!($81)) {
      $82 = $83 & 1;
      $84 = ($82<<24>>24)==(0);
      if ($84) {
       ;HEAP32[$78+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$1+8>>2]|0;
       break;
      }
      $85 = HEAP32[$36>>2]|0;
      $86 = HEAP32[$37>>2]|0;
      $87 = ($86>>>0)>(4294967279);
      if ($87) {
       label = 30;
       break L12;
      }
      $90 = ($86>>>0)<(11);
      if ($90) {
       $91 = $86 << 1;
       $92 = $91&255;
       HEAP8[$78>>0] = $92;
       $93 = (($78) + 1|0);
       $__p$0$i$i$i$i$i = $93;
      } else {
       $94 = (($86) + 16)|0;
       $95 = $94 & -16;
       __THREW__ = 0;
       $96 = (invoke_ii(2988,($95|0))|0);
       $97 = __THREW__; __THREW__ = 0;
       $98 = $97&1;
       if ($98) {
        label = 42;
        break L12;
       }
       $99 = (($78) + 8|0);
       HEAP32[$99>>2] = $96;
       $100 = $95 | 1;
       HEAP32[$78>>2] = $100;
       $101 = (($78) + 4|0);
       HEAP32[$101>>2] = $86;
       $__p$0$i$i$i$i$i = $96;
      }
      _memcpy(($__p$0$i$i$i$i$i|0),($85|0),($86|0))|0;
      $102 = (($__p$0$i$i$i$i$i) + ($86)|0);
      HEAP8[$102>>0] = 0;
     }
    } while(0);
    $103 = HEAP32[$3>>2]|0;
    $104 = (($103) + 12|0);
    HEAP32[$3>>2] = $104;
    $108 = $83;
   }
   $107 = $108 & 1;
   $109 = ($107<<24>>24)==(0);
   if (!($109)) {
    $110 = HEAP32[$36>>2]|0;
    __ZdlPv($110);
   }
  }
  $119 = (($kw$014) + 1)|0;
  $120 = ($119|0)<(128);
  if ($120) {
   $kw$014 = $119;
  } else {
   label = 47;
   break;
  }
 }
 do {
  if ((label|0) == 21) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  else if ((label|0) == 30) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    $113 = ___cxa_find_matching_catch()|0;
    $114 = tempRet0;
    $116 = $83;$lpad$phi$index = $113;$lpad$phi$index2 = $114;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 42) {
   $111 = ___cxa_find_matching_catch()|0;
   $112 = tempRet0;
   $$pre = HEAP8[$1>>0]|0;
   $116 = $$pre;$lpad$phi$index = $111;$lpad$phi$index2 = $112;
  }
  else if ((label|0) == 47) {
   $121 = HEAP32[$outNames>>2]|0;
   $122 = HEAP32[$3>>2]|0;
   __ZNSt3__16__sortIRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEvT0_SB_T_($121,$122,$0);
   STACKTOP = sp;return;
  }
 } while(0);
 $115 = $116 & 1;
 $117 = ($115<<24>>24)==(0);
 if ($117) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $118 = HEAP32[$36>>2]|0;
 __ZdlPv($118);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 8|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = (($__v) + 12|0);
 HEAP32[$14>>2] = 0;
 $15 = (($__v) + 16|0);
 HEAP32[$15>>2] = $8;
 $16 = ($__n|0)==(0);
 if ($16) {
  $19 = 0;
 } else {
  $17 = ($__n*12)|0;
  $18 = (__Znwj($17)|0);
  $19 = $18;
 }
 HEAP32[$__v>>2] = $19;
 $20 = (($19) + (($13*12)|0)|0);
 $21 = (($__v) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = (($__v) + 4|0);
 HEAP32[$22>>2] = $20;
 $23 = (($19) + (($__n*12)|0)|0);
 HEAP32[$14>>2] = $23;
 __THREW__ = 0;
 invoke_vii(2524,($this|0),($__v|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  $41 = HEAP32[$22>>2]|0;
  $42 = HEAP32[$21>>2]|0;
  $43 = ($42|0)==($41|0);
  if (!($43)) {
   $45 = $42;
   while(1) {
    $44 = (($45) + -12|0);
    HEAP32[$21>>2] = $44;
    $46 = HEAP8[$44>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if (!($48)) {
     $50 = (($45) + -4|0);
     $51 = HEAP32[$50>>2]|0;
     __ZdlPv($51);
    }
    $49 = ($44|0)==($41|0);
    if ($49) {
     break;
    } else {
     $45 = $44;
    }
   }
  }
  $52 = HEAP32[$__v>>2]|0;
  $53 = ($52|0)==(0|0);
  if ($53) {
   ___resumeException($39|0);
   // unreachable;
  }
  __ZdlPv($52);
  ___resumeException($39|0);
  // unreachable;
 } else {
  $26 = HEAP32[$22>>2]|0;
  $27 = HEAP32[$21>>2]|0;
  $28 = ($27|0)==($26|0);
  if (!($28)) {
   $30 = $27;
   while(1) {
    $29 = (($30) + -12|0);
    HEAP32[$21>>2] = $29;
    $31 = HEAP8[$29>>0]|0;
    $32 = $31 & 1;
    $33 = ($32<<24>>24)==(0);
    if (!($33)) {
     $35 = (($30) + -4|0);
     $36 = HEAP32[$35>>2]|0;
     __ZdlPv($36);
    }
    $34 = ($29|0)==($26|0);
    if ($34) {
     break;
    } else {
     $30 = $29;
    }
   }
  }
  $37 = HEAP32[$__v>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  __ZdlPv($37);
  STACKTOP = sp;return;
 }
}
function __ZN8keywords18KeywordSetToStringERK16ShaderKeywordSetR8UnityStr($kw,$res) {
 $kw = $kw|0;
 $res = $res|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i3 = 0, $$pre$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $sorted = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $sorted = sp;
 HEAP32[$sorted>>2] = 0;
 $0 = (($sorted) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($sorted) + 8|0);
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3247,($kw|0),($sorted|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vii(3248,($sorted|0),($res|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[$sorted>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    STACKTOP = sp;return;
   }
   $8 = HEAP32[$0>>2]|0;
   $9 = ($8|0)==($6|0);
   if ($9) {
    $19 = $6;
   } else {
    $11 = $8;
    while(1) {
     $10 = (($11) + -12|0);
     HEAP32[$0>>2] = $10;
     $12 = HEAP8[$10>>0]|0;
     $13 = $12 & 1;
     $14 = ($13<<24>>24)==(0);
     if ($14) {
      $16 = $10;
     } else {
      $17 = (($11) + -4|0);
      $18 = HEAP32[$17>>2]|0;
      __ZdlPv($18);
      $$pre$i$i$i$i$i3 = HEAP32[$0>>2]|0;
      $16 = $$pre$i$i$i$i$i3;
     }
     $15 = ($16|0)==($6|0);
     if ($15) {
      break;
     } else {
      $11 = $16;
     }
    }
    $$pre$i$i$i4 = HEAP32[$sorted>>2]|0;
    $19 = $$pre$i$i$i4;
   }
   __ZdlPv($19);
   STACKTOP = sp;return;
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $22 = HEAP32[$sorted>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  ___resumeException($20|0);
  // unreachable;
 }
 $24 = HEAP32[$0>>2]|0;
 $25 = ($24|0)==($22|0);
 if ($25) {
  $35 = $22;
 } else {
  $27 = $24;
  while(1) {
   $26 = (($27) + -12|0);
   HEAP32[$0>>2] = $26;
   $28 = HEAP8[$26>>0]|0;
   $29 = $28 & 1;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $32 = $26;
   } else {
    $33 = (($27) + -4|0);
    $34 = HEAP32[$33>>2]|0;
    __ZdlPv($34);
    $$pre$i$i$i$i$i = HEAP32[$0>>2]|0;
    $32 = $$pre$i$i$i$i$i;
   }
   $31 = ($32|0)==($22|0);
   if ($31) {
    break;
   } else {
    $27 = $32;
   }
  }
  $$pre$i$i$i = HEAP32[$sorted>>2]|0;
  $35 = $$pre$i$i$i;
 }
 __ZdlPv($35);
 ___resumeException($20|0);
 // unreachable;
}
function __ZL26KeywordSetToStringDontSortRKNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEER8UnityStr($names,$res) {
 $names = $names|0;
 $res = $res|0;
 var $$pn$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__cap$0$i$i = 0, $__p$0$i$i = 0, $__p$0$sum$pre$i$i = 0, $__p$0$sum$pre$phi$i$iZZZ2D = 0, $__sz$0$i$i = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$res>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $6 = (($res) + 1|0);
  HEAP8[$6>>0] = 0;
  HEAP8[$res>>0] = 0;
 } else {
  $3 = (($res) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP8[$4>>0] = 0;
  $5 = (($res) + 4|0);
  HEAP32[$5>>2] = 0;
 }
 $7 = (($names) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$names>>2]|0;
 $10 = ($8|0)==($9|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($res) + 4|0);
 $12 = (($res) + 1|0);
 $13 = (($res) + 8|0);
 $57 = $9;$j$01 = 0;
 while(1) {
  $14 = HEAP8[$res>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $18 = $14&255;
   $19 = $18 >>> 1;
   $21 = $19;
  } else {
   $17 = HEAP32[$11>>2]|0;
   $21 = $17;
  }
  $20 = ($21|0)==(0);
  if ($20) {
   $40 = $57;
  } else {
   $22 = ($15<<24>>24)!=(0);
   if ($22) {
    $25 = HEAP32[$res>>2]|0;
    $26 = $25 & -2;
    $27 = (($26) + -1)|0;
    $28 = HEAP32[$11>>2]|0;
    $__cap$0$i$i = $27;$__sz$0$i$i = $28;
   } else {
    $23 = $14&255;
    $24 = $23 >>> 1;
    $__cap$0$i$i = 10;$__sz$0$i$i = $24;
   }
   $29 = ($__sz$0$i$i|0)==($__cap$0$i$i|0);
   if ($29) {
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE9__grow_byEjjjjjj($res,$__cap$0$i$i,1,$__cap$0$i$i,$__cap$0$i$i,0,0);
    $30 = HEAP8[$res>>0]|0;
    $31 = $30 & 1;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     label = 16;
    } else {
     label = 17;
    }
   } else {
    if ($22) {
     label = 17;
    } else {
     label = 16;
    }
   }
   if ((label|0) == 16) {
    label = 0;
    $33 = $__sz$0$i$i << 1;
    $34 = (($33) + 2)|0;
    $35 = $34&255;
    HEAP8[$res>>0] = $35;
    $__p$0$sum$pre$i$i = (($__sz$0$i$i) + 1)|0;
    $$pn$i$i = $12;$__p$0$sum$pre$phi$i$iZZZ2D = $__p$0$sum$pre$i$i;
   }
   else if ((label|0) == 17) {
    label = 0;
    $36 = HEAP32[$13>>2]|0;
    $37 = (($__sz$0$i$i) + 1)|0;
    HEAP32[$11>>2] = $37;
    $$pn$i$i = $36;$__p$0$sum$pre$phi$i$iZZZ2D = $37;
   }
   $__p$0$i$i = (($$pn$i$i) + ($__sz$0$i$i)|0);
   HEAP8[$__p$0$i$i>>0] = 32;
   $38 = (($$pn$i$i) + ($__p$0$sum$pre$phi$i$iZZZ2D)|0);
   HEAP8[$38>>0] = 0;
   $$pre = HEAP32[$names>>2]|0;
   $40 = $$pre;
  }
  $39 = (($40) + (($j$01*12)|0)|0);
  $41 = HEAP8[$39>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   $46 = (($39) + 1|0);
   $47 = $46;
  } else {
   $44 = ((($40) + (($j$01*12)|0)|0) + 8|0);
   $45 = HEAP32[$44>>2]|0;
   $47 = $45;
  }
  $48 = (_strlen(($47|0))|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6appendEPKcj($res,$47,$48)|0);
  $49 = (($j$01) + 1)|0;
  $50 = HEAP32[$7>>2]|0;
  $51 = HEAP32[$names>>2]|0;
  $52 = $50;
  $53 = $51;
  $54 = (($52) - ($53))|0;
  $55 = (($54|0) / 12)&-1;
  $56 = ($49|0)==($55|0);
  if ($56) {
   break;
  } else {
   $57 = $51;$j$01 = $49;
  }
 }
 STACKTOP = sp;return;
}
function __ZN8keywords20KeywordNamesToStringERKNSt3__16vectorI8UnityStrNS0_9allocatorIS2_EEEERS2_($kw,$res) {
 $kw = $kw|0;
 $res = $res|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $sorted = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp;
 $$byval_copy = sp + 24|0;
 $sorted = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 HEAP32[$sorted>>2] = 0;
 $2 = (($sorted) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($sorted) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$kw>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = (($kw) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1935,($sorted|0),($$byval_copy|0),($$byval_copy1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  $9 = HEAP32[$sorted>>2]|0;
  $10 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_viii(1936,($9|0),($10|0),($$byval_copy1|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __THREW__ = 0;
   invoke_vii(3248,($sorted|0),($res|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[$sorted>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     STACKTOP = sp;return;
    }
    $17 = HEAP32[$2>>2]|0;
    $18 = ($17|0)==($15|0);
    if (!($18)) {
     $20 = $17;
     while(1) {
      $19 = (($20) + -12|0);
      HEAP32[$2>>2] = $19;
      $21 = HEAP8[$19>>0]|0;
      $22 = $21 & 1;
      $23 = ($22<<24>>24)==(0);
      if (!($23)) {
       $25 = (($20) + -4|0);
       $26 = HEAP32[$25>>2]|0;
       __ZdlPv($26);
      }
      $24 = ($19|0)==($15|0);
      if ($24) {
       break;
      } else {
       $20 = $19;
      }
     }
    }
    __ZdlPv($15);
    STACKTOP = sp;return;
   }
  }
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $29 = HEAP32[$sorted>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  ___resumeException($27|0);
  // unreachable;
 }
 $31 = HEAP32[$2>>2]|0;
 $32 = ($31|0)==($29|0);
 if (!($32)) {
  $34 = $31;
  while(1) {
   $33 = (($34) + -12|0);
   HEAP32[$2>>2] = $33;
   $35 = HEAP8[$33>>0]|0;
   $36 = $35 & 1;
   $37 = ($36<<24>>24)==(0);
   if (!($37)) {
    $39 = (($34) + -4|0);
    $40 = HEAP32[$39>>2]|0;
    __ZdlPv($40);
   }
   $38 = ($33|0)==($29|0);
   if ($38) {
    break;
   } else {
    $34 = $33;
   }
  }
 }
 __ZdlPv($29);
 ___resumeException($27|0);
 // unreachable;
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignINS_11__wrap_iterIPK8UnityStrEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS6_NS_15iterator_traitsISG_E9referenceEEE5valueEvE4typeESG_SG_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i43 = 0, $$0$lcssa$i$i = 0, $$04$i$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i17 = 0, $$pre$i29 = 0, $$pre1$i = 0, $$pre1$i23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i11 = 0, $__p$0$i$i$i$i$i$i22 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $107 = ($9|0)==(0|0);
  if ($107) {
   $123 = $8;
  } else {
   $108 = (($this) + 4|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ($109|0)==($9|0);
   if ($110) {
    $120 = $9;
   } else {
    $112 = $109;
    while(1) {
     $111 = (($112) + -12|0);
     HEAP32[$108>>2] = $111;
     $113 = HEAP8[$111>>0]|0;
     $114 = $113 & 1;
     $115 = ($114<<24>>24)==(0);
     if ($115) {
      $117 = $111;
     } else {
      $118 = (($112) + -4|0);
      $119 = HEAP32[$118>>2]|0;
      __ZdlPv($119);
      $$pre$i$i$i$i = HEAP32[$108>>2]|0;
      $117 = $$pre$i$i$i$i;
     }
     $116 = ($117|0)==($9|0);
     if ($116) {
      break;
     } else {
      $112 = $117;
     }
    }
    $$pre$i29 = HEAP32[$this>>2]|0;
    $120 = $$pre$i29;
   }
   __ZdlPv($120);
   HEAP32[$7>>2] = 0;
   HEAP32[$108>>2] = 0;
   HEAP32[$this>>2] = 0;
   $123 = 0;
  }
  $121 = ($6>>>0)>(357913941);
  if ($121) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $122 = $123;
  $124 = (($122|0) / 12)&-1;
  $125 = ($124>>>0)<(178956970);
  if ($125) {
   $126 = $124 << 1;
   $127 = ($126>>>0)<($6>>>0);
   $128 = $127 ? $6 : $126;
   $129 = ($128>>>0)>(357913941);
   if ($129) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i43 = $128;
   }
  } else {
   $$0$i43 = 357913941;
  }
  $130 = ($$0$i43*12)|0;
  $131 = (__Znwj($130)|0);
  $132 = (($this) + 4|0);
  HEAP32[$132>>2] = $131;
  HEAP32[$this>>2] = $131;
  $133 = (($131) + (($$0$i43*12)|0)|0);
  HEAP32[$7>>2] = $133;
  $134 = ($1|0)==($2|0);
  if ($134) {
   STACKTOP = sp;return;
  } else {
   $136 = $131;$138 = $1;
  }
  while(1) {
   $135 = ($136|0)==(0|0);
   if ($135) {
    $163 = 0;
   } else {
    $137 = HEAP8[$138>>0]|0;
    $139 = $137 & 1;
    $140 = ($139<<24>>24)==(0);
    if ($140) {
     $141 = (($138) + 1|0);
     $142 = $137&255;
     $143 = $142 >>> 1;
     $150 = $143;$160 = $141;
    } else {
     $144 = (($138) + 8|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = (($138) + 4|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = ($147>>>0)>(4294967279);
     if ($148) {
      label = 54;
      break;
     } else {
      $150 = $147;$160 = $145;
     }
    }
    $149 = ($150>>>0)<(11);
    if ($149) {
     $151 = $150 << 1;
     $152 = $151&255;
     HEAP8[$136>>0] = $152;
     $153 = (($136) + 1|0);
     $__p$0$i$i$i$i$i$i = $153;
    } else {
     $154 = (($150) + 16)|0;
     $155 = $154 & -16;
     $156 = (__Znwj($155)|0);
     $157 = (($136) + 8|0);
     HEAP32[$157>>2] = $156;
     $158 = $155 | 1;
     HEAP32[$136>>2] = $158;
     $159 = (($136) + 4|0);
     HEAP32[$159>>2] = $150;
     $__p$0$i$i$i$i$i$i = $156;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($160|0),($150|0))|0;
    $161 = (($__p$0$i$i$i$i$i$i) + ($150)|0);
    HEAP8[$161>>0] = 0;
    $$pre1$i = HEAP32[$132>>2]|0;
    $163 = $$pre1$i;
   }
   $162 = (($163) + 12|0);
   HEAP32[$132>>2] = $162;
   $164 = (($138) + 12|0);
   $165 = ($164|0)==($2|0);
   if ($165) {
    label = 60;
    break;
   } else {
    $136 = $162;$138 = $164;
   }
  }
  if ((label|0) == 54) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  else if ((label|0) == 60) {
   STACKTOP = sp;return;
  }
 }
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16;
 $18 = (($17) - ($11))|0;
 $19 = (($18|0) / 12)&-1;
 $20 = ($6>>>0)>($19>>>0);
 if ($20) {
  $21 = (($1) + (($19*12)|0)|0);
  $23 = $21;$__growing$0$off0 = 1;
 } else {
  $23 = $2;$__growing$0$off0 = 0;
 }
 $22 = ($1|0)==($23|0);
 L43: do {
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $24 = (($0) + 1|0);
   $25 = (($0) + 8|0);
   $26 = (($0) + 4|0);
   $$04$i$i = $9;$28 = $1;
   while(1) {
    $27 = HEAP8[$28>>0]|0;
    $29 = $27 & 1;
    $30 = ($29<<24>>24)==(0);
    if ($30) {
     $31 = (($28) + 1|0);
     $32 = $27&255;
     $33 = $32 >>> 1;
     $40 = $33;$47 = $31;
    } else {
     $34 = (($28) + 8|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($28) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37>>>0)>(4294967279);
     if ($38) {
      label = 9;
      break;
     } else {
      $40 = $37;$47 = $35;
     }
    }
    $39 = ($40>>>0)<(11);
    if ($39) {
     $41 = $40 << 1;
     $42 = $41&255;
     HEAP8[$0>>0] = $42;
     $__p$0$i$i$i$i$i$i11 = $24;
    } else {
     $43 = (($40) + 16)|0;
     $44 = $43 & -16;
     $45 = (__Znwj($44)|0);
     HEAP32[$25>>2] = $45;
     $46 = $44 | 1;
     HEAP32[$0>>2] = $46;
     HEAP32[$26>>2] = $40;
     $__p$0$i$i$i$i$i$i11 = $45;
    }
    _memcpy(($__p$0$i$i$i$i$i$i11|0),($47|0),($40|0))|0;
    $48 = (($__p$0$i$i$i$i$i$i11) + ($40)|0);
    HEAP8[$48>>0] = 0;
    __THREW__ = 0;
    (invoke_iii(2233,($$04$i$i|0),($0|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    $51 = HEAP8[$0>>0]|0;
    $52 = $51 & 1;
    $53 = ($52<<24>>24)==(0);
    if (!($53)) {
     $54 = HEAP32[$25>>2]|0;
     __ZdlPv($54);
    }
    $55 = (($28) + 12|0);
    $56 = (($$04$i$i) + 12|0);
    $57 = ($55|0)==($23|0);
    if ($57) {
     $$0$lcssa$i$i = $56;
     break L43;
    } else {
     $$04$i$i = $56;$28 = $55;
    }
   }
   if ((label|0) == 9) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $60 = HEAP8[$0>>0]|0;
   $61 = $60 & 1;
   $62 = ($61<<24>>24)==(0);
   if ($62) {
    ___resumeException($58|0);
    // unreachable;
   }
   $63 = HEAP32[$25>>2]|0;
   __ZdlPv($63);
   ___resumeException($58|0);
   // unreachable;
  }
 } while(0);
 if (!($__growing$0$off0)) {
  $96 = HEAP32[$15>>2]|0;
  $97 = ($96|0)==($$0$lcssa$i$i|0);
  if ($97) {
   STACKTOP = sp;return;
  } else {
   $99 = $96;
  }
  while(1) {
   $98 = (($99) + -12|0);
   HEAP32[$15>>2] = $98;
   $100 = HEAP8[$98>>0]|0;
   $101 = $100 & 1;
   $102 = ($101<<24>>24)==(0);
   if ($102) {
    $104 = $98;
   } else {
    $105 = (($99) + -4|0);
    $106 = HEAP32[$105>>2]|0;
    __ZdlPv($106);
    $$pre$i$i = HEAP32[$15>>2]|0;
    $104 = $$pre$i$i;
   }
   $103 = ($104|0)==($$0$lcssa$i$i|0);
   if ($103) {
    break;
   } else {
    $99 = $104;
   }
  }
  STACKTOP = sp;return;
 }
 $64 = ($23|0)==($2|0);
 if ($64) {
  STACKTOP = sp;return;
 }
 $$pre$i17 = HEAP32[$15>>2]|0;
 $66 = $$pre$i17;$68 = $23;
 while(1) {
  $65 = ($66|0)==(0|0);
  if ($65) {
   $93 = 0;
  } else {
   $67 = HEAP8[$68>>0]|0;
   $69 = $67 & 1;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    $71 = (($68) + 1|0);
    $72 = $67&255;
    $73 = $72 >>> 1;
    $80 = $73;$90 = $71;
   } else {
    $74 = (($68) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($68) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = ($77>>>0)>(4294967279);
    if ($78) {
     label = 27;
     break;
    } else {
     $80 = $77;$90 = $75;
    }
   }
   $79 = ($80>>>0)<(11);
   if ($79) {
    $81 = $80 << 1;
    $82 = $81&255;
    HEAP8[$66>>0] = $82;
    $83 = (($66) + 1|0);
    $__p$0$i$i$i$i$i$i22 = $83;
   } else {
    $84 = (($80) + 16)|0;
    $85 = $84 & -16;
    $86 = (__Znwj($85)|0);
    $87 = (($66) + 8|0);
    HEAP32[$87>>2] = $86;
    $88 = $85 | 1;
    HEAP32[$66>>2] = $88;
    $89 = (($66) + 4|0);
    HEAP32[$89>>2] = $80;
    $__p$0$i$i$i$i$i$i22 = $86;
   }
   _memcpy(($__p$0$i$i$i$i$i$i22|0),($90|0),($80|0))|0;
   $91 = (($__p$0$i$i$i$i$i$i22) + ($80)|0);
   HEAP8[$91>>0] = 0;
   $$pre1$i23 = HEAP32[$15>>2]|0;
   $93 = $$pre1$i23;
  }
  $92 = (($93) + 12|0);
  HEAP32[$15>>2] = $92;
  $94 = (($68) + 12|0);
  $95 = ($94|0)==($2|0);
  if ($95) {
   label = 60;
   break;
  } else {
   $66 = $92;$68 = $94;
  }
 }
 if ((label|0) == 27) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 60) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__sortIRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEvT0_SB_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$$$i$i$i = 0, $$$$i$i$i12 = 0, $$$$i$i$i18 = 0, $$$$i$i$i18$us = 0, $$$$i$i$i25 = 0, $$$$i$i$i31 = 0, $$$$i$i$i31$us = 0, $$$$i$i$i38 = 0, $$$$i$i$i45 = 0, $$$$i$i$i51 = 0, $$$$i$i$i59 = 0, $$$$i$i$i6 = 0, $$$i$i$i = 0, $$$i$i$i11 = 0, $$$i$i$i17 = 0, $$$i$i$i17$us = 0, $$$i$i$i24 = 0, $$$i$i$i30 = 0, $$$i$i$i30$us = 0, $$$i$i$i37 = 0;
 var $$$i$i$i44 = 0, $$$i$i$i5 = 0, $$$i$i$i50 = 0, $$$i$i$i58 = 0, $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$lcssa64 = 0, $$lcssa67 = 0, $$lcssa68 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$0$lcssa63 = 0, $__i$065 = 0, $__i$065$us = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$2$us = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0;
 var $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$sroa$0$i$i$i54 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$sroa$0$i$i$i54 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -12|0);
  $2 = (($1) + 1|0);
  $3 = (($$01$ph) + -4|0);
  $4 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $5 = $$0;
   $6 = (($0) - ($5))|0;
   $7 = (($6|0) / 12)&-1;
   switch ($7|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 4:  {
    label = 20;
    break L1;
    break;
   }
   case 5:  {
    label = 21;
    break L1;
    break;
   }
   case 3:  {
    label = 19;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 175;
    break L1;
    break;
   }
   default: {
   }
   }
   $42 = ($6|0)<(84);
   if ($42) {
    label = 23;
    break L1;
   }
   $43 = ($6|0)>(11988);
   $44 = (($6|0) / 24)&-1;
   $45 = (($$0) + (($44*12)|0)|0);
   if ($43) {
    $46 = (($6|0) / 48)&-1;
    $47 = (($$0) + (($46*12)|0)|0);
    $$sum = (($46) + ($44))|0;
    $48 = (($$0) + (($$sum*12)|0)|0);
    $49 = (__ZNSt3__17__sort5IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_SB_SB_T_($$0,$47,$45,$48,$1,0)|0);
    $__n_swaps$0 = $49;
   } else {
    $50 = (__ZNSt3__17__sort3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_T_($$0,$45,$1,0)|0);
    $__n_swaps$0 = $50;
   }
   $51 = HEAP8[$$0>>0]|0;
   $52 = $51 & 1;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    $56 = $51&255;
    $57 = $56 >>> 1;
    $73 = $57;
   } else {
    $54 = (($$0) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $73 = $55;
   }
   $58 = HEAP8[$45>>0]|0;
   $59 = $58 & 1;
   $60 = ($59<<24>>24)==(0);
   if ($60) {
    $63 = $58&255;
    $64 = $63 >>> 1;
    $72 = $64;
   } else {
    $61 = ((($$0) + (($44*12)|0)|0) + 4|0);
    $62 = HEAP32[$61>>2]|0;
    $72 = $62;
   }
   if ($53) {
    $67 = (($$0) + 1|0);
    $75 = $67;
   } else {
    $65 = (($$0) + 8|0);
    $66 = HEAP32[$65>>2]|0;
    $75 = $66;
   }
   if ($60) {
    $70 = (($45) + 1|0);
    $76 = $70;
   } else {
    $68 = ((($$0) + (($44*12)|0)|0) + 8|0);
    $69 = HEAP32[$68>>2]|0;
    $76 = $69;
   }
   $71 = ($72>>>0)<($73>>>0);
   $74 = $71 ? $72 : $73;
   $77 = (_memcmp($75,$76,$74)|0);
   $78 = ($77|0)==(0);
   if ($78) {
    $79 = ($73>>>0)<($72>>>0);
    $$$i$i$i5 = $71&1;
    $$$$i$i$i6 = $79 ? -1 : $$$i$i$i5;
    $81 = $$$$i$i$i6;
   } else {
    $81 = $77;
   }
   $80 = ($81|0)<(0);
   do {
    if ($80) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $82 = (($45) + 1|0);
     $83 = ((($$0) + (($44*12)|0)|0) + 8|0);
     $84 = ((($$0) + (($44*12)|0)|0) + 4|0);
     $__j$0 = $1;
     while(1) {
      $85 = (($__j$0) + -12|0);
      $86 = ($$0|0)==($85|0);
      if ($86) {
       break;
      }
      $240 = HEAP8[$85>>0]|0;
      $241 = $240 & 1;
      $242 = ($241<<24>>24)==(0);
      if ($242) {
       $245 = $240&255;
       $246 = $245 >>> 1;
       $256 = $246;
      } else {
       $243 = (($__j$0) + -8|0);
       $244 = HEAP32[$243>>2]|0;
       $256 = $244;
      }
      if ($60) {
       $248 = $58&255;
       $249 = $248 >>> 1;
       $255 = $249;
      } else {
       $247 = HEAP32[$84>>2]|0;
       $255 = $247;
      }
      if ($242) {
       $252 = (($85) + 1|0);
       $258 = $252;
      } else {
       $250 = (($__j$0) + -4|0);
       $251 = HEAP32[$250>>2]|0;
       $258 = $251;
      }
      if ($60) {
       $259 = $82;
      } else {
       $253 = HEAP32[$83>>2]|0;
       $259 = $253;
      }
      $254 = ($255>>>0)<($256>>>0);
      $257 = $254 ? $255 : $256;
      $260 = (_memcmp($258,$259,$257)|0);
      $261 = ($260|0)==(0);
      if ($261) {
       $262 = ($256>>>0)<($255>>>0);
       $$$i$i$i37 = $254&1;
       $$$$i$i$i38 = $262 ? -1 : $$$i$i$i37;
       $264 = $$$$i$i$i38;
      } else {
       $264 = $260;
      }
      $263 = ($264|0)<(0);
      if ($263) {
       label = 120;
       break;
      } else {
       $__j$0 = $85;
      }
     }
     if ((label|0) == 120) {
      label = 0;
      ;HEAP32[$__t$sroa$0$i$i$i54+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+8>>2]=HEAP32[$$0+8>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$85+8>>2]|0;
      ;HEAP32[$85+0>>2]=HEAP32[$__t$sroa$0$i$i$i54+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$__t$sroa$0$i$i$i54+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$__t$sroa$0$i$i$i54+8>>2]|0;
      $265 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $85;$__n_swaps$3 = $265;
      break;
     }
     $87 = (($$0) + 12|0);
     if ($53) {
      $90 = $51&255;
      $91 = $90 >>> 1;
      $104 = $91;
     } else {
      $88 = (($$0) + 4|0);
      $89 = HEAP32[$88>>2]|0;
      $104 = $89;
     }
     $92 = HEAP8[$1>>0]|0;
     $93 = $92 & 1;
     $94 = ($93<<24>>24)==(0);
     if ($94) {
      $96 = $92&255;
      $97 = $96 >>> 1;
      $103 = $97;
     } else {
      $95 = HEAP32[$4>>2]|0;
      $103 = $95;
     }
     if ($53) {
      $100 = (($$0) + 1|0);
      $106 = $100;
     } else {
      $98 = (($$0) + 8|0);
      $99 = HEAP32[$98>>2]|0;
      $106 = $99;
     }
     if ($94) {
      $107 = $2;
     } else {
      $101 = HEAP32[$3>>2]|0;
      $107 = $101;
     }
     $102 = ($103>>>0)<($104>>>0);
     $105 = $102 ? $103 : $104;
     $108 = (_memcmp($106,$107,$105)|0);
     $109 = ($108|0)==(0);
     if ($109) {
      $110 = ($104>>>0)<($103>>>0);
      $$$i$i$i11 = $102&1;
      $$$$i$i$i12 = $110 ? -1 : $$$i$i$i11;
      $112 = $$$$i$i$i12;
     } else {
      $112 = $108;
     }
     $111 = ($112|0)<(0);
     if ($111) {
      $__i$1 = $87;
     } else {
      $113 = ($87|0)==($1|0);
      if ($113) {
       label = 175;
       break L1;
      }
      $114 = $51&255;
      $115 = $114 >>> 1;
      $116 = (($$0) + 1|0);
      $117 = (($$0) + 8|0);
      $118 = (($$0) + 4|0);
      L77: do {
       if ($53) {
        $__i$065$us = $87;
        while(1) {
         $121 = HEAP8[$__i$065$us>>0]|0;
         $122 = $121 & 1;
         $123 = ($122<<24>>24)==(0);
         if ($123) {
          $128 = $121&255;
          $129 = $128 >>> 1;
          $130 = (($__i$065$us) + 1|0);
          $132 = $129;$134 = $130;
         } else {
          $124 = (($__i$065$us) + 4|0);
          $125 = HEAP32[$124>>2]|0;
          $126 = (($__i$065$us) + 8|0);
          $127 = HEAP32[$126>>2]|0;
          $132 = $125;$134 = $127;
         }
         $131 = ($132>>>0)<($115>>>0);
         $133 = $131 ? $132 : $115;
         $135 = (_memcmp($116,$134,$133)|0);
         $136 = ($135|0)==(0);
         if ($136) {
          $137 = ($115>>>0)<($132>>>0);
          $$$i$i$i17$us = $131&1;
          $$$$i$i$i18$us = $137 ? -1 : $$$i$i$i17$us;
          $139 = $$$$i$i$i18$us;
         } else {
          $139 = $135;
         }
         $138 = ($139|0)<(0);
         $120 = (($__i$065$us) + 12|0);
         if ($138) {
          $$lcssa64 = $__i$065$us;$__i$0$lcssa63 = $__i$065$us;
          break L77;
         }
         $119 = ($120|0)==($1|0);
         if ($119) {
          label = 175;
          break L1;
         } else {
          $__i$065$us = $120;
         }
        }
       } else {
        $__i$065 = $87;
        while(1) {
         $142 = HEAP32[$118>>2]|0;
         $143 = HEAP8[$__i$065>>0]|0;
         $144 = $143 & 1;
         $145 = ($144<<24>>24)==(0);
         if ($145) {
          $150 = $143&255;
          $151 = $150 >>> 1;
          $152 = (($__i$065) + 1|0);
          $155 = $151;$157 = $152;
         } else {
          $146 = (($__i$065) + 4|0);
          $147 = HEAP32[$146>>2]|0;
          $148 = (($__i$065) + 8|0);
          $149 = HEAP32[$148>>2]|0;
          $155 = $147;$157 = $149;
         }
         $153 = HEAP32[$117>>2]|0;
         $154 = ($155>>>0)<($142>>>0);
         $156 = $154 ? $155 : $142;
         $158 = (_memcmp($153,$157,$156)|0);
         $159 = ($158|0)==(0);
         if ($159) {
          $160 = ($142>>>0)<($155>>>0);
          $$$i$i$i17 = $154&1;
          $$$$i$i$i18 = $160 ? -1 : $$$i$i$i17;
          $162 = $$$$i$i$i18;
         } else {
          $162 = $158;
         }
         $161 = ($162|0)<(0);
         $141 = (($__i$065) + 12|0);
         if ($161) {
          $$lcssa64 = $__i$065;$__i$0$lcssa63 = $__i$065;
          break L77;
         }
         $140 = ($141|0)==($1|0);
         if ($140) {
          label = 175;
          break L1;
         } else {
          $__i$065 = $141;
         }
        }
       }
      } while(0);
      ;HEAP32[$__t$sroa$0$i$i$i54+0>>2]=HEAP32[$$lcssa64+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+4>>2]=HEAP32[$$lcssa64+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+8>>2]=HEAP32[$$lcssa64+8>>2]|0;
      ;HEAP32[$$lcssa64+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$lcssa64+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$lcssa64+8>>2]=HEAP32[$1+8>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$sroa$0$i$i$i54+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$sroa$0$i$i$i54+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$sroa$0$i$i$i54+8>>2]|0;
      $163 = (($__i$0$lcssa63) + 12|0);
      $__i$1 = $163;
     }
     $164 = ($__i$1|0)==($1|0);
     if ($164) {
      label = 175;
      break L1;
     }
     $165 = (($$0) + 1|0);
     $166 = (($$0) + 8|0);
     $167 = (($$0) + 4|0);
     $__i$2$ph = $__i$1;$__j$1$ph = $1;
     while(1) {
      $168 = HEAP8[$$0>>0]|0;
      $169 = $168 & 1;
      $170 = ($169<<24>>24)==(0);
      $171 = $168&255;
      $172 = $171 >>> 1;
      $__i$2 = $__i$2$ph;
      while(1) {
       if ($170) {
        $187 = $172;
       } else {
        $173 = HEAP32[$167>>2]|0;
        $187 = $173;
       }
       $174 = HEAP8[$__i$2>>0]|0;
       $175 = $174 & 1;
       $176 = ($175<<24>>24)==(0);
       if ($176) {
        $179 = $174&255;
        $180 = $179 >>> 1;
        $186 = $180;
       } else {
        $177 = (($__i$2) + 4|0);
        $178 = HEAP32[$177>>2]|0;
        $186 = $178;
       }
       if ($170) {
        $189 = $165;
       } else {
        $181 = HEAP32[$166>>2]|0;
        $189 = $181;
       }
       if ($176) {
        $184 = (($__i$2) + 1|0);
        $190 = $184;
       } else {
        $182 = (($__i$2) + 8|0);
        $183 = HEAP32[$182>>2]|0;
        $190 = $183;
       }
       $185 = ($186>>>0)<($187>>>0);
       $188 = $185 ? $186 : $187;
       $191 = (_memcmp($189,$190,$188)|0);
       $192 = ($191|0)==(0);
       if ($192) {
        $193 = ($187>>>0)<($186>>>0);
        $$$i$i$i24 = $185&1;
        $$$$i$i$i25 = $193 ? -1 : $$$i$i$i24;
        $195 = $$$$i$i$i25;
       } else {
        $195 = $191;
       }
       $194 = ($195|0)<(0);
       $196 = (($__i$2) + 12|0);
       if ($194) {
        break;
       } else {
        $__i$2 = $196;
       }
      }
      if ($170) {
       $__j$2$us = $__j$1$ph;
       while(1) {
        $197 = (($__j$2$us) + -12|0);
        $198 = HEAP8[$197>>0]|0;
        $199 = $198 & 1;
        $200 = ($199<<24>>24)==(0);
        if ($200) {
         $205 = $198&255;
         $206 = $205 >>> 1;
         $207 = (($197) + 1|0);
         $209 = $206;$211 = $207;
        } else {
         $201 = (($__j$2$us) + -8|0);
         $202 = HEAP32[$201>>2]|0;
         $203 = (($__j$2$us) + -4|0);
         $204 = HEAP32[$203>>2]|0;
         $209 = $202;$211 = $204;
        }
        $208 = ($209>>>0)<($172>>>0);
        $210 = $208 ? $209 : $172;
        $212 = (_memcmp($165,$211,$210)|0);
        $213 = ($212|0)==(0);
        if ($213) {
         $214 = ($172>>>0)<($209>>>0);
         $$$i$i$i30$us = $208&1;
         $$$$i$i$i31$us = $214 ? -1 : $$$i$i$i30$us;
         $216 = $$$$i$i$i31$us;
        } else {
         $216 = $212;
        }
        $215 = ($216|0)<(0);
        if ($215) {
         $__j$2$us = $197;
        } else {
         $$lcssa67 = $197;$$lcssa68 = $197;
         break;
        }
       }
      } else {
       $__j$2 = $__j$1$ph;
       while(1) {
        $217 = (($__j$2) + -12|0);
        $218 = HEAP32[$167>>2]|0;
        $219 = HEAP8[$217>>0]|0;
        $220 = $219 & 1;
        $221 = ($220<<24>>24)==(0);
        if ($221) {
         $226 = $219&255;
         $227 = $226 >>> 1;
         $228 = (($217) + 1|0);
         $231 = $227;$233 = $228;
        } else {
         $222 = (($__j$2) + -8|0);
         $223 = HEAP32[$222>>2]|0;
         $224 = (($__j$2) + -4|0);
         $225 = HEAP32[$224>>2]|0;
         $231 = $223;$233 = $225;
        }
        $229 = HEAP32[$166>>2]|0;
        $230 = ($231>>>0)<($218>>>0);
        $232 = $230 ? $231 : $218;
        $234 = (_memcmp($229,$233,$232)|0);
        $235 = ($234|0)==(0);
        if ($235) {
         $236 = ($218>>>0)<($231>>>0);
         $$$i$i$i30 = $230&1;
         $$$$i$i$i31 = $236 ? -1 : $$$i$i$i30;
         $238 = $$$$i$i$i31;
        } else {
         $238 = $234;
        }
        $237 = ($238|0)<(0);
        if ($237) {
         $__j$2 = $217;
        } else {
         $$lcssa67 = $217;$$lcssa68 = $217;
         break;
        }
       }
      }
      $239 = ($__i$2>>>0)<($$lcssa67>>>0);
      if (!($239)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$sroa$0$i$i$i54+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+8>>2]=HEAP32[$__i$2+8>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$$lcssa68+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$$lcssa68+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$$lcssa68+8>>2]|0;
      ;HEAP32[$$lcssa68+0>>2]=HEAP32[$__t$sroa$0$i$i$i54+0>>2]|0;HEAP32[$$lcssa68+4>>2]=HEAP32[$__t$sroa$0$i$i$i54+4>>2]|0;HEAP32[$$lcssa68+8>>2]=HEAP32[$__t$sroa$0$i$i$i54+8>>2]|0;
      $__i$2$ph = $196;$__j$1$ph = $$lcssa67;
     }
    }
   } while(0);
   $266 = (($$0) + 12|0);
   $267 = ($266>>>0)<($__j$3>>>0);
   L145: do {
    if ($267) {
     $__i$3$ph = $266;$__j$4$ph = $__j$3;$__m$0$ph = $45;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $268 = HEAP8[$__m$0$ph>>0]|0;
      $269 = $268 & 1;
      $270 = ($269<<24>>24)==(0);
      $271 = $268&255;
      $272 = $271 >>> 1;
      $273 = (($__m$0$ph) + 1|0);
      $274 = (($__m$0$ph) + 8|0);
      $275 = (($__m$0$ph) + 4|0);
      $__i$3 = $__i$3$ph;
      while(1) {
       $276 = HEAP8[$__i$3>>0]|0;
       $277 = $276 & 1;
       $278 = ($277<<24>>24)==(0);
       if ($278) {
        $281 = $276&255;
        $282 = $281 >>> 1;
        $290 = $282;
       } else {
        $279 = (($__i$3) + 4|0);
        $280 = HEAP32[$279>>2]|0;
        $290 = $280;
       }
       if ($270) {
        $289 = $272;
       } else {
        $283 = HEAP32[$275>>2]|0;
        $289 = $283;
       }
       if ($278) {
        $286 = (($__i$3) + 1|0);
        $292 = $286;
       } else {
        $284 = (($__i$3) + 8|0);
        $285 = HEAP32[$284>>2]|0;
        $292 = $285;
       }
       if ($270) {
        $293 = $273;
       } else {
        $287 = HEAP32[$274>>2]|0;
        $293 = $287;
       }
       $288 = ($289>>>0)<($290>>>0);
       $291 = $288 ? $289 : $290;
       $294 = (_memcmp($292,$293,$291)|0);
       $295 = ($294|0)==(0);
       if ($295) {
        $296 = ($290>>>0)<($289>>>0);
        $$$i$i$i44 = $288&1;
        $$$$i$i$i45 = $296 ? -1 : $$$i$i$i44;
        $298 = $$$$i$i$i45;
       } else {
        $298 = $294;
       }
       $297 = ($298|0)<(0);
       $299 = (($__i$3) + 12|0);
       if ($297) {
        $__i$3 = $299;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $300 = (($__j$5) + -12|0);
       $301 = HEAP8[$300>>0]|0;
       $302 = $301 & 1;
       $303 = ($302<<24>>24)==(0);
       if ($303) {
        $306 = $301&255;
        $307 = $306 >>> 1;
        $315 = $307;
       } else {
        $304 = (($__j$5) + -8|0);
        $305 = HEAP32[$304>>2]|0;
        $315 = $305;
       }
       if ($270) {
        $314 = $272;
       } else {
        $308 = HEAP32[$275>>2]|0;
        $314 = $308;
       }
       if ($303) {
        $311 = (($300) + 1|0);
        $317 = $311;
       } else {
        $309 = (($__j$5) + -4|0);
        $310 = HEAP32[$309>>2]|0;
        $317 = $310;
       }
       if ($270) {
        $318 = $273;
       } else {
        $312 = HEAP32[$274>>2]|0;
        $318 = $312;
       }
       $313 = ($314>>>0)<($315>>>0);
       $316 = $313 ? $314 : $315;
       $319 = (_memcmp($317,$318,$316)|0);
       $320 = ($319|0)==(0);
       if ($320) {
        $321 = ($315>>>0)<($314>>>0);
        $$$i$i$i50 = $313&1;
        $$$$i$i$i51 = $321 ? -1 : $$$i$i$i50;
        $323 = $$$$i$i$i51;
       } else {
        $323 = $319;
       }
       $322 = ($323|0)<(0);
       if ($322) {
        break;
       } else {
        $__j$5 = $300;
       }
      }
      $324 = ($__i$3>>>0)>($300>>>0);
      if ($324) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L145;
      }
      ;HEAP32[$__t$sroa$0$i$i$i54+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+8>>2]=HEAP32[$__i$3+8>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$300+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$300+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$300+8>>2]|0;
      ;HEAP32[$300+0>>2]=HEAP32[$__t$sroa$0$i$i$i54+0>>2]|0;HEAP32[$300+4>>2]=HEAP32[$__t$sroa$0$i$i$i54+4>>2]|0;HEAP32[$300+8>>2]=HEAP32[$__t$sroa$0$i$i$i54+8>>2]|0;
      $325 = (($__n_swaps$4$ph) + 1)|0;
      $326 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $326 ? $300 : $__m$0$ph;
      $__i$3$ph = $299;$__j$4$ph = $300;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $325;
     }
    } else {
     $__i$4 = $266;$__m$2 = $45;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $327 = ($__i$4|0)==($__m$2|0);
   if ($327) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $328 = HEAP8[$__m$2>>0]|0;
    $329 = $328 & 1;
    $330 = ($329<<24>>24)==(0);
    if ($330) {
     $333 = $328&255;
     $334 = $333 >>> 1;
     $350 = $334;
    } else {
     $331 = (($__m$2) + 4|0);
     $332 = HEAP32[$331>>2]|0;
     $350 = $332;
    }
    $335 = HEAP8[$__i$4>>0]|0;
    $336 = $335 & 1;
    $337 = ($336<<24>>24)==(0);
    if ($337) {
     $340 = $335&255;
     $341 = $340 >>> 1;
     $349 = $341;
    } else {
     $338 = (($__i$4) + 4|0);
     $339 = HEAP32[$338>>2]|0;
     $349 = $339;
    }
    if ($330) {
     $344 = (($__m$2) + 1|0);
     $352 = $344;
    } else {
     $342 = (($__m$2) + 8|0);
     $343 = HEAP32[$342>>2]|0;
     $352 = $343;
    }
    if ($337) {
     $347 = (($__i$4) + 1|0);
     $353 = $347;
    } else {
     $345 = (($__i$4) + 8|0);
     $346 = HEAP32[$345>>2]|0;
     $353 = $346;
    }
    $348 = ($349>>>0)<($350>>>0);
    $351 = $348 ? $349 : $350;
    $354 = (_memcmp($352,$353,$351)|0);
    $355 = ($354|0)==(0);
    if ($355) {
     $356 = ($350>>>0)<($349>>>0);
     $$$i$i$i58 = $348&1;
     $$$$i$i$i59 = $356 ? -1 : $$$i$i$i58;
     $358 = $$$$i$i$i59;
    } else {
     $358 = $354;
    }
    $357 = ($358|0)<(0);
    if ($357) {
     ;HEAP32[$__t$sroa$0$i$i$i54+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+8>>2]=HEAP32[$__i$4+8>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$sroa$0$i$i$i54+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$sroa$0$i$i$i54+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$sroa$0$i$i$i54+8>>2]|0;
     $359 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $359;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $360 = ($__n_swaps$6|0)==(0);
   if ($360) {
    $361 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEbT0_SB_T_($$0,$__i$4,0)|0);
    $362 = (($__i$4) + 12|0);
    $363 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEbT0_SB_T_($362,$$01$ph,0)|0);
    if ($363) {
     label = 170;
     break;
    }
    if ($361) {
     $$0 = $362;
     continue;
    }
   }
   $364 = $__i$4;
   $365 = (($364) - ($5))|0;
   $366 = (($0) - ($364))|0;
   $367 = ($365|0)<($366|0);
   if (!($367)) {
    label = 174;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEvT0_SB_T_($$0,$__i$4,$__comp);
   $368 = (($__i$4) + 12|0);
   $$0 = $368;
  }
  if ((label|0) == 170) {
   label = 0;
   if ($361) {
    label = 175;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 174) {
   label = 0;
   $369 = (($__i$4) + 12|0);
   __ZNSt3__16__sortIRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEvT0_SB_T_($369,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $8 = HEAP8[$1>>0]|0;
  $9 = $8 & 1;
  $10 = ($9<<24>>24)==(0);
  if ($10) {
   $12 = $8&255;
   $13 = $12 >>> 1;
   $27 = $13;
  } else {
   $11 = HEAP32[$4>>2]|0;
   $27 = $11;
  }
  $14 = HEAP8[$$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $19 = $14&255;
   $20 = $19 >>> 1;
   $26 = $20;
  } else {
   $17 = (($$0) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $26 = $18;
  }
  if ($10) {
   $29 = $2;
  } else {
   $21 = HEAP32[$3>>2]|0;
   $29 = $21;
  }
  if ($16) {
   $24 = (($$0) + 1|0);
   $30 = $24;
  } else {
   $22 = (($$0) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $30 = $23;
  }
  $25 = ($26>>>0)<($27>>>0);
  $28 = $25 ? $26 : $27;
  $31 = (_memcmp($29,$30,$28)|0);
  $32 = ($31|0)==(0);
  if ($32) {
   $33 = ($27>>>0)<($26>>>0);
   $$$i$i$i = $25&1;
   $$$$i$i$i = $33 ? -1 : $$$i$i$i;
   $35 = $$$$i$i$i;
  } else {
   $35 = $31;
  }
  $34 = ($35|0)<(0);
  if (!($34)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$sroa$0$i$i$i54+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i54+8>>2]=HEAP32[$$0+8>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$sroa$0$i$i$i54+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$sroa$0$i$i$i54+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$sroa$0$i$i$i54+8>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 19) {
  $36 = (($$0) + 12|0);
  (__ZNSt3__17__sort3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_T_($$0,$36,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 20) {
  $37 = (($$0) + 12|0);
  $38 = (($$0) + 24|0);
  (__ZNSt3__17__sort4IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_SB_T_($$0,$37,$38,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $39 = (($$0) + 12|0);
  $40 = (($$0) + 24|0);
  $41 = (($$0) + 36|0);
  (__ZNSt3__17__sort5IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_SB_SB_T_($$0,$39,$40,$41,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 23) {
  __ZNSt3__118__insertion_sort_3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEvT0_SB_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 175) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$$$i$i$i = 0, $$$$i$i$i12 = 0, $$$$i$i$i18 = 0, $$$$i$i$i5 = 0, $$$i$i$i = 0, $$$i$i$i11 = 0, $$$i$i$i17 = 0, $$$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__t$sroa$0$i$i$i22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$sroa$0$i$i$i22 = sp;
 $0 = HEAP8[$__y>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $22 = $6;
 } else {
  $3 = (($__y) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $22 = $4;
 }
 $7 = HEAP8[$__x>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $12 = $7&255;
  $13 = $12 >>> 1;
  $21 = $13;
 } else {
  $10 = (($__x) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $21 = $11;
 }
 if ($2) {
  $16 = (($__y) + 1|0);
  $24 = $16;
 } else {
  $14 = (($__y) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $24 = $15;
 }
 if ($9) {
  $19 = (($__x) + 1|0);
  $25 = $19;
 } else {
  $17 = (($__x) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $25 = $18;
 }
 $20 = ($21>>>0)<($22>>>0);
 $23 = $20 ? $21 : $22;
 $26 = (_memcmp($24,$25,$23)|0);
 $27 = ($26|0)==(0);
 if ($27) {
  $28 = ($22>>>0)<($21>>>0);
  $$$i$i$i = $20&1;
  $$$$i$i$i = $28 ? -1 : $$$i$i$i;
  $30 = $$$$i$i$i;
 } else {
  $30 = $26;
 }
 $29 = ($30|0)<(0);
 $31 = HEAP8[$__z>>0]|0;
 $32 = $31 & 1;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  $36 = $31&255;
  $37 = $36 >>> 1;
  $50 = $37;
 } else {
  $34 = (($__z) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $50 = $35;
 }
 if ($2) {
  $40 = $0&255;
  $41 = $40 >>> 1;
  $49 = $41;
 } else {
  $38 = (($__y) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $49 = $39;
 }
 if ($33) {
  $44 = (($__z) + 1|0);
  $52 = $44;
 } else {
  $42 = (($__z) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $52 = $43;
 }
 if ($2) {
  $47 = (($__y) + 1|0);
  $53 = $47;
 } else {
  $45 = (($__y) + 8|0);
  $46 = HEAP32[$45>>2]|0;
  $53 = $46;
 }
 $48 = ($49>>>0)<($50>>>0);
 $51 = $48 ? $49 : $50;
 $54 = (_memcmp($52,$53,$51)|0);
 $55 = ($54|0)==(0);
 if ($55) {
  $56 = ($50>>>0)<($49>>>0);
  $$$i$i$i4 = $48&1;
  $$$$i$i$i5 = $56 ? -1 : $$$i$i$i4;
  $58 = $$$$i$i$i5;
 } else {
  $58 = $54;
 }
 $57 = ($58|0)<(0);
 if (!($29)) {
  if (!($57)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$sroa$0$i$i$i22+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+8>>2]=HEAP32[$__y+8>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$sroa$0$i$i$i22+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$sroa$0$i$i$i22+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$sroa$0$i$i$i22+8>>2]|0;
  $59 = HEAP8[$__y>>0]|0;
  $60 = $59 & 1;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $64 = $59&255;
   $65 = $64 >>> 1;
   $81 = $65;
  } else {
   $62 = (($__y) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $81 = $63;
  }
  $66 = HEAP8[$__x>>0]|0;
  $67 = $66 & 1;
  $68 = ($67<<24>>24)==(0);
  if ($68) {
   $71 = $66&255;
   $72 = $71 >>> 1;
   $80 = $72;
  } else {
   $69 = (($__x) + 4|0);
   $70 = HEAP32[$69>>2]|0;
   $80 = $70;
  }
  if ($61) {
   $75 = (($__y) + 1|0);
   $83 = $75;
  } else {
   $73 = (($__y) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   $83 = $74;
  }
  if ($68) {
   $78 = (($__x) + 1|0);
   $84 = $78;
  } else {
   $76 = (($__x) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   $84 = $77;
  }
  $79 = ($80>>>0)<($81>>>0);
  $82 = $79 ? $80 : $81;
  $85 = (_memcmp($83,$84,$82)|0);
  $86 = ($85|0)==(0);
  if ($86) {
   $87 = ($81>>>0)<($80>>>0);
   $$$i$i$i17 = $79&1;
   $$$$i$i$i18 = $87 ? -1 : $$$i$i$i17;
   $89 = $$$$i$i$i18;
  } else {
   $89 = $85;
  }
  $88 = ($89|0)<(0);
  if (!($88)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$sroa$0$i$i$i22+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+8>>2]=HEAP32[$__x+8>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__t$sroa$0$i$i$i22+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$sroa$0$i$i$i22+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$sroa$0$i$i$i22+8>>2]|0;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($57) {
  ;HEAP32[$__t$sroa$0$i$i$i22+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+8>>2]=HEAP32[$__x+8>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__z+8>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$sroa$0$i$i$i22+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$sroa$0$i$i$i22+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$sroa$0$i$i$i22+8>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i22+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+8>>2]=HEAP32[$__x+8>>2]|0;
 ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__t$sroa$0$i$i$i22+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$sroa$0$i$i$i22+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$sroa$0$i$i$i22+8>>2]|0;
 $90 = HEAP8[$__z>>0]|0;
 $91 = $90 & 1;
 $92 = ($91<<24>>24)==(0);
 if ($92) {
  $95 = $90&255;
  $96 = $95 >>> 1;
  $112 = $96;
 } else {
  $93 = (($__z) + 4|0);
  $94 = HEAP32[$93>>2]|0;
  $112 = $94;
 }
 $97 = HEAP8[$__y>>0]|0;
 $98 = $97 & 1;
 $99 = ($98<<24>>24)==(0);
 if ($99) {
  $102 = $97&255;
  $103 = $102 >>> 1;
  $111 = $103;
 } else {
  $100 = (($__y) + 4|0);
  $101 = HEAP32[$100>>2]|0;
  $111 = $101;
 }
 if ($92) {
  $106 = (($__z) + 1|0);
  $114 = $106;
 } else {
  $104 = (($__z) + 8|0);
  $105 = HEAP32[$104>>2]|0;
  $114 = $105;
 }
 if ($99) {
  $109 = (($__y) + 1|0);
  $115 = $109;
 } else {
  $107 = (($__y) + 8|0);
  $108 = HEAP32[$107>>2]|0;
  $115 = $108;
 }
 $110 = ($111>>>0)<($112>>>0);
 $113 = $110 ? $111 : $112;
 $116 = (_memcmp($114,$115,$113)|0);
 $117 = ($116|0)==(0);
 if ($117) {
  $118 = ($112>>>0)<($111>>>0);
  $$$i$i$i11 = $110&1;
  $$$$i$i$i12 = $118 ? -1 : $$$i$i$i11;
  $120 = $$$$i$i$i12;
 } else {
  $120 = $116;
 }
 $119 = ($120|0)<(0);
 if (!($119)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i22+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i22+8>>2]=HEAP32[$__y+8>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;
 ;HEAP32[$__z+0>>2]=HEAP32[$__t$sroa$0$i$i$i22+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$sroa$0$i$i$i22+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$sroa$0$i$i$i22+8>>2]|0;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_SB_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$$$i$i$i = 0, $$$$i$i$i12 = 0, $$$$i$i$i6 = 0, $$$i$i$i = 0, $$$i$i$i11 = 0, $$$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $__r$0 = 0, $__t$sroa$0$i$i$i14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$sroa$0$i$i$i14 = sp;
 $0 = (__ZNSt3__17__sort3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_T_($__x1,$__x2,$__x3,0)|0);
 $1 = HEAP8[$__x4>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $23 = $7;
 } else {
  $4 = (($__x4) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $23 = $5;
 }
 $8 = HEAP8[$__x3>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $13 = $8&255;
  $14 = $13 >>> 1;
  $22 = $14;
 } else {
  $11 = (($__x3) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $22 = $12;
 }
 if ($3) {
  $17 = (($__x4) + 1|0);
  $25 = $17;
 } else {
  $15 = (($__x4) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $25 = $16;
 }
 if ($10) {
  $20 = (($__x3) + 1|0);
  $26 = $20;
 } else {
  $18 = (($__x3) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $26 = $19;
 }
 $21 = ($22>>>0)<($23>>>0);
 $24 = $21 ? $22 : $23;
 $27 = (_memcmp($25,$26,$24)|0);
 $28 = ($27|0)==(0);
 if ($28) {
  $29 = ($23>>>0)<($22>>>0);
  $$$i$i$i = $21&1;
  $$$$i$i$i = $29 ? -1 : $$$i$i$i;
  $31 = $$$$i$i$i;
 } else {
  $31 = $27;
 }
 $30 = ($31|0)<(0);
 if (!($30)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i14+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i14+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i14+8>>2]=HEAP32[$__x3+8>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$sroa$0$i$i$i14+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$sroa$0$i$i$i14+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$sroa$0$i$i$i14+8>>2]|0;
 $32 = (($0) + 1)|0;
 $33 = HEAP8[$__x3>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $38 = $33&255;
  $39 = $38 >>> 1;
  $55 = $39;
 } else {
  $36 = (($__x3) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $55 = $37;
 }
 $40 = HEAP8[$__x2>>0]|0;
 $41 = $40 & 1;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  $45 = $40&255;
  $46 = $45 >>> 1;
  $54 = $46;
 } else {
  $43 = (($__x2) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $54 = $44;
 }
 if ($35) {
  $49 = (($__x3) + 1|0);
  $57 = $49;
 } else {
  $47 = (($__x3) + 8|0);
  $48 = HEAP32[$47>>2]|0;
  $57 = $48;
 }
 if ($42) {
  $52 = (($__x2) + 1|0);
  $58 = $52;
 } else {
  $50 = (($__x2) + 8|0);
  $51 = HEAP32[$50>>2]|0;
  $58 = $51;
 }
 $53 = ($54>>>0)<($55>>>0);
 $56 = $53 ? $54 : $55;
 $59 = (_memcmp($57,$58,$56)|0);
 $60 = ($59|0)==(0);
 if ($60) {
  $61 = ($55>>>0)<($54>>>0);
  $$$i$i$i11 = $53&1;
  $$$$i$i$i12 = $61 ? -1 : $$$i$i$i11;
  $63 = $$$$i$i$i12;
 } else {
  $63 = $59;
 }
 $62 = ($63|0)<(0);
 if (!($62)) {
  $__r$0 = $32;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i14+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i14+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i14+8>>2]=HEAP32[$__x2+8>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$sroa$0$i$i$i14+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$sroa$0$i$i$i14+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$sroa$0$i$i$i14+8>>2]|0;
 $64 = (($0) + 2)|0;
 $65 = HEAP8[$__x2>>0]|0;
 $66 = $65 & 1;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  $70 = $65&255;
  $71 = $70 >>> 1;
  $87 = $71;
 } else {
  $68 = (($__x2) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  $87 = $69;
 }
 $72 = HEAP8[$__x1>>0]|0;
 $73 = $72 & 1;
 $74 = ($73<<24>>24)==(0);
 if ($74) {
  $77 = $72&255;
  $78 = $77 >>> 1;
  $86 = $78;
 } else {
  $75 = (($__x1) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  $86 = $76;
 }
 if ($67) {
  $81 = (($__x2) + 1|0);
  $89 = $81;
 } else {
  $79 = (($__x2) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  $89 = $80;
 }
 if ($74) {
  $84 = (($__x1) + 1|0);
  $90 = $84;
 } else {
  $82 = (($__x1) + 8|0);
  $83 = HEAP32[$82>>2]|0;
  $90 = $83;
 }
 $85 = ($86>>>0)<($87>>>0);
 $88 = $85 ? $86 : $87;
 $91 = (_memcmp($89,$90,$88)|0);
 $92 = ($91|0)==(0);
 if ($92) {
  $93 = ($87>>>0)<($86>>>0);
  $$$i$i$i5 = $85&1;
  $$$$i$i$i6 = $93 ? -1 : $$$i$i$i5;
  $95 = $$$$i$i$i6;
 } else {
  $95 = $91;
 }
 $94 = ($95|0)<(0);
 if (!($94)) {
  $__r$0 = $64;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i14+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i14+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i14+8>>2]=HEAP32[$__x1+8>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$sroa$0$i$i$i14+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$sroa$0$i$i$i14+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$sroa$0$i$i$i14+8>>2]|0;
 $96 = (($0) + 3)|0;
 $__r$0 = $96;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_SB_SB_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $$$$i$i$i = 0, $$$$i$i$i12 = 0, $$$$i$i$i20 = 0, $$$$i$i$i6 = 0, $$$i$i$i = 0, $$$i$i$i11 = 0, $$$i$i$i19 = 0, $$$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__t$sroa$0$i$i$i15 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$sroa$0$i$i$i15 = sp;
 $0 = (__ZNSt3__17__sort4IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_SB_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = HEAP8[$__x5>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $23 = $7;
 } else {
  $4 = (($__x5) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $23 = $5;
 }
 $8 = HEAP8[$__x4>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $13 = $8&255;
  $14 = $13 >>> 1;
  $22 = $14;
 } else {
  $11 = (($__x4) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $22 = $12;
 }
 if ($3) {
  $17 = (($__x5) + 1|0);
  $25 = $17;
 } else {
  $15 = (($__x5) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $25 = $16;
 }
 if ($10) {
  $20 = (($__x4) + 1|0);
  $26 = $20;
 } else {
  $18 = (($__x4) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $26 = $19;
 }
 $21 = ($22>>>0)<($23>>>0);
 $24 = $21 ? $22 : $23;
 $27 = (_memcmp($25,$26,$24)|0);
 $28 = ($27|0)==(0);
 if ($28) {
  $29 = ($23>>>0)<($22>>>0);
  $$$i$i$i = $21&1;
  $$$$i$i$i = $29 ? -1 : $$$i$i$i;
  $31 = $$$$i$i$i;
 } else {
  $31 = $27;
 }
 $30 = ($31|0)<(0);
 if (!($30)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i15+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i15+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i15+8>>2]=HEAP32[$__x4+8>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__x5+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__x5+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__x5+8>>2]|0;
 ;HEAP32[$__x5+0>>2]=HEAP32[$__t$sroa$0$i$i$i15+0>>2]|0;HEAP32[$__x5+4>>2]=HEAP32[$__t$sroa$0$i$i$i15+4>>2]|0;HEAP32[$__x5+8>>2]=HEAP32[$__t$sroa$0$i$i$i15+8>>2]|0;
 $32 = (($0) + 1)|0;
 $33 = HEAP8[$__x4>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $38 = $33&255;
  $39 = $38 >>> 1;
  $55 = $39;
 } else {
  $36 = (($__x4) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $55 = $37;
 }
 $40 = HEAP8[$__x3>>0]|0;
 $41 = $40 & 1;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  $45 = $40&255;
  $46 = $45 >>> 1;
  $54 = $46;
 } else {
  $43 = (($__x3) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $54 = $44;
 }
 if ($35) {
  $49 = (($__x4) + 1|0);
  $57 = $49;
 } else {
  $47 = (($__x4) + 8|0);
  $48 = HEAP32[$47>>2]|0;
  $57 = $48;
 }
 if ($42) {
  $52 = (($__x3) + 1|0);
  $58 = $52;
 } else {
  $50 = (($__x3) + 8|0);
  $51 = HEAP32[$50>>2]|0;
  $58 = $51;
 }
 $53 = ($54>>>0)<($55>>>0);
 $56 = $53 ? $54 : $55;
 $59 = (_memcmp($57,$58,$56)|0);
 $60 = ($59|0)==(0);
 if ($60) {
  $61 = ($55>>>0)<($54>>>0);
  $$$i$i$i11 = $53&1;
  $$$$i$i$i12 = $61 ? -1 : $$$i$i$i11;
  $63 = $$$$i$i$i12;
 } else {
  $63 = $59;
 }
 $62 = ($63|0)<(0);
 if (!($62)) {
  $__r$0 = $32;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i15+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i15+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i15+8>>2]=HEAP32[$__x3+8>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$sroa$0$i$i$i15+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$sroa$0$i$i$i15+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$sroa$0$i$i$i15+8>>2]|0;
 $64 = (($0) + 2)|0;
 $65 = HEAP8[$__x3>>0]|0;
 $66 = $65 & 1;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  $70 = $65&255;
  $71 = $70 >>> 1;
  $87 = $71;
 } else {
  $68 = (($__x3) + 4|0);
  $69 = HEAP32[$68>>2]|0;
  $87 = $69;
 }
 $72 = HEAP8[$__x2>>0]|0;
 $73 = $72 & 1;
 $74 = ($73<<24>>24)==(0);
 if ($74) {
  $77 = $72&255;
  $78 = $77 >>> 1;
  $86 = $78;
 } else {
  $75 = (($__x2) + 4|0);
  $76 = HEAP32[$75>>2]|0;
  $86 = $76;
 }
 if ($67) {
  $81 = (($__x3) + 1|0);
  $89 = $81;
 } else {
  $79 = (($__x3) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  $89 = $80;
 }
 if ($74) {
  $84 = (($__x2) + 1|0);
  $90 = $84;
 } else {
  $82 = (($__x2) + 8|0);
  $83 = HEAP32[$82>>2]|0;
  $90 = $83;
 }
 $85 = ($86>>>0)<($87>>>0);
 $88 = $85 ? $86 : $87;
 $91 = (_memcmp($89,$90,$88)|0);
 $92 = ($91|0)==(0);
 if ($92) {
  $93 = ($87>>>0)<($86>>>0);
  $$$i$i$i19 = $85&1;
  $$$$i$i$i20 = $93 ? -1 : $$$i$i$i19;
  $95 = $$$$i$i$i20;
 } else {
  $95 = $91;
 }
 $94 = ($95|0)<(0);
 if (!($94)) {
  $__r$0 = $64;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i15+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i15+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i15+8>>2]=HEAP32[$__x2+8>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$sroa$0$i$i$i15+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$sroa$0$i$i$i15+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$sroa$0$i$i$i15+8>>2]|0;
 $96 = (($0) + 3)|0;
 $97 = HEAP8[$__x2>>0]|0;
 $98 = $97 & 1;
 $99 = ($98<<24>>24)==(0);
 if ($99) {
  $102 = $97&255;
  $103 = $102 >>> 1;
  $119 = $103;
 } else {
  $100 = (($__x2) + 4|0);
  $101 = HEAP32[$100>>2]|0;
  $119 = $101;
 }
 $104 = HEAP8[$__x1>>0]|0;
 $105 = $104 & 1;
 $106 = ($105<<24>>24)==(0);
 if ($106) {
  $109 = $104&255;
  $110 = $109 >>> 1;
  $118 = $110;
 } else {
  $107 = (($__x1) + 4|0);
  $108 = HEAP32[$107>>2]|0;
  $118 = $108;
 }
 if ($99) {
  $113 = (($__x2) + 1|0);
  $121 = $113;
 } else {
  $111 = (($__x2) + 8|0);
  $112 = HEAP32[$111>>2]|0;
  $121 = $112;
 }
 if ($106) {
  $116 = (($__x1) + 1|0);
  $122 = $116;
 } else {
  $114 = (($__x1) + 8|0);
  $115 = HEAP32[$114>>2]|0;
  $122 = $115;
 }
 $117 = ($118>>>0)<($119>>>0);
 $120 = $117 ? $118 : $119;
 $123 = (_memcmp($121,$122,$120)|0);
 $124 = ($123|0)==(0);
 if ($124) {
  $125 = ($119>>>0)<($118>>>0);
  $$$i$i$i5 = $117&1;
  $$$$i$i$i6 = $125 ? -1 : $$$i$i$i5;
  $127 = $$$$i$i$i6;
 } else {
  $127 = $123;
 }
 $126 = ($127|0)<(0);
 if (!($126)) {
  $__r$0 = $96;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$sroa$0$i$i$i15+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i15+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i15+8>>2]=HEAP32[$__x1+8>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$sroa$0$i$i$i15+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$sroa$0$i$i$i15+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$sroa$0$i$i$i15+8>>2]|0;
 $128 = (($0) + 4)|0;
 $__r$0 = $128;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEvT0_SB_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$ = 0, $$$$i$i$i = 0, $$$$i$i$i5 = 0, $$$i$i$i = 0, $$$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$09 = 0, $__j$010 = 0, $__j$010$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa11 = 0, $__p$0$i$i$i = 0, $__t = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = (($__first) + 24|0);
 $1 = (($__first) + 12|0);
 (__ZNSt3__17__sort3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 36|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($__t) + 1|0);
 $5 = (($__t) + 8|0);
 $6 = (($__t) + 4|0);
 $__i$09 = $2;$__j$010 = $0;
 L4: while(1) {
  $7 = HEAP8[$__i$09>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   $12 = $7&255;
   $13 = $12 >>> 1;
   $29 = $13;
  } else {
   $10 = (($__i$09) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $29 = $11;
  }
  $14 = HEAP8[$__j$010>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $19 = $14&255;
   $20 = $19 >>> 1;
   $28 = $20;
  } else {
   $17 = (($__j$010) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $28 = $18;
  }
  if ($9) {
   $23 = (($__i$09) + 1|0);
   $31 = $23;
  } else {
   $21 = (($__i$09) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $31 = $22;
  }
  if ($16) {
   $26 = (($__j$010) + 1|0);
   $32 = $26;
  } else {
   $24 = (($__j$010) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $32 = $25;
  }
  $27 = ($28>>>0)<($29>>>0);
  $30 = $27 ? $28 : $29;
  $33 = (_memcmp($31,$32,$30)|0);
  $34 = ($33|0)==(0);
  if ($34) {
   $35 = ($29>>>0)<($28>>>0);
   $$$i$i$i = $27&1;
   $$$$i$i$i = $35 ? -1 : $$$i$i$i;
   $37 = $$$$i$i$i;
  } else {
   $37 = $33;
  }
  $36 = ($37|0)<(0);
  if ($36) {
   $38 = HEAP8[$__i$09>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    ;HEAP32[$__t+0>>2]=HEAP32[$__i$09+0>>2]|0;HEAP32[$__t+4>>2]=HEAP32[$__i$09+4>>2]|0;HEAP32[$__t+8>>2]=HEAP32[$__i$09+8>>2]|0;
    $__j$1 = $__i$09;$__k$0 = $__j$010;
   } else {
    $41 = (($__i$09) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($__i$09) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44>>>0)>(4294967279);
    if ($45) {
     label = 21;
     break;
    }
    $46 = ($44>>>0)<(11);
    if ($46) {
     $47 = $44 << 1;
     $48 = $47&255;
     HEAP8[$__t>>0] = $48;
     $__p$0$i$i$i = $4;
    } else {
     $49 = (($44) + 16)|0;
     $50 = $49 & -16;
     $51 = (__Znwj($50)|0);
     HEAP32[$5>>2] = $51;
     $52 = $50 | 1;
     HEAP32[$__t>>2] = $52;
     HEAP32[$6>>2] = $44;
     $__p$0$i$i$i = $51;
    }
    _memcpy(($__p$0$i$i$i|0),($42|0),($44|0))|0;
    $53 = (($__p$0$i$i$i) + ($44)|0);
    HEAP8[$53>>0] = 0;
    $__j$1 = $__i$09;$__k$0 = $__j$010;
   }
   while(1) {
    __THREW__ = 0;
    (invoke_iii(2233,($__j$1|0),($__k$0|0))|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 43;
     break L4;
    }
    $56 = ($__k$0|0)==($__first|0);
    if ($56) {
     $__k$0$lcssa11 = $__first;
     break;
    }
    $57 = (($__k$0) + -12|0);
    $58 = HEAP8[$__t>>0]|0;
    $59 = $58 & 1;
    $60 = ($59<<24>>24)==(0);
    if ($60) {
     $62 = $58&255;
     $63 = $62 >>> 1;
     $77 = $63;
    } else {
     $61 = HEAP32[$6>>2]|0;
     $77 = $61;
    }
    $64 = HEAP8[$57>>0]|0;
    $65 = $64 & 1;
    $66 = ($65<<24>>24)==(0);
    if ($66) {
     $69 = $64&255;
     $70 = $69 >>> 1;
     $76 = $70;
    } else {
     $67 = (($__k$0) + -8|0);
     $68 = HEAP32[$67>>2]|0;
     $76 = $68;
    }
    $71 = HEAP32[$5>>2]|0;
    $$ = $60 ? $4 : $71;
    if ($66) {
     $74 = (($57) + 1|0);
     $79 = $74;
    } else {
     $72 = (($__k$0) + -4|0);
     $73 = HEAP32[$72>>2]|0;
     $79 = $73;
    }
    $75 = ($76>>>0)<($77>>>0);
    $78 = $75 ? $76 : $77;
    $80 = (_memcmp($$,$79,$78)|0);
    $81 = ($80|0)==(0);
    if ($81) {
     $82 = ($77>>>0)<($76>>>0);
     $$$i$i$i4 = $75&1;
     $$$$i$i$i5 = $82 ? -1 : $$$i$i$i4;
     $84 = $$$$i$i$i5;
    } else {
     $84 = $80;
    }
    $83 = ($84|0)<(0);
    if ($83) {
     $__j$1$phi = $__k$0;$__k$0 = $57;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa11 = $__k$0;
     break;
    }
   }
   __THREW__ = 0;
   (invoke_iii(2233,($__k$0$lcssa11|0),($__t|0))|0);
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    label = 44;
    break;
   }
   $87 = HEAP8[$__t>>0]|0;
   $88 = $87 & 1;
   $89 = ($88<<24>>24)==(0);
   if (!($89)) {
    $90 = HEAP32[$5>>2]|0;
    __ZdlPv($90);
   }
  }
  $99 = (($__i$09) + 12|0);
  $100 = ($99|0)==($__last|0);
  if ($100) {
   label = 48;
   break;
  } else {
   $__j$010$phi = $__i$09;$__i$09 = $99;$__j$010 = $__j$010$phi;
  }
 }
 if ((label|0) == 21) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 43) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  $lpad$phi$index = $91;$lpad$phi$index2 = $92;
 }
 else if ((label|0) == 44) {
  $93 = ___cxa_find_matching_catch()|0;
  $94 = tempRet0;
  $lpad$phi$index = $93;$lpad$phi$index2 = $94;
 }
 else if ((label|0) == 48) {
  STACKTOP = sp;return;
 }
 $95 = HEAP8[$__t>>0]|0;
 $96 = $95 & 1;
 $97 = ($96<<24>>24)==(0);
 if ($97) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $98 = HEAP32[$5>>2]|0;
 __ZdlPv($98);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEbT0_SB_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$ = 0, $$$$i$i$i = 0, $$$$i$i$i13 = 0, $$$$i$i$i6 = 0, $$$i$i$i = 0, $$$i$i$i12 = 0, $$$i$i$i5 = 0, $$0 = 0, $$0120 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$018 = 0;
 var $__count$1 = 0, $__i$019 = 0, $__i$1 = 0, $__i$2 = 0, $__j$017 = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa21 = 0, $__p$0$i$i$i = 0, $__t = 0, $__t$sroa$0$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$sroa$0$i$i$i = sp;
 $__t = sp + 12|0;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 12)&-1;
 switch ($3|0) {
 case 3:  {
  $36 = (($__first) + 12|0);
  $37 = (($__last) + -12|0);
  (__ZNSt3__17__sort3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_T_($__first,$36,$37,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 4:  {
  $38 = (($__first) + 12|0);
  $39 = (($__first) + 24|0);
  $40 = (($__last) + -12|0);
  (__ZNSt3__17__sort4IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_SB_T_($__first,$38,$39,$40,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 5:  {
  $41 = (($__first) + 12|0);
  $42 = (($__first) + 24|0);
  $43 = (($__first) + 36|0);
  $44 = (($__last) + -12|0);
  (__ZNSt3__17__sort5IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_SB_SB_T_($__first,$41,$42,$43,$44,0)|0);
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -12|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   $10 = $5&255;
   $11 = $10 >>> 1;
   $27 = $11;
  } else {
   $8 = (($__last) + -8|0);
   $9 = HEAP32[$8>>2]|0;
   $27 = $9;
  }
  $12 = HEAP8[$__first>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $17 = $12&255;
   $18 = $17 >>> 1;
   $26 = $18;
  } else {
   $15 = (($__first) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $26 = $16;
  }
  if ($7) {
   $21 = (($4) + 1|0);
   $29 = $21;
  } else {
   $19 = (($__last) + -4|0);
   $20 = HEAP32[$19>>2]|0;
   $29 = $20;
  }
  if ($14) {
   $24 = (($__first) + 1|0);
   $30 = $24;
  } else {
   $22 = (($__first) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $30 = $23;
  }
  $25 = ($26>>>0)<($27>>>0);
  $28 = $25 ? $26 : $27;
  $31 = (_memcmp($29,$30,$28)|0);
  $32 = ($31|0)==(0);
  if ($32) {
   $33 = ($27>>>0)<($26>>>0);
   $$$i$i$i = $25&1;
   $$$$i$i$i = $33 ? -1 : $$$i$i$i;
   $35 = $$$$i$i$i;
  } else {
   $35 = $31;
  }
  $34 = ($35|0)<(0);
  if (!($34)) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  ;HEAP32[$__t$sroa$0$i$i$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$sroa$0$i$i$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$sroa$0$i$i$i+8>>2]=HEAP32[$__first+8>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$sroa$0$i$i$i+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$sroa$0$i$i$i+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$sroa$0$i$i$i+8>>2]|0;
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 case 1: case 0:  {
  $$3 = 1;
  STACKTOP = sp;return ($$3|0);
  break;
 }
 default: {
  $45 = (($__first) + 24|0);
  $46 = (($__first) + 12|0);
  (__ZNSt3__17__sort3IRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEjT0_SB_SB_T_($__first,$46,$45,0)|0);
  $47 = (($__first) + 36|0);
  $48 = ($47|0)==($__last|0);
  if ($48) {
   $$3 = 1;
   STACKTOP = sp;return ($$3|0);
  }
  $49 = (($__t) + 1|0);
  $50 = (($__t) + 8|0);
  $51 = (($__t) + 4|0);
  $$0120 = 0;$__count$018 = 0;$__i$019 = $47;$__j$017 = $45;
  L12: while(1) {
   $52 = HEAP8[$__i$019>>0]|0;
   $53 = $52 & 1;
   $54 = ($53<<24>>24)==(0);
   if ($54) {
    $57 = $52&255;
    $58 = $57 >>> 1;
    $74 = $58;
   } else {
    $55 = (($__i$019) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $74 = $56;
   }
   $59 = HEAP8[$__j$017>>0]|0;
   $60 = $59 & 1;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    $64 = $59&255;
    $65 = $64 >>> 1;
    $73 = $65;
   } else {
    $62 = (($__j$017) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    $73 = $63;
   }
   if ($54) {
    $68 = (($__i$019) + 1|0);
    $76 = $68;
   } else {
    $66 = (($__i$019) + 8|0);
    $67 = HEAP32[$66>>2]|0;
    $76 = $67;
   }
   if ($61) {
    $71 = (($__j$017) + 1|0);
    $77 = $71;
   } else {
    $69 = (($__j$017) + 8|0);
    $70 = HEAP32[$69>>2]|0;
    $77 = $70;
   }
   $72 = ($73>>>0)<($74>>>0);
   $75 = $72 ? $73 : $74;
   $78 = (_memcmp($76,$77,$75)|0);
   $79 = ($78|0)==(0);
   if ($79) {
    $80 = ($74>>>0)<($73>>>0);
    $$$i$i$i5 = $72&1;
    $$$$i$i$i6 = $80 ? -1 : $$$i$i$i5;
    $82 = $$$$i$i$i6;
   } else {
    $82 = $78;
   }
   $81 = ($82|0)<(0);
   if ($81) {
    if ($54) {
     ;HEAP32[$__t+0>>2]=HEAP32[$__i$019+0>>2]|0;HEAP32[$__t+4>>2]=HEAP32[$__i$019+4>>2]|0;HEAP32[$__t+8>>2]=HEAP32[$__i$019+8>>2]|0;
     $__j$1 = $__i$019;$__k$0 = $__j$017;
    } else {
     $83 = (($__i$019) + 8|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = (($__i$019) + 4|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86>>>0)>(4294967279);
     if ($87) {
      label = 41;
      break;
     }
     $88 = ($86>>>0)<(11);
     if ($88) {
      $89 = $86 << 1;
      $90 = $89&255;
      HEAP8[$__t>>0] = $90;
      $__p$0$i$i$i = $49;
     } else {
      $91 = (($86) + 16)|0;
      $92 = $91 & -16;
      $93 = (__Znwj($92)|0);
      HEAP32[$50>>2] = $93;
      $94 = $92 | 1;
      HEAP32[$__t>>2] = $94;
      HEAP32[$51>>2] = $86;
      $__p$0$i$i$i = $93;
     }
     _memcpy(($__p$0$i$i$i|0),($84|0),($86|0))|0;
     $95 = (($__p$0$i$i$i) + ($86)|0);
     HEAP8[$95>>0] = 0;
     $__j$1 = $__i$019;$__k$0 = $__j$017;
    }
    while(1) {
     __THREW__ = 0;
     (invoke_iii(2233,($__j$1|0),($__k$0|0))|0);
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      label = 63;
      break L12;
     }
     $98 = ($__k$0|0)==($__first|0);
     if ($98) {
      $__k$0$lcssa21 = $__first;
      break;
     }
     $99 = (($__k$0) + -12|0);
     $100 = HEAP8[$__t>>0]|0;
     $101 = $100 & 1;
     $102 = ($101<<24>>24)==(0);
     if ($102) {
      $104 = $100&255;
      $105 = $104 >>> 1;
      $119 = $105;
     } else {
      $103 = HEAP32[$51>>2]|0;
      $119 = $103;
     }
     $106 = HEAP8[$99>>0]|0;
     $107 = $106 & 1;
     $108 = ($107<<24>>24)==(0);
     if ($108) {
      $111 = $106&255;
      $112 = $111 >>> 1;
      $118 = $112;
     } else {
      $109 = (($__k$0) + -8|0);
      $110 = HEAP32[$109>>2]|0;
      $118 = $110;
     }
     $113 = HEAP32[$50>>2]|0;
     $$ = $102 ? $49 : $113;
     if ($108) {
      $116 = (($99) + 1|0);
      $121 = $116;
     } else {
      $114 = (($__k$0) + -4|0);
      $115 = HEAP32[$114>>2]|0;
      $121 = $115;
     }
     $117 = ($118>>>0)<($119>>>0);
     $120 = $117 ? $118 : $119;
     $122 = (_memcmp($$,$121,$120)|0);
     $123 = ($122|0)==(0);
     if ($123) {
      $124 = ($119>>>0)<($118>>>0);
      $$$i$i$i12 = $117&1;
      $$$$i$i$i13 = $124 ? -1 : $$$i$i$i12;
      $126 = $$$$i$i$i13;
     } else {
      $126 = $122;
     }
     $125 = ($126|0)<(0);
     if ($125) {
      $__j$1$phi = $__k$0;$__k$0 = $99;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa21 = $__k$0;
      break;
     }
    }
    __THREW__ = 0;
    (invoke_iii(2233,($__k$0$lcssa21|0),($__t|0))|0);
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     label = 64;
     break;
    }
    $129 = (($__count$018) + 1)|0;
    $130 = ($129|0)==(8);
    if ($130) {
     $131 = (($__i$019) + 12|0);
     $132 = ($131|0)==($__last|0);
     $$0 = 1;$$1 = $132;$__i$1 = $131;
    } else {
     $$0 = 0;$$1 = $$0120;$__i$1 = $__i$019;
    }
    $141 = HEAP8[$__t>>0]|0;
    $142 = $141 & 1;
    $143 = ($142<<24>>24)==(0);
    if (!($143)) {
     $144 = HEAP32[$50>>2]|0;
     __ZdlPv($144);
    }
    if ($$0) {
     $$3 = $$1;
     label = 71;
     break;
    } else {
     $$2 = $$1;$__count$1 = $129;$__i$2 = $__i$1;
    }
   } else {
    $$2 = $$0120;$__count$1 = $__count$018;$__i$2 = $__i$019;
   }
   $145 = (($__i$2) + 12|0);
   $146 = ($145|0)==($__last|0);
   if ($146) {
    $$3 = 1;
    label = 71;
    break;
   } else {
    $$0120 = $$2;$__count$018 = $__count$1;$__i$019 = $145;$__j$017 = $__i$2;
   }
  }
  if ((label|0) == 41) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  else if ((label|0) == 63) {
   $133 = ___cxa_find_matching_catch()|0;
   $134 = tempRet0;
   $lpad$phi$index = $133;$lpad$phi$index2 = $134;
  }
  else if ((label|0) == 64) {
   $135 = ___cxa_find_matching_catch()|0;
   $136 = tempRet0;
   $lpad$phi$index = $135;$lpad$phi$index2 = $136;
  }
  else if ((label|0) == 71) {
   STACKTOP = sp;return ($$3|0);
  }
  $137 = HEAP8[$__t>>0]|0;
  $138 = $137 & 1;
  $139 = ($138<<24>>24)==(0);
  if ($139) {
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  $140 = HEAP32[$50>>2]|0;
  __ZdlPv($140);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIPKciEENS_19__map_value_compareIS3_S4_15smaller_cstringLb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $15 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $15;
   $$0$i = $15;$32 = $15;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (_strcmp($3,$5)|0);
    $7 = ($6|0)<(0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = (_strcmp($5,$3)|0);
    $11 = ($10|0)<(0);
    if (!($11)) {
     label = 9;
     break;
    }
    $12 = (($__nd$0$in$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $13;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$32 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $12;$32 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$32 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $16 = HEAP32[$$0$i>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $42 = 0;$__r$0 = $16;
  HEAP32[$agg$result>>2] = $__r$0;
  $41 = (($agg$result) + 4|0);
  HEAP8[$41>>0] = $42;
  STACKTOP = sp;return;
 }
 $18 = (__Znwj(24)|0);
 $19 = (($18) + 16|0);
 $20 = $__v;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 4)|0;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = $19;
 $27 = $26;
 HEAP32[$27>>2] = $22;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 HEAP32[$18>>2] = 0;
 $30 = (($18) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = (($18) + 8|0);
 HEAP32[$31>>2] = $32;
 HEAP32[$$0$i>>2] = $18;
 $33 = HEAP32[$this>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $37 = $18;
 } else {
  HEAP32[$this>>2] = $34;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $37 = $$pre$i;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($36,$37);
 $38 = (($this) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$38>>2] = $40;
 $42 = 1;$__r$0 = $18;
 HEAP32[$agg$result>>2] = $__r$0;
 $41 = (($agg$result) + 4|0);
 HEAP8[$41>>0] = $42;
 STACKTOP = sp;return;
}
function __ZN18UnityPropertySheet11UnityTexEnvC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 16|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 $2 = $this;
 $3 = $2;
 HEAP32[$3>>2] = 1065353216;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 1065353216;
 $6 = $0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18UnityPropertySheet25AssignDefinedPropertiesToERN9ShaderLab13PropertySheetE($this,$target) {
 $this = $this|0;
 $target = $target|0;
 var $$0$i = 0, $$0$i$i$i = Math_fround(0), $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i18 = 0, $$0$i$i$i$i$i18$us = 0, $$0$i$i$i$i$i4 = 0, $$0$i$i$i$i22 = 0, $$0$i$i$i$i22$us = 0, $$0$i$i$i$i8 = 0, $$0$i1$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i16 = 0, $$0$ph5$i$i$i30 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i10 = 0, $$0$ph7$i$i$i24 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i20 = 0;
 var $$01$i$i$i$i20$us = 0, $$01$i$i$i$i6 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i11 = 0, $$01$ph6$i$in$i$i25 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i13 = 0, $$013$i$in$i$i27 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0);
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0;
 var $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $temp$0$i = 0, $tmpcast$byval_copy = 0;
 var $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast1$byval_copy = sp + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $0 = sp + 32|0;
 $1 = sp + 16|0;
 $2 = sp;
 $3 = sp + 8|0;
 $4 = (($target) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($target) + 12|0);
 $7 = ($5|0)==($6|0);
 L1: do {
  if (!($7)) {
   $8 = (($this) + 16|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 16|0);
   $11 = ($9|0)==(0|0);
   if ($11) {
    $13 = $5;
    while(1) {
     $12 = (($13) + 4|0);
     $14 = HEAP32[$12>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      $$01$i$i$i$i20$us = $13;
      while(1) {
       $18 = (($$01$i$i$i$i20$us) + 8|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = HEAP32[$19>>2]|0;
       $21 = ($20|0)==($$01$i$i$i$i20$us|0);
       if ($21) {
        $$0$i$i$i$i22$us = $19;
        break;
       } else {
        $$01$i$i$i$i20$us = $19;
       }
      }
     } else {
      $$0$i$i$i$i$i18$us = $14;
      while(1) {
       $16 = HEAP32[$$0$i$i$i$i$i18$us>>2]|0;
       $17 = ($16|0)==(0|0);
       if ($17) {
        $$0$i$i$i$i22$us = $$0$i$i$i$i$i18$us;
        break;
       } else {
        $$0$i$i$i$i$i18$us = $16;
       }
      }
     }
     $22 = ($$0$i$i$i$i22$us|0)==($6|0);
     if ($22) {
      break L1;
     } else {
      $13 = $$0$i$i$i$i22$us;
     }
    }
   } else {
    $24 = $5;
   }
   while(1) {
    $23 = (($24) + 16|0);
    $25 = HEAP32[$23>>2]|0;
    $$0$ph7$i$i$i24 = $10;$$01$ph6$i$in$i$i25 = $9;
    L15: while(1) {
     $$013$i$in$i$i27 = $$01$ph6$i$in$i$i25;
     while(1) {
      $26 = (($$013$i$in$i$i27) + 16|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)<($25|0);
      if (!($28)) {
       break;
      }
      $31 = (($$013$i$in$i$i27) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($32|0)==(0|0);
      if ($33) {
       $$0$ph5$i$i$i30 = $$0$ph7$i$i$i24;
       break L15;
      } else {
       $$013$i$in$i$i27 = $32;
      }
     }
     $29 = HEAP32[$$013$i$in$i$i27>>2]|0;
     $30 = ($29|0)==(0|0);
     if ($30) {
      $$0$ph5$i$i$i30 = $$013$i$in$i$i27;
      break;
     } else {
      $$0$ph7$i$i$i24 = $$013$i$in$i$i27;$$01$ph6$i$in$i$i25 = $29;
     }
    }
    $34 = ($$0$ph5$i$i$i30|0)==($10|0);
    if (!($34)) {
     $35 = (($$0$ph5$i$i$i30) + 16|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($25|0)<($36|0);
     if (!($37)) {
      $38 = (($$0$ph5$i$i$i30) + 20|0);
      $39 = Math_fround(HEAPF32[$38>>2]);
      $40 = (($24) + 20|0);
      HEAPF32[$40>>2] = $39;
     }
    }
    $41 = (($24) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    if ($43) {
     $$01$i$i$i$i20 = $24;
     while(1) {
      $46 = (($$01$i$i$i$i20) + 8|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)==($$01$i$i$i$i20|0);
      if ($49) {
       $$0$i$i$i$i22 = $47;
       break;
      } else {
       $$01$i$i$i$i20 = $47;
      }
     }
    } else {
     $$0$i$i$i$i$i18 = $42;
     while(1) {
      $44 = HEAP32[$$0$i$i$i$i$i18>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $$0$i$i$i$i22 = $$0$i$i$i$i$i18;
       break;
      } else {
       $$0$i$i$i$i$i18 = $44;
      }
     }
    }
    $50 = ($$0$i$i$i$i22|0)==($6|0);
    if ($50) {
     break;
    } else {
     $24 = $$0$i$i$i$i22;
    }
   }
  }
 } while(0);
 $51 = (($target) + 20|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($target) + 24|0);
 $54 = ($52|0)==($53|0);
 L34: do {
  if (!($54)) {
   $55 = (($this) + 28|0);
   $56 = (($this) + 28|0);
   $57 = (($1) + 4|0);
   $58 = (($1) + 8|0);
   $59 = (($1) + 12|0);
   $61 = $52;
   while(1) {
    $60 = (($61) + 16|0);
    $62 = HEAP32[$55>>2]|0;
    $63 = ($62|0)==(0|0);
    do {
     if (!($63)) {
      $64 = HEAP32[$60>>2]|0;
      $$0$ph7$i$i$i10 = $56;$$01$ph6$i$in$i$i11 = $62;
      L40: while(1) {
       $$013$i$in$i$i13 = $$01$ph6$i$in$i$i11;
       while(1) {
        $65 = (($$013$i$in$i$i13) + 16|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = ($66|0)<($64|0);
        if (!($67)) {
         break;
        }
        $70 = (($$013$i$in$i$i13) + 4|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = ($71|0)==(0|0);
        if ($72) {
         $$0$ph5$i$i$i16 = $$0$ph7$i$i$i10;
         break L40;
        } else {
         $$013$i$in$i$i13 = $71;
        }
       }
       $68 = HEAP32[$$013$i$in$i$i13>>2]|0;
       $69 = ($68|0)==(0|0);
       if ($69) {
        $$0$ph5$i$i$i16 = $$013$i$in$i$i13;
        break;
       } else {
        $$0$ph7$i$i$i10 = $$013$i$in$i$i13;$$01$ph6$i$in$i$i11 = $68;
       }
      }
      $73 = ($$0$ph5$i$i$i16|0)==($56|0);
      if (!($73)) {
       $74 = (($$0$ph5$i$i$i16) + 16|0);
       $75 = HEAP32[$74>>2]|0;
       $76 = ($64|0)<($75|0);
       if (!($76)) {
        $77 = (__ZNK9ShaderLab13PropertySheet11GetColorTagERKNS_16FastPropertyNameE($target,$60)|0);
        $78 = (($$0$ph5$i$i$i16) + 20|0);
        if (!($77)) {
         __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($target,$60,$78);
         break;
        }
        $79 = (__Z19GetActiveColorSpacev()|0);
        $80 = ($79|0)==(1);
        if ($80) {
         $81 = Math_fround(HEAPF32[$78>>2]);
         $82 = !($81 <= Math_fround(0.0404499992728233337402));
         do {
          if ($82) {
           $84 = $81 < Math_fround(1.0);
           if ($84) {
            $85 = Math_fround($81 + Math_fround(0.054999999701976776123));
            $86 = Math_fround($85 / Math_fround(1.05499994754791259766));
            $87 = (Math_fround(+(Math_pow((+$86),2.40000009536743164063))));
            $$0$i$i$i = $87;
            break;
           } else {
            $88 = (Math_fround(+(Math_pow((+$81),2.40000009536743164063))));
            $$0$i$i$i = $88;
            break;
           }
          } else {
           $83 = Math_fround($81 / Math_fround(12.9200000762939453125));
           $$0$i$i$i = $83;
          }
         } while(0);
         $89 = (($$0$ph5$i$i$i16) + 24|0);
         $90 = Math_fround(HEAPF32[$89>>2]);
         $91 = !($90 <= Math_fround(0.0404499992728233337402));
         do {
          if ($91) {
           $93 = $90 < Math_fround(1.0);
           if ($93) {
            $94 = Math_fround($90 + Math_fround(0.054999999701976776123));
            $95 = Math_fround($94 / Math_fround(1.05499994754791259766));
            $96 = (Math_fround(+(Math_pow((+$95),2.40000009536743164063))));
            $$0$i3$i$i = $96;
            break;
           } else {
            $97 = (Math_fround(+(Math_pow((+$90),2.40000009536743164063))));
            $$0$i3$i$i = $97;
            break;
           }
          } else {
           $92 = Math_fround($90 / Math_fround(12.9200000762939453125));
           $$0$i3$i$i = $92;
          }
         } while(0);
         $98 = (($$0$ph5$i$i$i16) + 28|0);
         $99 = Math_fround(HEAPF32[$98>>2]);
         $100 = !($99 <= Math_fround(0.0404499992728233337402));
         do {
          if ($100) {
           $102 = $99 < Math_fround(1.0);
           if ($102) {
            $103 = Math_fround($99 + Math_fround(0.054999999701976776123));
            $104 = Math_fround($103 / Math_fround(1.05499994754791259766));
            $105 = (Math_fround(+(Math_pow((+$104),2.40000009536743164063))));
            $$0$i1$i$i = $105;
            break;
           } else {
            $106 = (Math_fround(+(Math_pow((+$99),2.40000009536743164063))));
            $$0$i1$i$i = $106;
            break;
           }
          } else {
           $101 = Math_fround($99 / Math_fround(12.9200000762939453125));
           $$0$i1$i$i = $101;
          }
         } while(0);
         $107 = (($$0$ph5$i$i$i16) + 32|0);
         $108 = Math_fround(HEAPF32[$107>>2]);
         HEAPF32[$1>>2] = $$0$i$i$i;
         HEAPF32[$57>>2] = $$0$i3$i$i;
         HEAPF32[$58>>2] = $$0$i1$i$i;
         HEAPF32[$59>>2] = $108;
        } else {
         ;HEAP32[$1+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$78+12>>2]|0;
        }
        __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($target,$60,$1);
       }
      }
     }
    } while(0);
    $109 = (($61) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ($110|0)==(0|0);
    if ($111) {
     $$01$i$i$i$i6 = $61;
     while(1) {
      $114 = (($$01$i$i$i$i6) + 8|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = HEAP32[$115>>2]|0;
      $117 = ($116|0)==($$01$i$i$i$i6|0);
      if ($117) {
       $$0$i$i$i$i8 = $115;
       break;
      } else {
       $$01$i$i$i$i6 = $115;
      }
     }
    } else {
     $$0$i$i$i$i$i4 = $110;
     while(1) {
      $112 = HEAP32[$$0$i$i$i$i$i4>>2]|0;
      $113 = ($112|0)==(0|0);
      if ($113) {
       $$0$i$i$i$i8 = $$0$i$i$i$i$i4;
       break;
      } else {
       $$0$i$i$i$i$i4 = $112;
      }
     }
    }
    $118 = ($$0$i$i$i$i8|0)==($53|0);
    if ($118) {
     break L34;
    }
    $61 = $$0$i$i$i$i8;
   }
  }
 } while(0);
 $119 = (($target) + 44|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = (($target) + 48|0);
 $122 = ($120|0)==($121|0);
 if ($122) {
  STACKTOP = sp;return;
 }
 $123 = (($this) + 4|0);
 $124 = (($this) + 4|0);
 $126 = $120;
 while(1) {
  $125 = (($126) + 16|0);
  $127 = HEAP32[$123>>2]|0;
  $128 = ($127|0)==(0|0);
  if (!($128)) {
   $129 = HEAP32[$125>>2]|0;
   $$0$ph7$i$i$i = $124;$$01$ph6$i$in$i$i = $127;
   L94: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $130 = (($$013$i$in$i$i) + 16|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($131|0)<($129|0);
     if (!($132)) {
      break;
     }
     $135 = (($$013$i$in$i$i) + 4|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = ($136|0)==(0|0);
     if ($137) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L94;
     } else {
      $$013$i$in$i$i = $136;
     }
    }
    $133 = HEAP32[$$013$i$in$i$i>>2]|0;
    $134 = ($133|0)==(0|0);
    if ($134) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $133;
    }
   }
   $138 = ($$0$ph5$i$i$i|0)==($124|0);
   if (!($138)) {
    $139 = (($$0$ph5$i$i$i) + 16|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = ($129|0)<($140|0);
    if (!($141)) {
     $142 = (($$0$ph5$i$i$i) + 36|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = ($143|0)==(0);
     if ($144) {
      $$0$i = 0;
     } else {
      HEAP32[$0>>2] = $143;
      $145 = HEAP32[560624>>2]|0;
      $146 = ($145|0)==(0|0);
      if ($146) {
       label = 77;
      } else {
       $147 = (($145) + 36|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = (($145) + 4|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = ($148|0)==($150|0);
       do {
        if ($151) {
         $152 = (($145) + 28|0);
         $153 = HEAP32[$152>>2]|0;
         $154 = (($145) + 32|0);
         $155 = HEAP32[$154>>2]|0;
         $156 = (($153) + ($155<<3)|0);
         $172 = $156;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast1$byval_copy,$145,$0);
         $157 = HEAP32[$tmpcast1$byval_copy>>2]|0;
         $158 = ($157|0)==(-1);
         $159 = (($145) + 28|0);
         $160 = HEAP32[$159>>2]|0;
         if ($158) {
          $161 = (($145) + 32|0);
          $162 = HEAP32[$161>>2]|0;
          $163 = (($160) + ($162<<3)|0);
          $172 = $163;
          break;
         } else {
          $164 = (($160) + ($157<<3)|0);
          $172 = $164;
          break;
         }
        }
       } while(0);
       $165 = HEAP32[560624>>2]|0;
       $166 = (($165) + 28|0);
       $167 = HEAP32[$166>>2]|0;
       $168 = (($165) + 32|0);
       $169 = HEAP32[$168>>2]|0;
       $170 = (($167) + ($169<<3)|0);
       $171 = ($172|0)==($170|0);
       if ($171) {
        label = 77;
       } else {
        $173 = (($172) + 4|0);
        $174 = HEAP32[$173>>2]|0;
        $175 = ($174|0)==(0|0);
        if ($175) {
         label = 77;
        } else {
         $temp$0$i = $174;
        }
       }
      }
      if ((label|0) == 77) {
       label = 0;
       $176 = HEAP32[$142>>2]|0;
       $177 = (__Z31ReadObjectFromPersistentManageri($176)|0);
       $temp$0$i = $177;
      }
      $$0$i = $temp$0$i;
     }
     $178 = (($$0$ph5$i$i$i) + 20|0);
     $179 = $178;
     $180 = $179;
     $181 = HEAP32[$180>>2]|0;
     $182 = (($179) + 4)|0;
     $183 = $182;
     $184 = HEAP32[$183>>2]|0;
     $185 = $2;
     $186 = $185;
     HEAP32[$186>>2] = $181;
     $187 = (($185) + 4)|0;
     $188 = $187;
     HEAP32[$188>>2] = $184;
     $189 = (($$0$ph5$i$i$i) + 28|0);
     $190 = $189;
     $191 = $190;
     $192 = HEAP32[$191>>2]|0;
     $193 = (($190) + 4)|0;
     $194 = $193;
     $195 = HEAP32[$194>>2]|0;
     $196 = $3;
     $197 = $196;
     HEAP32[$197>>2] = $192;
     $198 = (($196) + 4)|0;
     $199 = $198;
     HEAP32[$199>>2] = $195;
     ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
     ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
     __ZN9ShaderLab13PropertySheet23SetTextureWithPlacementERKNS_16FastPropertyNameEP7Texture8Vector2fS6_($target,$125,$$0$i,$tmpcast$byval_copy,$tmpcast1$byval_copy);
    }
   }
  }
  $200 = (($126) + 4|0);
  $201 = HEAP32[$200>>2]|0;
  $202 = ($201|0)==(0|0);
  if ($202) {
   $$01$i$i$i$i = $126;
   while(1) {
    $205 = (($$01$i$i$i$i) + 8|0);
    $206 = HEAP32[$205>>2]|0;
    $207 = HEAP32[$206>>2]|0;
    $208 = ($207|0)==($$01$i$i$i$i|0);
    if ($208) {
     $$0$i$i$i$i = $206;
     break;
    } else {
     $$01$i$i$i$i = $206;
    }
   }
  } else {
   $$0$i$i$i$i$i = $201;
   while(1) {
    $203 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $204 = ($203|0)==(0|0);
    if ($204) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $203;
    }
   }
  }
  $209 = ($$0$i$i$i$i|0)==($121|0);
  if ($209) {
   break;
  }
  $126 = $$0$i$i$i$i;
 }
 STACKTOP = sp;return;
}
function __ZN18UnityPropertySheet20AddNewShaderlabPropsERKN9ShaderLab13PropertySheetE($this,$source) {
 $this = $this|0;
 $source = $source|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i11 = 0, $$0$i$i$i$i$i21 = 0, $$0$i$i$i$i15 = 0, $$0$i$i$i$i19 = 0, $$0$i$i$i$i25 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i13 = 0, $$01$i$i$i$i23 = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$lcssa74 = 0, $$pre = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0;
 var $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $addedAny$0$off0$ = 0, $addedAny$0$off0$lcssa = 0, $addedAny$0$off081 = 0, $addedAny$2$off0$ = 0, $addedAny$2$off0$lcssa = 0, $addedAny$2$off075 = 0, $addedAny$3$off0 = 0, $addedAny$4$off0$lcssa = 0, $addedAny$4$off067 = 0, $addedAny$5$off0 = 0, $not$ = 0, $not$61 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = (($source) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($source) + 12|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  $addedAny$0$off0$lcssa = 0;
 } else {
  $6 = (($this) + 12|0);
  $7 = (($0) + 4|0);
  $9 = $3;$addedAny$0$off081 = 0;
  while(1) {
   $8 = (($9) + 16|0);
   $10 = HEAP32[$8>>2]|0;
   $11 = (($9) + 20|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = (HEAPF32[tempDoublePtr>>2]=$12,HEAP32[tempDoublePtr>>2]|0);
   $14 = $1;
   $15 = $14;
   HEAP32[$15>>2] = $10;
   $16 = (($14) + 4)|0;
   $17 = $16;
   HEAP32[$17>>2] = $13;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($0,$6,$1);
   $18 = HEAP8[$7>>0]|0;
   $not$61 = ($18<<24>>24)!=(0);
   $addedAny$0$off0$ = $addedAny$0$off081 | $not$61;
   $19 = (($9) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$01$i$i$i$i23 = $9;
    while(1) {
     $24 = (($$01$i$i$i$i23) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==($$01$i$i$i$i23|0);
     if ($27) {
      $$0$i$i$i$i25 = $25;
      break;
     } else {
      $$01$i$i$i$i23 = $25;
     }
    }
   } else {
    $$0$i$i$i$i$i21 = $20;
    while(1) {
     $22 = HEAP32[$$0$i$i$i$i$i21>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      $$0$i$i$i$i25 = $$0$i$i$i$i$i21;
      break;
     } else {
      $$0$i$i$i$i$i21 = $22;
     }
    }
   }
   $28 = ($$0$i$i$i$i25|0)==($4|0);
   if ($28) {
    $addedAny$0$off0$lcssa = $addedAny$0$off0$;
    break;
   } else {
    $9 = $$0$i$i$i$i25;$addedAny$0$off081 = $addedAny$0$off0$;
   }
  }
 }
 $29 = (($source) + 20|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($source) + 24|0);
 $32 = ($30|0)==($31|0);
 $33 = (($source) + 44|0);
 $34 = HEAP32[$33>>2]|0;
 $$pre = (($source) + 48|0);
 if ($32) {
  $$lcssa74 = $34;$addedAny$2$off0$lcssa = $addedAny$0$off0$lcssa;
 } else {
  $35 = (($this) + 24|0);
  $36 = (($1) + 4|0);
  $37 = (($1) + 8|0);
  $38 = (($1) + 12|0);
  $39 = (($1) + 16|0);
  $40 = (($0) + 4|0);
  $42 = $34;$44 = $30;$addedAny$2$off075 = $addedAny$0$off0$lcssa;
  while(1) {
   $41 = ($42|0)==($$pre|0);
   L17: do {
    if ($41) {
     label = 22;
    } else {
     $43 = (($44) + 20|0);
     $49 = $42;
     while(1) {
      $48 = (($49) + 24|0);
      $50 = HEAP32[$48>>2]|0;
      $51 = ($50|0)==($43|0);
      if ($51) {
       $addedAny$3$off0 = $addedAny$2$off075;
       break L17;
      }
      $52 = (($49) + 28|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==($43|0);
      if ($54) {
       $addedAny$3$off0 = $addedAny$2$off075;
       break L17;
      }
      $55 = (($49) + 32|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($56|0)==($43|0);
      if ($57) {
       $addedAny$3$off0 = $addedAny$2$off075;
       break L17;
      }
      $58 = (($49) + 4|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($59|0)==(0|0);
      if ($60) {
       $$01$i$i$i = $49;
       while(1) {
        $63 = (($$01$i$i$i) + 8|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = HEAP32[$64>>2]|0;
        $66 = ($65|0)==($$01$i$i$i|0);
        if ($66) {
         $$0$i$i$i = $64;
         break;
        } else {
         $$01$i$i$i = $64;
        }
       }
      } else {
       $$0$i$i$i$i19 = $59;
       while(1) {
        $61 = HEAP32[$$0$i$i$i$i19>>2]|0;
        $62 = ($61|0)==(0|0);
        if ($62) {
         $$0$i$i$i = $$0$i$i$i$i19;
         break;
        } else {
         $$0$i$i$i$i19 = $61;
        }
       }
      }
      $67 = ($$0$i$i$i|0)==($$pre|0);
      if ($67) {
       label = 22;
       break;
      } else {
       $49 = $$0$i$i$i;
      }
     }
    }
   } while(0);
   if ((label|0) == 22) {
    label = 0;
    $68 = (($44) + 16|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($44) + 20|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = (($44) + 24|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = (($44) + 28|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = (($44) + 32|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    HEAP32[$1>>2] = $69;
    HEAPF32[$36>>2] = $71;
    HEAPF32[$37>>2] = $73;
    HEAPF32[$38>>2] = $75;
    HEAPF32[$39>>2] = $77;
    __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10ColorRGBAfEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($0,$35,$1);
    $78 = HEAP8[$40>>0]|0;
    $not$ = ($78<<24>>24)!=(0);
    $addedAny$2$off0$ = $addedAny$2$off075 | $not$;
    $addedAny$3$off0 = $addedAny$2$off0$;
   }
   $79 = (($44) + 4|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    $$01$i$i$i$i13 = $44;
    while(1) {
     $84 = (($$01$i$i$i$i13) + 8|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86|0)==($$01$i$i$i$i13|0);
     if ($87) {
      $$0$i$i$i$i15 = $85;
      break;
     } else {
      $$01$i$i$i$i13 = $85;
     }
    }
   } else {
    $$0$i$i$i$i$i11 = $80;
    while(1) {
     $82 = HEAP32[$$0$i$i$i$i$i11>>2]|0;
     $83 = ($82|0)==(0|0);
     if ($83) {
      $$0$i$i$i$i15 = $$0$i$i$i$i$i11;
      break;
     } else {
      $$0$i$i$i$i$i11 = $82;
     }
    }
   }
   $88 = ($$0$i$i$i$i15|0)==($31|0);
   $89 = HEAP32[$33>>2]|0;
   if ($88) {
    $$lcssa74 = $89;$addedAny$2$off0$lcssa = $addedAny$3$off0;
    break;
   } else {
    $42 = $89;$44 = $$0$i$i$i$i15;$addedAny$2$off075 = $addedAny$3$off0;
   }
  }
 }
 $45 = ($$lcssa74|0)==($$pre|0);
 if ($45) {
  $addedAny$4$off0$lcssa = $addedAny$2$off0$lcssa;
  STACKTOP = sp;return ($addedAny$4$off0$lcssa|0);
 }
 $46 = (($this) + 4|0);
 $47 = (($this) + 4|0);
 $91 = $$lcssa74;$addedAny$4$off067 = $addedAny$2$off0$lcssa;
 while(1) {
  $90 = (($91) + 16|0);
  $92 = HEAP32[$46>>2]|0;
  $93 = ($92|0)==(0|0);
  if ($93) {
   label = 36;
  } else {
   $94 = HEAP32[$90>>2]|0;
   $$0$ph7$i$i$i = $47;$$01$ph6$i$in$i$i = $92;
   L49: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $95 = (($$013$i$in$i$i) + 16|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = ($96|0)<($94|0);
     if (!($97)) {
      break;
     }
     $100 = (($$013$i$in$i$i) + 4|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101|0)==(0|0);
     if ($102) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L49;
     } else {
      $$013$i$in$i$i = $101;
     }
    }
    $98 = HEAP32[$$013$i$in$i$i>>2]|0;
    $99 = ($98|0)==(0|0);
    if ($99) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $98;
    }
   }
   $103 = ($$0$ph5$i$i$i|0)==($47|0);
   if ($103) {
    label = 36;
   } else {
    $104 = (($$0$ph5$i$i$i) + 16|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($94|0)<($105|0);
    if ($106) {
     label = 36;
    } else {
     $addedAny$5$off0 = $addedAny$4$off067;
    }
   }
  }
  if ((label|0) == 36) {
   label = 0;
   $107 = (($91) + 20|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($108) + 44|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = (($108) + 48|0);
   $112 = Math_fround(HEAPF32[$111>>2]);
   $113 = (HEAPF32[tempDoublePtr>>2]=$110,HEAP32[tempDoublePtr>>2]|0);
   $114 = (HEAPF32[tempDoublePtr>>2]=$112,HEAP32[tempDoublePtr>>2]|0);
   $115 = (($108) + 52|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   $117 = (($108) + 56|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = (HEAPF32[tempDoublePtr>>2]=$116,HEAP32[tempDoublePtr>>2]|0);
   $120 = (HEAPF32[tempDoublePtr>>2]=$118,HEAP32[tempDoublePtr>>2]|0);
   $121 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_($this,$90)|0);
   $122 = $121;
   $123 = $122;
   HEAP32[$123>>2] = $113;
   $124 = (($122) + 4)|0;
   $125 = $124;
   HEAP32[$125>>2] = $114;
   $126 = (($121) + 8|0);
   $127 = $126;
   $128 = $127;
   HEAP32[$128>>2] = $119;
   $129 = (($127) + 4)|0;
   $130 = $129;
   HEAP32[$130>>2] = $120;
   $131 = (($121) + 16|0);
   HEAP32[$131>>2] = 0;
   $addedAny$5$off0 = 1;
  }
  $132 = (($91) + 4|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(0|0);
  if ($134) {
   $$01$i$i$i$i = $91;
   while(1) {
    $137 = (($$01$i$i$i$i) + 8|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = HEAP32[$138>>2]|0;
    $140 = ($139|0)==($$01$i$i$i$i|0);
    if ($140) {
     $$0$i$i$i$i = $138;
     break;
    } else {
     $$01$i$i$i$i = $138;
    }
   }
  } else {
   $$0$i$i$i$i$i = $133;
   while(1) {
    $135 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $136 = ($135|0)==(0|0);
    if ($136) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $135;
    }
   }
  }
  $141 = ($$0$i$i$i$i|0)==($$pre|0);
  if ($141) {
   $addedAny$4$off0$lcssa = $addedAny$5$off0;
   break;
  }
  $91 = $$0$i$i$i$i;$addedAny$4$off067 = $addedAny$5$off0;
 }
 STACKTOP = sp;return ($addedAny$4$off0$lcssa|0);
}
function __ZNSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$32 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$32 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$32 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$32 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $41 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($41|0);
 }
 $16 = (__Znwj(40)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 $20 = (($16) + 28|0);
 $21 = (($16) + 36|0);
 $22 = $19;
 $23 = $22;
 HEAP32[$23>>2] = 1065353216;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 1065353216;
 $26 = $20;
 $27 = $26;
 HEAP32[$27>>2] = 0;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = 0;
 HEAP32[$21>>2] = 0;
 HEAP32[$16>>2] = 0;
 $30 = (($16) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = (($16) + 8|0);
 HEAP32[$31>>2] = $32;
 HEAP32[$$0$i>>2] = $16;
 $33 = HEAP32[$this>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $37 = $16;
 } else {
  HEAP32[$this>>2] = $34;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $37 = $$pre$i;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($36,$37);
 $38 = (($this) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$38>>2] = $40;
 $__r$0 = $16;
 $41 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($41|0);
}
function __ZN18UnityPropertySheet21AddNewSerializedPropsERKS_($this,$source) {
 $this = $this|0;
 $source = $source|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i16 = 0, $$0$i$i$i$i$i2 = 0, $$0$i$i$i$i20 = 0, $$0$i$i$i$i6 = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i14 = 0, $$0$ph5$i$i$i28 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i22 = 0, $$0$ph7$i$i$i8 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i18 = 0, $$01$i$i$i$i4 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i23 = 0, $$01$ph6$i$in$i$i9 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i11 = 0;
 var $$013$i$in$i$i25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($source) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($source) + 16|0);
 $3 = ($1|0)==($2|0);
 L1: do {
  if (!($3)) {
   $4 = (($this) + 12|0);
   $5 = (($this) + 16|0);
   $6 = (($this) + 16|0);
   $8 = $1;
   while(1) {
    $7 = (($8) + 16|0);
    $9 = HEAP32[$5>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     label = 11;
    } else {
     $11 = HEAP32[$7>>2]|0;
     $$0$ph7$i$i$i22 = $6;$$01$ph6$i$in$i$i23 = $9;
     L7: while(1) {
      $$013$i$in$i$i25 = $$01$ph6$i$in$i$i23;
      while(1) {
       $12 = (($$013$i$in$i$i25) + 16|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = ($13|0)<($11|0);
       if (!($14)) {
        break;
       }
       $17 = (($$013$i$in$i$i25) + 4|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = ($18|0)==(0|0);
       if ($19) {
        $$0$ph5$i$i$i28 = $$0$ph7$i$i$i22;
        break L7;
       } else {
        $$013$i$in$i$i25 = $18;
       }
      }
      $15 = HEAP32[$$013$i$in$i$i25>>2]|0;
      $16 = ($15|0)==(0|0);
      if ($16) {
       $$0$ph5$i$i$i28 = $$013$i$in$i$i25;
       break;
      } else {
       $$0$ph7$i$i$i22 = $$013$i$in$i$i25;$$01$ph6$i$in$i$i23 = $15;
      }
     }
     $20 = ($$0$ph5$i$i$i28|0)==($6|0);
     if ($20) {
      label = 11;
     } else {
      $21 = (($$0$ph5$i$i$i28) + 16|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($11|0)<($22|0);
      if ($23) {
       label = 11;
      }
     }
    }
    if ((label|0) == 11) {
     label = 0;
     $24 = (($8) + 20|0);
     $25 = Math_fround(HEAPF32[$24>>2]);
     $26 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameEfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_fEEEEEixERS7_($4,$7)|0);
     HEAPF32[$26>>2] = $25;
    }
    $27 = (($8) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     $$01$i$i$i$i18 = $8;
     while(1) {
      $32 = (($$01$i$i$i$i18) + 8|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==($$01$i$i$i$i18|0);
      if ($35) {
       $$0$i$i$i$i20 = $33;
       break;
      } else {
       $$01$i$i$i$i18 = $33;
      }
     }
    } else {
     $$0$i$i$i$i$i16 = $28;
     while(1) {
      $30 = HEAP32[$$0$i$i$i$i$i16>>2]|0;
      $31 = ($30|0)==(0|0);
      if ($31) {
       $$0$i$i$i$i20 = $$0$i$i$i$i$i16;
       break;
      } else {
       $$0$i$i$i$i$i16 = $30;
      }
     }
    }
    $36 = ($$0$i$i$i$i20|0)==($2|0);
    if ($36) {
     break L1;
    }
    $8 = $$0$i$i$i$i20;
   }
  }
 } while(0);
 $37 = (($source) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($source) + 28|0);
 $40 = ($38|0)==($39|0);
 L27: do {
  if (!($40)) {
   $41 = (($this) + 24|0);
   $42 = (($this) + 28|0);
   $43 = (($this) + 28|0);
   $45 = $38;
   while(1) {
    $44 = (($45) + 16|0);
    $46 = HEAP32[$42>>2]|0;
    $47 = ($46|0)==(0|0);
    if ($47) {
     label = 28;
    } else {
     $48 = HEAP32[$44>>2]|0;
     $$0$ph7$i$i$i8 = $43;$$01$ph6$i$in$i$i9 = $46;
     L33: while(1) {
      $$013$i$in$i$i11 = $$01$ph6$i$in$i$i9;
      while(1) {
       $49 = (($$013$i$in$i$i11) + 16|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)<($48|0);
       if (!($51)) {
        break;
       }
       $54 = (($$013$i$in$i$i11) + 4|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = ($55|0)==(0|0);
       if ($56) {
        $$0$ph5$i$i$i14 = $$0$ph7$i$i$i8;
        break L33;
       } else {
        $$013$i$in$i$i11 = $55;
       }
      }
      $52 = HEAP32[$$013$i$in$i$i11>>2]|0;
      $53 = ($52|0)==(0|0);
      if ($53) {
       $$0$ph5$i$i$i14 = $$013$i$in$i$i11;
       break;
      } else {
       $$0$ph7$i$i$i8 = $$013$i$in$i$i11;$$01$ph6$i$in$i$i9 = $52;
      }
     }
     $57 = ($$0$ph5$i$i$i14|0)==($43|0);
     if ($57) {
      label = 28;
     } else {
      $58 = (($$0$ph5$i$i$i14) + 16|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($48|0)<($59|0);
      if ($60) {
       label = 28;
      }
     }
    }
    if ((label|0) == 28) {
     label = 0;
     $61 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameE10ColorRGBAfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_($41,$44)|0);
     $62 = (($45) + 20|0);
     $63 = Math_fround(HEAPF32[$62>>2]);
     $64 = (($45) + 24|0);
     $65 = Math_fround(HEAPF32[$64>>2]);
     $66 = (($45) + 28|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = (($45) + 32|0);
     $69 = Math_fround(HEAPF32[$68>>2]);
     HEAPF32[$61>>2] = $63;
     $70 = (($61) + 4|0);
     HEAPF32[$70>>2] = $65;
     $71 = (($61) + 8|0);
     HEAPF32[$71>>2] = $67;
     $72 = (($61) + 12|0);
     HEAPF32[$72>>2] = $69;
    }
    $73 = (($45) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)==(0|0);
    if ($75) {
     $$01$i$i$i$i4 = $45;
     while(1) {
      $78 = (($$01$i$i$i$i4) + 8|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = HEAP32[$79>>2]|0;
      $81 = ($80|0)==($$01$i$i$i$i4|0);
      if ($81) {
       $$0$i$i$i$i6 = $79;
       break;
      } else {
       $$01$i$i$i$i4 = $79;
      }
     }
    } else {
     $$0$i$i$i$i$i2 = $74;
     while(1) {
      $76 = HEAP32[$$0$i$i$i$i$i2>>2]|0;
      $77 = ($76|0)==(0|0);
      if ($77) {
       $$0$i$i$i$i6 = $$0$i$i$i$i$i2;
       break;
      } else {
       $$0$i$i$i$i$i2 = $76;
      }
     }
    }
    $82 = ($$0$i$i$i$i6|0)==($39|0);
    if ($82) {
     break L27;
    }
    $45 = $$0$i$i$i$i6;
   }
  }
 } while(0);
 $83 = HEAP32[$source>>2]|0;
 $84 = (($source) + 4|0);
 $85 = ($83|0)==($84|0);
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = (($this) + 4|0);
 $87 = (($this) + 4|0);
 $89 = $83;
 while(1) {
  $88 = (($89) + 16|0);
  $90 = HEAP32[$86>>2]|0;
  $91 = ($90|0)==(0|0);
  if ($91) {
   label = 45;
  } else {
   $92 = HEAP32[$88>>2]|0;
   $$0$ph7$i$i$i = $87;$$01$ph6$i$in$i$i = $90;
   L60: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $93 = (($$013$i$in$i$i) + 16|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ($94|0)<($92|0);
     if (!($95)) {
      break;
     }
     $98 = (($$013$i$in$i$i) + 4|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ($99|0)==(0|0);
     if ($100) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L60;
     } else {
      $$013$i$in$i$i = $99;
     }
    }
    $96 = HEAP32[$$013$i$in$i$i>>2]|0;
    $97 = ($96|0)==(0|0);
    if ($97) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $96;
    }
   }
   $101 = ($$0$ph5$i$i$i|0)==($87|0);
   if ($101) {
    label = 45;
   } else {
    $102 = (($$0$ph5$i$i$i) + 16|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = ($92|0)<($103|0);
    if ($104) {
     label = 45;
    }
   }
  }
  if ((label|0) == 45) {
   label = 0;
   $105 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_($this,$88)|0);
   $106 = (($89) + 20|0);
   ;HEAP32[$105+0>>2]=HEAP32[$106+0>>2]|0;HEAP32[$105+4>>2]=HEAP32[$106+4>>2]|0;HEAP32[$105+8>>2]=HEAP32[$106+8>>2]|0;HEAP32[$105+12>>2]=HEAP32[$106+12>>2]|0;
   $107 = (($89) + 36|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = (($105) + 16|0);
   HEAP32[$109>>2] = $108;
  }
  $110 = (($89) + 4|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(0|0);
  if ($112) {
   $$01$i$i$i$i = $89;
   while(1) {
    $115 = (($$01$i$i$i$i) + 8|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = HEAP32[$116>>2]|0;
    $118 = ($117|0)==($$01$i$i$i$i|0);
    if ($118) {
     $$0$i$i$i$i = $116;
     break;
    } else {
     $$01$i$i$i$i = $116;
    }
   }
  } else {
   $$0$i$i$i$i$i = $111;
   while(1) {
    $113 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $114 = ($113|0)==(0|0);
    if ($114) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $113;
    }
   }
  }
  $119 = ($$0$i$i$i$i|0)==($84|0);
  if ($119) {
   break;
  }
  $89 = $$0$i$i$i$i;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIN9ShaderLab16FastPropertyNameEfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_fEEEEEixERS7_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$22 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $31 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($31|0);
 }
 $16 = (__Znwj(24)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 HEAP32[$16>>2] = 0;
 $20 = (($16) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $16;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $16;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $__r$0 = $16;
 $31 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($31|0);
}
function __GLOBAL__I_a8687() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[647840>>0] = 8;
 HEAP8[((647840 + 1|0))>>0]=1886217556&255;HEAP8[((647840 + 1|0))+1>>0]=(1886217556>>8)&255;HEAP8[((647840 + 1|0))+2>>0]=(1886217556>>16)&255;HEAP8[((647840 + 1|0))+3>>0]=1886217556>>24;
 HEAP8[((647840 + 5|0))>>0] = 0;
 STACKTOP = sp;return;
}
function __Z11GetJobQueuev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[647856>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z14CreateJobQueuev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628232>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(1,$$byval_copy,0,16,647864,15)|0);
 HEAP32[647856>>2] = $2;
 STACKTOP = sp;return;
}
function __Z21ClearFenceWithoutSyncR8JobFence($fence) {
 $fence = $fence|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$fence>>2] = 0;
 STACKTOP = sp;return;
}
function __Z21CompleteFenceInternalR8JobFence($fence) {
 $fence = $fence|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$fence>>2] = 0;
 STACKTOP = sp;return;
}
function __Z11ScheduleJobR8JobFencePFvPvES1_11JobPriority($fence,$jobFunc,$userData,$priority) {
 $fence = $fence|0;
 $jobFunc = $jobFunc|0;
 $userData = $userData|0;
 $priority = $priority|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$fence>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  HEAP32[$fence>>2] = 0;
 }
 FUNCTION_TABLE_vi[$jobFunc & 4095]($userData);
 $2 = $fence;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __Z18ScheduleJobDependsR8JobFencePFvPvES1_S0_11JobPriority($fence,$jobFunc,$userData,$dependsOn,$priority) {
 $fence = $fence|0;
 $jobFunc = $jobFunc|0;
 $userData = $userData|0;
 $dependsOn = $dependsOn|0;
 $priority = $priority|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$fence>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  HEAP32[$fence>>2] = 0;
 }
 FUNCTION_TABLE_vi[$jobFunc & 4095]($userData);
 $2 = $fence;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __Z15ScheduleForEachR8JobFencePFvPvjES1_iPFvS1_E11JobPriority($fence,$concurrentJobFunc,$userData,$iterationCount,$combineJobFunc,$priority) {
 $fence = $fence|0;
 $concurrentJobFunc = $concurrentJobFunc|0;
 $userData = $userData|0;
 $iterationCount = $iterationCount|0;
 $combineJobFunc = $combineJobFunc|0;
 $priority = $priority|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$fence>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  HEAP32[$fence>>2] = 0;
 }
 $2 = ($iterationCount|0)==(0);
 if (!($2)) {
  $i$01$i = 0;
  while(1) {
   FUNCTION_TABLE_vii[$concurrentJobFunc & 4095]($userData,$i$01$i);
   $3 = (($i$01$i) + 1)|0;
   $exitcond$i = ($3|0)==($iterationCount|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $3;
   }
  }
 }
 $4 = ($combineJobFunc|0)==(0|0);
 if (!($4)) {
  FUNCTION_TABLE_vi[$combineJobFunc & 4095]($userData);
 }
 $5 = $fence;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function __Z22ScheduleForEachDependsR8JobFencePFvPvjES1_iS0_PFvS1_E11JobPriority($fence,$concurrentJobFunc,$userData,$iterationCount,$dependsOn,$combineJobFunc,$priority) {
 $fence = $fence|0;
 $concurrentJobFunc = $concurrentJobFunc|0;
 $userData = $userData|0;
 $iterationCount = $iterationCount|0;
 $dependsOn = $dependsOn|0;
 $combineJobFunc = $combineJobFunc|0;
 $priority = $priority|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$fence>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  HEAP32[$fence>>2] = 0;
 }
 $2 = ($iterationCount|0)==(0);
 if (!($2)) {
  $i$01$i = 0;
  while(1) {
   FUNCTION_TABLE_vii[$concurrentJobFunc & 4095]($userData,$i$01$i);
   $3 = (($i$01$i) + 1)|0;
   $exitcond$i = ($3|0)==($iterationCount|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $3;
   }
  }
 }
 $4 = ($combineJobFunc|0)==(0|0);
 if (!($4)) {
  FUNCTION_TABLE_vi[$combineJobFunc & 4095]($userData);
 }
 $5 = $fence;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function __Z11BeginJobSetR8JobFencei($fence,$jobCount) {
 $fence = $fence|0;
 $jobCount = $jobCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z9EndJobSetR8JobFence11JobPriority($fence,$priority) {
 $fence = $fence|0;
 $priority = $priority|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z21ScheduleForEachJobSetR8JobFencePFvPvjES1_iPFvS1_ES0_11JobPriority($fence,$concurrentJobFunc,$userData,$iterationCount,$combineJobFunc,$dependsOn,$priority) {
 $fence = $fence|0;
 $concurrentJobFunc = $concurrentJobFunc|0;
 $userData = $userData|0;
 $iterationCount = $iterationCount|0;
 $combineJobFunc = $combineJobFunc|0;
 $dependsOn = $dependsOn|0;
 $priority = $priority|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond$i$i = 0, $i$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$fence>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  HEAP32[$fence>>2] = 0;
 }
 $2 = ($iterationCount|0)==(0);
 if (!($2)) {
  $i$01$i$i = 0;
  while(1) {
   FUNCTION_TABLE_vii[$concurrentJobFunc & 4095]($userData,$i$01$i$i);
   $3 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($3|0)==($iterationCount|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $3;
   }
  }
 }
 $4 = ($combineJobFunc|0)==(0|0);
 if (!($4)) {
  FUNCTION_TABLE_vi[$combineJobFunc & 4095]($userData);
 }
 $5 = $fence;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function __Z22GetJobQueueThreadCountv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z40ConfigureBlockRangesWithMinIndicesPerJobP10BlockRangeii($blockRanges,$totalIndices,$minimumIndicesPerJob) {
 $blockRanges = $blockRanges|0;
 $totalIndices = $totalIndices|0;
 $minimumIndicesPerJob = $minimumIndicesPerJob|0;
 var $$0$i1 = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z22GetJobQueueThreadCountv()|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $$0$i1 = 1;$15 = $totalIndices;
 } else {
  $2 = (($totalIndices|0) / ($minimumIndicesPerJob|0))&-1;
  $3 = (($2) + 1)|0;
  $4 = $0 << 1;
  $5 = (($4) + 2)|0;
  $6 = ($5|0)<($3|0);
  $7 = $6 ? $5 : $3;
  $8 = ($7|0)>(16);
  $9 = $8 ? 16 : $7;
  $10 = (($totalIndices|0) / ($9|0))&-1;
  $11 = ($9|0)==(0);
  if ($11) {
   $$0$i2 = 0;
   STACKTOP = sp;return ($$0$i2|0);
  } else {
   $$0$i1 = $9;$15 = $10;
  }
 }
 $12 = (($$0$i1) + -1)|0;
 $13 = ((($blockRanges) + (($12*12)|0)|0) + 4|0);
 $i$01$i = 0;
 while(1) {
  $14 = Math_imul($i$01$i, $15)|0;
  $16 = (($blockRanges) + (($i$01$i*12)|0)|0);
  HEAP32[$16>>2] = $14;
  $17 = ($i$01$i|0)==($12|0);
  if ($17) {
   $19 = (($totalIndices) - ($14))|0;
   HEAP32[$13>>2] = $19;
  } else {
   $18 = ((($blockRanges) + (($i$01$i*12)|0)|0) + 4|0);
   HEAP32[$18>>2] = $15;
  }
  $20 = ((($blockRanges) + (($i$01$i*12)|0)|0) + 8|0);
  HEAP32[$20>>2] = $$0$i1;
  $21 = (($i$01$i) + 1)|0;
  $exitcond$i = ($21|0)==($$0$i1|0);
  if ($exitcond$i) {
   $$0$i2 = $$0$i1;
   break;
  } else {
   $i$01$i = $21;
  }
 }
 STACKTOP = sp;return ($$0$i2|0);
}
function __Z20ConfigureBlockRangesP10BlockRangeii($blockRanges,$totalIndices,$blockRangeCount) {
 $blockRanges = $blockRanges|0;
 $totalIndices = $totalIndices|0;
 $blockRangeCount = $blockRangeCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($totalIndices|0) / ($blockRangeCount|0))&-1;
 $1 = ($blockRangeCount|0)==(0);
 if ($1) {
  STACKTOP = sp;return ($blockRangeCount|0);
 }
 $2 = (($blockRangeCount) + -1)|0;
 $i$01 = 0;
 while(1) {
  $3 = Math_imul($i$01, $0)|0;
  $4 = (($blockRanges) + (($i$01*12)|0)|0);
  HEAP32[$4>>2] = $3;
  $5 = ($i$01|0)==($2|0);
  if ($5) {
   $7 = (($totalIndices) - ($3))|0;
   $8 = ((($blockRanges) + (($2*12)|0)|0) + 4|0);
   HEAP32[$8>>2] = $7;
  } else {
   $6 = ((($blockRanges) + (($i$01*12)|0)|0) + 4|0);
   HEAP32[$6>>2] = $0;
  }
  $9 = ((($blockRanges) + (($i$01*12)|0)|0) + 8|0);
  HEAP32[$9>>2] = $blockRangeCount;
  $10 = (($i$01) + 1)|0;
  $exitcond = ($10|0)==($blockRangeCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $10;
  }
 }
 STACKTOP = sp;return ($blockRangeCount|0);
}
function __ZN10FileSystem16StaticInitializeEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10FileSystem13StaticDestroyEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK10FileSystem6DeleteEPKcb($this,$path,$recurse) {
 $this = $this|0;
 $path = $path|0;
 $recurse = $recurse|0;
 var $$0$i4 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $e = 0, $it$0$ph1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $e = sp;
 $0 = (($e) + 1040|0);
 HEAP8[$e>>0] = 0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3249,($e|0),($path|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  $5 = HEAP32[$0>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   ___resumeException($3|0);
   // unreachable;
  }
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 64|0);
  $9 = HEAP32[$8>>2]|0;
  __THREW__ = 0;
  invoke_vii($9|0,($5|0),($e|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   ___resumeException($3|0);
   // unreachable;
  }
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$0$i4 = 0;
  STACKTOP = sp;return ($$0$i4|0);
 }
 $16 = HEAP32[$14>>2]|0;
 $17 = (($16) + 116|0);
 $18 = HEAP32[$17>>2]|0;
 __THREW__ = 0;
 $19 = (invoke_iiii($18|0,($14|0),($e|0),($recurse|0))|0);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 do {
  if (!($21)) {
   $22 = HEAP32[647896>>2]|0;
   $23 = (($22) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$0>>2]|0;
   $26 = ($25|0)==($24|0);
   if ($26) {
    __THREW__ = 0;
    $27 = (invoke_ii(3312,($24|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    L18: do {
     if ($27) {
      $30 = HEAP32[647896>>2]|0;
      $31 = (($30) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($30) + 16|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==(0);
      if (!($35)) {
       $36 = (($32) + ($34<<2)|0);
       $69 = $34;$70 = $32;$71 = $36;$it$0$ph1$i$i = $32;
       while(1) {
        $41 = (($it$0$ph1$i$i) + 4|0);
        $42 = $41;
        $38 = $70;$39 = $69;$46 = $71;
        while(1) {
         $43 = HEAP32[$it$0$ph1$i$i>>2]|0;
         $44 = ($43|0)==($25|0);
         if (!($44)) {
          break;
         }
         $45 = $46;
         $47 = (($45) - ($42))|0;
         _memmove(($it$0$ph1$i$i|0),($41|0),($47|0))|0;
         $48 = HEAP32[$33>>2]|0;
         $49 = (($48) + -1)|0;
         HEAP32[$33>>2] = $49;
         $50 = HEAP32[$31>>2]|0;
         $51 = (($50) + ($49<<2)|0);
         $52 = ($it$0$ph1$i$i|0)==($51|0);
         if ($52) {
          break L18;
         } else {
          $38 = $50;$39 = $49;$46 = $51;
         }
        }
        $37 = (($38) + ($39<<2)|0);
        $40 = ($41|0)==($37|0);
        if ($40) {
         break;
        } else {
         $69 = $39;$70 = $38;$71 = $37;$it$0$ph1$i$i = $41;
        }
       }
      }
     }
    } while(0);
    $$pr = HEAP32[$0>>2]|0;
    $54 = $$pr;
   } else {
    $54 = $25;
   }
   $53 = ($54|0)==(0|0);
   if ($53) {
    $$0$i4 = $19;
    STACKTOP = sp;return ($$0$i4|0);
   }
   $55 = HEAP32[$54>>2]|0;
   $56 = (($55) + 64|0);
   $57 = HEAP32[$56>>2]|0;
   FUNCTION_TABLE_vii[$57 & 4095]($54,$e);
   $$0$i4 = $19;
   STACKTOP = sp;return ($$0$i4|0);
  }
 } while(0);
 $58 = ___cxa_find_matching_catch()|0;
 $59 = tempRet0;
 $60 = HEAP32[$0>>2]|0;
 $61 = ($60|0)==(0|0);
 if ($61) {
  ___resumeException($58|0);
  // unreachable;
 }
 $62 = HEAP32[$60>>2]|0;
 $63 = (($62) + 64|0);
 $64 = HEAP32[$63>>2]|0;
 __THREW__ = 0;
 invoke_vii($64|0,($60|0),($e|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch(0|0)|0;
  $68 = tempRet0;
  ___clang_call_terminate($67);
  // unreachable;
 } else {
  ___resumeException($58|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN15FileSystemEntry6DeleteEb($this,$recursively) {
 $this = $this|0;
 $recursively = $recursively|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $it$0$ph1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 116|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($1,$this,$recursively)|0);
 $7 = HEAP32[647896>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = ($10|0)==($9|0);
 if (!($11)) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (__ZNK16MemoryFileSystem7IsEmptyEv($9)|0);
 if (!($12)) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[647896>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = (($15) + ($17<<2)|0);
 $36 = $17;$37 = $15;$38 = $19;$it$0$ph1$i = $15;
 L13: while(1) {
  $24 = (($it$0$ph1$i) + 4|0);
  $25 = $24;
  $21 = $37;$22 = $36;$29 = $38;
  while(1) {
   $26 = HEAP32[$it$0$ph1$i>>2]|0;
   $27 = ($26|0)==($10|0);
   if (!($27)) {
    break;
   }
   $28 = $29;
   $30 = (($28) - ($25))|0;
   _memmove(($it$0$ph1$i|0),($24|0),($30|0))|0;
   $31 = HEAP32[$16>>2]|0;
   $32 = (($31) + -1)|0;
   HEAP32[$16>>2] = $32;
   $33 = HEAP32[$14>>2]|0;
   $34 = (($33) + ($32<<2)|0);
   $35 = ($it$0$ph1$i|0)==($34|0);
   if ($35) {
    $$0 = $6;
    label = 10;
    break L13;
   } else {
    $21 = $33;$22 = $32;$29 = $34;
   }
  }
  $20 = (($21) + ($22<<2)|0);
  $23 = ($24|0)==($20|0);
  if ($23) {
   $$0 = $6;
   label = 10;
   break;
  } else {
   $36 = $22;$37 = $21;$38 = $20;$it$0$ph1$i = $24;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK10FileSystem9EnumerateEPKcP13dynamic_arrayI13FileEntryInfoLj8EEb19FileEnumerationFlag($this,$path,$outList,$recurse,$flags) {
 $this = $this|0;
 $path = $path|0;
 $outList = $outList|0;
 $recurse = $recurse|0;
 $flags = $flags|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $handlerData = 0, $i$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1072|0;
 $data = sp + 8|0;
 $handlerData = sp;
 $0 = HEAP32[647896>>2]|0;
 $1 = (($0) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   label = 5;
  } else {
   $4 = (($0) + 8|0);
   $i$0$i = $2;
   while(1) {
    $5 = (($i$0$i) + -1)|0;
    $6 = ($i$0$i|0)==(0);
    if ($6) {
     label = 5;
     break L1;
    }
    $7 = HEAP32[$4>>2]|0;
    $8 = (($7) + ($5<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + 48|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (FUNCTION_TABLE_iii[$12 & 4095]($9,$path)|0);
    if ($13) {
     $$0$i = $9;
     break;
    } else {
     $i$0$i = $5;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $14 = HEAP32[$0>>2]|0;
  $$0$i = $14;
 }
 $15 = (($data) + 1040|0);
 HEAP8[$data>>0] = 0;
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;
 (_strncpy(($data|0),($path|0),1040)|0);
 $16 = HEAP32[$$0$i>>2]|0;
 $17 = (($16) + 60|0);
 $18 = HEAP32[$17>>2]|0;
 __THREW__ = 0;
 invoke_vii($18|0,($$0$i|0),($data|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if (!($20)) {
  HEAP32[$handlerData>>2] = 0;
  $21 = HEAP32[$15>>2]|0;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 148|0);
  $24 = HEAP32[$23>>2]|0;
  __THREW__ = 0;
  $25 = (invoke_iiiiiii($24|0,($21|0),($data|0),($outList|0),($recurse|0),($handlerData|0),($flags|0))|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   $28 = HEAP32[$15>>2]|0;
   $29 = ($28|0)==(0|0);
   if ($29) {
    STACKTOP = sp;return ($25|0);
   }
   $30 = HEAP32[$28>>2]|0;
   $31 = (($30) + 64|0);
   $32 = HEAP32[$31>>2]|0;
   FUNCTION_TABLE_vii[$32 & 4095]($28,$data);
   STACKTOP = sp;return ($25|0);
  }
 }
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 $35 = HEAP32[$15>>2]|0;
 $36 = ($35|0)==(0|0);
 if ($36) {
  ___resumeException($33|0);
  // unreachable;
 }
 $37 = HEAP32[$35>>2]|0;
 $38 = (($37) + 64|0);
 $39 = HEAP32[$38>>2]|0;
 __THREW__ = 0;
 invoke_vii($39|0,($35|0),($data|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($33|0);
  // unreachable;
 }
 return 0|0;
}
function __Z13GetFileSystemv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[647896>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNK10FileSystem16CurrentDirectoryEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN22LocalFileSystemHandler16CurrentDirectoryEv($agg$result);
 STACKTOP = sp;return;
}
function __ZN10FileSystem19SetCurrentDirectoryERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($agg$result,$this,$newCurrentDirectory) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $newCurrentDirectory = $newCurrentDirectory|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN22LocalFileSystemHandler19SetCurrentDirectoryERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($agg$result,$newCurrentDirectory);
 STACKTOP = sp;return;
}
function __ZNK10FileSystem10ToAbsoluteEPKc($agg$result,$this,$relative) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $relative = $relative|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $i$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if (!($2)) {
   $3 = (($this) + 8|0);
   $i$0 = $1;
   while(1) {
    $4 = (($i$0) + -1)|0;
    $5 = ($i$0|0)==(0);
    if ($5) {
     break L1;
    }
    $6 = HEAP32[$3>>2]|0;
    $7 = (($6) + ($4<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 56|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (FUNCTION_TABLE_iii[$11 & 4095]($8,$relative)|0);
    if ($12) {
     break;
    } else {
     $i$0 = $4;
    }
   }
   $13 = (_strlen(($relative|0))|0);
   $14 = ($13>>>0)>(4294967279);
   if ($14) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $15 = ($13>>>0)<(11);
   if ($15) {
    $16 = $13 << 1;
    $17 = $16&255;
    HEAP8[$agg$result>>0] = $17;
    $18 = (($agg$result) + 1|0);
    $__p$0$i$i$i = $18;
   } else {
    $19 = (($13) + 16)|0;
    $20 = $19 & -16;
    $21 = (__Znwj($20)|0);
    $22 = (($agg$result) + 8|0);
    HEAP32[$22>>2] = $21;
    $23 = $20 | 1;
    HEAP32[$agg$result>>2] = $23;
    $24 = (($agg$result) + 4|0);
    HEAP32[$24>>2] = $13;
    $__p$0$i$i$i = $21;
   }
   _memcpy(($__p$0$i$i$i|0),($relative|0),($13|0))|0;
   $25 = (($__p$0$i$i$i) + ($13)|0);
   HEAP8[$25>>0] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $26 = HEAP32[$this>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 52|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_viii[$29 & 4095]($agg$result,$26,$relative);
 STACKTOP = sp;return;
}
function __ZN15FileSystemEntry11CreateAsDirEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 112|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iii[$5 & 4095]($1,$this)|0);
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK10FileSystem16LastErrorMessageEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZN10FileSystem5StartEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$01$i = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = HEAP32[628408>>2]|0;
 HEAP32[$3>>2] = $4;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 $5 = (__Znwj10MemLabelIdbiPKci(24,$$byval_copy5,1,16,647880,290)|0);
 $6 = HEAP32[628408>>2]|0;
 $7 = (($5) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($5) + 12|0);
 HEAP32[$8>>2] = $6;
 $9 = (($5) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = (($5) + 20|0);
 HEAP32[$10>>2] = 0;
 $11 = HEAP32[628408>>2]|0;
 HEAP32[$1>>2] = $11;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 $12 = (invoke_iiiiiii(103,4,($$byval_copy5|0),0,16,(647880|0),62)|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  label = 4;
 } else {
  HEAP32[$12>>2] = ((650560 + 8|0));
  HEAP32[$5>>2] = $12;
  $15 = HEAP32[628408>>2]|0;
  HEAP32[$2>>2] = $15;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  $16 = (invoke_iiiiiii(103,32,($$byval_copy5|0),0,16,(647880|0),65)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   label = 4;
  } else {
   __THREW__ = 0;
   invoke_vii(3250,($16|0),(647872|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $35 = (($5) + 4|0);
    HEAP32[$35>>2] = $16;
    HEAP32[647896>>2] = $5;
    STACKTOP = sp;return;
   }
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viiiiii(97,($16|0),($$byval_copy5|0),0,16,(647880|0),65);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $33 = ___cxa_find_matching_catch(0|0)|0;
    $34 = tempRet0;
    ___clang_call_terminate($33);
    // unreachable;
   } else {
    $$0$i = $24;$$01$i = $23;
   }
  }
 }
 if ((label|0) == 4) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  $$0$i = $22;$$01$i = $21;
 }
 $27 = HEAP32[$10>>2]|0;
 $28 = ($27|0)>(-1);
 do {
  if ($28) {
   $29 = HEAP32[$7>>2]|0;
   $30 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $30;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($29|0),($$byval_copy5|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $33 = ___cxa_find_matching_catch(0|0)|0;
    $34 = tempRet0;
    ___clang_call_terminate($33);
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_viiiiii(97,($5|0),($$byval_copy5|0),1,16,(647880|0),290);
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch(0|0)|0;
  $39 = tempRet0;
  ___clang_call_terminate($38);
  // unreachable;
 } else {
  ___resumeException($$01$i|0);
  // unreachable;
 }
}
function __ZN13FileEntryDataaSERKS_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_strncpy(($this|0),($other|0),1040)|0);
 $0 = (($this) + 1039|0);
 HEAP8[$0>>0] = 0;
 $1 = (($other) + 1040|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1040|0);
 HEAP32[$3>>2] = $2;
 $4 = (($other) + 1044|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 1044|0);
 HEAP32[$6>>2] = $5;
 $7 = ($2|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return ($this|0);
 }
 $8 = HEAP32[$2>>2]|0;
 $9 = (($8) + 60|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 4095]($2,$this);
 STACKTOP = sp;return ($this|0);
}
function __ZN15FileSystemEntryC2EPKc($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 HEAP8[$this>>0] = 0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3249,($this|0),($path|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  ___resumeException($3|0);
  // unreachable;
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 __THREW__ = 0;
 invoke_vii($9|0,($5|0),($this|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($3|0);
  // unreachable;
 }
}
function __ZN15FileSystemEntry3SetEPKc($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $0 = sp;
 $1 = (($0) + 1040|0);
 HEAP8[$0>>0] = 0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 (_strncpy(($this|0),($0|0),1040)|0);
 $2 = (($this) + 1039|0);
 HEAP8[$2>>0] = 0;
 $3 = HEAP32[$1>>2]|0;
 $4 = (($this) + 1040|0);
 HEAP32[$4>>2] = $3;
 $5 = (($0) + 1044|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 1044|0);
 HEAP32[$7>>2] = $6;
 $8 = ($3|0)==(0|0);
 do {
  if (!($8)) {
   $9 = HEAP32[$3>>2]|0;
   $10 = (($9) + 60|0);
   $11 = HEAP32[$10>>2]|0;
   __THREW__ = 0;
   invoke_vii($11|0,($3|0),($this|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $$pre = HEAP32[$1>>2]|0;
    $14 = ($$pre|0)==(0|0);
    if ($14) {
     break;
    }
    $15 = HEAP32[$$pre>>2]|0;
    $16 = (($15) + 64|0);
    $17 = HEAP32[$16>>2]|0;
    FUNCTION_TABLE_vii[$17 & 4095]($$pre,$0);
    break;
   }
   $36 = ___cxa_find_matching_catch()|0;
   $37 = tempRet0;
   $38 = HEAP32[$1>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    ___resumeException($36|0);
    // unreachable;
   }
   $40 = HEAP32[$38>>2]|0;
   $41 = (($40) + 64|0);
   $42 = HEAP32[$41>>2]|0;
   __THREW__ = 0;
   invoke_vii($42|0,($38|0),($0|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $45 = ___cxa_find_matching_catch(0|0)|0;
    $46 = tempRet0;
    ___clang_call_terminate($45);
    // unreachable;
   } else {
    ___resumeException($36|0);
    // unreachable;
   }
  }
 } while(0);
 (_strncpy(($this|0),($path|0),1040)|0);
 __Z24ConvertSeparatorsToUnityPc($this);
 $18 = HEAP32[647896>>2]|0;
 $19 = (($18) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 L14: do {
  if (!($21)) {
   $22 = (($18) + 8|0);
   $i$0$i = $20;
   while(1) {
    $23 = (($i$0$i) + -1)|0;
    $24 = ($i$0$i|0)==(0);
    if ($24) {
     break L14;
    }
    $25 = HEAP32[$22>>2]|0;
    $26 = (($25) + ($23<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 48|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (FUNCTION_TABLE_iii[$30 & 4095]($27,$path)|0);
    if ($31) {
     $$0$i = $27;
     break;
    } else {
     $i$0$i = $23;
    }
   }
   $33 = HEAP32[$$0$i>>2]|0;
   $34 = (($33) + 60|0);
   $35 = HEAP32[$34>>2]|0;
   FUNCTION_TABLE_vii[$35 & 4095]($$0$i,$this);
   STACKTOP = sp;return;
  }
 } while(0);
 $32 = HEAP32[$18>>2]|0;
 $$0$i = $32;
 $33 = HEAP32[$$0$i>>2]|0;
 $34 = (($33) + 60|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$35 & 4095]($$0$i,$this);
 STACKTOP = sp;return;
}
function __ZNK15FileSystemEntry4PathEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZNK15FileSystemEntry8FilenameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $s$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strrchr($this,47)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_strrchr($this,92)|0);
  $s$0 = $2;
 } else {
  $s$0 = $0;
 }
 $3 = ($s$0|0)==(0|0);
 $4 = (($s$0) + 1|0);
 $5 = $3 ? $this : $4;
 STACKTOP = sp;return ($5|0);
}
function __ZN15FileSystemEntry8SetFlagsEjj($this,$attributeMask,$attributeValue) {
 $this = $this|0;
 $attributeMask = $attributeMask|0;
 $attributeValue = $attributeValue|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $7 = 0;
  STACKTOP = sp;return ($7|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 104|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$5 & 511]($1,$this,$attributeMask,$attributeValue)|0);
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZNK15FileSystemEntry5IsDirEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $7 = 0;
  STACKTOP = sp;return ($7|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iii[$5 & 4095]($1,$this)|0);
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZNK15FileSystemEntry4SizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1044|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $8 = 0;$9 = 0;
  tempRet0 = $8;
  STACKTOP = sp;return ($9|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iii[$5 & 4095]($1,$this)|0);
 $7 = tempRet0;
 $8 = $7;$9 = $6;
 tempRet0 = $8;
 STACKTOP = sp;return ($9|0);
}
function __ZN15FileSystemEntry6CopyToERS_($this,$to) {
 $this = $this|0;
 $to = $to|0;
 var $$ = 0, $$0 = 0, $$02 = 0, $$08 = 0, $$1 = 0, $$13 = 0, $$19 = 0, $$210 = 0, $$24 = 0, $$311 = 0, $$35 = 0, $$4 = 0, $$412 = 0, $$46 = 0, $$5 = 0, $$513 = 0, $$57 = 0, $$byval_copy48 = 0, $$ph = 0, $$pre = 0;
 var $$pre$i = 0, $$pre$i15 = 0, $$pre$phi110Z2D = 0, $$pre$phiZ2D = 0, $$pre109 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $bytesread = 0, $byteswritten = 0, $childEntries = 0, $destination = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body38$indexZ2D = 0;
 var $eh$lpad$body47$index16Z2D = 0, $eh$lpad$body47$indexZ2D = 0, $eh$lpad$body55$index29Z2D = 0, $eh$lpad$body55$indexZ2D = 0, $fromReader = 0, $fullDestinationPath = 0, $handlerData = 0, $i$093 = 0, $item = 0, $lpad$phi$index = 0, $lpad$phi$index23 = 0, $lpad$phi99$index = 0, $lpad$phi99$index9 = 0, $s$0$i = 0, $toWriter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4320|0;
 $$byval_copy48 = sp + 4312|0;
 $0 = sp + 4308|0;
 $1 = sp + 4304|0;
 $2 = sp + 4300|0;
 $3 = sp + 4296|0;
 $fromReader = sp + 3232|0;
 $toWriter = sp + 2168|0;
 $bytesread = sp + 8|0;
 $byteswritten = sp;
 $childEntries = sp + 24|0;
 $handlerData = sp + 16|0;
 $item = sp + 40|0;
 $fullDestinationPath = sp + 1096|0;
 $destination = sp + 1112|0;
 $4 = (($this) + 1040|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$5 = 0;
  STACKTOP = sp;return ($$5|0);
 }
 $7 = (($to) + 1040|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$5 = 0;
  STACKTOP = sp;return ($$5|0);
 }
 $10 = ($5|0)==($8|0);
 if ($10) {
  $11 = (($this) + 1044|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($to) + 1044|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  if ($15) {
   $16 = HEAP32[$5>>2]|0;
   $17 = (($16) + 132|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (FUNCTION_TABLE_iiii[$18 & 2047]($5,$this,$to)|0);
   $$5 = $19;
   STACKTOP = sp;return ($$5|0);
  }
 }
 $20 = HEAP32[$8>>2]|0;
 $21 = (($20) + 116|0);
 $22 = HEAP32[$21>>2]|0;
 (FUNCTION_TABLE_iiii[$22 & 2047]($8,$to,1)|0);
 $23 = HEAP32[$4>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 80|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (FUNCTION_TABLE_iii[$26 & 4095]($23,$this)|0);
 L12: do {
  if ($27) {
   $283 = HEAP32[$7>>2]|0;
   $284 = HEAP32[$283>>2]|0;
   $285 = (($284) + 112|0);
   $286 = HEAP32[$285>>2]|0;
   (FUNCTION_TABLE_iii[$286 & 4095]($283,$to)|0);
   HEAP32[$childEntries>>2] = 0;
   $287 = (($childEntries) + 8|0);
   HEAP32[$287>>2] = 0;
   $288 = (($childEntries) + 12|0);
   HEAP32[$288>>2] = 0;
   $289 = (($childEntries) + 4|0);
   HEAP32[$289>>2] = 61;
   HEAP32[$handlerData>>2] = 0;
   $290 = HEAP32[$4>>2]|0;
   $291 = HEAP32[$290>>2]|0;
   $292 = (($291) + 148|0);
   $293 = HEAP32[$292>>2]|0;
   __THREW__ = 0;
   (invoke_iiiiiii($293|0,($290|0),($this|0),($childEntries|0),0,($handlerData|0),0)|0);
   $294 = __THREW__; __THREW__ = 0;
   $295 = $294&1;
   L122: do {
    if ($295) {
     $376 = ___cxa_find_matching_catch()|0;
     $377 = tempRet0;
     $eh$lpad$body47$index16Z2D = $377;$eh$lpad$body47$indexZ2D = $376;
     label = 106;
    } else {
     $296 = HEAP32[$287>>2]|0;
     $297 = ($296|0)==(0);
     L124: do {
      if ($297) {
       $$4 = 1;
      } else {
       $298 = HEAP32[$childEntries>>2]|0;
       $299 = (($item) + 1040|0);
       $300 = (($fullDestinationPath) + 1|0);
       $301 = (($destination) + 1040|0);
       $302 = (($fullDestinationPath) + 8|0);
       $303 = (($fullDestinationPath) + 4|0);
       $i$093 = $298;
       while(1) {
        HEAP8[$item>>0] = 0;
        ;HEAP32[$299+0>>2]=0|0;HEAP32[$299+4>>2]=0|0;HEAP32[$299+8>>2]=0|0;HEAP32[$299+12>>2]=0|0;
        __THREW__ = 0;
        invoke_vii(3249,($item|0),($i$093|0));
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        if ($310) {
         label = 83;
         break;
        }
        $322 = (_strlen(($to|0))|0);
        $323 = ($322>>>0)>(4294967279);
        if ($323) {
         label = 87;
         break;
        }
        $326 = ($322>>>0)<(11);
        if ($326) {
         $327 = $322 << 1;
         $328 = $327&255;
         HEAP8[$fullDestinationPath>>0] = $328;
         $__p$0$i$i$i = $300;
        } else {
         $329 = (($322) + 16)|0;
         $330 = $329 & -16;
         __THREW__ = 0;
         $331 = (invoke_ii(2988,($330|0))|0);
         $332 = __THREW__; __THREW__ = 0;
         $333 = $332&1;
         if ($333) {
          label = 107;
          break;
         }
         HEAP32[$302>>2] = $331;
         $334 = $330 | 1;
         HEAP32[$fullDestinationPath>>2] = $334;
         HEAP32[$303>>2] = $322;
         $__p$0$i$i$i = $331;
        }
        _memcpy(($__p$0$i$i$i|0),($to|0),($322|0))|0;
        $335 = (($__p$0$i$i$i) + ($322)|0);
        HEAP8[$335>>0] = 0;
        __THREW__ = 0;
        (invoke_iiii(1480,($fullDestinationPath|0),(647888|0),1)|0);
        $336 = __THREW__; __THREW__ = 0;
        $337 = $336&1;
        if ($337) {
         label = 110;
         break;
        }
        $338 = (_strrchr($item,47)|0);
        $339 = ($338|0)==(0|0);
        if ($339) {
         $340 = (_strrchr($item,92)|0);
         $s$0$i = $340;
        } else {
         $s$0$i = $338;
        }
        $341 = ($s$0$i|0)==(0|0);
        $342 = (($s$0$i) + 1|0);
        $343 = $341 ? $item : $342;
        $344 = (_strlen(($343|0))|0);
        __THREW__ = 0;
        (invoke_iiii(1480,($fullDestinationPath|0),($343|0),($344|0))|0);
        $345 = __THREW__; __THREW__ = 0;
        $346 = $345&1;
        if ($346) {
         label = 110;
         break;
        }
        $347 = HEAP8[$fullDestinationPath>>0]|0;
        $348 = $347 & 1;
        $349 = ($348<<24>>24)==(0);
        $350 = HEAP32[$302>>2]|0;
        $$ = $349 ? $300 : $350;
        HEAP8[$destination>>0] = 0;
        ;HEAP32[$301+0>>2]=0|0;HEAP32[$301+4>>2]=0|0;HEAP32[$301+8>>2]=0|0;HEAP32[$301+12>>2]=0|0;
        __THREW__ = 0;
        invoke_vii(3249,($destination|0),($$|0));
        $351 = __THREW__; __THREW__ = 0;
        $352 = $351&1;
        if ($352) {
         label = 98;
         break;
        }
        __THREW__ = 0;
        $364 = (invoke_iii(2529,($item|0),($destination|0))|0);
        $365 = __THREW__; __THREW__ = 0;
        $366 = $365&1;
        if ($366) {
         label = 112;
         break;
        }
        $367 = HEAP32[$301>>2]|0;
        $368 = ($367|0)==(0|0);
        if (!($368)) {
         $369 = HEAP32[$367>>2]|0;
         $370 = (($369) + 64|0);
         $371 = HEAP32[$370>>2]|0;
         __THREW__ = 0;
         invoke_vii($371|0,($367|0),($destination|0));
         $372 = __THREW__; __THREW__ = 0;
         $373 = $372&1;
         if ($373) {
          label = 110;
          break;
         }
        }
        $393 = HEAP8[$fullDestinationPath>>0]|0;
        $394 = $393 & 1;
        $395 = ($394<<24>>24)==(0);
        if (!($395)) {
         $396 = HEAP32[$302>>2]|0;
         __ZdlPv($396);
        }
        $397 = HEAP32[$299>>2]|0;
        $398 = ($397|0)==(0|0);
        if (!($398)) {
         $399 = HEAP32[$397>>2]|0;
         $400 = (($399) + 64|0);
         $401 = HEAP32[$400>>2]|0;
         __THREW__ = 0;
         invoke_vii($401|0,($397|0),($item|0));
         $402 = __THREW__; __THREW__ = 0;
         $403 = $402&1;
         if ($403) {
          label = 104;
          break;
         }
        }
        $308 = (($i$093) + 1088|0);
        if (!($364)) {
         $$4 = 0;
         break L124;
        }
        $304 = HEAP32[$childEntries>>2]|0;
        $305 = HEAP32[$287>>2]|0;
        $306 = (($304) + (($305*1088)|0)|0);
        $307 = ($308|0)==($306|0);
        if ($307) {
         $$4 = 1;
         break L124;
        } else {
         $i$093 = $308;
        }
       }
       do {
        if ((label|0) == 83) {
         $311 = ___cxa_find_matching_catch()|0;
         $312 = tempRet0;
         $313 = HEAP32[$299>>2]|0;
         $314 = ($313|0)==(0|0);
         if ($314) {
          $eh$lpad$body47$index16Z2D = $312;$eh$lpad$body47$indexZ2D = $311;
          label = 106;
          break L122;
         }
         $315 = HEAP32[$313>>2]|0;
         $316 = (($315) + 64|0);
         $317 = HEAP32[$316>>2]|0;
         __THREW__ = 0;
         invoke_vii($317|0,($313|0),($item|0));
         $318 = __THREW__; __THREW__ = 0;
         $319 = $318&1;
         if (!($319)) {
          $eh$lpad$body47$index16Z2D = $312;$eh$lpad$body47$indexZ2D = $311;
          label = 106;
          break L122;
         }
         $320 = ___cxa_find_matching_catch(0|0)|0;
         $321 = tempRet0;
         ___clang_call_terminate($320);
         // unreachable;
        }
        else if ((label|0) == 87) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $324 = __THREW__; __THREW__ = 0;
         $325 = $324&1;
         if ($325) {
          $380 = ___cxa_find_matching_catch()|0;
          $381 = tempRet0;
          $lpad$phi$index = $380;$lpad$phi$index23 = $381;
          label = 109;
          break;
         } else {
          // unreachable;
         }
        }
        else if ((label|0) == 98) {
         $353 = ___cxa_find_matching_catch()|0;
         $354 = tempRet0;
         $355 = HEAP32[$301>>2]|0;
         $356 = ($355|0)==(0|0);
         if ($356) {
          $eh$lpad$body55$index29Z2D = $354;$eh$lpad$body55$indexZ2D = $353;
          label = 111;
         } else {
          $357 = HEAP32[$355>>2]|0;
          $358 = (($357) + 64|0);
          $359 = HEAP32[$358>>2]|0;
          __THREW__ = 0;
          invoke_vii($359|0,($355|0),($destination|0));
          $360 = __THREW__; __THREW__ = 0;
          $361 = $360&1;
          if ($361) {
           $362 = ___cxa_find_matching_catch(0|0)|0;
           $363 = tempRet0;
           ___clang_call_terminate($362);
           // unreachable;
          } else {
           $eh$lpad$body55$index29Z2D = $354;$eh$lpad$body55$indexZ2D = $353;
           label = 111;
          }
         }
        }
        else if ((label|0) == 104) {
         $374 = ___cxa_find_matching_catch()|0;
         $375 = tempRet0;
         $eh$lpad$body47$index16Z2D = $375;$eh$lpad$body47$indexZ2D = $374;
         label = 106;
         break L122;
        }
        else if ((label|0) == 107) {
         $378 = ___cxa_find_matching_catch()|0;
         $379 = tempRet0;
         $lpad$phi$index = $378;$lpad$phi$index23 = $379;
         label = 109;
        }
        else if ((label|0) == 110) {
         $382 = ___cxa_find_matching_catch()|0;
         $383 = tempRet0;
         $eh$lpad$body55$index29Z2D = $383;$eh$lpad$body55$indexZ2D = $382;
         label = 111;
        }
        else if ((label|0) == 112) {
         $384 = ___cxa_find_matching_catch()|0;
         $385 = tempRet0;
         $386 = HEAP32[$301>>2]|0;
         $387 = ($386|0)==(0|0);
         if ($387) {
          $$210 = $384;$$24 = $385;
          label = 119;
         } else {
          $388 = HEAP32[$386>>2]|0;
          $389 = (($388) + 64|0);
          $390 = HEAP32[$389>>2]|0;
          __THREW__ = 0;
          invoke_vii($390|0,($386|0),($destination|0));
          $391 = __THREW__; __THREW__ = 0;
          $392 = $391&1;
          if ($392) {
           break L12;
          } else {
           $$210 = $384;$$24 = $385;
           label = 119;
          }
         }
        }
       } while(0);
       if ((label|0) == 109) {
        $$311 = $lpad$phi$index;$$35 = $lpad$phi$index23;
       }
       else if ((label|0) == 111) {
        $$210 = $eh$lpad$body55$indexZ2D;$$24 = $eh$lpad$body55$index29Z2D;
        label = 119;
       }
       if ((label|0) == 119) {
        $404 = HEAP8[$fullDestinationPath>>0]|0;
        $405 = $404 & 1;
        $406 = ($405<<24>>24)==(0);
        if ($406) {
         $$311 = $$210;$$35 = $$24;
        } else {
         $407 = HEAP32[$302>>2]|0;
         __ZdlPv($407);
         $$311 = $$210;$$35 = $$24;
        }
       }
       $408 = HEAP32[$299>>2]|0;
       $409 = ($408|0)==(0|0);
       if ($409) {
        $$412 = $$311;$$46 = $$35;
        break L122;
       }
       $410 = HEAP32[$408>>2]|0;
       $411 = (($410) + 64|0);
       $412 = HEAP32[$411>>2]|0;
       __THREW__ = 0;
       invoke_vii($412|0,($408|0),($item|0));
       $413 = __THREW__; __THREW__ = 0;
       $414 = $413&1;
       if ($414) {
        break L12;
       } else {
        $$412 = $$311;$$46 = $$35;
        break L122;
       }
      }
     } while(0);
     $415 = HEAP32[$288>>2]|0;
     $416 = ($415|0)>(-1);
     if (!($416)) {
      $$5 = $$4;
      STACKTOP = sp;return ($$5|0);
     }
     $417 = HEAP32[$childEntries>>2]|0;
     $418 = HEAP32[$289>>2]|0;
     HEAP32[$0>>2] = $418;
     ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($417,$$byval_copy48);
     HEAP32[$childEntries>>2] = 0;
     $$5 = $$4;
     STACKTOP = sp;return ($$5|0);
    }
   } while(0);
   if ((label|0) == 106) {
    $$412 = $eh$lpad$body47$indexZ2D;$$46 = $eh$lpad$body47$index16Z2D;
   }
   $419 = HEAP32[$288>>2]|0;
   $420 = ($419|0)>(-1);
   if (!($420)) {
    $$513 = $$412;$$57 = $$46;
    ___resumeException($$513|0);
    // unreachable;
   }
   $421 = HEAP32[$childEntries>>2]|0;
   $422 = HEAP32[$289>>2]|0;
   HEAP32[$0>>2] = $422;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($421|0),($$byval_copy48|0));
   $423 = __THREW__; __THREW__ = 0;
   $424 = $423&1;
   if (!($424)) {
    HEAP32[$childEntries>>2] = 0;
    $$513 = $$412;$$57 = $$46;
    ___resumeException($$513|0);
    // unreachable;
   }
  } else {
   __ZN12FileAccessorC2Ev($fromReader);
   __THREW__ = 0;
   invoke_vi(3584,($toWriter|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   L14: do {
    if ($29) {
     label = 14;
    } else {
     $30 = (($fromReader) + 4|0);
     (_strncpy(($30|0),($this|0),1040)|0);
     $31 = (($fromReader) + 1043|0);
     HEAP8[$31>>0] = 0;
     $32 = HEAP32[$4>>2]|0;
     $33 = (($fromReader) + 1044|0);
     HEAP32[$33>>2] = $32;
     $34 = (($this) + 1044|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($fromReader) + 1048|0);
     HEAP32[$36>>2] = $35;
     $37 = ($32|0)==(0|0);
     if ($37) {
      $46 = $35;
      label = 11;
     } else {
      $38 = HEAP32[$32>>2]|0;
      $39 = (($38) + 60|0);
      $40 = HEAP32[$39>>2]|0;
      __THREW__ = 0;
      invoke_vii($40|0,($32|0),($30|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 16;
      } else {
       $$pre$i = HEAP32[$36>>2]|0;
       $46 = $$pre$i;
       label = 11;
      }
     }
     L19: do {
      if ((label|0) == 11) {
       $43 = (($fromReader) + 1052|0);
       HEAP32[$43>>2] = 0;
       $44 = (($fromReader) + 1060|0);
       HEAP8[$44>>0] = 1;
       $45 = HEAP32[$46>>2]|0;
       $47 = (($45) + 8|0);
       $48 = HEAP32[$47>>2]|0;
       __THREW__ = 0;
       $49 = (invoke_iiiii($48|0,($46|0),($30|0),0,0)|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        label = 16;
       } else {
        L22: do {
         if ($49) {
          $56 = (($toWriter) + 4|0);
          (_strncpy(($56|0),($to|0),1040)|0);
          $57 = (($toWriter) + 1043|0);
          HEAP8[$57>>0] = 0;
          $58 = HEAP32[$7>>2]|0;
          $59 = (($toWriter) + 1044|0);
          HEAP32[$59>>2] = $58;
          $60 = (($to) + 1044|0);
          $61 = HEAP32[$60>>2]|0;
          $62 = (($toWriter) + 1048|0);
          HEAP32[$62>>2] = $61;
          $63 = ($58|0)==(0|0);
          if ($63) {
           $72 = $61;
          } else {
           $64 = HEAP32[$58>>2]|0;
           $65 = (($64) + 60|0);
           $66 = HEAP32[$65>>2]|0;
           __THREW__ = 0;
           invoke_vii($66|0,($58|0),($56|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 16;
            break L19;
           }
           $$pre$i15 = HEAP32[$62>>2]|0;
           $72 = $$pre$i15;
          }
          $69 = (($toWriter) + 1052|0);
          HEAP32[$69>>2] = 0;
          $70 = (($toWriter) + 1060|0);
          HEAP8[$70>>0] = 1;
          $71 = HEAP32[$72>>2]|0;
          $73 = (($71) + 8|0);
          $74 = HEAP32[$73>>2]|0;
          __THREW__ = 0;
          $75 = (invoke_iiiii($74|0,($72|0),($56|0),1,0)|0);
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           label = 16;
           break L19;
          }
          if ($75) {
           $78 = HEAP32[$36>>2]|0;
           $79 = ($78|0)==(0|0);
           if ($79) {
            $88 = 0;$91 = 0;
           } else {
            $80 = HEAP32[$78>>2]|0;
            $81 = (($80) + 44|0);
            $82 = HEAP32[$81>>2]|0;
            __THREW__ = 0;
            $83 = (invoke_iii($82|0,($78|0),($30|0))|0);
            $84 = tempRet0;
            $85 = __THREW__; __THREW__ = 0;
            $86 = $85&1;
            if ($86) {
             label = 16;
             break L19;
            } else {
             $88 = $84;$91 = $83;
            }
           }
           $87 = ($88>>>0)<(0);
           $89 = ($88|0)==(0);
           $90 = ($91>>>0)<(65536);
           $92 = $89 & $90;
           $93 = $87 | $92;
           $94 = $93 ? $91 : 65536;
           $93 ? $88 : 0;
           $95 = ($94|0)==(0);
           if ($95) {
            $$1 = 1;$$pre$phiZ2D = $70;
           } else {
            $96 = HEAP32[628512>>2]|0;
            HEAP32[$3>>2] = $96;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$3+0>>2]|0;
            $97 = (invoke_iiiiiiii(108,(0|0),($94|0),1,($$byval_copy48|0),0,(647880|0),370)|0);
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            L35: do {
             if ($99) {
              $$ph = 0;
              label = 34;
             } else {
              $100 = HEAP32[$36>>2]|0;
              $101 = ($100|0)==(0|0);
              L37: do {
               if ($101) {
                $154 = 0;$156 = 0;
                label = 38;
               } else {
                $103 = $100;$137 = 0;$138 = 0;
                while(1) {
                 $102 = HEAP32[$103>>2]|0;
                 $104 = (($102) + 16|0);
                 $105 = HEAP32[$104>>2]|0;
                 __THREW__ = 0;
                 $106 = (invoke_iiiiiii($105|0,($103|0),($30|0),($94|0),0,($97|0),($bytesread|0))|0);
                 $107 = __THREW__; __THREW__ = 0;
                 $108 = $107&1;
                 if ($108) {
                  break;
                 }
                 if (!($106)) {
                  $154 = $137;$156 = $138;
                  label = 38;
                  break L37;
                 }
                 $109 = HEAP32[$62>>2]|0;
                 $110 = ($109|0)==(0|0);
                 if ($110) {
                  $$0 = 0;
                  break L37;
                 }
                 $111 = $bytesread;
                 $112 = $111;
                 $113 = HEAP32[$112>>2]|0;
                 $114 = (($111) + 4)|0;
                 $115 = $114;
                 $116 = HEAP32[$115>>2]|0;
                 $117 = HEAP32[$109>>2]|0;
                 $118 = (($117) + 24|0);
                 $119 = HEAP32[$118>>2]|0;
                 __THREW__ = 0;
                 $120 = (invoke_iiiiiii($119|0,($109|0),($56|0),($113|0),($116|0),($97|0),($byteswritten|0))|0);
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  break;
                 }
                 if (!($120)) {
                  $$0 = 0;
                  break L37;
                 }
                 $131 = $byteswritten;
                 $132 = $131;
                 $133 = HEAP32[$132>>2]|0;
                 $134 = (($131) + 4)|0;
                 $135 = $134;
                 $136 = HEAP32[$135>>2]|0;
                 $139 = (_i64Add(($133|0),($136|0),($137|0),($138|0))|0);
                 $140 = tempRet0;
                 $141 = HEAP32[$36>>2]|0;
                 $142 = ($141|0)==(0|0);
                 if ($142) {
                  $154 = $139;$156 = $140;
                  label = 38;
                  break L37;
                 } else {
                  $103 = $141;$137 = $139;$138 = $140;
                 }
                }
                $123 = ___cxa_find_matching_catch()|0;
                $124 = tempRet0;
                $128 = $97;$lpad$phi99$index = $123;$lpad$phi99$index9 = $124;
                break L35;
               }
              } while(0);
              do {
               if ((label|0) == 38) {
                $143 = HEAP8[$70>>0]|0;
                $144 = ($143<<24>>24)==(0);
                if (!($144)) {
                 $145 = HEAP32[$62>>2]|0;
                 $146 = ($145|0)==(0|0);
                 if ($146) {
                  $$0 = 0;
                  break;
                 }
                 $147 = HEAP32[$145>>2]|0;
                 $148 = (($147) + 28|0);
                 $149 = HEAP32[$148>>2]|0;
                 __THREW__ = 0;
                 $150 = (invoke_iii($149|0,($145|0),($56|0))|0);
                 $151 = __THREW__; __THREW__ = 0;
                 $152 = $151&1;
                 if ($152) {
                  $$ph = $97;
                  label = 34;
                  break L35;
                 }
                 if (!($150)) {
                  $$0 = 0;
                  break;
                 }
                }
                $153 = ($91|0)==($154|0);
                $155 = ($88|0)==($156|0);
                $157 = $153 & $155;
                $$0 = $157;
               }
              } while(0);
              $158 = ($94|0)>(-1);
              if (!($158)) {
               $$1 = $$0;$$pre$phiZ2D = $70;
               break L22;
              }
              HEAP32[$1>>2] = $96;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$1+0>>2]|0;
              invoke_vii(2591,($97|0),($$byval_copy48|0));
              $159 = __THREW__; __THREW__ = 0;
              $160 = $159&1;
              if ($160) {
               label = 16;
               break L19;
              } else {
               $$1 = $$0;$$pre$phiZ2D = $70;
               break L22;
              }
             }
            } while(0);
            if ((label|0) == 34) {
             $125 = ___cxa_find_matching_catch()|0;
             $126 = tempRet0;
             $128 = $$ph;$lpad$phi99$index = $125;$lpad$phi99$index9 = $126;
            }
            $127 = ($94|0)>(-1);
            if (!($127)) {
             $$02 = $lpad$phi99$index9;$$08 = $lpad$phi99$index;$$pre$phi110Z2D = $70;
             break L19;
            }
            HEAP32[$2>>2] = $96;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy48+0>>2]=HEAP32[$2+0>>2]|0;
            invoke_vii(2591,($128|0),($$byval_copy48|0));
            $129 = __THREW__; __THREW__ = 0;
            $130 = $129&1;
            if ($130) {
             break L12;
            } else {
             $$02 = $lpad$phi99$index9;$$08 = $lpad$phi99$index;$$pre$phi110Z2D = $70;
             break L19;
            }
           }
          } else {
           $$1 = 0;$$pre$phiZ2D = $70;
          }
         } else {
          $$pre = (($toWriter) + 1060|0);
          $$1 = 0;$$pre$phiZ2D = $$pre;
         }
        } while(0);
        HEAP32[$toWriter>>2] = ((647904 + 8|0));
        $161 = HEAP8[$$pre$phiZ2D>>0]|0;
        $162 = ($161<<24>>24)==(0);
        if (!($162)) {
         $163 = (($toWriter) + 1048|0);
         $164 = HEAP32[$163>>2]|0;
         $165 = ($164|0)==(0|0);
         if (!($165)) {
          $166 = (($toWriter) + 4|0);
          $167 = HEAP32[$164>>2]|0;
          $168 = (($167) + 28|0);
          $169 = HEAP32[$168>>2]|0;
          __THREW__ = 0;
          (invoke_iii($169|0,($164|0),($166|0))|0);
          $170 = __THREW__; __THREW__ = 0;
          $171 = $170&1;
          if ($171) {
           $181 = ___cxa_find_matching_catch()|0;
           $182 = tempRet0;
           $183 = (($toWriter) + 1044|0);
           $184 = HEAP32[$183>>2]|0;
           $185 = ($184|0)==(0|0);
           if ($185) {
            $eh$lpad$body$index3Z2D = $182;$eh$lpad$body$indexZ2D = $181;
            label = 15;
            break L14;
           }
           $186 = HEAP32[$184>>2]|0;
           $187 = (($186) + 64|0);
           $188 = HEAP32[$187>>2]|0;
           __THREW__ = 0;
           invoke_vii($188|0,($184|0),($166|0));
           $189 = __THREW__; __THREW__ = 0;
           $190 = $189&1;
           if (!($190)) {
            $eh$lpad$body$index3Z2D = $182;$eh$lpad$body$indexZ2D = $181;
            label = 15;
            break L14;
           }
           $191 = ___cxa_find_matching_catch(0|0)|0;
           $192 = tempRet0;
           ___clang_call_terminate($191);
           // unreachable;
          }
         }
        }
        $172 = (($toWriter) + 1044|0);
        $173 = HEAP32[$172>>2]|0;
        $174 = ($173|0)==(0|0);
        if (!($174)) {
         $175 = (($toWriter) + 4|0);
         $176 = HEAP32[$173>>2]|0;
         $177 = (($176) + 64|0);
         $178 = HEAP32[$177>>2]|0;
         __THREW__ = 0;
         invoke_vii($178|0,($173|0),($175|0));
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if ($180) {
          label = 14;
          break L14;
         }
        }
        HEAP32[$fromReader>>2] = ((647904 + 8|0));
        $193 = HEAP8[$44>>0]|0;
        $194 = ($193<<24>>24)==(0);
        if (!($194)) {
         $195 = HEAP32[$36>>2]|0;
         $196 = ($195|0)==(0|0);
         if (!($196)) {
          $197 = HEAP32[$195>>2]|0;
          $198 = (($197) + 28|0);
          $199 = HEAP32[$198>>2]|0;
          __THREW__ = 0;
          (invoke_iii($199|0,($195|0),($30|0))|0);
          $200 = __THREW__; __THREW__ = 0;
          $201 = $200&1;
          if ($201) {
           $207 = ___cxa_find_matching_catch()|0;
           $208 = tempRet0;
           $209 = HEAP32[$33>>2]|0;
           $210 = ($209|0)==(0|0);
           if ($210) {
            ___resumeException($207|0);
            // unreachable;
           }
           $211 = HEAP32[$209>>2]|0;
           $212 = (($211) + 64|0);
           $213 = HEAP32[$212>>2]|0;
           __THREW__ = 0;
           invoke_vii($213|0,($209|0),($30|0));
           $214 = __THREW__; __THREW__ = 0;
           $215 = $214&1;
           if ($215) {
            $216 = ___cxa_find_matching_catch(0|0)|0;
            $217 = tempRet0;
            ___clang_call_terminate($216);
            // unreachable;
           } else {
            ___resumeException($207|0);
            // unreachable;
           }
          }
         }
        }
        $202 = HEAP32[$33>>2]|0;
        $203 = ($202|0)==(0|0);
        if ($203) {
         $$5 = $$1;
         STACKTOP = sp;return ($$5|0);
        }
        $204 = HEAP32[$202>>2]|0;
        $205 = (($204) + 64|0);
        $206 = HEAP32[$205>>2]|0;
        FUNCTION_TABLE_vii[$206 & 4095]($202,$30);
        $$5 = $$1;
        STACKTOP = sp;return ($$5|0);
       }
      }
     } while(0);
     if ((label|0) == 16) {
      $54 = ___cxa_find_matching_catch()|0;
      $55 = tempRet0;
      $$pre109 = (($toWriter) + 1060|0);
      $$02 = $55;$$08 = $54;$$pre$phi110Z2D = $$pre109;
     }
     HEAP32[$toWriter>>2] = ((647904 + 8|0));
     $218 = HEAP8[$$pre$phi110Z2D>>0]|0;
     $219 = ($218<<24>>24)==(0);
     if (!($219)) {
      $220 = (($toWriter) + 1048|0);
      $221 = HEAP32[$220>>2]|0;
      $222 = ($221|0)==(0|0);
      if (!($222)) {
       $223 = (($toWriter) + 4|0);
       $224 = HEAP32[$221>>2]|0;
       $225 = (($224) + 28|0);
       $226 = HEAP32[$225>>2]|0;
       __THREW__ = 0;
       (invoke_iii($226|0,($221|0),($223|0))|0);
       $227 = __THREW__; __THREW__ = 0;
       $228 = $227&1;
       if ($228) {
        $238 = ___cxa_find_matching_catch(0|0)|0;
        $239 = tempRet0;
        $240 = (($toWriter) + 1044|0);
        $241 = HEAP32[$240>>2]|0;
        $242 = ($241|0)==(0|0);
        if ($242) {
         $eh$lpad$body38$indexZ2D = $238;
         ___clang_call_terminate($eh$lpad$body38$indexZ2D);
         // unreachable;
        }
        $243 = HEAP32[$241>>2]|0;
        $244 = (($243) + 64|0);
        $245 = HEAP32[$244>>2]|0;
        __THREW__ = 0;
        invoke_vii($245|0,($241|0),($223|0));
        $246 = __THREW__; __THREW__ = 0;
        $247 = $246&1;
        if ($247) {
         $248 = ___cxa_find_matching_catch(0|0)|0;
         $249 = tempRet0;
         ___clang_call_terminate($248);
         // unreachable;
        } else {
         $eh$lpad$body38$indexZ2D = $238;
         ___clang_call_terminate($eh$lpad$body38$indexZ2D);
         // unreachable;
        }
       }
      }
     }
     $229 = (($toWriter) + 1044|0);
     $230 = HEAP32[$229>>2]|0;
     $231 = ($230|0)==(0|0);
     if ($231) {
      $$13 = $$02;$$19 = $$08;
     } else {
      $232 = (($toWriter) + 4|0);
      $233 = HEAP32[$230>>2]|0;
      $234 = (($233) + 64|0);
      $235 = HEAP32[$234>>2]|0;
      __THREW__ = 0;
      invoke_vii($235|0,($230|0),($232|0));
      $236 = __THREW__; __THREW__ = 0;
      $237 = $236&1;
      if ($237) {
       break L12;
      } else {
       $$13 = $$02;$$19 = $$08;
      }
     }
    }
   } while(0);
   if ((label|0) == 14) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    $eh$lpad$body$index3Z2D = $53;$eh$lpad$body$indexZ2D = $52;
    label = 15;
   }
   if ((label|0) == 15) {
    $$13 = $eh$lpad$body$index3Z2D;$$19 = $eh$lpad$body$indexZ2D;
   }
   HEAP32[$fromReader>>2] = ((647904 + 8|0));
   $250 = (($fromReader) + 1060|0);
   $251 = HEAP8[$250>>0]|0;
   $252 = ($251<<24>>24)==(0);
   if (!($252)) {
    $253 = (($fromReader) + 1048|0);
    $254 = HEAP32[$253>>2]|0;
    $255 = ($254|0)==(0|0);
    if (!($255)) {
     $256 = (($fromReader) + 4|0);
     $257 = HEAP32[$254>>2]|0;
     $258 = (($257) + 28|0);
     $259 = HEAP32[$258>>2]|0;
     __THREW__ = 0;
     (invoke_iii($259|0,($254|0),($256|0))|0);
     $260 = __THREW__; __THREW__ = 0;
     $261 = $260&1;
     if ($261) {
      $271 = ___cxa_find_matching_catch(0|0)|0;
      $272 = tempRet0;
      $273 = (($fromReader) + 1044|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = ($274|0)==(0|0);
      if ($275) {
       $eh$lpad$body38$indexZ2D = $271;
       ___clang_call_terminate($eh$lpad$body38$indexZ2D);
       // unreachable;
      }
      $276 = HEAP32[$274>>2]|0;
      $277 = (($276) + 64|0);
      $278 = HEAP32[$277>>2]|0;
      __THREW__ = 0;
      invoke_vii($278|0,($274|0),($256|0));
      $279 = __THREW__; __THREW__ = 0;
      $280 = $279&1;
      if ($280) {
       $281 = ___cxa_find_matching_catch(0|0)|0;
       $282 = tempRet0;
       ___clang_call_terminate($281);
       // unreachable;
      } else {
       $eh$lpad$body38$indexZ2D = $271;
       ___clang_call_terminate($eh$lpad$body38$indexZ2D);
       // unreachable;
      }
     }
    }
   }
   $262 = (($fromReader) + 1044|0);
   $263 = HEAP32[$262>>2]|0;
   $264 = ($263|0)==(0|0);
   if ($264) {
    $$513 = $$19;$$57 = $$13;
    ___resumeException($$513|0);
    // unreachable;
   }
   $265 = (($fromReader) + 4|0);
   $266 = HEAP32[$263>>2]|0;
   $267 = (($266) + 64|0);
   $268 = HEAP32[$267>>2]|0;
   __THREW__ = 0;
   invoke_vii($268|0,($263|0),($265|0));
   $269 = __THREW__; __THREW__ = 0;
   $270 = $269&1;
   if (!($270)) {
    $$513 = $$19;$$57 = $$13;
    ___resumeException($$513|0);
    // unreachable;
   }
  }
 } while(0);
 $425 = ___cxa_find_matching_catch(0|0)|0;
 $426 = tempRet0;
 $eh$lpad$body38$indexZ2D = $425;
 ___clang_call_terminate($eh$lpad$body38$indexZ2D);
 // unreachable;
 return 0|0;
}
function __ZN12FileAccessor4OpenER15FileSystemEntry14FilePermission16FileAutoBehavior($this,$entry,$permissions,$behavior) {
 $this = $this|0;
 $entry = $entry|0;
 $permissions = $permissions|0;
 $behavior = $behavior|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 (_strncpy(($0|0),($entry|0),1040)|0);
 $1 = (($this) + 1043|0);
 HEAP8[$1>>0] = 0;
 $2 = (($entry) + 1040|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 1044|0);
 HEAP32[$4>>2] = $3;
 $5 = (($entry) + 1044|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 1048|0);
 HEAP32[$7>>2] = $6;
 $8 = ($3|0)==(0|0);
 if ($8) {
  $15 = $6;
 } else {
  $9 = HEAP32[$3>>2]|0;
  $10 = (($9) + 60|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($3,$0);
  $$pre = HEAP32[$7>>2]|0;
  $15 = $$pre;
 }
 $12 = (($this) + 1052|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 1060|0);
 HEAP8[$13>>0] = 1;
 $14 = HEAP32[$15>>2]|0;
 $16 = (($14) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_iiiii[$17 & 511]($15,$0,$permissions,$behavior)|0);
 STACKTOP = sp;return ($18|0);
}
function __ZN12FileAccessor4ReadEyPvPy($this,$0,$1,$buffer,$actual) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $10 = 0;
  STACKTOP = sp;return ($10|0);
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$3>>2]|0;
 $7 = (($6) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiiii[$8 & 255]($3,$5,$0,$1,$buffer,$actual)|0);
 $10 = $9;
 STACKTOP = sp;return ($10|0);
}
function __ZN12FileAccessor5WriteEyPKvPy($this,$0,$1,$buffer,$actual) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $10 = 0;
  STACKTOP = sp;return ($10|0);
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$3>>2]|0;
 $7 = (($6) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiiii[$8 & 255]($3,$5,$0,$1,$buffer,$actual)|0);
 $10 = $9;
 STACKTOP = sp;return ($10|0);
}
function __ZN12FileAccessor5CloseEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1060|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 1048|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($this) + 4|0);
 $7 = HEAP32[$4>>2]|0;
 $8 = (($7) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$9 & 4095]($4,$6)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK15FileSystemEntry6ExistsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $7 = 0;
  STACKTOP = sp;return ($7|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iii[$5 & 4095]($1,$this)|0);
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZNK15FileSystemEntry12FolderExistsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $13 = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 80|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iii[$5 & 4095]($1,$this)|0);
  if ($6) {
   $7 = HEAP32[$0>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $13 = 0;
   } else {
    $9 = HEAP32[$7>>2]|0;
    $10 = (($9) + 156|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (FUNCTION_TABLE_iii[$11 & 4095]($7,$this)|0);
    $13 = $12;
   }
  } else {
   $13 = 0;
  }
 }
 STACKTOP = sp;return ($13|0);
}
function __ZN15FileSystemEntry8IsLockedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $7 = 0;
  STACKTOP = sp;return ($7|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 96|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iii[$5 & 4095]($1,$this)|0);
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZN12FileAccessorC2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $0 = sp;
 HEAP32[$this>>2] = ((647904 + 8|0));
 $1 = (($this) + 4|0);
 $2 = (($this) + 1044|0);
 HEAP8[$1>>0] = 0;
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
 $3 = (($0) + 1040|0);
 HEAP8[$0>>0] = 0;
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 (_strncpy(($1|0),($0|0),1040)|0);
 $4 = (($this) + 1043|0);
 HEAP8[$4>>0] = 0;
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $5;
 $6 = (($0) + 1044|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 1048|0);
 HEAP32[$8>>2] = $7;
 $9 = ($5|0)==(0|0);
 if ($9) {
  $21 = (($this) + 1052|0);
  HEAP32[$21>>2] = 0;
  $22 = (($this) + 1060|0);
  HEAP8[$22>>0] = 0;
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$5>>2]|0;
 $11 = (($10) + 60|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 invoke_vii($12|0,($5|0),($1|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 do {
  if ($14) {
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   $27 = HEAP32[$3>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $$0 = $26;$$01 = $25;
   } else {
    $29 = HEAP32[$27>>2]|0;
    $30 = (($29) + 64|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vii($31|0,($27|0),($0|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     $41 = ___cxa_find_matching_catch(0|0)|0;
     $42 = tempRet0;
     ___clang_call_terminate($41);
     // unreachable;
    } else {
     $$0 = $26;$$01 = $25;
    }
   }
  } else {
   $$pre = HEAP32[$3>>2]|0;
   $15 = ($$pre|0)==(0|0);
   if ($15) {
    $21 = (($this) + 1052|0);
    HEAP32[$21>>2] = 0;
    $22 = (($this) + 1060|0);
    HEAP8[$22>>0] = 0;
    STACKTOP = sp;return;
   }
   $16 = HEAP32[$$pre>>2]|0;
   $17 = (($16) + 64|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vii($18|0,($$pre|0),($0|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $$0 = $24;$$01 = $23;
    break;
   } else {
    $21 = (($this) + 1052|0);
    HEAP32[$21>>2] = 0;
    $22 = (($this) + 1060|0);
    HEAP8[$22>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $34 = HEAP32[$2>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $36 = HEAP32[$34>>2]|0;
 $37 = (($36) + 64|0);
 $38 = HEAP32[$37>>2]|0;
 __THREW__ = 0;
 invoke_vii($38|0,($34|0),($1|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN12FileAccessorD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((647904 + 8|0));
 $0 = (($this) + 1060|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 1048|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($this) + 4|0);
   $7 = HEAP32[$4>>2]|0;
   $8 = (($7) + 28|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   (invoke_iii($9|0,($4|0),($6|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $21 = ___cxa_find_matching_catch()|0;
    $22 = tempRet0;
    $23 = (($this) + 1044|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0|0);
    if ($25) {
     $eh$lpad$body$index3Z2D = $22;$eh$lpad$body$indexZ2D = $21;
     __ZdlPv($this);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
    $26 = HEAP32[$24>>2]|0;
    $27 = (($26) + 64|0);
    $28 = HEAP32[$27>>2]|0;
    __THREW__ = 0;
    invoke_vii($28|0,($24|0),($6|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch(0|0)|0;
     $32 = tempRet0;
     ___clang_call_terminate($31);
     // unreachable;
    } else {
     $eh$lpad$body$index3Z2D = $22;$eh$lpad$body$indexZ2D = $21;
     __ZdlPv($this);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
  }
 }
 $12 = (($this) + 1044|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $15 = (($this) + 4|0);
 $16 = HEAP32[$13>>2]|0;
 $17 = (($16) + 64|0);
 $18 = HEAP32[$17>>2]|0;
 __THREW__ = 0;
 invoke_vii($18|0,($13|0),($15|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if (!($20)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 $eh$lpad$body$index3Z2D = $34;$eh$lpad$body$indexZ2D = $33;
 __ZdlPv($this);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN12FileAccessorD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((647904 + 8|0));
 $0 = (($this) + 1060|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 1048|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($this) + 4|0);
   $7 = HEAP32[$4>>2]|0;
   $8 = (($7) + 28|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   (invoke_iii($9|0,($4|0),($6|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $19 = ___cxa_find_matching_catch()|0;
    $20 = tempRet0;
    $21 = (($this) + 1044|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     ___resumeException($19|0);
     // unreachable;
    }
    $24 = HEAP32[$22>>2]|0;
    $25 = (($24) + 64|0);
    $26 = HEAP32[$25>>2]|0;
    __THREW__ = 0;
    invoke_vii($26|0,($22|0),($6|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $29 = ___cxa_find_matching_catch(0|0)|0;
     $30 = tempRet0;
     ___clang_call_terminate($29);
     // unreachable;
    } else {
     ___resumeException($19|0);
     // unreachable;
    }
   }
  }
 }
 $12 = (($this) + 1044|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 4|0);
 $16 = HEAP32[$13>>2]|0;
 $17 = (($16) + 64|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($13,$15);
 STACKTOP = sp;return;
}
function __ZN12FileAccessor4OpenEPKc14FilePermission16FileAutoBehavior($this,$path,$permissions,$behavior) {
 $this = $this|0;
 $path = $path|0;
 $permissions = $permissions|0;
 $behavior = $behavior|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $item = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $item = sp;
 $0 = (($item) + 1040|0);
 HEAP8[$item>>0] = 0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3249,($item|0),($path|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  $5 = HEAP32[$0>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   ___resumeException($3|0);
   // unreachable;
  }
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 64|0);
  $9 = HEAP32[$8>>2]|0;
  __THREW__ = 0;
  invoke_vii($9|0,($5|0),($item|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch(0|0)|0;
   $13 = tempRet0;
   ___clang_call_terminate($12);
   // unreachable;
  } else {
   ___resumeException($3|0);
   // unreachable;
  }
 }
 $14 = (($this) + 1060|0);
 HEAP8[$14>>0] = 1;
 $15 = (($this) + 4|0);
 (_strncpy(($15|0),($item|0),1040)|0);
 $16 = (($this) + 1043|0);
 HEAP8[$16>>0] = 0;
 $17 = HEAP32[$0>>2]|0;
 $18 = (($this) + 1044|0);
 HEAP32[$18>>2] = $17;
 $19 = (($item) + 1044|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 1048|0);
 HEAP32[$21>>2] = $20;
 $22 = ($17|0)==(0|0);
 if ($22) {
  $30 = $20;
  label = 9;
 } else {
  $23 = HEAP32[$17>>2]|0;
  $24 = (($23) + 60|0);
  $25 = HEAP32[$24>>2]|0;
  __THREW__ = 0;
  invoke_vii($25|0,($17|0),($15|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   $$pre$i = HEAP32[$21>>2]|0;
   $30 = $$pre$i;
   label = 9;
  }
 }
 if ((label|0) == 9) {
  $28 = (($this) + 1052|0);
  HEAP32[$28>>2] = 0;
  HEAP8[$14>>0] = 1;
  $29 = HEAP32[$30>>2]|0;
  $31 = (($29) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  __THREW__ = 0;
  $33 = (invoke_iiiii($32|0,($30|0),($15|0),($permissions|0),($behavior|0))|0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if (!($35)) {
   $36 = HEAP32[$0>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    STACKTOP = sp;return ($33|0);
   }
   $38 = HEAP32[$36>>2]|0;
   $39 = (($38) + 64|0);
   $40 = HEAP32[$39>>2]|0;
   FUNCTION_TABLE_vii[$40 & 4095]($36,$item);
   STACKTOP = sp;return ($33|0);
  }
 }
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 $43 = HEAP32[$0>>2]|0;
 $44 = ($43|0)==(0|0);
 if ($44) {
  ___resumeException($41|0);
  // unreachable;
 }
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + 64|0);
 $47 = HEAP32[$46>>2]|0;
 __THREW__ = 0;
 invoke_vii($47|0,($43|0),($item|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch(0|0)|0;
  $51 = tempRet0;
  ___clang_call_terminate($50);
  // unreachable;
 } else {
  ___resumeException($41|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN12FileAccessor4ReadEyyPvPy($this,$0,$1,$2,$3,$buffer,$actual) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($this) + 1048|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $12 = 0;
  STACKTOP = sp;return ($12|0);
 }
 $7 = (($this) + 4|0);
 $8 = HEAP32[$5>>2]|0;
 $9 = (($8) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiiiiiii[$10 & 63]($5,$7,$0,$1,$2,$3,$buffer,$actual)|0);
 $12 = $11;
 STACKTOP = sp;return ($12|0);
}
function __ZN13FileEntryDataC2ERKS_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_strncpy(($this|0),($other|0),1040)|0);
 $0 = (($this) + 1039|0);
 HEAP8[$0>>0] = 0;
 $1 = (($other) + 1040|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 1040|0);
 HEAP32[$3>>2] = $2;
 $4 = (($other) + 1044|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 1044|0);
 HEAP32[$6>>2] = $5;
 $7 = ($2|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$2>>2]|0;
 $9 = (($8) + 60|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 4095]($2,$this);
 STACKTOP = sp;return;
}
function __ZN13FileEntryDataD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1040|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($1,$this);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignIPS6_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS6_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i11 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i3 = 0, $$012$i$i = 0, $$03$i$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i1 = 0, $$pre$i10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i5 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 12)&-1;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = ($3>>>0)>($10>>>0);
 if ($11) {
  $64 = ($6|0)==(0|0);
  if ($64) {
   $80 = $5;
  } else {
   $65 = (($this) + 4|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==($6|0);
   if ($67) {
    $77 = $6;
   } else {
    $69 = $66;
    while(1) {
     $68 = (($69) + -12|0);
     HEAP32[$65>>2] = $68;
     $70 = HEAP8[$68>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $74 = $68;
     } else {
      $75 = (($69) + -4|0);
      $76 = HEAP32[$75>>2]|0;
      __ZdlPv($76);
      $$pre$i$i$i$i = HEAP32[$65>>2]|0;
      $74 = $$pre$i$i$i$i;
     }
     $73 = ($74|0)==($6|0);
     if ($73) {
      break;
     } else {
      $69 = $74;
     }
    }
    $$pre$i10 = HEAP32[$this>>2]|0;
    $77 = $$pre$i10;
   }
   __ZdlPv($77);
   HEAP32[$4>>2] = 0;
   HEAP32[$65>>2] = 0;
   HEAP32[$this>>2] = 0;
   $80 = 0;
  }
  $78 = ($3>>>0)>(357913941);
  if ($78) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $79 = $80;
  $81 = (($79|0) / 12)&-1;
  $82 = ($81>>>0)<(178956970);
  if ($82) {
   $83 = $81 << 1;
   $84 = ($83>>>0)<($3>>>0);
   $85 = $84 ? $3 : $83;
   $86 = ($85>>>0)>(357913941);
   if ($86) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i11 = $85;
   }
  } else {
   $$0$i11 = 357913941;
  }
  $87 = ($$0$i11*12)|0;
  $88 = (__Znwj($87)|0);
  $89 = (($this) + 4|0);
  HEAP32[$89>>2] = $88;
  HEAP32[$this>>2] = $88;
  $90 = (($88) + (($$0$i11*12)|0)|0);
  HEAP32[$4>>2] = $90;
  $91 = ($__first|0)==($__last|0);
  if ($91) {
   STACKTOP = sp;return;
  } else {
   $$01$i = $__first;$93 = $88;
  }
  L23: while(1) {
   $92 = ($93|0)==(0|0);
   do {
    if (!($92)) {
     $94 = HEAP8[$$01$i>>0]|0;
     $95 = $94 & 1;
     $96 = ($95<<24>>24)==(0);
     if ($96) {
      ;HEAP32[$93+0>>2]=HEAP32[$$01$i+0>>2]|0;HEAP32[$93+4>>2]=HEAP32[$$01$i+4>>2]|0;HEAP32[$93+8>>2]=HEAP32[$$01$i+8>>2]|0;
      break;
     }
     $97 = (($$01$i) + 8|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($$01$i) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = ($100>>>0)>(4294967279);
     if ($101) {
      label = 42;
      break L23;
     }
     $102 = ($100>>>0)<(11);
     if ($102) {
      $103 = $100 << 1;
      $104 = $103&255;
      HEAP8[$93>>0] = $104;
      $105 = (($93) + 1|0);
      $__p$0$i$i$i$i$i = $105;
     } else {
      $106 = (($100) + 16)|0;
      $107 = $106 & -16;
      $108 = (__Znwj($107)|0);
      $109 = (($93) + 8|0);
      HEAP32[$109>>2] = $108;
      $110 = $107 | 1;
      HEAP32[$93>>2] = $110;
      $111 = (($93) + 4|0);
      HEAP32[$111>>2] = $100;
      $__p$0$i$i$i$i$i = $108;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($98|0),($100|0))|0;
     $112 = (($__p$0$i$i$i$i$i) + ($100)|0);
     HEAP8[$112>>0] = 0;
    }
   } while(0);
   $113 = HEAP32[$89>>2]|0;
   $114 = (($113) + 12|0);
   HEAP32[$89>>2] = $114;
   $115 = (($$01$i) + 12|0);
   $116 = ($115|0)==($__last|0);
   if ($116) {
    label = 48;
    break;
   } else {
    $$01$i = $115;$93 = $114;
   }
  }
  if ((label|0) == 42) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  else if ((label|0) == 48) {
   STACKTOP = sp;return;
  }
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 12)&-1;
 $17 = ($3>>>0)>($16>>>0);
 if ($17) {
  $18 = (($__first) + (($16*12)|0)|0);
  $20 = $18;$__growing$0$off0 = 1;
 } else {
  $20 = $__last;$__growing$0$off0 = 0;
 }
 $19 = ($20|0)==($__first|0);
 if ($19) {
  $$0$lcssa$i$i = $6;
 } else {
  $scevgep$i$i = (($20) + -12|0);
  $21 = (0 - ($1))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($21)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $6;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($$03$i$i,$$012$i$i)|0);
   $22 = (($$012$i$i) + 12|0);
   $23 = (($$03$i$i) + 12|0);
   $24 = ($22|0)==($20|0);
   if ($24) {
    break;
   } else {
    $$012$i$i = $22;$$03$i$i = $23;
   }
  }
  $25 = (($uglygep6$i$i>>>0) / 12)&-1;
  $26 = (($25) + 1)|0;
  $scevgep7$i$i = (($6) + (($26*12)|0)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if (!($__growing$0$off0)) {
  $53 = HEAP32[$12>>2]|0;
  $54 = ($53|0)==($$0$lcssa$i$i|0);
  if ($54) {
   STACKTOP = sp;return;
  } else {
   $56 = $53;
  }
  while(1) {
   $55 = (($56) + -12|0);
   HEAP32[$12>>2] = $55;
   $57 = HEAP8[$55>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    $61 = $55;
   } else {
    $62 = (($56) + -4|0);
    $63 = HEAP32[$62>>2]|0;
    __ZdlPv($63);
    $$pre$i$i = HEAP32[$12>>2]|0;
    $61 = $$pre$i$i;
   }
   $60 = ($61|0)==($$0$lcssa$i$i|0);
   if ($60) {
    break;
   } else {
    $56 = $61;
   }
  }
  STACKTOP = sp;return;
 }
 $27 = ($20|0)==($__last|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $$pre$i1 = HEAP32[$12>>2]|0;
 $$01$i3 = $20;$29 = $$pre$i1;
 L63: while(1) {
  $28 = ($29|0)==(0|0);
  do {
   if (!($28)) {
    $30 = HEAP8[$$01$i3>>0]|0;
    $31 = $30 & 1;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     ;HEAP32[$29+0>>2]=HEAP32[$$01$i3+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[$$01$i3+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$$01$i3+8>>2]|0;
     break;
    }
    $33 = (($$01$i3) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($$01$i3) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36>>>0)>(4294967279);
    if ($37) {
     label = 15;
     break L63;
    }
    $38 = ($36>>>0)<(11);
    if ($38) {
     $39 = $36 << 1;
     $40 = $39&255;
     HEAP8[$29>>0] = $40;
     $41 = (($29) + 1|0);
     $__p$0$i$i$i$i$i5 = $41;
    } else {
     $42 = (($36) + 16)|0;
     $43 = $42 & -16;
     $44 = (__Znwj($43)|0);
     $45 = (($29) + 8|0);
     HEAP32[$45>>2] = $44;
     $46 = $43 | 1;
     HEAP32[$29>>2] = $46;
     $47 = (($29) + 4|0);
     HEAP32[$47>>2] = $36;
     $__p$0$i$i$i$i$i5 = $44;
    }
    _memcpy(($__p$0$i$i$i$i$i5|0),($34|0),($36|0))|0;
    $48 = (($__p$0$i$i$i$i$i5) + ($36)|0);
    HEAP8[$48>>0] = 0;
   }
  } while(0);
  $49 = HEAP32[$12>>2]|0;
  $50 = (($49) + 12|0);
  HEAP32[$12>>2] = $50;
  $51 = (($$01$i3) + 12|0);
  $52 = ($51|0)==($__last|0);
  if ($52) {
   label = 48;
   break;
  } else {
   $$01$i3 = $51;$29 = $50;
  }
 }
 if ((label|0) == 15) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 48) {
  STACKTOP = sp;return;
 }
}
function __ZN22LocalFileSystemHandler4NameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (647920|0);
}
function __ZN17FileSystemHandler11HasFastHashERK13FileEntryDataR7Hash128($this,$data,$fastHash) {
 $this = $this|0;
 $data = $data|0;
 $fastHash = $fastHash|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN17FileSystemHandler11MoveToTrashER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 116|0);
 $2 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_iiii[$2 & 2047]($this,$data,1)|0);
 STACKTOP = sp;return 1;
}
function __ZNK17FileSystemHandler12GetAssetGUIDERK13FileEntryData($agg$result,$this,$data) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN17FileSystemHandler5TouchER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK22LocalFileSystemHandler9CanHandleEPKc($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN22LocalFileSystemHandler19InitializeFileEntryER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 1040|0);
 HEAP32[$0>>2] = $this;
 $1 = (($data) + 1044|0);
 HEAP32[$1>>2] = $this;
 STACKTOP = sp;return;
}
function __ZN22LocalFileSystemHandler16DestroyFileEntryER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN22LocalFileSystemHandler16CurrentDirectoryEv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen((647928|0))|0);
 $1 = ($0>>>0)>(4294967279);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = ($0>>>0)<(11);
 if ($2) {
  $3 = $0 << 1;
  $4 = $3&255;
  HEAP8[$agg$result>>0] = $4;
  $5 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $5;
 } else {
  $6 = (($0) + 16)|0;
  $7 = $6 & -16;
  $8 = (__Znwj($7)|0);
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $8;
  $10 = $7 | 1;
  HEAP32[$agg$result>>2] = $10;
  $11 = (($agg$result) + 4|0);
  HEAP32[$11>>2] = $0;
  $__p$0$i$i$i = $8;
 }
 _memcpy(($__p$0$i$i$i|0),(647928|0),($0|0))|0;
 $12 = (($__p$0$i$i$i) + ($0)|0);
 HEAP8[$12>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN22LocalFileSystemHandler19SetCurrentDirectoryERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($agg$result,$newCurrentDirectory) {
 $agg$result = $agg$result|0;
 $newCurrentDirectory = $newCurrentDirectory|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen((647928|0))|0);
 $1 = ($0>>>0)>(4294967279);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = ($0>>>0)<(11);
 if ($2) {
  $3 = $0 << 1;
  $4 = $3&255;
  HEAP8[$agg$result>>0] = $4;
  $5 = (($agg$result) + 1|0);
  $__p$0$i$i$i$i = $5;
 } else {
  $6 = (($0) + 16)|0;
  $7 = $6 & -16;
  $8 = (__Znwj($7)|0);
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $8;
  $10 = $7 | 1;
  HEAP32[$agg$result>>2] = $10;
  $11 = (($agg$result) + 4|0);
  HEAP32[$11>>2] = $0;
  $__p$0$i$i$i$i = $8;
 }
 _memcpy(($__p$0$i$i$i$i|0),(647928|0),($0|0))|0;
 $12 = (($__p$0$i$i$i$i) + ($0)|0);
 HEAP8[$12>>0] = 0;
 $13 = HEAP8[$newCurrentDirectory>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $18 = (($newCurrentDirectory) + 1|0);
  $19 = $18;
  (_strncpy((647928|0),($19|0),1040)|0);
  STACKTOP = sp;return;
 } else {
  $16 = (($newCurrentDirectory) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $19 = $17;
  (_strncpy((647928|0),($19|0),1040)|0);
  STACKTOP = sp;return;
 }
}
function __ZN22LocalFileSystemHandler10ToAbsoluteEPKc($agg$result,$this,$relative) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $relative = $relative|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i3 = 0, $path = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $path = sp + 12|0;
 $0 = sp;
 $1 = (_strlen(($relative|0))|0);
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$path>>0] = $5;
  $6 = (($path) + 1|0);
  $__p$0$i$i$i = $6;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  $10 = (($path) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$path>>2] = $11;
  $12 = (($path) + 4|0);
  HEAP32[$12>>2] = $1;
  $__p$0$i$i$i = $9;
 }
 _memcpy(($__p$0$i$i$i|0),($relative|0),($1|0))|0;
 $13 = (($__p$0$i$i$i) + ($1)|0);
 HEAP8[$13>>0] = 0;
 $14 = HEAP32[$this>>2]|0;
 $15 = (($14) + 56|0);
 $16 = HEAP32[$15>>2]|0;
 __THREW__ = 0;
 $17 = (invoke_iii($16|0,($this|0),($relative|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L8: do {
  if ($19) {
   label = 18;
  } else {
   do {
    if ($17) {
     $20 = HEAP8[$path>>0]|0;
     $21 = $20 & 1;
     $22 = ($21<<24>>24)==(0);
     if ($22) {
      ;HEAP32[$agg$result+0>>2]=HEAP32[$path+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$path+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$path+8>>2]|0;
      break;
     }
     $23 = (($path) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($path) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26>>>0)>(4294967279);
     if ($27) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 18;
       break L8;
      }
      // unreachable;
     }
     $30 = ($26>>>0)<(11);
     if ($30) {
      $31 = $26 << 1;
      $32 = $31&255;
      HEAP8[$agg$result>>0] = $32;
      $33 = (($agg$result) + 1|0);
      $__p$0$i$i$i3 = $33;
     } else {
      $34 = (($26) + 16)|0;
      $35 = $34 & -16;
      __THREW__ = 0;
      $36 = (invoke_ii(2988,($35|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 18;
       break L8;
      }
      $39 = (($agg$result) + 8|0);
      HEAP32[$39>>2] = $36;
      $40 = $35 | 1;
      HEAP32[$agg$result>>2] = $40;
      $41 = (($agg$result) + 4|0);
      HEAP32[$41>>2] = $26;
      $__p$0$i$i$i3 = $36;
     }
     _memcpy(($__p$0$i$i$i3|0),($24|0),($26|0))|0;
     $42 = (($__p$0$i$i$i3) + ($26)|0);
     HEAP8[$42>>0] = 0;
    } else {
     __THREW__ = 0;
     $45 = (invoke_i(105)|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 18;
      break L8;
     }
     __THREW__ = 0;
     invoke_vii(3251,($0|0),($45|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      label = 18;
      break L8;
     }
     __THREW__ = 0;
     invoke_viii(1776,($agg$result|0),($0|0),($path|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      $57 = ___cxa_find_matching_catch()|0;
      $58 = tempRet0;
      $59 = HEAP8[$0>>0]|0;
      $60 = $59 & 1;
      $61 = ($60<<24>>24)==(0);
      if ($61) {
       $$0 = $58;$$01 = $57;
       break L8;
      }
      $62 = (($0) + 8|0);
      $63 = HEAP32[$62>>2]|0;
      __ZdlPv($63);
      $$0 = $58;$$01 = $57;
      break L8;
     } else {
      $52 = HEAP8[$0>>0]|0;
      $53 = $52 & 1;
      $54 = ($53<<24>>24)==(0);
      if ($54) {
       break;
      }
      $55 = (($0) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      __ZdlPv($56);
      break;
     }
    }
   } while(0);
   $64 = HEAP8[$path>>0]|0;
   $65 = $64 & 1;
   $66 = ($65<<24>>24)==(0);
   if ($66) {
    STACKTOP = sp;return;
   }
   $67 = (($path) + 8|0);
   $68 = HEAP32[$67>>2]|0;
   __ZdlPv($68);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 18) {
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  $$0 = $44;$$01 = $43;
 }
 $69 = HEAP8[$path>>0]|0;
 $70 = $69 & 1;
 $71 = ($70<<24>>24)==(0);
 if ($71) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $72 = (($path) + 8|0);
 $73 = HEAP32[$72>>2]|0;
 __ZdlPv($73);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN22LocalFileSystemHandler18IsAbsoluteFilePathEPKc($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $0 = 0, $strlenfirst = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $strlenfirst = HEAP8[$path>>0]|0;
 $0 = ($strlenfirst<<24>>24)==(47);
 STACKTOP = sp;return ($0|0);
}
function __ZN22LocalFileSystemHandler16LastErrorMessageEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0] = 0;
 $0 = (($agg$result) + 1|0);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN22LocalFileSystemHandler9LastErrorEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN22LocalFileSystemHandler9MakeLocalER13FileEntryDatab($this,$data,$overwriteIfAlreadyExistsLocaly) {
 $this = $this|0;
 $data = $data|0;
 $overwriteIfAlreadyExistsLocaly = $overwriteIfAlreadyExistsLocaly|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($overwriteIfAlreadyExistsLocaly) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 4095]($this,$data)|0);
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __ZN17FileSystemHandler10AtomicMoveER13FileEntryDataS1_($this,$from,$to) {
 $this = $this|0;
 $from = $from|0;
 $to = $to|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE6appendEjc($this,$__n,$__c) {
 $this = $this|0;
 $__n = $__n|0;
 $__c = $__c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)==(0);
 if ($0) {
  STACKTOP = sp;return ($this|0);
 }
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $15 = 10;$8 = $1;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 & -2;
  $phitmp$i = (($5) + -1)|0;
  $6 = $4&255;
  $15 = $phitmp$i;$8 = $6;
 }
 $7 = $8 & 1;
 $9 = ($7<<24>>24)==(0);
 if ($9) {
  $12 = $8&255;
  $13 = $12 >>> 1;
  $16 = $13;
 } else {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $16 = $11;
 }
 $14 = (($15) - ($16))|0;
 $17 = ($14>>>0)<($__n>>>0);
 if ($17) {
  $18 = (($__n) - ($15))|0;
  $19 = (($18) + ($16))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE9__grow_byEjjjjjj($this,$15,$19,$16,$16,0,0);
  $$pre = HEAP8[$this>>0]|0;
  $21 = $$pre;
 } else {
  $21 = $8;
 }
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($22) {
  $25 = (($this) + 1|0);
  $27 = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $27 = $24;
 }
 $26 = (($27) + ($16)|0);
 _memset(($26|0),($__c|0),($__n|0))|0;
 $28 = (($16) + ($__n))|0;
 $29 = HEAP8[$this>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $33 = $28 << 1;
  $34 = $33&255;
  HEAP8[$this>>0] = $34;
 } else {
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $28;
 }
 $35 = (($27) + ($28)|0);
 HEAP8[$35>>0] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE9__grow_byEjjjjjj($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 var $$byval_copy1 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (2147483631 - ($__old_cap))|0;
 $2 = ($1>>>0)<($__delta_cap>>>0);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = HEAP8[$this>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($this) + 1|0);
  $20 = $8;
 } else {
  $6 = (($this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $20 = $7;
 }
 $9 = ($__old_cap>>>0)<(1073741799);
 if ($9) {
  $10 = (($__delta_cap) + ($__old_cap))|0;
  $11 = $__old_cap << 1;
  $12 = ($10>>>0)<($11>>>0);
  $13 = $12 ? $11 : $10;
  $14 = ($13>>>0)<(11);
  if ($14) {
   $17 = 11;
  } else {
   $15 = (($13) + 16)|0;
   $16 = $15 & -16;
   $17 = $16;
  }
 } else {
  $17 = 2147483631;
 }
 HEAP32[$0>>2] = 46;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($17,16,$$byval_copy1,0,650008,79)|0);
 $19 = ($__n_copy|0)==(0);
 if (!($19)) {
  _memcpy(($18|0),($20|0),($__n_copy|0))|0;
 }
 $21 = (($__old_sz) - ($__n_del))|0;
 $22 = ($21|0)==($__n_copy|0);
 if (!($22)) {
  $23 = (($21) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $24 = (($18) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $25 = (($20) + ($$sum1)|0);
  _memcpy(($24|0),($25|0),($23|0))|0;
 }
 $26 = ($__old_cap|0)==(10);
 if ($26) {
  $31 = (($this) + 8|0);
  HEAP32[$31>>2] = $18;
  $32 = $17 | 1;
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($20|0),($$byval_copy1|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  ___cxa_call_unexpected(($29|0));
  // unreachable;
 } else {
  $31 = (($this) + 8|0);
  HEAP32[$31>>2] = $18;
  $32 = $17 | 1;
  HEAP32[$this>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN16MemoryFileSystemC2EPKc($this,$mountPoint) {
 $this = $this|0;
 $mountPoint = $mountPoint|0;
 var $$0 = 0, $$01 = 0, $$byval_copy1 = 0, $$in = 0, $$in6 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((650016 + 8|0));
 $2 = (($this) + 4|0);
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 8|0);
 HEAP32[$2>>2] = $5;
 $6 = (($this) + 20|0);
 $7 = (_strlen(($mountPoint|0))|0);
 $8 = ($7>>>0)>(2147483631);
 do {
  if ($8) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 24;
   } else {
    // unreachable;
   }
  } else {
   $11 = ($7>>>0)<(11);
   if ($11) {
    $12 = $7 << 1;
    $13 = $12&255;
    HEAP8[$6>>0] = $13;
    $14 = (($6) + 1|0);
    $$pre$phiZ2D = $6;$__p$0$i$i$i = $14;
   } else {
    $15 = (($7) + 16)|0;
    $16 = $15 & -16;
    HEAP32[$1>>2] = 46;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $17 = (invoke_iiiiiii(102,($16|0),16,($$byval_copy1|0),0,(650184|0),79)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 24;
     break;
    }
    $20 = (($this) + 28|0);
    HEAP32[$20>>2] = $17;
    $21 = $16 | 1;
    HEAP32[$6>>2] = $21;
    $22 = (($this) + 24|0);
    HEAP32[$22>>2] = $7;
    $$pre$phiZ2D = $6;$__p$0$i$i$i = $17;
   }
   _memcpy(($__p$0$i$i$i|0),($mountPoint|0),($7|0))|0;
   $23 = (($__p$0$i$i$i) + ($7)|0);
   HEAP8[$23>>0] = 0;
   $24 = HEAP8[$$pre$phiZ2D>>0]|0;
   $25 = $24 & 1;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    $29 = $24&255;
    $30 = $29 >>> 1;
    $32 = $30;
   } else {
    $27 = (($this) + 24|0);
    $28 = HEAP32[$27>>2]|0;
    $32 = $28;
   }
   $31 = ($32|0)==(0);
   do {
    if ($31) {
     label = 28;
    } else {
     if ($26) {
      $37 = $24&255;
      $38 = $37 >>> 1;
      $39 = (($6) + 1|0);
      $$in = $38;$42 = $39;
     } else {
      $33 = (($this) + 24|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($this) + 28|0);
      $36 = HEAP32[$35>>2]|0;
      $$in = $34;$42 = $36;
     }
     $40 = (($$in) + -1)|0;
     $41 = (($42) + ($40)|0);
     $43 = HEAP8[$41>>0]|0;
     $44 = ($43<<24>>24)==(47);
     if ($44) {
      if ($26) {
       $47 = $24&255;
       $48 = $47 >>> 1;
       $49 = $24&255;
       $50 = $49 >>> 1;
       $$in6 = $48;$53 = $50;
      } else {
       $45 = (($this) + 24|0);
       $46 = HEAP32[$45>>2]|0;
       $$in6 = $46;$53 = $46;
      }
      $51 = (($$in6) + -1)|0;
      $52 = ($53>>>0)<($51>>>0);
      if ($52) {
       $54 = (($51) - ($53))|0;
       __THREW__ = 0;
       (invoke_iiii(1564,($6|0),($54|0),0)|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       } else {
        label = 28;
        break;
       }
      }
      if ($26) {
       $61 = ((($6) + ($51)|0) + 1|0);
       HEAP8[$61>>0] = 0;
       $62 = $51 << 1;
       $63 = $62&255;
       HEAP8[$$pre$phiZ2D>>0] = $63;
       label = 28;
       break;
      } else {
       $57 = (($this) + 28|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($58) + ($51)|0);
       HEAP8[$59>>0] = 0;
       $60 = (($this) + 24|0);
       HEAP32[$60>>2] = $51;
       label = 28;
       break;
      }
     } else {
      label = 28;
     }
    }
   } while(0);
   if ((label|0) == 28) {
    __THREW__ = 0;
    (invoke_iiii(1565,($this|0),(650184|0),1)|0);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if (!($78)) {
     STACKTOP = sp;return;
    }
   }
   $66 = ___cxa_find_matching_catch()|0;
   $67 = tempRet0;
   $68 = HEAP8[$$pre$phiZ2D>>0]|0;
   $69 = $68 & 1;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    $$0 = $67;$$01 = $66;
   } else {
    $71 = (($this) + 28|0);
    $72 = HEAP32[$71>>2]|0;
    HEAP32[$0>>2] = 46;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($72|0),($$byval_copy1|0));
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if ($74) {
     $75 = ___cxa_find_matching_catch()|0;
     $76 = tempRet0;
     ___cxa_call_unexpected(($75|0));
     // unreachable;
    } else {
     $$0 = $67;$$01 = $66;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $64 = ___cxa_find_matching_catch()|0;
  $65 = tempRet0;
  $$0 = $65;$$01 = $64;
 }
 $79 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE7destroyEPNS_11__tree_nodeISC_PvEE($2,$79);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN16MemoryFileSystem16FindNodeOrCreateEPKcb($this,$path,$dir) {
 $this = $this|0;
 $path = $path|0;
 $dir = $dir|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy19 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$phiZ2D = 0, $$pre11$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $__parent$i$i = 0, $__r$0$i$i = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var $goodPath = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy19 = sp + 108|0;
 $0 = sp + 104|0;
 $1 = sp + 100|0;
 $2 = sp + 96|0;
 $3 = sp + 92|0;
 $4 = sp + 88|0;
 $__parent$i$i = sp + 84|0;
 $5 = sp + 72|0;
 $6 = sp + 68|0;
 $7 = sp + 48|0;
 $8 = sp + 44|0;
 $goodPath = sp + 32|0;
 $9 = sp + 16|0;
 $10 = sp + 12|0;
 $11 = sp + 8|0;
 $12 = sp + 64|0;
 $13 = sp;
 ;HEAP32[$goodPath+0>>2]=0|0;HEAP32[$goodPath+4>>2]=0|0;HEAP32[$goodPath+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($path|0),($goodPath|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 L1: do {
  if ($15) {
   label = 37;
  } else {
   $16 = HEAP8[$goodPath>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    ;HEAP32[$9+0>>2]=HEAP32[$goodPath+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$goodPath+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$goodPath+8>>2]|0;
    $$pre = HEAP8[$9>>0]|0;
    $$pre$phiZ2D = $9;$43 = $$pre;
   } else {
    $19 = (($goodPath) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($goodPath) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22>>>0)>(2147483631);
    if ($23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 37;
      break;
     }
     // unreachable;
    }
    $26 = ($22>>>0)<(11);
    if ($26) {
     $27 = $22 << 1;
     $28 = $27&255;
     HEAP8[$9>>0] = $28;
     $29 = (($9) + 1|0);
     $$pre11$pre$phiZZ2D = $9;$185 = $28;$__p$0$i$i$i$i$i = $29;
    } else {
     $30 = (($22) + 16)|0;
     $31 = $30 & -16;
     HEAP32[$8>>2] = 46;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$8+0>>2]|0;
     $32 = (invoke_iiiiiii(102,($31|0),16,($$byval_copy19|0),0,(650184|0),79)|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      label = 37;
      break;
     }
     $35 = (($9) + 8|0);
     HEAP32[$35>>2] = $32;
     $36 = $31 | 1;
     HEAP32[$9>>2] = $36;
     $37 = (($9) + 4|0);
     HEAP32[$37>>2] = $22;
     $38 = $36&255;
     $$pre11$pre$phiZZ2D = $9;$185 = $38;$__p$0$i$i$i$i$i = $32;
    }
    _memcpy(($__p$0$i$i$i$i$i|0),($20|0),($22|0))|0;
    $39 = (($__p$0$i$i$i$i$i) + ($22)|0);
    HEAP8[$39>>0] = 0;
    $$pre$phiZ2D = $$pre11$pre$phiZZ2D;$43 = $185;
   }
   $40 = (($9) + 12|0);
   HEAP32[$40>>2] = 0;
   $41 = (($this) + 4|0);
   $42 = $43 & 1;
   $44 = ($42<<24>>24)==(0);
   L16: do {
    if ($44) {
     ;HEAP32[$7+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
     label = 22;
    } else {
     $45 = (($9) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($9) + 4|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48>>>0)>(2147483631);
     do {
      if ($49) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if (!($51)) {
        // unreachable;
       }
      } else {
       $52 = ($48>>>0)<(11);
       if ($52) {
        $53 = $48 << 1;
        $54 = $53&255;
        HEAP8[$7>>0] = $54;
        $55 = (($7) + 1|0);
        $__p$0$i$i$i$i$i$i$i$i = $55;
       } else {
        $56 = (($48) + 16)|0;
        $57 = $56 & -16;
        HEAP32[$6>>2] = 46;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$6+0>>2]|0;
        $58 = (invoke_iiiiiii(102,($57|0),16,($$byval_copy19|0),0,(650184|0),79)|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        $61 = (($7) + 8|0);
        HEAP32[$61>>2] = $58;
        $62 = $57 | 1;
        HEAP32[$7>>2] = $62;
        $63 = (($7) + 4|0);
        HEAP32[$63>>2] = $48;
        $__p$0$i$i$i$i$i$i$i$i = $58;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($46|0),($48|0))|0;
       $64 = (($__p$0$i$i$i$i$i$i$i$i) + ($48)|0);
       HEAP8[$64>>0] = 0;
       label = 22;
       break L16;
      }
     } while(0);
     $118 = ___cxa_find_matching_catch()|0;
     $119 = tempRet0;
     $eh$lpad$body$index3Z2D = $119;$eh$lpad$body$indexZ2D = $118;
    }
   } while(0);
   L29: do {
    if ((label|0) == 22) {
     $65 = (($7) + 12|0);
     HEAP32[$65>>2] = 0;
     $66 = (__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE12__find_equalISC_EERPNS_16__tree_node_baseIPvEESO_RKT_($41,$__parent$i$i,$7)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($67|0)==(0|0);
     do {
      if ($68) {
       __THREW__ = 0;
       invoke_viii(1938,($5|0),($41|0),($7|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        $93 = ___cxa_find_matching_catch()|0;
        $94 = tempRet0;
        $95 = HEAP8[$7>>0]|0;
        $96 = $95 & 1;
        $97 = ($96<<24>>24)==(0);
        if ($97) {
         $eh$lpad$body$index3Z2D = $94;$eh$lpad$body$indexZ2D = $93;
         break L29;
        }
        $98 = (($7) + 8|0);
        $99 = HEAP32[$98>>2]|0;
        HEAP32[$3>>2] = 46;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($99|0),($$byval_copy19|0));
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if (!($101)) {
         $eh$lpad$body$index3Z2D = $94;$eh$lpad$body$indexZ2D = $93;
         break L29;
        }
        $102 = ___cxa_find_matching_catch()|0;
        $103 = tempRet0;
        ___cxa_call_unexpected(($102|0));
        // unreachable;
       } else {
        $71 = HEAP32[$5>>2]|0;
        HEAP32[$5>>2] = 0;
        $72 = HEAP32[$__parent$i$i>>2]|0;
        HEAP32[$71>>2] = 0;
        $73 = (($71) + 4|0);
        HEAP32[$73>>2] = 0;
        $74 = (($71) + 8|0);
        HEAP32[$74>>2] = $72;
        HEAP32[$66>>2] = $71;
        $75 = HEAP32[$41>>2]|0;
        $76 = HEAP32[$75>>2]|0;
        $77 = ($76|0)==(0|0);
        if ($77) {
         $80 = $71;
        } else {
         HEAP32[$41>>2] = $76;
         $$pre$i$i$i = HEAP32[$66>>2]|0;
         $80 = $$pre$i$i$i;
        }
        $78 = (($this) + 8|0);
        $79 = HEAP32[$78>>2]|0;
        __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($79,$80);
        $81 = (($this) + 12|0);
        $82 = HEAP32[$81>>2]|0;
        $83 = (($82) + 1)|0;
        HEAP32[$81>>2] = $83;
        $__r$0$i$i = $71;
        break;
       }
      } else {
       $__r$0$i$i = $67;
      }
     } while(0);
     $84 = HEAP8[$7>>0]|0;
     $85 = $84 & 1;
     $86 = ($85<<24>>24)==(0);
     if (!($86)) {
      $87 = (($7) + 8|0);
      $88 = HEAP32[$87>>2]|0;
      HEAP32[$4>>2] = 46;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
      invoke_vii(2591,($88|0),($$byval_copy19|0));
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      if ($90) {
       $91 = ___cxa_find_matching_catch()|0;
       $92 = tempRet0;
       ___cxa_call_unexpected(($91|0));
       // unreachable;
      }
     }
     $104 = HEAP8[$$pre$phiZ2D>>0]|0;
     $105 = $104 & 1;
     $106 = ($105<<24>>24)==(0);
     if (!($106)) {
      $107 = (($9) + 8|0);
      $108 = HEAP32[$107>>2]|0;
      HEAP32[$2>>2] = 46;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($108|0),($$byval_copy19|0));
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       $111 = ___cxa_find_matching_catch()|0;
       $112 = tempRet0;
       ___cxa_call_unexpected(($111|0));
       // unreachable;
      }
     }
     $113 = (($__r$0$i$i) + 28|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = ($114|0)==(0|0);
     if ($115) {
      $129 = HEAP32[628408>>2]|0;
      HEAP32[$10>>2] = $129;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$10+0>>2]|0;
      $130 = (invoke_iiiiiii(103,12,($$byval_copy19|0),0,16,(650184|0),540)|0);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       label = 37;
       break L1;
      }
      HEAP32[$130>>2] = 0;
      $133 = (($130) + 4|0);
      __THREW__ = 0;
      invoke_vi(3585,($133|0));
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       $157 = ___cxa_find_matching_catch()|0;
       $158 = tempRet0;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$10+0>>2]|0;
       invoke_viiiiii(97,($130|0),($$byval_copy19|0),0,16,(650184|0),540);
       $159 = __THREW__; __THREW__ = 0;
       $160 = $159&1;
       if (!($160)) {
        $$01 = $157;$$02 = $158;
        break L1;
       }
       $183 = ___cxa_find_matching_catch(0|0)|0;
       $184 = tempRet0;
       ___clang_call_terminate($183);
       // unreachable;
      }
      if ($dir) {
       $144 = 0;
      } else {
       $136 = HEAP32[628408>>2]|0;
       HEAP32[$11>>2] = $136;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$11+0>>2]|0;
       $137 = (invoke_iiiiiii(103,40,($$byval_copy19|0),0,16,(650184|0),541)|0);
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if ($139) {
        label = 37;
        break L1;
       }
       $140 = HEAP32[628408>>2]|0;
       HEAP32[$12>>2] = $140;
       $141 = HEAP32[650272>>2]|0;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$12+0>>2]|0;
       invoke_viii(1939,($137|0),($$byval_copy19|0),($141|0));
       $142 = __THREW__; __THREW__ = 0;
       $143 = $142&1;
       if ($143) {
        $161 = ___cxa_find_matching_catch()|0;
        $162 = tempRet0;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$11+0>>2]|0;
        invoke_viiiiii(97,($137|0),($$byval_copy19|0),0,16,(650184|0),541);
        $163 = __THREW__; __THREW__ = 0;
        $164 = $163&1;
        if (!($164)) {
         $$01 = $161;$$02 = $162;
         break L1;
        }
        $183 = ___cxa_find_matching_catch(0|0)|0;
        $184 = tempRet0;
        ___clang_call_terminate($183);
        // unreachable;
       } else {
        $144 = $137;
       }
      }
      HEAP32[$130>>2] = $144;
      __THREW__ = 0;
      invoke_vi(3585,($13|0));
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       label = 37;
       break L1;
      }
      $147 = $13;
      $148 = $147;
      $149 = HEAP32[$148>>2]|0;
      $150 = (($147) + 4)|0;
      $151 = $150;
      $152 = HEAP32[$151>>2]|0;
      $153 = $133;
      $154 = $153;
      HEAP32[$154>>2] = $149;
      $155 = (($153) + 4)|0;
      $156 = $155;
      HEAP32[$156>>2] = $152;
      HEAP32[$113>>2] = $130;
      $$0 = $130;
     } else {
      $$0 = $114;
     }
     $165 = HEAP8[$goodPath>>0]|0;
     $166 = $165 & 1;
     $167 = ($166<<24>>24)==(0);
     if ($167) {
      STACKTOP = sp;return ($$0|0);
     }
     $168 = (($goodPath) + 8|0);
     $169 = HEAP32[$168>>2]|0;
     HEAP32[$0>>2] = 46;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($169|0),($$byval_copy19|0));
     $170 = __THREW__; __THREW__ = 0;
     $171 = $170&1;
     if ($171) {
      $172 = ___cxa_find_matching_catch()|0;
      $173 = tempRet0;
      ___cxa_call_unexpected(($172|0));
      // unreachable;
     } else {
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $120 = HEAP8[$$pre$phiZ2D>>0]|0;
   $121 = $120 & 1;
   $122 = ($121<<24>>24)==(0);
   if ($122) {
    $$01 = $eh$lpad$body$indexZ2D;$$02 = $eh$lpad$body$index3Z2D;
   } else {
    $123 = (($9) + 8|0);
    $124 = HEAP32[$123>>2]|0;
    HEAP32[$1>>2] = 46;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($124|0),($$byval_copy19|0));
    $125 = __THREW__; __THREW__ = 0;
    $126 = $125&1;
    if ($126) {
     $127 = ___cxa_find_matching_catch()|0;
     $128 = tempRet0;
     ___cxa_call_unexpected(($127|0));
     // unreachable;
    } else {
     $$01 = $eh$lpad$body$indexZ2D;$$02 = $eh$lpad$body$index3Z2D;
    }
   }
  }
 } while(0);
 if ((label|0) == 37) {
  $116 = ___cxa_find_matching_catch()|0;
  $117 = tempRet0;
  $$01 = $116;$$02 = $117;
 }
 $174 = HEAP8[$goodPath>>0]|0;
 $175 = $174 & 1;
 $176 = ($175<<24>>24)==(0);
 if ($176) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $177 = (($goodPath) + 8|0);
 $178 = HEAP32[$177>>2]|0;
 HEAP32[$0>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($178|0),($$byval_copy19|0));
 $179 = __THREW__; __THREW__ = 0;
 $180 = $179&1;
 if ($180) {
  $181 = ___cxa_find_matching_catch()|0;
  $182 = tempRet0;
  ___cxa_call_unexpected(($181|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN16MemoryFileSystemD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1176,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN16MemoryFileSystemD2Ev($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((650016 + 8|0));
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = ($4|0)==($5|0);
 L1: do {
  if (!($6)) {
   $8 = $4;
   while(1) {
    $7 = (($8) + 28|0);
    $9 = HEAP32[$7>>2]|0;
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = HEAP32[628408>>2]|0;
     $13 = (($10) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($14) + -1)|0;
     HEAP32[$13>>2] = $15;
     $16 = HEAP32[$13>>2]|0;
     $17 = ($16|0)==(0);
     if ($17) {
      $18 = HEAP32[$10>>2]|0;
      $19 = HEAP32[$18>>2]|0;
      __THREW__ = 0;
      invoke_vi($19|0,($10|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      HEAP32[$1>>2] = $12;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($10|0),($$byval_copy3|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
     }
    }
    $36 = HEAP32[$7>>2]|0;
    $37 = HEAP32[628408>>2]|0;
    HEAP32[$2>>2] = $37;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($36|0),($$byval_copy3|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    HEAP32[$7>>2] = 0;
    $40 = (($8) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     $$01$i$i$i = $8;
     while(1) {
      $45 = (($$01$i$i$i) + 8|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = HEAP32[$46>>2]|0;
      $48 = ($47|0)==($$01$i$i$i|0);
      if ($48) {
       $$0$i$i$i = $46;
       break;
      } else {
       $$01$i$i$i = $46;
      }
     }
    } else {
     $$0$i$i$i$i = $41;
     while(1) {
      $43 = HEAP32[$$0$i$i$i$i>>2]|0;
      $44 = ($43|0)==(0|0);
      if ($44) {
       $$0$i$i$i = $$0$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i = $43;
      }
     }
    }
    $49 = ($$0$i$i$i|0)==($5|0);
    if ($49) {
     break L1;
    } else {
     $8 = $$0$i$i$i;
    }
   }
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $26 = (($this) + 20|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27 & 1;
   $29 = ($28<<24>>24)==(0);
   if ($29) {
    $62 = (($this) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE7destroyEPNS_11__tree_nodeISC_PvEE($3,$63);
    ___resumeException($24|0);
    // unreachable;
   }
   $30 = (($this) + 28|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[$0>>2] = 46;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($31|0),($$byval_copy3|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    $34 = ___cxa_find_matching_catch()|0;
    $35 = tempRet0;
    ___cxa_call_unexpected(($34|0));
    // unreachable;
   } else {
    $62 = (($this) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE7destroyEPNS_11__tree_nodeISC_PvEE($3,$63);
    ___resumeException($24|0);
    // unreachable;
   }
  }
 } while(0);
 $50 = (($this) + 20|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = $51 & 1;
 $53 = ($52<<24>>24)==(0);
 if ($53) {
  $60 = (($this) + 8|0);
  $61 = HEAP32[$60>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE7destroyEPNS_11__tree_nodeISC_PvEE($3,$61);
  STACKTOP = sp;return;
 }
 $54 = (($this) + 28|0);
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$0>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($55|0),($$byval_copy3|0));
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $58 = ___cxa_find_matching_catch()|0;
  $59 = tempRet0;
  ___cxa_call_unexpected(($58|0));
  // unreachable;
 } else {
  $60 = (($this) + 8|0);
  $61 = HEAP32[$60>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE7destroyEPNS_11__tree_nodeISC_PvEE($3,$61);
  STACKTOP = sp;return;
 }
}
function __ZNK16MemoryFileSystem7IsEmptyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 STACKTOP = sp;return ($2|0);
}
function __ZNK16MemoryFileSystem9CanHandleEPKc($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 $8 = (_strstr($path,$7)|0);
 $not$ = ($8|0)!=(0|0);
 STACKTOP = sp;return ($not$|0);
}
function __ZN16MemoryFileSystem19InitializeFileEntryER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 1040|0);
 HEAP32[$0>>2] = $this;
 $1 = (($data) + 1044|0);
 HEAP32[$1>>2] = $this;
 STACKTOP = sp;return;
}
function __ZN16MemoryFileSystem16DestroyFileEntryER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16MemoryFileSystem10ToAbsoluteEPKc($agg$result,$this,$relative) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $relative = $relative|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (($this) + 20|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($2) + 1|0);
  $9 = $8;
 } else {
  $6 = (($this) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $9 = $7;
 }
 $10 = (_strlen(($9|0))|0);
 $11 = ($10>>>0)>(4294967279);
 if ($11) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $12 = ($10>>>0)<(11);
 if ($12) {
  $13 = $10 << 1;
  $14 = $13&255;
  HEAP8[$0>>0] = $14;
  $15 = (($0) + 1|0);
  $__p$0$i$i$i = $15;
 } else {
  $16 = (($10) + 16)|0;
  $17 = $16 & -16;
  $18 = (__Znwj($17)|0);
  $19 = (($0) + 8|0);
  HEAP32[$19>>2] = $18;
  $20 = $17 | 1;
  HEAP32[$0>>2] = $20;
  $21 = (($0) + 4|0);
  HEAP32[$21>>2] = $10;
  $__p$0$i$i$i = $18;
 }
 _memcpy(($__p$0$i$i$i|0),($9|0),($10|0))|0;
 $22 = (($__p$0$i$i$i) + ($10)|0);
 HEAP8[$22>>0] = 0;
 $23 = (_strlen(($relative|0))|0);
 $24 = ($23>>>0)>(4294967279);
 do {
  if ($24) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 22;
   } else {
    // unreachable;
   }
  } else {
   $27 = ($23>>>0)<(11);
   if ($27) {
    $28 = $23 << 1;
    $29 = $28&255;
    HEAP8[$1>>0] = $29;
    $30 = (($1) + 1|0);
    $__p$0$i$i$i3 = $30;
   } else {
    $31 = (($23) + 16)|0;
    $32 = $31 & -16;
    __THREW__ = 0;
    $33 = (invoke_ii(2988,($32|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 22;
     break;
    }
    $36 = (($1) + 8|0);
    HEAP32[$36>>2] = $33;
    $37 = $32 | 1;
    HEAP32[$1>>2] = $37;
    $38 = (($1) + 4|0);
    HEAP32[$38>>2] = $23;
    $__p$0$i$i$i3 = $33;
   }
   _memcpy(($__p$0$i$i$i3|0),($relative|0),($23|0))|0;
   $39 = (($__p$0$i$i$i3) + ($23)|0);
   HEAP8[$39>>0] = 0;
   __THREW__ = 0;
   invoke_viii(1776,($agg$result|0),($0|0),($1|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if ($41) {
    $54 = ___cxa_find_matching_catch()|0;
    $55 = tempRet0;
    $56 = HEAP8[$1>>0]|0;
    $57 = $56 & 1;
    $58 = ($57<<24>>24)==(0);
    if ($58) {
     $$0 = $55;$$01 = $54;
     break;
    }
    $59 = (($1) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    __ZdlPv($60);
    $$0 = $55;$$01 = $54;
    break;
   }
   $42 = HEAP8[$1>>0]|0;
   $43 = $42 & 1;
   $44 = ($43<<24>>24)==(0);
   if (!($44)) {
    $45 = (($1) + 8|0);
    $46 = HEAP32[$45>>2]|0;
    __ZdlPv($46);
   }
   $47 = HEAP8[$0>>0]|0;
   $48 = $47 & 1;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    STACKTOP = sp;return;
   }
   $50 = (($0) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   __ZdlPv($51);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 22) {
  $52 = ___cxa_find_matching_catch()|0;
  $53 = tempRet0;
  $$0 = $53;$$01 = $52;
 }
 $61 = HEAP8[$0>>0]|0;
 $62 = $61 & 1;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $64 = (($0) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 __ZdlPv($65);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN16MemoryFileSystem18IsAbsoluteFilePathEPKc($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $8 = (($0) + 1|0);
  $9 = $1&255;
  $10 = $9 >>> 1;
  $11 = $8;$12 = $10;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $11 = $5;$12 = $7;
 }
 $13 = (_strncmp($path,$11,$12)|0);
 $14 = ($13|0)==(0);
 STACKTOP = sp;return ($14|0);
}
function __ZN16MemoryFileSystem4OpenER13FileEntryData14FilePermission16FileAutoBehavior($this,$data,$permissions,$behavior) {
 $this = $this|0;
 $data = $data|0;
 $permissions = $permissions|0;
 $behavior = $behavior|0;
 var $$0 = 0, $$0$i = 0, $$2 = 0, $$24 = 0, $$byval_copy15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var $file$2 = 0, $file$212 = 0, $goodPath$i = 0, $it$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy15 = sp + 40|0;
 $0 = sp + 36|0;
 $1 = sp + 32|0;
 $goodPath$i = sp + 20|0;
 $it$i = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = sp + 12|0;
 L1: do {
  if ((($permissions|0) == 0)) {
   ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viii(1937,($this|0),($data|0),($goodPath$i|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   do {
    if ($7) {
     $14 = ___cxa_find_matching_catch()|0;
     $15 = tempRet0;
     $16 = HEAP8[$goodPath$i>>0]|0;
     $17 = $16 & 1;
     $18 = ($17<<24>>24)==(0);
     if ($18) {
      $eh$lpad$body$index3Z2D = $15;$eh$lpad$body$indexZ2D = $14;
     } else {
      $19 = (($goodPath$i) + 8|0);
      $20 = HEAP32[$19>>2]|0;
      HEAP32[$0>>2] = 46;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($20|0),($$byval_copy15|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       ___cxa_call_unexpected(($23|0));
       // unreachable;
      } else {
       $eh$lpad$body$index3Z2D = $15;$eh$lpad$body$indexZ2D = $14;
      }
     }
    } else {
     $8 = (($this) + 4|0);
     __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$8,$goodPath$i);
     $9 = (($this) + 8|0);
     $10 = HEAP32[$it$i>>2]|0;
     $11 = ($10|0)==($9|0);
     if ($11) {
      $$0$i = 0;
     } else {
      $12 = (($10) + 28|0);
      $13 = HEAP32[$12>>2]|0;
      $$0$i = $13;
     }
     $25 = HEAP8[$goodPath$i>>0]|0;
     $26 = $25 & 1;
     $27 = ($26<<24>>24)==(0);
     if (!($27)) {
      $28 = (($goodPath$i) + 8|0);
      $29 = HEAP32[$28>>2]|0;
      HEAP32[$1>>2] = 46;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($29|0),($$byval_copy15|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       $32 = ___cxa_find_matching_catch()|0;
       $33 = tempRet0;
       ___cxa_call_unexpected(($32|0));
       // unreachable;
      }
     }
     $34 = ($$0$i|0)==(0|0);
     if ($34) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $35 = HEAP32[$$0$i>>2]|0;
     $36 = ($35|0)==(0|0);
     if (!($36)) {
      $37 = (($35) + 4|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38|0)>(1);
      if ($39) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
     $40 = HEAP32[628408>>2]|0;
     HEAP32[$2>>2] = $40;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
     $41 = (invoke_iiiiiii(103,24,($$byval_copy15|0),0,16,(650184|0),126)|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      $48 = ___cxa_find_matching_catch()|0;
      $49 = tempRet0;
      $eh$lpad$body$index3Z2D = $49;$eh$lpad$body$indexZ2D = $48;
      break;
     }
     $44 = HEAP32[$$0$i>>2]|0;
     $45 = HEAP32[628408>>2]|0;
     HEAP32[$3>>2] = $45;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_viiii(402,($41|0),($44|0),0,($$byval_copy15|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if (!($47)) {
      $file$2 = $41;
      label = 35;
      break L1;
     }
     $50 = ___cxa_find_matching_catch()|0;
     $51 = tempRet0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_viiiiii(97,($41|0),($$byval_copy15|0),0,16,(650184|0),126);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $110 = ___cxa_find_matching_catch(0|0)|0;
      $111 = tempRet0;
      ___clang_call_terminate($110);
      // unreachable;
     } else {
      $$2 = $51;$$24 = $50;
      ___resumeException($$24|0);
      // unreachable;
     }
    }
   } while(0);
   $$2 = $eh$lpad$body$index3Z2D;$$24 = $eh$lpad$body$indexZ2D;
   ___resumeException($$24|0);
   // unreachable;
  } else if ((($permissions|0) == 2) | (($permissions|0) == 3) | (($permissions|0) == 1)) {
   __THREW__ = 0;
   $54 = (invoke_iiii(1565,($this|0),($data|0),0)|0);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   do {
    if (!($56)) {
     $57 = ($54|0)==(0|0);
     if ($57) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $58 = HEAP32[$54>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $60 = (($58) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)>(1);
     if ($62) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $63 = HEAP32[628408>>2]|0;
     HEAP32[$4>>2] = $63;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$4+0>>2]|0;
     $64 = (invoke_iiiiiii(103,24,($$byval_copy15|0),0,16,(650184|0),139)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if (!($66)) {
      $67 = HEAP32[$54>>2]|0;
      $68 = HEAP32[628408>>2]|0;
      HEAP32[$5>>2] = $68;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_viiii(402,($64|0),($67|0),($permissions|0),($$byval_copy15|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       $73 = ___cxa_find_matching_catch()|0;
       $74 = tempRet0;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$4+0>>2]|0;
       invoke_viiiiii(97,($64|0),($$byval_copy15|0),0,16,(650184|0),139);
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        $110 = ___cxa_find_matching_catch(0|0)|0;
        $111 = tempRet0;
        ___clang_call_terminate($110);
        // unreachable;
       } else {
        $$2 = $74;$$24 = $73;
        ___resumeException($$24|0);
        // unreachable;
       }
      }
      if ((($permissions|0) == 3)) {
       $88 = HEAP32[$64>>2]|0;
       $89 = (($88) + 32|0);
       $90 = HEAP32[$89>>2]|0;
       __THREW__ = 0;
       $91 = (invoke_iiiii($90|0,($64|0),0,0,3)|0);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        break;
       }
       if ($91) {
        $file$2 = $64;
        label = 35;
        break L1;
       }
       $94 = HEAP32[$64>>2]|0;
       $95 = (($94) + 12|0);
       $96 = HEAP32[$95>>2]|0;
       __THREW__ = 0;
       (invoke_ii($96|0,($64|0))|0);
       $97 = __THREW__; __THREW__ = 0;
       $98 = $97&1;
       if ($98) {
        break;
       } else {
        $file$212 = $64;
        break L1;
       }
      } else if ((($permissions|0) == 1)) {
       $77 = HEAP32[$64>>2]|0;
       $78 = (($77) + 40|0);
       $79 = HEAP32[$78>>2]|0;
       __THREW__ = 0;
       $80 = (invoke_iiii($79|0,($64|0),0,0)|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        break;
       }
       if ($80) {
        $file$2 = $64;
        label = 35;
        break L1;
       }
       $83 = HEAP32[$64>>2]|0;
       $84 = (($83) + 12|0);
       $85 = HEAP32[$84>>2]|0;
       __THREW__ = 0;
       (invoke_ii($85|0,($64|0))|0);
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       } else {
        $file$212 = $64;
        break L1;
       }
      } else {
       $file$2 = $64;
       label = 35;
       break L1;
      }
     }
    }
   } while(0);
   $71 = ___cxa_find_matching_catch()|0;
   $72 = tempRet0;
   $$2 = $72;$$24 = $71;
   ___resumeException($$24|0);
   // unreachable;
  } else {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 if ((label|0) == 35) {
  $cond = ($file$2|0)==(0|0);
  if ($cond) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $file$212 = $file$2;
  }
 }
 $99 = HEAP32[$file$212>>2]|0;
 $100 = (($99) + 8|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = (FUNCTION_TABLE_ii[$101 & 4095]($file$212)|0);
 if ($102) {
  $107 = (($data) + 1040|0);
  HEAP32[$107>>2] = $this;
  $108 = (($data) + 1044|0);
  HEAP32[$108>>2] = $this;
  $109 = (($data) + 1048|0);
  HEAP32[$109>>2] = $file$212;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $103 = HEAP32[628408>>2]|0;
  $104 = HEAP32[$file$212>>2]|0;
  $105 = HEAP32[$104>>2]|0;
  FUNCTION_TABLE_vi[$105 & 4095]($file$212);
  HEAP32[$0>>2] = $103;
  ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($file$212,$$byval_copy15);
  $106 = (($data) + 1052|0);
  HEAP32[$106>>2] = -1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN16MemoryFileSystem5CloseER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($data) + 1048|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[628408>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vi[$6 & 4095]($2);
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
 $7 = (($data) + 1052|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$1>>2] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16MemoryFileSystem4ReadER13FileEntryDatayyPvPy($this,$data,$0,$1,$2,$3,$buffer,$actual) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($data) + 1048|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiiiii[$9 & 127]($5,$0,$1,$2,$3,$buffer,$actual)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16MemoryFileSystem4ReadER13FileEntryDatayPvPy($this,$data,$0,$1,$buffer,$actual) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($data) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = (($5) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiiii[$7 & 255]($3,$0,$1,$buffer,$actual)|0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16MemoryFileSystem5WriteER13FileEntryDatayyPvPy($this,$data,$0,$1,$2,$3,$buffer,$actual) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($data) + 1048|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiiiii[$9 & 127]($5,$0,$1,$2,$3,$buffer,$actual)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16MemoryFileSystem5WriteER13FileEntryDatayPvPy($this,$data,$0,$1,$buffer,$actual) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($data) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = (($5) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiiii[$7 & 255]($3,$0,$1,$buffer,$actual)|0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16MemoryFileSystem4SeekER13FileEntryDatay10FileOrigin($this,$data,$0,$1,$origin) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $origin = $origin|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($data) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = (($5) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiii[$7 & 511]($3,$0,$1,$origin)|0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK16MemoryFileSystem8PositionERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 1048|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $8 = 0;$9 = 0;
  tempRet0 = $8;
  STACKTOP = sp;return ($9|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
 $7 = tempRet0;
 $8 = $7;$9 = $6;
 tempRet0 = $8;
 STACKTOP = sp;return ($9|0);
}
function __ZN16MemoryFileSystem9SetLengthER13FileEntryDatay($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($data) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = (($5) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$7 & 2047]($3,$0,$1)|0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK16MemoryFileSystem4SizeERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0$i = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $goodPath$i = 0, $it$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $goodPath$i = sp + 8|0;
 $it$i = sp + 20|0;
 $2 = (($data) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $45 = HEAP32[$3>>2]|0;
  $46 = (($45) + 44|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (FUNCTION_TABLE_ii[$47 & 4095]($3)|0);
  $49 = tempRet0;
  $50 = $49;$51 = $48;
  tempRet0 = $50;
  STACKTOP = sp;return ($51|0);
 }
 ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($data|0),($goodPath$i|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$goodPath$i>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $eh$lpad$body$index3Z2D = $14;$eh$lpad$body$indexZ2D = $13;
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $18 = (($goodPath$i) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($19|0),($$byval_copy8|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $22 = ___cxa_find_matching_catch()|0;
   $23 = tempRet0;
   ___cxa_call_unexpected(($22|0));
   // unreachable;
  } else {
   $eh$lpad$body$index3Z2D = $14;$eh$lpad$body$indexZ2D = $13;
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $7 = (($this) + 4|0);
 __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$7,$goodPath$i);
 $8 = (($this) + 8|0);
 $9 = HEAP32[$it$i>>2]|0;
 $10 = ($9|0)==($8|0);
 if ($10) {
  $$0$i = 0;
 } else {
  $11 = (($9) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $$0$i = $12;
 }
 $24 = HEAP8[$goodPath$i>>0]|0;
 $25 = $24 & 1;
 $26 = ($25<<24>>24)==(0);
 if (!($26)) {
  $27 = (($goodPath$i) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$1>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($28|0),($$byval_copy8|0));
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   ___cxa_call_unexpected(($31|0));
   // unreachable;
  }
 }
 $33 = ($$0$i|0)==(0|0);
 if ($33) {
  $50 = 0;$51 = 0;
  tempRet0 = $50;
  STACKTOP = sp;return ($51|0);
 }
 $34 = HEAP32[$$0$i>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $50 = 0;$51 = 0;
  tempRet0 = $50;
  STACKTOP = sp;return ($51|0);
 }
 $38 = HEAP32[$34>>2]|0;
 $39 = (($38) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 __THREW__ = 0;
 $41 = (invoke_ii($40|0,($34|0))|0);
 $42 = tempRet0;
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if (!($44)) {
  $50 = $42;$51 = $41;
  tempRet0 = $50;
  STACKTOP = sp;return ($51|0);
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $eh$lpad$body$index3Z2D = $37;$eh$lpad$body$indexZ2D = $36;
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
 return 0|0;
}
function __ZN16MemoryFileSystem6ParentERK13FileEntryDataRNSt3__112basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE($this,$data,$out_path) {
 $this = $this|0;
 $data = $data|0;
 $out_path = $out_path|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $goodPath$i = 0, $it$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 44|0;
 $0 = sp;
 $goodPath$i = sp + 4|0;
 $it$i = sp + 16|0;
 $1 = sp + 20|0;
 $2 = sp + 32|0;
 $3 = (_strlen(($data|0))|0);
 $4 = ($3>>>0)>(4294967279);
 if ($4) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $5 = ($3>>>0)<(11);
 if ($5) {
  $6 = $3 << 1;
  $7 = $6&255;
  HEAP8[$2>>0] = $7;
  $8 = (($2) + 1|0);
  $__p$0$i$i$i = $8;
 } else {
  $9 = (($3) + 16)|0;
  $10 = $9 & -16;
  $11 = (__Znwj($10)|0);
  $12 = (($2) + 8|0);
  HEAP32[$12>>2] = $11;
  $13 = $10 | 1;
  HEAP32[$2>>2] = $13;
  $14 = (($2) + 4|0);
  HEAP32[$14>>2] = $3;
  $__p$0$i$i$i = $11;
 }
 _memcpy(($__p$0$i$i$i|0),($data|0),($3|0))|0;
 $15 = (($__p$0$i$i$i) + ($3)|0);
 HEAP8[$15>>0] = 0;
 __THREW__ = 0;
 invoke_vii(3252,($1|0),($2|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if ($17) {
   $66 = ___cxa_find_matching_catch()|0;
   $67 = tempRet0;
   $$0 = $66;$$01 = $67;
  } else {
   __THREW__ = 0;
   (invoke_iii(2233,($out_path|0),($1|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    $70 = HEAP8[$1>>0]|0;
    $71 = $70 & 1;
    $72 = ($71<<24>>24)==(0);
    if ($72) {
     $$0 = $68;$$01 = $69;
     break;
    }
    $73 = (($1) + 8|0);
    $74 = HEAP32[$73>>2]|0;
    __ZdlPv($74);
    $$0 = $68;$$01 = $69;
    break;
   }
   $20 = HEAP8[$1>>0]|0;
   $21 = $20 & 1;
   $22 = ($21<<24>>24)==(0);
   if (!($22)) {
    $23 = (($1) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZdlPv($24);
   }
   $25 = HEAP8[$2>>0]|0;
   $26 = $25 & 1;
   $27 = ($26<<24>>24)==(0);
   if (!($27)) {
    $28 = (($2) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    __ZdlPv($29);
   }
   $30 = HEAP8[$out_path>>0]|0;
   $31 = $30 & 1;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $35 = (($out_path) + 1|0);
    $36 = $35;
   } else {
    $33 = (($out_path) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    $36 = $34;
   }
   ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viii(1937,($this|0),($36|0),($goodPath$i|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $45 = ___cxa_find_matching_catch()|0;
    $46 = tempRet0;
    $47 = HEAP8[$goodPath$i>>0]|0;
    $48 = $47 & 1;
    $49 = ($48<<24>>24)==(0);
    if (!($49)) {
     $50 = (($goodPath$i) + 8|0);
     $51 = HEAP32[$50>>2]|0;
     HEAP32[$0>>2] = 46;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($51|0),($$byval_copy1|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $54 = ___cxa_find_matching_catch()|0;
      $55 = tempRet0;
      ___cxa_call_unexpected(($54|0));
      // unreachable;
     }
    }
    $$1 = $45;$$12 = $46;
    ___resumeException($$1|0);
    // unreachable;
   }
   $39 = (($this) + 4|0);
   __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$39,$goodPath$i);
   $40 = (($this) + 8|0);
   $41 = HEAP32[$it$i>>2]|0;
   $42 = ($41|0)==($40|0);
   if ($42) {
    $$0$i = 0;
   } else {
    $43 = (($41) + 28|0);
    $44 = HEAP32[$43>>2]|0;
    $$0$i = $44;
   }
   $56 = HEAP8[$goodPath$i>>0]|0;
   $57 = $56 & 1;
   $58 = ($57<<24>>24)==(0);
   if ($58) {
    $65 = ($$0$i|0)!=(0|0);
    STACKTOP = sp;return ($65|0);
   }
   $59 = (($goodPath$i) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   HEAP32[$0>>2] = 46;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy1|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    ___cxa_call_unexpected(($63|0));
    // unreachable;
   } else {
    $65 = ($$0$i|0)!=(0|0);
    STACKTOP = sp;return ($65|0);
   }
  }
 } while(0);
 $75 = HEAP8[$2>>0]|0;
 $76 = $75 & 1;
 $77 = ($76<<24>>24)==(0);
 if ($77) {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$1|0);
  // unreachable;
 }
 $78 = (($2) + 8|0);
 $79 = HEAP32[$78>>2]|0;
 __ZdlPv($79);
 $$1 = $$0;$$12 = $$01;
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __ZNK16MemoryFileSystem8FilenameERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $s$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strrchr($data,47)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_strrchr($data,92)|0);
  $s$0 = $2;
 } else {
  $s$0 = $0;
 }
 $3 = ($s$0|0)==(0|0);
 $4 = (($s$0) + 1|0);
 $5 = $3 ? $data : $4;
 STACKTOP = sp;return ($5|0);
}
function __ZNK16MemoryFileSystem5IsDirERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $goodPath$i = 0, $it$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $goodPath$i = sp + 4|0;
 $it$i = sp + 16|0;
 ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($data|0),($goodPath$i|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP8[$goodPath$i>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   ___resumeException($9|0);
   // unreachable;
  }
  $14 = (($goodPath$i) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($15|0),($$byval_copy1|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   ___cxa_call_unexpected(($18|0));
   // unreachable;
  } else {
   ___resumeException($9|0);
   // unreachable;
  }
 }
 $3 = (($this) + 4|0);
 __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$3,$goodPath$i);
 $4 = (($this) + 8|0);
 $5 = HEAP32[$it$i>>2]|0;
 $6 = ($5|0)==($4|0);
 if ($6) {
  $$0$i = 0;
 } else {
  $7 = (($5) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $$0$i = $8;
 }
 $20 = HEAP8[$goodPath$i>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if (!($22)) {
  $23 = (($goodPath$i) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($24|0),($$byval_copy1|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   ___cxa_call_unexpected(($27|0));
   // unreachable;
  }
 }
 $29 = ($$0$i|0)==(0|0);
 if ($29) {
  $32 = 0;
  STACKTOP = sp;return ($32|0);
 }
 $30 = HEAP32[$$0$i>>2]|0;
 $31 = ($30|0)==(0|0);
 $32 = $31;
 STACKTOP = sp;return ($32|0);
}
function __ZNK16MemoryFileSystem8IsHiddenERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK16MemoryFileSystem9IsSymLinkERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK16MemoryFileSystem12LastModifiedERK13FileEntryData($agg$result,$this,$data) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $data = $data|0;
 var $$0$i = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $goodPath$i = 0, $it$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $goodPath$i = sp + 8|0;
 $it$i = sp + 20|0;
 ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($data|0),($goodPath$i|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $12 = HEAP8[$goodPath$i>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $eh$lpad$body$index3Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $15 = (($goodPath$i) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($16|0),($$byval_copy8|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $19 = ___cxa_find_matching_catch()|0;
   $20 = tempRet0;
   ___cxa_call_unexpected(($19|0));
   // unreachable;
  } else {
   $eh$lpad$body$index3Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $4 = (($this) + 4|0);
 __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$4,$goodPath$i);
 $5 = (($this) + 8|0);
 $6 = HEAP32[$it$i>>2]|0;
 $7 = ($6|0)==($5|0);
 if ($7) {
  $$0$i = 0;
 } else {
  $8 = (($6) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $$0$i = $9;
 }
 $21 = HEAP8[$goodPath$i>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if (!($23)) {
  $24 = (($goodPath$i) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$1>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($25|0),($$byval_copy8|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   ___cxa_call_unexpected(($28|0));
   // unreachable;
  }
 }
 $30 = ($$0$i|0)==(0|0);
 if (!($30)) {
  $31 = (($$0$i) + 4|0);
  $32 = $31;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $agg$result;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3585,($agg$result|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if (!($43)) {
  STACKTOP = sp;return;
 }
 $44 = ___cxa_find_matching_catch()|0;
 $45 = tempRet0;
 $eh$lpad$body$index3Z2D = $45;$eh$lpad$body$indexZ2D = $44;
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN16MemoryFileSystem8IsLockedERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $goodPath$i = 0, $it$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $goodPath$i = sp + 4|0;
 $it$i = sp + 16|0;
 ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($data|0),($goodPath$i|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP8[$goodPath$i>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   ___resumeException($9|0);
   // unreachable;
  }
  $14 = (($goodPath$i) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($15|0),($$byval_copy1|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   ___cxa_call_unexpected(($18|0));
   // unreachable;
  } else {
   ___resumeException($9|0);
   // unreachable;
  }
 }
 $3 = (($this) + 4|0);
 __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$3,$goodPath$i);
 $4 = (($this) + 8|0);
 $5 = HEAP32[$it$i>>2]|0;
 $6 = ($5|0)==($4|0);
 if ($6) {
  $$0$i = 0;
 } else {
  $7 = (($5) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $$0$i = $8;
 }
 $20 = HEAP8[$goodPath$i>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if (!($22)) {
  $23 = (($goodPath$i) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($24|0),($$byval_copy1|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   ___cxa_call_unexpected(($27|0));
   // unreachable;
  }
 }
 $29 = ($$0$i|0)==(0|0);
 if ($29) {
  $35 = 0;
  STACKTOP = sp;return ($35|0);
 }
 $30 = HEAP32[$$0$i>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  $35 = 0;
  STACKTOP = sp;return ($35|0);
 }
 $32 = (($30) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)>(1);
 $35 = $34;
 STACKTOP = sp;return ($35|0);
}
function __ZN16MemoryFileSystem11HasFastHashERK13FileEntryDataR7Hash128($this,$data,$fastHash) {
 $this = $this|0;
 $data = $data|0;
 $fastHash = $fastHash|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN16MemoryFileSystem8SetFlagsER13FileEntryDatajj($this,$data,$attributeMask,$attributeValue) {
 $this = $this|0;
 $data = $data|0;
 $attributeMask = $attributeMask|0;
 $attributeValue = $attributeValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN16MemoryFileSystem12CreateAsFileER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $$0$i = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $goodPath$i = 0, $it$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy8 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $goodPath$i = sp + 8|0;
 $it$i = sp + 20|0;
 ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($data|0),($goodPath$i|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $12 = HEAP8[$goodPath$i>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $eh$lpad$body$index3Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $15 = (($goodPath$i) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($16|0),($$byval_copy8|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   $19 = ___cxa_find_matching_catch()|0;
   $20 = tempRet0;
   ___cxa_call_unexpected(($19|0));
   // unreachable;
  } else {
   $eh$lpad$body$index3Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 $4 = (($this) + 4|0);
 __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$4,$goodPath$i);
 $5 = (($this) + 8|0);
 $6 = HEAP32[$it$i>>2]|0;
 $7 = ($6|0)==($5|0);
 if ($7) {
  $$0$i = 0;
 } else {
  $8 = (($6) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  $$0$i = $9;
 }
 $21 = HEAP8[$goodPath$i>>0]|0;
 $22 = $21 & 1;
 $23 = ($22<<24>>24)==(0);
 if (!($23)) {
  $24 = (($goodPath$i) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$1>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($25|0),($$byval_copy8|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   ___cxa_call_unexpected(($28|0));
   // unreachable;
  }
 }
 $30 = ($$0$i|0)==(0|0);
 if (!($30)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $33 = (invoke_iiii(1565,($this|0),($data|0),0)|0);
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $eh$lpad$body$index3Z2D = $32;$eh$lpad$body$indexZ2D = $31;
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 } else {
  $36 = ($33|0)!=(0|0);
  $$0 = $36;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN16MemoryFileSystem11CreateAsDirER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$04 = 0, $$2 = 0, $$23 = 0, $$byval_copy11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i5 = 0, $dirPath = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $goodPath$i = 0, $it$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy11 = sp + 68|0;
 $0 = sp + 64|0;
 $1 = sp + 60|0;
 $2 = sp + 56|0;
 $goodPath$i = sp + 44|0;
 $it$i = sp + 40|0;
 $3 = sp + 24|0;
 $dirPath = sp + 12|0;
 $4 = sp;
 $5 = sp + 28|0;
 $6 = (_strlen(($data|0))|0);
 $7 = ($6>>>0)>(4294967279);
 if ($7) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $8 = ($6>>>0)<(11);
 if ($8) {
  $9 = $6 << 1;
  $10 = $9&255;
  HEAP8[$5>>0] = $10;
  $11 = (($5) + 1|0);
  $__p$0$i$i$i = $11;
 } else {
  $12 = (($6) + 16)|0;
  $13 = $12 & -16;
  $14 = (__Znwj($13)|0);
  $15 = (($5) + 8|0);
  HEAP32[$15>>2] = $14;
  $16 = $13 | 1;
  HEAP32[$5>>2] = $16;
  $17 = (($5) + 4|0);
  HEAP32[$17>>2] = $6;
  $__p$0$i$i$i = $14;
 }
 _memcpy(($__p$0$i$i$i|0),($data|0),($6|0))|0;
 $18 = (($__p$0$i$i$i) + ($6)|0);
 HEAP8[$18>>0] = 0;
 __THREW__ = 0;
 invoke_vii(3253,($4|0),($5|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  $$0 = $92;$$01 = $91;
 } else {
  $21 = HEAP8[$4>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   $26 = (($4) + 1|0);
   $27 = $26;
  } else {
   $24 = (($4) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $27 = $25;
  }
  $28 = (_strlen(($27|0))|0);
  $29 = ($28>>>0)>(2147483631);
  do {
   if ($29) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     // unreachable;
    }
   } else {
    $32 = ($28>>>0)<(11);
    if ($32) {
     $33 = $28 << 1;
     $34 = $33&255;
     HEAP8[$dirPath>>0] = $34;
     $35 = (($dirPath) + 1|0);
     $__p$0$i$i$i5 = $35;
    } else {
     $36 = (($28) + 16)|0;
     $37 = $36 & -16;
     HEAP32[$3>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
     $38 = (invoke_iiiiiii(102,($37|0),16,($$byval_copy11|0),0,(650184|0),79)|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     $41 = (($dirPath) + 8|0);
     HEAP32[$41>>2] = $38;
     $42 = $37 | 1;
     HEAP32[$dirPath>>2] = $42;
     $43 = (($dirPath) + 4|0);
     HEAP32[$43>>2] = $28;
     $__p$0$i$i$i5 = $38;
    }
    _memcpy(($__p$0$i$i$i5|0),($27|0),($28|0))|0;
    $44 = (($__p$0$i$i$i5) + ($28)|0);
    HEAP8[$44>>0] = 0;
    $45 = HEAP8[$4>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if (!($47)) {
     $48 = (($4) + 8|0);
     $49 = HEAP32[$48>>2]|0;
     __ZdlPv($49);
    }
    $50 = HEAP8[$5>>0]|0;
    $51 = $50 & 1;
    $52 = ($51<<24>>24)==(0);
    if (!($52)) {
     $53 = (($5) + 8|0);
     $54 = HEAP32[$53>>2]|0;
     __ZdlPv($54);
    }
    $55 = HEAP8[$dirPath>>0]|0;
    $56 = $55 & 1;
    $57 = ($56<<24>>24)==(0);
    if ($57) {
     $60 = (($dirPath) + 1|0);
     $61 = $60;
    } else {
     $58 = (($dirPath) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     $61 = $59;
    }
    ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
    __THREW__ = 0;
    invoke_viii(1937,($this|0),($61|0),($goodPath$i|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    L33: do {
     if ($63) {
      $70 = ___cxa_find_matching_catch()|0;
      $71 = tempRet0;
      $72 = HEAP8[$goodPath$i>>0]|0;
      $73 = $72 & 1;
      $74 = ($73<<24>>24)==(0);
      if ($74) {
       $eh$lpad$body$index3Z2D = $71;$eh$lpad$body$indexZ2D = $70;
      } else {
       $75 = (($goodPath$i) + 8|0);
       $76 = HEAP32[$75>>2]|0;
       HEAP32[$1>>2] = 46;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($76|0),($$byval_copy11|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        $79 = ___cxa_find_matching_catch()|0;
        $80 = tempRet0;
        ___cxa_call_unexpected(($79|0));
        // unreachable;
       } else {
        $eh$lpad$body$index3Z2D = $71;$eh$lpad$body$indexZ2D = $70;
       }
      }
     } else {
      $64 = (($this) + 4|0);
      __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$64,$goodPath$i);
      $65 = (($this) + 8|0);
      $66 = HEAP32[$it$i>>2]|0;
      $67 = ($66|0)==($65|0);
      if ($67) {
       $$0$i = 0;
      } else {
       $68 = (($66) + 28|0);
       $69 = HEAP32[$68>>2]|0;
       $$0$i = $69;
      }
      $81 = HEAP8[$goodPath$i>>0]|0;
      $82 = $81 & 1;
      $83 = ($82<<24>>24)==(0);
      if (!($83)) {
       $84 = (($goodPath$i) + 8|0);
       $85 = HEAP32[$84>>2]|0;
       HEAP32[$2>>2] = 46;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
       invoke_vii(2591,($85|0),($$byval_copy11|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        $88 = ___cxa_find_matching_catch()|0;
        $89 = tempRet0;
        ___cxa_call_unexpected(($88|0));
        // unreachable;
       }
      }
      $90 = ($$0$i|0)==(0|0);
      do {
       if ($90) {
        $107 = HEAP8[$dirPath>>0]|0;
        $108 = $107 & 1;
        $109 = ($108<<24>>24)==(0);
        if ($109) {
         $112 = (($dirPath) + 1|0);
         $113 = $112;
        } else {
         $110 = (($dirPath) + 8|0);
         $111 = HEAP32[$110>>2]|0;
         $113 = $111;
        }
        __THREW__ = 0;
        $114 = (invoke_iiii(1565,($this|0),($113|0),1)|0);
        $115 = __THREW__; __THREW__ = 0;
        $116 = $115&1;
        if ($116) {
         $105 = ___cxa_find_matching_catch()|0;
         $106 = tempRet0;
         $eh$lpad$body$index3Z2D = $106;$eh$lpad$body$indexZ2D = $105;
         break L33;
        } else {
         $117 = ($114|0)!=(0|0);
         $$04 = $117;
         break;
        }
       } else {
        $$04 = 0;
       }
      } while(0);
      $118 = HEAP8[$dirPath>>0]|0;
      $119 = $118 & 1;
      $120 = ($119<<24>>24)==(0);
      if ($120) {
       STACKTOP = sp;return ($$04|0);
      }
      $121 = (($dirPath) + 8|0);
      $122 = HEAP32[$121>>2]|0;
      HEAP32[$0>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($122|0),($$byval_copy11|0));
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       $125 = ___cxa_find_matching_catch()|0;
       $126 = tempRet0;
       ___cxa_call_unexpected(($125|0));
       // unreachable;
      } else {
       STACKTOP = sp;return ($$04|0);
      }
     }
    } while(0);
    $127 = HEAP8[$dirPath>>0]|0;
    $128 = $127 & 1;
    $129 = ($128<<24>>24)==(0);
    if ($129) {
     $$2 = $eh$lpad$body$index3Z2D;$$23 = $eh$lpad$body$indexZ2D;
     ___resumeException($$23|0);
     // unreachable;
    }
    $130 = (($dirPath) + 8|0);
    $131 = HEAP32[$130>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($131|0),($$byval_copy11|0));
    $132 = __THREW__; __THREW__ = 0;
    $133 = $132&1;
    if ($133) {
     $134 = ___cxa_find_matching_catch()|0;
     $135 = tempRet0;
     ___cxa_call_unexpected(($134|0));
     // unreachable;
    } else {
     $$2 = $eh$lpad$body$index3Z2D;$$23 = $eh$lpad$body$indexZ2D;
     ___resumeException($$23|0);
     // unreachable;
    }
   }
  } while(0);
  $93 = ___cxa_find_matching_catch()|0;
  $94 = tempRet0;
  $95 = HEAP8[$4>>0]|0;
  $96 = $95 & 1;
  $97 = ($96<<24>>24)==(0);
  if ($97) {
   $$0 = $94;$$01 = $93;
  } else {
   $98 = (($4) + 8|0);
   $99 = HEAP32[$98>>2]|0;
   __ZdlPv($99);
   $$0 = $94;$$01 = $93;
  }
 }
 $100 = HEAP8[$5>>0]|0;
 $101 = $100 & 1;
 $102 = ($101<<24>>24)==(0);
 if ($102) {
  $$2 = $$0;$$23 = $$01;
  ___resumeException($$23|0);
  // unreachable;
 }
 $103 = (($5) + 8|0);
 $104 = HEAP32[$103>>2]|0;
 __ZdlPv($104);
 $$2 = $$0;$$23 = $$01;
 ___resumeException($$23|0);
 // unreachable;
 return 0|0;
}
function __ZN16MemoryFileSystem6DeleteER13FileEntryDatab($this,$data,$recursively) {
 $this = $this|0;
 $data = $data|0;
 $recursively = $recursively|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i25 = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$12 = 0, $$14 = 0, $$byval_copy19 = 0, $$in = 0, $$in$ph = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre61 = 0, $$pre63 = 0, $$sink$index7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__p$0$i$i$i = 0, $firstIt = 0, $goodPath = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy19 = sp + 64|0;
 $0 = sp + 60|0;
 $1 = sp + 56|0;
 $2 = sp + 52|0;
 $3 = sp + 48|0;
 $4 = sp + 44|0;
 $5 = sp + 40|0;
 $6 = sp + 32|0;
 $goodPath = sp + 20|0;
 $firstIt = sp + 16|0;
 $7 = sp + 4|0;
 $8 = sp;
 $9 = sp + 36|0;
 ;HEAP32[$goodPath+0>>2]=0|0;HEAP32[$goodPath+4>>2]=0|0;HEAP32[$goodPath+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($data|0),($goodPath|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   $$12 = $21;$$sink$index7 = $22;
  } else {
   $12 = HEAP8[$goodPath>>0]|0;
   $13 = $12 & 1;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $17 = $12&255;
    $18 = $17 >>> 1;
    $20 = $18;
   } else {
    $15 = (($goodPath) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $20 = $16;
   }
   $19 = ($20|0)==(0);
   L7: do {
    if ($19) {
     $$14 = 0;
    } else {
     if ($14) {
      $25 = (($goodPath) + 1|0);
      $26 = $25;
     } else {
      $23 = (($goodPath) + 8|0);
      $24 = HEAP32[$23>>2]|0;
      $26 = $24;
     }
     $27 = (_strlen(($26|0))|0);
     $28 = ($27>>>0)>(2147483631);
     L13: do {
      if ($28) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        label = 52;
       } else {
        // unreachable;
       }
      } else {
       $31 = ($27>>>0)<(11);
       if ($31) {
        $32 = $27 << 1;
        $33 = $32&255;
        HEAP8[$7>>0] = $33;
        $34 = (($7) + 1|0);
        $$pre$phiZ2D = $7;$__p$0$i$i$i = $34;
       } else {
        $35 = (($27) + 16)|0;
        $36 = $35 & -16;
        HEAP32[$5>>2] = 46;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$5+0>>2]|0;
        $37 = (invoke_iiiiiii(102,($36|0),16,($$byval_copy19|0),0,(650184|0),79)|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         label = 52;
         break;
        }
        $40 = (($7) + 8|0);
        HEAP32[$40>>2] = $37;
        $41 = $36 | 1;
        HEAP32[$7>>2] = $41;
        $42 = (($7) + 4|0);
        HEAP32[$42>>2] = $27;
        $$pre$phiZ2D = $7;$__p$0$i$i$i = $37;
       }
       _memcpy(($__p$0$i$i$i|0),($26|0),($27|0))|0;
       $43 = (($__p$0$i$i$i) + ($27)|0);
       HEAP8[$43>>0] = 0;
       $44 = (($this) + 4|0);
       __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_15__tree_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($firstIt,$44,$7);
       $45 = HEAP8[$$pre$phiZ2D>>0]|0;
       $46 = $45 & 1;
       $47 = ($46<<24>>24)==(0);
       if (!($47)) {
        $48 = (($7) + 8|0);
        $49 = HEAP32[$48>>2]|0;
        HEAP32[$4>>2] = 46;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
        invoke_vii(2591,($49|0),($$byval_copy19|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         $52 = ___cxa_find_matching_catch()|0;
         $53 = tempRet0;
         ___cxa_call_unexpected(($52|0));
         // unreachable;
        }
       }
       $54 = (($this) + 8|0);
       $55 = HEAP32[$firstIt>>2]|0;
       $56 = ($55|0)==($54|0);
       if ($56) {
        $$14 = 0;
        break L7;
       }
       $57 = (($55) + 28|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = HEAP32[$58>>2]|0;
       $60 = ($59|0)==(0|0);
       if ($60) {
        $61 = (($55) + 4|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = ($62|0)==(0|0);
        if ($63) {
         $$01$i$i$i = $55;
         while(1) {
          $66 = (($$01$i$i$i) + 8|0);
          $67 = HEAP32[$66>>2]|0;
          $68 = HEAP32[$67>>2]|0;
          $69 = ($68|0)==($$01$i$i$i|0);
          if ($69) {
           $$in$ph = $67;
           break;
          } else {
           $$01$i$i$i = $67;
          }
         }
        } else {
         $$0$i$i$i$i = $62;
         while(1) {
          $64 = HEAP32[$$0$i$i$i$i>>2]|0;
          $65 = ($64|0)==(0|0);
          if ($65) {
           $$in$ph = $$0$i$i$i$i;
           break;
          } else {
           $$0$i$i$i$i = $64;
          }
         }
        }
        $70 = ($$in$ph|0)==($54|0);
        L36: do {
         if (!($70)) {
          $71 = (($goodPath) + 1|0);
          $72 = (($goodPath) + 4|0);
          $73 = (($goodPath) + 8|0);
          $$in = $$in$ph;
          L38: while(1) {
           $74 = (($$in) + 16|0);
           $75 = HEAP8[$74>>0]|0;
           $76 = $75 & 1;
           $77 = ($76<<24>>24)==(0);
           if ($77) {
            $80 = (($74) + 1|0);
            $88 = $80;
           } else {
            $78 = (($$in) + 24|0);
            $79 = HEAP32[$78>>2]|0;
            $88 = $79;
           }
           $81 = HEAP8[$goodPath>>0]|0;
           $82 = $81 & 1;
           $83 = ($82<<24>>24)==(0);
           if ($83) {
            $86 = $81&255;
            $87 = $86 >>> 1;
            $89 = $71;$90 = $87;
           } else {
            $84 = HEAP32[$73>>2]|0;
            $85 = HEAP32[$72>>2]|0;
            $89 = $84;$90 = $85;
           }
           $91 = (_strncmp($88,$89,$90)|0);
           $92 = ($91|0)==(0);
           if (!($92)) {
            break L36;
           }
           if (!($recursively)) {
            $$14 = 0;
            break L7;
           }
           $93 = (($$in) + 28|0);
           $94 = HEAP32[$93>>2]|0;
           $95 = HEAP32[$94>>2]|0;
           $96 = ($95|0)==(0|0);
           do {
            if (!($96)) {
             $97 = HEAP32[628408>>2]|0;
             $98 = (($95) + 4|0);
             $99 = HEAP32[$98>>2]|0;
             $100 = (($99) + -1)|0;
             HEAP32[$98>>2] = $100;
             $101 = HEAP32[$98>>2]|0;
             $102 = ($101|0)==(0);
             if (!($102)) {
              break;
             }
             $103 = HEAP32[$95>>2]|0;
             $104 = HEAP32[$103>>2]|0;
             __THREW__ = 0;
             invoke_vi($104|0,($95|0));
             $105 = __THREW__; __THREW__ = 0;
             $106 = $105&1;
             if ($106) {
              break L38;
             }
             HEAP32[$0>>2] = $97;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
             invoke_vii(2591,($95|0),($$byval_copy19|0));
             $107 = __THREW__; __THREW__ = 0;
             $108 = $107&1;
             if ($108) {
              break L38;
             }
            }
           } while(0);
           $109 = HEAP32[$93>>2]|0;
           $110 = HEAP32[628408>>2]|0;
           HEAP32[$1>>2] = $110;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
           invoke_vii(2591,($109|0),($$byval_copy19|0));
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            break;
           }
           HEAP32[$93>>2] = 0;
           $113 = (($$in) + 4|0);
           $114 = HEAP32[$113>>2]|0;
           $115 = ($114|0)==(0|0);
           if ($115) {
            $$01$i$i$i$i = $$in;
            while(1) {
             $118 = (($$01$i$i$i$i) + 8|0);
             $119 = HEAP32[$118>>2]|0;
             $120 = HEAP32[$119>>2]|0;
             $121 = ($120|0)==($$01$i$i$i$i|0);
             if ($121) {
              $$0$i$i$i$i25 = $119;
              break;
             } else {
              $$01$i$i$i$i = $119;
             }
            }
           } else {
            $$0$i$i$i$i$i = $114;
            while(1) {
             $116 = HEAP32[$$0$i$i$i$i$i>>2]|0;
             $117 = ($116|0)==(0|0);
             if ($117) {
              $$0$i$i$i$i25 = $$0$i$i$i$i$i;
              break;
             } else {
              $$0$i$i$i$i$i = $116;
             }
            }
           }
           HEAP32[$1>>2] = $$in;
           ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
           __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE5eraseENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEE($8,$44,$$byval_copy19);
           $122 = ($$0$i$i$i$i25|0)==($54|0);
           if ($122) {
            break L36;
           } else {
            $$in = $$0$i$i$i$i25;
           }
          }
          $143 = ___cxa_find_matching_catch()|0;
          $144 = tempRet0;
          $lpad$phi$index = $143;$lpad$phi$index2 = $144;
          break L13;
         }
        } while(0);
        $$pre = HEAP32[$firstIt>>2]|0;
        $$phi$trans$insert = (($$pre) + 28|0);
        $$pre61 = HEAP32[$$phi$trans$insert>>2]|0;
        $$pre63 = HEAP32[$$pre61>>2]|0;
        $123 = ($$pre63|0)==(0|0);
        if (!($123)) {
         $126 = $$pre63;
         label = 46;
        }
       } else {
        $126 = $59;
        label = 46;
       }
       if ((label|0) == 46) {
        $124 = HEAP32[628408>>2]|0;
        $125 = (($126) + 4|0);
        $127 = HEAP32[$125>>2]|0;
        $128 = (($127) + -1)|0;
        HEAP32[$125>>2] = $128;
        $129 = HEAP32[$125>>2]|0;
        $130 = ($129|0)==(0);
        if ($130) {
         $131 = HEAP32[$126>>2]|0;
         $132 = HEAP32[$131>>2]|0;
         __THREW__ = 0;
         invoke_vi($132|0,($126|0));
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          label = 52;
          break;
         }
         HEAP32[$2>>2] = $124;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
         invoke_vii(2591,($126|0),($$byval_copy19|0));
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if ($136) {
          label = 52;
          break;
         }
        }
       }
       $137 = HEAP32[$firstIt>>2]|0;
       $138 = (($137) + 28|0);
       $139 = HEAP32[$138>>2]|0;
       $140 = HEAP32[628408>>2]|0;
       HEAP32[$3>>2] = $140;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
       invoke_vii(2591,($139|0),($$byval_copy19|0));
       $141 = __THREW__; __THREW__ = 0;
       $142 = $141&1;
       if ($142) {
        label = 52;
       } else {
        HEAP32[$138>>2] = 0;
        HEAP32[$1>>2] = $137;
        ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
        __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE5eraseENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEE($9,$44,$$byval_copy19);
        $$14 = 1;
        break L7;
       }
      }
     } while(0);
     if ((label|0) == 52) {
      $145 = ___cxa_find_matching_catch()|0;
      $146 = tempRet0;
      $lpad$phi$index = $145;$lpad$phi$index2 = $146;
     }
     $$12 = $lpad$phi$index;$$sink$index7 = $lpad$phi$index2;
     break L1;
    }
   } while(0);
   $147 = HEAP8[$goodPath>>0]|0;
   $148 = $147 & 1;
   $149 = ($148<<24>>24)==(0);
   if ($149) {
    STACKTOP = sp;return ($$14|0);
   }
   $150 = (($goodPath) + 8|0);
   $151 = HEAP32[$150>>2]|0;
   HEAP32[$1>>2] = 46;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($151|0),($$byval_copy19|0));
   $152 = __THREW__; __THREW__ = 0;
   $153 = $152&1;
   if ($153) {
    $154 = ___cxa_find_matching_catch()|0;
    $155 = tempRet0;
    ___cxa_call_unexpected(($154|0));
    // unreachable;
   } else {
    STACKTOP = sp;return ($$14|0);
   }
  }
 } while(0);
 $156 = HEAP8[$goodPath>>0]|0;
 $157 = $156 & 1;
 $158 = ($157<<24>>24)==(0);
 if ($158) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $159 = (($goodPath) + 8|0);
 $160 = HEAP32[$159>>2]|0;
 HEAP32[$6>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_vii(2591,($160|0),($$byval_copy19|0));
 $161 = __THREW__; __THREW__ = 0;
 $162 = $161&1;
 if ($162) {
  $163 = ___cxa_find_matching_catch()|0;
  $164 = tempRet0;
  ___cxa_call_unexpected(($163|0));
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK16MemoryFileSystem11GetGoodPathEPKcRNSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEE($this,$path,$outPath) {
 $this = $this|0;
 $path = $path|0;
 $outPath = $outPath|0;
 var $$0$i$i = 0, $$localPath$0 = 0, $$ph$i = 0, $$pre$i = 0, $$pre$phi4$iZ2D = 0, $$pre$phi6$iZ2D = 0, $$pre3$i = 0, $$pre5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localPath$0 = 0, $v$off$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
 } else {
  $4 = (($this) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 $8 = (_strstr($path,$7)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $localPath$0 = $path;
 } else {
  if ($3) {
   $12 = $1&255;
   $13 = $12 >>> 1;
   $15 = $13;
  } else {
   $10 = (($this) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $15 = $11;
  }
  $14 = (($8) + ($15)|0);
  $localPath$0 = $14;
 }
 $16 = HEAP8[$localPath$0>>0]|0;
 $17 = ($16<<24>>24)==(47);
 $18 = (($localPath$0) + 1|0);
 $$localPath$0 = $17 ? $18 : $localPath$0;
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE6assignEPKc($outPath,$$localPath$0)|0);
 $19 = HEAP8[$outPath>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $24 = (($outPath) + 1|0);
  $$pre5$i = (($outPath) + 8|0);
  $$ph$i = $24;$$pre$phi4$iZ2D = $24;$$pre$phi6$iZ2D = $$pre5$i;
 } else {
  $22 = (($outPath) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $$pre3$i = (($outPath) + 1|0);
  $$ph$i = $23;$$pre$phi4$iZ2D = $$pre3$i;$$pre$phi6$iZ2D = $22;
 }
 $25 = (($outPath) + 4|0);
 $27 = $19;$37 = $$ph$i;
 while(1) {
  $26 = $27 & 1;
  $28 = ($26<<24>>24)==(0);
  if ($28) {
   $31 = $27&255;
   $32 = $31 >>> 1;
   $34 = $$pre$phi4$iZ2D;$35 = $32;
  } else {
   $29 = HEAP32[$$pre$phi6$iZ2D>>2]|0;
   $30 = HEAP32[$25>>2]|0;
   $34 = $29;$35 = $30;
  }
  $33 = (($34) + ($35)|0);
  $36 = ($37|0)==($33|0);
  if ($36) {
   break;
  }
  $38 = HEAP8[$37>>0]|0;
  $v$off$i$i = (($38) + -65)<<24>>24;
  $39 = ($v$off$i$i&255)<(26);
  if ($39) {
   $40 = $38&255;
   $41 = $40 | 32;
   $42 = $41&255;
   $$0$i$i = $42;
  } else {
   $$0$i$i = $38;
  }
  HEAP8[$37>>0] = $$0$i$i;
  $43 = (($37) + 1|0);
  $$pre$i = HEAP8[$outPath>>0]|0;
  $27 = $$pre$i;$37 = $43;
 }
 STACKTOP = sp;return;
}
function __ZN16MemoryFileSystem11MoveToTrashER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK16MemoryFileSystem6TargetERK13FileEntryDataR15FileSystemEntry($this,$data,$out_symLink) {
 $this = $this|0;
 $data = $data|0;
 $out_symLink = $out_symLink|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN16MemoryFileSystem4LockER13FileEntryData12FileLockMode($this,$data,$lockMode) {
 $this = $this|0;
 $data = $data|0;
 $lockMode = $lockMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN16MemoryFileSystem4CopyER13FileEntryDataS1_($this,$from,$to) {
 $this = $this|0;
 $from = $from|0;
 $to = $to|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK16MemoryFileSystem12GetAssetGUIDERK13FileEntryData($agg$result,$this,$data) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN16MemoryFileSystem9MakeLocalER13FileEntryDatab($this,$data,$overwriteIfAlreadyExistsLocaly) {
 $this = $this|0;
 $data = $data|0;
 $overwriteIfAlreadyExistsLocaly = $overwriteIfAlreadyExistsLocaly|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK16MemoryFileSystem9EnumerateEPKcP13dynamic_arrayI13FileEntryInfoLj8EEbPPv19FileEnumerationFlag($this,$path,$fileEntryInfoList,$recurse,$handlerData,$flags) {
 $this = $this|0;
 $path = $path|0;
 $fileEntryInfoList = $fileEntryInfoList|0;
 $recurse = $recurse|0;
 $handlerData = $handlerData|0;
 $flags = $flags|0;
 var $$ = 0, $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i13 = 0, $$0$i$i$i17 = 0, $$01$i$i$i = 0, $$01$i$i$i15 = 0, $$02 = 0, $$03 = 0, $$2 = 0, $$25 = 0, $$50 = 0, $$byval_copy12 = 0, $$pn$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__cap$0$i$i = 0, $__p$0$i$i = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i22 = 0, $__p$0$sum$pre$i$i = 0, $__p$0$sum$pre$phi$i$iZZZ2D = 0, $__sz$0$i$i = 0, $fileNamePart = 0, $fullPath = 0, $it = 0, $localPath = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $recurseLookupOffset$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy12 = sp + 88|0;
 $0 = sp + 84|0;
 $1 = sp + 80|0;
 $2 = sp + 76|0;
 $3 = sp + 72|0;
 $4 = sp + 68|0;
 $5 = sp + 64|0;
 $localPath = sp + 40|0;
 $it = sp + 36|0;
 $6 = sp + 24|0;
 $fullPath = sp + 12|0;
 $fileNamePart = sp;
 $7 = sp + 52|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 56|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iii[$10 & 4095]($this,$path)|0);
 ;HEAP32[$localPath+0>>2]=0|0;HEAP32[$localPath+4>>2]=0|0;HEAP32[$localPath+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($path|0),($localPath|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L1: do {
  if ($13) {
   label = 22;
  } else {
   __THREW__ = 0;
   (invoke_ii(3313,($localPath|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 22;
   } else {
    $16 = HEAP8[$localPath>>0]|0;
    $17 = $16 & 1;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     $21 = $16&255;
     $22 = $21 >>> 1;
     $24 = $22;
    } else {
     $19 = (($localPath) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $24 = $20;
    }
    $23 = ($24|0)==(0);
    $25 = (($this) + 4|0);
    L8: do {
     if ($23) {
      $26 = HEAP32[$25>>2]|0;
      HEAP32[$it>>2] = $26;
     } else {
      if ($18) {
       $29 = (($localPath) + 1|0);
       $30 = $29;
      } else {
       $27 = (($localPath) + 8|0);
       $28 = HEAP32[$27>>2]|0;
       $30 = $28;
      }
      $31 = (_strlen(($30|0))|0);
      $32 = ($31>>>0)>(2147483631);
      do {
       if ($32) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         // unreachable;
        }
       } else {
        $35 = ($31>>>0)<(11);
        if ($35) {
         $36 = $31 << 1;
         $37 = $36&255;
         HEAP8[$6>>0] = $37;
         $38 = (($6) + 1|0);
         $$pre$phiZ2D = $6;$__p$0$i$i$i = $38;
        } else {
         $39 = (($31) + 16)|0;
         $40 = $39 & -16;
         HEAP32[$3>>2] = 46;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
         $41 = (invoke_iiiiiii(102,($40|0),16,($$byval_copy12|0),0,(650184|0),79)|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break;
         }
         $44 = (($6) + 8|0);
         HEAP32[$44>>2] = $41;
         $45 = $40 | 1;
         HEAP32[$6>>2] = $45;
         $46 = (($6) + 4|0);
         HEAP32[$46>>2] = $31;
         $$pre$phiZ2D = $6;$__p$0$i$i$i = $41;
        }
        _memcpy(($__p$0$i$i$i|0),($30|0),($31|0))|0;
        $47 = (($__p$0$i$i$i) + ($31)|0);
        HEAP8[$47>>0] = 0;
        __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it,$25,$6);
        $48 = HEAP8[$$pre$phiZ2D>>0]|0;
        $49 = $48 & 1;
        $50 = ($49<<24>>24)==(0);
        if ($50) {
         break L8;
        }
        $51 = (($6) + 8|0);
        $52 = HEAP32[$51>>2]|0;
        HEAP32[$2>>2] = 46;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($52|0),($$byval_copy12|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if (!($54)) {
         break L8;
        }
        $55 = ___cxa_find_matching_catch()|0;
        $56 = tempRet0;
        ___cxa_call_unexpected(($55|0));
        // unreachable;
       }
      } while(0);
      $62 = ___cxa_find_matching_catch()|0;
      $63 = tempRet0;
      $$2 = $63;$$25 = $62;
      break L1;
     }
    } while(0);
    $57 = (($this) + 8|0);
    $58 = HEAP32[$it>>2]|0;
    $59 = ($58|0)==($57|0);
    if ($59) {
     $$0 = 0;
    } else {
     ;HEAP32[$fullPath+0>>2]=0|0;HEAP32[$fullPath+4>>2]=0|0;HEAP32[$fullPath+8>>2]=0|0;
     $64 = HEAP8[$localPath>>0]|0;
     $65 = $64 & 1;
     $66 = ($65<<24>>24)==(0);
     if ($66) {
      $69 = $64&255;
      $70 = $69 >>> 1;
      $72 = $70;
     } else {
      $67 = (($localPath) + 4|0);
      $68 = HEAP32[$67>>2]|0;
      $72 = $68;
     }
     $71 = ($72|0)==(0);
     if ($71) {
      $74 = $58;$recurseLookupOffset$0$ph = 0;
     } else {
      if ($66) {
       $105 = $64&255;
       $106 = $105 >>> 1;
       $108 = $106;
      } else {
       $103 = (($localPath) + 4|0);
       $104 = HEAP32[$103>>2]|0;
       $108 = $104;
      }
      $107 = (($108) + 1)|0;
      $109 = (($58) + 4|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)==(0|0);
      if ($111) {
       $$01$i$i$i = $58;
       while(1) {
        $114 = (($$01$i$i$i) + 8|0);
        $115 = HEAP32[$114>>2]|0;
        $116 = HEAP32[$115>>2]|0;
        $117 = ($116|0)==($$01$i$i$i|0);
        if ($117) {
         $$0$i$i$i = $115;
         break;
        } else {
         $$01$i$i$i = $115;
        }
       }
      } else {
       $$0$i$i$i$i = $110;
       while(1) {
        $112 = HEAP32[$$0$i$i$i$i>>2]|0;
        $113 = ($112|0)==(0|0);
        if ($113) {
         $$0$i$i$i = $$0$i$i$i$i;
         break;
        } else {
         $$0$i$i$i$i = $112;
        }
       }
      }
      HEAP32[$it>>2] = $$0$i$i$i;
      $74 = $$0$i$i$i;$recurseLookupOffset$0$ph = $107;
     }
     $73 = ($74|0)==($57|0);
     L48: do {
      if (!($73)) {
       $75 = (($fileEntryInfoList) + 8|0);
       $76 = (($fileEntryInfoList) + 12|0);
       $77 = (($fileEntryInfoList) + 4|0);
       $78 = (($this) + 20|0);
       $79 = (($78) + 1|0);
       $80 = (($fullPath) + 4|0);
       $81 = (($fullPath) + 1|0);
       $82 = (($fullPath) + 8|0);
       $83 = (($this) + 28|0);
       $84 = (($7) + 1|0);
       $85 = (($fileNamePart) + 1|0);
       $86 = ($flags|0)==(0);
       $87 = (($fileNamePart) + 8|0);
       $88 = $flags & 8;
       $89 = ($88|0)==(0);
       $90 = $flags & 2;
       $91 = ($90|0)==(0);
       $92 = $flags & 32;
       $93 = ($92|0)==(0);
       $94 = $flags & 16;
       $95 = ($94|0)==(0);
       $96 = $flags & 4;
       $97 = ($96|0)==(0);
       $98 = (($7) + 8|0);
       $99 = (($7) + 4|0);
       $100 = (($localPath) + 1|0);
       $101 = (($localPath) + 4|0);
       $102 = (($localPath) + 8|0);
       $123 = $64;$131 = $74;
       L50: while(1) {
        $122 = $123 & 1;
        $124 = ($122<<24>>24)==(0);
        if ($124) {
         $126 = $123&255;
         $127 = $126 >>> 1;
         $129 = $127;
        } else {
         $125 = HEAP32[$101>>2]|0;
         $129 = $125;
        }
        $128 = ($129|0)==(0);
        if (!($128)) {
         $130 = (($131) + 16|0);
         $132 = HEAP8[$130>>0]|0;
         $133 = $132 & 1;
         $134 = ($133<<24>>24)==(0);
         if ($134) {
          $137 = (($130) + 1|0);
          $142 = $137;
         } else {
          $135 = (($131) + 24|0);
          $136 = HEAP32[$135>>2]|0;
          $142 = $136;
         }
         if ($124) {
          $140 = $123&255;
          $141 = $140 >>> 1;
          $143 = $100;$144 = $141;
         } else {
          $138 = HEAP32[$102>>2]|0;
          $139 = HEAP32[$101>>2]|0;
          $143 = $138;$144 = $139;
         }
         $145 = (_strncmp($142,$143,$144)|0);
         $146 = ($145|0)==(0);
         if (!($146)) {
          break L48;
         }
        }
        if ($recurse) {
         label = 62;
        } else {
         $147 = (($131) + 16|0);
         $148 = HEAP8[$147>>0]|0;
         $149 = $148 & 1;
         $150 = ($149<<24>>24)==(0);
         if ($150) {
          $153 = $148&255;
          $154 = $153 >>> 1;
          $156 = $154;
         } else {
          $151 = (($131) + 20|0);
          $152 = HEAP32[$151>>2]|0;
          $156 = $152;
         }
         $155 = ($156>>>0)>($recurseLookupOffset$0$ph>>>0);
         if ($155) {
          if ($150) {
           $159 = (($147) + 1|0);
           $161 = $159;
          } else {
           $157 = (($131) + 24|0);
           $158 = HEAP32[$157>>2]|0;
           $161 = $158;
          }
          $160 = (($161) + ($recurseLookupOffset$0$ph)|0);
          $162 = (($156) - ($recurseLookupOffset$0$ph))|0;
          $163 = (_memchr($160,47,$162)|0);
          $164 = ($163|0)==(0|0);
          if ($164) {
           label = 62;
          } else {
           $165 = $163;
           $166 = $161;
           $167 = (($165) - ($166))|0;
           $168 = ($167|0)==(-1);
           if ($168) {
            label = 62;
           } else {
            $317 = $131;
           }
          }
         } else {
          label = 62;
         }
        }
        do {
         if ((label|0) == 62) {
          label = 0;
          $169 = HEAP32[$75>>2]|0;
          $170 = (($169) + 1)|0;
          HEAP32[$75>>2] = $170;
          $171 = HEAP32[$76>>2]|0;
          $172 = $171 & 2147483647;
          $173 = ($170>>>0)>($172>>>0);
          if ($173) {
           $174 = $171 << 1;
           $175 = ($174|0)==(0);
           $176 = $175 ? 1 : $174;
           $177 = ($172>>>0)<($176>>>0);
           do {
            if ($177) {
             $178 = ($171|0)>(-1);
             if ($178) {
              HEAP32[$76>>2] = $176;
              $179 = HEAP32[$fileEntryInfoList>>2]|0;
              $180 = ($176*1088)|0;
              $181 = HEAP32[$77>>2]|0;
              HEAP32[$0>>2] = $181;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
              $182 = (invoke_iiiiiiii(108,($179|0),($180|0),8,($$byval_copy12|0),0,(650184|0),370)|0);
              $183 = __THREW__; __THREW__ = 0;
              $184 = $183&1;
              if ($184) {
               label = 38;
               break L50;
              }
              HEAP32[$fileEntryInfoList>>2] = $182;
              break;
             } else {
              $185 = ($176*1088)|0;
              $186 = HEAP32[$77>>2]|0;
              HEAP32[$1>>2] = $186;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
              $187 = (invoke_iiiiiii(102,($185|0),8,($$byval_copy12|0),0,(650184|0),352)|0);
              $188 = __THREW__; __THREW__ = 0;
              $189 = $188&1;
              if ($189) {
               label = 38;
               break L50;
              }
              $190 = HEAP32[$fileEntryInfoList>>2]|0;
              $191 = HEAP32[$75>>2]|0;
              $192 = ($191*1088)|0;
              _memcpy(($187|0),($190|0),($192|0))|0;
              HEAP32[$76>>2] = $176;
              HEAP32[$fileEntryInfoList>>2] = $187;
              break;
             }
            }
           } while(0);
           $$pre$i = HEAP32[$75>>2]|0;
           $194 = $$pre$i;
          } else {
           $194 = $170;
          }
          $193 = (($194) + -1)|0;
          $195 = HEAP32[$fileEntryInfoList>>2]|0;
          if ($11) {
           $196 = HEAP8[$78>>0]|0;
           $197 = $196 & 1;
           $198 = ($197<<24>>24)==(0);
           if ($198) {
            $200 = $79;
           } else {
            $199 = HEAP32[$83>>2]|0;
            $200 = $199;
           }
           __THREW__ = 0;
           (invoke_iii(2353,($fullPath|0),($200|0))|0);
           $201 = __THREW__; __THREW__ = 0;
           $202 = $201&1;
           if ($202) {
            label = 38;
            break L50;
           }
           $203 = HEAP8[$fullPath>>0]|0;
           $204 = $203 & 1;
           $205 = ($204<<24>>24)!=(0);
           if ($205) {
            $208 = HEAP32[$fullPath>>2]|0;
            $209 = $208 & -2;
            $210 = (($209) + -1)|0;
            $211 = HEAP32[$80>>2]|0;
            $__cap$0$i$i = $210;$__sz$0$i$i = $211;
           } else {
            $206 = $203&255;
            $207 = $206 >>> 1;
            $__cap$0$i$i = 10;$__sz$0$i$i = $207;
           }
           $212 = ($__sz$0$i$i|0)==($__cap$0$i$i|0);
           if ($212) {
            __THREW__ = 0;
            invoke_viiiiiii(68,($fullPath|0),($__cap$0$i$i|0),1,($__cap$0$i$i|0),($__cap$0$i$i|0),0,0);
            $213 = __THREW__; __THREW__ = 0;
            $214 = $213&1;
            if ($214) {
             label = 38;
             break L50;
            }
            $215 = HEAP8[$fullPath>>0]|0;
            $216 = $215 & 1;
            $217 = ($216<<24>>24)==(0);
            if ($217) {
             label = 81;
            } else {
             label = 82;
            }
           } else {
            if ($205) {
             label = 82;
            } else {
             label = 81;
            }
           }
           if ((label|0) == 81) {
            label = 0;
            $218 = $__sz$0$i$i << 1;
            $219 = (($218) + 2)|0;
            $220 = $219&255;
            HEAP8[$fullPath>>0] = $220;
            $__p$0$sum$pre$i$i = (($__sz$0$i$i) + 1)|0;
            $$pn$i$i = $81;$__p$0$sum$pre$phi$i$iZZZ2D = $__p$0$sum$pre$i$i;
           }
           else if ((label|0) == 82) {
            label = 0;
            $221 = HEAP32[$82>>2]|0;
            $222 = (($__sz$0$i$i) + 1)|0;
            HEAP32[$80>>2] = $222;
            $$pn$i$i = $221;$__p$0$sum$pre$phi$i$iZZZ2D = $222;
           }
           $__p$0$i$i = (($$pn$i$i) + ($__sz$0$i$i)|0);
           HEAP8[$__p$0$i$i>>0] = 47;
           $223 = (($$pn$i$i) + ($__p$0$sum$pre$phi$i$iZZZ2D)|0);
           HEAP8[$223>>0] = 0;
           $224 = (($131) + 16|0);
           $225 = HEAP8[$224>>0]|0;
           $226 = $225 & 1;
           $227 = ($226<<24>>24)==(0);
           if ($227) {
            $230 = (($224) + 1|0);
            $231 = $230;
           } else {
            $228 = (($131) + 24|0);
            $229 = HEAP32[$228>>2]|0;
            $231 = $229;
           }
           $232 = (_strlen(($231|0))|0);
           __THREW__ = 0;
           (invoke_iiii(1529,($fullPath|0),($231|0),($232|0))|0);
           $233 = __THREW__; __THREW__ = 0;
           $234 = $233&1;
           if ($234) {
            label = 38;
            break L50;
           }
          } else {
           $235 = (($131) + 16|0);
           $236 = HEAP8[$235>>0]|0;
           $237 = $236 & 1;
           $238 = ($237<<24>>24)==(0);
           if ($238) {
            $241 = (($235) + 1|0);
            $242 = $241;
           } else {
            $239 = (($131) + 24|0);
            $240 = HEAP32[$239>>2]|0;
            $242 = $240;
           }
           __THREW__ = 0;
           (invoke_iii(2353,($fullPath|0),($242|0))|0);
           $243 = __THREW__; __THREW__ = 0;
           $244 = $243&1;
           if ($244) {
            label = 38;
            break L50;
           }
          }
          $245 = (($195) + (($193*1088)|0)|0);
          $246 = HEAP8[$fullPath>>0]|0;
          $247 = $246 & 1;
          $248 = ($247<<24>>24)==(0);
          $249 = HEAP32[$82>>2]|0;
          $$ = $248 ? $81 : $249;
          (_strncpy(($245|0),($$|0),1040)|0);
          $250 = ((($195) + (($193*1088)|0)|0) + 1039|0);
          HEAP8[$250>>0] = 0;
          $251 = HEAP32[$it>>2]|0;
          $252 = (($251) + 28|0);
          $253 = HEAP32[$252>>2]|0;
          $254 = HEAP32[$253>>2]|0;
          $255 = ($254|0)==(0|0);
          $256 = ((($195) + (($193*1088)|0)|0) + 1080|0);
          $257 = $255&1;
          HEAP8[$256>>0] = $257;
          $258 = ((($195) + (($193*1088)|0)|0) + 1072|0);
          $259 = (($253) + 4|0);
          $260 = $259;
          $261 = $260;
          $262 = HEAP32[$261>>2]|0;
          $263 = (($260) + 4)|0;
          $264 = $263;
          $265 = HEAP32[$264>>2]|0;
          $266 = $258;
          $267 = $266;
          HEAP32[$267>>2] = $262;
          $268 = (($266) + 4)|0;
          $269 = $268;
          HEAP32[$269>>2] = $265;
          $270 = ((($195) + (($193*1088)|0)|0) + 1081|0);
          HEAP8[$270>>0] = 0;
          $271 = ((($195) + (($193*1088)|0)|0) + 1082|0);
          HEAP8[$271>>0] = 0;
          $272 = HEAP8[$fullPath>>0]|0;
          $273 = $272 & 1;
          $274 = ($273<<24>>24)==(0);
          $275 = HEAP32[$82>>2]|0;
          $276 = $274 ? $81 : $275;
          $277 = (_strlen(($276|0))|0);
          $278 = ($277>>>0)>(4294967279);
          if ($278) {
           label = 92;
           break L50;
          }
          $281 = ($277>>>0)<(11);
          if ($281) {
           $282 = $277 << 1;
           $283 = $282&255;
           HEAP8[$7>>0] = $283;
           $__p$0$i$i$i22 = $84;
          } else {
           $284 = (($277) + 16)|0;
           $285 = $284 & -16;
           __THREW__ = 0;
           $286 = (invoke_ii(2988,($285|0))|0);
           $287 = __THREW__; __THREW__ = 0;
           $288 = $287&1;
           if ($288) {
            label = 38;
            break L50;
           }
           HEAP32[$98>>2] = $286;
           $289 = $285 | 1;
           HEAP32[$7>>2] = $289;
           HEAP32[$99>>2] = $277;
           $__p$0$i$i$i22 = $286;
          }
          _memcpy(($__p$0$i$i$i22|0),($276|0),($277|0))|0;
          $290 = (($__p$0$i$i$i22) + ($277)|0);
          HEAP8[$290>>0] = 0;
          __THREW__ = 0;
          invoke_vii(2754,($fileNamePart|0),($7|0));
          $291 = __THREW__; __THREW__ = 0;
          $292 = $291&1;
          if ($292) {
           label = 112;
           break L50;
          }
          $293 = HEAP8[$7>>0]|0;
          $294 = $293 & 1;
          $295 = ($294<<24>>24)==(0);
          if (!($295)) {
           $296 = HEAP32[$98>>2]|0;
           __ZdlPv($296);
          }
          $297 = HEAP8[$fileNamePart>>0]|0;
          $298 = $297 & 1;
          $299 = ($298<<24>>24)==(0);
          $300 = HEAP32[$87>>2]|0;
          $$50 = $299 ? $85 : $300;
          do {
           if (!($86)) {
            $301 = HEAP8[$256>>0]|0;
            $302 = ($301<<24>>24)==(0);
            $303 = HEAP8[$271>>0]|0;
            $304 = ($303<<24>>24)==(0);
            do {
             if ($302) {
              if ($304) {
               if ($89) {
                label = 109;
                break;
               } else {
                break;
               }
              } else {
               if ($91) {
                label = 109;
                break;
               } else {
                break;
               }
              }
             } else {
              if ($304) {
               if ($95) {
                label = 109;
                break;
               } else {
                break;
               }
              } else {
               if ($97) {
                label = 109;
                break;
               } else {
                break;
               }
              }
             }
            } while(0);
            if ((label|0) == 109) {
             label = 0;
             if ($93) {
              break;
             }
             $305 = HEAP8[$$50>>0]|0;
             $306 = ($305<<24>>24)==(46);
             if (!($306)) {
              break;
             }
            }
            $307 = HEAP32[$75>>2]|0;
            $308 = (($307) + -1)|0;
            HEAP32[$75>>2] = $308;
           }
          } while(0);
          if ($299) {
           $317 = $251;
           break;
          }
          $315 = HEAP32[$87>>2]|0;
          __ZdlPv($315);
          $317 = $251;
         }
        } while(0);
        $316 = (($317) + 4|0);
        $318 = HEAP32[$316>>2]|0;
        $319 = ($318|0)==(0|0);
        if ($319) {
         $$01$i$i$i15 = $317;
         while(1) {
          $322 = (($$01$i$i$i15) + 8|0);
          $323 = HEAP32[$322>>2]|0;
          $324 = HEAP32[$323>>2]|0;
          $325 = ($324|0)==($$01$i$i$i15|0);
          if ($325) {
           $$0$i$i$i17 = $323;
           break;
          } else {
           $$01$i$i$i15 = $323;
          }
         }
        } else {
         $$0$i$i$i$i13 = $318;
         while(1) {
          $320 = HEAP32[$$0$i$i$i$i13>>2]|0;
          $321 = ($320|0)==(0|0);
          if ($321) {
           $$0$i$i$i17 = $$0$i$i$i$i13;
           break;
          } else {
           $$0$i$i$i$i13 = $320;
          }
         }
        }
        HEAP32[$it>>2] = $$0$i$i$i17;
        $326 = ($$0$i$i$i17|0)==($57|0);
        if ($326) {
         break L48;
        }
        $$pre = HEAP8[$localPath>>0]|0;
        $123 = $$pre;$131 = $$0$i$i$i17;
       }
       do {
        if ((label|0) == 38) {
         $118 = ___cxa_find_matching_catch()|0;
         $119 = tempRet0;
         $lpad$phi$index = $118;$lpad$phi$index2 = $119;
         label = 40;
        }
        else if ((label|0) == 92) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $279 = __THREW__; __THREW__ = 0;
         $280 = $279&1;
         if ($280) {
          $120 = ___cxa_find_matching_catch()|0;
          $121 = tempRet0;
          $lpad$phi$index = $120;$lpad$phi$index2 = $121;
          label = 40;
          break;
         } else {
          // unreachable;
         }
        }
        else if ((label|0) == 112) {
         $309 = ___cxa_find_matching_catch()|0;
         $310 = tempRet0;
         $311 = HEAP8[$7>>0]|0;
         $312 = $311 & 1;
         $313 = ($312<<24>>24)==(0);
         if ($313) {
          $$02 = $310;$$03 = $309;
         } else {
          $314 = HEAP32[$98>>2]|0;
          __ZdlPv($314);
          $$02 = $310;$$03 = $309;
         }
        }
       } while(0);
       if ((label|0) == 40) {
        $$02 = $lpad$phi$index2;$$03 = $lpad$phi$index;
       }
       $336 = HEAP8[$fullPath>>0]|0;
       $337 = $336 & 1;
       $338 = ($337<<24>>24)==(0);
       if ($338) {
        $$2 = $$02;$$25 = $$03;
        break L1;
       }
       $339 = HEAP32[$82>>2]|0;
       HEAP32[$4>>2] = 90;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
       invoke_vii(2591,($339|0),($$byval_copy12|0));
       $340 = __THREW__; __THREW__ = 0;
       $341 = $340&1;
       if (!($341)) {
        $$2 = $$02;$$25 = $$03;
        break L1;
       }
       $342 = ___cxa_find_matching_catch()|0;
       $343 = tempRet0;
       ___cxa_call_unexpected(($342|0));
       // unreachable;
      }
     } while(0);
     $327 = HEAP8[$fullPath>>0]|0;
     $328 = $327 & 1;
     $329 = ($328<<24>>24)==(0);
     if ($329) {
      $$0 = 1;
     } else {
      $330 = (($fullPath) + 8|0);
      $331 = HEAP32[$330>>2]|0;
      HEAP32[$0>>2] = 90;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($331|0),($$byval_copy12|0));
      $332 = __THREW__; __THREW__ = 0;
      $333 = $332&1;
      if ($333) {
       $334 = ___cxa_find_matching_catch()|0;
       $335 = tempRet0;
       ___cxa_call_unexpected(($334|0));
       // unreachable;
      } else {
       $$0 = 1;
      }
     }
    }
    $344 = HEAP8[$localPath>>0]|0;
    $345 = $344 & 1;
    $346 = ($345<<24>>24)==(0);
    if ($346) {
     STACKTOP = sp;return ($$0|0);
    }
    $347 = (($localPath) + 8|0);
    $348 = HEAP32[$347>>2]|0;
    HEAP32[$1>>2] = 46;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($348|0),($$byval_copy12|0));
    $349 = __THREW__; __THREW__ = 0;
    $350 = $349&1;
    if ($350) {
     $351 = ___cxa_find_matching_catch()|0;
     $352 = tempRet0;
     ___cxa_call_unexpected(($351|0));
     // unreachable;
    } else {
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $60 = ___cxa_find_matching_catch()|0;
  $61 = tempRet0;
  $$2 = $61;$$25 = $60;
 }
 $353 = HEAP8[$localPath>>0]|0;
 $354 = $353 & 1;
 $355 = ($354<<24>>24)==(0);
 if ($355) {
  ___resumeException($$25|0);
  // unreachable;
 }
 $356 = (($localPath) + 8|0);
 $357 = HEAP32[$356>>2]|0;
 HEAP32[$5>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$5+0>>2]|0;
 invoke_vii(2591,($357|0),($$byval_copy12|0));
 $358 = __THREW__; __THREW__ = 0;
 $359 = $358&1;
 if ($359) {
  $360 = ___cxa_find_matching_catch()|0;
  $361 = tempRet0;
  ___cxa_call_unexpected(($360|0));
  // unreachable;
 } else {
  ___resumeException($$25|0);
  // unreachable;
 }
 return 0|0;
}
function __Z16TrimSlashInplaceINSt3__112basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEERT_S9_($path) {
 $path = $path|0;
 var $$in = 0, $$in2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$path>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($path) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8|0)==(0);
 if ($7) {
  STACKTOP = sp;return ($path|0);
 }
 if ($2) {
  $13 = $0&255;
  $14 = $13 >>> 1;
  $15 = (($path) + 1|0);
  $$in = $14;$18 = $15;
 } else {
  $9 = (($path) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($path) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $$in = $10;$18 = $12;
 }
 $16 = (($$in) + -1)|0;
 $17 = (($18) + ($16)|0);
 $19 = HEAP8[$17>>0]|0;
 $20 = ($19<<24>>24)==(47);
 if (!($20)) {
  STACKTOP = sp;return ($path|0);
 }
 if ($2) {
  $23 = $0&255;
  $24 = $23 >>> 1;
  $25 = $0&255;
  $26 = $25 >>> 1;
  $$in2 = $24;$29 = $26;
 } else {
  $21 = (($path) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $$in2 = $22;$29 = $22;
 }
 $27 = (($$in2) + -1)|0;
 $28 = ($29>>>0)<($27>>>0);
 if ($28) {
  $30 = (($27) - ($29))|0;
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE6appendEjc($path,$30,0)|0);
  STACKTOP = sp;return ($path|0);
 }
 if ($2) {
  $35 = ((($path) + ($27)|0) + 1|0);
  HEAP8[$35>>0] = 0;
  $36 = $27 << 1;
  $37 = $36&255;
  HEAP8[$path>>0] = $37;
  STACKTOP = sp;return ($path|0);
 } else {
  $31 = (($path) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + ($27)|0);
  HEAP8[$33>>0] = 0;
  $34 = (($path) + 4|0);
  HEAP32[$34>>2] = $27;
  STACKTOP = sp;return ($path|0);
 }
 return 0|0;
}
function __ZN16MemoryFileSystem5TouchER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK16MemoryFileSystem6ExistsERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $goodPath$i = 0, $it$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $goodPath$i = sp + 4|0;
 $it$i = sp + 16|0;
 ;HEAP32[$goodPath$i+0>>2]=0|0;HEAP32[$goodPath$i+4>>2]=0|0;HEAP32[$goodPath$i+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1937,($this|0),($data|0),($goodPath$i|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP8[$goodPath$i>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   ___resumeException($9|0);
   // unreachable;
  }
  $14 = (($goodPath$i) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($15|0),($$byval_copy1|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   ___cxa_call_unexpected(($18|0));
   // unreachable;
  } else {
   ___resumeException($9|0);
   // unreachable;
  }
 }
 $3 = (($this) + 4|0);
 __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($it$i,$3,$goodPath$i);
 $4 = (($this) + 8|0);
 $5 = HEAP32[$it$i>>2]|0;
 $6 = ($5|0)==($4|0);
 if ($6) {
  $$0$i = 0;
 } else {
  $7 = (($5) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $$0$i = $8;
 }
 $20 = HEAP8[$goodPath$i>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $29 = ($$0$i|0)!=(0|0);
  STACKTOP = sp;return ($29|0);
 }
 $23 = (($goodPath$i) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$0>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($24|0),($$byval_copy1|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  ___cxa_call_unexpected(($27|0));
  // unreachable;
 } else {
  $29 = ($$0$i|0)!=(0|0);
  STACKTOP = sp;return ($29|0);
 }
 return 0|0;
}
function __ZN16MemoryFileSystem4NameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (650192|0);
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE12__find_equalISC_EERPNS_16__tree_node_baseIPvEESO_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$$i$i$i$i5 = 0, $$$$i$i$i$i5$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$$i$i$i$i4 = 0, $$$i$i$i$i4$us = 0, $$0 = 0, $$lcssa = 0, $$lcssa9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__nd$0$in = 0, $__nd$0$in$lcssa = 0, $__nd$0$in$lcssa7 = 0, $__nd$0$in$lcssa8 = 0, $__nd$0$in$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $97 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $97;
  $$0 = $97;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__v>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__v) + 1|0);
 $9 = (($__v) + 8|0);
 $10 = (($__v) + 4|0);
 L5: do {
  if ($5) {
   $__nd$0$in$us = $1;
   while(1) {
    $11 = (($__nd$0$in$us) + 16|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = $12 & 1;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     $19 = $12&255;
     $20 = $19 >>> 1;
     $21 = (($11) + 1|0);
     $23 = $20;$25 = $21;
    } else {
     $15 = (($__nd$0$in$us) + 20|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($__nd$0$in$us) + 24|0);
     $18 = HEAP32[$17>>2]|0;
     $23 = $16;$25 = $18;
    }
    $22 = ($23>>>0)<($7>>>0);
    $24 = $22 ? $23 : $7;
    $26 = (_memcmp($8,$25,$24)|0);
    $27 = ($26|0)==(0);
    if ($27) {
     $28 = ($7>>>0)<($23>>>0);
     $$$i$i$i$i4$us = $22&1;
     $$$$i$i$i$i5$us = $28 ? -1 : $$$i$i$i$i4$us;
     $30 = $$$$i$i$i$i5$us;
    } else {
     $30 = $26;
    }
    $29 = ($30|0)<(0);
    if ($29) {
     $50 = HEAP32[$__nd$0$in$us>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      $$lcssa9 = $__nd$0$in$us;$__nd$0$in$lcssa8 = $__nd$0$in$us;
      label = 24;
      break;
     } else {
      $__nd$0$in$us = $50;
      continue;
     }
    }
    if ($14) {
     $35 = $12&255;
     $36 = $35 >>> 1;
     $37 = (($11) + 1|0);
     $39 = $36;$41 = $37;
    } else {
     $31 = (($__nd$0$in$us) + 20|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($__nd$0$in$us) + 24|0);
     $34 = HEAP32[$33>>2]|0;
     $39 = $32;$41 = $34;
    }
    $38 = ($7>>>0)<($39>>>0);
    $40 = $38 ? $7 : $39;
    $42 = (_memcmp($41,$8,$40)|0);
    $43 = ($42|0)==(0);
    if ($43) {
     $44 = ($39>>>0)<($7>>>0);
     $$$i$i$i$i$us = $38&1;
     $$$$i$i$i$i$us = $44 ? -1 : $$$i$i$i$i$us;
     $46 = $$$$i$i$i$i$us;
    } else {
     $46 = $42;
    }
    $45 = ($46|0)<(0);
    if (!($45)) {
     $__nd$0$in$lcssa = $__nd$0$in$us;
     label = 33;
     break L5;
    }
    $47 = (($__nd$0$in$us) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     $$lcssa = $47;$__nd$0$in$lcssa7 = $__nd$0$in$us;
     label = 32;
     break;
    } else {
     $__nd$0$in$us = $48;
    }
   }
  } else {
   $__nd$0$in = $1;
   while(1) {
    $52 = (($__nd$0$in) + 16|0);
    $53 = HEAP32[$10>>2]|0;
    $54 = HEAP8[$52>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if ($56) {
     $61 = $54&255;
     $62 = $61 >>> 1;
     $63 = (($52) + 1|0);
     $66 = $62;$68 = $63;
    } else {
     $57 = (($__nd$0$in) + 20|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($__nd$0$in) + 24|0);
     $60 = HEAP32[$59>>2]|0;
     $66 = $58;$68 = $60;
    }
    $64 = HEAP32[$9>>2]|0;
    $65 = ($66>>>0)<($53>>>0);
    $67 = $65 ? $66 : $53;
    $69 = (_memcmp($64,$68,$67)|0);
    $70 = ($69|0)==(0);
    if ($70) {
     $71 = ($53>>>0)<($66>>>0);
     $$$i$i$i$i4 = $65&1;
     $$$$i$i$i$i5 = $71 ? -1 : $$$i$i$i$i4;
     $73 = $$$$i$i$i$i5;
    } else {
     $73 = $69;
    }
    $72 = ($73|0)<(0);
    if ($72) {
     $74 = HEAP32[$__nd$0$in>>2]|0;
     $75 = ($74|0)==(0|0);
     if ($75) {
      $$lcssa9 = $__nd$0$in;$__nd$0$in$lcssa8 = $__nd$0$in;
      label = 24;
      break;
     } else {
      $__nd$0$in = $74;
      continue;
     }
    }
    if ($56) {
     $80 = $54&255;
     $81 = $80 >>> 1;
     $82 = (($52) + 1|0);
     $86 = $81;$88 = $82;
    } else {
     $76 = (($__nd$0$in) + 20|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($__nd$0$in) + 24|0);
     $79 = HEAP32[$78>>2]|0;
     $86 = $77;$88 = $79;
    }
    $83 = HEAP32[$10>>2]|0;
    $84 = HEAP32[$9>>2]|0;
    $85 = ($83>>>0)<($86>>>0);
    $87 = $85 ? $83 : $86;
    $89 = (_memcmp($88,$84,$87)|0);
    $90 = ($89|0)==(0);
    if ($90) {
     $91 = ($86>>>0)<($83>>>0);
     $$$i$i$i$i = $85&1;
     $$$$i$i$i$i = $91 ? -1 : $$$i$i$i$i;
     $93 = $$$$i$i$i$i;
    } else {
     $93 = $89;
    }
    $92 = ($93|0)<(0);
    if (!($92)) {
     $__nd$0$in$lcssa = $__nd$0$in;
     label = 33;
     break L5;
    }
    $94 = (($__nd$0$in) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0|0);
    if ($96) {
     $$lcssa = $94;$__nd$0$in$lcssa7 = $__nd$0$in;
     label = 32;
     break;
    } else {
     $__nd$0$in = $95;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa8;
  $$0 = $$lcssa9;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa7;
  $$0 = $$lcssa;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE16__construct_nodeERKSC_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 HEAP32[$0>>2] = 46;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Z15malloc_internaljj10MemLabelIdiPKci(32,16,$$byval_copy2,0,650184,79)|0);
 $4 = $2;
 $5 = (($3) + 16|0);
 $6 = HEAP8[$__v>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  ;HEAP32[$5+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$__v+8>>2]|0;
  $29 = (($3) + 28|0);
  $30 = (($__v) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$29>>2] = $31;
  HEAP32[$agg$result>>2] = $3;
  $32 = (($agg$result) + 4|0);
  $33 = $32;
  $34 = $33;
  HEAP32[$34>>2] = $4;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = 1;
  STACKTOP = sp;return;
 }
 $9 = (($__v) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($__v) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12>>>0)>(2147483631);
 do {
  if ($13) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  } else {
   $16 = ($12>>>0)<(11);
   if ($16) {
    $17 = $12 << 1;
    $18 = $17&255;
    HEAP8[$5>>0] = $18;
    $19 = (($3) + 17|0);
    $__p$0$i$i$i$i$i$i$i$i = $19;
   } else {
    $20 = (($12) + 16)|0;
    $21 = $20 & -16;
    HEAP32[$0>>2] = 46;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (invoke_iiiiiii(102,($21|0),16,($$byval_copy2|0),0,(650184|0),79)|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = (($3) + 24|0);
    HEAP32[$25>>2] = $22;
    $26 = $21 | 1;
    HEAP32[$5>>2] = $26;
    $27 = (($3) + 20|0);
    HEAP32[$27>>2] = $12;
    $__p$0$i$i$i$i$i$i$i$i = $22;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($10|0),($12|0))|0;
   $28 = (($__p$0$i$i$i$i$i$i$i$i) + ($12)|0);
   HEAP8[$28>>0] = 0;
   $29 = (($3) + 28|0);
   $30 = (($__v) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[$29>>2] = $31;
   HEAP32[$agg$result>>2] = $3;
   $32 = (($agg$result) + 4|0);
   $33 = $32;
   $34 = $33;
   HEAP32[$34>>2] = $4;
   $35 = (($33) + 4)|0;
   $36 = $35;
   HEAP32[$36>>2] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 $39 = ($3|0)==(0|0);
 if ($39) {
  ___resumeException($37|0);
  // unreachable;
 }
 HEAP32[$1>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($3|0),($$byval_copy2|0));
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  ___cxa_call_unexpected(($42|0));
  // unreachable;
 } else {
  ___resumeException($37|0);
  // unreachable;
 }
}
function __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$i = 0, $$$i$i$i$i = 0, $$$i$i$i$i$i = 0, $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = HEAP8[$__v>>0]|0;
  $5 = $4 & 1;
  $6 = ($5<<24>>24)==(0);
  $7 = $4&255;
  $8 = $7 >>> 1;
  $9 = (($__v) + 1|0);
  $10 = (($__v) + 8|0);
  $11 = (($__v) + 4|0);
  $$0$ph7$i = $2;$$01$ph6$i$in = $1;
  L3: while(1) {
   $$013$i$in = $$01$ph6$i$in;
   while(1) {
    $12 = (($$013$i$in) + 16|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     $18 = $13&255;
     $19 = $18 >>> 1;
     $27 = $19;
    } else {
     $16 = (($$013$i$in) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $27 = $17;
    }
    if ($6) {
     $26 = $8;
    } else {
     $20 = HEAP32[$11>>2]|0;
     $26 = $20;
    }
    if ($15) {
     $23 = (($12) + 1|0);
     $29 = $23;
    } else {
     $21 = (($$013$i$in) + 24|0);
     $22 = HEAP32[$21>>2]|0;
     $29 = $22;
    }
    if ($6) {
     $30 = $9;
    } else {
     $24 = HEAP32[$10>>2]|0;
     $30 = $24;
    }
    $25 = ($26>>>0)<($27>>>0);
    $28 = $25 ? $26 : $27;
    $31 = (_memcmp($29,$30,$28)|0);
    $32 = ($31|0)==(0);
    if ($32) {
     $33 = ($27>>>0)<($26>>>0);
     $$$i$i$i$i$i = $25&1;
     $$$$i$i$i$i$i = $33 ? -1 : $$$i$i$i$i$i;
     $35 = $$$$i$i$i$i$i;
    } else {
     $35 = $31;
    }
    $34 = ($35|0)<(0);
    if (!($34)) {
     break;
    }
    $38 = (($$013$i$in) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$0$ph5$i = $$0$ph7$i;
     break L3;
    } else {
     $$013$i$in = $39;
    }
   }
   $36 = HEAP32[$$013$i$in>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    $$0$ph5$i = $$013$i$in;
    break;
   } else {
    $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $36;
   }
  }
  $41 = ($$0$ph5$i|0)==($2|0);
  if (!($41)) {
   $42 = (($$0$ph5$i) + 16|0);
   if ($6) {
    $57 = $8;
   } else {
    $43 = HEAP32[$11>>2]|0;
    $57 = $43;
   }
   $44 = HEAP8[$42>>0]|0;
   $45 = $44 & 1;
   $46 = ($45<<24>>24)==(0);
   if ($46) {
    $49 = $44&255;
    $50 = $49 >>> 1;
    $56 = $50;
   } else {
    $47 = (($$0$ph5$i) + 20|0);
    $48 = HEAP32[$47>>2]|0;
    $56 = $48;
   }
   if ($6) {
    $59 = $9;
   } else {
    $51 = HEAP32[$10>>2]|0;
    $59 = $51;
   }
   if ($46) {
    $54 = (($42) + 1|0);
    $60 = $54;
   } else {
    $52 = (($$0$ph5$i) + 24|0);
    $53 = HEAP32[$52>>2]|0;
    $60 = $53;
   }
   $55 = ($56>>>0)<($57>>>0);
   $58 = $55 ? $56 : $57;
   $61 = (_memcmp($59,$60,$58)|0);
   $62 = ($61|0)==(0);
   if ($62) {
    $63 = ($57>>>0)<($56>>>0);
    $$$i$i$i$i = $55&1;
    $$$$i$i$i$i = $63 ? -1 : $$$i$i$i$i;
    $65 = $$$$i$i$i$i;
   } else {
    $65 = $61;
   }
   $64 = ($65|0)<(0);
   if (!($64)) {
    HEAP32[$agg$result>>2] = $$0$ph5$i;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE5eraseENS_21__tree_const_iteratorISC_PNS_11__tree_nodeISC_PvEEiEE($agg$result,$this,$__p) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__p = $__p|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$__p>>2]|0;
 HEAP32[$agg$result>>2] = $2;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$01$i$i = $2;
  while(1) {
   $8 = (($$01$i$i) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($$01$i$i|0);
   if ($11) {
    $$0$i$i = $9;
    break;
   } else {
    $$01$i$i = $9;
   }
  }
 } else {
  $$0$i$i$i = $4;
  while(1) {
   $6 = HEAP32[$$0$i$i$i>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $$0$i$i = $$0$i$i$i;
    break;
   } else {
    $$0$i$i$i = $6;
   }
  }
 }
 HEAP32[$agg$result>>2] = $$0$i$i;
 $12 = HEAP32[$this>>2]|0;
 $13 = ($12|0)==($2|0);
 if ($13) {
  HEAP32[$this>>2] = $$0$i$i;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = (($2) + 16|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  $21 = (($2) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($22|0),($$byval_copy1|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   ___cxa_call_unexpected(($25|0));
   // unreachable;
  }
 }
 $27 = (($this) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($28,$2);
 HEAP32[$1>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($2|0),($$byval_copy1|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  ___cxa_call_unexpected(($31|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE4findIS8_EENS_15__tree_iteratorISC_PNS_11__tree_nodeISC_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$i = 0, $$$i$i$i$i = 0, $$$i$i$i$i$i = 0, $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = HEAP8[$__v>>0]|0;
  $5 = $4 & 1;
  $6 = ($5<<24>>24)==(0);
  $7 = $4&255;
  $8 = $7 >>> 1;
  $9 = (($__v) + 1|0);
  $10 = (($__v) + 8|0);
  $11 = (($__v) + 4|0);
  $$0$ph7$i = $2;$$01$ph6$i$in = $1;
  L3: while(1) {
   $$013$i$in = $$01$ph6$i$in;
   while(1) {
    $12 = (($$013$i$in) + 16|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     $18 = $13&255;
     $19 = $18 >>> 1;
     $27 = $19;
    } else {
     $16 = (($$013$i$in) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $27 = $17;
    }
    if ($6) {
     $26 = $8;
    } else {
     $20 = HEAP32[$11>>2]|0;
     $26 = $20;
    }
    if ($15) {
     $23 = (($12) + 1|0);
     $29 = $23;
    } else {
     $21 = (($$013$i$in) + 24|0);
     $22 = HEAP32[$21>>2]|0;
     $29 = $22;
    }
    if ($6) {
     $30 = $9;
    } else {
     $24 = HEAP32[$10>>2]|0;
     $30 = $24;
    }
    $25 = ($26>>>0)<($27>>>0);
    $28 = $25 ? $26 : $27;
    $31 = (_memcmp($29,$30,$28)|0);
    $32 = ($31|0)==(0);
    if ($32) {
     $33 = ($27>>>0)<($26>>>0);
     $$$i$i$i$i$i = $25&1;
     $$$$i$i$i$i$i = $33 ? -1 : $$$i$i$i$i$i;
     $35 = $$$$i$i$i$i$i;
    } else {
     $35 = $31;
    }
    $34 = ($35|0)<(0);
    if (!($34)) {
     break;
    }
    $38 = (($$013$i$in) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$0$ph5$i = $$0$ph7$i;
     break L3;
    } else {
     $$013$i$in = $39;
    }
   }
   $36 = HEAP32[$$013$i$in>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    $$0$ph5$i = $$013$i$in;
    break;
   } else {
    $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $36;
   }
  }
  $41 = ($$0$ph5$i|0)==($2|0);
  if (!($41)) {
   $42 = (($$0$ph5$i) + 16|0);
   if ($6) {
    $57 = $8;
   } else {
    $43 = HEAP32[$11>>2]|0;
    $57 = $43;
   }
   $44 = HEAP8[$42>>0]|0;
   $45 = $44 & 1;
   $46 = ($45<<24>>24)==(0);
   if ($46) {
    $49 = $44&255;
    $50 = $49 >>> 1;
    $56 = $50;
   } else {
    $47 = (($$0$ph5$i) + 20|0);
    $48 = HEAP32[$47>>2]|0;
    $56 = $48;
   }
   if ($6) {
    $59 = $9;
   } else {
    $51 = HEAP32[$10>>2]|0;
    $59 = $51;
   }
   if ($46) {
    $54 = (($42) + 1|0);
    $60 = $54;
   } else {
    $52 = (($$0$ph5$i) + 24|0);
    $53 = HEAP32[$52>>2]|0;
    $60 = $53;
   }
   $55 = ($56>>>0)<($57>>>0);
   $58 = $55 ? $56 : $57;
   $61 = (_memcmp($59,$60,$58)|0);
   $62 = ($61|0)==(0);
   if ($62) {
    $63 = ($57>>>0)<($56>>>0);
    $$$i$i$i$i = $55&1;
    $$$$i$i$i$i = $63 ? -1 : $$$i$i$i$i;
    $65 = $$$$i$i$i$i;
   } else {
    $65 = $61;
   }
   $64 = ($65|0)<(0);
   if (!($64)) {
    HEAP32[$agg$result>>2] = $$0$ph5$i;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE7destroyEPNS_11__tree_nodeISC_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($__nd|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE7destroyEPNS_11__tree_nodeISC_PvEE($this,$3);
 $4 = (($__nd) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE7destroyEPNS_11__tree_nodeISC_PvEE($this,$5);
 $6 = (($__nd) + 16|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = (($__nd) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = 46;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($11|0),($$byval_copy1|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   ___cxa_call_unexpected(($14|0));
   // unreachable;
  }
 }
 HEAP32[$1>>2] = 46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy1|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  ___cxa_call_unexpected(($18|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN10MemoryFileC2EP14MemoryFileData14FilePermission10MemLabelId($this,$data,$permissions,$allocLabel) {
 $this = $this|0;
 $data = $data|0;
 $permissions = $permissions|0;
 $allocLabel = $allocLabel|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((650200 + 8|0));
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $data;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $permissions;
 $4 = HEAP32[$allocLabel>>2]|0;
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 16|0);
 $7 = $6;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 $11 = ($data|0)==(0|0);
 if (!($11)) {
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 1)|0;
  HEAP32[$25>>2] = $27;
  $28 = HEAP32[$25>>2]|0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $12 = (invoke_iiiiiii(103,40,($$byval_copy2|0),0,16,(650264|0),13)|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $$0 = $20;$$01 = $19;
  ___resumeException($$01|0);
  // unreachable;
 }
 $15 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $15;
 $16 = HEAP32[650272>>2]|0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1939,($12|0),($$byval_copy2|0),($16|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if (!($18)) {
  HEAP32[$2>>2] = $12;
  STACKTOP = sp;return;
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($12|0),($$byval_copy2|0),0,16,(650264|0),13);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $29 = ___cxa_find_matching_catch(0|0)|0;
  $30 = tempRet0;
  ___clang_call_terminate($29);
  // unreachable;
 } else {
  $$0 = $22;$$01 = $21;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN10MemoryFileD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((650200 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + -1)|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$6>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 invoke_vi($12|0,($2|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZdlPv($this);
  ___resumeException($17|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $5;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($2|0),($$byval_copy|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZdlPv($this);
  ___resumeException($17|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN10MemoryFileD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((650200 + 8|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + -1)|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$6>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = HEAP32[$2>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($2);
  HEAP32[$0>>2] = $5;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
 }
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10MemoryFile5CloseEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + -1)|0;
 HEAP32[$6>>2] = $8;
 $9 = HEAP32[$6>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = HEAP32[$2>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($2);
  HEAP32[$0>>2] = $5;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
 }
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return 1;
}
function __ZN10MemoryFile4ReadEyyPvPy($this,$0,$1,$2,$3,$buffer,$actual) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & -3;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$5>>2]|0;
 $12 = (($11) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiiiiii[$13 & 255]($5,$0,$1,$2,$3,$buffer)|0);
 $15 = tempRet0;
 $16 = (_i64Add(($14|0),($15|0),($0|0),($1|0))|0);
 $17 = tempRet0;
 $18 = (($this) + 16|0);
 $19 = $18;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = ($actual|0)==(0|0);
 if ($23) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = $actual;
 $25 = $24;
 HEAP32[$25>>2] = $14;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $15;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10MemoryFile4ReadEyPvPy($this,$0,$1,$buffer,$actual) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 16|0);
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiiii[$4 & 127]($this,$8,$11,$0,$1,$buffer,$actual)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN10MemoryFile5WriteEyyPKvPy($this,$0,$1,$2,$3,$buffer,$actual) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[$5>>2]|0;
 $11 = (($10) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iiiiiii[$12 & 255]($5,$0,$1,$2,$3,$buffer)|0);
 $14 = tempRet0;
 $15 = (_i64Add(($13|0),($14|0),($0|0),($1|0))|0);
 $16 = tempRet0;
 $17 = (($this) + 16|0);
 $18 = $17;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = ($actual|0)==(0|0);
 if ($22) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = $actual;
 $24 = $23;
 HEAP32[$24>>2] = $13;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $14;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10MemoryFile5WriteEyPKvPy($this,$0,$1,$buffer,$actual) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 16|0);
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiiii[$4 & 127]($this,$8,$11,$0,$1,$buffer,$actual)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN10MemoryFile4SeekEy10FileOrigin($this,$0,$1,$origin) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $origin = $origin|0;
 var $$0 = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ((($origin|0) == 2)) {
  $5 = (($this) + 16|0);
  $6 = $5;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = (_i64Add(($8|0),($11|0),($0|0),($1|0))|0);
  $13 = tempRet0;
  $22 = $3;$28 = $13;$31 = $12;
 } else if ((($origin|0) == 1)) {
  $22 = $3;$28 = $1;$31 = $0;
 } else if ((($origin|0) == 3)) {
  $14 = HEAP32[$3>>2]|0;
  $15 = (($14) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_ii[$16 & 4095]($3)|0);
  $18 = tempRet0;
  $19 = (_i64Subtract(($17|0),($18|0),($0|0),($1|0))|0);
  $20 = tempRet0;
  $$pre = HEAP32[$2>>2]|0;
  $22 = $$pre;$28 = $20;$31 = $19;
 } else {
  $22 = $3;$28 = 0;$31 = 0;
 }
 $21 = HEAP32[$22>>2]|0;
 $23 = (($21) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_ii[$24 & 4095]($22)|0);
 $26 = tempRet0;
 $27 = ($28>>>0)>($26>>>0);
 $29 = ($28|0)==($26|0);
 $30 = ($31>>>0)>($25>>>0);
 $32 = $29 & $30;
 $33 = $27 | $32;
 if ($33) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = (($this) + 16|0);
 $35 = $34;
 $36 = $35;
 HEAP32[$36>>2] = $0;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $1;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK10MemoryFile8PositionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 tempRet0 = $6;
 STACKTOP = sp;return ($3|0);
}
function __ZN10MemoryFile9SetLengthEy($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
 } else {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $$0 = 0;
  } else {
   $8 = HEAP32[$3>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   FUNCTION_TABLE_viii[$10 & 4095]($3,$0,$1);
   $$0 = 1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK10MemoryFile4SizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $8 = 0;$9 = 0;
  tempRet0 = $8;
  STACKTOP = sp;return ($9|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
 $7 = tempRet0;
 $8 = $7;$9 = $6;
 tempRet0 = $8;
 STACKTOP = sp;return ($9|0);
}
function __ZN10MemoryFile5FlushEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK10MemoryFile6IsOpenEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN25MultiBlocksMemoryFileDataC2E10MemLabelIdj($this,$allocLabel,$blockSize) {
 $this = $this|0;
 $allocLabel = $allocLabel|0;
 $blockSize = $blockSize|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((587472 + 8|0));
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 1;
 HEAP32[$this>>2] = ((650280 + 8|0));
 $3 = HEAP32[$allocLabel>>2]|0;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = $blockSize;
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 20|0);
 HEAP32[$7>>2] = $3;
 $8 = (($this) + 24|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 28|0);
 $10 = (($this) + 32|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$9>>2] = 64;
 HEAP32[$0>>2] = $3;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $11 = (invoke_iiiiiiii(108,(0|0),256,4,($$byval_copy1|0),0,(650320|0),370)|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  HEAP32[$6>>2] = $11;
  STACKTOP = sp;return;
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $16 = HEAP32[$9>>2]|0;
 $17 = ($16|0)>(-1);
 if (!($17)) {
  ___resumeException($14|0);
  // unreachable;
 }
 $18 = HEAP32[$6>>2]|0;
 $19 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $19;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($18|0),($$byval_copy1|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  ___clang_call_terminate($22);
  // unreachable;
 }
 HEAP32[$6>>2] = 0;
 ___resumeException($14|0);
 // unreachable;
}
function __ZN25MultiBlocksMemoryFileDataD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1180,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN25MultiBlocksMemoryFileDataD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((650280 + 8|0));
 $2 = (($this) + 16|0);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 L1: do {
  if (!($5)) {
   $6 = (($this) + 8|0);
   $i$06 = 0;
   while(1) {
    $7 = HEAP32[$2>>2]|0;
    $8 = (($7) + ($i$06<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = HEAP32[$6>>2]|0;
    HEAP32[$1>>2] = $10;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy2|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = (($i$06) + 1)|0;
    $14 = HEAP32[$3>>2]|0;
    $15 = ($13>>>0)<($14>>>0);
    if ($15) {
     $i$06 = $13;
    } else {
     break L1;
    }
   }
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   $18 = (($this) + 28|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)>(-1);
   if (!($20)) {
    $$0 = $17;$$01 = $16;
    ___resumeException($$01|0);
    // unreachable;
   }
   $21 = HEAP32[$2>>2]|0;
   $22 = (($this) + 20|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$0>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($21|0),($$byval_copy2|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    $36 = ___cxa_find_matching_catch(0|0)|0;
    $37 = tempRet0;
    ___clang_call_terminate($36);
    // unreachable;
   }
   HEAP32[$2>>2] = 0;
   $$0 = $17;$$01 = $16;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $26 = (($this) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$2>>2]|0;
 $30 = (($this) + 20|0);
 $31 = HEAP32[$30>>2]|0;
 HEAP32[$0>>2] = $31;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy2|0));
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  $$0 = $35;$$01 = $34;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN25MultiBlocksMemoryFileData4LockEPPv($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$data>>2] = 0;
  STACKTOP = sp;return 1;
 }
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($2>>>0)>($5>>>0);
 if ($6) {
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = $11;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $12 = (__Z15malloc_internaljj10MemLabelIdiPKci($2,16,$$byval_copy,0,650320,38)|0);
  HEAP32[$data>>2] = $12;
  $13 = HEAP32[$this>>2]|0;
  $14 = (($13) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$1>>2]|0;
  (FUNCTION_TABLE_iiiiiii[$15 & 255]($this,0,0,$16,0,$12)|0);
  $17 = tempRet0;
  STACKTOP = sp;return 1;
 } else {
  $7 = (($this) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$data>>2] = $9;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN25MultiBlocksMemoryFileData6UnlockEPv($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($data|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $6;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($data,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZNK25MultiBlocksMemoryFileData4ReadEyyPv($this,$0,$1,$2,$3,$dst) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $dst = $dst|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$03 = 0, $blockOffset$02 = 0, $dstPos$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (___udivdi3(($0|0),($1|0),($5|0),0)|0);
 $7 = tempRet0;
 $8 = (_i64Add(($2|0),($3|0),($0|0),($1|0))|0);
 $9 = tempRet0;
 $10 = (($this) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>(0);
 $13 = ($9|0)==(0);
 $14 = ($8>>>0)>($11>>>0);
 $15 = $13 & $14;
 $16 = $12 | $15;
 $17 = (_i64Subtract(($11|0),0,($0|0),($1|0))|0);
 $18 = tempRet0;
 $19 = $16 ? $17 : $2;
 $20 = $16 ? $18 : $3;
 $21 = (($this) + 24|0);
 $22 = ($19|0)==(0);
 $23 = ($20|0)==(0);
 $24 = $22 & $23;
 if ($24) {
  $52 = 0;$53 = 0;
  tempRet0 = $52;
  STACKTOP = sp;return ($53|0);
 }
 $25 = Math_imul($6, $5)|0;
 $26 = (_i64Subtract(($0|0),($1|0),($25|0),0)|0);
 $27 = tempRet0;
 $28 = (($this) + 16|0);
 $33 = 0;$34 = 0;$block$03 = $6;$blockOffset$02 = $26;$dstPos$01 = 0;
 while(1) {
  $29 = HEAP32[$21>>2]|0;
  $30 = ($block$03>>>0)<($29>>>0);
  if (!($30)) {
   $52 = $34;$53 = $33;
   label = 8;
   break;
  }
  $31 = HEAP32[$4>>2]|0;
  $32 = (($31) - ($blockOffset$02))|0;
  $35 = (_i64Subtract(($19|0),($20|0),($33|0),($34|0))|0);
  $36 = tempRet0;
  $37 = ($35>>>0)<($32>>>0);
  $38 = $37 ? $35 : $32;
  $39 = HEAP32[$28>>2]|0;
  $40 = (($39) + ($block$03<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  $43 = (($dst) + ($dstPos$01)|0);
  if ($42) {
   _memset(($43|0),0,($38|0))|0;
  } else {
   $44 = (($41) + ($blockOffset$02)|0);
   _memcpy(($43|0),($44|0),($38|0))|0;
  }
  $45 = (($38) + ($dstPos$01))|0;
  $46 = (($block$03) + 1)|0;
  $47 = (0)<($20>>>0);
  $48 = (0)==($20|0);
  $49 = ($45>>>0)<($19>>>0);
  $50 = $48 & $49;
  $51 = $47 | $50;
  if ($51) {
   $33 = $45;$34 = 0;$block$03 = $46;$blockOffset$02 = 0;$dstPos$01 = $45;
  } else {
   $52 = 0;$53 = $45;
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  tempRet0 = $52;
  STACKTOP = sp;return ($53|0);
 }
 return 0|0;
}
function __ZN25MultiBlocksMemoryFileData5WriteEyyPKv($this,$0,$1,$2,$3,$src) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $src = $src|0;
 var $$byval_copy = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $$pre9 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $block$04 = 0, $blockOffset$03 = 0, $srcPos$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $4 = sp;
 $5 = (_i64Add(($2|0),($3|0),($0|0),($1|0))|0);
 $6 = tempRet0;
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (___udivdi3(($5|0),($6|0),($8|0),0)|0);
 $10 = tempRet0;
 $11 = (_i64Add(($9|0),($10|0),1,0)|0);
 $12 = tempRet0;
 $13 = (($this) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($11>>>0)>($14>>>0);
 if ($15) {
  __ZN25MultiBlocksMemoryFileData17AdjustBlocksCountEj($this,$11);
  $$pre = HEAP32[$7>>2]|0;
  $16 = $$pre;
 } else {
  $16 = $8;
 }
 $17 = (___udivdi3(($0|0),($1|0),($16|0),0)|0);
 $18 = tempRet0;
 $19 = ($2|0)==(0);
 $20 = ($3|0)==(0);
 $21 = $19 & $20;
 if ($21) {
  $54 = 0;$55 = 0;
  $53 = (($this) + 32|0);
  $56 = (_i64Add(($54|0),($55|0),($0|0),($1|0))|0);
  $57 = tempRet0;
  $58 = HEAP32[$53>>2]|0;
  $59 = ($58>>>0)<($56>>>0);
  $60 = $59 ? $56 : $58;
  HEAP32[$53>>2] = $60;
  tempRet0 = $55;
  STACKTOP = sp;return ($54|0);
 }
 $22 = Math_imul($17, $16)|0;
 $23 = (_i64Subtract(($0|0),($1|0),($22|0),0)|0);
 $24 = tempRet0;
 $25 = (($this) + 16|0);
 $26 = (($this) + 8|0);
 $28 = $16;$29 = 0;$30 = 0;$block$04 = $17;$blockOffset$03 = $23;$srcPos$02 = 0;
 while(1) {
  $27 = (($28) - ($blockOffset$03))|0;
  $31 = (_i64Subtract(($2|0),($3|0),($29|0),($30|0))|0);
  $32 = tempRet0;
  $33 = ($31>>>0)<($27>>>0);
  $34 = $33 ? $31 : $27;
  $35 = HEAP32[$25>>2]|0;
  $36 = (($35) + ($block$04<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   $39 = HEAP32[$26>>2]|0;
   HEAP32[$4>>2] = $39;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;
   $40 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy,0,650320,108)|0);
   $41 = HEAP32[$25>>2]|0;
   $42 = (($41) + ($block$04<<2)|0);
   HEAP32[$42>>2] = $40;
   $$pre6 = HEAP32[$25>>2]|0;
   $$phi$trans$insert = (($$pre6) + ($block$04<<2)|0);
   $$pre7 = HEAP32[$$phi$trans$insert>>2]|0;
   $44 = $$pre7;
  } else {
   $44 = $37;
  }
  $43 = (($44) + ($blockOffset$03)|0);
  $45 = (($src) + ($srcPos$02)|0);
  _memcpy(($43|0),($45|0),($34|0))|0;
  $46 = (($34) + ($srcPos$02))|0;
  $47 = (0)<($3>>>0);
  $48 = (0)==($3|0);
  $49 = ($46>>>0)<($2>>>0);
  $50 = $48 & $49;
  $51 = $47 | $50;
  if (!($51)) {
   $54 = $46;$55 = 0;
   break;
  }
  $52 = (($block$04) + 1)|0;
  $$pre9 = HEAP32[$7>>2]|0;
  $28 = $$pre9;$29 = $46;$30 = 0;$block$04 = $52;$blockOffset$03 = 0;$srcPos$02 = $46;
 }
 $53 = (($this) + 32|0);
 $56 = (_i64Add(($54|0),($55|0),($0|0),($1|0))|0);
 $57 = tempRet0;
 $58 = HEAP32[$53>>2]|0;
 $59 = ($58>>>0)<($56>>>0);
 $60 = $59 ? $56 : $58;
 HEAP32[$53>>2] = $60;
 tempRet0 = $55;
 STACKTOP = sp;return ($54|0);
}
function __ZN25MultiBlocksMemoryFileData17AdjustBlocksCountEj($this,$blocksCount) {
 $this = $this|0;
 $blocksCount = $blocksCount|0;
 var $$byval_copy2 = 0, $$size$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond4 = 0;
 var $i$02 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 16|0);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>($blocksCount>>>0);
 if ($5) {
  $6 = (($this) + 8|0);
  $i$02 = $blocksCount;
  while(1) {
   $7 = HEAP32[$2>>2]|0;
   $8 = (($7) + ($i$02<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$6>>2]|0;
   HEAP32[$1>>2] = $10;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy2);
   $11 = (($i$02) + 1)|0;
   $exitcond4 = ($11|0)==($4|0);
   if ($exitcond4) {
    break;
   } else {
    $i$02 = $11;
   }
  }
 }
 HEAP32[$3>>2] = $blocksCount;
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 2147483647;
 $15 = ($14>>>0)<($blocksCount>>>0);
 do {
  if ($15) {
   $16 = $13 << 1;
   $17 = ($16>>>0)>($blocksCount>>>0);
   $$size$i = $17 ? $16 : $blocksCount;
   $18 = ($14>>>0)<($$size$i>>>0);
   if ($18) {
    $19 = ($13|0)>(-1);
    if ($19) {
     HEAP32[$12>>2] = $$size$i;
     $20 = HEAP32[$2>>2]|0;
     $21 = $$size$i << 2;
     $22 = (($this) + 20|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z16realloc_internalPvji10MemLabelIdiPKci($20,$21,4,$$byval_copy2,0,650320,370)|0);
     HEAP32[$2>>2] = $24;
     break;
    } else {
     $25 = $$size$i << 2;
     $26 = (($this) + 20|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$0>>2] = $27;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,4,$$byval_copy2,0,650320,352)|0);
     $29 = HEAP32[$2>>2]|0;
     $30 = HEAP32[$3>>2]|0;
     $31 = $30 << 2;
     _memcpy(($28|0),($29|0),($31|0))|0;
     HEAP32[$12>>2] = $$size$i;
     HEAP32[$2>>2] = $28;
     break;
    }
   }
  }
 } while(0);
 $32 = ($4>>>0)<($blocksCount>>>0);
 if (!($32)) {
  STACKTOP = sp;return;
 }
 $i1$01 = $4;
 while(1) {
  $33 = HEAP32[$2>>2]|0;
  $34 = (($33) + ($i1$01<<2)|0);
  HEAP32[$34>>2] = 0;
  $35 = (($i1$01) + 1)|0;
  $exitcond = ($35|0)==($blocksCount|0);
  if ($exitcond) {
   break;
  } else {
   $i1$01 = $35;
  }
 }
 STACKTOP = sp;return;
}
function __ZN25MultiBlocksMemoryFileData9SetLengthEy($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (___udivdi3(($0|0),($1|0),($3|0),0)|0);
 $5 = tempRet0;
 __ZN25MultiBlocksMemoryFileData17AdjustBlocksCountEj($this,$4);
 $6 = (($this) + 32|0);
 HEAP32[$6>>2] = $0;
 STACKTOP = sp;return;
}
function __ZNK25MultiBlocksMemoryFileData4SizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 tempRet0 = 0;
 STACKTOP = sp;return ($1|0);
}
function __ZN12_GLOBAL__N_138ArchiveRedirectFileSystemStaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628408>>2]|0;
 $2 = (0|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[0>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095](0);
 }
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z18IsDirectoryCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($path) {
 $path = $path|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $e = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1072|0;
 $e = sp + 16|0;
 $0 = sp;
 $1 = (__Z13GetFileSystemv()|0);
 $2 = HEAP8[$path>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = (($path) + 1|0);
  $8 = $7;
 } else {
  $5 = (($path) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $8 = $6;
 }
 __ZNK10FileSystem10ToAbsoluteEPKc($0,$1,$8);
 $9 = HEAP8[$0>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $14 = (($0) + 1|0);
  $15 = $14;
 } else {
  $12 = (($0) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $15 = $13;
 }
 __THREW__ = 0;
 invoke_vii(3227,($e|0),($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $28 = HEAP8[$0>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $$0 = $26;$$01 = $27;
   ___resumeException($$0|0);
   // unreachable;
  }
  $31 = (($0) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  __ZdlPv($32);
  $$0 = $26;$$01 = $27;
  ___resumeException($$0|0);
  // unreachable;
 }
 $18 = HEAP8[$0>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
 }
 __THREW__ = 0;
 $23 = (invoke_ii(3314,($e|0))|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  __ZN13FileEntryDataD2Ev($e);
  STACKTOP = sp;return ($23|0);
 }
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3572,($e|0));
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $37 = ___cxa_find_matching_catch(0|0)|0;
  $38 = tempRet0;
  ___clang_call_terminate($37);
  // unreachable;
 } else {
  $$0 = $33;$$01 = $34;
  ___resumeException($$0|0);
  // unreachable;
 }
 return 0|0;
}
function __Z13IsFileCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($path) {
 $path = $path|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $e = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1072|0;
 $e = sp + 16|0;
 $0 = sp;
 $1 = (__Z13GetFileSystemv()|0);
 $2 = HEAP8[$path>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = (($path) + 1|0);
  $8 = $7;
 } else {
  $5 = (($path) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $8 = $6;
 }
 __ZNK10FileSystem10ToAbsoluteEPKc($0,$1,$8);
 $9 = HEAP8[$0>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $14 = (($0) + 1|0);
  $15 = $14;
 } else {
  $12 = (($0) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $15 = $13;
 }
 __THREW__ = 0;
 invoke_vii(3227,($e|0),($15|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $32 = HEAP8[$0>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   $$0 = $30;$$01 = $31;
   ___resumeException($$0|0);
   // unreachable;
  }
  $35 = (($0) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  __ZdlPv($36);
  $$0 = $30;$$01 = $31;
  ___resumeException($$0|0);
  // unreachable;
 }
 $18 = HEAP8[$0>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
 }
 __THREW__ = 0;
 $23 = (invoke_ii(3315,($e|0))|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if (!($25)) {
  if ($23) {
   $29 = 0;
   __ZN13FileEntryDataD2Ev($e);
   STACKTOP = sp;return ($29|0);
  }
  __THREW__ = 0;
  $26 = (invoke_ii(3316,($e|0))|0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if (!($28)) {
   $29 = $26;
   __ZN13FileEntryDataD2Ev($e);
   STACKTOP = sp;return ($29|0);
  }
 }
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3572,($e|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 } else {
  $$0 = $37;$$01 = $38;
  ___resumeException($$0|0);
  // unreachable;
 }
 return 0|0;
}
function __Z18PathToAbsolutePathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$path) {
 $agg$result = $agg$result|0;
 $path = $path|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z13GetFileSystemv()|0);
 $1 = HEAP8[$path>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($path) + 1|0);
  $7 = $6;
 } else {
  $4 = (($path) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 __ZNK10FileSystem10ToAbsoluteEPKc($agg$result,$0,$7);
 STACKTOP = sp;return;
}
function __Z23GetFolderContentsAtPathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_3setIS5_NS_4lessIS5_EENS3_IS5_EEEE($pathName,$paths) {
 $pathName = $pathName|0;
 $paths = $paths|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy6 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $children = 0, $e = 0, $i$012 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1120|0;
 $$byval_copy6 = sp + 1108|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 16|0;
 $e = sp + 24|0;
 $children = sp + 1080|0;
 $3 = sp + 1096|0;
 $4 = HEAP8[$pathName>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $9 = (($pathName) + 1|0);
  $10 = $9;
 } else {
  $7 = (($pathName) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $10 = $8;
 }
 __ZN15FileSystemEntryC2EPKc($e,$10);
 HEAP32[$children>>2] = 0;
 $11 = (($children) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (($children) + 12|0);
 HEAP32[$12>>2] = 0;
 $13 = (($children) + 4|0);
 HEAP32[$13>>2] = 61;
 __THREW__ = 0;
 $14 = (invoke_i(105)|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 L5: do {
  if ($16) {
   label = 22;
  } else {
   __THREW__ = 0;
   $17 = (invoke_ii(3317,($e|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    label = 22;
   } else {
    __THREW__ = 0;
    (invoke_iiiiii(205,($14|0),($17|0),($children|0),0,0)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 22;
    } else {
     $22 = HEAP32[$children>>2]|0;
     $23 = HEAP32[$11>>2]|0;
     $24 = ($23|0)==(0);
     L9: do {
      if ($24) {
       $$lcssa = $22;
      } else {
       $25 = (($3) + 1|0);
       $26 = (($3) + 8|0);
       $27 = (($3) + 4|0);
       $i$012 = $22;
       while(1) {
        $28 = (_strlen(($i$012|0))|0);
        $29 = ($28>>>0)>(4294967279);
        if ($29) {
         label = 10;
         break;
        }
        $32 = ($28>>>0)<(11);
        if ($32) {
         $33 = $28 << 1;
         $34 = $33&255;
         HEAP8[$3>>0] = $34;
         $__p$0$i$i$i = $25;
        } else {
         $35 = (($28) + 16)|0;
         $36 = $35 & -16;
         __THREW__ = 0;
         $37 = (invoke_ii(2988,($36|0))|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          label = 21;
          break;
         }
         HEAP32[$26>>2] = $37;
         $40 = $36 | 1;
         HEAP32[$3>>2] = $40;
         HEAP32[$27>>2] = $28;
         $__p$0$i$i$i = $37;
        }
        _memcpy(($__p$0$i$i$i|0),($i$012|0),($28|0))|0;
        $41 = (($__p$0$i$i$i) + ($28)|0);
        HEAP8[$41>>0] = 0;
        __THREW__ = 0;
        invoke_viii(1940,($1|0),($paths|0),($3|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         label = 24;
         break;
        }
        $44 = HEAP8[$3>>0]|0;
        $45 = $44 & 1;
        $46 = ($45<<24>>24)==(0);
        if (!($46)) {
         $47 = HEAP32[$26>>2]|0;
         __ZdlPv($47);
        }
        $48 = (($i$012) + 1088|0);
        $49 = HEAP32[$children>>2]|0;
        $50 = HEAP32[$11>>2]|0;
        $51 = (($49) + (($50*1088)|0)|0);
        $52 = ($48|0)==($51|0);
        if ($52) {
         $$lcssa = $49;
         break L9;
        } else {
         $i$012 = $48;
        }
       }
       if ((label|0) == 10) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 22;
         break L5;
        }
        // unreachable;
       }
       else if ((label|0) == 21) {
        $55 = ___cxa_find_matching_catch()|0;
        $56 = tempRet0;
        $lpad$phi$index = $55;$lpad$phi$index2 = $56;
        label = 23;
        break L5;
       }
       else if ((label|0) == 24) {
        $59 = ___cxa_find_matching_catch()|0;
        $60 = tempRet0;
        $61 = HEAP8[$3>>0]|0;
        $62 = $61 & 1;
        $63 = ($62<<24>>24)==(0);
        if ($63) {
         $$0 = $59;$$01 = $60;
         label = 30;
         break L5;
        }
        $64 = HEAP32[$26>>2]|0;
        __ZdlPv($64);
        $$0 = $59;$$01 = $60;
        label = 30;
        break L5;
       }
      }
     } while(0);
     $65 = HEAP32[$12>>2]|0;
     $66 = ($65|0)>(-1);
     if (!($66)) {
      __ZN13FileEntryDataD2Ev($e);
      STACKTOP = sp;return 1;
     }
     $67 = HEAP32[$13>>2]|0;
     HEAP32[$0>>2] = $67;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($$lcssa|0),($$byval_copy6|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      $53 = ___cxa_find_matching_catch()|0;
      $54 = tempRet0;
      $$1 = $53;$$12 = $54;
      break;
     }
     HEAP32[$children>>2] = 0;
     __ZN13FileEntryDataD2Ev($e);
     STACKTOP = sp;return 1;
    }
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  $lpad$phi$index = $57;$lpad$phi$index2 = $58;
  label = 23;
 }
 if ((label|0) == 23) {
  $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
  label = 30;
 }
 do {
  if ((label|0) == 30) {
   $70 = HEAP32[$12>>2]|0;
   $71 = ($70|0)>(-1);
   if ($71) {
    $72 = HEAP32[$children>>2]|0;
    $73 = HEAP32[$13>>2]|0;
    HEAP32[$2>>2] = $73;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($72|0),($$byval_copy6|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     $78 = ___cxa_find_matching_catch(0|0)|0;
     $79 = tempRet0;
     ___clang_call_terminate($78);
     // unreachable;
    } else {
     HEAP32[$children>>2] = 0;
     $$1 = $$0;$$12 = $$01;
     break;
    }
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3572,($e|0));
 $76 = __THREW__; __THREW__ = 0;
 $77 = $76&1;
 if ($77) {
  $78 = ___cxa_find_matching_catch(0|0)|0;
  $79 = tempRet0;
  ___clang_call_terminate($78);
  // unreachable;
 } else {
  ___resumeException($$1|0);
  // unreachable;
 }
 return 0|0;
}
function __Z18ReadStringFromFilePNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEERKNS0_IcS2_NS_9allocatorIcEEEE($outData,$pathName) {
 $outData = $outData|0;
 $pathName = $pathName|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, $actual = 0, $e = 0, $reader = 0, $success$0$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2128|0;
 $e = sp + 1072|0;
 $reader = sp + 8|0;
 $actual = sp;
 $0 = HEAP8[$pathName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($pathName) + 1|0);
  $6 = $5;
 } else {
  $3 = (($pathName) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 __ZN15FileSystemEntryC2EPKc($e,$6);
 __THREW__ = 0;
 $7 = (invoke_ii(3306,($e|0))|0);
 $8 = tempRet0;
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L5: do {
  if ($10) {
   label = 8;
  } else {
   __THREW__ = 0;
   invoke_vi(3584,($reader|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 8;
   } else {
    __THREW__ = 0;
    $13 = (invoke_iiiii(252,($reader|0),($e|0),0,0)|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    L8: do {
     if (!($15)) {
      do {
       if ($13) {
        $22 = HEAP8[$outData>>0]|0;
        $23 = $22 & 1;
        $24 = ($23<<24>>24)==(0);
        if ($24) {
         $27 = $22&255;
         $28 = $27 >>> 1;
         $30 = $28;
        } else {
         $25 = (($outData) + 4|0);
         $26 = HEAP32[$25>>2]|0;
         $30 = $26;
        }
        $29 = ($30>>>0)<($7>>>0);
        do {
         if ($29) {
          $31 = (($7) - ($30))|0;
          __THREW__ = 0;
          (invoke_iiii(1566,($outData|0),($31|0),0)|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if ($33) {
           break L8;
          }
         } else {
          if ($24) {
           $38 = ((($outData) + ($7)|0) + 1|0);
           HEAP8[$38>>0] = 0;
           $39 = $7 << 1;
           $40 = $39&255;
           HEAP8[$outData>>0] = $40;
           break;
          } else {
           $34 = (($outData) + 8|0);
           $35 = HEAP32[$34>>2]|0;
           $36 = (($35) + ($7)|0);
           HEAP8[$36>>0] = 0;
           $37 = (($outData) + 4|0);
           HEAP32[$37>>2] = $7;
           break;
          }
         }
        } while(0);
        $41 = $actual;
        $42 = $41;
        HEAP32[$42>>2] = 0;
        $43 = (($41) + 4)|0;
        $44 = $43;
        HEAP32[$44>>2] = 0;
        $45 = ($7|0)==(0);
        if ($45) {
         $success$0$off0 = 1;
        } else {
         $46 = HEAP8[$outData>>0]|0;
         $47 = $46 & 1;
         $48 = ($47<<24>>24)==(0);
         if ($48) {
          $51 = (($outData) + 1|0);
          $52 = $51;
         } else {
          $49 = (($outData) + 8|0);
          $50 = HEAP32[$49>>2]|0;
          $52 = $50;
         }
         __THREW__ = 0;
         $53 = (invoke_iiiiii(206,($reader|0),($7|0),0,($52|0),($actual|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break L8;
         } else {
          $success$0$off0 = $53;
         }
        }
        __THREW__ = 0;
        (invoke_ii(3318,($reader|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break L8;
        }
        if ($success$0$off0) {
         $58 = $actual;
         $59 = $58;
         $60 = HEAP32[$59>>2]|0;
         $61 = (($58) + 4)|0;
         $62 = $61;
         $63 = HEAP32[$62>>2]|0;
         $64 = ($60|0)==($7|0);
         $65 = ($63|0)==(0);
         $66 = $64 & $65;
         if ($66) {
          $$02 = 1;
          break;
         }
        }
        $67 = HEAP8[$outData>>0]|0;
        $68 = $67 & 1;
        $69 = ($68<<24>>24)==(0);
        if ($69) {
         $73 = (($outData) + 1|0);
         HEAP8[$73>>0] = 0;
         HEAP8[$outData>>0] = 0;
         $$02 = 0;
         break;
        } else {
         $70 = (($outData) + 8|0);
         $71 = HEAP32[$70>>2]|0;
         HEAP8[$71>>0] = 0;
         $72 = (($outData) + 4|0);
         HEAP32[$72>>2] = 0;
         $$02 = 0;
         break;
        }
       } else {
        $$02 = 0;
       }
      } while(0);
      __THREW__ = 0;
      invoke_vi(1174,($reader|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 8;
       break L5;
      }
      __ZN13FileEntryDataD2Ev($e);
      STACKTOP = sp;return ($$02|0);
     }
    } while(0);
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    __THREW__ = 0;
    invoke_vi(1174,($reader|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     $78 = ___cxa_find_matching_catch(0|0)|0;
     $79 = tempRet0;
     ___clang_call_terminate($78);
     // unreachable;
    } else {
     $$0 = $19;$$01 = $18;
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $$0 = $17;$$01 = $16;
 }
 __THREW__ = 0;
 invoke_vi(3572,($e|0));
 $76 = __THREW__; __THREW__ = 0;
 $77 = $76&1;
 if ($77) {
  $78 = ___cxa_find_matching_catch(0|0)|0;
  $79 = tempRet0;
  ___clang_call_terminate($78);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
 return 0|0;
}
function __Z16WriteBytesToFilePKviRKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($data,$byteLength,$pathName) {
 $data = $data|0;
 $byteLength = $byteLength|0;
 $pathName = $pathName|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $actual = 0, $e = 0;
 var $writer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 2128|0;
 $e = sp + 1072|0;
 $writer = sp + 8|0;
 $actual = sp;
 $0 = HEAP8[$pathName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($pathName) + 1|0);
  $6 = $5;
 } else {
  $3 = (($pathName) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 __ZN15FileSystemEntryC2EPKc($e,$6);
 __THREW__ = 0;
 invoke_vi(3584,($writer|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L5: do {
  if ($8) {
   label = 7;
  } else {
   __THREW__ = 0;
   $9 = (invoke_iiiii(252,($writer|0),($e|0),1,0)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   do {
    if (!($11)) {
     if ($9) {
      $18 = $actual;
      $19 = $18;
      HEAP32[$19>>2] = 0;
      $20 = (($18) + 4)|0;
      $21 = $20;
      HEAP32[$21>>2] = 0;
      $22 = ($byteLength|0)<(0);
      $23 = $22 << 31 >> 31;
      __THREW__ = 0;
      $24 = (invoke_iiiiii(207,($writer|0),($byteLength|0),($23|0),($data|0),($actual|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(3318,($writer|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      } else {
       $$0 = $24;
      }
     } else {
      $$0 = 0;
     }
     __THREW__ = 0;
     invoke_vi(1174,($writer|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      label = 7;
      break L5;
     }
     __ZN13FileEntryDataD2Ev($e);
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __THREW__ = 0;
   invoke_vi(1174,($writer|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $33 = ___cxa_find_matching_catch(0|0)|0;
    $34 = tempRet0;
    ___clang_call_terminate($33);
    // unreachable;
   } else {
    $$01 = $15;$$02 = $14;
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $$01 = $13;$$02 = $12;
 }
 __THREW__ = 0;
 invoke_vi(3572,($e|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch(0|0)|0;
  $34 = tempRet0;
  ___clang_call_terminate($33);
  // unreachable;
 } else {
  ___resumeException($$02|0);
  // unreachable;
 }
 return 0|0;
}
function __Z21DeleteFileOrDirectoryRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($path) {
 $path = $path|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z13GetFileSystemv()|0);
 $1 = HEAP8[$path>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($path) + 1|0);
  $7 = $6;
 } else {
  $4 = (($path) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 $8 = (__ZNK10FileSystem6DeleteEPKcb($0,$7,1)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z15CreateDirectoryRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName) {
 $pathName = $pathName|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $8 = 0, $9 = 0, $absolutePath = 0, $d = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1088|0;
 $vararg_buffer = sp;
 $absolutePath = sp + 1076|0;
 $d = sp + 8|0;
 $0 = sp + 1064|0;
 $1 = (__Z13IsFileCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName)|0);
 if ($1) {
  $$14 = 0;
  STACKTOP = sp;return ($$14|0);
 }
 $2 = (__Z18IsDirectoryCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName)|0);
 if ($2) {
  $$14 = 1;
  STACKTOP = sp;return ($$14|0);
 }
 $3 = (__Z13GetFileSystemv()|0);
 $4 = HEAP8[$pathName>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $9 = (($pathName) + 1|0);
  $10 = $9;
 } else {
  $7 = (($pathName) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $10 = $8;
 }
 __ZNK10FileSystem10ToAbsoluteEPKc($absolutePath,$3,$10);
 $11 = HEAP8[$pathName>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $16 = (($pathName) + 1|0);
  $17 = $16;
 } else {
  $14 = (($pathName) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $17 = $15;
 }
 __THREW__ = 0;
 invoke_vii(3227,($d|0),($17|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L15: do {
  if ($19) {
   label = 23;
  } else {
   __THREW__ = 0;
   $20 = (invoke_ii(3319,($d|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   L17: do {
    if ($22) {
     label = 24;
    } else {
     do {
      if ($20) {
       $$03 = 1;
      } else {
       $23 = HEAP8[$absolutePath>>0]|0;
       $24 = $23 & 1;
       $25 = ($24<<24>>24)==(0);
       if ($25) {
        $28 = (($absolutePath) + 1|0);
        $40 = $28;
       } else {
        $26 = (($absolutePath) + 8|0);
        $27 = HEAP32[$26>>2]|0;
        $40 = $27;
       }
       __THREW__ = 0;
       $29 = (invoke_i(105)|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 24;
        break L17;
       }
       __THREW__ = 0;
       invoke_vii(3254,($0|0),($29|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        label = 24;
        break L17;
       }
       $34 = HEAP8[$0>>0]|0;
       $35 = $34 & 1;
       $36 = ($35<<24>>24)==(0);
       if ($36) {
        $39 = (($0) + 1|0);
        $41 = $39;
       } else {
        $37 = (($0) + 8|0);
        $38 = HEAP32[$37>>2]|0;
        $41 = $38;
       }
       __THREW__ = 0;
       HEAP32[$vararg_buffer>>2] = $40;
       $vararg_ptr1 = (($vararg_buffer) + 4|0);
       HEAP32[$vararg_ptr1>>2] = $41;
       invoke_vii(2587,(650328|0),($vararg_buffer|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        $53 = ___cxa_find_matching_catch()|0;
        $54 = tempRet0;
        $55 = HEAP8[$0>>0]|0;
        $56 = $55 & 1;
        $57 = ($56<<24>>24)==(0);
        if ($57) {
         $$0 = $54;$$01 = $53;
         break L17;
        }
        $58 = (($0) + 8|0);
        $59 = HEAP32[$58>>2]|0;
        __ZdlPv($59);
        $$0 = $54;$$01 = $53;
        break L17;
       } else {
        $44 = HEAP8[$0>>0]|0;
        $45 = $44 & 1;
        $46 = ($45<<24>>24)==(0);
        if ($46) {
         $$03 = 0;
         break;
        }
        $47 = (($0) + 8|0);
        $48 = HEAP32[$47>>2]|0;
        __ZdlPv($48);
        $$03 = 0;
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3572,($d|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 23;
      break L15;
     }
     $62 = HEAP8[$absolutePath>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $$14 = $$03;
      STACKTOP = sp;return ($$14|0);
     }
     $65 = (($absolutePath) + 8|0);
     $66 = HEAP32[$65>>2]|0;
     __ZdlPv($66);
     $$14 = $$03;
     STACKTOP = sp;return ($$14|0);
    }
   } while(0);
   if ((label|0) == 24) {
    $51 = ___cxa_find_matching_catch()|0;
    $52 = tempRet0;
    $$0 = $52;$$01 = $51;
   }
   __THREW__ = 0;
   invoke_vi(3572,($d|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $74 = ___cxa_find_matching_catch(0|0)|0;
    $75 = tempRet0;
    ___clang_call_terminate($74);
    // unreachable;
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  $$1 = $50;$$12 = $49;
 }
 $69 = HEAP8[$absolutePath>>0]|0;
 $70 = $69 & 1;
 $71 = ($70<<24>>24)==(0);
 if ($71) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $72 = (($absolutePath) + 8|0);
 $73 = HEAP32[$72>>2]|0;
 __ZdlPv($73);
 ___resumeException($$12|0);
 // unreachable;
 return 0|0;
}
function __Z13GetFileLengthRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($pathName) {
 $pathName = $pathName|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $e = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $e = sp;
 $0 = HEAP8[$pathName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($pathName) + 1|0);
  $6 = $5;
 } else {
  $3 = (($pathName) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 __ZN15FileSystemEntryC2EPKc($e,$6);
 __THREW__ = 0;
 $7 = (invoke_ii(3306,($e|0))|0);
 $8 = tempRet0;
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __ZN13FileEntryDataD2Ev($e);
  STACKTOP = sp;return ($7|0);
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3572,($e|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
 return 0|0;
}
function __Z12SetFileFlagsRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjj($path,$attributeMask,$attributeValue) {
 $path = $path|0;
 $attributeMask = $attributeMask|0;
 $attributeValue = $attributeValue|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $e = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $e = sp;
 $0 = HEAP8[$path>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($path) + 1|0);
  $6 = $5;
 } else {
  $3 = (($path) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 __ZN15FileSystemEntryC2EPKc($e,$6);
 __THREW__ = 0;
 $7 = (invoke_iiii(1567,($e|0),($attributeMask|0),($attributeValue|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZN13FileEntryDataD2Ev($e);
  STACKTOP = sp;return ($7|0);
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3572,($e|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
 return 0|0;
}
function __Z22IsFileOrDirectoryInUseRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($path) {
 $path = $path|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $e = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $e = sp;
 $0 = HEAP8[$path>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($path) + 1|0);
  $6 = $5;
 } else {
  $3 = (($path) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 __ZN15FileSystemEntryC2EPKc($e,$6);
 __THREW__ = 0;
 $7 = (invoke_ii(3320,($e|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZN13FileEntryDataD2Ev($e);
  STACKTOP = sp;return ($7|0);
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3572,($e|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN4FileC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN4FileD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 (invoke_ii(3261,($this|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $10 = (($this) + 12|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   ___resumeException($8|0);
   // unreachable;
  }
  $14 = (($this) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $2 = (($this) + 12|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3 & 1;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   STACKTOP = sp;return;
  }
  $6 = (($this) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  __ZdlPv($7);
  STACKTOP = sp;return;
 }
}
function __ZN4File5CloseEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $errorString = 0, $success$0$off0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $errorString = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $success$0$off0 = 1;
  } else {
   $4 = (__ZN12FileAccessor5CloseEv($2)|0);
   if ($4) {
    $success$0$off0 = 1;
   } else {
    $5 = (__Znwj(16)|0);
    $6 = (($errorString) + 8|0);
    HEAP32[$6>>2] = $5;
    HEAP32[$errorString>>2] = 17;
    $7 = (($errorString) + 4|0);
    HEAP32[$7>>2] = 13;
    dest=$5+0|0; src=650376+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $8 = (($5) + 13|0);
    HEAP8[$8>>0] = 0;
    $9 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    $10 = (invoke_ii(3317,($9|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = (_strlen(($10|0))|0);
     __THREW__ = 0;
     (invoke_iiii(1480,($errorString|0),($10|0),($13|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP8[$errorString>>0]|0;
      $17 = $16 & 1;
      $18 = ($17<<24>>24)==(0);
      if ($18) {
       $20 = (($errorString) + 1|0);
       $21 = $20;
      } else {
       $19 = HEAP32[$6>>2]|0;
       $21 = $19;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($21|0),0,(650368|0),424,1,0,0,(0|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       $24 = HEAP8[$errorString>>0]|0;
       $25 = $24 & 1;
       $26 = ($25<<24>>24)==(0);
       if ($26) {
        $success$0$off0 = 0;
        break;
       }
       $27 = HEAP32[$6>>2]|0;
       __ZdlPv($27);
       $success$0$off0 = 0;
       break;
      }
     }
    }
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    $30 = HEAP8[$errorString>>0]|0;
    $31 = $30 & 1;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     ___resumeException($28|0);
     // unreachable;
    }
    $33 = HEAP32[$6>>2]|0;
    __ZdlPv($33);
    ___resumeException($28|0);
    // unreachable;
   }
  }
 } while(0);
 $34 = HEAP32[$this>>2]|0;
 $35 = HEAP32[628392>>2]|0;
 $36 = ($34|0)==(0|0);
 if (!($36)) {
  __ZN13FileEntryDataD2Ev($34);
 }
 HEAP32[$0>>2] = $35;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($34,$$byval_copy1);
 HEAP32[$this>>2] = 0;
 $37 = HEAP32[$1>>2]|0;
 $38 = HEAP32[628392>>2]|0;
 $39 = ($37|0)==(0|0);
 if ($39) {
  HEAP32[$0>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy1);
  HEAP32[$1>>2] = 0;
  STACKTOP = sp;return ($success$0$off0|0);
 }
 $40 = HEAP32[$37>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 FUNCTION_TABLE_vi[$41 & 4095]($37);
 HEAP32[$0>>2] = $38;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy1);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return ($success$0$off0|0);
}
function __ZN4File19SetCurrentDirectoryERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($path) {
 $path = $path|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Z13GetFileSystemv()|0);
 __ZN10FileSystem19SetCurrentDirectoryERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$1,$path);
 $2 = HEAP8[$0>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($0) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 __ZdlPv($6);
 STACKTOP = sp;return;
}
function __ZN4File19OpenFileSystemEntryERK15FileSystemEntryNS_10PermissionENS_12AutoBehaviorE($this,$fileSystemEntry,$permission,$behavior) {
 $this = $this|0;
 $fileSystemEntry = $fileSystemEntry|0;
 $permission = $permission|0;
 $behavior = $behavior|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$us = 0, $retryCount$09$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[628392>>2]|0;
  __ZN13FileEntryDataD2Ev($3);
  HEAP32[$0>>2] = $5;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy5);
  HEAP32[$this>>2] = 0;
 }
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  (__ZN12FileAccessor5CloseEv($7)|0);
  $9 = HEAP32[$6>>2]|0;
  $10 = HEAP32[628392>>2]|0;
  $11 = ($9|0)==(0|0);
  if (!($11)) {
   $12 = HEAP32[$9>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   FUNCTION_TABLE_vi[$13 & 4095]($9);
  }
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy5);
  HEAP32[$6>>2] = 0;
 }
 $14 = HEAP32[628392>>2]|0;
 HEAP32[$1>>2] = $14;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 $15 = (__Znwj10MemLabelIdbiPKci(1056,$$byval_copy5,0,16,650368,315)|0);
 $16 = (($15) + 1040|0);
 HEAP8[$15>>0] = 0;
 ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
 __THREW__ = 0;
 (invoke_iii(2530,($15|0),($fileSystemEntry|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3572,($15|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $23 = ___cxa_find_matching_catch(0|0)|0;
   $24 = tempRet0;
   ___clang_call_terminate($23);
   // unreachable;
  }
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viiiiii(97,($15|0),($$byval_copy5|0),0,16,(650368|0),315);
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   $46 = ___cxa_find_matching_catch(0|0)|0;
   $47 = tempRet0;
   ___clang_call_terminate($46);
   // unreachable;
  } else {
   $$0 = $20;$$01 = $19;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 HEAP32[$this>>2] = $15;
 $25 = HEAP32[628392>>2]|0;
 HEAP32[$2>>2] = $25;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
 $26 = (__Znwj10MemLabelIdbiPKci(1064,$$byval_copy5,0,16,650368,317)|0);
 __THREW__ = 0;
 invoke_vi(3584,($26|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_viiiiii(97,($26|0),($$byval_copy5|0),0,16,(650368|0),317);
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if ($43) {
   $46 = ___cxa_find_matching_catch(0|0)|0;
   $47 = tempRet0;
   ___clang_call_terminate($46);
   // unreachable;
  } else {
   $$0 = $41;$$01 = $40;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 HEAP32[$6>>2] = $26;
 $29 = (($this) + 8|0);
 HEAP32[$29>>2] = 0;
 $30 = HEAP32[$this>>2]|0;
 $31 = (__ZN12FileAccessor4OpenER15FileSystemEntry14FilePermission16FileAutoBehavior($26,$30,$permission,0)|0);
 if ($31) {
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
 }
 $32 = $behavior & 2;
 $33 = ($32|0)==(0);
 L28: do {
  if (!($33)) {
   $retryCount$09$us = 4;
   while(1) {
    $34 = ($retryCount$09$us|0)>(0);
    if (!($34)) {
     break L28;
    }
    $phitmp$us = (($retryCount$09$us) + -1)|0;
    $35 = HEAP32[$6>>2]|0;
    $36 = HEAP32[$this>>2]|0;
    $37 = (__ZN12FileAccessor4OpenER15FileSystemEntry14FilePermission16FileAutoBehavior($35,$36,$permission,0)|0);
    if ($37) {
     $$02 = 1;
     break;
    } else {
     $retryCount$09$us = $phitmp$us;
    }
   }
   STACKTOP = sp;return ($$02|0);
  }
 } while(0);
 $44 = $behavior & 1;
 $45 = ($44|0)==(0);
 if ($45) {
  $$02 = 0;
  STACKTOP = sp;return ($$02|0);
 }
 (__ZN4File5CloseEv($this)|0);
 $$02 = 0;
 STACKTOP = sp;return ($$02|0);
}
function __ZN4File4OpenERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS_10PermissionENS_12AutoBehaviorE($this,$path,$perm,$behavior) {
 $this = $this|0;
 $path = $path|0;
 $perm = $perm|0;
 $behavior = $behavior|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fileSystemEntry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $fileSystemEntry = sp;
 $0 = HEAP8[$path>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($path) + 1|0);
  $6 = $5;
 } else {
  $3 = (($path) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 }
 __ZN15FileSystemEntryC2EPKc($fileSystemEntry,$6);
 __THREW__ = 0;
 $7 = (invoke_iiiii(253,($this|0),($fileSystemEntry|0),($perm|0),($behavior|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZN13FileEntryDataD2Ev($fileSystemEntry);
  STACKTOP = sp;return ($7|0);
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3572,($fileSystemEntry|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN4File4ReadEiPvi($this,$position,$buffer,$size) {
 $this = $this|0;
 $position = $position|0;
 $buffer = $buffer|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $actual = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $actual = sp;
 $0 = $actual;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($position|0)<(0);
 $7 = $6 << 31 >> 31;
 $8 = ($size|0)<(0);
 $9 = $8 << 31 >> 31;
 (__ZN12FileAccessor4ReadEyyPvPy($5,$position,$7,$size,$9,$buffer,$actual)|0);
 $10 = $actual;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (_i64Add(($12|0),($15|0),($position|0),($7|0))|0);
 $17 = tempRet0;
 $18 = (($this) + 8|0);
 HEAP32[$18>>2] = $16;
 STACKTOP = sp;return ($12|0);
}
function __ZN4File5WriteEPKvi($this,$buffer,$size) {
 $this = $this|0;
 $buffer = $buffer|0;
 $size = $size|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $actual = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $actual = sp;
 $0 = $actual;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($size|0)<(0);
 $7 = $6 << 31 >> 31;
 $8 = (__ZN12FileAccessor5WriteEyPKvPy($5,$size,$7,$buffer,$actual)|0);
 $9 = $actual;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (_i64Add(($16|0),0,($11|0),($14|0))|0);
 $18 = tempRet0;
 HEAP32[$15>>2] = $17;
 $19 = ($11|0)==($size|0);
 $20 = ($14|0)==($7|0);
 $21 = $19 & $20;
 $$ = $8 & $21;
 STACKTOP = sp;return ($$|0);
}
function __ZN4File7IsValidEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $5 = 0;
 } else {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)!=(0|0);
  $5 = $4;
 }
 STACKTOP = sp;return ($5|0);
}
function __ZNK20LocalFileSystemPosix5IsDirERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $statbuffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $statbuffer = sp;
 $0 = (_stat(($data|0),($statbuffer|0))|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($statbuffer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 61440;
 $5 = ($4|0)==(16384);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK20LocalFileSystemPosix8IsHiddenERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK20LocalFileSystemPosix9IsSymLinkERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $statbuffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $statbuffer = sp;
 $0 = (_lstat(($data|0),($statbuffer|0))|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($statbuffer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 61440;
 $5 = ($4|0)==(40960);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK20LocalFileSystemPosix4SizeERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $statbuffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $statbuffer = sp;
 $0 = (_stat(($data|0),($statbuffer|0))|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($statbuffer) + 36|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)<(0);
  $5 = $4 << 31 >> 31;
  $6 = $5;$7 = $3;
 } else {
  $6 = 0;$7 = 0;
 }
 tempRet0 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZNK20LocalFileSystemPosix12LastModifiedERK13FileEntryData($agg$result,$this,$data) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $statbuffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $statbuffer = sp;
 __ZN8DateTimeC2Ev($agg$result);
 $0 = (_stat(($data|0),($statbuffer|0))|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (($statbuffer) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -2082844800)|0;
 $5 = ($4|0)<(0);
 $6 = $5 << 31 >> 31;
 $7 = (($agg$result) + 2|0);
 HEAP16[$7>>1] = 0;
 $8 = (($agg$result) + 4|0);
 HEAP32[$8>>2] = $4;
 $9 = $6&65535;
 HEAP16[$agg$result>>1] = $9;
 STACKTOP = sp;return;
}
function __ZN20LocalFileSystemPosix6ParentERK13FileEntryDataRNSt3__112basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE($this,$data,$path) {
 $this = $this|0;
 $data = $data|0;
 $path = $path|0;
 var $$0 = 0, $$0$i$i = 0, $$01 = 0, $$013$i$i = 0, $$02 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i$i = 0;
 var $__ps$0$i$i = 0, $__ps$0$i$i7 = 0, $phitmp = 0, $trimmed = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $trimmed = sp + 12|0;
 $0 = sp;
 $1 = (_strlen(($data|0))|0);
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$trimmed>>0] = $5;
  $6 = (($trimmed) + 1|0);
  $$pre$phiZ2D = $trimmed;$16 = $5;$__p$0$i$i$i = $6;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  $10 = (($trimmed) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$trimmed>>2] = $11;
  $12 = (($trimmed) + 4|0);
  HEAP32[$12>>2] = $1;
  $13 = $11&255;
  $$pre$phiZ2D = $trimmed;$16 = $13;$__p$0$i$i$i = $9;
 }
 _memcpy(($__p$0$i$i$i|0),($data|0),($1|0))|0;
 $14 = (($__p$0$i$i$i) + ($1)|0);
 HEAP8[$14>>0] = 0;
 $15 = $16 & 1;
 $17 = ($15<<24>>24)==(0);
 if ($17) {
  $20 = (($trimmed) + 1|0);
  $34 = $20;
 } else {
  $18 = (($trimmed) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $34 = $19;
 }
 $21 = $16 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $27 = (($trimmed) + 1|0);
  $28 = $16&255;
  $29 = $28 >>> 1;
  $31 = $27;$32 = $29;
 } else {
  $23 = (($trimmed) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($trimmed) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $31 = $24;$32 = $26;
 }
 $30 = (($31) + ($32)|0);
 $33 = ($34|0)==($30|0);
 if ($33) {
  $41 = $16;
 } else {
  $36 = $34;
  while(1) {
   $35 = HEAP8[$36>>0]|0;
   $37 = ($35<<24>>24)==(92);
   if ($37) {
    HEAP8[$36>>0] = 47;
   }
   $38 = (($36) + 1|0);
   $39 = ($38|0)==($30|0);
   if ($39) {
    break;
   } else {
    $36 = $38;
   }
  }
  $$pre = HEAP8[$$pre$phiZ2D>>0]|0;
  $41 = $$pre;
 }
 $40 = $41 & 1;
 $42 = ($40<<24>>24)==(0);
 if ($42) {
  $47 = $41&255;
  $48 = $47 >>> 1;
  $49 = (($trimmed) + 1|0);
  $$013$i$i = $48;$51 = $49;
 } else {
  $43 = (($trimmed) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($trimmed) + 8|0);
  $46 = HEAP32[$45>>2]|0;
  $$013$i$i = $44;$51 = $46;
 }
 $50 = (($51) + ($$013$i$i)|0);
 $__ps$0$i$i = $50;
 while(1) {
  $52 = ($__ps$0$i$i|0)==($51|0);
  if ($52) {
   $$0$i$i = 0;
   break;
  }
  $53 = (($__ps$0$i$i) + -1|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = $54&255;
  $56 = (_memchr(650392,$55,2)|0);
  $57 = ($56|0)==(0|0);
  if ($57) {
   label = 23;
   break;
  } else {
   $__ps$0$i$i = $53;
  }
 }
 if ((label|0) == 23) {
  $58 = $53;
  $59 = $51;
  $60 = (1 - ($59))|0;
  $phitmp = (($60) + ($58))|0;
  $$0$i$i = $phitmp;
 }
 $61 = $41 & 1;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $65 = $41&255;
  $66 = $65 >>> 1;
  $68 = $66;
 } else {
  $63 = (($trimmed) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $68 = $64;
 }
 $67 = ($68>>>0)<($$0$i$i>>>0);
 L38: do {
  if ($67) {
   __THREW__ = 0;
   invoke_vi(3304,0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 44;
   } else {
    // unreachable;
   }
  } else {
   if ($62) {
    $74 = (($trimmed) + 1|0);
    $75 = $$0$i$i << 1;
    $76 = $75&255;
    HEAP8[$$pre$phiZ2D>>0] = $76;
    $78 = $74;
   } else {
    $71 = (($trimmed) + 8|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($trimmed) + 4|0);
    HEAP32[$73>>2] = $$0$i$i;
    $78 = $72;
   }
   $77 = (($78) + ($$0$i$i)|0);
   HEAP8[$77>>0] = 0;
   $79 = HEAP8[$$pre$phiZ2D>>0]|0;
   $80 = $79 & 1;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    $84 = $79&255;
    $85 = $84 >>> 1;
    $87 = $85;
   } else {
    $82 = (($trimmed) + 4|0);
    $83 = HEAP32[$82>>2]|0;
    $87 = $83;
   }
   $86 = ($87|0)==(0);
   L50: do {
    if ($86) {
     $$0 = 0;$162 = $79;
    } else {
     if ($81) {
      $90 = (($trimmed) + 1|0);
      $92 = $90;
     } else {
      $88 = (($trimmed) + 8|0);
      $89 = HEAP32[$88>>2]|0;
      $92 = $89;
     }
     $91 = (($92) + ($87)|0);
     $__ps$0$i$i7 = $91;
     while(1) {
      $93 = ($__ps$0$i$i7|0)==($92|0);
      if ($93) {
       $$0 = 0;$162 = $79;
       break L50;
      }
      $94 = (($__ps$0$i$i7) + -1|0);
      $95 = HEAP8[$94>>0]|0;
      $96 = ($95<<24>>24)==(47);
      if ($96) {
       break;
      } else {
       $__ps$0$i$i7 = $94;
      }
     }
     $97 = $94;
     $98 = $92;
     $99 = (($97) - ($98))|0;
     $100 = ($99|0)==(-1);
     if ($100) {
      $$0 = 0;$162 = $79;
     } else {
      if ($81) {
       $107 = $79&255;
       $108 = $107 >>> 1;
       $109 = (($trimmed) + 1|0);
       $111 = $108;$128 = $109;
      } else {
       $103 = (($trimmed) + 4|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = (($trimmed) + 8|0);
       $106 = HEAP32[$105>>2]|0;
       $111 = $104;$128 = $106;
      }
      $110 = ($111>>>0)<($99>>>0);
      $112 = $110 ? $111 : $99;
      $113 = ($112>>>0)>(4294967279);
      if ($113) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        label = 44;
        break L38;
       }
       // unreachable;
      }
      $116 = ($112>>>0)<(11);
      if ($116) {
       $117 = $112 << 1;
       $118 = $117&255;
       HEAP8[$0>>0] = $118;
       $119 = (($0) + 1|0);
       $__p$0$i$i = $119;
      } else {
       $120 = (($112) + 16)|0;
       $121 = $120 & -16;
       __THREW__ = 0;
       $122 = (invoke_ii(2988,($121|0))|0);
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        label = 44;
        break L38;
       }
       $125 = (($0) + 8|0);
       HEAP32[$125>>2] = $122;
       $126 = $121 | 1;
       HEAP32[$0>>2] = $126;
       $127 = (($0) + 4|0);
       HEAP32[$127>>2] = $112;
       $__p$0$i$i = $122;
      }
      _memcpy(($__p$0$i$i|0),($128|0),($112|0))|0;
      $129 = (($__p$0$i$i) + ($112)|0);
      HEAP8[$129>>0] = 0;
      __THREW__ = 0;
      (invoke_iii(2233,($path|0),($0|0))|0);
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       $154 = ___cxa_find_matching_catch()|0;
       $155 = tempRet0;
       $156 = HEAP8[$0>>0]|0;
       $157 = $156 & 1;
       $158 = ($157<<24>>24)==(0);
       if ($158) {
        $$01 = $155;$$02 = $154;
        break L38;
       }
       $159 = (($0) + 8|0);
       $160 = HEAP32[$159>>2]|0;
       __ZdlPv($160);
       $$01 = $155;$$02 = $154;
       break L38;
      }
      $132 = HEAP8[$0>>0]|0;
      $133 = $132 & 1;
      $134 = ($133<<24>>24)==(0);
      if (!($134)) {
       $135 = (($0) + 8|0);
       $136 = HEAP32[$135>>2]|0;
       __ZdlPv($136);
      }
      $137 = HEAP8[$path>>0]|0;
      $138 = $137 & 1;
      $139 = ($138<<24>>24)==(0);
      if ($139) {
       $142 = $137&255;
       $143 = $142 >>> 1;
       $152 = $143;
      } else {
       $140 = (($path) + 4|0);
       $141 = HEAP32[$140>>2]|0;
       $152 = $141;
      }
      $144 = HEAP8[$$pre$phiZ2D>>0]|0;
      $145 = $144 & 1;
      $146 = ($145<<24>>24)==(0);
      if ($146) {
       $149 = $144&255;
       $150 = $149 >>> 1;
       $153 = $150;
      } else {
       $147 = (($trimmed) + 4|0);
       $148 = HEAP32[$147>>2]|0;
       $153 = $148;
      }
      $151 = ($152>>>0)<($153>>>0);
      $$0 = $151;$162 = $144;
     }
    }
   } while(0);
   $161 = $162 & 1;
   $163 = ($161<<24>>24)==(0);
   if ($163) {
    STACKTOP = sp;return ($$0|0);
   }
   $164 = (($trimmed) + 8|0);
   $165 = HEAP32[$164>>2]|0;
   __ZdlPv($165);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 if ((label|0) == 44) {
  $101 = ___cxa_find_matching_catch()|0;
  $102 = tempRet0;
  $$01 = $102;$$02 = $101;
 }
 $166 = HEAP8[$$pre$phiZ2D>>0]|0;
 $167 = $166 & 1;
 $168 = ($167<<24>>24)==(0);
 if ($168) {
  ___resumeException($$02|0);
  // unreachable;
 }
 $169 = (($trimmed) + 8|0);
 $170 = HEAP32[$169>>2]|0;
 __ZdlPv($170);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZNK20LocalFileSystemPosix8FilenameERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $$pn = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strrchr($data,47)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_strrchr($data,92)|0);
  $$pn = $2;
 } else {
  $$pn = $0;
 }
 $$0 = (($$pn) + 1|0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN20LocalFileSystemPosix9SetLengthER13FileEntryDatay($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_truncate(($data|0),($0|0))|0);
 $3 = ($2|0)==(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN20LocalFileSystemPosix8SetFlagsER13FileEntryDatajj($this,$data,$attributeMask,$attributeValue) {
 $this = $this|0;
 $data = $data|0;
 $attributeMask = $attributeMask|0;
 $attributeValue = $attributeValue|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN20LocalFileSystemPosix12CreateAsFileER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_fopen(($data|0),(650400|0))|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
 } else {
  (_fclose(($0|0))|0);
  $$0 = 1;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN20LocalFileSystemPosix11CreateAsDirER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_mkdir(($data|0),493)|0);
 $1 = ($0|0)==(0);
 STACKTOP = sp;return ($1|0);
}
function __ZN20LocalFileSystemPosix4LockER13FileEntryData12FileLockMode($this,$data,$lockMode) {
 $this = $this|0;
 $data = $data|0;
 $lockMode = $lockMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN20LocalFileSystemPosix6DeleteER13FileEntryDatab($this,$data,$recursively) {
 $this = $this|0;
 $data = $data|0;
 $recursively = $recursively|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$02$in = 0, $$byval_copy6 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $childEntries = 0, $handlerData = 0, $i$09 = 0, $item = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1104|0;
 $$byval_copy6 = sp + 1088|0;
 $0 = sp;
 $childEntries = sp + 8|0;
 $handlerData = sp + 24|0;
 $item = sp + 32|0;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iii[$3 & 4095]($this,$data)|0);
 if (!($4)) {
  $5 = (_unlink(($data|0))|0);
  $$02$in = $5;
  $$02 = ($$02$in|0)==(0);
  STACKTOP = sp;return ($$02|0);
 }
 L5: do {
  if ($recursively) {
   $6 = HEAP32[$this>>2]|0;
   $7 = (($6) + 88|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (FUNCTION_TABLE_iii[$8 & 4095]($this,$data)|0);
   if (!($9)) {
    HEAP32[$childEntries>>2] = 0;
    $10 = (($childEntries) + 8|0);
    HEAP32[$10>>2] = 0;
    $11 = (($childEntries) + 12|0);
    HEAP32[$11>>2] = 0;
    $12 = (($childEntries) + 4|0);
    HEAP32[$12>>2] = 61;
    HEAP32[$handlerData>>2] = 0;
    $13 = HEAP32[$this>>2]|0;
    $14 = (($13) + 148|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    (invoke_iiiiiii($15|0,($this|0),($data|0),($childEntries|0),0,($handlerData|0),0)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    L8: do {
     if ($17) {
      $34 = ___cxa_find_matching_catch()|0;
      $35 = tempRet0;
      $lpad$phi$index = $34;$lpad$phi$index2 = $35;
      label = 14;
     } else {
      $18 = HEAP32[$childEntries>>2]|0;
      $19 = HEAP32[$10>>2]|0;
      $20 = ($19|0)==(0);
      L10: do {
       if ($20) {
        $$lcssa = $18;
       } else {
        $i$09 = $18;
        while(1) {
         __THREW__ = 0;
         invoke_vii(3227,($item|0),($i$09|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          label = 12;
          break;
         }
         __THREW__ = 0;
         (invoke_iii(2531,($item|0),1)|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if ($24) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3572,($item|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if ($26) {
          label = 12;
          break;
         }
         $27 = (($i$09) + 1088|0);
         $28 = HEAP32[$childEntries>>2]|0;
         $29 = HEAP32[$10>>2]|0;
         $30 = (($28) + (($29*1088)|0)|0);
         $31 = ($27|0)==($30|0);
         if ($31) {
          $$lcssa = $28;
          break L10;
         } else {
          $i$09 = $27;
         }
        }
        if ((label|0) == 12) {
         $32 = ___cxa_find_matching_catch()|0;
         $33 = tempRet0;
         $lpad$phi$index = $32;$lpad$phi$index2 = $33;
         label = 14;
         break L8;
        }
        $36 = ___cxa_find_matching_catch()|0;
        $37 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3572,($item|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         $$0 = $37;$$01 = $36;
         break L8;
        }
        $55 = ___cxa_find_matching_catch(0|0)|0;
        $56 = tempRet0;
        ___clang_call_terminate($55);
        // unreachable;
       }
      } while(0);
      $40 = HEAP32[$11>>2]|0;
      $41 = ($40|0)>(-1);
      if (!($41)) {
       break L5;
      }
      $42 = HEAP32[$12>>2]|0;
      HEAP32[$0>>2] = $42;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($$lcssa,$$byval_copy6);
      HEAP32[$childEntries>>2] = 0;
      break L5;
     }
    } while(0);
    if ((label|0) == 14) {
     $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
    }
    $43 = HEAP32[$11>>2]|0;
    $44 = ($43|0)>(-1);
    if (!($44)) {
     ___resumeException($$01|0);
     // unreachable;
    }
    $45 = HEAP32[$childEntries>>2]|0;
    $46 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $46;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($45|0),($$byval_copy6|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     $55 = ___cxa_find_matching_catch(0|0)|0;
     $56 = tempRet0;
     ___clang_call_terminate($55);
     // unreachable;
    }
    HEAP32[$childEntries>>2] = 0;
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $49 = HEAP32[$this>>2]|0;
 $50 = (($49) + 88|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (FUNCTION_TABLE_iii[$51 & 4095]($this,$data)|0);
 if ($52) {
  $53 = (_unlink(($data|0))|0);
  $$02$in = $53;
  $$02 = ($$02$in|0)==(0);
  STACKTOP = sp;return ($$02|0);
 } else {
  $54 = (_rmdir(($data|0))|0);
  $$02$in = $54;
  $$02 = ($$02$in|0)==(0);
  STACKTOP = sp;return ($$02|0);
 }
 return 0|0;
}
function __ZNK20LocalFileSystemPosix6TargetERK13FileEntryDataR15FileSystemEntry($this,$data,$out_symLink) {
 $this = $this|0;
 $data = $data|0;
 $out_symLink = $out_symLink|0;
 var $$1 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $buf = 0, $target = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $buf = sp + 16|0;
 $target = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 4095]($this,$data)|0);
 if (!($3)) {
  __ZN15FileSystemEntry3SetEPKc($out_symLink,$data);
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $4 = (_readlink(($data|0),($buf|0),1024)|0);
 $5 = ($4|0)<(1024);
 if (!($5)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $6 = ($4>>>0)>(4294967279);
 if ($6) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $7 = ($4>>>0)<(11);
 if ($7) {
  $8 = $4 << 1;
  $9 = $8&255;
  HEAP8[$target>>0] = $9;
  $10 = (($target) + 1|0);
  $$pre$phiZ2D = $target;$20 = $9;$__p$0$i$i$i = $10;
 } else {
  $11 = (($4) + 16)|0;
  $12 = $11 & -16;
  $13 = (__Znwj($12)|0);
  $14 = (($target) + 8|0);
  HEAP32[$14>>2] = $13;
  $15 = $12 | 1;
  HEAP32[$target>>2] = $15;
  $16 = (($target) + 4|0);
  HEAP32[$16>>2] = $4;
  $17 = $15&255;
  $$pre$phiZ2D = $target;$20 = $17;$__p$0$i$i$i = $13;
 }
 _memcpy(($__p$0$i$i$i|0),($buf|0),($4|0))|0;
 $18 = (($__p$0$i$i$i) + ($4)|0);
 HEAP8[$18>>0] = 0;
 $19 = $20 & 1;
 $21 = ($19<<24>>24)==(0);
 if ($21) {
  $24 = (($target) + 1|0);
  $25 = $24;
 } else {
  $22 = (($target) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $25 = $23;
 }
 __THREW__ = 0;
 invoke_vii(3249,($out_symLink|0),($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $35 = HEAP8[$$pre$phiZ2D>>0]|0;
  $36 = $35 & 1;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   ___resumeException($33|0);
   // unreachable;
  }
  $38 = (($target) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  __ZdlPv($39);
  ___resumeException($33|0);
  // unreachable;
 } else {
  $28 = HEAP8[$$pre$phiZ2D>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
  $31 = (($target) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  __ZdlPv($32);
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZNK20LocalFileSystemPosix6ExistsERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_access(($data|0),0)|0);
 $1 = ($0|0)==(0);
 STACKTOP = sp;return ($1|0);
}
function __ZN20LocalFileSystemPosix8IsLockedERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $$02 = 0, $$04 = 0, $$1 = 0, $$13 = 0, $$15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i14 = 0, $__p$0$i$i$i7 = 0, $copyOfData = 0, $isUsed$0 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $paths = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1120|0;
 $0 = sp + 1096|0;
 $paths = sp;
 $1 = sp + 12|0;
 $2 = sp + 24|0;
 $copyOfData = sp + 40|0;
 $3 = (_strlen(($data|0))|0);
 $4 = ($3>>>0)>(4294967279);
 if ($4) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $5 = ($3>>>0)<(11);
 if ($5) {
  $6 = $3 << 1;
  $7 = $6&255;
  HEAP8[$0>>0] = $7;
  $8 = (($0) + 1|0);
  $__p$0$i$i$i = $8;
 } else {
  $9 = (($3) + 16)|0;
  $10 = $9 & -16;
  $11 = (__Znwj($10)|0);
  $12 = (($0) + 8|0);
  HEAP32[$12>>2] = $11;
  $13 = $10 | 1;
  HEAP32[$0>>2] = $13;
  $14 = (($0) + 4|0);
  HEAP32[$14>>2] = $3;
  $__p$0$i$i$i = $11;
 }
 _memcpy(($__p$0$i$i$i|0),($data|0),($3|0))|0;
 $15 = (($__p$0$i$i$i) + ($3)|0);
 HEAP8[$15>>0] = 0;
 __THREW__ = 0;
 $16 = (invoke_ii(3257,($0|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $61 = HEAP8[$0>>0]|0;
  $62 = $61 & 1;
  $63 = ($62<<24>>24)==(0);
  if ($63) {
   $$13 = $60;$$15 = $59;
   ___resumeException($$15|0);
   // unreachable;
  }
  $64 = (($0) + 8|0);
  $65 = HEAP32[$64>>2]|0;
  __ZdlPv($65);
  $$13 = $60;$$15 = $59;
  ___resumeException($$15|0);
  // unreachable;
 }
 $19 = HEAP8[$0>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  $22 = (($0) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  __ZdlPv($23);
 }
 if (!($16)) {
  $89 = (_strlen(($data|0))|0);
  $90 = ($89>>>0)>(4294967279);
  if ($90) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $91 = ($89>>>0)<(11);
  if ($91) {
   $92 = $89 << 1;
   $93 = $92&255;
   HEAP8[$2>>0] = $93;
   $94 = (($2) + 1|0);
   $__p$0$i$i$i14 = $94;
  } else {
   $95 = (($89) + 16)|0;
   $96 = $95 & -16;
   $97 = (__Znwj($96)|0);
   $98 = (($2) + 8|0);
   HEAP32[$98>>2] = $97;
   $99 = $96 | 1;
   HEAP32[$2>>2] = $99;
   $100 = (($2) + 4|0);
   HEAP32[$100>>2] = $89;
   $__p$0$i$i$i14 = $97;
  }
  _memcpy(($__p$0$i$i$i14|0),($data|0),($89|0))|0;
  $101 = (($__p$0$i$i$i14) + ($89)|0);
  HEAP8[$101>>0] = 0;
  __THREW__ = 0;
  $102 = (invoke_ii(3266,($2|0))|0);
  $103 = __THREW__; __THREW__ = 0;
  $104 = $103&1;
  if ($104) {
   $117 = ___cxa_find_matching_catch()|0;
   $118 = tempRet0;
   $119 = HEAP8[$2>>0]|0;
   $120 = $119 & 1;
   $121 = ($120<<24>>24)==(0);
   if ($121) {
    $$13 = $118;$$15 = $117;
    ___resumeException($$15|0);
    // unreachable;
   }
   $122 = (($2) + 8|0);
   $123 = HEAP32[$122>>2]|0;
   __ZdlPv($123);
   $$13 = $118;$$15 = $117;
   ___resumeException($$15|0);
   // unreachable;
  }
  $105 = HEAP8[$2>>0]|0;
  $106 = $105 & 1;
  $107 = ($106<<24>>24)==(0);
  if (!($107)) {
   $108 = (($2) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   __ZdlPv($109);
  }
  if (!($102)) {
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
  __ZN13FileEntryDataC2ERKS_($copyOfData,$data);
  $110 = (($copyOfData) + 1048|0);
  HEAP32[$110>>2] = 0;
  $111 = HEAP32[$this>>2]|0;
  $112 = (($111) + 8|0);
  $113 = HEAP32[$112>>2]|0;
  __THREW__ = 0;
  $114 = (invoke_iiiii($113|0,($this|0),($copyOfData|0),0,0)|0);
  $115 = __THREW__; __THREW__ = 0;
  $116 = $115&1;
  do {
   if (!($116)) {
    if ($114) {
     $128 = HEAP32[$110>>2]|0;
     $129 = (_fileno(($128|0))|0);
     __THREW__ = 0;
     $130 = (invoke_iii(2532,($129|0),6)|0);
     $131 = __THREW__; __THREW__ = 0;
     $132 = $131&1;
     if ($132) {
      break;
     }
     __THREW__ = 0;
     (invoke_iii(2532,($129|0),12)|0);
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if ($134) {
      break;
     }
     $135 = ($130|0)!=(0);
     $136 = HEAP32[$this>>2]|0;
     $137 = (($136) + 28|0);
     $138 = HEAP32[$137>>2]|0;
     __THREW__ = 0;
     (invoke_iii($138|0,($this|0),($copyOfData|0))|0);
     $139 = __THREW__; __THREW__ = 0;
     $140 = $139&1;
     if ($140) {
      break;
     } else {
      $isUsed$0 = $135;
     }
    } else {
     $isUsed$0 = 1;
    }
    __ZN13FileEntryDataD2Ev($copyOfData);
    $$1 = $isUsed$0;
    STACKTOP = sp;return ($$1|0);
   }
  } while(0);
  $124 = ___cxa_find_matching_catch()|0;
  $125 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3572,($copyOfData|0));
  $126 = __THREW__; __THREW__ = 0;
  $127 = $126&1;
  if ($127) {
   $142 = ___cxa_find_matching_catch(0|0)|0;
   $143 = tempRet0;
   ___clang_call_terminate($142);
   // unreachable;
  } else {
   $$13 = $125;$$15 = $124;
   ___resumeException($$15|0);
   // unreachable;
  }
 }
 $24 = (($paths) + 4|0);
 HEAP32[$24>>2] = 0;
 $25 = (($paths) + 8|0);
 HEAP32[$25>>2] = 0;
 $26 = (($paths) + 4|0);
 HEAP32[$paths>>2] = $26;
 $27 = (_strlen(($data|0))|0);
 $28 = ($27>>>0)>(4294967279);
 L53: do {
  if ($28) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 27;
   } else {
    // unreachable;
   }
  } else {
   $31 = ($27>>>0)<(11);
   if ($31) {
    $32 = $27 << 1;
    $33 = $32&255;
    HEAP8[$1>>0] = $33;
    $34 = (($1) + 1|0);
    $__p$0$i$i$i7 = $34;
   } else {
    $35 = (($27) + 16)|0;
    $36 = $35 & -16;
    __THREW__ = 0;
    $37 = (invoke_ii(2988,($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 27;
     break;
    }
    $40 = (($1) + 8|0);
    HEAP32[$40>>2] = $37;
    $41 = $36 | 1;
    HEAP32[$1>>2] = $41;
    $42 = (($1) + 4|0);
    HEAP32[$42>>2] = $27;
    $__p$0$i$i$i7 = $37;
   }
   _memcpy(($__p$0$i$i$i7|0),($data|0),($27|0))|0;
   $43 = (($__p$0$i$i$i7) + ($27)|0);
   HEAP8[$43>>0] = 0;
   __THREW__ = 0;
   $44 = (invoke_iii(2417,($1|0),($paths|0))|0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $70 = ___cxa_find_matching_catch()|0;
    $71 = tempRet0;
    $72 = HEAP8[$1>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    if ($74) {
     $$02 = $71;$$04 = $70;
     break;
    }
    $75 = (($1) + 8|0);
    $76 = HEAP32[$75>>2]|0;
    __ZdlPv($76);
    $$02 = $71;$$04 = $70;
    break;
   }
   $47 = HEAP8[$1>>0]|0;
   $48 = $47 & 1;
   $49 = ($48<<24>>24)==(0);
   if (!($49)) {
    $50 = (($1) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    __ZdlPv($51);
   }
   L67: do {
    if ($44) {
     $52 = HEAP32[$paths>>2]|0;
     $53 = ($52|0)==($26|0);
     if (!($53)) {
      $55 = $52;
      while(1) {
       $54 = (($55) + 16|0);
       __THREW__ = 0;
       $56 = (invoke_ii(3267,($54|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 26;
        break;
       }
       if ($56) {
        break;
       }
       $77 = (($55) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($78|0)==(0|0);
       if ($79) {
        $$01$i$i$i = $55;
        while(1) {
         $82 = (($$01$i$i$i) + 8|0);
         $83 = HEAP32[$82>>2]|0;
         $84 = HEAP32[$83>>2]|0;
         $85 = ($84|0)==($$01$i$i$i|0);
         if ($85) {
          $$0$i$i$i = $83;
          break;
         } else {
          $$01$i$i$i = $83;
         }
        }
       } else {
        $$0$i$i$i$i = $78;
        while(1) {
         $80 = HEAP32[$$0$i$i$i$i>>2]|0;
         $81 = ($80|0)==(0|0);
         if ($81) {
          $$0$i$i$i = $$0$i$i$i$i;
          break;
         } else {
          $$0$i$i$i$i = $80;
         }
        }
       }
       $86 = ($$0$i$i$i|0)==($26|0);
       if ($86) {
        break L67;
       } else {
        $55 = $$0$i$i$i;
       }
      }
      if ((label|0) == 26) {
       $66 = ___cxa_find_matching_catch()|0;
       $67 = tempRet0;
       $lpad$phi$index = $66;$lpad$phi$index2 = $67;
       label = 28;
       break L53;
      }
      $141 = HEAP32[$24>>2]|0;
      __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($paths,$141);
      $$1 = 1;
      STACKTOP = sp;return ($$1|0);
     }
    }
   } while(0);
   $87 = HEAP32[$24>>2]|0;
   __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($paths,$87);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 if ((label|0) == 27) {
  $68 = ___cxa_find_matching_catch()|0;
  $69 = tempRet0;
  $lpad$phi$index = $68;$lpad$phi$index2 = $69;
  label = 28;
 }
 if ((label|0) == 28) {
  $$02 = $lpad$phi$index2;$$04 = $lpad$phi$index;
 }
 $88 = HEAP32[$24>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($paths,$88);
 $$13 = $$02;$$15 = $$04;
 ___resumeException($$15|0);
 // unreachable;
 return 0|0;
}
function __ZN20LocalFileSystemPosix10AtomicMoveER13FileEntryDataS1_($this,$from,$to) {
 $this = $this|0;
 $from = $from|0;
 $to = $to|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viii[$4 & 4095]($0,$this,$from);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (($0) + 1|0);
  $22 = $10;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $22 = $9;
 }
 $11 = HEAP32[$this>>2]|0;
 $12 = (($11) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 __THREW__ = 0;
 invoke_viii($13|0,($1|0),($this|0),($to|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  $38 = HEAP8[$0>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if ($40) {
   ___resumeException($36|0);
   // unreachable;
  }
  $41 = (($0) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  __ZdlPv($42);
  ___resumeException($36|0);
  // unreachable;
 }
 $16 = HEAP8[$1>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $21 = (($1) + 1|0);
  $23 = $21;
 } else {
  $19 = (($1) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $23 = $20;
 }
 $24 = (_rename(($22|0),($23|0))|0);
 $25 = HEAP8[$1>>0]|0;
 $26 = $25 & 1;
 $27 = ($26<<24>>24)==(0);
 if (!($27)) {
  $28 = (($1) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  __ZdlPv($29);
 }
 $30 = HEAP8[$0>>0]|0;
 $31 = $30 & 1;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  $35 = ($24|0)==(0);
  STACKTOP = sp;return ($35|0);
 }
 $33 = (($0) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 __ZdlPv($34);
 $35 = ($24|0)==(0);
 STACKTOP = sp;return ($35|0);
}
function __ZN20LocalFileSystemPosix4CopyER13FileEntryDataS1_($this,$f,$t) {
 $this = $this|0;
 $f = $f|0;
 $t = $t|0;
 var $$ = 0, $$02 = 0, $$06 = 0, $$13 = 0, $$17 = 0, $$2 = 0, $$24 = 0, $$28 = 0, $$3 = 0, $$35 = 0, $$39 = 0, $$4 = 0, $$410 = 0, $$5 = 0, $$511 = 0, $$byval_copy14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $actualRead = 0, $actualWrite = 0;
 var $childEntries = 0, $destination = 0, $from = 0, $fullDestinationPath = 0, $handlerData = 0, $i$038 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi37$index = 0, $lpad$phi37$index7 = 0, $source = 0, $to = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4320|0;
 $$byval_copy14 = sp + 4312|0;
 $0 = sp + 4308|0;
 $1 = sp + 4304|0;
 $2 = sp + 4300|0;
 $3 = sp + 4296|0;
 $from = sp + 3232|0;
 $to = sp + 2168|0;
 $actualRead = sp + 8|0;
 $actualWrite = sp;
 $childEntries = sp + 24|0;
 $handlerData = sp + 16|0;
 $source = sp + 40|0;
 $fullDestinationPath = sp + 1096|0;
 $destination = sp + 1112|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 116|0);
 $6 = HEAP32[$5>>2]|0;
 (FUNCTION_TABLE_iiii[$6 & 2047]($this,$t,1)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iii[$9 & 4095]($this,$f)|0);
 if (!($10)) {
  __ZN12FileAccessorC2Ev($from);
  __THREW__ = 0;
  invoke_vi(3584,($to|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  L3: do {
   if ($12) {
    label = 13;
   } else {
    __THREW__ = 0;
    (invoke_iiiii(254,($from|0),($f|0),0,0)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    L5: do {
     if ($14) {
      label = 14;
     } else {
      __THREW__ = 0;
      (invoke_iiiii(254,($to|0),($t|0),1,0)|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       label = 14;
      } else {
       $17 = $actualRead;
       $18 = $17;
       HEAP32[$18>>2] = 0;
       $19 = (($17) + 4)|0;
       $20 = $19;
       HEAP32[$20>>2] = 0;
       $21 = $actualWrite;
       $22 = $21;
       HEAP32[$22>>2] = 0;
       $23 = (($21) + 4)|0;
       $24 = $23;
       HEAP32[$24>>2] = 0;
       $25 = HEAP32[628512>>2]|0;
       $26 = HEAP32[$this>>2]|0;
       $27 = (($26) + 44|0);
       $28 = HEAP32[$27>>2]|0;
       __THREW__ = 0;
       $29 = (invoke_iii($28|0,($this|0),($f|0))|0);
       $30 = tempRet0;
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        $33 = ___cxa_find_matching_catch()|0;
        $34 = tempRet0;
        $178 = $34;$179 = $33;$66 = 0;
       } else {
        $35 = ($29|0)==(0);
        if ($35) {
         $46 = 0;$74 = 0;
         label = 9;
        } else {
         HEAP32[$3>>2] = $25;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
         $36 = (invoke_iiiiiiii(108,(0|0),($29|0),1,($$byval_copy14|0),0,(650768|0),370)|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          $180 = 0;$65 = $29;
         } else {
          $46 = $36;$74 = $29;
          label = 9;
         }
        }
        do {
         if ((label|0) == 9) {
          $39 = HEAP32[$this>>2]|0;
          $40 = (($39) + 44|0);
          $41 = HEAP32[$40>>2]|0;
          __THREW__ = 0;
          $42 = (invoke_iii($41|0,($this|0),($f|0))|0);
          $43 = tempRet0;
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           $180 = $46;$65 = $74;
          } else {
           __THREW__ = 0;
           $47 = (invoke_iiiiii(206,($from|0),($42|0),($43|0),($46|0),($actualRead|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            $180 = $46;$65 = $74;
           } else {
            if ($47) {
             $50 = $actualRead;
             $51 = $50;
             $52 = HEAP32[$51>>2]|0;
             $53 = (($50) + 4)|0;
             $54 = $53;
             $55 = HEAP32[$54>>2]|0;
             __THREW__ = 0;
             (invoke_iiiiii(207,($to|0),($52|0),($55|0),($46|0),($actualWrite|0))|0);
             $56 = __THREW__; __THREW__ = 0;
             $57 = $56&1;
             if ($57) {
              $180 = $46;$65 = $74;
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(3318,($to|0))|0);
            $69 = __THREW__; __THREW__ = 0;
            $70 = $69&1;
            if ($70) {
             $180 = $46;$65 = $74;
            } else {
             __THREW__ = 0;
             (invoke_ii(3318,($from|0))|0);
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if ($72) {
              $180 = $46;$65 = $74;
             } else {
              $73 = ($74|0)>(-1);
              if ($73) {
               HEAP32[$0>>2] = $25;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
               invoke_vii(2591,($46|0),($$byval_copy14|0));
               $75 = __THREW__; __THREW__ = 0;
               $76 = $75&1;
               if ($76) {
                label = 14;
                break L5;
               }
              }
              __THREW__ = 0;
              invoke_vi(1174,($to|0));
              $77 = __THREW__; __THREW__ = 0;
              $78 = $77&1;
              if ($78) {
               label = 13;
               break L3;
              }
              __ZN12FileAccessorD2Ev($from);
              $$3 = $47;
              STACKTOP = sp;return ($$3|0);
             }
            }
           }
          }
         }
        } while(0);
        $62 = ___cxa_find_matching_catch()|0;
        $63 = tempRet0;
        $64 = ($65|0)>(-1);
        if ($64) {
         $178 = $63;$179 = $62;$66 = $180;
        } else {
         $$02 = $63;$$06 = $62;
         break;
        }
       }
       HEAP32[$1>>2] = $25;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($66|0),($$byval_copy14|0));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        $176 = ___cxa_find_matching_catch(0|0)|0;
        $177 = tempRet0;
        ___clang_call_terminate($176);
        // unreachable;
       } else {
        $$02 = $178;$$06 = $179;
       }
      }
     }
    } while(0);
    if ((label|0) == 14) {
     $60 = ___cxa_find_matching_catch()|0;
     $61 = tempRet0;
     $$02 = $61;$$06 = $60;
    }
    __THREW__ = 0;
    invoke_vi(1174,($to|0));
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     $176 = ___cxa_find_matching_catch(0|0)|0;
     $177 = tempRet0;
     ___clang_call_terminate($176);
     // unreachable;
    } else {
     $$13 = $$02;$$17 = $$06;
    }
   }
  } while(0);
  if ((label|0) == 13) {
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $$13 = $59;$$17 = $58;
  }
  __THREW__ = 0;
  invoke_vi(1174,($from|0));
  $81 = __THREW__; __THREW__ = 0;
  $82 = $81&1;
  if ($82) {
   $176 = ___cxa_find_matching_catch(0|0)|0;
   $177 = tempRet0;
   ___clang_call_terminate($176);
   // unreachable;
  } else {
   $$5 = $$13;$$511 = $$17;
   ___resumeException($$511|0);
   // unreachable;
  }
 }
 $83 = HEAP32[$this>>2]|0;
 $84 = (($83) + 112|0);
 $85 = HEAP32[$84>>2]|0;
 (FUNCTION_TABLE_iii[$85 & 4095]($this,$t)|0);
 HEAP32[$childEntries>>2] = 0;
 $86 = (($childEntries) + 8|0);
 HEAP32[$86>>2] = 0;
 $87 = (($childEntries) + 12|0);
 HEAP32[$87>>2] = 0;
 $88 = (($childEntries) + 4|0);
 HEAP32[$88>>2] = 61;
 HEAP32[$handlerData>>2] = 0;
 $89 = HEAP32[$this>>2]|0;
 $90 = (($89) + 148|0);
 $91 = HEAP32[$90>>2]|0;
 __THREW__ = 0;
 (invoke_iiiiiii($91|0,($this|0),($f|0),($childEntries|0),0,($handlerData|0),0)|0);
 $92 = __THREW__; __THREW__ = 0;
 $93 = $92&1;
 L41: do {
  if ($93) {
   $142 = ___cxa_find_matching_catch()|0;
   $143 = tempRet0;
   $lpad$phi$index = $142;$lpad$phi$index2 = $143;
   label = 45;
  } else {
   $94 = HEAP32[$86>>2]|0;
   $95 = ($94|0)==(0);
   L43: do {
    if ($95) {
     $$2 = 1;
    } else {
     $96 = HEAP32[$childEntries>>2]|0;
     $97 = (($fullDestinationPath) + 1|0);
     $98 = (($fullDestinationPath) + 8|0);
     $99 = (($fullDestinationPath) + 4|0);
     $i$038 = $96;
     while(1) {
      __THREW__ = 0;
      invoke_vii(3227,($source|0),($i$038|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       label = 43;
       break;
      }
      $107 = (_strlen(($t|0))|0);
      $108 = ($107>>>0)>(4294967279);
      if ($108) {
       label = 31;
       break;
      }
      $111 = ($107>>>0)<(11);
      if ($111) {
       $112 = $107 << 1;
       $113 = $112&255;
       HEAP8[$fullDestinationPath>>0] = $113;
       $__p$0$i$i$i = $97;
      } else {
       $114 = (($107) + 16)|0;
       $115 = $114 & -16;
       __THREW__ = 0;
       $116 = (invoke_ii(2988,($115|0))|0);
       $117 = __THREW__; __THREW__ = 0;
       $118 = $117&1;
       if ($118) {
        label = 46;
        break;
       }
       HEAP32[$98>>2] = $116;
       $119 = $115 | 1;
       HEAP32[$fullDestinationPath>>2] = $119;
       HEAP32[$99>>2] = $107;
       $__p$0$i$i$i = $116;
      }
      _memcpy(($__p$0$i$i$i|0),($t|0),($107|0))|0;
      $120 = (($__p$0$i$i$i) + ($107)|0);
      HEAP8[$120>>0] = 0;
      __THREW__ = 0;
      (invoke_iiii(1480,($fullDestinationPath|0),(650408|0),1)|0);
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $123 = (invoke_ii(3321,($source|0))|0);
      $124 = __THREW__; __THREW__ = 0;
      $125 = $124&1;
      if ($125) {
       label = 49;
       break;
      }
      $126 = (_strlen(($123|0))|0);
      __THREW__ = 0;
      (invoke_iiii(1480,($fullDestinationPath|0),($123|0),($126|0))|0);
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       label = 49;
       break;
      }
      $129 = HEAP8[$fullDestinationPath>>0]|0;
      $130 = $129 & 1;
      $131 = ($130<<24>>24)==(0);
      $132 = HEAP32[$98>>2]|0;
      $$ = $131 ? $97 : $132;
      __THREW__ = 0;
      invoke_vii(3227,($destination|0),($$|0));
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $135 = (invoke_iii(2529,($source|0),($destination|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       label = 50;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3572,($destination|0));
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       label = 49;
       break;
      }
      $154 = HEAP8[$fullDestinationPath>>0]|0;
      $155 = $154 & 1;
      $156 = ($155<<24>>24)==(0);
      if (!($156)) {
       $157 = HEAP32[$98>>2]|0;
       __ZdlPv($157);
      }
      __THREW__ = 0;
      invoke_vi(3572,($source|0));
      $158 = __THREW__; __THREW__ = 0;
      $159 = $158&1;
      if ($159) {
       label = 43;
       break;
      }
      $104 = (($i$038) + 1088|0);
      if (!($135)) {
       $$2 = 0;
       break L43;
      }
      $100 = HEAP32[$childEntries>>2]|0;
      $101 = HEAP32[$86>>2]|0;
      $102 = (($100) + (($101*1088)|0)|0);
      $103 = ($104|0)==($102|0);
      if ($103) {
       $$2 = 1;
       break L43;
      } else {
       $i$038 = $104;
      }
     }
     do {
      if ((label|0) == 31) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $109 = __THREW__; __THREW__ = 0;
       $110 = $109&1;
       if ($110) {
        $146 = ___cxa_find_matching_catch()|0;
        $147 = tempRet0;
        $lpad$phi37$index = $146;$lpad$phi37$index7 = $147;
        label = 48;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 43) {
       $140 = ___cxa_find_matching_catch()|0;
       $141 = tempRet0;
       $lpad$phi$index = $140;$lpad$phi$index2 = $141;
       label = 45;
       break L41;
      }
      else if ((label|0) == 46) {
       $144 = ___cxa_find_matching_catch()|0;
       $145 = tempRet0;
       $lpad$phi37$index = $144;$lpad$phi37$index7 = $145;
       label = 48;
      }
      else if ((label|0) == 49) {
       $148 = ___cxa_find_matching_catch()|0;
       $149 = tempRet0;
       $$24 = $149;$$28 = $148;
       label = 55;
      }
      else if ((label|0) == 50) {
       $150 = ___cxa_find_matching_catch()|0;
       $151 = tempRet0;
       __THREW__ = 0;
       invoke_vi(3572,($destination|0));
       $152 = __THREW__; __THREW__ = 0;
       $153 = $152&1;
       if ($153) {
        $176 = ___cxa_find_matching_catch(0|0)|0;
        $177 = tempRet0;
        ___clang_call_terminate($176);
        // unreachable;
       } else {
        $$24 = $151;$$28 = $150;
        label = 55;
       }
      }
     } while(0);
     if ((label|0) == 48) {
      $$35 = $lpad$phi37$index7;$$39 = $lpad$phi37$index;
     }
     else if ((label|0) == 55) {
      $160 = HEAP8[$fullDestinationPath>>0]|0;
      $161 = $160 & 1;
      $162 = ($161<<24>>24)==(0);
      if ($162) {
       $$35 = $$24;$$39 = $$28;
      } else {
       $163 = HEAP32[$98>>2]|0;
       __ZdlPv($163);
       $$35 = $$24;$$39 = $$28;
      }
     }
     __THREW__ = 0;
     invoke_vi(3572,($source|0));
     $164 = __THREW__; __THREW__ = 0;
     $165 = $164&1;
     if (!($165)) {
      $$4 = $$35;$$410 = $$39;
      break L41;
     }
     $176 = ___cxa_find_matching_catch(0|0)|0;
     $177 = tempRet0;
     ___clang_call_terminate($176);
     // unreachable;
    }
   } while(0);
   $166 = HEAP32[$87>>2]|0;
   $167 = ($166|0)>(-1);
   if (!($167)) {
    $$3 = $$2;
    STACKTOP = sp;return ($$3|0);
   }
   $168 = HEAP32[$childEntries>>2]|0;
   $169 = HEAP32[$88>>2]|0;
   HEAP32[$0>>2] = $169;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($168,$$byval_copy14);
   HEAP32[$childEntries>>2] = 0;
   $$3 = $$2;
   STACKTOP = sp;return ($$3|0);
  }
 } while(0);
 if ((label|0) == 45) {
  $$4 = $lpad$phi$index2;$$410 = $lpad$phi$index;
 }
 $170 = HEAP32[$87>>2]|0;
 $171 = ($170|0)>(-1);
 if (!($171)) {
  $$5 = $$4;$$511 = $$410;
  ___resumeException($$511|0);
  // unreachable;
 }
 $172 = HEAP32[$childEntries>>2]|0;
 $173 = HEAP32[$88>>2]|0;
 HEAP32[$2>>2] = $173;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($172|0),($$byval_copy14|0));
 $174 = __THREW__; __THREW__ = 0;
 $175 = $174&1;
 if ($175) {
  $176 = ___cxa_find_matching_catch(0|0)|0;
  $177 = tempRet0;
  ___clang_call_terminate($176);
  // unreachable;
 }
 HEAP32[$childEntries>>2] = 0;
 $$5 = $$4;$$511 = $$410;
 ___resumeException($$511|0);
 // unreachable;
 return 0|0;
}
function __ZN20LocalFileSystemPosix4OpenER13FileEntryData14FilePermission16FileAutoBehavior($this,$data,$permissions,$behavior) {
 $this = $this|0;
 $data = $data|0;
 $permissions = $permissions|0;
 $behavior = $behavior|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f$0 = 0, $fileMode$0 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($permissions|0) == 3)) {
  $fileMode$0 = 650440;
 } else if ((($permissions|0) == 2)) {
  $fileMode$0 = 650432;
 } else if ((($permissions|0) == 1)) {
  $fileMode$0 = 650424;
 } else if ((($permissions|0) == 0)) {
  $fileMode$0 = 650416;
 } else {
  $fileMode$0 = 0;
 }
 $0 = (_fopen(($data|0),($fileMode$0|0))|0);
 $1 = ($0|0)==(0|0);
 $2 = ($permissions|0)==(2);
 $or$cond = $1 & $2;
 if ($or$cond) {
  $3 = (_fopen(($data|0),(650448|0))|0);
  $f$0 = $3;
 } else {
  $4 = ($0|0)!=(0|0);
  $5 = ($permissions|0)==(3);
  $or$cond1 = $4 & $5;
  if ($or$cond1) {
   (_fseek(($0|0),0,2)|0);
   $f$0 = $0;
  } else {
   $f$0 = $0;
  }
 }
 $6 = (($data) + 1048|0);
 HEAP32[$6>>2] = $f$0;
 $7 = (($data) + 1040|0);
 HEAP32[$7>>2] = $this;
 $8 = (($data) + 1044|0);
 HEAP32[$8>>2] = $this;
 $9 = ($f$0|0)!=(0|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN20LocalFileSystemPosix4ReadER13FileEntryDatayyPvPy($this,$data,$0,$1,$2,$3,$buffer,$actual) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($data) + 1048|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (_fseek(($5|0),($0|0),0)|0);
 $7 = (_fread(($buffer|0),1,($2|0),($5|0))|0);
 $8 = $actual;
 $9 = $8;
 HEAP32[$9>>2] = $7;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 $12 = (_ferror(($5|0))|0);
 $13 = (($data) + 1052|0);
 HEAP32[$13>>2] = $12;
 $14 = ($12|0)==(0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20LocalFileSystemPosix4ReadER13FileEntryDatayPvPy($this,$data,$0,$1,$buffer,$actual) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$ = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($data) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return 0;
 } else {
  $5 = (_fread(($buffer|0),1,($0|0),($3|0))|0);
  $6 = $actual;
  $7 = $6;
  HEAP32[$7>>2] = $5;
  $8 = (($6) + 4)|0;
  $9 = $8;
  HEAP32[$9>>2] = 0;
  $10 = (_ferror(($3|0))|0);
  $11 = (($data) + 1052|0);
  HEAP32[$11>>2] = $10;
  $12 = ($10|0)==(0);
  $13 = ($5|0)!=(0);
  $$ = $12 & $13;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function __ZN20LocalFileSystemPosix5CloseER13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 1048|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($data) + 1052|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$0>>2] = 0;
 $4 = (_fclose(($1|0))|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $$pre = HEAP32[$3>>2]|0;
  $9 = $$pre;
 } else {
  $6 = (___errno_location()|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$3>>2] = $7;
  $9 = $7;
 }
 $8 = ($9|0)==(0);
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20LocalFileSystemPosix5WriteER13FileEntryDatayyPvPy($this,$data,$0,$1,$2,$3,$buffer,$actual) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $10 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = (($data) + 1048|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (_fseek(($5|0),($0|0),0)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiiii[$9 & 255]($this,$data,$2,$3,$buffer,$actual)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20LocalFileSystemPosix5WriteER13FileEntryDatayPvPy($this,$data,$0,$1,$buffer,$actual) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $buffer = $buffer|0;
 $actual = $actual|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($data) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (_fwrite(($buffer|0),1,($0|0),($3|0))|0);
 $6 = $actual;
 $7 = $6;
 HEAP32[$7>>2] = $5;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = (_ferror(($3|0))|0);
 $11 = (($data) + 1052|0);
 HEAP32[$11>>2] = $10;
 $12 = ($10|0)==(0);
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20LocalFileSystemPosix4SeekER13FileEntryDatay10FileOrigin($this,$data,$0,$1,$origin) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 $origin = $origin|0;
 var $$0 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $mode$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($data) + 1048|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ((($origin|0) == 2)) {
  $mode$0 = 1;
 } else if ((($origin|0) == 3)) {
  $mode$0 = 2;
 } else {
  $mode$0 = 0;
 }
 $5 = (_fseek(($3|0),($0|0),($mode$0|0))|0);
 $6 = ($5|0)==(0);
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK20LocalFileSystemPosix8PositionERK13FileEntryData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 1048|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $6 = 0;$7 = 0;
 } else {
  $3 = (_ftell(($1|0))|0);
  $4 = ($3|0)<(0);
  $5 = $4 << 31 >> 31;
  $6 = $5;$7 = $3;
 }
 tempRet0 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZNK20LocalFileSystemPosix9EnumerateEPKcP13dynamic_arrayI13FileEntryInfoLj8EEbPPv19FileEnumerationFlag($this,$path,$outList,$recurse,$handlerData,$flags) {
 $this = $this|0;
 $path = $path|0;
 $outList = $outList|0;
 $recurse = $recurse|0;
 $handlerData = $handlerData|0;
 $flags = $flags|0;
 var $$ = 0, $$01 = 0, $$byval_copy7 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $brmerge$demorgan = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $parentPath = 0, $retValue$2$off0 = 0, $statbuffer = 0, $vararg_ptr6 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy7 = sp;
 $0 = sp + 100|0;
 $1 = sp + 8|0;
 $parentPath = sp + 12|0;
 $statbuffer = sp + 24|0;
 $2 = (_opendir(($path|0))|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$01 = 0;
  STACKTOP = sp;return ($$01|0);
 }
 $4 = (_strlen(($path|0))|0);
 $5 = ($4>>>0)>(4294967279);
 if ($5) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $6 = ($4>>>0)<(11);
 if ($6) {
  $7 = $4 << 1;
  $8 = $7&255;
  HEAP8[$parentPath>>0] = $8;
  $9 = (($parentPath) + 1|0);
  $$pre$phiZ2D = $parentPath;$19 = $8;$__p$0$i$i$i = $9;
 } else {
  $10 = (($4) + 16)|0;
  $11 = $10 & -16;
  $12 = (__Znwj($11)|0);
  $13 = (($parentPath) + 8|0);
  HEAP32[$13>>2] = $12;
  $14 = $11 | 1;
  HEAP32[$parentPath>>2] = $14;
  $15 = (($parentPath) + 4|0);
  HEAP32[$15>>2] = $4;
  $16 = $14&255;
  $$pre$phiZ2D = $parentPath;$19 = $16;$__p$0$i$i$i = $12;
 }
 _memcpy(($__p$0$i$i$i|0),($path|0),($4|0))|0;
 $17 = (($__p$0$i$i$i) + ($4)|0);
 HEAP8[$17>>0] = 0;
 $18 = $19 & 1;
 $20 = ($18<<24>>24)==(0);
 if ($20) {
  $23 = $19&255;
  $24 = $23 >>> 1;
  $26 = $24;
 } else {
  $21 = (($parentPath) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $26 = $22;
 }
 $25 = ($26|0)==(0);
 if ($25) {
  label = 15;
 } else {
  $27 = $19 & 1;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $33 = (($parentPath) + 1|0);
   $34 = $19&255;
   $35 = $34 >>> 1;
   $36 = $35;$38 = $33;
  } else {
   $29 = (($parentPath) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($parentPath) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $36 = $32;$38 = $30;
  }
  $$sum = (($36) + -1)|0;
  $37 = (($38) + ($$sum)|0);
  $39 = HEAP8[$37>>0]|0;
  $40 = ($39<<24>>24)==(47);
  if ($40) {
   label = 16;
  } else {
   label = 15;
  }
 }
 if ((label|0) == 15) {
  __THREW__ = 0;
  (invoke_iiii(1480,($parentPath|0),(650408|0),1)|0);
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if ($42) {
   $63 = ___cxa_find_matching_catch()|0;
   $64 = tempRet0;
   $lpad$phi$index = $63;$lpad$phi$index2 = $64;
  } else {
   label = 16;
  }
 }
 do {
  if ((label|0) == 16) {
   $43 = (($outList) + 8|0);
   $44 = (($outList) + 12|0);
   $45 = (($outList) + 4|0);
   $46 = (($parentPath) + 1|0);
   $47 = (($statbuffer) + 12|0);
   $48 = (($statbuffer) + 56|0);
   $49 = ($flags|0)==(0);
   $50 = $flags & 8;
   $51 = ($50|0)==(0);
   $52 = $flags & 2;
   $53 = ($52|0)==(0);
   $54 = $flags & 32;
   $55 = ($54|0)==(0);
   $56 = $flags & 16;
   $57 = ($56|0)==(0);
   $58 = $flags & 4;
   $59 = ($58|0)==(0);
   $60 = (($parentPath) + 8|0);
   L26: while(1) {
    __THREW__ = 0;
    $70 = (invoke_ii(3322,($2|0))|0);
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     label = 17;
     break;
    }
    $73 = ($70|0)==(0|0);
    if ($73) {
     $retValue$2$off0 = 1;
     break;
    }
    $74 = (($70) + 11|0);
    $75 = (_strcmp($74,650456)|0);
    $76 = ($75|0)==(0);
    if ($76) {
     continue;
    }
    $77 = (_strcmp($74,650464)|0);
    $78 = ($77|0)==(0);
    if ($78) {
     continue;
    }
    $79 = HEAP32[$43>>2]|0;
    $80 = (($79) + 1)|0;
    HEAP32[$43>>2] = $80;
    $81 = HEAP32[$44>>2]|0;
    $82 = $81 & 2147483647;
    $83 = ($80>>>0)>($82>>>0);
    if ($83) {
     $84 = $81 << 1;
     $85 = ($84|0)==(0);
     $86 = $85 ? 1 : $84;
     $87 = ($82>>>0)<($86>>>0);
     do {
      if ($87) {
       $88 = ($81|0)>(-1);
       if ($88) {
        HEAP32[$44>>2] = $86;
        $89 = HEAP32[$outList>>2]|0;
        $90 = ($86*1088)|0;
        $91 = HEAP32[$45>>2]|0;
        HEAP32[$0>>2] = $91;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
        $92 = (invoke_iiiiiiii(108,($89|0),($90|0),8,($$byval_copy7|0),0,(650768|0),370)|0);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         label = 17;
         break L26;
        }
        HEAP32[$outList>>2] = $92;
        break;
       } else {
        $95 = ($86*1088)|0;
        $96 = HEAP32[$45>>2]|0;
        HEAP32[$1>>2] = $96;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
        $97 = (invoke_iiiiiii(102,($95|0),8,($$byval_copy7|0),0,(650768|0),352)|0);
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         label = 17;
         break L26;
        }
        $100 = HEAP32[$outList>>2]|0;
        $101 = HEAP32[$43>>2]|0;
        $102 = ($101*1088)|0;
        _memcpy(($97|0),($100|0),($102|0))|0;
        HEAP32[$44>>2] = $86;
        HEAP32[$outList>>2] = $97;
        break;
       }
      }
     } while(0);
     $$pre$i = HEAP32[$43>>2]|0;
     $104 = $$pre$i;
    } else {
     $104 = $80;
    }
    $103 = (($104) + -1)|0;
    $105 = HEAP32[$outList>>2]|0;
    $106 = (($105) + (($103*1088)|0)|0);
    $107 = HEAP8[$$pre$phiZ2D>>0]|0;
    $108 = $107 & 1;
    $109 = ($108<<24>>24)==(0);
    $110 = HEAP32[$60>>2]|0;
    $$ = $109 ? $46 : $110;
    HEAP32[$$byval_copy7>>2] = $$;
    $vararg_ptr6 = (($$byval_copy7) + 4|0);
    HEAP32[$vararg_ptr6>>2] = $74;
    (_sprintf($106,650472,$$byval_copy7)|0);
    (_stat(($106|0),($statbuffer|0))|0);
    $111 = HEAP32[$47>>2]|0;
    $112 = $111 & 61440;
    $113 = ($112|0)==(16384);
    $114 = ((($105) + (($103*1088)|0)|0) + 1080|0);
    $115 = $113&1;
    HEAP8[$114>>0] = $115;
    $116 = ($112|0)==(40960);
    $117 = ((($105) + (($103*1088)|0)|0) + 1081|0);
    $118 = $116&1;
    HEAP8[$117>>0] = $118;
    $119 = HEAP8[$74>>0]|0;
    $120 = ($119<<24>>24)==(46);
    $121 = ((($105) + (($103*1088)|0)|0) + 1082|0);
    $122 = $120&1;
    HEAP8[$121>>0] = $122;
    $123 = HEAP32[$48>>2]|0;
    $124 = (($123) + -2082844800)|0;
    $125 = ($124|0)<(0);
    $126 = $125 << 31 >> 31;
    $127 = ((($105) + (($103*1088)|0)|0) + 1074|0);
    HEAP16[$127>>1] = 0;
    $128 = ((($105) + (($103*1088)|0)|0) + 1076|0);
    HEAP32[$128>>2] = $124;
    $129 = $126&65535;
    $130 = ((($105) + (($103*1088)|0)|0) + 1072|0);
    HEAP16[$130>>1] = $129;
    do {
     if (!($49)) {
      do {
       if ($113) {
        if ($120) {
         if ($59) {
          label = 41;
          break;
         } else {
          break;
         }
        } else {
         if ($57) {
          label = 41;
          break;
         } else {
          break;
         }
        }
       } else {
        if ($120) {
         if ($53) {
          label = 41;
          break;
         } else {
          break;
         }
        } else {
         if ($51) {
          label = 41;
          break;
         } else {
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 41) {
       label = 0;
       if ($55) {
        break;
       }
       $131 = HEAP8[$74>>0]|0;
       $132 = ($131<<24>>24)==(46);
       if (!($132)) {
        break;
       }
      }
      $133 = HEAP32[$43>>2]|0;
      $134 = (($133) + -1)|0;
      HEAP32[$43>>2] = $134;
      continue L26;
     }
    } while(0);
    $brmerge$demorgan = $113 & $recurse;
    if (!($brmerge$demorgan)) {
     continue;
    }
    $135 = HEAP32[$this>>2]|0;
    $136 = (($135) + 148|0);
    $137 = HEAP32[$136>>2]|0;
    __THREW__ = 0;
    $138 = (invoke_iiiiiii($137|0,($this|0),($106|0),($outList|0),($recurse|0),($handlerData|0),($flags|0))|0);
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     label = 17;
     break;
    }
    if (!($138)) {
     $retValue$2$off0 = 0;
     break;
    }
   }
   if ((label|0) == 17) {
    $61 = ___cxa_find_matching_catch()|0;
    $62 = tempRet0;
    $lpad$phi$index = $61;$lpad$phi$index2 = $62;
    break;
   }
   (_closedir(($2|0))|0);
   $141 = HEAP8[$$pre$phiZ2D>>0]|0;
   $142 = $141 & 1;
   $143 = ($142<<24>>24)==(0);
   if ($143) {
    $$01 = $retValue$2$off0;
    STACKTOP = sp;return ($$01|0);
   }
   $144 = HEAP32[$60>>2]|0;
   __ZdlPv($144);
   $$01 = $retValue$2$off0;
   STACKTOP = sp;return ($$01|0);
  }
 } while(0);
 $65 = HEAP8[$$pre$phiZ2D>>0]|0;
 $66 = $65 & 1;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $68 = (($parentPath) + 8|0);
 $69 = HEAP32[$68>>2]|0;
 __ZdlPv($69);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZNK20LocalFileSystemPosix18GetApplicationPathEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen((648968|0))|0);
 $1 = ($0>>>0)>(4294967279);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = ($0>>>0)<(11);
 if ($2) {
  $3 = $0 << 1;
  $4 = $3&255;
  HEAP8[$agg$result>>0] = $4;
  $5 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $5;
 } else {
  $6 = (($0) + 16)|0;
  $7 = $6 & -16;
  $8 = (__Znwj($7)|0);
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $8;
  $10 = $7 | 1;
  HEAP32[$agg$result>>2] = $10;
  $11 = (($agg$result) + 4|0);
  HEAP32[$11>>2] = $0;
  $__p$0$i$i$i = $8;
 }
 _memcpy(($__p$0$i$i$i|0),(648968|0),($0|0))|0;
 $12 = (($__p$0$i$i$i) + ($0)|0);
 HEAP8[$12>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK20LocalFileSystemPosix20GetUserAppDataFolderEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 184|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($agg$result,$this);
 STACKTOP = sp;return;
}
function __ZNK20LocalFileSystemPosix21GetUserAppCacheFolderEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 180|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($agg$result,$this);
 $5 = HEAP8[$agg$result>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = $5&255;
  $11 = $10 >>> 1;
  $13 = $11;
 } else {
  $8 = (($agg$result) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $13 = $9;
 }
 $12 = ($13|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP8[$1>>0] = 12;
 $14 = (($1) + 1|0);
 ;HEAP8[$14+0>>0]=HEAP8[650480+0>>0]|0;HEAP8[$14+1>>0]=HEAP8[650480+1>>0]|0;HEAP8[$14+2>>0]=HEAP8[650480+2>>0]|0;HEAP8[$14+3>>0]=HEAP8[650480+3>>0]|0;HEAP8[$14+4>>0]=HEAP8[650480+4>>0]|0;HEAP8[$14+5>>0]=HEAP8[650480+5>>0]|0;
 $15 = (($1) + 7|0);
 HEAP8[$15>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1776,($0|0),($agg$result|0),($1|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if ($17) {
   $34 = ___cxa_find_matching_catch()|0;
   $35 = tempRet0;
   $$0 = $35;$$01 = $34;
   label = 16;
  } else {
   __THREW__ = 0;
   (invoke_iii(2233,($agg$result|0),($0|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $36 = ___cxa_find_matching_catch()|0;
    $37 = tempRet0;
    $38 = HEAP8[$0>>0]|0;
    $39 = $38 & 1;
    $40 = ($39<<24>>24)==(0);
    if ($40) {
     $$0 = $37;$$01 = $36;
     label = 16;
     break;
    }
    $41 = (($0) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    __ZdlPv($42);
    $$0 = $37;$$01 = $36;
    label = 16;
    break;
   }
   $20 = HEAP8[$0>>0]|0;
   $21 = $20 & 1;
   $22 = ($21<<24>>24)==(0);
   if (!($22)) {
    $23 = (($0) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZdlPv($24);
   }
   $25 = HEAP8[$1>>0]|0;
   $26 = $25 & 1;
   $27 = ($26<<24>>24)==(0);
   if (!($27)) {
    $28 = (($1) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    __ZdlPv($29);
   }
   __THREW__ = 0;
   (invoke_ii(3323,($agg$result|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    $$1 = $33;$$12 = $32;
    break;
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 16) {
  $43 = HEAP8[$1>>0]|0;
  $44 = $43 & 1;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   $$1 = $$0;$$12 = $$01;
  } else {
   $46 = (($1) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   __ZdlPv($47);
   $$1 = $$0;$$12 = $$01;
  }
 }
 $48 = HEAP8[$agg$result>>0]|0;
 $49 = $48 & 1;
 $50 = ($49<<24>>24)==(0);
 if ($50) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $51 = (($agg$result) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 __ZdlPv($52);
 ___resumeException($$12|0);
 // unreachable;
}
function __ZNK20LocalFileSystemPosix20GetApplicationFolderEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 160|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($agg$result,$this);
 __THREW__ = 0;
 invoke_vii(3252,($0|0),($agg$result|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if ($5) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   $$0 = $14;$$01 = $13;
  } else {
   __THREW__ = 0;
   (invoke_iii(2233,($agg$result|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $15 = ___cxa_find_matching_catch()|0;
    $16 = tempRet0;
    $17 = HEAP8[$0>>0]|0;
    $18 = $17 & 1;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     $$0 = $16;$$01 = $15;
     break;
    }
    $20 = (($0) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    __ZdlPv($21);
    $$0 = $16;$$01 = $15;
    break;
   }
   $8 = HEAP8[$0>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    STACKTOP = sp;return;
   }
   $11 = (($0) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   __ZdlPv($12);
   STACKTOP = sp;return;
  }
 } while(0);
 $22 = HEAP8[$agg$result>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $25 = (($agg$result) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 __ZdlPv($26);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZNK20LocalFileSystemPosix25GetApplicationManagedPathEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 172|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($0,$this);
 HEAP8[$1>>0] = 14;
 $5 = (($1) + 1|0);
 ;HEAP8[$5+0>>0]=HEAP8[650488+0>>0]|0;HEAP8[$5+1>>0]=HEAP8[650488+1>>0]|0;HEAP8[$5+2>>0]=HEAP8[650488+2>>0]|0;HEAP8[$5+3>>0]=HEAP8[650488+3>>0]|0;HEAP8[$5+4>>0]=HEAP8[650488+4>>0]|0;HEAP8[$5+5>>0]=HEAP8[650488+5>>0]|0;HEAP8[$5+6>>0]=HEAP8[650488+6>>0]|0;
 $6 = (($1) + 8|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1776,($agg$result|0),($0|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $20 = HEAP8[$1>>0]|0;
  $21 = $20 & 1;
  $22 = ($21<<24>>24)==(0);
  if (!($22)) {
   $23 = HEAP32[$6>>2]|0;
   __ZdlPv($23);
  }
  $24 = HEAP8[$0>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   ___resumeException($18|0);
   // unreachable;
  }
  $27 = (($0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __ZdlPv($28);
  ___resumeException($18|0);
  // unreachable;
 } else {
  $9 = HEAP8[$1>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $12 = HEAP32[$6>>2]|0;
   __ZdlPv($12);
  }
  $13 = HEAP8[$0>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   STACKTOP = sp;return;
  }
  $16 = (($0) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  __ZdlPv($17);
  STACKTOP = sp;return;
 }
}
function __ZNK20LocalFileSystemPosix26GetApplicationContentsPathEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 164|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($0,$this);
 HEAP8[$1>>0] = 8;
 $5 = (($1) + 1|0);
 HEAP8[$5>>0]=1635017028&255;HEAP8[$5+1>>0]=(1635017028>>8)&255;HEAP8[$5+2>>0]=(1635017028>>16)&255;HEAP8[$5+3>>0]=1635017028>>24;
 $6 = (($1) + 5|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1776,($agg$result|0),($0|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP8[$1>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if (!($23)) {
   $24 = (($1) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   __ZdlPv($25);
  }
  $26 = HEAP8[$0>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   ___resumeException($19|0);
   // unreachable;
  }
  $29 = (($0) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  __ZdlPv($30);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $9 = HEAP8[$1>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   $12 = (($1) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   __ZdlPv($13);
  }
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   STACKTOP = sp;return;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  STACKTOP = sp;return;
 }
}
function __ZNK20LocalFileSystemPosix19GetUserConfigFolderEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__p$0$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 16|0;
 $1 = sp + 4|0;
 $2 = (_getenv((650496|0))|0);
 $3 = (_strlen(($2|0))|0);
 $4 = ($3>>>0)>(4294967279);
 if ($4) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $5 = ($3>>>0)<(11);
 if ($5) {
  $6 = $3 << 1;
  $7 = $6&255;
  HEAP8[$agg$result>>0] = $7;
  $8 = (($agg$result) + 1|0);
  $$pre$phiZ2D = $agg$result;$18 = $7;$__p$0$i$i$i = $8;
 } else {
  $9 = (($3) + 16)|0;
  $10 = $9 & -16;
  $11 = (__Znwj($10)|0);
  $12 = (($agg$result) + 8|0);
  HEAP32[$12>>2] = $11;
  $13 = $10 | 1;
  HEAP32[$agg$result>>2] = $13;
  $14 = (($agg$result) + 4|0);
  HEAP32[$14>>2] = $3;
  $15 = $13&255;
  $$pre$phiZ2D = $agg$result;$18 = $15;$__p$0$i$i$i = $11;
 }
 _memcpy(($__p$0$i$i$i|0),($2|0),($3|0))|0;
 $16 = (($__p$0$i$i$i) + ($3)|0);
 HEAP8[$16>>0] = 0;
 $17 = $18 & 1;
 $19 = ($17<<24>>24)==(0);
 if ($19) {
  $22 = $18&255;
  $23 = $22 >>> 1;
  $25 = $23;
 } else {
  $20 = (($agg$result) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  $25 = $21;
 }
 $24 = ($25|0)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 $26 = (invoke_ii(2988,16)|0);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 L15: do {
  if ($28) {
   label = 27;
  } else {
   $29 = (($1) + 8|0);
   HEAP32[$29>>2] = $26;
   HEAP32[$1>>2] = 17;
   $30 = (($1) + 4|0);
   HEAP32[$30>>2] = 15;
   dest=$26+0|0; src=650504+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $31 = (($26) + 15|0);
   HEAP8[$31>>0] = 0;
   __THREW__ = 0;
   invoke_viii(1776,($0|0),($agg$result|0),($1|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   do {
    if ($33) {
     $66 = ___cxa_find_matching_catch()|0;
     $67 = tempRet0;
     $$0 = $67;$$01 = $66;
    } else {
     __THREW__ = 0;
     (invoke_iii(2233,($agg$result|0),($0|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      $68 = ___cxa_find_matching_catch()|0;
      $69 = tempRet0;
      $70 = HEAP8[$0>>0]|0;
      $71 = $70 & 1;
      $72 = ($71<<24>>24)==(0);
      if ($72) {
       $$0 = $69;$$01 = $68;
       break;
      }
      $73 = (($0) + 8|0);
      $74 = HEAP32[$73>>2]|0;
      __ZdlPv($74);
      $$0 = $69;$$01 = $68;
      break;
     }
     $36 = HEAP8[$0>>0]|0;
     $37 = $36 & 1;
     $38 = ($37<<24>>24)==(0);
     if (!($38)) {
      $39 = (($0) + 8|0);
      $40 = HEAP32[$39>>2]|0;
      __ZdlPv($40);
     }
     $41 = HEAP8[$1>>0]|0;
     $42 = $41 & 1;
     $43 = ($42<<24>>24)==(0);
     if (!($43)) {
      $44 = HEAP32[$29>>2]|0;
      __ZdlPv($44);
     }
     __THREW__ = 0;
     $45 = (invoke_ii(3257,($agg$result|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 27;
      break L15;
     }
     if ($45) {
      STACKTOP = sp;return;
     }
     $48 = HEAP8[$$pre$phiZ2D>>0]|0;
     $49 = $48 & 1;
     $50 = ($49<<24>>24)==(0);
     if ($50) {
      $53 = (($agg$result) + 1|0);
      $54 = $53;
     } else {
      $51 = (($agg$result) + 8|0);
      $52 = HEAP32[$51>>2]|0;
      $54 = $52;
     }
     __THREW__ = 0;
     HEAP32[$vararg_buffer>>2] = $54;
     invoke_vii(2587,(650520|0),($vararg_buffer|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 27;
      break L15;
     }
     $57 = HEAP8[$$pre$phiZ2D>>0]|0;
     $58 = $57 & 1;
     $59 = ($58<<24>>24)==(0);
     if ($59) {
      $62 = (($agg$result) + 1|0);
      $63 = $62;
     } else {
      $60 = (($agg$result) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $63 = $61;
     }
     (_mkdir(($63|0),448)|0);
     STACKTOP = sp;return;
    }
   } while(0);
   $75 = HEAP8[$1>>0]|0;
   $76 = $75 & 1;
   $77 = ($76<<24>>24)==(0);
   if ($77) {
    $$1 = $$0;$$12 = $$01;
   } else {
    $78 = HEAP32[$29>>2]|0;
    __ZdlPv($78);
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $64 = ___cxa_find_matching_catch()|0;
  $65 = tempRet0;
  $$1 = $65;$$12 = $64;
 }
 $79 = HEAP8[$$pre$phiZ2D>>0]|0;
 $80 = $79 & 1;
 $81 = ($80<<24>>24)==(0);
 if ($81) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $82 = (($agg$result) + 8|0);
 $83 = HEAP32[$82>>2]|0;
 __ZdlPv($83);
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN20LocalFileSystemPosixD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN20LocalFileSystemPosixD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __Z9SetupArgviPPKc($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = sp + 12|0;
 HEAP32[650776>>2] = $a;
 HEAP32[650784>>2] = $b;
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=650792+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 (invoke_ii(3324,($0|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $33 = HEAP8[$0>>0]|0;
  $34 = $33 & 1;
  $35 = ($34<<24>>24)==(0);
  if ($35) {
   $$0 = $32;$$01 = $31;
   ___resumeException($$01|0);
   // unreachable;
  }
  $36 = (($0) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  __ZdlPv($37);
  $$0 = $32;$$01 = $31;
  ___resumeException($$01|0);
  // unreachable;
 }
 $7 = HEAP8[$0>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
 }
 HEAP8[$1>>0] = 18;
 $12 = (($1) + 1|0);
 dest=$12+0|0; src=650808+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $13 = (($1) + 10|0);
 HEAP8[$13>>0] = 0;
 __THREW__ = 0;
 (invoke_ii(3324,($1|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  $40 = HEAP8[$1>>0]|0;
  $41 = $40 & 1;
  $42 = ($41<<24>>24)==(0);
  if ($42) {
   $$0 = $39;$$01 = $38;
   ___resumeException($$01|0);
   // unreachable;
  }
  $43 = (($1) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  __ZdlPv($44);
  $$0 = $39;$$01 = $38;
  ___resumeException($$01|0);
  // unreachable;
 }
 $16 = HEAP8[$1>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 if (!($18)) {
  $19 = (($1) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  __ZdlPv($20);
 }
 $21 = (__Znwj(16)|0);
 $22 = (($2) + 8|0);
 HEAP32[$22>>2] = $21;
 HEAP32[$2>>2] = 17;
 $23 = (($2) + 4|0);
 HEAP32[$23>>2] = 12;
 dest=$21+0|0; src=650824+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $24 = (($21) + 12|0);
 HEAP8[$24>>0] = 0;
 __THREW__ = 0;
 (invoke_ii(3324,($2|0))|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  $47 = HEAP8[$2>>0]|0;
  $48 = $47 & 1;
  $49 = ($48<<24>>24)==(0);
  if ($49) {
   $$0 = $46;$$01 = $45;
   ___resumeException($$01|0);
   // unreachable;
  }
  $50 = HEAP32[$22>>2]|0;
  __ZdlPv($50);
  $$0 = $46;$$01 = $45;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $27 = HEAP8[$2>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   STACKTOP = sp;return;
  }
  $30 = HEAP32[$22>>2]|0;
  __ZdlPv($30);
  STACKTOP = sp;return;
 }
}
function __Z7HasARGVRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($name) {
 $name = $name|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $i$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP32[650776>>2]|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  $$02 = 0;
  STACKTOP = sp;return ($$02|0);
 }
 $4 = (($0) + 1|0);
 $5 = (($1) + 1|0);
 $6 = (($0) + 8|0);
 $7 = (($1) + 8|0);
 $8 = (($0) + 4|0);
 $i$06 = 0;
 while(1) {
  $12 = HEAP32[650784>>2]|0;
  $13 = (($12) + ($i$06<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (_strlen(($14|0))|0);
  $16 = ($15>>>0)>(4294967279);
  if ($16) {
   label = 5;
   break;
  }
  $17 = ($15>>>0)<(11);
  if ($17) {
   $18 = $15 << 1;
   $19 = $18&255;
   HEAP8[$0>>0] = $19;
   $__p$0$i$i$i = $4;
  } else {
   $20 = (($15) + 16)|0;
   $21 = $20 & -16;
   $22 = (__Znwj($21)|0);
   HEAP32[$6>>2] = $22;
   $23 = $21 | 1;
   HEAP32[$0>>2] = $23;
   HEAP32[$8>>2] = $15;
   $__p$0$i$i$i = $22;
  }
  _memcpy(($__p$0$i$i$i|0),($14|0),($15|0))|0;
  $24 = (($__p$0$i$i$i) + ($15)|0);
  HEAP8[$24>>0] = 0;
  __THREW__ = 0;
  invoke_viii(1631,($1|0),(650840|0),($name|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   label = 16;
   break;
  }
  $27 = HEAP8[$0>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  $30 = HEAP32[$6>>2]|0;
  $$ = $29 ? $4 : $30;
  $31 = HEAP8[$1>>0]|0;
  $32 = $31 & 1;
  $33 = ($32<<24>>24)==(0);
  $34 = HEAP32[$7>>2]|0;
  $35 = $33 ? $5 : $34;
  __THREW__ = 0;
  $36 = (invoke_iii(2448,($$|0),($35|0))|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   label = 17;
   break;
  }
  $39 = HEAP8[$1>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if (!($41)) {
   $42 = HEAP32[$7>>2]|0;
   __ZdlPv($42);
  }
  $43 = ($36|0)==(0);
  $44 = HEAP8[$0>>0]|0;
  $45 = $44 & 1;
  $46 = ($45<<24>>24)==(0);
  if (!($46)) {
   $47 = HEAP32[$6>>2]|0;
   __ZdlPv($47);
  }
  $11 = (($i$06) + 1)|0;
  if ($43) {
   $$02 = 1;
   label = 21;
   break;
  }
  $9 = HEAP32[650776>>2]|0;
  $10 = ($11|0)<($9|0);
  if ($10) {
   $i$06 = $11;
  } else {
   $$02 = 0;
   label = 21;
   break;
  }
 }
 if ((label|0) == 5) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 16) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $$0 = $49;$$01 = $48;
 }
 else if ((label|0) == 17) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  $52 = HEAP8[$1>>0]|0;
  $53 = $52 & 1;
  $54 = ($53<<24>>24)==(0);
  if ($54) {
   $$0 = $51;$$01 = $50;
  } else {
   $55 = HEAP32[$7>>2]|0;
   __ZdlPv($55);
   $$0 = $51;$$01 = $50;
  }
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return ($$02|0);
 }
 $56 = HEAP8[$0>>0]|0;
 $57 = $56 & 1;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $59 = HEAP32[$6>>2]|0;
 __ZdlPv($59);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z7GetArgcv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[650776>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z7GetArgvv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[650784>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __Z16GetValuesForARGVRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$name) {
 $agg$result = $agg$result|0;
 $name = $name|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre28 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0;
 var $__p$0$i$i$i12 = 0, $found$0$off026 = 0, $found$1$off0 = 0, $i$027 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi25$index = 0, $lpad$phi25$index7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = sp + 12|0;
 HEAP32[$agg$result>>2] = 0;
 $3 = (($agg$result) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($agg$result) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[650776>>2]|0;
 __THREW__ = 0;
 invoke_vii(3255,($agg$result|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 7;
  } else {
   $8 = HEAP32[650776>>2]|0;
   $9 = ($8|0)>(0);
   if (!($9)) {
    STACKTOP = sp;return;
   }
   $10 = (($0) + 1|0);
   $11 = (($0) + 8|0);
   $12 = (($0) + 4|0);
   $13 = (($1) + 1|0);
   $14 = (($2) + 1|0);
   $15 = (($1) + 8|0);
   $16 = (($2) + 8|0);
   $17 = (($1) + 4|0);
   $found$0$off026 = 0;$i$027 = 0;
   L6: while(1) {
    $18 = HEAP32[650784>>2]|0;
    $19 = (($18) + ($i$027<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    if ($found$0$off026) {
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)==(45);
     if ($22) {
      label = 56;
      break;
     }
     $27 = (_strlen(($20|0))|0);
     $28 = ($27>>>0)>(4294967279);
     if ($28) {
      label = 10;
      break;
     }
     $31 = ($27>>>0)<(11);
     if ($31) {
      $32 = $27 << 1;
      $33 = $32&255;
      HEAP8[$0>>0] = $33;
      $47 = $33;$__p$0$i$i$i = $10;
     } else {
      $34 = (($27) + 16)|0;
      $35 = $34 & -16;
      __THREW__ = 0;
      $36 = (invoke_ii(2988,($35|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 6;
       break;
      }
      HEAP32[$11>>2] = $36;
      $39 = $35 | 1;
      HEAP32[$0>>2] = $39;
      HEAP32[$12>>2] = $27;
      $40 = $39&255;
      $47 = $40;$__p$0$i$i$i = $36;
     }
     _memcpy(($__p$0$i$i$i|0),($20|0),($27|0))|0;
     $41 = (($__p$0$i$i$i) + ($27)|0);
     HEAP8[$41>>0] = 0;
     $42 = HEAP32[$3>>2]|0;
     $43 = HEAP32[$4>>2]|0;
     $44 = ($42|0)==($43|0);
     if ($44) {
      __THREW__ = 0;
      invoke_vii(2523,($agg$result|0),($0|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 33;
       break;
      }
      $$pre28 = HEAP8[$0>>0]|0;
      $72 = $$pre28;
     } else {
      $45 = ($42|0)==(0|0);
      do {
       if (!($45)) {
        $46 = $47 & 1;
        $48 = ($46<<24>>24)==(0);
        if ($48) {
         ;HEAP32[$42+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$0+8>>2]|0;
         break;
        }
        $49 = HEAP32[$11>>2]|0;
        $50 = HEAP32[$12>>2]|0;
        $51 = ($50>>>0)>(4294967279);
        if ($51) {
         label = 21;
         break L6;
        }
        $54 = ($50>>>0)<(11);
        if ($54) {
         $55 = $50 << 1;
         $56 = $55&255;
         HEAP8[$42>>0] = $56;
         $57 = (($42) + 1|0);
         $__p$0$i$i$i$i$i = $57;
        } else {
         $58 = (($50) + 16)|0;
         $59 = $58 & -16;
         __THREW__ = 0;
         $60 = (invoke_ii(2988,($59|0))|0);
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          label = 33;
          break L6;
         }
         $63 = (($42) + 8|0);
         HEAP32[$63>>2] = $60;
         $64 = $59 | 1;
         HEAP32[$42>>2] = $64;
         $65 = (($42) + 4|0);
         HEAP32[$65>>2] = $50;
         $__p$0$i$i$i$i$i = $60;
        }
        _memcpy(($__p$0$i$i$i$i$i|0),($49|0),($50|0))|0;
        $66 = (($__p$0$i$i$i$i$i) + ($50)|0);
        HEAP8[$66>>0] = 0;
       }
      } while(0);
      $67 = HEAP32[$3>>2]|0;
      $68 = (($67) + 12|0);
      HEAP32[$3>>2] = $68;
      $72 = $47;
     }
     $71 = $72 & 1;
     $73 = ($71<<24>>24)==(0);
     if ($73) {
      $found$1$off0 = 1;
     } else {
      $74 = HEAP32[$11>>2]|0;
      __ZdlPv($74);
      $found$1$off0 = 1;
     }
    } else {
     $83 = (_strlen(($20|0))|0);
     $84 = ($83>>>0)>(4294967279);
     if ($84) {
      label = 38;
      break;
     }
     $87 = ($83>>>0)<(11);
     if ($87) {
      $88 = $83 << 1;
      $89 = $88&255;
      HEAP8[$1>>0] = $89;
      $__p$0$i$i$i12 = $13;
     } else {
      $90 = (($83) + 16)|0;
      $91 = $90 & -16;
      __THREW__ = 0;
      $92 = (invoke_ii(2988,($91|0))|0);
      $93 = __THREW__; __THREW__ = 0;
      $94 = $93&1;
      if ($94) {
       label = 6;
       break;
      }
      HEAP32[$15>>2] = $92;
      $95 = $91 | 1;
      HEAP32[$1>>2] = $95;
      HEAP32[$17>>2] = $83;
      $__p$0$i$i$i12 = $92;
     }
     _memcpy(($__p$0$i$i$i12|0),($20|0),($83|0))|0;
     $96 = (($__p$0$i$i$i12) + ($83)|0);
     HEAP8[$96>>0] = 0;
     __THREW__ = 0;
     invoke_viii(1631,($2|0),(650840|0),($name|0));
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      label = 50;
      break;
     }
     $99 = HEAP8[$1>>0]|0;
     $100 = $99 & 1;
     $101 = ($100<<24>>24)==(0);
     $102 = HEAP32[$15>>2]|0;
     $$ = $101 ? $13 : $102;
     $103 = HEAP8[$2>>0]|0;
     $104 = $103 & 1;
     $105 = ($104<<24>>24)==(0);
     $106 = HEAP32[$16>>2]|0;
     $107 = $105 ? $14 : $106;
     __THREW__ = 0;
     $108 = (invoke_iii(2448,($$|0),($107|0))|0);
     $109 = __THREW__; __THREW__ = 0;
     $110 = $109&1;
     if ($110) {
      label = 51;
      break;
     }
     $111 = ($108|0)==(0);
     $112 = HEAP8[$2>>0]|0;
     $113 = $112 & 1;
     $114 = ($113<<24>>24)==(0);
     if (!($114)) {
      $115 = HEAP32[$16>>2]|0;
      __ZdlPv($115);
     }
     $116 = HEAP8[$1>>0]|0;
     $117 = $116 & 1;
     $118 = ($117<<24>>24)==(0);
     if ($118) {
      $found$1$off0 = $111;
     } else {
      $119 = HEAP32[$15>>2]|0;
      __ZdlPv($119);
      $found$1$off0 = $111;
     }
    }
    $132 = (($i$027) + 1)|0;
    $133 = HEAP32[650776>>2]|0;
    $134 = ($132|0)<($133|0);
    if ($134) {
     $found$0$off026 = $found$1$off0;$i$027 = $132;
    } else {
     label = 56;
     break;
    }
   }
   do {
    if ((label|0) == 6) {
     $23 = ___cxa_find_matching_catch()|0;
     $24 = tempRet0;
     $lpad$phi$index = $23;$lpad$phi$index2 = $24;
     label = 8;
     break L1;
    }
    else if ((label|0) == 10) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      label = 7;
      break L1;
     }
     // unreachable;
    }
    else if ((label|0) == 21) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $77 = ___cxa_find_matching_catch()|0;
      $78 = tempRet0;
      $80 = $47;$lpad$phi25$index = $77;$lpad$phi25$index7 = $78;
      label = 35;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 33) {
     $75 = ___cxa_find_matching_catch()|0;
     $76 = tempRet0;
     $$pre = HEAP8[$0>>0]|0;
     $80 = $$pre;$lpad$phi25$index = $75;$lpad$phi25$index7 = $76;
     label = 35;
    }
    else if ((label|0) == 38) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      label = 7;
      break L1;
     }
     // unreachable;
    }
    else if ((label|0) == 50) {
     $120 = ___cxa_find_matching_catch()|0;
     $121 = tempRet0;
     $$0 = $121;$$01 = $120;
     label = 53;
    }
    else if ((label|0) == 51) {
     $122 = ___cxa_find_matching_catch()|0;
     $123 = tempRet0;
     $124 = HEAP8[$2>>0]|0;
     $125 = $124 & 1;
     $126 = ($125<<24>>24)==(0);
     if ($126) {
      $$0 = $123;$$01 = $122;
      label = 53;
     } else {
      $127 = HEAP32[$16>>2]|0;
      __ZdlPv($127);
      $$0 = $123;$$01 = $122;
      label = 53;
     }
    }
    else if ((label|0) == 56) {
     STACKTOP = sp;return;
    }
   } while(0);
   if ((label|0) == 35) {
    $79 = $80 & 1;
    $81 = ($79<<24>>24)==(0);
    if ($81) {
     $$1 = $lpad$phi25$index7;$$12 = $lpad$phi25$index;
     break;
    }
    $82 = HEAP32[$11>>2]|0;
    __ZdlPv($82);
    $$1 = $lpad$phi25$index7;$$12 = $lpad$phi25$index;
    break;
   }
   else if ((label|0) == 53) {
    $128 = HEAP8[$1>>0]|0;
    $129 = $128 & 1;
    $130 = ($129<<24>>24)==(0);
    if ($130) {
     $$1 = $$0;$$12 = $$01;
     break;
    }
    $131 = HEAP32[$15>>2]|0;
    __ZdlPv($131);
    $$1 = $$0;$$12 = $$01;
    break;
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index2 = $26;
  label = 8;
 }
 if ((label|0) == 8) {
  $$1 = $lpad$phi$index2;$$12 = $lpad$phi$index;
 }
 $135 = HEAP32[$agg$result>>2]|0;
 $136 = ($135|0)==(0|0);
 if ($136) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $137 = HEAP32[$3>>2]|0;
 $138 = ($137|0)==($135|0);
 if ($138) {
  $148 = $135;
 } else {
  $140 = $137;
  while(1) {
   $139 = (($140) + -12|0);
   HEAP32[$3>>2] = $139;
   $141 = HEAP8[$139>>0]|0;
   $142 = $141 & 1;
   $143 = ($142<<24>>24)==(0);
   if ($143) {
    $145 = $139;
   } else {
    $146 = (($140) + -4|0);
    $147 = HEAP32[$146>>2]|0;
    __ZdlPv($147);
    $$pre$i$i$i$i$i = HEAP32[$3>>2]|0;
    $145 = $$pre$i$i$i$i$i;
   }
   $144 = ($145|0)==($135|0);
   if ($144) {
    break;
   } else {
    $140 = $145;
   }
  }
  $$pre$i$i$i = HEAP32[$agg$result>>2]|0;
  $148 = $$pre$i$i$i;
 }
 __ZdlPv($148);
 ___resumeException($$12|0);
 // unreachable;
}
function __Z20GetFirstValueForARGVRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$name) {
 $agg$result = $agg$result|0;
 $name = $name|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i3 = 0, $$pre$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $values = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $values = sp;
 __Z16GetValuesForARGVRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($values,$name);
 $0 = HEAP32[$values>>2]|0;
 $1 = (($values) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 L1: do {
  if ($3) {
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
   label = 20;
  } else {
   $20 = HEAP8[$0>>0]|0;
   $21 = $20 & 1;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
    break;
   }
   $23 = (($0) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($0) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26>>>0)>(4294967279);
   do {
    if ($27) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      // unreachable;
     }
    } else {
     $30 = ($26>>>0)<(11);
     if ($30) {
      $31 = $26 << 1;
      $32 = $31&255;
      HEAP8[$agg$result>>0] = $32;
      $33 = (($agg$result) + 1|0);
      $__p$0$i$i$i = $33;
     } else {
      $34 = (($26) + 16)|0;
      $35 = $34 & -16;
      __THREW__ = 0;
      $36 = (invoke_ii(2988,($35|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = (($agg$result) + 8|0);
      HEAP32[$39>>2] = $36;
      $40 = $35 | 1;
      HEAP32[$agg$result>>2] = $40;
      $41 = (($agg$result) + 4|0);
      HEAP32[$41>>2] = $26;
      $__p$0$i$i$i = $36;
     }
     _memcpy(($__p$0$i$i$i|0),($24|0),($26|0))|0;
     $42 = (($__p$0$i$i$i) + ($26)|0);
     HEAP8[$42>>0] = 0;
     label = 20;
     break L1;
    }
   } while(0);
   $4 = ___cxa_find_matching_catch()|0;
   $5 = tempRet0;
   $6 = HEAP32[$values>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    ___resumeException($4|0);
    // unreachable;
   }
   $8 = HEAP32[$1>>2]|0;
   $9 = ($8|0)==($6|0);
   if ($9) {
    $19 = $6;
   } else {
    $11 = $8;
    while(1) {
     $10 = (($11) + -12|0);
     HEAP32[$1>>2] = $10;
     $12 = HEAP8[$10>>0]|0;
     $13 = $12 & 1;
     $14 = ($13<<24>>24)==(0);
     if ($14) {
      $16 = $10;
     } else {
      $17 = (($11) + -4|0);
      $18 = HEAP32[$17>>2]|0;
      __ZdlPv($18);
      $$pre$i$i$i$i$i3 = HEAP32[$1>>2]|0;
      $16 = $$pre$i$i$i$i$i3;
     }
     $15 = ($16|0)==($6|0);
     if ($15) {
      break;
     } else {
      $11 = $16;
     }
    }
    $$pre$i$i$i4 = HEAP32[$values>>2]|0;
    $19 = $$pre$i$i$i4;
   }
   __ZdlPv($19);
   ___resumeException($4|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 20) {
  $43 = ($0|0)==(0|0);
  if ($43) {
   STACKTOP = sp;return;
  }
 }
 if ($3) {
  $53 = $0;
 } else {
  $45 = $2;
  while(1) {
   $44 = (($45) + -12|0);
   HEAP32[$1>>2] = $44;
   $46 = HEAP8[$44>>0]|0;
   $47 = $46 & 1;
   $48 = ($47<<24>>24)==(0);
   if ($48) {
    $50 = $44;
   } else {
    $51 = (($45) + -4|0);
    $52 = HEAP32[$51>>2]|0;
    __ZdlPv($52);
    $$pre$i$i$i$i$i = HEAP32[$1>>2]|0;
    $50 = $$pre$i$i$i$i$i;
   }
   $49 = ($50|0)==($0|0);
   if ($49) {
    break;
   } else {
    $45 = $50;
   }
  }
  $$pre$i$i$i = HEAP32[$values>>2]|0;
  $53 = $$pre$i$i$i;
 }
 __ZdlPv($53);
 STACKTOP = sp;return;
}
function __Z7CRCInitv() {
 var $$01$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond$i6 = 0, $i$010 = 0, $i$03$i1 = 0, $value$02$i2 = 0, $value$1$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_malloc(1024)|0);
 $i$010 = 0;
 while(1) {
  $1 = $i$010 << 7;
  $2 = $1 & 128;
  $3 = $i$010 << 5;
  $4 = $3 & 64;
  $5 = $4 | $2;
  $6 = $i$010 << 3;
  $7 = $6 & 32;
  $8 = $7 | $5;
  $9 = $i$010 << 1;
  $10 = $9 & 16;
  $11 = $10 | $8;
  $12 = $i$010 >>> 1;
  $13 = $12 & 8;
  $14 = $13 | $11;
  $15 = $i$010 >>> 3;
  $16 = $15 & 4;
  $17 = $16 | $14;
  $18 = $i$010 >>> 5;
  $19 = $18 & 2;
  $20 = $19 | $17;
  $21 = $i$010 >>> 7;
  $22 = $21 & 1;
  $23 = $22 | $20;
  $24 = $i$010 << 31;
  $25 = (($0) + ($i$010<<2)|0);
  $26 = $23 << 25;
  $27 = $24 >> 31;
  $28 = $27 & 79764919;
  $29 = $28 ^ $26;
  $30 = $29 << 1;
  $31 = $26 >> 31;
  $32 = $31 & 79764919;
  $33 = $32 ^ $30;
  $34 = $33 << 1;
  $35 = $30 >> 31;
  $36 = $35 & 79764919;
  $37 = $36 ^ $34;
  $38 = $37 << 1;
  $39 = $34 >> 31;
  $40 = $39 & 79764919;
  $41 = $40 ^ $38;
  $42 = $41 << 1;
  $43 = $38 >> 31;
  $44 = $43 & 79764919;
  $45 = $44 ^ $42;
  $46 = $45 << 1;
  $47 = $42 >> 31;
  $48 = $47 & 79764919;
  $49 = $48 ^ $46;
  $50 = $49 << 1;
  $51 = $46 >> 31;
  $52 = $51 & 79764919;
  $53 = $52 ^ $50;
  $54 = $53 << 1;
  $55 = $50 >> 31;
  $56 = $55 & 79764919;
  $57 = $56 ^ $54;
  HEAP32[$25>>2] = $57;
  $$01$i3 = $57;$i$03$i1 = 1;$value$02$i2 = 0;
  while(1) {
   $58 = $$01$i3 & 1;
   $59 = ($58|0)==(0);
   if ($59) {
    $value$1$i5 = $value$02$i2;
   } else {
    $60 = (32 - ($i$03$i1))|0;
    $61 = 1 << $60;
    $62 = $61 | $value$02$i2;
    $value$1$i5 = $62;
   }
   $63 = $$01$i3 >>> 1;
   $64 = (($i$03$i1) + 1)|0;
   $exitcond$i6 = ($i$03$i1|0)==(32);
   if ($exitcond$i6) {
    break;
   } else {
    $$01$i3 = $63;$i$03$i1 = $64;$value$02$i2 = $value$1$i5;
   }
  }
  HEAP32[$25>>2] = $value$1$i5;
  $65 = (($i$010) + 1)|0;
  $exitcond = ($65|0)==(256);
  if ($exitcond) {
   break;
  } else {
   $i$010 = $65;
  }
 }
 STACKTOP = sp;return ($0|0);
}
function __Z8CRCBeginv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __Z7CRCDonej($crc) {
 $crc = $crc|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $crc ^ -1;
 STACKTOP = sp;return ($0|0);
}
function __Z7CRCFeedjPKhj($crc,$buffer,$len) {
 $crc = $crc|0;
 $buffer = $buffer|0;
 $len = $len|0;
 var $$014 = 0, $$02$lcssa = 0, $$023 = 0, $$05 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[650848>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (__Z7CRCInitv()|0);
  HEAP32[650848>>2] = $2;
  $12 = $2;
 } else {
  $12 = $0;
 }
 $3 = ($len|0)==(0);
 if ($3) {
  $$02$lcssa = $crc;
  STACKTOP = sp;return ($$02$lcssa|0);
 } else {
  $$014 = $buffer;$$023 = $crc;$$05 = $len;
 }
 while(1) {
  $4 = (($$05) + -1)|0;
  $5 = $$023 >>> 8;
  $6 = $$023 & 255;
  $7 = (($$014) + 1|0);
  $8 = HEAP8[$$014>>0]|0;
  $9 = $8&255;
  $10 = $9 ^ $6;
  $11 = (($12) + ($10<<2)|0);
  $13 = HEAP32[$11>>2]|0;
  $14 = $13 ^ $5;
  $15 = ($4|0)==(0);
  if ($15) {
   $$02$lcssa = $14;
   break;
  } else {
   $$014 = $7;$$023 = $14;$$05 = $4;
  }
 }
 STACKTOP = sp;return ($$02$lcssa|0);
}
function __ZN8DateTimeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $this;
 $1 = $0;
 HEAP16[$1>>1]=0&65535;HEAP16[$1+2>>1]=0>>>16;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP16[$3>>1]=0&65535;HEAP16[$3+2>>1]=0>>>16;
 STACKTOP = sp;return;
}
function _printf_console($log,$varargs) {
 $log = $log|0;
 $varargs = $varargs|0;
 var $$ph$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $list$i = 0, $vacopy_currentptr = 0, $vl = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $list$i = sp + 16|0;
 $vl = sp;
 HEAP32[$vl>>2] = $varargs;
 $vacopy_currentptr = HEAP32[$vl>>2]|0;
 HEAP32[$list$i>>2] = $vacopy_currentptr;
 $0 = (0|0)==(0|0);
 if (!($0)) {
  $1 = (abort /* segfault, call an absolute addr */ (5,($log|0),($list$i|0))|0);
  if (!($1)) {
   STACKTOP = sp;return;
  }
 }
 $2 = HEAP32[650856>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[_stdout>>2]|0;
  HEAP32[650856>>2] = $4;
  $5 = ($4|0)==(0|0);
  if ($5) {
   STACKTOP = sp;return;
  } else {
   $$ph$i = $4;
  }
 } else {
  $$ph$i = $2;
 }
 (_vfprintf(($$ph$i|0),($log|0),($list$i|0))|0);
 $6 = HEAP32[650856>>2]|0;
 (_fflush(($6|0))|0);
 STACKTOP = sp;return;
}
function __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE($condition,$errorNum,$file,$line,$mode,$objectInstanceID,$identifier,$doubleClickCallback) {
 $condition = $condition|0;
 $errorNum = $errorNum|0;
 $file = $file|0;
 $line = $line|0;
 $mode = $mode|0;
 $objectInstanceID = $objectInstanceID|0;
 $identifier = $identifier|0;
 $doubleClickCallback = $doubleClickCallback|0;
 var $$0 = 0, $$01 = 0, $$04 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__p$0$i$i$i = 0, $conditionStr = 0, $preprocessedFile = 0, $stackTrace = 0, $strippedStackTrace = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $stackTrace = sp;
 $strippedStackTrace = sp + 12|0;
 $preprocessedFile = sp + 24|0;
 $conditionStr = sp + 36|0;
 HEAP32[$0>>2] = $line;
 ;HEAP32[$stackTrace+0>>2]=0|0;HEAP32[$stackTrace+4>>2]=0|0;HEAP32[$stackTrace+8>>2]=0|0;
 ;HEAP32[$strippedStackTrace+0>>2]=0|0;HEAP32[$strippedStackTrace+4>>2]=0|0;HEAP32[$strippedStackTrace+8>>2]=0|0;
 ;HEAP32[$preprocessedFile+0>>2]=0|0;HEAP32[$preprocessedFile+4>>2]=0|0;HEAP32[$preprocessedFile+8>>2]=0|0;
 $1 = (0|0)==(0|0);
 do {
  if ($1) {
   $$04 = $file;
   label = 19;
  } else {
   __THREW__ = 0;
   (invoke_iii(2392,($preprocessedFile|0),($file|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if ($3) {
    label = 16;
   } else {
    $4 = (_strlen(($condition|0))|0);
    $5 = ($4>>>0)>(4294967279);
    if ($5) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      label = 16;
      break;
     }
     // unreachable;
    }
    $8 = ($4>>>0)<(11);
    if ($8) {
     $9 = $4 << 1;
     $10 = $9&255;
     HEAP8[$conditionStr>>0] = $10;
     $11 = (($conditionStr) + 1|0);
     $__p$0$i$i$i = $11;
    } else {
     $12 = (($4) + 16)|0;
     $13 = $12 & -16;
     __THREW__ = 0;
     $14 = (invoke_ii(2988,($13|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 16;
      break;
     }
     $17 = (($conditionStr) + 8|0);
     HEAP32[$17>>2] = $14;
     $18 = $13 | 1;
     HEAP32[$conditionStr>>2] = $18;
     $19 = (($conditionStr) + 4|0);
     HEAP32[$19>>2] = $4;
     $__p$0$i$i$i = $14;
    }
    _memcpy(($__p$0$i$i$i|0),($condition|0),($4|0))|0;
    $20 = (($__p$0$i$i$i) + ($4)|0);
    HEAP8[$20>>0] = 0;
    __THREW__ = 0;
    invoke_viiiiiiii(0|0,($conditionStr|0),($strippedStackTrace|0),($stackTrace|0),($errorNum|0),($preprocessedFile|0),($0|0),($mode|0),($objectInstanceID|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $36 = ___cxa_find_matching_catch()|0;
     $37 = tempRet0;
     $38 = HEAP8[$conditionStr>>0]|0;
     $39 = $38 & 1;
     $40 = ($39<<24>>24)==(0);
     if ($40) {
      $$0 = $37;$$01 = $36;
      break;
     }
     $41 = (($conditionStr) + 8|0);
     $42 = HEAP32[$41>>2]|0;
     __ZdlPv($42);
     $$0 = $37;$$01 = $36;
     break;
    }
    $23 = HEAP8[$preprocessedFile>>0]|0;
    $24 = $23 & 1;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     $28 = (($preprocessedFile) + 1|0);
     $90 = $28;
    } else {
     $26 = (($preprocessedFile) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     $90 = $27;
    }
    $29 = HEAP8[$conditionStr>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if ($31) {
     $$04 = $90;
     label = 19;
    } else {
     $32 = (($conditionStr) + 8|0);
     $33 = HEAP32[$32>>2]|0;
     __ZdlPv($33);
     $$04 = $90;
     label = 19;
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $43 = HEAP8[$strippedStackTrace>>0]|0;
  $44 = $43 & 1;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   $48 = (($strippedStackTrace) + 1|0);
   $56 = $48;
  } else {
   $46 = (($strippedStackTrace) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   $56 = $47;
  }
  $49 = HEAP8[$stackTrace>>0]|0;
  $50 = $49 & 1;
  $51 = ($50<<24>>24)==(0);
  if ($51) {
   $54 = (($stackTrace) + 1|0);
   $57 = $54;
  } else {
   $52 = (($stackTrace) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $57 = $53;
  }
  $55 = HEAP32[$0>>2]|0;
  __THREW__ = 0;
  invoke_viiiiiiiiii(9,($condition|0),($56|0),($57|0),($errorNum|0),($$04|0),($55|0),($mode|0),($objectInstanceID|0),($identifier|0),($doubleClickCallback|0));
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if ($59) {
   label = 16;
  } else {
   $60 = HEAP8[$preprocessedFile>>0]|0;
   $61 = $60 & 1;
   $62 = ($61<<24>>24)==(0);
   if (!($62)) {
    $63 = (($preprocessedFile) + 8|0);
    $64 = HEAP32[$63>>2]|0;
    __ZdlPv($64);
   }
   $65 = HEAP8[$strippedStackTrace>>0]|0;
   $66 = $65 & 1;
   $67 = ($66<<24>>24)==(0);
   if (!($67)) {
    $68 = (($strippedStackTrace) + 8|0);
    $69 = HEAP32[$68>>2]|0;
    __ZdlPv($69);
   }
   $70 = HEAP8[$stackTrace>>0]|0;
   $71 = $70 & 1;
   $72 = ($71<<24>>24)==(0);
   if ($72) {
    STACKTOP = sp;return;
   }
   $73 = (($stackTrace) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   __ZdlPv($74);
   STACKTOP = sp;return;
  }
 }
 if ((label|0) == 16) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  $$0 = $35;$$01 = $34;
 }
 $75 = HEAP8[$preprocessedFile>>0]|0;
 $76 = $75 & 1;
 $77 = ($76<<24>>24)==(0);
 if (!($77)) {
  $78 = (($preprocessedFile) + 8|0);
  $79 = HEAP32[$78>>2]|0;
  __ZdlPv($79);
 }
 $80 = HEAP8[$strippedStackTrace>>0]|0;
 $81 = $80 & 1;
 $82 = ($81<<24>>24)==(0);
 if (!($82)) {
  $83 = (($strippedStackTrace) + 8|0);
  $84 = HEAP32[$83>>2]|0;
  __ZdlPv($84);
 }
 $85 = HEAP8[$stackTrace>>0]|0;
 $86 = $85 & 1;
 $87 = ($86<<24>>24)==(0);
 if ($87) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $88 = (($stackTrace) + 8|0);
 $89 = HEAP32[$88>>2]|0;
 __ZdlPv($89);
 ___resumeException($$01|0);
 // unreachable;
}
function __Z15CleanLogHandler7LogTypePKcz($logType,$log,$varargs) {
 $logType = $logType|0;
 $log = $log|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vl = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vl = sp;
 $0 = (0|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (0 + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $5 = $2;
 while(1) {
  HEAP32[$vl>>2] = $varargs;
  $4 = (($5) + 8|0);
  $6 = HEAP32[$4>>2]|0;
  (FUNCTION_TABLE_iiii[$6 & 2047]($logType,$log,$vl)|0);
  $7 = (($5) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   break;
  } else {
   $5 = $8;
  }
 }
 STACKTOP = sp;return;
}
function __Z40DebugStringToFilePostprocessedStacktracePKcS0_S0_iS0_iiiiPFvRK11CppLogEntryE($condition,$strippedStacktrace,$stacktrace,$errorNum,$file,$line,$mode,$objectInstanceID,$identifier,$doubleClickCallback) {
 $condition = $condition|0;
 $strippedStacktrace = $strippedStacktrace|0;
 $stacktrace = $stacktrace|0;
 $errorNum = $errorNum|0;
 $file = $file|0;
 $line = $line|0;
 $mode = $mode|0;
 $objectInstanceID = $objectInstanceID|0;
 $identifier = $identifier|0;
 $doubleClickCallback = $doubleClickCallback|0;
 var $$$i = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i16 = 0, $__p$0$i$i$i22 = 0, $__p$0$i$i$i8 = 0;
 var $conditionAndStacktrace = 0, $conditionAndStrippedStacktrace = 0, $logType$0$i = 0, $vararg_buffer5 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer5 = sp;
 $0 = sp + 56|0;
 $1 = sp + 8|0;
 $conditionAndStacktrace = sp + 20|0;
 $conditionAndStrippedStacktrace = sp + 32|0;
 $2 = sp + 44|0;
 $3 = $mode & 131072;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = $mode & 1059153;
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = $mode & 2;
   $8 = ($7|0)==(0);
   if ($8) {
    $9 = $mode & 4736;
    $10 = ($9|0)==(0);
    $$$i = $10 ? 3 : 2;
    $logType$0$i = $$$i;
   } else {
    $logType$0$i = 1;
   }
  } else {
   $logType$0$i = 0;
  }
 } else {
  $logType$0$i = 4;
 }
 $11 = HEAP32[650864>>2]|0;
 $12 = ($11|0)==((1)|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[650864>>2] = (1);
 $13 = (0|0)==(0|0);
 L9: do {
  if (!($13)) {
   $14 = (_strlen(($condition|0))|0);
   $15 = ($14>>>0)>(4294967279);
   if ($15) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $16 = ($14>>>0)<(11);
   if ($16) {
    $17 = $14 << 1;
    $18 = $17&255;
    HEAP8[$0>>0] = $18;
    $19 = (($0) + 1|0);
    $__p$0$i$i$i = $19;
   } else {
    $20 = (($14) + 16)|0;
    $21 = $20 & -16;
    $22 = (__Znwj($21)|0);
    $23 = (($0) + 8|0);
    HEAP32[$23>>2] = $22;
    $24 = $21 | 1;
    HEAP32[$0>>2] = $24;
    $25 = (($0) + 4|0);
    HEAP32[$25>>2] = $14;
    $__p$0$i$i$i = $22;
   }
   _memcpy(($__p$0$i$i$i|0),($condition|0),($14|0))|0;
   $26 = (($__p$0$i$i$i) + ($14)|0);
   HEAP8[$26>>0] = 0;
   $27 = (_strlen(($strippedStacktrace|0))|0);
   $28 = ($27>>>0)>(4294967279);
   do {
    if ($28) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      label = 24;
     } else {
      // unreachable;
     }
    } else {
     $31 = ($27>>>0)<(11);
     if ($31) {
      $32 = $27 << 1;
      $33 = $32&255;
      HEAP8[$1>>0] = $33;
      $34 = (($1) + 1|0);
      $__p$0$i$i$i8 = $34;
     } else {
      $35 = (($27) + 16)|0;
      $36 = $35 & -16;
      __THREW__ = 0;
      $37 = (invoke_ii(2988,($36|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 24;
       break;
      }
      $40 = (($1) + 8|0);
      HEAP32[$40>>2] = $37;
      $41 = $36 | 1;
      HEAP32[$1>>2] = $41;
      $42 = (($1) + 4|0);
      HEAP32[$42>>2] = $27;
      $__p$0$i$i$i8 = $37;
     }
     _memcpy(($__p$0$i$i$i8|0),($strippedStacktrace|0),($27|0))|0;
     $43 = (($__p$0$i$i$i8) + ($27)|0);
     HEAP8[$43>>0] = 0;
     __THREW__ = 0;
     invoke_viii(0|0,($0|0),($1|0),($logType$0$i|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      $58 = ___cxa_find_matching_catch()|0;
      $59 = tempRet0;
      $60 = HEAP8[$1>>0]|0;
      $61 = $60 & 1;
      $62 = ($61<<24>>24)==(0);
      if ($62) {
       $$0 = $59;$$01 = $58;
       break;
      }
      $63 = (($1) + 8|0);
      $64 = HEAP32[$63>>2]|0;
      __ZdlPv($64);
      $$0 = $59;$$01 = $58;
      break;
     }
     $46 = HEAP8[$1>>0]|0;
     $47 = $46 & 1;
     $48 = ($47<<24>>24)==(0);
     if (!($48)) {
      $49 = (($1) + 8|0);
      $50 = HEAP32[$49>>2]|0;
      __ZdlPv($50);
     }
     $51 = HEAP8[$0>>0]|0;
     $52 = $51 & 1;
     $53 = ($52<<24>>24)==(0);
     if ($53) {
      break L9;
     }
     $54 = (($0) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     __ZdlPv($55);
     break L9;
    }
   } while(0);
   if ((label|0) == 24) {
    $56 = ___cxa_find_matching_catch()|0;
    $57 = tempRet0;
    $$0 = $57;$$01 = $56;
   }
   $65 = HEAP8[$0>>0]|0;
   $66 = $65 & 1;
   $67 = ($66<<24>>24)==(0);
   if ($67) {
    $$3 = $$0;$$34 = $$01;
    ___resumeException($$34|0);
    // unreachable;
   }
   $68 = (($0) + 8|0);
   $69 = HEAP32[$68>>2]|0;
   __ZdlPv($69);
   $$3 = $$0;$$34 = $$01;
   ___resumeException($$34|0);
   // unreachable;
  }
 } while(0);
 $70 = (_strlen(($condition|0))|0);
 $71 = ($70>>>0)>(4294967279);
 if ($71) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $72 = ($70>>>0)<(11);
 if ($72) {
  $73 = $70 << 1;
  $74 = $73&255;
  HEAP8[$conditionAndStacktrace>>0] = $74;
  $75 = (($conditionAndStacktrace) + 1|0);
  $__p$0$i$i$i16 = $75;
 } else {
  $76 = (($70) + 16)|0;
  $77 = $76 & -16;
  $78 = (__Znwj($77)|0);
  $79 = (($conditionAndStacktrace) + 8|0);
  HEAP32[$79>>2] = $78;
  $80 = $77 | 1;
  HEAP32[$conditionAndStacktrace>>2] = $80;
  $81 = (($conditionAndStacktrace) + 4|0);
  HEAP32[$81>>2] = $70;
  $__p$0$i$i$i16 = $78;
 }
 _memcpy(($__p$0$i$i$i16|0),($condition|0),($70|0))|0;
 $82 = (($__p$0$i$i$i16) + ($70)|0);
 HEAP8[$82>>0] = 0;
 $83 = ($stacktrace|0)==(0|0);
 if ($83) {
  label = 38;
 } else {
  __THREW__ = 0;
  (invoke_iiii(1480,($conditionAndStacktrace|0),(650872|0),1)|0);
  $84 = __THREW__; __THREW__ = 0;
  $85 = $84&1;
  if ($85) {
   label = 37;
  } else {
   $86 = (_strlen(($stacktrace|0))|0);
   __THREW__ = 0;
   (invoke_iiii(1480,($conditionAndStacktrace|0),($stacktrace|0),($86|0))|0);
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    label = 37;
   } else {
    label = 38;
   }
  }
 }
 do {
  if ((label|0) == 38) {
   $91 = (_strlen(($condition|0))|0);
   $92 = ($91>>>0)>(4294967279);
   if ($92) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     label = 37;
     break;
    }
    // unreachable;
   }
   $95 = ($91>>>0)<(11);
   if ($95) {
    $96 = $91 << 1;
    $97 = $96&255;
    HEAP8[$conditionAndStrippedStacktrace>>0] = $97;
    $98 = (($conditionAndStrippedStacktrace) + 1|0);
    $__p$0$i$i$i22 = $98;
   } else {
    $99 = (($91) + 16)|0;
    $100 = $99 & -16;
    __THREW__ = 0;
    $101 = (invoke_ii(2988,($100|0))|0);
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 37;
     break;
    }
    $104 = (($conditionAndStrippedStacktrace) + 8|0);
    HEAP32[$104>>2] = $101;
    $105 = $100 | 1;
    HEAP32[$conditionAndStrippedStacktrace>>2] = $105;
    $106 = (($conditionAndStrippedStacktrace) + 4|0);
    HEAP32[$106>>2] = $91;
    $__p$0$i$i$i22 = $101;
   }
   _memcpy(($__p$0$i$i$i22|0),($condition|0),($91|0))|0;
   $107 = (($__p$0$i$i$i22) + ($91)|0);
   HEAP8[$107>>0] = 0;
   $108 = ($strippedStacktrace|0)==(0|0);
   if ($108) {
    label = 49;
   } else {
    __THREW__ = 0;
    (invoke_iiii(1480,($conditionAndStrippedStacktrace|0),(650872|0),1)|0);
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 48;
    } else {
     $111 = (_strlen(($strippedStacktrace|0))|0);
     __THREW__ = 0;
     (invoke_iiii(1480,($conditionAndStrippedStacktrace|0),($strippedStacktrace|0),($111|0))|0);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      label = 48;
     } else {
      label = 49;
     }
    }
   }
   do {
    if ((label|0) == 49) {
     $116 = ($errorNum|0)==(0);
     if ($116) {
      __THREW__ = 0;
      HEAP32[$vararg_buffer5>>2] = $condition;
      invoke_viii(1941,($logType$0$i|0),(650904|0),($vararg_buffer5|0));
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       label = 48;
       break;
      }
     } else {
      __THREW__ = 0;
      HEAP32[$vararg_buffer5>>2] = $condition;
      $vararg_ptr1 = (($vararg_buffer5) + 4|0);
      HEAP32[$vararg_ptr1>>2] = $errorNum;
      invoke_viii(1941,($logType$0$i|0),(650880|0),($vararg_buffer5|0));
      $117 = __THREW__; __THREW__ = 0;
      $118 = $117&1;
      if ($118) {
       label = 48;
       break;
      }
     }
     __THREW__ = 0;
     HEAP32[$vararg_buffer5>>2] = $condition;
     invoke_viii(1617,($2|0),(650912|0),($vararg_buffer5|0));
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if ($122) {
      label = 48;
     } else {
      $123 = HEAP8[$2>>0]|0;
      $124 = $123 & 1;
      $125 = ($124<<24>>24)==(0);
      if ($125) {
       $128 = (($2) + 1|0);
       $129 = $128;
      } else {
       $126 = (($2) + 8|0);
       $127 = HEAP32[$126>>2]|0;
       $129 = $127;
      }
      __THREW__ = 0;
      invoke_vii(3256,($129|0),($logType$0$i|0));
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       $140 = ___cxa_find_matching_catch()|0;
       $141 = tempRet0;
       $142 = HEAP8[$2>>0]|0;
       $143 = $142 & 1;
       $144 = ($143<<24>>24)==(0);
       if ($144) {
        $$1 = $141;$$12 = $140;
        break;
       }
       $145 = (($2) + 8|0);
       $146 = HEAP32[$145>>2]|0;
       __ZdlPv($146);
       $$1 = $141;$$12 = $140;
       break;
      }
      $132 = HEAP8[$2>>0]|0;
      $133 = $132 & 1;
      $134 = ($133<<24>>24)==(0);
      if (!($134)) {
       $135 = (($2) + 8|0);
       $136 = HEAP32[$135>>2]|0;
       __ZdlPv($136);
      }
      $137 = (0|0)==(0|0);
      if (!($137)) {
       __THREW__ = 0;
       invoke_viiiiiiii(0|0,($conditionAndStrippedStacktrace|0),($errorNum|0),($file|0),($line|0),($mode|0),($objectInstanceID|0),($identifier|0),($doubleClickCallback|0));
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if ($139) {
        label = 48;
        break;
       }
      }
      HEAP32[650864>>2] = 0;
      $147 = HEAP8[$conditionAndStrippedStacktrace>>0]|0;
      $148 = $147 & 1;
      $149 = ($148<<24>>24)==(0);
      if (!($149)) {
       $150 = (($conditionAndStrippedStacktrace) + 8|0);
       $151 = HEAP32[$150>>2]|0;
       __ZdlPv($151);
      }
      $152 = HEAP8[$conditionAndStacktrace>>0]|0;
      $153 = $152 & 1;
      $154 = ($153<<24>>24)==(0);
      if ($154) {
       STACKTOP = sp;return;
      }
      $155 = (($conditionAndStacktrace) + 8|0);
      $156 = HEAP32[$155>>2]|0;
      __ZdlPv($156);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 48) {
    $114 = ___cxa_find_matching_catch()|0;
    $115 = tempRet0;
    $$1 = $115;$$12 = $114;
   }
   $157 = HEAP8[$conditionAndStrippedStacktrace>>0]|0;
   $158 = $157 & 1;
   $159 = ($158<<24>>24)==(0);
   if ($159) {
    $$2 = $$1;$$23 = $$12;
   } else {
    $160 = (($conditionAndStrippedStacktrace) + 8|0);
    $161 = HEAP32[$160>>2]|0;
    __ZdlPv($161);
    $$2 = $$1;$$23 = $$12;
   }
  }
 } while(0);
 if ((label|0) == 37) {
  $89 = ___cxa_find_matching_catch()|0;
  $90 = tempRet0;
  $$2 = $90;$$23 = $89;
 }
 $162 = HEAP8[$conditionAndStacktrace>>0]|0;
 $163 = $162 & 1;
 $164 = ($163<<24>>24)==(0);
 if ($164) {
  $$3 = $$2;$$34 = $$23;
  ___resumeException($$34|0);
  // unreachable;
 }
 $165 = (($conditionAndStacktrace) + 8|0);
 $166 = HEAP32[$165>>2]|0;
 __ZdlPv($166);
 $$3 = $$2;$$34 = $$23;
 ___resumeException($$34|0);
 // unreachable;
}
function __Z19DebugTextLineByLinePKci($text,$maxLineLen) {
 $text = $text|0;
 $maxLineLen = $maxLineLen|0;
 var $$ = 0, $$12 = 0, $$maxLineLen = 0, $$pre = 0, $$pre10 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $lineEnd$0 = 0, $lineEnd$1 = 0, $lineStart$0 = 0, $lineStart$1$be = 0, $lineStart$16 = 0, $lineStart$2 = 0, $out = 0, $phitmp = 0, $phitmp$i$i = 0, $phitmp11 = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $out = sp + 4|0;
 $0 = ($maxLineLen|0)==(-1);
 $lineStart$0 = $text;
 while(1) {
  $1 = HEAP8[$lineStart$0>>0]|0;
  if (!((($1<<24>>24) == 10) | (($1<<24>>24) == 13))) {
   break;
  }
  $2 = (($lineStart$0) + 1|0);
  $lineStart$0 = $2;
 }
 $$maxLineLen = $0 ? 1023 : $maxLineLen;
 ;HEAP32[$out+0>>2]=0|0;HEAP32[$out+4>>2]=0|0;HEAP32[$out+8>>2]=0|0;
 $3 = HEAP8[$lineStart$0>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($out) + 4|0);
 $6 = (($out) + 1|0);
 $7 = (($out) + 8|0);
 $59 = $3;$lineStart$16 = $lineStart$0;
 L8: while(1) {
  $60 = $59;$lineEnd$0 = $lineStart$16;
  while(1) {
   if ((($60<<24>>24) == 0) | (($60<<24>>24) == 10) | (($60<<24>>24) == 13)) {
    break;
   }
   $8 = (($lineEnd$0) + 1|0);
   $$pre7 = HEAP8[$8>>0]|0;
   $60 = $$pre7;$lineEnd$0 = $8;
  }
  $9 = $lineEnd$0;
  $10 = $lineStart$16;
  $11 = (($9) - ($10))|0;
  $12 = ($11|0)>($$maxLineLen|0);
  if ($12) {
   $13 = (($lineStart$16) + ($$maxLineLen)|0);
   $$pre8 = HEAP8[$13>>0]|0;
   $61 = $$pre8;$lineEnd$1 = $13;
  } else {
   $61 = $60;$lineEnd$1 = $lineEnd$0;
  }
  $14 = $lineEnd$1;
  $15 = (($14) - ($10))|0;
  $16 = HEAP8[$out>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $23 = 10;$25 = $16;
  } else {
   $19 = HEAP32[$out>>2]|0;
   $20 = $19 & -2;
   $phitmp$i$i = (($20) + -1)|0;
   $21 = $19&255;
   $23 = $phitmp$i$i;$25 = $21;
  }
  $22 = ($23>>>0)<($15>>>0);
  $24 = $25 & 1;
  $26 = ($24<<24>>24)==(0);
  do {
   if ($22) {
    if ($26) {
     $35 = $25&255;
     $36 = $35 >>> 1;
     $38 = $36;
    } else {
     $34 = HEAP32[$5>>2]|0;
     $38 = $34;
    }
    $37 = (($15) - ($23))|0;
    __THREW__ = 0;
    invoke_viiiiiiii(29,($out|0),($23|0),($37|0),($38|0),0,($38|0),($15|0),($lineStart$16|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 28;
     break L8;
    }
    $$pre9 = HEAP8[$out>>0]|0;
    $42 = $$pre9;
   } else {
    $27 = HEAP32[$7>>2]|0;
    $$ = $26 ? $6 : $27;
    _memmove(($$|0),($lineStart$16|0),($15|0))|0;
    $28 = (($$) + ($15)|0);
    HEAP8[$28>>0] = 0;
    $29 = HEAP8[$out>>0]|0;
    $30 = $29 & 1;
    $31 = ($30<<24>>24)==(0);
    if ($31) {
     $32 = $15 << 1;
     $33 = $32&255;
     HEAP8[$out>>0] = $33;
     $42 = $33;
     break;
    } else {
     HEAP32[$5>>2] = $15;
     $42 = $29;
     break;
    }
   }
  } while(0);
  $41 = $42 & 1;
  $43 = ($41<<24>>24)==(0);
  $44 = HEAP32[$7>>2]|0;
  $$12 = $43 ? $6 : $44;
  __THREW__ = 0;
  HEAP32[$vararg_buffer>>2] = $$12;
  invoke_vii(2587,(650912|0),($vararg_buffer|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   label = 28;
   break;
  }
  L33: do {
   if ((($61<<24>>24) == 10) | (($61<<24>>24) == 13)) {
    $lineStart$2 = $lineEnd$1;
    while(1) {
     $49 = HEAP8[$lineStart$2>>0]|0;
     if (!((($49<<24>>24) == 10) | (($49<<24>>24) == 13))) {
      $48 = $49;$lineStart$1$be = $lineStart$2;
      break L33;
     }
     $50 = (($lineStart$2) + 1|0);
     $lineStart$2 = $50;
    }
   } else {
    $$pre10 = HEAP8[$lineEnd$1>>0]|0;
    $48 = $$pre10;$lineStart$1$be = $lineEnd$1;
   }
  } while(0);
  $47 = ($48<<24>>24)==(0);
  if ($47) {
   label = 30;
   break;
  } else {
   $59 = $48;$lineStart$16 = $lineStart$1$be;
  }
 }
 if ((label|0) == 28) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $53 = HEAP8[$out>>0]|0;
  $54 = $53 & 1;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   ___resumeException($51|0);
   // unreachable;
  }
  $56 = HEAP32[$7>>2]|0;
  __ZdlPv($56);
  ___resumeException($51|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  $$pre = HEAP8[$out>>0]|0;
  $phitmp = $$pre & 1;
  $phitmp11 = ($phitmp<<24>>24)==(0);
  if ($phitmp11) {
   STACKTOP = sp;return;
  }
  $57 = (($out) + 8|0);
  $58 = HEAP32[$57>>2]|0;
  __ZdlPv($58);
  STACKTOP = sp;return;
 }
}
function __ZN10MemoryPool16StaticInitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628480>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,650928,9)|0);
 HEAP32[$2>>2] = 0;
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[650920>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN10MemoryPool13StaticDestroyEv() {
 var $$byval_copy2 = 0, $$lcssa = 0, $$lcssa7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i$i$i$i$i = 0, $i$09 = 0, $or$cond = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[650920>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($4|0)==($5|0);
 if ($6) {
  $$lcssa = $2;$$lcssa7 = $3;$28 = $4;$30 = $4;
 } else {
  $8 = $5;$i$09 = 0;
  while(1) {
   $7 = (($8) + ($i$09<<2)|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = HEAP32[628480>>2]|0;
   $11 = ($9|0)==(0|0);
   if (!($11)) {
    __ZN10MemoryPoolD2Ev($9);
   }
   HEAP32[$0>>2] = $10;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy2);
   $12 = HEAP32[650920>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + ($i$09<<2)|0);
   HEAP32[$14>>2] = 0;
   $15 = (($i$09) + 1)|0;
   $16 = HEAP32[650920>>2]|0;
   $17 = (($16) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$16>>2]|0;
   $20 = $18;
   $21 = $19;
   $22 = (($20) - ($21))|0;
   $23 = $22 >> 2;
   $24 = ($15>>>0)<($23>>>0);
   if ($24) {
    $8 = $19;$i$09 = $15;
   } else {
    $$lcssa = $16;$$lcssa7 = $17;$28 = $19;$30 = $18;
    break;
   }
  }
 }
 $25 = HEAP32[628480>>2]|0;
 $26 = ($$lcssa|0)==(0|0);
 $27 = ($28|0)==(0|0);
 $or$cond = $26 | $27;
 if ($or$cond) {
  HEAP32[$1>>2] = $25;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($$lcssa,$$byval_copy2);
  HEAP32[650920>>2] = 0;
  STACKTOP = sp;return;
 }
 $29 = ($30|0)==($28|0);
 if (!($29)) {
  $__new_last2$i$i$i$i$i$i = $28;
  $scevgep$i$i$i$i$i$i = (($30) + -4|0);
  $31 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($31)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $32 = $uglygep3$i$i$i$i$i$i >>> 2;
  $33 = $32 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($30) + ($33<<2)|0);
  HEAP32[$$lcssa7>>2] = $scevgep4$i$i$i$i$i$i;
 }
 HEAP32[$0>>2] = 65;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($28|0),($$byval_copy2|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  HEAP32[$1>>2] = $25;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($$lcssa,$$byval_copy2);
  HEAP32[650920>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN10MemoryPool24RegisterStaticMemoryPoolEPS_($pool) {
 $pool = $pool|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $pool;
 $1 = HEAP32[650920>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  __ZNSt3__16vectorIP10MemoryPool13stl_allocatorIS2_L18MemLabelIdentifier65ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($1,$0);
  STACKTOP = sp;return;
 }
 $7 = ($3|0)==(0|0);
 if ($7) {
  $9 = 0;
 } else {
  HEAP32[$3>>2] = $pool;
  $$pre$i = HEAP32[$2>>2]|0;
  $9 = $$pre$i;
 }
 $8 = (($9) + 4|0);
 HEAP32[$2>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN10MemoryPoolC2EbPKcii10MemLabelId($this,$threadCheck,$name,$blockSize,$hintSize,$label) {
 $this = $this|0;
 $threadCheck = $threadCheck|0;
 $name = $name|0;
 $blockSize = $blockSize|0;
 $hintSize = $hintSize|0;
 $label = $label|0;
 var $$blockSize = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$label>>2]|0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = $0;
 $3 = (($this) + 20|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 24|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 36|0);
 HEAP32[$5>>2] = $0;
 $6 = ($blockSize|0)<(4);
 $$blockSize = $6 ? 4 : $blockSize;
 HEAP32[$this>>2] = $$blockSize;
 $7 = (($hintSize) + 4095)|0;
 $8 = $7 & -4096;
 $9 = (($this) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = (($8>>>0) / ($$blockSize>>>0))&-1;
 $11 = (($this) + 8|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 32|0);
 HEAP8[$12>>0] = 1;
 $13 = (($this) + 28|0);
 HEAP32[$13>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10MemoryPoolD2Ev($this) {
 $this = $this|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $it$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 L1: do {
  if ($8) {
   label = 5;
  } else {
   $9 = (($this) + 36|0);
   $it$01$i = $4;
   while(1) {
    $10 = HEAP32[$it$01$i>>2]|0;
    $11 = HEAP32[$9>>2]|0;
    HEAP32[$2>>2] = $11;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($10|0),($$byval_copy8|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = (($it$01$i) + 4|0);
    $15 = ($14|0)==($7|0);
    if ($15) {
     label = 5;
     break L1;
    } else {
     $it$01$i = $14;
    }
   }
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $$pre = (($this) + 24|0);
   $$pre$phiZ2D = $$pre;$lpad$phi$index = $28;$lpad$phi$index2 = $29;
  }
 } while(0);
 do {
  if ((label|0) == 5) {
   $16 = (($this) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>(-1);
   if (!($18)) {
    HEAP32[$5>>2] = 0;
    HEAP32[$16>>2] = 0;
    $24 = (($this) + 28|0);
    HEAP32[$24>>2] = 0;
    $25 = HEAP32[$3>>2]|0;
    $26 = (($this) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    HEAP32[$0>>2] = $27;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy8);
    HEAP32[$3>>2] = 0;
    STACKTOP = sp;return;
   }
   $19 = HEAP32[$3>>2]|0;
   $20 = (($this) + 16|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$1>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($19|0),($$byval_copy8|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    $$pre$phiZ2D = $16;$lpad$phi$index = $30;$lpad$phi$index2 = $31;
    break;
   }
   HEAP32[$3>>2] = 0;
   HEAP32[$5>>2] = 0;
   HEAP32[$16>>2] = 0;
   $24 = (($this) + 28|0);
   HEAP32[$24>>2] = 0;
   $25 = HEAP32[$3>>2]|0;
   $26 = (($this) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$0>>2] = $27;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy8);
   HEAP32[$3>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $32 = HEAP32[$$pre$phiZ2D>>2]|0;
 $33 = ($32|0)>(-1);
 if (!($33)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $34 = HEAP32[$3>>2]|0;
 $35 = (($this) + 16|0);
 $36 = HEAP32[$35>>2]|0;
 HEAP32[$0>>2] = $36;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy8|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch(0|0)|0;
  $40 = tempRet0;
  ___clang_call_terminate($39);
  // unreachable;
 }
 HEAP32[$3>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN10MemoryPool14AllocNewBubbleEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $j$03 = 0, $newBubble$0$lcssa = 0, $newBubble$04 = 0, $scevgep = 0, $smax = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 32|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $9 = (__Z15malloc_internaljj10MemLabelIdiPKci($6,16,$$byval_copy2,0,650928,99)|0);
 $10 = (($this) + 12|0);
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 $14 = (($this) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($13>>>0)>($16>>>0);
 if ($17) {
  $18 = $15 << 1;
  $19 = ($18|0)==(0);
  $20 = $19 ? 1 : $18;
  $21 = ($16>>>0)<($20>>>0);
  do {
   if ($21) {
    $22 = ($15|0)>(-1);
    if ($22) {
     HEAP32[$14>>2] = $20;
     $23 = HEAP32[$10>>2]|0;
     $24 = $20 << 2;
     $25 = (($this) + 16|0);
     $26 = HEAP32[$25>>2]|0;
     HEAP32[$0>>2] = $26;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $27 = (__Z16realloc_internalPvji10MemLabelIdiPKci($23,$24,4,$$byval_copy2,0,650928,370)|0);
     HEAP32[$10>>2] = $27;
     break;
    } else {
     $28 = $20 << 2;
     $29 = (($this) + 16|0);
     $30 = HEAP32[$29>>2]|0;
     HEAP32[$0>>2] = $30;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     $31 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,4,$$byval_copy2,0,650928,352)|0);
     $32 = HEAP32[$10>>2]|0;
     $33 = HEAP32[$11>>2]|0;
     $34 = $33 << 2;
     _memcpy(($31|0),($32|0),($34|0))|0;
     HEAP32[$14>>2] = $20;
     HEAP32[$10>>2] = $31;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$11>>2]|0;
  $36 = $$pre$i$i;
 } else {
  $36 = $13;
 }
 $35 = (($36) + -1)|0;
 $37 = HEAP32[$10>>2]|0;
 $38 = (($37) + ($35<<2)|0);
 HEAP32[$38>>2] = $9;
 $39 = (($this) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 HEAP32[$39>>2] = $9;
 $41 = (($this) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + -1)|0;
 $44 = ($43|0)>(0);
 if ($44) {
  $45 = HEAP32[$this>>2]|0;
  $46 = ($43|0)>(1);
  $smax = $46 ? $43 : 1;
  $47 = Math_imul($45, $smax)|0;
  $scevgep = (($9) + ($47)|0);
  $j$03 = 0;$newBubble$04 = $9;
  while(1) {
   $48 = (($newBubble$04) + ($45)|0);
   HEAP32[$newBubble$04>>2] = $48;
   $49 = (($j$03) + 1)|0;
   $50 = ($49|0)<($43|0);
   if ($50) {
    $j$03 = $49;$newBubble$04 = $48;
   } else {
    break;
   }
  }
  $newBubble$0$lcssa = $scevgep;
 } else {
  $newBubble$0$lcssa = $9;
 }
 HEAP32[$newBubble$0$lcssa>>2] = $40;
 $51 = HEAP32[$39>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(650936,0,650928,122,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN10MemoryPool8AllocateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZN10MemoryPool8AllocateEj($this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN10MemoryPool8AllocateEj($this,$amount) {
 $this = $this|0;
 $amount = $amount|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 8|0;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1>>>0)<($amount>>>0);
 if (!($2)) {
  $24 = (($this) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   __ZN10MemoryPool14AllocNewBubbleEv($this);
   $27 = HEAP32[$24>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $30 = $27;
   }
  } else {
   $30 = $25;
  }
  $29 = HEAP32[$30>>2]|0;
  HEAP32[$24>>2] = $29;
  $$0 = $30;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = $amount;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 __Z6FormatPKcz($0,650952,$vararg_buffer);
 $3 = HEAP8[$0>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($0) + 1|0);
  $9 = $8;
 } else {
  $6 = (($0) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $9 = $7;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($9|0),0,(650928|0),141,1,0,0,(0|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  $19 = HEAP8[$0>>0]|0;
  $20 = $19 & 1;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   ___resumeException($17|0);
   // unreachable;
  }
  $22 = (($0) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  __ZdlPv($23);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $12 = HEAP8[$0>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $15 = (($0) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  __ZdlPv($16);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10MemoryPool10DeallocateEPv($this,$mem_Block) {
 $this = $this|0;
 $mem_Block = $mem_Block|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mem_Block|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$mem_Block>>2] = $2;
 HEAP32[$1>>2] = $mem_Block;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIP10MemoryPool13stl_allocatorIS2_L18MemLabelIdentifier65ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 2;
  HEAP32[$0>>2] = 65;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,650928,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<2)|0);
 $24 = (($23) + ($$0$i3<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$__x>>2]|0;
  HEAP32[$22>>2] = $26;
 }
 $27 = (($23) + ($8<<2)|0);
 $28 = HEAP32[$this>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = $29;
 $31 = $28;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $$sum1 = (($7) - ($33))|0;
 $34 = (($23) + ($$sum1<<2)|0);
 _memcpy(($34|0),($28|0),($32|0))|0;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $34;
 HEAP32[$1>>2] = $27;
 HEAP32[$10>>2] = $24;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 65;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z14AppendPathNameRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_($agg$result,$pathName,$append) {
 $agg$result = $agg$result|0;
 $pathName = $pathName|0;
 $append = $append|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1942,($pathName|0),($append|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 $4 = HEAP8[$agg$result>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  ___resumeException($2|0);
  // unreachable;
 }
 $7 = (($agg$result) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 __ZdlPv($8);
 ___resumeException($2|0);
 // unreachable;
}
function __ZL18AppendPathNameImplRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_cRS5_($pathName,$append,$res) {
 $pathName = $pathName|0;
 $append = $append|0;
 $res = $res|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$in = 0, $$pn$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__cap$0$i$i = 0, $__p$0$i$i = 0, $__p$0$sum$pre$i$i = 0, $__p$0$sum$pre$phi$i$iZZZ2D = 0, $__sz$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP8[$pathName>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = $2&255;
  $8 = $7 >>> 1;
  $17 = $8;
 } else {
  $5 = (($pathName) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $17 = $6;
 }
 $9 = HEAP8[$append>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $14 = $9&255;
  $15 = $14 >>> 1;
  $19 = $15;
 } else {
  $12 = (($append) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $19 = $13;
 }
 $16 = (($17) + 1)|0;
 $18 = (($16) + ($19))|0;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj($res,$18);
 $20 = HEAP8[$pathName>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $25 = $20&255;
  $26 = $25 >>> 1;
  $28 = $26;
 } else {
  $23 = (($pathName) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $28 = $24;
 }
 $27 = ($28|0)==(0);
 if (!($27)) {
  $29 = HEAP8[$append>>0]|0;
  $30 = $29 & 1;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $34 = $29&255;
   $35 = $34 >>> 1;
   $37 = $35;
  } else {
   $32 = (($append) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $37 = $33;
  }
  $36 = ($37|0)==(0);
  if (!($36)) {
   if ($22) {
    $42 = $20&255;
    $43 = $42 >>> 1;
    $44 = (($pathName) + 1|0);
    $$in = $43;$47 = $44;
   } else {
    $38 = (($pathName) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($pathName) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    $$in = $39;$47 = $41;
   }
   $45 = (($$in) + -1)|0;
   $46 = (($47) + ($45)|0);
   $48 = HEAP8[$46>>0]|0;
   $49 = ($48<<24>>24)==(47);
   if ($31) {
    $52 = (($append) + 1|0);
    $54 = $52;
   } else {
    $50 = (($append) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $54 = $51;
   }
   $53 = HEAP8[$54>>0]|0;
   $55 = ($53<<24>>24)==(47);
   if ($22) {
    $60 = (($pathName) + 1|0);
    $61 = $20&255;
    $62 = $61 >>> 1;
    $63 = $60;$64 = $62;
   } else {
    $56 = (($pathName) + 8|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($pathName) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $63 = $57;$64 = $59;
   }
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($res,$63,$64)|0);
   if ($49) {
    $65 = HEAP8[$append>>0]|0;
    $66 = $65 & 1;
    $67 = ($66<<24>>24)==(0);
    if ($55) {
     if ($67) {
      $75 = (($append) + 2|0);
      HEAP32[$0>>2] = $75;
      $76 = (($append) + 1|0);
      $77 = $65&255;
      $78 = $77 >>> 1;
      $80 = $76;$81 = $78;
     } else {
      $68 = (($append) + 8|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($69) + 1|0);
      HEAP32[$0>>2] = $70;
      $71 = (($append) + 8|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($append) + 4|0);
      $74 = HEAP32[$73>>2]|0;
      $80 = $72;$81 = $74;
     }
     $79 = (($80) + ($81)|0);
     HEAP32[$1>>2] = $79;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
     (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendINS_11__wrap_iterIPKcEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeESC_SC_($res,$$byval_copy,$$byval_copy1)|0);
     STACKTOP = sp;return;
    } else {
     if ($67) {
      $86 = (($append) + 1|0);
      $87 = $65&255;
      $88 = $87 >>> 1;
      $89 = $86;$90 = $88;
     } else {
      $82 = (($append) + 8|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = (($append) + 4|0);
      $85 = HEAP32[$84>>2]|0;
      $89 = $83;$90 = $85;
     }
     (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($res,$89,$90)|0);
     STACKTOP = sp;return;
    }
   }
   if ($55) {
    $91 = HEAP8[$append>>0]|0;
    $92 = $91 & 1;
    $93 = ($92<<24>>24)==(0);
    if ($93) {
     $98 = (($append) + 1|0);
     $99 = $91&255;
     $100 = $99 >>> 1;
     $101 = $98;$102 = $100;
    } else {
     $94 = (($append) + 8|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = (($append) + 4|0);
     $97 = HEAP32[$96>>2]|0;
     $101 = $95;$102 = $97;
    }
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($res,$101,$102)|0);
    STACKTOP = sp;return;
   }
   $103 = HEAP8[$res>>0]|0;
   $104 = $103 & 1;
   $105 = ($104<<24>>24)!=(0);
   if ($105) {
    $108 = HEAP32[$res>>2]|0;
    $109 = $108 & -2;
    $110 = (($109) + -1)|0;
    $111 = (($res) + 4|0);
    $112 = HEAP32[$111>>2]|0;
    $__cap$0$i$i = $110;$__sz$0$i$i = $112;
   } else {
    $106 = $103&255;
    $107 = $106 >>> 1;
    $__cap$0$i$i = 10;$__sz$0$i$i = $107;
   }
   $113 = ($__sz$0$i$i|0)==($__cap$0$i$i|0);
   if ($113) {
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($res,$__cap$0$i$i,1,$__cap$0$i$i,$__cap$0$i$i,0,0);
    $114 = HEAP8[$res>>0]|0;
    $115 = $114 & 1;
    $116 = ($115<<24>>24)==(0);
    if ($116) {
     label = 45;
    } else {
     label = 46;
    }
   } else {
    if ($105) {
     label = 46;
    } else {
     label = 45;
    }
   }
   if ((label|0) == 45) {
    $117 = (($res) + 1|0);
    $118 = $__sz$0$i$i << 1;
    $119 = (($118) + 2)|0;
    $120 = $119&255;
    HEAP8[$res>>0] = $120;
    $__p$0$sum$pre$i$i = (($__sz$0$i$i) + 1)|0;
    $$pn$i$i = $117;$__p$0$sum$pre$phi$i$iZZZ2D = $__p$0$sum$pre$i$i;
   }
   else if ((label|0) == 46) {
    $121 = (($res) + 8|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = (($__sz$0$i$i) + 1)|0;
    $124 = (($res) + 4|0);
    HEAP32[$124>>2] = $123;
    $$pn$i$i = $122;$__p$0$sum$pre$phi$i$iZZZ2D = $123;
   }
   $__p$0$i$i = (($$pn$i$i) + ($__sz$0$i$i)|0);
   HEAP8[$__p$0$i$i>>0] = 47;
   $125 = (($$pn$i$i) + ($__p$0$sum$pre$phi$i$iZZZ2D)|0);
   HEAP8[$125>>0] = 0;
   $126 = HEAP8[$append>>0]|0;
   $127 = $126 & 1;
   $128 = ($127<<24>>24)==(0);
   if ($128) {
    $133 = (($append) + 1|0);
    $134 = $126&255;
    $135 = $134 >>> 1;
    $136 = $133;$137 = $135;
   } else {
    $129 = (($append) + 8|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = (($append) + 4|0);
    $132 = HEAP32[$131>>2]|0;
    $136 = $130;$137 = $132;
   }
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($res,$136,$137)|0);
   STACKTOP = sp;return;
  }
 }
 if ($22) {
  $140 = $20&255;
  $141 = $140 >>> 1;
  $143 = $141;
 } else {
  $138 = (($pathName) + 4|0);
  $139 = HEAP32[$138>>2]|0;
  $143 = $139;
 }
 $142 = ($143|0)==(0);
 if ($142) {
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($res,$append)|0);
  STACKTOP = sp;return;
 } else {
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($res,$pathName)|0);
  STACKTOP = sp;return;
 }
}
function __Z20GetPathNameExtensionRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$pathName) {
 $agg$result = $agg$result|0;
 $pathName = $pathName|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$pathName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = (($pathName) + 1|0);
  $8 = $0&255;
  $9 = $8 >>> 1;
  $11 = $9;$15 = $7;
 } else {
  $3 = (($pathName) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($pathName) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $11 = $6;$15 = $4;
 }
 $10 = ($11|0)==(0);
 L5: do {
  if ($10) {
   $$0$i = 651024;
  } else {
   $i$01$i = 0;
   while(1) {
    $12 = (($11) - ($i$01$i))|0;
    $13 = (($12) + -1)|0;
    $14 = (($15) + ($13)|0);
    $16 = HEAP8[$14>>0]|0;
    if ((($16<<24>>24) == 46)) {
     break;
    } else if ((($16<<24>>24) == 47)) {
     $$0$i = 651024;
     break L5;
    }
    $18 = (($i$01$i) + 1)|0;
    $19 = ($18>>>0)<($11>>>0);
    if ($19) {
     $i$01$i = $18;
    } else {
     $$0$i = 651024;
     break L5;
    }
   }
   $17 = (($15) + ($12)|0);
   $$0$i = $17;
  }
 } while(0);
 $20 = (_strlen(($$0$i|0))|0);
 $21 = ($20>>>0)>(4294967279);
 if ($21) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = ($20>>>0)<(11);
 if ($22) {
  $23 = $20 << 1;
  $24 = $23&255;
  HEAP8[$agg$result>>0] = $24;
  $25 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $25;
  _memcpy(($__p$0$i$i$i|0),($$0$i|0),($20|0))|0;
  $32 = (($__p$0$i$i$i) + ($20)|0);
  HEAP8[$32>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $26 = (($20) + 16)|0;
  $27 = $26 & -16;
  $28 = (__Znwj($27)|0);
  $29 = (($agg$result) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $27 | 1;
  HEAP32[$agg$result>>2] = $30;
  $31 = (($agg$result) + 4|0);
  HEAP32[$31>>2] = $20;
  $__p$0$i$i$i = $28;
  _memcpy(($__p$0$i$i$i|0),($$0$i|0),($20|0))|0;
  $32 = (($__p$0$i$i$i) + ($20)|0);
  HEAP8[$32>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __Z23DeletePathNameExtensionRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$pathName) {
 $agg$result = $agg$result|0;
 $pathName = $pathName|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i8 = 0, $__ps$0$i = 0, $__ps$0$i3 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$pathName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($pathName) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8|0)==(0);
 L5: do {
  if ($7) {
   $$0$i = -1;
  } else {
   if ($2) {
    $11 = (($pathName) + 1|0);
    $13 = $11;
   } else {
    $9 = (($pathName) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $13 = $10;
   }
   $12 = (($13) + ($8)|0);
   $__ps$0$i = $12;
   while(1) {
    $14 = ($__ps$0$i|0)==($13|0);
    if ($14) {
     $$0$i = -1;
     break L5;
    }
    $15 = (($__ps$0$i) + -1|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(47);
    if ($17) {
     break;
    } else {
     $__ps$0$i = $15;
    }
   }
   $18 = $15;
   $19 = $13;
   $20 = (($18) - ($19))|0;
   $$0$i = $20;
  }
 } while(0);
 if ($2) {
  $23 = $0&255;
  $24 = $23 >>> 1;
  $26 = $24;
 } else {
  $21 = (($pathName) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $26 = $22;
 }
 $25 = ($26|0)==(0);
 L20: do {
  if (!($25)) {
   if ($2) {
    $29 = (($pathName) + 1|0);
    $31 = $29;
   } else {
    $27 = (($pathName) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $31 = $28;
   }
   $30 = (($31) + ($26)|0);
   $__ps$0$i3 = $30;
   while(1) {
    $32 = ($__ps$0$i3|0)==($31|0);
    if ($32) {
     break L20;
    }
    $33 = (($__ps$0$i3) + -1|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)==(46);
    if ($35) {
     break;
    } else {
     $__ps$0$i3 = $33;
    }
   }
   $36 = $33;
   $37 = $31;
   $38 = (($36) - ($37))|0;
   $39 = ($38|0)==(-1);
   if (!($39)) {
    $40 = ($$0$i|0)==(-1);
    $41 = ($38>>>0)>($$0$i>>>0);
    $or$cond = $40 | $41;
    if ($or$cond) {
     if ($2) {
      $44 = (($pathName) + 1|0);
      $56 = $44;
     } else {
      $42 = (($pathName) + 8|0);
      $43 = HEAP32[$42>>2]|0;
      $56 = $43;
     }
     $45 = ($38>>>0)>(4294967279);
     if ($45) {
      __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
      // unreachable;
     }
     $46 = ($38>>>0)<(11);
     if ($46) {
      $47 = $38 << 1;
      $48 = $47&255;
      HEAP8[$agg$result>>0] = $48;
      $49 = (($agg$result) + 1|0);
      $__p$0$i$i$i8 = $49;
     } else {
      $50 = (($38) + 16)|0;
      $51 = $50 & -16;
      $52 = (__Znwj($51)|0);
      $53 = (($agg$result) + 8|0);
      HEAP32[$53>>2] = $52;
      $54 = $51 | 1;
      HEAP32[$agg$result>>2] = $54;
      $55 = (($agg$result) + 4|0);
      HEAP32[$55>>2] = $38;
      $__p$0$i$i$i8 = $52;
     }
     _memcpy(($__p$0$i$i$i8|0),($56|0),($38|0))|0;
     $57 = (($__p$0$i$i$i8) + ($38)|0);
     HEAP8[$57>>0] = 0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ($2) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$pathName+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$pathName+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$pathName+8>>2]|0;
  STACKTOP = sp;return;
 }
 $58 = (($pathName) + 8|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($pathName) + 4|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61>>>0)>(4294967279);
 if ($62) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $63 = ($61>>>0)<(11);
 if ($63) {
  $64 = $61 << 1;
  $65 = $64&255;
  HEAP8[$agg$result>>0] = $65;
  $66 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $66;
 } else {
  $67 = (($61) + 16)|0;
  $68 = $67 & -16;
  $69 = (__Znwj($68)|0);
  $70 = (($agg$result) + 8|0);
  HEAP32[$70>>2] = $69;
  $71 = $68 | 1;
  HEAP32[$agg$result>>2] = $71;
  $72 = (($agg$result) + 4|0);
  HEAP32[$72>>2] = $61;
  $__p$0$i$i$i = $69;
 }
 _memcpy(($__p$0$i$i$i|0),($59|0),($61|0))|0;
 $73 = (($__p$0$i$i$i) + ($61)|0);
 HEAP8[$73>>0] = 0;
 STACKTOP = sp;return;
}
function __Z27FindSeparatedPathComponentsPKcjc($agg$result,$constPathName,$size,$separator) {
 $agg$result = $agg$result|0;
 $constPathName = $constPathName|0;
 $size = $size|0;
 $separator = $separator|0;
 var $$0 = 0, $$0$lcssa$i = 0, $$01 = 0, $$01$i = 0, $$02$i$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$ph$i$i$i = 0, $__p$01$i$i$i = 0, $current$012 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi11$index = 0, $lpad$phi11$index7 = 0, $or$cond = 0, $scevgep$i$i$i = 0, $scevgep3$i$i$i = 0, $scevgep4$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($constPathName) + ($size)|0);
 HEAP32[$agg$result>>2] = 0;
 $2 = (($agg$result) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($agg$result) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ($size|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($0) + 1|0);
 $6 = (($0) + 8|0);
 $7 = (($0) + 4|0);
 $current$012 = $constPathName;
 L4: while(1) {
  $$01$i = $current$012;
  while(1) {
   $10 = HEAP8[$$01$i>>0]|0;
   $11 = ($10<<24>>24)==($separator<<24>>24);
   $9 = (($$01$i) + 1|0);
   if ($11) {
    $$0$lcssa$i = $$01$i;
    break;
   }
   $8 = ($9|0)==($1|0);
   if ($8) {
    $$0$lcssa$i = $1;
    break;
   } else {
    $$01$i = $9;
   }
  }
  $12 = ($$0$lcssa$i|0)==($current$012|0);
  if (!($12)) {
   $13 = $current$012;
   $14 = $$0$lcssa$i;
   $15 = (($14) - ($13))|0;
   $16 = ($15>>>0)>(4294967279);
   if ($16) {
    label = 8;
    break;
   }
   $19 = ($15>>>0)<(11);
   if ($19) {
    $20 = $15 << 1;
    $21 = $20&255;
    HEAP8[$0>>0] = $21;
    $__p$0$ph$i$i$i = $5;
   } else {
    $22 = (($15) + 16)|0;
    $23 = $22 & -16;
    __THREW__ = 0;
    $24 = (invoke_ii(2988,($23|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     label = 32;
     break;
    }
    HEAP32[$6>>2] = $24;
    $27 = $23 | 1;
    HEAP32[$0>>2] = $27;
    HEAP32[$7>>2] = $15;
    $__p$0$ph$i$i$i = $24;
   }
   $$02$i$i$i = $current$012;$__p$01$i$i$i = $__p$0$ph$i$i$i;
   while(1) {
    $28 = HEAP8[$$02$i$i$i>>0]|0;
    HEAP8[$__p$01$i$i$i>>0] = $28;
    $29 = (($$02$i$i$i) + 1|0);
    $30 = (($__p$01$i$i$i) + 1|0);
    $31 = ($29|0)==($$0$lcssa$i|0);
    if ($31) {
     break;
    } else {
     $$02$i$i$i = $29;$__p$01$i$i$i = $30;
    }
   }
   $32 = (0 - ($13))|0;
   $scevgep$i$i$i = (($$0$lcssa$i) + ($32)|0);
   $scevgep3$i$i$i = $scevgep$i$i$i;
   $scevgep4$i$i$i = (($__p$0$ph$i$i$i) + ($scevgep3$i$i$i)|0);
   HEAP8[$scevgep4$i$i$i>>0] = 0;
   $33 = HEAP32[$2>>2]|0;
   $34 = HEAP32[$3>>2]|0;
   $35 = ($33|0)==($34|0);
   if ($35) {
    __THREW__ = 0;
    invoke_vii(2523,($agg$result|0),($0|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     label = 35;
     break;
    }
   } else {
    $36 = ($33|0)==(0|0);
    do {
     if (!($36)) {
      $37 = HEAP8[$0>>0]|0;
      $38 = $37 & 1;
      $39 = ($38<<24>>24)==(0);
      if ($39) {
       ;HEAP32[$33+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$0+8>>2]|0;
       break;
      }
      $40 = HEAP32[$6>>2]|0;
      $41 = HEAP32[$7>>2]|0;
      $42 = ($41>>>0)>(4294967279);
      if ($42) {
       label = 21;
       break L4;
      }
      $45 = ($41>>>0)<(11);
      if ($45) {
       $46 = $41 << 1;
       $47 = $46&255;
       HEAP8[$33>>0] = $47;
       $48 = (($33) + 1|0);
       $__p$0$i$i$i$i$i = $48;
      } else {
       $49 = (($41) + 16)|0;
       $50 = $49 & -16;
       __THREW__ = 0;
       $51 = (invoke_ii(2988,($50|0))|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        label = 35;
        break L4;
       }
       $54 = (($33) + 8|0);
       HEAP32[$54>>2] = $51;
       $55 = $50 | 1;
       HEAP32[$33>>2] = $55;
       $56 = (($33) + 4|0);
       HEAP32[$56>>2] = $41;
       $__p$0$i$i$i$i$i = $51;
      }
      _memcpy(($__p$0$i$i$i$i$i|0),($40|0),($41|0))|0;
      $57 = (($__p$0$i$i$i$i$i) + ($41)|0);
      HEAP8[$57>>0] = 0;
     }
    } while(0);
    $58 = HEAP32[$2>>2]|0;
    $59 = (($58) + 12|0);
    HEAP32[$2>>2] = $59;
   }
   $62 = HEAP8[$0>>0]|0;
   $63 = $62 & 1;
   $64 = ($63<<24>>24)==(0);
   if (!($64)) {
    $65 = HEAP32[$6>>2]|0;
    __ZdlPv($65);
   }
  }
  $78 = ($$0$lcssa$i|0)==($1|0);
  $79 = (($$0$lcssa$i) + 1|0);
  $80 = ($79|0)==($1|0);
  $or$cond = $78 | $80;
  if ($or$cond) {
   label = 40;
   break;
  } else {
   $current$012 = $79;
  }
 }
 do {
  if ((label|0) == 8) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    $lpad$phi$index = $68;$lpad$phi$index2 = $69;
    label = 34;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 21) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $72 = ___cxa_find_matching_catch()|0;
    $73 = tempRet0;
    $75 = $37;$lpad$phi11$index = $72;$lpad$phi11$index7 = $73;
    label = 37;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 32) {
   $66 = ___cxa_find_matching_catch()|0;
   $67 = tempRet0;
   $lpad$phi$index = $66;$lpad$phi$index2 = $67;
   label = 34;
  }
  else if ((label|0) == 35) {
   $70 = ___cxa_find_matching_catch()|0;
   $71 = tempRet0;
   $$pre = HEAP8[$0>>0]|0;
   $75 = $$pre;$lpad$phi11$index = $70;$lpad$phi11$index7 = $71;
   label = 37;
  }
  else if ((label|0) == 40) {
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 34) {
  $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
 }
 else if ((label|0) == 37) {
  $74 = $75 & 1;
  $76 = ($74<<24>>24)==(0);
  if ($76) {
   $$0 = $lpad$phi11$index7;$$01 = $lpad$phi11$index;
  } else {
   $77 = HEAP32[$6>>2]|0;
   __ZdlPv($77);
   $$0 = $lpad$phi11$index7;$$01 = $lpad$phi11$index;
  }
 }
 $81 = HEAP32[$agg$result>>2]|0;
 $82 = ($81|0)==(0|0);
 if ($82) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $83 = HEAP32[$2>>2]|0;
 $84 = ($83|0)==($81|0);
 if ($84) {
  $94 = $81;
 } else {
  $86 = $83;
  while(1) {
   $85 = (($86) + -12|0);
   HEAP32[$2>>2] = $85;
   $87 = HEAP8[$85>>0]|0;
   $88 = $87 & 1;
   $89 = ($88<<24>>24)==(0);
   if ($89) {
    $91 = $85;
   } else {
    $92 = (($86) + -4|0);
    $93 = HEAP32[$92>>2]|0;
    __ZdlPv($93);
    $$pre$i$i$i$i$i = HEAP32[$2>>2]|0;
    $91 = $$pre$i$i$i$i$i;
   }
   $90 = ($91|0)==($81|0);
   if ($90) {
    break;
   } else {
    $86 = $91;
   }
  }
  $$pre$i$i$i = HEAP32[$agg$result>>2]|0;
  $94 = $$pre$i$i$i;
 }
 __ZdlPv($94);
 ___resumeException($$01|0);
 // unreachable;
}
function __Z27DeleteLastPathNameComponentRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$pathName) {
 $agg$result = $agg$result|0;
 $pathName = $pathName|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__ps$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$pathName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($pathName) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8|0)==(0);
 L5: do {
  if (!($7)) {
   if ($2) {
    $11 = (($pathName) + 1|0);
    $13 = $11;
   } else {
    $9 = (($pathName) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $13 = $10;
   }
   $12 = (($13) + ($8)|0);
   $__ps$0$i = $12;
   while(1) {
    $14 = ($__ps$0$i|0)==($13|0);
    if ($14) {
     break L5;
    }
    $15 = (($__ps$0$i) + -1|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(47);
    if ($17) {
     break;
    } else {
     $__ps$0$i = $15;
    }
   }
   $18 = $15;
   $19 = $13;
   $20 = (($18) - ($19))|0;
   $21 = ($20|0)==(-1);
   if (!($21)) {
    if ($2) {
     $24 = (($pathName) + 1|0);
     $36 = $24;
    } else {
     $22 = (($pathName) + 8|0);
     $23 = HEAP32[$22>>2]|0;
     $36 = $23;
    }
    $25 = ($20>>>0)>(4294967279);
    if ($25) {
     __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
     // unreachable;
    }
    $26 = ($20>>>0)<(11);
    if ($26) {
     $27 = $20 << 1;
     $28 = $27&255;
     HEAP8[$agg$result>>0] = $28;
     $29 = (($agg$result) + 1|0);
     $__p$0$i$i$i = $29;
    } else {
     $30 = (($20) + 16)|0;
     $31 = $30 & -16;
     $32 = (__Znwj($31)|0);
     $33 = (($agg$result) + 8|0);
     HEAP32[$33>>2] = $32;
     $34 = $31 | 1;
     HEAP32[$agg$result>>2] = $34;
     $35 = (($agg$result) + 4|0);
     HEAP32[$35>>2] = $20;
     $__p$0$i$i$i = $32;
    }
    _memcpy(($__p$0$i$i$i|0),($36|0),($20|0))|0;
    $37 = (($__p$0$i$i$i) + ($20)|0);
    HEAP8[$37>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __Z24GetLastPathNameComponentRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$pathName) {
 $agg$result = $agg$result|0;
 $pathName = $pathName|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$pathName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = (($pathName) + 1|0);
  $8 = $0&255;
  $9 = $8 >>> 1;
  $11 = $9;$17 = $7;
 } else {
  $3 = (($pathName) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($pathName) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $11 = $6;$17 = $4;
 }
 $10 = ($11|0)==(0);
 L5: do {
  if ($10) {
   $$0$i = $17;
  } else {
   $i$01$i = 0;
   while(1) {
    $14 = (($11) - ($i$01$i))|0;
    $15 = (($14) + -1)|0;
    $16 = (($17) + ($15)|0);
    $18 = HEAP8[$16>>0]|0;
    $19 = ($18<<24>>24)==(47);
    $13 = (($i$01$i) + 1)|0;
    if ($19) {
     break;
    }
    $12 = ($13>>>0)<($11>>>0);
    if ($12) {
     $i$01$i = $13;
    } else {
     $$0$i = $17;
     break L5;
    }
   }
   $20 = (($17) + ($14)|0);
   $$0$i = $20;
  }
 } while(0);
 $21 = (_strlen(($$0$i|0))|0);
 $22 = ($21>>>0)>(4294967279);
 if ($22) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = ($21>>>0)<(11);
 if ($23) {
  $24 = $21 << 1;
  $25 = $24&255;
  HEAP8[$agg$result>>0] = $25;
  $26 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $26;
  _memcpy(($__p$0$i$i$i|0),($$0$i|0),($21|0))|0;
  $33 = (($__p$0$i$i$i) + ($21)|0);
  HEAP8[$33>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $27 = (($21) + 16)|0;
  $28 = $27 & -16;
  $29 = (__Znwj($28)|0);
  $30 = (($agg$result) + 8|0);
  HEAP32[$30>>2] = $29;
  $31 = $28 | 1;
  HEAP32[$agg$result>>2] = $31;
  $32 = (($agg$result) + 4|0);
  HEAP32[$32>>2] = $21;
  $__p$0$i$i$i = $29;
  _memcpy(($__p$0$i$i$i|0),($$0$i|0),($21|0))|0;
  $33 = (($__p$0$i$i$i) + ($21)|0);
  HEAP8[$33>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __Z19StandardizePathNameRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$pathName) {
 $agg$result = $agg$result|0;
 $pathName = $pathName|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i2 = 0, $__p$0$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$pathName>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($pathName) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8|0)==(0);
 if ($7) {
  if ($2) {
   ;HEAP32[$agg$result+0>>2]=HEAP32[$pathName+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$pathName+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$pathName+8>>2]|0;
   STACKTOP = sp;return;
  }
  $9 = (($pathName) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($pathName) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12>>>0)>(4294967279);
  if ($13) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $14 = ($12>>>0)<(11);
  if ($14) {
   $15 = $12 << 1;
   $16 = $15&255;
   HEAP8[$agg$result>>0] = $16;
   $17 = (($agg$result) + 1|0);
   $__p$0$i$i$i2 = $17;
  } else {
   $18 = (($12) + 16)|0;
   $19 = $18 & -16;
   $20 = (__Znwj($19)|0);
   $21 = (($agg$result) + 8|0);
   HEAP32[$21>>2] = $20;
   $22 = $19 | 1;
   HEAP32[$agg$result>>2] = $22;
   $23 = (($agg$result) + 4|0);
   HEAP32[$23>>2] = $12;
   $__p$0$i$i$i2 = $20;
  }
  _memcpy(($__p$0$i$i$i2|0),($10|0),($12|0))|0;
  $24 = (($__p$0$i$i$i2) + ($12)|0);
  HEAP8[$24>>0] = 0;
  STACKTOP = sp;return;
 }
 if ($2) {
  $27 = (($pathName) + 1|0);
  $29 = $27;
 } else {
  $25 = (($pathName) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $29 = $26;
 }
 $28 = HEAP8[$29>>0]|0;
 $30 = ($28<<24>>24)==(47);
 if ($30) {
  if ($2) {
   $33 = $0&255;
   $34 = $33 >>> 1;
   $36 = $34;
  } else {
   $31 = (($pathName) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $36 = $32;
  }
  $35 = ($36>>>0)>(1);
  if ($35) {
   if ($2) {
    $39 = (($pathName) + 1|0);
    $41 = $39;
   } else {
    $37 = (($pathName) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    $41 = $38;
   }
   $40 = (($41) + 1|0);
   $42 = HEAP8[$40>>0]|0;
   $43 = ($42<<24>>24)==(47);
   if (!($43)) {
    if ($2) {
     $48 = (($pathName) + 1|0);
     $49 = $0&255;
     $50 = $49 >>> 1;
     $$pn = $48;$53 = $50;
    } else {
     $44 = (($pathName) + 8|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($pathName) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $$pn = $45;$53 = $47;
    }
    $51 = (($$pn) + 1|0);
    $52 = (($53) + -1)|0;
    $54 = ($52>>>0)>(4294967279);
    if ($54) {
     __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
     // unreachable;
    }
    $55 = ($52>>>0)<(11);
    if ($55) {
     $56 = $52 << 1;
     $57 = $56&255;
     HEAP8[$agg$result>>0] = $57;
     $58 = (($agg$result) + 1|0);
     $__p$0$i$i$i7 = $58;
    } else {
     $59 = (($53) + 15)|0;
     $60 = $59 & -16;
     $61 = (__Znwj($60)|0);
     $62 = (($agg$result) + 8|0);
     HEAP32[$62>>2] = $61;
     $63 = $60 | 1;
     HEAP32[$agg$result>>2] = $63;
     $64 = (($agg$result) + 4|0);
     HEAP32[$64>>2] = $52;
     $__p$0$i$i$i7 = $61;
    }
    _memcpy(($__p$0$i$i$i7|0),($51|0),($52|0))|0;
    $65 = (($__p$0$i$i$i7) + ($52)|0);
    HEAP8[$65>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 if ($2) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$pathName+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$pathName+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$pathName+8>>2]|0;
  STACKTOP = sp;return;
 }
 $66 = (($pathName) + 8|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($pathName) + 4|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69>>>0)>(4294967279);
 if ($70) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $71 = ($69>>>0)<(11);
 if ($71) {
  $72 = $69 << 1;
  $73 = $72&255;
  HEAP8[$agg$result>>0] = $73;
  $74 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $74;
 } else {
  $75 = (($69) + 16)|0;
  $76 = $75 & -16;
  $77 = (__Znwj($76)|0);
  $78 = (($agg$result) + 8|0);
  HEAP32[$78>>2] = $77;
  $79 = $76 | 1;
  HEAP32[$agg$result>>2] = $79;
  $80 = (($agg$result) + 4|0);
  HEAP32[$80>>2] = $69;
  $__p$0$i$i$i = $77;
 }
 _memcpy(($__p$0$i$i$i|0),($67|0),($69|0))|0;
 $81 = (($__p$0$i$i$i) + ($69)|0);
 HEAP8[$81>>0] = 0;
 STACKTOP = sp;return;
}
function __Z24ConvertSeparatorsToUnityPc($pathName) {
 $pathName = $pathName|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $pathName;
 while(1) {
  $0 = HEAP8[$$0>>0]|0;
  if ((($0<<24>>24) == 92)) {
   HEAP8[$$0>>0] = 47;
  } else if ((($0<<24>>24) == 0)) {
   break;
  }
  $1 = (($$0) + 1|0);
  $$0 = $1;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendINS_11__wrap_iterIPKcEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$02 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = $0&255;
  $4 = $3 >>> 1;
  $17 = 10;$18 = $4;$44 = $0;
 } else {
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$this>>2]|0;
  $8 = $7 & -2;
  $phitmp$i = (($8) + -1)|0;
  $9 = $7&255;
  $17 = $phitmp$i;$18 = $6;$44 = $9;
 }
 $10 = HEAP32[$__first>>2]|0;
 $11 = HEAP32[$__last>>2]|0;
 $12 = $11;
 $13 = $10;
 $14 = (($12) - ($13))|0;
 $15 = ($11|0)==($10|0);
 if ($15) {
  STACKTOP = sp;return ($this|0);
 }
 $16 = (($17) - ($18))|0;
 $19 = ($16>>>0)<($14>>>0);
 if ($19) {
  $20 = (($18) - ($17))|0;
  $21 = (($20) + ($14))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($this,$17,$21,$18,$18,0,0);
  $$pre = HEAP8[$this>>0]|0;
  $23 = $$pre;
 } else {
  $23 = $44;
 }
 $22 = $23 & 1;
 $24 = ($22<<24>>24)==(0);
 if ($24) {
  $27 = (($this) + 1|0);
  $29 = $27;
 } else {
  $25 = (($this) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $29 = $26;
 }
 $28 = (($29) + ($18)|0);
 $31 = $10;$__p$02 = $28;
 while(1) {
  $30 = HEAP8[$31>>0]|0;
  HEAP8[$__p$02>>0] = $30;
  $32 = (($__p$02) + 1|0);
  $33 = HEAP32[$__first>>2]|0;
  $34 = (($33) + 1|0);
  HEAP32[$__first>>2] = $34;
  $35 = HEAP32[$__last>>2]|0;
  $36 = ($34|0)==($35|0);
  if ($36) {
   break;
  } else {
   $31 = $34;$__p$02 = $32;
  }
 }
 HEAP8[$32>>0] = 0;
 $37 = (($14) + ($18))|0;
 $38 = HEAP8[$this>>0]|0;
 $39 = $38 & 1;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  $42 = $37 << 1;
  $43 = $42&255;
  HEAP8[$this>>0] = $43;
  STACKTOP = sp;return ($this|0);
 } else {
  $41 = (($this) + 4|0);
  HEAP32[$41>>2] = $37;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __Z27GetUserAuthorizationManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (651032|0);
}
function __ZN24UserAuthorizationManager22GetAuthorizationDialogEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $storemerge = 0, $temp$0$i = 0, $temp$0$i$i = 0, $temp$0$i12 = 0, $temp$0$i6 = 0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $0 = sp + 32|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0$i$i = 0;
 } else {
  HEAP32[$3>>2] = $9;
  $11 = HEAP32[560624>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   label = 10;
  } else {
   $13 = (($11) + 36|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($11) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14|0)==($16|0);
   do {
    if ($17) {
     $18 = (($11) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($11) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $38 = $22;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$11,$3);
     $23 = HEAP32[$vararg_buffer>>2]|0;
     $24 = ($23|0)==(-1);
     $25 = (($11) + 28|0);
     $26 = HEAP32[$25>>2]|0;
     if ($24) {
      $27 = (($11) + 32|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($26) + ($28<<3)|0);
      $38 = $29;
      break;
     } else {
      $30 = (($26) + ($23<<3)|0);
      $38 = $30;
      break;
     }
    }
   } while(0);
   $31 = HEAP32[560624>>2]|0;
   $32 = (($31) + 28|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 32|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) + ($35<<3)|0);
   $37 = ($38|0)==($36|0);
   if ($37) {
    label = 10;
   } else {
    $39 = (($38) + 4|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==(0|0);
    if ($41) {
     label = 10;
    } else {
     $temp$0$i$i = $40;
    }
   }
  }
  if ((label|0) == 10) {
   $42 = HEAP32[$8>>2]|0;
   $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
   $temp$0$i$i = $43;
  }
  $phitmp$i = ($temp$0$i$i|0)!=(0|0);
  $$0$i$i = $phitmp$i;
 }
 if ($7) {
  if (!($$0$i$i)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $135 = HEAP32[$8>>2]|0;
  $136 = ($135|0)==(0);
  if ($136) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $135;
   $137 = HEAP32[560624>>2]|0;
   $138 = ($137|0)==(0|0);
   if ($138) {
    label = 51;
   } else {
    $139 = (($137) + 36|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = (($137) + 4|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = ($140|0)==($142|0);
    do {
     if ($143) {
      $144 = (($137) + 28|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = (($137) + 32|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = (($145) + ($147<<3)|0);
      $164 = $148;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$137,$0);
      $149 = HEAP32[$vararg_buffer>>2]|0;
      $150 = ($149|0)==(-1);
      $151 = (($137) + 28|0);
      $152 = HEAP32[$151>>2]|0;
      if ($150) {
       $153 = (($137) + 32|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = (($152) + ($154<<3)|0);
       $164 = $155;
       break;
      } else {
       $156 = (($152) + ($149<<3)|0);
       $164 = $156;
       break;
      }
     }
    } while(0);
    $157 = HEAP32[560624>>2]|0;
    $158 = (($157) + 28|0);
    $159 = HEAP32[$158>>2]|0;
    $160 = (($157) + 32|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = (($159) + ($161<<3)|0);
    $163 = ($164|0)==($162|0);
    if ($163) {
     label = 51;
    } else {
     $165 = (($164) + 4|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = ($166|0)==(0|0);
     if ($167) {
      label = 51;
     } else {
      $temp$0$i12 = $166;
     }
    }
   }
   if ((label|0) == 51) {
    $168 = HEAP32[$8>>2]|0;
    $169 = (__Z31ReadObjectFromPersistentManageri($168)|0);
    $temp$0$i12 = $169;
   }
   $$0$i = $temp$0$i12;
  }
  __Z22DestroyObjectHighLevelP6Objectb($$0$i,1);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($$0$i$i)) {
  HEAP8[$4>>0] = 0;
  $44 = (($4) + 1|0);
  HEAP8[$44>>0] = 0;
  __THREW__ = 0;
  HEAP32[$vararg_buffer>>2] = 651064;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 0;
  $45 = (invoke_iiii(1568,($4|0),(651048|0),($vararg_buffer|0))|0);
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if ($47) {
   $93 = ___cxa_find_matching_catch()|0;
   $94 = tempRet0;
   $95 = HEAP8[$4>>0]|0;
   $96 = $95 & 1;
   $97 = ($96<<24>>24)==(0);
   if ($97) {
    ___resumeException($93|0);
    // unreachable;
   }
   $98 = (($4) + 8|0);
   $99 = HEAP32[$98>>2]|0;
   __ZdlPv($99);
   ___resumeException($93|0);
   // unreachable;
  }
  $48 = ($45|0)==(0|0);
  if ($48) {
   $storemerge = 0;
  } else {
   $49 = (($45) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $storemerge = $50;
  }
  HEAP32[$8>>2] = $storemerge;
  $51 = HEAP8[$4>>0]|0;
  $52 = $51 & 1;
  $53 = ($52<<24>>24)==(0);
  if ($53) {
   $56 = $storemerge;
  } else {
   $54 = (($4) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   __ZdlPv($55);
   $$pre = HEAP32[$8>>2]|0;
   $56 = $$pre;
  }
  HEAP32[$2>>2] = $56;
  $57 = HEAP32[560624>>2]|0;
  $58 = ($57|0)==(0|0);
  if ($58) {
   label = 27;
  } else {
   $59 = (($57) + 36|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (($57) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($60|0)==($62|0);
   do {
    if ($63) {
     $64 = (($57) + 28|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (($57) + 32|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($65) + ($67<<3)|0);
     $84 = $68;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$57,$2);
     $69 = HEAP32[$vararg_buffer>>2]|0;
     $70 = ($69|0)==(-1);
     $71 = (($57) + 28|0);
     $72 = HEAP32[$71>>2]|0;
     if ($70) {
      $73 = (($57) + 32|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + ($74<<3)|0);
      $84 = $75;
      break;
     } else {
      $76 = (($72) + ($69<<3)|0);
      $84 = $76;
      break;
     }
    }
   } while(0);
   $77 = HEAP32[560624>>2]|0;
   $78 = (($77) + 28|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($77) + 32|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($79) + ($81<<3)|0);
   $83 = ($84|0)==($82|0);
   if ($83) {
    label = 27;
   } else {
    $85 = (($84) + 4|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==(0|0);
    if ($87) {
     label = 27;
    } else {
     $temp$0$i = $86;
    }
   }
  }
  if ((label|0) == 27) {
   $88 = HEAP32[$8>>2]|0;
   $89 = (__Z31ReadObjectFromPersistentManageri($88)|0);
   $temp$0$i = $89;
  }
  $90 = HEAP32[$temp$0$i>>2]|0;
  $91 = (($90) + 44|0);
  $92 = HEAP32[$91>>2]|0;
  FUNCTION_TABLE_vii[$92 & 4095]($temp$0$i,1);
 }
 $100 = HEAP32[$8>>2]|0;
 HEAP32[$1>>2] = $100;
 $101 = HEAP32[560624>>2]|0;
 $102 = ($101|0)==(0|0);
 if ($102) {
  label = 39;
 } else {
  $103 = (($101) + 36|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = (($101) + 4|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = ($104|0)==($106|0);
  do {
   if ($107) {
    $108 = (($101) + 28|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($101) + 32|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = (($109) + ($111<<3)|0);
    $128 = $112;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$101,$1);
    $113 = HEAP32[$vararg_buffer>>2]|0;
    $114 = ($113|0)==(-1);
    $115 = (($101) + 28|0);
    $116 = HEAP32[$115>>2]|0;
    if ($114) {
     $117 = (($101) + 32|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = (($116) + ($118<<3)|0);
     $128 = $119;
     break;
    } else {
     $120 = (($116) + ($113<<3)|0);
     $128 = $120;
     break;
    }
   }
  } while(0);
  $121 = HEAP32[560624>>2]|0;
  $122 = (($121) + 28|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = (($121) + 32|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (($123) + ($125<<3)|0);
  $127 = ($128|0)==($126|0);
  if ($127) {
   label = 39;
  } else {
   $129 = (($128) + 4|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ($130|0)==(0|0);
   if ($131) {
    label = 39;
   } else {
    $temp$0$i6 = $130;
   }
  }
 }
 if ((label|0) == 39) {
  $132 = HEAP32[$8>>2]|0;
  $133 = (__Z31ReadObjectFromPersistentManageri($132)|0);
  $temp$0$i6 = $133;
 }
 $134 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($temp$0$i6,114)|0);
 $$0 = $134;
 STACKTOP = sp;return ($$0|0);
}
function __Z10BeginsWithPKcS0_($s,$beginsWith) {
 $s = $s|0;
 $beginsWith = $beginsWith|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($beginsWith|0))|0);
 $1 = (_strncmp($s,$beginsWith,$0)|0);
 $2 = ($1|0)==(0);
 STACKTOP = sp;return ($2|0);
}
function __Z7StrICmpPKcS0_($str1,$str2) {
 $str1 = $str1|0;
 $str2 = $str2|0;
 var $$0 = 0, $$0$i = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $p1$0 = 0, $p2$0 = 0, $v$off$i = 0, $v$off$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $p1$0 = $str1;$p2$0 = $str2;
 while(1) {
  $0 = HEAP8[$p1$0>>0]|0;
  $v$off$i = (($0) + -65)<<24>>24;
  $1 = ($v$off$i&255)<(26);
  if ($1) {
   $2 = $0&255;
   $3 = $2 | 32;
   $4 = $3&255;
   $$0$i = $4;
  } else {
   $$0$i = $0;
  }
  $5 = HEAP8[$p2$0>>0]|0;
  $v$off$i1 = (($5) + -65)<<24>>24;
  $6 = ($v$off$i1&255)<(26);
  if ($6) {
   $7 = $5&255;
   $8 = $7 | 32;
   $9 = $8&255;
   $$0$i2 = $9;
  } else {
   $$0$i2 = $5;
  }
  $10 = ($$0$i<<24>>24)==($$0$i2<<24>>24);
  if (!($10)) {
   break;
  }
  $11 = (($p1$0) + 1|0);
  $12 = (($p2$0) + 1|0);
  $13 = ($$0$i<<24>>24)==(0);
  if ($13) {
   $$0 = 0;
   label = 9;
   break;
  } else {
   $p1$0 = $11;$p2$0 = $12;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return ($$0|0);
 }
 $14 = $$0$i << 24 >> 24;
 $15 = $$0$i2 << 24 >> 24;
 $16 = (($14) - ($15))|0;
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __Z6StrCmpPKcS0_($str1,$str2) {
 $str1 = $str1|0;
 $str2 = $str2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $p1$0 = 0, $p2$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $p1$0 = $str1;$p2$0 = $str2;
 while(1) {
  $0 = HEAP8[$p1$0>>0]|0;
  $1 = HEAP8[$p2$0>>0]|0;
  $2 = ($0<<24>>24)==($1<<24>>24);
  if (!($2)) {
   break;
  }
  $3 = (($p1$0) + 1|0);
  $4 = (($p2$0) + 1|0);
  $5 = ($0<<24>>24)==(0);
  if ($5) {
   $$0 = 0;
   label = 5;
   break;
  } else {
   $p1$0 = $3;$p2$0 = $4;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 $6 = $0 << 24 >> 24;
 $7 = $1 << 24 >> 24;
 $8 = (($6) - ($7))|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __Z11StringToIntPKc($s) {
 $s = $s|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_atol($s)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z14StringToUInt64PKc($s) {
 $s = $s|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strtoull($s,0,10)|0);
 $1 = tempRet0;
 tempRet0 = $1;
 STACKTOP = sp;return ($0|0);
}
function __Z11IntToStringi($agg$result,$i) {
 $agg$result = $agg$result|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $buf$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $vararg_buffer = sp;
 $buf$i = sp + 4|0;
 HEAP32[$vararg_buffer>>2] = $i;
 (_snprintf($buf$i,255,651088,$vararg_buffer)|0);
 $0 = (_strlen(($buf$i|0))|0);
 $1 = ($0>>>0)>(4294967279);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = ($0>>>0)<(11);
 if ($2) {
  $3 = $0 << 1;
  $4 = $3&255;
  HEAP8[$agg$result>>0] = $4;
  $5 = (($agg$result) + 1|0);
  $__p$0$i$i$i$i = $5;
  _memcpy(($__p$0$i$i$i$i|0),($buf$i|0),($0|0))|0;
  $12 = (($__p$0$i$i$i$i) + ($0)|0);
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $6 = (($0) + 16)|0;
  $7 = $6 & -16;
  $8 = (__Znwj($7)|0);
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $8;
  $10 = $7 | 1;
  HEAP32[$agg$result>>2] = $10;
  $11 = (($agg$result) + 4|0);
  HEAP32[$11>>2] = $0;
  $__p$0$i$i$i$i = $8;
  _memcpy(($__p$0$i$i$i$i|0),($buf$i|0),($0|0))|0;
  $12 = (($__p$0$i$i$i$i) + ($0)|0);
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __Z21UnsignedInt64ToStringy($agg$result,$0,$1) {
 $agg$result = $agg$result|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $buf$i = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $vararg_buffer = sp;
 $buf$i = sp + 8|0;
 $2 = $vararg_buffer;
 $3 = $2;
 HEAP32[$3>>2] = $0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = $1;
 (_snprintf($buf$i,255,651096,$vararg_buffer)|0);
 $6 = (_strlen(($buf$i|0))|0);
 $7 = ($6>>>0)>(4294967279);
 if ($7) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $8 = ($6>>>0)<(11);
 if ($8) {
  $9 = $6 << 1;
  $10 = $9&255;
  HEAP8[$agg$result>>0] = $10;
  $11 = (($agg$result) + 1|0);
  $__p$0$i$i$i$i = $11;
  _memcpy(($__p$0$i$i$i$i|0),($buf$i|0),($6|0))|0;
  $18 = (($__p$0$i$i$i$i) + ($6)|0);
  HEAP8[$18>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $12 = (($6) + 16)|0;
  $13 = $12 & -16;
  $14 = (__Znwj($13)|0);
  $15 = (($agg$result) + 8|0);
  HEAP32[$15>>2] = $14;
  $16 = $13 | 1;
  HEAP32[$agg$result>>2] = $16;
  $17 = (($agg$result) + 4|0);
  HEAP32[$17>>2] = $6;
  $__p$0$i$i$i$i = $14;
  _memcpy(($__p$0$i$i$i$i|0),($buf$i|0),($6|0))|0;
  $18 = (($__p$0$i$i$i$i) + ($6)|0);
  HEAP8[$18>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __Z19SimpleStringToFloatPKcPi($str,$outLength) {
 $str = $str|0;
 $outLength = $outLength|0;
 var $$lcssa = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0;
 var $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $c$off$i = 0, $c$off$i1 = 0, $c$off$i13 = 0, $c$off$i8 = 0, $negative$0$off0 = 0, $negative$1$off0 = 0;
 var $number$0$lcssa = 0.0, $number$010 = 0.0, $number$14 = 0.0, $number$2 = 0.0, $number$3 = 0.0, $p$0 = 0, $p$1$lcssa = 0, $p$19 = 0, $p$2 = 0, $p$22 = 0, $p$26 = 0, $p$3 = 0, $scaler$05 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$str>>0]|0;
 $1 = $0 << 24 >> 24;
 if ((($1|0) == 45)) {
  $negative$0$off0 = 1;
  label = 3;
 } else if ((($1|0) == 43)) {
  $negative$0$off0 = 0;
  label = 3;
 } else {
  $3 = $0;$negative$1$off0 = 0;$p$0 = $str;
 }
 if ((label|0) == 3) {
  $2 = (($str) + 1|0);
  $$pre = HEAP8[$2>>0]|0;
  $3 = $$pre;$negative$1$off0 = $negative$0$off0;$p$0 = $2;
 }
 $c$off$i8 = (($3) + -48)<<24>>24;
 $4 = ($c$off$i8&255)<(10);
 if ($4) {
  $7 = $3;$number$010 = 0.0;$p$19 = $p$0;
  while(1) {
   $5 = $number$010 * 10.0;
   $6 = $7 << 24 >> 24;
   $8 = (($6) + -48)|0;
   $9 = (+($8|0));
   $10 = $5 + $9;
   $11 = (($p$19) + 1|0);
   $12 = HEAP8[$11>>0]|0;
   $c$off$i = (($12) + -48)<<24>>24;
   $13 = ($c$off$i&255)<(10);
   if ($13) {
    $7 = $12;$number$010 = $10;$p$19 = $11;
   } else {
    $$lcssa = $12;$number$0$lcssa = $10;$p$1$lcssa = $11;
    break;
   }
  }
 } else {
  $$lcssa = $3;$number$0$lcssa = 0.0;$p$1$lcssa = $p$0;
 }
 $14 = ($$lcssa<<24>>24)==(46);
 if ($14) {
  $p$22 = (($p$1$lcssa) + 1|0);
  $15 = HEAP8[$p$22>>0]|0;
  $c$off$i13 = (($15) + -48)<<24>>24;
  $16 = ($c$off$i13&255)<(10);
  if ($16) {
   $18 = $15;$number$14 = $number$0$lcssa;$p$26 = $p$22;$scaler$05 = 0.100000000000000005551;
   while(1) {
    $17 = $18 << 24 >> 24;
    $19 = (($17) + -48)|0;
    $20 = (+($19|0));
    $21 = $scaler$05 * $20;
    $22 = $number$14 + $21;
    $23 = $scaler$05 * 0.100000000000000005551;
    $p$2 = (($p$26) + 1|0);
    $24 = HEAP8[$p$2>>0]|0;
    $c$off$i1 = (($24) + -48)<<24>>24;
    $25 = ($c$off$i1&255)<(10);
    if ($25) {
     $18 = $24;$number$14 = $22;$p$26 = $p$2;$scaler$05 = $23;
    } else {
     $number$2 = $22;$p$3 = $p$2;
     break;
    }
   }
  } else {
   $number$2 = $number$0$lcssa;$p$3 = $p$22;
  }
 } else {
  $number$2 = $number$0$lcssa;$p$3 = $p$1$lcssa;
 }
 if ($negative$1$off0) {
  $26 = -$number$2;
  $number$3 = $26;
 } else {
  $number$3 = $number$2;
 }
 $27 = ($outLength|0)==(0|0);
 if ($27) {
  $31 = Math_fround($number$3);
  STACKTOP = sp;return (Math_fround($31));
 }
 $28 = $p$3;
 $29 = $str;
 $30 = (($28) - ($29))|0;
 HEAP32[$outLength>>2] = $30;
 $31 = Math_fround($number$3);
 STACKTOP = sp;return (Math_fround($31));
}
function __Z13VFormatBufferPciPKcPi($buffer,$size,$format,$ap) {
 $buffer = $buffer|0;
 $size = $size|0;
 $format = $format|0;
 $ap = $ap|0;
 var $vacopy_currentptr = 0, $zp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $zp = sp;
 $vacopy_currentptr = HEAP32[$ap>>2]|0;
 HEAP32[$zp>>2] = $vacopy_currentptr;
 (_vsnprintf($buffer,$size,$format,$zp)|0);
 STACKTOP = sp;return;
}
function __Z6FormatPKcz($agg$result,$format,$varargs) {
 $agg$result = $agg$result|0;
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $buffer$i = 0, $va = 0, $vacopy_currentptr = 0, $zp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 10272|0;
 $zp$i = sp + 16|0;
 $buffer$i = sp + 32|0;
 $va = sp;
 HEAP32[$va>>2] = $varargs;
 $vacopy_currentptr = HEAP32[$va>>2]|0;
 HEAP32[$zp$i>>2] = $vacopy_currentptr;
 (_vsnprintf($buffer$i,10240,$format,$zp$i)|0);
 $0 = (_strlen(($buffer$i|0))|0);
 $1 = ($0>>>0)>(4294967279);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = ($0>>>0)<(11);
 if ($2) {
  $3 = $0 << 1;
  $4 = $3&255;
  HEAP8[$agg$result>>0] = $4;
  $5 = (($agg$result) + 1|0);
  $__p$0$i$i$i$i = $5;
  _memcpy(($__p$0$i$i$i$i|0),($buffer$i|0),($0|0))|0;
  $12 = (($__p$0$i$i$i$i) + ($0)|0);
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $6 = (($0) + 16)|0;
  $7 = $6 & -16;
  $8 = (__Znwj($7)|0);
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $8;
  $10 = $7 | 1;
  HEAP32[$agg$result>>2] = $10;
  $11 = (($agg$result) + 4|0);
  HEAP32[$11>>2] = $0;
  $__p$0$i$i$i$i = $8;
  _memcpy(($__p$0$i$i$i$i|0),($buffer$i|0),($0|0))|0;
  $12 = (($__p$0$i$i$i$i) + ($0)|0);
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __Z16HexStringToBytesPKcjPv($str,$bytes,$data) {
 $str = $str|0;
 $bytes = $bytes|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b$0$in = 0, $b$1 = 0, $b$1$in = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bytes|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $1 = $i$01 << 1;
  $2 = (($str) + ($1)|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3 << 24 >> 24;
  $5 = ($3<<24>>24)<(58);
  do {
   if ($5) {
    $6 = $4 << 4;
    $7 = (($6) + -768)|0;
    $b$0$in = $7;
   } else {
    $8 = ($3<<24>>24)<(91);
    $9 = $4 << 4;
    if ($8) {
     $10 = (($9) + -880)|0;
     $b$0$in = $10;
     break;
    } else {
     $11 = (($9) + 144)|0;
     $b$0$in = $11;
     break;
    }
   }
  } while(0);
  $12 = $1 | 1;
  $13 = (($str) + ($12)|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14 << 24 >> 24;
  $16 = ($14<<24>>24)<(58);
  do {
   if ($16) {
    $17 = (($15) + -48)|0;
    $18 = $b$0$in & 255;
    $19 = $17 | $18;
    $b$1$in = $19;
   } else {
    $20 = ($14<<24>>24)<(91);
    if ($20) {
     $21 = (($15) + -55)|0;
     $22 = $b$0$in & 255;
     $23 = $21 | $22;
     $b$1$in = $23;
     break;
    } else {
     $24 = (($15) + 169)|0;
     $25 = $24 | $b$0$in;
     $b$1$in = $25;
     break;
    }
   }
  } while(0);
  $b$1 = $b$1$in&255;
  $26 = (($data) + ($i$01)|0);
  HEAP8[$26>>0] = $b$1;
  $27 = (($i$01) + 1)|0;
  $exitcond = ($27|0)==($bytes|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $27;
  }
 }
 STACKTOP = sp;return;
}
function __Z6AppendPKcS0_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $0 = (_strlen(($a|0))|0);
 $1 = (_strlen(($b|0))|0);
 $2 = (($1) + ($0))|0;
 __THREW__ = 0;
 invoke_vii(3257,($agg$result|0),($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if (!($4)) {
   $5 = HEAP8[$agg$result>>0]|0;
   $6 = $5 & 1;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $12 = 10;$14 = $5;
   } else {
    $8 = HEAP32[$agg$result>>2]|0;
    $9 = $8 & -2;
    $phitmp$i$i = (($9) + -1)|0;
    $10 = $8&255;
    $12 = $phitmp$i$i;$14 = $10;
   }
   $11 = ($12>>>0)<($0>>>0);
   $13 = $14 & 1;
   $15 = ($13<<24>>24)==(0);
   do {
    if ($11) {
     if ($15) {
      $29 = $14&255;
      $30 = $29 >>> 1;
      $32 = $30;
     } else {
      $27 = (($agg$result) + 4|0);
      $28 = HEAP32[$27>>2]|0;
      $32 = $28;
     }
     $31 = (($0) - ($12))|0;
     __THREW__ = 0;
     invoke_viiiiiiii(29,($agg$result|0),($12|0),($31|0),($32|0),0,($32|0),($0|0),($a|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break L1;
     }
    } else {
     if ($15) {
      $18 = (($agg$result) + 1|0);
      $19 = $18;
     } else {
      $16 = (($agg$result) + 8|0);
      $17 = HEAP32[$16>>2]|0;
      $19 = $17;
     }
     _memmove(($19|0),($a|0),($0|0))|0;
     $20 = (($19) + ($0)|0);
     HEAP8[$20>>0] = 0;
     $21 = HEAP8[$agg$result>>0]|0;
     $22 = $21 & 1;
     $23 = ($22<<24>>24)==(0);
     if ($23) {
      $25 = $0 << 1;
      $26 = $25&255;
      HEAP8[$agg$result>>0] = $26;
      break;
     } else {
      $24 = (($agg$result) + 4|0);
      HEAP32[$24>>2] = $0;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   (invoke_iiii(1480,($agg$result|0),($b|0),($1|0))|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 $39 = HEAP8[$agg$result>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  ___resumeException($37|0);
  // unreachable;
 }
 $42 = (($agg$result) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 __ZdlPv($43);
 ___resumeException($37|0);
 // unreachable;
}
function __Z6AppendRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKc($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $0 = (_strlen(($b|0))|0);
 $1 = HEAP8[$a>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $9 = $7;
 } else {
  $4 = (($a) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $9 = $5;
 }
 $8 = (($9) + ($0))|0;
 __THREW__ = 0;
 invoke_vii(3257,($agg$result|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L5: do {
  if (!($11)) {
   $12 = HEAP8[$a>>0]|0;
   $13 = $12 & 1;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $19 = (($a) + 1|0);
    $20 = $12&255;
    $21 = $20 >>> 1;
    $30 = $21;$38 = $19;
   } else {
    $15 = (($a) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($a) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $30 = $18;$38 = $16;
   }
   $22 = HEAP8[$agg$result>>0]|0;
   $23 = $22 & 1;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    $29 = 10;$32 = $22;
   } else {
    $25 = HEAP32[$agg$result>>2]|0;
    $26 = $25 & -2;
    $phitmp$i$i$i = (($26) + -1)|0;
    $27 = $25&255;
    $29 = $phitmp$i$i$i;$32 = $27;
   }
   $28 = ($29>>>0)<($30>>>0);
   $31 = $32 & 1;
   $33 = ($31<<24>>24)==(0);
   do {
    if ($28) {
     if ($33) {
      $48 = $32&255;
      $49 = $48 >>> 1;
      $51 = $49;
     } else {
      $46 = (($agg$result) + 4|0);
      $47 = HEAP32[$46>>2]|0;
      $51 = $47;
     }
     $50 = (($30) - ($29))|0;
     __THREW__ = 0;
     invoke_viiiiiiii(29,($agg$result|0),($29|0),($50|0),($51|0),0,($51|0),($30|0),($38|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break L5;
     }
    } else {
     if ($33) {
      $36 = (($agg$result) + 1|0);
      $37 = $36;
     } else {
      $34 = (($agg$result) + 8|0);
      $35 = HEAP32[$34>>2]|0;
      $37 = $35;
     }
     _memmove(($37|0),($38|0),($30|0))|0;
     $39 = (($37) + ($30)|0);
     HEAP8[$39>>0] = 0;
     $40 = HEAP8[$agg$result>>0]|0;
     $41 = $40 & 1;
     $42 = ($41<<24>>24)==(0);
     if ($42) {
      $44 = $30 << 1;
      $45 = $44&255;
      HEAP8[$agg$result>>0] = $45;
      break;
     } else {
      $43 = (($agg$result) + 4|0);
      HEAP32[$43>>2] = $30;
      break;
     }
    }
   } while(0);
   __THREW__ = 0;
   (invoke_iiii(1480,($agg$result|0),($b|0),($0|0))|0);
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if (!($55)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 $58 = HEAP8[$agg$result>>0]|0;
 $59 = $58 & 1;
 $60 = ($59<<24>>24)==(0);
 if ($60) {
  ___resumeException($56|0);
  // unreachable;
 }
 $61 = (($agg$result) + 8|0);
 $62 = HEAP32[$61>>2]|0;
 __ZdlPv($62);
 ___resumeException($56|0);
 // unreachable;
}
function __Z17GetNumericVersionPKc($versionCString) {
 $versionCString = $versionCString|0;
 var $$0 = 0, $$off = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $fix$0 = 0;
 var $fix$1 = 0, $major$0 = 0, $minor$0 = 0, $minor$1 = 0, $release$0 = 0, $spos$0 = 0, $spos$1 = 0, $spos$2 = 0, $type$0 = 0, $version$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$versionCString>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $0 << 24 >> 24;
 $3 = (($versionCString) + 1|0);
 $4 = (($2) + -48)|0;
 $5 = HEAP8[$3>>0]|0;
 $$off = (($5) + -48)<<24>>24;
 $6 = ($$off&255)<(9);
 if ($6) {
  $7 = $5 << 24 >> 24;
  $8 = ($4*10)|0;
  $9 = (($versionCString) + 2|0);
  $10 = (($8) + -48)|0;
  $11 = (($10) + ($7))|0;
  $$pre = HEAP8[$9>>0]|0;
  $72 = $$pre;$major$0 = $11;$spos$0 = $9;
 } else {
  $72 = $5;$major$0 = $4;$spos$0 = $3;
 }
 if ((($72<<24>>24) == 46)) {
  $12 = (($spos$0) + 1|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $fix$1 = 0;$minor$1 = 0;$release$0 = 0;$type$0 = 114;
  } else {
   $15 = (($spos$0) + 2|0);
   $16 = $13 << 24 >> 24;
   $17 = (($16) + -48)|0;
   $$pre1 = HEAP8[$15>>0]|0;
   $73 = $$pre1;$minor$0 = $17;$spos$1 = $15;
   label = 7;
  }
 } else if ((($72<<24>>24) == 0)) {
  $fix$1 = 0;$minor$1 = 0;$release$0 = 0;$type$0 = 114;
 } else {
  $73 = $72;$minor$0 = 0;$spos$1 = $spos$0;
  label = 7;
 }
 do {
  if ((label|0) == 7) {
   if ((($73<<24>>24) == 46)) {
    $18 = (($spos$1) + 1|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     $fix$1 = 0;$minor$1 = $minor$0;$release$0 = 0;$type$0 = 114;
     break;
    }
    $21 = (($spos$1) + 2|0);
    $22 = $19 << 24 >> 24;
    $23 = (($22) + -48)|0;
    $$pre2 = HEAP8[$21>>0]|0;
    $25 = $$pre2;$fix$0 = $23;$spos$2 = $21;
   } else if ((($73<<24>>24) == 0)) {
    $fix$1 = 0;$minor$1 = $minor$0;$release$0 = 0;$type$0 = 114;
    break;
   } else {
    $25 = $73;$fix$0 = 0;$spos$2 = $spos$1;
   }
   $24 = ($25<<24>>24)==(0);
   if ($24) {
    $fix$1 = $fix$0;$minor$1 = $minor$0;$release$0 = 0;$type$0 = 114;
   } else {
    $26 = (($spos$2) + 1|0);
    $27 = $25 << 24 >> 24;
    $28 = HEAP8[$26>>0]|0;
    $29 = ($28<<24>>24)==(0);
    if ($29) {
     $fix$1 = $fix$0;$minor$1 = $minor$0;$release$0 = 0;$type$0 = $27;
    } else {
     $30 = (($spos$2) + 2|0);
     $31 = $28 << 24 >> 24;
     $32 = (($31) + -48)|0;
     $33 = HEAP8[$30>>0]|0;
     $34 = ($33<<24>>24)==(0);
     if ($34) {
      $fix$1 = $fix$0;$minor$1 = $minor$0;$release$0 = $32;$type$0 = $27;
     } else {
      $35 = ($32*10)|0;
      $36 = (($spos$2) + 3|0);
      $37 = $33 << 24 >> 24;
      $38 = (($35) + -48)|0;
      $39 = (($38) + ($37))|0;
      $40 = HEAP8[$36>>0]|0;
      $41 = ($40<<24>>24)==(0);
      if ($41) {
       $fix$1 = $fix$0;$minor$1 = $minor$0;$release$0 = $39;$type$0 = $27;
      } else {
       $42 = ($39*10)|0;
       $43 = $40 << 24 >> 24;
       $44 = (($42) + -48)|0;
       $45 = (($44) + ($43))|0;
       $fix$1 = $fix$0;$minor$1 = $minor$0;$release$0 = $45;$type$0 = $27;
      }
     }
    }
   }
  }
 } while(0);
 $46 = (($major$0|0) / 10)&-1;
 $47 = (($46|0) % 10)&-1;
 $48 = $47 << 28;
 $49 = (($major$0|0) % 10)&-1;
 $50 = $49 << 24;
 $51 = $50 | $48;
 $52 = (($minor$1|0) % 10)&-1;
 $53 = $52 << 20;
 $54 = $51 | $53;
 $55 = (($fix$1|0) % 10)&-1;
 $56 = $55 << 16;
 $57 = $54 | $56;
 switch ($type$0|0) {
 case 100: case 68:  {
  $58 = $57 | 8192;
  $version$0 = $58;
  break;
 }
 case 97: case 65:  {
  $59 = $57 | 16384;
  $version$0 = $59;
  break;
 }
 case 98: case 66:  {
  $60 = $57 | 24576;
  $version$0 = $60;
  break;
 }
 case 114: case 102: case 82: case 70:  {
  $61 = $57 | 32768;
  $version$0 = $61;
  break;
 }
 default: {
  $version$0 = $57;
 }
 }
 $62 = (($release$0|0) / 100)&-1;
 $63 = (($62|0) % 10)&-1;
 $64 = $63 << 8;
 $65 = $64 | $version$0;
 $66 = (($release$0|0) / 10)&-1;
 $67 = (($66|0) % 10)&-1;
 $68 = $67 << 4;
 $69 = $65 | $68;
 $70 = (($release$0|0) % 10)&-1;
 $71 = $69 | $70;
 $$0 = $71;
 STACKTOP = sp;return ($$0|0);
}
function __Z5SplitRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEcRNS_6vectorIS5_NS3_IS5_EEEEi($s,$splitChar,$parts,$maxSplits) {
 $s = $s|0;
 $splitChar = $splitChar|0;
 $parts = $parts|0;
 $maxSplits = $maxSplits|0;
 var $$0 = 0, $$01 = 0, $$0219 = 0, $$1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $n$0$lcssa = 0, $n$020 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = ($maxSplits|0)==(1);
 L1: do {
  if ($2) {
   $n$0$lcssa = 0;
  } else {
   $3 = (($s) + 1|0);
   $4 = $splitChar&255;
   $5 = (($parts) + 4|0);
   $6 = (($parts) + 8|0);
   $7 = (($1) + 8|0);
   $8 = (($1) + 4|0);
   $9 = (($s) + 8|0);
   $10 = (($s) + 4|0);
   $$0219 = $maxSplits;$n$020 = 0;
   L3: while(1) {
    $11 = HEAP8[$s>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if ($13) {
     $15 = $11&255;
     $16 = $15 >>> 1;
     $18 = $16;
    } else {
     $14 = HEAP32[$10>>2]|0;
     $18 = $14;
    }
    $17 = ($18>>>0)>($n$020>>>0);
    if (!($17)) {
     $n$0$lcssa = $n$020;
     break L1;
    }
    if ($13) {
     $21 = $3;
    } else {
     $19 = HEAP32[$9>>2]|0;
     $21 = $19;
    }
    $20 = (($21) + ($n$020)|0);
    $22 = (($18) - ($n$020))|0;
    $23 = (_memchr($20,$4,$22)|0);
    $24 = ($23|0)==(0|0);
    if ($24) {
     $n$0$lcssa = $n$020;
     break L1;
    }
    $25 = $23;
    $26 = $21;
    $27 = (($25) - ($26))|0;
    $28 = ($27|0)==(-1);
    if ($28) {
     $n$0$lcssa = $n$020;
     break L1;
    }
    $83 = ($27>>>0)>($n$020>>>0);
    if ($83) {
     $84 = (($27) - ($n$020))|0;
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($1,$s,$n$020,$84,0);
     $85 = HEAP32[$5>>2]|0;
     $86 = HEAP32[$6>>2]|0;
     $87 = ($85|0)==($86|0);
     if ($87) {
      __THREW__ = 0;
      invoke_vii(2523,($parts|0),($1|0));
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       label = 51;
       break;
      }
     } else {
      $88 = ($85|0)==(0|0);
      do {
       if (!($88)) {
        $89 = HEAP8[$1>>0]|0;
        $90 = $89 & 1;
        $91 = ($90<<24>>24)==(0);
        if ($91) {
         ;HEAP32[$85+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$1+8>>2]|0;
         break;
        }
        $92 = HEAP32[$7>>2]|0;
        $93 = HEAP32[$8>>2]|0;
        $94 = ($93>>>0)>(4294967279);
        if ($94) {
         label = 39;
         break L3;
        }
        $97 = ($93>>>0)<(11);
        if ($97) {
         $98 = $93 << 1;
         $99 = $98&255;
         HEAP8[$85>>0] = $99;
         $100 = (($85) + 1|0);
         $__p$0$i$i$i$i$i9 = $100;
        } else {
         $101 = (($93) + 16)|0;
         $102 = $101 & -16;
         __THREW__ = 0;
         $103 = (invoke_ii(2988,($102|0))|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 51;
          break L3;
         }
         $106 = (($85) + 8|0);
         HEAP32[$106>>2] = $103;
         $107 = $102 | 1;
         HEAP32[$85>>2] = $107;
         $108 = (($85) + 4|0);
         HEAP32[$108>>2] = $93;
         $__p$0$i$i$i$i$i9 = $103;
        }
        _memcpy(($__p$0$i$i$i$i$i9|0),($92|0),($93|0))|0;
        $109 = (($__p$0$i$i$i$i$i9) + ($93)|0);
        HEAP8[$109>>0] = 0;
       }
      } while(0);
      $110 = HEAP32[$5>>2]|0;
      $111 = (($110) + 12|0);
      HEAP32[$5>>2] = $111;
     }
     $114 = HEAP8[$1>>0]|0;
     $115 = $114 & 1;
     $116 = ($115<<24>>24)==(0);
     if (!($116)) {
      $117 = HEAP32[$7>>2]|0;
      __ZdlPv($117);
     }
     $118 = (($$0219) + -1)|0;
     $$1 = $118;
    } else {
     $$1 = $$0219;
    }
    $127 = (($27) + 1)|0;
    $128 = ($$1|0)==(1);
    if ($128) {
     $n$0$lcssa = $127;
     break L1;
    } else {
     $$0219 = $$1;$n$020 = $127;
    }
   }
   do {
    if ((label|0) == 39) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      $121 = ___cxa_find_matching_catch()|0;
      $122 = tempRet0;
      $124 = $89;$lpad$phi$index = $121;$lpad$phi$index2 = $122;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 51) {
     $119 = ___cxa_find_matching_catch()|0;
     $120 = tempRet0;
     $$pre = HEAP8[$1>>0]|0;
     $124 = $$pre;$lpad$phi$index = $119;$lpad$phi$index2 = $120;
    }
   } while(0);
   $123 = $124 & 1;
   $125 = ($123<<24>>24)==(0);
   if ($125) {
    $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
    ___resumeException($$01|0);
    // unreachable;
   }
   $126 = HEAP32[$7>>2]|0;
   __ZdlPv($126);
   $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $29 = HEAP8[$s>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $34 = $29&255;
  $35 = $34 >>> 1;
  $37 = $35;
 } else {
  $32 = (($s) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $37 = $33;
 }
 $36 = ($n$0$lcssa>>>0)<($37>>>0);
 if (!($36)) {
  STACKTOP = sp;return;
 }
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($0,$s,$n$0$lcssa,-1,0);
 $38 = (($parts) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($parts) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)==($41|0);
 L56: do {
  if ($42) {
   __THREW__ = 0;
   invoke_vii(2523,($parts|0),($0|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 31;
   } else {
    label = 29;
   }
  } else {
   $43 = ($39|0)==(0|0);
   do {
    if (!($43)) {
     $44 = HEAP8[$0>>0]|0;
     $45 = $44 & 1;
     $46 = ($45<<24>>24)==(0);
     if ($46) {
      ;HEAP32[$39+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$0+8>>2]|0;
      break;
     }
     $47 = (($0) + 8|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($0) + 4|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($50>>>0)>(4294967279);
     if ($51) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 31;
       break L56;
      }
      // unreachable;
     }
     $54 = ($50>>>0)<(11);
     if ($54) {
      $55 = $50 << 1;
      $56 = $55&255;
      HEAP8[$39>>0] = $56;
      $57 = (($39) + 1|0);
      $__p$0$i$i$i$i$i = $57;
     } else {
      $58 = (($50) + 16)|0;
      $59 = $58 & -16;
      __THREW__ = 0;
      $60 = (invoke_ii(2988,($59|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 31;
       break L56;
      }
      $63 = (($39) + 8|0);
      HEAP32[$63>>2] = $60;
      $64 = $59 | 1;
      HEAP32[$39>>2] = $64;
      $65 = (($39) + 4|0);
      HEAP32[$65>>2] = $50;
      $__p$0$i$i$i$i$i = $60;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($48|0),($50|0))|0;
     $66 = (($__p$0$i$i$i$i$i) + ($50)|0);
     HEAP8[$66>>0] = 0;
    }
   } while(0);
   $67 = HEAP32[$38>>2]|0;
   $68 = (($67) + 12|0);
   HEAP32[$38>>2] = $68;
   label = 29;
  }
 } while(0);
 if ((label|0) == 29) {
  $71 = HEAP8[$0>>0]|0;
  $72 = $71 & 1;
  $73 = ($72<<24>>24)==(0);
  if ($73) {
   STACKTOP = sp;return;
  }
  $74 = (($0) + 8|0);
  $75 = HEAP32[$74>>2]|0;
  __ZdlPv($75);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 31) {
  $76 = ___cxa_find_matching_catch()|0;
  $77 = tempRet0;
  $78 = HEAP8[$0>>0]|0;
  $79 = $78 & 1;
  $80 = ($79<<24>>24)==(0);
  if ($80) {
   $$0 = $77;$$01 = $76;
   ___resumeException($$01|0);
   // unreachable;
  }
  $81 = (($0) + 8|0);
  $82 = HEAP32[$81>>2]|0;
  __ZdlPv($82);
  $$0 = $77;$$01 = $76;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN17UniqueIDGeneratorC2E10MemLabelId($this,$memLabel) {
 $this = $this|0;
 $memLabel = $memLabel|0;
 var $$byval_copy2 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$memLabel>>2]|0;
 HEAP32[$this>>2] = 0;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 12|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$2>>2] = $3;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy2|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$this>>2] = 0;
  HEAP32[$5>>2] = 1;
  HEAP32[$6>>2] = 1;
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$1>>2] = $9;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $10 = (invoke_iiiiiiii(108,(0|0),4,4,($$byval_copy2|0),0,(651104|0),370)|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   HEAP32[$this>>2] = $10;
   $$pre$i$i = HEAP32[$5>>2]|0;
   $phitmp = (($$pre$i$i) + -1)|0;
   $13 = (($10) + ($phitmp<<2)|0);
   HEAP32[$13>>2] = 2;
   $14 = (($this) + 16|0);
   HEAP32[$14>>2] = 1;
   STACKTOP = sp;return;
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $17 = HEAP32[$6>>2]|0;
 $18 = ($17|0)>(-1);
 if (!($18)) {
  ___resumeException($15|0);
  // unreachable;
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = $20;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($19|0),($$byval_copy2|0));
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 if ($22) {
  $23 = ___cxa_find_matching_catch(0|0)|0;
  $24 = tempRet0;
  ___clang_call_terminate($23);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($15|0);
 // unreachable;
}
function __ZN17UniqueIDGenerator10AllocateIDEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  $$pre1 = HEAP32[$this>>2]|0;
  $33 = $$pre1;$34 = $2;
  $32 = (($33) + ($34<<2)|0);
  $35 = HEAP32[$32>>2]|0;
  HEAP32[$1>>2] = $35;
  STACKTOP = sp;return ($34|0);
 }
 $6 = (($2) + 1)|0;
 HEAP32[$3>>2] = $6;
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($6>>>0)>($9>>>0);
 if ($10) {
  $11 = $8 << 1;
  $12 = ($11|0)==(0);
  $13 = $12 ? 1 : $11;
  $14 = ($9>>>0)<($13>>>0);
  do {
   if ($14) {
    $15 = ($8|0)>(-1);
    if ($15) {
     HEAP32[$7>>2] = $13;
     $16 = HEAP32[$this>>2]|0;
     $17 = $13 << 2;
     $18 = (($this) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$0>>2] = $19;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($16,$17,4,$$byval_copy1,0,651104,370)|0);
     HEAP32[$this>>2] = $20;
     break;
    } else {
     $21 = $13 << 2;
     $22 = (($this) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,4,$$byval_copy1,0,651104,352)|0);
     $25 = HEAP32[$this>>2]|0;
     $26 = HEAP32[$3>>2]|0;
     $27 = $26 << 2;
     _memcpy(($24|0),($25|0),($27|0))|0;
     HEAP32[$7>>2] = $13;
     HEAP32[$this>>2] = $24;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$3>>2]|0;
  $29 = $$pre$i$i;
 } else {
  $29 = $6;
 }
 $28 = (($29) + -1)|0;
 $30 = HEAP32[$this>>2]|0;
 $31 = (($30) + ($28<<2)|0);
 HEAP32[$31>>2] = $6;
 $$pre = HEAP32[$1>>2]|0;
 $33 = $30;$34 = $$pre;
 $32 = (($33) + ($34<<2)|0);
 $35 = HEAP32[$32>>2]|0;
 HEAP32[$1>>2] = $35;
 STACKTOP = sp;return ($34|0);
}
function __ZN17UniqueIDGenerator8RemoveIDEj($this,$_ID) {
 $this = $this|0;
 $_ID = $_ID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + ($_ID<<2)|0);
 HEAP32[$3>>2] = $1;
 HEAP32[$0>>2] = $_ID;
 STACKTOP = sp;return;
}
function __ZN35RegisterRuntimeInitializeAndCleanupC2EPFvvES1_i($this,$Initialize,$Cleanup,$order) {
 $this = $this|0;
 $Initialize = $Initialize|0;
 $Cleanup = $Cleanup|0;
 $order = $order|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[651112>>2]|0;
 $1 = ($0|0)>(99);
 if ($1) {
  _exit(-1);
  // unreachable;
 } else {
  $2 = ((651120 + ($0<<4)|0) + 4|0);
  HEAP32[$2>>2] = $Initialize;
  $3 = ((651120 + ($0<<4)|0) + 8|0);
  HEAP32[$3>>2] = $Cleanup;
  $4 = (651120 + ($0<<4)|0);
  HEAP32[$4>>2] = $order;
  $5 = ((651120 + ($0<<4)|0) + 12|0);
  HEAP8[$5>>0] = 0;
  $6 = (($0) + 1)|0;
  HEAP32[651112>>2] = $6;
  STACKTOP = sp;return;
 }
}
function __ZN35RegisterRuntimeInitializeAndCleanup22ExecuteInitializationsEv() {
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[651112>>2]|0;
 $2 = (651120 + ($1<<4)|0);
 __ZNSt3__16__sortIRNS_6__lessI15OrderedCallbackS2_EEPS2_EEvT0_S6_T_(651120,$2,$0);
 $3 = HEAP32[651112>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $14 = $3;$i$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $5 = ((651120 + ($i$01<<4)|0) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = $14;
  } else {
   $8 = ((651120 + ($i$01<<4)|0) + 12|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    FUNCTION_TABLE_v[$6 & 1023]();
    HEAP8[$8>>0] = 1;
    $$pre = HEAP32[651112>>2]|0;
    $13 = $$pre;
   } else {
    $13 = $14;
   }
  }
  $11 = (($i$01) + 1)|0;
  $12 = ($11|0)<($13|0);
  if ($12) {
   $14 = $13;$i$01 = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRNS_6__lessI15OrderedCallbackS2_EEPS2_EEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$027 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0;
 var $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i23 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -16|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 4;
   switch ($4|0) {
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 71;
    break L1;
    break;
   }
   default: {
   }
   }
   $37 = ($3|0)<(496);
   if ($37) {
    label = 21;
    break L1;
   }
   $38 = ($3|0)>(15984);
   $39 = (($4|0) / 2)&-1;
   $40 = (($$0) + ($39<<4)|0);
   do {
    if ($38) {
     $41 = (($4|0) / 4)&-1;
     $42 = (($$0) + ($41<<4)|0);
     $$sum = (($41) + ($39))|0;
     $43 = (($$0) + ($$sum<<4)|0);
     $44 = (__ZNSt3__17__sort4IRNS_6__lessI15OrderedCallbackS2_EEPS2_EEjT0_S6_S6_S6_T_($$0,$42,$40,$43,0)|0);
     $45 = HEAP32[$1>>2]|0;
     $46 = HEAP32[$43>>2]|0;
     $47 = ($45|0)<($46|0);
     if (!($47)) {
      $$pre$phiZ2D = $40;$__n_swaps$0 = $44;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$43+12>>2]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$1+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $48 = HEAP32[$43>>2]|0;
     $49 = HEAP32[$40>>2]|0;
     $50 = ($48|0)<($49|0);
     if (!($50)) {
      $51 = (($44) + 1)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $51;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$43+12>>2]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $52 = HEAP32[$40>>2]|0;
     $53 = HEAP32[$42>>2]|0;
     $54 = ($52|0)<($53|0);
     if (!($54)) {
      $55 = (($44) + 2)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $55;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$42+12>>2]|0;
     ;HEAP32[$42+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $56 = HEAP32[$42>>2]|0;
     $57 = HEAP32[$$0>>2]|0;
     $58 = ($56|0)<($57|0);
     if ($58) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$42+12>>2]|0;
      ;HEAP32[$42+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $60 = (($44) + 4)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $60;
      break;
     } else {
      $59 = (($44) + 3)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $59;
      break;
     }
    } else {
     $61 = HEAP32[$40>>2]|0;
     $62 = HEAP32[$$0>>2]|0;
     $63 = ($61|0)<($62|0);
     $64 = HEAP32[$1>>2]|0;
     $65 = ($64|0)<($61|0);
     if (!($63)) {
      if (!($65)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 0;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $66 = HEAP32[$40>>2]|0;
      $67 = HEAP32[$$0>>2]|0;
      $68 = ($66|0)<($67|0);
      if (!($68)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
      break;
     }
     if ($65) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
     ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $69 = HEAP32[$1>>2]|0;
     $70 = HEAP32[$40>>2]|0;
     $71 = ($69|0)<($70|0);
     if ($71) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $72 = HEAP32[$$0>>2]|0;
   $73 = HEAP32[$$pre$phiZ2D>>2]|0;
   $74 = ($72|0)<($73|0);
   do {
    if ($74) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $75 = (($__j$0) + -16|0);
      $76 = ($$0|0)==($75|0);
      if ($76) {
       break;
      }
      $94 = HEAP32[$75>>2]|0;
      $95 = ($94|0)<($73|0);
      if ($95) {
       label = 54;
       break;
      } else {
       $__j$0 = $75;
      }
     }
     if ((label|0) == 54) {
      label = 0;
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$75+12>>2]|0;
      ;HEAP32[$75+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $96 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $75;$__n_swaps$3 = $96;
      break;
     }
     $77 = (($$0) + 16|0);
     $78 = HEAP32[$1>>2]|0;
     $79 = ($72|0)<($78|0);
     if ($79) {
      $__i$1 = $77;
     } else {
      $80 = ($77|0)==($1|0);
      if ($80) {
       label = 71;
       break L1;
      } else {
       $__i$027 = $77;
      }
      while(1) {
       $83 = HEAP32[$__i$027>>2]|0;
       $84 = ($72|0)<($83|0);
       $82 = (($__i$027) + 16|0);
       if ($84) {
        break;
       }
       $81 = ($82|0)==($1|0);
       if ($81) {
        label = 71;
        break L1;
       } else {
        $__i$027 = $82;
       }
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$027+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$027+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$027+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$027+12>>2]|0;
      ;HEAP32[$__i$027+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$027+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$027+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$027+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $__i$1 = $82;
     }
     $85 = ($__i$1|0)==($1|0);
     if ($85) {
      label = 71;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $86 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $87 = HEAP32[$__i$2>>2]|0;
       $88 = ($86|0)<($87|0);
       $89 = (($__i$2) + 16|0);
       if ($88) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $89;
       }
      }
      while(1) {
       $90 = (($__j$2) + -16|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($86|0)<($91|0);
       if ($92) {
        $__j$2 = $90;
       } else {
        break;
       }
      }
      $93 = ($__i$2>>>0)<($90>>>0);
      if (!($93)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$2+12>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$90+12>>2]|0;
      ;HEAP32[$90+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $__i$2$ph = $89;$__j$1$ph = $90;
     }
    }
   } while(0);
   $97 = (($$0) + 16|0);
   $98 = ($97>>>0)<($__j$3>>>0);
   L55: do {
    if ($98) {
     $__i$3$ph = $97;$__j$4$ph = $__j$3;$__m$0$ph = $40;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $99 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $100 = HEAP32[$__i$3>>2]|0;
       $101 = ($100|0)<($99|0);
       $102 = (($__i$3) + 16|0);
       if ($101) {
        $__i$3 = $102;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $103 = (($__j$5) + -16|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ($104|0)<($99|0);
       if ($105) {
        break;
       } else {
        $__j$5 = $103;
       }
      }
      $106 = ($__i$3>>>0)>($103>>>0);
      if ($106) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L55;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$3+12>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$103+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$103+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$103+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$103+12>>2]|0;
      ;HEAP32[$103+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $107 = (($__n_swaps$4$ph) + 1)|0;
      $108 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $108 ? $103 : $__m$0$ph;
      $__i$3$ph = $102;$__j$4$ph = $103;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $107;
     }
    } else {
     $__i$4 = $97;$__m$2 = $40;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $109 = ($__i$4|0)==($__m$2|0);
   if ($109) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $110 = HEAP32[$__m$2>>2]|0;
    $111 = HEAP32[$__i$4>>2]|0;
    $112 = ($110|0)<($111|0);
    if ($112) {
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$4+12>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $113 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $113;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $114 = ($__n_swaps$6|0)==(0);
   if ($114) {
    $115 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI15OrderedCallbackS2_EEPS2_EEbT0_S6_T_($$0,$__i$4,0)|0);
    $116 = (($__i$4) + 16|0);
    $117 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI15OrderedCallbackS2_EEPS2_EEbT0_S6_T_($116,$$01$ph,0)|0);
    if ($117) {
     label = 66;
     break;
    }
    if ($115) {
     $$0 = $116;
     continue;
    }
   }
   $118 = $__i$4;
   $119 = (($118) - ($2))|0;
   $120 = (($0) - ($118))|0;
   $121 = ($119|0)<($120|0);
   if (!($121)) {
    label = 70;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessI15OrderedCallbackS2_EEPS2_EEvT0_S6_T_($$0,$__i$4,$__comp);
   $122 = (($__i$4) + 16|0);
   $$0 = $122;
  }
  if ((label|0) == 66) {
   label = 0;
   if ($115) {
    label = 71;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 70) {
   label = 0;
   $123 = (($__i$4) + 16|0);
   __ZNSt3__16__sortIRNS_6__lessI15OrderedCallbackS2_EEPS2_EEvT0_S6_T_($123,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $8 = (($$0) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$$0>>2]|0;
  $11 = ($9|0)<($10|0);
  $12 = HEAP32[$1>>2]|0;
  $13 = ($12|0)<($9|0);
  if (!($11)) {
   if (!($13)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   $14 = HEAP32[$8>>2]|0;
   $15 = HEAP32[$$0>>2]|0;
   $16 = ($14|0)<($15|0);
   if (!($16)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   STACKTOP = sp;return;
  }
  if ($13) {
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $17 = HEAP32[$1>>2]|0;
  $18 = HEAP32[$8>>2]|0;
  $19 = ($17|0)<($18|0);
  if (!($19)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $20 = (($$0) + 16|0);
  $21 = (($$0) + 32|0);
  (__ZNSt3__17__sort4IRNS_6__lessI15OrderedCallbackS2_EEPS2_EEjT0_S6_S6_S6_T_($$0,$20,$21,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $22 = (($$0) + 16|0);
  $23 = (($$0) + 32|0);
  $24 = (($$0) + 48|0);
  (__ZNSt3__17__sort4IRNS_6__lessI15OrderedCallbackS2_EEPS2_EEjT0_S6_S6_S6_T_($$0,$22,$23,$24,0)|0);
  $25 = HEAP32[$1>>2]|0;
  $26 = HEAP32[$24>>2]|0;
  $27 = ($25|0)<($26|0);
  if (!($27)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $28 = HEAP32[$24>>2]|0;
  $29 = HEAP32[$23>>2]|0;
  $30 = ($28|0)<($29|0);
  if (!($30)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$23+12>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $31 = HEAP32[$23>>2]|0;
  $32 = HEAP32[$22>>2]|0;
  $33 = ($31|0)<($32|0);
  if (!($33)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $34 = HEAP32[$22>>2]|0;
  $35 = HEAP32[$$0>>2]|0;
  $36 = ($34|0)<($35|0);
  if (!($36)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IRNS_6__lessI15OrderedCallbackS2_EEPS2_EEvT0_S6_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 71) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRNS_6__lessI15OrderedCallbackS2_EEPS2_EEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i2 = sp;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3|0)<($0|0);
 do {
  if ($2) {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
    ;HEAP32[$__x1+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $$0$i = 1;
    break;
   }
   ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
   ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
   ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
   $8 = HEAP32[$__x3>>2]|0;
   $9 = HEAP32[$__x2>>2]|0;
   $10 = ($8|0)<($9|0);
   if ($10) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $5 = HEAP32[$__x2>>2]|0;
    $6 = HEAP32[$__x1>>2]|0;
    $7 = ($5|0)<($6|0);
    if ($7) {
     ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
     ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
     ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $11 = HEAP32[$__x4>>2]|0;
 $12 = HEAP32[$__x3>>2]|0;
 $13 = ($11|0)<($12|0);
 if (!($13)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x3+12>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $14 = (($$0$i) + 1)|0;
 $15 = HEAP32[$__x3>>2]|0;
 $16 = HEAP32[$__x2>>2]|0;
 $17 = ($15|0)<($16|0);
 if (!($17)) {
  $__r$0 = $14;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $18 = (($$0$i) + 2)|0;
 $19 = HEAP32[$__x2>>2]|0;
 $20 = HEAP32[$__x1>>2]|0;
 $21 = ($19|0)<($20|0);
 if (!($21)) {
  $__r$0 = $18;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $22 = (($$0$i) + 3)|0;
 $__r$0 = $22;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_6__lessI15OrderedCallbackS2_EEPS2_EEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i = 0, $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4$i = sp + 16|0;
 $__t$sroa$1 = sp;
 $0 = (($__first) + 32|0);
 $1 = (($__first) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = ($2|0)<($3|0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5|0)<($2|0);
 do {
  if ($4) {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    break;
   }
   ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
   $9 = HEAP32[$1>>2]|0;
   $10 = ($5|0)<($9|0);
   if ($10) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
   }
  } else {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    $7 = HEAP32[$1>>2]|0;
    $8 = ($7|0)<($3|0);
    if ($8) {
     ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    }
   }
  }
 } while(0);
 $11 = (($__first) + 48|0);
 $12 = ($11|0)==($__last|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $__i$02 = $11;$__j$01 = $0;
 while(1) {
  $13 = HEAP32[$__i$02>>2]|0;
  $14 = HEAP32[$__j$01>>2]|0;
  $15 = ($13|0)<($14|0);
  if ($15) {
   $16 = (($__i$02) + 4|0);
   ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$16+8>>2]|0;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;
    $17 = ($__k$0|0)==($__first|0);
    if ($17) {
     $__k$0$lcssa = $__first;
     break;
    }
    $18 = (($__k$0) + -16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($13|0)<($19|0);
    if ($20) {
     $__j$1$phi = $__k$0;$__k$0 = $18;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAP32[$__k$0$lcssa>>2] = $13;
   $21 = (($__k$0$lcssa) + 4|0);
   ;HEAP32[$21+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;
  }
  $22 = (($__i$02) + 16|0);
  $23 = ($22|0)==($__last|0);
  if ($23) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $22;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI15OrderedCallbackS2_EEPS2_EEbT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$014 = 0, $__count$1 = 0, $__i$015 = 0, $__j$013 = 0, $__j$013$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i5 = 0, $__t$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4$i5 = sp + 16|0;
 $__t$sroa$1 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 4;
 switch ($3|0) {
 case 3:  {
  $8 = (($__first) + 16|0);
  $9 = (($__last) + -16|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$__first>>2]|0;
  $12 = ($10|0)<($11|0);
  $13 = HEAP32[$9>>2]|0;
  $14 = ($13|0)<($10|0);
  if (!($12)) {
   if (!($14)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $15 = HEAP32[$8>>2]|0;
   $16 = HEAP32[$__first>>2]|0;
   $17 = ($15|0)<($16|0);
   if (!($17)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($14) {
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$9+12>>2]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $18 = HEAP32[$9>>2]|0;
  $19 = HEAP32[$8>>2]|0;
  $20 = ($18|0)<($19|0);
  if (!($20)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
  ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $24 = (($__first) + 16|0);
  $25 = (($__first) + 32|0);
  $26 = (($__first) + 48|0);
  $27 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IRNS_6__lessI15OrderedCallbackS2_EEPS2_EEjT0_S6_S6_S6_T_($__first,$24,$25,$26,0)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$26>>2]|0;
  $30 = ($28|0)<($29|0);
  if (!($30)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$26+12>>2]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$27+12>>2]|0;
  ;HEAP32[$27+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $31 = HEAP32[$26>>2]|0;
  $32 = HEAP32[$25>>2]|0;
  $33 = ($31|0)<($32|0);
  if (!($33)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$25+12>>2]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $34 = HEAP32[$25>>2]|0;
  $35 = HEAP32[$24>>2]|0;
  $36 = ($34|0)<($35|0);
  if (!($36)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $37 = HEAP32[$24>>2]|0;
  $38 = HEAP32[$__first>>2]|0;
  $39 = ($37|0)<($38|0);
  if (!($39)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $21 = (($__first) + 16|0);
  $22 = (($__first) + 32|0);
  $23 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IRNS_6__lessI15OrderedCallbackS2_EEPS2_EEjT0_S6_S6_S6_T_($__first,$21,$22,$23,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $40 = (($__first) + 32|0);
  $41 = (($__first) + 16|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$__first>>2]|0;
  $44 = ($42|0)<($43|0);
  $45 = HEAP32[$40>>2]|0;
  $46 = ($45|0)<($42|0);
  do {
   if ($44) {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     break;
    }
    ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;
    ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
    $49 = HEAP32[$41>>2]|0;
    $50 = ($45|0)<($49|0);
    if ($50) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
    }
   } else {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     $47 = HEAP32[$41>>2]|0;
     $48 = ($47|0)<($43|0);
     if ($48) {
      ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
      ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;
      ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     }
    }
   }
  } while(0);
  $51 = (($__first) + 48|0);
  $52 = ($51|0)==($__last|0);
  if ($52) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$014 = 0;$__i$015 = $51;$__j$013 = $40;
  while(1) {
   $53 = HEAP32[$__i$015>>2]|0;
   $54 = HEAP32[$__j$013>>2]|0;
   $55 = ($53|0)<($54|0);
   if ($55) {
    $56 = (($__i$015) + 4|0);
    ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$56+8>>2]|0;
    $__j$1 = $__i$015;$__k$0 = $__j$013;
    while(1) {
     ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;
     $57 = ($__k$0|0)==($__first|0);
     if ($57) {
      $__k$0$lcssa = $__first;
      break;
     }
     $58 = (($__k$0) + -16|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($53|0)<($59|0);
     if ($60) {
      $__j$1$phi = $__k$0;$__k$0 = $58;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $53;
    $61 = (($__k$0$lcssa) + 4|0);
    ;HEAP32[$61+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;
    $62 = (($__count$014) + 1)|0;
    $63 = ($62|0)==(8);
    if ($63) {
     break;
    } else {
     $__count$1 = $62;
    }
   } else {
    $__count$1 = $__count$014;
   }
   $66 = (($__i$015) + 16|0);
   $67 = ($66|0)==($__last|0);
   if ($67) {
    $$0 = 1;
    label = 35;
    break;
   } else {
    $__j$013$phi = $__i$015;$__count$014 = $__count$1;$__i$015 = $66;$__j$013 = $__j$013$phi;
   }
  }
  if ((label|0) == 35) {
   STACKTOP = sp;return ($$0|0);
  }
  $64 = (($__i$015) + 16|0);
  $65 = ($64|0)==($__last|0);
  $$0 = $65;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __Z12MurmurHash2APKvij($key,$len,$seed) {
 $key = $key|0;
 $len = $len|0;
 $seed = $seed|0;
 var $$0$lcssa = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$0$lcssa = 0, $data$01 = 0, $h$0$lcssa = 0, $h$02 = 0, $phitmp = 0, $scevgep = 0, $t$0 = 0, $t$1 = 0, $t$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($len|0)>(3);
 if ($0) {
  $1 = (($len) + -4)|0;
  $2 = $1 & -4;
  $3 = (($2) + 4)|0;
  $$03 = $len;$data$01 = $key;$h$02 = $seed;
  while(1) {
   $4 = HEAP32[$data$01>>2]|0;
   $5 = Math_imul($4, 1540483477)|0;
   $6 = $5 >>> 24;
   $7 = $6 ^ $5;
   $8 = Math_imul($7, 1540483477)|0;
   $9 = Math_imul($h$02, 1540483477)|0;
   $10 = $8 ^ $9;
   $11 = (($data$01) + 4|0);
   $12 = (($$03) + -4)|0;
   $13 = ($12|0)>(3);
   if ($13) {
    $$03 = $12;$data$01 = $11;$h$02 = $10;
   } else {
    break;
   }
  }
  $14 = (($1) - ($2))|0;
  $scevgep = (($key) + ($3)|0);
  $$0$lcssa = $14;$data$0$lcssa = $scevgep;$h$0$lcssa = $10;
 } else {
  $$0$lcssa = $len;$data$0$lcssa = $key;$h$0$lcssa = $seed;
 }
 if ((($$0$lcssa|0) == 3)) {
  $15 = (($data$0$lcssa) + 2|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16&255;
  $18 = $17 << 16;
  $t$0 = $18;
  label = 7;
 } else if ((($$0$lcssa|0) == 2)) {
  $t$0 = 0;
  label = 7;
 } else if ((($$0$lcssa|0) == 1)) {
  $t$1 = 0;
  label = 8;
 } else {
  $t$2 = 0;
 }
 if ((label|0) == 7) {
  $19 = (($data$0$lcssa) + 1|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20&255;
  $22 = $21 << 8;
  $23 = $22 | $t$0;
  $t$1 = $23;
  label = 8;
 }
 if ((label|0) == 8) {
  $24 = HEAP8[$data$0$lcssa>>0]|0;
  $25 = $24&255;
  $26 = $25 ^ $t$1;
  $phitmp = Math_imul($26, 1540483477)|0;
  $t$2 = $phitmp;
 }
 $27 = $t$2 >>> 24;
 $28 = $27 ^ $t$2;
 $29 = Math_imul($28, 1540483477)|0;
 $30 = Math_imul($h$0$lcssa, 1540483477)|0;
 $31 = $29 ^ $30;
 $32 = Math_imul($len, 1540483477)|0;
 $33 = $32 >>> 24;
 $34 = $33 ^ $32;
 $35 = Math_imul($34, 1540483477)|0;
 $36 = Math_imul($31, 1540483477)|0;
 $37 = $36 ^ $35;
 $38 = $37 >>> 13;
 $39 = $38 ^ $37;
 $40 = Math_imul($39, 1540483477)|0;
 $41 = $40 >>> 15;
 $42 = $41 ^ $40;
 STACKTOP = sp;return ($42|0);
}
function __Z40GetTemporaryCachePathApplicationSpecificv($agg$result) {
 $agg$result = $agg$result|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $brokenPath = 0, $cachePath = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $cachePath = sp + 48|0;
 $brokenPath = sp;
 $0 = sp + 12|0;
 $1 = sp + 24|0;
 $2 = sp + 36|0;
 __ZN10systeminfo21GetTemporaryCachePathEv($cachePath);
 $3 = HEAP8[$cachePath>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = $3&255;
  $9 = $8 >>> 1;
  $11 = $9;
 } else {
  $6 = (($cachePath) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $11 = $7;
 }
 $10 = ($11|0)==(0);
 L5: do {
  if ($10) {
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
  } else {
   HEAP8[$0>>0] = 0;
   $12 = (($0) + 1|0);
   HEAP8[$12>>0] = 0;
   __THREW__ = 0;
   invoke_viii(1776,($brokenPath|0),($cachePath|0),($0|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $25 = ___cxa_find_matching_catch()|0;
    $26 = tempRet0;
    $27 = HEAP8[$0>>0]|0;
    $28 = $27 & 1;
    $29 = ($28<<24>>24)==(0);
    if ($29) {
     $$2 = $26;$$23 = $25;
    } else {
     $30 = (($0) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __ZdlPv($31);
     $$2 = $26;$$23 = $25;
    }
   } else {
    $15 = HEAP8[$0>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if (!($17)) {
     $18 = (($0) + 8|0);
     $19 = HEAP32[$18>>2]|0;
     __ZdlPv($19);
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3257,($brokenPath|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    L14: do {
     if ($22) {
      label = 14;
     } else {
      L16: do {
       if ($20) {
        __THREW__ = 0;
        (invoke_iii(2233,($cachePath|0),($brokenPath|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if ($24) {
         label = 14;
         break L14;
        }
       } else {
        HEAP8[$2>>0] = 0;
        $34 = (($2) + 1|0);
        HEAP8[$34>>0] = 0;
        __THREW__ = 0;
        invoke_viii(1776,($1|0),($cachePath|0),($2|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        do {
         if ($36) {
          $49 = ___cxa_find_matching_catch()|0;
          $50 = tempRet0;
          $$0 = $50;$$01 = $49;
         } else {
          __THREW__ = 0;
          (invoke_iii(2233,($cachePath|0),($1|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           $51 = ___cxa_find_matching_catch()|0;
           $52 = tempRet0;
           $53 = HEAP8[$1>>0]|0;
           $54 = $53 & 1;
           $55 = ($54<<24>>24)==(0);
           if ($55) {
            $$0 = $52;$$01 = $51;
            break;
           }
           $56 = (($1) + 8|0);
           $57 = HEAP32[$56>>2]|0;
           __ZdlPv($57);
           $$0 = $52;$$01 = $51;
           break;
          }
          $39 = HEAP8[$1>>0]|0;
          $40 = $39 & 1;
          $41 = ($40<<24>>24)==(0);
          if (!($41)) {
           $42 = (($1) + 8|0);
           $43 = HEAP32[$42>>2]|0;
           __ZdlPv($43);
          }
          $44 = HEAP8[$2>>0]|0;
          $45 = $44 & 1;
          $46 = ($45<<24>>24)==(0);
          if ($46) {
           break L16;
          }
          $47 = (($2) + 8|0);
          $48 = HEAP32[$47>>2]|0;
          __ZdlPv($48);
          break L16;
         }
        } while(0);
        $58 = HEAP8[$2>>0]|0;
        $59 = $58 & 1;
        $60 = ($59<<24>>24)==(0);
        if ($60) {
         $$1 = $$0;$$12 = $$01;
         break L14;
        }
        $61 = (($2) + 8|0);
        $62 = HEAP32[$61>>2]|0;
        __ZdlPv($62);
        $$1 = $$0;$$12 = $$01;
        break L14;
       }
      } while(0);
      __THREW__ = 0;
      $63 = (invoke_ii(3260,($cachePath|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 14;
      } else {
       do {
        if ($63) {
         $66 = HEAP8[$cachePath>>0]|0;
         $67 = $66 & 1;
         $68 = ($67<<24>>24)==(0);
         if ($68) {
          ;HEAP32[$agg$result+0>>2]=HEAP32[$cachePath+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$cachePath+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$cachePath+8>>2]|0;
          break;
         }
         $69 = (($cachePath) + 8|0);
         $70 = HEAP32[$69>>2]|0;
         $71 = (($cachePath) + 4|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = ($72>>>0)>(4294967279);
         if ($73) {
          __THREW__ = 0;
          invoke_vi(3309,0);
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           label = 14;
           break L14;
          }
          // unreachable;
         }
         $76 = ($72>>>0)<(11);
         if ($76) {
          $77 = $72 << 1;
          $78 = $77&255;
          HEAP8[$agg$result>>0] = $78;
          $79 = (($agg$result) + 1|0);
          $__p$0$i$i$i = $79;
         } else {
          $80 = (($72) + 16)|0;
          $81 = $80 & -16;
          __THREW__ = 0;
          $82 = (invoke_ii(2988,($81|0))|0);
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           label = 14;
           break L14;
          }
          $85 = (($agg$result) + 8|0);
          HEAP32[$85>>2] = $82;
          $86 = $81 | 1;
          HEAP32[$agg$result>>2] = $86;
          $87 = (($agg$result) + 4|0);
          HEAP32[$87>>2] = $72;
          $__p$0$i$i$i = $82;
         }
         _memcpy(($__p$0$i$i$i|0),($70|0),($72|0))|0;
         $88 = (($__p$0$i$i$i) + ($72)|0);
         HEAP8[$88>>0] = 0;
        } else {
         ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
        }
       } while(0);
       $89 = HEAP8[$brokenPath>>0]|0;
       $90 = $89 & 1;
       $91 = ($90<<24>>24)==(0);
       if ($91) {
        break L5;
       }
       $92 = (($brokenPath) + 8|0);
       $93 = HEAP32[$92>>2]|0;
       __ZdlPv($93);
       break L5;
      }
     }
    } while(0);
    if ((label|0) == 14) {
     $32 = ___cxa_find_matching_catch()|0;
     $33 = tempRet0;
     $$1 = $33;$$12 = $32;
    }
    $94 = HEAP8[$brokenPath>>0]|0;
    $95 = $94 & 1;
    $96 = ($95<<24>>24)==(0);
    if ($96) {
     $$2 = $$1;$$23 = $$12;
    } else {
     $97 = (($brokenPath) + 8|0);
     $98 = HEAP32[$97>>2]|0;
     __ZdlPv($98);
     $$2 = $$1;$$23 = $$12;
    }
   }
   $104 = HEAP8[$cachePath>>0]|0;
   $105 = $104 & 1;
   $106 = ($105<<24>>24)==(0);
   if ($106) {
    ___resumeException($$23|0);
    // unreachable;
   }
   $107 = (($cachePath) + 8|0);
   $108 = HEAP32[$107>>2]|0;
   __ZdlPv($108);
   ___resumeException($$23|0);
   // unreachable;
  }
 } while(0);
 $99 = HEAP8[$cachePath>>0]|0;
 $100 = $99 & 1;
 $101 = ($100<<24>>24)==(0);
 if ($101) {
  STACKTOP = sp;return;
 }
 $102 = (($cachePath) + 8|0);
 $103 = HEAP32[$102>>2]|0;
 __ZdlPv($103);
 STACKTOP = sp;return;
}
function __Z26InitializeAsyncReadManagerv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628240>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(224,$$byval_copy1,1,16,652720,14)|0);
 __THREW__ = 0;
 invoke_vi(3586,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  HEAP32[652728>>2] = $2;
  STACKTOP = sp;return;
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($2|0),($$byval_copy1|0),1,16,(652720|0),14);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
}
function __Z16AsyncReadRequestP16AsyncReadCommand($request) {
 $request = $request|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[652728>>2]|0;
 $1 = (__ZN13OpenFileCache10OpenCachedERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$request)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($request) + 24|0);
  HEAP32[$3>>2] = 2;
  STACKTOP = sp;return;
 }
 $4 = (($request) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($request) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($request) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZN4File4ReadEiPvi($1,$5,$7,$9)|0);
 $11 = HEAP32[$8>>2]|0;
 $12 = ($10|0)==($11|0);
 $13 = (($request) + 24|0);
 if ($12) {
  HEAP32[$13>>2] = 0;
  STACKTOP = sp;return;
 } else {
  HEAP32[$13>>2] = 2;
  STACKTOP = sp;return;
 }
}
function __Z17AsyncReadWaitDoneP16AsyncReadCommand($request) {
 $request = $request|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z23AsyncReadForceCloseFileRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($path) {
 $path = $path|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[652728>>2]|0;
 __ZN13OpenFileCache10ForceCloseERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($0,$path);
 STACKTOP = sp;return;
}
function __ZN13OpenFileCacheC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = $this;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3519,($1|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   break;
  }
  $4 = (($1) + 28|0);
  $5 = ($4|0)==($0|0);
  if ($5) {
   label = 4;
   break;
  } else {
   $1 = $4;
  }
 }
 if ((label|0) == 4) {
  $6 = (($this) + 140|0);
  dest=$6+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $9 = ($this|0)==($1|0);
 if ($9) {
  ___resumeException($7|0);
  // unreachable;
 } else {
  $11 = $1;
 }
 while(1) {
  $10 = (($11) + -28|0);
  __THREW__ = 0;
  invoke_vi(3517,($10|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   label = 9;
   break;
  }
  $14 = ($10|0)==($this|0);
  if ($14) {
   label = 8;
   break;
  } else {
   $11 = $10;
  }
 }
 if ((label|0) == 8) {
  ___resumeException($7|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 }
}
function __ZN13OpenFileCache10OpenCachedERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$thePath) {
 $this = $this|0;
 $thePath = $thePath|0;
 var $$0 = 0, $$lruTimeStamp$0 = 0, $$lruTimeStamp$0$1 = 0, $$lruTimeStamp$0$2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__lhs_sz$05$i$us = 0, $__lp$03$i$us = 0, $__rp$04$i$us = 0;
 var $i$011 = 0, $i$012 = 0, $i$012$us = 0, $i1$0$lruIndex$0 = 0, $i1$0$lruIndex$0$1 = 0, $i1$0$lruIndex$0$2 = 0, $i1$0$lruIndex$0$3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 220|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = HEAP8[$thePath>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 $7 = $4&255;
 $8 = $7 >>> 1;
 $9 = (($thePath) + 1|0);
 $10 = (($thePath) + 8|0);
 $11 = (($thePath) + 4|0);
 L1: do {
  if ($6) {
   $i$012$us = 0;
   while(1) {
    $12 = ((($this) + (($i$012$us*12)|0)|0) + 140|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     $18 = $13&255;
     $19 = $18 >>> 1;
     $21 = $19;
    } else {
     $16 = ((($this) + (($i$012$us*12)|0)|0) + 144|0);
     $17 = HEAP32[$16>>2]|0;
     $21 = $17;
    }
    $20 = ($8|0)==($21|0);
    L8: do {
     if ($20) {
      if ($15) {
       $24 = (($12) + 1|0);
       $112 = $24;
      } else {
       $22 = ((($this) + (($i$012$us*12)|0)|0) + 148|0);
       $23 = HEAP32[$22>>2]|0;
       $112 = $23;
      }
      $25 = ($8|0)==(0);
      if ($25) {
       $i$011 = $i$012$us;
       label = 21;
       break L1;
      } else {
       $__lhs_sz$05$i$us = $8;$__lp$03$i$us = $9;$__rp$04$i$us = $112;
      }
      while(1) {
       $26 = HEAP8[$__lp$03$i$us>>0]|0;
       $27 = HEAP8[$__rp$04$i$us>>0]|0;
       $28 = ($26<<24>>24)==($27<<24>>24);
       if (!($28)) {
        break L8;
       }
       $31 = (($__lhs_sz$05$i$us) + -1)|0;
       $32 = (($__lp$03$i$us) + 1|0);
       $33 = (($__rp$04$i$us) + 1|0);
       $34 = ($31|0)==(0);
       if ($34) {
        $i$011 = $i$012$us;
        label = 21;
        break L1;
       } else {
        $__lhs_sz$05$i$us = $31;$__lp$03$i$us = $32;$__rp$04$i$us = $33;
       }
      }
     }
    } while(0);
    $29 = (($i$012$us) + 1)|0;
    $30 = ($29|0)<(5);
    if ($30) {
     $i$012$us = $29;
    } else {
     break;
    }
   }
  } else {
   $i$012 = 0;
   while(1) {
    $35 = ((($this) + (($i$012*12)|0)|0) + 140|0);
    $36 = HEAP32[$11>>2]|0;
    $37 = HEAP8[$35>>0]|0;
    $38 = $37 & 1;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     $42 = $37&255;
     $43 = $42 >>> 1;
     $45 = $43;
    } else {
     $40 = ((($this) + (($i$012*12)|0)|0) + 144|0);
     $41 = HEAP32[$40>>2]|0;
     $45 = $41;
    }
    $44 = ($36|0)==($45|0);
    if ($44) {
     $46 = HEAP32[$10>>2]|0;
     if ($39) {
      $49 = (($35) + 1|0);
      $50 = $49;
     } else {
      $47 = ((($this) + (($i$012*12)|0)|0) + 148|0);
      $48 = HEAP32[$47>>2]|0;
      $50 = $48;
     }
     $51 = (_memcmp($46,$50,$36)|0);
     $52 = ($51|0)==(0);
     if ($52) {
      $i$011 = $i$012;
      label = 21;
      break L1;
     }
    }
    $55 = (($i$012) + 1)|0;
    $56 = ($55|0)<(5);
    if ($56) {
     $i$012 = $55;
    } else {
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $53 = ((($this) + ($i$011<<2)|0) + 200|0);
  HEAP32[$53>>2] = $3;
  $54 = (($this) + (($i$011*28)|0)|0);
  $$0 = $54;
  STACKTOP = sp;return ($$0|0);
 }
 $57 = (($this) + 200|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 204|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60>>>0)<($58>>>0);
 $$lruTimeStamp$0 = $61 ? $60 : $58;
 $i1$0$lruIndex$0 = $61&1;
 $62 = (($this) + 208|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63>>>0)<($$lruTimeStamp$0>>>0);
 $$lruTimeStamp$0$1 = $64 ? $63 : $$lruTimeStamp$0;
 $i1$0$lruIndex$0$1 = $64 ? 2 : $i1$0$lruIndex$0;
 $65 = (($this) + 212|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66>>>0)<($$lruTimeStamp$0$1>>>0);
 $$lruTimeStamp$0$2 = $67 ? $66 : $$lruTimeStamp$0$1;
 $i1$0$lruIndex$0$2 = $67 ? 3 : $i1$0$lruIndex$0$1;
 $68 = (($this) + 216|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69>>>0)<($$lruTimeStamp$0$2>>>0);
 $i1$0$lruIndex$0$3 = $70 ? 4 : $i1$0$lruIndex$0$2;
 $71 = (($this) + (($i1$0$lruIndex$0$3*28)|0)|0);
 $72 = (__ZN4File7IsValidEv($71)|0);
 if ($72) {
  (__ZN4File5CloseEv($71)|0);
 }
 $73 = (__ZN4File4OpenERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS_10PermissionENS_12AutoBehaviorE($71,$thePath,0,0)|0);
 if ($73) {
  $109 = HEAP32[$1>>2]|0;
  $110 = ((($this) + ($i1$0$lruIndex$0$3<<2)|0) + 200|0);
  HEAP32[$110>>2] = $109;
  $111 = ((($this) + (($i1$0$lruIndex$0$3*12)|0)|0) + 140|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($111,$thePath)|0);
  $$0 = $71;
  STACKTOP = sp;return ($$0|0);
 }
 $74 = HEAP8[$thePath>>0]|0;
 $75 = $74 & 1;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  $78 = $9;
 } else {
  $77 = HEAP32[$10>>2]|0;
  $78 = $77;
 }
 HEAP32[$vararg_buffer>>2] = $78;
 __Z6FormatPKcz($0,652736,$vararg_buffer);
 $79 = HEAP8[$0>>0]|0;
 $80 = $79 & 1;
 $81 = ($80<<24>>24)==(0);
 if ($81) {
  $84 = (($0) + 1|0);
  $85 = $84;
 } else {
  $82 = (($0) + 8|0);
  $83 = HEAP32[$82>>2]|0;
  $85 = $83;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($85|0),0,(652768|0),54,1,0,0,(0|0));
 $86 = __THREW__; __THREW__ = 0;
 $87 = $86&1;
 if ($87) {
  $102 = ___cxa_find_matching_catch()|0;
  $103 = tempRet0;
  $104 = HEAP8[$0>>0]|0;
  $105 = $104 & 1;
  $106 = ($105<<24>>24)==(0);
  if ($106) {
   ___resumeException($102|0);
   // unreachable;
  }
  $107 = (($0) + 8|0);
  $108 = HEAP32[$107>>2]|0;
  __ZdlPv($108);
  ___resumeException($102|0);
  // unreachable;
 }
 $88 = HEAP8[$0>>0]|0;
 $89 = $88 & 1;
 $90 = ($89<<24>>24)==(0);
 if (!($90)) {
  $91 = (($0) + 8|0);
  $92 = HEAP32[$91>>2]|0;
  __ZdlPv($92);
 }
 $93 = ((($this) + ($i1$0$lruIndex$0$3<<2)|0) + 200|0);
 HEAP32[$93>>2] = 0;
 $94 = ((($this) + (($i1$0$lruIndex$0$3*12)|0)|0) + 140|0);
 $95 = HEAP8[$94>>0]|0;
 $96 = $95 & 1;
 $97 = ($96<<24>>24)==(0);
 if ($97) {
  $101 = (($94) + 1|0);
  HEAP8[$101>>0] = 0;
  HEAP8[$94>>0] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $98 = ((($this) + (($i1$0$lruIndex$0$3*12)|0)|0) + 148|0);
  $99 = HEAP32[$98>>2]|0;
  HEAP8[$99>>0] = 0;
  $100 = ((($this) + (($i1$0$lruIndex$0$3*12)|0)|0) + 144|0);
  HEAP32[$100>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN13OpenFileCache10ForceCloseERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$path) {
 $this = $this|0;
 $path = $path|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $__lhs_sz$05$i = 0, $__lhs_sz$05$i$us = 0, $__lp$03$i = 0, $__lp$03$i$us = 0, $__rp$04$i = 0, $__rp$04$i$us = 0, $i$010 = 0, $i$010$us = 0;
 var $i$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$path>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 $3 = $0&255;
 $4 = $3 >>> 1;
 $5 = (($path) + 1|0);
 $6 = (($path) + 8|0);
 $7 = (($path) + 4|0);
 L1: do {
  if ($2) {
   $i$010$us = 0;
   while(1) {
    $8 = ((($this) + (($i$010$us*12)|0)|0) + 140|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9 & 1;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $14 = $9&255;
     $15 = $14 >>> 1;
     $17 = $15;
    } else {
     $12 = ((($this) + (($i$010$us*12)|0)|0) + 144|0);
     $13 = HEAP32[$12>>2]|0;
     $17 = $13;
    }
    $16 = ($17|0)==($4|0);
    L8: do {
     if ($16) {
      if (!($11)) {
       $18 = ((($this) + (($i$010$us*12)|0)|0) + 148|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (_memcmp($19,$5,$4)|0);
       $21 = ($20|0)==(0);
       if ($21) {
        $61 = $8;$68 = $8;$i$06 = $i$010$us;
        break L1;
       } else {
        break;
       }
      }
      $22 = (($8) + 1|0);
      $23 = ($4|0)==(0);
      if ($23) {
       $61 = $8;$68 = $8;$i$06 = $i$010$us;
       break L1;
      } else {
       $__lhs_sz$05$i$us = $4;$__lp$03$i$us = $22;$__rp$04$i$us = $5;
      }
      while(1) {
       $24 = HEAP8[$__lp$03$i$us>>0]|0;
       $25 = HEAP8[$__rp$04$i$us>>0]|0;
       $26 = ($24<<24>>24)==($25<<24>>24);
       if (!($26)) {
        break L8;
       }
       $29 = (($__lhs_sz$05$i$us) + -1)|0;
       $30 = (($__lp$03$i$us) + 1|0);
       $31 = (($__rp$04$i$us) + 1|0);
       $32 = ($29|0)==(0);
       if ($32) {
        $61 = $8;$68 = $8;$i$06 = $i$010$us;
        break L1;
       } else {
        $__lhs_sz$05$i$us = $29;$__lp$03$i$us = $30;$__rp$04$i$us = $31;
       }
      }
     }
    } while(0);
    $27 = (($i$010$us) + 1)|0;
    $28 = ($27|0)<(5);
    if ($28) {
     $i$010$us = $27;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  } else {
   $i$010 = 0;
   while(1) {
    $33 = ((($this) + (($i$010*12)|0)|0) + 140|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = $34 & 1;
    $36 = ($35<<24>>24)==(0);
    if ($36) {
     $39 = $34&255;
     $40 = $39 >>> 1;
     $43 = $40;
    } else {
     $37 = ((($this) + (($i$010*12)|0)|0) + 144|0);
     $38 = HEAP32[$37>>2]|0;
     $43 = $38;
    }
    $41 = HEAP32[$7>>2]|0;
    $42 = ($43|0)==($41|0);
    L24: do {
     if ($42) {
      if (!($36)) {
       $54 = ((($this) + (($i$010*12)|0)|0) + 148|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = HEAP32[$6>>2]|0;
       $57 = (_memcmp($55,$56,$43)|0);
       $58 = ($57|0)==(0);
       if ($58) {
        $61 = $33;$68 = $33;$i$06 = $i$010;
        break L1;
       } else {
        break;
       }
      }
      $44 = (($33) + 1|0);
      $45 = HEAP32[$6>>2]|0;
      $46 = ($43|0)==(0);
      if ($46) {
       $61 = $33;$68 = $33;$i$06 = $i$010;
       break L1;
      } else {
       $__lhs_sz$05$i = $43;$__lp$03$i = $44;$__rp$04$i = $45;
      }
      while(1) {
       $47 = HEAP8[$__lp$03$i>>0]|0;
       $48 = HEAP8[$__rp$04$i>>0]|0;
       $49 = ($47<<24>>24)==($48<<24>>24);
       if (!($49)) {
        break L24;
       }
       $50 = (($__lhs_sz$05$i) + -1)|0;
       $51 = (($__lp$03$i) + 1|0);
       $52 = (($__rp$04$i) + 1|0);
       $53 = ($50|0)==(0);
       if ($53) {
        $61 = $33;$68 = $33;$i$06 = $i$010;
        break L1;
       } else {
        $__lhs_sz$05$i = $50;$__lp$03$i = $51;$__rp$04$i = $52;
       }
      }
     }
    } while(0);
    $70 = (($i$010) + 1)|0;
    $71 = ($70|0)<(5);
    if ($71) {
     $i$010 = $70;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $59 = (($this) + (($i$06*28)|0)|0);
 (__ZN4File5CloseEv($59)|0);
 $60 = HEAP8[$61>>0]|0;
 $62 = $60 & 1;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  $67 = (($68) + 1|0);
  HEAP8[$67>>0] = 0;
  HEAP8[$61>>0] = 0;
 } else {
  $64 = ((($this) + (($i$06*12)|0)|0) + 148|0);
  $65 = HEAP32[$64>>2]|0;
  HEAP8[$65>>0] = 0;
  $66 = ((($this) + (($i$06*12)|0)|0) + 144|0);
  HEAP32[$66>>2] = 0;
 }
 $69 = ((($this) + ($i$06<<2)|0) + 200|0);
 HEAP32[$69>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK9ShaderLab16FastPropertyName7GetNameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $propName$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(-1);
 do {
  if ($1) {
   $propName$0 = 652776;
  } else {
   $2 = $0 & -1073741824;
   if ((($2|0) == 1073741824)) {
    $3 = $0 & 1073741823;
    $4 = (__Z25GetBuiltinVectorParamNamei($3)|0);
    $propName$0 = $4;
    break;
   } else if ((($2|0) == -2147483648)) {
    $5 = $0 & 1073741823;
    $6 = (__Z25GetBuiltinMatrixParamNamei($5)|0);
    $propName$0 = $6;
    break;
   } else if ((($2|0) == -1073741824)) {
    $7 = $0 & 1073741823;
    $8 = (__Z25GetBuiltinTexEnvParamNamei($7)|0);
    $propName$0 = $8;
    break;
   } else {
    $9 = ($0|0)>(-1);
    if (!($9)) {
     $propName$0 = 652776;
     break;
    }
    $10 = HEAP32[652792>>2]|0;
    $11 = (($10) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($0>>>0)<($12>>>0);
    if (!($13)) {
     $propName$0 = 652776;
     break;
    }
    $14 = HEAP32[$10>>2]|0;
    $15 = (($14) + ($0<<2)|0);
    $16 = HEAP32[$15>>2]|0;
    $propName$0 = $16;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($propName$0|0);
}
function __ZN9ShaderLab33GenerateFastPropertyName28BitHashEPKc($name) {
 $name = $name|0;
 var $$02$i$i$i$i = 0, $$masked$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i$i = 0, $i$03$i$i$i$i = 0, $p$01$i$i$i = 0, $reflection$01$i$i$i$i = 0, $reflection$1$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$02$i$i$i$i = -1;$i$03$i$i$i$i = 0;$reflection$01$i$i$i$i = 0;
 while(1) {
  $0 = $$02$i$i$i$i & 1;
  $1 = ($0|0)==(0);
  if ($1) {
   $reflection$1$i$i$i$i = $reflection$01$i$i$i$i;
  } else {
   $2 = (31 - ($i$03$i$i$i$i))|0;
   $3 = 1 << $2;
   $4 = $3 | $reflection$01$i$i$i$i;
   $reflection$1$i$i$i$i = $4;
  }
  $5 = (($i$03$i$i$i$i) + 1)|0;
  $6 = $$02$i$i$i$i >>> 1;
  $exitcond$i$i$i$i = ($5|0)==(32);
  if ($exitcond$i$i$i$i) {
   break;
  } else {
   $$02$i$i$i$i = $6;$i$03$i$i$i$i = $5;$reflection$01$i$i$i$i = $reflection$1$i$i$i$i;
  }
 }
 $7 = (_strlen(($name|0))|0);
 $8 = (($name) + ($7)|0);
 $9 = ($7|0)>(0);
 if ($9) {
  $13 = $reflection$1$i$i$i$i;$p$01$i$i$i = $name;
 } else {
  $20 = $reflection$1$i$i$i$i;
  $19 = $20 & 268435455;
  $21 = $19 ^ 268435455;
  STACKTOP = sp;return ($21|0);
 }
 while(1) {
  $10 = HEAP8[$p$01$i$i$i>>0]|0;
  $11 = $10&255;
  $12 = $13 >>> 8;
  $$masked$i$i$i = $13 & 255;
  $14 = $11 ^ $$masked$i$i$i;
  $15 = (584048 + ($14<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16 ^ $12;
  $18 = (($p$01$i$i$i) + 1|0);
  $exitcond$i$i$i = ($18|0)==($8|0);
  if ($exitcond$i$i$i) {
   $20 = $17;
   break;
  } else {
   $13 = $17;$p$01$i$i$i = $18;
  }
 }
 $19 = $20 & 268435455;
 $21 = $19 ^ 268435455;
 STACKTOP = sp;return ($21|0);
}
function __ZN9ShaderLab16FastPropertyName15InitBy28BitHashEj($this,$hash) {
 $this = $this|0;
 $hash = $hash|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$02$i$i$i$i$i = 0, $$masked$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i$i = 0, $exitcond$i$i$i$i$i = 0, $i$03$i$i$i$i$i = 0, $p$01$i$i$i$i = 0, $reflection$01$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = -1;
 $0 = HEAP32[652800>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = (($0) + 4|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $6 = $2;
 }
 while(1) {
  $5 = (($6) + 16|0);
  $7 = HEAP32[$5>>2]|0;
  $$02$i$i$i$i$i = -1;$i$03$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i = 0;
  while(1) {
   $8 = $$02$i$i$i$i$i & 1;
   $9 = ($8|0)==(0);
   if ($9) {
    $reflection$1$i$i$i$i$i = $reflection$01$i$i$i$i$i;
   } else {
    $10 = (31 - ($i$03$i$i$i$i$i))|0;
    $11 = 1 << $10;
    $12 = $11 | $reflection$01$i$i$i$i$i;
    $reflection$1$i$i$i$i$i = $12;
   }
   $13 = (($i$03$i$i$i$i$i) + 1)|0;
   $14 = $$02$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i = ($13|0)==(32);
   if ($exitcond$i$i$i$i$i) {
    break;
   } else {
    $$02$i$i$i$i$i = $14;$i$03$i$i$i$i$i = $13;$reflection$01$i$i$i$i$i = $reflection$1$i$i$i$i$i;
   }
  }
  $15 = (_strlen(($7|0))|0);
  $16 = (($7) + ($15)|0);
  $17 = ($15|0)>(0);
  if ($17) {
   $21 = $reflection$1$i$i$i$i$i;$p$01$i$i$i$i = $7;
   while(1) {
    $18 = HEAP8[$p$01$i$i$i$i>>0]|0;
    $19 = $18&255;
    $20 = $21 >>> 8;
    $$masked$i$i$i$i = $21 & 255;
    $22 = $19 ^ $$masked$i$i$i$i;
    $23 = (584048 + ($22<<2)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = $24 ^ $20;
    $26 = (($p$01$i$i$i$i) + 1|0);
    $exitcond$i$i$i$i = ($26|0)==($16|0);
    if ($exitcond$i$i$i$i) {
     $28 = $25;
     break;
    } else {
     $21 = $25;$p$01$i$i$i$i = $26;
    }
   }
  } else {
   $28 = $reflection$1$i$i$i$i$i;
  }
  $27 = $28 & 268435455;
  $29 = $27 ^ 268435455;
  $30 = ($29|0)==($hash|0);
  if ($30) {
   $31 = (($6) + 20|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$this>>2] = $32;
  }
  $33 = (($6) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$01$i$i$i$i = $6;
   while(1) {
    $38 = (($$01$i$i$i$i) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==($$01$i$i$i$i|0);
    if ($41) {
     $$0$i$i$i$i = $39;
     break;
    } else {
     $$01$i$i$i$i = $39;
    }
   }
  } else {
   $$0$i$i$i$i$i = $34;
   while(1) {
    $36 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $36;
    }
   }
  }
  $42 = ($$0$i$i$i$i|0)==($3|0);
  if ($42) {
   break;
  } else {
   $6 = $$0$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab16FastPropertyName4InitEPKc($this,$inName) {
 $this = $this|0;
 $inName = $inName|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $builtinIndex = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $builtinIndex = sp + 8|0;
 $1 = HEAP32[652800>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __Z33InitializeBuiltinShaderParamNamesv();
  $3 = (__Znwj(12)|0);
  $4 = (($3) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($3) + 8|0);
  HEAP32[$5>>2] = 0;
  HEAP32[$3>>2] = $4;
  HEAP32[652800>>2] = $3;
  $6 = (__Znwj(16)|0);
  HEAP32[$6>>2] = 0;
  $7 = (($6) + 8|0);
  HEAP32[$7>>2] = 0;
  $8 = (($6) + 12|0);
  HEAP32[$8>>2] = 0;
  $9 = (($6) + 4|0);
  HEAP32[$9>>2] = 61;
  HEAP32[652792>>2] = $6;
  $11 = $3;
 } else {
  $11 = $1;
 }
 $10 = (($11) + 4|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = (($11) + 4|0);
 $14 = ($12|0)==(0|0);
 if (!($14)) {
  $$0$ph7$i$i$i = $13;$$01$ph6$i$in$i$i = $12;
  L5: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $15 = (($$013$i$in$i$i) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (_strcmp($16,$inName)|0);
    $18 = ($17|0)<(0);
    if (!($18)) {
     break;
    }
    $21 = (($$013$i$in$i$i) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0|0);
    if ($23) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L5;
    } else {
     $$013$i$in$i$i = $22;
    }
   }
   $19 = HEAP32[$$013$i$in$i$i>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $19;
   }
  }
  $24 = ($$0$ph5$i$i$i|0)==($13|0);
  if (!($24)) {
   $25 = (($$0$ph5$i$i$i) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (_strcmp($inName,$26)|0);
   $28 = ($27|0)<(0);
   $29 = ($$0$ph5$i$i$i|0)==($13|0);
   $or$cond = $28 | $29;
   if (!($or$cond)) {
    $30 = (($$0$ph5$i$i$i) + 20|0);
    $31 = HEAP32[$30>>2]|0;
    HEAP32[$this>>2] = $31;
    STACKTOP = sp;return;
   }
  }
 }
 $32 = (_strlen(($inName|0))|0);
 $33 = (($32) + 1)|0;
 $34 = (__Znaj($33)|0);
 _memcpy(($34|0),($inName|0),($33|0))|0;
 HEAP32[$builtinIndex>>2] = -1;
 $35 = (__Z20IsVectorBuiltinParamPKcPi($inName,$builtinIndex)|0);
 do {
  if ($35) {
   $36 = HEAP32[$builtinIndex>>2]|0;
   $37 = $36 | 1073741824;
   HEAP32[$this>>2] = $37;
   $81 = $37;
  } else {
   $38 = (__Z20IsMatrixBuiltinParamPKcPi($inName,$builtinIndex)|0);
   if ($38) {
    $39 = HEAP32[$builtinIndex>>2]|0;
    $40 = $39 | -2147483648;
    HEAP32[$this>>2] = $40;
    $81 = $40;
    break;
   }
   $41 = (__Z20IsTexEnvBuiltinParamPKcPi($inName,$builtinIndex)|0);
   if ($41) {
    $42 = HEAP32[$builtinIndex>>2]|0;
    $43 = $42 | -1073741824;
    HEAP32[$this>>2] = $43;
    $81 = $43;
    break;
   }
   $44 = HEAP32[652808>>2]|0;
   $45 = (($44) + 1)|0;
   HEAP32[652808>>2] = $45;
   HEAP32[$this>>2] = $44;
   $46 = HEAP32[652792>>2]|0;
   $47 = (($46) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + 1)|0;
   HEAP32[$47>>2] = $49;
   $50 = (($46) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = $51 & 2147483647;
   $53 = ($49>>>0)>($52>>>0);
   if ($53) {
    $54 = $51 << 1;
    $55 = ($54|0)==(0);
    $56 = $55 ? 1 : $54;
    $57 = ($52>>>0)<($56>>>0);
    do {
     if ($57) {
      $58 = ($51|0)>(-1);
      if ($58) {
       HEAP32[$50>>2] = $56;
       $59 = HEAP32[$46>>2]|0;
       $60 = $56 << 2;
       $61 = (($46) + 4|0);
       $62 = HEAP32[$61>>2]|0;
       HEAP32[$0>>2] = $62;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       $63 = (__Z16realloc_internalPvji10MemLabelIdiPKci($59,$60,4,$$byval_copy1,0,652816,370)|0);
       HEAP32[$46>>2] = $63;
       break;
      } else {
       $64 = $56 << 2;
       $65 = (($46) + 4|0);
       $66 = HEAP32[$65>>2]|0;
       HEAP32[$0>>2] = $66;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       $67 = (__Z15malloc_internaljj10MemLabelIdiPKci($64,4,$$byval_copy1,0,652816,352)|0);
       $68 = HEAP32[$46>>2]|0;
       $69 = HEAP32[$47>>2]|0;
       $70 = $69 << 2;
       _memcpy(($67|0),($68|0),($70|0))|0;
       HEAP32[$50>>2] = $56;
       HEAP32[$46>>2] = $67;
       break;
      }
     }
    } while(0);
    $$pre$i$i = HEAP32[$47>>2]|0;
    $72 = $$pre$i$i;
   } else {
    $72 = $49;
   }
   $71 = (($72) + -1)|0;
   $73 = HEAP32[$46>>2]|0;
   $74 = (($73) + ($71<<2)|0);
   HEAP32[$74>>2] = $34;
   $$pre = HEAP32[$this>>2]|0;
   $81 = $$pre;
  }
 } while(0);
 $75 = HEAP32[652800>>2]|0;
 $76 = $34;
 $77 = $0;
 $78 = $77;
 HEAP32[$78>>2] = $76;
 $79 = (($77) + 4)|0;
 $80 = $79;
 HEAP32[$80>>2] = $81;
 __ZNSt3__16__treeINS_12__value_typeIPKciEENS_19__map_value_compareIS3_S4_N9ShaderLab14CStringCompareELb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($$byval_copy1,$75,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIPKciEENS_19__map_value_compareIS3_S4_N9ShaderLab14CStringCompareELb1EEENS_9allocatorIS4_EEE15__insert_uniqueERKS4_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $15 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $15;
   $$0$i = $15;$32 = $15;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (_strcmp($3,$5)|0);
    $7 = ($6|0)<(0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = (_strcmp($5,$3)|0);
    $11 = ($10|0)<(0);
    if (!($11)) {
     label = 9;
     break;
    }
    $12 = (($__nd$0$in$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $13;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$32 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $12;$32 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$32 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $16 = HEAP32[$$0$i>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $42 = 0;$__r$0 = $16;
  HEAP32[$agg$result>>2] = $__r$0;
  $41 = (($agg$result) + 4|0);
  HEAP8[$41>>0] = $42;
  STACKTOP = sp;return;
 }
 $18 = (__Znwj(24)|0);
 $19 = (($18) + 16|0);
 $20 = $__v;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 4)|0;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = $19;
 $27 = $26;
 HEAP32[$27>>2] = $22;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 HEAP32[$18>>2] = 0;
 $30 = (($18) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = (($18) + 8|0);
 HEAP32[$31>>2] = $32;
 HEAP32[$$0$i>>2] = $18;
 $33 = HEAP32[$this>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $37 = $18;
 } else {
  HEAP32[$this>>2] = $34;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $37 = $$pre$i;
 }
 $36 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($36,$37);
 $38 = (($this) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 1)|0;
 HEAP32[$38>>2] = $40;
 $42 = 1;$__r$0 = $18;
 HEAP32[$agg$result>>2] = $__r$0;
 $41 = (($agg$result) + 4|0);
 HEAP8[$41>>0] = $42;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab33ShaderPassContextStaticInitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(104,$$byval_copy,0,16,652832,12)|0);
 $3 = (($2) + 4|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 $4 = (($2) + 20|0);
 HEAP32[$4>>2] = ((587472 + 8|0));
 $5 = (($2) + 24|0);
 HEAP32[$5>>2] = 1;
 HEAP32[$4>>2] = ((653968 + 8|0));
 $6 = (($2) + 32|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 36|0);
 HEAP32[$7>>2] = 0;
 $8 = (($2) + 28|0);
 HEAP32[$8>>2] = $6;
 $9 = (($2) + 44|0);
 HEAP32[$9>>2] = 0;
 $10 = (($2) + 48|0);
 HEAP32[$10>>2] = 0;
 $11 = (($2) + 40|0);
 HEAP32[$11>>2] = $9;
 $12 = (($2) + 56|0);
 HEAP32[$12>>2] = 0;
 $13 = (($2) + 60|0);
 HEAP32[$13>>2] = 0;
 $14 = (($2) + 52|0);
 HEAP32[$14>>2] = $12;
 $15 = (($2) + 68|0);
 HEAP32[$15>>2] = 0;
 $16 = (($2) + 72|0);
 HEAP32[$16>>2] = 0;
 $17 = (($2) + 64|0);
 HEAP32[$17>>2] = $15;
 $18 = (($2) + 80|0);
 HEAP32[$18>>2] = 0;
 $19 = (($2) + 84|0);
 HEAP32[$19>>2] = 0;
 $20 = (($2) + 76|0);
 HEAP32[$20>>2] = $18;
 $21 = (($2) + 92|0);
 HEAP32[$21>>2] = 0;
 $22 = (($2) + 96|0);
 HEAP32[$22>>2] = 0;
 $23 = (($2) + 88|0);
 HEAP32[$23>>2] = $21;
 $24 = (($2) + 100|0);
 HEAP32[$24>>2] = 0;
 HEAP32[652824>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab30ShaderPassContextStaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[652824>>2]|0;
 $2 = HEAP32[628272>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($1) + 20|0);
  __ZN9ShaderLab13PropertySheetD2Ev($4);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[652824>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9IntShaderC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 36|0);
 HEAP32[$3>>2] = 2000;
 $4 = (($this) + 40|0);
 HEAP32[$4>>2] = -1;
 $5 = (($this) + 44|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 48|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 52|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 60|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 64|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 56|0);
 HEAP32[$10>>2] = 61;
 $11 = (($this) + 68|0);
 $scevgep = (($this) + 12|0);
 dest=$11+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$scevgep+0>>2]=4294967295|0;HEAP32[$scevgep+4>>2]=4294967295|0;HEAP32[$scevgep+8>>2]=4294967295|0;HEAP32[$scevgep+12>>2]=4294967295|0;HEAP32[$scevgep+16>>2]=4294967295|0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9IntShaderD2Ev($this) {
 $this = $this|0;
 var $$3 = 0, $$34 = 0, $$byval_copy7 = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i20 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i21 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i25 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i23 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   label = 16;
  } else {
   $5 = (($3) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + -1)|0;
   HEAP32[$5>>2] = $7;
   $8 = HEAP32[$5>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = HEAP32[$3>>2]|0;
    $11 = (($10) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi($12|0,($3|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     $17 = ___cxa_find_matching_catch()|0;
     $18 = tempRet0;
     $lpad$phi$index = $17;$lpad$phi$index2 = $18;
     label = 7;
     break;
    }
   }
   HEAP32[$2>>2] = 0;
   label = 16;
  }
 } while(0);
 L7: do {
  if ((label|0) == 16) {
   $41 = HEAP32[$this>>2]|0;
   $42 = (($this) + 4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($41|0)==($43|0);
   L9: do {
    if (!($44)) {
     $46 = $41;
     while(1) {
      $45 = HEAP32[$46>>2]|0;
      $47 = HEAP32[628272>>2]|0;
      $48 = ($45|0)==(0|0);
      if (!($48)) {
       __THREW__ = 0;
       invoke_vi(3587,($45|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
      }
      HEAP32[$1>>2] = $47;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($45|0),($$byval_copy7|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      HEAP32[$46>>2] = 0;
      $53 = (($46) + 4|0);
      $54 = HEAP32[$42>>2]|0;
      $55 = ($53|0)==($54|0);
      if ($55) {
       break L9;
      } else {
       $46 = $53;
      }
     }
     $15 = ___cxa_find_matching_catch()|0;
     $16 = tempRet0;
     $lpad$phi$index = $15;$lpad$phi$index2 = $16;
     label = 7;
     break L7;
    }
   } while(0);
   $56 = (($this) + 96|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==(0|0);
   if (!($58)) {
    $59 = (($this) + 100|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==($57|0);
    if ($61) {
     $77 = $57;
    } else {
     $63 = $60;
     while(1) {
      $62 = (($63) + -24|0);
      HEAP32[$59>>2] = $62;
      $64 = (($63) + -12|0);
      $65 = HEAP8[$64>>0]|0;
      $66 = $65 & 1;
      $67 = ($66<<24>>24)==(0);
      if (!($67)) {
       $68 = (($63) + -4|0);
       $69 = HEAP32[$68>>2]|0;
       __ZdlPv($69);
      }
      $70 = HEAP8[$62>>0]|0;
      $71 = $70 & 1;
      $72 = ($71<<24>>24)==(0);
      if (!($72)) {
       $75 = (($63) + -16|0);
       $76 = HEAP32[$75>>2]|0;
       __ZdlPv($76);
      }
      $73 = HEAP32[$59>>2]|0;
      $74 = ($73|0)==($57|0);
      if ($74) {
       break;
      } else {
       $63 = $73;
      }
     }
     $$pre$i$i$i13 = HEAP32[$56>>2]|0;
     $77 = $$pre$i$i$i13;
    }
    __ZdlPv($77);
   }
   $78 = (($this) + 84|0);
   $79 = HEAP8[$78>>0]|0;
   $80 = $79 & 1;
   $81 = ($80<<24>>24)==(0);
   if (!($81)) {
    $82 = (($this) + 92|0);
    $83 = HEAP32[$82>>2]|0;
    __ZdlPv($83);
   }
   $84 = (($this) + 72|0);
   $85 = HEAP8[$84>>0]|0;
   $86 = $85 & 1;
   $87 = ($86<<24>>24)==(0);
   if (!($87)) {
    $88 = (($this) + 80|0);
    $89 = HEAP32[$88>>2]|0;
    __ZdlPv($89);
   }
   $90 = (($this) + 64|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)>(-1);
   do {
    if ($92) {
     $93 = (($this) + 52|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = (($this) + 56|0);
     $96 = HEAP32[$95>>2]|0;
     HEAP32[$0>>2] = $96;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($94|0),($$byval_copy7|0));
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      $118 = ___cxa_find_matching_catch()|0;
      $119 = tempRet0;
      $$3 = $119;$$34 = $118;
      break L7;
     } else {
      HEAP32[$93>>2] = 0;
      break;
     }
    }
   } while(0);
   $99 = HEAP32[$this>>2]|0;
   $100 = ($99|0)==(0|0);
   if ($100) {
    STACKTOP = sp;return;
   }
   $101 = HEAP32[$42>>2]|0;
   $102 = ($101|0)==($99|0);
   if (!($102)) {
    $__new_last2$i$i$i$i$i20 = $99;
    $scevgep$i$i$i$i$i21 = (($101) + -4|0);
    $103 = (0 - ($__new_last2$i$i$i$i$i20))|0;
    $uglygep$i$i$i$i$i23 = (($scevgep$i$i$i$i$i21) + ($103)|0);
    $uglygep3$i$i$i$i$i24 = $uglygep$i$i$i$i$i23;
    $104 = $uglygep3$i$i$i$i$i24 >>> 2;
    $105 = $104 ^ -1;
    $scevgep4$i$i$i$i$i25 = (($101) + ($105<<2)|0);
    HEAP32[$42>>2] = $scevgep4$i$i$i$i$i25;
   }
   __ZdlPv($99);
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 7) {
   $19 = (($this) + 96|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = (($this) + 100|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==($20|0);
    if ($24) {
     $40 = $20;
    } else {
     $26 = $23;
     while(1) {
      $25 = (($26) + -24|0);
      HEAP32[$22>>2] = $25;
      $27 = (($26) + -12|0);
      $28 = HEAP8[$27>>0]|0;
      $29 = $28 & 1;
      $30 = ($29<<24>>24)==(0);
      if (!($30)) {
       $31 = (($26) + -4|0);
       $32 = HEAP32[$31>>2]|0;
       __ZdlPv($32);
      }
      $33 = HEAP8[$25>>0]|0;
      $34 = $33 & 1;
      $35 = ($34<<24>>24)==(0);
      if (!($35)) {
       $38 = (($26) + -16|0);
       $39 = HEAP32[$38>>2]|0;
       __ZdlPv($39);
      }
      $36 = HEAP32[$22>>2]|0;
      $37 = ($36|0)==($20|0);
      if ($37) {
       break;
      } else {
       $26 = $36;
      }
     }
     $$pre$i$i$i = HEAP32[$19>>2]|0;
     $40 = $$pre$i$i$i;
    }
    __ZdlPv($40);
   }
   $106 = (($this) + 84|0);
   $107 = HEAP8[$106>>0]|0;
   $108 = $107 & 1;
   $109 = ($108<<24>>24)==(0);
   if (!($109)) {
    $110 = (($this) + 92|0);
    $111 = HEAP32[$110>>2]|0;
    __ZdlPv($111);
   }
   $112 = (($this) + 72|0);
   $113 = HEAP8[$112>>0]|0;
   $114 = $113 & 1;
   $115 = ($114<<24>>24)==(0);
   if (!($115)) {
    $116 = (($this) + 80|0);
    $117 = HEAP32[$116>>2]|0;
    __ZdlPv($117);
   }
   $120 = (($this) + 64|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($121|0)>(-1);
   if ($122) {
    $123 = (($this) + 52|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (($this) + 56|0);
    $126 = HEAP32[$125>>2]|0;
    HEAP32[$0>>2] = $126;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($124|0),($$byval_copy7|0));
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     $137 = ___cxa_find_matching_catch(0|0)|0;
     $138 = tempRet0;
     ___clang_call_terminate($137);
     // unreachable;
    } else {
     HEAP32[$123>>2] = 0;
     $$3 = $lpad$phi$index2;$$34 = $lpad$phi$index;
     break;
    }
   } else {
    $$3 = $lpad$phi$index2;$$34 = $lpad$phi$index;
   }
  }
 } while(0);
 $129 = HEAP32[$this>>2]|0;
 $130 = ($129|0)==(0|0);
 if ($130) {
  ___resumeException($$34|0);
  // unreachable;
 }
 $131 = (($this) + 4|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($132|0)==($129|0);
 if (!($133)) {
  $__new_last2$i$i$i$i$i = $129;
  $scevgep$i$i$i$i$i = (($132) + -4|0);
  $134 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($134)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $135 = $uglygep3$i$i$i$i$i >>> 2;
  $136 = $135 ^ -1;
  $scevgep4$i$i$i$i$i = (($132) + ($136<<2)|0);
  HEAP32[$131>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($129);
 ___resumeException($$34|0);
 // unreachable;
}
function __ZNK9ShaderLab9IntShader6GetTagEib($this,$tagID,$firstSubShaderOnly) {
 $this = $this|0;
 $tagID = $tagID|0;
 $firstSubShaderOnly = $firstSubShaderOnly|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i8 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i2 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i3 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$022 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($firstSubShaderOnly) {
  $4 = (($this) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$this>>2]|0;
  $7 = (($6) + ($5<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 24|0);
  $12 = ($10|0)==(0|0);
  if ($12) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0$ph7$i$i$i2 = $11;$$01$ph6$i$in$i$i3 = $10;
  }
  L5: while(1) {
   $$013$i$in$i$i5 = $$01$ph6$i$in$i$i3;
   while(1) {
    $13 = (($$013$i$in$i$i5) + 16|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)<($tagID|0);
    if (!($15)) {
     break;
    }
    $18 = (($$013$i$in$i$i5) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     $$0$ph5$i$i$i8 = $$0$ph7$i$i$i2;
     break L5;
    } else {
     $$013$i$in$i$i5 = $19;
    }
   }
   $16 = HEAP32[$$013$i$in$i$i5>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $$0$ph5$i$i$i8 = $$013$i$in$i$i5;
    break;
   } else {
    $$0$ph7$i$i$i2 = $$013$i$in$i$i5;$$01$ph6$i$in$i$i3 = $16;
   }
  }
  $21 = ($$0$ph5$i$i$i8|0)==($11|0);
  if ($21) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $22 = (($$0$ph5$i$i$i8) + 16|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>($tagID|0);
  if ($24) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $25 = (($$0$ph5$i$i$i8) + 20|0);
  $26 = HEAP32[$25>>2]|0;
  $$0 = $26;
  STACKTOP = sp;return ($$0|0);
 }
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$022 = 0;
 }
 while(1) {
  $27 = (($2) + ($i$022<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 24|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 24|0);
  $32 = ($30|0)==(0|0);
  if (!($32)) {
   $$0$ph7$i$i$i = $31;$$01$ph6$i$in$i$i = $30;
   L25: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $33 = (($$013$i$in$i$i) + 16|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)<($tagID|0);
     if (!($35)) {
      break;
     }
     $38 = (($$013$i$in$i$i) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L25;
     } else {
      $$013$i$in$i$i = $39;
     }
    }
    $36 = HEAP32[$$013$i$in$i$i>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $36;
    }
   }
   $41 = ($$0$ph5$i$i$i|0)==($31|0);
   if (!($41)) {
    $42 = (($$0$ph5$i$i$i) + 16|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)>($tagID|0);
    if (!($44)) {
     break;
    }
   }
  }
  $47 = (($i$022) + 1)|0;
  $48 = $1;
  $49 = $2;
  $50 = (($48) - ($49))|0;
  $51 = $50 >> 2;
  $52 = ($47>>>0)<($51>>>0);
  if ($52) {
   $i$022 = $47;
  } else {
   $$0 = -1;
   label = 20;
   break;
  }
 }
 if ((label|0) == 20) {
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($$0$ph5$i$i$i) + 20|0);
 $46 = HEAP32[$45>>2]|0;
 $$0 = $46;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK9ShaderLab9IntShader13GetDependencyERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__lhs_sz$05$i = 0, $__lhs_sz$05$i$us = 0, $__lp$03$i = 0, $__lp$03$i$us = 0, $__rp$04$i = 0, $__rp$04$i$us = 0, $i$06 = 0, $i$07 = 0;
 var $i$07$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 24)&-1;
 $8 = ($1|0)==($3|0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = HEAP8[$name>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 $12 = $9&255;
 $13 = $12 >>> 1;
 $14 = (($name) + 1|0);
 $15 = (($name) + 8|0);
 $16 = (($name) + 4|0);
 L4: do {
  if ($11) {
   $i$07$us = 0;
   while(1) {
    $17 = (($3) + (($i$07$us*24)|0)|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18 & 1;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     $23 = $18&255;
     $24 = $23 >>> 1;
     $26 = $24;
    } else {
     $21 = ((($3) + (($i$07$us*24)|0)|0) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $26 = $22;
    }
    $25 = ($26|0)==($13|0);
    L27: do {
     if ($25) {
      if (!($20)) {
       $27 = ((($3) + (($i$07$us*24)|0)|0) + 8|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = (_memcmp($28,$14,$13)|0);
       $30 = ($29|0)==(0);
       if ($30) {
        $i$06 = $i$07$us;
        break L4;
       } else {
        break;
       }
      }
      $31 = (($17) + 1|0);
      $32 = ($13|0)==(0);
      if ($32) {
       $i$06 = $i$07$us;
       break L4;
      } else {
       $__lhs_sz$05$i$us = $13;$__lp$03$i$us = $31;$__rp$04$i$us = $14;
      }
      while(1) {
       $33 = HEAP8[$__lp$03$i$us>>0]|0;
       $34 = HEAP8[$__rp$04$i$us>>0]|0;
       $35 = ($33<<24>>24)==($34<<24>>24);
       if (!($35)) {
        break L27;
       }
       $38 = (($__lhs_sz$05$i$us) + -1)|0;
       $39 = (($__lp$03$i$us) + 1|0);
       $40 = (($__rp$04$i$us) + 1|0);
       $41 = ($38|0)==(0);
       if ($41) {
        $i$06 = $i$07$us;
        break L4;
       } else {
        $__lhs_sz$05$i$us = $38;$__lp$03$i$us = $39;$__rp$04$i$us = $40;
       }
      }
     }
    } while(0);
    $36 = (($i$07$us) + 1)|0;
    $37 = ($36>>>0)<($7>>>0);
    if ($37) {
     $i$07$us = $36;
    } else {
     $$0 = 0;
     break;
    }
   }
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$07 = 0;
   while(1) {
    $42 = (($3) + (($i$07*24)|0)|0);
    $43 = HEAP8[$42>>0]|0;
    $44 = $43 & 1;
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     $48 = $43&255;
     $49 = $48 >>> 1;
     $52 = $49;
    } else {
     $46 = ((($3) + (($i$07*24)|0)|0) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $52 = $47;
    }
    $50 = HEAP32[$16>>2]|0;
    $51 = ($52|0)==($50|0);
    L11: do {
     if ($51) {
      if (!($45)) {
       $63 = ((($3) + (($i$07*24)|0)|0) + 8|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = HEAP32[$15>>2]|0;
       $66 = (_memcmp($64,$65,$52)|0);
       $67 = ($66|0)==(0);
       if ($67) {
        $i$06 = $i$07;
        break L4;
       } else {
        break;
       }
      }
      $53 = (($42) + 1|0);
      $54 = HEAP32[$15>>2]|0;
      $55 = ($52|0)==(0);
      if ($55) {
       $i$06 = $i$07;
       break L4;
      } else {
       $__lhs_sz$05$i = $52;$__lp$03$i = $53;$__rp$04$i = $54;
      }
      while(1) {
       $56 = HEAP8[$__lp$03$i>>0]|0;
       $57 = HEAP8[$__rp$04$i>>0]|0;
       $58 = ($56<<24>>24)==($57<<24>>24);
       if (!($58)) {
        break L11;
       }
       $59 = (($__lhs_sz$05$i) + -1)|0;
       $60 = (($__lp$03$i) + 1|0);
       $61 = (($__rp$04$i) + 1|0);
       $62 = ($59|0)==(0);
       if ($62) {
        $i$06 = $i$07;
        break L4;
       } else {
        $__lhs_sz$05$i = $59;$__lp$03$i = $60;$__rp$04$i = $61;
       }
      }
     }
    } while(0);
    $69 = (($i$07) + 1)|0;
    $70 = ($69>>>0)<($7>>>0);
    if ($70) {
     $i$07 = $69;
    } else {
     $$0 = 0;
     break;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $68 = ((($3) + (($i$06*24)|0)|0) + 12|0);
 $$0 = $68;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK9ShaderLab9IntShader14GetRenderQueueEi($this,$subshaderIndex) {
 $this = $this|0;
 $subshaderIndex = $subshaderIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + ($subshaderIndex<<2)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 if (!($5)) {
  $8 = $4;
  STACKTOP = sp;return ($8|0);
 }
 $6 = (($this) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZNK9ShaderLab9IntShader14MakePropertiesEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(84,$$byval_copy1,0,16,652840,84)|0);
 $3 = (($this) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vii(3238,($2|0),($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  STACKTOP = sp;return ($2|0);
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($2|0),($$byval_copy1|0),0,16,(652840|0),84);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN9ShaderLab9IntShader8PostLoadEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i11 = 0, $$0$ph5$i$i$i49 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i43 = 0, $$0$ph7$i$i$i5 = 0, $$01 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i44 = 0, $$01$ph6$i$in$i$i6 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i46 = 0, $$013$i$in$i$i8 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$lcssa78 = 0, $$pre$phi95Z2D = 0;
 var $$pre$phiZ2D = 0, $$pre$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond = 0, $i$079 = 0, $i1$072 = 0, $i2$075 = 0, $or$cond = 0, $or$cond97 = 0, $queueName = 0, $rp$077 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 84|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $queueName = sp + 48|0;
 $5 = sp + 60|0;
 $6 = sp + 72|0;
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = ($8|0)==($9|0);
 if ($10) {
  $$lcssa78 = 0;
 } else {
  $12 = $9;$i$079 = 0;
  while(1) {
   $11 = (($12) + ($i$079<<2)|0);
   $13 = HEAP32[$11>>2]|0;
   __ZN9ShaderLab9SubShader8PostLoadEv($13);
   $14 = (($i$079) + 1)|0;
   $15 = HEAP32[$7>>2]|0;
   $16 = HEAP32[$this>>2]|0;
   $17 = $15;
   $18 = $16;
   $19 = (($17) - ($18))|0;
   $20 = $19 >> 2;
   $21 = ($14>>>0)<($20>>>0);
   if ($21) {
    $12 = $16;$i$079 = $14;
   } else {
    $$lcssa78 = $20;
    break;
   }
  }
 }
 $22 = (($this) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(-1);
 $25 = $24 ? 2147483647 : $23;
 $26 = (($this) + 32|0);
 HEAP32[$26>>2] = -1;
 $27 = ($$lcssa78|0)==(0);
 $rp$077 = 0;
 while(1) {
  $28 = ((($this) + ($rp$077<<2)|0) + 12|0);
  HEAP32[$28>>2] = -1;
  L7: do {
   if (!($27)) {
    $29 = HEAP32[$this>>2]|0;
    $30 = 1 << $rp$077;
    $i1$072 = 0;
    while(1) {
     $31 = (($29) + ($i1$072<<2)|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($32) + 16|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)>(0);
     if ($35) {
      $36 = (($32) + 32|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = ($37|0)>($25|0);
      if (!($38)) {
       $39 = HEAP32[$26>>2]|0;
       $40 = ($39|0)<(0);
       if ($40) {
        HEAP32[$26>>2] = $i1$072;
       }
       $41 = (($32) + 36|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = $42 & $30;
       $44 = ($43|0)==(0);
       if (!($44)) {
        break;
       }
      }
     }
     $45 = (($i1$072) + 1)|0;
     $46 = ($45>>>0)<($$lcssa78>>>0);
     if ($46) {
      $i1$072 = $45;
     } else {
      break L7;
     }
    }
    HEAP32[$28>>2] = $i1$072;
   }
  } while(0);
  $47 = ($rp$077|0)==(1);
  if ($47) {
   $48 = (($rp$077) + 1)|0;
   $rp$077 = $48;
   continue;
  }
  $49 = HEAP32[$28>>2]|0;
  $50 = ($49|0)!=(-1);
  $51 = ($rp$077|0)>(0);
  $or$cond = $50 & $51;
  L23: do {
   if ($or$cond) {
    $i2$075 = 0;
    while(1) {
     $52 = ((($this) + ($i2$075<<2)|0) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)!=(-1);
     $55 = ($53|0)<($49|0);
     $or$cond97 = $54 & $55;
     if ($or$cond97) {
      break;
     }
     $56 = (($i2$075) + 1)|0;
     $57 = ($56|0)<($rp$077|0);
     if ($57) {
      $i2$075 = $56;
     } else {
      break L23;
     }
    }
    HEAP32[$28>>2] = -1;
   }
  } while(0);
  $58 = (($rp$077) + 1)|0;
  $exitcond = ($58|0)==(5);
  if ($exitcond) {
   break;
  } else {
   $rp$077 = $58;
  }
 }
 $59 = HEAP32[$26>>2]|0;
 $60 = ($59|0)<(0);
 if ($60) {
  HEAP32[$26>>2] = 0;
  $63 = 0;
 } else {
  $63 = $59;
 }
 $61 = HEAP32[$this>>2]|0;
 $62 = (($61) + ($63<<2)|0);
 $64 = HEAP32[$62>>2]|0;
 $65 = HEAP8[652992>>0]|0;
 $66 = ($65<<24>>24)==(0);
 do {
  if ($66) {
   HEAP8[$0>>0] = 10;
   $67 = (($0) + 1|0);
   ;HEAP8[$67+0>>0]=HEAP8[653000+0>>0]|0;HEAP8[$67+1>>0]=HEAP8[653000+1>>0]|0;HEAP8[$67+2>>0]=HEAP8[653000+2>>0]|0;HEAP8[$67+3>>0]=HEAP8[653000+3>>0]|0;HEAP8[$67+4>>0]=HEAP8[653000+4>>0]|0;
   $68 = (($0) + 6|0);
   HEAP8[$68>>0] = 0;
   __THREW__ = 0;
   $69 = (invoke_ii(3224,($0|0))|0);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if (!($71)) {
    $72 = HEAP8[$0>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    if (!($74)) {
     $75 = (($0) + 8|0);
     $76 = HEAP32[$75>>2]|0;
     __ZdlPv($76);
    }
    HEAP32[652984>>2] = $69;
    HEAP8[652992>>0] = 1;
    break;
   }
   $207 = ___cxa_find_matching_catch()|0;
   $208 = tempRet0;
   $209 = HEAP8[$0>>0]|0;
   $210 = $209 & 1;
   $211 = ($210<<24>>24)==(0);
   if ($211) {
    $$2 = $208;$$23 = $207;
    ___resumeException($$23|0);
    // unreachable;
   }
   $212 = (($0) + 8|0);
   $213 = HEAP32[$212>>2]|0;
   __ZdlPv($213);
   $$2 = $208;$$23 = $207;
   ___resumeException($$23|0);
   // unreachable;
  }
 } while(0);
 $77 = HEAP8[653016>>0]|0;
 $78 = ($77<<24>>24)==(0);
 do {
  if ($78) {
   $79 = (__Znwj(16)|0);
   $80 = (($1) + 8|0);
   HEAP32[$80>>2] = $79;
   HEAP32[$1>>2] = 17;
   $81 = (($1) + 4|0);
   HEAP32[$81>>2] = 15;
   dest=$79+0|0; src=653024+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $82 = (($79) + 15|0);
   HEAP8[$82>>0] = 0;
   __THREW__ = 0;
   $83 = (invoke_ii(3224,($1|0))|0);
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   if (!($85)) {
    $86 = HEAP8[$1>>0]|0;
    $87 = $86 & 1;
    $88 = ($87<<24>>24)==(0);
    if (!($88)) {
     $89 = HEAP32[$80>>2]|0;
     __ZdlPv($89);
    }
    HEAP32[653008>>2] = $83;
    HEAP8[653016>>0] = 1;
    break;
   }
   $214 = ___cxa_find_matching_catch()|0;
   $215 = tempRet0;
   $216 = HEAP8[$1>>0]|0;
   $217 = $216 & 1;
   $218 = ($217<<24>>24)==(0);
   if ($218) {
    $$2 = $215;$$23 = $214;
    ___resumeException($$23|0);
    // unreachable;
   }
   $219 = HEAP32[$80>>2]|0;
   __ZdlPv($219);
   $$2 = $215;$$23 = $214;
   ___resumeException($$23|0);
   // unreachable;
  }
 } while(0);
 $90 = HEAP8[653048>>0]|0;
 $91 = ($90<<24>>24)==(0);
 do {
  if ($91) {
   $92 = (__Znwj(16)|0);
   $93 = (($2) + 8|0);
   HEAP32[$93>>2] = $92;
   HEAP32[$2>>2] = 17;
   $94 = (($2) + 4|0);
   HEAP32[$94>>2] = 15;
   dest=$92+0|0; src=653056+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $95 = (($92) + 15|0);
   HEAP8[$95>>0] = 0;
   __THREW__ = 0;
   $96 = (invoke_ii(3224,($2|0))|0);
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   if (!($98)) {
    $99 = HEAP8[$2>>0]|0;
    $100 = $99 & 1;
    $101 = ($100<<24>>24)==(0);
    if (!($101)) {
     $102 = HEAP32[$93>>2]|0;
     __ZdlPv($102);
    }
    HEAP32[653040>>2] = $96;
    HEAP8[653048>>0] = 1;
    break;
   }
   $220 = ___cxa_find_matching_catch()|0;
   $221 = tempRet0;
   $222 = HEAP8[$2>>0]|0;
   $223 = $222 & 1;
   $224 = ($223<<24>>24)==(0);
   if ($224) {
    $$2 = $221;$$23 = $220;
    ___resumeException($$23|0);
    // unreachable;
   }
   $225 = HEAP32[$93>>2]|0;
   __ZdlPv($225);
   $$2 = $221;$$23 = $220;
   ___resumeException($$23|0);
   // unreachable;
  }
 } while(0);
 $103 = HEAP8[653080>>0]|0;
 $104 = ($103<<24>>24)==(0);
 do {
  if ($104) {
   HEAP8[$3>>0] = 8;
   $105 = (($3) + 1|0);
   HEAP8[$105>>0]=1702195828&255;HEAP8[$105+1>>0]=(1702195828>>8)&255;HEAP8[$105+2>>0]=(1702195828>>16)&255;HEAP8[$105+3>>0]=1702195828>>24;
   $106 = (($3) + 5|0);
   HEAP8[$106>>0] = 0;
   __THREW__ = 0;
   $107 = (invoke_ii(3224,($3|0))|0);
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if (!($109)) {
    $110 = HEAP8[$3>>0]|0;
    $111 = $110 & 1;
    $112 = ($111<<24>>24)==(0);
    if (!($112)) {
     $113 = (($3) + 8|0);
     $114 = HEAP32[$113>>2]|0;
     __ZdlPv($114);
    }
    HEAP32[653072>>2] = $107;
    HEAP8[653080>>0] = 1;
    break;
   }
   $226 = ___cxa_find_matching_catch()|0;
   $227 = tempRet0;
   $228 = HEAP8[$3>>0]|0;
   $229 = $228 & 1;
   $230 = ($229<<24>>24)==(0);
   if ($230) {
    $$2 = $227;$$23 = $226;
    ___resumeException($$23|0);
    // unreachable;
   }
   $231 = (($3) + 8|0);
   $232 = HEAP32[$231>>2]|0;
   __ZdlPv($232);
   $$2 = $227;$$23 = $226;
   ___resumeException($$23|0);
   // unreachable;
  }
 } while(0);
 $115 = HEAP8[653096>>0]|0;
 $116 = ($115<<24>>24)==(0);
 do {
  if ($116) {
   HEAP8[$4>>0] = 18;
   $117 = (($4) + 1|0);
   dest=$117+0|0; src=653104+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $118 = (($4) + 10|0);
   HEAP8[$118>>0] = 0;
   __THREW__ = 0;
   $119 = (invoke_ii(3224,($4|0))|0);
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if (!($121)) {
    $122 = HEAP8[$4>>0]|0;
    $123 = $122 & 1;
    $124 = ($123<<24>>24)==(0);
    if (!($124)) {
     $125 = (($4) + 8|0);
     $126 = HEAP32[$125>>2]|0;
     __ZdlPv($126);
    }
    HEAP32[653088>>2] = $119;
    HEAP8[653096>>0] = 1;
    break;
   }
   $233 = ___cxa_find_matching_catch()|0;
   $234 = tempRet0;
   $235 = HEAP8[$4>>0]|0;
   $236 = $235 & 1;
   $237 = ($236<<24>>24)==(0);
   if ($237) {
    $$2 = $234;$$23 = $233;
    ___resumeException($$23|0);
    // unreachable;
   }
   $238 = (($4) + 8|0);
   $239 = HEAP32[$238>>2]|0;
   __ZdlPv($239);
   $$2 = $234;$$23 = $233;
   ___resumeException($$23|0);
   // unreachable;
  }
 } while(0);
 $127 = (($this) + 36|0);
 HEAP32[$127>>2] = 2000;
 $128 = (($64) + 24|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = (($64) + 24|0);
 $131 = ($129|0)==(0|0);
 L98: do {
  if (!($131)) {
   $132 = HEAP32[652984>>2]|0;
   $$0$ph7$i$i$i43 = $130;$$01$ph6$i$in$i$i44 = $129;
   L100: while(1) {
    $$013$i$in$i$i46 = $$01$ph6$i$in$i$i44;
    while(1) {
     $133 = (($$013$i$in$i$i46) + 16|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = ($134|0)<($132|0);
     if (!($135)) {
      break;
     }
     $138 = (($$013$i$in$i$i46) + 4|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = ($139|0)==(0|0);
     if ($140) {
      $$0$ph5$i$i$i49 = $$0$ph7$i$i$i43;
      break L100;
     } else {
      $$013$i$in$i$i46 = $139;
     }
    }
    $136 = HEAP32[$$013$i$in$i$i46>>2]|0;
    $137 = ($136|0)==(0|0);
    if ($137) {
     $$0$ph5$i$i$i49 = $$013$i$in$i$i46;
     break;
    } else {
     $$0$ph7$i$i$i43 = $$013$i$in$i$i46;$$01$ph6$i$in$i$i44 = $136;
    }
   }
   $141 = ($$0$ph5$i$i$i49|0)==($130|0);
   if (!($141)) {
    $142 = (($$0$ph5$i$i$i49) + 16|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = ($132|0)<($143|0);
    if (!($144)) {
     $145 = (($$0$ph5$i$i$i49) + 20|0);
     $146 = HEAP32[$145>>2]|0;
     __ZN9ShaderLab16GetShaderTagNameEi($queueName,$146);
     __THREW__ = 0;
     $147 = (invoke_iii(2533,($queueName|0),($127|0))|0);
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     L109: do {
      if ($149) {
       $240 = ___cxa_find_matching_catch()|0;
       $241 = tempRet0;
       $$pre$pre$phiZZ2D = $queueName;$eh$lpad$body$index3Z2D = $241;$eh$lpad$body$indexZ2D = $240;
       label = 94;
      } else {
       L111: do {
        if ($147) {
         $$pre$phi95Z2D = $queueName;
        } else {
         ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
         $150 = HEAP8[$queueName>>0]|0;
         $151 = $150 & 1;
         $152 = ($151<<24>>24)==(0);
         if ($152) {
          $155 = $150&255;
          $156 = $155 >>> 1;
          $158 = $156;
         } else {
          $153 = (($queueName) + 4|0);
          $154 = HEAP32[$153>>2]|0;
          $158 = $154;
         }
         $157 = (($158) + 18)|0;
         $159 = ($157>>>0)>(4294967279);
         do {
          if ($159) {
           __THREW__ = 0;
           invoke_vi(3309,0);
           $160 = __THREW__; __THREW__ = 0;
           $161 = $160&1;
           if (!($161)) {
            // unreachable;
           }
          } else {
           $162 = ($157>>>0)<(11);
           if ($162) {
            HEAP8[$6>>0] = 36;
            $163 = (($6) + 1|0);
            $__p$0$i$i = $163;
           } else {
            $164 = (($158) + 34)|0;
            $165 = $164 & -16;
            __THREW__ = 0;
            $166 = (invoke_ii(2988,($165|0))|0);
            $167 = __THREW__; __THREW__ = 0;
            $168 = $167&1;
            if ($168) {
             break;
            }
            $169 = (($6) + 8|0);
            HEAP32[$169>>2] = $166;
            $170 = $165 | 1;
            HEAP32[$6>>2] = $170;
            $171 = (($6) + 4|0);
            HEAP32[$171>>2] = 18;
            $__p$0$i$i = $166;
           }
           dest=$__p$0$i$i+0|0; src=653120+0|0; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $172 = (($__p$0$i$i) + 18|0);
           HEAP8[$172>>0] = 0;
           if ($152) {
            $175 = (($queueName) + 1|0);
            $176 = $175;
           } else {
            $173 = (($queueName) + 8|0);
            $174 = HEAP32[$173>>2]|0;
            $176 = $174;
           }
           __THREW__ = 0;
           (invoke_iiii(1480,($6|0),($176|0),($158|0))|0);
           $177 = __THREW__; __THREW__ = 0;
           $178 = $177&1;
           if ($178) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(1627,($5|0),($6|0),(653144|0));
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           do {
            if ($187) {
             $242 = ___cxa_find_matching_catch()|0;
             $243 = tempRet0;
             $$0 = $243;$$01 = $242;
            } else {
             $188 = HEAP8[$5>>0]|0;
             $189 = $188 & 1;
             $190 = ($189<<24>>24)==(0);
             if ($190) {
              $193 = (($5) + 1|0);
              $194 = $193;
             } else {
              $191 = (($5) + 8|0);
              $192 = HEAP32[$191>>2]|0;
              $194 = $192;
             }
             __THREW__ = 0;
             invoke_viiiiiiii(21,($194|0),0,(652840|0),214,1,0,0,(0|0));
             $195 = __THREW__; __THREW__ = 0;
             $196 = $195&1;
             if ($196) {
              $244 = ___cxa_find_matching_catch()|0;
              $245 = tempRet0;
              $246 = HEAP8[$5>>0]|0;
              $247 = $246 & 1;
              $248 = ($247<<24>>24)==(0);
              if ($248) {
               $$0 = $245;$$01 = $244;
               break;
              }
              $249 = (($5) + 8|0);
              $250 = HEAP32[$249>>2]|0;
              __ZdlPv($250);
              $$0 = $245;$$01 = $244;
              break;
             }
             $197 = HEAP8[$5>>0]|0;
             $198 = $197 & 1;
             $199 = ($198<<24>>24)==(0);
             if (!($199)) {
              $200 = (($5) + 8|0);
              $201 = HEAP32[$200>>2]|0;
              __ZdlPv($201);
             }
             $202 = HEAP8[$6>>0]|0;
             $203 = $202 & 1;
             $204 = ($203<<24>>24)==(0);
             if ($204) {
              $$pre$phi95Z2D = $queueName;
              break L111;
             }
             $205 = (($6) + 8|0);
             $206 = HEAP32[$205>>2]|0;
             __ZdlPv($206);
             $$pre$phi95Z2D = $queueName;
             break L111;
            }
           } while(0);
           $251 = HEAP8[$6>>0]|0;
           $252 = $251 & 1;
           $253 = ($252<<24>>24)==(0);
           if ($253) {
            $$1 = $$0;$$12 = $$01;$$pre$phiZ2D = $queueName;
            break L109;
           }
           $254 = (($6) + 8|0);
           $255 = HEAP32[$254>>2]|0;
           __ZdlPv($255);
           $$1 = $$0;$$12 = $$01;$$pre$phiZ2D = $queueName;
           break L109;
          }
         } while(0);
         $179 = ___cxa_find_matching_catch()|0;
         $180 = tempRet0;
         $181 = HEAP8[$6>>0]|0;
         $182 = $181 & 1;
         $183 = ($182<<24>>24)==(0);
         if ($183) {
          $$pre$pre$phiZZ2D = $queueName;$eh$lpad$body$index3Z2D = $180;$eh$lpad$body$indexZ2D = $179;
          label = 94;
          break L109;
         }
         $184 = (($6) + 8|0);
         $185 = HEAP32[$184>>2]|0;
         __ZdlPv($185);
         $$pre$pre$phiZZ2D = $queueName;$eh$lpad$body$index3Z2D = $180;$eh$lpad$body$indexZ2D = $179;
         label = 94;
         break L109;
        }
       } while(0);
       $256 = HEAP8[$$pre$phi95Z2D>>0]|0;
       $257 = $256 & 1;
       $258 = ($257<<24>>24)==(0);
       if ($258) {
        break L98;
       }
       $259 = (($queueName) + 8|0);
       $260 = HEAP32[$259>>2]|0;
       __ZdlPv($260);
       break L98;
      }
     } while(0);
     if ((label|0) == 94) {
      $$1 = $eh$lpad$body$index3Z2D;$$12 = $eh$lpad$body$indexZ2D;$$pre$phiZ2D = $$pre$pre$phiZZ2D;
     }
     $261 = HEAP8[$$pre$phiZ2D>>0]|0;
     $262 = $261 & 1;
     $263 = ($262<<24>>24)==(0);
     if ($263) {
      $$2 = $$1;$$23 = $$12;
      ___resumeException($$23|0);
      // unreachable;
     }
     $264 = (($queueName) + 8|0);
     $265 = HEAP32[$264>>2]|0;
     __ZdlPv($265);
     $$2 = $$1;$$23 = $$12;
     ___resumeException($$23|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $266 = (($this) + 44|0);
 HEAP8[$266>>0] = 0;
 $267 = HEAP32[$128>>2]|0;
 $268 = ($267|0)==(0|0);
 if ($268) {
  $269 = (($this) + 48|0);
  HEAP32[$269>>2] = 0;
  STACKTOP = sp;return;
 }
 $270 = HEAP32[653008>>2]|0;
 $$0$ph7$i$i$i5 = $130;$$01$ph6$i$in$i$i6 = $267;
 L166: while(1) {
  $$013$i$in$i$i8 = $$01$ph6$i$in$i$i6;
  while(1) {
   $271 = (($$013$i$in$i$i8) + 16|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = ($272|0)<($270|0);
   if (!($273)) {
    break;
   }
   $276 = (($$013$i$in$i$i8) + 4|0);
   $277 = HEAP32[$276>>2]|0;
   $278 = ($277|0)==(0|0);
   if ($278) {
    $$0$ph5$i$i$i11 = $$0$ph7$i$i$i5;
    break L166;
   } else {
    $$013$i$in$i$i8 = $277;
   }
  }
  $274 = HEAP32[$$013$i$in$i$i8>>2]|0;
  $275 = ($274|0)==(0|0);
  if ($275) {
   $$0$ph5$i$i$i11 = $$013$i$in$i$i8;
   break;
  } else {
   $$0$ph7$i$i$i5 = $$013$i$in$i$i8;$$01$ph6$i$in$i$i6 = $274;
  }
 }
 $279 = ($$0$ph5$i$i$i11|0)==($130|0);
 if (!($279)) {
  $280 = (($$0$ph5$i$i$i11) + 16|0);
  $281 = HEAP32[$280>>2]|0;
  $282 = ($270|0)<($281|0);
  if (!($282)) {
   $283 = (($$0$ph5$i$i$i11) + 20|0);
   $284 = HEAP32[$283>>2]|0;
   $285 = HEAP32[653072>>2]|0;
   $286 = ($284|0)==($285|0);
   if ($286) {
    HEAP8[$266>>0] = 1;
   }
  }
 }
 $287 = (($this) + 48|0);
 HEAP32[$287>>2] = 0;
 if ($268) {
  STACKTOP = sp;return;
 }
 $288 = HEAP32[653040>>2]|0;
 $$0$ph7$i$i$i = $130;$$01$ph6$i$in$i$i = $267;
 L181: while(1) {
  $$013$i$in$i$i = $$01$ph6$i$in$i$i;
  while(1) {
   $289 = (($$013$i$in$i$i) + 16|0);
   $290 = HEAP32[$289>>2]|0;
   $291 = ($290|0)<($288|0);
   if (!($291)) {
    break;
   }
   $294 = (($$013$i$in$i$i) + 4|0);
   $295 = HEAP32[$294>>2]|0;
   $296 = ($295|0)==(0|0);
   if ($296) {
    $$0$ph5$i$i$i = $$0$ph7$i$i$i;
    break L181;
   } else {
    $$013$i$in$i$i = $295;
   }
  }
  $292 = HEAP32[$$013$i$in$i$i>>2]|0;
  $293 = ($292|0)==(0|0);
  if ($293) {
   $$0$ph5$i$i$i = $$013$i$in$i$i;
   break;
  } else {
   $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $292;
  }
 }
 $297 = ($$0$ph5$i$i$i|0)==($130|0);
 if ($297) {
  STACKTOP = sp;return;
 }
 $298 = (($$0$ph5$i$i$i) + 16|0);
 $299 = HEAP32[$298>>2]|0;
 $300 = ($288|0)<($299|0);
 if ($300) {
  STACKTOP = sp;return;
 }
 $301 = (($$0$ph5$i$i$i) + 20|0);
 $302 = HEAP32[$301>>2]|0;
 $303 = HEAP32[653072>>2]|0;
 $304 = ($302|0)==($303|0);
 if ($304) {
  HEAP32[$287>>2] = 1;
  STACKTOP = sp;return;
 }
 $305 = HEAP32[653088>>2]|0;
 $306 = ($302|0)==($305|0);
 if (!($306)) {
  STACKTOP = sp;return;
 }
 HEAP32[$287>>2] = 2;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab19ParseQueueAndOffsetERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERi($str,$outQueue) {
 $str = $str|0;
 $outQueue = $outQueue|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $endpointer = 0, $i$04 = 0, $uppercased = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $uppercased = sp + 4|0;
 $endpointer = sp;
 __Z7ToUpperINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_($uppercased,$str);
 $0 = HEAP8[$uppercased>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = (($uppercased) + 1|0);
  $19 = $5;
 } else {
  $3 = (($uppercased) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $19 = $4;
 }
 $6 = (($str) + 4|0);
 $i$04 = 0;
 while(1) {
  $7 = HEAP8[$str>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   $11 = $7&255;
   $12 = $11 >>> 1;
   $16 = $12;
  } else {
   $10 = HEAP32[$6>>2]|0;
   $16 = $10;
  }
  $13 = ((652848 + (($i$04*12)|0)|0) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($16|0)<($14|0);
  if (!($15)) {
   $17 = (652848 + (($i$04*12)|0)|0);
   $18 = HEAP32[$17>>2]|0;
   $20 = (_memcmp($19,$18,$14)|0);
   $21 = ($20|0)==(0);
   if ($21) {
    if ($9) {
     $23 = $7&255;
     $24 = $23 >>> 1;
     $26 = $24;
    } else {
     $22 = HEAP32[$6>>2]|0;
     $26 = $22;
    }
    $25 = ($26|0)==($14|0);
    if ($25) {
     label = 14;
     break;
    }
    HEAP32[$endpointer>>2] = 0;
    $29 = (($19) + ($14)|0);
    $30 = (_strtol($29,$endpointer,10)|0);
    $31 = HEAP32[$endpointer>>2]|0;
    $32 = ($31|0)==($29|0);
    if (!($32)) {
     label = 16;
     break;
    }
   }
  }
  $36 = (($i$04) + 1)|0;
  $37 = ($36>>>0)<(5);
  if ($37) {
   $i$04 = $36;
  } else {
   $$0 = 0;
   break;
  }
 }
 if ((label|0) == 14) {
  $27 = ((652848 + (($i$04*12)|0)|0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$outQueue>>2] = $28;
  $$0 = 1;
 }
 else if ((label|0) == 16) {
  $33 = ((652848 + (($i$04*12)|0)|0) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) + ($30))|0;
  HEAP32[$outQueue>>2] = $35;
  $$0 = 1;
 }
 $38 = HEAP8[$uppercased>>0]|0;
 $39 = $38 & 1;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return ($$0|0);
 }
 $41 = (($uppercased) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 __ZdlPv($42);
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab9IntShader15ResolveFallbackERKNS_12ParserShaderEP6ShaderRNSt3__16vectorI4PPtrIS4_ENS6_9allocatorIS9_EEEEbR12ShaderErrors($this,$parsed,$dstShader,$dependenciesTable,$useDependenciesTable,$outErrors) {
 $this = $this|0;
 $parsed = $parsed|0;
 $dstShader = $dstShader|0;
 $dependenciesTable = $dependenciesTable|0;
 $useDependenciesTable = $useDependenciesTable|0;
 $outErrors = $outErrors|0;
 var $$ = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$4 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$05 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (($this) + 84|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $9 = $7;
 } else {
  $4 = (($this) + 88|0);
  $5 = HEAP32[$4>>2]|0;
  $9 = $5;
 }
 $8 = ($9|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $10 = (__Z19FindShaderLabShaderRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_6vectorI4PPtrI6ShaderENS3_ISB_EEEEb($0,$dependenciesTable,$useDependenciesTable)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  $95 = HEAP8[674240>>0]|0;
  $96 = $95 & 1;
  $97 = ($96<<24>>24)==(0);
  $98 = HEAP32[((674240 + 8|0))>>2]|0;
  $$4 = $97 ? ((674240 + 1|0)) : $98;
  $99 = HEAP8[$0>>0]|0;
  $100 = $99 & 1;
  $101 = ($100<<24>>24)==(0);
  if ($101) {
   $104 = (($0) + 1|0);
   $105 = $104;
  } else {
   $102 = (($this) + 92|0);
   $103 = HEAP32[$102>>2]|0;
   $105 = $103;
  }
  HEAP32[$vararg_buffer2>>2] = $$4;
  $vararg_ptr5 = (($vararg_buffer2) + 4|0);
  HEAP32[$vararg_ptr5>>2] = $105;
  _printf_console(653208,$vararg_buffer2);
  STACKTOP = sp;return;
 }
 $12 = (($10) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = HEAP8[674240>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  $18 = HEAP32[((674240 + 8|0))>>2]|0;
  $$ = $17 ? ((674240 + 1|0)) : $18;
  $19 = HEAP8[$0>>0]|0;
  $20 = $19 & 1;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   $24 = (($0) + 1|0);
   $25 = $24;
  } else {
   $22 = (($this) + 92|0);
   $23 = HEAP32[$22>>2]|0;
   $25 = $23;
  }
  HEAP32[$vararg_buffer2>>2] = $$;
  $vararg_ptr1 = (($vararg_buffer2) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $25;
  _printf_console(653152,$vararg_buffer2);
  STACKTOP = sp;return;
 }
 $26 = (($this) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$this>>2]|0;
 $29 = $27;
 $30 = $28;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 2;
 $33 = (($13) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$13>>2]|0;
 $36 = $34;
 $37 = $35;
 $38 = (($36) - ($37))|0;
 $39 = $38 >> 2;
 $40 = (($39) + ($32))|0;
 $41 = (($this) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42;
 $44 = (($43) - ($30))|0;
 $45 = $44 >> 2;
 $46 = ($45>>>0)<($40>>>0);
 if ($46) {
  $47 = ($40|0)==(0);
  if ($47) {
   $51 = 0;
  } else {
   $48 = $40 << 2;
   $49 = (__Znwj($48)|0);
   $51 = $49;
  }
  $50 = (($51) + ($32<<2)|0);
  $52 = (($51) + ($40<<2)|0);
  _memcpy(($51|0),($28|0),($31|0))|0;
  HEAP32[$this>>2] = $51;
  HEAP32[$26>>2] = $50;
  HEAP32[$41>>2] = $52;
  $53 = ($28|0)==(0|0);
  if (!($53)) {
   __ZdlPv($28);
  }
 }
 $54 = HEAP32[$33>>2]|0;
 $55 = HEAP32[$13>>2]|0;
 $56 = ($54|0)==($55|0);
 if ($56) {
  STACKTOP = sp;return;
 } else {
  $58 = $55;$i$05 = 0;
 }
 while(1) {
  $57 = (($58) + ($i$05<<2)|0);
  $59 = HEAP32[$57>>2]|0;
  $60 = (__ZN9ShaderLab9SubShader19CreateFromSubShaderERKS0_($59)|0);
  $61 = HEAP32[$26>>2]|0;
  $62 = HEAP32[$41>>2]|0;
  $63 = ($61|0)==($62|0);
  if ($63) {
   $67 = HEAP32[$this>>2]|0;
   $68 = $61;
   $69 = $67;
   $70 = (($68) - ($69))|0;
   $71 = $70 >> 2;
   $72 = (($71) + 1)|0;
   $73 = ($72>>>0)>(1073741823);
   if ($73) {
    label = 22;
    break;
   }
   $74 = ($71>>>0)<(536870911);
   if ($74) {
    $75 = $70 >> 1;
    $76 = ($75>>>0)<($72>>>0);
    $77 = $76 ? $72 : $75;
    $78 = ($77|0)==(0);
    if ($78) {
     $$0$i3$i$i = 0;$82 = 0;
    } else {
     $$0$i2$i$i = $77;
     label = 25;
    }
   } else {
    $$0$i2$i$i = 1073741823;
    label = 25;
   }
   if ((label|0) == 25) {
    label = 0;
    $79 = $$0$i2$i$i << 2;
    $80 = (__Znwj($79)|0);
    $$0$i3$i$i = $$0$i2$i$i;$82 = $80;
   }
   $81 = (($82) + ($71<<2)|0);
   $83 = (($82) + ($$0$i3$i$i<<2)|0);
   $84 = ($81|0)==(0|0);
   if (!($84)) {
    HEAP32[$81>>2] = $60;
   }
   $85 = (($82) + ($72<<2)|0);
   _memcpy(($82|0),($67|0),($70|0))|0;
   HEAP32[$this>>2] = $82;
   HEAP32[$26>>2] = $85;
   HEAP32[$41>>2] = $83;
   $86 = ($67|0)==(0|0);
   if (!($86)) {
    __ZdlPv($67);
   }
  } else {
   $64 = ($61|0)==(0|0);
   if ($64) {
    $66 = 0;
   } else {
    HEAP32[$61>>2] = $60;
    $$pre$i = HEAP32[$26>>2]|0;
    $66 = $$pre$i;
   }
   $65 = (($66) + 4|0);
   HEAP32[$26>>2] = $65;
  }
  $87 = (($i$05) + 1)|0;
  $88 = HEAP32[$33>>2]|0;
  $89 = HEAP32[$13>>2]|0;
  $90 = $88;
  $91 = $89;
  $92 = (($90) - ($91))|0;
  $93 = $92 >> 2;
  $94 = ($87>>>0)<($93>>>0);
  if ($94) {
   $58 = $89;$i$05 = $87;
  } else {
   label = 35;
   break;
  }
 }
 if ((label|0) == 22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 35) {
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab9IntShader27RemoveUnsupportedSubShadersEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$in = 0, $$pre = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $hadShadowPasses = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $hadShadowPasses = sp + 8|0;
 HEAP8[$hadShadowPasses>>0] = 0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 68|0);
 $$in = $7;$12 = $3;
 while(1) {
  $10 = (($$in) + -1)|0;
  $11 = (($12) + ($10<<2)|0);
  $13 = HEAP32[$11>>2]|0;
  $14 = HEAP32[$9>>2]|0;
  $15 = (__ZN9ShaderLab9SubShader20IsSubShaderSupportedEPKNS_13PropertySheetERb($13,$14,$hadShadowPasses)|0);
  if (!($15)) {
   $17 = HEAP32[$this>>2]|0;
   $18 = (($17) + ($10<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[628272>>2]|0;
   $21 = ($19|0)==(0|0);
   if (!($21)) {
    __ZN9ShaderLab9SubShaderD2Ev($19);
   }
   HEAP32[$0>>2] = $20;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy);
   HEAP32[$18>>2] = 0;
   $22 = HEAP32[$this>>2]|0;
   $23 = $18;
   $24 = $22;
   $25 = (($23) - ($24))|0;
   $26 = $25 >> 2;
   $27 = (($22) + ($26<<2)|0);
   $$sum$i = (($26) + 1)|0;
   $28 = (($22) + ($$sum$i<<2)|0);
   $29 = HEAP32[$1>>2]|0;
   $30 = $29;
   $31 = $28;
   $32 = (($30) - ($31))|0;
   $33 = $32 >> 2;
   _memmove(($27|0),($28|0),($32|0))|0;
   $$sum1$i = (($33) + ($26))|0;
   $34 = (($22) + ($$sum1$i<<2)|0);
   $35 = HEAP32[$1>>2]|0;
   $36 = ($35|0)==($34|0);
   if (!($36)) {
    $__new_last2$i$i$i = $34;
    $scevgep$i$i$i = (($35) + -4|0);
    $37 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($37)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $38 = $uglygep3$i$i$i >>> 2;
    $39 = $38 ^ -1;
    $scevgep4$i$i$i = (($35) + ($39<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i;
   }
  }
  $16 = ($10|0)==(0);
  if ($16) {
   break;
  }
  $$pre = HEAP32[$this>>2]|0;
  $$in = $10;$12 = $$pre;
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9IntShader10LinkShaderERNSt3__16vectorI4PPtrI6ShaderENS1_9allocatorIS5_EEEEbR12ShaderErrors($this,$dependenciesTable,$useDependenciesTable,$outErrors) {
 $this = $this|0;
 $dependenciesTable = $dependenciesTable|0;
 $useDependenciesTable = $useDependenciesTable|0;
 $outErrors = $outErrors|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$07 = 0, $p$03 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  $6 = $3;$i$07 = 0;
  while(1) {
   $5 = ((($6) + (($i$07*24)|0)|0) + 12|0);
   $7 = (__Z19FindShaderLabShaderRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_6vectorI4PPtrI6ShaderENS3_ISB_EEEEb($5,$dependenciesTable,$useDependenciesTable)|0);
   $8 = ($7|0)==(0|0);
   if ($8) {
    $9 = HEAP8[674240>>0]|0;
    $10 = $9 & 1;
    $11 = ($10<<24>>24)==(0);
    $12 = HEAP32[((674240 + 8|0))>>2]|0;
    $$ = $11 ? ((674240 + 1|0)) : $12;
    $13 = (($6) + (($i$07*24)|0)|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = $14 & 1;
    $16 = ($15<<24>>24)==(0);
    if ($16) {
     $19 = (($13) + 1|0);
     $26 = $19;
    } else {
     $17 = ((($6) + (($i$07*24)|0)|0) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     $26 = $18;
    }
    $20 = HEAP8[$5>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $25 = (($5) + 1|0);
     $27 = $25;
    } else {
     $23 = ((($6) + (($i$07*24)|0)|0) + 20|0);
     $24 = HEAP32[$23>>2]|0;
     $27 = $24;
    }
    HEAP32[$vararg_buffer>>2] = $$;
    $vararg_ptr1 = (($vararg_buffer) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $26;
    $vararg_ptr2 = (($vararg_buffer) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $27;
    _printf_console(653256,$vararg_buffer);
   }
   $28 = (($i$07) + 1)|0;
   $29 = HEAP32[$0>>2]|0;
   $30 = HEAP32[$2>>2]|0;
   $31 = $29;
   $32 = $30;
   $33 = (($31) - ($32))|0;
   $34 = (($33|0) / 24)&-1;
   $35 = ($28>>>0)<($34>>>0);
   if ($35) {
    $6 = $30;$i$07 = $28;
   } else {
    break;
   }
  }
 }
 __ZN9ShaderLab9IntShader27RemoveUnsupportedSubShadersEv($this);
 $36 = HEAP32[$this>>2]|0;
 $37 = (($this) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($36|0)==($38|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 68|0);
 $41 = (($this) + 52|0);
 $43 = $36;
 while(1) {
  $42 = HEAP32[$43>>2]|0;
  $44 = HEAP32[$40>>2]|0;
  __ZN9ShaderLab9SubShader15CollectChannelsEPKNS_13PropertySheetE($42,$44);
  $45 = (($42) + 16|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)>(0);
  if ($47) {
   $p$03 = 0;
   while(1) {
    $48 = HEAP32[$42>>2]|0;
    $49 = (($48) + ($p$03<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + 4|0);
    $52 = HEAP32[$40>>2]|0;
    __ZN9ShaderLab11ShaderState29FindPropsAffectingStateBlocksERKNS_13PropertySheetER13dynamic_arrayIiLj4EE($51,$52,$41);
    $53 = (($p$03) + 1)|0;
    $54 = HEAP32[$45>>2]|0;
    $55 = ($53|0)<($54|0);
    if ($55) {
     $p$03 = $53;
    } else {
     break;
    }
   }
  }
  $56 = (($43) + 4|0);
  $57 = HEAP32[$37>>2]|0;
  $58 = ($56|0)==($57|0);
  if ($58) {
   break;
  } else {
   $43 = $56;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9IntShader23CreateStateBlocksForKeyEjPKNS_13PropertySheetERKNS_17ShaderPassContextE($this,$key,$props,$passContext) {
 $this = $this|0;
 $key = $key|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $19 = $2;$5 = $0;
 }
 while(1) {
  $4 = HEAP32[$5>>2]|0;
  $6 = (($4) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)>(0);
  if ($8) {
   $p$01 = 0;
   while(1) {
    $9 = HEAP32[$4>>2]|0;
    $10 = (($9) + ($p$01<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($11) + 4|0);
    __ZN9ShaderLab11ShaderState17BuildDeviceStatesEjPKNS_13PropertySheetERKNS_17ShaderPassContextE($12,$key,$props,$passContext);
    $13 = (($p$01) + 1)|0;
    $14 = HEAP32[$6>>2]|0;
    $15 = ($13|0)<($14|0);
    if ($15) {
     $p$01 = $13;
    } else {
     break;
    }
   }
   $$pre = HEAP32[$1>>2]|0;
   $18 = $$pre;
  } else {
   $18 = $19;
  }
  $16 = (($5) + 4|0);
  $17 = ($16|0)==($18|0);
  if ($17) {
   break;
  } else {
   $19 = $18;$5 = $16;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab4PassC2ENS0_8PassTypeE($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 __ZN9ShaderLab11ShaderStateC2Ev($0);
 $1 = (($this) + 592|0);
 __THREW__ = 0;
 invoke_vi(3476,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($this) + 628|0);
  ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  $5 = (($this) + 640|0);
  HEAP32[$5>>2] = $type;
  $6 = (($this) + 644|0);
  HEAP32[$6>>2] = 0;
  $7 = (($this) + 648|0);
  HEAP32[$7>>2] = 0;
  $8 = (($this) + 652|0);
  HEAP32[$8>>2] = 0;
  $9 = (($this) + 656|0);
  HEAP32[$9>>2] = 1;
  $10 = (($this) + 660|0);
  HEAP32[$10>>2] = 0;
  $11 = (($this) + 668|0);
  HEAP32[$11>>2] = 0;
  $12 = (($this) + 672|0);
  HEAP32[$12>>2] = 0;
  $13 = (($this) + 668|0);
  $14 = (($this) + 664|0);
  HEAP32[$14>>2] = $13;
  $15 = (($this) + 676|0);
  HEAP32[$15>>2] = -1;
  $16 = (($this) + 680|0);
  ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
  STACKTOP = sp;return;
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3588,($0|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  ___resumeException($17|0);
  // unreachable;
 }
}
function __ZN9ShaderLab4PassD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i4 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 648|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZdaPv($2);
 }
 __THREW__ = 0;
 $4 = (invoke_i(59)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = HEAP32[$4>>2]|0;
  $8 = (($7) + 200|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($this) + 652|0);
  __THREW__ = 0;
  invoke_vii($9|0,($4|0),($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = (($this) + 680|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    $16 = (($this) + 684|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==($14|0);
    if (!($18)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i = $14;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i = (($17) + -4|0);
     $19 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i) + ($19)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i;
     $20 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i >>> 2;
     $21 = $20 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i = (($17) + ($21<<2)|0);
     HEAP32[$16>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($14);
   }
   $22 = (($this) + 664|0);
   $23 = (($this) + 668|0);
   $24 = HEAP32[$23>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($22,$24);
   $25 = (($this) + 628|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    $35 = (($this) + 4|0);
    __ZN9ShaderLab11ShaderStateD2Ev($35);
    STACKTOP = sp;return;
   }
   $29 = (($this) + 636|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($30|0),($$byval_copy1|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $33 = ___cxa_find_matching_catch()|0;
    $34 = tempRet0;
    ___cxa_call_unexpected(($33|0));
    // unreachable;
   } else {
    $35 = (($this) + 4|0);
    __ZN9ShaderLab11ShaderStateD2Ev($35);
    STACKTOP = sp;return;
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = (($this) + 680|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = (($this) + 684|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($39|0);
  if (!($43)) {
   $__new_last2$i$i$i$i$i$i$i$i$i$i$i4 = $39;
   $scevgep$i$i$i$i$i$i$i$i$i$i$i5 = (($42) + -4|0);
   $44 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i4))|0;
   $uglygep$i$i$i$i$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i5) + ($44)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i$i$i$i$i7;
   $45 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i8 >>> 2;
   $46 = $45 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i$i$i9 = (($42) + ($46<<2)|0);
   HEAP32[$41>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i9;
  }
  __ZdlPv($39);
 }
 $47 = (($this) + 664|0);
 $48 = (($this) + 668|0);
 $49 = HEAP32[$48>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($47,$49);
 $50 = (($this) + 628|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = $51 & 1;
 $53 = ($52<<24>>24)==(0);
 if (!($53)) {
  $54 = (($this) + 636|0);
  $55 = HEAP32[$54>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($55|0),($$byval_copy1|0));
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   ___cxa_call_unexpected(($58|0));
   // unreachable;
  }
 }
 $60 = (($this) + 4|0);
 __THREW__ = 0;
 invoke_vi(3588,($60|0));
 $61 = __THREW__; __THREW__ = 0;
 $62 = $61&1;
 if ($62) {
  $63 = ___cxa_find_matching_catch(0|0)|0;
  $64 = tempRet0;
  ___clang_call_terminate($63);
  // unreachable;
 } else {
  ___resumeException($36|0);
  // unreachable;
 }
}
function __ZN9ShaderLab4Pass6RetainEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 656|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab4Pass7ReleaseEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 656|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -1)|0;
 HEAP32[$1>>2] = $3;
 $4 = ($3|0)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 __ZN9ShaderLab4PassD2Ev($this);
 $5 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab19GetTexEnvForBindingERKNS_14TextureBindingEPKNS_13PropertySheetERKNS_17ShaderPassContextE($binding,$props,$passContext) {
 $binding = $binding|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $location$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $location$i = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[$binding>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZN9ShaderLab11shaderprops9GetTexEnvEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameE16TextureDimensionRNS0_16PropertyLocationE($props,$passContext,$$byval_copy,5,$location$i)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN9ShaderLab23ClearGrabPassFrameStateEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z22GetRenderBufferManagerv()|0);
 $1 = HEAP32[653544>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($0,$1);
  HEAP32[653544>>2] = 0;
 }
 $3 = HEAP32[653568>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $i$01 = 0;
 } else {
  HEAP32[653568>>2] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $5 = HEAP32[653552>>2]|0;
  $6 = ((($5) + ($i$01<<3)|0) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($0,$7);
  $8 = (($i$01) + 1)|0;
  $exitcond = ($8|0)==($3|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $8;
  }
 }
 HEAP32[653568>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab4Pass9ApplyPassEjPKNS_13PropertySheetERKNS_17ShaderPassContextEP6Shaderi($this,$stateKey,$props,$passContext,$fromShader,$passIndex) {
 $this = $this|0;
 $stateKey = $stateKey|0;
 $props = $props|0;
 $passContext = $passContext|0;
 $fromShader = $fromShader|0;
 $passIndex = $passIndex|0;
 var $$0 = 0, $$byval_copy2 = 0, $$in$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$i$i = 0, $existingTexture$02$i$i = 0, $existingTexture$1$off0$i$i = 0, $height$0$i$i = 0, $i$07$i$i = 0, $r$i$i = 0, $r1$i$i = 0, $rect$i$i = 0, $rt$1$i$i = 0, $rt$15$i$i = 0, $width$0$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy2 = sp + 64|0;
 $0 = sp;
 $r$i$i = sp + 8|0;
 $r1$i$i = sp + 24|0;
 $rect$i$i = sp + 40|0;
 $1 = sp + 56|0;
 $2 = sp + 60|0;
 $3 = (__Z12GetGfxDevicev()|0);
 $4 = (($this) + 640|0);
 $5 = HEAP32[$4>>2]|0;
 if ((($5|0) == 2)) {
  $20 = (($this) + 676|0);
  $21 = (__Z16GetRenderManagerv()|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0);
  if ($23) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$1>>2] = $22;
  $24 = HEAP32[560624>>2]|0;
  $25 = ($24|0)==(0|0);
  if ($25) {
   label = 14;
  } else {
   $26 = (($24) + 36|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($24) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)==($29|0);
   do {
    if ($30) {
     $31 = (($24) + 28|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($24) + 32|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + ($34<<3)|0);
     $51 = $35;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$24,$1);
     $36 = HEAP32[$$byval_copy2>>2]|0;
     $37 = ($36|0)==(-1);
     $38 = (($24) + 28|0);
     $39 = HEAP32[$38>>2]|0;
     if ($37) {
      $40 = (($24) + 32|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($39) + ($41<<3)|0);
      $51 = $42;
      break;
     } else {
      $43 = (($39) + ($36<<3)|0);
      $51 = $43;
      break;
     }
    }
   } while(0);
   $44 = HEAP32[560624>>2]|0;
   $45 = (($44) + 28|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 32|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($46) + ($48<<3)|0);
   $50 = ($51|0)==($49|0);
   if ($50) {
    label = 14;
   } else {
    $52 = (($51) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     label = 14;
    } else {
     $$in$i = $53;
    }
   }
  }
  if ((label|0) == 14) {
   $55 = HEAP32[$21>>2]|0;
   $56 = (__Z31ReadObjectFromPersistentManageri($55)|0);
   $57 = ($56|0)==(0|0);
   if ($57) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$in$i = $56;
   }
  }
  $58 = (__ZN13RenderTexture9GetActiveEv()|0);
  $59 = ($58|0)==(0|0);
  if ($59) {
   __ZNK6Camera13GetCameraRectEb($r$i$i,$$in$i,1);
   $64 = (($r$i$i) + 8|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = Math_fround($65 + Math_fround(0.5));
   $67 = (~~(($66))>>>0);
   $68 = (($r$i$i) + 12|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($69 + Math_fround(0.5));
   $71 = (~~(($70))>>>0);
   $height$0$i$i = $71;$width$0$i$i = $67;
  } else {
   $60 = (($58) + 100|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($58) + 104|0);
   $63 = HEAP32[$62>>2]|0;
   $height$0$i$i = $63;$width$0$i$i = $61;
  }
  $72 = (__Z22GetRenderBufferManagerv()|0);
  $73 = HEAP32[$20>>2]|0;
  $74 = ($73|0)==(-1);
  L24: do {
   if ($74) {
    $75 = HEAP32[653544>>2]|0;
    $76 = ($75|0)==(0|0);
    if (!($76)) {
     __ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture($72,$75);
     HEAP32[653544>>2] = 0;
    }
    $77 = (($$in$i) + 620|0);
    $78 = HEAP8[$77>>0]|0;
    $79 = ($78<<24>>24)!=(0);
    $80 = $79 ? 9 : 7;
    $81 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($72,$width$0$i$i,$height$0$i$i,2,$80,0,0,1)|0);
    $82 = ($81|0)==(0|0);
    if (!($82)) {
     $83 = HEAP32[$81>>2]|0;
     $84 = (($83) + 36|0);
     $85 = HEAP32[$84>>2]|0;
     FUNCTION_TABLE_vii[$85 & 4095]($81,653928);
    }
    HEAP32[653544>>2] = $81;
    $existingTexture$1$off0$i$i = 0;$rt$1$i$i = $81;
    label = 38;
   } else {
    $86 = HEAP32[653568>>2]|0;
    $87 = ($86|0)>(0);
    L33: do {
     if ($87) {
      $88 = HEAP32[653552>>2]|0;
      $i$07$i$i = 0;
      while(1) {
       $91 = (($88) + ($i$07$i$i<<3)|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = ($92|0)==($73|0);
       $90 = (($i$07$i$i) + 1)|0;
       if ($93) {
        break;
       }
       $89 = ($90|0)<($86|0);
       if ($89) {
        $i$07$i$i = $90;
       } else {
        $existingTexture$02$i$i = 0;
        break L33;
       }
      }
      $94 = ((($88) + ($i$07$i$i<<3)|0) + 4|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = ($95|0)==(0|0);
      if ($96) {
       $existingTexture$02$i$i = 1;
      } else {
       $rt$15$i$i = $95;
       break L24;
      }
     } else {
      $existingTexture$02$i$i = 0;
     }
    } while(0);
    $97 = (($$in$i) + 620|0);
    $98 = HEAP8[$97>>0]|0;
    $99 = ($98<<24>>24)!=(0);
    $100 = $99 ? 9 : 7;
    $101 = (__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei($72,$width$0$i$i,$height$0$i$i,2,$100,0,0,1)|0);
    $102 = ($101|0)==(0|0);
    if (!($102)) {
     $103 = HEAP32[$101>>2]|0;
     $104 = (($103) + 36|0);
     $105 = HEAP32[$104>>2]|0;
     FUNCTION_TABLE_vii[$105 & 4095]($101,653928);
    }
    $106 = HEAP32[$20>>2]|0;
    $107 = HEAP32[653568>>2]|0;
    $108 = (($107) + 1)|0;
    HEAP32[653568>>2] = $108;
    $109 = HEAP32[653576>>2]|0;
    $110 = $109 & 2147483647;
    $111 = ($108>>>0)>($110>>>0);
    if ($111) {
     $112 = $109 << 1;
     $113 = ($112|0)==(0);
     $114 = $113 ? 1 : $112;
     $115 = ($110>>>0)<($114>>>0);
     do {
      if ($115) {
       $116 = ($109|0)>(-1);
       if ($116) {
        HEAP32[653576>>2] = $114;
        $117 = HEAP32[653552>>2]|0;
        $118 = $114 << 3;
        $119 = HEAP32[653560>>2]|0;
        HEAP32[$0>>2] = $119;
        ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
        $120 = (__Z16realloc_internalPvji10MemLabelIdiPKci($117,$118,4,$$byval_copy2,0,653904,370)|0);
        HEAP32[653552>>2] = $120;
        break;
       } else {
        $121 = $114 << 3;
        $122 = HEAP32[653560>>2]|0;
        HEAP32[$0>>2] = $122;
        ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
        $123 = (__Z15malloc_internaljj10MemLabelIdiPKci($121,4,$$byval_copy2,0,653904,352)|0);
        $124 = HEAP32[653552>>2]|0;
        $125 = HEAP32[653568>>2]|0;
        $126 = $125 << 3;
        _memcpy(($123|0),($124|0),($126|0))|0;
        HEAP32[653576>>2] = $114;
        HEAP32[653552>>2] = $123;
        break;
       }
      }
     } while(0);
     $$pre$i$i$i$i = HEAP32[653568>>2]|0;
     $128 = $$pre$i$i$i$i;
    } else {
     $128 = $108;
    }
    $127 = (($128) + -1)|0;
    $129 = HEAP32[653552>>2]|0;
    $130 = (($129) + ($127<<3)|0);
    HEAP32[$130>>2] = $106;
    $131 = ((($129) + ($127<<3)|0) + 4|0);
    HEAP32[$131>>2] = $101;
    $existingTexture$1$off0$i$i = $existingTexture$02$i$i;$rt$1$i$i = $101;
    label = 38;
   }
  } while(0);
  if ((label|0) == 38) {
   $132 = ($rt$1$i$i|0)==(0|0);
   $brmerge$i$i = $132 | $existingTexture$1$off0$i$i;
   if ($brmerge$i$i) {
    $rt$15$i$i = $rt$1$i$i;
   } else {
    __ZNK6Camera18GetRenderRectangleEv($r1$i$i,$$in$i);
    __Z14RectfToRectIntRK5RectTIfE($rect$i$i,$r1$i$i);
    $133 = HEAP32[$rect$i$i>>2]|0;
    $134 = (($rect$i$i) + 4|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($rect$i$i) + 8|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = (($rect$i$i) + 12|0);
    $139 = HEAP32[$138>>2]|0;
    __ZN13RenderTexture10GrabPixelsEiiii($rt$1$i$i,$133,$135,$137,$139);
    __ZN13RenderTexture24CorrectVerticalTexelSizeEb($rt$1$i$i,0);
    $rt$15$i$i = $rt$1$i$i;
   }
  }
  $140 = ($rt$15$i$i|0)==(0|0);
  if ($140) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $141 = HEAP32[$20>>2]|0;
  $142 = ($141|0)!=(-1);
  $143 = $142 ? $20 : 653520;
  __ZN7Texture13SetFilterModeEi($rt$15$i$i,1);
  (__ZN13RenderTexture17SetGlobalPropertyERKN9ShaderLab16FastPropertyNameE($rt$15$i$i,$143)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($5|0) == 0)) {
  $6 = (($this) + 4|0);
  $7 = (__ZN9ShaderLab11ShaderState16ApplyShaderStateEjPKNS_13PropertySheetERKNS_17ShaderPassContextEP6ShaderPNS_4PassE($6,$stateKey,$props,$passContext,$fromShader,$this)|0);
  $8 = HEAP32[$3>>2]|0;
  $9 = (($8) + 228|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_iii[$10 & 4095]($3,2)|0);
  if (!($11)) {
   $12 = HEAP32[$3>>2]|0;
   $13 = (($12) + 204|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($this) + 652|0);
   $16 = HEAP32[$15>>2]|0;
   HEAP32[$2>>2] = $16;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   FUNCTION_TABLE_viiii[$14 & 511]($3,$$byval_copy2,$props,$passContext);
  }
  $17 = ($7|0)!=(0|0);
  $18 = (($this) + 592|0);
  $19 = $17 ? $7 : $18;
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9ShaderLab4Pass20BuildDefaultChannelsEPKNS_13PropertySheetE($this,$props) {
 $this = $this|0;
 $props = $props|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $texDim = 0, $tu$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $texDim = sp + 4|0;
 $1 = (($this) + 592|0);
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,0,0);
 $2 = (($this) + 224|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,1,2);
 }
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,2,1);
 }
 $8 = (($this) + 644|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 648|0);
 $tu$01 = 0;
 while(1) {
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[652824>>2]|0;
  $14 = (($12) + (($tu$01*52)|0)|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[$0>>2] = $15;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN9ShaderLab11shaderprops13GetTexEnvInfoEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameER16TextureDimension($props,$13,$$byval_copy,$texDim);
  $16 = (($tu$01) + 4)|0;
  __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($1,3,$16);
  $17 = (($tu$01) + 1)|0;
  $18 = HEAP32[$8>>2]|0;
  $19 = ($17|0)<($18|0);
  if ($19) {
   $tu$01 = $17;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab4Pass19CollectPassChannelsEPKNS_13PropertySheetE($this,$props) {
 $this = $this|0;
 $props = $props|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 592|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  __ZN9ShaderLab4Pass20BuildDefaultChannelsEPKNS_13PropertySheetE($this,$props);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 300|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  __ZN14ChannelAssigns6UnbindE15VertexComponent($0,3);
  STACKTOP = sp;return;
 }
 $6 = (($this) + 603|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 << 24 >> 24;
 $9 = ($7<<24>>24)==(-1);
 if (!($9)) {
  $10 = (($this) + 644|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)>(0);
  if ($12) {
   $13 = (($props) + 48|0);
   $14 = (($props) + 48|0);
   $15 = (($this) + 648|0);
   $40 = $11;$i$05 = 0;
   while(1) {
    $16 = HEAP32[$13>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $39 = $40;
    } else {
     $18 = HEAP32[$15>>2]|0;
     $19 = (($18) + (($i$05*52)|0)|0);
     $20 = HEAP32[$19>>2]|0;
     $$0$ph7$i$i$i$i = $14;$$01$ph6$i$in$i$i$i = $16;
     L17: while(1) {
      $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
      while(1) {
       $21 = (($$013$i$in$i$i$i) + 16|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($22|0)<($20|0);
       if (!($23)) {
        break;
       }
       $26 = (($$013$i$in$i$i$i) + 4|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($27|0)==(0|0);
       if ($28) {
        $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
        break L17;
       } else {
        $$013$i$in$i$i$i = $27;
       }
      }
      $24 = HEAP32[$$013$i$in$i$i$i>>2]|0;
      $25 = ($24|0)==(0|0);
      if ($25) {
       $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
       break;
      } else {
       $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $24;
      }
     }
     $29 = ($$0$ph5$i$i$i$i|0)==($14|0);
     if ($29) {
      $39 = $40;
     } else {
      $30 = (($$0$ph5$i$i$i$i) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($20|0)<($31|0);
      if ($32) {
       $39 = $40;
      } else {
       $33 = (($$0$ph5$i$i$i$i) + 20|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ($34|0)==(0|0);
       if ($35) {
        $39 = $40;
       } else {
        $36 = (($i$05) + 4)|0;
        __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($0,$8,$36);
        $$pre = HEAP32[$10>>2]|0;
        $39 = $$pre;
       }
      }
     }
    }
    $37 = (($i$05) + 1)|0;
    $38 = ($37|0)<($39|0);
    if ($38) {
     $40 = $39;$i$05 = $37;
    } else {
     break;
    }
   }
  }
  __ZN14ChannelAssigns6UnbindE15VertexComponent($0,3);
 }
 __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($0,0,0);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab4Pass15IsPassSupportedEPKNS_13PropertySheetE($this,$props) {
 $this = $this|0;
 $props = $props|0;
 var $$ = 0, $$0 = 0, $$4 = 0, $$5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer12 = 0, $vararg_ptr3 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer12 = sp;
 $0 = (($this) + 640|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 2)) {
  $2 = (__ZN13RenderTexture9IsEnabledEv()|0);
  $3 = HEAP32[((640792 + 232|0))>>2]|0;
  $4 = ($3|0)>(0);
  $or$cond = $2 & $4;
  if (!($or$cond)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $5 = HEAP8[((640792 + 261|0))>>0]|0;
  $6 = ($5<<24>>24)!=(0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 } else if ((($1|0) == 1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $7 = HEAP8[((640792 + 128|0))>>0]|0;
  $8 = ($7<<24>>24)==(0);
  do {
   if ($8) {
    $9 = (($this) + 300|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     $12 = (($this) + 304|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if (!($14)) {
      break;
     }
    }
    _printf_console(653584,$vararg_buffer12);
    $15 = HEAP8[674240>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    $18 = HEAP32[((674240 + 8|0))>>2]|0;
    $$ = $17 ? ((674240 + 1|0)) : $18;
    $19 = (($this) + 628|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $25 = (($19) + 1|0);
     $26 = $25;
    } else {
     $23 = (($this) + 636|0);
     $24 = HEAP32[$23>>2]|0;
     $26 = $24;
    }
    HEAP32[$vararg_buffer12>>2] = $$;
    $vararg_ptr3 = (($vararg_buffer12) + 4|0);
    HEAP32[$vararg_ptr3>>2] = $26;
    _printf_console(653608,$vararg_buffer12);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $27 = (($this) + 4|0);
  $28 = (__ZNK9ShaderLab11ShaderState22IsShaderStateSupportedEv($27)|0);
  if (!($28)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $29 = (($this) + 644|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)>(4);
  if ($31) {
   _printf_console(653584,$vararg_buffer12);
   $32 = HEAP8[674240>>0]|0;
   $33 = $32 & 1;
   $34 = ($33<<24>>24)==(0);
   $35 = HEAP32[((674240 + 8|0))>>2]|0;
   $$4 = $34 ? ((674240 + 1|0)) : $35;
   HEAP32[$vararg_buffer12>>2] = $$4;
   $vararg_ptr9 = (($vararg_buffer12) + 4|0);
   HEAP32[$vararg_ptr9>>2] = 4;
   _printf_console(653696,$vararg_buffer12);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $36 = (($this) + 652|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $39 = (($this) + 224|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   $42 = (($this) + 300|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    $45 = (($this) + 601|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = ($46<<24>>24)==(-1);
    if ($47) {
     $48 = (($this) + 292|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)!=(0);
     $61 = $50;
    } else {
     $61 = 1;
    }
   } else {
    $61 = 1;
   }
  } else {
   $61 = 1;
  }
  $51 = (__Z12GetGfxDevicev()|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + 196|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = HEAP32[$29>>2]|0;
  $56 = (($this) + 648|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (($this) + 225|0);
  $59 = HEAP8[$58>>0]|0;
  $60 = ($59<<24>>24)!=(0);
  $62 = (FUNCTION_TABLE_iiiiiii[$54 & 255]($51,$55,$57,$props,$61,$60)|0);
  HEAP32[$36>>2] = $62;
  $63 = ($62|0)==(0|0);
  if (!($63)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  _printf_console(653584,$vararg_buffer12);
  $64 = HEAP8[674240>>0]|0;
  $65 = $64 & 1;
  $66 = ($65<<24>>24)==(0);
  $67 = HEAP32[((674240 + 8|0))>>2]|0;
  $$5 = $66 ? ((674240 + 1|0)) : $67;
  HEAP32[$vararg_buffer12>>2] = $$5;
  _printf_console(653768,$vararg_buffer12);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9ShaderLab4Pass16SetupPassOptionsEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i30 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i24 = 0, $$01 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i25 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i27 = 0, $$1 = 0, $$12 = 0, $$60 = 0, $$61 = 0, $$ph$i = 0, $$pre$i = 0, $$pre$phi4$iZ2D = 0, $$pre$phi6$iZ2D = 0;
 var $$pre3$i = 0, $$pre5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i$i11 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$0$lcssa = 0, $i$048 = 0, $not$ = 0, $options = 0, $passRenderOptions$2 = 0, $passType$1 = 0, $passType$2 = 0;
 var $typeName = 0, $v$off$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 60|0;
 $1 = sp;
 $typeName = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 36|0;
 $options = sp + 48|0;
 $4 = HEAP8[653824>>0]|0;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   HEAP8[$0>>0] = 18;
   $6 = (($0) + 1|0);
   dest=$6+0|0; src=653832+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $7 = (($0) + 10|0);
   HEAP8[$7>>0] = 0;
   __THREW__ = 0;
   $8 = (invoke_ii(3224,($0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP8[$0>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = (($0) + 8|0);
     $15 = HEAP32[$14>>2]|0;
     __ZdlPv($15);
    }
    HEAP32[653816>>2] = $8;
    HEAP8[653824>>0] = 1;
    break;
   }
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $51 = HEAP8[$0>>0]|0;
   $52 = $51 & 1;
   $53 = ($52<<24>>24)==(0);
   if ($53) {
    $$1 = $50;$$12 = $49;
    ___resumeException($$12|0);
    // unreachable;
   }
   $54 = (($0) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   __ZdlPv($55);
   $$1 = $50;$$12 = $49;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $16 = HEAP8[653856>>0]|0;
 $17 = ($16<<24>>24)==(0);
 do {
  if ($17) {
   $18 = (__Znwj(16)|0);
   $19 = (($1) + 8|0);
   HEAP32[$19>>2] = $18;
   HEAP32[$1>>2] = 17;
   $20 = (($1) + 4|0);
   HEAP32[$20>>2] = 14;
   dest=$18+0|0; src=653864+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $21 = (($18) + 14|0);
   HEAP8[$21>>0] = 0;
   __THREW__ = 0;
   $22 = (invoke_ii(3224,($1|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP8[$1>>0]|0;
    $26 = $25 & 1;
    $27 = ($26<<24>>24)==(0);
    if (!($27)) {
     $28 = HEAP32[$19>>2]|0;
     __ZdlPv($28);
    }
    HEAP32[653848>>2] = $22;
    HEAP8[653856>>0] = 1;
    break;
   }
   $56 = ___cxa_find_matching_catch()|0;
   $57 = tempRet0;
   $58 = HEAP8[$1>>0]|0;
   $59 = $58 & 1;
   $60 = ($59<<24>>24)==(0);
   if ($60) {
    $$1 = $57;$$12 = $56;
    ___resumeException($$12|0);
    // unreachable;
   }
   $61 = HEAP32[$19>>2]|0;
   __ZdlPv($61);
   $$1 = $57;$$12 = $56;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $29 = (($this) + 668|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 668|0);
 $32 = ($30|0)==(0|0);
 L27: do {
  if ($32) {
   label = 19;
  } else {
   $33 = HEAP32[653816>>2]|0;
   $$0$ph7$i$i$i = $31;$$01$ph6$i$in$i$i = $30;
   L29: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $34 = (($$013$i$in$i$i) + 16|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)<($33|0);
     if (!($36)) {
      break;
     }
     $39 = (($$013$i$in$i$i) + 4|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L29;
     } else {
      $$013$i$in$i$i = $40;
     }
    }
    $37 = HEAP32[$$013$i$in$i$i>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $37;
    }
   }
   $42 = ($$0$ph5$i$i$i|0)==($31|0);
   if ($42) {
    label = 19;
   } else {
    $43 = (($$0$ph5$i$i$i) + 16|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($33|0)<($44|0);
    if ($45) {
     label = 19;
    } else {
     $62 = (($$0$ph5$i$i$i) + 20|0);
     $63 = HEAP32[$62>>2]|0;
     __ZN9ShaderLab16GetShaderTagNameEi($typeName,$63);
     $64 = (($2) + 1|0);
     $65 = (($typeName) + 1|0);
     $66 = (($2) + 8|0);
     $67 = (($typeName) + 8|0);
     $68 = (($2) + 4|0);
     $i$048 = 0;
     while(1) {
      $71 = (653472 + ($i$048<<2)|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (_strlen(($72|0))|0);
      $74 = ($73>>>0)>(4294967279);
      if ($74) {
       label = 27;
       break;
      }
      $77 = ($73>>>0)<(11);
      if ($77) {
       $78 = $73 << 1;
       $79 = $78&255;
       HEAP8[$2>>0] = $79;
       $93 = $79;$__p$0$i$i$i11 = $64;
      } else {
       $80 = (($73) + 16)|0;
       $81 = $80 & -16;
       __THREW__ = 0;
       $82 = (invoke_ii(2988,($81|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        label = 37;
        break;
       }
       HEAP32[$66>>2] = $82;
       $85 = $81 | 1;
       HEAP32[$2>>2] = $85;
       HEAP32[$68>>2] = $73;
       $86 = $85&255;
       $93 = $86;$__p$0$i$i$i11 = $82;
      }
      _memcpy(($__p$0$i$i$i11|0),($72|0),($73|0))|0;
      $87 = (($__p$0$i$i$i11) + ($73)|0);
      HEAP8[$87>>0] = 0;
      $88 = HEAP8[$typeName>>0]|0;
      $89 = $88 & 1;
      $90 = ($89<<24>>24)==(0);
      $91 = HEAP32[$67>>2]|0;
      $$ = $90 ? $65 : $91;
      $92 = $93 & 1;
      $94 = ($92<<24>>24)==(0);
      $95 = HEAP32[$66>>2]|0;
      $96 = $94 ? $64 : $95;
      __THREW__ = 0;
      $97 = (invoke_iii(2448,($$|0),($96|0))|0);
      $98 = __THREW__; __THREW__ = 0;
      $99 = $98&1;
      if ($99) {
       label = 40;
       break;
      }
      $100 = HEAP8[$2>>0]|0;
      $101 = $100 & 1;
      $102 = ($101<<24>>24)==(0);
      if (!($102)) {
       $103 = HEAP32[$66>>2]|0;
       __ZdlPv($103);
      }
      $104 = ($97|0)==(0);
      $70 = (($i$048) + 1)|0;
      if ($104) {
       $i$0$lcssa = $i$048;
       label = 42;
       break;
      }
      $69 = ($70|0)<(11);
      if ($69) {
       $i$048 = $70;
      } else {
       $i$0$lcssa = $70;
       label = 42;
       break;
      }
     }
     L51: do {
      if ((label|0) == 27) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        $107 = ___cxa_find_matching_catch()|0;
        $108 = tempRet0;
        $eh$lpad$body$index4Z2D = $108;$eh$lpad$body$indexZ2D = $107;
        label = 39;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 37) {
       $105 = ___cxa_find_matching_catch()|0;
       $106 = tempRet0;
       $eh$lpad$body$index4Z2D = $106;$eh$lpad$body$indexZ2D = $105;
       label = 39;
      }
      else if ((label|0) == 40) {
       $109 = ___cxa_find_matching_catch()|0;
       $110 = tempRet0;
       $111 = HEAP8[$2>>0]|0;
       $112 = $111 & 1;
       $113 = ($112<<24>>24)==(0);
       if ($113) {
        $$0 = $110;$$01 = $109;
       } else {
        $114 = HEAP32[$66>>2]|0;
        __ZdlPv($114);
        $$0 = $110;$$01 = $109;
       }
      }
      else if ((label|0) == 42) {
       $115 = ($i$0$lcssa|0)==(11);
       L55: do {
        if ($115) {
         ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
         $116 = HEAP8[$typeName>>0]|0;
         $117 = $116 & 1;
         $118 = ($117<<24>>24)==(0);
         if ($118) {
          $121 = $116&255;
          $122 = $121 >>> 1;
          $124 = $122;
         } else {
          $119 = (($typeName) + 4|0);
          $120 = HEAP32[$119>>2]|0;
          $124 = $120;
         }
         $123 = (($124) + 19)|0;
         $125 = ($123>>>0)>(4294967279);
         do {
          if ($125) {
           __THREW__ = 0;
           invoke_vi(3309,0);
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if (!($127)) {
            // unreachable;
           }
          } else {
           $128 = ($123>>>0)<(11);
           if ($128) {
            HEAP8[$3>>0] = 38;
            $129 = (($3) + 1|0);
            $__p$0$i$i = $129;
           } else {
            $130 = (($124) + 35)|0;
            $131 = $130 & -16;
            __THREW__ = 0;
            $132 = (invoke_ii(2988,($131|0))|0);
            $133 = __THREW__; __THREW__ = 0;
            $134 = $133&1;
            if ($134) {
             break;
            }
            $135 = (($3) + 8|0);
            HEAP32[$135>>2] = $132;
            $136 = $131 | 1;
            HEAP32[$3>>2] = $136;
            $137 = (($3) + 4|0);
            HEAP32[$137>>2] = 19;
            $__p$0$i$i = $132;
           }
           dest=$__p$0$i$i+0|0; src=653880+0|0; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $138 = (($__p$0$i$i) + 19|0);
           HEAP8[$138>>0] = 0;
           $139 = HEAP32[$67>>2]|0;
           $$60 = $118 ? $65 : $139;
           __THREW__ = 0;
           (invoke_iiii(1480,($3|0),($$60|0),($124|0))|0);
           $140 = __THREW__; __THREW__ = 0;
           $141 = $140&1;
           if (!($141)) {
            $149 = HEAP8[$3>>0]|0;
            $150 = $149 & 1;
            $151 = ($150<<24>>24)==(0);
            if ($151) {
             $154 = (($3) + 1|0);
             $155 = $154;
            } else {
             $152 = (($3) + 8|0);
             $153 = HEAP32[$152>>2]|0;
             $155 = $153;
            }
            __THREW__ = 0;
            invoke_viiiiiiii(21,($155|0),0,(653904|0),441,1,0,0,(0|0));
            $156 = __THREW__; __THREW__ = 0;
            $157 = $156&1;
            if ($157) {
             $163 = ___cxa_find_matching_catch()|0;
             $164 = tempRet0;
             $165 = HEAP8[$3>>0]|0;
             $166 = $165 & 1;
             $167 = ($166<<24>>24)==(0);
             if ($167) {
              $$0 = $164;$$01 = $163;
              break L51;
             }
             $168 = (($3) + 8|0);
             $169 = HEAP32[$168>>2]|0;
             __ZdlPv($169);
             $$0 = $164;$$01 = $163;
             break L51;
            } else {
             $158 = HEAP8[$3>>0]|0;
             $159 = $158 & 1;
             $160 = ($159<<24>>24)==(0);
             if ($160) {
              $passType$1 = 0;
              break L55;
             }
             $161 = (($3) + 8|0);
             $162 = HEAP32[$161>>2]|0;
             __ZdlPv($162);
             $passType$1 = 0;
             break L55;
            }
           }
          }
         } while(0);
         $142 = ___cxa_find_matching_catch()|0;
         $143 = tempRet0;
         $144 = HEAP8[$3>>0]|0;
         $145 = $144 & 1;
         $146 = ($145<<24>>24)==(0);
         if ($146) {
          $eh$lpad$body$index4Z2D = $143;$eh$lpad$body$indexZ2D = $142;
          label = 39;
          break L51;
         }
         $147 = (($3) + 8|0);
         $148 = HEAP32[$147>>2]|0;
         __ZdlPv($148);
         $eh$lpad$body$index4Z2D = $143;$eh$lpad$body$indexZ2D = $142;
         label = 39;
         break L51;
        } else {
         $passType$1 = $i$0$lcssa;
        }
       } while(0);
       $170 = HEAP8[$typeName>>0]|0;
       $171 = $170 & 1;
       $172 = ($171<<24>>24)==(0);
       if ($172) {
        $passType$2 = $passType$1;
        break L27;
       }
       $173 = HEAP32[$67>>2]|0;
       __ZdlPv($173);
       $passType$2 = $passType$1;
       break L27;
      }
     } while(0);
     if ((label|0) == 39) {
      $$0 = $eh$lpad$body$index4Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
     $174 = HEAP8[$typeName>>0]|0;
     $175 = $174 & 1;
     $176 = ($175<<24>>24)==(0);
     if ($176) {
      $$1 = $$0;$$12 = $$01;
      ___resumeException($$12|0);
      // unreachable;
     }
     $177 = HEAP32[$67>>2]|0;
     __ZdlPv($177);
     $$1 = $$0;$$12 = $$01;
     ___resumeException($$12|0);
     // unreachable;
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $46 = (($this) + 224|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = $47&255;
  $passType$2 = $48;
 }
 $178 = HEAP32[$29>>2]|0;
 $179 = ($178|0)==(0|0);
 if ($179) {
  $passRenderOptions$2 = 0;
  $225 = (($this) + 584|0);
  HEAP32[$225>>2] = $passType$2;
  $226 = (($this) + 660|0);
  HEAP32[$226>>2] = $passRenderOptions$2;
  STACKTOP = sp;return;
 }
 $180 = HEAP32[653848>>2]|0;
 $$0$ph7$i$i$i24 = $31;$$01$ph6$i$in$i$i25 = $178;
 L102: while(1) {
  $$013$i$in$i$i27 = $$01$ph6$i$in$i$i25;
  while(1) {
   $181 = (($$013$i$in$i$i27) + 16|0);
   $182 = HEAP32[$181>>2]|0;
   $183 = ($182|0)<($180|0);
   if (!($183)) {
    break;
   }
   $186 = (($$013$i$in$i$i27) + 4|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ($187|0)==(0|0);
   if ($188) {
    $$0$ph5$i$i$i30 = $$0$ph7$i$i$i24;
    break L102;
   } else {
    $$013$i$in$i$i27 = $187;
   }
  }
  $184 = HEAP32[$$013$i$in$i$i27>>2]|0;
  $185 = ($184|0)==(0|0);
  if ($185) {
   $$0$ph5$i$i$i30 = $$013$i$in$i$i27;
   break;
  } else {
   $$0$ph7$i$i$i24 = $$013$i$in$i$i27;$$01$ph6$i$in$i$i25 = $184;
  }
 }
 $189 = ($$0$ph5$i$i$i30|0)==($31|0);
 if ($189) {
  $passRenderOptions$2 = 0;
  $225 = (($this) + 584|0);
  HEAP32[$225>>2] = $passType$2;
  $226 = (($this) + 660|0);
  HEAP32[$226>>2] = $passRenderOptions$2;
  STACKTOP = sp;return;
 }
 $190 = (($$0$ph5$i$i$i30) + 16|0);
 $191 = HEAP32[$190>>2]|0;
 $192 = ($180|0)<($191|0);
 if ($192) {
  $passRenderOptions$2 = 0;
  $225 = (($this) + 584|0);
  HEAP32[$225>>2] = $passType$2;
  $226 = (($this) + 660|0);
  HEAP32[$226>>2] = $passRenderOptions$2;
  STACKTOP = sp;return;
 }
 $193 = (($$0$ph5$i$i$i30) + 20|0);
 $194 = HEAP32[$193>>2]|0;
 __ZN9ShaderLab16GetShaderTagNameEi($options,$194);
 $195 = HEAP8[$options>>0]|0;
 $196 = $195 & 1;
 $197 = ($196<<24>>24)==(0);
 if ($197) {
  $200 = (($options) + 1|0);
  $$pre5$i = (($options) + 8|0);
  $$ph$i = $200;$$pre$phi4$iZ2D = $200;$$pre$phi6$iZ2D = $$pre5$i;
 } else {
  $198 = (($options) + 8|0);
  $199 = HEAP32[$198>>2]|0;
  $$pre3$i = (($options) + 1|0);
  $$ph$i = $199;$$pre$phi4$iZ2D = $$pre3$i;$$pre$phi6$iZ2D = $198;
 }
 $201 = (($options) + 4|0);
 $203 = $195;$213 = $$ph$i;
 while(1) {
  $202 = $203 & 1;
  $204 = ($202<<24>>24)==(0);
  if ($204) {
   $207 = $203&255;
   $208 = $207 >>> 1;
   $210 = $$pre$phi4$iZ2D;$211 = $208;
  } else {
   $205 = HEAP32[$$pre$phi6$iZ2D>>2]|0;
   $206 = HEAP32[$201>>2]|0;
   $210 = $205;$211 = $206;
  }
  $209 = (($210) + ($211)|0);
  $212 = ($213|0)==($209|0);
  if ($212) {
   break;
  }
  $216 = HEAP8[$213>>0]|0;
  $v$off$i$i = (($216) + -97)<<24>>24;
  $217 = ($v$off$i$i&255)<(26);
  if ($217) {
   $218 = $216&255;
   $219 = $218 & 223;
   $220 = $219&255;
   $$0$i$i = $220;
  } else {
   $$0$i$i = $216;
  }
  HEAP8[$213>>0] = $$0$i$i;
  $221 = (($213) + 1|0);
  $$pre$i = HEAP8[$options>>0]|0;
  $203 = $$pre$i;$213 = $221;
 }
 $214 = (($options) + 8|0);
 $215 = HEAP32[$214>>2]|0;
 if ($204) {
  $222 = (($options) + 1|0);
  $223 = $222;
 } else {
  $223 = $215;
 }
 $224 = (_strstr($223,653912)|0);
 $not$ = ($224|0)!=(0|0);
 $$61 = $not$&1;
 if ($204) {
  $passRenderOptions$2 = $$61;
  $225 = (($this) + 584|0);
  HEAP32[$225>>2] = $passType$2;
  $226 = (($this) + 660|0);
  HEAP32[$226>>2] = $passRenderOptions$2;
  STACKTOP = sp;return;
 }
 __ZdlPv($215);
 $passRenderOptions$2 = $$61;
 $225 = (($this) + 584|0);
 HEAP32[$225>>2] = $passType$2;
 $226 = (($this) + 660|0);
 HEAP32[$226>>2] = $passRenderOptions$2;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab4Pass21ComputePassValuesHashERK16ShaderKeywordSetPKNS_13PropertySheetERKNS_17ShaderPassContextEP6Shader($this,$localKeywords,$props,$passContext,$fromShader) {
 $this = $this|0;
 $localKeywords = $localKeywords|0;
 $props = $props|0;
 $passContext = $passContext|0;
 $fromShader = $fromShader|0;
 var $$byval_copy14 = 0, $$index = 0, $$index8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0, $bufferPtr$03 = 0, $bufferPtr$1 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $pt1$02 = 0, $res = 0, $res3 = 0, $sizeTotal$1 = 0, $sizeTotal$1$1 = 0, $sizeTotal$1$2 = 0, $sizeTotal$1$3 = 0, $sizeTotal$1$4 = 0;
 var $sizeTotal$1$5 = 0, $usedKeywords = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy14 = sp + 36|0;
 $0 = sp;
 $usedKeywords = sp + 8|0;
 $res = sp + 24|0;
 $1 = sp + 28|0;
 $res3 = sp + 32|0;
 $2 = $this;
 ;HEAP32[$usedKeywords+0>>2]=0|0;HEAP32[$usedKeywords+4>>2]=0|0;HEAP32[$usedKeywords+8>>2]=0|0;HEAP32[$usedKeywords+12>>2]=0|0;
 $3 = (($this) + 296|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $sizeTotal$1 = 20;
 } else {
  $6 = (__ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult($4,$fromShader,$this,$localKeywords,$usedKeywords,$res)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $sizeTotal$1 = 20;
  } else {
   $8 = HEAP32[$6>>2]|0;
   $9 = (($8) + 156|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 20)|0;
   $sizeTotal$1 = $11;
  }
 }
 $12 = (($this) + 300|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $sizeTotal$1$1 = $sizeTotal$1;
 } else {
  $60 = (__ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult($13,$fromShader,$this,$localKeywords,$usedKeywords,$res)|0);
  $61 = ($60|0)==(0|0);
  if ($61) {
   $sizeTotal$1$1 = $sizeTotal$1;
  } else {
   $62 = HEAP32[$60>>2]|0;
   $63 = (($62) + 156|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + ($sizeTotal$1))|0;
   $sizeTotal$1$1 = $65;
  }
 }
 $66 = (($this) + 304|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  $sizeTotal$1$2 = $sizeTotal$1$1;
 } else {
  $69 = (__ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult($67,$fromShader,$this,$localKeywords,$usedKeywords,$res)|0);
  $70 = ($69|0)==(0|0);
  if ($70) {
   $sizeTotal$1$2 = $sizeTotal$1$1;
  } else {
   $71 = HEAP32[$69>>2]|0;
   $72 = (($71) + 156|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($73) + ($sizeTotal$1$1))|0;
   $sizeTotal$1$2 = $74;
  }
 }
 $75 = (($this) + 308|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0|0);
 if ($77) {
  $sizeTotal$1$3 = $sizeTotal$1$2;
 } else {
  $78 = (__ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult($76,$fromShader,$this,$localKeywords,$usedKeywords,$res)|0);
  $79 = ($78|0)==(0|0);
  if ($79) {
   $sizeTotal$1$3 = $sizeTotal$1$2;
  } else {
   $80 = HEAP32[$78>>2]|0;
   $81 = (($80) + 156|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($82) + ($sizeTotal$1$2))|0;
   $sizeTotal$1$3 = $83;
  }
 }
 $84 = (($this) + 312|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($85|0)==(0|0);
 if ($86) {
  $sizeTotal$1$4 = $sizeTotal$1$3;
 } else {
  $87 = (__ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult($85,$fromShader,$this,$localKeywords,$usedKeywords,$res)|0);
  $88 = ($87|0)==(0|0);
  if ($88) {
   $sizeTotal$1$4 = $sizeTotal$1$3;
  } else {
   $89 = HEAP32[$87>>2]|0;
   $90 = (($89) + 156|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($91) + ($sizeTotal$1$3))|0;
   $sizeTotal$1$4 = $92;
  }
 }
 $93 = (($this) + 316|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ($94|0)==(0|0);
 if ($95) {
  $sizeTotal$1$5 = $sizeTotal$1$4;
 } else {
  $96 = (__ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult($94,$fromShader,$this,$localKeywords,$usedKeywords,$res)|0);
  $97 = ($96|0)==(0|0);
  if ($97) {
   $sizeTotal$1$5 = $sizeTotal$1$4;
  } else {
   $98 = HEAP32[$96>>2]|0;
   $99 = (($98) + 156|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($100) + ($sizeTotal$1$4))|0;
   $sizeTotal$1$5 = $101;
  }
 }
 $16 = (($sizeTotal$1$5) + 15)|0;
 $102 = ($16>>>0)<(2000);
 if ($102) {
  $15 = ($sizeTotal$1$5|0)==(0);
  if ($15) {
   $29 = 0;$allocPtr$0 = 0;
  } else {
   $17 = STACKTOP; STACKTOP = STACKTOP + ((((1*$16)|0)+15)&-16)|0;;
   $29 = 0;$allocPtr$0 = $17;
  }
 } else {
  $18 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $18;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
  $19 = (invoke_iiiiiii(102,($16|0),16,($$byval_copy14|0),0,(653904|0),499)|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $22 = ___cxa_find_matching_catch()|0;
   $23 = tempRet0;
   $$index = $22;$$index8 = $23;$103 = $0;
   ___resumeException($$index|0);
   // unreachable;
  } else {
   $29 = $19;$allocPtr$0 = $19;
  }
 }
 $33 = $allocPtr$0;
 $34 = (($33) + 15)|0;
 $35 = $34 & -16;
 $36 = $35;
 _memset(($36|0),0,($sizeTotal$1$5|0))|0;
 $37 = $35;
 HEAP32[$37>>2] = $2;
 $38 = (($36) + 4|0);
 dest=$38+0|0; src=$localKeywords+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $39 = (($36) + 20|0);
 $bufferPtr$03 = $39;$pt1$02 = 0;
 while(1) {
  $40 = ((($this) + ($pt1$02<<2)|0) + 296|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   $bufferPtr$1 = $bufferPtr$03;
  } else {
   __THREW__ = 0;
   $43 = (invoke_iiiiiii(112,($41|0),($fromShader|0),($this|0),($localKeywords|0),($usedKeywords|0),($res3|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    label = 9;
    break;
   }
   $46 = ($43|0)==(0|0);
   if ($46) {
    $bufferPtr$1 = $bufferPtr$03;
   } else {
    $47 = HEAP32[$43>>2]|0;
    __THREW__ = 0;
    $48 = (invoke_iiiiiiii(113,($47|0),($props|0),($passContext|0),($bufferPtr$03|0),(0|0),(0|0),(0|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 9;
     break;
    } else {
     $bufferPtr$1 = $48;
    }
   }
  }
  $51 = (($pt1$02) + 1)|0;
  $52 = ($51|0)<(6);
  if ($52) {
   $bufferPtr$03 = $bufferPtr$1;$pt1$02 = $51;
  } else {
   label = 19;
   break;
  }
 }
 do {
  if ((label|0) == 9) {
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $lpad$phi$index = $24;$lpad$phi$index2 = $25;
  }
  else if ((label|0) == 19) {
   __THREW__ = 0;
   $53 = (invoke_iiii(1557,($36|0),($sizeTotal$1$5|0),-1756908916)|0);
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    $26 = ___cxa_find_matching_catch()|0;
    $27 = tempRet0;
    $lpad$phi$index = $26;$lpad$phi$index2 = $27;
    break;
   }
   $56 = ($29|0)==(0|0);
   if ($56) {
    STACKTOP = sp;return ($53|0);
   }
   $57 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $57;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($29,$$byval_copy14);
   STACKTOP = sp;return ($53|0);
  }
 } while(0);
 $28 = ($29|0)==(0|0);
 if ($28) {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$103 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $30 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy14|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $58 = ___cxa_find_matching_catch(0|0)|0;
  $59 = tempRet0;
  ___clang_call_terminate($58);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$103 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN9ShaderLab27ComputeStateBlockValuesHashERK13dynamic_arrayIiLj4EEPKNS_13PropertySheetERKNS_17ShaderPassContextE($propNames,$props,$passContext) {
 $propNames = $propNames|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$0 = 0, $$byval_copy15 = 0, $$index = 0, $$index8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $allocPtr$0 = 0, $bufferPtr$04 = 0, $i$05 = 0, $location$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy15 = sp + 16|0;
 $0 = sp;
 $location$i = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = (($propNames) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = $4 << 2;
 $7 = (($6) + 15)|0;
 $8 = ($7>>>0)<(2000);
 if ($8) {
  $9 = STACKTOP; STACKTOP = STACKTOP + ((((1*$7)|0)+15)&-16)|0;;
  $21 = 0;$allocPtr$0 = $9;
 } else {
  $10 = HEAP32[628512>>2]|0;
  HEAP32[$2>>2] = $10;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
  $11 = (invoke_iiiiiii(102,($7|0),16,($$byval_copy15|0),0,(653904|0),536)|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   $$index = $14;$$index8 = $15;$47 = $0;
   ___resumeException($$index|0);
   // unreachable;
  } else {
   $21 = $11;$allocPtr$0 = $11;
  }
 }
 $25 = $allocPtr$0;
 $26 = (($25) + 15)|0;
 $27 = $26 & -16;
 $28 = $27;
 $29 = $27;
 $bufferPtr$04 = $29;$i$05 = 0;
 while(1) {
  $30 = HEAP32[$propNames>>2]|0;
  $31 = (($30) + ($i$05<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  HEAP32[$1>>2] = $32;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;
  $33 = (invoke_iiiii(255,($props|0),($passContext|0),($$byval_copy15|0),($location$i|0))|0);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 6;
   break;
  }
  $36 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$bufferPtr$04>>2] = $36;
  $37 = (($bufferPtr$04) + 4|0);
  $38 = (($i$05) + 1)|0;
  $39 = ($38|0)==($4|0);
  if ($39) {
   label = 13;
   break;
  } else {
   $bufferPtr$04 = $37;$i$05 = $38;
  }
 }
 do {
  if ((label|0) == 6) {
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   $lpad$phi$index = $16;$lpad$phi$index2 = $17;
  }
  else if ((label|0) == 13) {
   __THREW__ = 0;
   $40 = (invoke_iiii(1557,($28|0),($6|0),-1756908916)|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    $lpad$phi$index = $18;$lpad$phi$index2 = $19;
    break;
   }
   $43 = ($21|0)==(0|0);
   if ($43) {
    $$0 = $40;
    STACKTOP = sp;return ($$0|0);
   }
   $44 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $44;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($21,$$byval_copy15);
   $$0 = $40;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $20 = ($21|0)==(0|0);
 if ($20) {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$47 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $22 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $22;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($21|0),($$byval_copy15|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $45 = ___cxa_find_matching_catch(0|0)|0;
  $46 = tempRet0;
  ___clang_call_terminate($45);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$47 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __GLOBAL__I_a9384() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,653528);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[653520>>2] = $1;
 HEAP32[653544>>2] = 0;
 HEAP32[653552>>2] = 0;
 HEAP32[653568>>2] = 0;
 HEAP32[653576>>2] = 0;
 HEAP32[653560>>2] = 61;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab10SubProgramC2ERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP16PropertyNamesSet($this,$programCode,$outNames) {
 $this = $this|0;
 $programCode = $programCode|0;
 $outNames = $outNames|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 __ZN14ChannelAssignsC2Ev($0);
 $1 = (($this) + 40|0);
 $2 = (($this) + 60|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;
 $3 = HEAP8[$programCode>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  ;HEAP32[$2+0>>2]=HEAP32[$programCode+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$programCode+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$programCode+8>>2]|0;
 } else {
  $6 = (($programCode) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($programCode) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9>>>0)>(4294967279);
  if ($10) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $11 = ($9>>>0)<(11);
  if ($11) {
   $12 = $9 << 1;
   $13 = $12&255;
   HEAP8[$2>>0] = $13;
   $14 = (($2) + 1|0);
   $__p$0$i$i$i = $14;
  } else {
   $15 = (($9) + 16)|0;
   $16 = $15 & -16;
   $17 = (__Znwj($16)|0);
   $18 = (($this) + 68|0);
   HEAP32[$18>>2] = $17;
   $19 = $16 | 1;
   HEAP32[$2>>2] = $19;
   $20 = (($this) + 64|0);
   HEAP32[$20>>2] = $9;
   $__p$0$i$i$i = $17;
  }
  _memcpy(($__p$0$i$i$i|0),($7|0),($9|0))|0;
  $21 = (($__p$0$i$i$i) + ($9)|0);
  HEAP8[$21>>0] = 0;
 }
 $22 = (($this) + 72|0);
 ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;
 $23 = (($this) + 84|0);
 HEAP32[$23>>2] = $outNames;
 __THREW__ = 0;
 $24 = (invoke_ii(2988,164)|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if (!($26)) {
  HEAP32[$24>>2] = 0;
  $27 = (($24) + 8|0);
  HEAP32[$27>>2] = 0;
  $28 = (($24) + 12|0);
  HEAP32[$28>>2] = 0;
  $29 = (($24) + 4|0);
  HEAP32[$29>>2] = 61;
  $30 = (($24) + 16|0);
  HEAP32[$30>>2] = 0;
  $31 = (($24) + 24|0);
  HEAP32[$31>>2] = 0;
  $32 = (($24) + 28|0);
  HEAP32[$32>>2] = 0;
  $33 = (($24) + 20|0);
  HEAP32[$33>>2] = 61;
  $34 = (($24) + 32|0);
  $35 = (($24) + 52|0);
  HEAP32[$35>>2] = 0;
  $36 = (($24) + 56|0);
  HEAP32[$36>>2] = 0;
  $37 = (($24) + 48|0);
  ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
  HEAP32[$37>>2] = 61;
  $38 = (($24) + 60|0);
  HEAP32[$38>>2] = 0;
  $39 = (($24) + 64|0);
  HEAP32[$39>>2] = 0;
  $40 = (($24) + 68|0);
  HEAP32[$40>>2] = 0;
  $41 = (($24) + 72|0);
  HEAP32[$41>>2] = -1;
  $42 = (($24) + 76|0);
  $43 = $42;
  $44 = $43;
  HEAP16[$44>>1]=0&65535;HEAP16[$44+2>>1]=0>>>16;
  $45 = (($43) + 4)|0;
  $46 = $45;
  HEAP16[$46>>1]=0&65535;HEAP16[$46+2>>1]=0>>>16;
  $47 = (($24) + 84|0);
  HEAP32[$47>>2] = -1;
  $48 = (($24) + 88|0);
  $49 = $48;
  $50 = $49;
  HEAP16[$50>>1]=0&65535;HEAP16[$50+2>>1]=0>>>16;
  $51 = (($49) + 4)|0;
  $52 = $51;
  HEAP16[$52>>1]=0&65535;HEAP16[$52+2>>1]=0>>>16;
  $53 = (($24) + 96|0);
  HEAP32[$53>>2] = -1;
  $54 = (($24) + 100|0);
  $55 = $54;
  $56 = $55;
  HEAP16[$56>>1]=0&65535;HEAP16[$56+2>>1]=0>>>16;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP16[$58>>1]=0&65535;HEAP16[$58+2>>1]=0>>>16;
  $59 = (($24) + 108|0);
  HEAP32[$59>>2] = -1;
  $60 = (($24) + 112|0);
  $61 = $60;
  $62 = $61;
  HEAP16[$62>>1]=0&65535;HEAP16[$62+2>>1]=0>>>16;
  $63 = (($61) + 4)|0;
  $64 = $63;
  HEAP16[$64>>1]=0&65535;HEAP16[$64+2>>1]=0>>>16;
  $65 = (($24) + 120|0);
  HEAP32[$65>>2] = -1;
  $66 = (($24) + 124|0);
  $67 = $66;
  $68 = $67;
  HEAP16[$68>>1]=0&65535;HEAP16[$68+2>>1]=0>>>16;
  $69 = (($67) + 4)|0;
  $70 = $69;
  HEAP16[$70>>1]=0&65535;HEAP16[$70+2>>1]=0>>>16;
  $71 = (($24) + 132|0);
  HEAP32[$71>>2] = -1;
  $72 = (($24) + 136|0);
  $73 = $72;
  $74 = $73;
  HEAP16[$74>>1]=0&65535;HEAP16[$74+2>>1]=0>>>16;
  $75 = (($73) + 4)|0;
  $76 = $75;
  HEAP16[$76>>1]=0&65535;HEAP16[$76+2>>1]=0>>>16;
  $77 = (($24) + 144|0);
  HEAP32[$77>>2] = -1;
  $78 = (($24) + 148|0);
  ;HEAP16[$78+0>>1]=0|0;HEAP16[$78+2>>1]=0|0;HEAP16[$78+4>>1]=0|0;HEAP16[$78+6>>1]=0|0;HEAP16[$78+8>>1]=0|0;HEAP16[$78+10>>1]=0|0;HEAP16[$78+12>>1]=0|0;HEAP16[$78+14>>1]=0|0;
  HEAP32[$this>>2] = $24;
  __THREW__ = 0;
  (invoke_iii(2233,($22|0),(674240|0))|0);
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if (!($80)) {
   STACKTOP = sp;return;
  }
 }
 $81 = ___cxa_find_matching_catch()|0;
 $82 = tempRet0;
 $83 = HEAP8[$22>>0]|0;
 $84 = $83 & 1;
 $85 = ($84<<24>>24)==(0);
 if (!($85)) {
  $86 = (($this) + 80|0);
  $87 = HEAP32[$86>>2]|0;
  __ZdlPv($87);
 }
 $88 = HEAP8[$2>>0]|0;
 $89 = $88 & 1;
 $90 = ($89<<24>>24)==(0);
 if ($90) {
  ___resumeException($81|0);
  // unreachable;
 }
 $91 = (($this) + 68|0);
 $92 = HEAP32[$91>>2]|0;
 __ZdlPv($92);
 ___resumeException($81|0);
 // unreachable;
}
function __ZN9ShaderLab10SubProgramD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   label = 5;
  } else {
   __THREW__ = 0;
   $3 = (invoke_i(71)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = HEAP32[$3>>2]|0;
    $7 = (($6) + 236|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vii($8|0,($3|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     label = 5;
     break;
    }
   }
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   $$0 = $13;$$01 = $12;
  }
 } while(0);
 L6: do {
  if ((label|0) == 5) {
   HEAP32[$0>>2] = 0;
   $14 = HEAP32[$this>>2]|0;
   $15 = ($14|0)==(0|0);
   do {
    if (!($15)) {
     __THREW__ = 0;
     invoke_vi(3475,($14|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      $30 = ___cxa_find_matching_catch()|0;
      $31 = tempRet0;
      __ZdlPv($14);
      $$0 = $31;$$01 = $30;
      break L6;
     } else {
      __ZdlPv($14);
      break;
     }
    }
   } while(0);
   $18 = (($this) + 72|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = $19 & 1;
   $21 = ($20<<24>>24)==(0);
   if (!($21)) {
    $22 = (($this) + 80|0);
    $23 = HEAP32[$22>>2]|0;
    __ZdlPv($23);
   }
   $24 = (($this) + 60|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = $25 & 1;
   $27 = ($26<<24>>24)==(0);
   if ($27) {
    STACKTOP = sp;return;
   }
   $28 = (($this) + 68|0);
   $29 = HEAP32[$28>>2]|0;
   __ZdlPv($29);
   STACKTOP = sp;return;
  }
 } while(0);
 $32 = (($this) + 72|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if (!($35)) {
  $36 = (($this) + 80|0);
  $37 = HEAP32[$36>>2]|0;
  __ZdlPv($37);
 }
 $38 = (($this) + 60|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $42 = (($this) + 68|0);
 $43 = HEAP32[$42>>2]|0;
 __ZdlPv($43);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN9ShaderLab10SubProgram14EnsureCompiledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $output = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $output = sp;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN22CreateGpuProgramOutputC2Ev($output);
 $3 = (($this) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($output) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 72|0);
 $7 = (($output) + 12|0);
 HEAP32[$7>>2] = $6;
 __THREW__ = 0;
 $8 = (invoke_i(59)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if (!($10)) {
   $11 = HEAP32[$8>>2]|0;
   $12 = (($11) + 220|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($this) + 60|0);
   __THREW__ = 0;
   $15 = (invoke_iiii($13|0,($8|0),($14|0),($output|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    HEAP32[$0>>2] = $15;
    $18 = HEAP32[$8>>2]|0;
    $19 = (($18) + 664|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP8[$6>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     $26 = (($6) + 1|0);
     $27 = $26;
    } else {
     $24 = (($this) + 80|0);
     $25 = HEAP32[$24>>2]|0;
     $27 = $25;
    }
    __THREW__ = 0;
    invoke_viii($20|0,($8|0),($15|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = HEAP32[$output>>2]|0;
     $31 = ($30|0)==(0|0);
     if (!($31)) {
      $32 = HEAP32[$this>>2]|0;
      __THREW__ = 0;
      (invoke_iii(2534,($32|0),($30|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
     }
     $39 = (($output) + 4|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(0|0);
     if (!($41)) {
      $42 = (($this) + 4|0);
      dest=$42+0|0; src=$40+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     }
     $43 = HEAP32[$0>>2]|0;
     $44 = ($43|0)==(0|0);
     do {
      if (!($44)) {
       $45 = HEAP8[$14>>0]|0;
       $46 = $45 & 1;
       $47 = ($46<<24>>24)==(0);
       if ($47) {
        $51 = (($14) + 1|0);
        HEAP8[$51>>0] = 0;
        HEAP8[$14>>0] = 0;
       } else {
        $48 = (($this) + 68|0);
        $49 = HEAP32[$48>>2]|0;
        HEAP8[$49>>0] = 0;
        $50 = (($this) + 64|0);
        HEAP32[$50>>2] = 0;
       }
       $52 = HEAP8[$6>>0]|0;
       $53 = $52 & 1;
       $54 = ($53<<24>>24)==(0);
       if ($54) {
        $58 = (($6) + 1|0);
        HEAP8[$58>>0] = 0;
        HEAP8[$6>>0] = 0;
        break;
       } else {
        $55 = (($this) + 80|0);
        $56 = HEAP32[$55>>2]|0;
        HEAP8[$56>>0] = 0;
        $57 = (($this) + 76|0);
        HEAP32[$57>>2] = 0;
        break;
       }
      }
     } while(0);
     __ZN22CreateGpuProgramOutputD2Ev($output);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3589,($output|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $59 = ___cxa_find_matching_catch(0|0)|0;
  $60 = tempRet0;
  ___clang_call_terminate($59);
  // unreachable;
 } else {
  ___resumeException($35|0);
  // unreachable;
 }
}
function __ZN20GpuProgramParametersaSERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy5 = 0, $$idx = 0, $$idx5 = 0, $$idx6 = 0, $$pre$i = 0, $$pre$i2 = 0, $$pre$i4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 4|0;
 $1 = sp;
 $2 = ($0|0)==($this|0);
 do {
  if (!($2)) {
   $3 = HEAP32[$0>>2]|0;
   $4 = (($0) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $$idx = ($5*20)|0;
   $6 = (($$idx|0) / 20)&-1;
   $7 = (($this) + 8|0);
   HEAP32[$7>>2] = $6;
   $8 = (($this) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 & 2147483647;
   $11 = ($10>>>0)<($6>>>0);
   if ($11) {
    $14 = ($9|0)>(-1);
    if ($14) {
     HEAP32[$8>>2] = $6;
     $15 = HEAP32[$this>>2]|0;
     $16 = (($this) + 4|0);
     $17 = HEAP32[$16>>2]|0;
     HEAP32[$1>>2] = $17;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
     $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($15,$$idx,4,$$byval_copy5,0,653960,370)|0);
     HEAP32[$this>>2] = $18;
     $27 = $18;
    } else {
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$1>>2] = $20;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx,4,$$byval_copy5,0,653960,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$7>>2]|0;
     $24 = ($23*20)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$8>>2] = $6;
     HEAP32[$this>>2] = $21;
     $27 = $21;
    }
    $25 = HEAP32[$7>>2]|0;
    $26 = ($25*20)|0;
    _memcpy(($27|0),($3|0),($26|0))|0;
    if ($2) {
     break;
    }
   } else {
    $$pre$i4 = HEAP32[$this>>2]|0;
    $12 = HEAP32[$7>>2]|0;
    $13 = ($12*20)|0;
    _memcpy(($$pre$i4|0),($3|0),($13|0))|0;
   }
   $28 = (($this) + 16|0);
   $29 = (($0) + 16|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($0) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $$idx5 = $32 << 3;
   $33 = $$idx5 >> 3;
   $34 = (($this) + 24|0);
   HEAP32[$34>>2] = $33;
   $35 = (($this) + 28|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = $36 & 2147483647;
   $38 = ($37>>>0)<($33>>>0);
   do {
    if ($38) {
     $39 = ($36|0)>(-1);
     if ($39) {
      HEAP32[$35>>2] = $33;
      $40 = HEAP32[$28>>2]|0;
      $41 = (($this) + 20|0);
      $42 = HEAP32[$41>>2]|0;
      HEAP32[$1>>2] = $42;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
      $43 = (__Z16realloc_internalPvji10MemLabelIdiPKci($40,$$idx5,4,$$byval_copy5,0,653960,370)|0);
      HEAP32[$28>>2] = $43;
      $52 = $43;
      break;
     } else {
      $44 = (($this) + 20|0);
      $45 = HEAP32[$44>>2]|0;
      HEAP32[$1>>2] = $45;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
      $46 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx5,4,$$byval_copy5,0,653960,352)|0);
      $47 = HEAP32[$28>>2]|0;
      $48 = HEAP32[$34>>2]|0;
      $49 = $48 << 3;
      _memcpy(($46|0),($47|0),($49|0))|0;
      HEAP32[$35>>2] = $33;
      HEAP32[$28>>2] = $46;
      $52 = $46;
      break;
     }
    } else {
     $$pre$i = HEAP32[$28>>2]|0;
     $52 = $$pre$i;
    }
   } while(0);
   $50 = HEAP32[$34>>2]|0;
   $51 = $50 << 3;
   _memcpy(($52|0),($30|0),($51|0))|0;
   if (!($2)) {
    $53 = (($this) + 32|0);
    $54 = (($0) + 32|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($0) + 36|0);
    $57 = HEAP32[$56>>2]|0;
    __ZNSt3__16vectorIN20GpuProgramParameters16TextureParameterENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($53,$55,$57);
    $58 = (($this) + 44|0);
    $59 = (($0) + 44|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($0) + 52|0);
    $62 = HEAP32[$61>>2]|0;
    $$idx6 = $62 << 3;
    $63 = $$idx6 >> 3;
    $64 = (($this) + 52|0);
    HEAP32[$64>>2] = $63;
    $65 = (($this) + 56|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = $66 & 2147483647;
    $68 = ($67>>>0)<($63>>>0);
    if ($68) {
     $71 = ($66|0)>(-1);
     if ($71) {
      HEAP32[$65>>2] = $63;
      $72 = HEAP32[$58>>2]|0;
      $73 = (($this) + 48|0);
      $74 = HEAP32[$73>>2]|0;
      HEAP32[$1>>2] = $74;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
      $75 = (__Z16realloc_internalPvji10MemLabelIdiPKci($72,$$idx6,4,$$byval_copy5,0,653960,370)|0);
      HEAP32[$58>>2] = $75;
      $84 = $75;
     } else {
      $76 = (($this) + 48|0);
      $77 = HEAP32[$76>>2]|0;
      HEAP32[$1>>2] = $77;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
      $78 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx6,4,$$byval_copy5,0,653960,352)|0);
      $79 = HEAP32[$58>>2]|0;
      $80 = HEAP32[$64>>2]|0;
      $81 = $80 << 3;
      _memcpy(($78|0),($79|0),($81|0))|0;
      HEAP32[$65>>2] = $63;
      HEAP32[$58>>2] = $78;
      $84 = $78;
     }
     $82 = HEAP32[$64>>2]|0;
     $83 = $82 << 3;
     _memcpy(($84|0),($60|0),($83|0))|0;
     if ($2) {
      break;
     }
    } else {
     $$pre$i2 = HEAP32[$58>>2]|0;
     $69 = HEAP32[$64>>2]|0;
     $70 = $69 << 3;
     _memcpy(($$pre$i2|0),($60|0),($70|0))|0;
    }
    $85 = (($this) + 60|0);
    $86 = (($0) + 60|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = (($0) + 64|0);
    $89 = HEAP32[$88>>2]|0;
    __ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($85,$87,$89);
   }
  }
 } while(0);
 $90 = (($this) + 72|0);
 $91 = (($0) + 72|0);
 dest=$90+0|0; src=$91+0|0; stop=dest+92|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return ($this|0);
}
function __ZN9ShaderLab7ProgramC2Ei10ShaderType($this,$subProgramsCapacity,$type) {
 $this = $this|0;
 $subProgramsCapacity = $subProgramsCapacity|0;
 $type = $type|0;
 var $$01$i$i$i$i = 0, $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 32|0;
 $0 = sp + 28|0;
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 12|0;
 HEAP32[$this>>2] = ((587472 + 8|0));
 $8 = (($this) + 4|0);
 HEAP32[$8>>2] = 1;
 HEAP32[$this>>2] = ((653944 + 8|0));
 $9 = (($this) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 16|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 20|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 12|0);
 HEAP32[$12>>2] = 61;
 $13 = (($this) + 24|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 32|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 36|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 28|0);
 HEAP32[$16>>2] = 61;
 $17 = (($this) + 44|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 48|0);
 HEAP8[$18>>0] = 0;
 $19 = (($this) + 49|0);
 HEAP8[$19>>0] = 0;
 $20 = (($this) + 52|0);
 dest=$20+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $21 = (($this) + 96|0);
 HEAP32[$21>>2] = 32;
 $22 = (($this) + 100|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 108|0);
 HEAP32[$23>>2] = 16;
 $24 = (($this) + 104|0);
 HEAP32[$24>>2] = 6;
 $25 = (($this) + 112|0);
 HEAP8[$25>>0] = 0;
 $26 = (($this) + 116|0);
 HEAP32[$26>>2] = -1;
 $27 = (($this) + 120|0);
 HEAP32[$27>>2] = $type;
 $28 = (($this) + 124|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 132|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 136|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 128|0);
 HEAP32[$31>>2] = 61;
 $32 = (($this) + 140|0);
 HEAP8[$32>>0] = 0;
 $33 = (($this) + 141|0);
 HEAP8[$33>>0] = 0;
 $34 = ($subProgramsCapacity|0)==(0);
 if ($34) {
  label = 4;
 } else {
  HEAP32[$11>>2] = $subProgramsCapacity;
  $35 = $subProgramsCapacity << 2;
  HEAP32[$3>>2] = 61;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
  $36 = (invoke_iiiiiiii(108,(0|0),($35|0),4,($$byval_copy7|0),0,(653960|0),370)|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if (!($38)) {
   HEAP32[$9>>2] = $36;
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   $39 = HEAP32[$15>>2]|0;
   $40 = $39 & 2147483647;
   $41 = ($40>>>0)<($subProgramsCapacity>>>0);
   do {
    if ($41) {
     $42 = ($39|0)>(-1);
     if ($42) {
      HEAP32[$15>>2] = $subProgramsCapacity;
      $43 = HEAP32[$13>>2]|0;
      $44 = $subProgramsCapacity << 4;
      $45 = HEAP32[$16>>2]|0;
      HEAP32[$1>>2] = $45;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
      $46 = (invoke_iiiiiiii(108,($43|0),($44|0),4,($$byval_copy7|0),0,(653960|0),370)|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break L4;
      }
      HEAP32[$13>>2] = $46;
      break;
     } else {
      $49 = $subProgramsCapacity << 4;
      $50 = HEAP32[$16>>2]|0;
      HEAP32[$2>>2] = $50;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
      $51 = (invoke_iiiiiii(102,($49|0),4,($$byval_copy7|0),0,(653960|0),352)|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break L4;
      }
      $54 = HEAP32[$13>>2]|0;
      $55 = HEAP32[$14>>2]|0;
      $56 = $55 << 4;
      _memcpy(($51|0),($54|0),($56|0))|0;
      HEAP32[$15>>2] = $subProgramsCapacity;
      HEAP32[$13>>2] = $51;
      break;
     }
    }
   } while(0);
   HEAP8[$19>>0] = 1;
   $57 = (($this) + 72|0);
   $58 = $57;
   $59 = $58;
   HEAP32[$59>>2] = -1;
   $60 = (($58) + 4)|0;
   $61 = $60;
   HEAP32[$61>>2] = -1;
   $62 = (($this) + 80|0);
   $63 = $62;
   $64 = $63;
   HEAP32[$64>>2] = 0;
   $65 = (($63) + 4)|0;
   $66 = $65;
   HEAP32[$66>>2] = 0;
   $67 = (($this) + 88|0);
   HEAP32[$67>>2] = 0;
   $68 = HEAP32[$21>>2]|0;
   $69 = ($68*20)|0;
   HEAP32[$0>>2] = 58;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   $70 = (invoke_iiiiiii(102,($69|0),16,($$byval_copy7|0),0,(653960|0),79)|0);
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if (!($72)) {
    $73 = (($this) + 92|0);
    HEAP32[$73>>2] = $70;
    $74 = HEAP32[$21>>2]|0;
    $75 = (($70) + (($74*20)|0)|0);
    $76 = ($70|0)==($75|0);
    if ($76) {
     STACKTOP = sp;return;
    } else {
     $$01$i$i$i$i = $70;
    }
    while(1) {
     $77 = ($$01$i$i$i$i|0)==(0|0);
     if (!($77)) {
      ;HEAP32[$$01$i$i$i$i+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$$01$i$i$i$i+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$$01$i$i$i$i+8>>2]=HEAP32[$57+8>>2]|0;HEAP32[$$01$i$i$i$i+12>>2]=HEAP32[$57+12>>2]|0;HEAP32[$$01$i$i$i$i+16>>2]=HEAP32[$57+16>>2]|0;
     }
     $78 = (($$01$i$i$i$i) + 20|0);
     $79 = ($78|0)==($75|0);
     if ($79) {
      break;
     } else {
      $$01$i$i$i$i = $78;
     }
    }
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $80 = ___cxa_find_matching_catch()|0;
 $81 = tempRet0;
 $82 = HEAP32[$30>>2]|0;
 $83 = ($82|0)>(-1);
 do {
  if ($83) {
   $84 = HEAP32[$28>>2]|0;
   $85 = HEAP32[$31>>2]|0;
   HEAP32[$4>>2] = $85;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($84|0),($$byval_copy7|0));
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    $105 = ___cxa_find_matching_catch(0|0)|0;
    $106 = tempRet0;
    ___clang_call_terminate($105);
    // unreachable;
   } else {
    HEAP32[$28>>2] = 0;
    break;
   }
  }
 } while(0);
 $88 = (($this) + 92|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($89|0)==(0|0);
 if (!($90)) {
  HEAP32[$5>>2] = 58;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,($89|0),($$byval_copy7|0));
  $91 = __THREW__; __THREW__ = 0;
  $92 = $91&1;
  if ($92) {
   $105 = ___cxa_find_matching_catch(0|0)|0;
   $106 = tempRet0;
   ___clang_call_terminate($105);
   // unreachable;
  }
 }
 $93 = HEAP32[$15>>2]|0;
 $94 = ($93|0)>(-1);
 do {
  if ($94) {
   $95 = HEAP32[$13>>2]|0;
   $96 = HEAP32[$16>>2]|0;
   HEAP32[$6>>2] = $96;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
   invoke_vii(2591,($95|0),($$byval_copy7|0));
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   if ($98) {
    $105 = ___cxa_find_matching_catch(0|0)|0;
    $106 = tempRet0;
    ___clang_call_terminate($105);
    // unreachable;
   } else {
    HEAP32[$13>>2] = 0;
    break;
   }
  }
 } while(0);
 $99 = HEAP32[$11>>2]|0;
 $100 = ($99|0)>(-1);
 if (!($100)) {
  ___resumeException($80|0);
  // unreachable;
 }
 $101 = HEAP32[$9>>2]|0;
 $102 = HEAP32[$12>>2]|0;
 HEAP32[$7>>2] = $102;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$7+0>>2]|0;
 invoke_vii(2591,($101|0),($$byval_copy7|0));
 $103 = __THREW__; __THREW__ = 0;
 $104 = $103&1;
 if ($104) {
  $105 = ___cxa_find_matching_catch(0|0)|0;
  $106 = tempRet0;
  ___clang_call_terminate($105);
  // unreachable;
 }
 HEAP32[$9>>2] = 0;
 ___resumeException($80|0);
 // unreachable;
}
function __ZN9ShaderLab7ProgramD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1184,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab7ProgramD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$byval_copy7 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$018 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy7 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = sp + 24|0;
 HEAP32[$this>>2] = ((653944 + 8|0));
 $7 = (($this) + 8|0);
 $8 = (($this) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 L1: do {
  if ($10) {
   label = 11;
  } else {
   $103 = $9;$i$018 = 0;
   while(1) {
    $11 = HEAP32[$7>>2]|0;
    $12 = (($11) + ($i$018<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $39 = $103;
    } else {
     __THREW__ = 0;
     $15 = (invoke_i(59)|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     $18 = HEAP32[$15>>2]|0;
     $19 = (($18) + 232|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = HEAP32[$7>>2]|0;
     $22 = (($21) + ($i$018<<2)|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vii($20|0,($15|0),($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     $$pre = HEAP32[$8>>2]|0;
     $39 = $$pre;
    }
    $37 = (($i$018) + 1)|0;
    $38 = ($37>>>0)<($39>>>0);
    if ($38) {
     $103 = $39;$i$018 = $37;
    } else {
     label = 11;
     break L1;
    }
   }
   $26 = ___cxa_find_matching_catch()|0;
   $27 = tempRet0;
   $28 = (($this) + 136|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>(-1);
   if ($30) {
    $31 = (($this) + 124|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($this) + 128|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$1>>2] = $34;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($32|0),($$byval_copy7|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     $101 = ___cxa_find_matching_catch(0|0)|0;
     $102 = tempRet0;
     ___clang_call_terminate($101);
     // unreachable;
    } else {
     HEAP32[$31>>2] = 0;
     $$0 = $27;$$01 = $26;
     label = 25;
     break;
    }
   } else {
    $$0 = $27;$$01 = $26;
    label = 25;
   }
  }
 } while(0);
 L15: do {
  if ((label|0) == 11) {
   $40 = (($this) + 136|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)>(-1);
   do {
    if ($42) {
     $43 = (($this) + 124|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($this) + 128|0);
     $46 = HEAP32[$45>>2]|0;
     HEAP32[$4>>2] = $46;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($44|0),($$byval_copy7|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $71 = ___cxa_find_matching_catch()|0;
      $72 = tempRet0;
      $$0 = $72;$$01 = $71;
      label = 25;
      break L15;
     } else {
      HEAP32[$43>>2] = 0;
      break;
     }
    }
   } while(0);
   $49 = (($this) + 92|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   if (!($51)) {
    HEAP32[$3>>2] = 58;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($50|0),($$byval_copy7|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $73 = ___cxa_find_matching_catch()|0;
     $74 = tempRet0;
     $$1 = $74;$$12 = $73;
     label = 28;
     break;
    }
   }
   $54 = (($this) + 36|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)>(-1);
   do {
    if ($56) {
     $57 = (($this) + 24|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($this) + 28|0);
     $60 = HEAP32[$59>>2]|0;
     HEAP32[$2>>2] = $60;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($58|0),($$byval_copy7|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      $80 = ___cxa_find_matching_catch()|0;
      $81 = tempRet0;
      $$2 = $81;$$23 = $80;
      break L15;
     } else {
      HEAP32[$57>>2] = 0;
      break;
     }
    }
   } while(0);
   $63 = (($this) + 20|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)>(-1);
   if (!($65)) {
    STACKTOP = sp;return;
   }
   $66 = HEAP32[$7>>2]|0;
   $67 = (($this) + 12|0);
   $68 = HEAP32[$67>>2]|0;
   HEAP32[$1>>2] = $68;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($66|0),($$byval_copy7|0));
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    $91 = ___cxa_find_matching_catch()|0;
    $92 = tempRet0;
    $$3 = $92;$$34 = $91;
    ___resumeException($$34|0);
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 25) {
  $75 = (($this) + 92|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0|0);
  if ($77) {
   $$1 = $$0;$$12 = $$01;
   label = 28;
  } else {
   HEAP32[$0>>2] = 58;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($76|0),($$byval_copy7|0));
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $101 = ___cxa_find_matching_catch(0|0)|0;
    $102 = tempRet0;
    ___clang_call_terminate($101);
    // unreachable;
   } else {
    $$1 = $$0;$$12 = $$01;
    label = 28;
   }
  }
 }
 do {
  if ((label|0) == 28) {
   $82 = (($this) + 36|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)>(-1);
   if ($84) {
    $85 = (($this) + 24|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($this) + 28|0);
    $88 = HEAP32[$87>>2]|0;
    HEAP32[$5>>2] = $88;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($86|0),($$byval_copy7|0));
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     $101 = ___cxa_find_matching_catch(0|0)|0;
     $102 = tempRet0;
     ___clang_call_terminate($101);
     // unreachable;
    } else {
     HEAP32[$85>>2] = 0;
     $$2 = $$1;$$23 = $$12;
     break;
    }
   } else {
    $$2 = $$1;$$23 = $$12;
   }
  }
 } while(0);
 $93 = (($this) + 20|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ($94|0)>(-1);
 if (!($95)) {
  $$3 = $$2;$$34 = $$23;
  ___resumeException($$34|0);
  // unreachable;
 }
 $96 = HEAP32[$7>>2]|0;
 $97 = (($this) + 12|0);
 $98 = HEAP32[$97>>2]|0;
 HEAP32[$6>>2] = $98;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_vii(2591,($96|0),($$byval_copy7|0));
 $99 = __THREW__; __THREW__ = 0;
 $100 = $99&1;
 if ($100) {
  $101 = ___cxa_find_matching_catch(0|0)|0;
  $102 = tempRet0;
  ___clang_call_terminate($101);
  // unreachable;
 }
 HEAP32[$7>>2] = 0;
 $$3 = $$2;$$34 = $$23;
 ___resumeException($$34|0);
 // unreachable;
}
function __ZN9ShaderLab7Program13AddSubProgramEPNS_10SubProgramE($this,$sub) {
 $this = $this|0;
 $sub = $sub|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 140|0);
 HEAP8[$1>>0] = 1;
 $2 = (($sub) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 4095]($3)|0);
  if (!($8)) {
   $9 = (__Z12GetGfxDevicev()|0);
   $10 = (($9) + 5928|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(4);
   if (!($12)) {
    $13 = (($this) + 124|0);
    $14 = (($sub) + 44|0);
    __ZN13dynamic_arrayI16ShaderKeywordSetLj4EE9push_backERKS0_($13,$14);
    $15 = ($sub|0)==(0|0);
    if ($15) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3590,($sub|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $18 = ___cxa_find_matching_catch()|0;
     $19 = tempRet0;
     __ZdlPv($sub);
     ___resumeException($18|0);
     // unreachable;
    }
    __ZdlPv($sub);
    STACKTOP = sp;return;
   }
  }
 }
 $20 = (($this) + 8|0);
 $21 = (($this) + 16|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 1)|0;
 HEAP32[$21>>2] = $23;
 $24 = (($this) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2147483647;
 $27 = ($23>>>0)>($26>>>0);
 if ($27) {
  $28 = $25 << 1;
  $29 = ($28|0)==(0);
  $30 = $29 ? 1 : $28;
  $31 = ($26>>>0)<($30>>>0);
  do {
   if ($31) {
    $32 = ($25|0)>(-1);
    if ($32) {
     HEAP32[$24>>2] = $30;
     $33 = HEAP32[$20>>2]|0;
     $34 = $30 << 2;
     $35 = (($this) + 12|0);
     $36 = HEAP32[$35>>2]|0;
     HEAP32[$0>>2] = $36;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $37 = (__Z16realloc_internalPvji10MemLabelIdiPKci($33,$34,4,$$byval_copy1,0,653960,370)|0);
     HEAP32[$20>>2] = $37;
     break;
    } else {
     $38 = $30 << 2;
     $39 = (($this) + 12|0);
     $40 = HEAP32[$39>>2]|0;
     HEAP32[$0>>2] = $40;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $41 = (__Z15malloc_internaljj10MemLabelIdiPKci($38,4,$$byval_copy1,0,653960,352)|0);
     $42 = HEAP32[$20>>2]|0;
     $43 = HEAP32[$21>>2]|0;
     $44 = $43 << 2;
     _memcpy(($41|0),($42|0),($44|0))|0;
     HEAP32[$24>>2] = $30;
     HEAP32[$20>>2] = $41;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$21>>2]|0;
  $46 = $$pre$i$i;
 } else {
  $46 = $23;
 }
 $45 = (($46) + -1)|0;
 $47 = HEAP32[$20>>2]|0;
 $48 = (($47) + ($45<<2)|0);
 HEAP32[$48>>2] = $sub;
 $49 = (($this) + 24|0);
 $50 = (($sub) + 44|0);
 __ZN13dynamic_arrayI16ShaderKeywordSetLj4EE9push_backERKS0_($49,$50);
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI16ShaderKeywordSetLj4EE9push_backERKS0_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if (!($7)) {
  $26 = $3;
  $25 = (($26) + -1)|0;
  $27 = HEAP32[$this>>2]|0;
  $28 = (($27) + ($25<<4)|0);
  ;HEAP32[$28+0>>2]=HEAP32[$t+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$t+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$t+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$t+12>>2]|0;
  STACKTOP = sp;return;
 }
 $8 = $5 << 1;
 $9 = ($8|0)==(0);
 $10 = $9 ? 1 : $8;
 $11 = ($6>>>0)<($10>>>0);
 do {
  if ($11) {
   $12 = ($5|0)>(-1);
   if ($12) {
    HEAP32[$4>>2] = $10;
    $13 = HEAP32[$this>>2]|0;
    $14 = $10 << 4;
    $15 = (($this) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,653960,370)|0);
    HEAP32[$this>>2] = $17;
    break;
   } else {
    $18 = $10 << 4;
    $19 = (($this) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,653960,352)|0);
    $22 = HEAP32[$this>>2]|0;
    $23 = HEAP32[$1>>2]|0;
    $24 = $23 << 4;
    _memcpy(($21|0),($22|0),($24|0))|0;
    HEAP32[$4>>2] = $10;
    HEAP32[$this>>2] = $21;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$1>>2]|0;
 $26 = $$pre$i;
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + ($25<<4)|0);
 ;HEAP32[$28+0>>2]=HEAP32[$t+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$t+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$t+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$t+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab7Program22ComputeSupportsShadowsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 141|0);
 HEAP8[$0>>0] = 0;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $i$04 = 0;
 while(1) {
  $8 = (($5) + ($i$04<<4)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 448;
  $11 = ($10|0)==(0);
  $7 = (($i$04) + 1)|0;
  if (!($11)) {
   break;
  }
  $6 = ($7>>>0)<($2>>>0);
  if ($6) {
   $i$04 = $7;
  } else {
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($this,$kw) {
 $this = $this|0;
 $kw = $kw|0;
 var $$03$i = 0, $$04$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3<<4)|0);
 $5 = ($3|0)==(0);
 L1: do {
  if ($5) {
   $$03$i = $1;
   label = 6;
  } else {
   $$04$i = $1;
   while(1) {
    $i$01$i$i$i = 0;
    while(1) {
     $8 = (($$04$i) + ($i$01$i$i$i<<2)|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($kw) + ($i$01$i$i$i<<2)|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($9|0)==($11|0);
     $7 = (($i$01$i$i$i) + 1)|0;
     if (!($12)) {
      break;
     }
     $6 = ($7|0)<(4);
     if ($6) {
      $i$01$i$i$i = $7;
     } else {
      $$03$i = $$04$i;
      label = 6;
      break L1;
     }
    }
    $13 = (($$04$i) + 16|0);
    $14 = ($13|0)==($4|0);
    if ($14) {
     break;
    } else {
     $$04$i = $13;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $15 = ($$03$i|0)==($4|0);
  if (!($15)) {
   STACKTOP = sp;return;
  }
 }
 __ZN13dynamic_arrayI16ShaderKeywordSetLj4EE9push_backERKS0_($0,$kw);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab7Program14RemoveVariantsERK13dynamic_arrayI16ShaderKeywordSetLj4EE($this,$variants) {
 $this = $this|0;
 $variants = $variants|0;
 var $$01$i$i$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $nsubs$010 = 0, $nsubs$1$ph4 = 0, $nsubs$1$ph5 = 0, $si$0$ph6 = 0, $si$02 = 0, $vi$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 92|0);
 $2 = (($this) + 96|0);
 HEAP32[$2>>2] = 32;
 $3 = (($this) + 108|0);
 HEAP32[$3>>2] = 16;
 $4 = (($this) + 104|0);
 HEAP32[$4>>2] = 6;
 $5 = (($this) + 112|0);
 HEAP8[$5>>0] = 0;
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Z15malloc_internaljj10MemLabelIdiPKci(640,16,$$byval_copy1,0,653960,79)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy1);
 }
 HEAP32[$1>>2] = $6;
 $9 = HEAP32[$2>>2]|0;
 $10 = (($6) + (($9*20)|0)|0);
 $11 = ($6|0)==($10|0);
 if (!($11)) {
  $12 = (($this) + 72|0);
  $$01$i$i$i$i = $6;
  while(1) {
   $13 = ($$01$i$i$i$i|0)==(0|0);
   if (!($13)) {
    ;HEAP32[$$01$i$i$i$i+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$$01$i$i$i$i+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$$01$i$i$i$i+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$$01$i$i$i$i+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$$01$i$i$i$i+16>>2]=HEAP32[$12+16>>2]|0;
   }
   $14 = (($$01$i$i$i$i) + 20|0);
   $15 = ($14|0)==($10|0);
   if ($15) {
    break;
   } else {
    $$01$i$i$i$i = $14;
   }
  }
 }
 $16 = (($this) + 100|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 44|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 32|0);
 $19 = (($variants) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$18>>2]|0;
 $23 = (($this) + 24|0);
 $24 = (($this) + 8|0);
 $25 = (($this) + 16|0);
 $nsubs$010 = $22;$vi$07 = 0;
 while(1) {
  $26 = ($nsubs$010|0)==(0);
  L17: do {
   if ($26) {
    $nsubs$1$ph4 = 0;
   } else {
    $nsubs$1$ph5 = $nsubs$010;$si$0$ph6 = 0;
    while(1) {
     $27 = HEAP32[$variants>>2]|0;
     $28 = HEAP32[$23>>2]|0;
     $si$02 = $si$0$ph6;
     L20: while(1) {
      $i$01$i$i = 0;
      while(1) {
       $31 = ((($27) + ($vi$07<<4)|0) + ($i$01$i$i<<2)|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = ((($28) + ($si$02<<4)|0) + ($i$01$i$i<<2)|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ($32|0)==($34|0);
       $30 = (($i$01$i$i) + 1)|0;
       if (!($35)) {
        break;
       }
       $29 = ($30|0)<(4);
       if ($29) {
        $i$01$i$i = $30;
       } else {
        break L20;
       }
      }
      $60 = (($si$02) + 1)|0;
      $61 = ($60|0)==($nsubs$1$ph5|0);
      if ($61) {
       $nsubs$1$ph4 = $nsubs$1$ph5;
       break L17;
      } else {
       $si$02 = $60;
      }
     }
     $36 = HEAP32[$24>>2]|0;
     $37 = (($36) + ($si$02<<2)|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if ($39) {
      $49 = $36;
     } else {
      $40 = (__Z12GetGfxDevicev()|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($41) + 232|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = HEAP32[$24>>2]|0;
      $45 = (($44) + ($si$02<<2)|0);
      $46 = HEAP32[$45>>2]|0;
      FUNCTION_TABLE_vii[$43 & 4095]($40,$46);
      $$pre = HEAP32[$24>>2]|0;
      $49 = $$pre;
     }
     $47 = (($nsubs$1$ph5) + -1)|0;
     $48 = (($49) + ($47<<2)|0);
     $50 = HEAP32[$48>>2]|0;
     $51 = (($49) + ($si$02<<2)|0);
     HEAP32[$51>>2] = $50;
     $52 = HEAP32[$23>>2]|0;
     $53 = (($52) + ($si$02<<4)|0);
     $54 = (($52) + ($47<<4)|0);
     ;HEAP32[$53+0>>2]=HEAP32[$54+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$54+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$54+8>>2]|0;HEAP32[$53+12>>2]=HEAP32[$54+12>>2]|0;
     $55 = HEAP32[$25>>2]|0;
     $56 = (($55) + -1)|0;
     HEAP32[$25>>2] = $56;
     $57 = HEAP32[$18>>2]|0;
     $58 = (($57) + -1)|0;
     HEAP32[$18>>2] = $58;
     $59 = ($si$02|0)==($47|0);
     if ($59) {
      $nsubs$1$ph4 = $si$02;
      break;
     } else {
      $nsubs$1$ph5 = $47;$si$0$ph6 = $si$02;
     }
    }
   }
  } while(0);
  $62 = (($vi$07) + 1)|0;
  $63 = ($62|0)==($20|0);
  if ($63) {
   break;
  } else {
   $nsubs$010 = $nsubs$1$ph4;$vi$07 = $62;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK9ShaderLab7Program11IsSupportedEPK6Shader($this,$fromShader) {
 $this = $this|0;
 $fromShader = $fromShader|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $not$ = ($4|0)!=(0);
 $$0 = $not$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab7Program26FindBestMatchingSubProgramERK16ShaderKeywordSet($this,$kwords) {
 $this = $this|0;
 $kwords = $kwords|0;
 var $$03$i = 0, $$03$i$us = 0, $$04$i = 0, $$04$i$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $bestScore$0$ = 0, $bestScore$0$$us = 0, $bestScore$08 = 0, $bestScore$08$us = 0, $bestScore$1 = 0, $bestScore$1$us = 0, $bestSubProgramIndex$0$i$0 = 0, $bestSubProgramIndex$0$i$0$us = 0, $bestSubProgramIndex$0$lcssa = 0, $bestSubProgramIndex$09 = 0, $bestSubProgramIndex$09$us = 0, $bestSubProgramIndex$1 = 0, $bestSubProgramIndex$1$us = 0;
 var $exitcond$i$us = 0, $i$01$i$i$i = 0, $i$01$i$i$i$us = 0, $i$01$i$us = 0, $i$04 = 0, $i$04$us = 0, $matchingCount$03$i$us = 0, $mismatchingCount$02$i$us = 0, $not$ = 0, $not$$us = 0, $phitmp$i$us = 0, $skipThis$0$off0 = 0, $skipThis$0$off0$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $82 = 0;
  STACKTOP = sp;return ($82|0);
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[652824>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(0);
 $8 = (($this) + 132|0);
 $9 = (($this) + 124|0);
 if ($7) {
  $bestScore$08$us = -2147483648;$bestSubProgramIndex$09$us = -1;$i$04$us = 0;
  while(1) {
   $i$01$i$us = 0;$matchingCount$03$i$us = 0;$mismatchingCount$02$i$us = 0;
   while(1) {
    $10 = ((($4) + ($i$04$us<<4)|0) + ($i$01$i$us<<2)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($kwords) + ($i$01$i$us<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = $13 & $11;
    $15 = $13 ^ -1;
    $16 = $11 & $15;
    $17 = $14 >>> 1;
    $18 = $17 & 1431655765;
    $19 = (($14) - ($18))|0;
    $20 = $19 & 858993459;
    $21 = $19 >>> 2;
    $22 = $21 & 858993459;
    $23 = (($22) + ($20))|0;
    $24 = $23 >>> 4;
    $25 = (($24) + ($23))|0;
    $26 = $25 & 252645135;
    $27 = Math_imul($26, 16843009)|0;
    $28 = $27 >>> 24;
    $29 = (($28) + ($matchingCount$03$i$us))|0;
    $30 = $16 >>> 1;
    $31 = $30 & 1431655765;
    $32 = (($16) - ($31))|0;
    $33 = $32 & 858993459;
    $34 = $32 >>> 2;
    $35 = $34 & 858993459;
    $36 = (($35) + ($33))|0;
    $37 = $36 >>> 4;
    $38 = (($37) + ($36))|0;
    $39 = $38 & 252645135;
    $40 = Math_imul($39, 16843009)|0;
    $41 = $40 >>> 24;
    $42 = (($41) + ($mismatchingCount$02$i$us))|0;
    $43 = (($i$01$i$us) + 1)|0;
    $exitcond$i$us = ($43|0)==($6|0);
    if ($exitcond$i$us) {
     break;
    } else {
     $i$01$i$us = $43;$matchingCount$03$i$us = $29;$mismatchingCount$02$i$us = $42;
    }
   }
   $phitmp$i$us = $42 << 4;
   $44 = (($29) - ($phitmp$i$us))|0;
   $45 = ($44|0)>($bestScore$08$us|0);
   if ($45) {
    $46 = HEAP32[$8>>2]|0;
    $47 = ($46|0)==(0);
    if ($47) {
     $skipThis$0$off0$us = 0;
    } else {
     $48 = HEAP32[$9>>2]|0;
     $49 = (($48) + ($46<<4)|0);
     $$04$i$us = $48;
     L29: while(1) {
      $i$01$i$i$i$us = 0;
      while(1) {
       $50 = (($$04$i$us) + ($i$01$i$i$i$us<<2)|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = ((($4) + ($i$04$us<<4)|0) + ($i$01$i$i$i$us<<2)|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($51|0)==($53|0);
       $55 = (($i$01$i$i$i$us) + 1)|0;
       if (!($54)) {
        break;
       }
       $58 = ($55|0)<(4);
       if ($58) {
        $i$01$i$i$i$us = $55;
       } else {
        $$03$i$us = $$04$i$us;
        break L29;
       }
      }
      $56 = (($$04$i$us) + 16|0);
      $57 = ($56|0)==($49|0);
      if ($57) {
       $$03$i$us = $49;
       break;
      } else {
       $$04$i$us = $56;
      }
     }
     $not$$us = ($$03$i$us|0)!=($49|0);
     $skipThis$0$off0$us = $not$$us;
    }
    $bestScore$0$$us = $skipThis$0$off0$us ? $bestScore$08$us : $44;
    $bestSubProgramIndex$0$i$0$us = $skipThis$0$off0$us ? $bestSubProgramIndex$09$us : $i$04$us;
    $bestScore$1$us = $bestScore$0$$us;$bestSubProgramIndex$1$us = $bestSubProgramIndex$0$i$0$us;
   } else {
    $bestScore$1$us = $bestScore$08$us;$bestSubProgramIndex$1$us = $bestSubProgramIndex$09$us;
   }
   $59 = (($i$04$us) + 1)|0;
   $60 = ($59>>>0)<($1>>>0);
   if ($60) {
    $bestScore$08$us = $bestScore$1$us;$bestSubProgramIndex$09$us = $bestSubProgramIndex$1$us;$i$04$us = $59;
   } else {
    $bestSubProgramIndex$0$lcssa = $bestSubProgramIndex$1$us;
    break;
   }
  }
 } else {
  $bestScore$08 = -2147483648;$bestSubProgramIndex$09 = -1;$i$04 = 0;
  while(1) {
   $61 = ($bestScore$08|0)<(0);
   if ($61) {
    $62 = HEAP32[$8>>2]|0;
    $63 = ($62|0)==(0);
    if ($63) {
     $skipThis$0$off0 = 0;
    } else {
     $64 = HEAP32[$9>>2]|0;
     $65 = (($64) + ($62<<4)|0);
     $$04$i = $64;
     L11: while(1) {
      $i$01$i$i$i = 0;
      while(1) {
       $68 = (($$04$i) + ($i$01$i$i$i<<2)|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ((($4) + ($i$04<<4)|0) + ($i$01$i$i$i<<2)|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = ($69|0)==($71|0);
       $67 = (($i$01$i$i$i) + 1)|0;
       if (!($72)) {
        break;
       }
       $66 = ($67|0)<(4);
       if ($66) {
        $i$01$i$i$i = $67;
       } else {
        $$03$i = $$04$i;
        break L11;
       }
      }
      $73 = (($$04$i) + 16|0);
      $74 = ($73|0)==($65|0);
      if ($74) {
       $$03$i = $65;
       break;
      } else {
       $$04$i = $73;
      }
     }
     $not$ = ($$03$i|0)!=($65|0);
     $skipThis$0$off0 = $not$;
    }
    $bestScore$0$ = $skipThis$0$off0 ? $bestScore$08 : 0;
    $bestSubProgramIndex$0$i$0 = $skipThis$0$off0 ? $bestSubProgramIndex$09 : $i$04;
    $bestScore$1 = $bestScore$0$;$bestSubProgramIndex$1 = $bestSubProgramIndex$0$i$0;
   } else {
    $bestScore$1 = $bestScore$08;$bestSubProgramIndex$1 = $bestSubProgramIndex$09;
   }
   $75 = (($i$04) + 1)|0;
   $76 = ($75>>>0)<($1>>>0);
   if ($76) {
    $bestScore$08 = $bestScore$1;$bestSubProgramIndex$09 = $bestSubProgramIndex$1;$i$04 = $75;
   } else {
    $bestSubProgramIndex$0$lcssa = $bestSubProgramIndex$1;
    break;
   }
  }
 }
 $77 = ($bestSubProgramIndex$0$lcssa|0)>(-1);
 if (!($77)) {
  $82 = 0;
  STACKTOP = sp;return ($82|0);
 }
 $78 = (($this) + 8|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($79) + ($bestSubProgramIndex$0$lcssa<<2)|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = $81;
 STACKTOP = sp;return ($82|0);
}
function __ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult($this,$fromShader,$fromPass,$kwords,$outUsedKeywords,$outResult) {
 $this = $this|0;
 $fromShader = $fromShader|0;
 $fromPass = $fromPass|0;
 $kwords = $kwords|0;
 $outUsedKeywords = $outUsedKeywords|0;
 $outResult = $outResult|0;
 var $$0 = 0, $$03$i$i = 0, $$03$i$i6 = 0, $$04$i$i = 0, $$04$i$i2 = 0, $$phi$trans$insert = 0, $$pr = 0, $$pre = 0, $$pre18 = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $i$01$i$i$i$i = 0, $i$01$i$i$i$i4 = 0, $pos$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i = sp + 40|0;
 $0 = sp;
 $1 = sp + 24|0;
 HEAP32[$outResult>>2] = 0;
 ;HEAP32[$outUsedKeywords+0>>2]=HEAP32[$kwords+0>>2]|0;HEAP32[$outUsedKeywords+4>>2]=HEAP32[$kwords+4>>2]|0;HEAP32[$outUsedKeywords+8>>2]=HEAP32[$kwords+8>>2]|0;HEAP32[$outUsedKeywords+12>>2]=HEAP32[$kwords+12>>2]|0;
 $2 = (($this) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  $5 = (($this) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $8 = (($this) + 40|0);
 $9 = (($this) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10|0)==($12|0);
 do {
  if ($13) {
   $14 = (($this) + 92|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($this) + 96|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($15) + (($17*20)|0)|0);
   $28 = $15;$29 = $17;$31 = $18;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E13find_positionERS3_($pos$i$i,$8,$kwords);
   $19 = HEAP32[$pos$i$i>>2]|0;
   $20 = ($19|0)==(-1);
   $21 = (($this) + 92|0);
   $22 = HEAP32[$21>>2]|0;
   if ($20) {
    $23 = (($this) + 96|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($22) + (($24*20)|0)|0);
    $28 = $22;$29 = $24;$31 = $25;
    break;
   } else {
    $26 = (($22) + (($19*20)|0)|0);
    $$phi$trans$insert = (($this) + 96|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $28 = $22;$29 = $$pre;$31 = $26;
    break;
   }
  }
 } while(0);
 $27 = (($28) + (($29*20)|0)|0);
 $30 = ($31|0)==($27|0);
 if (!($30)) {
  $32 = (($31) + 16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==(0|0);
  if ($34) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $35 = (($33) + 44|0);
  ;HEAP32[$outUsedKeywords+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$outUsedKeywords+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$outUsedKeywords+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$outUsedKeywords+12>>2]=HEAP32[$35+12>>2]|0;
  $$0 = $33;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = HEAP32[$outResult>>2]|0;
 $37 = ($36|0)==(2);
 if ($37) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = (__ZN9ShaderLab7Program26FindBestMatchingSubProgramERK16ShaderKeywordSet($this,$kwords)|0);
 $39 = ($38|0)==(0|0);
 do {
  if (!($39)) {
   HEAP32[$outResult>>2] = 0;
   $40 = (($38) + 44|0);
   ;HEAP32[$outUsedKeywords+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$outUsedKeywords+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$outUsedKeywords+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$outUsedKeywords+12>>2]=HEAP32[$40+12>>2]|0;
   __ZN9ShaderLab10SubProgram14EnsureCompiledEv($38);
   $41 = (($38) + 40|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $44 = HEAP32[$42>>2]|0;
    $45 = (($44) + 12|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (FUNCTION_TABLE_ii[$46 & 4095]($42)|0);
    if ($47) {
     break;
    }
   }
   $48 = (__Z12GetGfxDevicev()|0);
   $49 = (($48) + 5928|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(4);
   if (!($51)) {
    $52 = (($this) + 124|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($this) + 132|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($53) + ($55<<4)|0);
    $57 = ($55|0)==(0);
    L28: do {
     if ($57) {
      $$03$i$i6 = $53;
      label = 21;
     } else {
      $$04$i$i2 = $53;
      while(1) {
       $i$01$i$i$i$i4 = 0;
       while(1) {
        $60 = (($$04$i$i2) + ($i$01$i$i$i$i4<<2)|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = (($kwords) + ($i$01$i$i$i$i4<<2)|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = ($61|0)==($63|0);
        $59 = (($i$01$i$i$i$i4) + 1)|0;
        if (!($64)) {
         break;
        }
        $58 = ($59|0)<(4);
        if ($58) {
         $i$01$i$i$i$i4 = $59;
        } else {
         $$03$i$i6 = $$04$i$i2;
         label = 21;
         break L28;
        }
       }
       $65 = (($$04$i$i2) + 16|0);
       $66 = ($65|0)==($56|0);
       if ($66) {
        label = 22;
        break;
       } else {
        $$04$i$i2 = $65;
       }
      }
     }
    } while(0);
    if ((label|0) == 21) {
     $67 = ($$03$i$i6|0)==($56|0);
     if ($67) {
      label = 22;
     } else {
      $69 = $53;$70 = $55;
     }
    }
    if ((label|0) == 22) {
     __ZN13dynamic_arrayI16ShaderKeywordSetLj4EE9push_backERKS0_($52,$kwords);
     $$pre18 = HEAP32[$52>>2]|0;
     $$pre19 = HEAP32[$54>>2]|0;
     $69 = $$pre18;$70 = $$pre19;
    }
    $68 = (($69) + ($70<<4)|0);
    $71 = ($70|0)==(0);
    L40: do {
     if ($71) {
      $$03$i$i = $69;
      label = 28;
     } else {
      $$04$i$i = $69;
      while(1) {
       $i$01$i$i$i$i = 0;
       while(1) {
        $74 = (($$04$i$i) + ($i$01$i$i$i$i<<2)|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($outUsedKeywords) + ($i$01$i$i$i$i<<2)|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = ($75|0)==($77|0);
        $73 = (($i$01$i$i$i$i) + 1)|0;
        if (!($78)) {
         break;
        }
        $72 = ($73|0)<(4);
        if ($72) {
         $i$01$i$i$i$i = $73;
        } else {
         $$03$i$i = $$04$i$i;
         label = 28;
         break L40;
        }
       }
       $79 = (($$04$i$i) + 16|0);
       $80 = ($79|0)==($68|0);
       if ($80) {
        label = 29;
        break;
       } else {
        $$04$i$i = $79;
       }
      }
     }
    } while(0);
    if ((label|0) == 28) {
     $81 = ($$03$i$i|0)==($68|0);
     if ($81) {
      label = 29;
     }
    }
    if ((label|0) == 29) {
     __ZN13dynamic_arrayI16ShaderKeywordSetLj4EE9push_backERKS0_($52,$outUsedKeywords);
    }
    HEAP32[$outResult>>2] = 2;
    $82 = (($this) + 140|0);
    HEAP8[$82>>0] = 1;
   }
  }
 } while(0);
 $$pr = HEAP32[$outResult>>2]|0;
 $83 = ($$pr|0)==(2);
 if ($83) {
  $$0 = $38;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$0+0>>2]=HEAP32[$kwords+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$kwords+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$kwords+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$kwords+12>>2]|0;
 $84 = (($0) + 16|0);
 HEAP32[$84>>2] = $38;
 __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E12resize_deltaEjj($8,1,0);
 __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E15insert_noresizeERKS7_($1,$8,$0);
 $$0 = $38;
 STACKTOP = sp;return ($$0|0);
}
function __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E12resize_deltaEjj($this,$delta,$min_buckets_wanted) {
 $this = $this|0;
 $delta = $delta|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $sz$0$i = 0, $sz$0$i1 = 0, $tmp = 0, $tmp1$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp + 96|0;
 $tmp1$i = sp;
 $tmp = sp + 20|0;
 $0 = (($this) + 72|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E12maybe_shrinkEv($this);
 }
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>($min_buckets_wanted>>>0);
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 if ($5) {
  $8 = (($7) + ($delta))|0;
  $9 = (($this) + 68|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8>>>0)>($10>>>0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
 }
 $12 = (($this) + 60|0);
 $13 = (($7) + ($delta))|0;
 $14 = (Math_fround(($13>>>0)));
 $sz$0$i = 32;
 while(1) {
  $15 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($15)) {
   $16 = (Math_fround(($sz$0$i>>>0)));
   $17 = Math_fround($16 * Math_fround(0.5));
   $18 = !($14 >= $17);
   if ($18) {
    break;
   }
  }
  $19 = $sz$0$i << 1;
  $sz$0$i = $19;
 }
 $20 = ($sz$0$i>>>0)>($4>>>0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($13) - ($22))|0;
 $24 = (Math_fround(($23>>>0)));
 $sz$0$i1 = 32;
 while(1) {
  $25 = ($sz$0$i1>>>0)<($min_buckets_wanted>>>0);
  if (!($25)) {
   $26 = (Math_fround(($sz$0$i1>>>0)));
   $27 = Math_fround($26 * Math_fround(0.5));
   $28 = !($24 >= $27);
   if ($28) {
    break;
   }
  }
  $29 = $sz$0$i1 << 1;
  $sz$0$i1 = $29;
 }
 $30 = (($tmp) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = (($tmp) + 8|0);
 $32 = (($this) + 8|0);
 $33 = HEAP8[$32>>0]|0;
 HEAP8[$31>>0] = $33;
 $34 = (($tmp) + 9|0);
 $35 = (($this) + 9|0);
 $36 = HEAP8[$35>>0]|0;
 HEAP8[$34>>0] = $36;
 $37 = (($tmp) + 12|0);
 $38 = (($this) + 12|0);
 ;HEAP32[$37+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$38+12>>2]|0;HEAP32[$37+16>>2]=HEAP32[$38+16>>2]|0;
 $39 = (($tmp) + 32|0);
 $40 = (($this) + 32|0);
 ;HEAP32[$39+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$40+16>>2]|0;
 $41 = (($tmp) + 52|0);
 ;HEAP32[$41+0>>2]=0|0;HEAP32[$41+4>>2]=0|0;HEAP32[$41+8>>2]=0|0;HEAP32[$41+12>>2]=0|0;HEAP32[$41+16>>2]=0|0;HEAP8[$41+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E9copy_fromERKSI_j($tmp,$this,$sz$0$i1);
 $42 = HEAP32[$21>>2]|0;
 $43 = HEAP32[$30>>2]|0;
 HEAP32[$21>>2] = $43;
 HEAP32[$30>>2] = $42;
 $44 = HEAP8[$32>>0]|0;
 $45 = HEAP16[$31>>1]|0;
 $46 = $45&255;
 HEAP8[$32>>0] = $46;
 HEAP8[$31>>0] = $44;
 $47 = HEAP8[$35>>0]|0;
 $48 = ($45&65535) >>> 8;
 $49 = $48&255;
 HEAP8[$35>>0] = $49;
 HEAP8[$34>>0] = $47;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$38+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$38+16>>2]|0;
 ;HEAP32[$38+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$37+12>>2]|0;HEAP32[$38+16>>2]=HEAP32[$37+16>>2]|0;
 ;HEAP32[$37+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$$byval_copy+12>>2]|0;HEAP32[$37+16>>2]=HEAP32[$$byval_copy+16>>2]|0;
 ;HEAP32[$tmp1$i+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$tmp1$i+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$tmp1$i+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$tmp1$i+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$tmp1$i+16>>2]=HEAP32[$40+16>>2]|0;
 ;HEAP32[$40+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$39+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$39+16>>2]|0;
 ;HEAP32[$39+0>>2]=HEAP32[$tmp1$i+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$tmp1$i+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$tmp1$i+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$tmp1$i+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$tmp1$i+16>>2]|0;
 $50 = (($this) + 52|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = HEAP32[$41>>2]|0;
 HEAP32[$50>>2] = $52;
 HEAP32[$41>>2] = $51;
 $53 = (($tmp) + 56|0);
 $54 = HEAP32[$3>>2]|0;
 $55 = HEAP32[$53>>2]|0;
 HEAP32[$3>>2] = $55;
 HEAP32[$53>>2] = $54;
 $56 = (($tmp) + 60|0);
 $57 = HEAP32[$12>>2]|0;
 $58 = HEAP32[$56>>2]|0;
 HEAP32[$12>>2] = $58;
 HEAP32[$56>>2] = $57;
 $59 = (Math_fround(($55>>>0)));
 $60 = Math_fround($59 * Math_fround(0.5));
 $61 = (~~(($60))>>>0);
 $62 = (($this) + 68|0);
 HEAP32[$62>>2] = $61;
 $63 = Math_fround($59 * Math_fround(0.20000000298023223877));
 $64 = (~~(($63))>>>0);
 $65 = (($this) + 64|0);
 HEAP32[$65>>2] = $64;
 HEAP8[$0>>0] = 0;
 $66 = (Math_fround(($54>>>0)));
 $67 = Math_fround($66 * Math_fround(0.5));
 $68 = (~~(($67))>>>0);
 $69 = (($tmp) + 68|0);
 HEAP32[$69>>2] = $68;
 $70 = Math_fround($66 * Math_fround(0.20000000298023223877));
 $71 = (~~(($70))>>>0);
 $72 = (($tmp) + 64|0);
 HEAP32[$72>>2] = $71;
 $73 = (($tmp) + 72|0);
 HEAP8[$73>>0] = 0;
 $74 = ($51|0)==(0|0);
 if ($74) {
  STACKTOP = sp;return;
 }
 HEAP32[$tmp1$i>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$tmp1$i+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($51,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E15insert_noresizeERKS7_($agg$result,$this,$obj) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $obj = $obj|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i = 0, $pos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos = sp;
 __ZNK15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E13find_positionERS3_($pos,$this,$obj);
 $0 = HEAP32[$pos>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  $2 = (($this) + 52|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + (($0*20)|0)|0);
  $5 = (($this) + 56|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + (($6*20)|0)|0);
  HEAP32[$agg$result>>2] = $this;
  $8 = (($agg$result) + 4|0);
  HEAP32[$8>>2] = $4;
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $7;
  $10 = (($agg$result) + 12|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($pos) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 L5: do {
  if ($15) {
   label = 9;
  } else {
   $16 = (($this) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0);
   if ($18) {
    label = 9;
   } else {
    $19 = (($this) + 52|0);
    $20 = HEAP32[$19>>2]|0;
    $i$01$i$i$i$i = 0;
    while(1) {
     $23 = ((($this) + ($i$01$i$i$i$i<<2)|0) + 12|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ((($20) + (($12*20)|0)|0) + ($i$01$i$i$i$i<<2)|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($24|0)==($26|0);
     $22 = (($i$01$i$i$i$i) + 1)|0;
     if (!($27)) {
      label = 9;
      break L5;
     }
     $21 = ($22|0)<(4);
     if ($21) {
      $i$01$i$i$i$i = $22;
     } else {
      break;
     }
    }
    $28 = (($17) + -1)|0;
    HEAP32[$16>>2] = $28;
    $34 = $20;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $29 = (($this) + 60|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  $$phi$trans$insert = (($this) + 52|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $34 = $$pre;
 }
 $32 = (($this) + 52|0);
 $33 = (($34) + (($12*20)|0)|0);
 $35 = ($33|0)==(0|0);
 if (!($35)) {
  ;HEAP32[$33+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$obj+12>>2]|0;HEAP32[$33+16>>2]=HEAP32[$obj+16>>2]|0;
 }
 $36 = HEAP32[$32>>2]|0;
 $37 = (($36) + (($12*20)|0)|0);
 $38 = (($this) + 56|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($36) + (($39*20)|0)|0);
 HEAP32[$agg$result>>2] = $this;
 $41 = (($agg$result) + 4|0);
 HEAP32[$41>>2] = $37;
 $42 = (($agg$result) + 8|0);
 HEAP32[$42>>2] = $40;
 $43 = (($agg$result) + 12|0);
 HEAP8[$43>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E13find_positionERS3_($agg$result,$this,$key) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $key = $key|0;
 var $$ = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, $i$01$i$i$i$i = 0, $i$01$i$i$i$i1 = 0, $num_probes$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = $key;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (_i64Add(($5|0),($8|0),2127912214,0)|0);
 $10 = tempRet0;
 $11 = (_bitshift64Shl(($5|0),($8|0),12)|0);
 $12 = tempRet0;
 $13 = (_i64Add(($9|0),($10|0),($11|0),($12|0))|0);
 $14 = tempRet0;
 $15 = $13 ^ -949894596;
 $16 = (_bitshift64Lshr(($13|0),($14|0),19)|0);
 $17 = tempRet0;
 $18 = $15 ^ $16;
 $19 = $14 ^ $17;
 $20 = (_i64Add(($18|0),($19|0),374761393,0)|0);
 $21 = tempRet0;
 $22 = (_bitshift64Shl(($18|0),($19|0),5)|0);
 $23 = tempRet0;
 $24 = (_i64Add(($20|0),($21|0),($22|0),($23|0))|0);
 $25 = tempRet0;
 $26 = (($this) + 52|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($this) + 8|0);
 $29 = (($this) + 4|0);
 $$sink = $24;$39 = -1;$num_probes$0 = 0;
 L1: while(1) {
  $30 = $$sink & $2;
  $i$01$i$i$i$i1 = 0;
  while(1) {
   $33 = ((($this) + ($i$01$i$i$i$i1<<2)|0) + 32|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($27) + (($30*20)|0)|0) + ($i$01$i$i$i$i1<<2)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($34|0)==($36|0);
   $32 = (($i$01$i$i$i$i1) + 1)|0;
   if (!($37)) {
    break;
   }
   $31 = ($32|0)<(4);
   if ($31) {
    $i$01$i$i$i$i1 = $32;
   } else {
    break L1;
   }
  }
  $41 = HEAP8[$28>>0]|0;
  $42 = ($41<<24>>24)==(0);
  L7: do {
   if ($42) {
    $i$01$i$i$i = 0;
    label = 14;
   } else {
    $43 = HEAP32[$29>>2]|0;
    $44 = ($43|0)==(0);
    if ($44) {
     $i$01$i$i$i = 0;
     label = 14;
    } else {
     $i$01$i$i$i$i = 0;
     while(1) {
      $47 = ((($this) + ($i$01$i$i$i$i<<2)|0) + 12|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ((($27) + (($30*20)|0)|0) + ($i$01$i$i$i$i<<2)|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($48|0)==($50|0);
      $46 = (($i$01$i$i$i$i) + 1)|0;
      if (!($51)) {
       $i$01$i$i$i = 0;
       label = 14;
       break L7;
      }
      $45 = ($46|0)<(4);
      if ($45) {
       $i$01$i$i$i$i = $46;
      } else {
       break;
      }
     }
     $52 = ($39|0)==(-1);
     $$ = $52 ? $30 : $39;
     $63 = $$;
    }
   }
  } while(0);
  L13: do {
   if ((label|0) == 14) {
    while(1) {
     label = 0;
     $55 = (($key) + ($i$01$i$i$i<<2)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ((($27) + (($30*20)|0)|0) + ($i$01$i$i$i<<2)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($56|0)==($58|0);
     $54 = (($i$01$i$i$i) + 1)|0;
     if (!($59)) {
      $63 = $39;
      break L13;
     }
     $53 = ($54|0)<(4);
     if ($53) {
      $i$01$i$i$i = $54;
      label = 14;
     } else {
      label = 15;
      break L1;
     }
    }
   }
  } while(0);
  $61 = (($num_probes$0) + 1)|0;
  $62 = (($61) + ($30))|0;
  $$sink = $62;$39 = $63;$num_probes$0 = $61;
 }
 if ((label|0) == 15) {
  HEAP32[$agg$result>>2] = $30;
  $60 = (($agg$result) + 4|0);
  HEAP32[$60>>2] = -1;
  STACKTOP = sp;return;
 }
 $38 = ($39|0)==(-1);
 HEAP32[$agg$result>>2] = -1;
 $40 = (($agg$result) + 4|0);
 if ($38) {
  HEAP32[$40>>2] = $30;
  STACKTOP = sp;return;
 } else {
  HEAP32[$40>>2] = $39;
  STACKTOP = sp;return;
 }
}
function __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E12maybe_shrinkEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $sz$0 = 0, $sz$0$in = 0, $tmp = 0, $tmp1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp + 96|0;
 $tmp1$i = sp;
 $tmp = sp + 20|0;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($3))|0;
 $5 = (($this) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if (!($7)) {
  $61 = (($this) + 72|0);
  HEAP8[$61>>0] = 0;
  STACKTOP = sp;return;
 }
 $8 = (($this) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9>>>0)>(32);
 if ($10) {
  $sz$0$in = $9;
 } else {
  $61 = (($this) + 72|0);
  HEAP8[$61>>0] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $sz$0 = $sz$0$in >>> 1;
  $11 = ($sz$0$in>>>0)<(66);
  if ($11) {
   break;
  }
  $12 = (Math_fround(($4>>>0)));
  $13 = (Math_fround(($sz$0>>>0)));
  $14 = Math_fround($13 * Math_fround(0.20000000298023223877));
  $15 = $12 < $14;
  if ($15) {
   $sz$0$in = $sz$0;
  } else {
   break;
  }
 }
 $16 = (($tmp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($tmp) + 8|0);
 $18 = (($this) + 8|0);
 $19 = HEAP8[$18>>0]|0;
 HEAP8[$17>>0] = $19;
 $20 = (($tmp) + 9|0);
 $21 = (($this) + 9|0);
 $22 = HEAP8[$21>>0]|0;
 HEAP8[$20>>0] = $22;
 $23 = (($tmp) + 12|0);
 $24 = (($this) + 12|0);
 ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$24+16>>2]|0;
 $25 = (($tmp) + 32|0);
 $26 = (($this) + 32|0);
 ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$26+16>>2]|0;
 $27 = (($tmp) + 52|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;HEAP32[$27+16>>2]=0|0;HEAP8[$27+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E9copy_fromERKSI_j($tmp,$this,$sz$0);
 $28 = HEAP32[$2>>2]|0;
 $29 = HEAP32[$16>>2]|0;
 HEAP32[$2>>2] = $29;
 HEAP32[$16>>2] = $28;
 $30 = HEAP8[$18>>0]|0;
 $31 = HEAP16[$17>>1]|0;
 $32 = $31&255;
 HEAP8[$18>>0] = $32;
 HEAP8[$17>>0] = $30;
 $33 = HEAP8[$21>>0]|0;
 $34 = ($31&65535) >>> 8;
 $35 = $34&255;
 HEAP8[$21>>0] = $35;
 HEAP8[$20>>0] = $33;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$24+16>>2]|0;
 ;HEAP32[$24+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$23+16>>2]|0;
 ;HEAP32[$23+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$$byval_copy+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$$byval_copy+16>>2]|0;
 ;HEAP32[$tmp1$i+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$tmp1$i+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$tmp1$i+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$tmp1$i+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$tmp1$i+16>>2]=HEAP32[$26+16>>2]|0;
 ;HEAP32[$26+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$25+16>>2]|0;
 ;HEAP32[$25+0>>2]=HEAP32[$tmp1$i+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$tmp1$i+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$tmp1$i+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$tmp1$i+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$tmp1$i+16>>2]|0;
 $36 = (($this) + 52|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$27>>2]|0;
 HEAP32[$36>>2] = $38;
 HEAP32[$27>>2] = $37;
 $39 = (($tmp) + 56|0);
 $40 = HEAP32[$8>>2]|0;
 $41 = HEAP32[$39>>2]|0;
 HEAP32[$8>>2] = $41;
 HEAP32[$39>>2] = $40;
 $42 = (($tmp) + 60|0);
 $43 = HEAP32[$0>>2]|0;
 $44 = HEAP32[$42>>2]|0;
 HEAP32[$0>>2] = $44;
 HEAP32[$42>>2] = $43;
 $45 = (Math_fround(($41>>>0)));
 $46 = Math_fround($45 * Math_fround(0.5));
 $47 = (~~(($46))>>>0);
 $48 = (($this) + 68|0);
 HEAP32[$48>>2] = $47;
 $49 = Math_fround($45 * Math_fround(0.20000000298023223877));
 $50 = (~~(($49))>>>0);
 HEAP32[$5>>2] = $50;
 $51 = (($this) + 72|0);
 HEAP8[$51>>0] = 0;
 $52 = (Math_fround(($40>>>0)));
 $53 = Math_fround($52 * Math_fround(0.5));
 $54 = (~~(($53))>>>0);
 $55 = (($tmp) + 68|0);
 HEAP32[$55>>2] = $54;
 $56 = Math_fround($52 * Math_fround(0.20000000298023223877));
 $57 = (~~(($56))>>>0);
 $58 = (($tmp) + 64|0);
 HEAP32[$58>>2] = $57;
 $59 = (($tmp) + 72|0);
 HEAP8[$59>>0] = 0;
 $60 = ($37|0)==(0|0);
 if ($60) {
  $61 = (($this) + 72|0);
  HEAP8[$61>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$tmp1$i>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$tmp1$i+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy);
 $61 = (($this) + 72|0);
 HEAP8[$61>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK16ShaderKeywordSetPN9ShaderLab10SubProgramEEES2_NS4_7Program24ShaderKeywordHashFunctorEN14dense_hash_mapIS2_S6_S9_NS0_8equal_toIS2_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESC_SF_E9copy_fromERKSI_j($this,$ht,$min_buckets_wanted) {
 $this = $this|0;
 $ht = $ht|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$01$i$i$i = 0, $$01$i$i$i4 = 0, $$012$i$i = 0, $$03$i$i = 0, $$be = 0, $$byval_copy3 = 0, $$ph10 = 0, $$pn = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $bucknum$0 = 0, $i$01$i$i$i$i = 0, $i$01$i$i$i$i$i$i = 0, $i$01$i$i$i$i$i$i$i$i = 0, $i$01$i$i$i$i2$i$i = 0, $i$01$i$i$i$i2$i$i$i$i = 0, $num_probes$0 = 0, $sz$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 $2 = (($this) + 56|0);
 HEAP32[$2>>2] = 32;
 $3 = (($this) + 68|0);
 HEAP32[$3>>2] = 16;
 $4 = (($this) + 64|0);
 HEAP32[$4>>2] = 6;
 $5 = (($this) + 72|0);
 HEAP8[$5>>0] = 0;
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Z15malloc_internaljj10MemLabelIdiPKci(640,16,$$byval_copy3,0,653960,79)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy3);
 }
 HEAP32[$1>>2] = $6;
 $9 = HEAP32[$2>>2]|0;
 $10 = (($6) + (($9*20)|0)|0);
 $11 = ($6|0)==($10|0);
 if (!($11)) {
  $12 = (($this) + 32|0);
  $$01$i$i$i = $6;
  while(1) {
   $13 = ($$01$i$i$i|0)==(0|0);
   if (!($13)) {
    ;HEAP32[$$01$i$i$i+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$$01$i$i$i+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$$01$i$i$i+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$$01$i$i$i+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$$01$i$i$i+16>>2]=HEAP32[$12+16>>2]|0;
   }
   $14 = (($$01$i$i$i) + 20|0);
   $15 = ($14|0)==($10|0);
   if ($15) {
    break;
   } else {
    $$01$i$i$i = $14;
   }
  }
 }
 $16 = (($this) + 60|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($ht) + 60|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($ht) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) - ($21))|0;
 $23 = (Math_fround(($22>>>0)));
 $sz$0$i = 32;
 while(1) {
  $24 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($24)) {
   $25 = (Math_fround(($sz$0$i>>>0)));
   $26 = Math_fround($25 * Math_fround(0.5));
   $27 = !($23 >= $26);
   if ($27) {
    break;
   }
  }
  $28 = $sz$0$i << 1;
  $sz$0$i = $28;
 }
 $29 = HEAP32[$2>>2]|0;
 $30 = ($sz$0$i>>>0)>($29>>>0);
 if ($30) {
  $31 = ($sz$0$i*20)|0;
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $32 = (__Z15malloc_internaljj10MemLabelIdiPKci($31,16,$$byval_copy3,0,653960,79)|0);
  $33 = HEAP32[$1>>2]|0;
  $34 = HEAP32[$2>>2]|0;
  $35 = ($34>>>0)>($sz$0$i>>>0);
  $36 = $35 ? $sz$0$i : $34;
  $37 = (($33) + (($36*20)|0)|0);
  $38 = ($36|0)==(0);
  if ($38) {
   $45 = $34;
  } else {
   $$012$i$i = $32;$$03$i$i = $33;
   while(1) {
    $39 = ($$012$i$i|0)==(0|0);
    if (!($39)) {
     ;HEAP32[$$012$i$i+0>>2]=HEAP32[$$03$i$i+0>>2]|0;HEAP32[$$012$i$i+4>>2]=HEAP32[$$03$i$i+4>>2]|0;HEAP32[$$012$i$i+8>>2]=HEAP32[$$03$i$i+8>>2]|0;HEAP32[$$012$i$i+12>>2]=HEAP32[$$03$i$i+12>>2]|0;HEAP32[$$012$i$i+16>>2]=HEAP32[$$03$i$i+16>>2]|0;
    }
    $40 = (($$03$i$i) + 20|0);
    $41 = (($$012$i$i) + 20|0);
    $42 = ($40|0)==($37|0);
    if ($42) {
     break;
    } else {
     $$012$i$i = $41;$$03$i$i = $40;
    }
   }
   $$pre$i = HEAP32[$2>>2]|0;
   $45 = $$pre$i;
  }
  $43 = (($32) + (($sz$0$i*20)|0)|0);
  $44 = ($45|0)==($sz$0$i|0);
  if (!($44)) {
   $46 = (($32) + (($45*20)|0)|0);
   $47 = (($this) + 32|0);
   $$01$i$i$i4 = $46;
   while(1) {
    $48 = ($$01$i$i$i4|0)==(0|0);
    if (!($48)) {
     ;HEAP32[$$01$i$i$i4+0>>2]=HEAP32[$47+0>>2]|0;HEAP32[$$01$i$i$i4+4>>2]=HEAP32[$47+4>>2]|0;HEAP32[$$01$i$i$i4+8>>2]=HEAP32[$47+8>>2]|0;HEAP32[$$01$i$i$i4+12>>2]=HEAP32[$47+12>>2]|0;HEAP32[$$01$i$i$i4+16>>2]=HEAP32[$47+16>>2]|0;
    }
    $49 = (($$01$i$i$i4) + 20|0);
    $50 = ($49|0)==($43|0);
    if ($50) {
     break;
    } else {
     $$01$i$i$i4 = $49;
    }
   }
  }
  $51 = HEAP32[$1>>2]|0;
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($51,$$byval_copy3);
  HEAP32[$1>>2] = $32;
  HEAP32[$2>>2] = $sz$0$i;
  $52 = (~~(($26))>>>0);
  HEAP32[$3>>2] = $52;
  $53 = Math_fround($25 * Math_fround(0.20000000298023223877));
  $54 = (~~(($53))>>>0);
  HEAP32[$4>>2] = $54;
  HEAP8[$5>>0] = 0;
  $152 = $sz$0$i;
 } else {
  $152 = $29;
 }
 $55 = (($ht) + 52|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($ht) + 56|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($56) + (($58*20)|0)|0);
 $60 = ($58|0)==(0);
 L37: do {
  if ($60) {
   $$ph10 = $56;
  } else {
   $61 = (($ht) + 8|0);
   $67 = $56;
   while(1) {
    $i$01$i$i$i$i$i$i$i$i = 0;
    while(1) {
     $64 = ((($ht) + ($i$01$i$i$i$i$i$i$i$i<<2)|0) + 32|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (($67) + ($i$01$i$i$i$i$i$i$i$i<<2)|0);
     $68 = HEAP32[$66>>2]|0;
     $69 = ($65|0)==($68|0);
     $63 = (($i$01$i$i$i$i$i$i$i$i) + 1)|0;
     if (!($69)) {
      label = 29;
      break;
     }
     $62 = ($63|0)<(4);
     if ($62) {
      $i$01$i$i$i$i$i$i$i$i = $63;
     } else {
      break;
     }
    }
    if ((label|0) == 29) {
     label = 0;
     $70 = HEAP8[$61>>0]|0;
     $71 = ($70<<24>>24)==(0);
     if ($71) {
      $$ph10 = $67;
      break L37;
     }
     $72 = HEAP32[$20>>2]|0;
     $73 = ($72|0)==(0);
     if ($73) {
      $$ph10 = $67;
      break L37;
     } else {
      $i$01$i$i$i$i2$i$i$i$i = 0;
     }
     while(1) {
      $76 = ((($ht) + ($i$01$i$i$i$i2$i$i$i$i<<2)|0) + 12|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($67) + ($i$01$i$i$i$i2$i$i$i$i<<2)|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = ($77|0)==($79|0);
      $75 = (($i$01$i$i$i$i2$i$i$i$i) + 1)|0;
      if (!($80)) {
       $$ph10 = $67;
       break L37;
      }
      $74 = ($75|0)<(4);
      if ($74) {
       $i$01$i$i$i$i2$i$i$i$i = $75;
      } else {
       break;
      }
     }
    }
    $81 = (($67) + 20|0);
    $82 = ($81|0)==($59|0);
    if ($82) {
     break;
    } else {
     $67 = $81;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $83 = ($$ph10|0)==($59|0);
 if ($83) {
  STACKTOP = sp;return;
 }
 $84 = (($ht) + 8|0);
 $86 = $152;$88 = $$ph10;
 while(1) {
  $85 = (($86) + -1)|0;
  $87 = $88;
  $89 = $87;
  $90 = HEAP32[$89>>2]|0;
  $91 = (($87) + 4)|0;
  $92 = $91;
  $93 = HEAP32[$92>>2]|0;
  $94 = (_i64Add(($90|0),($93|0),2127912214,0)|0);
  $95 = tempRet0;
  $96 = (_bitshift64Shl(($90|0),($93|0),12)|0);
  $97 = tempRet0;
  $98 = (_i64Add(($94|0),($95|0),($96|0),($97|0))|0);
  $99 = tempRet0;
  $100 = $98 ^ -949894596;
  $101 = (_bitshift64Lshr(($98|0),($99|0),19)|0);
  $102 = tempRet0;
  $103 = $100 ^ $101;
  $104 = $99 ^ $102;
  $105 = (_i64Add(($103|0),($104|0),374761393,0)|0);
  $106 = tempRet0;
  $107 = (_bitshift64Shl(($103|0),($104|0),5)|0);
  $108 = tempRet0;
  $109 = (_i64Add(($105|0),($106|0),($107|0),($108|0))|0);
  $110 = tempRet0;
  $111 = HEAP32[$1>>2]|0;
  $$pn = $109;$num_probes$0 = 0;
  L58: while(1) {
   $bucknum$0 = $$pn & $85;
   $i$01$i$i$i$i = 0;
   while(1) {
    $114 = ((($this) + ($i$01$i$i$i$i<<2)|0) + 32|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = ((($111) + (($bucknum$0*20)|0)|0) + ($i$01$i$i$i$i<<2)|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ($115|0)==($117|0);
    $113 = (($i$01$i$i$i$i) + 1)|0;
    if (!($118)) {
     break;
    }
    $112 = ($113|0)<(4);
    if ($112) {
     $i$01$i$i$i$i = $113;
    } else {
     break L58;
    }
   }
   $119 = (($num_probes$0) + 1)|0;
   $120 = (($119) + ($bucknum$0))|0;
   $$pn = $120;$num_probes$0 = $119;
  }
  $121 = (($111) + (($bucknum$0*20)|0)|0);
  $122 = ($121|0)==(0|0);
  if (!($122)) {
   ;HEAP32[$121+0>>2]=HEAP32[$88+0>>2]|0;HEAP32[$121+4>>2]=HEAP32[$88+4>>2]|0;HEAP32[$121+8>>2]=HEAP32[$88+8>>2]|0;HEAP32[$121+12>>2]=HEAP32[$88+12>>2]|0;HEAP32[$121+16>>2]=HEAP32[$88+16>>2]|0;
  }
  $123 = HEAP32[$16>>2]|0;
  $124 = (($123) + 1)|0;
  HEAP32[$16>>2] = $124;
  $125 = (($88) + 20|0);
  $126 = ($125|0)==($59|0);
  L68: do {
   if ($126) {
    $$be = $59;
   } else {
    $136 = $125;
    while(1) {
     $i$01$i$i$i$i$i$i = 0;
     while(1) {
      $133 = ((($ht) + ($i$01$i$i$i$i$i$i<<2)|0) + 32|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = (($136) + ($i$01$i$i$i$i$i$i<<2)|0);
      $137 = HEAP32[$135>>2]|0;
      $138 = ($134|0)==($137|0);
      $132 = (($i$01$i$i$i$i$i$i) + 1)|0;
      if (!($138)) {
       label = 49;
       break;
      }
      $131 = ($132|0)<(4);
      if ($131) {
       $i$01$i$i$i$i$i$i = $132;
      } else {
       break;
      }
     }
     if ((label|0) == 49) {
      label = 0;
      $139 = HEAP8[$84>>0]|0;
      $140 = ($139<<24>>24)==(0);
      if ($140) {
       $$be = $136;
       break L68;
      }
      $141 = HEAP32[$20>>2]|0;
      $142 = ($141|0)==(0);
      if ($142) {
       $$be = $136;
       break L68;
      } else {
       $i$01$i$i$i$i2$i$i = 0;
      }
      while(1) {
       $145 = ((($ht) + ($i$01$i$i$i$i2$i$i<<2)|0) + 12|0);
       $146 = HEAP32[$145>>2]|0;
       $147 = (($136) + ($i$01$i$i$i$i2$i$i<<2)|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = ($146|0)==($148|0);
       $144 = (($i$01$i$i$i$i2$i$i) + 1)|0;
       if (!($149)) {
        $$be = $136;
        break L68;
       }
       $143 = ($144|0)<(4);
       if ($143) {
        $i$01$i$i$i$i2$i$i = $144;
       } else {
        break;
       }
      }
     }
     $150 = (($136) + 20|0);
     $151 = ($150|0)==($59|0);
     if ($151) {
      $$be = $59;
      break;
     } else {
      $136 = $150;
     }
    }
   }
  } while(0);
  $127 = HEAP32[$55>>2]|0;
  $128 = HEAP32[$57>>2]|0;
  $129 = (($127) + (($128*20)|0)|0);
  $130 = ($$be|0)==($129|0);
  if ($130) {
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $86 = $$pre;$88 = $$be;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i13 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i5 = 0, $$012$i$i = 0, $$03$i$i = 0, $$byval_copy5 = 0, $$idx$i$i$i = 0, $$idx$i$i$i$i$i$i = 0, $$idx$i$i$i$i$i$i6 = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i7 = 0, $$pre$i$i$i$i2 = 0, $$pre$i1 = 0, $$pre$i3 = 0, $$pre3$i = 0, $$pre3$i8 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 4|0;
 $0 = sp;
 $1 = $__last;
 $2 = $__first;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / 28)&-1;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$this>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 28)&-1;
 $12 = ($4>>>0)>($11>>>0);
 if ($12) {
  $120 = ($7|0)==(0|0);
  if ($120) {
   $142 = $6;
  } else {
   $121 = (($this) + 4|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = ($122|0)==($7|0);
   do {
    if ($123) {
     $139 = $7;
    } else {
     $125 = $122;
     while(1) {
      $124 = (($125) + -28|0);
      HEAP32[$121>>2] = $124;
      $126 = (($125) + -12|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ($127|0)>(-1);
      if ($128) {
       $131 = (($125) + -24|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = (($125) + -20|0);
       $134 = HEAP32[$133>>2]|0;
       HEAP32[$0>>2] = $134;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($132|0),($$byval_copy5|0));
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if ($136) {
        label = 37;
        break;
       }
       HEAP32[$131>>2] = 0;
       $$pre$i$i$i$i = HEAP32[$121>>2]|0;
       $130 = $$pre$i$i$i$i;
      } else {
       $130 = $124;
      }
      $129 = ($130|0)==($7|0);
      if ($129) {
       label = 38;
       break;
      } else {
       $125 = $130;
      }
     }
     if ((label|0) == 37) {
      $137 = ___cxa_find_matching_catch()|0;
      $138 = tempRet0;
      ___cxa_call_unexpected(($137|0));
      // unreachable;
     }
     else if ((label|0) == 38) {
      $$pre$i1 = HEAP32[$this>>2]|0;
      $139 = $$pre$i1;
      break;
     }
    }
   } while(0);
   __ZdlPv($139);
   HEAP32[$5>>2] = 0;
   HEAP32[$121>>2] = 0;
   HEAP32[$this>>2] = 0;
   $142 = 0;
  }
  $140 = ($4>>>0)>(153391689);
  if ($140) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $141 = $142;
  $143 = (($141|0) / 28)&-1;
  $144 = ($143>>>0)<(76695844);
  if ($144) {
   $145 = $143 << 1;
   $146 = ($145>>>0)<($4>>>0);
   $147 = $146 ? $4 : $145;
   $148 = ($147>>>0)>(153391689);
   if ($148) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i13 = $147;
   }
  } else {
   $$0$i13 = 153391689;
  }
  $149 = ($$0$i13*28)|0;
  $150 = (__Znwj($149)|0);
  $151 = (($this) + 4|0);
  HEAP32[$151>>2] = $150;
  HEAP32[$this>>2] = $150;
  $152 = (($150) + (($$0$i13*28)|0)|0);
  HEAP32[$5>>2] = $152;
  $153 = ($__first|0)==($__last|0);
  if ($153) {
   STACKTOP = sp;return;
  }
  $$01$i = $__first;$155 = $150;
  while(1) {
   $154 = ($155|0)==(0|0);
   if ($154) {
    $186 = 0;
   } else {
    $156 = HEAP32[$$01$i>>2]|0;
    HEAP32[$155>>2] = $156;
    $157 = (($$01$i) + 8|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($155) + 8|0);
    HEAP32[$159>>2] = $158;
    $160 = (($155) + 12|0);
    HEAP32[$160>>2] = 0;
    $161 = (($155) + 16|0);
    HEAP32[$161>>2] = 0;
    $162 = (($155) + 4|0);
    HEAP32[$162>>2] = 0;
    $163 = (($$01$i) + 4|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = (($$01$i) + 12|0);
    $166 = HEAP32[$165>>2]|0;
    $$idx$i$i$i$i$i$i = ($166*20)|0;
    $167 = (($$idx$i$i$i$i$i$i|0) / 20)&-1;
    HEAP32[$160>>2] = $167;
    $168 = ($$idx$i$i$i$i$i$i|0)==(0);
    if ($168) {
     $171 = $167;$172 = 0;
    } else {
     HEAP32[$161>>2] = $167;
     HEAP32[$0>>2] = $158;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $169 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i$i$i$i$i,4,$$byval_copy5,0,653960,370)|0);
     HEAP32[$162>>2] = $169;
     $$pre$i$i$i$i$i = HEAP32[$160>>2]|0;
     $171 = $$pre$i$i$i$i$i;$172 = $169;
    }
    $170 = ($171*20)|0;
    _memcpy(($172|0),($164|0),($170|0))|0;
    $173 = (($155) + 20|0);
    $174 = (($$01$i) + 20|0);
    $175 = $174;
    $176 = $175;
    $177 = HEAP32[$176>>2]|0;
    $178 = (($175) + 4)|0;
    $179 = $178;
    $180 = HEAP32[$179>>2]|0;
    $181 = $173;
    $182 = $181;
    HEAP32[$182>>2] = $177;
    $183 = (($181) + 4)|0;
    $184 = $183;
    HEAP32[$184>>2] = $180;
    $$pre3$i = HEAP32[$151>>2]|0;
    $186 = $$pre3$i;
   }
   $185 = (($186) + 28|0);
   HEAP32[$151>>2] = $185;
   $187 = (($$01$i) + 28|0);
   $188 = ($187|0)==($__last|0);
   if ($188) {
    break;
   } else {
    $$01$i = $187;$155 = $185;
   }
  }
  STACKTOP = sp;return;
 }
 $13 = (($this) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 28)&-1;
 $18 = ($4>>>0)>($17>>>0);
 if ($18) {
  $19 = (($__first) + (($17*28)|0)|0);
  $21 = $19;$__growing$0$off0 = 1;
 } else {
  $21 = $__last;$__growing$0$off0 = 0;
 }
 $20 = ($21|0)==($__first|0);
 if ($20) {
  $$0$lcssa$i$i = $7;
 } else {
  $scevgep$i$i = (($21) + -28|0);
  $22 = (0 - ($2))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($22)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $7;
  while(1) {
   $23 = HEAP32[$$012$i$i>>2]|0;
   HEAP32[$$03$i$i>>2] = $23;
   $24 = (($$03$i$i) + 4|0);
   $25 = ($$012$i$i|0)==($$03$i$i|0);
   if (!($25)) {
    $26 = (($$012$i$i) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($$012$i$i) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    $$idx$i$i$i = ($29*20)|0;
    $30 = (($$idx$i$i$i|0) / 20)&-1;
    $31 = (($$03$i$i) + 12|0);
    HEAP32[$31>>2] = $30;
    $32 = (($$03$i$i) + 16|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = $33 & 2147483647;
    $35 = ($34>>>0)<($30>>>0);
    do {
     if ($35) {
      $36 = ($33|0)>(-1);
      if ($36) {
       HEAP32[$32>>2] = $30;
       $37 = HEAP32[$24>>2]|0;
       $38 = (($$03$i$i) + 8|0);
       $39 = HEAP32[$38>>2]|0;
       HEAP32[$0>>2] = $39;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $40 = (__Z16realloc_internalPvji10MemLabelIdiPKci($37,$$idx$i$i$i,4,$$byval_copy5,0,653960,370)|0);
       HEAP32[$24>>2] = $40;
       $49 = $40;
       break;
      } else {
       $41 = (($$03$i$i) + 8|0);
       $42 = HEAP32[$41>>2]|0;
       HEAP32[$0>>2] = $42;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
       $43 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx$i$i$i,4,$$byval_copy5,0,653960,352)|0);
       $44 = HEAP32[$24>>2]|0;
       $45 = HEAP32[$31>>2]|0;
       $46 = ($45*20)|0;
       _memcpy(($43|0),($44|0),($46|0))|0;
       HEAP32[$32>>2] = $30;
       HEAP32[$24>>2] = $43;
       $49 = $43;
       break;
      }
     } else {
      $$pre$i$i$i$i2 = HEAP32[$24>>2]|0;
      $49 = $$pre$i$i$i$i2;
     }
    } while(0);
    $47 = HEAP32[$31>>2]|0;
    $48 = ($47*20)|0;
    _memcpy(($49|0),($27|0),($48|0))|0;
   }
   $50 = (($$03$i$i) + 20|0);
   $51 = (($$012$i$i) + 20|0);
   $52 = $51;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = $50;
   $59 = $58;
   HEAP32[$59>>2] = $54;
   $60 = (($58) + 4)|0;
   $61 = $60;
   HEAP32[$61>>2] = $57;
   $62 = (($$012$i$i) + 28|0);
   $63 = (($$03$i$i) + 28|0);
   $64 = ($62|0)==($21|0);
   if ($64) {
    break;
   } else {
    $$012$i$i = $62;$$03$i$i = $63;
   }
  }
  $65 = (($uglygep6$i$i>>>0) / 28)&-1;
  $66 = (($65) + 1)|0;
  $scevgep7$i$i = (($7) + (($66*28)|0)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if ($__growing$0$off0) {
  $67 = ($21|0)==($__last|0);
  if ($67) {
   STACKTOP = sp;return;
  }
  $$pre$i3 = HEAP32[$13>>2]|0;
  $$01$i5 = $21;$69 = $$pre$i3;
  while(1) {
   $68 = ($69|0)==(0|0);
   if ($68) {
    $100 = 0;
   } else {
    $70 = HEAP32[$$01$i5>>2]|0;
    HEAP32[$69>>2] = $70;
    $71 = (($$01$i5) + 8|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($69) + 8|0);
    HEAP32[$73>>2] = $72;
    $74 = (($69) + 12|0);
    HEAP32[$74>>2] = 0;
    $75 = (($69) + 16|0);
    HEAP32[$75>>2] = 0;
    $76 = (($69) + 4|0);
    HEAP32[$76>>2] = 0;
    $77 = (($$01$i5) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (($$01$i5) + 12|0);
    $80 = HEAP32[$79>>2]|0;
    $$idx$i$i$i$i$i$i6 = ($80*20)|0;
    $81 = (($$idx$i$i$i$i$i$i6|0) / 20)&-1;
    HEAP32[$74>>2] = $81;
    $82 = ($$idx$i$i$i$i$i$i6|0)==(0);
    if ($82) {
     $85 = $81;$86 = 0;
    } else {
     HEAP32[$75>>2] = $81;
     HEAP32[$0>>2] = $72;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $83 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i$i$i$i$i6,4,$$byval_copy5,0,653960,370)|0);
     HEAP32[$76>>2] = $83;
     $$pre$i$i$i$i$i7 = HEAP32[$74>>2]|0;
     $85 = $$pre$i$i$i$i$i7;$86 = $83;
    }
    $84 = ($85*20)|0;
    _memcpy(($86|0),($78|0),($84|0))|0;
    $87 = (($69) + 20|0);
    $88 = (($$01$i5) + 20|0);
    $89 = $88;
    $90 = $89;
    $91 = HEAP32[$90>>2]|0;
    $92 = (($89) + 4)|0;
    $93 = $92;
    $94 = HEAP32[$93>>2]|0;
    $95 = $87;
    $96 = $95;
    HEAP32[$96>>2] = $91;
    $97 = (($95) + 4)|0;
    $98 = $97;
    HEAP32[$98>>2] = $94;
    $$pre3$i8 = HEAP32[$13>>2]|0;
    $100 = $$pre3$i8;
   }
   $99 = (($100) + 28|0);
   HEAP32[$13>>2] = $99;
   $101 = (($$01$i5) + 28|0);
   $102 = ($101|0)==($__last|0);
   if ($102) {
    break;
   } else {
    $$01$i5 = $101;$69 = $99;
   }
  }
  STACKTOP = sp;return;
 } else {
  $103 = HEAP32[$13>>2]|0;
  $104 = ($103|0)==($$0$lcssa$i$i|0);
  if ($104) {
   STACKTOP = sp;return;
  }
  $106 = $103;
  while(1) {
   $105 = (($106) + -28|0);
   HEAP32[$13>>2] = $105;
   $107 = (($106) + -12|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = ($108|0)>(-1);
   if ($109) {
    $112 = (($106) + -24|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = (($106) + -20|0);
    $115 = HEAP32[$114>>2]|0;
    HEAP32[$0>>2] = $115;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($113|0),($$byval_copy5|0));
    $116 = __THREW__; __THREW__ = 0;
    $117 = $116&1;
    if ($117) {
     label = 29;
     break;
    }
    HEAP32[$112>>2] = 0;
    $$pre$i$i = HEAP32[$13>>2]|0;
    $111 = $$pre$i$i;
   } else {
    $111 = $105;
   }
   $110 = ($111|0)==($$0$lcssa$i$i|0);
   if ($110) {
    label = 52;
    break;
   } else {
    $106 = $111;
   }
  }
  if ((label|0) == 29) {
   $118 = ___cxa_find_matching_catch()|0;
   $119 = tempRet0;
   ___cxa_call_unexpected(($118|0));
   // unreachable;
  }
  else if ((label|0) == 52) {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__16vectorIN20GpuProgramParameters16TextureParameterENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 4;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = $15 >> 4;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $26 = $__last;
   $27 = (($26) - ($1))|0;
   $28 = $27 >> 4;
   _memmove(($6|0),($__first|0),($27|0))|0;
   $29 = (($6) + ($28<<4)|0);
   $30 = HEAP32[$12>>2]|0;
   $31 = ($30|0)==($29|0);
   if ($31) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $29;
   $scevgep$i$i = (($30) + -16|0);
   $32 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($32)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $33 = $uglygep3$i$i >>> 4;
   $34 = $33 ^ -1;
   $scevgep4$i$i = (($30) + ($34<<4)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + ($16<<4)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$12>>2]|0;
  $$01$i3 = $18;$21 = $$pre$i1;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $23 = 0;
   } else {
    ;HEAP32[$21+0>>2]=HEAP32[$$01$i3+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$$01$i3+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$$01$i3+8>>2]|0;HEAP32[$21+12>>2]=HEAP32[$$01$i3+12>>2]|0;
    $$pre2$i4 = HEAP32[$12>>2]|0;
    $23 = $$pre2$i4;
   }
   $22 = (($23) + 16|0);
   HEAP32[$12>>2] = $22;
   $24 = (($$01$i3) + 16|0);
   $25 = ($24|0)==($__last|0);
   if ($25) {
    break;
   } else {
    $$01$i3 = $24;$21 = $22;
   }
  }
  STACKTOP = sp;return;
 }
 $35 = ($6|0)==(0|0);
 if ($35) {
  $44 = $5;
 } else {
  $36 = (($this) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==($6|0);
  if (!($38)) {
   $scevgep$i$i$i$i = (($37) + -16|0);
   $39 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($39)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $40 = $uglygep3$i$i$i$i >>> 4;
   $41 = $40 ^ -1;
   $scevgep4$i$i$i$i = (($37) + ($41<<4)|0);
   HEAP32[$36>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$36>>2] = 0;
  HEAP32[$this>>2] = 0;
  $44 = 0;
 }
 $42 = ($3>>>0)>(268435455);
 if ($42) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $43 = $44;
 $45 = $43 >> 4;
 $46 = ($45>>>0)<(134217727);
 if ($46) {
  $47 = $43 >> 3;
  $48 = ($47>>>0)<($3>>>0);
  $49 = $48 ? $3 : $47;
  $50 = ($49>>>0)>(268435455);
  if ($50) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $49;
  }
 } else {
  $$0$i7 = 268435455;
 }
 $51 = $$0$i7 << 4;
 $52 = (__Znwj($51)|0);
 $53 = (($this) + 4|0);
 HEAP32[$53>>2] = $52;
 HEAP32[$this>>2] = $52;
 $54 = (($52) + ($$0$i7<<4)|0);
 HEAP32[$4>>2] = $54;
 $55 = ($__first|0)==($__last|0);
 if ($55) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$57 = $52;
 }
 while(1) {
  $56 = ($57|0)==(0|0);
  if ($56) {
   $59 = 0;
  } else {
   ;HEAP32[$57+0>>2]=HEAP32[$$01$i+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$$01$i+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$$01$i+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$$01$i+12>>2]|0;
   $$pre2$i = HEAP32[$53>>2]|0;
   $59 = $$pre2$i;
  }
  $58 = (($59) + 16|0);
  HEAP32[$53>>2] = $58;
  $60 = (($$01$i) + 16|0);
  $61 = ($60|0)==($__last|0);
  if ($61) {
   break;
  } else {
   $$01$i = $60;$57 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheetC2ERKS0_($this,$old) {
 $this = $this|0;
 $old = $old|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i13 = 0, $$0$i$i$i$i$i$i$i25 = 0, $$0$i$i$i$i$i$i$i43 = 0, $$0$i$i$i$i$i$i17 = 0, $$0$i$i$i$i$i$i29 = 0, $$0$i$i$i$i$i$i34 = 0, $$0$i$i$i$i$i$i47 = 0, $$0$i$i$i$i$i54 = 0, $$01 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$01$i$i$i$i$i$i = 0, $$01$i$i$i$i$i$i15 = 0, $$01$i$i$i$i$i$i27 = 0, $$01$i$i$i$i$i$i45 = 0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$4 = 0, $$45 = 0, $$5 = 0, $$56 = 0, $$6 = 0, $$67 = 0, $$byval_copy4 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i11 = 0, $$pre$i$i$i$i$i$i23 = 0, $$pre$i$i$i$i$i$i41 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__parent$i$i$i$i = 0, $__parent$i$i$i$i$i = 0, $__parent$i$i$i$i$i20 = 0, $__parent$i$i$i$i$i37 = 0, $__parent$i$i$i$i$i8 = 0, $info = 0, $name = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy4 = sp + 184|0;
 $0 = sp + 164|0;
 $__parent$i$i$i$i$i37 = sp + 160|0;
 $1 = sp + 156|0;
 $2 = sp + 8|0;
 $__parent$i$i$i$i = sp + 152|0;
 $3 = sp + 148|0;
 $__parent$i$i$i$i$i20 = sp + 144|0;
 $4 = sp + 140|0;
 $5 = sp + 72|0;
 $__parent$i$i$i$i$i8 = sp + 36|0;
 $6 = sp + 44|0;
 $7 = sp + 16|0;
 $__parent$i$i$i$i$i = sp + 40|0;
 $8 = sp + 48|0;
 $9 = sp;
 $name = sp + 52|0;
 $info = sp + 56|0;
 HEAP32[$this>>2] = ((587472 + 8|0));
 $10 = (($this) + 4|0);
 HEAP32[$10>>2] = 1;
 HEAP32[$this>>2] = ((653968 + 8|0));
 $11 = (($this) + 8|0);
 $12 = (($this) + 12|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 16|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 12|0);
 HEAP32[$11>>2] = $14;
 $15 = (($old) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($old) + 12|0);
 $18 = ($16|0)==($17|0);
 L1: do {
  if (!($18)) {
   $20 = $16;
   while(1) {
    $19 = (($20) + 16|0);
    $21 = $19;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + 4)|0;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    $27 = $9;
    $28 = $27;
    HEAP32[$28>>2] = $23;
    $29 = (($27) + 4)|0;
    $30 = $29;
    HEAP32[$30>>2] = $26;
    HEAP32[$8>>2] = $14;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$8+0>>2]|0;
    $31 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS4_PNS_11__tree_nodeIS4_SE_EEiEESH_RKT_($11,$$byval_copy4,$__parent$i$i$i$i$i,$9)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     __THREW__ = 0;
     $34 = (invoke_ii(2988,24)|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     $37 = (($34) + 16|0);
     $38 = $9;
     $39 = $38;
     $40 = HEAP32[$39>>2]|0;
     $41 = (($38) + 4)|0;
     $42 = $41;
     $43 = HEAP32[$42>>2]|0;
     $44 = $37;
     $45 = $44;
     HEAP32[$45>>2] = $40;
     $46 = (($44) + 4)|0;
     $47 = $46;
     HEAP32[$47>>2] = $43;
     $48 = HEAP32[$__parent$i$i$i$i$i>>2]|0;
     HEAP32[$34>>2] = 0;
     $49 = (($34) + 4|0);
     HEAP32[$49>>2] = 0;
     $50 = (($34) + 8|0);
     HEAP32[$50>>2] = $48;
     HEAP32[$31>>2] = $34;
     $51 = HEAP32[$11>>2]|0;
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==(0|0);
     if ($53) {
      $55 = $34;
     } else {
      HEAP32[$11>>2] = $52;
      $$pre$i$i$i$i$i$i = HEAP32[$31>>2]|0;
      $55 = $$pre$i$i$i$i$i$i;
     }
     $54 = HEAP32[$12>>2]|0;
     __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($54,$55);
     $56 = HEAP32[$13>>2]|0;
     $57 = (($56) + 1)|0;
     HEAP32[$13>>2] = $57;
    }
    $58 = (($20) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59|0)==(0|0);
    if ($60) {
     $$01$i$i$i$i$i$i = $20;
     while(1) {
      $63 = (($$01$i$i$i$i$i$i) + 8|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = ($65|0)==($$01$i$i$i$i$i$i|0);
      if ($66) {
       $$0$i$i$i$i$i$i = $64;
       break;
      } else {
       $$01$i$i$i$i$i$i = $64;
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i = $59;
     while(1) {
      $61 = HEAP32[$$0$i$i$i$i$i$i$i>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $$0$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i$i$i = $61;
      }
     }
    }
    $67 = ($$0$i$i$i$i$i$i|0)==($17|0);
    if ($67) {
     break L1;
    } else {
     $20 = $$0$i$i$i$i$i$i;
    }
   }
   $288 = ___cxa_find_matching_catch()|0;
   $289 = tempRet0;
   $290 = HEAP32[$12>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($11,$290);
   $$6 = $289;$$67 = $288;
   ___resumeException($$67|0);
   // unreachable;
  }
 } while(0);
 $68 = (($this) + 20|0);
 $69 = (($this) + 24|0);
 HEAP32[$69>>2] = 0;
 $70 = (($this) + 28|0);
 HEAP32[$70>>2] = 0;
 $71 = (($this) + 24|0);
 HEAP32[$68>>2] = $71;
 $72 = (($old) + 20|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($old) + 24|0);
 $75 = ($73|0)==($74|0);
 L22: do {
  if ($75) {
   label = 25;
  } else {
   $77 = $73;
   while(1) {
    $76 = (($77) + 16|0);
    ;HEAP32[$7+0>>2]=HEAP32[$76+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$76+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$76+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$76+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$76+16>>2]|0;
    HEAP32[$6>>2] = $71;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$6+0>>2]|0;
    $78 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($68,$$byval_copy4,$__parent$i$i$i$i$i8,$7)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($79|0)==(0|0);
    if ($80) {
     __THREW__ = 0;
     $81 = (invoke_ii(2988,36)|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      break;
     }
     $84 = (($81) + 16|0);
     ;HEAP32[$84+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$84+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$84+16>>2]=HEAP32[$7+16>>2]|0;
     $85 = HEAP32[$__parent$i$i$i$i$i8>>2]|0;
     HEAP32[$81>>2] = 0;
     $86 = (($81) + 4|0);
     HEAP32[$86>>2] = 0;
     $87 = (($81) + 8|0);
     HEAP32[$87>>2] = $85;
     HEAP32[$78>>2] = $81;
     $88 = HEAP32[$68>>2]|0;
     $89 = HEAP32[$88>>2]|0;
     $90 = ($89|0)==(0|0);
     if ($90) {
      $92 = $81;
     } else {
      HEAP32[$68>>2] = $89;
      $$pre$i$i$i$i$i$i11 = HEAP32[$78>>2]|0;
      $92 = $$pre$i$i$i$i$i$i11;
     }
     $91 = HEAP32[$69>>2]|0;
     __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($91,$92);
     $93 = HEAP32[$70>>2]|0;
     $94 = (($93) + 1)|0;
     HEAP32[$70>>2] = $94;
    }
    $95 = (($77) + 4|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ($96|0)==(0|0);
    if ($97) {
     $$01$i$i$i$i$i$i15 = $77;
     while(1) {
      $100 = (($$01$i$i$i$i$i$i15) + 8|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = HEAP32[$101>>2]|0;
      $103 = ($102|0)==($$01$i$i$i$i$i$i15|0);
      if ($103) {
       $$0$i$i$i$i$i$i17 = $101;
       break;
      } else {
       $$01$i$i$i$i$i$i15 = $101;
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i13 = $96;
     while(1) {
      $98 = HEAP32[$$0$i$i$i$i$i$i$i13>>2]|0;
      $99 = ($98|0)==(0|0);
      if ($99) {
       $$0$i$i$i$i$i$i17 = $$0$i$i$i$i$i$i$i13;
       break;
      } else {
       $$0$i$i$i$i$i$i$i13 = $98;
      }
     }
    }
    $104 = ($$0$i$i$i$i$i$i17|0)==($74|0);
    if ($104) {
     label = 25;
     break L22;
    } else {
     $77 = $$0$i$i$i$i$i$i17;
    }
   }
   $291 = ___cxa_find_matching_catch()|0;
   $292 = tempRet0;
   $293 = HEAP32[$69>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($68,$293);
   $$5 = $292;$$56 = $291;
  }
 } while(0);
 if ((label|0) == 25) {
  $105 = (($this) + 32|0);
  $106 = (($this) + 36|0);
  HEAP32[$106>>2] = 0;
  $107 = (($this) + 40|0);
  HEAP32[$107>>2] = 0;
  $108 = (($this) + 36|0);
  HEAP32[$105>>2] = $108;
  $109 = (($old) + 32|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (($old) + 36|0);
  $112 = ($110|0)==($111|0);
  L43: do {
   if ($112) {
    label = 37;
   } else {
    $114 = $110;
    while(1) {
     $113 = (($114) + 16|0);
     dest=$5+0|0; src=$113+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     HEAP32[$4>>2] = $108;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
     $115 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($105,$$byval_copy4,$__parent$i$i$i$i$i20,$5)|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = ($116|0)==(0|0);
     if ($117) {
      __THREW__ = 0;
      $118 = (invoke_ii(2988,84)|0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       break;
      }
      $121 = (($118) + 16|0);
      dest=$121+0|0; src=$5+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $122 = HEAP32[$__parent$i$i$i$i$i20>>2]|0;
      HEAP32[$118>>2] = 0;
      $123 = (($118) + 4|0);
      HEAP32[$123>>2] = 0;
      $124 = (($118) + 8|0);
      HEAP32[$124>>2] = $122;
      HEAP32[$115>>2] = $118;
      $125 = HEAP32[$105>>2]|0;
      $126 = HEAP32[$125>>2]|0;
      $127 = ($126|0)==(0|0);
      if ($127) {
       $129 = $118;
      } else {
       HEAP32[$105>>2] = $126;
       $$pre$i$i$i$i$i$i23 = HEAP32[$115>>2]|0;
       $129 = $$pre$i$i$i$i$i$i23;
      }
      $128 = HEAP32[$106>>2]|0;
      __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($128,$129);
      $130 = HEAP32[$107>>2]|0;
      $131 = (($130) + 1)|0;
      HEAP32[$107>>2] = $131;
     }
     $132 = (($114) + 4|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($133|0)==(0|0);
     if ($134) {
      $$01$i$i$i$i$i$i27 = $114;
      while(1) {
       $137 = (($$01$i$i$i$i$i$i27) + 8|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = HEAP32[$138>>2]|0;
       $140 = ($139|0)==($$01$i$i$i$i$i$i27|0);
       if ($140) {
        $$0$i$i$i$i$i$i29 = $138;
        break;
       } else {
        $$01$i$i$i$i$i$i27 = $138;
       }
      }
     } else {
      $$0$i$i$i$i$i$i$i25 = $133;
      while(1) {
       $135 = HEAP32[$$0$i$i$i$i$i$i$i25>>2]|0;
       $136 = ($135|0)==(0|0);
       if ($136) {
        $$0$i$i$i$i$i$i29 = $$0$i$i$i$i$i$i$i25;
        break;
       } else {
        $$0$i$i$i$i$i$i$i25 = $135;
       }
      }
     }
     $141 = ($$0$i$i$i$i$i$i29|0)==($111|0);
     if ($141) {
      label = 37;
      break L43;
     } else {
      $114 = $$0$i$i$i$i$i$i29;
     }
    }
    $294 = ___cxa_find_matching_catch()|0;
    $295 = tempRet0;
    $296 = HEAP32[$106>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($105,$296);
    $$4 = $295;$$45 = $294;
   }
  } while(0);
  if ((label|0) == 37) {
   $142 = (($this) + 44|0);
   $143 = (($this) + 48|0);
   HEAP32[$143>>2] = 0;
   $144 = (($this) + 52|0);
   HEAP32[$144>>2] = 0;
   $145 = (($this) + 48|0);
   HEAP32[$142>>2] = $145;
   $146 = (($this) + 56|0);
   $147 = (($this) + 60|0);
   HEAP32[$147>>2] = 0;
   $148 = (($this) + 64|0);
   HEAP32[$148>>2] = 0;
   $149 = (($this) + 60|0);
   HEAP32[$146>>2] = $149;
   $150 = (($old) + 56|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (($old) + 60|0);
   $153 = ($151|0)==($152|0);
   L64: do {
    if ($153) {
     label = 49;
    } else {
     $155 = $151;
     while(1) {
      $154 = (($155) + 16|0);
      HEAP32[$3>>2] = $149;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
      $156 = (__ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SA_EEiEESD_RKT_($146,$$byval_copy4,$__parent$i$i$i$i,$154)|0);
      $157 = HEAP32[$156>>2]|0;
      $158 = ($157|0)==(0|0);
      if ($158) {
       __THREW__ = 0;
       $159 = (invoke_ii(2988,20)|0);
       $160 = __THREW__; __THREW__ = 0;
       $161 = $160&1;
       if ($161) {
        break;
       }
       $162 = (($159) + 16|0);
       $163 = HEAP32[$154>>2]|0;
       HEAP32[$162>>2] = $163;
       $164 = HEAP32[$__parent$i$i$i$i>>2]|0;
       HEAP32[$159>>2] = 0;
       $165 = (($159) + 4|0);
       HEAP32[$165>>2] = 0;
       $166 = (($159) + 8|0);
       HEAP32[$166>>2] = $164;
       HEAP32[$156>>2] = $159;
       $167 = HEAP32[$146>>2]|0;
       $168 = HEAP32[$167>>2]|0;
       $169 = ($168|0)==(0|0);
       if ($169) {
        $171 = $159;
       } else {
        HEAP32[$146>>2] = $168;
        $$pre$i$i$i$i$i = HEAP32[$156>>2]|0;
        $171 = $$pre$i$i$i$i$i;
       }
       $170 = HEAP32[$147>>2]|0;
       __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($170,$171);
       $172 = HEAP32[$148>>2]|0;
       $173 = (($172) + 1)|0;
       HEAP32[$148>>2] = $173;
      }
      $174 = (($155) + 4|0);
      $175 = HEAP32[$174>>2]|0;
      $176 = ($175|0)==(0|0);
      if ($176) {
       $$01$i$i$i$i$i = $155;
       while(1) {
        $179 = (($$01$i$i$i$i$i) + 8|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = HEAP32[$180>>2]|0;
        $182 = ($181|0)==($$01$i$i$i$i$i|0);
        if ($182) {
         $$0$i$i$i$i$i = $180;
         break;
        } else {
         $$01$i$i$i$i$i = $180;
        }
       }
      } else {
       $$0$i$i$i$i$i$i34 = $175;
       while(1) {
        $177 = HEAP32[$$0$i$i$i$i$i$i34>>2]|0;
        $178 = ($177|0)==(0|0);
        if ($178) {
         $$0$i$i$i$i$i = $$0$i$i$i$i$i$i34;
         break;
        } else {
         $$0$i$i$i$i$i$i34 = $177;
        }
       }
      }
      $183 = ($$0$i$i$i$i$i|0)==($152|0);
      if ($183) {
       label = 49;
       break L64;
      } else {
       $155 = $$0$i$i$i$i$i;
      }
     }
     $297 = ___cxa_find_matching_catch()|0;
     $298 = tempRet0;
     $299 = HEAP32[$147>>2]|0;
     __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($146,$299);
     $$2 = $298;$$23 = $297;
    }
   } while(0);
   if ((label|0) == 49) {
    $184 = (($this) + 68|0);
    $185 = (($this) + 72|0);
    HEAP32[$185>>2] = 0;
    $186 = (($this) + 76|0);
    HEAP32[$186>>2] = 0;
    $187 = (($this) + 72|0);
    HEAP32[$184>>2] = $187;
    $188 = (($old) + 68|0);
    $189 = HEAP32[$188>>2]|0;
    $190 = (($old) + 72|0);
    $191 = ($189|0)==($190|0);
    L85: do {
     if ($191) {
      label = 61;
     } else {
      $193 = $189;
      while(1) {
       $192 = (($193) + 16|0);
       $194 = $192;
       $195 = $194;
       $196 = HEAP32[$195>>2]|0;
       $197 = (($194) + 4)|0;
       $198 = $197;
       $199 = HEAP32[$198>>2]|0;
       $200 = $2;
       $201 = $200;
       HEAP32[$201>>2] = $196;
       $202 = (($200) + 4)|0;
       $203 = $202;
       HEAP32[$203>>2] = $199;
       HEAP32[$1>>2] = $187;
       ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
       $204 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($184,$$byval_copy4,$__parent$i$i$i$i$i37,$2)|0);
       $205 = HEAP32[$204>>2]|0;
       $206 = ($205|0)==(0|0);
       if ($206) {
        __THREW__ = 0;
        $207 = (invoke_ii(2988,24)|0);
        $208 = __THREW__; __THREW__ = 0;
        $209 = $208&1;
        if ($209) {
         break;
        }
        $210 = (($207) + 16|0);
        $211 = $2;
        $212 = $211;
        $213 = HEAP32[$212>>2]|0;
        $214 = (($211) + 4)|0;
        $215 = $214;
        $216 = HEAP32[$215>>2]|0;
        $217 = $210;
        $218 = $217;
        HEAP32[$218>>2] = $213;
        $219 = (($217) + 4)|0;
        $220 = $219;
        HEAP32[$220>>2] = $216;
        $221 = HEAP32[$__parent$i$i$i$i$i37>>2]|0;
        HEAP32[$207>>2] = 0;
        $222 = (($207) + 4|0);
        HEAP32[$222>>2] = 0;
        $223 = (($207) + 8|0);
        HEAP32[$223>>2] = $221;
        HEAP32[$204>>2] = $207;
        $224 = HEAP32[$184>>2]|0;
        $225 = HEAP32[$224>>2]|0;
        $226 = ($225|0)==(0|0);
        if ($226) {
         $228 = $207;
        } else {
         HEAP32[$184>>2] = $225;
         $$pre$i$i$i$i$i$i41 = HEAP32[$204>>2]|0;
         $228 = $$pre$i$i$i$i$i$i41;
        }
        $227 = HEAP32[$185>>2]|0;
        __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($227,$228);
        $229 = HEAP32[$186>>2]|0;
        $230 = (($229) + 1)|0;
        HEAP32[$186>>2] = $230;
       }
       $231 = (($193) + 4|0);
       $232 = HEAP32[$231>>2]|0;
       $233 = ($232|0)==(0|0);
       if ($233) {
        $$01$i$i$i$i$i$i45 = $193;
        while(1) {
         $236 = (($$01$i$i$i$i$i$i45) + 8|0);
         $237 = HEAP32[$236>>2]|0;
         $238 = HEAP32[$237>>2]|0;
         $239 = ($238|0)==($$01$i$i$i$i$i$i45|0);
         if ($239) {
          $$0$i$i$i$i$i$i47 = $237;
          break;
         } else {
          $$01$i$i$i$i$i$i45 = $237;
         }
        }
       } else {
        $$0$i$i$i$i$i$i$i43 = $232;
        while(1) {
         $234 = HEAP32[$$0$i$i$i$i$i$i$i43>>2]|0;
         $235 = ($234|0)==(0|0);
         if ($235) {
          $$0$i$i$i$i$i$i47 = $$0$i$i$i$i$i$i$i43;
          break;
         } else {
          $$0$i$i$i$i$i$i$i43 = $234;
         }
        }
       }
       $240 = ($$0$i$i$i$i$i$i47|0)==($190|0);
       if ($240) {
        label = 61;
        break L85;
       } else {
        $193 = $$0$i$i$i$i$i$i47;
       }
      }
      $300 = ___cxa_find_matching_catch()|0;
      $301 = tempRet0;
      $302 = HEAP32[$185>>2]|0;
      __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($184,$302);
      $$1 = $301;$$12 = $300;
     }
    } while(0);
    if ((label|0) == 61) {
     $241 = (($this) + 80|0);
     HEAP32[$241>>2] = 0;
     $242 = (($old) + 44|0);
     $243 = HEAP32[$242>>2]|0;
     $244 = (($old) + 48|0);
     $245 = ($243|0)==($244|0);
     if ($245) {
      STACKTOP = sp;return;
     }
     $246 = (($0) + 4|0);
     $247 = (($info) + 12|0);
     $248 = (($info) + 8|0);
     $249 = (($info) + 4|0);
     $251 = $243;
     while(1) {
      $250 = (($251) + 16|0);
      $252 = HEAP32[$250>>2]|0;
      HEAP32[$name>>2] = $252;
      ;HEAP32[$info+0>>2]=0|0;HEAP32[$info+4>>2]=0|0;HEAP32[$info+8>>2]=0|0;HEAP32[$info+12>>2]=0|0;
      __THREW__ = 0;
      $253 = (invoke_ii(2988,64)|0);
      $254 = __THREW__; __THREW__ = 0;
      $255 = $254&1;
      if ($255) {
       label = 83;
       break;
      }
      $256 = (($251) + 20|0);
      $257 = HEAP32[$256>>2]|0;
      __THREW__ = 0;
      invoke_vii(3258,($253|0),($257|0));
      $258 = __THREW__; __THREW__ = 0;
      $259 = $258&1;
      if ($259) {
       label = 84;
       break;
      }
      HEAP32[$info>>2] = $253;
      $260 = (($253) + 24|0);
      HEAP32[$260>>2] = $this;
      __THREW__ = 0;
      invoke_viii(1943,($this|0),($name|0),($info|0));
      $261 = __THREW__; __THREW__ = 0;
      $262 = $261&1;
      if ($262) {
       label = 83;
       break;
      }
      $263 = (($251) + 24|0);
      $264 = HEAP32[$263>>2]|0;
      $265 = ($264|0)==(0|0);
      if (!($265)) {
       $266 = HEAP32[$249>>2]|0;
       ;HEAP32[$266+0>>2]=HEAP32[$264+0>>2]|0;HEAP32[$266+4>>2]=HEAP32[$264+4>>2]|0;HEAP32[$266+8>>2]=HEAP32[$264+8>>2]|0;HEAP32[$266+12>>2]=HEAP32[$264+12>>2]|0;
      }
      $267 = (($251) + 28|0);
      $268 = HEAP32[$267>>2]|0;
      $269 = ($268|0)==(0|0);
      if (!($269)) {
       $270 = HEAP32[$248>>2]|0;
       ;HEAP32[$270+0>>2]=HEAP32[$268+0>>2]|0;HEAP32[$270+4>>2]=HEAP32[$268+4>>2]|0;HEAP32[$270+8>>2]=HEAP32[$268+8>>2]|0;HEAP32[$270+12>>2]=HEAP32[$268+12>>2]|0;
      }
      $271 = (($251) + 32|0);
      $272 = HEAP32[$271>>2]|0;
      $273 = ($272|0)==(0|0);
      if (!($273)) {
       $274 = HEAP32[$247>>2]|0;
       ;HEAP32[$274+0>>2]=HEAP32[$272+0>>2]|0;HEAP32[$274+4>>2]=HEAP32[$272+4>>2]|0;HEAP32[$274+8>>2]=HEAP32[$272+8>>2]|0;HEAP32[$274+12>>2]=HEAP32[$272+12>>2]|0;
      }
      $275 = HEAP32[$name>>2]|0;
      HEAP32[$0>>2] = $275;
      ;HEAP32[$246+0>>2]=HEAP32[$info+0>>2]|0;HEAP32[$246+4>>2]=HEAP32[$info+4>>2]|0;HEAP32[$246+8>>2]=HEAP32[$info+8>>2]|0;HEAP32[$246+12>>2]=HEAP32[$info+12>>2]|0;
      __THREW__ = 0;
      invoke_viii(1944,($$byval_copy4|0),($142|0),($0|0));
      $276 = __THREW__; __THREW__ = 0;
      $277 = $276&1;
      if ($277) {
       label = 83;
       break;
      }
      $278 = (($251) + 4|0);
      $279 = HEAP32[$278>>2]|0;
      $280 = ($279|0)==(0|0);
      if ($280) {
       $$01$i$i$i$i = $251;
       while(1) {
        $283 = (($$01$i$i$i$i) + 8|0);
        $284 = HEAP32[$283>>2]|0;
        $285 = HEAP32[$284>>2]|0;
        $286 = ($285|0)==($$01$i$i$i$i|0);
        if ($286) {
         $$0$i$i$i$i = $284;
         break;
        } else {
         $$01$i$i$i$i = $284;
        }
       }
      } else {
       $$0$i$i$i$i$i54 = $279;
       while(1) {
        $281 = HEAP32[$$0$i$i$i$i$i54>>2]|0;
        $282 = ($281|0)==(0|0);
        if ($282) {
         $$0$i$i$i$i = $$0$i$i$i$i$i54;
         break;
        } else {
         $$0$i$i$i$i$i54 = $281;
        }
       }
      }
      $287 = ($$0$i$i$i$i|0)==($244|0);
      if ($287) {
       label = 85;
       break;
      } else {
       $251 = $$0$i$i$i$i;
      }
     }
     if ((label|0) == 83) {
      $303 = ___cxa_find_matching_catch()|0;
      $304 = tempRet0;
      $$0 = $304;$$01 = $303;
     }
     else if ((label|0) == 84) {
      $305 = ___cxa_find_matching_catch()|0;
      $306 = tempRet0;
      __ZdlPv($253);
      $$0 = $306;$$01 = $305;
     }
     else if ((label|0) == 85) {
      STACKTOP = sp;return;
     }
     $307 = HEAP32[$185>>2]|0;
     __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($184,$307);
     $$1 = $$0;$$12 = $$01;
    }
    $308 = HEAP32[$147>>2]|0;
    __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($146,$308);
    $$2 = $$1;$$23 = $$12;
   }
   $309 = HEAP32[$143>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($142,$309);
   $310 = HEAP32[$106>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($105,$310);
   $$4 = $$2;$$45 = $$23;
  }
  $311 = HEAP32[$69>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($68,$311);
  $$5 = $$4;$$56 = $$45;
 }
 $312 = HEAP32[$12>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($11,$312);
 $$6 = $$5;$$67 = $$56;
 ___resumeException($$67|0);
 // unreachable;
}
function __ZN9ShaderLab13PropertySheet19InitTexturePropertyERKNS_16FastPropertyNameERNS0_15TexturePropertyEPKS4_($this,$name,$info,$fromInfo) {
 $this = $this|0;
 $name = $name|0;
 $info = $info|0;
 $fromInfo = $fromInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9ShaderLab13PropertySheet22SetupTexturePropertiesERKNS_16FastPropertyNameERNS0_15TexturePropertyE($this,$name,$info);
 $0 = ($fromInfo|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($fromInfo) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($info) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  ;HEAP32[$5+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$2+12>>2]|0;
 }
 $6 = (($fromInfo) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($info) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  ;HEAP32[$10+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$7+12>>2]|0;
 }
 $11 = (($fromInfo) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($info) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 ;HEAP32[$15+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$12+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheetD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1186,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab13PropertySheetD2Ev($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((653968 + 8|0));
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 48|0);
 $3 = ($1|0)==($2|0);
 L1: do {
  if (!($3)) {
   $5 = $1;
   while(1) {
    $4 = (($5) + 20|0);
    $6 = HEAP32[$4>>2]|0;
    $7 = ($6|0)==(0|0);
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3473,($6|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __ZdlPv($6);
    }
    $10 = (($5) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$01$i$i$i = $5;
     while(1) {
      $15 = (($$01$i$i$i) + 8|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17|0)==($$01$i$i$i|0);
      if ($18) {
       $$0$i$i$i = $16;
       break;
      } else {
       $$01$i$i$i = $16;
      }
     }
    } else {
     $$0$i$i$i$i = $11;
     while(1) {
      $13 = HEAP32[$$0$i$i$i$i>>2]|0;
      $14 = ($13|0)==(0|0);
      if ($14) {
       $$0$i$i$i = $$0$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i = $13;
      }
     }
    }
    $19 = ($$0$i$i$i|0)==($2|0);
    if ($19) {
     break L1;
    } else {
     $5 = $$0$i$i$i;
    }
   }
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   __ZdlPv($6);
   $39 = (($this) + 68|0);
   $40 = (($this) + 72|0);
   $41 = HEAP32[$40>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($39,$41);
   $42 = (($this) + 56|0);
   $43 = (($this) + 60|0);
   $44 = HEAP32[$43>>2]|0;
   __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($42,$44);
   $45 = (($this) + 48|0);
   $46 = HEAP32[$45>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$46);
   $47 = (($this) + 32|0);
   $48 = (($this) + 36|0);
   $49 = HEAP32[$48>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($47,$49);
   $50 = (($this) + 20|0);
   $51 = (($this) + 24|0);
   $52 = HEAP32[$51>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($50,$52);
   $53 = (($this) + 8|0);
   $54 = (($this) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($53,$55);
   ___resumeException($37|0);
   // unreachable;
  }
 } while(0);
 $20 = (($this) + 68|0);
 $21 = (($this) + 72|0);
 $22 = HEAP32[$21>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($20,$22);
 $23 = (($this) + 56|0);
 $24 = (($this) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($23,$25);
 $26 = (($this) + 48|0);
 $27 = HEAP32[$26>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($0,$27);
 $28 = (($this) + 32|0);
 $29 = (($this) + 36|0);
 $30 = HEAP32[$29>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($28,$30);
 $31 = (($this) + 20|0);
 $32 = (($this) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($31,$33);
 $34 = (($this) + 8|0);
 $35 = (($this) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameEfEENS_19__map_value_compareIS3_S4_NS_4lessIS3_EELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($34,$36);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheet17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $2;
 }
 while(1) {
  $4 = (($5) + 20|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   __ZN9ShaderLab6TexEnv17MainThreadCleanupEv($6);
  }
  $8 = (($5) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$01$i$i$i = $5;
   while(1) {
    $13 = (($$01$i$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i$i|0);
    if ($16) {
     $$0$i$i$i = $14;
     break;
    } else {
     $$01$i$i$i = $14;
    }
   }
  } else {
   $$0$i$i$i$i = $9;
   while(1) {
    $11 = HEAP32[$$0$i$i$i$i>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $11;
    }
   }
  }
  $17 = ($$0$i$i$i|0)==($0|0);
  if ($17) {
   break;
  } else {
   $5 = $$0$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = Math_fround($val);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameEfNS_4lessIS2_EENS_9allocatorINS_4pairIKS2_fEEEEEixERS7_($0,$name)|0);
 HEAPF32[$1>>2] = $val;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = $val|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 (__Z13add_or_updateINSt3__13mapIN9ShaderLab16FastPropertyNameE8Vector4fNS0_4lessIS3_EENS0_9allocatorINS0_4pairIKS3_S4_EEEEEES3_S4_EbRT_RKT0_RKT1_($0,$name,$val)|0);
 STACKTOP = sp;return;
}
function __Z13add_or_updateINSt3__13mapIN9ShaderLab16FastPropertyNameE8Vector4fNS0_4lessIS3_EENS0_9allocatorINS0_4pairIKS3_S4_EEEEEES3_S4_EbRT_RKT0_RKT1_($m,$key,$val) {
 $m = $m|0;
 $key = $key|0;
 $val = $val|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i18 = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__parent$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 28|0;
 $__parent$i$i = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = (($m) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($m) + 4|0);
 $5 = ($3|0)==(0|0);
 $$pre = HEAP32[$key>>2]|0;
 if ($5) {
  $$0$ph5$i$i$i18 = $4;
 } else {
  $$0$ph7$i$i$i = $4;$$01$ph6$i$in$i$i = $3;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $6 = (($$013$i$in$i$i) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)<($$pre|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($4|0);
  if ($14) {
   $$0$ph5$i$i$i18 = $4;
  } else {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($$pre|0)<($16|0);
   if ($17) {
    $$0$ph5$i$i$i18 = $$0$ph5$i$i$i;
   } else {
    $18 = (($$0$ph5$i$i$i) + 20|0);
    ;HEAP32[$18+0>>2]=HEAP32[$val+0>>2]|0;HEAP32[$18+4>>2]=HEAP32[$val+4>>2]|0;HEAP32[$18+8>>2]=HEAP32[$val+8>>2]|0;HEAP32[$18+12>>2]=HEAP32[$val+12>>2]|0;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$1>>2] = $$pre;
 $19 = (($1) + 4|0);
 ;HEAP32[$19+0>>2]=HEAP32[$val+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$val+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$val+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$val+12>>2]|0;
 HEAP32[$0>>2] = $$0$ph5$i$i$i18;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $20 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($m,$$byval_copy,$__parent$i$i,$1)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = (__Znwj(36)|0);
 $24 = (($23) + 16|0);
 ;HEAP32[$24+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$1+16>>2]|0;
 $25 = HEAP32[$__parent$i$i>>2]|0;
 HEAP32[$23>>2] = 0;
 $26 = (($23) + 4|0);
 HEAP32[$26>>2] = 0;
 $27 = (($23) + 8|0);
 HEAP32[$27>>2] = $25;
 HEAP32[$20>>2] = $23;
 $28 = HEAP32[$m>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  $32 = $23;
 } else {
  HEAP32[$m>>2] = $29;
  $$pre$i$i$i = HEAP32[$20>>2]|0;
  $32 = $$pre$i$i$i;
 }
 $31 = HEAP32[$2>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($31,$32);
 $33 = (($m) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 1)|0;
 HEAP32[$33>>2] = $35;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab13PropertySheet16SetVectorIndexedERKNS_16FastPropertyNameEif($this,$name,$index,$value) {
 $this = $this|0;
 $name = $name|0;
 $index = $index|0;
 $value = Math_fround($value);
 var $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i18 = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__parent$i$i = 0, $defaultVector = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 48|0;
 $__parent$i$i = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $defaultVector = sp + 32|0;
 $2 = (($this) + 20|0);
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 24|0);
 $6 = ($4|0)==(0|0);
 $$pre = HEAP32[$name>>2]|0;
 if ($6) {
  $$0$ph5$i$i$i18 = $5;
 } else {
  $$0$ph7$i$i$i = $5;$$01$ph6$i$in$i$i = $4;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<($$pre|0);
    if (!($9)) {
     break;
    }
    $12 = (($$013$i$in$i$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $13;
    }
   }
   $10 = HEAP32[$$013$i$in$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $10;
   }
  }
  $15 = ($$0$ph5$i$i$i|0)==($5|0);
  if ($15) {
   $$0$ph5$i$i$i18 = $5;
  } else {
   $16 = (($$0$ph5$i$i$i) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($$pre|0)<($17|0);
   if ($18) {
    $$0$ph5$i$i$i18 = $$0$ph5$i$i$i;
   } else {
    $19 = (($$0$ph5$i$i$i) + 20|0);
    $20 = (($19) + ($index<<2)|0);
    HEAPF32[$20>>2] = $value;
    STACKTOP = sp;return;
   }
  }
 }
 $21 = (($defaultVector) + ($index<<2)|0);
 ;HEAP32[$defaultVector+0>>2]=0|0;HEAP32[$defaultVector+4>>2]=0|0;HEAP32[$defaultVector+8>>2]=0|0;HEAP32[$defaultVector+12>>2]=0|0;
 HEAPF32[$21>>2] = $value;
 HEAP32[$1>>2] = $$pre;
 $22 = (($1) + 4|0);
 ;HEAP32[$22+0>>2]=HEAP32[$defaultVector+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$defaultVector+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$defaultVector+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$defaultVector+12>>2]|0;
 HEAP32[$0>>2] = $$0$ph5$i$i$i18;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $23 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($2,$$byval_copy,$__parent$i$i,$1)|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $26 = (__Znwj(36)|0);
 $27 = (($26) + 16|0);
 ;HEAP32[$27+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$27+16>>2]=HEAP32[$1+16>>2]|0;
 $28 = HEAP32[$__parent$i$i>>2]|0;
 HEAP32[$26>>2] = 0;
 $29 = (($26) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($26) + 8|0);
 HEAP32[$30>>2] = $28;
 HEAP32[$23>>2] = $26;
 $31 = HEAP32[$2>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $35 = $26;
 } else {
  HEAP32[$2>>2] = $32;
  $$pre$i$i$i = HEAP32[$23>>2]|0;
  $35 = $$pre$i$i$i;
 }
 $34 = HEAP32[$3>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($34,$35);
 $36 = (($this) + 28|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 HEAP32[$36>>2] = $38;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheet9SetMatrixERKNS_16FastPropertyNameERK10Matrix4x4f($this,$name,$val) {
 $this = $this|0;
 $name = $name|0;
 $val = $val|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 (__Z13add_or_updateINSt3__13mapIN9ShaderLab16FastPropertyNameE10Matrix4x4fNS0_4lessIS3_EENS0_9allocatorINS0_4pairIKS3_S4_EEEEEES3_S4_EbRT_RKT0_RKT1_($0,$name,$val)|0);
 STACKTOP = sp;return;
}
function __Z13add_or_updateINSt3__13mapIN9ShaderLab16FastPropertyNameE10Matrix4x4fNS0_4lessIS3_EENS0_9allocatorINS0_4pairIKS3_S4_EEEEEES3_S4_EbRT_RKT0_RKT1_($m,$key,$val) {
 $m = $m|0;
 $key = $key|0;
 $val = $val|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i20 = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__parent$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy = sp + 76|0;
 $__parent$i$i = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = (($m) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($m) + 4|0);
 $5 = ($3|0)==(0|0);
 $$pre = HEAP32[$key>>2]|0;
 if ($5) {
  $$0$ph5$i$i$i20 = $4;
 } else {
  $$0$ph7$i$i$i = $4;$$01$ph6$i$in$i$i = $3;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $6 = (($$013$i$in$i$i) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)<($$pre|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($4|0);
  if ($14) {
   $$0$ph5$i$i$i20 = $4;
  } else {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($$pre|0)<($16|0);
   if ($17) {
    $$0$ph5$i$i$i20 = $$0$ph5$i$i$i;
   } else {
    $18 = (($$0$ph5$i$i$i) + 20|0);
    dest=$18+0|0; src=$val+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$1>>2] = $$pre;
 $19 = (($1) + 4|0);
 dest=$19+0|0; src=$val+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$0>>2] = $$0$ph5$i$i$i20;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $20 = (__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($m,$$byval_copy,$__parent$i$i,$1)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = (__Znwj(84)|0);
 $24 = (($23) + 16|0);
 dest=$24+0|0; src=$1+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $25 = HEAP32[$__parent$i$i>>2]|0;
 HEAP32[$23>>2] = 0;
 $26 = (($23) + 4|0);
 HEAP32[$26>>2] = 0;
 $27 = (($23) + 8|0);
 HEAP32[$27>>2] = $25;
 HEAP32[$20>>2] = $23;
 $28 = HEAP32[$m>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  $32 = $23;
 } else {
  HEAP32[$m>>2] = $29;
  $$pre$i$i$i = HEAP32[$20>>2]|0;
  $32 = $$pre$i$i$i;
 }
 $31 = HEAP32[$2>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($31,$32);
 $33 = (($m) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 1)|0;
 HEAP32[$33>>2] = $35;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture($this,$name,$tex) {
 $this = $this|0;
 $name = $name|0;
 $tex = $tex|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy3 = sp;
 $0 = sp + 64|0;
 $1 = sp + 16|0;
 $2 = sp + 32|0;
 $3 = sp + 44|0;
 $4 = sp + 48|0;
 $5 = (__ZN9ShaderLab13PropertySheet26GetOrCreateTexturePropertyERKNS_16FastPropertyNameE($this,$name)|0);
 __ZN9ShaderLab13PropertySheet22SetupTexturePropertiesERKNS_16FastPropertyNameERNS0_15TexturePropertyE($this,$name,$5);
 $6 = ($tex|0)==(0|0);
 $7 = HEAP32[$5>>2]|0;
 do {
  if ($6) {
   HEAP32[$3>>2] = 0;
   $84 = (($5) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
   __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($7,$$byval_copy3,0,0,$85);
   $86 = (($5) + 8|0);
   $87 = HEAP32[$86>>2]|0;
   HEAPF32[$87>>2] = Math_fround(1.0);
   $88 = (($87) + 4|0);
   HEAPF32[$88>>2] = Math_fround(1.0);
   $89 = (($87) + 8|0);
   HEAPF32[$89>>2] = Math_fround(1.0);
   $90 = (($87) + 12|0);
   HEAPF32[$90>>2] = Math_fround(1.0);
   $91 = (($5) + 12|0);
   $92 = HEAP32[$91>>2]|0;
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($4,0,0,Math_fround(1.0));
   ;HEAP32[$92+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$92+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$92+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$92+12>>2]=HEAP32[$4+12>>2]|0;
  } else {
   $8 = (($tex) + 44|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $9;
   $10 = HEAP32[$tex>>2]|0;
   $11 = (($10) + 92|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (FUNCTION_TABLE_ii[$12 & 4095]($tex)|0);
   $14 = (($5) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($7,$$byval_copy3,$13,$tex,$15);
   $16 = (($5) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($tex) + 72|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = (($tex) + 76|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = HEAP32[$tex>>2]|0;
   $23 = (($22) + 116|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (FUNCTION_TABLE_ii[$24 & 4095]($tex)|0);
   $26 = (Math_fround(($25|0)));
   $27 = HEAP32[$tex>>2]|0;
   $28 = (($27) + 120|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (FUNCTION_TABLE_ii[$29 & 4095]($tex)|0);
   $31 = (Math_fround(($30|0)));
   HEAPF32[$17>>2] = $19;
   $32 = (($17) + 4|0);
   HEAPF32[$32>>2] = $21;
   $33 = (($17) + 8|0);
   HEAPF32[$33>>2] = $26;
   $34 = (($17) + 12|0);
   HEAPF32[$34>>2] = $31;
   $35 = (($5) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($tex) + 52|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (__Z19GetActiveColorSpacev()|0);
   $40 = ($39|0)==(1);
   if ($40) {
    $41 = (($tex) + 56|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42;
   } else {
    $43 = 0;
   }
   __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($1,$38,$43,Math_fround(1.0));
   ;HEAP32[$36+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$1+12>>2]|0;
   $44 = (($7) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(5);
   if (!($46)) {
    $47 = HEAP32[$tex>>2]|0;
    $48 = (($47) + 92|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (FUNCTION_TABLE_ii[$49 & 4095]($tex)|0);
    $51 = HEAP32[$44>>2]|0;
    $52 = ($50|0)==($51|0);
    if (!($52)) {
     $53 = HEAP32[$tex>>2]|0;
     $54 = (($53) + 92|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (FUNCTION_TABLE_ii[$55 & 4095]($tex)|0);
     $57 = (654120 + ($56<<2)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = HEAP32[$44>>2]|0;
     $60 = (654120 + ($59<<2)|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = (__ZNK9ShaderLab16FastPropertyName7GetNameEv($name)|0);
     HEAP32[$$byval_copy3>>2] = $58;
     $vararg_ptr1 = (($$byval_copy3) + 4|0);
     HEAP32[$vararg_ptr1>>2] = $61;
     $vararg_ptr2 = (($$byval_copy3) + 8|0);
     HEAP32[$vararg_ptr2>>2] = $62;
     __Z6FormatPKcz($2,654032,$$byval_copy3);
     $63 = HEAP8[$2>>0]|0;
     $64 = $63 & 1;
     $65 = ($64<<24>>24)==(0);
     if ($65) {
      $68 = (($2) + 1|0);
      $69 = $68;
     } else {
      $66 = (($2) + 8|0);
      $67 = HEAP32[$66>>2]|0;
      $69 = $67;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($69|0),0,(654112|0),102,1,0,0,(0|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if (!($71)) {
      $72 = HEAP8[$2>>0]|0;
      $73 = $72 & 1;
      $74 = ($73<<24>>24)==(0);
      if ($74) {
       break;
      }
      $75 = (($2) + 8|0);
      $76 = HEAP32[$75>>2]|0;
      __ZdlPv($76);
      break;
     }
     $77 = ___cxa_find_matching_catch()|0;
     $78 = tempRet0;
     $79 = HEAP8[$2>>0]|0;
     $80 = $79 & 1;
     $81 = ($80<<24>>24)==(0);
     if ($81) {
      ___resumeException($77|0);
      // unreachable;
     }
     $82 = (($2) + 8|0);
     $83 = HEAP32[$82>>2]|0;
     __ZdlPv($83);
     ___resumeException($77|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $93 = (($5) + 4|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = HEAP32[$5>>2]|0;
 $96 = (($95) + 44|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($95) + 32|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($97 * $99);
 $101 = (($95) + 48|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($95) + 36|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($102 * $104);
 $106 = (($95) + 52|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($95) + 56|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 HEAPF32[$94>>2] = $100;
 $110 = (($94) + 4|0);
 HEAPF32[$110>>2] = $105;
 $111 = (($94) + 8|0);
 HEAPF32[$111>>2] = $107;
 $112 = (($94) + 12|0);
 HEAPF32[$112>>2] = $109;
 $113 = HEAP32[$5>>2]|0;
 STACKTOP = sp;return ($113|0);
}
function __ZN9ShaderLab13PropertySheet26GetOrCreateTexturePropertyERKNS_16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $info = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 40|0;
 $1 = sp;
 $info = sp + 24|0;
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 48|0);
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$name>>2]|0;
  $$0$ph7$i$i$i = $4;$$01$ph6$i$in$i$i = $3;
  L3: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)<($6|0);
    if (!($9)) {
     break;
    }
    $12 = (($$013$i$in$i$i) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L3;
    } else {
     $$013$i$in$i$i = $13;
    }
   }
   $10 = HEAP32[$$013$i$in$i$i>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $10;
   }
  }
  $15 = ($$0$ph5$i$i$i|0)==($4|0);
  if (!($15)) {
   $16 = (($$0$ph5$i$i$i) + 16|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($6|0)<($17|0);
   if (!($18)) {
    $37 = $$0$ph5$i$i$i;
    $36 = (($37) + 20|0);
    STACKTOP = sp;return ($36|0);
   }
  }
 }
 ;HEAP32[$info+0>>2]=0|0;HEAP32[$info+4>>2]=0|0;HEAP32[$info+8>>2]=0|0;HEAP32[$info+12>>2]=0|0;
 $19 = (__Znwj(64)|0);
 $20 = (($19) + 8|0);
 $21 = (($19) + 12|0);
 $22 = (($19) + 60|0);
 ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;HEAP32[$20+16>>2]=0|0;HEAP32[$20+20>>2]=0|0;
 HEAP32[$22>>2] = -1;
 HEAP32[$20>>2] = 0;
 HEAP32[$21>>2] = 0;
 HEAP32[$19>>2] = 0;
 $23 = (($19) + 4|0);
 HEAP32[$23>>2] = 5;
 $24 = (($19) + 36|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($19) + 32|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($19) + 40|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($19) + 44|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($19) + 48|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($19) + 52|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($19) + 56|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 HEAP32[$info>>2] = $19;
 $31 = (($19) + 24|0);
 HEAP32[$31>>2] = $this;
 __ZN9ShaderLab13PropertySheet22SetupTexturePropertiesERKNS_16FastPropertyNameERNS0_15TexturePropertyE($this,$name,$info);
 $32 = HEAP32[$name>>2]|0;
 $33 = (($this) + 44|0);
 HEAP32[$1>>2] = $32;
 $34 = (($1) + 4|0);
 ;HEAP32[$34+0>>2]=HEAP32[$info+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$info+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$info+8>>2]|0;HEAP32[$34+12>>2]=HEAP32[$info+12>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_($0,$33,$1);
 $35 = HEAP32[$0>>2]|0;
 $37 = $35;
 $36 = (($37) + 20|0);
 STACKTOP = sp;return ($36|0);
}
function __ZN9ShaderLab13PropertySheet22SetupTexturePropertiesERKNS_16FastPropertyNameERNS0_15TexturePropertyE($this,$name,$info) {
 $this = $this|0;
 $name = $name|0;
 $info = $info|0;
 var $$0 = 0, $$0$i = 0, $$0$i15 = 0, $$0$i31 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i25 = 0, $__p$0$i$i$i9 = 0, $defaultValue = 0, $paramIndex$i = 0, $paramIndex$i12 = 0, $paramIndex$i28 = 0, $propName = 0, $propName1 = 0, $propName2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 200|0;
 $1 = sp + 192|0;
 $2 = sp + 168|0;
 $paramIndex$i28 = sp + 164|0;
 $3 = sp + 160|0;
 $4 = sp + 152|0;
 $5 = sp + 128|0;
 $paramIndex$i12 = sp + 124|0;
 $6 = sp + 120|0;
 $7 = sp + 112|0;
 $8 = sp + 28|0;
 $paramIndex$i = sp;
 $propName = sp + 4|0;
 $9 = sp + 16|0;
 $propName1 = sp + 48|0;
 $10 = sp + 60|0;
 $propName2 = sp + 72|0;
 $11 = sp + 84|0;
 $defaultValue = sp + 96|0;
 $12 = (($info) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 L1: do {
  if ($14) {
   $15 = (__ZNK9ShaderLab16FastPropertyName7GetNameEv($name)|0);
   $16 = (_strlen(($15|0))|0);
   $17 = ($16>>>0)>(4294967279);
   if ($17) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $18 = ($16>>>0)<(11);
   if ($18) {
    $19 = $16 << 1;
    $20 = $19&255;
    HEAP8[$9>>0] = $20;
    $21 = (($9) + 1|0);
    $__p$0$i$i$i = $21;
   } else {
    $22 = (($16) + 16)|0;
    $23 = $22 & -16;
    $24 = (__Znwj($23)|0);
    $25 = (($9) + 8|0);
    HEAP32[$25>>2] = $24;
    $26 = $23 | 1;
    HEAP32[$9>>2] = $26;
    $27 = (($9) + 4|0);
    HEAP32[$27>>2] = $16;
    $__p$0$i$i$i = $24;
   }
   _memcpy(($__p$0$i$i$i|0),($15|0),($16|0))|0;
   $28 = (($__p$0$i$i$i) + ($16)|0);
   HEAP8[$28>>0] = 0;
   __THREW__ = 0;
   invoke_viii(1627,($propName|0),($9|0),(654144|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    $77 = HEAP8[$9>>0]|0;
    $78 = $77 & 1;
    $79 = ($78<<24>>24)==(0);
    if ($79) {
     $$0 = $76;$$01 = $75;
     ___resumeException($$01|0);
     // unreachable;
    }
    $80 = (($9) + 8|0);
    $81 = HEAP32[$80>>2]|0;
    __ZdlPv($81);
    $$0 = $76;$$01 = $75;
    ___resumeException($$01|0);
    // unreachable;
   }
   $31 = HEAP8[$9>>0]|0;
   $32 = $31 & 1;
   $33 = ($32<<24>>24)==(0);
   if (!($33)) {
    $34 = (($9) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    __ZdlPv($35);
   }
   HEAP32[$paramIndex$i>>2] = -1;
   $36 = HEAP8[$propName>>0]|0;
   $37 = $36 & 1;
   $38 = ($37<<24>>24)==(0);
   if ($38) {
    $41 = (($propName) + 1|0);
    $42 = $41;
   } else {
    $39 = (($propName) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $42 = $40;
   }
   __THREW__ = 0;
   $43 = (invoke_iii(2535,($42|0),($paramIndex$i|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   do {
    if (!($45)) {
     if ($43) {
      __THREW__ = 0;
      $46 = (invoke_i(59)|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = HEAP32[$paramIndex$i>>2]|0;
      $50 = ((($46) + ($49<<4)|0) + 4|0);
      $$0$i = $50;
     } else {
      $51 = HEAP8[$propName>>0]|0;
      $52 = $51 & 1;
      $53 = ($52<<24>>24)==(0);
      if ($53) {
       $56 = (($propName) + 1|0);
       $57 = $56;
      } else {
       $54 = (($propName) + 8|0);
       $55 = HEAP32[$54>>2]|0;
       $57 = $55;
      }
      HEAP32[$6>>2] = -1;
      __THREW__ = 0;
      invoke_vii(2618,($6|0),($57|0));
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      $60 = HEAP32[$6>>2]|0;
      $61 = (($this) + 20|0);
      HEAP32[$8>>2] = $60;
      $62 = (($8) + 4|0);
      HEAPF32[$62>>2] = Math_fround(1.0);
      $63 = (($8) + 8|0);
      HEAPF32[$63>>2] = Math_fround(1.0);
      $64 = (($8) + 12|0);
      HEAPF32[$64>>2] = Math_fround(0.0);
      $65 = (($8) + 16|0);
      HEAPF32[$65>>2] = Math_fround(0.0);
      __THREW__ = 0;
      invoke_viii(1945,($7|0),($61|0),($8|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $68 = HEAP32[$7>>2]|0;
      $69 = (($68) + 20|0);
      $$0$i = $69;
     }
     HEAP32[$12>>2] = $$0$i;
     $70 = HEAP8[$propName>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      break L1;
     }
     $73 = (($propName) + 8|0);
     $74 = HEAP32[$73>>2]|0;
     __ZdlPv($74);
     break L1;
    }
   } while(0);
   $82 = ___cxa_find_matching_catch()|0;
   $83 = tempRet0;
   $84 = HEAP8[$propName>>0]|0;
   $85 = $84 & 1;
   $86 = ($85<<24>>24)==(0);
   if ($86) {
    $$0 = $83;$$01 = $82;
    ___resumeException($$01|0);
    // unreachable;
   }
   $87 = (($propName) + 8|0);
   $88 = HEAP32[$87>>2]|0;
   __ZdlPv($88);
   $$0 = $83;$$01 = $82;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $89 = (($info) + 8|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($90|0)==(0|0);
 L44: do {
  if ($91) {
   $92 = (__ZNK9ShaderLab16FastPropertyName7GetNameEv($name)|0);
   $93 = (_strlen(($92|0))|0);
   $94 = ($93>>>0)>(4294967279);
   if ($94) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $95 = ($93>>>0)<(11);
   if ($95) {
    $96 = $93 << 1;
    $97 = $96&255;
    HEAP8[$10>>0] = $97;
    $98 = (($10) + 1|0);
    $__p$0$i$i$i9 = $98;
   } else {
    $99 = (($93) + 16)|0;
    $100 = $99 & -16;
    $101 = (__Znwj($100)|0);
    $102 = (($10) + 8|0);
    HEAP32[$102>>2] = $101;
    $103 = $100 | 1;
    HEAP32[$10>>2] = $103;
    $104 = (($10) + 4|0);
    HEAP32[$104>>2] = $93;
    $__p$0$i$i$i9 = $101;
   }
   _memcpy(($__p$0$i$i$i9|0),($92|0),($93|0))|0;
   $105 = (($__p$0$i$i$i9) + ($93)|0);
   HEAP8[$105>>0] = 0;
   __THREW__ = 0;
   invoke_viii(1627,($propName1|0),($10|0),(654152|0));
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    $152 = ___cxa_find_matching_catch()|0;
    $153 = tempRet0;
    $154 = HEAP8[$10>>0]|0;
    $155 = $154 & 1;
    $156 = ($155<<24>>24)==(0);
    if ($156) {
     $$0 = $153;$$01 = $152;
     ___resumeException($$01|0);
     // unreachable;
    }
    $157 = (($10) + 8|0);
    $158 = HEAP32[$157>>2]|0;
    __ZdlPv($158);
    $$0 = $153;$$01 = $152;
    ___resumeException($$01|0);
    // unreachable;
   }
   $108 = HEAP8[$10>>0]|0;
   $109 = $108 & 1;
   $110 = ($109<<24>>24)==(0);
   if (!($110)) {
    $111 = (($10) + 8|0);
    $112 = HEAP32[$111>>2]|0;
    __ZdlPv($112);
   }
   HEAP32[$paramIndex$i12>>2] = -1;
   $113 = HEAP8[$propName1>>0]|0;
   $114 = $113 & 1;
   $115 = ($114<<24>>24)==(0);
   if ($115) {
    $118 = (($propName1) + 1|0);
    $119 = $118;
   } else {
    $116 = (($propName1) + 8|0);
    $117 = HEAP32[$116>>2]|0;
    $119 = $117;
   }
   __THREW__ = 0;
   $120 = (invoke_iii(2535,($119|0),($paramIndex$i12|0))|0);
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   do {
    if (!($122)) {
     if ($120) {
      __THREW__ = 0;
      $123 = (invoke_i(59)|0);
      $124 = __THREW__; __THREW__ = 0;
      $125 = $124&1;
      if ($125) {
       break;
      }
      $126 = HEAP32[$paramIndex$i12>>2]|0;
      $127 = ((($123) + ($126<<4)|0) + 4|0);
      $$0$i15 = $127;
     } else {
      $128 = HEAP8[$propName1>>0]|0;
      $129 = $128 & 1;
      $130 = ($129<<24>>24)==(0);
      if ($130) {
       $133 = (($propName1) + 1|0);
       $134 = $133;
      } else {
       $131 = (($propName1) + 8|0);
       $132 = HEAP32[$131>>2]|0;
       $134 = $132;
      }
      HEAP32[$3>>2] = -1;
      __THREW__ = 0;
      invoke_vii(2618,($3|0),($134|0));
      $135 = __THREW__; __THREW__ = 0;
      $136 = $135&1;
      if ($136) {
       break;
      }
      $137 = HEAP32[$3>>2]|0;
      $138 = (($this) + 20|0);
      HEAP32[$5>>2] = $137;
      $139 = (($5) + 4|0);
      HEAPF32[$139>>2] = Math_fround(1.0);
      $140 = (($5) + 8|0);
      HEAPF32[$140>>2] = Math_fround(1.0);
      $141 = (($5) + 12|0);
      HEAPF32[$141>>2] = Math_fround(1.0);
      $142 = (($5) + 16|0);
      HEAPF32[$142>>2] = Math_fround(1.0);
      __THREW__ = 0;
      invoke_viii(1945,($4|0),($138|0),($5|0));
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       break;
      }
      $145 = HEAP32[$4>>2]|0;
      $146 = (($145) + 20|0);
      $$0$i15 = $146;
     }
     HEAP32[$89>>2] = $$0$i15;
     $147 = HEAP8[$propName1>>0]|0;
     $148 = $147 & 1;
     $149 = ($148<<24>>24)==(0);
     if ($149) {
      break L44;
     }
     $150 = (($propName1) + 8|0);
     $151 = HEAP32[$150>>2]|0;
     __ZdlPv($151);
     break L44;
    }
   } while(0);
   $159 = ___cxa_find_matching_catch()|0;
   $160 = tempRet0;
   $161 = HEAP8[$propName1>>0]|0;
   $162 = $161 & 1;
   $163 = ($162<<24>>24)==(0);
   if ($163) {
    $$0 = $160;$$01 = $159;
    ___resumeException($$01|0);
    // unreachable;
   }
   $164 = (($propName1) + 8|0);
   $165 = HEAP32[$164>>2]|0;
   __ZdlPv($165);
   $$0 = $160;$$01 = $159;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $166 = (($info) + 12|0);
 $167 = HEAP32[$166>>2]|0;
 $168 = ($167|0)==(0|0);
 if (!($168)) {
  STACKTOP = sp;return;
 }
 $169 = (__ZNK9ShaderLab16FastPropertyName7GetNameEv($name)|0);
 $170 = (_strlen(($169|0))|0);
 $171 = ($170>>>0)>(4294967279);
 if ($171) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $172 = ($170>>>0)<(11);
 if ($172) {
  $173 = $170 << 1;
  $174 = $173&255;
  HEAP8[$11>>0] = $174;
  $175 = (($11) + 1|0);
  $__p$0$i$i$i25 = $175;
 } else {
  $176 = (($170) + 16)|0;
  $177 = $176 & -16;
  $178 = (__Znwj($177)|0);
  $179 = (($11) + 8|0);
  HEAP32[$179>>2] = $178;
  $180 = $177 | 1;
  HEAP32[$11>>2] = $180;
  $181 = (($11) + 4|0);
  HEAP32[$181>>2] = $170;
  $__p$0$i$i$i25 = $178;
 }
 _memcpy(($__p$0$i$i$i25|0),($169|0),($170|0))|0;
 $182 = (($__p$0$i$i$i25) + ($170)|0);
 HEAP8[$182>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1627,($propName2|0),($11|0),(654168|0));
 $183 = __THREW__; __THREW__ = 0;
 $184 = $183&1;
 if ($184) {
  $228 = ___cxa_find_matching_catch()|0;
  $229 = tempRet0;
  $230 = HEAP8[$11>>0]|0;
  $231 = $230 & 1;
  $232 = ($231<<24>>24)==(0);
  if ($232) {
   $$0 = $229;$$01 = $228;
   ___resumeException($$01|0);
   // unreachable;
  }
  $233 = (($11) + 8|0);
  $234 = HEAP32[$233>>2]|0;
  __ZdlPv($234);
  $$0 = $229;$$01 = $228;
  ___resumeException($$01|0);
  // unreachable;
 }
 $185 = HEAP8[$11>>0]|0;
 $186 = $185 & 1;
 $187 = ($186<<24>>24)==(0);
 if (!($187)) {
  $188 = (($11) + 8|0);
  $189 = HEAP32[$188>>2]|0;
  __ZdlPv($189);
 }
 __THREW__ = 0;
 invoke_viiif(7,($defaultValue|0),0,0,1.0);
 $190 = __THREW__; __THREW__ = 0;
 $191 = $190&1;
 do {
  if (!($191)) {
   HEAP32[$paramIndex$i28>>2] = -1;
   $192 = HEAP8[$propName2>>0]|0;
   $193 = $192 & 1;
   $194 = ($193<<24>>24)==(0);
   if ($194) {
    $197 = (($propName2) + 1|0);
    $198 = $197;
   } else {
    $195 = (($propName2) + 8|0);
    $196 = HEAP32[$195>>2]|0;
    $198 = $196;
   }
   __THREW__ = 0;
   $199 = (invoke_iii(2535,($198|0),($paramIndex$i28|0))|0);
   $200 = __THREW__; __THREW__ = 0;
   $201 = $200&1;
   if (!($201)) {
    if ($199) {
     __THREW__ = 0;
     $202 = (invoke_i(59)|0);
     $203 = __THREW__; __THREW__ = 0;
     $204 = $203&1;
     if ($204) {
      break;
     }
     $205 = HEAP32[$paramIndex$i28>>2]|0;
     $206 = ((($202) + ($205<<4)|0) + 4|0);
     $$0$i31 = $206;
    } else {
     $207 = HEAP8[$propName2>>0]|0;
     $208 = $207 & 1;
     $209 = ($208<<24>>24)==(0);
     if ($209) {
      $212 = (($propName2) + 1|0);
      $213 = $212;
     } else {
      $210 = (($propName2) + 8|0);
      $211 = HEAP32[$210>>2]|0;
      $213 = $211;
     }
     HEAP32[$0>>2] = -1;
     __THREW__ = 0;
     invoke_vii(2618,($0|0),($213|0));
     $214 = __THREW__; __THREW__ = 0;
     $215 = $214&1;
     if ($215) {
      break;
     }
     $216 = HEAP32[$0>>2]|0;
     $217 = (($this) + 20|0);
     HEAP32[$2>>2] = $216;
     $218 = (($2) + 4|0);
     ;HEAP32[$218+0>>2]=HEAP32[$defaultValue+0>>2]|0;HEAP32[$218+4>>2]=HEAP32[$defaultValue+4>>2]|0;HEAP32[$218+8>>2]=HEAP32[$defaultValue+8>>2]|0;HEAP32[$218+12>>2]=HEAP32[$defaultValue+12>>2]|0;
     __THREW__ = 0;
     invoke_viii(1945,($1|0),($217|0),($2|0));
     $219 = __THREW__; __THREW__ = 0;
     $220 = $219&1;
     if ($220) {
      break;
     }
     $221 = HEAP32[$1>>2]|0;
     $222 = (($221) + 20|0);
     $$0$i31 = $222;
    }
    HEAP32[$166>>2] = $$0$i31;
    $223 = HEAP8[$propName2>>0]|0;
    $224 = $223 & 1;
    $225 = ($224<<24>>24)==(0);
    if ($225) {
     STACKTOP = sp;return;
    }
    $226 = (($propName2) + 8|0);
    $227 = HEAP32[$226>>2]|0;
    __ZdlPv($227);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $235 = ___cxa_find_matching_catch()|0;
 $236 = tempRet0;
 $237 = HEAP8[$propName2>>0]|0;
 $238 = $237 & 1;
 $239 = ($238<<24>>24)==(0);
 if ($239) {
  $$0 = $236;$$01 = $235;
  ___resumeException($$01|0);
  // unreachable;
 }
 $240 = (($propName2) + 8|0);
 $241 = HEAP32[$240>>2]|0;
 __ZdlPv($241);
 $$0 = $236;$$01 = $235;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN9ShaderLab13PropertySheet16SetRectTextureIDERKNS_16FastPropertyNameE9TextureIDiiffff($this,$name,$texID,$width,$height,$texelSizeX,$texelSizeY,$uvScaleX,$uvScaleY) {
 $this = $this|0;
 $name = $name|0;
 $texID = $texID|0;
 $width = $width|0;
 $height = $height|0;
 $texelSizeX = Math_fround($texelSizeX);
 $texelSizeY = Math_fround($texelSizeY);
 $uvScaleX = Math_fround($uvScaleX);
 $uvScaleY = Math_fround($uvScaleY);
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (__ZN9ShaderLab13PropertySheet26GetOrCreateTexturePropertyERKNS_16FastPropertyNameE($this,$name)|0);
 __ZN9ShaderLab13PropertySheet22SetupTexturePropertiesERKNS_16FastPropertyNameERNS0_15TexturePropertyE($this,$name,$3);
 $4 = HEAP32[$texID>>2]|0;
 $5 = ($4|0)==(0);
 $6 = HEAP32[$3>>2]|0;
 if ($5) {
  HEAP32[$1>>2] = 0;
  $17 = (($3) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($6,$$byval_copy1,0,0,$18);
  $19 = (($3) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  HEAPF32[$20>>2] = Math_fround(1.0);
  $21 = (($20) + 4|0);
  HEAPF32[$21>>2] = Math_fround(1.0);
  $22 = (($20) + 8|0);
  HEAPF32[$22>>2] = Math_fround(1.0);
  $23 = (($20) + 12|0);
  HEAPF32[$23>>2] = Math_fround(1.0);
 } else {
  HEAP32[$0>>2] = $4;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($6,$$byval_copy1,2,0,$8);
  $9 = HEAP32[$3>>2]|0;
  __ZN9ShaderLab6TexEnv21TextureUVScaleChangedEff($9,$uvScaleX,$uvScaleY);
  $10 = (($3) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (Math_fround(($width|0)));
  $13 = (Math_fround(($height|0)));
  HEAPF32[$11>>2] = $texelSizeX;
  $14 = (($11) + 4|0);
  HEAPF32[$14>>2] = $texelSizeY;
  $15 = (($11) + 8|0);
  HEAPF32[$15>>2] = $12;
  $16 = (($11) + 12|0);
  HEAPF32[$16>>2] = $13;
 }
 $24 = (($3) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$3>>2]|0;
 $27 = (($26) + 44|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($26) + 32|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 * $30);
 $32 = (($26) + 48|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($26) + 36|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($33 * $35);
 $37 = (($26) + 52|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($26) + 56|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 HEAPF32[$25>>2] = $31;
 $41 = (($25) + 4|0);
 HEAPF32[$41>>2] = $36;
 $42 = (($25) + 8|0);
 HEAPF32[$42>>2] = $38;
 $43 = (($25) + 12|0);
 HEAPF32[$43>>2] = $40;
 $44 = (($3) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($2,0,0,Math_fround(1.0));
 ;HEAP32[$45+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$2+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheet23SetTextureWithPlacementERKNS_16FastPropertyNameEP7Texture8Vector2fS6_($this,$name,$tex,$scale,$offset) {
 $this = $this|0;
 $name = $name|0;
 $tex = $tex|0;
 $scale = $scale|0;
 $offset = $offset|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0);
 var $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0;
 var $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy3 = sp;
 $0 = sp + 64|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = sp + 48|0;
 $5 = (__ZN9ShaderLab13PropertySheet26GetOrCreateTexturePropertyERKNS_16FastPropertyNameE($this,$name)|0);
 __ZN9ShaderLab13PropertySheet22SetupTexturePropertiesERKNS_16FastPropertyNameERNS0_15TexturePropertyE($this,$name,$5);
 $6 = ($tex|0)!=(0|0);
 $7 = HEAP32[$5>>2]|0;
 if ($6) {
  $8 = (($tex) + 44|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$0>>2] = $9;
  $10 = HEAP32[$tex>>2]|0;
  $11 = (($10) + 92|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 4095]($tex)|0);
  $14 = (($5) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($7,$$byval_copy3,$13,$tex,$15);
 } else {
  HEAP32[$1>>2] = 0;
  $16 = (($5) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($7,$$byval_copy3,0,0,$17);
 }
 $18 = HEAP32[$5>>2]|0;
 $19 = Math_fround(HEAPF32[$offset>>2]);
 $20 = (($offset) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 __ZN9ShaderLab6TexEnv16SetTextureOffsetEff($18,$19,$21);
 $22 = HEAP32[$5>>2]|0;
 $23 = Math_fround(HEAPF32[$scale>>2]);
 $24 = (($scale) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 __ZN9ShaderLab6TexEnv15SetTextureScaleEff($22,$23,$25);
 $26 = (($5) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$5>>2]|0;
 $29 = (($28) + 44|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($28) + 32|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($30 * $32);
 $34 = (($28) + 48|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($28) + 36|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 * $37);
 $39 = (($28) + 52|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($28) + 56|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 HEAPF32[$27>>2] = $33;
 $43 = (($27) + 4|0);
 HEAPF32[$43>>2] = $38;
 $44 = (($27) + 8|0);
 HEAPF32[$44>>2] = $40;
 $45 = (($27) + 12|0);
 HEAPF32[$45>>2] = $42;
 $46 = (($5) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 if (!($6)) {
  HEAPF32[$47>>2] = Math_fround(1.0);
  $119 = (($47) + 4|0);
  HEAPF32[$119>>2] = Math_fround(1.0);
  $120 = (($47) + 8|0);
  HEAPF32[$120>>2] = Math_fround(1.0);
  $121 = (($47) + 12|0);
  HEAPF32[$121>>2] = Math_fround(1.0);
  $122 = (($5) + 12|0);
  $123 = HEAP32[$122>>2]|0;
  __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($4,0,0,Math_fround(1.0));
  ;HEAP32[$123+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$123+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$123+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$123+12>>2]=HEAP32[$4+12>>2]|0;
  STACKTOP = sp;return;
 }
 $48 = (($tex) + 72|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($tex) + 76|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = HEAP32[$tex>>2]|0;
 $53 = (($52) + 116|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (FUNCTION_TABLE_ii[$54 & 4095]($tex)|0);
 $56 = (Math_fround(($55|0)));
 $57 = HEAP32[$tex>>2]|0;
 $58 = (($57) + 120|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (FUNCTION_TABLE_ii[$59 & 4095]($tex)|0);
 $61 = (Math_fround(($60|0)));
 HEAPF32[$47>>2] = $49;
 $62 = (($47) + 4|0);
 HEAPF32[$62>>2] = $51;
 $63 = (($47) + 8|0);
 HEAPF32[$63>>2] = $56;
 $64 = (($47) + 12|0);
 HEAPF32[$64>>2] = $61;
 $65 = (($5) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($tex) + 52|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (__Z19GetActiveColorSpacev()|0);
 $70 = ($69|0)==(1);
 if ($70) {
  $71 = (($tex) + 56|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = $72;
 } else {
  $73 = 0;
 }
 __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($2,$68,$73,Math_fround(1.0));
 ;HEAP32[$66+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$66+12>>2]=HEAP32[$2+12>>2]|0;
 $74 = HEAP32[$5>>2]|0;
 $75 = (($74) + 4|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(5);
 if ($77) {
  STACKTOP = sp;return;
 }
 $78 = HEAP32[$tex>>2]|0;
 $79 = (($78) + 92|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (FUNCTION_TABLE_ii[$80 & 4095]($tex)|0);
 $82 = HEAP32[$5>>2]|0;
 $83 = (($82) + 4|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($81|0)==($84|0);
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = HEAP32[$tex>>2]|0;
 $87 = (($86) + 92|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (FUNCTION_TABLE_ii[$88 & 4095]($tex)|0);
 $90 = (654120 + ($89<<2)|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = HEAP32[$5>>2]|0;
 $93 = (($92) + 4|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (654120 + ($94<<2)|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (__ZNK9ShaderLab16FastPropertyName7GetNameEv($name)|0);
 HEAP32[$$byval_copy3>>2] = $91;
 $vararg_ptr1 = (($$byval_copy3) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $96;
 $vararg_ptr2 = (($$byval_copy3) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $97;
 __Z6FormatPKcz($3,654032,$$byval_copy3);
 $98 = HEAP8[$3>>0]|0;
 $99 = $98 & 1;
 $100 = ($99<<24>>24)==(0);
 if ($100) {
  $103 = (($3) + 1|0);
  $104 = $103;
 } else {
  $101 = (($3) + 8|0);
  $102 = HEAP32[$101>>2]|0;
  $104 = $102;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($104|0),0,(654112|0),154,1,0,0,(0|0));
 $105 = __THREW__; __THREW__ = 0;
 $106 = $105&1;
 if ($106) {
  $112 = ___cxa_find_matching_catch()|0;
  $113 = tempRet0;
  $114 = HEAP8[$3>>0]|0;
  $115 = $114 & 1;
  $116 = ($115<<24>>24)==(0);
  if ($116) {
   ___resumeException($112|0);
   // unreachable;
  }
  $117 = (($3) + 8|0);
  $118 = HEAP32[$117>>2]|0;
  __ZdlPv($118);
  ___resumeException($112|0);
  // unreachable;
 } else {
  $107 = HEAP8[$3>>0]|0;
  $108 = $107 & 1;
  $109 = ($108<<24>>24)==(0);
  if ($109) {
   STACKTOP = sp;return;
  }
  $110 = (($3) + 8|0);
  $111 = HEAP32[$110>>2]|0;
  __ZdlPv($111);
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab13PropertySheet16SetTextureOffsetERKNS_16FastPropertyNameEff($this,$name,$x,$y) {
 $this = $this|0;
 $name = $name|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9ShaderLab13PropertySheet26GetOrCreateTexturePropertyERKNS_16FastPropertyNameE($this,$name)|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN9ShaderLab6TexEnv16SetTextureOffsetEff($1,$x,$y);
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + 8|0);
 HEAPF32[$5>>2] = $x;
 $6 = (($3) + 12|0);
 HEAPF32[$6>>2] = $y;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheet15SetTextureScaleERKNS_16FastPropertyNameEff($this,$name,$x,$y) {
 $this = $this|0;
 $name = $name|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9ShaderLab13PropertySheet26GetOrCreateTexturePropertyERKNS_16FastPropertyNameE($this,$name)|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN9ShaderLab6TexEnv15SetTextureScaleEff($1,$x,$y);
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 32|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $x);
 HEAPF32[$3>>2] = $8;
 $9 = (($5) + 36|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * $y);
 $12 = (($3) + 4|0);
 HEAPF32[$12>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheet31SetTextureScaleAndOffsetIndexedERKNS_16FastPropertyNameEif($this,$name,$index,$value) {
 $this = $this|0;
 $name = $name|0;
 $index = $index|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $v$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9ShaderLab13PropertySheet26GetOrCreateTexturePropertyERKNS_16FastPropertyNameE($this,$name)|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN9ShaderLab6TexEnv31SetTextureScaleAndOffsetIndexedEif($1,$index,$value);
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 if ((($index|0) == 0)) {
  $5 = HEAP32[$0>>2]|0;
  $6 = (($5) + 32|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround($7 * $value);
  $v$1 = $8;
 } else if ((($index|0) == 1)) {
  $9 = HEAP32[$0>>2]|0;
  $10 = (($9) + 36|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($11 * $value);
  $v$1 = $12;
 } else {
  $v$1 = $value;
 }
 $13 = (($3) + ($index<<2)|0);
 HEAPF32[$13>>2] = $v$1;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab13PropertySheet11SetColorTagERKNS_16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 56|0);
 __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_($0,$1,$name);
 STACKTOP = sp;return;
}
function __ZNK9ShaderLab13PropertySheet11GetColorTagERKNS_16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__rt$0$in$i$i = 0, $__rt$0$in$in$be$i$i = 0, $__rt$0$in1$i$i = 0, $__rt$0$in2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $__rt$0$in1$i$i = HEAP32[$0>>2]|0;
 $1 = ($__rt$0$in1$i$i|0)==(0|0);
 if ($1) {
  $$0$i$i = 0;
  STACKTOP = sp;return ($$0$i$i|0);
 }
 $2 = HEAP32[$name>>2]|0;
 $__rt$0$in2$i$i = $__rt$0$in1$i$i;
 while(1) {
  $3 = (($__rt$0$in2$i$i) + 16|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($2|0)<($4|0);
  if ($5) {
   $__rt$0$in$in$be$i$i = $__rt$0$in2$i$i;
  } else {
   $6 = ($4|0)<($2|0);
   if (!($6)) {
    $$0$i$i = 1;
    label = 8;
    break;
   }
   $7 = (($__rt$0$in2$i$i) + 4|0);
   $__rt$0$in$in$be$i$i = $7;
  }
  $__rt$0$in$i$i = HEAP32[$__rt$0$in$in$be$i$i>>2]|0;
  $8 = ($__rt$0$in$i$i|0)==(0|0);
  if ($8) {
   $$0$i$i = 0;
   label = 8;
   break;
  } else {
   $__rt$0$in2$i$i = $__rt$0$in$i$i;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0$i$i|0);
 }
 return 0|0;
}
function __ZNK9ShaderLab13PropertySheet11HasPropertyERKNS_16FastPropertyNameE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__rt$0$in$i$i = 0, $__rt$0$in$i$i12 = 0, $__rt$0$in$i$i19 = 0, $__rt$0$in$i$i26 = 0, $__rt$0$in$i$i5 = 0, $__rt$0$in$in$be$i$i = 0, $__rt$0$in$in$be$i$i11 = 0, $__rt$0$in$in$be$i$i18 = 0, $__rt$0$in$in$be$i$i25 = 0, $__rt$0$in$in$be$i$i4 = 0, $__rt$0$in1$i$i = 0, $__rt$0$in1$i$i1 = 0, $__rt$0$in1$i$i15 = 0, $__rt$0$in1$i$i22 = 0;
 var $__rt$0$in1$i$i8 = 0, $__rt$0$in2$i$i = 0, $__rt$0$in2$i$i10 = 0, $__rt$0$in2$i$i17 = 0, $__rt$0$in2$i$i24 = 0, $__rt$0$in2$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $__rt$0$in1$i$i = HEAP32[$0>>2]|0;
 $1 = ($__rt$0$in1$i$i|0)==(0|0);
 L1: do {
  if (!($1)) {
   $2 = HEAP32[$name>>2]|0;
   $__rt$0$in2$i$i = $__rt$0$in1$i$i;
   while(1) {
    $3 = (($__rt$0$in2$i$i) + 16|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($2|0)<($4|0);
    if ($5) {
     $__rt$0$in$in$be$i$i = $__rt$0$in2$i$i;
    } else {
     $6 = ($4|0)<($2|0);
     if (!($6)) {
      $$0 = 1;
      break;
     }
     $7 = (($__rt$0$in2$i$i) + 4|0);
     $__rt$0$in$in$be$i$i = $7;
    }
    $__rt$0$in$i$i = HEAP32[$__rt$0$in$in$be$i$i>>2]|0;
    $8 = ($__rt$0$in$i$i|0)==(0|0);
    if ($8) {
     break L1;
    } else {
     $__rt$0$in2$i$i = $__rt$0$in$i$i;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $9 = (($this) + 24|0);
 $__rt$0$in1$i$i22 = HEAP32[$9>>2]|0;
 $10 = ($__rt$0$in1$i$i22|0)==(0|0);
 L12: do {
  if (!($10)) {
   $11 = HEAP32[$name>>2]|0;
   $__rt$0$in2$i$i24 = $__rt$0$in1$i$i22;
   while(1) {
    $12 = (($__rt$0$in2$i$i24) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)<($13|0);
    if ($14) {
     $__rt$0$in$in$be$i$i25 = $__rt$0$in2$i$i24;
    } else {
     $15 = ($13|0)<($11|0);
     if (!($15)) {
      $$0 = 1;
      break;
     }
     $16 = (($__rt$0$in2$i$i24) + 4|0);
     $__rt$0$in$in$be$i$i25 = $16;
    }
    $__rt$0$in$i$i26 = HEAP32[$__rt$0$in$in$be$i$i25>>2]|0;
    $17 = ($__rt$0$in$i$i26|0)==(0|0);
    if ($17) {
     break L12;
    } else {
     $__rt$0$in2$i$i24 = $__rt$0$in$i$i26;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $18 = (($this) + 36|0);
 $__rt$0$in1$i$i15 = HEAP32[$18>>2]|0;
 $19 = ($__rt$0$in1$i$i15|0)==(0|0);
 L23: do {
  if (!($19)) {
   $20 = HEAP32[$name>>2]|0;
   $__rt$0$in2$i$i17 = $__rt$0$in1$i$i15;
   while(1) {
    $21 = (($__rt$0$in2$i$i17) + 16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($20|0)<($22|0);
    if ($23) {
     $__rt$0$in$in$be$i$i18 = $__rt$0$in2$i$i17;
    } else {
     $24 = ($22|0)<($20|0);
     if (!($24)) {
      $$0 = 1;
      break;
     }
     $25 = (($__rt$0$in2$i$i17) + 4|0);
     $__rt$0$in$in$be$i$i18 = $25;
    }
    $__rt$0$in$i$i19 = HEAP32[$__rt$0$in$in$be$i$i18>>2]|0;
    $26 = ($__rt$0$in$i$i19|0)==(0|0);
    if ($26) {
     break L23;
    } else {
     $__rt$0$in2$i$i17 = $__rt$0$in$i$i19;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $27 = (($this) + 48|0);
 $__rt$0$in1$i$i8 = HEAP32[$27>>2]|0;
 $28 = ($__rt$0$in1$i$i8|0)==(0|0);
 L34: do {
  if (!($28)) {
   $29 = HEAP32[$name>>2]|0;
   $__rt$0$in2$i$i10 = $__rt$0$in1$i$i8;
   while(1) {
    $30 = (($__rt$0$in2$i$i10) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($29|0)<($31|0);
    if ($32) {
     $__rt$0$in$in$be$i$i11 = $__rt$0$in2$i$i10;
    } else {
     $33 = ($31|0)<($29|0);
     if (!($33)) {
      $$0 = 1;
      break;
     }
     $34 = (($__rt$0$in2$i$i10) + 4|0);
     $__rt$0$in$in$be$i$i11 = $34;
    }
    $__rt$0$in$i$i12 = HEAP32[$__rt$0$in$in$be$i$i11>>2]|0;
    $35 = ($__rt$0$in$i$i12|0)==(0|0);
    if ($35) {
     break L34;
    } else {
     $__rt$0$in2$i$i10 = $__rt$0$in$i$i12;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $36 = (($this) + 72|0);
 $__rt$0$in1$i$i1 = HEAP32[$36>>2]|0;
 $37 = ($__rt$0$in1$i$i1|0)==(0|0);
 if ($37) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = HEAP32[$name>>2]|0;
 $__rt$0$in2$i$i3 = $__rt$0$in1$i$i1;
 while(1) {
  $39 = (($__rt$0$in2$i$i3) + 16|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($38|0)<($40|0);
  if ($41) {
   $__rt$0$in$in$be$i$i4 = $__rt$0$in2$i$i3;
  } else {
   $42 = ($40|0)<($38|0);
   if (!($42)) {
    $$0 = 1;
    label = 36;
    break;
   }
   $43 = (($__rt$0$in2$i$i3) + 4|0);
   $__rt$0$in$in$be$i$i4 = $43;
  }
  $__rt$0$in$i$i5 = HEAP32[$__rt$0$in$in$be$i$i4>>2]|0;
  $44 = ($__rt$0$in$i$i5|0)==(0|0);
  if ($44) {
   $$0 = 0;
   label = 36;
   break;
  } else {
   $__rt$0$in2$i$i3 = $__rt$0$in$i$i5;
  }
 }
 if ((label|0) == 36) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK9ShaderLab13PropertySheet14GetMemoryUsageEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, $tmp2 = 0, $tmp3 = 0;
 var $tmp4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7*68)|0;
 $9 = (($this) + 52|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 76|0);
 $12 = HEAP32[$11>>2]|0;
 $tmp = (($3) + ($1))|0;
 $tmp1 = (($tmp) + ($12))|0;
 $tmp2 = $tmp1 << 3;
 $tmp3 = (($10) + ($5))|0;
 $tmp4 = ($tmp3*20)|0;
 $13 = (($8) + 84)|0;
 $14 = (($13) + ($tmp2))|0;
 $15 = (($14) + ($tmp4))|0;
 STACKTOP = sp;return ($15|0);
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = HEAP32[$__v>>2]|0;
  $4 = (($1) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($3|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($3|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($3|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($3|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $31 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $30 = (($agg$result) + 4|0);
  HEAP8[$30>>0] = $31;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(20)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__v>>2]|0;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $31 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $30 = (($agg$result) + 4|0);
 HEAP8[$30>>0] = $31;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = HEAP32[$__v>>2]|0;
  $4 = (($1) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($3|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($3|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($3|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($3|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE12__find_equalIS5_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS5_PNS_11__tree_nodeIS5_SF_EEiEESI_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = HEAP32[$__v>>2]|0;
  $4 = (($1) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($3|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($3|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($3|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($3|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$20 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $30 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(36)|0);
 $17 = (($16) + 16|0);
 ;HEAP32[$17+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$__v+16>>2]|0;
 HEAP32[$16>>2] = 0;
 $18 = (($16) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $16;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $16;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE15ComputeBufferIDEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIN9ShaderLab16FastPropertyNameENS_4lessIS2_EENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SA_EEiEESD_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = HEAP32[$__v>>2]|0;
  $4 = (($1) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($3|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($3|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($3|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($3|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE10Matrix4x4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$20 = $13;
  } else {
   $3 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $30 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(36)|0);
 $17 = (($16) + 16|0);
 ;HEAP32[$17+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$__v+16>>2]|0;
 HEAP32[$16>>2] = 0;
 $18 = (($16) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $16;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $16;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __Z5yylexv() {
 var $$0$i32 = 0, $$01$i = 0, $$2 = 0, $$c14 = 0, $$c15 = 0, $$c16 = 0, $$c17 = 0, $$depth$1 = 0, $$lcssa$i = 0, $$off = 0, $$pre = 0, $$pre147 = 0, $$pre148 = 0, $$pre148$pre = 0, $$pre151 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$062 = 0, $c2$1 = 0;
 var $cond = 0, $depth$0$ph = 0, $depth$161 = 0, $depth$2 = 0, $exitcond = 0, $i$0$ph = 0, $or$cond = 0, $p$0 = 0, $phitmp = 0, $temp = 0, $yy_act$0 = 0, $yy_bp$0$ph = 0, $yy_bp$1$ph = 0, $yy_c$0$ph$i = 0, $yy_c$0$ph$i41 = 0, $yy_c$0$ph$i51 = 0, $yy_c$0$ph$in = 0, $yy_cp$0 = 0, $yy_cp$0$ph = 0, $yy_cp$06$i = 0;
 var $yy_cp$06$i37 = 0, $yy_cp$06$i47 = 0, $yy_cp$1 = 0, $yy_cp$1$in = 0, $yy_cp$1$in$ph = 0, $yy_current_state$0 = 0, $yy_current_state$0$lcssa$i = 0, $yy_current_state$0$ph = 0, $yy_current_state$05$i = 0, $yy_current_state$05$i38 = 0, $yy_current_state$05$i48 = 0, $yy_current_state$1 = 0, $yy_current_state$1$i = 0, $yy_current_state$1$i43 = 0, $yy_current_state$1$i53 = 0, $yy_current_state$1$ph = 0, $yy_current_state$1$ph$i = 0, $yy_current_state$1$ph$i40 = 0, $yy_current_state$1$ph$i50 = 0, $yy_current_state$2 = 0;
 var $yy_current_state$2$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $temp = sp;
 $0 = HEAP32[654208>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  HEAP32[654208>>2] = 1;
  $2 = HEAP32[654216>>2]|0;
  $3 = ($2|0)==(0);
  if ($3) {
   HEAP32[654216>>2] = 1;
  }
  $4 = HEAP32[654176>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $6 = HEAP32[_stdin>>2]|0;
   HEAP32[654176>>2] = $6;
  }
  $7 = HEAP32[654184>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $9 = HEAP32[_stdout>>2]|0;
   HEAP32[654184>>2] = $9;
  }
  $10 = HEAP32[654224>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   label = 10;
  } else {
   $12 = HEAP32[$10>>2]|0;
   $phitmp = ($12|0)==(0|0);
   if ($phitmp) {
    label = 10;
   } else {
    $17 = $10;$18 = 0;$20 = $12;
   }
  }
  if ((label|0) == 10) {
   __ZL21yyensure_buffer_stackv();
   $13 = HEAP32[654176>>2]|0;
   $14 = (__Z16yy_create_bufferP8_IO_FILEi($13,16384)|0);
   $15 = HEAP32[654224>>2]|0;
   HEAP32[$15>>2] = $14;
   $$pre = HEAP32[654224>>2]|0;
   $$pre147 = HEAP32[$$pre>>2]|0;
   $17 = $$pre;$18 = 0;$20 = $$pre147;
  }
  $16 = (($17) + ($18<<2)|0);
  $19 = (($20) + 16|0);
  $21 = HEAP32[$19>>2]|0;
  HEAP32[673648>>2] = $21;
  $22 = (($20) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[654232>>2] = $23;
  HEAP32[654200>>2] = $23;
  $24 = HEAP32[$16>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  HEAP32[654176>>2] = $25;
  $26 = HEAP8[$23>>0]|0;
  HEAP8[654240>>0] = $26;
 }
 L18: while(1) {
  $27 = HEAP32[654232>>2]|0;
  $28 = HEAP8[654240>>0]|0;
  HEAP8[$27>>0] = $28;
  $29 = HEAP32[654216>>2]|0;
  $yy_bp$0$ph = $27;$yy_cp$0$ph = $27;$yy_current_state$0$ph = $29;
  L20: while(1) {
   $yy_cp$0 = $yy_cp$0$ph;$yy_current_state$0 = $yy_current_state$0$ph;
   while(1) {
    $30 = HEAP8[$yy_cp$0>>0]|0;
    $31 = $30&255;
    $32 = (654248 + ($31<<2)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (655272 + ($yy_current_state$0<<1)|0);
    $35 = HEAP16[$34>>1]|0;
    $36 = ($35<<16>>16)==(0);
    if ($36) {
     $yy_c$0$ph$in = $33;$yy_current_state$1$ph = $yy_current_state$0;
    } else {
     HEAP32[657544>>2] = $yy_current_state$0;
     HEAP32[657552>>2] = $yy_cp$0;
     $yy_c$0$ph$in = $33;$yy_current_state$1$ph = $yy_current_state$0;
    }
    L26: while(1) {
     $37 = $yy_c$0$ph$in & 255;
     $yy_current_state$1 = $yy_current_state$1$ph;
     while(1) {
      $38 = (657560 + ($yy_current_state$1<<1)|0);
      $39 = HEAP16[$38>>1]|0;
      $40 = $39 << 16 >> 16;
      $41 = (($40) + ($37))|0;
      $42 = (659848 + ($41<<1)|0);
      $43 = HEAP16[$42>>1]|0;
      $44 = $43 << 16 >> 16;
      $45 = ($44|0)==($yy_current_state$1|0);
      if ($45) {
       break L26;
      }
      $46 = (665408 + ($yy_current_state$1<<1)|0);
      $47 = HEAP16[$46>>1]|0;
      $48 = $47 << 16 >> 16;
      $49 = ($47<<16>>16)>(1133);
      if ($49) {
       break;
      } else {
       $yy_current_state$1 = $48;
      }
     }
     $50 = (667696 + ($37<<2)|0);
     $51 = HEAP32[$50>>2]|0;
     $yy_c$0$ph$in = $51;$yy_current_state$1$ph = $48;
    }
    $52 = (668016 + ($41<<1)|0);
    $53 = HEAP16[$52>>1]|0;
    $54 = ($53<<16>>16)==(1133);
    if ($54) {
     break;
    }
    $55 = (($yy_cp$0) + 1|0);
    $56 = $53 << 16 >> 16;
    $yy_cp$0 = $55;$yy_current_state$0 = $56;
   }
   $57 = HEAP32[657544>>2]|0;
   $yy_bp$1$ph = $yy_bp$0$ph;$yy_cp$1$in$ph = 657552;$yy_current_state$2$ph = $57;
   L35: while(1) {
    $yy_cp$1$in = $yy_cp$1$in$ph;$yy_current_state$2 = $yy_current_state$2$ph;
    L37: while(1) {
     $yy_cp$1 = HEAP32[$yy_cp$1$in>>2]|0;
     $58 = (655272 + ($yy_current_state$2<<1)|0);
     $59 = HEAP16[$58>>1]|0;
     $60 = $59 << 16 >> 16;
     HEAP32[654200>>2] = $yy_bp$1$ph;
     $61 = $yy_cp$1;
     $62 = HEAP8[$yy_cp$1>>0]|0;
     HEAP8[654240>>0] = $62;
     HEAP8[$yy_cp$1>>0] = 0;
     HEAP32[654232>>2] = $yy_cp$1;
     $454 = $yy_cp$1;$yy_act$0 = $60;
     L39: while(1) {
      switch ($yy_act$0|0) {
      case 63: case 2:  {
       $$2 = 292;
       break L18;
       break;
      }
      case 1:  {
       label = 350;
       break L18;
       break;
      }
      case 228: case 221: case 220:  {
       continue L18;
       break;
      }
      case 0:  {
       break L39;
       break;
      }
      case 3:  {
       label = 28;
       break L18;
       break;
      }
      case 4:  {
       label = 29;
       break L18;
       break;
      }
      case 7:  {
       label = 32;
       break L18;
       break;
      }
      case 8:  {
       label = 33;
       break L18;
       break;
      }
      case 9:  {
       label = 34;
       break L18;
       break;
      }
      case 10:  {
       label = 35;
       break L18;
       break;
      }
      case 11:  {
       label = 36;
       break L18;
       break;
      }
      case 12:  {
       label = 37;
       break L18;
       break;
      }
      case 5:  {
       label = 30;
       break L18;
       break;
      }
      case 13:  {
       label = 38;
       break L18;
       break;
      }
      case 14:  {
       label = 39;
       break L18;
       break;
      }
      case 15:  {
       label = 40;
       break L18;
       break;
      }
      case 6:  {
       label = 31;
       break L18;
       break;
      }
      case 16:  {
       label = 41;
       break L18;
       break;
      }
      case 27:  {
       label = 52;
       break L18;
       break;
      }
      case 26:  {
       label = 51;
       break L18;
       break;
      }
      case 34:  {
       label = 59;
       break L18;
       break;
      }
      case 29:  {
       label = 54;
       break L18;
       break;
      }
      case 30:  {
       label = 55;
       break L18;
       break;
      }
      case 28:  {
       label = 53;
       break L18;
       break;
      }
      case 18:  {
       label = 43;
       break L18;
       break;
      }
      case 22:  {
       label = 47;
       break L18;
       break;
      }
      case 23:  {
       label = 48;
       break L18;
       break;
      }
      case 19:  {
       label = 44;
       break L18;
       break;
      }
      case 21:  {
       label = 46;
       break L18;
       break;
      }
      case 25:  {
       label = 50;
       break L18;
       break;
      }
      case 31:  {
       label = 56;
       break L18;
       break;
      }
      case 17:  {
       label = 42;
       break L18;
       break;
      }
      case 20:  {
       label = 45;
       break L18;
       break;
      }
      case 32:  {
       label = 57;
       break L18;
       break;
      }
      case 24:  {
       label = 49;
       break L18;
       break;
      }
      case 35:  {
       label = 60;
       break L18;
       break;
      }
      case 33:  {
       label = 58;
       break L18;
       break;
      }
      case 36:  {
       label = 61;
       break L18;
       break;
      }
      case 49:  {
       label = 74;
       break L18;
       break;
      }
      case 51:  {
       label = 76;
       break L18;
       break;
      }
      case 52:  {
       label = 77;
       break L18;
       break;
      }
      case 37:  {
       label = 62;
       break L18;
       break;
      }
      case 54:  {
       label = 79;
       break L18;
       break;
      }
      case 38:  {
       label = 63;
       break L18;
       break;
      }
      case 40:  {
       label = 65;
       break L18;
       break;
      }
      case 41:  {
       label = 66;
       break L18;
       break;
      }
      case 47:  {
       label = 72;
       break L18;
       break;
      }
      case 43:  {
       label = 68;
       break L18;
       break;
      }
      case 45:  {
       label = 70;
       break L18;
       break;
      }
      case 44:  {
       label = 69;
       break L18;
       break;
      }
      case 42:  {
       label = 67;
       break L18;
       break;
      }
      case 53:  {
       label = 78;
       break L18;
       break;
      }
      case 50:  {
       label = 75;
       break L18;
       break;
      }
      case 55:  {
       label = 80;
       break L18;
       break;
      }
      case 56:  {
       label = 81;
       break L18;
       break;
      }
      case 57:  {
       label = 82;
       break L18;
       break;
      }
      case 39:  {
       label = 64;
       break L18;
       break;
      }
      case 46:  {
       label = 71;
       break L18;
       break;
      }
      case 48:  {
       label = 73;
       break L18;
       break;
      }
      case 60:  {
       label = 85;
       break L18;
       break;
      }
      case 64:  {
       label = 88;
       break L18;
       break;
      }
      case 79:  {
       label = 103;
       break L18;
       break;
      }
      case 61:  {
       label = 86;
       break L18;
       break;
      }
      case 72:  {
       label = 96;
       break L18;
       break;
      }
      case 62:  {
       label = 87;
       break L18;
       break;
      }
      case 58:  {
       label = 83;
       break L18;
       break;
      }
      case 59:  {
       label = 84;
       break L18;
       break;
      }
      case 68:  {
       label = 92;
       break L18;
       break;
      }
      case 69:  {
       label = 93;
       break L18;
       break;
      }
      case 70:  {
       label = 94;
       break L18;
       break;
      }
      case 71:  {
       label = 95;
       break L18;
       break;
      }
      case 65:  {
       label = 89;
       break L18;
       break;
      }
      case 67:  {
       label = 91;
       break L18;
       break;
      }
      case 73:  {
       label = 97;
       break L18;
       break;
      }
      case 75:  {
       label = 99;
       break L18;
       break;
      }
      case 76:  {
       label = 100;
       break L18;
       break;
      }
      case 77:  {
       label = 101;
       break L18;
       break;
      }
      case 78:  {
       label = 102;
       break L18;
       break;
      }
      case 80:  {
       label = 104;
       break L18;
       break;
      }
      case 66:  {
       label = 90;
       break L18;
       break;
      }
      case 74:  {
       label = 98;
       break L18;
       break;
      }
      case 83:  {
       label = 107;
       break L18;
       break;
      }
      case 86:  {
       label = 110;
       break L18;
       break;
      }
      case 87:  {
       label = 111;
       break L18;
       break;
      }
      case 90:  {
       label = 114;
       break L18;
       break;
      }
      case 94:  {
       label = 118;
       break L18;
       break;
      }
      case 97:  {
       label = 121;
       break L18;
       break;
      }
      case 100:  {
       label = 124;
       break L18;
       break;
      }
      case 95:  {
       label = 119;
       break L18;
       break;
      }
      case 101:  {
       label = 125;
       break L18;
       break;
      }
      case 85:  {
       label = 109;
       break L18;
       break;
      }
      case 89:  {
       label = 113;
       break L18;
       break;
      }
      case 84:  {
       label = 108;
       break L18;
       break;
      }
      case 91:  {
       label = 115;
       break L18;
       break;
      }
      case 92:  {
       label = 116;
       break L18;
       break;
      }
      case 99:  {
       label = 123;
       break L18;
       break;
      }
      case 82:  {
       label = 106;
       break L18;
       break;
      }
      case 81:  {
       label = 105;
       break L18;
       break;
      }
      case 88:  {
       label = 112;
       break L18;
       break;
      }
      case 93:  {
       label = 117;
       break L18;
       break;
      }
      case 98:  {
       label = 122;
       break L18;
       break;
      }
      case 96:  {
       label = 120;
       break L18;
       break;
      }
      case 116:  {
       label = 146;
       break L18;
       break;
      }
      case 106:  {
       label = 136;
       break L18;
       break;
      }
      case 117:  {
       label = 147;
       break L18;
       break;
      }
      case 102:  {
       label = 126;
       break L18;
       break;
      }
      case 104:  {
       label = 128;
       break L18;
       break;
      }
      case 107:  {
       label = 137;
       break L18;
       break;
      }
      case 103:  {
       label = 127;
       break L18;
       break;
      }
      case 105:  {
       label = 135;
       break L18;
       break;
      }
      case 108:  {
       label = 138;
       break L18;
       break;
      }
      case 109:  {
       label = 139;
       break L18;
       break;
      }
      case 111:  {
       label = 141;
       break L18;
       break;
      }
      case 113:  {
       label = 143;
       break L18;
       break;
      }
      case 110:  {
       label = 140;
       break L18;
       break;
      }
      case 112:  {
       label = 142;
       break L18;
       break;
      }
      case 114:  {
       label = 144;
       break L18;
       break;
      }
      case 115:  {
       label = 145;
       break L18;
       break;
      }
      case 120:  {
       label = 150;
       break L18;
       break;
      }
      case 118:  {
       label = 148;
       break L18;
       break;
      }
      case 128:  {
       label = 158;
       break L18;
       break;
      }
      case 119:  {
       label = 149;
       break L18;
       break;
      }
      case 122:  {
       label = 152;
       break L18;
       break;
      }
      case 132:  {
       label = 162;
       break L18;
       break;
      }
      case 126:  {
       label = 156;
       break L18;
       break;
      }
      case 133:  {
       label = 163;
       break L18;
       break;
      }
      case 121:  {
       label = 151;
       break L18;
       break;
      }
      case 124:  {
       label = 154;
       break L18;
       break;
      }
      case 130:  {
       label = 160;
       break L18;
       break;
      }
      case 134:  {
       label = 164;
       break L18;
       break;
      }
      case 123:  {
       label = 153;
       break L18;
       break;
      }
      case 125:  {
       label = 155;
       break L18;
       break;
      }
      case 127:  {
       label = 157;
       break L18;
       break;
      }
      case 135:  {
       label = 165;
       break L18;
       break;
      }
      case 137:  {
       label = 167;
       break L18;
       break;
      }
      case 138:  {
       label = 168;
       break L18;
       break;
      }
      case 131:  {
       label = 161;
       break L18;
       break;
      }
      case 136:  {
       label = 166;
       break L18;
       break;
      }
      case 129:  {
       label = 159;
       break L18;
       break;
      }
      case 139:  {
       label = 169;
       break L18;
       break;
      }
      case 141:  {
       label = 171;
       break L18;
       break;
      }
      case 142:  {
       label = 172;
       break L18;
       break;
      }
      case 144:  {
       label = 174;
       break L18;
       break;
      }
      case 146:  {
       label = 176;
       break L18;
       break;
      }
      case 155:  {
       label = 185;
       break L18;
       break;
      }
      case 147:  {
       label = 177;
       break L18;
       break;
      }
      case 154:  {
       label = 184;
       break L18;
       break;
      }
      case 153:  {
       label = 183;
       break L18;
       break;
      }
      case 152:  {
       label = 182;
       break L18;
       break;
      }
      case 156:  {
       label = 186;
       break L18;
       break;
      }
      case 157:  {
       label = 187;
       break L18;
       break;
      }
      case 145:  {
       label = 175;
       break L18;
       break;
      }
      case 148:  {
       label = 178;
       break L18;
       break;
      }
      case 149:  {
       label = 179;
       break L18;
       break;
      }
      case 143:  {
       label = 173;
       break L18;
       break;
      }
      case 150:  {
       label = 180;
       break L18;
       break;
      }
      case 151:  {
       label = 181;
       break L18;
       break;
      }
      case 140:  {
       label = 170;
       break L18;
       break;
      }
      case 164:  {
       label = 194;
       break L18;
       break;
      }
      case 165:  {
       label = 195;
       break L18;
       break;
      }
      case 166:  {
       label = 196;
       break L18;
       break;
      }
      case 168:  {
       label = 198;
       break L18;
       break;
      }
      case 162:  {
       label = 192;
       break L18;
       break;
      }
      case 170:  {
       label = 200;
       break L18;
       break;
      }
      case 171:  {
       label = 201;
       break L18;
       break;
      }
      case 158:  {
       label = 188;
       break L18;
       break;
      }
      case 172:  {
       label = 202;
       break L18;
       break;
      }
      case 159:  {
       label = 189;
       break L18;
       break;
      }
      case 163:  {
       label = 193;
       break L18;
       break;
      }
      case 173:  {
       label = 203;
       break L18;
       break;
      }
      case 160:  {
       label = 190;
       break L18;
       break;
      }
      case 161:  {
       label = 191;
       break L18;
       break;
      }
      case 167:  {
       label = 197;
       break L18;
       break;
      }
      case 169:  {
       label = 199;
       break L18;
       break;
      }
      case 174:  {
       label = 204;
       break L18;
       break;
      }
      case 175:  {
       label = 205;
       break L18;
       break;
      }
      case 181:  {
       label = 211;
       break L18;
       break;
      }
      case 179:  {
       label = 209;
       break L18;
       break;
      }
      case 184:  {
       label = 214;
       break L18;
       break;
      }
      case 185:  {
       label = 215;
       break L18;
       break;
      }
      case 187:  {
       label = 217;
       break L18;
       break;
      }
      case 189:  {
       label = 219;
       break L18;
       break;
      }
      case 192:  {
       label = 222;
       break L18;
       break;
      }
      case 188:  {
       label = 218;
       break L18;
       break;
      }
      case 193:  {
       label = 223;
       break L18;
       break;
      }
      case 194:  {
       label = 224;
       break L18;
       break;
      }
      case 178:  {
       label = 208;
       break L18;
       break;
      }
      case 176:  {
       label = 206;
       break L18;
       break;
      }
      case 183:  {
       label = 213;
       break L18;
       break;
      }
      case 186:  {
       label = 216;
       break L18;
       break;
      }
      case 180:  {
       label = 210;
       break L18;
       break;
      }
      case 182:  {
       label = 212;
       break L18;
       break;
      }
      case 177:  {
       label = 207;
       break L18;
       break;
      }
      case 190:  {
       label = 220;
       break L18;
       break;
      }
      case 191:  {
       label = 221;
       break L18;
       break;
      }
      case 206:  {
       label = 236;
       break L18;
       break;
      }
      case 207:  {
       label = 237;
       break L18;
       break;
      }
      case 208:  {
       label = 238;
       break L18;
       break;
      }
      case 209:  {
       label = 239;
       break L18;
       break;
      }
      case 196:  {
       label = 226;
       break L18;
       break;
      }
      case 210:  {
       label = 240;
       break L18;
       break;
      }
      case 211:  {
       label = 241;
       break L18;
       break;
      }
      case 213:  {
       label = 243;
       break L18;
       break;
      }
      case 214:  {
       label = 244;
       break L18;
       break;
      }
      case 198:  {
       label = 228;
       break L18;
       break;
      }
      case 212:  {
       label = 242;
       break L18;
       break;
      }
      case 204:  {
       label = 234;
       break L18;
       break;
      }
      case 200:  {
       label = 230;
       break L18;
       break;
      }
      case 215:  {
       label = 245;
       break L20;
       break;
      }
      case 195:  {
       label = 225;
       break L18;
       break;
      }
      case 197:  {
       label = 227;
       break L18;
       break;
      }
      case 201:  {
       label = 231;
       break L18;
       break;
      }
      case 202:  {
       label = 232;
       break L18;
       break;
      }
      case 199:  {
       label = 229;
       break L18;
       break;
      }
      case 203:  {
       label = 233;
       break L18;
       break;
      }
      case 205:  {
       label = 235;
       break L18;
       break;
      }
      case 219:  {
       label = 262;
       break L18;
       break;
      }
      case 222:  {
       label = 266;
       break L20;
       break;
      }
      case 223:  {
       label = 267;
       break L20;
       break;
      }
      case 217:  {
       label = 260;
       break L20;
       break;
      }
      case 216:  {
       label = 259;
       break L20;
       break;
      }
      case 218:  {
       label = 261;
       break L18;
       break;
      }
      case 226:  {
       $depth$0$ph = 1;
       label = 270;
       break L20;
       break;
      }
      case 224:  {
       label = 268;
       break L20;
       break;
      }
      case 225:  {
       label = 269;
       break L20;
       break;
      }
      case 227:  {
       label = 305;
       break L18;
       break;
      }
      case 238: case 237: case 236: case 235: case 234: case 233: case 232: case 231: case 230:  {
       label = 306;
       break L18;
       break;
      }
      case 229:  {
       break;
      }
      default: {
       label = 349;
       break L18;
      }
      }
      $295 = HEAP32[654200>>2]|0;
      $296 = $295;
      $297 = (($61) - ($296))|0;
      $298 = (($297) + -1)|0;
      $299 = HEAP8[654240>>0]|0;
      HEAP8[$yy_cp$1>>0] = $299;
      $300 = HEAP32[654224>>2]|0;
      $301 = HEAP32[$300>>2]|0;
      $302 = (($301) + 44|0);
      $303 = HEAP32[$302>>2]|0;
      $304 = ($303|0)==(0);
      if ($304) {
       $305 = (($301) + 16|0);
       $306 = HEAP32[$305>>2]|0;
       HEAP32[673648>>2] = $306;
       $307 = HEAP32[654176>>2]|0;
       HEAP32[$301>>2] = $307;
       $308 = HEAP32[654224>>2]|0;
       $309 = HEAP32[$308>>2]|0;
       $310 = (($309) + 44|0);
       HEAP32[$310>>2] = 1;
       $$pre151 = HEAP32[$308>>2]|0;
       $314 = $$pre151;
      } else {
       $314 = $301;
      }
      $311 = HEAP32[654232>>2]|0;
      $312 = HEAP32[673648>>2]|0;
      $313 = (($314) + 4|0);
      $315 = HEAP32[$313>>2]|0;
      $316 = (($315) + ($312)|0);
      $317 = ($311>>>0)>($316>>>0);
      if (!($317)) {
       break L37;
      }
      $380 = (__ZL18yy_get_next_bufferv()|0);
      if ((($380|0) == 0)) {
       break L35;
      } else if ((($380|0) == 2)) {
       label = 339;
       break L37;
      } else if (!((($380|0) == 1))) {
       continue L18;
      }
      $381 = HEAP32[654200>>2]|0;
      HEAP32[654232>>2] = $381;
      $382 = HEAP32[654216>>2]|0;
      $383 = (($382) + -1)|0;
      $384 = (($383|0) / 2)&-1;
      $385 = (($384) + 230)|0;
      $454 = $381;$yy_act$0 = $385;
     }
     $63 = HEAP8[654240>>0]|0;
     HEAP8[$yy_cp$1>>0] = $63;
     $64 = HEAP32[657544>>2]|0;
     $yy_cp$1$in = 657552;$yy_current_state$2 = $64;
    }
    if ((label|0) == 339) {
     label = 0;
     $418 = HEAP32[673648>>2]|0;
     $419 = HEAP32[654224>>2]|0;
     $420 = HEAP32[$419>>2]|0;
     $421 = (($420) + 4|0);
     $422 = HEAP32[$421>>2]|0;
     $423 = (($422) + ($418)|0);
     HEAP32[654232>>2] = $423;
     $424 = HEAP32[654216>>2]|0;
     $425 = HEAP32[654200>>2]|0;
     $426 = ($425>>>0)<($423>>>0);
     if ($426) {
      $yy_cp$06$i47 = $425;$yy_current_state$05$i48 = $424;
     } else {
      $yy_bp$1$ph = $425;$yy_cp$1$in$ph = 654232;$yy_current_state$2$ph = $424;
      continue;
     }
     while(1) {
      $427 = HEAP8[$yy_cp$06$i47>>0]|0;
      $428 = ($427<<24>>24)==(0);
      if ($428) {
       $462 = 1;
      } else {
       $429 = $427&255;
       $430 = (654248 + ($429<<2)|0);
       $431 = HEAP32[$430>>2]|0;
       $462 = $431;
      }
      $432 = (655272 + ($yy_current_state$05$i48<<1)|0);
      $433 = HEAP16[$432>>1]|0;
      $434 = ($433<<16>>16)==(0);
      if ($434) {
       $yy_c$0$ph$i51 = $462;$yy_current_state$1$ph$i50 = $yy_current_state$05$i48;
      } else {
       HEAP32[657544>>2] = $yy_current_state$05$i48;
       HEAP32[657552>>2] = $yy_cp$06$i47;
       $yy_c$0$ph$i51 = $462;$yy_current_state$1$ph$i50 = $yy_current_state$05$i48;
      }
      L57: while(1) {
       $435 = $yy_c$0$ph$i51 & 255;
       $yy_current_state$1$i53 = $yy_current_state$1$ph$i50;
       while(1) {
        $436 = (657560 + ($yy_current_state$1$i53<<1)|0);
        $437 = HEAP16[$436>>1]|0;
        $438 = $437 << 16 >> 16;
        $439 = (($438) + ($435))|0;
        $440 = (659848 + ($439<<1)|0);
        $441 = HEAP16[$440>>1]|0;
        $442 = $441 << 16 >> 16;
        $443 = ($442|0)==($yy_current_state$1$i53|0);
        if ($443) {
         break L57;
        }
        $444 = (665408 + ($yy_current_state$1$i53<<1)|0);
        $445 = HEAP16[$444>>1]|0;
        $446 = $445 << 16 >> 16;
        $447 = ($445<<16>>16)>(1133);
        if ($447) {
         break;
        } else {
         $yy_current_state$1$i53 = $446;
        }
       }
       $448 = (667696 + ($435<<2)|0);
       $449 = HEAP32[$448>>2]|0;
       $yy_c$0$ph$i51 = $449;$yy_current_state$1$ph$i50 = $446;
      }
      $450 = (668016 + ($439<<1)|0);
      $451 = HEAP16[$450>>1]|0;
      $452 = $451 << 16 >> 16;
      $453 = (($yy_cp$06$i47) + 1|0);
      $exitcond = ($453|0)==($423|0);
      if ($exitcond) {
       $yy_bp$1$ph = $425;$yy_cp$1$in$ph = 654232;$yy_current_state$2$ph = $452;
       continue L35;
      } else {
       $yy_cp$06$i47 = $453;$yy_current_state$05$i48 = $452;
      }
     }
    }
    $318 = HEAP32[654200>>2]|0;
    $319 = (($318) + ($298)|0);
    HEAP32[654232>>2] = $319;
    $320 = HEAP32[654216>>2]|0;
    $321 = ($298|0)>(0);
    if ($321) {
     $yy_cp$06$i = $318;$yy_current_state$05$i = $320;
     while(1) {
      $322 = HEAP8[$yy_cp$06$i>>0]|0;
      $323 = ($322<<24>>24)==(0);
      if ($323) {
       $460 = 1;
      } else {
       $324 = $322&255;
       $325 = (654248 + ($324<<2)|0);
       $326 = HEAP32[$325>>2]|0;
       $460 = $326;
      }
      $327 = (655272 + ($yy_current_state$05$i<<1)|0);
      $328 = HEAP16[$327>>1]|0;
      $329 = ($328<<16>>16)==(0);
      if ($329) {
       $yy_c$0$ph$i = $460;$yy_current_state$1$ph$i = $yy_current_state$05$i;
      } else {
       HEAP32[657544>>2] = $yy_current_state$05$i;
       HEAP32[657552>>2] = $yy_cp$06$i;
       $yy_c$0$ph$i = $460;$yy_current_state$1$ph$i = $yy_current_state$05$i;
      }
      L73: while(1) {
       $330 = $yy_c$0$ph$i & 255;
       $yy_current_state$1$i = $yy_current_state$1$ph$i;
       while(1) {
        $331 = (657560 + ($yy_current_state$1$i<<1)|0);
        $332 = HEAP16[$331>>1]|0;
        $333 = $332 << 16 >> 16;
        $334 = (($333) + ($330))|0;
        $335 = (659848 + ($334<<1)|0);
        $336 = HEAP16[$335>>1]|0;
        $337 = $336 << 16 >> 16;
        $338 = ($337|0)==($yy_current_state$1$i|0);
        if ($338) {
         break L73;
        }
        $339 = (665408 + ($yy_current_state$1$i<<1)|0);
        $340 = HEAP16[$339>>1]|0;
        $341 = $340 << 16 >> 16;
        $342 = ($340<<16>>16)>(1133);
        if ($342) {
         break;
        } else {
         $yy_current_state$1$i = $341;
        }
       }
       $343 = (667696 + ($330<<2)|0);
       $344 = HEAP32[$343>>2]|0;
       $yy_c$0$ph$i = $344;$yy_current_state$1$ph$i = $341;
      }
      $345 = (668016 + ($334<<1)|0);
      $346 = HEAP16[$345>>1]|0;
      $347 = $346 << 16 >> 16;
      $348 = (($yy_cp$06$i) + 1|0);
      $349 = ($348>>>0)<($319>>>0);
      if ($349) {
       $yy_cp$06$i = $348;$yy_current_state$05$i = $347;
      } else {
       $yy_current_state$0$lcssa$i = $347;
       break;
      }
     }
    } else {
     $yy_current_state$0$lcssa$i = $320;
    }
    $350 = (655272 + ($yy_current_state$0$lcssa$i<<1)|0);
    $351 = HEAP16[$350>>1]|0;
    $352 = ($351<<16>>16)==(0);
    if (!($352)) {
     HEAP32[657544>>2] = $yy_current_state$0$lcssa$i;
     HEAP32[657552>>2] = $319;
    }
    $353 = (657560 + ($yy_current_state$0$lcssa$i<<1)|0);
    $354 = HEAP16[$353>>1]|0;
    $355 = $354 << 16 >> 16;
    $356 = (($355) + 1)|0;
    $357 = (659848 + ($356<<1)|0);
    $358 = HEAP16[$357>>1]|0;
    $359 = $358 << 16 >> 16;
    $360 = ($359|0)==($yy_current_state$0$lcssa$i|0);
    if ($360) {
     $$lcssa$i = $355;
    } else {
     $$01$i = $yy_current_state$0$lcssa$i;
     while(1) {
      $361 = (665408 + ($$01$i<<1)|0);
      $362 = HEAP16[$361>>1]|0;
      $363 = $362 << 16 >> 16;
      $364 = (657560 + ($363<<1)|0);
      $365 = HEAP16[$364>>1]|0;
      $366 = $365 << 16 >> 16;
      $367 = (($366) + 1)|0;
      $368 = (659848 + ($367<<1)|0);
      $369 = HEAP16[$368>>1]|0;
      $370 = ($369<<16>>16)==($362<<16>>16);
      if ($370) {
       $$lcssa$i = $366;
       break;
      } else {
       $$01$i = $363;
      }
     }
    }
    $371 = (($$lcssa$i) + 1)|0;
    $372 = (668016 + ($371<<1)|0);
    $373 = HEAP16[$372>>1]|0;
    $374 = $373 << 16 >> 16;
    $375 = ($373<<16>>16)==(1133);
    $376 = $375 ? 0 : $374;
    $377 = ($376|0)==(0);
    if (!($377)) {
     label = 325;
     break;
    }
    $379 = HEAP32[657544>>2]|0;
    $yy_bp$1$ph = $318;$yy_cp$1$in$ph = 657552;$yy_current_state$2$ph = $379;
   }
   if ((label|0) == 325) {
    label = 0;
    $378 = (($318) + ($297)|0);
    HEAP32[654232>>2] = $378;
    $yy_bp$0$ph = $318;$yy_cp$0$ph = $378;$yy_current_state$0$ph = $376;
    continue;
   }
   $386 = HEAP32[654200>>2]|0;
   $387 = (($386) + ($298)|0);
   HEAP32[654232>>2] = $387;
   $388 = HEAP32[654216>>2]|0;
   $389 = ($298|0)>(0);
   if ($389) {
    $yy_cp$06$i37 = $386;$yy_current_state$05$i38 = $388;
   } else {
    $yy_bp$0$ph = $386;$yy_cp$0$ph = $387;$yy_current_state$0$ph = $388;
    continue;
   }
   while(1) {
    $390 = HEAP8[$yy_cp$06$i37>>0]|0;
    $391 = ($390<<24>>24)==(0);
    if ($391) {
     $461 = 1;
    } else {
     $392 = $390&255;
     $393 = (654248 + ($392<<2)|0);
     $394 = HEAP32[$393>>2]|0;
     $461 = $394;
    }
    $395 = (655272 + ($yy_current_state$05$i38<<1)|0);
    $396 = HEAP16[$395>>1]|0;
    $397 = ($396<<16>>16)==(0);
    if ($397) {
     $yy_c$0$ph$i41 = $461;$yy_current_state$1$ph$i40 = $yy_current_state$05$i38;
    } else {
     HEAP32[657544>>2] = $yy_current_state$05$i38;
     HEAP32[657552>>2] = $yy_cp$06$i37;
     $yy_c$0$ph$i41 = $461;$yy_current_state$1$ph$i40 = $yy_current_state$05$i38;
    }
    L99: while(1) {
     $398 = $yy_c$0$ph$i41 & 255;
     $yy_current_state$1$i43 = $yy_current_state$1$ph$i40;
     while(1) {
      $399 = (657560 + ($yy_current_state$1$i43<<1)|0);
      $400 = HEAP16[$399>>1]|0;
      $401 = $400 << 16 >> 16;
      $402 = (($401) + ($398))|0;
      $403 = (659848 + ($402<<1)|0);
      $404 = HEAP16[$403>>1]|0;
      $405 = $404 << 16 >> 16;
      $406 = ($405|0)==($yy_current_state$1$i43|0);
      if ($406) {
       break L99;
      }
      $407 = (665408 + ($yy_current_state$1$i43<<1)|0);
      $408 = HEAP16[$407>>1]|0;
      $409 = $408 << 16 >> 16;
      $410 = ($408<<16>>16)>(1133);
      if ($410) {
       break;
      } else {
       $yy_current_state$1$i43 = $409;
      }
     }
     $411 = (667696 + ($398<<2)|0);
     $412 = HEAP32[$411>>2]|0;
     $yy_c$0$ph$i41 = $412;$yy_current_state$1$ph$i40 = $409;
    }
    $413 = (668016 + ($402<<1)|0);
    $414 = HEAP16[$413>>1]|0;
    $415 = $414 << 16 >> 16;
    $416 = (($yy_cp$06$i37) + 1|0);
    $417 = ($416>>>0)<($387>>>0);
    if ($417) {
     $yy_cp$06$i37 = $416;$yy_current_state$05$i38 = $415;
    } else {
     $yy_bp$0$ph = $386;$yy_cp$0$ph = $387;$yy_current_state$0$ph = $415;
     continue L20;
    }
   }
  }
  if ((label|0) == 245) {
   label = 0;
   $$pre148$pre = HEAP8[654240>>0]|0;
   $$pre148 = $$pre148$pre;$459 = $454;$i$0$ph = 0;
   L108: while(1) {
    $110 = $$pre148;$111 = $459;
    while(1) {
     HEAP8[$111>>0] = $110;
     $112 = HEAP32[654232>>2]|0;
     $113 = HEAP8[$112>>0]|0;
     $114 = ($113<<24>>24)==(0);
     do {
      if ($114) {
       $115 = HEAP32[673648>>2]|0;
       $116 = HEAP32[654224>>2]|0;
       $117 = HEAP32[$116>>2]|0;
       $118 = (($117) + 4|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = (($119) + ($115)|0);
       $121 = ($112>>>0)<($120>>>0);
       if ($121) {
        HEAP8[$112>>0] = 0;
        break;
       }
       $122 = HEAP32[654200>>2]|0;
       $123 = (($112) + 1|0);
       HEAP32[654232>>2] = $123;
       $124 = (__ZL18yy_get_next_bufferv()|0);
       if ((($124|0) == 2)) {
        label = 251;
        break L108;
       } else if ((($124|0) == 1)) {
        break L108;
       } else if (!((($124|0) == 0))) {
        break;
       }
       $126 = $122;
       $127 = $112;
       $128 = (($127) - ($126))|0;
       $129 = HEAP32[654200>>2]|0;
       $130 = (($129) + ($128)|0);
       HEAP32[654232>>2] = $130;
      }
     } while(0);
     $131 = HEAP32[654232>>2]|0;
     $132 = HEAP8[$131>>0]|0;
     $133 = $132&255;
     HEAP8[$131>>0] = 0;
     $134 = HEAP32[654232>>2]|0;
     $135 = (($134) + 1|0);
     HEAP32[654232>>2] = $135;
     $136 = HEAP8[$135>>0]|0;
     HEAP8[654240>>0] = $136;
     if ((($133|0) == 9) | (($133|0) == 32)) {
      $110 = $136;$111 = $135;
     } else {
      break;
     }
    }
    $$off = (($133) + -48)|0;
    $137 = ($$off>>>0)>(9);
    $138 = ($i$0$ph|0)>(254);
    $or$cond = $137 | $138;
    if ($or$cond) {
     break;
    }
    $cond = ($132<<24>>24)==(0);
    if ($cond) {
     label = 256;
     break L18;
    }
    $139 = (($i$0$ph) + 1)|0;
    $140 = (($temp) + ($i$0$ph)|0);
    HEAP8[$140>>0] = $132;
    $$pre148 = $136;$459 = $135;$i$0$ph = $139;
   }
   if ((label|0) == 251) {
    label = 0;
    $125 = HEAP32[654176>>2]|0;
    __Z9yyrestartP8_IO_FILE($125);
   }
   $141 = (($temp) + ($i$0$ph)|0);
   HEAP8[$141>>0] = 0;
   $142 = (_atoi($temp)|0);
   HEAP32[654192>>2] = $142;
   continue;
  }
  else if ((label|0) == 259) {
   label = 0;
   $143 = (__ZL18ScanErrorOrWarningb(1)|0);
   if ($143) {
    continue;
   } else {
    $$2 = 0;
    break;
   }
  }
  else if ((label|0) == 260) {
   label = 0;
   $144 = (__ZL18ScanErrorOrWarningb(0)|0);
   if ($144) {
    continue;
   } else {
    $$2 = 0;
    break;
   }
  }
  else if ((label|0) == 266) {
   label = 0;
   $168 = HEAP32[654192>>2]|0;
   $169 = (($168) + 1)|0;
   HEAP32[654192>>2] = $169;
   continue;
  }
  else if ((label|0) == 267) {
   label = 0;
   $170 = HEAP32[654192>>2]|0;
   $171 = (($170) + 1)|0;
   HEAP32[654192>>2] = $171;
   continue;
  }
  else if ((label|0) == 268) {
   label = 0;
   $172 = HEAP32[654192>>2]|0;
   $173 = (($172) + 1)|0;
   HEAP32[654192>>2] = $173;
   continue;
  }
  else if ((label|0) == 269) {
   label = 0;
   $174 = HEAP32[654192>>2]|0;
   $175 = (($174) + 1)|0;
   HEAP32[654192>>2] = $175;
   continue;
  }
  else if ((label|0) == 270) {
   while(1) {
    label = 0;
    L131: while(1) {
     $176 = HEAP8[654240>>0]|0;
     $177 = HEAP32[654232>>2]|0;
     HEAP8[$177>>0] = $176;
     $178 = HEAP32[654232>>2]|0;
     $179 = HEAP8[$178>>0]|0;
     $180 = ($179<<24>>24)==(0);
     do {
      if ($180) {
       $181 = HEAP32[673648>>2]|0;
       $182 = HEAP32[654224>>2]|0;
       $183 = HEAP32[$182>>2]|0;
       $184 = (($183) + 4|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = (($185) + ($181)|0);
       $187 = ($178>>>0)<($186>>>0);
       if ($187) {
        HEAP8[$178>>0] = 0;
        break;
       }
       $188 = HEAP32[654200>>2]|0;
       $189 = (($178) + 1|0);
       HEAP32[654232>>2] = $189;
       $190 = (__ZL18yy_get_next_bufferv()|0);
       if ((($190|0) == 2)) {
        label = 275;
        break L18;
       } else if ((($190|0) == 1)) {
        label = 304;
        break L18;
       } else if (!((($190|0) == 0))) {
        break;
       }
       $192 = $188;
       $193 = $178;
       $194 = (($193) - ($192))|0;
       $195 = HEAP32[654200>>2]|0;
       $196 = (($195) + ($194)|0);
       HEAP32[654232>>2] = $196;
      }
     } while(0);
     $197 = HEAP32[654232>>2]|0;
     $198 = HEAP8[$197>>0]|0;
     $199 = $198&255;
     HEAP8[$197>>0] = 0;
     $200 = HEAP32[654232>>2]|0;
     $201 = (($200) + 1|0);
     HEAP32[654232>>2] = $201;
     $202 = HEAP8[$201>>0]|0;
     HEAP8[654240>>0] = $202;
     switch ($199|0) {
     case 10:  {
      $232 = HEAP32[654192>>2]|0;
      $233 = (($232) + 1)|0;
      HEAP32[654192>>2] = $233;
      continue L131;
      break;
     }
     case 42:  {
      $234 = $202;$235 = $201;
      label = 287;
      break L131;
      break;
     }
     case 13:  {
      break;
     }
     case 0:  {
      label = 304;
      break L18;
      break;
     }
     case 47:  {
      $263 = $202;$264 = $201;$depth$161 = $depth$0$ph;
      label = 295;
      break L131;
      break;
     }
     default: {
      continue L131;
     }
     }
     $203 = HEAP32[654192>>2]|0;
     $204 = (($203) + 1)|0;
     HEAP32[654192>>2] = $204;
     HEAP8[$201>>0] = $202;
     $205 = HEAP32[654232>>2]|0;
     $206 = HEAP8[$205>>0]|0;
     $207 = ($206<<24>>24)==(0);
     do {
      if ($207) {
       $208 = HEAP32[673648>>2]|0;
       $209 = HEAP32[654224>>2]|0;
       $210 = HEAP32[$209>>2]|0;
       $211 = (($210) + 4|0);
       $212 = HEAP32[$211>>2]|0;
       $213 = (($212) + ($208)|0);
       $214 = ($205>>>0)<($213>>>0);
       if ($214) {
        HEAP8[$205>>0] = 0;
        break;
       }
       $215 = HEAP32[654200>>2]|0;
       $216 = (($205) + 1|0);
       HEAP32[654232>>2] = $216;
       $217 = (__ZL18yy_get_next_bufferv()|0);
       if ((($217|0) == 0)) {
        $219 = $215;
        $220 = $205;
        $221 = (($220) - ($219))|0;
        $222 = HEAP32[654200>>2]|0;
        $223 = (($222) + ($221)|0);
        HEAP32[654232>>2] = $223;
        break;
       } else if ((($217|0) == 2)) {
        $218 = HEAP32[654176>>2]|0;
        __Z9yyrestartP8_IO_FILE($218);
        continue L131;
       } else if ((($217|0) == 1)) {
        continue L131;
       } else {
        break;
       }
      }
     } while(0);
     $224 = HEAP32[654232>>2]|0;
     $225 = HEAP8[$224>>0]|0;
     HEAP8[$224>>0] = 0;
     $226 = HEAP32[654232>>2]|0;
     $227 = (($226) + 1|0);
     HEAP32[654232>>2] = $227;
     $228 = HEAP8[$227>>0]|0;
     HEAP8[654240>>0] = $228;
     $229 = ($225<<24>>24)==(13);
     if (!($229)) {
      continue;
     }
     $230 = HEAP32[654192>>2]|0;
     $231 = (($230) + 1)|0;
     HEAP32[654192>>2] = $231;
    }
    L153: do {
     if ((label|0) == 287) {
      while(1) {
       label = 0;
       HEAP8[$235>>0] = $234;
       $236 = HEAP32[654232>>2]|0;
       $237 = HEAP8[$236>>0]|0;
       $238 = ($237<<24>>24)==(0);
       do {
        if ($238) {
         $239 = HEAP32[673648>>2]|0;
         $240 = HEAP32[654224>>2]|0;
         $241 = HEAP32[$240>>2]|0;
         $242 = (($241) + 4|0);
         $243 = HEAP32[$242>>2]|0;
         $244 = (($243) + ($239)|0);
         $245 = ($236>>>0)<($244>>>0);
         if ($245) {
          HEAP8[$236>>0] = 0;
          break;
         }
         $246 = HEAP32[654200>>2]|0;
         $247 = (($236) + 1|0);
         HEAP32[654232>>2] = $247;
         $248 = (__ZL18yy_get_next_bufferv()|0);
         if ((($248|0) == 1)) {
          label = 304;
          break L18;
         } else if ((($248|0) == 2)) {
          label = 291;
          break L18;
         } else if (!((($248|0) == 0))) {
          break;
         }
         $250 = $246;
         $251 = $236;
         $252 = (($251) - ($250))|0;
         $253 = HEAP32[654200>>2]|0;
         $254 = (($253) + ($252)|0);
         HEAP32[654232>>2] = $254;
        }
       } while(0);
       $255 = HEAP32[654232>>2]|0;
       $256 = HEAP8[$255>>0]|0;
       $257 = $256&255;
       HEAP8[$255>>0] = 0;
       $258 = HEAP32[654232>>2]|0;
       $259 = (($258) + 1|0);
       HEAP32[654232>>2] = $259;
       $260 = HEAP8[$259>>0]|0;
       HEAP8[654240>>0] = $260;
       if ((($257|0) == 42)) {
        $234 = $260;$235 = $259;
        label = 287;
       } else if ((($257|0) == 47)) {
        break;
       } else {
        $c2$1 = $257;$depth$2 = $depth$0$ph;
        break L153;
       }
      }
      $261 = (($depth$0$ph) + -1)|0;
      $262 = ($261|0)==(0);
      if ($262) {
       continue L18;
      } else {
       $263 = $260;$264 = $259;$depth$161 = $261;
       label = 295;
      }
     }
    } while(0);
    if ((label|0) == 295) {
     label = 0;
     HEAP8[$264>>0] = $263;
     $265 = HEAP32[654232>>2]|0;
     $266 = HEAP8[$265>>0]|0;
     $267 = ($266<<24>>24)==(0);
     do {
      if ($267) {
       $268 = HEAP32[673648>>2]|0;
       $269 = HEAP32[654224>>2]|0;
       $270 = HEAP32[$269>>2]|0;
       $271 = (($270) + 4|0);
       $272 = HEAP32[$271>>2]|0;
       $273 = (($272) + ($268)|0);
       $274 = ($265>>>0)<($273>>>0);
       if ($274) {
        HEAP8[$265>>0] = 0;
        label = 301;
        break;
       }
       $275 = HEAP32[654200>>2]|0;
       $276 = (($265) + 1|0);
       HEAP32[654232>>2] = $276;
       $277 = (__ZL18yy_get_next_bufferv()|0);
       if ((($277|0) == 2)) {
        $278 = HEAP32[654176>>2]|0;
        __Z9yyrestartP8_IO_FILE($278);
        $$0$i32 = 0;
        break;
       } else if ((($277|0) == 1)) {
        $$0$i32 = 0;
        break;
       } else if ((($277|0) == 0)) {
        $279 = $275;
        $280 = $265;
        $281 = (($280) - ($279))|0;
        $282 = HEAP32[654200>>2]|0;
        $283 = (($282) + ($281)|0);
        HEAP32[654232>>2] = $283;
        label = 301;
        break;
       } else {
        label = 301;
        break;
       }
      } else {
       label = 301;
      }
     } while(0);
     if ((label|0) == 301) {
      label = 0;
      $284 = HEAP32[654232>>2]|0;
      $285 = HEAP8[$284>>0]|0;
      $286 = $285&255;
      HEAP8[$284>>0] = 0;
      $287 = HEAP32[654232>>2]|0;
      $288 = (($287) + 1|0);
      HEAP32[654232>>2] = $288;
      $289 = HEAP8[$288>>0]|0;
      HEAP8[654240>>0] = $289;
      $$0$i32 = $286;
     }
     $290 = ($$0$i32|0)==(42);
     $291 = $290&1;
     $$depth$1 = (($291) + ($depth$161))|0;
     $c2$1 = $$0$i32;$depth$2 = $$depth$1;
    }
    if ((($c2$1|0) == 0) | (($c2$1|0) == -1)) {
     label = 304;
     break L18;
    } else {
     $depth$0$ph = $depth$2;
     label = 270;
    }
   }
  }
 }
 L180:  switch (label|0) {
  case 28: {
   $$2 = 299;
   break;
  }
  case 29: {
   HEAP32[654216>>2] = 13;
   $$2 = 299;
   break;
  }
  case 30: {
   $$2 = 298;
   break;
  }
  case 31: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = 0;
   $$2 = 354;
   break;
  }
  case 32: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (1);
   $$2 = 354;
   break;
  }
  case 33: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (1);
   $$2 = 354;
   break;
  }
  case 34: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (2);
   $$2 = 354;
   break;
  }
  case 35: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (3);
   $$2 = 354;
   break;
  }
  case 36: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (4);
   $$2 = 354;
   break;
  }
  case 37: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (5);
   $$2 = 354;
   break;
  }
  case 38: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (6);
   $$2 = 354;
   break;
  }
  case 39: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (7);
   $$2 = 354;
   break;
  }
  case 40: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (8);
   $$2 = 354;
   break;
  }
  case 41: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (9);
   $$2 = 354;
   break;
  }
  case 42: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (10);
   $$2 = 354;
   break;
  }
  case 43: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (11);
   $$2 = 354;
   break;
  }
  case 44: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (12);
   $$2 = 354;
   break;
  }
  case 45: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (13);
   $$2 = 354;
   break;
  }
  case 46: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (14);
   $$2 = 354;
   break;
  }
  case 47: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (15);
   $$2 = 354;
   break;
  }
  case 48: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (16);
   $$2 = 354;
   break;
  }
  case 49: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (17);
   $$2 = 354;
   break;
  }
  case 50: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (18);
   $$2 = 354;
   break;
  }
  case 51: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (19);
   $$2 = 354;
   break;
  }
  case 52: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (20);
   $$2 = 354;
   break;
  }
  case 53: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (21);
   $$2 = 354;
   break;
  }
  case 54: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (22);
   $$2 = 354;
   break;
  }
  case 55: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (23);
   $$2 = 354;
   break;
  }
  case 56: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (24);
   $$2 = 354;
   break;
  }
  case 57: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (25);
   $$2 = 354;
   break;
  }
  case 58: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (26);
   $$2 = 354;
   break;
  }
  case 59: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (27);
   $$2 = 354;
   break;
  }
  case 60: {
   $$2 = 300;
   break;
  }
  case 61: {
   $$2 = 309;
   break;
  }
  case 62: {
   $$2 = 258;
   break;
  }
  case 63: {
   $$2 = 277;
   break;
  }
  case 64: {
   $$2 = 306;
   break;
  }
  case 65: {
   $$2 = 307;
   break;
  }
  case 66: {
   $$2 = 308;
   break;
  }
  case 67: {
   $$2 = 311;
   break;
  }
  case 68: {
   $$2 = 326;
   break;
  }
  case 69: {
   $$2 = 327;
   break;
  }
  case 70: {
   $$2 = 270;
   break;
  }
  case 71: {
   $$2 = 302;
   break;
  }
  case 72: {
   $$2 = 303;
   break;
  }
  case 73: {
   $$2 = 295;
   break;
  }
  case 74: {
   HEAP32[654216>>2] = 15;
   $$2 = 264;
   break;
  }
  case 75: {
   HEAP32[654216>>2] = 15;
   $$2 = 265;
   break;
  }
  case 76: {
   HEAP32[674280>>2] = (1);
   HEAP32[654216>>2] = 1;
   $$2 = 351;
   break;
  }
  case 77: {
   HEAP32[674280>>2] = (2);
   HEAP32[654216>>2] = 1;
   $$2 = 351;
   break;
  }
  case 78: {
   HEAP32[674280>>2] = (3);
   HEAP32[654216>>2] = 1;
   $$2 = 351;
   break;
  }
  case 79: {
   HEAP32[674280>>2] = (4);
   HEAP32[654216>>2] = 1;
   $$2 = 351;
   break;
  }
  case 80: {
   HEAP32[674280>>2] = (5);
   HEAP32[654216>>2] = 1;
   $$2 = 351;
   break;
  }
  case 81: {
   HEAP32[674280>>2] = (6);
   HEAP32[654216>>2] = 1;
   $$2 = 351;
   break;
  }
  case 82: {
   HEAP32[674280>>2] = (7);
   HEAP32[654216>>2] = 1;
   $$2 = 351;
   break;
  }
  case 83: {
   HEAP32[674280>>2] = (8);
   HEAP32[654216>>2] = 1;
   $$2 = 351;
   break;
  }
  case 84: {
   HEAP32[654216>>2] = 5;
   $$2 = 301;
   break;
  }
  case 85: {
   $$2 = 280;
   break;
  }
  case 86: {
   $$2 = 325;
   break;
  }
  case 87: {
   $$2 = 324;
   break;
  }
  case 88: {
   HEAP32[674280>>2] = 0;
   $$2 = 355;
   break;
  }
  case 89: {
   HEAP32[674280>>2] = (1);
   $$2 = 355;
   break;
  }
  case 90: {
   HEAP32[674280>>2] = (2);
   $$2 = 355;
   break;
  }
  case 91: {
   HEAP32[674280>>2] = (3);
   $$2 = 355;
   break;
  }
  case 92: {
   HEAP32[674280>>2] = (-1);
   $$2 = 355;
   break;
  }
  case 93: {
   HEAP32[654216>>2] = 1;
   $$2 = 125;
   break;
  }
  case 94: {
   HEAP32[654216>>2] = 9;
   $$2 = 328;
   break;
  }
  case 95: {
   $$2 = 329;
   break;
  }
  case 96: {
   $$2 = 330;
   break;
  }
  case 97: {
   $$2 = 331;
   break;
  }
  case 98: {
   $$2 = 332;
   break;
  }
  case 99: {
   $$2 = 336;
   break;
  }
  case 100: {
   $$2 = 340;
   break;
  }
  case 101: {
   HEAP32[674280>>2] = (1);
   $$2 = 351;
   break;
  }
  case 102: {
   HEAP32[674280>>2] = (2);
   $$2 = 351;
   break;
  }
  case 103: {
   HEAP32[674280>>2] = (3);
   $$2 = 351;
   break;
  }
  case 104: {
   HEAP32[674280>>2] = (4);
   $$2 = 351;
   break;
  }
  case 105: {
   HEAP32[674280>>2] = (5);
   $$2 = 351;
   break;
  }
  case 106: {
   HEAP32[674280>>2] = (6);
   $$2 = 351;
   break;
  }
  case 107: {
   HEAP32[674280>>2] = (7);
   $$2 = 351;
   break;
  }
  case 108: {
   HEAP32[674280>>2] = (8);
   $$2 = 351;
   break;
  }
  case 109: {
   $$2 = 333;
   break;
  }
  case 110: {
   $$2 = 334;
   break;
  }
  case 111: {
   $$2 = 335;
   break;
  }
  case 112: {
   $$2 = 337;
   break;
  }
  case 113: {
   $$2 = 338;
   break;
  }
  case 114: {
   $$2 = 339;
   break;
  }
  case 115: {
   $$2 = 341;
   break;
  }
  case 116: {
   $$2 = 342;
   break;
  }
  case 117: {
   $$2 = 343;
   break;
  }
  case 118: {
   HEAP32[674280>>2] = 0;
   $$2 = 359;
   break;
  }
  case 119: {
   HEAP32[674280>>2] = (1);
   $$2 = 359;
   break;
  }
  case 120: {
   HEAP32[674280>>2] = (2);
   $$2 = 359;
   break;
  }
  case 121: {
   HEAP32[674280>>2] = (3);
   $$2 = 359;
   break;
  }
  case 122: {
   HEAP32[674280>>2] = (4);
   $$2 = 359;
   break;
  }
  case 123: {
   HEAP32[674280>>2] = (5);
   $$2 = 359;
   break;
  }
  case 124: {
   HEAP32[674280>>2] = (6);
   $$2 = 359;
   break;
  }
  case 125: {
   HEAP32[674280>>2] = (7);
   $$2 = 359;
   break;
  }
  case 126: {
   HEAP32[654216>>2] = 1;
   $$2 = 125;
   break;
  }
  case 127: {
   HEAP32[654216>>2] = 17;
   HEAP32[674280>>2] = 0;
   $$2 = 269;
   break;
  }
  case 128: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = 0;
   $65 = HEAP32[654200>>2]|0;
   $66 = HEAP8[$65>>0]|0;
   $67 = ($66<<24>>24)==(0);
   if ($67) {
    $$2 = 353;
   } else {
    $70 = $66;$72 = 0;$74 = 0;$76 = 0;$78 = 0;$a$062 = $65;
    while(1) {
     $68 = (($a$062) + 1|0);
     $69 = $70 << 24 >> 24;
     switch ($69|0) {
     case 65: case 97:  {
      $77 = $78 | 1;
      $$c14 = $77;
      HEAP32[674280>>2] = $$c14;
      $455 = $77;$456 = $77;$457 = $77;$458 = $77;
      break;
     }
     case 82: case 114:  {
      $71 = $72 | 8;
      $$c17 = $71;
      HEAP32[674280>>2] = $$c17;
      $455 = $71;$456 = $71;$457 = $71;$458 = $71;
      break;
     }
     case 71: case 103:  {
      $73 = $74 | 4;
      $$c16 = $73;
      HEAP32[674280>>2] = $$c16;
      $455 = $73;$456 = $73;$457 = $73;$458 = $73;
      break;
     }
     case 66: case 98:  {
      $75 = $76 | 2;
      $$c15 = $75;
      HEAP32[674280>>2] = $$c15;
      $455 = $75;$456 = $75;$457 = $75;$458 = $75;
      break;
     }
     default: {
      $455 = $78;$456 = $76;$457 = $74;$458 = $72;
     }
     }
     $79 = HEAP8[$68>>0]|0;
     $80 = ($79<<24>>24)==(0);
     if ($80) {
      $$2 = 353;
      break L180;
     } else {
      $70 = $79;$72 = $458;$74 = $457;$76 = $456;$78 = $455;$a$062 = $68;
     }
    }
   }
   break;
  }
  case 135: {
   $$2 = 283;
   break;
  }
  case 136: {
   $$2 = 266;
   break;
  }
  case 137: {
   HEAP32[674280>>2] = (1);
   $$2 = 348;
   break;
  }
  case 138: {
   HEAP32[674280>>2] = (2);
   $$2 = 348;
   break;
  }
  case 139: {
   $$2 = 284;
   break;
  }
  case 140: {
   $$2 = 285;
   break;
  }
  case 141: {
   $$2 = 286;
   break;
  }
  case 142: {
   $$2 = 287;
   break;
  }
  case 143: {
   $$2 = 288;
   break;
  }
  case 144: {
   $$2 = 289;
   break;
  }
  case 145: {
   HEAP32[654216>>2] = 1;
   $$2 = 267;
   break;
  }
  case 146: {
   HEAP32[674280>>2] = 0;
   $$2 = 349;
   break;
  }
  case 147: {
   HEAP32[674280>>2] = (1);
   $$2 = 349;
   break;
  }
  case 148: {
   HEAP32[674280>>2] = (2);
   $$2 = 349;
   break;
  }
  case 149: {
   HEAP32[674280>>2] = (3);
   $$2 = 349;
   break;
  }
  case 150: {
   HEAP32[674280>>2] = (4);
   $$2 = 349;
   break;
  }
  case 151: {
   HEAP32[674280>>2] = (5);
   $$2 = 349;
   break;
  }
  case 152: {
   HEAP32[674280>>2] = (6);
   $$2 = 349;
   break;
  }
  case 153: {
   HEAP32[674280>>2] = (7);
   $$2 = 349;
   break;
  }
  case 154: {
   HEAP32[674280>>2] = (8);
   $$2 = 349;
   break;
  }
  case 155: {
   HEAP32[674280>>2] = (9);
   $$2 = 349;
   break;
  }
  case 156: {
   HEAP32[674280>>2] = (10);
   $$2 = 349;
   break;
  }
  case 157: {
   HEAP32[674280>>2] = (1);
   $$2 = 349;
   break;
  }
  case 158: {
   HEAP32[674280>>2] = 0;
   $$2 = 349;
   break;
  }
  case 159: {
   HEAP32[674280>>2] = (1);
   $$2 = 349;
   break;
  }
  case 160: {
   HEAP32[674280>>2] = 0;
   $$2 = 349;
   break;
  }
  case 161: {
   HEAP32[654216>>2] = 1;
   $$2 = 268;
   break;
  }
  case 162: {
   HEAP32[674280>>2] = 0;
   $$2 = 350;
   break;
  }
  case 163: {
   HEAP32[674280>>2] = (1);
   $$2 = 350;
   break;
  }
  case 164: {
   HEAP32[674280>>2] = (2);
   $$2 = 350;
   break;
  }
  case 165: {
   HEAP32[674280>>2] = (3);
   $$2 = 350;
   break;
  }
  case 166: {
   HEAP32[674280>>2] = (4);
   $$2 = 350;
   break;
  }
  case 167: {
   HEAP32[674280>>2] = (5);
   $$2 = 350;
   break;
  }
  case 168: {
   HEAP32[674280>>2] = (6);
   $$2 = 350;
   break;
  }
  case 169: {
   HEAP32[674280>>2] = (7);
   $$2 = 350;
   break;
  }
  case 170: {
   HEAP32[674280>>2] = (8);
   $$2 = 350;
   break;
  }
  case 171: {
   HEAP32[674280>>2] = (9);
   $$2 = 350;
   break;
  }
  case 172: {
   HEAP32[674280>>2] = (10);
   $$2 = 350;
   break;
  }
  case 173: {
   HEAP32[674280>>2] = (11);
   $$2 = 350;
   break;
  }
  case 174: {
   HEAP32[674280>>2] = (12);
   $$2 = 350;
   break;
  }
  case 175: {
   HEAP32[674280>>2] = (13);
   $$2 = 350;
   break;
  }
  case 176: {
   HEAP32[674280>>2] = (14);
   $$2 = 350;
   break;
  }
  case 177: {
   HEAP32[674280>>2] = (15);
   $$2 = 350;
   break;
  }
  case 178: {
   HEAP32[674280>>2] = (16);
   $$2 = 350;
   break;
  }
  case 179: {
   HEAP32[674280>>2] = (17);
   $$2 = 350;
   break;
  }
  case 180: {
   HEAP32[674280>>2] = (18);
   $$2 = 350;
   break;
  }
  case 181: {
   HEAP32[674280>>2] = (19);
   $$2 = 350;
   break;
  }
  case 182: {
   HEAP32[674280>>2] = (20);
   $$2 = 350;
   break;
  }
  case 183: {
   HEAP32[654216>>2] = 7;
   $$2 = 294;
   break;
  }
  case 184: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (1);
   $$2 = 358;
   break;
  }
  case 185: {
   HEAP32[654216>>2] = 1;
   HEAP32[674280>>2] = (2);
   $$2 = 358;
   break;
  }
  case 186: {
   $$2 = 280;
   break;
  }
  case 187: {
   $$2 = 282;
   break;
  }
  case 188: {
   HEAP32[654216>>2] = 1;
   $$2 = 259;
   break;
  }
  case 189: {
   HEAP32[654216>>2] = 1;
   $$2 = 261;
   break;
  }
  case 190: {
   HEAP32[654216>>2] = 1;
   $$2 = 260;
   break;
  }
  case 191: {
   HEAP32[654216>>2] = 3;
   $$2 = 276;
   break;
  }
  case 192: {
   $$2 = 281;
   break;
  }
  case 193: {
   $$2 = 271;
   break;
  }
  case 194: {
   HEAP32[674280>>2] = 0;
   $$2 = 356;
   break;
  }
  case 195: {
   HEAP32[674280>>2] = (1);
   $$2 = 356;
   break;
  }
  case 196: {
   HEAP32[674280>>2] = (2);
   $$2 = 356;
   break;
  }
  case 197: {
   HEAP32[674280>>2] = (3);
   $$2 = 356;
   break;
  }
  case 198: {
   HEAP32[674280>>2] = (4);
   $$2 = 356;
   break;
  }
  case 199: {
   HEAP32[674280>>2] = (5);
   $$2 = 356;
   break;
  }
  case 200: {
   HEAP32[674280>>2] = (6);
   $$2 = 356;
   break;
  }
  case 201: {
   HEAP32[674280>>2] = (7);
   $$2 = 356;
   break;
  }
  case 202: {
   $$2 = 272;
   break;
  }
  case 203: {
   $$2 = 296;
   break;
  }
  case 204: {
   $$2 = 297;
   break;
  }
  case 205: {
   $$2 = 273;
   break;
  }
  case 206: {
   $$2 = 274;
   break;
  }
  case 207: {
   $$2 = 275;
   break;
  }
  case 208: {
   $$2 = 279;
   break;
  }
  case 209: {
   HEAP32[654216>>2] = 11;
   $$2 = 278;
   break;
  }
  case 210: {
   HEAP32[654216>>2] = 1;
   $81 = HEAP32[654200>>2]|0;
   $82 = HEAP8[$81>>0]|0;
   $83 = $82 << 24 >> 24;
   $$2 = $83;
   break;
  }
  case 211: {
   HEAP32[674280>>2] = (2);
   HEAP32[654216>>2] = 3;
   $$2 = 357;
   break;
  }
  case 212: {
   HEAP32[674280>>2] = (3);
   HEAP32[654216>>2] = 3;
   $$2 = 357;
   break;
  }
  case 213: {
   HEAP32[674280>>2] = (4);
   HEAP32[654216>>2] = 3;
   $$2 = 357;
   break;
  }
  case 214: {
   HEAP32[674280>>2] = (2);
   HEAP32[654216>>2] = 3;
   $$2 = 357;
   break;
  }
  case 215: {
   HEAP32[674280>>2] = (5);
   HEAP32[654216>>2] = 3;
   $$2 = 357;
   break;
  }
  case 216: {
   HEAP32[654216>>2] = 3;
   HEAP32[674280>>2] = 0;
   $$2 = 352;
   break;
  }
  case 217: {
   HEAP32[654216>>2] = 3;
   HEAP32[674280>>2] = 0;
   $$2 = 352;
   break;
  }
  case 218: {
   HEAP32[654216>>2] = 3;
   HEAP32[674280>>2] = 0;
   $$2 = 352;
   break;
  }
  case 219: {
   HEAP32[654216>>2] = 3;
   HEAP32[674280>>2] = 0;
   $$2 = 352;
   break;
  }
  case 220: {
   HEAP32[654216>>2] = 3;
   HEAP32[674280>>2] = 0;
   $$2 = 352;
   break;
  }
  case 221: {
   HEAP32[654216>>2] = 1;
   $$2 = 305;
   break;
  }
  case 222: {
   HEAP32[654216>>2] = 1;
   $$2 = 310;
   break;
  }
  case 223: {
   $$2 = 312;
   break;
  }
  case 224: {
   $$2 = 291;
   break;
  }
  case 225: {
   $$2 = 293;
   break;
  }
  case 226: {
   $$2 = 291;
   break;
  }
  case 227: {
   $$2 = 262;
   break;
  }
  case 228: {
   $$2 = 263;
   break;
  }
  case 229: {
   $$2 = 304;
   break;
  }
  case 230: {
   $$2 = 313;
   break;
  }
  case 231: {
   $$2 = 314;
   break;
  }
  case 232: {
   $$2 = 315;
   break;
  }
  case 233: {
   $$2 = 316;
   break;
  }
  case 234: {
   $$2 = 317;
   break;
  }
  case 235: {
   $$2 = 318;
   break;
  }
  case 236: {
   $$2 = 319;
   break;
  }
  case 237: {
   $$2 = 320;
   break;
  }
  case 238: {
   $$2 = 321;
   break;
  }
  case 239: {
   $$2 = 322;
   break;
  }
  case 240: {
   $$2 = 323;
   break;
  }
  case 241: {
   $84 = HEAP32[654200>>2]|0;
   $85 = (_strlen(($84|0))|0);
   $86 = HEAP32[679312>>2]|0;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($87) + 12|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($85) + -1)|0;
   $91 = (FUNCTION_TABLE_iiii[$89 & 2047]($86,$90,1)|0);
   $92 = (($84) + 1|0);
   $93 = (($85) + -2)|0;
   _memcpy(($91|0),($92|0),($93|0))|0;
   $94 = (($91) + ($93)|0);
   HEAP8[$94>>0] = 0;
   HEAP32[674280>>2] = $91;
   $$2 = 346;
   break;
  }
  case 242: {
   $95 = HEAP32[654200>>2]|0;
   $96 = (_strlen(($95|0))|0);
   $97 = HEAP32[679312>>2]|0;
   $98 = HEAP32[$97>>2]|0;
   $99 = (($98) + 12|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($96) + -1)|0;
   $102 = (FUNCTION_TABLE_iiii[$100 & 2047]($97,$101,1)|0);
   $103 = (($95) + 1|0);
   $104 = (($96) + -2)|0;
   _memcpy(($102|0),($103|0),($104|0))|0;
   $105 = (($102) + ($104)|0);
   HEAP8[$105>>0] = 0;
   HEAP32[674280>>2] = $102;
   $$2 = 346;
   break;
  }
  case 243: {
   $106 = HEAP32[654200>>2]|0;
   $107 = (Math_fround(__Z19SimpleStringToFloatPKcPi($106,0)));
   HEAPF32[674280>>2] = $107;
   $$2 = 347;
   break;
  }
  case 244: {
   $108 = HEAP32[654200>>2]|0;
   $109 = (Math_fround(__Z19SimpleStringToFloatPKcPi($108,0)));
   HEAPF32[674280>>2] = $109;
   $$2 = 347;
   break;
  }
  case 256: {
   (__Z7yyerrorPKc(673576)|0);
   $$2 = 0;
   break;
  }
  case 261: {
   $145 = HEAP32[654200>>2]|0;
   $146 = (_strlen(($145|0))|0);
   $147 = (($146) + 1)|0;
   $148 = HEAP32[679312>>2]|0;
   $149 = HEAP32[$148>>2]|0;
   $150 = (($149) + 12|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = (FUNCTION_TABLE_iiii[$151 & 2047]($148,$147,1)|0);
   _memcpy(($152|0),($145|0),($147|0))|0;
   HEAP32[674280>>2] = $152;
   $$2 = 344;
   break;
  }
  case 262: {
   $153 = HEAP32[654200>>2]|0;
   $154 = (_strlen(($153|0))|0);
   $155 = HEAP32[679312>>2]|0;
   $156 = HEAP32[$155>>2]|0;
   $157 = (($156) + 12|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = (($154) + -1)|0;
   $160 = (FUNCTION_TABLE_iiii[$158 & 2047]($155,$159,1)|0);
   $161 = (($153) + 1|0);
   $162 = (($154) + -2)|0;
   _memcpy(($160|0),($161|0),($162|0))|0;
   $163 = (($160) + ($162)|0);
   HEAP8[$163>>0] = 0;
   HEAP32[674280>>2] = $160;
   $p$0 = $160;
   while(1) {
    $164 = HEAP8[$p$0>>0]|0;
    if ((($164<<24>>24) == 0)) {
     $$2 = 345;
     break L180;
    } else if ((($164<<24>>24) == 10)) {
     $165 = HEAP32[654192>>2]|0;
     $166 = (($165) + 1)|0;
     HEAP32[654192>>2] = $166;
    }
    $167 = (($p$0) + 1|0);
    $p$0 = $167;
   }
   break;
  }
  case 275: {
   $191 = HEAP32[654176>>2]|0;
   __Z9yyrestartP8_IO_FILE($191);
   label = 304;
   break;
  }
  case 291: {
   $249 = HEAP32[654176>>2]|0;
   __Z9yyrestartP8_IO_FILE($249);
   label = 304;
   break;
  }
  case 305: {
   $292 = HEAP32[654200>>2]|0;
   $293 = HEAP8[$292>>0]|0;
   $294 = $293 << 24 >> 24;
   $$2 = $294;
   break;
  }
  case 306: {
   $$2 = 0;
   break;
  }
  case 349: {
   __ZL14yy_fatal_errorPKc(673656);
   // unreachable;
   break;
  }
  case 350: {
   $$2 = 290;
   break;
  }
 }
 if ((label|0) == 304) {
  (__Z7yyerrorPKc(673600)|0);
  $$2 = 0;
 }
 STACKTOP = sp;return ($$2|0);
}
function __ZL21yyensure_buffer_stackv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[654224>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[628272>>2]|0;
  HEAP32[$0>>2] = $3;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $4 = (__Z15malloc_internaljj10MemLabelIdiPKci(4,16,$$byval_copy1,0,673896,478)|0);
  HEAP32[654224>>2] = $4;
  $5 = ($4|0)==(0|0);
  if ($5) {
   __ZL14yy_fatal_errorPKc(673920);
   // unreachable;
  }
  HEAP32[$4>>2] = 0;
  HEAP32[673904>>2] = 1;
  STACKTOP = sp;return;
 }
 $6 = HEAP32[673904>>2]|0;
 $7 = (($6) + -1)|0;
 $8 = (0)<($7>>>0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($6) + 8)|0;
 $10 = $9 << 2;
 $11 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $11;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $12 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,16,$$byval_copy1,0,673896,482)|0);
 HEAP32[654224>>2] = $12;
 $13 = ($12|0)==(0|0);
 if ($13) {
  __ZL14yy_fatal_errorPKc(673920);
  // unreachable;
 }
 $14 = HEAP32[673904>>2]|0;
 $15 = (($12) + ($14<<2)|0);
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP32[$15+20>>2]=0|0;HEAP32[$15+24>>2]=0|0;HEAP32[$15+28>>2]=0|0;
 HEAP32[673904>>2] = $9;
 STACKTOP = sp;return;
}
function __Z16yy_create_bufferP8_IO_FILEi($file,$size) {
 $file = $file|0;
 $size = $size|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Z15malloc_internaljj10MemLabelIdiPKci(48,16,$$byval_copy1,0,673896,478)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZL14yy_fatal_errorPKc(673712);
  // unreachable;
 }
 $4 = (($2) + 12|0);
 HEAP32[$4>>2] = $size;
 $5 = (($size) + 2)|0;
 $6 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $6;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $7 = (__Z15malloc_internaljj10MemLabelIdiPKci($5,16,$$byval_copy1,0,673896,478)|0);
 $8 = (($2) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = ($7|0)==(0|0);
 if ($9) {
  __ZL14yy_fatal_errorPKc(673712);
  // unreachable;
 }
 $10 = (($2) + 20|0);
 HEAP32[$10>>2] = 1;
 $11 = (___errno_location()|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($2) + 16|0);
 HEAP32[$13>>2] = 0;
 HEAP8[$7>>0] = 0;
 $14 = HEAP32[$8>>2]|0;
 $15 = (($14) + 1|0);
 HEAP8[$15>>0] = 0;
 $16 = HEAP32[$8>>2]|0;
 $17 = (($2) + 8|0);
 HEAP32[$17>>2] = $16;
 $18 = (($2) + 28|0);
 HEAP32[$18>>2] = 1;
 $19 = (($2) + 44|0);
 HEAP32[$19>>2] = 0;
 $20 = HEAP32[654224>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $24 = 0;
 } else {
  $22 = HEAP32[$20>>2]|0;
  $24 = $22;
 }
 $23 = ($24|0)==($2|0);
 if ($23) {
  $25 = HEAP32[$20>>2]|0;
  $26 = (($25) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[673648>>2] = $27;
  $28 = (($25) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[654232>>2] = $29;
  HEAP32[654200>>2] = $29;
  $30 = HEAP32[$20>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  HEAP32[654176>>2] = $31;
  $32 = HEAP8[$29>>0]|0;
  HEAP8[654240>>0] = $32;
 }
 HEAP32[$2>>2] = $file;
 $33 = (($2) + 40|0);
 HEAP32[$33>>2] = 1;
 $34 = HEAP32[654224>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  $38 = 0;
 } else {
  $36 = HEAP32[$34>>2]|0;
  $38 = $36;
 }
 $37 = ($38|0)==($2|0);
 if ($37) {
  $41 = (($2) + 24|0);
  HEAP32[$41>>2] = 0;
  HEAP32[$11>>2] = $12;
  STACKTOP = sp;return ($2|0);
 }
 $39 = (($2) + 32|0);
 HEAP32[$39>>2] = 1;
 $40 = (($2) + 36|0);
 HEAP32[$40>>2] = 0;
 $41 = (($2) + 24|0);
 HEAP32[$41>>2] = 0;
 HEAP32[$11>>2] = $12;
 STACKTOP = sp;return ($2|0);
}
function __ZL18ScanErrorOrWarningb($warning) {
 $warning = $warning|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$pn$i$i26 = 0, $$pre = 0, $$pre39 = 0, $$pre41 = 0, $$pre42 = 0, $$pre47$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__cap$0$i$i22 = 0, $__p$0$i$i27 = 0, $__p$0$sum$pre$i$i24 = 0, $__p$0$sum$pre$phi$i$i25ZZZ2D = 0, $__sz$0$i$i23 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $msg = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $msg = sp;
 $$pre = HEAP8[654240>>0]|0;
 $$pre39 = HEAP32[654232>>2]|0;
 $0 = $$pre;$1 = $$pre39;
 L1: while(1) {
  HEAP8[$1>>0] = $0;
  $2 = HEAP32[654232>>2]|0;
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  do {
   if ($4) {
    $5 = HEAP32[673648>>2]|0;
    $6 = HEAP32[654224>>2]|0;
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + ($5)|0);
    $11 = ($2>>>0)<($10>>>0);
    if ($11) {
     HEAP8[$2>>0] = 0;
     break;
    }
    $12 = HEAP32[654200>>2]|0;
    $13 = (($2) + 1|0);
    HEAP32[654232>>2] = $13;
    $14 = (__ZL18yy_get_next_bufferv()|0);
    if ((($14|0) == 2)) {
     label = 6;
     break L1;
    } else if ((($14|0) == 1)) {
     break L1;
    } else if (!((($14|0) == 0))) {
     break;
    }
    $16 = $12;
    $17 = $2;
    $18 = (($17) - ($16))|0;
    $19 = HEAP32[654200>>2]|0;
    $20 = (($19) + ($18)|0);
    HEAP32[654232>>2] = $20;
   }
  } while(0);
  $21 = HEAP32[654232>>2]|0;
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  HEAP8[$21>>0] = 0;
  $24 = HEAP32[654232>>2]|0;
  $25 = (($24) + 1|0);
  HEAP32[654232>>2] = $25;
  $26 = HEAP8[$25>>0]|0;
  HEAP8[654240>>0] = $26;
  switch ($23|0) {
  case 32: case 9:  {
   $0 = $26;$1 = $25;
   break;
  }
  case 10: case 13: case 0:  {
   break L1;
   break;
  }
  default: {
   label = 10;
   break L1;
  }
  }
 }
 if ((label|0) == 6) {
  $15 = HEAP32[654176>>2]|0;
  __Z9yyrestartP8_IO_FILE($15);
 }
 else if ((label|0) == 10) {
  ;HEAP32[$msg+0>>2]=0|0;HEAP32[$msg+4>>2]=0|0;HEAP32[$msg+8>>2]=0|0;
  $$pre47$pre = (($msg) + 8|0);
  $28 = (($msg) + 1|0);
  HEAP8[$msg>>0] = 2;
  $$pre42 = (($msg) + 4|0);
  HEAP8[$28>>0] = $22;
  $29 = (($msg) + 2|0);
  HEAP8[$29>>0] = 0;
  L13: while(1) {
   $30 = HEAP8[654240>>0]|0;
   $31 = HEAP32[654232>>2]|0;
   HEAP8[$31>>0] = $30;
   $32 = HEAP32[654232>>2]|0;
   $33 = HEAP8[$32>>0]|0;
   $34 = ($33<<24>>24)==(0);
   do {
    if ($34) {
     $35 = HEAP32[673648>>2]|0;
     $36 = HEAP32[654224>>2]|0;
     $37 = HEAP32[$36>>2]|0;
     $38 = (($37) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + ($35)|0);
     $41 = ($32>>>0)<($40>>>0);
     if ($41) {
      HEAP8[$32>>0] = 0;
      break;
     }
     $42 = HEAP32[654200>>2]|0;
     $43 = (($32) + 1|0);
     HEAP32[654232>>2] = $43;
     __THREW__ = 0;
     $44 = (invoke_i(106)|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 38;
      break L13;
     }
     if ((($44|0) == 2)) {
      label = 16;
      break L13;
     } else if ((($44|0) == 1)) {
      label = 42;
      break L13;
     } else if (!((($44|0) == 0))) {
      break;
     }
     $50 = $42;
     $51 = $32;
     $52 = (($51) - ($50))|0;
     $53 = HEAP32[654200>>2]|0;
     $54 = (($53) + ($52)|0);
     HEAP32[654232>>2] = $54;
    }
   } while(0);
   $55 = HEAP32[654232>>2]|0;
   $56 = HEAP8[$55>>0]|0;
   $57 = $56&255;
   HEAP8[$55>>0] = 0;
   $58 = HEAP32[654232>>2]|0;
   $59 = (($58) + 1|0);
   HEAP32[654232>>2] = $59;
   $60 = HEAP8[$59>>0]|0;
   HEAP8[654240>>0] = $60;
   if ((($57|0) == 0)) {
    label = 42;
    break;
   } else if ((($57|0) == 10) | (($57|0) == 13)) {
    label = 43;
    break;
   }
   $61 = HEAP8[$msg>>0]|0;
   $62 = $61 & 1;
   $63 = ($62<<24>>24)!=(0);
   if ($63) {
    $66 = HEAP32[$msg>>2]|0;
    $67 = $66 & -2;
    $68 = (($67) + -1)|0;
    $69 = HEAP32[$$pre42>>2]|0;
    $70 = $66&255;
    $76 = $70;$__cap$0$i$i22 = $68;$__sz$0$i$i23 = $69;
   } else {
    $64 = $61&255;
    $65 = $64 >>> 1;
    $76 = $61;$__cap$0$i$i22 = 10;$__sz$0$i$i23 = $65;
   }
   $71 = ($__sz$0$i$i23|0)==($__cap$0$i$i22|0);
   do {
    if ($71) {
     $72 = ($__cap$0$i$i22|0)==(-17);
     if ($72) {
      label = 24;
      break L13;
     }
     $75 = $76 & 1;
     $77 = ($75<<24>>24)==(0);
     $78 = HEAP32[$$pre47$pre>>2]|0;
     $$ = $77 ? $28 : $78;
     $79 = ($__cap$0$i$i22>>>0)<(2147483623);
     if ($79) {
      $80 = (($__cap$0$i$i22) + 1)|0;
      $81 = $__cap$0$i$i22 << 1;
      $82 = ($80>>>0)<($81>>>0);
      $83 = $82 ? $81 : $80;
      $84 = ($83>>>0)<(11);
      if ($84) {
       $87 = 11;
      } else {
       $85 = (($83) + 16)|0;
       $86 = $85 & -16;
       $87 = $86;
      }
     } else {
      $87 = -17;
     }
     __THREW__ = 0;
     $88 = (invoke_ii(2988,($87|0))|0);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 38;
      break L13;
     }
     _memcpy(($88|0),($$|0),($__cap$0$i$i22|0))|0;
     $91 = ($__cap$0$i$i22|0)==(10);
     if (!($91)) {
      __ZdlPv($$);
     }
     HEAP32[$$pre47$pre>>2] = $88;
     $92 = $87 | 1;
     HEAP32[$msg>>2] = $92;
     $118 = $88;
     label = 36;
    } else {
     if ($63) {
      $$pre41 = HEAP32[$$pre47$pre>>2]|0;
      $118 = $$pre41;
      label = 36;
      break;
     } else {
      $93 = $__sz$0$i$i23 << 1;
      $94 = (($93) + 2)|0;
      $95 = $94&255;
      HEAP8[$msg>>0] = $95;
      $__p$0$sum$pre$i$i24 = (($__sz$0$i$i23) + 1)|0;
      $$pn$i$i26 = $28;$__p$0$sum$pre$phi$i$i25ZZZ2D = $__p$0$sum$pre$i$i24;
      break;
     }
    }
   } while(0);
   if ((label|0) == 36) {
    label = 0;
    $96 = (($__sz$0$i$i23) + 1)|0;
    HEAP32[$$pre42>>2] = $96;
    $$pn$i$i26 = $118;$__p$0$sum$pre$phi$i$i25ZZZ2D = $96;
   }
   $__p$0$i$i27 = (($$pn$i$i26) + ($__sz$0$i$i23)|0);
   HEAP8[$__p$0$i$i27>>0] = $56;
   $97 = (($$pn$i$i26) + ($__p$0$sum$pre$phi$i$i25ZZZ2D)|0);
   HEAP8[$97>>0] = 0;
  }
  if ((label|0) == 16) {
   $47 = HEAP32[654176>>2]|0;
   __THREW__ = 0;
   invoke_vi(3591,($47|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    label = 39;
   } else {
    label = 42;
   }
  }
  else if ((label|0) == 24) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    label = 39;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 38) {
   $98 = ___cxa_find_matching_catch()|0;
   $99 = tempRet0;
   $lpad$phi$index = $98;$lpad$phi$index2 = $99;
  }
  else if ((label|0) == 43) {
   $110 = HEAP32[674256>>2]|0;
   $111 = HEAP32[654192>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(104,($110|0),($msg|0),($111|0),($warning|0),0);
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    label = 39;
   } else {
    $$0 = 1;
    label = 44;
   }
  }
  if ((label|0) == 42) {
   $107 = $warning ? 674160 : 674184;
   __THREW__ = 0;
   (invoke_ii(3325,($107|0))|0);
   $108 = __THREW__; __THREW__ = 0;
   $109 = $108&1;
   if ($109) {
    label = 39;
   } else {
    $$0 = 0;
    label = 44;
   }
  }
  if ((label|0) == 39) {
   $100 = ___cxa_find_matching_catch()|0;
   $101 = tempRet0;
   $lpad$phi$index = $100;$lpad$phi$index2 = $101;
  }
  else if ((label|0) == 44) {
   $114 = HEAP8[$msg>>0]|0;
   $115 = $114 & 1;
   $116 = ($115<<24>>24)==(0);
   if ($116) {
    $$1 = $$0;
    STACKTOP = sp;return ($$1|0);
   }
   $117 = HEAP32[$$pre47$pre>>2]|0;
   __ZdlPv($117);
   $$1 = $$0;
   STACKTOP = sp;return ($$1|0);
  }
  $102 = HEAP8[$msg>>0]|0;
  $103 = $102 & 1;
  $104 = ($103<<24>>24)==(0);
  if ($104) {
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  $105 = (($msg) + 8|0);
  $106 = HEAP32[$105>>2]|0;
  __ZdlPv($106);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $27 = $warning ? 674160 : 674184;
 (__Z7yyerrorPKc($27)|0);
 $$1 = 0;
 STACKTOP = sp;return ($$1|0);
}
function __ZL18yy_get_next_bufferv() {
 var $$ = 0, $$0 = 0, $$44 = 0, $$byval_copy1 = 0, $$num_to_read$0 = 0, $$phi$trans$insert42 = 0, $$pn = 0, $$pn$in = 0, $$pn$in16 = 0, $$pn17 = 0, $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre41 = 0, $$pre43 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dest$024 = 0, $exitcond = 0, $i$022 = 0, $n$0$lcssa = 0, $n$09 = 0, $n$18 = 0, $num_to_read$0 = 0, $num_to_read$0$in = 0, $num_to_read$0$in18 = 0, $num_to_read$0$lcssa = 0;
 var $num_to_read$019 = 0, $ret_val$0 = 0, $source$023 = 0, $storemerge2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[654224>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[654200>>2]|0;
 $6 = HEAP32[654232>>2]|0;
 $7 = HEAP32[673648>>2]|0;
 $8 = (($7) + 1)|0;
 $9 = (($4) + ($8)|0);
 $10 = ($6>>>0)>($9>>>0);
 if ($10) {
  __ZL14yy_fatal_errorPKc(673976);
  // unreachable;
 }
 $11 = (($2) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 $14 = $6;
 $15 = $5;
 $16 = (($14) - ($15))|0;
 if ($13) {
  $17 = ($16|0)==(1);
  $$ = $17 ? 1 : 2;
  $$0 = $$;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($16) + -1)|0;
 $19 = ($18|0)>(0);
 if ($19) {
  $20 = (($14) + -1)|0;
  $21 = (($20) - ($15))|0;
  $dest$024 = $4;$i$022 = 0;$source$023 = $5;
  while(1) {
   $22 = (($source$023) + 1|0);
   $23 = HEAP8[$source$023>>0]|0;
   $24 = (($dest$024) + 1|0);
   HEAP8[$dest$024>>0] = $23;
   $25 = (($i$022) + 1)|0;
   $exitcond = ($25|0)==($21|0);
   if ($exitcond) {
    break;
   } else {
    $dest$024 = $24;$i$022 = $25;$source$023 = $22;
   }
  }
  $$pre35 = HEAP32[654224>>2]|0;
  $$pre36 = HEAP32[$$pre35>>2]|0;
  $152 = $$pre35;$27 = $$pre36;
 } else {
  $152 = $1;$27 = $2;
 }
 $26 = (($27) + 44|0);
 $28 = HEAP32[$26>>2]|0;
 $29 = ($28|0)==(2);
 if ($29) {
  HEAP32[673648>>2] = 0;
  $31 = (($27) + 16|0);
  HEAP32[$31>>2] = 0;
  $114 = $152;
 } else {
  $$pn$in16 = (($27) + 12|0);
  $$pn17 = HEAP32[$$pn$in16>>2]|0;
  $num_to_read$0$in18 = (($$pn17) - ($18))|0;
  $num_to_read$019 = (($num_to_read$0$in18) + -1)|0;
  $30 = ($num_to_read$019|0)==(0);
  L16: do {
   if ($30) {
    $33 = $152;$34 = $27;
    while(1) {
     $32 = ($33|0)==(0|0);
     $$44 = $32 ? 0 : $34;
     $35 = HEAP32[654232>>2]|0;
     $36 = (($$44) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = $35;
     $39 = $37;
     $40 = (($38) - ($39))|0;
     $41 = (($$44) + 20|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0);
     if ($43) {
      break;
     }
     $44 = (($$44) + 12|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = $45 << 1;
     $47 = ($46|0)==(0);
     if ($47) {
      $48 = $45 >>> 3;
      $49 = (($48) + ($45))|0;
      $storemerge2 = $49;
     } else {
      $storemerge2 = $46;
     }
     HEAP32[$44>>2] = $storemerge2;
     $50 = (($storemerge2) + 2)|0;
     $51 = HEAP32[628272>>2]|0;
     HEAP32[$0>>2] = $51;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $52 = (__Z16realloc_internalPvji10MemLabelIdiPKci($37,$50,16,$$byval_copy1,0,673896,482)|0);
     HEAP32[$36>>2] = $52;
     $53 = ($52|0)==(0|0);
     if ($53) {
      label = 18;
      break;
     }
     $54 = (($52) + ($40)|0);
     HEAP32[654232>>2] = $54;
     $55 = HEAP32[654224>>2]|0;
     $56 = HEAP32[$55>>2]|0;
     $$pn$in = (($56) + 12|0);
     $$pn = HEAP32[$$pn$in>>2]|0;
     $num_to_read$0$in = (($$pn) - ($18))|0;
     $num_to_read$0 = (($num_to_read$0$in) + -1)|0;
     $57 = ($num_to_read$0|0)==(0);
     if ($57) {
      $33 = $55;$34 = $56;
     } else {
      $60 = $56;$85 = $55;$num_to_read$0$lcssa = $num_to_read$0;
      break L16;
     }
    }
    if ((label|0) == 18) {
     __ZL14yy_fatal_errorPKc(674032);
     // unreachable;
    }
    HEAP32[$36>>2] = 0;
    __ZL14yy_fatal_errorPKc(674032);
    // unreachable;
   } else {
    $60 = $27;$85 = $152;$num_to_read$0$lcssa = $num_to_read$019;
   }
  } while(0);
  $58 = ($num_to_read$0$lcssa>>>0)>(8192);
  $$num_to_read$0 = $58 ? 8192 : $num_to_read$0$lcssa;
  $59 = (($60) + 24|0);
  $61 = HEAP32[$59>>2]|0;
  $62 = ($61|0)==(0);
  L30: do {
   if ($62) {
    $83 = (___errno_location()|0);
    HEAP32[$83>>2] = 0;
    $84 = HEAP32[$85>>2]|0;
    $86 = (($84) + 4|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = (($87) + ($18)|0);
    $89 = HEAP32[654176>>2]|0;
    $90 = (_fread(($88|0),1,($$num_to_read$0|0),($89|0))|0);
    HEAP32[673648>>2] = $90;
    $91 = ($90|0)==(0);
    if ($91) {
     while(1) {
      $92 = HEAP32[654176>>2]|0;
      $93 = (_ferror(($92|0))|0);
      $94 = ($93|0)==(0);
      if ($94) {
       $108 = 0;
       break L30;
      }
      $95 = HEAP32[$83>>2]|0;
      $96 = ($95|0)==(4);
      if (!($96)) {
       break;
      }
      HEAP32[$83>>2] = 0;
      _clearerr(($92|0));
      $97 = HEAP32[654224>>2]|0;
      $98 = HEAP32[$97>>2]|0;
      $99 = (($98) + 4|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = (($100) + ($18)|0);
      $102 = HEAP32[654176>>2]|0;
      $103 = (_fread(($101|0),1,($$num_to_read$0|0),($102|0))|0);
      HEAP32[673648>>2] = $103;
      $104 = ($103|0)==(0);
      if (!($104)) {
       $108 = $103;
       break L30;
      }
     }
     __ZL14yy_fatal_errorPKc(674080);
     // unreachable;
    } else {
     $108 = $90;
    }
   } else {
    $63 = ($$num_to_read$0|0)==(0);
    do {
     if ($63) {
      $n$18 = 0;
     } else {
      $n$09 = 0;
      while(1) {
       $64 = HEAP32[654176>>2]|0;
       $65 = (_getc(($64|0))|0);
       if ((($65|0) == 10) | (($65|0) == -1)) {
        $n$0$lcssa = $n$09;
        break;
       }
       $66 = $65&255;
       $67 = HEAP32[654224>>2]|0;
       $68 = HEAP32[$67>>2]|0;
       $69 = (($68) + 4|0);
       $70 = HEAP32[$69>>2]|0;
       $$sum1 = (($n$09) + ($18))|0;
       $71 = (($70) + ($$sum1)|0);
       HEAP8[$71>>0] = $66;
       $72 = (($n$09) + 1)|0;
       $73 = ($72>>>0)<($$num_to_read$0>>>0);
       if ($73) {
        $n$09 = $72;
       } else {
        $n$0$lcssa = $72;
        break;
       }
      }
      if ((($65|0) == 10)) {
       $74 = (($n$0$lcssa) + 1)|0;
       $75 = HEAP32[654224>>2]|0;
       $76 = HEAP32[$75>>2]|0;
       $77 = (($76) + 4|0);
       $78 = HEAP32[$77>>2]|0;
       $$sum = (($n$0$lcssa) + ($18))|0;
       $79 = (($78) + ($$sum)|0);
       HEAP8[$79>>0] = 10;
       $n$18 = $74;
       break;
      } else if (!((($65|0) == -1))) {
       $n$18 = $n$0$lcssa;
       break;
      }
      $80 = HEAP32[654176>>2]|0;
      $81 = (_ferror(($80|0))|0);
      $82 = ($81|0)==(0);
      if ($82) {
       $n$18 = $n$0$lcssa;
      } else {
       __ZL14yy_fatal_errorPKc(674080);
       // unreachable;
      }
     }
    } while(0);
    HEAP32[673648>>2] = $n$18;
    $108 = $n$18;
   }
  } while(0);
  $105 = HEAP32[654224>>2]|0;
  $106 = HEAP32[$105>>2]|0;
  $107 = (($106) + 16|0);
  HEAP32[$107>>2] = $108;
  $114 = $105;
 }
 $109 = HEAP32[673648>>2]|0;
 $110 = ($109|0)==(0);
 do {
  if ($110) {
   $111 = ($18|0)==(0);
   if ($111) {
    $112 = HEAP32[654176>>2]|0;
    __Z9yyrestartP8_IO_FILE($112);
    $$pre37 = HEAP32[654224>>2]|0;
    $119 = $$pre37;$ret_val$0 = 1;
    break;
   } else {
    $113 = HEAP32[$114>>2]|0;
    $115 = (($113) + 44|0);
    HEAP32[$115>>2] = 2;
    $119 = $114;$ret_val$0 = 2;
    break;
   }
  } else {
   $119 = $114;$ret_val$0 = 0;
  }
 } while(0);
 $116 = HEAP32[673648>>2]|0;
 $117 = (($116) + ($18))|0;
 $118 = HEAP32[$119>>2]|0;
 $120 = (($118) + 12|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($117>>>0)>($121>>>0);
 do {
  if ($122) {
   $123 = $116 >>> 1;
   $124 = (($117) + ($123))|0;
   $125 = (($118) + 4|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = HEAP32[628272>>2]|0;
   HEAP32[$0>>2] = $127;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   $128 = (__Z16realloc_internalPvji10MemLabelIdiPKci($126,$124,16,$$byval_copy1,0,673896,482)|0);
   $129 = HEAP32[654224>>2]|0;
   $130 = HEAP32[$129>>2]|0;
   $131 = (($130) + 4|0);
   HEAP32[$131>>2] = $128;
   $132 = HEAP32[654224>>2]|0;
   $133 = HEAP32[$132>>2]|0;
   $134 = (($133) + 4|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = ($135|0)==(0|0);
   if ($136) {
    __ZL14yy_fatal_errorPKc(674112);
    // unreachable;
   } else {
    $$pre41 = HEAP32[673648>>2]|0;
    $138 = $$pre41;$140 = $135;
    break;
   }
  } else {
   $$phi$trans$insert42 = (($118) + 4|0);
   $$pre43 = HEAP32[$$phi$trans$insert42>>2]|0;
   $138 = $116;$140 = $$pre43;
  }
 } while(0);
 $137 = (($138) + ($18))|0;
 HEAP32[673648>>2] = $137;
 $139 = (($140) + ($137)|0);
 HEAP8[$139>>0] = 0;
 $141 = HEAP32[673648>>2]|0;
 $142 = (($141) + 1)|0;
 $143 = HEAP32[654224>>2]|0;
 $144 = HEAP32[$143>>2]|0;
 $145 = (($144) + 4|0);
 $146 = HEAP32[$145>>2]|0;
 $147 = (($146) + ($142)|0);
 HEAP8[$147>>0] = 0;
 $148 = HEAP32[654224>>2]|0;
 $149 = HEAP32[$148>>2]|0;
 $150 = (($149) + 4|0);
 $151 = HEAP32[$150>>2]|0;
 HEAP32[654200>>2] = $151;
 $$0 = $ret_val$0;
 STACKTOP = sp;return ($$0|0);
}
function __ZL14yy_fatal_errorPKc($msg) {
 $msg = $msg|0;
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[_stderr>>2]|0;
 HEAP32[$vararg_buffer>>2] = $msg;
 (_fprintf(($0|0),(673912|0),($vararg_buffer|0))|0);
 _exit(2);
 // unreachable;
}
function __Z9yyrestartP8_IO_FILE($input_file) {
 $input_file = $input_file|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[654224>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  label = 3;
 } else {
  $2 = HEAP32[$0>>2]|0;
  $phitmp = ($2|0)==(0|0);
  if ($phitmp) {
   label = 3;
  } else {
   $10 = $0;$11 = 0;
   label = 5;
  }
 }
 if ((label|0) == 3) {
  __ZL21yyensure_buffer_stackv();
  $3 = HEAP32[654176>>2]|0;
  $4 = (__Z16yy_create_bufferP8_IO_FILEi($3,16384)|0);
  $5 = HEAP32[654224>>2]|0;
  HEAP32[$5>>2] = $4;
  $$pre = HEAP32[654224>>2]|0;
  $6 = ($$pre|0)==(0|0);
  if ($6) {
   $7 = (___errno_location()|0);
   $8 = HEAP32[$7>>2]|0;
   $38 = 0;$48 = $8;$49 = $7;
  } else {
   $10 = $$pre;$11 = 0;
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $9 = (($10) + ($11<<2)|0);
  $12 = HEAP32[$9>>2]|0;
  $13 = (___errno_location()|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==(0|0);
  if ($15) {
   $38 = 0;$48 = $14;$49 = $13;
  } else {
   $16 = (($12) + 16|0);
   HEAP32[$16>>2] = 0;
   $17 = (($12) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP8[$18>>0] = 0;
   $19 = HEAP32[$17>>2]|0;
   $20 = (($19) + 1|0);
   HEAP8[$20>>0] = 0;
   $21 = HEAP32[$17>>2]|0;
   $22 = (($12) + 8|0);
   HEAP32[$22>>2] = $21;
   $23 = (($12) + 28|0);
   HEAP32[$23>>2] = 1;
   $24 = (($12) + 44|0);
   HEAP32[$24>>2] = 0;
   $25 = HEAP32[654224>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    $29 = 0;
   } else {
    $27 = HEAP32[$25>>2]|0;
    $29 = $27;
   }
   $28 = ($29|0)==($12|0);
   if ($28) {
    $30 = HEAP32[$25>>2]|0;
    $31 = (($30) + 16|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[673648>>2] = $32;
    $33 = (($30) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[654232>>2] = $34;
    HEAP32[654200>>2] = $34;
    $35 = HEAP32[$25>>2]|0;
    $36 = HEAP32[$35>>2]|0;
    HEAP32[654176>>2] = $36;
    $37 = HEAP8[$34>>0]|0;
    HEAP8[654240>>0] = $37;
    $38 = $12;$48 = $14;$49 = $13;
   } else {
    $38 = $12;$48 = $14;$49 = $13;
   }
  }
 }
 HEAP32[$38>>2] = $input_file;
 $39 = (($38) + 40|0);
 HEAP32[$39>>2] = 1;
 $40 = HEAP32[654224>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  $44 = 0;
 } else {
  $42 = HEAP32[$40>>2]|0;
  $44 = $42;
 }
 $43 = ($44|0)==($38|0);
 if (!($43)) {
  $45 = (($38) + 32|0);
  HEAP32[$45>>2] = 1;
  $46 = (($38) + 36|0);
  HEAP32[$46>>2] = 0;
 }
 $47 = (($38) + 24|0);
 HEAP32[$47>>2] = 0;
 HEAP32[$49>>2] = $48;
 $50 = HEAP32[$40>>2]|0;
 $51 = (($50) + 16|0);
 $52 = HEAP32[$51>>2]|0;
 HEAP32[673648>>2] = $52;
 $53 = (($50) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[654232>>2] = $54;
 HEAP32[654200>>2] = $54;
 $55 = HEAP32[$40>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 HEAP32[654176>>2] = $56;
 $57 = HEAP8[$54>>0]|0;
 HEAP8[654240>>0] = $57;
 STACKTOP = sp;return;
}
function __Z14yy_scan_bufferPcj($base,$size) {
 $base = $base|0;
 $size = $size|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($size>>>0)<(2);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($size) + -2)|0;
 $3 = (($base) + ($2)|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($size) + -1)|0;
 $7 = (($base) + ($6)|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $10;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $11 = (__Z15malloc_internaljj10MemLabelIdiPKci(48,16,$$byval_copy,0,673896,478)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  __ZL14yy_fatal_errorPKc(673760);
  // unreachable;
 }
 $13 = (($11) + 12|0);
 HEAP32[$13>>2] = $2;
 $14 = (($11) + 4|0);
 HEAP32[$14>>2] = $base;
 $15 = (($11) + 8|0);
 HEAP32[$15>>2] = $base;
 $16 = (($11) + 20|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$11>>2] = 0;
 $17 = (($11) + 16|0);
 HEAP32[$17>>2] = $2;
 $18 = (($11) + 24|0);
 HEAP32[$18>>2] = 0;
 $19 = (($11) + 28|0);
 HEAP32[$19>>2] = 1;
 $20 = (($11) + 40|0);
 HEAP32[$20>>2] = 0;
 $21 = (($11) + 44|0);
 HEAP32[$21>>2] = 0;
 __ZL21yyensure_buffer_stackv();
 $22 = HEAP32[654224>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $26 = 0;
 } else {
  $24 = HEAP32[$22>>2]|0;
  $26 = $24;
 }
 $25 = ($26|0)==($11|0);
 if ($25) {
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = HEAP32[$22>>2]|0;
 $phitmp$i = ($27|0)==(0|0);
 if ($phitmp$i) {
  $39 = $22;$40 = 0;
 } else {
  $28 = HEAP8[654240>>0]|0;
  $29 = HEAP32[654232>>2]|0;
  HEAP8[$29>>0] = $28;
  $30 = HEAP32[654232>>2]|0;
  $31 = HEAP32[654224>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 8|0);
  HEAP32[$33>>2] = $30;
  $34 = HEAP32[673648>>2]|0;
  $35 = HEAP32[654224>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 16|0);
  HEAP32[$37>>2] = $34;
  $39 = $35;$40 = 0;
 }
 $38 = (($39) + ($40<<2)|0);
 HEAP32[$38>>2] = $11;
 $41 = HEAP32[654224>>2]|0;
 $42 = (($41) + ($40<<2)|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 16|0);
 $45 = HEAP32[$44>>2]|0;
 HEAP32[673648>>2] = $45;
 $46 = (($43) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 HEAP32[654232>>2] = $47;
 HEAP32[654200>>2] = $47;
 $48 = HEAP32[$42>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 HEAP32[654176>>2] = $49;
 $50 = HEAP8[$47>>0]|0;
 HEAP8[654240>>0] = $50;
 $$0 = $11;
 STACKTOP = sp;return ($$0|0);
}
function __Z13yy_scan_bytesPKcj($yybytes,$_yybytes_len) {
 $yybytes = $yybytes|0;
 $_yybytes_len = $_yybytes_len|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($_yybytes_len) + 2)|0;
 $2 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Z15malloc_internaljj10MemLabelIdiPKci($1,16,$$byval_copy,0,673896,478)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZL14yy_fatal_errorPKc(673808);
  // unreachable;
 }
 $5 = ($_yybytes_len|0)==(0);
 if (!($5)) {
  $i$01 = 0;
  while(1) {
   $6 = (($yybytes) + ($i$01)|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = (($3) + ($i$01)|0);
   HEAP8[$8>>0] = $7;
   $9 = (($i$01) + 1)|0;
   $exitcond = ($9|0)==($_yybytes_len|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $9;
   }
  }
 }
 $10 = (($_yybytes_len) + 1)|0;
 $11 = (($3) + ($10)|0);
 HEAP8[$11>>0] = 0;
 $12 = (($3) + ($_yybytes_len)|0);
 HEAP8[$12>>0] = 0;
 $13 = (__Z14yy_scan_bufferPcj($3,$1)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  __ZL14yy_fatal_errorPKc(673856);
  // unreachable;
 } else {
  $15 = (($13) + 20|0);
  HEAP32[$15>>2] = 1;
  STACKTOP = sp;return ($13|0);
 }
 return 0|0;
}
function __Z10SetupLexerPKcj($c,$length) {
 $c = $c|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z13yy_scan_bytesPKcj($c,$length)|0);
 HEAP32[673888>>2] = $0;
 __ZL21yyensure_buffer_stackv();
 $1 = HEAP32[654224>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $5 = $3;
 }
 $4 = ($5|0)==($0|0);
 if ($4) {
  HEAP32[654192>>2] = 1;
  HEAP32[654216>>2] = 1;
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$1>>2]|0;
 $phitmp$i = ($6|0)==(0|0);
 if ($phitmp$i) {
  $18 = $1;$19 = 0;
 } else {
  $7 = HEAP8[654240>>0]|0;
  $8 = HEAP32[654232>>2]|0;
  HEAP8[$8>>0] = $7;
  $9 = HEAP32[654232>>2]|0;
  $10 = HEAP32[654224>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 8|0);
  HEAP32[$12>>2] = $9;
  $13 = HEAP32[673648>>2]|0;
  $14 = HEAP32[654224>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 16|0);
  HEAP32[$16>>2] = $13;
  $18 = $14;$19 = 0;
 }
 $17 = (($18) + ($19<<2)|0);
 HEAP32[$17>>2] = $0;
 $20 = HEAP32[654224>>2]|0;
 $21 = (($20) + ($19<<2)|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[673648>>2] = $24;
 $25 = (($22) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[654232>>2] = $26;
 HEAP32[654200>>2] = $26;
 $27 = HEAP32[$21>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 HEAP32[654176>>2] = $28;
 $29 = HEAP8[$26>>0]|0;
 HEAP8[654240>>0] = $29;
 HEAP32[654192>>2] = 1;
 HEAP32[654216>>2] = 1;
 STACKTOP = sp;return;
}
function __Z13TearDownLexerv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[654224>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 if (1) {
  HEAP32[$1>>2] = 0;
 }
 $5 = (($3) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($3) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[628272>>2]|0;
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy1);
 }
 $11 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $11;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy1);
 STACKTOP = sp;return;
}
function __ZNSt3__15stackIPN9ShaderLab17ParserShaderStateENS_5dequeIS3_NS_9allocatorIS3_EEEEED1Ev($this) {
 $this = $this|0;
 var $$lcssa$i = 0, $$ph$i = 0, $$ph1$i = 0, $$pre$i$i$i$i = 0, $$pre2$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$01$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 10;
 $5 = (($1) + ($4<<2)|0);
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if ($8) {
  $9 = (($this) + 20|0);
  $23 = 0;$32 = $9;$60 = 0;
 } else {
  $10 = HEAP32[$5>>2]|0;
  $11 = $3 & 1023;
  $12 = (($10) + ($11<<2)|0);
  $13 = (($this) + 20|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($3))|0;
  $16 = $15 >>> 10;
  $17 = (($1) + ($16<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $15 & 1023;
  $20 = (($18) + ($19<<2)|0);
  $23 = $20;$32 = $13;$60 = $12;
 }
 $$ph$i = $60;$$ph1$i = $5;
 L5: while(1) {
  $22 = $$ph$i;
  while(1) {
   $21 = ($22|0)==($23|0);
   if ($21) {
    break L5;
   }
   $24 = (($22) + 4|0);
   $25 = HEAP32[$$ph1$i>>2]|0;
   $26 = $24;
   $27 = $25;
   $28 = (($26) - ($27))|0;
   $29 = ($28|0)==(4096);
   if ($29) {
    break;
   } else {
    $22 = $24;
   }
  }
  $30 = (($$ph1$i) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $$ph$i = $31;$$ph1$i = $30;
 }
 HEAP32[$32>>2] = 0;
 $33 = $7;
 $34 = $1;
 $35 = (($33) - ($34))|0;
 $36 = $35 >> 2;
 $37 = ($36>>>0)>(2);
 if ($37) {
  $39 = $1;
  while(1) {
   $38 = HEAP32[$39>>2]|0;
   __ZdlPv($38);
   $40 = HEAP32[$0>>2]|0;
   $41 = (($40) + 4|0);
   HEAP32[$0>>2] = $41;
   $42 = HEAP32[$6>>2]|0;
   $43 = $42;
   $44 = $41;
   $45 = (($43) - ($44))|0;
   $46 = $45 >> 2;
   $47 = ($46>>>0)>(2);
   if ($47) {
    $39 = $41;
   } else {
    $$lcssa$i = $46;
    break;
   }
  }
 } else {
  $$lcssa$i = $36;
 }
 if ((($$lcssa$i|0) == 1)) {
  HEAP32[$2>>2] = 512;
 } else if ((($$lcssa$i|0) == 2)) {
  HEAP32[$2>>2] = 1024;
 }
 $48 = HEAP32[$0>>2]|0;
 $49 = HEAP32[$6>>2]|0;
 $50 = ($48|0)==($49|0);
 if (!($50)) {
  $__i$01$i$i$i$i = $48;
  while(1) {
   $51 = HEAP32[$__i$01$i$i$i$i>>2]|0;
   __ZdlPv($51);
   $52 = (($__i$01$i$i$i$i) + 4|0);
   $53 = ($52|0)==($49|0);
   if ($53) {
    break;
   } else {
    $__i$01$i$i$i$i = $52;
   }
  }
  $$pre$i$i$i$i = HEAP32[$0>>2]|0;
  $$pre2$i$i$i$i = HEAP32[$6>>2]|0;
  $54 = ($$pre2$i$i$i$i|0)==($$pre$i$i$i$i|0);
  if (!($54)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $$pre$i$i$i$i;
   $scevgep$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i) + -4|0);
   $55 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($55)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $56 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 2;
   $57 = $56 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i) + ($57<<2)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
 }
 $58 = HEAP32[$this>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  STACKTOP = sp;return;
 }
 __ZdlPv($58);
 STACKTOP = sp;return;
}
function __Z7yyparsev() {
 var $$ = 0, $$0 = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i2$i$i = 0, $$0$i2$i$i174 = 0, $$0$i2$i$i179 = 0, $$0$i2$i$i33 = 0, $$0$i3$i$i = 0, $$0$i3$i$i175 = 0, $$0$i3$i$i181 = 0, $$0$i3$i$i35 = 0, $$01$i$i$i$i$i = 0, $$011 = 0, $$1 = 0, $$112 = 0, $$2 = 0, $$213 = 0, $$3 = 0, $$314 = 0;
 var $$4 = 0, $$415 = 0, $$byval_copy43 = 0, $$pr = 0, $$pr320 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i268 = 0, $$pre$i$i$i$i$i60 = 0, $$pre$i$i$i$i$i63 = 0, $$pre$i$i$i$i$i70 = 0, $$pre$i$i$i$i$i77 = 0, $$pre$i$i$i$i$i84 = 0, $$pre$i$i$i$i$i91 = 0, $$pre$i$i$i269 = 0, $$pre$i$i$i64 = 0, $$pre$i$i$i71 = 0, $$pre$i$i$i78 = 0;
 var $$pre$i$i$i85 = 0, $$pre$i$i$i92 = 0, $$pre$i169 = 0, $$pre$i173 = 0, $$pre$i176 = 0, $$pre$i22 = 0, $$pre$i30 = 0, $$pre$phi1455Z2D = 0, $$pre$phi1457Z2D = 0, $$pre$phi1461Z2D = 0, $$pre$phi1463Z2D = 0, $$pre$phi1467Z2D = 0, $$pre$phi1469Z2D = 0, $$pre$phi1473Z2D = 0, $$pre$phi1475Z2D = 0, $$pre$phi1479Z2D = 0, $$pre$phi1481Z2D = 0, $$pre$phi1485Z2D = 0, $$pre$phi1487Z2D = 0, $$pre$phi1491Z2D = 0;
 var $$pre$phi1493Z2D = 0, $$pre$phi1497Z2D = 0, $$pre$phi1501Z2D = 0, $$pre$phi1505Z2D = 0, $$pre$phi1523Z2D = 0, $$pre$phiZ2D = 0, $$pre1437 = 0, $$pre1438 = 0, $$pre1439 = 0, $$pre1440 = 0, $$pre1450 = 0, $$pre1458 = 0, $$pre1464 = 0, $$pre1470 = 0, $$pre1476 = 0, $$pre1482 = 0, $$pre1488 = 0, $$pre1494 = 0, $$pre1498 = 0, $$pre1502 = 0;
 var $$pre1506 = 0, $$pre1510 = 0, $$pre1514 = 0, $$pre1518 = 0, $$sum = 0, $$sum20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0;
 var $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0;
 var $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0;
 var $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0;
 var $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0;
 var $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0;
 var $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0;
 var $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0;
 var $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0;
 var $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0;
 var $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0;
 var $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0;
 var $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0;
 var $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0;
 var $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0;
 var $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0;
 var $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = Math_fround(0), $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0;
 var $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0;
 var $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0;
 var $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0;
 var $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0;
 var $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0;
 var $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0;
 var $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0;
 var $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0;
 var $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0;
 var $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0;
 var $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0;
 var $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0;
 var $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0;
 var $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0;
 var $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0;
 var $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0;
 var $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0;
 var $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0;
 var $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0;
 var $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0;
 var $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0;
 var $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0;
 var $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0;
 var $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0;
 var $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0;
 var $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0;
 var $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0;
 var $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0;
 var $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0;
 var $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0;
 var $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0;
 var $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0;
 var $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = Math_fround(0), $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0;
 var $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0;
 var $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0, $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0;
 var $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0;
 var $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0;
 var $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0, $1981 = 0, $1982 = 0;
 var $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $2016 = 0, $2017 = 0;
 var $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0;
 var $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0, $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0, $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0;
 var $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0, $2067 = 0, $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0;
 var $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0;
 var $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0;
 var $2108 = 0, $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0, $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0;
 var $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0, $2130 = 0, $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0, $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0;
 var $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0;
 var $2162 = 0, $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0, $2167 = 0, $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0, $2174 = 0, $2175 = 0, $2176 = 0, $2177 = 0, $2178 = 0, $2179 = 0, $218 = 0;
 var $2180 = 0, $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0, $2185 = 0, $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0, $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0;
 var $2199 = 0, $22 = 0, $220 = 0, $2200 = 0, $2201 = 0, $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0, $2210 = 0, $2211 = 0, $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0;
 var $2216 = 0, $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0, $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0, $2228 = 0, $2229 = 0, $223 = 0, $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0;
 var $2234 = 0, $2235 = 0, $2236 = 0, $2237 = 0, $2238 = 0, $2239 = 0, $224 = 0, $2240 = 0, $2241 = 0, $2242 = 0, $2243 = 0, $2244 = 0, $2245 = 0, $2246 = 0, $2247 = 0, $2248 = 0, $2249 = 0, $225 = 0, $2250 = 0, $2251 = 0;
 var $2252 = 0, $2253 = 0, $2254 = 0, $2255 = 0, $2256 = 0, $2257 = 0, $2258 = 0, $2259 = 0, $226 = 0, $2260 = 0, $2261 = 0, $2262 = 0, $2263 = 0, $2264 = 0, $2265 = 0, $2266 = 0, $2267 = 0, $2268 = 0, $2269 = 0, $227 = 0;
 var $2270 = 0, $2271 = 0, $2272 = 0, $2273 = 0, $2274 = 0, $2275 = 0, $2276 = 0, $2277 = 0, $2278 = 0, $2279 = 0, $228 = 0, $2280 = 0, $2281 = 0, $2282 = 0, $2283 = 0, $2284 = 0, $2285 = 0, $2286 = 0, $2287 = 0, $2288 = 0;
 var $2289 = 0, $229 = 0, $2290 = 0, $2291 = 0, $2292 = 0, $2293 = 0, $2294 = 0, $2295 = 0, $2296 = 0, $2297 = 0, $2298 = 0, $2299 = 0, $23 = 0, $230 = 0, $2300 = 0, $2301 = 0, $2302 = 0, $2303 = 0, $2304 = 0, $2305 = 0;
 var $2306 = 0, $2307 = 0, $2308 = 0, $2309 = 0, $231 = 0, $2310 = 0, $2311 = 0, $2312 = 0, $2313 = 0, $2314 = 0, $2315 = 0, $2316 = 0, $2317 = 0, $2318 = 0, $2319 = 0, $232 = 0, $2320 = 0, $2321 = 0, $2322 = 0, $2323 = 0;
 var $2324 = 0, $2325 = 0, $2326 = 0, $2327 = 0, $2328 = 0, $2329 = 0, $233 = 0, $2330 = 0, $2331 = 0, $2332 = 0, $2333 = 0, $2334 = 0, $2335 = 0, $2336 = 0, $2337 = 0, $2338 = 0, $2339 = 0, $234 = 0, $2340 = 0, $2341 = 0;
 var $2342 = 0, $2343 = 0, $2344 = 0, $2345 = 0, $2346 = 0, $2347 = 0, $2348 = 0, $2349 = 0, $235 = 0, $2350 = 0, $2351 = 0, $2352 = 0, $2353 = 0, $2354 = 0, $2355 = 0, $2356 = 0, $2357 = 0, $2358 = 0, $2359 = 0, $236 = 0;
 var $2360 = 0, $2361 = 0, $2362 = 0, $2363 = 0, $2364 = 0, $2365 = 0, $2366 = 0, $2367 = 0, $2368 = 0, $2369 = 0, $237 = 0, $2370 = 0, $2371 = 0, $2372 = 0, $2373 = 0, $2374 = 0, $2375 = 0, $2376 = 0, $2377 = 0, $2378 = 0;
 var $2379 = 0, $238 = 0, $2380 = 0, $2381 = 0, $2382 = 0, $2383 = 0, $2384 = 0, $2385 = 0, $2386 = 0, $2387 = 0, $2388 = 0, $2389 = 0, $239 = 0, $2390 = 0, $2391 = 0, $2392 = 0, $2393 = 0, $2394 = 0, $2395 = 0, $2396 = 0;
 var $2397 = 0, $2398 = 0, $2399 = 0, $24 = 0, $240 = 0, $2400 = 0, $2401 = 0, $2402 = 0, $2403 = 0, $2404 = 0, $2405 = 0, $2406 = 0, $2407 = 0, $2408 = 0, $2409 = 0, $241 = 0, $2410 = 0, $2411 = 0, $2412 = 0, $2413 = 0;
 var $2414 = 0, $2415 = 0, $2416 = 0, $2417 = 0, $2418 = 0, $2419 = 0, $242 = 0, $2420 = 0, $2421 = 0, $2422 = 0, $2423 = 0, $2424 = 0, $2425 = 0, $2426 = 0, $2427 = 0, $2428 = 0, $2429 = 0, $243 = 0, $2430 = 0, $2431 = 0;
 var $2432 = 0, $2433 = 0, $2434 = 0, $2435 = 0, $2436 = 0, $2437 = 0, $2438 = 0, $2439 = 0, $244 = 0, $2440 = 0, $2441 = 0, $2442 = 0, $2443 = 0, $2444 = 0, $2445 = 0, $2446 = 0, $2447 = 0, $2448 = 0, $2449 = 0, $245 = 0;
 var $2450 = 0, $2451 = 0, $2452 = 0, $2453 = 0, $2454 = 0, $2455 = 0, $2456 = 0, $2457 = 0, $2458 = 0, $2459 = 0, $246 = 0, $2460 = 0, $2461 = 0, $2462 = 0, $2463 = 0, $2464 = 0, $2465 = 0, $2466 = 0, $2467 = 0, $2468 = 0;
 var $2469 = 0, $247 = 0, $2470 = 0, $2471 = 0, $2472 = 0, $2473 = 0, $2474 = 0, $2475 = 0, $2476 = 0, $2477 = 0, $2478 = 0, $2479 = 0, $248 = 0, $2480 = 0, $2481 = 0, $2482 = 0, $2483 = 0, $2484 = 0, $2485 = 0, $2486 = 0;
 var $2487 = 0, $2488 = 0, $2489 = 0, $249 = 0, $2490 = 0, $2491 = 0, $2492 = 0, $2493 = 0, $2494 = 0, $2495 = 0, $2496 = 0, $2497 = 0, $2498 = 0, $2499 = 0, $25 = 0, $250 = 0, $2500 = 0, $2501 = 0, $2502 = 0, $2503 = 0;
 var $2504 = 0, $2505 = 0, $2506 = 0, $2507 = 0, $2508 = 0, $2509 = 0, $251 = 0, $2510 = 0, $2511 = 0, $2512 = 0, $2513 = 0, $2514 = 0, $2515 = 0, $2516 = 0, $2517 = 0, $2518 = 0, $2519 = 0, $252 = 0, $2520 = 0, $2521 = 0;
 var $2522 = 0, $2523 = 0, $2524 = 0, $2525 = 0, $2526 = 0, $2527 = 0, $2528 = 0, $2529 = 0, $253 = 0, $2530 = 0, $2531 = 0, $2532 = 0, $2533 = 0, $2534 = 0, $2535 = 0, $2536 = 0, $2537 = 0, $2538 = 0, $2539 = 0, $254 = 0;
 var $2540 = 0, $2541 = 0, $2542 = 0, $2543 = 0, $2544 = 0, $2545 = 0, $2546 = 0, $2547 = 0, $2548 = 0, $2549 = 0, $255 = 0, $2550 = 0, $2551 = 0, $2552 = 0, $2553 = 0, $2554 = 0, $2555 = 0, $2556 = 0, $2557 = 0, $2558 = 0;
 var $2559 = 0, $256 = 0, $2560 = 0, $2561 = 0, $2562 = 0, $2563 = 0, $2564 = 0, $2565 = 0, $2566 = 0, $2567 = 0, $2568 = 0, $2569 = 0, $257 = 0, $2570 = 0, $2571 = 0, $2572 = 0, $2573 = 0, $2574 = 0, $2575 = 0, $2576 = 0;
 var $2577 = 0, $2578 = 0, $2579 = 0, $258 = 0, $2580 = 0, $2581 = 0, $2582 = 0, $2583 = 0, $2584 = 0, $2585 = 0, $2586 = 0, $2587 = 0, $2588 = 0, $2589 = 0, $259 = 0, $2590 = 0, $2591 = 0, $2592 = 0, $2593 = 0, $2594 = 0;
 var $2595 = 0, $2596 = 0, $2597 = 0, $2598 = 0, $2599 = 0, $26 = 0, $260 = 0, $2600 = 0, $2601 = 0, $2602 = 0, $2603 = 0, $2604 = 0, $2605 = 0, $2606 = 0, $2607 = 0, $2608 = Math_fround(0), $2609 = 0, $261 = 0, $2610 = 0, $2611 = 0;
 var $2612 = 0, $2613 = 0, $2614 = 0, $2615 = 0, $2616 = 0, $2617 = 0, $2618 = 0, $2619 = 0, $262 = 0, $2620 = 0, $2621 = 0, $2622 = 0, $2623 = 0, $2624 = 0, $2625 = 0, $2626 = 0, $2627 = 0, $2628 = 0, $2629 = 0, $263 = 0;
 var $2630 = 0, $2631 = 0, $2632 = 0, $2633 = 0, $2634 = 0, $2635 = 0, $2636 = 0, $2637 = 0, $2638 = 0, $2639 = 0, $264 = 0, $2640 = 0, $2641 = 0, $2642 = Math_fround(0), $2643 = 0, $2644 = 0, $2645 = 0, $2646 = 0, $2647 = 0, $2648 = 0;
 var $2649 = 0, $265 = 0, $2650 = 0, $2651 = 0, $2652 = 0, $2653 = 0, $2654 = 0, $2655 = 0, $2656 = 0, $2657 = 0, $2658 = 0, $2659 = 0, $266 = 0, $2660 = 0, $2661 = 0, $2662 = 0, $2663 = 0, $2664 = 0, $2665 = 0, $2666 = 0;
 var $2667 = 0, $2668 = 0, $2669 = 0, $267 = 0, $2670 = 0, $2671 = 0, $2672 = 0, $2673 = 0, $2674 = 0, $2675 = 0, $2676 = Math_fround(0), $2677 = 0, $2678 = Math_fround(0), $2679 = 0, $268 = 0, $2680 = 0, $2681 = 0, $2682 = 0, $2683 = 0, $2684 = 0;
 var $2685 = 0, $2686 = 0, $2687 = 0, $2688 = 0, $2689 = 0, $269 = 0, $2690 = 0, $2691 = 0, $2692 = 0, $2693 = 0, $2694 = 0, $2695 = 0, $2696 = 0, $2697 = 0, $2698 = 0, $2699 = 0, $27 = 0, $270 = 0, $2700 = 0, $2701 = 0;
 var $2702 = 0, $2703 = 0, $2704 = 0, $2705 = 0, $2706 = 0, $2707 = 0, $2708 = 0, $2709 = 0, $271 = 0, $2710 = 0, $2711 = 0, $2712 = 0, $2713 = Math_fround(0), $2714 = 0, $2715 = 0, $2716 = 0, $2717 = 0, $2718 = 0, $2719 = 0, $272 = 0;
 var $2720 = 0, $2721 = 0, $2722 = 0, $2723 = 0, $2724 = 0, $2725 = 0, $2726 = 0, $2727 = 0, $2728 = 0, $2729 = 0, $273 = 0, $2730 = 0, $2731 = 0, $2732 = 0, $2733 = 0, $2734 = 0, $2735 = 0, $2736 = 0, $2737 = 0, $2738 = 0;
 var $2739 = 0, $274 = 0, $2740 = 0, $2741 = 0, $2742 = 0, $2743 = 0, $2744 = 0, $2745 = 0, $2746 = 0, $2747 = Math_fround(0), $2748 = 0, $2749 = Math_fround(0), $275 = 0, $2750 = 0, $2751 = 0, $2752 = 0, $2753 = 0, $2754 = 0, $2755 = 0, $2756 = 0;
 var $2757 = 0, $2758 = 0, $2759 = 0, $276 = 0, $2760 = 0, $2761 = 0, $2762 = 0, $2763 = 0, $2764 = 0, $2765 = 0, $2766 = 0, $2767 = 0, $2768 = 0, $2769 = 0, $277 = 0, $2770 = 0, $2771 = 0, $2772 = 0, $2773 = 0, $2774 = 0;
 var $2775 = 0, $2776 = 0, $2777 = 0, $2778 = 0, $2779 = 0, $278 = 0, $2780 = 0, $2781 = 0, $2782 = 0, $2783 = 0, $2784 = Math_fround(0), $2785 = 0, $2786 = 0, $2787 = 0, $2788 = 0, $2789 = 0, $279 = 0, $2790 = 0, $2791 = 0, $2792 = 0;
 var $2793 = 0, $2794 = 0, $2795 = 0, $2796 = 0, $2797 = 0, $2798 = 0, $2799 = 0, $28 = 0, $280 = 0, $2800 = 0, $2801 = 0, $2802 = 0, $2803 = 0, $2804 = 0, $2805 = 0, $2806 = 0, $2807 = 0, $2808 = 0, $2809 = 0, $281 = 0;
 var $2810 = 0, $2811 = 0, $2812 = 0, $2813 = 0, $2814 = 0, $2815 = 0, $2816 = 0, $2817 = 0, $2818 = Math_fround(0), $2819 = 0, $282 = 0, $2820 = Math_fround(0), $2821 = 0, $2822 = 0, $2823 = 0, $2824 = 0, $2825 = 0, $2826 = 0, $2827 = 0, $2828 = 0;
 var $2829 = 0, $283 = 0, $2830 = 0, $2831 = 0, $2832 = 0, $2833 = 0, $2834 = 0, $2835 = 0, $2836 = 0, $2837 = 0, $2838 = 0, $2839 = 0, $284 = 0, $2840 = 0, $2841 = 0, $2842 = 0, $2843 = 0, $2844 = 0, $2845 = 0, $2846 = 0;
 var $2847 = 0, $2848 = 0, $2849 = 0, $285 = 0, $2850 = 0, $2851 = 0, $2852 = 0, $2853 = 0, $2854 = 0, $2855 = Math_fround(0), $2856 = 0, $2857 = 0, $2858 = 0, $2859 = 0, $286 = 0, $2860 = 0, $2861 = 0, $2862 = 0, $2863 = 0, $2864 = 0;
 var $2865 = 0, $2866 = 0, $2867 = 0, $2868 = 0, $2869 = 0, $287 = 0, $2870 = 0, $2871 = 0, $2872 = 0, $2873 = 0, $2874 = 0, $2875 = 0, $2876 = 0, $2877 = 0, $2878 = 0, $2879 = 0, $288 = 0, $2880 = 0, $2881 = 0, $2882 = 0;
 var $2883 = 0, $2884 = 0, $2885 = 0, $2886 = 0, $2887 = 0, $2888 = 0, $2889 = Math_fround(0), $289 = 0, $2890 = 0, $2891 = Math_fround(0), $2892 = 0, $2893 = 0, $2894 = 0, $2895 = 0, $2896 = 0, $2897 = 0, $2898 = 0, $2899 = 0, $29 = 0, $290 = 0;
 var $2900 = 0, $2901 = 0, $2902 = 0, $2903 = 0, $2904 = 0, $2905 = 0, $2906 = 0, $2907 = 0, $2908 = 0, $2909 = 0, $291 = 0, $2910 = 0, $2911 = 0, $2912 = 0, $2913 = 0, $2914 = 0, $2915 = 0, $2916 = 0, $2917 = 0, $2918 = 0;
 var $2919 = 0, $292 = 0, $2920 = 0, $2921 = 0, $2922 = 0, $2923 = 0, $2924 = 0, $2925 = 0, $2926 = Math_fround(0), $2927 = 0, $2928 = 0, $2929 = 0, $293 = 0, $2930 = 0, $2931 = 0, $2932 = 0, $2933 = 0, $2934 = 0, $2935 = 0, $2936 = 0;
 var $2937 = 0, $2938 = 0, $2939 = 0, $294 = 0, $2940 = 0, $2941 = 0, $2942 = 0, $2943 = 0, $2944 = 0, $2945 = 0, $2946 = 0, $2947 = 0, $2948 = 0, $2949 = 0, $295 = 0, $2950 = 0, $2951 = 0, $2952 = 0, $2953 = 0, $2954 = 0;
 var $2955 = 0, $2956 = 0, $2957 = 0, $2958 = 0, $2959 = 0, $296 = 0, $2960 = Math_fround(0), $2961 = 0, $2962 = Math_fround(0), $2963 = 0, $2964 = 0, $2965 = 0, $2966 = 0, $2967 = 0, $2968 = 0, $2969 = 0, $297 = 0, $2970 = 0, $2971 = 0, $2972 = 0;
 var $2973 = 0, $2974 = 0, $2975 = 0, $2976 = 0, $2977 = 0, $2978 = 0, $2979 = 0, $298 = 0, $2980 = 0, $2981 = 0, $2982 = 0, $2983 = 0, $2984 = 0, $2985 = 0, $2986 = 0, $2987 = 0, $2988 = 0, $2989 = 0, $299 = 0, $2990 = 0;
 var $2991 = 0, $2992 = 0, $2993 = 0, $2994 = 0, $2995 = 0, $2996 = 0, $2997 = Math_fround(0), $2998 = 0, $2999 = 0, $3 = 0, $30 = 0, $300 = 0, $3000 = 0, $3001 = 0, $3002 = 0, $3003 = 0, $3004 = 0, $3005 = 0, $3006 = 0, $3007 = 0;
 var $3008 = 0, $3009 = 0, $301 = 0, $3010 = 0, $3011 = 0, $3012 = 0, $3013 = 0, $3014 = 0, $3015 = 0, $3016 = 0, $3017 = 0, $3018 = 0, $3019 = 0, $302 = 0, $3020 = 0, $3021 = 0, $3022 = 0, $3023 = 0, $3024 = 0, $3025 = 0;
 var $3026 = 0, $3027 = 0, $3028 = 0, $3029 = 0, $303 = 0, $3030 = 0, $3031 = Math_fround(0), $3032 = 0, $3033 = 0, $3034 = 0, $3035 = 0, $3036 = 0, $3037 = 0, $3038 = 0, $3039 = 0, $304 = 0, $3040 = 0, $3041 = 0, $3042 = 0, $3043 = 0;
 var $3044 = 0, $3045 = Math_fround(0), $3046 = 0, $3047 = 0, $3048 = 0, $3049 = 0, $305 = 0, $3050 = 0, $3051 = 0, $3052 = 0, $3053 = 0, $3054 = 0, $3055 = 0, $3056 = 0, $3057 = 0, $3058 = 0, $3059 = 0, $306 = 0, $3060 = 0, $3061 = 0;
 var $3062 = 0, $3063 = 0, $3064 = 0, $3065 = 0, $3066 = 0, $3067 = 0, $3068 = Math_fround(0), $3069 = 0, $307 = 0, $3070 = 0, $3071 = 0, $3072 = 0, $3073 = 0, $3074 = 0, $3075 = 0, $3076 = 0, $3077 = 0, $3078 = 0, $3079 = 0, $308 = 0;
 var $3080 = 0, $3081 = 0, $3082 = 0, $3083 = 0, $3084 = 0, $3085 = 0, $3086 = 0, $3087 = 0, $3088 = 0, $3089 = 0, $309 = 0, $3090 = 0, $3091 = 0, $3092 = 0, $3093 = 0, $3094 = 0, $3095 = 0, $3096 = 0, $3097 = 0, $3098 = 0;
 var $3099 = 0, $31 = 0, $310 = 0, $3100 = 0, $3101 = 0, $3102 = Math_fround(0), $3103 = 0, $3104 = 0, $3105 = 0, $3106 = 0, $3107 = 0, $3108 = 0, $3109 = 0, $311 = 0, $3110 = 0, $3111 = 0, $3112 = 0, $3113 = 0, $3114 = 0, $3115 = 0;
 var $3116 = Math_fround(0), $3117 = 0, $3118 = 0, $3119 = 0, $312 = 0, $3120 = 0, $3121 = 0, $3122 = 0, $3123 = 0, $3124 = 0, $3125 = 0, $3126 = 0, $3127 = 0, $3128 = 0, $3129 = 0, $313 = 0, $3130 = 0, $3131 = 0, $3132 = 0, $3133 = 0;
 var $3134 = 0, $3135 = 0, $3136 = 0, $3137 = 0, $3138 = 0, $3139 = Math_fround(0), $314 = 0, $3140 = 0, $3141 = 0, $3142 = 0, $3143 = 0, $3144 = 0, $3145 = Math_fround(0), $3146 = 0, $3147 = 0, $3148 = 0, $3149 = 0, $315 = 0, $3150 = 0, $3151 = 0;
 var $3152 = 0, $3153 = 0, $3154 = 0, $3155 = 0, $3156 = Math_fround(0), $3157 = 0, $3158 = 0, $3159 = 0, $316 = 0, $3160 = 0, $3161 = 0, $3162 = 0, $3163 = 0, $3164 = 0, $3165 = 0, $3166 = 0, $3167 = 0, $3168 = 0, $3169 = 0, $317 = 0;
 var $3170 = 0, $3171 = 0, $3172 = 0, $3173 = 0, $3174 = 0, $3175 = 0, $3176 = 0, $3177 = 0, $3178 = 0, $3179 = 0, $318 = 0, $3180 = 0, $3181 = 0, $3182 = 0, $3183 = 0, $3184 = 0, $3185 = 0, $3186 = 0, $3187 = 0, $3188 = 0;
 var $3189 = 0, $319 = 0, $3190 = 0, $3191 = 0, $3192 = 0, $3193 = 0, $3194 = 0, $3195 = 0, $3196 = 0, $3197 = 0, $3198 = 0, $3199 = 0, $32 = 0, $320 = 0, $3200 = 0, $3201 = 0, $3202 = 0, $3203 = 0, $3204 = 0, $3205 = 0;
 var $3206 = 0, $3207 = 0, $3208 = 0, $3209 = Math_fround(0), $321 = 0, $3210 = 0, $3211 = 0, $3212 = 0, $3213 = 0, $3214 = 0, $3215 = 0, $3216 = 0, $3217 = 0, $3218 = 0, $3219 = 0, $322 = 0, $3220 = Math_fround(0), $3221 = 0, $3222 = 0, $3223 = 0;
 var $3224 = 0, $3225 = 0, $3226 = 0, $3227 = 0, $3228 = 0, $3229 = 0, $323 = 0, $3230 = 0, $3231 = Math_fround(0), $3232 = 0, $3233 = 0, $3234 = 0, $3235 = 0, $3236 = 0, $3237 = 0, $3238 = 0, $3239 = 0, $324 = 0, $3240 = 0, $3241 = 0;
 var $3242 = 0, $3243 = 0, $3244 = 0, $3245 = 0, $3246 = 0, $3247 = 0, $3248 = 0, $3249 = 0, $325 = 0, $3250 = 0, $3251 = 0, $3252 = 0, $3253 = 0, $3254 = 0, $3255 = 0, $3256 = 0, $3257 = 0, $3258 = 0, $3259 = 0, $326 = 0;
 var $3260 = 0, $3261 = 0, $3262 = 0, $3263 = 0, $3264 = 0, $3265 = 0, $3266 = 0, $3267 = 0, $3268 = 0, $3269 = 0, $327 = 0, $3270 = 0, $3271 = 0, $3272 = 0, $3273 = 0, $3274 = 0, $3275 = 0, $3276 = 0, $3277 = 0, $3278 = 0;
 var $3279 = 0, $328 = 0, $3280 = 0, $3281 = 0, $3282 = 0, $3283 = 0, $3284 = 0, $3285 = 0, $3286 = 0, $3287 = 0, $3288 = 0, $3289 = 0, $329 = 0, $3290 = 0, $3291 = 0, $3292 = 0, $3293 = 0, $3294 = 0, $3295 = 0, $3296 = 0;
 var $3297 = 0, $3298 = 0, $3299 = 0, $33 = 0, $330 = 0, $3300 = 0, $3301 = 0, $3302 = 0, $3303 = 0, $3304 = 0, $3305 = 0, $3306 = 0, $3307 = 0, $3308 = 0, $3309 = 0, $331 = 0, $3310 = 0, $3311 = 0, $3312 = 0, $3313 = 0;
 var $3314 = 0, $3315 = 0, $3316 = 0, $3317 = 0, $3318 = 0, $3319 = 0, $332 = 0, $3320 = 0, $3321 = 0, $3322 = 0, $3323 = 0, $3324 = 0, $3325 = 0, $3326 = 0, $3327 = 0, $3328 = 0, $3329 = 0, $333 = 0, $3330 = 0, $3331 = 0;
 var $3332 = 0, $3333 = 0, $3334 = 0, $3335 = 0, $3336 = 0, $3337 = 0, $3338 = 0, $3339 = 0, $334 = 0, $3340 = 0, $3341 = 0, $3342 = 0, $3343 = 0, $3344 = 0, $3345 = 0, $3346 = 0, $3347 = 0, $3348 = 0, $3349 = 0, $335 = 0;
 var $3350 = 0, $3351 = 0, $3352 = 0, $3353 = 0, $3354 = 0, $3355 = 0, $3356 = 0, $3357 = 0, $3358 = 0, $3359 = 0, $336 = 0, $3360 = 0, $3361 = 0, $3362 = 0, $3363 = 0, $3364 = 0, $3365 = 0, $3366 = 0, $3367 = 0, $3368 = 0;
 var $3369 = 0, $337 = 0, $3370 = 0, $3371 = 0, $3372 = 0, $3373 = 0, $3374 = 0, $3375 = 0, $3376 = 0, $3377 = 0, $3378 = 0, $3379 = 0, $338 = 0, $3380 = 0, $3381 = 0, $3382 = 0, $3383 = 0, $3384 = 0, $3385 = 0, $3386 = 0;
 var $3387 = 0, $3388 = 0, $3389 = 0, $339 = 0, $3390 = 0, $3391 = 0, $3392 = 0, $3393 = 0, $3394 = 0, $3395 = 0, $3396 = 0, $3397 = 0, $3398 = 0, $3399 = 0, $34 = 0, $340 = 0, $3400 = 0, $3401 = 0, $3402 = 0, $3403 = 0;
 var $3404 = 0, $3405 = 0, $3406 = 0, $3407 = 0, $3408 = 0, $3409 = 0, $341 = 0, $3410 = 0, $3411 = 0, $3412 = 0, $3413 = 0, $3414 = 0, $3415 = 0, $3416 = 0, $3417 = 0, $3418 = 0, $3419 = 0, $342 = 0, $3420 = 0, $3421 = 0;
 var $3422 = 0, $3423 = 0, $3424 = 0, $3425 = 0, $3426 = 0, $3427 = 0, $3428 = 0, $3429 = 0, $343 = 0, $3430 = 0, $3431 = 0, $3432 = 0, $3433 = 0, $3434 = 0, $3435 = 0, $3436 = 0, $3437 = 0, $3438 = 0, $3439 = 0, $344 = 0;
 var $3440 = 0, $3441 = 0, $3442 = 0, $3443 = 0, $3444 = 0, $3445 = 0, $3446 = 0, $3447 = 0, $3448 = 0, $3449 = 0, $345 = 0, $3450 = 0, $3451 = 0, $3452 = 0, $3453 = 0, $3454 = 0, $3455 = 0, $3456 = 0, $3457 = 0, $3458 = 0;
 var $3459 = 0, $346 = 0, $3460 = 0, $3461 = 0, $3462 = 0, $3463 = 0, $3464 = 0, $3465 = 0, $3466 = 0, $3467 = 0, $3468 = 0, $3469 = 0, $347 = 0, $3470 = 0, $3471 = 0, $3472 = 0, $3473 = 0, $3474 = 0, $3475 = 0, $3476 = 0;
 var $3477 = 0, $3478 = 0, $3479 = 0, $348 = 0, $3480 = 0, $3481 = 0, $3482 = 0, $3483 = 0, $3484 = 0, $3485 = 0, $3486 = 0, $3487 = 0, $3488 = 0, $3489 = 0, $349 = 0, $3490 = 0, $3491 = 0, $3492 = 0, $3493 = 0, $3494 = 0;
 var $3495 = 0, $3496 = 0, $3497 = 0, $3498 = 0, $3499 = 0, $35 = 0, $350 = 0, $3500 = 0, $3501 = 0, $3502 = 0, $3503 = 0, $3504 = 0, $3505 = 0, $3506 = 0, $3507 = 0, $3508 = 0, $3509 = 0, $351 = 0, $3510 = 0, $3511 = 0;
 var $3512 = 0, $3513 = 0, $3514 = 0, $3515 = 0, $3516 = 0, $3517 = 0, $3518 = 0, $3519 = 0, $352 = 0, $3520 = 0, $3521 = 0, $3522 = 0, $3523 = Math_fround(0), $3524 = 0, $3525 = 0, $3526 = 0, $3527 = 0, $3528 = 0, $3529 = 0, $353 = 0;
 var $3530 = 0, $3531 = 0, $3532 = 0, $3533 = 0, $3534 = 0, $3535 = 0, $3536 = 0, $3537 = 0, $3538 = 0, $3539 = 0, $354 = 0, $3540 = 0, $3541 = 0, $3542 = 0, $3543 = 0, $3544 = 0, $3545 = Math_fround(0), $3546 = 0, $3547 = 0, $3548 = 0;
 var $3549 = 0, $355 = 0, $3550 = 0, $3551 = 0, $3552 = 0, $3553 = 0, $3554 = 0, $3555 = 0, $3556 = 0, $3557 = 0, $3558 = Math_fround(0), $3559 = 0, $356 = 0, $3560 = 0, $3561 = 0, $3562 = 0, $3563 = 0, $3564 = 0, $3565 = 0, $3566 = 0;
 var $3567 = 0, $3568 = 0, $3569 = 0, $357 = 0, $3570 = 0, $3571 = Math_fround(0), $3572 = 0, $3573 = 0, $3574 = 0, $3575 = 0, $3576 = 0, $3577 = 0, $3578 = 0, $3579 = 0, $358 = 0, $3580 = 0, $3581 = 0, $3582 = 0, $3583 = 0, $3584 = 0;
 var $3585 = 0, $3586 = Math_fround(0), $3587 = 0, $3588 = 0, $3589 = 0, $359 = 0, $3590 = 0, $3591 = 0, $3592 = 0, $3593 = 0, $3594 = 0, $3595 = 0, $3596 = 0, $3597 = 0, $3598 = 0, $3599 = Math_fround(0), $36 = 0, $360 = 0, $3600 = 0, $3601 = 0;
 var $3602 = 0, $3603 = 0, $3604 = 0, $3605 = 0, $3606 = 0, $3607 = 0, $3608 = 0, $3609 = 0, $361 = 0, $3610 = 0, $3611 = 0, $3612 = Math_fround(0), $3613 = 0, $3614 = 0, $3615 = 0, $3616 = 0, $3617 = 0, $3618 = 0, $3619 = 0, $362 = 0;
 var $3620 = 0, $3621 = 0, $3622 = 0, $3623 = 0, $3624 = 0, $3625 = 0, $3626 = 0, $3627 = 0, $3628 = 0, $3629 = 0, $363 = 0, $3630 = 0, $3631 = 0, $3632 = 0, $3633 = 0, $3634 = 0, $3635 = 0, $3636 = 0, $3637 = 0, $3638 = 0;
 var $3639 = 0, $364 = 0, $3640 = 0, $3641 = 0, $3642 = 0, $3643 = 0, $3644 = 0, $3645 = 0, $3646 = 0, $3647 = 0, $3648 = 0, $3649 = 0, $365 = 0, $3650 = 0, $3651 = 0, $3652 = 0, $3653 = 0, $3654 = 0, $3655 = 0, $3656 = 0;
 var $3657 = 0, $3658 = 0, $3659 = 0, $366 = 0, $3660 = 0, $3661 = 0, $3662 = 0, $3663 = 0, $3664 = 0, $3665 = 0, $3666 = 0, $3667 = 0, $3668 = 0, $3669 = 0, $367 = 0, $3670 = 0, $3671 = 0, $3672 = 0, $3673 = 0, $3674 = 0;
 var $3675 = 0, $3676 = 0, $3677 = 0, $3678 = 0, $3679 = 0, $368 = 0, $3680 = 0, $3681 = 0, $3682 = 0, $3683 = 0, $3684 = 0, $3685 = 0, $3686 = 0, $3687 = 0, $3688 = 0, $3689 = 0, $369 = 0, $3690 = 0, $3691 = 0, $3692 = 0;
 var $3693 = 0, $3694 = 0, $3695 = 0, $3696 = 0, $3697 = 0, $3698 = 0, $3699 = 0, $37 = 0, $370 = 0, $3700 = 0, $3701 = 0, $3702 = 0, $3703 = 0, $3704 = 0, $3705 = 0, $3706 = 0, $3707 = 0, $3708 = 0, $3709 = 0, $371 = 0;
 var $3710 = 0, $3711 = 0, $3712 = 0, $3713 = 0, $3714 = 0, $3715 = 0, $3716 = 0, $3717 = 0, $3718 = 0, $3719 = 0, $372 = 0, $3720 = 0, $3721 = 0, $3722 = 0, $3723 = 0, $3724 = 0, $3725 = 0, $3726 = 0, $3727 = 0, $3728 = 0;
 var $3729 = 0, $373 = 0, $3730 = 0, $3731 = 0, $3732 = 0, $3733 = 0, $3734 = 0, $3735 = 0, $3736 = 0, $3737 = 0, $3738 = 0, $3739 = 0, $374 = 0, $3740 = 0, $3741 = 0, $3742 = 0, $3743 = 0, $3744 = 0, $3745 = 0, $3746 = 0;
 var $3747 = 0, $3748 = 0, $3749 = 0, $375 = 0, $3750 = 0, $3751 = 0, $3752 = 0, $3753 = 0, $3754 = 0, $3755 = 0, $3756 = 0, $3757 = 0, $3758 = 0, $3759 = 0, $376 = 0, $3760 = 0, $3761 = 0, $3762 = 0, $3763 = 0, $3764 = 0;
 var $3765 = 0, $3766 = 0, $3767 = 0, $3768 = 0, $3769 = 0, $377 = 0, $3770 = Math_fround(0), $3771 = 0, $3772 = Math_fround(0), $3773 = 0, $3774 = Math_fround(0), $3775 = 0, $3776 = Math_fround(0), $3777 = 0, $3778 = 0, $3779 = 0, $378 = 0, $3780 = 0, $3781 = 0, $3782 = Math_fround(0);
 var $3783 = 0, $3784 = Math_fround(0), $3785 = 0, $3786 = Math_fround(0), $3787 = 0, $3788 = 0, $3789 = 0, $379 = 0, $3790 = 0, $3791 = 0, $3792 = 0, $3793 = 0, $3794 = 0, $3795 = 0, $3796 = 0, $3797 = 0, $3798 = 0, $3799 = 0, $38 = 0, $380 = 0;
 var $3800 = 0, $3801 = 0, $3802 = 0, $3803 = 0, $3804 = 0, $3805 = 0, $3806 = 0, $3807 = 0, $3808 = 0, $3809 = 0, $381 = 0, $3810 = 0, $3811 = 0, $3812 = 0, $3813 = 0, $3814 = 0, $3815 = 0, $3816 = 0, $3817 = 0, $3818 = 0;
 var $3819 = 0, $382 = 0, $3820 = 0, $3821 = 0, $3822 = 0, $3823 = 0, $3824 = 0, $3825 = 0, $3826 = 0, $3827 = 0, $3828 = 0, $3829 = 0, $383 = 0, $3830 = 0, $3831 = 0, $3832 = 0, $3833 = 0, $3834 = 0, $3835 = 0, $3836 = 0;
 var $3837 = 0, $3838 = 0, $3839 = 0, $384 = 0, $3840 = 0, $3841 = 0, $3842 = 0, $3843 = 0, $3844 = 0, $3845 = 0, $3846 = 0, $3847 = 0, $3848 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0;
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = Math_fround(0), $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0;
 var $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = Math_fround(0), $874 = 0, $875 = Math_fround(0), $876 = 0, $877 = Math_fround(0);
 var $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0;
 var $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0;
 var $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0;
 var $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0;
 var $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0;
 var $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0;
 var $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i40 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0;
 var $__p$0$i$i$i$i$i101 = 0, $__p$0$i$i$i$i$i277 = 0, $__p$0$i$i$i108 = 0, $__p$0$i$i$i113 = 0, $__p$0$i$i$i118 = 0, $__p$0$i$i$i121 = 0, $__p$0$i$i$i130 = 0, $__p$0$i$i$i133 = 0, $__p$0$i$i$i142 = 0, $__p$0$i$i$i187 = 0, $__p$0$i$i$i192 = 0, $__p$0$i$i$i197 = 0, $__p$0$i$i$i2$i$i = 0, $__p$0$i$i$i202 = 0, $__p$0$i$i$i207 = 0, $__p$0$i$i$i212 = 0, $__p$0$i$i$i217 = 0, $__p$0$i$i$i222 = 0, $__p$0$i$i$i227 = 0, $__p$0$i$i$i232 = 0;
 var $__p$0$i$i$i237 = 0, $__p$0$i$i$i242 = 0, $__p$0$i$i$i247 = 0, $__p$0$i$i$i252 = 0, $__p$0$i$i$i257 = 0, $__p$0$i$i$i262 = 0, $__p$0$i$i$i274 = 0, $__p$0$i$i$i55 = 0, $__p$0$i$i$i98 = 0, $lpad$phi$index = 0, $lpad$phi$index27 = 0, $lpad$phi329$index = 0, $lpad$phi329$index22 = 0, $lpad$phi334$index = 0, $lpad$phi334$index17 = 0, $lpad$phi339$index = 0, $lpad$phi339$index12 = 0, $lpad$phi344$index = 0, $lpad$phi344$index7 = 0, $lpad$phi349$index = 0;
 var $lpad$phi349$index2 = 0, $not$ = 0, $phitmp$i$i = 0, $phitmp$i$i147 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i41 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i45 = 0, $scevgep810 = 0, $t$0321 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i43 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i44 = 0, $yyresult$0 = 0, $yyss$0 = 0, $yyss$1 = 0, $yyss$3 = 0, $yyssa = 0, $yyssp$0 = 0;
 var $yyssp$1 = 0, $yyssp$2 = 0, $yystacksize$0 = 0, $yystacksize$1 = 0, $yystate$0 = 0, $yystate$1 = 0, $yytoken$2 = 0, $yyval$sroa$0$0 = 0, $yyvs$0 = 0, $yyvs$1 = 0, $yyvsa = 0, $yyvsp$0 = 0, $yyvsp$1 = 0, $yyvsp$2 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1744|0;
 $$byval_copy43 = sp + 8|0;
 $0 = sp + 1316|0;
 $1 = sp + 1304|0;
 $2 = sp;
 $yyssa = sp + 1344|0;
 $yyvsa = sp + 504|0;
 $3 = sp + 480|0;
 $4 = sp + 464|0;
 $5 = sp + 452|0;
 $6 = sp + 440|0;
 $7 = sp + 428|0;
 $8 = sp + 416|0;
 $9 = sp + 404|0;
 $10 = sp + 392|0;
 $11 = sp + 380|0;
 $12 = sp + 376|0;
 $13 = sp + 364|0;
 $14 = sp + 352|0;
 $15 = sp + 348|0;
 $16 = sp + 336|0;
 $17 = sp + 324|0;
 $18 = sp + 312|0;
 $19 = sp + 300|0;
 $20 = sp + 288|0;
 $21 = sp + 1328|0;
 $22 = sp + 132|0;
 $23 = sp + 108|0;
 $24 = sp + 96|0;
 $25 = sp + 84|0;
 $26 = sp + 72|0;
 $27 = sp + 120|0;
 $28 = sp + 36|0;
 $29 = sp + 24|0;
 $30 = sp + 12|0;
 $31 = sp + 48|0;
 $32 = sp + 60|0;
 $33 = sp + 264|0;
 $34 = sp + 144|0;
 $35 = sp + 156|0;
 $36 = sp + 168|0;
 $37 = sp + 180|0;
 $38 = sp + 192|0;
 $39 = sp + 204|0;
 $40 = sp + 216|0;
 $41 = sp + 228|0;
 $42 = sp + 240|0;
 $43 = sp + 252|0;
 $44 = sp + 276|0;
 HEAP32[674288>>2] = 0;
 HEAP32[674272>>2] = -2;
 $45 = (($3) + 1|0);
 $46 = (($3) + 12|0);
 $47 = (($46) + 1|0);
 $48 = (($3) + 8|0);
 $49 = (($3) + 20|0);
 $50 = (($3) + 16|0);
 $51 = (($3) + 4|0);
 $52 = (($5) + 1|0);
 $53 = (($4) + 1|0);
 $54 = (($5) + 8|0);
 $55 = (($4) + 8|0);
 $56 = (($4) + 4|0);
 $57 = (($5) + 4|0);
 $58 = (($6) + 1|0);
 $59 = (($6) + 8|0);
 $60 = (($6) + 4|0);
 $61 = (($7) + 1|0);
 $62 = (($7) + 8|0);
 $63 = (($7) + 4|0);
 $64 = (($8) + 1|0);
 $65 = (($8) + 8|0);
 $66 = (($8) + 4|0);
 $67 = (($9) + 1|0);
 $68 = (($9) + 8|0);
 $69 = (($9) + 4|0);
 $70 = (($10) + 1|0);
 $71 = (($11) + 1|0);
 $72 = (($10) + 8|0);
 $73 = (($11) + 8|0);
 $74 = (($11) + 4|0);
 $75 = (($10) + 4|0);
 $76 = (($13) + 1|0);
 $77 = (($14) + 1|0);
 $78 = (($13) + 8|0);
 $79 = (($14) + 8|0);
 $80 = (($14) + 4|0);
 $81 = (($13) + 4|0);
 $82 = (($17) + 1|0);
 $83 = (($16) + 1|0);
 $84 = (($17) + 8|0);
 $85 = (($16) + 8|0);
 $86 = (($16) + 4|0);
 $87 = (($17) + 4|0);
 $88 = (($18) + 8|0);
 $89 = (($19) + 8|0);
 $90 = (($19) + 4|0);
 $91 = (($20) + 8|0);
 $92 = (($21) + 1|0);
 $93 = (($21) + 8|0);
 $94 = (($21) + 4|0);
 $95 = (($22) + 1|0);
 $96 = (($22) + 8|0);
 $97 = (($22) + 4|0);
 $98 = (($23) + 1|0);
 $99 = (($23) + 8|0);
 $100 = (($23) + 4|0);
 $101 = (($24) + 1|0);
 $102 = (($24) + 8|0);
 $103 = (($24) + 4|0);
 $104 = (($25) + 1|0);
 $105 = (($25) + 8|0);
 $106 = (($25) + 4|0);
 $107 = (($26) + 1|0);
 $108 = (($26) + 8|0);
 $109 = (($26) + 4|0);
 $110 = (($27) + 1|0);
 $111 = (($27) + 8|0);
 $112 = (($27) + 4|0);
 $113 = (($28) + 1|0);
 $114 = (($28) + 8|0);
 $115 = (($28) + 4|0);
 $116 = (($29) + 1|0);
 $117 = (($29) + 8|0);
 $118 = (($29) + 4|0);
 $119 = (($30) + 1|0);
 $120 = (($30) + 8|0);
 $121 = (($30) + 4|0);
 $122 = (($31) + 1|0);
 $123 = (($31) + 8|0);
 $124 = (($31) + 4|0);
 $125 = (($32) + 1|0);
 $126 = (($32) + 8|0);
 $127 = (($32) + 4|0);
 $128 = (($33) + 1|0);
 $129 = (($33) + 8|0);
 $130 = (($33) + 4|0);
 $131 = (($34) + 1|0);
 $132 = (($34) + 8|0);
 $133 = (($34) + 4|0);
 $134 = (($35) + 1|0);
 $135 = (($35) + 8|0);
 $136 = (($35) + 4|0);
 $137 = (($36) + 1|0);
 $138 = (($36) + 8|0);
 $139 = (($36) + 4|0);
 $140 = (($37) + 1|0);
 $141 = (($37) + 8|0);
 $142 = (($37) + 4|0);
 $143 = (($38) + 8|0);
 $144 = (($38) + 4|0);
 $145 = (($39) + 8|0);
 $146 = (($40) + 8|0);
 $147 = (($40) + 4|0);
 $148 = (($41) + 8|0);
 $149 = (($41) + 4|0);
 $150 = (($42) + 8|0);
 $151 = (($42) + 4|0);
 $152 = (($43) + 8|0);
 $153 = (($43) + 4|0);
 $154 = (($44) + 8|0);
 $155 = (($44) + 4|0);
 $yyss$0 = $yyssa;$yyssp$1 = $yyssa;$yystacksize$0 = 200;$yystate$1 = 0;$yyvs$0 = $yyvsa;$yyvsp$1 = $yyvsa;
 L1: while(1) {
  $157 = $yystate$1&65535;
  HEAP16[$yyssp$1>>1] = $157;
  $$sum = (($yystacksize$0) + -1)|0;
  $158 = (($yyss$0) + ($$sum<<1)|0);
  $159 = ($158>>>0)>($yyssp$1>>>0);
  if ($159) {
   $yyss$1 = $yyss$0;$yyssp$2 = $yyssp$1;$yystacksize$1 = $yystacksize$0;$yyvs$1 = $yyvs$0;$yyvsp$2 = $yyvsp$1;
  } else {
   $160 = $yyssp$1;
   $161 = $yyss$0;
   $162 = (($160) - ($161))|0;
   $163 = $162 >> 1;
   $164 = (($163) + 1)|0;
   $165 = ($yystacksize$0>>>0)>(9999);
   if ($165) {
    label = 993;
    break;
   }
   $166 = $yystacksize$0 << 1;
   $167 = ($166>>>0)>(10000);
   $$ = $167 ? 10000 : $166;
   $168 = ($$*6)|0;
   $169 = $168 | 3;
   $170 = (_malloc($169)|0);
   $171 = ($170|0)==(0|0);
   if ($171) {
    label = 993;
    break;
   }
   $172 = $164 << 1;
   _memcpy(($170|0),($yyss$0|0),($172|0))|0;
   $173 = $$ >>> 1;
   $174 = $173 & 1073741823;
   $175 = (($170) + ($174<<2)|0);
   $176 = $164 << 2;
   _memcpy(($175|0),($yyvs$0|0),($176|0))|0;
   $177 = ($yyss$0|0)==($yyssa|0);
   if (!($177)) {
    _free($yyss$0);
   }
   $178 = (($170) + ($163<<1)|0);
   $179 = (($175) + ($163<<2)|0);
   $$sum20 = (($$) + -1)|0;
   $180 = ($$sum20|0)>($163|0);
   if ($180) {
    $yyss$1 = $170;$yyssp$2 = $178;$yystacksize$1 = $$;$yyvs$1 = $175;$yyvsp$2 = $179;
   } else {
    $yyresult$0 = 1;$yyss$3 = $170;
    label = 999;
    break;
   }
  }
  $181 = (674296 + ($yystate$1<<1)|0);
  $182 = HEAP16[$181>>1]|0;
  $183 = $182 << 16 >> 16;
  $184 = ($182<<16>>16)==(-239);
  if ($184) {
   label = 23;
  } else {
   $185 = HEAP32[674272>>2]|0;
   $186 = ($185|0)==(-2);
   if ($186) {
    $187 = (__Z5yylexv()|0);
    HEAP32[674272>>2] = $187;
    $189 = $187;
   } else {
    $189 = $185;
   }
   $188 = ($189|0)<(1);
   if ($188) {
    HEAP32[674272>>2] = 0;
    $206 = 0;$yytoken$2 = 0;
   } else {
    $190 = ($189>>>0)<(360);
    if ($190) {
     $191 = (675112 + ($189)|0);
     $192 = HEAP8[$191>>0]|0;
     $193 = $192&255;
     $206 = $189;$yytoken$2 = $193;
    } else {
     $206 = $189;$yytoken$2 = 2;
    }
   }
   $194 = (($yytoken$2) + ($183))|0;
   $195 = ($194>>>0)>(430);
   if ($195) {
    label = 23;
   } else {
    $196 = (675472 + ($194<<1)|0);
    $197 = HEAP16[$196>>1]|0;
    $198 = $197 << 16 >> 16;
    $199 = ($198|0)==($yytoken$2|0);
    if ($199) {
     $200 = (676336 + ($194<<1)|0);
     $201 = HEAP16[$200>>1]|0;
     $202 = $201&65535;
     $203 = ($201<<16>>16)==(0);
     if ($203) {
      label = 987;
      break;
     }
     $204 = ($194|0)==(63);
     if ($204) {
      $yyresult$0 = 0;$yyss$3 = $yyss$1;
      label = 999;
      break;
     }
     $205 = ($206|0)==(0);
     if (!($205)) {
      HEAP32[674272>>2] = -2;
     }
     $207 = (($yyvsp$2) + 4|0);
     $208 = HEAP32[674280>>2]|0;
     HEAP32[$207>>2] = $208;
     $yyssp$0 = $yyssp$2;$yystate$0 = $202;$yyvsp$0 = $207;
    } else {
     label = 23;
    }
   }
  }
  do {
   if ((label|0) == 23) {
    label = 0;
    $209 = (677200 + ($yystate$1)|0);
    $210 = HEAP8[$209>>0]|0;
    $211 = $210&255;
    $212 = ($210<<24>>24)==(0);
    if ($212) {
     label = 987;
     break L1;
    }
    $213 = (677608 + ($211)|0);
    $214 = HEAP8[$213>>0]|0;
    $215 = $214&255;
    $216 = (1 - ($215))|0;
    $217 = (($yyvsp$2) + ($216<<2)|0);
    $218 = HEAP32[$217>>2]|0;
    L31: do {
     switch ($211|0) {
     case 44:  {
      $1135 = (($yyvsp$2) + -12|0);
      $1136 = HEAP32[$1135>>2]|0;
      $1137 = HEAP32[$yyvsp$2>>2]|0;
      $1138 = (_strlen(($1137|0))|0);
      $1139 = ($1138>>>0)>(4294967279);
      if ($1139) {
       label = 328;
       break L1;
      }
      $1140 = ($1138>>>0)<(11);
      if ($1140) {
       $1141 = $1138 << 1;
       $1142 = $1141&255;
       HEAP8[$10>>0] = $1142;
       $__p$0$i$i$i118 = $70;
      } else {
       $1143 = (($1138) + 16)|0;
       $1144 = $1143 & -16;
       $1145 = (__Znwj($1144)|0);
       HEAP32[$72>>2] = $1145;
       $1146 = $1144 | 1;
       HEAP32[$10>>2] = $1146;
       HEAP32[$75>>2] = $1138;
       $__p$0$i$i$i118 = $1145;
      }
      _memcpy(($__p$0$i$i$i118|0),($1137|0),($1138|0))|0;
      $1147 = (($__p$0$i$i$i118) + ($1138)|0);
      HEAP8[$1147>>0] = 0;
      __THREW__ = 0;
      $1148 = (invoke_ii(3224,($10|0))|0);
      $1149 = __THREW__; __THREW__ = 0;
      $1150 = $1149&1;
      if ($1150) {
       label = 347;
       break L1;
      }
      $1151 = (($yyvsp$2) + -8|0);
      $1152 = HEAP32[$1151>>2]|0;
      $1153 = (_strlen(($1152|0))|0);
      $1154 = ($1153>>>0)>(4294967279);
      if ($1154) {
       label = 334;
       break L1;
      }
      $1157 = ($1153>>>0)<(11);
      if ($1157) {
       $1158 = $1153 << 1;
       $1159 = $1158&255;
       HEAP8[$11>>0] = $1159;
       $__p$0$i$i$i121 = $71;
      } else {
       $1160 = (($1153) + 16)|0;
       $1161 = $1160 & -16;
       __THREW__ = 0;
       $1162 = (invoke_ii(2988,($1161|0))|0);
       $1163 = __THREW__; __THREW__ = 0;
       $1164 = $1163&1;
       if ($1164) {
        label = 347;
        break L1;
       }
       HEAP32[$73>>2] = $1162;
       $1165 = $1161 | 1;
       HEAP32[$11>>2] = $1165;
       HEAP32[$74>>2] = $1153;
       $__p$0$i$i$i121 = $1162;
      }
      _memcpy(($__p$0$i$i$i121|0),($1152|0),($1153|0))|0;
      $1166 = (($__p$0$i$i$i121) + ($1153)|0);
      HEAP8[$1166>>0] = 0;
      __THREW__ = 0;
      $1167 = (invoke_ii(3224,($11|0))|0);
      $1168 = __THREW__; __THREW__ = 0;
      $1169 = $1168&1;
      if ($1169) {
       label = 350;
       break L1;
      }
      HEAP32[$12>>2] = $1167;
      __THREW__ = 0;
      $1170 = (invoke_iii(2536,($1136|0),($12|0))|0);
      $1171 = __THREW__; __THREW__ = 0;
      $1172 = $1171&1;
      if ($1172) {
       label = 350;
       break L1;
      }
      HEAP32[$1170>>2] = $1148;
      $1173 = HEAP8[$11>>0]|0;
      $1174 = $1173 & 1;
      $1175 = ($1174<<24>>24)==(0);
      if (!($1175)) {
       $1176 = HEAP32[$73>>2]|0;
       __ZdlPv($1176);
      }
      $1177 = HEAP8[$10>>0]|0;
      $1178 = $1177 & 1;
      $1179 = ($1178<<24>>24)==(0);
      if (!($1179)) {
       $1180 = HEAP32[$72>>2]|0;
       __ZdlPv($1180);
      }
      $1181 = HEAP32[679312>>2]|0;
      $1182 = HEAP32[$1181>>2]|0;
      $1183 = (($1182) + 20|0);
      $1184 = HEAP32[$1183>>2]|0;
      $1185 = HEAP32[$1151>>2]|0;
      FUNCTION_TABLE_vii[$1184 & 4095]($1181,$1185);
      $1186 = HEAP32[679312>>2]|0;
      $1187 = HEAP32[$1186>>2]|0;
      $1188 = (($1187) + 20|0);
      $1189 = HEAP32[$1188>>2]|0;
      $1190 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$1189 & 4095]($1186,$1190);
      $yyval$sroa$0$0 = $1136;
      break;
     }
     case 43:  {
      $1132 = (__Znwj(12)|0);
      $1133 = (($1132) + 4|0);
      HEAP32[$1133>>2] = 0;
      $1134 = (($1132) + 8|0);
      HEAP32[$1134>>2] = 0;
      HEAP32[$1132>>2] = $1133;
      $yyval$sroa$0$0 = $1132;
      break;
     }
     case 45:  {
      $1205 = (($yyvsp$2) + -12|0);
      $1206 = HEAP32[$1205>>2]|0;
      $1207 = HEAP32[$yyvsp$2>>2]|0;
      $1208 = (_strlen(($1207|0))|0);
      $1209 = ($1208>>>0)>(4294967279);
      if ($1209) {
       label = 355;
       break L1;
      }
      $1210 = ($1208>>>0)<(11);
      if ($1210) {
       $1211 = $1208 << 1;
       $1212 = $1211&255;
       HEAP8[$13>>0] = $1212;
       $__p$0$i$i$i130 = $76;
      } else {
       $1213 = (($1208) + 16)|0;
       $1214 = $1213 & -16;
       $1215 = (__Znwj($1214)|0);
       HEAP32[$78>>2] = $1215;
       $1216 = $1214 | 1;
       HEAP32[$13>>2] = $1216;
       HEAP32[$81>>2] = $1208;
       $__p$0$i$i$i130 = $1215;
      }
      _memcpy(($__p$0$i$i$i130|0),($1207|0),($1208|0))|0;
      $1217 = (($__p$0$i$i$i130) + ($1208)|0);
      HEAP8[$1217>>0] = 0;
      __THREW__ = 0;
      $1218 = (invoke_ii(3224,($13|0))|0);
      $1219 = __THREW__; __THREW__ = 0;
      $1220 = $1219&1;
      if ($1220) {
       label = 374;
       break L1;
      }
      $1221 = (($yyvsp$2) + -8|0);
      $1222 = HEAP32[$1221>>2]|0;
      $1223 = (_strlen(($1222|0))|0);
      $1224 = ($1223>>>0)>(4294967279);
      if ($1224) {
       label = 361;
       break L1;
      }
      $1227 = ($1223>>>0)<(11);
      if ($1227) {
       $1228 = $1223 << 1;
       $1229 = $1228&255;
       HEAP8[$14>>0] = $1229;
       $__p$0$i$i$i133 = $77;
      } else {
       $1230 = (($1223) + 16)|0;
       $1231 = $1230 & -16;
       __THREW__ = 0;
       $1232 = (invoke_ii(2988,($1231|0))|0);
       $1233 = __THREW__; __THREW__ = 0;
       $1234 = $1233&1;
       if ($1234) {
        label = 374;
        break L1;
       }
       HEAP32[$79>>2] = $1232;
       $1235 = $1231 | 1;
       HEAP32[$14>>2] = $1235;
       HEAP32[$80>>2] = $1223;
       $__p$0$i$i$i133 = $1232;
      }
      _memcpy(($__p$0$i$i$i133|0),($1222|0),($1223|0))|0;
      $1236 = (($__p$0$i$i$i133) + ($1223)|0);
      HEAP8[$1236>>0] = 0;
      __THREW__ = 0;
      $1237 = (invoke_ii(3224,($14|0))|0);
      $1238 = __THREW__; __THREW__ = 0;
      $1239 = $1238&1;
      if ($1239) {
       label = 377;
       break L1;
      }
      HEAP32[$15>>2] = $1237;
      __THREW__ = 0;
      $1240 = (invoke_iii(2536,($1206|0),($15|0))|0);
      $1241 = __THREW__; __THREW__ = 0;
      $1242 = $1241&1;
      if ($1242) {
       label = 377;
       break L1;
      }
      HEAP32[$1240>>2] = $1218;
      $1243 = HEAP8[$14>>0]|0;
      $1244 = $1243 & 1;
      $1245 = ($1244<<24>>24)==(0);
      if (!($1245)) {
       $1246 = HEAP32[$79>>2]|0;
       __ZdlPv($1246);
      }
      $1247 = HEAP8[$13>>0]|0;
      $1248 = $1247 & 1;
      $1249 = ($1248<<24>>24)==(0);
      if (!($1249)) {
       $1250 = HEAP32[$78>>2]|0;
       __ZdlPv($1250);
      }
      $1251 = HEAP32[679312>>2]|0;
      $1252 = HEAP32[$1251>>2]|0;
      $1253 = (($1252) + 20|0);
      $1254 = HEAP32[$1253>>2]|0;
      $1255 = HEAP32[$1221>>2]|0;
      FUNCTION_TABLE_vii[$1254 & 4095]($1251,$1255);
      $1256 = HEAP32[679312>>2]|0;
      $1257 = HEAP32[$1256>>2]|0;
      $1258 = (($1257) + 20|0);
      $1259 = HEAP32[$1258>>2]|0;
      $1260 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$1259 & 4095]($1256,$1260);
      $yyval$sroa$0$0 = $1206;
      break;
     }
     case 47:  {
      $1286 = (($yyvsp$2) + -8|0);
      $1287 = HEAP32[$1286>>2]|0;
      $1288 = Math_fround(HEAPF32[$yyvsp$2>>2]);
      $1289 = (~~(($1288)));
      $1290 = (($1287) + 652|0);
      HEAP32[$1290>>2] = $1289;
      $yyval$sroa$0$0 = $1287;
      break;
     }
     case 48:  {
      $1291 = (($yyvsp$2) + -8|0);
      $1292 = HEAP32[$1291>>2]|0;
      $1293 = HEAP32[$yyvsp$2>>2]|0;
      $1294 = (_strlen(($1293|0))|0);
      $1295 = ($1294>>>0)>(4294967279);
      if ($1295) {
       label = 384;
       break L1;
      }
      $1296 = ($1294>>>0)<(11);
      if ($1296) {
       $1297 = $1294 << 1;
       $1298 = $1297&255;
       HEAP8[$17>>0] = $1298;
       $__p$0$i$i$i142 = $82;
      } else {
       $1299 = (($1294) + 16)|0;
       $1300 = $1299 & -16;
       $1301 = (__Znwj($1300)|0);
       HEAP32[$84>>2] = $1301;
       $1302 = $1300 | 1;
       HEAP32[$17>>2] = $1302;
       HEAP32[$87>>2] = $1294;
       $__p$0$i$i$i142 = $1301;
      }
      _memcpy(($__p$0$i$i$i142|0),($1293|0),($1294|0))|0;
      $1303 = (($__p$0$i$i$i142) + ($1294)|0);
      HEAP8[$1303>>0] = 0;
      __THREW__ = 0;
      invoke_vii(3261,($16|0),($17|0));
      $1304 = __THREW__; __THREW__ = 0;
      $1305 = $1304&1;
      if ($1305) {
       label = 410;
       break L1;
      }
      $1306 = HEAP8[$16>>0]|0;
      $1307 = $1306 & 1;
      $1308 = ($1307<<24>>24)==(0);
      if ($1308) {
       $1311 = $1306&255;
       $1312 = $1311 >>> 1;
       $1321 = $1312;$1329 = $83;
      } else {
       $1309 = HEAP32[$85>>2]|0;
       $1310 = HEAP32[$86>>2]|0;
       $1321 = $1310;$1329 = $1309;
      }
      $1313 = HEAP8[$1292>>0]|0;
      $1314 = $1313 & 1;
      $1315 = ($1314<<24>>24)==(0);
      if ($1315) {
       $1320 = 10;$1323 = $1313;
      } else {
       $1316 = HEAP32[$1292>>2]|0;
       $1317 = $1316 & -2;
       $phitmp$i$i147 = (($1317) + -1)|0;
       $1318 = $1316&255;
       $1320 = $phitmp$i$i147;$1323 = $1318;
      }
      $1319 = ($1320>>>0)<($1321>>>0);
      $1322 = $1323 & 1;
      $1324 = ($1322<<24>>24)==(0);
      do {
       if ($1319) {
        if ($1324) {
         $1339 = $1323&255;
         $1340 = $1339 >>> 1;
         $1342 = $1340;
        } else {
         $1337 = (($1292) + 4|0);
         $1338 = HEAP32[$1337>>2]|0;
         $1342 = $1338;
        }
        $1341 = (($1321) - ($1320))|0;
        __THREW__ = 0;
        invoke_viiiiiiii(22,($1292|0),($1320|0),($1341|0),($1342|0),0,($1342|0),($1321|0),($1329|0));
        $1343 = __THREW__; __THREW__ = 0;
        $1344 = $1343&1;
        if ($1344) {
         label = 411;
         break L1;
        }
       } else {
        if ($1324) {
         $1327 = (($1292) + 1|0);
         $1328 = $1327;
        } else {
         $1325 = (($1292) + 8|0);
         $1326 = HEAP32[$1325>>2]|0;
         $1328 = $1326;
        }
        _memmove(($1328|0),($1329|0),($1321|0))|0;
        $1330 = (($1328) + ($1321)|0);
        HEAP8[$1330>>0] = 0;
        $1331 = HEAP8[$1292>>0]|0;
        $1332 = $1331 & 1;
        $1333 = ($1332<<24>>24)==(0);
        if ($1333) {
         $1335 = $1321 << 1;
         $1336 = $1335&255;
         HEAP8[$1292>>0] = $1336;
         break;
        } else {
         $1334 = (($1292) + 4|0);
         HEAP32[$1334>>2] = $1321;
         break;
        }
       }
      } while(0);
      $1345 = HEAP8[$16>>0]|0;
      $1346 = $1345 & 1;
      $1347 = ($1346<<24>>24)==(0);
      if (!($1347)) {
       $1348 = HEAP32[$85>>2]|0;
       __ZdlPv($1348);
      }
      $1349 = HEAP8[$17>>0]|0;
      $1350 = $1349 & 1;
      $1351 = ($1350<<24>>24)==(0);
      if (!($1351)) {
       $1352 = HEAP32[$84>>2]|0;
       __ZdlPv($1352);
      }
      $1353 = HEAP32[679312>>2]|0;
      $1354 = HEAP32[$1353>>2]|0;
      $1355 = (($1354) + 20|0);
      $1356 = HEAP32[$1355>>2]|0;
      $1357 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$1356 & 4095]($1353,$1357);
      $yyval$sroa$0$0 = $1292;
      break;
     }
     case 46:  {
      $1275 = HEAP32[((674208 + 20|0))>>2]|0;
      $1276 = HEAP32[((674208 + 16|0))>>2]|0;
      $1277 = (($1275) + -1)|0;
      $1278 = (($1277) + ($1276))|0;
      $1279 = HEAP32[((674208 + 4|0))>>2]|0;
      $1280 = $1278 >>> 10;
      $1281 = (($1279) + ($1280<<2)|0);
      $1282 = HEAP32[$1281>>2]|0;
      $1283 = $1278 & 1023;
      $1284 = (($1282) + ($1283<<2)|0);
      $1285 = HEAP32[$1284>>2]|0;
      $yyval$sroa$0$0 = $1285;
      break;
     }
     case 50:  {
      $1378 = (($yyvsp$2) + -16|0);
      $1379 = HEAP32[$1378>>2]|0;
      $1380 = (($yyvsp$2) + -4|0);
      $1381 = HEAP32[$1380>>2]|0;
      $1382 = (($1379) + 520|0);
      __ZN9ShaderLab18ParserBindChannels9MergeWithERKS0_($1382,$1381);
      $1383 = HEAP32[$1380>>2]|0;
      $1384 = ($1383|0)==(0|0);
      if ($1384) {
       $yyval$sroa$0$0 = $1379;
      } else {
       __ZdlPv($1383);
       $yyval$sroa$0$0 = $1379;
      }
      break;
     }
     case 51:  {
      $1385 = (($yyvsp$2) + -16|0);
      $1386 = HEAP32[$1385>>2]|0;
      $1387 = (($yyvsp$2) + -4|0);
      $1388 = HEAP32[$1387>>2]|0;
      $1389 = (($1386) + 216|0);
      $1390 = (($1388) + 216|0);
      dest=$1389+0|0; src=$1390+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $1391 = (($1386) + 180|0);
      $1392 = (($1388) + 180|0);
      dest=$1391+0|0; src=$1392+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $1393 = (($1386) + 252|0);
      $1394 = (($1388) + 252|0);
      dest=$1393+0|0; src=$1394+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $1395 = (($1386) + 288|0);
      $1396 = (($1388) + 288|0);
      dest=$1395+0|0; src=$1396+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $1397 = (($1386) + 44|0);
      $1398 = (($1388) + 44|0);
      $1399 = $1398;
      $1400 = $1399;
      $1401 = HEAP32[$1400>>2]|0;
      $1402 = (($1399) + 4)|0;
      $1403 = $1402;
      $1404 = HEAP32[$1403>>2]|0;
      $1405 = $1397;
      $1406 = $1405;
      HEAP32[$1406>>2] = $1401;
      $1407 = (($1405) + 4)|0;
      $1408 = $1407;
      HEAP32[$1408>>2] = $1404;
      __ZL14PopShaderStatev();
      $yyval$sroa$0$0 = $1386;
      break;
     }
     case 52:  {
      $1409 = (($yyvsp$2) + -16|0);
      $1410 = HEAP32[$1409>>2]|0;
      $1411 = (($yyvsp$2) + -4|0);
      $1412 = HEAP32[$1411>>2]|0;
      $1413 = (($1410) + 472|0);
      $1414 = (($1412) + 472|0);
      dest=$1413+0|0; src=$1414+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $1415 = (($1412) + 508|0);
      $1416 = HEAP32[$1415>>2]|0;
      $1417 = (($1410) + 508|0);
      HEAP32[$1417>>2] = $1416;
      $1418 = (($1410) + 464|0);
      $1419 = (($1412) + 464|0);
      $1420 = $1419;
      $1421 = $1420;
      $1422 = HEAP32[$1421>>2]|0;
      $1423 = (($1420) + 4)|0;
      $1424 = $1423;
      $1425 = HEAP32[$1424>>2]|0;
      $1426 = $1418;
      $1427 = $1426;
      HEAP32[$1427>>2] = $1422;
      $1428 = (($1426) + 4)|0;
      $1429 = $1428;
      HEAP32[$1429>>2] = $1425;
      $1430 = (($1410) + 448|0);
      $1431 = (($1412) + 448|0);
      $1432 = $1431;
      $1433 = $1432;
      $1434 = HEAP32[$1433>>2]|0;
      $1435 = (($1432) + 4)|0;
      $1436 = $1435;
      $1437 = HEAP32[$1436>>2]|0;
      $1438 = $1430;
      $1439 = $1438;
      HEAP32[$1439>>2] = $1434;
      $1440 = (($1438) + 4)|0;
      $1441 = $1440;
      HEAP32[$1441>>2] = $1437;
      $1442 = (($1410) + 456|0);
      $1443 = (($1412) + 456|0);
      $1444 = $1443;
      $1445 = $1444;
      $1446 = HEAP32[$1445>>2]|0;
      $1447 = (($1444) + 4)|0;
      $1448 = $1447;
      $1449 = HEAP32[$1448>>2]|0;
      $1450 = $1442;
      $1451 = $1450;
      HEAP32[$1451>>2] = $1446;
      $1452 = (($1450) + 4)|0;
      $1453 = $1452;
      HEAP32[$1453>>2] = $1449;
      __ZL14PopShaderStatev();
      $yyval$sroa$0$0 = $1410;
      break;
     }
     case 49:  {
      $1370 = (($yyvsp$2) + -16|0);
      $1371 = HEAP32[$1370>>2]|0;
      $1372 = (($yyvsp$2) + -4|0);
      $1373 = HEAP32[$1372>>2]|0;
      __ZN9ShaderLab17ParserShaderState7AddTagsERKNSt3__13mapIiiNS1_4lessIiEENS1_9allocatorINS1_4pairIKiiEEEEEE($1371,$1373);
      $1374 = HEAP32[$1372>>2]|0;
      $1375 = ($1374|0)==(0|0);
      if ($1375) {
       $yyval$sroa$0$0 = $1371;
      } else {
       $1376 = (($1374) + 4|0);
       $1377 = HEAP32[$1376>>2]|0;
       __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1374,$1377);
       __ZdlPv($1374);
       $yyval$sroa$0$0 = $1371;
      }
      break;
     }
     case 53:  {
      $1454 = (($yyvsp$2) + -8|0);
      $1455 = HEAP32[$1454>>2]|0;
      $1456 = (($1455) + 144|0);
      $1457 = HEAP32[$yyvsp$2>>2]|0;
      $1458 = (($1457) + 12|0);
      dest=$1456+0|0; src=$1458+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $1459 = HEAP32[$yyvsp$2>>2]|0;
      $1460 = ($1459|0)==(0|0);
      if ($1460) {
       $yyval$sroa$0$0 = $1455;
      } else {
       $1461 = HEAP8[$1459>>0]|0;
       $1462 = $1461 & 1;
       $1463 = ($1462<<24>>24)==(0);
       if (!($1463)) {
        $1464 = (($1459) + 8|0);
        $1465 = HEAP32[$1464>>2]|0;
        __ZdlPv($1465);
       }
       __ZdlPv($1459);
       $yyval$sroa$0$0 = $1455;
      }
      break;
     }
     case 56:  {
      $1486 = (($yyvsp$2) + -8|0);
      $1487 = HEAP32[$1486>>2]|0;
      $1488 = (($1487) + 12|0);
      $1489 = HEAP32[$yyvsp$2>>2]|0;
      $1490 = $1489;
      $1491 = $1490;
      $1492 = HEAP32[$1491>>2]|0;
      $1493 = (($1490) + 4)|0;
      $1494 = $1493;
      $1495 = HEAP32[$1494>>2]|0;
      $1496 = $1488;
      $1497 = $1496;
      HEAP32[$1497>>2] = $1492;
      $1498 = (($1496) + 4)|0;
      $1499 = $1498;
      HEAP32[$1499>>2] = $1495;
      $1500 = HEAP32[$yyvsp$2>>2]|0;
      $1501 = ($1500|0)==(0|0);
      if ($1501) {
       $yyval$sroa$0$0 = $1487;
      } else {
       __ZdlPv($1500);
       $yyval$sroa$0$0 = $1487;
      }
      break;
     }
     case 57:  {
      $1502 = (($yyvsp$2) + -8|0);
      $1503 = HEAP32[$1502>>2]|0;
      $1504 = (($1503) + 12|0);
      HEAPF32[$1504>>2] = Math_fround(4.0);
      $1505 = (($1503) + 16|0);
      HEAP32[$1505>>2] = -1;
      $yyval$sroa$0$0 = $1503;
      break;
     }
     case 58:  {
      $1506 = (($yyvsp$2) + -8|0);
      $1507 = HEAP32[$1506>>2]|0;
      $1508 = (($1507) + 12|0);
      HEAPF32[$1508>>2] = Math_fround(0.0);
      $1509 = (($1507) + 16|0);
      HEAP32[$1509>>2] = -1;
      $yyval$sroa$0$0 = $1507;
      break;
     }
     case 59:  {
      $1510 = (($yyvsp$2) + -8|0);
      $1511 = HEAP32[$1510>>2]|0;
      $1512 = (($1511) + 20|0);
      $1513 = HEAP32[$yyvsp$2>>2]|0;
      $1514 = $1513;
      $1515 = $1514;
      $1516 = HEAP32[$1515>>2]|0;
      $1517 = (($1514) + 4)|0;
      $1518 = $1517;
      $1519 = HEAP32[$1518>>2]|0;
      $1520 = $1512;
      $1521 = $1520;
      HEAP32[$1521>>2] = $1516;
      $1522 = (($1520) + 4)|0;
      $1523 = $1522;
      HEAP32[$1523>>2] = $1519;
      $1524 = HEAP32[$yyvsp$2>>2]|0;
      $1525 = ($1524|0)==(0|0);
      if ($1525) {
       $yyval$sroa$0$0 = $1511;
      } else {
       __ZdlPv($1524);
       $yyval$sroa$0$0 = $1511;
      }
      break;
     }
     case 60:  {
      $1526 = (($yyvsp$2) + -8|0);
      $1527 = HEAP32[$1526>>2]|0;
      $1528 = HEAP32[$yyvsp$2>>2]|0;
      $1529 = (($1527) + 516|0);
      HEAP32[$1529>>2] = $1528;
      $yyval$sroa$0$0 = $1527;
      break;
     }
     case 61:  {
      $1530 = (($yyvsp$2) + -8|0);
      $1531 = HEAP32[$1530>>2]|0;
      $1532 = (($1531) + 136|0);
      $1533 = HEAP32[$yyvsp$2>>2]|0;
      $1534 = $1533;
      $1535 = $1534;
      $1536 = HEAP32[$1535>>2]|0;
      $1537 = (($1534) + 4)|0;
      $1538 = $1537;
      $1539 = HEAP32[$1538>>2]|0;
      $1540 = $1532;
      $1541 = $1540;
      HEAP32[$1541>>2] = $1536;
      $1542 = (($1540) + 4)|0;
      $1543 = $1542;
      HEAP32[$1543>>2] = $1539;
      $1544 = HEAP32[$yyvsp$2>>2]|0;
      $1545 = ($1544|0)==(0|0);
      if ($1545) {
       $yyval$sroa$0$0 = $1531;
      } else {
       __ZdlPv($1544);
       $yyval$sroa$0$0 = $1531;
      }
      break;
     }
     case 54:  {
      $1466 = (($yyvsp$2) + -8|0);
      $1467 = HEAP32[$1466>>2]|0;
      $1468 = HEAP8[$yyvsp$2>>0]|0;
      $1469 = (($1467) + 76|0);
      HEAP8[$1469>>0] = $1468;
      $yyval$sroa$0$0 = $1467;
      break;
     }
     case 55:  {
      $1470 = (($yyvsp$2) + -8|0);
      $1471 = HEAP32[$1470>>2]|0;
      $1472 = (($1471) + 80|0);
      $1473 = HEAP32[$yyvsp$2>>2]|0;
      $1474 = $1473;
      $1475 = $1474;
      $1476 = HEAP32[$1475>>2]|0;
      $1477 = (($1474) + 4)|0;
      $1478 = $1477;
      $1479 = HEAP32[$1478>>2]|0;
      $1480 = $1472;
      $1481 = $1480;
      HEAP32[$1481>>2] = $1476;
      $1482 = (($1480) + 4)|0;
      $1483 = $1482;
      HEAP32[$1483>>2] = $1479;
      $1484 = HEAP32[$yyvsp$2>>2]|0;
      $1485 = ($1484|0)==(0|0);
      if ($1485) {
       $yyval$sroa$0$0 = $1471;
      } else {
       __ZdlPv($1484);
       $yyval$sroa$0$0 = $1471;
      }
      break;
     }
     case 62:  {
      $1546 = (($yyvsp$2) + -12|0);
      $1547 = HEAP32[$1546>>2]|0;
      $1548 = (($1547) + 28|0);
      $1549 = (($yyvsp$2) + -4|0);
      $1550 = HEAP32[$1549>>2]|0;
      $1551 = $1550;
      $1552 = $1551;
      $1553 = HEAP32[$1552>>2]|0;
      $1554 = (($1551) + 4)|0;
      $1555 = $1554;
      $1556 = HEAP32[$1555>>2]|0;
      $1557 = $1548;
      $1558 = $1557;
      HEAP32[$1558>>2] = $1553;
      $1559 = (($1557) + 4)|0;
      $1560 = $1559;
      HEAP32[$1560>>2] = $1556;
      $1561 = HEAP32[$1549>>2]|0;
      $1562 = ($1561|0)==(0|0);
      if (!($1562)) {
       __ZdlPv($1561);
      }
      $1563 = (($1547) + 36|0);
      $1564 = HEAP32[$yyvsp$2>>2]|0;
      $1565 = $1564;
      $1566 = $1565;
      $1567 = HEAP32[$1566>>2]|0;
      $1568 = (($1565) + 4)|0;
      $1569 = $1568;
      $1570 = HEAP32[$1569>>2]|0;
      $1571 = $1563;
      $1572 = $1571;
      HEAP32[$1572>>2] = $1567;
      $1573 = (($1571) + 4)|0;
      $1574 = $1573;
      HEAP32[$1574>>2] = $1570;
      $1575 = HEAP32[$yyvsp$2>>2]|0;
      $1576 = ($1575|0)==(0|0);
      if ($1576) {
       $yyval$sroa$0$0 = $1547;
      } else {
       __ZdlPv($1575);
       $yyval$sroa$0$0 = $1547;
      }
      break;
     }
     case 68:  {
      $1680 = (($yyvsp$2) + -12|0);
      $1681 = HEAP32[$1680>>2]|0;
      $1682 = (($1681) + 88|0);
      $1683 = (($yyvsp$2) + -4|0);
      $1684 = HEAP32[$1683>>2]|0;
      $1685 = $1684;
      $1686 = $1685;
      $1687 = HEAP32[$1686>>2]|0;
      $1688 = (($1685) + 4)|0;
      $1689 = $1688;
      $1690 = HEAP32[$1689>>2]|0;
      $1691 = $1682;
      $1692 = $1691;
      HEAP32[$1692>>2] = $1687;
      $1693 = (($1691) + 4)|0;
      $1694 = $1693;
      HEAP32[$1694>>2] = $1690;
      $1695 = (($1681) + 104|0);
      $1696 = HEAP32[$1683>>2]|0;
      $1697 = $1696;
      $1698 = $1697;
      $1699 = HEAP32[$1698>>2]|0;
      $1700 = (($1697) + 4)|0;
      $1701 = $1700;
      $1702 = HEAP32[$1701>>2]|0;
      $1703 = $1695;
      $1704 = $1703;
      HEAP32[$1704>>2] = $1699;
      $1705 = (($1703) + 4)|0;
      $1706 = $1705;
      HEAP32[$1706>>2] = $1702;
      $1707 = HEAP32[$1683>>2]|0;
      $1708 = ($1707|0)==(0|0);
      if (!($1708)) {
       __ZdlPv($1707);
      }
      $1709 = (($1681) + 96|0);
      $1710 = HEAP32[$yyvsp$2>>2]|0;
      $1711 = $1710;
      $1712 = $1711;
      $1713 = HEAP32[$1712>>2]|0;
      $1714 = (($1711) + 4)|0;
      $1715 = $1714;
      $1716 = HEAP32[$1715>>2]|0;
      $1717 = $1709;
      $1718 = $1717;
      HEAP32[$1718>>2] = $1713;
      $1719 = (($1717) + 4)|0;
      $1720 = $1719;
      HEAP32[$1720>>2] = $1716;
      $1721 = (($1681) + 112|0);
      $1722 = HEAP32[$yyvsp$2>>2]|0;
      $1723 = $1722;
      $1724 = $1723;
      $1725 = HEAP32[$1724>>2]|0;
      $1726 = (($1723) + 4)|0;
      $1727 = $1726;
      $1728 = HEAP32[$1727>>2]|0;
      $1729 = $1721;
      $1730 = $1729;
      HEAP32[$1730>>2] = $1725;
      $1731 = (($1729) + 4)|0;
      $1732 = $1731;
      HEAP32[$1732>>2] = $1728;
      $1733 = HEAP32[$yyvsp$2>>2]|0;
      $1734 = ($1733|0)==(0|0);
      if ($1734) {
       $yyval$sroa$0$0 = $1681;
      } else {
       __ZdlPv($1733);
       $yyval$sroa$0$0 = $1681;
      }
      break;
     }
     case 65:  {
      $1599 = (($yyvsp$2) + -8|0);
      $1600 = HEAP32[$1599>>2]|0;
      $1601 = (($1600) + 52|0);
      $1602 = HEAP32[$yyvsp$2>>2]|0;
      $1603 = $1602;
      $1604 = $1603;
      $1605 = HEAP32[$1604>>2]|0;
      $1606 = (($1603) + 4)|0;
      $1607 = $1606;
      $1608 = HEAP32[$1607>>2]|0;
      $1609 = $1601;
      $1610 = $1609;
      HEAP32[$1610>>2] = $1605;
      $1611 = (($1609) + 4)|0;
      $1612 = $1611;
      HEAP32[$1612>>2] = $1608;
      $1613 = HEAP32[$yyvsp$2>>2]|0;
      $1614 = ($1613|0)==(0|0);
      if ($1614) {
       $yyval$sroa$0$0 = $1600;
      } else {
       __ZdlPv($1613);
       $yyval$sroa$0$0 = $1600;
      }
      break;
     }
     case 63:  {
      $1577 = (($yyvsp$2) + -12|0);
      $1578 = HEAP32[$1577>>2]|0;
      $1579 = (($1578) + 28|0);
      HEAPF32[$1579>>2] = Math_fround(4.0);
      $1580 = (($1578) + 32|0);
      HEAP32[$1580>>2] = -1;
      $1581 = (($1578) + 36|0);
      $1582 = HEAP32[$yyvsp$2>>2]|0;
      $1583 = $1582;
      $1584 = $1583;
      $1585 = HEAP32[$1584>>2]|0;
      $1586 = (($1583) + 4)|0;
      $1587 = $1586;
      $1588 = HEAP32[$1587>>2]|0;
      $1589 = $1581;
      $1590 = $1589;
      HEAP32[$1590>>2] = $1585;
      $1591 = (($1589) + 4)|0;
      $1592 = $1591;
      HEAP32[$1592>>2] = $1588;
      $1593 = HEAP32[$yyvsp$2>>2]|0;
      $1594 = ($1593|0)==(0|0);
      if ($1594) {
       $yyval$sroa$0$0 = $1578;
      } else {
       __ZdlPv($1593);
       $yyval$sroa$0$0 = $1578;
      }
      break;
     }
     case 66:  {
      $1615 = (($yyvsp$2) + -8|0);
      $1616 = HEAP32[$1615>>2]|0;
      $1617 = (($1616) + 52|0);
      HEAPF32[$1617>>2] = Math_fround(0.0);
      $1618 = (($1616) + 56|0);
      HEAP32[$1618>>2] = -1;
      $yyval$sroa$0$0 = $1616;
      break;
     }
     case 67:  {
      $1619 = (($yyvsp$2) + -24|0);
      $1620 = HEAP32[$1619>>2]|0;
      $1621 = (($1620) + 88|0);
      $1622 = (($yyvsp$2) + -16|0);
      $1623 = HEAP32[$1622>>2]|0;
      $1624 = $1623;
      $1625 = $1624;
      $1626 = HEAP32[$1625>>2]|0;
      $1627 = (($1624) + 4)|0;
      $1628 = $1627;
      $1629 = HEAP32[$1628>>2]|0;
      $1630 = $1621;
      $1631 = $1630;
      HEAP32[$1631>>2] = $1626;
      $1632 = (($1630) + 4)|0;
      $1633 = $1632;
      HEAP32[$1633>>2] = $1629;
      $1634 = HEAP32[$1622>>2]|0;
      $1635 = ($1634|0)==(0|0);
      if (!($1635)) {
       __ZdlPv($1634);
      }
      $1636 = (($1620) + 96|0);
      $1637 = (($yyvsp$2) + -12|0);
      $1638 = HEAP32[$1637>>2]|0;
      $1639 = $1638;
      $1640 = $1639;
      $1641 = HEAP32[$1640>>2]|0;
      $1642 = (($1639) + 4)|0;
      $1643 = $1642;
      $1644 = HEAP32[$1643>>2]|0;
      $1645 = $1636;
      $1646 = $1645;
      HEAP32[$1646>>2] = $1641;
      $1647 = (($1645) + 4)|0;
      $1648 = $1647;
      HEAP32[$1648>>2] = $1644;
      $1649 = HEAP32[$1637>>2]|0;
      $1650 = ($1649|0)==(0|0);
      if (!($1650)) {
       __ZdlPv($1649);
      }
      $1651 = (($1620) + 104|0);
      $1652 = (($yyvsp$2) + -4|0);
      $1653 = HEAP32[$1652>>2]|0;
      $1654 = $1653;
      $1655 = $1654;
      $1656 = HEAP32[$1655>>2]|0;
      $1657 = (($1654) + 4)|0;
      $1658 = $1657;
      $1659 = HEAP32[$1658>>2]|0;
      $1660 = $1651;
      $1661 = $1660;
      HEAP32[$1661>>2] = $1656;
      $1662 = (($1660) + 4)|0;
      $1663 = $1662;
      HEAP32[$1663>>2] = $1659;
      $1664 = HEAP32[$1652>>2]|0;
      $1665 = ($1664|0)==(0|0);
      if (!($1665)) {
       __ZdlPv($1664);
      }
      $1666 = (($1620) + 112|0);
      $1667 = HEAP32[$yyvsp$2>>2]|0;
      $1668 = $1667;
      $1669 = $1668;
      $1670 = HEAP32[$1669>>2]|0;
      $1671 = (($1668) + 4)|0;
      $1672 = $1671;
      $1673 = HEAP32[$1672>>2]|0;
      $1674 = $1666;
      $1675 = $1674;
      HEAP32[$1675>>2] = $1670;
      $1676 = (($1674) + 4)|0;
      $1677 = $1676;
      HEAP32[$1677>>2] = $1673;
      $1678 = HEAP32[$yyvsp$2>>2]|0;
      $1679 = ($1678|0)==(0|0);
      if ($1679) {
       $yyval$sroa$0$0 = $1620;
      } else {
       __ZdlPv($1678);
       $yyval$sroa$0$0 = $1620;
      }
      break;
     }
     case 64:  {
      $1595 = (($yyvsp$2) + -8|0);
      $1596 = HEAP32[$1595>>2]|0;
      $1597 = (($1596) + 28|0);
      HEAPF32[$1597>>2] = Math_fround(0.0);
      $1598 = (($1596) + 32|0);
      HEAP32[$1598>>2] = -1;
      $yyval$sroa$0$0 = $1596;
      break;
     }
     case 3:  {
      $228 = HEAP32[$yyvsp$2>>2]|0;
      $229 = ($228|0)==(0|0);
      if ($229) {
       $yyval$sroa$0$0 = $218;
      } else {
       $230 = HEAP32[674232>>2]|0;
       $231 = ($230|0)==($228|0);
       if ($231) {
        $237 = $228;
       } else {
        $232 = HEAP32[$228>>2]|0;
        $233 = (($228) + 4|0);
        $234 = HEAP32[$233>>2]|0;
        __ZNSt3__16vectorIN9ShaderLab14ParserPropertyENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($230,$232,$234);
        $$pre = HEAP32[$yyvsp$2>>2]|0;
        $235 = ($$pre|0)==(0|0);
        if ($235) {
         $yyval$sroa$0$0 = $218;
         break L31;
        } else {
         $237 = $$pre;
        }
       }
       $236 = HEAP32[$237>>2]|0;
       $238 = ($236|0)==(0|0);
       if (!($238)) {
        $239 = (($237) + 4|0);
        while(1) {
         $240 = HEAP32[$239>>2]|0;
         $241 = ($240|0)==($236|0);
         if ($241) {
          break;
         }
         $242 = (($240) + -76|0);
         HEAP32[$239>>2] = $242;
         __THREW__ = 0;
         invoke_vi(3592,($242|0));
         $243 = __THREW__; __THREW__ = 0;
         $244 = $243&1;
         if ($244) {
          label = 33;
          break L1;
         }
        }
        $247 = HEAP32[$237>>2]|0;
        __ZdlPv($247);
       }
       __ZdlPv($237);
       $yyval$sroa$0$0 = $218;
      }
      break;
     }
     case 7:  {
      $248 = HEAP32[$yyvsp$2>>2]|0;
      $249 = ($248|0)==(0|0);
      if ($249) {
       $yyval$sroa$0$0 = $218;
      } else {
       $250 = HEAP32[674232>>2]|0;
       $251 = (($250) + 16|0);
       $252 = HEAP32[$251>>2]|0;
       $253 = (($250) + 20|0);
       $254 = HEAP32[$253>>2]|0;
       $255 = ($252|0)==($254|0);
       if (!($255)) {
        $256 = ($252|0)==(0|0);
        if ($256) {
         $258 = 0;
        } else {
         HEAP32[$252>>2] = $248;
         $$pre$i = HEAP32[$251>>2]|0;
         $258 = $$pre$i;
        }
        $257 = (($258) + 4|0);
        HEAP32[$251>>2] = $257;
        $yyval$sroa$0$0 = $218;
        break L31;
       }
       $259 = (($250) + 12|0);
       $260 = HEAP32[$259>>2]|0;
       $261 = $252;
       $262 = $260;
       $263 = (($261) - ($262))|0;
       $264 = $263 >> 2;
       $265 = (($264) + 1)|0;
       $266 = ($265>>>0)>(1073741823);
       if ($266) {
        label = 42;
        break L1;
       }
       $267 = ($264>>>0)<(536870911);
       if ($267) {
        $268 = $263 >> 1;
        $269 = ($268>>>0)<($265>>>0);
        $270 = $269 ? $265 : $268;
        $271 = ($270|0)==(0);
        if ($271) {
         $$0$i3$i$i = 0;$275 = 0;
        } else {
         $$0$i2$i$i = $270;
         label = 45;
        }
       } else {
        $$0$i2$i$i = 1073741823;
        label = 45;
       }
       if ((label|0) == 45) {
        label = 0;
        $272 = $$0$i2$i$i << 2;
        $273 = (__Znwj($272)|0);
        $$0$i3$i$i = $$0$i2$i$i;$275 = $273;
       }
       $274 = (($275) + ($264<<2)|0);
       $276 = (($275) + ($$0$i3$i$i<<2)|0);
       $277 = ($274|0)==(0|0);
       if (!($277)) {
        $278 = HEAP32[$yyvsp$2>>2]|0;
        HEAP32[$274>>2] = $278;
       }
       $279 = (($275) + ($265<<2)|0);
       _memcpy(($275|0),($260|0),($263|0))|0;
       HEAP32[$259>>2] = $275;
       HEAP32[$251>>2] = $279;
       HEAP32[$253>>2] = $276;
       $280 = ($260|0)==(0|0);
       if ($280) {
        $yyval$sroa$0$0 = $218;
       } else {
        __ZdlPv($260);
        $yyval$sroa$0$0 = $218;
       }
      }
      break;
     }
     case 2:  {
      $219 = HEAP32[$yyvsp$2>>2]|0;
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc(674240,$219)|0);
      $220 = HEAP32[674232>>2]|0;
      $221 = (($220) + 24|0);
      $222 = HEAP32[$yyvsp$2>>2]|0;
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($221,$222)|0);
      $223 = HEAP32[679312>>2]|0;
      $224 = HEAP32[$223>>2]|0;
      $225 = (($224) + 20|0);
      $226 = HEAP32[$225>>2]|0;
      $227 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$226 & 4095]($223,$227);
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 13:  {
      $281 = (__Znwj(28)|0);
      HEAP32[$281>>2] = 0;
      $282 = (($281) + 4|0);
      HEAP32[$282>>2] = 0;
      $283 = (($281) + 8|0);
      HEAP32[$283>>2] = 0;
      $284 = (($281) + 16|0);
      HEAP32[$284>>2] = 0;
      $285 = (($281) + 20|0);
      HEAP32[$285>>2] = 0;
      $286 = (($281) + 12|0);
      HEAP32[$286>>2] = $284;
      $287 = (($281) + 24|0);
      HEAP32[$287>>2] = 0;
      $288 = HEAP32[((674208 + 20|0))>>2]|0;
      $289 = HEAP32[((674208 + 16|0))>>2]|0;
      $290 = (($288) + -1)|0;
      $291 = (($290) + ($289))|0;
      $292 = HEAP32[((674208 + 4|0))>>2]|0;
      $293 = $291 >>> 10;
      $294 = (($292) + ($293<<2)|0);
      $295 = HEAP32[$294>>2]|0;
      $296 = $291 & 1023;
      $297 = (($295) + ($296<<2)|0);
      $298 = HEAP32[$297>>2]|0;
      $299 = (($298) + 640|0);
      $300 = ($286|0)==($299|0);
      if (!($300)) {
       __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($286,0);
       HEAP32[$285>>2] = 0;
       HEAP32[$286>>2] = $284;
       HEAP32[$284>>2] = 0;
       $301 = HEAP32[$299>>2]|0;
       $302 = (($298) + 644|0);
       $303 = ($301|0)==($302|0);
       if (!($303)) {
        $305 = $301;
        while(1) {
         $304 = (($305) + 16|0);
         $306 = $304;
         $307 = $306;
         $308 = HEAP32[$307>>2]|0;
         $309 = (($306) + 4)|0;
         $310 = $309;
         $311 = HEAP32[$310>>2]|0;
         $312 = $2;
         $313 = $312;
         HEAP32[$313>>2] = $308;
         $314 = (($312) + 4)|0;
         $315 = $314;
         HEAP32[$315>>2] = $311;
         HEAP32[$1>>2] = $284;
         ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$1+0>>2]|0;
         $316 = (__ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($286,$$byval_copy43,$0,$2)|0);
         $317 = HEAP32[$316>>2]|0;
         $318 = ($317|0)==(0|0);
         if ($318) {
          $319 = (__Znwj(24)|0);
          $320 = (($319) + 16|0);
          $321 = $2;
          $322 = $321;
          $323 = HEAP32[$322>>2]|0;
          $324 = (($321) + 4)|0;
          $325 = $324;
          $326 = HEAP32[$325>>2]|0;
          $327 = $320;
          $328 = $327;
          HEAP32[$328>>2] = $323;
          $329 = (($327) + 4)|0;
          $330 = $329;
          HEAP32[$330>>2] = $326;
          $331 = HEAP32[$0>>2]|0;
          HEAP32[$319>>2] = 0;
          $332 = (($319) + 4|0);
          HEAP32[$332>>2] = 0;
          $333 = (($319) + 8|0);
          HEAP32[$333>>2] = $331;
          HEAP32[$316>>2] = $319;
          $334 = HEAP32[$286>>2]|0;
          $335 = HEAP32[$334>>2]|0;
          $336 = ($335|0)==(0|0);
          if ($336) {
           $338 = $319;
          } else {
           HEAP32[$286>>2] = $335;
           $$pre$i$i$i$i$i = HEAP32[$316>>2]|0;
           $338 = $$pre$i$i$i$i$i;
          }
          $337 = HEAP32[$284>>2]|0;
          __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($337,$338);
          $339 = HEAP32[$285>>2]|0;
          $340 = (($339) + 1)|0;
          HEAP32[$285>>2] = $340;
         }
         $341 = (($305) + 4|0);
         $342 = HEAP32[$341>>2]|0;
         $343 = ($342|0)==(0|0);
         if ($343) {
          $$01$i$i$i$i$i = $305;
          while(1) {
           $346 = (($$01$i$i$i$i$i) + 8|0);
           $347 = HEAP32[$346>>2]|0;
           $348 = HEAP32[$347>>2]|0;
           $349 = ($348|0)==($$01$i$i$i$i$i|0);
           if ($349) {
            $$0$i$i$i$i$i = $347;
            break;
           } else {
            $$01$i$i$i$i$i = $347;
           }
          }
         } else {
          $$0$i$i$i$i$i$i = $342;
          while(1) {
           $344 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
           $345 = ($344|0)==(0|0);
           if ($345) {
            $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
            break;
           } else {
            $$0$i$i$i$i$i$i = $344;
           }
          }
         }
         $350 = ($$0$i$i$i$i$i|0)==($302|0);
         if ($350) {
          break;
         } else {
          $305 = $$0$i$i$i$i$i;
         }
        }
       }
      }
      $351 = (($298) + 652|0);
      $352 = HEAP32[$351>>2]|0;
      HEAP32[$287>>2] = $352;
      $353 = (($yyvsp$2) + -4|0);
      $354 = HEAP32[$353>>2]|0;
      $355 = ($281|0)==($354|0);
      if ($355) {
       $360 = $281;
      } else {
       $356 = HEAP32[$354>>2]|0;
       $357 = (($354) + 4|0);
       $358 = HEAP32[$357>>2]|0;
       __ZNSt3__16vectorIPN9ShaderLab14ParserBasePassENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($281,$356,$358);
       $$pr = HEAP32[$353>>2]|0;
       $360 = $$pr;
      }
      $359 = ($360|0)==(0|0);
      if (!($359)) {
       $361 = HEAP32[$360>>2]|0;
       $362 = ($361|0)==(0|0);
       if (!($362)) {
        $363 = (($360) + 4|0);
        $364 = HEAP32[$363>>2]|0;
        $365 = ($364|0)==($361|0);
        if (!($365)) {
         $__new_last2$i$i$i$i$i = $361;
         $scevgep$i$i$i$i$i = (($364) + -4|0);
         $366 = (0 - ($__new_last2$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($366)|0);
         $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
         $367 = $uglygep3$i$i$i$i$i >>> 2;
         $368 = $367 ^ -1;
         $scevgep4$i$i$i$i$i = (($364) + ($368<<2)|0);
         HEAP32[$363>>2] = $scevgep4$i$i$i$i$i;
        }
        __ZdlPv($361);
       }
       __ZdlPv($360);
      }
      __ZL14PopShaderStatev();
      $yyval$sroa$0$0 = $281;
      break;
     }
     case 10:  {
      __ZL15PushShaderStatev();
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 12:  {
      __ZL15PushShaderStatev();
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 11:  {
      __ZL14PopShaderStatev();
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 15:  {
      $377 = HEAP32[674232>>2]|0;
      $378 = (($377) + 48|0);
      $379 = (($yyvsp$2) + -8|0);
      $380 = HEAP32[$379>>2]|0;
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($378,$380)|0);
      $381 = HEAP32[679312>>2]|0;
      $382 = HEAP32[$381>>2]|0;
      $383 = (($382) + 20|0);
      $384 = HEAP32[$383>>2]|0;
      $385 = HEAP32[$379>>2]|0;
      FUNCTION_TABLE_vii[$384 & 4095]($381,$385);
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 16:  {
      $386 = HEAP32[674232>>2]|0;
      $387 = (($386) + 72|0);
      HEAP8[$387>>0] = 1;
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 14:  {
      $369 = HEAP32[674232>>2]|0;
      $370 = (($369) + 48|0);
      $371 = HEAP32[$yyvsp$2>>2]|0;
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($370,$371)|0);
      $372 = HEAP32[679312>>2]|0;
      $373 = HEAP32[$372>>2]|0;
      $374 = (($373) + 20|0);
      $375 = HEAP32[$374>>2]|0;
      $376 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$375 & 4095]($372,$376);
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 17:  {
      $388 = HEAP32[674232>>2]|0;
      $389 = (($388) + 60|0);
      $390 = (($yyvsp$2) + -8|0);
      $391 = HEAP32[$390>>2]|0;
      $392 = HEAP32[$yyvsp$2>>2]|0;
      $393 = (_strlen(($391|0))|0);
      $394 = ($393>>>0)>(4294967279);
      if ($394) {
       label = 78;
       break L1;
      }
      $395 = ($393>>>0)<(11);
      if ($395) {
       $396 = $393 << 1;
       $397 = $396&255;
       HEAP8[$3>>0] = $397;
       $422 = $397;$__p$0$i$i$i$i$i = $45;
      } else {
       $398 = (($393) + 16)|0;
       $399 = $398 & -16;
       $400 = (__Znwj($399)|0);
       HEAP32[$48>>2] = $400;
       $401 = $399 | 1;
       HEAP32[$3>>2] = $401;
       HEAP32[$51>>2] = $393;
       $402 = $401&255;
       $422 = $402;$__p$0$i$i$i$i$i = $400;
      }
      _memcpy(($__p$0$i$i$i$i$i|0),($391|0),($393|0))|0;
      $403 = (($__p$0$i$i$i$i$i) + ($393)|0);
      HEAP8[$403>>0] = 0;
      $404 = (_strlen(($392|0))|0);
      $405 = ($404>>>0)>(4294967279);
      if ($405) {
       label = 83;
       break L1;
      }
      $408 = ($404>>>0)<(11);
      if ($408) {
       $409 = $404 << 1;
       $410 = $409&255;
       HEAP8[$46>>0] = $410;
       $__p$0$i$i$i2$i$i = $47;
      } else {
       $411 = (($404) + 16)|0;
       $412 = $411 & -16;
       __THREW__ = 0;
       $413 = (invoke_ii(2988,($412|0))|0);
       $414 = __THREW__; __THREW__ = 0;
       $415 = $414&1;
       if ($415) {
        label = 89;
        break L1;
       }
       HEAP32[$49>>2] = $413;
       $416 = $412 | 1;
       HEAP32[$46>>2] = $416;
       HEAP32[$50>>2] = $404;
       $__p$0$i$i$i2$i$i = $413;
      }
      _memcpy(($__p$0$i$i$i2$i$i|0),($392|0),($404|0))|0;
      $425 = (($__p$0$i$i$i2$i$i) + ($404)|0);
      HEAP8[$425>>0] = 0;
      $426 = (($388) + 64|0);
      $427 = HEAP32[$426>>2]|0;
      $428 = (($388) + 68|0);
      $429 = HEAP32[$428>>2]|0;
      $430 = ($427|0)==($429|0);
      if ($430) {
       __THREW__ = 0;
       invoke_vii(3259,($389|0),($3|0));
       $436 = __THREW__; __THREW__ = 0;
       $437 = $436&1;
       if ($437) {
        label = 105;
        break L1;
       }
      } else {
       $431 = ($427|0)==(0|0);
       if ($431) {
        $435 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(3223,($427|0),($3|0));
        $432 = __THREW__; __THREW__ = 0;
        $433 = $432&1;
        if ($433) {
         label = 105;
         break L1;
        }
        $$pre$i22 = HEAP32[$426>>2]|0;
        $435 = $$pre$i22;
       }
       $434 = (($435) + 24|0);
       HEAP32[$426>>2] = $434;
      }
      $438 = HEAP8[$46>>0]|0;
      $439 = $438 & 1;
      $440 = ($439<<24>>24)==(0);
      if (!($440)) {
       $441 = HEAP32[$49>>2]|0;
       __ZdlPv($441);
      }
      $442 = HEAP8[$3>>0]|0;
      $443 = $442 & 1;
      $444 = ($443<<24>>24)==(0);
      if (!($444)) {
       $445 = HEAP32[$48>>2]|0;
       __ZdlPv($445);
      }
      $446 = HEAP32[679312>>2]|0;
      $447 = HEAP32[$446>>2]|0;
      $448 = (($447) + 20|0);
      $449 = HEAP32[$448>>2]|0;
      $450 = HEAP32[$390>>2]|0;
      FUNCTION_TABLE_vii[$449 & 4095]($446,$450);
      $451 = HEAP32[679312>>2]|0;
      $452 = HEAP32[$451>>2]|0;
      $453 = (($452) + 20|0);
      $454 = HEAP32[$453>>2]|0;
      $455 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$454 & 4095]($451,$455);
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 19:  {
      $474 = (__Znwj(12)|0);
      HEAP32[$474>>2] = 0;
      $475 = (($474) + 4|0);
      HEAP32[$475>>2] = 0;
      $476 = (($474) + 8|0);
      HEAP32[$476>>2] = 0;
      $477 = (__Znwj(4)|0);
      $478 = (($477) + 4|0);
      $479 = ($477|0)==(0|0);
      if (!($479)) {
       $480 = HEAP32[$yyvsp$2>>2]|0;
       HEAP32[$477>>2] = $480;
      }
      $481 = (($477) + 4|0);
      HEAP32[$474>>2] = $477;
      HEAP32[$475>>2] = $481;
      HEAP32[$476>>2] = $478;
      $yyval$sroa$0$0 = $474;
      break;
     }
     case 18:  {
      $466 = HEAP32[674232>>2]|0;
      $467 = (($466) + 36|0);
      $468 = HEAP32[$yyvsp$2>>2]|0;
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($467,$468)|0);
      $469 = HEAP32[679312>>2]|0;
      $470 = HEAP32[$469>>2]|0;
      $471 = (($470) + 20|0);
      $472 = HEAP32[$471>>2]|0;
      $473 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$472 & 4095]($469,$473);
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 20:  {
      $482 = (($yyvsp$2) + -8|0);
      $483 = HEAP32[$482>>2]|0;
      $484 = (($483) + 4|0);
      $485 = HEAP32[$484>>2]|0;
      $486 = (($483) + 8|0);
      $487 = HEAP32[$486>>2]|0;
      $488 = ($485|0)==($487|0);
      if (!($488)) {
       $489 = ($485|0)==(0|0);
       if ($489) {
        $492 = 0;
       } else {
        $490 = HEAP32[$yyvsp$2>>2]|0;
        HEAP32[$485>>2] = $490;
        $$pre$i30 = HEAP32[$484>>2]|0;
        $492 = $$pre$i30;
       }
       $491 = (($492) + 4|0);
       HEAP32[$484>>2] = $491;
       $yyval$sroa$0$0 = $483;
       break L31;
      }
      $493 = HEAP32[$483>>2]|0;
      $494 = $485;
      $495 = $493;
      $496 = (($494) - ($495))|0;
      $497 = $496 >> 2;
      $498 = (($497) + 1)|0;
      $499 = ($498>>>0)>(1073741823);
      if ($499) {
       label = 118;
       break L1;
      }
      $500 = ($497>>>0)<(536870911);
      if ($500) {
       $501 = $496 >> 1;
       $502 = ($501>>>0)<($498>>>0);
       $503 = $502 ? $498 : $501;
       $504 = ($503|0)==(0);
       if ($504) {
        $$0$i3$i$i35 = 0;$508 = 0;
       } else {
        $$0$i2$i$i33 = $503;
        label = 121;
       }
      } else {
       $$0$i2$i$i33 = 1073741823;
       label = 121;
      }
      if ((label|0) == 121) {
       label = 0;
       $505 = $$0$i2$i$i33 << 2;
       $506 = (__Znwj($505)|0);
       $$0$i3$i$i35 = $$0$i2$i$i33;$508 = $506;
      }
      $507 = (($508) + ($497<<2)|0);
      $509 = (($508) + ($$0$i3$i$i35<<2)|0);
      $510 = ($507|0)==(0|0);
      if (!($510)) {
       $511 = HEAP32[$yyvsp$2>>2]|0;
       HEAP32[$507>>2] = $511;
      }
      $512 = (($508) + ($498<<2)|0);
      _memcpy(($508|0),($493|0),($496|0))|0;
      HEAP32[$483>>2] = $508;
      HEAP32[$484>>2] = $512;
      HEAP32[$486>>2] = $509;
      $513 = ($493|0)==(0|0);
      if ($513) {
       $yyval$sroa$0$0 = $483;
      } else {
       __ZdlPv($493);
       $yyval$sroa$0$0 = $483;
      }
      break;
     }
     case 22:  {
      $514 = (__Znwj(700)|0);
      $515 = HEAP32[((674208 + 20|0))>>2]|0;
      $516 = HEAP32[((674208 + 16|0))>>2]|0;
      $517 = (($515) + -1)|0;
      $518 = (($517) + ($516))|0;
      $519 = HEAP32[((674208 + 4|0))>>2]|0;
      $520 = $518 >>> 10;
      $521 = (($519) + ($520<<2)|0);
      $522 = HEAP32[$521>>2]|0;
      $523 = $518 & 1023;
      $524 = (($522) + ($523<<2)|0);
      $525 = HEAP32[$524>>2]|0;
      $526 = (($514) + 4|0);
      HEAP32[$526>>2] = 0;
      HEAP32[$514>>2] = ((679936 + 8|0));
      $527 = (($514) + 8|0);
      __THREW__ = 0;
      invoke_vii(3260,($527|0),($525|0));
      $528 = __THREW__; __THREW__ = 0;
      $529 = $528&1;
      if ($529) {
       label = 129;
       break L1;
      }
      $530 = (($514) + 664|0);
      ;HEAP32[$530+0>>2]=0|0;HEAP32[$530+4>>2]=0|0;HEAP32[$530+8>>2]=0|0;
      $scevgep810 = (($514) + 676|0);
      ;HEAP32[$scevgep810+0>>2]=HEAP32[677800+0>>2]|0;HEAP32[$scevgep810+4>>2]=HEAP32[677800+4>>2]|0;HEAP32[$scevgep810+8>>2]=HEAP32[677800+8>>2]|0;HEAP32[$scevgep810+12>>2]=HEAP32[677800+12>>2]|0;HEAP32[$scevgep810+16>>2]=HEAP32[677800+16>>2]|0;HEAP32[$scevgep810+20>>2]=HEAP32[677800+20>>2]|0;
      ;HEAP32[677800+0>>2]=0|0;HEAP32[677800+4>>2]=0|0;HEAP32[677800+8>>2]=0|0;HEAP32[677800+12>>2]=0|0;HEAP32[677800+16>>2]=0|0;HEAP32[677800+20>>2]=0|0;
      $531 = (($yyvsp$2) + -4|0);
      $532 = HEAP32[$531>>2]|0;
      $533 = ($530|0)==($532|0);
      if ($533) {
       $540 = $530;
      } else {
       $536 = HEAP32[$532>>2]|0;
       $537 = (($532) + 4|0);
       $538 = HEAP32[$537>>2]|0;
       __ZNSt3__16vectorIN9ShaderLab16ParserSetTextureENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($530,$536,$538);
       $$pr320 = HEAP32[$531>>2]|0;
       $540 = $$pr320;
      }
      $539 = ($540|0)==(0|0);
      if (!($539)) {
       $541 = HEAP32[$540>>2]|0;
       $542 = ($541|0)==(0|0);
       if (!($542)) {
        $543 = (($540) + 4|0);
        $544 = HEAP32[$543>>2]|0;
        $545 = ($544|0)==($541|0);
        if (!($545)) {
         $__new_last2$i$i$i$i$i40 = $541;
         $scevgep$i$i$i$i$i41 = (($544) + -52|0);
         $546 = (0 - ($__new_last2$i$i$i$i$i40))|0;
         $uglygep$i$i$i$i$i43 = (($scevgep$i$i$i$i$i41) + ($546)|0);
         $uglygep3$i$i$i$i$i44 = $uglygep$i$i$i$i$i43;
         $547 = (($uglygep3$i$i$i$i$i44>>>0) / 52)&-1;
         $548 = $547 ^ -1;
         $scevgep4$i$i$i$i$i45 = (($544) + (($548*52)|0)|0);
         HEAP32[$543>>2] = $scevgep4$i$i$i$i$i45;
        }
        __ZdlPv($541);
       }
       __ZdlPv($540);
      }
      __ZL14PopShaderStatev();
      $yyval$sroa$0$0 = $514;
      break;
     }
     case 21:  {
      __ZL15PushShaderStatev();
      ;HEAP32[677800+0>>2]=0|0;HEAP32[677800+4>>2]=0|0;HEAP32[677800+8>>2]=0|0;HEAP32[677800+12>>2]=0|0;HEAP32[677800+16>>2]=0|0;HEAP32[677800+20>>2]=0|0;
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 23:  {
      $549 = (($yyvsp$2) + -4|0);
      $550 = HEAP32[$549>>2]|0;
      $yyval$sroa$0$0 = $550;
      break;
     }
     case 25:  {
      $581 = (__Znwj(44)|0);
      $582 = (($581) + 4|0);
      HEAP32[$582>>2] = 2;
      HEAP32[$581>>2] = ((678840 + 8|0));
      $583 = (($581) + 8|0);
      $584 = (($581) + 36|0);
      HEAP32[$584>>2] = 0;
      $585 = (($581) + 40|0);
      HEAP32[$585>>2] = 0;
      $586 = (($581) + 32|0);
      ;HEAP32[$583+0>>2]=0|0;HEAP32[$583+4>>2]=0|0;HEAP32[$583+8>>2]=0|0;HEAP32[$583+12>>2]=0|0;HEAP32[$583+16>>2]=0|0;HEAP32[$583+20>>2]=0|0;
      HEAP32[$586>>2] = $584;
      $yyval$sroa$0$0 = $581;
      break;
     }
     case 26:  {
      $587 = (($yyvsp$2) + -16|0);
      $588 = HEAP32[$587>>2]|0;
      $589 = (($yyvsp$2) + -4|0);
      $590 = HEAP32[$589>>2]|0;
      __ZN9ShaderLab14ParserGrabPass7AddTagsERKNSt3__13mapIiiNS1_4lessIiEENS1_9allocatorINS1_4pairIKiiEEEEEE($588,$590);
      $591 = HEAP32[$589>>2]|0;
      $592 = ($591|0)==(0|0);
      if ($592) {
       $yyval$sroa$0$0 = $588;
      } else {
       $593 = (($591) + 4|0);
       $594 = HEAP32[$593>>2]|0;
       __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($591,$594);
       __ZdlPv($591);
       $yyval$sroa$0$0 = $588;
      }
      break;
     }
     case 27:  {
      $595 = (($yyvsp$2) + -8|0);
      $596 = HEAP32[$595>>2]|0;
      $597 = HEAP32[$yyvsp$2>>2]|0;
      $598 = (_strlen(($597|0))|0);
      $599 = ($598>>>0)>(4294967279);
      if ($599) {
       label = 154;
       break L1;
      }
      $600 = ($598>>>0)<(11);
      if ($600) {
       $601 = $598 << 1;
       $602 = $601&255;
       HEAP8[$5>>0] = $602;
       $__p$0$i$i$i = $52;
      } else {
       $603 = (($598) + 16)|0;
       $604 = $603 & -16;
       $605 = (__Znwj($604)|0);
       HEAP32[$54>>2] = $605;
       $606 = $604 | 1;
       HEAP32[$5>>2] = $606;
       HEAP32[$57>>2] = $598;
       $__p$0$i$i$i = $605;
      }
      _memcpy(($__p$0$i$i$i|0),($597|0),($598|0))|0;
      $607 = (($__p$0$i$i$i) + ($598)|0);
      HEAP8[$607>>0] = 0;
      __THREW__ = 0;
      invoke_vii(3261,($4|0),($5|0));
      $608 = __THREW__; __THREW__ = 0;
      $609 = $608&1;
      if ($609) {
       label = 180;
       break L1;
      }
      $610 = (($596) + 8|0);
      $611 = HEAP8[$4>>0]|0;
      $612 = $611 & 1;
      $613 = ($612<<24>>24)==(0);
      if ($613) {
       $616 = $611&255;
       $617 = $616 >>> 1;
       $626 = $617;$634 = $53;
      } else {
       $614 = HEAP32[$55>>2]|0;
       $615 = HEAP32[$56>>2]|0;
       $626 = $615;$634 = $614;
      }
      $618 = HEAP8[$610>>0]|0;
      $619 = $618 & 1;
      $620 = ($619<<24>>24)==(0);
      if ($620) {
       $625 = 10;$628 = $618;
      } else {
       $621 = HEAP32[$610>>2]|0;
       $622 = $621 & -2;
       $phitmp$i$i = (($622) + -1)|0;
       $623 = $621&255;
       $625 = $phitmp$i$i;$628 = $623;
      }
      $624 = ($625>>>0)<($626>>>0);
      $627 = $628 & 1;
      $629 = ($627<<24>>24)==(0);
      do {
       if ($624) {
        if ($629) {
         $644 = $628&255;
         $645 = $644 >>> 1;
         $647 = $645;
        } else {
         $642 = (($596) + 12|0);
         $643 = HEAP32[$642>>2]|0;
         $647 = $643;
        }
        $646 = (($626) - ($625))|0;
        __THREW__ = 0;
        invoke_viiiiiiii(22,($610|0),($625|0),($646|0),($647|0),0,($647|0),($626|0),($634|0));
        $648 = __THREW__; __THREW__ = 0;
        $649 = $648&1;
        if ($649) {
         label = 181;
         break L1;
        }
       } else {
        if ($629) {
         $632 = (($610) + 1|0);
         $633 = $632;
        } else {
         $630 = (($596) + 16|0);
         $631 = HEAP32[$630>>2]|0;
         $633 = $631;
        }
        _memmove(($633|0),($634|0),($626|0))|0;
        $635 = (($633) + ($626)|0);
        HEAP8[$635>>0] = 0;
        $636 = HEAP8[$610>>0]|0;
        $637 = $636 & 1;
        $638 = ($637<<24>>24)==(0);
        if ($638) {
         $640 = $626 << 1;
         $641 = $640&255;
         HEAP8[$610>>0] = $641;
         break;
        } else {
         $639 = (($596) + 12|0);
         HEAP32[$639>>2] = $626;
         break;
        }
       }
      } while(0);
      $650 = HEAP8[$4>>0]|0;
      $651 = $650 & 1;
      $652 = ($651<<24>>24)==(0);
      if (!($652)) {
       $653 = HEAP32[$55>>2]|0;
       __ZdlPv($653);
      }
      $654 = HEAP8[$5>>0]|0;
      $655 = $654 & 1;
      $656 = ($655<<24>>24)==(0);
      if (!($656)) {
       $657 = HEAP32[$54>>2]|0;
       __ZdlPv($657);
      }
      $658 = HEAP32[679312>>2]|0;
      $659 = HEAP32[$658>>2]|0;
      $660 = (($659) + 20|0);
      $661 = HEAP32[$660>>2]|0;
      $662 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$661 & 4095]($658,$662);
      $yyval$sroa$0$0 = $596;
      break;
     }
     case 24:  {
      $551 = (__Znwj(20)|0);
      $552 = HEAP32[$yyvsp$2>>2]|0;
      $553 = (($551) + 4|0);
      HEAP32[$553>>2] = 1;
      HEAP32[$551>>2] = ((678856 + 8|0));
      $554 = (($551) + 8|0);
      $555 = (_strlen(($552|0))|0);
      $556 = ($555>>>0)>(2147483631);
      if ($556) {
       label = 140;
       break L1;
      }
      $559 = ($555>>>0)<(11);
      if ($559) {
       $560 = $555 << 1;
       $561 = $560&255;
       HEAP8[$554>>0] = $561;
       $562 = (($551) + 9|0);
       $__p$0$i$i$i$i$i$i = $562;
      } else {
       $563 = (($555) + 16)|0;
       $564 = $563 & -16;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy43+0>>2]=HEAP32[$0+0>>2]|0;
       $565 = (invoke_iiiiiii(102,($564|0),16,($$byval_copy43|0),0,(678832|0),79)|0);
       $566 = __THREW__; __THREW__ = 0;
       $567 = $566&1;
       if ($567) {
        label = 147;
        break L1;
       }
       $568 = (($551) + 16|0);
       HEAP32[$568>>2] = $565;
       $569 = $564 | 1;
       HEAP32[$554>>2] = $569;
       $570 = (($551) + 12|0);
       HEAP32[$570>>2] = $555;
       $__p$0$i$i$i$i$i$i = $565;
      }
      _memcpy(($__p$0$i$i$i$i$i$i|0),($552|0),($555|0))|0;
      $571 = (($__p$0$i$i$i$i$i$i) + ($555)|0);
      HEAP8[$571>>0] = 0;
      $572 = HEAP32[679312>>2]|0;
      $573 = HEAP32[$572>>2]|0;
      $574 = (($573) + 20|0);
      $575 = HEAP32[$574>>2]|0;
      $576 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$575 & 4095]($572,$576);
      $yyval$sroa$0$0 = $551;
      break;
     }
     case 30:  {
      $706 = (($yyvsp$2) + -4|0);
      $707 = HEAP32[$706>>2]|0;
      $yyval$sroa$0$0 = $707;
      break;
     }
     case 29:  {
      $yyval$sroa$0$0 = 0;
      break;
     }
     case 28:  {
      $675 = (($yyvsp$2) + -4|0);
      $676 = HEAP32[$675>>2]|0;
      $677 = (($676) + 20|0);
      $678 = HEAP32[$yyvsp$2>>2]|0;
      $679 = (_strlen(($678|0))|0);
      $680 = ($679>>>0)>(4294967279);
      if ($680) {
       label = 186;
       break L1;
      }
      $681 = ($679>>>0)<(11);
      if ($681) {
       $682 = $679 << 1;
       $683 = $682&255;
       HEAP8[$6>>0] = $683;
       $__p$0$i$i$i55 = $58;
      } else {
       $684 = (($679) + 16)|0;
       $685 = $684 & -16;
       $686 = (__Znwj($685)|0);
       HEAP32[$59>>2] = $686;
       $687 = $685 | 1;
       HEAP32[$6>>2] = $687;
       HEAP32[$60>>2] = $679;
       $__p$0$i$i$i55 = $686;
      }
      _memcpy(($__p$0$i$i$i55|0),($678|0),($679|0))|0;
      $688 = (($__p$0$i$i$i55) + ($679)|0);
      HEAP8[$688>>0] = 0;
      __THREW__ = 0;
      (invoke_iii(2233,($677|0),($6|0))|0);
      $689 = __THREW__; __THREW__ = 0;
      $690 = $689&1;
      if ($690) {
       label = 194;
       break L1;
      }
      $691 = HEAP8[$6>>0]|0;
      $692 = $691 & 1;
      $693 = ($692<<24>>24)==(0);
      if (!($693)) {
       $694 = HEAP32[$59>>2]|0;
       __ZdlPv($694);
      }
      $695 = HEAP32[679312>>2]|0;
      $696 = HEAP32[$695>>2]|0;
      $697 = (($696) + 20|0);
      $698 = HEAP32[$697>>2]|0;
      $699 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$698 & 4095]($695,$699);
      $yyval$sroa$0$0 = $676;
      break;
     }
     case 31:  {
      $708 = (__Znwj(12)|0);
      $709 = $708;
      $710 = $709;
      HEAP32[$710>>2] = 0;
      $711 = (($709) + 4)|0;
      $712 = $711;
      HEAP32[$712>>2] = 0;
      HEAP32[$708>>2] = 0;
      $713 = (($708) + 4|0);
      HEAP32[$713>>2] = 0;
      $714 = (($708) + 8|0);
      HEAP32[$714>>2] = 0;
      $yyval$sroa$0$0 = $708;
      break;
     }
     case 32:  {
      $715 = (($yyvsp$2) + -36|0);
      $716 = HEAP32[$715>>2]|0;
      $717 = (($yyvsp$2) + -28|0);
      $718 = HEAP32[$717>>2]|0;
      $719 = (($yyvsp$2) + -20|0);
      $720 = HEAP32[$719>>2]|0;
      $721 = (($yyvsp$2) + -32|0);
      $722 = HEAP32[$721>>2]|0;
      $723 = HEAP32[$yyvsp$2>>2]|0;
      __ZN9ShaderLab16ParserProperties16AddColorPropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEERK8Vector4f($716,$718,$720,$722,$723);
      $724 = HEAP32[$yyvsp$2>>2]|0;
      $725 = ($724|0)==(0|0);
      if (!($725)) {
       __ZdlPv($724);
      }
      $726 = HEAP32[$721>>2]|0;
      $727 = ($726|0)==(0|0);
      if (!($727)) {
       $728 = HEAP32[$726>>2]|0;
       $729 = ($728|0)==(0|0);
       if (!($729)) {
        $730 = (($726) + 4|0);
        $731 = HEAP32[$730>>2]|0;
        $732 = ($731|0)==($728|0);
        if ($732) {
         $742 = $728;
        } else {
         $734 = $731;
         while(1) {
          $733 = (($734) + -12|0);
          HEAP32[$730>>2] = $733;
          $735 = HEAP8[$733>>0]|0;
          $736 = $735 & 1;
          $737 = ($736<<24>>24)==(0);
          if ($737) {
           $739 = $733;
          } else {
           $740 = (($734) + -4|0);
           $741 = HEAP32[$740>>2]|0;
           __ZdlPv($741);
           $$pre$i$i$i$i$i60 = HEAP32[$730>>2]|0;
           $739 = $$pre$i$i$i$i$i60;
          }
          $738 = ($739|0)==($728|0);
          if ($738) {
           break;
          } else {
           $734 = $739;
          }
         }
         $$pre$i$i$i = HEAP32[$726>>2]|0;
         $742 = $$pre$i$i$i;
        }
        __ZdlPv($742);
       }
       __ZdlPv($726);
      }
      $743 = HEAP32[679312>>2]|0;
      $744 = HEAP32[$743>>2]|0;
      $745 = (($744) + 20|0);
      $746 = HEAP32[$745>>2]|0;
      $747 = HEAP32[$717>>2]|0;
      FUNCTION_TABLE_vii[$746 & 4095]($743,$747);
      $748 = HEAP32[679312>>2]|0;
      $749 = HEAP32[$748>>2]|0;
      $750 = (($749) + 20|0);
      $751 = HEAP32[$750>>2]|0;
      $752 = HEAP32[$719>>2]|0;
      FUNCTION_TABLE_vii[$751 & 4095]($748,$752);
      $yyval$sroa$0$0 = $716;
      break;
     }
     case 33:  {
      $753 = (($yyvsp$2) + -36|0);
      $754 = HEAP32[$753>>2]|0;
      $755 = (($yyvsp$2) + -28|0);
      $756 = HEAP32[$755>>2]|0;
      $757 = (($yyvsp$2) + -20|0);
      $758 = HEAP32[$757>>2]|0;
      $759 = (($yyvsp$2) + -32|0);
      $760 = HEAP32[$759>>2]|0;
      $761 = HEAP32[$yyvsp$2>>2]|0;
      __ZN9ShaderLab16ParserProperties17AddVectorPropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEERK8Vector4f($754,$756,$758,$760,$761);
      $762 = HEAP32[$yyvsp$2>>2]|0;
      $763 = ($762|0)==(0|0);
      if (!($763)) {
       __ZdlPv($762);
      }
      $764 = HEAP32[$759>>2]|0;
      $765 = ($764|0)==(0|0);
      if (!($765)) {
       $766 = HEAP32[$764>>2]|0;
       $767 = ($766|0)==(0|0);
       if (!($767)) {
        $768 = (($764) + 4|0);
        $769 = HEAP32[$768>>2]|0;
        $770 = ($769|0)==($766|0);
        if ($770) {
         $780 = $766;
        } else {
         $772 = $769;
         while(1) {
          $771 = (($772) + -12|0);
          HEAP32[$768>>2] = $771;
          $773 = HEAP8[$771>>0]|0;
          $774 = $773 & 1;
          $775 = ($774<<24>>24)==(0);
          if ($775) {
           $777 = $771;
          } else {
           $778 = (($772) + -4|0);
           $779 = HEAP32[$778>>2]|0;
           __ZdlPv($779);
           $$pre$i$i$i$i$i63 = HEAP32[$768>>2]|0;
           $777 = $$pre$i$i$i$i$i63;
          }
          $776 = ($777|0)==($766|0);
          if ($776) {
           break;
          } else {
           $772 = $777;
          }
         }
         $$pre$i$i$i64 = HEAP32[$764>>2]|0;
         $780 = $$pre$i$i$i64;
        }
        __ZdlPv($780);
       }
       __ZdlPv($764);
      }
      $781 = HEAP32[679312>>2]|0;
      $782 = HEAP32[$781>>2]|0;
      $783 = (($782) + 20|0);
      $784 = HEAP32[$783>>2]|0;
      $785 = HEAP32[$755>>2]|0;
      FUNCTION_TABLE_vii[$784 & 4095]($781,$785);
      $786 = HEAP32[679312>>2]|0;
      $787 = HEAP32[$786>>2]|0;
      $788 = (($787) + 20|0);
      $789 = HEAP32[$788>>2]|0;
      $790 = HEAP32[$757>>2]|0;
      FUNCTION_TABLE_vii[$789 & 4095]($786,$790);
      $yyval$sroa$0$0 = $754;
      break;
     }
     case 34:  {
      $791 = (($yyvsp$2) + -36|0);
      $792 = HEAP32[$791>>2]|0;
      $793 = (($yyvsp$2) + -28|0);
      $794 = HEAP32[$793>>2]|0;
      $795 = (($yyvsp$2) + -20|0);
      $796 = HEAP32[$795>>2]|0;
      $797 = (($yyvsp$2) + -32|0);
      $798 = HEAP32[$797>>2]|0;
      $799 = HEAP32[$yyvsp$2>>2]|0;
      __ZN9ShaderLab16ParserProperties17AddVectorPropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEERK8Vector4f($792,$794,$796,$798,$799);
      $800 = HEAP32[$yyvsp$2>>2]|0;
      $801 = ($800|0)==(0|0);
      if (!($801)) {
       __ZdlPv($800);
      }
      $802 = HEAP32[$797>>2]|0;
      $803 = ($802|0)==(0|0);
      if (!($803)) {
       $804 = HEAP32[$802>>2]|0;
       $805 = ($804|0)==(0|0);
       if (!($805)) {
        $806 = (($802) + 4|0);
        $807 = HEAP32[$806>>2]|0;
        $808 = ($807|0)==($804|0);
        if ($808) {
         $818 = $804;
        } else {
         $810 = $807;
         while(1) {
          $809 = (($810) + -12|0);
          HEAP32[$806>>2] = $809;
          $811 = HEAP8[$809>>0]|0;
          $812 = $811 & 1;
          $813 = ($812<<24>>24)==(0);
          if ($813) {
           $815 = $809;
          } else {
           $816 = (($810) + -4|0);
           $817 = HEAP32[$816>>2]|0;
           __ZdlPv($817);
           $$pre$i$i$i$i$i70 = HEAP32[$806>>2]|0;
           $815 = $$pre$i$i$i$i$i70;
          }
          $814 = ($815|0)==($804|0);
          if ($814) {
           break;
          } else {
           $810 = $815;
          }
         }
         $$pre$i$i$i71 = HEAP32[$802>>2]|0;
         $818 = $$pre$i$i$i71;
        }
        __ZdlPv($818);
       }
       __ZdlPv($802);
      }
      $819 = HEAP32[679312>>2]|0;
      $820 = HEAP32[$819>>2]|0;
      $821 = (($820) + 20|0);
      $822 = HEAP32[$821>>2]|0;
      $823 = HEAP32[$793>>2]|0;
      FUNCTION_TABLE_vii[$822 & 4095]($819,$823);
      $824 = HEAP32[679312>>2]|0;
      $825 = HEAP32[$824>>2]|0;
      $826 = (($825) + 20|0);
      $827 = HEAP32[$826>>2]|0;
      $828 = HEAP32[$795>>2]|0;
      FUNCTION_TABLE_vii[$827 & 4095]($824,$828);
      $yyval$sroa$0$0 = $792;
      break;
     }
     case 37:  {
      $888 = (($yyvsp$2) + -36|0);
      $889 = HEAP32[$888>>2]|0;
      $890 = (__Znwj(16)|0);
      __THREW__ = 0;
      invoke_vi(3593,($890|0));
      $891 = __THREW__; __THREW__ = 0;
      $892 = $891&1;
      if ($892) {
       label = 260;
       break L1;
      }
      $893 = HEAP32[$yyvsp$2>>2]|0;
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($890,$893)|0);
      $894 = HEAP32[679312>>2]|0;
      $895 = HEAP32[$894>>2]|0;
      $896 = (($895) + 20|0);
      $897 = HEAP32[$896>>2]|0;
      $898 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$897 & 4095]($894,$898);
      $899 = (($yyvsp$2) + -12|0);
      $900 = HEAP32[$899>>2]|0;
      $901 = (($890) + 12|0);
      HEAP32[$901>>2] = $900;
      $902 = (($yyvsp$2) + -28|0);
      $903 = HEAP32[$902>>2]|0;
      $904 = (($yyvsp$2) + -20|0);
      $905 = HEAP32[$904>>2]|0;
      $906 = (($yyvsp$2) + -32|0);
      $907 = HEAP32[$906>>2]|0;
      __ZN9ShaderLab16ParserProperties18AddTexturePropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEERKNS_21ParserTexturePropertyE($889,$903,$905,$907,$890);
      $908 = HEAP32[$906>>2]|0;
      $909 = ($908|0)==(0|0);
      if (!($909)) {
       $910 = HEAP32[$908>>2]|0;
       $911 = ($910|0)==(0|0);
       if (!($911)) {
        $912 = (($908) + 4|0);
        $913 = HEAP32[$912>>2]|0;
        $914 = ($913|0)==($910|0);
        if ($914) {
         $924 = $910;
        } else {
         $916 = $913;
         while(1) {
          $915 = (($916) + -12|0);
          HEAP32[$912>>2] = $915;
          $917 = HEAP8[$915>>0]|0;
          $918 = $917 & 1;
          $919 = ($918<<24>>24)==(0);
          if ($919) {
           $921 = $915;
          } else {
           $922 = (($916) + -4|0);
           $923 = HEAP32[$922>>2]|0;
           __ZdlPv($923);
           $$pre$i$i$i$i$i84 = HEAP32[$912>>2]|0;
           $921 = $$pre$i$i$i$i$i84;
          }
          $920 = ($921|0)==($910|0);
          if ($920) {
           break;
          } else {
           $916 = $921;
          }
         }
         $$pre$i$i$i85 = HEAP32[$908>>2]|0;
         $924 = $$pre$i$i$i85;
        }
        __ZdlPv($924);
       }
       __ZdlPv($908);
      }
      $925 = HEAP32[679312>>2]|0;
      $926 = HEAP32[$925>>2]|0;
      $927 = (($926) + 20|0);
      $928 = HEAP32[$927>>2]|0;
      $929 = HEAP32[$902>>2]|0;
      FUNCTION_TABLE_vii[$928 & 4095]($925,$929);
      $930 = HEAP32[679312>>2]|0;
      $931 = HEAP32[$930>>2]|0;
      $932 = (($931) + 20|0);
      $933 = HEAP32[$932>>2]|0;
      $934 = HEAP32[$904>>2]|0;
      FUNCTION_TABLE_vii[$933 & 4095]($930,$934);
      $935 = ($890|0)==(0|0);
      if ($935) {
       $yyval$sroa$0$0 = $889;
      } else {
       $936 = HEAP8[$890>>0]|0;
       $937 = $936 & 1;
       $938 = ($937<<24>>24)==(0);
       if (!($938)) {
        $939 = (($890) + 8|0);
        $940 = HEAP32[$939>>2]|0;
        __ZdlPv($940);
       }
       __ZdlPv($890);
       $yyval$sroa$0$0 = $889;
      }
      break;
     }
     case 35:  {
      $829 = (($yyvsp$2) + -36|0);
      $830 = HEAP32[$829>>2]|0;
      $831 = (($yyvsp$2) + -28|0);
      $832 = HEAP32[$831>>2]|0;
      $833 = (($yyvsp$2) + -20|0);
      $834 = HEAP32[$833>>2]|0;
      $835 = (($yyvsp$2) + -32|0);
      $836 = HEAP32[$835>>2]|0;
      $837 = Math_fround(HEAPF32[$yyvsp$2>>2]);
      __ZN9ShaderLab16ParserProperties16AddFloatPropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEEf($830,$832,$834,$836,$837);
      $838 = HEAP32[$835>>2]|0;
      $839 = ($838|0)==(0|0);
      if (!($839)) {
       $840 = HEAP32[$838>>2]|0;
       $841 = ($840|0)==(0|0);
       if (!($841)) {
        $842 = (($838) + 4|0);
        $843 = HEAP32[$842>>2]|0;
        $844 = ($843|0)==($840|0);
        if ($844) {
         $854 = $840;
        } else {
         $846 = $843;
         while(1) {
          $845 = (($846) + -12|0);
          HEAP32[$842>>2] = $845;
          $847 = HEAP8[$845>>0]|0;
          $848 = $847 & 1;
          $849 = ($848<<24>>24)==(0);
          if ($849) {
           $851 = $845;
          } else {
           $852 = (($846) + -4|0);
           $853 = HEAP32[$852>>2]|0;
           __ZdlPv($853);
           $$pre$i$i$i$i$i77 = HEAP32[$842>>2]|0;
           $851 = $$pre$i$i$i$i$i77;
          }
          $850 = ($851|0)==($840|0);
          if ($850) {
           break;
          } else {
           $846 = $851;
          }
         }
         $$pre$i$i$i78 = HEAP32[$838>>2]|0;
         $854 = $$pre$i$i$i78;
        }
        __ZdlPv($854);
       }
       __ZdlPv($838);
      }
      $855 = HEAP32[679312>>2]|0;
      $856 = HEAP32[$855>>2]|0;
      $857 = (($856) + 20|0);
      $858 = HEAP32[$857>>2]|0;
      $859 = HEAP32[$831>>2]|0;
      FUNCTION_TABLE_vii[$858 & 4095]($855,$859);
      $860 = HEAP32[679312>>2]|0;
      $861 = HEAP32[$860>>2]|0;
      $862 = (($861) + 20|0);
      $863 = HEAP32[$862>>2]|0;
      $864 = HEAP32[$833>>2]|0;
      FUNCTION_TABLE_vii[$863 & 4095]($860,$864);
      $yyval$sroa$0$0 = $830;
      break;
     }
     case 36:  {
      $865 = (($yyvsp$2) + -56|0);
      $866 = HEAP32[$865>>2]|0;
      $867 = (($yyvsp$2) + -48|0);
      $868 = HEAP32[$867>>2]|0;
      $869 = (($yyvsp$2) + -40|0);
      $870 = HEAP32[$869>>2]|0;
      $871 = (($yyvsp$2) + -52|0);
      $872 = HEAP32[$871>>2]|0;
      $873 = Math_fround(HEAPF32[$yyvsp$2>>2]);
      $874 = (($yyvsp$2) + -24|0);
      $875 = Math_fround(HEAPF32[$874>>2]);
      $876 = (($yyvsp$2) + -16|0);
      $877 = Math_fround(HEAPF32[$876>>2]);
      __ZN9ShaderLab16ParserProperties16AddRangePropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEEfff($866,$868,$870,$872,$873,$875,$877);
      $878 = HEAP32[679312>>2]|0;
      $879 = HEAP32[$878>>2]|0;
      $880 = (($879) + 20|0);
      $881 = HEAP32[$880>>2]|0;
      $882 = HEAP32[$867>>2]|0;
      FUNCTION_TABLE_vii[$881 & 4095]($878,$882);
      $883 = HEAP32[679312>>2]|0;
      $884 = HEAP32[$883>>2]|0;
      $885 = (($884) + 20|0);
      $886 = HEAP32[$885>>2]|0;
      $887 = HEAP32[$869>>2]|0;
      FUNCTION_TABLE_vii[$886 & 4095]($883,$887);
      $yyval$sroa$0$0 = $866;
      break;
     }
     case 38:  {
      $943 = (($yyvsp$2) + -48|0);
      $944 = HEAP32[$943>>2]|0;
      $945 = (($yyvsp$2) + -4|0);
      $946 = HEAP32[$945>>2]|0;
      $947 = (($yyvsp$2) + -12|0);
      $948 = HEAP32[$947>>2]|0;
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($946,$948)|0);
      $949 = HEAP32[679312>>2]|0;
      $950 = HEAP32[$949>>2]|0;
      $951 = (($950) + 20|0);
      $952 = HEAP32[$951>>2]|0;
      $953 = HEAP32[$947>>2]|0;
      FUNCTION_TABLE_vii[$952 & 4095]($949,$953);
      $954 = (($yyvsp$2) + -24|0);
      $955 = HEAP32[$954>>2]|0;
      $956 = (($946) + 12|0);
      HEAP32[$956>>2] = $955;
      $957 = (($yyvsp$2) + -40|0);
      $958 = HEAP32[$957>>2]|0;
      $959 = (($yyvsp$2) + -32|0);
      $960 = HEAP32[$959>>2]|0;
      $961 = (($yyvsp$2) + -44|0);
      $962 = HEAP32[$961>>2]|0;
      __ZN9ShaderLab16ParserProperties18AddTexturePropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEERKNS_21ParserTexturePropertyE($944,$958,$960,$962,$946);
      $963 = HEAP32[$961>>2]|0;
      $964 = ($963|0)==(0|0);
      if (!($964)) {
       $965 = HEAP32[$963>>2]|0;
       $966 = ($965|0)==(0|0);
       if (!($966)) {
        $967 = (($963) + 4|0);
        $968 = HEAP32[$967>>2]|0;
        $969 = ($968|0)==($965|0);
        if ($969) {
         $979 = $965;
        } else {
         $971 = $968;
         while(1) {
          $970 = (($971) + -12|0);
          HEAP32[$967>>2] = $970;
          $972 = HEAP8[$970>>0]|0;
          $973 = $972 & 1;
          $974 = ($973<<24>>24)==(0);
          if ($974) {
           $976 = $970;
          } else {
           $977 = (($971) + -4|0);
           $978 = HEAP32[$977>>2]|0;
           __ZdlPv($978);
           $$pre$i$i$i$i$i91 = HEAP32[$967>>2]|0;
           $976 = $$pre$i$i$i$i$i91;
          }
          $975 = ($976|0)==($965|0);
          if ($975) {
           break;
          } else {
           $971 = $976;
          }
         }
         $$pre$i$i$i92 = HEAP32[$963>>2]|0;
         $979 = $$pre$i$i$i92;
        }
        __ZdlPv($979);
       }
       __ZdlPv($963);
      }
      $980 = HEAP32[679312>>2]|0;
      $981 = HEAP32[$980>>2]|0;
      $982 = (($981) + 20|0);
      $983 = HEAP32[$982>>2]|0;
      $984 = HEAP32[$957>>2]|0;
      FUNCTION_TABLE_vii[$983 & 4095]($980,$984);
      $985 = HEAP32[679312>>2]|0;
      $986 = HEAP32[$985>>2]|0;
      $987 = (($986) + 20|0);
      $988 = HEAP32[$987>>2]|0;
      $989 = HEAP32[$959>>2]|0;
      FUNCTION_TABLE_vii[$988 & 4095]($985,$989);
      $990 = ($946|0)==(0|0);
      if ($990) {
       $yyval$sroa$0$0 = $944;
      } else {
       $991 = HEAP8[$946>>0]|0;
       $992 = $991 & 1;
       $993 = ($992<<24>>24)==(0);
       if (!($993)) {
        $994 = (($946) + 8|0);
        $995 = HEAP32[$994>>2]|0;
        __ZdlPv($995);
       }
       __ZdlPv($946);
       $yyval$sroa$0$0 = $944;
      }
      break;
     }
     case 39:  {
      $996 = (__Znwj(12)|0);
      HEAP32[$996>>2] = 0;
      $997 = (($996) + 4|0);
      HEAP32[$997>>2] = 0;
      $998 = (($996) + 8|0);
      HEAP32[$998>>2] = 0;
      $yyval$sroa$0$0 = $996;
      break;
     }
     case 40:  {
      $999 = (($yyvsp$2) + -4|0);
      $1000 = HEAP32[$999>>2]|0;
      $1001 = HEAP32[$yyvsp$2>>2]|0;
      $1002 = (_strlen(($1001|0))|0);
      $1003 = ($1002>>>0)>(4294967279);
      if ($1003) {
       label = 276;
       break L1;
      }
      $1004 = ($1002>>>0)<(11);
      if ($1004) {
       $1005 = $1002 << 1;
       $1006 = $1005&255;
       HEAP8[$7>>0] = $1006;
       $1020 = $1006;$__p$0$i$i$i98 = $61;
      } else {
       $1007 = (($1002) + 16)|0;
       $1008 = $1007 & -16;
       $1009 = (__Znwj($1008)|0);
       HEAP32[$62>>2] = $1009;
       $1010 = $1008 | 1;
       HEAP32[$7>>2] = $1010;
       HEAP32[$63>>2] = $1002;
       $1011 = $1010&255;
       $1020 = $1011;$__p$0$i$i$i98 = $1009;
      }
      _memcpy(($__p$0$i$i$i98|0),($1001|0),($1002|0))|0;
      $1012 = (($__p$0$i$i$i98) + ($1002)|0);
      HEAP8[$1012>>0] = 0;
      $1013 = (($1000) + 4|0);
      $1014 = HEAP32[$1013>>2]|0;
      $1015 = (($1000) + 8|0);
      $1016 = HEAP32[$1015>>2]|0;
      $1017 = ($1014|0)==($1016|0);
      if ($1017) {
       __THREW__ = 0;
       invoke_vii(2523,($1000|0),($7|0));
       $1042 = __THREW__; __THREW__ = 0;
       $1043 = $1042&1;
       if ($1043) {
        label = 298;
        break L1;
       }
       $$pre1439 = HEAP8[$7>>0]|0;
       $1045 = $$pre1439;
      } else {
       $1018 = ($1014|0)==(0|0);
       do {
        if (!($1018)) {
         $1019 = $1020 & 1;
         $1021 = ($1019<<24>>24)==(0);
         if ($1021) {
          ;HEAP32[$1014+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$1014+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$1014+8>>2]=HEAP32[$7+8>>2]|0;
          break;
         }
         $1022 = HEAP32[$62>>2]|0;
         $1023 = HEAP32[$63>>2]|0;
         $1024 = ($1023>>>0)>(4294967279);
         if ($1024) {
          label = 285;
          break L1;
         }
         $1027 = ($1023>>>0)<(11);
         if ($1027) {
          $1028 = $1023 << 1;
          $1029 = $1028&255;
          HEAP8[$1014>>0] = $1029;
          $1030 = (($1014) + 1|0);
          $__p$0$i$i$i$i$i101 = $1030;
         } else {
          $1031 = (($1023) + 16)|0;
          $1032 = $1031 & -16;
          __THREW__ = 0;
          $1033 = (invoke_ii(2988,($1032|0))|0);
          $1034 = __THREW__; __THREW__ = 0;
          $1035 = $1034&1;
          if ($1035) {
           label = 298;
           break L1;
          }
          $1036 = (($1014) + 8|0);
          HEAP32[$1036>>2] = $1033;
          $1037 = $1032 | 1;
          HEAP32[$1014>>2] = $1037;
          $1038 = (($1014) + 4|0);
          HEAP32[$1038>>2] = $1023;
          $__p$0$i$i$i$i$i101 = $1033;
         }
         _memcpy(($__p$0$i$i$i$i$i101|0),($1022|0),($1023|0))|0;
         $1039 = (($__p$0$i$i$i$i$i101) + ($1023)|0);
         HEAP8[$1039>>0] = 0;
        }
       } while(0);
       $1040 = HEAP32[$1013>>2]|0;
       $1041 = (($1040) + 12|0);
       HEAP32[$1013>>2] = $1041;
       $1045 = $1020;
      }
      $1044 = $1045 & 1;
      $1046 = ($1044<<24>>24)==(0);
      if (!($1046)) {
       $1047 = HEAP32[$62>>2]|0;
       __ZdlPv($1047);
      }
      $1048 = HEAP32[679312>>2]|0;
      $1049 = HEAP32[$1048>>2]|0;
      $1050 = (($1049) + 20|0);
      $1051 = HEAP32[$1050>>2]|0;
      $1052 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$1051 & 4095]($1048,$1052);
      $yyval$sroa$0$0 = $1000;
      break;
     }
     case 41:  {
      $1061 = (__Znwj(120)|0);
      __THREW__ = 0;
      invoke_vi(3575,($1061|0));
      $1062 = __THREW__; __THREW__ = 0;
      $1063 = $1062&1;
      if ($1063) {
       label = 312;
       break L1;
      }
      $1064 = (($yyvsp$2) + -8|0);
      $1065 = HEAP32[$1064>>2]|0;
      $1066 = (_strlen(($1065|0))|0);
      $1067 = ($1066>>>0)>(4294967279);
      if ($1067) {
       label = 304;
       break L1;
      }
      $1068 = ($1066>>>0)<(11);
      if ($1068) {
       $1069 = $1066 << 1;
       $1070 = $1069&255;
       HEAP8[$8>>0] = $1070;
       $__p$0$i$i$i108 = $64;
      } else {
       $1071 = (($1066) + 16)|0;
       $1072 = $1071 & -16;
       $1073 = (__Znwj($1072)|0);
       HEAP32[$65>>2] = $1073;
       $1074 = $1072 | 1;
       HEAP32[$8>>2] = $1074;
       HEAP32[$66>>2] = $1066;
       $__p$0$i$i$i108 = $1073;
      }
      _memcpy(($__p$0$i$i$i108|0),($1065|0),($1066|0))|0;
      $1075 = (($__p$0$i$i$i108) + ($1066)|0);
      HEAP8[$1075>>0] = 0;
      __THREW__ = 0;
      $1076 = (invoke_ii(3326,($8|0))|0);
      $1077 = __THREW__; __THREW__ = 0;
      $1078 = $1077&1;
      if ($1078) {
       label = 313;
       break L1;
      }
      $1079 = HEAP8[$8>>0]|0;
      $1080 = $1079 & 1;
      $1081 = ($1080<<24>>24)==(0);
      if (!($1081)) {
       $1082 = HEAP32[$65>>2]|0;
       __ZdlPv($1082);
      }
      $1083 = HEAP32[$yyvsp$2>>2]|0;
      $1084 = HEAP32[674256>>2]|0;
      __ZN9ShaderLab18ParserBindChannels4BindE13ShaderChannel15VertexComponentbP12ShaderErrors($1061,$1076,$1083,1,$1084);
      $1085 = HEAP32[679312>>2]|0;
      $1086 = HEAP32[$1085>>2]|0;
      $1087 = (($1086) + 20|0);
      $1088 = HEAP32[$1087>>2]|0;
      $1089 = HEAP32[$1064>>2]|0;
      FUNCTION_TABLE_vii[$1088 & 4095]($1085,$1089);
      $yyval$sroa$0$0 = $1061;
      break;
     }
     case 42:  {
      $1098 = (($yyvsp$2) + -16|0);
      $1099 = HEAP32[$1098>>2]|0;
      $1100 = (($yyvsp$2) + -8|0);
      $1101 = HEAP32[$1100>>2]|0;
      $1102 = (_strlen(($1101|0))|0);
      $1103 = ($1102>>>0)>(4294967279);
      if ($1103) {
       label = 316;
       break L1;
      }
      $1104 = ($1102>>>0)<(11);
      if ($1104) {
       $1105 = $1102 << 1;
       $1106 = $1105&255;
       HEAP8[$9>>0] = $1106;
       $__p$0$i$i$i113 = $67;
      } else {
       $1107 = (($1102) + 16)|0;
       $1108 = $1107 & -16;
       $1109 = (__Znwj($1108)|0);
       HEAP32[$68>>2] = $1109;
       $1110 = $1108 | 1;
       HEAP32[$9>>2] = $1110;
       HEAP32[$69>>2] = $1102;
       $__p$0$i$i$i113 = $1109;
      }
      _memcpy(($__p$0$i$i$i113|0),($1101|0),($1102|0))|0;
      $1111 = (($__p$0$i$i$i113) + ($1102)|0);
      HEAP8[$1111>>0] = 0;
      __THREW__ = 0;
      $1112 = (invoke_ii(3326,($9|0))|0);
      $1113 = __THREW__; __THREW__ = 0;
      $1114 = $1113&1;
      if ($1114) {
       label = 324;
       break L1;
      }
      $1115 = HEAP8[$9>>0]|0;
      $1116 = $1115 & 1;
      $1117 = ($1116<<24>>24)==(0);
      if (!($1117)) {
       $1118 = HEAP32[$68>>2]|0;
       __ZdlPv($1118);
      }
      $1119 = HEAP32[$yyvsp$2>>2]|0;
      $1120 = HEAP32[674256>>2]|0;
      __ZN9ShaderLab18ParserBindChannels4BindE13ShaderChannel15VertexComponentbP12ShaderErrors($1099,$1112,$1119,1,$1120);
      $1121 = HEAP32[679312>>2]|0;
      $1122 = HEAP32[$1121>>2]|0;
      $1123 = (($1122) + 20|0);
      $1124 = HEAP32[$1123>>2]|0;
      $1125 = HEAP32[$1100>>2]|0;
      FUNCTION_TABLE_vii[$1124 & 4095]($1121,$1125);
      $yyval$sroa$0$0 = $1099;
      break;
     }
     case 134:  {
      $3098 = (($yyvsp$2) + -16|0);
      $3099 = HEAP32[$3098>>2]|0;
      $3100 = ($3099|0)==(0|0);
      if ($3100) {
       $$pre1494 = (($yyvsp$2) + -4|0);
       $$pre$phi1497Z2D = $$pre1494;
      } else {
       $3101 = (($yyvsp$2) + -8|0);
       $3102 = Math_fround(HEAPF32[$3101>>2]);
       $3103 = (~~(($3102)));
       $3104 = (($yyvsp$2) + -4|0);
       $3105 = HEAP32[$3104>>2]|0;
       $3106 = (_strlen(($3105|0))|0);
       $3107 = ($3106>>>0)>(4294967279);
       if ($3107) {
        label = 823;
        break L1;
       }
       $3108 = ($3106>>>0)<(11);
       if ($3108) {
        $3109 = $3106 << 1;
        $3110 = $3109&255;
        HEAP8[$36>>0] = $3110;
        $__p$0$i$i$i262 = $137;
       } else {
        $3111 = (($3106) + 16)|0;
        $3112 = $3111 & -16;
        $3113 = (__Znwj($3112)|0);
        HEAP32[$138>>2] = $3113;
        $3114 = $3112 | 1;
        HEAP32[$36>>2] = $3114;
        HEAP32[$139>>2] = $3106;
        $__p$0$i$i$i262 = $3113;
       }
       _memcpy(($__p$0$i$i$i262|0),($3105|0),($3106|0))|0;
       $3115 = (($__p$0$i$i$i262) + ($3106)|0);
       HEAP8[$3115>>0] = 0;
       $3116 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $3117 = (~~(($3116)));
       __THREW__ = 0;
       invoke_viiiii(106,($3099|0),3,($3103|0),($36|0),($3117|0));
       $3118 = __THREW__; __THREW__ = 0;
       $3119 = $3118&1;
       if ($3119) {
        label = 830;
        break L1;
       }
       $3120 = HEAP8[$36>>0]|0;
       $3121 = $3120 & 1;
       $3122 = ($3121<<24>>24)==(0);
       if ($3122) {
        $$pre$phi1497Z2D = $3104;
       } else {
        $3123 = HEAP32[$138>>2]|0;
        __ZdlPv($3123);
        $$pre$phi1497Z2D = $3104;
       }
      }
      $3130 = HEAP32[679312>>2]|0;
      $3131 = HEAP32[$3130>>2]|0;
      $3132 = (($3131) + 20|0);
      $3133 = HEAP32[$3132>>2]|0;
      $3134 = HEAP32[$$pre$phi1497Z2D>>2]|0;
      FUNCTION_TABLE_vii[$3133 & 4095]($3130,$3134);
      $yyval$sroa$0$0 = $3099;
      break;
     }
     case 135:  {
      $3135 = (($yyvsp$2) + -20|0);
      $3136 = HEAP32[$3135>>2]|0;
      $3137 = ($3136|0)==(0|0);
      if ($3137) {
       $$pre1498 = (($yyvsp$2) + -8|0);
       $$pre$phi1501Z2D = $$pre1498;
      } else {
       $3138 = (($yyvsp$2) + -12|0);
       $3139 = Math_fround(HEAPF32[$3138>>2]);
       $3140 = (~~(($3139)));
       $3141 = (($yyvsp$2) + -8|0);
       $3142 = HEAP32[$3141>>2]|0;
       $3143 = (($yyvsp$2) + -4|0);
       $3144 = HEAP32[$3143>>2]|0;
       $3145 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $3146 = (~~(($3145)));
       __ZN9ShaderLab16ParserSubProgram15AddTextureParamEiPKc16TextureDimensioni($3136,$3140,$3142,$3144,$3146);
       $$pre$phi1501Z2D = $3141;
      }
      $3147 = HEAP32[679312>>2]|0;
      $3148 = HEAP32[$3147>>2]|0;
      $3149 = (($3148) + 20|0);
      $3150 = HEAP32[$3149>>2]|0;
      $3151 = HEAP32[$$pre$phi1501Z2D>>2]|0;
      FUNCTION_TABLE_vii[$3150 & 4095]($3147,$3151);
      $yyval$sroa$0$0 = $3136;
      break;
     }
     case 136:  {
      $3152 = (($yyvsp$2) + -16|0);
      $3153 = HEAP32[$3152>>2]|0;
      $3154 = ($3153|0)==(0|0);
      if ($3154) {
       $$pre1502 = (($yyvsp$2) + -4|0);
       $$pre$phi1505Z2D = $$pre1502;
      } else {
       $3155 = (($yyvsp$2) + -8|0);
       $3156 = Math_fround(HEAPF32[$3155>>2]);
       $3157 = (~~(($3156)));
       $3158 = (($yyvsp$2) + -4|0);
       $3159 = HEAP32[$3158>>2]|0;
       $3160 = HEAP32[$yyvsp$2>>2]|0;
       __ZN9ShaderLab16ParserSubProgram15AddTextureParamEiPKc16TextureDimensioni($3153,$3157,$3159,$3160,$3157);
       $$pre$phi1505Z2D = $3158;
      }
      $3161 = HEAP32[679312>>2]|0;
      $3162 = HEAP32[$3161>>2]|0;
      $3163 = (($3162) + 20|0);
      $3164 = HEAP32[$3163>>2]|0;
      $3165 = HEAP32[$$pre$phi1505Z2D>>2]|0;
      FUNCTION_TABLE_vii[$3164 & 4095]($3161,$3165);
      $yyval$sroa$0$0 = $3153;
      break;
     }
     case 137:  {
      $3166 = (($yyvsp$2) + -12|0);
      $3167 = HEAP32[$3166>>2]|0;
      $3168 = ($3167|0)==(0|0);
      $$pre1506 = (($yyvsp$2) + -4|0);
      if (!($3168)) {
       $3169 = HEAP32[$$pre1506>>2]|0;
       $3170 = HEAP32[$yyvsp$2>>2]|0;
       $3171 = (($3167) + 176|0);
       $3172 = HEAP32[$3171>>2]|0;
       $3173 = (($3167) + 172|0);
       $3174 = HEAP32[$3173>>2]|0;
       $3175 = $3172;
       $3176 = $3174;
       $3177 = (($3175) - ($3176))|0;
       $3178 = (($3177|0) / 24)&-1;
       __ZN9ShaderLab16ParserSubProgram15AddTextureParamEiPKc16TextureDimensioni($3167,$3178,$3169,$3170,$3178);
      }
      $3179 = HEAP32[679312>>2]|0;
      $3180 = HEAP32[$3179>>2]|0;
      $3181 = (($3180) + 20|0);
      $3182 = HEAP32[$3181>>2]|0;
      $3183 = HEAP32[$$pre1506>>2]|0;
      FUNCTION_TABLE_vii[$3182 & 4095]($3179,$3183);
      $yyval$sroa$0$0 = $3167;
      break;
     }
     case 138:  {
      $3184 = (($yyvsp$2) + -16|0);
      $3185 = HEAP32[$3184>>2]|0;
      $3186 = ($3185|0)==(0|0);
      $$pre1510 = (($yyvsp$2) + -4|0);
      if (!($3186)) {
       $3187 = HEAP32[$$pre1510>>2]|0;
       __ZN9ShaderLab16ParserSubProgram11SetKeywordsERKNSt3__16vectorINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS6_IS8_EEEE($3185,$3187);
      }
      $3188 = HEAP32[$$pre1510>>2]|0;
      $3189 = ($3188|0)==(0|0);
      if ($3189) {
       $yyval$sroa$0$0 = $3185;
      } else {
       $3190 = HEAP32[$3188>>2]|0;
       $3191 = ($3190|0)==(0|0);
       if (!($3191)) {
        $3192 = (($3188) + 4|0);
        $3193 = HEAP32[$3192>>2]|0;
        $3194 = ($3193|0)==($3190|0);
        if ($3194) {
         $3204 = $3190;
        } else {
         $3196 = $3193;
         while(1) {
          $3195 = (($3196) + -12|0);
          HEAP32[$3192>>2] = $3195;
          $3197 = HEAP8[$3195>>0]|0;
          $3198 = $3197 & 1;
          $3199 = ($3198<<24>>24)==(0);
          if ($3199) {
           $3201 = $3195;
          } else {
           $3202 = (($3196) + -4|0);
           $3203 = HEAP32[$3202>>2]|0;
           __ZdlPv($3203);
           $$pre$i$i$i$i$i268 = HEAP32[$3192>>2]|0;
           $3201 = $$pre$i$i$i$i$i268;
          }
          $3200 = ($3201|0)==($3190|0);
          if ($3200) {
           break;
          } else {
           $3196 = $3201;
          }
         }
         $$pre$i$i$i269 = HEAP32[$3188>>2]|0;
         $3204 = $$pre$i$i$i269;
        }
        __ZdlPv($3204);
       }
       __ZdlPv($3188);
       $yyval$sroa$0$0 = $3185;
      }
      break;
     }
     case 139:  {
      $3205 = (($yyvsp$2) + -12|0);
      $3206 = HEAP32[$3205>>2]|0;
      $3207 = ($3206|0)==(0|0);
      $$pre1514 = (($yyvsp$2) + -4|0);
      if (!($3207)) {
       $3208 = HEAP32[$$pre1514>>2]|0;
       $3209 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $3210 = (~~(($3209)));
       __ZN9ShaderLab16ParserSubProgram14SetConstBufferEPKci($3206,$3208,$3210);
      }
      $3211 = HEAP32[679312>>2]|0;
      $3212 = HEAP32[$3211>>2]|0;
      $3213 = (($3212) + 20|0);
      $3214 = HEAP32[$3213>>2]|0;
      $3215 = HEAP32[$$pre1514>>2]|0;
      FUNCTION_TABLE_vii[$3214 & 4095]($3211,$3215);
      $yyval$sroa$0$0 = $3206;
      break;
     }
     case 141:  {
      $3227 = (($yyvsp$2) + -12|0);
      $3228 = HEAP32[$3227>>2]|0;
      $3229 = ($3228|0)==(0|0);
      if ($3229) {
       $$pre$phi1523Z2D = $yyvsp$2;
      } else {
       $3230 = (($yyvsp$2) + -4|0);
       $3231 = Math_fround(HEAPF32[$3230>>2]);
       $3232 = (~~(($3231)));
       $3233 = HEAP32[$yyvsp$2>>2]|0;
       __ZN9ShaderLab16ParserSubProgram14AddBufferParamEiPKc($3228,$3232,$3233);
       $$pre$phi1523Z2D = $yyvsp$2;
      }
      $3234 = HEAP32[679312>>2]|0;
      $3235 = HEAP32[$3234>>2]|0;
      $3236 = (($3235) + 20|0);
      $3237 = HEAP32[$3236>>2]|0;
      $3238 = HEAP32[$$pre$phi1523Z2D>>2]|0;
      FUNCTION_TABLE_vii[$3237 & 4095]($3234,$3238);
      $yyval$sroa$0$0 = $3228;
      break;
     }
     case 140:  {
      $3216 = (($yyvsp$2) + -12|0);
      $3217 = HEAP32[$3216>>2]|0;
      $3218 = ($3217|0)==(0|0);
      $$pre1518 = (($yyvsp$2) + -4|0);
      if (!($3218)) {
       $3219 = HEAP32[$$pre1518>>2]|0;
       $3220 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $3221 = (~~(($3220)));
       __ZN9ShaderLab16ParserSubProgram6BindCBEPKci($3217,$3219,$3221);
      }
      $3222 = HEAP32[679312>>2]|0;
      $3223 = HEAP32[$3222>>2]|0;
      $3224 = (($3223) + 20|0);
      $3225 = HEAP32[$3224>>2]|0;
      $3226 = HEAP32[$$pre1518>>2]|0;
      FUNCTION_TABLE_vii[$3225 & 4095]($3222,$3226);
      $yyval$sroa$0$0 = $3217;
      break;
     }
     case 142:  {
      $3239 = (__Znwj(12)|0);
      HEAP32[$3239>>2] = 0;
      $3240 = (($3239) + 4|0);
      HEAP32[$3240>>2] = 0;
      $3241 = (($3239) + 8|0);
      HEAP32[$3241>>2] = 0;
      $yyval$sroa$0$0 = $3239;
      break;
     }
     case 143:  {
      $3242 = (($yyvsp$2) + -4|0);
      $3243 = HEAP32[$3242>>2]|0;
      $3244 = HEAP32[$yyvsp$2>>2]|0;
      $3245 = (_strlen(($3244|0))|0);
      $3246 = ($3245>>>0)>(4294967279);
      if ($3246) {
       label = 867;
       break L1;
      }
      $3247 = ($3245>>>0)<(11);
      if ($3247) {
       $3248 = $3245 << 1;
       $3249 = $3248&255;
       HEAP8[$37>>0] = $3249;
       $3263 = $3249;$__p$0$i$i$i274 = $140;
      } else {
       $3250 = (($3245) + 16)|0;
       $3251 = $3250 & -16;
       $3252 = (__Znwj($3251)|0);
       HEAP32[$141>>2] = $3252;
       $3253 = $3251 | 1;
       HEAP32[$37>>2] = $3253;
       HEAP32[$142>>2] = $3245;
       $3254 = $3253&255;
       $3263 = $3254;$__p$0$i$i$i274 = $3252;
      }
      _memcpy(($__p$0$i$i$i274|0),($3244|0),($3245|0))|0;
      $3255 = (($__p$0$i$i$i274) + ($3245)|0);
      HEAP8[$3255>>0] = 0;
      $3256 = (($3243) + 4|0);
      $3257 = HEAP32[$3256>>2]|0;
      $3258 = (($3243) + 8|0);
      $3259 = HEAP32[$3258>>2]|0;
      $3260 = ($3257|0)==($3259|0);
      if ($3260) {
       __THREW__ = 0;
       invoke_vii(2523,($3243|0),($37|0));
       $3285 = __THREW__; __THREW__ = 0;
       $3286 = $3285&1;
       if ($3286) {
        label = 889;
        break L1;
       }
       $$pre1440 = HEAP8[$37>>0]|0;
       $3288 = $$pre1440;
      } else {
       $3261 = ($3257|0)==(0|0);
       do {
        if (!($3261)) {
         $3262 = $3263 & 1;
         $3264 = ($3262<<24>>24)==(0);
         if ($3264) {
          ;HEAP32[$3257+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$3257+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$3257+8>>2]=HEAP32[$37+8>>2]|0;
          break;
         }
         $3265 = HEAP32[$141>>2]|0;
         $3266 = HEAP32[$142>>2]|0;
         $3267 = ($3266>>>0)>(4294967279);
         if ($3267) {
          label = 876;
          break L1;
         }
         $3270 = ($3266>>>0)<(11);
         if ($3270) {
          $3271 = $3266 << 1;
          $3272 = $3271&255;
          HEAP8[$3257>>0] = $3272;
          $3273 = (($3257) + 1|0);
          $__p$0$i$i$i$i$i277 = $3273;
         } else {
          $3274 = (($3266) + 16)|0;
          $3275 = $3274 & -16;
          __THREW__ = 0;
          $3276 = (invoke_ii(2988,($3275|0))|0);
          $3277 = __THREW__; __THREW__ = 0;
          $3278 = $3277&1;
          if ($3278) {
           label = 889;
           break L1;
          }
          $3279 = (($3257) + 8|0);
          HEAP32[$3279>>2] = $3276;
          $3280 = $3275 | 1;
          HEAP32[$3257>>2] = $3280;
          $3281 = (($3257) + 4|0);
          HEAP32[$3281>>2] = $3266;
          $__p$0$i$i$i$i$i277 = $3276;
         }
         _memcpy(($__p$0$i$i$i$i$i277|0),($3265|0),($3266|0))|0;
         $3282 = (($__p$0$i$i$i$i$i277) + ($3266)|0);
         HEAP8[$3282>>0] = 0;
        }
       } while(0);
       $3283 = HEAP32[$3256>>2]|0;
       $3284 = (($3283) + 12|0);
       HEAP32[$3256>>2] = $3284;
       $3288 = $3263;
      }
      $3287 = $3288 & 1;
      $3289 = ($3287<<24>>24)==(0);
      if (!($3289)) {
       $3290 = HEAP32[$141>>2]|0;
       __ZdlPv($3290);
      }
      $3291 = HEAP32[679312>>2]|0;
      $3292 = HEAP32[$3291>>2]|0;
      $3293 = (($3292) + 20|0);
      $3294 = HEAP32[$3293>>2]|0;
      $3295 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3294 & 4095]($3291,$3295);
      $yyval$sroa$0$0 = $3243;
      break;
     }
     case 144:  {
      $3304 = (__Znwj(16)|0);
      __THREW__ = 0;
      invoke_vi(3593,($3304|0));
      $3305 = __THREW__; __THREW__ = 0;
      $3306 = $3305&1;
      if ($3306) {
       label = 895;
       break L1;
      }
      $yyval$sroa$0$0 = $3304;
      break;
     }
     case 148:  {
      $3353 = (($yyvsp$2) + -4|0);
      $3354 = HEAP32[$3353>>2]|0;
      $yyval$sroa$0$0 = $3354;
      break;
     }
     case 153:  {
      $3402 = (($yyvsp$2) + -16|0);
      $3403 = HEAP32[$3402>>2]|0;
      $3404 = (($yyvsp$2) + -24|0);
      $3405 = HEAP32[$3404>>2]|0;
      $3406 = (($yyvsp$2) + -4|0);
      $3407 = HEAP32[$3406>>2]|0;
      $3408 = HEAP32[$yyvsp$2>>2]|0;
      $3409 = HEAP32[674256>>2]|0;
      $3410 = (__Znwj(64)|0);
      HEAP32[$146>>2] = $3410;
      HEAP32[$40>>2] = 65;
      HEAP32[$147>>2] = 52;
      dest=$3410+0|0; src=678104+0|0; stop=dest+52|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $3411 = (($3410) + 52|0);
      HEAP8[$3411>>0] = 0;
      $3412 = HEAP32[654192>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(104,($3409|0),($40|0),($3412|0),1,0);
      $3413 = __THREW__; __THREW__ = 0;
      $3414 = $3413&1;
      if ($3414) {
       label = 916;
       break L1;
      }
      $3415 = $3405 << 16;
      $3416 = $3403 << 8;
      $3417 = $3408 << 24;
      $3418 = $3416 | $3415;
      $3419 = $3418 | $3407;
      $3420 = $3419 | $3417;
      $3421 = $3420 | 40960;
      $3422 = $3421;
      $3423 = HEAP8[$40>>0]|0;
      $3424 = $3423 & 1;
      $3425 = ($3424<<24>>24)==(0);
      if ($3425) {
       $yyval$sroa$0$0 = $3422;
      } else {
       $3426 = HEAP32[$146>>2]|0;
       __ZdlPv($3426);
       $yyval$sroa$0$0 = $3422;
      }
      break;
     }
     case 152:  {
      $3387 = (($yyvsp$2) + -12|0);
      $3388 = HEAP32[$3387>>2]|0;
      $3389 = $3388 << 8;
      $3390 = (($yyvsp$2) + -20|0);
      $3391 = HEAP32[$3390>>2]|0;
      $3392 = $3391 << 16;
      $3393 = (($yyvsp$2) + -4|0);
      $3394 = HEAP32[$3393>>2]|0;
      $3395 = HEAP32[$yyvsp$2>>2]|0;
      $3396 = $3395 << 24;
      $3397 = $3389 | $3392;
      $3398 = $3397 | $3394;
      $3399 = $3398 | $3396;
      $3400 = $3399 | 40960;
      $3401 = $3400;
      $yyval$sroa$0$0 = $3401;
      break;
     }
     case 150:  {
      $3369 = HEAP32[$yyvsp$2>>2]|0;
      $3370 = $3369 << 24;
      $3371 = (($yyvsp$2) + -4|0);
      $3372 = HEAP32[$3371>>2]|0;
      $3373 = $3372 << 16;
      $3374 = $3373 | $3370;
      $3375 = $3374;
      $yyval$sroa$0$0 = $3375;
      break;
     }
     case 151:  {
      $3376 = (($yyvsp$2) + -12|0);
      $3377 = HEAP32[$3376>>2]|0;
      $3378 = $3377 << 16;
      $3379 = (($yyvsp$2) + -4|0);
      $3380 = HEAP32[$3379>>2]|0;
      $3381 = HEAP32[$yyvsp$2>>2]|0;
      $3382 = $3381 << 24;
      $3383 = $3380 | $3378;
      $3384 = $3383 | $3382;
      $3385 = $3384 | 256;
      $3386 = $3385;
      $yyval$sroa$0$0 = $3386;
      break;
     }
     case 145:  {
      $3309 = (($yyvsp$2) + -4|0);
      $3310 = HEAP32[$3309>>2]|0;
      $3311 = HEAP32[$yyvsp$2>>2]|0;
      $3312 = (($3310) + 12|0);
      HEAP32[$3312>>2] = $3311;
      $yyval$sroa$0$0 = $3310;
      break;
     }
     case 149:  {
      $3355 = (($yyvsp$2) + -12|0);
      $3356 = HEAP32[$3355>>2]|0;
      $3357 = $3356 << 16;
      $3358 = (($yyvsp$2) + -8|0);
      $3359 = HEAP32[$3358>>2]|0;
      $3360 = $3359 << 8;
      $3361 = $3360 | $3357;
      $3362 = (($yyvsp$2) + -4|0);
      $3363 = HEAP32[$3362>>2]|0;
      $3364 = $3361 | $3363;
      $3365 = HEAP32[$yyvsp$2>>2]|0;
      $3366 = $3365 << 24;
      $3367 = $3364 | $3366;
      $3368 = $3367;
      $yyval$sroa$0$0 = $3368;
      break;
     }
     case 146:  {
      $3313 = (($yyvsp$2) + -8|0);
      $3314 = HEAP32[$3313>>2]|0;
      $3315 = HEAP32[674256>>2]|0;
      $3316 = (__Znwj(64)|0);
      HEAP32[$143>>2] = $3316;
      HEAP32[$38>>2] = 65;
      HEAP32[$144>>2] = 54;
      dest=$3316+0|0; src=678048+0|0; stop=dest+54|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $3317 = (($3316) + 54|0);
      HEAP8[$3317>>0] = 0;
      $3318 = HEAP32[654192>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(104,($3315|0),($38|0),($3318|0),1,0);
      $3319 = __THREW__; __THREW__ = 0;
      $3320 = $3319&1;
      if ($3320) {
       label = 900;
       break L1;
      }
      $3321 = HEAP8[$38>>0]|0;
      $3322 = $3321 & 1;
      $3323 = ($3322<<24>>24)==(0);
      if ($3323) {
       $yyval$sroa$0$0 = $3314;
      } else {
       $3324 = HEAP32[$143>>2]|0;
       __ZdlPv($3324);
       $yyval$sroa$0$0 = $3314;
      }
      break;
     }
     case 147:  {
      $3331 = (($yyvsp$2) + -8|0);
      $3332 = HEAP32[$3331>>2]|0;
      $3333 = HEAP32[674256>>2]|0;
      $3334 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = $3334;
      __Z6FormatPKcz($39,677968,$$byval_copy43);
      $3335 = HEAP32[654192>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(104,($3333|0),($39|0),($3335|0),1,0);
      $3336 = __THREW__; __THREW__ = 0;
      $3337 = $3336&1;
      if ($3337) {
       label = 906;
       break L1;
      }
      $3338 = HEAP8[$39>>0]|0;
      $3339 = $3338 & 1;
      $3340 = ($3339<<24>>24)==(0);
      if (!($3340)) {
       $3341 = HEAP32[$145>>2]|0;
       __ZdlPv($3341);
      }
      $3342 = HEAP32[679312>>2]|0;
      $3343 = HEAP32[$3342>>2]|0;
      $3344 = (($3343) + 20|0);
      $3345 = HEAP32[$3344>>2]|0;
      $3346 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3345 & 4095]($3342,$3346);
      $yyval$sroa$0$0 = $3332;
      break;
     }
     case 160:  {
      $yyval$sroa$0$0 = (2);
      break;
     }
     case 159:  {
      $yyval$sroa$0$0 = (4);
      break;
     }
     case 161:  {
      $3469 = HEAP32[674256>>2]|0;
      $3470 = (__Znwj(64)|0);
      HEAP32[$150>>2] = $3470;
      HEAP32[$42>>2] = 65;
      HEAP32[$151>>2] = 51;
      dest=$3470+0|0; src=678216+0|0; stop=dest+51|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $3471 = (($3470) + 51|0);
      HEAP8[$3471>>0] = 0;
      $3472 = HEAP32[654192>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(104,($3469|0),($42|0),($3472|0),1,0);
      $3473 = __THREW__; __THREW__ = 0;
      $3474 = $3473&1;
      if ($3474) {
       label = 932;
       break L1;
      }
      $3475 = HEAP8[$42>>0]|0;
      $3476 = $3475 & 1;
      $3477 = ($3476<<24>>24)==(0);
      if ($3477) {
       $yyval$sroa$0$0 = (2);
      } else {
       $3478 = HEAP32[$150>>2]|0;
       __ZdlPv($3478);
       $yyval$sroa$0$0 = (2);
      }
      break;
     }
     case 157:  {
      $yyval$sroa$0$0 = (1);
      break;
     }
     case 162:  {
      $yyval$sroa$0$0 = (4);
      break;
     }
     case 155:  {
      $3464 = HEAP32[$yyvsp$2>>2]|0;
      $3465 = $3464 | 8;
      $3466 = $3465;
      $yyval$sroa$0$0 = $3466;
      break;
     }
     case 163:  {
      $3485 = HEAP32[674256>>2]|0;
      $3486 = (__Znwj(64)|0);
      HEAP32[$152>>2] = $3486;
      HEAP32[$43>>2] = 65;
      HEAP32[$153>>2] = 53;
      dest=$3486+0|0; src=678272+0|0; stop=dest+53|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $3487 = (($3486) + 53|0);
      HEAP8[$3487>>0] = 0;
      $3488 = HEAP32[654192>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(104,($3485|0),($43|0),($3488|0),1,0);
      $3489 = __THREW__; __THREW__ = 0;
      $3490 = $3489&1;
      if ($3490) {
       label = 938;
       break L1;
      }
      $3491 = HEAP8[$43>>0]|0;
      $3492 = $3491 & 1;
      $3493 = ($3492<<24>>24)==(0);
      if ($3493) {
       $yyval$sroa$0$0 = (2);
      } else {
       $3494 = HEAP32[$152>>2]|0;
       __ZdlPv($3494);
       $yyval$sroa$0$0 = (2);
      }
      break;
     }
     case 158:  {
      $yyval$sroa$0$0 = (2);
      break;
     }
     case 154:  {
      $3433 = (($yyvsp$2) + -12|0);
      $3434 = HEAP32[$3433>>2]|0;
      $3435 = (($yyvsp$2) + -20|0);
      $3436 = HEAP32[$3435>>2]|0;
      $3437 = (($yyvsp$2) + -4|0);
      $3438 = HEAP32[$3437>>2]|0;
      $3439 = HEAP32[$yyvsp$2>>2]|0;
      $3440 = HEAP32[674256>>2]|0;
      $3441 = (__Znwj(64)|0);
      HEAP32[$148>>2] = $3441;
      HEAP32[$41>>2] = 65;
      HEAP32[$149>>2] = 51;
      dest=$3441+0|0; src=678160+0|0; stop=dest+51|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $3442 = (($3441) + 51|0);
      HEAP8[$3442>>0] = 0;
      $3443 = HEAP32[654192>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(104,($3440|0),($41|0),($3443|0),1,0);
      $3444 = __THREW__; __THREW__ = 0;
      $3445 = $3444&1;
      if ($3445) {
       label = 921;
       break L1;
      }
      $3446 = $3436 << 16;
      $3447 = $3434 << 8;
      $3448 = $3439 << 24;
      $3449 = $3447 | $3446;
      $3450 = $3449 | $3438;
      $3451 = $3450 | $3448;
      $3452 = $3451 | 40960;
      $3453 = $3452;
      $3454 = HEAP8[$41>>0]|0;
      $3455 = $3454 & 1;
      $3456 = ($3455<<24>>24)==(0);
      if ($3456) {
       $yyval$sroa$0$0 = $3453;
      } else {
       $3457 = HEAP32[$148>>2]|0;
       __ZdlPv($3457);
       $yyval$sroa$0$0 = $3453;
      }
      break;
     }
     case 156:  {
      $3467 = HEAP32[$yyvsp$2>>2]|0;
      $3468 = $3467;
      $yyval$sroa$0$0 = $3468;
      break;
     }
     case 169:  {
      $3542 = (__Znwj(8)|0);
      $3543 = (($3542) + 4|0);
      HEAP32[$3543>>2] = -1;
      $3544 = HEAP32[$yyvsp$2>>2]|0;
      $3545 = (Math_fround(($3544|0)));
      HEAPF32[$3542>>2] = $3545;
      HEAP32[$3543>>2] = -1;
      $yyval$sroa$0$0 = $3542;
      break;
     }
     case 171:  {
      $3555 = (__Znwj(8)|0);
      $3556 = (($3555) + 4|0);
      HEAP32[$3556>>2] = -1;
      $3557 = HEAP32[$yyvsp$2>>2]|0;
      $3558 = (Math_fround(($3557|0)));
      HEAPF32[$3555>>2] = $3558;
      HEAP32[$3556>>2] = -1;
      $yyval$sroa$0$0 = $3555;
      break;
     }
     case 164:  {
      $3501 = HEAP32[674256>>2]|0;
      $3502 = (__Znwj(64)|0);
      HEAP32[$154>>2] = $3502;
      HEAP32[$44>>2] = 65;
      HEAP32[$155>>2] = 57;
      dest=$3502+0|0; src=678328+0|0; stop=dest+57|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $3503 = (($3502) + 57|0);
      HEAP8[$3503>>0] = 0;
      $3504 = HEAP32[654192>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(104,($3501|0),($44|0),($3504|0),1,0);
      $3505 = __THREW__; __THREW__ = 0;
      $3506 = $3505&1;
      if ($3506) {
       label = 943;
       break L1;
      }
      $3507 = HEAP8[$44>>0]|0;
      $3508 = $3507 & 1;
      $3509 = ($3508<<24>>24)==(0);
      if ($3509) {
       $yyval$sroa$0$0 = (2);
      } else {
       $3510 = HEAP32[$154>>2]|0;
       __ZdlPv($3510);
       $yyval$sroa$0$0 = (2);
      }
      break;
     }
     case 170:  {
      $3546 = (__Znwj(8)|0);
      HEAPF32[$3546>>2] = Math_fround(0.0);
      $3547 = (($3546) + 4|0);
      HEAP32[$3547>>2] = -1;
      $3548 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3548);
      $3549 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3547>>2] = $3549;
      $3550 = HEAP32[679312>>2]|0;
      $3551 = HEAP32[$3550>>2]|0;
      $3552 = (($3551) + 20|0);
      $3553 = HEAP32[$3552>>2]|0;
      $3554 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3553 & 4095]($3550,$3554);
      $yyval$sroa$0$0 = $3546;
      break;
     }
     case 173:  {
      $3568 = (__Znwj(8)|0);
      $3569 = (($3568) + 4|0);
      HEAP32[$3569>>2] = -1;
      $3570 = HEAP32[$yyvsp$2>>2]|0;
      $3571 = (Math_fround(($3570|0)));
      HEAPF32[$3568>>2] = $3571;
      HEAP32[$3569>>2] = -1;
      $yyval$sroa$0$0 = $3568;
      break;
     }
     case 174:  {
      $3572 = (__Znwj(8)|0);
      $3573 = (($3572) + 4|0);
      HEAPF32[$3572>>2] = Math_fround(0.0);
      HEAP32[$3573>>2] = -1;
      $yyval$sroa$0$0 = $3572;
      break;
     }
     case 175:  {
      $3574 = (__Znwj(8)|0);
      HEAPF32[$3574>>2] = Math_fround(0.0);
      $3575 = (($3574) + 4|0);
      HEAP32[$3575>>2] = -1;
      $3576 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3576);
      $3577 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3575>>2] = $3577;
      $3578 = HEAP32[679312>>2]|0;
      $3579 = HEAP32[$3578>>2]|0;
      $3580 = (($3579) + 20|0);
      $3581 = HEAP32[$3580>>2]|0;
      $3582 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3581 & 4095]($3578,$3582);
      $yyval$sroa$0$0 = $3574;
      break;
     }
     case 176:  {
      $3583 = (__Znwj(8)|0);
      $3584 = (($3583) + 4|0);
      HEAP32[$3584>>2] = -1;
      $3585 = HEAP32[$yyvsp$2>>2]|0;
      $3586 = (Math_fround(($3585|0)));
      HEAPF32[$3583>>2] = $3586;
      HEAP32[$3584>>2] = -1;
      $yyval$sroa$0$0 = $3583;
      break;
     }
     case 165:  {
      $3517 = (($yyvsp$2) + -4|0);
      $3518 = HEAP32[$3517>>2]|0;
      $3519 = $3518 | 128;
      $3520 = $3519;
      $yyval$sroa$0$0 = $3520;
      break;
     }
     case 166:  {
      $3521 = (__Znwj(8)|0);
      HEAPF32[$3521>>2] = Math_fround(0.0);
      $3522 = (($3521) + 4|0);
      $3523 = Math_fround(HEAPF32[$yyvsp$2>>2]);
      HEAPF32[$3521>>2] = $3523;
      HEAP32[$3522>>2] = -1;
      $yyval$sroa$0$0 = $3521;
      break;
     }
     case 167:  {
      $3524 = (__Znwj(8)|0);
      HEAPF32[$3524>>2] = Math_fround(0.0);
      $3525 = (($3524) + 4|0);
      HEAP32[$3525>>2] = -1;
      $3526 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3526);
      $3527 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3525>>2] = $3527;
      $3528 = HEAP32[679312>>2]|0;
      $3529 = HEAP32[$3528>>2]|0;
      $3530 = (($3529) + 20|0);
      $3531 = HEAP32[$3530>>2]|0;
      $3532 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3531 & 4095]($3528,$3532);
      $yyval$sroa$0$0 = $3524;
      break;
     }
     case 172:  {
      $3559 = (__Znwj(8)|0);
      HEAPF32[$3559>>2] = Math_fround(0.0);
      $3560 = (($3559) + 4|0);
      HEAP32[$3560>>2] = -1;
      $3561 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3561);
      $3562 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3560>>2] = $3562;
      $3563 = HEAP32[679312>>2]|0;
      $3564 = HEAP32[$3563>>2]|0;
      $3565 = (($3564) + 20|0);
      $3566 = HEAP32[$3565>>2]|0;
      $3567 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3566 & 4095]($3563,$3567);
      $yyval$sroa$0$0 = $3559;
      break;
     }
     case 177:  {
      $3587 = (__Znwj(8)|0);
      HEAPF32[$3587>>2] = Math_fround(0.0);
      $3588 = (($3587) + 4|0);
      HEAP32[$3588>>2] = -1;
      $3589 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3589);
      $3590 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3588>>2] = $3590;
      $3591 = HEAP32[679312>>2]|0;
      $3592 = HEAP32[$3591>>2]|0;
      $3593 = (($3592) + 20|0);
      $3594 = HEAP32[$3593>>2]|0;
      $3595 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3594 & 4095]($3591,$3595);
      $yyval$sroa$0$0 = $3587;
      break;
     }
     case 168:  {
      $3533 = (__Znwj(8)|0);
      HEAPF32[$3533>>2] = Math_fround(0.0);
      $3534 = (($3533) + 4|0);
      HEAP32[$3534>>2] = -1;
      $3535 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3535);
      $3536 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3534>>2] = $3536;
      $3537 = HEAP32[679312>>2]|0;
      $3538 = HEAP32[$3537>>2]|0;
      $3539 = (($3538) + 20|0);
      $3540 = HEAP32[$3539>>2]|0;
      $3541 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3540 & 4095]($3537,$3541);
      $yyval$sroa$0$0 = $3533;
      break;
     }
     case 180:  {
      $3609 = (__Znwj(8)|0);
      $3610 = (($3609) + 4|0);
      HEAP32[$3610>>2] = -1;
      $3611 = HEAP32[$yyvsp$2>>2]|0;
      $3612 = (Math_fround(($3611|0)));
      HEAPF32[$3609>>2] = $3612;
      HEAP32[$3610>>2] = -1;
      $yyval$sroa$0$0 = $3609;
      break;
     }
     case 179:  {
      $3600 = (__Znwj(8)|0);
      HEAPF32[$3600>>2] = Math_fround(0.0);
      $3601 = (($3600) + 4|0);
      HEAP32[$3601>>2] = -1;
      $3602 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3602);
      $3603 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3601>>2] = $3603;
      $3604 = HEAP32[679312>>2]|0;
      $3605 = HEAP32[$3604>>2]|0;
      $3606 = (($3605) + 20|0);
      $3607 = HEAP32[$3606>>2]|0;
      $3608 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3607 & 4095]($3604,$3608);
      $yyval$sroa$0$0 = $3600;
      break;
     }
     case 183:  {
      $3624 = (__Znwj(8)|0);
      $3625 = (($3624) + 4|0);
      HEAPF32[$3624>>2] = Math_fround(0.0);
      HEAP32[$3625>>2] = -1;
      $yyval$sroa$0$0 = $3624;
      break;
     }
     case 186:  {
      $3633 = (__Znwj(48)|0);
      $3634 = (($3633) + 16|0);
      ;HEAP32[$3633+0>>2]=0|0;HEAP32[$3633+4>>2]=0|0;HEAP32[$3633+8>>2]=0|0;HEAP32[$3633+12>>2]=0|0;
      HEAP32[$3634>>2] = -1;
      $3635 = (($3633) + 20|0);
      HEAPF32[$3635>>2] = Math_fround(0.0);
      $3636 = (($3633) + 24|0);
      HEAP32[$3636>>2] = -1;
      $3637 = (($3633) + 28|0);
      HEAPF32[$3637>>2] = Math_fround(0.0);
      $3638 = (($3633) + 32|0);
      HEAP32[$3638>>2] = -1;
      $3639 = (($3633) + 36|0);
      HEAPF32[$3639>>2] = Math_fround(0.0);
      $3640 = (($3633) + 40|0);
      HEAP32[$3640>>2] = -1;
      $3641 = (($3633) + 44|0);
      HEAP32[$3641>>2] = -1;
      $3642 = (($3633) + 12|0);
      $3643 = (($yyvsp$2) + -28|0);
      $3644 = HEAP32[$3643>>2]|0;
      $3645 = (($yyvsp$2) + -20|0);
      $3646 = HEAP32[$3645>>2]|0;
      $3647 = (($yyvsp$2) + -12|0);
      $3648 = HEAP32[$3647>>2]|0;
      $3649 = (($yyvsp$2) + -4|0);
      $3650 = HEAP32[$3649>>2]|0;
      $3651 = $3644;
      $3652 = $3651;
      $3653 = HEAP32[$3652>>2]|0;
      $3654 = (($3651) + 4)|0;
      $3655 = $3654;
      $3656 = HEAP32[$3655>>2]|0;
      $3657 = $3642;
      $3658 = $3657;
      HEAP32[$3658>>2] = $3653;
      $3659 = (($3657) + 4)|0;
      $3660 = $3659;
      HEAP32[$3660>>2] = $3656;
      $3661 = $3646;
      $3662 = $3661;
      $3663 = HEAP32[$3662>>2]|0;
      $3664 = (($3661) + 4)|0;
      $3665 = $3664;
      $3666 = HEAP32[$3665>>2]|0;
      $3667 = $3635;
      $3668 = $3667;
      HEAP32[$3668>>2] = $3663;
      $3669 = (($3667) + 4)|0;
      $3670 = $3669;
      HEAP32[$3670>>2] = $3666;
      $3671 = $3648;
      $3672 = $3671;
      $3673 = HEAP32[$3672>>2]|0;
      $3674 = (($3671) + 4)|0;
      $3675 = $3674;
      $3676 = HEAP32[$3675>>2]|0;
      $3677 = $3637;
      $3678 = $3677;
      HEAP32[$3678>>2] = $3673;
      $3679 = (($3677) + 4)|0;
      $3680 = $3679;
      HEAP32[$3680>>2] = $3676;
      $3681 = $3650;
      $3682 = $3681;
      $3683 = HEAP32[$3682>>2]|0;
      $3684 = (($3681) + 4)|0;
      $3685 = $3684;
      $3686 = HEAP32[$3685>>2]|0;
      $3687 = $3639;
      $3688 = $3687;
      HEAP32[$3688>>2] = $3683;
      $3689 = (($3687) + 4)|0;
      $3690 = $3689;
      HEAP32[$3690>>2] = $3686;
      HEAP32[$3641>>2] = -1;
      $3691 = HEAP32[$3643>>2]|0;
      $3692 = ($3691|0)==(0|0);
      if (!($3692)) {
       __ZdlPv($3691);
      }
      $3693 = HEAP32[$3645>>2]|0;
      $3694 = ($3693|0)==(0|0);
      if (!($3694)) {
       __ZdlPv($3693);
      }
      $3695 = HEAP32[$3647>>2]|0;
      $3696 = ($3695|0)==(0|0);
      if (!($3696)) {
       __ZdlPv($3695);
      }
      $3697 = HEAP32[$3649>>2]|0;
      $3698 = ($3697|0)==(0|0);
      if ($3698) {
       $yyval$sroa$0$0 = $3633;
      } else {
       __ZdlPv($3697);
       $yyval$sroa$0$0 = $3633;
      }
      break;
     }
     case 181:  {
      $3613 = (__Znwj(8)|0);
      HEAPF32[$3613>>2] = Math_fround(0.0);
      $3614 = (($3613) + 4|0);
      HEAP32[$3614>>2] = -1;
      $3615 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3615);
      $3616 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3614>>2] = $3616;
      $3617 = HEAP32[679312>>2]|0;
      $3618 = HEAP32[$3617>>2]|0;
      $3619 = (($3618) + 20|0);
      $3620 = HEAP32[$3619>>2]|0;
      $3621 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3620 & 4095]($3617,$3621);
      $yyval$sroa$0$0 = $3613;
      break;
     }
     case 182:  {
      $3622 = (__Znwj(8)|0);
      $3623 = (($3622) + 4|0);
      HEAPF32[$3622>>2] = Math_fround(1.0);
      HEAP32[$3623>>2] = -1;
      $yyval$sroa$0$0 = $3622;
      break;
     }
     case 184:  {
      $3626 = $218;
      $3627 = $3626 & -256;
      $3628 = $3627 | 1;
      $3629 = $3628;
      $yyval$sroa$0$0 = $3629;
      break;
     }
     case 185:  {
      $3630 = $218;
      $3631 = $3630 & -256;
      $3632 = $3631;
      $yyval$sroa$0$0 = $3632;
      break;
     }
     case 178:  {
      $3596 = (__Znwj(8)|0);
      $3597 = (($3596) + 4|0);
      HEAP32[$3597>>2] = -1;
      $3598 = HEAP32[$yyvsp$2>>2]|0;
      $3599 = (Math_fround(($3598|0)));
      HEAPF32[$3596>>2] = $3599;
      HEAP32[$3597>>2] = -1;
      $yyval$sroa$0$0 = $3596;
      break;
     }
     case 189:  {
      $3768 = (__Znwj(16)|0);
      $3769 = (($yyvsp$2) + -28|0);
      $3770 = Math_fround(HEAPF32[$3769>>2]);
      $3771 = (($yyvsp$2) + -20|0);
      $3772 = Math_fround(HEAPF32[$3771>>2]);
      $3773 = (($yyvsp$2) + -12|0);
      $3774 = Math_fround(HEAPF32[$3773>>2]);
      $3775 = (($yyvsp$2) + -4|0);
      $3776 = Math_fround(HEAPF32[$3775>>2]);
      HEAPF32[$3768>>2] = $3770;
      $3777 = (($3768) + 4|0);
      HEAPF32[$3777>>2] = $3772;
      $3778 = (($3768) + 8|0);
      HEAPF32[$3778>>2] = $3774;
      $3779 = (($3768) + 12|0);
      HEAPF32[$3779>>2] = $3776;
      $yyval$sroa$0$0 = $3768;
      break;
     }
     case 187:  {
      $3699 = (__Znwj(48)|0);
      $3700 = (($3699) + 16|0);
      ;HEAP32[$3699+0>>2]=0|0;HEAP32[$3699+4>>2]=0|0;HEAP32[$3699+8>>2]=0|0;HEAP32[$3699+12>>2]=0|0;
      HEAP32[$3700>>2] = -1;
      $3701 = (($3699) + 20|0);
      HEAPF32[$3701>>2] = Math_fround(0.0);
      $3702 = (($3699) + 24|0);
      HEAP32[$3702>>2] = -1;
      $3703 = (($3699) + 28|0);
      HEAPF32[$3703>>2] = Math_fround(0.0);
      $3704 = (($3699) + 32|0);
      HEAP32[$3704>>2] = -1;
      $3705 = (($3699) + 36|0);
      HEAPF32[$3705>>2] = Math_fround(0.0);
      $3706 = (($3699) + 40|0);
      HEAP32[$3706>>2] = -1;
      $3707 = (($3699) + 44|0);
      HEAP32[$3707>>2] = -1;
      $3708 = (($3699) + 12|0);
      $3709 = (($yyvsp$2) + -20|0);
      $3710 = HEAP32[$3709>>2]|0;
      $3711 = (($yyvsp$2) + -12|0);
      $3712 = HEAP32[$3711>>2]|0;
      $3713 = (($yyvsp$2) + -4|0);
      $3714 = HEAP32[$3713>>2]|0;
      $3715 = $3710;
      $3716 = $3715;
      $3717 = HEAP32[$3716>>2]|0;
      $3718 = (($3715) + 4)|0;
      $3719 = $3718;
      $3720 = HEAP32[$3719>>2]|0;
      $3721 = $3708;
      $3722 = $3721;
      HEAP32[$3722>>2] = $3717;
      $3723 = (($3721) + 4)|0;
      $3724 = $3723;
      HEAP32[$3724>>2] = $3720;
      $3725 = $3712;
      $3726 = $3725;
      $3727 = HEAP32[$3726>>2]|0;
      $3728 = (($3725) + 4)|0;
      $3729 = $3728;
      $3730 = HEAP32[$3729>>2]|0;
      $3731 = $3701;
      $3732 = $3731;
      HEAP32[$3732>>2] = $3727;
      $3733 = (($3731) + 4)|0;
      $3734 = $3733;
      HEAP32[$3734>>2] = $3730;
      $3735 = $3714;
      $3736 = $3735;
      $3737 = HEAP32[$3736>>2]|0;
      $3738 = (($3735) + 4)|0;
      $3739 = $3738;
      $3740 = HEAP32[$3739>>2]|0;
      $3741 = $3703;
      $3742 = $3741;
      HEAP32[$3742>>2] = $3737;
      $3743 = (($3741) + 4)|0;
      $3744 = $3743;
      HEAP32[$3744>>2] = $3740;
      HEAPF32[$3705>>2] = Math_fround(1.0);
      HEAP32[$3706>>2] = -1;
      HEAP32[$3707>>2] = -1;
      $3745 = HEAP32[$3709>>2]|0;
      $3746 = ($3745|0)==(0|0);
      if (!($3746)) {
       __ZdlPv($3745);
      }
      $3747 = HEAP32[$3711>>2]|0;
      $3748 = ($3747|0)==(0|0);
      if (!($3748)) {
       __ZdlPv($3747);
      }
      $3749 = HEAP32[$3713>>2]|0;
      $3750 = ($3749|0)==(0|0);
      if ($3750) {
       $yyval$sroa$0$0 = $3699;
      } else {
       __ZdlPv($3749);
       $yyval$sroa$0$0 = $3699;
      }
      break;
     }
     case 188:  {
      $3751 = (__Znwj(48)|0);
      $3752 = (($3751) + 16|0);
      ;HEAP32[$3751+0>>2]=0|0;HEAP32[$3751+4>>2]=0|0;HEAP32[$3751+8>>2]=0|0;HEAP32[$3751+12>>2]=0|0;
      HEAP32[$3752>>2] = -1;
      $3753 = (($3751) + 20|0);
      HEAPF32[$3753>>2] = Math_fround(0.0);
      $3754 = (($3751) + 24|0);
      HEAP32[$3754>>2] = -1;
      $3755 = (($3751) + 28|0);
      HEAPF32[$3755>>2] = Math_fround(0.0);
      $3756 = (($3751) + 32|0);
      HEAP32[$3756>>2] = -1;
      $3757 = (($3751) + 36|0);
      HEAPF32[$3757>>2] = Math_fround(0.0);
      $3758 = (($3751) + 40|0);
      HEAP32[$3758>>2] = -1;
      $3759 = (($3751) + 44|0);
      HEAP32[$3759>>2] = -1;
      $3760 = HEAP32[$yyvsp$2>>2]|0;
      (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($3751,$3760)|0);
      $3761 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$3761);
      $3762 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$3759>>2] = $3762;
      $3763 = HEAP32[679312>>2]|0;
      $3764 = HEAP32[$3763>>2]|0;
      $3765 = (($3764) + 20|0);
      $3766 = HEAP32[$3765>>2]|0;
      $3767 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$3766 & 4095]($3763,$3767);
      $yyval$sroa$0$0 = $3751;
      break;
     }
     case 190:  {
      $3780 = (__Znwj(16)|0);
      $3781 = (($yyvsp$2) + -20|0);
      $3782 = Math_fround(HEAPF32[$3781>>2]);
      $3783 = (($yyvsp$2) + -12|0);
      $3784 = Math_fround(HEAPF32[$3783>>2]);
      $3785 = (($yyvsp$2) + -4|0);
      $3786 = Math_fround(HEAPF32[$3785>>2]);
      HEAPF32[$3780>>2] = $3782;
      $3787 = (($3780) + 4|0);
      HEAPF32[$3787>>2] = $3784;
      $3788 = (($3780) + 8|0);
      HEAPF32[$3788>>2] = $3786;
      $3789 = (($3780) + 12|0);
      HEAPF32[$3789>>2] = Math_fround(1.0);
      $yyval$sroa$0$0 = $3780;
      break;
     }
     case 69:  {
      $1735 = (($yyvsp$2) + -8|0);
      $1736 = HEAP32[$1735>>2]|0;
      $1737 = (($1736) + 88|0);
      HEAPF32[$1737>>2] = Math_fround(1.0);
      $1738 = (($1736) + 92|0);
      HEAP32[$1738>>2] = -1;
      $1739 = (($1736) + 104|0);
      HEAPF32[$1739>>2] = Math_fround(1.0);
      $1740 = (($1736) + 108|0);
      HEAP32[$1740>>2] = -1;
      $1741 = (($1736) + 96|0);
      HEAPF32[$1741>>2] = Math_fround(0.0);
      $1742 = (($1736) + 100|0);
      HEAP32[$1742>>2] = -1;
      $1743 = (($1736) + 112|0);
      HEAPF32[$1743>>2] = Math_fround(0.0);
      $1744 = (($1736) + 116|0);
      HEAP32[$1744>>2] = -1;
      $yyval$sroa$0$0 = $1736;
      break;
     }
     case 70:  {
      $1745 = (($yyvsp$2) + -16|0);
      $1746 = HEAP32[$1745>>2]|0;
      $1747 = (($1746) + 120|0);
      $1748 = (($yyvsp$2) + -8|0);
      $1749 = HEAP32[$1748>>2]|0;
      $1750 = $1749;
      $1751 = $1750;
      $1752 = HEAP32[$1751>>2]|0;
      $1753 = (($1750) + 4)|0;
      $1754 = $1753;
      $1755 = HEAP32[$1754>>2]|0;
      $1756 = $1747;
      $1757 = $1756;
      HEAP32[$1757>>2] = $1752;
      $1758 = (($1756) + 4)|0;
      $1759 = $1758;
      HEAP32[$1759>>2] = $1755;
      $1760 = HEAP32[$1748>>2]|0;
      $1761 = ($1760|0)==(0|0);
      if (!($1761)) {
       __ZdlPv($1760);
      }
      $1762 = (($1746) + 128|0);
      $1763 = HEAP32[$yyvsp$2>>2]|0;
      $1764 = $1763;
      $1765 = $1764;
      $1766 = HEAP32[$1765>>2]|0;
      $1767 = (($1764) + 4)|0;
      $1768 = $1767;
      $1769 = HEAP32[$1768>>2]|0;
      $1770 = $1762;
      $1771 = $1770;
      HEAP32[$1771>>2] = $1766;
      $1772 = (($1770) + 4)|0;
      $1773 = $1772;
      HEAP32[$1773>>2] = $1769;
      $1774 = HEAP32[$yyvsp$2>>2]|0;
      $1775 = ($1774|0)==(0|0);
      if ($1775) {
       $yyval$sroa$0$0 = $1746;
      } else {
       __ZdlPv($1774);
       $yyval$sroa$0$0 = $1746;
      }
      break;
     }
     case 76:  {
      $1891 = (($yyvsp$2) + -20|0);
      $1892 = HEAP32[$1891>>2]|0;
      $1893 = (($yyvsp$2) + -12|0);
      $1894 = HEAP32[$1893>>2]|0;
      $1895 = (_strcmp(677824,$1894)|0);
      $1896 = ($1895|0)==(0);
      if ($1896) {
       $t$0321 = 1;
       label = 478;
      } else {
       $1897 = (_strcmp(677832,$1894)|0);
       $1898 = ($1897|0)==(0);
       if ($1898) {
        $t$0321 = 2;
        label = 478;
       } else {
        $1899 = (_strcmp(677840,$1894)|0);
        $1900 = ($1899|0)==(0);
        if ($1900) {
         $t$0321 = 3;
         label = 478;
        } else {
         $1901 = (_strcmp(677848,$1894)|0);
         $1902 = ($1901|0)==(0);
         if ($1902) {
          $t$0321 = 4;
          label = 478;
         } else {
          $1903 = (_strcmp(677856,$1894)|0);
          $not$ = ($1903|0)==(0);
          if ($not$) {
           $t$0321 = 5;
           label = 478;
          } else {
           $1929 = HEAP32[674256>>2]|0;
           $1930 = (__Znwj(32)|0);
           HEAP32[$89>>2] = $1930;
           HEAP32[$19>>2] = 33;
           HEAP32[$90>>2] = 25;
           dest=$1930+0|0; src=677912+0|0; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
           $1931 = (($1930) + 25|0);
           HEAP8[$1931>>0] = 0;
           $1932 = HEAP32[654192>>2]|0;
           __THREW__ = 0;
           invoke_viiiii(104,($1929|0),($19|0),($1932|0),0,0);
           $1933 = __THREW__; __THREW__ = 0;
           $1934 = $1933&1;
           if ($1934) {
            label = 495;
            break L1;
           }
           $1935 = HEAP8[$19>>0]|0;
           $1936 = $1935 & 1;
           $1937 = ($1936<<24>>24)==(0);
           if (!($1937)) {
            $1938 = HEAP32[$89>>2]|0;
            __ZdlPv($1938);
           }
           $1939 = (($yyvsp$2) + -4|0);
           $1940 = HEAP32[$1939>>2]|0;
           $1941 = ($1940|0)==(0|0);
           if (!($1941)) {
            __THREW__ = 0;
            invoke_vi(3594,($1940|0));
            $1942 = __THREW__; __THREW__ = 0;
            $1943 = $1942&1;
            if ($1943) {
             label = 497;
             break L1;
            }
            __ZdlPv($1940);
           }
          }
         }
        }
       }
      }
      if ((label|0) == 478) {
       label = 0;
       $1904 = (677800 + ($t$0321<<2)|0);
       $1905 = HEAP32[$1904>>2]|0;
       $1906 = ($1905|0)==(0|0);
       if (!($1906)) {
        $1907 = HEAP32[674256>>2]|0;
        HEAP32[$$byval_copy43>>2] = $1894;
        __Z6FormatPKcz($18,677864,$$byval_copy43);
        $1908 = HEAP32[654192>>2]|0;
        __THREW__ = 0;
        invoke_viiiii(104,($1907|0),($18|0),($1908|0),0,0);
        $1909 = __THREW__; __THREW__ = 0;
        $1910 = $1909&1;
        if ($1910) {
         label = 485;
         break L1;
        }
        $1911 = HEAP8[$18>>0]|0;
        $1912 = $1911 & 1;
        $1913 = ($1912<<24>>24)==(0);
        if (!($1913)) {
         $1914 = HEAP32[$88>>2]|0;
         __ZdlPv($1914);
        }
        $1915 = HEAP32[$1904>>2]|0;
        $1916 = ($1915|0)==(0|0);
        if (!($1916)) {
         __THREW__ = 0;
         invoke_vi(3594,($1915|0));
         $1917 = __THREW__; __THREW__ = 0;
         $1918 = $1917&1;
         if ($1918) {
          label = 487;
          break L1;
         }
         __ZdlPv($1915);
        }
       }
       $1927 = (($yyvsp$2) + -4|0);
       $1928 = HEAP32[$1927>>2]|0;
       HEAP32[$1904>>2] = $1928;
      }
      $1952 = HEAP32[679312>>2]|0;
      $1953 = HEAP32[$1952>>2]|0;
      $1954 = (($1953) + 20|0);
      $1955 = HEAP32[$1954>>2]|0;
      $1956 = HEAP32[$1893>>2]|0;
      FUNCTION_TABLE_vii[$1955 & 4095]($1952,$1956);
      $yyval$sroa$0$0 = $1892;
      break;
     }
     case 71:  {
      $1776 = (($yyvsp$2) + -8|0);
      $1777 = HEAP32[$1776>>2]|0;
      $1778 = (($1777) + 120|0);
      $1779 = HEAP32[$yyvsp$2>>2]|0;
      $1780 = $1779;
      $1781 = $1780;
      $1782 = HEAP32[$1781>>2]|0;
      $1783 = (($1780) + 4)|0;
      $1784 = $1783;
      $1785 = HEAP32[$1784>>2]|0;
      $1786 = $1778;
      $1787 = $1786;
      HEAP32[$1787>>2] = $1782;
      $1788 = (($1786) + 4)|0;
      $1789 = $1788;
      HEAP32[$1789>>2] = $1785;
      $1790 = (($1777) + 128|0);
      $1791 = HEAP32[$yyvsp$2>>2]|0;
      $1792 = $1791;
      $1793 = $1792;
      $1794 = HEAP32[$1793>>2]|0;
      $1795 = (($1792) + 4)|0;
      $1796 = $1795;
      $1797 = HEAP32[$1796>>2]|0;
      $1798 = $1790;
      $1799 = $1798;
      HEAP32[$1799>>2] = $1794;
      $1800 = (($1798) + 4)|0;
      $1801 = $1800;
      HEAP32[$1801>>2] = $1797;
      $1802 = HEAP32[$yyvsp$2>>2]|0;
      $1803 = ($1802|0)==(0|0);
      if ($1803) {
       $yyval$sroa$0$0 = $1777;
      } else {
       __ZdlPv($1802);
       $yyval$sroa$0$0 = $1777;
      }
      break;
     }
     case 72:  {
      $1804 = (($yyvsp$2) + -16|0);
      $1805 = HEAP32[$1804>>2]|0;
      $1806 = (($yyvsp$2) + -4|0);
      $1807 = HEAP32[$1806>>2]|0;
      $1808 = (($1805) + 440|0);
      $1809 = (($1807) + 440|0);
      $1810 = $1809;
      $1811 = $1810;
      $1812 = HEAP32[$1811>>2]|0;
      $1813 = (($1810) + 4)|0;
      $1814 = $1813;
      $1815 = HEAP32[$1814>>2]|0;
      $1816 = $1808;
      $1817 = $1816;
      HEAP32[$1817>>2] = $1812;
      $1818 = (($1816) + 4)|0;
      $1819 = $1818;
      HEAP32[$1819>>2] = $1815;
      $1820 = (($1805) + 424|0);
      $1821 = (($1807) + 424|0);
      $1822 = $1821;
      $1823 = $1822;
      $1824 = HEAP32[$1823>>2]|0;
      $1825 = (($1822) + 4)|0;
      $1826 = $1825;
      $1827 = HEAP32[$1826>>2]|0;
      $1828 = $1820;
      $1829 = $1828;
      HEAP32[$1829>>2] = $1824;
      $1830 = (($1828) + 4)|0;
      $1831 = $1830;
      HEAP32[$1831>>2] = $1827;
      $1832 = (($1805) + 432|0);
      $1833 = (($1807) + 432|0);
      $1834 = $1833;
      $1835 = $1834;
      $1836 = HEAP32[$1835>>2]|0;
      $1837 = (($1834) + 4)|0;
      $1838 = $1837;
      $1839 = HEAP32[$1838>>2]|0;
      $1840 = $1832;
      $1841 = $1840;
      HEAP32[$1841>>2] = $1836;
      $1842 = (($1840) + 4)|0;
      $1843 = $1842;
      HEAP32[$1843>>2] = $1839;
      $1844 = (($1805) + 328|0);
      $1845 = (($1807) + 328|0);
      ;HEAP32[$1844+0>>2]=HEAP32[$1845+0>>2]|0;HEAP32[$1844+4>>2]=HEAP32[$1845+4>>2]|0;HEAP32[$1844+8>>2]=HEAP32[$1845+8>>2]|0;HEAP32[$1844+12>>2]=HEAP32[$1845+12>>2]|0;HEAP32[$1844+16>>2]=HEAP32[$1845+16>>2]|0;HEAP32[$1844+20>>2]=HEAP32[$1845+20>>2]|0;HEAP32[$1844+24>>2]=HEAP32[$1845+24>>2]|0;HEAP32[$1844+28>>2]=HEAP32[$1845+28>>2]|0;
      $1846 = (($1805) + 360|0);
      $1847 = (($1807) + 360|0);
      ;HEAP32[$1846+0>>2]=HEAP32[$1847+0>>2]|0;HEAP32[$1846+4>>2]=HEAP32[$1847+4>>2]|0;HEAP32[$1846+8>>2]=HEAP32[$1847+8>>2]|0;HEAP32[$1846+12>>2]=HEAP32[$1847+12>>2]|0;HEAP32[$1846+16>>2]=HEAP32[$1847+16>>2]|0;HEAP32[$1846+20>>2]=HEAP32[$1847+20>>2]|0;HEAP32[$1846+24>>2]=HEAP32[$1847+24>>2]|0;HEAP32[$1846+28>>2]=HEAP32[$1847+28>>2]|0;
      $1848 = (($1805) + 392|0);
      $1849 = (($1807) + 392|0);
      ;HEAP32[$1848+0>>2]=HEAP32[$1849+0>>2]|0;HEAP32[$1848+4>>2]=HEAP32[$1849+4>>2]|0;HEAP32[$1848+8>>2]=HEAP32[$1849+8>>2]|0;HEAP32[$1848+12>>2]=HEAP32[$1849+12>>2]|0;HEAP32[$1848+16>>2]=HEAP32[$1849+16>>2]|0;HEAP32[$1848+20>>2]=HEAP32[$1849+20>>2]|0;HEAP32[$1848+24>>2]=HEAP32[$1849+24>>2]|0;HEAP32[$1848+28>>2]=HEAP32[$1849+28>>2]|0;
      __ZL14PopShaderStatev();
      $yyval$sroa$0$0 = $1805;
      break;
     }
     case 75:  {
      $1886 = (($yyvsp$2) + -8|0);
      $1887 = HEAP32[$1886>>2]|0;
      $1888 = Math_fround(HEAPF32[$yyvsp$2>>2]);
      $1889 = (~~(($1888)));
      $1890 = (($1887) + 512|0);
      HEAP32[$1890>>2] = $1889;
      $yyval$sroa$0$0 = $1887;
      break;
     }
     case 74:  {
      $1854 = (($yyvsp$2) + -16|0);
      $1855 = HEAP32[$1854>>2]|0;
      $1856 = (($1855) + 60|0);
      $1857 = (($yyvsp$2) + -8|0);
      $1858 = HEAP32[$1857>>2]|0;
      $1859 = $1858;
      $1860 = $1859;
      $1861 = HEAP32[$1860>>2]|0;
      $1862 = (($1859) + 4)|0;
      $1863 = $1862;
      $1864 = HEAP32[$1863>>2]|0;
      $1865 = $1856;
      $1866 = $1865;
      HEAP32[$1866>>2] = $1861;
      $1867 = (($1865) + 4)|0;
      $1868 = $1867;
      HEAP32[$1868>>2] = $1864;
      $1869 = HEAP32[$1857>>2]|0;
      $1870 = ($1869|0)==(0|0);
      if (!($1870)) {
       __ZdlPv($1869);
      }
      $1871 = HEAP32[$1854>>2]|0;
      $1872 = (($1871) + 68|0);
      $1873 = HEAP32[$yyvsp$2>>2]|0;
      $1874 = $1873;
      $1875 = $1874;
      $1876 = HEAP32[$1875>>2]|0;
      $1877 = (($1874) + 4)|0;
      $1878 = $1877;
      $1879 = HEAP32[$1878>>2]|0;
      $1880 = $1872;
      $1881 = $1880;
      HEAP32[$1881>>2] = $1876;
      $1882 = (($1880) + 4)|0;
      $1883 = $1882;
      HEAP32[$1883>>2] = $1879;
      $1884 = HEAP32[$yyvsp$2>>2]|0;
      $1885 = ($1884|0)==(0|0);
      if ($1885) {
       $yyval$sroa$0$0 = $1855;
      } else {
       __ZdlPv($1884);
       $yyval$sroa$0$0 = $1855;
      }
      break;
     }
     case 73:  {
      $1850 = (($yyvsp$2) + -8|0);
      $1851 = HEAP32[$1850>>2]|0;
      $1852 = HEAP8[$yyvsp$2>>0]|0;
      $1853 = (($1851) + 324|0);
      HEAP8[$1853>>0] = $1852;
      $yyval$sroa$0$0 = $1851;
      break;
     }
     case 83:  {
      $2043 = (($yyvsp$2) + -8|0);
      $2044 = HEAP32[$2043>>2]|0;
      $2045 = (($2044) + 216|0);
      $2046 = HEAP32[$yyvsp$2>>2]|0;
      $2047 = (($2046) + 12|0);
      dest=$2045+0|0; src=$2047+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $2048 = HEAP32[$yyvsp$2>>2]|0;
      $2049 = ($2048|0)==(0|0);
      if ($2049) {
       $yyval$sroa$0$0 = $2044;
      } else {
       $2050 = HEAP8[$2048>>0]|0;
       $2051 = $2050 & 1;
       $2052 = ($2051<<24>>24)==(0);
       if (!($2052)) {
        $2053 = (($2048) + 8|0);
        $2054 = HEAP32[$2053>>2]|0;
        __ZdlPv($2054);
       }
       __ZdlPv($2048);
       $yyval$sroa$0$0 = $2044;
      }
      break;
     }
     case 85:  {
      $2067 = (($yyvsp$2) + -8|0);
      $2068 = HEAP32[$2067>>2]|0;
      $2069 = (($2068) + 252|0);
      $2070 = HEAP32[$yyvsp$2>>2]|0;
      $2071 = (($2070) + 12|0);
      dest=$2069+0|0; src=$2071+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $2072 = HEAP32[$yyvsp$2>>2]|0;
      $2073 = ($2072|0)==(0|0);
      if ($2073) {
       $yyval$sroa$0$0 = $2068;
      } else {
       $2074 = HEAP8[$2072>>0]|0;
       $2075 = $2074 & 1;
       $2076 = ($2075<<24>>24)==(0);
       if (!($2076)) {
        $2077 = (($2072) + 8|0);
        $2078 = HEAP32[$2077>>2]|0;
        __ZdlPv($2078);
       }
       __ZdlPv($2072);
       $yyval$sroa$0$0 = $2068;
      }
      break;
     }
     case 77:  {
      __ZL15PushShaderStatev();
      $1957 = HEAP32[((674208 + 20|0))>>2]|0;
      $1958 = HEAP32[((674208 + 16|0))>>2]|0;
      $1959 = (($1957) + -1)|0;
      $1960 = (($1959) + ($1958))|0;
      $1961 = HEAP32[((674208 + 4|0))>>2]|0;
      $1962 = $1960 >>> 10;
      $1963 = (($1961) + ($1962<<2)|0);
      $1964 = HEAP32[$1963>>2]|0;
      $1965 = $1960 & 1023;
      $1966 = (($1964) + ($1965<<2)|0);
      $1967 = HEAP32[$1966>>2]|0;
      $yyval$sroa$0$0 = $1967;
      break;
     }
     case 86:  {
      $2079 = (($yyvsp$2) + -8|0);
      $2080 = HEAP32[$2079>>2]|0;
      $2081 = (($2080) + 288|0);
      $2082 = HEAP32[$yyvsp$2>>2]|0;
      $2083 = (($2082) + 12|0);
      dest=$2081+0|0; src=$2083+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $2084 = HEAP32[$yyvsp$2>>2]|0;
      $2085 = ($2084|0)==(0|0);
      if ($2085) {
       $yyval$sroa$0$0 = $2080;
      } else {
       $2086 = HEAP8[$2084>>0]|0;
       $2087 = $2086 & 1;
       $2088 = ($2087<<24>>24)==(0);
       if (!($2088)) {
        $2089 = (($2084) + 8|0);
        $2090 = HEAP32[$2089>>2]|0;
        __ZdlPv($2090);
       }
       __ZdlPv($2084);
       $yyval$sroa$0$0 = $2080;
      }
      break;
     }
     case 87:  {
      $2091 = (($yyvsp$2) + -8|0);
      $2092 = HEAP32[$2091>>2]|0;
      $2093 = (($2092) + 44|0);
      $2094 = HEAP32[$yyvsp$2>>2]|0;
      $2095 = $2094;
      $2096 = $2095;
      $2097 = HEAP32[$2096>>2]|0;
      $2098 = (($2095) + 4)|0;
      $2099 = $2098;
      $2100 = HEAP32[$2099>>2]|0;
      $2101 = $2093;
      $2102 = $2101;
      HEAP32[$2102>>2] = $2097;
      $2103 = (($2101) + 4)|0;
      $2104 = $2103;
      HEAP32[$2104>>2] = $2100;
      $2105 = HEAP32[$yyvsp$2>>2]|0;
      $2106 = ($2105|0)==(0|0);
      if ($2106) {
       $yyval$sroa$0$0 = $2092;
      } else {
       __ZdlPv($2105);
       $yyval$sroa$0$0 = $2092;
      }
      break;
     }
     case 89:  {
      $2118 = (($yyvsp$2) + -8|0);
      $2119 = HEAP32[$2118>>2]|0;
      $2120 = (($2119) + 440|0);
      $2121 = HEAP32[$yyvsp$2>>2]|0;
      $2122 = $2121;
      $2123 = $2122;
      $2124 = HEAP32[$2123>>2]|0;
      $2125 = (($2122) + 4)|0;
      $2126 = $2125;
      $2127 = HEAP32[$2126>>2]|0;
      $2128 = $2120;
      $2129 = $2128;
      HEAP32[$2129>>2] = $2124;
      $2130 = (($2128) + 4)|0;
      $2131 = $2130;
      HEAP32[$2131>>2] = $2127;
      $2132 = HEAP32[$yyvsp$2>>2]|0;
      $2133 = ($2132|0)==(0|0);
      if ($2133) {
       $yyval$sroa$0$0 = $2119;
      } else {
       __ZdlPv($2132);
       $yyval$sroa$0$0 = $2119;
      }
      break;
     }
     case 88:  {
      __ZL15PushShaderStatev();
      $2107 = HEAP32[((674208 + 20|0))>>2]|0;
      $2108 = HEAP32[((674208 + 16|0))>>2]|0;
      $2109 = (($2107) + -1)|0;
      $2110 = (($2109) + ($2108))|0;
      $2111 = HEAP32[((674208 + 4|0))>>2]|0;
      $2112 = $2110 >>> 10;
      $2113 = (($2111) + ($2112<<2)|0);
      $2114 = HEAP32[$2113>>2]|0;
      $2115 = $2110 & 1023;
      $2116 = (($2114) + ($2115<<2)|0);
      $2117 = HEAP32[$2116>>2]|0;
      $yyval$sroa$0$0 = $2117;
      break;
     }
     case 79:  {
      $1980 = (($yyvsp$2) + -8|0);
      $1981 = HEAP32[$1980>>2]|0;
      $1982 = HEAP32[$yyvsp$2>>2]|0;
      $1983 = (($1981) + 508|0);
      HEAP32[$1983>>2] = $1982;
      $yyval$sroa$0$0 = $1981;
      break;
     }
     case 84:  {
      $2055 = (($yyvsp$2) + -8|0);
      $2056 = HEAP32[$2055>>2]|0;
      $2057 = (($2056) + 180|0);
      $2058 = HEAP32[$yyvsp$2>>2]|0;
      $2059 = (($2058) + 12|0);
      dest=$2057+0|0; src=$2059+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $2060 = HEAP32[$yyvsp$2>>2]|0;
      $2061 = ($2060|0)==(0|0);
      if ($2061) {
       $yyval$sroa$0$0 = $2056;
      } else {
       $2062 = HEAP8[$2060>>0]|0;
       $2063 = $2062 & 1;
       $2064 = ($2063<<24>>24)==(0);
       if (!($2064)) {
        $2065 = (($2060) + 8|0);
        $2066 = HEAP32[$2065>>2]|0;
        __ZdlPv($2066);
       }
       __ZdlPv($2060);
       $yyval$sroa$0$0 = $2056;
      }
      break;
     }
     case 82:  {
      __ZL15PushShaderStatev();
      $2032 = HEAP32[((674208 + 20|0))>>2]|0;
      $2033 = HEAP32[((674208 + 16|0))>>2]|0;
      $2034 = (($2032) + -1)|0;
      $2035 = (($2034) + ($2033))|0;
      $2036 = HEAP32[((674208 + 4|0))>>2]|0;
      $2037 = $2035 >>> 10;
      $2038 = (($2036) + ($2037<<2)|0);
      $2039 = HEAP32[$2038>>2]|0;
      $2040 = $2035 & 1023;
      $2041 = (($2039) + ($2040<<2)|0);
      $2042 = HEAP32[$2041>>2]|0;
      $yyval$sroa$0$0 = $2042;
      break;
     }
     case 78:  {
      $1968 = (($yyvsp$2) + -8|0);
      $1969 = HEAP32[$1968>>2]|0;
      $1970 = (($1969) + 472|0);
      $1971 = HEAP32[$yyvsp$2>>2]|0;
      $1972 = (($1971) + 12|0);
      dest=$1970+0|0; src=$1972+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $1973 = HEAP32[$yyvsp$2>>2]|0;
      $1974 = ($1973|0)==(0|0);
      if ($1974) {
       $yyval$sroa$0$0 = $1969;
      } else {
       $1975 = HEAP8[$1973>>0]|0;
       $1976 = $1975 & 1;
       $1977 = ($1976<<24>>24)==(0);
       if (!($1977)) {
        $1978 = (($1973) + 8|0);
        $1979 = HEAP32[$1978>>2]|0;
        __ZdlPv($1979);
       }
       __ZdlPv($1973);
       $yyval$sroa$0$0 = $1969;
      }
      break;
     }
     case 80:  {
      $1984 = (($yyvsp$2) + -8|0);
      $1985 = HEAP32[$1984>>2]|0;
      $1986 = (($1985) + 464|0);
      $1987 = HEAP32[$yyvsp$2>>2]|0;
      $1988 = $1987;
      $1989 = $1988;
      $1990 = HEAP32[$1989>>2]|0;
      $1991 = (($1988) + 4)|0;
      $1992 = $1991;
      $1993 = HEAP32[$1992>>2]|0;
      $1994 = $1986;
      $1995 = $1994;
      HEAP32[$1995>>2] = $1990;
      $1996 = (($1994) + 4)|0;
      $1997 = $1996;
      HEAP32[$1997>>2] = $1993;
      $1998 = HEAP32[$yyvsp$2>>2]|0;
      $1999 = ($1998|0)==(0|0);
      if ($1999) {
       $yyval$sroa$0$0 = $1985;
      } else {
       __ZdlPv($1998);
       $yyval$sroa$0$0 = $1985;
      }
      break;
     }
     case 81:  {
      $2000 = (($yyvsp$2) + -16|0);
      $2001 = HEAP32[$2000>>2]|0;
      $2002 = (($2001) + 448|0);
      $2003 = (($yyvsp$2) + -8|0);
      $2004 = HEAP32[$2003>>2]|0;
      $2005 = $2004;
      $2006 = $2005;
      $2007 = HEAP32[$2006>>2]|0;
      $2008 = (($2005) + 4)|0;
      $2009 = $2008;
      $2010 = HEAP32[$2009>>2]|0;
      $2011 = $2002;
      $2012 = $2011;
      HEAP32[$2012>>2] = $2007;
      $2013 = (($2011) + 4)|0;
      $2014 = $2013;
      HEAP32[$2014>>2] = $2010;
      $2015 = HEAP32[$2003>>2]|0;
      $2016 = ($2015|0)==(0|0);
      if (!($2016)) {
       __ZdlPv($2015);
      }
      $2017 = HEAP32[$2000>>2]|0;
      $2018 = (($2017) + 456|0);
      $2019 = HEAP32[$yyvsp$2>>2]|0;
      $2020 = $2019;
      $2021 = $2020;
      $2022 = HEAP32[$2021>>2]|0;
      $2023 = (($2020) + 4)|0;
      $2024 = $2023;
      $2025 = HEAP32[$2024>>2]|0;
      $2026 = $2018;
      $2027 = $2026;
      HEAP32[$2027>>2] = $2022;
      $2028 = (($2026) + 4)|0;
      $2029 = $2028;
      HEAP32[$2029>>2] = $2025;
      $2030 = HEAP32[$yyvsp$2>>2]|0;
      $2031 = ($2030|0)==(0|0);
      if ($2031) {
       $yyval$sroa$0$0 = $2001;
      } else {
       __ZdlPv($2030);
       $yyval$sroa$0$0 = $2001;
      }
      break;
     }
     case 94:  {
      $2198 = (($yyvsp$2) + -8|0);
      $2199 = HEAP32[$2198>>2]|0;
      $2200 = (($2199) + 336|0);
      $2201 = HEAP32[$yyvsp$2>>2]|0;
      $2202 = $2201;
      $2203 = $2202;
      $2204 = HEAP32[$2203>>2]|0;
      $2205 = (($2202) + 4)|0;
      $2206 = $2205;
      $2207 = HEAP32[$2206>>2]|0;
      $2208 = $2200;
      $2209 = $2208;
      HEAP32[$2209>>2] = $2204;
      $2210 = (($2208) + 4)|0;
      $2211 = $2210;
      HEAP32[$2211>>2] = $2207;
      $2212 = HEAP32[$yyvsp$2>>2]|0;
      $2213 = ($2212|0)==(0|0);
      if ($2213) {
       $yyval$sroa$0$0 = $2199;
      } else {
       __ZdlPv($2212);
       $yyval$sroa$0$0 = $2199;
      }
      break;
     }
     case 104:  {
      $2358 = (__Znwj(12)|0);
      HEAP32[$2358>>2] = 0;
      $2359 = (($2358) + 4|0);
      HEAP32[$2359>>2] = 0;
      $2360 = (($2358) + 8|0);
      HEAP32[$2360>>2] = 0;
      $yyval$sroa$0$0 = $2358;
      break;
     }
     case 98:  {
      $2262 = (($yyvsp$2) + -8|0);
      $2263 = HEAP32[$2262>>2]|0;
      $2264 = (($2263) + 368|0);
      $2265 = HEAP32[$yyvsp$2>>2]|0;
      $2266 = $2265;
      $2267 = $2266;
      $2268 = HEAP32[$2267>>2]|0;
      $2269 = (($2266) + 4)|0;
      $2270 = $2269;
      $2271 = HEAP32[$2270>>2]|0;
      $2272 = $2264;
      $2273 = $2272;
      HEAP32[$2273>>2] = $2268;
      $2274 = (($2272) + 4)|0;
      $2275 = $2274;
      HEAP32[$2275>>2] = $2271;
      $2276 = HEAP32[$yyvsp$2>>2]|0;
      $2277 = ($2276|0)==(0|0);
      if ($2277) {
       $yyval$sroa$0$0 = $2263;
      } else {
       __ZdlPv($2276);
       $yyval$sroa$0$0 = $2263;
      }
      break;
     }
     case 110:  {
      $2432 = (($yyvsp$2) + -8|0);
      $2433 = HEAP32[$2432>>2]|0;
      $2434 = HEAP32[$yyvsp$2>>2]|0;
      $2435 = (($2433) + 4|0);
      HEAP32[$2435>>2] = $2434;
      $2436 = HEAP32[$yyvsp$2>>2]|0;
      $2437 = (($2433) + 8|0);
      HEAP32[$2437>>2] = $2436;
      $yyval$sroa$0$0 = $2433;
      break;
     }
     case 112:  {
      $2446 = (($yyvsp$2) + -8|0);
      $2447 = HEAP32[$2446>>2]|0;
      $2448 = HEAP32[$yyvsp$2>>2]|0;
      $2449 = (__Z6StrCmpPKcS0_($2448,677944)|0);
      $2450 = ($2449|0)==(0);
      if ($2450) {
       $2451 = (($2447) + 49|0);
       HEAP8[$2451>>0] = 1;
      } else {
       $2452 = HEAP32[674256>>2]|0;
       $2453 = HEAP32[$yyvsp$2>>2]|0;
       HEAP32[$$byval_copy43>>2] = $2453;
       __Z6FormatPKcz($20,677968,$$byval_copy43);
       $2454 = HEAP32[654192>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(104,($2452|0),($20|0),($2454|0),1,0);
       $2455 = __THREW__; __THREW__ = 0;
       $2456 = $2455&1;
       if ($2456) {
        label = 583;
        break L1;
       }
       $2457 = HEAP8[$20>>0]|0;
       $2458 = $2457 & 1;
       $2459 = ($2458<<24>>24)==(0);
       if (!($2459)) {
        $2460 = HEAP32[$91>>2]|0;
        __ZdlPv($2460);
       }
      }
      $2467 = HEAP32[679312>>2]|0;
      $2468 = HEAP32[$2467>>2]|0;
      $2469 = (($2468) + 20|0);
      $2470 = HEAP32[$2469>>2]|0;
      $2471 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$2470 & 4095]($2467,$2471);
      $yyval$sroa$0$0 = $2447;
      break;
     }
     case 90:  {
      $2134 = (($yyvsp$2) + -8|0);
      $2135 = HEAP32[$2134>>2]|0;
      $2136 = (($2135) + 424|0);
      $2137 = HEAP32[$yyvsp$2>>2]|0;
      $2138 = $2137;
      $2139 = $2138;
      $2140 = HEAP32[$2139>>2]|0;
      $2141 = (($2138) + 4)|0;
      $2142 = $2141;
      $2143 = HEAP32[$2142>>2]|0;
      $2144 = $2136;
      $2145 = $2144;
      HEAP32[$2145>>2] = $2140;
      $2146 = (($2144) + 4)|0;
      $2147 = $2146;
      HEAP32[$2147>>2] = $2143;
      $2148 = HEAP32[$yyvsp$2>>2]|0;
      $2149 = ($2148|0)==(0|0);
      if ($2149) {
       $yyval$sroa$0$0 = $2135;
      } else {
       __ZdlPv($2148);
       $yyval$sroa$0$0 = $2135;
      }
      break;
     }
     case 93:  {
      $2182 = (($yyvsp$2) + -8|0);
      $2183 = HEAP32[$2182>>2]|0;
      $2184 = (($2183) + 328|0);
      $2185 = HEAP32[$yyvsp$2>>2]|0;
      $2186 = $2185;
      $2187 = $2186;
      $2188 = HEAP32[$2187>>2]|0;
      $2189 = (($2186) + 4)|0;
      $2190 = $2189;
      $2191 = HEAP32[$2190>>2]|0;
      $2192 = $2184;
      $2193 = $2192;
      HEAP32[$2193>>2] = $2188;
      $2194 = (($2192) + 4)|0;
      $2195 = $2194;
      HEAP32[$2195>>2] = $2191;
      $2196 = HEAP32[$yyvsp$2>>2]|0;
      $2197 = ($2196|0)==(0|0);
      if ($2197) {
       $yyval$sroa$0$0 = $2183;
      } else {
       __ZdlPv($2196);
       $yyval$sroa$0$0 = $2183;
      }
      break;
     }
     case 96:  {
      $2230 = (($yyvsp$2) + -8|0);
      $2231 = HEAP32[$2230>>2]|0;
      $2232 = (($2231) + 384|0);
      $2233 = HEAP32[$yyvsp$2>>2]|0;
      $2234 = $2233;
      $2235 = $2234;
      $2236 = HEAP32[$2235>>2]|0;
      $2237 = (($2234) + 4)|0;
      $2238 = $2237;
      $2239 = HEAP32[$2238>>2]|0;
      $2240 = $2232;
      $2241 = $2240;
      HEAP32[$2241>>2] = $2236;
      $2242 = (($2240) + 4)|0;
      $2243 = $2242;
      HEAP32[$2243>>2] = $2239;
      $2244 = HEAP32[$yyvsp$2>>2]|0;
      $2245 = ($2244|0)==(0|0);
      if ($2245) {
       $yyval$sroa$0$0 = $2231;
      } else {
       __ZdlPv($2244);
       $yyval$sroa$0$0 = $2231;
      }
      break;
     }
     case 91:  {
      $2150 = (($yyvsp$2) + -8|0);
      $2151 = HEAP32[$2150>>2]|0;
      $2152 = (($2151) + 432|0);
      $2153 = HEAP32[$yyvsp$2>>2]|0;
      $2154 = $2153;
      $2155 = $2154;
      $2156 = HEAP32[$2155>>2]|0;
      $2157 = (($2154) + 4)|0;
      $2158 = $2157;
      $2159 = HEAP32[$2158>>2]|0;
      $2160 = $2152;
      $2161 = $2160;
      HEAP32[$2161>>2] = $2156;
      $2162 = (($2160) + 4)|0;
      $2163 = $2162;
      HEAP32[$2163>>2] = $2159;
      $2164 = HEAP32[$yyvsp$2>>2]|0;
      $2165 = ($2164|0)==(0|0);
      if ($2165) {
       $yyval$sroa$0$0 = $2151;
      } else {
       __ZdlPv($2164);
       $yyval$sroa$0$0 = $2151;
      }
      break;
     }
     case 97:  {
      $2246 = (($yyvsp$2) + -8|0);
      $2247 = HEAP32[$2246>>2]|0;
      $2248 = (($2247) + 360|0);
      $2249 = HEAP32[$yyvsp$2>>2]|0;
      $2250 = $2249;
      $2251 = $2250;
      $2252 = HEAP32[$2251>>2]|0;
      $2253 = (($2250) + 4)|0;
      $2254 = $2253;
      $2255 = HEAP32[$2254>>2]|0;
      $2256 = $2248;
      $2257 = $2256;
      HEAP32[$2257>>2] = $2252;
      $2258 = (($2256) + 4)|0;
      $2259 = $2258;
      HEAP32[$2259>>2] = $2255;
      $2260 = HEAP32[$yyvsp$2>>2]|0;
      $2261 = ($2260|0)==(0|0);
      if ($2261) {
       $yyval$sroa$0$0 = $2247;
      } else {
       __ZdlPv($2260);
       $yyval$sroa$0$0 = $2247;
      }
      break;
     }
     case 101:  {
      $2310 = (($yyvsp$2) + -8|0);
      $2311 = HEAP32[$2310>>2]|0;
      $2312 = (($2311) + 392|0);
      $2313 = HEAP32[$yyvsp$2>>2]|0;
      $2314 = $2313;
      $2315 = $2314;
      $2316 = HEAP32[$2315>>2]|0;
      $2317 = (($2314) + 4)|0;
      $2318 = $2317;
      $2319 = HEAP32[$2318>>2]|0;
      $2320 = $2312;
      $2321 = $2320;
      HEAP32[$2321>>2] = $2316;
      $2322 = (($2320) + 4)|0;
      $2323 = $2322;
      HEAP32[$2323>>2] = $2319;
      $2324 = HEAP32[$yyvsp$2>>2]|0;
      $2325 = ($2324|0)==(0|0);
      if ($2325) {
       $yyval$sroa$0$0 = $2311;
      } else {
       __ZdlPv($2324);
       $yyval$sroa$0$0 = $2311;
      }
      break;
     }
     case 102:  {
      $2326 = (($yyvsp$2) + -8|0);
      $2327 = HEAP32[$2326>>2]|0;
      $2328 = (($2327) + 400|0);
      $2329 = HEAP32[$yyvsp$2>>2]|0;
      $2330 = $2329;
      $2331 = $2330;
      $2332 = HEAP32[$2331>>2]|0;
      $2333 = (($2330) + 4)|0;
      $2334 = $2333;
      $2335 = HEAP32[$2334>>2]|0;
      $2336 = $2328;
      $2337 = $2336;
      HEAP32[$2337>>2] = $2332;
      $2338 = (($2336) + 4)|0;
      $2339 = $2338;
      HEAP32[$2339>>2] = $2335;
      $2340 = HEAP32[$yyvsp$2>>2]|0;
      $2341 = ($2340|0)==(0|0);
      if ($2341) {
       $yyval$sroa$0$0 = $2327;
      } else {
       __ZdlPv($2340);
       $yyval$sroa$0$0 = $2327;
      }
      break;
     }
     case 103:  {
      $2342 = (($yyvsp$2) + -8|0);
      $2343 = HEAP32[$2342>>2]|0;
      $2344 = (($2343) + 408|0);
      $2345 = HEAP32[$yyvsp$2>>2]|0;
      $2346 = $2345;
      $2347 = $2346;
      $2348 = HEAP32[$2347>>2]|0;
      $2349 = (($2346) + 4)|0;
      $2350 = $2349;
      $2351 = HEAP32[$2350>>2]|0;
      $2352 = $2344;
      $2353 = $2352;
      HEAP32[$2353>>2] = $2348;
      $2354 = (($2352) + 4)|0;
      $2355 = $2354;
      HEAP32[$2355>>2] = $2351;
      $2356 = HEAP32[$yyvsp$2>>2]|0;
      $2357 = ($2356|0)==(0|0);
      if ($2357) {
       $yyval$sroa$0$0 = $2343;
      } else {
       __ZdlPv($2356);
       $yyval$sroa$0$0 = $2343;
      }
      break;
     }
     case 105:  {
      $2361 = (($yyvsp$2) + -4|0);
      $2362 = HEAP32[$2361>>2]|0;
      $2363 = HEAP32[$yyvsp$2>>2]|0;
      $2364 = (($2362) + 4|0);
      $2365 = HEAP32[$2364>>2]|0;
      $2366 = (($2362) + 8|0);
      $2367 = HEAP32[$2366>>2]|0;
      $2368 = ($2365|0)==($2367|0);
      if ($2368) {
       __ZNSt3__16vectorIN9ShaderLab16ParserSetTextureENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($2362,$2363);
      } else {
       $2369 = ($2365|0)==(0|0);
       if ($2369) {
        $2371 = 0;
       } else {
        dest=$2365+0|0; src=$2363+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $$pre$i169 = HEAP32[$2364>>2]|0;
        $2371 = $$pre$i169;
       }
       $2370 = (($2371) + 52|0);
       HEAP32[$2364>>2] = $2370;
      }
      $2372 = HEAP32[$yyvsp$2>>2]|0;
      $2373 = ($2372|0)==(0|0);
      if ($2373) {
       $yyval$sroa$0$0 = $2362;
      } else {
       __ZdlPv($2372);
       $yyval$sroa$0$0 = $2362;
      }
      break;
     }
     case 106:  {
      $2374 = (__Znwj(52)|0);
      $2375 = (($2374) + 12|0);
      $2376 = (($2374) + 16|0);
      $2377 = (($2374) + 20|0);
      $2378 = (($2374) + 24|0);
      $2379 = (($2374) + 28|0);
      $2380 = (($2374) + 32|0);
      $2381 = (($2374) + 36|0);
      $2382 = (($2374) + 40|0);
      $2383 = (($2374) + 44|0);
      HEAP32[$2374>>2] = -1;
      $2384 = (($2374) + 4|0);
      HEAP32[$2384>>2] = 16842752;
      $2385 = (($2374) + 8|0);
      HEAP32[$2385>>2] = 17104900;
      HEAPF32[$2375>>2] = Math_fround(0.0);
      HEAP32[$2376>>2] = -1;
      HEAPF32[$2377>>2] = Math_fround(0.0);
      HEAP32[$2378>>2] = -1;
      HEAPF32[$2379>>2] = Math_fround(0.0);
      HEAP32[$2380>>2] = -1;
      HEAPF32[$2381>>2] = Math_fround(0.0);
      HEAP32[$2382>>2] = -1;
      HEAP32[$2383>>2] = -1;
      $2386 = (($2374) + 48|0);
      HEAP8[$2386>>0] = 0;
      $2387 = (($2374) + 49|0);
      HEAP8[$2387>>0] = 0;
      $2388 = HEAP32[$yyvsp$2>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$2388);
      $2389 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$2374>>2] = $2389;
      $2390 = HEAP32[679312>>2]|0;
      $2391 = HEAP32[$2390>>2]|0;
      $2392 = (($2391) + 20|0);
      $2393 = HEAP32[$2392>>2]|0;
      $2394 = HEAP32[$yyvsp$2>>2]|0;
      FUNCTION_TABLE_vii[$2393 & 4095]($2390,$2394);
      $yyval$sroa$0$0 = $2374;
      break;
     }
     case 107:  {
      $2395 = (($yyvsp$2) + -4|0);
      $2396 = HEAP32[$2395>>2]|0;
      $2397 = (($yyvsp$2) + -12|0);
      $2398 = HEAP32[$2397>>2]|0;
      HEAP32[$$byval_copy43>>2] = -1;
      __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy43,$2398);
      $2399 = HEAP32[$$byval_copy43>>2]|0;
      HEAP32[$2396>>2] = $2399;
      $2400 = HEAP32[679312>>2]|0;
      $2401 = HEAP32[$2400>>2]|0;
      $2402 = (($2401) + 20|0);
      $2403 = HEAP32[$2402>>2]|0;
      $2404 = HEAP32[$2397>>2]|0;
      FUNCTION_TABLE_vii[$2403 & 4095]($2400,$2404);
      $yyval$sroa$0$0 = $2396;
      break;
     }
     case 108:  {
      $2405 = (__Znwj(52)|0);
      $2406 = (($2405) + 12|0);
      $2407 = (($2405) + 16|0);
      $2408 = (($2405) + 20|0);
      $2409 = (($2405) + 24|0);
      $2410 = (($2405) + 28|0);
      $2411 = (($2405) + 32|0);
      $2412 = (($2405) + 36|0);
      $2413 = (($2405) + 40|0);
      $2414 = (($2405) + 44|0);
      HEAP32[$2405>>2] = -1;
      $2415 = (($2405) + 4|0);
      HEAP32[$2415>>2] = 16842752;
      $2416 = (($2405) + 8|0);
      HEAP32[$2416>>2] = 17104900;
      HEAPF32[$2406>>2] = Math_fround(0.0);
      HEAP32[$2407>>2] = -1;
      HEAPF32[$2408>>2] = Math_fround(0.0);
      HEAP32[$2409>>2] = -1;
      HEAPF32[$2410>>2] = Math_fround(0.0);
      HEAP32[$2411>>2] = -1;
      HEAPF32[$2412>>2] = Math_fround(0.0);
      HEAP32[$2413>>2] = -1;
      HEAP32[$2414>>2] = -1;
      $2417 = (($2405) + 48|0);
      HEAP8[$2417>>0] = 0;
      $2418 = (($2405) + 49|0);
      HEAP8[$2418>>0] = 0;
      $yyval$sroa$0$0 = $2405;
      break;
     }
     case 99:  {
      $2278 = (($yyvsp$2) + -8|0);
      $2279 = HEAP32[$2278>>2]|0;
      $2280 = (($2279) + 376|0);
      $2281 = HEAP32[$yyvsp$2>>2]|0;
      $2282 = $2281;
      $2283 = $2282;
      $2284 = HEAP32[$2283>>2]|0;
      $2285 = (($2282) + 4)|0;
      $2286 = $2285;
      $2287 = HEAP32[$2286>>2]|0;
      $2288 = $2280;
      $2289 = $2288;
      HEAP32[$2289>>2] = $2284;
      $2290 = (($2288) + 4)|0;
      $2291 = $2290;
      HEAP32[$2291>>2] = $2287;
      $2292 = HEAP32[$yyvsp$2>>2]|0;
      $2293 = ($2292|0)==(0|0);
      if ($2293) {
       $yyval$sroa$0$0 = $2279;
      } else {
       __ZdlPv($2292);
       $yyval$sroa$0$0 = $2279;
      }
      break;
     }
     case 111:  {
      $2438 = (($yyvsp$2) + -16|0);
      $2439 = HEAP32[$2438>>2]|0;
      $2440 = (($yyvsp$2) + -8|0);
      $2441 = HEAP32[$2440>>2]|0;
      $2442 = (($2439) + 4|0);
      HEAP32[$2442>>2] = $2441;
      $2443 = HEAP32[$yyvsp$2>>2]|0;
      $2444 = $2443 | 262148;
      $2445 = (($2439) + 8|0);
      HEAP32[$2445>>2] = $2444;
      $yyval$sroa$0$0 = $2439;
      break;
     }
     case 95:  {
      $2214 = (($yyvsp$2) + -8|0);
      $2215 = HEAP32[$2214>>2]|0;
      $2216 = (($2215) + 344|0);
      $2217 = HEAP32[$yyvsp$2>>2]|0;
      $2218 = $2217;
      $2219 = $2218;
      $2220 = HEAP32[$2219>>2]|0;
      $2221 = (($2218) + 4)|0;
      $2222 = $2221;
      $2223 = HEAP32[$2222>>2]|0;
      $2224 = $2216;
      $2225 = $2224;
      HEAP32[$2225>>2] = $2220;
      $2226 = (($2224) + 4)|0;
      $2227 = $2226;
      HEAP32[$2227>>2] = $2223;
      $2228 = HEAP32[$yyvsp$2>>2]|0;
      $2229 = ($2228|0)==(0|0);
      if ($2229) {
       $yyval$sroa$0$0 = $2215;
      } else {
       __ZdlPv($2228);
       $yyval$sroa$0$0 = $2215;
      }
      break;
     }
     case 109:  {
      $2419 = (($yyvsp$2) + -8|0);
      $2420 = HEAP32[$2419>>2]|0;
      $2421 = HEAP32[$yyvsp$2>>2]|0;
      $2422 = (($2421) + 12|0);
      $2423 = (($2420) + 12|0);
      dest=$2423+0|0; src=$2422+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $2424 = (($2420) + 48|0);
      HEAP8[$2424>>0] = 1;
      $2425 = HEAP32[$yyvsp$2>>2]|0;
      $2426 = ($2425|0)==(0|0);
      if ($2426) {
       $yyval$sroa$0$0 = $2420;
      } else {
       $2427 = HEAP8[$2425>>0]|0;
       $2428 = $2427 & 1;
       $2429 = ($2428<<24>>24)==(0);
       if (!($2429)) {
        $2430 = (($2425) + 8|0);
        $2431 = HEAP32[$2430>>2]|0;
        __ZdlPv($2431);
       }
       __ZdlPv($2425);
       $yyval$sroa$0$0 = $2420;
      }
      break;
     }
     case 92:  {
      $2166 = (($yyvsp$2) + -8|0);
      $2167 = HEAP32[$2166>>2]|0;
      $2168 = (($2167) + 352|0);
      $2169 = HEAP32[$yyvsp$2>>2]|0;
      $2170 = $2169;
      $2171 = $2170;
      $2172 = HEAP32[$2171>>2]|0;
      $2173 = (($2170) + 4)|0;
      $2174 = $2173;
      $2175 = HEAP32[$2174>>2]|0;
      $2176 = $2168;
      $2177 = $2176;
      HEAP32[$2177>>2] = $2172;
      $2178 = (($2176) + 4)|0;
      $2179 = $2178;
      HEAP32[$2179>>2] = $2175;
      $2180 = HEAP32[$yyvsp$2>>2]|0;
      $2181 = ($2180|0)==(0|0);
      if ($2181) {
       $yyval$sroa$0$0 = $2167;
      } else {
       __ZdlPv($2180);
       $yyval$sroa$0$0 = $2167;
      }
      break;
     }
     case 100:  {
      $2294 = (($yyvsp$2) + -8|0);
      $2295 = HEAP32[$2294>>2]|0;
      $2296 = (($2295) + 416|0);
      $2297 = HEAP32[$yyvsp$2>>2]|0;
      $2298 = $2297;
      $2299 = $2298;
      $2300 = HEAP32[$2299>>2]|0;
      $2301 = (($2298) + 4)|0;
      $2302 = $2301;
      $2303 = HEAP32[$2302>>2]|0;
      $2304 = $2296;
      $2305 = $2304;
      HEAP32[$2305>>2] = $2300;
      $2306 = (($2304) + 4)|0;
      $2307 = $2306;
      HEAP32[$2307>>2] = $2303;
      $2308 = HEAP32[$yyvsp$2>>2]|0;
      $2309 = ($2308|0)==(0|0);
      if ($2309) {
       $yyval$sroa$0$0 = $2295;
      } else {
       __ZdlPv($2308);
       $yyval$sroa$0$0 = $2295;
      }
      break;
     }
     case 115:  {
      $2480 = (($yyvsp$2) + -24|0);
      $2481 = HEAP32[$2480>>2]|0;
      $2482 = (($yyvsp$2) + -4|0);
      $2483 = HEAP32[$2482>>2]|0;
      $2484 = ($2483|0)==(0|0);
      do {
       if (!($2484)) {
        $2485 = (($2481) + 4|0);
        $2486 = HEAP32[$2485>>2]|0;
        $2487 = (($2481) + 8|0);
        $2488 = HEAP32[$2487>>2]|0;
        $2489 = ($2486|0)==($2488|0);
        if (!($2489)) {
         $2490 = ($2486|0)==(0|0);
         if ($2490) {
          $2492 = 0;
         } else {
          HEAP32[$2486>>2] = $2483;
          $$pre$i173 = HEAP32[$2485>>2]|0;
          $2492 = $$pre$i173;
         }
         $2491 = (($2492) + 4|0);
         HEAP32[$2485>>2] = $2491;
         break;
        }
        $2493 = HEAP32[$2481>>2]|0;
        $2494 = $2486;
        $2495 = $2493;
        $2496 = (($2494) - ($2495))|0;
        $2497 = $2496 >> 2;
        $2498 = (($2497) + 1)|0;
        $2499 = ($2498>>>0)>(1073741823);
        if ($2499) {
         label = 594;
         break L1;
        }
        $2500 = ($2497>>>0)<(536870911);
        if ($2500) {
         $2501 = $2496 >> 1;
         $2502 = ($2501>>>0)<($2498>>>0);
         $2503 = $2502 ? $2498 : $2501;
         $2504 = ($2503|0)==(0);
         if ($2504) {
          $$0$i3$i$i175 = 0;$2508 = 0;
         } else {
          $$0$i2$i$i174 = $2503;
          label = 597;
         }
        } else {
         $$0$i2$i$i174 = 1073741823;
         label = 597;
        }
        if ((label|0) == 597) {
         label = 0;
         $2505 = $$0$i2$i$i174 << 2;
         $2506 = (__Znwj($2505)|0);
         $$0$i3$i$i175 = $$0$i2$i$i174;$2508 = $2506;
        }
        $2507 = (($2508) + ($2497<<2)|0);
        $2509 = (($2508) + ($$0$i3$i$i175<<2)|0);
        $2510 = ($2507|0)==(0|0);
        if (!($2510)) {
         $2511 = HEAP32[$2482>>2]|0;
         HEAP32[$2507>>2] = $2511;
        }
        $2512 = (($2508) + ($2498<<2)|0);
        _memcpy(($2508|0),($2493|0),($2496|0))|0;
        HEAP32[$2481>>2] = $2508;
        HEAP32[$2485>>2] = $2512;
        HEAP32[$2487>>2] = $2509;
        $2513 = ($2493|0)==(0|0);
        if (!($2513)) {
         __ZdlPv($2493);
        }
       }
      } while(0);
      $2514 = HEAP32[679312>>2]|0;
      $2515 = HEAP32[$2514>>2]|0;
      $2516 = (($2515) + 20|0);
      $2517 = HEAP32[$2516>>2]|0;
      $2518 = (($yyvsp$2) + -16|0);
      $2519 = HEAP32[$2518>>2]|0;
      FUNCTION_TABLE_vii[$2517 & 4095]($2514,$2519);
      HEAP8[678040>>0] = 0;
      $yyval$sroa$0$0 = $2481;
      break;
     }
     case 118:  {
      $2560 = (($yyvsp$2) + -4|0);
      $2561 = HEAP32[$2560>>2]|0;
      $2562 = ($2561|0)==(0|0);
      if ($2562) {
       $$pre$phiZ2D = $yyvsp$2;
      } else {
       $2563 = HEAP32[$yyvsp$2>>2]|0;
       (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($2561,$2563)|0);
       $$pre$phiZ2D = $yyvsp$2;
      }
      $2564 = HEAP32[679312>>2]|0;
      $2565 = HEAP32[$2564>>2]|0;
      $2566 = (($2565) + 20|0);
      $2567 = HEAP32[$2566>>2]|0;
      $2568 = HEAP32[$$pre$phiZ2D>>2]|0;
      FUNCTION_TABLE_vii[$2567 & 4095]($2564,$2568);
      $yyval$sroa$0$0 = $2561;
      break;
     }
     case 114:  {
      $2475 = HEAP32[674264>>2]|0;
      $2476 = (($yyvsp$2) + -4|0);
      $2477 = HEAP32[$2476>>2]|0;
      $2478 = (__Z30ComputeIgnoreCurrentSubProgram17GfxDeviceRendererPKc($2475,$2477)|0);
      $2479 = $2478&1;
      HEAP8[678040>>0] = $2479;
      $yyval$sroa$0$0 = $218;
      break;
     }
     case 117:  {
      $2553 = HEAP8[678040>>0]|0;
      $2554 = ($2553<<24>>24)==(0);
      if ($2554) {
       $2555 = (__Znwj(220)|0);
       __THREW__ = 0;
       invoke_vi(3595,($2555|0));
       $2556 = __THREW__; __THREW__ = 0;
       $2557 = $2556&1;
       if ($2557) {
        label = 620;
        break L1;
       } else {
        $3848 = $2555;
       }
      } else {
       $3848 = 0;
      }
      $yyval$sroa$0$0 = $3848;
      break;
     }
     case 119:  {
      $2569 = (($yyvsp$2) + -12|0);
      $2570 = HEAP32[$2569>>2]|0;
      $2571 = ($2570|0)==(0|0);
      $$pre1450 = (($yyvsp$2) + -4|0);
      if (!($2571)) {
       $2572 = HEAP32[$$pre1450>>2]|0;
       $2573 = (_strlen(($2572|0))|0);
       $2574 = ($2573>>>0)>(4294967279);
       if ($2574) {
        label = 627;
        break L1;
       }
       $2575 = ($2573>>>0)<(11);
       if ($2575) {
        $2576 = $2573 << 1;
        $2577 = $2576&255;
        HEAP8[$21>>0] = $2577;
        $__p$0$i$i$i187 = $92;
       } else {
        $2578 = (($2573) + 16)|0;
        $2579 = $2578 & -16;
        $2580 = (__Znwj($2579)|0);
        HEAP32[$93>>2] = $2580;
        $2581 = $2579 | 1;
        HEAP32[$21>>2] = $2581;
        HEAP32[$94>>2] = $2573;
        $__p$0$i$i$i187 = $2580;
       }
       _memcpy(($__p$0$i$i$i187|0),($2572|0),($2573|0))|0;
       $2582 = (($__p$0$i$i$i187) + ($2573)|0);
       HEAP8[$2582>>0] = 0;
       __THREW__ = 0;
       $2583 = (invoke_ii(3326,($21|0))|0);
       $2584 = __THREW__; __THREW__ = 0;
       $2585 = $2584&1;
       if ($2585) {
        label = 635;
        break L1;
       }
       $2586 = HEAP8[$21>>0]|0;
       $2587 = $2586 & 1;
       $2588 = ($2587<<24>>24)==(0);
       if (!($2588)) {
        $2589 = HEAP32[$93>>2]|0;
        __ZdlPv($2589);
       }
       $2590 = HEAP32[$2569>>2]|0;
       $2591 = (($2590) + 12|0);
       $2592 = HEAP32[$yyvsp$2>>2]|0;
       __ZN9ShaderLab18ParserBindChannels4BindE13ShaderChannel15VertexComponentbP12ShaderErrors($2591,$2583,$2592,0,0);
      }
      $2599 = HEAP32[679312>>2]|0;
      $2600 = HEAP32[$2599>>2]|0;
      $2601 = (($2600) + 20|0);
      $2602 = HEAP32[$2601>>2]|0;
      $2603 = HEAP32[$$pre1450>>2]|0;
      FUNCTION_TABLE_vii[$2602 & 4095]($2599,$2603);
      $yyval$sroa$0$0 = $2570;
      break;
     }
     case 116:  {
      $2520 = (($yyvsp$2) + -16|0);
      $2521 = HEAP32[$2520>>2]|0;
      HEAP8[678040>>0] = 0;
      $2522 = (($yyvsp$2) + -4|0);
      $2523 = (($2521) + 4|0);
      $2524 = HEAP32[$2523>>2]|0;
      $2525 = (($2521) + 8|0);
      $2526 = HEAP32[$2525>>2]|0;
      $2527 = ($2524|0)==($2526|0);
      if ($2527) {
       $2532 = HEAP32[$2521>>2]|0;
       $2533 = $2524;
       $2534 = $2532;
       $2535 = (($2533) - ($2534))|0;
       $2536 = $2535 >> 2;
       $2537 = (($2536) + 1)|0;
       $2538 = ($2537>>>0)>(1073741823);
       if ($2538) {
        label = 608;
        break L1;
       }
       $2539 = ($2536>>>0)<(536870911);
       if ($2539) {
        $2540 = $2535 >> 1;
        $2541 = ($2540>>>0)<($2537>>>0);
        $2542 = $2541 ? $2537 : $2540;
        $2543 = ($2542|0)==(0);
        if ($2543) {
         $$0$i3$i$i181 = 0;$2547 = 0;
        } else {
         $$0$i2$i$i179 = $2542;
         label = 611;
        }
       } else {
        $$0$i2$i$i179 = 1073741823;
        label = 611;
       }
       if ((label|0) == 611) {
        label = 0;
        $2544 = $$0$i2$i$i179 << 2;
        $2545 = (__Znwj($2544)|0);
        $$0$i3$i$i181 = $$0$i2$i$i179;$2547 = $2545;
       }
       $2546 = (($2547) + ($2536<<2)|0);
       $2548 = (($2547) + ($$0$i3$i$i181<<2)|0);
       $2549 = ($2546|0)==(0|0);
       if (!($2549)) {
        $2550 = HEAP32[$2522>>2]|0;
        HEAP32[$2546>>2] = $2550;
       }
       $2551 = (($2547) + ($2537<<2)|0);
       _memcpy(($2547|0),($2532|0),($2535|0))|0;
       HEAP32[$2521>>2] = $2547;
       HEAP32[$2523>>2] = $2551;
       HEAP32[$2525>>2] = $2548;
       $2552 = ($2532|0)==(0|0);
       if (!($2552)) {
        __ZdlPv($2532);
       }
      } else {
       $2528 = ($2524|0)==(0|0);
       if ($2528) {
        $2531 = 0;
       } else {
        $2529 = HEAP32[$2522>>2]|0;
        HEAP32[$2524>>2] = $2529;
        $$pre$i176 = HEAP32[$2523>>2]|0;
        $2531 = $$pre$i176;
       }
       $2530 = (($2531) + 4|0);
       HEAP32[$2523>>2] = $2530;
      }
      HEAP8[678040>>0] = 0;
      $yyval$sroa$0$0 = $2521;
      break;
     }
     case 113:  {
      $2472 = (__Znwj(12)|0);
      HEAP32[$2472>>2] = 0;
      $2473 = (($2472) + 4|0);
      HEAP32[$2473>>2] = 0;
      $2474 = (($2472) + 8|0);
      HEAP32[$2474>>2] = 0;
      $yyval$sroa$0$0 = $2472;
      break;
     }
     case 120:  {
      $2604 = (($yyvsp$2) + -12|0);
      $2605 = HEAP32[$2604>>2]|0;
      $2606 = ($2605|0)==(0|0);
      if ($2606) {
       $$pre$phi1455Z2D = $yyvsp$2;
      } else {
       $2607 = (($yyvsp$2) + -4|0);
       $2608 = Math_fround(HEAPF32[$2607>>2]);
       $2609 = (~~(($2608)));
       $2610 = HEAP32[$yyvsp$2>>2]|0;
       $2611 = (_strlen(($2610|0))|0);
       $2612 = ($2611>>>0)>(4294967279);
       if ($2612) {
        label = 641;
        break L1;
       }
       $2613 = ($2611>>>0)<(11);
       if ($2613) {
        $2614 = $2611 << 1;
        $2615 = $2614&255;
        HEAP8[$22>>0] = $2615;
        $__p$0$i$i$i192 = $95;
       } else {
        $2616 = (($2611) + 16)|0;
        $2617 = $2616 & -16;
        $2618 = (__Znwj($2617)|0);
        HEAP32[$96>>2] = $2618;
        $2619 = $2617 | 1;
        HEAP32[$22>>2] = $2619;
        HEAP32[$97>>2] = $2611;
        $__p$0$i$i$i192 = $2618;
       }
       _memcpy(($__p$0$i$i$i192|0),($2610|0),($2611|0))|0;
       $2620 = (($__p$0$i$i$i192) + ($2611)|0);
       HEAP8[$2620>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2605|0),0,($2609|0),1,($22|0));
       $2621 = __THREW__; __THREW__ = 0;
       $2622 = $2621&1;
       if ($2622) {
        label = 648;
        break L1;
       }
       $2623 = HEAP8[$22>>0]|0;
       $2624 = $2623 & 1;
       $2625 = ($2624<<24>>24)==(0);
       if ($2625) {
        $$pre$phi1455Z2D = $yyvsp$2;
       } else {
        $2626 = HEAP32[$96>>2]|0;
        __ZdlPv($2626);
        $$pre$phi1455Z2D = $yyvsp$2;
       }
      }
      $2633 = HEAP32[679312>>2]|0;
      $2634 = HEAP32[$2633>>2]|0;
      $2635 = (($2634) + 20|0);
      $2636 = HEAP32[$2635>>2]|0;
      $2637 = HEAP32[$$pre$phi1455Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2636 & 4095]($2633,$2637);
      $yyval$sroa$0$0 = $2605;
      break;
     }
     case 121:  {
      $2638 = (($yyvsp$2) + -12|0);
      $2639 = HEAP32[$2638>>2]|0;
      $2640 = ($2639|0)==(0|0);
      if ($2640) {
       $$pre$phi1457Z2D = $yyvsp$2;
      } else {
       $2641 = (($yyvsp$2) + -4|0);
       $2642 = Math_fround(HEAPF32[$2641>>2]);
       $2643 = (~~(($2642)));
       $2644 = HEAP32[$yyvsp$2>>2]|0;
       $2645 = (_strlen(($2644|0))|0);
       $2646 = ($2645>>>0)>(4294967279);
       if ($2646) {
        label = 654;
        break L1;
       }
       $2647 = ($2645>>>0)<(11);
       if ($2647) {
        $2648 = $2645 << 1;
        $2649 = $2648&255;
        HEAP8[$23>>0] = $2649;
        $__p$0$i$i$i197 = $98;
       } else {
        $2650 = (($2645) + 16)|0;
        $2651 = $2650 & -16;
        $2652 = (__Znwj($2651)|0);
        HEAP32[$99>>2] = $2652;
        $2653 = $2651 | 1;
        HEAP32[$23>>2] = $2653;
        HEAP32[$100>>2] = $2645;
        $__p$0$i$i$i197 = $2652;
       }
       _memcpy(($__p$0$i$i$i197|0),($2644|0),($2645|0))|0;
       $2654 = (($__p$0$i$i$i197) + ($2645)|0);
       HEAP8[$2654>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2639|0),0,($2643|0),4,($23|0));
       $2655 = __THREW__; __THREW__ = 0;
       $2656 = $2655&1;
       if ($2656) {
        label = 661;
        break L1;
       }
       $2657 = HEAP8[$23>>0]|0;
       $2658 = $2657 & 1;
       $2659 = ($2658<<24>>24)==(0);
       if ($2659) {
        $$pre$phi1457Z2D = $yyvsp$2;
       } else {
        $2660 = HEAP32[$99>>2]|0;
        __ZdlPv($2660);
        $$pre$phi1457Z2D = $yyvsp$2;
       }
      }
      $2667 = HEAP32[679312>>2]|0;
      $2668 = HEAP32[$2667>>2]|0;
      $2669 = (($2668) + 20|0);
      $2670 = HEAP32[$2669>>2]|0;
      $2671 = HEAP32[$$pre$phi1457Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2670 & 4095]($2667,$2671);
      $yyval$sroa$0$0 = $2639;
      break;
     }
     case 122:  {
      $2672 = (($yyvsp$2) + -16|0);
      $2673 = HEAP32[$2672>>2]|0;
      $2674 = ($2673|0)==(0|0);
      if ($2674) {
       $$pre1458 = (($yyvsp$2) + -4|0);
       $$pre$phi1461Z2D = $$pre1458;
      } else {
       $2675 = (($yyvsp$2) + -8|0);
       $2676 = Math_fround(HEAPF32[$2675>>2]);
       $2677 = (~~(($2676)));
       $2678 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $2679 = (~~(($2678)));
       $2680 = (($yyvsp$2) + -4|0);
       $2681 = HEAP32[$2680>>2]|0;
       $2682 = (_strlen(($2681|0))|0);
       $2683 = ($2682>>>0)>(4294967279);
       if ($2683) {
        label = 667;
        break L1;
       }
       $2684 = ($2682>>>0)<(11);
       if ($2684) {
        $2685 = $2682 << 1;
        $2686 = $2685&255;
        HEAP8[$24>>0] = $2686;
        $__p$0$i$i$i202 = $101;
       } else {
        $2687 = (($2682) + 16)|0;
        $2688 = $2687 & -16;
        $2689 = (__Znwj($2688)|0);
        HEAP32[$102>>2] = $2689;
        $2690 = $2688 | 1;
        HEAP32[$24>>2] = $2690;
        HEAP32[$103>>2] = $2682;
        $__p$0$i$i$i202 = $2689;
       }
       _memcpy(($__p$0$i$i$i202|0),($2681|0),($2682|0))|0;
       $2691 = (($__p$0$i$i$i202) + ($2682)|0);
       HEAP8[$2691>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2673|0),0,($2677|0),($2679|0),($24|0));
       $2692 = __THREW__; __THREW__ = 0;
       $2693 = $2692&1;
       if ($2693) {
        label = 674;
        break L1;
       }
       $2694 = HEAP8[$24>>0]|0;
       $2695 = $2694 & 1;
       $2696 = ($2695<<24>>24)==(0);
       if ($2696) {
        $$pre$phi1461Z2D = $2680;
       } else {
        $2697 = HEAP32[$102>>2]|0;
        __ZdlPv($2697);
        $$pre$phi1461Z2D = $2680;
       }
      }
      $2704 = HEAP32[679312>>2]|0;
      $2705 = HEAP32[$2704>>2]|0;
      $2706 = (($2705) + 20|0);
      $2707 = HEAP32[$2706>>2]|0;
      $2708 = HEAP32[$$pre$phi1461Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2707 & 4095]($2704,$2708);
      $yyval$sroa$0$0 = $2673;
      break;
     }
     case 126:  {
      $2814 = (($yyvsp$2) + -16|0);
      $2815 = HEAP32[$2814>>2]|0;
      $2816 = ($2815|0)==(0|0);
      if ($2816) {
       $$pre1470 = (($yyvsp$2) + -4|0);
       $$pre$phi1473Z2D = $$pre1470;
      } else {
       $2817 = (($yyvsp$2) + -8|0);
       $2818 = Math_fround(HEAPF32[$2817>>2]);
       $2819 = (~~(($2818)));
       $2820 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $2821 = (~~(($2820)));
       $2822 = (($yyvsp$2) + -4|0);
       $2823 = HEAP32[$2822>>2]|0;
       $2824 = (_strlen(($2823|0))|0);
       $2825 = ($2824>>>0)>(4294967279);
       if ($2825) {
        label = 719;
        break L1;
       }
       $2826 = ($2824>>>0)<(11);
       if ($2826) {
        $2827 = $2824 << 1;
        $2828 = $2827&255;
        HEAP8[$28>>0] = $2828;
        $__p$0$i$i$i222 = $113;
       } else {
        $2829 = (($2824) + 16)|0;
        $2830 = $2829 & -16;
        $2831 = (__Znwj($2830)|0);
        HEAP32[$114>>2] = $2831;
        $2832 = $2830 | 1;
        HEAP32[$28>>2] = $2832;
        HEAP32[$115>>2] = $2824;
        $__p$0$i$i$i222 = $2831;
       }
       _memcpy(($__p$0$i$i$i222|0),($2823|0),($2824|0))|0;
       $2833 = (($__p$0$i$i$i222) + ($2824)|0);
       HEAP8[$2833>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2815|0),2,($2819|0),($2821|0),($28|0));
       $2834 = __THREW__; __THREW__ = 0;
       $2835 = $2834&1;
       if ($2835) {
        label = 726;
        break L1;
       }
       $2836 = HEAP8[$28>>0]|0;
       $2837 = $2836 & 1;
       $2838 = ($2837<<24>>24)==(0);
       if ($2838) {
        $$pre$phi1473Z2D = $2822;
       } else {
        $2839 = HEAP32[$114>>2]|0;
        __ZdlPv($2839);
        $$pre$phi1473Z2D = $2822;
       }
      }
      $2846 = HEAP32[679312>>2]|0;
      $2847 = HEAP32[$2846>>2]|0;
      $2848 = (($2847) + 20|0);
      $2849 = HEAP32[$2848>>2]|0;
      $2850 = HEAP32[$$pre$phi1473Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2849 & 4095]($2846,$2850);
      $yyval$sroa$0$0 = $2815;
      break;
     }
     case 123:  {
      $2709 = (($yyvsp$2) + -12|0);
      $2710 = HEAP32[$2709>>2]|0;
      $2711 = ($2710|0)==(0|0);
      if ($2711) {
       $$pre$phi1463Z2D = $yyvsp$2;
      } else {
       $2712 = (($yyvsp$2) + -4|0);
       $2713 = Math_fround(HEAPF32[$2712>>2]);
       $2714 = (~~(($2713)));
       $2715 = HEAP32[$yyvsp$2>>2]|0;
       $2716 = (_strlen(($2715|0))|0);
       $2717 = ($2716>>>0)>(4294967279);
       if ($2717) {
        label = 680;
        break L1;
       }
       $2718 = ($2716>>>0)<(11);
       if ($2718) {
        $2719 = $2716 << 1;
        $2720 = $2719&255;
        HEAP8[$25>>0] = $2720;
        $__p$0$i$i$i207 = $104;
       } else {
        $2721 = (($2716) + 16)|0;
        $2722 = $2721 & -16;
        $2723 = (__Znwj($2722)|0);
        HEAP32[$105>>2] = $2723;
        $2724 = $2722 | 1;
        HEAP32[$25>>2] = $2724;
        HEAP32[$106>>2] = $2716;
        $__p$0$i$i$i207 = $2723;
       }
       _memcpy(($__p$0$i$i$i207|0),($2715|0),($2716|0))|0;
       $2725 = (($__p$0$i$i$i207) + ($2716)|0);
       HEAP8[$2725>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2710|0),1,($2714|0),1,($25|0));
       $2726 = __THREW__; __THREW__ = 0;
       $2727 = $2726&1;
       if ($2727) {
        label = 687;
        break L1;
       }
       $2728 = HEAP8[$25>>0]|0;
       $2729 = $2728 & 1;
       $2730 = ($2729<<24>>24)==(0);
       if ($2730) {
        $$pre$phi1463Z2D = $yyvsp$2;
       } else {
        $2731 = HEAP32[$105>>2]|0;
        __ZdlPv($2731);
        $$pre$phi1463Z2D = $yyvsp$2;
       }
      }
      $2738 = HEAP32[679312>>2]|0;
      $2739 = HEAP32[$2738>>2]|0;
      $2740 = (($2739) + 20|0);
      $2741 = HEAP32[$2740>>2]|0;
      $2742 = HEAP32[$$pre$phi1463Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2741 & 4095]($2738,$2742);
      $yyval$sroa$0$0 = $2710;
      break;
     }
     case 124:  {
      $2743 = (($yyvsp$2) + -16|0);
      $2744 = HEAP32[$2743>>2]|0;
      $2745 = ($2744|0)==(0|0);
      if ($2745) {
       $$pre1464 = (($yyvsp$2) + -4|0);
       $$pre$phi1467Z2D = $$pre1464;
      } else {
       $2746 = (($yyvsp$2) + -8|0);
       $2747 = Math_fround(HEAPF32[$2746>>2]);
       $2748 = (~~(($2747)));
       $2749 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $2750 = (~~(($2749)));
       $2751 = (($yyvsp$2) + -4|0);
       $2752 = HEAP32[$2751>>2]|0;
       $2753 = (_strlen(($2752|0))|0);
       $2754 = ($2753>>>0)>(4294967279);
       if ($2754) {
        label = 693;
        break L1;
       }
       $2755 = ($2753>>>0)<(11);
       if ($2755) {
        $2756 = $2753 << 1;
        $2757 = $2756&255;
        HEAP8[$26>>0] = $2757;
        $__p$0$i$i$i212 = $107;
       } else {
        $2758 = (($2753) + 16)|0;
        $2759 = $2758 & -16;
        $2760 = (__Znwj($2759)|0);
        HEAP32[$108>>2] = $2760;
        $2761 = $2759 | 1;
        HEAP32[$26>>2] = $2761;
        HEAP32[$109>>2] = $2753;
        $__p$0$i$i$i212 = $2760;
       }
       _memcpy(($__p$0$i$i$i212|0),($2752|0),($2753|0))|0;
       $2762 = (($__p$0$i$i$i212) + ($2753)|0);
       HEAP8[$2762>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2744|0),1,($2748|0),($2750|0),($26|0));
       $2763 = __THREW__; __THREW__ = 0;
       $2764 = $2763&1;
       if ($2764) {
        label = 700;
        break L1;
       }
       $2765 = HEAP8[$26>>0]|0;
       $2766 = $2765 & 1;
       $2767 = ($2766<<24>>24)==(0);
       if ($2767) {
        $$pre$phi1467Z2D = $2751;
       } else {
        $2768 = HEAP32[$108>>2]|0;
        __ZdlPv($2768);
        $$pre$phi1467Z2D = $2751;
       }
      }
      $2775 = HEAP32[679312>>2]|0;
      $2776 = HEAP32[$2775>>2]|0;
      $2777 = (($2776) + 20|0);
      $2778 = HEAP32[$2777>>2]|0;
      $2779 = HEAP32[$$pre$phi1467Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2778 & 4095]($2775,$2779);
      $yyval$sroa$0$0 = $2744;
      break;
     }
     case 125:  {
      $2780 = (($yyvsp$2) + -12|0);
      $2781 = HEAP32[$2780>>2]|0;
      $2782 = ($2781|0)==(0|0);
      if ($2782) {
       $$pre$phi1469Z2D = $yyvsp$2;
      } else {
       $2783 = (($yyvsp$2) + -4|0);
       $2784 = Math_fround(HEAPF32[$2783>>2]);
       $2785 = (~~(($2784)));
       $2786 = HEAP32[$yyvsp$2>>2]|0;
       $2787 = (_strlen(($2786|0))|0);
       $2788 = ($2787>>>0)>(4294967279);
       if ($2788) {
        label = 706;
        break L1;
       }
       $2789 = ($2787>>>0)<(11);
       if ($2789) {
        $2790 = $2787 << 1;
        $2791 = $2790&255;
        HEAP8[$27>>0] = $2791;
        $__p$0$i$i$i217 = $110;
       } else {
        $2792 = (($2787) + 16)|0;
        $2793 = $2792 & -16;
        $2794 = (__Znwj($2793)|0);
        HEAP32[$111>>2] = $2794;
        $2795 = $2793 | 1;
        HEAP32[$27>>2] = $2795;
        HEAP32[$112>>2] = $2787;
        $__p$0$i$i$i217 = $2794;
       }
       _memcpy(($__p$0$i$i$i217|0),($2786|0),($2787|0))|0;
       $2796 = (($__p$0$i$i$i217) + ($2787)|0);
       HEAP8[$2796>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2781|0),2,($2785|0),1,($27|0));
       $2797 = __THREW__; __THREW__ = 0;
       $2798 = $2797&1;
       if ($2798) {
        label = 713;
        break L1;
       }
       $2799 = HEAP8[$27>>0]|0;
       $2800 = $2799 & 1;
       $2801 = ($2800<<24>>24)==(0);
       if ($2801) {
        $$pre$phi1469Z2D = $yyvsp$2;
       } else {
        $2802 = HEAP32[$111>>2]|0;
        __ZdlPv($2802);
        $$pre$phi1469Z2D = $yyvsp$2;
       }
      }
      $2809 = HEAP32[679312>>2]|0;
      $2810 = HEAP32[$2809>>2]|0;
      $2811 = (($2810) + 20|0);
      $2812 = HEAP32[$2811>>2]|0;
      $2813 = HEAP32[$$pre$phi1469Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2812 & 4095]($2809,$2813);
      $yyval$sroa$0$0 = $2781;
      break;
     }
     case 127:  {
      $2851 = (($yyvsp$2) + -12|0);
      $2852 = HEAP32[$2851>>2]|0;
      $2853 = ($2852|0)==(0|0);
      if ($2853) {
       $$pre$phi1475Z2D = $yyvsp$2;
      } else {
       $2854 = (($yyvsp$2) + -4|0);
       $2855 = Math_fround(HEAPF32[$2854>>2]);
       $2856 = (~~(($2855)));
       $2857 = HEAP32[$yyvsp$2>>2]|0;
       $2858 = (_strlen(($2857|0))|0);
       $2859 = ($2858>>>0)>(4294967279);
       if ($2859) {
        label = 732;
        break L1;
       }
       $2860 = ($2858>>>0)<(11);
       if ($2860) {
        $2861 = $2858 << 1;
        $2862 = $2861&255;
        HEAP8[$29>>0] = $2862;
        $__p$0$i$i$i227 = $116;
       } else {
        $2863 = (($2858) + 16)|0;
        $2864 = $2863 & -16;
        $2865 = (__Znwj($2864)|0);
        HEAP32[$117>>2] = $2865;
        $2866 = $2864 | 1;
        HEAP32[$29>>2] = $2866;
        HEAP32[$118>>2] = $2858;
        $__p$0$i$i$i227 = $2865;
       }
       _memcpy(($__p$0$i$i$i227|0),($2857|0),($2858|0))|0;
       $2867 = (($__p$0$i$i$i227) + ($2858)|0);
       HEAP8[$2867>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2852|0),3,($2856|0),1,($29|0));
       $2868 = __THREW__; __THREW__ = 0;
       $2869 = $2868&1;
       if ($2869) {
        label = 739;
        break L1;
       }
       $2870 = HEAP8[$29>>0]|0;
       $2871 = $2870 & 1;
       $2872 = ($2871<<24>>24)==(0);
       if ($2872) {
        $$pre$phi1475Z2D = $yyvsp$2;
       } else {
        $2873 = HEAP32[$117>>2]|0;
        __ZdlPv($2873);
        $$pre$phi1475Z2D = $yyvsp$2;
       }
      }
      $2880 = HEAP32[679312>>2]|0;
      $2881 = HEAP32[$2880>>2]|0;
      $2882 = (($2881) + 20|0);
      $2883 = HEAP32[$2882>>2]|0;
      $2884 = HEAP32[$$pre$phi1475Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2883 & 4095]($2880,$2884);
      $yyval$sroa$0$0 = $2852;
      break;
     }
     case 128:  {
      $2885 = (($yyvsp$2) + -16|0);
      $2886 = HEAP32[$2885>>2]|0;
      $2887 = ($2886|0)==(0|0);
      if ($2887) {
       $$pre1476 = (($yyvsp$2) + -4|0);
       $$pre$phi1479Z2D = $$pre1476;
      } else {
       $2888 = (($yyvsp$2) + -8|0);
       $2889 = Math_fround(HEAPF32[$2888>>2]);
       $2890 = (~~(($2889)));
       $2891 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $2892 = (~~(($2891)));
       $2893 = (($yyvsp$2) + -4|0);
       $2894 = HEAP32[$2893>>2]|0;
       $2895 = (_strlen(($2894|0))|0);
       $2896 = ($2895>>>0)>(4294967279);
       if ($2896) {
        label = 745;
        break L1;
       }
       $2897 = ($2895>>>0)<(11);
       if ($2897) {
        $2898 = $2895 << 1;
        $2899 = $2898&255;
        HEAP8[$30>>0] = $2899;
        $__p$0$i$i$i232 = $119;
       } else {
        $2900 = (($2895) + 16)|0;
        $2901 = $2900 & -16;
        $2902 = (__Znwj($2901)|0);
        HEAP32[$120>>2] = $2902;
        $2903 = $2901 | 1;
        HEAP32[$30>>2] = $2903;
        HEAP32[$121>>2] = $2895;
        $__p$0$i$i$i232 = $2902;
       }
       _memcpy(($__p$0$i$i$i232|0),($2894|0),($2895|0))|0;
       $2904 = (($__p$0$i$i$i232) + ($2895)|0);
       HEAP8[$2904>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2886|0),3,($2890|0),($2892|0),($30|0));
       $2905 = __THREW__; __THREW__ = 0;
       $2906 = $2905&1;
       if ($2906) {
        label = 752;
        break L1;
       }
       $2907 = HEAP8[$30>>0]|0;
       $2908 = $2907 & 1;
       $2909 = ($2908<<24>>24)==(0);
       if ($2909) {
        $$pre$phi1479Z2D = $2893;
       } else {
        $2910 = HEAP32[$120>>2]|0;
        __ZdlPv($2910);
        $$pre$phi1479Z2D = $2893;
       }
      }
      $2917 = HEAP32[679312>>2]|0;
      $2918 = HEAP32[$2917>>2]|0;
      $2919 = (($2918) + 20|0);
      $2920 = HEAP32[$2919>>2]|0;
      $2921 = HEAP32[$$pre$phi1479Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2920 & 4095]($2917,$2921);
      $yyval$sroa$0$0 = $2886;
      break;
     }
     case 132:  {
      $3027 = (($yyvsp$2) + -16|0);
      $3028 = HEAP32[$3027>>2]|0;
      $3029 = ($3028|0)==(0|0);
      if ($3029) {
       $$pre1488 = (($yyvsp$2) + -4|0);
       $$pre$phi1491Z2D = $$pre1488;
      } else {
       $3030 = (($yyvsp$2) + -8|0);
       $3031 = Math_fround(HEAPF32[$3030>>2]);
       $3032 = (~~(($3031)));
       $3033 = (($yyvsp$2) + -4|0);
       $3034 = HEAP32[$3033>>2]|0;
       $3035 = (_strlen(($3034|0))|0);
       $3036 = ($3035>>>0)>(4294967279);
       if ($3036) {
        label = 797;
        break L1;
       }
       $3037 = ($3035>>>0)<(11);
       if ($3037) {
        $3038 = $3035 << 1;
        $3039 = $3038&255;
        HEAP8[$34>>0] = $3039;
        $__p$0$i$i$i252 = $131;
       } else {
        $3040 = (($3035) + 16)|0;
        $3041 = $3040 & -16;
        $3042 = (__Znwj($3041)|0);
        HEAP32[$132>>2] = $3042;
        $3043 = $3041 | 1;
        HEAP32[$34>>2] = $3043;
        HEAP32[$133>>2] = $3035;
        $__p$0$i$i$i252 = $3042;
       }
       _memcpy(($__p$0$i$i$i252|0),($3034|0),($3035|0))|0;
       $3044 = (($__p$0$i$i$i252) + ($3035)|0);
       HEAP8[$3044>>0] = 0;
       $3045 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $3046 = (~~(($3045)));
       __THREW__ = 0;
       invoke_viiiii(106,($3028|0),0,($3032|0),($34|0),($3046|0));
       $3047 = __THREW__; __THREW__ = 0;
       $3048 = $3047&1;
       if ($3048) {
        label = 804;
        break L1;
       }
       $3049 = HEAP8[$34>>0]|0;
       $3050 = $3049 & 1;
       $3051 = ($3050<<24>>24)==(0);
       if ($3051) {
        $$pre$phi1491Z2D = $3033;
       } else {
        $3052 = HEAP32[$132>>2]|0;
        __ZdlPv($3052);
        $$pre$phi1491Z2D = $3033;
       }
      }
      $3059 = HEAP32[679312>>2]|0;
      $3060 = HEAP32[$3059>>2]|0;
      $3061 = (($3060) + 20|0);
      $3062 = HEAP32[$3061>>2]|0;
      $3063 = HEAP32[$$pre$phi1491Z2D>>2]|0;
      FUNCTION_TABLE_vii[$3062 & 4095]($3059,$3063);
      $yyval$sroa$0$0 = $3028;
      break;
     }
     case 130:  {
      $2956 = (($yyvsp$2) + -16|0);
      $2957 = HEAP32[$2956>>2]|0;
      $2958 = ($2957|0)==(0|0);
      if ($2958) {
       $$pre1482 = (($yyvsp$2) + -4|0);
       $$pre$phi1485Z2D = $$pre1482;
      } else {
       $2959 = (($yyvsp$2) + -8|0);
       $2960 = Math_fround(HEAPF32[$2959>>2]);
       $2961 = (~~(($2960)));
       $2962 = Math_fround(HEAPF32[$yyvsp$2>>2]);
       $2963 = (~~(($2962)));
       $2964 = (($yyvsp$2) + -4|0);
       $2965 = HEAP32[$2964>>2]|0;
       $2966 = (_strlen(($2965|0))|0);
       $2967 = ($2966>>>0)>(4294967279);
       if ($2967) {
        label = 771;
        break L1;
       }
       $2968 = ($2966>>>0)<(11);
       if ($2968) {
        $2969 = $2966 << 1;
        $2970 = $2969&255;
        HEAP8[$32>>0] = $2970;
        $__p$0$i$i$i242 = $125;
       } else {
        $2971 = (($2966) + 16)|0;
        $2972 = $2971 & -16;
        $2973 = (__Znwj($2972)|0);
        HEAP32[$126>>2] = $2973;
        $2974 = $2972 | 1;
        HEAP32[$32>>2] = $2974;
        HEAP32[$127>>2] = $2966;
        $__p$0$i$i$i242 = $2973;
       }
       _memcpy(($__p$0$i$i$i242|0),($2965|0),($2966|0))|0;
       $2975 = (($__p$0$i$i$i242) + ($2966)|0);
       HEAP8[$2975>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2957|0),4,($2961|0),($2963|0),($32|0));
       $2976 = __THREW__; __THREW__ = 0;
       $2977 = $2976&1;
       if ($2977) {
        label = 778;
        break L1;
       }
       $2978 = HEAP8[$32>>0]|0;
       $2979 = $2978 & 1;
       $2980 = ($2979<<24>>24)==(0);
       if ($2980) {
        $$pre$phi1485Z2D = $2964;
       } else {
        $2981 = HEAP32[$126>>2]|0;
        __ZdlPv($2981);
        $$pre$phi1485Z2D = $2964;
       }
      }
      $2988 = HEAP32[679312>>2]|0;
      $2989 = HEAP32[$2988>>2]|0;
      $2990 = (($2989) + 20|0);
      $2991 = HEAP32[$2990>>2]|0;
      $2992 = HEAP32[$$pre$phi1485Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2991 & 4095]($2988,$2992);
      $yyval$sroa$0$0 = $2957;
      break;
     }
     case 129:  {
      $2922 = (($yyvsp$2) + -12|0);
      $2923 = HEAP32[$2922>>2]|0;
      $2924 = ($2923|0)==(0|0);
      if ($2924) {
       $$pre$phi1481Z2D = $yyvsp$2;
      } else {
       $2925 = (($yyvsp$2) + -4|0);
       $2926 = Math_fround(HEAPF32[$2925>>2]);
       $2927 = (~~(($2926)));
       $2928 = HEAP32[$yyvsp$2>>2]|0;
       $2929 = (_strlen(($2928|0))|0);
       $2930 = ($2929>>>0)>(4294967279);
       if ($2930) {
        label = 758;
        break L1;
       }
       $2931 = ($2929>>>0)<(11);
       if ($2931) {
        $2932 = $2929 << 1;
        $2933 = $2932&255;
        HEAP8[$31>>0] = $2933;
        $__p$0$i$i$i237 = $122;
       } else {
        $2934 = (($2929) + 16)|0;
        $2935 = $2934 & -16;
        $2936 = (__Znwj($2935)|0);
        HEAP32[$123>>2] = $2936;
        $2937 = $2935 | 1;
        HEAP32[$31>>2] = $2937;
        HEAP32[$124>>2] = $2929;
        $__p$0$i$i$i237 = $2936;
       }
       _memcpy(($__p$0$i$i$i237|0),($2928|0),($2929|0))|0;
       $2938 = (($__p$0$i$i$i237) + ($2929)|0);
       HEAP8[$2938>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(105,($2923|0),4,($2927|0),1,($31|0));
       $2939 = __THREW__; __THREW__ = 0;
       $2940 = $2939&1;
       if ($2940) {
        label = 765;
        break L1;
       }
       $2941 = HEAP8[$31>>0]|0;
       $2942 = $2941 & 1;
       $2943 = ($2942<<24>>24)==(0);
       if ($2943) {
        $$pre$phi1481Z2D = $yyvsp$2;
       } else {
        $2944 = HEAP32[$123>>2]|0;
        __ZdlPv($2944);
        $$pre$phi1481Z2D = $yyvsp$2;
       }
      }
      $2951 = HEAP32[679312>>2]|0;
      $2952 = HEAP32[$2951>>2]|0;
      $2953 = (($2952) + 20|0);
      $2954 = HEAP32[$2953>>2]|0;
      $2955 = HEAP32[$$pre$phi1481Z2D>>2]|0;
      FUNCTION_TABLE_vii[$2954 & 4095]($2951,$2955);
      $yyval$sroa$0$0 = $2923;
      break;
     }
     case 131:  {
      $2993 = (($yyvsp$2) + -12|0);
      $2994 = HEAP32[$2993>>2]|0;
      $2995 = ($2994|0)==(0|0);
      if ($2995) {
       $$pre$phi1487Z2D = $yyvsp$2;
      } else {
       $2996 = (($yyvsp$2) + -4|0);
       $2997 = Math_fround(HEAPF32[$2996>>2]);
       $2998 = (~~(($2997)));
       $2999 = HEAP32[$yyvsp$2>>2]|0;
       $3000 = (_strlen(($2999|0))|0);
       $3001 = ($3000>>>0)>(4294967279);
       if ($3001) {
        label = 784;
        break L1;
       }
       $3002 = ($3000>>>0)<(11);
       if ($3002) {
        $3003 = $3000 << 1;
        $3004 = $3003&255;
        HEAP8[$33>>0] = $3004;
        $__p$0$i$i$i247 = $128;
       } else {
        $3005 = (($3000) + 16)|0;
        $3006 = $3005 & -16;
        $3007 = (__Znwj($3006)|0);
        HEAP32[$129>>2] = $3007;
        $3008 = $3006 | 1;
        HEAP32[$33>>2] = $3008;
        HEAP32[$130>>2] = $3000;
        $__p$0$i$i$i247 = $3007;
       }
       _memcpy(($__p$0$i$i$i247|0),($2999|0),($3000|0))|0;
       $3009 = (($__p$0$i$i$i247) + ($3000)|0);
       HEAP8[$3009>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(106,($2994|0),0,($2998|0),($33|0),4);
       $3010 = __THREW__; __THREW__ = 0;
       $3011 = $3010&1;
       if ($3011) {
        label = 791;
        break L1;
       }
       $3012 = HEAP8[$33>>0]|0;
       $3013 = $3012 & 1;
       $3014 = ($3013<<24>>24)==(0);
       if ($3014) {
        $$pre$phi1487Z2D = $yyvsp$2;
       } else {
        $3015 = HEAP32[$129>>2]|0;
        __ZdlPv($3015);
        $$pre$phi1487Z2D = $yyvsp$2;
       }
      }
      $3022 = HEAP32[679312>>2]|0;
      $3023 = HEAP32[$3022>>2]|0;
      $3024 = (($3023) + 20|0);
      $3025 = HEAP32[$3024>>2]|0;
      $3026 = HEAP32[$$pre$phi1487Z2D>>2]|0;
      FUNCTION_TABLE_vii[$3025 & 4095]($3022,$3026);
      $yyval$sroa$0$0 = $2994;
      break;
     }
     case 133:  {
      $3064 = (($yyvsp$2) + -12|0);
      $3065 = HEAP32[$3064>>2]|0;
      $3066 = ($3065|0)==(0|0);
      if ($3066) {
       $$pre$phi1493Z2D = $yyvsp$2;
      } else {
       $3067 = (($yyvsp$2) + -4|0);
       $3068 = Math_fround(HEAPF32[$3067>>2]);
       $3069 = (~~(($3068)));
       $3070 = HEAP32[$yyvsp$2>>2]|0;
       $3071 = (_strlen(($3070|0))|0);
       $3072 = ($3071>>>0)>(4294967279);
       if ($3072) {
        label = 810;
        break L1;
       }
       $3073 = ($3071>>>0)<(11);
       if ($3073) {
        $3074 = $3071 << 1;
        $3075 = $3074&255;
        HEAP8[$35>>0] = $3075;
        $__p$0$i$i$i257 = $134;
       } else {
        $3076 = (($3071) + 16)|0;
        $3077 = $3076 & -16;
        $3078 = (__Znwj($3077)|0);
        HEAP32[$135>>2] = $3078;
        $3079 = $3077 | 1;
        HEAP32[$35>>2] = $3079;
        HEAP32[$136>>2] = $3071;
        $__p$0$i$i$i257 = $3078;
       }
       _memcpy(($__p$0$i$i$i257|0),($3070|0),($3071|0))|0;
       $3080 = (($__p$0$i$i$i257) + ($3071)|0);
       HEAP8[$3080>>0] = 0;
       __THREW__ = 0;
       invoke_viiiii(106,($3065|0),3,($3069|0),($35|0),4);
       $3081 = __THREW__; __THREW__ = 0;
       $3082 = $3081&1;
       if ($3082) {
        label = 817;
        break L1;
       }
       $3083 = HEAP8[$35>>0]|0;
       $3084 = $3083 & 1;
       $3085 = ($3084<<24>>24)==(0);
       if ($3085) {
        $$pre$phi1493Z2D = $yyvsp$2;
       } else {
        $3086 = HEAP32[$135>>2]|0;
        __ZdlPv($3086);
        $$pre$phi1493Z2D = $yyvsp$2;
       }
      }
      $3093 = HEAP32[679312>>2]|0;
      $3094 = HEAP32[$3093>>2]|0;
      $3095 = (($3094) + 20|0);
      $3096 = HEAP32[$3095>>2]|0;
      $3097 = HEAP32[$$pre$phi1493Z2D>>2]|0;
      FUNCTION_TABLE_vii[$3096 & 4095]($3093,$3097);
      $yyval$sroa$0$0 = $3065;
      break;
     }
     default: {
      $yyval$sroa$0$0 = $218;
     }
     }
    } while(0);
    $3790 = (0 - ($215))|0;
    $3791 = (($yyssp$2) + ($3790<<1)|0);
    $3792 = (($yyvsp$2) + ($216<<2)|0);
    HEAP32[$217>>2] = $yyval$sroa$0$0;
    $3793 = (678392 + ($211)|0);
    $3794 = HEAP8[$3793>>0]|0;
    $3795 = $3794&255;
    $3796 = (($3795) + -114)|0;
    $3797 = (678584 + ($3796<<1)|0);
    $3798 = HEAP16[$3797>>1]|0;
    $3799 = $3798 << 16 >> 16;
    $3800 = HEAP16[$3791>>1]|0;
    $3801 = $3800 << 16 >> 16;
    $3802 = (($3801) + ($3799))|0;
    $3803 = ($3802>>>0)<(431);
    if ($3803) {
     $3804 = (675472 + ($3802<<1)|0);
     $3805 = HEAP16[$3804>>1]|0;
     $3806 = ($3805<<16>>16)==($3800<<16>>16);
     if ($3806) {
      $3807 = (676336 + ($3802<<1)|0);
      $3808 = HEAP16[$3807>>1]|0;
      $3809 = $3808&65535;
      $yyssp$0 = $3791;$yystate$0 = $3809;$yyvsp$0 = $3792;
      break;
     }
    }
    $3810 = (678680 + ($3796<<1)|0);
    $3811 = HEAP16[$3810>>1]|0;
    $3812 = $3811 << 16 >> 16;
    $yyssp$0 = $3791;$yystate$0 = $3812;$yyvsp$0 = $3792;
   }
  } while(0);
  $156 = (($yyssp$0) + 2|0);
  $yyss$0 = $yyss$1;$yyssp$1 = $156;$yystacksize$0 = $yystacksize$1;$yystate$1 = $yystate$0;$yyvs$0 = $yyvs$1;$yyvsp$1 = $yyvsp$0;
 }
 switch (label|0) {
  case 33: {
   $245 = ___cxa_find_matching_catch()|0;
   $246 = tempRet0;
   ___cxa_call_unexpected(($245|0));
   // unreachable;
   break;
  }
  case 42: {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 78: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 83: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $406 = __THREW__; __THREW__ = 0;
   $407 = $406&1;
   if ($407) {
    $419 = ___cxa_find_matching_catch()|0;
    $420 = tempRet0;
    $lpad$phi349$index = $419;$lpad$phi349$index2 = $420;
    label = 91;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 89: {
   $417 = ___cxa_find_matching_catch()|0;
   $418 = tempRet0;
   $lpad$phi349$index = $417;$lpad$phi349$index2 = $418;
   label = 91;
   break;
  }
  case 105: {
   $456 = ___cxa_find_matching_catch()|0;
   $457 = tempRet0;
   $458 = HEAP8[$46>>0]|0;
   $459 = $458 & 1;
   $460 = ($459<<24>>24)==(0);
   if (!($460)) {
    $461 = HEAP32[$49>>2]|0;
    __ZdlPv($461);
   }
   $462 = HEAP8[$3>>0]|0;
   $463 = $462 & 1;
   $464 = ($463<<24>>24)==(0);
   if ($464) {
    $$4 = $457;$$415 = $456;
    ___resumeException($$415|0);
    // unreachable;
   }
   $465 = HEAP32[$48>>2]|0;
   __ZdlPv($465);
   $$4 = $457;$$415 = $456;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 118: {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 129: {
   $534 = ___cxa_find_matching_catch()|0;
   $535 = tempRet0;
   __ZdlPv($514);
   $$4 = $535;$$415 = $534;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 140: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $557 = __THREW__; __THREW__ = 0;
   $558 = $557&1;
   if ($558) {
    $579 = ___cxa_find_matching_catch()|0;
    $580 = tempRet0;
    $lpad$phi344$index = $579;$lpad$phi344$index7 = $580;
    label = 149;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 147: {
   $577 = ___cxa_find_matching_catch()|0;
   $578 = tempRet0;
   $lpad$phi344$index = $577;$lpad$phi344$index7 = $578;
   label = 149;
   break;
  }
  case 154: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 180: {
   $663 = ___cxa_find_matching_catch()|0;
   $664 = tempRet0;
   $$0 = $664;$$011 = $663;
   label = 183;
   break;
  }
  case 181: {
   $665 = ___cxa_find_matching_catch()|0;
   $666 = tempRet0;
   $667 = HEAP8[$4>>0]|0;
   $668 = $667 & 1;
   $669 = ($668<<24>>24)==(0);
   if ($669) {
    $$0 = $666;$$011 = $665;
    label = 183;
   } else {
    $670 = HEAP32[$55>>2]|0;
    __ZdlPv($670);
    $$0 = $666;$$011 = $665;
    label = 183;
   }
   break;
  }
  case 186: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 194: {
   $700 = ___cxa_find_matching_catch()|0;
   $701 = tempRet0;
   $702 = HEAP8[$6>>0]|0;
   $703 = $702 & 1;
   $704 = ($703<<24>>24)==(0);
   if ($704) {
    $$4 = $701;$$415 = $700;
    ___resumeException($$415|0);
    // unreachable;
   }
   $705 = HEAP32[$59>>2]|0;
   __ZdlPv($705);
   $$4 = $701;$$415 = $700;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 260: {
   $941 = ___cxa_find_matching_catch()|0;
   $942 = tempRet0;
   __ZdlPv($890);
   $$4 = $942;$$415 = $941;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 276: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 285: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $1025 = __THREW__; __THREW__ = 0;
   $1026 = $1025&1;
   if ($1026) {
    $1055 = ___cxa_find_matching_catch()|0;
    $1056 = tempRet0;
    $1058 = $1020;$lpad$phi339$index = $1055;$lpad$phi339$index12 = $1056;
    label = 300;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 298: {
   $1053 = ___cxa_find_matching_catch()|0;
   $1054 = tempRet0;
   $$pre1437 = HEAP8[$7>>0]|0;
   $1058 = $$pre1437;$lpad$phi339$index = $1053;$lpad$phi339$index12 = $1054;
   label = 300;
   break;
  }
  case 304: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 312: {
   $1090 = ___cxa_find_matching_catch()|0;
   $1091 = tempRet0;
   __ZdlPv($1061);
   $$4 = $1091;$$415 = $1090;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 313: {
   $1092 = ___cxa_find_matching_catch()|0;
   $1093 = tempRet0;
   $1094 = HEAP8[$8>>0]|0;
   $1095 = $1094 & 1;
   $1096 = ($1095<<24>>24)==(0);
   if ($1096) {
    $$4 = $1093;$$415 = $1092;
    ___resumeException($$415|0);
    // unreachable;
   }
   $1097 = HEAP32[$65>>2]|0;
   __ZdlPv($1097);
   $$4 = $1093;$$415 = $1092;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 316: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 324: {
   $1126 = ___cxa_find_matching_catch()|0;
   $1127 = tempRet0;
   $1128 = HEAP8[$9>>0]|0;
   $1129 = $1128 & 1;
   $1130 = ($1129<<24>>24)==(0);
   if ($1130) {
    $$4 = $1127;$$415 = $1126;
    ___resumeException($$415|0);
    // unreachable;
   }
   $1131 = HEAP32[$68>>2]|0;
   __ZdlPv($1131);
   $$4 = $1127;$$415 = $1126;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 328: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 334: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $1155 = __THREW__; __THREW__ = 0;
   $1156 = $1155&1;
   if ($1156) {
    $1193 = ___cxa_find_matching_catch()|0;
    $1194 = tempRet0;
    $lpad$phi334$index = $1193;$lpad$phi334$index17 = $1194;
    label = 349;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 347: {
   $1191 = ___cxa_find_matching_catch()|0;
   $1192 = tempRet0;
   $lpad$phi334$index = $1191;$lpad$phi334$index17 = $1192;
   label = 349;
   break;
  }
  case 350: {
   $1195 = ___cxa_find_matching_catch()|0;
   $1196 = tempRet0;
   $1197 = HEAP8[$11>>0]|0;
   $1198 = $1197 & 1;
   $1199 = ($1198<<24>>24)==(0);
   if ($1199) {
    $$1 = $1196;$$112 = $1195;
    label = 352;
   } else {
    $1200 = HEAP32[$73>>2]|0;
    __ZdlPv($1200);
    $$1 = $1196;$$112 = $1195;
    label = 352;
   }
   break;
  }
  case 355: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 361: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $1225 = __THREW__; __THREW__ = 0;
   $1226 = $1225&1;
   if ($1226) {
    $1263 = ___cxa_find_matching_catch()|0;
    $1264 = tempRet0;
    $lpad$phi329$index = $1263;$lpad$phi329$index22 = $1264;
    label = 376;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 374: {
   $1261 = ___cxa_find_matching_catch()|0;
   $1262 = tempRet0;
   $lpad$phi329$index = $1261;$lpad$phi329$index22 = $1262;
   label = 376;
   break;
  }
  case 377: {
   $1265 = ___cxa_find_matching_catch()|0;
   $1266 = tempRet0;
   $1267 = HEAP8[$14>>0]|0;
   $1268 = $1267 & 1;
   $1269 = ($1268<<24>>24)==(0);
   if ($1269) {
    $$2 = $1266;$$213 = $1265;
    label = 379;
   } else {
    $1270 = HEAP32[$79>>2]|0;
    __ZdlPv($1270);
    $$2 = $1266;$$213 = $1265;
    label = 379;
   }
   break;
  }
  case 384: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 410: {
   $1358 = ___cxa_find_matching_catch()|0;
   $1359 = tempRet0;
   $$3 = $1359;$$314 = $1358;
   label = 413;
   break;
  }
  case 411: {
   $1360 = ___cxa_find_matching_catch()|0;
   $1361 = tempRet0;
   $1362 = HEAP8[$16>>0]|0;
   $1363 = $1362 & 1;
   $1364 = ($1363<<24>>24)==(0);
   if ($1364) {
    $$3 = $1361;$$314 = $1360;
    label = 413;
   } else {
    $1365 = HEAP32[$85>>2]|0;
    __ZdlPv($1365);
    $$3 = $1361;$$314 = $1360;
    label = 413;
   }
   break;
  }
  case 485: {
   $1919 = ___cxa_find_matching_catch()|0;
   $1920 = tempRet0;
   $1921 = HEAP8[$18>>0]|0;
   $1922 = $1921 & 1;
   $1923 = ($1922<<24>>24)==(0);
   if ($1923) {
    $$4 = $1920;$$415 = $1919;
    ___resumeException($$415|0);
    // unreachable;
   }
   $1924 = HEAP32[$88>>2]|0;
   __ZdlPv($1924);
   $$4 = $1920;$$415 = $1919;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 487: {
   $1925 = ___cxa_find_matching_catch()|0;
   $1926 = tempRet0;
   __ZdlPv($1915);
   $$4 = $1926;$$415 = $1925;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 495: {
   $1944 = ___cxa_find_matching_catch()|0;
   $1945 = tempRet0;
   $1946 = HEAP8[$19>>0]|0;
   $1947 = $1946 & 1;
   $1948 = ($1947<<24>>24)==(0);
   if ($1948) {
    $$4 = $1945;$$415 = $1944;
    ___resumeException($$415|0);
    // unreachable;
   }
   $1949 = HEAP32[$89>>2]|0;
   __ZdlPv($1949);
   $$4 = $1945;$$415 = $1944;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 497: {
   $1950 = ___cxa_find_matching_catch()|0;
   $1951 = tempRet0;
   __ZdlPv($1940);
   $$4 = $1951;$$415 = $1950;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 583: {
   $2461 = ___cxa_find_matching_catch()|0;
   $2462 = tempRet0;
   $2463 = HEAP8[$20>>0]|0;
   $2464 = $2463 & 1;
   $2465 = ($2464<<24>>24)==(0);
   if ($2465) {
    $$4 = $2462;$$415 = $2461;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2466 = HEAP32[$91>>2]|0;
   __ZdlPv($2466);
   $$4 = $2462;$$415 = $2461;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 594: {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 608: {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 620: {
   $2558 = ___cxa_find_matching_catch()|0;
   $2559 = tempRet0;
   __ZdlPv($2555);
   $$4 = $2559;$$415 = $2558;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 627: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 635: {
   $2593 = ___cxa_find_matching_catch()|0;
   $2594 = tempRet0;
   $2595 = HEAP8[$21>>0]|0;
   $2596 = $2595 & 1;
   $2597 = ($2596<<24>>24)==(0);
   if ($2597) {
    $$4 = $2594;$$415 = $2593;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2598 = HEAP32[$93>>2]|0;
   __ZdlPv($2598);
   $$4 = $2594;$$415 = $2593;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 641: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 648: {
   $2627 = ___cxa_find_matching_catch()|0;
   $2628 = tempRet0;
   $2629 = HEAP8[$22>>0]|0;
   $2630 = $2629 & 1;
   $2631 = ($2630<<24>>24)==(0);
   if ($2631) {
    $$4 = $2628;$$415 = $2627;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2632 = HEAP32[$96>>2]|0;
   __ZdlPv($2632);
   $$4 = $2628;$$415 = $2627;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 654: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 661: {
   $2661 = ___cxa_find_matching_catch()|0;
   $2662 = tempRet0;
   $2663 = HEAP8[$23>>0]|0;
   $2664 = $2663 & 1;
   $2665 = ($2664<<24>>24)==(0);
   if ($2665) {
    $$4 = $2662;$$415 = $2661;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2666 = HEAP32[$99>>2]|0;
   __ZdlPv($2666);
   $$4 = $2662;$$415 = $2661;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 667: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 674: {
   $2698 = ___cxa_find_matching_catch()|0;
   $2699 = tempRet0;
   $2700 = HEAP8[$24>>0]|0;
   $2701 = $2700 & 1;
   $2702 = ($2701<<24>>24)==(0);
   if ($2702) {
    $$4 = $2699;$$415 = $2698;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2703 = HEAP32[$102>>2]|0;
   __ZdlPv($2703);
   $$4 = $2699;$$415 = $2698;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 680: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 687: {
   $2732 = ___cxa_find_matching_catch()|0;
   $2733 = tempRet0;
   $2734 = HEAP8[$25>>0]|0;
   $2735 = $2734 & 1;
   $2736 = ($2735<<24>>24)==(0);
   if ($2736) {
    $$4 = $2733;$$415 = $2732;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2737 = HEAP32[$105>>2]|0;
   __ZdlPv($2737);
   $$4 = $2733;$$415 = $2732;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 693: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 700: {
   $2769 = ___cxa_find_matching_catch()|0;
   $2770 = tempRet0;
   $2771 = HEAP8[$26>>0]|0;
   $2772 = $2771 & 1;
   $2773 = ($2772<<24>>24)==(0);
   if ($2773) {
    $$4 = $2770;$$415 = $2769;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2774 = HEAP32[$108>>2]|0;
   __ZdlPv($2774);
   $$4 = $2770;$$415 = $2769;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 706: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 713: {
   $2803 = ___cxa_find_matching_catch()|0;
   $2804 = tempRet0;
   $2805 = HEAP8[$27>>0]|0;
   $2806 = $2805 & 1;
   $2807 = ($2806<<24>>24)==(0);
   if ($2807) {
    $$4 = $2804;$$415 = $2803;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2808 = HEAP32[$111>>2]|0;
   __ZdlPv($2808);
   $$4 = $2804;$$415 = $2803;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 719: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 726: {
   $2840 = ___cxa_find_matching_catch()|0;
   $2841 = tempRet0;
   $2842 = HEAP8[$28>>0]|0;
   $2843 = $2842 & 1;
   $2844 = ($2843<<24>>24)==(0);
   if ($2844) {
    $$4 = $2841;$$415 = $2840;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2845 = HEAP32[$114>>2]|0;
   __ZdlPv($2845);
   $$4 = $2841;$$415 = $2840;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 732: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 739: {
   $2874 = ___cxa_find_matching_catch()|0;
   $2875 = tempRet0;
   $2876 = HEAP8[$29>>0]|0;
   $2877 = $2876 & 1;
   $2878 = ($2877<<24>>24)==(0);
   if ($2878) {
    $$4 = $2875;$$415 = $2874;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2879 = HEAP32[$117>>2]|0;
   __ZdlPv($2879);
   $$4 = $2875;$$415 = $2874;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 745: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 752: {
   $2911 = ___cxa_find_matching_catch()|0;
   $2912 = tempRet0;
   $2913 = HEAP8[$30>>0]|0;
   $2914 = $2913 & 1;
   $2915 = ($2914<<24>>24)==(0);
   if ($2915) {
    $$4 = $2912;$$415 = $2911;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2916 = HEAP32[$120>>2]|0;
   __ZdlPv($2916);
   $$4 = $2912;$$415 = $2911;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 758: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 765: {
   $2945 = ___cxa_find_matching_catch()|0;
   $2946 = tempRet0;
   $2947 = HEAP8[$31>>0]|0;
   $2948 = $2947 & 1;
   $2949 = ($2948<<24>>24)==(0);
   if ($2949) {
    $$4 = $2946;$$415 = $2945;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2950 = HEAP32[$123>>2]|0;
   __ZdlPv($2950);
   $$4 = $2946;$$415 = $2945;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 771: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 778: {
   $2982 = ___cxa_find_matching_catch()|0;
   $2983 = tempRet0;
   $2984 = HEAP8[$32>>0]|0;
   $2985 = $2984 & 1;
   $2986 = ($2985<<24>>24)==(0);
   if ($2986) {
    $$4 = $2983;$$415 = $2982;
    ___resumeException($$415|0);
    // unreachable;
   }
   $2987 = HEAP32[$126>>2]|0;
   __ZdlPv($2987);
   $$4 = $2983;$$415 = $2982;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 784: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 791: {
   $3016 = ___cxa_find_matching_catch()|0;
   $3017 = tempRet0;
   $3018 = HEAP8[$33>>0]|0;
   $3019 = $3018 & 1;
   $3020 = ($3019<<24>>24)==(0);
   if ($3020) {
    $$4 = $3017;$$415 = $3016;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3021 = HEAP32[$129>>2]|0;
   __ZdlPv($3021);
   $$4 = $3017;$$415 = $3016;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 797: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 804: {
   $3053 = ___cxa_find_matching_catch()|0;
   $3054 = tempRet0;
   $3055 = HEAP8[$34>>0]|0;
   $3056 = $3055 & 1;
   $3057 = ($3056<<24>>24)==(0);
   if ($3057) {
    $$4 = $3054;$$415 = $3053;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3058 = HEAP32[$132>>2]|0;
   __ZdlPv($3058);
   $$4 = $3054;$$415 = $3053;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 810: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 817: {
   $3087 = ___cxa_find_matching_catch()|0;
   $3088 = tempRet0;
   $3089 = HEAP8[$35>>0]|0;
   $3090 = $3089 & 1;
   $3091 = ($3090<<24>>24)==(0);
   if ($3091) {
    $$4 = $3088;$$415 = $3087;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3092 = HEAP32[$135>>2]|0;
   __ZdlPv($3092);
   $$4 = $3088;$$415 = $3087;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 823: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 830: {
   $3124 = ___cxa_find_matching_catch()|0;
   $3125 = tempRet0;
   $3126 = HEAP8[$36>>0]|0;
   $3127 = $3126 & 1;
   $3128 = ($3127<<24>>24)==(0);
   if ($3128) {
    $$4 = $3125;$$415 = $3124;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3129 = HEAP32[$138>>2]|0;
   __ZdlPv($3129);
   $$4 = $3125;$$415 = $3124;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 867: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 876: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $3268 = __THREW__; __THREW__ = 0;
   $3269 = $3268&1;
   if ($3269) {
    $3298 = ___cxa_find_matching_catch()|0;
    $3299 = tempRet0;
    $3301 = $3263;$lpad$phi$index = $3298;$lpad$phi$index27 = $3299;
    label = 891;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 889: {
   $3296 = ___cxa_find_matching_catch()|0;
   $3297 = tempRet0;
   $$pre1438 = HEAP8[$37>>0]|0;
   $3301 = $$pre1438;$lpad$phi$index = $3296;$lpad$phi$index27 = $3297;
   label = 891;
   break;
  }
  case 895: {
   $3307 = ___cxa_find_matching_catch()|0;
   $3308 = tempRet0;
   __ZdlPv($3304);
   $$4 = $3308;$$415 = $3307;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 900: {
   $3325 = ___cxa_find_matching_catch()|0;
   $3326 = tempRet0;
   $3327 = HEAP8[$38>>0]|0;
   $3328 = $3327 & 1;
   $3329 = ($3328<<24>>24)==(0);
   if ($3329) {
    $$4 = $3326;$$415 = $3325;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3330 = HEAP32[$143>>2]|0;
   __ZdlPv($3330);
   $$4 = $3326;$$415 = $3325;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 906: {
   $3347 = ___cxa_find_matching_catch()|0;
   $3348 = tempRet0;
   $3349 = HEAP8[$39>>0]|0;
   $3350 = $3349 & 1;
   $3351 = ($3350<<24>>24)==(0);
   if ($3351) {
    $$4 = $3348;$$415 = $3347;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3352 = HEAP32[$145>>2]|0;
   __ZdlPv($3352);
   $$4 = $3348;$$415 = $3347;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 916: {
   $3427 = ___cxa_find_matching_catch()|0;
   $3428 = tempRet0;
   $3429 = HEAP8[$40>>0]|0;
   $3430 = $3429 & 1;
   $3431 = ($3430<<24>>24)==(0);
   if ($3431) {
    $$4 = $3428;$$415 = $3427;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3432 = HEAP32[$146>>2]|0;
   __ZdlPv($3432);
   $$4 = $3428;$$415 = $3427;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 921: {
   $3458 = ___cxa_find_matching_catch()|0;
   $3459 = tempRet0;
   $3460 = HEAP8[$41>>0]|0;
   $3461 = $3460 & 1;
   $3462 = ($3461<<24>>24)==(0);
   if ($3462) {
    $$4 = $3459;$$415 = $3458;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3463 = HEAP32[$148>>2]|0;
   __ZdlPv($3463);
   $$4 = $3459;$$415 = $3458;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 932: {
   $3479 = ___cxa_find_matching_catch()|0;
   $3480 = tempRet0;
   $3481 = HEAP8[$42>>0]|0;
   $3482 = $3481 & 1;
   $3483 = ($3482<<24>>24)==(0);
   if ($3483) {
    $$4 = $3480;$$415 = $3479;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3484 = HEAP32[$150>>2]|0;
   __ZdlPv($3484);
   $$4 = $3480;$$415 = $3479;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 938: {
   $3495 = ___cxa_find_matching_catch()|0;
   $3496 = tempRet0;
   $3497 = HEAP8[$43>>0]|0;
   $3498 = $3497 & 1;
   $3499 = ($3498<<24>>24)==(0);
   if ($3499) {
    $$4 = $3496;$$415 = $3495;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3500 = HEAP32[$152>>2]|0;
   __ZdlPv($3500);
   $$4 = $3496;$$415 = $3495;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 943: {
   $3511 = ___cxa_find_matching_catch()|0;
   $3512 = tempRet0;
   $3513 = HEAP8[$44>>0]|0;
   $3514 = $3513 & 1;
   $3515 = ($3514<<24>>24)==(0);
   if ($3515) {
    $$4 = $3512;$$415 = $3511;
    ___resumeException($$415|0);
    // unreachable;
   }
   $3516 = HEAP32[$154>>2]|0;
   __ZdlPv($3516);
   $$4 = $3512;$$415 = $3511;
   ___resumeException($$415|0);
   // unreachable;
   break;
  }
  case 987: {
   $3813 = HEAP32[674288>>2]|0;
   $3814 = (($3813) + 1)|0;
   HEAP32[674288>>2] = $3814;
   $3815 = HEAP32[674256>>2]|0;
   HEAP32[$$byval_copy43>>2] = 678776;
   __Z6FormatPKcz($1,678816,$$byval_copy43);
   $3816 = HEAP32[654192>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(104,($3815|0),($1|0),($3816|0),0,0);
   $3817 = __THREW__; __THREW__ = 0;
   $3818 = $3817&1;
   if (!($3818)) {
    $3819 = HEAP8[$1>>0]|0;
    $3820 = $3819 & 1;
    $3821 = ($3820<<24>>24)==(0);
    if ($3821) {
     $yyresult$0 = 1;$yyss$3 = $yyss$1;
     label = 999;
     break;
    }
    $3822 = (($1) + 8|0);
    $3823 = HEAP32[$3822>>2]|0;
    __ZdlPv($3823);
    $yyresult$0 = 1;$yyss$3 = $yyss$1;
    label = 999;
    break;
   }
   $3824 = ___cxa_find_matching_catch()|0;
   $3825 = tempRet0;
   $3826 = HEAP8[$1>>0]|0;
   $3827 = $3826 & 1;
   $3828 = ($3827<<24>>24)==(0);
   if ($3828) {
    ___resumeException($3824|0);
    // unreachable;
   }
   $3829 = (($1) + 8|0);
   $3830 = HEAP32[$3829>>2]|0;
   __ZdlPv($3830);
   ___resumeException($3824|0);
   // unreachable;
   break;
  }
  case 993: {
   $3831 = HEAP32[674256>>2]|0;
   HEAP32[$$byval_copy43>>2] = 678792;
   __Z6FormatPKcz($0,678816,$$byval_copy43);
   $3832 = HEAP32[654192>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(104,($3831|0),($0|0),($3832|0),0,0);
   $3833 = __THREW__; __THREW__ = 0;
   $3834 = $3833&1;
   if (!($3834)) {
    $3835 = HEAP8[$0>>0]|0;
    $3836 = $3835 & 1;
    $3837 = ($3836<<24>>24)==(0);
    if ($3837) {
     $yyresult$0 = 2;$yyss$3 = $yyss$0;
     label = 999;
     break;
    }
    $3838 = (($0) + 8|0);
    $3839 = HEAP32[$3838>>2]|0;
    __ZdlPv($3839);
    $yyresult$0 = 2;$yyss$3 = $yyss$0;
    label = 999;
    break;
   }
   $3840 = ___cxa_find_matching_catch()|0;
   $3841 = tempRet0;
   $3842 = HEAP8[$0>>0]|0;
   $3843 = $3842 & 1;
   $3844 = ($3843<<24>>24)==(0);
   if ($3844) {
    ___resumeException($3840|0);
    // unreachable;
   }
   $3845 = (($0) + 8|0);
   $3846 = HEAP32[$3845>>2]|0;
   __ZdlPv($3846);
   ___resumeException($3840|0);
   // unreachable;
   break;
  }
 }
 if ((label|0) == 91) {
  $421 = $422 & 1;
  $423 = ($421<<24>>24)==(0);
  if ($423) {
   ___resumeException($lpad$phi349$index|0);
   // unreachable;
  }
  $424 = HEAP32[$48>>2]|0;
  __ZdlPv($424);
  ___resumeException($lpad$phi349$index|0);
  // unreachable;
 }
 else if ((label|0) == 149) {
  __ZdlPv($551);
  $$4 = $lpad$phi344$index7;$$415 = $lpad$phi344$index;
  ___resumeException($$415|0);
  // unreachable;
 }
 else if ((label|0) == 183) {
  $671 = HEAP8[$5>>0]|0;
  $672 = $671 & 1;
  $673 = ($672<<24>>24)==(0);
  if ($673) {
   $$4 = $$0;$$415 = $$011;
   ___resumeException($$415|0);
   // unreachable;
  }
  $674 = HEAP32[$54>>2]|0;
  __ZdlPv($674);
  $$4 = $$0;$$415 = $$011;
  ___resumeException($$415|0);
  // unreachable;
 }
 else if ((label|0) == 300) {
  $1057 = $1058 & 1;
  $1059 = ($1057<<24>>24)==(0);
  if ($1059) {
   $$4 = $lpad$phi339$index12;$$415 = $lpad$phi339$index;
   ___resumeException($$415|0);
   // unreachable;
  }
  $1060 = HEAP32[$62>>2]|0;
  __ZdlPv($1060);
  $$4 = $lpad$phi339$index12;$$415 = $lpad$phi339$index;
  ___resumeException($$415|0);
  // unreachable;
 }
 else if ((label|0) == 349) {
  $$1 = $lpad$phi334$index17;$$112 = $lpad$phi334$index;
  label = 352;
 }
 else if ((label|0) == 376) {
  $$2 = $lpad$phi329$index22;$$213 = $lpad$phi329$index;
  label = 379;
 }
 else if ((label|0) == 413) {
  $1366 = HEAP8[$17>>0]|0;
  $1367 = $1366 & 1;
  $1368 = ($1367<<24>>24)==(0);
  if ($1368) {
   $$4 = $$3;$$415 = $$314;
   ___resumeException($$415|0);
   // unreachable;
  }
  $1369 = HEAP32[$84>>2]|0;
  __ZdlPv($1369);
  $$4 = $$3;$$415 = $$314;
  ___resumeException($$415|0);
  // unreachable;
 }
 else if ((label|0) == 891) {
  $3300 = $3301 & 1;
  $3302 = ($3300<<24>>24)==(0);
  if ($3302) {
   $$4 = $lpad$phi$index27;$$415 = $lpad$phi$index;
   ___resumeException($$415|0);
   // unreachable;
  }
  $3303 = HEAP32[$141>>2]|0;
  __ZdlPv($3303);
  $$4 = $lpad$phi$index27;$$415 = $lpad$phi$index;
  ___resumeException($$415|0);
  // unreachable;
 }
 else if ((label|0) == 999) {
  $3847 = ($yyss$3|0)==($yyssa|0);
  if ($3847) {
   STACKTOP = sp;return ($yyresult$0|0);
  }
  _free($yyss$3);
  STACKTOP = sp;return ($yyresult$0|0);
 }
 if ((label|0) == 352) {
  $1201 = HEAP8[$10>>0]|0;
  $1202 = $1201 & 1;
  $1203 = ($1202<<24>>24)==(0);
  if ($1203) {
   $$4 = $$1;$$415 = $$112;
   ___resumeException($$415|0);
   // unreachable;
  }
  $1204 = HEAP32[$72>>2]|0;
  __ZdlPv($1204);
  $$4 = $$1;$$415 = $$112;
  ___resumeException($$415|0);
  // unreachable;
 }
 else if ((label|0) == 379) {
  $1271 = HEAP8[$13>>0]|0;
  $1272 = $1271 & 1;
  $1273 = ($1272<<24>>24)==(0);
  if ($1273) {
   $$4 = $$2;$$415 = $$213;
   ___resumeException($$415|0);
   // unreachable;
  }
  $1274 = HEAP32[$78>>2]|0;
  __ZdlPv($1274);
  $$4 = $$2;$$415 = $$213;
  ___resumeException($$415|0);
  // unreachable;
 }
 return 0|0;
}
function __ZL15PushShaderStatev() {
 var $$neg2$i$i$i = 0, $$pre$i$i = 0, $$pre1$i$i = 0, $$pre2$i$i = 0, $$pre3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(656)|0);
 $1 = HEAP32[((674208 + 20|0))>>2]|0;
 $2 = HEAP32[((674208 + 16|0))>>2]|0;
 $3 = (($1) + -1)|0;
 $4 = (($3) + ($2))|0;
 $5 = HEAP32[((674208 + 4|0))>>2]|0;
 $6 = $4 >>> 10;
 $7 = (($5) + ($6<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $4 & 1023;
 $10 = (($8) + ($9<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_vii(3260,($0|0),($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  __ZdlPv($0);
  ___resumeException($39|0);
  // unreachable;
 }
 $14 = HEAP32[((674208 + 8|0))>>2]|0;
 $15 = HEAP32[((674208 + 4|0))>>2]|0;
 $16 = ($14|0)==($15|0);
 if ($16) {
  $24 = 0;
 } else {
  $17 = $14;
  $18 = $15;
  $19 = (($17) - ($18))|0;
  $20 = $19 << 8;
  $21 = (($20) + -1)|0;
  $24 = $21;
 }
 $22 = HEAP32[((674208 + 16|0))>>2]|0;
 $23 = HEAP32[((674208 + 20|0))>>2]|0;
 $$neg2$i$i$i = (($24) - ($22))|0;
 $25 = ($$neg2$i$i$i|0)==($23|0);
 if ($25) {
  __ZNSt3__15dequeIPN9ShaderLab17ParserShaderStateENS_9allocatorIS3_EEE19__add_back_capacityEv(674208);
  $$pre$i$i = HEAP32[((674208 + 20|0))>>2]|0;
  $$pre1$i$i = HEAP32[((674208 + 16|0))>>2]|0;
  $$pre2$i$i = HEAP32[((674208 + 4|0))>>2]|0;
  $$pre3$i$i = HEAP32[((674208 + 8|0))>>2]|0;
  $27 = $$pre$i$i;$28 = $$pre1$i$i;$30 = $$pre3$i$i;$31 = $$pre2$i$i;
 } else {
  $27 = $23;$28 = $22;$30 = $14;$31 = $15;
 }
 $26 = (($27) + ($28))|0;
 $29 = ($30|0)==($31|0);
 if ($29) {
  $38 = (($27) + 1)|0;
  HEAP32[((674208 + 20|0))>>2] = $38;
  STACKTOP = sp;return;
 }
 $32 = $26 >>> 10;
 $33 = (($31) + ($32<<2)|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $26 & 1023;
 $36 = (($34) + ($35<<2)|0);
 $37 = ($36|0)==(0|0);
 if ($37) {
  $38 = (($27) + 1)|0;
  HEAP32[((674208 + 20|0))>>2] = $38;
  STACKTOP = sp;return;
 }
 HEAP32[$36>>2] = $0;
 $38 = (($27) + 1)|0;
 HEAP32[((674208 + 20|0))>>2] = $38;
 STACKTOP = sp;return;
}
function __ZL14PopShaderStatev() {
 var $$byval_copy = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[((674208 + 20|0))>>2]|0;
 $2 = HEAP32[((674208 + 16|0))>>2]|0;
 $3 = (($1) + -1)|0;
 $4 = (($3) + ($2))|0;
 $5 = HEAP32[((674208 + 4|0))>>2]|0;
 $6 = $4 >>> 10;
 $7 = (($5) + ($6<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $4 & 1023;
 $10 = (($8) + ($9<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 HEAP32[((674208 + 20|0))>>2] = $3;
 $12 = HEAP32[((674208 + 8|0))>>2]|0;
 $13 = ($12|0)==($5|0);
 if ($13) {
  $19 = 0;
 } else {
  $14 = $12;
  $15 = $5;
  $16 = (($14) - ($15))|0;
  $17 = $16 << 8;
  $18 = (($17) + -1)|0;
  $19 = $18;
 }
 $$neg1$i = (1 - ($1))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($19))|0;
 $20 = (($$neg2$i$i$i) - ($2))|0;
 $21 = ($20>>>0)>(2047);
 if ($21) {
  $22 = (($12) + -4|0);
  $23 = HEAP32[$22>>2]|0;
  __ZdlPv($23);
  $24 = HEAP32[((674208 + 8|0))>>2]|0;
  $25 = (($24) + -4|0);
  $__new_last2$i$i$i$i$i = $25;
  $26 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($25) + ($26)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $27 = $uglygep3$i$i$i$i$i >>> 2;
  $28 = $27 ^ -1;
  $scevgep4$i$i$i$i$i = (($24) + ($28<<2)|0);
  HEAP32[((674208 + 8|0))>>2] = $scevgep4$i$i$i$i$i;
 }
 $29 = ($11|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($11) + 640|0);
 $31 = (($11) + 644|0);
 $32 = HEAP32[$31>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($30,$32);
 $33 = HEAP8[$11>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if (!($35)) {
  $36 = (($11) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($37|0),($$byval_copy|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if ($39) {
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   ___cxa_call_unexpected(($40|0));
   // unreachable;
  }
 }
 __ZdlPv($11);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab14ParserGrabPass7AddTagsERKNSt3__13mapIiiNS1_4lessIiEENS1_9allocatorINS1_4pairIKiiEEEEEE($this,$tags) {
 $this = $this|0;
 $tags = $tags|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__parent$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $__parent$i$i$i = sp + 12|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$tags>>2]|0;
 $4 = (($tags) + 4|0);
 $5 = (($this) + 36|0);
 $6 = ($3|0)==($4|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 36|0);
 $8 = (($this) + 40|0);
 $10 = $3;
 while(1) {
  $9 = (($10) + 16|0);
  $11 = $9;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = $1;
  $18 = $17;
  HEAP32[$18>>2] = $13;
  $19 = (($17) + 4)|0;
  $20 = $19;
  HEAP32[$20>>2] = $16;
  HEAP32[$0>>2] = $5;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($2,$$byval_copy,$__parent$i$i$i,$1)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   $24 = (__Znwj(24)|0);
   $25 = (($24) + 16|0);
   $26 = $1;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + 4)|0;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = $25;
   $33 = $32;
   HEAP32[$33>>2] = $28;
   $34 = (($32) + 4)|0;
   $35 = $34;
   HEAP32[$35>>2] = $31;
   $36 = HEAP32[$__parent$i$i$i>>2]|0;
   HEAP32[$24>>2] = 0;
   $37 = (($24) + 4|0);
   HEAP32[$37>>2] = 0;
   $38 = (($24) + 8|0);
   HEAP32[$38>>2] = $36;
   HEAP32[$21>>2] = $24;
   $39 = HEAP32[$2>>2]|0;
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    $43 = $24;
   } else {
    HEAP32[$2>>2] = $40;
    $$pre$i$i$i$i = HEAP32[$21>>2]|0;
    $43 = $$pre$i$i$i$i;
   }
   $42 = HEAP32[$7>>2]|0;
   __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($42,$43);
   $44 = HEAP32[$8>>2]|0;
   $45 = (($44) + 1)|0;
   HEAP32[$8>>2] = $45;
  }
  $46 = (($10) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  if ($48) {
   $$01$i$i$i$i = $10;
   while(1) {
    $51 = (($$01$i$i$i$i) + 8|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==($$01$i$i$i$i|0);
    if ($54) {
     $$0$i$i$i$i = $52;
     break;
    } else {
     $$01$i$i$i$i = $52;
    }
   }
  } else {
   $$0$i$i$i$i$i = $47;
   while(1) {
    $49 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $50 = ($49|0)==(0|0);
    if ($50) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $49;
    }
   }
  }
  $55 = ($$0$i$i$i$i|0)==($4|0);
  if ($55) {
   break;
  } else {
   $10 = $$0$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIiiNS_4lessIiEENS_9allocatorINS_4pairIKiiEEEEEixERS5_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$22 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $31 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($31|0);
 }
 $16 = (__Znwj(24)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$16>>2] = 0;
 $20 = (($16) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $16;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $16;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $__r$0 = $16;
 $31 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($31|0);
}
function __ZN9ShaderLab17ParserShaderState7AddTagsERKNSt3__13mapIiiNS1_4lessIiEENS1_9allocatorINS1_4pairIKiiEEEEEE($this,$tags) {
 $this = $this|0;
 $tags = $tags|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__parent$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $__parent$i$i$i = sp + 12|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 640|0);
 $3 = HEAP32[$tags>>2]|0;
 $4 = (($tags) + 4|0);
 $5 = (($this) + 644|0);
 $6 = ($3|0)==($4|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 644|0);
 $8 = (($this) + 648|0);
 $10 = $3;
 while(1) {
  $9 = (($10) + 16|0);
  $11 = $9;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = $1;
  $18 = $17;
  HEAP32[$18>>2] = $13;
  $19 = (($17) + 4)|0;
  $20 = $19;
  HEAP32[$20>>2] = $16;
  HEAP32[$0>>2] = $5;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($2,$$byval_copy,$__parent$i$i$i,$1)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   $24 = (__Znwj(24)|0);
   $25 = (($24) + 16|0);
   $26 = $1;
   $27 = $26;
   $28 = HEAP32[$27>>2]|0;
   $29 = (($26) + 4)|0;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = $25;
   $33 = $32;
   HEAP32[$33>>2] = $28;
   $34 = (($32) + 4)|0;
   $35 = $34;
   HEAP32[$35>>2] = $31;
   $36 = HEAP32[$__parent$i$i$i>>2]|0;
   HEAP32[$24>>2] = 0;
   $37 = (($24) + 4|0);
   HEAP32[$37>>2] = 0;
   $38 = (($24) + 8|0);
   HEAP32[$38>>2] = $36;
   HEAP32[$21>>2] = $24;
   $39 = HEAP32[$2>>2]|0;
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    $43 = $24;
   } else {
    HEAP32[$2>>2] = $40;
    $$pre$i$i$i$i = HEAP32[$21>>2]|0;
    $43 = $$pre$i$i$i$i;
   }
   $42 = HEAP32[$7>>2]|0;
   __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($42,$43);
   $44 = HEAP32[$8>>2]|0;
   $45 = (($44) + 1)|0;
   HEAP32[$8>>2] = $45;
  }
  $46 = (($10) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  if ($48) {
   $$01$i$i$i$i = $10;
   while(1) {
    $51 = (($$01$i$i$i$i) + 8|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==($$01$i$i$i$i|0);
    if ($54) {
     $$0$i$i$i$i = $52;
     break;
    } else {
     $$01$i$i$i$i = $52;
    }
   }
  } else {
   $$0$i$i$i$i$i = $47;
   while(1) {
    $49 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $50 = ($49|0)==(0|0);
    if ($50) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $49;
    }
   }
  }
  $55 = ($$0$i$i$i$i|0)==($4|0);
  if ($55) {
   break;
  } else {
   $10 = $$0$i$i$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __Z7yyerrorPKc($s) {
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[674256>>2]|0;
 HEAP32[$vararg_buffer>>2] = $s;
 __Z6FormatPKcz($0,678816,$vararg_buffer);
 $2 = HEAP32[654192>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(104,($1|0),($0|0),($2|0),0,0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $12 = HEAP8[$0>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   ___resumeException($10|0);
   // unreachable;
  }
  $15 = (($0) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  __ZdlPv($16);
  ___resumeException($10|0);
  // unreachable;
 } else {
  $5 = HEAP8[$0>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   STACKTOP = sp;return 0;
  }
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
  STACKTOP = sp;return 0;
 }
 return 0|0;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSetTextureENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 52)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(82595524);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 52)&-1;
 $14 = ($13>>>0)<(41297762);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 82595524;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*52)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*52)|0)|0);
 $23 = (($22) + (($$0$i3*52)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  dest=$21+0|0; src=$__x+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $25 = (($22) + (($7*52)|0)|0);
 $26 = (($5|0) / -52)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*52)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSetTextureENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 52)&-1;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 52)&-1;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = (($15|0) / 52)&-1;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $26 = $__last;
   $27 = (($26) - ($1))|0;
   $28 = (($27|0) / 52)&-1;
   _memmove(($6|0),($__first|0),($27|0))|0;
   $29 = (($6) + (($28*52)|0)|0);
   $30 = HEAP32[$12>>2]|0;
   $31 = ($30|0)==($29|0);
   if ($31) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $29;
   $scevgep$i$i = (($30) + -52|0);
   $32 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($32)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $33 = (($uglygep3$i$i>>>0) / 52)&-1;
   $34 = $33 ^ -1;
   $scevgep4$i$i = (($30) + (($34*52)|0)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + (($16*52)|0)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$12>>2]|0;
  $$01$i3 = $18;$21 = $$pre$i1;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $23 = 0;
   } else {
    dest=$21+0|0; src=$$01$i3+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre2$i4 = HEAP32[$12>>2]|0;
    $23 = $$pre2$i4;
   }
   $22 = (($23) + 52|0);
   HEAP32[$12>>2] = $22;
   $24 = (($$01$i3) + 52|0);
   $25 = ($24|0)==($__last|0);
   if ($25) {
    break;
   } else {
    $$01$i3 = $24;$21 = $22;
   }
  }
  STACKTOP = sp;return;
 }
 $35 = ($6|0)==(0|0);
 if ($35) {
  $44 = $5;
 } else {
  $36 = (($this) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==($6|0);
  if (!($38)) {
   $scevgep$i$i$i$i = (($37) + -52|0);
   $39 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($39)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $40 = (($uglygep3$i$i$i$i>>>0) / 52)&-1;
   $41 = $40 ^ -1;
   $scevgep4$i$i$i$i = (($37) + (($41*52)|0)|0);
   HEAP32[$36>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$36>>2] = 0;
  HEAP32[$this>>2] = 0;
  $44 = 0;
 }
 $42 = ($3>>>0)>(82595524);
 if ($42) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $43 = $44;
 $45 = (($43|0) / 52)&-1;
 $46 = ($45>>>0)<(41297762);
 if ($46) {
  $47 = $45 << 1;
  $48 = ($47>>>0)<($3>>>0);
  $49 = $48 ? $3 : $47;
  $50 = ($49>>>0)>(82595524);
  if ($50) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $49;
  }
 } else {
  $$0$i7 = 82595524;
 }
 $51 = ($$0$i7*52)|0;
 $52 = (__Znwj($51)|0);
 $53 = (($this) + 4|0);
 HEAP32[$53>>2] = $52;
 HEAP32[$this>>2] = $52;
 $54 = (($52) + (($$0$i7*52)|0)|0);
 HEAP32[$4>>2] = $54;
 $55 = ($__first|0)==($__last|0);
 if ($55) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$57 = $52;
 }
 while(1) {
  $56 = ($57|0)==(0|0);
  if ($56) {
   $59 = 0;
  } else {
   dest=$57+0|0; src=$$01$i+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre2$i = HEAP32[$53>>2]|0;
   $59 = $$pre2$i;
  }
  $58 = (($59) + 52|0);
  HEAP32[$53>>2] = $58;
  $60 = (($$01$i) + 52|0);
  $61 = ($60|0)==($__last|0);
  if ($61) {
   break;
  } else {
   $$01$i = $60;$57 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS5_IS8_EEE21__push_back_slow_pathIKS8_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i13 = 0, $$0$i14 = 0, $$01$i$i = 0, $$index = 0, $$index3 = 0, $$pre = 0, $$pre$i = 0, $$pre11 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 24)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(178956970);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 24)&-1;
 $14 = ($13>>>0)<(89478485);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i14 = 0;$22 = 0;
  } else {
   $$0$i13 = $17;
   label = 5;
  }
 } else {
  $$0$i13 = 178956970;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i13*24)|0;
  $20 = (__Znwj($19)|0);
  $$0$i14 = $$0$i13;$22 = $20;
 }
 $21 = (($22) + (($6*24)|0)|0);
 $23 = (($22) + (($$0$i14*24)|0)|0);
 $24 = ($21|0)==(0|0);
 do {
  if ($24) {
   $31 = $1;$32 = $2;
   label = 10;
  } else {
   __THREW__ = 0;
   invoke_vii(3223,($21|0),($__x|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $27 = ___cxa_find_matching_catch()|0;
    $28 = tempRet0;
    $$index = $27;$$index3 = $28;
    break;
   } else {
    $$pre11 = HEAP32[$this>>2]|0;
    $$pre12 = HEAP32[$0>>2]|0;
    $31 = $$pre12;$32 = $$pre11;
    label = 10;
    break;
   }
  }
 } while(0);
 L14: do {
  if ((label|0) == 10) {
   $29 = (($22) + (($7*24)|0)|0);
   $30 = ($31|0)==($32|0);
   do {
    if ($30) {
     HEAP32[$this>>2] = $21;
     HEAP32[$0>>2] = $29;
     HEAP32[$9>>2] = $23;
     $55 = $31;
    } else {
     $$01$i$i = $31;$34 = $21;
     while(1) {
      $33 = (($34) + -24|0);
      $35 = (($$01$i$i) + -24|0);
      __THREW__ = 0;
      invoke_vii(3223,($33|0),($35|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 23;
       break;
      }
      $38 = ($35|0)==($32|0);
      if ($38) {
       label = 14;
       break;
      } else {
       $$01$i$i = $35;$34 = $33;
      }
     }
     if ((label|0) == 14) {
      $$pre$i = HEAP32[$this>>2]|0;
      $$pre = HEAP32[$0>>2]|0;
      HEAP32[$this>>2] = $33;
      HEAP32[$0>>2] = $29;
      HEAP32[$9>>2] = $23;
      $39 = ($$pre|0)==($$pre$i|0);
      if ($39) {
       $55 = $$pre$i;
       break;
      } else {
       $41 = $$pre;
      }
      while(1) {
       $40 = (($41) + -24|0);
       $42 = (($41) + -12|0);
       $43 = HEAP8[$42>>0]|0;
       $44 = $43 & 1;
       $45 = ($44<<24>>24)==(0);
       if (!($45)) {
        $46 = (($41) + -4|0);
        $47 = HEAP32[$46>>2]|0;
        __ZdlPv($47);
       }
       $48 = HEAP8[$40>>0]|0;
       $49 = $48 & 1;
       $50 = ($49<<24>>24)==(0);
       if (!($50)) {
        $52 = (($41) + -16|0);
        $53 = HEAP32[$52>>2]|0;
        __ZdlPv($53);
       }
       $51 = ($40|0)==($$pre$i|0);
       if ($51) {
        $55 = $$pre$i;
        break;
       } else {
        $41 = $40;
       }
      }
     }
     else if ((label|0) == 23) {
      $56 = ___cxa_find_matching_catch()|0;
      $57 = tempRet0;
      $58 = ($29|0)==($34|0);
      if ($58) {
       $$index = $56;$$index3 = $57;
       break L14;
      } else {
       $60 = $29;
      }
      while(1) {
       $59 = (($60) + -24|0);
       $61 = (($60) + -12|0);
       $62 = HEAP8[$61>>0]|0;
       $63 = $62 & 1;
       $64 = ($63<<24>>24)==(0);
       if (!($64)) {
        $65 = (($60) + -4|0);
        $66 = HEAP32[$65>>2]|0;
        __ZdlPv($66);
       }
       $67 = HEAP8[$59>>0]|0;
       $68 = $67 & 1;
       $69 = ($68<<24>>24)==(0);
       if (!($69)) {
        $71 = (($60) + -16|0);
        $72 = HEAP32[$71>>2]|0;
        __ZdlPv($72);
       }
       $70 = ($59|0)==($34|0);
       if ($70) {
        $$index = $56;$$index3 = $57;
        break L14;
       } else {
        $60 = $59;
       }
      }
     }
    }
   } while(0);
   $54 = ($55|0)==(0|0);
   if ($54) {
    STACKTOP = sp;return;
   }
   __ZdlPv($55);
   STACKTOP = sp;return;
  }
 } while(0);
 $73 = ($22|0)==(0|0);
 if ($73) {
  ___resumeException($$index|0);
  // unreachable;
 }
 __ZdlPv($22);
 ___resumeException($$index|0);
 // unreachable;
}
function __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($this,$__hint,$__parent,$__v) {
 $this = $this|0;
 $__hint = $__hint|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__nd$0$in$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$__hint>>2]|0;
 $2 = ($1|0)==($0|0);
 if (!($2)) {
  $3 = (($1) + 16|0);
  $4 = HEAP32[$__v>>2]|0;
  $5 = HEAP32[$3>>2]|0;
  $6 = ($4|0)<($5|0);
  if (!($6)) {
   $36 = ($5|0)<($4|0);
   if (!($36)) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
   $37 = (($1) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    $$01$i$i$i$i$i = $1;
    while(1) {
     $42 = (($$01$i$i$i$i$i) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==($$01$i$i$i$i$i|0);
     if ($45) {
      $$0$i$i$i$i$i = $43;
      break;
     } else {
      $$01$i$i$i$i$i = $43;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $38;
    while(1) {
     $40 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $40;
     }
    }
   }
   $46 = ($$0$i$i$i$i$i|0)==($0|0);
   if (!($46)) {
    $47 = (($$0$i$i$i$i$i) + 16|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($4|0)<($48|0);
    if (!($49)) {
     $50 = (($this) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==(0|0);
     if ($52) {
      HEAP32[$__parent>>2] = $0;
      $$0 = $0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $__nd$0$in$i = $51;
     }
     while(1) {
      $53 = (($__nd$0$in$i) + 16|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($4|0)<($54|0);
      if ($55) {
       $56 = HEAP32[$__nd$0$in$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        label = 34;
        break;
       } else {
        $__nd$0$in$i = $56;
        continue;
       }
      }
      $58 = ($54|0)<($4|0);
      if (!($58)) {
       label = 38;
       break;
      }
      $59 = (($__nd$0$in$i) + 4|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if ($61) {
       label = 37;
       break;
      } else {
       $__nd$0$in$i = $60;
      }
     }
     if ((label|0) == 34) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__nd$0$in$i;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 37) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $59;
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 38) {
      HEAP32[$__parent>>2] = $__nd$0$in$i;
      $$0 = $__parent;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   if ($39) {
    HEAP32[$__parent>>2] = $1;
    $$0 = $37;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$__parent>>2] = $$0$i$i$i$i$i;
    $$0 = $$0$i$i$i$i$i;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = ($1|0)==($7|0);
 $$pre = HEAP32[$1>>2]|0;
 if ($8) {
  $22 = $1;
 } else {
  $9 = ($$pre|0)==(0|0);
  if ($9) {
   $$01$i$i = $1;
   while(1) {
    $13 = (($$01$i$i) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($$01$i$i|0);
    if ($16) {
     $$01$i$i = $14;
    } else {
     $$0$i$i = $14;
     break;
    }
   }
  } else {
   $$0$i$i$i = $$pre;
   while(1) {
    $10 = (($$0$i$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $11;
    }
   }
  }
  $17 = (($$0$i$i) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$__v>>2]|0;
  $20 = ($18|0)<($19|0);
  if ($20) {
   $22 = $$0$i$i;
  } else {
   $24 = (($this) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0|0);
   if ($26) {
    HEAP32[$__parent>>2] = $0;
    $$0 = $0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $__nd$0$in$i5 = $25;
   }
   while(1) {
    $27 = (($__nd$0$in$i5) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($19|0)<($28|0);
    if ($29) {
     $30 = HEAP32[$__nd$0$in$i5>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      label = 15;
      break;
     } else {
      $__nd$0$in$i5 = $30;
      continue;
     }
    }
    $32 = ($28|0)<($19|0);
    if (!($32)) {
     label = 19;
     break;
    }
    $33 = (($__nd$0$in$i5) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 18;
     break;
    } else {
     $__nd$0$in$i5 = $34;
    }
   }
   if ((label|0) == 15) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__nd$0$in$i5;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 18) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $33;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    HEAP32[$__parent>>2] = $__nd$0$in$i5;
    $$0 = $__parent;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $21 = ($$pre|0)==(0|0);
 if ($21) {
  HEAP32[$__parent>>2] = $1;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$__parent>>2] = $22;
  $23 = (($22) + 4|0);
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9ShaderLab14ParserGrabPassD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((678840 + 8|0));
 $1 = (($this) + 32|0);
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1,$3);
 $4 = (($this) + 20|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($this) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 $10 = (($this) + 8|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($15|0),($$byval_copy|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  ___cxa_call_unexpected(($18|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab14ParserGrabPassD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((678840 + 8|0));
 $1 = (($this) + 32|0);
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($1,$3);
 $4 = (($this) + 20|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($this) + 28|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 $10 = (($this) + 8|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $14 = (($this) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($15|0),($$byval_copy|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  ___cxa_call_unexpected(($18|0));
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab13ParserUsePassD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((678856 + 8|0));
 $1 = (($this) + 8|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($6|0),($$byval_copy|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab13ParserUsePassD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((678856 + 8|0));
 $1 = (($this) + 8|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($6|0),($$byval_copy|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab17ParserShaderStateC2ERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$01$i$i$i$i$i$i = 0, $$byval_copy2 = 0, $$pre$i$i$i$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__parent$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $1 = sp + 16|0;
 $__parent$i$i$i$i$i = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp;
 $4 = HEAP8[$0>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $11 = (($0) + 1|0);
  $12 = $4&255;
  $13 = $12 >>> 1;
  $15 = $13;$26 = $11;
 } else {
  $7 = (($0) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($0) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $15 = $10;$26 = $8;
 }
 $14 = ($15>>>0)>(2147483631);
 if ($14) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = ($15>>>0)<(11);
 if ($16) {
  $17 = $15 << 1;
  $18 = $17&255;
  HEAP8[$this>>0] = $18;
  $19 = (($this) + 1|0);
  $__p$0$i$i$i$i = $19;
 } else {
  $20 = (($15) + 16)|0;
  $21 = $20 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,16,$$byval_copy2,0,678832,79)|0);
  $23 = (($this) + 8|0);
  HEAP32[$23>>2] = $22;
  $24 = $21 | 1;
  HEAP32[$this>>2] = $24;
  $25 = (($this) + 4|0);
  HEAP32[$25>>2] = $15;
  $__p$0$i$i$i$i = $22;
 }
 _memcpy(($__p$0$i$i$i$i|0),($26|0),($15|0))|0;
 $27 = (($__p$0$i$i$i$i) + ($15)|0);
 HEAP8[$27>>0] = 0;
 $28 = (($this) + 12|0);
 $29 = (($0) + 12|0);
 _memcpy(($28|0),($29|0),628)|0;
 $30 = (($this) + 640|0);
 $31 = (($this) + 644|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 648|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 644|0);
 HEAP32[$30>>2] = $33;
 $34 = (($0) + 640|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($0) + 644|0);
 $37 = ($35|0)==($36|0);
 if ($37) {
  $87 = (($this) + 652|0);
  $88 = (($0) + 652|0);
  $89 = HEAP32[$88>>2]|0;
  HEAP32[$87>>2] = $89;
  STACKTOP = sp;return;
 }
 $39 = $35;
 while(1) {
  $38 = (($39) + 16|0);
  $40 = $38;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = $3;
  $47 = $46;
  HEAP32[$47>>2] = $42;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $45;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  $50 = (__ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($30,$$byval_copy2,$__parent$i$i$i$i$i,$3)|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)==(0|0);
  if ($52) {
   __THREW__ = 0;
   $53 = (invoke_ii(2988,24)|0);
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    break;
   }
   $56 = (($53) + 16|0);
   $57 = $3;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + 4)|0;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = $56;
   $64 = $63;
   HEAP32[$64>>2] = $59;
   $65 = (($63) + 4)|0;
   $66 = $65;
   HEAP32[$66>>2] = $62;
   $67 = HEAP32[$__parent$i$i$i$i$i>>2]|0;
   HEAP32[$53>>2] = 0;
   $68 = (($53) + 4|0);
   HEAP32[$68>>2] = 0;
   $69 = (($53) + 8|0);
   HEAP32[$69>>2] = $67;
   HEAP32[$50>>2] = $53;
   $70 = HEAP32[$30>>2]|0;
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    $74 = $53;
   } else {
    HEAP32[$30>>2] = $71;
    $$pre$i$i$i$i$i$i = HEAP32[$50>>2]|0;
    $74 = $$pre$i$i$i$i$i$i;
   }
   $73 = HEAP32[$31>>2]|0;
   __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($73,$74);
   $75 = HEAP32[$32>>2]|0;
   $76 = (($75) + 1)|0;
   HEAP32[$32>>2] = $76;
  }
  $77 = (($39) + 4|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($78|0)==(0|0);
  if ($79) {
   $$01$i$i$i$i$i$i = $39;
   while(1) {
    $82 = (($$01$i$i$i$i$i$i) + 8|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = HEAP32[$83>>2]|0;
    $85 = ($84|0)==($$01$i$i$i$i$i$i|0);
    if ($85) {
     $$0$i$i$i$i$i$i = $83;
     break;
    } else {
     $$01$i$i$i$i$i$i = $83;
    }
   }
  } else {
   $$0$i$i$i$i$i$i$i = $78;
   while(1) {
    $80 = HEAP32[$$0$i$i$i$i$i$i$i>>2]|0;
    $81 = ($80|0)==(0|0);
    if ($81) {
     $$0$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i$i$i = $80;
    }
   }
  }
  $86 = ($$0$i$i$i$i$i$i|0)==($36|0);
  if ($86) {
   label = 21;
   break;
  } else {
   $39 = $$0$i$i$i$i$i$i;
  }
 }
 if ((label|0) == 21) {
  $87 = (($this) + 652|0);
  $88 = (($0) + 652|0);
  $89 = HEAP32[$88>>2]|0;
  HEAP32[$87>>2] = $89;
  STACKTOP = sp;return;
 }
 $90 = ___cxa_find_matching_catch()|0;
 $91 = tempRet0;
 $92 = HEAP32[$31>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($30,$92);
 $93 = HEAP8[$this>>0]|0;
 $94 = $93 & 1;
 $95 = ($94<<24>>24)==(0);
 if ($95) {
  ___resumeException($90|0);
  // unreachable;
 }
 $96 = (($this) + 8|0);
 $97 = HEAP32[$96>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($97|0),($$byval_copy2|0));
 $98 = __THREW__; __THREW__ = 0;
 $99 = $98&1;
 if ($99) {
  $100 = ___cxa_find_matching_catch()|0;
  $101 = tempRet0;
  ___cxa_call_unexpected(($100|0));
  // unreachable;
 } else {
  ___resumeException($90|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIPN9ShaderLab14ParserBasePassENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = $15 >> 2;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $27 = $__last;
   $28 = (($27) - ($1))|0;
   $29 = $28 >> 2;
   _memmove(($6|0),($__first|0),($28|0))|0;
   $30 = (($6) + ($29<<2)|0);
   $31 = HEAP32[$12>>2]|0;
   $32 = ($31|0)==($30|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $30;
   $scevgep$i$i = (($31) + -4|0);
   $33 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($33)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $34 = $uglygep3$i$i >>> 2;
   $35 = $34 ^ -1;
   $scevgep4$i$i = (($31) + ($35<<2)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + ($16<<2)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$12>>2]|0;
  $$01$i3 = $18;$21 = $$pre$i1;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $24 = 0;
   } else {
    $22 = HEAP32[$$01$i3>>2]|0;
    HEAP32[$21>>2] = $22;
    $$pre2$i4 = HEAP32[$12>>2]|0;
    $24 = $$pre2$i4;
   }
   $23 = (($24) + 4|0);
   HEAP32[$12>>2] = $23;
   $25 = (($$01$i3) + 4|0);
   $26 = ($25|0)==($__last|0);
   if ($26) {
    break;
   } else {
    $$01$i3 = $25;$21 = $23;
   }
  }
  STACKTOP = sp;return;
 }
 $36 = ($6|0)==(0|0);
 if ($36) {
  $45 = $5;
 } else {
  $37 = (($this) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==($6|0);
  if (!($39)) {
   $scevgep$i$i$i$i = (($38) + -4|0);
   $40 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($40)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $41 = $uglygep3$i$i$i$i >>> 2;
   $42 = $41 ^ -1;
   $scevgep4$i$i$i$i = (($38) + ($42<<2)|0);
   HEAP32[$37>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$37>>2] = 0;
  HEAP32[$this>>2] = 0;
  $45 = 0;
 }
 $43 = ($3>>>0)>(1073741823);
 if ($43) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $44 = $45;
 $46 = $44 >> 2;
 $47 = ($46>>>0)<(536870911);
 if ($47) {
  $48 = $44 >> 1;
  $49 = ($48>>>0)<($3>>>0);
  $50 = $49 ? $3 : $48;
  $51 = ($50>>>0)>(1073741823);
  if ($51) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $50;
  }
 } else {
  $$0$i7 = 1073741823;
 }
 $52 = $$0$i7 << 2;
 $53 = (__Znwj($52)|0);
 $54 = (($this) + 4|0);
 HEAP32[$54>>2] = $53;
 HEAP32[$this>>2] = $53;
 $55 = (($53) + ($$0$i7<<2)|0);
 HEAP32[$4>>2] = $55;
 $56 = ($__first|0)==($__last|0);
 if ($56) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$58 = $53;
 }
 while(1) {
  $57 = ($58|0)==(0|0);
  if ($57) {
   $61 = 0;
  } else {
   $59 = HEAP32[$$01$i>>2]|0;
   HEAP32[$58>>2] = $59;
   $$pre2$i = HEAP32[$54>>2]|0;
   $61 = $$pre2$i;
  }
  $60 = (($61) + 4|0);
  HEAP32[$54>>2] = $60;
  $62 = (($$01$i) + 4|0);
  $63 = ($62|0)==($__last|0);
  if ($63) {
   break;
  } else {
   $$01$i = $62;$58 = $60;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__15dequeIPN9ShaderLab17ParserShaderStateENS_9allocatorIS3_EEE19__add_back_capacityEv($this) {
 $this = $this|0;
 var $$0153 = 0, $$055 = 0, $$pr$pre$i = 0, $$pr$pre$i36 = 0, $$pre = 0, $$pre$i = 0, $$pre$i33 = 0, $$pre50 = 0, $$pre8$i = 0, $$pre8$i19 = 0, $$pre8$i28 = 0, $$pre8$i38 = 0, $$sum = 0, $$sum$i = 0, $$sum$i30 = 0, $$sum41 = 0, $$sum42 = 0, $$sum43 = 0, $$sum51 = 0, $$sum52 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__buf = 0, $__i$0 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $__buf = sp;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>(1023);
 if ($3) {
  $4 = (($2) + -1024)|0;
  HEAP32[$1>>2] = $4;
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($6) + 4|0);
  HEAP32[$5>>2] = $8;
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  do {
   if ($13) {
    $14 = HEAP32[$this>>2]|0;
    $15 = ($8>>>0)>($14>>>0);
    if ($15) {
     $16 = $8;
     $17 = $14;
     $18 = (($16) - ($17))|0;
     $19 = $18 >> 2;
     $20 = (($19) + 1)|0;
     $21 = (($20|0) / -2)&-1;
     $$sum42 = (($21) + 1)|0;
     $22 = (($6) + ($$sum42<<2)|0);
     $23 = $10;
     $24 = (($23) - ($16))|0;
     $25 = $24 >> 2;
     _memmove(($22|0),($8|0),($24|0))|0;
     $$sum$i = (($25) + 1)|0;
     $$sum43 = (($$sum$i) + ($21))|0;
     $26 = (($6) + ($$sum43<<2)|0);
     HEAP32[$9>>2] = $26;
     $27 = HEAP32[$5>>2]|0;
     $28 = (($27) + ($21<<2)|0);
     HEAP32[$5>>2] = $28;
     $54 = $26;
     label = 13;
     break;
    }
    $29 = $10;
    $30 = $14;
    $31 = (($29) - ($30))|0;
    $32 = $31 >> 1;
    $33 = ($32|0)==(0);
    $34 = $33 ? 1 : $32;
    $35 = $34 >>> 2;
    $36 = $34 << 2;
    $37 = (__Znwj($36)|0);
    $38 = (($37) + ($35<<2)|0);
    $39 = (($37) + ($34<<2)|0);
    $40 = ($8|0)==($10|0);
    if ($40) {
     $49 = $38;$51 = $14;
    } else {
     $42 = $38;$44 = $8;
     while(1) {
      $41 = ($42|0)==(0|0);
      if ($41) {
       $46 = 0;
      } else {
       $43 = HEAP32[$44>>2]|0;
       HEAP32[$42>>2] = $43;
       $46 = $42;
      }
      $45 = (($46) + 4|0);
      $47 = (($44) + 4|0);
      $48 = ($47|0)==($10|0);
      if ($48) {
       break;
      } else {
       $42 = $45;$44 = $47;
      }
     }
     $$pre$i = HEAP32[$this>>2]|0;
     $49 = $45;$51 = $$pre$i;
    }
    HEAP32[$this>>2] = $37;
    HEAP32[$5>>2] = $38;
    HEAP32[$9>>2] = $49;
    HEAP32[$11>>2] = $39;
    $50 = ($51|0)==(0|0);
    if ($50) {
     $53 = $49;
     label = 12;
    } else {
     __ZdlPv($51);
     $$pr$pre$i = HEAP32[$9>>2]|0;
     $53 = $$pr$pre$i;
     label = 12;
    }
   } else {
    $53 = $10;
    label = 12;
   }
  } while(0);
  if ((label|0) == 12) {
   $52 = ($53|0)==(0|0);
   if ($52) {
    $56 = 0;
   } else {
    $54 = $53;
    label = 13;
   }
  }
  if ((label|0) == 13) {
   HEAP32[$54>>2] = $7;
   $$pre8$i = HEAP32[$9>>2]|0;
   $56 = $$pre8$i;
  }
  $55 = (($56) + 4|0);
  HEAP32[$9>>2] = $55;
  STACKTOP = sp;return;
 }
 $57 = (($this) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($this) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $58;
 $62 = $60;
 $63 = (($61) - ($62))|0;
 $64 = $63 >> 2;
 $65 = (($this) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$this>>2]|0;
 $68 = $66;
 $69 = $67;
 $70 = (($68) - ($69))|0;
 $71 = $70 >> 2;
 $72 = ($64>>>0)<($71>>>0);
 if ($72) {
  $73 = ($66|0)==($58|0);
  $74 = (__Znwj(4096)|0);
  if (!($73)) {
   $75 = ($58|0)==(0|0);
   if ($75) {
    $77 = 0;
   } else {
    HEAP32[$58>>2] = $74;
    $$pre8$i28 = HEAP32[$57>>2]|0;
    $77 = $$pre8$i28;
   }
   $76 = (($77) + 4|0);
   HEAP32[$57>>2] = $76;
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $74;
  __ZNSt3__114__split_bufferIPPN9ShaderLab17ParserShaderStateENS_9allocatorIS4_EEE10push_frontERKS4_($this,$0);
  $78 = HEAP32[$59>>2]|0;
  $79 = HEAP32[$78>>2]|0;
  $80 = (($78) + 4|0);
  HEAP32[$59>>2] = $80;
  $81 = HEAP32[$57>>2]|0;
  $82 = HEAP32[$65>>2]|0;
  $83 = ($81|0)==($82|0);
  do {
   if ($83) {
    $84 = HEAP32[$this>>2]|0;
    $85 = ($80>>>0)>($84>>>0);
    if ($85) {
     $86 = $80;
     $87 = $84;
     $88 = (($86) - ($87))|0;
     $89 = $88 >> 2;
     $90 = (($89) + 1)|0;
     $91 = (($90|0) / -2)&-1;
     $$sum = (($91) + 1)|0;
     $92 = (($78) + ($$sum<<2)|0);
     $93 = $81;
     $94 = (($93) - ($86))|0;
     $95 = $94 >> 2;
     _memmove(($92|0),($80|0),($94|0))|0;
     $$sum$i30 = (($95) + 1)|0;
     $$sum41 = (($$sum$i30) + ($91))|0;
     $96 = (($78) + ($$sum41<<2)|0);
     HEAP32[$57>>2] = $96;
     $97 = HEAP32[$59>>2]|0;
     $98 = (($97) + ($91<<2)|0);
     HEAP32[$59>>2] = $98;
     $124 = $96;
     label = 31;
     break;
    }
    $99 = $81;
    $100 = $84;
    $101 = (($99) - ($100))|0;
    $102 = $101 >> 1;
    $103 = ($102|0)==(0);
    $104 = $103 ? 1 : $102;
    $105 = $104 >>> 2;
    $106 = $104 << 2;
    $107 = (__Znwj($106)|0);
    $108 = (($107) + ($105<<2)|0);
    $109 = (($107) + ($104<<2)|0);
    $110 = ($80|0)==($81|0);
    if ($110) {
     $119 = $108;$121 = $84;
    } else {
     $112 = $108;$114 = $80;
     while(1) {
      $111 = ($112|0)==(0|0);
      if ($111) {
       $116 = 0;
      } else {
       $113 = HEAP32[$114>>2]|0;
       HEAP32[$112>>2] = $113;
       $116 = $112;
      }
      $115 = (($116) + 4|0);
      $117 = (($114) + 4|0);
      $118 = ($117|0)==($81|0);
      if ($118) {
       break;
      } else {
       $112 = $115;$114 = $117;
      }
     }
     $$pre$i33 = HEAP32[$this>>2]|0;
     $119 = $115;$121 = $$pre$i33;
    }
    HEAP32[$this>>2] = $107;
    HEAP32[$59>>2] = $108;
    HEAP32[$57>>2] = $119;
    HEAP32[$65>>2] = $109;
    $120 = ($121|0)==(0|0);
    if ($120) {
     $123 = $119;
     label = 30;
    } else {
     __ZdlPv($121);
     $$pr$pre$i36 = HEAP32[$57>>2]|0;
     $123 = $$pr$pre$i36;
     label = 30;
    }
   } else {
    $123 = $81;
    label = 30;
   }
  } while(0);
  if ((label|0) == 30) {
   $122 = ($123|0)==(0|0);
   if ($122) {
    $126 = 0;
   } else {
    $124 = $123;
    label = 31;
   }
  }
  if ((label|0) == 31) {
   HEAP32[$124>>2] = $79;
   $$pre8$i38 = HEAP32[$57>>2]|0;
   $126 = $$pre8$i38;
  }
  $125 = (($126) + 4|0);
  HEAP32[$57>>2] = $125;
  STACKTOP = sp;return;
 }
 $127 = $70 >> 1;
 $128 = ($127|0)==(0);
 $129 = $128 ? 1 : $127;
 $130 = (($this) + 12|0);
 $131 = (($__buf) + 12|0);
 $132 = (($__buf) + 16|0);
 HEAP32[$132>>2] = $130;
 $133 = $129 << 2;
 $134 = (__Znwj($133)|0);
 HEAP32[$__buf>>2] = $134;
 $135 = (($134) + ($64<<2)|0);
 $136 = (($__buf) + 8|0);
 HEAP32[$136>>2] = $135;
 $137 = (($__buf) + 4|0);
 HEAP32[$137>>2] = $135;
 $138 = (($134) + ($129<<2)|0);
 HEAP32[$131>>2] = $138;
 __THREW__ = 0;
 $139 = (invoke_ii(2988,4096)|0);
 $140 = __THREW__; __THREW__ = 0;
 $141 = $140&1;
 L54: do {
  if ($141) {
   label = 42;
  } else {
   $142 = ($64|0)==($129|0);
   do {
    if ($142) {
     $143 = ($135>>>0)>($134>>>0);
     $144 = $135;
     $145 = $134;
     $146 = (($144) - ($145))|0;
     if ($143) {
      $147 = $146 >> 2;
      $148 = (($147) + 1)|0;
      $149 = (($148|0) / -2)&-1;
      $$sum52 = (($64) + ($149))|0;
      $150 = (($134) + ($$sum52<<2)|0);
      HEAP32[$136>>2] = $150;
      HEAP32[$137>>2] = $150;
      $163 = $150;
      break;
     }
     $151 = $146 >> 1;
     $152 = ($151|0)==(0);
     $153 = $152 ? 1 : $151;
     $154 = $153 << 2;
     __THREW__ = 0;
     $155 = (invoke_ii(2988,($154|0))|0);
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if ($157) {
      label = 42;
      break L54;
     }
     $158 = $153 >>> 2;
     $159 = (($155) + ($158<<2)|0);
     $160 = (($155) + ($153<<2)|0);
     HEAP32[$__buf>>2] = $155;
     HEAP32[$137>>2] = $159;
     HEAP32[$136>>2] = $159;
     HEAP32[$131>>2] = $160;
     $161 = ($134|0)==(0|0);
     if ($161) {
      $163 = $159;
     } else {
      __ZdlPv($134);
      $163 = $159;
     }
    } else {
     $163 = $135;
    }
   } while(0);
   $162 = ($163|0)==(0|0);
   if ($162) {
    $175 = 0;
   } else {
    HEAP32[$163>>2] = $139;
    $$pre8$i19 = HEAP32[$136>>2]|0;
    $175 = $$pre8$i19;
   }
   $174 = (($175) + 4|0);
   HEAP32[$136>>2] = $174;
   $176 = HEAP32[$57>>2]|0;
   $__i$0 = $176;
   while(1) {
    $177 = HEAP32[$59>>2]|0;
    $178 = ($__i$0|0)==($177|0);
    if ($178) {
     break;
    }
    $179 = (($__i$0) + -4|0);
    __THREW__ = 0;
    invoke_vii(3262,($__buf|0),($179|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if ($181) {
     label = 51;
     break;
    } else {
     $__i$0 = $179;
    }
   }
   if ((label|0) == 51) {
    $194 = ___cxa_find_matching_catch()|0;
    $195 = tempRet0;
    $$pre = HEAP32[$137>>2]|0;
    $$pre50 = HEAP32[$136>>2]|0;
    $196 = ($$pre50|0)==($$pre|0);
    if ($196) {
     $$0153 = $194;$$055 = $195;
     break;
    }
    $__new_last2$i$i$i$i$i = $$pre;
    $scevgep$i$i$i$i$i = (($$pre50) + -4|0);
    $197 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($197)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $198 = $uglygep3$i$i$i$i$i >>> 2;
    $199 = $198 ^ -1;
    $scevgep4$i$i$i$i$i = (($$pre50) + ($199<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i;
    $$0153 = $194;$$055 = $195;
    break;
   }
   $182 = HEAP32[$this>>2]|0;
   $183 = HEAP32[$__buf>>2]|0;
   HEAP32[$this>>2] = $183;
   HEAP32[$__buf>>2] = $182;
   $184 = HEAP32[$137>>2]|0;
   HEAP32[$59>>2] = $184;
   HEAP32[$137>>2] = $__i$0;
   $185 = HEAP32[$57>>2]|0;
   $186 = HEAP32[$136>>2]|0;
   HEAP32[$57>>2] = $186;
   HEAP32[$136>>2] = $185;
   $187 = HEAP32[$65>>2]|0;
   $188 = HEAP32[$131>>2]|0;
   HEAP32[$65>>2] = $188;
   HEAP32[$131>>2] = $187;
   $189 = ($185|0)==($__i$0|0);
   if (!($189)) {
    $__new_last2$i$i$i$i$i2 = $__i$0;
    $scevgep$i$i$i$i$i3 = (($185) + -4|0);
    $190 = (0 - ($__new_last2$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($190)|0);
    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
    $191 = $uglygep3$i$i$i$i$i6 >>> 2;
    $192 = $191 ^ -1;
    $scevgep4$i$i$i$i$i7 = (($185) + ($192<<2)|0);
    HEAP32[$136>>2] = $scevgep4$i$i$i$i$i7;
   }
   $193 = ($182|0)==(0|0);
   if ($193) {
    STACKTOP = sp;return;
   }
   __ZdlPv($182);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 42) {
  $164 = ___cxa_find_matching_catch(0|0)|0;
  $165 = tempRet0;
  (___cxa_begin_catch(($164|0))|0);
  $$sum51 = (($64) + -1)|0;
  $166 = (($134) + ($$sum51<<2)|0);
  $167 = HEAP32[$166>>2]|0;
  __ZdlPv($167);
  __THREW__ = 0;
  invoke_v(140);
  $168 = __THREW__; __THREW__ = 0;
  $169 = $168&1;
  if (!($169)) {
   // unreachable;
  }
  $170 = ___cxa_find_matching_catch()|0;
  $171 = tempRet0;
  __THREW__ = 0;
  invoke_v(66);
  $172 = __THREW__; __THREW__ = 0;
  $173 = $172&1;
  if ($173) {
   $202 = ___cxa_find_matching_catch(0|0)|0;
   $203 = tempRet0;
   ___clang_call_terminate($202);
   // unreachable;
  } else {
   $$0153 = $170;$$055 = $171;
  }
 }
 $200 = HEAP32[$__buf>>2]|0;
 $201 = ($200|0)==(0|0);
 if ($201) {
  ___resumeException($$0153|0);
  // unreachable;
 }
 __ZdlPv($200);
 ___resumeException($$0153|0);
 // unreachable;
}
function __ZNSt3__114__split_bufferIPPN9ShaderLab17ParserShaderStateENS_9allocatorIS4_EEE10push_frontERKS4_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIPPN9ShaderLab17ParserShaderStateERNS_9allocatorIS4_EEE10push_frontERKS4_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$pre = 0, $$pre7 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5>>>0)<($7>>>0);
   $9 = $7;
   if ($8) {
    $10 = $5;
    $11 = (($9) - ($10))|0;
    $12 = $11 >> 2;
    $13 = (($12) + 1)|0;
    $14 = (($13|0) / 2)&-1;
    $15 = $1;
    $16 = (($10) - ($15))|0;
    $17 = $16 >> 2;
    $$sum = (($14) - ($17))|0;
    $18 = (($5) + ($$sum<<2)|0);
    _memmove(($18|0),($1|0),($16|0))|0;
    HEAP32[$0>>2] = $18;
    $19 = HEAP32[$4>>2]|0;
    $20 = (($19) + ($14<<2)|0);
    HEAP32[$4>>2] = $20;
    $45 = $18;
    break;
   }
   $21 = $1;
   $22 = (($9) - ($21))|0;
   $23 = $22 >> 1;
   $24 = ($23|0)==(0);
   $25 = $24 ? 1 : $23;
   $26 = (($25) + 3)|0;
   $27 = $26 >>> 2;
   $28 = $25 << 2;
   $29 = (__Znwj($28)|0);
   $30 = (($29) + ($27<<2)|0);
   $31 = (($29) + ($25<<2)|0);
   $32 = ($1|0)==($5|0);
   if ($32) {
    $41 = $30;$43 = $1;
   } else {
    $34 = $30;$36 = $1;
    while(1) {
     $33 = ($34|0)==(0|0);
     if ($33) {
      $38 = 0;
     } else {
      $35 = HEAP32[$36>>2]|0;
      HEAP32[$34>>2] = $35;
      $38 = $34;
     }
     $37 = (($38) + 4|0);
     $39 = (($36) + 4|0);
     $40 = ($39|0)==($5|0);
     if ($40) {
      break;
     } else {
      $34 = $37;$36 = $39;
     }
    }
    $$pre = HEAP32[$this>>2]|0;
    $41 = $37;$43 = $$pre;
   }
   HEAP32[$this>>2] = $29;
   HEAP32[$0>>2] = $30;
   HEAP32[$4>>2] = $41;
   HEAP32[$6>>2] = $31;
   $42 = ($43|0)==(0|0);
   if ($42) {
    $45 = $30;
   } else {
    __ZdlPv($43);
    $$pre7 = HEAP32[$0>>2]|0;
    $45 = $$pre7;
   }
  } else {
   $45 = $1;
  }
 } while(0);
 $44 = (($45) + -4|0);
 $46 = HEAP32[$__x>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = HEAP32[$0>>2]|0;
 $48 = (($47) + -4|0);
 HEAP32[$0>>2] = $48;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab14ParserPropertyD2Ev($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 68|0);
  $5 = HEAP32[$4>>2]|0;
  __ZdlPv($5);
 }
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if ($11) {
   $21 = $7;
  } else {
   $13 = $10;
   while(1) {
    $12 = (($13) + -12|0);
    HEAP32[$9>>2] = $12;
    $14 = HEAP8[$12>>0]|0;
    $15 = $14 & 1;
    $16 = ($15<<24>>24)==(0);
    if ($16) {
     $18 = $12;
    } else {
     $19 = (($13) + -4|0);
     $20 = HEAP32[$19>>2]|0;
     __ZdlPv($20);
     $$pre$i$i$i$i$i = HEAP32[$9>>2]|0;
     $18 = $$pre$i$i$i$i$i;
    }
    $17 = ($18|0)==($7|0);
    if ($17) {
     break;
    } else {
     $13 = $18;
    }
   }
   $$pre$i$i$i = HEAP32[$6>>2]|0;
   $21 = $$pre$i$i$i;
  }
  __ZdlPv($21);
 }
 $22 = (($this) + 12|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23 & 1;
 $25 = ($24<<24>>24)==(0);
 if (!($25)) {
  $26 = (($this) + 20|0);
  $27 = HEAP32[$26>>2]|0;
  __ZdlPv($27);
 }
 $28 = HEAP8[$this>>0]|0;
 $29 = $28 & 1;
 $30 = ($29<<24>>24)==(0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 __ZdlPv($32);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN9ShaderLab14ParserPropertyENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i3 = 0, $$012$i$i = 0, $$03$i$i = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep6$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 76)&-1;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 76)&-1;
 $11 = ($3>>>0)>($10>>>0);
 if ($11) {
  $56 = ($6|0)==(0|0);
  do {
   if ($56) {
    $68 = $5;
   } else {
    $57 = (($this) + 4|0);
    while(1) {
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==($6|0);
     if ($59) {
      label = 24;
      break;
     }
     $60 = (($58) + -76|0);
     HEAP32[$57>>2] = $60;
     __THREW__ = 0;
     invoke_vi(3592,($60|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 23;
      break;
     }
    }
    if ((label|0) == 23) {
     $63 = ___cxa_find_matching_catch()|0;
     $64 = tempRet0;
     ___cxa_call_unexpected(($63|0));
     // unreachable;
    }
    else if ((label|0) == 24) {
     $65 = HEAP32[$this>>2]|0;
     __ZdlPv($65);
     HEAP32[$4>>2] = 0;
     HEAP32[$57>>2] = 0;
     HEAP32[$this>>2] = 0;
     $68 = 0;
     break;
    }
   }
  } while(0);
  $66 = ($3>>>0)>(56512727);
  if ($66) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $67 = $68;
  $69 = (($67|0) / 76)&-1;
  $70 = ($69>>>0)<(28256363);
  if ($70) {
   $71 = $69 << 1;
   $72 = ($71>>>0)<($3>>>0);
   $73 = $72 ? $3 : $71;
   $74 = ($73>>>0)>(56512727);
   if ($74) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i7 = $73;
   }
  } else {
   $$0$i7 = 56512727;
  }
  $75 = ($$0$i7*76)|0;
  $76 = (__Znwj($75)|0);
  $77 = (($this) + 4|0);
  HEAP32[$77>>2] = $76;
  HEAP32[$this>>2] = $76;
  $78 = (($76) + (($$0$i7*76)|0)|0);
  HEAP32[$4>>2] = $78;
  $79 = ($__first|0)==($__last|0);
  if ($79) {
   STACKTOP = sp;return;
  } else {
   $$01$i = $__first;$81 = $76;
  }
  while(1) {
   $80 = ($81|0)==(0|0);
   if ($80) {
    $83 = 0;
   } else {
    __ZN9ShaderLab14ParserPropertyC2ERKS0_($81,$$01$i);
    $$pre2$i = HEAP32[$77>>2]|0;
    $83 = $$pre2$i;
   }
   $82 = (($83) + 76|0);
   HEAP32[$77>>2] = $82;
   $84 = (($$01$i) + 76|0);
   $85 = ($84|0)==($__last|0);
   if ($85) {
    break;
   } else {
    $$01$i = $84;$81 = $82;
   }
  }
  STACKTOP = sp;return;
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 76)&-1;
 $17 = ($3>>>0)>($16>>>0);
 if ($17) {
  $18 = (($__first) + (($16*76)|0)|0);
  $20 = $18;$__growing$0$off0 = 1;
 } else {
  $20 = $__last;$__growing$0$off0 = 0;
 }
 $19 = ($20|0)==($__first|0);
 if ($19) {
  $$0$lcssa$i$i = $6;
 } else {
  $scevgep$i$i = (($20) + -76|0);
  $21 = (0 - ($1))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($21)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $6;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($$03$i$i,$$012$i$i)|0);
   $22 = (($$03$i$i) + 12|0);
   $23 = (($$012$i$i) + 12|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($22,$23)|0);
   $24 = ($$03$i$i|0)==($$012$i$i|0);
   if (!($24)) {
    $25 = (($$03$i$i) + 24|0);
    $26 = (($$012$i$i) + 24|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($$012$i$i) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    __ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignIPS6_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS6_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($25,$27,$29);
   }
   $30 = (($$03$i$i) + 36|0);
   $31 = (($$012$i$i) + 36|0);
   ;HEAP32[$30+0>>2]=HEAP32[$31+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$31+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$31+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$31+12>>2]|0;HEAP32[$30+16>>2]=HEAP32[$31+16>>2]|0;HEAP32[$30+20>>2]=HEAP32[$31+20>>2]|0;
   $32 = (($$03$i$i) + 60|0);
   $33 = (($$012$i$i) + 60|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($32,$33)|0);
   $34 = (($$012$i$i) + 72|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($$03$i$i) + 72|0);
   HEAP32[$36>>2] = $35;
   $37 = (($$012$i$i) + 76|0);
   $38 = (($$03$i$i) + 76|0);
   $39 = ($37|0)==($20|0);
   if ($39) {
    break;
   } else {
    $$012$i$i = $37;$$03$i$i = $38;
   }
  }
  $40 = (($uglygep6$i$i>>>0) / 76)&-1;
  $41 = (($40) + 1)|0;
  $scevgep7$i$i = (($6) + (($41*76)|0)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if (!($__growing$0$off0)) {
  while(1) {
   $49 = HEAP32[$12>>2]|0;
   $50 = ($49|0)==($$0$lcssa$i$i|0);
   if ($50) {
    label = 34;
    break;
   }
   $51 = (($49) + -76|0);
   HEAP32[$12>>2] = $51;
   __THREW__ = 0;
   invoke_vi(3592,($51|0));
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    label = 18;
    break;
   }
  }
  if ((label|0) == 18) {
   $54 = ___cxa_find_matching_catch()|0;
   $55 = tempRet0;
   ___cxa_call_unexpected(($54|0));
   // unreachable;
  }
  else if ((label|0) == 34) {
   STACKTOP = sp;return;
  }
 }
 $42 = ($20|0)==($__last|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $$pre$i1 = HEAP32[$12>>2]|0;
 $$01$i3 = $20;$44 = $$pre$i1;
 while(1) {
  $43 = ($44|0)==(0|0);
  if ($43) {
   $46 = 0;
  } else {
   __ZN9ShaderLab14ParserPropertyC2ERKS0_($44,$$01$i3);
   $$pre2$i4 = HEAP32[$12>>2]|0;
   $46 = $$pre2$i4;
  }
  $45 = (($46) + 76|0);
  HEAP32[$12>>2] = $45;
  $47 = (($$01$i3) + 76|0);
  $48 = ($47|0)==($__last|0);
  if ($48) {
   break;
  } else {
   $$01$i3 = $47;$44 = $45;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab14ParserPropertyC2ERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  ;HEAP32[$this+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$0+8>>2]|0;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($0) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7>>>0)>(4294967279);
  if ($8) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $9 = ($7>>>0)<(11);
  if ($9) {
   $10 = $7 << 1;
   $11 = $10&255;
   HEAP8[$this>>0] = $11;
   $12 = (($this) + 1|0);
   $__p$0$i$i$i = $12;
  } else {
   $13 = (($7) + 16)|0;
   $14 = $13 & -16;
   $15 = (__Znwj($14)|0);
   $16 = (($this) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = $14 | 1;
   HEAP32[$this>>2] = $17;
   $18 = (($this) + 4|0);
   HEAP32[$18>>2] = $7;
   $__p$0$i$i$i = $15;
  }
  _memcpy(($__p$0$i$i$i|0),($5|0),($7|0))|0;
  $19 = (($__p$0$i$i$i) + ($7)|0);
  HEAP8[$19>>0] = 0;
 }
 $20 = (($this) + 12|0);
 $21 = (($0) + 12|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 L12: do {
  if ($24) {
   ;HEAP32[$20+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$21+8>>2]|0;
   label = 19;
  } else {
   $25 = (($0) + 20|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($0) + 16|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28>>>0)>(4294967279);
   do {
    if ($29) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      // unreachable;
     }
    } else {
     $32 = ($28>>>0)<(11);
     if ($32) {
      $33 = $28 << 1;
      $34 = $33&255;
      HEAP8[$20>>0] = $34;
      $35 = (($20) + 1|0);
      $__p$0$i$i$i4 = $35;
     } else {
      $36 = (($28) + 16)|0;
      $37 = $36 & -16;
      __THREW__ = 0;
      $38 = (invoke_ii(2988,($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      $41 = (($this) + 20|0);
      HEAP32[$41>>2] = $38;
      $42 = $37 | 1;
      HEAP32[$20>>2] = $42;
      $43 = (($this) + 16|0);
      HEAP32[$43>>2] = $28;
      $__p$0$i$i$i4 = $38;
     }
     _memcpy(($__p$0$i$i$i4|0),($26|0),($28|0))|0;
     $44 = (($__p$0$i$i$i4) + ($28)|0);
     HEAP8[$44>>0] = 0;
     label = 19;
     break L12;
    }
   } while(0);
   $79 = ___cxa_find_matching_catch()|0;
   $80 = tempRet0;
   $$1 = $80;$$12 = $79;
  }
 } while(0);
 if ((label|0) == 19) {
  $45 = (($this) + 24|0);
  $46 = (($0) + 24|0);
  __THREW__ = 0;
  invoke_vii(3263,($45|0),($46|0));
  $47 = __THREW__; __THREW__ = 0;
  $48 = $47&1;
  if ($48) {
   $81 = ___cxa_find_matching_catch()|0;
   $82 = tempRet0;
   $$0 = $82;$$01 = $81;
  } else {
   $49 = (($this) + 36|0);
   $50 = (($0) + 36|0);
   ;HEAP32[$49+0>>2]=HEAP32[$50+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$49+12>>2]=HEAP32[$50+12>>2]|0;HEAP32[$49+16>>2]=HEAP32[$50+16>>2]|0;HEAP32[$49+20>>2]=HEAP32[$50+20>>2]|0;
   $51 = (($this) + 60|0);
   $52 = (($0) + 60|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = $53 & 1;
   $55 = ($54<<24>>24)==(0);
   if ($55) {
    ;HEAP32[$51+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$51+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$52+8>>2]|0;
    $76 = (($this) + 72|0);
    $77 = (($0) + 72|0);
    $78 = HEAP32[$77>>2]|0;
    HEAP32[$76>>2] = $78;
    STACKTOP = sp;return;
   }
   $56 = (($0) + 68|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($0) + 64|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59>>>0)>(4294967279);
   do {
    if ($60) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if (!($62)) {
      // unreachable;
     }
    } else {
     $63 = ($59>>>0)<(11);
     if ($63) {
      $64 = $59 << 1;
      $65 = $64&255;
      HEAP8[$51>>0] = $65;
      $66 = (($51) + 1|0);
      $__p$0$i$i$i$i$i = $66;
     } else {
      $67 = (($59) + 16)|0;
      $68 = $67 & -16;
      __THREW__ = 0;
      $69 = (invoke_ii(2988,($68|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      $72 = (($this) + 68|0);
      HEAP32[$72>>2] = $69;
      $73 = $68 | 1;
      HEAP32[$51>>2] = $73;
      $74 = (($this) + 64|0);
      HEAP32[$74>>2] = $59;
      $__p$0$i$i$i$i$i = $69;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($57|0),($59|0))|0;
     $75 = (($__p$0$i$i$i$i$i) + ($59)|0);
     HEAP8[$75>>0] = 0;
     $76 = (($this) + 72|0);
     $77 = (($0) + 72|0);
     $78 = HEAP32[$77>>2]|0;
     HEAP32[$76>>2] = $78;
     STACKTOP = sp;return;
    }
   } while(0);
   $83 = ___cxa_find_matching_catch()|0;
   $84 = tempRet0;
   $85 = HEAP32[$45>>2]|0;
   $86 = ($85|0)==(0|0);
   if ($86) {
    $$0 = $84;$$01 = $83;
   } else {
    $87 = (($this) + 28|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==($85|0);
    if ($89) {
     $99 = $85;
    } else {
     $91 = $88;
     while(1) {
      $90 = (($91) + -12|0);
      HEAP32[$87>>2] = $90;
      $92 = HEAP8[$90>>0]|0;
      $93 = $92 & 1;
      $94 = ($93<<24>>24)==(0);
      if ($94) {
       $96 = $90;
      } else {
       $97 = (($91) + -4|0);
       $98 = HEAP32[$97>>2]|0;
       __ZdlPv($98);
       $$pre$i$i$i$i$i = HEAP32[$87>>2]|0;
       $96 = $$pre$i$i$i$i$i;
      }
      $95 = ($96|0)==($85|0);
      if ($95) {
       break;
      } else {
       $91 = $96;
      }
     }
     $$pre$i$i$i = HEAP32[$45>>2]|0;
     $99 = $$pre$i$i$i;
    }
    __ZdlPv($99);
    $$0 = $84;$$01 = $83;
   }
  }
  $100 = HEAP8[$20>>0]|0;
  $101 = $100 & 1;
  $102 = ($101<<24>>24)==(0);
  if ($102) {
   $$1 = $$0;$$12 = $$01;
  } else {
   $103 = (($this) + 20|0);
   $104 = HEAP32[$103>>2]|0;
   __ZdlPv($104);
   $$1 = $$0;$$12 = $$01;
  }
 }
 $105 = HEAP8[$this>>0]|0;
 $106 = $105 & 1;
 $107 = ($106<<24>>24)==(0);
 if ($107) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $108 = (($this) + 8|0);
 $109 = HEAP32[$108>>2]|0;
 __ZdlPv($109);
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN9ShaderLab13InitShaderLabEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[678928>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 HEAP8[678928>>0] = 1;
 $2 = (__Znaj(388)|0);
 HEAP32[$2>>2] = 6;
 $3 = (($2) + 4|0);
 $4 = (($2) + 12|0);
 $5 = (($2) + 16|0);
 $6 = (($2) + 64|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;
 HEAP32[$6>>2] = -1;
 HEAP32[$4>>2] = 0;
 HEAP32[$5>>2] = 0;
 HEAP32[$3>>2] = 0;
 $7 = (($2) + 8|0);
 HEAP32[$7>>2] = 5;
 $8 = (($2) + 40|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($2) + 36|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($2) + 44|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($2) + 48|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($2) + 52|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($2) + 56|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($2) + 60|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($2) + 68|0);
 $16 = (($2) + 76|0);
 $17 = (($2) + 80|0);
 $18 = (($2) + 128|0);
 ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;
 HEAP32[$18>>2] = -1;
 HEAP32[$16>>2] = 0;
 HEAP32[$17>>2] = 0;
 HEAP32[$15>>2] = 0;
 $19 = (($2) + 72|0);
 HEAP32[$19>>2] = 5;
 $20 = (($2) + 104|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($2) + 100|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($2) + 108|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($2) + 112|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($2) + 116|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($2) + 120|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($2) + 124|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($2) + 132|0);
 $28 = (($2) + 140|0);
 $29 = (($2) + 144|0);
 $30 = (($2) + 192|0);
 ;HEAP32[$28+0>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;HEAP32[$28+12>>2]=0|0;HEAP32[$28+16>>2]=0|0;HEAP32[$28+20>>2]=0|0;
 HEAP32[$30>>2] = -1;
 HEAP32[$28>>2] = 0;
 HEAP32[$29>>2] = 0;
 HEAP32[$27>>2] = 0;
 $31 = (($2) + 136|0);
 HEAP32[$31>>2] = 5;
 $32 = (($2) + 168|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $33 = (($2) + 164|0);
 HEAPF32[$33>>2] = Math_fround(1.0);
 $34 = (($2) + 172|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($2) + 176|0);
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($2) + 180|0);
 HEAPF32[$36>>2] = Math_fround(1.0);
 $37 = (($2) + 184|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($2) + 188|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($2) + 196|0);
 $40 = (($2) + 204|0);
 $41 = (($2) + 208|0);
 $42 = (($2) + 256|0);
 ;HEAP32[$40+0>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;HEAP32[$40+16>>2]=0|0;HEAP32[$40+20>>2]=0|0;
 HEAP32[$42>>2] = -1;
 HEAP32[$40>>2] = 0;
 HEAP32[$41>>2] = 0;
 HEAP32[$39>>2] = 0;
 $43 = (($2) + 200|0);
 HEAP32[$43>>2] = 5;
 $44 = (($2) + 232|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 $45 = (($2) + 228|0);
 HEAPF32[$45>>2] = Math_fround(1.0);
 $46 = (($2) + 236|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($2) + 240|0);
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (($2) + 244|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($2) + 248|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($2) + 252|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($2) + 268|0);
 $52 = (($2) + 272|0);
 $53 = (($2) + 320|0);
 ;HEAP32[$51+0>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;HEAP32[$51+12>>2]=0|0;HEAP32[$51+16>>2]=0|0;HEAP32[$51+20>>2]=0|0;
 HEAP32[$53>>2] = -1;
 HEAP32[$51>>2] = 0;
 HEAP32[$52>>2] = 0;
 $54 = (($2) + 296|0);
 HEAPF32[$54>>2] = Math_fround(1.0);
 $55 = (($2) + 292|0);
 HEAPF32[$55>>2] = Math_fround(1.0);
 $56 = (($2) + 300|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($2) + 304|0);
 HEAPF32[$57>>2] = Math_fround(1.0);
 $58 = (($2) + 308|0);
 HEAPF32[$58>>2] = Math_fround(1.0);
 $59 = (($2) + 312|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($2) + 316|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($2) + 332|0);
 $62 = (($2) + 336|0);
 $63 = (($2) + 384|0);
 ;HEAP32[$61+0>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;HEAP32[$61+12>>2]=0|0;HEAP32[$61+16>>2]=0|0;HEAP32[$61+20>>2]=0|0;
 HEAP32[$63>>2] = -1;
 HEAP32[$61>>2] = 0;
 HEAP32[$62>>2] = 0;
 $64 = (($2) + 360|0);
 HEAPF32[$64>>2] = Math_fround(1.0);
 $65 = (($2) + 356|0);
 HEAPF32[$65>>2] = Math_fround(1.0);
 $66 = (($2) + 364|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($2) + 368|0);
 HEAPF32[$67>>2] = Math_fround(1.0);
 $68 = (($2) + 372|0);
 HEAPF32[$68>>2] = Math_fround(1.0);
 $69 = (($2) + 376|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 $70 = (($2) + 380|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 HEAP32[678936>>2] = $3;
 HEAP32[$7>>2] = 0;
 HEAP32[$3>>2] = 0;
 $71 = (($2) + 72|0);
 HEAP32[$71>>2] = 1;
 $72 = (($2) + 68|0);
 HEAP32[$72>>2] = 1;
 $73 = (($2) + 136|0);
 HEAP32[$73>>2] = 2;
 $74 = (($2) + 132|0);
 HEAP32[$74>>2] = 2;
 $75 = (($2) + 200|0);
 HEAP32[$75>>2] = 3;
 $76 = (($2) + 196|0);
 HEAP32[$76>>2] = 3;
 $77 = (($2) + 264|0);
 HEAP32[$77>>2] = 4;
 $78 = (($2) + 260|0);
 HEAP32[$78>>2] = 4;
 $79 = (($2) + 328|0);
 HEAP32[$79>>2] = 5;
 $80 = (($2) + 324|0);
 HEAP32[$80>>2] = 5;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab14GetShaderTagIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($name) {
 $name = $name|0;
 var $$0 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0;
 var $9 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 40|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 24|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_26compare_string_insensitiveLb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($2,678912,$name);
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(((678912 + 4|0))|0);
 if (!($5)) {
  $6 = (($4) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP32[((678912 + 8|0))>>2]|0;
 $9 = HEAP8[$name>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $14 = (($name) + 1|0);
  $15 = $14;
 } else {
  $12 = (($name) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $15 = $13;
 }
 $16 = (_strlen(($15|0))|0);
 $17 = ($16>>>0)>(4294967279);
 if ($17) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $18 = ($16>>>0)<(11);
 if ($18) {
  $19 = $16 << 1;
  $20 = $19&255;
  HEAP8[$3>>0] = $20;
  $21 = (($3) + 1|0);
  $$pre$phiZ2D = $3;$32 = $20;$__p$0$i$i$i$i$i = $21;
 } else {
  $22 = (($16) + 16)|0;
  $23 = $22 & -16;
  $24 = (__Znwj($23)|0);
  $25 = (($3) + 8|0);
  HEAP32[$25>>2] = $24;
  $26 = $23 | 1;
  HEAP32[$3>>2] = $26;
  $27 = (($3) + 4|0);
  HEAP32[$27>>2] = $16;
  $28 = $26&255;
  $$pre$phiZ2D = $3;$32 = $28;$__p$0$i$i$i$i$i = $24;
 }
 _memcpy(($__p$0$i$i$i$i$i|0),($15|0),($16|0))|0;
 $29 = (($__p$0$i$i$i$i$i) + ($16)|0);
 HEAP8[$29>>0] = 0;
 $30 = (($3) + 12|0);
 HEAP32[$30>>2] = $8;
 $31 = $32 & 1;
 $33 = ($31<<24>>24)==(0);
 L16: do {
  if ($33) {
   ;HEAP32[$1+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
   label = 21;
  } else {
   $34 = (($3) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($3) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37>>>0)>(4294967279);
   do {
    if ($38) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      // unreachable;
     }
    } else {
     $41 = ($37>>>0)<(11);
     if ($41) {
      $42 = $37 << 1;
      $43 = $42&255;
      HEAP8[$1>>0] = $43;
      $44 = (($1) + 1|0);
      $__p$0$i$i$i$i$i$i$i$i = $44;
     } else {
      $45 = (($37) + 16)|0;
      $46 = $45 & -16;
      __THREW__ = 0;
      $47 = (invoke_ii(2988,($46|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      $50 = (($1) + 8|0);
      HEAP32[$50>>2] = $47;
      $51 = $46 | 1;
      HEAP32[$1>>2] = $51;
      $52 = (($1) + 4|0);
      HEAP32[$52>>2] = $37;
      $__p$0$i$i$i$i$i$i$i$i = $47;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i$i|0),($35|0),($37|0))|0;
     $53 = (($__p$0$i$i$i$i$i$i$i$i) + ($37)|0);
     HEAP8[$53>>0] = 0;
     label = 21;
     break L16;
    }
   } while(0);
   $73 = ___cxa_find_matching_catch()|0;
   $74 = tempRet0;
   $eh$lpad$body$index3Z2D = $74;$eh$lpad$body$indexZ2D = $73;
  }
 } while(0);
 do {
  if ((label|0) == 21) {
   $54 = (($1) + 12|0);
   HEAP32[$54>>2] = $8;
   __THREW__ = 0;
   invoke_viii(1946,($0|0),(678912|0),($1|0));
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if ($56) {
    $62 = ___cxa_find_matching_catch()|0;
    $63 = tempRet0;
    $64 = HEAP8[$1>>0]|0;
    $65 = $64 & 1;
    $66 = ($65<<24>>24)==(0);
    if ($66) {
     $eh$lpad$body$index3Z2D = $63;$eh$lpad$body$indexZ2D = $62;
     break;
    }
    $67 = (($1) + 8|0);
    $68 = HEAP32[$67>>2]|0;
    __ZdlPv($68);
    $eh$lpad$body$index3Z2D = $63;$eh$lpad$body$indexZ2D = $62;
    break;
   }
   $57 = HEAP8[$1>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if (!($59)) {
    $60 = (($1) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    __ZdlPv($61);
   }
   $69 = $32 & 1;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    $$0 = $8;
    STACKTOP = sp;return ($$0|0);
   }
   $71 = (($3) + 8|0);
   $72 = HEAP32[$71>>2]|0;
   __ZdlPv($72);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $75 = $32 & 1;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $77 = (($3) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 __ZdlPv($78);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
 return 0|0;
}
function __ZN9ShaderLab16GetShaderTagNameEi($agg$result,$id) {
 $agg$result = $agg$result|0;
 $id = $id|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[678912>>2]|0;
 $1 = ($0|0)==(((678912 + 4|0))|0);
 L1: do {
  if (!($1)) {
   $3 = $0;
   while(1) {
    $2 = (($3) + 28|0);
    $4 = HEAP32[$2>>2]|0;
    $5 = ($4|0)==($id|0);
    if ($5) {
     break;
    }
    $26 = (($3) + 4|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     $$01$i$i$i = $3;
     while(1) {
      $31 = (($$01$i$i$i) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = HEAP32[$32>>2]|0;
      $34 = ($33|0)==($$01$i$i$i|0);
      if ($34) {
       $$0$i$i$i = $32;
       break;
      } else {
       $$01$i$i$i = $32;
      }
     }
    } else {
     $$0$i$i$i$i = $27;
     while(1) {
      $29 = HEAP32[$$0$i$i$i$i>>2]|0;
      $30 = ($29|0)==(0|0);
      if ($30) {
       $$0$i$i$i = $$0$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i = $29;
      }
     }
    }
    $35 = ($$0$i$i$i|0)==(((678912 + 4|0))|0);
    if ($35) {
     break L1;
    } else {
     $3 = $$0$i$i$i;
    }
   }
   $6 = (($3) + 16|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = $7 & 1;
   $9 = ($8<<24>>24)==(0);
   if ($9) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$6+8>>2]|0;
    STACKTOP = sp;return;
   }
   $10 = (($3) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($3) + 20|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13>>>0)>(4294967279);
   if ($14) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $15 = ($13>>>0)<(11);
   if ($15) {
    $16 = $13 << 1;
    $17 = $16&255;
    HEAP8[$agg$result>>0] = $17;
    $18 = (($agg$result) + 1|0);
    $__p$0$i$i$i3 = $18;
   } else {
    $19 = (($13) + 16)|0;
    $20 = $19 & -16;
    $21 = (__Znwj($20)|0);
    $22 = (($agg$result) + 8|0);
    HEAP32[$22>>2] = $21;
    $23 = $20 | 1;
    HEAP32[$agg$result>>2] = $23;
    $24 = (($agg$result) + 4|0);
    HEAP32[$24>>2] = $13;
    $__p$0$i$i$i3 = $21;
   }
   _memcpy(($__p$0$i$i$i3|0),($11|0),($13|0))|0;
   $25 = (($__p$0$i$i$i3) + ($13)|0);
   HEAP8[$25>>0] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $36 = (__Znwj(16)|0);
 $37 = (($agg$result) + 8|0);
 HEAP32[$37>>2] = $36;
 HEAP32[$agg$result>>2] = 17;
 $38 = (($agg$result) + 4|0);
 HEAP32[$38>>2] = 13;
 dest=$36+0|0; src=678944+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $39 = (($36) + 13|0);
 HEAP8[$39>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab11shaderprops9GetTexEnvEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameE16TextureDimensionRNS0_16PropertyLocationE($props,$passContext,$name,$texDim,$outLocation) {
 $props = $props|0;
 $passContext = $passContext|0;
 $name = $name|0;
 $texDim = $texDim|0;
 $outLocation = $outLocation|0;
 var $$$i = 0, $$$i25 = 0, $$0 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i$i21 = 0, $$0$ph5$i$i$i$i33 = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i$i15 = 0, $$0$ph7$i$i$i$i27 = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i$i16 = 0, $$01$ph6$i$in$i$i$i28 = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i$i18 = 0, $$013$i$in$i$i$i30 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond3 = 0;
 var $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$name>>2]|0;
 $1 = ($0|0)!=(-1);
 $2 = ($0>>>0)>(1073741823);
 $$$i = $1 & $2;
 if ($$$i) {
  $3 = (__Z12GetGfxDevicev()|0);
  $4 = $0 & 1073741823;
  $5 = ((($3) + ($4<<6)|0) + 3748|0);
  HEAP32[$outLocation>>2] = 2;
  $6 = ((($3) + ($4<<6)|0) + 3756|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = HEAP32[$5>>2]|0;
   $10 = ($9|0)==($texDim|0);
   $11 = ($texDim|0)==(5);
   $or$cond = $10 | $11;
   if ($or$cond) {
    $$0 = $5;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $12 = (($props) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($props) + 48|0);
 $15 = ($13|0)==(0|0);
 do {
  if (!($15)) {
   $$0$ph7$i$i$i$i27 = $14;$$01$ph6$i$in$i$i$i28 = $13;
   L7: while(1) {
    $$013$i$in$i$i$i30 = $$01$ph6$i$in$i$i$i28;
    while(1) {
     $16 = (($$013$i$in$i$i$i30) + 16|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)<($0|0);
     if (!($18)) {
      break;
     }
     $21 = (($$013$i$in$i$i$i30) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(0|0);
     if ($23) {
      $$0$ph5$i$i$i$i33 = $$0$ph7$i$i$i$i27;
      break L7;
     } else {
      $$013$i$in$i$i$i30 = $22;
     }
    }
    $19 = HEAP32[$$013$i$in$i$i$i30>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($20) {
     $$0$ph5$i$i$i$i33 = $$013$i$in$i$i$i30;
     break;
    } else {
     $$0$ph7$i$i$i$i27 = $$013$i$in$i$i$i30;$$01$ph6$i$in$i$i$i28 = $19;
    }
   }
   $24 = ($$0$ph5$i$i$i$i33|0)==($14|0);
   if (!($24)) {
    $25 = (($$0$ph5$i$i$i$i33) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($0|0)<($26|0);
    if (!($27)) {
     $28 = (($$0$ph5$i$i$i$i33) + 20|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($29|0)==(0|0);
     if (!($30)) {
      HEAP32[$outLocation>>2] = 0;
      $31 = (($29) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($32|0)==(0);
      if (!($33)) {
       $34 = HEAP32[$29>>2]|0;
       $35 = ($34|0)==($texDim|0);
       $36 = ($texDim|0)==(5);
       $or$cond3 = $35 | $36;
       if ($or$cond3) {
        $$0 = $29;
        STACKTOP = sp;return ($$0|0);
       }
      }
      $37 = (($29) + 60|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38|0)!=(-1);
      $40 = ($38>>>0)>(1073741823);
      $$$i25 = $39 & $40;
      if ($$$i25) {
       $41 = (__Z12GetGfxDevicev()|0);
       $42 = HEAP32[$37>>2]|0;
       $43 = $42 & 1073741823;
       $44 = ((($41) + ($43<<6)|0) + 3748|0);
       HEAP32[$outLocation>>2] = 2;
       $45 = ((($41) + ($43<<6)|0) + 3756|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46|0)==(0);
       if ($47) {
        break;
       }
       $48 = HEAP32[$44>>2]|0;
       $49 = ($48|0)==($texDim|0);
       $50 = ($texDim|0)==(5);
       $or$cond5 = $49 | $50;
       if ($or$cond5) {
        $$0 = $44;
       } else {
        break;
       }
       STACKTOP = sp;return ($$0|0);
      }
      $51 = (($passContext) + 68|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (($passContext) + 68|0);
      $54 = ($52|0)==(0|0);
      if (!($54)) {
       $$0$ph7$i$i$i$i15 = $53;$$01$ph6$i$in$i$i$i16 = $52;
       L27: while(1) {
        $$013$i$in$i$i$i18 = $$01$ph6$i$in$i$i$i16;
        while(1) {
         $55 = (($$013$i$in$i$i$i18) + 16|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($56|0)<($38|0);
         if (!($57)) {
          break;
         }
         $60 = (($$013$i$in$i$i$i18) + 4|0);
         $61 = HEAP32[$60>>2]|0;
         $62 = ($61|0)==(0|0);
         if ($62) {
          $$0$ph5$i$i$i$i21 = $$0$ph7$i$i$i$i15;
          break L27;
         } else {
          $$013$i$in$i$i$i18 = $61;
         }
        }
        $58 = HEAP32[$$013$i$in$i$i$i18>>2]|0;
        $59 = ($58|0)==(0|0);
        if ($59) {
         $$0$ph5$i$i$i$i21 = $$013$i$in$i$i$i18;
         break;
        } else {
         $$0$ph7$i$i$i$i15 = $$013$i$in$i$i$i18;$$01$ph6$i$in$i$i$i16 = $58;
        }
       }
       $63 = ($$0$ph5$i$i$i$i21|0)==($53|0);
       if (!($63)) {
        $64 = (($$0$ph5$i$i$i$i21) + 16|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = ($38|0)<($65|0);
        if (!($66)) {
         $67 = (($$0$ph5$i$i$i$i21) + 20|0);
         $68 = HEAP32[$67>>2]|0;
         HEAP32[$outLocation>>2] = 1;
         $69 = ($68|0)==(0|0);
         if ($69) {
          break;
         }
         $70 = (($68) + 8|0);
         $71 = HEAP32[$70>>2]|0;
         $72 = ($71|0)==(0);
         if ($72) {
          break;
         }
         $73 = HEAP32[$68>>2]|0;
         $74 = ($73|0)==($texDim|0);
         $75 = ($texDim|0)==(5);
         $or$cond7 = $74 | $75;
         if ($or$cond7) {
          $$0 = $68;
         } else {
          break;
         }
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
      HEAP32[$outLocation>>2] = 1;
     }
    }
   }
  }
 } while(0);
 $76 = (($passContext) + 68|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($passContext) + 68|0);
 $79 = ($77|0)==(0|0);
 if ($79) {
  label = 35;
 } else {
  $$0$ph7$i$i$i$i = $78;$$01$ph6$i$in$i$i$i = $77;
  L42: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $80 = (($$013$i$in$i$i$i) + 16|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ($81|0)<($0|0);
    if (!($82)) {
     break;
    }
    $85 = (($$013$i$in$i$i$i) + 4|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==(0|0);
    if ($87) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L42;
    } else {
     $$013$i$in$i$i$i = $86;
    }
   }
   $83 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $84 = ($83|0)==(0|0);
   if ($84) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $83;
   }
  }
  $88 = ($$0$ph5$i$i$i$i|0)==($78|0);
  if ($88) {
   label = 35;
  } else {
   $89 = (($$0$ph5$i$i$i$i) + 16|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($0|0)<($90|0);
   if ($91) {
    label = 35;
   } else {
    $92 = (($$0$ph5$i$i$i$i) + 20|0);
    $93 = HEAP32[$92>>2]|0;
    HEAP32[$outLocation>>2] = 1;
    $94 = ($93|0)==(0|0);
    if (!($94)) {
     $95 = (($93) + 8|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = ($96|0)==(0);
     if (!($97)) {
      $98 = HEAP32[$93>>2]|0;
      $99 = ($98|0)==($texDim|0);
      $100 = ($texDim|0)==(5);
      $or$cond9 = $99 | $100;
      if ($or$cond9) {
       $$0 = $93;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 if ((label|0) == 35) {
  HEAP32[$outLocation>>2] = 1;
 }
 HEAP32[$outLocation>>2] = 4;
 $101 = HEAP32[678936>>2]|0;
 $102 = (($101) + ($texDim<<6)|0);
 $$0 = $102;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab11shaderprops13GetTexEnvInfoEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameER16TextureDimension($props,$passContext,$name,$outTexDim) {
 $props = $props|0;
 $passContext = $passContext|0;
 $name = $name|0;
 $outTexDim = $outTexDim|0;
 var $$$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i$i8 = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i$i2 = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i$i3 = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge = 0, $te$014 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$name>>2]|0;
 $1 = ($0|0)!=(-1);
 $2 = ($0>>>0)>(1073741823);
 $$$i = $1 & $2;
 do {
  if ($$$i) {
   $3 = (__Z12GetGfxDevicev()|0);
   $4 = $0 & 1073741823;
   $5 = ((($3) + ($4<<6)|0) + 3748|0);
   $te$014 = $5;
  } else {
   $6 = (($props) + 48|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($props) + 48|0);
   $9 = ($7|0)==(0|0);
   if (!($9)) {
    $$0$ph7$i$i$i$i2 = $8;$$01$ph6$i$in$i$i$i3 = $7;
    L4: while(1) {
     $$013$i$in$i$i$i5 = $$01$ph6$i$in$i$i$i3;
     while(1) {
      $10 = (($$013$i$in$i$i$i5) + 16|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ($11|0)<($0|0);
      if (!($12)) {
       break;
      }
      $15 = (($$013$i$in$i$i$i5) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(0|0);
      if ($17) {
       $$0$ph5$i$i$i$i8 = $$0$ph7$i$i$i$i2;
       break L4;
      } else {
       $$013$i$in$i$i$i5 = $16;
      }
     }
     $13 = HEAP32[$$013$i$in$i$i$i5>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      $$0$ph5$i$i$i$i8 = $$013$i$in$i$i$i5;
      break;
     } else {
      $$0$ph7$i$i$i$i2 = $$013$i$in$i$i$i5;$$01$ph6$i$in$i$i$i3 = $13;
     }
    }
    $18 = ($$0$ph5$i$i$i$i8|0)==($8|0);
    if (!($18)) {
     $19 = (($$0$ph5$i$i$i$i8) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($0|0)<($20|0);
     if (!($21)) {
      $22 = (($$0$ph5$i$i$i$i8) + 20|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ($23|0)==(0|0);
      if (!($24)) {
       $te$014 = $23;
       break;
      }
     }
    }
   }
   $25 = (($passContext) + 68|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($passContext) + 68|0);
   $28 = ($26|0)==(0|0);
   if ($28) {
    $storemerge = -1;
    HEAP32[$outTexDim>>2] = $storemerge;
    STACKTOP = sp;return;
   } else {
    $$0$ph7$i$i$i$i = $27;$$01$ph6$i$in$i$i$i = $26;
   }
   L16: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $29 = (($$013$i$in$i$i$i) + 16|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)<($0|0);
     if (!($31)) {
      break;
     }
     $34 = (($$013$i$in$i$i$i) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($35|0)==(0|0);
     if ($36) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L16;
     } else {
      $$013$i$in$i$i$i = $35;
     }
    }
    $32 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $32;
    }
   }
   $37 = ($$0$ph5$i$i$i$i|0)==($27|0);
   if ($37) {
    $storemerge = -1;
    HEAP32[$outTexDim>>2] = $storemerge;
    STACKTOP = sp;return;
   }
   $38 = (($$0$ph5$i$i$i$i) + 16|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($0|0)<($39|0);
   if ($40) {
    $storemerge = -1;
    HEAP32[$outTexDim>>2] = $storemerge;
    STACKTOP = sp;return;
   }
   $41 = (($$0$ph5$i$i$i$i) + 20|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if ($43) {
    $storemerge = -1;
    HEAP32[$outTexDim>>2] = $storemerge;
    STACKTOP = sp;return;
   } else {
    $te$014 = $42;
   }
  }
 } while(0);
 $44 = HEAP32[$te$014>>2]|0;
 $storemerge = $44;
 HEAP32[$outTexDim>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$name,$outLocation) {
 $props = $props|0;
 $passContext = $passContext|0;
 $name = $name|0;
 $outLocation = $outLocation|0;
 var $$0 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i$i8 = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i$i2 = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i$i3 = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$name>>2]|0;
 $1 = ($0|0)==(-1);
 if ($1) {
  HEAP32[$outLocation>>2] = 3;
  $$0 = 678960;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($0>>>0)>(1073741823);
 if ($2) {
  HEAP32[$outLocation>>2] = 2;
  $3 = (__Z12GetGfxDevicev()|0);
  $4 = $0 & 1073741823;
  $5 = ((($3) + ($4<<4)|0) + 4|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($props) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($props) + 12|0);
 $9 = ($7|0)==(0|0);
 if (!($9)) {
  $$0$ph7$i$i$i$i2 = $8;$$01$ph6$i$in$i$i$i3 = $7;
  L10: while(1) {
   $$013$i$in$i$i$i5 = $$01$ph6$i$in$i$i$i3;
   while(1) {
    $10 = (($$013$i$in$i$i$i5) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)<($0|0);
    if (!($12)) {
     break;
    }
    $15 = (($$013$i$in$i$i$i5) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$0$ph5$i$i$i$i8 = $$0$ph7$i$i$i$i2;
     break L10;
    } else {
     $$013$i$in$i$i$i5 = $16;
    }
   }
   $13 = HEAP32[$$013$i$in$i$i$i5>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$0$ph5$i$i$i$i8 = $$013$i$in$i$i$i5;
    break;
   } else {
    $$0$ph7$i$i$i$i2 = $$013$i$in$i$i$i5;$$01$ph6$i$in$i$i$i3 = $13;
   }
  }
  $18 = ($$0$ph5$i$i$i$i8|0)==($8|0);
  if (!($18)) {
   $19 = (($$0$ph5$i$i$i$i8) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($0|0)<($20|0);
   if (!($21)) {
    $22 = (($$0$ph5$i$i$i$i8) + 20|0);
    HEAP32[$outLocation>>2] = 0;
    $$0 = $22;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $23 = (($passContext) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($passContext) + 32|0);
 $26 = ($24|0)==(0|0);
 if (!($26)) {
  $$0$ph7$i$i$i$i = $25;$$01$ph6$i$in$i$i$i = $24;
  L22: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $27 = (($$013$i$in$i$i$i) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)<($0|0);
    if (!($29)) {
     break;
    }
    $32 = (($$013$i$in$i$i$i) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L22;
    } else {
     $$013$i$in$i$i$i = $33;
    }
   }
   $30 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $30;
   }
  }
  $35 = ($$0$ph5$i$i$i$i|0)==($25|0);
  if (!($35)) {
   $36 = (($$0$ph5$i$i$i$i) + 16|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($0|0)<($37|0);
   if (!($38)) {
    $39 = (($$0$ph5$i$i$i$i) + 20|0);
    HEAP32[$outLocation>>2] = 1;
    $$0 = $39;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$outLocation>>2] = 4;
 $$0 = 678960;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab11shaderprops9GetVectorEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$name,$outLocation) {
 $props = $props|0;
 $passContext = $passContext|0;
 $name = $name|0;
 $outLocation = $outLocation|0;
 var $$0 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i$i8 = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i$i2 = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i$i3 = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$name>>2]|0;
 $1 = ($0|0)==(-1);
 if ($1) {
  HEAP32[$outLocation>>2] = 3;
  $$0 = 678872;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($0>>>0)>(1073741823);
 if ($2) {
  HEAP32[$outLocation>>2] = 2;
  $3 = (__Z12GetGfxDevicev()|0);
  $4 = $0 & 1073741823;
  $5 = ((($3) + ($4<<4)|0) + 4|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($props) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($props) + 24|0);
 $9 = ($7|0)==(0|0);
 if (!($9)) {
  $$0$ph7$i$i$i$i2 = $8;$$01$ph6$i$in$i$i$i3 = $7;
  L10: while(1) {
   $$013$i$in$i$i$i5 = $$01$ph6$i$in$i$i$i3;
   while(1) {
    $10 = (($$013$i$in$i$i$i5) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)<($0|0);
    if (!($12)) {
     break;
    }
    $15 = (($$013$i$in$i$i$i5) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$0$ph5$i$i$i$i8 = $$0$ph7$i$i$i$i2;
     break L10;
    } else {
     $$013$i$in$i$i$i5 = $16;
    }
   }
   $13 = HEAP32[$$013$i$in$i$i$i5>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$0$ph5$i$i$i$i8 = $$013$i$in$i$i$i5;
    break;
   } else {
    $$0$ph7$i$i$i$i2 = $$013$i$in$i$i$i5;$$01$ph6$i$in$i$i$i3 = $13;
   }
  }
  $18 = ($$0$ph5$i$i$i$i8|0)==($8|0);
  if (!($18)) {
   $19 = (($$0$ph5$i$i$i$i8) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($0|0)<($20|0);
   if (!($21)) {
    $22 = (($$0$ph5$i$i$i$i8) + 20|0);
    HEAP32[$outLocation>>2] = 0;
    $$0 = $22;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $23 = (($passContext) + 44|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($passContext) + 44|0);
 $26 = ($24|0)==(0|0);
 if (!($26)) {
  $$0$ph7$i$i$i$i = $25;$$01$ph6$i$in$i$i$i = $24;
  L22: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $27 = (($$013$i$in$i$i$i) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)<($0|0);
    if (!($29)) {
     break;
    }
    $32 = (($$013$i$in$i$i$i) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L22;
    } else {
     $$013$i$in$i$i$i = $33;
    }
   }
   $30 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $30;
   }
  }
  $35 = ($$0$ph5$i$i$i$i|0)==($25|0);
  if (!($35)) {
   $36 = (($$0$ph5$i$i$i$i) + 16|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($0|0)<($37|0);
   if (!($38)) {
    $39 = (($$0$ph5$i$i$i$i) + 20|0);
    HEAP32[$outLocation>>2] = 1;
    $$0 = $39;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$outLocation>>2] = 4;
 $$0 = 678872;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab11shaderprops9GetMatrixEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$name,$outLocation) {
 $props = $props|0;
 $passContext = $passContext|0;
 $name = $name|0;
 $outLocation = $outLocation|0;
 var $$0 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i$i8 = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i$i2 = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i$i3 = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$name>>2]|0;
 $1 = ($0|0)==(-1);
 if ($1) {
  HEAP32[$outLocation>>2] = 3;
  $$0 = 616552;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($0>>>0)>(1073741823);
 if ($2) {
  HEAP32[$outLocation>>2] = 2;
  $3 = (__Z12GetGfxDevicev()|0);
  $4 = $0 & 1073741823;
  $5 = ((($3) + ($4<<6)|0) + 2724|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($props) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($props) + 36|0);
 $9 = ($7|0)==(0|0);
 if (!($9)) {
  $$0$ph7$i$i$i$i2 = $8;$$01$ph6$i$in$i$i$i3 = $7;
  L10: while(1) {
   $$013$i$in$i$i$i5 = $$01$ph6$i$in$i$i$i3;
   while(1) {
    $10 = (($$013$i$in$i$i$i5) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)<($0|0);
    if (!($12)) {
     break;
    }
    $15 = (($$013$i$in$i$i$i5) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$0$ph5$i$i$i$i8 = $$0$ph7$i$i$i$i2;
     break L10;
    } else {
     $$013$i$in$i$i$i5 = $16;
    }
   }
   $13 = HEAP32[$$013$i$in$i$i$i5>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $$0$ph5$i$i$i$i8 = $$013$i$in$i$i$i5;
    break;
   } else {
    $$0$ph7$i$i$i$i2 = $$013$i$in$i$i$i5;$$01$ph6$i$in$i$i$i3 = $13;
   }
  }
  $18 = ($$0$ph5$i$i$i$i8|0)==($8|0);
  if (!($18)) {
   $19 = (($$0$ph5$i$i$i$i8) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($0|0)<($20|0);
   if (!($21)) {
    $22 = (($$0$ph5$i$i$i$i8) + 20|0);
    HEAP32[$outLocation>>2] = 0;
    $$0 = $22;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $23 = (($passContext) + 56|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($passContext) + 56|0);
 $26 = ($24|0)==(0|0);
 if (!($26)) {
  $$0$ph7$i$i$i$i = $25;$$01$ph6$i$in$i$i$i = $24;
  L22: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $27 = (($$013$i$in$i$i$i) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)<($0|0);
    if (!($29)) {
     break;
    }
    $32 = (($$013$i$in$i$i$i) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L22;
    } else {
     $$013$i$in$i$i$i = $33;
    }
   }
   $30 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $30;
   }
  }
  $35 = ($$0$ph5$i$i$i$i|0)==($25|0);
  if (!($35)) {
   $36 = (($$0$ph5$i$i$i$i) + 16|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($0|0)<($37|0);
   if (!($38)) {
    $39 = (($$0$ph5$i$i$i$i) + 20|0);
    HEAP32[$outLocation>>2] = 1;
    $$0 = $39;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$outLocation>>2] = 4;
 $$0 = 616552;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab11shaderprops16GetComputeBufferEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$name,$outLocation) {
 $props = $props|0;
 $passContext = $passContext|0;
 $name = $name|0;
 $outLocation = $outLocation|0;
 var $$$i = 0, $$$i10 = 0, $$0 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i$i8 = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i$i2 = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i$i3 = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$name>>2]|0;
 $1 = ($0|0)==(-1);
 if ($1) {
  HEAP32[$outLocation>>2] = 3;
  $$0 = 678888;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($props) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($props) + 72|0);
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  $$0$ph7$i$i$i$i2 = $4;$$01$ph6$i$in$i$i$i3 = $3;
  L6: while(1) {
   $$013$i$in$i$i$i5 = $$01$ph6$i$in$i$i$i3;
   while(1) {
    $6 = (($$013$i$in$i$i$i5) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)<($0|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i$i5) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i$i8 = $$0$ph7$i$i$i$i2;
     break L6;
    } else {
     $$013$i$in$i$i$i5 = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i$i5>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i$i8 = $$013$i$in$i$i$i5;
    break;
   } else {
    $$0$ph7$i$i$i$i2 = $$013$i$in$i$i$i5;$$01$ph6$i$in$i$i$i3 = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i$i8|0)==($4|0);
  if (!($14)) {
   $15 = (($$0$ph5$i$i$i$i8) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($0|0)<($16|0);
   $18 = (($$0$ph5$i$i$i$i8) + 20|0);
   $$$i10 = $17 ? 0 : $18;
   if (!($17)) {
    $19 = HEAP32[$$$i10>>2]|0;
    $20 = ($19|0)==(0);
    if (!($20)) {
     HEAP32[$outLocation>>2] = 0;
     $$0 = $$$i10;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $21 = (($passContext) + 92|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($passContext) + 92|0);
 $24 = ($22|0)==(0|0);
 if (!($24)) {
  $$0$ph7$i$i$i$i = $23;$$01$ph6$i$in$i$i$i = $22;
  L19: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $25 = (($$013$i$in$i$i$i) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)<($0|0);
    if (!($27)) {
     break;
    }
    $30 = (($$013$i$in$i$i$i) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L19;
    } else {
     $$013$i$in$i$i$i = $31;
    }
   }
   $28 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $29 = ($28|0)==(0|0);
   if ($29) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $28;
   }
  }
  $33 = ($$0$ph5$i$i$i$i|0)==($23|0);
  if (!($33)) {
   $34 = (($$0$ph5$i$i$i$i) + 16|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($0|0)<($35|0);
   $37 = (($$0$ph5$i$i$i$i) + 20|0);
   $$$i = $36 ? 0 : $37;
   if (!($36)) {
    $38 = HEAP32[$$$i>>2]|0;
    $39 = ($38|0)==(0);
    if (!($39)) {
     HEAP32[$outLocation>>2] = 1;
     $$0 = $$$i;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 HEAP32[$outLocation>>2] = 4;
 $$0 = 678888;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_26compare_string_insensitiveLb1EEENS5_IS8_EEE15__insert_uniqueERKS8_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_26compare_string_insensitiveLb1EEENS5_IS8_EEE12__find_equalIS8_EERPNS_16__tree_node_baseIPvEESJ_RKT_($this,$__parent,$__v)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $47 = 0;$__r$0 = $1;
  HEAP32[$agg$result>>2] = $__r$0;
  $46 = (($agg$result) + 4|0);
  HEAP8[$46>>0] = $47;
  STACKTOP = sp;return;
 }
 $3 = (__Znwj(32)|0);
 $4 = (($3) + 16|0);
 $5 = HEAP8[$__v>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 L4: do {
  if ($7) {
   ;HEAP32[$4+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__v+8>>2]|0;
  } else {
   $8 = (($__v) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($__v) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11>>>0)>(4294967279);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    } else {
     $15 = ($11>>>0)<(11);
     if ($15) {
      $16 = $11 << 1;
      $17 = $16&255;
      HEAP8[$4>>0] = $17;
      $18 = (($3) + 17|0);
      $__p$0$i$i$i$i$i$i$i$i$i = $18;
     } else {
      $19 = (($11) + 16)|0;
      $20 = $19 & -16;
      __THREW__ = 0;
      $21 = (invoke_ii(2988,($20|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      $24 = (($3) + 24|0);
      HEAP32[$24>>2] = $21;
      $25 = $20 | 1;
      HEAP32[$4>>2] = $25;
      $26 = (($3) + 20|0);
      HEAP32[$26>>2] = $11;
      $__p$0$i$i$i$i$i$i$i$i$i = $21;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($9|0),($11|0))|0;
     $27 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($11)|0);
     HEAP8[$27>>0] = 0;
     break L4;
    }
   } while(0);
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = ($3|0)==(0|0);
   if ($30) {
    ___resumeException($28|0);
    // unreachable;
   }
   __ZdlPv($3);
   ___resumeException($28|0);
   // unreachable;
  }
 } while(0);
 $31 = (($3) + 28|0);
 $32 = (($__v) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$31>>2] = $33;
 $34 = HEAP32[$__parent>>2]|0;
 HEAP32[$3>>2] = 0;
 $35 = (($3) + 4|0);
 HEAP32[$35>>2] = 0;
 $36 = (($3) + 8|0);
 HEAP32[$36>>2] = $34;
 HEAP32[$0>>2] = $3;
 $37 = HEAP32[$this>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  $42 = $3;
 } else {
  HEAP32[$this>>2] = $38;
  $$pre$i = HEAP32[$0>>2]|0;
  $42 = $$pre$i;
 }
 $40 = (($this) + 4|0);
 $41 = HEAP32[$40>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($41,$42);
 $43 = (($this) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 1)|0;
 HEAP32[$43>>2] = $45;
 $47 = 1;$__r$0 = $3;
 HEAP32[$agg$result>>2] = $__r$0;
 $46 = (($agg$result) + 4|0);
 HEAP8[$46>>0] = $47;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_26compare_string_insensitiveLb1EEENS5_IS8_EEE12__find_equalIS8_EERPNS_16__tree_node_baseIPvEESJ_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__nd$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $39 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $39;
  $$0 = $39;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__v) + 1|0);
 $4 = (($__v) + 8|0);
 $__nd$0$in = $1;
 while(1) {
  $5 = (($__nd$0$in) + 16|0);
  $6 = HEAP8[$__v>>0]|0;
  $7 = $6 & 1;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $16 = $3;
  } else {
   $9 = HEAP32[$4>>2]|0;
   $16 = $9;
  }
  $10 = HEAP8[$5>>0]|0;
  $11 = $10 & 1;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $15 = (($5) + 1|0);
   $17 = $15;
  } else {
   $13 = (($__nd$0$in) + 24|0);
   $14 = HEAP32[$13>>2]|0;
   $17 = $14;
  }
  $18 = (__Z7StrICmpPKcS0_($16,$17)|0);
  $19 = ($18|0)<(0);
  if ($19) {
   $20 = HEAP32[$__nd$0$in>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    label = 10;
    break;
   } else {
    $__nd$0$in = $20;
    continue;
   }
  }
  $22 = HEAP8[$5>>0]|0;
  $23 = $22 & 1;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   $27 = (($5) + 1|0);
   $32 = $27;
  } else {
   $25 = (($__nd$0$in) + 24|0);
   $26 = HEAP32[$25>>2]|0;
   $32 = $26;
  }
  $28 = HEAP8[$__v>>0]|0;
  $29 = $28 & 1;
  $30 = ($29<<24>>24)==(0);
  if ($30) {
   $33 = $3;
  } else {
   $31 = HEAP32[$4>>2]|0;
   $33 = $31;
  }
  $34 = (__Z7StrICmpPKcS0_($32,$33)|0);
  $35 = ($34|0)<(0);
  if (!($35)) {
   label = 19;
   break;
  }
  $36 = (($__nd$0$in) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   label = 18;
   break;
  } else {
   $__nd$0$in = $37;
  }
 }
 if ((label|0) == 10) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 18) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $36;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 19) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_26compare_string_insensitiveLb1EEENS5_IS8_EEE4findIS7_EENS_15__tree_iteratorIS8_PNS_11__tree_nodeIS8_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$ph5$i = 0, $$0$ph7$i = 0, $$01$ph6$i$in = 0, $$013$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = (($__v) + 1|0);
  $5 = (($__v) + 8|0);
  $$0$ph7$i = $2;$$01$ph6$i$in = $1;
  L3: while(1) {
   $$013$i$in = $$01$ph6$i$in;
   while(1) {
    $6 = (($$013$i$in) + 16|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = $7 & 1;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $12 = (($6) + 1|0);
     $17 = $12;
    } else {
     $10 = (($$013$i$in) + 24|0);
     $11 = HEAP32[$10>>2]|0;
     $17 = $11;
    }
    $13 = HEAP8[$__v>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     $18 = $4;
    } else {
     $16 = HEAP32[$5>>2]|0;
     $18 = $16;
    }
    $19 = (__Z7StrICmpPKcS0_($17,$18)|0);
    $20 = ($19|0)<(0);
    if (!($20)) {
     break;
    }
    $23 = (($$013$i$in) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0|0);
    if ($25) {
     $$0$ph5$i = $$0$ph7$i;
     break L3;
    } else {
     $$013$i$in = $24;
    }
   }
   $21 = HEAP32[$$013$i$in>>2]|0;
   $22 = ($21|0)==(0|0);
   if ($22) {
    $$0$ph5$i = $$013$i$in;
    break;
   } else {
    $$0$ph7$i = $$013$i$in;$$01$ph6$i$in = $21;
   }
  }
  $26 = ($$0$ph5$i|0)==($2|0);
  if (!($26)) {
   $27 = (($$0$ph5$i) + 16|0);
   $28 = HEAP8[$__v>>0]|0;
   $29 = $28 & 1;
   $30 = ($29<<24>>24)==(0);
   if ($30) {
    $38 = $4;
   } else {
    $31 = HEAP32[$5>>2]|0;
    $38 = $31;
   }
   $32 = HEAP8[$27>>0]|0;
   $33 = $32 & 1;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    $37 = (($27) + 1|0);
    $39 = $37;
   } else {
    $35 = (($$0$ph5$i) + 24|0);
    $36 = HEAP32[$35>>2]|0;
    $39 = $36;
   }
   $40 = (__Z7StrICmpPKcS0_($38,$39)|0);
   $41 = ($40|0)<(0);
   if (!($41)) {
    HEAP32[$agg$result>>2] = $$0$ph5$i;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN12ShaderErrors14AddShaderErrorERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEibb($this,$err,$line,$warning,$programError) {
 $this = $this|0;
 $err = $err|0;
 $line = $line|0;
 $warning = $warning|0;
 $programError = $programError|0;
 var $$0 = 0, $$01 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy5 = sp + 96|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 16|0;
 $4 = sp + 24|0;
 $5 = sp + 72|0;
 $6 = sp + 84|0;
 HEAP8[$5>>0] = 0;
 $7 = (($5) + 1|0);
 HEAP8[$7>>0] = 0;
 HEAP8[$6>>0] = 0;
 $8 = (($6) + 1|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiiii(30,($4|0),($err|0),($5|0),($6|0),-1,($line|0),($warning|0),($programError|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if ($10) {
   $52 = ___cxa_find_matching_catch()|0;
   $53 = tempRet0;
   $$0 = $53;$$01 = $52;
  } else {
   __THREW__ = 0;
   invoke_viii(1947,($3|0),($this|0),($4|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    $54 = ___cxa_find_matching_catch()|0;
    $55 = tempRet0;
    $56 = (($4) + 24|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = $57 & 1;
    $59 = ($58<<24>>24)==(0);
    if (!($59)) {
     $60 = (($4) + 32|0);
     $61 = HEAP32[$60>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($61|0),($$byval_copy5|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      $64 = ___cxa_find_matching_catch()|0;
      $65 = tempRet0;
      ___cxa_call_unexpected(($64|0));
      // unreachable;
     }
    }
    $66 = (($4) + 12|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67 & 1;
    $69 = ($68<<24>>24)==(0);
    if (!($69)) {
     $70 = (($4) + 20|0);
     $71 = HEAP32[$70>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($71|0),($$byval_copy5|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      $74 = ___cxa_find_matching_catch()|0;
      $75 = tempRet0;
      ___cxa_call_unexpected(($74|0));
      // unreachable;
     }
    }
    $76 = HEAP8[$4>>0]|0;
    $77 = $76 & 1;
    $78 = ($77<<24>>24)==(0);
    if ($78) {
     $$0 = $55;$$01 = $54;
     break;
    }
    $79 = (($4) + 8|0);
    $80 = HEAP32[$79>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($80|0),($$byval_copy5|0));
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if (!($82)) {
     $$0 = $55;$$01 = $54;
     break;
    }
    $83 = ___cxa_find_matching_catch()|0;
    $84 = tempRet0;
    ___cxa_call_unexpected(($83|0));
    // unreachable;
   }
   $13 = (($4) + 24|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 1;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    $17 = (($4) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($18|0),($$byval_copy5|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $21 = ___cxa_find_matching_catch()|0;
     $22 = tempRet0;
     ___cxa_call_unexpected(($21|0));
     // unreachable;
    }
   }
   $23 = (($4) + 12|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24 & 1;
   $26 = ($25<<24>>24)==(0);
   if (!($26)) {
    $27 = (($4) + 20|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($28|0),($$byval_copy5|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    }
   }
   $33 = HEAP8[$4>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if (!($35)) {
    $36 = (($4) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($37|0),($$byval_copy5|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     $40 = ___cxa_find_matching_catch()|0;
     $41 = tempRet0;
     ___cxa_call_unexpected(($40|0));
     // unreachable;
    }
   }
   $42 = HEAP8[$6>>0]|0;
   $43 = $42 & 1;
   $44 = ($43<<24>>24)==(0);
   if (!($44)) {
    $45 = (($6) + 8|0);
    $46 = HEAP32[$45>>2]|0;
    __ZdlPv($46);
   }
   $47 = HEAP8[$5>>0]|0;
   $48 = $47 & 1;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    STACKTOP = sp;return;
   }
   $50 = (($5) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   __ZdlPv($51);
   STACKTOP = sp;return;
  }
 } while(0);
 $85 = HEAP8[$6>>0]|0;
 $86 = $85 & 1;
 $87 = ($86<<24>>24)==(0);
 if (!($87)) {
  $88 = (($6) + 8|0);
  $89 = HEAP32[$88>>2]|0;
  __ZdlPv($89);
 }
 $90 = HEAP8[$5>>0]|0;
 $91 = $90 & 1;
 $92 = ($91<<24>>24)==(0);
 if ($92) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $93 = (($5) + 8|0);
 $94 = HEAP32[$93>>2]|0;
 __ZdlPv($94);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN12ShaderErrors21ClearNonProgramErrorsEv($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i2 = 0, $$01$i$i = 0, $$01$i$i$i = 0, $$be$in = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($this) + 4|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $6 = $2;
 while(1) {
  $5 = (($6) + 61|0);
  $7 = HEAP8[$5>>0]|0;
  $8 = ($7<<24>>24)==(0);
  $9 = (($6) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  L6: do {
   if ($8) {
    if ($11) {
     $$01$i$i$i = $6;
     while(1) {
      $14 = (($$01$i$i$i) + 8|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==($$01$i$i$i|0);
      if ($17) {
       $$0$i$i$i2 = $15;
       break;
      } else {
       $$01$i$i$i = $15;
      }
     }
    } else {
     $$0$i$i$i$i = $10;
     while(1) {
      $12 = HEAP32[$$0$i$i$i$i>>2]|0;
      $13 = ($12|0)==(0|0);
      if ($13) {
       $$0$i$i$i2 = $$0$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i = $12;
      }
     }
    }
    HEAP32[$0>>2] = $6;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE5eraseENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEE($1,$this,$$byval_copy);
    $$be$in = $$0$i$i$i2;
   } else {
    if (!($11)) {
     $$0$i$i$i = $10;
     while(1) {
      $18 = HEAP32[$$0$i$i$i>>2]|0;
      $19 = ($18|0)==(0|0);
      if ($19) {
       $$be$in = $$0$i$i$i;
       break L6;
      } else {
       $$0$i$i$i = $18;
      }
     }
    }
    $$01$i$i = $6;
    while(1) {
     $20 = (($$01$i$i) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==($$01$i$i|0);
     if ($23) {
      $$be$in = $21;
      break;
     } else {
      $$01$i$i = $21;
     }
    }
   }
  } while(0);
  $24 = ($$be$in|0)==($3|0);
  if ($24) {
   break;
  } else {
   $6 = $$be$in;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK12ShaderErrors9HasErrorsEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = ($0|0)==($1|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $4 = $0;
 }
 while(1) {
  $3 = (($4) + 60|0);
  $5 = HEAP8[$3>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $$0 = 1;
   label = 8;
   break;
  }
  $7 = (($4) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $$01$i$i = $4;
   while(1) {
    $12 = (($$01$i$i) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($$01$i$i|0);
    if ($15) {
     $$0$i$i = $13;
     break;
    } else {
     $$01$i$i = $13;
    }
   }
  } else {
   $$0$i$i$i = $8;
   while(1) {
    $10 = HEAP32[$$0$i$i$i>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $10;
    }
   }
  }
  $16 = ($$0$i$i|0)==($1|0);
  if ($16) {
   $$0 = 0;
   label = 8;
   break;
  } else {
   $4 = $$0$i$i;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE5eraseENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEE($agg$result,$this,$__p) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__p = $__p|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$__p>>2]|0;
 HEAP32[$agg$result>>2] = $3;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$01$i$i = $3;
  while(1) {
   $9 = (($$01$i$i) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==($$01$i$i|0);
   if ($12) {
    $$0$i$i = $10;
    break;
   } else {
    $$01$i$i = $10;
   }
  }
 } else {
  $$0$i$i$i = $5;
  while(1) {
   $7 = HEAP32[$$0$i$i$i>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $$0$i$i = $$0$i$i$i;
    break;
   } else {
    $$0$i$i$i = $7;
   }
  }
 }
 HEAP32[$agg$result>>2] = $$0$i$i;
 $13 = HEAP32[$this>>2]|0;
 $14 = ($13|0)==($3|0);
 if ($14) {
  HEAP32[$this>>2] = $$0$i$i;
 }
 $15 = (($this) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 $18 = (($3) + 16|0);
 $19 = (($3) + 40|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if (!($22)) {
  $23 = (($3) + 48|0);
  $24 = HEAP32[$23>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($24|0),($$byval_copy2|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   ___cxa_call_unexpected(($27|0));
   // unreachable;
  }
 }
 $29 = (($3) + 28|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = $30 & 1;
 $32 = ($31<<24>>24)==(0);
 if (!($32)) {
  $33 = (($3) + 36|0);
  $34 = HEAP32[$33>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($34|0),($$byval_copy2|0));
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if ($36) {
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   ___cxa_call_unexpected(($37|0));
   // unreachable;
  }
 }
 $39 = HEAP8[$18>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  $48 = (($this) + 4|0);
  $49 = HEAP32[$48>>2]|0;
  __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($49,$3);
  __ZdlPv($3);
  STACKTOP = sp;return;
 }
 $42 = (($3) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($43|0),($$byval_copy2|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  $48 = (($this) + 4|0);
  $49 = HEAP32[$48>>2]|0;
  __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($49,$3);
  __ZdlPv($3);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $11 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $11;
   $$0$i = $11;$23 = $11;
  } else {
   $__nd$0$in$i = $1;
   while(1) {
    $3 = (($__nd$0$in$i) + 16|0);
    $4 = (__ZNK12ShaderErrors11ShaderErrorltERKS0_($__v,$3)|0);
    if ($4) {
     $5 = HEAP32[$__nd$0$in$i>>2]|0;
     $6 = ($5|0)==(0|0);
     if ($6) {
      label = 4;
      break;
     } else {
      $__nd$0$in$i = $5;
      continue;
     }
    }
    $7 = (__ZNK12ShaderErrors11ShaderErrorltERKS0_($3,$__v)|0);
    if (!($7)) {
     label = 8;
     break;
    }
    $8 = (($__nd$0$in$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     label = 7;
     break;
    } else {
     $__nd$0$in$i = $9;
    }
   }
   if ((label|0) == 4) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 7) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $8;$23 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$23 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $12 = HEAP32[$$0$i>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $33 = 0;$__r$0 = $12;
  HEAP32[$agg$result>>2] = $__r$0;
  $32 = (($agg$result) + 4|0);
  HEAP8[$32>>0] = $33;
  STACKTOP = sp;return;
 }
 $14 = (__Znwj(64)|0);
 $15 = (($14) + 16|0);
 __THREW__ = 0;
 invoke_vii(3264,($15|0),($__v|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $20 = ($14|0)==(0|0);
  if ($20) {
   ___resumeException($18|0);
   // unreachable;
  }
  __ZdlPv($14);
  ___resumeException($18|0);
  // unreachable;
 } else {
  HEAP32[$14>>2] = 0;
  $21 = (($14) + 4|0);
  HEAP32[$21>>2] = 0;
  $22 = (($14) + 8|0);
  HEAP32[$22>>2] = $23;
  HEAP32[$$0$i>>2] = $14;
  $24 = HEAP32[$this>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   $28 = $14;
  } else {
   HEAP32[$this>>2] = $25;
   $$pre$i = HEAP32[$$0$i>>2]|0;
   $28 = $$pre$i;
  }
  $27 = HEAP32[$0>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($27,$28);
  $29 = (($this) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  $33 = 1;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $32 = (($agg$result) + 4|0);
  HEAP8[$32>>0] = $33;
  STACKTOP = sp;return;
 }
}
function __ZN12ShaderErrors11ShaderErrorC2ERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i12 = 0, $__p$0$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = sp + 8|0;
 $4 = sp + 12|0;
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $12 = (($0) + 1|0);
  $13 = $5&255;
  $14 = $13 >>> 1;
  $16 = $14;$27 = $12;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $16 = $11;$27 = $9;
 }
 $15 = ($16>>>0)>(2147483631);
 if ($15) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $17 = ($16>>>0)<(11);
 if ($17) {
  $18 = $16 << 1;
  $19 = $18&255;
  HEAP8[$this>>0] = $19;
  $20 = (($this) + 1|0);
  $__p$0$i$i$i$i = $20;
 } else {
  $21 = (($16) + 16)|0;
  $22 = $21 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,16,$$byval_copy4,0,678968,79)|0);
  $24 = (($this) + 8|0);
  HEAP32[$24>>2] = $23;
  $25 = $22 | 1;
  HEAP32[$this>>2] = $25;
  $26 = (($this) + 4|0);
  HEAP32[$26>>2] = $16;
  $__p$0$i$i$i$i = $23;
 }
 _memcpy(($__p$0$i$i$i$i|0),($27|0),($16|0))|0;
 $28 = (($__p$0$i$i$i$i) + ($16)|0);
 HEAP8[$28>>0] = 0;
 $29 = (($this) + 12|0);
 $30 = (($0) + 12|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31 & 1;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  $38 = (($30) + 1|0);
  $39 = $31&255;
  $40 = $39 >>> 1;
  $42 = $40;$57 = $38;
 } else {
  $34 = (($0) + 20|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($0) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  $42 = $37;$57 = $35;
 }
 $41 = ($42>>>0)>(2147483631);
 do {
  if ($41) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    label = 30;
   } else {
    // unreachable;
   }
  } else {
   $45 = ($42>>>0)<(11);
   if ($45) {
    $46 = $42 << 1;
    $47 = $46&255;
    HEAP8[$29>>0] = $47;
    $48 = (($29) + 1|0);
    $__p$0$i$i$i$i6 = $48;
   } else {
    $49 = (($42) + 16)|0;
    $50 = $49 & -16;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
    $51 = (invoke_iiiiiii(102,($50|0),16,($$byval_copy4|0),0,(678968|0),79)|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 30;
     break;
    }
    $54 = (($this) + 20|0);
    HEAP32[$54>>2] = $51;
    $55 = $50 | 1;
    HEAP32[$29>>2] = $55;
    $56 = (($this) + 16|0);
    HEAP32[$56>>2] = $42;
    $__p$0$i$i$i$i6 = $51;
   }
   _memcpy(($__p$0$i$i$i$i6|0),($57|0),($42|0))|0;
   $58 = (($__p$0$i$i$i$i6) + ($42)|0);
   HEAP8[$58>>0] = 0;
   $59 = (($this) + 24|0);
   $60 = (($0) + 24|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61 & 1;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    $68 = (($60) + 1|0);
    $69 = $61&255;
    $70 = $69 >>> 1;
    $72 = $70;$87 = $68;
   } else {
    $64 = (($0) + 32|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($0) + 28|0);
    $67 = HEAP32[$66>>2]|0;
    $72 = $67;$87 = $65;
   }
   $71 = ($72>>>0)>(2147483631);
   if ($71) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if (!($74)) {
     // unreachable;
    }
   } else {
    $75 = ($72>>>0)<(11);
    if ($75) {
     $76 = $72 << 1;
     $77 = $76&255;
     HEAP8[$59>>0] = $77;
     $78 = (($59) + 1|0);
     $__p$0$i$i$i$i12 = $78;
     _memcpy(($__p$0$i$i$i$i12|0),($87|0),($72|0))|0;
     $88 = (($__p$0$i$i$i$i12) + ($72)|0);
     HEAP8[$88>>0] = 0;
     $89 = (($this) + 36|0);
     $90 = (($0) + 36|0);
     ;HEAP32[$89+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$90+4>>2]|0;HEAP16[$89+8>>1]=HEAP16[$90+8>>1]|0;
     STACKTOP = sp;return;
    }
    $79 = (($72) + 16)|0;
    $80 = $79 & -16;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    $81 = (invoke_iiiiiii(102,($80|0),16,($$byval_copy4|0),0,(678968|0),79)|0);
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if (!($83)) {
     $84 = (($this) + 32|0);
     HEAP32[$84>>2] = $81;
     $85 = $80 | 1;
     HEAP32[$59>>2] = $85;
     $86 = (($this) + 28|0);
     HEAP32[$86>>2] = $72;
     $__p$0$i$i$i$i12 = $81;
     _memcpy(($__p$0$i$i$i$i12|0),($87|0),($72|0))|0;
     $88 = (($__p$0$i$i$i$i12) + ($72)|0);
     HEAP8[$88>>0] = 0;
     $89 = (($this) + 36|0);
     $90 = (($0) + 36|0);
     ;HEAP32[$89+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$90+4>>2]|0;HEAP16[$89+8>>1]=HEAP16[$90+8>>1]|0;
     STACKTOP = sp;return;
    }
   }
   $93 = ___cxa_find_matching_catch()|0;
   $94 = tempRet0;
   $95 = HEAP8[$29>>0]|0;
   $96 = $95 & 1;
   $97 = ($96<<24>>24)==(0);
   if ($97) {
    $$0 = $94;$$01 = $93;
   } else {
    $98 = (($this) + 20|0);
    $99 = HEAP32[$98>>2]|0;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($99|0),($$byval_copy4|0));
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     $102 = ___cxa_find_matching_catch()|0;
     $103 = tempRet0;
     ___cxa_call_unexpected(($102|0));
     // unreachable;
    } else {
     $$0 = $94;$$01 = $93;
    }
   }
  }
 } while(0);
 if ((label|0) == 30) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  $$0 = $92;$$01 = $91;
 }
 $104 = HEAP8[$this>>0]|0;
 $105 = $104 & 1;
 $106 = ($105<<24>>24)==(0);
 if ($106) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $107 = (($this) + 8|0);
 $108 = HEAP32[$107>>2]|0;
 HEAP32[$3>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($108|0),($$byval_copy4|0));
 $109 = __THREW__; __THREW__ = 0;
 $110 = $109&1;
 if ($110) {
  $111 = ___cxa_find_matching_catch()|0;
  $112 = tempRet0;
  ___cxa_call_unexpected(($111|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNK12ShaderErrors11ShaderErrorltERKS0_($this,$o) {
 $this = $this|0;
 $o = $o|0;
 var $$$$i$i = 0, $$$$i$i5 = 0, $$$i$i = 0, $$$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = (($o) + 44|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($1<<24>>24)==($3<<24>>24);
 if (!($4)) {
  $5 = ($1&255)<($3&255);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($this) + 24|0);
 $7 = (($o) + 24|0);
 $8 = HEAP8[$6>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $13 = $8&255;
  $14 = $13 >>> 1;
  $23 = $14;
 } else {
  $11 = (($this) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $23 = $12;
 }
 $15 = HEAP8[$7>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $20 = $15&255;
  $21 = $20 >>> 1;
  $24 = $21;
 } else {
  $18 = (($o) + 28|0);
  $19 = HEAP32[$18>>2]|0;
  $24 = $19;
 }
 $22 = ($23|0)==($24|0);
 if ($22) {
  if ($10) {
   $27 = (($6) + 1|0);
   $35 = $27;
  } else {
   $25 = (($this) + 32|0);
   $26 = HEAP32[$25>>2]|0;
   $35 = $26;
  }
  if ($17) {
   $30 = (($7) + 1|0);
   $36 = $30;
  } else {
   $28 = (($o) + 32|0);
   $29 = HEAP32[$28>>2]|0;
   $36 = $29;
  }
  if ($10) {
   $33 = $8&255;
   $34 = $33 >>> 1;
   $37 = $34;
  } else {
   $31 = (($this) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   $37 = $32;
  }
  $38 = (_strncmp($35,$36,$37)|0);
  $39 = ($38|0)==(0);
  if ($39) {
   $65 = (($this) + 40|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($o) + 40|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($66|0)==($68|0);
   if (!($69)) {
    $70 = ($66|0)<($68|0);
    $$0 = $70;
    STACKTOP = sp;return ($$0|0);
   }
   $71 = (($this) + 36|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($o) + 36|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($72|0)==($74|0);
   if (!($75)) {
    $76 = ($72|0)<($74|0);
    $$0 = $76;
    STACKTOP = sp;return ($$0|0);
   }
   $77 = HEAP8[$this>>0]|0;
   $78 = $77 & 1;
   $79 = ($78<<24>>24)==(0);
   if ($79) {
    $82 = $77&255;
    $83 = $82 >>> 1;
    $99 = $83;
   } else {
    $80 = (($this) + 4|0);
    $81 = HEAP32[$80>>2]|0;
    $99 = $81;
   }
   $84 = HEAP8[$o>>0]|0;
   $85 = $84 & 1;
   $86 = ($85<<24>>24)==(0);
   if ($86) {
    $89 = $84&255;
    $90 = $89 >>> 1;
    $98 = $90;
   } else {
    $87 = (($o) + 4|0);
    $88 = HEAP32[$87>>2]|0;
    $98 = $88;
   }
   if ($79) {
    $93 = (($this) + 1|0);
    $101 = $93;
   } else {
    $91 = (($this) + 8|0);
    $92 = HEAP32[$91>>2]|0;
    $101 = $92;
   }
   if ($86) {
    $96 = (($o) + 1|0);
    $102 = $96;
   } else {
    $94 = (($o) + 8|0);
    $95 = HEAP32[$94>>2]|0;
    $102 = $95;
   }
   $97 = ($98>>>0)<($99>>>0);
   $100 = $97 ? $98 : $99;
   $103 = (_memcmp($101,$102,$100)|0);
   $104 = ($103|0)==(0);
   if ($104) {
    $105 = ($99>>>0)<($98>>>0);
    $$$i$i4 = $97&1;
    $$$$i$i5 = $105 ? -1 : $$$i$i4;
    $107 = $$$$i$i5;
   } else {
    $107 = $103;
   }
   $106 = ($107|0)<(0);
   $$0 = $106;
   STACKTOP = sp;return ($$0|0);
  }
 }
 if ($10) {
  $42 = $8&255;
  $43 = $42 >>> 1;
  $56 = $43;
 } else {
  $40 = (($this) + 28|0);
  $41 = HEAP32[$40>>2]|0;
  $56 = $41;
 }
 if ($17) {
  $46 = $15&255;
  $47 = $46 >>> 1;
  $55 = $47;
 } else {
  $44 = (($o) + 28|0);
  $45 = HEAP32[$44>>2]|0;
  $55 = $45;
 }
 if ($10) {
  $50 = (($6) + 1|0);
  $58 = $50;
 } else {
  $48 = (($this) + 32|0);
  $49 = HEAP32[$48>>2]|0;
  $58 = $49;
 }
 if ($17) {
  $53 = (($7) + 1|0);
  $59 = $53;
 } else {
  $51 = (($o) + 32|0);
  $52 = HEAP32[$51>>2]|0;
  $59 = $52;
 }
 $54 = ($55>>>0)<($56>>>0);
 $57 = $54 ? $55 : $56;
 $60 = (_memcmp($58,$59,$57)|0);
 $61 = ($60|0)==(0);
 if ($61) {
  $62 = ($56>>>0)<($55>>>0);
  $$$i$i = $54&1;
  $$$$i$i = $62 ? -1 : $$$i$i;
  $64 = $$$$i$i;
 } else {
  $64 = $60;
 }
 $63 = ($64|0)<(0);
 $$0 = $63;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12ShaderErrors11ShaderErrorC2ERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_S9_iibb($this,$msg_,$msgDetails_,$file_,$compilerPlatform_,$line_,$warning_,$programError_) {
 $this = $this|0;
 $msg_ = $msg_|0;
 $msgDetails_ = $msgDetails_|0;
 $file_ = $file_|0;
 $compilerPlatform_ = $compilerPlatform_|0;
 $line_ = $line_|0;
 $warning_ = $warning_|0;
 $programError_ = $programError_|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i12 = 0, $__p$0$i$i$i$i6 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = HEAP8[$msg_>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $11 = (($msg_) + 1|0);
  $12 = $4&255;
  $13 = $12 >>> 1;
  $15 = $13;$26 = $11;
 } else {
  $7 = (($msg_) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($msg_) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $15 = $10;$26 = $8;
 }
 $14 = ($15>>>0)>(2147483631);
 if ($14) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = ($15>>>0)<(11);
 if ($16) {
  $17 = $15 << 1;
  $18 = $17&255;
  HEAP8[$this>>0] = $18;
  $19 = (($this) + 1|0);
  $__p$0$i$i$i$i = $19;
 } else {
  $20 = (($15) + 16)|0;
  $21 = $20 & -16;
  HEAP32[$0>>2] = 59;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,16,$$byval_copy4,0,678968,79)|0);
  $23 = (($this) + 8|0);
  HEAP32[$23>>2] = $22;
  $24 = $21 | 1;
  HEAP32[$this>>2] = $24;
  $25 = (($this) + 4|0);
  HEAP32[$25>>2] = $15;
  $__p$0$i$i$i$i = $22;
 }
 _memcpy(($__p$0$i$i$i$i|0),($26|0),($15|0))|0;
 $27 = (($__p$0$i$i$i$i) + ($15)|0);
 HEAP8[$27>>0] = 0;
 $28 = (($this) + 12|0);
 $29 = HEAP8[$msgDetails_>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $36 = (($msgDetails_) + 1|0);
  $37 = $29&255;
  $38 = $37 >>> 1;
  $40 = $38;$55 = $36;
 } else {
  $32 = (($msgDetails_) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($msgDetails_) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $40 = $35;$55 = $33;
 }
 $39 = ($40>>>0)>(2147483631);
 do {
  if ($39) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    label = 30;
   } else {
    // unreachable;
   }
  } else {
   $43 = ($40>>>0)<(11);
   if ($43) {
    $44 = $40 << 1;
    $45 = $44&255;
    HEAP8[$28>>0] = $45;
    $46 = (($28) + 1|0);
    $__p$0$i$i$i$i6 = $46;
   } else {
    $47 = (($40) + 16)|0;
    $48 = $47 & -16;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    $49 = (invoke_iiiiiii(102,($48|0),16,($$byval_copy4|0),0,(678968|0),79)|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 30;
     break;
    }
    $52 = (($this) + 20|0);
    HEAP32[$52>>2] = $49;
    $53 = $48 | 1;
    HEAP32[$28>>2] = $53;
    $54 = (($this) + 16|0);
    HEAP32[$54>>2] = $40;
    $__p$0$i$i$i$i6 = $49;
   }
   _memcpy(($__p$0$i$i$i$i6|0),($55|0),($40|0))|0;
   $56 = (($__p$0$i$i$i$i6) + ($40)|0);
   HEAP8[$56>>0] = 0;
   $57 = (($this) + 24|0);
   $58 = HEAP8[$file_>>0]|0;
   $59 = $58 & 1;
   $60 = ($59<<24>>24)==(0);
   if ($60) {
    $65 = (($file_) + 1|0);
    $66 = $58&255;
    $67 = $66 >>> 1;
    $69 = $67;$84 = $65;
   } else {
    $61 = (($file_) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($file_) + 4|0);
    $64 = HEAP32[$63>>2]|0;
    $69 = $64;$84 = $62;
   }
   $68 = ($69>>>0)>(2147483631);
   if ($68) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if (!($71)) {
     // unreachable;
    }
   } else {
    $72 = ($69>>>0)<(11);
    if ($72) {
     $73 = $69 << 1;
     $74 = $73&255;
     HEAP8[$57>>0] = $74;
     $75 = (($57) + 1|0);
     $__p$0$i$i$i$i12 = $75;
     _memcpy(($__p$0$i$i$i$i12|0),($84|0),($69|0))|0;
     $85 = (($__p$0$i$i$i$i12) + ($69)|0);
     HEAP8[$85>>0] = 0;
     $86 = (($this) + 36|0);
     HEAP32[$86>>2] = $compilerPlatform_;
     $87 = (($this) + 40|0);
     HEAP32[$87>>2] = $line_;
     $88 = (($this) + 44|0);
     $89 = $warning_&1;
     HEAP8[$88>>0] = $89;
     $90 = (($this) + 45|0);
     $91 = $programError_&1;
     HEAP8[$90>>0] = $91;
     STACKTOP = sp;return;
    }
    $76 = (($69) + 16)|0;
    $77 = $76 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $78 = (invoke_iiiiiii(102,($77|0),16,($$byval_copy4|0),0,(678968|0),79)|0);
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if (!($80)) {
     $81 = (($this) + 32|0);
     HEAP32[$81>>2] = $78;
     $82 = $77 | 1;
     HEAP32[$57>>2] = $82;
     $83 = (($this) + 28|0);
     HEAP32[$83>>2] = $69;
     $__p$0$i$i$i$i12 = $78;
     _memcpy(($__p$0$i$i$i$i12|0),($84|0),($69|0))|0;
     $85 = (($__p$0$i$i$i$i12) + ($69)|0);
     HEAP8[$85>>0] = 0;
     $86 = (($this) + 36|0);
     HEAP32[$86>>2] = $compilerPlatform_;
     $87 = (($this) + 40|0);
     HEAP32[$87>>2] = $line_;
     $88 = (($this) + 44|0);
     $89 = $warning_&1;
     HEAP8[$88>>0] = $89;
     $90 = (($this) + 45|0);
     $91 = $programError_&1;
     HEAP8[$90>>0] = $91;
     STACKTOP = sp;return;
    }
   }
   $94 = ___cxa_find_matching_catch()|0;
   $95 = tempRet0;
   $96 = HEAP8[$28>>0]|0;
   $97 = $96 & 1;
   $98 = ($97<<24>>24)==(0);
   if ($98) {
    $$0 = $95;$$01 = $94;
   } else {
    $99 = (($this) + 20|0);
    $100 = HEAP32[$99>>2]|0;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($100|0),($$byval_copy4|0));
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     $103 = ___cxa_find_matching_catch()|0;
     $104 = tempRet0;
     ___cxa_call_unexpected(($103|0));
     // unreachable;
    } else {
     $$0 = $95;$$01 = $94;
    }
   }
  }
 } while(0);
 if ((label|0) == 30) {
  $92 = ___cxa_find_matching_catch()|0;
  $93 = tempRet0;
  $$0 = $93;$$01 = $92;
 }
 $105 = HEAP8[$this>>0]|0;
 $106 = $105 & 1;
 $107 = ($106<<24>>24)==(0);
 if ($107) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $108 = (($this) + 8|0);
 $109 = HEAP32[$108>>2]|0;
 HEAP32[$2>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($109|0),($$byval_copy4|0));
 $110 = __THREW__; __THREW__ = 0;
 $111 = $110&1;
 if ($111) {
  $112 = ___cxa_find_matching_catch()|0;
  $113 = tempRet0;
  ___cxa_call_unexpected(($112|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN9ShaderLab9IntShader22CreateFromParsedShaderERKNS_12ParserShaderERNSt3__16vectorI4PPtrI6ShaderENS4_9allocatorIS8_EEEEbR12ShaderErrorsPS7_($parsed,$dependenciesTable,$useDependenciesTable,$outErrors,$fromShader) {
 $parsed = $parsed|0;
 $dependenciesTable = $dependenciesTable|0;
 $useDependenciesTable = $useDependenciesTable|0;
 $outErrors = $outErrors|0;
 $fromShader = $fromShader|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0;
 var $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__lhs_sz$05$i$i$i = 0, $__lp$03$i$i$i = 0, $__new_last2$i$i$i = 0, $__rp$04$i$i$i = 0, $i$02 = 0, $i$02$i = 0, $info$i = 0, $name$i = 0, $phitmp$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0;
 var $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp;
 $name$i = sp + 44|0;
 $0 = sp + 8|0;
 $info$i = sp + 24|0;
 $1 = sp + 40|0;
 if (!($useDependenciesTable)) {
  $2 = HEAP32[$dependenciesTable>>2]|0;
  $3 = (($dependenciesTable) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($2|0);
  if (!($5)) {
   $__new_last2$i$i$i = $2;
   $scevgep$i$i$i = (($4) + -4|0);
   $6 = (0 - ($__new_last2$i$i$i))|0;
   $uglygep$i$i$i = (($scevgep$i$i$i) + ($6)|0);
   $uglygep3$i$i$i = $uglygep$i$i$i;
   $7 = $uglygep3$i$i$i >>> 2;
   $8 = $7 ^ -1;
   $scevgep4$i$i$i = (($4) + ($8<<2)|0);
   HEAP32[$3>>2] = $scevgep4$i$i$i;
  }
 }
 $9 = HEAP32[628272>>2]|0;
 HEAP32[$1>>2] = $9;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $10 = (__Znwj10MemLabelIdbiPKci(108,$$byval_copy1,0,16,678976,73)|0);
 __THREW__ = 0;
 invoke_vi(3596,($10|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $210 = ___cxa_find_matching_catch()|0;
  $211 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viiiiii(97,($10|0),($$byval_copy1|0),0,16,(678976|0),73);
  $212 = __THREW__; __THREW__ = 0;
  $213 = $212&1;
  if ($213) {
   $222 = ___cxa_find_matching_catch(0|0)|0;
   $223 = tempRet0;
   ___clang_call_terminate($222);
   // unreachable;
  } else {
   ___resumeException($210|0);
   // unreachable;
  }
 }
 $13 = (($parsed) + 48|0);
 $14 = (($parsed) + 24|0);
 $15 = (($10) + 84|0);
 $16 = HEAP8[$13>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $21 = $16&255;
  $22 = $21 >>> 1;
  $24 = $22;
 } else {
  $19 = (($parsed) + 52|0);
  $20 = HEAP32[$19>>2]|0;
  $24 = $20;
 }
 $23 = ($24|0)==(0);
 L15: do {
  if ($23) {
   label = 27;
  } else {
   if ($18) {
    $27 = $16&255;
    $28 = $27 >>> 1;
    $37 = $28;
   } else {
    $25 = (($parsed) + 52|0);
    $26 = HEAP32[$25>>2]|0;
    $37 = $26;
   }
   $29 = HEAP8[$14>>0]|0;
   $30 = $29 & 1;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $34 = $29&255;
    $35 = $34 >>> 1;
    $38 = $35;
   } else {
    $32 = (($parsed) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    $38 = $33;
   }
   $36 = ($37|0)==($38|0);
   if ($36) {
    if ($18) {
     $41 = (($13) + 1|0);
     $53 = $41;
    } else {
     $39 = (($parsed) + 56|0);
     $40 = HEAP32[$39>>2]|0;
     $53 = $40;
    }
    if ($31) {
     $44 = (($14) + 1|0);
     $54 = $44;
    } else {
     $42 = (($parsed) + 32|0);
     $43 = HEAP32[$42>>2]|0;
     $54 = $43;
    }
    if ($18) {
     $45 = ($37|0)==(0);
     if (!($45)) {
      $__lhs_sz$05$i$i$i = $37;$__lp$03$i$i$i = $53;$__rp$04$i$i$i = $54;
      while(1) {
       $46 = HEAP8[$__lp$03$i$i$i>>0]|0;
       $47 = HEAP8[$__rp$04$i$i$i>>0]|0;
       $48 = ($46<<24>>24)==($47<<24>>24);
       if (!($48)) {
        label = 27;
        break L15;
       }
       $49 = (($__lhs_sz$05$i$i$i) + -1)|0;
       $50 = (($__lp$03$i$i$i) + 1|0);
       $51 = (($__rp$04$i$i$i) + 1|0);
       $52 = ($49|0)==(0);
       if ($52) {
        break;
       } else {
        $__lhs_sz$05$i$i$i = $49;$__lp$03$i$i$i = $50;$__rp$04$i$i$i = $51;
       }
      }
     }
     $58 = (($13) + 1|0);
     $59 = $58;
    } else {
     $55 = (_memcmp($53,$54,$37)|0);
     $phitmp$i$i = ($55|0)==(0);
     if (!($phitmp$i$i)) {
      label = 27;
      break;
     }
     $56 = (($parsed) + 56|0);
     $57 = HEAP32[$56>>2]|0;
     $59 = $57;
    }
    HEAP32[$$byval_copy1>>2] = $59;
    __Z6FormatPKcz($name$i,679264,$$byval_copy1);
    __THREW__ = 0;
    invoke_viiiii(104,($outErrors|0),($name$i|0),0,1,0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if (!($61)) {
     $62 = HEAP8[$name$i>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      break;
     }
     $65 = (($name$i) + 8|0);
     $66 = HEAP32[$65>>2]|0;
     __ZdlPv($66);
     break;
    }
    $67 = ___cxa_find_matching_catch()|0;
    $68 = tempRet0;
    $69 = HEAP8[$name$i>>0]|0;
    $70 = $69 & 1;
    $71 = ($70<<24>>24)==(0);
    if ($71) {
     ___resumeException($67|0);
     // unreachable;
    }
    $72 = (($name$i) + 8|0);
    $73 = HEAP32[$72>>2]|0;
    __ZdlPv($73);
    ___resumeException($67|0);
    // unreachable;
   } else {
    label = 27;
   }
  }
 } while(0);
 if ((label|0) == 27) {
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($15,$13)|0);
 }
 $74 = (($10) + 72|0);
 $75 = (($parsed) + 36|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($74,$75)|0);
 $76 = (($10) + 96|0);
 $77 = (($parsed) + 60|0);
 $78 = ($76|0)==($77|0);
 if (!($78)) {
  $79 = HEAP32[$77>>2]|0;
  $80 = (($parsed) + 64|0);
  $81 = HEAP32[$80>>2]|0;
  __ZNSt3__16vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS5_IS8_EEE6assignIPS8_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS8_NS_15iterator_traitsISE_E9referenceEEE5valueEvE4typeESE_SE_($76,$79,$81);
 }
 $82 = (__Znwj(84)|0);
 HEAP32[$82>>2] = ((587472 + 8|0));
 $83 = (($82) + 4|0);
 HEAP32[$83>>2] = 1;
 HEAP32[$82>>2] = ((653968 + 8|0));
 $84 = (($82) + 12|0);
 HEAP32[$84>>2] = 0;
 $85 = (($82) + 16|0);
 HEAP32[$85>>2] = 0;
 $86 = (($82) + 8|0);
 HEAP32[$86>>2] = $84;
 $87 = (($82) + 24|0);
 HEAP32[$87>>2] = 0;
 $88 = (($82) + 28|0);
 HEAP32[$88>>2] = 0;
 $89 = (($82) + 20|0);
 HEAP32[$89>>2] = $87;
 $90 = (($82) + 36|0);
 HEAP32[$90>>2] = 0;
 $91 = (($82) + 40|0);
 HEAP32[$91>>2] = 0;
 $92 = (($82) + 32|0);
 HEAP32[$92>>2] = $90;
 $93 = (($82) + 48|0);
 HEAP32[$93>>2] = 0;
 $94 = (($82) + 52|0);
 HEAP32[$94>>2] = 0;
 $95 = (($82) + 44|0);
 HEAP32[$95>>2] = $93;
 $96 = (($82) + 60|0);
 HEAP32[$96>>2] = 0;
 $97 = (($82) + 64|0);
 HEAP32[$97>>2] = 0;
 $98 = (($82) + 56|0);
 HEAP32[$98>>2] = $96;
 $99 = (($82) + 72|0);
 HEAP32[$99>>2] = 0;
 $100 = (($82) + 76|0);
 HEAP32[$100>>2] = 0;
 $101 = (($82) + 68|0);
 HEAP32[$101>>2] = $99;
 $102 = (($82) + 80|0);
 HEAP32[$102>>2] = 0;
 $103 = (($parsed) + 4|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = HEAP32[$parsed>>2]|0;
 $106 = ($104|0)==($105|0);
 L58: do {
  if (!($106)) {
   $107 = (($0) + 4|0);
   $108 = (($0) + 8|0);
   $109 = (($0) + 12|0);
   $111 = $105;$i$02$i = 0;
   L60: while(1) {
    $110 = (($111) + (($i$02$i*76)|0)|0);
    HEAP32[$$byval_copy1>>2] = -1;
    $112 = HEAP8[$110>>0]|0;
    $113 = $112 & 1;
    $114 = ($113<<24>>24)==(0);
    if ($114) {
     $117 = (($110) + 1|0);
     $118 = $117;
    } else {
     $115 = ((($111) + (($i$02$i*76)|0)|0) + 8|0);
     $116 = HEAP32[$115>>2]|0;
     $118 = $116;
    }
    __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy1,$118);
    $119 = HEAP32[$$byval_copy1>>2]|0;
    HEAP32[$name$i>>2] = $119;
    $120 = ((($111) + (($i$02$i*76)|0)|0) + 36|0);
    $121 = HEAP32[$120>>2]|0;
    switch ($121|0) {
    case 4:  {
     ;HEAP32[$info$i+0>>2]=0|0;HEAP32[$info$i+4>>2]=0|0;HEAP32[$info$i+8>>2]=0|0;HEAP32[$info$i+12>>2]=0|0;
     $132 = (__Znwj(64)|0);
     $133 = ((($111) + (($i$02$i*76)|0)|0) + 60|0);
     __THREW__ = 0;
     invoke_vii(3265,($132|0),($133|0));
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      break L60;
     }
     HEAP32[$info$i>>2] = $132;
     __ZN9ShaderLab13PropertySheet19InitTexturePropertyERKNS_16FastPropertyNameERNS0_15TexturePropertyEPKS4_($82,$name$i,$info$i,0);
     $136 = (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameENS1_13PropertySheet15TexturePropertyENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_($95,$name$i)|0);
     ;HEAP32[$136+0>>2]=HEAP32[$info$i+0>>2]|0;HEAP32[$136+4>>2]=HEAP32[$info$i+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$info$i+8>>2]|0;HEAP32[$136+12>>2]=HEAP32[$info$i+12>>2]|0;
     break;
    }
    case 0:  {
     __ZN9ShaderLab13PropertySheet11SetColorTagERKNS_16FastPropertyNameE($82,$name$i);
     label = 45;
     break;
    }
    case 1:  {
     label = 45;
     break;
    }
    case 3: case 2:  {
     $130 = ((($111) + (($i$02$i*76)|0)|0) + 44|0);
     $131 = Math_fround(HEAPF32[$130>>2]);
     __ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf($82,$name$i,$131);
     break;
    }
    default: {
    }
    }
    if ((label|0) == 45) {
     label = 0;
     $122 = ((($111) + (($i$02$i*76)|0)|0) + 44|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     HEAPF32[$0>>2] = $123;
     $124 = ((($111) + (($i$02$i*76)|0)|0) + 48|0);
     $125 = Math_fround(HEAPF32[$124>>2]);
     HEAPF32[$107>>2] = $125;
     $126 = ((($111) + (($i$02$i*76)|0)|0) + 52|0);
     $127 = Math_fround(HEAPF32[$126>>2]);
     HEAPF32[$108>>2] = $127;
     $128 = ((($111) + (($i$02$i*76)|0)|0) + 56|0);
     $129 = Math_fround(HEAPF32[$128>>2]);
     HEAPF32[$109>>2] = $129;
     __ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f($82,$name$i,$0);
    }
    $137 = (($i$02$i) + 1)|0;
    $138 = HEAP32[$103>>2]|0;
    $139 = HEAP32[$parsed>>2]|0;
    $140 = $138;
    $141 = $139;
    $142 = (($140) - ($141))|0;
    $143 = (($142|0) / 76)&-1;
    $144 = ($137>>>0)<($143>>>0);
    if ($144) {
     $111 = $139;$i$02$i = $137;
    } else {
     break L58;
    }
   }
   $145 = ___cxa_find_matching_catch()|0;
   $146 = tempRet0;
   __ZdlPv($132);
   ___resumeException($145|0);
   // unreachable;
  }
 } while(0);
 $147 = (($10) + 68|0);
 HEAP32[$147>>2] = $82;
 $148 = (($parsed) + 16|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = (($parsed) + 12|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = $149;
 $153 = $151;
 $154 = (($152) - ($153))|0;
 $155 = $154 >> 2;
 $156 = (($10) + 8|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = HEAP32[$10>>2]|0;
 $159 = $157;
 $160 = $158;
 $161 = (($159) - ($160))|0;
 $162 = $161 >> 2;
 $163 = ($162>>>0)<($155>>>0);
 if ($163) {
  $164 = (($10) + 4|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = $165;
  $167 = (($166) - ($160))|0;
  $168 = $167 >> 2;
  $169 = ($155|0)==(0);
  if ($169) {
   $172 = 0;
  } else {
   $170 = (__Znwj($154)|0);
   $172 = $170;
  }
  $171 = (($172) + ($168<<2)|0);
  $173 = (($172) + ($155<<2)|0);
  _memcpy(($172|0),($158|0),($167|0))|0;
  HEAP32[$10>>2] = $172;
  HEAP32[$164>>2] = $171;
  HEAP32[$156>>2] = $173;
  $174 = ($158|0)==(0|0);
  if (!($174)) {
   __ZdlPv($158);
  }
 }
 $175 = HEAP32[$148>>2]|0;
 $176 = HEAP32[$150>>2]|0;
 $177 = ($175|0)==($176|0);
 if ($177) {
  __ZN9ShaderLab9IntShader15ResolveFallbackERKNS_12ParserShaderEP6ShaderRNSt3__16vectorI4PPtrIS4_ENS6_9allocatorIS9_EEEEbR12ShaderErrors($10,$parsed,$fromShader,$dependenciesTable,$useDependenciesTable,$outErrors);
  __ZN9ShaderLab9IntShader10LinkShaderERNSt3__16vectorI4PPtrI6ShaderENS1_9allocatorIS5_EEEEbR12ShaderErrors($10,$dependenciesTable,$useDependenciesTable,$outErrors);
  STACKTOP = sp;return ($10|0);
 }
 $178 = (($10) + 4|0);
 $180 = $176;$i$02 = 0;
 L86: while(1) {
  $179 = (($180) + ($i$02<<2)|0);
  $181 = HEAP32[$179>>2]|0;
  $182 = (__ZN9ShaderLab9SubShader25CreateFromParsedSubShaderERKNS_15ParserSubShaderERNSt3__16vectorI4PPtrI6ShaderENS4_9allocatorIS8_EEEEbR12ShaderErrorsPS7_($181,$dependenciesTable,$useDependenciesTable,$outErrors,$fromShader)|0);
  $183 = ($182|0)==(0|0);
  do {
   if (!($183)) {
    $184 = HEAP32[$178>>2]|0;
    $185 = HEAP32[$156>>2]|0;
    $186 = ($184|0)==($185|0);
    if (!($186)) {
     $187 = ($184|0)==(0|0);
     if ($187) {
      $189 = 0;
     } else {
      HEAP32[$184>>2] = $182;
      $$pre$i = HEAP32[$178>>2]|0;
      $189 = $$pre$i;
     }
     $188 = (($189) + 4|0);
     HEAP32[$178>>2] = $188;
     break;
    }
    $190 = HEAP32[$10>>2]|0;
    $191 = $184;
    $192 = $190;
    $193 = (($191) - ($192))|0;
    $194 = $193 >> 2;
    $195 = (($194) + 1)|0;
    $196 = ($195>>>0)>(1073741823);
    if ($196) {
     label = 64;
     break L86;
    }
    $197 = ($194>>>0)<(536870911);
    if ($197) {
     $198 = $193 >> 1;
     $199 = ($198>>>0)<($195>>>0);
     $200 = $199 ? $195 : $198;
     $201 = ($200|0)==(0);
     if ($201) {
      $$0$i3$i$i = 0;$205 = 0;
     } else {
      $$0$i2$i$i = $200;
      label = 67;
     }
    } else {
     $$0$i2$i$i = 1073741823;
     label = 67;
    }
    if ((label|0) == 67) {
     label = 0;
     $202 = $$0$i2$i$i << 2;
     $203 = (__Znwj($202)|0);
     $$0$i3$i$i = $$0$i2$i$i;$205 = $203;
    }
    $204 = (($205) + ($194<<2)|0);
    $206 = (($205) + ($$0$i3$i$i<<2)|0);
    $207 = ($204|0)==(0|0);
    if (!($207)) {
     HEAP32[$204>>2] = $182;
    }
    $208 = (($205) + ($195<<2)|0);
    _memcpy(($205|0),($190|0),($193|0))|0;
    HEAP32[$10>>2] = $205;
    HEAP32[$178>>2] = $208;
    HEAP32[$156>>2] = $206;
    $209 = ($190|0)==(0|0);
    if (!($209)) {
     __ZdlPv($190);
    }
   }
  } while(0);
  $214 = (($i$02) + 1)|0;
  $215 = HEAP32[$148>>2]|0;
  $216 = HEAP32[$150>>2]|0;
  $217 = $215;
  $218 = $216;
  $219 = (($217) - ($218))|0;
  $220 = $219 >> 2;
  $221 = ($214>>>0)<($220>>>0);
  if ($221) {
   $180 = $216;$i$02 = $214;
  } else {
   label = 74;
   break;
  }
 }
 if ((label|0) == 64) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 74) {
  __ZN9ShaderLab9IntShader15ResolveFallbackERKNS_12ParserShaderEP6ShaderRNSt3__16vectorI4PPtrIS4_ENS6_9allocatorIS9_EEEEbR12ShaderErrors($10,$parsed,$fromShader,$dependenciesTable,$useDependenciesTable,$outErrors);
  __ZN9ShaderLab9IntShader10LinkShaderERNSt3__16vectorI4PPtrI6ShaderENS1_9allocatorIS5_EEEEbR12ShaderErrors($10,$dependenciesTable,$useDependenciesTable,$outErrors);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __ZN9ShaderLab9SubShader25CreateFromParsedSubShaderERKNS_15ParserSubShaderERNSt3__16vectorI4PPtrI6ShaderENS4_9allocatorIS8_EEEEbR12ShaderErrorsPS7_($parsed,$dependencies,$useDependenciesTable,$outErrors,$fromShader) {
 $parsed = $parsed|0;
 $dependencies = $dependencies|0;
 $useDependenciesTable = $useDependenciesTable|0;
 $outErrors = $outErrors|0;
 $fromShader = $fromShader|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01 = 0, $$01$i = 0, $$01$i$i$i$i = 0, $$02 = 0, $$1$i = 0, $$111 = 0, $$12$i = 0, $$2$i = 0, $$23$i = 0, $$3$i = 0, $$34$i = 0, $$byval_copy33 = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__p$0$i$i = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $buf$i = 0, $eh$lpad$body$index17Z2D = 0, $eh$lpad$body$indexZ2D = 0, $found$0$i = 0, $found$1$i = 0, $foundPasses$i = 0, $i$011$i = 0, $i$0110 = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index8 = 0, $lpad$phi29$index = 0, $lpad$phi29$index2 = 0, $or$cond$i = 0, $shaderName$i = 0, $str$0$i = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy33 = sp + 36|0;
 $0 = sp + 108|0;
 $1 = sp + 104|0;
 $2 = sp + 100|0;
 $3 = sp;
 $4 = sp + 88|0;
 $5 = sp + 76|0;
 $buf$i = sp + 112|0;
 $shaderName$i = sp + 40|0;
 $foundPasses$i = sp + 8|0;
 $6 = sp + 24|0;
 $7 = sp + 52|0;
 $8 = sp + 56|0;
 $9 = sp + 60|0;
 $10 = sp + 72|0;
 $11 = HEAP32[628272>>2]|0;
 HEAP32[$7>>2] = $11;
 ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$7+0>>2]|0;
 $12 = (__Znwj10MemLabelIdbiPKci(52,$$byval_copy33,0,16,678976,149)|0);
 __THREW__ = 0;
 invoke_vi(3597,($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $64 = ___cxa_find_matching_catch()|0;
  $65 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$7+0>>2]|0;
  invoke_viiiiii(97,($12|0),($$byval_copy33|0),0,16,(678976|0),149);
  $66 = __THREW__; __THREW__ = 0;
  $67 = $66&1;
  if ($67) {
   $341 = ___cxa_find_matching_catch(0|0)|0;
   $342 = tempRet0;
   ___clang_call_terminate($341);
   // unreachable;
  } else {
   $$01 = $64;$$02 = $65;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $15 = (($parsed) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$parsed>>2]|0;
 $18 = $16;
 $19 = $17;
 $20 = (($18) - ($19))|0;
 $21 = $20 >> 2;
 $22 = (($12) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($24>>>0)<($21>>>0);
 do {
  if ($25) {
   $26 = ($23|0)>(-1);
   if ($26) {
    HEAP32[$22>>2] = $21;
    $27 = HEAP32[$12>>2]|0;
    $28 = (($12) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$0>>2] = $29;
    ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
    $30 = (__Z16realloc_internalPvji10MemLabelIdiPKci($27,$20,4,$$byval_copy33,0,678976,370)|0);
    HEAP32[$12>>2] = $30;
    break;
   } else {
    $31 = (($12) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$0>>2] = $32;
    ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
    $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,4,$$byval_copy33,0,678976,352)|0);
    $34 = HEAP32[$12>>2]|0;
    $35 = (($12) + 8|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $36 << 2;
    _memcpy(($33|0),($34|0),($37|0))|0;
    HEAP32[$22>>2] = $21;
    HEAP32[$12>>2] = $33;
    break;
   }
  }
 } while(0);
 $38 = HEAP32[$15>>2]|0;
 $39 = HEAP32[$parsed>>2]|0;
 $40 = ($38|0)==($39|0);
 L13: do {
  if (!($40)) {
   $41 = (($12) + 16|0);
   $42 = (($12) + 8|0);
   $43 = (($9) + 1|0);
   $44 = (($5) + 1|0);
   $45 = (($5) + 8|0);
   $46 = (($4) + 8|0);
   $47 = (($9) + 8|0);
   $48 = (($5) + 4|0);
   $49 = (($9) + 4|0);
   $50 = (($shaderName$i) + 1|0);
   $51 = (($shaderName$i) + 8|0);
   $52 = (($foundPasses$i) + 8|0);
   $53 = (($foundPasses$i) + 12|0);
   $54 = (($foundPasses$i) + 4|0);
   $55 = (($6) + 1|0);
   $56 = (($6) + 8|0);
   $57 = (($6) + 4|0);
   $58 = (($shaderName$i) + 4|0);
   $60 = $39;$i$0110 = 0;
   L15: while(1) {
    $59 = (($60) + ($i$0110<<2)|0);
    $61 = HEAP32[$59>>2]|0;
    $62 = (($61) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    if ((($63|0) == 0)) {
     $68 = (__ZN9ShaderLab4Pass20CreateFromParsedPassERKNS_10ParserPassER12ShaderErrorsPK6Shader($61,0,$fromShader)|0);
     HEAP32[$8>>2] = $68;
     __ZN13dynamic_arrayIPN9ShaderLab4PassELj4EE9push_backERKS2_($12,$8);
     $69 = HEAP32[$41>>2]|0;
     $70 = (($69) + 1)|0;
     HEAP32[$41>>2] = $70;
    } else if ((($63|0) == 1)) {
     $71 = HEAP32[$42>>2]|0;
     $72 = (($61) + 8|0);
     $73 = HEAP8[$72>>0]|0;
     $74 = $73 & 1;
     $75 = ($74<<24>>24)==(0);
     if ($75) {
      $78 = (($72) + 1|0);
      $79 = $78;
     } else {
      $76 = (($61) + 16|0);
      $77 = HEAP32[$76>>2]|0;
      $79 = $77;
     }
     $80 = (_strlen(($79|0))|0);
     $81 = ($80>>>0)>(4294967279);
     if ($81) {
      label = 15;
      break;
     }
     $82 = ($80>>>0)<(11);
     if ($82) {
      $83 = $80 << 1;
      $84 = $83&255;
      HEAP8[$9>>0] = $84;
      $92 = $84;$__p$0$i$i$i = $43;
     } else {
      $85 = (($80) + 16)|0;
      $86 = $85 & -16;
      $87 = (__Znwj($86)|0);
      HEAP32[$47>>2] = $87;
      $88 = $86 | 1;
      HEAP32[$9>>2] = $88;
      HEAP32[$49>>2] = $80;
      $89 = $88&255;
      $92 = $89;$__p$0$i$i$i = $87;
     }
     _memcpy(($__p$0$i$i$i|0),($79|0),($80|0))|0;
     $90 = (($__p$0$i$i$i) + ($80)|0);
     HEAP8[$90>>0] = 0;
     $91 = $92 & 1;
     $93 = ($91<<24>>24)==(0);
     $94 = HEAP32[$47>>2]|0;
     $$ = $93 ? $43 : $94;
     $found$0$i = 0;$str$0$i = $$;
     while(1) {
      $95 = HEAP8[$str$0$i>>0]|0;
      if ((($95<<24>>24) == 47)) {
       $found$1$i = $str$0$i;
      } else if ((($95<<24>>24) == 0)) {
       break;
      } else {
       $found$1$i = $found$0$i;
      }
      $96 = (($str$0$i) + 1|0);
      $found$0$i = $found$1$i;$str$0$i = $96;
     }
     $97 = ($found$0$i|0)==(0|0);
     $98 = ($found$0$i|0)==($$|0);
     $or$cond$i = $97 | $98;
     if ($or$cond$i) {
      ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
      $99 = $92 & 1;
      $100 = ($99<<24>>24)==(0);
      if ($100) {
       $102 = $92&255;
       $103 = $102 >>> 1;
       $105 = $103;
      } else {
       $101 = HEAP32[$49>>2]|0;
       $105 = $101;
      }
      $104 = (($105) + 53)|0;
      $106 = ($104>>>0)>(4294967279);
      if ($106) {
       label = 28;
       break;
      }
      $109 = ($104>>>0)<(11);
      if ($109) {
       HEAP8[$5>>0] = 106;
       $__p$0$i$i = $44;
      } else {
       $110 = (($105) + 69)|0;
       $111 = $110 & -16;
       __THREW__ = 0;
       $112 = (invoke_ii(2988,($111|0))|0);
       $113 = __THREW__; __THREW__ = 0;
       $114 = $113&1;
       if ($114) {
        label = 35;
        break;
       }
       HEAP32[$45>>2] = $112;
       $115 = $111 | 1;
       HEAP32[$5>>2] = $115;
       HEAP32[$48>>2] = 53;
       $__p$0$i$i = $112;
      }
      dest=$__p$0$i$i+0|0; src=679208+0|0; stop=dest+53|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $116 = (($__p$0$i$i) + 53|0);
      HEAP8[$116>>0] = 0;
      $117 = $92 & 1;
      $118 = ($117<<24>>24)==(0);
      $119 = HEAP32[$47>>2]|0;
      $$111 = $118 ? $43 : $119;
      __THREW__ = 0;
      (invoke_iiii(1480,($5|0),($$111|0),($105|0))|0);
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       label = 35;
       break;
      }
      __THREW__ = 0;
      invoke_viii(1667,($4|0),($5|0),39);
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       label = 45;
       break;
      }
      __THREW__ = 0;
      invoke_viiiii(104,($outErrors|0),($4|0),-1,0,0);
      $132 = __THREW__; __THREW__ = 0;
      $133 = $132&1;
      if ($133) {
       label = 46;
       break;
      }
      $134 = HEAP8[$4>>0]|0;
      $135 = $134 & 1;
      $136 = ($135<<24>>24)==(0);
      if (!($136)) {
       $137 = HEAP32[$46>>2]|0;
       __ZdlPv($137);
      }
      $138 = HEAP8[$5>>0]|0;
      $139 = $138 & 1;
      $140 = ($139<<24>>24)==(0);
      if (!($140)) {
       $141 = HEAP32[$45>>2]|0;
       __ZdlPv($141);
      }
     } else {
      $154 = $found$0$i;
      $155 = $$;
      $156 = (($154) - ($155))|0;
      (_strncpy(($buf$i|0),($$|0),($156|0))|0);
      $157 = (($buf$i) + ($156)|0);
      HEAP8[$157>>0] = 0;
      $158 = (_strlen(($buf$i|0))|0);
      $159 = ($158>>>0)>(4294967279);
      if ($159) {
       label = 51;
       break;
      }
      $162 = ($158>>>0)<(11);
      if ($162) {
       $163 = $158 << 1;
       $164 = $163&255;
       HEAP8[$shaderName$i>>0] = $164;
       $__p$0$i$i$i$i = $50;
      } else {
       $165 = (($158) + 16)|0;
       $166 = $165 & -16;
       __THREW__ = 0;
       $167 = (invoke_ii(2988,($166|0))|0);
       $168 = __THREW__; __THREW__ = 0;
       $169 = $168&1;
       if ($169) {
        label = 99;
        break;
       }
       HEAP32[$51>>2] = $167;
       $170 = $166 | 1;
       HEAP32[$shaderName$i>>2] = $170;
       HEAP32[$58>>2] = $158;
       $__p$0$i$i$i$i = $167;
      }
      _memcpy(($__p$0$i$i$i$i|0),($buf$i|0),($158|0))|0;
      $171 = (($__p$0$i$i$i$i) + ($158)|0);
      HEAP8[$171>>0] = 0;
      __THREW__ = 0;
      $172 = (invoke_iiii(1569,($shaderName$i|0),($dependencies|0),($useDependenciesTable|0))|0);
      $173 = __THREW__; __THREW__ = 0;
      $174 = $173&1;
      if ($174) {
       label = 59;
       break;
      }
      $175 = ($172|0)==(0|0);
      do {
       if (!($175)) {
        HEAP32[$foundPasses$i>>2] = 0;
        HEAP32[$52>>2] = 0;
        HEAP32[$53>>2] = 0;
        HEAP32[$54>>2] = 61;
        $178 = (($172) + 52|0);
        $179 = HEAP32[$178>>2]|0;
        $180 = HEAP32[$179>>2]|0;
        $181 = HEAP32[$180>>2]|0;
        $182 = (($found$0$i) + 1|0);
        $183 = (_strlen(($182|0))|0);
        $184 = ($183>>>0)>(2147483631);
        if ($184) {
         label = 61;
         break L15;
        }
        $187 = ($183>>>0)<(11);
        if ($187) {
         $188 = $183 << 1;
         $189 = $188&255;
         HEAP8[$6>>0] = $189;
         $__p$0$i$i$i$i$i = $55;
        } else {
         $190 = (($183) + 16)|0;
         $191 = $190 & -16;
         HEAP32[$3>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$3+0>>2]|0;
         $192 = (invoke_iiiiiii(102,($191|0),16,($$byval_copy33|0),0,(678976|0),79)|0);
         $193 = __THREW__; __THREW__ = 0;
         $194 = $193&1;
         if ($194) {
          label = 75;
          break L15;
         }
         HEAP32[$56>>2] = $192;
         $195 = $191 | 1;
         HEAP32[$6>>2] = $195;
         HEAP32[$57>>2] = $183;
         $__p$0$i$i$i$i$i = $192;
        }
        _memcpy(($__p$0$i$i$i$i$i|0),($182|0),($183|0))|0;
        $196 = (($__p$0$i$i$i$i$i) + ($183)|0);
        HEAP8[$196>>0] = 0;
        __THREW__ = 0;
        invoke_viii(1948,($181|0),($6|0),($foundPasses$i|0));
        $197 = __THREW__; __THREW__ = 0;
        $198 = $197&1;
        if ($198) {
         label = 78;
         break L15;
        }
        $199 = HEAP8[$6>>0]|0;
        $200 = $199 & 1;
        $201 = ($200<<24>>24)==(0);
        if (!($201)) {
         $202 = HEAP32[$56>>2]|0;
         HEAP32[$2>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$2+0>>2]|0;
         invoke_vii(2591,($202|0),($$byval_copy33|0));
         $203 = __THREW__; __THREW__ = 0;
         $204 = $203&1;
         if ($204) {
          label = 71;
          break L15;
         }
        }
        $205 = HEAP32[$52>>2]|0;
        $206 = ($205|0)==(0);
        if (!($206)) {
         $i$011$i = 0;
         while(1) {
          $209 = HEAP32[$foundPasses$i>>2]|0;
          $210 = (($209) + ($i$011$i<<2)|0);
          __THREW__ = 0;
          invoke_vii(3266,($12|0),($210|0));
          $211 = __THREW__; __THREW__ = 0;
          $212 = $211&1;
          if ($212) {
           label = 74;
           break L15;
          }
          $213 = (($i$011$i) + 1)|0;
          $214 = HEAP32[$52>>2]|0;
          $215 = ($213>>>0)<($214>>>0);
          if ($215) {
           $i$011$i = $213;
          } else {
           break;
          }
         }
        }
        $232 = HEAP32[$53>>2]|0;
        $233 = ($232|0)>(-1);
        if (!($233)) {
         break;
        }
        $234 = HEAP32[$foundPasses$i>>2]|0;
        $235 = HEAP32[$54>>2]|0;
        HEAP32[$0>>2] = $235;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($234|0),($$byval_copy33|0));
        $236 = __THREW__; __THREW__ = 0;
        $237 = $236&1;
        if ($237) {
         label = 59;
         break L15;
        }
        HEAP32[$foundPasses$i>>2] = 0;
       }
      } while(0);
      $238 = HEAP8[$shaderName$i>>0]|0;
      $239 = $238 & 1;
      $240 = ($239<<24>>24)==(0);
      if (!($240)) {
       $241 = HEAP32[$51>>2]|0;
       __ZdlPv($241);
      }
     }
     $254 = HEAP8[$9>>0]|0;
     $255 = $254 & 1;
     $256 = ($255<<24>>24)==(0);
     if (!($256)) {
      $257 = HEAP32[$47>>2]|0;
      __ZdlPv($257);
     }
     $258 = HEAP32[$42>>2]|0;
     $259 = (($258) - ($71))|0;
     $260 = HEAP32[$41>>2]|0;
     $261 = (($259) + ($260))|0;
     HEAP32[$41>>2] = $261;
     $262 = ($258|0)==($71|0);
     if ($262) {
      label = 96;
      break;
     }
    } else if ((($63|0) == 2)) {
     $273 = (__ZN9ShaderLab4Pass20CreateFromParsedPassERKNS_14ParserGrabPassE($61)|0);
     HEAP32[$10>>2] = $273;
     __ZN13dynamic_arrayIPN9ShaderLab4PassELj4EE9push_backERKS2_($12,$10);
     $274 = HEAP32[$41>>2]|0;
     $275 = (($274) + 1)|0;
     HEAP32[$41>>2] = $275;
    }
    $276 = (($i$0110) + 1)|0;
    $277 = HEAP32[$15>>2]|0;
    $278 = HEAP32[$parsed>>2]|0;
    $279 = $277;
    $280 = $278;
    $281 = (($279) - ($280))|0;
    $282 = $281 >> 2;
    $283 = ($276>>>0)<($282>>>0);
    if ($283) {
     $60 = $278;$i$0110 = $276;
    } else {
     break L13;
    }
   }
   switch (label|0) {
    case 15: {
     __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
     // unreachable;
     break;
    }
    case 28: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $107 = __THREW__; __THREW__ = 0;
     $108 = $107&1;
     if ($108) {
      $124 = ___cxa_find_matching_catch()|0;
      $125 = tempRet0;
      $lpad$phi29$index = $124;$lpad$phi29$index2 = $125;
      label = 37;
      break;
     } else {
      // unreachable;
     }
     break;
    }
    case 35: {
     $122 = ___cxa_find_matching_catch()|0;
     $123 = tempRet0;
     $lpad$phi29$index = $122;$lpad$phi29$index2 = $123;
     label = 37;
     break;
    }
    case 45: {
     $142 = ___cxa_find_matching_catch()|0;
     $143 = tempRet0;
     $$0$i = $143;$$01$i = $142;
     label = 48;
     break;
    }
    case 46: {
     $144 = ___cxa_find_matching_catch()|0;
     $145 = tempRet0;
     $146 = HEAP8[$4>>0]|0;
     $147 = $146 & 1;
     $148 = ($147<<24>>24)==(0);
     if ($148) {
      $$0$i = $145;$$01$i = $144;
      label = 48;
     } else {
      $149 = HEAP32[$46>>2]|0;
      __ZdlPv($149);
      $$0$i = $145;$$01$i = $144;
      label = 48;
     }
     break;
    }
    case 51: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $160 = __THREW__; __THREW__ = 0;
     $161 = $160&1;
     if ($161) {
      $267 = ___cxa_find_matching_catch()|0;
      $268 = tempRet0;
      $eh$lpad$body$index17Z2D = $268;$eh$lpad$body$indexZ2D = $267;
      break;
     } else {
      // unreachable;
     }
     break;
    }
    case 59: {
     $176 = ___cxa_find_matching_catch()|0;
     $177 = tempRet0;
     $$2$i = $177;$$23$i = $176;
     label = 89;
     break;
    }
    case 61: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $185 = __THREW__; __THREW__ = 0;
     $186 = $185&1;
     if ($186) {
      $220 = ___cxa_find_matching_catch()|0;
      $221 = tempRet0;
      $lpad$phi$i$index = $220;$lpad$phi$i$index8 = $221;
      label = 77;
      break;
     } else {
      // unreachable;
     }
     break;
    }
    case 71: {
     $207 = ___cxa_find_matching_catch()|0;
     $208 = tempRet0;
     ___cxa_call_unexpected(($207|0));
     // unreachable;
     break;
    }
    case 74: {
     $216 = ___cxa_find_matching_catch()|0;
     $217 = tempRet0;
     $lpad$phi$i$index = $216;$lpad$phi$i$index8 = $217;
     label = 77;
     break;
    }
    case 75: {
     $218 = ___cxa_find_matching_catch()|0;
     $219 = tempRet0;
     $lpad$phi$i$index = $218;$lpad$phi$i$index8 = $219;
     label = 77;
     break;
    }
    case 78: {
     $222 = ___cxa_find_matching_catch()|0;
     $223 = tempRet0;
     $224 = HEAP8[$6>>0]|0;
     $225 = $224 & 1;
     $226 = ($225<<24>>24)==(0);
     if ($226) {
      $$1$i = $223;$$12$i = $222;
      label = 86;
     } else {
      $227 = HEAP32[$56>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($227|0),($$byval_copy33|0));
      $228 = __THREW__; __THREW__ = 0;
      $229 = $228&1;
      if ($229) {
       $230 = ___cxa_find_matching_catch()|0;
       $231 = tempRet0;
       ___cxa_call_unexpected(($230|0));
       // unreachable;
      } else {
       $$1$i = $223;$$12$i = $222;
       label = 86;
      }
     }
     break;
    }
    case 96: {
     $263 = HEAP32[628272>>2]|0;
     $264 = ($12|0)==(0|0);
     if (!($264)) {
      __ZN9ShaderLab9SubShaderD2Ev($12);
     }
     HEAP32[$0>>2] = $263;
     ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($12,$$byval_copy33);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 99: {
     $265 = ___cxa_find_matching_catch()|0;
     $266 = tempRet0;
     $eh$lpad$body$index17Z2D = $266;$eh$lpad$body$indexZ2D = $265;
     break;
    }
   }
   if ((label|0) == 37) {
    $126 = HEAP8[$5>>0]|0;
    $127 = $126 & 1;
    $128 = ($127<<24>>24)==(0);
    if ($128) {
     $eh$lpad$body$index17Z2D = $lpad$phi29$index2;$eh$lpad$body$indexZ2D = $lpad$phi29$index;
    } else {
     $129 = HEAP32[$45>>2]|0;
     __ZdlPv($129);
     $eh$lpad$body$index17Z2D = $lpad$phi29$index2;$eh$lpad$body$indexZ2D = $lpad$phi29$index;
    }
   }
   else if ((label|0) == 48) {
    $150 = HEAP8[$5>>0]|0;
    $151 = $150 & 1;
    $152 = ($151<<24>>24)==(0);
    if ($152) {
     $$3$i = $$0$i;$$34$i = $$01$i;
     label = 91;
    } else {
     $153 = HEAP32[$45>>2]|0;
     __ZdlPv($153);
     $$3$i = $$0$i;$$34$i = $$01$i;
     label = 91;
    }
   }
   else if ((label|0) == 77) {
    $$1$i = $lpad$phi$i$index8;$$12$i = $lpad$phi$i$index;
    label = 86;
   }
   do {
    if ((label|0) == 86) {
     $242 = HEAP32[$53>>2]|0;
     $243 = ($242|0)>(-1);
     if ($243) {
      $244 = HEAP32[$foundPasses$i>>2]|0;
      $245 = HEAP32[$54>>2]|0;
      HEAP32[$0>>2] = $245;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($244|0),($$byval_copy33|0));
      $246 = __THREW__; __THREW__ = 0;
      $247 = $246&1;
      if ($247) {
       $252 = ___cxa_find_matching_catch(0|0)|0;
       $253 = tempRet0;
       ___clang_call_terminate($252);
       // unreachable;
      } else {
       HEAP32[$foundPasses$i>>2] = 0;
       $$2$i = $$1$i;$$23$i = $$12$i;
       label = 89;
       break;
      }
     } else {
      $$2$i = $$1$i;$$23$i = $$12$i;
      label = 89;
     }
    }
   } while(0);
   if ((label|0) == 89) {
    $248 = HEAP8[$shaderName$i>>0]|0;
    $249 = $248 & 1;
    $250 = ($249<<24>>24)==(0);
    if ($250) {
     $$3$i = $$2$i;$$34$i = $$23$i;
     label = 91;
    } else {
     $251 = HEAP32[$51>>2]|0;
     __ZdlPv($251);
     $$3$i = $$2$i;$$34$i = $$23$i;
     label = 91;
    }
   }
   if ((label|0) == 91) {
    $eh$lpad$body$index17Z2D = $$3$i;$eh$lpad$body$indexZ2D = $$34$i;
   }
   $269 = HEAP8[$9>>0]|0;
   $270 = $269 & 1;
   $271 = ($270<<24>>24)==(0);
   if ($271) {
    $$01 = $eh$lpad$body$indexZ2D;$$02 = $eh$lpad$body$index17Z2D;
    ___resumeException($$01|0);
    // unreachable;
   }
   $272 = HEAP32[$47>>2]|0;
   __ZdlPv($272);
   $$01 = $eh$lpad$body$indexZ2D;$$02 = $eh$lpad$body$index17Z2D;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $284 = (($12) + 20|0);
 $285 = (($parsed) + 12|0);
 $286 = HEAP32[$285>>2]|0;
 $287 = (($parsed) + 16|0);
 $288 = (($12) + 24|0);
 $289 = ($286|0)==($287|0);
 if (!($289)) {
  $290 = (($12) + 28|0);
  $292 = $286;
  while(1) {
   $291 = (($292) + 16|0);
   $293 = $291;
   $294 = $293;
   $295 = HEAP32[$294>>2]|0;
   $296 = (($293) + 4)|0;
   $297 = $296;
   $298 = HEAP32[$297>>2]|0;
   $299 = $3;
   $300 = $299;
   HEAP32[$300>>2] = $295;
   $301 = (($299) + 4)|0;
   $302 = $301;
   HEAP32[$302>>2] = $298;
   HEAP32[$1>>2] = $288;
   ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$1+0>>2]|0;
   $303 = (__ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($284,$$byval_copy33,$0,$3)|0);
   $304 = HEAP32[$303>>2]|0;
   $305 = ($304|0)==(0|0);
   if ($305) {
    $306 = (__Znwj(24)|0);
    $307 = (($306) + 16|0);
    $308 = $3;
    $309 = $308;
    $310 = HEAP32[$309>>2]|0;
    $311 = (($308) + 4)|0;
    $312 = $311;
    $313 = HEAP32[$312>>2]|0;
    $314 = $307;
    $315 = $314;
    HEAP32[$315>>2] = $310;
    $316 = (($314) + 4)|0;
    $317 = $316;
    HEAP32[$317>>2] = $313;
    $318 = HEAP32[$0>>2]|0;
    HEAP32[$306>>2] = 0;
    $319 = (($306) + 4|0);
    HEAP32[$319>>2] = 0;
    $320 = (($306) + 8|0);
    HEAP32[$320>>2] = $318;
    HEAP32[$303>>2] = $306;
    $321 = HEAP32[$284>>2]|0;
    $322 = HEAP32[$321>>2]|0;
    $323 = ($322|0)==(0|0);
    if ($323) {
     $325 = $306;
    } else {
     HEAP32[$284>>2] = $322;
     $$pre$i$i$i$i = HEAP32[$303>>2]|0;
     $325 = $$pre$i$i$i$i;
    }
    $324 = HEAP32[$288>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($324,$325);
    $326 = HEAP32[$290>>2]|0;
    $327 = (($326) + 1)|0;
    HEAP32[$290>>2] = $327;
   }
   $328 = (($292) + 4|0);
   $329 = HEAP32[$328>>2]|0;
   $330 = ($329|0)==(0|0);
   if ($330) {
    $$01$i$i$i$i = $292;
    while(1) {
     $333 = (($$01$i$i$i$i) + 8|0);
     $334 = HEAP32[$333>>2]|0;
     $335 = HEAP32[$334>>2]|0;
     $336 = ($335|0)==($$01$i$i$i$i|0);
     if ($336) {
      $$0$i$i$i$i = $334;
      break;
     } else {
      $$01$i$i$i$i = $334;
     }
    }
   } else {
    $$0$i$i$i$i$i = $329;
    while(1) {
     $331 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $332 = ($331|0)==(0|0);
     if ($332) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $331;
     }
    }
   }
   $337 = ($$0$i$i$i$i|0)==($287|0);
   if ($337) {
    break;
   } else {
    $292 = $$0$i$i$i$i;
   }
  }
 }
 $338 = (($parsed) + 24|0);
 $339 = HEAP32[$338>>2]|0;
 $340 = (($12) + 32|0);
 HEAP32[$340>>2] = $339;
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13dynamic_arrayIPN9ShaderLab4PassELj4EE9push_backERKS2_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$t>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if (!($8)) {
  $27 = $4;
  $26 = (($27) + -1)|0;
  $28 = HEAP32[$this>>2]|0;
  $29 = (($28) + ($26<<2)|0);
  HEAP32[$29>>2] = $1;
  STACKTOP = sp;return;
 }
 $9 = $6 << 1;
 $10 = ($9|0)==(0);
 $11 = $10 ? 1 : $9;
 $12 = ($7>>>0)<($11>>>0);
 do {
  if ($12) {
   $13 = ($6|0)>(-1);
   if ($13) {
    HEAP32[$5>>2] = $11;
    $14 = HEAP32[$this>>2]|0;
    $15 = $11 << 2;
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy1,0,678976,370)|0);
    HEAP32[$this>>2] = $18;
    break;
   } else {
    $19 = $11 << 2;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,678976,352)|0);
    $23 = HEAP32[$this>>2]|0;
    $24 = HEAP32[$2>>2]|0;
    $25 = $24 << 2;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$5>>2] = $11;
    HEAP32[$this>>2] = $22;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$2>>2]|0;
 $27 = $$pre$i;
 $26 = (($27) + -1)|0;
 $28 = HEAP32[$this>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAP32[$29>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab4Pass20CreateFromParsedPassERKNS_10ParserPassER12ShaderErrorsPK6Shader($parsed,$outErrors,$fromShader) {
 $parsed = $parsed|0;
 $outErrors = $outErrors|0;
 $fromShader = $fromShader|0;
 var $$$i$i = 0, $$$i$i19 = 0, $$$i$i5 = 0, $$$i$i51 = 0, $$$i$i65 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$arith = 0, $$byval_copy9 = 0, $$idx$i = 0, $$idx$val = 0, $$idx$val$i = 0, $$idx1$i = 0, $$idx1$val$i = 0, $$idx2$i = 0, $$idx2$val$i = 0, $$idx3$i = 0, $$idx3$val$i = 0, $$neg2$i$i$i$i$i = 0;
 var $$neg2$i$i$i$i$i11 = 0, $$neg2$i$i$i$i$i25 = 0, $$neg2$i$i$i$i$i43 = 0, $$neg2$i$i$i$i$i57 = 0, $$neg2$i$i$i$i$i71 = 0, $$not$i = 0, $$not$i18 = 0, $$not$i4 = 0, $$not$i50 = 0, $$not$i64 = 0, $$overflow = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i10 = 0, $$sum$i$i$i$i$i24 = 0, $$sum$i$i$i$i$i42 = 0, $$sum$i$i$i$i$i56 = 0, $$sum$i$i$i$i$i70 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0);
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = Math_fround(0), $378 = Math_fround(0), $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i12 = 0, $__len$0$be$i$i$i$i$i26 = 0, $__len$0$be$i$i$i$i$i44 = 0, $__len$0$be$i$i$i$i$i58 = 0, $__len$0$be$i$i$i$i$i72 = 0, $__len$03$i$i$i$i$i = 0, $__len$03$i$i$i$i$i23 = 0, $__len$03$i$i$i$i$i41 = 0, $__len$03$i$i$i$i$i55 = 0, $__len$03$i$i$i$i$i69 = 0, $__len$03$i$i$i$i$i9 = 0, $__new_last2$i$i$i$i$i = 0, $exitcond = 0, $exitcond$i = 0, $i$01$i = 0;
 var $i$0122 = 0, $i1$0119 = 0, $idx$i35 = 0, $idx$i49 = 0, $idx$i63 = 0, $or$cond$i = 0, $or$cond$i20 = 0, $or$cond$i34 = 0, $or$cond$i52 = 0, $or$cond$i6 = 0, $or$cond$i66 = 0, $phitmp$i = 0, $phitmp14$i = 0, $phitmp16$i = 0, $phitmp18$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy9 = sp + 68|0;
 $0 = sp + 64|0;
 $1 = sp + 60|0;
 $idx$i63 = sp;
 $2 = sp + 56|0;
 $3 = sp + 52|0;
 $idx$i49 = sp + 48|0;
 $4 = sp + 44|0;
 $5 = sp + 12|0;
 $idx$i35 = sp + 20|0;
 $6 = sp + 8|0;
 $7 = sp + 16|0;
 $8 = sp + 24|0;
 $9 = sp + 28|0;
 $10 = sp + 32|0;
 $11 = sp + 36|0;
 $12 = sp + 40|0;
 $13 = HEAP32[628272>>2]|0;
 HEAP32[$12>>2] = $13;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$12+0>>2]|0;
 $14 = (__Znwj10MemLabelIdbiPKci(696,$$byval_copy9,0,16,678976,354)|0);
 __THREW__ = 0;
 invoke_vii(3267,($14|0),0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $98 = ___cxa_find_matching_catch()|0;
  $99 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$12+0>>2]|0;
  invoke_viiiiii(97,($14|0),($$byval_copy9|0),0,16,(678976|0),354);
  $100 = __THREW__; __THREW__ = 0;
  $101 = $100&1;
  if ($101) {
   $385 = ___cxa_find_matching_catch(0|0)|0;
   $386 = tempRet0;
   ___clang_call_terminate($385);
   // unreachable;
  } else {
   ___resumeException($98|0);
   // unreachable;
  }
 }
 $17 = (($14) + 680|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($14) + 684|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==($18|0);
 if (!($21)) {
  $__new_last2$i$i$i$i$i = $18;
  $scevgep$i$i$i$i$i = (($20) + -4|0);
  $22 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($22)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $23 = $uglygep3$i$i$i$i$i >>> 2;
  $24 = $23 ^ -1;
  $scevgep4$i$i$i$i$i = (($20) + ($24<<2)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i;
 }
 $25 = (($14) + 692|0);
 HEAP32[$25>>2] = 0;
 $26 = (($14) + 4|0);
 $27 = (($parsed) + 8|0);
 __ZN9ShaderLab11ShaderState21FromParsedShaderStateERKNS_17ParserShaderStateEP16PropertyNamesSet($26,$27,$17);
 $28 = (($14) + 592|0);
 $i$01$i = 0;
 while(1) {
  $29 = ((($parsed) + ($i$01$i<<2)|0) + 528|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = $30&255;
  $32 = ((($28) + ($i$01$i)|0) + 8|0);
  HEAP8[$32>>0] = $31;
  $33 = (($i$01$i) + 1)|0;
  $exitcond$i = ($33|0)==(28);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $33;
  }
 }
 $34 = (($parsed) + 644|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($14) + 596|0);
 HEAP32[$36>>2] = $35;
 $37 = (($parsed) + 640|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$28>>2] = $38;
 $39 = (($14) + 664|0);
 $40 = (($parsed) + 648|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($parsed) + 652|0);
 $43 = (($14) + 668|0);
 $44 = ($41|0)==($42|0);
 if (!($44)) {
  $45 = (($14) + 672|0);
  $47 = $41;
  while(1) {
   $46 = (($47) + 16|0);
   $48 = $46;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $idx$i63;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$1>>2] = $43;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
   $58 = (__ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($39,$$byval_copy9,$0,$idx$i63)|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0|0);
   if ($60) {
    $61 = (__Znwj(24)|0);
    $62 = (($61) + 16|0);
    $63 = $idx$i63;
    $64 = $63;
    $65 = HEAP32[$64>>2]|0;
    $66 = (($63) + 4)|0;
    $67 = $66;
    $68 = HEAP32[$67>>2]|0;
    $69 = $62;
    $70 = $69;
    HEAP32[$70>>2] = $65;
    $71 = (($69) + 4)|0;
    $72 = $71;
    HEAP32[$72>>2] = $68;
    $73 = HEAP32[$0>>2]|0;
    HEAP32[$61>>2] = 0;
    $74 = (($61) + 4|0);
    HEAP32[$74>>2] = 0;
    $75 = (($61) + 8|0);
    HEAP32[$75>>2] = $73;
    HEAP32[$58>>2] = $61;
    $76 = HEAP32[$39>>2]|0;
    $77 = HEAP32[$76>>2]|0;
    $78 = ($77|0)==(0|0);
    if ($78) {
     $80 = $61;
    } else {
     HEAP32[$39>>2] = $77;
     $$pre$i$i$i$i = HEAP32[$58>>2]|0;
     $80 = $$pre$i$i$i$i;
    }
    $79 = HEAP32[$43>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($79,$80);
    $81 = HEAP32[$45>>2]|0;
    $82 = (($81) + 1)|0;
    HEAP32[$45>>2] = $82;
   }
   $83 = (($47) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    $$01$i$i$i$i = $47;
    while(1) {
     $88 = (($$01$i$i$i$i) + 8|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = HEAP32[$89>>2]|0;
     $91 = ($90|0)==($$01$i$i$i$i|0);
     if ($91) {
      $$0$i$i$i$i = $89;
      break;
     } else {
      $$01$i$i$i$i = $89;
     }
    }
   } else {
    $$0$i$i$i$i$i = $84;
    while(1) {
     $86 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $87 = ($86|0)==(0|0);
     if ($87) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $86;
     }
    }
   }
   $92 = ($$0$i$i$i$i|0)==($42|0);
   if ($92) {
    break;
   } else {
    $47 = $$0$i$i$i$i;
   }
  }
 }
 $93 = (($14) + 628|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($93,$27)|0);
 $94 = (($parsed) + 520|0);
 $i$0122 = 0;
 while(1) {
  $95 = ((($parsed) + ($i$0122<<2)|0) + 676|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = ($96|0)==(0|0);
  if (!($97)) {
   $102 = HEAP32[$94>>2]|0;
   $103 = (__ZN9ShaderLab7Program23CreateFromParsedProgramERKNS_13ParserProgramE10ShaderTypeiP16PropertyNamesSetPK6Shader($96,$i$0122,$102,$17,$fromShader)|0);
   __ZN9ShaderLab11ShaderState10SetProgramE10ShaderTypePNS_7ProgramEPK6Shader($26,$i$0122,$103,$fromShader);
   $104 = (($103) + 4|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + -1)|0;
   HEAP32[$104>>2] = $106;
   $107 = HEAP32[$104>>2]|0;
   $108 = ($107|0)!=(0);
   $109 = ($103|0)==(0|0);
   $or$cond$i34 = $108 | $109;
   if (!($or$cond$i34)) {
    $110 = HEAP32[$103>>2]|0;
    $111 = (($110) + 4|0);
    $112 = HEAP32[$111>>2]|0;
    FUNCTION_TABLE_vi[$112 & 4095]($103);
   }
  }
  $113 = (($i$0122) + 1)|0;
  $exitcond = ($113|0)==(6);
  if ($exitcond) {
   break;
  } else {
   $i$0122 = $113;
  }
 }
 __ZN9ShaderLab11ShaderState25RemoveUnsupportedProgramsEPK6Shader($26,$fromShader);
 $114 = (($parsed) + 668|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = (($parsed) + 664|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = $115;
 $119 = $117;
 $120 = (($118) - ($119))|0;
 $121 = (($120|0) / 52)&-1;
 $122 = (($14) + 644|0);
 HEAP32[$122>>2] = $121;
 $$arith = ($121*52)|0;
 $$overflow = ($121>>>0)>(82595524);
 $123 = $$overflow ? -1 : $$arith;
 $124 = (__Znaj($123)|0);
 $125 = ($115|0)==($117|0);
 if ($125) {
  $126 = (($14) + 648|0);
  HEAP32[$126>>2] = $124;
  STACKTOP = sp;return ($14|0);
 }
 $127 = (($124) + (($121*52)|0)|0);
 $129 = $124;
 while(1) {
  $128 = (($129) + 12|0);
  $130 = (($129) + 16|0);
  $131 = (($129) + 20|0);
  $132 = (($129) + 24|0);
  $133 = (($129) + 28|0);
  $134 = (($129) + 32|0);
  $135 = (($129) + 36|0);
  $136 = (($129) + 40|0);
  $137 = (($129) + 44|0);
  $138 = (($129) + 4|0);
  HEAP32[$138>>2] = 16842752;
  $139 = (($129) + 8|0);
  HEAP32[$139>>2] = 17104900;
  HEAP32[$129>>2] = -1;
  HEAP32[$137>>2] = -1;
  HEAP32[$130>>2] = -1;
  HEAPF32[$128>>2] = Math_fround(0.0);
  HEAP32[$132>>2] = -1;
  HEAPF32[$131>>2] = Math_fround(0.0);
  HEAP32[$134>>2] = -1;
  HEAPF32[$133>>2] = Math_fround(0.0);
  HEAP32[$136>>2] = -1;
  HEAPF32[$135>>2] = Math_fround(0.0);
  $140 = (($129) + 48|0);
  HEAP8[$140>>0] = 0;
  $141 = (($129) + 49|0);
  HEAP8[$141>>0] = 0;
  $142 = (($129) + 52|0);
  $143 = ($142|0)==($127|0);
  if ($143) {
   break;
  } else {
   $129 = $142;
  }
 }
 $144 = (($14) + 648|0);
 HEAP32[$144>>2] = $124;
 if ($125) {
  STACKTOP = sp;return ($14|0);
 }
 $149 = $124;$i1$0119 = 0;
 while(1) {
  $145 = HEAP32[$116>>2]|0;
  $146 = (($145) + (($i1$0119*52)|0)|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = (($149) + (($i1$0119*52)|0)|0);
  HEAP32[$148>>2] = $147;
  $$idx$val = HEAP32[$146>>2]|0;
  $150 = ($$idx$val|0)!=(-1);
  $$not$i50 = $150 ^ 1;
  $151 = ($$idx$val>>>0)>(1073741823);
  $$$i$i51 = $150 & $151;
  $or$cond$i52 = $$$i$i51 | $$not$i50;
  do {
   if (!($or$cond$i52)) {
    HEAP32[$idx$i49>>2] = $$idx$val;
    $152 = HEAP32[$17>>2]|0;
    $153 = HEAP32[$19>>2]|0;
    $154 = $153;
    $155 = $152;
    $156 = (($154) - ($155))|0;
    $157 = $156 >> 2;
    $158 = ($157|0)==(0);
    if ($158) {
     $168 = $152;
    } else {
     $161 = $152;$__len$03$i$i$i$i$i55 = $157;
     while(1) {
      $159 = (($__len$03$i$i$i$i$i55|0) / 2)&-1;
      $160 = (($161) + ($159<<2)|0);
      $162 = HEAP32[$160>>2]|0;
      $163 = ($162|0)<($$idx$val|0);
      if ($163) {
       $$sum$i$i$i$i$i56 = (($159) + 1)|0;
       $164 = (($161) + ($$sum$i$i$i$i$i56<<2)|0);
       $$neg2$i$i$i$i$i57 = (($__len$03$i$i$i$i$i55) + -1)|0;
       $165 = (($$neg2$i$i$i$i$i57) - ($159))|0;
       $387 = $164;$__len$0$be$i$i$i$i$i58 = $165;
      } else {
       $387 = $161;$__len$0$be$i$i$i$i$i58 = $159;
      }
      $166 = ($__len$0$be$i$i$i$i$i58|0)==(0);
      if ($166) {
       $168 = $387;
       break;
      } else {
       $161 = $387;$__len$03$i$i$i$i$i55 = $__len$0$be$i$i$i$i$i58;
      }
     }
    }
    $167 = ($168|0)==($153|0);
    if (!($167)) {
     $169 = HEAP32[$168>>2]|0;
     $170 = ($$idx$val|0)<($169|0);
     if (!($170)) {
      break;
     }
    }
    HEAP32[$3>>2] = $168;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($2,$17,$$byval_copy9,$idx$i49);
    $171 = HEAP32[$25>>2]|0;
    $172 = (Math_fround(($171>>>0)));
    $173 = Math_fround($172 + Math_fround(12.0));
    $174 = (~~(($173))>>>0);
    HEAP32[$25>>2] = $174;
   }
  } while(0);
  $175 = ((($145) + (($i1$0119*52)|0)|0) + 4|0);
  $176 = HEAP32[$175>>2]|0;
  $177 = ((($149) + (($i1$0119*52)|0)|0) + 4|0);
  HEAP32[$177>>2] = $176;
  $178 = ((($145) + (($i1$0119*52)|0)|0) + 8|0);
  $179 = HEAP32[$178>>2]|0;
  $180 = ((($149) + (($i1$0119*52)|0)|0) + 8|0);
  HEAP32[$180>>2] = $179;
  $181 = ((($145) + (($i1$0119*52)|0)|0) + 48|0);
  $182 = HEAP8[$181>>0]|0;
  $183 = ($182<<24>>24)==(0);
  do {
   if (!($183)) {
    $184 = ((($145) + (($i1$0119*52)|0)|0) + 44|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ($185|0)==(-1);
    if ($186) {
     $187 = ((($145) + (($i1$0119*52)|0)|0) + 16|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = ($188|0)==(-1);
     if ($189) {
      $190 = ((($145) + (($i1$0119*52)|0)|0) + 12|0);
      $191 = Math_fround(HEAPF32[$190>>2]);
      $phitmp$i = (HEAPF32[tempDoublePtr>>2]=$191,HEAP32[tempDoublePtr>>2]|0);
      $388 = -1;$389 = $phitmp$i;$390 = 0;
     } else {
      $388 = $188;$389 = 0;$390 = 0;
     }
     $192 = ((($145) + (($i1$0119*52)|0)|0) + 24|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = ($193|0)==(-1);
     if ($194) {
      $195 = ((($145) + (($i1$0119*52)|0)|0) + 20|0);
      $196 = Math_fround(HEAPF32[$195>>2]);
      $phitmp14$i = (HEAPF32[tempDoublePtr>>2]=$196,HEAP32[tempDoublePtr>>2]|0);
      $391 = -1;$392 = $phitmp14$i;$393 = 0;
     } else {
      $391 = $193;$392 = 0;$393 = 0;
     }
     $197 = ((($145) + (($i1$0119*52)|0)|0) + 32|0);
     $198 = HEAP32[$197>>2]|0;
     $199 = ($198|0)==(-1);
     if ($199) {
      $200 = ((($145) + (($i1$0119*52)|0)|0) + 28|0);
      $201 = Math_fround(HEAPF32[$200>>2]);
      $phitmp16$i = (HEAPF32[tempDoublePtr>>2]=$201,HEAP32[tempDoublePtr>>2]|0);
      $394 = -1;$395 = $phitmp16$i;$396 = 0;
     } else {
      $394 = $198;$395 = 0;$396 = 0;
     }
     $202 = ((($145) + (($i1$0119*52)|0)|0) + 40|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = ($203|0)==(-1);
     if ($204) {
      $205 = ((($145) + (($i1$0119*52)|0)|0) + 36|0);
      $206 = Math_fround(HEAPF32[$205>>2]);
      $phitmp18$i = (HEAPF32[tempDoublePtr>>2]=$206,HEAP32[tempDoublePtr>>2]|0);
      $397 = -1;$398 = $phitmp18$i;$399 = 0;
     } else {
      $397 = $203;$398 = 0;$399 = 0;
     }
     $209 = $389;$210 = 0;$212 = $390;$213 = $388;$220 = $392;$221 = 0;$223 = $393;$224 = $391;$231 = $395;$232 = 0;$234 = $396;$235 = $394;$242 = $398;$243 = 0;$245 = $399;$246 = $397;$252 = -1;
    } else {
     $209 = 0;$210 = 0;$212 = 0;$213 = -1;$220 = 0;$221 = 0;$223 = 0;$224 = -1;$231 = 0;$232 = 0;$234 = 0;$235 = -1;$242 = 0;$243 = 0;$245 = 0;$246 = -1;$252 = $185;
    }
    $207 = ((($149) + (($i1$0119*52)|0)|0) + 12|0);
    $208 = $209 | $210;
    $211 = $212 | $213;
    $214 = $207;
    $215 = $214;
    HEAP32[$215>>2] = $208;
    $216 = (($214) + 4)|0;
    $217 = $216;
    HEAP32[$217>>2] = $211;
    $218 = ((($149) + (($i1$0119*52)|0)|0) + 20|0);
    $219 = $220 | $221;
    $222 = $223 | $224;
    $225 = $218;
    $226 = $225;
    HEAP32[$226>>2] = $219;
    $227 = (($225) + 4)|0;
    $228 = $227;
    HEAP32[$228>>2] = $222;
    $229 = ((($149) + (($i1$0119*52)|0)|0) + 28|0);
    $230 = $231 | $232;
    $233 = $234 | $235;
    $236 = $229;
    $237 = $236;
    HEAP32[$237>>2] = $230;
    $238 = (($236) + 4)|0;
    $239 = $238;
    HEAP32[$239>>2] = $233;
    $240 = ((($149) + (($i1$0119*52)|0)|0) + 36|0);
    $241 = $242 | $243;
    $244 = $245 | $246;
    $247 = $240;
    $248 = $247;
    HEAP32[$248>>2] = $241;
    $249 = (($247) + 4)|0;
    $250 = $249;
    HEAP32[$250>>2] = $244;
    $251 = ((($149) + (($i1$0119*52)|0)|0) + 44|0);
    HEAP32[$251>>2] = $252;
    $253 = ((($149) + (($i1$0119*52)|0)|0) + 48|0);
    HEAP8[$253>>0] = 1;
    $254 = HEAP32[$184>>2]|0;
    $255 = ($254|0)==(-1);
    if (!($255)) {
     $256 = ($254>>>0)>(1073741823);
     if ($256) {
      break;
     }
     HEAP32[$idx$i35>>2] = $254;
     $257 = HEAP32[$17>>2]|0;
     $258 = HEAP32[$19>>2]|0;
     $259 = $258;
     $260 = $257;
     $261 = (($259) - ($260))|0;
     $262 = $261 >> 2;
     $263 = ($262|0)==(0);
     if ($263) {
      $273 = $257;
     } else {
      $266 = $257;$__len$03$i$i$i$i$i41 = $262;
      while(1) {
       $264 = (($__len$03$i$i$i$i$i41|0) / 2)&-1;
       $265 = (($266) + ($264<<2)|0);
       $267 = HEAP32[$265>>2]|0;
       $268 = ($267|0)<($254|0);
       if ($268) {
        $$sum$i$i$i$i$i42 = (($264) + 1)|0;
        $269 = (($266) + ($$sum$i$i$i$i$i42<<2)|0);
        $$neg2$i$i$i$i$i43 = (($__len$03$i$i$i$i$i41) + -1)|0;
        $270 = (($$neg2$i$i$i$i$i43) - ($264))|0;
        $400 = $269;$__len$0$be$i$i$i$i$i44 = $270;
       } else {
        $400 = $266;$__len$0$be$i$i$i$i$i44 = $264;
       }
       $271 = ($__len$0$be$i$i$i$i$i44|0)==(0);
       if ($271) {
        $273 = $400;
        break;
       } else {
        $266 = $400;$__len$03$i$i$i$i$i41 = $__len$0$be$i$i$i$i$i44;
       }
      }
     }
     $272 = ($273|0)==($258|0);
     if (!($272)) {
      $274 = HEAP32[$273>>2]|0;
      $275 = ($254|0)<($274|0);
      if (!($275)) {
       break;
      }
     }
     HEAP32[$5>>2] = $273;
     ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$5+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($4,$17,$$byval_copy9,$idx$i35);
     $276 = HEAP32[$25>>2]|0;
     $277 = (Math_fround(($276>>>0)));
     $278 = Math_fround($277 + Math_fround(16.0));
     $279 = (~~(($278))>>>0);
     HEAP32[$25>>2] = $279;
     break;
    }
    $$idx3$i = ((($145) + (($i1$0119*52)|0)|0) + 16|0);
    $$idx3$val$i = HEAP32[$$idx3$i>>2]|0;
    $280 = ($$idx3$val$i|0)!=(-1);
    $$not$i18 = $280 ^ 1;
    $281 = ($$idx3$val$i>>>0)>(1073741823);
    $$$i$i19 = $280 & $281;
    $or$cond$i20 = $$$i$i19 | $$not$i18;
    do {
     if (!($or$cond$i20)) {
      HEAP32[$idx$i49>>2] = $$idx3$val$i;
      $282 = HEAP32[$17>>2]|0;
      $283 = HEAP32[$19>>2]|0;
      $284 = $283;
      $285 = $282;
      $286 = (($284) - ($285))|0;
      $287 = $286 >> 2;
      $288 = ($287|0)==(0);
      if ($288) {
       $298 = $282;
      } else {
       $291 = $282;$__len$03$i$i$i$i$i23 = $287;
       while(1) {
        $289 = (($__len$03$i$i$i$i$i23|0) / 2)&-1;
        $290 = (($291) + ($289<<2)|0);
        $292 = HEAP32[$290>>2]|0;
        $293 = ($292|0)<($$idx3$val$i|0);
        if ($293) {
         $$sum$i$i$i$i$i24 = (($289) + 1)|0;
         $294 = (($291) + ($$sum$i$i$i$i$i24<<2)|0);
         $$neg2$i$i$i$i$i25 = (($__len$03$i$i$i$i$i23) + -1)|0;
         $295 = (($$neg2$i$i$i$i$i25) - ($289))|0;
         $401 = $294;$__len$0$be$i$i$i$i$i26 = $295;
        } else {
         $401 = $291;$__len$0$be$i$i$i$i$i26 = $289;
        }
        $296 = ($__len$0$be$i$i$i$i$i26|0)==(0);
        if ($296) {
         $298 = $401;
         break;
        } else {
         $291 = $401;$__len$03$i$i$i$i$i23 = $__len$0$be$i$i$i$i$i26;
        }
       }
      }
      $297 = ($298|0)==($283|0);
      if (!($297)) {
       $299 = HEAP32[$298>>2]|0;
       $300 = ($$idx3$val$i|0)<($299|0);
       if (!($300)) {
        break;
       }
      }
      HEAP32[$7>>2] = $298;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$7+0>>2]|0;
      __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($6,$17,$$byval_copy9,$idx$i49);
      $301 = HEAP32[$25>>2]|0;
      $302 = (Math_fround(($301>>>0)));
      $303 = Math_fround($302 + Math_fround(4.0));
      $304 = (~~(($303))>>>0);
      HEAP32[$25>>2] = $304;
     }
    } while(0);
    $$idx2$i = ((($145) + (($i1$0119*52)|0)|0) + 24|0);
    $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
    $305 = ($$idx2$val$i|0)!=(-1);
    $$not$i4 = $305 ^ 1;
    $306 = ($$idx2$val$i>>>0)>(1073741823);
    $$$i$i5 = $305 & $306;
    $or$cond$i6 = $$$i$i5 | $$not$i4;
    do {
     if (!($or$cond$i6)) {
      HEAP32[$idx$i49>>2] = $$idx2$val$i;
      $307 = HEAP32[$17>>2]|0;
      $308 = HEAP32[$19>>2]|0;
      $309 = $308;
      $310 = $307;
      $311 = (($309) - ($310))|0;
      $312 = $311 >> 2;
      $313 = ($312|0)==(0);
      if ($313) {
       $323 = $307;
      } else {
       $316 = $307;$__len$03$i$i$i$i$i9 = $312;
       while(1) {
        $314 = (($__len$03$i$i$i$i$i9|0) / 2)&-1;
        $315 = (($316) + ($314<<2)|0);
        $317 = HEAP32[$315>>2]|0;
        $318 = ($317|0)<($$idx2$val$i|0);
        if ($318) {
         $$sum$i$i$i$i$i10 = (($314) + 1)|0;
         $319 = (($316) + ($$sum$i$i$i$i$i10<<2)|0);
         $$neg2$i$i$i$i$i11 = (($__len$03$i$i$i$i$i9) + -1)|0;
         $320 = (($$neg2$i$i$i$i$i11) - ($314))|0;
         $402 = $319;$__len$0$be$i$i$i$i$i12 = $320;
        } else {
         $402 = $316;$__len$0$be$i$i$i$i$i12 = $314;
        }
        $321 = ($__len$0$be$i$i$i$i$i12|0)==(0);
        if ($321) {
         $323 = $402;
         break;
        } else {
         $316 = $402;$__len$03$i$i$i$i$i9 = $__len$0$be$i$i$i$i$i12;
        }
       }
      }
      $322 = ($323|0)==($308|0);
      if (!($322)) {
       $324 = HEAP32[$323>>2]|0;
       $325 = ($$idx2$val$i|0)<($324|0);
       if (!($325)) {
        break;
       }
      }
      HEAP32[$9>>2] = $323;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$9+0>>2]|0;
      __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($8,$17,$$byval_copy9,$idx$i49);
      $326 = HEAP32[$25>>2]|0;
      $327 = (Math_fround(($326>>>0)));
      $328 = Math_fround($327 + Math_fround(4.0));
      $329 = (~~(($328))>>>0);
      HEAP32[$25>>2] = $329;
     }
    } while(0);
    $$idx1$i = ((($145) + (($i1$0119*52)|0)|0) + 32|0);
    $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
    $330 = ($$idx1$val$i|0)!=(-1);
    $$not$i = $330 ^ 1;
    $331 = ($$idx1$val$i>>>0)>(1073741823);
    $$$i$i = $330 & $331;
    $or$cond$i = $$$i$i | $$not$i;
    do {
     if (!($or$cond$i)) {
      HEAP32[$idx$i49>>2] = $$idx1$val$i;
      $332 = HEAP32[$17>>2]|0;
      $333 = HEAP32[$19>>2]|0;
      $334 = $333;
      $335 = $332;
      $336 = (($334) - ($335))|0;
      $337 = $336 >> 2;
      $338 = ($337|0)==(0);
      if ($338) {
       $348 = $332;
      } else {
       $341 = $332;$__len$03$i$i$i$i$i = $337;
       while(1) {
        $339 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
        $340 = (($341) + ($339<<2)|0);
        $342 = HEAP32[$340>>2]|0;
        $343 = ($342|0)<($$idx1$val$i|0);
        if ($343) {
         $$sum$i$i$i$i$i = (($339) + 1)|0;
         $344 = (($341) + ($$sum$i$i$i$i$i<<2)|0);
         $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
         $345 = (($$neg2$i$i$i$i$i) - ($339))|0;
         $403 = $344;$__len$0$be$i$i$i$i$i = $345;
        } else {
         $403 = $341;$__len$0$be$i$i$i$i$i = $339;
        }
        $346 = ($__len$0$be$i$i$i$i$i|0)==(0);
        if ($346) {
         $348 = $403;
         break;
        } else {
         $341 = $403;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
        }
       }
      }
      $347 = ($348|0)==($333|0);
      if (!($347)) {
       $349 = HEAP32[$348>>2]|0;
       $350 = ($$idx1$val$i|0)<($349|0);
       if (!($350)) {
        break;
       }
      }
      HEAP32[$11>>2] = $348;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$11+0>>2]|0;
      __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($10,$17,$$byval_copy9,$idx$i49);
      $351 = HEAP32[$25>>2]|0;
      $352 = (Math_fround(($351>>>0)));
      $353 = Math_fround($352 + Math_fround(4.0));
      $354 = (~~(($353))>>>0);
      HEAP32[$25>>2] = $354;
     }
    } while(0);
    $$idx$i = ((($145) + (($i1$0119*52)|0)|0) + 40|0);
    $$idx$val$i = HEAP32[$$idx$i>>2]|0;
    $355 = ($$idx$val$i|0)!=(-1);
    $$not$i64 = $355 ^ 1;
    $356 = ($$idx$val$i>>>0)>(1073741823);
    $$$i$i65 = $355 & $356;
    $or$cond$i66 = $$$i$i65 | $$not$i64;
    if (!($or$cond$i66)) {
     HEAP32[$idx$i63>>2] = $$idx$val$i;
     $357 = HEAP32[$17>>2]|0;
     $358 = HEAP32[$19>>2]|0;
     $359 = $358;
     $360 = $357;
     $361 = (($359) - ($360))|0;
     $362 = $361 >> 2;
     $363 = ($362|0)==(0);
     if ($363) {
      $373 = $357;
     } else {
      $366 = $357;$__len$03$i$i$i$i$i69 = $362;
      while(1) {
       $364 = (($__len$03$i$i$i$i$i69|0) / 2)&-1;
       $365 = (($366) + ($364<<2)|0);
       $367 = HEAP32[$365>>2]|0;
       $368 = ($367|0)<($$idx$val$i|0);
       if ($368) {
        $$sum$i$i$i$i$i70 = (($364) + 1)|0;
        $369 = (($366) + ($$sum$i$i$i$i$i70<<2)|0);
        $$neg2$i$i$i$i$i71 = (($__len$03$i$i$i$i$i69) + -1)|0;
        $370 = (($$neg2$i$i$i$i$i71) - ($364))|0;
        $404 = $369;$__len$0$be$i$i$i$i$i72 = $370;
       } else {
        $404 = $366;$__len$0$be$i$i$i$i$i72 = $364;
       }
       $371 = ($__len$0$be$i$i$i$i$i72|0)==(0);
       if ($371) {
        $373 = $404;
        break;
       } else {
        $366 = $404;$__len$03$i$i$i$i$i69 = $__len$0$be$i$i$i$i$i72;
       }
      }
     }
     $372 = ($373|0)==($358|0);
     if (!($372)) {
      $374 = HEAP32[$373>>2]|0;
      $375 = ($$idx$val$i|0)<($374|0);
      if (!($375)) {
       break;
      }
     }
     HEAP32[$1>>2] = $373;
     ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($0,$17,$$byval_copy9,$idx$i63);
     $376 = HEAP32[$25>>2]|0;
     $377 = (Math_fround(($376>>>0)));
     $378 = Math_fround($377 + Math_fround(4.0));
     $379 = (~~(($378))>>>0);
     HEAP32[$25>>2] = $379;
    }
   }
  } while(0);
  $380 = ((($145) + (($i1$0119*52)|0)|0) + 49|0);
  $381 = HEAP8[$380>>0]|0;
  $382 = ((($149) + (($i1$0119*52)|0)|0) + 49|0);
  HEAP8[$382>>0] = $381;
  $383 = (($i1$0119) + 1)|0;
  $384 = ($383>>>0)<($121>>>0);
  if (!($384)) {
   break;
  }
  $$pre = HEAP32[$144>>2]|0;
  $149 = $$pre;$i1$0119 = $383;
 }
 STACKTOP = sp;return ($14|0);
}
function __ZN9ShaderLab4Pass20CreateFromParsedPassERKNS_14ParserGrabPassE($parsed) {
 $parsed = $parsed|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy2 = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $__parent$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $__parent$i$i$i = sp + 12|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = HEAP32[628272>>2]|0;
 HEAP32[$2>>2] = $3;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 $4 = (__Znwj10MemLabelIdbiPKci(696,$$byval_copy2,0,16,678976,401)|0);
 __THREW__ = 0;
 invoke_vii(3267,($4|0),2);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_viiiiii(97,($4|0),($$byval_copy2|0),0,16,(678976|0),401);
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  } else {
   ___resumeException($78|0);
   // unreachable;
  }
 }
 $7 = (($4) + 628|0);
 $8 = (($parsed) + 8|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($7,$8)|0);
 $9 = (($4) + 664|0);
 $10 = (($parsed) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($parsed) + 36|0);
 $13 = (($4) + 668|0);
 $14 = ($11|0)==($12|0);
 if (!($14)) {
  $15 = (($4) + 672|0);
  $17 = $11;
  while(1) {
   $16 = (($17) + 16|0);
   $18 = $16;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 4)|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = $1;
   $25 = $24;
   HEAP32[$25>>2] = $20;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = $23;
   HEAP32[$0>>2] = $13;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $28 = (__ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($9,$$byval_copy2,$__parent$i$i$i,$1)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    $31 = (__Znwj(24)|0);
    $32 = (($31) + 16|0);
    $33 = $1;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = (($33) + 4)|0;
    $37 = $36;
    $38 = HEAP32[$37>>2]|0;
    $39 = $32;
    $40 = $39;
    HEAP32[$40>>2] = $35;
    $41 = (($39) + 4)|0;
    $42 = $41;
    HEAP32[$42>>2] = $38;
    $43 = HEAP32[$__parent$i$i$i>>2]|0;
    HEAP32[$31>>2] = 0;
    $44 = (($31) + 4|0);
    HEAP32[$44>>2] = 0;
    $45 = (($31) + 8|0);
    HEAP32[$45>>2] = $43;
    HEAP32[$28>>2] = $31;
    $46 = HEAP32[$9>>2]|0;
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(0|0);
    if ($48) {
     $50 = $31;
    } else {
     HEAP32[$9>>2] = $47;
     $$pre$i$i$i$i = HEAP32[$28>>2]|0;
     $50 = $$pre$i$i$i$i;
    }
    $49 = HEAP32[$13>>2]|0;
    __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($49,$50);
    $51 = HEAP32[$15>>2]|0;
    $52 = (($51) + 1)|0;
    HEAP32[$15>>2] = $52;
   }
   $53 = (($17) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    $$01$i$i$i$i = $17;
    while(1) {
     $58 = (($$01$i$i$i$i) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==($$01$i$i$i$i|0);
     if ($61) {
      $$0$i$i$i$i = $59;
      break;
     } else {
      $$01$i$i$i$i = $59;
     }
    }
   } else {
    $$0$i$i$i$i$i = $54;
    while(1) {
     $56 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $57 = ($56|0)==(0|0);
     if ($57) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $56;
     }
    }
   }
   $62 = ($$0$i$i$i$i|0)==($12|0);
   if ($62) {
    break;
   } else {
    $17 = $$0$i$i$i$i;
   }
  }
 }
 $63 = (($parsed) + 20|0);
 $64 = HEAP8[$63>>0]|0;
 $65 = $64 & 1;
 $66 = ($65<<24>>24)==(0);
 if ($66) {
  $69 = $64&255;
  $70 = $69 >>> 1;
  $72 = $70;
 } else {
  $67 = (($parsed) + 24|0);
  $68 = HEAP32[$67>>2]|0;
  $72 = $68;
 }
 $71 = ($72|0)==(0);
 if ($71) {
  STACKTOP = sp;return ($4|0);
 }
 $73 = (($4) + 676|0);
 if ($66) {
  $76 = (($63) + 1|0);
  $77 = $76;
 } else {
  $74 = (($parsed) + 28|0);
  $75 = HEAP32[$74>>2]|0;
  $77 = $75;
 }
 __ZN9ShaderLab16FastPropertyName4InitEPKc($73,$77);
 STACKTOP = sp;return ($4|0);
}
function __ZN9ShaderLab11ShaderState21FromParsedShaderStateERKNS_17ParserShaderStateEP16PropertyNamesSet($this,$parsed,$outNames) {
 $this = $this|0;
 $parsed = $parsed|0;
 $outNames = $outNames|0;
 var $$$i$i = 0, $$$i$i117 = 0, $$$i$i140 = 0, $$$i$i167 = 0, $$$i$i190 = 0, $$$i$i217 = 0, $$$i$i240 = 0, $$$i$i267 = 0, $$$i$i290 = 0, $$$i$i305 = 0, $$$i$i319 = 0, $$$i$i334 = 0, $$$i$i348 = 0, $$$i$i377 = 0, $$$i$i404 = 0, $$$i$i427 = 0, $$$i$i442 = 0, $$$i$i456 = 0, $$$i$i471 = 0, $$$i$i501 = 0;
 var $$$i$i515 = 0, $$$i$i543 = 0, $$$i$i55 = 0, $$$i$i557 = 0, $$$i$i585 = 0, $$$i$i599 = 0, $$$i$i627 = 0, $$$i$i641 = 0, $$$i$i669 = 0, $$$i$i90 = 0, $$0$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy35 = 0, $$idx$i = 0, $$idx$i135 = 0, $$idx$i185 = 0;
 var $$idx$i235 = 0, $$idx$i285 = 0, $$idx$i422 = 0, $$idx$val = 0, $$idx$val$i = 0, $$idx$val$i136 = 0, $$idx$val$i186 = 0, $$idx$val$i236 = 0, $$idx$val$i286 = 0, $$idx$val$i423 = 0, $$idx1$i = 0, $$idx1$i133 = 0, $$idx1$i183 = 0, $$idx1$i233 = 0, $$idx1$i283 = 0, $$idx1$i420 = 0, $$idx1$val$i = 0, $$idx1$val$i134 = 0, $$idx1$val$i184 = 0, $$idx1$val$i234 = 0;
 var $$idx1$val$i284 = 0, $$idx1$val$i421 = 0, $$idx2$i = 0, $$idx2$i131 = 0, $$idx2$i181 = 0, $$idx2$i231 = 0, $$idx2$i281 = 0, $$idx2$i418 = 0, $$idx2$val$i = 0, $$idx2$val$i132 = 0, $$idx2$val$i182 = 0, $$idx2$val$i232 = 0, $$idx2$val$i282 = 0, $$idx2$val$i419 = 0, $$idx22$val = 0, $$idx23$val = 0, $$idx24$val = 0, $$idx25$val = 0, $$idx26$val = 0, $$idx3$i = 0;
 var $$idx3$i129 = 0, $$idx3$i179 = 0, $$idx3$i229 = 0, $$idx3$i279 = 0, $$idx3$i416 = 0, $$idx3$val$i = 0, $$idx3$val$i130 = 0, $$idx3$val$i180 = 0, $$idx3$val$i230 = 0, $$idx3$val$i280 = 0, $$idx3$val$i417 = 0, $$neg2$i$i$i$i$i = 0, $$neg2$i$i$i$i$i123 = 0, $$neg2$i$i$i$i$i146 = 0, $$neg2$i$i$i$i$i173 = 0, $$neg2$i$i$i$i$i196 = 0, $$neg2$i$i$i$i$i223 = 0, $$neg2$i$i$i$i$i246 = 0, $$neg2$i$i$i$i$i273 = 0, $$neg2$i$i$i$i$i296 = 0;
 var $$neg2$i$i$i$i$i311 = 0, $$neg2$i$i$i$i$i325 = 0, $$neg2$i$i$i$i$i340 = 0, $$neg2$i$i$i$i$i354 = 0, $$neg2$i$i$i$i$i369 = 0, $$neg2$i$i$i$i$i383 = 0, $$neg2$i$i$i$i$i410 = 0, $$neg2$i$i$i$i$i433 = 0, $$neg2$i$i$i$i$i448 = 0, $$neg2$i$i$i$i$i462 = 0, $$neg2$i$i$i$i$i477 = 0, $$neg2$i$i$i$i$i492 = 0, $$neg2$i$i$i$i$i507 = 0, $$neg2$i$i$i$i$i521 = 0, $$neg2$i$i$i$i$i535 = 0, $$neg2$i$i$i$i$i549 = 0, $$neg2$i$i$i$i$i563 = 0, $$neg2$i$i$i$i$i577 = 0, $$neg2$i$i$i$i$i591 = 0, $$neg2$i$i$i$i$i605 = 0;
 var $$neg2$i$i$i$i$i61 = 0, $$neg2$i$i$i$i$i619 = 0, $$neg2$i$i$i$i$i633 = 0, $$neg2$i$i$i$i$i647 = 0, $$neg2$i$i$i$i$i661 = 0, $$neg2$i$i$i$i$i675 = 0, $$neg2$i$i$i$i$i96 = 0, $$not$i = 0, $$not$i116 = 0, $$not$i139 = 0, $$not$i166 = 0, $$not$i189 = 0, $$not$i216 = 0, $$not$i239 = 0, $$not$i266 = 0, $$not$i289 = 0, $$not$i304 = 0, $$not$i318 = 0, $$not$i333 = 0, $$not$i347 = 0;
 var $$not$i376 = 0, $$not$i403 = 0, $$not$i426 = 0, $$not$i441 = 0, $$not$i455 = 0, $$not$i470 = 0, $$not$i500 = 0, $$not$i514 = 0, $$not$i54 = 0, $$not$i542 = 0, $$not$i556 = 0, $$not$i584 = 0, $$not$i598 = 0, $$not$i626 = 0, $$not$i640 = 0, $$not$i668 = 0, $$not$i89 = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i122 = 0, $$sum$i$i$i$i$i145 = 0;
 var $$sum$i$i$i$i$i172 = 0, $$sum$i$i$i$i$i195 = 0, $$sum$i$i$i$i$i222 = 0, $$sum$i$i$i$i$i245 = 0, $$sum$i$i$i$i$i272 = 0, $$sum$i$i$i$i$i295 = 0, $$sum$i$i$i$i$i310 = 0, $$sum$i$i$i$i$i324 = 0, $$sum$i$i$i$i$i339 = 0, $$sum$i$i$i$i$i353 = 0, $$sum$i$i$i$i$i368 = 0, $$sum$i$i$i$i$i382 = 0, $$sum$i$i$i$i$i409 = 0, $$sum$i$i$i$i$i432 = 0, $$sum$i$i$i$i$i447 = 0, $$sum$i$i$i$i$i461 = 0, $$sum$i$i$i$i$i476 = 0, $$sum$i$i$i$i$i491 = 0, $$sum$i$i$i$i$i506 = 0, $$sum$i$i$i$i$i520 = 0;
 var $$sum$i$i$i$i$i534 = 0, $$sum$i$i$i$i$i548 = 0, $$sum$i$i$i$i$i562 = 0, $$sum$i$i$i$i$i576 = 0, $$sum$i$i$i$i$i590 = 0, $$sum$i$i$i$i$i60 = 0, $$sum$i$i$i$i$i604 = 0, $$sum$i$i$i$i$i618 = 0, $$sum$i$i$i$i$i632 = 0, $$sum$i$i$i$i$i646 = 0, $$sum$i$i$i$i$i660 = 0, $$sum$i$i$i$i$i674 = 0, $$sum$i$i$i$i$i95 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0;
 var $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0;
 var $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0;
 var $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = 0;
 var $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0;
 var $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = Math_fround(0), $1080 = 0, $1081 = 0, $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = Math_fround(0), $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0;
 var $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0);
 var $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0;
 var $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = Math_fround(0);
 var $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0;
 var $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = Math_fround(0), $1181 = Math_fround(0), $1182 = 0, $1183 = 0;
 var $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = Math_fround(0), $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0;
 var $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0;
 var $122 = Math_fround(0), $1220 = 0, $1221 = Math_fround(0), $1222 = Math_fround(0), $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = Math_fround(0), $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0;
 var $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0;
 var $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = Math_fround(0), $1270 = 0, $1271 = 0, $1272 = 0, $1273 = Math_fround(0);
 var $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = Math_fround(0), $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = Math_fround(0), $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = Math_fround(0), $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0;
 var $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0;
 var $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = Math_fround(0), $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0;
 var $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0;
 var $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = Math_fround(0), $136 = 0, $1360 = Math_fround(0), $1361 = 0, $1362 = 0, $1363 = 0;
 var $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = Math_fround(0), $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0;
 var $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0;
 var $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = Math_fround(0), $1414 = Math_fround(0), $1415 = 0, $1416 = 0, $1417 = 0;
 var $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0;
 var $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = Math_fround(0), $1441 = Math_fround(0), $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0;
 var $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = Math_fround(0), $1468 = Math_fround(0), $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0;
 var $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = Math_fround(0), $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0;
 var $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0;
 var $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = Math_fround(0), $1515 = Math_fround(0), $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = Math_fround(0), $1523 = 0, $1524 = 0, $1525 = 0;
 var $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = Math_fround(0), $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0;
 var $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = Math_fround(0), $155 = 0, $1550 = 0, $1551 = Math_fround(0), $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = Math_fround(0);
 var $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0;
 var $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0;
 var $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0;
 var $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = Math_fround(0), $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0;
 var $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = Math_fround(0), $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0;
 var $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = Math_fround(0), $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0;
 var $1670 = Math_fround(0), $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = Math_fround(0), $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0;
 var $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = Math_fround(0), $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0;
 var $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = Math_fround(0), $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0;
 var $1724 = 0, $1725 = 0, $1726 = Math_fround(0), $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = Math_fround(0), $1741 = 0;
 var $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = Math_fround(0), $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0;
 var $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = Math_fround(0), $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0;
 var $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = Math_fround(0), $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0;
 var $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0;
 var $1814 = 0, $1815 = Math_fround(0), $1816 = Math_fround(0), $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = Math_fround(0), $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0;
 var $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = Math_fround(0), $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0;
 var $1850 = 0, $1851 = Math_fround(0), $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = Math_fround(0), $1866 = 0, $1867 = 0, $1868 = 0;
 var $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = Math_fround(0), $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0;
 var $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = Math_fround(0), $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0;
 var $1904 = 0, $1905 = 0, $1906 = 0, $1907 = Math_fround(0), $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0, $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = Math_fround(0);
 var $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0, $1934 = 0, $1935 = Math_fround(0), $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0;
 var $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = Math_fround(0), $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0;
 var $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = Math_fround(0), $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0;
 var $1977 = Math_fround(0), $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = Math_fround(0), $1992 = 0, $1993 = 0, $1994 = 0;
 var $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $2 = 0, $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0, $2005 = Math_fround(0), $2006 = 0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0;
 var $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0;
 var $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0, $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0, $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0;
 var $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0;
 var $2066 = 0, $2067 = 0, $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0, $208 = Math_fround(0), $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0;
 var $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = Math_fround(0), $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0;
 var $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0, $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0;
 var $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = Math_fround(0), $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = Math_fround(0);
 var $495 = Math_fround(0), $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = Math_fround(0), $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = Math_fround(0), $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = Math_fround(0), $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = Math_fround(0), $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = Math_fround(0), $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = Math_fround(0), $646 = Math_fround(0), $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = Math_fround(0), $673 = Math_fround(0), $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = Math_fround(0), $727 = Math_fround(0), $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = Math_fround(0), $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = Math_fround(0), $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = Math_fround(0), $748 = 0, $749 = 0, $75 = Math_fround(0), $750 = 0, $751 = 0, $752 = Math_fround(0), $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0;
 var $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0;
 var $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = Math_fround(0), $824 = Math_fround(0), $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0;
 var $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = Math_fround(0), $851 = Math_fround(0), $852 = 0, $853 = 0, $854 = 0;
 var $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0;
 var $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = Math_fround(0), $878 = Math_fround(0), $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0;
 var $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = Math_fround(0), $905 = Math_fround(0), $906 = 0, $907 = 0, $908 = 0;
 var $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0;
 var $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = Math_fround(0), $932 = Math_fround(0), $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = Math_fround(0), $943 = 0, $944 = 0;
 var $945 = 0, $946 = 0, $947 = Math_fround(0), $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = Math_fround(0), $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = Math_fround(0), $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0;
 var $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0;
 var $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0;
 var $__len$0$be$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i124 = 0, $__len$0$be$i$i$i$i$i147 = 0, $__len$0$be$i$i$i$i$i174 = 0, $__len$0$be$i$i$i$i$i197 = 0, $__len$0$be$i$i$i$i$i224 = 0, $__len$0$be$i$i$i$i$i247 = 0, $__len$0$be$i$i$i$i$i274 = 0, $__len$0$be$i$i$i$i$i297 = 0, $__len$0$be$i$i$i$i$i312 = 0, $__len$0$be$i$i$i$i$i326 = 0, $__len$0$be$i$i$i$i$i341 = 0, $__len$0$be$i$i$i$i$i355 = 0, $__len$0$be$i$i$i$i$i370 = 0, $__len$0$be$i$i$i$i$i384 = 0, $__len$0$be$i$i$i$i$i411 = 0, $__len$0$be$i$i$i$i$i434 = 0, $__len$0$be$i$i$i$i$i449 = 0, $__len$0$be$i$i$i$i$i463 = 0, $__len$0$be$i$i$i$i$i478 = 0;
 var $__len$0$be$i$i$i$i$i493 = 0, $__len$0$be$i$i$i$i$i508 = 0, $__len$0$be$i$i$i$i$i522 = 0, $__len$0$be$i$i$i$i$i536 = 0, $__len$0$be$i$i$i$i$i550 = 0, $__len$0$be$i$i$i$i$i564 = 0, $__len$0$be$i$i$i$i$i578 = 0, $__len$0$be$i$i$i$i$i592 = 0, $__len$0$be$i$i$i$i$i606 = 0, $__len$0$be$i$i$i$i$i62 = 0, $__len$0$be$i$i$i$i$i620 = 0, $__len$0$be$i$i$i$i$i634 = 0, $__len$0$be$i$i$i$i$i648 = 0, $__len$0$be$i$i$i$i$i662 = 0, $__len$0$be$i$i$i$i$i676 = 0, $__len$0$be$i$i$i$i$i97 = 0, $__len$03$i$i$i$i$i = 0, $__len$03$i$i$i$i$i121 = 0, $__len$03$i$i$i$i$i144 = 0, $__len$03$i$i$i$i$i171 = 0;
 var $__len$03$i$i$i$i$i194 = 0, $__len$03$i$i$i$i$i221 = 0, $__len$03$i$i$i$i$i244 = 0, $__len$03$i$i$i$i$i271 = 0, $__len$03$i$i$i$i$i294 = 0, $__len$03$i$i$i$i$i309 = 0, $__len$03$i$i$i$i$i323 = 0, $__len$03$i$i$i$i$i338 = 0, $__len$03$i$i$i$i$i352 = 0, $__len$03$i$i$i$i$i367 = 0, $__len$03$i$i$i$i$i381 = 0, $__len$03$i$i$i$i$i408 = 0, $__len$03$i$i$i$i$i431 = 0, $__len$03$i$i$i$i$i446 = 0, $__len$03$i$i$i$i$i460 = 0, $__len$03$i$i$i$i$i475 = 0, $__len$03$i$i$i$i$i490 = 0, $__len$03$i$i$i$i$i505 = 0, $__len$03$i$i$i$i$i519 = 0, $__len$03$i$i$i$i$i533 = 0;
 var $__len$03$i$i$i$i$i547 = 0, $__len$03$i$i$i$i$i561 = 0, $__len$03$i$i$i$i$i575 = 0, $__len$03$i$i$i$i$i589 = 0, $__len$03$i$i$i$i$i59 = 0, $__len$03$i$i$i$i$i603 = 0, $__len$03$i$i$i$i$i617 = 0, $__len$03$i$i$i$i$i631 = 0, $__len$03$i$i$i$i$i645 = 0, $__len$03$i$i$i$i$i659 = 0, $__len$03$i$i$i$i$i673 = 0, $__len$03$i$i$i$i$i94 = 0, $idx$i = 0, $idx$i361 = 0, $idx$i402 = 0, $idx$i454 = 0, $idx$i484 = 0, $idx$i499 = 0, $idx$i513 = 0, $idx$i527 = 0;
 var $idx$i555 = 0, $idx$i569 = 0, $idx$i597 = 0, $idx$i611 = 0, $idx$i639 = 0, $idx$i653 = 0, $idx$i667 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i118 = 0, $or$cond$i141 = 0, $or$cond$i168 = 0, $or$cond$i191 = 0, $or$cond$i218 = 0, $or$cond$i241 = 0, $or$cond$i268 = 0, $or$cond$i291 = 0, $or$cond$i306 = 0, $or$cond$i320 = 0, $or$cond$i335 = 0;
 var $or$cond$i349 = 0, $or$cond$i378 = 0, $or$cond$i405 = 0, $or$cond$i428 = 0, $or$cond$i443 = 0, $or$cond$i457 = 0, $or$cond$i472 = 0, $or$cond$i502 = 0, $or$cond$i516 = 0, $or$cond$i544 = 0, $or$cond$i558 = 0, $or$cond$i56 = 0, $or$cond$i586 = 0, $or$cond$i600 = 0, $or$cond$i628 = 0, $or$cond$i642 = 0, $or$cond$i670 = 0, $or$cond$i91 = 0, $phitmp = 0, $phitmp$i = 0;
 var $phitmp$i102 = 0, $phitmp$i152 = 0, $phitmp$i202 = 0, $phitmp$i252 = 0, $phitmp$i27 = 0, $phitmp$i389 = 0, $phitmp$i39 = 0, $phitmp$i67 = 0, $phitmp1000 = 0, $phitmp1002 = 0, $phitmp1004 = 0, $phitmp14$i = 0, $phitmp14$i105 = 0, $phitmp14$i155 = 0, $phitmp14$i205 = 0, $phitmp14$i255 = 0, $phitmp14$i30 = 0, $phitmp14$i392 = 0, $phitmp14$i42 = 0, $phitmp14$i69 = 0;
 var $phitmp16$i = 0, $phitmp16$i108 = 0, $phitmp16$i158 = 0, $phitmp16$i208 = 0, $phitmp16$i258 = 0, $phitmp16$i33 = 0, $phitmp16$i395 = 0, $phitmp16$i45 = 0, $phitmp16$i71 = 0, $phitmp18$i = 0, $phitmp18$i111 = 0, $phitmp18$i161 = 0, $phitmp18$i211 = 0, $phitmp18$i261 = 0, $phitmp18$i36 = 0, $phitmp18$i398 = 0, $phitmp18$i48 = 0, $phitmp18$i73 = 0, $phitmp948 = 0, $phitmp950 = 0;
 var $phitmp952 = 0, $phitmp970 = 0, $phitmp972 = 0, $phitmp974 = 0, $phitmp976 = 0, $phitmp978 = 0, $phitmp980 = 0, $phitmp982 = 0, $phitmp984 = 0, $phitmp986 = 0, $phitmp988 = 0, $phitmp990 = 0, $phitmp992 = 0, $phitmp994 = 0, $phitmp996 = 0, $phitmp998 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy35 = sp + 348|0;
 $0 = sp + 344|0;
 $1 = sp + 340|0;
 $idx$i667 = sp + 336|0;
 $2 = sp + 332|0;
 $idx$i653 = sp + 328|0;
 $3 = sp + 324|0;
 $4 = sp + 320|0;
 $idx$i639 = sp + 316|0;
 $5 = sp + 312|0;
 $6 = sp + 308|0;
 $7 = sp + 304|0;
 $8 = sp + 300|0;
 $idx$i611 = sp + 296|0;
 $9 = sp + 292|0;
 $10 = sp + 288|0;
 $idx$i597 = sp + 284|0;
 $11 = sp + 280|0;
 $12 = sp + 276|0;
 $13 = sp + 272|0;
 $14 = sp + 268|0;
 $idx$i569 = sp + 264|0;
 $15 = sp + 260|0;
 $16 = sp + 256|0;
 $idx$i555 = sp + 252|0;
 $17 = sp + 248|0;
 $18 = sp + 244|0;
 $19 = sp + 240|0;
 $20 = sp + 236|0;
 $idx$i527 = sp + 232|0;
 $21 = sp + 228|0;
 $22 = sp + 224|0;
 $idx$i513 = sp + 220|0;
 $23 = sp + 216|0;
 $24 = sp + 212|0;
 $idx$i499 = sp + 208|0;
 $25 = sp + 204|0;
 $26 = sp + 200|0;
 $idx$i484 = sp + 196|0;
 $27 = sp + 192|0;
 $28 = sp + 188|0;
 $29 = sp + 184|0;
 $30 = sp + 180|0;
 $idx$i454 = sp + 168|0;
 $31 = sp + 76|0;
 $32 = sp + 72|0;
 $33 = sp + 68|0;
 $34 = sp + 64|0;
 $35 = sp + 60|0;
 $36 = sp + 56|0;
 $idx$i402 = sp + 52|0;
 $37 = sp + 48|0;
 $38 = sp + 44|0;
 $39 = sp + 40|0;
 $40 = sp + 36|0;
 $idx$i361 = sp + 12|0;
 $41 = sp;
 $42 = sp + 4|0;
 $43 = sp + 8|0;
 $44 = sp + 16|0;
 $45 = sp + 20|0;
 $46 = sp + 24|0;
 $47 = sp + 28|0;
 $48 = sp + 32|0;
 $49 = sp + 80|0;
 $50 = sp + 84|0;
 $51 = sp + 88|0;
 $52 = sp + 92|0;
 $53 = sp + 96|0;
 $54 = sp + 100|0;
 $55 = sp + 104|0;
 $56 = sp + 108|0;
 $57 = sp + 112|0;
 $58 = sp + 116|0;
 $59 = sp + 120|0;
 $60 = sp + 124|0;
 $61 = sp + 128|0;
 $62 = sp + 132|0;
 $63 = sp + 136|0;
 $64 = sp + 140|0;
 $65 = sp + 144|0;
 $66 = sp + 148|0;
 $67 = sp + 152|0;
 $68 = sp + 156|0;
 $69 = sp + 160|0;
 $idx$i = sp + 164|0;
 $70 = (($this) + 24|0);
 $71 = (($parsed) + 48|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(-1);
 if ($73) {
  $74 = (($parsed) + 44|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $phitmp = (HEAPF32[tempDoublePtr>>2]=$75,HEAP32[tempDoublePtr>>2]|0);
  $77 = -1;$78 = 0;$81 = $phitmp;
 } else {
  $77 = $72;$78 = 0;$81 = 0;
 }
 $76 = $77 | $78;
 $79 = $70;
 $80 = $79;
 HEAP32[$80>>2] = $81;
 $82 = (($79) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $76;
 $$idx26$val = HEAP32[$71>>2]|0;
 $84 = ($$idx26$val|0)!=(-1);
 $$not$i54 = $84 ^ 1;
 $85 = ($$idx26$val>>>0)>(1073741823);
 $$$i$i55 = $84 & $85;
 $or$cond$i56 = $$$i$i55 | $$not$i54;
 do {
  if (!($or$cond$i56)) {
   HEAP32[$0>>2] = $$idx26$val;
   $86 = HEAP32[$outNames>>2]|0;
   $87 = (($outNames) + 4|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = $88;
   $90 = $86;
   $91 = (($89) - ($90))|0;
   $92 = $91 >> 2;
   $93 = ($92|0)==(0);
   if ($93) {
    $103 = $86;
   } else {
    $96 = $86;$__len$03$i$i$i$i$i59 = $92;
    while(1) {
     $94 = (($__len$03$i$i$i$i$i59|0) / 2)&-1;
     $95 = (($96) + ($94<<2)|0);
     $97 = HEAP32[$95>>2]|0;
     $98 = ($97|0)<($$idx26$val|0);
     if ($98) {
      $$sum$i$i$i$i$i60 = (($94) + 1)|0;
      $99 = (($96) + ($$sum$i$i$i$i$i60<<2)|0);
      $$neg2$i$i$i$i$i61 = (($__len$03$i$i$i$i$i59) + -1)|0;
      $100 = (($$neg2$i$i$i$i$i61) - ($94))|0;
      $2019 = $99;$__len$0$be$i$i$i$i$i62 = $100;
     } else {
      $2019 = $96;$__len$0$be$i$i$i$i$i62 = $94;
     }
     $101 = ($__len$0$be$i$i$i$i$i62|0)==(0);
     if ($101) {
      $103 = $2019;
      break;
     } else {
      $96 = $2019;$__len$03$i$i$i$i$i59 = $__len$0$be$i$i$i$i$i62;
     }
    }
   }
   $102 = ($103|0)==($88|0);
   if (!($102)) {
    $104 = HEAP32[$103>>2]|0;
    $105 = ($$idx26$val|0)<($104|0);
    if (!($105)) {
     break;
    }
   }
   HEAP32[$68>>2] = $103;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$68+0>>2]|0;
   __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($67,$outNames,$$byval_copy35,$0);
   $106 = (($outNames) + 12|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (Math_fround(($107>>>0)));
   $109 = Math_fround($108 + Math_fround(4.0));
   $110 = (~~(($109))>>>0);
   HEAP32[$106>>2] = $110;
  }
 } while(0);
 $111 = (($parsed) + 76|0);
 $112 = HEAP8[$111>>0]|0;
 $113 = (($this) + 220|0);
 HEAP8[$113>>0] = $112;
 $114 = (($this) + 32|0);
 $115 = (($parsed) + 176|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = ($116|0)==(-1);
 if ($117) {
  $118 = (($parsed) + 148|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = ($119|0)==(-1);
  if ($120) {
   $121 = (($parsed) + 144|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $phitmp$i67 = (HEAPF32[tempDoublePtr>>2]=$122,HEAP32[tempDoublePtr>>2]|0);
   $2020 = -1;$2021 = $phitmp$i67;$2022 = 0;
  } else {
   $2020 = $119;$2021 = 0;$2022 = 0;
  }
  $123 = (($parsed) + 156|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($124|0)==(-1);
  if ($125) {
   $126 = (($parsed) + 152|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $phitmp14$i69 = (HEAPF32[tempDoublePtr>>2]=$127,HEAP32[tempDoublePtr>>2]|0);
   $2023 = -1;$2024 = $phitmp14$i69;$2025 = 0;
  } else {
   $2023 = $124;$2024 = 0;$2025 = 0;
  }
  $128 = (($parsed) + 164|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ($129|0)==(-1);
  if ($130) {
   $131 = (($parsed) + 160|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   $phitmp16$i71 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
   $2026 = -1;$2027 = $phitmp16$i71;$2028 = 0;
  } else {
   $2026 = $129;$2027 = 0;$2028 = 0;
  }
  $133 = (($parsed) + 172|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = ($134|0)==(-1);
  if ($135) {
   $136 = (($parsed) + 168|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $phitmp18$i73 = (HEAPF32[tempDoublePtr>>2]=$137,HEAP32[tempDoublePtr>>2]|0);
   $2029 = -1;$2030 = $phitmp18$i73;$2031 = 0;
  } else {
   $2029 = $134;$2030 = 0;$2031 = 0;
  }
  $139 = $2021;$140 = 0;$142 = $2022;$143 = $2020;$150 = $2024;$151 = 0;$153 = $2025;$154 = $2023;$161 = $2027;$162 = 0;$164 = $2028;$165 = $2026;$172 = $2030;$173 = 0;$175 = $2031;$176 = $2029;$182 = -1;
 } else {
  $139 = 0;$140 = 0;$142 = 0;$143 = -1;$150 = 0;$151 = 0;$153 = 0;$154 = -1;$161 = 0;$162 = 0;$164 = 0;$165 = -1;$172 = 0;$173 = 0;$175 = 0;$176 = -1;$182 = $116;
 }
 $138 = $139 | $140;
 $141 = $142 | $143;
 $144 = $114;
 $145 = $144;
 HEAP32[$145>>2] = $138;
 $146 = (($144) + 4)|0;
 $147 = $146;
 HEAP32[$147>>2] = $141;
 $148 = (($this) + 40|0);
 $149 = $150 | $151;
 $152 = $153 | $154;
 $155 = $148;
 $156 = $155;
 HEAP32[$156>>2] = $149;
 $157 = (($155) + 4)|0;
 $158 = $157;
 HEAP32[$158>>2] = $152;
 $159 = (($this) + 48|0);
 $160 = $161 | $162;
 $163 = $164 | $165;
 $166 = $159;
 $167 = $166;
 HEAP32[$167>>2] = $160;
 $168 = (($166) + 4)|0;
 $169 = $168;
 HEAP32[$169>>2] = $163;
 $170 = (($this) + 56|0);
 $171 = $172 | $173;
 $174 = $175 | $176;
 $177 = $170;
 $178 = $177;
 HEAP32[$178>>2] = $171;
 $179 = (($177) + 4)|0;
 $180 = $179;
 HEAP32[$180>>2] = $174;
 $181 = (($this) + 64|0);
 HEAP32[$181>>2] = $182;
 $183 = HEAP32[$115>>2]|0;
 $184 = ($183|0)==(-1);
 do {
  if ($184) {
   $$idx3$i = (($parsed) + 148|0);
   $$idx3$val$i = HEAP32[$$idx3$i>>2]|0;
   $211 = ($$idx3$val$i|0)!=(-1);
   $$not$i542 = $211 ^ 1;
   $212 = ($$idx3$val$i>>>0)>(1073741823);
   $$$i$i543 = $211 & $212;
   $or$cond$i544 = $$$i$i543 | $$not$i542;
   do {
    if (!($or$cond$i544)) {
     HEAP32[$0>>2] = $$idx3$val$i;
     $213 = HEAP32[$outNames>>2]|0;
     $214 = (($outNames) + 4|0);
     $215 = HEAP32[$214>>2]|0;
     $216 = $215;
     $217 = $213;
     $218 = (($216) - ($217))|0;
     $219 = $218 >> 2;
     $220 = ($219|0)==(0);
     if ($220) {
      $230 = $213;
     } else {
      $223 = $213;$__len$03$i$i$i$i$i547 = $219;
      while(1) {
       $221 = (($__len$03$i$i$i$i$i547|0) / 2)&-1;
       $222 = (($223) + ($221<<2)|0);
       $224 = HEAP32[$222>>2]|0;
       $225 = ($224|0)<($$idx3$val$i|0);
       if ($225) {
        $$sum$i$i$i$i$i548 = (($221) + 1)|0;
        $226 = (($223) + ($$sum$i$i$i$i$i548<<2)|0);
        $$neg2$i$i$i$i$i549 = (($__len$03$i$i$i$i$i547) + -1)|0;
        $227 = (($$neg2$i$i$i$i$i549) - ($221))|0;
        $2033 = $226;$__len$0$be$i$i$i$i$i550 = $227;
       } else {
        $2033 = $223;$__len$0$be$i$i$i$i$i550 = $221;
       }
       $228 = ($__len$0$be$i$i$i$i$i550|0)==(0);
       if ($228) {
        $230 = $2033;
        break;
       } else {
        $223 = $2033;$__len$03$i$i$i$i$i547 = $__len$0$be$i$i$i$i$i550;
       }
      }
     }
     $229 = ($230|0)==($215|0);
     if (!($229)) {
      $231 = HEAP32[$230>>2]|0;
      $232 = ($$idx3$val$i|0)<($231|0);
      if (!($232)) {
       break;
      }
     }
     HEAP32[$18>>2] = $230;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$18+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($17,$outNames,$$byval_copy35,$0);
     $233 = (($outNames) + 12|0);
     $234 = HEAP32[$233>>2]|0;
     $235 = (Math_fround(($234>>>0)));
     $236 = Math_fround($235 + Math_fround(4.0));
     $237 = (~~(($236))>>>0);
     HEAP32[$233>>2] = $237;
    }
   } while(0);
   $$idx2$i = (($parsed) + 156|0);
   $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
   $238 = ($$idx2$val$i|0)!=(-1);
   $$not$i116 = $238 ^ 1;
   $239 = ($$idx2$val$i>>>0)>(1073741823);
   $$$i$i117 = $238 & $239;
   $or$cond$i118 = $$$i$i117 | $$not$i116;
   do {
    if (!($or$cond$i118)) {
     HEAP32[$0>>2] = $$idx2$val$i;
     $240 = HEAP32[$outNames>>2]|0;
     $241 = (($outNames) + 4|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = $242;
     $244 = $240;
     $245 = (($243) - ($244))|0;
     $246 = $245 >> 2;
     $247 = ($246|0)==(0);
     if ($247) {
      $257 = $240;
     } else {
      $250 = $240;$__len$03$i$i$i$i$i121 = $246;
      while(1) {
       $248 = (($__len$03$i$i$i$i$i121|0) / 2)&-1;
       $249 = (($250) + ($248<<2)|0);
       $251 = HEAP32[$249>>2]|0;
       $252 = ($251|0)<($$idx2$val$i|0);
       if ($252) {
        $$sum$i$i$i$i$i122 = (($248) + 1)|0;
        $253 = (($250) + ($$sum$i$i$i$i$i122<<2)|0);
        $$neg2$i$i$i$i$i123 = (($__len$03$i$i$i$i$i121) + -1)|0;
        $254 = (($$neg2$i$i$i$i$i123) - ($248))|0;
        $2034 = $253;$__len$0$be$i$i$i$i$i124 = $254;
       } else {
        $2034 = $250;$__len$0$be$i$i$i$i$i124 = $248;
       }
       $255 = ($__len$0$be$i$i$i$i$i124|0)==(0);
       if ($255) {
        $257 = $2034;
        break;
       } else {
        $250 = $2034;$__len$03$i$i$i$i$i121 = $__len$0$be$i$i$i$i$i124;
       }
      }
     }
     $256 = ($257|0)==($242|0);
     if (!($256)) {
      $258 = HEAP32[$257>>2]|0;
      $259 = ($$idx2$val$i|0)<($258|0);
      if (!($259)) {
       break;
      }
     }
     HEAP32[$64>>2] = $257;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$64+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($63,$outNames,$$byval_copy35,$0);
     $260 = (($outNames) + 12|0);
     $261 = HEAP32[$260>>2]|0;
     $262 = (Math_fround(($261>>>0)));
     $263 = Math_fround($262 + Math_fround(4.0));
     $264 = (~~(($263))>>>0);
     HEAP32[$260>>2] = $264;
    }
   } while(0);
   $$idx1$i = (($parsed) + 164|0);
   $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
   $265 = ($$idx1$val$i|0)!=(-1);
   $$not$i89 = $265 ^ 1;
   $266 = ($$idx1$val$i>>>0)>(1073741823);
   $$$i$i90 = $265 & $266;
   $or$cond$i91 = $$$i$i90 | $$not$i89;
   do {
    if (!($or$cond$i91)) {
     HEAP32[$0>>2] = $$idx1$val$i;
     $267 = HEAP32[$outNames>>2]|0;
     $268 = (($outNames) + 4|0);
     $269 = HEAP32[$268>>2]|0;
     $270 = $269;
     $271 = $267;
     $272 = (($270) - ($271))|0;
     $273 = $272 >> 2;
     $274 = ($273|0)==(0);
     if ($274) {
      $284 = $267;
     } else {
      $277 = $267;$__len$03$i$i$i$i$i94 = $273;
      while(1) {
       $275 = (($__len$03$i$i$i$i$i94|0) / 2)&-1;
       $276 = (($277) + ($275<<2)|0);
       $278 = HEAP32[$276>>2]|0;
       $279 = ($278|0)<($$idx1$val$i|0);
       if ($279) {
        $$sum$i$i$i$i$i95 = (($275) + 1)|0;
        $280 = (($277) + ($$sum$i$i$i$i$i95<<2)|0);
        $$neg2$i$i$i$i$i96 = (($__len$03$i$i$i$i$i94) + -1)|0;
        $281 = (($$neg2$i$i$i$i$i96) - ($275))|0;
        $2035 = $280;$__len$0$be$i$i$i$i$i97 = $281;
       } else {
        $2035 = $277;$__len$0$be$i$i$i$i$i97 = $275;
       }
       $282 = ($__len$0$be$i$i$i$i$i97|0)==(0);
       if ($282) {
        $284 = $2035;
        break;
       } else {
        $277 = $2035;$__len$03$i$i$i$i$i94 = $__len$0$be$i$i$i$i$i97;
       }
      }
     }
     $283 = ($284|0)==($269|0);
     if (!($283)) {
      $285 = HEAP32[$284>>2]|0;
      $286 = ($$idx1$val$i|0)<($285|0);
      if (!($286)) {
       break;
      }
     }
     HEAP32[$66>>2] = $284;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$66+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($65,$outNames,$$byval_copy35,$0);
     $287 = (($outNames) + 12|0);
     $288 = HEAP32[$287>>2]|0;
     $289 = (Math_fround(($288>>>0)));
     $290 = Math_fround($289 + Math_fround(4.0));
     $291 = (~~(($290))>>>0);
     HEAP32[$287>>2] = $291;
    }
   } while(0);
   $$idx$i = (($parsed) + 172|0);
   $$idx$val$i = HEAP32[$$idx$i>>2]|0;
   $292 = ($$idx$val$i|0)!=(-1);
   $$not$i514 = $292 ^ 1;
   $293 = ($$idx$val$i>>>0)>(1073741823);
   $$$i$i515 = $292 & $293;
   $or$cond$i516 = $$$i$i515 | $$not$i514;
   if (!($or$cond$i516)) {
    HEAP32[$idx$i513>>2] = $$idx$val$i;
    $294 = HEAP32[$outNames>>2]|0;
    $295 = (($outNames) + 4|0);
    $296 = HEAP32[$295>>2]|0;
    $297 = $296;
    $298 = $294;
    $299 = (($297) - ($298))|0;
    $300 = $299 >> 2;
    $301 = ($300|0)==(0);
    if ($301) {
     $311 = $294;
    } else {
     $304 = $294;$__len$03$i$i$i$i$i519 = $300;
     while(1) {
      $302 = (($__len$03$i$i$i$i$i519|0) / 2)&-1;
      $303 = (($304) + ($302<<2)|0);
      $305 = HEAP32[$303>>2]|0;
      $306 = ($305|0)<($$idx$val$i|0);
      if ($306) {
       $$sum$i$i$i$i$i520 = (($302) + 1)|0;
       $307 = (($304) + ($$sum$i$i$i$i$i520<<2)|0);
       $$neg2$i$i$i$i$i521 = (($__len$03$i$i$i$i$i519) + -1)|0;
       $308 = (($$neg2$i$i$i$i$i521) - ($302))|0;
       $2036 = $307;$__len$0$be$i$i$i$i$i522 = $308;
      } else {
       $2036 = $304;$__len$0$be$i$i$i$i$i522 = $302;
      }
      $309 = ($__len$0$be$i$i$i$i$i522|0)==(0);
      if ($309) {
       $311 = $2036;
       break;
      } else {
       $304 = $2036;$__len$03$i$i$i$i$i519 = $__len$0$be$i$i$i$i$i522;
      }
     }
    }
    $310 = ($311|0)==($296|0);
    if (!($310)) {
     $312 = HEAP32[$311>>2]|0;
     $313 = ($$idx$val$i|0)<($312|0);
     if (!($313)) {
      break;
     }
    }
    HEAP32[$22>>2] = $311;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$22+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($21,$outNames,$$byval_copy35,$idx$i513);
    $314 = (($outNames) + 12|0);
    $315 = HEAP32[$314>>2]|0;
    $316 = (Math_fround(($315>>>0)));
    $317 = Math_fround($316 + Math_fround(4.0));
    $318 = (~~(($317))>>>0);
    HEAP32[$314>>2] = $318;
   }
  } else {
   $185 = ($183>>>0)>(1073741823);
   if (!($185)) {
    HEAP32[$idx$i527>>2] = $183;
    $186 = HEAP32[$outNames>>2]|0;
    $187 = (($outNames) + 4|0);
    $188 = HEAP32[$187>>2]|0;
    $189 = $188;
    $190 = $186;
    $191 = (($189) - ($190))|0;
    $192 = $191 >> 2;
    $193 = ($192|0)==(0);
    if ($193) {
     $203 = $186;
    } else {
     $196 = $186;$__len$03$i$i$i$i$i533 = $192;
     while(1) {
      $194 = (($__len$03$i$i$i$i$i533|0) / 2)&-1;
      $195 = (($196) + ($194<<2)|0);
      $197 = HEAP32[$195>>2]|0;
      $198 = ($197|0)<($183|0);
      if ($198) {
       $$sum$i$i$i$i$i534 = (($194) + 1)|0;
       $199 = (($196) + ($$sum$i$i$i$i$i534<<2)|0);
       $$neg2$i$i$i$i$i535 = (($__len$03$i$i$i$i$i533) + -1)|0;
       $200 = (($$neg2$i$i$i$i$i535) - ($194))|0;
       $2032 = $199;$__len$0$be$i$i$i$i$i536 = $200;
      } else {
       $2032 = $196;$__len$0$be$i$i$i$i$i536 = $194;
      }
      $201 = ($__len$0$be$i$i$i$i$i536|0)==(0);
      if ($201) {
       $203 = $2032;
       break;
      } else {
       $196 = $2032;$__len$03$i$i$i$i$i533 = $__len$0$be$i$i$i$i$i536;
      }
     }
    }
    $202 = ($203|0)==($188|0);
    if (!($202)) {
     $204 = HEAP32[$203>>2]|0;
     $205 = ($183|0)<($204|0);
     if (!($205)) {
      break;
     }
    }
    HEAP32[$20>>2] = $203;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$20+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($19,$outNames,$$byval_copy35,$idx$i527);
    $206 = (($outNames) + 12|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = (Math_fround(($207>>>0)));
    $209 = Math_fround($208 + Math_fround(16.0));
    $210 = (~~(($209))>>>0);
    HEAP32[$206>>2] = $210;
   }
  }
 } while(0);
 $319 = (($this) + 68|0);
 $320 = (($parsed) + 212|0);
 $321 = HEAP32[$320>>2]|0;
 $322 = ($321|0)==(-1);
 if ($322) {
  $323 = (($parsed) + 184|0);
  $324 = HEAP32[$323>>2]|0;
  $325 = ($324|0)==(-1);
  if ($325) {
   $326 = (($parsed) + 180|0);
   $327 = Math_fround(HEAPF32[$326>>2]);
   $phitmp$i102 = (HEAPF32[tempDoublePtr>>2]=$327,HEAP32[tempDoublePtr>>2]|0);
   $2037 = -1;$2038 = $phitmp$i102;$2039 = 0;
  } else {
   $2037 = $324;$2038 = 0;$2039 = 0;
  }
  $328 = (($parsed) + 192|0);
  $329 = HEAP32[$328>>2]|0;
  $330 = ($329|0)==(-1);
  if ($330) {
   $331 = (($parsed) + 188|0);
   $332 = Math_fround(HEAPF32[$331>>2]);
   $phitmp14$i105 = (HEAPF32[tempDoublePtr>>2]=$332,HEAP32[tempDoublePtr>>2]|0);
   $2040 = -1;$2041 = $phitmp14$i105;$2042 = 0;
  } else {
   $2040 = $329;$2041 = 0;$2042 = 0;
  }
  $333 = (($parsed) + 200|0);
  $334 = HEAP32[$333>>2]|0;
  $335 = ($334|0)==(-1);
  if ($335) {
   $336 = (($parsed) + 196|0);
   $337 = Math_fround(HEAPF32[$336>>2]);
   $phitmp16$i108 = (HEAPF32[tempDoublePtr>>2]=$337,HEAP32[tempDoublePtr>>2]|0);
   $2043 = -1;$2044 = $phitmp16$i108;$2045 = 0;
  } else {
   $2043 = $334;$2044 = 0;$2045 = 0;
  }
  $338 = (($parsed) + 208|0);
  $339 = HEAP32[$338>>2]|0;
  $340 = ($339|0)==(-1);
  if ($340) {
   $341 = (($parsed) + 204|0);
   $342 = Math_fround(HEAPF32[$341>>2]);
   $phitmp18$i111 = (HEAPF32[tempDoublePtr>>2]=$342,HEAP32[tempDoublePtr>>2]|0);
   $2046 = -1;$2047 = $phitmp18$i111;$2048 = 0;
  } else {
   $2046 = $339;$2047 = 0;$2048 = 0;
  }
  $344 = $2038;$345 = 0;$347 = $2039;$348 = $2037;$355 = $2041;$356 = 0;$358 = $2042;$359 = $2040;$366 = $2044;$367 = 0;$369 = $2045;$370 = $2043;$377 = $2047;$378 = 0;$380 = $2048;$381 = $2046;$387 = -1;
 } else {
  $344 = 0;$345 = 0;$347 = 0;$348 = -1;$355 = 0;$356 = 0;$358 = 0;$359 = -1;$366 = 0;$367 = 0;$369 = 0;$370 = -1;$377 = 0;$378 = 0;$380 = 0;$381 = -1;$387 = $321;
 }
 $343 = $344 | $345;
 $346 = $347 | $348;
 $349 = $319;
 $350 = $349;
 HEAP32[$350>>2] = $343;
 $351 = (($349) + 4)|0;
 $352 = $351;
 HEAP32[$352>>2] = $346;
 $353 = (($this) + 76|0);
 $354 = $355 | $356;
 $357 = $358 | $359;
 $360 = $353;
 $361 = $360;
 HEAP32[$361>>2] = $354;
 $362 = (($360) + 4)|0;
 $363 = $362;
 HEAP32[$363>>2] = $357;
 $364 = (($this) + 84|0);
 $365 = $366 | $367;
 $368 = $369 | $370;
 $371 = $364;
 $372 = $371;
 HEAP32[$372>>2] = $365;
 $373 = (($371) + 4)|0;
 $374 = $373;
 HEAP32[$374>>2] = $368;
 $375 = (($this) + 92|0);
 $376 = $377 | $378;
 $379 = $380 | $381;
 $382 = $375;
 $383 = $382;
 HEAP32[$383>>2] = $376;
 $384 = (($382) + 4)|0;
 $385 = $384;
 HEAP32[$385>>2] = $379;
 $386 = (($this) + 100|0);
 HEAP32[$386>>2] = $387;
 $388 = HEAP32[$320>>2]|0;
 $389 = ($388|0)==(-1);
 do {
  if ($389) {
   $$idx3$i129 = (($parsed) + 184|0);
   $$idx3$val$i130 = HEAP32[$$idx3$i129>>2]|0;
   $416 = ($$idx3$val$i130|0)!=(-1);
   $$not$i584 = $416 ^ 1;
   $417 = ($$idx3$val$i130>>>0)>(1073741823);
   $$$i$i585 = $416 & $417;
   $or$cond$i586 = $$$i$i585 | $$not$i584;
   do {
    if (!($or$cond$i586)) {
     HEAP32[$0>>2] = $$idx3$val$i130;
     $418 = HEAP32[$outNames>>2]|0;
     $419 = (($outNames) + 4|0);
     $420 = HEAP32[$419>>2]|0;
     $421 = $420;
     $422 = $418;
     $423 = (($421) - ($422))|0;
     $424 = $423 >> 2;
     $425 = ($424|0)==(0);
     if ($425) {
      $435 = $418;
     } else {
      $428 = $418;$__len$03$i$i$i$i$i589 = $424;
      while(1) {
       $426 = (($__len$03$i$i$i$i$i589|0) / 2)&-1;
       $427 = (($428) + ($426<<2)|0);
       $429 = HEAP32[$427>>2]|0;
       $430 = ($429|0)<($$idx3$val$i130|0);
       if ($430) {
        $$sum$i$i$i$i$i590 = (($426) + 1)|0;
        $431 = (($428) + ($$sum$i$i$i$i$i590<<2)|0);
        $$neg2$i$i$i$i$i591 = (($__len$03$i$i$i$i$i589) + -1)|0;
        $432 = (($$neg2$i$i$i$i$i591) - ($426))|0;
        $2050 = $431;$__len$0$be$i$i$i$i$i592 = $432;
       } else {
        $2050 = $428;$__len$0$be$i$i$i$i$i592 = $426;
       }
       $433 = ($__len$0$be$i$i$i$i$i592|0)==(0);
       if ($433) {
        $435 = $2050;
        break;
       } else {
        $428 = $2050;$__len$03$i$i$i$i$i589 = $__len$0$be$i$i$i$i$i592;
       }
      }
     }
     $434 = ($435|0)==($420|0);
     if (!($434)) {
      $436 = HEAP32[$435>>2]|0;
      $437 = ($$idx3$val$i130|0)<($436|0);
      if (!($437)) {
       break;
      }
     }
     HEAP32[$12>>2] = $435;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$12+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($11,$outNames,$$byval_copy35,$0);
     $438 = (($outNames) + 12|0);
     $439 = HEAP32[$438>>2]|0;
     $440 = (Math_fround(($439>>>0)));
     $441 = Math_fround($440 + Math_fround(4.0));
     $442 = (~~(($441))>>>0);
     HEAP32[$438>>2] = $442;
    }
   } while(0);
   $$idx2$i131 = (($parsed) + 192|0);
   $$idx2$val$i132 = HEAP32[$$idx2$i131>>2]|0;
   $443 = ($$idx2$val$i132|0)!=(-1);
   $$not$i166 = $443 ^ 1;
   $444 = ($$idx2$val$i132>>>0)>(1073741823);
   $$$i$i167 = $443 & $444;
   $or$cond$i168 = $$$i$i167 | $$not$i166;
   do {
    if (!($or$cond$i168)) {
     HEAP32[$0>>2] = $$idx2$val$i132;
     $445 = HEAP32[$outNames>>2]|0;
     $446 = (($outNames) + 4|0);
     $447 = HEAP32[$446>>2]|0;
     $448 = $447;
     $449 = $445;
     $450 = (($448) - ($449))|0;
     $451 = $450 >> 2;
     $452 = ($451|0)==(0);
     if ($452) {
      $462 = $445;
     } else {
      $455 = $445;$__len$03$i$i$i$i$i171 = $451;
      while(1) {
       $453 = (($__len$03$i$i$i$i$i171|0) / 2)&-1;
       $454 = (($455) + ($453<<2)|0);
       $456 = HEAP32[$454>>2]|0;
       $457 = ($456|0)<($$idx2$val$i132|0);
       if ($457) {
        $$sum$i$i$i$i$i172 = (($453) + 1)|0;
        $458 = (($455) + ($$sum$i$i$i$i$i172<<2)|0);
        $$neg2$i$i$i$i$i173 = (($__len$03$i$i$i$i$i171) + -1)|0;
        $459 = (($$neg2$i$i$i$i$i173) - ($453))|0;
        $2051 = $458;$__len$0$be$i$i$i$i$i174 = $459;
       } else {
        $2051 = $455;$__len$0$be$i$i$i$i$i174 = $453;
       }
       $460 = ($__len$0$be$i$i$i$i$i174|0)==(0);
       if ($460) {
        $462 = $2051;
        break;
       } else {
        $455 = $2051;$__len$03$i$i$i$i$i171 = $__len$0$be$i$i$i$i$i174;
       }
      }
     }
     $461 = ($462|0)==($447|0);
     if (!($461)) {
      $463 = HEAP32[$462>>2]|0;
      $464 = ($$idx2$val$i132|0)<($463|0);
      if (!($464)) {
       break;
      }
     }
     HEAP32[$60>>2] = $462;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$60+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($59,$outNames,$$byval_copy35,$0);
     $465 = (($outNames) + 12|0);
     $466 = HEAP32[$465>>2]|0;
     $467 = (Math_fround(($466>>>0)));
     $468 = Math_fround($467 + Math_fround(4.0));
     $469 = (~~(($468))>>>0);
     HEAP32[$465>>2] = $469;
    }
   } while(0);
   $$idx1$i133 = (($parsed) + 200|0);
   $$idx1$val$i134 = HEAP32[$$idx1$i133>>2]|0;
   $470 = ($$idx1$val$i134|0)!=(-1);
   $$not$i139 = $470 ^ 1;
   $471 = ($$idx1$val$i134>>>0)>(1073741823);
   $$$i$i140 = $470 & $471;
   $or$cond$i141 = $$$i$i140 | $$not$i139;
   do {
    if (!($or$cond$i141)) {
     HEAP32[$0>>2] = $$idx1$val$i134;
     $472 = HEAP32[$outNames>>2]|0;
     $473 = (($outNames) + 4|0);
     $474 = HEAP32[$473>>2]|0;
     $475 = $474;
     $476 = $472;
     $477 = (($475) - ($476))|0;
     $478 = $477 >> 2;
     $479 = ($478|0)==(0);
     if ($479) {
      $489 = $472;
     } else {
      $482 = $472;$__len$03$i$i$i$i$i144 = $478;
      while(1) {
       $480 = (($__len$03$i$i$i$i$i144|0) / 2)&-1;
       $481 = (($482) + ($480<<2)|0);
       $483 = HEAP32[$481>>2]|0;
       $484 = ($483|0)<($$idx1$val$i134|0);
       if ($484) {
        $$sum$i$i$i$i$i145 = (($480) + 1)|0;
        $485 = (($482) + ($$sum$i$i$i$i$i145<<2)|0);
        $$neg2$i$i$i$i$i146 = (($__len$03$i$i$i$i$i144) + -1)|0;
        $486 = (($$neg2$i$i$i$i$i146) - ($480))|0;
        $2052 = $485;$__len$0$be$i$i$i$i$i147 = $486;
       } else {
        $2052 = $482;$__len$0$be$i$i$i$i$i147 = $480;
       }
       $487 = ($__len$0$be$i$i$i$i$i147|0)==(0);
       if ($487) {
        $489 = $2052;
        break;
       } else {
        $482 = $2052;$__len$03$i$i$i$i$i144 = $__len$0$be$i$i$i$i$i147;
       }
      }
     }
     $488 = ($489|0)==($474|0);
     if (!($488)) {
      $490 = HEAP32[$489>>2]|0;
      $491 = ($$idx1$val$i134|0)<($490|0);
      if (!($491)) {
       break;
      }
     }
     HEAP32[$62>>2] = $489;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$62+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($61,$outNames,$$byval_copy35,$0);
     $492 = (($outNames) + 12|0);
     $493 = HEAP32[$492>>2]|0;
     $494 = (Math_fround(($493>>>0)));
     $495 = Math_fround($494 + Math_fround(4.0));
     $496 = (~~(($495))>>>0);
     HEAP32[$492>>2] = $496;
    }
   } while(0);
   $$idx$i135 = (($parsed) + 208|0);
   $$idx$val$i136 = HEAP32[$$idx$i135>>2]|0;
   $497 = ($$idx$val$i136|0)!=(-1);
   $$not$i556 = $497 ^ 1;
   $498 = ($$idx$val$i136>>>0)>(1073741823);
   $$$i$i557 = $497 & $498;
   $or$cond$i558 = $$$i$i557 | $$not$i556;
   if (!($or$cond$i558)) {
    HEAP32[$idx$i555>>2] = $$idx$val$i136;
    $499 = HEAP32[$outNames>>2]|0;
    $500 = (($outNames) + 4|0);
    $501 = HEAP32[$500>>2]|0;
    $502 = $501;
    $503 = $499;
    $504 = (($502) - ($503))|0;
    $505 = $504 >> 2;
    $506 = ($505|0)==(0);
    if ($506) {
     $516 = $499;
    } else {
     $509 = $499;$__len$03$i$i$i$i$i561 = $505;
     while(1) {
      $507 = (($__len$03$i$i$i$i$i561|0) / 2)&-1;
      $508 = (($509) + ($507<<2)|0);
      $510 = HEAP32[$508>>2]|0;
      $511 = ($510|0)<($$idx$val$i136|0);
      if ($511) {
       $$sum$i$i$i$i$i562 = (($507) + 1)|0;
       $512 = (($509) + ($$sum$i$i$i$i$i562<<2)|0);
       $$neg2$i$i$i$i$i563 = (($__len$03$i$i$i$i$i561) + -1)|0;
       $513 = (($$neg2$i$i$i$i$i563) - ($507))|0;
       $2053 = $512;$__len$0$be$i$i$i$i$i564 = $513;
      } else {
       $2053 = $509;$__len$0$be$i$i$i$i$i564 = $507;
      }
      $514 = ($__len$0$be$i$i$i$i$i564|0)==(0);
      if ($514) {
       $516 = $2053;
       break;
      } else {
       $509 = $2053;$__len$03$i$i$i$i$i561 = $__len$0$be$i$i$i$i$i564;
      }
     }
    }
    $515 = ($516|0)==($501|0);
    if (!($515)) {
     $517 = HEAP32[$516>>2]|0;
     $518 = ($$idx$val$i136|0)<($517|0);
     if (!($518)) {
      break;
     }
    }
    HEAP32[$16>>2] = $516;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$16+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($15,$outNames,$$byval_copy35,$idx$i555);
    $519 = (($outNames) + 12|0);
    $520 = HEAP32[$519>>2]|0;
    $521 = (Math_fround(($520>>>0)));
    $522 = Math_fround($521 + Math_fround(4.0));
    $523 = (~~(($522))>>>0);
    HEAP32[$519>>2] = $523;
   }
  } else {
   $390 = ($388>>>0)>(1073741823);
   if (!($390)) {
    HEAP32[$idx$i569>>2] = $388;
    $391 = HEAP32[$outNames>>2]|0;
    $392 = (($outNames) + 4|0);
    $393 = HEAP32[$392>>2]|0;
    $394 = $393;
    $395 = $391;
    $396 = (($394) - ($395))|0;
    $397 = $396 >> 2;
    $398 = ($397|0)==(0);
    if ($398) {
     $408 = $391;
    } else {
     $401 = $391;$__len$03$i$i$i$i$i575 = $397;
     while(1) {
      $399 = (($__len$03$i$i$i$i$i575|0) / 2)&-1;
      $400 = (($401) + ($399<<2)|0);
      $402 = HEAP32[$400>>2]|0;
      $403 = ($402|0)<($388|0);
      if ($403) {
       $$sum$i$i$i$i$i576 = (($399) + 1)|0;
       $404 = (($401) + ($$sum$i$i$i$i$i576<<2)|0);
       $$neg2$i$i$i$i$i577 = (($__len$03$i$i$i$i$i575) + -1)|0;
       $405 = (($$neg2$i$i$i$i$i577) - ($399))|0;
       $2049 = $404;$__len$0$be$i$i$i$i$i578 = $405;
      } else {
       $2049 = $401;$__len$0$be$i$i$i$i$i578 = $399;
      }
      $406 = ($__len$0$be$i$i$i$i$i578|0)==(0);
      if ($406) {
       $408 = $2049;
       break;
      } else {
       $401 = $2049;$__len$03$i$i$i$i$i575 = $__len$0$be$i$i$i$i$i578;
      }
     }
    }
    $407 = ($408|0)==($393|0);
    if (!($407)) {
     $409 = HEAP32[$408>>2]|0;
     $410 = ($388|0)<($409|0);
     if (!($410)) {
      break;
     }
    }
    HEAP32[$14>>2] = $408;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$14+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($13,$outNames,$$byval_copy35,$idx$i569);
    $411 = (($outNames) + 12|0);
    $412 = HEAP32[$411>>2]|0;
    $413 = (Math_fround(($412>>>0)));
    $414 = Math_fround($413 + Math_fround(16.0));
    $415 = (~~(($414))>>>0);
    HEAP32[$411>>2] = $415;
   }
  }
 } while(0);
 $524 = (($this) + 104|0);
 $525 = (($parsed) + 248|0);
 $526 = HEAP32[$525>>2]|0;
 $527 = ($526|0)==(-1);
 if ($527) {
  $528 = (($parsed) + 220|0);
  $529 = HEAP32[$528>>2]|0;
  $530 = ($529|0)==(-1);
  if ($530) {
   $531 = (($parsed) + 216|0);
   $532 = Math_fround(HEAPF32[$531>>2]);
   $phitmp$i152 = (HEAPF32[tempDoublePtr>>2]=$532,HEAP32[tempDoublePtr>>2]|0);
   $2054 = -1;$2055 = $phitmp$i152;$2056 = 0;
  } else {
   $2054 = $529;$2055 = 0;$2056 = 0;
  }
  $533 = (($parsed) + 228|0);
  $534 = HEAP32[$533>>2]|0;
  $535 = ($534|0)==(-1);
  if ($535) {
   $536 = (($parsed) + 224|0);
   $537 = Math_fround(HEAPF32[$536>>2]);
   $phitmp14$i155 = (HEAPF32[tempDoublePtr>>2]=$537,HEAP32[tempDoublePtr>>2]|0);
   $2057 = -1;$2058 = $phitmp14$i155;$2059 = 0;
  } else {
   $2057 = $534;$2058 = 0;$2059 = 0;
  }
  $538 = (($parsed) + 236|0);
  $539 = HEAP32[$538>>2]|0;
  $540 = ($539|0)==(-1);
  if ($540) {
   $541 = (($parsed) + 232|0);
   $542 = Math_fround(HEAPF32[$541>>2]);
   $phitmp16$i158 = (HEAPF32[tempDoublePtr>>2]=$542,HEAP32[tempDoublePtr>>2]|0);
   $2060 = -1;$2061 = $phitmp16$i158;$2062 = 0;
  } else {
   $2060 = $539;$2061 = 0;$2062 = 0;
  }
  $543 = (($parsed) + 244|0);
  $544 = HEAP32[$543>>2]|0;
  $545 = ($544|0)==(-1);
  if ($545) {
   $546 = (($parsed) + 240|0);
   $547 = Math_fround(HEAPF32[$546>>2]);
   $phitmp18$i161 = (HEAPF32[tempDoublePtr>>2]=$547,HEAP32[tempDoublePtr>>2]|0);
   $2063 = -1;$2064 = $phitmp18$i161;$2065 = 0;
  } else {
   $2063 = $544;$2064 = 0;$2065 = 0;
  }
  $549 = $2055;$550 = 0;$552 = $2056;$553 = $2054;$560 = $2058;$561 = 0;$563 = $2059;$564 = $2057;$571 = $2061;$572 = 0;$574 = $2062;$575 = $2060;$582 = $2064;$583 = 0;$585 = $2065;$586 = $2063;$592 = -1;
 } else {
  $549 = 0;$550 = 0;$552 = 0;$553 = -1;$560 = 0;$561 = 0;$563 = 0;$564 = -1;$571 = 0;$572 = 0;$574 = 0;$575 = -1;$582 = 0;$583 = 0;$585 = 0;$586 = -1;$592 = $526;
 }
 $548 = $549 | $550;
 $551 = $552 | $553;
 $554 = $524;
 $555 = $554;
 HEAP32[$555>>2] = $548;
 $556 = (($554) + 4)|0;
 $557 = $556;
 HEAP32[$557>>2] = $551;
 $558 = (($this) + 112|0);
 $559 = $560 | $561;
 $562 = $563 | $564;
 $565 = $558;
 $566 = $565;
 HEAP32[$566>>2] = $559;
 $567 = (($565) + 4)|0;
 $568 = $567;
 HEAP32[$568>>2] = $562;
 $569 = (($this) + 120|0);
 $570 = $571 | $572;
 $573 = $574 | $575;
 $576 = $569;
 $577 = $576;
 HEAP32[$577>>2] = $570;
 $578 = (($576) + 4)|0;
 $579 = $578;
 HEAP32[$579>>2] = $573;
 $580 = (($this) + 128|0);
 $581 = $582 | $583;
 $584 = $585 | $586;
 $587 = $580;
 $588 = $587;
 HEAP32[$588>>2] = $581;
 $589 = (($587) + 4)|0;
 $590 = $589;
 HEAP32[$590>>2] = $584;
 $591 = (($this) + 136|0);
 HEAP32[$591>>2] = $592;
 $593 = HEAP32[$525>>2]|0;
 $594 = ($593|0)==(-1);
 do {
  if ($594) {
   $$idx3$i179 = (($parsed) + 220|0);
   $$idx3$val$i180 = HEAP32[$$idx3$i179>>2]|0;
   $621 = ($$idx3$val$i180|0)!=(-1);
   $$not$i626 = $621 ^ 1;
   $622 = ($$idx3$val$i180>>>0)>(1073741823);
   $$$i$i627 = $621 & $622;
   $or$cond$i628 = $$$i$i627 | $$not$i626;
   do {
    if (!($or$cond$i628)) {
     HEAP32[$0>>2] = $$idx3$val$i180;
     $623 = HEAP32[$outNames>>2]|0;
     $624 = (($outNames) + 4|0);
     $625 = HEAP32[$624>>2]|0;
     $626 = $625;
     $627 = $623;
     $628 = (($626) - ($627))|0;
     $629 = $628 >> 2;
     $630 = ($629|0)==(0);
     if ($630) {
      $640 = $623;
     } else {
      $633 = $623;$__len$03$i$i$i$i$i631 = $629;
      while(1) {
       $631 = (($__len$03$i$i$i$i$i631|0) / 2)&-1;
       $632 = (($633) + ($631<<2)|0);
       $634 = HEAP32[$632>>2]|0;
       $635 = ($634|0)<($$idx3$val$i180|0);
       if ($635) {
        $$sum$i$i$i$i$i632 = (($631) + 1)|0;
        $636 = (($633) + ($$sum$i$i$i$i$i632<<2)|0);
        $$neg2$i$i$i$i$i633 = (($__len$03$i$i$i$i$i631) + -1)|0;
        $637 = (($$neg2$i$i$i$i$i633) - ($631))|0;
        $2067 = $636;$__len$0$be$i$i$i$i$i634 = $637;
       } else {
        $2067 = $633;$__len$0$be$i$i$i$i$i634 = $631;
       }
       $638 = ($__len$0$be$i$i$i$i$i634|0)==(0);
       if ($638) {
        $640 = $2067;
        break;
       } else {
        $633 = $2067;$__len$03$i$i$i$i$i631 = $__len$0$be$i$i$i$i$i634;
       }
      }
     }
     $639 = ($640|0)==($625|0);
     if (!($639)) {
      $641 = HEAP32[$640>>2]|0;
      $642 = ($$idx3$val$i180|0)<($641|0);
      if (!($642)) {
       break;
      }
     }
     HEAP32[$6>>2] = $640;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$6+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($5,$outNames,$$byval_copy35,$0);
     $643 = (($outNames) + 12|0);
     $644 = HEAP32[$643>>2]|0;
     $645 = (Math_fround(($644>>>0)));
     $646 = Math_fround($645 + Math_fround(4.0));
     $647 = (~~(($646))>>>0);
     HEAP32[$643>>2] = $647;
    }
   } while(0);
   $$idx2$i181 = (($parsed) + 228|0);
   $$idx2$val$i182 = HEAP32[$$idx2$i181>>2]|0;
   $648 = ($$idx2$val$i182|0)!=(-1);
   $$not$i216 = $648 ^ 1;
   $649 = ($$idx2$val$i182>>>0)>(1073741823);
   $$$i$i217 = $648 & $649;
   $or$cond$i218 = $$$i$i217 | $$not$i216;
   do {
    if (!($or$cond$i218)) {
     HEAP32[$0>>2] = $$idx2$val$i182;
     $650 = HEAP32[$outNames>>2]|0;
     $651 = (($outNames) + 4|0);
     $652 = HEAP32[$651>>2]|0;
     $653 = $652;
     $654 = $650;
     $655 = (($653) - ($654))|0;
     $656 = $655 >> 2;
     $657 = ($656|0)==(0);
     if ($657) {
      $667 = $650;
     } else {
      $660 = $650;$__len$03$i$i$i$i$i221 = $656;
      while(1) {
       $658 = (($__len$03$i$i$i$i$i221|0) / 2)&-1;
       $659 = (($660) + ($658<<2)|0);
       $661 = HEAP32[$659>>2]|0;
       $662 = ($661|0)<($$idx2$val$i182|0);
       if ($662) {
        $$sum$i$i$i$i$i222 = (($658) + 1)|0;
        $663 = (($660) + ($$sum$i$i$i$i$i222<<2)|0);
        $$neg2$i$i$i$i$i223 = (($__len$03$i$i$i$i$i221) + -1)|0;
        $664 = (($$neg2$i$i$i$i$i223) - ($658))|0;
        $2068 = $663;$__len$0$be$i$i$i$i$i224 = $664;
       } else {
        $2068 = $660;$__len$0$be$i$i$i$i$i224 = $658;
       }
       $665 = ($__len$0$be$i$i$i$i$i224|0)==(0);
       if ($665) {
        $667 = $2068;
        break;
       } else {
        $660 = $2068;$__len$03$i$i$i$i$i221 = $__len$0$be$i$i$i$i$i224;
       }
      }
     }
     $666 = ($667|0)==($652|0);
     if (!($666)) {
      $668 = HEAP32[$667>>2]|0;
      $669 = ($$idx2$val$i182|0)<($668|0);
      if (!($669)) {
       break;
      }
     }
     HEAP32[$56>>2] = $667;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$56+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($55,$outNames,$$byval_copy35,$0);
     $670 = (($outNames) + 12|0);
     $671 = HEAP32[$670>>2]|0;
     $672 = (Math_fround(($671>>>0)));
     $673 = Math_fround($672 + Math_fround(4.0));
     $674 = (~~(($673))>>>0);
     HEAP32[$670>>2] = $674;
    }
   } while(0);
   $$idx1$i183 = (($parsed) + 236|0);
   $$idx1$val$i184 = HEAP32[$$idx1$i183>>2]|0;
   $675 = ($$idx1$val$i184|0)!=(-1);
   $$not$i189 = $675 ^ 1;
   $676 = ($$idx1$val$i184>>>0)>(1073741823);
   $$$i$i190 = $675 & $676;
   $or$cond$i191 = $$$i$i190 | $$not$i189;
   do {
    if (!($or$cond$i191)) {
     HEAP32[$0>>2] = $$idx1$val$i184;
     $677 = HEAP32[$outNames>>2]|0;
     $678 = (($outNames) + 4|0);
     $679 = HEAP32[$678>>2]|0;
     $680 = $679;
     $681 = $677;
     $682 = (($680) - ($681))|0;
     $683 = $682 >> 2;
     $684 = ($683|0)==(0);
     if ($684) {
      $694 = $677;
     } else {
      $687 = $677;$__len$03$i$i$i$i$i194 = $683;
      while(1) {
       $685 = (($__len$03$i$i$i$i$i194|0) / 2)&-1;
       $686 = (($687) + ($685<<2)|0);
       $688 = HEAP32[$686>>2]|0;
       $689 = ($688|0)<($$idx1$val$i184|0);
       if ($689) {
        $$sum$i$i$i$i$i195 = (($685) + 1)|0;
        $690 = (($687) + ($$sum$i$i$i$i$i195<<2)|0);
        $$neg2$i$i$i$i$i196 = (($__len$03$i$i$i$i$i194) + -1)|0;
        $691 = (($$neg2$i$i$i$i$i196) - ($685))|0;
        $2069 = $690;$__len$0$be$i$i$i$i$i197 = $691;
       } else {
        $2069 = $687;$__len$0$be$i$i$i$i$i197 = $685;
       }
       $692 = ($__len$0$be$i$i$i$i$i197|0)==(0);
       if ($692) {
        $694 = $2069;
        break;
       } else {
        $687 = $2069;$__len$03$i$i$i$i$i194 = $__len$0$be$i$i$i$i$i197;
       }
      }
     }
     $693 = ($694|0)==($679|0);
     if (!($693)) {
      $695 = HEAP32[$694>>2]|0;
      $696 = ($$idx1$val$i184|0)<($695|0);
      if (!($696)) {
       break;
      }
     }
     HEAP32[$58>>2] = $694;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$58+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($57,$outNames,$$byval_copy35,$0);
     $697 = (($outNames) + 12|0);
     $698 = HEAP32[$697>>2]|0;
     $699 = (Math_fround(($698>>>0)));
     $700 = Math_fround($699 + Math_fround(4.0));
     $701 = (~~(($700))>>>0);
     HEAP32[$697>>2] = $701;
    }
   } while(0);
   $$idx$i185 = (($parsed) + 244|0);
   $$idx$val$i186 = HEAP32[$$idx$i185>>2]|0;
   $702 = ($$idx$val$i186|0)!=(-1);
   $$not$i598 = $702 ^ 1;
   $703 = ($$idx$val$i186>>>0)>(1073741823);
   $$$i$i599 = $702 & $703;
   $or$cond$i600 = $$$i$i599 | $$not$i598;
   if (!($or$cond$i600)) {
    HEAP32[$idx$i597>>2] = $$idx$val$i186;
    $704 = HEAP32[$outNames>>2]|0;
    $705 = (($outNames) + 4|0);
    $706 = HEAP32[$705>>2]|0;
    $707 = $706;
    $708 = $704;
    $709 = (($707) - ($708))|0;
    $710 = $709 >> 2;
    $711 = ($710|0)==(0);
    if ($711) {
     $721 = $704;
    } else {
     $714 = $704;$__len$03$i$i$i$i$i603 = $710;
     while(1) {
      $712 = (($__len$03$i$i$i$i$i603|0) / 2)&-1;
      $713 = (($714) + ($712<<2)|0);
      $715 = HEAP32[$713>>2]|0;
      $716 = ($715|0)<($$idx$val$i186|0);
      if ($716) {
       $$sum$i$i$i$i$i604 = (($712) + 1)|0;
       $717 = (($714) + ($$sum$i$i$i$i$i604<<2)|0);
       $$neg2$i$i$i$i$i605 = (($__len$03$i$i$i$i$i603) + -1)|0;
       $718 = (($$neg2$i$i$i$i$i605) - ($712))|0;
       $2070 = $717;$__len$0$be$i$i$i$i$i606 = $718;
      } else {
       $2070 = $714;$__len$0$be$i$i$i$i$i606 = $712;
      }
      $719 = ($__len$0$be$i$i$i$i$i606|0)==(0);
      if ($719) {
       $721 = $2070;
       break;
      } else {
       $714 = $2070;$__len$03$i$i$i$i$i603 = $__len$0$be$i$i$i$i$i606;
      }
     }
    }
    $720 = ($721|0)==($706|0);
    if (!($720)) {
     $722 = HEAP32[$721>>2]|0;
     $723 = ($$idx$val$i186|0)<($722|0);
     if (!($723)) {
      break;
     }
    }
    HEAP32[$10>>2] = $721;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$10+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($9,$outNames,$$byval_copy35,$idx$i597);
    $724 = (($outNames) + 12|0);
    $725 = HEAP32[$724>>2]|0;
    $726 = (Math_fround(($725>>>0)));
    $727 = Math_fround($726 + Math_fround(4.0));
    $728 = (~~(($727))>>>0);
    HEAP32[$724>>2] = $728;
   }
  } else {
   $595 = ($593>>>0)>(1073741823);
   if (!($595)) {
    HEAP32[$idx$i611>>2] = $593;
    $596 = HEAP32[$outNames>>2]|0;
    $597 = (($outNames) + 4|0);
    $598 = HEAP32[$597>>2]|0;
    $599 = $598;
    $600 = $596;
    $601 = (($599) - ($600))|0;
    $602 = $601 >> 2;
    $603 = ($602|0)==(0);
    if ($603) {
     $613 = $596;
    } else {
     $606 = $596;$__len$03$i$i$i$i$i617 = $602;
     while(1) {
      $604 = (($__len$03$i$i$i$i$i617|0) / 2)&-1;
      $605 = (($606) + ($604<<2)|0);
      $607 = HEAP32[$605>>2]|0;
      $608 = ($607|0)<($593|0);
      if ($608) {
       $$sum$i$i$i$i$i618 = (($604) + 1)|0;
       $609 = (($606) + ($$sum$i$i$i$i$i618<<2)|0);
       $$neg2$i$i$i$i$i619 = (($__len$03$i$i$i$i$i617) + -1)|0;
       $610 = (($$neg2$i$i$i$i$i619) - ($604))|0;
       $2066 = $609;$__len$0$be$i$i$i$i$i620 = $610;
      } else {
       $2066 = $606;$__len$0$be$i$i$i$i$i620 = $604;
      }
      $611 = ($__len$0$be$i$i$i$i$i620|0)==(0);
      if ($611) {
       $613 = $2066;
       break;
      } else {
       $606 = $2066;$__len$03$i$i$i$i$i617 = $__len$0$be$i$i$i$i$i620;
      }
     }
    }
    $612 = ($613|0)==($598|0);
    if (!($612)) {
     $614 = HEAP32[$613>>2]|0;
     $615 = ($593|0)<($614|0);
     if (!($615)) {
      break;
     }
    }
    HEAP32[$8>>2] = $613;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$8+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($7,$outNames,$$byval_copy35,$idx$i611);
    $616 = (($outNames) + 12|0);
    $617 = HEAP32[$616>>2]|0;
    $618 = (Math_fround(($617>>>0)));
    $619 = Math_fround($618 + Math_fround(16.0));
    $620 = (~~(($619))>>>0);
    HEAP32[$616>>2] = $620;
   }
  }
 } while(0);
 $729 = (($this) + 140|0);
 $730 = (($parsed) + 284|0);
 $731 = HEAP32[$730>>2]|0;
 $732 = ($731|0)==(-1);
 if ($732) {
  $733 = (($parsed) + 256|0);
  $734 = HEAP32[$733>>2]|0;
  $735 = ($734|0)==(-1);
  if ($735) {
   $736 = (($parsed) + 252|0);
   $737 = Math_fround(HEAPF32[$736>>2]);
   $phitmp$i202 = (HEAPF32[tempDoublePtr>>2]=$737,HEAP32[tempDoublePtr>>2]|0);
   $2071 = -1;$2072 = $phitmp$i202;$2073 = 0;
  } else {
   $2071 = $734;$2072 = 0;$2073 = 0;
  }
  $738 = (($parsed) + 264|0);
  $739 = HEAP32[$738>>2]|0;
  $740 = ($739|0)==(-1);
  if ($740) {
   $741 = (($parsed) + 260|0);
   $742 = Math_fround(HEAPF32[$741>>2]);
   $phitmp14$i205 = (HEAPF32[tempDoublePtr>>2]=$742,HEAP32[tempDoublePtr>>2]|0);
   $2074 = -1;$2075 = $phitmp14$i205;$2076 = 0;
  } else {
   $2074 = $739;$2075 = 0;$2076 = 0;
  }
  $743 = (($parsed) + 272|0);
  $744 = HEAP32[$743>>2]|0;
  $745 = ($744|0)==(-1);
  if ($745) {
   $746 = (($parsed) + 268|0);
   $747 = Math_fround(HEAPF32[$746>>2]);
   $phitmp16$i208 = (HEAPF32[tempDoublePtr>>2]=$747,HEAP32[tempDoublePtr>>2]|0);
   $2077 = -1;$2078 = $phitmp16$i208;$2079 = 0;
  } else {
   $2077 = $744;$2078 = 0;$2079 = 0;
  }
  $748 = (($parsed) + 280|0);
  $749 = HEAP32[$748>>2]|0;
  $750 = ($749|0)==(-1);
  if ($750) {
   $751 = (($parsed) + 276|0);
   $752 = Math_fround(HEAPF32[$751>>2]);
   $phitmp18$i211 = (HEAPF32[tempDoublePtr>>2]=$752,HEAP32[tempDoublePtr>>2]|0);
   $2080 = -1;$2081 = $phitmp18$i211;$2082 = 0;
  } else {
   $2080 = $749;$2081 = 0;$2082 = 0;
  }
  $754 = $2072;$755 = 0;$757 = $2073;$758 = $2071;$765 = $2075;$766 = 0;$768 = $2076;$769 = $2074;$776 = $2078;$777 = 0;$779 = $2079;$780 = $2077;$787 = $2081;$788 = 0;$790 = $2082;$791 = $2080;$797 = -1;
 } else {
  $754 = 0;$755 = 0;$757 = 0;$758 = -1;$765 = 0;$766 = 0;$768 = 0;$769 = -1;$776 = 0;$777 = 0;$779 = 0;$780 = -1;$787 = 0;$788 = 0;$790 = 0;$791 = -1;$797 = $731;
 }
 $753 = $754 | $755;
 $756 = $757 | $758;
 $759 = $729;
 $760 = $759;
 HEAP32[$760>>2] = $753;
 $761 = (($759) + 4)|0;
 $762 = $761;
 HEAP32[$762>>2] = $756;
 $763 = (($this) + 148|0);
 $764 = $765 | $766;
 $767 = $768 | $769;
 $770 = $763;
 $771 = $770;
 HEAP32[$771>>2] = $764;
 $772 = (($770) + 4)|0;
 $773 = $772;
 HEAP32[$773>>2] = $767;
 $774 = (($this) + 156|0);
 $775 = $776 | $777;
 $778 = $779 | $780;
 $781 = $774;
 $782 = $781;
 HEAP32[$782>>2] = $775;
 $783 = (($781) + 4)|0;
 $784 = $783;
 HEAP32[$784>>2] = $778;
 $785 = (($this) + 164|0);
 $786 = $787 | $788;
 $789 = $790 | $791;
 $792 = $785;
 $793 = $792;
 HEAP32[$793>>2] = $786;
 $794 = (($792) + 4)|0;
 $795 = $794;
 HEAP32[$795>>2] = $789;
 $796 = (($this) + 172|0);
 HEAP32[$796>>2] = $797;
 $798 = HEAP32[$730>>2]|0;
 $799 = ($798|0)==(-1);
 do {
  if ($799) {
   $$idx3$i229 = (($parsed) + 256|0);
   $$idx3$val$i230 = HEAP32[$$idx3$i229>>2]|0;
   $826 = ($$idx3$val$i230|0)!=(-1);
   $$not$i668 = $826 ^ 1;
   $827 = ($$idx3$val$i230>>>0)>(1073741823);
   $$$i$i669 = $826 & $827;
   $or$cond$i670 = $$$i$i669 | $$not$i668;
   do {
    if (!($or$cond$i670)) {
     HEAP32[$idx$i667>>2] = $$idx3$val$i230;
     $828 = HEAP32[$outNames>>2]|0;
     $829 = (($outNames) + 4|0);
     $830 = HEAP32[$829>>2]|0;
     $831 = $830;
     $832 = $828;
     $833 = (($831) - ($832))|0;
     $834 = $833 >> 2;
     $835 = ($834|0)==(0);
     if ($835) {
      $845 = $828;
     } else {
      $838 = $828;$__len$03$i$i$i$i$i673 = $834;
      while(1) {
       $836 = (($__len$03$i$i$i$i$i673|0) / 2)&-1;
       $837 = (($838) + ($836<<2)|0);
       $839 = HEAP32[$837>>2]|0;
       $840 = ($839|0)<($$idx3$val$i230|0);
       if ($840) {
        $$sum$i$i$i$i$i674 = (($836) + 1)|0;
        $841 = (($838) + ($$sum$i$i$i$i$i674<<2)|0);
        $$neg2$i$i$i$i$i675 = (($__len$03$i$i$i$i$i673) + -1)|0;
        $842 = (($$neg2$i$i$i$i$i675) - ($836))|0;
        $2084 = $841;$__len$0$be$i$i$i$i$i676 = $842;
       } else {
        $2084 = $838;$__len$0$be$i$i$i$i$i676 = $836;
       }
       $843 = ($__len$0$be$i$i$i$i$i676|0)==(0);
       if ($843) {
        $845 = $2084;
        break;
       } else {
        $838 = $2084;$__len$03$i$i$i$i$i673 = $__len$0$be$i$i$i$i$i676;
       }
      }
     }
     $844 = ($845|0)==($830|0);
     if (!($844)) {
      $846 = HEAP32[$845>>2]|0;
      $847 = ($$idx3$val$i230|0)<($846|0);
      if (!($847)) {
       break;
      }
     }
     HEAP32[$1>>2] = $845;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$1+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($0,$outNames,$$byval_copy35,$idx$i667);
     $848 = (($outNames) + 12|0);
     $849 = HEAP32[$848>>2]|0;
     $850 = (Math_fround(($849>>>0)));
     $851 = Math_fround($850 + Math_fround(4.0));
     $852 = (~~(($851))>>>0);
     HEAP32[$848>>2] = $852;
    }
   } while(0);
   $$idx2$i231 = (($parsed) + 264|0);
   $$idx2$val$i232 = HEAP32[$$idx2$i231>>2]|0;
   $853 = ($$idx2$val$i232|0)!=(-1);
   $$not$i266 = $853 ^ 1;
   $854 = ($$idx2$val$i232>>>0)>(1073741823);
   $$$i$i267 = $853 & $854;
   $or$cond$i268 = $$$i$i267 | $$not$i266;
   do {
    if (!($or$cond$i268)) {
     HEAP32[$idx$i667>>2] = $$idx2$val$i232;
     $855 = HEAP32[$outNames>>2]|0;
     $856 = (($outNames) + 4|0);
     $857 = HEAP32[$856>>2]|0;
     $858 = $857;
     $859 = $855;
     $860 = (($858) - ($859))|0;
     $861 = $860 >> 2;
     $862 = ($861|0)==(0);
     if ($862) {
      $872 = $855;
     } else {
      $865 = $855;$__len$03$i$i$i$i$i271 = $861;
      while(1) {
       $863 = (($__len$03$i$i$i$i$i271|0) / 2)&-1;
       $864 = (($865) + ($863<<2)|0);
       $866 = HEAP32[$864>>2]|0;
       $867 = ($866|0)<($$idx2$val$i232|0);
       if ($867) {
        $$sum$i$i$i$i$i272 = (($863) + 1)|0;
        $868 = (($865) + ($$sum$i$i$i$i$i272<<2)|0);
        $$neg2$i$i$i$i$i273 = (($__len$03$i$i$i$i$i271) + -1)|0;
        $869 = (($$neg2$i$i$i$i$i273) - ($863))|0;
        $2085 = $868;$__len$0$be$i$i$i$i$i274 = $869;
       } else {
        $2085 = $865;$__len$0$be$i$i$i$i$i274 = $863;
       }
       $870 = ($__len$0$be$i$i$i$i$i274|0)==(0);
       if ($870) {
        $872 = $2085;
        break;
       } else {
        $865 = $2085;$__len$03$i$i$i$i$i271 = $__len$0$be$i$i$i$i$i274;
       }
      }
     }
     $871 = ($872|0)==($857|0);
     if (!($871)) {
      $873 = HEAP32[$872>>2]|0;
      $874 = ($$idx2$val$i232|0)<($873|0);
      if (!($874)) {
       break;
      }
     }
     HEAP32[$52>>2] = $872;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$52+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($51,$outNames,$$byval_copy35,$idx$i667);
     $875 = (($outNames) + 12|0);
     $876 = HEAP32[$875>>2]|0;
     $877 = (Math_fround(($876>>>0)));
     $878 = Math_fround($877 + Math_fround(4.0));
     $879 = (~~(($878))>>>0);
     HEAP32[$875>>2] = $879;
    }
   } while(0);
   $$idx1$i233 = (($parsed) + 272|0);
   $$idx1$val$i234 = HEAP32[$$idx1$i233>>2]|0;
   $880 = ($$idx1$val$i234|0)!=(-1);
   $$not$i239 = $880 ^ 1;
   $881 = ($$idx1$val$i234>>>0)>(1073741823);
   $$$i$i240 = $880 & $881;
   $or$cond$i241 = $$$i$i240 | $$not$i239;
   do {
    if (!($or$cond$i241)) {
     HEAP32[$idx$i667>>2] = $$idx1$val$i234;
     $882 = HEAP32[$outNames>>2]|0;
     $883 = (($outNames) + 4|0);
     $884 = HEAP32[$883>>2]|0;
     $885 = $884;
     $886 = $882;
     $887 = (($885) - ($886))|0;
     $888 = $887 >> 2;
     $889 = ($888|0)==(0);
     if ($889) {
      $899 = $882;
     } else {
      $892 = $882;$__len$03$i$i$i$i$i244 = $888;
      while(1) {
       $890 = (($__len$03$i$i$i$i$i244|0) / 2)&-1;
       $891 = (($892) + ($890<<2)|0);
       $893 = HEAP32[$891>>2]|0;
       $894 = ($893|0)<($$idx1$val$i234|0);
       if ($894) {
        $$sum$i$i$i$i$i245 = (($890) + 1)|0;
        $895 = (($892) + ($$sum$i$i$i$i$i245<<2)|0);
        $$neg2$i$i$i$i$i246 = (($__len$03$i$i$i$i$i244) + -1)|0;
        $896 = (($$neg2$i$i$i$i$i246) - ($890))|0;
        $2086 = $895;$__len$0$be$i$i$i$i$i247 = $896;
       } else {
        $2086 = $892;$__len$0$be$i$i$i$i$i247 = $890;
       }
       $897 = ($__len$0$be$i$i$i$i$i247|0)==(0);
       if ($897) {
        $899 = $2086;
        break;
       } else {
        $892 = $2086;$__len$03$i$i$i$i$i244 = $__len$0$be$i$i$i$i$i247;
       }
      }
     }
     $898 = ($899|0)==($884|0);
     if (!($898)) {
      $900 = HEAP32[$899>>2]|0;
      $901 = ($$idx1$val$i234|0)<($900|0);
      if (!($901)) {
       break;
      }
     }
     HEAP32[$54>>2] = $899;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$54+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($53,$outNames,$$byval_copy35,$idx$i667);
     $902 = (($outNames) + 12|0);
     $903 = HEAP32[$902>>2]|0;
     $904 = (Math_fround(($903>>>0)));
     $905 = Math_fround($904 + Math_fround(4.0));
     $906 = (~~(($905))>>>0);
     HEAP32[$902>>2] = $906;
    }
   } while(0);
   $$idx$i235 = (($parsed) + 280|0);
   $$idx$val$i236 = HEAP32[$$idx$i235>>2]|0;
   $907 = ($$idx$val$i236|0)!=(-1);
   $$not$i640 = $907 ^ 1;
   $908 = ($$idx$val$i236>>>0)>(1073741823);
   $$$i$i641 = $907 & $908;
   $or$cond$i642 = $$$i$i641 | $$not$i640;
   if (!($or$cond$i642)) {
    HEAP32[$idx$i639>>2] = $$idx$val$i236;
    $909 = HEAP32[$outNames>>2]|0;
    $910 = (($outNames) + 4|0);
    $911 = HEAP32[$910>>2]|0;
    $912 = $911;
    $913 = $909;
    $914 = (($912) - ($913))|0;
    $915 = $914 >> 2;
    $916 = ($915|0)==(0);
    if ($916) {
     $926 = $909;
    } else {
     $919 = $909;$__len$03$i$i$i$i$i645 = $915;
     while(1) {
      $917 = (($__len$03$i$i$i$i$i645|0) / 2)&-1;
      $918 = (($919) + ($917<<2)|0);
      $920 = HEAP32[$918>>2]|0;
      $921 = ($920|0)<($$idx$val$i236|0);
      if ($921) {
       $$sum$i$i$i$i$i646 = (($917) + 1)|0;
       $922 = (($919) + ($$sum$i$i$i$i$i646<<2)|0);
       $$neg2$i$i$i$i$i647 = (($__len$03$i$i$i$i$i645) + -1)|0;
       $923 = (($$neg2$i$i$i$i$i647) - ($917))|0;
       $2087 = $922;$__len$0$be$i$i$i$i$i648 = $923;
      } else {
       $2087 = $919;$__len$0$be$i$i$i$i$i648 = $917;
      }
      $924 = ($__len$0$be$i$i$i$i$i648|0)==(0);
      if ($924) {
       $926 = $2087;
       break;
      } else {
       $919 = $2087;$__len$03$i$i$i$i$i645 = $__len$0$be$i$i$i$i$i648;
      }
     }
    }
    $925 = ($926|0)==($911|0);
    if (!($925)) {
     $927 = HEAP32[$926>>2]|0;
     $928 = ($$idx$val$i236|0)<($927|0);
     if (!($928)) {
      break;
     }
    }
    HEAP32[$4>>2] = $926;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$4+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($3,$outNames,$$byval_copy35,$idx$i639);
    $929 = (($outNames) + 12|0);
    $930 = HEAP32[$929>>2]|0;
    $931 = (Math_fround(($930>>>0)));
    $932 = Math_fround($931 + Math_fround(4.0));
    $933 = (~~(($932))>>>0);
    HEAP32[$929>>2] = $933;
   }
  } else {
   $800 = ($798>>>0)>(1073741823);
   if (!($800)) {
    HEAP32[$idx$i653>>2] = $798;
    $801 = HEAP32[$outNames>>2]|0;
    $802 = (($outNames) + 4|0);
    $803 = HEAP32[$802>>2]|0;
    $804 = $803;
    $805 = $801;
    $806 = (($804) - ($805))|0;
    $807 = $806 >> 2;
    $808 = ($807|0)==(0);
    if ($808) {
     $818 = $801;
    } else {
     $811 = $801;$__len$03$i$i$i$i$i659 = $807;
     while(1) {
      $809 = (($__len$03$i$i$i$i$i659|0) / 2)&-1;
      $810 = (($811) + ($809<<2)|0);
      $812 = HEAP32[$810>>2]|0;
      $813 = ($812|0)<($798|0);
      if ($813) {
       $$sum$i$i$i$i$i660 = (($809) + 1)|0;
       $814 = (($811) + ($$sum$i$i$i$i$i660<<2)|0);
       $$neg2$i$i$i$i$i661 = (($__len$03$i$i$i$i$i659) + -1)|0;
       $815 = (($$neg2$i$i$i$i$i661) - ($809))|0;
       $2083 = $814;$__len$0$be$i$i$i$i$i662 = $815;
      } else {
       $2083 = $811;$__len$0$be$i$i$i$i$i662 = $809;
      }
      $816 = ($__len$0$be$i$i$i$i$i662|0)==(0);
      if ($816) {
       $818 = $2083;
       break;
      } else {
       $811 = $2083;$__len$03$i$i$i$i$i659 = $__len$0$be$i$i$i$i$i662;
      }
     }
    }
    $817 = ($818|0)==($803|0);
    if (!($817)) {
     $819 = HEAP32[$818>>2]|0;
     $820 = ($798|0)<($819|0);
     if (!($820)) {
      break;
     }
    }
    HEAP32[$2>>2] = $818;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$2+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($idx$i667,$outNames,$$byval_copy35,$idx$i653);
    $821 = (($outNames) + 12|0);
    $822 = HEAP32[$821>>2]|0;
    $823 = (Math_fround(($822>>>0)));
    $824 = Math_fround($823 + Math_fround(16.0));
    $825 = (~~(($824))>>>0);
    HEAP32[$821>>2] = $825;
   }
  }
 } while(0);
 $934 = (($this) + 176|0);
 $935 = (($parsed) + 320|0);
 $936 = HEAP32[$935>>2]|0;
 $937 = ($936|0)==(-1);
 if ($937) {
  $938 = (($parsed) + 292|0);
  $939 = HEAP32[$938>>2]|0;
  $940 = ($939|0)==(-1);
  if ($940) {
   $941 = (($parsed) + 288|0);
   $942 = Math_fround(HEAPF32[$941>>2]);
   $phitmp$i252 = (HEAPF32[tempDoublePtr>>2]=$942,HEAP32[tempDoublePtr>>2]|0);
   $2088 = -1;$2089 = $phitmp$i252;$2090 = 0;
  } else {
   $2088 = $939;$2089 = 0;$2090 = 0;
  }
  $943 = (($parsed) + 300|0);
  $944 = HEAP32[$943>>2]|0;
  $945 = ($944|0)==(-1);
  if ($945) {
   $946 = (($parsed) + 296|0);
   $947 = Math_fround(HEAPF32[$946>>2]);
   $phitmp14$i255 = (HEAPF32[tempDoublePtr>>2]=$947,HEAP32[tempDoublePtr>>2]|0);
   $2091 = -1;$2092 = $phitmp14$i255;$2093 = 0;
  } else {
   $2091 = $944;$2092 = 0;$2093 = 0;
  }
  $948 = (($parsed) + 308|0);
  $949 = HEAP32[$948>>2]|0;
  $950 = ($949|0)==(-1);
  if ($950) {
   $951 = (($parsed) + 304|0);
   $952 = Math_fround(HEAPF32[$951>>2]);
   $phitmp16$i258 = (HEAPF32[tempDoublePtr>>2]=$952,HEAP32[tempDoublePtr>>2]|0);
   $2094 = -1;$2095 = $phitmp16$i258;$2096 = 0;
  } else {
   $2094 = $949;$2095 = 0;$2096 = 0;
  }
  $953 = (($parsed) + 316|0);
  $954 = HEAP32[$953>>2]|0;
  $955 = ($954|0)==(-1);
  if ($955) {
   $956 = (($parsed) + 312|0);
   $957 = Math_fround(HEAPF32[$956>>2]);
   $phitmp18$i261 = (HEAPF32[tempDoublePtr>>2]=$957,HEAP32[tempDoublePtr>>2]|0);
   $2097 = -1;$2098 = $phitmp18$i261;$2099 = 0;
  } else {
   $2097 = $954;$2098 = 0;$2099 = 0;
  }
  $1002 = -1;$959 = $2089;$960 = 0;$962 = $2090;$963 = $2088;$970 = $2092;$971 = 0;$973 = $2093;$974 = $2091;$981 = $2095;$982 = 0;$984 = $2096;$985 = $2094;$992 = $2098;$993 = 0;$995 = $2099;$996 = $2097;
 } else {
  $1002 = $936;$959 = 0;$960 = 0;$962 = 0;$963 = -1;$970 = 0;$971 = 0;$973 = 0;$974 = -1;$981 = 0;$982 = 0;$984 = 0;$985 = -1;$992 = 0;$993 = 0;$995 = 0;$996 = -1;
 }
 $958 = $959 | $960;
 $961 = $962 | $963;
 $964 = $934;
 $965 = $964;
 HEAP32[$965>>2] = $958;
 $966 = (($964) + 4)|0;
 $967 = $966;
 HEAP32[$967>>2] = $961;
 $968 = (($this) + 184|0);
 $969 = $970 | $971;
 $972 = $973 | $974;
 $975 = $968;
 $976 = $975;
 HEAP32[$976>>2] = $969;
 $977 = (($975) + 4)|0;
 $978 = $977;
 HEAP32[$978>>2] = $972;
 $979 = (($this) + 192|0);
 $980 = $981 | $982;
 $983 = $984 | $985;
 $986 = $979;
 $987 = $986;
 HEAP32[$987>>2] = $980;
 $988 = (($986) + 4)|0;
 $989 = $988;
 HEAP32[$989>>2] = $983;
 $990 = (($this) + 200|0);
 $991 = $992 | $993;
 $994 = $995 | $996;
 $997 = $990;
 $998 = $997;
 HEAP32[$998>>2] = $991;
 $999 = (($997) + 4)|0;
 $1000 = $999;
 HEAP32[$1000>>2] = $994;
 $1001 = (($this) + 208|0);
 HEAP32[$1001>>2] = $1002;
 $1003 = HEAP32[$935>>2]|0;
 $1004 = ($1003|0)==(-1);
 do {
  if ($1004) {
   $$idx3$i279 = (($parsed) + 292|0);
   $$idx3$val$i280 = HEAP32[$$idx3$i279>>2]|0;
   $1031 = ($$idx3$val$i280|0)!=(-1);
   $$not$i333 = $1031 ^ 1;
   $1032 = ($$idx3$val$i280>>>0)>(1073741823);
   $$$i$i334 = $1031 & $1032;
   $or$cond$i335 = $$$i$i334 | $$not$i333;
   do {
    if (!($or$cond$i335)) {
     HEAP32[$23>>2] = $$idx3$val$i280;
     $1033 = HEAP32[$outNames>>2]|0;
     $1034 = (($outNames) + 4|0);
     $1035 = HEAP32[$1034>>2]|0;
     $1036 = $1035;
     $1037 = $1033;
     $1038 = (($1036) - ($1037))|0;
     $1039 = $1038 >> 2;
     $1040 = ($1039|0)==(0);
     if ($1040) {
      $1050 = $1033;
     } else {
      $1043 = $1033;$__len$03$i$i$i$i$i338 = $1039;
      while(1) {
       $1041 = (($__len$03$i$i$i$i$i338|0) / 2)&-1;
       $1042 = (($1043) + ($1041<<2)|0);
       $1044 = HEAP32[$1042>>2]|0;
       $1045 = ($1044|0)<($$idx3$val$i280|0);
       if ($1045) {
        $$sum$i$i$i$i$i339 = (($1041) + 1)|0;
        $1046 = (($1043) + ($$sum$i$i$i$i$i339<<2)|0);
        $$neg2$i$i$i$i$i340 = (($__len$03$i$i$i$i$i338) + -1)|0;
        $1047 = (($$neg2$i$i$i$i$i340) - ($1041))|0;
        $2101 = $1046;$__len$0$be$i$i$i$i$i341 = $1047;
       } else {
        $2101 = $1043;$__len$0$be$i$i$i$i$i341 = $1041;
       }
       $1048 = ($__len$0$be$i$i$i$i$i341|0)==(0);
       if ($1048) {
        $1050 = $2101;
        break;
       } else {
        $1043 = $2101;$__len$03$i$i$i$i$i338 = $__len$0$be$i$i$i$i$i341;
       }
      }
     }
     $1049 = ($1050|0)==($1035|0);
     if (!($1049)) {
      $1051 = HEAP32[$1050>>2]|0;
      $1052 = ($$idx3$val$i280|0)<($1051|0);
      if (!($1052)) {
       break;
      }
     }
     HEAP32[$44>>2] = $1050;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$44+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($43,$outNames,$$byval_copy35,$23);
     $1053 = (($outNames) + 12|0);
     $1054 = HEAP32[$1053>>2]|0;
     $1055 = (Math_fround(($1054>>>0)));
     $1056 = Math_fround($1055 + Math_fround(4.0));
     $1057 = (~~(($1056))>>>0);
     HEAP32[$1053>>2] = $1057;
    }
   } while(0);
   $$idx2$i281 = (($parsed) + 300|0);
   $$idx2$val$i282 = HEAP32[$$idx2$i281>>2]|0;
   $1058 = ($$idx2$val$i282|0)!=(-1);
   $$not$i304 = $1058 ^ 1;
   $1059 = ($$idx2$val$i282>>>0)>(1073741823);
   $$$i$i305 = $1058 & $1059;
   $or$cond$i306 = $$$i$i305 | $$not$i304;
   do {
    if (!($or$cond$i306)) {
     HEAP32[$23>>2] = $$idx2$val$i282;
     $1060 = HEAP32[$outNames>>2]|0;
     $1061 = (($outNames) + 4|0);
     $1062 = HEAP32[$1061>>2]|0;
     $1063 = $1062;
     $1064 = $1060;
     $1065 = (($1063) - ($1064))|0;
     $1066 = $1065 >> 2;
     $1067 = ($1066|0)==(0);
     if ($1067) {
      $1077 = $1060;
     } else {
      $1070 = $1060;$__len$03$i$i$i$i$i309 = $1066;
      while(1) {
       $1068 = (($__len$03$i$i$i$i$i309|0) / 2)&-1;
       $1069 = (($1070) + ($1068<<2)|0);
       $1071 = HEAP32[$1069>>2]|0;
       $1072 = ($1071|0)<($$idx2$val$i282|0);
       if ($1072) {
        $$sum$i$i$i$i$i310 = (($1068) + 1)|0;
        $1073 = (($1070) + ($$sum$i$i$i$i$i310<<2)|0);
        $$neg2$i$i$i$i$i311 = (($__len$03$i$i$i$i$i309) + -1)|0;
        $1074 = (($$neg2$i$i$i$i$i311) - ($1068))|0;
        $2102 = $1073;$__len$0$be$i$i$i$i$i312 = $1074;
       } else {
        $2102 = $1070;$__len$0$be$i$i$i$i$i312 = $1068;
       }
       $1075 = ($__len$0$be$i$i$i$i$i312|0)==(0);
       if ($1075) {
        $1077 = $2102;
        break;
       } else {
        $1070 = $2102;$__len$03$i$i$i$i$i309 = $__len$0$be$i$i$i$i$i312;
       }
      }
     }
     $1076 = ($1077|0)==($1062|0);
     if (!($1076)) {
      $1078 = HEAP32[$1077>>2]|0;
      $1079 = ($$idx2$val$i282|0)<($1078|0);
      if (!($1079)) {
       break;
      }
     }
     HEAP32[$48>>2] = $1077;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$48+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($47,$outNames,$$byval_copy35,$23);
     $1080 = (($outNames) + 12|0);
     $1081 = HEAP32[$1080>>2]|0;
     $1082 = (Math_fround(($1081>>>0)));
     $1083 = Math_fround($1082 + Math_fround(4.0));
     $1084 = (~~(($1083))>>>0);
     HEAP32[$1080>>2] = $1084;
    }
   } while(0);
   $$idx1$i283 = (($parsed) + 308|0);
   $$idx1$val$i284 = HEAP32[$$idx1$i283>>2]|0;
   $1085 = ($$idx1$val$i284|0)!=(-1);
   $$not$i289 = $1085 ^ 1;
   $1086 = ($$idx1$val$i284>>>0)>(1073741823);
   $$$i$i290 = $1085 & $1086;
   $or$cond$i291 = $$$i$i290 | $$not$i289;
   do {
    if (!($or$cond$i291)) {
     HEAP32[$23>>2] = $$idx1$val$i284;
     $1087 = HEAP32[$outNames>>2]|0;
     $1088 = (($outNames) + 4|0);
     $1089 = HEAP32[$1088>>2]|0;
     $1090 = $1089;
     $1091 = $1087;
     $1092 = (($1090) - ($1091))|0;
     $1093 = $1092 >> 2;
     $1094 = ($1093|0)==(0);
     if ($1094) {
      $1104 = $1087;
     } else {
      $1097 = $1087;$__len$03$i$i$i$i$i294 = $1093;
      while(1) {
       $1095 = (($__len$03$i$i$i$i$i294|0) / 2)&-1;
       $1096 = (($1097) + ($1095<<2)|0);
       $1098 = HEAP32[$1096>>2]|0;
       $1099 = ($1098|0)<($$idx1$val$i284|0);
       if ($1099) {
        $$sum$i$i$i$i$i295 = (($1095) + 1)|0;
        $1100 = (($1097) + ($$sum$i$i$i$i$i295<<2)|0);
        $$neg2$i$i$i$i$i296 = (($__len$03$i$i$i$i$i294) + -1)|0;
        $1101 = (($$neg2$i$i$i$i$i296) - ($1095))|0;
        $2103 = $1100;$__len$0$be$i$i$i$i$i297 = $1101;
       } else {
        $2103 = $1097;$__len$0$be$i$i$i$i$i297 = $1095;
       }
       $1102 = ($__len$0$be$i$i$i$i$i297|0)==(0);
       if ($1102) {
        $1104 = $2103;
        break;
       } else {
        $1097 = $2103;$__len$03$i$i$i$i$i294 = $__len$0$be$i$i$i$i$i297;
       }
      }
     }
     $1103 = ($1104|0)==($1089|0);
     if (!($1103)) {
      $1105 = HEAP32[$1104>>2]|0;
      $1106 = ($$idx1$val$i284|0)<($1105|0);
      if (!($1106)) {
       break;
      }
     }
     HEAP32[$50>>2] = $1104;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$50+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($49,$outNames,$$byval_copy35,$23);
     $1107 = (($outNames) + 12|0);
     $1108 = HEAP32[$1107>>2]|0;
     $1109 = (Math_fround(($1108>>>0)));
     $1110 = Math_fround($1109 + Math_fround(4.0));
     $1111 = (~~(($1110))>>>0);
     HEAP32[$1107>>2] = $1111;
    }
   } while(0);
   $$idx$i285 = (($parsed) + 316|0);
   $$idx$val$i286 = HEAP32[$$idx$i285>>2]|0;
   $1112 = ($$idx$val$i286|0)!=(-1);
   $$not$i403 = $1112 ^ 1;
   $1113 = ($$idx$val$i286>>>0)>(1073741823);
   $$$i$i404 = $1112 & $1113;
   $or$cond$i405 = $$$i$i404 | $$not$i403;
   if (!($or$cond$i405)) {
    HEAP32[$idx$i402>>2] = $$idx$val$i286;
    $1114 = HEAP32[$outNames>>2]|0;
    $1115 = (($outNames) + 4|0);
    $1116 = HEAP32[$1115>>2]|0;
    $1117 = $1116;
    $1118 = $1114;
    $1119 = (($1117) - ($1118))|0;
    $1120 = $1119 >> 2;
    $1121 = ($1120|0)==(0);
    if ($1121) {
     $1131 = $1114;
    } else {
     $1124 = $1114;$__len$03$i$i$i$i$i408 = $1120;
     while(1) {
      $1122 = (($__len$03$i$i$i$i$i408|0) / 2)&-1;
      $1123 = (($1124) + ($1122<<2)|0);
      $1125 = HEAP32[$1123>>2]|0;
      $1126 = ($1125|0)<($$idx$val$i286|0);
      if ($1126) {
       $$sum$i$i$i$i$i409 = (($1122) + 1)|0;
       $1127 = (($1124) + ($$sum$i$i$i$i$i409<<2)|0);
       $$neg2$i$i$i$i$i410 = (($__len$03$i$i$i$i$i408) + -1)|0;
       $1128 = (($$neg2$i$i$i$i$i410) - ($1122))|0;
       $2104 = $1127;$__len$0$be$i$i$i$i$i411 = $1128;
      } else {
       $2104 = $1124;$__len$0$be$i$i$i$i$i411 = $1122;
      }
      $1129 = ($__len$0$be$i$i$i$i$i411|0)==(0);
      if ($1129) {
       $1131 = $2104;
       break;
      } else {
       $1124 = $2104;$__len$03$i$i$i$i$i408 = $__len$0$be$i$i$i$i$i411;
      }
     }
    }
    $1130 = ($1131|0)==($1116|0);
    if (!($1130)) {
     $1132 = HEAP32[$1131>>2]|0;
     $1133 = ($$idx$val$i286|0)<($1132|0);
     if (!($1133)) {
      break;
     }
    }
    HEAP32[$36>>2] = $1131;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$36+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($35,$outNames,$$byval_copy35,$idx$i402);
    $1134 = (($outNames) + 12|0);
    $1135 = HEAP32[$1134>>2]|0;
    $1136 = (Math_fround(($1135>>>0)));
    $1137 = Math_fround($1136 + Math_fround(4.0));
    $1138 = (~~(($1137))>>>0);
    HEAP32[$1134>>2] = $1138;
   }
  } else {
   $1005 = ($1003>>>0)>(1073741823);
   if (!($1005)) {
    HEAP32[$idx$i361>>2] = $1003;
    $1006 = HEAP32[$outNames>>2]|0;
    $1007 = (($outNames) + 4|0);
    $1008 = HEAP32[$1007>>2]|0;
    $1009 = $1008;
    $1010 = $1006;
    $1011 = (($1009) - ($1010))|0;
    $1012 = $1011 >> 2;
    $1013 = ($1012|0)==(0);
    if ($1013) {
     $1023 = $1006;
    } else {
     $1016 = $1006;$__len$03$i$i$i$i$i367 = $1012;
     while(1) {
      $1014 = (($__len$03$i$i$i$i$i367|0) / 2)&-1;
      $1015 = (($1016) + ($1014<<2)|0);
      $1017 = HEAP32[$1015>>2]|0;
      $1018 = ($1017|0)<($1003|0);
      if ($1018) {
       $$sum$i$i$i$i$i368 = (($1014) + 1)|0;
       $1019 = (($1016) + ($$sum$i$i$i$i$i368<<2)|0);
       $$neg2$i$i$i$i$i369 = (($__len$03$i$i$i$i$i367) + -1)|0;
       $1020 = (($$neg2$i$i$i$i$i369) - ($1014))|0;
       $2100 = $1019;$__len$0$be$i$i$i$i$i370 = $1020;
      } else {
       $2100 = $1016;$__len$0$be$i$i$i$i$i370 = $1014;
      }
      $1021 = ($__len$0$be$i$i$i$i$i370|0)==(0);
      if ($1021) {
       $1023 = $2100;
       break;
      } else {
       $1016 = $2100;$__len$03$i$i$i$i$i367 = $__len$0$be$i$i$i$i$i370;
      }
     }
    }
    $1022 = ($1023|0)==($1008|0);
    if (!($1022)) {
     $1024 = HEAP32[$1023>>2]|0;
     $1025 = ($1003|0)<($1024|0);
     if (!($1025)) {
      break;
     }
    }
    HEAP32[$40>>2] = $1023;
    ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$40+0>>2]|0;
    __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($39,$outNames,$$byval_copy35,$idx$i361);
    $1026 = (($outNames) + 12|0);
    $1027 = HEAP32[$1026>>2]|0;
    $1028 = (Math_fround(($1027>>>0)));
    $1029 = Math_fround($1028 + Math_fround(16.0));
    $1030 = (~~(($1029))>>>0);
    HEAP32[$1026>>2] = $1030;
   }
  }
 } while(0);
 $1139 = (($parsed) + 324|0);
 $1140 = HEAP8[$1139>>0]|0;
 $1141 = (($this) + 221|0);
 HEAP8[$1141>>0] = $1140;
 $1142 = (($this) + 224|0);
 $1143 = (($parsed) + 452|0);
 $1144 = HEAP32[$1143>>2]|0;
 $1145 = ($1144|0)==(-1);
 if ($1145) {
  $1146 = (($parsed) + 448|0);
  $1147 = Math_fround(HEAPF32[$1146>>2]);
  $phitmp948 = (HEAPF32[tempDoublePtr>>2]=$1147,HEAP32[tempDoublePtr>>2]|0);
  $1149 = -1;$1150 = 0;$1153 = $phitmp948;
 } else {
  $1149 = $1144;$1150 = 0;$1153 = 0;
 }
 $1148 = $1149 | $1150;
 $1151 = $1142;
 $1152 = $1151;
 HEAP32[$1152>>2] = $1153;
 $1154 = (($1151) + 4)|0;
 $1155 = $1154;
 HEAP32[$1155>>2] = $1148;
 $$idx25$val = HEAP32[$1143>>2]|0;
 $1156 = ($$idx25$val|0)!=(-1);
 $$not$i318 = $1156 ^ 1;
 $1157 = ($$idx25$val>>>0)>(1073741823);
 $$$i$i319 = $1156 & $1157;
 $or$cond$i320 = $$$i$i319 | $$not$i318;
 do {
  if (!($or$cond$i320)) {
   HEAP32[$23>>2] = $$idx25$val;
   $1158 = HEAP32[$outNames>>2]|0;
   $1159 = (($outNames) + 4|0);
   $1160 = HEAP32[$1159>>2]|0;
   $1161 = $1160;
   $1162 = $1158;
   $1163 = (($1161) - ($1162))|0;
   $1164 = $1163 >> 2;
   $1165 = ($1164|0)==(0);
   if ($1165) {
    $1175 = $1158;
   } else {
    $1168 = $1158;$__len$03$i$i$i$i$i323 = $1164;
    while(1) {
     $1166 = (($__len$03$i$i$i$i$i323|0) / 2)&-1;
     $1167 = (($1168) + ($1166<<2)|0);
     $1169 = HEAP32[$1167>>2]|0;
     $1170 = ($1169|0)<($$idx25$val|0);
     if ($1170) {
      $$sum$i$i$i$i$i324 = (($1166) + 1)|0;
      $1171 = (($1168) + ($$sum$i$i$i$i$i324<<2)|0);
      $$neg2$i$i$i$i$i325 = (($__len$03$i$i$i$i$i323) + -1)|0;
      $1172 = (($$neg2$i$i$i$i$i325) - ($1166))|0;
      $2105 = $1171;$__len$0$be$i$i$i$i$i326 = $1172;
     } else {
      $2105 = $1168;$__len$0$be$i$i$i$i$i326 = $1166;
     }
     $1173 = ($__len$0$be$i$i$i$i$i326|0)==(0);
     if ($1173) {
      $1175 = $2105;
      break;
     } else {
      $1168 = $2105;$__len$03$i$i$i$i$i323 = $__len$0$be$i$i$i$i$i326;
     }
    }
   }
   $1174 = ($1175|0)==($1160|0);
   if (!($1174)) {
    $1176 = HEAP32[$1175>>2]|0;
    $1177 = ($$idx25$val|0)<($1176|0);
    if (!($1177)) {
     break;
    }
   }
   HEAP32[$46>>2] = $1175;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$46+0>>2]|0;
   __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($45,$outNames,$$byval_copy35,$23);
   $1178 = (($outNames) + 12|0);
   $1179 = HEAP32[$1178>>2]|0;
   $1180 = (Math_fround(($1179>>>0)));
   $1181 = Math_fround($1180 + Math_fround(4.0));
   $1182 = (~~(($1181))>>>0);
   HEAP32[$1178>>2] = $1182;
  }
 } while(0);
 $1183 = (($this) + 232|0);
 $1184 = (($parsed) + 460|0);
 $1185 = HEAP32[$1184>>2]|0;
 $1186 = ($1185|0)==(-1);
 if ($1186) {
  $1187 = (($parsed) + 456|0);
  $1188 = Math_fround(HEAPF32[$1187>>2]);
  $phitmp950 = (HEAPF32[tempDoublePtr>>2]=$1188,HEAP32[tempDoublePtr>>2]|0);
  $1190 = -1;$1191 = 0;$1194 = $phitmp950;
 } else {
  $1190 = $1185;$1191 = 0;$1194 = 0;
 }
 $1189 = $1190 | $1191;
 $1192 = $1183;
 $1193 = $1192;
 HEAP32[$1193>>2] = $1194;
 $1195 = (($1192) + 4)|0;
 $1196 = $1195;
 HEAP32[$1196>>2] = $1189;
 $$idx24$val = HEAP32[$1184>>2]|0;
 $1197 = ($$idx24$val|0)!=(-1);
 $$not$i347 = $1197 ^ 1;
 $1198 = ($$idx24$val>>>0)>(1073741823);
 $$$i$i348 = $1197 & $1198;
 $or$cond$i349 = $$$i$i348 | $$not$i347;
 do {
  if (!($or$cond$i349)) {
   HEAP32[$23>>2] = $$idx24$val;
   $1199 = HEAP32[$outNames>>2]|0;
   $1200 = (($outNames) + 4|0);
   $1201 = HEAP32[$1200>>2]|0;
   $1202 = $1201;
   $1203 = $1199;
   $1204 = (($1202) - ($1203))|0;
   $1205 = $1204 >> 2;
   $1206 = ($1205|0)==(0);
   if ($1206) {
    $1216 = $1199;
   } else {
    $1209 = $1199;$__len$03$i$i$i$i$i352 = $1205;
    while(1) {
     $1207 = (($__len$03$i$i$i$i$i352|0) / 2)&-1;
     $1208 = (($1209) + ($1207<<2)|0);
     $1210 = HEAP32[$1208>>2]|0;
     $1211 = ($1210|0)<($$idx24$val|0);
     if ($1211) {
      $$sum$i$i$i$i$i353 = (($1207) + 1)|0;
      $1212 = (($1209) + ($$sum$i$i$i$i$i353<<2)|0);
      $$neg2$i$i$i$i$i354 = (($__len$03$i$i$i$i$i352) + -1)|0;
      $1213 = (($$neg2$i$i$i$i$i354) - ($1207))|0;
      $2106 = $1212;$__len$0$be$i$i$i$i$i355 = $1213;
     } else {
      $2106 = $1209;$__len$0$be$i$i$i$i$i355 = $1207;
     }
     $1214 = ($__len$0$be$i$i$i$i$i355|0)==(0);
     if ($1214) {
      $1216 = $2106;
      break;
     } else {
      $1209 = $2106;$__len$03$i$i$i$i$i352 = $__len$0$be$i$i$i$i$i355;
     }
    }
   }
   $1215 = ($1216|0)==($1201|0);
   if (!($1215)) {
    $1217 = HEAP32[$1216>>2]|0;
    $1218 = ($$idx24$val|0)<($1217|0);
    if (!($1218)) {
     break;
    }
   }
   HEAP32[$42>>2] = $1216;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$42+0>>2]|0;
   __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($41,$outNames,$$byval_copy35,$23);
   $1219 = (($outNames) + 12|0);
   $1220 = HEAP32[$1219>>2]|0;
   $1221 = (Math_fround(($1220>>>0)));
   $1222 = Math_fround($1221 + Math_fround(4.0));
   $1223 = (~~(($1222))>>>0);
   HEAP32[$1219>>2] = $1223;
  }
 } while(0);
 $1224 = (($this) + 240|0);
 $1225 = (($parsed) + 468|0);
 $1226 = HEAP32[$1225>>2]|0;
 $1227 = ($1226|0)==(-1);
 if ($1227) {
  $1228 = (($parsed) + 464|0);
  $1229 = Math_fround(HEAPF32[$1228>>2]);
  $phitmp952 = (HEAPF32[tempDoublePtr>>2]=$1229,HEAP32[tempDoublePtr>>2]|0);
  $1231 = -1;$1232 = 0;$1235 = $phitmp952;
 } else {
  $1231 = $1226;$1232 = 0;$1235 = 0;
 }
 $1230 = $1231 | $1232;
 $1233 = $1224;
 $1234 = $1233;
 HEAP32[$1234>>2] = $1235;
 $1236 = (($1233) + 4)|0;
 $1237 = $1236;
 HEAP32[$1237>>2] = $1230;
 $$idx23$val = HEAP32[$1225>>2]|0;
 $1238 = ($$idx23$val|0)!=(-1);
 $$not$i376 = $1238 ^ 1;
 $1239 = ($$idx23$val>>>0)>(1073741823);
 $$$i$i377 = $1238 & $1239;
 $or$cond$i378 = $$$i$i377 | $$not$i376;
 do {
  if (!($or$cond$i378)) {
   HEAP32[$23>>2] = $$idx23$val;
   $1240 = HEAP32[$outNames>>2]|0;
   $1241 = (($outNames) + 4|0);
   $1242 = HEAP32[$1241>>2]|0;
   $1243 = $1242;
   $1244 = $1240;
   $1245 = (($1243) - ($1244))|0;
   $1246 = $1245 >> 2;
   $1247 = ($1246|0)==(0);
   if ($1247) {
    $1257 = $1240;
   } else {
    $1250 = $1240;$__len$03$i$i$i$i$i381 = $1246;
    while(1) {
     $1248 = (($__len$03$i$i$i$i$i381|0) / 2)&-1;
     $1249 = (($1250) + ($1248<<2)|0);
     $1251 = HEAP32[$1249>>2]|0;
     $1252 = ($1251|0)<($$idx23$val|0);
     if ($1252) {
      $$sum$i$i$i$i$i382 = (($1248) + 1)|0;
      $1253 = (($1250) + ($$sum$i$i$i$i$i382<<2)|0);
      $$neg2$i$i$i$i$i383 = (($__len$03$i$i$i$i$i381) + -1)|0;
      $1254 = (($$neg2$i$i$i$i$i383) - ($1248))|0;
      $2107 = $1253;$__len$0$be$i$i$i$i$i384 = $1254;
     } else {
      $2107 = $1250;$__len$0$be$i$i$i$i$i384 = $1248;
     }
     $1255 = ($__len$0$be$i$i$i$i$i384|0)==(0);
     if ($1255) {
      $1257 = $2107;
      break;
     } else {
      $1250 = $2107;$__len$03$i$i$i$i$i381 = $__len$0$be$i$i$i$i$i384;
     }
    }
   }
   $1256 = ($1257|0)==($1242|0);
   if (!($1256)) {
    $1258 = HEAP32[$1257>>2]|0;
    $1259 = ($$idx23$val|0)<($1258|0);
    if (!($1259)) {
     break;
    }
   }
   HEAP32[$38>>2] = $1257;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$38+0>>2]|0;
   __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($37,$outNames,$$byval_copy35,$23);
   $1260 = (($outNames) + 12|0);
   $1261 = HEAP32[$1260>>2]|0;
   $1262 = (Math_fround(($1261>>>0)));
   $1263 = Math_fround($1262 + Math_fround(4.0));
   $1264 = (~~(($1263))>>>0);
   HEAP32[$1260>>2] = $1264;
  }
 } while(0);
 $1265 = (($this) + 248|0);
 $1266 = (($parsed) + 504|0);
 $1267 = HEAP32[$1266>>2]|0;
 $1268 = ($1267|0)==(-1);
 if ($1268) {
  $1269 = (($parsed) + 476|0);
  $1270 = HEAP32[$1269>>2]|0;
  $1271 = ($1270|0)==(-1);
  if ($1271) {
   $1272 = (($parsed) + 472|0);
   $1273 = Math_fround(HEAPF32[$1272>>2]);
   $phitmp$i389 = (HEAPF32[tempDoublePtr>>2]=$1273,HEAP32[tempDoublePtr>>2]|0);
   $2108 = -1;$2109 = $phitmp$i389;$2110 = 0;
  } else {
   $2108 = $1270;$2109 = 0;$2110 = 0;
  }
  $1274 = (($parsed) + 484|0);
  $1275 = HEAP32[$1274>>2]|0;
  $1276 = ($1275|0)==(-1);
  if ($1276) {
   $1277 = (($parsed) + 480|0);
   $1278 = Math_fround(HEAPF32[$1277>>2]);
   $phitmp14$i392 = (HEAPF32[tempDoublePtr>>2]=$1278,HEAP32[tempDoublePtr>>2]|0);
   $2111 = -1;$2112 = $phitmp14$i392;$2113 = 0;
  } else {
   $2111 = $1275;$2112 = 0;$2113 = 0;
  }
  $1279 = (($parsed) + 492|0);
  $1280 = HEAP32[$1279>>2]|0;
  $1281 = ($1280|0)==(-1);
  if ($1281) {
   $1282 = (($parsed) + 488|0);
   $1283 = Math_fround(HEAPF32[$1282>>2]);
   $phitmp16$i395 = (HEAPF32[tempDoublePtr>>2]=$1283,HEAP32[tempDoublePtr>>2]|0);
   $2114 = -1;$2115 = $phitmp16$i395;$2116 = 0;
  } else {
   $2114 = $1280;$2115 = 0;$2116 = 0;
  }
  $1284 = (($parsed) + 500|0);
  $1285 = HEAP32[$1284>>2]|0;
  $1286 = ($1285|0)==(-1);
  if ($1286) {
   $1287 = (($parsed) + 496|0);
   $1288 = Math_fround(HEAPF32[$1287>>2]);
   $phitmp18$i398 = (HEAPF32[tempDoublePtr>>2]=$1288,HEAP32[tempDoublePtr>>2]|0);
   $2117 = -1;$2118 = $phitmp18$i398;$2119 = 0;
  } else {
   $2117 = $1285;$2118 = 0;$2119 = 0;
  }
  $1290 = $2109;$1291 = 0;$1293 = $2110;$1294 = $2108;$1301 = $2112;$1302 = 0;$1304 = $2113;$1305 = $2111;$1312 = $2115;$1313 = 0;$1315 = $2116;$1316 = $2114;$1323 = $2118;$1324 = 0;$1326 = $2119;$1327 = $2117;$1333 = -1;
 } else {
  $1290 = 0;$1291 = 0;$1293 = 0;$1294 = -1;$1301 = 0;$1302 = 0;$1304 = 0;$1305 = -1;$1312 = 0;$1313 = 0;$1315 = 0;$1316 = -1;$1323 = 0;$1324 = 0;$1326 = 0;$1327 = -1;$1333 = $1267;
 }
 $1289 = $1290 | $1291;
 $1292 = $1293 | $1294;
 $1295 = $1265;
 $1296 = $1295;
 HEAP32[$1296>>2] = $1289;
 $1297 = (($1295) + 4)|0;
 $1298 = $1297;
 HEAP32[$1298>>2] = $1292;
 $1299 = (($this) + 256|0);
 $1300 = $1301 | $1302;
 $1303 = $1304 | $1305;
 $1306 = $1299;
 $1307 = $1306;
 HEAP32[$1307>>2] = $1300;
 $1308 = (($1306) + 4)|0;
 $1309 = $1308;
 HEAP32[$1309>>2] = $1303;
 $1310 = (($this) + 264|0);
 $1311 = $1312 | $1313;
 $1314 = $1315 | $1316;
 $1317 = $1310;
 $1318 = $1317;
 HEAP32[$1318>>2] = $1311;
 $1319 = (($1317) + 4)|0;
 $1320 = $1319;
 HEAP32[$1320>>2] = $1314;
 $1321 = (($this) + 272|0);
 $1322 = $1323 | $1324;
 $1325 = $1326 | $1327;
 $1328 = $1321;
 $1329 = $1328;
 HEAP32[$1329>>2] = $1322;
 $1330 = (($1328) + 4)|0;
 $1331 = $1330;
 HEAP32[$1331>>2] = $1325;
 $1332 = (($this) + 280|0);
 HEAP32[$1332>>2] = $1333;
 $1334 = HEAP32[$1266>>2]|0;
 $1335 = ($1334|0)==(-1);
 do {
  if ($1335) {
   $$idx3$i416 = (($parsed) + 476|0);
   $$idx3$val$i417 = HEAP32[$$idx3$i416>>2]|0;
   $1362 = ($$idx3$val$i417|0)!=(-1);
   $$not$i470 = $1362 ^ 1;
   $1363 = ($$idx3$val$i417>>>0)>(1073741823);
   $$$i$i471 = $1362 & $1363;
   $or$cond$i472 = $$$i$i471 | $$not$i470;
   do {
    if (!($or$cond$i472)) {
     HEAP32[$23>>2] = $$idx3$val$i417;
     $1364 = HEAP32[$outNames>>2]|0;
     $1365 = (($outNames) + 4|0);
     $1366 = HEAP32[$1365>>2]|0;
     $1367 = $1366;
     $1368 = $1364;
     $1369 = (($1367) - ($1368))|0;
     $1370 = $1369 >> 2;
     $1371 = ($1370|0)==(0);
     if ($1371) {
      $1381 = $1364;
     } else {
      $1374 = $1364;$__len$03$i$i$i$i$i475 = $1370;
      while(1) {
       $1372 = (($__len$03$i$i$i$i$i475|0) / 2)&-1;
       $1373 = (($1374) + ($1372<<2)|0);
       $1375 = HEAP32[$1373>>2]|0;
       $1376 = ($1375|0)<($$idx3$val$i417|0);
       if ($1376) {
        $$sum$i$i$i$i$i476 = (($1372) + 1)|0;
        $1377 = (($1374) + ($$sum$i$i$i$i$i476<<2)|0);
        $$neg2$i$i$i$i$i477 = (($__len$03$i$i$i$i$i475) + -1)|0;
        $1378 = (($$neg2$i$i$i$i$i477) - ($1372))|0;
        $2121 = $1377;$__len$0$be$i$i$i$i$i478 = $1378;
       } else {
        $2121 = $1374;$__len$0$be$i$i$i$i$i478 = $1372;
       }
       $1379 = ($__len$0$be$i$i$i$i$i478|0)==(0);
       if ($1379) {
        $1381 = $2121;
        break;
       } else {
        $1374 = $2121;$__len$03$i$i$i$i$i475 = $__len$0$be$i$i$i$i$i478;
       }
      }
     }
     $1380 = ($1381|0)==($1366|0);
     if (!($1380)) {
      $1382 = HEAP32[$1381>>2]|0;
      $1383 = ($$idx3$val$i417|0)<($1382|0);
      if (!($1383)) {
       break;
      }
     }
     HEAP32[$28>>2] = $1381;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$28+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($27,$outNames,$$byval_copy35,$23);
     $1384 = (($outNames) + 12|0);
     $1385 = HEAP32[$1384>>2]|0;
     $1386 = (Math_fround(($1385>>>0)));
     $1387 = Math_fround($1386 + Math_fround(4.0));
     $1388 = (~~(($1387))>>>0);
     HEAP32[$1384>>2] = $1388;
    }
   } while(0);
   $$idx2$i418 = (($parsed) + 484|0);
   $$idx2$val$i419 = HEAP32[$$idx2$i418>>2]|0;
   $1389 = ($$idx2$val$i419|0)!=(-1);
   $$not$i441 = $1389 ^ 1;
   $1390 = ($$idx2$val$i419>>>0)>(1073741823);
   $$$i$i442 = $1389 & $1390;
   $or$cond$i443 = $$$i$i442 | $$not$i441;
   do {
    if (!($or$cond$i443)) {
     HEAP32[$23>>2] = $$idx2$val$i419;
     $1391 = HEAP32[$outNames>>2]|0;
     $1392 = (($outNames) + 4|0);
     $1393 = HEAP32[$1392>>2]|0;
     $1394 = $1393;
     $1395 = $1391;
     $1396 = (($1394) - ($1395))|0;
     $1397 = $1396 >> 2;
     $1398 = ($1397|0)==(0);
     if ($1398) {
      $1408 = $1391;
     } else {
      $1401 = $1391;$__len$03$i$i$i$i$i446 = $1397;
      while(1) {
       $1399 = (($__len$03$i$i$i$i$i446|0) / 2)&-1;
       $1400 = (($1401) + ($1399<<2)|0);
       $1402 = HEAP32[$1400>>2]|0;
       $1403 = ($1402|0)<($$idx2$val$i419|0);
       if ($1403) {
        $$sum$i$i$i$i$i447 = (($1399) + 1)|0;
        $1404 = (($1401) + ($$sum$i$i$i$i$i447<<2)|0);
        $$neg2$i$i$i$i$i448 = (($__len$03$i$i$i$i$i446) + -1)|0;
        $1405 = (($$neg2$i$i$i$i$i448) - ($1399))|0;
        $2122 = $1404;$__len$0$be$i$i$i$i$i449 = $1405;
       } else {
        $2122 = $1401;$__len$0$be$i$i$i$i$i449 = $1399;
       }
       $1406 = ($__len$0$be$i$i$i$i$i449|0)==(0);
       if ($1406) {
        $1408 = $2122;
        break;
       } else {
        $1401 = $2122;$__len$03$i$i$i$i$i446 = $__len$0$be$i$i$i$i$i449;
       }
      }
     }
     $1407 = ($1408|0)==($1393|0);
     if (!($1407)) {
      $1409 = HEAP32[$1408>>2]|0;
      $1410 = ($$idx2$val$i419|0)<($1409|0);
      if (!($1410)) {
       break;
      }
     }
     HEAP32[$32>>2] = $1408;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$32+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($31,$outNames,$$byval_copy35,$23);
     $1411 = (($outNames) + 12|0);
     $1412 = HEAP32[$1411>>2]|0;
     $1413 = (Math_fround(($1412>>>0)));
     $1414 = Math_fround($1413 + Math_fround(4.0));
     $1415 = (~~(($1414))>>>0);
     HEAP32[$1411>>2] = $1415;
    }
   } while(0);
   $$idx1$i420 = (($parsed) + 492|0);
   $$idx1$val$i421 = HEAP32[$$idx1$i420>>2]|0;
   $1416 = ($$idx1$val$i421|0)!=(-1);
   $$not$i426 = $1416 ^ 1;
   $1417 = ($$idx1$val$i421>>>0)>(1073741823);
   $$$i$i427 = $1416 & $1417;
   $or$cond$i428 = $$$i$i427 | $$not$i426;
   do {
    if (!($or$cond$i428)) {
     HEAP32[$23>>2] = $$idx1$val$i421;
     $1418 = HEAP32[$outNames>>2]|0;
     $1419 = (($outNames) + 4|0);
     $1420 = HEAP32[$1419>>2]|0;
     $1421 = $1420;
     $1422 = $1418;
     $1423 = (($1421) - ($1422))|0;
     $1424 = $1423 >> 2;
     $1425 = ($1424|0)==(0);
     if ($1425) {
      $1435 = $1418;
     } else {
      $1428 = $1418;$__len$03$i$i$i$i$i431 = $1424;
      while(1) {
       $1426 = (($__len$03$i$i$i$i$i431|0) / 2)&-1;
       $1427 = (($1428) + ($1426<<2)|0);
       $1429 = HEAP32[$1427>>2]|0;
       $1430 = ($1429|0)<($$idx1$val$i421|0);
       if ($1430) {
        $$sum$i$i$i$i$i432 = (($1426) + 1)|0;
        $1431 = (($1428) + ($$sum$i$i$i$i$i432<<2)|0);
        $$neg2$i$i$i$i$i433 = (($__len$03$i$i$i$i$i431) + -1)|0;
        $1432 = (($$neg2$i$i$i$i$i433) - ($1426))|0;
        $2123 = $1431;$__len$0$be$i$i$i$i$i434 = $1432;
       } else {
        $2123 = $1428;$__len$0$be$i$i$i$i$i434 = $1426;
       }
       $1433 = ($__len$0$be$i$i$i$i$i434|0)==(0);
       if ($1433) {
        $1435 = $2123;
        break;
       } else {
        $1428 = $2123;$__len$03$i$i$i$i$i431 = $__len$0$be$i$i$i$i$i434;
       }
      }
     }
     $1434 = ($1435|0)==($1420|0);
     if (!($1434)) {
      $1436 = HEAP32[$1435>>2]|0;
      $1437 = ($$idx1$val$i421|0)<($1436|0);
      if (!($1437)) {
       break;
      }
     }
     HEAP32[$34>>2] = $1435;
     ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$34+0>>2]|0;
     __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($33,$outNames,$$byval_copy35,$23);
     $1438 = (($outNames) + 12|0);
     $1439 = HEAP32[$1438>>2]|0;
     $1440 = (Math_fround(($1439>>>0)));
     $1441 = Math_fround($1440 + Math_fround(4.0));
     $1442 = (~~(($1441))>>>0);
     HEAP32[$1438>>2] = $1442;
    }
   } while(0);
   $$idx$i422 = (($parsed) + 500|0);
   $$idx$val$i423 = HEAP32[$$idx$i422>>2]|0;
   $1443 = ($$idx$val$i423|0)!=(-1);
   $$not$i500 = $1443 ^ 1;
   $1444 = ($$idx$val$i423>>>0)>(1073741823);
   $$$i$i501 = $1443 & $1444;
   $or$cond$i502 = $$$i$i501 | $$not$i500;
   if ($or$cond$i502) {
    break;
   }
   HEAP32[$idx$i499>>2] = $$idx$val$i423;
   $1445 = HEAP32[$outNames>>2]|0;
   $1446 = (($outNames) + 4|0);
   $1447 = HEAP32[$1446>>2]|0;
   $1448 = $1447;
   $1449 = $1445;
   $1450 = (($1448) - ($1449))|0;
   $1451 = $1450 >> 2;
   $1452 = ($1451|0)==(0);
   if ($1452) {
    $1462 = $1445;
   } else {
    $1455 = $1445;$__len$03$i$i$i$i$i505 = $1451;
    while(1) {
     $1453 = (($__len$03$i$i$i$i$i505|0) / 2)&-1;
     $1454 = (($1455) + ($1453<<2)|0);
     $1456 = HEAP32[$1454>>2]|0;
     $1457 = ($1456|0)<($$idx$val$i423|0);
     if ($1457) {
      $$sum$i$i$i$i$i506 = (($1453) + 1)|0;
      $1458 = (($1455) + ($$sum$i$i$i$i$i506<<2)|0);
      $$neg2$i$i$i$i$i507 = (($__len$03$i$i$i$i$i505) + -1)|0;
      $1459 = (($$neg2$i$i$i$i$i507) - ($1453))|0;
      $2124 = $1458;$__len$0$be$i$i$i$i$i508 = $1459;
     } else {
      $2124 = $1455;$__len$0$be$i$i$i$i$i508 = $1453;
     }
     $1460 = ($__len$0$be$i$i$i$i$i508|0)==(0);
     if ($1460) {
      $1462 = $2124;
      break;
     } else {
      $1455 = $2124;$__len$03$i$i$i$i$i505 = $__len$0$be$i$i$i$i$i508;
     }
    }
   }
   $1461 = ($1462|0)==($1447|0);
   if (!($1461)) {
    $1463 = HEAP32[$1462>>2]|0;
    $1464 = ($$idx$val$i423|0)<($1463|0);
    if (!($1464)) {
     break;
    }
   }
   HEAP32[$24>>2] = $1462;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$24+0>>2]|0;
   __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($23,$outNames,$$byval_copy35,$idx$i499);
   $1465 = (($outNames) + 12|0);
   $1466 = HEAP32[$1465>>2]|0;
   $1467 = (Math_fround(($1466>>>0)));
   $1468 = Math_fround($1467 + Math_fround(4.0));
   $1469 = (~~(($1468))>>>0);
   HEAP32[$1465>>2] = $1469;
  } else {
   $1336 = ($1334>>>0)>(1073741823);
   if ($1336) {
    break;
   }
   HEAP32[$idx$i484>>2] = $1334;
   $1337 = HEAP32[$outNames>>2]|0;
   $1338 = (($outNames) + 4|0);
   $1339 = HEAP32[$1338>>2]|0;
   $1340 = $1339;
   $1341 = $1337;
   $1342 = (($1340) - ($1341))|0;
   $1343 = $1342 >> 2;
   $1344 = ($1343|0)==(0);
   if ($1344) {
    $1354 = $1337;
   } else {
    $1347 = $1337;$__len$03$i$i$i$i$i490 = $1343;
    while(1) {
     $1345 = (($__len$03$i$i$i$i$i490|0) / 2)&-1;
     $1346 = (($1347) + ($1345<<2)|0);
     $1348 = HEAP32[$1346>>2]|0;
     $1349 = ($1348|0)<($1334|0);
     if ($1349) {
      $$sum$i$i$i$i$i491 = (($1345) + 1)|0;
      $1350 = (($1347) + ($$sum$i$i$i$i$i491<<2)|0);
      $$neg2$i$i$i$i$i492 = (($__len$03$i$i$i$i$i490) + -1)|0;
      $1351 = (($$neg2$i$i$i$i$i492) - ($1345))|0;
      $2120 = $1350;$__len$0$be$i$i$i$i$i493 = $1351;
     } else {
      $2120 = $1347;$__len$0$be$i$i$i$i$i493 = $1345;
     }
     $1352 = ($__len$0$be$i$i$i$i$i493|0)==(0);
     if ($1352) {
      $1354 = $2120;
      break;
     } else {
      $1347 = $2120;$__len$03$i$i$i$i$i490 = $__len$0$be$i$i$i$i$i493;
     }
    }
   }
   $1353 = ($1354|0)==($1339|0);
   if (!($1353)) {
    $1355 = HEAP32[$1354>>2]|0;
    $1356 = ($1334|0)<($1355|0);
    if (!($1356)) {
     break;
    }
   }
   HEAP32[$26>>2] = $1354;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$26+0>>2]|0;
   __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($25,$outNames,$$byval_copy35,$idx$i484);
   $1357 = (($outNames) + 12|0);
   $1358 = HEAP32[$1357>>2]|0;
   $1359 = (Math_fround(($1358>>>0)));
   $1360 = Math_fround($1359 + Math_fround(16.0));
   $1361 = (~~(($1360))>>>0);
   HEAP32[$1357>>2] = $1361;
  }
 } while(0);
 $1470 = (($parsed) + 508|0);
 $1471 = HEAP32[$1470>>2]|0;
 $1472 = (($this) + 284|0);
 HEAP32[$1472>>2] = $1471;
 $1473 = (($parsed) + 516|0);
 $1474 = HEAP32[$1473>>2]|0;
 $1475 = (($this) + 288|0);
 HEAP32[$1475>>2] = $1474;
 $1476 = (($this) + 16|0);
 $1477 = (($parsed) + 40|0);
 $1478 = HEAP32[$1477>>2]|0;
 $1479 = ($1478|0)==(-1);
 if ($1479) {
  $1480 = (($parsed) + 36|0);
  $1481 = Math_fround(HEAPF32[$1480>>2]);
  $phitmp970 = (HEAPF32[tempDoublePtr>>2]=$1481,HEAP32[tempDoublePtr>>2]|0);
  $1483 = -1;$1484 = 0;$1487 = $phitmp970;
 } else {
  $1483 = $1478;$1484 = 0;$1487 = 0;
 }
 $1482 = $1483 | $1484;
 $1485 = $1476;
 $1486 = $1485;
 HEAP32[$1486>>2] = $1487;
 $1488 = (($1485) + 4)|0;
 $1489 = $1488;
 HEAP32[$1489>>2] = $1482;
 $$idx22$val = HEAP32[$1477>>2]|0;
 $1490 = ($$idx22$val|0)!=(-1);
 $$not$i455 = $1490 ^ 1;
 $1491 = ($$idx22$val>>>0)>(1073741823);
 $$$i$i456 = $1490 & $1491;
 $or$cond$i457 = $$$i$i456 | $$not$i455;
 do {
  if (!($or$cond$i457)) {
   HEAP32[$idx$i454>>2] = $$idx22$val;
   $1492 = HEAP32[$outNames>>2]|0;
   $1493 = (($outNames) + 4|0);
   $1494 = HEAP32[$1493>>2]|0;
   $1495 = $1494;
   $1496 = $1492;
   $1497 = (($1495) - ($1496))|0;
   $1498 = $1497 >> 2;
   $1499 = ($1498|0)==(0);
   if ($1499) {
    $1509 = $1492;
   } else {
    $1502 = $1492;$__len$03$i$i$i$i$i460 = $1498;
    while(1) {
     $1500 = (($__len$03$i$i$i$i$i460|0) / 2)&-1;
     $1501 = (($1502) + ($1500<<2)|0);
     $1503 = HEAP32[$1501>>2]|0;
     $1504 = ($1503|0)<($$idx22$val|0);
     if ($1504) {
      $$sum$i$i$i$i$i461 = (($1500) + 1)|0;
      $1505 = (($1502) + ($$sum$i$i$i$i$i461<<2)|0);
      $$neg2$i$i$i$i$i462 = (($__len$03$i$i$i$i$i460) + -1)|0;
      $1506 = (($$neg2$i$i$i$i$i462) - ($1500))|0;
      $2125 = $1505;$__len$0$be$i$i$i$i$i463 = $1506;
     } else {
      $2125 = $1502;$__len$0$be$i$i$i$i$i463 = $1500;
     }
     $1507 = ($__len$0$be$i$i$i$i$i463|0)==(0);
     if ($1507) {
      $1509 = $2125;
      break;
     } else {
      $1502 = $2125;$__len$03$i$i$i$i$i460 = $__len$0$be$i$i$i$i$i463;
     }
    }
   }
   $1508 = ($1509|0)==($1494|0);
   if (!($1508)) {
    $1510 = HEAP32[$1509>>2]|0;
    $1511 = ($$idx22$val|0)<($1510|0);
    if (!($1511)) {
     break;
    }
   }
   HEAP32[$30>>2] = $1509;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$30+0>>2]|0;
   __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($29,$outNames,$$byval_copy35,$idx$i454);
   $1512 = (($outNames) + 12|0);
   $1513 = HEAP32[$1512>>2]|0;
   $1514 = (Math_fround(($1513>>>0)));
   $1515 = Math_fround($1514 + Math_fround(4.0));
   $1516 = (~~(($1515))>>>0);
   HEAP32[$1512>>2] = $1516;
  }
 } while(0);
 $1517 = (($this) + 444|0);
 $1518 = (($parsed) + 56|0);
 $1519 = HEAP32[$1518>>2]|0;
 $1520 = ($1519|0)==(-1);
 if ($1520) {
  $1521 = (($parsed) + 52|0);
  $1522 = Math_fround(HEAPF32[$1521>>2]);
  $phitmp972 = (HEAPF32[tempDoublePtr>>2]=$1522,HEAP32[tempDoublePtr>>2]|0);
  $1524 = -1;$1525 = 0;$1528 = $phitmp972;
 } else {
  $1524 = $1519;$1525 = 0;$1528 = 0;
 }
 $1523 = $1524 | $1525;
 $1526 = $1517;
 $1527 = $1526;
 HEAP32[$1527>>2] = $1528;
 $1529 = (($1526) + 4)|0;
 $1530 = $1529;
 HEAP32[$1530>>2] = $1523;
 $1531 = (($this) + 452|0);
 $1532 = (($parsed) + 72|0);
 $1533 = HEAP32[$1532>>2]|0;
 $1534 = ($1533|0)==(-1);
 if ($1534) {
  $1535 = (($parsed) + 68|0);
  $1536 = Math_fround(HEAPF32[$1535>>2]);
  $phitmp974 = (HEAPF32[tempDoublePtr>>2]=$1536,HEAP32[tempDoublePtr>>2]|0);
  $1538 = -1;$1539 = 0;$1542 = $phitmp974;
 } else {
  $1538 = $1533;$1539 = 0;$1542 = 0;
 }
 $1537 = $1538 | $1539;
 $1540 = $1531;
 $1541 = $1540;
 HEAP32[$1541>>2] = $1542;
 $1543 = (($1540) + 4)|0;
 $1544 = $1543;
 HEAP32[$1544>>2] = $1537;
 $1545 = (($this) + 460|0);
 $1546 = (($parsed) + 64|0);
 $1547 = HEAP32[$1546>>2]|0;
 $1548 = ($1547|0)==(-1);
 $1549 = (HEAP32[tempDoublePtr>>2]=$1542,Math_fround(HEAPF32[tempDoublePtr>>2]));
 if ($1548) {
  $1550 = (($parsed) + 60|0);
  $1551 = Math_fround(HEAPF32[$1550>>2]);
  $phitmp976 = (HEAPF32[tempDoublePtr>>2]=$1551,HEAP32[tempDoublePtr>>2]|0);
  $1553 = -1;$1554 = 0;$1557 = $phitmp976;
 } else {
  $1553 = $1547;$1554 = 0;$1557 = 0;
 }
 $1552 = $1553 | $1554;
 $1555 = $1545;
 $1556 = $1555;
 HEAP32[$1556>>2] = $1557;
 $1558 = (($1555) + 4)|0;
 $1559 = $1558;
 HEAP32[$1559>>2] = $1552;
 $1560 = ($1538|0)==(-1);
 $1561 = (HEAP32[tempDoublePtr>>2]=$1557,Math_fround(HEAPF32[tempDoublePtr>>2]));
 do {
  if ($1560) {
   $1562 = (($this) + 452|0);
   $1563 = $1549 == Math_fround(1.0);
   $1564 = ($1553|0)==(-1);
   $or$cond = $1563 & $1564;
   if (!($or$cond)) {
    break;
   }
   $1565 = (($this) + 460|0);
   $1566 = $1561 == Math_fround(1.0);
   if (!($1566)) {
    break;
   }
   $1567 = (($parsed) + 648|0);
   $1568 = HEAP32[$1567>>2]|0;
   $1569 = ($1568|0)==(0);
   if ($1569) {
    break;
   }
   HEAP8[$$byval_copy35>>0] = 18;
   $1570 = (($$byval_copy35) + 1|0);
   dest=$1570+0|0; src=679176+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $1571 = (($$byval_copy35) + 10|0);
   HEAP8[$1571>>0] = 0;
   __THREW__ = 0;
   $1572 = (invoke_ii(3224,($$byval_copy35|0))|0);
   $1573 = __THREW__; __THREW__ = 0;
   $1574 = $1573&1;
   if ($1574) {
    $1610 = ___cxa_find_matching_catch()|0;
    $1611 = tempRet0;
    $1612 = HEAP8[$$byval_copy35>>0]|0;
    $1613 = $1612 & 1;
    $1614 = ($1613<<24>>24)==(0);
    if ($1614) {
     $$0$i = $1610;$$01$i = $1611;
     ___resumeException($$0$i|0);
     // unreachable;
    }
    $1615 = (($$byval_copy35) + 8|0);
    $1616 = HEAP32[$1615>>2]|0;
    __ZdlPv($1616);
    $$0$i = $1610;$$01$i = $1611;
    ___resumeException($$0$i|0);
    // unreachable;
   }
   $1575 = HEAP8[$$byval_copy35>>0]|0;
   $1576 = $1575 & 1;
   $1577 = ($1576<<24>>24)==(0);
   if (!($1577)) {
    $1578 = (($$byval_copy35) + 8|0);
    $1579 = HEAP32[$1578>>2]|0;
    __ZdlPv($1579);
   }
   $1580 = (__Znwj(16)|0);
   $1581 = (($idx$i454) + 8|0);
   HEAP32[$1581>>2] = $1580;
   HEAP32[$idx$i454>>2] = 17;
   $1582 = (($idx$i454) + 4|0);
   HEAP32[$1582>>2] = 12;
   dest=$1580+0|0; src=679192+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $1583 = (($1580) + 12|0);
   HEAP8[$1583>>0] = 0;
   __THREW__ = 0;
   $1584 = (invoke_ii(3224,($idx$i454|0))|0);
   $1585 = __THREW__; __THREW__ = 0;
   $1586 = $1585&1;
   if ($1586) {
    $1617 = ___cxa_find_matching_catch()|0;
    $1618 = tempRet0;
    $1619 = HEAP8[$idx$i454>>0]|0;
    $1620 = $1619 & 1;
    $1621 = ($1620<<24>>24)==(0);
    if ($1621) {
     $$0$i = $1617;$$01$i = $1618;
     ___resumeException($$0$i|0);
     // unreachable;
    }
    $1622 = HEAP32[$1581>>2]|0;
    __ZdlPv($1622);
    $$0$i = $1617;$$01$i = $1618;
    ___resumeException($$0$i|0);
    // unreachable;
   }
   $1587 = HEAP8[$idx$i454>>0]|0;
   $1588 = $1587 & 1;
   $1589 = ($1588<<24>>24)==(0);
   if (!($1589)) {
    $1590 = HEAP32[$1581>>2]|0;
    __ZdlPv($1590);
   }
   $1591 = (($parsed) + 644|0);
   $1592 = HEAP32[$1591>>2]|0;
   $1593 = (($parsed) + 644|0);
   $1594 = ($1592|0)==(0|0);
   if ($1594) {
    break;
   } else {
    $$0$ph7$i$i$i$i = $1593;$$01$ph6$i$in$i$i$i = $1592;
   }
   L595: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $1595 = (($$013$i$in$i$i$i) + 16|0);
     $1596 = HEAP32[$1595>>2]|0;
     $1597 = ($1596|0)<($1572|0);
     if (!($1597)) {
      break;
     }
     $1600 = (($$013$i$in$i$i$i) + 4|0);
     $1601 = HEAP32[$1600>>2]|0;
     $1602 = ($1601|0)==(0|0);
     if ($1602) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L595;
     } else {
      $$013$i$in$i$i$i = $1601;
     }
    }
    $1598 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $1599 = ($1598|0)==(0|0);
    if ($1599) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $1598;
    }
   }
   $1603 = ($$0$ph5$i$i$i$i|0)==($1593|0);
   if ($1603) {
    break;
   }
   $1604 = (($$0$ph5$i$i$i$i) + 16|0);
   $1605 = HEAP32[$1604>>2]|0;
   $1606 = ($1572|0)<($1605|0);
   if ($1606) {
    break;
   }
   $1607 = (($$0$ph5$i$i$i$i) + 20|0);
   $1608 = HEAP32[$1607>>2]|0;
   $1609 = ($1608|0)==($1584|0);
   if (!($1609)) {
    break;
   }
   HEAPF32[$1562>>2] = Math_fround(0.0);
   HEAPF32[$1565>>2] = Math_fround(0.0);
  }
 } while(0);
 $1623 = (($this) + 356|0);
 $1624 = (($this) + 412|0);
 $1625 = (($parsed) + 32|0);
 $1626 = HEAP32[$1625>>2]|0;
 $1627 = ($1626|0)==(-1);
 if ($1627) {
  $1628 = (($parsed) + 28|0);
  $1629 = Math_fround(HEAPF32[$1628>>2]);
  $phitmp978 = (HEAPF32[tempDoublePtr>>2]=$1629,HEAP32[tempDoublePtr>>2]|0);
  $1631 = -1;$1632 = 0;$1635 = $phitmp978;
 } else {
  $1631 = $1626;$1632 = 0;$1635 = 0;
 }
 $1630 = $1631 | $1632;
 $1633 = $1624;
 $1634 = $1633;
 HEAP32[$1634>>2] = $1635;
 $1636 = (($1633) + 4)|0;
 $1637 = $1636;
 HEAP32[$1637>>2] = $1630;
 $1638 = (($parsed) + 92|0);
 $1639 = HEAP32[$1638>>2]|0;
 $1640 = ($1639|0)==(-1);
 if ($1640) {
  $1641 = (($parsed) + 88|0);
  $1642 = Math_fround(HEAPF32[$1641>>2]);
  $phitmp980 = (HEAPF32[tempDoublePtr>>2]=$1642,HEAP32[tempDoublePtr>>2]|0);
  $1644 = -1;$1645 = 0;$1648 = $phitmp980;
 } else {
  $1644 = $1639;$1645 = 0;$1648 = 0;
 }
 $1643 = $1644 | $1645;
 $1646 = $1623;
 $1647 = $1646;
 HEAP32[$1647>>2] = $1648;
 $1649 = (($1646) + 4)|0;
 $1650 = $1649;
 HEAP32[$1650>>2] = $1643;
 $1651 = (($this) + 364|0);
 $1652 = (($parsed) + 100|0);
 $1653 = HEAP32[$1652>>2]|0;
 $1654 = ($1653|0)==(-1);
 if ($1654) {
  $1655 = (($parsed) + 96|0);
  $1656 = Math_fround(HEAPF32[$1655>>2]);
  $phitmp982 = (HEAPF32[tempDoublePtr>>2]=$1656,HEAP32[tempDoublePtr>>2]|0);
  $1658 = -1;$1659 = 0;$1662 = $phitmp982;
 } else {
  $1658 = $1653;$1659 = 0;$1662 = 0;
 }
 $1657 = $1658 | $1659;
 $1660 = $1651;
 $1661 = $1660;
 HEAP32[$1661>>2] = $1662;
 $1663 = (($1660) + 4)|0;
 $1664 = $1663;
 HEAP32[$1664>>2] = $1657;
 $1665 = (($this) + 372|0);
 $1666 = (($parsed) + 108|0);
 $1667 = HEAP32[$1666>>2]|0;
 $1668 = ($1667|0)==(-1);
 if ($1668) {
  $1669 = (($parsed) + 104|0);
  $1670 = Math_fround(HEAPF32[$1669>>2]);
  $phitmp984 = (HEAPF32[tempDoublePtr>>2]=$1670,HEAP32[tempDoublePtr>>2]|0);
  $1672 = -1;$1673 = 0;$1676 = $phitmp984;
 } else {
  $1672 = $1667;$1673 = 0;$1676 = 0;
 }
 $1671 = $1672 | $1673;
 $1674 = $1665;
 $1675 = $1674;
 HEAP32[$1675>>2] = $1676;
 $1677 = (($1674) + 4)|0;
 $1678 = $1677;
 HEAP32[$1678>>2] = $1671;
 $1679 = (($this) + 380|0);
 $1680 = (($parsed) + 116|0);
 $1681 = HEAP32[$1680>>2]|0;
 $1682 = ($1681|0)==(-1);
 if ($1682) {
  $1683 = (($parsed) + 112|0);
  $1684 = Math_fround(HEAPF32[$1683>>2]);
  $phitmp986 = (HEAPF32[tempDoublePtr>>2]=$1684,HEAP32[tempDoublePtr>>2]|0);
  $1686 = -1;$1687 = 0;$1690 = $phitmp986;
 } else {
  $1686 = $1681;$1687 = 0;$1690 = 0;
 }
 $1685 = $1686 | $1687;
 $1688 = $1679;
 $1689 = $1688;
 HEAP32[$1689>>2] = $1690;
 $1691 = (($1688) + 4)|0;
 $1692 = $1691;
 HEAP32[$1692>>2] = $1685;
 $1693 = (($this) + 404|0);
 $1694 = (($parsed) + 140|0);
 $1695 = HEAP32[$1694>>2]|0;
 $1696 = ($1695|0)==(-1);
 if ($1696) {
  $1697 = (($parsed) + 136|0);
  $1698 = Math_fround(HEAPF32[$1697>>2]);
  $phitmp988 = (HEAPF32[tempDoublePtr>>2]=$1698,HEAP32[tempDoublePtr>>2]|0);
  $1700 = -1;$1701 = 0;$1704 = $phitmp988;
 } else {
  $1700 = $1695;$1701 = 0;$1704 = 0;
 }
 $1699 = $1700 | $1701;
 $1702 = $1693;
 $1703 = $1702;
 HEAP32[$1703>>2] = $1704;
 $1705 = (($1702) + 4)|0;
 $1706 = $1705;
 HEAP32[$1706>>2] = $1699;
 $1707 = (($this) + 420|0);
 $1708 = (($parsed) + 84|0);
 $1709 = HEAP32[$1708>>2]|0;
 $1710 = ($1709|0)==(-1);
 if ($1710) {
  $1711 = (($parsed) + 80|0);
  $1712 = Math_fround(HEAPF32[$1711>>2]);
  $phitmp990 = (HEAPF32[tempDoublePtr>>2]=$1712,HEAP32[tempDoublePtr>>2]|0);
  $1714 = -1;$1715 = 0;$1718 = $phitmp990;
 } else {
  $1714 = $1709;$1715 = 0;$1718 = 0;
 }
 $1713 = $1714 | $1715;
 $1716 = $1707;
 $1717 = $1716;
 HEAP32[$1717>>2] = $1718;
 $1719 = (($1716) + 4)|0;
 $1720 = $1719;
 HEAP32[$1720>>2] = $1713;
 $1721 = (($this) + 388|0);
 $1722 = (($parsed) + 124|0);
 $1723 = HEAP32[$1722>>2]|0;
 $1724 = ($1723|0)==(-1);
 if ($1724) {
  $1725 = (($parsed) + 120|0);
  $1726 = Math_fround(HEAPF32[$1725>>2]);
  $phitmp992 = (HEAPF32[tempDoublePtr>>2]=$1726,HEAP32[tempDoublePtr>>2]|0);
  $1728 = -1;$1729 = 0;$1732 = $phitmp992;
 } else {
  $1728 = $1723;$1729 = 0;$1732 = 0;
 }
 $1727 = $1728 | $1729;
 $1730 = $1721;
 $1731 = $1730;
 HEAP32[$1731>>2] = $1732;
 $1733 = (($1730) + 4)|0;
 $1734 = $1733;
 HEAP32[$1734>>2] = $1727;
 $1735 = (($this) + 396|0);
 $1736 = (($parsed) + 132|0);
 $1737 = HEAP32[$1736>>2]|0;
 $1738 = ($1737|0)==(-1);
 if ($1738) {
  $1739 = (($parsed) + 128|0);
  $1740 = Math_fround(HEAPF32[$1739>>2]);
  $phitmp994 = (HEAPF32[tempDoublePtr>>2]=$1740,HEAP32[tempDoublePtr>>2]|0);
  $1742 = -1;$1743 = 0;$1746 = $phitmp994;
 } else {
  $1742 = $1737;$1743 = 0;$1746 = 0;
 }
 $1741 = $1742 | $1743;
 $1744 = $1735;
 $1745 = $1744;
 HEAP32[$1745>>2] = $1746;
 $1747 = (($1744) + 4)|0;
 $1748 = $1747;
 HEAP32[$1748>>2] = $1741;
 $1749 = (($this) + 436|0);
 $1750 = (($parsed) + 16|0);
 $1751 = HEAP32[$1750>>2]|0;
 $1752 = ($1751|0)==(-1);
 if ($1752) {
  $1753 = (($parsed) + 12|0);
  $1754 = Math_fround(HEAPF32[$1753>>2]);
  $phitmp996 = (HEAPF32[tempDoublePtr>>2]=$1754,HEAP32[tempDoublePtr>>2]|0);
  $1756 = -1;$1757 = 0;$1760 = $phitmp996;
 } else {
  $1756 = $1751;$1757 = 0;$1760 = 0;
 }
 $1755 = $1756 | $1757;
 $1758 = $1749;
 $1759 = $1758;
 HEAP32[$1759>>2] = $1760;
 $1761 = (($1758) + 4)|0;
 $1762 = $1761;
 HEAP32[$1762>>2] = $1755;
 $1763 = (($this) + 428|0);
 $1764 = (($parsed) + 24|0);
 $1765 = HEAP32[$1764>>2]|0;
 $1766 = ($1765|0)==(-1);
 if ($1766) {
  $1767 = (($parsed) + 20|0);
  $1768 = Math_fround(HEAPF32[$1767>>2]);
  $phitmp998 = (HEAPF32[tempDoublePtr>>2]=$1768,HEAP32[tempDoublePtr>>2]|0);
  $1770 = -1;$1771 = 0;$1774 = $phitmp998;
 } else {
  $1770 = $1765;$1771 = 0;$1774 = 0;
 }
 $1769 = $1770 | $1771;
 $1772 = $1763;
 $1773 = $1772;
 HEAP32[$1773>>2] = $1774;
 $1775 = (($1772) + 4)|0;
 $1776 = $1775;
 HEAP32[$1776>>2] = $1769;
 $1777 = (($this) + 212|0);
 $1778 = (($parsed) + 444|0);
 $1779 = HEAP32[$1778>>2]|0;
 $1780 = ($1779|0)==(-1);
 if ($1780) {
  $1781 = (($parsed) + 440|0);
  $1782 = Math_fround(HEAPF32[$1781>>2]);
  $phitmp1000 = (HEAPF32[tempDoublePtr>>2]=$1782,HEAP32[tempDoublePtr>>2]|0);
  $1784 = -1;$1785 = 0;$1788 = $phitmp1000;
 } else {
  $1784 = $1779;$1785 = 0;$1788 = 0;
 }
 $1783 = $1784 | $1785;
 $1786 = $1777;
 $1787 = $1786;
 HEAP32[$1787>>2] = $1788;
 $1789 = (($1786) + 4)|0;
 $1790 = $1789;
 HEAP32[$1790>>2] = $1783;
 $$idx$val = HEAP32[$1778>>2]|0;
 $1791 = ($$idx$val|0)!=(-1);
 $$not$i = $1791 ^ 1;
 $1792 = ($$idx$val>>>0)>(1073741823);
 $$$i$i = $1791 & $1792;
 $or$cond$i = $$$i$i | $$not$i;
 do {
  if (!($or$cond$i)) {
   HEAP32[$idx$i>>2] = $$idx$val;
   $1793 = HEAP32[$outNames>>2]|0;
   $1794 = (($outNames) + 4|0);
   $1795 = HEAP32[$1794>>2]|0;
   $1796 = $1795;
   $1797 = $1793;
   $1798 = (($1796) - ($1797))|0;
   $1799 = $1798 >> 2;
   $1800 = ($1799|0)==(0);
   if ($1800) {
    $1810 = $1793;
   } else {
    $1803 = $1793;$__len$03$i$i$i$i$i = $1799;
    while(1) {
     $1801 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
     $1802 = (($1803) + ($1801<<2)|0);
     $1804 = HEAP32[$1802>>2]|0;
     $1805 = ($1804|0)<($$idx$val|0);
     if ($1805) {
      $$sum$i$i$i$i$i = (($1801) + 1)|0;
      $1806 = (($1803) + ($$sum$i$i$i$i$i<<2)|0);
      $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
      $1807 = (($$neg2$i$i$i$i$i) - ($1801))|0;
      $2126 = $1806;$__len$0$be$i$i$i$i$i = $1807;
     } else {
      $2126 = $1803;$__len$0$be$i$i$i$i$i = $1801;
     }
     $1808 = ($__len$0$be$i$i$i$i$i|0)==(0);
     if ($1808) {
      $1810 = $2126;
      break;
     } else {
      $1803 = $2126;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
     }
    }
   }
   $1809 = ($1810|0)==($1795|0);
   if (!($1809)) {
    $1811 = HEAP32[$1810>>2]|0;
    $1812 = ($$idx$val|0)<($1811|0);
    if (!($1812)) {
     break;
    }
   }
   HEAP32[$69>>2] = $1810;
   ;HEAP32[$$byval_copy35+0>>2]=HEAP32[$69+0>>2]|0;
   __ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_($idx$i454,$outNames,$$byval_copy35,$idx$i);
   $1813 = (($outNames) + 12|0);
   $1814 = HEAP32[$1813>>2]|0;
   $1815 = (Math_fround(($1814>>>0)));
   $1816 = Math_fround($1815 + Math_fround(4.0));
   $1817 = (~~(($1816))>>>0);
   HEAP32[$1813>>2] = $1817;
  }
 } while(0);
 $1818 = (($this) + 468|0);
 $1819 = (($parsed) + 428|0);
 $1820 = HEAP32[$1819>>2]|0;
 $1821 = ($1820|0)==(-1);
 if ($1821) {
  $1822 = (($parsed) + 424|0);
  $1823 = Math_fround(HEAPF32[$1822>>2]);
  $phitmp1002 = (HEAPF32[tempDoublePtr>>2]=$1823,HEAP32[tempDoublePtr>>2]|0);
  $1825 = -1;$1826 = 0;$1829 = $phitmp1002;
 } else {
  $1825 = $1820;$1826 = 0;$1829 = 0;
 }
 $1824 = $1825 | $1826;
 $1827 = $1818;
 $1828 = $1827;
 HEAP32[$1828>>2] = $1829;
 $1830 = (($1827) + 4)|0;
 $1831 = $1830;
 HEAP32[$1831>>2] = $1824;
 $1832 = (($this) + 476|0);
 $1833 = (($parsed) + 436|0);
 $1834 = HEAP32[$1833>>2]|0;
 $1835 = ($1834|0)==(-1);
 if ($1835) {
  $1836 = (($parsed) + 432|0);
  $1837 = Math_fround(HEAPF32[$1836>>2]);
  $phitmp1004 = (HEAPF32[tempDoublePtr>>2]=$1837,HEAP32[tempDoublePtr>>2]|0);
  $1839 = -1;$1840 = 0;$1843 = $phitmp1004;
 } else {
  $1839 = $1834;$1840 = 0;$1843 = 0;
 }
 $1838 = $1839 | $1840;
 $1841 = $1832;
 $1842 = $1841;
 HEAP32[$1842>>2] = $1843;
 $1844 = (($1841) + 4)|0;
 $1845 = $1844;
 HEAP32[$1845>>2] = $1838;
 $1846 = (($this) + 484|0);
 $1847 = (($parsed) + 356|0);
 $1848 = HEAP32[$1847>>2]|0;
 $1849 = ($1848|0)==(-1);
 if ($1849) {
  $1850 = (($parsed) + 352|0);
  $1851 = Math_fround(HEAPF32[$1850>>2]);
  $phitmp$i39 = (HEAPF32[tempDoublePtr>>2]=$1851,HEAP32[tempDoublePtr>>2]|0);
  $1853 = -1;$1854 = 0;$1857 = $phitmp$i39;
 } else {
  $1853 = $1848;$1854 = 0;$1857 = 0;
 }
 $1852 = $1853 | $1854;
 $1855 = $1846;
 $1856 = $1855;
 HEAP32[$1856>>2] = $1857;
 $1858 = (($1855) + 4)|0;
 $1859 = $1858;
 HEAP32[$1859>>2] = $1852;
 $1860 = (($this) + 492|0);
 $1861 = (($parsed) + 332|0);
 $1862 = HEAP32[$1861>>2]|0;
 $1863 = ($1862|0)==(-1);
 if ($1863) {
  $1864 = (($parsed) + 328|0);
  $1865 = Math_fround(HEAPF32[$1864>>2]);
  $phitmp14$i42 = (HEAPF32[tempDoublePtr>>2]=$1865,HEAP32[tempDoublePtr>>2]|0);
  $1867 = -1;$1868 = 0;$1871 = $phitmp14$i42;
 } else {
  $1867 = $1862;$1868 = 0;$1871 = 0;
 }
 $1866 = $1867 | $1868;
 $1869 = $1860;
 $1870 = $1869;
 HEAP32[$1870>>2] = $1871;
 $1872 = (($1869) + 4)|0;
 $1873 = $1872;
 HEAP32[$1873>>2] = $1866;
 $1874 = (($this) + 500|0);
 $1875 = (($parsed) + 340|0);
 $1876 = HEAP32[$1875>>2]|0;
 $1877 = ($1876|0)==(-1);
 if ($1877) {
  $1878 = (($parsed) + 336|0);
  $1879 = Math_fround(HEAPF32[$1878>>2]);
  $phitmp16$i45 = (HEAPF32[tempDoublePtr>>2]=$1879,HEAP32[tempDoublePtr>>2]|0);
  $1881 = -1;$1882 = 0;$1885 = $phitmp16$i45;
 } else {
  $1881 = $1876;$1882 = 0;$1885 = 0;
 }
 $1880 = $1881 | $1882;
 $1883 = $1874;
 $1884 = $1883;
 HEAP32[$1884>>2] = $1885;
 $1886 = (($1883) + 4)|0;
 $1887 = $1886;
 HEAP32[$1887>>2] = $1880;
 $1888 = (($this) + 508|0);
 $1889 = (($parsed) + 348|0);
 $1890 = HEAP32[$1889>>2]|0;
 $1891 = ($1890|0)==(-1);
 if ($1891) {
  $1892 = (($parsed) + 344|0);
  $1893 = Math_fround(HEAPF32[$1892>>2]);
  $phitmp18$i48 = (HEAPF32[tempDoublePtr>>2]=$1893,HEAP32[tempDoublePtr>>2]|0);
  $1895 = -1;$1896 = 0;$1899 = $phitmp18$i48;
 } else {
  $1895 = $1890;$1896 = 0;$1899 = 0;
 }
 $1894 = $1895 | $1896;
 $1897 = $1888;
 $1898 = $1897;
 HEAP32[$1898>>2] = $1899;
 $1900 = (($1897) + 4)|0;
 $1901 = $1900;
 HEAP32[$1901>>2] = $1894;
 $1902 = (($this) + 516|0);
 $1903 = (($parsed) + 388|0);
 $1904 = HEAP32[$1903>>2]|0;
 $1905 = ($1904|0)==(-1);
 if ($1905) {
  $1906 = (($parsed) + 384|0);
  $1907 = Math_fround(HEAPF32[$1906>>2]);
  $phitmp$i27 = (HEAPF32[tempDoublePtr>>2]=$1907,HEAP32[tempDoublePtr>>2]|0);
  $1909 = -1;$1910 = 0;$1913 = $phitmp$i27;
 } else {
  $1909 = $1904;$1910 = 0;$1913 = 0;
 }
 $1908 = $1909 | $1910;
 $1911 = $1902;
 $1912 = $1911;
 HEAP32[$1912>>2] = $1913;
 $1914 = (($1911) + 4)|0;
 $1915 = $1914;
 HEAP32[$1915>>2] = $1908;
 $1916 = (($this) + 524|0);
 $1917 = (($parsed) + 364|0);
 $1918 = HEAP32[$1917>>2]|0;
 $1919 = ($1918|0)==(-1);
 if ($1919) {
  $1920 = (($parsed) + 360|0);
  $1921 = Math_fround(HEAPF32[$1920>>2]);
  $phitmp14$i30 = (HEAPF32[tempDoublePtr>>2]=$1921,HEAP32[tempDoublePtr>>2]|0);
  $1923 = -1;$1924 = 0;$1927 = $phitmp14$i30;
 } else {
  $1923 = $1918;$1924 = 0;$1927 = 0;
 }
 $1922 = $1923 | $1924;
 $1925 = $1916;
 $1926 = $1925;
 HEAP32[$1926>>2] = $1927;
 $1928 = (($1925) + 4)|0;
 $1929 = $1928;
 HEAP32[$1929>>2] = $1922;
 $1930 = (($this) + 532|0);
 $1931 = (($parsed) + 372|0);
 $1932 = HEAP32[$1931>>2]|0;
 $1933 = ($1932|0)==(-1);
 if ($1933) {
  $1934 = (($parsed) + 368|0);
  $1935 = Math_fround(HEAPF32[$1934>>2]);
  $phitmp16$i33 = (HEAPF32[tempDoublePtr>>2]=$1935,HEAP32[tempDoublePtr>>2]|0);
  $1937 = -1;$1938 = 0;$1941 = $phitmp16$i33;
 } else {
  $1937 = $1932;$1938 = 0;$1941 = 0;
 }
 $1936 = $1937 | $1938;
 $1939 = $1930;
 $1940 = $1939;
 HEAP32[$1940>>2] = $1941;
 $1942 = (($1939) + 4)|0;
 $1943 = $1942;
 HEAP32[$1943>>2] = $1936;
 $1944 = (($this) + 540|0);
 $1945 = (($parsed) + 380|0);
 $1946 = HEAP32[$1945>>2]|0;
 $1947 = ($1946|0)==(-1);
 if ($1947) {
  $1948 = (($parsed) + 376|0);
  $1949 = Math_fround(HEAPF32[$1948>>2]);
  $phitmp18$i36 = (HEAPF32[tempDoublePtr>>2]=$1949,HEAP32[tempDoublePtr>>2]|0);
  $1951 = -1;$1952 = 0;$1955 = $phitmp18$i36;
 } else {
  $1951 = $1946;$1952 = 0;$1955 = 0;
 }
 $1950 = $1951 | $1952;
 $1953 = $1944;
 $1954 = $1953;
 HEAP32[$1954>>2] = $1955;
 $1956 = (($1953) + 4)|0;
 $1957 = $1956;
 HEAP32[$1957>>2] = $1950;
 $1958 = (($this) + 548|0);
 $1959 = (($parsed) + 420|0);
 $1960 = HEAP32[$1959>>2]|0;
 $1961 = ($1960|0)==(-1);
 if ($1961) {
  $1962 = (($parsed) + 416|0);
  $1963 = Math_fround(HEAPF32[$1962>>2]);
  $phitmp$i = (HEAPF32[tempDoublePtr>>2]=$1963,HEAP32[tempDoublePtr>>2]|0);
  $1965 = -1;$1966 = 0;$1969 = $phitmp$i;
 } else {
  $1965 = $1960;$1966 = 0;$1969 = 0;
 }
 $1964 = $1965 | $1966;
 $1967 = $1958;
 $1968 = $1967;
 HEAP32[$1968>>2] = $1969;
 $1970 = (($1967) + 4)|0;
 $1971 = $1970;
 HEAP32[$1971>>2] = $1964;
 $1972 = (($this) + 556|0);
 $1973 = (($parsed) + 396|0);
 $1974 = HEAP32[$1973>>2]|0;
 $1975 = ($1974|0)==(-1);
 if ($1975) {
  $1976 = (($parsed) + 392|0);
  $1977 = Math_fround(HEAPF32[$1976>>2]);
  $phitmp14$i = (HEAPF32[tempDoublePtr>>2]=$1977,HEAP32[tempDoublePtr>>2]|0);
  $1979 = -1;$1980 = 0;$1983 = $phitmp14$i;
 } else {
  $1979 = $1974;$1980 = 0;$1983 = 0;
 }
 $1978 = $1979 | $1980;
 $1981 = $1972;
 $1982 = $1981;
 HEAP32[$1982>>2] = $1983;
 $1984 = (($1981) + 4)|0;
 $1985 = $1984;
 HEAP32[$1985>>2] = $1978;
 $1986 = (($this) + 564|0);
 $1987 = (($parsed) + 404|0);
 $1988 = HEAP32[$1987>>2]|0;
 $1989 = ($1988|0)==(-1);
 if ($1989) {
  $1990 = (($parsed) + 400|0);
  $1991 = Math_fround(HEAPF32[$1990>>2]);
  $phitmp16$i = (HEAPF32[tempDoublePtr>>2]=$1991,HEAP32[tempDoublePtr>>2]|0);
  $1993 = -1;$1994 = 0;$1997 = $phitmp16$i;
 } else {
  $1993 = $1988;$1994 = 0;$1997 = 0;
 }
 $1992 = $1993 | $1994;
 $1995 = $1986;
 $1996 = $1995;
 HEAP32[$1996>>2] = $1997;
 $1998 = (($1995) + 4)|0;
 $1999 = $1998;
 HEAP32[$1999>>2] = $1992;
 $2000 = (($this) + 572|0);
 $2001 = (($parsed) + 412|0);
 $2002 = HEAP32[$2001>>2]|0;
 $2003 = ($2002|0)==(-1);
 if (!($2003)) {
  $2007 = $2002;$2008 = 0;$2011 = 0;
  $2006 = $2007 | $2008;
  $2009 = $2000;
  $2010 = $2009;
  HEAP32[$2010>>2] = $2011;
  $2012 = (($2009) + 4)|0;
  $2013 = $2012;
  HEAP32[$2013>>2] = $2006;
  $2014 = (($parsed) + 512|0);
  $2015 = HEAP32[$2014>>2]|0;
  $2016 = (($this) + 584|0);
  HEAP32[$2016>>2] = $2015;
  $2017 = HEAP32[652824>>2]|0;
  $2018 = (($2017) + 20|0);
  __ZN9ShaderLab11ShaderState17BuildDeviceStatesEjPKNS_13PropertySheetERKNS_17ShaderPassContextE($this,0,$2018,$2017);
  STACKTOP = sp;return;
 }
 $2004 = (($parsed) + 408|0);
 $2005 = Math_fround(HEAPF32[$2004>>2]);
 $phitmp18$i = (HEAPF32[tempDoublePtr>>2]=$2005,HEAP32[tempDoublePtr>>2]|0);
 $2007 = -1;$2008 = 0;$2011 = $phitmp18$i;
 $2006 = $2007 | $2008;
 $2009 = $2000;
 $2010 = $2009;
 HEAP32[$2010>>2] = $2011;
 $2012 = (($2009) + 4)|0;
 $2013 = $2012;
 HEAP32[$2013>>2] = $2006;
 $2014 = (($parsed) + 512|0);
 $2015 = HEAP32[$2014>>2]|0;
 $2016 = (($this) + 584|0);
 HEAP32[$2016>>2] = $2015;
 $2017 = HEAP32[652824>>2]|0;
 $2018 = (($2017) + 20|0);
 __ZN9ShaderLab11ShaderState17BuildDeviceStatesEjPKNS_13PropertySheetERKNS_17ShaderPassContextE($this,0,$2018,$2017);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab7Program23CreateFromParsedProgramERKNS_13ParserProgramE10ShaderTypeiP16PropertyNamesSetPK6Shader($parsed,$programType,$gpuProgramID,$outNames,$fromShader) {
 $parsed = $parsed|0;
 $programType = $programType|0;
 $gpuProgramID = $gpuProgramID|0;
 $outNames = $outNames|0;
 $fromShader = $fromShader|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$6 = 0, $$index = 0, $$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $subNdx$04 = 0, $subNdx$04$us = 0, $vararg_buffer12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer12 = sp;
 $0 = sp + 4|0;
 $1 = (($parsed) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$parsed>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (__Z12GetGfxDevicev()|0);
 $9 = (($8) + 5928|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__Znwj(144)|0);
 __THREW__ = 0;
 invoke_viii(1949,($11|0),($7|0),($programType|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $65 = ___cxa_find_matching_catch()|0;
  $66 = tempRet0;
  __ZdlPv($11);
  $$0 = $65;$$01 = $66;
  ___resumeException($$0|0);
  // unreachable;
 }
 $14 = (($11) + 116|0);
 HEAP32[$14>>2] = $gpuProgramID;
 $15 = ($7|0)==(0);
 if ($15) {
  STACKTOP = sp;return ($11|0);
 }
 $16 = ($10|0)==(4);
 $17 = ($fromShader|0)==(0|0);
 $18 = (($0) + 1|0);
 $19 = (($0) + 8|0);
 $20 = (($fromShader) + 24|0);
 $21 = (($fromShader) + 4|0);
 do {
  if ($16) {
   $subNdx$04 = 0;
   while(1) {
    $67 = HEAP32[$parsed>>2]|0;
    $68 = (($67) + ($subNdx$04<<2)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = HEAP8[$69>>0]|0;
    $71 = $70 & 1;
    $72 = ($71<<24>>24)==(0);
    if ($72) {
     $75 = (($69) + 1|0);
     $76 = $75;
    } else {
     $73 = (($69) + 8|0);
     $74 = HEAP32[$73>>2]|0;
     $76 = $74;
    }
    $77 = (__Z21CheckGpuProgramUsablePKc($76)|0);
    if ((($77|0) == 2)) {
     if ($17) {
      HEAP32[$vararg_buffer12>>2] = 679104;
      __Z6FormatPKcz($0,678984,$vararg_buffer12);
      $91 = 0;
     } else {
      $78 = HEAP32[$20>>2]|0;
      $79 = HEAP8[$78>>0]|0;
      $80 = ($79<<24>>24)==(0);
      if ($80) {
       $81 = HEAP32[$fromShader>>2]|0;
       $82 = (($81) + 32|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = (FUNCTION_TABLE_ii[$83 & 4095]($fromShader)|0);
       $85 = $84;
      } else {
       $85 = $78;
      }
      HEAP32[$vararg_buffer12>>2] = $85;
      __Z6FormatPKcz($0,678984,$vararg_buffer12);
      $86 = HEAP32[$21>>2]|0;
      $91 = $86;
     }
     $87 = HEAP8[$0>>0]|0;
     $88 = $87 & 1;
     $89 = ($88<<24>>24)==(0);
     $90 = HEAP32[$19>>2]|0;
     $$6 = $89 ? $18 : $90;
     __THREW__ = 0;
     invoke_viiiiiiii(21,($$6|0),0,(678976|0),519,512,($91|0),0,(0|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      label = 36;
      break;
     }
     $94 = HEAP8[$0>>0]|0;
     $95 = $94 & 1;
     $96 = ($95<<24>>24)==(0);
     if (!($96)) {
      $97 = HEAP32[$19>>2]|0;
      __ZdlPv($97);
     }
    } else if ((($77|0) == 0)) {
     $104 = (__ZN9ShaderLab10SubProgram26CreateFromParsedSubProgramERKNS_16ParserSubProgramEP16PropertyNamesSet($69,$outNames)|0);
     $105 = ($subNdx$04|0)==(0);
     if ($105) {
      __ZN9ShaderLab10SubProgram14EnsureCompiledEv($104);
     }
     __ZN9ShaderLab7Program13AddSubProgramEPNS_10SubProgramE($11,$104);
    }
    $106 = (($subNdx$04) + 1)|0;
    $107 = ($106>>>0)<($7>>>0);
    if ($107) {
     $subNdx$04 = $106;
    } else {
     label = 43;
     break;
    }
   }
   if ((label|0) == 36) {
    $98 = ___cxa_find_matching_catch()|0;
    $99 = tempRet0;
    $$index = $98;$$index2 = $99;
    break;
   }
   else if ((label|0) == 43) {
    STACKTOP = sp;return ($11|0);
   }
  } else {
   $subNdx$04$us = 0;
   L9: while(1) {
    $22 = HEAP32[$parsed>>2]|0;
    $23 = (($22) + ($subNdx$04$us<<2)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = HEAP8[((640792 + 249|0))>>0]|0;
    $26 = ($25<<24>>24)==(0);
    if ($26) {
     $27 = (($24) + 132|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = $28 & 2048;
     $30 = ($29|0)==(0);
     if ($30) {
      label = 6;
     }
    } else {
     label = 6;
    }
    do {
     if ((label|0) == 6) {
      label = 0;
      $31 = HEAP8[$24>>0]|0;
      $32 = $31 & 1;
      $33 = ($32<<24>>24)==(0);
      if ($33) {
       $36 = (($24) + 1|0);
       $37 = $36;
      } else {
       $34 = (($24) + 8|0);
       $35 = HEAP32[$34>>2]|0;
       $37 = $35;
      }
      $38 = (__Z21CheckGpuProgramUsablePKc($37)|0);
      if ((($38|0) == 0)) {
       $59 = (__ZN9ShaderLab10SubProgram26CreateFromParsedSubProgramERKNS_16ParserSubProgramEP16PropertyNamesSet($24,$outNames)|0);
       $60 = ($subNdx$04$us|0)==(0);
       if ($60) {
        __ZN9ShaderLab10SubProgram14EnsureCompiledEv($59);
       }
       __ZN9ShaderLab7Program13AddSubProgramEPNS_10SubProgramE($11,$59);
       break;
      } else if (!((($38|0) == 2))) {
       break;
      }
      if ($17) {
       HEAP32[$vararg_buffer12>>2] = 679104;
       __Z6FormatPKcz($0,678984,$vararg_buffer12);
       $52 = 0;
      } else {
       $39 = HEAP32[$20>>2]|0;
       $40 = HEAP8[$39>>0]|0;
       $41 = ($40<<24>>24)==(0);
       if ($41) {
        $42 = HEAP32[$fromShader>>2]|0;
        $43 = (($42) + 32|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = (FUNCTION_TABLE_ii[$44 & 4095]($fromShader)|0);
        $46 = $45;
       } else {
        $46 = $39;
       }
       HEAP32[$vararg_buffer12>>2] = $46;
       __Z6FormatPKcz($0,678984,$vararg_buffer12);
       $47 = HEAP32[$21>>2]|0;
       $52 = $47;
      }
      $48 = HEAP8[$0>>0]|0;
      $49 = $48 & 1;
      $50 = ($49<<24>>24)==(0);
      $51 = HEAP32[$19>>2]|0;
      $$ = $50 ? $18 : $51;
      __THREW__ = 0;
      invoke_viiiiiiii(21,($$|0),0,(678976|0),519,512,($52|0),0,(0|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 22;
       break L9;
      }
      $55 = HEAP8[$0>>0]|0;
      $56 = $55 & 1;
      $57 = ($56<<24>>24)==(0);
      if (!($57)) {
       $58 = HEAP32[$19>>2]|0;
       __ZdlPv($58);
      }
     }
    } while(0);
    $61 = (($subNdx$04$us) + 1)|0;
    $62 = ($61>>>0)<($7>>>0);
    if ($62) {
     $subNdx$04$us = $61;
    } else {
     label = 43;
     break;
    }
   }
   if ((label|0) == 22) {
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    $$index = $63;$$index2 = $64;
    break;
   }
   else if ((label|0) == 43) {
    STACKTOP = sp;return ($11|0);
   }
  }
 } while(0);
 $100 = HEAP8[$0>>0]|0;
 $101 = $100 & 1;
 $102 = ($101<<24>>24)==(0);
 if ($102) {
  $$0 = $$index;$$01 = $$index2;
  ___resumeException($$0|0);
  // unreachable;
 }
 $103 = HEAP32[$19>>2]|0;
 __ZdlPv($103);
 $$0 = $$index;$$01 = $$index2;
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __ZN9ShaderLab10SubProgram26CreateFromParsedSubProgramERKNS_16ParserSubProgramEP16PropertyNamesSet($parsed,$outNames) {
 $parsed = $parsed|0;
 $outNames = $outNames|0;
 var $$byval_copy = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__lhs_sz$05$i = 0, $__lp$03$i = 0, $__rp$04$i = 0, $exitcond$i = 0, $i$01$i = 0, $i$012 = 0, $i1$05 = 0, $i2$04 = 0, $j$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Znwj(88)|0);
 __THREW__ = 0;
 invoke_viii(1950,($1|0),($parsed|0),($outNames|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZdlPv($1);
  ___resumeException($10|0);
  // unreachable;
 }
 $4 = (($1) + 44|0);
 $5 = (($parsed) + 132|0);
 ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$5+12>>2]|0;
 $6 = (__Z12GetGfxDevicev()|0);
 $7 = (($6) + 5928|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(15);
 if ($9) {
  STACKTOP = sp;return ($1|0);
 }
 $12 = (($1) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $i$01$i = 0;
  while(1) {
   $15 = ((($parsed) + ($i$01$i<<2)|0) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16&255;
   $18 = ((($12) + ($i$01$i)|0) + 8|0);
   HEAP8[$18>>0] = $17;
   $19 = (($i$01$i) + 1)|0;
   $exitcond$i = ($19|0)==(28);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $19;
   }
  }
  $20 = (($parsed) + 128|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($1) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = (($parsed) + 124|0);
  $24 = HEAP32[$23>>2]|0;
  HEAP32[$12>>2] = $24;
  $25 = ($24|0)==(0);
  if ($25) {
   __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($12,0,0);
  }
 }
 $26 = HEAP32[$1>>2]|0;
 $27 = (($parsed) + 160|0);
 $28 = (($parsed) + 148|0);
 __ZL23AddGpuProgramParametersR20GpuProgramParametersRKNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS1_9allocatorIS5_EEEERKNS2_INS4_15VectorParameterENS6_ISB_EEEEiP16PropertyNamesSet($26,$27,$28,-1,$outNames);
 $29 = (($parsed) + 196|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($parsed) + 200|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($30|0)==($32|0);
 if (!($33)) {
  $34 = $32;
  $35 = $30;
  $36 = (($34) - ($35))|0;
  $37 = (($36|0) / 40)&-1;
  $38 = HEAP32[$1>>2]|0;
  $39 = (($38) + 60|0);
  $40 = (($38) + 64|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = HEAP32[$39>>2]|0;
  $43 = $41;
  $44 = $42;
  $45 = (($43) - ($44))|0;
  $46 = (($45|0) / 28)&-1;
  $47 = ($46>>>0)<($37>>>0);
  L15: do {
   if ($47) {
    $48 = (($37) - ($46))|0;
    __ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE8__appendEj($39,$48);
   } else {
    $49 = ($46>>>0)>($37>>>0);
    if ($49) {
     $50 = (($42) + (($37*28)|0)|0);
     $51 = ($41|0)==($50|0);
     if (!($51)) {
      $53 = $41;
      while(1) {
       $52 = (($53) + -28|0);
       HEAP32[$40>>2] = $52;
       $54 = (($53) + -12|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = ($55|0)>(-1);
       if ($56) {
        $59 = (($53) + -24|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = (($53) + -20|0);
        $62 = HEAP32[$61>>2]|0;
        HEAP32[$0>>2] = $62;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($60|0),($$byval_copy|0));
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         break;
        }
        HEAP32[$59>>2] = 0;
        $$pre$i$i$i$i = HEAP32[$40>>2]|0;
        $58 = $$pre$i$i$i$i;
       } else {
        $58 = $52;
       }
       $57 = ($58|0)==($50|0);
       if ($57) {
        break L15;
       } else {
        $53 = $58;
       }
      }
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      ___cxa_call_unexpected(($65|0));
      // unreachable;
     }
    }
   }
  } while(0);
  $67 = (__Z12GetGfxDevicev()|0);
  $68 = (($parsed) + 212|0);
  $69 = (($parsed) + 208|0);
  $i$012 = 0;
  while(1) {
   $70 = HEAP32[$1>>2]|0;
   $71 = (($70) + 60|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = HEAP32[$29>>2]|0;
   $74 = (($73) + (($i$012*40)|0)|0);
   HEAP32[$$byval_copy>>2] = -1;
   $75 = HEAP8[$74>>0]|0;
   $76 = $75 & 1;
   $77 = ($76<<24>>24)==(0);
   if ($77) {
    $80 = (($74) + 1|0);
    $81 = $80;
   } else {
    $78 = ((($73) + (($i$012*40)|0)|0) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    $81 = $79;
   }
   __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy,$81);
   $82 = HEAP32[$$byval_copy>>2]|0;
   $83 = (($72) + (($i$012*28)|0)|0);
   HEAP32[$83>>2] = $82;
   $84 = HEAP32[$29>>2]|0;
   $85 = ((($84) + (($i$012*40)|0)|0) + 36|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($86) + 15)|0;
   $88 = $87 & -16;
   $89 = ((($72) + (($i$012*28)|0)|0) + 20|0);
   HEAP32[$89>>2] = $88;
   $90 = ((($72) + (($i$012*28)|0)|0) + 24|0);
   HEAP32[$90>>2] = -1;
   $91 = HEAP32[$68>>2]|0;
   $92 = HEAP32[$69>>2]|0;
   $93 = ($91|0)==($92|0);
   if (!($93)) {
    $j$07 = 0;
    while(1) {
     $94 = (($92) + ($j$07<<4)|0);
     $95 = (($84) + (($i$012*40)|0)|0);
     $96 = HEAP8[$94>>0]|0;
     $97 = $96 & 1;
     $98 = ($97<<24>>24)==(0);
     if ($98) {
      $101 = $96&255;
      $102 = $101 >>> 1;
      $111 = $102;
     } else {
      $99 = ((($92) + ($j$07<<4)|0) + 4|0);
      $100 = HEAP32[$99>>2]|0;
      $111 = $100;
     }
     $103 = HEAP8[$95>>0]|0;
     $104 = $103 & 1;
     $105 = ($104<<24>>24)==(0);
     if ($105) {
      $108 = $103&255;
      $109 = $108 >>> 1;
      $112 = $109;
     } else {
      $106 = ((($84) + (($i$012*40)|0)|0) + 4|0);
      $107 = HEAP32[$106>>2]|0;
      $112 = $107;
     }
     $110 = ($111|0)==($112|0);
     L45: do {
      if ($110) {
       if ($98) {
        $115 = (($94) + 1|0);
        $127 = $115;
       } else {
        $113 = ((($92) + ($j$07<<4)|0) + 8|0);
        $114 = HEAP32[$113>>2]|0;
        $127 = $114;
       }
       if ($105) {
        $118 = (($95) + 1|0);
        $128 = $118;
       } else {
        $116 = ((($84) + (($i$012*40)|0)|0) + 8|0);
        $117 = HEAP32[$116>>2]|0;
        $128 = $117;
       }
       if ($98) {
        $119 = ($111|0)==(0);
        if (!($119)) {
         $__lhs_sz$05$i = $111;$__lp$03$i = $127;$__rp$04$i = $128;
         while(1) {
          $120 = HEAP8[$__lp$03$i>>0]|0;
          $121 = HEAP8[$__rp$04$i>>0]|0;
          $122 = ($120<<24>>24)==($121<<24>>24);
          if (!($122)) {
           break L45;
          }
          $123 = (($__lhs_sz$05$i) + -1)|0;
          $124 = (($__lp$03$i) + 1|0);
          $125 = (($__rp$04$i) + 1|0);
          $126 = ($123|0)==(0);
          if ($126) {
           break;
          } else {
           $__lhs_sz$05$i = $123;$__lp$03$i = $124;$__rp$04$i = $125;
          }
         }
        }
       } else {
        $129 = (_memcmp($127,$128,$111)|0);
        $130 = ($129|0)==(0);
        if (!($130)) {
         break;
        }
       }
       $131 = ((($92) + ($j$07<<4)|0) + 12|0);
       $132 = HEAP32[$131>>2]|0;
       HEAP32[$90>>2] = $132;
      }
     } while(0);
     $133 = (($j$07) + 1)|0;
     $134 = $91;
     $135 = $92;
     $136 = (($134) - ($135))|0;
     $137 = $136 >> 4;
     $138 = ($133>>>0)<($137>>>0);
     if ($138) {
      $j$07 = $133;
     } else {
      break;
     }
    }
   }
   $139 = HEAP32[$67>>2]|0;
   $140 = (($139) + 240|0);
   $141 = HEAP32[$140>>2]|0;
   FUNCTION_TABLE_viii[$141 & 4095]($67,$82,$88);
   $142 = HEAP32[$1>>2]|0;
   $143 = HEAP32[$29>>2]|0;
   $144 = ((($143) + (($i$012*40)|0)|0) + 12|0);
   $145 = ((($143) + (($i$012*40)|0)|0) + 24|0);
   __ZL23AddGpuProgramParametersR20GpuProgramParametersRKNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS1_9allocatorIS5_EEEERKNS2_INS4_15VectorParameterENS6_ISB_EEEEiP16PropertyNamesSet($142,$144,$145,$i$012,$outNames);
   $146 = (($i$012) + 1)|0;
   $147 = ($146>>>0)<($37>>>0);
   if ($147) {
    $i$012 = $146;
   } else {
    break;
   }
  }
 }
 $148 = HEAP32[$1>>2]|0;
 __ZN20GpuProgramParameters9MakeReadyEv($148);
 $149 = (($parsed) + 176|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = (($parsed) + 172|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = ($150|0)==($152|0);
 if (!($153)) {
  $155 = $152;$i1$05 = 0;
  while(1) {
   $154 = (($155) + (($i1$05*24)|0)|0);
   $156 = HEAP32[$1>>2]|0;
   $157 = ((($155) + (($i1$05*24)|0)|0) + 12|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = ((($155) + (($i1$05*24)|0)|0) + 16|0);
   $160 = HEAP32[$159>>2]|0;
   $161 = HEAP8[$154>>0]|0;
   $162 = $161 & 1;
   $163 = ($162<<24>>24)==(0);
   if ($163) {
    $166 = (($154) + 1|0);
    $169 = $166;
   } else {
    $164 = ((($155) + (($i1$05*24)|0)|0) + 8|0);
    $165 = HEAP32[$164>>2]|0;
    $169 = $165;
   }
   $167 = ((($155) + (($i1$05*24)|0)|0) + 20|0);
   $168 = HEAP32[$167>>2]|0;
   __ZN20GpuProgramParameters15AddTextureParamEiiPKc16TextureDimensionP16PropertyNamesSet($156,$158,$160,$169,$168,$outNames);
   $170 = (($i1$05) + 1)|0;
   $171 = HEAP32[$149>>2]|0;
   $172 = HEAP32[$151>>2]|0;
   $173 = $171;
   $174 = $172;
   $175 = (($173) - ($174))|0;
   $176 = (($175|0) / 24)&-1;
   $177 = ($170>>>0)<($176>>>0);
   if ($177) {
    $155 = $172;$i1$05 = $170;
   } else {
    break;
   }
  }
 }
 $178 = (($1) + 40|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ($179|0)==(0|0);
 if (!($180)) {
  $181 = HEAP32[$1>>2]|0;
  $182 = (($181) + 36|0);
  $183 = HEAP32[$182>>2]|0;
  $184 = (($181) + 32|0);
  $185 = HEAP32[$184>>2]|0;
  $186 = $183;
  $187 = $185;
  $188 = (($186) - ($187))|0;
  $189 = $188 >> 4;
  $190 = HEAP32[((640792 + 96|0))>>2]|0;
  $191 = ($189|0)>($190|0);
  if ($191) {
   $192 = (($179) + 8|0);
   HEAP8[$192>>0] = 1;
  }
 }
 $193 = (($parsed) + 188|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = (($parsed) + 184|0);
 $196 = HEAP32[$195>>2]|0;
 $197 = ($194|0)==($196|0);
 if ($197) {
  STACKTOP = sp;return ($1|0);
 } else {
  $200 = $196;$i2$04 = 0;
 }
 while(1) {
  $198 = HEAP32[$1>>2]|0;
  $199 = ((($200) + ($i2$04<<4)|0) + 12|0);
  $201 = HEAP32[$199>>2]|0;
  $202 = (($200) + ($i2$04<<4)|0);
  $203 = HEAP8[$202>>0]|0;
  $204 = $203 & 1;
  $205 = ($204<<24>>24)==(0);
  if ($205) {
   $208 = (($202) + 1|0);
   $209 = $208;
  } else {
   $206 = ((($200) + ($i2$04<<4)|0) + 8|0);
   $207 = HEAP32[$206>>2]|0;
   $209 = $207;
  }
  __ZN20GpuProgramParameters14AddBufferParamEiPKcP16PropertyNamesSet($198,$201,$209,$outNames);
  $210 = (($i2$04) + 1)|0;
  $211 = HEAP32[$193>>2]|0;
  $212 = HEAP32[$195>>2]|0;
  $213 = $211;
  $214 = $212;
  $215 = (($213) - ($214))|0;
  $216 = $215 >> 4;
  $217 = ($210>>>0)<($216>>>0);
  if ($217) {
   $200 = $212;$i2$04 = $210;
  } else {
   break;
  }
 }
 STACKTOP = sp;return ($1|0);
}
function __ZL23AddGpuProgramParametersR20GpuProgramParametersRKNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS1_9allocatorIS5_EEEERKNS2_INS4_15VectorParameterENS6_ISB_EEEEiP16PropertyNamesSet($params,$matrices,$vectors,$cbIndex,$outNames) {
 $params = $params|0;
 $matrices = $matrices|0;
 $vectors = $vectors|0;
 $cbIndex = $cbIndex|0;
 $outNames = $outNames|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i1$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($vectors) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$vectors>>2]|0;
 $3 = ($1|0)==($2|0);
 if (!($3)) {
  $9 = $2;$i$03 = 0;
  while(1) {
   $8 = ((($9) + (($i$03*24)|0)|0) + 16|0);
   $10 = HEAP32[$8>>2]|0;
   $11 = ((($9) + (($i$03*24)|0)|0) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($9) + (($i$03*24)|0)|0) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($9) + (($i$03*24)|0)|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    $21 = (($15) + 1|0);
    $22 = $21;
   } else {
    $19 = ((($9) + (($i$03*24)|0)|0) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $22 = $20;
   }
   __ZN20GpuProgramParameters14AddVectorParamEi15ShaderParamTypeiPKciP16PropertyNamesSet($params,$10,$12,$14,$22,$cbIndex,$outNames);
   $23 = (($i$03) + 1)|0;
   $24 = HEAP32[$0>>2]|0;
   $25 = HEAP32[$vectors>>2]|0;
   $26 = $24;
   $27 = $25;
   $28 = (($26) - ($27))|0;
   $29 = (($28|0) / 24)&-1;
   $30 = ($23>>>0)<($29>>>0);
   if ($30) {
    $9 = $25;$i$03 = $23;
   } else {
    break;
   }
  }
 }
 $4 = (($matrices) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$matrices>>2]|0;
 $7 = ($5|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $32 = $6;$i1$02 = 0;
 }
 while(1) {
  $31 = (($32) + (($i1$02*24)|0)|0);
  $33 = ((($32) + (($i1$02*24)|0)|0) + 16|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ((($32) + (($i1$02*24)|0)|0) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP8[$31>>0]|0;
  $38 = $37 & 1;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $42 = (($31) + 1|0);
   $45 = $42;
  } else {
   $40 = ((($32) + (($i1$02*24)|0)|0) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $45 = $41;
  }
  $43 = ((($32) + (($i1$02*24)|0)|0) + 20|0);
  $44 = HEAP32[$43>>2]|0;
  __ZN20GpuProgramParameters14AddMatrixParamEi15ShaderParamTypePKciiiP16PropertyNamesSet($params,$34,$36,$45,$44,4,$cbIndex,$outNames);
  $46 = (($i1$02) + 1)|0;
  $47 = HEAP32[$4>>2]|0;
  $48 = HEAP32[$matrices>>2]|0;
  $49 = $47;
  $50 = $48;
  $51 = (($49) - ($50))|0;
  $52 = (($51|0) / 24)&-1;
  $53 = ($46>>>0)<($52>>>0);
  if ($53) {
   $32 = $48;$i1$02 = $46;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z11ParseShaderPKcjRNSt3__16vectorI4PPtrI6ShaderENS1_9allocatorIS5_EEEEbPPN9ShaderLab12ParserShaderER12ShaderErrors17GfxDeviceRendererPS4_($shader,$shaderLength,$dependenciesTable,$useDependenciesTable,$outParsedForm,$outErrors,$renderer,$fromShader) {
 $shader = $shader|0;
 $shaderLength = $shaderLength|0;
 $dependenciesTable = $dependenciesTable|0;
 $useDependenciesTable = $useDependenciesTable|0;
 $outParsedForm = $outParsedForm|0;
 $outErrors = $outErrors|0;
 $renderer = $renderer|0;
 $fromShader = $fromShader|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZN12ShaderErrors21ClearNonProgramErrorsEv($outErrors);
 $2 = (__Z14PreParseShaderPKcj17GfxDeviceRendererR12ShaderErrors($shader,$shaderLength,$renderer,$outErrors)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$outParsedForm>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$outParsedForm>>2] = $2;
 $4 = (__ZNK12ShaderErrors9HasErrorsEv($outErrors)|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__ZN9ShaderLab9IntShader22CreateFromParsedShaderERKNS_12ParserShaderERNSt3__16vectorI4PPtrI6ShaderENS4_9allocatorIS8_EEEEbR12ShaderErrorsPS7_($2,$dependenciesTable,$useDependenciesTable,$outErrors,$fromShader)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = (($5) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if (!($10)) {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($2) + 72|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 do {
  if ($13) {
   $14 = (__Znwj(48)|0);
   $15 = (($1) + 8|0);
   HEAP32[$15>>2] = $14;
   HEAP32[$1>>2] = 49;
   $16 = (($1) + 4|0);
   HEAP32[$16>>2] = 43;
   dest=$14+0|0; src=679128+0|0; stop=dest+43|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $17 = (($14) + 43|0);
   HEAP8[$17>>0] = 0;
   __THREW__ = 0;
   invoke_viiiii(104,($outErrors|0),($1|0),-1,1,0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP8[$1>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     break;
    }
    $23 = HEAP32[$15>>2]|0;
    __ZdlPv($23);
    break;
   }
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $26 = HEAP8[$1>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    ___resumeException($24|0);
    // unreachable;
   }
   $29 = HEAP32[$15>>2]|0;
   __ZdlPv($29);
   ___resumeException($24|0);
   // unreachable;
  }
 } while(0);
 $30 = HEAP32[628272>>2]|0;
 __ZN9ShaderLab9IntShaderD2Ev($5);
 HEAP32[$0>>2] = $30;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__16vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS5_IS8_EEE6assignIPS8_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS8_NS_15iterator_traitsISE_E9referenceEEE5valueEvE4typeESE_SE_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i9 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i4 = 0, $$012$i$i = 0, $$03$i$i = 0, $$pre$i1 = 0, $$pre$i2 = 0, $$pre2$i = 0, $$pre2$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $__growing$0$off0 = 0, $scevgep$i$i = 0, $scevgep7$i$i = 0, $uglygep$i$i = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 24)&-1;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 24)&-1;
 $11 = ($3>>>0)>($10>>>0);
 if ($11) {
  $53 = ($6|0)==(0|0);
  if ($53) {
   $75 = $5;
  } else {
   $54 = (($this) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==($6|0);
   if ($56) {
    $72 = $6;
   } else {
    $58 = $55;
    while(1) {
     $57 = (($58) + -24|0);
     HEAP32[$54>>2] = $57;
     $59 = (($58) + -12|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60 & 1;
     $62 = ($61<<24>>24)==(0);
     if (!($62)) {
      $63 = (($58) + -4|0);
      $64 = HEAP32[$63>>2]|0;
      __ZdlPv($64);
     }
     $65 = HEAP8[$57>>0]|0;
     $66 = $65 & 1;
     $67 = ($66<<24>>24)==(0);
     if (!($67)) {
      $70 = (($58) + -16|0);
      $71 = HEAP32[$70>>2]|0;
      __ZdlPv($71);
     }
     $68 = HEAP32[$54>>2]|0;
     $69 = ($68|0)==($6|0);
     if ($69) {
      break;
     } else {
      $58 = $68;
     }
    }
    $$pre$i1 = HEAP32[$this>>2]|0;
    $72 = $$pre$i1;
   }
   __ZdlPv($72);
   HEAP32[$4>>2] = 0;
   HEAP32[$54>>2] = 0;
   HEAP32[$this>>2] = 0;
   $75 = 0;
  }
  $73 = ($3>>>0)>(178956970);
  if ($73) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $74 = $75;
  $76 = (($74|0) / 24)&-1;
  $77 = ($76>>>0)<(89478485);
  if ($77) {
   $78 = $76 << 1;
   $79 = ($78>>>0)<($3>>>0);
   $80 = $79 ? $3 : $78;
   $81 = ($80>>>0)>(178956970);
   if ($81) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i9 = $80;
   }
  } else {
   $$0$i9 = 178956970;
  }
  $82 = ($$0$i9*24)|0;
  $83 = (__Znwj($82)|0);
  $84 = (($this) + 4|0);
  HEAP32[$84>>2] = $83;
  HEAP32[$this>>2] = $83;
  $85 = (($83) + (($$0$i9*24)|0)|0);
  HEAP32[$4>>2] = $85;
  $86 = ($__first|0)==($__last|0);
  if ($86) {
   STACKTOP = sp;return;
  } else {
   $$01$i = $__first;$88 = $83;
  }
  while(1) {
   $87 = ($88|0)==(0|0);
   if ($87) {
    $90 = 0;
   } else {
    __ZNSt3__14pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_EC2ERKS7_($88,$$01$i);
    $$pre2$i = HEAP32[$84>>2]|0;
    $90 = $$pre2$i;
   }
   $89 = (($90) + 24|0);
   HEAP32[$84>>2] = $89;
   $91 = (($$01$i) + 24|0);
   $92 = ($91|0)==($__last|0);
   if ($92) {
    break;
   } else {
    $$01$i = $91;$88 = $89;
   }
  }
  STACKTOP = sp;return;
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 24)&-1;
 $17 = ($3>>>0)>($16>>>0);
 if ($17) {
  $18 = (($__first) + (($16*24)|0)|0);
  $20 = $18;$__growing$0$off0 = 1;
 } else {
  $20 = $__last;$__growing$0$off0 = 0;
 }
 $19 = ($20|0)==($__first|0);
 if ($19) {
  $$0$lcssa$i$i = $6;
 } else {
  $scevgep$i$i = (($20) + -24|0);
  $21 = (0 - ($1))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($21)|0);
  $uglygep6$i$i = $uglygep$i$i;
  $$012$i$i = $__first;$$03$i$i = $6;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($$03$i$i,$$012$i$i)|0);
   $22 = (($$03$i$i) + 12|0);
   $23 = (($$012$i$i) + 12|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($22,$23)|0);
   $24 = (($$012$i$i) + 24|0);
   $25 = (($$03$i$i) + 24|0);
   $26 = ($24|0)==($20|0);
   if ($26) {
    break;
   } else {
    $$012$i$i = $24;$$03$i$i = $25;
   }
  }
  $27 = (($uglygep6$i$i>>>0) / 24)&-1;
  $28 = (($27) + 1)|0;
  $scevgep7$i$i = (($6) + (($28*24)|0)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if ($__growing$0$off0) {
  $29 = ($20|0)==($__last|0);
  if ($29) {
   STACKTOP = sp;return;
  }
  $$pre$i2 = HEAP32[$12>>2]|0;
  $$01$i4 = $20;$31 = $$pre$i2;
  while(1) {
   $30 = ($31|0)==(0|0);
   if ($30) {
    $33 = 0;
   } else {
    __ZNSt3__14pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_EC2ERKS7_($31,$$01$i4);
    $$pre2$i5 = HEAP32[$12>>2]|0;
    $33 = $$pre2$i5;
   }
   $32 = (($33) + 24|0);
   HEAP32[$12>>2] = $32;
   $34 = (($$01$i4) + 24|0);
   $35 = ($34|0)==($__last|0);
   if ($35) {
    break;
   } else {
    $$01$i4 = $34;$31 = $32;
   }
  }
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$12>>2]|0;
 $37 = ($36|0)==($$0$lcssa$i$i|0);
 if ($37) {
  STACKTOP = sp;return;
 } else {
  $39 = $36;
 }
 while(1) {
  $38 = (($39) + -24|0);
  HEAP32[$12>>2] = $38;
  $40 = (($39) + -12|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if (!($43)) {
   $44 = (($39) + -4|0);
   $45 = HEAP32[$44>>2]|0;
   __ZdlPv($45);
  }
  $46 = HEAP8[$38>>0]|0;
  $47 = $46 & 1;
  $48 = ($47<<24>>24)==(0);
  if (!($48)) {
   $51 = (($39) + -16|0);
   $52 = HEAP32[$51>>2]|0;
   __ZdlPv($52);
  }
  $49 = HEAP32[$12>>2]|0;
  $50 = ($49|0)==($$0$lcssa$i$i|0);
  if ($50) {
   break;
  } else {
   $39 = $49;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i712 = 0, $$0$i713 = 0, $$0$i9 = 0, $$byval_copy1 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i3 = 0, $$pre1$i = 0, $$pre1$i10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 28)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $17 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;HEAP32[$11+24>>2]=0|0;
    HEAP32[$11>>2] = -1;
    $12 = (($11) + 4|0);
    HEAP32[$12>>2] = 0;
    $13 = (($11) + 12|0);
    HEAP32[$13>>2] = 0;
    $14 = (($11) + 16|0);
    HEAP32[$14>>2] = 0;
    $15 = (($11) + 8|0);
    HEAP32[$15>>2] = 61;
    $$pre1$i = HEAP32[$3>>2]|0;
    $17 = $$pre1$i;
   }
   $16 = (($17) + 28|0);
   HEAP32[$3>>2] = $16;
   $18 = (($$0$i) + -1)|0;
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   } else {
    $$0$i = $18;$11 = $16;
   }
  }
  STACKTOP = sp;return;
 }
 $20 = (($this) + 8|0);
 $21 = HEAP32[$this>>2]|0;
 $22 = $21;
 $23 = (($6) - ($22))|0;
 $24 = (($23|0) / 28)&-1;
 $25 = (($24) + ($__n))|0;
 $26 = ($25>>>0)>(153391689);
 if ($26) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $27 = (($5) - ($22))|0;
 $28 = (($27|0) / 28)&-1;
 $29 = ($28>>>0)<(76695844);
 if ($29) {
  $32 = $28 << 1;
  $33 = ($32>>>0)<($25>>>0);
  $34 = $33 ? $25 : $32;
  $35 = (($__v) + 12|0);
  HEAP32[$35>>2] = 0;
  $36 = (($__v) + 16|0);
  HEAP32[$36>>2] = $20;
  $37 = ($34|0)==(0);
  if ($37) {
   $$0$i713 = 0;$40 = 0;$45 = $35;
  } else {
   $$0$i712 = $34;$100 = $35;
   label = 10;
  }
 } else {
  $30 = (($__v) + 12|0);
  HEAP32[$30>>2] = 0;
  $31 = (($__v) + 16|0);
  HEAP32[$31>>2] = $20;
  $$0$i712 = 153391689;$100 = $30;
  label = 10;
 }
 if ((label|0) == 10) {
  $38 = ($$0$i712*28)|0;
  $39 = (__Znwj($38)|0);
  $$0$i713 = $$0$i712;$40 = $39;$45 = $100;
 }
 HEAP32[$__v>>2] = $40;
 $41 = (($40) + (($24*28)|0)|0);
 $42 = (($__v) + 8|0);
 HEAP32[$42>>2] = $41;
 $43 = (($__v) + 4|0);
 HEAP32[$43>>2] = $41;
 $44 = (($40) + (($$0$i713*28)|0)|0);
 HEAP32[$45>>2] = $44;
 $$0$i9 = $__n;$47 = $41;
 while(1) {
  $46 = ($47|0)==(0|0);
  if ($46) {
   $53 = 0;
  } else {
   ;HEAP32[$47+0>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;HEAP32[$47+12>>2]=0|0;HEAP32[$47+16>>2]=0|0;HEAP32[$47+20>>2]=0|0;HEAP32[$47+24>>2]=0|0;
   HEAP32[$47>>2] = -1;
   $48 = (($47) + 4|0);
   HEAP32[$48>>2] = 0;
   $49 = (($47) + 12|0);
   HEAP32[$49>>2] = 0;
   $50 = (($47) + 16|0);
   HEAP32[$50>>2] = 0;
   $51 = (($47) + 8|0);
   HEAP32[$51>>2] = 61;
   $$pre1$i10 = HEAP32[$42>>2]|0;
   $53 = $$pre1$i10;
  }
  $52 = (($53) + 28|0);
  HEAP32[$42>>2] = $52;
  $54 = (($$0$i9) + -1)|0;
  $55 = ($54|0)==(0);
  if ($55) {
   break;
  } else {
   $$0$i9 = $54;$47 = $52;
  }
 }
 __THREW__ = 0;
 invoke_vii(3268,($this|0),($__v|0));
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  $80 = HEAP32[$43>>2]|0;
  $81 = HEAP32[$42>>2]|0;
  $82 = ($81|0)==($80|0);
  L26: do {
   if (!($82)) {
    $84 = $81;
    while(1) {
     $83 = (($84) + -28|0);
     HEAP32[$42>>2] = $83;
     $85 = (($84) + -12|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($86|0)>(-1);
     if ($87) {
      $90 = (($84) + -24|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($84) + -20|0);
      $93 = HEAP32[$92>>2]|0;
      HEAP32[$0>>2] = $93;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($91|0),($$byval_copy1|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       break;
      }
      HEAP32[$90>>2] = 0;
      $$pre$i$i$i$i$i = HEAP32[$42>>2]|0;
      $89 = $$pre$i$i$i$i$i;
     } else {
      $89 = $83;
     }
     $88 = ($89|0)==($80|0);
     if ($88) {
      break L26;
     } else {
      $84 = $89;
     }
    }
    $96 = ___cxa_find_matching_catch()|0;
    $97 = tempRet0;
    ___cxa_call_unexpected(($96|0));
    // unreachable;
   }
  } while(0);
  $98 = HEAP32[$__v>>2]|0;
  $99 = ($98|0)==(0|0);
  if ($99) {
   ___resumeException($78|0);
   // unreachable;
  }
  __ZdlPv($98);
  ___resumeException($78|0);
  // unreachable;
 } else {
  $58 = HEAP32[$43>>2]|0;
  $59 = HEAP32[$42>>2]|0;
  $60 = ($59|0)==($58|0);
  L41: do {
   if (!($60)) {
    $62 = $59;
    while(1) {
     $61 = (($62) + -28|0);
     HEAP32[$42>>2] = $61;
     $63 = (($62) + -12|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)>(-1);
     if ($65) {
      $68 = (($62) + -24|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = (($62) + -20|0);
      $71 = HEAP32[$70>>2]|0;
      HEAP32[$0>>2] = $71;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($69|0),($$byval_copy1|0));
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       break;
      }
      HEAP32[$68>>2] = 0;
      $$pre$i$i$i$i$i3 = HEAP32[$42>>2]|0;
      $67 = $$pre$i$i$i$i$i3;
     } else {
      $67 = $61;
     }
     $66 = ($67|0)==($58|0);
     if ($66) {
      break L41;
     } else {
      $62 = $67;
     }
    }
    $74 = ___cxa_find_matching_catch()|0;
    $75 = tempRet0;
    ___cxa_call_unexpected(($74|0));
    // unreachable;
   }
  } while(0);
  $76 = HEAP32[$__v>>2]|0;
  $77 = ($76|0)==(0|0);
  if ($77) {
   STACKTOP = sp;return;
  }
  __ZdlPv($76);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$byval_copy = 0, $$idx$i$i$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__v) + 4|0);
 $5 = ($3|0)==($1|0);
 if ($5) {
  $$pre1 = HEAP32[$4>>2]|0;
  $41 = $$pre1;$42 = $1;
 } else {
  $$pre$i = HEAP32[$4>>2]|0;
  $$01$i = $3;$9 = $$pre$i;
  while(1) {
   $6 = (($$01$i) + -28|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($9) + -28|0);
   HEAP32[$8>>2] = $7;
   $10 = (($$01$i) + -20|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + -20|0);
   HEAP32[$12>>2] = $11;
   $13 = (($9) + -16|0);
   HEAP32[$13>>2] = 0;
   $14 = (($9) + -12|0);
   HEAP32[$14>>2] = 0;
   $15 = (($9) + -24|0);
   HEAP32[$15>>2] = 0;
   $16 = (($$01$i) + -24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($$01$i) + -16|0);
   $19 = HEAP32[$18>>2]|0;
   $$idx$i$i$i$i$i$i = ($19*20)|0;
   $20 = (($$idx$i$i$i$i$i$i|0) / 20)&-1;
   HEAP32[$13>>2] = $20;
   $21 = ($$idx$i$i$i$i$i$i|0)==(0);
   if ($21) {
    $24 = $20;$25 = 0;
   } else {
    HEAP32[$14>>2] = $20;
    HEAP32[$0>>2] = $11;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i$i$i$i$i,4,$$byval_copy,0,678976,370)|0);
    HEAP32[$15>>2] = $22;
    $$pre$i$i$i$i$i = HEAP32[$13>>2]|0;
    $24 = $$pre$i$i$i$i$i;$25 = $22;
   }
   $23 = ($24*20)|0;
   _memcpy(($25|0),($17|0),($23|0))|0;
   $26 = (($9) + -8|0);
   $27 = (($$01$i) + -8|0);
   $28 = $27;
   $29 = $28;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($28) + 4)|0;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = $26;
   $35 = $34;
   HEAP32[$35>>2] = $30;
   $36 = (($34) + 4)|0;
   $37 = $36;
   HEAP32[$37>>2] = $33;
   $38 = HEAP32[$4>>2]|0;
   $39 = (($38) + -28|0);
   HEAP32[$4>>2] = $39;
   $40 = ($6|0)==($1|0);
   if ($40) {
    break;
   } else {
    $$01$i = $6;$9 = $39;
   }
  }
  $$pre = HEAP32[$this>>2]|0;
  $41 = $39;$42 = $$pre;
 }
 HEAP32[$this>>2] = $41;
 HEAP32[$4>>2] = $42;
 $43 = (($__v) + 8|0);
 $44 = HEAP32[$2>>2]|0;
 $45 = HEAP32[$43>>2]|0;
 HEAP32[$2>>2] = $45;
 HEAP32[$43>>2] = $44;
 $46 = (($this) + 8|0);
 $47 = (($__v) + 12|0);
 $48 = HEAP32[$46>>2]|0;
 $49 = HEAP32[$47>>2]|0;
 HEAP32[$46>>2] = $49;
 HEAP32[$47>>2] = $48;
 $50 = HEAP32[$4>>2]|0;
 HEAP32[$__v>>2] = $50;
 STACKTOP = sp;return;
}
function __ZNSt3__13mapIN9ShaderLab16FastPropertyNameENS1_13PropertySheet15TexturePropertyENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$22 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $31 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($31|0);
 }
 $16 = (__Znwj(36)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;
 HEAP32[$16>>2] = 0;
 $20 = (($16) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $16;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $16;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $__r$0 = $16;
 $31 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($31|0);
}
function __Z30ComputeIgnoreCurrentSubProgram17GfxDeviceRendererPKc($renderer,$tags) {
 $renderer = $renderer|0;
 $tags = $tags|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($tags|0)==(0|0);
 L1: do {
  if ($0) {
   $$0 = 0;
  } else {
   switch ($renderer|0) {
   case 3:  {
    $13 = (_strstr($tags,679368)|0);
    $14 = ($13|0)==(0|0);
    $$0 = $14;
    break L1;
    break;
   }
   case 13:  {
    $17 = (_strstr($tags,679384)|0);
    $18 = ($17|0)==(0|0);
    STACKTOP = sp;return ($18|0);
    break;
   }
   case 2:  {
    $11 = (_strstr($tags,679360)|0);
    $12 = ($11|0)==(0|0);
    $$0 = $12;
    break L1;
    break;
   }
   case 1:  {
    $5 = (_strstr($tags,679336)|0);
    $6 = ($5|0)==(0|0);
    $$0 = $6;
    break L1;
    break;
   }
   case 14:  {
    $9 = (_strstr($tags,679352)|0);
    $10 = ($9|0)==(0|0);
    $$0 = $10;
    break L1;
    break;
   }
   case 0:  {
    $1 = (_strstr($tags,679320)|0);
    $2 = ($1|0)==(0|0);
    $$0 = $2;
    break L1;
    break;
   }
   case 8:  {
    $3 = (_strstr($tags,679328)|0);
    $4 = ($3|0)==(0|0);
    $$0 = $4;
    break L1;
    break;
   }
   case 6:  {
    $7 = (_strstr($tags,679344)|0);
    $8 = ($7|0)==(0|0);
    $$0 = $8;
    break L1;
    break;
   }
   case 12:  {
    $15 = (_strstr($tags,679376)|0);
    $16 = ($15|0)==(0|0);
    $$0 = $16;
    break L1;
    break;
   }
   default: {
    $$0 = 0;
    break L1;
   }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z24CreateDefaultShaderStateRN9ShaderLab17ParserShaderStateE($base) {
 $base = $base|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($base) + 52|0);
 HEAPF32[$1>>2] = Math_fround(2.0);
 $2 = (($base) + 56|0);
 HEAP32[$2>>2] = -1;
 $3 = (($base) + 28|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($base) + 32|0);
 HEAP32[$4>>2] = -1;
 $5 = (($base) + 36|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($base) + 40|0);
 HEAP32[$6>>2] = -1;
 $7 = (($base) + 44|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($base) + 48|0);
 HEAP32[$8>>2] = -1;
 $9 = (($base) + 516|0);
 HEAP32[$9>>2] = 0;
 $10 = (($base) + 76|0);
 HEAP8[$10>>0] = 0;
 $11 = (($base) + 80|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($base) + 84|0);
 HEAP32[$12>>2] = -1;
 $13 = (($base) + 144|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($base) + 148|0);
 HEAP32[$14>>2] = -1;
 $15 = (($base) + 152|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($base) + 156|0);
 HEAP32[$16>>2] = -1;
 $17 = (($base) + 160|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($base) + 164|0);
 HEAP32[$18>>2] = -1;
 $19 = (($base) + 168|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($base) + 172|0);
 HEAP32[$20>>2] = -1;
 $21 = (($base) + 176|0);
 HEAP32[$21>>2] = -1;
 $22 = (($base) + 216|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($base) + 220|0);
 HEAP32[$23>>2] = -1;
 $24 = (($base) + 224|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($base) + 228|0);
 HEAP32[$25>>2] = -1;
 $26 = (($base) + 232|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($base) + 236|0);
 HEAP32[$27>>2] = -1;
 $28 = (($base) + 240|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($base) + 244|0);
 HEAP32[$29>>2] = -1;
 $30 = (($base) + 248|0);
 HEAP32[$30>>2] = -1;
 $31 = (($base) + 180|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($base) + 184|0);
 HEAP32[$32>>2] = -1;
 $33 = (($base) + 188|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 $34 = (($base) + 192|0);
 HEAP32[$34>>2] = -1;
 $35 = (($base) + 196|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($base) + 200|0);
 HEAP32[$36>>2] = -1;
 $37 = (($base) + 204|0);
 HEAPF32[$37>>2] = Math_fround(1.0);
 $38 = (($base) + 208|0);
 HEAP32[$38>>2] = -1;
 $39 = (($base) + 212|0);
 HEAP32[$39>>2] = -1;
 $40 = (($base) + 252|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($base) + 256|0);
 HEAP32[$41>>2] = -1;
 $42 = (($base) + 260|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($base) + 264|0);
 HEAP32[$43>>2] = -1;
 $44 = (($base) + 268|0);
 HEAPF32[$44>>2] = Math_fround(0.0);
 $45 = (($base) + 272|0);
 HEAP32[$45>>2] = -1;
 $46 = (($base) + 276|0);
 HEAPF32[$46>>2] = Math_fround(1.0);
 $47 = (($base) + 280|0);
 HEAP32[$47>>2] = -1;
 $48 = (($base) + 284|0);
 HEAP32[$48>>2] = -1;
 $49 = (($base) + 288|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($base) + 292|0);
 HEAP32[$50>>2] = -1;
 $51 = (($base) + 296|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($base) + 300|0);
 HEAP32[$52>>2] = -1;
 $53 = (($base) + 304|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($base) + 308|0);
 HEAP32[$54>>2] = -1;
 $55 = (($base) + 312|0);
 HEAPF32[$55>>2] = Math_fround(1.0);
 $56 = (($base) + 316|0);
 HEAP32[$56>>2] = -1;
 $57 = (($base) + 320|0);
 HEAP32[$57>>2] = -1;
 $58 = (($base) + 12|0);
 HEAPF32[$58>>2] = Math_fround(4.0);
 $59 = (($base) + 16|0);
 HEAP32[$59>>2] = -1;
 $60 = (($base) + 136|0);
 HEAPF32[$60>>2] = Math_fround(15.0);
 $61 = (($base) + 140|0);
 HEAP32[$61>>2] = -1;
 $62 = (($base) + 20|0);
 HEAPF32[$62>>2] = Math_fround(1.0);
 $63 = (($base) + 24|0);
 HEAP32[$63>>2] = -1;
 $64 = (($base) + 324|0);
 HEAP8[$64>>0] = 0;
 $65 = (($base) + 88|0);
 HEAPF32[$65>>2] = Math_fround(1.0);
 $66 = (($base) + 92|0);
 HEAP32[$66>>2] = -1;
 $67 = (($base) + 96|0);
 HEAPF32[$67>>2] = Math_fround(0.0);
 $68 = (($base) + 100|0);
 HEAP32[$68>>2] = -1;
 $69 = (($base) + 104|0);
 HEAPF32[$69>>2] = Math_fround(1.0);
 $70 = (($base) + 108|0);
 HEAP32[$70>>2] = -1;
 $71 = (($base) + 112|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($base) + 116|0);
 HEAP32[$72>>2] = -1;
 $73 = (($base) + 120|0);
 HEAPF32[$73>>2] = Math_fround(0.0);
 $74 = (($base) + 124|0);
 HEAP32[$74>>2] = -1;
 $75 = (($base) + 128|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($base) + 132|0);
 HEAP32[$76>>2] = -1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,679392);
 $77 = HEAP32[$0>>2]|0;
 $78 = (($base) + 504|0);
 HEAP32[$78>>2] = $77;
 $79 = (($base) + 508|0);
 HEAP32[$79>>2] = -1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,679408);
 $80 = HEAP32[$0>>2]|0;
 $81 = (($base) + 452|0);
 HEAP32[$81>>2] = $80;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,679424);
 $82 = HEAP32[$0>>2]|0;
 $83 = (($base) + 460|0);
 HEAP32[$83>>2] = $82;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,679440);
 $84 = HEAP32[$0>>2]|0;
 $85 = (($base) + 468|0);
 HEAP32[$85>>2] = $84;
 $86 = (($base) + 60|0);
 HEAPF32[$86>>2] = Math_fround(0.0);
 $87 = (($base) + 64|0);
 HEAP32[$87>>2] = -1;
 $88 = (($base) + 68|0);
 HEAPF32[$88>>2] = Math_fround(0.0);
 $89 = (($base) + 72|0);
 HEAP32[$89>>2] = -1;
 $90 = (($base) + 512|0);
 HEAP32[$90>>2] = -1;
 $91 = (($base) + 652|0);
 HEAP32[$91>>2] = 0;
 $92 = (($base) + 424|0);
 HEAPF32[$92>>2] = Math_fround(255.0);
 $93 = (($base) + 428|0);
 HEAP32[$93>>2] = -1;
 $94 = (($base) + 432|0);
 HEAPF32[$94>>2] = Math_fround(255.0);
 $95 = (($base) + 436|0);
 HEAP32[$95>>2] = -1;
 $96 = (($base) + 440|0);
 HEAPF32[$96>>2] = Math_fround(0.0);
 $97 = (($base) + 444|0);
 HEAP32[$97>>2] = -1;
 $98 = (($base) + 328|0);
 $99 = (($base) + 352|0);
 HEAPF32[$99>>2] = Math_fround(8.0);
 $100 = (($base) + 356|0);
 HEAP32[$100>>2] = -1;
 HEAPF32[$98>>2] = Math_fround(0.0);
 $101 = (($base) + 332|0);
 HEAP32[$101>>2] = -1;
 $102 = (($base) + 336|0);
 HEAPF32[$102>>2] = Math_fround(0.0);
 $103 = (($base) + 340|0);
 HEAP32[$103>>2] = -1;
 $104 = (($base) + 344|0);
 HEAPF32[$104>>2] = Math_fround(0.0);
 $105 = (($base) + 348|0);
 HEAP32[$105>>2] = -1;
 $106 = (($base) + 360|0);
 ;HEAP32[$106+0>>2]=HEAP32[$98+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$98+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$98+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$98+12>>2]|0;HEAP32[$106+16>>2]=HEAP32[$98+16>>2]|0;HEAP32[$106+20>>2]=HEAP32[$98+20>>2]|0;HEAP32[$106+24>>2]=HEAP32[$98+24>>2]|0;HEAP32[$106+28>>2]=HEAP32[$98+28>>2]|0;
 $107 = (($base) + 392|0);
 ;HEAP32[$107+0>>2]=HEAP32[$98+0>>2]|0;HEAP32[$107+4>>2]=HEAP32[$98+4>>2]|0;HEAP32[$107+8>>2]=HEAP32[$98+8>>2]|0;HEAP32[$107+12>>2]=HEAP32[$98+12>>2]|0;HEAP32[$107+16>>2]=HEAP32[$98+16>>2]|0;HEAP32[$107+20>>2]=HEAP32[$98+20>>2]|0;HEAP32[$107+24>>2]=HEAP32[$98+24>>2]|0;HEAP32[$107+28>>2]=HEAP32[$98+28>>2]|0;
 STACKTOP = sp;return;
}
function __Z14PreParseShaderPKcj17GfxDeviceRendererR12ShaderErrors($text,$shaderLength,$gfxRenderer,$outErrors) {
 $text = $text|0;
 $shaderLength = $shaderLength|0;
 $gfxRenderer = $gfxRenderer|0;
 $outErrors = $outErrors|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $$byval_copy3 = 0, $$byval_copy8 = 0, $$lcssa = 0, $$neg = 0, $$neg$lcssa = 0, $$neg1$i = 0, $$neg1$i12 = 0, $$neg2$i$i$i = 0, $$neg2$i$i$i13 = 0, $$neg2$i$i$i8 = 0, $$neg29 = 0, $$neg30 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $$pre1$i$i = 0;
 var $$pre2$i$i = 0, $$pre3$i$i = 0, $$pre34 = 0, $$pre35 = 0, $$pre37 = 0, $$pre38 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $base = 0, $emptyStack = 0, $errors = 0, $lastParsed = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i19 = 0, $shader$0 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i17 = 0;
 var $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i18 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 752|0;
 $$byval_copy8 = sp;
 $$byval_copy3 = sp + 744|0;
 $0 = sp + 740|0;
 $1 = sp + 736|0;
 $2 = sp + 732|0;
 $3 = sp + 728|0;
 $4 = sp + 748|0;
 $5 = sp + 688|0;
 $base = sp + 32|0;
 $6 = sp + 24|0;
 $errors = sp + 12|0;
 $lastParsed = sp + 692|0;
 $emptyStack = sp + 704|0;
 $7 = ($shaderLength>>>0)>(2);
 if ($7) {
  $8 = HEAP8[$text>>0]|0;
  $9 = ($8<<24>>24)==(-17);
  if ($9) {
   $10 = (($text) + 1|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = ($11<<24>>24)==(-69);
   if ($12) {
    $13 = (($text) + 2|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = ($14<<24>>24)==(-65);
    if ($15) {
     $16 = (($text) + 3|0);
     $17 = (($shaderLength) + -3)|0;
     $$0 = $16;$$01 = $17;
    } else {
     $$0 = $text;$$01 = $shaderLength;
    }
   } else {
    $$0 = $text;$$01 = $shaderLength;
   }
  } else {
   $$0 = $text;$$01 = $shaderLength;
  }
 } else {
  $$0 = $text;$$01 = $shaderLength;
 }
 HEAP32[674264>>2] = $gfxRenderer;
 __ZN9ShaderLab17ParserShaderStateC2Ev($base);
 __THREW__ = 0;
 invoke_vi(3598,($base|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L7: do {
  if ($19) {
   label = 47;
  } else {
   __THREW__ = 0;
   (invoke_iii(2392,(674240|0),(679464|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    label = 47;
   } else {
    $22 = HEAP32[((674208 + 8|0))>>2]|0;
    $23 = HEAP32[((674208 + 4|0))>>2]|0;
    $24 = ($22|0)==($23|0);
    if ($24) {
     $32 = 0;
    } else {
     $25 = $22;
     $26 = $23;
     $27 = (($25) - ($26))|0;
     $28 = $27 << 8;
     $29 = (($28) + -1)|0;
     $32 = $29;
    }
    $30 = HEAP32[((674208 + 16|0))>>2]|0;
    $31 = HEAP32[((674208 + 20|0))>>2]|0;
    $$neg2$i$i$i = (($32) - ($30))|0;
    $33 = ($$neg2$i$i$i|0)==($31|0);
    if ($33) {
     __THREW__ = 0;
     invoke_vi(3599,(674208|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 47;
      break;
     }
     $$pre$i$i = HEAP32[((674208 + 20|0))>>2]|0;
     $$pre1$i$i = HEAP32[((674208 + 16|0))>>2]|0;
     $$pre2$i$i = HEAP32[((674208 + 4|0))>>2]|0;
     $$pre3$i$i = HEAP32[((674208 + 8|0))>>2]|0;
     $37 = $$pre$i$i;$38 = $$pre1$i$i;$40 = $$pre3$i$i;$41 = $$pre2$i$i;
    } else {
     $37 = $31;$38 = $30;$40 = $22;$41 = $23;
    }
    $36 = (($37) + ($38))|0;
    $39 = ($40|0)==($41|0);
    if (!($39)) {
     $42 = $36 >>> 10;
     $43 = (($41) + ($42<<2)|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = $36 & 1023;
     $46 = (($44) + ($45<<2)|0);
     $47 = ($46|0)==(0|0);
     if (!($47)) {
      HEAP32[$46>>2] = $base;
     }
    }
    $48 = (($37) + 1)|0;
    HEAP32[((674208 + 20|0))>>2] = $48;
    HEAP32[674256>>2] = $outErrors;
    $49 = HEAP8[674240>>0]|0;
    $50 = $49 & 1;
    $51 = ($50<<24>>24)==(0);
    if ($51) {
     HEAP8[((674240 + 1|0))>>0] = 0;
     HEAP8[674240>>0] = 0;
    } else {
     $52 = HEAP32[((674240 + 8|0))>>2]|0;
     HEAP8[$52>>0] = 0;
     HEAP32[((674240 + 4|0))>>2] = 0;
    }
    $53 = HEAP32[628272>>2]|0;
    HEAP32[$6>>2] = $53;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$6+0>>2]|0;
    $54 = (invoke_iiiiiii(103,76,($$byval_copy8|0),0,16,(679568|0),160)|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 47;
    } else {
     dest=$54+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$54+72>>0]=0|0;
     HEAP32[674232>>2] = $54;
     __THREW__ = 0;
     $57 = (invoke_ii(2988,64)|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      label = 47;
     } else {
      __THREW__ = 0;
      invoke_viii(1614,($57|0),32768,(679576|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       $149 = ___cxa_find_matching_catch()|0;
       $150 = tempRet0;
       __ZdlPv($57);
       $$02 = $150;$$03 = $149;
       break;
      }
      HEAP32[679312>>2] = $57;
      __THREW__ = 0;
      invoke_vii(3269,($$0|0),($$01|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       label = 47;
      } else {
       __THREW__ = 0;
       $64 = (invoke_i(107)|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        label = 47;
       } else {
        __THREW__ = 0;
        invoke_v(187);
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         label = 47;
        } else {
         $69 = HEAP32[679312>>2]|0;
         $70 = ($69|0)==(0|0);
         if (!($70)) {
          $71 = HEAP32[$69>>2]|0;
          $72 = (($71) + 4|0);
          $73 = HEAP32[$72>>2]|0;
          __THREW__ = 0;
          invoke_vi($73|0,($69|0));
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           label = 47;
           break;
          }
         }
         HEAP32[679312>>2] = 0;
         $76 = (($errors) + 4|0);
         HEAP32[$76>>2] = 0;
         $77 = (($errors) + 8|0);
         HEAP32[$77>>2] = 0;
         $78 = (($errors) + 4|0);
         HEAP32[$errors>>2] = $78;
         $79 = HEAP32[674256>>2]|0;
         $80 = ($errors|0)==($79|0);
         if ($80) {
          $85 = $errors;$86 = 0;
          label = 30;
         } else {
          $81 = HEAP32[$79>>2]|0;
          HEAP32[$3>>2] = $81;
          $82 = (($79) + 4|0);
          HEAP32[$4>>2] = $82;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
          ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$4+0>>2]|0;
          invoke_viii(1951,($errors|0),($$byval_copy3|0),($$byval_copy8|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if (!($84)) {
           $$pre37 = HEAP32[674256>>2]|0;
           $$phi$trans$insert = (($$pre37) + 4|0);
           $$pre38 = HEAP32[$$phi$trans$insert>>2]|0;
           $85 = $$pre37;$86 = $$pre38;
           label = 30;
          }
         }
         do {
          if ((label|0) == 30) {
           __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($85,$86);
           $87 = (($85) + 8|0);
           HEAP32[$87>>2] = 0;
           $88 = (($85) + 4|0);
           HEAP32[$85>>2] = $88;
           HEAP32[$88>>2] = 0;
           $89 = HEAP32[674256>>2]|0;
           $90 = ($89|0)==($errors|0);
           if (!($90)) {
            $91 = HEAP32[$errors>>2]|0;
            HEAP32[$1>>2] = $91;
            HEAP32[$2>>2] = $78;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
            ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
            invoke_viii(1951,($89|0),($$byval_copy3|0),($$byval_copy8|0));
            $92 = __THREW__; __THREW__ = 0;
            $93 = $92&1;
            if ($93) {
             break;
            }
           }
           $94 = HEAP32[$76>>2]|0;
           __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($errors,$94);
           ;HEAP32[$lastParsed+0>>2]=0|0;HEAP32[$lastParsed+4>>2]=0|0;HEAP32[$lastParsed+8>>2]=0|0;
           ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$lastParsed+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$lastParsed+4>>2]|0;HEAP32[$$byval_copy8+8>>2]=HEAP32[$lastParsed+8>>2]|0;
           ;HEAP32[$lastParsed+0>>2]=HEAP32[674240+0>>2]|0;HEAP32[$lastParsed+4>>2]=HEAP32[674240+4>>2]|0;HEAP32[$lastParsed+8>>2]=HEAP32[674240+8>>2]|0;
           ;HEAP32[674240+0>>2]=HEAP32[$$byval_copy8+0>>2]|0;HEAP32[674240+4>>2]=HEAP32[$$byval_copy8+4>>2]|0;HEAP32[674240+8>>2]=HEAP32[$$byval_copy8+8>>2]|0;
           __THREW__ = 0;
           (invoke_iii(2233,(674240|0),($lastParsed|0))|0);
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if ($96) {
            $154 = ___cxa_find_matching_catch()|0;
            $155 = tempRet0;
            $156 = HEAP8[$lastParsed>>0]|0;
            $157 = $156 & 1;
            $158 = ($157<<24>>24)==(0);
            if ($158) {
             $$02 = $155;$$03 = $154;
             break L7;
            }
            $159 = (($lastParsed) + 8|0);
            $160 = HEAP32[$159>>2]|0;
            __ZdlPv($160);
            $$02 = $155;$$03 = $154;
            break L7;
           }
           $97 = HEAP8[$lastParsed>>0]|0;
           $98 = $97 & 1;
           $99 = ($98<<24>>24)==(0);
           if (!($99)) {
            $100 = (($lastParsed) + 8|0);
            $101 = HEAP32[$100>>2]|0;
            __ZdlPv($101);
           }
           HEAP32[674232>>2] = 0;
           HEAP32[674256>>2] = 0;
           $102 = HEAP32[((674208 + 20|0))>>2]|0;
           $$neg29 = (0 - ($102))|0;
           $103 = ($102>>>0)>(1);
           L51: do {
            if ($103) {
             $$neg30 = $$neg29;$106 = $102;
             while(1) {
              $104 = HEAP32[((674208 + 16|0))>>2]|0;
              $105 = (($106) + -1)|0;
              $107 = (($104) + ($105))|0;
              $108 = HEAP32[((674208 + 4|0))>>2]|0;
              $109 = $107 >>> 10;
              $110 = (($108) + ($109<<2)|0);
              $111 = HEAP32[$110>>2]|0;
              $112 = $107 & 1023;
              $113 = (($111) + ($112<<2)|0);
              $114 = HEAP32[$113>>2]|0;
              HEAP32[((674208 + 20|0))>>2] = $105;
              $115 = HEAP32[((674208 + 8|0))>>2]|0;
              $116 = ($115|0)==($108|0);
              if ($116) {
               $122 = 0;
              } else {
               $117 = $115;
               $118 = $108;
               $119 = (($117) - ($118))|0;
               $120 = $119 << 8;
               $121 = (($120) + -1)|0;
               $122 = $121;
              }
              $$neg1$i = (($$neg30) + 1)|0;
              $$neg2$i$i$i8 = (($$neg1$i) + ($122))|0;
              $123 = (($$neg2$i$i$i8) - ($104))|0;
              $124 = ($123>>>0)>(2047);
              if ($124) {
               $125 = (($115) + -4|0);
               $126 = HEAP32[$125>>2]|0;
               __ZdlPv($126);
               $127 = HEAP32[((674208 + 8|0))>>2]|0;
               $128 = (($127) + -4|0);
               $__new_last2$i$i$i$i$i = $128;
               $129 = (0 - ($__new_last2$i$i$i$i$i))|0;
               $uglygep$i$i$i$i$i = (($128) + ($129)|0);
               $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
               $130 = $uglygep3$i$i$i$i$i >>> 2;
               $131 = $130 ^ -1;
               $scevgep4$i$i$i$i$i = (($127) + ($131<<2)|0);
               HEAP32[((674208 + 8|0))>>2] = $scevgep4$i$i$i$i$i;
              }
              $132 = ($114|0)==(0|0);
              if (!($132)) {
               $133 = (($114) + 640|0);
               $134 = (($114) + 644|0);
               $135 = HEAP32[$134>>2]|0;
               __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($133,$135);
               $136 = HEAP8[$114>>0]|0;
               $137 = $136 & 1;
               $138 = ($137<<24>>24)==(0);
               if (!($138)) {
                $139 = (($114) + 8|0);
                $140 = HEAP32[$139>>2]|0;
                HEAP32[$0>>2] = 59;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
                invoke_vii(2591,($140|0),($$byval_copy8|0));
                $141 = __THREW__; __THREW__ = 0;
                $142 = $141&1;
                if ($142) {
                 break;
                }
               }
               __ZdlPv($114);
              }
              $145 = HEAP32[((674208 + 20|0))>>2]|0;
              $$neg = (0 - ($145))|0;
              $146 = ($145>>>0)>(1);
              if ($146) {
               $$neg30 = $$neg;$106 = $145;
              } else {
               $$lcssa = $145;$$neg$lcssa = $$neg;
               break L51;
              }
             }
             $143 = ___cxa_find_matching_catch()|0;
             $144 = tempRet0;
             ___cxa_call_unexpected(($143|0));
             // unreachable;
            } else {
             $$lcssa = $102;$$neg$lcssa = $$neg29;
            }
           } while(0);
           $161 = (($$lcssa) + -1)|0;
           HEAP32[((674208 + 20|0))>>2] = $161;
           $162 = HEAP32[((674208 + 8|0))>>2]|0;
           $163 = HEAP32[((674208 + 4|0))>>2]|0;
           $164 = ($162|0)==($163|0);
           if ($164) {
            $171 = 0;
           } else {
            $165 = $162;
            $166 = $163;
            $167 = (($165) - ($166))|0;
            $168 = $167 << 8;
            $169 = (($168) + -1)|0;
            $171 = $169;
           }
           $170 = HEAP32[((674208 + 16|0))>>2]|0;
           $$neg1$i12 = (($$neg$lcssa) + 1)|0;
           $$neg2$i$i$i13 = (($$neg1$i12) + ($171))|0;
           $172 = (($$neg2$i$i$i13) - ($170))|0;
           $173 = ($172>>>0)>(2047);
           if ($173) {
            $174 = (($162) + -4|0);
            $175 = HEAP32[$174>>2]|0;
            __ZdlPv($175);
            $176 = HEAP32[((674208 + 8|0))>>2]|0;
            $177 = (($176) + -4|0);
            $__new_last2$i$i$i$i$i15 = $177;
            $178 = (0 - ($__new_last2$i$i$i$i$i15))|0;
            $uglygep$i$i$i$i$i17 = (($177) + ($178)|0);
            $uglygep3$i$i$i$i$i18 = $uglygep$i$i$i$i$i17;
            $179 = $uglygep3$i$i$i$i$i18 >>> 2;
            $180 = $179 ^ -1;
            $scevgep4$i$i$i$i$i19 = (($176) + ($180<<2)|0);
            HEAP32[((674208 + 8|0))>>2] = $scevgep4$i$i$i$i$i19;
            $$pre = HEAP32[((674208 + 4|0))>>2]|0;
            $$pre34 = HEAP32[((674208 + 16|0))>>2]|0;
            $$pre35 = HEAP32[((674208 + 20|0))>>2]|0;
            $183 = $$pre;$185 = $scevgep4$i$i$i$i$i19;$189 = $$pre34;$191 = $$pre35;
           } else {
            $183 = $163;$185 = $162;$189 = $170;$191 = $161;
           }
           ;HEAP32[$emptyStack+0>>2]=0|0;HEAP32[$emptyStack+4>>2]=0|0;HEAP32[$emptyStack+8>>2]=0|0;HEAP32[$emptyStack+12>>2]=0|0;HEAP32[$emptyStack+16>>2]=0|0;
           $181 = HEAP32[674208>>2]|0;
           HEAP32[674208>>2] = 0;
           HEAP32[$emptyStack>>2] = $181;
           $182 = (($emptyStack) + 4|0);
           HEAP32[((674208 + 4|0))>>2] = 0;
           HEAP32[$182>>2] = $183;
           $184 = (($emptyStack) + 8|0);
           HEAP32[((674208 + 8|0))>>2] = 0;
           HEAP32[$184>>2] = $185;
           $186 = (($emptyStack) + 12|0);
           $187 = HEAP32[((674208 + 12|0))>>2]|0;
           HEAP32[((674208 + 12|0))>>2] = 0;
           HEAP32[$186>>2] = $187;
           $188 = (($emptyStack) + 16|0);
           HEAP32[((674208 + 16|0))>>2] = 0;
           HEAP32[$188>>2] = $189;
           $190 = (($emptyStack) + 20|0);
           HEAP32[((674208 + 20|0))>>2] = 0;
           HEAP32[$190>>2] = $191;
           __ZNSt3__15stackIPN9ShaderLab17ParserShaderStateENS_5dequeIS3_NS_9allocatorIS3_EEEEED1Ev($emptyStack);
           $192 = ($64|0)==(0);
           if ($192) {
            $shader$0 = $54;
           } else {
            $193 = HEAP32[628272>>2]|0;
            $194 = ($54|0)==(0|0);
            if (!($194)) {
             __THREW__ = 0;
             invoke_vi(3578,($54|0));
             $195 = __THREW__; __THREW__ = 0;
             $196 = $195&1;
             if ($196) {
              label = 47;
              break L7;
             }
            }
            HEAP32[$$byval_copy3>>2] = $193;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$$byval_copy3+0>>2]|0;
            invoke_vii(2591,($54|0),($$byval_copy8|0));
            $197 = __THREW__; __THREW__ = 0;
            $198 = $197&1;
            if ($198) {
             label = 47;
             break L7;
            } else {
             $shader$0 = 0;
            }
           }
           $199 = (($base) + 640|0);
           $200 = (($base) + 644|0);
           $201 = HEAP32[$200>>2]|0;
           __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($199,$201);
           $202 = HEAP8[$base>>0]|0;
           $203 = $202 & 1;
           $204 = ($203<<24>>24)==(0);
           if ($204) {
            STACKTOP = sp;return ($shader$0|0);
           }
           $205 = (($base) + 8|0);
           $206 = HEAP32[$205>>2]|0;
           HEAP32[$1>>2] = 59;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
           invoke_vii(2591,($206|0),($$byval_copy8|0));
           $207 = __THREW__; __THREW__ = 0;
           $208 = $207&1;
           if ($208) {
            $209 = ___cxa_find_matching_catch()|0;
            $210 = tempRet0;
            ___cxa_call_unexpected(($209|0));
            // unreachable;
           } else {
            STACKTOP = sp;return ($shader$0|0);
           }
          }
         } while(0);
         $151 = ___cxa_find_matching_catch()|0;
         $152 = tempRet0;
         $153 = HEAP32[$76>>2]|0;
         __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($errors,$153);
         $$02 = $152;$$03 = $151;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 47) {
  $147 = ___cxa_find_matching_catch()|0;
  $148 = tempRet0;
  $$02 = $148;$$03 = $147;
 }
 $211 = (($base) + 640|0);
 $212 = (($base) + 644|0);
 $213 = HEAP32[$212>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($211,$213);
 $214 = HEAP8[$base>>0]|0;
 $215 = $214 & 1;
 $216 = ($215<<24>>24)==(0);
 if ($216) {
  ___resumeException($$03|0);
  // unreachable;
 }
 $217 = (($base) + 8|0);
 $218 = HEAP32[$217>>2]|0;
 HEAP32[$5>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$5+0>>2]|0;
 invoke_vii(2591,($218|0),($$byval_copy8|0));
 $219 = __THREW__; __THREW__ = 0;
 $220 = $219&1;
 if ($220) {
  $221 = ___cxa_find_matching_catch()|0;
  $222 = tempRet0;
  ___cxa_call_unexpected(($221|0));
  // unreachable;
 } else {
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE14__assign_multiINS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEEEvT_SF_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i2 = 0, $$0$i$i12 = 0, $$0$i$i6 = 0, $$0$i$i9 = 0, $$0$i1$i = 0, $$01$i$i = 0, $$01$i$i4 = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__cache$0$ph = 0, $__cache$021 = 0, $__cache$1$lcssa = 0, $__cache$2$lcssa = 0, $__nd$0$in$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = HEAP32[$this>>2]|0;
   $5 = (($this) + 4|0);
   HEAP32[$this>>2] = $5;
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 8|0);
   HEAP32[$7>>2] = 0;
   HEAP32[$5>>2] = 0;
   HEAP32[$1>>2] = 0;
   $8 = (($4) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $__cache$0$ph = $4;
   } else {
    $__cache$0$ph = $9;
   }
   $11 = ($__cache$0$ph|0)==(0|0);
   if (!($11)) {
    $12 = (($this) + 4|0);
    $$pre = HEAP32[$__first>>2]|0;
    $15 = $$pre;$__cache$021 = $__cache$0$ph;
    while(1) {
     $13 = HEAP32[$__last>>2]|0;
     $14 = ($15|0)==($13|0);
     if ($14) {
      label = 7;
      break;
     }
     $19 = (($__cache$021) + 16|0);
     $20 = (($15) + 16|0);
     __THREW__ = 0;
     (invoke_iii(2359,($19|0),($20|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     $23 = (($__cache$021) + 28|0);
     $24 = (($15) + 28|0);
     __THREW__ = 0;
     (invoke_iii(2359,($23|0),($24|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = (($__cache$021) + 40|0);
     $28 = (($15) + 40|0);
     __THREW__ = 0;
     (invoke_iii(2359,($27|0),($28|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     $31 = (($__cache$021) + 52|0);
     $32 = (($15) + 52|0);
     ;HEAP32[$31+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$31+4>>2]=HEAP32[$32+4>>2]|0;HEAP16[$31+8>>1]=HEAP16[$32+8>>1]|0;
     $33 = (($__cache$021) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     do {
      if ($35) {
       $$0$i = 0;
      } else {
       $36 = HEAP32[$34>>2]|0;
       $37 = ($36|0)==($__cache$021|0);
       if ($37) {
        HEAP32[$34>>2] = 0;
        $38 = HEAP32[$33>>2]|0;
        $39 = (($38) + 4|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = ($40|0)==(0|0);
        if ($41) {
         $$0$i = $38;
         break;
        } else {
         $$0$i1$i = $40;
        }
        while(1) {
         $42 = HEAP32[$$0$i1$i>>2]|0;
         $43 = ($42|0)==(0|0);
         if (!($43)) {
          $$0$i1$i = $42;
          continue;
         }
         $44 = (($$0$i1$i) + 4|0);
         $45 = HEAP32[$44>>2]|0;
         $46 = ($45|0)==(0|0);
         if ($46) {
          break;
         } else {
          $$0$i1$i = $45;
         }
        }
        $$0$i = $$0$i1$i;
        break;
       } else {
        $47 = (($34) + 4|0);
        HEAP32[$47>>2] = 0;
        $48 = HEAP32[$33>>2]|0;
        $49 = HEAP32[$48>>2]|0;
        $50 = ($49|0)==(0|0);
        if ($50) {
         $$0$i = $48;
         break;
        } else {
         $$0$i$i12 = $49;
        }
        while(1) {
         $51 = HEAP32[$$0$i$i12>>2]|0;
         $52 = ($51|0)==(0|0);
         if (!($52)) {
          $$0$i$i12 = $51;
          continue;
         }
         $53 = (($$0$i$i12) + 4|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = ($54|0)==(0|0);
         if ($55) {
          break;
         } else {
          $$0$i$i12 = $54;
         }
        }
        $$0$i = $$0$i$i12;
        break;
       }
      }
     } while(0);
     $56 = HEAP32[$12>>2]|0;
     $57 = ($56|0)==(0|0);
     if ($57) {
      $$0$i$i9 = $5;$66 = $5;
     } else {
      $__nd$0$in$i$i = $56;
      while(1) {
       $58 = (($__nd$0$in$i$i) + 16|0);
       $59 = (__ZNK12ShaderErrors11ShaderErrorltERKS0_($19,$58)|0);
       if ($59) {
        $60 = HEAP32[$__nd$0$in$i$i>>2]|0;
        $61 = ($60|0)==(0|0);
        if ($61) {
         $$0$i$i9 = $__nd$0$in$i$i;$66 = $__nd$0$in$i$i;
         break;
        } else {
         $__nd$0$in$i$i = $60;
         continue;
        }
       } else {
        $62 = (($__nd$0$in$i$i) + 4|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = ($63|0)==(0|0);
        if ($64) {
         $$0$i$i9 = $62;$66 = $__nd$0$in$i$i;
         break;
        } else {
         $__nd$0$in$i$i = $63;
         continue;
        }
       }
      }
     }
     HEAP32[$__cache$021>>2] = 0;
     $65 = (($__cache$021) + 4|0);
     HEAP32[$65>>2] = 0;
     HEAP32[$33>>2] = $66;
     HEAP32[$$0$i$i9>>2] = $__cache$021;
     $67 = HEAP32[$this>>2]|0;
     $68 = HEAP32[$67>>2]|0;
     $69 = ($68|0)==(0|0);
     if ($69) {
      $71 = $__cache$021;
     } else {
      HEAP32[$this>>2] = $68;
      $$pre$i$i = HEAP32[$$0$i$i9>>2]|0;
      $71 = $$pre$i$i;
     }
     $70 = HEAP32[$12>>2]|0;
     __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($70,$71);
     $72 = HEAP32[$1>>2]|0;
     $73 = (($72) + 1)|0;
     HEAP32[$1>>2] = $73;
     $74 = HEAP32[$__first>>2]|0;
     $75 = (($74) + 4|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==(0|0);
     if ($77) {
      $$01$i$i4 = $74;
      while(1) {
       $80 = (($$01$i$i4) + 8|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = HEAP32[$81>>2]|0;
       $83 = ($82|0)==($$01$i$i4|0);
       if ($83) {
        $$0$i$i6 = $81;
        break;
       } else {
        $$01$i$i4 = $81;
       }
      }
     } else {
      $$0$i$i$i2 = $76;
      while(1) {
       $78 = HEAP32[$$0$i$i$i2>>2]|0;
       $79 = ($78|0)==(0|0);
       if ($79) {
        $$0$i$i6 = $$0$i$i$i2;
        break;
       } else {
        $$0$i$i$i2 = $78;
       }
      }
     }
     HEAP32[$__first>>2] = $$0$i$i6;
     $84 = ($$0$i|0)==(0|0);
     if ($84) {
      break L1;
     } else {
      $15 = $$0$i$i6;$__cache$021 = $$0$i;
     }
    }
    if ((label|0) == 7) {
     $16 = (($__cache$021) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      $__cache$2$lcssa = $__cache$021;
     } else {
      $101 = $17;
      while(1) {
       $100 = (($101) + 8|0);
       $102 = HEAP32[$100>>2]|0;
       $103 = ($102|0)==(0|0);
       if ($103) {
        break;
       } else {
        $101 = $102;
       }
      }
      $__cache$2$lcssa = $101;
     }
     __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__cache$2$lcssa);
     break;
    }
    $85 = ___cxa_find_matching_catch(0|0)|0;
    $86 = tempRet0;
    (___cxa_begin_catch(($85|0))|0);
    $87 = (($__cache$021) + 8|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ($88|0)==(0|0);
    if ($89) {
     $__cache$1$lcssa = $__cache$021;
    } else {
     $91 = $88;
     while(1) {
      $90 = (($91) + 8|0);
      $92 = HEAP32[$90>>2]|0;
      $93 = ($92|0)==(0|0);
      if ($93) {
       break;
      } else {
       $91 = $92;
      }
     }
     $__cache$1$lcssa = $91;
    }
    __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($this,$__cache$1$lcssa);
    __THREW__ = 0;
    invoke_v(140);
    $98 = __THREW__; __THREW__ = 0;
    $99 = $98&1;
    if (!($99)) {
     // unreachable;
    }
    $94 = ___cxa_find_matching_catch()|0;
    $95 = tempRet0;
    __THREW__ = 0;
    invoke_v(66);
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     $121 = ___cxa_find_matching_catch(0|0)|0;
     $122 = tempRet0;
     ___clang_call_terminate($121);
     // unreachable;
    } else {
     ___resumeException($94|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $104 = HEAP32[$__first>>2]|0;
 $105 = HEAP32[$__last>>2]|0;
 $106 = ($104|0)==($105|0);
 if ($106) {
  STACKTOP = sp;return;
 } else {
  $108 = $104;
 }
 while(1) {
  $107 = (($108) + 16|0);
  __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE14__insert_multiERKS2_($0,$this,$107);
  $109 = HEAP32[$__first>>2]|0;
  $110 = (($109) + 4|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(0|0);
  if ($112) {
   $$01$i$i = $109;
   while(1) {
    $115 = (($$01$i$i) + 8|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = HEAP32[$116>>2]|0;
    $118 = ($117|0)==($$01$i$i|0);
    if ($118) {
     $$0$i$i = $116;
     break;
    } else {
     $$01$i$i = $116;
    }
   }
  } else {
   $$0$i$i$i = $111;
   while(1) {
    $113 = HEAP32[$$0$i$i$i>>2]|0;
    $114 = ($113|0)==(0|0);
    if ($114) {
     $$0$i$i = $$0$i$i$i;
     break;
    } else {
     $$0$i$i$i = $113;
    }
   }
  }
  HEAP32[$__first>>2] = $$0$i$i;
  $119 = HEAP32[$__last>>2]|0;
  $120 = ($$0$i$i|0)==($119|0);
  if ($120) {
   break;
  } else {
   $108 = $$0$i$i;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE14__insert_multiERKS2_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $10 = (($this) + 4|0);
  $$0$i = $10;$20 = $10;
 } else {
  $__nd$0$in$i = $1;
  while(1) {
   $3 = (($__nd$0$in$i) + 16|0);
   $4 = (__ZNK12ShaderErrors11ShaderErrorltERKS0_($__v,$3)|0);
   if ($4) {
    $5 = HEAP32[$__nd$0$in$i>>2]|0;
    $6 = ($5|0)==(0|0);
    if ($6) {
     $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
     break;
    } else {
     $__nd$0$in$i = $5;
     continue;
    }
   } else {
    $7 = (($__nd$0$in$i) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $$0$i = $7;$20 = $__nd$0$in$i;
     break;
    } else {
     $__nd$0$in$i = $8;
     continue;
    }
   }
  }
 }
 $11 = (__Znwj(64)|0);
 $12 = (($11) + 16|0);
 __THREW__ = 0;
 invoke_vii(3264,($12|0),($__v|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  HEAP32[$11>>2] = 0;
  $18 = (($11) + 4|0);
  HEAP32[$18>>2] = 0;
  $19 = (($11) + 8|0);
  HEAP32[$19>>2] = $20;
  HEAP32[$$0$i>>2] = $11;
  $21 = HEAP32[$this>>2]|0;
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   $25 = $11;
  } else {
   HEAP32[$this>>2] = $22;
   $$pre$i = HEAP32[$$0$i>>2]|0;
   $25 = $$pre$i;
  }
  $24 = HEAP32[$0>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
  $26 = (($this) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 1)|0;
  HEAP32[$26>>2] = $28;
  HEAP32[$agg$result>>2] = $11;
  STACKTOP = sp;return;
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $17 = ($11|0)==(0|0);
 if ($17) {
  ___resumeException($15|0);
  // unreachable;
 }
 __ZdlPv($11);
 ___resumeException($15|0);
 // unreachable;
}
function __ZN9ShaderLab17ParserShaderStateC2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 HEAP32[$1>>2] = -1;
 $2 = (($this) + 20|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 24|0);
 HEAP32[$3>>2] = -1;
 $4 = (($this) + 28|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = -1;
 $6 = (($this) + 36|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 40|0);
 HEAP32[$7>>2] = -1;
 $8 = (($this) + 44|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 48|0);
 HEAP32[$9>>2] = -1;
 $10 = (($this) + 52|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 56|0);
 HEAP32[$11>>2] = -1;
 $12 = (($this) + 60|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 64|0);
 HEAP32[$13>>2] = -1;
 $14 = (($this) + 68|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($this) + 72|0);
 HEAP32[$15>>2] = -1;
 $16 = (($this) + 80|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 84|0);
 HEAP32[$17>>2] = -1;
 $18 = (($this) + 88|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 92|0);
 HEAP32[$19>>2] = -1;
 $20 = (($this) + 96|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($this) + 100|0);
 HEAP32[$21>>2] = -1;
 $22 = (($this) + 104|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 108|0);
 HEAP32[$23>>2] = -1;
 $24 = (($this) + 112|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($this) + 116|0);
 HEAP32[$25>>2] = -1;
 $26 = (($this) + 120|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 124|0);
 HEAP32[$27>>2] = -1;
 $28 = (($this) + 128|0);
 HEAPF32[$28>>2] = Math_fround(0.0);
 $29 = (($this) + 132|0);
 HEAP32[$29>>2] = -1;
 $30 = (($this) + 136|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($this) + 140|0);
 HEAP32[$31>>2] = -1;
 $32 = (($this) + 144|0);
 HEAPF32[$32>>2] = Math_fround(0.0);
 $33 = (($this) + 148|0);
 HEAP32[$33>>2] = -1;
 $34 = (($this) + 152|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($this) + 156|0);
 HEAP32[$35>>2] = -1;
 $36 = (($this) + 160|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($this) + 164|0);
 HEAP32[$37>>2] = -1;
 $38 = (($this) + 168|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($this) + 172|0);
 HEAP32[$39>>2] = -1;
 $40 = (($this) + 176|0);
 HEAP32[$40>>2] = -1;
 $41 = (($this) + 180|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($this) + 184|0);
 HEAP32[$42>>2] = -1;
 $43 = (($this) + 188|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($this) + 192|0);
 HEAP32[$44>>2] = -1;
 $45 = (($this) + 196|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($this) + 200|0);
 HEAP32[$46>>2] = -1;
 $47 = (($this) + 204|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($this) + 208|0);
 HEAP32[$48>>2] = -1;
 $49 = (($this) + 212|0);
 HEAP32[$49>>2] = -1;
 $50 = (($this) + 216|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($this) + 220|0);
 HEAP32[$51>>2] = -1;
 $52 = (($this) + 224|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($this) + 228|0);
 HEAP32[$53>>2] = -1;
 $54 = (($this) + 232|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($this) + 236|0);
 HEAP32[$55>>2] = -1;
 $56 = (($this) + 240|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($this) + 244|0);
 HEAP32[$57>>2] = -1;
 $58 = (($this) + 248|0);
 HEAP32[$58>>2] = -1;
 $59 = (($this) + 252|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($this) + 256|0);
 HEAP32[$60>>2] = -1;
 $61 = (($this) + 260|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (($this) + 264|0);
 HEAP32[$62>>2] = -1;
 $63 = (($this) + 268|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (($this) + 272|0);
 HEAP32[$64>>2] = -1;
 $65 = (($this) + 276|0);
 HEAPF32[$65>>2] = Math_fround(0.0);
 $66 = (($this) + 280|0);
 HEAP32[$66>>2] = -1;
 $67 = (($this) + 284|0);
 HEAP32[$67>>2] = -1;
 $68 = (($this) + 288|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 $69 = (($this) + 292|0);
 HEAP32[$69>>2] = -1;
 $70 = (($this) + 296|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($this) + 300|0);
 HEAP32[$71>>2] = -1;
 $72 = (($this) + 304|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($this) + 308|0);
 HEAP32[$73>>2] = -1;
 $74 = (($this) + 312|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($this) + 316|0);
 HEAP32[$75>>2] = -1;
 $76 = (($this) + 320|0);
 HEAP32[$76>>2] = -1;
 $77 = (($this) + 328|0);
 HEAPF32[$77>>2] = Math_fround(0.0);
 $78 = (($this) + 332|0);
 HEAP32[$78>>2] = -1;
 $79 = (($this) + 336|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($this) + 340|0);
 HEAP32[$80>>2] = -1;
 $81 = (($this) + 344|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 $82 = (($this) + 348|0);
 HEAP32[$82>>2] = -1;
 $83 = (($this) + 352|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($this) + 356|0);
 HEAP32[$84>>2] = -1;
 $85 = (($this) + 360|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 $86 = (($this) + 364|0);
 HEAP32[$86>>2] = -1;
 $87 = (($this) + 368|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($this) + 372|0);
 HEAP32[$88>>2] = -1;
 $89 = (($this) + 376|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 $90 = (($this) + 380|0);
 HEAP32[$90>>2] = -1;
 $91 = (($this) + 384|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($this) + 388|0);
 HEAP32[$92>>2] = -1;
 $93 = (($this) + 392|0);
 HEAPF32[$93>>2] = Math_fround(0.0);
 $94 = (($this) + 396|0);
 HEAP32[$94>>2] = -1;
 $95 = (($this) + 400|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($this) + 404|0);
 HEAP32[$96>>2] = -1;
 $97 = (($this) + 408|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 $98 = (($this) + 412|0);
 HEAP32[$98>>2] = -1;
 $99 = (($this) + 416|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = (($this) + 420|0);
 HEAP32[$100>>2] = -1;
 $101 = (($this) + 424|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = (($this) + 428|0);
 HEAP32[$102>>2] = -1;
 $103 = (($this) + 432|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($this) + 436|0);
 HEAP32[$104>>2] = -1;
 $105 = (($this) + 440|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = (($this) + 444|0);
 HEAP32[$106>>2] = -1;
 $107 = (($this) + 448|0);
 HEAPF32[$107>>2] = Math_fround(0.0);
 $108 = (($this) + 452|0);
 HEAP32[$108>>2] = -1;
 $109 = (($this) + 456|0);
 HEAPF32[$109>>2] = Math_fround(0.0);
 $110 = (($this) + 460|0);
 HEAP32[$110>>2] = -1;
 $111 = (($this) + 464|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = (($this) + 468|0);
 HEAP32[$112>>2] = -1;
 $113 = (($this) + 472|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = (($this) + 476|0);
 HEAP32[$114>>2] = -1;
 $115 = (($this) + 480|0);
 HEAPF32[$115>>2] = Math_fround(0.0);
 $116 = (($this) + 484|0);
 HEAP32[$116>>2] = -1;
 $117 = (($this) + 488|0);
 HEAPF32[$117>>2] = Math_fround(0.0);
 $118 = (($this) + 492|0);
 HEAP32[$118>>2] = -1;
 $119 = (($this) + 496|0);
 HEAPF32[$119>>2] = Math_fround(0.0);
 $120 = (($this) + 500|0);
 HEAP32[$120>>2] = -1;
 $121 = (($this) + 504|0);
 HEAP32[$121>>2] = -1;
 $122 = (($this) + 520|0);
 __THREW__ = 0;
 invoke_vi(3575,($122|0));
 $123 = __THREW__; __THREW__ = 0;
 $124 = $123&1;
 if (!($124)) {
  $125 = (($this) + 644|0);
  HEAP32[$125>>2] = 0;
  $126 = (($this) + 648|0);
  HEAP32[$126>>2] = 0;
  $127 = (($this) + 644|0);
  $128 = (($this) + 640|0);
  HEAP32[$128>>2] = $127;
  STACKTOP = sp;return;
 }
 $129 = ___cxa_find_matching_catch()|0;
 $130 = tempRet0;
 $131 = HEAP8[$this>>0]|0;
 $132 = $131 & 1;
 $133 = ($132<<24>>24)==(0);
 if ($133) {
  ___resumeException($129|0);
  // unreachable;
 }
 $134 = (($this) + 8|0);
 $135 = HEAP32[$134>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($135|0),($$byval_copy|0));
 $136 = __THREW__; __THREW__ = 0;
 $137 = $136&1;
 if ($137) {
  $138 = ___cxa_find_matching_catch()|0;
  $139 = tempRet0;
  ___cxa_call_unexpected(($138|0));
  // unreachable;
 } else {
  ___resumeException($129|0);
  // unreachable;
 }
}
function __ZN9ShaderLab11ShaderStateC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 61;
 $3 = (($this) + 16|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = -1;
 $5 = (($this) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = -1;
 $7 = (($this) + 32|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = -1;
 $9 = (($this) + 40|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = -1;
 $11 = (($this) + 48|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = -1;
 $13 = (($this) + 56|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($this) + 60|0);
 HEAP32[$14>>2] = -1;
 $15 = (($this) + 64|0);
 HEAP32[$15>>2] = -1;
 $16 = (($this) + 68|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = -1;
 $18 = (($this) + 76|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 80|0);
 HEAP32[$19>>2] = -1;
 $20 = (($this) + 84|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = -1;
 $22 = (($this) + 92|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 96|0);
 HEAP32[$23>>2] = -1;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = -1;
 $25 = (($this) + 104|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($this) + 108|0);
 HEAP32[$26>>2] = -1;
 $27 = (($this) + 112|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 116|0);
 HEAP32[$28>>2] = -1;
 $29 = (($this) + 120|0);
 HEAPF32[$29>>2] = Math_fround(0.0);
 $30 = (($this) + 124|0);
 HEAP32[$30>>2] = -1;
 $31 = (($this) + 128|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($this) + 132|0);
 HEAP32[$32>>2] = -1;
 $33 = (($this) + 136|0);
 HEAP32[$33>>2] = -1;
 $34 = (($this) + 140|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($this) + 144|0);
 HEAP32[$35>>2] = -1;
 $36 = (($this) + 148|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($this) + 152|0);
 HEAP32[$37>>2] = -1;
 $38 = (($this) + 156|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($this) + 160|0);
 HEAP32[$39>>2] = -1;
 $40 = (($this) + 164|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($this) + 168|0);
 HEAP32[$41>>2] = -1;
 $42 = (($this) + 172|0);
 HEAP32[$42>>2] = -1;
 $43 = (($this) + 176|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($this) + 180|0);
 HEAP32[$44>>2] = -1;
 $45 = (($this) + 184|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($this) + 188|0);
 HEAP32[$46>>2] = -1;
 $47 = (($this) + 192|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($this) + 196|0);
 HEAP32[$48>>2] = -1;
 $49 = (($this) + 200|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($this) + 204|0);
 HEAP32[$50>>2] = -1;
 $51 = (($this) + 208|0);
 HEAP32[$51>>2] = -1;
 $52 = (($this) + 212|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($this) + 216|0);
 HEAP32[$53>>2] = -1;
 $54 = (($this) + 224|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($this) + 228|0);
 HEAP32[$55>>2] = -1;
 $56 = (($this) + 232|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($this) + 236|0);
 HEAP32[$57>>2] = -1;
 $58 = (($this) + 240|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($this) + 244|0);
 HEAP32[$59>>2] = -1;
 $60 = (($this) + 248|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($this) + 252|0);
 HEAP32[$61>>2] = -1;
 $62 = (($this) + 256|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($this) + 260|0);
 HEAP32[$63>>2] = -1;
 $64 = (($this) + 264|0);
 HEAPF32[$64>>2] = Math_fround(0.0);
 $65 = (($this) + 268|0);
 HEAP32[$65>>2] = -1;
 $66 = (($this) + 272|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($this) + 276|0);
 HEAP32[$67>>2] = -1;
 $68 = (($this) + 280|0);
 HEAP32[$68>>2] = -1;
 $69 = (($this) + 316|0);
 HEAP32[$69>>2] = 0;
 $70 = (($this) + 324|0);
 HEAP32[$70>>2] = 0;
 $71 = (($this) + 328|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 320|0);
 HEAP32[$72>>2] = 61;
 $73 = (($this) + 332|0);
 HEAP8[$73>>0] = 0;
 $74 = (($this) + 336|0);
 HEAP32[$74>>2] = 0;
 $75 = (($this) + 344|0);
 HEAP32[$75>>2] = 0;
 $76 = (($this) + 348|0);
 HEAP32[$76>>2] = 0;
 $77 = (($this) + 340|0);
 HEAP32[$77>>2] = 61;
 $78 = (($this) + 352|0);
 HEAP8[$78>>0] = 0;
 $79 = (($this) + 356|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($this) + 360|0);
 HEAP32[$80>>2] = -1;
 $81 = (($this) + 364|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 $82 = (($this) + 368|0);
 HEAP32[$82>>2] = -1;
 $83 = (($this) + 372|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = (($this) + 376|0);
 HEAP32[$84>>2] = -1;
 $85 = (($this) + 380|0);
 HEAPF32[$85>>2] = Math_fround(0.0);
 $86 = (($this) + 384|0);
 HEAP32[$86>>2] = -1;
 $87 = (($this) + 388|0);
 HEAPF32[$87>>2] = Math_fround(0.0);
 $88 = (($this) + 392|0);
 HEAP32[$88>>2] = -1;
 $89 = (($this) + 396|0);
 HEAPF32[$89>>2] = Math_fround(0.0);
 $90 = (($this) + 400|0);
 HEAP32[$90>>2] = -1;
 $91 = (($this) + 404|0);
 HEAPF32[$91>>2] = Math_fround(0.0);
 $92 = (($this) + 408|0);
 HEAP32[$92>>2] = -1;
 $93 = (($this) + 412|0);
 HEAPF32[$93>>2] = Math_fround(0.0);
 $94 = (($this) + 416|0);
 HEAP32[$94>>2] = -1;
 $95 = (($this) + 420|0);
 HEAPF32[$95>>2] = Math_fround(0.0);
 $96 = (($this) + 424|0);
 HEAP32[$96>>2] = -1;
 $97 = (($this) + 428|0);
 HEAPF32[$97>>2] = Math_fround(0.0);
 $98 = (($this) + 432|0);
 HEAP32[$98>>2] = -1;
 $99 = (($this) + 436|0);
 HEAPF32[$99>>2] = Math_fround(0.0);
 $100 = (($this) + 440|0);
 HEAP32[$100>>2] = -1;
 $101 = (($this) + 444|0);
 HEAPF32[$101>>2] = Math_fround(0.0);
 $102 = (($this) + 448|0);
 HEAP32[$102>>2] = -1;
 $103 = (($this) + 452|0);
 HEAPF32[$103>>2] = Math_fround(0.0);
 $104 = (($this) + 456|0);
 HEAP32[$104>>2] = -1;
 $105 = (($this) + 460|0);
 HEAPF32[$105>>2] = Math_fround(0.0);
 $106 = (($this) + 464|0);
 HEAP32[$106>>2] = -1;
 $107 = (($this) + 468|0);
 $108 = (($this) + 472|0);
 $109 = (($this) + 476|0);
 $110 = (($this) + 480|0);
 $111 = (($this) + 484|0);
 $112 = (($this) + 488|0);
 $113 = (($this) + 492|0);
 $114 = (($this) + 496|0);
 $115 = (($this) + 500|0);
 $116 = (($this) + 504|0);
 $117 = (($this) + 508|0);
 $118 = (($this) + 512|0);
 HEAP32[$112>>2] = -1;
 HEAPF32[$111>>2] = Math_fround(8.0);
 HEAP32[$114>>2] = -1;
 HEAPF32[$113>>2] = Math_fround(0.0);
 HEAP32[$116>>2] = -1;
 HEAPF32[$115>>2] = Math_fround(0.0);
 HEAP32[$118>>2] = -1;
 HEAPF32[$117>>2] = Math_fround(0.0);
 $119 = (($this) + 516|0);
 $120 = (($this) + 520|0);
 $121 = (($this) + 524|0);
 $122 = (($this) + 528|0);
 $123 = (($this) + 532|0);
 $124 = (($this) + 536|0);
 $125 = (($this) + 540|0);
 $126 = (($this) + 544|0);
 HEAP32[$120>>2] = -1;
 HEAPF32[$119>>2] = Math_fround(8.0);
 HEAP32[$122>>2] = -1;
 HEAPF32[$121>>2] = Math_fround(0.0);
 HEAP32[$124>>2] = -1;
 HEAPF32[$123>>2] = Math_fround(0.0);
 HEAP32[$126>>2] = -1;
 HEAPF32[$125>>2] = Math_fround(0.0);
 $127 = (($this) + 548|0);
 $128 = (($this) + 552|0);
 $129 = (($this) + 556|0);
 $130 = (($this) + 560|0);
 $131 = (($this) + 564|0);
 $132 = (($this) + 568|0);
 $133 = (($this) + 572|0);
 $134 = (($this) + 576|0);
 HEAP32[$128>>2] = -1;
 HEAPF32[$127>>2] = Math_fround(8.0);
 HEAP32[$130>>2] = -1;
 HEAPF32[$129>>2] = Math_fround(0.0);
 HEAP32[$132>>2] = -1;
 HEAPF32[$131>>2] = Math_fround(0.0);
 HEAP32[$134>>2] = -1;
 HEAPF32[$133>>2] = Math_fround(0.0);
 HEAP32[$108>>2] = -1;
 HEAPF32[$107>>2] = Math_fround(255.0);
 HEAP32[$110>>2] = -1;
 HEAPF32[$109>>2] = Math_fround(255.0);
 $135 = (($this) + 580|0);
 HEAP32[$135>>2] = 0;
 $136 = (($this) + 584|0);
 HEAP32[$136>>2] = -1;
 $scevgep = (($this) + 292|0);
 ;HEAP32[$scevgep+0>>2]=0|0;HEAP32[$scevgep+4>>2]=0|0;HEAP32[$scevgep+8>>2]=0|0;HEAP32[$scevgep+12>>2]=0|0;HEAP32[$scevgep+16>>2]=0|0;HEAP32[$scevgep+20>>2]=0|0;
 HEAP32[$4>>2] = -1;
 HEAPF32[$3>>2] = Math_fround(0.0);
 HEAP32[$6>>2] = -1;
 HEAPF32[$5>>2] = Math_fround(0.0);
 $137 = (($this) + 288|0);
 HEAP32[$137>>2] = 0;
 $138 = (($this) + 220|0);
 HEAP8[$138>>0] = 0;
 HEAP32[$15>>2] = -1;
 HEAP32[$8>>2] = -1;
 HEAPF32[$7>>2] = Math_fround(0.0);
 HEAP32[$10>>2] = -1;
 HEAPF32[$9>>2] = Math_fround(0.0);
 HEAP32[$12>>2] = -1;
 HEAPF32[$11>>2] = Math_fround(0.0);
 HEAP32[$14>>2] = -1;
 HEAPF32[$13>>2] = Math_fround(1.0);
 HEAP32[$33>>2] = -1;
 HEAP32[$26>>2] = -1;
 HEAPF32[$25>>2] = Math_fround(0.0);
 HEAP32[$28>>2] = -1;
 HEAPF32[$27>>2] = Math_fround(0.0);
 HEAP32[$30>>2] = -1;
 HEAPF32[$29>>2] = Math_fround(0.0);
 HEAP32[$32>>2] = -1;
 HEAPF32[$31>>2] = Math_fround(1.0);
 HEAP32[$24>>2] = -1;
 HEAP32[$17>>2] = -1;
 HEAPF32[$16>>2] = Math_fround(0.0);
 HEAP32[$19>>2] = -1;
 HEAPF32[$18>>2] = Math_fround(0.0);
 HEAP32[$21>>2] = -1;
 HEAPF32[$20>>2] = Math_fround(0.0);
 HEAP32[$23>>2] = -1;
 HEAPF32[$22>>2] = Math_fround(1.0);
 HEAP32[$42>>2] = -1;
 HEAP32[$35>>2] = -1;
 HEAPF32[$34>>2] = Math_fround(0.0);
 HEAP32[$37>>2] = -1;
 HEAPF32[$36>>2] = Math_fround(0.0);
 HEAP32[$39>>2] = -1;
 HEAPF32[$38>>2] = Math_fround(0.0);
 HEAP32[$41>>2] = -1;
 HEAPF32[$40>>2] = Math_fround(1.0);
 HEAP32[$51>>2] = -1;
 HEAP32[$44>>2] = -1;
 HEAPF32[$43>>2] = Math_fround(0.0);
 HEAP32[$46>>2] = -1;
 HEAPF32[$45>>2] = Math_fround(0.0);
 HEAP32[$48>>2] = -1;
 HEAPF32[$47>>2] = Math_fround(0.0);
 HEAP32[$50>>2] = -1;
 HEAPF32[$49>>2] = Math_fround(1.0);
 $139 = (($this) + 221|0);
 HEAP8[$139>>0] = 0;
 HEAP32[$68>>2] = -1;
 HEAP32[$61>>2] = -1;
 HEAPF32[$60>>2] = Math_fround(0.0);
 HEAP32[$63>>2] = -1;
 HEAPF32[$62>>2] = Math_fround(0.0);
 HEAP32[$65>>2] = -1;
 HEAPF32[$64>>2] = Math_fround(0.0);
 HEAP32[$67>>2] = -1;
 HEAPF32[$66>>2] = Math_fround(0.0);
 $140 = (($this) + 284|0);
 HEAP32[$140>>2] = 0;
 HEAP32[$55>>2] = -1;
 HEAPF32[$54>>2] = Math_fround(0.0);
 HEAP32[$57>>2] = -1;
 HEAPF32[$56>>2] = Math_fround(1.0);
 HEAP32[$59>>2] = -1;
 HEAPF32[$58>>2] = Math_fround(1.0);
 HEAP32[$53>>2] = -1;
 HEAPF32[$52>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZNK9ShaderLab20ShaderBlendStateDesc15ToGfxBlendStateEPKNS_13PropertySheetERKNS_17ShaderPassContextER13GfxBlendState($this,$props,$passContext,$state) {
 $this = $this|0;
 $props = $props|0;
 $passContext = $passContext|0;
 $state = $state|0;
 var $$$i22 = 0, $$0$i = 0, $$0$i11 = 0, $$0$i20 = 0, $$0$i23 = 0, $$0$i32 = 0, $$0$i35 = 0, $$0$i44 = 0, $$0$i8 = 0, $$byval_copy8 = 0, $$in$i = 0, $$in$i14 = 0, $$in$i17 = 0, $$in$i2 = 0, $$in$i26 = 0, $$in$i29 = 0, $$in$i38 = 0, $$in$i41 = 0, $$in$i5 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0);
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $location$i$i40 = 0, $phitmp = 0, $phitmp46 = 0, $phitmp47 = 0, $phitmp48 = 0, $phitmp49 = 0;
 var $phitmp50 = 0, $phitmp51 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 8|0;
 $location$i$i40 = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 if ($3) {
  $$in$i = $this;
 } else {
  HEAP32[$0>>2] = $2;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $4 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i = $4;
 }
 $5 = Math_fround(HEAPF32[$$in$i>>2]);
 $6 = (~~(($5)));
 $7 = ($6|0)<(0);
 if ($7) {
  $$0$i = 0;
 } else {
  $8 = ($6|0)>(10);
  $9 = $6&255;
  $phitmp = $8 ? 10 : $9;
  $$0$i = $phitmp;
 }
 $10 = (($state) + 4|0);
 HEAP8[$10>>0] = $$0$i;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(-1);
 if ($13) {
  $15 = (($this) + 8|0);
  $$in$i5 = $15;
 } else {
  HEAP32[$0>>2] = $12;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $14 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i5 = $14;
 }
 $16 = Math_fround(HEAPF32[$$in$i5>>2]);
 $17 = (~~(($16)));
 $18 = ($17|0)<(0);
 if ($18) {
  $$0$i8 = 0;
 } else {
  $19 = ($17|0)>(10);
  $20 = $17&255;
  $phitmp46 = $19 ? 10 : $20;
  $$0$i8 = $phitmp46;
 }
 $21 = (($state) + 5|0);
 HEAP8[$21>>0] = $$0$i8;
 $22 = (($this) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(-1);
 if ($24) {
  $26 = (($this) + 16|0);
  $$in$i17 = $26;
 } else {
  HEAP32[$0>>2] = $23;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $25 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i17 = $25;
 }
 $27 = Math_fround(HEAPF32[$$in$i17>>2]);
 $28 = (~~(($27)));
 $29 = ($28|0)<(0);
 if ($29) {
  $$0$i20 = 0;
 } else {
  $30 = ($28|0)>(10);
  $31 = $28&255;
  $phitmp47 = $30 ? 10 : $31;
  $$0$i20 = $phitmp47;
 }
 $32 = (($state) + 6|0);
 HEAP8[$32>>0] = $$0$i20;
 $33 = (($this) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $37 = (($this) + 24|0);
  $$in$i29 = $37;
 } else {
  HEAP32[$0>>2] = $34;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $36 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i29 = $36;
 }
 $38 = Math_fround(HEAPF32[$$in$i29>>2]);
 $39 = (~~(($38)));
 $40 = ($39|0)<(0);
 if ($40) {
  $$0$i32 = 0;
 } else {
  $41 = ($39|0)>(10);
  $42 = $39&255;
  $phitmp48 = $41 ? 10 : $42;
  $$0$i32 = $phitmp48;
 }
 $43 = (($state) + 7|0);
 HEAP8[$43>>0] = $$0$i32;
 $44 = (($this) + 36|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(-1);
 if ($46) {
  $48 = (($this) + 32|0);
  $$in$i41 = $48;
 } else {
  HEAP32[$0>>2] = $45;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $47 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i41 = $47;
 }
 $49 = Math_fround(HEAPF32[$$in$i41>>2]);
 $50 = (~~(($49)));
 $51 = ($50|0)<(0);
 if ($51) {
  $$0$i44 = 0;
 } else {
  $52 = ($50|0)>(20);
  $53 = $50&255;
  $phitmp49 = $52 ? 20 : $53;
  $$0$i44 = $phitmp49;
 }
 $54 = (($state) + 8|0);
 HEAP8[$54>>0] = $$0$i44;
 $55 = (($this) + 44|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(-1);
 if ($57) {
  $59 = (($this) + 40|0);
  $$in$i38 = $59;
 } else {
  HEAP32[$0>>2] = $56;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $58 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i38 = $58;
 }
 $60 = Math_fround(HEAPF32[$$in$i38>>2]);
 $61 = (~~(($60)));
 $62 = ($61|0)<(0);
 if ($62) {
  $$0$i35 = 0;
 } else {
  $63 = ($61|0)>(20);
  $64 = $61&255;
  $phitmp50 = $63 ? 20 : $64;
  $$0$i35 = $phitmp50;
 }
 $65 = (($state) + 9|0);
 HEAP8[$65>>0] = $$0$i35;
 $66 = (($this) + 52|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(-1);
 if ($68) {
  $70 = (($this) + 48|0);
  $$in$i26 = $70;
 } else {
  HEAP32[$0>>2] = $67;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $69 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i26 = $69;
 }
 $71 = Math_fround(HEAPF32[$$in$i26>>2]);
 $72 = (~~(($71)));
 $73 = ($72|0)<(0);
 if ($73) {
  $$0$i23 = 0;
 } else {
  $74 = ($72|0)>(15);
  $$$i22 = $74 ? 15 : $72;
  $$0$i23 = $$$i22;
 }
 HEAP32[$state>>2] = $$0$i23;
 $75 = (($this) + 60|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(-1);
 if ($77) {
  $79 = (($this) + 56|0);
  $$in$i14 = $79;
 } else {
  HEAP32[$0>>2] = $76;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $78 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i14 = $78;
 }
 $80 = Math_fround(HEAPF32[$$in$i14>>2]);
 $81 = (~~(($80)));
 $82 = ($81|0)<(0);
 if ($82) {
  $$0$i11 = 0;
 } else {
  $83 = ($81|0)>(8);
  $84 = $81&255;
  $phitmp51 = $83 ? 8 : $84;
  $$0$i11 = $phitmp51;
 }
 $85 = (($state) + 10|0);
 HEAP8[$85>>0] = $$0$i11;
 $86 = (($this) + 68|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(-1);
 if ($88) {
  $90 = (($this) + 64|0);
  $$in$i2 = $90;
  $91 = Math_fround(HEAPF32[$$in$i2>>2]);
  $92 = $91 != Math_fround(0.0);
  $93 = (($state) + 11|0);
  $94 = $92&1;
  HEAP8[$93>>0] = $94;
  STACKTOP = sp;return;
 } else {
  HEAP32[$0>>2] = $87;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  $89 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy8,$location$i$i40)|0);
  $$in$i2 = $89;
  $91 = Math_fround(HEAPF32[$$in$i2>>2]);
  $92 = $91 != Math_fround(0.0);
  $93 = (($state) + 11|0);
  $94 = $92&1;
  HEAP8[$93>>0] = $94;
  STACKTOP = sp;return;
 }
}
function __ZNK9ShaderLab21ShaderRasterStateDesc16ToGfxRasterStateEPKNS_13PropertySheetERKNS_17ShaderPassContextER14GfxRasterState($this,$props,$passContext,$state) {
 $this = $this|0;
 $props = $props|0;
 $passContext = $passContext|0;
 $state = $state|0;
 var $$$i = 0, $$0$i = 0, $$byval_copy2 = 0, $$in$i = 0, $$in$i2 = 0, $$in$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = Math_fround(0), $23 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $location$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $location$i$i4 = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 if ($3) {
  $$in$i = $this;
 } else {
  HEAP32[$0>>2] = $2;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $4 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy2,$location$i$i4)|0);
  $$in$i = $4;
 }
 $5 = Math_fround(HEAPF32[$$in$i>>2]);
 $6 = (~~(($5)));
 $7 = ($6|0)<(0);
 if ($7) {
  $$0$i = 0;
 } else {
  $8 = ($6|0)>(2);
  $$$i = $8 ? 2 : $6;
  $$0$i = $$$i;
 }
 HEAP32[$state>>2] = $$0$i;
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(-1);
 if ($11) {
  $13 = (($this) + 8|0);
  $$in$i5 = $13;
 } else {
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $12 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy2,$location$i$i4)|0);
  $$in$i5 = $12;
 }
 $14 = Math_fround(HEAPF32[$$in$i5>>2]);
 $15 = (~~(($14)));
 $16 = (($state) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(-1);
 if ($19) {
  $21 = (($this) + 16|0);
  $$in$i2 = $21;
  $22 = Math_fround(HEAPF32[$$in$i2>>2]);
  $23 = (($state) + 8|0);
  HEAPF32[$23>>2] = $22;
  STACKTOP = sp;return;
 } else {
  HEAP32[$0>>2] = $18;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy2,$location$i$i4)|0);
  $$in$i2 = $20;
  $22 = Math_fround(HEAPF32[$$in$i2>>2]);
  $23 = (($state) + 8|0);
  HEAPF32[$23>>2] = $22;
  STACKTOP = sp;return;
 }
}
function __ZNK9ShaderLab22ShaderStencilStateDesc17ToGfxStencilStateEPKNS_13PropertySheetERKNS_17ShaderPassContextERK14GfxRasterStateR15GfxStencilState($this,$props,$passContext,$raster,$state) {
 $this = $this|0;
 $props = $props|0;
 $passContext = $passContext|0;
 $raster = $raster|0;
 $state = $state|0;
 var $$0$i = 0, $$0$i18 = 0, $$0$i21 = 0, $$0$i30 = 0, $$0$i33 = 0, $$0$i42 = 0, $$0$i46 = 0, $$0$i9 = 0, $$byval_copy9 = 0, $$in$i = 0, $$in$i12 = 0, $$in$i15 = 0, $$in$i2 = 0, $$in$i24 = 0, $$in$i27 = 0, $$in$i36 = 0, $$in$i39 = 0, $$in$i49 = 0, $$in$i5 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0;
 var $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $location$i$i48 = 0, $opBackPtr$0 = 0, $opFrontPtr$0 = 0, $phitmp = 0, $phitmp51 = 0, $phitmp52 = 0, $phitmp53 = 0, $phitmp54 = 0;
 var $phitmp55 = 0, $phitmp56 = 0, $phitmp57 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy9 = sp + 8|0;
 $location$i$i48 = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(-1);
 if ($3) {
  $$in$i = $this;
 } else {
  HEAP32[$0>>2] = $2;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  $4 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
  $$in$i = $4;
 }
 $5 = Math_fround(HEAPF32[$$in$i>>2]);
 $6 = (~~(($5))&255);
 $7 = (($state) + 1|0);
 HEAP8[$7>>0] = $6;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(-1);
 if ($10) {
  $12 = (($this) + 8|0);
  $$in$i2 = $12;
 } else {
  HEAP32[$0>>2] = $9;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  $11 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
  $$in$i2 = $11;
 }
 $13 = Math_fround(HEAPF32[$$in$i2>>2]);
 $14 = (~~(($13))&255);
 $15 = (($state) + 2|0);
 HEAP8[$15>>0] = $14;
 $16 = (($this) + 48|0);
 $17 = (($this) + 80|0);
 $18 = (($this) + 16|0);
 $19 = (($this) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(-1);
 if ($21) {
  $22 = (($this) + 24|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = $23 == Math_fround(0.0);
  if ($24) {
   $25 = (($this) + 36|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(-1);
   if ($27) {
    $28 = (($this) + 32|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = $29 == Math_fround(0.0);
    if ($30) {
     $31 = (($this) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(-1);
     if ($33) {
      $34 = (($this) + 40|0);
      $35 = Math_fround(HEAPF32[$34>>2]);
      $36 = $35 == Math_fround(0.0);
      if ($36) {
       $37 = (($this) + 20|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = ($38|0)==(-1);
       if ($39) {
        $40 = Math_fround(HEAPF32[$18>>2]);
        $41 = $40 == Math_fround(8.0);
        if ($41) {
         $opBackPtr$0 = $17;$opFrontPtr$0 = $16;
        } else {
         label = 15;
        }
       } else {
        label = 15;
       }
      } else {
       label = 15;
      }
     } else {
      label = 15;
     }
    } else {
     label = 15;
    }
   } else {
    label = 15;
   }
  } else {
   label = 15;
  }
 } else {
  label = 15;
 }
 do {
  if ((label|0) == 15) {
   $42 = HEAP32[$raster>>2]|0;
   if ((($42|0) == 0)) {
    $opBackPtr$0 = $18;$opFrontPtr$0 = $18;
    break;
   } else if ((($42|0) == 1)) {
    $opBackPtr$0 = $18;$opFrontPtr$0 = $16;
    break;
   } else {
    $opBackPtr$0 = $17;$opFrontPtr$0 = $18;
    break;
   }
  }
 } while(0);
 $43 = (($opFrontPtr$0) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(-1);
 if ($45) {
  $46 = (($opFrontPtr$0) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = $47 == Math_fround(0.0);
  if ($48) {
   $49 = (($opFrontPtr$0) + 20|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(-1);
   if ($51) {
    $52 = (($opFrontPtr$0) + 16|0);
    $53 = Math_fround(HEAPF32[$52>>2]);
    $54 = $53 == Math_fround(0.0);
    if ($54) {
     $55 = (($opFrontPtr$0) + 28|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($56|0)==(-1);
     if ($57) {
      $58 = (($opFrontPtr$0) + 24|0);
      $59 = Math_fround(HEAPF32[$58>>2]);
      $60 = $59 == Math_fround(0.0);
      if ($60) {
       $61 = (($opFrontPtr$0) + 4|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = ($62|0)==(-1);
       if ($63) {
        $64 = Math_fround(HEAPF32[$opFrontPtr$0>>2]);
        $65 = $64 == Math_fround(8.0);
        if (!($65)) {
         label = 26;
        }
       } else {
        label = 26;
       }
      } else {
       label = 26;
      }
     } else {
      label = 26;
     }
    } else {
     label = 26;
    }
   } else {
    label = 26;
   }
  } else {
   label = 26;
  }
 } else {
  label = 26;
 }
 if ((label|0) == 26) {
  $66 = (($opFrontPtr$0) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(-1);
  if ($68) {
   $$in$i15 = $opFrontPtr$0;
  } else {
   HEAP32[$0>>2] = $67;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
   $69 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
   $$in$i15 = $69;
  }
  $70 = Math_fround(HEAPF32[$$in$i15>>2]);
  $71 = (~~(($70)));
  $72 = ($71|0)<(0);
  if ($72) {
   $$0$i18 = 0;
  } else {
   $73 = ($71|0)>(8);
   $74 = $71&255;
   $phitmp = $73 ? 8 : $74;
   $$0$i18 = $phitmp;
  }
  $75 = (($state) + 4|0);
  HEAP8[$75>>0] = $$0$i18;
  $76 = HEAP32[$43>>2]|0;
  $77 = ($76|0)==(-1);
  if ($77) {
   $79 = (($opFrontPtr$0) + 8|0);
   $$in$i27 = $79;
  } else {
   HEAP32[$0>>2] = $76;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
   $78 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
   $$in$i27 = $78;
  }
  $80 = Math_fround(HEAPF32[$$in$i27>>2]);
  $81 = (~~(($80)));
  $82 = ($81|0)<(0);
  if ($82) {
   $$0$i30 = 0;
  } else {
   $83 = ($81|0)>(7);
   $84 = $81&255;
   $phitmp51 = $83 ? 7 : $84;
   $$0$i30 = $phitmp51;
  }
  $85 = (($state) + 5|0);
  HEAP8[$85>>0] = $$0$i30;
  $86 = (($opFrontPtr$0) + 20|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==(-1);
  if ($88) {
   $90 = (($opFrontPtr$0) + 16|0);
   $$in$i39 = $90;
  } else {
   HEAP32[$0>>2] = $87;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
   $89 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
   $$in$i39 = $89;
  }
  $91 = Math_fround(HEAPF32[$$in$i39>>2]);
  $92 = (~~(($91)));
  $93 = ($92|0)<(0);
  if ($93) {
   $$0$i42 = 0;
  } else {
   $94 = ($92|0)>(7);
   $95 = $92&255;
   $phitmp52 = $94 ? 7 : $95;
   $$0$i42 = $phitmp52;
  }
  $96 = (($state) + 6|0);
  HEAP8[$96>>0] = $$0$i42;
  $97 = (($opFrontPtr$0) + 28|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ($98|0)==(-1);
  if ($99) {
   $101 = (($opFrontPtr$0) + 24|0);
   $$in$i49 = $101;
  } else {
   HEAP32[$0>>2] = $98;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
   $100 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
   $$in$i49 = $100;
  }
  $102 = Math_fround(HEAPF32[$$in$i49>>2]);
  $103 = (~~(($102)));
  $104 = ($103|0)<(0);
  if ($104) {
   $$0$i46 = 0;
  } else {
   $105 = ($103|0)>(7);
   $106 = $103&255;
   $phitmp53 = $105 ? 7 : $106;
   $$0$i46 = $phitmp53;
  }
  $107 = (($state) + 7|0);
  HEAP8[$107>>0] = $$0$i46;
  HEAP8[$state>>0] = 1;
 }
 $108 = (($opBackPtr$0) + 12|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ($109|0)==(-1);
 if ($110) {
  $111 = (($opBackPtr$0) + 8|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = $112 == Math_fround(0.0);
  if ($113) {
   $114 = (($opBackPtr$0) + 20|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ($115|0)==(-1);
   if ($116) {
    $117 = (($opBackPtr$0) + 16|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = $118 == Math_fround(0.0);
    if ($119) {
     $120 = (($opBackPtr$0) + 28|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = ($121|0)==(-1);
     if ($122) {
      $123 = (($opBackPtr$0) + 24|0);
      $124 = Math_fround(HEAPF32[$123>>2]);
      $125 = $124 == Math_fround(0.0);
      if ($125) {
       $126 = (($opBackPtr$0) + 4|0);
       $127 = HEAP32[$126>>2]|0;
       $128 = ($127|0)==(-1);
       if ($128) {
        $129 = Math_fround(HEAPF32[$opBackPtr$0>>2]);
        $130 = $129 == Math_fround(8.0);
        if ($130) {
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $131 = (($opBackPtr$0) + 4|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($132|0)==(-1);
 if ($133) {
  $$in$i36 = $opBackPtr$0;
 } else {
  HEAP32[$0>>2] = $132;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  $134 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
  $$in$i36 = $134;
 }
 $135 = Math_fround(HEAPF32[$$in$i36>>2]);
 $136 = (~~(($135)));
 $137 = ($136|0)<(0);
 if ($137) {
  $$0$i33 = 0;
 } else {
  $138 = ($136|0)>(8);
  $139 = $136&255;
  $phitmp54 = $138 ? 8 : $139;
  $$0$i33 = $phitmp54;
 }
 $140 = (($state) + 8|0);
 HEAP8[$140>>0] = $$0$i33;
 $141 = HEAP32[$108>>2]|0;
 $142 = ($141|0)==(-1);
 if ($142) {
  $144 = (($opBackPtr$0) + 8|0);
  $$in$i24 = $144;
 } else {
  HEAP32[$0>>2] = $141;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  $143 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
  $$in$i24 = $143;
 }
 $145 = Math_fround(HEAPF32[$$in$i24>>2]);
 $146 = (~~(($145)));
 $147 = ($146|0)<(0);
 if ($147) {
  $$0$i21 = 0;
 } else {
  $148 = ($146|0)>(7);
  $149 = $146&255;
  $phitmp55 = $148 ? 7 : $149;
  $$0$i21 = $phitmp55;
 }
 $150 = (($state) + 9|0);
 HEAP8[$150>>0] = $$0$i21;
 $151 = (($opBackPtr$0) + 20|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = ($152|0)==(-1);
 if ($153) {
  $155 = (($opBackPtr$0) + 16|0);
  $$in$i12 = $155;
 } else {
  HEAP32[$0>>2] = $152;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  $154 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
  $$in$i12 = $154;
 }
 $156 = Math_fround(HEAPF32[$$in$i12>>2]);
 $157 = (~~(($156)));
 $158 = ($157|0)<(0);
 if ($158) {
  $$0$i9 = 0;
 } else {
  $159 = ($157|0)>(7);
  $160 = $157&255;
  $phitmp56 = $159 ? 7 : $160;
  $$0$i9 = $phitmp56;
 }
 $161 = (($state) + 10|0);
 HEAP8[$161>>0] = $$0$i9;
 $162 = (($opBackPtr$0) + 28|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = ($163|0)==(-1);
 if ($164) {
  $166 = (($opBackPtr$0) + 24|0);
  $$in$i5 = $166;
 } else {
  HEAP32[$0>>2] = $163;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  $165 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy9,$location$i$i48)|0);
  $$in$i5 = $165;
 }
 $167 = Math_fround(HEAPF32[$$in$i5>>2]);
 $168 = (~~(($167)));
 $169 = ($168|0)<(0);
 if ($169) {
  $$0$i = 0;
 } else {
  $170 = ($168|0)>(7);
  $171 = $168&255;
  $phitmp57 = $170 ? 7 : $171;
  $$0$i = $phitmp57;
 }
 $172 = (($state) + 11|0);
 HEAP8[$172>>0] = $$0$i;
 HEAP8[$state>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab11ShaderState17BuildDeviceStatesEjPKNS_13PropertySheetERKNS_17ShaderPassContextE($this,$key,$props,$passContext) {
 $this = $this|0;
 $key = $key|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$0$i$i = 0, $$byval_copy3 = 0, $$in$i$i = 0, $$in$i2$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $gfxblend = 0, $gfxdepth = 0, $gfxraster = 0, $gfxstencil = 0, $i$01 = 0, $location$i$i1$i = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 44|0;
 $location$i$i1$i = sp + 40|0;
 $0 = sp + 12|0;
 $gfxblend = sp + 16|0;
 $gfxdepth = sp + 48|0;
 $gfxraster = sp;
 $gfxstencil = sp + 28|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = HEAP32[$this>>2]|0;
   $i$01 = 0;
   while(1) {
    $7 = (($4) + (($i$01*20)|0)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==($key|0);
    $6 = (($i$01) + 1)|0;
    if ($9) {
     break;
    }
    $5 = ($6|0)==($2|0);
    if ($5) {
     break L1;
    } else {
     $i$01 = $6;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $10 = (($2) + 1)|0;
 HEAP32[$1>>2] = $10;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2147483647;
 $14 = ($10>>>0)>($13>>>0);
 if ($14) {
  $15 = $12 << 1;
  $16 = ($15|0)==(0);
  $17 = $16 ? 1 : $15;
  $18 = ($13>>>0)<($17>>>0);
  do {
   if ($18) {
    $19 = ($12|0)>(-1);
    if ($19) {
     HEAP32[$11>>2] = $17;
     $20 = HEAP32[$this>>2]|0;
     $21 = ($17*20)|0;
     $22 = (($this) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$location$i$i1$i>>2] = $23;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$location$i$i1$i+0>>2]|0;
     $24 = (__Z16realloc_internalPvji10MemLabelIdiPKci($20,$21,4,$$byval_copy3,0,679600,370)|0);
     HEAP32[$this>>2] = $24;
     break;
    } else {
     $25 = ($17*20)|0;
     $26 = (($this) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$location$i$i1$i>>2] = $27;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$location$i$i1$i+0>>2]|0;
     $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,4,$$byval_copy3,0,679600,352)|0);
     $29 = HEAP32[$this>>2]|0;
     $30 = HEAP32[$1>>2]|0;
     $31 = ($30*20)|0;
     _memcpy(($28|0),($29|0),($31|0))|0;
     HEAP32[$11>>2] = $17;
     HEAP32[$this>>2] = $28;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$1>>2]|0;
  $33 = $$pre$i;
 } else {
  $33 = $10;
 }
 $32 = (($33) + -1)|0;
 $34 = HEAP32[$this>>2]|0;
 $35 = (($34) + (($32*20)|0)|0);
 HEAP32[$35>>2] = $key;
 $36 = (__Z12GetGfxDevicev()|0);
 HEAP32[$gfxblend>>2] = 15;
 $37 = (($gfxblend) + 4|0);
 HEAP8[$37>>0] = 1;
 $38 = (($gfxblend) + 5|0);
 HEAP8[$38>>0] = 0;
 $39 = (($gfxblend) + 6|0);
 HEAP8[$39>>0] = 1;
 $40 = (($gfxblend) + 7|0);
 ;HEAP8[$40+0>>0]=0|0;HEAP8[$40+1>>0]=0|0;HEAP8[$40+2>>0]=0|0;HEAP8[$40+3>>0]=0|0;HEAP8[$40+4>>0]=0|0;
 $41 = (($this) + 356|0);
 __ZNK9ShaderLab20ShaderBlendStateDesc15ToGfxBlendStateEPKNS_13PropertySheetERKNS_17ShaderPassContextER13GfxBlendState($41,$props,$passContext,$gfxblend);
 HEAP8[$gfxdepth>>0] = 1;
 $42 = (($gfxdepth) + 1|0);
 HEAP8[$42>>0] = 2;
 $43 = (($this) + 432|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(-1);
 if ($45) {
  $47 = (($this) + 428|0);
  $$in$i$i = $47;
 } else {
  HEAP32[$0>>2] = $44;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $46 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy3,$location$i$i1$i)|0);
  $$in$i$i = $46;
 }
 $48 = Math_fround(HEAPF32[$$in$i$i>>2]);
 $49 = $48 != Math_fround(0.0);
 $50 = $49&1;
 HEAP8[$gfxdepth>>0] = $50;
 $51 = (($this) + 440|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(-1);
 if ($53) {
  $55 = (($this) + 436|0);
  $$in$i2$i = $55;
 } else {
  HEAP32[$0>>2] = $52;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $54 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy3,$location$i$i1$i)|0);
  $$in$i2$i = $54;
 }
 $56 = Math_fround(HEAPF32[$$in$i2$i>>2]);
 $57 = (~~(($56)));
 $58 = ($57|0)<(0);
 if ($58) {
  $$0$i$i = 0;
 } else {
  $59 = ($57|0)>(8);
  $60 = $57&255;
  $phitmp$i = $59 ? 8 : $60;
  $$0$i$i = $phitmp$i;
 }
 HEAP8[$42>>0] = $$0$i$i;
 $61 = $gfxraster;
 $62 = $61;
 HEAP32[$62>>2] = 0;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = 0;
 HEAP32[$gfxraster>>2] = 2;
 $65 = (($gfxraster) + 4|0);
 HEAP32[$65>>2] = 0;
 $66 = (($gfxraster) + 8|0);
 HEAPF32[$66>>2] = Math_fround(0.0);
 $67 = (($this) + 444|0);
 __ZNK9ShaderLab21ShaderRasterStateDesc16ToGfxRasterStateEPKNS_13PropertySheetERKNS_17ShaderPassContextER14GfxRasterState($67,$props,$passContext,$gfxraster);
 HEAP8[$gfxstencil>>0] = 0;
 $68 = (($gfxstencil) + 1|0);
 HEAP8[$68>>0] = -1;
 $69 = (($gfxstencil) + 2|0);
 HEAP8[$69>>0] = -1;
 $70 = (($gfxstencil) + 4|0);
 HEAP8[$70>>0] = 8;
 $71 = (($gfxstencil) + 5|0);
 HEAP8[$71>>0] = 0;
 $72 = (($gfxstencil) + 6|0);
 HEAP8[$72>>0] = 0;
 $73 = (($gfxstencil) + 7|0);
 HEAP8[$73>>0] = 0;
 $74 = (($gfxstencil) + 8|0);
 HEAP8[$74>>0] = 8;
 $75 = (($gfxstencil) + 9|0);
 HEAP8[$75>>0] = 0;
 $76 = (($gfxstencil) + 10|0);
 HEAP8[$76>>0] = 0;
 $77 = (($gfxstencil) + 11|0);
 HEAP8[$77>>0] = 0;
 $78 = (($this) + 468|0);
 __ZNK9ShaderLab22ShaderStencilStateDesc17ToGfxStencilStateEPKNS_13PropertySheetERKNS_17ShaderPassContextERK14GfxRasterStateR15GfxStencilState($78,$props,$passContext,$gfxraster,$gfxstencil);
 $79 = HEAP32[$36>>2]|0;
 $80 = (($79) + 32|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (FUNCTION_TABLE_iii[$81 & 4095]($36,$gfxblend)|0);
 $83 = ((($34) + (($32*20)|0)|0) + 4|0);
 HEAP32[$83>>2] = $82;
 $84 = HEAP32[$36>>2]|0;
 $85 = (($84) + 36|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (FUNCTION_TABLE_iii[$86 & 4095]($36,$gfxdepth)|0);
 $88 = ((($34) + (($32*20)|0)|0) + 8|0);
 HEAP32[$88>>2] = $87;
 $89 = HEAP32[$36>>2]|0;
 $90 = (($89) + 44|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (FUNCTION_TABLE_iii[$91 & 4095]($36,$gfxraster)|0);
 $93 = ((($34) + (($32*20)|0)|0) + 12|0);
 HEAP32[$93>>2] = $92;
 $94 = HEAP32[$36>>2]|0;
 $95 = (($94) + 40|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (FUNCTION_TABLE_iii[$96 & 4095]($36,$gfxstencil)|0);
 $98 = ((($34) + (($32*20)|0)|0) + 16|0);
 HEAP32[$98>>2] = $97;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab11ShaderState29FindPropsAffectingStateBlocksERKNS_13PropertySheetER13dynamic_arrayIiLj4EE($this,$shaderProps,$outProps) {
 $this = $this|0;
 $shaderProps = $shaderProps|0;
 $outProps = $outProps|0;
 var $$0$lcssa$i = 0, $$01$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 336|0);
 $2 = (($this) + 344|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 352|0);
 HEAP8[$3>>0] = 0;
 $4 = (($this) + 412|0);
 $5 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$4)|0);
 $6 = $5&1;
 $7 = HEAP8[$3>>0]|0;
 $8 = $7&255;
 $9 = $8 | $6;
 $10 = $9&255;
 HEAP8[$3>>0] = $10;
 $11 = (($this) + 356|0);
 $12 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$11)|0);
 $13 = $12&1;
 $14 = HEAP8[$3>>0]|0;
 $15 = $14&255;
 $16 = $15 | $13;
 $17 = $16&255;
 HEAP8[$3>>0] = $17;
 $18 = (($this) + 364|0);
 $19 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$18)|0);
 $20 = $19&1;
 $21 = HEAP8[$3>>0]|0;
 $22 = $21&255;
 $23 = $22 | $20;
 $24 = $23&255;
 HEAP8[$3>>0] = $24;
 $25 = (($this) + 372|0);
 $26 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$25)|0);
 $27 = $26&1;
 $28 = HEAP8[$3>>0]|0;
 $29 = $28&255;
 $30 = $29 | $27;
 $31 = $30&255;
 HEAP8[$3>>0] = $31;
 $32 = (($this) + 380|0);
 $33 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$32)|0);
 $34 = $33&1;
 $35 = HEAP8[$3>>0]|0;
 $36 = $35&255;
 $37 = $36 | $34;
 $38 = $37&255;
 HEAP8[$3>>0] = $38;
 $39 = (($this) + 404|0);
 $40 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$39)|0);
 $41 = $40&1;
 $42 = HEAP8[$3>>0]|0;
 $43 = $42&255;
 $44 = $43 | $41;
 $45 = $44&255;
 HEAP8[$3>>0] = $45;
 $46 = (($this) + 420|0);
 $47 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$46)|0);
 $48 = $47&1;
 $49 = HEAP8[$3>>0]|0;
 $50 = $49&255;
 $51 = $50 | $48;
 $52 = $51&255;
 HEAP8[$3>>0] = $52;
 $53 = (($this) + 388|0);
 $54 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$53)|0);
 $55 = $54&1;
 $56 = HEAP8[$3>>0]|0;
 $57 = $56&255;
 $58 = $57 | $55;
 $59 = $58&255;
 HEAP8[$3>>0] = $59;
 $60 = (($this) + 396|0);
 $61 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$60)|0);
 $62 = $61&1;
 $63 = HEAP8[$3>>0]|0;
 $64 = $63&255;
 $65 = $64 | $62;
 $66 = $65&255;
 HEAP8[$3>>0] = $66;
 $67 = (($this) + 428|0);
 $68 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$67)|0);
 $69 = $68&1;
 $70 = HEAP8[$3>>0]|0;
 $71 = $70&255;
 $72 = $71 | $69;
 $73 = $72&255;
 HEAP8[$3>>0] = $73;
 $74 = (($this) + 436|0);
 $75 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$74)|0);
 $76 = $75&1;
 $77 = HEAP8[$3>>0]|0;
 $78 = $77&255;
 $79 = $78 | $76;
 $80 = $79&255;
 HEAP8[$3>>0] = $80;
 $81 = (($this) + 444|0);
 $82 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$81)|0);
 $83 = $82&1;
 $84 = HEAP8[$3>>0]|0;
 $85 = $84&255;
 $86 = $85 | $83;
 $87 = $86&255;
 HEAP8[$3>>0] = $87;
 $88 = (($this) + 452|0);
 $89 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$88)|0);
 $90 = $89&1;
 $91 = HEAP8[$3>>0]|0;
 $92 = $91&255;
 $93 = $92 | $90;
 $94 = $93&255;
 HEAP8[$3>>0] = $94;
 $95 = (($this) + 460|0);
 $96 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$95)|0);
 $97 = $96&1;
 $98 = HEAP8[$3>>0]|0;
 $99 = $98&255;
 $100 = $99 | $97;
 $101 = $100&255;
 HEAP8[$3>>0] = $101;
 $102 = (($this) + 468|0);
 $103 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$102)|0);
 $104 = $103&1;
 $105 = HEAP8[$3>>0]|0;
 $106 = $105&255;
 $107 = $106 | $104;
 $108 = $107&255;
 HEAP8[$3>>0] = $108;
 $109 = (($this) + 476|0);
 $110 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$109)|0);
 $111 = $110&1;
 $112 = HEAP8[$3>>0]|0;
 $113 = $112&255;
 $114 = $113 | $111;
 $115 = $114&255;
 HEAP8[$3>>0] = $115;
 $116 = (($this) + 484|0);
 $117 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$116)|0);
 $118 = $117&1;
 $119 = HEAP8[$3>>0]|0;
 $120 = $119&255;
 $121 = $120 | $118;
 $122 = $121&255;
 HEAP8[$3>>0] = $122;
 $123 = (($this) + 492|0);
 $124 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$123)|0);
 $125 = $124&1;
 $126 = HEAP8[$3>>0]|0;
 $127 = $126&255;
 $128 = $127 | $125;
 $129 = $128&255;
 HEAP8[$3>>0] = $129;
 $130 = (($this) + 500|0);
 $131 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$130)|0);
 $132 = $131&1;
 $133 = HEAP8[$3>>0]|0;
 $134 = $133&255;
 $135 = $134 | $132;
 $136 = $135&255;
 HEAP8[$3>>0] = $136;
 $137 = (($this) + 508|0);
 $138 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$137)|0);
 $139 = $138&1;
 $140 = HEAP8[$3>>0]|0;
 $141 = $140&255;
 $142 = $141 | $139;
 $143 = $142&255;
 HEAP8[$3>>0] = $143;
 $144 = (($this) + 516|0);
 $145 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$144)|0);
 $146 = $145&1;
 $147 = HEAP8[$3>>0]|0;
 $148 = $147&255;
 $149 = $148 | $146;
 $150 = $149&255;
 HEAP8[$3>>0] = $150;
 $151 = (($this) + 524|0);
 $152 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$151)|0);
 $153 = $152&1;
 $154 = HEAP8[$3>>0]|0;
 $155 = $154&255;
 $156 = $155 | $153;
 $157 = $156&255;
 HEAP8[$3>>0] = $157;
 $158 = (($this) + 532|0);
 $159 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$158)|0);
 $160 = $159&1;
 $161 = HEAP8[$3>>0]|0;
 $162 = $161&255;
 $163 = $162 | $160;
 $164 = $163&255;
 HEAP8[$3>>0] = $164;
 $165 = (($this) + 540|0);
 $166 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$165)|0);
 $167 = $166&1;
 $168 = HEAP8[$3>>0]|0;
 $169 = $168&255;
 $170 = $169 | $167;
 $171 = $170&255;
 HEAP8[$3>>0] = $171;
 $172 = (($this) + 548|0);
 $173 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$172)|0);
 $174 = $173&1;
 $175 = HEAP8[$3>>0]|0;
 $176 = $175&255;
 $177 = $176 | $174;
 $178 = $177&255;
 HEAP8[$3>>0] = $178;
 $179 = (($this) + 556|0);
 $180 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$179)|0);
 $181 = $180&1;
 $182 = HEAP8[$3>>0]|0;
 $183 = $182&255;
 $184 = $183 | $181;
 $185 = $184&255;
 HEAP8[$3>>0] = $185;
 $186 = (($this) + 564|0);
 $187 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$186)|0);
 $188 = $187&1;
 $189 = HEAP8[$3>>0]|0;
 $190 = $189&255;
 $191 = $190 | $188;
 $192 = $191&255;
 HEAP8[$3>>0] = $192;
 $193 = (($this) + 572|0);
 $194 = (__ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$1,$193)|0);
 $195 = $194&1;
 $196 = HEAP8[$3>>0]|0;
 $197 = $196&255;
 $198 = $197 | $195;
 $199 = $198&255;
 HEAP8[$3>>0] = $199;
 $200 = HEAP32[$2>>2]|0;
 $201 = ($200|0)==(0);
 if ($201) {
  STACKTOP = sp;return;
 }
 $202 = (($outProps) + 8|0);
 $203 = (($outProps) + 12|0);
 $204 = (($outProps) + 4|0);
 $$pre = HEAP32[$outProps>>2]|0;
 $207 = $$pre;$i$01 = 0;
 while(1) {
  $205 = HEAP32[$202>>2]|0;
  $206 = (($207) + ($205<<2)|0);
  $208 = ($205|0)==(0);
  L6: do {
   if ($208) {
    $$0$lcssa$i = $207;
    label = 7;
   } else {
    $209 = HEAP32[$1>>2]|0;
    $210 = (($209) + ($i$01<<2)|0);
    $211 = HEAP32[$210>>2]|0;
    $$01$i = $207;
    while(1) {
     $214 = HEAP32[$$01$i>>2]|0;
     $215 = ($214|0)==($211|0);
     $213 = (($$01$i) + 4|0);
     if ($215) {
      $$0$lcssa$i = $$01$i;
      label = 7;
      break L6;
     }
     $212 = ($213|0)==($206|0);
     if ($212) {
      label = 8;
      break;
     } else {
      $$01$i = $213;
     }
    }
   }
  } while(0);
  if ((label|0) == 7) {
   label = 0;
   $216 = ($$0$lcssa$i|0)==($206|0);
   if ($216) {
    label = 8;
   } else {
    $244 = $207;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $217 = HEAP32[$1>>2]|0;
   $218 = (($217) + ($i$01<<2)|0);
   $219 = HEAP32[$218>>2]|0;
   $220 = (($205) + 1)|0;
   HEAP32[$202>>2] = $220;
   $221 = HEAP32[$203>>2]|0;
   $222 = $221 & 2147483647;
   $223 = ($220>>>0)>($222>>>0);
   if ($223) {
    $224 = $221 << 1;
    $225 = ($224|0)==(0);
    $226 = $225 ? 1 : $224;
    $227 = ($222>>>0)<($226>>>0);
    do {
     if ($227) {
      $228 = ($221|0)>(-1);
      if ($228) {
       HEAP32[$203>>2] = $226;
       $229 = $226 << 2;
       $230 = HEAP32[$204>>2]|0;
       HEAP32[$0>>2] = $230;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       $231 = (__Z16realloc_internalPvji10MemLabelIdiPKci($207,$229,4,$$byval_copy1,0,679600,370)|0);
       HEAP32[$outProps>>2] = $231;
       $245 = $231;
       break;
      } else {
       $232 = $226 << 2;
       $233 = HEAP32[$204>>2]|0;
       HEAP32[$0>>2] = $233;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       $234 = (__Z15malloc_internaljj10MemLabelIdiPKci($232,4,$$byval_copy1,0,679600,352)|0);
       $235 = HEAP32[$outProps>>2]|0;
       $236 = HEAP32[$202>>2]|0;
       $237 = $236 << 2;
       _memcpy(($234|0),($235|0),($237|0))|0;
       HEAP32[$203>>2] = $226;
       HEAP32[$outProps>>2] = $234;
       $245 = $234;
       break;
      }
     } else {
      $245 = $207;
     }
    } while(0);
    $$pre$i$i = HEAP32[$202>>2]|0;
    $239 = $$pre$i$i;$241 = $245;
   } else {
    $239 = $220;$241 = $207;
   }
   $238 = (($239) + -1)|0;
   $240 = (($241) + ($238<<2)|0);
   HEAP32[$240>>2] = $219;
   $244 = $241;
  }
  $242 = (($i$01) + 1)|0;
  $243 = ($242|0)==($200|0);
  if ($243) {
   break;
  } else {
   $207 = $244;$i$01 = $242;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLabL18AddPropertyToArrayERKNS_13PropertySheetER13dynamic_arrayIiLj4EERKNS_8FloatValE($shaderProps,$arr,$p) {
 $shaderProps = $shaderProps|0;
 $arr = $arr|0;
 $p = $p|0;
 var $$$i1 = 0, $$0 = 0, $$0$lcssa$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$byval_copy1 = 0, $$not = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($p) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)!=(-1);
 $$not = $3 ^ 1;
 $4 = ($2>>>0)>(1073741823);
 $$$i1 = $3 & $4;
 $or$cond = $$$i1 | $$not;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$arr>>2]|0;
 $6 = (($arr) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($7<<2)|0);
 $9 = ($7|0)==(0);
 L4: do {
  if ($9) {
   $$0$lcssa$i = $5;
   label = 5;
  } else {
   $$01$i = $5;
   while(1) {
    $12 = HEAP32[$$01$i>>2]|0;
    $13 = ($12|0)==($2|0);
    $11 = (($$01$i) + 4|0);
    if ($13) {
     $$0$lcssa$i = $$01$i;
     label = 5;
     break L4;
    }
    $10 = ($11|0)==($8|0);
    if ($10) {
     label = 6;
     break;
    } else {
     $$01$i = $11;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $14 = ($$0$lcssa$i|0)==($8|0);
  if ($14) {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $15 = (($7) + 1)|0;
  HEAP32[$6>>2] = $15;
  $16 = (($arr) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17 & 2147483647;
  $19 = ($15>>>0)>($18>>>0);
  if ($19) {
   $20 = $17 << 1;
   $21 = ($20|0)==(0);
   $22 = $21 ? 1 : $20;
   $23 = ($18>>>0)<($22>>>0);
   do {
    if ($23) {
     $24 = ($17|0)>(-1);
     if ($24) {
      HEAP32[$16>>2] = $22;
      $25 = $22 << 2;
      $26 = (($arr) + 4|0);
      $27 = HEAP32[$26>>2]|0;
      HEAP32[$0>>2] = $27;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $28 = (__Z16realloc_internalPvji10MemLabelIdiPKci($5,$25,4,$$byval_copy1,0,679600,370)|0);
      HEAP32[$arr>>2] = $28;
      $57 = $28;
      break;
     } else {
      $29 = $22 << 2;
      $30 = (($arr) + 4|0);
      $31 = HEAP32[$30>>2]|0;
      HEAP32[$0>>2] = $31;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $32 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,4,$$byval_copy1,0,679600,352)|0);
      $33 = HEAP32[$arr>>2]|0;
      $34 = HEAP32[$6>>2]|0;
      $35 = $34 << 2;
      _memcpy(($32|0),($33|0),($35|0))|0;
      HEAP32[$16>>2] = $22;
      HEAP32[$arr>>2] = $32;
      $57 = $32;
      break;
     }
    } else {
     $57 = $5;
    }
   } while(0);
   $$pre$i$i = HEAP32[$6>>2]|0;
   $37 = $$pre$i$i;$39 = $57;
  } else {
   $37 = $15;$39 = $5;
  }
  $36 = (($37) + -1)|0;
  $38 = (($39) + ($36<<2)|0);
  HEAP32[$38>>2] = $2;
 }
 $40 = (($shaderProps) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($shaderProps) + 12|0);
 $43 = ($41|0)==(0|0);
 if ($43) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $44 = HEAP32[$1>>2]|0;
 $$0$ph7$i$i$i$i = $42;$$01$ph6$i$in$i$i$i = $41;
 L25: while(1) {
  $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
  while(1) {
   $45 = (($$013$i$in$i$i$i) + 16|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)<($44|0);
   if (!($47)) {
    break;
   }
   $50 = (($$013$i$in$i$i$i) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
    break L25;
   } else {
    $$013$i$in$i$i$i = $51;
   }
  }
  $48 = HEAP32[$$013$i$in$i$i$i>>2]|0;
  $49 = ($48|0)==(0|0);
  if ($49) {
   $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
   break;
  } else {
   $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $48;
  }
 }
 $53 = ($$0$ph5$i$i$i$i|0)==($42|0);
 if ($53) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $54 = (($$0$ph5$i$i$i$i) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($44|0)<($55|0);
 $$0 = $56;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab11ShaderState10SetProgramE10ShaderTypePNS_7ProgramEPK6Shader($this,$type,$prog,$fromShader) {
 $this = $this|0;
 $type = $type|0;
 $prog = $prog|0;
 $fromShader = $fromShader|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($prog|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (__ZNK9ShaderLab7Program11IsSupportedEPK6Shader($prog,$fromShader)|0);
 if (!($1)) {
  $2 = (($this) + 332|0);
  HEAP8[$2>>0] = 1;
  STACKTOP = sp;return;
 }
 $3 = (($prog) + 132|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($this) + 316|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($this) + 324|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + ($9<<4)|0);
  $11 = (($prog) + 124|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($4<<4)|0);
  (__ZN13dynamic_arrayI16ShaderKeywordSetLj4EE6insertEPS0_PKS0_S4_($6,$10,$12,$13)|0);
 }
 $14 = ((($this) + ($type<<2)|0) + 292|0);
 HEAP32[$14>>2] = $prog;
 $15 = (($prog) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$15>>2] = $17;
 $18 = HEAP32[$15>>2]|0;
 __ZN9ShaderLab7Program22ComputeSupportsShadowsEv($prog);
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI16ShaderKeywordSetLj4EE6insertEPS0_PKS0_S4_($this,$insert_before,$input_begin,$input_end) {
 $this = $this|0;
 $insert_before = $insert_before|0;
 $input_begin = $input_begin|0;
 $input_end = $input_end|0;
 var $$byval_copy1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = $insert_before;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 4;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) - ($5))|0;
 $9 = $input_end;
 $10 = $input_begin;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 4;
 $13 = (($7) + ($12))|0;
 HEAP32[$6>>2] = $13;
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($13>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $13;
    $19 = $13 << 4;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$19,4,$$byval_copy1,0,679600,370)|0);
    HEAP32[$this>>2] = $22;
    $31 = $22;
    break;
   } else {
    $23 = $13 << 4;
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$0>>2] = $25;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,4,$$byval_copy1,0,679600,352)|0);
    $27 = HEAP32[$this>>2]|0;
    $28 = HEAP32[$6>>2]|0;
    $29 = $28 << 4;
    _memcpy(($26|0),($27|0),($29|0))|0;
    HEAP32[$14>>2] = $13;
    HEAP32[$this>>2] = $26;
    $31 = $26;
    break;
   }
  } else {
   $31 = $1;
  }
 } while(0);
 $30 = (($31) + ($5<<4)|0);
 $$sum = (($5) + ($12))|0;
 $32 = (($31) + ($$sum<<4)|0);
 $33 = $8 << 4;
 _memmove(($32|0),($30|0),($33|0))|0;
 _memcpy(($30|0),($input_begin|0),($11|0))|0;
 STACKTOP = sp;return ($30|0);
}
function __ZN9ShaderLab11ShaderState25RemoveUnsupportedProgramsEPK6Shader($this,$fromShader) {
 $this = $this|0;
 $fromShader = $fromShader|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 316|0);
 $1 = (($this) + 324|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 332|0);
 $5 = (($this) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __ZN9ShaderLab7Program14RemoveVariantsERK13dynamic_arrayI16ShaderKeywordSetLj4EE($6,$0);
  $8 = HEAP32[$5>>2]|0;
  $9 = (__ZNK9ShaderLab7Program11IsSupportedEPK6Shader($8,$fromShader)|0);
  if (!($9)) {
   HEAP8[$4>>0] = 1;
  }
 }
 $10 = (($this) + 296|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  __ZN9ShaderLab7Program14RemoveVariantsERK13dynamic_arrayI16ShaderKeywordSetLj4EE($11,$0);
  $13 = HEAP32[$10>>2]|0;
  $14 = (__ZNK9ShaderLab7Program11IsSupportedEPK6Shader($13,$fromShader)|0);
  if (!($14)) {
   HEAP8[$4>>0] = 1;
  }
 }
 $15 = (($this) + 300|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  __ZN9ShaderLab7Program14RemoveVariantsERK13dynamic_arrayI16ShaderKeywordSetLj4EE($16,$0);
  $18 = HEAP32[$15>>2]|0;
  $19 = (__ZNK9ShaderLab7Program11IsSupportedEPK6Shader($18,$fromShader)|0);
  if (!($19)) {
   HEAP8[$4>>0] = 1;
  }
 }
 $20 = (($this) + 304|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  __ZN9ShaderLab7Program14RemoveVariantsERK13dynamic_arrayI16ShaderKeywordSetLj4EE($21,$0);
  $23 = HEAP32[$20>>2]|0;
  $24 = (__ZNK9ShaderLab7Program11IsSupportedEPK6Shader($23,$fromShader)|0);
  if (!($24)) {
   HEAP8[$4>>0] = 1;
  }
 }
 $25 = (($this) + 308|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  __ZN9ShaderLab7Program14RemoveVariantsERK13dynamic_arrayI16ShaderKeywordSetLj4EE($26,$0);
  $28 = HEAP32[$25>>2]|0;
  $29 = (__ZNK9ShaderLab7Program11IsSupportedEPK6Shader($28,$fromShader)|0);
  if (!($29)) {
   HEAP8[$4>>0] = 1;
  }
 }
 $30 = (($this) + 312|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 __ZN9ShaderLab7Program14RemoveVariantsERK13dynamic_arrayI16ShaderKeywordSetLj4EE($31,$0);
 $33 = HEAP32[$30>>2]|0;
 $34 = (__ZNK9ShaderLab7Program11IsSupportedEPK6Shader($33,$fromShader)|0);
 if ($34) {
  STACKTOP = sp;return;
 }
 HEAP8[$4>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab11ShaderStateD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $8 = 0, $9 = 0, $i$011 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $i$011 = 0;
 while(1) {
  $5 = ((($this) + ($i$011<<2)|0) + 292|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $8 = (($6) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + -1)|0;
   HEAP32[$8>>2] = $10;
   $11 = HEAP32[$8>>2]|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = HEAP32[$6>>2]|0;
    $14 = (($13) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_vi($15|0,($6|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 6;
     break;
    }
   }
   HEAP32[$5>>2] = 0;
  }
  $29 = (($i$011) + 1)|0;
  $30 = ($29|0)<(6);
  if ($30) {
   $i$011 = $29;
  } else {
   label = 10;
   break;
  }
 }
 L9: do {
  if ((label|0) == 6) {
   $18 = ___cxa_find_matching_catch()|0;
   $19 = tempRet0;
   $20 = (($this) + 348|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)>(-1);
   if ($22) {
    $23 = (($this) + 336|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($this) + 340|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP32[$4>>2] = $26;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($24|0),($$byval_copy5|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $76 = ___cxa_find_matching_catch(0|0)|0;
     $77 = tempRet0;
     ___clang_call_terminate($76);
     // unreachable;
    } else {
     HEAP32[$23>>2] = 0;
     $$0 = $19;$$01 = $18;
     label = 21;
     break;
    }
   } else {
    $$0 = $19;$$01 = $18;
    label = 21;
   }
  }
  else if ((label|0) == 10) {
   $31 = (($this) + 348|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)>(-1);
   do {
    if ($33) {
     $34 = (($this) + 336|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($this) + 340|0);
     $37 = HEAP32[$36>>2]|0;
     HEAP32[$3>>2] = $37;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($35|0),($$byval_copy5|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      $55 = ___cxa_find_matching_catch()|0;
      $56 = tempRet0;
      $$0 = $56;$$01 = $55;
      label = 21;
      break L9;
     } else {
      HEAP32[$34>>2] = 0;
      break;
     }
    }
   } while(0);
   $40 = (($this) + 328|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)>(-1);
   do {
    if ($42) {
     $43 = (($this) + 316|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($this) + 320|0);
     $46 = HEAP32[$45>>2]|0;
     HEAP32[$2>>2] = $46;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($44|0),($$byval_copy5|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      $57 = ___cxa_find_matching_catch()|0;
      $58 = tempRet0;
      $$1 = $58;$$12 = $57;
      break L9;
     } else {
      HEAP32[$43>>2] = 0;
      break;
     }
    }
   } while(0);
   $49 = (($this) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)>(-1);
   if (!($51)) {
    STACKTOP = sp;return;
   }
   $52 = HEAP32[$this>>2]|0;
   $53 = (($this) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$0>>2] = $54;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($52,$$byval_copy5);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 21) {
   $59 = (($this) + 328|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)>(-1);
   if ($61) {
    $62 = (($this) + 316|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($this) + 320|0);
    $65 = HEAP32[$64>>2]|0;
    HEAP32[$1>>2] = $65;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($63|0),($$byval_copy5|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     $76 = ___cxa_find_matching_catch(0|0)|0;
     $77 = tempRet0;
     ___clang_call_terminate($76);
     // unreachable;
    } else {
     HEAP32[$62>>2] = 0;
     $$1 = $$0;$$12 = $$01;
     break;
    }
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 $68 = (($this) + 12|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)>(-1);
 if (!($70)) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $71 = HEAP32[$this>>2]|0;
 $72 = (($this) + 4|0);
 $73 = HEAP32[$72>>2]|0;
 HEAP32[$0>>2] = $73;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($71|0),($$byval_copy5|0));
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if ($75) {
  $76 = ___cxa_find_matching_catch(0|0)|0;
  $77 = tempRet0;
  ___clang_call_terminate($76);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$12|0);
 // unreachable;
}
function __ZNK9ShaderLab11ShaderState22IsShaderStateSupportedEv($this) {
 $this = $this|0;
 var $$off = 0, $$off14 = 0, $$off15 = 0, $$off16 = 0, $$off17 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$or$cond26 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond20 = 0, $or$cond22 = 0, $or$cond24 = 0, $or$cond27 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 332|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return 0;
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = (($5) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = (($5) + 8|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = (($5) + 9|0);
 $13 = HEAP8[$12>>0]|0;
 if ((($7<<24>>24) == 3) | (($7<<24>>24) == 6)) {
  label = 5;
 } else {
  if ((($9<<24>>24) == 2) | (($9<<24>>24) == 4)) {
   label = 5;
  } else {
   $$pre = HEAP8[((640792 + 133|0))>>0]|0;
   $20 = $$pre;
  }
 }
 if ((label|0) == 5) {
  $14 = HEAP16[((640792 + 132|0))>>1]|0;
  $15 = $14&255;
  $16 = ($15<<24>>24)==(0);
  $17 = ($14&65535) >>> 8;
  $18 = $17&255;
  if ($16) {
   STACKTOP = sp;return 0;
  } else {
   $20 = $18;
  }
 }
 $19 = ($20<<24>>24)==(0);
 if ($19) {
  $21 = (($5) + 6|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($7<<24>>24)==($22<<24>>24);
  if (!($23)) {
   STACKTOP = sp;return 0;
  }
  $24 = (($5) + 7|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($9<<24>>24)==($25<<24>>24);
  $27 = ($11<<24>>24)==($13<<24>>24);
  $or$cond27 = $26 & $27;
  if (!($or$cond27)) {
   STACKTOP = sp;return 0;
  }
 }
 $$off = (($11) + -1)<<24>>24;
 $28 = ($$off&255)<(2);
 $29 = HEAP16[((640792 + 134|0))>>1]|0;
 $30 = $29&255;
 $31 = ($30<<24>>24)==(0);
 $or$cond = $28 & $31;
 if ($or$cond) {
  STACKTOP = sp;return 0;
 }
 $$off14 = (($13) + -1)<<24>>24;
 $32 = ($$off14&255)<(2);
 $or$cond20 = $32 & $31;
 if ($or$cond20) {
  STACKTOP = sp;return 0;
 }
 $$off15 = (($11) + -3)<<24>>24;
 $33 = ($$off15&255)<(2);
 $34 = ($29&65535)<(256);
 $or$cond22 = $33 & $34;
 if ($or$cond22) {
  STACKTOP = sp;return 0;
 }
 $$off16 = (($13) + -3)<<24>>24;
 $35 = ($$off16&255)<(2);
 $or$cond24 = $35 & $34;
 if ($or$cond24) {
  STACKTOP = sp;return 0;
 } else {
  $$off17 = (($11) + -5)<<24>>24;
  $36 = HEAP8[((640792 + 136|0))>>0]|0;
  $notlhs = ($$off17&255)>(15);
  $notrhs = ($36<<24>>24)!=(0);
  $not$or$cond26 = $notrhs | $notlhs;
  STACKTOP = sp;return ($not$or$cond26|0);
 }
 return 0|0;
}
function __ZN9ShaderLab11ShaderState20FindSubProgramsToUseEP6ShaderPNS_4PassEPPNS_10SubProgramERKNS_17ShaderPassContextE($this,$fromShader,$fromPass,$subPrograms,$passContext) {
 $this = $this|0;
 $fromShader = $fromShader|0;
 $fromPass = $fromPass|0;
 $subPrograms = $subPrograms|0;
 $passContext = $passContext|0;
 var $$useError$1$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $hadSomeUnsupported$1$off024 = 0, $hadSomeUnsupported$2$off0 = 0, $kwords = 0, $not$ = 0, $pt$022 = 0, $res = 0, $searchCounter$123 = 0;
 var $searchCounter$2 = 0, $useError$1$off0$ = 0, $useError$1$off025 = 0, $useError$3$off0 = 0, $usedKeywords = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $kwords = sp + 24|0;
 $usedKeywords = sp;
 $res = sp + 16|0;
 $0 = (($passContext) + 4|0);
 ;HEAP32[$kwords+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$kwords+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$kwords+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$kwords+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$usedKeywords+0>>2]=0|0;HEAP32[$usedKeywords+4>>2]=0|0;HEAP32[$usedKeywords+8>>2]=0|0;HEAP32[$usedKeywords+12>>2]=0|0;
 $hadSomeUnsupported$1$off024 = 0;$pt$022 = 0;$searchCounter$123 = 0;$useError$1$off025 = 0;
 while(1) {
  $1 = ((($this) + ($pt$022<<2)|0) + 292|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if ($3) {
   $4 = (($subPrograms) + ($pt$022<<2)|0);
   HEAP32[$4>>2] = 0;
   $hadSomeUnsupported$2$off0 = $hadSomeUnsupported$1$off024;$searchCounter$2 = $searchCounter$123;$useError$3$off0 = $useError$1$off025;
  } else {
   HEAP32[$res>>2] = 0;
   $5 = (__ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult($2,$fromShader,$fromPass,$kwords,$usedKeywords,$res)|0);
   $6 = (($subPrograms) + ($pt$022<<2)|0);
   HEAP32[$6>>2] = $5;
   $7 = HEAP32[$res>>2]|0;
   $8 = ($7|0)==(1);
   $$useError$1$off0 = $8 | $useError$1$off025;
   $9 = ($7|0)==(2);
   if ($9) {
    $10 = (($this) + 292|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if (!($12)) {
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($11,$kwords);
     $13 = HEAP32[$10>>2]|0;
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($13,$usedKeywords);
    }
    HEAP32[$subPrograms>>2] = 0;
    $14 = (($this) + 296|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($15,$kwords);
     $188 = HEAP32[$14>>2]|0;
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($188,$usedKeywords);
    }
    $189 = (($subPrograms) + 4|0);
    HEAP32[$189>>2] = 0;
    $190 = (($this) + 300|0);
    $191 = HEAP32[$190>>2]|0;
    $192 = ($191|0)==(0|0);
    if (!($192)) {
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($191,$kwords);
     $193 = HEAP32[$190>>2]|0;
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($193,$usedKeywords);
    }
    $194 = (($subPrograms) + 8|0);
    HEAP32[$194>>2] = 0;
    $195 = (($this) + 304|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = ($196|0)==(0|0);
    if (!($197)) {
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($196,$kwords);
     $198 = HEAP32[$195>>2]|0;
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($198,$usedKeywords);
    }
    $199 = (($subPrograms) + 12|0);
    HEAP32[$199>>2] = 0;
    $200 = (($this) + 308|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = ($201|0)==(0|0);
    if (!($202)) {
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($201,$kwords);
     $203 = HEAP32[$200>>2]|0;
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($203,$usedKeywords);
    }
    $204 = (($subPrograms) + 16|0);
    HEAP32[$204>>2] = 0;
    $205 = (($this) + 312|0);
    $206 = HEAP32[$205>>2]|0;
    $207 = ($206|0)==(0|0);
    if (!($207)) {
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($206,$kwords);
     $208 = HEAP32[$205>>2]|0;
     __ZN9ShaderLab7Program24MarkVariantAsUnsupportedERK16ShaderKeywordSet($208,$usedKeywords);
    }
    $209 = (($subPrograms) + 20|0);
    HEAP32[$209>>2] = 0;
    $210 = (($searchCounter$123) + 1)|0;
    $211 = ($210|0)<(10);
    if ($211) {
     $hadSomeUnsupported$1$off024 = 1;$pt$022 = 0;$searchCounter$123 = $210;$useError$1$off025 = $$useError$1$off0;
     continue;
    } else {
     $hadSomeUnsupported$2$off0 = 1;$searchCounter$2 = $210;$useError$3$off0 = 1;
    }
   } else {
    $hadSomeUnsupported$2$off0 = $hadSomeUnsupported$1$off024;$searchCounter$2 = $searchCounter$123;$useError$3$off0 = $$useError$1$off0;
   }
  }
  $17 = (($pt$022) + 1)|0;
  $18 = ($17|0)<(6);
  if ($18) {
   $hadSomeUnsupported$1$off024 = $hadSomeUnsupported$2$off0;$pt$022 = $17;$searchCounter$123 = $searchCounter$2;$useError$1$off025 = $useError$3$off0;
  } else {
   break;
  }
 }
 if ($hadSomeUnsupported$2$off0) {
  $19 = (($this) + 316|0);
  $20 = (($this) + 324|0);
  $21 = (($this) + 292|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $24 = (($22) + 132|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if (!($26)) {
    $27 = HEAP32[$19>>2]|0;
    $28 = HEAP32[$20>>2]|0;
    $29 = (($27) + ($28<<4)|0);
    $30 = (($22) + 124|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + ($25<<4)|0);
    (__ZN13dynamic_arrayI16ShaderKeywordSetLj4EE6insertEPS0_PKS0_S4_($19,$29,$31,$32)|0);
   }
  }
  $33 = (($this) + 296|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   $129 = (($34) + 132|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ($130|0)==(0);
   if (!($131)) {
    $132 = HEAP32[$19>>2]|0;
    $133 = HEAP32[$20>>2]|0;
    $134 = (($132) + ($133<<4)|0);
    $135 = (($34) + 124|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($136) + ($130<<4)|0);
    (__ZN13dynamic_arrayI16ShaderKeywordSetLj4EE6insertEPS0_PKS0_S4_($19,$134,$136,$137)|0);
   }
  }
  $138 = (($this) + 300|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = ($139|0)==(0|0);
  if (!($140)) {
   $141 = (($139) + 132|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = ($142|0)==(0);
   if (!($143)) {
    $144 = HEAP32[$19>>2]|0;
    $145 = HEAP32[$20>>2]|0;
    $146 = (($144) + ($145<<4)|0);
    $147 = (($139) + 124|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = (($148) + ($142<<4)|0);
    (__ZN13dynamic_arrayI16ShaderKeywordSetLj4EE6insertEPS0_PKS0_S4_($19,$146,$148,$149)|0);
   }
  }
  $150 = (($this) + 304|0);
  $151 = HEAP32[$150>>2]|0;
  $152 = ($151|0)==(0|0);
  if (!($152)) {
   $153 = (($151) + 132|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ($154|0)==(0);
   if (!($155)) {
    $156 = HEAP32[$19>>2]|0;
    $157 = HEAP32[$20>>2]|0;
    $158 = (($156) + ($157<<4)|0);
    $159 = (($151) + 124|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = (($160) + ($154<<4)|0);
    (__ZN13dynamic_arrayI16ShaderKeywordSetLj4EE6insertEPS0_PKS0_S4_($19,$158,$160,$161)|0);
   }
  }
  $162 = (($this) + 308|0);
  $163 = HEAP32[$162>>2]|0;
  $164 = ($163|0)==(0|0);
  if (!($164)) {
   $165 = (($163) + 132|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ($166|0)==(0);
   if (!($167)) {
    $168 = HEAP32[$19>>2]|0;
    $169 = HEAP32[$20>>2]|0;
    $170 = (($168) + ($169<<4)|0);
    $171 = (($163) + 124|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = (($172) + ($166<<4)|0);
    (__ZN13dynamic_arrayI16ShaderKeywordSetLj4EE6insertEPS0_PKS0_S4_($19,$170,$172,$173)|0);
   }
  }
  $174 = (($this) + 312|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = ($175|0)==(0|0);
  if (!($176)) {
   $177 = (($175) + 132|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = ($178|0)==(0);
   if (!($179)) {
    $180 = HEAP32[$19>>2]|0;
    $181 = HEAP32[$20>>2]|0;
    $182 = (($180) + ($181<<4)|0);
    $183 = (($175) + 124|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = (($184) + ($178<<4)|0);
    (__ZN13dynamic_arrayI16ShaderKeywordSetLj4EE6insertEPS0_PKS0_S4_($19,$182,$184,$185)|0);
   }
  }
  __ZN9ShaderLab11ShaderState25RemoveUnsupportedProgramsEPK6Shader($this,$fromShader);
  $186 = (($this) + 332|0);
  $187 = HEAP8[$186>>0]|0;
  $not$ = ($187<<24>>24)!=(0);
  $useError$1$off0$ = $useError$3$off0 | $not$;
  if (!($useError$1$off0$)) {
   label = 15;
  }
 } else {
  if (!($useError$3$off0)) {
   label = 15;
  }
 }
 if ((label|0) == 15) {
  $36 = (($subPrograms) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   STACKTOP = sp;return;
  }
  $39 = (($subPrograms) + 8|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==(0|0);
  if ($41) {
   STACKTOP = sp;return;
  }
  $42 = (($40) + 40|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   STACKTOP = sp;return;
  }
  $45 = (($43) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(6);
  if (!($47)) {
   STACKTOP = sp;return;
  }
 }
 $48 = (__ZN6Shader10GetDefaultEv()|0);
 $49 = (($48) + 52|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 32|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$50>>2]|0;
 $54 = (($53) + ($52<<2)|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 296|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0|0);
 if ($60) {
  $68 = 0;
 } else {
  $61 = (($59) + 16|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)>(0);
  if ($63) {
   $64 = (($59) + 8|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if ($67) {
    $68 = 0;
   } else {
    __ZN9ShaderLab10SubProgram14EnsureCompiledEv($66);
    $68 = $66;
   }
  } else {
   $68 = 0;
  }
 }
 HEAP32[$subPrograms>>2] = $68;
 $69 = (($57) + 300|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==(0|0);
 if ($71) {
  $80 = 0;
 } else {
  $72 = (($70) + 16|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ($73|0)>(0);
  if ($74) {
   $75 = (($70) + 8|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if ($78) {
    $80 = 0;
   } else {
    __ZN9ShaderLab10SubProgram14EnsureCompiledEv($77);
    $80 = $77;
   }
  } else {
   $80 = 0;
  }
 }
 $79 = (($subPrograms) + 4|0);
 HEAP32[$79>>2] = $80;
 $81 = (($57) + 304|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  $92 = 0;
 } else {
  $84 = (($82) + 16|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)>(0);
  if ($86) {
   $87 = (($82) + 8|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)==(0|0);
   if ($90) {
    $92 = 0;
   } else {
    __ZN9ShaderLab10SubProgram14EnsureCompiledEv($89);
    $92 = $89;
   }
  } else {
   $92 = 0;
  }
 }
 $91 = (($subPrograms) + 8|0);
 HEAP32[$91>>2] = $92;
 $93 = (($57) + 308|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ($94|0)==(0|0);
 if ($95) {
  $104 = 0;
 } else {
  $96 = (($94) + 16|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = ($97|0)>(0);
  if ($98) {
   $99 = (($94) + 8|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = HEAP32[$100>>2]|0;
   $102 = ($101|0)==(0|0);
   if ($102) {
    $104 = 0;
   } else {
    __ZN9ShaderLab10SubProgram14EnsureCompiledEv($101);
    $104 = $101;
   }
  } else {
   $104 = 0;
  }
 }
 $103 = (($subPrograms) + 12|0);
 HEAP32[$103>>2] = $104;
 $105 = (($57) + 312|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($106|0)==(0|0);
 if ($107) {
  $116 = 0;
 } else {
  $108 = (($106) + 16|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)>(0);
  if ($110) {
   $111 = (($106) + 8|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = HEAP32[$112>>2]|0;
   $114 = ($113|0)==(0|0);
   if ($114) {
    $116 = 0;
   } else {
    __ZN9ShaderLab10SubProgram14EnsureCompiledEv($113);
    $116 = $113;
   }
  } else {
   $116 = 0;
  }
 }
 $115 = (($subPrograms) + 16|0);
 HEAP32[$115>>2] = $116;
 $117 = (($57) + 316|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = ($118|0)==(0|0);
 if ($119) {
  $128 = 0;
 } else {
  $120 = (($118) + 16|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = ($121|0)>(0);
  if ($122) {
   $123 = (($118) + 8|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = HEAP32[$124>>2]|0;
   $126 = ($125|0)==(0|0);
   if ($126) {
    $128 = 0;
   } else {
    __ZN9ShaderLab10SubProgram14EnsureCompiledEv($125);
    $128 = $125;
   }
  } else {
   $128 = 0;
  }
 }
 $127 = (($subPrograms) + 20|0);
 HEAP32[$127>>2] = $128;
 if ($hadSomeUnsupported$2$off0) {
  __ZN6Shader27MarkShaderStateNotSupportedEPS_($fromShader);
  STACKTOP = sp;return;
 } else {
  __ZN6Shader19MarkShaderHasErrorsEPS_($fromShader);
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab11ShaderState16ApplyShaderStateEjPKNS_13PropertySheetERKNS_17ShaderPassContextEP6ShaderPNS_4PassE($this,$stateKey,$props,$passContext,$fromShader,$fromPass) {
 $this = $this|0;
 $stateKey = $stateKey|0;
 $props = $props|0;
 $passContext = $passContext|0;
 $fromShader = $fromShader|0;
 $fromPass = $fromPass|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$byval_copy1 = 0, $$in$i = 0, $$in$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $9 = 0, $it$02$i = 0, $location$i$i1 = 0, $subPrograms = 0, $vsChannels$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $location$i$i1 = sp;
 $0 = sp + 4|0;
 $subPrograms = sp + 8|0;
 $1 = (__Z12GetGfxDevicev()|0);
 __ZN9ShaderLab11ShaderState20FindSubProgramsToUseEP6ShaderPNS_4PassEPPNS_10SubProgramERKNS_17ShaderPassContextE($this,$fromShader,$fromPass,$subPrograms,$passContext);
 __ZN14GraphicsHelper10SetShadersER9GfxDevicePPN9ShaderLab10SubProgramEPKNS2_13PropertySheetERKNS2_17ShaderPassContextE($1,$subPrograms,$props,$passContext);
 $2 = (($subPrograms) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $6 = (($this) + 284|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(-1);
  $9 = HEAP32[678896>>2]|0;
  $$ = $8 ? $9 : $7;
  $10 = ($$|0)==(0);
  if ($10) {
   $15 = HEAP32[$1>>2]|0;
   $16 = (($15) + 168|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vi[$17 & 4095]($1);
  } else {
   $11 = (($this) + 224|0);
   $12 = (($this) + 232|0);
   $13 = (($this) + 240|0);
   $14 = (($this) + 248|0);
   __ZN14GraphicsHelper11EnableFFFogE7FogModeRKN9ShaderLab8FloatValES4_S4_RKNS1_9VectorValEPKNS1_13PropertySheetERKNS1_17ShaderPassContextE($$,$11,$12,$13,$14,$props,$passContext);
  }
  $18 = HEAP32[$1>>2]|0;
  $19 = (($18) + 140|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($this) + 220|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)!=(0);
  $24 = (($this) + 221|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)!=(0);
  $27 = (($this) + 288|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viiii[$20 & 511]($1,$23,$26,$28);
  $29 = HEAP8[$21>>0]|0;
  $30 = ($29<<24>>24)==(0);
  if (!($30)) {
   $31 = (($this) + 104|0);
   $32 = (($this) + 68|0);
   $33 = (($this) + 140|0);
   $34 = (($this) + 176|0);
   $35 = (($this) + 24|0);
   __ZN14GraphicsHelper13SetFFMaterialERKN9ShaderLab9VectorValES3_S3_S3_RKNS0_8FloatValEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($31,$32,$33,$34,$35,$props,$passContext);
  }
  $36 = (($this) + 32|0);
  __ZN14GraphicsHelper10SetFFColorERKN9ShaderLab9VectorValEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE($36,$props,$passContext);
  $vsChannels$0 = 0;
 } else {
  $5 = (($3) + 4|0);
  $vsChannels$0 = $5;
 }
 $37 = (($this) + 352|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  $$0 = $stateKey;
 } else {
  $40 = (($this) + 336|0);
  $41 = (__ZN9ShaderLab27ComputeStateBlockValuesHashERK13dynamic_arrayIiLj4EEPKNS_13PropertySheetERKNS_17ShaderPassContextE($40,$props,$passContext)|0);
  __ZN9ShaderLab11ShaderState17BuildDeviceStatesEjPKNS_13PropertySheetERKNS_17ShaderPassContextE($this,$41,$props,$passContext);
  $$0 = $41;
 }
 $42 = HEAP32[$this>>2]|0;
 $43 = (($this) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + (($44*20)|0)|0);
 $46 = ($44|0)==(0);
 L15: do {
  if ($46) {
   $$0$i = $42;
  } else {
   $it$02$i = $42;
   while(1) {
    $49 = HEAP32[$it$02$i>>2]|0;
    $50 = ($49|0)==($$0|0);
    $48 = (($it$02$i) + 20|0);
    if ($50) {
     $$0$i = $it$02$i;
     break L15;
    }
    $47 = ($48|0)==($45|0);
    if ($47) {
     $$0$i = $42;
     break;
    } else {
     $it$02$i = $48;
    }
   }
  }
 } while(0);
 $51 = (($$0$i) + 4|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($this) + 16|0);
 __ZN14GraphicsHelper13SetBlendStateEPK16DeviceBlendStateRKN9ShaderLab8FloatValEPKNS3_13PropertySheetERKNS3_17ShaderPassContextE($52,$53,$props,$passContext);
 $54 = HEAP32[$1>>2]|0;
 $55 = (($54) + 60|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($$0$i) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_vii[$56 & 4095]($1,$58);
 $59 = HEAP32[$1>>2]|0;
 $60 = (($59) + 56|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($$0$i) + 12|0);
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_vii[$61 & 4095]($1,$63);
 $64 = HEAP8[678904>>0]|0;
 $65 = ($64<<24>>24)==(0);
 if ($65) {
  $78 = HEAP32[$1>>2]|0;
  $79 = (($78) + 68|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($this) + 216|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(-1);
  if ($83) {
   $85 = (($this) + 212|0);
   $$in$i = $85;
  } else {
   HEAP32[$0>>2] = $82;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   $84 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy1,$location$i$i1)|0);
   $$in$i = $84;
  }
  $86 = Math_fround(HEAPF32[$$in$i>>2]);
  $87 = (~~(($86)));
  FUNCTION_TABLE_vii[$80 & 4095]($1,$87);
  STACKTOP = sp;return ($vsChannels$0|0);
 } else {
  $66 = HEAP32[$1>>2]|0;
  $67 = (($66) + 64|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = (($$0$i) + 16|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($this) + 216|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(-1);
  if ($73) {
   $75 = (($this) + 212|0);
   $$in$i2 = $75;
  } else {
   HEAP32[$0>>2] = $72;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   $74 = (__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE($props,$passContext,$$byval_copy1,$location$i$i1)|0);
   $$in$i2 = $74;
  }
  $76 = Math_fround(HEAPF32[$$in$i2>>2]);
  $77 = (~~(($76)));
  FUNCTION_TABLE_viii[$68 & 4095]($1,$70,$77);
  STACKTOP = sp;return ($vsChannels$0|0);
 }
 return 0|0;
}
function __ZN14GraphicsHelper10SetShadersER9GfxDevicePPN9ShaderLab10SubProgramEPKNS2_13PropertySheetERKNS2_17ShaderPassContextE($device,$programs,$props,$passContext) {
 $device = $device|0;
 $programs = $programs|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $gpuPrograms = 0, $params2 = 0, $paramsBuffer = 0, $pt$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy6 = sp + 84|0;
 $paramsBuffer = sp;
 $0 = sp + 24|0;
 $gpuPrograms = sp + 32|0;
 $params2 = sp + 56|0;
 $1 = sp + 80|0;
 $2 = (($device) + 5786|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $29 = HEAP32[$device>>2]|0;
  $30 = (($29) + 224|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_viiii[$31 & 511]($device,$programs,$props,$passContext);
  STACKTOP = sp;return;
 }
 $pt$05 = 0;
 while(1) {
  $7 = (($paramsBuffer) + ($pt$05<<2)|0);
  HEAP32[$7>>2] = 0;
  $8 = (($programs) + ($pt$05<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = HEAP32[$9>>2]|0;
   $12 = (($11) + 156|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)>(0);
   if ($14) {
    $15 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $15;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
    $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($13,16,$$byval_copy6,0,679600,52)|0);
    HEAP32[$7>>2] = $16;
    (__ZNK20GpuProgramParameters13PrepareValuesEPKN9ShaderLab13PropertySheetERKNS0_17ShaderPassContextEPhPKhP12GfxPatchInfoPb($11,$props,$passContext,$16,0,0,0)|0);
   }
  }
  $17 = (($pt$05) + 1)|0;
  $exitcond = ($17|0)==(6);
  if ($exitcond) {
   break;
  } else {
   $pt$05 = $17;
  }
 }
 $5 = HEAP32[$programs>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  HEAP32[$gpuPrograms>>2] = 0;
 } else {
  $18 = (($5) + 40|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$gpuPrograms>>2] = $19;
 }
 $20 = (($programs) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $75 = (($gpuPrograms) + 4|0);
  HEAP32[$75>>2] = 0;
 } else {
  $72 = (($21) + 40|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($gpuPrograms) + 4|0);
  HEAP32[$74>>2] = $73;
 }
 $76 = (($programs) + 8|0);
 $53 = HEAP32[$76>>2]|0;
 $77 = ($53|0)==(0|0);
 if ($77) {
  $81 = (($gpuPrograms) + 8|0);
  HEAP32[$81>>2] = 0;
 } else {
  $78 = (($53) + 40|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = (($gpuPrograms) + 8|0);
  HEAP32[$80>>2] = $79;
 }
 $82 = (($programs) + 12|0);
 $57 = HEAP32[$82>>2]|0;
 $83 = ($57|0)==(0|0);
 if ($83) {
  $87 = (($gpuPrograms) + 12|0);
  HEAP32[$87>>2] = 0;
 } else {
  $84 = (($57) + 40|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($gpuPrograms) + 12|0);
  HEAP32[$86>>2] = $85;
 }
 $88 = (($programs) + 16|0);
 $61 = HEAP32[$88>>2]|0;
 $89 = ($61|0)==(0|0);
 if ($89) {
  $93 = (($gpuPrograms) + 16|0);
  HEAP32[$93>>2] = 0;
 } else {
  $90 = (($61) + 40|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($gpuPrograms) + 16|0);
  HEAP32[$92>>2] = $91;
 }
 $94 = (($programs) + 20|0);
 $65 = HEAP32[$94>>2]|0;
 $95 = ($65|0)==(0|0);
 if ($95) {
  $99 = (($gpuPrograms) + 20|0);
  HEAP32[$99>>2] = 0;
 } else {
  $96 = (($65) + 40|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (($gpuPrograms) + 20|0);
  HEAP32[$98>>2] = $97;
 }
 if ($6) {
  HEAP32[$params2>>2] = 0;
 } else {
  $23 = HEAP32[$5>>2]|0;
  HEAP32[$params2>>2] = $23;
 }
 if ($22) {
  $51 = (($params2) + 4|0);
  HEAP32[$51>>2] = 0;
 } else {
  $49 = HEAP32[$21>>2]|0;
  $50 = (($params2) + 4|0);
  HEAP32[$50>>2] = $49;
 }
 if ($77) {
  $55 = (($params2) + 8|0);
  HEAP32[$55>>2] = 0;
 } else {
  $52 = HEAP32[$53>>2]|0;
  $54 = (($params2) + 8|0);
  HEAP32[$54>>2] = $52;
 }
 if ($83) {
  $59 = (($params2) + 12|0);
  HEAP32[$59>>2] = 0;
 } else {
  $56 = HEAP32[$57>>2]|0;
  $58 = (($params2) + 12|0);
  HEAP32[$58>>2] = $56;
 }
 if ($89) {
  $63 = (($params2) + 16|0);
  HEAP32[$63>>2] = 0;
 } else {
  $60 = HEAP32[$61>>2]|0;
  $62 = (($params2) + 16|0);
  HEAP32[$62>>2] = $60;
 }
 if ($95) {
  $67 = (($params2) + 20|0);
  HEAP32[$67>>2] = 0;
 } else {
  $64 = HEAP32[$65>>2]|0;
  $66 = (($params2) + 20|0);
  HEAP32[$66>>2] = $64;
 }
 $68 = HEAP32[$device>>2]|0;
 $69 = (($68) + 808|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_viiii[$70 & 511]($device,$gpuPrograms,$params2,$paramsBuffer);
 $25 = HEAP32[$paramsBuffer>>2]|0;
 $71 = ($25|0)==(0|0);
 if (!($71)) {
  $24 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $24;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy6);
 }
 $26 = (($paramsBuffer) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $32 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $32;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy6);
 }
 $33 = (($paramsBuffer) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $36;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($34,$$byval_copy6);
 }
 $37 = (($paramsBuffer) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $40;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($38,$$byval_copy6);
 }
 $41 = (($paramsBuffer) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if (!($43)) {
  $44 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $44;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($42,$$byval_copy6);
 }
 $45 = (($paramsBuffer) + 20|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 if ($47) {
  STACKTOP = sp;return;
 }
 $48 = HEAP32[628512>>2]|0;
 HEAP32[$1>>2] = $48;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($46,$$byval_copy6);
 STACKTOP = sp;return;
}
function __ZNK9ShaderLab11ShaderState29GetSupportsFullForwardShadowsEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$01 = 0;
 while(1) {
  $0 = ((($this) + ($i$01<<2)|0) + 292|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(0|0);
  if (!($2)) {
   $3 = (($1) + 141|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if (!($5)) {
    $$0 = 1;
    label = 5;
    break;
   }
  }
  $6 = (($i$01) + 1)|0;
  $7 = ($6|0)<(6);
  if ($7) {
   $i$01 = $6;
  } else {
   $$0 = 0;
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9ShaderLab13ParserProgramD2Ev($this) {
 $this = $this|0;
 var $$lcssa12 = 0, $$pre = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 do {
  if ($3) {
   $$lcssa12 = $0;$22 = $0;
  } else {
   $27 = $2;$5 = $0;
   while(1) {
    $4 = HEAP32[$5>>2]|0;
    $6 = ($4|0)==(0|0);
    if ($6) {
     $11 = $27;
    } else {
     __THREW__ = 0;
     invoke_vi(3600,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __ZdlPv($4);
     $$pre18 = HEAP32[$1>>2]|0;
     $11 = $$pre18;
    }
    $9 = (($5) + 4|0);
    $10 = ($9|0)==($11|0);
    if ($10) {
     label = 10;
     break;
    } else {
     $27 = $11;$5 = $9;
    }
   }
   if ((label|0) == 10) {
    $$pre = HEAP32[$this>>2]|0;
    $$lcssa12 = $11;$22 = $$pre;
    break;
   }
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   __ZdlPv($4);
   $14 = HEAP32[$this>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    ___resumeException($12|0);
    // unreachable;
   }
   $16 = HEAP32[$1>>2]|0;
   $17 = ($16|0)==($14|0);
   if (!($17)) {
    $__new_last2$i$i$i$i$i1 = $14;
    $scevgep$i$i$i$i$i2 = (($16) + -4|0);
    $18 = (0 - ($__new_last2$i$i$i$i$i1))|0;
    $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($18)|0);
    $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
    $19 = $uglygep3$i$i$i$i$i5 >>> 2;
    $20 = $19 ^ -1;
    $scevgep4$i$i$i$i$i6 = (($16) + ($20<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i6;
   }
   __ZdlPv($14);
   ___resumeException($12|0);
   // unreachable;
  }
 } while(0);
 $21 = ($22|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $23 = ($$lcssa12|0)==($22|0);
 if (!($23)) {
  $__new_last2$i$i$i$i$i = $22;
  $scevgep$i$i$i$i$i = (($$lcssa12) + -4|0);
  $24 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($24)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $25 = $uglygep3$i$i$i$i$i >>> 2;
  $26 = $25 ^ -1;
  $scevgep4$i$i$i$i$i = (($$lcssa12) + ($26<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($22);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab16ParserSubProgram11SetKeywordsERKNSt3__16vectorINS1_12basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEENS6_IS8_EEEE($this,$keywords) {
 $this = $this|0;
 $keywords = $keywords|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $1 = (($keywords) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$keywords>>2]|0;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $6 = $3;$i$01 = 0;
 }
 while(1) {
  $5 = (($6) + (($i$01*12)|0)|0);
  $7 = HEAP8[$5>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   $12 = (($5) + 1|0);
   $13 = $12;
  } else {
   $10 = ((($6) + (($i$01*12)|0)|0) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $13 = $11;
  }
  $14 = (__ZN8keywords6CreateEPKc($13)|0);
  $15 = $14 & 31;
  $16 = 1 << $15;
  $17 = $14 >>> 5;
  $18 = ((($this) + ($17<<2)|0) + 132|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $16 | $19;
  HEAP32[$18>>2] = $20;
  $21 = (($i$01) + 1)|0;
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$keywords>>2]|0;
  $24 = $22;
  $25 = $23;
  $26 = (($24) - ($25))|0;
  $27 = (($26|0) / 12)&-1;
  $28 = ($21>>>0)<($27>>>0);
  if ($28) {
   $6 = $23;$i$01 = $21;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab16ParserSubProgram14SetConstBufferEPKci($this,$name,$usedSize) {
 $this = $this|0;
 $name = $name|0;
 $usedSize = $usedSize|0;
 var $$0 = 0, $$01 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (_strlen(($name|0))|0);
 $3 = ($2>>>0)>(4294967279);
 if ($3) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $4 = ($2>>>0)<(11);
 if ($4) {
  $5 = $2 << 1;
  $6 = $5&255;
  HEAP8[$1>>0] = $6;
  $7 = (($1) + 1|0);
  $$pre$phiZ2D = $1;$17 = $6;$__p$0$i$i$i = $7;
 } else {
  $8 = (($2) + 16)|0;
  $9 = $8 & -16;
  $10 = (__Znwj($9)|0);
  $11 = (($1) + 8|0);
  HEAP32[$11>>2] = $10;
  $12 = $9 | 1;
  HEAP32[$1>>2] = $12;
  $13 = (($1) + 4|0);
  HEAP32[$13>>2] = $2;
  $14 = $12&255;
  $$pre$phiZ2D = $1;$17 = $14;$__p$0$i$i$i = $10;
 }
 _memcpy(($__p$0$i$i$i|0),($name|0),($2|0))|0;
 $15 = (($__p$0$i$i$i) + ($2)|0);
 HEAP8[$15>>0] = 0;
 $16 = $17 & 1;
 $18 = ($16<<24>>24)==(0);
 do {
  if ($18) {
   ;HEAP32[$0+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
   label = 16;
  } else {
   $19 = (($1) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($1) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22>>>0)>(4294967279);
   if ($23) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     label = 26;
     break;
    }
    // unreachable;
   }
   $26 = ($22>>>0)<(11);
   if ($26) {
    $27 = $22 << 1;
    $28 = $27&255;
    HEAP8[$0>>0] = $28;
    $29 = (($0) + 1|0);
    $__p$0$i$i$i$i$i = $29;
   } else {
    $30 = (($22) + 16)|0;
    $31 = $30 & -16;
    __THREW__ = 0;
    $32 = (invoke_ii(2988,($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     label = 26;
     break;
    }
    $35 = (($0) + 8|0);
    HEAP32[$35>>2] = $32;
    $36 = $31 | 1;
    HEAP32[$0>>2] = $36;
    $37 = (($0) + 4|0);
    HEAP32[$37>>2] = $22;
    $__p$0$i$i$i$i$i = $32;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($20|0),($22|0))|0;
   $38 = (($__p$0$i$i$i$i$i) + ($22)|0);
   HEAP8[$38>>0] = 0;
   label = 16;
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   $39 = (($0) + 12|0);
   $40 = (($0) + 36|0);
   ;HEAP32[$39+0>>2]=0|0;HEAP32[$39+4>>2]=0|0;HEAP32[$39+8>>2]=0|0;HEAP32[$39+12>>2]=0|0;HEAP32[$39+16>>2]=0|0;HEAP32[$39+20>>2]=0|0;
   HEAP32[$40>>2] = $usedSize;
   $41 = (($this) + 200|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($this) + 204|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($42|0)==($44|0);
   do {
    if ($45) {
     $51 = (($this) + 196|0);
     __THREW__ = 0;
     invoke_vii(3271,($51|0),($0|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      label = 27;
     }
    } else {
     $46 = ($42|0)==(0|0);
     if ($46) {
      $50 = 0;
     } else {
      __THREW__ = 0;
      invoke_vii(3270,($42|0),($0|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 27;
       break;
      }
      $$pre$i = HEAP32[$41>>2]|0;
      $50 = $$pre$i;
     }
     $49 = (($50) + 40|0);
     HEAP32[$41>>2] = $49;
    }
   } while(0);
   if ((label|0) == 27) {
    $62 = ___cxa_find_matching_catch()|0;
    $63 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3574,($0|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if (!($65)) {
     $$0 = $63;$$01 = $62;
     break;
    }
    $70 = ___cxa_find_matching_catch(0|0)|0;
    $71 = tempRet0;
    ___clang_call_terminate($70);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3574,($0|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    label = 26;
   } else {
    $56 = $17 & 1;
    $57 = ($56<<24>>24)==(0);
    if ($57) {
     STACKTOP = sp;return;
    }
    $58 = (($1) + 8|0);
    $59 = HEAP32[$58>>2]|0;
    __ZdlPv($59);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 26) {
  $60 = ___cxa_find_matching_catch()|0;
  $61 = tempRet0;
  $$0 = $61;$$01 = $60;
 }
 $66 = $17 & 1;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $68 = (($1) + 8|0);
 $69 = HEAP32[$68>>2]|0;
 __ZdlPv($69);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN9ShaderLab16ParserSubProgram6BindCBEPKci($this,$name,$bindIndex) {
 $this = $this|0;
 $name = $name|0;
 $bindIndex = $bindIndex|0;
 var $$0 = 0, $$01 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (_strlen(($name|0))|0);
 $3 = ($2>>>0)>(4294967279);
 if ($3) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $4 = ($2>>>0)<(11);
 if ($4) {
  $5 = $2 << 1;
  $6 = $5&255;
  HEAP8[$1>>0] = $6;
  $7 = (($1) + 1|0);
  $$pre$phiZ2D = $1;$17 = $6;$__p$0$i$i$i = $7;
 } else {
  $8 = (($2) + 16)|0;
  $9 = $8 & -16;
  $10 = (__Znwj($9)|0);
  $11 = (($1) + 8|0);
  HEAP32[$11>>2] = $10;
  $12 = $9 | 1;
  HEAP32[$1>>2] = $12;
  $13 = (($1) + 4|0);
  HEAP32[$13>>2] = $2;
  $14 = $12&255;
  $$pre$phiZ2D = $1;$17 = $14;$__p$0$i$i$i = $10;
 }
 _memcpy(($__p$0$i$i$i|0),($name|0),($2|0))|0;
 $15 = (($__p$0$i$i$i) + ($2)|0);
 HEAP8[$15>>0] = 0;
 $16 = $17 & 1;
 $18 = ($16<<24>>24)==(0);
 L8: do {
  if ($18) {
   ;HEAP32[$0+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
   label = 16;
  } else {
   $19 = (($1) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($1) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22>>>0)>(4294967279);
   do {
    if ($23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      // unreachable;
     }
    } else {
     $26 = ($22>>>0)<(11);
     if ($26) {
      $27 = $22 << 1;
      $28 = $27&255;
      HEAP8[$0>>0] = $28;
      $29 = (($0) + 1|0);
      $__p$0$i$i$i$i$i = $29;
     } else {
      $30 = (($22) + 16)|0;
      $31 = $30 & -16;
      __THREW__ = 0;
      $32 = (invoke_ii(2988,($31|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = (($0) + 8|0);
      HEAP32[$35>>2] = $32;
      $36 = $31 | 1;
      HEAP32[$0>>2] = $36;
      $37 = (($0) + 4|0);
      HEAP32[$37>>2] = $22;
      $__p$0$i$i$i$i$i = $32;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($20|0),($22|0))|0;
     $38 = (($__p$0$i$i$i$i$i) + ($22)|0);
     HEAP8[$38>>0] = 0;
     label = 16;
     break L8;
    }
   } while(0);
   $84 = ___cxa_find_matching_catch()|0;
   $85 = tempRet0;
   $$0 = $85;$$01 = $84;
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   $39 = (($0) + 12|0);
   HEAP32[$39>>2] = $bindIndex;
   $40 = (($this) + 212|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($this) + 216|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($41|0)==($43|0);
   do {
    if ($44) {
     $72 = (($this) + 208|0);
     __THREW__ = 0;
     invoke_vii(3229,($72|0),($0|0));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      label = 37;
     }
    } else {
     $45 = ($41|0)==(0|0);
     if ($45) {
      $71 = 0;
     } else {
      $46 = HEAP8[$0>>0]|0;
      $47 = $46 & 1;
      $48 = ($47<<24>>24)==(0);
      if ($48) {
       ;HEAP32[$41+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$0+8>>2]|0;
      } else {
       $49 = (($0) + 8|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = (($0) + 4|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52>>>0)>(4294967279);
       if ($53) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 37;
         break;
        }
        // unreachable;
       }
       $56 = ($52>>>0)<(11);
       if ($56) {
        $57 = $52 << 1;
        $58 = $57&255;
        HEAP8[$41>>0] = $58;
        $59 = (($41) + 1|0);
        $__p$0$i$i$i$i$i$i$i = $59;
       } else {
        $60 = (($52) + 16)|0;
        $61 = $60 & -16;
        __THREW__ = 0;
        $62 = (invoke_ii(2988,($61|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 37;
         break;
        }
        $65 = (($41) + 8|0);
        HEAP32[$65>>2] = $62;
        $66 = $61 | 1;
        HEAP32[$41>>2] = $66;
        $67 = (($41) + 4|0);
        HEAP32[$67>>2] = $52;
        $__p$0$i$i$i$i$i$i$i = $62;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i|0),($50|0),($52|0))|0;
       $68 = (($__p$0$i$i$i$i$i$i$i) + ($52)|0);
       HEAP8[$68>>0] = 0;
      }
      $69 = (($41) + 12|0);
      HEAP32[$69>>2] = $bindIndex;
      $$pre$i = HEAP32[$40>>2]|0;
      $71 = $$pre$i;
     }
     $70 = (($71) + 16|0);
     HEAP32[$40>>2] = $70;
    }
   } while(0);
   if ((label|0) == 37) {
    $86 = ___cxa_find_matching_catch()|0;
    $87 = tempRet0;
    $88 = HEAP8[$0>>0]|0;
    $89 = $88 & 1;
    $90 = ($89<<24>>24)==(0);
    if ($90) {
     $$0 = $87;$$01 = $86;
     break;
    }
    $91 = (($0) + 8|0);
    $92 = HEAP32[$91>>2]|0;
    __ZdlPv($92);
    $$0 = $87;$$01 = $86;
    break;
   }
   $75 = HEAP8[$0>>0]|0;
   $76 = $75 & 1;
   $77 = ($76<<24>>24)==(0);
   if (!($77)) {
    $78 = (($0) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    __ZdlPv($79);
   }
   $80 = $17 & 1;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = (($1) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   __ZdlPv($83);
   STACKTOP = sp;return;
  }
 } while(0);
 $93 = $17 & 1;
 $94 = ($93<<24>>24)==(0);
 if ($94) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $95 = (($1) + 8|0);
 $96 = HEAP32[$95>>2]|0;
 __ZdlPv($96);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN9ShaderLab16ParserSubProgram14AddVectorParamE15ShaderParamTypeiiRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE($this,$type,$index,$dimension,$name) {
 $this = $this|0;
 $type = $type|0;
 $index = $index|0;
 $dimension = $dimension|0;
 $name = $name|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 200|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $6 = (($this) + 148|0);
 $7 = (($4) + -16|0);
 $8 = $5 ? $6 : $7;
 $9 = HEAP8[$name>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  ;HEAP32[$0+0>>2]=HEAP32[$name+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$name+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$name+8>>2]|0;
 } else {
  $12 = (($name) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($name) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15>>>0)>(4294967279);
  if ($16) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $17 = ($15>>>0)<(11);
  if ($17) {
   $18 = $15 << 1;
   $19 = $18&255;
   HEAP8[$0>>0] = $19;
   $20 = (($0) + 1|0);
   $__p$0$i$i$i$i$i = $20;
  } else {
   $21 = (($15) + 16)|0;
   $22 = $21 & -16;
   $23 = (__Znwj($22)|0);
   $24 = (($0) + 8|0);
   HEAP32[$24>>2] = $23;
   $25 = $22 | 1;
   HEAP32[$0>>2] = $25;
   $26 = (($0) + 4|0);
   HEAP32[$26>>2] = $15;
   $__p$0$i$i$i$i$i = $23;
  }
  _memcpy(($__p$0$i$i$i$i$i|0),($13|0),($15|0))|0;
  $27 = (($__p$0$i$i$i$i$i) + ($15)|0);
  HEAP8[$27>>0] = 0;
 }
 $28 = (($0) + 12|0);
 HEAP32[$28>>2] = $type;
 $29 = (($0) + 16|0);
 HEAP32[$29>>2] = $index;
 $30 = (($0) + 20|0);
 HEAP32[$30>>2] = $dimension;
 $31 = (($8) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($8) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32|0)==($34|0);
 do {
  if ($35) {
   __THREW__ = 0;
   invoke_vii(3272,($8|0),($0|0));
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    label = 27;
   } else {
    label = 24;
   }
  } else {
   $36 = ($32|0)==(0|0);
   if ($36) {
    $62 = 0;
   } else {
    $37 = HEAP8[$0>>0]|0;
    $38 = $37 & 1;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     ;HEAP32[$32+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$0+8>>2]|0;
    } else {
     $40 = (($0) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($0) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43>>>0)>(4294967279);
     if ($44) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 27;
       break;
      }
      // unreachable;
     }
     $47 = ($43>>>0)<(11);
     if ($47) {
      $48 = $43 << 1;
      $49 = $48&255;
      HEAP8[$32>>0] = $49;
      $50 = (($32) + 1|0);
      $__p$0$i$i$i$i$i$i$i = $50;
     } else {
      $51 = (($43) + 16)|0;
      $52 = $51 & -16;
      __THREW__ = 0;
      $53 = (invoke_ii(2988,($52|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 27;
       break;
      }
      $56 = (($32) + 8|0);
      HEAP32[$56>>2] = $53;
      $57 = $52 | 1;
      HEAP32[$32>>2] = $57;
      $58 = (($32) + 4|0);
      HEAP32[$58>>2] = $43;
      $__p$0$i$i$i$i$i$i$i = $53;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($41|0),($43|0))|0;
     $59 = (($__p$0$i$i$i$i$i$i$i) + ($43)|0);
     HEAP8[$59>>0] = 0;
    }
    $60 = (($32) + 12|0);
    ;HEAP32[$60+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$60+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$60+8>>2]=HEAP32[$28+8>>2]|0;
    $$pre$i = HEAP32[$31>>2]|0;
    $62 = $$pre$i;
   }
   $61 = (($62) + 24|0);
   HEAP32[$31>>2] = $61;
   label = 24;
  }
 } while(0);
 if ((label|0) == 24) {
  $65 = HEAP8[$0>>0]|0;
  $66 = $65 & 1;
  $67 = ($66<<24>>24)==(0);
  if ($67) {
   STACKTOP = sp;return;
  }
  $68 = (($0) + 8|0);
  $69 = HEAP32[$68>>2]|0;
  __ZdlPv($69);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 27) {
  $70 = ___cxa_find_matching_catch()|0;
  $71 = tempRet0;
  $72 = HEAP8[$0>>0]|0;
  $73 = $72 & 1;
  $74 = ($73<<24>>24)==(0);
  if ($74) {
   ___resumeException($70|0);
   // unreachable;
  }
  $75 = (($0) + 8|0);
  $76 = HEAP32[$75>>2]|0;
  __ZdlPv($76);
  ___resumeException($70|0);
  // unreachable;
 }
}
function __ZN9ShaderLab16ParserSubProgram14AddMatrixParamE15ShaderParamTypeiRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEi($this,$type,$index,$name,$rowCount) {
 $this = $this|0;
 $type = $type|0;
 $index = $index|0;
 $name = $name|0;
 $rowCount = $rowCount|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 200|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $6 = (($this) + 160|0);
 $7 = (($4) + -28|0);
 $8 = $5 ? $6 : $7;
 $9 = HEAP8[$name>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  ;HEAP32[$0+0>>2]=HEAP32[$name+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$name+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$name+8>>2]|0;
 } else {
  $12 = (($name) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($name) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15>>>0)>(4294967279);
  if ($16) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $17 = ($15>>>0)<(11);
  if ($17) {
   $18 = $15 << 1;
   $19 = $18&255;
   HEAP8[$0>>0] = $19;
   $20 = (($0) + 1|0);
   $__p$0$i$i$i$i$i = $20;
  } else {
   $21 = (($15) + 16)|0;
   $22 = $21 & -16;
   $23 = (__Znwj($22)|0);
   $24 = (($0) + 8|0);
   HEAP32[$24>>2] = $23;
   $25 = $22 | 1;
   HEAP32[$0>>2] = $25;
   $26 = (($0) + 4|0);
   HEAP32[$26>>2] = $15;
   $__p$0$i$i$i$i$i = $23;
  }
  _memcpy(($__p$0$i$i$i$i$i|0),($13|0),($15|0))|0;
  $27 = (($__p$0$i$i$i$i$i) + ($15)|0);
  HEAP8[$27>>0] = 0;
 }
 $28 = (($0) + 12|0);
 HEAP32[$28>>2] = $type;
 $29 = (($0) + 16|0);
 HEAP32[$29>>2] = $index;
 $30 = (($0) + 20|0);
 HEAP32[$30>>2] = $rowCount;
 $31 = (($8) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($8) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32|0)==($34|0);
 do {
  if ($35) {
   __THREW__ = 0;
   invoke_vii(3273,($8|0),($0|0));
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if ($64) {
    label = 27;
   } else {
    label = 24;
   }
  } else {
   $36 = ($32|0)==(0|0);
   if ($36) {
    $62 = 0;
   } else {
    $37 = HEAP8[$0>>0]|0;
    $38 = $37 & 1;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     ;HEAP32[$32+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$32+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$0+8>>2]|0;
    } else {
     $40 = (($0) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($0) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43>>>0)>(4294967279);
     if ($44) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 27;
       break;
      }
      // unreachable;
     }
     $47 = ($43>>>0)<(11);
     if ($47) {
      $48 = $43 << 1;
      $49 = $48&255;
      HEAP8[$32>>0] = $49;
      $50 = (($32) + 1|0);
      $__p$0$i$i$i$i$i$i$i = $50;
     } else {
      $51 = (($43) + 16)|0;
      $52 = $51 & -16;
      __THREW__ = 0;
      $53 = (invoke_ii(2988,($52|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 27;
       break;
      }
      $56 = (($32) + 8|0);
      HEAP32[$56>>2] = $53;
      $57 = $52 | 1;
      HEAP32[$32>>2] = $57;
      $58 = (($32) + 4|0);
      HEAP32[$58>>2] = $43;
      $__p$0$i$i$i$i$i$i$i = $53;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($41|0),($43|0))|0;
     $59 = (($__p$0$i$i$i$i$i$i$i) + ($43)|0);
     HEAP8[$59>>0] = 0;
    }
    $60 = (($32) + 12|0);
    ;HEAP32[$60+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$60+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$60+8>>2]=HEAP32[$28+8>>2]|0;
    $$pre$i = HEAP32[$31>>2]|0;
    $62 = $$pre$i;
   }
   $61 = (($62) + 24|0);
   HEAP32[$31>>2] = $61;
   label = 24;
  }
 } while(0);
 if ((label|0) == 24) {
  $65 = HEAP8[$0>>0]|0;
  $66 = $65 & 1;
  $67 = ($66<<24>>24)==(0);
  if ($67) {
   STACKTOP = sp;return;
  }
  $68 = (($0) + 8|0);
  $69 = HEAP32[$68>>2]|0;
  __ZdlPv($69);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 27) {
  $70 = ___cxa_find_matching_catch()|0;
  $71 = tempRet0;
  $72 = HEAP8[$0>>0]|0;
  $73 = $72 & 1;
  $74 = ($73<<24>>24)==(0);
  if ($74) {
   ___resumeException($70|0);
   // unreachable;
  }
  $75 = (($0) + 8|0);
  $76 = HEAP32[$75>>2]|0;
  __ZdlPv($76);
  ___resumeException($70|0);
  // unreachable;
 }
}
function __ZN9ShaderLab16ParserSubProgram15AddTextureParamEiPKc16TextureDimensioni($this,$index,$setTexture,$textureDimension,$sampler) {
 $this = $this|0;
 $index = $index|0;
 $setTexture = $setTexture|0;
 $textureDimension = $textureDimension|0;
 $sampler = $sampler|0;
 var $$0 = 0, $$01 = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (_strlen(($setTexture|0))|0);
 $3 = ($2>>>0)>(4294967279);
 if ($3) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $4 = ($2>>>0)<(11);
 if ($4) {
  $5 = $2 << 1;
  $6 = $5&255;
  HEAP8[$1>>0] = $6;
  $7 = (($1) + 1|0);
  $$pre$phiZ2D = $1;$17 = $6;$__p$0$i$i$i = $7;
 } else {
  $8 = (($2) + 16)|0;
  $9 = $8 & -16;
  $10 = (__Znwj($9)|0);
  $11 = (($1) + 8|0);
  HEAP32[$11>>2] = $10;
  $12 = $9 | 1;
  HEAP32[$1>>2] = $12;
  $13 = (($1) + 4|0);
  HEAP32[$13>>2] = $2;
  $14 = $12&255;
  $$pre$phiZ2D = $1;$17 = $14;$__p$0$i$i$i = $10;
 }
 _memcpy(($__p$0$i$i$i|0),($setTexture|0),($2|0))|0;
 $15 = (($__p$0$i$i$i) + ($2)|0);
 HEAP8[$15>>0] = 0;
 $16 = $17 & 1;
 $18 = ($16<<24>>24)==(0);
 L8: do {
  if ($18) {
   ;HEAP32[$0+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
   label = 16;
  } else {
   $19 = (($1) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($1) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22>>>0)>(4294967279);
   do {
    if ($23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      // unreachable;
     }
    } else {
     $26 = ($22>>>0)<(11);
     if ($26) {
      $27 = $22 << 1;
      $28 = $27&255;
      HEAP8[$0>>0] = $28;
      $29 = (($0) + 1|0);
      $__p$0$i$i$i$i$i = $29;
     } else {
      $30 = (($22) + 16)|0;
      $31 = $30 & -16;
      __THREW__ = 0;
      $32 = (invoke_ii(2988,($31|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = (($0) + 8|0);
      HEAP32[$35>>2] = $32;
      $36 = $31 | 1;
      HEAP32[$0>>2] = $36;
      $37 = (($0) + 4|0);
      HEAP32[$37>>2] = $22;
      $__p$0$i$i$i$i$i = $32;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($20|0),($22|0))|0;
     $38 = (($__p$0$i$i$i$i$i) + ($22)|0);
     HEAP8[$38>>0] = 0;
     label = 16;
     break L8;
    }
   } while(0);
   $86 = ___cxa_find_matching_catch()|0;
   $87 = tempRet0;
   $$0 = $87;$$01 = $86;
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   $39 = (($0) + 12|0);
   HEAP32[$39>>2] = $index;
   $40 = (($0) + 16|0);
   HEAP32[$40>>2] = $sampler;
   $41 = (($0) + 20|0);
   HEAP32[$41>>2] = $textureDimension;
   $42 = (($this) + 176|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($this) + 180|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($43|0)==($45|0);
   do {
    if ($46) {
     $74 = (($this) + 172|0);
     __THREW__ = 0;
     invoke_vii(3274,($74|0),($0|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      label = 37;
     }
    } else {
     $47 = ($43|0)==(0|0);
     if ($47) {
      $73 = 0;
     } else {
      $48 = HEAP8[$0>>0]|0;
      $49 = $48 & 1;
      $50 = ($49<<24>>24)==(0);
      if ($50) {
       ;HEAP32[$43+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$0+8>>2]|0;
      } else {
       $51 = (($0) + 8|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($0) + 4|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = ($54>>>0)>(4294967279);
       if ($55) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 37;
         break;
        }
        // unreachable;
       }
       $58 = ($54>>>0)<(11);
       if ($58) {
        $59 = $54 << 1;
        $60 = $59&255;
        HEAP8[$43>>0] = $60;
        $61 = (($43) + 1|0);
        $__p$0$i$i$i$i$i$i$i = $61;
       } else {
        $62 = (($54) + 16)|0;
        $63 = $62 & -16;
        __THREW__ = 0;
        $64 = (invoke_ii(2988,($63|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 37;
         break;
        }
        $67 = (($43) + 8|0);
        HEAP32[$67>>2] = $64;
        $68 = $63 | 1;
        HEAP32[$43>>2] = $68;
        $69 = (($43) + 4|0);
        HEAP32[$69>>2] = $54;
        $__p$0$i$i$i$i$i$i$i = $64;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i|0),($52|0),($54|0))|0;
       $70 = (($__p$0$i$i$i$i$i$i$i) + ($54)|0);
       HEAP8[$70>>0] = 0;
      }
      $71 = (($43) + 12|0);
      ;HEAP32[$71+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$39+8>>2]|0;
      $$pre$i = HEAP32[$42>>2]|0;
      $73 = $$pre$i;
     }
     $72 = (($73) + 24|0);
     HEAP32[$42>>2] = $72;
    }
   } while(0);
   if ((label|0) == 37) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    $90 = HEAP8[$0>>0]|0;
    $91 = $90 & 1;
    $92 = ($91<<24>>24)==(0);
    if ($92) {
     $$0 = $89;$$01 = $88;
     break;
    }
    $93 = (($0) + 8|0);
    $94 = HEAP32[$93>>2]|0;
    __ZdlPv($94);
    $$0 = $89;$$01 = $88;
    break;
   }
   $77 = HEAP8[$0>>0]|0;
   $78 = $77 & 1;
   $79 = ($78<<24>>24)==(0);
   if (!($79)) {
    $80 = (($0) + 8|0);
    $81 = HEAP32[$80>>2]|0;
    __ZdlPv($81);
   }
   $82 = $17 & 1;
   $83 = ($82<<24>>24)==(0);
   if ($83) {
    STACKTOP = sp;return;
   }
   $84 = (($1) + 8|0);
   $85 = HEAP32[$84>>2]|0;
   __ZdlPv($85);
   STACKTOP = sp;return;
  }
 } while(0);
 $95 = $17 & 1;
 $96 = ($95<<24>>24)==(0);
 if ($96) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $97 = (($1) + 8|0);
 $98 = HEAP32[$97>>2]|0;
 __ZdlPv($98);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN9ShaderLab16ParserProperties16AddFloatPropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEEf($this,$name,$desc,$attribs,$def) {
 $this = $this|0;
 $name = $name|0;
 $desc = $desc|0;
 $attribs = $attribs|0;
 $def = Math_fround($def);
 var $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i6 = 0, $$pre$i$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $p = sp;
 __ZN9ShaderLab14ParserPropertyC2EPKcS2_NS0_4TypeERKNSt3__16vectorINS4_12basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEENS9_ISB_EEEE($p,$name,$desc,2,$attribs);
 $0 = (($p) + 44|0);
 HEAPF32[$0>>2] = $def;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   __THREW__ = 0;
   invoke_vii(3276,($this|0),($p|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 21;
   } else {
    label = 7;
   }
  } else {
   $6 = ($2|0)==(0|0);
   if ($6) {
    $10 = 0;
   } else {
    __THREW__ = 0;
    invoke_vii(3275,($2|0),($p|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     label = 21;
     break;
    }
    $$pre$i = HEAP32[$1>>2]|0;
    $10 = $$pre$i;
   }
   $9 = (($10) + 76|0);
   HEAP32[$1>>2] = $9;
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $13 = (($p) + 60|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   $17 = (($p) + 68|0);
   $18 = HEAP32[$17>>2]|0;
   __ZdlPv($18);
  }
  $19 = (($p) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = (($p) + 28|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==($20|0);
   if ($24) {
    $34 = $20;
   } else {
    $26 = $23;
    while(1) {
     $25 = (($26) + -12|0);
     HEAP32[$22>>2] = $25;
     $27 = HEAP8[$25>>0]|0;
     $28 = $27 & 1;
     $29 = ($28<<24>>24)==(0);
     if ($29) {
      $31 = $25;
     } else {
      $32 = (($26) + -4|0);
      $33 = HEAP32[$32>>2]|0;
      __ZdlPv($33);
      $$pre$i$i$i$i$i$i = HEAP32[$22>>2]|0;
      $31 = $$pre$i$i$i$i$i$i;
     }
     $30 = ($31|0)==($20|0);
     if ($30) {
      break;
     } else {
      $26 = $31;
     }
    }
    $$pre$i$i$i$i = HEAP32[$19>>2]|0;
    $34 = $$pre$i$i$i$i;
   }
   __ZdlPv($34);
  }
  $35 = (($p) + 12|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  if (!($38)) {
   $39 = (($p) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   __ZdlPv($40);
  }
  $41 = HEAP8[$p>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   STACKTOP = sp;return;
  }
  $44 = (($p) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  __ZdlPv($45);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $48 = (($p) + 60|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49 & 1;
  $51 = ($50<<24>>24)==(0);
  if (!($51)) {
   $52 = (($p) + 68|0);
   $53 = HEAP32[$52>>2]|0;
   __ZdlPv($53);
  }
  $54 = (($p) + 24|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = (($p) + 28|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==($55|0);
   if ($59) {
    $69 = $55;
   } else {
    $61 = $58;
    while(1) {
     $60 = (($61) + -12|0);
     HEAP32[$57>>2] = $60;
     $62 = HEAP8[$60>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $66 = $60;
     } else {
      $67 = (($61) + -4|0);
      $68 = HEAP32[$67>>2]|0;
      __ZdlPv($68);
      $$pre$i$i$i$i$i$i6 = HEAP32[$57>>2]|0;
      $66 = $$pre$i$i$i$i$i$i6;
     }
     $65 = ($66|0)==($55|0);
     if ($65) {
      break;
     } else {
      $61 = $66;
     }
    }
    $$pre$i$i$i$i7 = HEAP32[$54>>2]|0;
    $69 = $$pre$i$i$i$i7;
   }
   __ZdlPv($69);
  }
  $70 = (($p) + 12|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71 & 1;
  $73 = ($72<<24>>24)==(0);
  if (!($73)) {
   $74 = (($p) + 20|0);
   $75 = HEAP32[$74>>2]|0;
   __ZdlPv($75);
  }
  $76 = HEAP8[$p>>0]|0;
  $77 = $76 & 1;
  $78 = ($77<<24>>24)==(0);
  if ($78) {
   ___resumeException($46|0);
   // unreachable;
  }
  $79 = (($p) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  __ZdlPv($80);
  ___resumeException($46|0);
  // unreachable;
 }
}
function __ZN9ShaderLab16ParserProperties17AddVectorPropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEERK8Vector4f($this,$name,$desc,$attribs,$def) {
 $this = $this|0;
 $name = $name|0;
 $desc = $desc|0;
 $attribs = $attribs|0;
 $def = $def|0;
 var $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i5 = 0, $$pre$i$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $p = sp;
 __ZN9ShaderLab14ParserPropertyC2EPKcS2_NS0_4TypeERKNSt3__16vectorINS4_12basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEENS9_ISB_EEEE($p,$name,$desc,1,$attribs);
 $0 = (($p) + 44|0);
 ;HEAP32[$0+0>>2]=HEAP32[$def+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$def+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$def+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$def+12>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   __THREW__ = 0;
   invoke_vii(3276,($this|0),($p|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 21;
   } else {
    label = 7;
   }
  } else {
   $6 = ($2|0)==(0|0);
   if ($6) {
    $10 = 0;
   } else {
    __THREW__ = 0;
    invoke_vii(3275,($2|0),($p|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     label = 21;
     break;
    }
    $$pre$i = HEAP32[$1>>2]|0;
    $10 = $$pre$i;
   }
   $9 = (($10) + 76|0);
   HEAP32[$1>>2] = $9;
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $13 = (($p) + 60|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   $17 = (($p) + 68|0);
   $18 = HEAP32[$17>>2]|0;
   __ZdlPv($18);
  }
  $19 = (($p) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = (($p) + 28|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==($20|0);
   if ($24) {
    $34 = $20;
   } else {
    $26 = $23;
    while(1) {
     $25 = (($26) + -12|0);
     HEAP32[$22>>2] = $25;
     $27 = HEAP8[$25>>0]|0;
     $28 = $27 & 1;
     $29 = ($28<<24>>24)==(0);
     if ($29) {
      $31 = $25;
     } else {
      $32 = (($26) + -4|0);
      $33 = HEAP32[$32>>2]|0;
      __ZdlPv($33);
      $$pre$i$i$i$i$i$i5 = HEAP32[$22>>2]|0;
      $31 = $$pre$i$i$i$i$i$i5;
     }
     $30 = ($31|0)==($20|0);
     if ($30) {
      break;
     } else {
      $26 = $31;
     }
    }
    $$pre$i$i$i$i6 = HEAP32[$19>>2]|0;
    $34 = $$pre$i$i$i$i6;
   }
   __ZdlPv($34);
  }
  $35 = (($p) + 12|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  if (!($38)) {
   $39 = (($p) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   __ZdlPv($40);
  }
  $41 = HEAP8[$p>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   STACKTOP = sp;return;
  }
  $44 = (($p) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  __ZdlPv($45);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $48 = (($p) + 60|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49 & 1;
  $51 = ($50<<24>>24)==(0);
  if (!($51)) {
   $52 = (($p) + 68|0);
   $53 = HEAP32[$52>>2]|0;
   __ZdlPv($53);
  }
  $54 = (($p) + 24|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = (($p) + 28|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==($55|0);
   if ($59) {
    $69 = $55;
   } else {
    $61 = $58;
    while(1) {
     $60 = (($61) + -12|0);
     HEAP32[$57>>2] = $60;
     $62 = HEAP8[$60>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $66 = $60;
     } else {
      $67 = (($61) + -4|0);
      $68 = HEAP32[$67>>2]|0;
      __ZdlPv($68);
      $$pre$i$i$i$i$i$i = HEAP32[$57>>2]|0;
      $66 = $$pre$i$i$i$i$i$i;
     }
     $65 = ($66|0)==($55|0);
     if ($65) {
      break;
     } else {
      $61 = $66;
     }
    }
    $$pre$i$i$i$i = HEAP32[$54>>2]|0;
    $69 = $$pre$i$i$i$i;
   }
   __ZdlPv($69);
  }
  $70 = (($p) + 12|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71 & 1;
  $73 = ($72<<24>>24)==(0);
  if (!($73)) {
   $74 = (($p) + 20|0);
   $75 = HEAP32[$74>>2]|0;
   __ZdlPv($75);
  }
  $76 = HEAP8[$p>>0]|0;
  $77 = $76 & 1;
  $78 = ($77<<24>>24)==(0);
  if ($78) {
   ___resumeException($46|0);
   // unreachable;
  }
  $79 = (($p) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  __ZdlPv($80);
  ___resumeException($46|0);
  // unreachable;
 }
}
function __ZN9ShaderLab16ParserProperties16AddColorPropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEERK8Vector4f($this,$name,$desc,$attribs,$def) {
 $this = $this|0;
 $name = $name|0;
 $desc = $desc|0;
 $attribs = $attribs|0;
 $def = $def|0;
 var $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i5 = 0, $$pre$i$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $p = sp;
 __ZN9ShaderLab14ParserPropertyC2EPKcS2_NS0_4TypeERKNSt3__16vectorINS4_12basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEENS9_ISB_EEEE($p,$name,$desc,0,$attribs);
 $0 = (($p) + 44|0);
 ;HEAP32[$0+0>>2]=HEAP32[$def+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$def+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$def+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$def+12>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 do {
  if ($5) {
   __THREW__ = 0;
   invoke_vii(3276,($this|0),($p|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 21;
   } else {
    label = 7;
   }
  } else {
   $6 = ($2|0)==(0|0);
   if ($6) {
    $10 = 0;
   } else {
    __THREW__ = 0;
    invoke_vii(3275,($2|0),($p|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     label = 21;
     break;
    }
    $$pre$i = HEAP32[$1>>2]|0;
    $10 = $$pre$i;
   }
   $9 = (($10) + 76|0);
   HEAP32[$1>>2] = $9;
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $13 = (($p) + 60|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   $17 = (($p) + 68|0);
   $18 = HEAP32[$17>>2]|0;
   __ZdlPv($18);
  }
  $19 = (($p) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = (($p) + 28|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==($20|0);
   if ($24) {
    $34 = $20;
   } else {
    $26 = $23;
    while(1) {
     $25 = (($26) + -12|0);
     HEAP32[$22>>2] = $25;
     $27 = HEAP8[$25>>0]|0;
     $28 = $27 & 1;
     $29 = ($28<<24>>24)==(0);
     if ($29) {
      $31 = $25;
     } else {
      $32 = (($26) + -4|0);
      $33 = HEAP32[$32>>2]|0;
      __ZdlPv($33);
      $$pre$i$i$i$i$i$i5 = HEAP32[$22>>2]|0;
      $31 = $$pre$i$i$i$i$i$i5;
     }
     $30 = ($31|0)==($20|0);
     if ($30) {
      break;
     } else {
      $26 = $31;
     }
    }
    $$pre$i$i$i$i6 = HEAP32[$19>>2]|0;
    $34 = $$pre$i$i$i$i6;
   }
   __ZdlPv($34);
  }
  $35 = (($p) + 12|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36 & 1;
  $38 = ($37<<24>>24)==(0);
  if (!($38)) {
   $39 = (($p) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   __ZdlPv($40);
  }
  $41 = HEAP8[$p>>0]|0;
  $42 = $41 & 1;
  $43 = ($42<<24>>24)==(0);
  if ($43) {
   STACKTOP = sp;return;
  }
  $44 = (($p) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  __ZdlPv($45);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $48 = (($p) + 60|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49 & 1;
  $51 = ($50<<24>>24)==(0);
  if (!($51)) {
   $52 = (($p) + 68|0);
   $53 = HEAP32[$52>>2]|0;
   __ZdlPv($53);
  }
  $54 = (($p) + 24|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0|0);
  if (!($56)) {
   $57 = (($p) + 28|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==($55|0);
   if ($59) {
    $69 = $55;
   } else {
    $61 = $58;
    while(1) {
     $60 = (($61) + -12|0);
     HEAP32[$57>>2] = $60;
     $62 = HEAP8[$60>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $66 = $60;
     } else {
      $67 = (($61) + -4|0);
      $68 = HEAP32[$67>>2]|0;
      __ZdlPv($68);
      $$pre$i$i$i$i$i$i = HEAP32[$57>>2]|0;
      $66 = $$pre$i$i$i$i$i$i;
     }
     $65 = ($66|0)==($55|0);
     if ($65) {
      break;
     } else {
      $61 = $66;
     }
    }
    $$pre$i$i$i$i = HEAP32[$54>>2]|0;
    $69 = $$pre$i$i$i$i;
   }
   __ZdlPv($69);
  }
  $70 = (($p) + 12|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71 & 1;
  $73 = ($72<<24>>24)==(0);
  if (!($73)) {
   $74 = (($p) + 20|0);
   $75 = HEAP32[$74>>2]|0;
   __ZdlPv($75);
  }
  $76 = HEAP8[$p>>0]|0;
  $77 = $76 & 1;
  $78 = ($77<<24>>24)==(0);
  if ($78) {
   ___resumeException($46|0);
   // unreachable;
  }
  $79 = (($p) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  __ZdlPv($80);
  ___resumeException($46|0);
  // unreachable;
 }
}
function __ZN9ShaderLab16ParserProperties16AddRangePropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEEfff($this,$name,$desc,$attribs,$def,$begin,$end) {
 $this = $this|0;
 $name = $name|0;
 $desc = $desc|0;
 $attribs = $attribs|0;
 $def = Math_fround($def);
 $begin = Math_fround($begin);
 $end = Math_fround($end);
 var $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i6 = 0, $$pre$i$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $p = sp;
 __ZN9ShaderLab14ParserPropertyC2EPKcS2_NS0_4TypeERKNSt3__16vectorINS4_12basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEENS9_ISB_EEEE($p,$name,$desc,3,$attribs);
 $0 = (($p) + 44|0);
 HEAPF32[$0>>2] = $def;
 $1 = (($p) + 48|0);
 HEAPF32[$1>>2] = $begin;
 $2 = (($p) + 52|0);
 HEAPF32[$2>>2] = $end;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 do {
  if ($7) {
   __THREW__ = 0;
   invoke_vii(3276,($this|0),($p|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 21;
   } else {
    label = 7;
   }
  } else {
   $8 = ($4|0)==(0|0);
   if ($8) {
    $12 = 0;
   } else {
    __THREW__ = 0;
    invoke_vii(3275,($4|0),($p|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 21;
     break;
    }
    $$pre$i = HEAP32[$3>>2]|0;
    $12 = $$pre$i;
   }
   $11 = (($12) + 76|0);
   HEAP32[$3>>2] = $11;
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $15 = (($p) + 60|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  if (!($18)) {
   $19 = (($p) + 68|0);
   $20 = HEAP32[$19>>2]|0;
   __ZdlPv($20);
  }
  $21 = (($p) + 24|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $24 = (($p) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==($22|0);
   if ($26) {
    $36 = $22;
   } else {
    $28 = $25;
    while(1) {
     $27 = (($28) + -12|0);
     HEAP32[$24>>2] = $27;
     $29 = HEAP8[$27>>0]|0;
     $30 = $29 & 1;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      $33 = $27;
     } else {
      $34 = (($28) + -4|0);
      $35 = HEAP32[$34>>2]|0;
      __ZdlPv($35);
      $$pre$i$i$i$i$i$i = HEAP32[$24>>2]|0;
      $33 = $$pre$i$i$i$i$i$i;
     }
     $32 = ($33|0)==($22|0);
     if ($32) {
      break;
     } else {
      $28 = $33;
     }
    }
    $$pre$i$i$i$i = HEAP32[$21>>2]|0;
    $36 = $$pre$i$i$i$i;
   }
   __ZdlPv($36);
  }
  $37 = (($p) + 12|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if (!($40)) {
   $41 = (($p) + 20|0);
   $42 = HEAP32[$41>>2]|0;
   __ZdlPv($42);
  }
  $43 = HEAP8[$p>>0]|0;
  $44 = $43 & 1;
  $45 = ($44<<24>>24)==(0);
  if ($45) {
   STACKTOP = sp;return;
  }
  $46 = (($p) + 8|0);
  $47 = HEAP32[$46>>2]|0;
  __ZdlPv($47);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $50 = (($p) + 60|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51 & 1;
  $53 = ($52<<24>>24)==(0);
  if (!($53)) {
   $54 = (($p) + 68|0);
   $55 = HEAP32[$54>>2]|0;
   __ZdlPv($55);
  }
  $56 = (($p) + 24|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   $59 = (($p) + 28|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ($60|0)==($57|0);
   if ($61) {
    $71 = $57;
   } else {
    $63 = $60;
    while(1) {
     $62 = (($63) + -12|0);
     HEAP32[$59>>2] = $62;
     $64 = HEAP8[$62>>0]|0;
     $65 = $64 & 1;
     $66 = ($65<<24>>24)==(0);
     if ($66) {
      $68 = $62;
     } else {
      $69 = (($63) + -4|0);
      $70 = HEAP32[$69>>2]|0;
      __ZdlPv($70);
      $$pre$i$i$i$i$i$i6 = HEAP32[$59>>2]|0;
      $68 = $$pre$i$i$i$i$i$i6;
     }
     $67 = ($68|0)==($57|0);
     if ($67) {
      break;
     } else {
      $63 = $68;
     }
    }
    $$pre$i$i$i$i7 = HEAP32[$56>>2]|0;
    $71 = $$pre$i$i$i$i7;
   }
   __ZdlPv($71);
  }
  $72 = (($p) + 12|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = $73 & 1;
  $75 = ($74<<24>>24)==(0);
  if (!($75)) {
   $76 = (($p) + 20|0);
   $77 = HEAP32[$76>>2]|0;
   __ZdlPv($77);
  }
  $78 = HEAP8[$p>>0]|0;
  $79 = $78 & 1;
  $80 = ($79<<24>>24)==(0);
  if ($80) {
   ___resumeException($48|0);
   // unreachable;
  }
  $81 = (($p) + 8|0);
  $82 = HEAP32[$81>>2]|0;
  __ZdlPv($82);
  ___resumeException($48|0);
  // unreachable;
 }
}
function __ZN9ShaderLab16ParserProperties18AddTexturePropertyEPKcS2_RKNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEERKNS_21ParserTexturePropertyE($this,$name,$desc,$attribs,$tex) {
 $this = $this|0;
 $name = $name|0;
 $desc = $desc|0;
 $attribs = $attribs|0;
 $tex = $tex|0;
 var $$pre$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i6 = 0, $$pre$i$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $p = sp;
 __ZN9ShaderLab14ParserPropertyC2EPKcS2_NS0_4TypeERKNSt3__16vectorINS4_12basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEENS9_ISB_EEEE($p,$name,$desc,4,$attribs);
 $0 = (($p) + 60|0);
 __THREW__ = 0;
 (invoke_iii(2233,($0|0),($tex|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = (($tex) + 12|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($p) + 72|0);
   HEAP32[$5>>2] = $4;
   $6 = (($this) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($this) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)==($9|0);
   if ($10) {
    __THREW__ = 0;
    invoke_vii(3276,($this|0),($p|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
   } else {
    $11 = ($7|0)==(0|0);
    if ($11) {
     $15 = 0;
    } else {
     __THREW__ = 0;
     invoke_vii(3275,($7|0),($p|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $$pre$i = HEAP32[$6>>2]|0;
     $15 = $$pre$i;
    }
    $14 = (($15) + 76|0);
    HEAP32[$6>>2] = $14;
   }
   $18 = HEAP8[$0>>0]|0;
   $19 = $18 & 1;
   $20 = ($19<<24>>24)==(0);
   if (!($20)) {
    $21 = (($p) + 68|0);
    $22 = HEAP32[$21>>2]|0;
    __ZdlPv($22);
   }
   $23 = (($p) + 24|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = (($p) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==($24|0);
    if ($28) {
     $38 = $24;
    } else {
     $30 = $27;
     while(1) {
      $29 = (($30) + -12|0);
      HEAP32[$26>>2] = $29;
      $31 = HEAP8[$29>>0]|0;
      $32 = $31 & 1;
      $33 = ($32<<24>>24)==(0);
      if ($33) {
       $35 = $29;
      } else {
       $36 = (($30) + -4|0);
       $37 = HEAP32[$36>>2]|0;
       __ZdlPv($37);
       $$pre$i$i$i$i$i$i = HEAP32[$26>>2]|0;
       $35 = $$pre$i$i$i$i$i$i;
      }
      $34 = ($35|0)==($24|0);
      if ($34) {
       break;
      } else {
       $30 = $35;
      }
     }
     $$pre$i$i$i$i = HEAP32[$23>>2]|0;
     $38 = $$pre$i$i$i$i;
    }
    __ZdlPv($38);
   }
   $39 = (($p) + 12|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40 & 1;
   $42 = ($41<<24>>24)==(0);
   if (!($42)) {
    $43 = (($p) + 20|0);
    $44 = HEAP32[$43>>2]|0;
    __ZdlPv($44);
   }
   $45 = HEAP8[$p>>0]|0;
   $46 = $45 & 1;
   $47 = ($46<<24>>24)==(0);
   if ($47) {
    STACKTOP = sp;return;
   }
   $48 = (($p) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   __ZdlPv($49);
   STACKTOP = sp;return;
  }
 } while(0);
 $50 = ___cxa_find_matching_catch()|0;
 $51 = tempRet0;
 $52 = HEAP8[$0>>0]|0;
 $53 = $52 & 1;
 $54 = ($53<<24>>24)==(0);
 if (!($54)) {
  $55 = (($p) + 68|0);
  $56 = HEAP32[$55>>2]|0;
  __ZdlPv($56);
 }
 $57 = (($p) + 24|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0|0);
 if (!($59)) {
  $60 = (($p) + 28|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($61|0)==($58|0);
  if ($62) {
   $72 = $58;
  } else {
   $64 = $61;
   while(1) {
    $63 = (($64) + -12|0);
    HEAP32[$60>>2] = $63;
    $65 = HEAP8[$63>>0]|0;
    $66 = $65 & 1;
    $67 = ($66<<24>>24)==(0);
    if ($67) {
     $69 = $63;
    } else {
     $70 = (($64) + -4|0);
     $71 = HEAP32[$70>>2]|0;
     __ZdlPv($71);
     $$pre$i$i$i$i$i$i6 = HEAP32[$60>>2]|0;
     $69 = $$pre$i$i$i$i$i$i6;
    }
    $68 = ($69|0)==($58|0);
    if ($68) {
     break;
    } else {
     $64 = $69;
    }
   }
   $$pre$i$i$i$i7 = HEAP32[$57>>2]|0;
   $72 = $$pre$i$i$i$i7;
  }
  __ZdlPv($72);
 }
 $73 = (($p) + 12|0);
 $74 = HEAP8[$73>>0]|0;
 $75 = $74 & 1;
 $76 = ($75<<24>>24)==(0);
 if (!($76)) {
  $77 = (($p) + 20|0);
  $78 = HEAP32[$77>>2]|0;
  __ZdlPv($78);
 }
 $79 = HEAP8[$p>>0]|0;
 $80 = $79 & 1;
 $81 = ($80<<24>>24)==(0);
 if ($81) {
  ___resumeException($50|0);
  // unreachable;
 }
 $82 = (($p) + 8|0);
 $83 = HEAP32[$82>>2]|0;
 __ZdlPv($83);
 ___resumeException($50|0);
 // unreachable;
}
function __ZN9ShaderLab21ParserTexturePropertyC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = 5;
 STACKTOP = sp;return;
}
function __Z19CheckChannelBinding13ShaderChannel15VertexComponentP12ShaderErrors($source,$target,$outErrors) {
 $source = $source|0;
 $target = $target|0;
 $outErrors = $outErrors|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond10 = 0, $or$cond11 = 0, $or$cond13 = 0, $source$off = 0, $target$off = 0, $target$off8 = 0, $target$off9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 8|0;
 $1 = ($target|0)==(-1);
 $target$off = (($target) + -12)|0;
 $2 = ($target$off>>>0)<(16);
 $or$cond13 = $1 | $2;
 if ($or$cond13) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = $target | $source;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($source|0)==(1);
 $6 = ($target|0)==(2);
 $or$cond10 = $5 & $6;
 if ($or$cond10) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ($source|0)==(2);
 $8 = ($target|0)==(1);
 $or$cond11 = $7 & $8;
 if ($or$cond11) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $source$off = (($source) + -3)|0;
 $9 = ($source$off>>>0)<(4);
 if ($9) {
  $target$off9 = (($target) + -3)|0;
  $10 = ($target$off9>>>0)<(9);
  if ($10) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $11 = ($source|0)==(7);
 if ($11) {
  $target$off8 = (($target) + -3)|0;
  $12 = ($target$off8>>>0)<(9);
  if ($12) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer>>2] = $source;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $target;
 __Z6FormatPKcz($0,679896,$vararg_buffer);
 __THREW__ = 0;
 invoke_viiiii(104,($outErrors|0),($0|0),0,0,0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $22 = HEAP8[$0>>0]|0;
  $23 = $22 & 1;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   ___resumeException($20|0);
   // unreachable;
  }
  $25 = (($0) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  __ZdlPv($26);
  ___resumeException($20|0);
  // unreachable;
 } else {
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $18 = (($0) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  __ZdlPv($19);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9ShaderLab18ParserBindChannelsC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 116|0);
 HEAP32[$1>>2] = 0;
 dest=$this+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN9ShaderLab18ParserBindChannels4BindE13ShaderChannel15VertexComponentbP12ShaderErrors($this,$source,$target,$checkBinding,$outErrors) {
 $this = $this|0;
 $source = $source|0;
 $target = $target|0;
 $checkBinding = $checkBinding|0;
 $outErrors = $outErrors|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($checkBinding) {
  $0 = (__Z19CheckChannelBinding13ShaderChannel15VertexComponentP12ShaderErrors($source,$target,$outErrors)|0);
  if (!($0)) {
   STACKTOP = sp;return;
  }
 }
 $1 = ($target|0)==(-1);
 if (!($1)) {
  $2 = (($this) + ($target<<2)|0);
  HEAP32[$2>>2] = $source;
  $3 = 1 << $target;
  $4 = (($this) + 112|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 | $3;
  HEAP32[$4>>2] = $6;
 }
 $7 = 1 << $source;
 $8 = (($this) + 116|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $7;
 HEAP32[$8>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab18ParserBindChannels9MergeWithERKS0_($this,$additional) {
 $this = $this|0;
 $additional = $additional|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = (($this) + 112|0);
 $i$01 = 0;
 while(1) {
  $2 = (($additional) + ($i$01<<2)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(-1);
  if (!($4)) {
   $5 = (($this) + ($i$01<<2)|0);
   HEAP32[$5>>2] = $3;
   $6 = 1 << $i$01;
   $7 = HEAP32[$1>>2]|0;
   $8 = $7 | $6;
   HEAP32[$1>>2] = $8;
   $9 = 1 << $3;
   $10 = HEAP32[$0>>2]|0;
   $11 = $10 | $9;
   HEAP32[$0>>2] = $11;
  }
  $12 = (($i$01) + 1)|0;
  $exitcond = ($12|0)==(28);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $12;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab15ParserSubShaderD2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 L1: do {
  if (!($3)) {
   $37 = $2;$5 = $0;
   while(1) {
    $4 = HEAP32[$5>>2]|0;
    $6 = ($4|0)==(0|0);
    if ($6) {
     $14 = $37;
    } else {
     $7 = HEAP32[$4>>2]|0;
     $8 = (($7) + 4|0);
     $9 = HEAP32[$8>>2]|0;
     __THREW__ = 0;
     invoke_vi($9|0,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $$pre = HEAP32[$1>>2]|0;
     $14 = $$pre;
    }
    $12 = (($5) + 4|0);
    $13 = ($12|0)==($14|0);
    if ($13) {
     break L1;
    } else {
     $37 = $14;$5 = $12;
    }
   }
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   $27 = (($this) + 12|0);
   $28 = (($this) + 16|0);
   $29 = HEAP32[$28>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($27,$29);
   $30 = HEAP32[$this>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    ___resumeException($25|0);
    // unreachable;
   }
   $32 = HEAP32[$1>>2]|0;
   $33 = ($32|0)==($30|0);
   if (!($33)) {
    $__new_last2$i$i$i$i$i = $30;
    $scevgep$i$i$i$i$i = (($32) + -4|0);
    $34 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($34)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $35 = $uglygep3$i$i$i$i$i >>> 2;
    $36 = $35 ^ -1;
    $scevgep4$i$i$i$i$i = (($32) + ($36<<2)|0);
    HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($30);
   ___resumeException($25|0);
   // unreachable;
  }
 } while(0);
 $15 = (($this) + 12|0);
 $16 = (($this) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($15,$17);
 $18 = HEAP32[$this>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$1>>2]|0;
 $21 = ($20|0)==($18|0);
 if (!($21)) {
  $__new_last2$i$i$i$i$i2 = $18;
  $scevgep$i$i$i$i$i3 = (($20) + -4|0);
  $22 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($22)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $23 = $uglygep3$i$i$i$i$i6 >>> 2;
  $24 = $23 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($20) + ($24<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i7;
 }
 __ZdlPv($18);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab12ParserShaderD2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i17 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i18 = 0, $scevgep4$i$i$i$i$i = 0;
 var $scevgep4$i$i$i$i$i22 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i20 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 L1: do {
  if (!($4)) {
   $131 = $3;$6 = $1;
   while(1) {
    $5 = HEAP32[$6>>2]|0;
    $7 = ($5|0)==(0|0);
    if ($7) {
     $12 = $131;
    } else {
     __THREW__ = 0;
     invoke_vi(3601,($5|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __ZdlPv($5);
     $$pre = HEAP32[$2>>2]|0;
     $12 = $$pre;
    }
    $10 = (($6) + 4|0);
    $11 = ($10|0)==($12|0);
    if ($11) {
     break L1;
    } else {
     $131 = $12;$6 = $10;
    }
   }
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   __ZdlPv($5);
   $15 = (($this) + 60|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $18 = (($this) + 64|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($16|0);
    if ($20) {
     $36 = $16;
    } else {
     $22 = $19;
     while(1) {
      $21 = (($22) + -24|0);
      HEAP32[$18>>2] = $21;
      $23 = (($22) + -12|0);
      $24 = HEAP8[$23>>0]|0;
      $25 = $24 & 1;
      $26 = ($25<<24>>24)==(0);
      if (!($26)) {
       $27 = (($22) + -4|0);
       $28 = HEAP32[$27>>2]|0;
       __ZdlPv($28);
      }
      $29 = HEAP8[$21>>0]|0;
      $30 = $29 & 1;
      $31 = ($30<<24>>24)==(0);
      if (!($31)) {
       $34 = (($22) + -16|0);
       $35 = HEAP32[$34>>2]|0;
       __ZdlPv($35);
      }
      $32 = HEAP32[$18>>2]|0;
      $33 = ($32|0)==($16|0);
      if ($33) {
       break;
      } else {
       $22 = $32;
      }
     }
     $$pre$i$i$i = HEAP32[$15>>2]|0;
     $36 = $$pre$i$i$i;
    }
    __ZdlPv($36);
   }
   $95 = (($this) + 48|0);
   $96 = HEAP8[$95>>0]|0;
   $97 = $96 & 1;
   $98 = ($97<<24>>24)==(0);
   if (!($98)) {
    $99 = (($this) + 56|0);
    $100 = HEAP32[$99>>2]|0;
    __ZdlPv($100);
   }
   $101 = (($this) + 36|0);
   $102 = HEAP8[$101>>0]|0;
   $103 = $102 & 1;
   $104 = ($103<<24>>24)==(0);
   if (!($104)) {
    $105 = (($this) + 44|0);
    $106 = HEAP32[$105>>2]|0;
    __ZdlPv($106);
   }
   $107 = (($this) + 24|0);
   $108 = HEAP8[$107>>0]|0;
   $109 = $108 & 1;
   $110 = ($109<<24>>24)==(0);
   if (!($110)) {
    $111 = (($this) + 32|0);
    $112 = HEAP32[$111>>2]|0;
    __ZdlPv($112);
   }
   $113 = HEAP32[$0>>2]|0;
   $114 = ($113|0)==(0|0);
   if (!($114)) {
    $115 = HEAP32[$2>>2]|0;
    $116 = ($115|0)==($113|0);
    if (!($116)) {
     $__new_last2$i$i$i$i$i = $113;
     $scevgep$i$i$i$i$i = (($115) + -4|0);
     $117 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($117)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $118 = $uglygep3$i$i$i$i$i >>> 2;
     $119 = $118 ^ -1;
     $scevgep4$i$i$i$i$i = (($115) + ($119<<2)|0);
     HEAP32[$2>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($113);
   }
   $120 = HEAP32[$this>>2]|0;
   $121 = ($120|0)==(0|0);
   if ($121) {
    ___resumeException($13|0);
    // unreachable;
   }
   $122 = (($this) + 4|0);
   while(1) {
    $123 = HEAP32[$122>>2]|0;
    $124 = ($123|0)==($120|0);
    if ($124) {
     break;
    }
    $125 = (($123) + -76|0);
    HEAP32[$122>>2] = $125;
    __THREW__ = 0;
    invoke_vi(3592,($125|0));
    $126 = __THREW__; __THREW__ = 0;
    $127 = $126&1;
    if ($127) {
     label = 55;
     break;
    }
   }
   if ((label|0) == 55) {
    $128 = ___cxa_find_matching_catch()|0;
    $129 = tempRet0;
    ___cxa_call_unexpected(($128|0));
    // unreachable;
   }
   $130 = HEAP32[$this>>2]|0;
   __ZdlPv($130);
   ___resumeException($13|0);
   // unreachable;
  }
 } while(0);
 $37 = (($this) + 60|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = (($this) + 64|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==($38|0);
  if ($42) {
   $58 = $38;
  } else {
   $44 = $41;
   while(1) {
    $43 = (($44) + -24|0);
    HEAP32[$40>>2] = $43;
    $45 = (($44) + -12|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46 & 1;
    $48 = ($47<<24>>24)==(0);
    if (!($48)) {
     $49 = (($44) + -4|0);
     $50 = HEAP32[$49>>2]|0;
     __ZdlPv($50);
    }
    $51 = HEAP8[$43>>0]|0;
    $52 = $51 & 1;
    $53 = ($52<<24>>24)==(0);
    if (!($53)) {
     $56 = (($44) + -16|0);
     $57 = HEAP32[$56>>2]|0;
     __ZdlPv($57);
    }
    $54 = HEAP32[$40>>2]|0;
    $55 = ($54|0)==($38|0);
    if ($55) {
     break;
    } else {
     $44 = $54;
    }
   }
   $$pre$i$i$i10 = HEAP32[$37>>2]|0;
   $58 = $$pre$i$i$i10;
  }
  __ZdlPv($58);
 }
 $59 = (($this) + 48|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = $60 & 1;
 $62 = ($61<<24>>24)==(0);
 if (!($62)) {
  $63 = (($this) + 56|0);
  $64 = HEAP32[$63>>2]|0;
  __ZdlPv($64);
 }
 $65 = (($this) + 36|0);
 $66 = HEAP8[$65>>0]|0;
 $67 = $66 & 1;
 $68 = ($67<<24>>24)==(0);
 if (!($68)) {
  $69 = (($this) + 44|0);
  $70 = HEAP32[$69>>2]|0;
  __ZdlPv($70);
 }
 $71 = (($this) + 24|0);
 $72 = HEAP8[$71>>0]|0;
 $73 = $72 & 1;
 $74 = ($73<<24>>24)==(0);
 if (!($74)) {
  $75 = (($this) + 32|0);
  $76 = HEAP32[$75>>2]|0;
  __ZdlPv($76);
 }
 $77 = HEAP32[$0>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $79 = HEAP32[$2>>2]|0;
  $80 = ($79|0)==($77|0);
  if (!($80)) {
   $__new_last2$i$i$i$i$i17 = $77;
   $scevgep$i$i$i$i$i18 = (($79) + -4|0);
   $81 = (0 - ($__new_last2$i$i$i$i$i17))|0;
   $uglygep$i$i$i$i$i20 = (($scevgep$i$i$i$i$i18) + ($81)|0);
   $uglygep3$i$i$i$i$i21 = $uglygep$i$i$i$i$i20;
   $82 = $uglygep3$i$i$i$i$i21 >>> 2;
   $83 = $82 ^ -1;
   $scevgep4$i$i$i$i$i22 = (($79) + ($83<<2)|0);
   HEAP32[$2>>2] = $scevgep4$i$i$i$i$i22;
  }
  __ZdlPv($77);
 }
 $84 = HEAP32[$this>>2]|0;
 $85 = ($84|0)==(0|0);
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = (($this) + 4|0);
 while(1) {
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==($84|0);
  if ($88) {
   break;
  }
  $89 = (($87) + -76|0);
  HEAP32[$86>>2] = $89;
  __THREW__ = 0;
  invoke_vi(3592,($89|0));
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   label = 38;
   break;
  }
 }
 if ((label|0) == 38) {
  $92 = ___cxa_find_matching_catch()|0;
  $93 = tempRet0;
  ___cxa_call_unexpected(($92|0));
  // unreachable;
 }
 $94 = HEAP32[$this>>2]|0;
 __ZdlPv($94);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab10ParserPassD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1192,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab10ParserPassD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i3 = 0, $i$013 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i4 = 0;
 var $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((679936 + 8|0));
 $i$013 = 0;
 while(1) {
  $1 = ((($this) + ($i$013<<2)|0) + 676|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   __THREW__ = 0;
   invoke_vi(3594,($2|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    label = 6;
    break;
   }
   __ZdlPv($2);
  }
  $6 = (($i$013) + 1)|0;
  $7 = ($6|0)<(6);
  if ($7) {
   $i$013 = $6;
  } else {
   label = 10;
   break;
  }
 }
 if ((label|0) == 6) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZdlPv($2);
  $10 = (($this) + 664|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = (($this) + 668|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($11|0);
   if (!($15)) {
    $__new_last2$i$i$i$i$i = $11;
    $scevgep$i$i$i$i$i = (($14) + -52|0);
    $16 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($16)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $17 = (($uglygep3$i$i$i$i$i>>>0) / 52)&-1;
    $18 = $17 ^ -1;
    $scevgep4$i$i$i$i$i = (($14) + (($18*52)|0)|0);
    HEAP32[$13>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($11);
  }
  $41 = (($this) + 8|0);
  $42 = (($this) + 648|0);
  $43 = (($this) + 652|0);
  $44 = HEAP32[$43>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($42,$44);
  $45 = HEAP8[$41>>0]|0;
  $46 = $45 & 1;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   ___resumeException($8|0);
   // unreachable;
  }
  $48 = (($this) + 16|0);
  $49 = HEAP32[$48>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($49|0),($$byval_copy1|0));
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   $52 = ___cxa_find_matching_catch()|0;
   $53 = tempRet0;
   ___cxa_call_unexpected(($52|0));
   // unreachable;
  } else {
   ___resumeException($8|0);
   // unreachable;
  }
 }
 else if ((label|0) == 10) {
  $19 = (($this) + 664|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = (($this) + 668|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==($20|0);
   if (!($24)) {
    $__new_last2$i$i$i$i$i3 = $20;
    $scevgep$i$i$i$i$i4 = (($23) + -52|0);
    $25 = (0 - ($__new_last2$i$i$i$i$i3))|0;
    $uglygep$i$i$i$i$i6 = (($scevgep$i$i$i$i$i4) + ($25)|0);
    $uglygep3$i$i$i$i$i7 = $uglygep$i$i$i$i$i6;
    $26 = (($uglygep3$i$i$i$i$i7>>>0) / 52)&-1;
    $27 = $26 ^ -1;
    $scevgep4$i$i$i$i$i8 = (($23) + (($27*52)|0)|0);
    HEAP32[$22>>2] = $scevgep4$i$i$i$i$i8;
   }
   __ZdlPv($20);
  }
  $28 = (($this) + 8|0);
  $29 = (($this) + 648|0);
  $30 = (($this) + 652|0);
  $31 = HEAP32[$30>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($29,$31);
  $32 = HEAP8[$28>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   STACKTOP = sp;return;
  }
  $35 = (($this) + 16|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($36|0),($$byval_copy1|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   ___cxa_call_unexpected(($39|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__16vectorIN9ShaderLab14ParserPropertyENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i11 = 0, $$0$i12 = 0, $$01$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre10 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 76)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(56512727);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 76)&-1;
 $14 = ($13>>>0)<(28256363);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i12 = 0;$22 = 0;
  } else {
   $$0$i11 = $17;
   label = 5;
  }
 } else {
  $$0$i11 = 56512727;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i11*76)|0;
  $20 = (__Znwj($19)|0);
  $$0$i12 = $$0$i11;$22 = $20;
 }
 $21 = (($22) + (($6*76)|0)|0);
 $23 = (($22) + (($$0$i12*76)|0)|0);
 $24 = ($21|0)==(0|0);
 do {
  if ($24) {
   $29 = $1;$30 = $2;
   label = 9;
  } else {
   __THREW__ = 0;
   invoke_vii(3275,($21|0),($__x|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $49 = ___cxa_find_matching_catch()|0;
    $50 = tempRet0;
    $53 = $21;$61 = $21;$lpad$phi$index = $49;$lpad$phi$index2 = $50;
    break;
   } else {
    $$pre9 = HEAP32[$this>>2]|0;
    $$pre10 = HEAP32[$0>>2]|0;
    $29 = $$pre10;$30 = $$pre9;
    label = 9;
    break;
   }
  }
 } while(0);
 L14: do {
  if ((label|0) == 9) {
   $27 = (($22) + (($7*76)|0)|0);
   $28 = ($29|0)==($30|0);
   do {
    if ($28) {
     $37 = $21;$40 = $29;$60 = $29;
    } else {
     $$01$i$i = $29;$32 = $21;
     while(1) {
      $31 = (($32) + -76|0);
      $33 = (($$01$i$i) + -76|0);
      __THREW__ = 0;
      invoke_vii(3275,($31|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 20;
       break;
      }
      $36 = ($33|0)==($30|0);
      if ($36) {
       label = 12;
       break;
      } else {
       $$01$i$i = $33;$32 = $31;
      }
     }
     if ((label|0) == 12) {
      $$pre$i = HEAP32[$this>>2]|0;
      $$pre = HEAP32[$0>>2]|0;
      $37 = $31;$40 = $$pre$i;$60 = $$pre;
      break;
     }
     else if ((label|0) == 20) {
      $47 = ___cxa_find_matching_catch()|0;
      $48 = tempRet0;
      $53 = $32;$61 = $27;$lpad$phi$index = $47;$lpad$phi$index2 = $48;
      break L14;
     }
    }
   } while(0);
   HEAP32[$this>>2] = $37;
   HEAP32[$0>>2] = $27;
   HEAP32[$9>>2] = $23;
   $39 = $60;
   while(1) {
    $38 = ($39|0)==($40|0);
    if ($38) {
     break;
    }
    $41 = (($39) + -76|0);
    __THREW__ = 0;
    invoke_vi(3592,($41|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 16;
     break;
    } else {
     $39 = $41;
    }
   }
   if ((label|0) == 16) {
    $44 = ___cxa_find_matching_catch()|0;
    $45 = tempRet0;
    ___cxa_call_unexpected(($44|0));
    // unreachable;
   }
   $46 = ($40|0)==(0|0);
   if ($46) {
    STACKTOP = sp;return;
   }
   __ZdlPv($40);
   STACKTOP = sp;return;
  }
 } while(0);
 $52 = $61;
 while(1) {
  $51 = ($52|0)==($53|0);
  if ($51) {
   break;
  }
  $54 = (($52) + -76|0);
  __THREW__ = 0;
  invoke_vi(3592,($54|0));
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if ($56) {
   label = 25;
   break;
  } else {
   $52 = $54;
  }
 }
 if ((label|0) == 25) {
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  ___cxa_call_unexpected(($57|0));
  // unreachable;
 }
 $59 = ($22|0)==(0|0);
 if ($59) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __ZdlPv($22);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram16TextureParameterENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i8 = 0, $$0$i9 = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__p$0$i$i$i$i$i$i = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 24)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(178956970);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 24)&-1;
 $15 = ($14>>>0)<(89478485);
 if ($15) {
  $18 = $14 << 1;
  $19 = ($18>>>0)<($8>>>0);
  $20 = $19 ? $8 : $18;
  $21 = (($__v) + 12|0);
  HEAP32[$21>>2] = 0;
  $22 = (($__v) + 16|0);
  HEAP32[$22>>2] = $0;
  $23 = ($20|0)==(0);
  if ($23) {
   $$0$i9 = 0;$26 = 0;$31 = $21;
  } else {
   $$0$i8 = $20;$90 = $21;
   label = 6;
  }
 } else {
  $16 = (($__v) + 12|0);
  HEAP32[$16>>2] = 0;
  $17 = (($__v) + 16|0);
  HEAP32[$17>>2] = $0;
  $$0$i8 = 178956970;$90 = $16;
  label = 6;
 }
 if ((label|0) == 6) {
  $24 = ($$0$i8*24)|0;
  $25 = (__Znwj($24)|0);
  $$0$i9 = $$0$i8;$26 = $25;$31 = $90;
 }
 HEAP32[$__v>>2] = $26;
 $27 = (($26) + (($7*24)|0)|0);
 $28 = (($__v) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = (($__v) + 4|0);
 HEAP32[$29>>2] = $27;
 $30 = (($26) + (($$0$i9*24)|0)|0);
 HEAP32[$31>>2] = $30;
 $32 = ($27|0)==(0|0);
 do {
  if ($32) {
   $59 = 0;
   label = 19;
  } else {
   $33 = HEAP8[$__x>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    ;HEAP32[$27+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__x+8>>2]|0;
    $$pre = $27;
   } else {
    $36 = (($__x) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($__x) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39>>>0)>(4294967279);
    if ($40) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     // unreachable;
    }
    $43 = ($39>>>0)<(11);
    if ($43) {
     $44 = $39 << 1;
     $45 = $44&255;
     HEAP8[$27>>0] = $45;
     $46 = (($27) + 1|0);
     $__p$0$i$i$i$i$i$i = $46;
    } else {
     $47 = (($39) + 16)|0;
     $48 = $47 & -16;
     __THREW__ = 0;
     $49 = (invoke_ii(2988,($48|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = ((($26) + (($7*24)|0)|0) + 8|0);
     HEAP32[$52>>2] = $49;
     $53 = $48 | 1;
     HEAP32[$27>>2] = $53;
     $54 = ((($26) + (($7*24)|0)|0) + 4|0);
     HEAP32[$54>>2] = $39;
     $__p$0$i$i$i$i$i$i = $49;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($37|0),($39|0))|0;
    $55 = (($__p$0$i$i$i$i$i$i) + ($39)|0);
    HEAP8[$55>>0] = 0;
    $$pre$pre = HEAP32[$28>>2]|0;
    $$pre = $$pre$pre;
   }
   $56 = ((($26) + (($7*24)|0)|0) + 12|0);
   $57 = (($__x) + 12|0);
   ;HEAP32[$56+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$57+8>>2]|0;
   $59 = $$pre;
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  $58 = (($59) + 24|0);
  HEAP32[$28>>2] = $58;
  __THREW__ = 0;
  invoke_vii(3236,($this|0),($__v|0));
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if (!($61)) {
   $62 = HEAP32[$29>>2]|0;
   $63 = HEAP32[$28>>2]|0;
   $64 = ($63|0)==($62|0);
   if (!($64)) {
    $66 = $63;
    while(1) {
     $65 = (($66) + -24|0);
     HEAP32[$28>>2] = $65;
     $67 = HEAP8[$65>>0]|0;
     $68 = $67 & 1;
     $69 = ($68<<24>>24)==(0);
     if (!($69)) {
      $71 = (($66) + -16|0);
      $72 = HEAP32[$71>>2]|0;
      __ZdlPv($72);
     }
     $70 = ($65|0)==($62|0);
     if ($70) {
      break;
     } else {
      $66 = $65;
     }
    }
   }
   $73 = HEAP32[$__v>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   __ZdlPv($73);
   STACKTOP = sp;return;
  }
 }
 $75 = ___cxa_find_matching_catch()|0;
 $76 = tempRet0;
 $77 = HEAP32[$29>>2]|0;
 $78 = HEAP32[$28>>2]|0;
 $79 = ($78|0)==($77|0);
 if (!($79)) {
  $81 = $78;
  while(1) {
   $80 = (($81) + -24|0);
   HEAP32[$28>>2] = $80;
   $82 = HEAP8[$80>>0]|0;
   $83 = $82 & 1;
   $84 = ($83<<24>>24)==(0);
   if (!($84)) {
    $86 = (($81) + -16|0);
    $87 = HEAP32[$86>>2]|0;
    __ZdlPv($87);
   }
   $85 = ($80|0)==($77|0);
   if ($85) {
    break;
   } else {
    $81 = $80;
   }
  }
 }
 $88 = HEAP32[$__v>>2]|0;
 $89 = ($88|0)==(0|0);
 if ($89) {
  ___resumeException($75|0);
  // unreachable;
 }
 __ZdlPv($88);
 ___resumeException($75|0);
 // unreachable;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i8 = 0, $$0$i9 = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__p$0$i$i$i$i$i$i = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 24)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(178956970);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 24)&-1;
 $15 = ($14>>>0)<(89478485);
 if ($15) {
  $18 = $14 << 1;
  $19 = ($18>>>0)<($8>>>0);
  $20 = $19 ? $8 : $18;
  $21 = (($__v) + 12|0);
  HEAP32[$21>>2] = 0;
  $22 = (($__v) + 16|0);
  HEAP32[$22>>2] = $0;
  $23 = ($20|0)==(0);
  if ($23) {
   $$0$i9 = 0;$26 = 0;$31 = $21;
  } else {
   $$0$i8 = $20;$90 = $21;
   label = 6;
  }
 } else {
  $16 = (($__v) + 12|0);
  HEAP32[$16>>2] = 0;
  $17 = (($__v) + 16|0);
  HEAP32[$17>>2] = $0;
  $$0$i8 = 178956970;$90 = $16;
  label = 6;
 }
 if ((label|0) == 6) {
  $24 = ($$0$i8*24)|0;
  $25 = (__Znwj($24)|0);
  $$0$i9 = $$0$i8;$26 = $25;$31 = $90;
 }
 HEAP32[$__v>>2] = $26;
 $27 = (($26) + (($7*24)|0)|0);
 $28 = (($__v) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = (($__v) + 4|0);
 HEAP32[$29>>2] = $27;
 $30 = (($26) + (($$0$i9*24)|0)|0);
 HEAP32[$31>>2] = $30;
 $32 = ($27|0)==(0|0);
 do {
  if ($32) {
   $59 = 0;
   label = 19;
  } else {
   $33 = HEAP8[$__x>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    ;HEAP32[$27+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__x+8>>2]|0;
    $$pre = $27;
   } else {
    $36 = (($__x) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($__x) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39>>>0)>(4294967279);
    if ($40) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     // unreachable;
    }
    $43 = ($39>>>0)<(11);
    if ($43) {
     $44 = $39 << 1;
     $45 = $44&255;
     HEAP8[$27>>0] = $45;
     $46 = (($27) + 1|0);
     $__p$0$i$i$i$i$i$i = $46;
    } else {
     $47 = (($39) + 16)|0;
     $48 = $47 & -16;
     __THREW__ = 0;
     $49 = (invoke_ii(2988,($48|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = ((($26) + (($7*24)|0)|0) + 8|0);
     HEAP32[$52>>2] = $49;
     $53 = $48 | 1;
     HEAP32[$27>>2] = $53;
     $54 = ((($26) + (($7*24)|0)|0) + 4|0);
     HEAP32[$54>>2] = $39;
     $__p$0$i$i$i$i$i$i = $49;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($37|0),($39|0))|0;
    $55 = (($__p$0$i$i$i$i$i$i) + ($39)|0);
    HEAP8[$55>>0] = 0;
    $$pre$pre = HEAP32[$28>>2]|0;
    $$pre = $$pre$pre;
   }
   $56 = ((($26) + (($7*24)|0)|0) + 12|0);
   $57 = (($__x) + 12|0);
   ;HEAP32[$56+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$57+8>>2]|0;
   $59 = $$pre;
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  $58 = (($59) + 24|0);
  HEAP32[$28>>2] = $58;
  __THREW__ = 0;
  invoke_vii(3235,($this|0),($__v|0));
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if (!($61)) {
   $62 = HEAP32[$29>>2]|0;
   $63 = HEAP32[$28>>2]|0;
   $64 = ($63|0)==($62|0);
   if (!($64)) {
    $66 = $63;
    while(1) {
     $65 = (($66) + -24|0);
     HEAP32[$28>>2] = $65;
     $67 = HEAP8[$65>>0]|0;
     $68 = $67 & 1;
     $69 = ($68<<24>>24)==(0);
     if (!($69)) {
      $71 = (($66) + -16|0);
      $72 = HEAP32[$71>>2]|0;
      __ZdlPv($72);
     }
     $70 = ($65|0)==($62|0);
     if ($70) {
      break;
     } else {
      $66 = $65;
     }
    }
   }
   $73 = HEAP32[$__v>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   __ZdlPv($73);
   STACKTOP = sp;return;
  }
 }
 $75 = ___cxa_find_matching_catch()|0;
 $76 = tempRet0;
 $77 = HEAP32[$29>>2]|0;
 $78 = HEAP32[$28>>2]|0;
 $79 = ($78|0)==($77|0);
 if (!($79)) {
  $81 = $78;
  while(1) {
   $80 = (($81) + -24|0);
   HEAP32[$28>>2] = $80;
   $82 = HEAP8[$80>>0]|0;
   $83 = $82 & 1;
   $84 = ($83<<24>>24)==(0);
   if (!($84)) {
    $86 = (($81) + -16|0);
    $87 = HEAP32[$86>>2]|0;
    __ZdlPv($87);
   }
   $85 = ($80|0)==($77|0);
   if ($85) {
    break;
   } else {
    $81 = $80;
   }
  }
 }
 $88 = HEAP32[$__v>>2]|0;
 $89 = ($88|0)==(0|0);
 if ($89) {
  ___resumeException($75|0);
  // unreachable;
 }
 __ZdlPv($88);
 ___resumeException($75|0);
 // unreachable;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15VectorParameterENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i8 = 0, $$0$i9 = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__p$0$i$i$i$i$i$i = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 24)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(178956970);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 24)&-1;
 $15 = ($14>>>0)<(89478485);
 if ($15) {
  $18 = $14 << 1;
  $19 = ($18>>>0)<($8>>>0);
  $20 = $19 ? $8 : $18;
  $21 = (($__v) + 12|0);
  HEAP32[$21>>2] = 0;
  $22 = (($__v) + 16|0);
  HEAP32[$22>>2] = $0;
  $23 = ($20|0)==(0);
  if ($23) {
   $$0$i9 = 0;$26 = 0;$31 = $21;
  } else {
   $$0$i8 = $20;$90 = $21;
   label = 6;
  }
 } else {
  $16 = (($__v) + 12|0);
  HEAP32[$16>>2] = 0;
  $17 = (($__v) + 16|0);
  HEAP32[$17>>2] = $0;
  $$0$i8 = 178956970;$90 = $16;
  label = 6;
 }
 if ((label|0) == 6) {
  $24 = ($$0$i8*24)|0;
  $25 = (__Znwj($24)|0);
  $$0$i9 = $$0$i8;$26 = $25;$31 = $90;
 }
 HEAP32[$__v>>2] = $26;
 $27 = (($26) + (($7*24)|0)|0);
 $28 = (($__v) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = (($__v) + 4|0);
 HEAP32[$29>>2] = $27;
 $30 = (($26) + (($$0$i9*24)|0)|0);
 HEAP32[$31>>2] = $30;
 $32 = ($27|0)==(0|0);
 do {
  if ($32) {
   $59 = 0;
   label = 19;
  } else {
   $33 = HEAP8[$__x>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    ;HEAP32[$27+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__x+8>>2]|0;
    $$pre = $27;
   } else {
    $36 = (($__x) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($__x) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39>>>0)>(4294967279);
    if ($40) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     // unreachable;
    }
    $43 = ($39>>>0)<(11);
    if ($43) {
     $44 = $39 << 1;
     $45 = $44&255;
     HEAP8[$27>>0] = $45;
     $46 = (($27) + 1|0);
     $__p$0$i$i$i$i$i$i = $46;
    } else {
     $47 = (($39) + 16)|0;
     $48 = $47 & -16;
     __THREW__ = 0;
     $49 = (invoke_ii(2988,($48|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = ((($26) + (($7*24)|0)|0) + 8|0);
     HEAP32[$52>>2] = $49;
     $53 = $48 | 1;
     HEAP32[$27>>2] = $53;
     $54 = ((($26) + (($7*24)|0)|0) + 4|0);
     HEAP32[$54>>2] = $39;
     $__p$0$i$i$i$i$i$i = $49;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($37|0),($39|0))|0;
    $55 = (($__p$0$i$i$i$i$i$i) + ($39)|0);
    HEAP8[$55>>0] = 0;
    $$pre$pre = HEAP32[$28>>2]|0;
    $$pre = $$pre$pre;
   }
   $56 = ((($26) + (($7*24)|0)|0) + 12|0);
   $57 = (($__x) + 12|0);
   ;HEAP32[$56+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$57+8>>2]|0;
   $59 = $$pre;
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  $58 = (($59) + 24|0);
  HEAP32[$28>>2] = $58;
  __THREW__ = 0;
  invoke_vii(3234,($this|0),($__v|0));
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if (!($61)) {
   $62 = HEAP32[$29>>2]|0;
   $63 = HEAP32[$28>>2]|0;
   $64 = ($63|0)==($62|0);
   if (!($64)) {
    $66 = $63;
    while(1) {
     $65 = (($66) + -24|0);
     HEAP32[$28>>2] = $65;
     $67 = HEAP8[$65>>0]|0;
     $68 = $67 & 1;
     $69 = ($68<<24>>24)==(0);
     if (!($69)) {
      $71 = (($66) + -16|0);
      $72 = HEAP32[$71>>2]|0;
      __ZdlPv($72);
     }
     $70 = ($65|0)==($62|0);
     if ($70) {
      break;
     } else {
      $66 = $65;
     }
    }
   }
   $73 = HEAP32[$__v>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   __ZdlPv($73);
   STACKTOP = sp;return;
  }
 }
 $75 = ___cxa_find_matching_catch()|0;
 $76 = tempRet0;
 $77 = HEAP32[$29>>2]|0;
 $78 = HEAP32[$28>>2]|0;
 $79 = ($78|0)==($77|0);
 if (!($79)) {
  $81 = $78;
  while(1) {
   $80 = (($81) + -24|0);
   HEAP32[$28>>2] = $80;
   $82 = HEAP8[$80>>0]|0;
   $83 = $82 & 1;
   $84 = ($83<<24>>24)==(0);
   if (!($84)) {
    $86 = (($81) + -16|0);
    $87 = HEAP32[$86>>2]|0;
    __ZdlPv($87);
   }
   $85 = ($80|0)==($77|0);
   if ($85) {
    break;
   } else {
    $81 = $80;
   }
  }
 }
 $88 = HEAP32[$__v>>2]|0;
 $89 = ($88|0)==(0|0);
 if ($89) {
  ___resumeException($75|0);
  // unreachable;
 }
 __ZdlPv($88);
 ___resumeException($75|0);
 // unreachable;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram14ConstantBufferENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i11 = 0, $$0$i12 = 0, $$01$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre10 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 40)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(107374182);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 40)&-1;
 $14 = ($13>>>0)<(53687091);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i12 = 0;$22 = 0;
  } else {
   $$0$i11 = $17;
   label = 5;
  }
 } else {
  $$0$i11 = 107374182;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i11*40)|0;
  $20 = (__Znwj($19)|0);
  $$0$i12 = $$0$i11;$22 = $20;
 }
 $21 = (($22) + (($6*40)|0)|0);
 $23 = (($22) + (($$0$i12*40)|0)|0);
 $24 = ($21|0)==(0|0);
 do {
  if ($24) {
   $29 = $1;$30 = $2;
   label = 9;
  } else {
   __THREW__ = 0;
   invoke_vii(3270,($21|0),($__x|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $49 = ___cxa_find_matching_catch()|0;
    $50 = tempRet0;
    $53 = $21;$61 = $21;$lpad$phi$index = $49;$lpad$phi$index2 = $50;
    break;
   } else {
    $$pre9 = HEAP32[$this>>2]|0;
    $$pre10 = HEAP32[$0>>2]|0;
    $29 = $$pre10;$30 = $$pre9;
    label = 9;
    break;
   }
  }
 } while(0);
 L14: do {
  if ((label|0) == 9) {
   $27 = (($22) + (($7*40)|0)|0);
   $28 = ($29|0)==($30|0);
   do {
    if ($28) {
     $37 = $21;$40 = $29;$60 = $29;
    } else {
     $$01$i$i = $29;$32 = $21;
     while(1) {
      $31 = (($32) + -40|0);
      $33 = (($$01$i$i) + -40|0);
      __THREW__ = 0;
      invoke_vii(3270,($31|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 20;
       break;
      }
      $36 = ($33|0)==($30|0);
      if ($36) {
       label = 12;
       break;
      } else {
       $$01$i$i = $33;$32 = $31;
      }
     }
     if ((label|0) == 12) {
      $$pre$i = HEAP32[$this>>2]|0;
      $$pre = HEAP32[$0>>2]|0;
      $37 = $31;$40 = $$pre$i;$60 = $$pre;
      break;
     }
     else if ((label|0) == 20) {
      $47 = ___cxa_find_matching_catch()|0;
      $48 = tempRet0;
      $53 = $32;$61 = $27;$lpad$phi$index = $47;$lpad$phi$index2 = $48;
      break L14;
     }
    }
   } while(0);
   HEAP32[$this>>2] = $37;
   HEAP32[$0>>2] = $27;
   HEAP32[$9>>2] = $23;
   $39 = $60;
   while(1) {
    $38 = ($39|0)==($40|0);
    if ($38) {
     break;
    }
    $41 = (($39) + -40|0);
    __THREW__ = 0;
    invoke_vi(3574,($41|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 16;
     break;
    } else {
     $39 = $41;
    }
   }
   if ((label|0) == 16) {
    $44 = ___cxa_find_matching_catch()|0;
    $45 = tempRet0;
    ___cxa_call_unexpected(($44|0));
    // unreachable;
   }
   $46 = ($40|0)==(0|0);
   if ($46) {
    STACKTOP = sp;return;
   }
   __ZdlPv($40);
   STACKTOP = sp;return;
  }
 } while(0);
 $52 = $61;
 while(1) {
  $51 = ($52|0)==($53|0);
  if ($51) {
   break;
  }
  $54 = (($52) + -40|0);
  __THREW__ = 0;
  invoke_vi(3574,($54|0));
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if ($56) {
   label = 25;
   break;
  } else {
   $52 = $54;
  }
 }
 if ((label|0) == 25) {
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  ___cxa_call_unexpected(($57|0));
  // unreachable;
 }
 $59 = ($22|0)==(0|0);
 if ($59) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __ZdlPv($22);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN9ShaderLab16ParserSubProgram14ConstantBufferC2ERKS1_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  ;HEAP32[$this+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$0+8>>2]|0;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($0) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7>>>0)>(4294967279);
  if ($8) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $9 = ($7>>>0)<(11);
  if ($9) {
   $10 = $7 << 1;
   $11 = $10&255;
   HEAP8[$this>>0] = $11;
   $12 = (($this) + 1|0);
   $__p$0$i$i$i = $12;
  } else {
   $13 = (($7) + 16)|0;
   $14 = $13 & -16;
   $15 = (__Znwj($14)|0);
   $16 = (($this) + 8|0);
   HEAP32[$16>>2] = $15;
   $17 = $14 | 1;
   HEAP32[$this>>2] = $17;
   $18 = (($this) + 4|0);
   HEAP32[$18>>2] = $7;
   $__p$0$i$i$i = $15;
  }
  _memcpy(($__p$0$i$i$i|0),($5|0),($7|0))|0;
  $19 = (($__p$0$i$i$i) + ($7)|0);
  HEAP8[$19>>0] = 0;
 }
 $20 = (($this) + 12|0);
 $21 = (($0) + 12|0);
 __THREW__ = 0;
 invoke_vii(3277,($20|0),($21|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $$0 = $32;$$01 = $31;
 } else {
  $24 = (($this) + 24|0);
  $25 = (($0) + 24|0);
  __THREW__ = 0;
  invoke_vii(3278,($24|0),($25|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   $28 = (($this) + 36|0);
   $29 = (($0) + 36|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$28>>2] = $30;
   STACKTOP = sp;return;
  }
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $35 = HEAP32[$20>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   $$0 = $34;$$01 = $33;
  } else {
   $37 = (($this) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==($35|0);
   if ($39) {
    $49 = $35;
   } else {
    $41 = $38;
    while(1) {
     $40 = (($41) + -24|0);
     HEAP32[$37>>2] = $40;
     $42 = HEAP8[$40>>0]|0;
     $43 = $42 & 1;
     $44 = ($43<<24>>24)==(0);
     if ($44) {
      $46 = $40;
     } else {
      $47 = (($41) + -16|0);
      $48 = HEAP32[$47>>2]|0;
      __ZdlPv($48);
      $$pre$i$i$i$i$i = HEAP32[$37>>2]|0;
      $46 = $$pre$i$i$i$i$i;
     }
     $45 = ($46|0)==($35|0);
     if ($45) {
      break;
     } else {
      $41 = $46;
     }
    }
    $$pre$i$i$i = HEAP32[$20>>2]|0;
    $49 = $$pre$i$i$i;
   }
   __ZdlPv($49);
   $$0 = $34;$$01 = $33;
  }
 }
 $50 = HEAP8[$this>>0]|0;
 $51 = $50 & 1;
 $52 = ($51<<24>>24)==(0);
 if ($52) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $53 = (($this) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15VectorParameterENS_9allocatorIS3_EEEC2ERKS6_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$01$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($__x) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$__x>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 24)&-1;
 $9 = ($3|0)==($4|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8>>>0)>(178956970);
 do {
  if ($10) {
   __THREW__ = 0;
   invoke_vi(3308,0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 21;
   } else {
    // unreachable;
   }
  } else {
   __THREW__ = 0;
   $13 = (invoke_ii(2988,($7|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 21;
   } else {
    HEAP32[$0>>2] = $13;
    HEAP32[$this>>2] = $13;
    $16 = (($13) + (($8*24)|0)|0);
    HEAP32[$1>>2] = $16;
    $17 = HEAP32[$__x>>2]|0;
    $18 = HEAP32[$2>>2]|0;
    $19 = ($17|0)==($18|0);
    if ($19) {
     STACKTOP = sp;return;
    } else {
     $$01$i = $17;$21 = $13;
    }
    while(1) {
     $20 = ($21|0)==(0|0);
     if ($20) {
      $48 = 0;
     } else {
      $22 = HEAP8[$$01$i>>0]|0;
      $23 = $22 & 1;
      $24 = ($23<<24>>24)==(0);
      if ($24) {
       ;HEAP32[$21+0>>2]=HEAP32[$$01$i+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$$01$i+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$$01$i+8>>2]|0;
      } else {
       $25 = (($$01$i) + 8|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = (($$01$i) + 4|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = ($28>>>0)>(4294967279);
       if ($29) {
        label = 11;
        break;
       }
       $32 = ($28>>>0)<(11);
       if ($32) {
        $33 = $28 << 1;
        $34 = $33&255;
        HEAP8[$21>>0] = $34;
        $35 = (($21) + 1|0);
        $__p$0$i$i$i$i$i$i$i = $35;
       } else {
        $36 = (($28) + 16)|0;
        $37 = $36 & -16;
        __THREW__ = 0;
        $38 = (invoke_ii(2988,($37|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 20;
         break;
        }
        $41 = (($21) + 8|0);
        HEAP32[$41>>2] = $38;
        $42 = $37 | 1;
        HEAP32[$21>>2] = $42;
        $43 = (($21) + 4|0);
        HEAP32[$43>>2] = $28;
        $__p$0$i$i$i$i$i$i$i = $38;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i|0),($26|0),($28|0))|0;
       $44 = (($__p$0$i$i$i$i$i$i$i) + ($28)|0);
       HEAP8[$44>>0] = 0;
      }
      $45 = (($21) + 12|0);
      $46 = (($$01$i) + 12|0);
      ;HEAP32[$45+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$46+8>>2]|0;
      $$pre3$i = HEAP32[$0>>2]|0;
      $48 = $$pre3$i;
     }
     $47 = (($48) + 24|0);
     HEAP32[$0>>2] = $47;
     $49 = (($$01$i) + 24|0);
     $50 = ($49|0)==($18|0);
     if ($50) {
      label = 29;
      break;
     } else {
      $$01$i = $49;$21 = $47;
     }
    }
    if ((label|0) == 11) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 21;
      break;
     }
     // unreachable;
    }
    else if ((label|0) == 20) {
     $51 = ___cxa_find_matching_catch()|0;
     $52 = tempRet0;
     $lpad$phi$index = $51;$lpad$phi$index2 = $52;
     break;
    }
    else if ((label|0) == 29) {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  $lpad$phi$index = $53;$lpad$phi$index2 = $54;
 }
 $55 = HEAP32[$this>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $57 = HEAP32[$0>>2]|0;
 $58 = ($57|0)==($55|0);
 if ($58) {
  $68 = $55;
 } else {
  $60 = $57;
  while(1) {
   $59 = (($60) + -24|0);
   HEAP32[$0>>2] = $59;
   $61 = HEAP8[$59>>0]|0;
   $62 = $61 & 1;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    $65 = $59;
   } else {
    $66 = (($60) + -16|0);
    $67 = HEAP32[$66>>2]|0;
    __ZdlPv($67);
    $$pre$i$i$i = HEAP32[$0>>2]|0;
    $65 = $$pre$i$i$i;
   }
   $64 = ($65|0)==($55|0);
   if ($64) {
    break;
   } else {
    $60 = $65;
   }
  }
  $$pre$i = HEAP32[$this>>2]|0;
  $68 = $$pre$i;
 }
 __ZdlPv($68);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS_9allocatorIS3_EEEC2ERKS6_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$01$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($__x) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$__x>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 24)&-1;
 $9 = ($3|0)==($4|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8>>>0)>(178956970);
 do {
  if ($10) {
   __THREW__ = 0;
   invoke_vi(3308,0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 21;
   } else {
    // unreachable;
   }
  } else {
   __THREW__ = 0;
   $13 = (invoke_ii(2988,($7|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 21;
   } else {
    HEAP32[$0>>2] = $13;
    HEAP32[$this>>2] = $13;
    $16 = (($13) + (($8*24)|0)|0);
    HEAP32[$1>>2] = $16;
    $17 = HEAP32[$__x>>2]|0;
    $18 = HEAP32[$2>>2]|0;
    $19 = ($17|0)==($18|0);
    if ($19) {
     STACKTOP = sp;return;
    } else {
     $$01$i = $17;$21 = $13;
    }
    while(1) {
     $20 = ($21|0)==(0|0);
     if ($20) {
      $48 = 0;
     } else {
      $22 = HEAP8[$$01$i>>0]|0;
      $23 = $22 & 1;
      $24 = ($23<<24>>24)==(0);
      if ($24) {
       ;HEAP32[$21+0>>2]=HEAP32[$$01$i+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$$01$i+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$$01$i+8>>2]|0;
      } else {
       $25 = (($$01$i) + 8|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = (($$01$i) + 4|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = ($28>>>0)>(4294967279);
       if ($29) {
        label = 11;
        break;
       }
       $32 = ($28>>>0)<(11);
       if ($32) {
        $33 = $28 << 1;
        $34 = $33&255;
        HEAP8[$21>>0] = $34;
        $35 = (($21) + 1|0);
        $__p$0$i$i$i$i$i$i$i = $35;
       } else {
        $36 = (($28) + 16)|0;
        $37 = $36 & -16;
        __THREW__ = 0;
        $38 = (invoke_ii(2988,($37|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 20;
         break;
        }
        $41 = (($21) + 8|0);
        HEAP32[$41>>2] = $38;
        $42 = $37 | 1;
        HEAP32[$21>>2] = $42;
        $43 = (($21) + 4|0);
        HEAP32[$43>>2] = $28;
        $__p$0$i$i$i$i$i$i$i = $38;
       }
       _memcpy(($__p$0$i$i$i$i$i$i$i|0),($26|0),($28|0))|0;
       $44 = (($__p$0$i$i$i$i$i$i$i) + ($28)|0);
       HEAP8[$44>>0] = 0;
      }
      $45 = (($21) + 12|0);
      $46 = (($$01$i) + 12|0);
      ;HEAP32[$45+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$46+8>>2]|0;
      $$pre3$i = HEAP32[$0>>2]|0;
      $48 = $$pre3$i;
     }
     $47 = (($48) + 24|0);
     HEAP32[$0>>2] = $47;
     $49 = (($$01$i) + 24|0);
     $50 = ($49|0)==($18|0);
     if ($50) {
      label = 29;
      break;
     } else {
      $$01$i = $49;$21 = $47;
     }
    }
    if ((label|0) == 11) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 21;
      break;
     }
     // unreachable;
    }
    else if ((label|0) == 20) {
     $51 = ___cxa_find_matching_catch()|0;
     $52 = tempRet0;
     $lpad$phi$index = $51;$lpad$phi$index2 = $52;
     break;
    }
    else if ((label|0) == 29) {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  $lpad$phi$index = $53;$lpad$phi$index2 = $54;
 }
 $55 = HEAP32[$this>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $57 = HEAP32[$0>>2]|0;
 $58 = ($57|0)==($55|0);
 if ($58) {
  $68 = $55;
 } else {
  $60 = $57;
  while(1) {
   $59 = (($60) + -24|0);
   HEAP32[$0>>2] = $59;
   $61 = HEAP8[$59>>0]|0;
   $62 = $61 & 1;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    $65 = $59;
   } else {
    $66 = (($60) + -16|0);
    $67 = HEAP32[$66>>2]|0;
    __ZdlPv($67);
    $$pre$i$i$i = HEAP32[$0>>2]|0;
    $65 = $$pre$i$i$i;
   }
   $64 = ($65|0)==($55|0);
   if ($64) {
    break;
   } else {
    $60 = $65;
   }
  }
  $$pre$i = HEAP32[$this>>2]|0;
  $68 = $$pre$i;
 }
 __ZdlPv($68);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN9ShaderLab14ParserPropertyC2EPKcS2_NS0_4TypeERKNSt3__16vectorINS4_12basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEENS9_ISB_EEEE($this,$name,$desc,$type,$attribs) {
 $this = $this|0;
 $name = $name|0;
 $desc = $desc|0;
 $type = $type|0;
 $attribs = $attribs|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$3 = 0, $$34 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i10 = 0, $__p$0$i$i$i6 = 0, $i$032 = 0, $j$027 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (_strlen(($name|0))|0);
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$this>>0] = $5;
  $6 = (($this) + 1|0);
  $__p$0$i$i$i = $6;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  $10 = (($this) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$this>>2] = $11;
  $12 = (($this) + 4|0);
  HEAP32[$12>>2] = $1;
  $__p$0$i$i$i = $9;
 }
 _memcpy(($__p$0$i$i$i|0),($name|0),($1|0))|0;
 $13 = (($__p$0$i$i$i) + ($1)|0);
 HEAP8[$13>>0] = 0;
 $14 = (($this) + 12|0);
 $15 = (_strlen(($desc|0))|0);
 $16 = ($15>>>0)>(4294967279);
 do {
  if ($16) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 32;
   } else {
    // unreachable;
   }
  } else {
   $19 = ($15>>>0)<(11);
   if ($19) {
    $20 = $15 << 1;
    $21 = $20&255;
    HEAP8[$14>>0] = $21;
    $22 = (($14) + 1|0);
    $__p$0$i$i$i6 = $22;
   } else {
    $23 = (($15) + 16)|0;
    $24 = $23 & -16;
    __THREW__ = 0;
    $25 = (invoke_ii(2988,($24|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     label = 32;
     break;
    }
    $28 = (($this) + 20|0);
    HEAP32[$28>>2] = $25;
    $29 = $24 | 1;
    HEAP32[$14>>2] = $29;
    $30 = (($this) + 16|0);
    HEAP32[$30>>2] = $15;
    $__p$0$i$i$i6 = $25;
   }
   _memcpy(($__p$0$i$i$i6|0),($desc|0),($15|0))|0;
   $31 = (($__p$0$i$i$i6) + ($15)|0);
   HEAP8[$31>>0] = 0;
   $32 = (($this) + 24|0);
   HEAP32[$32>>2] = 0;
   $33 = (($this) + 28|0);
   HEAP32[$33>>2] = 0;
   $34 = (($this) + 32|0);
   HEAP32[$34>>2] = 0;
   $35 = (($this) + 36|0);
   HEAP32[$35>>2] = $type;
   $36 = (($this) + 40|0);
   HEAP32[$36>>2] = 0;
   $37 = (($this) + 60|0);
   ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;
   $38 = (($this) + 72|0);
   HEAP32[$38>>2] = 5;
   $39 = (($attribs) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP32[$attribs>>2]|0;
   $42 = $40;
   $43 = $41;
   $44 = (($42) - ($43))|0;
   $45 = (($44|0) / 12)&-1;
   __THREW__ = 0;
   invoke_vii(3255,($32|0),($45|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   do {
    if ($47) {
     label = 35;
    } else {
     $48 = HEAP32[$39>>2]|0;
     $49 = HEAP32[$attribs>>2]|0;
     $50 = ($48|0)==($49|0);
     if ($50) {
      $scevgep = (($this) + 44|0);
      ;HEAP32[$scevgep+0>>2]=0|0;HEAP32[$scevgep+4>>2]=0|0;HEAP32[$scevgep+8>>2]=0|0;HEAP32[$scevgep+12>>2]=0|0;
      STACKTOP = sp;return;
     }
     $51 = (($0) + 1|0);
     $52 = (($0) + 8|0);
     $53 = (($0) + 4|0);
     $55 = $49;$i$032 = 0;
     L22: while(1) {
      $54 = (($55) + (($i$032*12)|0)|0);
      $56 = (($54) + 1|0);
      $57 = ((($55) + (($i$032*12)|0)|0) + 8|0);
      $j$027 = 0;
      while(1) {
       $60 = (679840 + ($j$027<<2)|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (_strlen(($61|0))|0);
       $63 = ($62>>>0)>(4294967279);
       if ($63) {
        label = 20;
        break L22;
       }
       $66 = ($62>>>0)<(11);
       if ($66) {
        $67 = $62 << 1;
        $68 = $67&255;
        HEAP8[$0>>0] = $68;
        $82 = $68;$__p$0$i$i$i10 = $51;
       } else {
        $69 = (($62) + 16)|0;
        $70 = $69 & -16;
        __THREW__ = 0;
        $71 = (invoke_ii(2988,($70|0))|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         label = 33;
         break L22;
        }
        HEAP32[$52>>2] = $71;
        $74 = $70 | 1;
        HEAP32[$0>>2] = $74;
        HEAP32[$53>>2] = $62;
        $75 = $74&255;
        $82 = $75;$__p$0$i$i$i10 = $71;
       }
       _memcpy(($__p$0$i$i$i10|0),($61|0),($62|0))|0;
       $76 = (($__p$0$i$i$i10) + ($62)|0);
       HEAP8[$76>>0] = 0;
       $77 = HEAP8[$54>>0]|0;
       $78 = $77 & 1;
       $79 = ($78<<24>>24)==(0);
       if ($79) {
        $85 = $56;
       } else {
        $80 = HEAP32[$57>>2]|0;
        $85 = $80;
       }
       $81 = $82 & 1;
       $83 = ($81<<24>>24)==(0);
       $84 = HEAP32[$52>>2]|0;
       $$ = $83 ? $51 : $84;
       __THREW__ = 0;
       $86 = (invoke_iii(2448,($85|0),($$|0))|0);
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        label = 37;
        break L22;
       }
       $89 = HEAP8[$0>>0]|0;
       $90 = $89 & 1;
       $91 = ($90<<24>>24)==(0);
       if (!($91)) {
        $92 = HEAP32[$52>>2]|0;
        __ZdlPv($92);
       }
       $93 = ($86|0)==(0);
       $59 = (($j$027) + 1)|0;
       if ($93) {
        label = 39;
        break;
       }
       $58 = ($59|0)<(14);
       if ($58) {
        $j$027 = $59;
       } else {
        label = 40;
        break;
       }
      }
      do {
       if ((label|0) == 39) {
        label = 0;
        $108 = 1 << $j$027;
        $109 = HEAP32[$36>>2]|0;
        $110 = $109 | $108;
        HEAP32[$36>>2] = $110;
       }
       else if ((label|0) == 40) {
        label = 0;
        $111 = HEAP32[$33>>2]|0;
        $112 = HEAP32[$34>>2]|0;
        $113 = ($111|0)==($112|0);
        if ($113) {
         __THREW__ = 0;
         invoke_vii(2523,($32|0),($54|0));
         $139 = __THREW__; __THREW__ = 0;
         $140 = $139&1;
         if ($140) {
          label = 34;
          break L22;
         } else {
          break;
         }
        }
        $114 = ($111|0)==(0|0);
        do {
         if (!($114)) {
          $115 = HEAP8[$54>>0]|0;
          $116 = $115 & 1;
          $117 = ($116<<24>>24)==(0);
          if ($117) {
           ;HEAP32[$111+0>>2]=HEAP32[$54+0>>2]|0;HEAP32[$111+4>>2]=HEAP32[$54+4>>2]|0;HEAP32[$111+8>>2]=HEAP32[$54+8>>2]|0;
           break;
          }
          $118 = HEAP32[$57>>2]|0;
          $119 = ((($55) + (($i$032*12)|0)|0) + 4|0);
          $120 = HEAP32[$119>>2]|0;
          $121 = ($120>>>0)>(4294967279);
          if ($121) {
           label = 45;
           break L22;
          }
          $124 = ($120>>>0)<(11);
          if ($124) {
           $125 = $120 << 1;
           $126 = $125&255;
           HEAP8[$111>>0] = $126;
           $127 = (($111) + 1|0);
           $__p$0$i$i$i$i$i = $127;
          } else {
           $128 = (($120) + 16)|0;
           $129 = $128 & -16;
           __THREW__ = 0;
           $130 = (invoke_ii(2988,($129|0))|0);
           $131 = __THREW__; __THREW__ = 0;
           $132 = $131&1;
           if ($132) {
            label = 34;
            break L22;
           }
           $133 = (($111) + 8|0);
           HEAP32[$133>>2] = $130;
           $134 = $129 | 1;
           HEAP32[$111>>2] = $134;
           $135 = (($111) + 4|0);
           HEAP32[$135>>2] = $120;
           $__p$0$i$i$i$i$i = $130;
          }
          _memcpy(($__p$0$i$i$i$i$i|0),($118|0),($120|0))|0;
          $136 = (($__p$0$i$i$i$i$i) + ($120)|0);
          HEAP8[$136>>0] = 0;
         }
        } while(0);
        $137 = HEAP32[$33>>2]|0;
        $138 = (($137) + 12|0);
        HEAP32[$33>>2] = $138;
       }
      } while(0);
      $141 = (($i$032) + 1)|0;
      $142 = HEAP32[$39>>2]|0;
      $143 = HEAP32[$attribs>>2]|0;
      $144 = $142;
      $145 = $143;
      $146 = (($144) - ($145))|0;
      $147 = (($146|0) / 12)&-1;
      $148 = ($141>>>0)<($147>>>0);
      if ($148) {
       $55 = $143;$i$032 = $141;
      } else {
       label = 16;
       break;
      }
     }
     if ((label|0) == 16) {
      $scevgep = (($this) + 44|0);
      ;HEAP32[$scevgep+0>>2]=0|0;HEAP32[$scevgep+4>>2]=0|0;HEAP32[$scevgep+8>>2]=0|0;HEAP32[$scevgep+12>>2]=0|0;
      STACKTOP = sp;return;
     }
     else if ((label|0) == 20) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 35;
       break;
      }
      // unreachable;
     }
     else if ((label|0) == 33) {
      $96 = ___cxa_find_matching_catch()|0;
      $97 = tempRet0;
      $lpad$phi$index = $96;$lpad$phi$index3 = $97;
      label = 36;
      break;
     }
     else if ((label|0) == 34) {
      $98 = ___cxa_find_matching_catch()|0;
      $99 = tempRet0;
      $lpad$phi$index = $98;$lpad$phi$index3 = $99;
      label = 36;
      break;
     }
     else if ((label|0) == 37) {
      $102 = ___cxa_find_matching_catch()|0;
      $103 = tempRet0;
      $104 = HEAP8[$0>>0]|0;
      $105 = $104 & 1;
      $106 = ($105<<24>>24)==(0);
      if ($106) {
       $$0 = $102;$$01 = $103;
       break;
      }
      $107 = HEAP32[$52>>2]|0;
      __ZdlPv($107);
      $$0 = $102;$$01 = $103;
      break;
     }
     else if ((label|0) == 45) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       label = 35;
       break;
      }
      // unreachable;
     }
    }
   } while(0);
   if ((label|0) == 35) {
    $100 = ___cxa_find_matching_catch()|0;
    $101 = tempRet0;
    $lpad$phi$index = $100;$lpad$phi$index3 = $101;
    label = 36;
   }
   if ((label|0) == 36) {
    $$0 = $lpad$phi$index;$$01 = $lpad$phi$index3;
   }
   $149 = HEAP8[$37>>0]|0;
   $150 = $149 & 1;
   $151 = ($150<<24>>24)==(0);
   if (!($151)) {
    $152 = (($this) + 68|0);
    $153 = HEAP32[$152>>2]|0;
    __ZdlPv($153);
   }
   $154 = HEAP32[$32>>2]|0;
   $155 = ($154|0)==(0|0);
   if (!($155)) {
    $156 = HEAP32[$33>>2]|0;
    $157 = ($156|0)==($154|0);
    if ($157) {
     $167 = $154;
    } else {
     $159 = $156;
     while(1) {
      $158 = (($159) + -12|0);
      HEAP32[$33>>2] = $158;
      $160 = HEAP8[$158>>0]|0;
      $161 = $160 & 1;
      $162 = ($161<<24>>24)==(0);
      if ($162) {
       $164 = $158;
      } else {
       $165 = (($159) + -4|0);
       $166 = HEAP32[$165>>2]|0;
       __ZdlPv($166);
       $$pre$i$i$i$i$i = HEAP32[$33>>2]|0;
       $164 = $$pre$i$i$i$i$i;
      }
      $163 = ($164|0)==($154|0);
      if ($163) {
       break;
      } else {
       $159 = $164;
      }
     }
     $$pre$i$i$i = HEAP32[$32>>2]|0;
     $167 = $$pre$i$i$i;
    }
    __ZdlPv($167);
   }
   $168 = HEAP8[$14>>0]|0;
   $169 = $168 & 1;
   $170 = ($169<<24>>24)==(0);
   if ($170) {
    $$3 = $$0;$$34 = $$01;
   } else {
    $171 = (($this) + 20|0);
    $172 = HEAP32[$171>>2]|0;
    __ZdlPv($172);
    $$3 = $$0;$$34 = $$01;
   }
  }
 } while(0);
 if ((label|0) == 32) {
  $94 = ___cxa_find_matching_catch()|0;
  $95 = tempRet0;
  $$3 = $94;$$34 = $95;
 }
 $173 = HEAP8[$this>>0]|0;
 $174 = $173 & 1;
 $175 = ($174<<24>>24)==(0);
 if ($175) {
  ___resumeException($$3|0);
  // unreachable;
 }
 $176 = (($this) + 8|0);
 $177 = HEAP32[$176>>2]|0;
 __ZdlPv($177);
 ___resumeException($$3|0);
 // unreachable;
}
function __ZN9ShaderLab9SubShaderC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 61;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 24|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 28|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 24|0);
 $7 = (($this) + 20|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 32|0);
 $9 = (($this) + 43|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP16[$8+8>>1]=0|0;HEAP8[$8+10>>0]=0|0;
 HEAP8[$9>>0] = 1;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = -1;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9SubShader19CreateFromSubShaderERKS0_($other) {
 $other = $other|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(52,$$byval_copy1,0,16,679952,43)|0);
 __THREW__ = 0;
 invoke_vii(3279,($2|0),($other|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  STACKTOP = sp;return ($2|0);
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($2|0),($$byval_copy1|0),0,16,(679952|0),43);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  ___resumeException($5|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN9ShaderLab9SubShaderC2ERKS0_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$0 = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$01 = 0, $$01$i$i$i$i$i$i = 0, $$byval_copy2 = 0, $$idx$i$i = 0, $$pre$i = 0, $$pre$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__parent$i$i$i$i$i = 0;
 var $i$02 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $0 = sp + 16|0;
 $__parent$i$i$i$i$i = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp;
 $3 = (($other) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 12|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$this>>2] = 0;
 $8 = HEAP32[$other>>2]|0;
 $9 = (($other) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $$idx$i$i = $10 << 2;
 $11 = $$idx$i$i >> 2;
 HEAP32[$6>>2] = $11;
 $12 = ($11|0)==(0);
 if ($12) {
  $14 = 0;$15 = 0;
 } else {
  HEAP32[$7>>2] = $11;
  HEAP32[$0>>2] = $4;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i,4,$$byval_copy2,0,679952,370)|0);
  HEAP32[$this>>2] = $13;
  $$pre$i = HEAP32[$6>>2]|0;
  $phitmp$i = $$pre$i << 2;
  $14 = $13;$15 = $phitmp$i;
 }
 _memcpy(($14|0),($8|0),($15|0))|0;
 $16 = (($this) + 16|0);
 $17 = HEAP32[$9>>2]|0;
 HEAP32[$16>>2] = $17;
 $18 = (($this) + 20|0);
 $19 = (($this) + 24|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 28|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 24|0);
 HEAP32[$18>>2] = $21;
 $22 = (($other) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($other) + 24|0);
 $25 = ($23|0)==($24|0);
 L4: do {
  if ($25) {
   label = 15;
  } else {
   $27 = $23;
   while(1) {
    $26 = (($27) + 16|0);
    $28 = $26;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 4)|0;
    $32 = $31;
    $33 = HEAP32[$32>>2]|0;
    $34 = $2;
    $35 = $34;
    HEAP32[$35>>2] = $30;
    $36 = (($34) + 4)|0;
    $37 = $36;
    HEAP32[$37>>2] = $33;
    HEAP32[$1>>2] = $21;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    $38 = (__ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE12__find_equalIS2_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_SC_EEiEESF_RKT_($18,$$byval_copy2,$__parent$i$i$i$i$i,$2)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     __THREW__ = 0;
     $41 = (invoke_ii(2988,24)|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     $44 = (($41) + 16|0);
     $45 = $2;
     $46 = $45;
     $47 = HEAP32[$46>>2]|0;
     $48 = (($45) + 4)|0;
     $49 = $48;
     $50 = HEAP32[$49>>2]|0;
     $51 = $44;
     $52 = $51;
     HEAP32[$52>>2] = $47;
     $53 = (($51) + 4)|0;
     $54 = $53;
     HEAP32[$54>>2] = $50;
     $55 = HEAP32[$__parent$i$i$i$i$i>>2]|0;
     HEAP32[$41>>2] = 0;
     $56 = (($41) + 4|0);
     HEAP32[$56>>2] = 0;
     $57 = (($41) + 8|0);
     HEAP32[$57>>2] = $55;
     HEAP32[$38>>2] = $41;
     $58 = HEAP32[$18>>2]|0;
     $59 = HEAP32[$58>>2]|0;
     $60 = ($59|0)==(0|0);
     if ($60) {
      $62 = $41;
     } else {
      HEAP32[$18>>2] = $59;
      $$pre$i$i$i$i$i$i = HEAP32[$38>>2]|0;
      $62 = $$pre$i$i$i$i$i$i;
     }
     $61 = HEAP32[$19>>2]|0;
     __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($61,$62);
     $63 = HEAP32[$20>>2]|0;
     $64 = (($63) + 1)|0;
     HEAP32[$20>>2] = $64;
    }
    $65 = (($27) + 4|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    if ($67) {
     $$01$i$i$i$i$i$i = $27;
     while(1) {
      $70 = (($$01$i$i$i$i$i$i) + 8|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = HEAP32[$71>>2]|0;
      $73 = ($72|0)==($$01$i$i$i$i$i$i|0);
      if ($73) {
       $$0$i$i$i$i$i$i = $71;
       break;
      } else {
       $$01$i$i$i$i$i$i = $71;
      }
     }
    } else {
     $$0$i$i$i$i$i$i$i = $66;
     while(1) {
      $68 = HEAP32[$$0$i$i$i$i$i$i$i>>2]|0;
      $69 = ($68|0)==(0|0);
      if ($69) {
       $$0$i$i$i$i$i$i = $$0$i$i$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i$i$i = $68;
      }
     }
    }
    $74 = ($$0$i$i$i$i$i$i|0)==($24|0);
    if ($74) {
     label = 15;
     break L4;
    } else {
     $27 = $$0$i$i$i$i$i$i;
    }
   }
   $96 = ___cxa_find_matching_catch()|0;
   $97 = tempRet0;
   $98 = HEAP32[$19>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($18,$98);
   $$0 = $97;$$01 = $96;
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   $75 = (($this) + 32|0);
   $76 = (($other) + 32|0);
   $77 = HEAP32[$76>>2]|0;
   HEAP32[$75>>2] = $77;
   $78 = (($this) + 36|0);
   $79 = (($this) + 43|0);
   $80 = (($other) + 43|0);
   ;HEAP32[$78+0>>2]=0|0;HEAP16[$78+4>>1]=0|0;HEAP8[$78+6>>0]=0|0;
   $81 = HEAP8[$80>>0]|0;
   HEAP8[$79>>0] = $81;
   $82 = (($this) + 44|0);
   $83 = (($other) + 44|0);
   $84 = HEAP32[$83>>2]|0;
   HEAP32[$82>>2] = $84;
   $85 = (($this) + 48|0);
   HEAP32[$85>>2] = -1;
   $86 = HEAP32[$6>>2]|0;
   $87 = ($86|0)==(0);
   if ($87) {
    STACKTOP = sp;return;
   } else {
    $i$02 = 0;
   }
   while(1) {
    $88 = HEAP32[$this>>2]|0;
    $89 = (($88) + ($i$02<<2)|0);
    $90 = HEAP32[$89>>2]|0;
    __THREW__ = 0;
    invoke_vi(3602,($90|0));
    $91 = __THREW__; __THREW__ = 0;
    $92 = $91&1;
    if ($92) {
     label = 19;
     break;
    }
    $93 = (($i$02) + 1)|0;
    $94 = HEAP32[$6>>2]|0;
    $95 = ($93>>>0)<($94>>>0);
    if ($95) {
     $i$02 = $93;
    } else {
     label = 20;
     break;
    }
   }
   if ((label|0) == 19) {
    $99 = ___cxa_find_matching_catch()|0;
    $100 = tempRet0;
    $101 = HEAP32[$19>>2]|0;
    __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($18,$101);
    $$0 = $100;$$01 = $99;
    break;
   }
   else if ((label|0) == 20) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $102 = HEAP32[$7>>2]|0;
 $103 = ($102|0)>(-1);
 if (!($103)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $104 = HEAP32[$this>>2]|0;
 $105 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = $105;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($104|0),($$byval_copy2|0));
 $106 = __THREW__; __THREW__ = 0;
 $107 = $106&1;
 if ($107) {
  $108 = ___cxa_find_matching_catch(0|0)|0;
  $109 = tempRet0;
  ___clang_call_terminate($108);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN9ShaderLab9SubShaderD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if (!($3)) {
   $4 = HEAP32[$this>>2]|0;
   $i$03 = $4;
   while(1) {
    $5 = HEAP32[$i$03>>2]|0;
    __THREW__ = 0;
    invoke_vi(3603,($5|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    $8 = (($i$03) + 4|0);
    $9 = HEAP32[$this>>2]|0;
    $10 = HEAP32[$1>>2]|0;
    $11 = (($9) + ($10<<2)|0);
    $12 = ($8|0)==($11|0);
    if ($12) {
     break L1;
    } else {
     $i$03 = $8;
    }
   }
   $22 = ___cxa_find_matching_catch()|0;
   $23 = tempRet0;
   $24 = (($this) + 20|0);
   $25 = (($this) + 24|0);
   $26 = HEAP32[$25>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($24,$26);
   $27 = (($this) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)>(-1);
   if (!($29)) {
    ___resumeException($22|0);
    // unreachable;
   }
   $30 = HEAP32[$this>>2]|0;
   $31 = (($this) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$0>>2] = $32;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($30|0),($$byval_copy1|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $35 = ___cxa_find_matching_catch(0|0)|0;
    $36 = tempRet0;
    ___clang_call_terminate($35);
    // unreachable;
   }
   HEAP32[$this>>2] = 0;
   ___resumeException($22|0);
   // unreachable;
  }
 } while(0);
 $13 = (($this) + 20|0);
 $14 = (($this) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiiEENS_19__map_value_compareIiS2_NS_4lessIiEELb1EEENS_9allocatorIS2_EEE7destroyEPNS_11__tree_nodeIS2_PvEE($13,$15);
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>(-1);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($this) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$0>>2] = $21;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy1);
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9SubShader15FindNamedPassesERK8UnityStrR13dynamic_arrayIPNS_4PassELj4EE($this,$passName,$outPasses) {
 $this = $this|0;
 $passName = $passName|0;
 $outPasses = $outPasses|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($passName) + 1|0);
 $5 = (($outPasses) + 8|0);
 $6 = (($outPasses) + 12|0);
 $7 = (($outPasses) + 4|0);
 $8 = (($passName) + 8|0);
 $9 = (($passName) + 4|0);
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$this>>2]|0;
  $11 = (($10) + ($i$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 628|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $19 = $14&255;
   $20 = $19 >>> 1;
   $28 = $20;
  } else {
   $17 = (($12) + 632|0);
   $18 = HEAP32[$17>>2]|0;
   $28 = $18;
  }
  $21 = HEAP8[$passName>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   $25 = $21&255;
   $26 = $25 >>> 1;
   $29 = $26;
  } else {
   $24 = HEAP32[$9>>2]|0;
   $29 = $24;
  }
  $27 = ($28|0)==($29|0);
  if ($27) {
   if ($16) {
    $32 = (($13) + 1|0);
    $38 = $32;
   } else {
    $30 = (($12) + 636|0);
    $31 = HEAP32[$30>>2]|0;
    $38 = $31;
   }
   if ($23) {
    $39 = $4;
   } else {
    $33 = HEAP32[$8>>2]|0;
    $39 = $33;
   }
   if ($16) {
    $36 = $14&255;
    $37 = $36 >>> 1;
    $40 = $37;
   } else {
    $34 = (($12) + 632|0);
    $35 = HEAP32[$34>>2]|0;
    $40 = $35;
   }
   $41 = (_strncmp($38,$39,$40)|0);
   $42 = ($41|0)==(0);
   if ($42) {
    $43 = HEAP32[$5>>2]|0;
    $44 = (($43) + 1)|0;
    HEAP32[$5>>2] = $44;
    $45 = HEAP32[$6>>2]|0;
    $46 = $45 & 2147483647;
    $47 = ($44>>>0)>($46>>>0);
    if ($47) {
     $48 = $45 << 1;
     $49 = ($48|0)==(0);
     $50 = $49 ? 1 : $48;
     $51 = ($46>>>0)<($50>>>0);
     do {
      if ($51) {
       $52 = ($45|0)>(-1);
       if ($52) {
        HEAP32[$6>>2] = $50;
        $53 = HEAP32[$outPasses>>2]|0;
        $54 = $50 << 2;
        $55 = HEAP32[$7>>2]|0;
        HEAP32[$0>>2] = $55;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
        $56 = (__Z16realloc_internalPvji10MemLabelIdiPKci($53,$54,4,$$byval_copy1,0,679952,370)|0);
        HEAP32[$outPasses>>2] = $56;
        break;
       } else {
        $57 = $50 << 2;
        $58 = HEAP32[$7>>2]|0;
        HEAP32[$0>>2] = $58;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
        $59 = (__Z15malloc_internaljj10MemLabelIdiPKci($57,4,$$byval_copy1,0,679952,352)|0);
        $60 = HEAP32[$outPasses>>2]|0;
        $61 = HEAP32[$5>>2]|0;
        $62 = $61 << 2;
        _memcpy(($59|0),($60|0),($62|0))|0;
        HEAP32[$6>>2] = $50;
        HEAP32[$outPasses>>2] = $59;
        break;
       }
      }
     } while(0);
     $$pre$i$i = HEAP32[$5>>2]|0;
     $64 = $$pre$i$i;
    } else {
     $64 = $44;
    }
    $63 = (($64) + -1)|0;
    $65 = HEAP32[$outPasses>>2]|0;
    $66 = (($65) + ($63<<2)|0);
    HEAP32[$66>>2] = $12;
    __ZN9ShaderLab4Pass6RetainEv($12);
   }
  }
  $67 = (($i$01) + 1)|0;
  $exitcond = ($67|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $67;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9SubShader15CollectChannelsEPKNS_13PropertySheetE($this,$props) {
 $this = $this|0;
 $props = $props|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$this>>2]|0;
 $i$01 = $3;
 while(1) {
  $4 = HEAP32[$i$01>>2]|0;
  __ZN9ShaderLab4Pass19CollectPassChannelsEPKNS_13PropertySheetE($4,$props);
  $5 = (($i$01) + 4|0);
  $6 = HEAP32[$this>>2]|0;
  $7 = HEAP32[$0>>2]|0;
  $8 = (($6) + ($7<<2)|0);
  $9 = ($5|0)==($8|0);
  if ($9) {
   break;
  } else {
   $i$01 = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9SubShader20IsSubShaderSupportedEPKNS_13PropertySheetERb($this,$props,$inoutHadShadowPasses) {
 $this = $this|0;
 $props = $props|0;
 $inoutHadShadowPasses = $inoutHadShadowPasses|0;
 var $$ = 0, $$$i = 0, $$$i37 = 0, $$$i67 = 0, $$0 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i$i35 = 0, $$0$ph5$i$i$i$i46 = 0, $$0$ph5$i$i$i$i55 = 0, $$0$ph5$i$i$i$i65 = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i$i29 = 0, $$0$ph7$i$i$i$i40 = 0, $$0$ph7$i$i$i$i49 = 0, $$0$ph7$i$i$i$i59 = 0, $$01 = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i$i30 = 0, $$01$ph6$i$in$i$i$i41 = 0, $$01$ph6$i$in$i$i$i50 = 0;
 var $$01$ph6$i$in$i$i$i60 = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i$i32 = 0, $$013$i$in$i$i$i43 = 0, $$013$i$in$i$i$i52 = 0, $$013$i$in$i$i$i62 = 0, $$02 = 0, $$73 = 0, $$74 = 0, $$lcssa105289 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $hadUnsupportedFixedFunction$0$off0$ph102191 = 0, $hadUnsupportedFixedFunction$0$off0$ph104149 = 0, $hadUnsupportedFixedFunction$0$off0$ph104149284 = 0, $hadUnsupportedFixedFunction$0$off0$ph104149288 = 0, $hadUnsupportedFixedFunction$0$off0$ph104162 = 0, $hadUnsupportedFixedFunction$0$off0$ph221 = 0, $i$0$ph219 = 0, $i1$0$ph141 = 0, $i6$079 = 0, $or$cond1$i = 0, $or$cond2$i = 0, $renderPathsThatNeedRemoval$0$ph101171287 = 0, $renderPathsThatNeedRemoval$0$ph101190 = 0, $renderPathsThatNeedRemoval$0$ph220 = 0;
 var $storemerge = 0, $vararg_buffer11 = 0, $vararg_ptr3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vararg_buffer11 = sp;
 $0 = sp + 68|0;
 $1 = sp + 8|0;
 $2 = sp + 20|0;
 $3 = sp + 32|0;
 $4 = sp + 44|0;
 $5 = sp + 56|0;
 $6 = HEAP8[679968>>0]|0;
 $7 = ($6<<24>>24)==(0);
 do {
  if ($7) {
   HEAP8[$0>>0] = 18;
   $8 = (($0) + 1|0);
   dest=$8+0|0; src=679976+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $9 = (($0) + 10|0);
   HEAP8[$9>>0] = 0;
   __THREW__ = 0;
   $10 = (invoke_ii(3224,($0|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP8[$0>>0]|0;
    $14 = $13 & 1;
    $15 = ($14<<24>>24)==(0);
    if (!($15)) {
     $16 = (($0) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     __ZdlPv($17);
    }
    HEAP32[679960>>2] = $10;
    HEAP8[679968>>0] = 1;
    break;
   }
   $127 = ___cxa_find_matching_catch()|0;
   $128 = tempRet0;
   $129 = HEAP8[$0>>0]|0;
   $130 = $129 & 1;
   $131 = ($130<<24>>24)==(0);
   if ($131) {
    $$01 = $127;$$02 = $128;
    ___resumeException($$01|0);
    // unreachable;
   }
   $132 = (($0) + 8|0);
   $133 = HEAP32[$132>>2]|0;
   __ZdlPv($133);
   $$01 = $127;$$02 = $128;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $18 = HEAP8[680000>>0]|0;
 $19 = ($18<<24>>24)==(0);
 do {
  if ($19) {
   $20 = (__Znwj(16)|0);
   $21 = (($1) + 8|0);
   HEAP32[$21>>2] = $20;
   HEAP32[$1>>2] = 17;
   $22 = (($1) + 4|0);
   HEAP32[$22>>2] = 12;
   dest=$20+0|0; src=680008+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $23 = (($20) + 12|0);
   HEAP8[$23>>0] = 0;
   __THREW__ = 0;
   $24 = (invoke_ii(3224,($1|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP8[$1>>0]|0;
    $28 = $27 & 1;
    $29 = ($28<<24>>24)==(0);
    if (!($29)) {
     $30 = HEAP32[$21>>2]|0;
     __ZdlPv($30);
    }
    HEAP32[679992>>2] = $24;
    HEAP8[680000>>0] = 1;
    break;
   }
   $134 = ___cxa_find_matching_catch()|0;
   $135 = tempRet0;
   $136 = HEAP8[$1>>0]|0;
   $137 = $136 & 1;
   $138 = ($137<<24>>24)==(0);
   if ($138) {
    $$01 = $134;$$02 = $135;
    ___resumeException($$01|0);
    // unreachable;
   }
   $139 = HEAP32[$21>>2]|0;
   __ZdlPv($139);
   $$01 = $134;$$02 = $135;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $31 = HEAP8[680032>>0]|0;
 $32 = ($31<<24>>24)==(0);
 do {
  if ($32) {
   $33 = (__Znwj(16)|0);
   $34 = (($2) + 8|0);
   HEAP32[$34>>2] = $33;
   HEAP32[$2>>2] = 17;
   $35 = (($2) + 4|0);
   HEAP32[$35>>2] = 15;
   dest=$33+0|0; src=680040+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $36 = (($33) + 15|0);
   HEAP8[$36>>0] = 0;
   __THREW__ = 0;
   $37 = (invoke_ii(3224,($2|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    $40 = HEAP8[$2>>0]|0;
    $41 = $40 & 1;
    $42 = ($41<<24>>24)==(0);
    if (!($42)) {
     $43 = HEAP32[$34>>2]|0;
     __ZdlPv($43);
    }
    HEAP32[680024>>2] = $37;
    HEAP8[680032>>0] = 1;
    break;
   }
   $140 = ___cxa_find_matching_catch()|0;
   $141 = tempRet0;
   $142 = HEAP8[$2>>0]|0;
   $143 = $142 & 1;
   $144 = ($143<<24>>24)==(0);
   if ($144) {
    $$01 = $140;$$02 = $141;
    ___resumeException($$01|0);
    // unreachable;
   }
   $145 = HEAP32[$34>>2]|0;
   __ZdlPv($145);
   $$01 = $140;$$02 = $141;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $44 = HEAP8[680064>>0]|0;
 $45 = ($44<<24>>24)==(0);
 do {
  if ($45) {
   HEAP8[$3>>0] = 12;
   $46 = (($3) + 1|0);
   ;HEAP8[$46+0>>0]=HEAP8[680072+0>>0]|0;HEAP8[$46+1>>0]=HEAP8[680072+1>>0]|0;HEAP8[$46+2>>0]=HEAP8[680072+2>>0]|0;HEAP8[$46+3>>0]=HEAP8[680072+3>>0]|0;HEAP8[$46+4>>0]=HEAP8[680072+4>>0]|0;HEAP8[$46+5>>0]=HEAP8[680072+5>>0]|0;
   $47 = (($3) + 7|0);
   HEAP8[$47>>0] = 0;
   __THREW__ = 0;
   $48 = (invoke_ii(3224,($3|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    $51 = HEAP8[$3>>0]|0;
    $52 = $51 & 1;
    $53 = ($52<<24>>24)==(0);
    if (!($53)) {
     $54 = (($3) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     __ZdlPv($55);
    }
    HEAP32[680056>>2] = $48;
    HEAP8[680064>>0] = 1;
    break;
   }
   $146 = ___cxa_find_matching_catch()|0;
   $147 = tempRet0;
   $148 = HEAP8[$3>>0]|0;
   $149 = $148 & 1;
   $150 = ($149<<24>>24)==(0);
   if ($150) {
    $$01 = $146;$$02 = $147;
    ___resumeException($$01|0);
    // unreachable;
   }
   $151 = (($3) + 8|0);
   $152 = HEAP32[$151>>2]|0;
   __ZdlPv($152);
   $$01 = $146;$$02 = $147;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $56 = HEAP8[680088>>0]|0;
 $57 = ($56<<24>>24)==(0);
 do {
  if ($57) {
   HEAP8[$4>>0] = 16;
   $58 = (($4) + 1|0);
   $59 = $58;
   $60 = $59;
   HEAP8[$60>>0]=1953654102&255;HEAP8[$60+1>>0]=(1953654102>>8)&255;HEAP8[$60+2>>0]=(1953654102>>16)&255;HEAP8[$60+3>>0]=1953654102>>24;
   $61 = (($59) + 4)|0;
   $62 = $61;
   HEAP8[$62>>0]=1296857189&255;HEAP8[$62+1>>0]=(1296857189>>8)&255;HEAP8[$62+2>>0]=(1296857189>>16)&255;HEAP8[$62+3>>0]=1296857189>>24;
   $63 = (($4) + 9|0);
   HEAP8[$63>>0] = 0;
   __THREW__ = 0;
   $64 = (invoke_ii(3224,($4|0))|0);
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if (!($66)) {
    $67 = HEAP8[$4>>0]|0;
    $68 = $67 & 1;
    $69 = ($68<<24>>24)==(0);
    if (!($69)) {
     $70 = (($4) + 8|0);
     $71 = HEAP32[$70>>2]|0;
     __ZdlPv($71);
    }
    HEAP32[680080>>2] = $64;
    HEAP8[680088>>0] = 1;
    break;
   }
   $153 = ___cxa_find_matching_catch()|0;
   $154 = tempRet0;
   $155 = HEAP8[$4>>0]|0;
   $156 = $155 & 1;
   $157 = ($156<<24>>24)==(0);
   if ($157) {
    $$01 = $153;$$02 = $154;
    ___resumeException($$01|0);
    // unreachable;
   }
   $158 = (($4) + 8|0);
   $159 = HEAP32[$158>>2]|0;
   __ZdlPv($159);
   $$01 = $153;$$02 = $154;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $72 = HEAP8[680104>>0]|0;
 $73 = ($72<<24>>24)==(0);
 do {
  if ($73) {
   $74 = (__Znwj(16)|0);
   $75 = (($5) + 8|0);
   HEAP32[$75>>2] = $74;
   HEAP32[$5>>2] = 17;
   $76 = (($5) + 4|0);
   HEAP32[$76>>2] = 12;
   dest=$74+0|0; src=680112+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $77 = (($74) + 12|0);
   HEAP8[$77>>0] = 0;
   __THREW__ = 0;
   $78 = (invoke_ii(3224,($5|0))|0);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if (!($80)) {
    $81 = HEAP8[$5>>0]|0;
    $82 = $81 & 1;
    $83 = ($82<<24>>24)==(0);
    if (!($83)) {
     $84 = HEAP32[$75>>2]|0;
     __ZdlPv($84);
    }
    HEAP32[680096>>2] = $78;
    HEAP8[680104>>0] = 1;
    break;
   }
   $160 = ___cxa_find_matching_catch()|0;
   $161 = tempRet0;
   $162 = HEAP8[$5>>0]|0;
   $163 = $162 & 1;
   $164 = ($163<<24>>24)==(0);
   if ($164) {
    $$01 = $160;$$02 = $161;
    ___resumeException($$01|0);
    // unreachable;
   }
   $165 = HEAP32[$75>>2]|0;
   __ZdlPv($165);
   $$01 = $160;$$02 = $161;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $85 = (($this) + 8|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(0);
 if (!($87)) {
  $88 = HEAP32[$this>>2]|0;
  $89 = (($this) + 16|0);
  $hadUnsupportedFixedFunction$0$off0$ph221 = 0;$i$0$ph219 = $88;$renderPathsThatNeedRemoval$0$ph220 = 0;
  L81: while(1) {
   $90 = (($i$0$ph219) + 4|0);
   $91 = $90;
   $hadUnsupportedFixedFunction$0$off0$ph102191 = $hadUnsupportedFixedFunction$0$off0$ph221;$renderPathsThatNeedRemoval$0$ph101190 = $renderPathsThatNeedRemoval$0$ph220;
   L83: while(1) {
    $hadUnsupportedFixedFunction$0$off0$ph104162 = $hadUnsupportedFixedFunction$0$off0$ph102191;
    while(1) {
     while(1) {
      $92 = HEAP32[$i$0$ph219>>2]|0;
      __ZN9ShaderLab4Pass16SetupPassOptionsEv($92);
      $93 = HEAP32[679960>>2]|0;
      $94 = HEAP32[679992>>2]|0;
      $95 = HEAP32[680024>>2]|0;
      $96 = (($92) + 668|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = (($92) + 668|0);
      $99 = ($97|0)==(0|0);
      if ($99) {
       $118 = 0;
      } else {
       $$0$ph7$i$i$i$i = $98;$$01$ph6$i$in$i$i$i = $97;
       L90: while(1) {
        $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
        while(1) {
         $100 = (($$013$i$in$i$i$i) + 16|0);
         $101 = HEAP32[$100>>2]|0;
         $102 = ($101|0)<($93|0);
         if (!($102)) {
          break;
         }
         $105 = (($$013$i$in$i$i$i) + 4|0);
         $106 = HEAP32[$105>>2]|0;
         $107 = ($106|0)==(0|0);
         if ($107) {
          $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
          break L90;
         } else {
          $$013$i$in$i$i$i = $106;
         }
        }
        $103 = HEAP32[$$013$i$in$i$i$i>>2]|0;
        $104 = ($103|0)==(0|0);
        if ($104) {
         $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
         break;
        } else {
         $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $103;
        }
       }
       $108 = ($$0$ph5$i$i$i$i|0)==($98|0);
       if ($108) {
        $118 = 0;
       } else {
        $109 = (($$0$ph5$i$i$i$i) + 16|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = ($110|0)>($93|0);
        if ($111) {
         $118 = 0;
        } else {
         $112 = (($$0$ph5$i$i$i$i) + 20|0);
         $113 = HEAP32[$112>>2]|0;
         $114 = ($113|0)==($94|0);
         $115 = ($113|0)==($95|0);
         $$$i = $114 | $115;
         $118 = $$$i;
        }
       }
      }
      $116 = (__ZN9ShaderLab4Pass15IsPassSupportedEPKNS_13PropertySheetE($92,$props)|0);
      if ($116) {
       label = 45;
       break L83;
      }
      $166 = HEAP32[679960>>2]|0;
      $167 = HEAP32[679992>>2]|0;
      $168 = HEAP32[680024>>2]|0;
      $169 = HEAP32[$96>>2]|0;
      $170 = ($169|0)==(0|0);
      if ($170) {
       break;
      } else {
       $$0$ph7$i$i$i$i29 = $98;$$01$ph6$i$in$i$i$i30 = $169;
      }
      L101: while(1) {
       $$013$i$in$i$i$i32 = $$01$ph6$i$in$i$i$i30;
       while(1) {
        $171 = (($$013$i$in$i$i$i32) + 16|0);
        $172 = HEAP32[$171>>2]|0;
        $173 = ($172|0)<($166|0);
        if (!($173)) {
         break;
        }
        $176 = (($$013$i$in$i$i$i32) + 4|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = ($177|0)==(0|0);
        if ($178) {
         $$0$ph5$i$i$i$i35 = $$0$ph7$i$i$i$i29;
         break L101;
        } else {
         $$013$i$in$i$i$i32 = $177;
        }
       }
       $174 = HEAP32[$$013$i$in$i$i$i32>>2]|0;
       $175 = ($174|0)==(0|0);
       if ($175) {
        $$0$ph5$i$i$i$i35 = $$013$i$in$i$i$i32;
        break;
       } else {
        $$0$ph7$i$i$i$i29 = $$013$i$in$i$i$i32;$$01$ph6$i$in$i$i$i30 = $174;
       }
      }
      $179 = ($$0$ph5$i$i$i$i35|0)==($98|0);
      if (!($179)) {
       $180 = (($$0$ph5$i$i$i$i35) + 16|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = ($181|0)>($166|0);
       if (!($182)) {
        $183 = (($$0$ph5$i$i$i$i35) + 20|0);
        $184 = HEAP32[$183>>2]|0;
        $185 = ($184|0)==($167|0);
        $186 = ($184|0)==($168|0);
        $$$i37 = $185 | $186;
        if ($$$i37) {
         label = 67;
         break L83;
        }
       }
      }
      $191 = HEAP32[680096>>2]|0;
      $$0$ph7$i$i$i$i40 = $98;$$01$ph6$i$in$i$i$i41 = $169;
      L112: while(1) {
       $$013$i$in$i$i$i43 = $$01$ph6$i$in$i$i$i41;
       while(1) {
        $192 = (($$013$i$in$i$i$i43) + 16|0);
        $193 = HEAP32[$192>>2]|0;
        $194 = ($193|0)<($166|0);
        if (!($194)) {
         break;
        }
        $197 = (($$013$i$in$i$i$i43) + 4|0);
        $198 = HEAP32[$197>>2]|0;
        $199 = ($198|0)==(0|0);
        if ($199) {
         $$0$ph5$i$i$i$i46 = $$0$ph7$i$i$i$i40;
         break L112;
        } else {
         $$013$i$in$i$i$i43 = $198;
        }
       }
       $195 = HEAP32[$$013$i$in$i$i$i43>>2]|0;
       $196 = ($195|0)==(0|0);
       if ($196) {
        $$0$ph5$i$i$i$i46 = $$013$i$in$i$i$i43;
        break;
       } else {
        $$0$ph7$i$i$i$i40 = $$013$i$in$i$i$i43;$$01$ph6$i$in$i$i$i41 = $195;
       }
      }
      $200 = ($$0$ph5$i$i$i$i46|0)==($98|0);
      if ($200) {
       label = 78;
       break;
      }
      $201 = (($$0$ph5$i$i$i$i46) + 16|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = ($202|0)>($166|0);
      if ($203) {
       label = 78;
       break;
      }
      $204 = (($$0$ph5$i$i$i$i46) + 20|0);
      $205 = HEAP32[$204>>2]|0;
      $206 = ($205|0)==($191|0);
      if (!($206)) {
       label = 78;
       break;
      }
      __ZN9ShaderLab4Pass7ReleaseEv($92);
      $207 = HEAP32[$this>>2]|0;
      $208 = HEAP32[$85>>2]|0;
      $209 = (($207) + ($208<<2)|0);
      $210 = $209;
      $211 = (($210) - ($91))|0;
      _memmove(($i$0$ph219|0),($90|0),($211|0))|0;
      $212 = HEAP32[$85>>2]|0;
      $213 = (($212) + -1)|0;
      HEAP32[$85>>2] = $213;
      $214 = HEAP32[$89>>2]|0;
      $215 = (($214) + -1)|0;
      HEAP32[$89>>2] = $215;
      $216 = HEAP32[$this>>2]|0;
      $217 = (($216) + ($213<<2)|0);
      $218 = ($i$0$ph219|0)==($217|0);
      if ($218) {
       $352 = $216;$353 = $213;$hadUnsupportedFixedFunction$0$off0$ph104149 = $hadUnsupportedFixedFunction$0$off0$ph104162;
       label = 92;
       break L81;
      }
     }
     if ((label|0) == 78) {
      label = 0;
      $219 = HEAP32[680056>>2]|0;
      $220 = HEAP32[680080>>2]|0;
      $$0$ph7$i$i$i$i49 = $98;$$01$ph6$i$in$i$i$i50 = $169;
      L124: while(1) {
       $$013$i$in$i$i$i52 = $$01$ph6$i$in$i$i$i50;
       while(1) {
        $221 = (($$013$i$in$i$i$i52) + 16|0);
        $222 = HEAP32[$221>>2]|0;
        $223 = ($222|0)<($166|0);
        if (!($223)) {
         break;
        }
        $226 = (($$013$i$in$i$i$i52) + 4|0);
        $227 = HEAP32[$226>>2]|0;
        $228 = ($227|0)==(0|0);
        if ($228) {
         $$0$ph5$i$i$i$i55 = $$0$ph7$i$i$i$i49;
         break L124;
        } else {
         $$013$i$in$i$i$i52 = $227;
        }
       }
       $224 = HEAP32[$$013$i$in$i$i$i52>>2]|0;
       $225 = ($224|0)==(0|0);
       if ($225) {
        $$0$ph5$i$i$i$i55 = $$013$i$in$i$i$i52;
        break;
       } else {
        $$0$ph7$i$i$i$i49 = $$013$i$in$i$i$i52;$$01$ph6$i$in$i$i$i50 = $224;
       }
      }
      $229 = ($$0$ph5$i$i$i$i55|0)==($98|0);
      if (!($229)) {
       $230 = (($$0$ph5$i$i$i$i55) + 16|0);
       $231 = HEAP32[$230>>2]|0;
       $232 = ($231|0)>($166|0);
       if (!($232)) {
        $233 = (($$0$ph5$i$i$i$i55) + 20|0);
        $234 = HEAP32[$233>>2]|0;
        $235 = ($234|0)==($219|0);
        $236 = ($234|0)==($220|0);
        $or$cond1$i = $235 | $236;
        $237 = ($234|0)==($191|0);
        $or$cond2$i = $or$cond1$i | $237;
        if (!($or$cond2$i)) {
         break;
        }
       }
      }
     }
     $256 = HEAP8[((640792 + 128|0))>>0]|0;
     $257 = ($256<<24>>24)==(0);
     if (!($257)) {
      $$0 = 0;
      label = 115;
      break L81;
     }
     _printf_console(680176,$vararg_buffer11);
     $258 = HEAP8[674240>>0]|0;
     $259 = $258 & 1;
     $260 = ($259<<24>>24)==(0);
     $261 = HEAP32[((674240 + 8|0))>>2]|0;
     $$ = $260 ? ((674240 + 1|0)) : $261;
     $262 = (($92) + 628|0);
     $263 = HEAP8[$262>>0]|0;
     $264 = $263 & 1;
     $265 = ($264<<24>>24)==(0);
     if ($265) {
      $268 = (($262) + 1|0);
      $269 = $268;
     } else {
      $266 = (($92) + 636|0);
      $267 = HEAP32[$266>>2]|0;
      $269 = $267;
     }
     HEAP32[$vararg_buffer11>>2] = $$;
     $vararg_ptr3 = (($vararg_buffer11) + 4|0);
     HEAP32[$vararg_ptr3>>2] = $269;
     _printf_console(680200,$vararg_buffer11);
     __ZN9ShaderLab4Pass7ReleaseEv($92);
     $270 = HEAP32[$this>>2]|0;
     $271 = HEAP32[$85>>2]|0;
     $272 = (($270) + ($271<<2)|0);
     $273 = $272;
     $274 = (($273) - ($91))|0;
     _memmove(($i$0$ph219|0),($90|0),($274|0))|0;
     $275 = HEAP32[$85>>2]|0;
     $276 = (($275) + -1)|0;
     HEAP32[$85>>2] = $276;
     $277 = HEAP32[$89>>2]|0;
     $278 = (($277) + -1)|0;
     HEAP32[$89>>2] = $278;
     $279 = HEAP32[$this>>2]|0;
     $280 = (($279) + ($276<<2)|0);
     $281 = ($i$0$ph219|0)==($280|0);
     if ($281) {
      $352 = $279;$353 = $276;$hadUnsupportedFixedFunction$0$off0$ph104149 = 1;
      label = 92;
      break L81;
     } else {
      $hadUnsupportedFixedFunction$0$off0$ph104162 = 1;
     }
    }
    $238 = (($92) + 584|0);
    $239 = HEAP32[$238>>2]|0;
    $240 = (680128 + ($239<<2)|0);
    $241 = HEAP32[$240>>2]|0;
    $242 = 1 << $241;
    $243 = $242 | $renderPathsThatNeedRemoval$0$ph101190;
    __ZN9ShaderLab4Pass7ReleaseEv($92);
    $244 = HEAP32[$this>>2]|0;
    $245 = HEAP32[$85>>2]|0;
    $246 = (($244) + ($245<<2)|0);
    $247 = $246;
    $248 = (($247) - ($91))|0;
    _memmove(($i$0$ph219|0),($90|0),($248|0))|0;
    $249 = HEAP32[$85>>2]|0;
    $250 = (($249) + -1)|0;
    HEAP32[$85>>2] = $250;
    $251 = HEAP32[$89>>2]|0;
    $252 = (($251) + -1)|0;
    HEAP32[$89>>2] = $252;
    $253 = HEAP32[$this>>2]|0;
    $254 = (($253) + ($250<<2)|0);
    $255 = ($i$0$ph219|0)==($254|0);
    if ($255) {
     $$lcssa105289 = $253;$284 = $250;$hadUnsupportedFixedFunction$0$off0$ph104149288 = $hadUnsupportedFixedFunction$0$off0$ph104162;$renderPathsThatNeedRemoval$0$ph101171287 = $243;
     label = 93;
     break L81;
    } else {
     $hadUnsupportedFixedFunction$0$off0$ph102191 = $hadUnsupportedFixedFunction$0$off0$ph104162;$renderPathsThatNeedRemoval$0$ph101190 = $243;
    }
   }
   if ((label|0) == 45) {
    label = 0;
    $117 = $118&1;
    $119 = HEAP8[$inoutHadShadowPasses>>0]|0;
    $120 = $119&255;
    $121 = $120 | $117;
    $122 = $121&255;
    $storemerge = $122;
   }
   else if ((label|0) == 67) {
    label = 0;
    $187 = HEAP8[$inoutHadShadowPasses>>0]|0;
    $188 = ($187<<24>>24)==(0);
    if (!($188)) {
     $$0 = 0;
     label = 115;
     break;
    }
    $189 = HEAP32[$89>>2]|0;
    $190 = (($189) + -1)|0;
    HEAP32[$89>>2] = $190;
    $storemerge = 1;
   }
   HEAP8[$inoutHadShadowPasses>>0] = $storemerge;
   $123 = HEAP32[$this>>2]|0;
   $124 = HEAP32[$85>>2]|0;
   $125 = (($123) + ($124<<2)|0);
   $126 = ($90|0)==($125|0);
   if ($126) {
    $352 = $123;$353 = $124;$hadUnsupportedFixedFunction$0$off0$ph104149 = $hadUnsupportedFixedFunction$0$off0$ph104162;
    label = 92;
    break;
   } else {
    $hadUnsupportedFixedFunction$0$off0$ph221 = $hadUnsupportedFixedFunction$0$off0$ph104162;$i$0$ph219 = $90;$renderPathsThatNeedRemoval$0$ph220 = $renderPathsThatNeedRemoval$0$ph101190;
   }
  }
  if ((label|0) == 92) {
   $282 = ($renderPathsThatNeedRemoval$0$ph101190|0)==(0);
   if ($282) {
    $313 = $353;$323 = $352;$hadUnsupportedFixedFunction$0$off0$ph104149284 = $hadUnsupportedFixedFunction$0$off0$ph104149;
   } else {
    $$lcssa105289 = $352;$284 = $353;$hadUnsupportedFixedFunction$0$off0$ph104149288 = $hadUnsupportedFixedFunction$0$off0$ph104149;$renderPathsThatNeedRemoval$0$ph101171287 = $renderPathsThatNeedRemoval$0$ph101190;
    label = 93;
   }
  }
  else if ((label|0) == 115) {
   STACKTOP = sp;return ($$0|0);
  }
  L149: do {
   if ((label|0) == 93) {
    $283 = ($284|0)==(0);
    if ($283) {
     $313 = $284;$323 = $$lcssa105289;$hadUnsupportedFixedFunction$0$off0$ph104149284 = $hadUnsupportedFixedFunction$0$off0$ph104149288;
    } else {
     $285 = (($this) + 16|0);
     $354 = $284;$355 = $$lcssa105289;$i1$0$ph141 = $$lcssa105289;
     while(1) {
      $286 = (($i1$0$ph141) + 4|0);
      $287 = $286;
      $309 = $355;$310 = $354;
      while(1) {
       $288 = HEAP32[$i1$0$ph141>>2]|0;
       $289 = (($288) + 584|0);
       $290 = HEAP32[$289>>2]|0;
       $291 = (680128 + ($290<<2)|0);
       $292 = HEAP32[$291>>2]|0;
       $293 = 1 << $292;
       $294 = $293 & $renderPathsThatNeedRemoval$0$ph101171287;
       $295 = ($294|0)==(0);
       if ($295) {
        break;
       }
       __ZN9ShaderLab4Pass7ReleaseEv($288);
       $296 = HEAP32[$this>>2]|0;
       $297 = HEAP32[$85>>2]|0;
       $298 = (($296) + ($297<<2)|0);
       $299 = $298;
       $300 = (($299) - ($287))|0;
       _memmove(($i1$0$ph141|0),($286|0),($300|0))|0;
       $301 = HEAP32[$85>>2]|0;
       $302 = (($301) + -1)|0;
       HEAP32[$85>>2] = $302;
       $303 = HEAP32[$285>>2]|0;
       $304 = (($303) + -1)|0;
       HEAP32[$285>>2] = $304;
       $305 = HEAP32[$this>>2]|0;
       $306 = (($305) + ($302<<2)|0);
       $307 = ($i1$0$ph141|0)==($306|0);
       if ($307) {
        $313 = $302;$323 = $305;$hadUnsupportedFixedFunction$0$off0$ph104149284 = $hadUnsupportedFixedFunction$0$off0$ph104149288;
        break L149;
       } else {
        $309 = $305;$310 = $302;
       }
      }
      $308 = (($309) + ($310<<2)|0);
      $311 = ($286|0)==($308|0);
      if ($311) {
       $313 = $310;$323 = $309;$hadUnsupportedFixedFunction$0$off0$ph104149284 = $hadUnsupportedFixedFunction$0$off0$ph104149288;
       break;
      } else {
       $354 = $310;$355 = $309;$i1$0$ph141 = $286;
      }
     }
    }
   }
  } while(0);
  $312 = ($313|0)==(0);
  if (!($312)) {
   if (!($hadUnsupportedFixedFunction$0$off0$ph104149284)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $318 = ($313|0)==(0);
   L163: do {
    if (!($318)) {
     $319 = HEAP32[679960>>2]|0;
     $320 = HEAP32[679992>>2]|0;
     $321 = HEAP32[680024>>2]|0;
     $i6$079 = $323;
     while(1) {
      $326 = HEAP32[$i6$079>>2]|0;
      $327 = (($326) + 668|0);
      $328 = HEAP32[$327>>2]|0;
      $329 = (($326) + 668|0);
      $330 = ($328|0)==(0|0);
      if ($330) {
       break;
      } else {
       $$0$ph7$i$i$i$i59 = $329;$$01$ph6$i$in$i$i$i60 = $328;
      }
      L167: while(1) {
       $$013$i$in$i$i$i62 = $$01$ph6$i$in$i$i$i60;
       while(1) {
        $331 = (($$013$i$in$i$i$i62) + 16|0);
        $332 = HEAP32[$331>>2]|0;
        $333 = ($332|0)<($319|0);
        if (!($333)) {
         break;
        }
        $336 = (($$013$i$in$i$i$i62) + 4|0);
        $337 = HEAP32[$336>>2]|0;
        $338 = ($337|0)==(0|0);
        if ($338) {
         $$0$ph5$i$i$i$i65 = $$0$ph7$i$i$i$i59;
         break L167;
        } else {
         $$013$i$in$i$i$i62 = $337;
        }
       }
       $334 = HEAP32[$$013$i$in$i$i$i62>>2]|0;
       $335 = ($334|0)==(0|0);
       if ($335) {
        $$0$ph5$i$i$i$i65 = $$013$i$in$i$i$i62;
        break;
       } else {
        $$0$ph7$i$i$i$i59 = $$013$i$in$i$i$i62;$$01$ph6$i$in$i$i$i60 = $334;
       }
      }
      $339 = ($$0$ph5$i$i$i$i65|0)==($329|0);
      if ($339) {
       break;
      }
      $340 = (($$0$ph5$i$i$i$i65) + 16|0);
      $341 = HEAP32[$340>>2]|0;
      $342 = ($341|0)>($319|0);
      if ($342) {
       break;
      }
      $343 = (($$0$ph5$i$i$i$i65) + 20|0);
      $344 = HEAP32[$343>>2]|0;
      $345 = ($344|0)==($320|0);
      $346 = ($344|0)==($321|0);
      $$$i67 = $345 | $346;
      $325 = (($i6$079) + 4|0);
      if (!($$$i67)) {
       break;
      }
      $322 = (($323) + ($313<<2)|0);
      $324 = ($325|0)==($322|0);
      if ($324) {
       break L163;
      } else {
       $i6$079 = $325;
      }
     }
     _printf_console(680176,$vararg_buffer11);
     $347 = HEAP8[674240>>0]|0;
     $348 = $347 & 1;
     $349 = ($348<<24>>24)==(0);
     $350 = HEAP32[((674240 + 8|0))>>2]|0;
     $$74 = $349 ? ((674240 + 1|0)) : $350;
     HEAP32[$vararg_buffer11>>2] = $$74;
     _printf_console(680280,$vararg_buffer11);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $351 = (($this) + 42|0);
   HEAP8[$351>>0] = 1;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 _printf_console(680176,$vararg_buffer11);
 $314 = HEAP8[674240>>0]|0;
 $315 = $314 & 1;
 $316 = ($315<<24>>24)==(0);
 $317 = HEAP32[((674240 + 8|0))>>2]|0;
 $$73 = $316 ? ((674240 + 1|0)) : $317;
 HEAP32[$vararg_buffer11>>2] = $$73;
 _printf_console(680240,$vararg_buffer11);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9ShaderLab9SubShader17InsertDefaultPassEPNS_4PassE($this,$pass) {
 $this = $this|0;
 $pass = $pass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $pass;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($0) + 4|0);
 (__ZN13dynamic_arrayIPN9ShaderLab4PassELj4EE6insertEPS2_PKS2_S6_($this,$1,$0,$2)|0);
 $3 = HEAP32[$0>>2]|0;
 __ZN9ShaderLab4Pass6RetainEv($3);
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$4>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab9SubShader8PostLoadEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i28 = 0, $$0$ph5$i$i$i45 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i22 = 0, $$0$ph7$i$i$i39 = 0, $$01 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i23 = 0, $$01$ph6$i$in$i$i40 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i25 = 0, $$013$i$in$i$i42 = 0, $$02$i = 0;
 var $$03$i = 0, $$05$i = 0, $$1 = 0, $$12 = 0, $$14$i = 0, $$16$i = 0, $$2 = 0, $$23 = 0, $$not = 0, $$pre = 0, $$pre$phi102Z2D = 0, $$pre$phiZ2D = 0, $$pre100$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i = 0, $__p$0$i$i$i7$i = 0, $brmerge = 0;
 var $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond = 0, $hasAlwaysPass$0$off0$not = 0, $hasAlwaysPass$0$off086 = 0, $hasAlwaysPass$1$off0 = 0, $i$015$i = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index2 = 0, $p$085 = 0, $queueName = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 108|0;
 $1 = sp + 96|0;
 $2 = sp + 84|0;
 $3 = sp + 72|0;
 $4 = sp + 60|0;
 $5 = sp + 48|0;
 $6 = sp + 24|0;
 $queueName = sp + 12|0;
 $7 = sp;
 $8 = sp + 36|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 36|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 41|0);
 HEAP8[$12>>0] = 0;
 $13 = HEAP8[680336>>0]|0;
 $14 = ($13<<24>>24)==(0);
 do {
  if ($14) {
   $15 = (__Znwj(16)|0);
   $16 = (($3) + 8|0);
   HEAP32[$16>>2] = $15;
   HEAP32[$3>>2] = 17;
   $17 = (($3) + 4|0);
   HEAP32[$17>>2] = 13;
   dest=$15+0|0; src=680344+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $18 = (($15) + 13|0);
   HEAP8[$18>>0] = 0;
   __THREW__ = 0;
   $19 = (invoke_ii(3224,($3|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP8[$3>>0]|0;
    $23 = $22 & 1;
    $24 = ($23<<24>>24)==(0);
    if (!($24)) {
     $25 = HEAP32[$16>>2]|0;
     __ZdlPv($25);
    }
    HEAP32[680328>>2] = $19;
    HEAP8[680336>>0] = 1;
    break;
   }
   $41 = ___cxa_find_matching_catch()|0;
   $42 = tempRet0;
   $43 = HEAP8[$3>>0]|0;
   $44 = $43 & 1;
   $45 = ($44<<24>>24)==(0);
   if ($45) {
    $$2 = $41;$$23 = $42;
    ___resumeException($$2|0);
    // unreachable;
   }
   $46 = HEAP32[$16>>2]|0;
   __ZdlPv($46);
   $$2 = $41;$$23 = $42;
   ___resumeException($$2|0);
   // unreachable;
  }
 } while(0);
 $26 = ($10|0)==(0);
 if (!($26)) {
  $27 = (($this) + 40|0);
  $hasAlwaysPass$0$off086 = 0;$p$085 = 0;
  while(1) {
   $28 = HEAP32[$this>>2]|0;
   $29 = (($28) + ($p$085<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 584|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = 1278 >>> $32;
   $34 = $33 & 1;
   $35 = ($34|0)==(0);
   if (!($35)) {
    $36 = (680128 + ($32<<2)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = 1 << $37;
    $39 = HEAP32[$11>>2]|0;
    $40 = $39 | $38;
    HEAP32[$11>>2] = $40;
   }
   if ((($32|0) == 0)) {
    $hasAlwaysPass$1$off0 = 1;
   } else if ((($32|0) == 5)) {
    HEAP8[$27>>0] = 1;
    $47 = (($30) + 4|0);
    $48 = (__ZNK9ShaderLab11ShaderState29GetSupportsFullForwardShadowsEv($47)|0);
    $49 = $48&1;
    $50 = HEAP8[$12>>0]|0;
    $51 = $50&255;
    $52 = $51 | $49;
    $53 = $52&255;
    HEAP8[$12>>0] = $53;
    $54 = (($30) + 668|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($30) + 668|0);
    $57 = ($55|0)==(0|0);
    if ($57) {
     label = 21;
    } else {
     $58 = HEAP32[680328>>2]|0;
     $$0$ph7$i$i$i = $56;$$01$ph6$i$in$i$i = $55;
     L26: while(1) {
      $$013$i$in$i$i = $$01$ph6$i$in$i$i;
      while(1) {
       $59 = (($$013$i$in$i$i) + 16|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ($60|0)<($58|0);
       if (!($61)) {
        break;
       }
       $64 = (($$013$i$in$i$i) + 4|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = ($65|0)==(0|0);
       if ($66) {
        $$0$ph5$i$i$i = $$0$ph7$i$i$i;
        break L26;
       } else {
        $$013$i$in$i$i = $65;
       }
      }
      $62 = HEAP32[$$013$i$in$i$i>>2]|0;
      $63 = ($62|0)==(0|0);
      if ($63) {
       $$0$ph5$i$i$i = $$013$i$in$i$i;
       break;
      } else {
       $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $62;
      }
     }
     $67 = ($$0$ph5$i$i$i|0)==($56|0);
     if ($67) {
      label = 21;
     } else {
      $68 = (($$0$ph5$i$i$i) + 16|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($58|0)<($69|0);
      if ($70) {
       label = 21;
      } else {
       $72 = $$0$ph5$i$i$i;
      }
     }
    }
    if ((label|0) == 21) {
     label = 0;
     $72 = $56;
    }
    $71 = ($72|0)!=($56|0);
    $73 = $71&1;
    $74 = $52 | $73;
    $75 = $74&255;
    HEAP8[$12>>0] = $75;
    $hasAlwaysPass$1$off0 = $hasAlwaysPass$0$off086;
   } else {
    $hasAlwaysPass$1$off0 = $hasAlwaysPass$0$off086;
   }
   $76 = (($p$085) + 1)|0;
   $exitcond = ($76|0)==($10|0);
   if ($exitcond) {
    break;
   } else {
    $hasAlwaysPass$0$off086 = $hasAlwaysPass$1$off0;$p$085 = $76;
   }
  }
  $77 = HEAP32[$11>>2]|0;
  $$not = ($77|0)!=(0);
  $hasAlwaysPass$0$off0$not = $hasAlwaysPass$1$off0 ^ 1;
  $brmerge = $$not | $hasAlwaysPass$0$off0$not;
  if (!($brmerge)) {
   HEAP32[$11>>2] = 5;
  }
 }
 $78 = HEAP8[680480>>0]|0;
 $79 = ($78<<24>>24)==(0);
 do {
  if ($79) {
   HEAP8[$0>>0] = 18;
   $80 = (($0) + 1|0);
   dest=$80+0|0; src=679976+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $81 = (($0) + 10|0);
   HEAP8[$81>>0] = 0;
   __THREW__ = 0;
   $82 = (invoke_ii(3224,($0|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if (!($84)) {
    $85 = HEAP8[$0>>0]|0;
    $86 = $85 & 1;
    $87 = ($86<<24>>24)==(0);
    if (!($87)) {
     $88 = (($0) + 8|0);
     $89 = HEAP32[$88>>2]|0;
     __ZdlPv($89);
    }
    HEAP32[680472>>2] = $82;
    HEAP8[680480>>0] = 1;
    break;
   }
   $156 = ___cxa_find_matching_catch()|0;
   $157 = tempRet0;
   $158 = HEAP8[$0>>0]|0;
   $159 = $158 & 1;
   $160 = ($159<<24>>24)==(0);
   if ($160) {
    $$14$i = $157;$$16$i = $156;
    ___resumeException($$16$i|0);
    // unreachable;
   }
   $161 = (($0) + 8|0);
   $162 = HEAP32[$161>>2]|0;
   __ZdlPv($162);
   $$14$i = $157;$$16$i = $156;
   ___resumeException($$16$i|0);
   // unreachable;
  }
 } while(0);
 $90 = (($this) + 16|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)>(0);
 L54: do {
  if ($92) {
   $93 = (($2) + 1|0);
   $94 = (($1) + 1|0);
   $95 = (($1) + 8|0);
   $96 = (($2) + 8|0);
   $97 = (($2) + 4|0);
   $i$015$i = 0;
   L56: while(1) {
    $98 = HEAP32[$this>>2]|0;
    $99 = (($98) + ($i$015$i<<2)|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($100) + 668|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = (($100) + 668|0);
    $104 = ($102|0)==(0|0);
    do {
     if (!($104)) {
      $105 = HEAP32[680472>>2]|0;
      $$0$ph7$i$i$i$i = $103;$$01$ph6$i$in$i$i$i = $102;
      L60: while(1) {
       $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
       while(1) {
        $106 = (($$013$i$in$i$i$i) + 16|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = ($107|0)<($105|0);
        if (!($108)) {
         break;
        }
        $111 = (($$013$i$in$i$i$i) + 4|0);
        $112 = HEAP32[$111>>2]|0;
        $113 = ($112|0)==(0|0);
        if ($113) {
         $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
         break L60;
        } else {
         $$013$i$in$i$i$i = $112;
        }
       }
       $109 = HEAP32[$$013$i$in$i$i$i>>2]|0;
       $110 = ($109|0)==(0|0);
       if ($110) {
        $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
        break;
       } else {
        $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $109;
       }
      }
      $114 = ($$0$ph5$i$i$i$i|0)==($103|0);
      if (!($114)) {
       $115 = (($$0$ph5$i$i$i$i) + 16|0);
       $116 = HEAP32[$115>>2]|0;
       $117 = ($105|0)<($116|0);
       if (!($117)) {
        $118 = (($$0$ph5$i$i$i$i) + 20|0);
        $119 = HEAP32[$118>>2]|0;
        __ZN9ShaderLab16GetShaderTagNameEi($1,$119);
        $120 = (_strlen((653424|0))|0);
        $121 = ($120>>>0)>(4294967279);
        if ($121) {
         label = 43;
         break L56;
        }
        $124 = ($120>>>0)<(11);
        if ($124) {
         $125 = $120 << 1;
         $126 = $125&255;
         HEAP8[$2>>0] = $126;
         $140 = $126;$__p$0$i$i$i7$i = $93;
        } else {
         $127 = (($120) + 16)|0;
         $128 = $127 & -16;
         __THREW__ = 0;
         $129 = (invoke_ii(2988,($128|0))|0);
         $130 = __THREW__; __THREW__ = 0;
         $131 = $130&1;
         if ($131) {
          label = 57;
          break L56;
         }
         HEAP32[$96>>2] = $129;
         $132 = $128 | 1;
         HEAP32[$2>>2] = $132;
         HEAP32[$97>>2] = $120;
         $133 = $132&255;
         $140 = $133;$__p$0$i$i$i7$i = $129;
        }
        _memcpy(($__p$0$i$i$i7$i|0),(653424|0),($120|0))|0;
        $134 = (($__p$0$i$i$i7$i) + ($120)|0);
        HEAP8[$134>>0] = 0;
        $135 = HEAP8[$1>>0]|0;
        $136 = $135 & 1;
        $137 = ($136<<24>>24)==(0);
        $138 = HEAP32[$95>>2]|0;
        $$$i = $137 ? $94 : $138;
        $139 = $140 & 1;
        $141 = ($139<<24>>24)==(0);
        $142 = HEAP32[$96>>2]|0;
        $143 = $141 ? $93 : $142;
        __THREW__ = 0;
        $144 = (invoke_iii(2448,($$$i|0),($143|0))|0);
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 60;
         break L56;
        }
        $147 = ($144|0)==(0);
        $148 = HEAP8[$2>>0]|0;
        $149 = $148 & 1;
        $150 = ($149<<24>>24)==(0);
        if (!($150)) {
         $151 = HEAP32[$96>>2]|0;
         __ZdlPv($151);
        }
        $152 = HEAP8[$1>>0]|0;
        $153 = $152 & 1;
        $154 = ($153<<24>>24)==(0);
        if ($154) {
         if ($147) {
          $$02$i = $i$015$i;
          break L54;
         } else {
          break;
         }
        } else {
         $155 = HEAP32[$95>>2]|0;
         __ZdlPv($155);
         if ($147) {
          $$02$i = $i$015$i;
          break L54;
         } else {
          break;
         }
        }
       }
      }
     }
    } while(0);
    $177 = (($i$015$i) + 1)|0;
    $178 = HEAP32[$90>>2]|0;
    $179 = ($177|0)<($178|0);
    if ($179) {
     $i$015$i = $177;
    } else {
     $$02$i = -1;
     break L54;
    }
   }
   do {
    if ((label|0) == 43) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $122 = __THREW__; __THREW__ = 0;
     $123 = $122&1;
     if ($123) {
      $165 = ___cxa_find_matching_catch()|0;
      $166 = tempRet0;
      $lpad$phi$i$index = $165;$lpad$phi$i$index2 = $166;
      label = 59;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 57) {
     $163 = ___cxa_find_matching_catch()|0;
     $164 = tempRet0;
     $lpad$phi$i$index = $163;$lpad$phi$i$index2 = $164;
     label = 59;
    }
    else if ((label|0) == 60) {
     $167 = ___cxa_find_matching_catch()|0;
     $168 = tempRet0;
     $169 = HEAP8[$2>>0]|0;
     $170 = $169 & 1;
     $171 = ($170<<24>>24)==(0);
     if ($171) {
      $$03$i = $168;$$05$i = $167;
     } else {
      $172 = HEAP32[$96>>2]|0;
      __ZdlPv($172);
      $$03$i = $168;$$05$i = $167;
     }
    }
   } while(0);
   if ((label|0) == 59) {
    $$03$i = $lpad$phi$i$index2;$$05$i = $lpad$phi$i$index;
   }
   $173 = HEAP8[$1>>0]|0;
   $174 = $173 & 1;
   $175 = ($174<<24>>24)==(0);
   if ($175) {
    $$14$i = $$03$i;$$16$i = $$05$i;
    ___resumeException($$16$i|0);
    // unreachable;
   }
   $176 = HEAP32[$95>>2]|0;
   __ZdlPv($176);
   $$14$i = $$03$i;$$16$i = $$05$i;
   ___resumeException($$16$i|0);
   // unreachable;
  } else {
   $$02$i = -1;
  }
 } while(0);
 $180 = (($this) + 44|0);
 HEAP32[$180>>2] = $$02$i;
 $181 = HEAP8[680368>>0]|0;
 $182 = ($181<<24>>24)==(0);
 do {
  if ($182) {
   $183 = (__Znwj(32)|0);
   $184 = (($4) + 8|0);
   HEAP32[$184>>2] = $183;
   HEAP32[$4>>2] = 33;
   $185 = (($4) + 4|0);
   HEAP32[$185>>2] = 20;
   dest=$183+0|0; src=680376+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $186 = (($183) + 20|0);
   HEAP8[$186>>0] = 0;
   __THREW__ = 0;
   $187 = (invoke_ii(3224,($4|0))|0);
   $188 = __THREW__; __THREW__ = 0;
   $189 = $188&1;
   if (!($189)) {
    $190 = HEAP8[$4>>0]|0;
    $191 = $190 & 1;
    $192 = ($191<<24>>24)==(0);
    if (!($192)) {
     $193 = HEAP32[$184>>2]|0;
     __ZdlPv($193);
    }
    HEAP32[680360>>2] = $187;
    HEAP8[680368>>0] = 1;
    break;
   }
   $228 = ___cxa_find_matching_catch()|0;
   $229 = tempRet0;
   $230 = HEAP8[$4>>0]|0;
   $231 = $230 & 1;
   $232 = ($231<<24>>24)==(0);
   if ($232) {
    $$2 = $228;$$23 = $229;
    ___resumeException($$2|0);
    // unreachable;
   }
   $233 = HEAP32[$184>>2]|0;
   __ZdlPv($233);
   $$2 = $228;$$23 = $229;
   ___resumeException($$2|0);
   // unreachable;
  }
 } while(0);
 $194 = HEAP8[680408>>0]|0;
 $195 = ($194<<24>>24)==(0);
 do {
  if ($195) {
   HEAP8[$5>>0] = 8;
   $196 = (($5) + 1|0);
   HEAP8[$196>>0]=1702195828&255;HEAP8[$196+1>>0]=(1702195828>>8)&255;HEAP8[$196+2>>0]=(1702195828>>16)&255;HEAP8[$196+3>>0]=1702195828>>24;
   $197 = (($5) + 5|0);
   HEAP8[$197>>0] = 0;
   __THREW__ = 0;
   $198 = (invoke_ii(3224,($5|0))|0);
   $199 = __THREW__; __THREW__ = 0;
   $200 = $199&1;
   if (!($200)) {
    $201 = HEAP8[$5>>0]|0;
    $202 = $201 & 1;
    $203 = ($202<<24>>24)==(0);
    if (!($203)) {
     $204 = (($5) + 8|0);
     $205 = HEAP32[$204>>2]|0;
     __ZdlPv($205);
    }
    HEAP32[680400>>2] = $198;
    HEAP8[680408>>0] = 1;
    break;
   }
   $234 = ___cxa_find_matching_catch()|0;
   $235 = tempRet0;
   $236 = HEAP8[$5>>0]|0;
   $237 = $236 & 1;
   $238 = ($237<<24>>24)==(0);
   if ($238) {
    $$2 = $234;$$23 = $235;
    ___resumeException($$2|0);
    // unreachable;
   }
   $239 = (($5) + 8|0);
   $240 = HEAP32[$239>>2]|0;
   __ZdlPv($240);
   $$2 = $234;$$23 = $235;
   ___resumeException($$2|0);
   // unreachable;
  }
 } while(0);
 $206 = (($this) + 24|0);
 $207 = HEAP32[$206>>2]|0;
 $208 = (($this) + 24|0);
 $209 = ($207|0)==(0|0);
 if (!($209)) {
  $210 = HEAP32[680360>>2]|0;
  $$0$ph7$i$i$i22 = $208;$$01$ph6$i$in$i$i23 = $207;
  L127: while(1) {
   $$013$i$in$i$i25 = $$01$ph6$i$in$i$i23;
   while(1) {
    $211 = (($$013$i$in$i$i25) + 16|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = ($212|0)<($210|0);
    if (!($213)) {
     break;
    }
    $216 = (($$013$i$in$i$i25) + 4|0);
    $217 = HEAP32[$216>>2]|0;
    $218 = ($217|0)==(0|0);
    if ($218) {
     $$0$ph5$i$i$i28 = $$0$ph7$i$i$i22;
     break L127;
    } else {
     $$013$i$in$i$i25 = $217;
    }
   }
   $214 = HEAP32[$$013$i$in$i$i25>>2]|0;
   $215 = ($214|0)==(0|0);
   if ($215) {
    $$0$ph5$i$i$i28 = $$013$i$in$i$i25;
    break;
   } else {
    $$0$ph7$i$i$i22 = $$013$i$in$i$i25;$$01$ph6$i$in$i$i23 = $214;
   }
  }
  $219 = ($$0$ph5$i$i$i28|0)==($208|0);
  if (!($219)) {
   $220 = (($$0$ph5$i$i$i28) + 16|0);
   $221 = HEAP32[$220>>2]|0;
   $222 = ($210|0)<($221|0);
   if (!($222)) {
    $223 = (($$0$ph5$i$i$i28) + 20|0);
    $224 = HEAP32[$223>>2]|0;
    $225 = HEAP32[680400>>2]|0;
    $226 = ($224|0)==($225|0);
    if ($226) {
     $227 = (($this) + 43|0);
     HEAP8[$227>>0] = 0;
    }
   }
  }
 }
 $241 = (($this) + 48|0);
 HEAP32[$241>>2] = -1;
 $242 = HEAP8[680424>>0]|0;
 $243 = ($242<<24>>24)==(0);
 do {
  if ($243) {
   HEAP8[$6>>0] = 10;
   $244 = (($6) + 1|0);
   ;HEAP8[$244+0>>0]=HEAP8[680432+0>>0]|0;HEAP8[$244+1>>0]=HEAP8[680432+1>>0]|0;HEAP8[$244+2>>0]=HEAP8[680432+2>>0]|0;HEAP8[$244+3>>0]=HEAP8[680432+3>>0]|0;HEAP8[$244+4>>0]=HEAP8[680432+4>>0]|0;
   $245 = (($6) + 6|0);
   HEAP8[$245>>0] = 0;
   __THREW__ = 0;
   $246 = (invoke_ii(3224,($6|0))|0);
   $247 = __THREW__; __THREW__ = 0;
   $248 = $247&1;
   if (!($248)) {
    $249 = HEAP8[$6>>0]|0;
    $250 = $249 & 1;
    $251 = ($250<<24>>24)==(0);
    if (!($251)) {
     $252 = (($6) + 8|0);
     $253 = HEAP32[$252>>2]|0;
     __ZdlPv($253);
    }
    HEAP32[680416>>2] = $246;
    HEAP8[680424>>0] = 1;
    $$pre = HEAP32[$206>>2]|0;
    $255 = $$pre;
    break;
   }
   $331 = ___cxa_find_matching_catch()|0;
   $332 = tempRet0;
   $333 = HEAP8[$6>>0]|0;
   $334 = $333 & 1;
   $335 = ($334<<24>>24)==(0);
   if ($335) {
    $$2 = $331;$$23 = $332;
    ___resumeException($$2|0);
    // unreachable;
   }
   $336 = (($6) + 8|0);
   $337 = HEAP32[$336>>2]|0;
   __ZdlPv($337);
   $$2 = $331;$$23 = $332;
   ___resumeException($$2|0);
   // unreachable;
  } else {
   $255 = $207;
  }
 } while(0);
 $254 = ($255|0)==(0|0);
 if ($254) {
  STACKTOP = sp;return;
 }
 $256 = HEAP32[680416>>2]|0;
 $$0$ph7$i$i$i39 = $208;$$01$ph6$i$in$i$i40 = $255;
 L154: while(1) {
  $$013$i$in$i$i42 = $$01$ph6$i$in$i$i40;
  while(1) {
   $257 = (($$013$i$in$i$i42) + 16|0);
   $258 = HEAP32[$257>>2]|0;
   $259 = ($258|0)<($256|0);
   if (!($259)) {
    break;
   }
   $262 = (($$013$i$in$i$i42) + 4|0);
   $263 = HEAP32[$262>>2]|0;
   $264 = ($263|0)==(0|0);
   if ($264) {
    $$0$ph5$i$i$i45 = $$0$ph7$i$i$i39;
    break L154;
   } else {
    $$013$i$in$i$i42 = $263;
   }
  }
  $260 = HEAP32[$$013$i$in$i$i42>>2]|0;
  $261 = ($260|0)==(0|0);
  if ($261) {
   $$0$ph5$i$i$i45 = $$013$i$in$i$i42;
   break;
  } else {
   $$0$ph7$i$i$i39 = $$013$i$in$i$i42;$$01$ph6$i$in$i$i40 = $260;
  }
 }
 $265 = ($$0$ph5$i$i$i45|0)==($208|0);
 if ($265) {
  STACKTOP = sp;return;
 }
 $266 = (($$0$ph5$i$i$i45) + 16|0);
 $267 = HEAP32[$266>>2]|0;
 $268 = ($256|0)<($267|0);
 if ($268) {
  STACKTOP = sp;return;
 }
 $269 = (($$0$ph5$i$i$i45) + 20|0);
 $270 = HEAP32[$269>>2]|0;
 __ZN9ShaderLab16GetShaderTagNameEi($queueName,$270);
 __THREW__ = 0;
 $271 = (invoke_iii(2533,($queueName|0),($241|0))|0);
 $272 = __THREW__; __THREW__ = 0;
 $273 = $272&1;
 L167: do {
  if ($273) {
   $338 = ___cxa_find_matching_catch()|0;
   $339 = tempRet0;
   $$pre100$pre$phiZZ2D = $queueName;$eh$lpad$body$index8Z2D = $339;$eh$lpad$body$indexZ2D = $338;
   label = 134;
  } else {
   L169: do {
    if ($271) {
     $$pre$phi102Z2D = $queueName;
    } else {
     ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
     $274 = HEAP8[$queueName>>0]|0;
     $275 = $274 & 1;
     $276 = ($275<<24>>24)==(0);
     if ($276) {
      $279 = $274&255;
      $280 = $279 >>> 1;
      $282 = $280;
     } else {
      $277 = (($queueName) + 4|0);
      $278 = HEAP32[$277>>2]|0;
      $282 = $278;
     }
     $281 = (($282) + 18)|0;
     $283 = ($281>>>0)>(4294967279);
     do {
      if ($283) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $284 = __THREW__; __THREW__ = 0;
       $285 = $284&1;
       if (!($285)) {
        // unreachable;
       }
      } else {
       $286 = ($281>>>0)<(11);
       if ($286) {
        HEAP8[$8>>0] = 36;
        $287 = (($8) + 1|0);
        $__p$0$i$i = $287;
       } else {
        $288 = (($282) + 34)|0;
        $289 = $288 & -16;
        __THREW__ = 0;
        $290 = (invoke_ii(2988,($289|0))|0);
        $291 = __THREW__; __THREW__ = 0;
        $292 = $291&1;
        if ($292) {
         break;
        }
        $293 = (($8) + 8|0);
        HEAP32[$293>>2] = $290;
        $294 = $289 | 1;
        HEAP32[$8>>2] = $294;
        $295 = (($8) + 4|0);
        HEAP32[$295>>2] = 18;
        $__p$0$i$i = $290;
       }
       dest=$__p$0$i$i+0|0; src=680440+0|0; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $296 = (($__p$0$i$i) + 18|0);
       HEAP8[$296>>0] = 0;
       if ($276) {
        $299 = (($queueName) + 1|0);
        $300 = $299;
       } else {
        $297 = (($queueName) + 8|0);
        $298 = HEAP32[$297>>2]|0;
        $300 = $298;
       }
       __THREW__ = 0;
       (invoke_iiii(1480,($8|0),($300|0),($282|0))|0);
       $301 = __THREW__; __THREW__ = 0;
       $302 = $301&1;
       if ($302) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(1627,($7|0),($8|0),(680464|0));
       $310 = __THREW__; __THREW__ = 0;
       $311 = $310&1;
       do {
        if ($311) {
         $340 = ___cxa_find_matching_catch()|0;
         $341 = tempRet0;
         $$0 = $340;$$01 = $341;
        } else {
         $312 = HEAP8[$7>>0]|0;
         $313 = $312 & 1;
         $314 = ($313<<24>>24)==(0);
         if ($314) {
          $317 = (($7) + 1|0);
          $318 = $317;
         } else {
          $315 = (($7) + 8|0);
          $316 = HEAP32[$315>>2]|0;
          $318 = $316;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,($318|0),0,(679952|0),349,1,0,0,(0|0));
         $319 = __THREW__; __THREW__ = 0;
         $320 = $319&1;
         if ($320) {
          $342 = ___cxa_find_matching_catch()|0;
          $343 = tempRet0;
          $344 = HEAP8[$7>>0]|0;
          $345 = $344 & 1;
          $346 = ($345<<24>>24)==(0);
          if ($346) {
           $$0 = $342;$$01 = $343;
           break;
          }
          $347 = (($7) + 8|0);
          $348 = HEAP32[$347>>2]|0;
          __ZdlPv($348);
          $$0 = $342;$$01 = $343;
          break;
         }
         $321 = HEAP8[$7>>0]|0;
         $322 = $321 & 1;
         $323 = ($322<<24>>24)==(0);
         if (!($323)) {
          $324 = (($7) + 8|0);
          $325 = HEAP32[$324>>2]|0;
          __ZdlPv($325);
         }
         $326 = HEAP8[$8>>0]|0;
         $327 = $326 & 1;
         $328 = ($327<<24>>24)==(0);
         if ($328) {
          $$pre$phi102Z2D = $queueName;
          break L169;
         }
         $329 = (($8) + 8|0);
         $330 = HEAP32[$329>>2]|0;
         __ZdlPv($330);
         $$pre$phi102Z2D = $queueName;
         break L169;
        }
       } while(0);
       $349 = HEAP8[$8>>0]|0;
       $350 = $349 & 1;
       $351 = ($350<<24>>24)==(0);
       if ($351) {
        $$1 = $$0;$$12 = $$01;$$pre$phiZ2D = $queueName;
        break L167;
       }
       $352 = (($8) + 8|0);
       $353 = HEAP32[$352>>2]|0;
       __ZdlPv($353);
       $$1 = $$0;$$12 = $$01;$$pre$phiZ2D = $queueName;
       break L167;
      }
     } while(0);
     $303 = ___cxa_find_matching_catch()|0;
     $304 = tempRet0;
     $305 = HEAP8[$8>>0]|0;
     $306 = $305 & 1;
     $307 = ($306<<24>>24)==(0);
     if ($307) {
      $$pre100$pre$phiZZ2D = $queueName;$eh$lpad$body$index8Z2D = $304;$eh$lpad$body$indexZ2D = $303;
      label = 134;
      break L167;
     }
     $308 = (($8) + 8|0);
     $309 = HEAP32[$308>>2]|0;
     __ZdlPv($309);
     $$pre100$pre$phiZZ2D = $queueName;$eh$lpad$body$index8Z2D = $304;$eh$lpad$body$indexZ2D = $303;
     label = 134;
     break L167;
    }
   } while(0);
   $354 = HEAP8[$$pre$phi102Z2D>>0]|0;
   $355 = $354 & 1;
   $356 = ($355<<24>>24)==(0);
   if ($356) {
    STACKTOP = sp;return;
   }
   $357 = (($queueName) + 8|0);
   $358 = HEAP32[$357>>2]|0;
   __ZdlPv($358);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 134) {
  $$1 = $eh$lpad$body$indexZ2D;$$12 = $eh$lpad$body$index8Z2D;$$pre$phiZ2D = $$pre100$pre$phiZZ2D;
 }
 $359 = HEAP8[$$pre$phiZ2D>>0]|0;
 $360 = $359 & 1;
 $361 = ($360<<24>>24)==(0);
 if ($361) {
  $$2 = $$1;$$23 = $$12;
  ___resumeException($$2|0);
  // unreachable;
 }
 $362 = (($queueName) + 8|0);
 $363 = HEAP32[$362>>2]|0;
 __ZdlPv($363);
 $$2 = $$1;$$23 = $$12;
 ___resumeException($$2|0);
 // unreachable;
}
function __ZN13dynamic_arrayIPN9ShaderLab4PassELj4EE6insertEPS2_PKS2_S6_($this,$insert_before,$input_begin,$input_end) {
 $this = $this|0;
 $insert_before = $insert_before|0;
 $input_begin = $input_begin|0;
 $input_end = $input_end|0;
 var $$byval_copy1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = $insert_before;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) - ($5))|0;
 $9 = $input_end;
 $10 = $input_begin;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = (($7) + ($12))|0;
 HEAP32[$6>>2] = $13;
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($13>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $13;
    $19 = $13 << 2;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$19,4,$$byval_copy1,0,679952,370)|0);
    HEAP32[$this>>2] = $22;
    $31 = $22;
    break;
   } else {
    $23 = $13 << 2;
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$0>>2] = $25;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,4,$$byval_copy1,0,679952,352)|0);
    $27 = HEAP32[$this>>2]|0;
    $28 = HEAP32[$6>>2]|0;
    $29 = $28 << 2;
    _memcpy(($26|0),($27|0),($29|0))|0;
    HEAP32[$14>>2] = $13;
    HEAP32[$this>>2] = $26;
    $31 = $26;
    break;
   }
  } else {
   $31 = $1;
  }
 } while(0);
 $30 = (($31) + ($5<<2)|0);
 $$sum = (($5) + ($12))|0;
 $32 = (($31) + ($$sum<<2)|0);
 $33 = $8 << 2;
 _memmove(($32|0),($30|0),($33|0))|0;
 _memcpy(($30|0),($input_begin|0),($11|0))|0;
 STACKTOP = sp;return ($30|0);
}
function __ZN9ShaderLab6TexEnvC2ERKS0_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 12|0);
 $2 = (($this) + 44|0);
 $3 = (($this) + 60|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 HEAP32[$3>>2] = -1;
 $4 = (($other) + 60|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$3>>2] = $5;
 $6 = (($other) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 $8 = (($other) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$1>>2] = $9;
 $10 = (($other) + 44|0);
 ;HEAP32[$2+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$10+12>>2]|0;
 $11 = (($other) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 32|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($other) + 36|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 36|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($other) + 40|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 40|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($other) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $23 = HEAP32[$other>>2]|0;
  HEAP32[$this>>2] = $23;
  $24 = (($other) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($this) + 4|0);
  HEAP32[$26>>2] = $25;
  STACKTOP = sp;return;
 }
 __ZN7Texture13AddTexEnvUserEPN9ShaderLab6TexEnvE($21,$this);
 $23 = HEAP32[$other>>2]|0;
 HEAP32[$this>>2] = $23;
 $24 = (($other) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 4|0);
 HEAP32[$26>>2] = $25;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnvC2ERKNS_21ParserTexturePropertyE($this,$prop) {
 $this = $this|0;
 $prop = $prop|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = (($this) + 12|0);
 $3 = (($this) + 28|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 60|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAP32[$4>>2] = -1;
 HEAP32[$0>>2] = -1;
 $5 = HEAP8[$prop>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (($prop) + 1|0);
  $11 = $10;
 } else {
  $8 = (($prop) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 }
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,$11);
 $12 = HEAP32[$0>>2]|0;
 HEAP32[$4>>2] = $12;
 HEAP32[$1>>2] = 0;
 HEAP32[$2>>2] = 0;
 $13 = (($this) + 44|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($this) + 48|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($this) + 52|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 56|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 32|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($this) + 36|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 40|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($prop) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$this>>2] = $21;
 $22 = HEAP32[$20>>2]|0;
 $23 = (($this) + 4|0);
 HEAP32[$23>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnvD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN7Texture16RemoveTexEnvUserEPN9ShaderLab6TexEnvEj($1,$this,$4);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnv17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN7Texture16RemoveTexEnvUserEPN9ShaderLab6TexEnvEj($1,$this,$4);
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnv15SetTextureScaleEff($this,$x,$y) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround($x + Math_fround(-1.0));
 $1 = $0 < Math_fround(0.0);
 if ($1) {
  $2 = Math_fround(-$0);
  $4 = $2;
 } else {
  $4 = $0;
 }
 $3 = !($4 <= Math_fround(9.99999997475242707878E-7));
 if (!($3)) {
  $5 = Math_fround($y + Math_fround(-1.0));
  $6 = $5 < Math_fround(0.0);
  if ($6) {
   $7 = Math_fround(-$5);
   $9 = $7;
  } else {
   $9 = $5;
  }
  $8 = !($9 <= Math_fround(9.99999997475242707878E-7));
  if (!($8)) {
   $10 = (($this) + 44|0);
   HEAPF32[$10>>2] = Math_fround(1.0);
   $11 = (($this) + 48|0);
   HEAPF32[$11>>2] = Math_fround(1.0);
   STACKTOP = sp;return;
  }
 }
 $12 = (($this) + 44|0);
 HEAPF32[$12>>2] = $x;
 $13 = (($this) + 48|0);
 HEAPF32[$13>>2] = $y;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnv16SetTextureOffsetEff($this,$x,$y) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x < Math_fround(0.0);
 if ($0) {
  $1 = Math_fround(-$x);
  $3 = $1;
 } else {
  $3 = $x;
 }
 $2 = !($3 <= Math_fround(9.99999997475242707878E-7));
 if (!($2)) {
  $4 = $y < Math_fround(0.0);
  if ($4) {
   $5 = Math_fround(-$y);
   $7 = $5;
  } else {
   $7 = $y;
  }
  $6 = !($7 <= Math_fround(9.99999997475242707878E-7));
  if (!($6)) {
   $8 = (($this) + 52|0);
   HEAPF32[$8>>2] = Math_fround(0.0);
   $9 = (($this) + 56|0);
   HEAPF32[$9>>2] = Math_fround(0.0);
   STACKTOP = sp;return;
  }
 }
 $10 = (($this) + 52|0);
 HEAPF32[$10>>2] = $x;
 $11 = (($this) + 56|0);
 HEAPF32[$11>>2] = $y;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnv31SetTextureScaleAndOffsetIndexedEif($this,$index,$x) {
 $this = $this|0;
 $index = $index|0;
 $x = Math_fround($x);
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = (($0) + ($index<<2)|0);
 HEAPF32[$1>>2] = $x;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($this,$tid,$texDim,$tex,$stValuePtr) {
 $this = $this|0;
 $tid = $tid|0;
 $texDim = $texDim|0;
 $tex = $tex|0;
 $stValuePtr = $stValuePtr|0;
 var $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $or$cond$i = 0, $te$02 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 8|0;
 $1 = (($this) + 28|0);
 HEAP32[$1>>2] = $stValuePtr;
 $2 = HEAP32[$tid>>2]|0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[652824>>2]|0;
 $5 = ($2|0)==(0);
 if ($5) {
  $7 = (($this) + 60|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(-1);
  do {
   if ($9) {
    $37 = 0;
   } else {
    $10 = ($8>>>0)>(1073741823);
    if ($10) {
     $11 = (__Z12GetGfxDevicev()|0);
     $12 = HEAP32[$7>>2]|0;
     $13 = $12 & 1073741823;
     $14 = ((($11) + ($13<<6)|0) + 3748|0);
     $te$02 = $14;
    } else {
     $15 = (($4) + 68|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($4) + 68|0);
     $18 = ($16|0)==(0|0);
     if ($18) {
      $37 = 0;
      break;
     } else {
      $$0$ph7$i$i$i$i = $17;$$01$ph6$i$in$i$i$i = $16;
     }
     L8: while(1) {
      $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
      while(1) {
       $19 = (($$013$i$in$i$i$i) + 16|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = ($20|0)<($8|0);
       if (!($21)) {
        break;
       }
       $24 = (($$013$i$in$i$i$i) + 4|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = ($25|0)==(0|0);
       if ($26) {
        $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
        break L8;
       } else {
        $$013$i$in$i$i$i = $25;
       }
      }
      $22 = HEAP32[$$013$i$in$i$i$i>>2]|0;
      $23 = ($22|0)==(0|0);
      if ($23) {
       $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
       break;
      } else {
       $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $22;
      }
     }
     $27 = ($$0$ph5$i$i$i$i|0)==($17|0);
     if ($27) {
      $37 = 0;
      break;
     }
     $28 = (($$0$ph5$i$i$i$i) + 16|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($8|0)<($29|0);
     if ($30) {
      $37 = 0;
      break;
     }
     $31 = (($$0$ph5$i$i$i$i) + 20|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      $37 = 0;
      break;
     } else {
      $te$02 = $32;
     }
    }
    $34 = (($te$02) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    $37 = $35;
   }
  } while(0);
  $36 = (($this) + 12|0);
  HEAP32[$36>>2] = $37;
 } else {
  $6 = (($this) + 12|0);
  HEAP32[$6>>2] = $2;
 }
 HEAP32[$this>>2] = $texDim;
 $38 = (($this) + 32|0);
 HEAPF32[$38>>2] = Math_fround(1.0);
 $39 = (($this) + 36|0);
 HEAPF32[$39>>2] = Math_fround(1.0);
 $40 = (($this) + 40|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = ($tex|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($tex) + 64|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 HEAPF32[$38>>2] = $43;
 $44 = (($tex) + 68|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 HEAPF32[$39>>2] = $45;
 $46 = (($tex) + 36|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 HEAPF32[$40>>2] = $47;
 $48 = (($this) + 16|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==($tex|0);
 if (!($50)) {
  $51 = ($49|0)==(0|0);
  if (!($51)) {
   $52 = (($this) + 20|0);
   $53 = HEAP32[$52>>2]|0;
   __ZN7Texture16RemoveTexEnvUserEPN9ShaderLab6TexEnvEj($49,$this,$53);
  }
  __ZN7Texture13AddTexEnvUserEPN9ShaderLab6TexEnvE($tex,$this);
 }
 $54 = HEAP32[$tex>>2]|0;
 $55 = (($54) + 92|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (FUNCTION_TABLE_ii[$56 & 4095]($tex)|0);
 $58 = (($this) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(5);
 $61 = ($57|0)==($59|0);
 $or$cond$i = $60 | $61;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 }
 $62 = (680536 + ($57<<2)|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (680536 + ($59<<2)|0);
 $65 = HEAP32[$64>>2]|0;
 HEAP32[$vararg_buffer>>2] = $63;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $65;
 __Z6FormatPKcz($0,680560,$vararg_buffer);
 $66 = HEAP8[$0>>0]|0;
 $67 = $66 & 1;
 $68 = ($67<<24>>24)==(0);
 if ($68) {
  $71 = (($0) + 1|0);
  $72 = $71;
 } else {
  $69 = (($0) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  $72 = $70;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($72|0),0,(680640|0),116,1,0,0,(0|0));
 $73 = __THREW__; __THREW__ = 0;
 $74 = $73&1;
 if ($74) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $82 = HEAP8[$0>>0]|0;
  $83 = $82 & 1;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   ___resumeException($80|0);
   // unreachable;
  }
  $85 = (($0) + 8|0);
  $86 = HEAP32[$85>>2]|0;
  __ZdlPv($86);
  ___resumeException($80|0);
  // unreachable;
 } else {
  $75 = HEAP8[$0>>0]|0;
  $76 = $75 & 1;
  $77 = ($76<<24>>24)==(0);
  if ($77) {
   STACKTOP = sp;return;
  }
  $78 = (($0) + 8|0);
  $79 = HEAP32[$78>>2]|0;
  __ZdlPv($79);
  STACKTOP = sp;return;
 }
}
function __ZN9ShaderLab6TexEnv19OverrideTextureInfoE9TextureIDff($this,$tid,$scaleX,$scaleY) {
 $this = $this|0;
 $tid = $tid|0;
 $scaleX = Math_fround($scaleX);
 $scaleY = Math_fround($scaleY);
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$tid>>2]|0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 40|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  __ZN7Texture16RemoveTexEnvUserEPN9ShaderLab6TexEnvEj($4,$this,$7);
 }
 $8 = (($this) + 32|0);
 HEAPF32[$8>>2] = $scaleX;
 $9 = (($this) + 36|0);
 HEAPF32[$9>>2] = $scaleY;
 $10 = (($this) + 28|0);
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnv21TextureMipBiasChangedEf($this,$mipBias) {
 $this = $this|0;
 $mipBias = Math_fround($mipBias);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAPF32[$0>>2] = $mipBias;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($5) + 36|0);
 HEAP8[$7>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnv21TextureUVScaleChangedEff($this,$x,$y) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 HEAPF32[$0>>2] = $x;
 $1 = (($this) + 36|0);
 HEAPF32[$1>>2] = $y;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($this) + 44|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($6 * $x);
  $8 = (($this) + 48|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($9 * $y);
  $11 = (($this) + 52|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($this) + 56|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$3>>2] = $7;
  $15 = (($3) + 4|0);
  HEAPF32[$15>>2] = $10;
  $16 = (($3) + 8|0);
  HEAPF32[$16>>2] = $12;
  $17 = (($3) + 12|0);
  HEAPF32[$17>>2] = $14;
 }
 $18 = (($this) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = (($19) + 80|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($22) + 36|0);
 HEAP8[$24>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK9ShaderLab6TexEnv11PrepareDataEP10TexEnvData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN10builtintex17GetDefaultTextureE16TextureDimension($4)|0);
  HEAP32[$0>>2] = $5;
  $6 = HEAP32[$this>>2]|0;
  if ((($6|0) == 0) | (($6|0) == 5)) {
   HEAP32[$this>>2] = 2;
   $13 = 2;$7 = $5;
  } else {
   $13 = $6;$7 = $5;
  }
 } else {
  $$pre = HEAP32[$this>>2]|0;
  $13 = $$pre;$7 = $1;
 }
 HEAP32[$data>>2] = $7;
 $8 = (($this) + 40|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($data) + 4|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($data) + 8|0);
 $12 = $13&255;
 $14 = HEAP8[$11>>0]|0;
 $15 = $12 & 15;
 $16 = $14 & -16;
 $17 = $16 | $15;
 HEAP8[$11>>0] = $17;
 STACKTOP = sp;return;
}
function __ZN9ShaderLab6TexEnv15InitFromTextureEP7TextureP8Vector4fiS4_i($this,$tex,$texelSizeValue,$texelSizeParamIndex,$hdrDecodeValue,$hdrDecodeParamIndex) {
 $this = $this|0;
 $tex = $tex|0;
 $texelSizeValue = $texelSizeValue|0;
 $texelSizeParamIndex = $texelSizeParamIndex|0;
 $hdrDecodeValue = $hdrDecodeValue|0;
 $hdrDecodeParamIndex = $hdrDecodeParamIndex|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $hdrDecode = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 28|0;
 $0 = sp;
 $hdrDecode = sp + 8|0;
 $1 = sp + 24|0;
 $2 = ($tex|0)==(0|0);
 if ($2) {
  HEAP32[$1>>2] = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($this,$$byval_copy1,0,0,0);
  STACKTOP = sp;return;
 }
 $3 = (($tex) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = HEAP32[$tex>>2]|0;
 $6 = (($5) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($tex)|0);
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN9ShaderLab6TexEnv14SetTextureInfoE9TextureID16TextureDimensionP7TextureP8Vector4f($this,$$byval_copy1,$8,$tex,0);
 $9 = (($tex) + 72|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($tex) + 76|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = HEAP32[$tex>>2]|0;
 $14 = (($13) + 116|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($tex)|0);
 $17 = (Math_fround(($16|0)));
 $18 = HEAP32[$tex>>2]|0;
 $19 = (($18) + 120|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_ii[$20 & 4095]($tex)|0);
 $22 = (Math_fround(($21|0)));
 $23 = ($texelSizeValue|0)==(0|0);
 if (!($23)) {
  HEAPF32[$texelSizeValue>>2] = $10;
  $24 = (($texelSizeValue) + 4|0);
  HEAPF32[$24>>2] = $12;
  $25 = (($texelSizeValue) + 8|0);
  HEAPF32[$25>>2] = $17;
  $26 = (($texelSizeValue) + 12|0);
  HEAPF32[$26>>2] = $22;
 }
 $27 = ($texelSizeParamIndex|0)!=(-1);
 if ($27) {
  $28 = (__Z12GetGfxDevicev()|0);
  $29 = ((($28) + ($texelSizeParamIndex<<4)|0) + 4|0);
  HEAPF32[$29>>2] = $10;
  $30 = ((($28) + ($texelSizeParamIndex<<4)|0) + 8|0);
  HEAPF32[$30>>2] = $12;
  $31 = ((($28) + ($texelSizeParamIndex<<4)|0) + 12|0);
  HEAPF32[$31>>2] = $17;
  $32 = ((($28) + ($texelSizeParamIndex<<4)|0) + 16|0);
  HEAPF32[$32>>2] = $22;
 }
 $33 = (($tex) + 52|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (__Z19GetActiveColorSpacev()|0);
 $36 = ($35|0)==(1);
 if ($36) {
  $37 = (($tex) + 56|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38;
 } else {
  $39 = 0;
 }
 __Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef($hdrDecode,$34,$39,Math_fround(1.0));
 $40 = ($hdrDecodeValue|0)==(0|0);
 if (!($40)) {
  ;HEAP32[$hdrDecodeValue+0>>2]=HEAP32[$hdrDecode+0>>2]|0;HEAP32[$hdrDecodeValue+4>>2]=HEAP32[$hdrDecode+4>>2]|0;HEAP32[$hdrDecodeValue+8>>2]=HEAP32[$hdrDecode+8>>2]|0;HEAP32[$hdrDecodeValue+12>>2]=HEAP32[$hdrDecode+12>>2]|0;
 }
 if (!($27)) {
  STACKTOP = sp;return;
 }
 $41 = (__Z12GetGfxDevicev()|0);
 $42 = ((($41) + ($hdrDecodeParamIndex<<4)|0) + 4|0);
 ;HEAP32[$42+0>>2]=HEAP32[$hdrDecode+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$hdrDecode+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$hdrDecode+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$hdrDecode+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN8combiner31DecodeTextureCombinerDescriptorEjRNS_9OperationEPNS_6SourceEPNS_7OperandERi($combinerDesc,$operation,$sources,$operands,$scale) {
 $combinerDesc = $combinerDesc|0;
 $operation = $operation|0;
 $sources = $sources|0;
 $operands = $operands|0;
 $scale = $scale|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $combinerDesc >>> 16;
 $1 = $combinerDesc >>> 8;
 $2 = $0 & 3;
 HEAP32[$sources>>2] = $2;
 $3 = $combinerDesc >>> 18;
 $4 = $3 & 63;
 HEAP32[$operands>>2] = $4;
 $5 = $combinerDesc & 3;
 $6 = (($sources) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = $combinerDesc >>> 2;
 $8 = $7 & 63;
 $9 = (($operands) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = $combinerDesc >>> 24;
 HEAP32[$scale>>2] = $10;
 $11 = $1 & 128;
 $12 = ($11|0)==(0);
 if ($12) {
  $22 = $1 & 255;
  HEAP32[$operation>>2] = $22;
  $23 = (($sources) + 8|0);
  HEAP32[$23>>2] = 0;
  $24 = (($operands) + 8|0);
  HEAP32[$24>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $13 = $1 & 96;
  $14 = $1 & 3;
  $15 = $combinerDesc >>> 10;
  $16 = $15 & 6;
  $17 = $16 | 1;
  $18 = (($sources) + 8|0);
  HEAP32[$18>>2] = $14;
  $19 = (($operands) + 8|0);
  HEAP32[$19>>2] = $17;
  $20 = ($13|0)==(0);
  $21 = $20 ? 5 : 8;
  HEAP32[$operation>>2] = $21;
  STACKTOP = sp;return;
 }
}
function __ZN7StriperC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 24|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7StriperD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN7Striper11FreeUsedRamEv($this)|0);
 STACKTOP = sp;return;
}
function __ZN7Striper11FreeUsedRamEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(3604,($1|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __ZdlPv($1);
    break;
   }
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZdlPv($1);
   $$0 = $6;$$01 = $5;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$0>>2] = 0;
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 do {
  if (!($9)) {
   __THREW__ = 0;
   invoke_vi(3604,($8|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __ZdlPv($8);
    break;
   }
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   __ZdlPv($8);
   $$0 = $13;$$01 = $12;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$7>>2] = 0;
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 do {
  if (!($16)) {
   __THREW__ = 0;
   invoke_vi(3604,($15|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __ZdlPv($15);
    break;
   }
   $19 = ___cxa_find_matching_catch()|0;
   $20 = tempRet0;
   __ZdlPv($15);
   $$0 = $20;$$01 = $19;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$14>>2] = 0;
 $21 = (($this) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  __ZdaPv($22);
 }
 HEAP32[$21>>2] = 0;
 $24 = HEAP32[$this>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  HEAP32[$this>>2] = 0;
  STACKTOP = sp;return ($this|0);
 }
 __THREW__ = 0;
 invoke_vi(3605,($24|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  __ZdlPv($24);
  $$0 = $29;$$01 = $28;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  __ZdlPv($24);
  HEAP32[$this>>2] = 0;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZN7Striper4InitER13STRIPERCREATE($this,$create) {
 $this = $this|0;
 $create = $create|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN7Striper11FreeUsedRamEv($this)|0);
 $0 = (__Znwj(20)|0);
 __THREW__ = 0;
 invoke_vi(3606,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  $$01 = $5;$$02 = $4;
  ___resumeException($$02|0);
  // unreachable;
 }
 HEAP32[$this>>2] = $0;
 $3 = ($0|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($create) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($create) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$create>>2]|0;
 $11 = (__ZN5Unity11Adjacencies4InitEPKtPKji($0,$7,$9,$10)|0);
 if ($11) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[$this>>2]|0;
 $13 = ($12|0)==(0|0);
 do {
  if (!($13)) {
   __THREW__ = 0;
   invoke_vi(3605,($12|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __ZdlPv($12);
    break;
   }
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   __ZdlPv($12);
   $$01 = $17;$$02 = $16;
   ___resumeException($$02|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$this>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7Striper7ComputeER13STRIPERRESULT($this,$result) {
 $this = $this|0;
 $result = $result|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$arith = 0, $$overflow = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $Index$04 = 0, $Index$1 = 0, $RS = 0, $TotalNbFaces$03 = 0, $cache = 0, $i$05 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $RS = sp + 84|0;
 $cache = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__Znwj(12)|0);
 __THREW__ = 0;
 invoke_vii(3280,($2|0),4096);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZdlPv($2);
  $$01 = $7;$$02 = $8;
  ___resumeException($$01|0);
  // unreachable;
 }
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = $2;
 $6 = ($2|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (__Znwj(12)|0);
 __THREW__ = 0;
 invoke_vii(3280,($9|0),4096);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZdlPv($9);
  $$01 = $14;$$02 = $15;
  ___resumeException($$01|0);
  // unreachable;
 }
 $12 = (($this) + 16|0);
 HEAP32[$12>>2] = $9;
 $13 = ($9|0)==(0|0);
 if ($13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = (($16) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (__Znaj($18)|0);
 $20 = (($this) + 4|0);
 HEAP32[$20>>2] = $19;
 $21 = ($19|0)==(0|0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = HEAP32[$17>>2]|0;
 $$arith = $22<<2;
 $$overflow = ($22>>>0)>(1073741823);
 $23 = $$overflow ? -1 : $$arith;
 $24 = (__Znaj($23)|0);
 $25 = ($24|0)==(0|0);
 if ($25) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = HEAP32[$17>>2]|0;
 _memset(($19|0),0,($26|0))|0;
 $27 = HEAP32[$17>>2]|0;
 $28 = $27 << 2;
 _memset(($24|0),0,($28|0))|0;
 $29 = HEAP32[$17>>2]|0;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $$phi$trans$insert = (($16) + 16|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $i$05 = 0;
  while(1) {
   $31 = ((($$pre) + (($i$05*24)|0)|0) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(-1);
   if (!($33)) {
    $34 = (($24) + ($i$05<<2)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 1)|0;
    HEAP32[$34>>2] = $36;
   }
   $37 = ((($$pre) + (($i$05*24)|0)|0) + 16|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(-1);
   if (!($39)) {
    $40 = (($24) + ($i$05<<2)|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($41) + 1)|0;
    HEAP32[$40>>2] = $42;
   }
   $43 = ((($$pre) + (($i$05*24)|0)|0) + 20|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(-1);
   if (!($45)) {
    $46 = (($24) + ($i$05<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + 1)|0;
    HEAP32[$46>>2] = $48;
   }
   $49 = (($i$05) + 1)|0;
   $50 = HEAP32[$17>>2]|0;
   $51 = ($49>>>0)<($50>>>0);
   if ($51) {
    $i$05 = $49;
   } else {
    break;
   }
  }
 }
 __ZN11RadixSorterC2Ev($RS);
 $52 = HEAP32[$this>>2]|0;
 $53 = (($52) + 12|0);
 $54 = HEAP32[$53>>2]|0;
 __THREW__ = 0;
 $55 = (invoke_iiiii(256,($RS|0),($24|0),($54|0),1)|0);
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $76 = ___cxa_find_matching_catch()|0;
  $77 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3607,($RS|0));
  $78 = __THREW__; __THREW__ = 0;
  $79 = $78&1;
  if ($79) {
   $111 = ___cxa_find_matching_catch(0|0)|0;
   $112 = tempRet0;
   ___clang_call_terminate($111);
   // unreachable;
  } else {
   $$01 = $76;$$02 = $77;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $58 = (($55) + 12|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$this>>2]|0;
 $61 = (($60) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = $62 << 2;
 _memcpy(($24|0),($59|0),($63|0))|0;
 __ZN11RadixSorterD2Ev($RS);
 $64 = (($this) + 8|0);
 HEAP32[$64>>2] = 0;
 dest=$cache+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 12|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0);
 L44: do {
  if ($68) {
   label = 29;
  } else {
   $Index$04 = 0;$TotalNbFaces$03 = 0;
   while(1) {
    $69 = HEAP32[$20>>2]|0;
    $Index$1 = $Index$04;
    while(1) {
     $70 = (($24) + ($Index$1<<2)|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = (($69) + ($71)|0);
     $73 = HEAP8[$72>>0]|0;
     $74 = ($73<<24>>24)==(0);
     $75 = (($Index$1) + 1)|0;
     if ($74) {
      break;
     } else {
      $Index$1 = $75;
     }
    }
    __THREW__ = 0;
    $80 = (invoke_iiii(1570,($this|0),($71|0),($cache|0))|0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    $83 = (($80) + ($TotalNbFaces$03))|0;
    $84 = HEAP32[$64>>2]|0;
    $85 = (($84) + 1)|0;
    HEAP32[$64>>2] = $85;
    $86 = HEAP32[$this>>2]|0;
    $87 = (($86) + 12|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ($83|0)==($88|0);
    if ($89) {
     label = 29;
     break L44;
    } else {
     $Index$04 = $Index$1;$TotalNbFaces$03 = $83;
    }
   }
   $90 = ___cxa_find_matching_catch()|0;
   $91 = tempRet0;
   $lpad$phi$index = $90;$lpad$phi$index3 = $91;
  }
 } while(0);
 if ((label|0) == 29) {
  __ZdaPv($24);
  $96 = HEAP32[$20>>2]|0;
  $97 = ($96|0)==(0|0);
  if (!($97)) {
   __ZdaPv($96);
  }
  HEAP32[$20>>2] = 0;
  $98 = HEAP32[$64>>2]|0;
  HEAP32[$result>>2] = $98;
  $99 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  $100 = (invoke_iii(2537,($99|0),(0|0))|0);
  $101 = __THREW__; __THREW__ = 0;
  $102 = $101&1;
  if (!($102)) {
   $103 = (($result) + 4|0);
   HEAP32[$103>>2] = $100;
   $104 = HEAP32[$12>>2]|0;
   __THREW__ = 0;
   $105 = (invoke_iii(2537,($104|0),(0|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if (!($107)) {
    $108 = (($result) + 8|0);
    HEAP32[$108>>2] = $105;
    __THREW__ = 0;
    (invoke_iii(2538,($this|0),($result|0))|0);
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if (!($110)) {
     __ZN14BestStripCacheD2Ev($cache);
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $92 = ___cxa_find_matching_catch()|0;
  $93 = tempRet0;
  $lpad$phi$index = $92;$lpad$phi$index3 = $93;
 }
 __THREW__ = 0;
 invoke_vi(3608,($cache|0));
 $94 = __THREW__; __THREW__ = 0;
 $95 = $94&1;
 if ($95) {
  $111 = ___cxa_find_matching_catch(0|0)|0;
  $112 = tempRet0;
  ___clang_call_terminate($111);
  // unreachable;
 } else {
  $$01 = $lpad$phi$index;$$02 = $lpad$phi$index3;
  ___resumeException($$01|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN7Striper16ComputeBestStripEjR14BestStripCache($this,$face,$bestStripCache) {
 $this = $this|0;
 $face = $face|0;
 $bestStripCache = $bestStripCache|0;
 var $$ = 0, $$$i = 0, $$$i11 = 0, $$$i30 = 0, $$0$ph$i = 0, $$0$ph$i18 = 0, $$01$i = 0, $$01$i$phi = 0, $$01$i25 = 0, $$01$i25$phi = 0, $$01$ph$i = 0, $$01$ph$i17 = 0, $$02$i = 0, $$02$i24 = 0, $$02$ph$i = 0, $$02$ph$i16 = 0, $$03$i = 0, $$03$i23 = 0, $$03$ph$i = 0, $$03$ph$i15 = 0;
 var $$04$off0$i = 0, $$04$off0$i20 = 0, $$04$off0$ph$i = 0, $$04$off0$ph$i12 = 0, $$2 = 0, $$pre = 0, $$pre86 = 0, $$pre87 = 0, $$pre88 = 0, $$pre89 = 0, $$pre90 = 0, $$pre91 = 0, $$pre94 = 0, $$sum31 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Best$1 = 0, $DoTheStrip$0$off0$i = 0;
 var $DoTheStrip$0$off0$i22 = 0, $DoTheStrip$0$off0$ph$i = 0, $DoTheStrip$0$off0$ph$i14 = 0, $Faces = 0, $FirstLength = 0, $Length = 0, $Length$0$i = 0, $Length$0$ph$i = 0, $Length$0$ph$i13 = 0, $Longest$1 = 0, $Longest$1$off = 0, $Longest$2 = 0, $Longest$295 = 0, $Longest$296 = 0, $Refs0 = 0, $Refs1 = 0, $Strip = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i3 = 0, $exitcond = 0;
 var $exitcond85 = 0, $i$0$neg52 = 0, $i$051 = 0, $i1$0$neg = 0, $i1$0$neg57 = 0, $i1$056 = 0, $j$069 = 0, $j2$040 = 0, $j3$037 = 0, $j4$033 = 0, $j5$032 = 0, $not$or$cond$i = 0, $not$or$cond$i28 = 0, $notlhs$i = 0, $notlhs$i26 = 0, $notrhs$i = 0, $notrhs$i27 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i4 = 0;
 var $scevgep4$i$i$i = 0, $scevgep4$i$i$i8 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i6 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $Strip = sp + 60|0;
 $Faces = sp;
 $Length = sp + 12|0;
 $FirstLength = sp + 24|0;
 $Refs0 = sp + 36|0;
 $Refs1 = sp + 48|0;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($face*24)|0)|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$Refs0>>2] = $4;
 $5 = ((($2) + (($face*24)|0)|0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$Refs1>>2] = $6;
 $7 = ((($2) + (($face*24)|0)|0) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($Refs0) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = (($Refs1) + 4|0);
 HEAP32[$10>>2] = $4;
 $11 = (($Refs0) + 8|0);
 HEAP32[$11>>2] = $6;
 $12 = (($Refs1) + 8|0);
 HEAP32[$12>>2] = $8;
 $13 = (($bestStripCache) + 72|0);
 $14 = (($bestStripCache) + 76|0);
 $15 = (($this) + 4|0);
 $18 = $0;$j$069 = 0;
 while(1) {
  $16 = (($bestStripCache) + (($j$069*24)|0)|0);
  $17 = (($18) + 12|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = (($19) + 5)|0;
  $21 = ((($bestStripCache) + (($j$069*24)|0)|0) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$16>>2]|0;
  $24 = $22;
  $25 = $23;
  $26 = (($24) - ($25))|0;
  $27 = $26 >> 2;
  $28 = ($27>>>0)<($20>>>0);
  if ($28) {
   $29 = (($20) - ($27))|0;
   __ZNSt3__16vectorIjNS_9allocatorIjEEE8__appendEj($16,$29);
   $$pre = HEAP32[$16>>2]|0;
   $$pre86 = HEAP32[$21>>2]|0;
   $37 = $$pre;$38 = $$pre86;
  } else {
   $30 = ($27>>>0)>($20>>>0);
   if ($30) {
    $31 = (($23) + ($20<<2)|0);
    $32 = ($22|0)==($31|0);
    if ($32) {
     $37 = $23;$38 = $22;
    } else {
     $__new_last2$i$i$i = $31;
     $scevgep$i$i$i = (($22) + -4|0);
     $33 = (0 - ($__new_last2$i$i$i))|0;
     $uglygep$i$i$i = (($scevgep$i$i$i) + ($33)|0);
     $uglygep3$i$i$i = $uglygep$i$i$i;
     $34 = $uglygep3$i$i$i >>> 2;
     $35 = $34 ^ -1;
     $scevgep4$i$i$i = (($22) + ($35<<2)|0);
     HEAP32[$21>>2] = $scevgep4$i$i$i;
     $37 = $23;$38 = $scevgep4$i$i$i;
    }
   } else {
    $37 = $23;$38 = $22;
   }
  }
  $36 = ($37|0)==($38|0);
  $$$i = $36 ? 0 : $37;
  $39 = (($Strip) + ($j$069<<2)|0);
  HEAP32[$39>>2] = $$$i;
  $40 = ((($bestStripCache) + (($j$069*24)|0)|0) + 12|0);
  $41 = HEAP32[$this>>2]|0;
  $42 = (($41) + 12|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 2)|0;
  $45 = ((($bestStripCache) + (($j$069*24)|0)|0) + 16|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$40>>2]|0;
  $48 = $46;
  $49 = $47;
  $50 = (($48) - ($49))|0;
  $51 = $50 >> 2;
  $52 = ($51>>>0)<($44>>>0);
  if ($52) {
   $53 = (($44) - ($51))|0;
   __ZNSt3__16vectorIjNS_9allocatorIjEEE8__appendEj($40,$53);
   $$pre87 = HEAP32[$40>>2]|0;
   $$pre88 = HEAP32[$45>>2]|0;
   $61 = $$pre87;$62 = $$pre88;
  } else {
   $54 = ($51>>>0)>($44>>>0);
   if ($54) {
    $55 = (($47) + ($44<<2)|0);
    $56 = ($46|0)==($55|0);
    if ($56) {
     $61 = $47;$62 = $46;
    } else {
     $__new_last2$i$i$i3 = $55;
     $scevgep$i$i$i4 = (($46) + -4|0);
     $57 = (0 - ($__new_last2$i$i$i3))|0;
     $uglygep$i$i$i6 = (($scevgep$i$i$i4) + ($57)|0);
     $uglygep3$i$i$i7 = $uglygep$i$i$i6;
     $58 = $uglygep3$i$i$i7 >>> 2;
     $59 = $58 ^ -1;
     $scevgep4$i$i$i8 = (($46) + ($59<<2)|0);
     HEAP32[$45>>2] = $scevgep4$i$i$i8;
     $61 = $47;$62 = $scevgep4$i$i$i8;
    }
   } else {
    $61 = $47;$62 = $46;
   }
  }
  $60 = ($61|0)==($62|0);
  $$$i11 = $60 ? 0 : $61;
  $63 = (($Faces) + ($j$069<<2)|0);
  HEAP32[$63>>2] = $$$i11;
  $64 = HEAP32[$this>>2]|0;
  $65 = (($64) + 12|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = $66 << 2;
  $68 = (($67) + 20)|0;
  _memset(($$$i|0),-1,($68|0))|0;
  $69 = HEAP32[$this>>2]|0;
  $70 = (($69) + 12|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = $71 << 2;
  $73 = (($72) + 8)|0;
  _memset(($$$i11|0),-1,($73|0))|0;
  $74 = HEAP32[$this>>2]|0;
  $75 = (($74) + 12|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = HEAP32[$14>>2]|0;
  $78 = HEAP32[$13>>2]|0;
  $79 = $77;
  $80 = $78;
  $81 = (($79) - ($80))|0;
  $82 = ($81>>>0)<($76>>>0);
  if ($82) {
   $83 = (($76) - ($81))|0;
   __ZNSt3__16vectorIcNS_9allocatorIcEEE8__appendEj($13,$83);
   $$pre89 = HEAP32[$13>>2]|0;
   $$pre90 = HEAP32[$14>>2]|0;
   $88 = $$pre89;$89 = $$pre90;
  } else {
   $84 = ($81>>>0)>($76>>>0);
   if ($84) {
    $85 = (($78) + ($76)|0);
    $86 = ($77|0)==($85|0);
    if ($86) {
     $88 = $78;$89 = $77;
    } else {
     HEAP32[$14>>2] = $85;
     $88 = $78;$89 = $85;
    }
   } else {
    $88 = $78;$89 = $77;
   }
  }
  $87 = ($88|0)==($89|0);
  $$$i30 = $87 ? 0 : $88;
  $90 = HEAP32[$15>>2]|0;
  $91 = HEAP32[$this>>2]|0;
  $92 = (($91) + 12|0);
  $93 = HEAP32[$92>>2]|0;
  _memcpy(($$$i30|0),($90|0),($93|0))|0;
  $94 = (($Refs0) + ($j$069<<2)|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($Refs1) + ($j$069<<2)|0);
  $97 = HEAP32[$96>>2]|0;
  HEAP32[$$$i>>2] = $95;
  $98 = (($$$i) + 4|0);
  HEAP32[$98>>2] = $97;
  $$0$ph$i18 = $face;$$01$ph$i17 = $95;$$02$ph$i16 = $97;$$03$ph$i15 = $$$i11;$$04$off0$ph$i12 = 0;$DoTheStrip$0$off0$ph$i14 = 1;$Length$0$ph$i13 = 2;
  L21: while(1) {
   $99 = (($$$i30) + ($$0$ph$i18)|0);
   $$01$i25 = $$01$ph$i17;$$02$i24 = $$02$ph$i16;$$03$i23 = $$03$ph$i15;$$04$off0$i20 = $$04$off0$ph$i12;$107 = $Length$0$ph$i13;$DoTheStrip$0$off0$i22 = $DoTheStrip$0$off0$ph$i14;
   while(1) {
    if (!($DoTheStrip$0$off0$i22)) {
     break L21;
    }
    $100 = $$04$off0$i20 ^ 1;
    $101 = HEAP32[$this>>2]|0;
    $102 = (($101) + 16|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($103) + (($$0$ph$i18*24)|0)|0);
    $105 = (__ZN5Unity11AdjTriangle14OppositeVertexEjj($104,$$01$i25,$$02$i24)|0);
    $106 = (($107) + 1)|0;
    $108 = (($$$i) + ($107<<2)|0);
    HEAP32[$108>>2] = $105;
    $109 = (($$03$i23) + 4|0);
    HEAP32[$$03$i23>>2] = $$0$ph$i18;
    HEAP8[$99>>0] = 1;
    $110 = HEAP32[$this>>2]|0;
    $111 = (($110) + 16|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($112) + (($$0$ph$i18*24)|0)|0);
    $114 = (__ZN5Unity11AdjTriangle8FindEdgeEjj($113,$$02$i24,$105)|0);
    $115 = $114&255;
    $116 = HEAP32[$this>>2]|0;
    $117 = (($116) + 16|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (((($118) + (($$0$ph$i18*24)|0)|0) + ($115<<2)|0) + 12|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = ($120|0)==(-1);
    if ($121) {
     $$01$i25$phi = $$02$i24;$$02$i24 = $105;$$03$i23 = $109;$$04$off0$i20 = $100;$107 = $106;$DoTheStrip$0$off0$i22 = 0;$$01$i25 = $$01$i25$phi;
    } else {
     break;
    }
   }
   $122 = $120 & 1073741823;
   $123 = (($118) + (($122*24)|0)|0);
   $124 = (__ZN5Unity11AdjTriangle19FindEdgeDirectionalEjjb($123,$$02$i24,$105,$100)|0);
   $125 = (($$$i30) + ($122)|0);
   $126 = HEAP8[$125>>0]|0;
   $notlhs$i26 = ($126<<24>>24)==(0);
   $notrhs$i27 = ($124<<24>>24)!=(-1);
   $not$or$cond$i28 = $notrhs$i27 & $notlhs$i26;
   $$0$ph$i18 = $122;$$01$ph$i17 = $$02$i24;$$02$ph$i16 = $105;$$03$ph$i15 = $109;$$04$off0$ph$i12 = $100;$DoTheStrip$0$off0$ph$i14 = $not$or$cond$i28;$Length$0$ph$i13 = $106;
  }
  $127 = (($Length) + ($j$069<<2)|0);
  HEAP32[$127>>2] = $107;
  $128 = (($FirstLength) + ($j$069<<2)|0);
  HEAP32[$128>>2] = $107;
  $129 = ($107>>>0)>(1);
  L28: do {
   if ($129) {
    $130 = $107 >>> 1;
    $i$0$neg52 = -1;$i$051 = 0;
    while(1) {
     $131 = (($i$0$neg52) + ($107))|0;
     $132 = (($$$i) + ($131<<2)|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = (($$$i) + ($i$051<<2)|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = $135 ^ $133;
     HEAP32[$134>>2] = $136;
     $137 = HEAP32[$132>>2]|0;
     $138 = $137 ^ $136;
     HEAP32[$132>>2] = $138;
     $139 = HEAP32[$134>>2]|0;
     $140 = $139 ^ $138;
     HEAP32[$134>>2] = $140;
     $141 = (($i$051) + 1)|0;
     $142 = ($141>>>0)<($130>>>0);
     if (!($142)) {
      break L28;
     }
     $phitmp = (-2 - ($i$051))|0;
     $i$0$neg52 = $phitmp;$i$051 = $141;
    }
   }
  } while(0);
  $143 = (($107) + -2)|0;
  $144 = ($143>>>0)>(1);
  if ($144) {
   $145 = $143 >>> 1;
   $i1$0$neg57 = 0;$i1$056 = 0;
   while(1) {
    $146 = (($i1$0$neg57) + -3)|0;
    $147 = (($146) + ($107))|0;
    $148 = (($$$i11) + ($147<<2)|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = (($$$i11) + ($i1$056<<2)|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = $151 ^ $149;
    HEAP32[$150>>2] = $152;
    $153 = HEAP32[$148>>2]|0;
    $154 = $153 ^ $152;
    HEAP32[$148>>2] = $154;
    $155 = HEAP32[$150>>2]|0;
    $156 = $155 ^ $154;
    HEAP32[$150>>2] = $156;
    $157 = (($i1$056) + 1)|0;
    $i1$0$neg = $i1$056 ^ -1;
    $158 = ($157>>>0)<($145>>>0);
    if ($158) {
     $i1$0$neg57 = $i1$0$neg;$i1$056 = $157;
    } else {
     break;
    }
   }
  }
  $159 = (($107) + -3)|0;
  $160 = (($$$i) + ($159<<2)|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = (($$$i) + ($143<<2)|0);
  $163 = HEAP32[$162>>2]|0;
  $164 = (($$$i11) + ($159<<2)|0);
  $$0$ph$i = $face;$$01$ph$i = $161;$$02$ph$i = $163;$$03$ph$i = $164;$$04$off0$ph$i = 1;$DoTheStrip$0$off0$ph$i = 1;$Length$0$ph$i = 2;
  L39: while(1) {
   $165 = (($$$i30) + ($$0$ph$i)|0);
   $$01$i = $$01$ph$i;$$02$i = $$02$ph$i;$$03$i = $$03$ph$i;$$04$off0$i = $$04$off0$ph$i;$DoTheStrip$0$off0$i = $DoTheStrip$0$off0$ph$i;$Length$0$i = $Length$0$ph$i;
   while(1) {
    if (!($DoTheStrip$0$off0$i)) {
     break L39;
    }
    $166 = $$04$off0$i ^ 1;
    $167 = HEAP32[$this>>2]|0;
    $168 = (($167) + 16|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = (($169) + (($$0$ph$i*24)|0)|0);
    $171 = (__ZN5Unity11AdjTriangle14OppositeVertexEjj($170,$$01$i,$$02$i)|0);
    $172 = (($Length$0$i) + 1)|0;
    $$sum31 = (($Length$0$i) + ($159))|0;
    $173 = (($$$i) + ($$sum31<<2)|0);
    HEAP32[$173>>2] = $171;
    $174 = (($$03$i) + 4|0);
    HEAP32[$$03$i>>2] = $$0$ph$i;
    HEAP8[$165>>0] = 1;
    $175 = HEAP32[$this>>2]|0;
    $176 = (($175) + 16|0);
    $177 = HEAP32[$176>>2]|0;
    $178 = (($177) + (($$0$ph$i*24)|0)|0);
    $179 = (__ZN5Unity11AdjTriangle8FindEdgeEjj($178,$$02$i,$171)|0);
    $180 = $179&255;
    $181 = HEAP32[$this>>2]|0;
    $182 = (($181) + 16|0);
    $183 = HEAP32[$182>>2]|0;
    $184 = (((($183) + (($$0$ph$i*24)|0)|0) + ($180<<2)|0) + 12|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = ($185|0)==(-1);
    if ($186) {
     $$01$i$phi = $$02$i;$$02$i = $171;$$03$i = $174;$$04$off0$i = $166;$DoTheStrip$0$off0$i = 0;$Length$0$i = $172;$$01$i = $$01$i$phi;
    } else {
     break;
    }
   }
   $187 = $185 & 1073741823;
   $188 = (($183) + (($187*24)|0)|0);
   $189 = (__ZN5Unity11AdjTriangle19FindEdgeDirectionalEjjb($188,$$02$i,$171,$166)|0);
   $190 = (($$$i30) + ($187)|0);
   $191 = HEAP8[$190>>0]|0;
   $notlhs$i = ($191<<24>>24)==(0);
   $notrhs$i = ($189<<24>>24)!=(-1);
   $not$or$cond$i = $notrhs$i & $notlhs$i;
   $$0$ph$i = $187;$$01$ph$i = $$02$i;$$02$ph$i = $171;$$03$ph$i = $174;$$04$off0$ph$i = $166;$DoTheStrip$0$off0$ph$i = $not$or$cond$i;$Length$0$ph$i = $172;
  }
  $192 = (($Length$0$i) + -3)|0;
  $193 = HEAP32[$127>>2]|0;
  $194 = (($192) + ($193))|0;
  HEAP32[$127>>2] = $194;
  $195 = (($j$069) + 1)|0;
  $exitcond85 = ($195|0)==(3);
  if ($exitcond85) {
   break;
  }
  $$pre94 = HEAP32[$this>>2]|0;
  $18 = $$pre94;$j$069 = $195;
 }
 $196 = HEAP32[$Length>>2]|0;
 $197 = (($Length) + 4|0);
 $198 = HEAP32[$197>>2]|0;
 $199 = ($198>>>0)>($196>>>0);
 $$ = $199 ? $198 : $196;
 $$2 = $199&1;
 $200 = (($Length) + 8|0);
 $201 = HEAP32[$200>>2]|0;
 $202 = ($201>>>0)>($$>>>0);
 $Longest$1 = $202 ? $201 : $$;
 $Best$1 = $202 ? 2 : $$2;
 $203 = (($Longest$1) + -2)|0;
 $204 = ($203|0)==(0);
 if (!($204)) {
  $205 = (($Faces) + ($Best$1<<2)|0);
  $206 = HEAP32[$205>>2]|0;
  $207 = HEAP32[$15>>2]|0;
  $j2$040 = 0;
  while(1) {
   $208 = (($206) + ($j2$040<<2)|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = (($207) + ($209)|0);
   HEAP8[$210>>0] = 1;
   $211 = (($j2$040) + 1)|0;
   $212 = ($211>>>0)<($203>>>0);
   if ($212) {
    $j2$040 = $211;
   } else {
    break;
   }
  }
 }
 $213 = (($FirstLength) + ($Best$1<<2)|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = $214 & 1;
 $216 = ($215|0)==(0);
 do {
  if ($216) {
   $Longest$2 = $Longest$1;
   label = 50;
  } else {
   $Longest$1$off = (($Longest$1) + -3)|0;
   $217 = ($Longest$1$off>>>0)<(2);
   if ($217) {
    $222 = (($Strip) + ($Best$1<<2)|0);
    $223 = HEAP32[$222>>2]|0;
    $224 = (($223) + 8|0);
    $225 = HEAP32[$224>>2]|0;
    $226 = (($223) + 4|0);
    $227 = HEAP32[$226>>2]|0;
    HEAP32[$224>>2] = $227;
    HEAP32[$226>>2] = $225;
    $Longest$295 = $Longest$1;
    break;
   }
   $218 = $Longest$1 >>> 1;
   $219 = ($218|0)==(0);
   if (!($219)) {
    $220 = (($Strip) + ($Best$1<<2)|0);
    $221 = HEAP32[$220>>2]|0;
    $j3$037 = 0;
    while(1) {
     $228 = (($Longest$1) - ($j3$037))|0;
     $229 = (($228) + -1)|0;
     $230 = (($221) + ($229<<2)|0);
     $231 = HEAP32[$230>>2]|0;
     $232 = (($221) + ($j3$037<<2)|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = $233 ^ $231;
     HEAP32[$232>>2] = $234;
     $235 = HEAP32[$230>>2]|0;
     $236 = $235 ^ $234;
     HEAP32[$230>>2] = $236;
     $237 = HEAP32[$232>>2]|0;
     $238 = $237 ^ $236;
     HEAP32[$232>>2] = $238;
     $239 = (($j3$037) + 1)|0;
     $240 = ($239>>>0)<($218>>>0);
     if ($240) {
      $j3$037 = $239;
     } else {
      break;
     }
    }
   }
   $241 = (($Longest$1) - ($214))|0;
   $242 = $241 & 1;
   $243 = ($242|0)==(0);
   if ($243) {
    $Longest$2 = $Longest$1;
    label = 50;
   } else {
    $244 = ($Longest$1|0)==(0);
    if (!($244)) {
     $245 = (($Strip) + ($Best$1<<2)|0);
     $246 = HEAP32[$245>>2]|0;
     $j4$033 = 0;
     while(1) {
      $247 = (($Longest$1) - ($j4$033))|0;
      $248 = (($247) + -1)|0;
      $249 = (($246) + ($248<<2)|0);
      $250 = HEAP32[$249>>2]|0;
      $251 = (($246) + ($247<<2)|0);
      HEAP32[$251>>2] = $250;
      $252 = (($j4$033) + 1)|0;
      $253 = ($252>>>0)<($Longest$1>>>0);
      if ($253) {
       $j4$033 = $252;
      } else {
       break;
      }
     }
    }
    $254 = (($Longest$1) + 1)|0;
    $Longest$2 = $254;
    label = 50;
   }
  }
 } while(0);
 if ((label|0) == 50) {
  $255 = ($Longest$2|0)==(0);
  if ($255) {
   $Longest$296 = 0;
   $262 = (($this) + 12|0);
   $263 = HEAP32[$262>>2]|0;
   (__ZN11CustomArray8StoreU32Ej($263,$Longest$296)|0);
   STACKTOP = sp;return ($203|0);
  } else {
   $Longest$295 = $Longest$2;
  }
 }
 $256 = (($Strip) + ($Best$1<<2)|0);
 $257 = (($this) + 16|0);
 $$pre91 = HEAP32[$256>>2]|0;
 $j5$032 = 0;
 while(1) {
  $258 = (($$pre91) + ($j5$032<<2)|0);
  $259 = HEAP32[$258>>2]|0;
  $260 = HEAP32[$257>>2]|0;
  (__ZN11CustomArray8StoreU32Ej($260,$259)|0);
  $261 = (($j5$032) + 1)|0;
  $exitcond = ($261|0)==($Longest$295|0);
  if ($exitcond) {
   $Longest$296 = $Longest$295;
   break;
  } else {
   $j5$032 = $261;
  }
 }
 $262 = (($this) + 12|0);
 $263 = HEAP32[$262>>2]|0;
 (__ZN11CustomArray8StoreU32Ej($263,$Longest$296)|0);
 STACKTOP = sp;return ($203|0);
}
function __ZN7Striper16ConnectAllStripsER13STRIPERRESULT($this,$result) {
 $this = $this|0;
 $result = $result|0;
 var $$0 = 0, $$lcssa = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $drefs$04 = 0, $drefs$1 = 0;
 var $j$01 = 0, $k$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(12)|0);
 __THREW__ = 0;
 invoke_vii(3280,($0|0),4096);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($0);
  ___resumeException($5|0);
  // unreachable;
 }
 $3 = (($this) + 24|0);
 HEAP32[$3>>2] = $0;
 $4 = ($0|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 20|0);
 HEAP32[$7>>2] = 0;
 $8 = (($result) + 8|0);
 $9 = HEAP32[$result>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$pre15 = (($result) + 4|0);
  $$pre$phiZ2D = $$pre15;$51 = $0;
 } else {
  $11 = HEAP32[$8>>2]|0;
  $12 = (($result) + 4|0);
  $drefs$04 = $11;$k$03 = 0;
  while(1) {
   $13 = ($k$03|0)==(0);
   do {
    if ($13) {
     $drefs$1 = $drefs$04;
    } else {
     $14 = (($drefs$04) + -4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = HEAP32[$drefs$04>>2]|0;
     $17 = HEAP32[$3>>2]|0;
     $18 = (__ZN11CustomArray8StoreU32Ej($17,$15)|0);
     (__ZN11CustomArray8StoreU32Ej($18,$16)|0);
     $19 = HEAP32[$7>>2]|0;
     $20 = (($19) + 2)|0;
     HEAP32[$7>>2] = $20;
     $21 = $20 & 1;
     $22 = ($21|0)==(0);
     if ($22) {
      $drefs$1 = $drefs$04;
     } else {
      $23 = (($drefs$04) + 4|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($16|0)==($24|0);
      if ($25) {
       $29 = HEAP32[$12>>2]|0;
       $30 = (($29) + ($k$03<<2)|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = (($31) + -1)|0;
       HEAP32[$30>>2] = $32;
       $drefs$1 = $23;
       break;
      } else {
       $26 = HEAP32[$3>>2]|0;
       (__ZN11CustomArray8StoreU32Ej($26,$16)|0);
       $27 = HEAP32[$7>>2]|0;
       $28 = (($27) + 1)|0;
       HEAP32[$7>>2] = $28;
       $drefs$1 = $drefs$04;
       break;
      }
     }
    }
   } while(0);
   $33 = HEAP32[$12>>2]|0;
   $34 = (($33) + ($k$03<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0);
   if ($36) {
    $$lcssa = 0;
   } else {
    $j$01 = 0;
    while(1) {
     $37 = (($drefs$1) + ($j$01<<2)|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = HEAP32[$3>>2]|0;
     (__ZN11CustomArray8StoreU32Ej($39,$38)|0);
     $40 = (($j$01) + 1)|0;
     $41 = HEAP32[$12>>2]|0;
     $42 = (($41) + ($k$03<<2)|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($40>>>0)<($43>>>0);
     if ($44) {
      $j$01 = $40;
     } else {
      $$lcssa = $43;
      break;
     }
    }
   }
   $45 = (($drefs$1) + ($$lcssa<<2)|0);
   $46 = HEAP32[$7>>2]|0;
   $47 = (($46) + ($$lcssa))|0;
   HEAP32[$7>>2] = $47;
   $48 = (($k$03) + 1)|0;
   $49 = HEAP32[$result>>2]|0;
   $50 = ($48>>>0)<($49>>>0);
   if ($50) {
    $drefs$04 = $45;$k$03 = $48;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$3>>2]|0;
  $$pre$phiZ2D = $12;$51 = $$pre;
 }
 HEAP32[$result>>2] = 1;
 $52 = (__ZN11CustomArray8CollapseEPv($51,0)|0);
 HEAP32[$8>>2] = $52;
 HEAP32[$$pre$phiZ2D>>2] = $7;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__16vectorIjNS_9allocatorIjEEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
   }
   $11 = (($10) + 4|0);
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$10 = $11;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($__n))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 if ($22) {
  $23 = $20 >> 1;
  $24 = ($23>>>0)<($18>>>0);
  $25 = $24 ? $18 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 2;
  $28 = (__Znwj($27)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($17<<2)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP32[$32>>2] = 0;
  }
  $33 = (($32) + 4|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($30) + ($18<<2)|0);
 _memcpy(($30|0),($14|0),($16|0))|0;
 HEAP32[$this>>2] = $30;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $36;
 $37 = ($14|0)==(0|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 __ZdlPv($14);
 STACKTOP = sp;return;
}
function __ZN14BestStripCacheD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i$i$1 = 0, $__new_last2$i$i$i$i$i$i$i$2 = 0, $__new_last2$i$i$i$i$i1$i$i = 0, $__new_last2$i$i$i$i$i1$i$i$1 = 0, $__new_last2$i$i$i$i$i1$i$i$2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$1 = 0, $scevgep$i$i$i$i$i$i$i$2 = 0, $scevgep$i$i$i$i$i2$i$i = 0, $scevgep$i$i$i$i$i2$i$i$1 = 0, $scevgep$i$i$i$i$i2$i$i$2 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$1 = 0, $scevgep4$i$i$i$i$i$i$i$2 = 0, $scevgep4$i$i$i$i$i6$i$i = 0, $scevgep4$i$i$i$i$i6$i$i$1 = 0, $scevgep4$i$i$i$i$i6$i$i$2 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$1 = 0, $uglygep$i$i$i$i$i$i$i$2 = 0;
 var $uglygep$i$i$i$i$i4$i$i = 0, $uglygep$i$i$i$i$i4$i$i$1 = 0, $uglygep$i$i$i$i$i4$i$i$2 = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$1 = 0, $uglygep3$i$i$i$i$i$i$i$2 = 0, $uglygep3$i$i$i$i$i5$i$i = 0, $uglygep3$i$i$i$i$i5$i$i$1 = 0, $uglygep3$i$i$i$i$i5$i$i$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 76|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if (!($5)) {
   HEAP32[$3>>2] = $1;
  }
  __ZdlPv($1);
 }
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 64|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $__new_last2$i$i$i$i$i$i$i = $7;
   $scevgep$i$i$i$i$i$i$i = (($10) + -4|0);
   $12 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($12)|0);
   $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
   $13 = $uglygep3$i$i$i$i$i$i$i >>> 2;
   $14 = $13 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($10) + ($14<<2)|0);
   HEAP32[$9>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 $15 = (($this) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = (($this) + 52|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($16|0);
  if (!($20)) {
   $__new_last2$i$i$i$i$i1$i$i = $16;
   $scevgep$i$i$i$i$i2$i$i = (($19) + -4|0);
   $21 = (0 - ($__new_last2$i$i$i$i$i1$i$i))|0;
   $uglygep$i$i$i$i$i4$i$i = (($scevgep$i$i$i$i$i2$i$i) + ($21)|0);
   $uglygep3$i$i$i$i$i5$i$i = $uglygep$i$i$i$i$i4$i$i;
   $22 = $uglygep3$i$i$i$i$i5$i$i >>> 2;
   $23 = $22 ^ -1;
   $scevgep4$i$i$i$i$i6$i$i = (($19) + ($23<<2)|0);
   HEAP32[$18>>2] = $scevgep4$i$i$i$i$i6$i$i;
  }
  __ZdlPv($16);
 }
 $24 = (($this) + 36|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (($this) + 40|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($25|0);
  if (!($29)) {
   $__new_last2$i$i$i$i$i$i$i$1 = $25;
   $scevgep$i$i$i$i$i$i$i$1 = (($28) + -4|0);
   $30 = (0 - ($__new_last2$i$i$i$i$i$i$i$1))|0;
   $uglygep$i$i$i$i$i$i$i$1 = (($scevgep$i$i$i$i$i$i$i$1) + ($30)|0);
   $uglygep3$i$i$i$i$i$i$i$1 = $uglygep$i$i$i$i$i$i$i$1;
   $31 = $uglygep3$i$i$i$i$i$i$i$1 >>> 2;
   $32 = $31 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$1 = (($28) + ($32<<2)|0);
   HEAP32[$27>>2] = $scevgep4$i$i$i$i$i$i$i$1;
  }
  __ZdlPv($25);
 }
 $33 = (($this) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = (($this) + 28|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==($34|0);
  if (!($38)) {
   $__new_last2$i$i$i$i$i1$i$i$1 = $34;
   $scevgep$i$i$i$i$i2$i$i$1 = (($37) + -4|0);
   $39 = (0 - ($__new_last2$i$i$i$i$i1$i$i$1))|0;
   $uglygep$i$i$i$i$i4$i$i$1 = (($scevgep$i$i$i$i$i2$i$i$1) + ($39)|0);
   $uglygep3$i$i$i$i$i5$i$i$1 = $uglygep$i$i$i$i$i4$i$i$1;
   $40 = $uglygep3$i$i$i$i$i5$i$i$1 >>> 2;
   $41 = $40 ^ -1;
   $scevgep4$i$i$i$i$i6$i$i$1 = (($37) + ($41<<2)|0);
   HEAP32[$36>>2] = $scevgep4$i$i$i$i$i6$i$i$1;
  }
  __ZdlPv($34);
 }
 $42 = (($this) + 12|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = (($this) + 16|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==($43|0);
  if (!($47)) {
   $__new_last2$i$i$i$i$i$i$i$2 = $43;
   $scevgep$i$i$i$i$i$i$i$2 = (($46) + -4|0);
   $48 = (0 - ($__new_last2$i$i$i$i$i$i$i$2))|0;
   $uglygep$i$i$i$i$i$i$i$2 = (($scevgep$i$i$i$i$i$i$i$2) + ($48)|0);
   $uglygep3$i$i$i$i$i$i$i$2 = $uglygep$i$i$i$i$i$i$i$2;
   $49 = $uglygep3$i$i$i$i$i$i$i$2 >>> 2;
   $50 = $49 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$2 = (($46) + ($50<<2)|0);
   HEAP32[$45>>2] = $scevgep4$i$i$i$i$i$i$i$2;
  }
  __ZdlPv($43);
 }
 $51 = HEAP32[$this>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = (($this) + 4|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==($51|0);
 if (!($55)) {
  $__new_last2$i$i$i$i$i1$i$i$2 = $51;
  $scevgep$i$i$i$i$i2$i$i$2 = (($54) + -4|0);
  $56 = (0 - ($__new_last2$i$i$i$i$i1$i$i$2))|0;
  $uglygep$i$i$i$i$i4$i$i$2 = (($scevgep$i$i$i$i$i2$i$i$2) + ($56)|0);
  $uglygep3$i$i$i$i$i5$i$i$2 = $uglygep$i$i$i$i$i4$i$i$2;
  $57 = $uglygep3$i$i$i$i$i5$i$i$2 >>> 2;
  $58 = $57 ^ -1;
  $scevgep4$i$i$i$i$i6$i$i$2 = (($54) + ($58<<2)|0);
  HEAP32[$53>>2] = $scevgep4$i$i$i$i$i6$i$i$2;
 }
 __ZdlPv($51);
 STACKTOP = sp;return;
}
function __ZN5Unity11AdjacenciesC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN5Unity11Adjacencies4InitEPKtPKji($this,$shortFaces,$faces,$faceCount) {
 $this = $this|0;
 $shortFaces = $shortFaces|0;
 $faces = $faces|0;
 $faceCount = $faceCount|0;
 var $$0 = 0, $$arith = 0, $$arith2 = 0, $$overflow = 0, $$overflow3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$01$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $faceCount;
 $$arith2 = ($faceCount*24)|0;
 $$overflow3 = ($faceCount>>>0)>(178956970);
 $1 = $$overflow3 ? -1 : $$arith2;
 $2 = (__Znaj($1)|0);
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = $2;
 $4 = ($2|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($faceCount*3)|0;
 $$arith = ($5*12)|0;
 $$overflow = ($5>>>0)>(357913941);
 $6 = $$overflow ? -1 : $$arith;
 $7 = (__Znaj($6)|0);
 $8 = (($this) + 8|0);
 HEAP32[$8>>2] = $7;
 $9 = ($7|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ($faceCount|0)==(0);
 if (!($10)) {
  $11 = ($shortFaces|0)==(0|0);
  if ($11) {
   $i$01$us = 0;
   while(1) {
    $12 = ($i$01$us*3)|0;
    $13 = (($faces) + ($12<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + 1)|0;
    $16 = (($faces) + ($15<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($12) + 2)|0;
    $19 = (($faces) + ($18<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    (__ZN5Unity11Adjacencies11AddTriangleEjjj($this,$14,$17,$20)|0);
    $21 = (($i$01$us) + 1)|0;
    $22 = HEAP32[$0>>2]|0;
    $23 = ($21>>>0)<($22>>>0);
    if ($23) {
     $i$01$us = $21;
    } else {
     break;
    }
   }
  } else {
   $i$01 = 0;
   while(1) {
    $24 = ($i$01*3)|0;
    $25 = (($shortFaces) + ($24<<1)|0);
    $26 = HEAP16[$25>>1]|0;
    $27 = $26&65535;
    $28 = (($24) + 1)|0;
    $29 = (($shortFaces) + ($28<<1)|0);
    $30 = HEAP16[$29>>1]|0;
    $31 = $30&65535;
    $32 = (($24) + 2)|0;
    $33 = (($shortFaces) + ($32<<1)|0);
    $34 = HEAP16[$33>>1]|0;
    $35 = $34&65535;
    (__ZN5Unity11Adjacencies11AddTriangleEjjj($this,$27,$31,$35)|0);
    $36 = (($i$01) + 1)|0;
    $37 = HEAP32[$0>>2]|0;
    $38 = ($36>>>0)<($37>>>0);
    if ($38) {
     $i$01 = $36;
    } else {
     break;
    }
   }
  }
 }
 $39 = (__ZN5Unity11Adjacencies14CreateDatabaseEv($this)|0);
 $$0 = $39;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity11AdjacenciesD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZdaPv($1);
 }
 HEAP32[$0>>2] = 0;
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$3>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZdaPv($4);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN5Unity11Adjacencies11AddTriangleEjjj($this,$ref0,$ref1,$ref2) {
 $this = $this|0;
 $ref0 = $ref0|0;
 $ref1 = $ref1|0;
 $ref2 = $ref2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge = 0, $storemerge$in = 0, $storemerge1 = 0, $storemerge1$in = 0, $storemerge2 = 0, $storemerge2$in = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + (($1*24)|0)|0);
 HEAP32[$4>>2] = $ref0;
 $5 = HEAP32[$0>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 4|0);
 HEAP32[$6>>2] = $ref1;
 $7 = HEAP32[$0>>2]|0;
 $8 = ((($3) + (($7*24)|0)|0) + 8|0);
 HEAP32[$8>>2] = $ref2;
 $9 = HEAP32[$0>>2]|0;
 $10 = ((($3) + (($9*24)|0)|0) + 12|0);
 HEAP32[$10>>2] = -1;
 $11 = HEAP32[$0>>2]|0;
 $12 = ((($3) + (($11*24)|0)|0) + 16|0);
 HEAP32[$12>>2] = -1;
 $13 = HEAP32[$0>>2]|0;
 $14 = ((($3) + (($13*24)|0)|0) + 20|0);
 HEAP32[$14>>2] = -1;
 $15 = ($ref0>>>0)<($ref1>>>0);
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$this>>2]|0;
 $18 = (($this) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + (($17*12)|0)|0);
 if ($15) {
  HEAP32[$20>>2] = $ref0;
  $21 = HEAP32[$this>>2]|0;
  $22 = ((($19) + (($21*12)|0)|0) + 4|0);
  HEAP32[$22>>2] = $ref1;
  $23 = HEAP32[$this>>2]|0;
  $24 = ((($19) + (($23*12)|0)|0) + 8|0);
  HEAP32[$24>>2] = $16;
 } else {
  HEAP32[$20>>2] = $ref1;
  $25 = HEAP32[$this>>2]|0;
  $26 = ((($19) + (($25*12)|0)|0) + 4|0);
  HEAP32[$26>>2] = $ref0;
  $27 = HEAP32[$this>>2]|0;
  $28 = ((($19) + (($27*12)|0)|0) + 8|0);
  HEAP32[$28>>2] = $16;
 }
 $storemerge$in = HEAP32[$this>>2]|0;
 $storemerge = (($storemerge$in) + 1)|0;
 HEAP32[$this>>2] = $storemerge;
 $29 = ($ref0>>>0)<($ref2>>>0);
 $30 = HEAP32[$0>>2]|0;
 $31 = (($19) + (($storemerge*12)|0)|0);
 if ($29) {
  HEAP32[$31>>2] = $ref0;
  $32 = HEAP32[$this>>2]|0;
  $33 = ((($19) + (($32*12)|0)|0) + 4|0);
  HEAP32[$33>>2] = $ref2;
  $34 = HEAP32[$this>>2]|0;
  $35 = ((($19) + (($34*12)|0)|0) + 8|0);
  HEAP32[$35>>2] = $30;
 } else {
  HEAP32[$31>>2] = $ref2;
  $36 = HEAP32[$this>>2]|0;
  $37 = ((($19) + (($36*12)|0)|0) + 4|0);
  HEAP32[$37>>2] = $ref0;
  $38 = HEAP32[$this>>2]|0;
  $39 = ((($19) + (($38*12)|0)|0) + 8|0);
  HEAP32[$39>>2] = $30;
 }
 $storemerge1$in = HEAP32[$this>>2]|0;
 $storemerge1 = (($storemerge1$in) + 1)|0;
 HEAP32[$this>>2] = $storemerge1;
 $40 = ($ref1>>>0)<($ref2>>>0);
 $41 = HEAP32[$0>>2]|0;
 $42 = (($19) + (($storemerge1*12)|0)|0);
 if ($40) {
  HEAP32[$42>>2] = $ref1;
  $43 = HEAP32[$this>>2]|0;
  $44 = ((($19) + (($43*12)|0)|0) + 4|0);
  HEAP32[$44>>2] = $ref2;
  $45 = HEAP32[$this>>2]|0;
  $46 = ((($19) + (($45*12)|0)|0) + 8|0);
  HEAP32[$46>>2] = $41;
  $storemerge2$in = HEAP32[$this>>2]|0;
  $storemerge2 = (($storemerge2$in) + 1)|0;
  HEAP32[$this>>2] = $storemerge2;
  $51 = HEAP32[$0>>2]|0;
  $52 = (($51) + 1)|0;
  HEAP32[$0>>2] = $52;
  STACKTOP = sp;return 1;
 } else {
  HEAP32[$42>>2] = $ref2;
  $47 = HEAP32[$this>>2]|0;
  $48 = ((($19) + (($47*12)|0)|0) + 4|0);
  HEAP32[$48>>2] = $ref1;
  $49 = HEAP32[$this>>2]|0;
  $50 = ((($19) + (($49*12)|0)|0) + 8|0);
  HEAP32[$50>>2] = $41;
  $storemerge2$in = HEAP32[$this>>2]|0;
  $storemerge2 = (($storemerge2$in) + 1)|0;
  HEAP32[$this>>2] = $storemerge2;
  $51 = HEAP32[$0>>2]|0;
  $52 = (($51) + 1)|0;
  HEAP32[$0>>2] = $52;
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __ZN5Unity11Adjacencies14CreateDatabaseEv($this) {
 $this = $this|0;
 var $$0 = 0, $$arith = 0, $$lcssa30 = 0, $$overflow = 0, $$phi$trans$insert = 0, $$phi$trans$insert39 = 0, $$phi$trans$insert41 = 0, $$pre = 0, $$pre$pre = 0, $$pre38 = 0, $$pre40 = 0, $$pre42 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $Core = 0, $Count$026 = 0, $Count$1 = 0, $LastRef0$024 = 0, $LastRef0$024$phi = 0, $LastRef1$025 = 0, $LastRef1$025$phi = 0, $Status2$0$off0 = 0;
 var $TmpBuffer = 0, $i$031 = 0, $i1$027 = 0, $or$cond = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $Core = sp + 12|0;
 $TmpBuffer = sp;
 __ZN11RadixSorterC2Ev($Core);
 $0 = HEAP32[$this>>2]|0;
 $$arith = $0<<2;
 $$overflow = ($0>>>0)>(1073741823);
 $1 = $$overflow ? -1 : $$arith;
 __THREW__ = 0;
 $2 = (invoke_ii(3167,($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = ($2|0)==(0|0);
  if ($5) {
   $$0 = 0;
   __ZN11RadixSorterD2Ev($Core);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $10 = (invoke_ii(3167,($1|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = ($10|0)==(0|0);
   if ($13) {
    $$0 = 0;
    __ZN11RadixSorterD2Ev($Core);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $14 = (invoke_ii(3167,($1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = ($14|0)==(0|0);
    if ($17) {
     $$0 = 0;
     __ZN11RadixSorterD2Ev($Core);
     STACKTOP = sp;return ($$0|0);
    }
    $18 = ($0|0)==(0);
    if ($18) {
     $$lcssa30 = 0;
    } else {
     $19 = (($this) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $i$031 = 0;
     while(1) {
      $21 = ((($20) + (($i$031*12)|0)|0) + 8|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($2) + ($i$031<<2)|0);
      HEAP32[$23>>2] = $22;
      $24 = (($20) + (($i$031*12)|0)|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($10) + ($i$031<<2)|0);
      HEAP32[$26>>2] = $25;
      $27 = ((($20) + (($i$031*12)|0)|0) + 4|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($14) + ($i$031<<2)|0);
      HEAP32[$29>>2] = $28;
      $30 = (($i$031) + 1)|0;
      $31 = ($30>>>0)<($0>>>0);
      if ($31) {
       $i$031 = $30;
      } else {
       $$lcssa30 = $0;
       break;
      }
     }
    }
    __THREW__ = 0;
    $32 = (invoke_iiiii(256,($Core|0),($2|0),($$lcssa30|0),1)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = HEAP32[$this>>2]|0;
     __THREW__ = 0;
     $36 = (invoke_iiiii(256,($32|0),($10|0),($35|0),1)|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      $39 = HEAP32[$this>>2]|0;
      __THREW__ = 0;
      $40 = (invoke_iiiii(256,($36|0),($14|0),($39|0),1)|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       $43 = (($40) + 12|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = HEAP32[$44>>2]|0;
       $46 = (($10) + ($45<<2)|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = (($14) + ($45<<2)|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = HEAP32[$this>>2]|0;
       $51 = ($50|0)==(0);
       do {
        if ($51) {
         $Status2$0$off0 = 1;
        } else {
         $52 = (($TmpBuffer) + 4|0);
         $54 = $45;$57 = $47;$59 = $49;$79 = $50;$Count$026 = 0;$LastRef0$024 = $47;$LastRef1$025 = $49;$i1$027 = 1;
         while(1) {
          $53 = (($2) + ($54<<2)|0);
          $55 = HEAP32[$53>>2]|0;
          $56 = ($57|0)==($LastRef0$024|0);
          $58 = ($59|0)==($LastRef1$025|0);
          $or$cond = $56 & $58;
          if ($or$cond) {
           $60 = (($Count$026) + 1)|0;
           $61 = (($TmpBuffer) + ($Count$026<<2)|0);
           HEAP32[$61>>2] = $55;
           $62 = ($60|0)==(3);
           if ($62) {
            label = 18;
            break;
           } else {
            $68 = $79;$Count$1 = $60;
           }
          } else {
           $63 = ($Count$026|0)==(2);
           if ($63) {
            $64 = HEAP32[$TmpBuffer>>2]|0;
            $65 = HEAP32[$52>>2]|0;
            $66 = (__ZN5Unity11Adjacencies10UpdateLinkEjjjj($this,$64,$65,$LastRef0$024,$LastRef1$025)|0);
            if (!($66)) {
             label = 22;
             break;
            }
            $$pre$pre = HEAP32[$this>>2]|0;
            $$pre = $$pre$pre;
           } else {
            $$pre = $79;
           }
           HEAP32[$TmpBuffer>>2] = $55;
           $68 = $$pre;$Count$1 = 1;
          }
          $67 = ($i1$027>>>0)<($68>>>0);
          if (!($67)) {
           label = 26;
           break;
          }
          $$phi$trans$insert = (($44) + ($i1$027<<2)|0);
          $$pre38 = HEAP32[$$phi$trans$insert>>2]|0;
          $$phi$trans$insert39 = (($10) + ($$pre38<<2)|0);
          $$pre40 = HEAP32[$$phi$trans$insert39>>2]|0;
          $$phi$trans$insert41 = (($14) + ($$pre38<<2)|0);
          $$pre42 = HEAP32[$$phi$trans$insert41>>2]|0;
          $phitmp = (($i1$027) + 1)|0;
          $LastRef1$025$phi = $59;$LastRef0$024$phi = $57;$54 = $$pre38;$57 = $$pre40;$59 = $$pre42;$79 = $68;$Count$026 = $Count$1;$i1$027 = $phitmp;$LastRef1$025 = $LastRef1$025$phi;$LastRef0$024 = $LastRef0$024$phi;
         }
         if ((label|0) == 18) {
          __ZdaPv($14);
          __ZdaPv($10);
          __ZdaPv($2);
          $$0 = 0;
          __ZN11RadixSorterD2Ev($Core);
          STACKTOP = sp;return ($$0|0);
         }
         else if ((label|0) == 22) {
          __ZdaPv($14);
          __ZdaPv($10);
          __ZdaPv($2);
          $$0 = 0;
          __ZN11RadixSorterD2Ev($Core);
          STACKTOP = sp;return ($$0|0);
         }
         else if ((label|0) == 26) {
          $69 = ($Count$1|0)==(2);
          if (!($69)) {
           $Status2$0$off0 = 1;
           break;
          }
          $70 = HEAP32[$TmpBuffer>>2]|0;
          $71 = (($TmpBuffer) + 4|0);
          $72 = HEAP32[$71>>2]|0;
          $73 = (__ZN5Unity11Adjacencies10UpdateLinkEjjjj($this,$70,$72,$57,$59)|0);
          $Status2$0$off0 = $73;
          break;
         }
        }
       } while(0);
       __ZdaPv($14);
       __ZdaPv($10);
       __ZdaPv($2);
       $74 = (($this) + 8|0);
       $75 = HEAP32[$74>>2]|0;
       $76 = ($75|0)==(0|0);
       if (!($76)) {
        __ZdaPv($75);
       }
       HEAP32[$74>>2] = 0;
       $$0 = $Status2$0$off0;
       __ZN11RadixSorterD2Ev($Core);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3607,($Core|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $77 = ___cxa_find_matching_catch(0|0)|0;
  $78 = tempRet0;
  ___clang_call_terminate($77);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN5Unity11Adjacencies10UpdateLinkEjjjj($this,$firsttri,$secondtri,$ref0,$ref1) {
 $this = $this|0;
 $firsttri = $firsttri|0;
 $secondtri = $secondtri|0;
 $ref0 = $ref0|0;
 $ref1 = $ref1|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($firsttri*24)|0)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($ref0|0);
 if ($4) {
  $5 = ((($1) + (($firsttri*24)|0)|0) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($ref1|0);
  if ($7) {
   $60 = 0;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 do {
  if ((label|0) == 3) {
   $8 = ($3|0)==($ref1|0);
   if ($8) {
    $9 = ((($1) + (($firsttri*24)|0)|0) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($ref0|0);
    if ($11) {
     $60 = 0;
     break;
    }
   }
   if ($4) {
    $12 = ((($1) + (($firsttri*24)|0)|0) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==($ref1|0);
    if ($14) {
     $60 = 1;
     break;
    }
   }
   if ($8) {
    $15 = ((($1) + (($firsttri*24)|0)|0) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($ref0|0);
    if ($17) {
     $60 = 1;
     break;
    }
   }
   $18 = ((($1) + (($firsttri*24)|0)|0) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==($ref0|0);
   if ($20) {
    $21 = ((($1) + (($firsttri*24)|0)|0) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($ref1|0);
    if ($23) {
     $60 = 2;
     break;
    }
   }
   $24 = ($19|0)==($ref1|0);
   if (!($24)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $25 = ((($1) + (($firsttri*24)|0)|0) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==($ref0|0);
   $28 = $27 ? 2 : 255;
   if ($27) {
    $60 = $28;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $29 = (($1) + (($secondtri*24)|0)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==($ref0|0);
 if ($31) {
  $32 = ((($1) + (($secondtri*24)|0)|0) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==($ref1|0);
  if ($34) {
   $57 = 0;
  } else {
   label = 15;
  }
 } else {
  label = 15;
 }
 do {
  if ((label|0) == 15) {
   $35 = ($30|0)==($ref1|0);
   if ($35) {
    $36 = ((($1) + (($secondtri*24)|0)|0) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==($ref0|0);
    if ($38) {
     $57 = 0;
     break;
    }
   }
   if ($31) {
    $39 = ((($1) + (($secondtri*24)|0)|0) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==($ref1|0);
    if ($41) {
     $57 = 1;
     break;
    }
   }
   if ($35) {
    $42 = ((($1) + (($secondtri*24)|0)|0) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==($ref0|0);
    if ($44) {
     $57 = 1;
     break;
    }
   }
   $45 = ((($1) + (($secondtri*24)|0)|0) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($ref0|0);
   if ($47) {
    $48 = ((($1) + (($secondtri*24)|0)|0) + 8|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($ref1|0);
    if ($50) {
     $57 = 2;
     break;
    }
   }
   $51 = ($46|0)==($ref1|0);
   if (!($51)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $52 = ((($1) + (($secondtri*24)|0)|0) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==($ref0|0);
   $55 = $54 ? 2 : 255;
   if ($54) {
    $57 = $55;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $56 = $57 << 30;
 $58 = $56 | $secondtri;
 $59 = (((($1) + (($firsttri*24)|0)|0) + ($60<<2)|0) + 12|0);
 HEAP32[$59>>2] = $58;
 $61 = $60 << 30;
 $62 = $61 | $firsttri;
 $63 = (((($1) + (($secondtri*24)|0)|0) + ($57<<2)|0) + 12|0);
 HEAP32[$63>>2] = $62;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5Unity11AdjTriangle8FindEdgeEjj($this,$vref0,$vref1) {
 $this = $this|0;
 $vref0 = $vref0|0;
 $vref1 = $vref1|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $EdgeNb$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==($vref0|0);
 if ($1) {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==($vref1|0);
  if ($4) {
   $EdgeNb$0 = 0;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 do {
  if ((label|0) == 3) {
   $5 = ($0|0)==($vref1|0);
   if ($5) {
    $6 = (($this) + 4|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==($vref0|0);
    if ($8) {
     $EdgeNb$0 = 0;
     break;
    }
   }
   if ($1) {
    $9 = (($this) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($vref1|0);
    if ($11) {
     $EdgeNb$0 = 1;
     break;
    }
   }
   if ($5) {
    $12 = (($this) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==($vref0|0);
    if ($14) {
     $EdgeNb$0 = 1;
     break;
    }
   }
   $15 = (($this) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($vref0|0);
   if ($17) {
    $18 = (($this) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($vref1|0);
    if ($20) {
     $EdgeNb$0 = 2;
     break;
    }
   }
   $21 = ($16|0)==($vref1|0);
   if ($21) {
    $22 = (($this) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==($vref0|0);
    $$ = $24 ? 2 : -1;
    STACKTOP = sp;return ($$|0);
   } else {
    $EdgeNb$0 = -1;
   }
  }
 } while(0);
 STACKTOP = sp;return ($EdgeNb$0|0);
}
function __ZN5Unity11AdjTriangle19FindEdgeDirectionalEjjb($this,$vref0,$vref1,$reverseEdgeDirection) {
 $this = $this|0;
 $vref0 = $vref0|0;
 $vref1 = $vref1|0;
 $reverseEdgeDirection = $reverseEdgeDirection|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $EdgeNb$0 = 0, $or$cond = 0, $vref0$vref1 = 0, $vref1$vref0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $vref1$vref0 = $reverseEdgeDirection ? $vref1 : $vref0;
 $vref0$vref1 = $reverseEdgeDirection ? $vref0 : $vref1;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==($vref1$vref0|0);
 if ($1) {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==($vref0$vref1|0);
  if ($4) {
   $EdgeNb$0 = 0;
   STACKTOP = sp;return ($EdgeNb$0|0);
  }
 }
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($vref1$vref0|0);
 $8 = ($0|0)==($vref0$vref1|0);
 $or$cond = $7 & $8;
 if ($or$cond) {
  $EdgeNb$0 = 1;
  STACKTOP = sp;return ($EdgeNb$0|0);
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($vref1$vref0|0);
 if ($11) {
  $12 = ($6|0)==($vref0$vref1|0);
  $$ = $12 ? 2 : -1;
  STACKTOP = sp;return ($$|0);
 } else {
  $EdgeNb$0 = -1;
  STACKTOP = sp;return ($EdgeNb$0|0);
 }
 return 0|0;
}
function __ZN5Unity11AdjTriangle14OppositeVertexEjj($this,$vref0,$vref1) {
 $this = $this|0;
 $vref0 = $vref0|0;
 $vref1 = $vref1|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $Ref$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==($vref0|0);
 if ($1) {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==($vref1|0);
  if ($4) {
   $5 = (($this) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $Ref$0 = $6;
   STACKTOP = sp;return ($Ref$0|0);
  }
 }
 $7 = ($0|0)==($vref1|0);
 if ($7) {
  $8 = (($this) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($vref0|0);
  if ($10) {
   $11 = (($this) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $Ref$0 = $12;
   STACKTOP = sp;return ($Ref$0|0);
  }
 }
 if ($1) {
  $13 = (($this) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==($vref1|0);
  if ($15) {
   $16 = (($this) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $Ref$0 = $17;
   STACKTOP = sp;return ($Ref$0|0);
  }
 }
 if ($7) {
  $18 = (($this) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($vref0|0);
  if ($20) {
   $21 = (($this) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $Ref$0 = $22;
   STACKTOP = sp;return ($Ref$0|0);
  }
 }
 $23 = (($this) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($vref0|0);
 if ($25) {
  $26 = (($this) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($vref1|0);
  if ($28) {
   $Ref$0 = $0;
   STACKTOP = sp;return ($Ref$0|0);
  }
 }
 $29 = ($24|0)==($vref1|0);
 if ($29) {
  $30 = (($this) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==($vref0|0);
  $$ = $32 ? $0 : -1;
  STACKTOP = sp;return ($$|0);
 } else {
  $Ref$0 = -1;
  STACKTOP = sp;return ($Ref$0|0);
 }
 return 0|0;
}
function __ZN11CustomArrayC2Em($this,$startsize) {
 $this = $this|0;
 $startsize = $startsize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (__Znwj(16)|0);
 $2 = (($1) + 4|0);
 HEAP32[$1>>2] = 0;
 $3 = (($1) + 12|0);
 HEAP32[$3>>2] = $startsize;
 $4 = (__Znaj($startsize)|0);
 HEAP32[$2>>2] = $4;
 $5 = (($1) + 8|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$this>>2] = $1;
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN11CustomArrayD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $CurCell$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZdaPv($1);
 }
 HEAP32[$0>>2] = 0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $CurCell$01 = $4;
 }
 while(1) {
  $6 = HEAP32[$CurCell$01>>2]|0;
  $7 = (($CurCell$01) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   __ZdaPv($8);
  }
  __ZdlPv($CurCell$01);
  $10 = ($6|0)==(0|0);
  if ($10) {
   break;
  } else {
   $CurCell$01 = $6;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11CustomArray8CollapseEPv($this,$userbuffer) {
 $this = $this|0;
 $userbuffer = $userbuffer|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $Addy$01$ph = 0, $Addy$02 = 0, $Addy$14 = 0, $Offset$0$i = 0, $p$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($userbuffer|0)==(0|0);
 do {
  if ($2) {
   $3 = (($this) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    $31 = $1;
   } else {
    __ZdaPv($4);
    $$pre = HEAP32[$0>>2]|0;
    $31 = $$pre;
   }
   HEAP32[$3>>2] = 0;
   $Offset$0$i = 0;$p$0$i = $31;
   while(1) {
    $6 = HEAP32[$p$0$i>>2]|0;
    $7 = ($6|0)==(0|0);
    $8 = (($p$0$i) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + ($Offset$0$i))|0;
    if ($7) {
     break;
    } else {
     $Offset$0$i = $10;$p$0$i = $6;
    }
   }
   $11 = ($10|0)==(0);
   if ($11) {
    HEAP32[$3>>2] = 0;
    $Addy$02 = 0;
    STACKTOP = sp;return ($Addy$02|0);
   } else {
    $12 = (__Znaj($10)|0);
    HEAP32[$3>>2] = $12;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $Addy$02 = 0;
    } else {
     $Addy$01$ph = $12;
     break;
    }
    STACKTOP = sp;return ($Addy$02|0);
   }
  } else {
   $Addy$01$ph = $userbuffer;
  }
 } while(0);
 $14 = HEAP32[$1>>2]|0;
 $15 = ($14|0)==(0|0);
 $16 = (($1) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($1) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 _memcpy(($Addy$01$ph|0),($17|0),($19|0))|0;
 if ($15) {
  $Addy$02 = $Addy$01$ph;
  STACKTOP = sp;return ($Addy$02|0);
 } else {
  $21 = $18;$24 = $1;$Addy$14 = $Addy$01$ph;
 }
 while(1) {
  $20 = HEAP32[$21>>2]|0;
  $22 = (($Addy$14) + ($20)|0);
  $23 = HEAP32[$24>>2]|0;
  $25 = HEAP32[$23>>2]|0;
  $26 = ($25|0)==(0|0);
  $27 = (($23) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($23) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  _memcpy(($22|0),($28|0),($30|0))|0;
  if ($26) {
   $Addy$02 = $Addy$01$ph;
   break;
  } else {
   $21 = $29;$24 = $23;$Addy$14 = $22;
  }
 }
 STACKTOP = sp;return ($Addy$02|0);
}
function __ZN11CustomArray8StoreU32Ej($this,$d) {
 $this = $this|0;
 $d = $d|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4)|0;
 $4 = (($0) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 do {
  if ($6) {
   $7 = (__Znwj(16)|0);
   $8 = (($7) + 4|0);
   HEAP32[$8>>2] = 0;
   HEAP32[$7>>2] = 0;
   $9 = ($0|0)==(0|0);
   if ($9) {
    $15 = (($7) + 12|0);
    HEAP32[$15>>2] = 0;
    $16 = (__Znaj(0)|0);
    HEAP32[$8>>2] = $16;
    $17 = (($7) + 8|0);
    HEAP32[$17>>2] = 0;
    HEAP32[$this>>2] = $7;
    $19 = $7;
    break;
   } else {
    $10 = HEAP32[$4>>2]|0;
    $11 = $10 << 1;
    $12 = (($7) + 12|0);
    HEAP32[$12>>2] = $11;
    $13 = (__Znaj($11)|0);
    HEAP32[$8>>2] = $13;
    $14 = (($7) + 8|0);
    HEAP32[$14>>2] = 0;
    HEAP32[$this>>2] = $7;
    HEAP32[$0>>2] = $7;
    $$pre = HEAP32[$this>>2]|0;
    $19 = $$pre;
    break;
   }
  } else {
   $19 = $0;
  }
 } while(0);
 $18 = (($19) + 4|0);
 $20 = HEAP32[$18>>2]|0;
 $21 = (($19) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + ($22)|0);
 HEAP32[$23>>2] = $d;
 $24 = (($22) + 4)|0;
 HEAP32[$21>>2] = $24;
 STACKTOP = sp;return ($this|0);
}
function __ZN11RadixSorterC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 16|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (__Znaj(4096)|0);
 HEAP32[$this>>2] = $3;
 $4 = (__Znaj(1024)|0);
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN11RadixSorterD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZdaPv($1);
 }
 HEAP32[$0>>2] = 0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __ZdaPv($3);
 }
 HEAP32[$this>>2] = 0;
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  __ZdaPv($6);
 }
 HEAP32[$5>>2] = 0;
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  HEAP32[$8>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZdaPv($9);
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11RadixSorter4SortEPjjb($this,$input,$nb,$signedvalues) {
 $this = $this|0;
 $input = $input|0;
 $nb = $nb|0;
 $signedvalues = $signedvalues|0;
 var $$AlreadySorted$0$off0 = 0, $$AlreadySorted$2 = 0, $$arith = 0, $$not = 0, $$overflow = 0, $$phi$trans$insert = 0, $$phi$trans$insert68 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre62 = 0, $$pre63 = 0, $$pre64 = 0, $$pre65 = 0, $$pre66 = 0, $$pre67 = 0, $$pre69 = 0, $$pre70 = 0, $$sum = 0, $$sum$us = 0, $$sum1112 = 0;
 var $$sum1314 = 0, $$sum1516 = 0, $$sum1718 = 0, $$sum1920 = 0, $$sum4 = 0, $$sum4$us = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum7$us = 0, $$sum8 = 0, $$sum910 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $AlreadySorted$0$off047 = 0, $AlreadySorted$240 = 0, $Indices$046 = 0, $Indices$139 = 0, $Indices7$028 = 0, $Indices7$028$us = 0, $NbNegativeValues$034 = 0, $PrevVal$044 = 0, $PrevVal$044$phi = 0, $PrevVal1$037 = 0, $PrevVal1$037$phi = 0, $exitcond = 0, $exitcond50 = 0, $exitcond51 = 0, $exitcond52 = 0, $exitcond53 = 0, $exitcond54 = 0, $exitcond55 = 0, $extract$t = 0;
 var $i$01$i = 0, $i$035 = 0, $i3$022 = 0, $i3$022$us = 0, $i4$027 = 0, $i4$027$us = 0, $i5$023 = 0, $i6$025 = 0, $j$030 = 0, $j$030$us = 0, $not$ = 0, $or$cond = 0, $or$cond71 = 0, $p$045 = 0, $p$138 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($nb>>>0);
 if ($2) {
  $3 = (($this) + 16|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   __ZdaPv($4);
  }
  HEAP32[$3>>2] = 0;
  $6 = (($this) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   __ZdaPv($7);
  }
  $$arith = $nb<<2;
  $$overflow = ($nb>>>0)>(1073741823);
  $9 = $$overflow ? -1 : $$arith;
  $10 = (__Znaj($9)|0);
  HEAP32[$6>>2] = $10;
  $11 = (__Znaj($9)|0);
  HEAP32[$3>>2] = $11;
  HEAP32[$0>>2] = $nb;
  $12 = ($nb|0)==(0);
  if ($12) {
   $$pre$phiZ2D = $6;
  } else {
   $i$01$i = 0;
   while(1) {
    $13 = (($10) + ($i$01$i<<2)|0);
    HEAP32[$13>>2] = $i$01$i;
    $14 = (($i$01$i) + 1)|0;
    $15 = ($14>>>0)<($nb>>>0);
    if ($15) {
     $i$01$i = $14;
    } else {
     $$pre$phiZ2D = $6;
     break;
    }
   }
  }
 } else {
  $$pre70 = (($this) + 12|0);
  $$pre$phiZ2D = $$pre70;
 }
 $16 = HEAP32[$this>>2]|0;
 _memset(($16|0),0,4096)|0;
 $17 = HEAP32[$$pre$phiZ2D>>2]|0;
 $18 = (($input) + ($nb<<2)|0);
 $19 = HEAP32[$this>>2]|0;
 $20 = HEAP32[$17>>2]|0;
 $21 = (($input) + ($20<<2)|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($18|0)==($input|0);
 if ($signedvalues) {
  if ($23) {
   STACKTOP = sp;return ($this|0);
  } else {
   $53 = $22;$AlreadySorted$240 = 1;$Indices$139 = $17;$PrevVal1$037 = $22;$p$138 = $input;
  }
  while(1) {
   $51 = (($Indices$139) + 4|0);
   $52 = ($53|0)<($PrevVal1$037|0);
   $$AlreadySorted$2 = $52 ? 0 : $AlreadySorted$240;
   $54 = (($p$138) + 1|0);
   $55 = HEAP8[$p$138>>0]|0;
   $56 = $55&255;
   $57 = (($19) + ($56<<2)|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($58) + 1)|0;
   HEAP32[$57>>2] = $59;
   $60 = (($p$138) + 2|0);
   $61 = HEAP8[$54>>0]|0;
   $62 = $61&255;
   $$sum1516 = $62 | 256;
   $63 = (($19) + ($$sum1516<<2)|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 1)|0;
   HEAP32[$63>>2] = $65;
   $66 = (($p$138) + 3|0);
   $67 = HEAP8[$60>>0]|0;
   $68 = $67&255;
   $$sum1718 = $68 | 512;
   $69 = (($19) + ($$sum1718<<2)|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) + 1)|0;
   HEAP32[$69>>2] = $71;
   $72 = (($p$138) + 4|0);
   $73 = HEAP8[$66>>0]|0;
   $74 = $73&255;
   $$sum1920 = $74 | 768;
   $75 = (($19) + ($$sum1920<<2)|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($76) + 1)|0;
   HEAP32[$75>>2] = $77;
   $78 = ($72|0)==($18|0);
   if ($78) {
    break;
   }
   $$pre65 = HEAP32[$51>>2]|0;
   $$phi$trans$insert = (($input) + ($$pre65<<2)|0);
   $$pre66 = HEAP32[$$phi$trans$insert>>2]|0;
   $PrevVal1$037$phi = $53;$53 = $$pre66;$AlreadySorted$240 = $$AlreadySorted$2;$Indices$139 = $51;$p$138 = $72;$PrevVal1$037 = $PrevVal1$037$phi;
  }
  $79 = $$AlreadySorted$2 & 1;
  $extract$t = ($79<<24>>24)==(0);
  if (!($extract$t)) {
   STACKTOP = sp;return ($this|0);
  }
 } else {
  if ($23) {
   STACKTOP = sp;return ($this|0);
  } else {
   $25 = $22;$AlreadySorted$0$off047 = 1;$Indices$046 = $17;$PrevVal$044 = $22;$p$045 = $input;
  }
  while(1) {
   $24 = (($Indices$046) + 4|0);
   $not$ = ($25>>>0)>=($PrevVal$044>>>0);
   $$AlreadySorted$0$off0 = $AlreadySorted$0$off047 & $not$;
   $26 = (($p$045) + 1|0);
   $27 = HEAP8[$p$045>>0]|0;
   $28 = $27&255;
   $29 = (($19) + ($28<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 1)|0;
   HEAP32[$29>>2] = $31;
   $32 = (($p$045) + 2|0);
   $33 = HEAP8[$26>>0]|0;
   $34 = $33&255;
   $$sum910 = $34 | 256;
   $35 = (($19) + ($$sum910<<2)|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 1)|0;
   HEAP32[$35>>2] = $37;
   $38 = (($p$045) + 3|0);
   $39 = HEAP8[$32>>0]|0;
   $40 = $39&255;
   $$sum1112 = $40 | 512;
   $41 = (($19) + ($$sum1112<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 1)|0;
   HEAP32[$41>>2] = $43;
   $44 = (($p$045) + 4|0);
   $45 = HEAP8[$38>>0]|0;
   $46 = $45&255;
   $$sum1314 = $46 | 768;
   $47 = (($19) + ($$sum1314<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + 1)|0;
   HEAP32[$47>>2] = $49;
   $50 = ($44|0)==($18|0);
   if ($50) {
    break;
   }
   $$pre67 = HEAP32[$24>>2]|0;
   $$phi$trans$insert68 = (($input) + ($$pre67<<2)|0);
   $$pre69 = HEAP32[$$phi$trans$insert68>>2]|0;
   $PrevVal$044$phi = $25;$25 = $$pre69;$AlreadySorted$0$off047 = $$AlreadySorted$0$off0;$Indices$046 = $24;$p$045 = $44;$PrevVal$044 = $PrevVal$044$phi;
  }
  if ($$AlreadySorted$0$off0) {
   STACKTOP = sp;return ($this|0);
  }
 }
 if ($signedvalues) {
  $NbNegativeValues$034 = 0;$i$035 = 128;
  while(1) {
   $$sum8 = (($i$035) + 768)|0;
   $82 = (($19) + ($$sum8<<2)|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($83) + ($NbNegativeValues$034))|0;
   $85 = (($i$035) + 1)|0;
   $exitcond53 = ($85|0)==(256);
   if ($exitcond53) {
    break;
   } else {
    $NbNegativeValues$034 = $84;$i$035 = $85;
   }
  }
  $86 = (($this) + 4|0);
  $87 = (($this) + 16|0);
  if ($signedvalues) {
   $152 = $17;$j$030 = 0;
   while(1) {
    $121 = $j$030 << 8;
    $i3$022 = 0;
    while(1) {
     $$sum7 = (($i3$022) + ($121))|0;
     $122 = (($19) + ($$sum7<<2)|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = ($123|0)==($nb|0);
     if ($124) {
      $168 = $152;
      break;
     }
     $125 = ($123|0)==(0);
     $126 = (($i3$022) + 1)|0;
     $127 = ($126>>>0)<(256);
     $or$cond71 = $125 & $127;
     if ($or$cond71) {
      $i3$022 = $126;
     } else {
      label = 37;
      break;
     }
    }
    if ((label|0) == 37) {
     label = 0;
     $$not = ($j$030|0)==(3);
     $128 = HEAP32[$86>>2]|0;
     if ($$not) {
      HEAP32[$128>>2] = $84;
      $140 = $84;$i5$023 = 1;
      while(1) {
       $136 = (($i5$023) + -1)|0;
       $$sum6 = (($136) + ($121))|0;
       $137 = (($19) + ($$sum6<<2)|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = (($138) + ($140))|0;
       $141 = (($128) + ($i5$023<<2)|0);
       HEAP32[$141>>2] = $139;
       $142 = (($i5$023) + 1)|0;
       $exitcond = ($142|0)==(128);
       if ($exitcond) {
        break;
       } else {
        $140 = $139;$i5$023 = $142;
       }
      }
      $143 = (($128) + 512|0);
      HEAP32[$143>>2] = 0;
      $148 = 0;$i6$025 = 129;
      while(1) {
       $144 = (($i6$025) + -1)|0;
       $$sum5 = (($144) + ($121))|0;
       $145 = (($19) + ($$sum5<<2)|0);
       $146 = HEAP32[$145>>2]|0;
       $147 = (($146) + ($148))|0;
       $149 = (($128) + ($i6$025<<2)|0);
       HEAP32[$149>>2] = $147;
       $150 = (($i6$025) + 1)|0;
       $exitcond50 = ($150|0)==(256);
       if ($exitcond50) {
        break;
       } else {
        $148 = $147;$i6$025 = $150;
       }
      }
     } else {
      HEAP32[$128>>2] = 0;
      $133 = 0;$i4$027 = 1;
      while(1) {
       $129 = (($i4$027) + -1)|0;
       $$sum4 = (($129) + ($121))|0;
       $130 = (($19) + ($$sum4<<2)|0);
       $131 = HEAP32[$130>>2]|0;
       $132 = (($131) + ($133))|0;
       $134 = (($128) + ($i4$027<<2)|0);
       HEAP32[$134>>2] = $132;
       $135 = (($i4$027) + 1)|0;
       $exitcond51 = ($135|0)==(256);
       if ($exitcond51) {
        break;
       } else {
        $133 = $132;$i4$027 = $135;
       }
      }
     }
     $151 = (($152) + ($nb<<2)|0);
     $153 = ($nb|0)==(0);
     if (!($153)) {
      $$pre = HEAP32[$87>>2]|0;
      $Indices7$028 = $152;
      while(1) {
       $154 = (($Indices7$028) + 4|0);
       $155 = HEAP32[$Indices7$028>>2]|0;
       $156 = $155 << 2;
       $$sum = (($156) + ($j$030))|0;
       $157 = (($input) + ($$sum)|0);
       $158 = HEAP8[$157>>0]|0;
       $159 = $158&255;
       $160 = (($128) + ($159<<2)|0);
       $161 = HEAP32[$160>>2]|0;
       $162 = (($161) + 1)|0;
       HEAP32[$160>>2] = $162;
       $163 = (($$pre) + ($161<<2)|0);
       HEAP32[$163>>2] = $155;
       $164 = ($154|0)==($151|0);
       if ($164) {
        break;
       } else {
        $Indices7$028 = $154;
       }
      }
     }
     $165 = HEAP32[$87>>2]|0;
     HEAP32[$$pre$phiZ2D>>2] = $165;
     HEAP32[$87>>2] = $152;
     $168 = $165;
    }
    $166 = (($j$030) + 1)|0;
    $exitcond52 = ($166|0)==(4);
    if ($exitcond52) {
     break;
    } else {
     $152 = $168;$j$030 = $166;
    }
   }
   STACKTOP = sp;return ($this|0);
  } else {
   $100 = $87;$96 = $86;
  }
 } else {
  $80 = (($this) + 4|0);
  $81 = (($this) + 16|0);
  $100 = $81;$96 = $80;
 }
 $98 = $17;$j$030$us = 0;
 while(1) {
  $88 = $j$030$us << 8;
  $i3$022$us = 0;
  while(1) {
   $$sum7$us = (($i3$022$us) + ($88))|0;
   $89 = (($19) + ($$sum7$us<<2)|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==($nb|0);
   if ($91) {
    $167 = $98;
    break;
   }
   $92 = ($90|0)==(0);
   $93 = (($i3$022$us) + 1)|0;
   $94 = ($93>>>0)<(256);
   $or$cond = $92 & $94;
   if ($or$cond) {
    $i3$022$us = $93;
   } else {
    label = 26;
    break;
   }
  }
  if ((label|0) == 26) {
   label = 0;
   $95 = HEAP32[$96>>2]|0;
   HEAP32[$95>>2] = 0;
   $117 = 0;$i4$027$us = 1;
   while(1) {
    $113 = (($i4$027$us) + -1)|0;
    $$sum4$us = (($113) + ($88))|0;
    $114 = (($19) + ($$sum4$us<<2)|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = (($115) + ($117))|0;
    $118 = (($95) + ($i4$027$us<<2)|0);
    HEAP32[$118>>2] = $116;
    $119 = (($i4$027$us) + 1)|0;
    $exitcond54 = ($119|0)==(256);
    if ($exitcond54) {
     break;
    } else {
     $117 = $116;$i4$027$us = $119;
    }
   }
   $97 = (($98) + ($nb<<2)|0);
   $99 = ($nb|0)==(0);
   if ($99) {
    $$pre62 = HEAP32[$100>>2]|0;
    $112 = $$pre62;
   } else {
    $$pre63 = HEAP32[$96>>2]|0;
    $$pre64 = HEAP32[$100>>2]|0;
    $Indices7$028$us = $98;
    while(1) {
     $101 = (($Indices7$028$us) + 4|0);
     $102 = HEAP32[$Indices7$028$us>>2]|0;
     $103 = $102 << 2;
     $$sum$us = (($103) + ($j$030$us))|0;
     $104 = (($input) + ($$sum$us)|0);
     $105 = HEAP8[$104>>0]|0;
     $106 = $105&255;
     $107 = (($$pre63) + ($106<<2)|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = (($108) + 1)|0;
     HEAP32[$107>>2] = $109;
     $110 = (($$pre64) + ($108<<2)|0);
     HEAP32[$110>>2] = $102;
     $111 = ($101|0)==($97|0);
     if ($111) {
      $112 = $$pre64;
      break;
     } else {
      $Indices7$028$us = $101;
     }
    }
   }
   HEAP32[$$pre$phiZ2D>>2] = $112;
   HEAP32[$100>>2] = $98;
   $167 = $112;
  }
  $120 = (($j$030$us) + 1)|0;
  $exitcond55 = ($120|0)==(4);
  if ($exitcond55) {
   break;
  } else {
   $98 = $167;$j$030$us = $120;
  }
 }
 STACKTOP = sp;return ($this|0);
}
function __Z51AssetBundleCreateRequest_Get_Custom_PropAssetBundleP15ScriptingObject($self) {
 $self = $self|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $pos$i$i$i$i = 0, $temp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($self) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0$i$i = 0;
  $39 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i$i)|0);
  STACKTOP = sp;return ($39|0);
 }
 HEAP32[$0>>2] = $4;
 $6 = HEAP32[560624>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  label = 10;
 } else {
  $8 = (($6) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  do {
   if ($12) {
    $13 = (($6) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($6) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + ($16<<3)|0);
    $33 = $17;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$6,$0);
    $18 = HEAP32[$pos$i$i$i$i>>2]|0;
    $19 = ($18|0)==(-1);
    $20 = (($6) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    if ($19) {
     $22 = (($6) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($21) + ($23<<3)|0);
     $33 = $24;
     break;
    } else {
     $25 = (($21) + ($18<<3)|0);
     $33 = $25;
     break;
    }
   }
  } while(0);
  $26 = HEAP32[560624>>2]|0;
  $27 = (($26) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + ($30<<3)|0);
  $32 = ($33|0)==($31|0);
  if ($32) {
   label = 10;
  } else {
   $34 = (($33) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 10;
   } else {
    $temp$0$i$i = $35;
   }
  }
 }
 if ((label|0) == 10) {
  $37 = HEAP32[$3>>2]|0;
  $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
  $temp$0$i$i = $38;
 }
 $$0$i$i = $temp$0$i$i;
 $39 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i$i)|0);
 STACKTOP = sp;return ($39|0);
}
function __Z58AssetBundleCreateRequest_CUSTOM_DisableCompatibilityChecksP15ScriptingObject($self) {
 $self = $self|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($self) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 76|0);
 HEAP8[$2>>0] = 0;
 STACKTOP = sp;return;
}
function __Z37AssetBundle_CUSTOM_LoadAsset_InternalP15ScriptingObjectP15ScriptingStringS0_($self_,$name_,$type) {
 $self_ = $self_|0;
 $name_ = $name_|0;
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $name = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($name,$name_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$name);
 __THREW__ = 0;
 $5 = (invoke_iiii(1571,($2|0),($0|0),($type|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $16 = HEAP8[$0>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   ___resumeException($14|0);
   // unreachable;
  }
  $19 = (($0) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  __ZdlPv($20);
  ___resumeException($14|0);
  // unreachable;
 }
 $8 = HEAP8[$0>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = (($0) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  __ZdlPv($12);
 }
 $13 = ($5|0)==(0|0);
 if ($13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (__ZN9Scripting19ScriptingWrapperForEP6Object($5)|0);
 $$0 = $21;
 STACKTOP = sp;return ($$0|0);
}
function __Z50AssetBundle_CUSTOM_LoadAssetWithSubAssets_InternalP15ScriptingObjectP15ScriptingStringS0_($self_,$name_,$type) {
 $self_ = $self_|0;
 $name_ = $name_|0;
 $type = $type|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i4 = 0, $name = 0, $objects = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i8 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $name = sp + 24|0;
 $objects = sp;
 $0 = sp + 12|0;
 __ZN11ICallStringC2EPv($name,$name_);
 HEAP32[$objects>>2] = 0;
 $1 = (($objects) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($objects) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = ($self_|0)==(0|0);
 do {
  if ($3) {
   $8 = 0;
   label = 4;
  } else {
   __THREW__ = 0;
   $4 = (invoke_ii(3327,($self_|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if ($6) {
    label = 16;
   } else {
    $7 = ($4|0)==(0|0);
    if ($7) {
     $8 = $self_;
     label = 4;
    } else {
     __THREW__ = 0;
     invoke_vii(3281,($0|0),($name|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 16;
     } else {
      __THREW__ = 0;
      invoke_viiii(403,($4|0),($0|0),($type|0),($objects|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       $32 = ___cxa_find_matching_catch()|0;
       $33 = tempRet0;
       $34 = HEAP8[$0>>0]|0;
       $35 = $34 & 1;
       $36 = ($35<<24>>24)==(0);
       if ($36) {
        $$0 = $32;$$01 = $33;
        break;
       }
       $37 = (($0) + 8|0);
       $38 = HEAP32[$37>>2]|0;
       __ZdlPv($38);
       $$0 = $32;$$01 = $33;
       break;
      }
      $15 = HEAP8[$0>>0]|0;
      $16 = $15 & 1;
      $17 = ($16<<24>>24)==(0);
      if (!($17)) {
       $18 = (($0) + 8|0);
       $19 = HEAP32[$18>>2]|0;
       __ZdlPv($19);
      }
      __THREW__ = 0;
      $20 = (invoke_iii(2539,($objects|0),0)|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 16;
      } else {
       $23 = HEAP32[$objects>>2]|0;
       $24 = ($23|0)==(0|0);
       if ($24) {
        STACKTOP = sp;return ($20|0);
       }
       $25 = HEAP32[$1>>2]|0;
       $26 = ($25|0)==($23|0);
       if (!($26)) {
        $__new_last2$i$i$i$i$i4 = $23;
        $scevgep$i$i$i$i$i5 = (($25) + -4|0);
        $27 = (0 - ($__new_last2$i$i$i$i$i4))|0;
        $uglygep$i$i$i$i$i7 = (($scevgep$i$i$i$i$i5) + ($27)|0);
        $uglygep3$i$i$i$i$i8 = $uglygep$i$i$i$i$i7;
        $28 = $uglygep3$i$i$i$i$i8 >>> 2;
        $29 = $28 ^ -1;
        $scevgep4$i$i$i$i$i9 = (($25) + ($29<<2)|0);
        HEAP32[$1>>2] = $scevgep4$i$i$i$i$i9;
       }
       __ZdlPv($23);
       STACKTOP = sp;return ($20|0);
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  __THREW__ = 0;
  invoke_vi(3609,($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 16;
  } else {
   // unreachable;
  }
 }
 if ((label|0) == 16) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $$0 = $30;$$01 = $31;
 }
 $39 = HEAP32[$objects>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $41 = HEAP32[$1>>2]|0;
 $42 = ($41|0)==($39|0);
 if (!($42)) {
  $__new_last2$i$i$i$i$i = $39;
  $scevgep$i$i$i$i$i = (($41) + -4|0);
  $43 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($43)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $44 = $uglygep3$i$i$i$i$i >>> 2;
  $45 = $44 ^ -1;
  $scevgep4$i$i$i$i$i = (($41) + ($45<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($39);
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __Z36CreateScriptingArrayFromUnityObjectsINSt3__16vectorIP6ObjectNS0_9allocatorIS3_EEEEEP14ScriptingArrayRKT_i($unityobjects,$classID) {
 $unityobjects = $unityobjects|0;
 $classID = $classID|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $i$0$lcssa$i$i = 0, $i$03$i$i = 0, $i$12$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetScriptingManagerv()|0);
 $1 = (__ZN16ScriptingManager23ClassIDToScriptingClassEi($0,$classID)|0);
 $2 = (($unityobjects) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$unityobjects>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = (__Z19scripting_array_newP14ScriptingClassjj($1,4,$8)|0);
 $10 = (__Z21GetScriptingArraySizeP14ScriptingArray($9)|0);
 $11 = HEAP32[$unityobjects>>2]|0;
 $12 = HEAP32[$2>>2]|0;
 $13 = ($11|0)==($12|0);
 if ($13) {
  $i$0$lcssa$i$i = 0;
 } else {
  $16 = $11;$i$03$i$i = 0;
  while(1) {
   $15 = HEAP32[$16>>2]|0;
   $17 = (__ZN9Scripting19ScriptingWrapperForEP6Object($15)|0);
   __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($9,$i$03$i$i,$17);
   $18 = (($i$03$i$i) + 1)|0;
   $19 = (($16) + 4|0);
   $20 = HEAP32[$2>>2]|0;
   $21 = ($19|0)==($20|0);
   if ($21) {
    $i$0$lcssa$i$i = $18;
    break;
   } else {
    $16 = $19;$i$03$i$i = $18;
   }
  }
 }
 $14 = ($i$0$lcssa$i$i|0)<($10|0);
 if ($14) {
  $i$12$i$i = $i$0$lcssa$i$i;
 } else {
  STACKTOP = sp;return ($9|0);
 }
 while(1) {
  $22 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($9,$i$12$i$i,4)|0);
  HEAP32[$22>>2] = 0;
  $23 = (($i$12$i$i) + 1)|0;
  $exitcond$i$i = ($23|0)==($10|0);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$12$i$i = $23;
  }
 }
 STACKTOP = sp;return ($9|0);
}
function __Z61Register_UnityEngine_AssetBundleCreateRequest_get_assetBundlev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(680648,3328);
 STACKTOP = sp;return;
}
function __Z72Register_UnityEngine_AssetBundleCreateRequest_DisableCompatibilityChecksv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(680704,3610);
 STACKTOP = sp;return;
}
function __Z51Register_UnityEngine_AssetBundle_LoadAsset_Internalv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(680776,1572);
 STACKTOP = sp;return;
}
function __Z64Register_UnityEngine_AssetBundle_LoadAssetWithSubAssets_Internalv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(680824,1573);
 STACKTOP = sp;return;
}
function __Z28LayerMask_CUSTOM_LayerToNamei($layer) {
 $layer = $layer|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z13GetTagManagerv()|0);
 $1 = (__ZN10TagManager13LayerToStringEj($0,$layer)|0);
 $2 = (__Z20scripting_string_newRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z28LayerMask_CUSTOM_NameToLayerP15ScriptingString($layerName_) {
 $layerName_ = $layerName_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $layerName = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $layerName = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($layerName,$layerName_);
 $1 = (__Z13GetTagManagerv()|0);
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$layerName);
 __THREW__ = 0;
 $2 = (invoke_iii(2540,($1|0),($0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $12 = HEAP8[$0>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   ___resumeException($10|0);
   // unreachable;
  }
  $15 = (($0) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  __ZdlPv($16);
  ___resumeException($10|0);
  // unreachable;
 } else {
  $5 = HEAP8[$0>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   STACKTOP = sp;return ($2|0);
  }
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z33Coroutine_CUSTOM_ReleaseCoroutineP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $$0$i$i = 0;
 } else {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $$0$i$i = $2;
 }
 __ZN9Coroutine18CleanupCoroutineGCEPv($$0$i$i);
 STACKTOP = sp;return;
}
function __Z55ScriptableObject_CUSTOM_Internal_CreateScriptableObjectP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Scripting28CreateEngineScriptableObjectEP15ScriptingObject($self_);
 STACKTOP = sp;return;
}
function __Z38ScriptableObject_CUSTOM_CreateInstanceP15ScriptingString($className_) {
 $className_ = $className_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $className = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $className = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($className,$className_);
 __ZNK11ICallString6AsUTF8Ev($0,$className);
 __THREW__ = 0;
 $1 = (invoke_ii(3329,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   ___resumeException($9|0);
   // unreachable;
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $4 = HEAP8[$0>>0]|0;
  $5 = $4 & 1;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   STACKTOP = sp;return ($1|0);
  }
  $7 = (($0) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  __ZdlPv($8);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z46ScriptableObject_CUSTOM_CreateInstanceFromTypeP15ScriptingObject($type) {
 $type = $type|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9Scripting30CreateScriptableObjectWithTypeEP15ScriptingObject($type)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z21Resources_CUSTOM_LoadP15ScriptingStringP15ScriptingObject($path_,$systemTypeInstance) {
 $path_ = $path_|0;
 $systemTypeInstance = $systemTypeInstance|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i3 = 0, $$01 = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $args = 0, $found = 0, $lowerPath = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $o$2 = 0, $path = 0, $pos$i$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $pos$i$i$i$i4 = sp + 72|0;
 $0 = sp;
 $1 = sp + 4|0;
 $path = sp + 8|0;
 $lowerPath = sp + 12|0;
 $2 = sp + 24|0;
 $found = sp + 40|0;
 $args = sp + 48|0;
 __ZN11ICallStringC2EPv($path,$path_);
 __ZN9Scripting11RaiseIfNullEP15ScriptingObject($systemTypeInstance);
 $3 = (__Z39scripting_class_from_systemtypeinstanceP15ScriptingObject($systemTypeInstance)|0);
 __ZNK11ICallString6AsUTF8Ev($2,$path);
 __THREW__ = 0;
 invoke_vii(3282,($lowerPath|0),($2|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  $71 = HEAP8[$2>>0]|0;
  $72 = $71 & 1;
  $73 = ($72<<24>>24)==(0);
  if ($73) {
   $$0 = $69;$$01 = $70;
   ___resumeException($$0|0);
   // unreachable;
  }
  $74 = (($2) + 8|0);
  $75 = HEAP32[$74>>2]|0;
  __ZdlPv($75);
  $$0 = $69;$$01 = $70;
  ___resumeException($$0|0);
  // unreachable;
 }
 $6 = HEAP8[$2>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($2) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 __THREW__ = 0;
 $11 = (invoke_i(108)|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 L11: do {
  if ($13) {
   label = 22;
  } else {
   __THREW__ = 0;
   invoke_viii(1952,($found|0),($11|0),($lowerPath|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 22;
   } else {
    $16 = HEAP32[$found>>2]|0;
    $17 = (($found) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($16|0)==($18|0);
    L14: do {
     if ($19) {
      $o$2 = 0;
     } else {
      $20 = (($args) + 4|0);
      $21 = (($args) + 8|0);
      $22 = (($args) + 12|0);
      $23 = (($args) + 13|0);
      $24 = (($args) + 14|0);
      $25 = (($args) + 16|0);
      $26 = (($args) + 20|0);
      $27 = (($args) + 21|0);
      $28 = (($args) + 22|0);
      $30 = $16;
      L16: while(1) {
       $29 = (($30) + 28|0);
       $31 = HEAP32[$29>>2]|0;
       $32 = ($31|0)==(0);
       do {
        if (!($32)) {
         HEAP32[$0>>2] = $31;
         $33 = HEAP32[560624>>2]|0;
         $34 = ($33|0)==(0|0);
         if ($34) {
          label = 17;
         } else {
          $35 = (($33) + 36|0);
          $36 = HEAP32[$35>>2]|0;
          $37 = (($33) + 4|0);
          $38 = HEAP32[$37>>2]|0;
          $39 = ($36|0)==($38|0);
          do {
           if ($39) {
            $40 = (($33) + 28|0);
            $41 = HEAP32[$40>>2]|0;
            $42 = (($33) + 32|0);
            $43 = HEAP32[$42>>2]|0;
            $44 = (($41) + ($43<<3)|0);
            $60 = $44;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i4,$33,$0);
            $45 = HEAP32[$pos$i$i$i$i4>>2]|0;
            $46 = ($45|0)==(-1);
            $47 = (($33) + 28|0);
            $48 = HEAP32[$47>>2]|0;
            if ($46) {
             $49 = (($33) + 32|0);
             $50 = HEAP32[$49>>2]|0;
             $51 = (($48) + ($50<<3)|0);
             $60 = $51;
             break;
            } else {
             $52 = (($48) + ($45<<3)|0);
             $60 = $52;
             break;
            }
           }
          } while(0);
          $53 = HEAP32[560624>>2]|0;
          $54 = (($53) + 28|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = (($53) + 32|0);
          $57 = HEAP32[$56>>2]|0;
          $58 = (($55) + ($57<<3)|0);
          $59 = ($60|0)==($58|0);
          if ($59) {
           label = 17;
          } else {
           $61 = (($60) + 4|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = ($62|0)==(0|0);
           if ($63) {
            label = 17;
           }
          }
         }
         if ((label|0) == 17) {
          label = 0;
          $64 = HEAP32[$29>>2]|0;
          __THREW__ = 0;
          $65 = (invoke_ii(3215,($64|0))|0);
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           break L16;
          }
          $68 = ($65|0)==(0|0);
          if ($68) {
           break;
          }
         }
         __THREW__ = 0;
         $85 = (invoke_i(108)|0);
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break L16;
         }
         $88 = HEAP32[$29>>2]|0;
         __THREW__ = 0;
         invoke_vii(3283,($85|0),($88|0));
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          break L16;
         }
         $91 = HEAP32[$29>>2]|0;
         $92 = ($91|0)==(0);
         do {
          if ($92) {
           $$0$i3 = 0;
          } else {
           HEAP32[$1>>2] = $91;
           $93 = HEAP32[560624>>2]|0;
           $94 = ($93|0)==(0|0);
           if (!($94)) {
            $95 = (($93) + 36|0);
            $96 = HEAP32[$95>>2]|0;
            $97 = (($93) + 4|0);
            $98 = HEAP32[$97>>2]|0;
            $99 = ($96|0)==($98|0);
            do {
             if ($99) {
              $100 = (($93) + 28|0);
              $101 = HEAP32[$100>>2]|0;
              $102 = (($93) + 32|0);
              $103 = HEAP32[$102>>2]|0;
              $104 = (($101) + ($103<<3)|0);
              $120 = $104;
             } else {
              __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i4,$93,$1);
              $105 = HEAP32[$pos$i$i$i$i4>>2]|0;
              $106 = ($105|0)==(-1);
              $107 = (($93) + 28|0);
              $108 = HEAP32[$107>>2]|0;
              if ($106) {
               $109 = (($93) + 32|0);
               $110 = HEAP32[$109>>2]|0;
               $111 = (($108) + ($110<<3)|0);
               $120 = $111;
               break;
              } else {
               $112 = (($108) + ($105<<3)|0);
               $120 = $112;
               break;
              }
             }
            } while(0);
            $113 = HEAP32[560624>>2]|0;
            $114 = (($113) + 28|0);
            $115 = HEAP32[$114>>2]|0;
            $116 = (($113) + 32|0);
            $117 = HEAP32[$116>>2]|0;
            $118 = (($115) + ($117<<3)|0);
            $119 = ($120|0)==($118|0);
            if (!($119)) {
             $121 = (($120) + 4|0);
             $122 = HEAP32[$121>>2]|0;
             $123 = ($122|0)==(0|0);
             if (!($123)) {
              $$0$i3 = $122;
              break;
             }
            }
           }
           $124 = HEAP32[$29>>2]|0;
           __THREW__ = 0;
           $125 = (invoke_ii(3215,($124|0))|0);
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            break L16;
           } else {
            $$0$i3 = $125;
           }
          }
         } while(0);
         __THREW__ = 0;
         $128 = (invoke_ii(3302,($$0$i3|0))|0);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          break L16;
         }
         $131 = ($128|0)==(0|0);
         if (!($131)) {
          __THREW__ = 0;
          $132 = (invoke_ii(3330,($128|0))|0);
          $133 = __THREW__; __THREW__ = 0;
          $134 = $133&1;
          if ($134) {
           break L16;
          }
          __THREW__ = 0;
          $135 = (invoke_iii(2432,($132|0),($3|0))|0);
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           break L16;
          }
          if ($135) {
           $o$2 = $128;
           break L14;
          }
          $138 = ($$0$i3|0)==(0|0);
          if (!($138)) {
           $139 = (($$0$i3) + 8|0);
           $140 = HEAP32[$139>>2]|0;
           $141 = $140 >>> 21;
           $142 = HEAP32[560640>>2]|0;
           $143 = Math_imul($142, $141)|0;
           $144 = (($143) + 1)|0;
           $145 = $144 >> 5;
           $146 = $145 << 5;
           $147 = (($144) - ($146))|0;
           $148 = HEAP32[560632>>2]|0;
           $149 = (($148) + ($145<<2)|0);
           $150 = HEAP32[$149>>2]|0;
           $151 = 1 << $147;
           $152 = $151 & $150;
           $153 = ($152|0)==(0);
           if ($153) {
            break;
           }
           HEAP32[$args>>2] = $$0$i3;
           HEAP32[$20>>2] = $systemTypeInstance;
           HEAP32[$21>>2] = 0;
           HEAP8[$22>>0] = 0;
           HEAP8[$23>>0] = 1;
           HEAP8[$24>>0] = 1;
           HEAP32[$25>>2] = 0;
           HEAP8[$26>>0] = 1;
           HEAP8[$27>>0] = 0;
           HEAP8[$28>>0] = 0;
           __THREW__ = 0;
           $154 = (invoke_ii(3331,($args|0))|0);
           $155 = __THREW__; __THREW__ = 0;
           $156 = $155&1;
           if ($156) {
            break L16;
           }
           $157 = ($154|0)==(0|0);
           if (!($157)) {
            $o$2 = $154;
            break L14;
           }
          }
         }
        }
       } while(0);
       $158 = (($30) + 4|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = ($159|0)==(0|0);
       if ($160) {
        $$01$i$i$i$i = $30;
        while(1) {
         $163 = (($$01$i$i$i$i) + 8|0);
         $164 = HEAP32[$163>>2]|0;
         $165 = HEAP32[$164>>2]|0;
         $166 = ($165|0)==($$01$i$i$i$i|0);
         if ($166) {
          $$0$i$i$i$i = $164;
          break;
         } else {
          $$01$i$i$i$i = $164;
         }
        }
       } else {
        $$0$i$i$i$i$i = $159;
        while(1) {
         $161 = HEAP32[$$0$i$i$i$i$i>>2]|0;
         $162 = ($161|0)==(0|0);
         if ($162) {
          $$0$i$i$i$i = $$0$i$i$i$i$i;
          break;
         } else {
          $$0$i$i$i$i$i = $161;
         }
        }
       }
       $167 = HEAP32[$17>>2]|0;
       $168 = ($$0$i$i$i$i|0)==($167|0);
       if ($168) {
        $o$2 = 0;
        break L14;
       } else {
        $30 = $$0$i$i$i$i;
       }
      }
      $76 = ___cxa_find_matching_catch()|0;
      $77 = tempRet0;
      $lpad$phi$index = $76;$lpad$phi$index2 = $77;
      break L11;
     }
    } while(0);
    $169 = HEAP8[$lowerPath>>0]|0;
    $170 = $169 & 1;
    $171 = ($170<<24>>24)==(0);
    if ($171) {
     STACKTOP = sp;return ($o$2|0);
    }
    $172 = (($lowerPath) + 8|0);
    $173 = HEAP32[$172>>2]|0;
    __ZdlPv($173);
    STACKTOP = sp;return ($o$2|0);
   }
  }
 } while(0);
 if ((label|0) == 22) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  $lpad$phi$index = $78;$lpad$phi$index2 = $79;
 }
 $80 = HEAP8[$lowerPath>>0]|0;
 $81 = $80 & 1;
 $82 = ($81<<24>>24)==(0);
 if ($82) {
  $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
  ___resumeException($$0|0);
  // unreachable;
 }
 $83 = (($lowerPath) + 8|0);
 $84 = HEAP32[$83>>2]|0;
 __ZdlPv($84);
 $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __Z42Register_UnityEngine_LayerMask_LayerToNamev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(680888,3332);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_LayerMask_NameToLayerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(680928,3333);
 STACKTOP = sp;return;
}
function __Z47Register_UnityEngine_Coroutine_ReleaseCoroutinev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(680968,3611);
 STACKTOP = sp;return;
}
function __Z69Register_UnityEngine_ScriptableObject_Internal_CreateScriptableObjectv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681008,3612);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_ScriptableObject_CreateInstancev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681072,3334);
 STACKTOP = sp;return;
}
function __Z60Register_UnityEngine_ScriptableObject_CreateInstanceFromTypev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681120,3335);
 STACKTOP = sp;return;
}
function __Z35Register_UnityEngine_Resources_Loadv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681176,2541);
 STACKTOP = sp;return;
}
function __Z32Renderer_Get_Custom_PropMaterialP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (__ZN8Renderer32GetAndAssignInstantiatedMaterialEib($1,0,0)|0);
   $5 = (__ZN9Scripting19ScriptingWrapperForEP6Object($4)|0);
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return 0|0;
}
function __Z27Screen_Get_Custom_PropWidthv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetScreenManagerv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z28Screen_Get_Custom_PropHeightv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetScreenManagerv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z42Register_UnityEngine_Renderer_get_materialv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681208,3336);
 STACKTOP = sp;return;
}
function __Z37Register_UnityEngine_Screen_get_widthv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681248,109);
 STACKTOP = sp;return;
}
function __Z38Register_UnityEngine_Screen_get_heightv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681280,110);
 STACKTOP = sp;return;
}
function __Z37GUILayer_CUSTOM_INTERNAL_CALL_HitTestP15ScriptingObjectRK8Vector3f($self_,$screenPosition) {
 $self_ = $self_|0;
 $screenPosition = $screenPosition|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  $5 = Math_fround(HEAPF32[$screenPosition>>2]);
  $6 = (($screenPosition) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  HEAPF32[$0>>2] = $5;
  $8 = (($0) + 4|0);
  HEAPF32[$8>>2] = $7;
  $9 = (__ZN8GUILayer7HitTestERK8Vector2f($2,$0)|0);
  $10 = (__ZN9Scripting19ScriptingWrapperForEP6Object($9)|0);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __Z51Register_UnityEngine_GUILayer_INTERNAL_CALL_HitTestv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681312,2542);
 STACKTOP = sp;return;
}
function __Z20Gradient_CUSTOM_InitP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(68)|0);
 __THREW__ = 0;
 invoke_vi(3551,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($self_) + 8|0);
  HEAP32[$3>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __Z23Gradient_CUSTOM_CleanupP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($self_) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZdlPv($2);
  ___resumeException($6|0);
  // unreachable;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __Z34Register_UnityEngine_Gradient_Initv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681360,3613);
 STACKTOP = sp;return;
}
function __Z37Register_UnityEngine_Gradient_Cleanupv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681392,3614);
 STACKTOP = sp;return;
}
function __Z26GUI_Set_Custom_PropChangedh($value) {
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z11GetGUIStatev()|0);
 $1 = ($value<<24>>24)!=(0);
 $2 = $1&1;
 $3 = (($0) + 64|0);
 HEAP32[$3>>2] = $2;
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_GUI_set_changedv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681424,3615);
 STACKTOP = sp;return;
}
function __Z46GUILayoutUtility_CUSTOM_Internal_GetWindowRecti($agg$result,$windowID) {
 $agg$result = $agg$result|0;
 $windowID = $windowID|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z11GetGUIStatev()|0);
 __ZN5IMGUI13GetWindowRectER8GUIStatei($agg$result,$0,$windowID);
 STACKTOP = sp;return;
}
function __Z57GUILayoutUtility_CUSTOM_INTERNAL_CALL_Internal_MoveWindowiRK5RectTIfE($windowID,$r) {
 $windowID = $windowID|0;
 $r = $r|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z11GetGUIStatev()|0);
 __ZN5IMGUI20MoveWindowFromLayoutER8GUIStateiRK5RectTIfE($0,$windowID,$r);
 STACKTOP = sp;return;
}
function __Z60Register_UnityEngine_GUILayoutUtility_Internal_GetWindowRectv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681456,3284);
 STACKTOP = sp;return;
}
function __Z71Register_UnityEngine_GUILayoutUtility_INTERNAL_CALL_Internal_MoveWindowv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681512,3285);
 STACKTOP = sp;return;
}
function __Z41GUIUtility_CUSTOM_Internal_GetDefaultSkini($skinMode) {
 $skinMode = $skinMode|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14GetDefaultSkini($skinMode)|0);
 $1 = (($0) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __Z34GUIUtility_CUSTOM_Internal_ExitGUIv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z38GUIUtility_CUSTOM_Internal_GetGUIDepthv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z11GetGUIStatev()|0);
 $1 = (($0) + 328|0);
 $2 = HEAP32[$1>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __Z55Register_UnityEngine_GUIUtility_Internal_GetDefaultSkinv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681576,3337);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_GUIUtility_Internal_ExitGUIv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681624,188);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_GUIUtility_Internal_GetGUIDepthv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681672,111);
 STACKTOP = sp;return;
}
function __Z28GUIStyleState_CUSTOM_CleanupP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   __ZdlPv($2);
  }
 }
 STACKTOP = sp;return;
}
function __Z42GUIStyleState_CUSTOM_GetBackgroundInternalP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = HEAP32[$2>>2]|0;
   $5 = (__Z33TransferPPtrToMonoObjectUnCheckedi24TransferInstructionFlags($4,8388608)|0);
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z43GUIStyleState_CUSTOM_INTERNAL_set_textColorP15ScriptingObjectRK10ColorRGBAf($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
  // unreachable;
 }
 $1 = (($self_) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
  // unreachable;
 } else {
  $4 = Math_fround(HEAPF32[$value>>2]);
  $5 = (($value) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($value) + 8|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($value) + 12|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($2) + 4|0);
  HEAPF32[$11>>2] = $4;
  $12 = (($2) + 8|0);
  HEAPF32[$12>>2] = $6;
  $13 = (($2) + 12|0);
  HEAPF32[$13>>2] = $8;
  $14 = (($2) + 16|0);
  HEAPF32[$14>>2] = $10;
  STACKTOP = sp;return;
 }
}
function __Z22RectOffset_CUSTOM_InitP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(16)|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $1 = (($self_) + 8|0);
 HEAP32[$1>>2] = $0;
 STACKTOP = sp;return;
}
function __Z25RectOffset_CUSTOM_CleanupP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   __ZdlPv($2);
  }
 }
 STACKTOP = sp;return;
}
function __Z30RectOffset_Get_Custom_PropLeftP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = HEAP32[$2>>2]|0;
   STACKTOP = sp;return ($4|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z30RectOffset_Set_Custom_PropLeftP15ScriptingObjecti($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   HEAP32[$2>>2] = $value;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
}
function __Z31RectOffset_Get_Custom_PropRightP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z31RectOffset_Set_Custom_PropRightP15ScriptingObjecti($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 4|0);
   HEAP32[$4>>2] = $value;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
}
function __Z29RectOffset_Get_Custom_PropTopP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z29RectOffset_Set_Custom_PropTopP15ScriptingObjecti($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 8|0);
   HEAP32[$4>>2] = $value;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
}
function __Z32RectOffset_Get_Custom_PropBottomP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z32RectOffset_Set_Custom_PropBottomP15ScriptingObjecti($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 12|0);
   HEAP32[$4>>2] = $value;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
}
function __Z36RectOffset_Get_Custom_PropHorizontalP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = HEAP32[$2>>2]|0;
   $5 = (($2) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + ($4))|0;
   STACKTOP = sp;return ($7|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z34RectOffset_Get_Custom_PropVerticalP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($2) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + ($5))|0;
   STACKTOP = sp;return ($8|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z20GUIStyle_CUSTOM_InitP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(292)|0);
 __THREW__ = 0;
 invoke_vi(3550,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZdlPv($0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($self_) + 8|0);
  HEAP32[$3>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __Z23GUIStyle_CUSTOM_CleanupP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($self_) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP8[$3>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($3) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($9|0),($$byval_copy|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   ___cxa_call_unexpected(($12|0));
   // unreachable;
  }
 }
 __ZdlPv($3);
 STACKTOP = sp;return;
}
function __Z28GUIStyle_Get_Custom_PropNameP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
  // unreachable;
 }
 $2 = (($self_) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
  // unreachable;
 }
 $5 = HEAP8[$3>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $8 = (($3) + 1|0);
  $9 = $5&255;
  $10 = $9 >>> 1;
  $17 = $10;$27 = $8;
 } else {
  $11 = (($3) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($3) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14>>>0)>(4294967279);
  if ($15) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $17 = $14;$27 = $12;
  }
 }
 $16 = ($17>>>0)<(11);
 if ($16) {
  $18 = $17 << 1;
  $19 = $18&255;
  HEAP8[$0>>0] = $19;
  $20 = (($0) + 1|0);
  $__p$0$i$i$i$i = $20;
 } else {
  $21 = (($17) + 16)|0;
  $22 = $21 & -16;
  $23 = (__Znwj($22)|0);
  $24 = (($0) + 8|0);
  HEAP32[$24>>2] = $23;
  $25 = $22 | 1;
  HEAP32[$0>>2] = $25;
  $26 = (($0) + 4|0);
  HEAP32[$26>>2] = $17;
  $__p$0$i$i$i$i = $23;
 }
 _memcpy(($__p$0$i$i$i$i|0),($27|0),($17|0))|0;
 $28 = (($__p$0$i$i$i$i) + ($17)|0);
 HEAP8[$28>>0] = 0;
 __THREW__ = 0;
 $29 = (invoke_ii(3338,($0|0))|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  $39 = HEAP8[$0>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   ___resumeException($37|0);
   // unreachable;
  }
  $42 = (($0) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  __ZdlPv($43);
  ___resumeException($37|0);
  // unreachable;
 } else {
  $32 = HEAP8[$0>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   STACKTOP = sp;return ($29|0);
  }
  $35 = (($0) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  __ZdlPv($36);
  STACKTOP = sp;return ($29|0);
 }
 return 0|0;
}
function __Z28GUIStyle_Set_Custom_PropNameP15ScriptingObjectP15ScriptingString($self_,$value_) {
 $self_ = $self_|0;
 $value_ = $value_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i$i = 0;
 var $value = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $value = sp + 16|0;
 $0 = sp + 4|0;
 __ZN11ICallStringC2EPv($value,$value_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
  // unreachable;
 }
 $2 = (($self_) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
  // unreachable;
 }
 __ZNK11ICallString6AsUTF8Ev($0,$value);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $12 = (($0) + 1|0);
  $13 = $5&255;
  $14 = $13 >>> 1;
  $23 = $14;$31 = $12;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $23 = $11;$31 = $9;
 }
 $15 = HEAP8[$3>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $22 = 10;$25 = $15;
 } else {
  $18 = HEAP32[$3>>2]|0;
  $19 = $18 & -2;
  $phitmp$i$i = (($19) + -1)|0;
  $20 = $18&255;
  $22 = $phitmp$i$i;$25 = $20;
 }
 $21 = ($22>>>0)<($23>>>0);
 $24 = $25 & 1;
 $26 = ($24<<24>>24)==(0);
 do {
  if ($21) {
   if ($26) {
    $41 = $25&255;
    $42 = $41 >>> 1;
    $44 = $42;
   } else {
    $39 = (($3) + 4|0);
    $40 = HEAP32[$39>>2]|0;
    $44 = $40;
   }
   $43 = (($23) - ($22))|0;
   __THREW__ = 0;
   invoke_viiiiiiii(22,($3|0),($22|0),($43|0),($44|0),0,($44|0),($23|0),($31|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    $54 = HEAP8[$0>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if ($56) {
     ___resumeException($52|0);
     // unreachable;
    }
    $57 = (($0) + 8|0);
    $58 = HEAP32[$57>>2]|0;
    __ZdlPv($58);
    ___resumeException($52|0);
    // unreachable;
   }
  } else {
   if ($26) {
    $29 = (($3) + 1|0);
    $30 = $29;
   } else {
    $27 = (($3) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $30 = $28;
   }
   _memmove(($30|0),($31|0),($23|0))|0;
   $32 = (($30) + ($23)|0);
   HEAP8[$32>>0] = 0;
   $33 = HEAP8[$3>>0]|0;
   $34 = $33 & 1;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    $37 = $23 << 1;
    $38 = $37&255;
    HEAP8[$3>>0] = $38;
    break;
   } else {
    $36 = (($3) + 4|0);
    HEAP32[$36>>2] = $23;
    break;
   }
  }
 } while(0);
 $47 = HEAP8[$0>>0]|0;
 $48 = $47 & 1;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  STACKTOP = sp;return;
 }
 $50 = (($0) + 8|0);
 $51 = HEAP32[$50>>2]|0;
 __ZdlPv($51);
 STACKTOP = sp;return;
}
function __Z32GUIStyle_CUSTOM_GetStyleStatePtrP15ScriptingObjecti($self_,$idx) {
 $self_ = $self_|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 12|0);
   $5 = (($4) + (($idx*20)|0)|0);
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z32GUIStyle_CUSTOM_GetRectOffsetPtrP15ScriptingObjecti($self_,$idx) {
 $self_ = $self_|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 172|0);
   $5 = (($4) + ($idx<<4)|0);
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z34GUIStyle_Get_Custom_PropFixedWidthP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 272|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   STACKTOP = sp;return (Math_fround($5));
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return Math_fround(0);
}
function __Z35GUIStyle_Get_Custom_PropFixedHeightP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 276|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   STACKTOP = sp;return (Math_fround($5));
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return Math_fround(0);
}
function __Z36GUIStyle_Get_Custom_PropStretchWidthP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 288|0);
   $5 = HEAP8[$4>>0]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z36GUIStyle_Set_Custom_PropStretchWidthP15ScriptingObjecth($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($value<<24>>24)!=(0);
 $1 = ($self_|0)==(0|0);
 if (!($1)) {
  $2 = (($self_) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($3) + 288|0);
   $6 = $0&1;
   HEAP8[$5>>0] = $6;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
}
function __Z37GUIStyle_Get_Custom_PropStretchHeightP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 289|0);
   $5 = HEAP8[$4>>0]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z37GUIStyle_Set_Custom_PropStretchHeightP15ScriptingObjecth($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($value<<24>>24)!=(0);
 $1 = ($self_|0)==(0|0);
 if (!($1)) {
  $2 = (($self_) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($3) + 289|0);
   $6 = $0&1;
   HEAP8[$5>>0] = $6;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(682808,$vararg_buffer);
 // unreachable;
}
function __Z30GUIStyle_CUSTOM_SetDefaultFontP15ScriptingObject($font_) {
 $font_ = $font_|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($font_|0)==(0|0);
 if ($0) {
  $$0$i$i = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($font_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $$0$i$i = 0;
  } else {
   $$0$i$i = $1;
  }
 }
 __ZN8GUIStyle14SetDefaultFontEPN13TextRendering4FontE($$0$i$i);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_GUIStyleState_Cleanupv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681720,3616);
 STACKTOP = sp;return;
}
function __Z56Register_UnityEngine_GUIStyleState_GetBackgroundInternalv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681760,3339);
 STACKTOP = sp;return;
}
function __Z57Register_UnityEngine_GUIStyleState_INTERNAL_set_textColorv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681816,3286);
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_RectOffset_Initv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681872,3617);
 STACKTOP = sp;return;
}
function __Z39Register_UnityEngine_RectOffset_Cleanupv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681904,3618);
 STACKTOP = sp;return;
}
function __Z40Register_UnityEngine_RectOffset_get_leftv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681936,3340);
 STACKTOP = sp;return;
}
function __Z40Register_UnityEngine_RectOffset_set_leftv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(681976,3287);
 STACKTOP = sp;return;
}
function __Z41Register_UnityEngine_RectOffset_get_rightv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682016,3341);
 STACKTOP = sp;return;
}
function __Z41Register_UnityEngine_RectOffset_set_rightv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682056,3288);
 STACKTOP = sp;return;
}
function __Z39Register_UnityEngine_RectOffset_get_topv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682096,3342);
 STACKTOP = sp;return;
}
function __Z39Register_UnityEngine_RectOffset_set_topv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682128,3289);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_RectOffset_get_bottomv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682160,3343);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_RectOffset_set_bottomv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682200,3290);
 STACKTOP = sp;return;
}
function __Z46Register_UnityEngine_RectOffset_get_horizontalv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682240,3344);
 STACKTOP = sp;return;
}
function __Z44Register_UnityEngine_RectOffset_get_verticalv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682280,3345);
 STACKTOP = sp;return;
}
function __Z34Register_UnityEngine_GUIStyle_Initv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682320,3619);
 STACKTOP = sp;return;
}
function __Z37Register_UnityEngine_GUIStyle_Cleanupv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682352,3620);
 STACKTOP = sp;return;
}
function __Z38Register_UnityEngine_GUIStyle_get_namev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682384,3346);
 STACKTOP = sp;return;
}
function __Z38Register_UnityEngine_GUIStyle_set_namev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682416,3291);
 STACKTOP = sp;return;
}
function __Z46Register_UnityEngine_GUIStyle_GetStyleStatePtrv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682448,2543);
 STACKTOP = sp;return;
}
function __Z46Register_UnityEngine_GUIStyle_GetRectOffsetPtrv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682488,2544);
 STACKTOP = sp;return;
}
function __Z44Register_UnityEngine_GUIStyle_get_fixedWidthv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682528,227);
 STACKTOP = sp;return;
}
function __Z45Register_UnityEngine_GUIStyle_get_fixedHeightv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682568,228);
 STACKTOP = sp;return;
}
function __Z46Register_UnityEngine_GUIStyle_get_stretchWidthv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682608,3347);
 STACKTOP = sp;return;
}
function __Z46Register_UnityEngine_GUIStyle_set_stretchWidthv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682648,3292);
 STACKTOP = sp;return;
}
function __Z47Register_UnityEngine_GUIStyle_get_stretchHeightv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682688,3348);
 STACKTOP = sp;return;
}
function __Z47Register_UnityEngine_GUIStyle_set_stretchHeightv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682728,3293);
 STACKTOP = sp;return;
}
function __Z44Register_UnityEngine_GUIStyle_SetDefaultFontv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682768,3621);
 STACKTOP = sp;return;
}
function __Z17Event_CUSTOM_InitP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(44)|0);
 $1 = (($0) + 4|0);
 $2 = (($0) + 40|0);
 HEAP32[$2>>2] = 0;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 $3 = (($self_) + 8|0);
 HEAP32[$3>>2] = $0;
 __ZN10InputEvent4InitEv($0);
 STACKTOP = sp;return;
}
function __Z20Event_CUSTOM_CleanupP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($self_) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3498,($2|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZdlPv($2);
  ___resumeException($6|0);
  // unreachable;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __Z25Event_Get_Custom_PropTypeP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (__Z11GetGUIStatev()|0);
 $1 = ($self_|0)==(0|0);
 if (!($1)) {
  $2 = (($self_) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN5IMGUI12GetEventTypeERK8GUIStateRK10InputEvent($0,$3)|0);
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(683160,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z38Event_CUSTOM_Internal_GetMousePositionP15ScriptingObjectP13Vector2fIcall($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(683160,$vararg_buffer);
  // unreachable;
 }
 $1 = (($self_) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(683160,$vararg_buffer);
  // unreachable;
 } else {
  $4 = (($2) + 4|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($2) + 8|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (HEAPF32[tempDoublePtr>>2]=$5,HEAP32[tempDoublePtr>>2]|0);
  $9 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
  $10 = $value;
  $11 = $10;
  HEAP32[$11>>2] = $8;
  $12 = (($10) + 4)|0;
  $13 = $12;
  HEAP32[$13>>2] = $9;
  STACKTOP = sp;return;
 }
}
function __Z30Event_Get_Custom_PropModifiersP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 24|0);
   $5 = HEAP32[$4>>2]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(683160,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z30Event_Get_Custom_PropCharacterP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 36|0);
   $5 = HEAP16[$4>>1]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(683160,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z32Event_Get_Custom_PropCommandNameP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 40|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   $7 = $6 ? 682816 : $5;
   $8 = (__Z20scripting_string_newPKc($7)|0);
   STACKTOP = sp;return ($8|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(683160,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z28Event_Get_Custom_PropKeyCodeP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 38|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = $5&65535;
   STACKTOP = sp;return ($6|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(683160,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z36Event_CUSTOM_Internal_SetNativeEvent6IntPtr($ptr_) {
 $ptr_ = $ptr_|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ptr_>>2]|0;
 $1 = (__Z11GetGUIStatev()|0);
 __ZN8GUIState24Internal_SetManagedEventEPv($1,$0);
 STACKTOP = sp;return;
}
function __Z31Register_UnityEngine_Event_Initv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682824,3622);
 STACKTOP = sp;return;
}
function __Z34Register_UnityEngine_Event_Cleanupv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682848,3623);
 STACKTOP = sp;return;
}
function __Z35Register_UnityEngine_Event_get_typev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682880,3349);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Event_Internal_GetMousePositionv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682912,3294);
 STACKTOP = sp;return;
}
function __Z40Register_UnityEngine_Event_get_modifiersv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(682960,3350);
 STACKTOP = sp;return;
}
function __Z40Register_UnityEngine_Event_get_characterv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683000,3351);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_Event_get_commandNamev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683040,3352);
 STACKTOP = sp;return;
}
function __Z38Register_UnityEngine_Event_get_keyCodev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683080,3353);
 STACKTOP = sp;return;
}
function __Z50Register_UnityEngine_Event_Internal_SetNativeEventv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683112,3624);
 STACKTOP = sp;return;
}
function __Z34Vector3_CUSTOM_INTERNAL_CALL_SlerpRK8Vector3fS1_f($agg$result,$from,$to,$t) {
 $agg$result = $agg$result|0;
 $from = $from|0;
 $to = $to|0;
 $t = Math_fround($t);
 var $$$i = Math_fround(0), $$0$i = Math_fround(0), $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $t < Math_fround(0.0);
 if ($0) {
  $$0$i = Math_fround(0.0);
 } else {
  $1 = $t > Math_fround(1.0);
  $$$i = $1 ? Math_fround(1.0) : $t;
  $$0$i = $$$i;
 }
 __Z5SlerpRK8Vector3fS1_f($agg$result,$from,$to,$$0$i);
 STACKTOP = sp;return;
}
function __Z42Vector3_CUSTOM_INTERNAL_CALL_RotateTowardsRK8Vector3fS1_ff($agg$result,$current,$target,$maxRadiansDelta,$maxMagnitudeDelta) {
 $agg$result = $agg$result|0;
 $current = $current|0;
 $target = $target|0;
 $maxRadiansDelta = Math_fround($maxRadiansDelta);
 $maxMagnitudeDelta = Math_fround($maxMagnitudeDelta);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z13RotateTowardsRK8Vector3fS1_ff($agg$result,$current,$target,$maxRadiansDelta,$maxMagnitudeDelta);
 STACKTOP = sp;return;
}
function __Z46Quaternion_CUSTOM_INTERNAL_CALL_FromToRotationRK8Vector3fS1_($agg$result,$fromDirection,$toDirection) {
 $agg$result = $agg$result|0;
 $fromDirection = $fromDirection|0;
 $toDirection = $toDirection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z20FromToQuaternionSafeRK8Vector3fS1_($agg$result,$fromDirection,$toDirection);
 STACKTOP = sp;return;
}
function __Z44Quaternion_CUSTOM_INTERNAL_CALL_LookRotationRK8Vector3fS1_($agg$result,$forward,$upwards) {
 $agg$result = $agg$result|0;
 $forward = $forward|0;
 $upwards = $upwards|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $3 = 0;
 var $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $m = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $m = sp + 12|0;
 $0 = sp;
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $1 = (($agg$result) + 4|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($agg$result) + 8|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($agg$result) + 12|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (__Z24LookRotationToQuaternionRK8Vector3fS1_P11Quaternionf($forward,$upwards,$agg$result)|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = Math_fround(HEAPF32[$forward>>2]);
 $6 = Math_fround($5 * $5);
 $7 = (($forward) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($8 * $8);
 $10 = Math_fround($6 + $9);
 $11 = (($forward) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $12);
 $14 = Math_fround($10 + $13);
 $15 = (Math_fround(Math_sqrt((Math_fround($14)))));
 $16 = Math_fround(HEAPF32[616648>>2]);
 $17 = $15 > $16;
 if ($17) {
  ;HEAP32[$0+0>>2]=HEAP32[$forward+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$forward+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$forward+8>>2]|0;
  $18 = Math_fround(HEAPF32[$0>>2]);
  $19 = Math_fround($18 / $15);
  HEAPF32[$0>>2] = $19;
  $20 = (($0) + 4|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($21 / $15);
  HEAPF32[$20>>2] = $22;
  $23 = (($0) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($24 / $15);
  HEAPF32[$23>>2] = $25;
  (__ZN10Matrix3x3f17SetFromToRotationERK8Vector3fS2_($m,616744,$0)|0);
  __Z18MatrixToQuaternionRK10Matrix3x3fR11Quaternionf($m,$agg$result);
  STACKTOP = sp;return;
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(683168,0,683208,78,4,0,0,0);
  STACKTOP = sp;return;
 }
}
function __Z39Quaternion_CUSTOM_INTERNAL_CALL_InverseRK11Quaternionf($agg$result,$rotation) {
 $agg$result = $agg$result|0;
 $rotation = $rotation|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$rotation>>2]);
 $1 = Math_fround(-$0);
 $2 = (($rotation) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(-$3);
 $5 = (($rotation) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 $8 = (($rotation) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$agg$result>>2] = $1;
 $10 = (($agg$result) + 4|0);
 HEAPF32[$10>>2] = $4;
 $11 = (($agg$result) + 8|0);
 HEAPF32[$11>>2] = $7;
 $12 = (($agg$result) + 12|0);
 HEAPF32[$12>>2] = $9;
 STACKTOP = sp;return;
}
function __Z51Quaternion_CUSTOM_INTERNAL_CALL_Internal_ToEulerRadRK11Quaternionf($agg$result,$rotation) {
 $agg$result = $agg$result|0;
 $rotation = $rotation|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $outRotation = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $outRotation = sp;
 $0 = Math_fround(HEAPF32[$rotation>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($rotation) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($rotation) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (($rotation) + 12|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (Math_fround(Math_sqrt((Math_fround($13)))));
 $15 = Math_fround(HEAPF32[616648>>2]);
 $16 = $14 < $15;
 if ($16) {
  HEAPF32[$outRotation>>2] = Math_fround(0.0);
  $17 = (($outRotation) + 4|0);
  HEAPF32[$17>>2] = Math_fround(0.0);
  $18 = (($outRotation) + 8|0);
  HEAPF32[$18>>2] = Math_fround(0.0);
  $19 = (($outRotation) + 12|0);
  HEAPF32[$19>>2] = Math_fround(1.0);
  __Z17QuaternionToEulerRK11Quaternionf($agg$result,$outRotation);
  STACKTOP = sp;return;
 } else {
  $20 = Math_fround($0 / $14);
  $21 = Math_fround($3 / $14);
  $22 = Math_fround($7 / $14);
  $23 = Math_fround($11 / $14);
  HEAPF32[$outRotation>>2] = $20;
  $24 = (($outRotation) + 4|0);
  HEAPF32[$24>>2] = $21;
  $25 = (($outRotation) + 8|0);
  HEAPF32[$25>>2] = $22;
  $26 = (($outRotation) + 12|0);
  HEAPF32[$26>>2] = $23;
  __Z17QuaternionToEulerRK11Quaternionf($agg$result,$outRotation);
  STACKTOP = sp;return;
 }
}
function __Z53Quaternion_CUSTOM_INTERNAL_CALL_Internal_FromEulerRadRK8Vector3f($agg$result,$euler) {
 $agg$result = $agg$result|0;
 $euler = $euler|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z17EulerToQuaternionRK8Vector3f($agg$result,$euler);
 STACKTOP = sp;return;
}
function __Z38Matrix4x4_CUSTOM_INTERNAL_CALL_InverseRK10Matrix4x4f($agg$result,$m) {
 $agg$result = $agg$result|0;
 $m = $m|0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 dest=$agg$result+0|0; src=$m+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 (__Z20InvertMatrix4x4_FullPKfPf($agg$result,$agg$result)|0);
 STACKTOP = sp;return;
}
function __Z40Matrix4x4_CUSTOM_INTERNAL_CALL_TransposeRK10Matrix4x4f($agg$result,$m) {
 $agg$result = $agg$result|0;
 $m = $m|0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 dest=$agg$result+0|0; src=$m+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 (__ZN10Matrix4x4f9TransposeEv($agg$result)|0);
 STACKTOP = sp;return;
}
function __Z37Matrix4x4_CUSTOM_INTERNAL_CALL_InvertRK10Matrix4x4fPS_($inMatrix,$dest) {
 $inMatrix = $inMatrix|0;
 $dest = $dest|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20InvertMatrix4x4_FullPKfPf($inMatrix,$dest)|0);
 $1 = $0&1;
 STACKTOP = sp;return ($1|0);
}
function __Z35Matrix4x4_Get_Custom_PropIsIdentity10Matrix4x4f($self) {
 $self = $self|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[616648>>2]);
 $1 = (__ZNK10Matrix4x4f10IsIdentityEf($self,$0)|0);
 $2 = $1&1;
 STACKTOP = sp;return ($2|0);
}
function __Z34Matrix4x4_CUSTOM_INTERNAL_CALL_TRSRK8Vector3fRK11QuaternionfS1_($agg$result,$pos,$q,$s) {
 $agg$result = $agg$result|0;
 $pos = $pos|0;
 $q = $q|0;
 $s = $s|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($agg$result,$pos,$q,$s);
 STACKTOP = sp;return;
}
function __Z22Matrix4x4_CUSTOM_Orthoffffff($agg$result,$left,$right,$bottom,$top,$zNear,$zFar) {
 $agg$result = $agg$result|0;
 $left = Math_fround($left);
 $right = Math_fround($right);
 $bottom = Math_fround($bottom);
 $top = Math_fround($top);
 $zNear = Math_fround($zNear);
 $zFar = Math_fround($zFar);
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN10Matrix4x4f8SetOrthoEffffff($agg$result,$left,$right,$bottom,$top,$zNear,$zFar)|0);
 STACKTOP = sp;return;
}
function __Z28Matrix4x4_CUSTOM_Perspectiveffff($agg$result,$fov,$aspect,$zNear,$zFar) {
 $agg$result = $agg$result|0;
 $fov = Math_fround($fov);
 $aspect = Math_fround($aspect);
 $zNear = Math_fround($zNear);
 $zFar = Math_fround($zFar);
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN10Matrix4x4f14SetPerspectiveEffff($agg$result,$fov,$aspect,$zNear,$zFar)|0);
 STACKTOP = sp;return;
}
function __Z45Bounds_CUSTOM_INTERNAL_CALL_Internal_ContainsRK4AABBRK8Vector3f($m,$point) {
 $m = $m|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK4AABB8IsInsideERK8Vector3f($m,$point)|0);
 $1 = $0&1;
 STACKTOP = sp;return ($1|0);
}
function __Z48Bounds_CUSTOM_INTERNAL_CALL_Internal_SqrDistanceRK4AABBRK8Vector3f($m,$point) {
 $m = $m|0;
 $point = $point|0;
 var $0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($point,$m)));
 STACKTOP = sp;return (Math_fround($0));
}
function __Z49Bounds_CUSTOM_INTERNAL_CALL_Internal_IntersectRayR3RayR4AABBPf($ray,$bounds,$distance) {
 $ray = $ray|0;
 $bounds = $bounds|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16IntersectRayAABBRK3RayRK4AABBPf($ray,$bounds,$distance)|0);
 $1 = $0&1;
 STACKTOP = sp;return ($1|0);
}
function __Z52Bounds_CUSTOM_INTERNAL_CALL_Internal_GetClosestPointR4AABBR8Vector3f($agg$result,$bounds,$point) {
 $agg$result = $agg$result|0;
 $bounds = $bounds|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $outSqrDistance = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $outSqrDistance = sp;
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $0 = (($agg$result) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($agg$result) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 __Z21CalculateClosestPointRK8Vector3fRK4AABBRS_Rf($point,$bounds,$agg$result,$outSqrDistance);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_Vector3_INTERNAL_CALL_Slerpv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683216,8);
 STACKTOP = sp;return;
}
function __Z56Register_UnityEngine_Vector3_INTERNAL_CALL_RotateTowardsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683264,1);
 STACKTOP = sp;return;
}
function __Z60Register_UnityEngine_Quaternion_INTERNAL_CALL_FromToRotationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683320,1953);
 STACKTOP = sp;return;
}
function __Z58Register_UnityEngine_Quaternion_INTERNAL_CALL_LookRotationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683376,1954);
 STACKTOP = sp;return;
}
function __Z53Register_UnityEngine_Quaternion_INTERNAL_CALL_Inversev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683432,3295);
 STACKTOP = sp;return;
}
function __Z65Register_UnityEngine_Quaternion_INTERNAL_CALL_Internal_ToEulerRadv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683480,3296);
 STACKTOP = sp;return;
}
function __Z67Register_UnityEngine_Quaternion_INTERNAL_CALL_Internal_FromEulerRadv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683544,3297);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Matrix4x4_INTERNAL_CALL_Inversev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683608,3298);
 STACKTOP = sp;return;
}
function __Z54Register_UnityEngine_Matrix4x4_INTERNAL_CALL_Transposev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683656,3299);
 STACKTOP = sp;return;
}
function __Z51Register_UnityEngine_Matrix4x4_INTERNAL_CALL_Invertv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683704,2545);
 STACKTOP = sp;return;
}
function __Z45Register_UnityEngine_Matrix4x4_get_isIdentityv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683752,3354);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_Matrix4x4_INTERNAL_CALL_TRSv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683792,404);
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_Matrix4x4_Orthov() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683840,1);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_Matrix4x4_Perspectivev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683872,6);
 STACKTOP = sp;return;
}
function __Z59Register_UnityEngine_Bounds_INTERNAL_CALL_Internal_Containsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683912,2546);
 STACKTOP = sp;return;
}
function __Z62Register_UnityEngine_Bounds_INTERNAL_CALL_Internal_SqrDistancev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(683968,54);
 STACKTOP = sp;return;
}
function __Z63Register_UnityEngine_Bounds_INTERNAL_CALL_Internal_IntersectRayv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684024,1574);
 STACKTOP = sp;return;
}
function __Z66Register_UnityEngine_Bounds_INTERNAL_CALL_Internal_GetClosestPointv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684080,1955);
 STACKTOP = sp;return;
}
function __Z29TextAsset_Get_Custom_PropTextP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $4 = (($1) + 40|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (($1) + 41|0);
  $11 = $10;
  $12 = (__Z20scripting_string_newPKc($11)|0);
  STACKTOP = sp;return ($12|0);
 } else {
  $8 = (($1) + 48|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
  $12 = (__Z20scripting_string_newPKc($11)|0);
  STACKTOP = sp;return ($12|0);
 }
 return 0|0;
}
function __Z39Register_UnityEngine_TextAsset_get_textv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684144,3355);
 STACKTOP = sp;return;
}
function __Z26Shader_CUSTOM_PropertyToIDP15ScriptingString($name_) {
 $name_ = $name_|0;
 var $0 = 0, $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $name = sp;
 __ZN11ICallStringC2EPv($name,$name_);
 $0 = (__Z25ScriptingStringToPropertyR11ICallString($name)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z38Material_CUSTOM_INTERNAL_CALL_SetColorP15ScriptingObjectiRK10ColorRGBAf($self_,$nameID,$color) {
 $self_ = $self_|0;
 $nameID = $nameID|0;
 $color = $color|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  HEAP32[$0>>2] = $nameID;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($2,$$byval_copy,$color);
  STACKTOP = sp;return;
 }
}
function __Z24Material_CUSTOM_GetColorP15ScriptingObjecti($agg$result,$self_,$nameID) {
 $agg$result = $agg$result|0;
 $self_ = $self_|0;
 $nameID = $nameID|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  HEAP32[$0>>2] = $nameID;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN5Unity8Material8GetColorEN9ShaderLab16FastPropertyNameE($agg$result,$2,$$byval_copy);
  STACKTOP = sp;return;
 }
}
function __Z24Material_CUSTOM_SetFloatP15ScriptingObjectif($self_,$nameID,$value) {
 $self_ = $self_|0;
 $nameID = $nameID|0;
 $value = Math_fround($value);
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  HEAP32[$0>>2] = $nameID;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __ZN5Unity8Material8SetFloatEN9ShaderLab16FastPropertyNameEf($2,$$byval_copy,$value);
  STACKTOP = sp;return;
 }
}
function __Z35Material_Set_Custom_PropRenderQueueP15ScriptingObjecti($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZN5Unity8Material20SetCustomRenderQueueEi($1,$value);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z29Material_CUSTOM_EnableKeywordP15ScriptingObjectP15ScriptingString($self_,$keyword_) {
 $self_ = $self_|0;
 $keyword_ = $keyword_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $keyword = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $keyword = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($keyword,$keyword_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$keyword);
 __THREW__ = 0;
 invoke_vii(3300,($2|0),($0|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __Z30Material_CUSTOM_DisableKeywordP15ScriptingObjectP15ScriptingString($self_,$keyword_) {
 $self_ = $self_|0;
 $keyword_ = $keyword_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $keyword = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $keyword = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($keyword,$keyword_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$keyword);
 __THREW__ = 0;
 invoke_vii(3301,($2|0),($0|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __Z40Register_UnityEngine_Shader_PropertyToIDv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684176,3356);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Material_INTERNAL_CALL_SetColorv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684216,1956);
 STACKTOP = sp;return;
}
function __Z38Register_UnityEngine_Material_GetColorv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684264,1957);
 STACKTOP = sp;return;
}
function __Z38Register_UnityEngine_Material_SetFloatv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684296,43);
 STACKTOP = sp;return;
}
function __Z45Register_UnityEngine_Material_set_renderQueuev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684328,3302);
 STACKTOP = sp;return;
}
function __Z43Register_UnityEngine_Material_EnableKeywordv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684368,3303);
 STACKTOP = sp;return;
}
function __Z44Register_UnityEngine_Material_DisableKeywordv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684408,3304);
 STACKTOP = sp;return;
}
function __Z37AsyncOperation_CUSTOM_InternalDestroyP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   __ZN14AsyncOperation7ReleaseEv($2);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(684496,$vararg_buffer);
 // unreachable;
}
function __Z51Register_UnityEngine_AsyncOperation_InternalDestroyv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684448,3625);
 STACKTOP = sp;return;
}
function __Z40Application_CUSTOM_Internal_ExternalCallP15ScriptingString($script_) {
 $script_ = $script_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $script = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $script = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($script,$script_);
 __ZNK11ICallString6AsUTF8Ev($0,$script);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 __THREW__ = 0;
 invoke_vi(3626,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP8[$0>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   ___resumeException($15|0);
   // unreachable;
  }
  $20 = (($0) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  __ZdlPv($21);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $10 = HEAP8[$0>>0]|0;
  $11 = $10 & 1;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   STACKTOP = sp;return;
  }
  $13 = (($0) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  __ZdlPv($14);
  STACKTOP = sp;return;
 }
}
function __Z54Register_UnityEngine_Application_Internal_ExternalCallv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684504,3627);
 STACKTOP = sp;return;
}
function __Z32Behaviour_Set_Custom_PropEnabledP15ScriptingObjecth($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = HEAP32[$1>>2]|0;
   $5 = (($4) + 120|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($value<<24>>24)!=(0);
   FUNCTION_TABLE_vii[$6 & 4095]($1,$7);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z42Register_UnityEngine_Behaviour_set_enabledv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684552,3305);
 STACKTOP = sp;return;
}
function __Z35Camera_Get_Custom_PropNearClipPlaneP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 456|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   STACKTOP = sp;return (Math_fround($5));
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return Math_fround(0);
}
function __Z34Camera_Get_Custom_PropFarClipPlaneP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 460|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   STACKTOP = sp;return (Math_fround($5));
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return Math_fround(0);
}
function __Z33Camera_Get_Custom_PropCullingMaskP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 412|0);
   $5 = HEAP32[$4>>2]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return 0|0;
}
function __Z31Camera_Get_Custom_PropEventMaskP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 416|0);
   $5 = HEAP32[$4>>2]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return 0|0;
}
function __Z36Camera_CUSTOM_INTERNAL_get_pixelRectP15ScriptingObjectR5RectTIfE($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  __ZNK6Camera13GetCameraRectEb($0,$2,1);
  ;HEAP32[$value+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$value+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$value+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$value+12>>2]=HEAP32[$0+12>>2]|0;
  STACKTOP = sp;return;
 }
}
function __Z35Camera_Get_Custom_PropTargetTextureP15ScriptingObject($com_) {
 $com_ = $com_|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = ($com_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($com_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $com_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $5 = (($2) + 292|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $$0$i$i = 0;
  $41 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i$i)|0);
  STACKTOP = sp;return ($41|0);
 }
 HEAP32[$0>>2] = $6;
 $8 = HEAP32[560624>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 13;
 } else {
  $10 = (($8) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($8) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  do {
   if ($14) {
    $15 = (($8) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($8) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + ($18<<3)|0);
    $35 = $19;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$8,$0);
    $20 = HEAP32[$pos$i$i$i$i>>2]|0;
    $21 = ($20|0)==(-1);
    $22 = (($8) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    if ($21) {
     $24 = (($8) + 32|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($23) + ($25<<3)|0);
     $35 = $26;
     break;
    } else {
     $27 = (($23) + ($20<<3)|0);
     $35 = $27;
     break;
    }
   }
  } while(0);
  $28 = HEAP32[560624>>2]|0;
  $29 = (($28) + 28|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 32|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + ($32<<3)|0);
  $34 = ($35|0)==($33|0);
  if ($34) {
   label = 13;
  } else {
   $36 = (($35) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    label = 13;
   } else {
    $temp$0$i$i = $37;
   }
  }
 }
 if ((label|0) == 13) {
  $39 = HEAP32[$5>>2]|0;
  $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
  $temp$0$i$i = $40;
 }
 $$0$i$i = $temp$0$i$i;
 $41 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i$i)|0);
 STACKTOP = sp;return ($41|0);
}
function __Z32Camera_Get_Custom_PropClearFlagsP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 376|0);
   $5 = HEAP32[$4>>2]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return 0|0;
}
function __Z46Camera_CUSTOM_INTERNAL_CALL_ViewportPointToRayP15ScriptingObjectRK8Vector3f($agg$result,$self_,$position) {
 $agg$result = $agg$result|0;
 $self_ = $self_|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  $5 = Math_fround(HEAPF32[$position>>2]);
  $6 = (($position) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  HEAPF32[$0>>2] = $5;
  $8 = (($0) + 4|0);
  HEAPF32[$8>>2] = $7;
  __ZNK6Camera18ViewportPointToRayERK8Vector2f($agg$result,$2,$0);
  STACKTOP = sp;return;
 }
}
function __Z44Camera_CUSTOM_INTERNAL_CALL_ScreenPointToRayP15ScriptingObjectRK8Vector3f($agg$result,$self_,$position) {
 $agg$result = $agg$result|0;
 $self_ = $self_|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  $5 = Math_fround(HEAPF32[$position>>2]);
  $6 = (($position) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  HEAPF32[$0>>2] = $5;
  $8 = (($0) + 4|0);
  HEAPF32[$8>>2] = $7;
  __ZNK6Camera16ScreenPointToRayERK8Vector2f($agg$result,$2,$0);
  STACKTOP = sp;return;
 }
}
function __Z26Camera_Get_Custom_PropMainv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14FindMainCamerav()|0);
 $1 = (__ZN9Scripting19ScriptingWrapperForEP6Object($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z37Camera_Get_Custom_PropAllCamerasCountv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetRenderManagerv()|0);
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z16GetRenderManagerv()|0);
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2))|0;
 STACKTOP = sp;return ($6|0);
}
function __Z27Camera_CUSTOM_GetAllCamerasP14ScriptingArray($cameras) {
 $cameras = $cameras|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 __ZN9Scripting11RaiseIfNullEPv($cameras);
 $0 = (__Z21GetScriptingArraySizeP14ScriptingArray($cameras)|0);
 $1 = (__Z16GetRenderManagerv()|0);
 $2 = (($1) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z16GetRenderManagerv()|0);
 $5 = (($4) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($3))|0;
 $8 = ($0|0)<($7|0);
 if ($8) {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(684592,$vararg_buffer);
  // unreachable;
 } else {
  $9 = (__Z16GetRenderManagerv()|0);
  $10 = (($9) + 4|0);
  $11 = (__Z34FillScriptingArrayFromUnityObjectsINSt3__14listI4PPtrI6CameraENS0_9allocatorIS4_EEEEEiP14ScriptingArrayRKT_i($cameras,$10,0)|0);
  $12 = (__Z16GetRenderManagerv()|0);
  $13 = (($12) + 16|0);
  $14 = (__Z34FillScriptingArrayFromUnityObjectsINSt3__14listI4PPtrI6CameraENS0_9allocatorIS4_EEEEEiP14ScriptingArrayRKT_i($cameras,$13,$11)|0);
  $15 = (($14) + ($11))|0;
  STACKTOP = sp;return ($15|0);
 }
 return 0|0;
}
function __Z38Camera_CUSTOM_INTERNAL_CALL_RaycastTryP15ScriptingObjectRK3Rayfi($self_,$ray,$distance,$layerMask) {
 $self_ = $self_|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $layerMask = $layerMask|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $normalizedRay = 0, $or$cond = 0, $rayHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $normalizedRay = sp + 48|0;
 $rayHit = sp;
 $0 = (__Z19GetRaycastInterfacev()|0);
 $1 = ($0|0)==(0|0);
 $2 = $distance < Math_fround(1.1920928955078125E-7);
 $or$cond = $1 | $2;
 if ($or$cond) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $3 = (($ray) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $4);
 $6 = (($ray) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (($ray) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (Math_fround(Math_sqrt((Math_fround($13)))));
 $15 = Math_fround(HEAPF32[616648>>2]);
 $16 = !($14 <= $15);
 if (!($16)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $17 = Math_fround($4 / $14);
 $18 = Math_fround($7 / $14);
 $19 = Math_fround($11 / $14);
 ;HEAP32[$normalizedRay+0>>2]=0|0;HEAP32[$normalizedRay+4>>2]=0|0;HEAP32[$normalizedRay+8>>2]=0|0;HEAP32[$normalizedRay+12>>2]=0|0;HEAP32[$normalizedRay+16>>2]=0|0;
 ;HEAP32[$normalizedRay+0>>2]=HEAP32[$ray+0>>2]|0;HEAP32[$normalizedRay+4>>2]=HEAP32[$ray+4>>2]|0;HEAP32[$normalizedRay+8>>2]=HEAP32[$ray+8>>2]|0;
 $20 = (($normalizedRay) + 12|0);
 HEAPF32[$20>>2] = $17;
 $21 = (($normalizedRay) + 16|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($normalizedRay) + 20|0);
 HEAPF32[$22>>2] = $19;
 $23 = (($rayHit) + 32|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($rayHit) + 36|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 ;HEAP32[$rayHit+0>>2]=0|0;HEAP32[$rayHit+4>>2]=0|0;HEAP32[$rayHit+8>>2]=0|0;HEAP32[$rayHit+12>>2]=0|0;HEAP32[$rayHit+16>>2]=0|0;HEAP32[$rayHit+20>>2]=0|0;
 $25 = HEAP32[$0>>2]|0;
 $26 = (($25) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($self_|0)==(0|0);
 if ($28) {
  $31 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($31);
  // unreachable;
 }
 $29 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $30 = ($29|0)==(0|0);
 if ($30) {
  $31 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($31);
  // unreachable;
 }
 $32 = (($29) + 412|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $35 = ($34|0)==(0|0);
 if ($35) {
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($self_);
  // unreachable;
 }
 $36 = (($34) + 416|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $33 & -3;
 $39 = $38 & $37;
 $40 = (FUNCTION_TABLE_iiifii[$27 & 1]($0,$normalizedRay,$distance,$39,$rayHit)|0);
 if (!($40)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $41 = HEAP32[$0>>2]|0;
 $42 = (($41) + 20|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (FUNCTION_TABLE_iii[$43 & 4095]($0,$rayHit)|0);
 $45 = ($44|0)==(0|0);
 if ($45) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $46 = (__ZN9Scripting19ScriptingWrapperForEP6Object($44)|0);
 $$1 = $46;
 STACKTOP = sp;return ($$1|0);
}
function __Z40Camera_CUSTOM_INTERNAL_CALL_RaycastTry2DP15ScriptingObjectRK3Rayfi($self_,$ray,$distance,$layerMask) {
 $self_ = $self_|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $layerMask = $layerMask|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $normalizedRay = 0, $or$cond = 0, $rayHit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $normalizedRay = sp + 40|0;
 $rayHit = sp;
 $0 = (__Z13GetIPhysics2Dv()|0);
 $1 = ($0|0)==(0|0);
 $2 = $distance < Math_fround(1.1920928955078125E-7);
 $or$cond = $1 | $2;
 if ($or$cond) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $3 = (($ray) + 12|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * $4);
 $6 = (($ray) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (($ray) + 20|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (Math_fround(Math_sqrt((Math_fround($13)))));
 $15 = Math_fround(HEAPF32[616648>>2]);
 $16 = !($14 <= $15);
 if (!($16)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $17 = Math_fround($4 / $14);
 $18 = Math_fround($7 / $14);
 $19 = Math_fround($11 / $14);
 ;HEAP32[$normalizedRay+0>>2]=0|0;HEAP32[$normalizedRay+4>>2]=0|0;HEAP32[$normalizedRay+8>>2]=0|0;HEAP32[$normalizedRay+12>>2]=0|0;HEAP32[$normalizedRay+16>>2]=0|0;
 ;HEAP32[$normalizedRay+0>>2]=HEAP32[$ray+0>>2]|0;HEAP32[$normalizedRay+4>>2]=HEAP32[$ray+4>>2]|0;HEAP32[$normalizedRay+8>>2]=HEAP32[$ray+8>>2]|0;
 $20 = (($normalizedRay) + 12|0);
 HEAPF32[$20>>2] = $17;
 $21 = (($normalizedRay) + 16|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($normalizedRay) + 20|0);
 HEAPF32[$22>>2] = $19;
 ;HEAP32[$rayHit+0>>2]=0|0;HEAP32[$rayHit+4>>2]=0|0;HEAP32[$rayHit+8>>2]=0|0;HEAP32[$rayHit+12>>2]=0|0;HEAP32[$rayHit+16>>2]=0|0;HEAP32[$rayHit+20>>2]=0|0;
 $23 = HEAP32[$0>>2]|0;
 $24 = (($23) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($self_|0)==(0|0);
 if ($26) {
  $29 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($29);
  // unreachable;
 }
 $27 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $28 = ($27|0)==(0|0);
 if ($28) {
  $29 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($29);
  // unreachable;
 }
 $30 = (($27) + 412|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $33 = ($32|0)==(0|0);
 if ($33) {
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($self_);
  // unreachable;
 }
 $34 = (($32) + 416|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $31 & -3;
 $37 = $36 & $35;
 $38 = (FUNCTION_TABLE_iiifii[$25 & 1]($0,$normalizedRay,$distance,$37,$rayHit)|0);
 if (!($38)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $39 = HEAP32[$0>>2]|0;
 $40 = (($39) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (FUNCTION_TABLE_iii[$41 & 4095]($0,$rayHit)|0);
 $43 = ($42|0)==(0|0);
 if ($43) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $44 = (__ZN9Scripting19ScriptingWrapperForEP6Object($42)|0);
 $$1 = $44;
 STACKTOP = sp;return ($$1|0);
}
function __Z45Register_UnityEngine_Camera_get_nearClipPlanev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684728,229);
 STACKTOP = sp;return;
}
function __Z44Register_UnityEngine_Camera_get_farClipPlanev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684768,230);
 STACKTOP = sp;return;
}
function __Z43Register_UnityEngine_Camera_get_cullingMaskv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684808,3357);
 STACKTOP = sp;return;
}
function __Z41Register_UnityEngine_Camera_get_eventMaskv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684848,3358);
 STACKTOP = sp;return;
}
function __Z50Register_UnityEngine_Camera_INTERNAL_get_pixelRectv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684888,3306);
 STACKTOP = sp;return;
}
function __Z45Register_UnityEngine_Camera_get_targetTexturev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684936,3359);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_Camera_get_clearFlagsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(684976,3360);
 STACKTOP = sp;return;
}
function __Z60Register_UnityEngine_Camera_INTERNAL_CALL_ViewportPointToRayv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685016,1958);
 STACKTOP = sp;return;
}
function __Z58Register_UnityEngine_Camera_INTERNAL_CALL_ScreenPointToRayv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685072,1959);
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_Camera_get_mainv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685128,112);
 STACKTOP = sp;return;
}
function __Z47Register_UnityEngine_Camera_get_allCamerasCountv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685160,113);
 STACKTOP = sp;return;
}
function __Z41Register_UnityEngine_Camera_GetAllCamerasv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685200,3361);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Camera_INTERNAL_CALL_RaycastTryv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685240,4);
 STACKTOP = sp;return;
}
function __Z54Register_UnityEngine_Camera_INTERNAL_CALL_RaycastTry2Dv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685288,5);
 STACKTOP = sp;return;
}
function __Z34FillScriptingArrayFromUnityObjectsINSt3__14listI4PPtrI6CameraENS0_9allocatorIS4_EEEEEiP14ScriptingArrayRKT_i($array,$container,$offset) {
 $array = $array|0;
 $container = $container|0;
 $offset = $offset|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$0$lcssa = 0, $i$03 = 0, $i$12 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($container) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z21GetScriptingArraySizeP14ScriptingArray($array)|0);
 $4 = (($container) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($container|0);
 if ($6) {
  $i$0$lcssa = $offset;
 } else {
  $9 = $5;$i$03 = $offset;
  while(1) {
   $8 = (($9) + 8|0);
   $10 = HEAP32[$8>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    $$0$i = 0;
   } else {
    HEAP32[$0>>2] = $10;
    $12 = HEAP32[560624>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 13;
    } else {
     $14 = (($12) + 36|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($12) + 4|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($15|0)==($17|0);
     do {
      if ($18) {
       $19 = (($12) + 28|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($12) + 32|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + ($22<<3)|0);
       $39 = $23;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$12,$0);
       $24 = HEAP32[$pos$i$i$i$i>>2]|0;
       $25 = ($24|0)==(-1);
       $26 = (($12) + 28|0);
       $27 = HEAP32[$26>>2]|0;
       if ($25) {
        $28 = (($12) + 32|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = (($27) + ($29<<3)|0);
        $39 = $30;
        break;
       } else {
        $31 = (($27) + ($24<<3)|0);
        $39 = $31;
        break;
       }
      }
     } while(0);
     $32 = HEAP32[560624>>2]|0;
     $33 = (($32) + 28|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + 32|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($34) + ($36<<3)|0);
     $38 = ($39|0)==($37|0);
     if ($38) {
      label = 13;
     } else {
      $40 = (($39) + 4|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41|0)==(0|0);
      if ($42) {
       label = 13;
      } else {
       $temp$0$i = $41;
      }
     }
    }
    if ((label|0) == 13) {
     label = 0;
     $43 = HEAP32[$8>>2]|0;
     $44 = (__Z31ReadObjectFromPersistentManageri($43)|0);
     $temp$0$i = $44;
    }
    $$0$i = $temp$0$i;
   }
   $45 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i)|0);
   __ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject($array,$i$03,$45);
   $46 = (($i$03) + 1)|0;
   $47 = (($9) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($container|0);
   if ($49) {
    $i$0$lcssa = $46;
    break;
   } else {
    $9 = $48;$i$03 = $46;
   }
  }
 }
 $7 = ($i$0$lcssa|0)<($3|0);
 if ($7) {
  $i$12 = $i$0$lcssa;
 } else {
  STACKTOP = sp;return ($2|0);
 }
 while(1) {
  $50 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($array,$i$12,4)|0);
  HEAP32[$50>>2] = 0;
  $51 = (($i$12) + 1)|0;
  $exitcond = ($51|0)==($3|0);
  if ($exitcond) {
   break;
  } else {
   $i$12 = $51;
  }
 }
 STACKTOP = sp;return ($2|0);
}
function __Z35Debug_CUSTOM_INTERNAL_CALL_DrawLineRK8Vector3fS1_RK10ColorRGBAffh($start,$end,$color,$duration,$depthTest) {
 $start = $start|0;
 $end = $end|0;
 $color = $color|0;
 $duration = Math_fround($duration);
 $depthTest = $depthTest|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z25Debug_CUSTOM_Internal_LogiP15ScriptingStringP15ScriptingObject($level,$msg_,$obj_) {
 $level = $level|0;
 $msg_ = $msg_|0;
 $obj_ = $obj_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $msg = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $msg = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($msg,$msg_);
 __ZNK11ICallString6AsUTF8Ev($0,$msg);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $12 = $6;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $12 = $5;
 }
 $7 = ($level|0)==(0);
 if ($7) {
  $13 = 17408;
 } else {
  $8 = ($level|0)==(1);
  $phitmp = $8 ? 16896 : 16640;
  $13 = $phitmp;
 }
 __THREW__ = 0;
 $9 = (invoke_ii(3362,($obj_|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  invoke_viiiiiiii(21,($12|0),0,(685336|0),62,($13|0),($9|0),0,(0|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $16 = HEAP8[$0>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    STACKTOP = sp;return;
   }
   $19 = (($0) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   __ZdlPv($20);
   STACKTOP = sp;return;
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $23 = HEAP8[$0>>0]|0;
 $24 = $23 & 1;
 $25 = ($24<<24>>24)==(0);
 if ($25) {
  ___resumeException($21|0);
  // unreachable;
 }
 $26 = (($0) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 __ZdlPv($27);
 ___resumeException($21|0);
 // unreachable;
}
function __Z49Register_UnityEngine_Debug_INTERNAL_CALL_DrawLinev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685440,4);
 STACKTOP = sp;return;
}
function __Z39Register_UnityEngine_Debug_Internal_Logv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685488,1960);
 STACKTOP = sp;return;
}
function __Z31Display_CUSTOM_GetSystemExtImpl6IntPtrPiS0_($nativeDisplay_,$w,$h) {
 $nativeDisplay_ = $nativeDisplay_|0;
 $w = $w|0;
 $h = $h|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetScreenManagerv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 HEAP32[$w>>2] = $4;
 $5 = (__Z16GetScreenManagerv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 HEAP32[$h>>2] = $9;
 STACKTOP = sp;return;
}
function __Z34Display_CUSTOM_GetRenderingExtImpl6IntPtrPiS0_($nativeDisplay_,$w,$h) {
 $nativeDisplay_ = $nativeDisplay_|0;
 $w = $w|0;
 $h = $h|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetScreenManagerv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($0)|0);
 HEAP32[$w>>2] = $4;
 $5 = (__Z16GetScreenManagerv()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 HEAP32[$h>>2] = $9;
 STACKTOP = sp;return;
}
function __Z38Display_CUSTOM_GetRenderingBuffersImpl6IntPtrP21ScriptingRenderBufferS1_($nativeDisplay_,$color,$depth) {
 $nativeDisplay_ = $nativeDisplay_|0;
 $color = $color|0;
 $depth = $depth|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($color) + 4|0);
 $1 = (($depth) + 4|0);
 HEAP32[$1>>2] = 0;
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __Z41Display_CUSTOM_SetRenderingResolutionImpl6IntPtrii($nativeDisplay_,$w,$h) {
 $nativeDisplay_ = $nativeDisplay_|0;
 $w = $w|0;
 $h = $h|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetScreenManagerv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__Z16GetScreenManagerv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 FUNCTION_TABLE_viiiii[$3 & 255]($0,$w,$h,$8,0);
 STACKTOP = sp;return;
}
function __Z34Display_CUSTOM_ActivateDisplayImpl6IntPtriii($nativeDisplay_,$width,$height,$refreshRate) {
 $nativeDisplay_ = $nativeDisplay_|0;
 $width = $width|0;
 $height = $height|0;
 $refreshRate = $refreshRate|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z28Display_CUSTOM_SetParamsImpl6IntPtriiii($nativeDisplay_,$width,$height,$x,$y) {
 $nativeDisplay_ = $nativeDisplay_|0;
 $width = $width|0;
 $height = $height|0;
 $x = $x|0;
 $y = $y|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z38Display_CUSTOM_MultiDisplayLicenseImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z34Display_CUSTOM_RelativeMouseAtImpliiPiS_($x,$y,$rx,$ry) {
 $x = $x|0;
 $y = $y|0;
 $rx = $rx|0;
 $ry = $ry|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z45Register_UnityEngine_Display_GetSystemExtImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685520,1961);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_Display_GetRenderingExtImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685560,1962);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Display_GetRenderingBuffersImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685608,1963);
 STACKTOP = sp;return;
}
function __Z55Register_UnityEngine_Display_SetRenderingResolutionImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685656,1964);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_Display_ActivateDisplayImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685704,405);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_Display_SetParamsImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685752,107);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Display_MultiDisplayLicenseImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685792,114);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_Display_RelativeMouseAtImplv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685840,257);
 STACKTOP = sp;return;
}
function __Z40MonoBehaviour_CUSTOM_StartCoroutine_AutoP15ScriptingObjectS0_($self_,$routine) {
 $self_ = $self_|0;
 $routine = $routine|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 __ZN9Scripting11RaiseIfNullEP15ScriptingObject($routine);
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $4 = (($1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(685888,$vararg_buffer);
  // unreachable;
 }
 $7 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($self_);
  // unreachable;
 }
 $9 = (($7) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 >>> 21;
 $12 = HEAP32[560640>>2]|0;
 $13 = Math_imul($12, $11)|0;
 $14 = (($13) + 114)|0;
 $15 = $14 >> 5;
 $16 = $15 << 5;
 $17 = (($14) - ($16))|0;
 $18 = HEAP32[560632>>2]|0;
 $19 = (($18) + ($15<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = 1 << $17;
 $22 = $21 & $20;
 $23 = ($22|0)==(0);
 if ($23) {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(685888,$vararg_buffer);
  // unreachable;
 }
 $24 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $25 = ($24|0)==(0|0);
 if ($25) {
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($self_);
  // unreachable;
 } else {
  $26 = (__ZN13MonoBehaviour22StartCoroutineManaged2EP15ScriptingObject($24,$routine)|0);
  STACKTOP = sp;return ($26|0);
 }
 return 0|0;
}
function __Z54Register_UnityEngine_MonoBehaviour_StartCoroutine_Autov() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(685944,2547);
 STACKTOP = sp;return;
}
function __Z22Input_CUSTOM_GetKeyInti($key) {
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $key$off = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $key$off = (($key) + -1)|0;
 $0 = ($key$off>>>0)<(569);
 if ($0) {
  $1 = (__Z15GetInputManagerv()|0);
  $2 = $key >>> 5;
  $3 = (($1) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($2<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $key & 31;
  $8 = 1 << $7;
  $9 = (($1) + 40|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($2<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 | $6;
  $14 = $13 & $8;
  $15 = ($14|0)!=(0);
  $16 = $15&1;
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = ($key|0)==(0);
 if ($17) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(685992,$vararg_buffer);
  // unreachable;
 }
 return 0|0;
}
function __Z20Input_CUSTOM_GetAxisP15ScriptingString($axisName_) {
 $axisName_ = $axisName_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $axisName = 0, $name = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $axisName = sp + 12|0;
 $name = sp;
 __ZN11ICallStringC2EPv($axisName,$axisName_);
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($name,$axisName);
 __THREW__ = 0;
 $0 = (invoke_i(55)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fii(55,($0|0),($name|0)))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP8[$name>>0]|0;
   $7 = $6 & 1;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    STACKTOP = sp;return (Math_fround($3));
   }
   $9 = (($name) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   __ZdlPv($10);
   STACKTOP = sp;return (Math_fround($3));
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $13 = HEAP8[$name>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  ___resumeException($11|0);
  // unreachable;
 }
 $16 = (($name) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 __ZdlPv($17);
 ___resumeException($11|0);
 // unreachable;
 return Math_fround(0);
}
function __Z23Input_CUSTOM_GetAxisRawP15ScriptingString($axisName_) {
 $axisName_ = $axisName_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $axisName = 0, $name = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $axisName = sp + 12|0;
 $name = sp;
 __ZN11ICallStringC2EPv($axisName,$axisName_);
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($name,$axisName);
 __THREW__ = 0;
 $0 = (invoke_i(55)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fii(56,($0|0),($name|0)))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP8[$name>>0]|0;
   $7 = $6 & 1;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    STACKTOP = sp;return (Math_fround($3));
   }
   $9 = (($name) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   __ZdlPv($10);
   STACKTOP = sp;return (Math_fround($3));
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $13 = HEAP8[$name>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  ___resumeException($11|0);
  // unreachable;
 }
 $16 = (($name) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 __ZdlPv($17);
 ___resumeException($11|0);
 // unreachable;
 return Math_fround(0);
}
function __Z22Input_CUSTOM_GetButtonP15ScriptingString($buttonName_) {
 $buttonName_ = $buttonName_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buttonName = 0;
 var $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buttonName = sp + 12|0;
 $name = sp;
 __ZN11ICallStringC2EPv($buttonName,$buttonName_);
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($name,$buttonName);
 __THREW__ = 0;
 $0 = (invoke_i(55)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2548,($0|0),($name|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3&1;
   $7 = HEAP8[$name>>0]|0;
   $8 = $7 & 1;
   $9 = ($8<<24>>24)==(0);
   if ($9) {
    STACKTOP = sp;return ($6|0);
   }
   $10 = (($name) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   __ZdlPv($11);
   STACKTOP = sp;return ($6|0);
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $14 = HEAP8[$name>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  ___resumeException($12|0);
  // unreachable;
 }
 $17 = (($name) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 __ZdlPv($18);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z26Input_CUSTOM_GetButtonDownP15ScriptingString($buttonName_) {
 $buttonName_ = $buttonName_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buttonName = 0;
 var $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buttonName = sp + 12|0;
 $name = sp;
 __ZN11ICallStringC2EPv($buttonName,$buttonName_);
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($name,$buttonName);
 __THREW__ = 0;
 $0 = (invoke_i(55)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2549,($0|0),($name|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3&1;
   $7 = HEAP8[$name>>0]|0;
   $8 = $7 & 1;
   $9 = ($8<<24>>24)==(0);
   if ($9) {
    STACKTOP = sp;return ($6|0);
   }
   $10 = (($name) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   __ZdlPv($11);
   STACKTOP = sp;return ($6|0);
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $14 = HEAP8[$name>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  ___resumeException($12|0);
  // unreachable;
 }
 $17 = (($name) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 __ZdlPv($18);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z27Input_CUSTOM_GetMouseButtoni($button) {
 $button = $button|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($button>>>0)<(7);
 if ($0) {
  $1 = (__Z15GetInputManagerv()|0);
  $2 = (($button) + 323)|0;
  $3 = $2 >>> 5;
  $4 = (($1) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($3<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $2 & 31;
  $9 = 1 << $8;
  $10 = (($1) + 40|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + ($3<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 | $7;
  $15 = $14 & $9;
  $16 = ($15|0)!=(0);
  $17 = $16&1;
  STACKTOP = sp;return ($17|0);
 } else {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(686016,$vararg_buffer);
  // unreachable;
 }
 return 0|0;
}
function __Z31Input_CUSTOM_GetMouseButtonDowni($button) {
 $button = $button|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($button>>>0)<(7);
 if ($0) {
  $1 = (__Z15GetInputManagerv()|0);
  $2 = (($button) + 323)|0;
  $3 = $2 >>> 5;
  $4 = (($1) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($3<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $2 & 31;
  $9 = 1 << $8;
  $10 = $7 & $9;
  $11 = ($10|0)!=(0);
  $12 = $11&1;
  STACKTOP = sp;return ($12|0);
 } else {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(686016,$vararg_buffer);
  // unreachable;
 }
 return 0|0;
}
function __Z27Input_CUSTOM_ResetInputAxesv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z34Input_Get_Custom_PropMousePositionv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetInputManagerv()|0);
 $1 = (($0) + 100|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($0) + 104|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$agg$result>>2] = $2;
 $5 = (($agg$result) + 4|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($agg$result) + 8|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_Input_GetKeyIntv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686048,3363);
 STACKTOP = sp;return;
}
function __Z34Register_UnityEngine_Input_GetAxisv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686080,231);
 STACKTOP = sp;return;
}
function __Z37Register_UnityEngine_Input_GetAxisRawv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686112,232);
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_Input_GetButtonv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686144,3364);
 STACKTOP = sp;return;
}
function __Z40Register_UnityEngine_Input_GetButtonDownv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686176,3365);
 STACKTOP = sp;return;
}
function __Z41Register_UnityEngine_Input_GetMouseButtonv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686216,3366);
 STACKTOP = sp;return;
}
function __Z45Register_UnityEngine_Input_GetMouseButtonDownv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686256,3367);
 STACKTOP = sp;return;
}
function __Z41Register_UnityEngine_Input_ResetInputAxesv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686296,189);
 STACKTOP = sp;return;
}
function __Z44Register_UnityEngine_Input_get_mousePositionv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686336,3628);
 STACKTOP = sp;return;
}
function __Z21Object_CUSTOM_DestroyP15ScriptingObjectf($obj_,$t) {
 $obj_ = $obj_|0;
 $t = Math_fround($t);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($obj_|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 0;
 } else {
  $2 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($obj_)|0);
  HEAP32[$0>>2] = $2;
 }
 __ZN9Scripting26DestroyObjectFromScriptingE4PPtrI6ObjectEf($0,$t);
 STACKTOP = sp;return;
}
function __Z26Object_Get_Custom_PropNameP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = HEAP32[$1>>2]|0;
   $5 = (($4) + 32|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (FUNCTION_TABLE_ii[$6 & 4095]($1)|0);
   $8 = (__Z20scripting_string_newPKc($7)|0);
   STACKTOP = sp;return ($8|0);
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return 0|0;
}
function __Z26Object_Set_Custom_PropNameP15ScriptingObjectP15ScriptingString($self_,$value_) {
 $self_ = $self_|0;
 $value_ = $value_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($value,$value_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $5 = HEAP32[$2>>2]|0;
 $6 = (($5) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 __ZNK11ICallString6AsUTF8Ev($0,$value);
 $8 = HEAP8[$0>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $13 = (($0) + 1|0);
  $14 = $13;
 } else {
  $11 = (($0) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $14 = $12;
 }
 __THREW__ = 0;
 invoke_vii($7|0,($2|0),($14|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $24 = HEAP8[$0>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   ___resumeException($22|0);
   // unreachable;
  }
  $27 = (($0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __ZdlPv($28);
  ___resumeException($22|0);
  // unreachable;
 } else {
  $17 = HEAP8[$0>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $20 = (($0) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  __ZdlPv($21);
  STACKTOP = sp;return;
 }
}
function __Z22Object_CUSTOM_ToStringP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $$0$i$i = 0;
 } else {
  $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $3 = ($2|0)==(0|0);
  if ($3) {
   $$0$i$i = 0;
  } else {
   $$0$i$i = $2;
  }
 }
 __Z19UnityObjectToStringP6Object($0,$$0$i$i);
 __THREW__ = 0;
 $4 = (invoke_ii(3338,($0|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return ($4|0);
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z35Register_UnityEngine_Object_Destroyv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686376,188);
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_Object_get_namev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686408,3368);
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_Object_set_namev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686440,3307);
 STACKTOP = sp;return;
}
function __Z36Register_UnityEngine_Object_ToStringv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686472,3369);
 STACKTOP = sp;return;
}
function __Z34Component_Get_Custom_PropTransformP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $4 = (($1) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  __ZN9Scripting18RaiseMonoExceptionEPKcz(686504,$vararg_buffer);
  // unreachable;
 }
 $7 = (($5) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $$0$i = $12;
  STACKTOP = sp;return ($$0$i|0);
 }
 $14 = (__ZN9Scripting19ScriptingWrapperForEP6Object($10)|0);
 $$0$i = $14;
 STACKTOP = sp;return ($$0$i|0);
}
function __Z35Component_Get_Custom_PropGameObjectP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 24|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (__ZN9Scripting19ScriptingWrapperForEP6Object($5)|0);
   STACKTOP = sp;return ($6|0);
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return 0|0;
}
function __Z28Component_CUSTOM_SendMessageP15ScriptingObjectP15ScriptingStringS0_i($self_,$methodName_,$value,$options) {
 $self_ = $self_|0;
 $methodName_ = $methodName_|0;
 $value = $value|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $methodName = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $methodName = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($methodName,$methodName_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $5 = (($2) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$methodName);
 __THREW__ = 0;
 (invoke_iiiii(258,($6|0),($0|0),($value|0),($options|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $16 = HEAP8[$0>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   ___resumeException($14|0);
   // unreachable;
  }
  $19 = (($0) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  __ZdlPv($20);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = (($0) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  __ZdlPv($13);
  STACKTOP = sp;return;
 }
}
function __Z44Register_UnityEngine_Component_get_transformv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686560,3370);
 STACKTOP = sp;return;
}
function __Z45Register_UnityEngine_Component_get_gameObjectv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686600,3371);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_Component_SendMessagev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686640,406);
 STACKTOP = sp;return;
}
function __Z33GameObject_CUSTOM_CreatePrimitivei($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15CreatePrimitivei($type)|0);
 $1 = (__ZN9Scripting19ScriptingWrapperForEP6Object($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z30GameObject_CUSTOM_GetComponentP15ScriptingObjectS0_($self_,$type) {
 $self_ = $self_|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $getComponentArgs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $getComponentArgs = sp;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 } else {
  HEAP32[$getComponentArgs>>2] = $1;
  $4 = (($getComponentArgs) + 4|0);
  $5 = (($getComponentArgs) + 8|0);
  HEAP32[$5>>2] = 0;
  $6 = (($getComponentArgs) + 12|0);
  HEAP8[$6>>0] = 0;
  $7 = (($getComponentArgs) + 13|0);
  HEAP8[$7>>0] = 1;
  $8 = (($getComponentArgs) + 14|0);
  HEAP8[$8>>0] = 1;
  $9 = (($getComponentArgs) + 16|0);
  HEAP32[$9>>2] = 0;
  $10 = (($getComponentArgs) + 20|0);
  ;HEAP16[$10+0>>1]=257|0;HEAP8[$10+2>>0]=1|0;
  HEAP32[$4>>2] = $type;
  $11 = (__Z42ScriptingGetComponentsOfTypeFromGameObjectRK26ScriptingGetComponentsArgs($getComponentArgs)|0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z35GameObject_Get_Custom_PropTransformP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
  // unreachable;
 }
 $4 = (($1) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 }
 $11 = (__ZN9Scripting19ScriptingWrapperForEP6Object($7)|0);
 $$0$i = $11;
 STACKTOP = sp;return ($$0$i|0);
}
function __Z29GameObject_Set_Custom_PropTagP15ScriptingObjectP15ScriptingString($self_,$value_) {
 $self_ = $self_|0;
 $value_ = $value_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp;
 __ZN11ICallStringC2EPv($value,$value_);
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (__Z18ExtractTagThrowingR11ICallString($value)|0);
   __ZN5Unity10GameObject6SetTagEj($1,$4);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z29GameObject_CUSTOM_SendMessageP15ScriptingObjectP15ScriptingStringS0_i($self_,$methodName_,$value,$options) {
 $self_ = $self_|0;
 $methodName_ = $methodName_|0;
 $value = $value|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $methodName = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $methodName = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($methodName,$methodName_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$methodName);
 __THREW__ = 0;
 (invoke_iiiii(258,($2|0),($0|0),($value|0),($options|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __Z47Register_UnityEngine_GameObject_CreatePrimitivev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686680,3372);
 STACKTOP = sp;return;
}
function __Z44Register_UnityEngine_GameObject_GetComponentv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686720,2550);
 STACKTOP = sp;return;
}
function __Z45Register_UnityEngine_GameObject_get_transformv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686760,3373);
 STACKTOP = sp;return;
}
function __Z39Register_UnityEngine_GameObject_set_tagv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686800,3308);
 STACKTOP = sp;return;
}
function __Z43Register_UnityEngine_GameObject_SendMessagev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686832,407);
 STACKTOP = sp;return;
}
function __Z38Transform_CUSTOM_INTERNAL_get_positionP15ScriptingObjectR8Vector3f($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
 } else {
  $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $3 = ($2|0)==(0|0);
  if ($3) {
   $4 = $self_;
  } else {
   __ZNK9Transform11GetPositionEv($0,$2);
   ;HEAP32[$value+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$value+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$value+8>>2]=HEAP32[$0+8>>2]|0;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
 // unreachable;
}
function __Z38Transform_CUSTOM_INTERNAL_set_positionP15ScriptingObjectRK8Vector3f($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZN9Transform11SetPositionERK8Vector3f($1,$value);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z46Transform_CUSTOM_INTERNAL_get_localEulerAnglesP15ScriptingObjectR8Vector3f($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
 } else {
  $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $3 = ($2|0)==(0|0);
  if ($3) {
   $4 = $self_;
  } else {
   __ZN9Transform19GetLocalEulerAnglesEv($0,$2);
   ;HEAP32[$value+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$value+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$value+8>>2]=HEAP32[$0+8>>2]|0;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
 // unreachable;
}
function __Z46Transform_CUSTOM_INTERNAL_set_localEulerAnglesP15ScriptingObjectRK8Vector3f($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZN9Transform19SetLocalEulerAnglesERK8Vector3f($1,$value);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z38Transform_CUSTOM_INTERNAL_get_rotationP15ScriptingObjectR11Quaternionf($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  __ZNK9Transform11GetRotationEv($0,$2);
  ;HEAP32[$value+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$value+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$value+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$value+12>>2]=HEAP32[$0+12>>2]|0;
  STACKTOP = sp;return;
 }
}
function __Z38Transform_CUSTOM_INTERNAL_set_rotationP15ScriptingObjectRK11Quaternionf($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZN9Transform15SetRotationSafeERK11Quaternionf($1,$value);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z43Transform_CUSTOM_INTERNAL_get_localRotationP15ScriptingObjectR11Quaternionf($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 28|0);
   _memmove(($value|0),($4|0),16)|0;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z43Transform_CUSTOM_INTERNAL_set_localRotationP15ScriptingObjectRK11Quaternionf($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZN9Transform20SetLocalRotationSafeERK11Quaternionf($1,$value);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z40Transform_CUSTOM_INTERNAL_set_localScaleP15ScriptingObjectRK8Vector3f($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZN9Transform13SetLocalScaleERK8Vector3f($1,$value);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z48Transform_CUSTOM_INTERNAL_get_localToWorldMatrixP15ScriptingObjectR10Matrix4x4f($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  __ZNK9Transform21GetLocalToWorldMatrixEv($0,$2);
  dest=$value+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
}
function __Z49Transform_CUSTOM_INTERNAL_CALL_TransformDirectionP15ScriptingObjectRK8Vector3f($agg$result,$self_,$direction) {
 $agg$result = $agg$result|0;
 $self_ = $self_|0;
 $direction = $direction|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZNK9Transform18TransformDirectionERK8Vector3f($agg$result,$1,$direction);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z56Transform_CUSTOM_INTERNAL_CALL_InverseTransformDirectionP15ScriptingObjectRK8Vector3f($agg$result,$self_,$direction) {
 $agg$result = $agg$result|0;
 $self_ = $self_|0;
 $direction = $direction|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZNK9Transform25InverseTransformDirectionERK8Vector3f($agg$result,$1,$direction);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z45Transform_CUSTOM_INTERNAL_CALL_TransformPointP15ScriptingObjectRK8Vector3f($agg$result,$self_,$position) {
 $agg$result = $agg$result|0;
 $self_ = $self_|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZNK9Transform14TransformPointERK8Vector3f($agg$result,$1,$position);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z52Transform_CUSTOM_INTERNAL_CALL_InverseTransformPointP15ScriptingObjectRK8Vector3f($agg$result,$self_,$position) {
 $agg$result = $agg$result|0;
 $self_ = $self_|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZNK9Transform21InverseTransformPointERK8Vector3f($agg$result,$1,$position);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z52Register_UnityEngine_Transform_INTERNAL_get_positionv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686872,3309);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Transform_INTERNAL_set_positionv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686920,3310);
 STACKTOP = sp;return;
}
function __Z60Register_UnityEngine_Transform_INTERNAL_get_localEulerAnglesv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(686968,3311);
 STACKTOP = sp;return;
}
function __Z60Register_UnityEngine_Transform_INTERNAL_set_localEulerAnglesv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687024,3312);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Transform_INTERNAL_get_rotationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687080,3313);
 STACKTOP = sp;return;
}
function __Z52Register_UnityEngine_Transform_INTERNAL_set_rotationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687128,3314);
 STACKTOP = sp;return;
}
function __Z57Register_UnityEngine_Transform_INTERNAL_get_localRotationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687176,3315);
 STACKTOP = sp;return;
}
function __Z57Register_UnityEngine_Transform_INTERNAL_set_localRotationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687232,3316);
 STACKTOP = sp;return;
}
function __Z54Register_UnityEngine_Transform_INTERNAL_set_localScalev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687288,3317);
 STACKTOP = sp;return;
}
function __Z62Register_UnityEngine_Transform_INTERNAL_get_localToWorldMatrixv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687336,3318);
 STACKTOP = sp;return;
}
function __Z63Register_UnityEngine_Transform_INTERNAL_CALL_TransformDirectionv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687392,1965);
 STACKTOP = sp;return;
}
function __Z70Register_UnityEngine_Transform_INTERNAL_CALL_InverseTransformDirectionv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687448,1966);
 STACKTOP = sp;return;
}
function __Z59Register_UnityEngine_Transform_INTERNAL_CALL_TransformPointv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687512,1967);
 STACKTOP = sp;return;
}
function __Z66Register_UnityEngine_Transform_INTERNAL_CALL_InverseTransformPointv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687568,1968);
 STACKTOP = sp;return;
}
function __Z24Time_Get_Custom_PropTimev() {
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14GetTimeManagerv()|0);
 $1 = (($0) + 88|0);
 $2 = +HEAPF64[$1>>3];
 $3 = Math_fround($2);
 STACKTOP = sp;return (Math_fround($3));
}
function __Z29Time_Get_Custom_PropDeltaTimev() {
 var $0 = 0, $1 = 0, $2 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14GetTimeManagerv()|0);
 $1 = (($0) + 104|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 STACKTOP = sp;return (Math_fround($2));
}
function __Z34Register_UnityEngine_Time_get_timev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687632,1);
 STACKTOP = sp;return;
}
function __Z39Register_UnityEngine_Time_get_deltaTimev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687664,2);
 STACKTOP = sp;return;
}
function __Z28Random_CUSTOM_RandomRangeIntii($min,$max) {
 $min = $min|0;
 $max = $max|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetScriptingRandv()|0);
 $1 = ($min|0)<($max|0);
 if ($1) {
  $2 = (($max) - ($min))|0;
  $3 = HEAP32[$0>>2]|0;
  $4 = $3 << 11;
  $5 = $4 ^ $3;
  $6 = (($0) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$6>>2] = $9;
  $10 = (($0) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$8>>2] = $11;
  $12 = $11 >>> 19;
  $13 = $5 >>> 8;
  $14 = $13 ^ $5;
  $15 = $14 ^ $11;
  $16 = $15 ^ $12;
  HEAP32[$10>>2] = $16;
  $17 = (($16>>>0) % ($2>>>0))&-1;
  $18 = (($17) + ($min))|0;
  $$0$i = $18;
  STACKTOP = sp;return ($$0$i|0);
 }
 $19 = ($min|0)>($max|0);
 if (!($19)) {
  $$0$i = $min;
  STACKTOP = sp;return ($$0$i|0);
 }
 $20 = (($min) - ($max))|0;
 $21 = HEAP32[$0>>2]|0;
 $22 = $21 << 11;
 $23 = $22 ^ $21;
 $24 = (($0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$0>>2] = $25;
 $26 = (($0) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$24>>2] = $27;
 $28 = (($0) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$26>>2] = $29;
 $30 = $29 >>> 19;
 $31 = $23 >>> 8;
 $32 = $31 ^ $23;
 $33 = $32 ^ $29;
 $34 = $33 ^ $30;
 HEAP32[$28>>2] = $34;
 $35 = (($34>>>0) % ($20>>>0))&-1;
 $36 = (($min) - ($35))|0;
 $$0$i = $36;
 STACKTOP = sp;return ($$0$i|0);
}
function __Z42Register_UnityEngine_Random_RandomRangeIntv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(687696,2551);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a11687() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[687736>>2] = Math_fround(4.0);
 HEAPF32[((687736 + 4|0))>>2] = Math_fround(4.0);
 HEAPF32[((687736 + 8|0))>>2] = Math_fround(4.0);
 HEAPF32[((687736 + 12|0))>>2] = Math_fround(4.0);
 HEAPF32[687752>>2] = Math_fround(0.03125);
 HEAPF32[((687752 + 4|0))>>2] = Math_fround(0.03125);
 HEAPF32[((687752 + 8|0))>>2] = Math_fround(0.03125);
 HEAPF32[((687752 + 12|0))>>2] = Math_fround(0.03125);
 HEAPF32[687768>>2] = Math_fround(-31.5);
 HEAPF32[((687768 + 4|0))>>2] = Math_fround(-31.5);
 HEAPF32[((687768 + 8|0))>>2] = Math_fround(-31.5);
 HEAPF32[((687768 + 12|0))>>2] = Math_fround(-31.5);
 HEAPF32[687784>>2] = Math_fround(16.0);
 HEAPF32[((687784 + 4|0))>>2] = Math_fround(16.0);
 HEAPF32[((687784 + 8|0))>>2] = Math_fround(16.0);
 HEAPF32[((687784 + 12|0))>>2] = Math_fround(16.0);
 HEAPF32[687800>>2] = Math_fround(-0.5);
 HEAPF32[((687800 + 4|0))>>2] = Math_fround(-0.5);
 HEAPF32[((687800 + 8|0))>>2] = Math_fround(-0.5);
 HEAPF32[((687800 + 12|0))>>2] = Math_fround(-0.5);
 HEAPF32[687816>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((687816 + 4|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((687816 + 8|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[((687816 + 12|0))>>2] = Math_fround(1.1920928955078125E-7);
 HEAPF32[687832>>2] = Math_fround(0.0);
 HEAPF32[((687832 + 4|0))>>2] = Math_fround(1.0);
 HEAPF32[((687832 + 8|0))>>2] = Math_fround(2.0);
 HEAPF32[((687832 + 12|0))>>2] = Math_fround(3.0);
 HEAPF32[687848>>2] = Math_fround(1.52590218931436538696E-5);
 HEAPF32[((687848 + 4|0))>>2] = Math_fround(1.52590218931436538696E-5);
 HEAPF32[((687848 + 8|0))>>2] = Math_fround(1.52590218931436538696E-5);
 HEAPF32[((687848 + 12|0))>>2] = Math_fround(1.52590218931436538696E-5);
 HEAP32[687864>>2] = 65535;
 HEAP32[((687864 + 4|0))>>2] = 65535;
 HEAP32[((687864 + 8|0))>>2] = 65535;
 HEAP32[((687864 + 12|0))>>2] = 65535;
 HEAPF32[687880>>2] = Math_fround(1.52590218931436538696E-5);
 HEAPF32[((687880 + 4|0))>>2] = Math_fround(1.52590218931436538696E-5);
 HEAPF32[((687880 + 8|0))>>2] = Math_fround(1.52590218931436538696E-5);
 HEAPF32[((687880 + 12|0))>>2] = Math_fround(1.52590218931436538696E-5);
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplIfE6AssignEPK11KeyframeTplIfES4_($this,$begin,$end) {
 $this = $this|0;
 $begin = $begin|0;
 $end = $end|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 56|0);
 $2 = $end;
 $3 = $begin;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 4;
 $6 = (($this) + 64|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 68|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9>>>0)<($5>>>0);
 do {
  if ($10) {
   $11 = ($8|0)>(-1);
   if ($11) {
    HEAP32[$7>>2] = $5;
    $12 = HEAP32[$1>>2]|0;
    $13 = (($this) + 60|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$0>>2] = $14;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $15 = (__Z16realloc_internalPvji10MemLabelIdiPKci($12,$4,4,$$byval_copy1,0,687896,370)|0);
    HEAP32[$1>>2] = $15;
    $24 = $15;
    break;
   } else {
    $16 = (($this) + 60|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($4,4,$$byval_copy1,0,687896,352)|0);
    $19 = HEAP32[$1>>2]|0;
    $20 = HEAP32[$6>>2]|0;
    $21 = $20 << 4;
    _memcpy(($18|0),($19|0),($21|0))|0;
    HEAP32[$7>>2] = $5;
    HEAP32[$1>>2] = $18;
    $24 = $18;
    break;
   }
  } else {
   $$pre$i = HEAP32[$1>>2]|0;
   $24 = $$pre$i;
  }
 } while(0);
 $22 = HEAP32[$6>>2]|0;
 $23 = $22 << 4;
 _memcpy(($24|0),($begin|0),($23|0))|0;
 __ZN17AnimationCurveTplIfE15InvalidateCacheEv($this);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a11737() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[687904>>2] = 0;
 HEAP32[687912>>2] = 61;
 HEAP32[687920>>2] = 32;
 HEAP32[$0>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (invoke_iiiiiiii(108,(0|0),128,4,($$byval_copy1|0),0,(687928|0),370)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  HEAP32[687904>>2] = $2;
  STACKTOP = sp;return;
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $7 = HEAP32[687920>>2]|0;
 $8 = ($7|0)>(-1);
 if (!($8)) {
  ___resumeException($5|0);
  // unreachable;
 }
 $9 = HEAP32[687904>>2]|0;
 $10 = HEAP32[687912>>2]|0;
 HEAP32[$1>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($9|0),($$byval_copy1|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch(0|0)|0;
  $14 = tempRet0;
  ___clang_call_terminate($13);
  // unreachable;
 }
 HEAP32[687904>>2] = 0;
 ___resumeException($5|0);
 // unreachable;
}
function __ZN17CallbackArrayBaseIPFvvEE10UnregisterES1_($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==($callback|0);
 if ($1) {
  HEAP32[$this>>2] = 0;
 }
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($callback|0);
 if ($4) {
  HEAP32[$2>>2] = 0;
 }
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($callback|0);
 if ($7) {
  HEAP32[$5>>2] = 0;
 }
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($callback|0);
 if ($10) {
  HEAP32[$8>>2] = 0;
 }
 $11 = (($this) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($callback|0);
 if ($13) {
  HEAP32[$11>>2] = 0;
 }
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($callback|0);
 if ($16) {
  HEAP32[$14>>2] = 0;
 }
 $17 = (($this) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==($callback|0);
 if ($19) {
  HEAP32[$17>>2] = 0;
 }
 $20 = (($this) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($callback|0);
 if ($22) {
  HEAP32[$20>>2] = 0;
 }
 $23 = (($this) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($callback|0);
 if ($25) {
  HEAP32[$23>>2] = 0;
 }
 $26 = (($this) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==($callback|0);
 if ($28) {
  HEAP32[$26>>2] = 0;
 }
 $29 = (($this) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==($callback|0);
 if ($31) {
  HEAP32[$29>>2] = 0;
 }
 $32 = (($this) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==($callback|0);
 if ($34) {
  HEAP32[$32>>2] = 0;
 }
 $35 = (($this) + 48|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==($callback|0);
 if ($37) {
  HEAP32[$35>>2] = 0;
 }
 $38 = (($this) + 52|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==($callback|0);
 if ($40) {
  HEAP32[$38>>2] = 0;
 }
 $41 = (($this) + 56|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==($callback|0);
 if ($43) {
  HEAP32[$41>>2] = 0;
 }
 $44 = (($this) + 60|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==($callback|0);
 if (!($46)) {
  STACKTOP = sp;return;
 }
 HEAP32[$44>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIfNS_9allocatorIfEEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAPF32[$10>>2] = Math_fround(0.0);
   }
   $11 = (($10) + 4|0);
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$10 = $11;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($__n))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 if ($22) {
  $23 = $20 >> 1;
  $24 = ($23>>>0)<($18>>>0);
  $25 = $24 ? $18 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 2;
  $28 = (__Znwj($27)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($17<<2)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAPF32[$32>>2] = Math_fround(0.0);
  }
  $33 = (($32) + 4|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($30) + ($18<<2)|0);
 _memcpy(($30|0),($14|0),($16|0))|0;
 HEAP32[$this>>2] = $30;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $36;
 $37 = ($14|0)==(0|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 __ZdlPv($14);
 STACKTOP = sp;return;
}
function __ZN8ColliderD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i2 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i12$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((688920 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($this) + 40|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($this) + 44|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==($3|0);
   if (!($7)) {
    $__new_last2$i$i$i$i$i$i$i$i$i = $3;
    $scevgep$i$i$i$i$i$i$i$i$i = (($6) + -4|0);
    $8 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($8)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
    $9 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 2;
    $10 = $9 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i = (($6) + ($10<<2)|0);
    HEAP32[$5>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($3);
  }
  HEAP32[$this>>2] = ((562072 + 8|0));
  __THREW__ = 0;
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    STACKTOP = sp;return;
   }
   $15 = ___cxa_find_matching_catch()|0;
   $16 = tempRet0;
   __THREW__ = 0;
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $19 = ___cxa_find_matching_catch(0|0)|0;
    $20 = tempRet0;
    ___clang_call_terminate($19);
    // unreachable;
   } else {
    ___resumeException($15|0);
    // unreachable;
   }
  }
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $27 = ___cxa_find_matching_catch(0|0)|0;
   $28 = tempRet0;
   __THREW__ = 0;
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $31 = ___cxa_find_matching_catch(0|0)|0;
    $32 = tempRet0;
    ___clang_call_terminate($31);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $27;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   ___resumeException($21|0);
   // unreachable;
  }
  $33 = ___cxa_find_matching_catch(0|0)|0;
  $34 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $33;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 $37 = (($this) + 40|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = (($this) + 44|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==($38|0);
  if (!($42)) {
   $__new_last2$i$i$i$i$i$i$i$i$i2 = $38;
   $scevgep$i$i$i$i$i$i$i$i$i3 = (($41) + -4|0);
   $43 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i2))|0;
   $uglygep$i$i$i$i$i$i$i$i$i5 = (($scevgep$i$i$i$i$i$i$i$i$i3) + ($43)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i6 = $uglygep$i$i$i$i$i$i$i$i$i5;
   $44 = $uglygep3$i$i$i$i$i$i$i$i$i6 >>> 2;
   $45 = $44 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i7 = (($41) + ($45<<2)|0);
   HEAP32[$40>>2] = $scevgep4$i$i$i$i$i$i$i$i$i7;
  }
  __ZdlPv($38);
 }
 HEAP32[$this>>2] = ((562072 + 8|0));
 __THREW__ = 0;
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $58 = ___cxa_find_matching_catch(0|0)|0;
  $59 = tempRet0;
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if ($61) {
   $64 = ___cxa_find_matching_catch(0|0)|0;
   $65 = tempRet0;
   __THREW__ = 0;
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    $68 = ___cxa_find_matching_catch(0|0)|0;
    $69 = tempRet0;
    ___clang_call_terminate($68);
    // unreachable;
   } else {
    $eh$lpad$body$i12$indexZ2D = $64;
    ___clang_call_terminate($eh$lpad$body$i12$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $62 = __THREW__; __THREW__ = 0;
  $63 = $62&1;
  if (!($63)) {
   $eh$lpad$body$indexZ2D = $58;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
  $70 = ___cxa_find_matching_catch(0|0)|0;
  $71 = tempRet0;
  $eh$lpad$body$i12$indexZ2D = $70;
  ___clang_call_terminate($eh$lpad$body$i12$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  if ($49) {
   $50 = ___cxa_find_matching_catch(0|0)|0;
   $51 = tempRet0;
   __THREW__ = 0;
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $54 = ___cxa_find_matching_catch(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $50;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if (!($57)) {
   ___resumeException($35|0);
   // unreachable;
  }
  $72 = ___cxa_find_matching_catch(0|0)|0;
  $73 = tempRet0;
  $eh$lpad$body$indexZ2D = $72;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 }
}
function __ZNK8Collider16SupportsMaterialEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK8Collider15SupportsTriggerEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN8Collider12GetIsTriggerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN8ColliderD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8ColliderD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN8ColliderD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3629,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN15CapsuleCollider9SetHeightEf($this,$height) {
 $this = $this|0;
 $height = Math_fround($height);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sCapsule = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sCapsule = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 56|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 != $height;
 if ($3) {
  HEAPF32[$1>>2] = $height;
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 HEAP32[$sCapsule>>2] = 2;
 $7 = (($sCapsule) + 4|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($sCapsule) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = HEAP32[$5>>2]|0;
 $10 = (($9) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 (FUNCTION_TABLE_iii[$11 & 4095]($5,$sCapsule)|0);
 __ZNK15CapsuleCollider16GetGlobalExtentsERK8Vector3f($0,$this,616696);
 $12 = (($0) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * Math_fround(0.5));
 HEAPF32[$8>>2] = $14;
 $15 = HEAP32[$4>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($15,$sCapsule);
 __ZN8Collider32RigidbodyMassDistributionChangedEv($this);
 STACKTOP = sp;return;
}
function __ZNK15CapsuleCollider16GetGlobalExtentsERK8Vector3f($agg$result,$this,$additionalScale) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $additionalScale = $additionalScale|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0;
 var $scale = 0, $scales4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $scale = sp + 32|0;
 $0 = sp;
 $scales4 = sp + 16|0;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($2)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($0,$3);
 $4 = Math_fround(HEAPF32[$0>>2]);
 $5 = Math_fround(HEAPF32[$additionalScale>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($additionalScale) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = (($0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($additionalScale) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 * $15);
 HEAPF32[$scale>>2] = $6;
 $17 = (($scale) + 4|0);
 HEAPF32[$17>>2] = $11;
 $18 = (($scale) + 8|0);
 HEAPF32[$18>>2] = $16;
 HEAPF32[$scales4>>2] = $6;
 $19 = (($scales4) + 4|0);
 HEAPF32[$19>>2] = $11;
 $20 = (($scales4) + 8|0);
 HEAPF32[$20>>2] = $16;
 $21 = (($scales4) + 12|0);
 HEAPF32[$21>>2] = $6;
 $22 = (($this) + 56|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($this) + 60|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($scale) + ($25<<2)|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($23 * $27);
 $29 = $28 < Math_fround(0.0);
 if ($29) {
  $30 = Math_fround(-$28);
  $32 = $30;
 } else {
  $32 = $28;
 }
 $31 = $32 < Math_fround(9.99999974737875163555E-6);
 $33 = $31 ? Math_fround(9.99999974737875163555E-6) : $32;
 $34 = (($25) + 1)|0;
 $35 = $34 & 3;
 $36 = (($scales4) + ($35<<2)|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($25) + 2)|0;
 $39 = $38 & 3;
 $40 = (($scales4) + ($39<<2)|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = $37 < Math_fround(0.0);
 if ($42) {
  $43 = Math_fround(-$37);
  $47 = $43;
 } else {
  $47 = $37;
 }
 $44 = $41 < Math_fround(0.0);
 if ($44) {
  $45 = Math_fround(-$41);
  $48 = $45;
 } else {
  $48 = $41;
 }
 $46 = $47 < $48;
 $49 = $46 ? $48 : $47;
 $50 = (($this) + 52|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($51 * $49);
 $53 = Math_fround($52 * Math_fround(2.0));
 $54 = Math_fround($33 - $53);
 $55 = $54 < Math_fround(9.99999974737875163555E-6);
 $56 = $55 ? Math_fround(9.99999974737875163555E-6) : $54;
 $57 = $52 < Math_fround(9.99999974737875163555E-6);
 $58 = $57 ? Math_fround(9.99999974737875163555E-6) : $52;
 HEAPF32[$agg$result>>2] = $58;
 $59 = (($agg$result) + 4|0);
 HEAPF32[$59>>2] = $56;
 STACKTOP = sp;return;
}
function __ZNK15CapsuleCollider18CalculateTransformEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = Math_fround(0), $8 = Math_fround(0);
 var $9 = Math_fround(0), $center = 0, $rotation = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $center = sp + 32|0;
 $rotation = sp;
 $0 = sp + 16|0;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($2)|0);
 $4 = (($this) + 64|0);
 __ZNK9Transform14TransformPointERK8Vector3f($center,$3,$4);
 __ZNK9Transform11GetRotationEv($0,$3);
 $5 = (($this) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 if ((($6|0) == 1)) {
  $7 = Math_fround(HEAPF32[616744>>2]);
  $8 = Math_fround($7 * Math_fround(-0.707106769084930419921));
  $9 = Math_fround(HEAPF32[((616744 + 4|0))>>2]);
  $10 = Math_fround($9 * Math_fround(-0.707106769084930419921));
  $11 = Math_fround(HEAPF32[((616744 + 8|0))>>2]);
  $12 = Math_fround($11 * Math_fround(-0.707106769084930419921));
  $22 = $8;$25 = Math_fround(0.707106769084930419921);$30 = $12;$35 = $10;
 } else if ((($6|0) == 2)) {
  $13 = Math_fround(HEAPF32[616728>>2]);
  $14 = Math_fround($13 * Math_fround(0.707106769084930419921));
  $15 = Math_fround(HEAPF32[((616728 + 4|0))>>2]);
  $16 = Math_fround($15 * Math_fround(0.707106769084930419921));
  $17 = Math_fround(HEAPF32[((616728 + 8|0))>>2]);
  $18 = Math_fround($17 * Math_fround(0.707106769084930419921));
  $22 = $14;$25 = Math_fround(0.707106769084930419921);$30 = $18;$35 = $16;
 } else {
  $22 = Math_fround(0.0);$25 = Math_fround(1.0);$30 = Math_fround(0.0);$35 = Math_fround(0.0);
 }
 $19 = (($0) + 12|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($22 * $20);
 $23 = Math_fround(HEAPF32[$0>>2]);
 $24 = Math_fround($25 * $23);
 $26 = Math_fround($21 + $24);
 $27 = (($0) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($30 * $28);
 $31 = Math_fround($26 + $29);
 $32 = (($0) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($35 * $33);
 $36 = Math_fround($31 - $34);
 $37 = Math_fround($35 * $20);
 $38 = Math_fround($25 * $28);
 $39 = Math_fround($37 + $38);
 $40 = Math_fround($22 * $33);
 $41 = Math_fround($40 + $39);
 $42 = Math_fround($30 * $23);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($30 * $20);
 $45 = Math_fround($25 * $33);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($35 * $23);
 $48 = Math_fround($47 + $46);
 $49 = Math_fround($22 * $28);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($25 * $20);
 $52 = Math_fround($22 * $23);
 $53 = Math_fround($51 - $52);
 $54 = Math_fround($35 * $28);
 $55 = Math_fround($53 - $54);
 $56 = Math_fround($30 * $33);
 $57 = Math_fround($55 - $56);
 HEAPF32[$rotation>>2] = $36;
 $58 = (($rotation) + 4|0);
 HEAPF32[$58>>2] = $43;
 $59 = (($rotation) + 8|0);
 HEAPF32[$59>>2] = $50;
 $60 = (($rotation) + 12|0);
 HEAPF32[$60>>2] = $57;
 __ZN10Matrix4x4f5SetTRERK8Vector3fRK11Quaternionf($agg$result,$center,$rotation);
 STACKTOP = sp;return;
}
function __ZN24ControllerFilterCallbackD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN19ControllerHitReportD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__new_last2$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((688680 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if (!($5)) {
  $__new_last2$i$i$i$i$i$i = $1;
  $scevgep$i$i$i$i$i$i = (($4) + -44|0);
  $6 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($6)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $7 = (($uglygep3$i$i$i$i$i$i>>>0) / 44)&-1;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($4) + (($8*44)|0)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i;
 }
 __ZdlPv($1);
 STACKTOP = sp;return;
}
function __ZN23ControllerContactFilterD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN19CharacterController13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__ZNK5Unity10GameObject8IsActiveEv($1)|0);
  if ($3) {
   $4 = HEAP32[$this>>2]|0;
   $5 = (($4) + 136|0);
   $6 = HEAP32[$5>>2]|0;
   FUNCTION_TABLE_vii[$6 & 4095]($this,0);
  }
 }
 __ZN8Collider13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 STACKTOP = sp;return;
}
function __ZN19CharacterController10SmartResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0;
 var $9 = Math_fround(0), $aabb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $aabb = sp;
 ;HEAP32[$aabb+0>>2]=0|0;HEAP32[$aabb+4>>2]=0|0;HEAP32[$aabb+8>>2]=0|0;HEAP32[$aabb+12>>2]=0|0;HEAP32[$aabb+16>>2]=0|0;HEAP32[$aabb+20>>2]=0|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__Z18CalculateLocalAABBRN5Unity10GameObjectEP4AABB($1,$aabb)|0);
  if ($3) {
   $4 = Math_fround(HEAPF32[$aabb>>2]);
   $5 = (($aabb) + 12|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = Math_fround($4 + $6);
   $8 = (($aabb) + 4|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   $10 = (($aabb) + 16|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = Math_fround($9 + $11);
   $13 = (($aabb) + 8|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = (($aabb) + 20|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($14 + $16);
   $18 = $7 < $17;
   $19 = $18 ? $17 : $7;
   __ZN19CharacterController9SetRadiusEf($this,$19);
   $20 = Math_fround($12 * Math_fround(2.0));
   __ZN19CharacterController9SetHeightEf($this,$20);
   STACKTOP = sp;return;
  }
 }
 __ZN19CharacterController9SetRadiusEf($this,Math_fround(0.5));
 __ZN19CharacterController9SetHeightEf($this,Math_fround(2.0));
 STACKTOP = sp;return;
}
function __ZN19CharacterController9SetRadiusEf($this,$radius) {
 $this = $this|0;
 $radius = Math_fround($radius);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $scale$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scale$i = sp;
 $0 = (($this) + 84|0);
 HEAPF32[$0>>2] = $radius;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($5)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($scale$i,$6);
 $7 = (($this) + 80|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($scale$i) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = $11 < Math_fround(0.0);
 if ($12) {
  $13 = Math_fround(-$11);
  $15 = $13;
 } else {
  $15 = $11;
 }
 $14 = $15 < Math_fround(9.99999974737875163555E-6);
 $16 = $14 ? Math_fround(9.99999974737875163555E-6) : $15;
 $17 = Math_fround(HEAPF32[$scale$i>>2]);
 $18 = $17 < Math_fround(0.0);
 if ($18) {
  $19 = Math_fround(-$17);
  $25 = $19;
 } else {
  $25 = $17;
 }
 $20 = (($scale$i) + 8|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = $21 < Math_fround(0.0);
 if ($22) {
  $23 = Math_fround(-$21);
  $26 = $23;
 } else {
  $26 = $21;
 }
 $24 = $25 < $26;
 $27 = $24 ? $26 : $25;
 $28 = Math_fround(HEAPF32[$0>>2]);
 $29 = Math_fround($28 * $27);
 $30 = Math_fround($29 * Math_fround(2.0));
 $31 = Math_fround($16 - $30);
 $32 = $31 < Math_fround(9.99999974737875163555E-6);
 $33 = $32 ? Math_fround(9.99999974737875163555E-6) : $31;
 $34 = $29 < Math_fround(9.99999974737875163555E-6);
 $35 = $34 ? Math_fround(9.99999974737875163555E-6) : $29;
 $36 = HEAP32[$1>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 112|0);
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_iif[$39 & 31]($36,$35)|0);
 $40 = HEAP32[$1>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 120|0);
 $43 = HEAP32[$42>>2]|0;
 (FUNCTION_TABLE_iif[$43 & 31]($40,$33)|0);
 STACKTOP = sp;return;
}
function __ZN19CharacterController9SetHeightEf($this,$height) {
 $this = $this|0;
 $height = Math_fround($height);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $scale$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scale$i = sp;
 $0 = (($this) + 80|0);
 HEAPF32[$0>>2] = $height;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($5)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($scale$i,$6);
 $7 = Math_fround(HEAPF32[$0>>2]);
 $8 = (($scale$i) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 * $9);
 $11 = $10 < Math_fround(0.0);
 if ($11) {
  $12 = Math_fround(-$10);
  $14 = $12;
 } else {
  $14 = $10;
 }
 $13 = $14 < Math_fround(9.99999974737875163555E-6);
 $15 = $13 ? Math_fround(9.99999974737875163555E-6) : $14;
 $16 = Math_fround(HEAPF32[$scale$i>>2]);
 $17 = $16 < Math_fround(0.0);
 if ($17) {
  $18 = Math_fround(-$16);
  $24 = $18;
 } else {
  $24 = $16;
 }
 $19 = (($scale$i) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = $20 < Math_fround(0.0);
 if ($21) {
  $22 = Math_fround(-$20);
  $25 = $22;
 } else {
  $25 = $20;
 }
 $23 = $24 < $25;
 $26 = $23 ? $25 : $24;
 $27 = (($this) + 84|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $26);
 $30 = Math_fround($29 * Math_fround(2.0));
 $31 = Math_fround($15 - $30);
 $32 = $31 < Math_fround(9.99999974737875163555E-6);
 $33 = $32 ? Math_fround(9.99999974737875163555E-6) : $31;
 $34 = $29 < Math_fround(9.99999974737875163555E-6);
 $35 = $34 ? Math_fround(9.99999974737875163555E-6) : $29;
 $36 = HEAP32[$1>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 112|0);
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_iif[$39 & 31]($36,$35)|0);
 $40 = HEAP32[$1>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 120|0);
 $43 = HEAP32[$42>>2]|0;
 (FUNCTION_TABLE_iif[$43 & 31]($40,$33)|0);
 STACKTOP = sp;return;
}
function __ZN19CharacterController5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 ;HEAP32[$0+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[616680+8>>2]|0;
 $1 = (($this) + 84|0);
 $2 = (($this) + 80|0);
 $3 = (($this) + 64|0);
 HEAPF32[$3>>2] = Math_fround(0.00100000004749745130539);
 $4 = (($this) + 68|0);
 HEAPF32[$4>>2] = Math_fround(0.0799999982118606567383);
 $5 = (($this) + 76|0);
 HEAPF32[$5>>2] = Math_fround(0.300000011920928955078);
 HEAPF32[$2>>2] = Math_fround(2.0);
 HEAPF32[$1>>2] = Math_fround(0.300000011920928955078);
 $6 = (($this) + 72|0);
 HEAPF32[$6>>2] = Math_fround(45.0);
 STACKTOP = sp;return;
}
function __ZN19CharacterController4MoveERK8Vector3f($this,$movement) {
 $this = $this|0;
 $movement = $movement|0;
 var $$3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0.0, $117 = Math_fround(0), $118 = 0, $119 = 0.0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = 0, $122 = 0.0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0.0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0.0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $controllerHit$sroa$2 = 0, $data = 0;
 var $data1 = 0, $filters = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp = Math_fround(0), $pos = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $data = sp + 80|0;
 $filters = sp + 48|0;
 $0 = sp + 96|0;
 $controllerHit$sroa$2 = sp;
 $data1 = sp + 64|0;
 $pos = sp + 36|0;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$3 = 0;
  STACKTOP = sp;return ($$3|0);
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($2)|0);
 $8 = +HEAPF64[$7>>3];
 $9 = Math_fround($8);
 $10 = (($7) + 8|0);
 $11 = +HEAPF64[$10>>3];
 $12 = Math_fround($11);
 $13 = (($7) + 16|0);
 $14 = +HEAPF64[$13>>3];
 $15 = Math_fround($14);
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 80|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vi[$19 & 4095]($16);
 $20 = (($this) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 92|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_vii[$24 & 4095]($data,$21);
 $25 = (($this) + 56|0);
 HEAP32[$filters>>2] = $data;
 $26 = (($filters) + 4|0);
 HEAP32[$26>>2] = $25;
 $27 = (($filters) + 8|0);
 HEAP16[$27>>1] = 7;
 $28 = (($filters) + 12|0);
 HEAP32[$28>>2] = 687936;
 $29 = (($this) + 136|0);
 $30 = +HEAPF64[$29>>3];
 $31 = $30 > 0.0;
 if ($31) {
  $32 = (__Z17GetPhysicsManagerv()|0);
  $33 = (($32) + 824|0);
  $34 = +HEAPF64[$33>>3];
  $35 = +HEAPF64[$29>>3];
  $36 = $34 - $35;
  $phitmp = Math_fround($36);
  $46 = $phitmp;
 } else {
  $46 = Math_fround(0.0);
 }
 $37 = (__Z17GetPhysicsManagerv()|0);
 $38 = (($37) + 824|0);
 $39 = +HEAPF64[$38>>3];
 HEAPF64[$29>>3] = $39;
 $40 = HEAP32[$1>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 64|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 FUNCTION_TABLE_viiiffii[$43 & 3]($0,$40,$movement,$45,$46,$filters,0);
 $47 = HEAP8[$0>>0]|0;
 $48 = $47&255;
 $49 = (__Z30GetDisableImmediateDestructionv()|0);
 __Z30SetDisableImmediateDestructionb(1);
 $50 = HEAP32[((687944 + 4|0))>>2]|0;
 HEAP32[((687944 + 4|0))>>2] = 0;
 $51 = HEAP32[((687944 + 8|0))>>2]|0;
 HEAP32[((687944 + 8|0))>>2] = 0;
 HEAP32[((687944 + 12|0))>>2] = 0;
 $52 = ($50|0)==($51|0);
 L7: do {
  if ($52) {
   label = 18;
  } else {
   $53 = (($controllerHit$sroa$2) + 12|0);
   $54 = (($controllerHit$sroa$2) + 24|0);
   $55 = (($data1) + 8|0);
   $56 = (($data1) + 4|0);
   $58 = $50;
   while(1) {
    dest=$controllerHit$sroa$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $57 = (($58) + 4|0);
    ;HEAP32[$controllerHit$sroa$2+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$controllerHit$sroa$2+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$controllerHit$sroa$2+8>>2]=HEAP32[$57+8>>2]|0;
    $59 = (($58) + 16|0);
    ;HEAP32[$53+0>>2]=HEAP32[$59+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$59+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$59+8>>2]|0;
    $60 = (($58) + 28|0);
    ;HEAP32[$54+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$60+8>>2]|0;
    $61 = (($58) + 40|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    __THREW__ = 0;
    $63 = (invoke_ii(3302,($this|0))|0);
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     label = 13;
     break;
    }
    $66 = HEAP32[$58>>2]|0;
    __THREW__ = 0;
    $67 = (invoke_ii(3302,($66|0))|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     label = 13;
     break;
    }
    __THREW__ = 0;
    $70 = (invoke_i(84)|0);
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     label = 13;
     break;
    }
    $73 = (($70) + 264|0);
    $74 = HEAP32[$73>>2]|0;
    __THREW__ = 0;
    $75 = (invoke_ii(3286,($74|0))|0);
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     label = 13;
     break;
    }
    $78 = (($75) + 8|0);
    HEAP32[$78>>2] = $63;
    $79 = (($75) + 12|0);
    HEAP32[$79>>2] = $67;
    $80 = (($75) + 16|0);
    dest=$80+0|0; src=$controllerHit$sroa$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $81 = (($75) + 52|0);
    HEAPF32[$81>>2] = $62;
    $82 = (($75) + 56|0);
    HEAP32[$82>>2] = 0;
    HEAP32[$56>>2] = 0;
    HEAP32[$55>>2] = $75;
    HEAP32[$data1>>2] = 100003;
    __THREW__ = 0;
    invoke_viii(1969,($this|0),(564944|0),($data1|0));
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     label = 13;
     break;
    }
    $85 = HEAP32[$1>>2]|0;
    $86 = ($85|0)==(0|0);
    if ($86) {
     label = 12;
     break;
    }
    $94 = (($58) + 44|0);
    $95 = ($94|0)==($51|0);
    if ($95) {
     label = 18;
     break L7;
    } else {
     $58 = $94;
    }
   }
   if ((label|0) == 12) {
    __THREW__ = 0;
    invoke_vi(3630,($49|0));
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     label = 14;
     break;
    } else {
     label = 29;
     break;
    }
   }
   else if ((label|0) == 13) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    $lpad$phi$index = $89;$lpad$phi$index2 = $90;
    break;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  __THREW__ = 0;
  invoke_vi(3630,($49|0));
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   label = 14;
  } else {
   $98 = (($this) + 132|0);
   HEAP32[$98>>2] = $48;
   $99 = $48 & 4;
   $100 = ($99|0)==(0);
   if (!($100)) {
    $101 = (($this) + 104|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $103 = $102 < Math_fround(0.0);
    if ($103) {
     HEAPF32[$101>>2] = Math_fround(0.0);
    }
   }
   $104 = (($this) + 24|0);
   $105 = HEAP32[$104>>2]|0;
   __THREW__ = 0;
   $106 = (invoke_ii(3220,($105|0))|0);
   $107 = __THREW__; __THREW__ = 0;
   $108 = $107&1;
   if ($108) {
    label = 14;
   } else {
    $109 = HEAP32[$1>>2]|0;
    $110 = HEAP32[$109>>2]|0;
    $111 = (($110) + 24|0);
    $112 = HEAP32[$111>>2]|0;
    __THREW__ = 0;
    $113 = (invoke_ii($112|0,($109|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     label = 14;
    } else {
     $116 = +HEAPF64[$113>>3];
     $117 = Math_fround($116);
     $118 = (($113) + 8|0);
     $119 = +HEAPF64[$118>>3];
     $120 = Math_fround($119);
     $121 = (($113) + 16|0);
     $122 = +HEAPF64[$121>>3];
     $123 = Math_fround($122);
     HEAPF32[$pos>>2] = $117;
     $124 = (($pos) + 4|0);
     HEAPF32[$124>>2] = $120;
     $125 = (($pos) + 8|0);
     HEAPF32[$125>>2] = $123;
     __THREW__ = 0;
     $126 = (invoke_i(87)|0);
     $127 = __THREW__; __THREW__ = 0;
     $128 = $127&1;
     if ($128) {
      label = 14;
     } else {
      $129 = Math_fround($123 - $15);
      $130 = Math_fround($120 - $12);
      $131 = Math_fround($117 - $9);
      $132 = (($126) + 116|0);
      $133 = Math_fround(HEAPF32[$132>>2]);
      $134 = Math_fround($131 * $133);
      $135 = Math_fround($130 * $133);
      $136 = Math_fround($129 * $133);
      $137 = (($this) + 108|0);
      HEAPF32[$137>>2] = $134;
      $138 = (($this) + 112|0);
      HEAPF32[$138>>2] = $135;
      $139 = (($this) + 116|0);
      HEAPF32[$139>>2] = $136;
      __THREW__ = 0;
      $140 = (invoke_i(103)|0);
      $141 = __THREW__; __THREW__ = 0;
      $142 = $141&1;
      if ($142) {
       label = 14;
      } else {
       $143 = HEAP32[((564104 + 8|0))>>2]|0;
       $144 = (($140) + 28|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = Math_imul($145, $143)|0;
       $147 = (($146) + 143)|0;
       $148 = $147 & 31;
       $149 = 1 << $148;
       $150 = $149 ^ -1;
       $151 = $147 >>> 5;
       $152 = (($140) + 4|0);
       $153 = HEAP32[$152>>2]|0;
       $154 = (($153) + ($151<<2)|0);
       $155 = HEAP32[$154>>2]|0;
       $156 = $155 & $150;
       HEAP32[$154>>2] = $156;
       $157 = (($this) + 88|0);
       __THREW__ = 0;
       invoke_viii(1970,($106|0),($pos|0),($157|0));
       $158 = __THREW__; __THREW__ = 0;
       $159 = $158&1;
       if ($159) {
        label = 14;
       } else {
        __THREW__ = 0;
        $160 = (invoke_i(103)|0);
        $161 = __THREW__; __THREW__ = 0;
        $162 = $161&1;
        if ($162) {
         label = 14;
        } else {
         $163 = HEAP32[((564104 + 8|0))>>2]|0;
         $164 = (($160) + 28|0);
         $165 = HEAP32[$164>>2]|0;
         $166 = Math_imul($165, $163)|0;
         $167 = (($166) + 143)|0;
         $168 = $167 & 31;
         $169 = 1 << $168;
         $170 = $167 >>> 5;
         $171 = (($160) + 4|0);
         $172 = HEAP32[$171>>2]|0;
         $173 = (($172) + ($170<<2)|0);
         $174 = HEAP32[$173>>2]|0;
         $175 = $169 | $174;
         HEAP32[$173>>2] = $175;
         label = 29;
        }
       }
      }
     }
    }
   }
  }
 }
 if ((label|0) == 14) {
  $91 = ___cxa_find_matching_catch()|0;
  $92 = tempRet0;
  $lpad$phi$index = $91;$lpad$phi$index2 = $92;
 }
 else if ((label|0) == 29) {
  $176 = ($50|0)==(0|0);
  if ($176) {
   $$3 = $48;
   STACKTOP = sp;return ($$3|0);
  }
  __ZdlPv($50);
  $$3 = $48;
  STACKTOP = sp;return ($$3|0);
 }
 $93 = ($50|0)==(0|0);
 if ($93) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __ZdlPv($50);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN19CharacterController11GetVelocityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN19CharacterController6CreateEPK9Rigidbody($this,$ignoreAttachRigidbody) {
 $this = $this|0;
 $ignoreAttachRigidbody = $ignoreAttachRigidbody|0;
 var $$sroa$14$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0);
 var $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0);
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0.0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0.0, $71 = 0, $72 = Math_fround(0), $73 = 0.0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0;
 var $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $desc = 0, $not$$i = 0, $scale$i = 0, $storemerge = Math_fround(0), $switch$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $scale$i = sp + 112|0;
 $$sroa$14$i = sp + 152|0;
 $desc = sp;
 $0 = sp + 136|0;
 $1 = (($desc) + 4|0);
 $2 = (($desc) + 32|0);
 $3 = (($desc) + 36|0);
 $4 = (($desc) + 40|0);
 $5 = (($desc) + 44|0);
 $6 = (($desc) + 56|0);
 $7 = (($desc) + 60|0);
 $8 = (($desc) + 64|0);
 $9 = (($desc) + 68|0);
 $10 = (($desc) + 72|0);
 $11 = (($desc) + 76|0);
 $12 = (($desc) + 8|0);
 $13 = (($desc) + 48|0);
 $14 = (($desc) + 52|0);
 HEAP32[$desc>>2] = ((688632 + 8|0));
 $15 = (($desc) + 104|0);
 $16 = (($desc) + 100|0);
 $17 = (($desc) + 108|0);
 ;HEAP32[$scale$i+0>>2]=0|0;HEAP32[$scale$i+4>>2]=0|0;HEAP32[$scale$i+8>>2]=0|0;HEAP32[$scale$i+12>>2]=0|0;HEAP32[$scale$i+16>>2]=0|0;HEAP32[$scale$i+20>>2]=0|0;
 ;HEAP32[$$sroa$14$i+0>>2]=0|0;HEAP32[$$sroa$14$i+4>>2]=0|0;HEAP32[$$sroa$14$i+8>>2]=0|0;HEAP32[$$sroa$14$i+12>>2]=0|0;HEAP32[$$sroa$14$i+16>>2]=0|0;HEAP32[$$sroa$14$i+20>>2]=0|0;
 HEAP32[$1>>2] = 1;
 ;HEAP32[$12+0>>2]=HEAP32[$scale$i+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$scale$i+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$scale$i+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$scale$i+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$scale$i+16>>2]|0;HEAP32[$12+20>>2]=HEAP32[$scale$i+20>>2]|0;
 HEAPF32[$2>>2] = Math_fround(0.0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 HEAPF32[$8>>2] = Math_fround(10.0);
 HEAPF32[$9>>2] = Math_fround(0.800000011920928955078);
 HEAPF32[$10>>2] = Math_fround(1.5);
 ;HEAP32[$11+0>>2]=HEAP32[$$sroa$14$i+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$$sroa$14$i+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$$sroa$14$i+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$$sroa$14$i+12>>2]|0;HEAP32[$11+16>>2]=HEAP32[$$sroa$14$i+16>>2]|0;
 HEAPF32[$16>>2] = Math_fround(0.0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 72|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 / Math_fround(360.0));
 $21 = Math_fround($20 * Math_fround(2.0));
 $22 = Math_fround($21 * Math_fround(3.14159274101257324219));
 $23 = (Math_fround(+(Math_cos((+$22)))));
 $24 = $23 < Math_fround(0.0);
 $storemerge = $24 ? Math_fround(0.0) : $23;
 HEAPF32[$5>>2] = $storemerge;
 $25 = (($this) + 68|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 HEAPF32[$6>>2] = $26;
 $27 = (($this) + 76|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$7>>2] = $28;
 $29 = (($desc) + 96|0);
 HEAP32[$29>>2] = $this;
 $30 = (($this) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($31)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($scale$i,$32);
 $33 = (($this) + 80|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($scale$i) + 4|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 * $36);
 $38 = $37 < Math_fround(0.0);
 if ($38) {
  $39 = Math_fround(-$37);
  $41 = $39;
 } else {
  $41 = $37;
 }
 $40 = $41 < Math_fround(9.99999974737875163555E-6);
 $42 = $40 ? Math_fround(9.99999974737875163555E-6) : $41;
 $43 = Math_fround(HEAPF32[$scale$i>>2]);
 $44 = $43 < Math_fround(0.0);
 if ($44) {
  $45 = Math_fround(-$43);
  $51 = $45;
 } else {
  $51 = $43;
 }
 $46 = (($scale$i) + 8|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = $47 < Math_fround(0.0);
 if ($48) {
  $49 = Math_fround(-$47);
  $52 = $49;
 } else {
  $52 = $47;
 }
 $50 = $51 < $52;
 $53 = $50 ? $52 : $51;
 $54 = (($this) + 84|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * $53);
 $57 = Math_fround($56 * Math_fround(2.0));
 $58 = Math_fround($42 - $57);
 $59 = $58 < Math_fround(9.99999974737875163555E-6);
 $60 = $59 ? Math_fround(9.99999974737875163555E-6) : $58;
 $61 = $56 < Math_fround(9.99999974737875163555E-6);
 $62 = $61 ? Math_fround(9.99999974737875163555E-6) : $56;
 HEAPF32[$16>>2] = $62;
 HEAPF32[$15>>2] = $60;
 $63 = HEAP32[$30>>2]|0;
 $64 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($63)|0);
 $65 = (($this) + 88|0);
 __ZNK9Transform14TransformPointERK8Vector3f($0,$64,$65);
 $66 = Math_fround(HEAPF32[$0>>2]);
 $67 = +$66;
 $68 = (($0) + 4|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = +$69;
 $71 = (($0) + 8|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = +$72;
 HEAPF64[$12>>3] = $67;
 $74 = (($desc) + 16|0);
 HEAPF64[$74>>3] = $70;
 $75 = (($desc) + 24|0);
 HEAPF64[$75>>3] = $73;
 $76 = (__Z17GetPhysicsManagerv()|0);
 $77 = (__ZN14PhysicsManager20GetDefaultPxMaterialEv($76)|0);
 $78 = (($desc) + 92|0);
 HEAP32[$78>>2] = $77;
 HEAP32[$17>>2] = 1;
 HEAP32[$11>>2] = 687944;
 $79 = (($this) + 52|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0|0);
 if (!($81)) {
  $82 = HEAP32[$80>>2]|0;
  $83 = (($82) + 12|0);
  $84 = HEAP32[$83>>2]|0;
  FUNCTION_TABLE_vi[$84 & 4095]($80);
  HEAP32[$79>>2] = 0;
 }
 $85 = (($this) + 32|0);
 HEAP32[$85>>2] = 0;
 $86 = HEAP32[$1>>2]|0;
 $switch$i$i = ($86>>>0)<(2);
 if ($switch$i$i) {
  $87 = Math_fround(HEAPF32[$9>>2]);
  $88 = $87 < Math_fround(0.0);
  if (!($88)) {
   $89 = Math_fround(HEAPF32[$10>>2]);
   $90 = $89 < Math_fround(1.0);
   if (!($90)) {
    $91 = Math_fround(HEAPF32[$8>>2]);
    $92 = $91 < Math_fround(0.0);
    if (!($92)) {
     $93 = Math_fround(HEAPF32[$5>>2]);
     $94 = $93 < Math_fround(0.0);
     if (!($94)) {
      $95 = Math_fround(HEAPF32[$7>>2]);
      $96 = $95 < Math_fround(0.0);
      if (!($96)) {
       $97 = Math_fround(HEAPF32[$6>>2]);
       $98 = !($97 <= Math_fround(0.0));
       if ($98) {
        $99 = HEAP32[$78>>2]|0;
        $100 = ($99|0)==(0|0);
        if (!($100)) {
         $101 = (($desc) + 80|0);
         $102 = HEAP32[$101>>2]|0;
         $103 = ($102|0)==(0|0);
         if (!($103)) {
          $104 = HEAP32[$11>>2]|0;
          $105 = ($104|0)==(0|0);
          if ($105) {
           HEAP32[$11>>2] = $102;
           $106 = (__Z15PxGetFoundationv()|0);
           $107 = HEAP32[$106>>2]|0;
           $108 = (($107) + 4|0);
           $109 = HEAP32[$108>>2]|0;
           $110 = (FUNCTION_TABLE_ii[$109 & 4095]($106)|0);
           $111 = HEAP32[$110>>2]|0;
           $112 = (($111) + 8|0);
           $113 = HEAP32[$112>>2]|0;
           FUNCTION_TABLE_viiiii[$113 & 255]($110,2,688424,688520,602);
          }
         }
         $114 = Math_fround(HEAPF32[$16>>2]);
         $115 = !($114 <= Math_fround(0.0));
         if ($115) {
          $116 = Math_fround(HEAPF32[$15>>2]);
          $117 = !($116 <= Math_fround(0.0));
          if ($117) {
           $118 = Math_fround(HEAPF32[$7>>2]);
           $119 = Math_fround($114 * Math_fround(2.0));
           $120 = Math_fround($119 + $116);
           $not$$i = !($118 > $120);
           if ($not$$i) {
            $125 = HEAP32[688192>>2]|0;
            $126 = HEAP32[$125>>2]|0;
            $127 = (($126) + 16|0);
            $128 = HEAP32[$127>>2]|0;
            $129 = (FUNCTION_TABLE_iii[$128 & 4095]($125,$desc)|0);
            HEAP32[$79>>2] = $129;
            $130 = HEAP32[$129>>2]|0;
            $131 = (($130) + 36|0);
            $132 = HEAP32[$131>>2]|0;
            $133 = (FUNCTION_TABLE_ii[$132 & 4095]($129)|0);
            $134 = HEAP32[$133>>2]|0;
            $135 = (($134) + 108|0);
            $136 = HEAP32[$135>>2]|0;
            (FUNCTION_TABLE_iiiii[$136 & 511]($133,$85,1,0)|0);
            $137 = HEAP32[$85>>2]|0;
            $138 = (($137) + 8|0);
            HEAP32[$138>>2] = $this;
            __ZN8Collider10SetupLayerEv($this);
            $139 = (($this) + 100|0);
            $140 = HEAP8[$139>>0]|0;
            $141 = ($140<<24>>24)==(0);
            __ZN8Collider19SetDisableCollisionEb($this,$141);
            $142 = HEAP32[$85>>2]|0;
            $143 = (($this) + 60|0);
            HEAP32[$143>>2] = $142;
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $121 = ($this|0)==(0|0);
 if ($121) {
  $124 = 0;
 } else {
  $122 = (($this) + 4|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = $123;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688136,0,688184,322,1,$124,0,0);
 STACKTOP = sp;return;
}
function __ZN5physx23PxCapsuleControllerDesc12setToDefaultEv($this) {
 $this = $this|0;
 var $$sroa$14 = 0, $$sroa$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$sroa$2 = sp;
 $$sroa$14 = sp + 24|0;
 ;HEAP32[$$sroa$2+0>>2]=0|0;HEAP32[$$sroa$2+4>>2]=0|0;HEAP32[$$sroa$2+8>>2]=0|0;HEAP32[$$sroa$2+12>>2]=0|0;HEAP32[$$sroa$2+16>>2]=0|0;HEAP32[$$sroa$2+20>>2]=0|0;
 ;HEAP32[$$sroa$14+0>>2]=0|0;HEAP32[$$sroa$14+4>>2]=0|0;HEAP32[$$sroa$14+8>>2]=0|0;HEAP32[$$sroa$14+12>>2]=0|0;HEAP32[$$sroa$14+16>>2]=0|0;HEAP32[$$sroa$14+20>>2]=0|0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 1;
 $1 = (($this) + 8|0);
 ;HEAP32[$1+0>>2]=HEAP32[$$sroa$2+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$sroa$2+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$sroa$2+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$$sroa$2+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$$sroa$2+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$$sroa$2+20>>2]|0;
 $2 = (($this) + 32|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($this) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 40|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($this) + 44|0);
 HEAPF32[$5>>2] = Math_fround(0.707000017166137695313);
 $6 = (($this) + 48|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 52|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 56|0);
 HEAPF32[$8>>2] = Math_fround(0.100000001490116119385);
 $9 = (($this) + 60|0);
 HEAPF32[$9>>2] = Math_fround(0.5);
 $10 = (($this) + 64|0);
 HEAPF32[$10>>2] = Math_fround(10.0);
 $11 = (($this) + 68|0);
 HEAPF32[$11>>2] = Math_fround(0.800000011920928955078);
 $12 = (($this) + 72|0);
 HEAPF32[$12>>2] = Math_fround(1.5);
 $13 = (($this) + 76|0);
 ;HEAP32[$13+0>>2]=HEAP32[$$sroa$14+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$$sroa$14+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$$sroa$14+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$$sroa$14+12>>2]|0;HEAP32[$13+16>>2]=HEAP32[$$sroa$14+16>>2]|0;HEAP32[$13+20>>2]=HEAP32[$$sroa$14+20>>2]|0;
 $14 = (($this) + 100|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($this) + 104|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($this) + 108|0);
 HEAP32[$16>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK5physx23PxCapsuleControllerDesc7isValidEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $not$ = 0, $switch$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $switch$i = ($1>>>0)<(2);
 if ($switch$i) {
  $2 = (($this) + 68|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = $3 < Math_fround(0.0);
  if ($4) {
   $$0 = 0;
  } else {
   $5 = (($this) + 72|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = $6 < Math_fround(1.0);
   if ($7) {
    $$0 = 0;
   } else {
    $8 = (($this) + 64|0);
    $9 = Math_fround(HEAPF32[$8>>2]);
    $10 = $9 < Math_fround(0.0);
    if ($10) {
     $$0 = 0;
    } else {
     $11 = (($this) + 44|0);
     $12 = Math_fround(HEAPF32[$11>>2]);
     $13 = $12 < Math_fround(0.0);
     if ($13) {
      $$0 = 0;
     } else {
      $14 = (($this) + 60|0);
      $15 = Math_fround(HEAPF32[$14>>2]);
      $16 = $15 < Math_fround(0.0);
      if ($16) {
       $$0 = 0;
      } else {
       $17 = (($this) + 56|0);
       $18 = Math_fround(HEAPF32[$17>>2]);
       $19 = !($18 <= Math_fround(0.0));
       if ($19) {
        $20 = (($this) + 92|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)==(0|0);
        if ($22) {
         $$0 = 0;
        } else {
         $23 = (($this) + 80|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = ($24|0)==(0|0);
         if (!($25)) {
          $26 = (($this) + 76|0);
          $27 = HEAP32[$26>>2]|0;
          $28 = ($27|0)==(0|0);
          if ($28) {
           HEAP32[$26>>2] = $24;
           $29 = (__Z15PxGetFoundationv()|0);
           $30 = HEAP32[$29>>2]|0;
           $31 = (($30) + 4|0);
           $32 = HEAP32[$31>>2]|0;
           $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
           $34 = HEAP32[$33>>2]|0;
           $35 = (($34) + 8|0);
           $36 = HEAP32[$35>>2]|0;
           FUNCTION_TABLE_viiiii[$36 & 255]($33,2,688424,688520,602);
          }
         }
         $37 = (($this) + 100|0);
         $38 = Math_fround(HEAPF32[$37>>2]);
         $39 = !($38 <= Math_fround(0.0));
         if ($39) {
          $40 = (($this) + 104|0);
          $41 = Math_fround(HEAPF32[$40>>2]);
          $42 = !($41 <= Math_fround(0.0));
          if ($42) {
           $43 = Math_fround(HEAPF32[$14>>2]);
           $44 = Math_fround($38 * Math_fround(2.0));
           $45 = Math_fround($44 + $41);
           $not$ = !($43 > $45);
           $$0 = $not$;
          } else {
           $$0 = 0;
          }
         } else {
          $$0 = 0;
         }
        }
       } else {
        $$0 = 0;
       }
      }
     }
    }
   }
  }
 } else {
  $$0 = 0;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN5physx23PxCapsuleControllerDescD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN19CharacterController9GetBoundsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $7 = 0, $8 = 0, $9 = 0, $aabb = 0, $center2 = 0, $p = 0, $scale$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $scale$i = sp + 48|0;
 $p = sp;
 $center2 = sp + 12|0;
 $aabb = sp + 24|0;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN8Collider9GetBoundsEv($agg$result,$this);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($4)|0);
 $6 = (($this) + 88|0);
 __ZNK9Transform14TransformPointERK8Vector3f($p,$5,$6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($7)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($scale$i,$8);
 $9 = (($this) + 80|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($scale$i) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = $13 < Math_fround(0.0);
 if ($14) {
  $15 = Math_fround(-$13);
  $17 = $15;
 } else {
  $17 = $13;
 }
 $16 = $17 < Math_fround(9.99999974737875163555E-6);
 $18 = $16 ? Math_fround(9.99999974737875163555E-6) : $17;
 $19 = Math_fround(HEAPF32[$scale$i>>2]);
 $20 = $19 < Math_fround(0.0);
 if ($20) {
  $21 = Math_fround(-$19);
  $27 = $21;
 } else {
  $27 = $19;
 }
 $22 = (($scale$i) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = $23 < Math_fround(0.0);
 if ($24) {
  $25 = Math_fround(-$23);
  $28 = $25;
 } else {
  $28 = $23;
 }
 $26 = $27 < $28;
 $29 = $26 ? $28 : $27;
 $30 = (($this) + 84|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $29);
 $33 = Math_fround($32 * Math_fround(2.0));
 $34 = Math_fround($18 - $33);
 $35 = $34 < Math_fround(9.99999974737875163555E-6);
 $36 = $35 ? Math_fround(9.99999974737875163555E-6) : $34;
 $37 = $32 < Math_fround(9.99999974737875163555E-6);
 $38 = $37 ? Math_fround(9.99999974737875163555E-6) : $32;
 $39 = Math_fround($36 * Math_fround(0.5));
 $40 = Math_fround(HEAPF32[$p>>2]);
 $41 = Math_fround($40 + Math_fround(0.0));
 $42 = (($p) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($43 + $39);
 $45 = (($p) + 8|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 + Math_fround(0.0));
 $48 = Math_fround($36 * Math_fround(-0.5));
 $49 = Math_fround($43 + $48);
 HEAPF32[$center2>>2] = $41;
 $50 = (($center2) + 4|0);
 HEAPF32[$50>>2] = $49;
 $51 = (($center2) + 8|0);
 HEAPF32[$51>>2] = $47;
 $52 = (($aabb) + 12|0);
 ;HEAP32[$aabb+0>>2]=0|0;HEAP32[$aabb+4>>2]=0|0;HEAP32[$aabb+8>>2]=0|0;
 HEAPF32[$aabb>>2] = $41;
 $53 = (($aabb) + 4|0);
 HEAPF32[$53>>2] = $44;
 $54 = (($aabb) + 8|0);
 HEAPF32[$54>>2] = $47;
 ;HEAP32[$52+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$52+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$52+8>>2]=HEAP32[616680+8>>2]|0;
 __ZN4AABB11EncapsulateERK8Vector3f($aabb,$center2);
 $55 = Math_fround(HEAPF32[$52>>2]);
 $56 = Math_fround($38 + $55);
 HEAPF32[$52>>2] = $56;
 $57 = (($aabb) + 16|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($38 + $58);
 HEAPF32[$57>>2] = $59;
 $60 = (($aabb) + 20|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($38 + $61);
 HEAPF32[$60>>2] = $62;
 ;HEAP32[$agg$result+0>>2]=HEAP32[$aabb+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$aabb+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$aabb+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$aabb+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$aabb+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$aabb+20>>2]|0;
 STACKTOP = sp;return;
}
function __ZN19CharacterController7CleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($1);
 HEAP32[$0>>2] = 0;
 $6 = (($this) + 32|0);
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN19CharacterController16TransformChangedEi($this,$change) {
 $this = $this|0;
 $change = $change|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0.0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0.0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $scale$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $scale$i = sp + 36|0;
 $0 = sp;
 $1 = sp + 24|0;
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $change & 8;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($this) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($8)|0);
  __ZNK9Transform18GetWorldScaleLossyEv($scale$i,$9);
  $10 = (($this) + 80|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($scale$i) + 4|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($11 * $13);
  $15 = $14 < Math_fround(0.0);
  if ($15) {
   $16 = Math_fround(-$14);
   $18 = $16;
  } else {
   $18 = $14;
  }
  $17 = $18 < Math_fround(9.99999974737875163555E-6);
  $19 = $17 ? Math_fround(9.99999974737875163555E-6) : $18;
  $20 = Math_fround(HEAPF32[$scale$i>>2]);
  $21 = $20 < Math_fround(0.0);
  if ($21) {
   $22 = Math_fround(-$20);
   $28 = $22;
  } else {
   $28 = $20;
  }
  $23 = (($scale$i) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = $24 < Math_fround(0.0);
  if ($25) {
   $26 = Math_fround(-$24);
   $29 = $26;
  } else {
   $29 = $24;
  }
  $27 = $28 < $29;
  $30 = $27 ? $29 : $28;
  $31 = (($this) + 84|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($32 * $30);
  $34 = Math_fround($33 * Math_fround(2.0));
  $35 = Math_fround($19 - $34);
  $36 = $35 < Math_fround(9.99999974737875163555E-6);
  $37 = $36 ? Math_fround(9.99999974737875163555E-6) : $35;
  $38 = $33 < Math_fround(9.99999974737875163555E-6);
  $39 = $38 ? Math_fround(9.99999974737875163555E-6) : $33;
  $40 = HEAP32[$2>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 112|0);
  $43 = HEAP32[$42>>2]|0;
  (FUNCTION_TABLE_iif[$43 & 31]($40,$39)|0);
  $44 = HEAP32[$2>>2]|0;
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 120|0);
  $47 = HEAP32[$46>>2]|0;
  (FUNCTION_TABLE_iif[$47 & 31]($44,$37)|0);
 }
 $48 = $change & 1;
 $49 = ($48|0)==(0);
 if ($49) {
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$2>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 20|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 24|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($55)|0);
 $57 = (($this) + 88|0);
 __ZNK9Transform14TransformPointERK8Vector3f($1,$56,$57);
 $58 = Math_fround(HEAPF32[$1>>2]);
 $59 = +$58;
 $60 = (($1) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = +$61;
 $63 = (($1) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = +$64;
 HEAPF64[$0>>3] = $59;
 $66 = (($0) + 8|0);
 HEAPF64[$66>>3] = $62;
 $67 = (($0) + 16|0);
 HEAPF64[$67>>3] = $65;
 (FUNCTION_TABLE_iii[$53 & 4095]($50,$0)|0);
 $68 = (($this) + 104|0);
 HEAPF32[$68>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN19CharacterController12ScaleChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $scale$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scale$i = sp;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($4)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($scale$i,$5);
 $6 = (($this) + 80|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($scale$i) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 * $9);
 $11 = $10 < Math_fround(0.0);
 if ($11) {
  $12 = Math_fround(-$10);
  $14 = $12;
 } else {
  $14 = $10;
 }
 $13 = $14 < Math_fround(9.99999974737875163555E-6);
 $15 = $13 ? Math_fround(9.99999974737875163555E-6) : $14;
 $16 = Math_fround(HEAPF32[$scale$i>>2]);
 $17 = $16 < Math_fround(0.0);
 if ($17) {
  $18 = Math_fround(-$16);
  $24 = $18;
 } else {
  $24 = $16;
 }
 $19 = (($scale$i) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = $20 < Math_fround(0.0);
 if ($21) {
  $22 = Math_fround(-$20);
  $25 = $22;
 } else {
  $25 = $20;
 }
 $23 = $24 < $25;
 $26 = $23 ? $25 : $24;
 $27 = (($this) + 84|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $26);
 $30 = Math_fround($29 * Math_fround(2.0));
 $31 = Math_fround($15 - $30);
 $32 = $31 < Math_fround(9.99999974737875163555E-6);
 $33 = $32 ? Math_fround(9.99999974737875163555E-6) : $31;
 $34 = $29 < Math_fround(9.99999974737875163555E-6);
 $35 = $34 ? Math_fround(9.99999974737875163555E-6) : $29;
 $36 = HEAP32[$0>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 112|0);
 $39 = HEAP32[$38>>2]|0;
 (FUNCTION_TABLE_iif[$39 & 31]($36,$35)|0);
 $40 = HEAP32[$0>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 120|0);
 $43 = HEAP32[$42>>2]|0;
 (FUNCTION_TABLE_iif[$43 & 31]($40,$33)|0);
 STACKTOP = sp;return;
}
function __ZN19CharacterController22ApplyRootMotionBuiltinEP14RootMotionData($this,$rootMotion) {
 $this = $this|0;
 $rootMotion = $rootMotion|0;
 var $$$i = Math_fround(0), $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $deltaMotion = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $deltaMotion = sp;
 $1 = (($this) + 37|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__Z14GetTimeManagerv()|0);
 $5 = (($4) + 104|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (__Z17GetPhysicsManagerv()|0);
 __ZN14PhysicsManager10GetGravityEv($0,$7);
 $8 = (($0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($6 * $9);
 $11 = (($this) + 104|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 + $10);
 HEAPF32[$11>>2] = $13;
 $14 = (($deltaMotion) + 4|0);
 ;HEAP32[$deltaMotion+0>>2]=HEAP32[$rootMotion+0>>2]|0;HEAP32[$deltaMotion+4>>2]=HEAP32[$rootMotion+4>>2]|0;HEAP32[$deltaMotion+8>>2]=HEAP32[$rootMotion+8>>2]|0;
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($6 * $13);
 $17 = (($rootMotion) + 28|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = $18 < Math_fround(0.0);
 if ($19) {
  $$0$i = Math_fround(0.0);
 } else {
  $20 = $18 > Math_fround(1.0);
  $$$i = $20 ? Math_fround(1.0) : $18;
  $$0$i = $$$i;
 }
 $21 = Math_fround($16 * $$0$i);
 $22 = Math_fround(Math_fround(1.0) - $$0$i);
 $23 = Math_fround($15 * $22);
 $24 = Math_fround($21 + $23);
 HEAPF32[$14>>2] = $24;
 (__ZN19CharacterController4MoveERK8Vector3f($this,$deltaMotion)|0);
 $25 = (($this) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($26)|0);
 $28 = (($rootMotion) + 12|0);
 __ZN9Transform11SetRotationERK11Quaternionf($27,$28);
 $29 = (($rootMotion) + 32|0);
 HEAP8[$29>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN19CharacterController15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(143,565032,1971,100006);
 STACKTOP = sp;return;
}
function __ZZN19CharacterController15InitializeClassEvEN52FunctorImpl_CharacterController_kAnimatorMoveBuiltin4CallEPviR11MessageData($object,$messageID,$messageData) {
 $object = $object|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($messageData) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN19CharacterController22ApplyRootMotionBuiltinEP14RootMotionData($object,$1);
 STACKTOP = sp;return;
}
function __ZN19CharacterController12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN19CharacterController13GetSlopeLimitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN19CharacterController13GetStepOffsetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN19CharacterController9GetCenterEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN19CharacterController12SetIsTriggerEb($this,$trigger) {
 $this = $this|0;
 $trigger = $trigger|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($trigger) {
  $0 = ($this|0)==(0|0);
  if ($0) {
   $3 = 0;
  } else {
   $1 = (($this) + 4|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = $2;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688200,0,688184,600,1,$3,0,0);
 }
 $4 = (($this) + 36|0);
 HEAP8[$4>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN19CharacterController23CreateControllerManagerEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z16GetDynamicsScenev()|0);
 $1 = (__Z25PxCreateControllerManagerRN5physx7PxSceneE($0)|0);
 HEAP32[688192>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN19CharacterController24CleanupControllerManagerEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[688192>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($0);
 HEAP32[688192>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN19CharacterController23UpdateControllerManagerEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[688192>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($0);
 HEAP32[688192>>2] = 0;
 $4 = (__Z16GetDynamicsScenev()|0);
 $5 = (__Z25PxCreateControllerManagerRN5physx7PxSceneE($4)|0);
 HEAP32[688192>>2] = $5;
 STACKTOP = sp;return;
}
function __Z33RegisterClass_CharacterControllerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(143,190,191,0,192);
 STACKTOP = sp;return;
}
function __ZN19CharacterController13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(56)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN8Collider13RegisterClassEv();
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 19;
 dest=$3+0|0; src=688248+0|0; stop=dest+19|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 19|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,143,56,($0|0),144,(2552|0),0,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN19CharacterController7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(144,$$byval_copy2,1,16,688184,85)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1972,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((687960 + 8|0));
  $6 = (($3) + 56|0);
  HEAP32[$6>>2] = ((688656 + 8|0));
  $7 = (($3) + 60|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 88|0);
  HEAPF32[$8>>2] = Math_fround(0.0);
  $9 = (($3) + 92|0);
  HEAPF32[$9>>2] = Math_fround(0.0);
  $10 = (($3) + 96|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($3) + 52|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 104|0);
  $13 = (($3) + 100|0);
  ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;HEAP32[$12+20>>2]=0|0;HEAP32[$12+24>>2]=0|0;HEAP32[$12+28>>2]=0|0;
  HEAP8[$13>>0] = 1;
  $14 = (($3) + 136|0);
  HEAPF64[$14>>3] = 0.0;
  STACKTOP = sp;return ($3|0);
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(688184|0),85);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $19 = ___cxa_find_matching_catch(0|0)|0;
  $20 = tempRet0;
  ___clang_call_terminate($19);
  // unreachable;
 } else {
  ___resumeException($15|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK19CharacterController25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 143;
}
function __ZN19CharacterController23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688272,688248,$this,0);
 __ZN19CharacterController8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN19CharacterController23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,688272,688248,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN19CharacterController8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN19CharacterController23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19CharacterController8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN19CharacterController23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19CharacterController8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN19CharacterController23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19CharacterController8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN19CharacterController23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN19CharacterControllerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((687960 + 8|0));
 __ZN8ColliderD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN19CharacterControllerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((687960 + 8|0));
 __THREW__ = 0;
 invoke_vi(3629,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN19CharacterController8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5$i$i$i = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 80|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$0>>2]);
  HEAPF32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre6;
 }
 $8 = (($this) + 84|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre7 = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $16 = $$pre7;$18 = $$pre8;
 }
 $14 = (($this) + 72|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $22 = $$pre9;$24 = $$pre10;
 }
 $20 = (($this) + 76|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$22>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $28 = $$pre11;$30 = $$pre12;
 }
 $26 = (($this) + 68|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)<($30>>>0);
 if ($29) {
  $31 = Math_fround(HEAPF32[$26>>2]);
  HEAPF32[$28>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $34 = $$pre13;$36 = $$pre14;
 }
 $32 = (($this) + 64|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)<($36>>>0);
 if ($35) {
  $37 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$34>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$32,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $40 = $$pre15;$42 = $$pre16;
 }
 $38 = (($this) + 88|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)<($42>>>0);
 if ($41) {
  $43 = Math_fround(HEAPF32[$38>>2]);
  HEAPF32[$40>>2] = $43;
  HEAP32[$1>>2] = $39;
  $46 = $39;$48 = $42;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$38,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre3$i$i$i = HEAP32[$4>>2]|0;
  $46 = $$pre$i$i$i;$48 = $$pre3$i$i$i;
 }
 $44 = (($this) + 92|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)<($48>>>0);
 if ($47) {
  $49 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$46>>2] = $49;
  HEAP32[$1>>2] = $45;
  $52 = $45;$54 = $48;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$44,4);
  $$pre4$i$i$i = HEAP32[$1>>2]|0;
  $$pre5$i$i$i = HEAP32[$4>>2]|0;
  $52 = $$pre4$i$i$i;$54 = $$pre5$i$i$i;
 }
 $50 = (($this) + 96|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)<($54>>>0);
 if ($53) {
  $55 = Math_fround(HEAPF32[$50>>2]);
  HEAPF32[$52>>2] = $55;
  HEAP32[$1>>2] = $51;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$50,4);
  STACKTOP = sp;return;
 }
}
function __ZN19CharacterController8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i19Z2D = 0, $$pre$phi$i$i$i24Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0;
 var $$pre33 = 0, $$pre34 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 80|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre26 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $0;$13 = $$pre;$15 = $$pre26;$9 = $$pre$i$i$i;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $0;$13 = $3;$15 = $5;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $10;
 $11 = (($this) + 84|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i3 = HEAP32[$11>>2]|0;
  $$pre27 = HEAP32[$1>>2]|0;
  $$pre28 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i4Z2D = $11;$18 = $$pre$i$i$i3;$22 = $$pre27;$24 = $$pre28;
 } else {
  $16 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$1>>2] = $12;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $11;$18 = $17;$22 = $12;$24 = $15;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $19;
 $20 = (($this) + 72|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre$i$i$i8 = HEAP32[$20>>2]|0;
  $$pre29 = HEAP32[$1>>2]|0;
  $$pre30 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i9Z2D = $20;$27 = $$pre$i$i$i8;$31 = $$pre29;$33 = $$pre30;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $26 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $20;$27 = $26;$31 = $21;$33 = $24;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $28;
 $29 = (($this) + 76|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$29,4);
  $$pre$i$i$i13 = HEAP32[$29>>2]|0;
  $$pre31 = HEAP32[$1>>2]|0;
  $$pre32 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i14Z2D = $29;$36 = $$pre$i$i$i13;$40 = $$pre31;$42 = $$pre32;
 } else {
  $34 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$29>>2] = $34;
  HEAP32[$1>>2] = $30;
  $35 = (HEAPF32[tempDoublePtr>>2]=$34,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $29;$36 = $35;$40 = $30;$42 = $33;
 }
 $37 = (_llvm_bswap_i32(($36|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $37;
 $38 = (($this) + 68|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)>($42>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
  $$pre$i$i$i18 = HEAP32[$38>>2]|0;
  $$pre33 = HEAP32[$1>>2]|0;
  $$pre34 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i19Z2D = $38;$45 = $$pre$i$i$i18;$49 = $$pre33;$51 = $$pre34;
 } else {
  $43 = Math_fround(HEAPF32[$40>>2]);
  HEAPF32[$38>>2] = $43;
  HEAP32[$1>>2] = $39;
  $44 = (HEAPF32[tempDoublePtr>>2]=$43,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i19Z2D = $38;$45 = $44;$49 = $39;$51 = $42;
 }
 $46 = (_llvm_bswap_i32(($45|0))|0);
 HEAP32[$$pre$phi$i$i$i19Z2D>>2] = $46;
 $47 = (($this) + 64|0);
 $48 = (($49) + 4|0);
 $50 = ($48>>>0)>($51>>>0);
 if ($50) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$47,4);
  $$pre$i$i$i23 = HEAP32[$47>>2]|0;
  $$pre$phi$i$i$i24Z2D = $47;$54 = $$pre$i$i$i23;
  $55 = (_llvm_bswap_i32(($54|0))|0);
  HEAP32[$$pre$phi$i$i$i24Z2D>>2] = $55;
  $56 = (($this) + 88|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$56,0,0);
  STACKTOP = sp;return;
 } else {
  $52 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$47>>2] = $52;
  HEAP32[$1>>2] = $48;
  $53 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i24Z2D = $47;$54 = $53;
  $55 = (_llvm_bswap_i32(($54|0))|0);
  HEAP32[$$pre$phi$i$i$i24Z2D>>2] = $55;
  $56 = (($this) + 88|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$56,0,0);
  STACKTOP = sp;return;
 }
}
function __ZN19CharacterController8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5$i$i$i = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 80|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre6;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 84|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre7 = HEAP32[$1>>2]|0;
  $$pre8 = HEAP32[$4>>2]|0;
  $16 = $$pre7;$18 = $$pre8;
 } else {
  $13 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 72|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $22 = $$pre9;$24 = $$pre10;
 } else {
  $19 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 }
 $20 = (($this) + 76|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $28 = $$pre11;$30 = $$pre12;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 }
 $26 = (($this) + 68|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $34 = $$pre13;$36 = $$pre14;
 } else {
  $31 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 }
 $32 = (($this) + 64|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$32,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $40 = $$pre15;$42 = $$pre16;
 } else {
  $37 = Math_fround(HEAPF32[$34>>2]);
  HEAPF32[$32>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 }
 $38 = (($this) + 88|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)>($42>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre3$i$i$i = HEAP32[$4>>2]|0;
  $46 = $$pre$i$i$i;$48 = $$pre3$i$i$i;
 } else {
  $43 = Math_fround(HEAPF32[$40>>2]);
  HEAPF32[$38>>2] = $43;
  HEAP32[$1>>2] = $39;
  $46 = $39;$48 = $42;
 }
 $44 = (($this) + 92|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)>($48>>>0);
 if ($47) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$44,4);
  $$pre4$i$i$i = HEAP32[$1>>2]|0;
  $$pre5$i$i$i = HEAP32[$4>>2]|0;
  $52 = $$pre4$i$i$i;$54 = $$pre5$i$i$i;
 } else {
  $49 = Math_fround(HEAPF32[$46>>2]);
  HEAPF32[$44>>2] = $49;
  HEAP32[$1>>2] = $45;
  $52 = $45;$54 = $48;
 }
 $50 = (($this) + 96|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)>($54>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$50,4);
  STACKTOP = sp;return;
 } else {
  $55 = Math_fround(HEAPF32[$52>>2]);
  HEAPF32[$50>>2] = $55;
  HEAP32[$1>>2] = $51;
  STACKTOP = sp;return;
 }
}
function __ZN19CharacterController8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN8Collider8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 80|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,688280,0);
 $1 = (($this) + 84|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,688296,0);
 $2 = (($this) + 72|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$2,688312,0);
 $3 = (($this) + 76|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$3,688328,0);
 $4 = (($this) + 68|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$4,688344,0);
 $5 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,688360,0);
 $6 = (($this) + 88|0);
 $7 = HEAP32[580776>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,688384,$7,$converter$i$i,1)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($8|0)>(0);
  if ($10) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,688400,0);
   $11 = (($this) + 92|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$11,688408,0);
   $12 = (($this) + 96|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,688416,0);
  } else {
   $13 = HEAP32[$converter$i$i>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    (FUNCTION_TABLE_iii[$13 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $15 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = Math_fround(HEAPF32[$2>>2]);
 $17 = $16 < Math_fround(45.0);
 $18 = $17 ? $16 : Math_fround(45.0);
 HEAPF32[$2>>2] = $18;
 STACKTOP = sp;return;
}
function __ZN19CharacterController8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 80|0);
 $1 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688280,$1,$0,2048);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 84|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688296,$1,$8,2048);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 72|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688312,$1,$13,2048);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 76|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688328,$1,$18,2048);
 $19 = HEAP32[$2>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 68|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688344,$1,$23,2048);
 $24 = HEAP32[$2>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688360,$1,$28,0);
 $29 = HEAP32[$2>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$5>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = (($this) + 88|0);
 $34 = HEAP32[580776>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688384,$34,$33,0);
 $35 = (($transfer) + 16|0);
 $36 = (__ZNK16TypeTreeIterator7GetNodeEv($35)|0);
 $37 = (($36) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 | 2097152;
 $40 = HEAP32[$2>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$5>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 20|0);
 HEAP32[$43>>2] = $39;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688400,$1,$33,0);
 $44 = HEAP32[$2>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$5>>2]|0;
 $47 = ((($45) + (($46*24)|0)|0) + 12|0);
 HEAP32[$47>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $48 = (($this) + 92|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688408,$1,$48,0);
 $49 = HEAP32[$2>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$5>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $53 = (($this) + 96|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,688416,$1,$53,0);
 $54 = HEAP32[$2>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$5>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN5physx23PxCapsuleControllerDescD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN23ControllerContactFilter9preFilterERKN5physx12PxFilterDataEPKNS0_7PxShapeEPKNS0_12PxRigidActorERNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEE($this,$filterData0,$shape,$actor,$filterFlags) {
 $this = $this|0;
 $filterData0 = $filterData0|0;
 $shape = $shape|0;
 $actor = $actor|0;
 $filterFlags = $filterFlags|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $filterData1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $filterData1 = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($shape|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($shape|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$shape>>2]|0;
  $5 = (($4) + 92|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($filterData1,$shape);
  $7 = HEAP32[$filterData0>>2]|0;
  $8 = $7 & 255;
  $9 = HEAP32[$filterData1>>2]|0;
  $10 = $9 & 255;
  $11 = (__Z17GetPhysicsManagerv()|0);
  $12 = (__ZN14PhysicsManager18GetIgnoreCollisionEii($11,$8,$10)|0);
  $13 = (__ZN14PhysicsManager18GetIgnoreCollisionEPKN5physx12PxFilterDataES3_($11,$filterData0,$filterData1)|0);
  $brmerge = $12 | $13;
  if ($brmerge) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZN23ControllerContactFilter10postFilterERKN5physx12PxFilterDataERKNS0_10PxQueryHitE($this,$filterData,$hit) {
 $this = $this|0;
 $filterData = $filterData|0;
 $hit = $hit|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2;
}
function __ZN23ControllerContactFilterD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN19ControllerHitReport10onShapeHitERKN5physx20PxControllerShapeHitE($this,$hit) {
 $this = $this|0;
 $hit = $hit|0;
 var $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0.0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0.0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp;
 $1 = (($hit) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$hit>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 88|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
 $10 = (($9) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (__ZN5Unity10GameObject17WillHandleMessageERK17MessageIdentifier($11,564944)|0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 8|0);
 dest=$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 if ($18) {
  $22 = (($this) + 4|0);
  __ZNSt3__16vectorIN19ControllerHitReport29RecordedControllerColliderHitENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($22,$0);
  $$pre$i = HEAP32[$14>>2]|0;
  $33 = $$pre$i;
 } else {
  $19 = ($15|0)==(0|0);
  if ($19) {
   $21 = 0;
  } else {
   dest=$15+0|0; src=$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre$i$i = HEAP32[$14>>2]|0;
   $21 = $$pre$i$i;
  }
  $20 = (($21) + 44|0);
  HEAP32[$14>>2] = $20;
  $33 = $20;
 }
 $23 = (($hit) + 8|0);
 $24 = +HEAPF64[$23>>3];
 $25 = Math_fround($24);
 $26 = (($hit) + 16|0);
 $27 = +HEAPF64[$26>>3];
 $28 = Math_fround($27);
 $29 = (($hit) + 24|0);
 $30 = +HEAPF64[$29>>3];
 $31 = Math_fround($30);
 $32 = (($33) + -40|0);
 HEAPF32[$32>>2] = $25;
 $34 = (($33) + -36|0);
 HEAPF32[$34>>2] = $28;
 $35 = (($33) + -32|0);
 HEAPF32[$35>>2] = $31;
 $36 = (($33) + -28|0);
 $37 = (($hit) + 32|0);
 ;HEAP32[$36+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$37+8>>2]|0;
 $38 = (($33) + -16|0);
 $39 = (($hit) + 44|0);
 ;HEAP32[$38+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$39+8>>2]|0;
 $40 = (($hit) + 56|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($33) + -4|0);
 HEAPF32[$42>>2] = $41;
 $43 = (($33) + -44|0);
 HEAP32[$43>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN19ControllerHitReport15onControllerHitERKN5physx16PxControllersHitE($this,$hit) {
 $this = $this|0;
 $hit = $hit|0;
 var $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0.0, $27 = Math_fround(0), $28 = 0, $29 = 0.0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0.0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp;
 $1 = (($hit) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$hit>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 88|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $12 = (($11) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (__ZN5Unity10GameObject17WillHandleMessageERK17MessageIdentifier($13,564944)|0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = (($this) + 8|0);
 dest=$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 if ($20) {
  $24 = (($this) + 4|0);
  __ZNSt3__16vectorIN19ControllerHitReport29RecordedControllerColliderHitENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($24,$0);
  $$pre$i = HEAP32[$16>>2]|0;
  $35 = $$pre$i;
 } else {
  $21 = ($17|0)==(0|0);
  if ($21) {
   $23 = 0;
  } else {
   dest=$17+0|0; src=$0+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre$i$i = HEAP32[$16>>2]|0;
   $23 = $$pre$i$i;
  }
  $22 = (($23) + 44|0);
  HEAP32[$16>>2] = $22;
  $35 = $22;
 }
 $25 = (($hit) + 8|0);
 $26 = +HEAPF64[$25>>3];
 $27 = Math_fround($26);
 $28 = (($hit) + 16|0);
 $29 = +HEAPF64[$28>>3];
 $30 = Math_fround($29);
 $31 = (($hit) + 24|0);
 $32 = +HEAPF64[$31>>3];
 $33 = Math_fround($32);
 $34 = (($35) + -40|0);
 HEAPF32[$34>>2] = $27;
 $36 = (($35) + -36|0);
 HEAPF32[$36>>2] = $30;
 $37 = (($35) + -32|0);
 HEAPF32[$37>>2] = $33;
 $38 = (($35) + -28|0);
 $39 = (($hit) + 32|0);
 ;HEAP32[$38+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$39+8>>2]|0;
 $40 = (($35) + -16|0);
 $41 = (($hit) + 44|0);
 ;HEAP32[$40+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$41+8>>2]|0;
 $42 = (($hit) + 56|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($35) + -4|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($35) + -44|0);
 HEAP32[$45>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN19ControllerHitReport13onObstacleHitERKN5physx23PxControllerObstacleHitE($this,$hit) {
 $this = $this|0;
 $hit = $hit|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN19ControllerHitReportD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((688680 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if (!($5)) {
  $__new_last2$i$i$i$i$i$i$i = $1;
  $scevgep$i$i$i$i$i$i$i = (($4) + -44|0);
  $6 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($6)|0);
  $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
  $7 = (($uglygep3$i$i$i$i$i$i$i>>>0) / 44)&-1;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i$i$i$i$i = (($4) + (($8*44)|0)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i$i;
 }
 __ZdlPv($1);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN19ControllerHitReport29RecordedControllerColliderHitENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 44)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(97612893);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 44)&-1;
 $14 = ($13>>>0)<(48806446);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 97612893;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*44)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*44)|0)|0);
 $23 = (($22) + (($$0$i3*44)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  dest=$21+0|0; src=$__x+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $25 = (($22) + (($7*44)|0)|0);
 $26 = (($5|0) / -44)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*44)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN24ControllerFilterCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN24ControllerFilterCallback6filterERKN5physx12PxControllerES3_($this,$a,$b) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $filterData0 = 0, $filterData1 = 0, $not$brmerge = 0, $shapeA = 0, $shapeB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $shapeA = sp + 40|0;
 $shapeB = sp;
 $filterData0 = sp + 8|0;
 $filterData1 = sp + 24|0;
 $0 = HEAP32[$a>>2]|0;
 $1 = (($0) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($a)|0);
 $4 = HEAP32[$b>>2]|0;
 $5 = (($4) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($b)|0);
 $8 = (__Z17GetPhysicsManagerv()|0);
 $9 = (($7) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = 1 << $12;
 $14 = (($3) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 40|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($8) + 676|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($17<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 & $13;
 $23 = ($22|0)==(0);
 if ($23) {
  STACKTOP = sp;return 0;
 } else {
  HEAP32[$shapeA>>2] = 0;
  $24 = HEAP32[$a>>2]|0;
  $25 = (($24) + 36|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (FUNCTION_TABLE_ii[$26 & 4095]($a)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 108|0);
  $30 = HEAP32[$29>>2]|0;
  (FUNCTION_TABLE_iiiii[$30 & 511]($27,$shapeA,1,0)|0);
  HEAP32[$shapeB>>2] = 0;
  $31 = HEAP32[$b>>2]|0;
  $32 = (($31) + 36|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (FUNCTION_TABLE_ii[$33 & 4095]($b)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + 108|0);
  $37 = HEAP32[$36>>2]|0;
  (FUNCTION_TABLE_iiiii[$37 & 511]($34,$shapeB,1,0)|0);
  $38 = HEAP32[$shapeA>>2]|0;
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 92|0);
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vii[$41 & 4095]($filterData0,$38);
  $42 = HEAP32[$shapeB>>2]|0;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 92|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_vii[$45 & 4095]($filterData1,$42);
  $46 = HEAP32[$filterData0>>2]|0;
  $47 = HEAP32[$filterData1>>2]|0;
  $48 = (__ZN14PhysicsManager18GetIgnoreCollisionEii($8,$46,$47)|0);
  $49 = (__ZN14PhysicsManager18GetIgnoreCollisionEPKN5physx12PxFilterDataES3_($8,$filterData0,$filterData1)|0);
  $brmerge = $48 | $49;
  $not$brmerge = $brmerge ^ 1;
  STACKTOP = sp;return ($not$brmerge|0);
 }
 return 0|0;
}
function __ZN5Unity5Cloth18ApplyConfigurationEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $$0$i5 = 0, $$0$i6 = Math_fround(0), $$1$i = Math_fround(0), $$1$i2 = Math_fround(0), $$1$i4 = Math_fround(0), $$pre = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0;
 var $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0;
 var $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $config$i = 0, $phitmp$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 8|0;
 $config$i = sp;
 $1 = (($this) + 32|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 < Math_fround(0.0);
 if ($3) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688736,0,688784,659,1,0,0,0);
  $$1$i = Math_fround(0.0);
 } else {
  $4 = $2 > Math_fround(1.0);
  if ($4) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688792,0,688784,660,1,0,0,0);
   $$1$i = Math_fround(1.0);
  } else {
   $$1$i = $2;
  }
 }
 HEAPF32[$1>>2] = $$1$i;
 $5 = (($this) + 180|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + 264|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_viii[$10 & 4095]($0,$6,3);
  HEAPF32[$0>>2] = $$1$i;
  $11 = HEAP32[$5>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 260|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_viii[$14 & 4095]($11,3,$0);
 }
 $15 = (($this) + 36|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 __ZN5Unity5Cloth22SetStretchingStiffnessEf($this,$16);
 $17 = (($this) + 40|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = HEAP32[$5>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  $21 = ($18<<24>>24)==(0);
  if ($21) {
   $25 = Math_fround(0.0);
  } else {
   $22 = (($this) + 295|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)!=(0);
   $phitmp$i = $24 ? Math_fround(1.0) : Math_fround(0.0);
   $25 = $phitmp$i;
  }
  HEAPF32[$config$i>>2] = $25;
  $26 = (($config$i) + 4|0);
  HEAPF32[$26>>2] = Math_fround(1.0);
  $27 = HEAP32[$19>>2]|0;
  $28 = (($27) + 268|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vii[$29 & 4095]($19,$config$i);
  $$pre = HEAP32[$5>>2]|0;
  $30 = ($$pre|0)==(0|0);
  if (!($30)) {
   $31 = (($this) + 41|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = HEAP32[$$pre>>2]|0;
   $34 = (($33) + 44|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($32<<24>>24)==(0);
   FUNCTION_TABLE_viii[$35 & 4095]($$pre,2,$36);
  }
 }
 $37 = (($this) + 44|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = $38 < Math_fround(0.0);
 if ($39) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688736,0,688784,702,1,0,0,0);
  $$1$i2 = Math_fround(0.0);
 } else {
  $40 = $38 > Math_fround(1.0);
  if ($40) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688792,0,688784,703,1,0,0,0);
   $$1$i2 = Math_fround(1.0);
  } else {
   $$1$i2 = $38;
  }
 }
 HEAPF32[$37>>2] = $$1$i2;
 $41 = HEAP32[$5>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = HEAP32[$41>>2]|0;
  $44 = (($43) + 176|0);
  $45 = HEAP32[$44>>2]|0;
  HEAPF32[$0>>2] = $$1$i2;
  $46 = (($0) + 4|0);
  HEAPF32[$46>>2] = $$1$i2;
  $47 = (($0) + 8|0);
  HEAPF32[$47>>2] = $$1$i2;
  FUNCTION_TABLE_vii[$45 & 4095]($41,$0);
  $$pre7 = HEAP32[$5>>2]|0;
  $48 = ($$pre7|0)==(0|0);
  if (!($48)) {
   $49 = (($this) + 76|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = HEAP32[$$pre7>>2]|0;
   $52 = (($51) + 172|0);
   $53 = HEAP32[$52>>2]|0;
   FUNCTION_TABLE_vif[$53 & 255]($$pre7,$50);
  }
 }
 $54 = (($this) + 80|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = $55 < Math_fround(0.0);
 if ($56) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688736,0,688784,758,1,0,0,0);
  $$1$i4 = Math_fround(0.0);
 } else {
  $57 = $55 > Math_fround(1.0);
  if ($57) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688792,0,688784,759,1,0,0,0);
   $$1$i4 = Math_fround(1.0);
  } else {
   $$1$i4 = $55;
  }
 }
 HEAPF32[$54>>2] = $$1$i4;
 $58 = HEAP32[$5>>2]|0;
 $59 = ($58|0)==(0|0);
 if (!($59)) {
  $60 = HEAP32[$58>>2]|0;
  $61 = (($60) + 372|0);
  $62 = HEAP32[$61>>2]|0;
  FUNCTION_TABLE_vif[$62 & 255]($58,$$1$i4);
 }
 $63 = (($this) + 84|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = $64 < Math_fround(0.0);
 if ($65) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688736,0,688784,769,1,0,0,0);
  $$0$i = Math_fround(0.0);
 } else {
  $$0$i = $64;
 }
 HEAPF32[$63>>2] = $$0$i;
 $66 = HEAP32[$5>>2]|0;
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = HEAP32[$66>>2]|0;
  $69 = (($68) + 380|0);
  $70 = HEAP32[$69>>2]|0;
  FUNCTION_TABLE_vif[$70 & 255]($66,$$0$i);
  $$pre8 = HEAP32[$5>>2]|0;
  $71 = ($$pre8|0)==(0|0);
  if (!($71)) {
   $72 = (($this) + 88|0);
   $73 = HEAP8[$72>>0]|0;
   $74 = ($73<<24>>24)!=(0);
   $75 = HEAP32[$$pre8>>2]|0;
   $76 = (($75) + 104|0);
   $77 = HEAP32[$76>>2]|0;
   FUNCTION_TABLE_viii[$77 & 4095]($$pre8,2,$74);
  }
 }
 $78 = (($this) + 89|0);
 $79 = HEAP8[$78>>0]|0;
 $80 = ($79<<24>>24)!=(0);
 __ZN5Unity5Cloth22SetUseVirtualParticlesEb($this,$80);
 $81 = (($this) + 92|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)==(0);
 if ($83) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688872,0,688784,810,1,0,0,0);
  $$0$i5 = 1;
 } else {
  $$0$i5 = $82;
 }
 HEAP32[$81>>2] = $$0$i5;
 $84 = HEAP32[$5>>2]|0;
 $85 = ($84|0)==(0|0);
 if (!($85)) {
  $86 = HEAP32[$84>>2]|0;
  $87 = (($86) + 128|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (Math_fround(($$0$i5>>>0)));
  FUNCTION_TABLE_vif[$88 & 255]($84,$89);
 }
 $90 = (($this) + 96|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = $91 < Math_fround(0.0);
 if ($92) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688736,0,688784,820,1,0,0,0);
  $$0$i6 = Math_fround(0.0);
 } else {
  $$0$i6 = $91;
 }
 HEAPF32[$90>>2] = $$0$i6;
 $93 = HEAP32[$5>>2]|0;
 $94 = ($93|0)==(0|0);
 if ($94) {
  STACKTOP = sp;return;
 }
 $95 = HEAP32[$93>>2]|0;
 $96 = (($95) + 452|0);
 $97 = HEAP32[$96>>2]|0;
 FUNCTION_TABLE_vif[$97 & 255]($93,$$0$i6);
 STACKTOP = sp;return;
}
function __ZN5Unity5Cloth22SetStretchingStiffnessEf($this,$value) {
 $this = $this|0;
 $value = Math_fround($value);
 var $$1 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $stretchConfig = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $stretchConfig = sp + 16|0;
 $0 = sp;
 $1 = !($value <= Math_fround(0.0));
 if ($1) {
  $2 = $value > Math_fround(1.0);
  if ($2) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688792,0,688784,674,1,0,0,0);
   $$1 = Math_fround(1.0);
  } else {
   $$1 = $value;
  }
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(688840,0,688784,673,1,0,0,0);
  $$1 = Math_fround(0.0);
 }
 $3 = (($this) + 36|0);
 HEAPF32[$3>>2] = $$1;
 $4 = (($this) + 180|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + 264|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viii[$9 & 4095]($stretchConfig,$5,1);
 HEAPF32[$stretchConfig>>2] = $$1;
 $10 = HEAP32[$4>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 260|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viii[$13 & 4095]($10,1,$stretchConfig);
 $14 = HEAP32[$4>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 264|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_viii[$17 & 4095]($0,$14,2);
 ;HEAP32[$stretchConfig+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$stretchConfig+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$stretchConfig+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$stretchConfig+12>>2]=HEAP32[$0+12>>2]|0;
 HEAPF32[$stretchConfig>>2] = $$1;
 $18 = HEAP32[$4>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 260|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_viii[$21 & 4095]($18,2,$stretchConfig);
 STACKTOP = sp;return;
}
function __ZN5Unity5Cloth22SetUseVirtualParticlesEb($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $$byval_copy15 = 0, $$lcssa = 0, $$lcssa28 = 0, $$lcssa30 = 0, $$ph = 0, $$ph24 = 0, $$ph25 = 0, $$ph26 = 0, $$pre = 0, $$pre38 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $i$032 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $midPoint = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy15 = sp + 52|0;
 $0 = sp + 48|0;
 $1 = sp + 44|0;
 $2 = sp + 40|0;
 $3 = sp + 36|0;
 $4 = sp + 32|0;
 $5 = sp + 28|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $midPoint = sp + 16|0;
 $10 = (($this) + 89|0);
 $11 = $value&1;
 HEAP8[$10>>0] = $11;
 $12 = (($this) + 180|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = HEAP32[628512>>2]|0;
 L4: do {
  if ($value) {
   $16 = (($this) + 224|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17>>>0) / 3)&-1;
   $19 = $18 << 2;
   $20 = ($19|0)==(0);
   if ($20) {
    $150 = 0;$151 = 0;$26 = $17;
   } else {
    $21 = $18 << 4;
    HEAP32[$9>>2] = $15;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$9+0>>2]|0;
    $22 = (invoke_iiiiiiii(108,(0|0),($21|0),4,($$byval_copy15|0),0,(688784|0),370)|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     $$ph25 = $19;$$ph26 = 0;
     label = 38;
     break;
    }
    $$pre = HEAP32[$16>>2]|0;
    $150 = $19;$151 = $22;$26 = $$pre;
   }
   $25 = ($26|0)==(0);
   L10: do {
    if ($25) {
     $$lcssa = $150;$$lcssa28 = 0;$$lcssa30 = $151;
    } else {
     $27 = (($this) + 216|0);
     $33 = 0;$35 = $150;$43 = $151;$i$032 = 0;
     L12: while(1) {
      $28 = HEAP32[$27>>2]|0;
      $29 = (($28) + ($i$032<<1)|0);
      $30 = HEAP16[$29>>1]|0;
      $31 = $30&65535;
      $32 = $33 | 1;
      $34 = $35 & 2147483647;
      $36 = ($32>>>0)>($34>>>0);
      do {
       if ($36) {
        $37 = $35 << 1;
        $38 = ($37|0)==(0);
        $39 = $38 ? 1 : $37;
        $40 = ($34>>>0)<($39>>>0);
        if ($40) {
         $41 = ($35|0)>(-1);
         if ($41) {
          $42 = $39 << 2;
          HEAP32[$7>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$7+0>>2]|0;
          $44 = (invoke_iiiiiiii(108,($43|0),($42|0),4,($$byval_copy15|0),0,(688784|0),370)|0);
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           $$ph = $39;$$ph24 = $43;
           break L12;
          }
          $53 = $44;$61 = $39;
          break;
         } else {
          $47 = $39 << 2;
          HEAP32[$8>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$8+0>>2]|0;
          $48 = (invoke_iiiiiii(102,($47|0),4,($$byval_copy15|0),0,(688784|0),352)|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           $$ph = $35;$$ph24 = $43;
           break L12;
          }
          $51 = $32 << 2;
          _memcpy(($48|0),($43|0),($51|0))|0;
          $53 = $48;$61 = $39;
          break;
         }
        } else {
         $53 = $43;$61 = $35;
        }
       } else {
        $53 = $43;$61 = $35;
       }
      } while(0);
      $52 = (($53) + ($33<<2)|0);
      HEAP32[$52>>2] = $31;
      $54 = (($i$032) + 1)|0;
      $55 = HEAP32[$27>>2]|0;
      $56 = (($55) + ($54<<1)|0);
      $57 = HEAP16[$56>>1]|0;
      $58 = $57&65535;
      $59 = $33 | 2;
      $60 = $61 & 2147483647;
      $62 = ($59>>>0)>($60>>>0);
      do {
       if ($62) {
        $63 = $61 << 1;
        $64 = ($63|0)==(0);
        $65 = $64 ? 1 : $63;
        $66 = ($60>>>0)<($65>>>0);
        if ($66) {
         $67 = ($61|0)>(-1);
         if ($67) {
          $68 = $65 << 2;
          HEAP32[$5>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$5+0>>2]|0;
          $69 = (invoke_iiiiiiii(108,($53|0),($68|0),4,($$byval_copy15|0),0,(688784|0),370)|0);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           $$ph = $65;$$ph24 = $53;
           break L12;
          }
          $78 = $69;$86 = $65;
          break;
         } else {
          $72 = $65 << 2;
          HEAP32[$6>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$6+0>>2]|0;
          $73 = (invoke_iiiiiii(102,($72|0),4,($$byval_copy15|0),0,(688784|0),352)|0);
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           $$ph = $61;$$ph24 = $53;
           break L12;
          }
          $76 = $59 << 2;
          _memcpy(($73|0),($53|0),($76|0))|0;
          $78 = $73;$86 = $65;
          break;
         }
        } else {
         $78 = $53;$86 = $61;
        }
       } else {
        $78 = $53;$86 = $61;
       }
      } while(0);
      $77 = (($78) + ($32<<2)|0);
      HEAP32[$77>>2] = $58;
      $79 = (($i$032) + 2)|0;
      $80 = HEAP32[$27>>2]|0;
      $81 = (($80) + ($79<<1)|0);
      $82 = HEAP16[$81>>1]|0;
      $83 = $82&65535;
      $84 = $33 | 3;
      $85 = $86 & 2147483647;
      $87 = ($84>>>0)>($85>>>0);
      do {
       if ($87) {
        $88 = $86 << 1;
        $89 = ($88|0)==(0);
        $90 = $89 ? 1 : $88;
        $91 = ($85>>>0)<($90>>>0);
        if ($91) {
         $92 = ($86|0)>(-1);
         if ($92) {
          $93 = $90 << 2;
          HEAP32[$3>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;
          $94 = (invoke_iiiiiiii(108,($78|0),($93|0),4,($$byval_copy15|0),0,(688784|0),370)|0);
          $95 = __THREW__; __THREW__ = 0;
          $96 = $95&1;
          if ($96) {
           $$ph = $90;$$ph24 = $78;
           break L12;
          }
          $103 = $94;$107 = $90;
          break;
         } else {
          $97 = $90 << 2;
          HEAP32[$4>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$4+0>>2]|0;
          $98 = (invoke_iiiiiii(102,($97|0),4,($$byval_copy15|0),0,(688784|0),352)|0);
          $99 = __THREW__; __THREW__ = 0;
          $100 = $99&1;
          if ($100) {
           $$ph = $86;$$ph24 = $78;
           break L12;
          }
          $101 = $84 << 2;
          _memcpy(($98|0),($78|0),($101|0))|0;
          $103 = $98;$107 = $90;
          break;
         }
        } else {
         $103 = $78;$107 = $86;
        }
       } else {
        $103 = $78;$107 = $86;
       }
      } while(0);
      $102 = (($103) + ($59<<2)|0);
      HEAP32[$102>>2] = $83;
      $104 = (($i$032) + 3)|0;
      $105 = (($33) + 4)|0;
      $106 = $107 & 2147483647;
      $108 = ($105>>>0)>($106>>>0);
      do {
       if ($108) {
        $109 = $107 << 1;
        $110 = ($109|0)==(0);
        $111 = $110 ? 1 : $109;
        $112 = ($106>>>0)<($111>>>0);
        if ($112) {
         $113 = ($107|0)>(-1);
         if ($113) {
          $114 = $111 << 2;
          HEAP32[$1>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;
          $115 = (invoke_iiiiiiii(108,($103|0),($114|0),4,($$byval_copy15|0),0,(688784|0),370)|0);
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           $$ph = $111;$$ph24 = $103;
           break L12;
          }
          $124 = $115;$152 = $111;
          break;
         } else {
          $118 = $111 << 2;
          HEAP32[$2>>2] = $15;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;
          $119 = (invoke_iiiiiii(102,($118|0),4,($$byval_copy15|0),0,(688784|0),352)|0);
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           $$ph = $107;$$ph24 = $103;
           break L12;
          }
          $122 = $105 << 2;
          _memcpy(($119|0),($103|0),($122|0))|0;
          $124 = $119;$152 = $111;
          break;
         }
        } else {
         $124 = $103;$152 = $107;
        }
       } else {
        $124 = $103;$152 = $107;
       }
      } while(0);
      $123 = (($124) + ($84<<2)|0);
      HEAP32[$123>>2] = 0;
      $125 = ($104>>>0)<($26>>>0);
      if ($125) {
       $33 = $105;$35 = $152;$43 = $124;$i$032 = $104;
      } else {
       $$lcssa = $152;$$lcssa28 = $105;$$lcssa30 = $124;
       break L10;
      }
     }
     $126 = ___cxa_find_matching_catch()|0;
     $127 = tempRet0;
     $131 = $$ph;$132 = $$ph24;$lpad$phi$index = $126;$lpad$phi$index2 = $127;
     break L4;
    }
   } while(0);
   $$pre38 = HEAP32[$12>>2]|0;
   $138 = $$pre38;$142 = $$lcssa28;$143 = $$lcssa30;$147 = $$lcssa;
   label = 42;
  } else {
   $138 = $13;$142 = 0;$143 = 0;$147 = 0;
   label = 42;
  }
 } while(0);
 if ((label|0) == 42) {
  HEAPF32[$midPoint>>2] = Math_fround(0.333333343267440795898);
  $135 = (($midPoint) + 4|0);
  HEAPF32[$135>>2] = Math_fround(0.333333343267440795898);
  $136 = (($midPoint) + 8|0);
  HEAPF32[$136>>2] = Math_fround(0.333333343267440795898);
  $137 = HEAP32[$138>>2]|0;
  $139 = (($137) + 352|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = $142 >>> 2;
  __THREW__ = 0;
  invoke_viiiii($140|0,($138|0),($141|0),($143|0),1,($midPoint|0));
  $144 = __THREW__; __THREW__ = 0;
  $145 = $144&1;
  if ($145) {
   $$ph25 = $147;$$ph26 = $143;
   label = 38;
  } else {
   $146 = ($147|0)>(-1);
   if (!($146)) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = $15;
   ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($143,$$byval_copy15);
   STACKTOP = sp;return;
  }
 }
 if ((label|0) == 38) {
  $128 = ___cxa_find_matching_catch()|0;
  $129 = tempRet0;
  $131 = $$ph25;$132 = $$ph26;$lpad$phi$index = $128;$lpad$phi$index2 = $129;
 }
 $130 = ($131|0)>(-1);
 if (!($130)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $15;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($132|0),($$byval_copy15|0));
 $133 = __THREW__; __THREW__ = 0;
 $134 = $133&1;
 if ($134) {
  $148 = ___cxa_find_matching_catch(0|0)|0;
  $149 = tempRet0;
  ___clang_call_terminate($148);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN5Unity5Cloth6CreateEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i = 0, $$0$i65 = 0, $$0$i72 = 0, $$0$lcssa$i = 0, $$0$lcssa$i58 = 0, $$01 = 0, $$01$i = 0, $$01$i57 = 0, $$byval_copy30 = 0, $$lcssa = 0, $$lcssa100 = 0, $$lcssa111 = 0, $$lcssa113 = 0, $$lcssa115 = 0, $$lcssa98 = 0, $$not = 0, $$not156 = 0, $$ph$ph = 0, $$ph$ph92$ph = 0;
 var $$ph90$ph = 0, $$ph90$ph93$ph = 0, $$pre = 0, $$pre$i$i44 = 0, $$pre$i$i50 = 0, $$pre146 = 0, $$pre147 = 0, $$pre150 = 0, $$pre151 = 0, $$pre152 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0);
 var $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0);
 var $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = 0;
 var $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0;
 var $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0;
 var $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0;
 var $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0;
 var $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0;
 var $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0;
 var $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0;
 var $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0;
 var $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0;
 var $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0;
 var $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0;
 var $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cIt$0103 = 0, $clothMeshDesc = 0, $hasUnfixedVertex$0$off0124 = 0, $hasUnfixedVertex$1$off0 = 0, $i$0$ph136 = 0, $i$0132 = 0, $i1$0125 = 0, $i2$091 = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0;
 var $n$0$ph135 = 0, $or$cond = 0, $or$cond155 = 0, $or$cond157 = 0, $or$cond89 = 0, $phitmp$i = 0, $sIt$0117 = 0, $sceneGravity = 0, $sphereIndex$0102 = 0, $sphereIndex$1 = 0, $storemerge = 0, $temp$0$i = 0, $temp$0$i12 = 0, $temp$0$i64 = 0, $temp$0$i7 = 0, $temp$0$i71 = 0, $worldScale = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $$byval_copy30 = sp + 280|0;
 $0 = sp + 352|0;
 $1 = sp + 348|0;
 $2 = sp + 344|0;
 $3 = sp + 340|0;
 $4 = sp + 336|0;
 $5 = sp + 332|0;
 $6 = sp + 328|0;
 $7 = sp + 324|0;
 $8 = sp + 320|0;
 $9 = sp + 316|0;
 $10 = sp + 312|0;
 $11 = sp + 308|0;
 $12 = sp + 304|0;
 $13 = sp + 300|0;
 $14 = sp + 296|0;
 $15 = sp + 292|0;
 $16 = sp + 288|0;
 $17 = sp + 276|0;
 $18 = sp + 36|0;
 $19 = sp;
 $20 = sp + 4|0;
 $21 = sp + 8|0;
 $22 = sp + 12|0;
 $23 = sp + 16|0;
 $24 = sp + 20|0;
 $25 = sp + 24|0;
 $sceneGravity = sp + 40|0;
 $26 = sp + 56|0;
 $27 = sp + 72|0;
 $worldScale = sp + 80|0;
 $28 = sp + 120|0;
 $clothMeshDesc = sp + 184|0;
 $29 = sp + 236|0;
 $30 = sp + 248|0;
 $31 = sp + 356|0;
 $32 = (($this) + 180|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = HEAP32[$33>>2]|0;
  $36 = (($35) + 84|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (FUNCTION_TABLE_ii[$37 & 4095]($33)|0);
  $39 = HEAP32[$32>>2]|0;
  $40 = HEAP32[$39>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vi[$41 & 4095]($39);
  $42 = HEAP32[$38>>2]|0;
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_vi[$43 & 4095]($38);
  HEAP32[$32>>2] = 0;
 }
 $44 = (($this) + 24|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($45,137)|0);
  $48 = ($47|0)==(0|0);
  if (!($48)) {
   $49 = (($47) + 428|0);
   HEAP32[$49>>2] = 0;
  }
 }
 $50 = (($this) + 192|0);
 HEAP32[$50>>2] = 0;
 $51 = (($this) + 196|0);
 HEAP32[$51>>2] = 0;
 $52 = HEAP32[$44>>2]|0;
 $53 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($52,137)|0);
 $54 = (($53) + 428|0);
 HEAP32[$54>>2] = $this;
 $55 = (__ZN19SkinnedMeshRenderer7GetMeshEv($53)|0);
 $56 = ($55|0)==(0|0);
 if ($56) {
  STACKTOP = sp;return;
 }
 $57 = (($this) + 296|0);
 $58 = (__ZN19SkinnedMeshRenderer17GetActualRootBoneEv($53)|0);
 __ZNK9Transform11GetPositionEv($25,$58);
 ;HEAP32[$57+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$25+8>>2]|0;
 $59 = (($this) + 188|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0);
 do {
  if (!($61)) {
   HEAP32[$24>>2] = $60;
   $62 = HEAP32[560624>>2]|0;
   $63 = ($62|0)==(0|0);
   if ($63) {
    label = 16;
   } else {
    $64 = (($62) + 36|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($62) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($65|0)==($67|0);
    do {
     if ($68) {
      $69 = (($62) + 28|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = (($62) + 32|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($70) + ($72<<3)|0);
      $89 = $73;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy30,$62,$24);
      $74 = HEAP32[$$byval_copy30>>2]|0;
      $75 = ($74|0)==(-1);
      $76 = (($62) + 28|0);
      $77 = HEAP32[$76>>2]|0;
      if ($75) {
       $78 = (($62) + 32|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = (($77) + ($79<<3)|0);
       $89 = $80;
       break;
      } else {
       $81 = (($77) + ($74<<3)|0);
       $89 = $81;
       break;
      }
     }
    } while(0);
    $82 = HEAP32[560624>>2]|0;
    $83 = (($82) + 28|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($82) + 32|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($84) + ($86<<3)|0);
    $88 = ($89|0)==($87|0);
    if ($88) {
     label = 16;
    } else {
     $90 = (($89) + 4|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($91|0)==(0|0);
     if ($92) {
      label = 16;
     }
    }
   }
   if ((label|0) == 16) {
    $93 = HEAP32[$59>>2]|0;
    $94 = (__Z31ReadObjectFromPersistentManageri($93)|0);
    $phitmp$i = ($94|0)==(0|0);
    if ($phitmp$i) {
     break;
    }
   }
   $95 = (__ZN19SkinnedMeshRenderer7GetMeshEv($53)|0);
   $96 = HEAP32[$59>>2]|0;
   $97 = ($96|0)==(0);
   if ($97) {
    $$0$i = 0;
   } else {
    HEAP32[$23>>2] = $96;
    $98 = HEAP32[560624>>2]|0;
    $99 = ($98|0)==(0|0);
    if ($99) {
     label = 26;
    } else {
     $100 = (($98) + 36|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (($98) + 4|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ($101|0)==($103|0);
     do {
      if ($104) {
       $105 = (($98) + 28|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = (($98) + 32|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = (($106) + ($108<<3)|0);
       $125 = $109;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy30,$98,$23);
       $110 = HEAP32[$$byval_copy30>>2]|0;
       $111 = ($110|0)==(-1);
       $112 = (($98) + 28|0);
       $113 = HEAP32[$112>>2]|0;
       if ($111) {
        $114 = (($98) + 32|0);
        $115 = HEAP32[$114>>2]|0;
        $116 = (($113) + ($115<<3)|0);
        $125 = $116;
        break;
       } else {
        $117 = (($113) + ($110<<3)|0);
        $125 = $117;
        break;
       }
      }
     } while(0);
     $118 = HEAP32[560624>>2]|0;
     $119 = (($118) + 28|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = (($118) + 32|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = (($120) + ($122<<3)|0);
     $124 = ($125|0)==($123|0);
     if ($124) {
      label = 26;
     } else {
      $126 = (($125) + 4|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = ($127|0)==(0|0);
      if ($128) {
       label = 26;
      } else {
       $temp$0$i = $127;
      }
     }
    }
    if ((label|0) == 26) {
     $129 = HEAP32[$59>>2]|0;
     $130 = (__Z31ReadObjectFromPersistentManageri($129)|0);
     $temp$0$i = $130;
    }
    $$0$i = $temp$0$i;
   }
   $131 = ($95|0)==($$0$i|0);
   if ($131) {
    $132 = HEAP32[$51>>2]|0;
    $133 = ($132|0)==(0);
    if ($133) {
     break;
    }
    $134 = HEAP32[$59>>2]|0;
    HEAP32[$22>>2] = $134;
    $135 = HEAP32[560624>>2]|0;
    $136 = ($135|0)==(0|0);
    if ($136) {
     label = 38;
    } else {
     $137 = (($135) + 36|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = (($135) + 4|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = ($138|0)==($140|0);
     do {
      if ($141) {
       $142 = (($135) + 28|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = (($135) + 32|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = (($143) + ($145<<3)|0);
       $162 = $146;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy30,$135,$22);
       $147 = HEAP32[$$byval_copy30>>2]|0;
       $148 = ($147|0)==(-1);
       $149 = (($135) + 28|0);
       $150 = HEAP32[$149>>2]|0;
       if ($148) {
        $151 = (($135) + 32|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = (($150) + ($152<<3)|0);
        $162 = $153;
        break;
       } else {
        $154 = (($150) + ($147<<3)|0);
        $162 = $154;
        break;
       }
      }
     } while(0);
     $155 = HEAP32[560624>>2]|0;
     $156 = (($155) + 28|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = (($155) + 32|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = (($157) + ($159<<3)|0);
     $161 = ($162|0)==($160|0);
     if ($161) {
      label = 38;
     } else {
      $163 = (($162) + 4|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = ($164|0)==(0|0);
      if ($165) {
       label = 38;
      } else {
       $temp$0$i7 = $164;
      }
     }
    }
    if ((label|0) == 38) {
     $166 = HEAP32[$59>>2]|0;
     $167 = (__Z31ReadObjectFromPersistentManageri($166)|0);
     $temp$0$i7 = $167;
    }
    $168 = (($temp$0$i7) + 28|0);
    $169 = HEAP32[$168>>2]|0;
    $170 = (($169) + 100|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = HEAP32[$51>>2]|0;
    $173 = ($171|0)==($172|0);
    if ($173) {
     break;
    }
   }
   $174 = (($this) + 112|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = ($175|0)>(-1);
   if ($176) {
    $177 = (($this) + 100|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = (($this) + 104|0);
    $180 = HEAP32[$179>>2]|0;
    HEAP32[$0>>2] = $180;
    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($178,$$byval_copy30);
    HEAP32[$177>>2] = 0;
   }
   $181 = (($this) + 108|0);
   HEAP32[$181>>2] = 0;
   HEAP32[$174>>2] = 0;
  }
 } while(0);
 $182 = (__ZN19SkinnedMeshRenderer7GetMeshEv($53)|0);
 $183 = ($182|0)==(0|0);
 if ($183) {
  $storemerge = 0;
 } else {
  $184 = (($182) + 4|0);
  $185 = HEAP32[$184>>2]|0;
  $storemerge = $185;
 }
 HEAP32[$59>>2] = $storemerge;
 HEAP32[$21>>2] = $storemerge;
 $186 = HEAP32[560624>>2]|0;
 $187 = ($186|0)==(0|0);
 if ($187) {
  label = 53;
 } else {
  $188 = (($186) + 36|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = (($186) + 4|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = ($189|0)==($191|0);
  do {
   if ($192) {
    $193 = (($186) + 28|0);
    $194 = HEAP32[$193>>2]|0;
    $195 = (($186) + 32|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = (($194) + ($196<<3)|0);
    $213 = $197;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy30,$186,$21);
    $198 = HEAP32[$$byval_copy30>>2]|0;
    $199 = ($198|0)==(-1);
    $200 = (($186) + 28|0);
    $201 = HEAP32[$200>>2]|0;
    if ($199) {
     $202 = (($186) + 32|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = (($201) + ($203<<3)|0);
     $213 = $204;
     break;
    } else {
     $205 = (($201) + ($198<<3)|0);
     $213 = $205;
     break;
    }
   }
  } while(0);
  $206 = HEAP32[560624>>2]|0;
  $207 = (($206) + 28|0);
  $208 = HEAP32[$207>>2]|0;
  $209 = (($206) + 32|0);
  $210 = HEAP32[$209>>2]|0;
  $211 = (($208) + ($210<<3)|0);
  $212 = ($213|0)==($211|0);
  if ($212) {
   label = 53;
  } else {
   $214 = (($213) + 4|0);
   $215 = HEAP32[$214>>2]|0;
   $216 = ($215|0)==(0|0);
   if ($216) {
    label = 53;
   } else {
    $temp$0$i12 = $215;
   }
  }
 }
 if ((label|0) == 53) {
  $217 = HEAP32[$59>>2]|0;
  $218 = (__Z31ReadObjectFromPersistentManageri($217)|0);
  $temp$0$i12 = $218;
 }
 $219 = (($this) + 232|0);
 $220 = (($this) + 216|0);
 $221 = (($this) + 200|0);
 $222 = (__Z19ExtractDataFromMeshR4MeshR13dynamic_arrayI8Vector3fLj4EERS1_ItLj2EES6_($temp$0$i12,$219,$220,$221)|0);
 if (!($222)) {
  STACKTOP = sp;return;
 }
 $223 = (($this) + 240|0);
 $224 = HEAP32[$223>>2]|0;
 HEAP32[$50>>2] = $224;
 $225 = (($this) + 208|0);
 $226 = HEAP32[$225>>2]|0;
 HEAP32[$51>>2] = $226;
 $227 = (($this) + 224|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = ($228|0)==(0);
 L82: do {
  if (!($229)) {
   $230 = (($this) + 228|0);
   $231 = (($this) + 220|0);
   $$pre147 = HEAP32[$220>>2]|0;
   $235 = $$pre147;$i$0$ph136 = 0;$n$0$ph135 = $228;
   while(1) {
    $i$0132 = $i$0$ph136;
    while(1) {
     $234 = (($235) + ($i$0132<<1)|0);
     $236 = HEAP16[$234>>1]|0;
     $237 = (($i$0132) + 1)|0;
     $238 = (($235) + ($237<<1)|0);
     $239 = HEAP16[$238>>1]|0;
     $240 = ($236<<16>>16)==($239<<16>>16);
     $$pre151 = (($i$0132) + 2)|0;
     $$pre152 = (($235) + ($$pre151<<1)|0);
     if ($240) {
      break;
     }
     $241 = HEAP16[$$pre152>>1]|0;
     $242 = ($239<<16>>16)==($241<<16>>16);
     $243 = ($241<<16>>16)==($236<<16>>16);
     $or$cond89 = $242 | $243;
     $233 = (($i$0132) + 3)|0;
     if ($or$cond89) {
      break;
     }
     $232 = ($233>>>0)<($n$0$ph135>>>0);
     if ($232) {
      $i$0132 = $233;
     } else {
      break L82;
     }
    }
    $244 = (($n$0$ph135) + -3)|0;
    $245 = (($235) + ($244<<1)|0);
    $246 = HEAP16[$245>>1]|0;
    HEAP16[$234>>1] = $246;
    $247 = (($n$0$ph135) + -2)|0;
    $248 = (($235) + ($247<<1)|0);
    $249 = HEAP16[$248>>1]|0;
    HEAP16[$238>>1] = $249;
    $250 = (($n$0$ph135) + -1)|0;
    $251 = (($235) + ($250<<1)|0);
    $252 = HEAP16[$251>>1]|0;
    HEAP16[$$pre152>>1] = $252;
    HEAP32[$227>>2] = $244;
    $253 = HEAP32[$230>>2]|0;
    $254 = $253 & 2147483647;
    $255 = ($254>>>0)<($244>>>0);
    do {
     if ($255) {
      $257 = ($253|0)>(-1);
      if ($257) {
       HEAP32[$230>>2] = $244;
       $258 = $244 << 1;
       $259 = HEAP32[$231>>2]|0;
       HEAP32[$0>>2] = $259;
       ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$0+0>>2]|0;
       $260 = (__Z16realloc_internalPvji10MemLabelIdiPKci($235,$258,2,$$byval_copy30,0,688784,370)|0);
       HEAP32[$220>>2] = $260;
       $804 = $260;
       break;
      } else {
       $261 = $244 << 1;
       $262 = HEAP32[$231>>2]|0;
       HEAP32[$0>>2] = $262;
       ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$0+0>>2]|0;
       $263 = (__Z15malloc_internaljj10MemLabelIdiPKci($261,2,$$byval_copy30,0,688784,352)|0);
       $264 = HEAP32[$220>>2]|0;
       $265 = HEAP32[$227>>2]|0;
       $266 = $265 << 1;
       _memcpy(($263|0),($264|0),($266|0))|0;
       HEAP32[$230>>2] = $244;
       HEAP32[$220>>2] = $263;
       $804 = $263;
       break;
      }
     } else {
      $804 = $235;
     }
    } while(0);
    $256 = ($i$0132>>>0)<($244>>>0);
    if ($256) {
     $235 = $804;$i$0$ph136 = $i$0132;$n$0$ph135 = $244;
    } else {
     break;
    }
   }
  }
 } while(0);
 __ZN5Unity5Cloth13UpdateNormalsEv($this);
 $267 = (__Z17GetPhysicsManagerv()|0);
 $268 = (__ZN14PhysicsManager16GetClothingSceneEv($267)|0);
 $269 = (($this) + 184|0);
 HEAP32[$269>>2] = $268;
 $270 = HEAP32[$268>>2]|0;
 $271 = (($270) + 252|0);
 $272 = HEAP32[$271>>2]|0;
 FUNCTION_TABLE_vii[$272 & 4095]($sceneGravity,$268);
 $273 = (__ZN19SkinnedMeshRenderer17GetActualRootBoneEv($53)|0);
 __ZNK9Transform11GetRotationEv($26,$273);
 $274 = Math_fround(HEAPF32[$26>>2]);
 $275 = Math_fround(-$274);
 $276 = (($26) + 4|0);
 $277 = Math_fround(HEAPF32[$276>>2]);
 $278 = Math_fround(-$277);
 $279 = (($26) + 8|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = (($26) + 12|0);
 $282 = Math_fround(HEAPF32[$281>>2]);
 $283 = Math_fround($274 * Math_fround(-2.0));
 $284 = Math_fround($277 * Math_fround(-2.0));
 $285 = Math_fround($280 * Math_fround(-2.0));
 $286 = Math_fround($283 * $275);
 $287 = Math_fround($284 * $278);
 $288 = Math_fround($280 * $285);
 $289 = Math_fround($284 * $275);
 $290 = Math_fround($285 * $275);
 $291 = Math_fround($285 * $278);
 $292 = Math_fround($283 * $282);
 $293 = Math_fround($284 * $282);
 $294 = Math_fround($282 * $285);
 $295 = Math_fround($287 - $288);
 $296 = Math_fround(Math_fround(1.0) - $295);
 $297 = Math_fround(HEAPF32[$sceneGravity>>2]);
 $298 = Math_fround($297 * $296);
 $299 = Math_fround($289 - $294);
 $300 = (($sceneGravity) + 4|0);
 $301 = Math_fround(HEAPF32[$300>>2]);
 $302 = Math_fround($299 * $301);
 $303 = Math_fround($302 + $298);
 $304 = Math_fround($290 + $293);
 $305 = (($sceneGravity) + 8|0);
 $306 = Math_fround(HEAPF32[$305>>2]);
 $307 = Math_fround($304 * $306);
 $308 = Math_fround($307 + $303);
 $309 = Math_fround($289 + $294);
 $310 = Math_fround($297 * $309);
 $311 = Math_fround($286 - $288);
 $312 = Math_fround(Math_fround(1.0) - $311);
 $313 = Math_fround($301 * $312);
 $314 = Math_fround($310 + $313);
 $315 = Math_fround($291 - $292);
 $316 = Math_fround($315 * $306);
 $317 = Math_fround($316 + $314);
 $318 = Math_fround($290 - $293);
 $319 = Math_fround($297 * $318);
 $320 = Math_fround($291 + $292);
 $321 = Math_fround($320 * $301);
 $322 = Math_fround($319 + $321);
 $323 = Math_fround($286 + $287);
 $324 = Math_fround(Math_fround(1.0) - $323);
 $325 = Math_fround($324 * $306);
 $326 = Math_fround($322 + $325);
 $327 = HEAP32[628512>>2]|0;
 $328 = HEAP32[$50>>2]|0;
 $329 = ($328|0)==(0);
 if ($329) {
  $336 = 0;$362 = 0;$796 = 0;
  label = 69;
 } else {
  $330 = $328 << 4;
  HEAP32[$14>>2] = $327;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$14+0>>2]|0;
  $331 = (invoke_iiiiiiii(108,(0|0),($330|0),4,($$byval_copy30|0),0,(688784|0),370)|0);
  $332 = __THREW__; __THREW__ = 0;
  $333 = $332&1;
  if ($333) {
   $805 = $328;$806 = 0;
   label = 78;
  } else {
   $$pre = HEAP32[$50>>2]|0;
   $336 = $$pre;$362 = $331;$796 = $328;
   label = 69;
  }
 }
 L101: do {
  if ((label|0) == 69) {
   $334 = (($this) + 100|0);
   HEAPF32[$27>>2] = Math_fround(3.40282346638528859812E+38);
   $335 = (($27) + 4|0);
   HEAPF32[$335>>2] = Math_fround(3.40282346638528859812E+38);
   __THREW__ = 0;
   invoke_viiii(408,($334|0),($336|0),($27|0),0);
   $337 = __THREW__; __THREW__ = 0;
   $338 = $337&1;
   if ($338) {
    $805 = $796;$806 = $362;
    label = 78;
   } else {
    $339 = (($this) + 295|0);
    HEAP8[$339>>0] = 0;
    __THREW__ = 0;
    $340 = (invoke_ii(3374,($53|0))|0);
    $341 = __THREW__; __THREW__ = 0;
    $342 = $341&1;
    if ($342) {
     $805 = $796;$806 = $362;
     label = 78;
    } else {
     __THREW__ = 0;
     invoke_vii(3319,($worldScale|0),($340|0));
     $343 = __THREW__; __THREW__ = 0;
     $344 = $343&1;
     if ($344) {
      $805 = $796;$806 = $362;
      label = 78;
     } else {
      __THREW__ = 0;
      invoke_vii(3320,($28|0),($worldScale|0));
      $345 = __THREW__; __THREW__ = 0;
      $346 = $345&1;
      if ($346) {
       $805 = $796;$806 = $362;
       label = 78;
      } else {
       $347 = HEAP32[$219>>2]|0;
       $348 = HEAP32[$223>>2]|0;
       __THREW__ = 0;
       invoke_viiii(409,($28|0),($347|0),($347|0),($348|0));
       $349 = __THREW__; __THREW__ = 0;
       $350 = $349&1;
       if ($350) {
        $805 = $796;$806 = $362;
        label = 78;
       } else {
        $351 = HEAP32[$50>>2]|0;
        $352 = ($351|0)==(0);
        L108: do {
         if (!($352)) {
          $353 = HEAP32[$219>>2]|0;
          $354 = HEAP32[$334>>2]|0;
          $hasUnfixedVertex$0$off0124 = 0;$i1$0125 = 0;
          while(1) {
           $355 = (($353) + (($i1$0125*12)|0)|0);
           $356 = Math_fround(HEAPF32[$355>>2]);
           $357 = ((($353) + (($i1$0125*12)|0)|0) + 4|0);
           $358 = Math_fround(HEAPF32[$357>>2]);
           $359 = ((($353) + (($i1$0125*12)|0)|0) + 8|0);
           $360 = Math_fround(HEAPF32[$359>>2]);
           $361 = (($362) + ($i1$0125<<4)|0);
           HEAPF32[$361>>2] = $356;
           $363 = ((($362) + ($i1$0125<<4)|0) + 4|0);
           HEAPF32[$363>>2] = $358;
           $364 = ((($362) + ($i1$0125<<4)|0) + 8|0);
           HEAPF32[$364>>2] = $360;
           $365 = (($354) + ($i1$0125<<3)|0);
           $366 = Math_fround(HEAPF32[$365>>2]);
           $367 = $366 > Math_fround(0.0);
           $368 = ((($362) + ($i1$0125<<4)|0) + 12|0);
           if ($367) {
            HEAPF32[$368>>2] = Math_fround(1.0);
            $hasUnfixedVertex$1$off0 = 1;
           } else {
            HEAPF32[$368>>2] = Math_fround(0.0);
            HEAP8[$339>>0] = 1;
            $hasUnfixedVertex$1$off0 = $hasUnfixedVertex$0$off0124;
           }
           $371 = (($i1$0125) + 1)|0;
           $372 = ($371>>>0)<($351>>>0);
           if ($372) {
            $hasUnfixedVertex$0$off0124 = $hasUnfixedVertex$1$off0;$i1$0125 = $371;
           } else {
            break;
           }
          }
          if ($hasUnfixedVertex$1$off0) {
           dest=$clothMeshDesc+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
           $373 = (($clothMeshDesc) + 4|0);
           HEAP32[$373>>2] = $362;
           $374 = (($clothMeshDesc) + 8|0);
           HEAP32[$374>>2] = $351;
           HEAP32[$clothMeshDesc>>2] = 16;
           $375 = (($362) + 12|0);
           $376 = (($clothMeshDesc) + 16|0);
           HEAP32[$376>>2] = $375;
           $377 = (($clothMeshDesc) + 20|0);
           HEAP32[$377>>2] = $351;
           $378 = (($clothMeshDesc) + 12|0);
           HEAP32[$378>>2] = 16;
           $379 = HEAP32[$227>>2]|0;
           $380 = (($379>>>0) / 3)&-1;
           $381 = (($clothMeshDesc) + 32|0);
           HEAP32[$381>>2] = $380;
           $382 = HEAP32[$220>>2]|0;
           $383 = (($clothMeshDesc) + 28|0);
           HEAP32[$383>>2] = $382;
           $384 = (($clothMeshDesc) + 24|0);
           HEAP32[$384>>2] = 6;
           $385 = (($clothMeshDesc) + 48|0);
           HEAP16[$385>>1] = 2;
           __THREW__ = 0;
           $386 = (invoke_i(115)|0);
           $387 = __THREW__; __THREW__ = 0;
           $388 = $387&1;
           if ($388) {
            $805 = $796;$806 = $362;
            label = 78;
            break L101;
           }
           HEAPF32[$29>>2] = $308;
           $389 = (($29) + 4|0);
           HEAPF32[$389>>2] = $317;
           $390 = (($29) + 8|0);
           HEAPF32[$390>>2] = $326;
           __THREW__ = 0;
           $391 = (invoke_iiiii(259,($386|0),($clothMeshDesc|0),($29|0),1)|0);
           $392 = __THREW__; __THREW__ = 0;
           $393 = $392&1;
           if ($393) {
            $805 = $796;$806 = $362;
            label = 78;
            break L101;
           }
           $394 = ($391|0)==(0|0);
           if ($394) {
            break;
           }
           $395 = HEAP32[628512>>2]|0;
           $396 = (($this) + 148|0);
           $397 = (($this) + 156|0);
           HEAP32[$397>>2] = 0;
           $398 = (($this) + 160|0);
           $399 = HEAP32[$398>>2]|0;
           $400 = (($this) + 140|0);
           $401 = HEAP32[$400>>2]|0;
           $402 = (($this) + 124|0);
           $403 = HEAP32[$402>>2]|0;
           $404 = (($403) + ($401))|0;
           $405 = $404 << 1;
           $406 = $399 & 2147483647;
           $407 = ($406>>>0)<($405>>>0);
           L121: do {
            if ($407) {
             $408 = ($399|0)>(-1);
             do {
              if ($408) {
               HEAP32[$398>>2] = $405;
               $409 = HEAP32[$396>>2]|0;
               $410 = $404 << 3;
               $411 = (($this) + 152|0);
               $412 = HEAP32[$411>>2]|0;
               HEAP32[$0>>2] = $412;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$0+0>>2]|0;
               $413 = (invoke_iiiiiiii(108,($409|0),($410|0),4,($$byval_copy30|0),0,(688784|0),370)|0);
               $414 = __THREW__; __THREW__ = 0;
               $415 = $414&1;
               if ($415) {
                break;
               }
               HEAP32[$396>>2] = $413;
               $431 = $413;
               label = 92;
               break L121;
              } else {
               $416 = $404 << 3;
               $417 = (($this) + 152|0);
               $418 = HEAP32[$417>>2]|0;
               HEAP32[$1>>2] = $418;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$1+0>>2]|0;
               $419 = (invoke_iiiiiii(102,($416|0),4,($$byval_copy30|0),0,(688784|0),352)|0);
               $420 = __THREW__; __THREW__ = 0;
               $421 = $420&1;
               if ($421) {
                break;
               }
               $422 = HEAP32[$396>>2]|0;
               $423 = HEAP32[$397>>2]|0;
               $424 = $423 << 2;
               _memcpy(($419|0),($422|0),($424|0))|0;
               HEAP32[$398>>2] = $405;
               HEAP32[$396>>2] = $419;
               $431 = $419;
               label = 92;
               break L121;
              }
             } while(0);
             $547 = ___cxa_find_matching_catch()|0;
             $548 = tempRet0;
             $559 = 0;$808 = $548;$809 = $547;
            } else {
             $$pre150 = HEAP32[$396>>2]|0;
             $431 = $$pre150;
             label = 92;
            }
           } while(0);
           if ((label|0) == 92) {
            $425 = (($this) + 132|0);
            $426 = HEAP32[$425>>2]|0;
            $427 = HEAP32[$400>>2]|0;
            $428 = (($426) + ($427<<3)|0);
            $429 = ($427|0)==(0);
            L132: do {
             if ($429) {
              $$lcssa111 = 0;$$lcssa113 = 0;$$lcssa115 = 0;
              label = 167;
             } else {
              $430 = $431;
              $432 = (($this) + 152|0);
              $603 = 0;$605 = 0;$613 = 0;$sIt$0117 = $426;
              L134: while(1) {
               $433 = HEAP32[$sIt$0117>>2]|0;
               $434 = ($433|0)==(0);
               if ($434) {
                $$0$i72 = 0;
               } else {
                HEAP32[$2>>2] = $433;
                $435 = HEAP32[560624>>2]|0;
                $436 = ($435|0)==(0|0);
                do {
                 if ($436) {
                  label = 103;
                 } else {
                  $437 = (($435) + 36|0);
                  $438 = HEAP32[$437>>2]|0;
                  $439 = (($435) + 4|0);
                  $440 = HEAP32[$439>>2]|0;
                  $441 = ($438|0)==($440|0);
                  do {
                   if ($441) {
                    $442 = (($435) + 28|0);
                    $443 = HEAP32[$442>>2]|0;
                    $444 = (($435) + 32|0);
                    $445 = HEAP32[$444>>2]|0;
                    $446 = (($443) + ($445<<3)|0);
                    $462 = $446;
                   } else {
                    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy30,$435,$2);
                    $447 = HEAP32[$$byval_copy30>>2]|0;
                    $448 = ($447|0)==(-1);
                    $449 = (($435) + 28|0);
                    $450 = HEAP32[$449>>2]|0;
                    if ($448) {
                     $451 = (($435) + 32|0);
                     $452 = HEAP32[$451>>2]|0;
                     $453 = (($450) + ($452<<3)|0);
                     $462 = $453;
                     break;
                    } else {
                     $454 = (($450) + ($447<<3)|0);
                     $462 = $454;
                     break;
                    }
                   }
                  } while(0);
                  $455 = HEAP32[560624>>2]|0;
                  $456 = (($455) + 28|0);
                  $457 = HEAP32[$456>>2]|0;
                  $458 = (($455) + 32|0);
                  $459 = HEAP32[$458>>2]|0;
                  $460 = (($457) + ($459<<3)|0);
                  $461 = ($462|0)==($460|0);
                  if ($461) {
                   label = 103;
                   break;
                  }
                  $463 = (($462) + 4|0);
                  $464 = HEAP32[$463>>2]|0;
                  $465 = ($464|0)==(0|0);
                  if ($465) {
                   label = 103;
                  } else {
                   $temp$0$i71 = $464;
                  }
                 }
                } while(0);
                if ((label|0) == 103) {
                 label = 0;
                 $466 = HEAP32[$sIt$0117>>2]|0;
                 __THREW__ = 0;
                 $467 = (invoke_ii(3215,($466|0))|0);
                 $468 = __THREW__; __THREW__ = 0;
                 $469 = $468&1;
                 if ($469) {
                  $$ph$ph92$ph = $605;$$ph90$ph93$ph = $613;
                  break;
                 } else {
                  $temp$0$i71 = $467;
                 }
                }
                $$0$i72 = $temp$0$i71;
               }
               $470 = (($sIt$0117) + 4|0);
               $471 = HEAP32[$470>>2]|0;
               $472 = ($471|0)==(0);
               if ($472) {
                $$0$i65 = 0;
               } else {
                HEAP32[$3>>2] = $471;
                $473 = HEAP32[560624>>2]|0;
                $474 = ($473|0)==(0|0);
                do {
                 if ($474) {
                  label = 114;
                 } else {
                  $475 = (($473) + 36|0);
                  $476 = HEAP32[$475>>2]|0;
                  $477 = (($473) + 4|0);
                  $478 = HEAP32[$477>>2]|0;
                  $479 = ($476|0)==($478|0);
                  do {
                   if ($479) {
                    $480 = (($473) + 28|0);
                    $481 = HEAP32[$480>>2]|0;
                    $482 = (($473) + 32|0);
                    $483 = HEAP32[$482>>2]|0;
                    $484 = (($481) + ($483<<3)|0);
                    $500 = $484;
                   } else {
                    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy30,$473,$3);
                    $485 = HEAP32[$$byval_copy30>>2]|0;
                    $486 = ($485|0)==(-1);
                    $487 = (($473) + 28|0);
                    $488 = HEAP32[$487>>2]|0;
                    if ($486) {
                     $489 = (($473) + 32|0);
                     $490 = HEAP32[$489>>2]|0;
                     $491 = (($488) + ($490<<3)|0);
                     $500 = $491;
                     break;
                    } else {
                     $492 = (($488) + ($485<<3)|0);
                     $500 = $492;
                     break;
                    }
                   }
                  } while(0);
                  $493 = HEAP32[560624>>2]|0;
                  $494 = (($493) + 28|0);
                  $495 = HEAP32[$494>>2]|0;
                  $496 = (($493) + 32|0);
                  $497 = HEAP32[$496>>2]|0;
                  $498 = (($495) + ($497<<3)|0);
                  $499 = ($500|0)==($498|0);
                  if ($499) {
                   label = 114;
                   break;
                  }
                  $501 = (($500) + 4|0);
                  $502 = HEAP32[$501>>2]|0;
                  $503 = ($502|0)==(0|0);
                  if ($503) {
                   label = 114;
                  } else {
                   $temp$0$i64 = $502;
                  }
                 }
                } while(0);
                if ((label|0) == 114) {
                 label = 0;
                 $504 = HEAP32[$470>>2]|0;
                 __THREW__ = 0;
                 $505 = (invoke_ii(3215,($504|0))|0);
                 $506 = __THREW__; __THREW__ = 0;
                 $507 = $506&1;
                 if ($507) {
                  $$ph$ph92$ph = $605;$$ph90$ph93$ph = $613;
                  break;
                 } else {
                  $temp$0$i64 = $505;
                 }
                }
                $$0$i65 = $temp$0$i64;
               }
               $508 = HEAP32[$396>>2]|0;
               $509 = HEAP32[$397>>2]|0;
               $510 = (($508) + ($509<<2)|0);
               $511 = ($431|0)==($510|0);
               L168: do {
                if ($511) {
                 $$0$lcssa$i58 = $431;
                } else {
                 $$01$i57 = $431;
                 while(1) {
                  $514 = HEAP32[$$01$i57>>2]|0;
                  $515 = ($514|0)==($$0$i72|0);
                  $513 = (($$01$i57) + 4|0);
                  if ($515) {
                   $$0$lcssa$i58 = $$01$i57;
                   break L168;
                  }
                  $512 = ($513|0)==($510|0);
                  if ($512) {
                   $$0$lcssa$i58 = $510;
                   break;
                  } else {
                   $$01$i57 = $513;
                  }
                 }
                }
               } while(0);
               $516 = $$0$lcssa$i58;
               $517 = (($516) - ($430))|0;
               $518 = $517 >> 2;
               $519 = ($$0$i72|0)==(0|0);
               $$not = $519 ^ 1;
               $520 = ($518|0)==($509|0);
               $or$cond155 = $520 & $$not;
               if ($or$cond155) {
                $521 = (($509) + 1)|0;
                HEAP32[$397>>2] = $521;
                $522 = HEAP32[$398>>2]|0;
                $523 = $522 & 2147483647;
                $524 = ($521>>>0)>($523>>>0);
                if ($524) {
                 $525 = $522 << 1;
                 $526 = ($525|0)==(0);
                 $527 = $526 ? 1 : $525;
                 $528 = ($523>>>0)<($527>>>0);
                 do {
                  if ($528) {
                   $529 = ($522|0)>(-1);
                   if ($529) {
                    HEAP32[$398>>2] = $527;
                    $530 = $527 << 2;
                    $531 = HEAP32[$432>>2]|0;
                    HEAP32[$4>>2] = $531;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$4+0>>2]|0;
                    $532 = (invoke_iiiiiiii(108,($508|0),($530|0),4,($$byval_copy30|0),0,(688784|0),370)|0);
                    $533 = __THREW__; __THREW__ = 0;
                    $534 = $533&1;
                    if ($534) {
                     $$ph$ph92$ph = $605;$$ph90$ph93$ph = $613;
                     break L134;
                    }
                    HEAP32[$396>>2] = $532;
                    $807 = $532;
                    break;
                   } else {
                    $535 = $527 << 2;
                    $536 = HEAP32[$432>>2]|0;
                    HEAP32[$5>>2] = $536;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$5+0>>2]|0;
                    $537 = (invoke_iiiiiii(102,($535|0),4,($$byval_copy30|0),0,(688784|0),352)|0);
                    $538 = __THREW__; __THREW__ = 0;
                    $539 = $538&1;
                    if ($539) {
                     $$ph$ph92$ph = $605;$$ph90$ph93$ph = $613;
                     break L134;
                    }
                    $540 = HEAP32[$396>>2]|0;
                    $541 = HEAP32[$397>>2]|0;
                    $542 = $541 << 2;
                    _memcpy(($537|0),($540|0),($542|0))|0;
                    HEAP32[$398>>2] = $527;
                    HEAP32[$396>>2] = $537;
                    $807 = $537;
                    break;
                   }
                  } else {
                   $807 = $508;
                  }
                 } while(0);
                 $$pre$i$i50 = HEAP32[$397>>2]|0;
                 $544 = $$pre$i$i50;$546 = $807;
                } else {
                 $544 = $521;$546 = $508;
                }
                $543 = (($544) + -1)|0;
                $545 = (($546) + ($543<<2)|0);
                HEAP32[$545>>2] = $$0$i72;
                $$pre146 = HEAP32[$396>>2]|0;
                $563 = $$pre146;$564 = $544;
               } else {
                $563 = $508;$564 = $509;
               }
               $562 = (($563) + ($564<<2)|0);
               $565 = ($431|0)==($562|0);
               L187: do {
                if ($565) {
                 $$0$lcssa$i = $431;
                } else {
                 $$01$i = $431;
                 while(1) {
                  $568 = HEAP32[$$01$i>>2]|0;
                  $569 = ($568|0)==($$0$i65|0);
                  $567 = (($$01$i) + 4|0);
                  if ($569) {
                   $$0$lcssa$i = $$01$i;
                   break L187;
                  }
                  $566 = ($567|0)==($562|0);
                  if ($566) {
                   $$0$lcssa$i = $562;
                   break;
                  } else {
                   $$01$i = $567;
                  }
                 }
                }
               } while(0);
               $570 = $$0$lcssa$i;
               $571 = (($570) - ($430))|0;
               $572 = $571 >> 2;
               $573 = ($$0$i65|0)==(0|0);
               $$not156 = $573 ^ 1;
               $574 = ($572|0)==($564|0);
               $or$cond157 = $574 & $$not156;
               if ($or$cond157) {
                $575 = (($564) + 1)|0;
                HEAP32[$397>>2] = $575;
                $576 = HEAP32[$398>>2]|0;
                $577 = $576 & 2147483647;
                $578 = ($575>>>0)>($577>>>0);
                if ($578) {
                 $579 = $576 << 1;
                 $580 = ($579|0)==(0);
                 $581 = $580 ? 1 : $579;
                 $582 = ($577>>>0)<($581>>>0);
                 do {
                  if ($582) {
                   $583 = ($576|0)>(-1);
                   if ($583) {
                    HEAP32[$398>>2] = $581;
                    $584 = $581 << 2;
                    $585 = HEAP32[$432>>2]|0;
                    HEAP32[$7>>2] = $585;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$7+0>>2]|0;
                    $586 = (invoke_iiiiiiii(108,($563|0),($584|0),4,($$byval_copy30|0),0,(688784|0),370)|0);
                    $587 = __THREW__; __THREW__ = 0;
                    $588 = $587&1;
                    if ($588) {
                     $$ph$ph92$ph = $605;$$ph90$ph93$ph = $613;
                     break L134;
                    }
                    HEAP32[$396>>2] = $586;
                    $811 = $586;
                    break;
                   } else {
                    $589 = $581 << 2;
                    $590 = HEAP32[$432>>2]|0;
                    HEAP32[$8>>2] = $590;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$8+0>>2]|0;
                    $591 = (invoke_iiiiiii(102,($589|0),4,($$byval_copy30|0),0,(688784|0),352)|0);
                    $592 = __THREW__; __THREW__ = 0;
                    $593 = $592&1;
                    if ($593) {
                     $$ph$ph92$ph = $605;$$ph90$ph93$ph = $613;
                     break L134;
                    }
                    $594 = HEAP32[$396>>2]|0;
                    $595 = HEAP32[$397>>2]|0;
                    $596 = $595 << 2;
                    _memcpy(($591|0),($594|0),($596|0))|0;
                    HEAP32[$398>>2] = $581;
                    HEAP32[$396>>2] = $591;
                    $811 = $591;
                    break;
                   }
                  } else {
                   $811 = $563;
                  }
                 } while(0);
                 $$pre$i$i44 = HEAP32[$397>>2]|0;
                 $598 = $$pre$i$i44;$600 = $811;
                } else {
                 $598 = $575;$600 = $563;
                }
                $597 = (($598) + -1)|0;
                $599 = (($600) + ($597<<2)|0);
                HEAP32[$599>>2] = $$0$i65;
               }
               do {
                if ($519) {
                 $812 = $605;$813 = $603;$814 = $613;
                } else {
                 $601 = ($$0$i72|0)==($$0$i65|0);
                 $or$cond = $573 | $601;
                 if ($or$cond) {
                  $812 = $605;$813 = $603;$814 = $613;
                  break;
                 }
                 $602 = (($603) + 1)|0;
                 $604 = $605 & 2147483647;
                 $606 = ($602>>>0)>($604>>>0);
                 do {
                  if ($606) {
                   $607 = $605 << 1;
                   $608 = ($607|0)==(0);
                   $609 = $608 ? 1 : $607;
                   $610 = ($604>>>0)<($609>>>0);
                   if (!($610)) {
                    $623 = $613;$626 = $605;
                    break;
                   }
                   $611 = ($605|0)>(-1);
                   if ($611) {
                    $612 = $609 << 2;
                    HEAP32[$9>>2] = $395;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$9+0>>2]|0;
                    $614 = (invoke_iiiiiiii(108,($613|0),($612|0),4,($$byval_copy30|0),0,(688784|0),370)|0);
                    $615 = __THREW__; __THREW__ = 0;
                    $616 = $615&1;
                    if ($616) {
                     $$ph$ph92$ph = $609;$$ph90$ph93$ph = $613;
                     break L134;
                    }
                    $623 = $614;$626 = $609;
                    break;
                   } else {
                    $617 = $609 << 2;
                    HEAP32[$10>>2] = $395;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$10+0>>2]|0;
                    $618 = (invoke_iiiiiii(102,($617|0),4,($$byval_copy30|0),0,(688784|0),352)|0);
                    $619 = __THREW__; __THREW__ = 0;
                    $620 = $619&1;
                    if ($620) {
                     $$ph$ph92$ph = $605;$$ph90$ph93$ph = $613;
                     break L134;
                    }
                    $621 = $602 << 2;
                    _memcpy(($618|0),($613|0),($621|0))|0;
                    $623 = $618;$626 = $609;
                    break;
                   }
                  } else {
                   $623 = $613;$626 = $605;
                  }
                 } while(0);
                 $622 = (($623) + ($603<<2)|0);
                 HEAP32[$622>>2] = $518;
                 $624 = (($603) + 2)|0;
                 $625 = $626 & 2147483647;
                 $627 = ($624>>>0)>($625>>>0);
                 do {
                  if ($627) {
                   $628 = $626 << 1;
                   $629 = ($628|0)==(0);
                   $630 = $629 ? 1 : $628;
                   $631 = ($625>>>0)<($630>>>0);
                   if (!($631)) {
                    $643 = $623;$815 = $626;
                    break;
                   }
                   $632 = ($626|0)>(-1);
                   if ($632) {
                    $633 = $630 << 2;
                    HEAP32[$11>>2] = $395;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$11+0>>2]|0;
                    $634 = (invoke_iiiiiiii(108,($623|0),($633|0),4,($$byval_copy30|0),0,(688784|0),370)|0);
                    $635 = __THREW__; __THREW__ = 0;
                    $636 = $635&1;
                    if ($636) {
                     $$ph$ph92$ph = $630;$$ph90$ph93$ph = $623;
                     break L134;
                    }
                    $643 = $634;$815 = $630;
                    break;
                   } else {
                    $637 = $630 << 2;
                    HEAP32[$12>>2] = $395;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$12+0>>2]|0;
                    $638 = (invoke_iiiiiii(102,($637|0),4,($$byval_copy30|0),0,(688784|0),352)|0);
                    $639 = __THREW__; __THREW__ = 0;
                    $640 = $639&1;
                    if ($640) {
                     $$ph$ph92$ph = $626;$$ph90$ph93$ph = $623;
                     break L134;
                    }
                    $641 = $624 << 2;
                    _memcpy(($638|0),($623|0),($641|0))|0;
                    $643 = $638;$815 = $630;
                    break;
                   }
                  } else {
                   $643 = $623;$815 = $626;
                  }
                 } while(0);
                 $642 = (($643) + ($602<<2)|0);
                 HEAP32[$642>>2] = $572;
                 $812 = $815;$813 = $624;$814 = $643;
                }
               } while(0);
               $644 = (($sIt$0117) + 8|0);
               $645 = ($644|0)==($428|0);
               if ($645) {
                $$lcssa111 = $812;$$lcssa113 = $813;$$lcssa115 = $814;
                label = 167;
                break L132;
               } else {
                $603 = $813;$605 = $812;$613 = $814;$sIt$0117 = $644;
               }
              }
              $553 = ___cxa_find_matching_catch()|0;
              $554 = tempRet0;
              $558 = $$ph$ph92$ph;$810 = $$ph90$ph93$ph;$lpad$phi$index = $553;$lpad$phi$index4 = $554;
             }
            } while(0);
            L229: do {
             if ((label|0) == 167) {
              $646 = (($this) + 116|0);
              $647 = HEAP32[$646>>2]|0;
              $648 = HEAP32[$402>>2]|0;
              $649 = (($647) + ($648<<2)|0);
              $650 = ($648|0)==(0);
              L231: do {
               if ($650) {
                $$lcssa = $$lcssa111;$$lcssa100 = $$lcssa115;$$lcssa98 = $$lcssa113;
               } else {
                $651 = HEAP32[$397>>2]|0;
                $691 = $$lcssa113;$693 = $$lcssa111;$701 = $$lcssa115;$cIt$0103 = $647;$sphereIndex$0102 = $651;
                L233: while(1) {
                 $652 = HEAP32[$cIt$0103>>2]|0;
                 $653 = ($652|0)==(0);
                 do {
                  if ($653) {
                   $816 = $693;$817 = $691;$818 = $701;$sphereIndex$1 = $sphereIndex$0102;
                  } else {
                   HEAP32[$13>>2] = $652;
                   $654 = HEAP32[560624>>2]|0;
                   $655 = ($654|0)==(0|0);
                   do {
                    if ($655) {
                     label = 178;
                    } else {
                     $656 = (($654) + 36|0);
                     $657 = HEAP32[$656>>2]|0;
                     $658 = (($654) + 4|0);
                     $659 = HEAP32[$658>>2]|0;
                     $660 = ($657|0)==($659|0);
                     do {
                      if ($660) {
                       $661 = (($654) + 28|0);
                       $662 = HEAP32[$661>>2]|0;
                       $663 = (($654) + 32|0);
                       $664 = HEAP32[$663>>2]|0;
                       $665 = (($662) + ($664<<3)|0);
                       $681 = $665;
                      } else {
                       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy30,$654,$13);
                       $666 = HEAP32[$$byval_copy30>>2]|0;
                       $667 = ($666|0)==(-1);
                       $668 = (($654) + 28|0);
                       $669 = HEAP32[$668>>2]|0;
                       if ($667) {
                        $670 = (($654) + 32|0);
                        $671 = HEAP32[$670>>2]|0;
                        $672 = (($669) + ($671<<3)|0);
                        $681 = $672;
                        break;
                       } else {
                        $673 = (($669) + ($666<<3)|0);
                        $681 = $673;
                        break;
                       }
                      }
                     } while(0);
                     $674 = HEAP32[560624>>2]|0;
                     $675 = (($674) + 28|0);
                     $676 = HEAP32[$675>>2]|0;
                     $677 = (($674) + 32|0);
                     $678 = HEAP32[$677>>2]|0;
                     $679 = (($676) + ($678<<3)|0);
                     $680 = ($681|0)==($679|0);
                     if ($680) {
                      label = 178;
                      break;
                     }
                     $682 = (($681) + 4|0);
                     $683 = HEAP32[$682>>2]|0;
                     $684 = ($683|0)==(0|0);
                     if ($684) {
                      label = 178;
                     }
                    }
                   } while(0);
                   if ((label|0) == 178) {
                    label = 0;
                    $685 = HEAP32[$cIt$0103>>2]|0;
                    __THREW__ = 0;
                    $686 = (invoke_ii(3215,($685|0))|0);
                    $687 = __THREW__; __THREW__ = 0;
                    $688 = $687&1;
                    if ($688) {
                     $$ph$ph = $693;$$ph90$ph = $701;
                     break L233;
                    }
                    $689 = ($686|0)==(0|0);
                    if ($689) {
                     $816 = $693;$817 = $691;$818 = $701;$sphereIndex$1 = $sphereIndex$0102;
                     break;
                    }
                   }
                   $690 = (($691) + 1)|0;
                   $692 = $693 & 2147483647;
                   $694 = ($690>>>0)>($692>>>0);
                   do {
                    if ($694) {
                     $695 = $693 << 1;
                     $696 = ($695|0)==(0);
                     $697 = $696 ? 1 : $695;
                     $698 = ($692>>>0)<($697>>>0);
                     if (!($698)) {
                      $711 = $701;$716 = $693;
                      break;
                     }
                     $699 = ($693|0)>(-1);
                     if ($699) {
                      $700 = $697 << 2;
                      HEAP32[$15>>2] = $395;
                      __THREW__ = 0;
                      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$15+0>>2]|0;
                      $702 = (invoke_iiiiiiii(108,($701|0),($700|0),4,($$byval_copy30|0),0,(688784|0),370)|0);
                      $703 = __THREW__; __THREW__ = 0;
                      $704 = $703&1;
                      if ($704) {
                       $$ph$ph = $697;$$ph90$ph = $701;
                       break L233;
                      }
                      $711 = $702;$716 = $697;
                      break;
                     } else {
                      $705 = $697 << 2;
                      HEAP32[$16>>2] = $395;
                      __THREW__ = 0;
                      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$16+0>>2]|0;
                      $706 = (invoke_iiiiiii(102,($705|0),4,($$byval_copy30|0),0,(688784|0),352)|0);
                      $707 = __THREW__; __THREW__ = 0;
                      $708 = $707&1;
                      if ($708) {
                       $$ph$ph = $693;$$ph90$ph = $701;
                       break L233;
                      }
                      $709 = $690 << 2;
                      _memcpy(($706|0),($701|0),($709|0))|0;
                      $711 = $706;$716 = $697;
                      break;
                     }
                    } else {
                     $711 = $701;$716 = $693;
                    }
                   } while(0);
                   $710 = (($711) + ($691<<2)|0);
                   HEAP32[$710>>2] = $sphereIndex$0102;
                   $712 = (($sphereIndex$0102) + 1)|0;
                   $713 = (($sphereIndex$0102) + 2)|0;
                   $714 = (($691) + 2)|0;
                   $715 = $716 & 2147483647;
                   $717 = ($714>>>0)>($715>>>0);
                   do {
                    if ($717) {
                     $718 = $716 << 1;
                     $719 = ($718|0)==(0);
                     $720 = $719 ? 1 : $718;
                     $721 = ($715>>>0)<($720>>>0);
                     if (!($721)) {
                      $733 = $711;$819 = $716;
                      break;
                     }
                     $722 = ($716|0)>(-1);
                     if ($722) {
                      $723 = $720 << 2;
                      HEAP32[$17>>2] = $395;
                      __THREW__ = 0;
                      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$17+0>>2]|0;
                      $724 = (invoke_iiiiiiii(108,($711|0),($723|0),4,($$byval_copy30|0),0,(688784|0),370)|0);
                      $725 = __THREW__; __THREW__ = 0;
                      $726 = $725&1;
                      if ($726) {
                       $$ph$ph = $720;$$ph90$ph = $711;
                       break L233;
                      }
                      $733 = $724;$819 = $720;
                      break;
                     } else {
                      $727 = $720 << 2;
                      HEAP32[$18>>2] = $395;
                      __THREW__ = 0;
                      ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$18+0>>2]|0;
                      $728 = (invoke_iiiiiii(102,($727|0),4,($$byval_copy30|0),0,(688784|0),352)|0);
                      $729 = __THREW__; __THREW__ = 0;
                      $730 = $729&1;
                      if ($730) {
                       $$ph$ph = $716;$$ph90$ph = $711;
                       break L233;
                      }
                      $731 = $714 << 2;
                      _memcpy(($728|0),($711|0),($731|0))|0;
                      $733 = $728;$819 = $720;
                      break;
                     }
                    } else {
                     $733 = $711;$819 = $716;
                    }
                   } while(0);
                   $732 = (($733) + ($690<<2)|0);
                   HEAP32[$732>>2] = $712;
                   $816 = $819;$817 = $714;$818 = $733;$sphereIndex$1 = $713;
                  }
                 } while(0);
                 $734 = (($cIt$0103) + 4|0);
                 $735 = ($734|0)==($649|0);
                 if ($735) {
                  $$lcssa = $816;$$lcssa100 = $818;$$lcssa98 = $817;
                  break L231;
                 } else {
                  $691 = $817;$693 = $816;$701 = $818;$cIt$0103 = $734;$sphereIndex$0102 = $sphereIndex$1;
                 }
                }
                $551 = ___cxa_find_matching_catch()|0;
                $552 = tempRet0;
                $558 = $$ph$ph;$810 = $$ph90$ph;$lpad$phi$index = $551;$lpad$phi$index4 = $552;
                break L229;
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3631,($this|0));
              $736 = __THREW__; __THREW__ = 0;
              $737 = $736&1;
              do {
               if (!($737)) {
                __THREW__ = 0;
                $738 = (invoke_i(115)|0);
                $739 = __THREW__; __THREW__ = 0;
                $740 = $739&1;
                if ($740) {
                 break;
                }
                $741 = HEAP32[$738>>2]|0;
                $742 = (($741) + 120|0);
                $743 = HEAP32[$742>>2]|0;
                HEAPF32[$30>>2] = Math_fround(0.0);
                $744 = (($30) + 4|0);
                HEAPF32[$744>>2] = Math_fround(0.0);
                $745 = (($30) + 8|0);
                HEAPF32[$745>>2] = Math_fround(0.0);
                $746 = (($30) + 12|0);
                HEAPF32[$746>>2] = Math_fround(1.0);
                $747 = (($30) + 16|0);
                HEAPF32[$747>>2] = Math_fround(0.0);
                $748 = (($30) + 20|0);
                HEAPF32[$748>>2] = Math_fround(0.0);
                $749 = (($30) + 24|0);
                HEAPF32[$749>>2] = Math_fround(0.0);
                HEAP16[$31>>1] = 0;
                __THREW__ = 0;
                $750 = (invoke_iiiiii($743|0,($738|0),($30|0),($391|0),($362|0),($31|0))|0);
                $751 = __THREW__; __THREW__ = 0;
                $752 = $751&1;
                if ($752) {
                 break;
                }
                HEAP32[$32>>2] = $750;
                $753 = HEAP32[$750>>2]|0;
                $754 = (($753) + 284|0);
                $755 = HEAP32[$754>>2]|0;
                $756 = (($this) + 164|0);
                $757 = HEAP32[$756>>2]|0;
                $758 = (($this) + 172|0);
                $759 = HEAP32[$758>>2]|0;
                __THREW__ = 0;
                invoke_viii($755|0,($750|0),($757|0),($759|0));
                $760 = __THREW__; __THREW__ = 0;
                $761 = $760&1;
                if ($761) {
                 break;
                }
                $762 = $$lcssa98 >>> 1;
                $763 = ($762|0)==(0);
                L277: do {
                 if (!($763)) {
                  $i2$091 = 0;
                  while(1) {
                   $764 = HEAP32[$32>>2]|0;
                   $765 = HEAP32[$764>>2]|0;
                   $766 = (($765) + 292|0);
                   $767 = HEAP32[$766>>2]|0;
                   $768 = $i2$091 << 1;
                   $769 = (($$lcssa100) + ($768<<2)|0);
                   $770 = HEAP32[$769>>2]|0;
                   $771 = $768 | 1;
                   $772 = (($$lcssa100) + ($771<<2)|0);
                   $773 = HEAP32[$772>>2]|0;
                   __THREW__ = 0;
                   invoke_viii($767|0,($764|0),($770|0),($773|0));
                   $774 = __THREW__; __THREW__ = 0;
                   $775 = $774&1;
                   if ($775) {
                    break;
                   }
                   $776 = (($i2$091) + 1)|0;
                   $777 = ($776>>>0)<($762>>>0);
                   if ($777) {
                    $i2$091 = $776;
                   } else {
                    break L277;
                   }
                  }
                  $549 = ___cxa_find_matching_catch()|0;
                  $550 = tempRet0;
                  $558 = $$lcssa;$810 = $$lcssa100;$lpad$phi$index = $549;$lpad$phi$index4 = $550;
                  break L229;
                 }
                } while(0);
                $778 = HEAP32[$32>>2]|0;
                $779 = (($778) + 8|0);
                HEAP32[$779>>2] = $this;
                $780 = HEAP32[$269>>2]|0;
                $781 = HEAP32[$780>>2]|0;
                $782 = (($781) + 44|0);
                $783 = HEAP32[$782>>2]|0;
                $784 = HEAP32[$32>>2]|0;
                __THREW__ = 0;
                invoke_vii($783|0,($780|0),($784|0));
                $785 = __THREW__; __THREW__ = 0;
                $786 = $785&1;
                if ($786) {
                 break;
                }
                $787 = (($this) + 264|0);
                HEAP32[$787>>2] = 0;
                $788 = (($this) + 268|0);
                HEAP32[$788>>2] = 0;
                $789 = (($this) + 272|0);
                HEAP32[$789>>2] = 0;
                __THREW__ = 0;
                invoke_vi(3632,($this|0));
                $790 = __THREW__; __THREW__ = 0;
                $791 = $790&1;
                if ($791) {
                 break;
                }
                $792 = ($$lcssa|0)>(-1);
                if (!($792)) {
                 break L108;
                }
                HEAP32[$19>>2] = $395;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$19+0>>2]|0;
                invoke_vii(2591,($$lcssa100|0),($$byval_copy30|0));
                $793 = __THREW__; __THREW__ = 0;
                $794 = $793&1;
                if ($794) {
                 $805 = $796;$806 = $362;
                 label = 78;
                 break L101;
                } else {
                 break L108;
                }
               }
              } while(0);
              $555 = ___cxa_find_matching_catch()|0;
              $556 = tempRet0;
              $558 = $$lcssa;$810 = $$lcssa100;$lpad$phi$index = $555;$lpad$phi$index4 = $556;
             }
            } while(0);
            $557 = ($558|0)>(-1);
            if ($557) {
             $559 = $810;$808 = $lpad$phi$index4;$809 = $lpad$phi$index;
            } else {
             $$0 = $lpad$phi$index;$$01 = $lpad$phi$index4;$798 = $796;$799 = $362;
             break L101;
            }
           }
           HEAP32[$6>>2] = $395;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$6+0>>2]|0;
           invoke_vii(2591,($559|0),($$byval_copy30|0));
           $560 = __THREW__; __THREW__ = 0;
           $561 = $560&1;
           if (!($561)) {
            $$0 = $809;$$01 = $808;$798 = $796;$799 = $362;
            break L101;
           }
           $802 = ___cxa_find_matching_catch(0|0)|0;
           $803 = tempRet0;
           ___clang_call_terminate($802);
           // unreachable;
          }
         }
        } while(0);
        $795 = ($796|0)>(-1);
        if (!($795)) {
         STACKTOP = sp;return;
        }
        HEAP32[$0>>2] = $327;
        ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$0+0>>2]|0;
        __Z19free_alloc_internalPv10MemLabelId($362,$$byval_copy30);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 78) {
  $369 = ___cxa_find_matching_catch()|0;
  $370 = tempRet0;
  $$0 = $369;$$01 = $370;$798 = $805;$799 = $806;
 }
 $797 = ($798|0)>(-1);
 if (!($797)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 HEAP32[$20>>2] = $327;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$20+0>>2]|0;
 invoke_vii(2591,($799|0),($$byval_copy30|0));
 $800 = __THREW__; __THREW__ = 0;
 $801 = $800&1;
 if ($801) {
  $802 = ___cxa_find_matching_catch(0|0)|0;
  $803 = tempRet0;
  ___clang_call_terminate($802);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN5Unity5Cloth13UpdateNormalsEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0;
 var $i$05 = 0, $i1$02 = 0, $i2$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 248|0);
 $2 = (($this) + 192|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 256|0);
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 260|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($3>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $3;
    $10 = HEAP32[$1>>2]|0;
    $11 = ($3*12)|0;
    $12 = (($this) + 252|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($10,$11,4,$$byval_copy1,0,688784,370)|0);
    HEAP32[$1>>2] = $14;
    break;
   } else {
    $15 = ($3*12)|0;
    $16 = (($this) + 252|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,4,$$byval_copy1,0,688784,352)|0);
    $19 = HEAP32[$1>>2]|0;
    $20 = HEAP32[$4>>2]|0;
    $21 = ($20*12)|0;
    _memcpy(($18|0),($19|0),($21|0))|0;
    HEAP32[$5>>2] = $3;
    HEAP32[$1>>2] = $18;
    break;
   }
  }
 } while(0);
 $22 = HEAP32[$2>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $35 = 0;
 } else {
  $i$05 = 0;
  while(1) {
   $24 = HEAP32[$1>>2]|0;
   $25 = (($24) + (($i$05*12)|0)|0);
   ;HEAP32[$25+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[616680+8>>2]|0;
   $26 = (($i$05) + 1)|0;
   $27 = HEAP32[$2>>2]|0;
   $28 = ($26>>>0)<($27>>>0);
   if ($28) {
    $i$05 = $26;
   } else {
    $35 = $27;
    break;
   }
  }
 }
 $29 = (($this) + 224|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if (!($31)) {
  $32 = (($this) + 216|0);
  $33 = (($this) + 232|0);
  $$pre = HEAP32[$32>>2]|0;
  $$pre7 = HEAP32[$33>>2]|0;
  $$pre8 = HEAP32[$1>>2]|0;
  $i1$02 = 0;
  while(1) {
   $37 = (($$pre) + ($i1$02<<1)|0);
   $38 = HEAP16[$37>>1]|0;
   $39 = $38&65535;
   $40 = (($i1$02) + 1)|0;
   $41 = (($$pre) + ($40<<1)|0);
   $42 = HEAP16[$41>>1]|0;
   $43 = $42&65535;
   $44 = (($i1$02) + 2)|0;
   $45 = (($$pre) + ($44<<1)|0);
   $46 = HEAP16[$45>>1]|0;
   $47 = $46&65535;
   $48 = (($$pre7) + (($39*12)|0)|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = ((($$pre7) + (($39*12)|0)|0) + 4|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = ((($$pre7) + (($39*12)|0)|0) + 8|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = (($$pre7) + (($43*12)|0)|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = Math_fround($55 - $49);
   $57 = ((($$pre7) + (($43*12)|0)|0) + 4|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = Math_fround($58 - $51);
   $60 = ((($$pre7) + (($43*12)|0)|0) + 8|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = Math_fround($61 - $53);
   $63 = (($$pre7) + (($47*12)|0)|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = Math_fround($64 - $49);
   $66 = ((($$pre7) + (($47*12)|0)|0) + 4|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = Math_fround($67 - $51);
   $69 = ((($$pre7) + (($47*12)|0)|0) + 8|0);
   $70 = Math_fround(HEAPF32[$69>>2]);
   $71 = Math_fround($70 - $53);
   $72 = Math_fround($59 * $71);
   $73 = Math_fround($62 * $68);
   $74 = Math_fround($72 - $73);
   $75 = Math_fround($62 * $65);
   $76 = Math_fround($56 * $71);
   $77 = Math_fround($75 - $76);
   $78 = Math_fround($56 * $68);
   $79 = Math_fround($59 * $65);
   $80 = Math_fround($78 - $79);
   $81 = (($$pre8) + (($39*12)|0)|0);
   $82 = Math_fround(HEAPF32[$81>>2]);
   $83 = Math_fround($82 + $74);
   HEAPF32[$81>>2] = $83;
   $84 = ((($$pre8) + (($39*12)|0)|0) + 4|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $86 = Math_fround($77 + $85);
   HEAPF32[$84>>2] = $86;
   $87 = ((($$pre8) + (($39*12)|0)|0) + 8|0);
   $88 = Math_fround(HEAPF32[$87>>2]);
   $89 = Math_fround($80 + $88);
   HEAPF32[$87>>2] = $89;
   $90 = (($$pre8) + (($43*12)|0)|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $92 = Math_fround($74 + $91);
   HEAPF32[$90>>2] = $92;
   $93 = ((($$pre8) + (($43*12)|0)|0) + 4|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = Math_fround($77 + $94);
   HEAPF32[$93>>2] = $95;
   $96 = ((($$pre8) + (($43*12)|0)|0) + 8|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $98 = Math_fround($80 + $97);
   HEAPF32[$96>>2] = $98;
   $99 = (($$pre8) + (($47*12)|0)|0);
   $100 = Math_fround(HEAPF32[$99>>2]);
   $101 = Math_fround($74 + $100);
   HEAPF32[$99>>2] = $101;
   $102 = ((($$pre8) + (($47*12)|0)|0) + 4|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = Math_fround($77 + $103);
   HEAPF32[$102>>2] = $104;
   $105 = ((($$pre8) + (($47*12)|0)|0) + 8|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = Math_fround($80 + $106);
   HEAPF32[$105>>2] = $107;
   $108 = (($i1$02) + 3)|0;
   $109 = ($108>>>0)<($30>>>0);
   if ($109) {
    $i1$02 = $108;
   } else {
    break;
   }
  }
 }
 $34 = ($35|0)==(0);
 if ($34) {
  STACKTOP = sp;return;
 }
 $36 = Math_fround(HEAPF32[616648>>2]);
 $i2$01 = 0;
 while(1) {
  $110 = HEAP32[$1>>2]|0;
  $111 = (($110) + (($i2$01*12)|0)|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = Math_fround($112 * $112);
  $114 = ((($110) + (($i2$01*12)|0)|0) + 4|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = Math_fround($115 * $115);
  $117 = Math_fround($113 + $116);
  $118 = ((($110) + (($i2$01*12)|0)|0) + 8|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = Math_fround($119 * $119);
  $121 = Math_fround($117 + $120);
  $122 = (Math_fround(Math_sqrt((Math_fround($121)))));
  $123 = $122 > $36;
  if ($123) {
   $124 = Math_fround($112 / $122);
   $125 = Math_fround($115 / $122);
   $126 = Math_fround($119 / $122);
   $130 = $124;$131 = $125;$132 = $126;
  } else {
   $127 = Math_fround(HEAPF32[616680>>2]);
   $128 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
   $129 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
   $130 = $127;$131 = $128;$132 = $129;
  }
  HEAPF32[$111>>2] = $130;
  HEAPF32[$114>>2] = $131;
  HEAPF32[$118>>2] = $132;
  $133 = (($i2$01) + 1)|0;
  $134 = HEAP32[$2>>2]|0;
  $135 = ($133>>>0)<($134>>>0);
  if ($135) {
   $i2$01 = $133;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIN5Unity5Cloth26ClothConstrainCoefficientsELj4EE18resize_initializedEjRKS2_b($this,$size,$t,$double_on_resize) {
 $this = $this|0;
 $size = $size|0;
 $t = $t|0;
 $double_on_resize = $double_on_resize|0;
 var $$01$i = 0, $$byval_copy1 = 0, $$size = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $requested_size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($3>>>0)<($size>>>0);
 do {
  if ($4) {
   if ($double_on_resize) {
    $5 = $2 << 1;
    $6 = ($5>>>0)>($size>>>0);
    $$size = $6 ? $5 : $size;
    $requested_size$0 = $$size;
   } else {
    $requested_size$0 = $size;
   }
   $7 = ($3>>>0)<($requested_size$0>>>0);
   if ($7) {
    $8 = ($2|0)>(-1);
    if ($8) {
     HEAP32[$1>>2] = $requested_size$0;
     $9 = HEAP32[$this>>2]|0;
     $10 = $requested_size$0 << 3;
     $11 = (($this) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     HEAP32[$0>>2] = $12;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($9,$10,4,$$byval_copy1,0,688784,370)|0);
     HEAP32[$this>>2] = $13;
     break;
    } else {
     $14 = $requested_size$0 << 3;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,688784,352)|0);
     $18 = HEAP32[$this>>2]|0;
     $19 = (($this) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = $20 << 3;
     _memcpy(($17|0),($18|0),($21|0))|0;
     HEAP32[$1>>2] = $requested_size$0;
     HEAP32[$this>>2] = $17;
     break;
    }
   }
  }
 } while(0);
 $22 = (($this) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($size>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + ($size<<3)|0);
 $27 = ($23|0)==($size|0);
 if ($27) {
  HEAP32[$22>>2] = $size;
  STACKTOP = sp;return;
 }
 $28 = (($25) + ($23<<3)|0);
 $$01$i = $28;
 while(1) {
  $29 = ($$01$i|0)==(0|0);
  if (!($29)) {
   $30 = $t;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $$01$i;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
  }
  $40 = (($$01$i) + 8|0);
  $41 = ($40|0)==($26|0);
  if ($41) {
   break;
  } else {
   $$01$i = $40;
  }
 }
 HEAP32[$22>>2] = $size;
 STACKTOP = sp;return;
}
function __ZN5Unity5Cloth15UpdateCollidersEv($this) {
 $this = $this|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0);
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0);
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cIt$07 = 0;
 var $extent = 0, $pos$i$i$i$i = 0, $sIt$08 = 0, $worldToRoot = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $pos$i$i$i$i = sp + 208|0;
 $0 = sp + 200|0;
 $worldToRoot = sp + 136|0;
 $1 = sp + 120|0;
 $2 = sp + 104|0;
 $extent = sp + 80|0;
 $3 = sp + 16|0;
 $4 = sp;
 $5 = sp + 88|0;
 $6 = (($this) + 164|0);
 $7 = (($this) + 172|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($9,137)|0);
 $11 = (__ZN19SkinnedMeshRenderer17GetActualRootBoneEv($10)|0);
 __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($worldToRoot,$11);
 $12 = (($this) + 148|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 156|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + ($15<<2)|0);
 $17 = ($15|0)==(0);
 if (!($17)) {
  $18 = (($worldToRoot) + 16|0);
  $19 = (($1) + 4|0);
  $20 = (($worldToRoot) + 32|0);
  $21 = (($1) + 8|0);
  $22 = (($worldToRoot) + 48|0);
  $23 = (($worldToRoot) + 4|0);
  $24 = (($worldToRoot) + 20|0);
  $25 = (($worldToRoot) + 36|0);
  $26 = (($worldToRoot) + 52|0);
  $27 = (($worldToRoot) + 8|0);
  $28 = (($worldToRoot) + 24|0);
  $29 = (($worldToRoot) + 40|0);
  $30 = (($worldToRoot) + 56|0);
  $31 = (($2) + 4|0);
  $32 = (($2) + 8|0);
  $33 = (($2) + 12|0);
  $sIt$08 = $13;
  while(1) {
   $34 = HEAP32[$sIt$08>>2]|0;
   __ZNK14SphereCollider15GetGlobalCenterEv($1,$34);
   $35 = Math_fround(HEAPF32[$worldToRoot>>2]);
   $36 = Math_fround(HEAPF32[$1>>2]);
   $37 = Math_fround($35 * $36);
   $38 = Math_fround(HEAPF32[$18>>2]);
   $39 = Math_fround(HEAPF32[$19>>2]);
   $40 = Math_fround($38 * $39);
   $41 = Math_fround($37 + $40);
   $42 = Math_fround(HEAPF32[$20>>2]);
   $43 = Math_fround(HEAPF32[$21>>2]);
   $44 = Math_fround($42 * $43);
   $45 = Math_fround($41 + $44);
   $46 = Math_fround(HEAPF32[$22>>2]);
   $47 = Math_fround($46 + $45);
   $48 = Math_fround(HEAPF32[$23>>2]);
   $49 = Math_fround($36 * $48);
   $50 = Math_fround(HEAPF32[$24>>2]);
   $51 = Math_fround($39 * $50);
   $52 = Math_fround($49 + $51);
   $53 = Math_fround(HEAPF32[$25>>2]);
   $54 = Math_fround($43 * $53);
   $55 = Math_fround($52 + $54);
   $56 = Math_fround(HEAPF32[$26>>2]);
   $57 = Math_fround($56 + $55);
   $58 = Math_fround(HEAPF32[$27>>2]);
   $59 = Math_fround($36 * $58);
   $60 = Math_fround(HEAPF32[$28>>2]);
   $61 = Math_fround($39 * $60);
   $62 = Math_fround($59 + $61);
   $63 = Math_fround(HEAPF32[$29>>2]);
   $64 = Math_fround($43 * $63);
   $65 = Math_fround($62 + $64);
   $66 = Math_fround(HEAPF32[$30>>2]);
   $67 = Math_fround($66 + $65);
   $68 = (Math_fround(__ZNK14SphereCollider15GetScaledRadiusERK8Vector3f($34,616696)));
   HEAPF32[$2>>2] = $47;
   HEAPF32[$31>>2] = $57;
   HEAPF32[$32>>2] = $67;
   HEAPF32[$33>>2] = $68;
   __ZN13dynamic_arrayI8Vector4fLj4EE9push_backERKS0_($6,$2);
   $69 = (($sIt$08) + 4|0);
   $70 = ($69|0)==($16|0);
   if ($70) {
    break;
   } else {
    $sIt$08 = $69;
   }
  }
 }
 $71 = (($this) + 116|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($this) + 124|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($72) + ($74<<2)|0);
 $76 = ($74|0)==(0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (($extent) + 4|0);
 $78 = (($pos$i$i$i$i) + 16|0);
 $79 = (($pos$i$i$i$i) + 32|0);
 $80 = (($pos$i$i$i$i) + 48|0);
 $81 = (($pos$i$i$i$i) + 4|0);
 $82 = (($pos$i$i$i$i) + 20|0);
 $83 = (($pos$i$i$i$i) + 36|0);
 $84 = (($pos$i$i$i$i) + 52|0);
 $85 = (($pos$i$i$i$i) + 8|0);
 $86 = (($pos$i$i$i$i) + 24|0);
 $87 = (($pos$i$i$i$i) + 40|0);
 $88 = (($pos$i$i$i$i) + 56|0);
 $89 = (($4) + 4|0);
 $90 = (($4) + 8|0);
 $91 = (($4) + 12|0);
 $92 = (($5) + 4|0);
 $93 = (($5) + 8|0);
 $94 = (($5) + 12|0);
 $cIt$07 = $72;
 while(1) {
  $95 = HEAP32[$cIt$07>>2]|0;
  $96 = ($95|0)==(0);
  do {
   if (!($96)) {
    HEAP32[$0>>2] = $95;
    $97 = HEAP32[560624>>2]|0;
    $98 = ($97|0)==(0|0);
    if ($98) {
     label = 16;
    } else {
     $99 = (($97) + 36|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = (($97) + 4|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = ($100|0)==($102|0);
     do {
      if ($103) {
       $104 = (($97) + 28|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = (($97) + 32|0);
       $107 = HEAP32[$106>>2]|0;
       $108 = (($105) + ($107<<3)|0);
       $124 = $108;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$97,$0);
       $109 = HEAP32[$pos$i$i$i$i>>2]|0;
       $110 = ($109|0)==(-1);
       $111 = (($97) + 28|0);
       $112 = HEAP32[$111>>2]|0;
       if ($110) {
        $113 = (($97) + 32|0);
        $114 = HEAP32[$113>>2]|0;
        $115 = (($112) + ($114<<3)|0);
        $124 = $115;
        break;
       } else {
        $116 = (($112) + ($109<<3)|0);
        $124 = $116;
        break;
       }
      }
     } while(0);
     $117 = HEAP32[560624>>2]|0;
     $118 = (($117) + 28|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = (($117) + 32|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = (($119) + ($121<<3)|0);
     $123 = ($124|0)==($122|0);
     if ($123) {
      label = 16;
     } else {
      $125 = (($124) + 4|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = ($126|0)==(0|0);
      if ($127) {
       label = 16;
      } else {
       $$in = $126;
      }
     }
    }
    if ((label|0) == 16) {
     label = 0;
     $128 = HEAP32[$cIt$07>>2]|0;
     $129 = (__Z31ReadObjectFromPersistentManageri($128)|0);
     $130 = ($129|0)==(0|0);
     if ($130) {
      break;
     } else {
      $$in = $129;
     }
    }
    __ZNK15CapsuleCollider16GetGlobalExtentsERK8Vector3f($extent,$$in,616696);
    $131 = Math_fround(HEAPF32[$77>>2]);
    $132 = Math_fround($131 * Math_fround(0.5));
    dest=$pos$i$i$i$i+0|0; src=$worldToRoot+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    __ZNK15CapsuleCollider18CalculateTransformEv($3,$$in);
    (__ZN10Matrix4x4fmLERKS_($pos$i$i$i$i,$3)|0);
    $133 = Math_fround(HEAPF32[$pos$i$i$i$i>>2]);
    $134 = Math_fround($132 * $133);
    $135 = Math_fround(HEAPF32[$78>>2]);
    $136 = Math_fround($135 * Math_fround(0.0));
    $137 = Math_fround($134 + $136);
    $138 = Math_fround(HEAPF32[$79>>2]);
    $139 = Math_fround($138 * Math_fround(0.0));
    $140 = Math_fround($137 + $139);
    $141 = Math_fround(HEAPF32[$80>>2]);
    $142 = Math_fround($141 + $140);
    $143 = Math_fround(HEAPF32[$81>>2]);
    $144 = Math_fround($132 * $143);
    $145 = Math_fround(HEAPF32[$82>>2]);
    $146 = Math_fround($145 * Math_fround(0.0));
    $147 = Math_fround($144 + $146);
    $148 = Math_fround(HEAPF32[$83>>2]);
    $149 = Math_fround($148 * Math_fround(0.0));
    $150 = Math_fround($147 + $149);
    $151 = Math_fround(HEAPF32[$84>>2]);
    $152 = Math_fround($151 + $150);
    $153 = Math_fround(HEAPF32[$85>>2]);
    $154 = Math_fround($132 * $153);
    $155 = Math_fround(HEAPF32[$86>>2]);
    $156 = Math_fround($155 * Math_fround(0.0));
    $157 = Math_fround($154 + $156);
    $158 = Math_fround(HEAPF32[$87>>2]);
    $159 = Math_fround($158 * Math_fround(0.0));
    $160 = Math_fround($157 + $159);
    $161 = Math_fround(HEAPF32[$88>>2]);
    $162 = Math_fround($161 + $160);
    $163 = Math_fround(HEAPF32[$extent>>2]);
    HEAPF32[$4>>2] = $142;
    HEAPF32[$89>>2] = $152;
    HEAPF32[$90>>2] = $162;
    HEAPF32[$91>>2] = $163;
    __ZN13dynamic_arrayI8Vector4fLj4EE9push_backERKS0_($6,$4);
    $164 = Math_fround(-$132);
    $165 = Math_fround(HEAPF32[$pos$i$i$i$i>>2]);
    $166 = Math_fround($165 * $164);
    $167 = Math_fround(HEAPF32[$78>>2]);
    $168 = Math_fround($167 * Math_fround(-0.0));
    $169 = Math_fround($166 + $168);
    $170 = Math_fround(HEAPF32[$79>>2]);
    $171 = Math_fround($170 * Math_fround(-0.0));
    $172 = Math_fround($169 + $171);
    $173 = Math_fround(HEAPF32[$80>>2]);
    $174 = Math_fround($173 + $172);
    $175 = Math_fround(HEAPF32[$81>>2]);
    $176 = Math_fround($175 * $164);
    $177 = Math_fround(HEAPF32[$82>>2]);
    $178 = Math_fround($177 * Math_fround(-0.0));
    $179 = Math_fround($176 + $178);
    $180 = Math_fround(HEAPF32[$83>>2]);
    $181 = Math_fround($180 * Math_fround(-0.0));
    $182 = Math_fround($179 + $181);
    $183 = Math_fround(HEAPF32[$84>>2]);
    $184 = Math_fround($183 + $182);
    $185 = Math_fround(HEAPF32[$85>>2]);
    $186 = Math_fround($185 * $164);
    $187 = Math_fround(HEAPF32[$86>>2]);
    $188 = Math_fround($187 * Math_fround(-0.0));
    $189 = Math_fround($186 + $188);
    $190 = Math_fround(HEAPF32[$87>>2]);
    $191 = Math_fround($190 * Math_fround(-0.0));
    $192 = Math_fround($189 + $191);
    $193 = Math_fround(HEAPF32[$88>>2]);
    $194 = Math_fround($193 + $192);
    $195 = Math_fround(HEAPF32[$extent>>2]);
    HEAPF32[$5>>2] = $174;
    HEAPF32[$92>>2] = $184;
    HEAPF32[$93>>2] = $194;
    HEAPF32[$94>>2] = $195;
    __ZN13dynamic_arrayI8Vector4fLj4EE9push_backERKS0_($6,$5);
   }
  } while(0);
  $196 = (($cIt$07) + 4|0);
  $197 = ($196|0)==($75|0);
  if ($197) {
   break;
  } else {
   $cIt$07 = $196;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayI8Vector4fLj4EE9push_backERKS0_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if (!($7)) {
  $26 = $3;
  $25 = (($26) + -1)|0;
  $27 = HEAP32[$this>>2]|0;
  $28 = (($27) + ($25<<4)|0);
  ;HEAP32[$28+0>>2]=HEAP32[$t+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$t+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$t+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$t+12>>2]|0;
  STACKTOP = sp;return;
 }
 $8 = $5 << 1;
 $9 = ($8|0)==(0);
 $10 = $9 ? 1 : $8;
 $11 = ($6>>>0)<($10>>>0);
 do {
  if ($11) {
   $12 = ($5|0)>(-1);
   if ($12) {
    HEAP32[$4>>2] = $10;
    $13 = HEAP32[$this>>2]|0;
    $14 = $10 << 4;
    $15 = (($this) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,688784,370)|0);
    HEAP32[$this>>2] = $17;
    break;
   } else {
    $18 = $10 << 4;
    $19 = (($this) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,688784,352)|0);
    $22 = HEAP32[$this>>2]|0;
    $23 = HEAP32[$1>>2]|0;
    $24 = $23 << 4;
    _memcpy(($21|0),($22|0),($24|0))|0;
    HEAP32[$4>>2] = $10;
    HEAP32[$this>>2] = $21;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$1>>2]|0;
 $26 = $$pre$i;
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + ($25<<4)|0);
 ;HEAP32[$28+0>>2]=HEAP32[$t+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$t+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$t+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$t+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN5Unity5Cloth19SetUpSkinnedBuffersEPvS1_S1_j($this,$vertices,$normals,$tangents,$bufferStride) {
 $this = $this|0;
 $vertices = $vertices|0;
 $normals = $normals|0;
 $tangents = $tangents|0;
 $bufferStride = $bufferStride|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre55 = 0, $$pre56 = 0, $$pre57 = 0, $$sum = 0, $$sum38 = 0, $$sum39 = 0, $$sum40 = 0, $$sum42 = 0, $$sum43 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0;
 var $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0;
 var $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0);
 var $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0;
 var $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0);
 var $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $hasMotionConstraints$0$off047 = 0, $hasMotionConstraints$1$off0 = 0, $hasSeparationConstraints$044 = 0, $hasSeparationConstraints$1 = 0, $i$052 = 0, $i1$046 = 0, $i4$045 = 0, $storemerge = Math_fround(0), $storemerge41 = Math_fround(0), $targetPose = 0, $temp$0$i = 0;
 var $temp$0$i26 = 0, $temp$0$i8 = 0, $worldScaleLossy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy7 = sp + 80|0;
 $0 = sp + 72|0;
 $1 = sp + 68|0;
 $2 = sp + 64|0;
 $3 = sp + 60|0;
 $4 = sp + 56|0;
 $5 = sp + 52|0;
 $6 = sp + 36|0;
 $7 = sp + 32|0;
 $8 = sp + 28|0;
 $targetPose = sp;
 $worldScaleLossy = sp + 40|0;
 $9 = (($this) + 180|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($13,137)|0);
 $15 = (__ZN19SkinnedMeshRenderer7GetMeshEv($14)|0);
 $16 = (($this) + 188|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $$0$i = 0;
 } else {
  HEAP32[$8>>2] = $17;
  $19 = HEAP32[560624>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   label = 11;
  } else {
   $21 = (($19) + 36|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($19) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22|0)==($24|0);
   do {
    if ($25) {
     $26 = (($19) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($19) + 32|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + ($29<<3)|0);
     $46 = $30;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy7,$19,$8);
     $31 = HEAP32[$$byval_copy7>>2]|0;
     $32 = ($31|0)==(-1);
     $33 = (($19) + 28|0);
     $34 = HEAP32[$33>>2]|0;
     if ($32) {
      $35 = (($19) + 32|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($34) + ($36<<3)|0);
      $46 = $37;
      break;
     } else {
      $38 = (($34) + ($31<<3)|0);
      $46 = $38;
      break;
     }
    }
   } while(0);
   $39 = HEAP32[560624>>2]|0;
   $40 = (($39) + 28|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + 32|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + ($43<<3)|0);
   $45 = ($46|0)==($44|0);
   if ($45) {
    label = 11;
   } else {
    $47 = (($46) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     label = 11;
    } else {
     $temp$0$i = $48;
    }
   }
  }
  if ((label|0) == 11) {
   $50 = HEAP32[$16>>2]|0;
   $51 = (__Z31ReadObjectFromPersistentManageri($50)|0);
   $temp$0$i = $51;
  }
  $$0$i = $temp$0$i;
 }
 $52 = ($15|0)==($$0$i|0);
 if ($52) {
  $53 = HEAP32[$16>>2]|0;
  HEAP32[$7>>2] = $53;
  $54 = HEAP32[560624>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   label = 22;
  } else {
   $56 = (($54) + 36|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($54) + 4|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($57|0)==($59|0);
   do {
    if ($60) {
     $61 = (($54) + 28|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($54) + 32|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($62) + ($64<<3)|0);
     $81 = $65;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy7,$54,$7);
     $66 = HEAP32[$$byval_copy7>>2]|0;
     $67 = ($66|0)==(-1);
     $68 = (($54) + 28|0);
     $69 = HEAP32[$68>>2]|0;
     if ($67) {
      $70 = (($54) + 32|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = (($69) + ($71<<3)|0);
      $81 = $72;
      break;
     } else {
      $73 = (($69) + ($66<<3)|0);
      $81 = $73;
      break;
     }
    }
   } while(0);
   $74 = HEAP32[560624>>2]|0;
   $75 = (($74) + 28|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = (($74) + 32|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (($76) + ($78<<3)|0);
   $80 = ($81|0)==($79|0);
   if ($80) {
    label = 22;
   } else {
    $82 = (($81) + 4|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($83|0)==(0|0);
    if ($84) {
     label = 22;
    } else {
     $temp$0$i8 = $83;
    }
   }
  }
  if ((label|0) == 22) {
   $85 = HEAP32[$16>>2]|0;
   $86 = (__Z31ReadObjectFromPersistentManageri($85)|0);
   $temp$0$i8 = $86;
  }
  $87 = (($temp$0$i8) + 28|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 100|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($this) + 196|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = ($90|0)==($92|0);
  if (!($93)) {
   label = 24;
  }
 } else {
  label = 24;
 }
 if ((label|0) == 24) {
  __ZN5Unity5Cloth6CreateEv($this);
 }
 $94 = (__ZN19SkinnedMeshRenderer17GetActualRootBoneEv($14)|0);
 $95 = (($targetPose) + 16|0);
 __ZNK9Transform22GetPositionAndRotationER8Vector3fR11Quaternionf($94,$95,$targetPose);
 $96 = HEAP32[$9>>2]|0;
 $97 = HEAP32[$96>>2]|0;
 $98 = (($97) + 116|0);
 $99 = HEAP32[$98>>2]|0;
 FUNCTION_TABLE_vii[$99 & 4095]($96,$targetPose);
 $100 = (($this) + 294|0);
 $101 = HEAP8[$100>>0]|0;
 $102 = ($101<<24>>24)==(0);
 if ($102) {
  $103 = (__Z14IsWorldPlayingv()|0);
  if ($103) {
   $$pre57 = (($this) + 192|0);
   $$pre$phiZ2D = $$pre57;
  } else {
   label = 28;
  }
 } else {
  label = 28;
 }
 do {
  if ((label|0) == 28) {
   HEAP8[$100>>0] = 0;
   $104 = HEAP32[$9>>2]|0;
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + 96|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (FUNCTION_TABLE_ii[$107 & 4095]($104)|0);
   $109 = HEAP32[628512>>2]|0;
   $110 = (($108) + 4|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = (($this) + 192|0);
   $113 = HEAP32[$112>>2]|0;
   $$idx = $113 << 4;
   $114 = $$idx >> 4;
   $115 = ($114|0)==(0);
   if ($115) {
    $119 = 0;$170 = 0;
    label = 31;
   } else {
    HEAP32[$6>>2] = $109;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
    $116 = (invoke_iiiiiiii(108,(0|0),($$idx|0),4,($$byval_copy7|0),0,(688784|0),370)|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     $142 = $114;$143 = 0;
    } else {
     $119 = $116;$170 = $114;
     label = 31;
    }
   }
   if ((label|0) == 31) {
    _memcpy(($119|0),($111|0),($$idx|0))|0;
    $120 = (($this) + 196|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = ($121|0)==(0);
    if (!($122)) {
     $123 = (($this) + 200|0);
     $$pre56 = HEAP32[$123>>2]|0;
     $i$052 = 0;
     while(1) {
      $124 = (($$pre56) + ($i$052<<1)|0);
      $125 = HEAP16[$124>>1]|0;
      $126 = $125&65535;
      $127 = Math_imul($i$052, $bufferStride)|0;
      $128 = (($vertices) + ($127)|0);
      $129 = Math_fround(HEAPF32[$128>>2]);
      $$sum42 = (($127) + 4)|0;
      $130 = (($vertices) + ($$sum42)|0);
      $131 = Math_fround(HEAPF32[$130>>2]);
      $$sum43 = (($127) + 8)|0;
      $132 = (($vertices) + ($$sum43)|0);
      $133 = Math_fround(HEAPF32[$132>>2]);
      $134 = (($119) + ($126<<4)|0);
      HEAPF32[$134>>2] = $129;
      $135 = ((($119) + ($126<<4)|0) + 4|0);
      HEAPF32[$135>>2] = $131;
      $136 = ((($119) + ($126<<4)|0) + 8|0);
      HEAPF32[$136>>2] = $133;
      $137 = (($i$052) + 1)|0;
      $138 = ($137>>>0)<($121>>>0);
      if ($138) {
       $i$052 = $137;
      } else {
       break;
      }
     }
    }
    $146 = HEAP32[$108>>2]|0;
    $147 = (($146) + 4|0);
    $148 = HEAP32[$147>>2]|0;
    __THREW__ = 0;
    invoke_vi($148|0,($108|0));
    $149 = __THREW__; __THREW__ = 0;
    $150 = $149&1;
    if ($150) {
     $142 = $170;$143 = $119;
    } else {
     $151 = HEAP32[$9>>2]|0;
     $152 = HEAP32[$151>>2]|0;
     $153 = (($152) + 100|0);
     $154 = HEAP32[$153>>2]|0;
     __THREW__ = 0;
     invoke_viii($154|0,($151|0),($119|0),($119|0));
     $155 = __THREW__; __THREW__ = 0;
     $156 = $155&1;
     if ($156) {
      $142 = $170;$143 = $119;
     } else {
      $157 = HEAP32[$9>>2]|0;
      $158 = HEAP32[$157>>2]|0;
      $159 = (($158) + 120|0);
      $160 = HEAP32[$159>>2]|0;
      __THREW__ = 0;
      invoke_vii($160|0,($157|0),($targetPose|0));
      $161 = __THREW__; __THREW__ = 0;
      $162 = $161&1;
      if ($162) {
       $142 = $170;$143 = $119;
      } else {
       $163 = HEAP32[$9>>2]|0;
       $164 = HEAP32[$163>>2]|0;
       $165 = (($164) + 256|0);
       $166 = HEAP32[$165>>2]|0;
       __THREW__ = 0;
       invoke_vi($166|0,($163|0));
       $167 = __THREW__; __THREW__ = 0;
       $168 = $167&1;
       if ($168) {
        $142 = $170;$143 = $119;
       } else {
        $169 = ($170|0)>(-1);
        if (!($169)) {
         $$pre$phiZ2D = $112;
         break;
        }
        HEAP32[$0>>2] = $109;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
        __Z19free_alloc_internalPv10MemLabelId($119,$$byval_copy7);
        $$pre$phiZ2D = $112;
        break;
       }
      }
     }
    }
   }
   $139 = ___cxa_find_matching_catch()|0;
   $140 = tempRet0;
   $141 = ($142|0)>(-1);
   if (!($141)) {
    $$0 = $139;$$01 = $140;
    ___resumeException($$0|0);
    // unreachable;
   }
   HEAP32[$5>>2] = $109;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($143|0),($$byval_copy7|0));
   $144 = __THREW__; __THREW__ = 0;
   $145 = $144&1;
   if ($145) {
    $388 = ___cxa_find_matching_catch(0|0)|0;
    $389 = tempRet0;
    ___clang_call_terminate($388);
    // unreachable;
   } else {
    $$0 = $139;$$01 = $140;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $171 = (__ZN19SkinnedMeshRenderer17GetActualRootBoneEv($14)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($worldScaleLossy,$171);
 $172 = Math_fround(HEAPF32[$worldScaleLossy>>2]);
 $173 = (($worldScaleLossy) + 4|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = Math_fround($172 + $174);
 $176 = (($worldScaleLossy) + 8|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = Math_fround($175 + $177);
 $179 = Math_fround($178 / Math_fround(3.0));
 $180 = HEAP32[628512>>2]|0;
 $181 = HEAP32[$$pre$phiZ2D>>2]|0;
 $182 = ($181|0)==(0);
 if ($182) {
  $203 = 0;$294 = 0;
  label = 45;
 } else {
  $183 = $181 << 4;
  HEAP32[$4>>2] = $180;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
  $184 = (invoke_iiiiiiii(108,(0|0),($183|0),4,($$byval_copy7|0),0,(688784|0),370)|0);
  $185 = __THREW__; __THREW__ = 0;
  $186 = $185&1;
  if ($186) {
   $214 = $181;$215 = 0;
  } else {
   $203 = $184;$294 = $181;
   label = 45;
  }
 }
 L69: do {
  if ((label|0) == 45) {
   $187 = (($this) + 196|0);
   $188 = HEAP32[$187>>2]|0;
   $189 = ($188|0)==(0);
   if ($189) {
    label = 53;
   } else {
    $190 = (($this) + 200|0);
    $191 = (($this) + 100|0);
    $$pre = HEAP32[$190>>2]|0;
    $$pre55 = HEAP32[$191>>2]|0;
    $hasMotionConstraints$0$off047 = 0;$i1$046 = 0;
    while(1) {
     $192 = (($$pre) + ($i1$046<<1)|0);
     $193 = HEAP16[$192>>1]|0;
     $194 = $193&65535;
     $195 = Math_imul($i1$046, $bufferStride)|0;
     $196 = (($vertices) + ($195)|0);
     $197 = Math_fround(HEAPF32[$196>>2]);
     $$sum39 = (($195) + 4)|0;
     $198 = (($vertices) + ($$sum39)|0);
     $199 = Math_fround(HEAPF32[$198>>2]);
     $$sum40 = (($195) + 8)|0;
     $200 = (($vertices) + ($$sum40)|0);
     $201 = Math_fround(HEAPF32[$200>>2]);
     $202 = (($203) + ($194<<4)|0);
     HEAPF32[$202>>2] = $197;
     $204 = ((($203) + ($194<<4)|0) + 4|0);
     HEAPF32[$204>>2] = $199;
     $205 = ((($203) + ($194<<4)|0) + 8|0);
     HEAPF32[$205>>2] = $201;
     $206 = (($$pre55) + ($194<<3)|0);
     $207 = Math_fround(HEAPF32[$206>>2]);
     $208 = ((($203) + ($194<<4)|0) + 12|0);
     $209 = $207 < Math_fround(3.40282346638528859812E+38);
     if ($209) {
      $210 = Math_fround($179 * $207);
      $hasMotionConstraints$1$off0 = 1;$storemerge41 = $210;
     } else {
      $hasMotionConstraints$1$off0 = $hasMotionConstraints$0$off047;$storemerge41 = $207;
     }
     HEAPF32[$208>>2] = $storemerge41;
     $218 = (($i1$046) + 1)|0;
     $219 = ($218>>>0)<($188>>>0);
     if ($219) {
      $hasMotionConstraints$0$off047 = $hasMotionConstraints$1$off0;$i1$046 = $218;
     } else {
      break;
     }
    }
    if ($hasMotionConstraints$1$off0) {
     label = 54;
    } else {
     label = 53;
    }
   }
   if ((label|0) == 53) {
    $220 = (($this) + 276|0);
    $221 = Math_fround(HEAPF32[$220>>2]);
    $222 = $221 != Math_fround(1.0);
    if ($222) {
     label = 54;
    } else {
     $229 = HEAP32[$9>>2]|0;
     $230 = HEAP32[$229>>2]|0;
     $231 = (($230) + 232|0);
     $232 = HEAP32[$231>>2]|0;
     __THREW__ = 0;
     $233 = (invoke_ii($232|0,($229|0))|0);
     $234 = __THREW__; __THREW__ = 0;
     $235 = $234&1;
     if ($235) {
      $214 = $294;$215 = $203;
      break;
     }
     $236 = ($233|0)==(0);
     if (!($236)) {
      $237 = HEAP32[$9>>2]|0;
      $238 = HEAP32[$237>>2]|0;
      $239 = (($238) + 224|0);
      $240 = HEAP32[$239>>2]|0;
      __THREW__ = 0;
      invoke_vii($240|0,($237|0),(0|0));
      $241 = __THREW__; __THREW__ = 0;
      $242 = $241&1;
      if ($242) {
       $214 = $294;$215 = $203;
       break;
      }
     }
    }
   }
   if ((label|0) == 54) {
    $223 = HEAP32[$9>>2]|0;
    $224 = HEAP32[$223>>2]|0;
    $225 = (($224) + 224|0);
    $226 = HEAP32[$225>>2]|0;
    __THREW__ = 0;
    invoke_vii($226|0,($223|0),($203|0));
    $227 = __THREW__; __THREW__ = 0;
    $228 = $227&1;
    if ($228) {
     $214 = $294;$215 = $203;
     break;
    }
   }
   $243 = ($normals|0)==(0|0);
   if ($243) {
    $390 = $203;$391 = $294;
    label = 81;
   } else {
    $244 = HEAP32[$16>>2]|0;
    HEAP32[$1>>2] = $244;
    $245 = HEAP32[560624>>2]|0;
    $246 = ($245|0)==(0|0);
    if ($246) {
     label = 67;
    } else {
     $247 = (($245) + 36|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = (($245) + 4|0);
     $250 = HEAP32[$249>>2]|0;
     $251 = ($248|0)==($250|0);
     do {
      if ($251) {
       $252 = (($245) + 28|0);
       $253 = HEAP32[$252>>2]|0;
       $254 = (($245) + 32|0);
       $255 = HEAP32[$254>>2]|0;
       $256 = (($253) + ($255<<3)|0);
       $272 = $256;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy7,$245,$1);
       $257 = HEAP32[$$byval_copy7>>2]|0;
       $258 = ($257|0)==(-1);
       $259 = (($245) + 28|0);
       $260 = HEAP32[$259>>2]|0;
       if ($258) {
        $261 = (($245) + 32|0);
        $262 = HEAP32[$261>>2]|0;
        $263 = (($260) + ($262<<3)|0);
        $272 = $263;
        break;
       } else {
        $264 = (($260) + ($257<<3)|0);
        $272 = $264;
        break;
       }
      }
     } while(0);
     $265 = HEAP32[560624>>2]|0;
     $266 = (($265) + 28|0);
     $267 = HEAP32[$266>>2]|0;
     $268 = (($265) + 32|0);
     $269 = HEAP32[$268>>2]|0;
     $270 = (($267) + ($269<<3)|0);
     $271 = ($272|0)==($270|0);
     if ($271) {
      label = 67;
     } else {
      $273 = (($272) + 4|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = ($274|0)==(0|0);
      if ($275) {
       label = 67;
      } else {
       $temp$0$i26 = $274;
      }
     }
    }
    if ((label|0) == 67) {
     $276 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     $277 = (invoke_ii(3215,($276|0))|0);
     $278 = __THREW__; __THREW__ = 0;
     $279 = $278&1;
     if ($279) {
      $214 = $294;$215 = $203;
      break;
     } else {
      $temp$0$i26 = $277;
     }
    }
    $280 = (($temp$0$i26) + 180|0);
    $281 = Math_fround(HEAPF32[$280>>2]);
    $282 = Math_fround($281 * $281);
    $283 = (($280) + 4|0);
    $284 = Math_fround(HEAPF32[$283>>2]);
    $285 = Math_fround($284 * $284);
    $286 = Math_fround($282 + $285);
    $287 = (($280) + 8|0);
    $288 = Math_fround(HEAPF32[$287>>2]);
    $289 = Math_fround($288 * $288);
    $290 = Math_fround($286 + $289);
    $291 = (Math_fround(Math_sqrt((Math_fround($290)))));
    $292 = HEAP32[$$pre$phiZ2D>>2]|0;
    $293 = $294 & 2147483647;
    $295 = ($293>>>0)<($292>>>0);
    do {
     if ($295) {
      $296 = ($294|0)>(-1);
      if ($296) {
       $297 = $292 << 4;
       HEAP32[$2>>2] = $180;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
       $298 = (invoke_iiiiiiii(108,($203|0),($297|0),4,($$byval_copy7|0),0,(688784|0),370)|0);
       $299 = __THREW__; __THREW__ = 0;
       $300 = $299&1;
       if ($300) {
        $214 = $292;$215 = $203;
        break L69;
       }
       $333 = $298;$392 = $292;
       break;
      } else {
       $301 = $292 << 4;
       HEAP32[$3>>2] = $180;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
       $302 = (invoke_iiiiiii(102,($301|0),4,($$byval_copy7|0),0,(688784|0),352)|0);
       $303 = __THREW__; __THREW__ = 0;
       $304 = $303&1;
       if ($304) {
        $214 = $294;$215 = $203;
        break L69;
       }
       _memcpy(($302|0),($203|0),($301|0))|0;
       $333 = $302;$392 = $292;
       break;
      }
     } else {
      $333 = $203;$392 = $294;
     }
    } while(0);
    $305 = HEAP32[$187>>2]|0;
    $306 = ($305|0)==(0);
    if ($306) {
     $390 = $333;$391 = $392;
     label = 81;
    } else {
     $307 = (($this) + 200|0);
     $308 = HEAP32[$307>>2]|0;
     $309 = (($this) + 100|0);
     $310 = HEAP32[$309>>2]|0;
     $hasSeparationConstraints$044 = 0;$i4$045 = 0;
     while(1) {
      $311 = (($308) + ($i4$045<<1)|0);
      $312 = HEAP16[$311>>1]|0;
      $313 = $312&65535;
      $314 = Math_imul($i4$045, $bufferStride)|0;
      $315 = (($normals) + ($314)|0);
      $316 = Math_fround(HEAPF32[$315>>2]);
      $$sum = (($314) + 4)|0;
      $317 = (($normals) + ($$sum)|0);
      $318 = Math_fround(HEAPF32[$317>>2]);
      $$sum38 = (($314) + 8)|0;
      $319 = (($normals) + ($$sum38)|0);
      $320 = Math_fround(HEAPF32[$319>>2]);
      $321 = (($310) + ($313<<3)|0);
      $322 = Math_fround(HEAPF32[$321>>2]);
      $323 = Math_fround($322 * Math_fround(2.0));
      $324 = $291 < $323;
      $325 = $324 ? $291 : $323;
      $326 = ((($310) + ($313<<3)|0) + 4|0);
      $327 = Math_fround(HEAPF32[$326>>2]);
      $328 = Math_fround($327 + $325);
      $329 = Math_fround($316 * $328);
      $330 = Math_fround($318 * $328);
      $331 = Math_fround($320 * $328);
      $332 = (($333) + ($313<<4)|0);
      $334 = Math_fround(HEAPF32[$332>>2]);
      $335 = Math_fround($334 - $329);
      HEAPF32[$332>>2] = $335;
      $336 = ((($333) + ($313<<4)|0) + 4|0);
      $337 = Math_fround(HEAPF32[$336>>2]);
      $338 = Math_fround($337 - $330);
      HEAPF32[$336>>2] = $338;
      $339 = ((($333) + ($313<<4)|0) + 8|0);
      $340 = Math_fround(HEAPF32[$339>>2]);
      $341 = Math_fround($340 - $331);
      HEAPF32[$339>>2] = $341;
      $342 = ((($333) + ($313<<4)|0) + 12|0);
      $343 = $328 < Math_fround(3.40282346638528859812E+38);
      if ($343) {
       $344 = Math_fround($179 * $325);
       $hasSeparationConstraints$1 = 1;$storemerge = $344;
      } else {
       $hasSeparationConstraints$1 = $hasSeparationConstraints$044;$storemerge = $325;
      }
      HEAPF32[$342>>2] = $storemerge;
      $345 = (($i4$045) + 1)|0;
      $346 = ($345>>>0)<($305>>>0);
      if ($346) {
       $hasSeparationConstraints$044 = $hasSeparationConstraints$1;$i4$045 = $345;
      } else {
       break;
      }
     }
     $347 = $hasSeparationConstraints$1 & 1;
     $348 = ($347<<24>>24)==(0);
     if ($348) {
      $390 = $333;$391 = $392;
      label = 81;
     } else {
      $349 = HEAP32[$9>>2]|0;
      $350 = HEAP32[$349>>2]|0;
      $351 = (($350) + 244|0);
      $352 = HEAP32[$351>>2]|0;
      __THREW__ = 0;
      invoke_vii($352|0,($349|0),($333|0));
      $353 = __THREW__; __THREW__ = 0;
      $354 = $353&1;
      if ($354) {
       $214 = $392;$215 = $333;
       break;
      } else {
       $386 = $392;$387 = $333;
      }
     }
    }
   }
   if ((label|0) == 81) {
    $355 = HEAP32[$9>>2]|0;
    $356 = HEAP32[$355>>2]|0;
    $357 = (($356) + 252|0);
    $358 = HEAP32[$357>>2]|0;
    __THREW__ = 0;
    $359 = (invoke_ii($358|0,($355|0))|0);
    $360 = __THREW__; __THREW__ = 0;
    $361 = $360&1;
    if ($361) {
     $214 = $391;$215 = $390;
     break;
    }
    $362 = ($359|0)==(0);
    if ($362) {
     $386 = $391;$387 = $390;
    } else {
     $363 = HEAP32[$9>>2]|0;
     $364 = HEAP32[$363>>2]|0;
     $365 = (($364) + 244|0);
     $366 = HEAP32[$365>>2]|0;
     __THREW__ = 0;
     invoke_vii($366|0,($363|0),(0|0));
     $367 = __THREW__; __THREW__ = 0;
     $368 = $367&1;
     if ($368) {
      $214 = $391;$215 = $390;
      break;
     } else {
      $386 = $391;$387 = $390;
     }
    }
   }
   $369 = (($this) + 264|0);
   HEAP32[$369>>2] = $vertices;
   $370 = (($this) + 268|0);
   HEAP32[$370>>2] = $normals;
   $371 = (($this) + 272|0);
   HEAP32[$371>>2] = $bufferStride;
   __THREW__ = 0;
   invoke_vi(3631,($this|0));
   $372 = __THREW__; __THREW__ = 0;
   $373 = $372&1;
   if ($373) {
    $214 = $386;$215 = $387;
   } else {
    $374 = (($this) + 172|0);
    $375 = HEAP32[$374>>2]|0;
    $376 = ($375|0)==(0);
    if (!($376)) {
     $377 = HEAP32[$9>>2]|0;
     $378 = HEAP32[$377>>2]|0;
     $379 = (($378) + 284|0);
     $380 = HEAP32[$379>>2]|0;
     $381 = (($this) + 164|0);
     $382 = HEAP32[$381>>2]|0;
     __THREW__ = 0;
     invoke_viii($380|0,($377|0),($382|0),($375|0));
     $383 = __THREW__; __THREW__ = 0;
     $384 = $383&1;
     if ($384) {
      $214 = $386;$215 = $387;
      break;
     }
    }
    $385 = ($386|0)>(-1);
    if (!($385)) {
     STACKTOP = sp;return;
    }
    HEAP32[$0>>2] = $180;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($387,$$byval_copy7);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $211 = ___cxa_find_matching_catch()|0;
 $212 = tempRet0;
 $213 = ($214|0)>(-1);
 if (!($213)) {
  $$0 = $211;$$01 = $212;
  ___resumeException($$0|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $180;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($215|0),($$byval_copy7|0));
 $216 = __THREW__; __THREW__ = 0;
 $217 = $216&1;
 if ($217) {
  $388 = ___cxa_find_matching_catch(0|0)|0;
  $389 = tempRet0;
  ___clang_call_terminate($388);
  // unreachable;
 } else {
  $$0 = $211;$$01 = $212;
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN5Unity5Cloth22ReadBackSkinnedBuffersEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$020 = 0, $i1$017 = 0, $i3$016 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 264|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 180|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + 96|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($6)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($11) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 276|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = $16 != Math_fround(1.0);
 do {
  if ($17) {
   $24 = HEAP32[$5>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   $26 = (($25) + 232|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (FUNCTION_TABLE_ii[$27 & 4095]($24)|0);
   $29 = ($28|0)==(0);
   if ($29) {
    label = 5;
   } else {
    $30 = HEAP32[628512>>2]|0;
    $31 = (($this) + 192|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0);
    if ($33) {
     $42 = 0;$97 = 0;
     label = 11;
    } else {
     $34 = $32 << 4;
     HEAP32[$1>>2] = $30;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     $35 = (invoke_iiiiiiii(108,(0|0),($34|0),4,($$byval_copy2|0),0,(688784|0),370)|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      $92 = $32;$93 = 0;
     } else {
      $42 = $35;$97 = $32;
      label = 11;
     }
    }
    if ((label|0) == 11) {
     $38 = HEAP32[$5>>2]|0;
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + 228|0);
     $41 = HEAP32[$40>>2]|0;
     __THREW__ = 0;
     (invoke_iii($41|0,($38|0),($42|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      $92 = $97;$93 = $42;
     } else {
      $45 = (($this) + 196|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(0);
      if (!($47)) {
       $48 = (($this) + 200|0);
       $49 = (($this) + 272|0);
       $50 = (($this) + 232|0);
       $i$020 = 0;
       while(1) {
        $51 = HEAP32[$48>>2]|0;
        $52 = (($51) + ($i$020<<1)|0);
        $53 = HEAP16[$52>>1]|0;
        $54 = HEAP32[$2>>2]|0;
        $55 = HEAP32[$49>>2]|0;
        $56 = Math_imul($55, $i$020)|0;
        $57 = (($54) + ($56)|0);
        $58 = $53&65535;
        $59 = HEAP32[$50>>2]|0;
        $60 = (($59) + (($58*12)|0)|0);
        $61 = (($42) + ($58<<4)|0);
        $62 = Math_fround(HEAPF32[$61>>2]);
        $63 = ((($42) + ($58<<4)|0) + 4|0);
        $64 = Math_fround(HEAPF32[$63>>2]);
        $65 = ((($42) + ($58<<4)|0) + 8|0);
        $66 = Math_fround(HEAPF32[$65>>2]);
        $67 = (($14) + ($58<<4)|0);
        $68 = Math_fround(HEAPF32[$67>>2]);
        $69 = ((($14) + ($58<<4)|0) + 4|0);
        $70 = Math_fround(HEAPF32[$69>>2]);
        $71 = ((($14) + ($58<<4)|0) + 8|0);
        $72 = Math_fround(HEAPF32[$71>>2]);
        $73 = Math_fround(HEAPF32[$15>>2]);
        $74 = Math_fround($68 * $73);
        $75 = Math_fround($70 * $73);
        $76 = Math_fround($72 * $73);
        $77 = Math_fround(Math_fround(1.0) - $73);
        $78 = Math_fround($62 * $77);
        $79 = Math_fround($64 * $77);
        $80 = Math_fround($66 * $77);
        $81 = Math_fround($74 + $78);
        $82 = Math_fround($75 + $79);
        $83 = Math_fround($76 + $80);
        HEAPF32[$60>>2] = $81;
        $84 = ((($59) + (($58*12)|0)|0) + 4|0);
        HEAPF32[$84>>2] = $82;
        $85 = ((($59) + (($58*12)|0)|0) + 8|0);
        HEAPF32[$85>>2] = $83;
        ;HEAP32[$57+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$60+8>>2]|0;
        $86 = (($i$020) + 1)|0;
        $87 = HEAP32[$45>>2]|0;
        $88 = ($86>>>0)<($87>>>0);
        if ($88) {
         $i$020 = $86;
        } else {
         break;
        }
       }
      }
      $96 = ($97|0)>(-1);
      if (!($96)) {
       break;
      }
      HEAP32[$0>>2] = $30;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($42,$$byval_copy2);
      break;
     }
    }
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    $91 = ($92|0)>(-1);
    if (!($91)) {
     ___resumeException($89|0);
     // unreachable;
    }
    HEAP32[$0>>2] = $30;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($93|0),($$byval_copy2|0));
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     $144 = ___cxa_find_matching_catch(0|0)|0;
     $145 = tempRet0;
     ___clang_call_terminate($144);
     // unreachable;
    } else {
     ___resumeException($89|0);
     // unreachable;
    }
   }
  } else {
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  $18 = (($this) + 196|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0);
  if (!($20)) {
   $21 = (($this) + 200|0);
   $22 = (($this) + 272|0);
   $23 = (($this) + 232|0);
   $i1$017 = 0;
   while(1) {
    $98 = HEAP32[$21>>2]|0;
    $99 = (($98) + ($i1$017<<1)|0);
    $100 = HEAP16[$99>>1]|0;
    $101 = HEAP32[$2>>2]|0;
    $102 = HEAP32[$22>>2]|0;
    $103 = Math_imul($102, $i1$017)|0;
    $104 = (($101) + ($103)|0);
    $105 = $100&65535;
    $106 = HEAP32[$23>>2]|0;
    $107 = (($106) + (($105*12)|0)|0);
    $108 = (($14) + ($105<<4)|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = ((($14) + ($105<<4)|0) + 4|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = ((($14) + ($105<<4)|0) + 8|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    HEAPF32[$107>>2] = $109;
    $114 = ((($106) + (($105*12)|0)|0) + 4|0);
    HEAPF32[$114>>2] = $111;
    $115 = ((($106) + (($105*12)|0)|0) + 8|0);
    HEAPF32[$115>>2] = $113;
    ;HEAP32[$104+0>>2]=HEAP32[$107+0>>2]|0;HEAP32[$104+4>>2]=HEAP32[$107+4>>2]|0;HEAP32[$104+8>>2]=HEAP32[$107+8>>2]|0;
    $116 = (($i1$017) + 1)|0;
    $117 = HEAP32[$18>>2]|0;
    $118 = ($116>>>0)<($117>>>0);
    if ($118) {
     $i1$017 = $116;
    } else {
     break;
    }
   }
  }
 }
 $119 = (($this) + 268|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($120|0)==(0|0);
 if (!($121)) {
  __ZN5Unity5Cloth13UpdateNormalsEv($this);
  $122 = (($this) + 196|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)==(0);
  if (!($124)) {
   $125 = (($this) + 200|0);
   $126 = (($this) + 272|0);
   $127 = (($this) + 248|0);
   $i3$016 = 0;
   while(1) {
    $128 = HEAP32[$125>>2]|0;
    $129 = (($128) + ($i3$016<<1)|0);
    $130 = HEAP16[$129>>1]|0;
    $131 = HEAP32[$119>>2]|0;
    $132 = HEAP32[$126>>2]|0;
    $133 = Math_imul($132, $i3$016)|0;
    $134 = (($131) + ($133)|0);
    $135 = $130&65535;
    $136 = HEAP32[$127>>2]|0;
    $137 = (($136) + (($135*12)|0)|0);
    ;HEAP32[$134+0>>2]=HEAP32[$137+0>>2]|0;HEAP32[$134+4>>2]=HEAP32[$137+4>>2]|0;HEAP32[$134+8>>2]=HEAP32[$137+8>>2]|0;
    $138 = (($i3$016) + 1)|0;
    $139 = HEAP32[$122>>2]|0;
    $140 = ($138>>>0)<($139>>>0);
    if ($140) {
     $i3$016 = $138;
    } else {
     break;
    }
   }
  }
 }
 $141 = HEAP32[$11>>2]|0;
 $142 = (($141) + 4|0);
 $143 = HEAP32[$142>>2]|0;
 FUNCTION_TABLE_vi[$143 & 4095]($11);
 STACKTOP = sp;return;
}
function __Z31SetShapeLocalPoseAndWakeUpActorPN5physx7PxShapeEPNS_12PxRigidActorERK10Matrix4x4f($shape,$actor,$matrix) {
 $shape = $shape|0;
 $actor = $actor|0;
 $matrix = $matrix|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0);
 var $9 = 0, $sRot$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $sRot$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 48|0;
 $2 = HEAP32[$shape>>2]|0;
 $3 = (($2) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 __Z18MatrixToQuaternionRK10Matrix4x4fR11Quaternionf($matrix,$sRot$i);
 $5 = (($matrix) + 48|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($matrix) + 52|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($matrix) + 56|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$sRot$i>>2]);
 $12 = (($sRot$i) + 4|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($sRot$i) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($sRot$i) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 HEAPF32[$0>>2] = $11;
 $18 = (($0) + 4|0);
 HEAPF32[$18>>2] = $13;
 $19 = (($0) + 8|0);
 HEAPF32[$19>>2] = $15;
 $20 = (($0) + 12|0);
 HEAPF32[$20>>2] = $17;
 $21 = (($0) + 16|0);
 HEAPF32[$21>>2] = $6;
 $22 = (($0) + 20|0);
 HEAPF32[$22>>2] = $8;
 $23 = (($0) + 24|0);
 HEAPF32[$23>>2] = $10;
 FUNCTION_TABLE_vii[$4 & 4095]($shape,$0);
 $24 = (($actor) + 4|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = ($25<<16>>16)==(5);
 if (!($26)) {
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$actor>>2]|0;
 $28 = (($27) + 28|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (FUNCTION_TABLE_ii[$29 & 4095]($actor)|0);
 $31 = ($30|0)==(0|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$actor>>2]|0;
 $33 = (($32) + 200|0);
 $34 = HEAP32[$33>>2]|0;
 FUNCTION_TABLE_vii[$34 & 4095]($1,$actor);
 $35 = HEAP8[$1>>0]|0;
 $36 = $35 & 1;
 $37 = ($36<<24>>24)==(0);
 if (!($37)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$actor>>2]|0;
 $39 = (($38) + 284|0);
 $40 = HEAP32[$39>>2]|0;
 FUNCTION_TABLE_vi[$40 & 4095]($actor);
 STACKTOP = sp;return;
}
function __ZN8ColliderC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((688920 + 8|0));
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 40|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 44|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 48|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 32|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 36|0);
 HEAP8[$7>>0] = 0;
 $8 = (($this) + 37|0);
 HEAP8[$8>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN8Collider15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN8Collider10SetEnabledEb($this,$enab) {
 $this = $this|0;
 $enab = $enab|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 37|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $enab&1;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $enab&1;
 HEAP8[$0>>0] = $5;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 144|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 4095]($this);
 $9 = HEAP32[$this>>2]|0;
 $10 = (($9) + 152|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$11 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN8Collider16RecreateColliderEPK9Rigidbody($this,$ignoreCollider) {
 $this = $this|0;
 $ignoreCollider = $ignoreCollider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZNK5Unity10GameObject8IsActiveEv($1)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 37|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 136|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($this,$ignoreCollider);
 STACKTOP = sp;return;
}
function __ZNK8Collider12GetRigidbodyEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN8Collider10DeactivateEN5Unity19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var $$neg2$i$i$i$i$i4$i = 0, $$sum$i$i$i$i = 0, $$sum$i$i$i$i$i3$i = 0, $$sum1$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i5$i = 0, $__len$03$i$i$i$i$i2$i = 0, $__new_last2$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 144|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 } else {
  $9 = $4;
 }
 while(1) {
  $8 = HEAP32[$9>>2]|0;
  $10 = (($8) + 40|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($8) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = $11;
  $16 = (($14) - ($15))|0;
  $17 = $16 >> 2;
  $18 = ($17|0)==(0);
  if ($18) {
   $28 = $11;
  } else {
   $21 = $11;$__len$03$i$i$i$i$i2$i = $17;
   while(1) {
    $19 = (($__len$03$i$i$i$i$i2$i|0) / 2)&-1;
    $20 = (($21) + ($19<<2)|0);
    $22 = HEAP32[$20>>2]|0;
    $23 = ($22>>>0)<($this>>>0);
    if ($23) {
     $$sum$i$i$i$i$i3$i = (($19) + 1)|0;
     $24 = (($21) + ($$sum$i$i$i$i$i3$i<<2)|0);
     $$neg2$i$i$i$i$i4$i = (($__len$03$i$i$i$i$i2$i) + -1)|0;
     $25 = (($$neg2$i$i$i$i$i4$i) - ($19))|0;
     $48 = $24;$__len$0$be$i$i$i$i$i5$i = $25;
    } else {
     $48 = $21;$__len$0$be$i$i$i$i$i5$i = $19;
    }
    $26 = ($__len$0$be$i$i$i$i$i5$i|0)==(0);
    if ($26) {
     $28 = $48;
     break;
    } else {
     $21 = $48;$__len$03$i$i$i$i$i2$i = $__len$0$be$i$i$i$i$i5$i;
    }
   }
  }
  $27 = ($28|0)==($13|0);
  if (!($27)) {
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29>>>0)>($this>>>0);
   if (!($30)) {
    $31 = $28;
    $32 = (($31) - ($15))|0;
    $33 = $32 >> 2;
    $34 = (($11) + ($33<<2)|0);
    $$sum$i$i$i$i = (($33) + 1)|0;
    $35 = (($11) + ($$sum$i$i$i$i<<2)|0);
    $36 = $35;
    $37 = (($14) - ($36))|0;
    $38 = $37 >> 2;
    _memmove(($34|0),($35|0),($37|0))|0;
    $$sum1$i$i$i$i = (($38) + ($33))|0;
    $39 = (($11) + ($$sum1$i$i$i$i<<2)|0);
    $40 = HEAP32[$12>>2]|0;
    $41 = ($40|0)==($39|0);
    if (!($41)) {
     $__new_last2$i$i$i$i$i$i = $39;
     $scevgep$i$i$i$i$i$i = (($40) + -4|0);
     $42 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($42)|0);
     $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
     $43 = $uglygep3$i$i$i$i$i$i >>> 2;
     $44 = $43 ^ -1;
     $scevgep4$i$i$i$i$i$i = (($40) + ($44<<2)|0);
     HEAP32[$12>>2] = $scevgep4$i$i$i$i$i$i;
    }
   }
  }
  $45 = (($9) + 4|0);
  $46 = HEAP32[$5>>2]|0;
  $47 = ($45|0)==($46|0);
  if ($47) {
   break;
  } else {
   $9 = $45;
  }
 }
 STACKTOP = sp;return;
}
function __ZN8Collider22CreatePhysXObjIfNeededEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($this) + 24|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (__ZNK5Unity10GameObject8IsActiveEv($4)|0);
   if ($6) {
    $7 = (($this) + 37|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if (!($9)) {
     $10 = HEAP32[$this>>2]|0;
     $11 = (($10) + 136|0);
     $12 = HEAP32[$11>>2]|0;
     FUNCTION_TABLE_vii[$12 & 4095]($this,0);
    }
   }
  }
 }
 STACKTOP = sp;return;
}
function __ZN8Collider13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (__ZNK5Unity10GameObject8IsActiveEv($2)|0);
  if ($4) {
   $5 = (($this) + 37|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if (!($7)) {
    $8 = (($this) + 32|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = HEAP32[$this>>2]|0;
     $12 = (($11) + 112|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (FUNCTION_TABLE_ii[$13 & 4095]($this)|0);
     if ($14) {
      $15 = (($this) + 28|0);
      $16 = HEAP32[$15>>2]|0;
      HEAP32[$0>>2] = $16;
      __ZN8Collider11SetMaterialE4PPtrI14PhysicMaterialE($this,$0);
     }
     $17 = HEAP32[$this>>2]|0;
     $18 = (($17) + 120|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($this) + 36|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)!=(0);
     FUNCTION_TABLE_vii[$19 & 4095]($this,$22);
    }
    $23 = HEAP32[$this>>2]|0;
    $24 = (($23) + 152|0);
    $25 = HEAP32[$24>>2]|0;
    FUNCTION_TABLE_vi[$25 & 4095]($this);
    $26 = HEAP32[$8>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     STACKTOP = sp;return;
    }
    $28 = HEAP32[$26>>2]|0;
    $29 = (($28) + 64|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (FUNCTION_TABLE_ii[$30 & 4095]($26)|0);
    $32 = (($31) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if ($34) {
     STACKTOP = sp;return;
    }
    __ZN9Rigidbody22UpdateMassDistributionEv($33);
    STACKTOP = sp;return;
   }
  }
 }
 $35 = HEAP32[$this>>2]|0;
 $36 = (($35) + 144|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vi[$37 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN8Collider11SetMaterialE4PPtrI14PhysicMaterialE($this,$material) {
 $this = $this|0;
 $material = $material|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $pMaterial = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $pMaterial = sp + 12|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 L1: do {
  if (!($5)) {
   $6 = (__ZNK6Object12GetClassNameEv($this)|0);
   __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($1,689288,$6);
   __THREW__ = 0;
   invoke_viii(1627,($0|0),($1|0),(689360|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   do {
    if ($8) {
     $32 = ___cxa_find_matching_catch()|0;
     $33 = tempRet0;
     $$0 = $33;$$01 = $32;
    } else {
     $9 = ($this|0)==(0|0);
     if ($9) {
      $19 = 0;
     } else {
      $10 = (($this) + 4|0);
      $11 = HEAP32[$10>>2]|0;
      $19 = $11;
     }
     $12 = HEAP8[$0>>0]|0;
     $13 = $12 & 1;
     $14 = ($13<<24>>24)==(0);
     if ($14) {
      $17 = (($0) + 1|0);
      $18 = $17;
     } else {
      $15 = (($0) + 8|0);
      $16 = HEAP32[$15>>2]|0;
      $18 = $16;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($18|0),0,(689184|0),606,1,($19|0),0,(0|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      $34 = ___cxa_find_matching_catch()|0;
      $35 = tempRet0;
      $36 = HEAP8[$0>>0]|0;
      $37 = $36 & 1;
      $38 = ($37<<24>>24)==(0);
      if ($38) {
       $$0 = $35;$$01 = $34;
       break;
      }
      $39 = (($0) + 8|0);
      $40 = HEAP32[$39>>2]|0;
      __ZdlPv($40);
      $$0 = $35;$$01 = $34;
      break;
     }
     $22 = HEAP8[$0>>0]|0;
     $23 = $22 & 1;
     $24 = ($23<<24>>24)==(0);
     if (!($24)) {
      $25 = (($0) + 8|0);
      $26 = HEAP32[$25>>2]|0;
      __ZdlPv($26);
     }
     $27 = HEAP8[$1>>0]|0;
     $28 = $27 & 1;
     $29 = ($28<<24>>24)==(0);
     if ($29) {
      break L1;
     }
     $30 = (($1) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __ZdlPv($31);
     break L1;
    }
   } while(0);
   $41 = HEAP8[$1>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $44 = (($1) + 8|0);
   $45 = HEAP32[$44>>2]|0;
   __ZdlPv($45);
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $46 = (($this) + 28|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$material>>2]|0;
 $49 = ($47|0)==($48|0);
 if (!($49)) {
  HEAP32[$46>>2] = $48;
 }
 $50 = (($this) + 32|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0|0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = (__ZN8Collider13GetPxMaterialEv($this)|0);
 HEAP32[$pMaterial>>2] = $53;
 $54 = ($53|0)==(0|0);
 if ($54) {
  STACKTOP = sp;return;
 }
 $55 = HEAP32[$50>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 96|0);
 $58 = HEAP32[$57>>2]|0;
 FUNCTION_TABLE_viii[$58 & 4095]($55,$pMaterial,1);
 STACKTOP = sp;return;
}
function __ZN8Collider32RigidbodyMassDistributionChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 __ZN9Rigidbody22UpdateMassDistributionEv($8);
 STACKTOP = sp;return;
}
function __ZN8Collider30GetRelativePositionAndRotationERK9TransformR10Matrix4x4f($this,$parent,$matrix) {
 $this = $this|0;
 $parent = $parent|0;
 $matrix = $matrix|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $childMatrix = 0, $parentMatrix = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $childMatrix = sp + 64|0;
 $parentMatrix = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($4)|0);
 FUNCTION_TABLE_viii[$2 & 4095]($this,$5,$childMatrix);
 __ZNK9Transform28GetWorldToLocalMatrixNoScaleEv($parentMatrix,$parent);
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($parentMatrix,$childMatrix,$matrix);
 $6 = HEAP32[$matrix>>2]|0;
 $7 = $6 & 2139095040;
 $8 = ($7|0)!=(2139095040);
 $9 = (($matrix) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2139095040;
 $12 = ($11|0)!=(2139095040);
 $13 = $8 & $12;
 $14 = (($matrix) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2139095040;
 $17 = ($16|0)!=(2139095040);
 $18 = $13 & $17;
 $19 = (($matrix) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 2139095040;
 $22 = ($21|0)!=(2139095040);
 $23 = $18 & $22;
 $24 = (($matrix) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = $25 & 2139095040;
 $27 = ($26|0)!=(2139095040);
 $28 = $23 & $27;
 $29 = (($matrix) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 2139095040;
 $32 = ($31|0)!=(2139095040);
 $33 = $28 & $32;
 $34 = (($matrix) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35 & 2139095040;
 $37 = ($36|0)!=(2139095040);
 $38 = $33 & $37;
 $39 = (($matrix) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = $40 & 2139095040;
 $42 = ($41|0)!=(2139095040);
 $43 = $38 & $42;
 $44 = (($matrix) + 40|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45 & 2139095040;
 $47 = ($46|0)!=(2139095040);
 $48 = $43 & $47;
 $49 = (($matrix) + 48|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 2139095040;
 $52 = ($51|0)!=(2139095040);
 $53 = $48 & $52;
 $54 = (($matrix) + 52|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = $55 & 2139095040;
 $57 = ($56|0)!=(2139095040);
 $58 = $53 & $57;
 $59 = (($matrix) + 56|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $60 & 2139095040;
 $62 = ($61|0)!=(2139095040);
 $63 = $58 & $62;
 $64 = (($matrix) + 60|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = $65 & 2139095040;
 $67 = ($66|0)!=(2139095040);
 $68 = $63 & $67;
 if ($68) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $69 = (($this) + 4|0);
 $70 = HEAP32[$69>>2]|0;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(689096,0,689184,149,1,$70,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN8Collider22GetPositionAndRotationERK9TransformR10Matrix4x4f($this,$transform,$matrix) {
 $this = $this|0;
 $transform = $transform|0;
 $matrix = $matrix|0;
 var $childPosition = 0, $childRotation = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $childPosition = sp + 16|0;
 $childRotation = sp;
 __ZNK9Transform11GetPositionEv($childPosition,$transform);
 __ZNK9Transform11GetRotationEv($childRotation,$transform);
 __ZN10Matrix4x4f5SetTRERK8Vector3fRK11Quaternionf($matrix,$childPosition,$childRotation);
 STACKTOP = sp;return;
}
function __ZN8Collider22FetchPoseFromTransformEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $pos = 0, $rot = 0, $sPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $rot = sp + 40|0;
 $pos = sp;
 $sPose = sp + 12|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($1)|0);
 HEAPF32[$pos>>2] = Math_fround(0.0);
 $3 = (($pos) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($pos) + 8|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 __ZNK9Transform22GetPositionAndRotationER8Vector3fR11Quaternionf($2,$pos,$rot);
 $5 = Math_fround(HEAPF32[$rot>>2]);
 HEAPF32[$sPose>>2] = $5;
 $6 = (($sPose) + 4|0);
 $7 = (($rot) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$6>>2] = $8;
 $9 = (($sPose) + 8|0);
 $10 = (($rot) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$9>>2] = $11;
 $12 = (($sPose) + 12|0);
 $13 = (($rot) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$12>>2] = $14;
 $15 = (($sPose) + 16|0);
 $16 = Math_fround(HEAPF32[$pos>>2]);
 HEAPF32[$15>>2] = $16;
 $17 = (($sPose) + 20|0);
 $18 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$17>>2] = $18;
 $19 = (($sPose) + 24|0);
 $20 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$19>>2] = $20;
 $21 = (($this) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 64|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_ii[$25 & 4095]($22)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 88|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_viii[$29 & 4095]($26,$sPose,1);
 STACKTOP = sp;return;
}
function __ZN8Collider14WordsToPointerEjj($word1,$word2) {
 $word1 = $word1|0;
 $word2 = $word2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $word1;
 STACKTOP = sp;return ($0|0);
}
function __ZN8Collider19CreateShapeInternalERN5physx10PxGeometryEPNS0_12PxRigidActorEib($this,$geom,$actor,$bodyCollisionDetectionMode,$disableCollisions) {
 $this = $this|0;
 $geom = $geom|0;
 $actor = $actor|0;
 $bodyCollisionDetectionMode = $bodyCollisionDetectionMode|0;
 $disableCollisions = $disableCollisions|0;
 var $$13 = 0, $$not = 0, $$not2 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $or$cond = 0, $pMaterial = 0, $phitmp = 0, $phitmp14 = 0, $pos$i$i$i$i = 0, $qryFilterData = 0, $shapeFlags = 0, $simFilterData = 0, $storemerge = 0;
 var $storemerge$i = 0, $storemerge1 = 0, $temp$0$i16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i$i = sp + 40|0;
 $0 = sp;
 $pMaterial = sp + 4|0;
 $1 = sp + 58|0;
 $shapeFlags = sp + 59|0;
 $simFilterData = sp + 24|0;
 $qryFilterData = sp + 8|0;
 $2 = sp + 57|0;
 $3 = sp + 56|0;
 HEAP32[$pMaterial>>2] = 0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   label = 12;
  } else {
   HEAP32[$0>>2] = $5;
   $7 = HEAP32[560624>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    label = 10;
   } else {
    $9 = (($7) + 36|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($7) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    do {
     if ($13) {
      $14 = (($7) + 28|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($7) + 32|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($15) + ($17<<3)|0);
      $34 = $18;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$7,$0);
      $19 = HEAP32[$pos$i$i$i$i>>2]|0;
      $20 = ($19|0)==(-1);
      $21 = (($7) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      if ($20) {
       $23 = (($7) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $34 = $25;
       break;
      } else {
       $26 = (($22) + ($19<<3)|0);
       $34 = $26;
       break;
      }
     }
    } while(0);
    $27 = HEAP32[560624>>2]|0;
    $28 = (($27) + 28|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + ($31<<3)|0);
    $33 = ($34|0)==($32|0);
    if ($33) {
     label = 10;
    } else {
     $35 = (($34) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      label = 10;
     } else {
      $temp$0$i16 = $36;
     }
    }
   }
   if ((label|0) == 10) {
    $38 = (__Z31ReadObjectFromPersistentManageri($5)|0);
    $39 = ($38|0)==(0|0);
    if ($39) {
     label = 12;
     break;
    } else {
     $temp$0$i16 = $38;
    }
   }
   $40 = (($temp$0$i16) + 68|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$pMaterial>>2] = $41;
  }
 } while(0);
 if ((label|0) == 12) {
  $42 = (__Z14GetDynamicsSDKv()|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 152|0);
  $45 = HEAP32[$44>>2]|0;
  (FUNCTION_TABLE_iiiii[$45 & 511]($42,$pMaterial,1,0)|0);
 }
 $46 = (__Z14GetDynamicsSDKv()|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (FUNCTION_TABLE_ii[$49 & 4095]($46)|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vii[$53 & 4095]($50,-1);
 $54 = HEAP32[$actor>>2]|0;
 $55 = (($54) + 92|0);
 $56 = HEAP32[$55>>2]|0;
 HEAP8[$1>>0] = 11;
 $57 = (FUNCTION_TABLE_iiiiii[$56 & 255]($actor,$geom,$pMaterial,1,$1)|0);
 $58 = (($this) + 32|0);
 HEAP32[$58>>2] = $57;
 $59 = (($57) + 8|0);
 HEAP32[$59>>2] = $this;
 $60 = HEAP32[$58>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = (($61) + 136|0);
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_vii[$63 & 4095]($shapeFlags,$60);
 ;HEAP32[$simFilterData+0>>2]=0|0;HEAP32[$simFilterData+4>>2]=0|0;HEAP32[$simFilterData+8>>2]=0|0;HEAP32[$simFilterData+12>>2]=0|0;
 ;HEAP32[$qryFilterData+0>>2]=0|0;HEAP32[$qryFilterData+4>>2]=0|0;HEAP32[$qryFilterData+8>>2]=0|0;HEAP32[$qryFilterData+12>>2]=0|0;
 $64 = (($this) + 36|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = ($65<<24>>24)==(0);
 if ($66) {
  $72 = (($actor) + 4|0);
  $73 = HEAP16[$72>>1]|0;
  $74 = ($73<<16>>16)!=(5);
  $75 = ($actor|0)==(0|0);
  $or$cond = $74 | $75;
  if ($or$cond) {
   label = 18;
  } else {
   $76 = HEAP32[$geom>>2]|0;
   $$off = (($76) + -5)|0;
   $77 = HEAP32[$actor>>2]|0;
   $78 = (($77) + 200|0);
   $79 = HEAP32[$78>>2]|0;
   FUNCTION_TABLE_vii[$79 & 4095]($2,$actor);
   $80 = HEAP8[$2>>0]|0;
   $81 = $80 & 1;
   $$not = ($$off>>>0)>(1);
   $$not2 = ($81<<24>>24)!=(0);
   $brmerge = $$not | $$not2;
   if ($brmerge) {
    label = 18;
   } else {
    $82 = HEAP8[$shapeFlags>>0]|0;
    $83 = $82 & -2;
    HEAP8[$shapeFlags>>0] = $83;
    $89 = $83;
   }
  }
  if ((label|0) == 18) {
   $84 = HEAP8[$shapeFlags>>0]|0;
   $85 = $84&255;
   $86 = $85 | 1;
   $87 = $86&255;
   HEAP8[$shapeFlags>>0] = $87;
   $89 = $87;
  }
  $88 = $89&255;
  $90 = $88 | 2;
  $91 = $90&255;
  $92 = $91 & -5;
  HEAP8[$shapeFlags>>0] = $92;
 } else {
  $67 = HEAP8[$shapeFlags>>0]|0;
  $68 = $67 & -8;
  $69 = $68&255;
  $70 = $69 | 6;
  $71 = $70&255;
  HEAP8[$shapeFlags>>0] = $71;
 }
 $93 = (($simFilterData) + 4|0);
 $94 = (($simFilterData) + 12|0);
 $95 = $this;
 HEAP32[$93>>2] = $95;
 HEAP32[$94>>2] = 0;
 if ((($bodyCollisionDetectionMode|0) == 0)) {
  $98 = (($simFilterData) + 8|0);
  HEAP32[$98>>2] = 0;
  $104 = 0;
 } else if ((($bodyCollisionDetectionMode|0) == 2)) {
  $97 = (($simFilterData) + 8|0);
  HEAP32[$97>>2] = 12;
  $104 = 12;
 } else if ((($bodyCollisionDetectionMode|0) == 1)) {
  $96 = (($simFilterData) + 8|0);
  HEAP32[$96>>2] = 4;
  $104 = 4;
 } else {
  $99 = (($simFilterData) + 8|0);
  HEAP32[$99>>2] = 0;
  $104 = 0;
 }
 $100 = (($actor) + 4|0);
 $101 = HEAP16[$100>>1]|0;
 $102 = ($101<<16>>16)==(5);
 if ($102) {
  $phitmp = ($actor|0)==(0|0);
  $phitmp14 = $phitmp ? 1 : 2;
  $105 = $phitmp14;
 } else {
  $105 = 1;
 }
 $103 = (($simFilterData) + 8|0);
 $storemerge = $104 | $105;
 $106 = $storemerge | 16;
 $storemerge1 = $disableCollisions ? $106 : $storemerge;
 HEAP32[$103>>2] = $storemerge1;
 $107 = (($actor) + 8|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (($this) + 24|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = (($110) + 52|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ($108|0)==(0|0);
 if ($113) {
  $119 = 0;
 } else {
  $114 = (($108) + 24|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($115) + 52|0);
  $117 = HEAP32[$116>>2]|0;
  $119 = $117;
 }
 $118 = $119 | $112;
 $120 = $118 & 1;
 $121 = ($120|0)==(0);
 if ($121) {
  $122 = $118 & 3;
  $123 = ($122|0)==(0);
  $$13 = $123 ? 0 : 136192;
  $127 = $$13;
 } else {
  $127 = 138240;
 }
 $124 = (($110) + 40|0);
 $125 = HEAP32[$124>>2]|0;
 $126 = $125 | $127;
 HEAP32[$simFilterData>>2] = $126;
 HEAP32[$qryFilterData>>2] = $126;
 $128 = (($qryFilterData) + 4|0);
 HEAP32[$128>>2] = $95;
 $129 = (($qryFilterData) + 12|0);
 HEAP32[$129>>2] = 0;
 $130 = HEAP32[$58>>2]|0;
 $131 = HEAP32[$130>>2]|0;
 $132 = (($131) + 76|0);
 $133 = HEAP32[$132>>2]|0;
 FUNCTION_TABLE_vii[$133 & 4095]($130,$simFilterData);
 $134 = HEAP32[$58>>2]|0;
 $135 = HEAP32[$134>>2]|0;
 $136 = (($135) + 88|0);
 $137 = HEAP32[$136>>2]|0;
 FUNCTION_TABLE_vii[$137 & 4095]($134,$qryFilterData);
 $138 = HEAP32[$58>>2]|0;
 $139 = HEAP32[$138>>2]|0;
 $140 = (($139) + 132|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = HEAP8[$shapeFlags>>0]|0;
 HEAP8[$3>>0] = $142;
 FUNCTION_TABLE_vii[$141 & 4095]($138,$3);
 $143 = HEAP32[$58>>2]|0;
 $144 = HEAP32[$143>>2]|0;
 $145 = (($144) + 120|0);
 $146 = HEAP32[$145>>2]|0;
 FUNCTION_TABLE_vif[$146 & 255]($143,Math_fround(0.0));
 $147 = HEAP32[$58>>2]|0;
 $148 = HEAP32[$147>>2]|0;
 $149 = (($148) + 112|0);
 $150 = HEAP32[$149>>2]|0;
 $151 = (__Z17GetPhysicsManagerv()|0);
 $152 = (Math_fround(__ZN14PhysicsManager27GetMinPenetrationForPenaltyEv($151)));
 FUNCTION_TABLE_vif[$150 & 255]($147,$152);
 $153 = HEAP32[$58>>2]|0;
 $154 = ($153|0)==(0|0);
 if ($154) {
  STACKTOP = sp;return;
 }
 $155 = HEAP32[$153>>2]|0;
 $156 = (($155) + 80|0);
 $157 = HEAP32[$156>>2]|0;
 FUNCTION_TABLE_vii[$157 & 4095]($pos$i$i$i$i,$153);
 $158 = (($pos$i$i$i$i) + 8|0);
 $159 = HEAP32[$158>>2]|0;
 $160 = $159 & -17;
 $161 = $159 | 16;
 $storemerge$i = $disableCollisions ? $161 : $160;
 HEAP32[$158>>2] = $storemerge$i;
 $162 = HEAP32[$58>>2]|0;
 $163 = HEAP32[$162>>2]|0;
 $164 = (($163) + 76|0);
 $165 = HEAP32[$164>>2]|0;
 FUNCTION_TABLE_vii[$165 & 4095]($162,$pos$i$i$i$i);
 STACKTOP = sp;return;
}
function __ZN8Collider11GetMaterialEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN8Collider19SetDisableCollisionEb($this,$disableCollision) {
 $this = $this|0;
 $disableCollision = $disableCollision|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $filterData = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $filterData = sp;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($filterData,$1);
 $6 = (($filterData) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & -17;
 $9 = $7 | 16;
 $storemerge = $disableCollision ? $9 : $8;
 HEAP32[$6>>2] = $storemerge;
 $10 = HEAP32[$0>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 76|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$13 & 4095]($10,$filterData);
 STACKTOP = sp;return;
}
function __ZN8Collider14FinalizeCreateERN5physx10PxGeometryEPK9Rigidbody($this,$geom,$dontAttachToRigidbody) {
 $this = $this|0;
 $geom = $geom|0;
 $dontAttachToRigidbody = $dontAttachToRigidbody|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $matrix = 0, $sRot$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $sRot$i = sp + 120|0;
 $matrix = sp;
 $0 = sp + 64|0;
 $1 = sp + 137|0;
 $2 = sp + 136|0;
 $3 = sp + 92|0;
 $4 = (__ZN8Collider24FindNewAttachedRigidbodyEPK9Rigidbody($this,$dontAttachToRigidbody)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $68 = (__Z14GetDynamicsSDKv()|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($69) + 104|0);
  $71 = HEAP32[$70>>2]|0;
  HEAPF32[$3>>2] = Math_fround(0.0);
  $72 = (($3) + 4|0);
  HEAPF32[$72>>2] = Math_fround(0.0);
  $73 = (($3) + 8|0);
  HEAPF32[$73>>2] = Math_fround(0.0);
  $74 = (($3) + 12|0);
  HEAPF32[$74>>2] = Math_fround(1.0);
  $75 = (($3) + 16|0);
  HEAPF32[$75>>2] = Math_fround(0.0);
  $76 = (($3) + 20|0);
  HEAPF32[$76>>2] = Math_fround(0.0);
  $77 = (($3) + 24|0);
  HEAPF32[$77>>2] = Math_fround(0.0);
  $78 = (FUNCTION_TABLE_iii[$71 & 4095]($68,$3)|0);
  $79 = ($78|0)==(0|0);
  if (!($79)) {
   $84 = (($78) + 8|0);
   HEAP32[$84>>2] = 0;
   __ZN8Collider19CreateShapeInternalERN5physx10PxGeometryEPNS0_12PxRigidActorEib($this,$geom,$78,0,0);
   $85 = HEAP32[$this>>2]|0;
   $86 = (($85) + 164|0);
   $87 = HEAP32[$86>>2]|0;
   FUNCTION_TABLE_vi[$87 & 4095]($this);
   $88 = (__Z16GetDynamicsScenev()|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (($89) + 44|0);
   $91 = HEAP32[$90>>2]|0;
   FUNCTION_TABLE_vii[$91 & 4095]($88,$78);
   $92 = HEAP32[$this>>2]|0;
   $93 = (($92) + 96|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($this) + 24|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = (($96) + 52|0);
   $98 = HEAP32[$97>>2]|0;
   FUNCTION_TABLE_vii[$94 & 4095]($this,$98);
   STACKTOP = sp;return;
  }
  $80 = ($this|0)==(0|0);
  if ($80) {
   $83 = 0;
  } else {
   $81 = (($this) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = $82;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(689192,0,689184,411,1,$83,0,0);
  STACKTOP = sp;return;
 }
 __ZN9Rigidbody6CreateEb($4,1);
 $6 = (($4) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = ($this|0)==(0|0);
  if ($9) {
   $12 = 0;
  } else {
   $10 = (($this) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $11;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(689192,0,689184,384,1,$12,0,0);
  STACKTOP = sp;return;
 }
 $13 = (($4) + 76|0);
 $14 = HEAP32[$13>>2]|0;
 $$off = (($14) + -1)|0;
 $15 = ($$off>>>0)<(2);
 $16 = HEAP32[$7>>2]|0;
 $17 = (($16) + 192|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_viii[$18 & 4095]($7,4,$15);
 $19 = HEAP32[$13>>2]|0;
 $20 = (__ZNK9Rigidbody19GetDetectCollisionsEv($4)|0);
 $21 = $20 ^ 1;
 __ZN8Collider19CreateShapeInternalERN5physx10PxGeometryEPNS0_12PxRigidActorEib($this,$geom,$7,$19,$21);
 $22 = (($4) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($23)|0);
 $25 = (__ZN8Collider30GetRelativePositionAndRotationERK9TransformR10Matrix4x4f($this,$24,$matrix)|0);
 if ($25) {
  $26 = (($this) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 68|0);
  $30 = HEAP32[$29>>2]|0;
  __Z18MatrixToQuaternionRK10Matrix4x4fR11Quaternionf($matrix,$sRot$i);
  $31 = (($matrix) + 48|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($matrix) + 52|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($matrix) + 56|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround(HEAPF32[$sRot$i>>2]);
  $38 = (($sRot$i) + 4|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = (($sRot$i) + 8|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = (($sRot$i) + 12|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  HEAPF32[$0>>2] = $37;
  $44 = (($0) + 4|0);
  HEAPF32[$44>>2] = $39;
  $45 = (($0) + 8|0);
  HEAPF32[$45>>2] = $41;
  $46 = (($0) + 12|0);
  HEAPF32[$46>>2] = $43;
  $47 = (($0) + 16|0);
  HEAPF32[$47>>2] = $32;
  $48 = (($0) + 20|0);
  HEAPF32[$48>>2] = $34;
  $49 = (($0) + 24|0);
  HEAPF32[$49>>2] = $36;
  FUNCTION_TABLE_vii[$30 & 4095]($27,$0);
 }
 $50 = (($4) + 69|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = ($51<<24>>24)==(0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = (($this) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 136|0);
 $57 = HEAP32[$56>>2]|0;
 FUNCTION_TABLE_vii[$57 & 4095]($1,$54);
 $58 = HEAP8[$1>>0]|0;
 $59 = $58 & 1;
 $60 = ($59<<24>>24)==(0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $61 = HEAP32[$7>>2]|0;
 $62 = (($61) + 200|0);
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_vii[$63 & 4095]($2,$7);
 $64 = HEAP8[$2>>0]|0;
 $65 = $64 & 1;
 $66 = ($65<<24>>24)==(0);
 if (!($66)) {
  STACKTOP = sp;return;
 }
 $67 = (Math_fround(__ZNK9Rigidbody7GetMassEv($4)));
 (__ZN5physx14PxRigidBodyExt23setMassAndUpdateInertiaERNS_11PxRigidBodyEfPKNS_6PxVec3Eb($7,$67,0,0)|0);
 STACKTOP = sp;return;
}
function __ZN8Collider24FindNewAttachedRigidbodyEPK9Rigidbody($this,$ignoreAttachRigidbody) {
 $this = $this|0;
 $ignoreAttachRigidbody = $ignoreAttachRigidbody|0;
 var $$0 = 0, $$not = 0, $$not1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond2 = 0, $parent$0 = 0, $parent$0$in = 0, $parent$0$in8 = 0, $parent$010 = 0, $parent$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($1,54)|0);
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = (__ZNK5Unity10GameObject8IsActiveEv($5)|0);
   $$not = $7 ^ 1;
   $8 = ($2|0)==($ignoreAttachRigidbody|0);
   $or$cond = $8 | $$not;
   if (!($or$cond)) {
    $$0 = $2;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $9 = HEAP32[$0>>2]|0;
 $10 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($9)|0);
 $parent$0$in8 = (($10) + 156|0);
 $parent$09 = HEAP32[$parent$0$in8>>2]|0;
 $11 = ($parent$09|0)==(0|0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $parent$010 = $parent$09;
 }
 while(1) {
  $12 = (($parent$010) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($13,54)|0);
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    $17 = (($15) + 24|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     $21 = (__ZNK5Unity10GameObject8IsActiveEv($18)|0);
     $$not1 = $21 ^ 1;
     $22 = ($15|0)==($ignoreAttachRigidbody|0);
     $or$cond2 = $22 | $$not1;
     if (!($or$cond2)) {
      $$0 = $15;
      label = 10;
      break;
     }
    }
   }
  }
  $parent$0$in = (($parent$010) + 156|0);
  $parent$0 = HEAP32[$parent$0$in>>2]|0;
  $20 = ($parent$0|0)==(0|0);
  if ($20) {
   $$0 = 0;
   label = 10;
   break;
  } else {
   $parent$010 = $parent$0;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN8Collider26SupportedMessagesDidChangeEi($this,$supported) {
 $this = $this|0;
 $supported = $supported|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $simFilterData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $simFilterData = sp;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = $supported & 1;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = $supported & 3;
  $13 = ($12|0)==(0);
  $$ = $13 ? 0 : 136192;
  $21 = $$;
 } else {
  $21 = 138240;
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 80|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($simFilterData,$14);
 $18 = HEAP32[$simFilterData>>2]|0;
 $19 = $18 & 255;
 $20 = $19 | $21;
 HEAP32[$simFilterData>>2] = $20;
 $22 = HEAP32[$0>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 76|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095]($22,$simFilterData);
 STACKTOP = sp;return;
}
function __ZN8Collider10SetupLayerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $qryFilterData = 0, $simFilterData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $simFilterData = sp + 16|0;
 $qryFilterData = sp;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 80|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($simFilterData,$1);
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($qryFilterData,$6);
 $10 = HEAP32[$simFilterData>>2]|0;
 $11 = $10 & -256;
 HEAP32[$simFilterData>>2] = $11;
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 | $11;
 HEAP32[$simFilterData>>2] = $16;
 $17 = (($simFilterData) + 4|0);
 $18 = (($simFilterData) + 12|0);
 $19 = $this;
 HEAP32[$17>>2] = $19;
 HEAP32[$18>>2] = 0;
 HEAP32[$qryFilterData>>2] = $16;
 $20 = (($qryFilterData) + 4|0);
 HEAP32[$20>>2] = $19;
 $21 = (($qryFilterData) + 12|0);
 HEAP32[$21>>2] = 0;
 $22 = HEAP32[$0>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 76|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095]($22,$simFilterData);
 $26 = HEAP32[$0>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 88|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$29 & 4095]($26,$qryFilterData);
 STACKTOP = sp;return;
}
function __ZN8Collider13GetPxMaterialEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $pos$i$i$i$i = 0, $temp$0$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i2 = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $temp$0$i2 = $36;
  }
 }
 $38 = (($temp$0$i2) + 68|0);
 $39 = HEAP32[$38>>2]|0;
 $$0 = $39;
 STACKTOP = sp;return ($$0|0);
}
function __ZN8Collider12SetIsTriggerEb($this,$trigger) {
 $this = $this|0;
 $trigger = $trigger|0;
 var $$$not = 0, $$not = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $flags = 0, $flags1 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $flags = sp + 4|0;
 $0 = sp;
 $flags1 = sp + 1|0;
 $1 = sp + 2|0;
 $2 = sp + 3|0;
 $3 = (($this) + 36|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = $trigger&1;
 $7 = ($5|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = $trigger&1;
 HEAP8[$3>>0] = $8;
 $9 = (($this) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + 136|0);
 $14 = HEAP32[$13>>2]|0;
 if ($trigger) {
  FUNCTION_TABLE_vii[$14 & 4095]($flags,$10);
  $15 = HEAP8[$flags>>0]|0;
  $16 = $15 & -8;
  $17 = $16&255;
  $18 = $17 | 6;
  $19 = $18&255;
  HEAP8[$flags>>0] = $19;
  $20 = HEAP32[$9>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 132|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP8[$0>>0] = $19;
  FUNCTION_TABLE_vii[$23 & 4095]($20,$0);
 } else {
  FUNCTION_TABLE_vii[$14 & 4095]($flags1,$10);
  $24 = HEAP32[$9>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 24|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (FUNCTION_TABLE_ii[$27 & 4095]($24)|0);
  $29 = HEAP32[$9>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 64|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
  $34 = (($33) + 4|0);
  $35 = HEAP16[$34>>1]|0;
  $36 = ($35<<16>>16)!=(5);
  $37 = ($33|0)==(0|0);
  $or$cond = $36 | $37;
  if ($or$cond) {
   label = 8;
  } else {
   $$off = (($28) + -5)|0;
   $38 = HEAP32[$33>>2]|0;
   $39 = (($38) + 200|0);
   $40 = HEAP32[$39>>2]|0;
   FUNCTION_TABLE_vii[$40 & 4095]($1,$33);
   $41 = HEAP8[$1>>0]|0;
   $42 = $41 & 1;
   $$$not = ($$off>>>0)>(1);
   $$not = ($42<<24>>24)!=(0);
   $brmerge = $$$not | $$not;
   if ($brmerge) {
    label = 8;
   } else {
    $43 = HEAP8[$flags1>>0]|0;
    $44 = $43 & -2;
    HEAP8[$flags1>>0] = $44;
    $50 = $44;
   }
  }
  if ((label|0) == 8) {
   $45 = HEAP8[$flags1>>0]|0;
   $46 = $45&255;
   $47 = $46 | 1;
   $48 = $47&255;
   HEAP8[$flags1>>0] = $48;
   $50 = $48;
  }
  $49 = $50&255;
  $51 = $49 | 2;
  $52 = $51&255;
  $53 = $52 & -5;
  HEAP8[$flags1>>0] = $53;
  $54 = HEAP32[$9>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + 132|0);
  $57 = HEAP32[$56>>2]|0;
  HEAP8[$2>>0] = $53;
  FUNCTION_TABLE_vii[$57 & 4095]($54,$2);
 }
 $58 = HEAP32[$9>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  STACKTOP = sp;return;
 }
 $60 = HEAP32[$58>>2]|0;
 $61 = (($60) + 64|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (FUNCTION_TABLE_ii[$62 & 4095]($58)|0);
 $64 = (($63) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)==(0|0);
 if ($66) {
  STACKTOP = sp;return;
 }
 __ZN9Rigidbody22UpdateMassDistributionEv($65);
 STACKTOP = sp;return;
}
function __ZN8Collider9GetBoundsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = (($this) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($5)|0);
  __ZNK9Transform11GetPositionEv($0,$6);
  $7 = (($agg$result) + 12|0);
  ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
  ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
  ;HEAP32[$7+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[616680+8>>2]|0;
  STACKTOP = sp;return;
 } else {
  __Z19getShapeWorldBoundsRKN5physx7PxShapeE($agg$result,$2);
  STACKTOP = sp;return;
 }
}
function __Z19getShapeWorldBoundsRKN5physx7PxShapeE($agg$result,$shape) {
 $agg$result = $agg$result|0;
 $shape = $shape|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0);
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0;
 var $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 128|0;
 $1 = sp;
 $2 = sp + 32|0;
 $3 = sp + 72|0;
 $tmp = sp + 104|0;
 $4 = HEAP32[$shape>>2]|0;
 $5 = (($4) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($shape)|0);
 $8 = HEAP32[$shape>>2]|0;
 $9 = (($8) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 4095]($2,$shape);
 $11 = HEAP32[$7>>2]|0;
 $12 = (($11) + 84|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$13 & 4095]($0,$7);
 $14 = HEAP32[$shape>>2]|0;
 $15 = (($14) + 72|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$16 & 4095]($1,$shape);
 $17 = (($1) + 16|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 * Math_fround(2.0));
 $20 = (($1) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($21 * Math_fround(2.0));
 $23 = (($1) + 24|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($24 * Math_fround(2.0));
 $26 = (($0) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 * $27);
 $29 = Math_fround($28 + Math_fround(-0.5));
 $30 = Math_fround(HEAPF32[$0>>2]);
 $31 = Math_fround($19 * $30);
 $32 = (($0) + 4|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($22 * $33);
 $35 = Math_fround($31 + $34);
 $36 = (($0) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($25 * $37);
 $39 = Math_fround($35 + $38);
 $40 = Math_fround($19 * $29);
 $41 = Math_fround($25 * $33);
 $42 = Math_fround($22 * $37);
 $43 = Math_fround($41 - $42);
 $44 = Math_fround($27 * $43);
 $45 = Math_fround($40 + $44);
 $46 = Math_fround($30 * $39);
 $47 = Math_fround($46 + $45);
 $48 = Math_fround($22 * $29);
 $49 = Math_fround($19 * $37);
 $50 = Math_fround($25 * $30);
 $51 = Math_fround($49 - $50);
 $52 = Math_fround($27 * $51);
 $53 = Math_fround($48 + $52);
 $54 = Math_fround($33 * $39);
 $55 = Math_fround($54 + $53);
 $56 = Math_fround($25 * $29);
 $57 = Math_fround($22 * $30);
 $58 = Math_fround($19 * $33);
 $59 = Math_fround($57 - $58);
 $60 = Math_fround($27 * $59);
 $61 = Math_fround($56 + $60);
 $62 = Math_fround($37 * $39);
 $63 = Math_fround($61 + $62);
 $64 = (($0) + 16|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 + $47);
 $67 = (($0) + 20|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = Math_fround($68 + $55);
 $70 = (($0) + 24|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 + $63);
 $73 = Math_fround(HEAPF32[$1>>2]);
 $74 = Math_fround($27 * $73);
 $75 = (($1) + 12|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($30 * $76);
 $78 = Math_fround($74 + $77);
 $79 = (($1) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($33 * $80);
 $82 = Math_fround($78 + $81);
 $83 = (($1) + 4|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($37 * $84);
 $86 = Math_fround($82 - $85);
 $87 = Math_fround($27 * $84);
 $88 = Math_fround($33 * $76);
 $89 = Math_fround($88 + $87);
 $90 = Math_fround($37 * $73);
 $91 = Math_fround($90 + $89);
 $92 = Math_fround($30 * $80);
 $93 = Math_fround($91 - $92);
 $94 = Math_fround($27 * $80);
 $95 = Math_fround($37 * $76);
 $96 = Math_fround($95 + $94);
 $97 = Math_fround($30 * $84);
 $98 = Math_fround($97 + $96);
 $99 = Math_fround($33 * $73);
 $100 = Math_fround($98 - $99);
 $101 = Math_fround($27 * $76);
 $102 = Math_fround($30 * $73);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($33 * $84);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($37 * $80);
 $107 = Math_fround($105 - $106);
 HEAPF32[$3>>2] = $86;
 $108 = (($3) + 4|0);
 HEAPF32[$108>>2] = $93;
 $109 = (($3) + 8|0);
 HEAPF32[$109>>2] = $100;
 $110 = (($3) + 12|0);
 HEAPF32[$110>>2] = $107;
 $111 = (($3) + 16|0);
 HEAPF32[$111>>2] = $66;
 $112 = (($3) + 20|0);
 HEAPF32[$112>>2] = $69;
 $113 = (($3) + 24|0);
 HEAPF32[$113>>2] = $72;
 __ZN5physx15PxGeometryQuery14getWorldBoundsERKNS_10PxGeometryERKNS_11PxTransformEf($tmp,$2,$3,Math_fround(1.00999999046325683594));
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 $114 = (($tmp) + 12|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround(HEAPF32[$tmp>>2]);
 $117 = Math_fround($115 - $116);
 $118 = (($tmp) + 16|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($tmp) + 4|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = Math_fround($119 - $121);
 $123 = (($tmp) + 20|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($tmp) + 8|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = Math_fround($124 - $126);
 $128 = Math_fround($117 * Math_fround(0.5));
 $129 = Math_fround($122 * Math_fround(0.5));
 $130 = Math_fround($127 * Math_fround(0.5));
 $131 = Math_fround($115 + $116);
 $132 = Math_fround($119 + $121);
 $133 = Math_fround($124 + $126);
 $134 = Math_fround($131 * Math_fround(0.5));
 $135 = Math_fround($132 * Math_fround(0.5));
 $136 = Math_fround($133 * Math_fround(0.5));
 $137 = (($agg$result) + 12|0);
 HEAPF32[$137>>2] = $128;
 $138 = (($agg$result) + 16|0);
 HEAPF32[$138>>2] = $129;
 $139 = (($agg$result) + 20|0);
 HEAPF32[$139>>2] = $130;
 HEAPF32[$agg$result>>2] = $134;
 $140 = (($agg$result) + 4|0);
 HEAPF32[$140>>2] = $135;
 $141 = (($agg$result) + 8|0);
 HEAPF32[$141>>2] = $136;
 STACKTOP = sp;return;
}
function __ZN8Collider7CleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $14 = HEAP32[$6>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$15 & 4095]($6);
 } else {
  $10 = HEAP32[$6>>2]|0;
  $11 = (($10) + 100|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$0>>2]|0;
  FUNCTION_TABLE_viii[$12 & 4095]($6,$13,1);
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN8Collider8ReCreateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 144|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($this);
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 136|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095]($this,0);
 STACKTOP = sp;return;
}
function __ZN8Collider16TransformChangedEi($this,$changeMask) {
 $this = $this|0;
 $changeMask = $changeMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = $changeMask & 32;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 64|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($1)|0);
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__ZN8Collider24FindNewAttachedRigidbodyEPK9Rigidbody($this,0)|0);
 $12 = ($11|0)==($10|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 148|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vi[$15 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZNK8Collider21ShouldIgnoreCollisionEPS_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $not$$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3;
 $5 = $1;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7|0)==(0);
 if ($8) {
  $18 = $1;
 } else {
  $11 = $1;$__len$03$i$i$i$i$i = $7;
  while(1) {
   $9 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $10 = (($11) + ($9<<2)|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12>>>0)<($other>>>0);
   if ($13) {
    $$sum$i$i$i$i$i = (($9) + 1)|0;
    $14 = (($11) + ($$sum$i$i$i$i$i<<2)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $15 = (($$neg2$i$i$i$i$i) - ($9))|0;
    $21 = $14;$__len$0$be$i$i$i$i$i = $15;
   } else {
    $21 = $11;$__len$0$be$i$i$i$i$i = $9;
   }
   $16 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($16) {
    $18 = $21;
    break;
   } else {
    $11 = $21;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $17 = ($18|0)==($3|0);
 if ($17) {
  $20 = 0;
  STACKTOP = sp;return ($20|0);
 }
 $19 = HEAP32[$18>>2]|0;
 $not$$i$i = ($19>>>0)<=($other>>>0);
 $20 = $not$$i$i;
 STACKTOP = sp;return ($20|0);
}
function __ZN8Collider15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(56,564552,1973,0);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(56,565120,1974,0);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(56,564104,1975,100000);
 STACKTOP = sp;return;
}
function __ZZN8Collider15InitializeClassEvEN34FunctorImpl_Collider_kLayerChanged4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $qryFilterData$i = 0, $simFilterData$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $simFilterData$i = sp + 16|0;
 $qryFilterData$i = sp;
 $2 = (($object) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = (($5) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($simFilterData$i,$3);
 $8 = HEAP32[$2>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 92|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095]($qryFilterData$i,$8);
 $12 = HEAP32[$simFilterData$i>>2]|0;
 $13 = $12 & -256;
 HEAP32[$simFilterData$i>>2] = $13;
 $14 = (($object) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 40|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 | $13;
 HEAP32[$simFilterData$i>>2] = $18;
 $19 = (($simFilterData$i) + 4|0);
 $20 = (($simFilterData$i) + 12|0);
 $21 = $object;
 HEAP32[$19>>2] = $21;
 HEAP32[$20>>2] = 0;
 HEAP32[$qryFilterData$i>>2] = $18;
 $22 = (($qryFilterData$i) + 4|0);
 HEAP32[$22>>2] = $21;
 $23 = (($qryFilterData$i) + 12|0);
 HEAP32[$23>>2] = 0;
 $24 = HEAP32[$2>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 76|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vii[$27 & 4095]($24,$simFilterData$i);
 $28 = HEAP32[$2>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 88|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095]($28,$qryFilterData$i);
 STACKTOP = sp;return;
}
function __ZZN8Collider15InitializeClassEvEN43FunctorImpl_Collider_kForceRecreateCollider4CallE_0PviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($object) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (__ZNK5Unity10GameObject8IsActiveEv($3)|0);
  if ($5) {
   $6 = (($object) + 37|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if (!($8)) {
    $9 = HEAP32[$object>>2]|0;
    $10 = (($9) + 136|0);
    $11 = HEAP32[$10>>2]|0;
    FUNCTION_TABLE_vii[$11 & 4095]($object,0);
   }
  }
 }
 STACKTOP = sp;return;
}
function __ZZN8Collider15InitializeClassEvEN38FunctorImpl_Collider_kTransformChanged4CallE_1PviR11MessageData($object,$messageID,$messageData) {
 $object = $object|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($messageData) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$object>>2]|0;
 $3 = (($2) + 160|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($object,$1);
 STACKTOP = sp;return;
}
function __Z22RegisterClass_Colliderv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(56,193,194,0,195);
 STACKTOP = sp;return;
}
function __ZN8Collider13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(2)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity9Component13RegisterClassEv();
 }
 HEAP8[$0>>0] = 16;
 $3 = (($0) + 1|0);
 $4 = $3;
 $5 = $4;
 HEAP8[$5>>0]=1819045699&255;HEAP8[$5+1>>0]=(1819045699>>8)&255;HEAP8[$5+2>>0]=(1819045699>>16)&255;HEAP8[$5+3>>0]=1819045699>>24;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP8[$7>>0]=1919247465&255;HEAP8[$7+1>>0]=(1919247465>>8)&255;HEAP8[$7+2>>0]=(1919247465>>16)&255;HEAP8[$7+3>>0]=1919247465>>24;
 $8 = (($0) + 9|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,56,2,($0|0),52,(2553|0),1,0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return;
 }
}
function __ZN8Collider12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN8Collider7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK8Collider25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 56;
}
function __ZN8Collider23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,689384,689368,$this,0);
 __ZN8Collider8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Collider23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,689384,689368,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN8Collider8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Collider23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Collider23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Collider23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Collider23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  $16 = HEAP32[$this>>2]|0;
  $17 = (($16) + 116|0);
  $18 = HEAP32[$17>>2]|0;
  (FUNCTION_TABLE_ii[$18 & 4095]($this)|0);
  STACKTOP = sp;return;
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiii[$9 & 2047]($7,$5,$11)|0);
 $13 = (($transfer) + 32|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  HEAP32[$4>>2] = $12;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 $16 = HEAP32[$this>>2]|0;
 $17 = (($16) + 116|0);
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_ii[$18 & 4095]($this)|0);
 STACKTOP = sp;return;
}
function __ZN8Collider8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phi3Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if ($3) {
  $4 = (($this) + 28|0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,689392,689472,$4,2048);
  $5 = (($localIdentifier$i$i$i) + 8|0);
  $6 = $5;
  $7 = $6;
  HEAP32[$7>>2] = 0;
  $8 = (($6) + 4)|0;
  $9 = $8;
  HEAP32[$9>>2] = 0;
  HEAP32[$localIdentifier$i$i$i>>2] = 0;
  $10 = HEAP32[580592>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,689440,$10,$4,1);
  $11 = (($transfer) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($transfer) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($13) + (($15*24)|0)|0) + 12|0);
  HEAP32[$16>>2] = 4;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $17 = HEAP32[580688>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,689456,$17,$5,1);
  $18 = HEAP32[$11>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = HEAP32[$14>>2]|0;
  $21 = ((($19) + (($20*24)|0)|0) + 12|0);
  HEAP32[$21>>2] = 8;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer11EndTransferEv($transfer);
 }
 $22 = HEAP32[$this>>2]|0;
 $23 = (($22) + 116|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_ii[$24 & 4095]($this)|0);
 if ($25) {
  $26 = (($this) + 36|0);
  $27 = HEAP32[580544>>2]|0;
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,689408,$27,$26,2048);
  $28 = (($transfer) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = (($transfer) + 20|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ((($30) + (($32*24)|0)|0) + 12|0);
  HEAP32[$33>>2] = 1;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  $$pre$phi3Z2D = $31;$$pre$phiZ2D = $28;$35 = $27;
  $34 = (($this) + 37|0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,689424,$35,$34,257);
  $36 = HEAP32[$$pre$phiZ2D>>2]|0;
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$$pre$phi3Z2D>>2]|0;
  $39 = ((($37) + (($38*24)|0)|0) + 12|0);
  HEAP32[$39>>2] = 1;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $$pre = HEAP32[580544>>2]|0;
  $$pre1 = (($transfer) + 12|0);
  $$pre2 = (($transfer) + 20|0);
  $$pre$phi3Z2D = $$pre2;$$pre$phiZ2D = $$pre1;$35 = $$pre;
  $34 = (($this) + 37|0);
  __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,689424,$35,$34,257);
  $36 = HEAP32[$$pre$phiZ2D>>2]|0;
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$$pre$phi3Z2D>>2]|0;
  $39 = ((($37) + (($38*24)|0)|0) + 12|0);
  HEAP32[$39>>2] = 1;
  __ZN13ProxyTransfer11EndTransferEv($transfer);
  __ZN13ProxyTransfer5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN8Collider8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i1 = 0, $converter$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i2 = sp + 8|0;
 $converter$i$i1 = sp;
 $converter$i$i = sp + 4|0;
 __ZN5Unity9Component8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if ($3) {
  $4 = (($this) + 28|0);
  $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,689392,689472,$converter$i$i,1)|0);
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = ($5|0)>(0);
   if ($7) {
    __ZN4PPtrI14PhysicMaterialE8TransferI14SafeBinaryReadEEvRT_($4,$transfer);
   } else {
    $8 = HEAP32[$converter$i$i>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     (FUNCTION_TABLE_iii[$8 & 4095]($4,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 }
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 116|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($this)|0);
 if ($13) {
  $14 = (($this) + 36|0);
  $15 = HEAP32[580544>>2]|0;
  $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,689408,$15,$converter$i$i1,0)|0);
  $17 = ($16|0)==(0);
  if ($17) {
   $43 = $15;
  } else {
   $18 = ($16|0)>(0);
   do {
    if ($18) {
     $19 = (($transfer) + 12|0);
     $20 = (($transfer) + 80|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($21) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($transfer) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($transfer) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($transfer) + 32|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = Math_imul($29, $27)|0;
     $$sum$i$i$i$i$i = (($23) - ($30))|0;
     $31 = (($25) + ($$sum$i$i$i$i$i)|0);
     HEAP32[$19>>2] = $31;
     $32 = ($$sum$i$i$i$i$i|0)<(0);
     if (!($32)) {
      $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
      $33 = (($25) + ($$sum1$i$i$i$i$i)|0);
      $34 = (($transfer) + 20|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($33>>>0)>($35>>>0);
      if (!($36)) {
       $37 = HEAP8[$31>>0]|0;
       HEAP8[$14>>0] = $37;
       $38 = HEAP32[$19>>2]|0;
       $39 = (($38) + 1|0);
       HEAP32[$19>>2] = $39;
       break;
      }
     }
     __ZN12CachedReader15UpdateReadCacheEPvj($19,$14,1);
    } else {
     $40 = HEAP32[$converter$i$i1>>2]|0;
     $41 = ($40|0)==(0|0);
     if (!($41)) {
      (FUNCTION_TABLE_iii[$40 & 4095]($14,$transfer)|0);
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
   $43 = $15;
  }
 } else {
  $$pre = HEAP32[580544>>2]|0;
  $43 = $$pre;
 }
 $42 = (($this) + 37|0);
 $44 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,689424,$43,$converter$i$i2,0)|0);
 $45 = ($44|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $46 = ($44|0)>(0);
 do {
  if ($46) {
   $47 = (($transfer) + 12|0);
   $48 = (($transfer) + 80|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($transfer) + 16|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($transfer) + 28|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($transfer) + 32|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = Math_imul($57, $55)|0;
   $$sum$i$i$i$i$i3 = (($51) - ($58))|0;
   $59 = (($53) + ($$sum$i$i$i$i$i3)|0);
   HEAP32[$47>>2] = $59;
   $60 = ($$sum$i$i$i$i$i3|0)<(0);
   if (!($60)) {
    $$sum1$i$i$i$i$i4 = (($$sum$i$i$i$i$i3) + 1)|0;
    $61 = (($53) + ($$sum1$i$i$i$i$i4)|0);
    $62 = (($transfer) + 20|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = ($61>>>0)>($63>>>0);
    if (!($64)) {
     $65 = HEAP8[$59>>0]|0;
     HEAP8[$42>>0] = $65;
     $66 = HEAP32[$47>>2]|0;
     $67 = (($66) + 1|0);
     HEAP32[$47>>2] = $67;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($47,$42,1);
  } else {
   $68 = HEAP32[$converter$i$i2>>2]|0;
   $69 = ($68|0)==(0|0);
   if (!($69)) {
    (FUNCTION_TABLE_iii[$68 & 4095]($42,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Collider8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phi3Z2D = 0, $$pre$phi5Z2D = 0, $$pre$phiZ2D = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if ($3) {
  $4 = (($this) + 28|0);
  __ZN4PPtrI14PhysicMaterialE8TransferI18StreamedBinaryReadILb0EEEEvRT_($4,$transfer);
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($this)|0);
 do {
  if ($8) {
   $9 = (($this) + 36|0);
   $10 = (($transfer) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 1|0);
   $13 = (($transfer) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12>>>0)>($14>>>0);
   if ($15) {
    __ZN12CachedReader15UpdateReadCacheEPvj($10,$9,1);
    $$pre$phi3Z2D = $10;$$pre$phi5Z2D = $13;$$pre$phiZ2D = $10;
    break;
   } else {
    $16 = HEAP8[$11>>0]|0;
    HEAP8[$9>>0] = $16;
    $17 = HEAP32[$10>>2]|0;
    $18 = (($17) + 1|0);
    HEAP32[$10>>2] = $18;
    $$pre$phi3Z2D = $10;$$pre$phi5Z2D = $13;$$pre$phiZ2D = $10;
    break;
   }
  } else {
   $$pre = (($transfer) + 12|0);
   $$pre4 = (($transfer) + 20|0);
   $$pre$phi3Z2D = $$pre;$$pre$phi5Z2D = $$pre4;$$pre$phiZ2D = $$pre;
  }
 } while(0);
 $19 = (($this) + 37|0);
 $20 = HEAP32[$$pre$phi3Z2D>>2]|0;
 $21 = (($20) + 1|0);
 $22 = HEAP32[$$pre$phi5Z2D>>2]|0;
 $23 = ($21>>>0)>($22>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($$pre$phiZ2D,$19,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $24 = HEAP8[$20>>0]|0;
  HEAP8[$19>>0] = $24;
  $25 = HEAP32[$$pre$phi3Z2D>>2]|0;
  $26 = (($25) + 1|0);
  HEAP32[$$pre$phi3Z2D>>2] = $26;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN8Collider8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phi3Z2D = 0, $$pre$phi5Z2D = 0, $$pre$phiZ2D = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if ($3) {
  $4 = (($this) + 28|0);
  __ZN4PPtrI14PhysicMaterialE8TransferI18StreamedBinaryReadILb1EEEEvRT_($4,$transfer);
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($this)|0);
 do {
  if ($8) {
   $9 = (($this) + 36|0);
   $10 = (($transfer) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 1|0);
   $13 = (($transfer) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12>>>0)>($14>>>0);
   if ($15) {
    __ZN12CachedReader15UpdateReadCacheEPvj($10,$9,1);
    $$pre$phi3Z2D = $10;$$pre$phi5Z2D = $13;$$pre$phiZ2D = $10;
    break;
   } else {
    $16 = HEAP8[$11>>0]|0;
    HEAP8[$9>>0] = $16;
    $17 = HEAP32[$10>>2]|0;
    $18 = (($17) + 1|0);
    HEAP32[$10>>2] = $18;
    $$pre$phi3Z2D = $10;$$pre$phi5Z2D = $13;$$pre$phiZ2D = $10;
    break;
   }
  } else {
   $$pre = (($transfer) + 12|0);
   $$pre4 = (($transfer) + 20|0);
   $$pre$phi3Z2D = $$pre;$$pre$phi5Z2D = $$pre4;$$pre$phiZ2D = $$pre;
  }
 } while(0);
 $19 = (($this) + 37|0);
 $20 = HEAP32[$$pre$phi3Z2D>>2]|0;
 $21 = (($20) + 1|0);
 $22 = HEAP32[$$pre$phi5Z2D>>2]|0;
 $23 = ($21>>>0)>($22>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($$pre$phiZ2D,$19,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $24 = HEAP8[$20>>0]|0;
  HEAP8[$19>>0] = $24;
  $25 = HEAP32[$$pre$phi3Z2D>>2]|0;
  $26 = (($25) + 1|0);
  HEAP32[$$pre$phi3Z2D>>2] = $26;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN8Collider8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phi3Z2D = 0, $$pre$phi5Z2D = 0, $$pre$phiZ2D = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if ($3) {
  $4 = (($this) + 28|0);
  __ZN4PPtrI14PhysicMaterialE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($4,$transfer);
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($this)|0);
 do {
  if ($8) {
   $9 = (($this) + 36|0);
   $10 = (($transfer) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 1|0);
   $13 = (($transfer) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12>>>0)<($14>>>0);
   if ($15) {
    $16 = HEAP8[$9>>0]|0;
    HEAP8[$11>>0] = $16;
    $17 = HEAP32[$10>>2]|0;
    $18 = (($17) + 1|0);
    HEAP32[$10>>2] = $18;
    $$pre$phi3Z2D = $10;$$pre$phi5Z2D = $13;$$pre$phiZ2D = $10;
    break;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($10,$9,1);
    $$pre$phi3Z2D = $10;$$pre$phi5Z2D = $13;$$pre$phiZ2D = $10;
    break;
   }
  } else {
   $$pre = (($transfer) + 12|0);
   $$pre4 = (($transfer) + 20|0);
   $$pre$phi3Z2D = $$pre;$$pre$phi5Z2D = $$pre4;$$pre$phiZ2D = $$pre;
  }
 } while(0);
 $19 = (($this) + 37|0);
 $20 = HEAP32[$$pre$phi3Z2D>>2]|0;
 $21 = (($20) + 1|0);
 $22 = HEAP32[$$pre$phi5Z2D>>2]|0;
 $23 = ($21>>>0)<($22>>>0);
 if ($23) {
  $24 = HEAP8[$19>>0]|0;
  HEAP8[$20>>0] = $24;
  $25 = HEAP32[$$pre$phi3Z2D>>2]|0;
  $26 = (($25) + 1|0);
  HEAP32[$$pre$phi3Z2D>>2] = $26;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($$pre$phiZ2D,$19,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN8Collider8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 112|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  $16 = HEAP32[$this>>2]|0;
  $17 = (($16) + 116|0);
  $18 = HEAP32[$17>>2]|0;
  (FUNCTION_TABLE_ii[$18 & 4095]($this)|0);
  STACKTOP = sp;return;
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiii[$9 & 2047]($7,$5,$11)|0);
 $13 = (($transfer) + 32|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  HEAP32[$4>>2] = $12;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 $16 = HEAP32[$this>>2]|0;
 $17 = (($16) + 116|0);
 $18 = HEAP32[$17>>2]|0;
 (FUNCTION_TABLE_ii[$18 & 4095]($this)|0);
 STACKTOP = sp;return;
}
function __ZN4PPtrI14PhysicMaterialE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI14PhysicMaterialE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI14PhysicMaterialE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI14PhysicMaterialE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,689440,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,689456,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,689440,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,689456,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN12MeshCollider17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 68|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (($this) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 80|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($9) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$8>>2]|0;
 $15 = HEAP32[$11>>2]|0;
 HEAP32[$15>>2] = $14;
 HEAP32[$8>>2] = 0;
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12MeshCollider13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 52|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = HEAP32[$1>>2]|0;
  $7 = (($6) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_ii[$8 & 4095]($1)|0);
  $10 = ($9|0)==(4);
  $11 = $10&1;
  $12 = ($5|0)==($11|0);
  if (!($12)) {
   $13 = (($this) + 24|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    $16 = (__ZNK5Unity10GameObject8IsActiveEv($14)|0);
    if ($16) {
     $17 = HEAP32[$this>>2]|0;
     $18 = (($17) + 136|0);
     $19 = HEAP32[$18>>2]|0;
     FUNCTION_TABLE_vii[$19 & 4095]($this,0);
    }
   }
  }
  $20 = HEAP32[$0>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   $22 = (($this) + 56|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($this) + 60|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==($23|0);
   if (!($26)) {
    HEAP32[$22>>2] = $23;
    $27 = (($this) + 24|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     $30 = (__ZNK5Unity10GameObject8IsActiveEv($28)|0);
     if ($30) {
      $31 = HEAP32[$this>>2]|0;
      $32 = (($31) + 136|0);
      $33 = HEAP32[$32>>2]|0;
      FUNCTION_TABLE_vii[$33 & 4095]($this,0);
     }
    }
   }
  }
 }
 __ZN8Collider13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider7CleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $sMesh = 0, $sMesh1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $sMesh = sp + 40|0;
 $sMesh1 = sp;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 68|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (($this) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = (($this) + 80|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($9) + 4|0);
  HEAP32[$13>>2] = $12;
  $14 = HEAP32[$8>>2]|0;
  $15 = HEAP32[$11>>2]|0;
  HEAP32[$15>>2] = $14;
  HEAP32[$8>>2] = 0;
  HEAP32[$11>>2] = 0;
 }
 $16 = (($this) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$17>>2]|0;
 $20 = (($19) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 4095]($17)|0);
 $23 = ($22|0)==(4);
 if ($23) {
  HEAP32[$sMesh>>2] = 4;
  $24 = (($sMesh) + 4|0);
  HEAPF32[$24>>2] = Math_fround(1.0);
  $25 = (($sMesh) + 8|0);
  HEAPF32[$25>>2] = Math_fround(1.0);
  $26 = (($sMesh) + 12|0);
  HEAPF32[$26>>2] = Math_fround(1.0);
  $27 = (($sMesh) + 16|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  $28 = (($sMesh) + 20|0);
  HEAPF32[$28>>2] = Math_fround(0.0);
  $29 = (($sMesh) + 24|0);
  HEAPF32[$29>>2] = Math_fround(0.0);
  $30 = (($sMesh) + 28|0);
  HEAPF32[$30>>2] = Math_fround(1.0);
  $31 = (($sMesh) + 32|0);
  HEAP32[$31>>2] = 0;
  $32 = HEAP32[$16>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 52|0);
  $35 = HEAP32[$34>>2]|0;
  (FUNCTION_TABLE_iii[$35 & 4095]($32,$sMesh)|0);
  __ZN8Collider7CleanupEv($this);
  $36 = (($this) + 53|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($37<<24>>24)==(0);
  if (!($38)) {
   STACKTOP = sp;return;
  }
  $39 = HEAP32[$31>>2]|0;
  $40 = HEAP32[$39>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vi[$41 & 4095]($39);
  STACKTOP = sp;return;
 } else {
  HEAP32[$sMesh1>>2] = 5;
  $42 = (($sMesh1) + 4|0);
  HEAPF32[$42>>2] = Math_fround(1.0);
  $43 = (($sMesh1) + 8|0);
  HEAPF32[$43>>2] = Math_fround(1.0);
  $44 = (($sMesh1) + 12|0);
  HEAPF32[$44>>2] = Math_fround(1.0);
  $45 = (($sMesh1) + 16|0);
  HEAPF32[$45>>2] = Math_fround(0.0);
  $46 = (($sMesh1) + 20|0);
  HEAPF32[$46>>2] = Math_fround(0.0);
  $47 = (($sMesh1) + 24|0);
  HEAPF32[$47>>2] = Math_fround(0.0);
  $48 = (($sMesh1) + 28|0);
  HEAPF32[$48>>2] = Math_fround(1.0);
  $49 = (($sMesh1) + 32|0);
  $50 = $49;
  $51 = $50;
  HEAP32[$51>>2] = 0;
  $52 = (($50) + 4)|0;
  $53 = $52;
  HEAP32[$53>>2] = 0;
  $54 = HEAP32[$16>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + 56|0);
  $57 = HEAP32[$56>>2]|0;
  (FUNCTION_TABLE_iii[$57 & 4095]($54,$sMesh1)|0);
  __ZN8Collider7CleanupEv($this);
  $58 = (($this) + 53|0);
  $59 = HEAP8[$58>>0]|0;
  $60 = ($59<<24>>24)==(0);
  if (!($60)) {
   STACKTOP = sp;return;
  }
  $61 = (($sMesh1) + 36|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = HEAP32[$62>>2]|0;
  $64 = HEAP32[$63>>2]|0;
  FUNCTION_TABLE_vi[$64 & 4095]($62);
  STACKTOP = sp;return;
 }
}
function __ZN12MeshCollider11CreateShapeEPvPK9RigidbodyRK8Vector3f($this,$nxmesh,$ignoreRigidbody,$scale) {
 $this = $this|0;
 $nxmesh = $nxmesh|0;
 $ignoreRigidbody = $ignoreRigidbody|0;
 $scale = $scale|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $sMeshGeom = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $sMeshGeom = sp;
 $0 = ($nxmesh|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 80|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($2) + 4|0);
  HEAP32[$6>>2] = $5;
  $7 = HEAP32[$1>>2]|0;
  $8 = HEAP32[$4>>2]|0;
  HEAP32[$8>>2] = $7;
  HEAP32[$1>>2] = 0;
  HEAP32[$4>>2] = 0;
 }
 $9 = (($this) + 52|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$sMeshGeom>>2] = 4;
  $12 = (($sMeshGeom) + 4|0);
  $13 = (($sMeshGeom) + 8|0);
  $14 = (($sMeshGeom) + 12|0);
  $15 = (($sMeshGeom) + 16|0);
  HEAPF32[$15>>2] = Math_fround(0.0);
  $16 = (($sMeshGeom) + 20|0);
  HEAPF32[$16>>2] = Math_fround(0.0);
  $17 = (($sMeshGeom) + 24|0);
  HEAPF32[$17>>2] = Math_fround(0.0);
  $18 = (($sMeshGeom) + 28|0);
  HEAPF32[$18>>2] = Math_fround(1.0);
  $19 = (($sMeshGeom) + 32|0);
  HEAP32[$19>>2] = $nxmesh;
  $20 = Math_fround(HEAPF32[$scale>>2]);
  $21 = (($scale) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($scale) + 8|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$12>>2] = $20;
  HEAPF32[$13>>2] = $22;
  HEAPF32[$14>>2] = $24;
  __ZN8Collider14FinalizeCreateERN5physx10PxGeometryEPK9Rigidbody($this,$sMeshGeom,$ignoreRigidbody);
  STACKTOP = sp;return;
 }
 $25 = (__ZN8Collider24FindNewAttachedRigidbodyEPK9Rigidbody($this,$ignoreRigidbody)|0);
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (__ZNK9Rigidbody14GetIsKinematicEv($25)|0);
  if (!($27)) {
   $28 = (($this) + 88|0);
   HEAP32[$28>>2] = 689672;
   $29 = (($this) + 92|0);
   HEAP32[$29>>2] = $this;
   $30 = (__Z17GetPhysicsManagerv()|0);
   $31 = (($30) + 644|0);
   $32 = ($1|0)==($31|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   $33 = HEAP32[$1>>2]|0;
   $34 = ($33|0)==(0|0);
   $$pre$i$i$i = (($this) + 80|0);
   if (!($34)) {
    $35 = HEAP32[$$pre$i$i$i>>2]|0;
    $36 = (($33) + 4|0);
    HEAP32[$36>>2] = $35;
    $37 = HEAP32[$1>>2]|0;
    $38 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$38>>2] = $37;
    HEAP32[$1>>2] = 0;
    HEAP32[$$pre$i$i$i>>2] = 0;
   }
   $39 = HEAP32[$31>>2]|0;
   HEAP32[$1>>2] = $39;
   HEAP32[$$pre$i$i$i>>2] = $31;
   $40 = (($39) + 4|0);
   HEAP32[$40>>2] = $1;
   $41 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$41>>2] = $1;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$sMeshGeom>>2] = 5;
 $42 = (($sMeshGeom) + 4|0);
 $43 = (($sMeshGeom) + 8|0);
 $44 = (($sMeshGeom) + 12|0);
 $45 = (($sMeshGeom) + 16|0);
 HEAPF32[$45>>2] = Math_fround(0.0);
 $46 = (($sMeshGeom) + 20|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = (($sMeshGeom) + 24|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($sMeshGeom) + 28|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($sMeshGeom) + 32|0);
 $50 = $49;
 $51 = $50;
 HEAP32[$51>>2] = 0;
 $52 = (($50) + 4)|0;
 $53 = $52;
 HEAP32[$53>>2] = 0;
 $54 = (($sMeshGeom) + 36|0);
 HEAP32[$54>>2] = $nxmesh;
 $55 = Math_fround(HEAPF32[$scale>>2]);
 $56 = (($scale) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($scale) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 HEAPF32[$42>>2] = $55;
 HEAPF32[$43>>2] = $57;
 HEAPF32[$44>>2] = $59;
 __ZN8Collider14FinalizeCreateERN5physx10PxGeometryEPK9Rigidbody($this,$sMeshGeom,$ignoreRigidbody);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider12ScaleChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sMeshGeom = 0, $scale = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $scale = sp + 40|0;
 $sMeshGeom = sp;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAPF32[$scale>>2] = Math_fround(0.0);
 $3 = (($scale) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($scale) + 8|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (__ZN12MeshCollider19ExtractMeshGeometryER8Vector3f($this,$scale)|0);
 $6 = (($this) + 52|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  HEAP32[$sMeshGeom>>2] = 5;
  $28 = (($sMeshGeom) + 4|0);
  HEAPF32[$28>>2] = Math_fround(1.0);
  $29 = (($sMeshGeom) + 8|0);
  HEAPF32[$29>>2] = Math_fround(1.0);
  $30 = (($sMeshGeom) + 12|0);
  HEAPF32[$30>>2] = Math_fround(1.0);
  $31 = (($sMeshGeom) + 16|0);
  HEAPF32[$31>>2] = Math_fround(0.0);
  $32 = (($sMeshGeom) + 20|0);
  HEAPF32[$32>>2] = Math_fround(0.0);
  $33 = (($sMeshGeom) + 24|0);
  HEAPF32[$33>>2] = Math_fround(0.0);
  $34 = (($sMeshGeom) + 28|0);
  HEAPF32[$34>>2] = Math_fround(1.0);
  $35 = (($sMeshGeom) + 32|0);
  $36 = $35;
  $37 = $36;
  HEAP32[$37>>2] = 0;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = 0;
  $40 = HEAP32[$0>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 56|0);
  $43 = HEAP32[$42>>2]|0;
  (FUNCTION_TABLE_iii[$43 & 4095]($40,$sMeshGeom)|0);
  $44 = (($sMeshGeom) + 36|0);
  HEAP32[$44>>2] = $5;
  $45 = Math_fround(HEAPF32[$scale>>2]);
  $46 = Math_fround(HEAPF32[$3>>2]);
  $47 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$28>>2] = $45;
  HEAPF32[$29>>2] = $46;
  HEAPF32[$30>>2] = $47;
  $48 = HEAP32[$0>>2]|0;
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 28|0);
  $51 = HEAP32[$50>>2]|0;
  FUNCTION_TABLE_vii[$51 & 4095]($48,$sMeshGeom);
  STACKTOP = sp;return;
 } else {
  HEAP32[$sMeshGeom>>2] = 4;
  $9 = (($sMeshGeom) + 4|0);
  HEAPF32[$9>>2] = Math_fround(1.0);
  $10 = (($sMeshGeom) + 8|0);
  HEAPF32[$10>>2] = Math_fround(1.0);
  $11 = (($sMeshGeom) + 12|0);
  HEAPF32[$11>>2] = Math_fround(1.0);
  $12 = (($sMeshGeom) + 16|0);
  HEAPF32[$12>>2] = Math_fround(0.0);
  $13 = (($sMeshGeom) + 20|0);
  HEAPF32[$13>>2] = Math_fround(0.0);
  $14 = (($sMeshGeom) + 24|0);
  HEAPF32[$14>>2] = Math_fround(0.0);
  $15 = (($sMeshGeom) + 28|0);
  HEAPF32[$15>>2] = Math_fround(1.0);
  $16 = (($sMeshGeom) + 32|0);
  HEAP32[$16>>2] = 0;
  $17 = HEAP32[$0>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 52|0);
  $20 = HEAP32[$19>>2]|0;
  (FUNCTION_TABLE_iii[$20 & 4095]($17,$sMeshGeom)|0);
  HEAP32[$16>>2] = $5;
  $21 = Math_fround(HEAPF32[$scale>>2]);
  $22 = Math_fround(HEAPF32[$3>>2]);
  $23 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$9>>2] = $21;
  HEAPF32[$10>>2] = $22;
  HEAPF32[$11>>2] = $23;
  $24 = HEAP32[$0>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vii[$27 & 4095]($24,$sMeshGeom);
  STACKTOP = sp;return;
 }
}
function __ZN12MeshCollider19ExtractMeshGeometryER8Vector3f($this,$scale) {
 $this = $this|0;
 $scale = $scale|0;
 var $$0 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $scalematrix = 0, $scalematrix$i = 0, $temp$0$i6 = 0, $x$03$i$i = 0;
 var $y$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $scalematrix$i = sp + 72|0;
 $0 = sp;
 $scalematrix = sp + 8|0;
 $1 = (($this) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 11;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($scalematrix$i,$4,$0);
    $16 = HEAP32[$scalematrix$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 11;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 11;
   } else {
    $$in = $33;$temp$0$i6 = $33;
   }
  }
 }
 if ((label|0) == 11) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$in = $36;$temp$0$i6 = $36;
  }
 }
 $38 = (($temp$0$i6) + 28|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 100|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0);
 if ($42) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = (__ZNK4Mesh17GetPrimitiveCountEv($$in)|0);
 $44 = ($43|0)==(0);
 if ($44) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($this) + 24|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($46)|0);
 $48 = (__ZNK9Transform34CalculateTransformMatrixScaleDeltaER10Matrix4x4f($47,$scalematrix)|0);
 $49 = HEAP32[$45>>2]|0;
 $50 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($49)|0);
 $51 = (__ZNK9Transform34CalculateTransformMatrixScaleDeltaER10Matrix4x4f($50,$scalematrix$i)|0);
 $52 = $51 & 2;
 $53 = ($52|0)==(0);
 L25: do {
  if ($53) {
   label = 23;
  } else {
   $x$03$i$i = 0;
   while(1) {
    $y$01$i$i = 0;
    while(1) {
     $54 = ($x$03$i$i|0)==($y$01$i$i|0);
     $55 = $y$01$i$i << 2;
     $56 = (($55) + ($x$03$i$i))|0;
     $57 = (($scalematrix$i) + ($56<<2)|0);
     $58 = Math_fround(HEAPF32[$57>>2]);
     $59 = $58 < Math_fround(0.0);
     if ($54) {
      if ($59) {
       break L25;
      }
     } else {
      if ($59) {
       $60 = Math_fround(-$58);
       $62 = $60;
      } else {
       $62 = $58;
      }
      $61 = !($62 <= Math_fround(0.00999999977648258209228));
      if ($61) {
       break L25;
      }
     }
     $63 = (($y$01$i$i) + 1)|0;
     $64 = ($63|0)<(3);
     if ($64) {
      $y$01$i$i = $63;
     } else {
      break;
     }
    }
    $65 = (($x$03$i$i) + 1)|0;
    $66 = ($65|0)<(3);
    if ($66) {
     $x$03$i$i = $65;
    } else {
     label = 23;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $67 = (($temp$0$i6) + 208|0);
  $68 = HEAP8[$67>>0]|0;
  $69 = ($68<<24>>24)==(0);
  if ($69) {
   $70 = Math_fround(HEAPF32[$scalematrix>>2]);
   $71 = (($scalematrix) + 20|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   $73 = (($scalematrix) + 40|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   HEAPF32[$scale>>2] = $70;
   $75 = (($scale) + 4|0);
   HEAPF32[$75>>2] = $72;
   $76 = (($scale) + 8|0);
   HEAPF32[$76>>2] = $74;
   $77 = (($this) + 53|0);
   HEAP8[$77>>0] = 1;
   $78 = (($this) + 52|0);
   $79 = HEAP8[$78>>0]|0;
   $80 = ($79<<24>>24)==(0);
   if ($80) {
    $82 = (__ZN4Mesh15GetSharedPxMeshEv($$in)|0);
    $$0 = $82;
    STACKTOP = sp;return ($$0|0);
   } else {
    $81 = (__ZN4Mesh21GetSharedPxConvexMeshEv($$in)|0);
    $$0 = $81;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $83 = (($this) + 53|0);
 HEAP8[$83>>0] = 0;
 $84 = (__Z11GetIPhysicsv()|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($85) + 32|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($this) + 52|0);
 $89 = HEAP8[$88>>0]|0;
 $90 = ($89<<24>>24)!=(0);
 $91 = (FUNCTION_TABLE_iiiiii[$87 & 255]($84,$$in,$90,$scalematrix,$48)|0);
 HEAPF32[$scale>>2] = Math_fround(1.0);
 $92 = (($scale) + 4|0);
 HEAPF32[$92>>2] = Math_fround(1.0);
 $93 = (($scale) + 8|0);
 HEAPF32[$93>>2] = Math_fround(1.0);
 $$0 = $91;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12MeshCollider6CreateEPK9Rigidbody($this,$ignoreRigidbody) {
 $this = $this|0;
 $ignoreRigidbody = $ignoreRigidbody|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $pos$i$i$i$i = 0, $scale = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp;
 $scale = sp + 4|0;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$this>>2]|0;
  $5 = (($4) + 144|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($this);
 }
 $7 = (($this) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 60|0);
 HEAP32[$9>>2] = $8;
 HEAPF32[$scale>>2] = Math_fround(0.0);
 $10 = (($scale) + 4|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($scale) + 8|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (__ZN12MeshCollider19ExtractMeshGeometryER8Vector3f($this,$scale)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$7>>2]|0;
 HEAP32[$0>>2] = $14;
 $15 = HEAP32[560624>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  label = 12;
 } else {
  $17 = (($15) + 36|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($15) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($18|0)==($20|0);
  do {
   if ($21) {
    $22 = (($15) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($15) + 32|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + ($25<<3)|0);
    $42 = $26;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$15,$0);
    $27 = HEAP32[$pos$i$i$i$i>>2]|0;
    $28 = ($27|0)==(-1);
    $29 = (($15) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    if ($28) {
     $31 = (($15) + 32|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($30) + ($32<<3)|0);
     $42 = $33;
     break;
    } else {
     $34 = (($30) + ($27<<3)|0);
     $42 = $34;
     break;
    }
   }
  } while(0);
  $35 = HEAP32[560624>>2]|0;
  $36 = (($35) + 28|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + 32|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + ($39<<3)|0);
  $41 = ($42|0)==($40|0);
  if ($41) {
   label = 12;
  } else {
   $43 = (($42) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0|0);
   if ($45) {
    label = 12;
   } else {
    $temp$0$i = $44;
   }
  }
 }
 if ((label|0) == 12) {
  $46 = HEAP32[$7>>2]|0;
  $47 = (__Z31ReadObjectFromPersistentManageri($46)|0);
  $temp$0$i = $47;
 }
 $48 = (($this) + 64|0);
 $49 = (($temp$0$i) + 212|0);
 $50 = ($48|0)==($49|0);
 if (!($50)) {
  $51 = HEAP32[$48>>2]|0;
  $52 = ($51|0)==(0|0);
  $$pre$i$i$i = (($this) + 68|0);
  if (!($52)) {
   $53 = HEAP32[$$pre$i$i$i>>2]|0;
   $54 = (($51) + 4|0);
   HEAP32[$54>>2] = $53;
   $55 = HEAP32[$48>>2]|0;
   $56 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$56>>2] = $55;
   HEAP32[$48>>2] = 0;
   HEAP32[$$pre$i$i$i>>2] = 0;
  }
  $57 = HEAP32[$49>>2]|0;
  HEAP32[$48>>2] = $57;
  HEAP32[$$pre$i$i$i>>2] = $49;
  $58 = (($57) + 4|0);
  HEAP32[$58>>2] = $48;
  $59 = HEAP32[$$pre$i$i$i>>2]|0;
  HEAP32[$59>>2] = $48;
 }
 __ZN12MeshCollider11CreateShapeEPvPK9RigidbodyRK8Vector3f($this,$12,$ignoreRigidbody,$scale);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider16TransformChangedEi($this,$changeMask) {
 $this = $this|0;
 $changeMask = $changeMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $matrix = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $matrix = sp;
 __ZN8Collider16TransformChangedEi($this,$changeMask);
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $29 = (($this) + 24|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   STACKTOP = sp;return;
  }
  $32 = (__ZNK5Unity10GameObject8IsActiveEv($30)|0);
  if (!($32)) {
   STACKTOP = sp;return;
  }
  $33 = (($this) + 37|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = ($34<<24>>24)==(0);
  if ($35) {
   STACKTOP = sp;return;
  }
  $36 = HEAP32[$this>>2]|0;
  $37 = (($36) + 136|0);
  $38 = HEAP32[$37>>2]|0;
  FUNCTION_TABLE_vii[$38 & 4095]($this,0);
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 do {
  if ($9) {
   $10 = HEAP32[$this>>2]|0;
   $11 = (($10) + 164|0);
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vi[$12 & 4095]($this);
  } else {
   $13 = (($8) + 24|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($14)|0);
   $16 = (__ZN8Collider30GetRelativePositionAndRotationERK9TransformR10Matrix4x4f($this,$15,$matrix)|0);
   if ($16) {
    $17 = HEAP32[$0>>2]|0;
    __Z31SetShapeLocalPoseAndWakeUpActorPN5physx7PxShapeEPNS_12PxRigidActorERK10Matrix4x4f($17,$6,$matrix);
   }
   $18 = HEAP32[$13>>2]|0;
   $19 = (($this) + 24|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($18|0)==($20|0);
   if ($21) {
    $22 = $changeMask & 8;
    $23 = ($22|0)==(0);
    if ($23) {
     break;
    }
   }
   __ZN8Collider32RigidbodyMassDistributionChangedEv($this);
  }
 } while(0);
 $24 = $changeMask & 8;
 $25 = ($24|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = (($26) + 140|0);
 $28 = HEAP32[$27>>2]|0;
 FUNCTION_TABLE_vi[$28 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(64,564416,1976,0);
 STACKTOP = sp;return;
}
function __ZZN12MeshCollider15InitializeClassEvEN39FunctorImpl_MeshCollider_kDidDeleteMesh4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = HEAP32[$object>>2]|0;
 $3 = (($2) + 144|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($object);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider13GetSharedMeshEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$agg$result>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN12MeshCollider5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newMesh = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newMesh = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($1,33)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($this) + 56|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0);
   if ($7) {
    __ZN10MeshFilter13GetSharedMeshEv($newMesh,$3);
    $8 = HEAP32[$newMesh>>2]|0;
    $9 = HEAP32[$5>>2]|0;
    $10 = ($8|0)==($9|0);
    if (!($10)) {
     HEAP32[$5>>2] = $8;
     $11 = HEAP32[$0>>2]|0;
     $12 = ($11|0)==(0|0);
     if (!($12)) {
      $13 = (__ZNK5Unity10GameObject8IsActiveEv($11)|0);
      if ($13) {
       $14 = HEAP32[$this>>2]|0;
       $15 = (($14) + 136|0);
       $16 = HEAP32[$15>>2]|0;
       FUNCTION_TABLE_vii[$16 & 4095]($this,0);
      }
     }
    }
   }
  }
 }
 $17 = (($this) + 52|0);
 HEAP8[$17>>0] = 0;
 STACKTOP = sp;return;
}
function __Z26RegisterClass_MeshColliderv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(64,196,197,0,198);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(56)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN8Collider13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 12;
 dest=$3+0|0; src=689768+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 12|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,64,56,($0|0),96,(2554|0),0,1);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN12MeshCollider12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12MeshCollider7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(96,$$byval_copy2,1,16,689864,20)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1972,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((689496 + 8|0));
  $6 = (($3) + 56|0);
  $7 = (($3) + 72|0);
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;
  HEAP32[$7>>2] = $3;
  $8 = (($3) + 88|0);
  $9 = (($3) + 76|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 80|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 84|0);
  HEAP32[$11>>2] = $8;
  $12 = (($3) + 53|0);
  HEAP8[$12>>0] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(689864|0),20);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch(0|0)|0;
  $18 = tempRet0;
  ___clang_call_terminate($17);
  // unreachable;
 } else {
  ___resumeException($13|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK12MeshCollider25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 64;
}
function __ZN12MeshCollider23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer8TransferI12MeshColliderEEvRT_PKc17TransferMetaFlags($transfer,$this,689784,0);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI12MeshColliderEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,689768,$data,$metaFlag);
 __ZN8Collider8TransferI13ProxyTransferEEvRT_($data,$this);
 __ZN13ProxyTransfer10SetVersionEi($this,2);
 $0 = (($data) + 52|0);
 $1 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,689792,$1,$0,0);
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer5AlignEv($this);
 $8 = (($data) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,689808,689848,$8,0);
 $9 = (($localIdentifier$i$i$i) + 8|0);
 $10 = $9;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $14 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,689816,$14,$8,1);
 $15 = HEAP32[$2>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$5>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $19 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,689832,$19,$9,1);
 $20 = HEAP32[$2>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$5>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,689784,689768,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN12MeshCollider8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 52|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $10 = (($this) + 56|0);
 __ZN4PPtrI4MeshE8TransferI18StreamedBinaryReadILb0EEEEvRT_($10,$transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 52|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,1);
 } else {
  $7 = HEAP8[$2>>0]|0;
  HEAP8[$0>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $10 = (($this) + 56|0);
 __ZN4PPtrI4MeshE8TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 52|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP8[$0>>0]|0;
  HEAP8[$2>>0] = $7;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 1|0);
  HEAP32[$1>>2] = $9;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $10 = (($this) + 56|0);
 __ZN4PPtrI4MeshE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
 STACKTOP = sp;return;
}
function __ZN12MeshCollider23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Collider8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN12MeshColliderD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((689496 + 8|0));
 __ZN8ColliderD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN12MeshColliderD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((689496 + 8|0));
 __THREW__ = 0;
 invoke_vi(3629,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN12MeshCollider8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 __ZN8Collider8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 52|0);
 $1 = HEAP32[580544>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,689792,$1,$converter$i$i1,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  do {
   if ($4) {
    $5 = (($transfer) + 12|0);
    $6 = (($transfer) + 80|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($transfer) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($transfer) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($transfer) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = Math_imul($15, $13)|0;
    $$sum$i$i$i$i$i = (($9) - ($16))|0;
    $17 = (($11) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$5>>2] = $17;
    $18 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($18)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $19 = (($11) + ($$sum1$i$i$i$i$i)|0);
     $20 = (($transfer) + 20|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($19>>>0)>($21>>>0);
     if (!($22)) {
      $23 = HEAP8[$17>>0]|0;
      HEAP8[$0>>0] = $23;
      $24 = HEAP32[$5>>2]|0;
      $25 = (($24) + 1|0);
      HEAP32[$5>>2] = $25;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($5,$0,1);
   } else {
    $26 = HEAP32[$converter$i$i1>>2]|0;
    $27 = ($26|0)==(0|0);
    if (!($27)) {
     (FUNCTION_TABLE_iii[$26 & 4095]($0,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $28 = (($this) + 56|0);
 $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,689808,689848,$converter$i$i1,1)|0);
 $30 = ($29|0)==(0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = ($29|0)>(0);
 if ($31) {
  __ZN4PPtrI4MeshE8TransferI14SafeBinaryReadEEvRT_($28,$transfer);
 } else {
  $32 = HEAP32[$converter$i$i1>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   (FUNCTION_TABLE_iii[$32 & 4095]($28,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNK14PhysicMaterial21CopyMaterialToDefaultEv($this) {
 $this = $this|0;
 var $$$i$i = Math_fround(0), $$0$i$i = Math_fround(0), $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pDefault = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pDefault = sp;
 $0 = (__Z14GetDynamicsSDKv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiiii[$3 & 511]($0,$pDefault,1,0)|0);
 $4 = HEAP32[$pDefault>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($this) + 68|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   STACKTOP = sp;return;
  } else {
   $$01$i = $7;
  }
 } else {
  $$01$i = $4;
 }
 $9 = HEAP32[$$01$i>>2]|0;
 $10 = (($9) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 48|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 FUNCTION_TABLE_vif[$11 & 255]($$01$i,$13);
 $14 = HEAP32[$$01$i>>2]|0;
 $15 = (($14) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 52|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 FUNCTION_TABLE_vif[$16 & 255]($$01$i,$18);
 $19 = HEAP32[$$01$i>>2]|0;
 $20 = (($19) + 44|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 56|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = $23 < Math_fround(0.0);
 if ($24) {
  $$0$i$i = Math_fround(0.0);
 } else {
  $25 = $23 > Math_fround(1.0);
  $$$i$i = $25 ? Math_fround(1.0) : $23;
  $$0$i$i = $$$i$i;
 }
 FUNCTION_TABLE_vif[$21 & 255]($$01$i,$$0$i$i);
 $26 = HEAP32[$$01$i>>2]|0;
 $27 = (($26) + 64|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$28 & 4095]($$01$i,$30);
 $31 = HEAP32[$$01$i>>2]|0;
 $32 = (($31) + 72|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 44|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$33 & 4095]($$01$i,$35);
 STACKTOP = sp;return;
}
function __ZN14PhysicMaterial17ReleasePxMaterialEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($1);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __Z23_SimulationFilterShaderjN5physx12PxFilterDataEjS0_RNS_7PxFlagsINS_10PxPairFlag4EnumEtEEPKvj($agg$result,$attributes0,$filterData0,$attributes1,$filterData1,$pairFlags,$constantBlock,$constantBlockSize) {
 $agg$result = $agg$result|0;
 $attributes0 = $attributes0|0;
 $filterData0 = $filterData0|0;
 $attributes1 = $attributes1|0;
 $filterData1 = $filterData1|0;
 $pairFlags = $pairFlags|0;
 $constantBlock = $constantBlock|0;
 $constantBlockSize = $constantBlockSize|0;
 var $$ = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $brmerge1 = 0, $or$cond$i = 0, $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$filterData0>>2]|0;
 $1 = HEAP32[$filterData1>>2]|0;
 $2 = $0 & 255;
 $3 = $1 & 255;
 $4 = (__Z21GetManagerFromContexti(9)|0);
 $5 = (__ZN14PhysicsManager18GetIgnoreCollisionEii($4,$2,$3)|0);
 $6 = (($filterData0) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($filterData0) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZN8Collider14WordsToPointerEjj($7,$9)|0);
 $11 = (($filterData1) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($filterData1) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (__ZN8Collider14WordsToPointerEjj($12,$14)|0);
 $16 = ($10|0)==(0|0);
 $17 = ($15|0)==(0|0);
 $or$cond$i = $16 | $17;
 if ($or$cond$i) {
  $$0$i = 0;
 } else {
  $18 = (__ZNK8Collider21ShouldIgnoreCollisionEPS_($10,$15)|0);
  $$0$i = $18;
 }
 $19 = (($filterData0) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 16;
 $22 = ($21|0)==(0);
 if ($22) {
  $23 = (($filterData1) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 & 16;
  $26 = ($25|0)!=(0);
  $brmerge = $5 | $$0$i;
  $brmerge1 = $brmerge | $26;
  if (!($brmerge1)) {
   $27 = $1 | $0;
   $28 = $27 >>> 8;
   $29 = $28&65535;
   HEAP16[$pairFlags>>1] = $29;
   $30 = $attributes0 & 32;
   $31 = ($30|0)==(0);
   if ($31) {
    $32 = $attributes1 & 32;
    $33 = ($32|0)==(0);
    if ($33) {
     $36 = $28 | 1025;
     $storemerge$in = $36;
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    $34 = $28 & 65515;
    $35 = $34 | 20;
    $storemerge$in = $35;
   }
   $storemerge = $storemerge$in&65535;
   $37 = $20 >>> 2;
   $38 = $24 >>> 2;
   $39 = $38 & $20;
   $40 = $24 & $37;
   $41 = $39 | $40;
   $42 = $41 & 16371;
   $43 = ($42|0)==(0);
   $$ = $43 ? 0 : 2049;
   $44 = $$ | $storemerge;
   HEAP16[$pairFlags>>1] = $44;
   HEAP16[$agg$result>>1] = 0;
   STACKTOP = sp;return;
  }
 }
 HEAP16[$agg$result>>1] = 2;
 STACKTOP = sp;return;
}
function __Z17GetPhysicsManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(9)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14PhysicsManager18GetIgnoreCollisionEii($this,$layer1,$layer2) {
 $this = $this|0;
 $layer1 = $layer1|0;
 $layer2 = $layer2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond1 = 0, $or$cond2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = $layer2 | $layer1;
 $2 = ($1|0)<(0);
 $3 = ($layer1|0)>(31);
 $or$cond1 = $2 | $3;
 $4 = ($layer2|0)>(31);
 $or$cond2 = $or$cond1 | $4;
 if (!($or$cond2)) {
  $26 = (($this) + 676|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + ($layer1<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = 1 << $layer2;
  $31 = $29 & $30;
  $32 = ($31|0)==(0);
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = 31;
 __Z6FormatPKcz($0,690344,$vararg_buffer);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (($0) + 1|0);
  $11 = $10;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($11|0),0,(690112|0),1904,1,0,0,(0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP8[$0>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   ___resumeException($19|0);
   // unreachable;
  }
  $24 = (($0) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  __ZdlPv($25);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN14PhysicsManager18GetIgnoreCollisionEPKN5physx12PxFilterDataES3_($this,$a,$b) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($a) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN8Collider14WordsToPointerEjj($1,$3)|0);
 $5 = (($b) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($b) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZN8Collider14WordsToPointerEjj($6,$8)|0);
 $10 = ($4|0)==(0|0);
 $11 = ($9|0)==(0|0);
 $or$cond = $10 | $11;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (__ZNK8Collider21ShouldIgnoreCollisionEPS_($4,$9)|0);
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11ErrorStreamD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16NovodexAllocatorD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18PhysxJobDispatcherD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z14UpdateVehiclesf($dt) {
 $dt = Math_fround($dt);
 var $$byval_copy1 = 0, $$lcssa = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $exitcond = 0, $exitcond14 = 0, $exitcond16 = 0, $filterData = 0, $filterData3 = 0, $filterData6 = 0, $i$010 = 0, $i1$02 = 0, $i5$07 = 0, $j$01 = 0;
 var $j2$03 = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $shapeBuffer = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy1 = sp + 104|0;
 $0 = sp;
 $shapeBuffer = sp + 8|0;
 $filterData = sp + 40|0;
 $filterData3 = sp + 56|0;
 $filterData6 = sp + 72|0;
 $1 = sp + 88|0;
 $2 = HEAP32[689968>>2]|0;
 $3 = HEAP32[689960>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7|0)==(0);
 if ($8) {
  $$lcssa = $3;$92 = $2;
 } else {
  $9 = (($filterData6) + 8|0);
  $10 = (($filterData3) + 8|0);
  $11 = (($filterData) + 8|0);
  $13 = $3;$i$010 = 0;
  while(1) {
   $12 = (($13) + ($i$010<<2)|0);
   $14 = HEAP32[$12>>2]|0;
   $15 = $14 >>> 5;
   $16 = HEAP32[((689984 + 4|0))>>2]|0;
   $17 = (($16) + ($15<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = $14 & 31;
   $20 = 1 << $19;
   $21 = $18 & $20;
   $22 = ($21|0)==(0);
   if ($22) {
    $164 = $13;
   } else {
    $23 = $20 ^ -1;
    $24 = $18 & $23;
    HEAP32[$17>>2] = $24;
    $25 = HEAP32[689912>>2]|0;
    $26 = (($25) + ($14<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 104|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + 104|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
    $34 = $33 >>> 3;
    $35 = $34 << 3;
    $36 = (($33) - ($35))|0;
    $37 = ($34|0)==(0);
    if (!($37)) {
     $38 = $14 << 16;
     $39 = (($38) + 65536)|0;
     $i1$02 = 0;
     while(1) {
      $40 = HEAP32[$29>>2]|0;
      $41 = (($40) + 108|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = $i1$02 << 3;
      (FUNCTION_TABLE_iiiii[$42 & 511]($29,$shapeBuffer,8,$43)|0);
      $j$01 = 0;
      while(1) {
       $44 = (($shapeBuffer) + ($j$01<<2)|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 92|0);
       $48 = HEAP32[$47>>2]|0;
       FUNCTION_TABLE_vii[$48 & 4095]($filterData,$45);
       $49 = HEAP32[$11>>2]|0;
       $50 = $49 & 65535;
       $51 = $50 | $39;
       HEAP32[$11>>2] = $51;
       $52 = HEAP32[$44>>2]|0;
       $53 = HEAP32[$52>>2]|0;
       $54 = (($53) + 88|0);
       $55 = HEAP32[$54>>2]|0;
       FUNCTION_TABLE_vii[$55 & 4095]($52,$filterData);
       $56 = (($j$01) + 1)|0;
       $exitcond = ($56|0)==(8);
       if ($exitcond) {
        break;
       } else {
        $j$01 = $56;
       }
      }
      $57 = (($i1$02) + 1)|0;
      $58 = ($57>>>0)<($34>>>0);
      if ($58) {
       $i1$02 = $57;
      } else {
       break;
      }
     }
    }
    $59 = ($33|0)==($35|0);
    if (!($59)) {
     $60 = HEAP32[$29>>2]|0;
     $61 = (($60) + 108|0);
     $62 = HEAP32[$61>>2]|0;
     (FUNCTION_TABLE_iiiii[$62 & 511]($29,$shapeBuffer,$36,$35)|0);
     $63 = $14 << 16;
     $64 = (($63) + 65536)|0;
     $j2$03 = 0;
     while(1) {
      $65 = (($shapeBuffer) + ($j2$03<<2)|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = HEAP32[$66>>2]|0;
      $68 = (($67) + 92|0);
      $69 = HEAP32[$68>>2]|0;
      FUNCTION_TABLE_vii[$69 & 4095]($filterData3,$66);
      $70 = HEAP32[$10>>2]|0;
      $71 = $70 & 65535;
      $72 = $71 | $64;
      HEAP32[$10>>2] = $72;
      $73 = HEAP32[$65>>2]|0;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($74) + 88|0);
      $76 = HEAP32[$75>>2]|0;
      FUNCTION_TABLE_vii[$76 & 4095]($73,$filterData3);
      $77 = (($j2$03) + 1)|0;
      $78 = ($77>>>0)<($36>>>0);
      if ($78) {
       $j2$03 = $77;
      } else {
       break;
      }
     }
    }
    $79 = (($27) + 8|0);
    $80 = (($27) + 48|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ($81|0)==(0);
    if (!($82)) {
     $83 = $14 << 16;
     $84 = (($83) + 65536)|0;
     $i5$07 = 0;
     while(1) {
      $85 = (__ZNK5physx22PxVehicleWheelsSimData23getSceneQueryFilterDataEj($79,$i5$07)|0);
      ;HEAP32[$filterData6+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$filterData6+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$filterData6+8>>2]=HEAP32[$85+8>>2]|0;HEAP32[$filterData6+12>>2]=HEAP32[$85+12>>2]|0;
      $86 = HEAP32[$9>>2]|0;
      $87 = $86 & 65535;
      $88 = $87 | $84;
      HEAP32[$9>>2] = $88;
      __ZN5physx22PxVehicleWheelsSimData23setSceneQueryFilterDataEjRKNS_12PxFilterDataE($79,$i5$07,$filterData6);
      $89 = (($i5$07) + 1)|0;
      $exitcond14 = ($89|0)==($81|0);
      if ($exitcond14) {
       break;
      } else {
       $i5$07 = $89;
      }
     }
    }
    $$pre17 = HEAP32[689960>>2]|0;
    $164 = $$pre17;
   }
   $90 = (($i$010) + 1)|0;
   $exitcond16 = ($90|0)==($7|0);
   if ($exitcond16) {
    break;
   } else {
    $13 = $164;$i$010 = $90;
   }
  }
  $$pre = HEAP32[689968>>2]|0;
  $$lcssa = $164;$92 = $$pre;
 }
 $91 = ($92|0)==($$lcssa|0);
 if (!($91)) {
  $__new_last2$i$i$i = $$lcssa;
  $scevgep$i$i$i = (($92) + -4|0);
  $93 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($93)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $94 = $uglygep3$i$i$i >>> 2;
  $95 = $94 ^ -1;
  $scevgep4$i$i$i = (($92) + ($95<<2)|0);
  HEAP32[689968>>2] = $scevgep4$i$i$i;
 }
 $96 = HEAP32[((689984 + 8|0))>>2]|0;
 $97 = ($96|0)==(0);
 if (!($97)) {
  $98 = HEAP32[((689984 + 4|0))>>2]|0;
  $99 = HEAP32[((689984 + 12|0))>>2]|0;
  $100 = $99 << 2;
  _memset(($98|0),0,($100|0))|0;
 }
 $101 = HEAP32[690000>>2]|0;
 $102 = (($101) + 20|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ($103>>>0)<(0);
 if ($104) {
  $105 = HEAP32[628352>>2]|0;
  HEAP32[$0>>2] = $105;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($101,$$byval_copy1);
  $106 = HEAP32[690008>>2]|0;
  $107 = HEAP32[$106>>2]|0;
  $108 = (($107) + 32|0);
  $109 = HEAP32[$108>>2]|0;
  FUNCTION_TABLE_vi[$109 & 4095]($106);
  $110 = (0 + 32)|0;
  $111 = ($110*80)|0;
  $112 = (($111) + 24)|0;
  $113 = $110 << 6;
  $114 = (($112) + ($113))|0;
  $115 = HEAP32[628352>>2]|0;
  HEAP32[$0>>2] = $115;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $116 = (__Z15malloc_internaljj10MemLabelIdiPKci($114,16,$$byval_copy1,0,690112,210)|0);
  $117 = (($116) + 8|0);
  HEAP32[$117>>2] = 208;
  $118 = (($116) + 12|0);
  HEAP32[$118>>2] = 0;
  $119 = (($116) + 16|0);
  HEAP32[$119>>2] = 0;
  $120 = (($116) + 24|0);
  HEAP32[$116>>2] = $120;
  $121 = (($116) + ($112)|0);
  $122 = (($116) + 4|0);
  HEAP32[$122>>2] = $121;
  $123 = (($116) + 20|0);
  HEAP32[$123>>2] = $110;
  HEAP32[690000>>2] = $116;
  $124 = HEAP32[690016>>2]|0;
  $125 = HEAP32[$123>>2]|0;
  $126 = (($$byval_copy1) + 36|0);
  $127 = (($$byval_copy1) + 72|0);
  dest=$126+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  ;HEAP32[$$byval_copy1+0>>2]=0|0;HEAP32[$$byval_copy1+4>>2]=0|0;HEAP32[$$byval_copy1+8>>2]=0|0;HEAP32[$$byval_copy1+12>>2]=0|0;HEAP32[$$byval_copy1+16>>2]=0|0;HEAP32[$$byval_copy1+20>>2]=0|0;HEAP32[$$byval_copy1+24>>2]=0|0;HEAP32[$$byval_copy1+28>>2]=0|0;HEAP8[$$byval_copy1+32>>0]=0|0;
  HEAP32[$127>>2] = $125;
  $128 = (($$byval_copy1) + 76|0);
  HEAP32[$128>>2] = 0;
  $129 = (($$byval_copy1) + 80|0);
  HEAP32[$129>>2] = 0;
  $130 = (($$byval_copy1) + 84|0);
  HEAP8[$130>>0] = 1;
  $131 = HEAP32[$116>>2]|0;
  $132 = (($$byval_copy1) + 36|0);
  HEAP32[$132>>2] = $131;
  $133 = HEAP32[$122>>2]|0;
  $134 = (($$byval_copy1) + 40|0);
  HEAP32[$134>>2] = $133;
  $135 = (($$byval_copy1) + 60|0);
  HEAP32[$135>>2] = $125;
  $136 = HEAP32[$117>>2]|0;
  $137 = (($$byval_copy1) + 8|0);
  HEAP32[$137>>2] = $136;
  $138 = HEAP32[$118>>2]|0;
  $139 = (($$byval_copy1) + 16|0);
  HEAP32[$139>>2] = $138;
  $140 = HEAP32[$119>>2]|0;
  $141 = (($$byval_copy1) + 20|0);
  HEAP32[$141>>2] = $140;
  $142 = HEAP32[$124>>2]|0;
  $143 = (($142) + 328|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = (FUNCTION_TABLE_iii[$144 & 4095]($124,$$byval_copy1)|0);
  HEAP32[690008>>2] = $145;
 }
 $146 = HEAP32[689920>>2]|0;
 $147 = HEAP32[689912>>2]|0;
 $148 = $146;
 $149 = $147;
 $150 = (($148) - ($149))|0;
 $151 = $150 >> 2;
 $152 = ($151|0)==(0);
 if ($152) {
  STACKTOP = sp;return;
 }
 $153 = HEAP32[690000>>2]|0;
 $154 = HEAP32[$153>>2]|0;
 $155 = (($153) + 20|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = HEAP32[690008>>2]|0;
 __ZN5physx27PxVehicleSuspensionRaycastsEPNS_12PxBatchQueryEjPPNS_15PxVehicleWheelsEjPNS_18PxBatchQueryResultINS_12PxRaycastHitEEEPKb($157,$151,$147,$156,$154,0);
 $158 = HEAP32[689936>>2]|0;
 $159 = HEAP32[690016>>2]|0;
 $160 = HEAP32[$159>>2]|0;
 $161 = (($160) + 252|0);
 $162 = HEAP32[$161>>2]|0;
 FUNCTION_TABLE_vii[$162 & 4095]($1,$159);
 $163 = HEAP32[690024>>2]|0;
 __ZN5physx16PxVehicleUpdatesEfRKNS_6PxVec3ERKNS_43PxVehicleDrivableSurfaceToTireFrictionPairsEjPPNS_15PxVehicleWheelsEPNS_25PxVehicleWheelQueryResultEPNS_29PxVehicleConcurrentUpdateDataE($dt,$1,$163,$151,$147,$158,0);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager9onTriggerEPN5physx13PxTriggerPairEj($this,$pairs,$count) {
 $this = $this|0;
 $pairs = $pairs|0;
 $count = $count|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$ph6$i$i$i = 0, $$0$ph8$i$i$i = 0, $$01$i$i$i$i = 0, $$01$ph7$i$in$i$i = 0, $$014$i$in$i$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$019 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($count|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 72|0);
 $3 = (($this) + 76|0);
 $4 = (($this) + 68|0);
 $5 = (($this) + 788|0);
 $6 = (($this) + 788|0);
 $7 = (($this) + 784|0);
 $8 = (($this) + 792|0);
 $i$019 = 0;
 while(1) {
  $9 = ((($pairs) + (($i$019*24)|0)|0) + 20|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10 & 3;
  $12 = ($11<<24>>24)==(0);
  $13 = (($pairs) + (($i$019*24)|0)|0);
  do {
   if ($12) {
    $52 = HEAP32[$13>>2]|0;
    $53 = (($52) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ((($pairs) + (($i$019*24)|0)|0) + 8|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($56) + 8|0);
    $58 = HEAP32[$57>>2]|0;
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
    $59 = HEAP32[$2>>2]|0;
    $60 = HEAP32[$3>>2]|0;
    $61 = ($59|0)==($60|0);
    if ($61) {
     __ZNSt3__16vectorIN14PhysicsManager15RecordedTriggerENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($4,$0);
     $$pre = HEAP32[$2>>2]|0;
     $66 = $$pre;
    } else {
     $62 = ($59|0)==(0|0);
     if ($62) {
      $64 = 0;
     } else {
      ;HEAP32[$59+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$59+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$0+8>>2]|0;
      $$pre$i = HEAP32[$2>>2]|0;
      $64 = $$pre$i;
     }
     $63 = (($64) + 12|0);
     HEAP32[$2>>2] = $63;
     $66 = $63;
    }
    $65 = (($66) + -8|0);
    HEAP32[$65>>2] = $54;
    $67 = HEAP32[$2>>2]|0;
    $68 = (($67) + -4|0);
    HEAP32[$68>>2] = $58;
    $69 = ((($pairs) + (($i$019*24)|0)|0) + 16|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = HEAP32[$2>>2]|0;
    $72 = (($71) + -12|0);
    HEAP32[$72>>2] = $70;
   } else {
    $14 = ((($pairs) + (($i$019*24)|0)|0) + 8|0);
    $15 = HEAP32[$13>>2]|0;
    $16 = HEAP32[$14>>2]|0;
    $17 = HEAP32[$5>>2]|0;
    $18 = ($17|0)==(0|0);
    if (!($18)) {
     $$0$ph8$i$i$i = $6;$$01$ph7$i$in$i$i = $17;
     L8: while(1) {
      $$014$i$in$i$i = $$01$ph7$i$in$i$i;
      while(1) {
       $19 = (($$014$i$in$i$i) + 16|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = ($20>>>0)<($15>>>0);
       if (!($21)) {
        $22 = ($15>>>0)<($20>>>0);
        if ($22) {
         break;
        }
        $23 = (($$014$i$in$i$i) + 20|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = ($24>>>0)<($16>>>0);
        if (!($25)) {
         break;
        }
       }
       $28 = (($$014$i$in$i$i) + 4|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29|0)==(0|0);
       if ($30) {
        $$0$ph6$i$i$i = $$0$ph8$i$i$i;
        break L8;
       } else {
        $$014$i$in$i$i = $29;
       }
      }
      $26 = HEAP32[$$014$i$in$i$i>>2]|0;
      $27 = ($26|0)==(0|0);
      if ($27) {
       $$0$ph6$i$i$i = $$014$i$in$i$i;
       break;
      } else {
       $$0$ph8$i$i$i = $$014$i$in$i$i;$$01$ph7$i$in$i$i = $26;
      }
     }
     $31 = ($$0$ph6$i$i$i|0)==($6|0);
     if (!($31)) {
      $32 = (($$0$ph6$i$i$i) + 16|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($15>>>0)<($33>>>0);
      if (!($34)) {
       $35 = ($33>>>0)<($15>>>0);
       if (!($35)) {
        $36 = (($$0$ph6$i$i$i) + 20|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = ($16>>>0)<($37>>>0);
        if ($38) {
         break;
        }
       }
       $39 = (($$0$ph6$i$i$i) + 4|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = ($40|0)==(0|0);
       if ($41) {
        $$01$i$i$i$i = $$0$ph6$i$i$i;
        while(1) {
         $44 = (($$01$i$i$i$i) + 8|0);
         $45 = HEAP32[$44>>2]|0;
         $46 = HEAP32[$45>>2]|0;
         $47 = ($46|0)==($$01$i$i$i$i|0);
         if ($47) {
          $$0$i$i$i$i = $45;
          break;
         } else {
          $$01$i$i$i$i = $45;
         }
        }
       } else {
        $$0$i$i$i$i$i = $40;
        while(1) {
         $42 = HEAP32[$$0$i$i$i$i$i>>2]|0;
         $43 = ($42|0)==(0|0);
         if ($43) {
          $$0$i$i$i$i = $$0$i$i$i$i$i;
          break;
         } else {
          $$0$i$i$i$i$i = $42;
         }
        }
       }
       $48 = HEAP32[$7>>2]|0;
       $49 = ($48|0)==($$0$ph6$i$i$i|0);
       if ($49) {
        HEAP32[$7>>2] = $$0$i$i$i$i;
       }
       $50 = HEAP32[$8>>2]|0;
       $51 = (($50) + -1)|0;
       HEAP32[$8>>2] = $51;
       __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($17,$$0$ph6$i$i$i);
       __ZdlPv($$0$ph6$i$i$i);
      }
     }
    }
   }
  } while(0);
  $73 = (($i$019) + 1)|0;
  $exitcond = ($73|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$019 = $73;
  }
 }
 STACKTOP = sp;return;
}
function __ZThn24_N14PhysicsManager9onTriggerEPN5physx13PxTriggerPairEj($this,$pairs,$count) {
 $this = $this|0;
 $pairs = $pairs|0;
 $count = $count|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 __ZN14PhysicsManager9onTriggerEPN5physx13PxTriggerPairEj($0,$pairs,$count);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager9onContactERKN5physx19PxContactPairHeaderEPKNS0_13PxContactPairEj($this,$pairHeader,$pairs,$nbPairs) {
 $this = $this|0;
 $pairHeader = $pairHeader|0;
 $pairs = $pairs|0;
 $nbPairs = $nbPairs|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = Math_fround(0), $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__f$01$i$i$i$i$i$i = 0, $__f$01$i$i$i$i$i$i$i$i = 0, $__f$01$i$i$i$i$i$i1 = 0, $c$sroa$2 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond = 0, $exitcond48 = 0, $i$036 = 0, $n$021 = 0, $n$021$us = 0, $or$cond$i = 0, $or$cond2$i = 0, $userBuffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 896|0;
 $0 = sp + 876|0;
 $1 = sp + 864|0;
 $2 = sp + 24|0;
 $userBuffer = sp + 96|0;
 $c$sroa$2 = sp;
 $3 = (($pairHeader) + 14|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 3;
 $6 = ($5<<16>>16)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$pairHeader>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($pairHeader) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($nbPairs|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($2) + 60|0);
 $16 = (($2) + 64|0);
 $17 = (($2) + 68|0);
 $18 = (($this) + 84|0);
 $19 = (($this) + 88|0);
 $20 = (($this) + 80|0);
 $21 = (($7) + 4|0);
 $22 = ($7|0)==(0|0);
 $23 = (($11) + 4|0);
 $24 = ($11|0)==(0|0);
 $25 = (($1) + 4|0);
 $26 = (($1) + 8|0);
 $27 = (($0) + 4|0);
 $28 = (($0) + 8|0);
 $29 = (($c$sroa$2) + 12|0);
 $i$036 = 0;
 L7: while(1) {
  $30 = (($pairs) + ($i$036<<5)|0);
  $31 = ((($pairs) + ($i$036<<5)|0) + 20|0);
  $32 = HEAP16[$31>>1]|0;
  $33 = $32 & 3;
  $34 = ($33<<16>>16)==(0);
  if ($34) {
   $35 = HEAP32[$30>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    $104 = 0;
   } else {
    $37 = (($35) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    $104 = $38;
   }
   $39 = ((($pairs) + ($i$036<<5)|0) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    $106 = 0;
   } else {
    $42 = (($40) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $106 = $43;
   }
   dest=$2+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$15>>2] = $15;
   HEAP32[$16>>2] = $15;
   HEAP32[$17>>2] = 0;
   $44 = HEAP32[$18>>2]|0;
   $45 = HEAP32[$19>>2]|0;
   $46 = ($44|0)==($45|0);
   if ($46) {
    __THREW__ = 0;
    invoke_vii(3321,($20|0),($2|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     label = 26;
     break;
    }
   } else {
    $47 = ($44|0)==(0|0);
    if (!($47)) {
     dest=$44+0|0; src=$2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $48 = (($44) + 60|0);
     HEAP32[$48>>2] = $48;
     $49 = (($44) + 64|0);
     HEAP32[$49>>2] = $48;
     $50 = (($44) + 68|0);
     HEAP32[$50>>2] = 0;
     $51 = HEAP32[$16>>2]|0;
     $52 = ($51|0)==($15|0);
     if (!($52)) {
      $57 = $51;$60 = $48;$64 = 0;
      while(1) {
       __THREW__ = 0;
       $53 = (invoke_ii(2988,40)|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 14;
        break L7;
       }
       $56 = (($57) + 8|0);
       $58 = (($53) + 8|0);
       ;HEAP32[$58+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$58+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$58+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$58+12>>2]=HEAP32[$56+12>>2]|0;HEAP32[$58+16>>2]=HEAP32[$56+16>>2]|0;HEAP32[$58+20>>2]=HEAP32[$56+20>>2]|0;HEAP32[$58+24>>2]=HEAP32[$56+24>>2]|0;HEAP32[$58+28>>2]=HEAP32[$56+28>>2]|0;
       $59 = (($60) + 4|0);
       HEAP32[$59>>2] = $53;
       $61 = HEAP32[$48>>2]|0;
       HEAP32[$53>>2] = $61;
       HEAP32[$48>>2] = $53;
       $62 = (($53) + 4|0);
       HEAP32[$62>>2] = $48;
       $63 = (($64) + 1)|0;
       HEAP32[$50>>2] = $63;
       $65 = (($57) + 4|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = ($66|0)==($15|0);
       if ($67) {
        break;
       } else {
        $57 = $66;$60 = $53;$64 = $63;
       }
      }
     }
    }
    $82 = HEAP32[$18>>2]|0;
    $83 = (($82) + 72|0);
    HEAP32[$18>>2] = $83;
   }
   $86 = HEAP32[$17>>2]|0;
   $87 = ($86|0)==(0);
   if (!($87)) {
    $88 = HEAP32[$16>>2]|0;
    $89 = HEAP32[$15>>2]|0;
    $90 = (($89) + 4|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = HEAP32[$88>>2]|0;
    $93 = (($92) + 4|0);
    HEAP32[$93>>2] = $91;
    $94 = HEAP32[$88>>2]|0;
    $95 = HEAP32[$90>>2]|0;
    HEAP32[$95>>2] = $94;
    HEAP32[$17>>2] = 0;
    $96 = ($88|0)==($15|0);
    if (!($96)) {
     $__f$01$i$i$i$i$i$i1 = $88;
     while(1) {
      $97 = (($__f$01$i$i$i$i$i$i1) + 4|0);
      $98 = HEAP32[$97>>2]|0;
      __ZdlPv($__f$01$i$i$i$i$i$i1);
      $99 = ($98|0)==($15|0);
      if ($99) {
       break;
      } else {
       $__f$01$i$i$i$i$i$i1 = $98;
      }
     }
    }
   }
   $100 = HEAP32[$18>>2]|0;
   $101 = (($100) + -64|0);
   HEAP32[$101>>2] = $9;
   $102 = (($100) + -60|0);
   HEAP32[$102>>2] = $13;
   $103 = (($100) + -56|0);
   HEAP32[$103>>2] = $104;
   $105 = (($100) + -52|0);
   HEAP32[$105>>2] = $106;
   $107 = ((($pairs) + ($i$036<<5)|0) + 22|0);
   $108 = HEAP16[$107>>1]|0;
   $109 = $108&65535;
   $110 = (($100) + -72|0);
   HEAP32[$110>>2] = $109;
   $111 = ((($pairs) + ($i$036<<5)|0) + 16|0);
   $112 = HEAP16[$111>>1]|0;
   $113 = ($112<<16>>16)==(0);
   if ($113) {
    $183 = Math_fround(0.0);$185 = Math_fround(0.0);$187 = Math_fround(0.0);
   } else {
    $114 = HEAP16[$31>>1]|0;
    $115 = $114&65535;
    $116 = $115 & 1;
    $117 = ($116|0)!=(0);
    $118 = $115 & 2;
    $119 = ($118|0)!=(0);
    $120 = (($100) + -12|0);
    $121 = $117 ? 0 : $104;
    $122 = $119 ? 0 : $106;
    $123 = (__ZNK5physx13PxContactPair15extractContactsEPNS_18PxContactPairPointEj($30,$userBuffer,16)|0);
    $124 = ($123|0)==(0);
    if ($124) {
     $183 = Math_fround(0.0);$185 = Math_fround(0.0);$187 = Math_fround(0.0);
    } else {
     $125 = $115 & 32;
     $126 = (($100) + -4|0);
     $127 = ($125|0)==(0);
     if ($127) {
      $n$021$us = 0;
      while(1) {
       ;HEAP32[$c$sroa$2+0>>2]=0|0;HEAP32[$c$sroa$2+4>>2]=0|0;HEAP32[$c$sroa$2+8>>2]=0|0;HEAP32[$c$sroa$2+12>>2]=0|0;HEAP32[$c$sroa$2+16>>2]=0|0;HEAP32[$c$sroa$2+20>>2]=0|0;
       $128 = (($userBuffer) + (($n$021$us*48)|0)|0);
       ;HEAP32[$c$sroa$2+0>>2]=HEAP32[$128+0>>2]|0;HEAP32[$c$sroa$2+4>>2]=HEAP32[$128+4>>2]|0;HEAP32[$c$sroa$2+8>>2]=HEAP32[$128+8>>2]|0;
       $129 = ((($userBuffer) + (($n$021$us*48)|0)|0) + 16|0);
       ;HEAP32[$29+0>>2]=HEAP32[$129+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[$129+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$129+8>>2]|0;
       $130 = (__Znwj(40)|0);
       $131 = (($130) + 8|0);
       HEAP32[$131>>2] = $121;
       $132 = (($130) + 12|0);
       HEAP32[$132>>2] = $122;
       $133 = (($130) + 16|0);
       ;HEAP32[$133+0>>2]=HEAP32[$c$sroa$2+0>>2]|0;HEAP32[$133+4>>2]=HEAP32[$c$sroa$2+4>>2]|0;HEAP32[$133+8>>2]=HEAP32[$c$sroa$2+8>>2]|0;HEAP32[$133+12>>2]=HEAP32[$c$sroa$2+12>>2]|0;HEAP32[$133+16>>2]=HEAP32[$c$sroa$2+16>>2]|0;HEAP32[$133+20>>2]=HEAP32[$c$sroa$2+20>>2]|0;
       $134 = HEAP32[$120>>2]|0;
       $135 = (($134) + 4|0);
       HEAP32[$135>>2] = $130;
       $136 = HEAP32[$120>>2]|0;
       HEAP32[$130>>2] = $136;
       HEAP32[$120>>2] = $130;
       $137 = (($130) + 4|0);
       HEAP32[$137>>2] = $120;
       $138 = HEAP32[$126>>2]|0;
       $139 = (($138) + 1)|0;
       HEAP32[$126>>2] = $139;
       $140 = (($n$021$us) + 1)|0;
       $exitcond48 = ($140|0)==($123|0);
       if ($exitcond48) {
        $183 = Math_fround(0.0);$185 = Math_fround(0.0);$187 = Math_fround(0.0);
        break;
       } else {
        $n$021$us = $140;
       }
      }
     } else {
      $172 = Math_fround(0.0);$176 = Math_fround(0.0);$180 = Math_fround(0.0);$n$021 = 0;
      while(1) {
       ;HEAP32[$c$sroa$2+0>>2]=0|0;HEAP32[$c$sroa$2+4>>2]=0|0;HEAP32[$c$sroa$2+8>>2]=0|0;HEAP32[$c$sroa$2+12>>2]=0|0;HEAP32[$c$sroa$2+16>>2]=0|0;HEAP32[$c$sroa$2+20>>2]=0|0;
       $157 = (($userBuffer) + (($n$021*48)|0)|0);
       ;HEAP32[$c$sroa$2+0>>2]=HEAP32[$157+0>>2]|0;HEAP32[$c$sroa$2+4>>2]=HEAP32[$157+4>>2]|0;HEAP32[$c$sroa$2+8>>2]=HEAP32[$157+8>>2]|0;
       $158 = ((($userBuffer) + (($n$021*48)|0)|0) + 16|0);
       ;HEAP32[$29+0>>2]=HEAP32[$158+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[$158+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$158+8>>2]|0;
       $159 = (__Znwj(40)|0);
       $160 = (($159) + 8|0);
       HEAP32[$160>>2] = $121;
       $161 = (($159) + 12|0);
       HEAP32[$161>>2] = $122;
       $162 = (($159) + 16|0);
       ;HEAP32[$162+0>>2]=HEAP32[$c$sroa$2+0>>2]|0;HEAP32[$162+4>>2]=HEAP32[$c$sroa$2+4>>2]|0;HEAP32[$162+8>>2]=HEAP32[$c$sroa$2+8>>2]|0;HEAP32[$162+12>>2]=HEAP32[$c$sroa$2+12>>2]|0;HEAP32[$162+16>>2]=HEAP32[$c$sroa$2+16>>2]|0;HEAP32[$162+20>>2]=HEAP32[$c$sroa$2+20>>2]|0;
       $163 = HEAP32[$120>>2]|0;
       $164 = (($163) + 4|0);
       HEAP32[$164>>2] = $159;
       $165 = HEAP32[$120>>2]|0;
       HEAP32[$159>>2] = $165;
       HEAP32[$120>>2] = $159;
       $166 = (($159) + 4|0);
       HEAP32[$166>>2] = $120;
       $167 = HEAP32[$126>>2]|0;
       $168 = (($167) + 1)|0;
       HEAP32[$126>>2] = $168;
       $169 = ((($userBuffer) + (($n$021*48)|0)|0) + 32|0);
       $170 = Math_fround(HEAPF32[$169>>2]);
       $171 = Math_fround($172 + $170);
       $173 = ((($userBuffer) + (($n$021*48)|0)|0) + 36|0);
       $174 = Math_fround(HEAPF32[$173>>2]);
       $175 = Math_fround($176 + $174);
       $177 = ((($userBuffer) + (($n$021*48)|0)|0) + 40|0);
       $178 = Math_fround(HEAPF32[$177>>2]);
       $179 = Math_fround($180 + $178);
       $181 = (($n$021) + 1)|0;
       $exitcond = ($181|0)==($123|0);
       if ($exitcond) {
        $183 = $171;$185 = $175;$187 = $179;
        break;
       } else {
        $172 = $171;$176 = $175;$180 = $179;$n$021 = $181;
       }
      }
     }
    }
   }
   $182 = (($100) + -48|0);
   HEAPF32[$182>>2] = $183;
   $184 = (($100) + -44|0);
   HEAPF32[$184>>2] = $185;
   $186 = (($100) + -40|0);
   HEAPF32[$186>>2] = $187;
   $188 = (($100) + -36|0);
   HEAPF32[$188>>2] = Math_fround(0.0);
   $189 = (($100) + -32|0);
   HEAPF32[$189>>2] = Math_fround(0.0);
   $190 = (($100) + -28|0);
   HEAPF32[$190>>2] = Math_fround(0.0);
   $191 = HEAP16[$21>>1]|0;
   $192 = ($191<<16>>16)!=(5);
   $or$cond$i = $192 | $22;
   if ($or$cond$i) {
    $209 = Math_fround(0.0);$212 = Math_fround(0.0);$215 = Math_fround(0.0);
   } else {
    $193 = HEAP32[$7>>2]|0;
    $194 = (($193) + 152|0);
    $195 = HEAP32[$194>>2]|0;
    FUNCTION_TABLE_vii[$195 & 4095]($0,$7);
    $196 = Math_fround(HEAPF32[$0>>2]);
    $197 = Math_fround(HEAPF32[$27>>2]);
    $198 = Math_fround(HEAPF32[$28>>2]);
    $209 = $196;$212 = $197;$215 = $198;
   }
   $199 = HEAP16[$23>>1]|0;
   $200 = ($199<<16>>16)!=(5);
   $or$cond2$i = $200 | $24;
   if ($or$cond2$i) {
    $208 = Math_fround(0.0);$211 = Math_fround(0.0);$214 = Math_fround(0.0);
   } else {
    $201 = HEAP32[$11>>2]|0;
    $202 = (($201) + 152|0);
    $203 = HEAP32[$202>>2]|0;
    FUNCTION_TABLE_vii[$203 & 4095]($1,$11);
    $204 = Math_fround(HEAPF32[$1>>2]);
    $205 = Math_fround(HEAPF32[$25>>2]);
    $206 = Math_fround(HEAPF32[$26>>2]);
    $208 = $204;$211 = $205;$214 = $206;
   }
   $207 = Math_fround($209 - $208);
   $210 = Math_fround($212 - $211);
   $213 = Math_fround($215 - $214);
   $216 = (($100) + -24|0);
   HEAPF32[$216>>2] = $207;
   $217 = (($100) + -20|0);
   HEAPF32[$217>>2] = $210;
   $218 = (($100) + -16|0);
   HEAPF32[$218>>2] = $213;
  }
  $219 = (($i$036) + 1)|0;
  $220 = ($219>>>0)<($nbPairs>>>0);
  if ($220) {
   $i$036 = $219;
  } else {
   label = 37;
   break;
  }
 }
 if ((label|0) == 14) {
  $68 = ___cxa_find_matching_catch()|0;
  $69 = tempRet0;
  $70 = ($64|0)==(0);
  if ($70) {
   $eh$lpad$body$index4Z2D = $69;$eh$lpad$body$indexZ2D = $68;
  } else {
   $71 = HEAP32[$49>>2]|0;
   $72 = (($60) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = HEAP32[$71>>2]|0;
   $75 = (($74) + 4|0);
   HEAP32[$75>>2] = $73;
   $76 = HEAP32[$71>>2]|0;
   $77 = HEAP32[$72>>2]|0;
   HEAP32[$77>>2] = $76;
   HEAP32[$50>>2] = 0;
   $78 = ($71|0)==($48|0);
   if ($78) {
    $eh$lpad$body$index4Z2D = $69;$eh$lpad$body$indexZ2D = $68;
   } else {
    $__f$01$i$i$i$i$i$i$i$i = $71;
    while(1) {
     $79 = (($__f$01$i$i$i$i$i$i$i$i) + 4|0);
     $80 = HEAP32[$79>>2]|0;
     __ZdlPv($__f$01$i$i$i$i$i$i$i$i);
     $81 = ($80|0)==($48|0);
     if ($81) {
      $eh$lpad$body$index4Z2D = $69;$eh$lpad$body$indexZ2D = $68;
      break;
     } else {
      $__f$01$i$i$i$i$i$i$i$i = $80;
     }
    }
   }
  }
 }
 else if ((label|0) == 26) {
  $141 = ___cxa_find_matching_catch()|0;
  $142 = tempRet0;
  $eh$lpad$body$index4Z2D = $142;$eh$lpad$body$indexZ2D = $141;
 }
 else if ((label|0) == 37) {
  STACKTOP = sp;return;
 }
 $143 = HEAP32[$17>>2]|0;
 $144 = ($143|0)==(0);
 if ($144) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $145 = HEAP32[$16>>2]|0;
 $146 = HEAP32[$15>>2]|0;
 $147 = (($146) + 4|0);
 $148 = HEAP32[$147>>2]|0;
 $149 = HEAP32[$145>>2]|0;
 $150 = (($149) + 4|0);
 HEAP32[$150>>2] = $148;
 $151 = HEAP32[$145>>2]|0;
 $152 = HEAP32[$147>>2]|0;
 HEAP32[$152>>2] = $151;
 HEAP32[$17>>2] = 0;
 $153 = ($145|0)==($15|0);
 if ($153) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 } else {
  $__f$01$i$i$i$i$i$i = $145;
 }
 while(1) {
  $154 = (($__f$01$i$i$i$i$i$i) + 4|0);
  $155 = HEAP32[$154>>2]|0;
  __ZdlPv($__f$01$i$i$i$i$i$i);
  $156 = ($155|0)==($15|0);
  if ($156) {
   break;
  } else {
   $__f$01$i$i$i$i$i$i = $155;
  }
 }
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNK5physx13PxContactPair15extractContactsEPNS_18PxContactPairPointEj($this,$userBuffer,$bufferSize) {
 $this = $this|0;
 $userBuffer = $userBuffer|0;
 $bufferSize = $bufferSize|0;
 var $$1 = 0, $$in = 0, $$in$us = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0;
 var $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = Math_fround(0), $99 = 0, $faceIndices$0$off0$i$i = 0, $modify$0$off0$i$i = 0, $nbContacts$013 = 0, $nbContacts$1 = 0, $nbContacts$1$lcssa = 0, $nbContacts$1$us = 0, $or$cond = 0, $patchHeaderSize$0$i$i = 0, $pointSize$0$i$i = 0, $start$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(0);
 $5 = ($bufferSize|0)==(0);
 $or$cond = $4 | $5;
 if ($or$cond) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $6 = (($this) + 18|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7&65535;
 $9 = ($7<<16>>16)==(0);
 if ($9) {
  $faceIndices$0$off0$i$i = 0;$modify$0$off0$i$i = 0;$patchHeaderSize$0$i$i = 0;$pointSize$0$i$i = 0;$start$0$i$i = 0;
 } else {
  $10 = (($1) + 2|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = $11&65535;
  $13 = $12 & 2;
  $14 = ($13|0)!=(0);
  $15 = $12 & 1;
  $16 = ($15|0)!=(0);
  $17 = $13 << 3;
  $18 = $17 | 4;
  $19 = (($1) + ($18)|0);
  $20 = $14 ? 4 : 32;
  if ($14) {
   $faceIndices$0$off0$i$i = $16;$modify$0$off0$i$i = 1;$patchHeaderSize$0$i$i = $20;$pointSize$0$i$i = 72;$start$0$i$i = $19;
  } else {
   $21 = $15 << 3;
   $22 = $21 | 16;
   $faceIndices$0$off0$i$i = $16;$modify$0$off0$i$i = 0;$patchHeaderSize$0$i$i = $20;$pointSize$0$i$i = $22;$start$0$i$i = $19;
  }
 }
 $23 = (($8) + 15)|0;
 $24 = $23 & 131056;
 $25 = (($1) + ($24)|0);
 $26 = (($this) + 20|0);
 $27 = HEAP16[$26>>1]|0;
 $28 = $27&65535;
 $29 = $start$0$i$i;
 $30 = $1;
 $31 = (($29) - ($30))|0;
 $32 = ($31>>>0)<($8>>>0);
 if (!($32)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $33 = $28 & 32;
 $34 = $28 & 64;
 $35 = ($34|0)==(0);
 $36 = ($33|0)==(0);
 $42 = $start$0$i$i;$nbContacts$013 = 0;
 L11: while(1) {
  $41 = HEAP16[$42>>1]|0;
  $43 = $41&65535;
  $44 = Math_imul($43, $pointSize$0$i$i)|0;
  $$sum$i = (($44) + ($patchHeaderSize$0$i$i))|0;
  $38 = (($42) + ($$sum$i)|0);
  $45 = (($42) + ($patchHeaderSize$0$i$i)|0);
  $46 = (($42) + 4|0);
  L13: do {
   if ($35) {
    $48 = 0;$51 = $45;$nbContacts$1$us = $nbContacts$013;
    while(1) {
     $47 = ($48>>>0)<($43>>>0);
     if (!($47)) {
      $nbContacts$1$lcssa = $nbContacts$1$us;
      break L13;
     }
     $49 = (($48) + 1)|0;
     $50 = (($51) + ($pointSize$0$i$i)|0);
     $52 = Math_fround(HEAPF32[$51>>2]);
     $53 = (($userBuffer) + (($nbContacts$1$us*48)|0)|0);
     HEAPF32[$53>>2] = $52;
     $54 = (($51) + 4|0);
     $55 = Math_fround(HEAPF32[$54>>2]);
     $56 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 4|0);
     HEAPF32[$56>>2] = $55;
     $57 = (($51) + 8|0);
     $58 = Math_fround(HEAPF32[$57>>2]);
     $59 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 8|0);
     HEAPF32[$59>>2] = $58;
     $60 = (($51) + 12|0);
     $61 = Math_fround(HEAPF32[$60>>2]);
     $62 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 12|0);
     HEAPF32[$62>>2] = $61;
     $63 = (($51) + 24|0);
     $$in$us = $modify$0$off0$i$i ? $63 : $46;
     $64 = Math_fround(HEAPF32[$$in$us>>2]);
     $65 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 16|0);
     HEAPF32[$65>>2] = $64;
     $66 = (($$in$us) + 4|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 20|0);
     HEAPF32[$68>>2] = $67;
     $69 = (($$in$us) + 8|0);
     $70 = Math_fround(HEAPF32[$69>>2]);
     $71 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 24|0);
     HEAPF32[$71>>2] = $70;
     if ($faceIndices$0$off0$i$i) {
      $73 = (($51) + 16|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 28|0);
      HEAP32[$75>>2] = $74;
      $76 = (($51) + 20|0);
      $77 = HEAP32[$76>>2]|0;
      $79 = $77;
     } else {
      $72 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 28|0);
      HEAP32[$72>>2] = -1;
      $79 = -1;
     }
     $78 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 44|0);
     HEAP32[$78>>2] = $79;
     if ($36) {
      $88 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 32|0);
      HEAPF32[$88>>2] = Math_fround(0.0);
      $89 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 36|0);
      HEAPF32[$89>>2] = Math_fround(0.0);
      $90 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 40|0);
      HEAPF32[$90>>2] = Math_fround(0.0);
     } else {
      $80 = (($25) + ($nbContacts$1$us<<2)|0);
      $81 = Math_fround(HEAPF32[$80>>2]);
      $82 = Math_fround($81 * $64);
      $83 = Math_fround($81 * $67);
      $84 = Math_fround($81 * $70);
      $85 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 32|0);
      HEAPF32[$85>>2] = $82;
      $86 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 36|0);
      HEAPF32[$86>>2] = $83;
      $87 = ((($userBuffer) + (($nbContacts$1$us*48)|0)|0) + 40|0);
      HEAPF32[$87>>2] = $84;
     }
     $91 = (($nbContacts$1$us) + 1)|0;
     $92 = ($91|0)==($bufferSize|0);
     if ($92) {
      $$1 = $bufferSize;
      label = 25;
      break L11;
     } else {
      $48 = $49;$51 = $50;$nbContacts$1$us = $91;
     }
    }
   } else {
    $94 = 0;$97 = $45;$nbContacts$1 = $nbContacts$013;
    while(1) {
     $93 = ($94>>>0)<($43>>>0);
     if (!($93)) {
      $nbContacts$1$lcssa = $nbContacts$1;
      break L13;
     }
     $95 = (($94) + 1)|0;
     $96 = (($97) + ($pointSize$0$i$i)|0);
     $98 = Math_fround(HEAPF32[$97>>2]);
     $99 = (($userBuffer) + (($nbContacts$1*48)|0)|0);
     HEAPF32[$99>>2] = $98;
     $100 = (($97) + 4|0);
     $101 = Math_fround(HEAPF32[$100>>2]);
     $102 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 4|0);
     HEAPF32[$102>>2] = $101;
     $103 = (($97) + 8|0);
     $104 = Math_fround(HEAPF32[$103>>2]);
     $105 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 8|0);
     HEAPF32[$105>>2] = $104;
     $106 = (($97) + 12|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 12|0);
     HEAPF32[$108>>2] = $107;
     $109 = (($97) + 24|0);
     $$in = $modify$0$off0$i$i ? $109 : $46;
     $110 = Math_fround(HEAPF32[$$in>>2]);
     $111 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 16|0);
     HEAPF32[$111>>2] = $110;
     $112 = (($$in) + 4|0);
     $113 = Math_fround(HEAPF32[$112>>2]);
     $114 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 20|0);
     HEAPF32[$114>>2] = $113;
     $115 = (($$in) + 8|0);
     $116 = Math_fround(HEAPF32[$115>>2]);
     $117 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 24|0);
     HEAPF32[$117>>2] = $116;
     if ($faceIndices$0$off0$i$i) {
      $119 = (($97) + 20|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 28|0);
      HEAP32[$121>>2] = $120;
      $122 = (($97) + 16|0);
      $123 = HEAP32[$122>>2]|0;
      $125 = $123;
     } else {
      $118 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 28|0);
      HEAP32[$118>>2] = -1;
      $125 = -1;
     }
     $124 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 44|0);
     HEAP32[$124>>2] = $125;
     if ($36) {
      $134 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 32|0);
      HEAPF32[$134>>2] = Math_fround(0.0);
      $135 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 36|0);
      HEAPF32[$135>>2] = Math_fround(0.0);
      $136 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 40|0);
      HEAPF32[$136>>2] = Math_fround(0.0);
     } else {
      $126 = (($25) + ($nbContacts$1<<2)|0);
      $127 = Math_fround(HEAPF32[$126>>2]);
      $128 = Math_fround($127 * $110);
      $129 = Math_fround($127 * $113);
      $130 = Math_fround($127 * $116);
      $131 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 32|0);
      HEAPF32[$131>>2] = $128;
      $132 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 36|0);
      HEAPF32[$132>>2] = $129;
      $133 = ((($userBuffer) + (($nbContacts$1*48)|0)|0) + 40|0);
      HEAPF32[$133>>2] = $130;
     }
     $137 = (($nbContacts$1) + 1)|0;
     $138 = ($137|0)==($bufferSize|0);
     if ($138) {
      $$1 = $bufferSize;
      label = 25;
      break L11;
     } else {
      $94 = $95;$97 = $96;$nbContacts$1 = $137;
     }
    }
   }
  } while(0);
  $37 = $38;
  $39 = (($37) - ($30))|0;
  $40 = ($39>>>0)<($8>>>0);
  if ($40) {
   $42 = $38;$nbContacts$013 = $nbContacts$1$lcssa;
  } else {
   $$1 = $nbContacts$1$lcssa;
   label = 25;
   break;
  }
 }
 if ((label|0) == 25) {
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZThn24_N14PhysicsManager9onContactERKN5physx19PxContactPairHeaderEPKNS0_13PxContactPairEj($this,$pairHeader,$pairs,$nbPairs) {
 $this = $this|0;
 $pairHeader = $pairHeader|0;
 $pairs = $pairs|0;
 $nbPairs = $nbPairs|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 __ZN14PhysicsManager9onContactERKN5physx19PxContactPairHeaderEPKNS0_13PxContactPairEj($0,$pairHeader,$pairs,$nbPairs);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager17onConstraintBreakEPN5physx16PxConstraintInfoEj($this,$constraints,$count) {
 $this = $this|0;
 $constraints = $constraints|0;
 $count = $count|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $jointbreak = 0, $pos$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp + 12|0;
 $jointbreak = sp;
 $1 = ($count|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($jointbreak) + 8|0);
 $3 = (($jointbreak) + 8|0);
 $4 = (($jointbreak) + 4|0);
 $5 = (($this) + 96|0);
 $6 = (($this) + 100|0);
 $7 = (($this) + 92|0);
 $i$01 = 0;
 while(1) {
  HEAP32[$2>>2] = 0;
  $8 = ((($constraints) + (($i$01*12)|0)|0) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  do {
   if ($12) {
    HEAP32[$3>>2] = 0;
   } else {
    $13 = (($11) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$3>>2] = $14;
    $15 = ($14|0)==(0);
    if (!($15)) {
     HEAP32[$0>>2] = $14;
     $16 = HEAP32[560624>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 14;
     } else {
      $18 = (($16) + 36|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = (($16) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($19|0)==($21|0);
      do {
       if ($22) {
        $23 = (($16) + 28|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = (($16) + 32|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = (($24) + ($26<<3)|0);
        $43 = $27;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$16,$0);
        $28 = HEAP32[$pos$i$i$i$i>>2]|0;
        $29 = ($28|0)==(-1);
        $30 = (($16) + 28|0);
        $31 = HEAP32[$30>>2]|0;
        if ($29) {
         $32 = (($16) + 32|0);
         $33 = HEAP32[$32>>2]|0;
         $34 = (($31) + ($33<<3)|0);
         $43 = $34;
         break;
        } else {
         $35 = (($31) + ($28<<3)|0);
         $43 = $35;
         break;
        }
       }
      } while(0);
      $36 = HEAP32[560624>>2]|0;
      $37 = (($36) + 28|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 32|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($38) + ($40<<3)|0);
      $42 = ($43|0)==($41|0);
      if ($42) {
       label = 14;
      } else {
       $44 = (($43) + 4|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = ($45|0)==(0|0);
       if ($46) {
        label = 14;
       }
      }
     }
     if ((label|0) == 14) {
      label = 0;
      $47 = HEAP32[$3>>2]|0;
      $48 = (__Z31ReadObjectFromPersistentManageri($47)|0);
      $49 = ($48|0)==(0|0);
      if ($49) {
       break;
      }
     }
     $50 = (($constraints) + (($i$01*12)|0)|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = HEAP32[$51>>2]|0;
     $53 = (($52) + 60|0);
     $54 = HEAP32[$53>>2]|0;
     FUNCTION_TABLE_viii[$54 & 4095]($51,$jointbreak,$4);
     $55 = HEAP32[$5>>2]|0;
     $56 = HEAP32[$6>>2]|0;
     $57 = ($55|0)==($56|0);
     if ($57) {
      __ZNSt3__16vectorIN14PhysicsManager18RecordedJointBreakENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($7,$jointbreak);
      break;
     }
     $58 = ($55|0)==(0|0);
     if ($58) {
      $72 = 0;
     } else {
      $59 = $jointbreak;
      $60 = $59;
      $61 = HEAP32[$60>>2]|0;
      $62 = (($59) + 4)|0;
      $63 = $62;
      $64 = HEAP32[$63>>2]|0;
      $65 = $55;
      $66 = $65;
      HEAP32[$66>>2] = $61;
      $67 = (($65) + 4)|0;
      $68 = $67;
      HEAP32[$68>>2] = $64;
      $69 = HEAP32[$2>>2]|0;
      $70 = (($55) + 8|0);
      HEAP32[$70>>2] = $69;
      $$pre$i = HEAP32[$5>>2]|0;
      $72 = $$pre$i;
     }
     $71 = (($72) + 12|0);
     HEAP32[$5>>2] = $71;
    }
   }
  } while(0);
  $73 = (($i$01) + 1)|0;
  $exitcond = ($73|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $73;
  }
 }
 STACKTOP = sp;return;
}
function __ZThn24_N14PhysicsManager17onConstraintBreakEPN5physx16PxConstraintInfoEj($this,$constraints,$count) {
 $this = $this|0;
 $constraints = $constraints|0;
 $count = $count|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 __ZN14PhysicsManager17onConstraintBreakEPN5physx16PxConstraintInfoEj($0,$constraints,$count);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager6onWakeEPPN5physx7PxActorEj($this,$actors,$count) {
 $this = $this|0;
 $actors = $actors|0;
 $count = $count|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn24_N14PhysicsManager6onWakeEPPN5physx7PxActorEj($this,$actors,$count) {
 $this = $this|0;
 $actors = $actors|0;
 $count = $count|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager7onSleepEPPN5physx7PxActorEj($this,$actors,$count) {
 $this = $this|0;
 $actors = $actors|0;
 $count = $count|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZThn24_N14PhysicsManager7onSleepEPPN5physx7PxActorEj($this,$actors,$count) {
 $this = $this|0;
 $actors = $actors|0;
 $count = $count|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager15InitializeClassEv() {
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $s = 0, $sCookingParams = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $s = sp + 44|0;
 $sCookingParams = sp;
 __Z27RegisterAllowNameConversionPKcS0_S0_(690472,690032,690056);
 __ZN12PhysXRaycast15InitializeClassEv();
 $0 = (__Z18PxCreateFoundationjRN5physx19PxAllocatorCallbackERNS_15PxErrorCallbackE(50528512,689896,689888)|0);
 HEAP32[690080>>2] = $0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(690088,0,690112,689,32785,0,0,0);
  $$pre = HEAP32[690080>>2]|0;
  $4 = $$pre;
 } else {
  $4 = $0;
 }
 HEAPF32[$s>>2] = Math_fround(1.0);
 $2 = (($s) + 4|0);
 HEAPF32[$2>>2] = Math_fround(1000.0);
 $3 = (($s) + 8|0);
 HEAPF32[$3>>2] = Math_fround(10.0);
 $5 = (__Z19PxCreateBasePhysicsjRN5physx12PxFoundationERKNS_17PxTolerancesScaleEbPNS_20PxProfileZoneManagerE(50528512,$4,$s,0,0)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  HEAP32[690120>>2] = 0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(690088,0,690112,704,32785,0,0,0);
  $$pre3 = HEAP32[690120>>2]|0;
  $7 = $$pre3;
 } else {
  __Z23PxRegisterArticulationsRN5physx9PxPhysicsE($5);
  __Z22PxRegisterHeightFieldsRN5physx9PxPhysicsE($5);
  __Z15PxRegisterClothRN5physx9PxPhysicsE($5);
  __Z19PxRegisterParticlesRN5physx9PxPhysicsE($5);
  HEAP32[690120>>2] = $5;
  $7 = $5;
 }
 $8 = (__Z16PxInitExtensionsRN5physx9PxPhysicsE($7)|0);
 if (!($8)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(690128,0,690112,707,32785,0,0,0);
 }
 $9 = (($sCookingParams) + 4|0);
 $10 = Math_fround(HEAPF32[$s>>2]);
 $11 = Math_fround($10 * Math_fround(0.0250000003725290298462));
 HEAPF32[$9>>2] = $11;
 $12 = (($sCookingParams) + 8|0);
 $13 = Math_fround($10 * Math_fround(0.0599999986588954925537));
 $14 = Math_fround($10 * $13);
 HEAPF32[$12>>2] = $14;
 $15 = (($sCookingParams) + 12|0);
 HEAP8[$15>>0] = 0;
 $16 = (($sCookingParams) + 13|0);
 HEAP8[$16>>0] = 0;
 $17 = (($sCookingParams) + 16|0);
 ;HEAP32[$17+0>>2]=HEAP32[$s+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$s+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$s+8>>2]|0;
 $18 = (($sCookingParams) + 28|0);
 HEAP32[$18>>2] = 0;
 $19 = (($sCookingParams) + 32|0);
 HEAP32[$19>>2] = 0;
 $20 = (($sCookingParams) + 36|0);
 HEAPF32[$20>>2] = Math_fround(0.0);
 $21 = (($sCookingParams) + 40|0);
 HEAPF32[$21>>2] = Math_fround(0.550000011920928955078);
 HEAP32[$sCookingParams>>2] = 0;
 $22 = HEAP32[690080>>2]|0;
 $23 = (__Z15PxCreateCookingjRN5physx12PxFoundationERKNS_15PxCookingParamsE(50528512,$22,$sCookingParams)|0);
 HEAP32[690160>>2] = $23;
 $24 = HEAP32[690120>>2]|0;
 (__ZN5physx16PxInitVehicleSDKERNS_9PxPhysicsEPNS_23PxSerializationRegistryE($24,0)|0);
 __ZN14PhysicsManager19CreateDynamicsSceneEb(0);
 __ZN19CharacterController23CreateControllerManagerEv();
 HEAP32[579376>>2] = 158;
 HEAP32[579384>>2] = 160;
 HEAP32[579392>>2] = 154;
 HEAP32[579400>>2] = 163;
 HEAP32[579408>>2] = 155;
 $25 = (__ZN15GlobalCallbacks3GetEv()|0);
 $i$01$i = 0;
 while(1) {
  $28 = ((($25) + ($i$01$i<<2)|0) + 128|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  $27 = (($i$01$i) + 1)|0;
  if ($30) {
   break;
  }
  $26 = ($27|0)<(16);
  if ($26) {
   $i$01$i = $27;
  } else {
   label = 12;
   break;
  }
 }
 if ((label|0) == 12) {
  STACKTOP = sp;return;
 }
 HEAP32[$28>>2] = 199;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager19CreateDynamicsSceneEb($enableAdaptiveForce) {
 $enableAdaptiveForce = $enableAdaptiveForce|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $materials = 0, $sceneDesc = 0, $storemerge = 0, $types = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy = sp + 192|0;
 $0 = sp;
 $sceneDesc = sp + 8|0;
 $1 = sp + 168|0;
 $materials = sp + 180|0;
 $types = sp + 184|0;
 $2 = HEAP32[690120>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = (($sceneDesc) + 80|0);
 dest=$sceneDesc+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $8 = Math_fround(HEAPF32[$6>>2]);
 $9 = Math_fround($8 * Math_fround(0.00999999977648258209228));
 HEAPF32[$7>>2] = $9;
 $10 = (($sceneDesc) + 84|0);
 HEAP32[$10>>2] = 0;
 $11 = (($sceneDesc) + 88|0);
 $12 = Math_fround(HEAPF32[$6>>2]);
 $13 = Math_fround($12 * Math_fround(0.0250000003725290298462));
 HEAPF32[$11>>2] = $13;
 $14 = (($sceneDesc) + 92|0);
 $15 = (($6) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * Math_fround(0.20000000298023223877));
 HEAPF32[$14>>2] = $17;
 $18 = (($sceneDesc) + 96|0);
 $19 = Math_fround(HEAPF32[$6>>2]);
 $20 = Math_fround($19 * Math_fround(0.0399999991059303283691));
 HEAPF32[$18>>2] = $20;
 $21 = (($sceneDesc) + 100|0);
 $22 = (($sceneDesc) + 104|0);
 $23 = (($sceneDesc) + 108|0);
 HEAP32[$23>>2] = 0;
 $24 = (($sceneDesc) + 112|0);
 HEAP32[$24>>2] = 0;
 $25 = (($sceneDesc) + 116|0);
 HEAP32[$25>>2] = 1;
 $26 = (($sceneDesc) + 120|0);
 HEAP32[$26>>2] = 1;
 $27 = (($sceneDesc) + 124|0);
 HEAP32[$27>>2] = 100;
 $28 = (($sceneDesc) + 128|0);
 HEAP32[$28>>2] = 0;
 $29 = (($sceneDesc) + 132|0);
 HEAP32[$29>>2] = 128;
 $30 = (($sceneDesc) + 136|0);
 HEAP32[$30>>2] = 0;
 $31 = (($sceneDesc) + 140|0);
 HEAP32[$31>>2] = 65536;
 $32 = (($sceneDesc) + 144|0);
 HEAP32[$32>>2] = 8192;
 $33 = (($sceneDesc) + 148|0);
 HEAP32[$33>>2] = 1;
 $34 = (($sceneDesc) + 152|0);
 HEAP32[$34>>2] = 0;
 $35 = (($sceneDesc) + 156|0);
 HEAPF32[$35>>2] = Math_fround(0.399999976158142089844);
 HEAPF32[$sceneDesc>>2] = Math_fround(0.0);
 $36 = (($sceneDesc) + 4|0);
 HEAPF32[$36>>2] = Math_fround(-9.81000041961669921875);
 $37 = (($sceneDesc) + 8|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 HEAP32[$22>>2] = 689904;
 $38 = (($sceneDesc) + 32|0);
 HEAP32[$38>>2] = 31;
 $storemerge = $enableAdaptiveForce ? 20 : 4;
 HEAP16[$21>>1] = $storemerge;
 $39 = HEAP32[690120>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 92|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (FUNCTION_TABLE_iii[$42 & 4095]($39,$sceneDesc)|0);
 HEAP32[690016>>2] = $43;
 __ZN19CharacterController23UpdateControllerManagerEv();
 $44 = HEAP32[690016>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 248|0);
 $47 = HEAP32[$46>>2]|0;
 HEAPF32[$1>>2] = Math_fround(0.0);
 $48 = (($1) + 4|0);
 HEAPF32[$48>>2] = Math_fround(-9.81000041961669921875);
 $49 = (($1) + 8|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 FUNCTION_TABLE_vii[$47 & 4095]($44,$1);
 HEAP32[690168>>2] = 0;
 $50 = HEAP32[689872>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  $52 = HEAP32[690120>>2]|0;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($53) + 144|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (FUNCTION_TABLE_iifff[$55 & 3]($52,Math_fround(1.0),Math_fround(1.0),Math_fround(0.00999999977648258209228))|0);
  HEAP32[689872>>2] = $56;
 }
 $57 = HEAP32[689880>>2]|0;
 $58 = ($57|0)==(0|0);
 if ($58) {
  $59 = HEAP32[690120>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 144|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_iifff[$62 & 3]($59,Math_fround(0.0),Math_fround(0.0),Math_fround(1.0))|0);
  HEAP32[689880>>2] = $63;
  $64 = HEAP32[$63>>2]|0;
  $65 = (($64) + 52|0);
  $66 = HEAP32[$65>>2]|0;
  FUNCTION_TABLE_viii[$66 & 4095]($63,1,1);
 }
 $67 = HEAP32[689928>>2]|0;
 $68 = HEAP32[689912>>2]|0;
 $69 = $67;
 $70 = $68;
 $71 = (($69) - ($70))|0;
 $72 = $71 >> 2;
 $73 = ($72>>>0)<(256);
 if ($73) {
  $74 = HEAP32[689920>>2]|0;
  $75 = $74;
  $76 = (($75) - ($70))|0;
  $77 = $76 >> 2;
  $78 = (__Znwj(1024)|0);
  $79 = (($78) + ($77<<2)|0);
  $80 = (($78) + 1024|0);
  _memcpy(($78|0),($68|0),($76|0))|0;
  HEAP32[689912>>2] = $78;
  HEAP32[689920>>2] = $79;
  HEAP32[689928>>2] = $80;
  $81 = ($68|0)==(0|0);
  if (!($81)) {
   __ZdlPv($68);
  }
 }
 $82 = HEAP32[689952>>2]|0;
 $83 = HEAP32[689936>>2]|0;
 $84 = $82;
 $85 = $83;
 $86 = (($84) - ($85))|0;
 $87 = $86 >> 3;
 $88 = ($87>>>0)<(256);
 if ($88) {
  $89 = HEAP32[689944>>2]|0;
  $90 = $89;
  $91 = (($90) - ($85))|0;
  $92 = $91 >> 3;
  $93 = (__Znwj(2048)|0);
  $94 = (($93) + ($92<<3)|0);
  $95 = (($93) + 2048|0);
  _memcpy(($93|0),($83|0),($91|0))|0;
  HEAP32[689936>>2] = $93;
  HEAP32[689944>>2] = $94;
  HEAP32[689952>>2] = $95;
  $96 = ($83|0)==(0|0);
  if (!($96)) {
   __ZdlPv($83);
  }
 }
 $97 = HEAP32[689976>>2]|0;
 $98 = HEAP32[689960>>2]|0;
 $99 = $97;
 $100 = $98;
 $101 = (($99) - ($100))|0;
 $102 = $101 >> 2;
 $103 = ($102>>>0)<(256);
 if ($103) {
  $104 = HEAP32[689968>>2]|0;
  $105 = $104;
  $106 = (($105) - ($100))|0;
  $107 = $106 >> 2;
  $108 = (__Znwj(1024)|0);
  $109 = (($108) + ($107<<2)|0);
  $110 = (($108) + 1024|0);
  _memcpy(($108|0),($98|0),($106|0))|0;
  HEAP32[689960>>2] = $108;
  HEAP32[689968>>2] = $109;
  HEAP32[689976>>2] = $110;
  $111 = ($98|0)==(0|0);
  if (!($111)) {
   __ZdlPv($98);
  }
 }
 __ZN14dynamic_bitset6resizeEjb(689984,256,0);
 $112 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $112;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $113 = (__Z15malloc_internaljj10MemLabelIdiPKci(18456,16,$$byval_copy,0,690112,210)|0);
 $114 = (($113) + 8|0);
 HEAP32[$114>>2] = 208;
 $115 = (($113) + 12|0);
 HEAP32[$115>>2] = 0;
 $116 = (($113) + 16|0);
 HEAP32[$116>>2] = 0;
 $117 = (($113) + 24|0);
 HEAP32[$113>>2] = $117;
 $118 = (($113) + 10264|0);
 $119 = (($113) + 4|0);
 HEAP32[$119>>2] = $118;
 $120 = (($113) + 20|0);
 HEAP32[$120>>2] = 128;
 HEAP32[690000>>2] = $113;
 $121 = HEAP32[690016>>2]|0;
 $122 = HEAP32[$120>>2]|0;
 $123 = (($$byval_copy) + 36|0);
 $124 = (($$byval_copy) + 72|0);
 dest=$123+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$$byval_copy+0>>2]=0|0;HEAP32[$$byval_copy+4>>2]=0|0;HEAP32[$$byval_copy+8>>2]=0|0;HEAP32[$$byval_copy+12>>2]=0|0;HEAP32[$$byval_copy+16>>2]=0|0;HEAP32[$$byval_copy+20>>2]=0|0;HEAP32[$$byval_copy+24>>2]=0|0;HEAP32[$$byval_copy+28>>2]=0|0;HEAP8[$$byval_copy+32>>0]=0|0;
 HEAP32[$124>>2] = $122;
 $125 = (($$byval_copy) + 76|0);
 HEAP32[$125>>2] = 0;
 $126 = (($$byval_copy) + 80|0);
 HEAP32[$126>>2] = 0;
 $127 = (($$byval_copy) + 84|0);
 HEAP8[$127>>0] = 1;
 $128 = HEAP32[$113>>2]|0;
 $129 = (($$byval_copy) + 36|0);
 HEAP32[$129>>2] = $128;
 $130 = HEAP32[$119>>2]|0;
 $131 = (($$byval_copy) + 40|0);
 HEAP32[$131>>2] = $130;
 $132 = (($$byval_copy) + 60|0);
 HEAP32[$132>>2] = $122;
 $133 = HEAP32[$114>>2]|0;
 $134 = (($$byval_copy) + 8|0);
 HEAP32[$134>>2] = $133;
 $135 = HEAP32[$115>>2]|0;
 $136 = (($$byval_copy) + 16|0);
 HEAP32[$136>>2] = $135;
 $137 = HEAP32[$116>>2]|0;
 $138 = (($$byval_copy) + 20|0);
 HEAP32[$138>>2] = $137;
 $139 = HEAP32[$121>>2]|0;
 $140 = (($139) + 328|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = (FUNCTION_TABLE_iii[$141 & 4095]($121,$$byval_copy)|0);
 HEAP32[690008>>2] = $142;
 $143 = (__ZN5physx43PxVehicleDrivableSurfaceToTireFrictionPairs8allocateEjj(1,1)|0);
 HEAP32[690024>>2] = $143;
 HEAP32[$materials>>2] = 0;
 HEAP32[$types>>2] = 0;
 __ZN5physx43PxVehicleDrivableSurfaceToTireFrictionPairs5setupEjjPPKNS_10PxMaterialEPKNS_28PxVehicleDrivableSurfaceTypeE($143,1,1,$materials,$types);
 STACKTOP = sp;return;
}
function __ZZN14PhysicsManager15InitializeClassEvEN18PhysicsFixedUpdate7ForwardEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(9)|0);
 __ZN14PhysicsManager11FixedUpdateEv($0);
 STACKTOP = sp;return;
}
function __ZZN14PhysicsManager15InitializeClassEvEN13PhysicsUpdate7ForwardE_0v() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(9)|0);
 __ZN14PhysicsManager6UpdateEv($0);
 STACKTOP = sp;return;
}
function __ZZN14PhysicsManager15InitializeClassEvEN24PhysicsRefreshWhenPaused7ForwardE_1v() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZN14PhysicsManager15InitializeClassEvEN25PhysicsSkinnedClothUpdate7ForwardE_2v() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(9)|0);
 __ZN14PhysicsManager18SkinnedClothUpdateEv($0);
 STACKTOP = sp;return;
}
function __ZZN14PhysicsManager15InitializeClassEvEN41PhysicsResetInterpolatedTransformPosition7ForwardE_3v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i = 0, $rot$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i = sp + 16|0;
 $rot$i = sp;
 $0 = (__Z21GetManagerFromContexti(9)|0);
 $1 = (($0) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 120|0);
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $6 = $2;
 }
 while(1) {
  $5 = (($6) + 36|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = (__ZN9Rigidbody10IsSleepingEv($7)|0);
  if (!($8)) {
   $9 = (($7) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($10)|0);
   __ZNK9Rigidbody11GetPositionEv($pos$i,$7);
   __ZNK9Rigidbody11GetRotationEv($rot$i,$7);
   __ZN9Transform45SetPositionAndRotationSafeWithoutNotificationERK8Vector3fRK11Quaternionf($11,$pos$i,$rot$i);
  }
  $12 = (($6) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($3|0);
  if ($14) {
   break;
  } else {
   $6 = $13;
  }
 }
 STACKTOP = sp;return;
}
function __ZZN14PhysicsManager15InitializeClassEvEN14didUnloadScene7ForwardE_4v() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(9)|0);
 __ZN14PhysicsManager13RecreateSceneEv($0);
 STACKTOP = sp;return;
}
function __Z14GetDynamicsSDKv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[690120>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN14PhysicsManager20CleanupDynamicsSceneEv() {
 var $$byval_copy1 = 0, $$pre = 0, $$pre23 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i1 = 0;
 var $__new_last2$i$i$i8 = 0, $i$017 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i2 = 0, $scevgep$i$i$i9 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i13 = 0, $scevgep4$i$i$i6 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i11 = 0, $uglygep$i$i$i4 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i12 = 0, $uglygep3$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[690000>>2]|0;
 $2 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy1);
 HEAP32[690000>>2] = 0;
 $3 = HEAP32[690008>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vi[$6 & 4095]($3);
 HEAP32[690008>>2] = 0;
 $7 = HEAP32[690024>>2]|0;
 __ZN5physx43PxVehicleDrivableSurfaceToTireFrictionPairs7releaseEv($7);
 HEAP32[690024>>2] = 0;
 $8 = HEAP32[689920>>2]|0;
 $9 = HEAP32[689912>>2]|0;
 $10 = ($8|0)==($9|0);
 if (!($10)) {
  $12 = $9;$55 = $8;$i$017 = 0;
  while(1) {
   $11 = (($12) + ($i$017<<2)|0);
   $13 = HEAP32[$11>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $17 = $55;$19 = $12;
   } else {
    __ZN5physx16PxVehicleNoDrive4freeEv($13);
    $$pre = HEAP32[689920>>2]|0;
    $$pre23 = HEAP32[689912>>2]|0;
    $17 = $$pre;$19 = $$pre23;
   }
   $15 = (($i$017) + 1)|0;
   $16 = $17;
   $18 = $19;
   $20 = (($16) - ($18))|0;
   $21 = $20 >> 2;
   $22 = ($15>>>0)<($21>>>0);
   if ($22) {
    $12 = $19;$55 = $17;$i$017 = $15;
   } else {
    break;
   }
  }
  $23 = ($17|0)==($19|0);
  if (!($23)) {
   $scevgep$i$i$i = (($17) + -4|0);
   $24 = (0 - ($18))|0;
   $uglygep$i$i$i = (($scevgep$i$i$i) + ($24)|0);
   $uglygep3$i$i$i = $uglygep$i$i$i;
   $25 = $uglygep3$i$i$i >>> 2;
   $26 = $25 ^ -1;
   $scevgep4$i$i$i = (($17) + ($26<<2)|0);
   HEAP32[689920>>2] = $scevgep4$i$i$i;
  }
 }
 $27 = HEAP32[689936>>2]|0;
 $28 = HEAP32[689944>>2]|0;
 $29 = ($28|0)==($27|0);
 if (!($29)) {
  $__new_last2$i$i$i1 = $27;
  $scevgep$i$i$i2 = (($28) + -8|0);
  $30 = (0 - ($__new_last2$i$i$i1))|0;
  $uglygep$i$i$i4 = (($scevgep$i$i$i2) + ($30)|0);
  $uglygep3$i$i$i5 = $uglygep$i$i$i4;
  $31 = $uglygep3$i$i$i5 >>> 3;
  $32 = $31 ^ -1;
  $scevgep4$i$i$i6 = (($28) + ($32<<3)|0);
  HEAP32[689944>>2] = $scevgep4$i$i$i6;
 }
 $33 = HEAP32[689960>>2]|0;
 $34 = HEAP32[689968>>2]|0;
 $35 = ($34|0)==($33|0);
 if (!($35)) {
  $__new_last2$i$i$i8 = $33;
  $scevgep$i$i$i9 = (($34) + -4|0);
  $36 = (0 - ($__new_last2$i$i$i8))|0;
  $uglygep$i$i$i11 = (($scevgep$i$i$i9) + ($36)|0);
  $uglygep3$i$i$i12 = $uglygep$i$i$i11;
  $37 = $uglygep3$i$i$i12 >>> 2;
  $38 = $37 ^ -1;
  $scevgep4$i$i$i13 = (($34) + ($38<<2)|0);
  HEAP32[689968>>2] = $scevgep4$i$i$i13;
 }
 $39 = HEAP32[((689984 + 4|0))>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = HEAP32[689984>>2]|0;
  HEAP32[$0>>2] = $41;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($39,$$byval_copy1);
  HEAP32[((689984 + 4|0))>>2] = 0;
  HEAP32[((689984 + 8|0))>>2] = 0;
  HEAP32[((689984 + 12|0))>>2] = 0;
 }
 $42 = HEAP32[690168>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $51 = HEAP32[690016>>2]|0;
  $52 = HEAP32[$51>>2]|0;
  $53 = (($52) + 8|0);
  $54 = HEAP32[$53>>2]|0;
  FUNCTION_TABLE_vi[$54 & 4095]($51);
  HEAP32[690016>>2] = 0;
  STACKTOP = sp;return;
 }
 $44 = HEAP32[$42>>2]|0;
 $45 = (($44) + 236|0);
 $46 = HEAP32[$45>>2]|0;
 (FUNCTION_TABLE_iiii[$46 & 2047]($42,0,0)|0);
 $47 = HEAP32[690168>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_vi[$50 & 4095]($47);
 HEAP32[690168>>2] = 0;
 $51 = HEAP32[690016>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 FUNCTION_TABLE_vi[$54 & 4095]($51);
 HEAP32[690016>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager12CleanupClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i3 = 0, $i$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $materialsTemp = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i6 = 0;
 var $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $materialsTemp = sp;
 __ZN12PhysXRaycast12CleanupClassEv();
 $0 = HEAP32[690120>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __ZN19CharacterController24CleanupControllerManagerEv();
 HEAP32[$materialsTemp>>2] = 0;
 $2 = (($materialsTemp) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($materialsTemp) + 8|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,134,($materialsTemp|0),0)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L4: do {
  if ($5) {
   label = 19;
  } else {
   $6 = HEAP32[$2>>2]|0;
   $7 = HEAP32[$materialsTemp>>2]|0;
   $8 = ($6|0)==($7|0);
   L6: do {
    if (!($8)) {
     $10 = $7;$i$01$i = 0;
     while(1) {
      $9 = (($10) + ($i$01$i<<2)|0);
      $11 = HEAP32[$9>>2]|0;
      __THREW__ = 0;
      invoke_vi(3633,($11|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      $14 = (($i$01$i) + 1)|0;
      $15 = HEAP32[$2>>2]|0;
      $16 = HEAP32[$materialsTemp>>2]|0;
      $17 = $15;
      $18 = $16;
      $19 = (($17) - ($18))|0;
      $20 = $19 >> 2;
      $21 = ($14>>>0)<($20>>>0);
      if ($21) {
       $10 = $16;$i$01$i = $14;
      } else {
       break L6;
      }
     }
     $57 = ___cxa_find_matching_catch()|0;
     $58 = tempRet0;
     $lpad$phi$index = $57;$lpad$phi$index2 = $58;
     break L4;
    }
   } while(0);
   $22 = HEAP32[690016>>2]|0;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 164|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   invoke_viii($25|0,($22|0),(0|0),0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 19;
   } else {
    __THREW__ = 0;
    invoke_v(200);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 19;
    } else {
     $30 = HEAP32[690160>>2]|0;
     $31 = HEAP32[$30>>2]|0;
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vi($32|0,($30|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      label = 19;
     } else {
      HEAP32[690160>>2] = 0;
      __THREW__ = 0;
      invoke_v(201);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 19;
      } else {
       __THREW__ = 0;
       invoke_vi(3634,(0|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 19;
       } else {
        $39 = HEAP32[690120>>2]|0;
        $40 = HEAP32[$39>>2]|0;
        $41 = (($40) + 8|0);
        $42 = HEAP32[$41>>2]|0;
        __THREW__ = 0;
        invoke_vi($42|0,($39|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 19;
        } else {
         HEAP32[690120>>2] = 0;
         $45 = HEAP32[690080>>2]|0;
         $46 = HEAP32[$45>>2]|0;
         $47 = HEAP32[$46>>2]|0;
         __THREW__ = 0;
         invoke_vi($47|0,($45|0));
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          label = 19;
         } else {
          HEAP32[690080>>2] = 0;
          $50 = HEAP32[$materialsTemp>>2]|0;
          $51 = ($50|0)==(0|0);
          if ($51) {
           STACKTOP = sp;return;
          }
          $52 = HEAP32[$2>>2]|0;
          $53 = ($52|0)==($50|0);
          if (!($53)) {
           $__new_last2$i$i$i$i$i3 = $50;
           $scevgep$i$i$i$i$i4 = (($52) + -4|0);
           $54 = (0 - ($__new_last2$i$i$i$i$i3))|0;
           $uglygep$i$i$i$i$i6 = (($scevgep$i$i$i$i$i4) + ($54)|0);
           $uglygep3$i$i$i$i$i7 = $uglygep$i$i$i$i$i6;
           $55 = $uglygep3$i$i$i$i$i7 >>> 2;
           $56 = $55 ^ -1;
           $scevgep4$i$i$i$i$i8 = (($52) + ($56<<2)|0);
           HEAP32[$2>>2] = $scevgep4$i$i$i$i$i8;
          }
          __ZdlPv($50);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $lpad$phi$index = $59;$lpad$phi$index2 = $60;
 }
 $61 = HEAP32[$materialsTemp>>2]|0;
 $62 = ($61|0)==(0|0);
 if ($62) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $63 = HEAP32[$2>>2]|0;
 $64 = ($63|0)==($61|0);
 if (!($64)) {
  $__new_last2$i$i$i$i$i = $61;
  $scevgep$i$i$i$i$i = (($63) + -4|0);
  $65 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($65)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $66 = $uglygep3$i$i$i$i$i >>> 2;
  $67 = $66 ^ -1;
  $scevgep4$i$i$i$i$i = (($63) + ($67<<2)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($61);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN14PhysicsManagerC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy13 = 0, $$pre$i$i$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i103 = 0, $__new_last2$i$i$i$i$i24 = 0, $__new_last2$i$i$i$i$i31 = 0, $__new_last2$i$i$i$i$i38 = 0, $__new_last2$i$i$i$i$i46 = 0, $__new_last2$i$i$i$i$i53 = 0, $__new_last2$i$i$i$i$i87 = 0, $__new_last2$i$i$i$i$i96 = 0, $__new_last2$i$i$i61 = 0, $__new_last2$i$i$i69 = 0, $__new_last2$i$i$i77 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0;
 var $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i104 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep$i$i$i$i$i32 = 0, $scevgep$i$i$i$i$i39 = 0, $scevgep$i$i$i$i$i47 = 0, $scevgep$i$i$i$i$i54 = 0, $scevgep$i$i$i$i$i88 = 0, $scevgep$i$i$i$i$i97 = 0, $scevgep$i$i$i62 = 0, $scevgep$i$i$i70 = 0, $scevgep$i$i$i78 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i101 = 0, $scevgep4$i$i$i$i$i108 = 0, $scevgep4$i$i$i$i$i29 = 0, $scevgep4$i$i$i$i$i36 = 0, $scevgep4$i$i$i$i$i43 = 0, $scevgep4$i$i$i$i$i51 = 0, $scevgep4$i$i$i$i$i58 = 0;
 var $scevgep4$i$i$i$i$i92 = 0, $scevgep4$i$i$i66 = 0, $scevgep4$i$i$i74 = 0, $scevgep4$i$i$i82 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i106 = 0, $uglygep$i$i$i$i$i27 = 0, $uglygep$i$i$i$i$i34 = 0, $uglygep$i$i$i$i$i41 = 0, $uglygep$i$i$i$i$i49 = 0, $uglygep$i$i$i$i$i56 = 0, $uglygep$i$i$i$i$i90 = 0, $uglygep$i$i$i$i$i99 = 0, $uglygep$i$i$i64 = 0, $uglygep$i$i$i72 = 0, $uglygep$i$i$i80 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i100 = 0, $uglygep3$i$i$i$i$i107 = 0, $uglygep3$i$i$i$i$i28 = 0;
 var $uglygep3$i$i$i$i$i35 = 0, $uglygep3$i$i$i$i$i42 = 0, $uglygep3$i$i$i$i$i50 = 0, $uglygep3$i$i$i$i$i57 = 0, $uglygep3$i$i$i$i$i91 = 0, $uglygep3$i$i$i65 = 0, $uglygep3$i$i$i73 = 0, $uglygep3$i$i$i81 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy13 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy13,$mode);
 $4 = (($this) + 24|0);
 HEAP32[$this>>2] = ((690176 + 8|0));
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = ((690176 + 136|0));
 $6 = (($this) + 28|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 32|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 36|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 60|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 68|0);
 $11 = (($this) + 72|0);
 $12 = (($this) + 80|0);
 $13 = (($this) + 84|0);
 $14 = (($this) + 92|0);
 $15 = (($this) + 96|0);
 $16 = (($this) + 108|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 112|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 116|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 120|0);
 $20 = (($this) + 124|0);
 dest=$10+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$19>>2] = $19;
 HEAP32[$20>>2] = $19;
 $21 = (($this) + 132|0);
 $22 = (($this) + 644|0);
 $24 = $21;
 while(1) {
  $23 = (($24) + 4|0);
  HEAP32[$24>>2] = $24;
  HEAP32[$23>>2] = $24;
  $25 = (($24) + 8|0);
  $26 = ($25|0)==($22|0);
  if ($26) {
   break;
  } else {
   $24 = $25;
  }
 }
 $27 = (($this) + 644|0);
 $28 = (($this) + 648|0);
 HEAP32[$27>>2] = $27;
 HEAP32[$28>>2] = $27;
 $29 = (($this) + 652|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 656|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 660|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 668|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 672|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 664|0);
 HEAP32[$34>>2] = 61;
 $35 = (($this) + 676|0);
 $36 = (($this) + 680|0);
 $37 = (($this) + 688|0);
 $38 = (($this) + 748|0);
 $39 = (($this) + 752|0);
 $40 = (($this) + 760|0);
 $41 = (($this) + 764|0);
 $42 = (($this) + 772|0);
 $43 = (($this) + 776|0);
 $44 = (($this) + 784|0);
 $45 = (($this) + 788|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 792|0);
 HEAP32[$46>>2] = 0;
 $47 = (($this) + 788|0);
 dest=$35+0|0; stop=dest+108|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$44>>2] = $47;
 $48 = (($this) + 796|0);
 $49 = (($this) + 800|0);
 $50 = (($this) + 804|0);
 $51 = (($this) + 808|0);
 $52 = (($this) + 812|0);
 $53 = (($this) + 816|0);
 $54 = (($this) + 56|0);
 ;HEAP32[$48+0>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;HEAP32[$48+20>>2]=0|0;
 HEAP8[$54>>0] = 1;
 $55 = (($this) + 57|0);
 HEAP8[$55>>0] = 0;
 HEAPF32[$6>>2] = Math_fround(0.0);
 HEAPF32[$7>>2] = Math_fround(-9.81000041961669921875);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $56 = (($this) + 52|0);
 HEAPF32[$56>>2] = Math_fround(2.0);
 HEAP32[$2>>2] = -1;
 __THREW__ = 0;
 invoke_viii(1977,($35|0),32,($2|0));
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 do {
  if (!($58)) {
   $59 = (($this) + 104|0);
   HEAP32[$59>>2] = 6;
   $60 = (($this) + 58|0);
   HEAP8[$60>>0] = 1;
   $61 = (($this) + 128|0);
   HEAPF32[$61>>2] = Math_fround(0.0);
   $62 = (($this) + 824|0);
   HEAPF64[$62>>3] = 0.0;
   $63 = (($this) + 40|0);
   HEAPF32[$63>>2] = Math_fround(0.00499999988824129104614);
   $64 = (($this) + 44|0);
   HEAPF32[$64>>2] = Math_fround(7.0);
   $65 = (($this) + 48|0);
   HEAPF32[$65>>2] = Math_fround(0.00999999977648258209228);
   __THREW__ = 0;
   invoke_vii(3322,($37|0),16);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if (!($67)) {
    $68 = HEAP32[$39>>2]|0;
    $69 = HEAP32[$38>>2]|0;
    $70 = $68;
    $71 = $69;
    $72 = (($70) - ($71))|0;
    $73 = (($72|0) / 48)&-1;
    $74 = ($73>>>0)<(128);
    if ($74) {
     $75 = (128 - ($73))|0;
     __THREW__ = 0;
     invoke_vii(3323,($38|0),($75|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break;
     }
    } else {
     $78 = ($73>>>0)>(128);
     if ($78) {
      $79 = (($69) + 6144|0);
      $80 = ($68|0)==($79|0);
      if (!($80)) {
       $__new_last2$i$i$i61 = $79;
       $scevgep$i$i$i62 = (($68) + -48|0);
       $81 = (0 - ($__new_last2$i$i$i61))|0;
       $uglygep$i$i$i64 = (($scevgep$i$i$i62) + ($81)|0);
       $uglygep3$i$i$i65 = $uglygep$i$i$i64;
       $82 = (($uglygep3$i$i$i65>>>0) / 48)&-1;
       $83 = $82 ^ -1;
       $scevgep4$i$i$i66 = (($68) + (($83*48)|0)|0);
       HEAP32[$39>>2] = $scevgep4$i$i$i66;
      }
     }
    }
    $84 = HEAP32[$41>>2]|0;
    $85 = HEAP32[$40>>2]|0;
    $86 = $84;
    $87 = $85;
    $88 = (($86) - ($87))|0;
    $89 = $88 >> 6;
    $90 = ($89>>>0)<(128);
    if ($90) {
     $91 = (128 - ($89))|0;
     __THREW__ = 0;
     invoke_vii(3324,($40|0),($91|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      break;
     }
    } else {
     $94 = ($89>>>0)>(128);
     if ($94) {
      $95 = (($85) + 8192|0);
      $96 = ($84|0)==($95|0);
      if (!($96)) {
       $__new_last2$i$i$i69 = $95;
       $scevgep$i$i$i70 = (($84) + -64|0);
       $97 = (0 - ($__new_last2$i$i$i69))|0;
       $uglygep$i$i$i72 = (($scevgep$i$i$i70) + ($97)|0);
       $uglygep3$i$i$i73 = $uglygep$i$i$i72;
       $98 = $uglygep3$i$i$i73 >>> 6;
       $99 = $98 ^ -1;
       $scevgep4$i$i$i74 = (($84) + ($99<<6)|0);
       HEAP32[$41>>2] = $scevgep4$i$i$i74;
      }
     }
    }
    $100 = HEAP32[$43>>2]|0;
    $101 = HEAP32[$42>>2]|0;
    $102 = $100;
    $103 = $101;
    $104 = (($102) - ($103))|0;
    $105 = $104 >> 4;
    $106 = ($105>>>0)<(128);
    if ($106) {
     $107 = (128 - ($105))|0;
     __THREW__ = 0;
     invoke_vii(3325,($42|0),($107|0));
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if ($109) {
      break;
     }
    } else {
     $110 = ($105>>>0)>(128);
     if ($110) {
      $111 = (($101) + 2048|0);
      $112 = ($100|0)==($111|0);
      if (!($112)) {
       $__new_last2$i$i$i77 = $111;
       $scevgep$i$i$i78 = (($100) + -16|0);
       $113 = (0 - ($__new_last2$i$i$i77))|0;
       $uglygep$i$i$i80 = (($scevgep$i$i$i78) + ($113)|0);
       $uglygep3$i$i$i81 = $uglygep$i$i$i80;
       $114 = $uglygep3$i$i$i81 >>> 4;
       $115 = $114 ^ -1;
       $scevgep4$i$i$i82 = (($100) + ($115<<4)|0);
       HEAP32[$43>>2] = $scevgep4$i$i$i82;
      }
     }
    }
    $116 = HEAP32[$50>>2]|0;
    $117 = HEAP32[$48>>2]|0;
    $118 = $116;
    $119 = $117;
    $120 = (($118) - ($119))|0;
    $121 = $120 >> 2;
    $122 = ($121>>>0)<(128);
    if ($122) {
     $123 = HEAP32[$49>>2]|0;
     $124 = $123;
     $125 = (($124) - ($119))|0;
     __THREW__ = 0;
     $126 = (invoke_ii(2988,512)|0);
     $127 = __THREW__; __THREW__ = 0;
     $128 = $127&1;
     if ($128) {
      break;
     }
     $129 = $125 >> 2;
     $130 = (($126) + ($129<<2)|0);
     $131 = (($126) + 512|0);
     _memcpy(($126|0),($117|0),($125|0))|0;
     HEAP32[$48>>2] = $126;
     HEAP32[$49>>2] = $130;
     HEAP32[$50>>2] = $131;
     $132 = ($117|0)==(0|0);
     if (!($132)) {
      __ZdlPv($117);
     }
    }
    $133 = HEAP32[$53>>2]|0;
    $134 = HEAP32[$51>>2]|0;
    $135 = $133;
    $136 = $134;
    $137 = (($135) - ($136))|0;
    $138 = (($137|0) / 44)&-1;
    $139 = ($138>>>0)<(128);
    if ($139) {
     $140 = HEAP32[$52>>2]|0;
     $141 = $140;
     $142 = (($141) - ($136))|0;
     $143 = (($142|0) / 44)&-1;
     __THREW__ = 0;
     $144 = (invoke_ii(2988,5632)|0);
     $145 = __THREW__; __THREW__ = 0;
     $146 = $145&1;
     if ($146) {
      break;
     }
     $147 = (($144) + (($143*44)|0)|0);
     $148 = (($144) + 5632|0);
     $149 = (($142|0) / -44)&-1;
     $$sum$i = (($149) + ($143))|0;
     $150 = (($144) + (($$sum$i*44)|0)|0);
     _memcpy(($150|0),($134|0),($142|0))|0;
     HEAP32[$51>>2] = $150;
     HEAP32[$52>>2] = $147;
     HEAP32[$53>>2] = $148;
     $151 = ($134|0)==(0|0);
     if (!($151)) {
      __ZdlPv($134);
     }
    }
    $152 = HEAP32[690120>>2]|0;
    $153 = ($152|0)==(0|0);
    if ($153) {
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3635,($this|0));
    $163 = __THREW__; __THREW__ = 0;
    $164 = $163&1;
    if (!($164)) {
     $165 = HEAP32[690016>>2]|0;
     $166 = HEAP32[$165>>2]|0;
     $167 = (($166) + 164|0);
     $168 = HEAP32[$167>>2]|0;
     __THREW__ = 0;
     invoke_viii($168|0,($165|0),(0|0),0);
     $169 = __THREW__; __THREW__ = 0;
     $170 = $169&1;
     if (!($170)) {
      $171 = HEAP32[690016>>2]|0;
      $172 = HEAP32[$171>>2]|0;
      $173 = (($172) + 164|0);
      $174 = HEAP32[$173>>2]|0;
      __THREW__ = 0;
      invoke_viii($174|0,($171|0),($4|0),0);
      $175 = __THREW__; __THREW__ = 0;
      $176 = $175&1;
      if (!($176)) {
       __THREW__ = 0;
       invoke_viii(1628,56,($16|0),1);
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if (!($178)) {
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $154 = ___cxa_find_matching_catch()|0;
 $155 = tempRet0;
 $156 = HEAP32[$51>>2]|0;
 $157 = ($156|0)==(0|0);
 if (!($157)) {
  $158 = HEAP32[$52>>2]|0;
  $159 = ($158|0)==($156|0);
  if (!($159)) {
   $__new_last2$i$i$i$i$i87 = $156;
   $scevgep$i$i$i$i$i88 = (($158) + -44|0);
   $160 = (0 - ($__new_last2$i$i$i$i$i87))|0;
   $uglygep$i$i$i$i$i90 = (($scevgep$i$i$i$i$i88) + ($160)|0);
   $uglygep3$i$i$i$i$i91 = $uglygep$i$i$i$i$i90;
   $161 = (($uglygep3$i$i$i$i$i91>>>0) / 44)&-1;
   $162 = $161 ^ -1;
   $scevgep4$i$i$i$i$i92 = (($158) + (($162*44)|0)|0);
   HEAP32[$52>>2] = $scevgep4$i$i$i$i$i92;
  }
  __ZdlPv($156);
 }
 $179 = HEAP32[$48>>2]|0;
 $180 = ($179|0)==(0|0);
 if (!($180)) {
  $181 = HEAP32[$49>>2]|0;
  $182 = ($181|0)==($179|0);
  if (!($182)) {
   $__new_last2$i$i$i$i$i96 = $179;
   $scevgep$i$i$i$i$i97 = (($181) + -4|0);
   $183 = (0 - ($__new_last2$i$i$i$i$i96))|0;
   $uglygep$i$i$i$i$i99 = (($scevgep$i$i$i$i$i97) + ($183)|0);
   $uglygep3$i$i$i$i$i100 = $uglygep$i$i$i$i$i99;
   $184 = $uglygep3$i$i$i$i$i100 >>> 2;
   $185 = $184 ^ -1;
   $scevgep4$i$i$i$i$i101 = (($181) + ($185<<2)|0);
   HEAP32[$49>>2] = $scevgep4$i$i$i$i$i101;
  }
  __ZdlPv($179);
 }
 $186 = HEAP32[$45>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_4pairIPN5physx7PxShapeES5_EEN14PhysicsManager16TriggerStayStateEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($44,$186);
 $187 = HEAP32[$42>>2]|0;
 $188 = ($187|0)==(0|0);
 if (!($188)) {
  $189 = HEAP32[$43>>2]|0;
  $190 = ($189|0)==($187|0);
  if (!($190)) {
   $__new_last2$i$i$i$i$i103 = $187;
   $scevgep$i$i$i$i$i104 = (($189) + -16|0);
   $191 = (0 - ($__new_last2$i$i$i$i$i103))|0;
   $uglygep$i$i$i$i$i106 = (($scevgep$i$i$i$i$i104) + ($191)|0);
   $uglygep3$i$i$i$i$i107 = $uglygep$i$i$i$i$i106;
   $192 = $uglygep3$i$i$i$i$i107 >>> 4;
   $193 = $192 ^ -1;
   $scevgep4$i$i$i$i$i108 = (($189) + ($193<<4)|0);
   HEAP32[$43>>2] = $scevgep4$i$i$i$i$i108;
  }
  __ZdlPv($187);
 }
 $194 = HEAP32[$40>>2]|0;
 $195 = ($194|0)==(0|0);
 if (!($195)) {
  $196 = HEAP32[$41>>2]|0;
  $197 = ($196|0)==($194|0);
  if (!($197)) {
   $__new_last2$i$i$i$i$i53 = $194;
   $scevgep$i$i$i$i$i54 = (($196) + -64|0);
   $198 = (0 - ($__new_last2$i$i$i$i$i53))|0;
   $uglygep$i$i$i$i$i56 = (($scevgep$i$i$i$i$i54) + ($198)|0);
   $uglygep3$i$i$i$i$i57 = $uglygep$i$i$i$i$i56;
   $199 = $uglygep3$i$i$i$i$i57 >>> 6;
   $200 = $199 ^ -1;
   $scevgep4$i$i$i$i$i58 = (($196) + ($200<<6)|0);
   HEAP32[$41>>2] = $scevgep4$i$i$i$i$i58;
  }
  __ZdlPv($194);
 }
 $201 = HEAP32[$38>>2]|0;
 $202 = ($201|0)==(0|0);
 if (!($202)) {
  $203 = HEAP32[$39>>2]|0;
  $204 = ($203|0)==($201|0);
  if (!($204)) {
   $__new_last2$i$i$i$i$i46 = $201;
   $scevgep$i$i$i$i$i47 = (($203) + -48|0);
   $205 = (0 - ($__new_last2$i$i$i$i$i46))|0;
   $uglygep$i$i$i$i$i49 = (($scevgep$i$i$i$i$i47) + ($205)|0);
   $uglygep3$i$i$i$i$i50 = $uglygep$i$i$i$i$i49;
   $206 = (($uglygep3$i$i$i$i$i50>>>0) / 48)&-1;
   $207 = $206 ^ -1;
   $scevgep4$i$i$i$i$i51 = (($203) + (($207*48)|0)|0);
   HEAP32[$39>>2] = $scevgep4$i$i$i$i$i51;
  }
  __ZdlPv($201);
 }
 __THREW__ = 0;
 invoke_vi(3636,($37|0));
 $208 = __THREW__; __THREW__ = 0;
 $209 = $208&1;
 do {
  if (!($209)) {
   $210 = HEAP32[$35>>2]|0;
   $211 = ($210|0)==(0|0);
   if (!($211)) {
    $212 = HEAP32[$36>>2]|0;
    $213 = ($212|0)==($210|0);
    if (!($213)) {
     $__new_last2$i$i$i$i$i38 = $210;
     $scevgep$i$i$i$i$i39 = (($212) + -4|0);
     $214 = (0 - ($__new_last2$i$i$i$i$i38))|0;
     $uglygep$i$i$i$i$i41 = (($scevgep$i$i$i$i$i39) + ($214)|0);
     $uglygep3$i$i$i$i$i42 = $uglygep$i$i$i$i$i41;
     $215 = $uglygep3$i$i$i$i$i42 >>> 2;
     $216 = $215 ^ -1;
     $scevgep4$i$i$i$i$i43 = (($212) + ($216<<2)|0);
     HEAP32[$36>>2] = $scevgep4$i$i$i$i$i43;
    }
    __ZdlPv($210);
   }
   $217 = HEAP32[$33>>2]|0;
   $218 = ($217|0)>(-1);
   if ($218) {
    $219 = HEAP32[$31>>2]|0;
    $220 = HEAP32[$34>>2]|0;
    HEAP32[$0>>2] = $220;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($219|0),($$byval_copy13|0));
    $221 = __THREW__; __THREW__ = 0;
    $222 = $221&1;
    if ($222) {
     break;
    }
    HEAP32[$31>>2] = 0;
   }
   HEAP32[$28>>2] = 0;
   HEAP32[$27>>2] = 0;
   $224 = $22;
   while(1) {
    $223 = (($224) + -8|0);
    $225 = (($224) + -4|0);
    HEAP32[$225>>2] = 0;
    HEAP32[$223>>2] = 0;
    $226 = ($223|0)==($21|0);
    if ($226) {
     break;
    } else {
     $224 = $223;
    }
   }
   HEAP32[$20>>2] = 0;
   HEAP32[$19>>2] = 0;
   $227 = HEAP32[$16>>2]|0;
   $228 = ($227|0)==(0|0);
   if (!($228)) {
    $229 = HEAP32[$17>>2]|0;
    $230 = ($229|0)==($227|0);
    if (!($230)) {
     $__new_last2$i$i$i$i$i31 = $227;
     $scevgep$i$i$i$i$i32 = (($229) + -4|0);
     $231 = (0 - ($__new_last2$i$i$i$i$i31))|0;
     $uglygep$i$i$i$i$i34 = (($scevgep$i$i$i$i$i32) + ($231)|0);
     $uglygep3$i$i$i$i$i35 = $uglygep$i$i$i$i$i34;
     $232 = $uglygep3$i$i$i$i$i35 >>> 2;
     $233 = $232 ^ -1;
     $scevgep4$i$i$i$i$i36 = (($229) + ($233<<2)|0);
     HEAP32[$17>>2] = $scevgep4$i$i$i$i$i36;
    }
    __ZdlPv($227);
   }
   $234 = HEAP32[$14>>2]|0;
   $235 = ($234|0)==(0|0);
   if (!($235)) {
    $236 = HEAP32[$15>>2]|0;
    $237 = ($236|0)==($234|0);
    if (!($237)) {
     $__new_last2$i$i$i$i$i24 = $234;
     $scevgep$i$i$i$i$i25 = (($236) + -12|0);
     $238 = (0 - ($__new_last2$i$i$i$i$i24))|0;
     $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($238)|0);
     $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
     $239 = (($uglygep3$i$i$i$i$i28>>>0) / 12)&-1;
     $240 = $239 ^ -1;
     $scevgep4$i$i$i$i$i29 = (($236) + (($240*12)|0)|0);
     HEAP32[$15>>2] = $scevgep4$i$i$i$i$i29;
    }
    __ZdlPv($234);
   }
   $241 = HEAP32[$12>>2]|0;
   $242 = ($241|0)==(0|0);
   if (!($242)) {
    $243 = HEAP32[$13>>2]|0;
    $244 = ($243|0)==($241|0);
    if ($244) {
     $266 = $241;
    } else {
     $246 = $243;
     while(1) {
      $245 = (($246) + -72|0);
      HEAP32[$13>>2] = $245;
      $247 = (($246) + -12|0);
      $248 = (($246) + -4|0);
      $249 = HEAP32[$248>>2]|0;
      $250 = ($249|0)==(0);
      if (!($250)) {
       $253 = (($246) + -8|0);
       $254 = HEAP32[$253>>2]|0;
       $255 = HEAP32[$247>>2]|0;
       $256 = (($255) + 4|0);
       $257 = HEAP32[$256>>2]|0;
       $258 = HEAP32[$254>>2]|0;
       $259 = (($258) + 4|0);
       HEAP32[$259>>2] = $257;
       $260 = HEAP32[$254>>2]|0;
       $261 = HEAP32[$256>>2]|0;
       HEAP32[$261>>2] = $260;
       HEAP32[$248>>2] = 0;
       $262 = ($254|0)==($247|0);
       if (!($262)) {
        $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = $254;
        while(1) {
         $263 = (($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i) + 4|0);
         $264 = HEAP32[$263>>2]|0;
         __ZdlPv($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i);
         $265 = ($264|0)==($247|0);
         if ($265) {
          break;
         } else {
          $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = $264;
         }
        }
       }
      }
      $251 = HEAP32[$13>>2]|0;
      $252 = ($251|0)==($241|0);
      if ($252) {
       break;
      } else {
       $246 = $251;
      }
     }
     $$pre$i$i$i = HEAP32[$12>>2]|0;
     $266 = $$pre$i$i$i;
    }
    __ZdlPv($266);
   }
   $267 = HEAP32[$10>>2]|0;
   $268 = ($267|0)==(0|0);
   if (!($268)) {
    $269 = HEAP32[$11>>2]|0;
    $270 = ($269|0)==($267|0);
    if (!($270)) {
     $__new_last2$i$i$i$i$i = $267;
     $scevgep$i$i$i$i$i = (($269) + -12|0);
     $271 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($271)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $272 = (($uglygep3$i$i$i$i$i>>>0) / 12)&-1;
     $273 = $272 ^ -1;
     $scevgep4$i$i$i$i$i = (($269) + (($273*12)|0)|0);
     HEAP32[$11>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($267);
   }
   HEAP32[$this>>2] = ((561192 + 8|0));
   __THREW__ = 0;
   $274 = __THREW__; __THREW__ = 0;
   $275 = $274&1;
   if (!($275)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $276 = __THREW__; __THREW__ = 0;
    $277 = $276&1;
    if (!($277)) {
     __THREW__ = 0;
     $284 = __THREW__; __THREW__ = 0;
     $285 = $284&1;
     if ($285) {
      break;
     }
     ___resumeException($154|0);
     // unreachable;
    }
    $278 = ___cxa_find_matching_catch(0|0)|0;
    $279 = tempRet0;
    __THREW__ = 0;
    $280 = __THREW__; __THREW__ = 0;
    $281 = $280&1;
    if ($281) {
     $282 = ___cxa_find_matching_catch(0|0)|0;
     $283 = tempRet0;
     ___clang_call_terminate($282);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $278;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $286 = ___cxa_find_matching_catch(0|0)|0;
   $287 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $288 = __THREW__; __THREW__ = 0;
   $289 = $288&1;
   if ($289) {
    $292 = ___cxa_find_matching_catch(0|0)|0;
    $293 = tempRet0;
    __THREW__ = 0;
    $294 = __THREW__; __THREW__ = 0;
    $295 = $294&1;
    if ($295) {
     $296 = ___cxa_find_matching_catch(0|0)|0;
     $297 = tempRet0;
     ___clang_call_terminate($296);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $292;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $290 = __THREW__; __THREW__ = 0;
   $291 = $290&1;
   if (!($291)) {
    $eh$lpad$body$indexZ2D = $286;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $298 = ___cxa_find_matching_catch(0|0)|0;
   $299 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $298;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 $300 = ___cxa_find_matching_catch(0|0)|0;
 $301 = tempRet0;
 $eh$lpad$body$indexZ2D = $300;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN14PhysicsManager11SweepShapes4InitEj($this,$initialCapacity) {
 $this = $this|0;
 $initialCapacity = $initialCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($initialCapacity>>>0);
 if ($7) {
  $8 = (($this) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9;
  $11 = (($10) - ($4))|0;
  $12 = $11 >> 2;
  $13 = ($initialCapacity|0)==(0);
  if ($13) {
   $17 = 0;
  } else {
   $14 = $initialCapacity << 2;
   $15 = (__Znwj($14)|0);
   $17 = $15;
  }
  $16 = (($17) + ($12<<2)|0);
  $18 = (($17) + ($initialCapacity<<2)|0);
  _memcpy(($17|0),($2|0),($11|0))|0;
  HEAP32[$this>>2] = $17;
  HEAP32[$8>>2] = $16;
  HEAP32[$0>>2] = $18;
  $19 = ($2|0)==(0|0);
  if (!($19)) {
   __ZdlPv($2);
  }
 }
 $20 = (($this) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $21;
 $25 = $23;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($27>>>0)<($initialCapacity>>>0);
 if ($28) {
  $29 = (($this) + 16|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = $30;
  $32 = (($31) - ($25))|0;
  $33 = $32 >> 2;
  $34 = ($initialCapacity|0)==(0);
  if ($34) {
   $38 = 0;
  } else {
   $35 = $initialCapacity << 2;
   $36 = (__Znwj($35)|0);
   $38 = $36;
  }
  $37 = (($38) + ($33<<2)|0);
  $39 = (($38) + ($initialCapacity<<2)|0);
  _memcpy(($38|0),($23|0),($32|0))|0;
  HEAP32[$22>>2] = $38;
  HEAP32[$29>>2] = $37;
  HEAP32[$20>>2] = $39;
  $40 = ($23|0)==(0|0);
  if (!($40)) {
   __ZdlPv($23);
  }
 }
 $41 = (($this) + 24|0);
 __ZNSt3__16vectorIN5physx11PxTransformENS_9allocatorIS2_EEE7reserveEj($41,$initialCapacity);
 $42 = (($this) + 44|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 36|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $43;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = $48 >> 4;
 $50 = ($49>>>0)<($initialCapacity>>>0);
 if ($50) {
  $51 = (($this) + 40|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52;
  $54 = (($53) - ($47))|0;
  $55 = $54 >> 4;
  $56 = ($initialCapacity|0)==(0);
  if ($56) {
   $60 = 0;
  } else {
   $57 = $initialCapacity << 4;
   $58 = (__Znwj($57)|0);
   $60 = $58;
  }
  $59 = (($60) + ($55<<4)|0);
  $61 = (($60) + ($initialCapacity<<4)|0);
  _memcpy(($60|0),($45|0),($54|0))|0;
  HEAP32[$44>>2] = $60;
  HEAP32[$51>>2] = $59;
  HEAP32[$42>>2] = $61;
  $62 = ($45|0)==(0|0);
  if (!($62)) {
   __ZdlPv($45);
  }
 }
 $63 = ($initialCapacity*36)|0;
 $64 = (($this) + 56|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($this) + 48|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = $65;
 $69 = $67;
 $70 = (($68) - ($69))|0;
 $71 = ($70>>>0)<($63>>>0);
 if (!($71)) {
  STACKTOP = sp;return;
 }
 $72 = (($this) + 52|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73;
 $75 = (($74) - ($69))|0;
 $76 = ($63|0)==(0);
 if ($76) {
  $79 = 0;
 } else {
  $77 = (__Znwj($63)|0);
  $79 = $77;
 }
 $78 = (($79) + ($75)|0);
 $80 = (($79) + ($63)|0);
 _memcpy(($79|0),($67|0),($75|0))|0;
 HEAP32[$66>>2] = $79;
 HEAP32[$72>>2] = $78;
 HEAP32[$64>>2] = $80;
 $81 = ($67|0)==(0|0);
 if ($81) {
  STACKTOP = sp;return;
 }
 __ZdlPv($67);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager20SetupDefaultMaterialEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mat = 0, $pos$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $mat = sp + 4|0;
 $1 = (($this) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = (($this) + 64|0);
   HEAP32[$4>>2] = 0;
  } else {
   HEAP32[$0>>2] = $2;
   $5 = HEAP32[560624>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    label = 12;
   } else {
    $7 = (($5) + 36|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($5) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    do {
     if ($11) {
      $12 = (($5) + 28|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($5) + 32|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($13) + ($15<<3)|0);
      $32 = $16;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$5,$0);
      $17 = HEAP32[$pos$i$i$i>>2]|0;
      $18 = ($17|0)==(-1);
      $19 = (($5) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      if ($18) {
       $21 = (($5) + 32|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + ($22<<3)|0);
       $32 = $23;
       break;
      } else {
       $24 = (($20) + ($17<<3)|0);
       $32 = $24;
       break;
      }
     }
    } while(0);
    $25 = HEAP32[560624>>2]|0;
    $26 = (($25) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + ($29<<3)|0);
    $31 = ($32|0)==($30|0);
    if ($31) {
     label = 12;
    } else {
     $33 = (($32) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      label = 12;
     } else {
      $36 = (($this) + 64|0);
      HEAP32[$36>>2] = $34;
      $41 = $34;
     }
    }
   }
   if ((label|0) == 12) {
    $37 = HEAP32[$1>>2]|0;
    $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
    $39 = (($this) + 64|0);
    HEAP32[$39>>2] = $38;
    $40 = ($38|0)==(0|0);
    if ($40) {
     break;
    } else {
     $41 = $38;
    }
   }
   __ZNK14PhysicMaterial21CopyMaterialToDefaultEv($41);
   STACKTOP = sp;return;
  }
 } while(0);
 $42 = HEAP32[690120>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 152|0);
 $45 = HEAP32[$44>>2]|0;
 (FUNCTION_TABLE_iiiii[$45 & 511]($42,$mat,1,0)|0);
 $46 = HEAP32[$mat>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 28|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vif[$49 & 255]($46,Math_fround(0.600000023841857910156));
 $50 = HEAP32[$mat>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + 36|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vif[$53 & 255]($50,Math_fround(0.600000023841857910156));
 $54 = HEAP32[$mat>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 44|0);
 $57 = HEAP32[$56>>2]|0;
 FUNCTION_TABLE_vif[$57 & 255]($54,Math_fround(0.0));
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[690120>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 28|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($this) + 32|0);
 HEAPF32[$4>>2] = Math_fround(-9.81000041961669921875);
 $5 = (($this) + 36|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 52|0);
 HEAPF32[$6>>2] = Math_fround(2.0);
 $7 = (($this) + 676|0);
 HEAP32[$0>>2] = -1;
 $8 = (($this) + 680|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$7>>2]|0;
 $11 = $9;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(32);
 if ($15) {
  $16 = (32 - ($14))|0;
  __ZNSt3__16vectorIjNS_9allocatorIjEEE8__appendEjRKj($7,$16,$0);
 } else {
  $17 = ($14>>>0)>(32);
  if ($17) {
   $18 = (($10) + 128|0);
   $19 = ($9|0)==($18|0);
   if (!($19)) {
    $__new_last2$i$i$i = $18;
    $scevgep$i$i$i = (($9) + -4|0);
    $20 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($20)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $21 = $uglygep3$i$i$i >>> 2;
    $22 = $21 ^ -1;
    $scevgep4$i$i$i = (($9) + ($22<<2)|0);
    HEAP32[$8>>2] = $scevgep4$i$i$i;
   }
  }
 }
 $23 = (($this) + 104|0);
 HEAP32[$23>>2] = 6;
 $24 = (($this) + 784|0);
 $25 = (($this) + 788|0);
 $26 = HEAP32[$25>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_4pairIPN5physx7PxShapeES5_EEN14PhysicsManager16TriggerStayStateEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($24,$26);
 $27 = (($this) + 792|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 788|0);
 HEAP32[$24>>2] = $28;
 HEAP32[$28>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$05 = 0, $node$01$i = 0, $node$01$i1 = 0, $node$01$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = (($this) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if (!($3)) {
  $node$01$i = $2;
  while(1) {
   $4 = (($node$01$i) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   HEAP32[$node$01$i>>2] = 0;
   HEAP32[$4>>2] = 0;
   $6 = ($5|0)==($0|0);
   if ($6) {
    break;
   } else {
    $node$01$i = $5;
   }
  }
 }
 HEAP32[$1>>2] = $0;
 HEAP32[$0>>2] = $0;
 $i$05 = 0;
 while(1) {
  $7 = ((($this) + ($i$05<<3)|0) + 132|0);
  $8 = ((($this) + ($i$05<<3)|0) + 136|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($7|0);
  if (!($10)) {
   $node$01$i1 = $9;
   while(1) {
    $11 = (($node$01$i1) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$node$01$i1>>2] = 0;
    HEAP32[$11>>2] = 0;
    $13 = ($12|0)==($7|0);
    if ($13) {
     break;
    } else {
     $node$01$i1 = $12;
    }
   }
  }
  HEAP32[$8>>2] = $7;
  HEAP32[$7>>2] = $7;
  $14 = (($i$05) + 1)|0;
  $exitcond = ($14|0)==(64);
  if ($exitcond) {
   break;
  } else {
   $i$05 = $14;
  }
 }
 $15 = (($this) + 644|0);
 $16 = (($this) + 648|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==($15|0);
 if (!($18)) {
  $node$01$i3 = $17;
  while(1) {
   $19 = (($node$01$i3) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[$node$01$i3>>2] = 0;
   HEAP32[$19>>2] = 0;
   $21 = ($20|0)==($15|0);
   if ($21) {
    break;
   } else {
    $node$01$i3 = $20;
   }
  }
 }
 HEAP32[$16>>2] = $15;
 HEAP32[$15>>2] = $15;
 $22 = HEAP32[690016>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 164|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_viii[$25 & 4095]($22,0,0);
 __ZN11GameManager17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager13RecreateSceneEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0;
 var $i$01$i = 0, $i$014 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $materials = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 14|0;
 $1 = sp + 12|0;
 $materials = sp;
 $2 = HEAP32[690120>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 784|0);
 $5 = (($this) + 788|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_4pairIPN5physx7PxShapeES5_EEN14PhysicsManager16TriggerStayStateEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($4,$6);
 $7 = (($this) + 792|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 788|0);
 HEAP32[$4>>2] = $8;
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[690016>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 236|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($9,1,0)|0);
 $13 = HEAP32[690016>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 72|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP16[$0>>1] = 2;
 $17 = (FUNCTION_TABLE_iii[$16 & 4095]($13,$0)|0);
 $18 = ($17|0)==(0);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $19 = HEAP32[690016>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 72|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP16[$1>>1] = 1;
 $23 = (FUNCTION_TABLE_iii[$22 & 4095]($19,$1)|0);
 $24 = ($23|0)==(0);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 HEAP32[$materials>>2] = 0;
 $25 = (($materials) + 4|0);
 HEAP32[$25>>2] = 0;
 $26 = (($materials) + 8|0);
 HEAP32[$26>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,134,($materials|0),0)|0);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 L10: do {
  if ($28) {
   label = 18;
  } else {
   $29 = HEAP32[$25>>2]|0;
   $30 = HEAP32[$materials>>2]|0;
   $31 = ($29|0)==($30|0);
   L12: do {
    if (!($31)) {
     $33 = $30;$i$01$i = 0;
     while(1) {
      $32 = (($33) + ($i$01$i<<2)|0);
      $34 = HEAP32[$32>>2]|0;
      __THREW__ = 0;
      invoke_vi(3633,($34|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = (($i$01$i) + 1)|0;
      $38 = HEAP32[$25>>2]|0;
      $39 = HEAP32[$materials>>2]|0;
      $40 = $38;
      $41 = $39;
      $42 = (($40) - ($41))|0;
      $43 = $42 >> 2;
      $44 = ($37>>>0)<($43>>>0);
      if ($44) {
       $33 = $39;$i$01$i = $37;
      } else {
       break L12;
      }
     }
     $92 = ___cxa_find_matching_catch()|0;
     $93 = tempRet0;
     $lpad$phi$index = $92;$lpad$phi$index3 = $93;
     break L10;
    }
   } while(0);
   $45 = HEAP32[690016>>2]|0;
   $46 = HEAP32[$45>>2]|0;
   $47 = (($46) + 164|0);
   $48 = HEAP32[$47>>2]|0;
   __THREW__ = 0;
   invoke_viii($48|0,($45|0),(0|0),0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    label = 18;
   } else {
    __THREW__ = 0;
    invoke_v(200);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     label = 18;
    } else {
     $53 = (($this) + 57|0);
     $54 = HEAP8[$53>>0]|0;
     $55 = ($54<<24>>24)!=(0);
     __THREW__ = 0;
     invoke_vi(3637,($55|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 18;
     } else {
      $58 = HEAP32[690016>>2]|0;
      $59 = HEAP32[$58>>2]|0;
      $60 = (($59) + 164|0);
      $61 = HEAP32[$60>>2]|0;
      __THREW__ = 0;
      invoke_viii($61|0,($58|0),(0|0),0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       label = 18;
      } else {
       $64 = HEAP32[690016>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = (($65) + 164|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($this) + 24|0);
       __THREW__ = 0;
       invoke_viii($67|0,($64|0),($68|0),0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 18;
       } else {
        $71 = HEAP32[$25>>2]|0;
        $72 = HEAP32[$materials>>2]|0;
        $73 = ($71|0)==($72|0);
        L23: do {
         if (!($73)) {
          $75 = $72;$i$014 = 0;
          while(1) {
           $74 = (($75) + ($i$014<<2)|0);
           $76 = HEAP32[$74>>2]|0;
           $77 = HEAP32[$76>>2]|0;
           $78 = (($77) + 12|0);
           $79 = HEAP32[$78>>2]|0;
           __THREW__ = 0;
           invoke_vii($79|0,($76|0),0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if ($81) {
            break;
           }
           $82 = (($i$014) + 1)|0;
           $83 = HEAP32[$25>>2]|0;
           $84 = HEAP32[$materials>>2]|0;
           $85 = $83;
           $86 = $84;
           $87 = (($85) - ($86))|0;
           $88 = $87 >> 2;
           $89 = ($82>>>0)<($88>>>0);
           if ($89) {
            $75 = $84;$i$014 = $82;
           } else {
            break L23;
           }
          }
          $90 = ___cxa_find_matching_catch()|0;
          $91 = tempRet0;
          $lpad$phi$index = $90;$lpad$phi$index3 = $91;
          break L10;
         }
        } while(0);
        __THREW__ = 0;
        $103 = (invoke_ii(3310,9)|0);
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if ($105) {
         label = 18;
        } else {
         $106 = HEAP32[$103>>2]|0;
         $107 = (($106) + 12|0);
         $108 = HEAP32[$107>>2]|0;
         __THREW__ = 0;
         invoke_vii($108|0,($103|0),0);
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          label = 18;
         } else {
          $111 = HEAP32[$materials>>2]|0;
          $112 = ($111|0)==(0|0);
          if ($112) {
           STACKTOP = sp;return;
          }
          $113 = HEAP32[$25>>2]|0;
          $114 = ($113|0)==($111|0);
          if (!($114)) {
           $__new_last2$i$i$i$i$i = $111;
           $scevgep$i$i$i$i$i = (($113) + -4|0);
           $115 = (0 - ($__new_last2$i$i$i$i$i))|0;
           $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($115)|0);
           $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
           $116 = $uglygep3$i$i$i$i$i >>> 2;
           $117 = $116 ^ -1;
           $scevgep4$i$i$i$i$i = (($113) + ($117<<2)|0);
           HEAP32[$25>>2] = $scevgep4$i$i$i$i$i;
          }
          __ZdlPv($111);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $94 = ___cxa_find_matching_catch()|0;
  $95 = tempRet0;
  $lpad$phi$index = $94;$lpad$phi$index3 = $95;
 }
 $96 = HEAP32[$materials>>2]|0;
 $97 = ($96|0)==(0|0);
 if ($97) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $98 = HEAP32[$25>>2]|0;
 $99 = ($98|0)==($96|0);
 if (!($99)) {
  $__new_last2$i$i$i$i$i1 = $96;
  $scevgep$i$i$i$i$i2 = (($98) + -4|0);
  $100 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($100)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $101 = $uglygep3$i$i$i$i$i5 >>> 2;
  $102 = $101 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($98) + ($102<<2)|0);
  HEAP32[$25>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($96);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z16GetDynamicsScenev() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[690016>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN14PhysicsManager21SimulateClothingSceneEPv($voidScene) {
 $voidScene = $voidScene|0;
 var $$byval_copy14 = 0, $$index = 0, $$index8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $allocPtr$0 = 0, $i$02 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy14 = sp + 8|0;
 $0 = sp;
 $1 = sp + 14|0;
 $2 = sp + 4|0;
 $3 = sp + 12|0;
 $4 = (__Z14IsWorldPlayingv()|0);
 if ($4) {
  $5 = (__Z14GetTimeManagerv()|0);
  $6 = (($5) + 104|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = $7 > Math_fround(0.0);
  if ($8) {
   $9 = HEAP32[$voidScene>>2]|0;
   $10 = (($9) + 220|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (__Z14GetTimeManagerv()|0);
   $13 = (($12) + 104|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   FUNCTION_TABLE_vifiiii[$11 & 3]($voidScene,$14,0,0,0,1);
   while(1) {
    $15 = HEAP32[$voidScene>>2]|0;
    $16 = (($15) + 232|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (FUNCTION_TABLE_iii[$17 & 4095]($voidScene,0)|0);
    if ($18) {
     break;
    }
   }
  }
 }
 $19 = HEAP32[$voidScene>>2]|0;
 $20 = (($19) + 236|0);
 $21 = HEAP32[$20>>2]|0;
 (FUNCTION_TABLE_iiii[$21 & 2047]($voidScene,1,0)|0);
 $22 = HEAP32[$voidScene>>2]|0;
 $23 = (($22) + 72|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP16[$1>>1] = 32;
 $25 = (FUNCTION_TABLE_iii[$24 & 4095]($voidScene,$1)|0);
 $26 = $25 << 2;
 $27 = (($26) + 15)|0;
 $28 = ($27>>>0)<(2000);
 $29 = ($25|0)!=(0);
 if ($28) {
  if ($29) {
   $30 = STACKTOP; STACKTOP = STACKTOP + ((((1*$27)|0)+15)&-16)|0;;
   $42 = 0;$allocPtr$0 = $30;
  } else {
   $42 = 0;$allocPtr$0 = 0;
  }
 } else {
  if ($29) {
   $31 = HEAP32[628512>>2]|0;
   HEAP32[$2>>2] = $31;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
   $32 = (invoke_iiiiiii(102,($27|0),16,($$byval_copy14|0),0,(690112|0),1321)|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $35 = ___cxa_find_matching_catch()|0;
    $36 = tempRet0;
    $$index = $35;$$index8 = $36;$68 = $0;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $42 = $32;$allocPtr$0 = $32;
   }
  } else {
   $42 = 0;$allocPtr$0 = 0;
  }
 }
 $46 = $allocPtr$0;
 $47 = (($46) + 15)|0;
 $48 = $47 & -16;
 $49 = $48;
 $50 = HEAP32[$voidScene>>2]|0;
 $51 = (($50) + 76|0);
 $52 = HEAP32[$51>>2]|0;
 HEAP16[$3>>1] = 32;
 __THREW__ = 0;
 (invoke_iiiiii($52|0,($voidScene|0),($3|0),($49|0),($25|0),0)|0);
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 L15: do {
  if ($54) {
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   $lpad$phi$index = $39;$lpad$phi$index2 = $40;
  } else {
   $55 = ($25|0)>(0);
   L18: do {
    if ($55) {
     $i$02 = 0;
     while(1) {
      $56 = (($49) + ($i$02<<2)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($57) + 8|0);
      $59 = HEAP32[$58>>2]|0;
      __THREW__ = 0;
      invoke_vi(3638,($59|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break;
      }
      $62 = (($i$02) + 1)|0;
      $63 = ($62|0)<($25|0);
      if ($63) {
       $i$02 = $62;
      } else {
       break L18;
      }
     }
     $37 = ___cxa_find_matching_catch()|0;
     $38 = tempRet0;
     $lpad$phi$index = $37;$lpad$phi$index2 = $38;
     break L15;
    }
   } while(0);
   $64 = ($42|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $65;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($42,$$byval_copy14);
   STACKTOP = sp;return;
  }
 } while(0);
 $41 = ($42|0)==(0|0);
 if ($41) {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$68 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $43 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $43;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($42|0),($$byval_copy14|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $66 = ___cxa_find_matching_catch(0|0)|0;
  $67 = tempRet0;
  ___clang_call_terminate($66);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$68 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __ZN14PhysicsManager11FixedUpdateEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$01$i = 0, $i$01$i1 = 0, $inData$c$i = 0, $level$012 = 0, $node$01$i = 0, $pose = 0, $velocity = 0, $velocityMessageData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $1 = sp;
 $velocityMessageData = sp + 16|0;
 $pose = sp + 28|0;
 $velocity = sp + 56|0;
 $2 = sp + 68|0;
 $3 = (__Z14GetTimeManagerv()|0);
 $4 = (($3) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 644|0);
 $7 = (($this) + 648|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($6|0);
 if ($9) {
  $24 = $8;
 } else {
  $11 = $8;
  while(1) {
   $10 = (($11) + 8|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($12) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $19 = 0;
   } else {
    $17 = (($15) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = $18;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE($13,0,690112,1150,1,$19,0,0);
   $20 = (($11) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==($6|0);
   if ($22) {
    break;
   } else {
    $11 = $21;
   }
  }
  $$pre = HEAP32[$7>>2]|0;
  $24 = $$pre;
 }
 $23 = ($24|0)==($6|0);
 if (!($23)) {
  $node$01$i = $24;
  while(1) {
   $25 = (($node$01$i) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   HEAP32[$node$01$i>>2] = 0;
   HEAP32[$25>>2] = 0;
   $27 = ($26|0)==($6|0);
   if ($27) {
    break;
   } else {
    $node$01$i = $26;
   }
  }
 }
 HEAP32[$7>>2] = $6;
 HEAP32[$6>>2] = $6;
 $28 = HEAP32[690120>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($this) + 124|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 120|0);
 $33 = ($31|0)==($32|0);
 if (!($33)) {
  $35 = $31;
  while(1) {
   $34 = (($35) + 36|0);
   $36 = HEAP32[$34>>2]|0;
   $37 = (($35) + 40|0);
   HEAP32[$37>>2] = 0;
   $38 = (($36) + 86|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = ($39<<24>>24)==(1);
   if ($40) {
    $41 = (($35) + 8|0);
    __ZNK9Rigidbody11GetPositionEv($0,$36);
    ;HEAP32[$41+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$0+8>>2]|0;
    $42 = (($35) + 20|0);
    __ZNK9Rigidbody11GetRotationEv($1,$36);
    ;HEAP32[$42+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$1+12>>2]|0;
   }
   $43 = (($35) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==($32|0);
   if ($45) {
    break;
   } else {
    $35 = $44;
   }
  }
 }
 __Z14UpdateVehiclesf($5);
 $46 = HEAP32[690016>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 220|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_vifiiii[$49 & 3]($46,$5,0,0,0,1);
 while(1) {
  $50 = HEAP32[690016>>2]|0;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + 232|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (FUNCTION_TABLE_iii[$53 & 4095]($50,0)|0);
  if ($54) {
   break;
  }
 }
 $55 = HEAP32[690016>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 236|0);
 $58 = HEAP32[$57>>2]|0;
 (FUNCTION_TABLE_iiii[$58 & 2047]($55,1,0)|0);
 $59 = +$5;
 $60 = (($this) + 824|0);
 $61 = +HEAPF64[$60>>3];
 $62 = $59 + $61;
 HEAPF64[$60>>3] = $62;
 $63 = (($this) + 112|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($this) + 108|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($64|0)==($66|0);
 if (!($67)) {
  $i$01$i1 = 0;
  while(1) {
   $68 = (__ZN5Unity10GameObject17GetMessageHandlerEv()|0);
   $69 = HEAP32[$65>>2]|0;
   $70 = (($69) + ($i$01$i1<<2)|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = HEAP32[((564104 + 8|0))>>2]|0;
   $73 = (($68) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = Math_imul($74, $72)|0;
   $76 = (($75) + ($71))|0;
   $77 = $76 & 31;
   $78 = 1 << $77;
   $79 = $78 ^ -1;
   $80 = $76 >>> 5;
   $81 = (($68) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($82) + ($80<<2)|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = $84 & $79;
   HEAP32[$83>>2] = $85;
   $86 = (($i$01$i1) + 1)|0;
   $87 = HEAP32[$63>>2]|0;
   $88 = $87;
   $89 = $69;
   $90 = (($88) - ($89))|0;
   $91 = $90 >> 2;
   $92 = ($86>>>0)<($91>>>0);
   if ($92) {
    $i$01$i1 = $86;
   } else {
    break;
   }
  }
 }
 $93 = (($this) + 58|0);
 HEAP8[$93>>0] = 0;
 $94 = (($velocityMessageData) + 8|0);
 HEAP32[$94>>2] = 0;
 $95 = (($velocityMessageData) + 4|0);
 HEAP32[$95>>2] = 0;
 HEAP32[$velocityMessageData>>2] = 0;
 $96 = (($pose) + 16|0);
 $97 = (($2) + 4|0);
 $98 = (($2) + 8|0);
 $99 = (($velocity) + 4|0);
 $100 = (($velocity) + 8|0);
 $inData$c$i = $velocity;
 $level$012 = 0;
 while(1) {
  $101 = ((($this) + ($level$012<<3)|0) + 136|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ((($this) + ($level$012<<3)|0) + 132|0);
  $104 = ($102|0)==($103|0);
  if (!($104)) {
   $106 = $102;
   while(1) {
    $105 = (($106) + 8|0);
    $107 = HEAP32[$105>>2]|0;
    $108 = (($107) + 40|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = HEAP32[$109>>2]|0;
    $111 = (($110) + 256|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (FUNCTION_TABLE_ii[$112 & 4095]($109)|0);
    if (!($113)) {
     $114 = (($107) + 72|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = ($115|0)==(0);
     if (!($116)) {
      __ZN9Rigidbody16ApplyConstraintsEv($107);
     }
     $117 = (($107) + 88|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = $118 & 1;
     $120 = ($119|0)==(0);
     if ($120) {
      $121 = (($107) + 24|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($122)|0);
      $124 = HEAP32[$109>>2]|0;
      $125 = (($124) + 84|0);
      $126 = HEAP32[$125>>2]|0;
      FUNCTION_TABLE_vii[$126 & 4095]($pose,$109);
      __ZN9Transform26SetPositionAndRotationSafeERK8Vector3fRK11Quaternionf($123,$96,$pose);
      $127 = (($122) + 52|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = $128 & 32;
      $130 = ($129|0)==(0);
      if (!($130)) {
       $131 = HEAP32[$109>>2]|0;
       $132 = (($131) + 152|0);
       $133 = HEAP32[$132>>2]|0;
       FUNCTION_TABLE_vii[$133 & 4095]($2,$109);
       $134 = Math_fround(HEAPF32[$2>>2]);
       $135 = Math_fround(HEAPF32[$97>>2]);
       $136 = Math_fround(HEAPF32[$98>>2]);
       HEAPF32[$velocity>>2] = $134;
       HEAPF32[$99>>2] = $135;
       HEAPF32[$100>>2] = $136;
       HEAP32[$95>>2] = $inData$c$i;
       HEAP32[$velocityMessageData>>2] = 100005;
       __ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData($122,566136,$velocityMessageData);
      }
     }
    }
    $137 = (($106) + 4|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($138|0)==($103|0);
    if ($139) {
     break;
    } else {
     $106 = $138;
    }
   }
  }
  $140 = (($level$012) + 1)|0;
  $exitcond = ($140|0)==(64);
  if ($exitcond) {
   break;
  } else {
   $level$012 = $140;
  }
 }
 $141 = HEAP32[$63>>2]|0;
 $142 = HEAP32[$65>>2]|0;
 $143 = ($141|0)==($142|0);
 if (!($143)) {
  $i$01$i = 0;
  while(1) {
   $144 = (__ZN5Unity10GameObject17GetMessageHandlerEv()|0);
   $145 = HEAP32[$65>>2]|0;
   $146 = (($145) + ($i$01$i<<2)|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = HEAP32[((564104 + 8|0))>>2]|0;
   $149 = (($144) + 28|0);
   $150 = HEAP32[$149>>2]|0;
   $151 = Math_imul($150, $148)|0;
   $152 = (($151) + ($147))|0;
   $153 = $152 & 31;
   $154 = 1 << $153;
   $155 = $152 >>> 5;
   $156 = (($144) + 4|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($157) + ($155<<2)|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = $154 | $159;
   HEAP32[$158>>2] = $160;
   $161 = (($i$01$i) + 1)|0;
   $162 = HEAP32[$63>>2]|0;
   $163 = $162;
   $164 = $145;
   $165 = (($163) - ($164))|0;
   $166 = $165 >> 2;
   $167 = ($161>>>0)<($166>>>0);
   if ($167) {
    $i$01$i = $161;
   } else {
    break;
   }
  }
 }
 HEAP8[$93>>0] = 1;
 __ZN14PhysicsManager22ProcessRecordedReportsEv($this);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager22ProcessRecordedReportsEv($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i39 = 0, $$0$i$i$i$i$i49 = 0, $$0$i$i$i$i35 = 0, $$0$i$i$i$i43 = 0, $$0$i$i$i$i53 = 0, $$0$i$i$i$i55 = 0, $$0$i$i$i59 = 0, $$0$ph6$i$i$i = 0, $$0$ph8$i$i$i = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i41 = 0, $$01$i$i$i$i51 = 0, $$01$i$i$i57 = 0, $$01$ph7$i$in$i$i = 0, $$014$i$in$i$i = 0, $$be$in = 0, $$pr = 0;
 var $$pre = 0, $$pre139 = 0, $$pre140 = 0, $$pre141 = 0, $$pre142 = 0, $$sroa$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__f$01$i$i$i$i$i$i$i$i$i$i$i = 0, $i$0116 = 0, $i2$084 = 0, $i3$076 = 0, $inData$c$i$i11 = 0, $inData$c$i$i18 = 0, $inData$c$i$i33 = 0, $kStayTrigger$byval_copy = 0, $or$cond = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i22 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i26 = 0, $shapePair = 0, $temp$0$i147 = 0, $temp$0$i5145 = 0, $uglygep$i$i$i = 0;
 var $uglygep$i$i$i24 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $kStayTrigger$byval_copy = sp + 36|0;
 $0 = sp;
 $1 = sp + 4|0;
 $shapePair = sp + 8|0;
 $$sroa$1 = sp + 56|0;
 $2 = sp + 16|0;
 __Z30SetDisableImmediateDestructionb(1);
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if (!($7)) {
  $8 = (($shapePair) + 4|0);
  $9 = (($2) + 4|0);
  $10 = (($2) + 8|0);
  $11 = (($2) + 12|0);
  $12 = (($2) + 16|0);
  $13 = (($this) + 784|0);
  $14 = (($this) + 788|0);
  $15 = (($this) + 788|0);
  $16 = (($this) + 784|0);
  $17 = (($this) + 792|0);
  $19 = $6;$374 = $4;$375 = 0;$i$0116 = 0;
  while(1) {
   $18 = ((($19) + (($i$0116*12)|0)|0) + 8|0);
   $20 = ((($19) + (($i$0116*12)|0)|0) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 32|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$18>>2]|0;
   $25 = (($24) + 32|0);
   $26 = HEAP32[$25>>2]|0;
   HEAP32[$shapePair>>2] = $23;
   HEAP32[$8>>2] = $26;
   $27 = ($23|0)==(0|0);
   $28 = ($26|0)==(0|0);
   $or$cond = $27 | $28;
   if ($or$cond) {
    $376 = $375;$92 = $374;$94 = $19;
   } else {
    $29 = (($19) + (($i$0116*12)|0)|0);
    $30 = HEAP32[$29>>2]|0;
    if ((($30|0) == 16)) {
     $42 = HEAP32[563584>>2]|0;
     $43 = HEAP32[((563584 + 4|0))>>2]|0;
     $44 = HEAP32[((563584 + 8|0))>>2]|0;
     $45 = HEAP32[((563584 + 12|0))>>2]|0;
     $46 = HEAP32[((563584 + 16|0))>>2]|0;
     $47 = HEAP32[$14>>2]|0;
     $48 = ($47|0)==(0|0);
     if ($48) {
      label = 17;
     } else {
      $$0$ph8$i$i$i = $15;$$01$ph7$i$in$i$i = $47;
      L10: while(1) {
       $$014$i$in$i$i = $$01$ph7$i$in$i$i;
       while(1) {
        $49 = (($$014$i$in$i$i) + 16|0);
        $50 = HEAP32[$49>>2]|0;
        $51 = ($50>>>0)<($23>>>0);
        if (!($51)) {
         $52 = ($23>>>0)<($50>>>0);
         if ($52) {
          break;
         }
         $53 = (($$014$i$in$i$i) + 20|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = ($54>>>0)<($26>>>0);
         if (!($55)) {
          break;
         }
        }
        $58 = (($$014$i$in$i$i) + 4|0);
        $59 = HEAP32[$58>>2]|0;
        $60 = ($59|0)==(0|0);
        if ($60) {
         $$0$ph6$i$i$i = $$0$ph8$i$i$i;
         break L10;
        } else {
         $$014$i$in$i$i = $59;
        }
       }
       $56 = HEAP32[$$014$i$in$i$i>>2]|0;
       $57 = ($56|0)==(0|0);
       if ($57) {
        $$0$ph6$i$i$i = $$014$i$in$i$i;
        break;
       } else {
        $$0$ph8$i$i$i = $$014$i$in$i$i;$$01$ph7$i$in$i$i = $56;
       }
      }
      $61 = ($$0$ph6$i$i$i|0)==($15|0);
      if ($61) {
       label = 17;
      } else {
       $62 = (($$0$ph6$i$i$i) + 16|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = ($23>>>0)<($63>>>0);
       if ($64) {
        label = 17;
       } else {
        $65 = ($63>>>0)<($23>>>0);
        if ($65) {
         $70 = $$0$ph6$i$i$i;
        } else {
         $66 = (($$0$ph6$i$i$i) + 20|0);
         $67 = HEAP32[$66>>2]|0;
         $68 = ($26>>>0)<($67>>>0);
         if ($68) {
          label = 17;
         } else {
          $70 = $$0$ph6$i$i$i;
         }
        }
       }
      }
     }
     if ((label|0) == 17) {
      label = 0;
      $70 = $15;
     }
     $69 = (($70) + 4|0);
     $71 = HEAP32[$69>>2]|0;
     $72 = ($71|0)==(0|0);
     if ($72) {
      $$01$i$i$i$i = $70;
      while(1) {
       $75 = (($$01$i$i$i$i) + 8|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = HEAP32[$76>>2]|0;
       $78 = ($77|0)==($$01$i$i$i$i|0);
       if ($78) {
        $$0$i$i$i$i = $76;
        break;
       } else {
        $$01$i$i$i$i = $76;
       }
      }
     } else {
      $$0$i$i$i$i$i = $71;
      while(1) {
       $73 = HEAP32[$$0$i$i$i$i$i>>2]|0;
       $74 = ($73|0)==(0|0);
       if ($74) {
        $$0$i$i$i$i = $$0$i$i$i$i$i;
        break;
       } else {
        $$0$i$i$i$i$i = $73;
       }
      }
     }
     $79 = HEAP32[$16>>2]|0;
     $80 = ($79|0)==($70|0);
     if ($80) {
      HEAP32[$16>>2] = $$0$i$i$i$i;
     }
     $81 = HEAP32[$17>>2]|0;
     $82 = (($81) + -1)|0;
     HEAP32[$17>>2] = $82;
     __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($47,$70);
     __ZdlPv($70);
     $85 = $42;$86 = $43;$87 = $44;$88 = $45;$89 = $46;
    } else if ((($30|0) == 4)) {
     $31 = HEAP32[563544>>2]|0;
     $32 = HEAP32[((563544 + 4|0))>>2]|0;
     $33 = HEAP32[((563544 + 8|0))>>2]|0;
     $34 = HEAP32[((563544 + 12|0))>>2]|0;
     $35 = HEAP32[((563544 + 16|0))>>2]|0;
     $36 = (__ZNSt3__13mapINS_4pairIPN5physx7PxShapeES4_EEN14PhysicsManager16TriggerStayStateENS_4lessIS5_EENS_9allocatorINS1_IKS5_S7_EEEEEixERSB_($13,$shapePair)|0);
     $37 = HEAP32[$20>>2]|0;
     $38 = HEAP32[$18>>2]|0;
     HEAP8[$36>>0] = 1;
     $39 = (($36) + 1|0);
     ;HEAP8[$39+0>>0]=HEAP8[$$sroa$1+0>>0]|0;HEAP8[$39+1>>0]=HEAP8[$$sroa$1+1>>0]|0;HEAP8[$39+2>>0]=HEAP8[$$sroa$1+2>>0]|0;
     $40 = (($36) + 4|0);
     HEAP32[$40>>2] = $37;
     $41 = (($36) + 8|0);
     HEAP32[$41>>2] = $38;
     $85 = $31;$86 = $32;$87 = $33;$88 = $34;$89 = $35;
    } else {
     $85 = 0;$86 = 0;$87 = -1;$88 = $375;$89 = 1;
    }
    $83 = HEAP32[$20>>2]|0;
    $84 = HEAP32[$18>>2]|0;
    HEAP32[$2>>2] = $85;
    HEAP32[$9>>2] = $86;
    HEAP32[$10>>2] = $87;
    HEAP32[$11>>2] = $88;
    HEAP32[$12>>2] = $89;
    ;HEAP32[$kStayTrigger$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$kStayTrigger$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$kStayTrigger$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$kStayTrigger$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$kStayTrigger$byval_copy+16>>2]=HEAP32[$2+16>>2]|0;
    __ZL16SendTriggerEventP8ColliderS0_17MessageIdentifier($83,$84,$kStayTrigger$byval_copy);
    $$pre141 = HEAP32[$3>>2]|0;
    $$pre142 = HEAP32[$5>>2]|0;
    $376 = $88;$92 = $$pre141;$94 = $$pre142;
   }
   $90 = (($i$0116) + 1)|0;
   $91 = $92;
   $93 = $94;
   $95 = (($91) - ($93))|0;
   $96 = (($95|0) / 12)&-1;
   $97 = ($90>>>0)<($96>>>0);
   if ($97) {
    $19 = $94;$374 = $92;$375 = $376;$i$0116 = $90;
   } else {
    break;
   }
  }
  $98 = ($92|0)==($94|0);
  if (!($98)) {
   $scevgep$i$i$i22 = (($92) + -12|0);
   $99 = (0 - ($93))|0;
   $uglygep$i$i$i24 = (($scevgep$i$i$i22) + ($99)|0);
   $uglygep3$i$i$i25 = $uglygep$i$i$i24;
   $100 = (($uglygep3$i$i$i25>>>0) / 12)&-1;
   $101 = $100 ^ -1;
   $scevgep4$i$i$i26 = (($92) + (($101*12)|0)|0);
   HEAP32[$3>>2] = $scevgep4$i$i$i26;
  }
 }
 $102 = (($this) + 784|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($this) + 788|0);
 $105 = ($103|0)==($104|0);
 if ($105) {
  $131 = $103;
 } else {
  $107 = $103;
  while(1) {
   $106 = (($107) + 24|0);
   $108 = HEAP8[$106>>0]|0;
   $109 = ($108<<24>>24)==(0);
   if ($109) {
    $110 = (($107) + 28|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = (($111) + 32|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = ($113|0)==(0|0);
    if (!($114)) {
     $115 = (($107) + 32|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = (($116) + 32|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = ($118|0)==(0|0);
     if (!($119)) {
      ;HEAP32[$kStayTrigger$byval_copy+0>>2]=HEAP32[563624+0>>2]|0;HEAP32[$kStayTrigger$byval_copy+4>>2]=HEAP32[563624+4>>2]|0;HEAP32[$kStayTrigger$byval_copy+8>>2]=HEAP32[563624+8>>2]|0;HEAP32[$kStayTrigger$byval_copy+12>>2]=HEAP32[563624+12>>2]|0;HEAP32[$kStayTrigger$byval_copy+16>>2]=HEAP32[563624+16>>2]|0;
      __ZL16SendTriggerEventP8ColliderS0_17MessageIdentifier($111,$116,$kStayTrigger$byval_copy);
     }
    }
   } else {
    HEAP8[$106>>0] = 0;
   }
   $120 = (($107) + 4|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($121|0)==(0|0);
   if ($122) {
    $$01$i$i$i57 = $107;
    while(1) {
     $125 = (($$01$i$i$i57) + 8|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = HEAP32[$126>>2]|0;
     $128 = ($127|0)==($$01$i$i$i57|0);
     if ($128) {
      $$0$i$i$i59 = $126;
      break;
     } else {
      $$01$i$i$i57 = $126;
     }
    }
   } else {
    $$0$i$i$i$i55 = $121;
    while(1) {
     $123 = HEAP32[$$0$i$i$i$i55>>2]|0;
     $124 = ($123|0)==(0|0);
     if ($124) {
      $$0$i$i$i59 = $$0$i$i$i$i55;
      break;
     } else {
      $$0$i$i$i$i55 = $123;
     }
    }
   }
   $129 = ($$0$i$i$i59|0)==($104|0);
   if ($129) {
    break;
   } else {
    $107 = $$0$i$i$i59;
   }
  }
  $$pre = HEAP32[$102>>2]|0;
  $131 = $$pre;
 }
 $130 = ($131|0)==($104|0);
 if (!($130)) {
  $132 = (($this) + 792|0);
  $133 = (($this) + 788|0);
  $152 = $131;
  while(1) {
   $151 = (($152) + 28|0);
   $153 = HEAP32[$151>>2]|0;
   $154 = (($153) + 32|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = ($155|0)==(0|0);
   L64: do {
    if ($156) {
     label = 47;
    } else {
     $157 = (($152) + 32|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (($158) + 32|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = ($160|0)==(0|0);
     if ($161) {
      label = 47;
     } else {
      $183 = (($152) + 4|0);
      $184 = HEAP32[$183>>2]|0;
      $185 = ($184|0)==(0|0);
      if (!($185)) {
       $$0$i$i$i$i35 = $184;
       while(1) {
        $186 = HEAP32[$$0$i$i$i$i35>>2]|0;
        $187 = ($186|0)==(0|0);
        if ($187) {
         $$be$in = $$0$i$i$i$i35;
         break L64;
        } else {
         $$0$i$i$i$i35 = $186;
        }
       }
      }
      $$01$i$i$i = $152;
      while(1) {
       $188 = (($$01$i$i$i) + 8|0);
       $189 = HEAP32[$188>>2]|0;
       $190 = HEAP32[$189>>2]|0;
       $191 = ($190|0)==($$01$i$i$i|0);
       if ($191) {
        $$be$in = $189;
        break;
       } else {
        $$01$i$i$i = $189;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 47) {
    label = 0;
    $162 = (($152) + 4|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = ($163|0)==(0|0);
    if ($164) {
     $$01$i$i$i$i51 = $152;
     while(1) {
      $167 = (($$01$i$i$i$i51) + 8|0);
      $168 = HEAP32[$167>>2]|0;
      $169 = HEAP32[$168>>2]|0;
      $170 = ($169|0)==($$01$i$i$i$i51|0);
      if ($170) {
       $$0$i$i$i$i53 = $168;
       break;
      } else {
       $$01$i$i$i$i51 = $168;
      }
     }
    } else {
     $$0$i$i$i$i$i49 = $163;
     while(1) {
      $165 = HEAP32[$$0$i$i$i$i$i49>>2]|0;
      $166 = ($165|0)==(0|0);
      if ($166) {
       $$0$i$i$i$i53 = $$0$i$i$i$i$i49;
       break;
      } else {
       $$0$i$i$i$i$i49 = $165;
      }
     }
    }
    if ($164) {
     $$01$i$i$i$i41 = $152;
     while(1) {
      $173 = (($$01$i$i$i$i41) + 8|0);
      $174 = HEAP32[$173>>2]|0;
      $175 = HEAP32[$174>>2]|0;
      $176 = ($175|0)==($$01$i$i$i$i41|0);
      if ($176) {
       $$0$i$i$i$i43 = $174;
       break;
      } else {
       $$01$i$i$i$i41 = $174;
      }
     }
    } else {
     $$0$i$i$i$i$i39 = $163;
     while(1) {
      $171 = HEAP32[$$0$i$i$i$i$i39>>2]|0;
      $172 = ($171|0)==(0|0);
      if ($172) {
       $$0$i$i$i$i43 = $$0$i$i$i$i$i39;
       break;
      } else {
       $$0$i$i$i$i$i39 = $171;
      }
     }
    }
    $177 = HEAP32[$102>>2]|0;
    $178 = ($177|0)==($152|0);
    if ($178) {
     HEAP32[$102>>2] = $$0$i$i$i$i43;
    }
    $179 = HEAP32[$132>>2]|0;
    $180 = (($179) + -1)|0;
    HEAP32[$132>>2] = $180;
    $181 = HEAP32[$133>>2]|0;
    __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($181,$152);
    __ZdlPv($152);
    $$be$in = $$0$i$i$i$i53;
   }
   $182 = ($$be$in|0)==($104|0);
   if ($182) {
    break;
   } else {
    $152 = $$be$in;
   }
  }
 }
 $134 = (($this) + 84|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($this) + 80|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($135|0)==($137|0);
 if (!($138)) {
  $139 = (($kStayTrigger$byval_copy) + 8|0);
  $140 = (($kStayTrigger$byval_copy) + 4|0);
  $141 = (($kStayTrigger$byval_copy) + 8|0);
  $142 = (($kStayTrigger$byval_copy) + 4|0);
  $143 = (($kStayTrigger$byval_copy) + 8|0);
  $144 = (($kStayTrigger$byval_copy) + 4|0);
  $145 = (($kStayTrigger$byval_copy) + 8|0);
  $146 = (($kStayTrigger$byval_copy) + 4|0);
  $147 = (($kStayTrigger$byval_copy) + 8|0);
  $148 = (($kStayTrigger$byval_copy) + 4|0);
  $149 = (($kStayTrigger$byval_copy) + 8|0);
  $150 = (($kStayTrigger$byval_copy) + 4|0);
  $193 = $137;$i2$084 = 0;
  while(1) {
   $192 = (($193) + (($i2$084*72)|0)|0);
   $194 = HEAP32[$192>>2]|0;
   $195 = $194 & 4;
   $196 = ($195|0)==(0);
   if ($196) {
    $211 = $194;
   } else {
    $197 = ((($193) + (($i2$084*72)|0)|0) + 4|0);
    HEAP8[$197>>0] = 0;
    $198 = ((($193) + (($i2$084*72)|0)|0) + 8|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = ($199|0)==(0|0);
    if ($200) {
     $201 = ((($193) + (($i2$084*72)|0)|0) + 16|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = $202;
    } else {
     $203 = $199;
    }
    HEAP32[$147>>2] = 0;
    $inData$c$i$i33 = $192;
    HEAP32[$148>>2] = $inData$c$i$i33;
    HEAP32[$kStayTrigger$byval_copy>>2] = 100004;
    __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($203,563664,$kStayTrigger$byval_copy);
    HEAP8[$197>>0] = 1;
    $204 = ((($193) + (($i2$084*72)|0)|0) + 12|0);
    $205 = HEAP32[$204>>2]|0;
    $206 = ($205|0)==(0|0);
    if ($206) {
     $207 = ((($193) + (($i2$084*72)|0)|0) + 20|0);
     $208 = HEAP32[$207>>2]|0;
     $209 = $208;
    } else {
     $209 = $205;
    }
    HEAP32[$149>>2] = 0;
    HEAP32[$150>>2] = $inData$c$i$i33;
    HEAP32[$kStayTrigger$byval_copy>>2] = 100004;
    __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($209,563664,$kStayTrigger$byval_copy);
    $$pre139 = HEAP32[$192>>2]|0;
    $211 = $$pre139;
   }
   $210 = $211 & 16;
   $212 = ($210|0)==(0);
   if ($212) {
    $227 = $211;
   } else {
    $213 = ((($193) + (($i2$084*72)|0)|0) + 4|0);
    HEAP8[$213>>0] = 0;
    $214 = ((($193) + (($i2$084*72)|0)|0) + 8|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = ($215|0)==(0|0);
    if ($216) {
     $217 = ((($193) + (($i2$084*72)|0)|0) + 16|0);
     $218 = HEAP32[$217>>2]|0;
     $219 = $218;
    } else {
     $219 = $215;
    }
    HEAP32[$143>>2] = 0;
    $inData$c$i$i18 = $192;
    HEAP32[$144>>2] = $inData$c$i$i18;
    HEAP32[$kStayTrigger$byval_copy>>2] = 100004;
    __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($219,563712,$kStayTrigger$byval_copy);
    HEAP8[$213>>0] = 1;
    $220 = ((($193) + (($i2$084*72)|0)|0) + 12|0);
    $221 = HEAP32[$220>>2]|0;
    $222 = ($221|0)==(0|0);
    if ($222) {
     $223 = ((($193) + (($i2$084*72)|0)|0) + 20|0);
     $224 = HEAP32[$223>>2]|0;
     $225 = $224;
    } else {
     $225 = $221;
    }
    HEAP32[$145>>2] = 0;
    HEAP32[$146>>2] = $inData$c$i$i18;
    HEAP32[$kStayTrigger$byval_copy>>2] = 100004;
    __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($225,563712,$kStayTrigger$byval_copy);
    $$pre140 = HEAP32[$192>>2]|0;
    $227 = $$pre140;
   }
   $226 = $227 & 8;
   $228 = ($226|0)==(0);
   if (!($228)) {
    $229 = ((($193) + (($i2$084*72)|0)|0) + 4|0);
    HEAP8[$229>>0] = 0;
    $230 = ((($193) + (($i2$084*72)|0)|0) + 8|0);
    $231 = HEAP32[$230>>2]|0;
    $232 = ($231|0)==(0|0);
    if ($232) {
     $233 = ((($193) + (($i2$084*72)|0)|0) + 16|0);
     $234 = HEAP32[$233>>2]|0;
     $235 = $234;
    } else {
     $235 = $231;
    }
    HEAP32[$139>>2] = 0;
    $inData$c$i$i11 = $192;
    HEAP32[$140>>2] = $inData$c$i$i11;
    HEAP32[$kStayTrigger$byval_copy>>2] = 100004;
    __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($235,563752,$kStayTrigger$byval_copy);
    HEAP8[$229>>0] = 1;
    $236 = ((($193) + (($i2$084*72)|0)|0) + 12|0);
    $237 = HEAP32[$236>>2]|0;
    $238 = ($237|0)==(0|0);
    if ($238) {
     $239 = ((($193) + (($i2$084*72)|0)|0) + 20|0);
     $240 = HEAP32[$239>>2]|0;
     $241 = $240;
    } else {
     $241 = $237;
    }
    HEAP32[$141>>2] = 0;
    HEAP32[$142>>2] = $inData$c$i$i11;
    HEAP32[$kStayTrigger$byval_copy>>2] = 100004;
    __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($241,563752,$kStayTrigger$byval_copy);
   }
   $242 = (($i2$084) + 1)|0;
   $243 = HEAP32[$134>>2]|0;
   $244 = HEAP32[$136>>2]|0;
   $245 = $243;
   $246 = $244;
   $247 = (($245) - ($246))|0;
   $248 = (($247|0) / 72)&-1;
   $249 = ($242>>>0)<($248>>>0);
   if ($249) {
    $193 = $244;$i2$084 = $242;
   } else {
    break;
   }
  }
  $250 = ($243|0)==($244|0);
  if (!($250)) {
   $252 = $243;
   while(1) {
    $251 = (($252) + -72|0);
    HEAP32[$134>>2] = $251;
    $253 = (($252) + -12|0);
    $254 = (($252) + -4|0);
    $255 = HEAP32[$254>>2]|0;
    $256 = ($255|0)==(0);
    if (!($256)) {
     $266 = (($252) + -8|0);
     $267 = HEAP32[$266>>2]|0;
     $268 = HEAP32[$253>>2]|0;
     $269 = (($268) + 4|0);
     $270 = HEAP32[$269>>2]|0;
     $271 = HEAP32[$267>>2]|0;
     $272 = (($271) + 4|0);
     HEAP32[$272>>2] = $270;
     $273 = HEAP32[$267>>2]|0;
     $274 = HEAP32[$269>>2]|0;
     HEAP32[$274>>2] = $273;
     HEAP32[$254>>2] = 0;
     $275 = ($267|0)==($253|0);
     if (!($275)) {
      $__f$01$i$i$i$i$i$i$i$i$i$i$i = $267;
      while(1) {
       $276 = (($__f$01$i$i$i$i$i$i$i$i$i$i$i) + 4|0);
       $277 = HEAP32[$276>>2]|0;
       __ZdlPv($__f$01$i$i$i$i$i$i$i$i$i$i$i);
       $278 = ($277|0)==($253|0);
       if ($278) {
        break;
       } else {
        $__f$01$i$i$i$i$i$i$i$i$i$i$i = $277;
       }
      }
     }
    }
    $257 = HEAP32[$134>>2]|0;
    $258 = ($257|0)==($244|0);
    if ($258) {
     break;
    } else {
     $252 = $257;
    }
   }
  }
 }
 $259 = (($this) + 96|0);
 $260 = HEAP32[$259>>2]|0;
 $261 = (($this) + 92|0);
 $262 = HEAP32[$261>>2]|0;
 $263 = ($260|0)==($262|0);
 if ($263) {
  __Z30SetDisableImmediateDestructionb(0);
  STACKTOP = sp;return;
 }
 $264 = (($kStayTrigger$byval_copy) + 8|0);
 $265 = (($kStayTrigger$byval_copy) + 4|0);
 $280 = $262;$i3$076 = 0;
 while(1) {
  $279 = ((($280) + (($i3$076*12)|0)|0) + 8|0);
  $281 = HEAP32[$279>>2]|0;
  $282 = ($281|0)==(0);
  do {
   if (!($282)) {
    HEAP32[$0>>2] = $281;
    $283 = HEAP32[560624>>2]|0;
    $284 = ($283|0)==(0|0);
    if ($284) {
     label = 104;
    } else {
     $285 = (($283) + 36|0);
     $286 = HEAP32[$285>>2]|0;
     $287 = (($283) + 4|0);
     $288 = HEAP32[$287>>2]|0;
     $289 = ($286|0)==($288|0);
     do {
      if ($289) {
       $290 = (($283) + 28|0);
       $291 = HEAP32[$290>>2]|0;
       $292 = (($283) + 32|0);
       $293 = HEAP32[$292>>2]|0;
       $294 = (($291) + ($293<<3)|0);
       $310 = $294;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($kStayTrigger$byval_copy,$283,$0);
       $295 = HEAP32[$kStayTrigger$byval_copy>>2]|0;
       $296 = ($295|0)==(-1);
       $297 = (($283) + 28|0);
       $298 = HEAP32[$297>>2]|0;
       if ($296) {
        $299 = (($283) + 32|0);
        $300 = HEAP32[$299>>2]|0;
        $301 = (($298) + ($300<<3)|0);
        $310 = $301;
        break;
       } else {
        $302 = (($298) + ($295<<3)|0);
        $310 = $302;
        break;
       }
      }
     } while(0);
     $303 = HEAP32[560624>>2]|0;
     $304 = (($303) + 28|0);
     $305 = HEAP32[$304>>2]|0;
     $306 = (($303) + 32|0);
     $307 = HEAP32[$306>>2]|0;
     $308 = (($305) + ($307<<3)|0);
     $309 = ($310|0)==($308|0);
     if ($309) {
      label = 104;
     } else {
      $311 = (($310) + 4|0);
      $312 = HEAP32[$311>>2]|0;
      $313 = ($312|0)==(0|0);
      if ($313) {
       label = 104;
      } else {
       $temp$0$i5145 = $312;
       label = 105;
      }
     }
    }
    if ((label|0) == 104) {
     label = 0;
     $314 = HEAP32[$279>>2]|0;
     $315 = (__Z31ReadObjectFromPersistentManageri($314)|0);
     $316 = ($315|0)==(0|0);
     if (!($316)) {
      $temp$0$i5145 = $315;
      label = 105;
     }
    }
    if ((label|0) == 105) {
     label = 0;
     $317 = (($temp$0$i5145) + 24|0);
     $318 = HEAP32[$317>>2]|0;
     $319 = ($318|0)==(0|0);
     if (!($319)) {
      $320 = (__ZNK5Unity10GameObject8IsActiveEv($318)|0);
      if ($320) {
       $321 = HEAP32[$317>>2]|0;
       $322 = (($280) + (($i3$076*12)|0)|0);
       $323 = Math_fround(HEAPF32[$322>>2]);
       HEAP32[$264>>2] = 0;
       HEAPF32[$265>>2] = $323;
       HEAP32[$kStayTrigger$byval_copy>>2] = 100002;
       __ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData($321,564064,$kStayTrigger$byval_copy);
      }
     }
    }
    $$pr = HEAP32[$279>>2]|0;
    $324 = ($$pr|0)==(0);
    if (!($324)) {
     HEAP32[$1>>2] = $$pr;
     $325 = HEAP32[560624>>2]|0;
     $326 = ($325|0)==(0|0);
     if ($326) {
      label = 117;
     } else {
      $327 = (($325) + 36|0);
      $328 = HEAP32[$327>>2]|0;
      $329 = (($325) + 4|0);
      $330 = HEAP32[$329>>2]|0;
      $331 = ($328|0)==($330|0);
      do {
       if ($331) {
        $332 = (($325) + 28|0);
        $333 = HEAP32[$332>>2]|0;
        $334 = (($325) + 32|0);
        $335 = HEAP32[$334>>2]|0;
        $336 = (($333) + ($335<<3)|0);
        $352 = $336;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($kStayTrigger$byval_copy,$325,$1);
        $337 = HEAP32[$kStayTrigger$byval_copy>>2]|0;
        $338 = ($337|0)==(-1);
        $339 = (($325) + 28|0);
        $340 = HEAP32[$339>>2]|0;
        if ($338) {
         $341 = (($325) + 32|0);
         $342 = HEAP32[$341>>2]|0;
         $343 = (($340) + ($342<<3)|0);
         $352 = $343;
         break;
        } else {
         $344 = (($340) + ($337<<3)|0);
         $352 = $344;
         break;
        }
       }
      } while(0);
      $345 = HEAP32[560624>>2]|0;
      $346 = (($345) + 28|0);
      $347 = HEAP32[$346>>2]|0;
      $348 = (($345) + 32|0);
      $349 = HEAP32[$348>>2]|0;
      $350 = (($347) + ($349<<3)|0);
      $351 = ($352|0)==($350|0);
      if ($351) {
       label = 117;
      } else {
       $353 = (($352) + 4|0);
       $354 = HEAP32[$353>>2]|0;
       $355 = ($354|0)==(0|0);
       if ($355) {
        label = 117;
       } else {
        $temp$0$i147 = $354;
       }
      }
     }
     if ((label|0) == 117) {
      label = 0;
      $356 = HEAP32[$279>>2]|0;
      $357 = (__Z31ReadObjectFromPersistentManageri($356)|0);
      $358 = ($357|0)==(0|0);
      if ($358) {
       break;
      } else {
       $temp$0$i147 = $357;
      }
     }
     $359 = (($temp$0$i147) + 24|0);
     $360 = HEAP32[$359>>2]|0;
     $361 = ($360|0)==(0|0);
     if (!($361)) {
      __Z30SetDisableImmediateDestructionb(0);
      __Z22DestroyObjectHighLevelP6Objectb($temp$0$i147,1);
      __Z30SetDisableImmediateDestructionb(1);
     }
    }
   }
  } while(0);
  $362 = (($i3$076) + 1)|0;
  $363 = HEAP32[$259>>2]|0;
  $364 = HEAP32[$261>>2]|0;
  $365 = $363;
  $366 = $364;
  $367 = (($365) - ($366))|0;
  $368 = (($367|0) / 12)&-1;
  $369 = ($362>>>0)<($368>>>0);
  if ($369) {
   $280 = $364;$i3$076 = $362;
  } else {
   break;
  }
 }
 $370 = ($363|0)==($364|0);
 if ($370) {
  __Z30SetDisableImmediateDestructionb(0);
  STACKTOP = sp;return;
 }
 $scevgep$i$i$i = (($363) + -12|0);
 $371 = (0 - ($366))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($371)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $372 = (($uglygep3$i$i$i>>>0) / 12)&-1;
 $373 = $372 ^ -1;
 $scevgep4$i$i$i = (($363) + (($373*12)|0)|0);
 HEAP32[$259>>2] = $scevgep4$i$i$i;
 __Z30SetDisableImmediateDestructionb(0);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager18SkinnedClothUpdateEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $storemerge$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 128|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = $2 == Math_fround(0.0);
 $4 = (__Z14GetTimeManagerv()|0);
 $5 = (($4) + 104|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 if ($3) {
  $storemerge$i = $6;
 } else {
  $7 = Math_fround($6 * Math_fround(0.00999999977648258209228));
  $8 = Math_fround($2 * Math_fround(0.990000009536743164062));
  $9 = Math_fround($8 + $7);
  $storemerge$i = $9;
 }
 HEAPF32[$1>>2] = $storemerge$i;
 $10 = HEAP32[690168>>2]|0;
 $11 = ($10|0)==(0|0);
 do {
  if (!($11)) {
   $12 = (($this) + 660|0);
   __ZN19SkinnedMeshRenderer22UpdateAllSkinnedMeshesENS_10UpdateTypeEP13dynamic_arrayIPS_Lj4EE(0,$12);
   $13 = HEAP32[690168>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 72|0);
   $16 = HEAP32[$15>>2]|0;
   HEAP16[$$byval_copy>>1] = 32;
   $17 = (FUNCTION_TABLE_iii[$16 & 4095]($13,$$byval_copy)|0);
   $18 = ($17|0)==(0);
   $19 = HEAP32[690168>>2]|0;
   if ($18) {
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    FUNCTION_TABLE_vi[$22 & 4095]($19);
    HEAP32[690168>>2] = 0;
    break;
   } else {
    __ZN14PhysicsManager21SimulateClothingSceneEPv($19);
    break;
   }
  }
 } while(0);
 $23 = (($this) + 652|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  __Z21CompleteFenceInternalR8JobFence($23);
 }
 $26 = (($this) + 660|0);
 __ZN19SkinnedMeshRenderer12UploadClothsERK13dynamic_arrayIPS_Lj4EE($26);
 $27 = (($this) + 672|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)>(-1);
 if (!($29)) {
  $33 = (($this) + 668|0);
  HEAP32[$33>>2] = 0;
  HEAP32[$27>>2] = 0;
  STACKTOP = sp;return;
 }
 $30 = HEAP32[$26>>2]|0;
 $31 = (($this) + 664|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP32[$0>>2] = $32;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($30,$$byval_copy);
 HEAP32[$26>>2] = 0;
 $33 = (($this) + 668|0);
 HEAP32[$33>>2] = 0;
 HEAP32[$27>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager16GetClothingSceneEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $sceneDesc = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $sceneDesc = sp;
 $0 = HEAP32[690168>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $46 = $0;
  STACKTOP = sp;return ($46|0);
 }
 $2 = HEAP32[690120>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = (($sceneDesc) + 80|0);
 dest=$sceneDesc+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $8 = Math_fround(HEAPF32[$6>>2]);
 $9 = Math_fround($8 * Math_fround(0.00999999977648258209228));
 HEAPF32[$7>>2] = $9;
 $10 = (($sceneDesc) + 84|0);
 HEAP32[$10>>2] = 0;
 $11 = (($sceneDesc) + 88|0);
 $12 = Math_fround(HEAPF32[$6>>2]);
 $13 = Math_fround($12 * Math_fround(0.0250000003725290298462));
 HEAPF32[$11>>2] = $13;
 $14 = (($sceneDesc) + 92|0);
 $15 = (($6) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * Math_fround(0.20000000298023223877));
 HEAPF32[$14>>2] = $17;
 $18 = (($sceneDesc) + 96|0);
 $19 = Math_fround(HEAPF32[$6>>2]);
 $20 = Math_fround($19 * Math_fround(0.0399999991059303283691));
 HEAPF32[$18>>2] = $20;
 $21 = (($sceneDesc) + 100|0);
 HEAP16[$21>>1] = 0;
 $22 = (($sceneDesc) + 104|0);
 $23 = (($sceneDesc) + 108|0);
 HEAP32[$23>>2] = 0;
 $24 = (($sceneDesc) + 112|0);
 HEAP32[$24>>2] = 0;
 $25 = (($sceneDesc) + 116|0);
 HEAP32[$25>>2] = 1;
 $26 = (($sceneDesc) + 120|0);
 HEAP32[$26>>2] = 1;
 $27 = (($sceneDesc) + 124|0);
 HEAP32[$27>>2] = 100;
 $28 = (($sceneDesc) + 128|0);
 HEAP32[$28>>2] = 0;
 $29 = (($sceneDesc) + 132|0);
 HEAP32[$29>>2] = 128;
 $30 = (($sceneDesc) + 136|0);
 HEAP32[$30>>2] = 0;
 $31 = (($sceneDesc) + 140|0);
 HEAP32[$31>>2] = 65536;
 $32 = (($sceneDesc) + 144|0);
 HEAP32[$32>>2] = 8192;
 $33 = (($sceneDesc) + 148|0);
 HEAP32[$33>>2] = 1;
 $34 = (($sceneDesc) + 152|0);
 HEAP32[$34>>2] = 0;
 $35 = (($sceneDesc) + 156|0);
 HEAPF32[$35>>2] = Math_fround(0.399999976158142089844);
 HEAP32[$22>>2] = 689904;
 $36 = (($sceneDesc) + 32|0);
 HEAP32[$36>>2] = 32;
 $37 = HEAP32[690120>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 92|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (FUNCTION_TABLE_iii[$40 & 4095]($37,$sceneDesc)|0);
 HEAP32[690168>>2] = $41;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 248|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 28|0);
 FUNCTION_TABLE_vii[$44 & 4095]($41,$45);
 $$pre = HEAP32[690168>>2]|0;
 $46 = $$pre;
 STACKTOP = sp;return ($46|0);
}
function __ZN14PhysicsManager6UpdateEv($this) {
 $this = $this|0;
 var $$$i = Math_fround(0), $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = Math_fround(0);
 var $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$01$i1 = 0, $pos = 0, $rot = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $rot = sp + 112|0;
 $pos = sp + 100|0;
 $0 = sp + 88|0;
 $1 = sp + 72|0;
 $2 = sp + 56|0;
 $3 = sp + 24|0;
 $4 = sp + 12|0;
 $5 = sp;
 $6 = sp + 40|0;
 $7 = (($this) + 112|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if (!($11)) {
  $i$01$i = 0;
  while(1) {
   $12 = (__ZN5Unity10GameObject17GetMessageHandlerEv()|0);
   $13 = HEAP32[$9>>2]|0;
   $14 = (($13) + ($i$01$i<<2)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[((564104 + 8|0))>>2]|0;
   $17 = (($12) + 28|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = Math_imul($18, $16)|0;
   $20 = (($19) + ($15))|0;
   $21 = $20 & 31;
   $22 = 1 << $21;
   $23 = $22 ^ -1;
   $24 = $20 >>> 5;
   $25 = (($12) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + ($24<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $28 & $23;
   HEAP32[$27>>2] = $29;
   $30 = (($i$01$i) + 1)|0;
   $31 = HEAP32[$7>>2]|0;
   $32 = $31;
   $33 = $13;
   $34 = (($32) - ($33))|0;
   $35 = $34 >> 2;
   $36 = ($30>>>0)<($35>>>0);
   if ($36) {
    $i$01$i = $30;
   } else {
    break;
   }
  }
 }
 $37 = (($this) + 58|0);
 HEAP8[$37>>0] = 0;
 $38 = (__ZN5Unity10GameObject17GetMessageHandlerEv()|0);
 $39 = HEAP32[((564104 + 8|0))>>2]|0;
 $40 = (($38) + 28|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = Math_imul($41, $39)|0;
 $43 = (($42) + 54)|0;
 $44 = $43 & 31;
 $45 = 1 << $44;
 $46 = $45 ^ -1;
 $47 = $43 >>> 5;
 $48 = (($38) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + ($47<<2)|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = $51 & $46;
 HEAP32[$50>>2] = $52;
 $53 = (__Z14GetTimeManagerv()|0);
 $54 = (($53) + 88|0);
 $55 = +HEAPF64[$54>>3];
 $56 = Math_fround($55);
 $57 = (__Z14GetTimeManagerv()|0);
 $58 = (($57) + 40|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (__Z14GetTimeManagerv()|0);
 $61 = (($60) + 24|0);
 $62 = +HEAPF64[$61>>3];
 $63 = Math_fround($62);
 $64 = Math_fround($56 - $63);
 $65 = Math_fround($64 / $59);
 $66 = $65 < Math_fround(0.0);
 if ($66) {
  $$0$i = Math_fround(0.0);
 } else {
  $67 = $65 > Math_fround(1.0);
  $$$i = $67 ? Math_fround(1.0) : $65;
  $$0$i = $$$i;
 }
 $68 = (($this) + 124|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($this) + 120|0);
 $71 = ($69|0)==($70|0);
 if (!($71)) {
  $72 = (($pos) + 4|0);
  $73 = (($pos) + 8|0);
  $74 = (($0) + 4|0);
  $75 = (($0) + 8|0);
  $76 = Math_fround(Math_fround(1.0) - $$0$i);
  $77 = (($4) + 4|0);
  $78 = (($4) + 8|0);
  $79 = (($3) + 4|0);
  $80 = (($3) + 8|0);
  $81 = (($5) + 4|0);
  $82 = (($5) + 8|0);
  $83 = Math_fround(HEAPF32[616648>>2]);
  $84 = (($6) + 12|0);
  $85 = (($6) + 8|0);
  $86 = (($6) + 4|0);
  $87 = (($rot) + 4|0);
  $88 = (($rot) + 8|0);
  $89 = (($rot) + 12|0);
  $91 = $69;
  while(1) {
   $90 = (($91) + 36|0);
   $92 = HEAP32[$90>>2]|0;
   $93 = (($91) + 40|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($94|0)==(0);
   do {
    if ($95) {
     $96 = (__ZN9Rigidbody10IsSleepingEv($92)|0);
     if (!($96)) {
      $97 = (($92) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($98)|0);
      HEAPF32[$pos>>2] = Math_fround(0.0);
      HEAPF32[$72>>2] = Math_fround(0.0);
      HEAPF32[$73>>2] = Math_fround(0.0);
      $100 = (($92) + 86|0);
      $101 = HEAP8[$100>>0]|0;
      $102 = $101&255;
      if ((($102|0) == 1)) {
       $103 = (($91) + 8|0);
       __ZNK9Rigidbody11GetPositionEv($0,$92);
       $104 = Math_fround(HEAPF32[$0>>2]);
       $105 = Math_fround($$0$i * $104);
       $106 = Math_fround(HEAPF32[$74>>2]);
       $107 = Math_fround($$0$i * $106);
       $108 = Math_fround(HEAPF32[$75>>2]);
       $109 = Math_fround($$0$i * $108);
       $110 = Math_fround(HEAPF32[$103>>2]);
       $111 = Math_fround($76 * $110);
       $112 = (($91) + 12|0);
       $113 = Math_fround(HEAPF32[$112>>2]);
       $114 = Math_fround($76 * $113);
       $115 = (($91) + 16|0);
       $116 = Math_fround(HEAPF32[$115>>2]);
       $117 = Math_fround($76 * $116);
       $118 = Math_fround($105 + $111);
       $119 = Math_fround($107 + $114);
       $120 = Math_fround($109 + $117);
       HEAPF32[$pos>>2] = $118;
       HEAPF32[$72>>2] = $119;
       HEAPF32[$73>>2] = $120;
       $121 = (($91) + 20|0);
       __ZNK9Rigidbody11GetRotationEv($2,$92);
       __Z5SlerpRK11QuaternionfS1_f($1,$121,$2,$$0$i);
       ;HEAP32[$rot+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$rot+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$rot+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$rot+12>>2]=HEAP32[$1+12>>2]|0;
       __ZN9Transform26SetPositionAndRotationSafeERK8Vector3fRK11Quaternionf($99,$pos,$rot);
       break;
      } else if (!((($102|0) == 2))) {
       break;
      }
      __ZNK9Rigidbody11GetPositionEv($3,$92);
      __ZNK9Rigidbody11GetVelocityEv($4,$92);
      $122 = Math_fround(HEAPF32[$4>>2]);
      $123 = Math_fround($64 * $122);
      $124 = Math_fround(HEAPF32[$77>>2]);
      $125 = Math_fround($64 * $124);
      $126 = Math_fround(HEAPF32[$78>>2]);
      $127 = Math_fround($64 * $126);
      $128 = Math_fround(HEAPF32[$3>>2]);
      $129 = Math_fround($123 + $128);
      $130 = Math_fround(HEAPF32[$79>>2]);
      $131 = Math_fround($125 + $130);
      $132 = Math_fround(HEAPF32[$80>>2]);
      $133 = Math_fround($127 + $132);
      HEAPF32[$pos>>2] = $129;
      HEAPF32[$72>>2] = $131;
      HEAPF32[$73>>2] = $133;
      __ZNK9Rigidbody18GetAngularVelocityEv($5,$92);
      $134 = Math_fround(HEAPF32[$5>>2]);
      $135 = Math_fround($134 * $134);
      $136 = Math_fround(HEAPF32[$81>>2]);
      $137 = Math_fround($136 * $136);
      $138 = Math_fround($135 + $137);
      $139 = Math_fround(HEAPF32[$82>>2]);
      $140 = Math_fround($139 * $139);
      $141 = Math_fround($138 + $140);
      $142 = (Math_fround(Math_sqrt((Math_fround($141)))));
      $143 = $142 > $83;
      if ($143) {
       $144 = Math_fround($64 * $142);
       $145 = Math_fround($144 * Math_fround(0.5));
       $146 = (Math_fround(+(Math_cos((+$145)))));
       $147 = (Math_fround(+(Math_sin((+$145)))));
       $148 = Math_fround($147 / $142);
       $149 = Math_fround($134 * $148);
       $150 = Math_fround($136 * $148);
       $151 = Math_fround($139 * $148);
       $152 = Math_fround($149 * $149);
       $153 = Math_fround($150 * $150);
       $154 = Math_fround($152 + $153);
       $155 = Math_fround($151 * $151);
       $156 = Math_fround($155 + $154);
       $157 = Math_fround($146 * $146);
       $158 = Math_fround($157 + $156);
       $159 = (Math_fround(Math_sqrt((Math_fround($158)))));
       $160 = $159 < $83;
       if ($160) {
        $167 = Math_fround(1.0);$170 = Math_fround(0.0);$174 = Math_fround(0.0);$178 = Math_fround(0.0);
       } else {
        $161 = Math_fround($149 / $159);
        $162 = Math_fround($150 / $159);
        $163 = Math_fround($151 / $159);
        $164 = Math_fround($146 / $159);
        $167 = $164;$170 = $161;$174 = $162;$178 = $163;
       }
      } else {
       $167 = Math_fround(1.0);$170 = Math_fround(0.0);$174 = Math_fround(0.0);$178 = Math_fround(0.0);
      }
      __ZNK9Rigidbody11GetRotationEv($6,$92);
      $165 = Math_fround(HEAPF32[$6>>2]);
      $166 = Math_fround($167 * $165);
      $168 = Math_fround(HEAPF32[$84>>2]);
      $169 = Math_fround($170 * $168);
      $171 = Math_fround($166 + $169);
      $172 = Math_fround(HEAPF32[$85>>2]);
      $173 = Math_fround($174 * $172);
      $175 = Math_fround($171 + $173);
      $176 = Math_fround(HEAPF32[$86>>2]);
      $177 = Math_fround($178 * $176);
      $179 = Math_fround($175 - $177);
      $180 = Math_fround($167 * $176);
      $181 = Math_fround($174 * $168);
      $182 = Math_fround($181 + $180);
      $183 = Math_fround($178 * $165);
      $184 = Math_fround($183 + $182);
      $185 = Math_fround($170 * $172);
      $186 = Math_fround($184 - $185);
      $187 = Math_fround($167 * $172);
      $188 = Math_fround($178 * $168);
      $189 = Math_fround($188 + $187);
      $190 = Math_fround($170 * $176);
      $191 = Math_fround($189 + $190);
      $192 = Math_fround($174 * $165);
      $193 = Math_fround($191 - $192);
      $194 = Math_fround($167 * $168);
      $195 = Math_fround($170 * $165);
      $196 = Math_fround($194 - $195);
      $197 = Math_fround($174 * $176);
      $198 = Math_fround($196 - $197);
      $199 = Math_fround($178 * $172);
      $200 = Math_fround($198 - $199);
      HEAPF32[$rot>>2] = $179;
      HEAPF32[$87>>2] = $186;
      HEAPF32[$88>>2] = $193;
      HEAPF32[$89>>2] = $200;
      __ZN9Transform26SetPositionAndRotationSafeERK8Vector3fRK11Quaternionf($99,$pos,$rot);
     }
    }
   } while(0);
   $201 = (($91) + 4|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = ($202|0)==($70|0);
   if ($203) {
    break;
   } else {
    $91 = $202;
   }
  }
 }
 $204 = HEAP32[$7>>2]|0;
 $205 = HEAP32[$9>>2]|0;
 $206 = ($204|0)==($205|0);
 if ($206) {
  HEAP8[$37>>0] = 1;
  $231 = (__ZN5Unity10GameObject17GetMessageHandlerEv()|0);
  $232 = HEAP32[((564104 + 8|0))>>2]|0;
  $233 = (($231) + 28|0);
  $234 = HEAP32[$233>>2]|0;
  $235 = Math_imul($234, $232)|0;
  $236 = (($235) + 54)|0;
  $237 = $236 & 31;
  $238 = 1 << $237;
  $239 = $236 >>> 5;
  $240 = (($231) + 4|0);
  $241 = HEAP32[$240>>2]|0;
  $242 = (($241) + ($239<<2)|0);
  $243 = HEAP32[$242>>2]|0;
  $244 = $238 | $243;
  HEAP32[$242>>2] = $244;
  STACKTOP = sp;return;
 } else {
  $i$01$i1 = 0;
 }
 while(1) {
  $207 = (__ZN5Unity10GameObject17GetMessageHandlerEv()|0);
  $208 = HEAP32[$9>>2]|0;
  $209 = (($208) + ($i$01$i1<<2)|0);
  $210 = HEAP32[$209>>2]|0;
  $211 = HEAP32[((564104 + 8|0))>>2]|0;
  $212 = (($207) + 28|0);
  $213 = HEAP32[$212>>2]|0;
  $214 = Math_imul($213, $211)|0;
  $215 = (($214) + ($210))|0;
  $216 = $215 & 31;
  $217 = 1 << $216;
  $218 = $215 >>> 5;
  $219 = (($207) + 4|0);
  $220 = HEAP32[$219>>2]|0;
  $221 = (($220) + ($218<<2)|0);
  $222 = HEAP32[$221>>2]|0;
  $223 = $217 | $222;
  HEAP32[$221>>2] = $223;
  $224 = (($i$01$i1) + 1)|0;
  $225 = HEAP32[$7>>2]|0;
  $226 = $225;
  $227 = $208;
  $228 = (($226) - ($227))|0;
  $229 = $228 >> 2;
  $230 = ($224>>>0)<($229>>>0);
  if ($230) {
   $i$01$i1 = $224;
  } else {
   break;
  }
 }
 HEAP8[$37>>0] = 1;
 $231 = (__ZN5Unity10GameObject17GetMessageHandlerEv()|0);
 $232 = HEAP32[((564104 + 8|0))>>2]|0;
 $233 = (($231) + 28|0);
 $234 = HEAP32[$233>>2]|0;
 $235 = Math_imul($234, $232)|0;
 $236 = (($235) + 54)|0;
 $237 = $236 & 31;
 $238 = 1 << $237;
 $239 = $236 >>> 5;
 $240 = (($231) + 4|0);
 $241 = HEAP32[$240>>2]|0;
 $242 = (($241) + ($239<<2)|0);
 $243 = HEAP32[$242>>2]|0;
 $244 = $238 | $243;
 HEAP32[$242>>2] = $244;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[690120>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[690016>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 248|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 28|0);
 FUNCTION_TABLE_vii[$5 & 4095]($2,$6);
 $7 = HEAP32[690016>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 256|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 52|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 FUNCTION_TABLE_vif[$10 & 255]($7,$12);
 $13 = (__Z24GetManagerPtrFromContexti(9)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 __ZN14PhysicsManager20SetupDefaultMaterialEv($this);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager10GetGravityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager27GetMinPenetrationForPenaltyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN14PhysicsManager17GetSleepThresholdEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZN10CastFilterD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager7RaycastERK3RayfR10RaycastHiti($this,$ray,$distance,$outHit,$mask) {
 $this = $this|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $outHit = $outHit|0;
 $mask = $mask|0;
 var $$0 = 0, $$01 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0;
 var $9 = 0, $buf$i = 0, $data$sroa$0 = 0, $fd1$i = 0, $filter = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $buf$i = sp + 56|0;
 $fd1$i = sp + 16|0;
 $0 = sp + 140|0;
 $filter = sp + 36|0;
 $data$sroa$0 = sp;
 $1 = $distance == Math_fround(inf);
 $$01 = $1 ? Math_fround(3.40282346638528859812E+38) : $distance;
 HEAP32[$filter>>2] = ((690808 + 8|0));
 $2 = (($filter) + 4|0);
 HEAP32[$2>>2] = 2;
 $3 = (($filter) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($filter) + 12|0);
 HEAP32[$4>>2] = $mask;
 $5 = (($filter) + 16|0);
 HEAP8[$5>>0] = 1;
 ;HEAP32[$data$sroa$0+0>>2]=0|0;HEAP32[$data$sroa$0+4>>2]=0|0;HEAP32[$data$sroa$0+8>>2]=0|0;HEAP32[$data$sroa$0+12>>2]=0|0;
 $6 = HEAP32[690016>>2]|0;
 $7 = (($ray) + 12|0);
 $8 = (($buf$i) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($buf$i) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($buf$i) + 12|0);
 HEAP32[$10>>2] = -1;
 $11 = (($buf$i) + 16|0);
 HEAP16[$11>>1] = 0;
 $12 = (($buf$i) + 20|0);
 $13 = (($buf$i) + 44|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;HEAP32[$12+20>>2]=0|0;
 HEAPF32[$13>>2] = Math_fround(3.40282346638528859812E+38);
 $14 = (($buf$i) + 48|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($buf$i) + 52|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($buf$i) + 68|0);
 HEAP8[$16>>0] = 0;
 $17 = (($buf$i) + 72|0);
 HEAP32[$17>>2] = 0;
 $18 = (($buf$i) + 76|0);
 HEAP32[$18>>2] = 0;
 $19 = (($buf$i) + 80|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$buf$i>>2] = ((404440 + 8|0));
 ;HEAP32[$fd1$i+0>>2]=HEAP32[$data$sroa$0+0>>2]|0;HEAP32[$fd1$i+4>>2]=HEAP32[$data$sroa$0+4>>2]|0;HEAP32[$fd1$i+8>>2]=HEAP32[$data$sroa$0+8>>2]|0;HEAP32[$fd1$i+12>>2]=HEAP32[$data$sroa$0+12>>2]|0;
 $20 = (($fd1$i) + 16|0);
 HEAP16[$20>>1] = 15;
 $21 = (($fd1$i) + 18|0);
 HEAP8[$21>>0] = 0;
 $22 = HEAP32[$6>>2]|0;
 $23 = (($22) + 348|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP16[$0>>1] = 15;
 (FUNCTION_TABLE_iiiifiiiii[$24 & 1]($6,$ray,$7,$$01,$buf$i,$0,$fd1$i,$filter,0)|0);
 $25 = HEAP32[$9>>2]|0;
 $26 = HEAP32[$10>>2]|0;
 $27 = Math_fround(HEAPF32[$12>>2]);
 $28 = (($buf$i) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($buf$i) + 28|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($buf$i) + 32|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($buf$i) + 36|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($buf$i) + 40|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround(HEAPF32[$13>>2]);
 $39 = Math_fround(HEAPF32[$14>>2]);
 $40 = Math_fround(HEAPF32[$15>>2]);
 $41 = ($25|0)==(0|0);
 if ($41) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = (($25) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($outHit) + 40|0);
 HEAP32[$44>>2] = $43;
 HEAPF32[$outHit>>2] = $27;
 $45 = (($outHit) + 4|0);
 HEAPF32[$45>>2] = $29;
 $46 = (($outHit) + 8|0);
 HEAPF32[$46>>2] = $31;
 $47 = (($outHit) + 12|0);
 HEAPF32[$47>>2] = $33;
 $48 = (($outHit) + 16|0);
 HEAPF32[$48>>2] = $35;
 $49 = (($outHit) + 20|0);
 HEAPF32[$49>>2] = $37;
 HEAP32[$buf$i>>2] = 5;
 $50 = (($buf$i) + 4|0);
 HEAPF32[$50>>2] = Math_fround(1.0);
 $51 = (($buf$i) + 8|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 $52 = (($buf$i) + 12|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($buf$i) + 16|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($buf$i) + 20|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($buf$i) + 24|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($buf$i) + 28|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($buf$i) + 32|0);
 $58 = $57;
 $59 = $58;
 HEAP32[$59>>2] = 0;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = 0;
 $62 = HEAP32[$25>>2]|0;
 $63 = (($62) + 56|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (FUNCTION_TABLE_iii[$64 & 4095]($25,$buf$i)|0);
 if ($65) {
  $66 = (($buf$i) + 36|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = HEAP32[$67>>2]|0;
  $69 = (($68) + 44|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (FUNCTION_TABLE_ii[$70 & 4095]($67)|0);
  $72 = (($71) + ($26<<2)|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($outHit) + 24|0);
  HEAP32[$74>>2] = $73;
 } else {
  $75 = (($outHit) + 24|0);
  HEAP32[$75>>2] = -1;
 }
 $76 = (($outHit) + 28|0);
 HEAPF32[$76>>2] = $38;
 $77 = (($outHit) + 32|0);
 HEAPF32[$77>>2] = $39;
 $78 = (($outHit) + 36|0);
 HEAPF32[$78>>2] = $40;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14PhysicsManager10RaycastAllERK3Rayfi($this,$ray,$distance,$mask) {
 $this = $this|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $mask = $mask|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i2 = 0, $blockingHit = 0, $data = 0, $exitcond = 0, $filter = 0, $i$014 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i3 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i7 = 0, $triangleMeshGeometry$i$i = 0, $uglygep$i$i$i = 0;
 var $uglygep$i$i$i5 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $triangleMeshGeometry$i$i = sp + 40|0;
 $blockingHit = sp + 82|0;
 $filter = sp + 20|0;
 $data = sp;
 $0 = sp + 80|0;
 $1 = (($this) + 808|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 812|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $__new_last2$i$i$i = $2;
  $scevgep$i$i$i = (($4) + -44|0);
  $6 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($6)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $7 = (($uglygep3$i$i$i>>>0) / 44)&-1;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i = (($4) + (($8*44)|0)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i;
 }
 $9 = $distance == Math_fround(inf);
 $$0 = $9 ? Math_fround(3.40282346638528859812E+38) : $distance;
 HEAP32[$filter>>2] = ((690808 + 8|0));
 $10 = (($filter) + 4|0);
 HEAP32[$10>>2] = 1;
 $11 = (($filter) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (($filter) + 12|0);
 HEAP32[$12>>2] = $mask;
 $13 = (($filter) + 16|0);
 HEAP8[$13>>0] = 0;
 ;HEAP32[$data+0>>2]=0|0;HEAP32[$data+4>>2]=0|0;HEAP32[$data+8>>2]=0|0;HEAP32[$data+12>>2]=0|0;
 $14 = (($data) + 16|0);
 HEAP16[$14>>1] = 15;
 $15 = (($data) + 18|0);
 HEAP8[$15>>0] = 0;
 $16 = HEAP32[690016>>2]|0;
 $17 = (($ray) + 12|0);
 HEAP16[$0>>1] = 15;
 $18 = (($this) + 760|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__ZN5physx7PxScene15raycastMultipleERKNS_6PxVec3ES3_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEPNS_12PxRaycastHitEjRbRKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPKNS_12PxQueryCacheEh($16,$ray,$17,$$0,$0,$19,128,$blockingHit,$data,$filter,0,0)|0);
 $21 = HEAP32[$3>>2]|0;
 $22 = HEAP32[$1>>2]|0;
 $23 = $21;
 $24 = $22;
 $25 = (($23) - ($24))|0;
 $26 = (($25|0) / 44)&-1;
 $27 = ($26>>>0)<($20>>>0);
 if ($27) {
  $28 = (($20) - ($26))|0;
  __ZNSt3__16vectorI10RaycastHitNS_9allocatorIS1_EEE8__appendEj($1,$28);
 } else {
  $29 = ($26>>>0)>($20>>>0);
  if ($29) {
   $30 = (($22) + (($20*44)|0)|0);
   $31 = ($21|0)==($30|0);
   if (!($31)) {
    $__new_last2$i$i$i2 = $30;
    $scevgep$i$i$i3 = (($21) + -44|0);
    $32 = (0 - ($__new_last2$i$i$i2))|0;
    $uglygep$i$i$i5 = (($scevgep$i$i$i3) + ($32)|0);
    $uglygep3$i$i$i6 = $uglygep$i$i$i5;
    $33 = (($uglygep3$i$i$i6>>>0) / 44)&-1;
    $34 = $33 ^ -1;
    $scevgep4$i$i$i7 = (($21) + (($34*44)|0)|0);
    HEAP32[$3>>2] = $scevgep4$i$i$i7;
   }
  }
 }
 $35 = ($20|0)>(0);
 if (!($35)) {
  STACKTOP = sp;return ($1|0);
 }
 $36 = (($triangleMeshGeometry$i$i) + 4|0);
 $37 = (($triangleMeshGeometry$i$i) + 8|0);
 $38 = (($triangleMeshGeometry$i$i) + 12|0);
 $39 = (($triangleMeshGeometry$i$i) + 16|0);
 $40 = (($triangleMeshGeometry$i$i) + 20|0);
 $41 = (($triangleMeshGeometry$i$i) + 24|0);
 $42 = (($triangleMeshGeometry$i$i) + 28|0);
 $43 = (($triangleMeshGeometry$i$i) + 32|0);
 $44 = (($triangleMeshGeometry$i$i) + 36|0);
 $i$014 = 0;
 while(1) {
  $45 = HEAP32[$18>>2]|0;
  $46 = HEAP32[$1>>2]|0;
  $47 = (($46) + (($i$014*44)|0)|0);
  $48 = ((($45) + ($i$014<<6)|0) + 4|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 8|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ((($46) + (($i$014*44)|0)|0) + 40|0);
  HEAP32[$52>>2] = $51;
  $53 = ((($45) + ($i$014<<6)|0) + 16|0);
  ;HEAP32[$47+0>>2]=HEAP32[$53+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$53+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$53+8>>2]|0;
  $54 = ((($46) + (($i$014*44)|0)|0) + 12|0);
  $55 = ((($45) + ($i$014<<6)|0) + 28|0);
  ;HEAP32[$54+0>>2]=HEAP32[$55+0>>2]|0;HEAP32[$54+4>>2]=HEAP32[$55+4>>2]|0;HEAP32[$54+8>>2]=HEAP32[$55+8>>2]|0;
  HEAP32[$triangleMeshGeometry$i$i>>2] = 5;
  HEAPF32[$36>>2] = Math_fround(1.0);
  HEAPF32[$37>>2] = Math_fround(1.0);
  HEAPF32[$38>>2] = Math_fround(1.0);
  HEAPF32[$39>>2] = Math_fround(0.0);
  HEAPF32[$40>>2] = Math_fround(0.0);
  HEAPF32[$41>>2] = Math_fround(0.0);
  HEAPF32[$42>>2] = Math_fround(1.0);
  $56 = $43;
  $57 = $56;
  HEAP32[$57>>2] = 0;
  $58 = (($56) + 4)|0;
  $59 = $58;
  HEAP32[$59>>2] = 0;
  $60 = HEAP32[$48>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + 56|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (FUNCTION_TABLE_iii[$63 & 4095]($60,$triangleMeshGeometry$i$i)|0);
  if ($64) {
   $65 = HEAP32[$44>>2]|0;
   $66 = HEAP32[$65>>2]|0;
   $67 = (($66) + 44|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_ii[$68 & 4095]($65)|0);
   $70 = ((($45) + ($i$014<<6)|0) + 8|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($69) + ($71<<2)|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ((($46) + (($i$014*44)|0)|0) + 24|0);
   HEAP32[$74>>2] = $73;
  } else {
   $75 = ((($46) + (($i$014*44)|0)|0) + 24|0);
   HEAP32[$75>>2] = -1;
  }
  $76 = ((($45) + ($i$014<<6)|0) + 40|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = ((($46) + (($i$014*44)|0)|0) + 28|0);
  HEAPF32[$78>>2] = $77;
  $79 = ((($45) + ($i$014<<6)|0) + 44|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = ((($46) + (($i$014*44)|0)|0) + 32|0);
  HEAPF32[$81>>2] = $80;
  $82 = ((($45) + ($i$014<<6)|0) + 48|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = ((($46) + (($i$014*44)|0)|0) + 36|0);
  HEAPF32[$84>>2] = $83;
  $85 = (($i$014) + 1)|0;
  $exitcond = ($85|0)==($20|0);
  if ($exitcond) {
   break;
  } else {
   $i$014 = $85;
  }
 }
 STACKTOP = sp;return ($1|0);
}
function __ZN5physx7PxScene15raycastMultipleERKNS_6PxVec3ES3_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEPNS_12PxRaycastHitEjRbRKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPKNS_12PxQueryCacheEh($this,$origin,$unitDir,$distance,$outputFlags,$hitBuffer,$hitBufferSize,$blockingHit,$filterData,$filterCall,$cache,$queryClient) {
 $this = $this|0;
 $origin = $origin|0;
 $unitDir = $unitDir|0;
 $distance = Math_fround($distance);
 $outputFlags = $outputFlags|0;
 $hitBuffer = $hitBuffer|0;
 $hitBufferSize = $hitBufferSize|0;
 $blockingHit = $blockingHit|0;
 $filterData = $filterData|0;
 $filterCall = $filterCall|0;
 $cache = $cache|0;
 $queryClient = $queryClient|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $8 = 0, $9 = 0, $buf = 0, $fd1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $buf = sp + 20|0;
 $fd1 = sp;
 $0 = sp + 104|0;
 $1 = (($buf) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($buf) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($buf) + 12|0);
 HEAP32[$3>>2] = -1;
 $4 = (($buf) + 16|0);
 HEAP16[$4>>1] = 0;
 $5 = (($buf) + 20|0);
 $6 = (($buf) + 44|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAPF32[$6>>2] = Math_fround(3.40282346638528859812E+38);
 $7 = (($buf) + 48|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($buf) + 52|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($buf) + 68|0);
 HEAP8[$9>>0] = 0;
 $10 = (($buf) + 72|0);
 HEAP32[$10>>2] = $hitBuffer;
 $11 = (($buf) + 76|0);
 HEAP32[$11>>2] = $hitBufferSize;
 $12 = (($buf) + 80|0);
 HEAP32[$12>>2] = 0;
 HEAP32[$buf>>2] = ((404440 + 8|0));
 ;HEAP32[$fd1+0>>2]=HEAP32[$filterData+0>>2]|0;HEAP32[$fd1+4>>2]=HEAP32[$filterData+4>>2]|0;HEAP32[$fd1+8>>2]=HEAP32[$filterData+8>>2]|0;HEAP32[$fd1+12>>2]=HEAP32[$filterData+12>>2]|0;
 $13 = (($filterData) + 16|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = (($fd1) + 16|0);
 HEAP16[$15>>1] = $14;
 $16 = (($fd1) + 18|0);
 HEAP8[$16>>0] = $queryClient;
 $17 = HEAP32[$this>>2]|0;
 $18 = (($17) + 348|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP16[$outputFlags>>1]|0;
 HEAP16[$0>>1] = $20;
 (FUNCTION_TABLE_iiiifiiiii[$19 & 1]($this,$origin,$unitDir,$distance,$buf,$0,$fd1,$filterCall,$cache)|0);
 $21 = HEAP8[$9>>0]|0;
 HEAP8[$blockingHit>>0] = $21;
 $22 = ($21<<24>>24)==(0);
 $23 = HEAP32[$12>>2]|0;
 if ($22) {
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = ($23>>>0)<($hitBufferSize>>>0);
 if ($24) {
  $25 = (($hitBuffer) + ($23<<6)|0);
  $26 = (($buf) + 4|0);
  ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;
  $27 = HEAP16[$4>>1]|0;
  $28 = ((($hitBuffer) + ($23<<6)|0) + 12|0);
  HEAP16[$28>>1] = $27;
  $29 = Math_fround(HEAPF32[$5>>2]);
  $30 = ((($hitBuffer) + ($23<<6)|0) + 16|0);
  HEAPF32[$30>>2] = $29;
  $31 = (($buf) + 24|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = ((($hitBuffer) + ($23<<6)|0) + 20|0);
  HEAPF32[$33>>2] = $32;
  $34 = (($buf) + 28|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = ((($hitBuffer) + ($23<<6)|0) + 24|0);
  HEAPF32[$36>>2] = $35;
  $37 = (($buf) + 32|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = ((($hitBuffer) + ($23<<6)|0) + 28|0);
  HEAPF32[$39>>2] = $38;
  $40 = (($buf) + 36|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = ((($hitBuffer) + ($23<<6)|0) + 32|0);
  HEAPF32[$42>>2] = $41;
  $43 = (($buf) + 40|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = ((($hitBuffer) + ($23<<6)|0) + 36|0);
  HEAPF32[$45>>2] = $44;
  $46 = Math_fround(HEAPF32[$6>>2]);
  $47 = ((($hitBuffer) + ($23<<6)|0) + 40|0);
  HEAPF32[$47>>2] = $46;
  $48 = ((($hitBuffer) + ($23<<6)|0) + 44|0);
  ;HEAP32[$48+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$48+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$48+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$48+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$48+16>>2]=HEAP32[$7+16>>2]|0;
  $49 = (($23) + 1)|0;
  $$0 = $49;
  STACKTOP = sp;return ($$0|0);
 } else {
  $50 = (($hitBufferSize) + -1)|0;
  $51 = (($hitBuffer) + ($50<<6)|0);
  $52 = (($buf) + 4|0);
  ;HEAP32[$51+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$51+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$51+8>>2]=HEAP32[$52+8>>2]|0;
  $53 = HEAP16[$4>>1]|0;
  $54 = ((($hitBuffer) + ($50<<6)|0) + 12|0);
  HEAP16[$54>>1] = $53;
  $55 = Math_fround(HEAPF32[$5>>2]);
  $56 = ((($hitBuffer) + ($50<<6)|0) + 16|0);
  HEAPF32[$56>>2] = $55;
  $57 = (($buf) + 24|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = ((($hitBuffer) + ($50<<6)|0) + 20|0);
  HEAPF32[$59>>2] = $58;
  $60 = (($buf) + 28|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = ((($hitBuffer) + ($50<<6)|0) + 24|0);
  HEAPF32[$62>>2] = $61;
  $63 = (($buf) + 32|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = ((($hitBuffer) + ($50<<6)|0) + 28|0);
  HEAPF32[$65>>2] = $64;
  $66 = (($buf) + 36|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($hitBuffer) + ($50<<6)|0) + 32|0);
  HEAPF32[$68>>2] = $67;
  $69 = (($buf) + 40|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = ((($hitBuffer) + ($50<<6)|0) + 36|0);
  HEAPF32[$71>>2] = $70;
  $72 = Math_fround(HEAPF32[$6>>2]);
  $73 = ((($hitBuffer) + ($50<<6)|0) + 40|0);
  HEAPF32[$73>>2] = $72;
  $74 = ((($hitBuffer) + ($50<<6)|0) + 44|0);
  ;HEAP32[$74+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$74+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$74+16>>2]=HEAP32[$7+16>>2]|0;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN14PhysicsManager7AddBodyEiR8ListNodeI9RigidbodyE($this,$depth,$node) {
 $this = $this|0;
 $depth = $depth|0;
 $node = $node|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($depth|0)>(62);
 if ($0) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(690384,0,690112,1927,1,0,0,0);
  $2 = 63;
 } else {
  $2 = $depth;
 }
 $1 = ((($this) + ($2<<3)|0) + 132|0);
 $3 = ($node|0)==($1|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$node>>2]|0;
 $5 = ($4|0)==(0|0);
 $$pre$i$i = (($node) + 4|0);
 if (!($5)) {
  $6 = HEAP32[$$pre$i$i>>2]|0;
  $7 = (($4) + 4|0);
  HEAP32[$7>>2] = $6;
  $8 = HEAP32[$node>>2]|0;
  $9 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$9>>2] = $8;
  HEAP32[$node>>2] = 0;
  HEAP32[$$pre$i$i>>2] = 0;
 }
 $10 = HEAP32[$1>>2]|0;
 HEAP32[$node>>2] = $10;
 HEAP32[$$pre$i$i>>2] = $1;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $node;
 $12 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$12>>2] = $node;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager20GetDefaultPxMaterialEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $mat = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mat = sp;
 $0 = HEAP32[690120>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiiii[$3 & 511]($0,$mat,1,0)|0);
 $4 = HEAP32[$mat>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __Z10GetCookingv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[690160>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__13mapINS_4pairIPN5physx7PxShapeES4_EEN14PhysicsManager16TriggerStayStateENS_4lessIS5_EENS_9allocatorINS1_IKS5_S7_EEEEEixERSB_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $19 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $19;
   $$0$i = $19;$39 = $19;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $4 = (($__k) + 4|0);
   $__nd$0$in$i = $1;
   L3: while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($3>>>0)<($6>>>0);
    do {
     if (!($7)) {
      $8 = ($6>>>0)<($3>>>0);
      if (!($8)) {
       $9 = HEAP32[$4>>2]|0;
       $10 = (($__nd$0$in$i) + 20|0);
       $11 = HEAP32[$10>>2]|0;
       $12 = ($9>>>0)<($11>>>0);
       if ($12) {
        break;
       }
       $15 = ($11>>>0)<($9>>>0);
       if (!($15)) {
        label = 11;
        break L3;
       }
      }
      $16 = (($__nd$0$in$i) + 4|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17|0)==(0|0);
      if ($18) {
       label = 10;
       break L3;
      } else {
       $__nd$0$in$i = $17;
       continue L3;
      }
     }
    } while(0);
    $13 = HEAP32[$__nd$0$in$i>>2]|0;
    $14 = ($13|0)==(0|0);
    if ($14) {
     label = 7;
     break;
    } else {
     $__nd$0$in$i = $13;
    }
   }
   if ((label|0) == 7) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$39 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 10) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $16;$39 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 11) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$39 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $20 = HEAP32[$$0$i>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $__r$0 = $20;
  $48 = (($__r$0) + 24|0);
  STACKTOP = sp;return ($48|0);
 }
 $22 = (__Znwj(36)|0);
 $23 = (($22) + 16|0);
 $24 = $__k;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $23;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (($22) + 24|0);
 HEAP8[$34>>0] = 1;
 $35 = (($22) + 28|0);
 HEAP32[$35>>2] = 0;
 $36 = (($22) + 32|0);
 HEAP32[$36>>2] = 0;
 HEAP32[$22>>2] = 0;
 $37 = (($22) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($22) + 8|0);
 HEAP32[$38>>2] = $39;
 HEAP32[$$0$i>>2] = $22;
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  $44 = $22;
 } else {
  HEAP32[$this>>2] = $41;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $44 = $$pre$i;
 }
 $43 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($43,$44);
 $45 = (($this) + 8|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46) + 1)|0;
 HEAP32[$45>>2] = $47;
 $__r$0 = $22;
 $48 = (($__r$0) + 24|0);
 STACKTOP = sp;return ($48|0);
}
function __ZL16SendTriggerEventP8ColliderS0_17MessageIdentifier($trigger,$collider,$messageID) {
 $trigger = $trigger|0;
 $collider = $collider|0;
 $messageID = $messageID|0;
 var $$0$i = 0, $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data$i6 = 0, $inData$c$i$i = 0, $inData$c$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data$i6 = sp;
 $0 = HEAP32[$collider>>2]|0;
 $1 = (($0) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($collider)|0);
 $4 = ($3|0)==(0|0);
 $$0$i = $4 ? $collider : $3;
 $5 = HEAP32[$trigger>>2]|0;
 $6 = (($5) + 128|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($trigger)|0);
 $9 = ($8|0)==(0|0);
 $$0$i1 = $9 ? $trigger : $8;
 $10 = (($data$i6) + 8|0);
 HEAP32[$10>>2] = 0;
 $11 = (($data$i6) + 4|0);
 $inData$c$i$i = $collider;
 HEAP32[$11>>2] = $inData$c$i$i;
 HEAP32[$data$i6>>2] = 56;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($trigger,$messageID,$data$i6);
 $12 = (($data$i6) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = (($data$i6) + 4|0);
 $inData$c$i$i3 = $trigger;
 HEAP32[$13>>2] = $inData$c$i$i3;
 HEAP32[$data$i6>>2] = 56;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($$0$i,$messageID,$data$i6);
 $14 = (($$0$i) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($collider) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 if (!($18)) {
  $19 = HEAP32[$collider>>2]|0;
  $20 = (($19) + 124|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_ii[$21 & 4095]($collider)|0);
  if ($22) {
   $23 = (($data$i6) + 8|0);
   HEAP32[$23>>2] = 0;
   $24 = (($data$i6) + 4|0);
   HEAP32[$24>>2] = $inData$c$i$i3;
   HEAP32[$data$i6>>2] = 56;
   __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($collider,$messageID,$data$i6);
  }
 }
 $25 = (($$0$i1) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($trigger) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($26|0)==($28|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($data$i6) + 8|0);
 HEAP32[$30>>2] = 0;
 $31 = (($data$i6) + 4|0);
 HEAP32[$31>>2] = $inData$c$i$i;
 HEAP32[$data$i6>>2] = 56;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($$0$i1,$messageID,$data$i6);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN5physx11PxTransformENS_9allocatorIS2_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0);
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 28)&-1;
 $7 = ($6>>>0)<($__n>>>0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = (($10) - ($4))|0;
 $12 = (($11|0) / 28)&-1;
 $13 = ($__n|0)==(0);
 if ($13) {
  $17 = 0;
 } else {
  $14 = ($__n*28)|0;
  $15 = (__Znwj($14)|0);
  $17 = $15;
 }
 $16 = (($17) + (($12*28)|0)|0);
 $18 = (($17) + (($__n*28)|0)|0);
 $19 = ($9|0)==($2|0);
 if ($19) {
  $47 = $16;
 } else {
  $scevgep$i$i = (($9) + -28|0);
  $20 = (0 - ($4))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($20)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $9;$23 = $16;
  while(1) {
   $21 = (($$01$i$i) + -28|0);
   $22 = (($23) + -28|0);
   $24 = Math_fround(HEAPF32[$21>>2]);
   HEAPF32[$22>>2] = $24;
   $25 = (($23) + -24|0);
   $26 = (($$01$i$i) + -24|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   HEAPF32[$25>>2] = $27;
   $28 = (($23) + -20|0);
   $29 = (($$01$i$i) + -20|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   HEAPF32[$28>>2] = $30;
   $31 = (($23) + -16|0);
   $32 = (($$01$i$i) + -16|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   HEAPF32[$31>>2] = $33;
   $34 = (($23) + -12|0);
   $35 = (($$01$i$i) + -12|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   HEAPF32[$34>>2] = $36;
   $37 = (($23) + -8|0);
   $38 = (($$01$i$i) + -8|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   HEAPF32[$37>>2] = $39;
   $40 = (($23) + -4|0);
   $41 = (($$01$i$i) + -4|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   HEAPF32[$40>>2] = $42;
   $43 = (($23) + -28|0);
   $44 = ($21|0)==($2|0);
   if ($44) {
    break;
   } else {
    $$01$i$i = $21;$23 = $43;
   }
  }
  $45 = (($uglygep4$i$i>>>0) / 28)&-1;
  $46 = $45 ^ -1;
  $$sum = (($12) + ($46))|0;
  $scevgep5$i$i = (($17) + (($$sum*28)|0)|0);
  $47 = $scevgep5$i$i;
 }
 HEAP32[$this>>2] = $47;
 HEAP32[$8>>2] = $16;
 HEAP32[$0>>2] = $18;
 $48 = ($2|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __Z28RegisterClass_PhysicsManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(55,202,203,0,204);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 14;
 dest=$3+0|0; src=690472+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 14|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,55,6,($0|0),832,(2555|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN14PhysicsManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(832,$$byval_copy2,1,16,690112,76)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1978,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(690112|0),76);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK14PhysicsManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 55;
}
function __ZN14PhysicsManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690488,690472,$this,0);
 __ZN14PhysicsManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,690488,690472,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN14PhysicsManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PhysicsManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PhysicsManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PhysicsManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $8;
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManagerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14PhysicsManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3639,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZThn24_N14PhysicsManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 __ZN14PhysicsManagerD2Ev($0);
 STACKTOP = sp;return;
}
function __ZThn24_N14PhysicsManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -24|0);
 __THREW__ = 0;
 invoke_vi(3639,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
}
function __ZN14PhysicsManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5 = 0, $$pre5$i$i$i = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $size$i$i$i = 0, $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i = sp + 16|0;
 $value = sp;
 $value1 = sp + 4|0;
 $value2 = sp + 8|0;
 $value3 = sp + 12|0;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$0>>2]);
  HEAPF32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre3$i$i$i = HEAP32[$4>>2]|0;
  $10 = $$pre$i$i$i;$12 = $$pre3$i$i$i;
 }
 $8 = (($this) + 32|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre4$i$i$i = HEAP32[$1>>2]|0;
  $$pre5$i$i$i = HEAP32[$4>>2]|0;
  $16 = $$pre4$i$i$i;$18 = $$pre5$i$i$i;
 }
 $14 = (($this) + 36|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
 }
 $20 = (($this) + 60|0);
 __ZN4PPtrI14PhysicMaterialE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($20,$transfer);
 $21 = (($this) + 52|0);
 $22 = HEAP32[$1>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$4>>2]|0;
 $25 = ($23>>>0)<($24>>>0);
 if ($25) {
  $26 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$22>>2] = $26;
  HEAP32[$1>>2] = $23;
  $30 = $23;$32 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$21,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$4>>2]|0;
  $30 = $$pre;$32 = $$pre5;
 }
 $27 = (($this) + 40|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 HEAPF32[$value>>2] = $28;
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)<($32>>>0);
 if ($31) {
  HEAPF32[$30>>2] = $28;
  HEAP32[$1>>2] = $29;
  $36 = $29;$38 = $32;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$value,4);
  $$pre6 = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $36 = $$pre6;$38 = $$pre7;
 }
 $33 = (($this) + 44|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 HEAPF32[$value1>>2] = $34;
 $35 = (($36) + 4|0);
 $37 = ($35>>>0)<($38>>>0);
 if ($37) {
  HEAPF32[$36>>2] = $34;
  HEAP32[$1>>2] = $35;
  $42 = $35;$44 = $38;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$value1,4);
  $$pre8 = HEAP32[$1>>2]|0;
  $$pre9 = HEAP32[$4>>2]|0;
  $42 = $$pre8;$44 = $$pre9;
 }
 $39 = (($this) + 48|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 HEAPF32[$value2>>2] = $40;
 $41 = (($42) + 4|0);
 $43 = ($41>>>0)<($44>>>0);
 if ($43) {
  HEAPF32[$42>>2] = $40;
  HEAP32[$1>>2] = $41;
  $48 = $41;$50 = $44;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$value2,4);
  $$pre10 = HEAP32[$1>>2]|0;
  $$pre11 = HEAP32[$4>>2]|0;
  $48 = $$pre10;$50 = $$pre11;
 }
 $45 = (($this) + 104|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$value3>>2] = $46;
 $47 = (($48) + 4|0);
 $49 = ($47>>>0)<($50>>>0);
 if ($49) {
  HEAP32[$48>>2] = $46;
  HEAP32[$1>>2] = $47;
  $53 = $47;$55 = $50;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$value3,4);
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $53 = $$pre12;$55 = $$pre13;
 }
 $51 = (($this) + 56|0);
 $52 = (($53) + 1|0);
 $54 = ($52>>>0)<($55>>>0);
 if ($54) {
  $56 = HEAP8[$51>>0]|0;
  HEAP8[$53>>0] = $56;
  $57 = HEAP32[$1>>2]|0;
  $58 = (($57) + 1|0);
  HEAP32[$1>>2] = $58;
  $61 = $58;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$51,1);
  $$pre14 = HEAP32[$1>>2]|0;
  $61 = $$pre14;
 }
 $59 = (($this) + 57|0);
 $60 = (($61) + 1|0);
 $62 = HEAP32[$4>>2]|0;
 $63 = ($60>>>0)<($62>>>0);
 if ($63) {
  $64 = HEAP8[$59>>0]|0;
  HEAP8[$61>>0] = $64;
  $65 = HEAP32[$1>>2]|0;
  $66 = (($65) + 1|0);
  HEAP32[$1>>2] = $66;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$59,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $67 = (($this) + 680|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($this) + 676|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = $68;
 $72 = $70;
 $73 = (($71) - ($72))|0;
 $74 = $73 >> 2;
 HEAP32[$size$i$i$i>>2] = $74;
 $75 = HEAP32[$1>>2]|0;
 $76 = (($75) + 4|0);
 $77 = HEAP32[$4>>2]|0;
 $78 = ($76>>>0)<($77>>>0);
 if ($78) {
  HEAP32[$75>>2] = $74;
  HEAP32[$1>>2] = $76;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i,4);
 }
 $79 = HEAP32[$67>>2]|0;
 $80 = HEAP32[$69>>2]|0;
 $81 = ($80|0)==($79|0);
 if ($81) {
  STACKTOP = sp;return;
 } else {
  $87 = $80;
 }
 while(1) {
  $82 = HEAP32[$1>>2]|0;
  $83 = (($82) + 4|0);
  $84 = HEAP32[$4>>2]|0;
  $85 = ($83>>>0)<($84>>>0);
  if ($85) {
   $86 = HEAP32[$87>>2]|0;
   HEAP32[$82>>2] = $86;
   HEAP32[$1>>2] = $83;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$87,4);
  }
  $88 = (($87) + 4|0);
  $89 = ($88|0)==($79|0);
  if ($89) {
   break;
  } else {
   $87 = $88;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$$i$i = 0, $$0$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i7 = 0, $$pre$phi$i$i$i11Z2D = 0, $$pre$phi$i$i$i16Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre18 = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = Math_fround(0), $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp + 12|0;
 $value1 = sp;
 $value2 = sp + 4|0;
 $value3 = sp + 8|0;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$0,0,0);
 $1 = (($this) + 60|0);
 __ZN4PPtrI14PhysicMaterialE8TransferI18StreamedBinaryReadILb1EEEEvRT_($1,$transfer);
 $2 = (($this) + 52|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre18 = HEAP32[$6>>2]|0;
  $$pre$phi$i$i$iZ2D = $2;$11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre18;
 } else {
  $9 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = (HEAPF32[tempDoublePtr>>2]=$9,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $2;$11 = $10;$14 = $5;$16 = $7;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$value,4);
  $$pre$i$i$i3 = HEAP32[$value>>2]|0;
  $$pre$phi$i$i$i4Z2D = $value;$19 = $$pre$i$i$i3;
 } else {
  $17 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$value>>2] = $17;
  HEAP32[$3>>2] = $13;
  $18 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $value;$19 = $18;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $20;
 $21 = HEAP32[690120>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  $23 = (HEAP32[tempDoublePtr>>2]=$20,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $24 = (($this) + 40|0);
  HEAPF32[$24>>2] = $23;
 }
 $25 = HEAP32[$3>>2]|0;
 $26 = (($25) + 4|0);
 $27 = HEAP32[$6>>2]|0;
 $28 = ($26>>>0)>($27>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$value1,4);
  $$pre$i$i$i15 = HEAP32[$value1>>2]|0;
  $$pre$phi$i$i$i16Z2D = $value1;$31 = $$pre$i$i$i15;
 } else {
  $29 = Math_fround(HEAPF32[$25>>2]);
  HEAPF32[$value1>>2] = $29;
  HEAP32[$3>>2] = $26;
  $30 = (HEAPF32[tempDoublePtr>>2]=$29,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i16Z2D = $value1;$31 = $30;
 }
 $32 = (_llvm_bswap_i32(($31|0))|0);
 HEAP32[$$pre$phi$i$i$i16Z2D>>2] = $32;
 $33 = HEAP32[690120>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = (HEAP32[tempDoublePtr>>2]=$32,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $36 = (($this) + 44|0);
  HEAPF32[$36>>2] = $35;
 }
 $37 = HEAP32[$3>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$6>>2]|0;
 $40 = ($38>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$value2,4);
  $$pre$i$i$i10 = HEAP32[$value2>>2]|0;
  $$pre$phi$i$i$i11Z2D = $value2;$43 = $$pre$i$i$i10;
 } else {
  $41 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$value2>>2] = $41;
  HEAP32[$3>>2] = $38;
  $42 = (HEAPF32[tempDoublePtr>>2]=$41,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i11Z2D = $value2;$43 = $42;
 }
 $44 = (_llvm_bswap_i32(($43|0))|0);
 HEAP32[$$pre$phi$i$i$i11Z2D>>2] = $44;
 $45 = HEAP32[690120>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = (HEAP32[tempDoublePtr>>2]=$44,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $48 = (($this) + 48|0);
  HEAPF32[$48>>2] = $47;
 }
 $49 = HEAP32[$3>>2]|0;
 $50 = (($49) + 4|0);
 $51 = HEAP32[$6>>2]|0;
 $52 = ($50>>>0)>($51>>>0);
 if ($52) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$value3,4);
  $$pre$i$i$i7 = HEAP32[$value3>>2]|0;
  $54 = $$pre$i$i$i7;
 } else {
  $53 = HEAP32[$49>>2]|0;
  HEAP32[$value3>>2] = $53;
  HEAP32[$3>>2] = $50;
  $54 = $53;
 }
 $55 = (_llvm_bswap_i32(($54|0))|0);
 HEAP32[$value3>>2] = $55;
 $56 = HEAP32[690120>>2]|0;
 $57 = ($56|0)==(0|0);
 if (!($57)) {
  $58 = ($55|0)<(1);
  if ($58) {
   $$0$i$i = 1;
  } else {
   $59 = ($55|0)>(100);
   $$$i$i = $59 ? 100 : $55;
   $$0$i$i = $$$i$i;
  }
  $60 = (($this) + 104|0);
  HEAP32[$60>>2] = $$0$i$i;
 }
 $61 = (($this) + 56|0);
 $62 = HEAP32[$3>>2]|0;
 $63 = (($62) + 1|0);
 $64 = HEAP32[$6>>2]|0;
 $65 = ($63>>>0)>($64>>>0);
 if ($65) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$61,1);
  $$pre19 = HEAP32[$3>>2]|0;
  $71 = $$pre19;
 } else {
  $66 = HEAP8[$62>>0]|0;
  HEAP8[$61>>0] = $66;
  $67 = HEAP32[$3>>2]|0;
  $68 = (($67) + 1|0);
  HEAP32[$3>>2] = $68;
  $71 = $68;
 }
 $69 = (($this) + 57|0);
 $70 = (($71) + 1|0);
 $72 = HEAP32[$6>>2]|0;
 $73 = ($70>>>0)>($72>>>0);
 if ($73) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$69,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  $77 = (($this) + 676|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIjNS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$77,0);
  STACKTOP = sp;return;
 } else {
  $74 = HEAP8[$71>>0]|0;
  HEAP8[$69>>0] = $74;
  $75 = HEAP32[$3>>2]|0;
  $76 = (($75) + 1|0);
  HEAP32[$3>>2] = $76;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  $77 = (($this) + 676|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIjNS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$77,0);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIjNS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i3 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i3;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i6 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i6;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 __Z14resize_trimmedINSt3__16vectorIjNS0_9allocatorIjEEEEEvRT_j($data,$24);
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$data>>2]|0;
 $28 = ($27|0)==($26|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $34 = $27;
 }
 while(1) {
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$7>>2]|0;
  $32 = ($30>>>0)>($31>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
   $$pre$i$i$i = HEAP32[$34>>2]|0;
   $35 = $$pre$i$i$i;
  } else {
   $33 = HEAP32[$29>>2]|0;
   HEAP32[$34>>2] = $33;
   HEAP32[$1>>2] = $30;
   $35 = $33;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$34>>2] = $36;
  $37 = (($34) + 4|0);
  $38 = ($37|0)==($26|0);
  if ($38) {
   break;
  } else {
   $34 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIjNS0_9allocatorIjEEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$idx = 0, $$pre50 = 0, $$pre51 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i26 = 0, $__new_last2$i$i$i$i$i35 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i27 = 0, $scevgep$i$i$i$i$i36 = 0, $scevgep$i$i$i13 = 0, $scevgep4$i$i$i$i$i31 = 0, $scevgep4$i$i$i$i$i40 = 0;
 var $scevgep4$i$i$i15 = 0, $scevgep8$i$i$i = 0, $scevgep8$i$i$i48 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i29 = 0, $uglygep$i$i$i$i$i38 = 0, $uglygep$i$i$i14 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i30 = 0, $uglygep3$i$i$i$i$i39 = 0, $uglygep6$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($sz>>>0);
 if (!($9)) {
  $63 = ($8>>>0)>($sz>>>0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  $64 = (($4) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $65 = $$idx >> 2;
  $66 = ($65|0)==(0);
  if ($66) {
   $81 = 0;$83 = 0;$scevgep8$i$i$i48 = 0;
  } else {
   $67 = ($65>>>0)>(1073741823);
   if ($67) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $68 = (__Znwj($$idx)|0);
   $69 = (($68) + ($65<<2)|0);
   $70 = ($sz|0)==(0);
   if ($70) {
    $81 = $68;$83 = $69;$scevgep8$i$i$i48 = $68;
   } else {
    $$sum = (($sz) + -1)|0;
    $scevgep$i$i$i = (($4) + ($$sum<<2)|0);
    $71 = (0 - ($6))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($71)|0);
    $73 = $68;$75 = $4;
    while(1) {
     $72 = ($73|0)==(0|0);
     if (!($72)) {
      $74 = HEAP32[$75>>2]|0;
      HEAP32[$73>>2] = $74;
     }
     $76 = (($73) + 4|0);
     $77 = (($75) + 4|0);
     $78 = ($77|0)==($64|0);
     if ($78) {
      break;
     } else {
      $73 = $76;$75 = $77;
     }
    }
    $uglygep6$i$i$i = $uglygep$i$i$i;
    $79 = $uglygep6$i$i$i >>> 2;
    $80 = (($79) + 1)|0;
    $scevgep8$i$i$i = (($68) + ($80<<2)|0);
    $81 = $68;$83 = $69;$scevgep8$i$i$i48 = $scevgep8$i$i$i;
   }
  }
  HEAP32[$v>>2] = $81;
  HEAP32[$2>>2] = $scevgep8$i$i$i48;
  $82 = (($v) + 8|0);
  HEAP32[$82>>2] = $83;
  $84 = ($4|0)==(0|0);
  if ($84) {
   STACKTOP = sp;return;
  }
  __ZdlPv($4);
  STACKTOP = sp;return;
 }
 $10 = (($v) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($6))|0;
 $14 = $13 >> 2;
 $15 = ($14|0)==($sz|0);
 if ($15) {
  $62 = (($sz) - ($8))|0;
  __ZNSt3__16vectorIjNS_9allocatorIjEEE8__appendEj($v,$62);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $16 = (($temp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($temp) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = ($sz|0)==(0);
 if ($18) {
  label = 6;
 } else {
  $19 = $sz << 2;
  __THREW__ = 0;
  $20 = (invoke_ii(2988,($19|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $23 = (($20) + ($sz<<2)|0);
   HEAP32[$temp>>2] = $20;
   HEAP32[$16>>2] = $20;
   HEAP32[$17>>2] = $23;
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$0>>2] = $4;
   HEAP32[$1>>2] = $3;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1979,($temp|0),($$byval_copy|0),($$byval_copy1|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$16>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = $30 >> 2;
    $32 = ($31>>>0)<($sz>>>0);
    if ($32) {
     $33 = (($sz) - ($31))|0;
     __THREW__ = 0;
     invoke_vii(3326,($temp|0),($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $$pre50 = HEAP32[$temp>>2]|0;
     $$pre51 = HEAP32[$16>>2]|0;
     $43 = $$pre50;$45 = $$pre51;
    } else {
     $36 = ($31>>>0)>($sz>>>0);
     if ($36) {
      $37 = (($27) + ($sz<<2)|0);
      $38 = ($26|0)==($37|0);
      if ($38) {
       $43 = $27;$45 = $26;
      } else {
       $__new_last2$i$i$i = $37;
       $scevgep$i$i$i13 = (($26) + -4|0);
       $39 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i14 = (($scevgep$i$i$i13) + ($39)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i14;
       $40 = $uglygep3$i$i$i >>> 2;
       $41 = $40 ^ -1;
       $scevgep4$i$i$i15 = (($26) + ($41<<2)|0);
       HEAP32[$16>>2] = $scevgep4$i$i$i15;
       $43 = $27;$45 = $scevgep4$i$i$i15;
      }
     } else {
      $43 = $27;$45 = $26;
     }
    }
    $42 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $42;
    HEAP32[$v>>2] = $43;
    $44 = HEAP32[$2>>2]|0;
    HEAP32[$16>>2] = $44;
    HEAP32[$2>>2] = $45;
    $46 = HEAP32[$17>>2]|0;
    $47 = HEAP32[$10>>2]|0;
    HEAP32[$17>>2] = $47;
    HEAP32[$10>>2] = $46;
    $48 = ($42|0)==(0|0);
    if ($48) {
     STACKTOP = sp;return;
    }
    $49 = ($44|0)==($42|0);
    if (!($49)) {
     $__new_last2$i$i$i$i$i26 = $42;
     $scevgep$i$i$i$i$i27 = (($44) + -4|0);
     $50 = (0 - ($__new_last2$i$i$i$i$i26))|0;
     $uglygep$i$i$i$i$i29 = (($scevgep$i$i$i$i$i27) + ($50)|0);
     $uglygep3$i$i$i$i$i30 = $uglygep$i$i$i$i$i29;
     $51 = $uglygep3$i$i$i$i$i30 >>> 2;
     $52 = $51 ^ -1;
     $scevgep4$i$i$i$i$i31 = (($44) + ($52<<2)|0);
     HEAP32[$16>>2] = $scevgep4$i$i$i$i$i31;
    }
    __ZdlPv($42);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $53 = ___cxa_find_matching_catch()|0;
 $54 = tempRet0;
 $55 = HEAP32[$temp>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($53|0);
  // unreachable;
 }
 $57 = HEAP32[$16>>2]|0;
 $58 = ($57|0)==($55|0);
 if (!($58)) {
  $__new_last2$i$i$i$i$i35 = $55;
  $scevgep$i$i$i$i$i36 = (($57) + -4|0);
  $59 = (0 - ($__new_last2$i$i$i$i$i35))|0;
  $uglygep$i$i$i$i$i38 = (($scevgep$i$i$i$i$i36) + ($59)|0);
  $uglygep3$i$i$i$i$i39 = $uglygep$i$i$i$i$i38;
  $60 = $uglygep3$i$i$i$i$i39 >>> 2;
  $61 = $60 ^ -1;
  $scevgep4$i$i$i$i$i40 = (($57) + ($61<<2)|0);
  HEAP32[$16>>2] = $scevgep4$i$i$i$i$i40;
 }
 __ZdlPv($55);
 ___resumeException($53|0);
 // unreachable;
}
function __ZNSt3__16vectorIjNS_9allocatorIjEEE6assignINS_11__wrap_iterIPjEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$promoted$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i10 = 0;
 var $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep8$i = 0, $scevgep8$i17 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i12 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($5>>>0)>($12>>>0);
 if (!($13)) {
  $14 = (($this) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15;
  $17 = (($16) - ($10))|0;
  $18 = $17 >> 2;
  $19 = ($5>>>0)>($18>>>0);
  if (!($19)) {
   $33 = $1;
   $34 = (($33) - ($3))|0;
   $35 = $34 >> 2;
   _memmove(($8|0),($0|0),($34|0))|0;
   $36 = (($8) + ($35<<2)|0);
   $37 = HEAP32[$14>>2]|0;
   $38 = ($37|0)==($36|0);
   if ($38) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $36;
   $scevgep$i$i = (($37) + -4|0);
   $39 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($39)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $40 = $uglygep3$i$i >>> 2;
   $41 = $40 ^ -1;
   $scevgep4$i$i = (($37) + ($41<<2)|0);
   HEAP32[$14>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $20 = (($0) + ($18<<2)|0);
  _memmove(($8|0),($0|0),($17|0))|0;
  $21 = ($20|0)==($1|0);
  if ($21) {
   STACKTOP = sp;return;
  }
  $22 = $20;
  $$promoted$i8 = HEAP32[$14>>2]|0;
  $scevgep$i10 = (($1) + -4|0);
  $23 = (0 - ($22))|0;
  $uglygep$i12 = (($scevgep$i10) + ($23)|0);
  $uglygep6$i13 = $uglygep$i12;
  $24 = $uglygep6$i13 >>> 2;
  $26 = $$promoted$i8;$28 = $20;
  while(1) {
   $25 = ($26|0)==(0|0);
   if (!($25)) {
    $27 = HEAP32[$28>>2]|0;
    HEAP32[$26>>2] = $27;
   }
   $29 = (($26) + 4|0);
   $30 = (($28) + 4|0);
   $31 = ($30|0)==($1|0);
   if ($31) {
    break;
   } else {
    $26 = $29;$28 = $30;
   }
  }
  $32 = (($24) + 1)|0;
  $scevgep8$i17 = (($$promoted$i8) + ($32<<2)|0);
  HEAP32[$14>>2] = $scevgep8$i17;
  STACKTOP = sp;return;
 }
 $42 = ($8|0)==(0|0);
 if ($42) {
  $51 = $7;
 } else {
  $43 = (($this) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==($8|0);
  if (!($45)) {
   $scevgep$i$i$i$i = (($44) + -4|0);
   $46 = (0 - ($10))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($46)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $47 = $uglygep3$i$i$i$i >>> 2;
   $48 = $47 ^ -1;
   $scevgep4$i$i$i$i = (($44) + ($48<<2)|0);
   HEAP32[$43>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($8);
  HEAP32[$6>>2] = 0;
  HEAP32[$43>>2] = 0;
  HEAP32[$this>>2] = 0;
  $51 = 0;
 }
 $49 = ($5>>>0)>(1073741823);
 if ($49) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $50 = $51;
 $52 = $50 >> 2;
 $53 = ($52>>>0)<(536870911);
 if ($53) {
  $54 = $50 >> 1;
  $55 = ($54>>>0)<($5>>>0);
  $56 = $55 ? $5 : $54;
  $57 = ($56>>>0)>(1073741823);
  if ($57) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $56;
  }
 } else {
  $$0$i37 = 1073741823;
 }
 $58 = $$0$i37 << 2;
 $59 = (__Znwj($58)|0);
 $60 = (($this) + 4|0);
 HEAP32[$60>>2] = $59;
 HEAP32[$this>>2] = $59;
 $61 = (($59) + ($$0$i37<<2)|0);
 HEAP32[$6>>2] = $61;
 $62 = ($0|0)==($1|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($1) + -4|0);
 $63 = (0 - ($3))|0;
 $uglygep$i = (($scevgep$i) + ($63)|0);
 $uglygep6$i = $uglygep$i;
 $64 = $uglygep6$i >>> 2;
 $66 = $59;$68 = $0;
 while(1) {
  $65 = ($66|0)==(0|0);
  if (!($65)) {
   $67 = HEAP32[$68>>2]|0;
   HEAP32[$66>>2] = $67;
  }
  $69 = (($66) + 4|0);
  $70 = (($68) + 4|0);
  $71 = ($70|0)==($1|0);
  if ($71) {
   break;
  } else {
   $66 = $69;$68 = $70;
  }
 }
 $72 = (($64) + 1)|0;
 $scevgep8$i = (($59) + ($72<<2)|0);
 HEAP32[$60>>2] = $scevgep8$i;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$$i$i = 0, $$0$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre3$i$i$i = 0, $$pre4$i$i$i = 0, $$pre5 = 0, $$pre5$i$i$i = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp + 12|0;
 $value1 = sp;
 $value2 = sp + 4|0;
 $value3 = sp + 8|0;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre3$i$i$i = HEAP32[$4>>2]|0;
  $10 = $$pre$i$i$i;$12 = $$pre3$i$i$i;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 32|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre4$i$i$i = HEAP32[$1>>2]|0;
  $$pre5$i$i$i = HEAP32[$4>>2]|0;
  $16 = $$pre4$i$i$i;$18 = $$pre5$i$i$i;
 } else {
  $13 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 36|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
 } else {
  $19 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
 }
 $20 = (($this) + 60|0);
 __ZN4PPtrI14PhysicMaterialE8TransferI18StreamedBinaryReadILb0EEEEvRT_($20,$transfer);
 $21 = (($this) + 52|0);
 $22 = HEAP32[$1>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$4>>2]|0;
 $25 = ($23>>>0)>($24>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$21,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$4>>2]|0;
  $28 = $$pre;$30 = $$pre5;
 } else {
  $26 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$21>>2] = $26;
  HEAP32[$1>>2] = $23;
  $28 = $23;$30 = $24;
 }
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$value,4);
 } else {
  $31 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$value>>2] = $31;
  HEAP32[$1>>2] = $27;
 }
 $32 = HEAP32[690120>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = Math_fround(HEAPF32[$value>>2]);
  $35 = (($this) + 40|0);
  HEAPF32[$35>>2] = $34;
 }
 $36 = HEAP32[$1>>2]|0;
 $37 = (($36) + 4|0);
 $38 = HEAP32[$4>>2]|0;
 $39 = ($37>>>0)>($38>>>0);
 if ($39) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$value1,4);
 } else {
  $40 = Math_fround(HEAPF32[$36>>2]);
  HEAPF32[$value1>>2] = $40;
  HEAP32[$1>>2] = $37;
 }
 $41 = HEAP32[690120>>2]|0;
 $42 = ($41|0)==(0|0);
 if (!($42)) {
  $43 = Math_fround(HEAPF32[$value1>>2]);
  $44 = (($this) + 44|0);
  HEAPF32[$44>>2] = $43;
 }
 $45 = HEAP32[$1>>2]|0;
 $46 = (($45) + 4|0);
 $47 = HEAP32[$4>>2]|0;
 $48 = ($46>>>0)>($47>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$value2,4);
 } else {
  $49 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$value2>>2] = $49;
  HEAP32[$1>>2] = $46;
 }
 $50 = HEAP32[690120>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  $52 = Math_fround(HEAPF32[$value2>>2]);
  $53 = (($this) + 48|0);
  HEAPF32[$53>>2] = $52;
 }
 $54 = HEAP32[$1>>2]|0;
 $55 = (($54) + 4|0);
 $56 = HEAP32[$4>>2]|0;
 $57 = ($55>>>0)>($56>>>0);
 if ($57) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$value3,4);
  $$pre6 = HEAP32[$value3>>2]|0;
  $62 = $$pre6;
 } else {
  $58 = HEAP32[$54>>2]|0;
  HEAP32[$value3>>2] = $58;
  HEAP32[$1>>2] = $55;
  $62 = $58;
 }
 $59 = HEAP32[690120>>2]|0;
 $60 = ($59|0)==(0|0);
 if (!($60)) {
  $61 = ($62|0)<(1);
  if ($61) {
   $$0$i$i = 1;
  } else {
   $63 = ($62|0)>(100);
   $$$i$i = $63 ? 100 : $62;
   $$0$i$i = $$$i$i;
  }
  $64 = (($this) + 104|0);
  HEAP32[$64>>2] = $$0$i$i;
 }
 $65 = (($this) + 56|0);
 $66 = HEAP32[$1>>2]|0;
 $67 = (($66) + 1|0);
 $68 = HEAP32[$4>>2]|0;
 $69 = ($67>>>0)>($68>>>0);
 if ($69) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$65,1);
  $$pre7 = HEAP32[$1>>2]|0;
  $75 = $$pre7;
 } else {
  $70 = HEAP8[$66>>0]|0;
  HEAP8[$65>>0] = $70;
  $71 = HEAP32[$1>>2]|0;
  $72 = (($71) + 1|0);
  HEAP32[$1>>2] = $72;
  $75 = $72;
 }
 $73 = (($this) + 57|0);
 $74 = (($75) + 1|0);
 $76 = HEAP32[$4>>2]|0;
 $77 = ($74>>>0)>($76>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$73,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  $81 = (($this) + 676|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIjNS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$81,0);
  STACKTOP = sp;return;
 } else {
  $78 = HEAP8[$75>>0]|0;
  HEAP8[$73>>0] = $78;
  $79 = HEAP32[$1>>2]|0;
  $80 = (($79) + 1|0);
  HEAP32[$1>>2] = $80;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  $81 = (($this) + 676|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIjNS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$81,0);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIjNS2_9allocatorIjEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIjNS0_9allocatorIjEEEEEvRT_j($data,$20);
  $21 = HEAP32[$size1>>2]|0;
  $22 = ($21|0)==(0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $23 = HEAP32[$data>>2]|0;
  $24 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$23,$24);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$$i$i = 0, $$0$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i5 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i4 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond13 = 0, $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i4 = sp + 16|0;
 $value = sp;
 $value1 = sp + 4|0;
 $value2 = sp + 8|0;
 $value3 = sp + 12|0;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580776>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,690496,$1,$converter$i$i4,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,690752,0);
   $5 = (($this) + 32|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,690760,0);
   $6 = (($this) + 36|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,690768,0);
  } else {
   $7 = HEAP32[$converter$i$i4>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    (FUNCTION_TABLE_iii[$7 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $9 = (($this) + 60|0);
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,690512,690784,$converter$i$i4,1)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ($10|0)>(0);
  if ($12) {
   __ZN4PPtrI14PhysicMaterialE8TransferI14SafeBinaryReadEEvRT_($9,$transfer);
  } else {
   $13 = HEAP32[$converter$i$i4>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    (FUNCTION_TABLE_iii[$13 & 4095]($9,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $15 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$15,690056,0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$value,690536,0);
 $16 = (($transfer) + 136|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 $19 = HEAP32[690120>>2]|0;
 $20 = ($19|0)==(0|0);
 $or$cond = $18 | $20;
 if (!($or$cond)) {
  $21 = Math_fround(HEAPF32[$value>>2]);
  $22 = (($this) + 40|0);
  HEAPF32[$22>>2] = $21;
 }
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$value1,690560,0);
 $23 = HEAP8[$16>>0]|0;
 $24 = ($23<<24>>24)==(0);
 $25 = HEAP32[690120>>2]|0;
 $26 = ($25|0)==(0|0);
 $or$cond11 = $24 | $26;
 if (!($or$cond11)) {
  $27 = Math_fround(HEAPF32[$value1>>2]);
  $28 = (($this) + 44|0);
  HEAPF32[$28>>2] = $27;
 }
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$value2,690584,0);
 $29 = HEAP8[$16>>0]|0;
 $30 = ($29<<24>>24)==(0);
 $31 = HEAP32[690120>>2]|0;
 $32 = ($31|0)==(0|0);
 $or$cond13 = $30 | $32;
 if (!($or$cond13)) {
  $33 = Math_fround(HEAPF32[$value2>>2]);
  $34 = (($this) + 48|0);
  HEAPF32[$34>>2] = $33;
 }
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$value3,690616,0);
 $35 = HEAP8[$16>>0]|0;
 $36 = ($35<<24>>24)==(0);
 if (!($36)) {
  $37 = HEAP32[$value3>>2]|0;
  $38 = HEAP32[690120>>2]|0;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   $40 = ($37|0)<(1);
   if ($40) {
    $$0$i$i = 1;
   } else {
    $41 = ($37|0)>(100);
    $$$i$i = $41 ? 100 : $37;
    $$0$i$i = $$$i$i;
   }
   $42 = (($this) + 104|0);
   HEAP32[$42>>2] = $$0$i$i;
  }
 }
 $43 = (($this) + 56|0);
 $44 = HEAP32[580544>>2]|0;
 $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,690640,$44,$converter$i$i4,0)|0);
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = ($45|0)>(0);
  do {
   if ($47) {
    $48 = (($transfer) + 12|0);
    $49 = (($transfer) + 80|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + 12|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($transfer) + 16|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($transfer) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($transfer) + 32|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = Math_imul($58, $56)|0;
    $$sum$i$i$i$i$i5 = (($52) - ($59))|0;
    $60 = (($54) + ($$sum$i$i$i$i$i5)|0);
    HEAP32[$48>>2] = $60;
    $61 = ($$sum$i$i$i$i$i5|0)<(0);
    if (!($61)) {
     $$sum1$i$i$i$i$i6 = (($$sum$i$i$i$i$i5) + 1)|0;
     $62 = (($54) + ($$sum1$i$i$i$i$i6)|0);
     $63 = (($transfer) + 20|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($62>>>0)>($64>>>0);
     if (!($65)) {
      $66 = HEAP8[$60>>0]|0;
      HEAP8[$43>>0] = $66;
      $67 = HEAP32[$48>>2]|0;
      $68 = (($67) + 1|0);
      HEAP32[$48>>2] = $68;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($48,$43,1);
   } else {
    $69 = HEAP32[$converter$i$i4>>2]|0;
    $70 = ($69|0)==(0|0);
    if (!($70)) {
     (FUNCTION_TABLE_iii[$69 & 4095]($43,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $71 = (($this) + 57|0);
 $72 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,690664,$44,$converter$i$i4,0)|0);
 $73 = ($72|0)==(0);
 if (!($73)) {
  $74 = ($72|0)>(0);
  do {
   if ($74) {
    $75 = (($transfer) + 12|0);
    $76 = (($transfer) + 80|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($77) + 12|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($transfer) + 16|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($transfer) + 28|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($transfer) + 32|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = Math_imul($85, $83)|0;
    $$sum$i$i$i$i$i = (($79) - ($86))|0;
    $87 = (($81) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$75>>2] = $87;
    $88 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($88)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $89 = (($81) + ($$sum1$i$i$i$i$i)|0);
     $90 = (($transfer) + 20|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($89>>>0)>($91>>>0);
     if (!($92)) {
      $93 = HEAP8[$87>>0]|0;
      HEAP8[$71>>0] = $93;
      $94 = HEAP32[$75>>2]|0;
      $95 = (($94) + 1|0);
      HEAP32[$75>>2] = $95;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($75,$71,1);
   } else {
    $96 = HEAP32[$converter$i$i4>>2]|0;
    $97 = ($96|0)==(0|0);
    if (!($97)) {
     (FUNCTION_TABLE_iii[$96 & 4095]($71,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $98 = (($this) + 676|0);
 $99 = HEAP32[580760>>2]|0;
 $100 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,690688,$99,$converter$i$i4,1)|0);
 $101 = ($100|0)==(0);
 if ($101) {
  STACKTOP = sp;return;
 }
 $102 = ($100|0)>(0);
 if ($102) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIjNS1_9allocatorIjEEEEEEvRT_17TransferMetaFlags($transfer,$98,0);
 } else {
  $103 = HEAP32[$converter$i$i4>>2]|0;
  $104 = ($103|0)==(0|0);
  if (!($104)) {
   (FUNCTION_TABLE_iii[$103 & 4095]($98,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIjNS1_9allocatorIjEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,690776,690776,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIjNS0_9allocatorIjEEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 L4: do {
  if (!($13)) {
   $14 = HEAP32[580752>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,690712,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if (!($23)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $75 = HEAP32[$data>>2]|0;
    $76 = ($75|0)==($11|0);
    if ($76) {
     break;
    } else {
     $77 = $75;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$77,690712,0);
     $78 = (($77) + 4|0);
     $79 = ($78|0)==($11|0);
     if ($79) {
      break L4;
     } else {
      $77 = $78;
     }
    }
   }
   $24 = HEAP32[$16>>2]|0;
   $25 = (($24) + 12|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$data>>2]|0;
   $28 = ($27|0)==($11|0);
   L11: do {
    if (!($28)) {
     $29 = (($this) + 12|0);
     $30 = (($this) + 16|0);
     $31 = (($this) + 28|0);
     $32 = (($this) + 32|0);
     $33 = (($this) + 20|0);
     $35 = 0;$38 = $24;$67 = $27;
     while(1) {
      $34 = Math_imul($35, $20)|0;
      $36 = (($34) + ($26))|0;
      $37 = (($38) + 20|0);
      HEAP32[$37>>2] = $36;
      $39 = (($38) + 12|0);
      HEAP32[$39>>2] = $36;
      $40 = (($38) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$38);
      $41 = $1;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = (($41) + 4)|0;
      $45 = $44;
      $46 = HEAP32[$45>>2]|0;
      $47 = $40;
      $48 = $47;
      HEAP32[$48>>2] = $43;
      $49 = (($47) + 4)|0;
      $50 = $49;
      HEAP32[$50>>2] = $46;
      $51 = HEAP32[$21>>2]|0;
      $52 = HEAP32[$51>>2]|0;
      $53 = (($52) + 1)|0;
      HEAP32[$51>>2] = $53;
      $54 = HEAP32[$16>>2]|0;
      $55 = (($54) + 12|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = HEAP32[$32>>2]|0;
      $60 = Math_imul($59, $58)|0;
      $$sum$i$i$i = (($56) - ($60))|0;
      $61 = (($57) + ($$sum$i$i$i)|0);
      HEAP32[$29>>2] = $61;
      $62 = ($$sum$i$i$i|0)<(0);
      if ($62) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $63 = (($57) + ($$sum1$i$i$i)|0);
       $64 = HEAP32[$33>>2]|0;
       $65 = ($63>>>0)>($64>>>0);
       if ($65) {
        label = 9;
       } else {
        $66 = HEAP32[$61>>2]|0;
        HEAP32[$67>>2] = $66;
        HEAP32[$29>>2] = $63;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($29,$67,4);
      }
      $68 = HEAP32[$this>>2]|0;
      $69 = $68 & 512;
      $70 = ($69|0)==(0);
      if (!($70)) {
       $71 = HEAP32[$67>>2]|0;
       $72 = (_llvm_bswap_i32(($71|0))|0);
       HEAP32[$67>>2] = $72;
      }
      $73 = (($67) + 4|0);
      $74 = ($73|0)==($11|0);
      if ($74) {
       break L11;
      }
      $$pre = HEAP32[$21>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$16>>2]|0;
      $35 = $$pre8;$38 = $$pre9;$67 = $73;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, $value = 0, $value1 = 0, $value2 = 0, $value3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 32|0;
 $value = sp + 16|0;
 $value1 = sp + 20|0;
 $value2 = sp + 24|0;
 $value3 = sp + 28|0;
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580776>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690496,$1,$0,2048);
 $2 = (($transfer) + 16|0);
 $3 = (__ZNK16TypeTreeIterator7GetNodeEv($2)|0);
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 | 2097152;
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 20|0);
 HEAP32[$12>>2] = $6;
 $13 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690752,$13,$0,0);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690760,$13,$18,0);
 $19 = HEAP32[$7>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$10>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690768,$13,$23,0);
 $24 = HEAP32[$7>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$10>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690512,690784,$28,2048);
 $29 = (($size$i$i$i$i) + 8|0);
 $30 = $29;
 $31 = $30;
 HEAP32[$31>>2] = 0;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = 0;
 HEAP32[$size$i$i$i$i>>2] = 0;
 $34 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690720,$34,$28,1);
 $35 = HEAP32[$7>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$10>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $39 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690736,$39,$29,1);
 $40 = HEAP32[$7>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$10>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690056,$13,$44,2048);
 $45 = HEAP32[$7>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$10>>2]|0;
 $48 = ((($46) + (($47*24)|0)|0) + 12|0);
 HEAP32[$48>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690536,$13,$value,0);
 $49 = HEAP32[$7>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$10>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690560,$13,$value1,0);
 $53 = HEAP32[$7>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$10>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690584,$13,$value2,0);
 $57 = HEAP32[$7>>2]|0;
 $58 = HEAP32[$57>>2]|0;
 $59 = HEAP32[$10>>2]|0;
 $60 = ((($58) + (($59*24)|0)|0) + 12|0);
 HEAP32[$60>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690616,$34,$value3,0);
 $61 = HEAP32[$7>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP32[$10>>2]|0;
 $64 = ((($62) + (($63*24)|0)|0) + 12|0);
 HEAP32[$64>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $65 = (($this) + 56|0);
 $66 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690640,$66,$65,0);
 $67 = HEAP32[$7>>2]|0;
 $68 = HEAP32[$67>>2]|0;
 $69 = HEAP32[$10>>2]|0;
 $70 = ((($68) + (($69*24)|0)|0) + 12|0);
 HEAP32[$70>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $71 = (($this) + 57|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690664,$66,$71,0);
 $72 = HEAP32[$7>>2]|0;
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$10>>2]|0;
 $75 = ((($73) + (($74*24)|0)|0) + 12|0);
 HEAP32[$75>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $76 = (($this) + 676|0);
 $77 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690688,$77,$76,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,690776,690776,$size$i$i$i$i,0);
 $78 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,690712,$78,$p$i$i$i,0);
 $79 = HEAP32[$7>>2]|0;
 $80 = HEAP32[$79>>2]|0;
 $81 = HEAP32[$10>>2]|0;
 $82 = ((($80) + (($81*24)|0)|0) + 12|0);
 HEAP32[$82>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI10RaycastHitNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 44)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    dest=$10+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 44|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = (($17|0) / 44)&-1;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(97612893);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = (($21|0) / 44)&-1;
 $23 = ($22>>>0)<(48806446);
 if ($23) {
  $24 = $22 << 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i57 = 0;$31 = 0;
  } else {
   $$0$i56 = $26;
   label = 9;
  }
 } else {
  $$0$i56 = 97612893;
  label = 9;
 }
 if ((label|0) == 9) {
  $28 = ($$0$i56*44)|0;
  $29 = (__Znwj($28)|0);
  $$0$i57 = $$0$i56;$31 = $29;
 }
 $30 = (($31) + (($18*44)|0)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if ($32) {
   $35 = 0;
  } else {
   dest=$33+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;HEAP32[$33+16>>2]=0|0;HEAP32[$33+20>>2]=0|0;
   $35 = $33;
  }
  $34 = (($35) + 44|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $34;
  }
 }
 $38 = (($31) + (($$0$i57*44)|0)|0);
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = $40;
 $42 = $39;
 $43 = (($41) - ($42))|0;
 $44 = (($43|0) / -44)&-1;
 $$sum = (($44) + ($18))|0;
 $45 = (($31) + (($$sum*44)|0)|0);
 _memcpy(($45|0),($39|0),($43|0))|0;
 HEAP32[$this>>2] = $45;
 HEAP32[$2>>2] = $34;
 HEAP32[$0>>2] = $38;
 $46 = ($39|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZdlPv($39);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_4pairIPN5physx7PxShapeES5_EEN14PhysicsManager16TriggerStayStateEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIPN5physx7PxShapeES5_EEN14PhysicsManager16TriggerStayStateEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_4pairIPN5physx7PxShapeES5_EEN14PhysicsManager16TriggerStayStateEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN5physx12PxOverlapHitENS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $14 = 0;
   } else {
    ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
    HEAP32[$10>>2] = 0;
    $11 = (($10) + 4|0);
    HEAP32[$11>>2] = 0;
    $12 = (($10) + 8|0);
    HEAP32[$12>>2] = -1;
    $$pre1$i = HEAP32[$2>>2]|0;
    $14 = $$pre1$i;
   }
   $13 = (($14) + 16|0);
   HEAP32[$2>>2] = $13;
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$10 = $13;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($5) - ($18))|0;
 $20 = $19 >> 4;
 $21 = (($20) + ($__n))|0;
 $22 = ($21>>>0)>(268435455);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($4) - ($18))|0;
 $24 = $23 >> 4;
 $25 = ($24>>>0)<(134217727);
 if ($25) {
  $26 = $23 >> 3;
  $27 = ($26>>>0)<($21>>>0);
  $28 = $27 ? $21 : $26;
  $29 = ($28|0)==(0);
  if ($29) {
   $$0$i57 = 0;$33 = 0;
  } else {
   $$0$i56 = $28;
   label = 9;
  }
 } else {
  $$0$i56 = 268435455;
  label = 9;
 }
 if ((label|0) == 9) {
  $30 = $$0$i56 << 4;
  $31 = (__Znwj($30)|0);
  $$0$i57 = $$0$i56;$33 = $31;
 }
 $32 = (($33) + ($20<<4)|0);
 $$0$i2 = $__n;$35 = $32;
 while(1) {
  $34 = ($35|0)==(0|0);
  if ($34) {
   $39 = 0;
  } else {
   ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;
   HEAP32[$35>>2] = 0;
   $36 = (($35) + 4|0);
   HEAP32[$36>>2] = 0;
   $37 = (($35) + 8|0);
   HEAP32[$37>>2] = -1;
   $39 = $35;
  }
  $38 = (($39) + 16|0);
  $40 = (($$0$i2) + -1)|0;
  $41 = ($40|0)==(0);
  if ($41) {
   break;
  } else {
   $$0$i2 = $40;$35 = $38;
  }
 }
 $42 = (($33) + ($$0$i57<<4)|0);
 $43 = HEAP32[$this>>2]|0;
 $44 = HEAP32[$2>>2]|0;
 $45 = $44;
 $46 = $43;
 $47 = (($45) - ($46))|0;
 $48 = $47 >> 4;
 $$sum = (($20) - ($48))|0;
 $49 = (($33) + ($$sum<<4)|0);
 _memcpy(($49|0),($43|0),($47|0))|0;
 HEAP32[$this>>2] = $49;
 HEAP32[$2>>2] = $38;
 HEAP32[$0>>2] = $42;
 $50 = ($43|0)==(0|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 __ZdlPv($43);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN5physx12PxRaycastHitENS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i712 = 0, $$0$i713 = 0, $$01$i$i = 0, $$pre$i2 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0;
 var $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $scevgep = 0, $scevgep11 = 0, $uglygep = 0, $uglygep10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 6;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $19 = 0;
   } else {
    HEAP32[$10>>2] = 0;
    $11 = (($10) + 4|0);
    HEAP32[$11>>2] = 0;
    $12 = (($10) + 8|0);
    HEAP32[$12>>2] = -1;
    $13 = (($10) + 12|0);
    HEAP16[$13>>1] = 0;
    $14 = (($10) + 16|0);
    $15 = (($10) + 40|0);
    ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;HEAP32[$14+16>>2]=0|0;HEAP32[$14+20>>2]=0|0;
    HEAPF32[$15>>2] = Math_fround(3.40282346638528859812E+38);
    $16 = (($10) + 44|0);
    HEAPF32[$16>>2] = Math_fround(0.0);
    $17 = (($10) + 48|0);
    HEAPF32[$17>>2] = Math_fround(0.0);
    $$pre1$i = HEAP32[$2>>2]|0;
    $19 = $$pre1$i;
   }
   $18 = (($19) + 64|0);
   HEAP32[$2>>2] = $18;
   $20 = (($$0$i) + -1)|0;
   $21 = ($20|0)==(0);
   if ($21) {
    break;
   } else {
    $$0$i = $20;$10 = $18;
   }
  }
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$this>>2]|0;
 $23 = $22;
 $24 = (($5) - ($23))|0;
 $25 = $24 >> 6;
 $26 = (($25) + ($__n))|0;
 $27 = ($26>>>0)>(67108863);
 if ($27) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $28 = (($4) - ($23))|0;
 $29 = $28 >> 6;
 $30 = ($29>>>0)<(33554431);
 if ($30) {
  $31 = $28 >> 5;
  $32 = ($31>>>0)<($26>>>0);
  $33 = $32 ? $26 : $31;
  $34 = ($33|0)==(0);
  if ($34) {
   $$0$i713 = 0;$38 = 0;
  } else {
   $$0$i712 = $33;
   label = 9;
  }
 } else {
  $$0$i712 = 67108863;
  label = 9;
 }
 if ((label|0) == 9) {
  $35 = $$0$i712 << 6;
  $36 = (__Znwj($35)|0);
  $$0$i713 = $$0$i712;$38 = $36;
 }
 $37 = (($38) + ($25<<6)|0);
 $$0$i4 = $__n;$40 = $37;
 while(1) {
  $39 = ($40|0)==(0|0);
  if ($39) {
   $49 = 0;
  } else {
   HEAP32[$40>>2] = 0;
   $41 = (($40) + 4|0);
   HEAP32[$41>>2] = 0;
   $42 = (($40) + 8|0);
   HEAP32[$42>>2] = -1;
   $43 = (($40) + 12|0);
   HEAP16[$43>>1] = 0;
   $44 = (($40) + 16|0);
   $45 = (($40) + 40|0);
   ;HEAP32[$44+0>>2]=0|0;HEAP32[$44+4>>2]=0|0;HEAP32[$44+8>>2]=0|0;HEAP32[$44+12>>2]=0|0;HEAP32[$44+16>>2]=0|0;HEAP32[$44+20>>2]=0|0;
   HEAPF32[$45>>2] = Math_fround(3.40282346638528859812E+38);
   $46 = (($40) + 44|0);
   HEAPF32[$46>>2] = Math_fround(0.0);
   $47 = (($40) + 48|0);
   HEAPF32[$47>>2] = Math_fround(0.0);
   $49 = $40;
  }
  $48 = (($49) + 64|0);
  $50 = (($$0$i4) + -1)|0;
  $51 = ($50|0)==(0);
  if ($51) {
   break;
  } else {
   $$0$i4 = $50;$40 = $48;
  }
 }
 $52 = (($38) + ($$0$i713<<6)|0);
 $53 = HEAP32[$this>>2]|0;
 $54 = HEAP32[$2>>2]|0;
 $55 = ($54|0)==($53|0);
 if ($55) {
  $91 = $37;$93 = $53;
 } else {
  $56 = $53;
  $57 = (($25) + -1)|0;
  $scevgep = (($54) + -64|0);
  $58 = (0 - ($56))|0;
  $uglygep = (($scevgep) + ($58)|0);
  $uglygep10 = $uglygep;
  $59 = $uglygep10 >>> 6;
  $60 = (($57) - ($59))|0;
  $$01$i$i = $54;$62 = $37;
  while(1) {
   $61 = (($62) + -64|0);
   $63 = (($$01$i$i) + -64|0);
   ;HEAP32[$61+0>>2]=HEAP32[$63+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$63+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$63+8>>2]|0;
   $64 = (($$01$i$i) + -52|0);
   $65 = HEAP16[$64>>1]|0;
   $66 = (($62) + -52|0);
   HEAP16[$66>>1] = $65;
   $67 = (($62) + -48|0);
   $68 = (($$01$i$i) + -48|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   HEAPF32[$67>>2] = $69;
   $70 = (($62) + -44|0);
   $71 = (($$01$i$i) + -44|0);
   $72 = Math_fround(HEAPF32[$71>>2]);
   HEAPF32[$70>>2] = $72;
   $73 = (($62) + -40|0);
   $74 = (($$01$i$i) + -40|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   HEAPF32[$73>>2] = $75;
   $76 = (($62) + -36|0);
   $77 = (($$01$i$i) + -36|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   HEAPF32[$76>>2] = $78;
   $79 = (($62) + -32|0);
   $80 = (($$01$i$i) + -32|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   HEAPF32[$79>>2] = $81;
   $82 = (($62) + -28|0);
   $83 = (($$01$i$i) + -28|0);
   $84 = Math_fround(HEAPF32[$83>>2]);
   HEAPF32[$82>>2] = $84;
   $85 = (($62) + -24|0);
   $86 = (($$01$i$i) + -24|0);
   $87 = Math_fround(HEAPF32[$86>>2]);
   HEAPF32[$85>>2] = $87;
   $88 = (($62) + -20|0);
   $89 = (($$01$i$i) + -20|0);
   ;HEAP32[$88+0>>2]=HEAP32[$89+0>>2]|0;HEAP32[$88+4>>2]=HEAP32[$89+4>>2]|0;HEAP32[$88+8>>2]=HEAP32[$89+8>>2]|0;HEAP32[$88+12>>2]=HEAP32[$89+12>>2]|0;HEAP32[$88+16>>2]=HEAP32[$89+16>>2]|0;
   $90 = ($63|0)==($53|0);
   if ($90) {
    break;
   } else {
    $$01$i$i = $63;$62 = $61;
   }
  }
  $scevgep11 = (($38) + ($60<<6)|0);
  $$pre$i2 = HEAP32[$this>>2]|0;
  $91 = $scevgep11;$93 = $$pre$i2;
 }
 HEAP32[$this>>2] = $91;
 HEAP32[$2>>2] = $48;
 HEAP32[$0>>2] = $52;
 $92 = ($93|0)==(0|0);
 if ($92) {
  STACKTOP = sp;return;
 }
 __ZdlPv($93);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN5physx10PxSweepHitENS_9allocatorIS2_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i712 = 0, $$0$i713 = 0, $$01$i$i = 0, $$pre$i2 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0);
 var $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $scevgep = 0, $scevgep11 = 0;
 var $uglygep = 0, $uglygep10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 48)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $17 = 0;
   } else {
    HEAP32[$10>>2] = 0;
    $11 = (($10) + 4|0);
    HEAP32[$11>>2] = 0;
    $12 = (($10) + 8|0);
    HEAP32[$12>>2] = -1;
    $13 = (($10) + 12|0);
    HEAP16[$13>>1] = 0;
    $14 = (($10) + 16|0);
    $15 = (($10) + 40|0);
    ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;HEAP32[$14+16>>2]=0|0;HEAP32[$14+20>>2]=0|0;
    HEAPF32[$15>>2] = Math_fround(3.40282346638528859812E+38);
    $$pre1$i = HEAP32[$2>>2]|0;
    $17 = $$pre1$i;
   }
   $16 = (($17) + 48|0);
   HEAP32[$2>>2] = $16;
   $18 = (($$0$i) + -1)|0;
   $19 = ($18|0)==(0);
   if ($19) {
    break;
   } else {
    $$0$i = $18;$10 = $16;
   }
  }
  STACKTOP = sp;return;
 }
 $20 = HEAP32[$this>>2]|0;
 $21 = $20;
 $22 = (($5) - ($21))|0;
 $23 = (($22|0) / 48)&-1;
 $24 = (($23) + ($__n))|0;
 $25 = ($24>>>0)>(89478485);
 if ($25) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $26 = (($4) - ($21))|0;
 $27 = (($26|0) / 48)&-1;
 $28 = ($27>>>0)<(44739242);
 if ($28) {
  $29 = $27 << 1;
  $30 = ($29>>>0)<($24>>>0);
  $31 = $30 ? $24 : $29;
  $32 = ($31|0)==(0);
  if ($32) {
   $$0$i713 = 0;$36 = 0;
  } else {
   $$0$i712 = $31;
   label = 9;
  }
 } else {
  $$0$i712 = 89478485;
  label = 9;
 }
 if ((label|0) == 9) {
  $33 = ($$0$i712*48)|0;
  $34 = (__Znwj($33)|0);
  $$0$i713 = $$0$i712;$36 = $34;
 }
 $35 = (($36) + (($23*48)|0)|0);
 $$0$i4 = $__n;$38 = $35;
 while(1) {
  $37 = ($38|0)==(0|0);
  if ($37) {
   $45 = 0;
  } else {
   HEAP32[$38>>2] = 0;
   $39 = (($38) + 4|0);
   HEAP32[$39>>2] = 0;
   $40 = (($38) + 8|0);
   HEAP32[$40>>2] = -1;
   $41 = (($38) + 12|0);
   HEAP16[$41>>1] = 0;
   $42 = (($38) + 16|0);
   $43 = (($38) + 40|0);
   ;HEAP32[$42+0>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;HEAP32[$42+12>>2]=0|0;HEAP32[$42+16>>2]=0|0;HEAP32[$42+20>>2]=0|0;
   HEAPF32[$43>>2] = Math_fround(3.40282346638528859812E+38);
   $45 = $38;
  }
  $44 = (($45) + 48|0);
  $46 = (($$0$i4) + -1)|0;
  $47 = ($46|0)==(0);
  if ($47) {
   break;
  } else {
   $$0$i4 = $46;$38 = $44;
  }
 }
 $48 = (($36) + (($$0$i713*48)|0)|0);
 $49 = HEAP32[$this>>2]|0;
 $50 = HEAP32[$2>>2]|0;
 $51 = ($50|0)==($49|0);
 if ($51) {
  $88 = $35;$90 = $49;
 } else {
  $52 = $49;
  $53 = (($23) + -1)|0;
  $scevgep = (($50) + -48|0);
  $54 = (0 - ($52))|0;
  $uglygep = (($scevgep) + ($54)|0);
  $uglygep10 = $uglygep;
  $55 = (($uglygep10>>>0) / 48)&-1;
  $56 = (($53) - ($55))|0;
  $$01$i$i = $50;$58 = $35;
  while(1) {
   $57 = (($58) + -48|0);
   $59 = (($$01$i$i) + -48|0);
   ;HEAP32[$57+0>>2]=HEAP32[$59+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$59+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$59+8>>2]|0;
   $60 = (($$01$i$i) + -36|0);
   $61 = HEAP16[$60>>1]|0;
   $62 = (($58) + -36|0);
   HEAP16[$62>>1] = $61;
   $63 = (($58) + -32|0);
   $64 = (($$01$i$i) + -32|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   HEAPF32[$63>>2] = $65;
   $66 = (($58) + -28|0);
   $67 = (($$01$i$i) + -28|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   HEAPF32[$66>>2] = $68;
   $69 = (($58) + -24|0);
   $70 = (($$01$i$i) + -24|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   HEAPF32[$69>>2] = $71;
   $72 = (($58) + -20|0);
   $73 = (($$01$i$i) + -20|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   HEAPF32[$72>>2] = $74;
   $75 = (($58) + -16|0);
   $76 = (($$01$i$i) + -16|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   HEAPF32[$75>>2] = $77;
   $78 = (($58) + -12|0);
   $79 = (($$01$i$i) + -12|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   HEAPF32[$78>>2] = $80;
   $81 = (($58) + -8|0);
   $82 = (($$01$i$i) + -8|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   HEAPF32[$81>>2] = $83;
   $84 = (($58) + -4|0);
   $85 = (($$01$i$i) + -4|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$84>>2] = $86;
   $87 = ($59|0)==($49|0);
   if ($87) {
    break;
   } else {
    $$01$i$i = $59;$58 = $57;
   }
  }
  $scevgep11 = (($36) + (($56*48)|0)|0);
  $$pre$i2 = HEAP32[$this>>2]|0;
  $88 = $scevgep11;$90 = $$pre$i2;
 }
 HEAP32[$this>>2] = $88;
 HEAP32[$2>>2] = $44;
 HEAP32[$0>>2] = $48;
 $89 = ($90|0)==(0|0);
 if ($89) {
  STACKTOP = sp;return;
 }
 __ZdlPv($90);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIjNS_9allocatorIjEEE8__appendEjRKj($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    $11 = HEAP32[$__x>>2]|0;
    HEAP32[$10>>2] = $11;
   }
   $12 = (($10) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $12;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(1073741823);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(536870911);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  $29 = (__Znwj($28)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   $34 = HEAP32[$__x>>2]|0;
   HEAP32[$33>>2] = $34;
  }
  $35 = (($33) + 4|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $35;
  }
 }
 $38 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 _memcpy(($31|0),($15|0),($17|0))|0;
 HEAP32[$this>>2] = $31;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $38;
 $39 = ($15|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 __ZdlPv($15);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN14PhysicsManager18RecordedJointBreakENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i4 = 0, $$0$i5 = 0, $$01$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, $scevgep3 = 0, $uglygep = 0, $uglygep2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($13>>>0)<(178956970);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i5 = 0;$22 = 0;
  } else {
   $$0$i4 = $17;
   label = 5;
  }
 } else {
  $$0$i4 = 357913941;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i4*12)|0;
  $20 = (__Znwj($19)|0);
  $$0$i5 = $$0$i4;$22 = $20;
 }
 $21 = (($22) + (($6*12)|0)|0);
 $23 = (($22) + (($$0$i5*12)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  $25 = $__x;
  $26 = $25;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 4)|0;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = $21;
  $32 = $31;
  HEAP32[$32>>2] = $27;
  $33 = (($31) + 4)|0;
  $34 = $33;
  HEAP32[$34>>2] = $30;
  $35 = (($__x) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($22) + (($6*12)|0)|0) + 8|0);
  HEAP32[$37>>2] = $36;
 }
 $38 = (($22) + (($7*12)|0)|0);
 $39 = ($1|0)==($2|0);
 if ($39) {
  $61 = $21;$63 = $1;
 } else {
  $40 = (($6) + -1)|0;
  $scevgep = (($1) + -12|0);
  $41 = (0 - ($4))|0;
  $uglygep = (($scevgep) + ($41)|0);
  $uglygep2 = $uglygep;
  $42 = (($uglygep2>>>0) / 12)&-1;
  $43 = (($40) - ($42))|0;
  $$01$i$i = $1;$45 = $21;
  while(1) {
   $44 = (($45) + -12|0);
   $46 = (($$01$i$i) + -12|0);
   $47 = $46;
   $48 = $47;
   $49 = HEAP32[$48>>2]|0;
   $50 = (($47) + 4)|0;
   $51 = $50;
   $52 = HEAP32[$51>>2]|0;
   $53 = $44;
   $54 = $53;
   HEAP32[$54>>2] = $49;
   $55 = (($53) + 4)|0;
   $56 = $55;
   HEAP32[$56>>2] = $52;
   $57 = (($$01$i$i) + -4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (($45) + -4|0);
   HEAP32[$59>>2] = $58;
   $60 = ($46|0)==($2|0);
   if ($60) {
    break;
   } else {
    $$01$i$i = $46;$45 = $44;
   }
  }
  $scevgep3 = (($22) + (($43*12)|0)|0);
  $$pre$i = HEAP32[$this>>2]|0;
  $61 = $scevgep3;$63 = $$pre$i;
 }
 HEAP32[$this>>2] = $61;
 HEAP32[$0>>2] = $38;
 HEAP32[$9>>2] = $23;
 $62 = ($63|0)==(0|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 __ZdlPv($63);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI9CollisionNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i26 = 0, $$0$i27 = 0, $$pre = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__f$01$i$i$i$i$i$i$i = 0, $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i3 = 0, $__v = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep = 0, $scevgep15 = 0, $scevgep16 = 0, $scevgep20 = 0, $uglygep = 0, $uglygep14 = 0, $uglygep18 = 0, $uglygep1819 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 72)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8>>>0)>(59652323);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 72)&-1;
 $15 = ($14>>>0)<(29826161);
 if ($15) {
  $18 = $14 << 1;
  $19 = ($18>>>0)<($8>>>0);
  $20 = $19 ? $8 : $18;
  $21 = (($__v) + 12|0);
  HEAP32[$21>>2] = 0;
  $22 = (($__v) + 16|0);
  HEAP32[$22>>2] = $0;
  $23 = ($20|0)==(0);
  if ($23) {
   $$0$i27 = 0;$26 = 0;$31 = $21;
  } else {
   $$0$i26 = $20;$133 = $21;
   label = 6;
  }
 } else {
  $16 = (($__v) + 12|0);
  HEAP32[$16>>2] = 0;
  $17 = (($__v) + 16|0);
  HEAP32[$17>>2] = $0;
  $$0$i26 = 59652323;$133 = $16;
  label = 6;
 }
 if ((label|0) == 6) {
  $24 = ($$0$i26*72)|0;
  $25 = (__Znwj($24)|0);
  $$0$i27 = $$0$i26;$26 = $25;$31 = $133;
 }
 HEAP32[$__v>>2] = $26;
 $27 = (($26) + (($7*72)|0)|0);
 $28 = (($__v) + 8|0);
 HEAP32[$28>>2] = $27;
 $29 = (($__v) + 4|0);
 HEAP32[$29>>2] = $27;
 $30 = (($26) + (($$0$i27*72)|0)|0);
 HEAP32[$31>>2] = $30;
 $32 = ($27|0)==(0|0);
 do {
  if ($32) {
   $70 = 0;
   label = 15;
  } else {
   dest=$27+0|0; src=$__x+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $33 = ((($26) + (($7*72)|0)|0) + 60|0);
   $34 = (($__x) + 60|0);
   HEAP32[$33>>2] = $33;
   $35 = ((($26) + (($7*72)|0)|0) + 64|0);
   HEAP32[$35>>2] = $33;
   $36 = ((($26) + (($7*72)|0)|0) + 68|0);
   HEAP32[$36>>2] = 0;
   $37 = (($__x) + 64|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==($34|0);
   if ($39) {
    $70 = $27;
    label = 15;
   } else {
    $44 = $38;$47 = $33;$51 = 0;
    while(1) {
     __THREW__ = 0;
     $40 = (invoke_ii(2988,40)|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     $43 = (($44) + 8|0);
     $45 = (($40) + 8|0);
     ;HEAP32[$45+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$43+12>>2]|0;HEAP32[$45+16>>2]=HEAP32[$43+16>>2]|0;HEAP32[$45+20>>2]=HEAP32[$43+20>>2]|0;HEAP32[$45+24>>2]=HEAP32[$43+24>>2]|0;HEAP32[$45+28>>2]=HEAP32[$43+28>>2]|0;
     $46 = (($47) + 4|0);
     HEAP32[$46>>2] = $40;
     $48 = HEAP32[$33>>2]|0;
     HEAP32[$40>>2] = $48;
     HEAP32[$33>>2] = $40;
     $49 = (($40) + 4|0);
     HEAP32[$49>>2] = $33;
     $50 = (($51) + 1)|0;
     HEAP32[$36>>2] = $50;
     $52 = (($44) + 4|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)==($34|0);
     if ($54) {
      label = 14;
      break;
     } else {
      $44 = $53;$47 = $40;$51 = $50;
     }
    }
    if ((label|0) == 14) {
     $$pre = HEAP32[$28>>2]|0;
     $70 = $$pre;
     label = 15;
     break;
    }
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    $57 = ($51|0)==(0);
    if ($57) {
     $106 = $27;$eh$lpad$body$index4Z2D = $56;$eh$lpad$body$indexZ2D = $55;
    } else {
     $58 = HEAP32[$35>>2]|0;
     $59 = (($47) + 4|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = HEAP32[$58>>2]|0;
     $62 = (($61) + 4|0);
     HEAP32[$62>>2] = $60;
     $63 = HEAP32[$58>>2]|0;
     $64 = HEAP32[$59>>2]|0;
     HEAP32[$64>>2] = $63;
     HEAP32[$36>>2] = 0;
     $65 = ($58|0)==($33|0);
     if ($65) {
      $106 = $27;$eh$lpad$body$index4Z2D = $56;$eh$lpad$body$indexZ2D = $55;
     } else {
      $__f$01$i$i$i$i$i$i$i = $58;
      while(1) {
       $66 = (($__f$01$i$i$i$i$i$i$i) + 4|0);
       $67 = HEAP32[$66>>2]|0;
       __ZdlPv($__f$01$i$i$i$i$i$i$i);
       $68 = ($67|0)==($33|0);
       if ($68) {
        $106 = $27;$eh$lpad$body$index4Z2D = $56;$eh$lpad$body$indexZ2D = $55;
        break;
       } else {
        $__f$01$i$i$i$i$i$i$i = $67;
       }
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   $69 = (($70) + 72|0);
   HEAP32[$28>>2] = $69;
   __THREW__ = 0;
   invoke_vii(3327,($this|0),($__v|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if ($72) {
    $102 = ___cxa_find_matching_catch()|0;
    $103 = tempRet0;
    $$pre24 = HEAP32[$29>>2]|0;
    $106 = $$pre24;$eh$lpad$body$index4Z2D = $103;$eh$lpad$body$indexZ2D = $102;
    break;
   }
   $73 = HEAP32[$29>>2]|0;
   $74 = HEAP32[$28>>2]|0;
   $75 = ($74|0)==($73|0);
   if (!($75)) {
    $76 = $73;
    $scevgep = (($74) + -72|0);
    $77 = (0 - ($76))|0;
    $uglygep = (($scevgep) + ($77)|0);
    $uglygep14 = $uglygep;
    $78 = (($uglygep14>>>0) / 72)&-1;
    $79 = $78 ^ -1;
    $81 = $74;
    while(1) {
     $80 = (($81) + -72|0);
     $82 = (($81) + -12|0);
     $83 = (($81) + -4|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ($84|0)==(0);
     if (!($85)) {
      $87 = (($81) + -8|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = HEAP32[$82>>2]|0;
      $90 = (($89) + 4|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = HEAP32[$88>>2]|0;
      $93 = (($92) + 4|0);
      HEAP32[$93>>2] = $91;
      $94 = HEAP32[$88>>2]|0;
      $95 = HEAP32[$90>>2]|0;
      HEAP32[$95>>2] = $94;
      HEAP32[$83>>2] = 0;
      $96 = ($88|0)==($82|0);
      if (!($96)) {
       $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i3 = $88;
       while(1) {
        $97 = (($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i3) + 4|0);
        $98 = HEAP32[$97>>2]|0;
        __ZdlPv($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i3);
        $99 = ($98|0)==($82|0);
        if ($99) {
         break;
        } else {
         $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i3 = $98;
        }
       }
      }
     }
     $86 = ($80|0)==($73|0);
     if ($86) {
      break;
     } else {
      $81 = $80;
     }
    }
    $scevgep15 = (($74) + (($79*72)|0)|0);
    HEAP32[$28>>2] = $scevgep15;
   }
   $100 = HEAP32[$__v>>2]|0;
   $101 = ($100|0)==(0|0);
   if ($101) {
    STACKTOP = sp;return;
   }
   __ZdlPv($100);
   STACKTOP = sp;return;
  }
 } while(0);
 $104 = HEAP32[$28>>2]|0;
 $105 = ($104|0)==($106|0);
 if (!($105)) {
  $107 = $106;
  $scevgep16 = (($104) + -72|0);
  $108 = (0 - ($107))|0;
  $uglygep18 = (($scevgep16) + ($108)|0);
  $uglygep1819 = $uglygep18;
  $109 = (($uglygep1819>>>0) / 72)&-1;
  $110 = $109 ^ -1;
  $112 = $104;
  while(1) {
   $111 = (($112) + -72|0);
   $113 = (($112) + -12|0);
   $114 = (($112) + -4|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ($115|0)==(0);
   if (!($116)) {
    $118 = (($112) + -8|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = HEAP32[$113>>2]|0;
    $121 = (($120) + 4|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = HEAP32[$119>>2]|0;
    $124 = (($123) + 4|0);
    HEAP32[$124>>2] = $122;
    $125 = HEAP32[$119>>2]|0;
    $126 = HEAP32[$121>>2]|0;
    HEAP32[$126>>2] = $125;
    HEAP32[$114>>2] = 0;
    $127 = ($119|0)==($113|0);
    if (!($127)) {
     $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = $119;
     while(1) {
      $128 = (($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i) + 4|0);
      $129 = HEAP32[$128>>2]|0;
      __ZdlPv($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i);
      $130 = ($129|0)==($113|0);
      if ($130) {
       break;
      } else {
       $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = $129;
      }
     }
    }
   }
   $117 = ($111|0)==($106|0);
   if ($117) {
    break;
   } else {
    $112 = $111;
   }
  }
  $scevgep20 = (($104) + (($110*72)|0)|0);
  HEAP32[$28>>2] = $scevgep20;
 }
 $131 = HEAP32[$__v>>2]|0;
 $132 = ($131|0)==(0|0);
 if ($132) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __ZdlPv($131);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__16vectorI9CollisionNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$07$i = 0, $$pre = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__f$01$i$i$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__v) + 4|0);
 $4 = ($2|0)==($0|0);
 $$pre19 = HEAP32[$3>>2]|0;
 if ($4) {
  $47 = $$pre19;$48 = $0;
  HEAP32[$this>>2] = $47;
  HEAP32[$3>>2] = $48;
  $49 = (($__v) + 8|0);
  $50 = HEAP32[$1>>2]|0;
  $51 = HEAP32[$49>>2]|0;
  HEAP32[$1>>2] = $51;
  HEAP32[$49>>2] = $50;
  $52 = (($this) + 8|0);
  $53 = (($__v) + 12|0);
  $54 = HEAP32[$52>>2]|0;
  $55 = HEAP32[$53>>2]|0;
  HEAP32[$52>>2] = $55;
  HEAP32[$53>>2] = $54;
  $56 = HEAP32[$3>>2]|0;
  HEAP32[$__v>>2] = $56;
  STACKTOP = sp;return;
 } else {
  $$07$i = $2;$6 = $$pre19;
 }
 L3: while(1) {
  $5 = (($6) + -72|0);
  $7 = (($$07$i) + -72|0);
  dest=$5+0|0; src=$7+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $8 = (($6) + -12|0);
  $9 = (($$07$i) + -12|0);
  HEAP32[$8>>2] = $8;
  $10 = (($6) + -8|0);
  HEAP32[$10>>2] = $8;
  $11 = (($6) + -4|0);
  HEAP32[$11>>2] = 0;
  $12 = (($$07$i) + -8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==($9|0);
  if (!($14)) {
   $19 = $13;$22 = $8;$26 = 0;
   while(1) {
    __THREW__ = 0;
    $15 = (invoke_ii(2988,40)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break L3;
    }
    $18 = (($19) + 8|0);
    $20 = (($15) + 8|0);
    ;HEAP32[$20+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$18+12>>2]|0;HEAP32[$20+16>>2]=HEAP32[$18+16>>2]|0;HEAP32[$20+20>>2]=HEAP32[$18+20>>2]|0;HEAP32[$20+24>>2]=HEAP32[$18+24>>2]|0;HEAP32[$20+28>>2]=HEAP32[$18+28>>2]|0;
    $21 = (($22) + 4|0);
    HEAP32[$21>>2] = $15;
    $23 = HEAP32[$8>>2]|0;
    HEAP32[$15>>2] = $23;
    HEAP32[$8>>2] = $15;
    $24 = (($15) + 4|0);
    HEAP32[$24>>2] = $8;
    $25 = (($26) + 1)|0;
    HEAP32[$11>>2] = $25;
    $27 = (($19) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==($9|0);
    if ($29) {
     break;
    } else {
     $19 = $28;$22 = $15;$26 = $25;
    }
   }
  }
  $44 = HEAP32[$3>>2]|0;
  $45 = (($44) + -72|0);
  HEAP32[$3>>2] = $45;
  $46 = ($7|0)==($0|0);
  if ($46) {
   label = 10;
   break;
  } else {
   $$07$i = $7;$6 = $45;
  }
 }
 if ((label|0) == 10) {
  $$pre = HEAP32[$this>>2]|0;
  $47 = $45;$48 = $$pre;
  HEAP32[$this>>2] = $47;
  HEAP32[$3>>2] = $48;
  $49 = (($__v) + 8|0);
  $50 = HEAP32[$1>>2]|0;
  $51 = HEAP32[$49>>2]|0;
  HEAP32[$1>>2] = $51;
  HEAP32[$49>>2] = $50;
  $52 = (($this) + 8|0);
  $53 = (($__v) + 12|0);
  $54 = HEAP32[$52>>2]|0;
  $55 = HEAP32[$53>>2]|0;
  HEAP32[$52>>2] = $55;
  HEAP32[$53>>2] = $54;
  $56 = HEAP32[$3>>2]|0;
  HEAP32[$__v>>2] = $56;
  STACKTOP = sp;return;
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 $32 = ($26|0)==(0);
 if ($32) {
  ___resumeException($30|0);
  // unreachable;
 }
 $33 = HEAP32[$10>>2]|0;
 $34 = (($22) + 4|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$33>>2]|0;
 $37 = (($36) + 4|0);
 HEAP32[$37>>2] = $35;
 $38 = HEAP32[$33>>2]|0;
 $39 = HEAP32[$34>>2]|0;
 HEAP32[$39>>2] = $38;
 HEAP32[$11>>2] = 0;
 $40 = ($33|0)==($8|0);
 if ($40) {
  ___resumeException($30|0);
  // unreachable;
 } else {
  $__f$01$i$i$i$i$i$i$i$i = $33;
 }
 while(1) {
  $41 = (($__f$01$i$i$i$i$i$i$i$i) + 4|0);
  $42 = HEAP32[$41>>2]|0;
  __ZdlPv($__f$01$i$i$i$i$i$i$i$i);
  $43 = ($42|0)==($8|0);
  if ($43) {
   break;
  } else {
   $__f$01$i$i$i$i$i$i$i$i = $42;
  }
 }
 ___resumeException($30|0);
 // unreachable;
}
function __ZNSt3__16vectorIN14PhysicsManager15RecordedTriggerENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($13>>>0)<(178956970);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 357913941;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*12)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*12)|0)|0);
 $23 = (($22) + (($$0$i3*12)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  ;HEAP32[$21+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__x+8>>2]|0;
 }
 $25 = (($22) + (($7*12)|0)|0);
 $26 = (($5|0) / -12)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*12)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManagerD2Ev($this) {
 $this = $this|0;
 var $$7 = 0, $$712 = 0, $$byval_copy18 = 0, $$pre$i$i$i = 0, $$pre$i$i$i146 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i144 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i113 = 0, $__new_last2$i$i$i$i$i124 = 0, $__new_last2$i$i$i$i$i133 = 0, $__new_last2$i$i$i$i$i150 = 0, $__new_last2$i$i$i$i$i21 = 0, $__new_last2$i$i$i$i$i28 = 0, $__new_last2$i$i$i$i$i35 = 0, $__new_last2$i$i$i$i$i42 = 0, $__new_last2$i$i$i$i$i49 = 0, $__new_last2$i$i$i$i$i57 = 0, $__new_last2$i$i$i$i$i64 = 0, $__new_last2$i$i$i$i$i72 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i81$indexZ2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i114 = 0, $scevgep$i$i$i$i$i125 = 0, $scevgep$i$i$i$i$i134 = 0, $scevgep$i$i$i$i$i151 = 0, $scevgep$i$i$i$i$i22 = 0, $scevgep$i$i$i$i$i29 = 0, $scevgep$i$i$i$i$i36 = 0, $scevgep$i$i$i$i$i43 = 0, $scevgep$i$i$i$i$i50 = 0, $scevgep$i$i$i$i$i58 = 0, $scevgep$i$i$i$i$i65 = 0, $scevgep$i$i$i$i$i73 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i118 = 0, $scevgep4$i$i$i$i$i129 = 0, $scevgep4$i$i$i$i$i138 = 0, $scevgep4$i$i$i$i$i155 = 0, $scevgep4$i$i$i$i$i26 = 0, $scevgep4$i$i$i$i$i33 = 0, $scevgep4$i$i$i$i$i40 = 0;
 var $scevgep4$i$i$i$i$i47 = 0, $scevgep4$i$i$i$i$i54 = 0, $scevgep4$i$i$i$i$i62 = 0, $scevgep4$i$i$i$i$i69 = 0, $scevgep4$i$i$i$i$i77 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i116 = 0, $uglygep$i$i$i$i$i127 = 0, $uglygep$i$i$i$i$i136 = 0, $uglygep$i$i$i$i$i153 = 0, $uglygep$i$i$i$i$i24 = 0, $uglygep$i$i$i$i$i31 = 0, $uglygep$i$i$i$i$i38 = 0, $uglygep$i$i$i$i$i45 = 0, $uglygep$i$i$i$i$i52 = 0, $uglygep$i$i$i$i$i60 = 0, $uglygep$i$i$i$i$i67 = 0, $uglygep$i$i$i$i$i75 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i117 = 0;
 var $uglygep3$i$i$i$i$i128 = 0, $uglygep3$i$i$i$i$i137 = 0, $uglygep3$i$i$i$i$i154 = 0, $uglygep3$i$i$i$i$i25 = 0, $uglygep3$i$i$i$i$i32 = 0, $uglygep3$i$i$i$i$i39 = 0, $uglygep3$i$i$i$i$i46 = 0, $uglygep3$i$i$i$i$i53 = 0, $uglygep3$i$i$i$i$i61 = 0, $uglygep3$i$i$i$i$i68 = 0, $uglygep3$i$i$i$i$i76 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy18 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((690176 + 8|0));
 $2 = (($this) + 24|0);
 HEAP32[$2>>2] = ((690176 + 136|0));
 $3 = (($this) + 808|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($this) + 812|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==($4|0);
  if (!($8)) {
   $__new_last2$i$i$i$i$i = $4;
   $scevgep$i$i$i$i$i = (($7) + -44|0);
   $9 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($9)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $10 = (($uglygep3$i$i$i$i$i>>>0) / 44)&-1;
   $11 = $10 ^ -1;
   $scevgep4$i$i$i$i$i = (($7) + (($11*44)|0)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($4);
 }
 $12 = (($this) + 796|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($this) + 800|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($13|0);
  if (!($17)) {
   $__new_last2$i$i$i$i$i21 = $13;
   $scevgep$i$i$i$i$i22 = (($16) + -4|0);
   $18 = (0 - ($__new_last2$i$i$i$i$i21))|0;
   $uglygep$i$i$i$i$i24 = (($scevgep$i$i$i$i$i22) + ($18)|0);
   $uglygep3$i$i$i$i$i25 = $uglygep$i$i$i$i$i24;
   $19 = $uglygep3$i$i$i$i$i25 >>> 2;
   $20 = $19 ^ -1;
   $scevgep4$i$i$i$i$i26 = (($16) + ($20<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i$i$i$i26;
  }
  __ZdlPv($13);
 }
 $21 = (($this) + 784|0);
 $22 = (($this) + 788|0);
 $23 = HEAP32[$22>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_4pairIPN5physx7PxShapeES5_EEN14PhysicsManager16TriggerStayStateEEENS_19__map_value_compareIS6_S9_NS_4lessIS6_EELb1EEENS_9allocatorIS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($21,$23);
 $24 = (($this) + 772|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (($this) + 776|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($25|0);
  if (!($29)) {
   $__new_last2$i$i$i$i$i28 = $25;
   $scevgep$i$i$i$i$i29 = (($28) + -16|0);
   $30 = (0 - ($__new_last2$i$i$i$i$i28))|0;
   $uglygep$i$i$i$i$i31 = (($scevgep$i$i$i$i$i29) + ($30)|0);
   $uglygep3$i$i$i$i$i32 = $uglygep$i$i$i$i$i31;
   $31 = $uglygep3$i$i$i$i$i32 >>> 4;
   $32 = $31 ^ -1;
   $scevgep4$i$i$i$i$i33 = (($28) + ($32<<4)|0);
   HEAP32[$27>>2] = $scevgep4$i$i$i$i$i33;
  }
  __ZdlPv($25);
 }
 $33 = (($this) + 760|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = (($this) + 764|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==($34|0);
  if (!($38)) {
   $__new_last2$i$i$i$i$i35 = $34;
   $scevgep$i$i$i$i$i36 = (($37) + -64|0);
   $39 = (0 - ($__new_last2$i$i$i$i$i35))|0;
   $uglygep$i$i$i$i$i38 = (($scevgep$i$i$i$i$i36) + ($39)|0);
   $uglygep3$i$i$i$i$i39 = $uglygep$i$i$i$i$i38;
   $40 = $uglygep3$i$i$i$i$i39 >>> 6;
   $41 = $40 ^ -1;
   $scevgep4$i$i$i$i$i40 = (($37) + ($41<<6)|0);
   HEAP32[$36>>2] = $scevgep4$i$i$i$i$i40;
  }
  __ZdlPv($34);
 }
 $42 = (($this) + 748|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = (($this) + 752|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==($43|0);
  if (!($47)) {
   $__new_last2$i$i$i$i$i42 = $43;
   $scevgep$i$i$i$i$i43 = (($46) + -48|0);
   $48 = (0 - ($__new_last2$i$i$i$i$i42))|0;
   $uglygep$i$i$i$i$i45 = (($scevgep$i$i$i$i$i43) + ($48)|0);
   $uglygep3$i$i$i$i$i46 = $uglygep$i$i$i$i$i45;
   $49 = (($uglygep3$i$i$i$i$i46>>>0) / 48)&-1;
   $50 = $49 ^ -1;
   $scevgep4$i$i$i$i$i47 = (($46) + (($50*48)|0)|0);
   HEAP32[$45>>2] = $scevgep4$i$i$i$i$i47;
  }
  __ZdlPv($43);
 }
 $51 = (($this) + 688|0);
 __THREW__ = 0;
 invoke_vi(3636,($51|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 L31: do {
  if ($53) {
   $161 = ___cxa_find_matching_catch()|0;
   $162 = tempRet0;
   $163 = (($this) + 676|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = ($164|0)==(0|0);
   if (!($165)) {
    $166 = (($this) + 680|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = ($167|0)==($164|0);
    if (!($168)) {
     $__new_last2$i$i$i$i$i113 = $164;
     $scevgep$i$i$i$i$i114 = (($167) + -4|0);
     $169 = (0 - ($__new_last2$i$i$i$i$i113))|0;
     $uglygep$i$i$i$i$i116 = (($scevgep$i$i$i$i$i114) + ($169)|0);
     $uglygep3$i$i$i$i$i117 = $uglygep$i$i$i$i$i116;
     $170 = $uglygep3$i$i$i$i$i117 >>> 2;
     $171 = $170 ^ -1;
     $scevgep4$i$i$i$i$i118 = (($167) + ($171<<2)|0);
     HEAP32[$166>>2] = $scevgep4$i$i$i$i$i118;
    }
    __ZdlPv($164);
   }
   $174 = (($this) + 672|0);
   $175 = HEAP32[$174>>2]|0;
   $176 = ($175|0)>(-1);
   if ($176) {
    $177 = (($this) + 660|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = (($this) + 664|0);
    $180 = HEAP32[$179>>2]|0;
    HEAP32[$0>>2] = $180;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($178|0),($$byval_copy18|0));
    $181 = __THREW__; __THREW__ = 0;
    $182 = $181&1;
    if (!($182)) {
     HEAP32[$177>>2] = 0;
     $$7 = $162;$$712 = $161;
     label = 72;
    }
   } else {
    $$7 = $162;$$712 = $161;
    label = 72;
   }
  } else {
   $54 = (($this) + 676|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0|0);
   if (!($56)) {
    $57 = (($this) + 680|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = ($58|0)==($55|0);
    if (!($59)) {
     $__new_last2$i$i$i$i$i49 = $55;
     $scevgep$i$i$i$i$i50 = (($58) + -4|0);
     $60 = (0 - ($__new_last2$i$i$i$i$i49))|0;
     $uglygep$i$i$i$i$i52 = (($scevgep$i$i$i$i$i50) + ($60)|0);
     $uglygep3$i$i$i$i$i53 = $uglygep$i$i$i$i$i52;
     $61 = $uglygep3$i$i$i$i$i53 >>> 2;
     $62 = $61 ^ -1;
     $scevgep4$i$i$i$i$i54 = (($58) + ($62<<2)|0);
     HEAP32[$57>>2] = $scevgep4$i$i$i$i$i54;
    }
    __ZdlPv($55);
   }
   $63 = (($this) + 672|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)>(-1);
   do {
    if ($65) {
     $66 = (($this) + 660|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($this) + 664|0);
     $69 = HEAP32[$68>>2]|0;
     HEAP32[$1>>2] = $69;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($67|0),($$byval_copy18|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      $172 = ___cxa_find_matching_catch()|0;
      $173 = tempRet0;
      $$7 = $173;$$712 = $172;
      label = 72;
      break L31;
     } else {
      HEAP32[$66>>2] = 0;
      break;
     }
    }
   } while(0);
   $72 = (($this) + 648|0);
   HEAP32[$72>>2] = 0;
   $73 = (($this) + 644|0);
   HEAP32[$73>>2] = 0;
   $74 = (($this) + 132|0);
   $75 = (($this) + 644|0);
   $77 = $75;
   while(1) {
    $76 = (($77) + -8|0);
    $78 = (($77) + -4|0);
    HEAP32[$78>>2] = 0;
    HEAP32[$76>>2] = 0;
    $79 = ($76|0)==($74|0);
    if ($79) {
     break;
    } else {
     $77 = $76;
    }
   }
   $80 = (($this) + 124|0);
   HEAP32[$80>>2] = 0;
   $81 = (($this) + 120|0);
   HEAP32[$81>>2] = 0;
   $82 = (($this) + 108|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==(0|0);
   if (!($84)) {
    $85 = (($this) + 112|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==($83|0);
    if (!($87)) {
     $__new_last2$i$i$i$i$i57 = $83;
     $scevgep$i$i$i$i$i58 = (($86) + -4|0);
     $88 = (0 - ($__new_last2$i$i$i$i$i57))|0;
     $uglygep$i$i$i$i$i60 = (($scevgep$i$i$i$i$i58) + ($88)|0);
     $uglygep3$i$i$i$i$i61 = $uglygep$i$i$i$i$i60;
     $89 = $uglygep3$i$i$i$i$i61 >>> 2;
     $90 = $89 ^ -1;
     $scevgep4$i$i$i$i$i62 = (($86) + ($90<<2)|0);
     HEAP32[$85>>2] = $scevgep4$i$i$i$i$i62;
    }
    __ZdlPv($83);
   }
   $91 = (($this) + 92|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ($92|0)==(0|0);
   if (!($93)) {
    $94 = (($this) + 96|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==($92|0);
    if (!($96)) {
     $__new_last2$i$i$i$i$i64 = $92;
     $scevgep$i$i$i$i$i65 = (($95) + -12|0);
     $97 = (0 - ($__new_last2$i$i$i$i$i64))|0;
     $uglygep$i$i$i$i$i67 = (($scevgep$i$i$i$i$i65) + ($97)|0);
     $uglygep3$i$i$i$i$i68 = $uglygep$i$i$i$i$i67;
     $98 = (($uglygep3$i$i$i$i$i68>>>0) / 12)&-1;
     $99 = $98 ^ -1;
     $scevgep4$i$i$i$i$i69 = (($95) + (($99*12)|0)|0);
     HEAP32[$94>>2] = $scevgep4$i$i$i$i$i69;
    }
    __ZdlPv($92);
   }
   $100 = (($this) + 80|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($101|0)==(0|0);
   if (!($102)) {
    $103 = (($this) + 84|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($104|0)==($101|0);
    if ($105) {
     $127 = $101;
    } else {
     $107 = $104;
     while(1) {
      $106 = (($107) + -72|0);
      HEAP32[$103>>2] = $106;
      $108 = (($107) + -12|0);
      $109 = (($107) + -4|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($110|0)==(0);
      if (!($111)) {
       $114 = (($107) + -8|0);
       $115 = HEAP32[$114>>2]|0;
       $116 = HEAP32[$108>>2]|0;
       $117 = (($116) + 4|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = HEAP32[$115>>2]|0;
       $120 = (($119) + 4|0);
       HEAP32[$120>>2] = $118;
       $121 = HEAP32[$115>>2]|0;
       $122 = HEAP32[$117>>2]|0;
       HEAP32[$122>>2] = $121;
       HEAP32[$109>>2] = 0;
       $123 = ($115|0)==($108|0);
       if (!($123)) {
        $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = $115;
        while(1) {
         $124 = (($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i) + 4|0);
         $125 = HEAP32[$124>>2]|0;
         __ZdlPv($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i);
         $126 = ($125|0)==($108|0);
         if ($126) {
          break;
         } else {
          $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i = $125;
         }
        }
       }
      }
      $112 = HEAP32[$103>>2]|0;
      $113 = ($112|0)==($101|0);
      if ($113) {
       break;
      } else {
       $107 = $112;
      }
     }
     $$pre$i$i$i = HEAP32[$100>>2]|0;
     $127 = $$pre$i$i$i;
    }
    __ZdlPv($127);
   }
   $128 = (($this) + 68|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0|0);
   if (!($130)) {
    $131 = (($this) + 72|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = ($132|0)==($129|0);
    if (!($133)) {
     $__new_last2$i$i$i$i$i72 = $129;
     $scevgep$i$i$i$i$i73 = (($132) + -12|0);
     $134 = (0 - ($__new_last2$i$i$i$i$i72))|0;
     $uglygep$i$i$i$i$i75 = (($scevgep$i$i$i$i$i73) + ($134)|0);
     $uglygep3$i$i$i$i$i76 = $uglygep$i$i$i$i$i75;
     $135 = (($uglygep3$i$i$i$i$i76>>>0) / 12)&-1;
     $136 = $135 ^ -1;
     $scevgep4$i$i$i$i$i77 = (($132) + (($136*12)|0)|0);
     HEAP32[$131>>2] = $scevgep4$i$i$i$i$i77;
    }
    __ZdlPv($129);
   }
   HEAP32[$this>>2] = ((561192 + 8|0));
   __THREW__ = 0;
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if (!($138)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if (!($140)) {
     STACKTOP = sp;return;
    }
    $141 = ___cxa_find_matching_catch()|0;
    $142 = tempRet0;
    __THREW__ = 0;
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if ($144) {
     $145 = ___cxa_find_matching_catch(0|0)|0;
     $146 = tempRet0;
     ___clang_call_terminate($145);
     // unreachable;
    } else {
     ___resumeException($141|0);
     // unreachable;
    }
   }
   $147 = ___cxa_find_matching_catch()|0;
   $148 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $149 = __THREW__; __THREW__ = 0;
   $150 = $149&1;
   if ($150) {
    $153 = ___cxa_find_matching_catch(0|0)|0;
    $154 = tempRet0;
    __THREW__ = 0;
    $155 = __THREW__; __THREW__ = 0;
    $156 = $155&1;
    if ($156) {
     $157 = ___cxa_find_matching_catch(0|0)|0;
     $158 = tempRet0;
     ___clang_call_terminate($157);
     // unreachable;
    } else {
     $eh$lpad$body$i81$indexZ2D = $153;
     ___clang_call_terminate($eh$lpad$body$i81$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $151 = __THREW__; __THREW__ = 0;
   $152 = $151&1;
   if (!($152)) {
    ___resumeException($147|0);
    // unreachable;
   }
   $159 = ___cxa_find_matching_catch(0|0)|0;
   $160 = tempRet0;
   $eh$lpad$body$i81$indexZ2D = $159;
   ___clang_call_terminate($eh$lpad$body$i81$indexZ2D);
   // unreachable;
  }
 } while(0);
 do {
  if ((label|0) == 72) {
   $183 = (($this) + 648|0);
   HEAP32[$183>>2] = 0;
   $184 = (($this) + 644|0);
   HEAP32[$184>>2] = 0;
   $185 = (($this) + 132|0);
   $186 = (($this) + 644|0);
   $188 = $186;
   while(1) {
    $187 = (($188) + -8|0);
    $189 = (($188) + -4|0);
    HEAP32[$189>>2] = 0;
    HEAP32[$187>>2] = 0;
    $190 = ($187|0)==($185|0);
    if ($190) {
     break;
    } else {
     $188 = $187;
    }
   }
   $191 = (($this) + 124|0);
   HEAP32[$191>>2] = 0;
   $192 = (($this) + 120|0);
   HEAP32[$192>>2] = 0;
   $193 = (($this) + 108|0);
   $194 = HEAP32[$193>>2]|0;
   $195 = ($194|0)==(0|0);
   if (!($195)) {
    $196 = (($this) + 112|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = ($197|0)==($194|0);
    if (!($198)) {
     $__new_last2$i$i$i$i$i124 = $194;
     $scevgep$i$i$i$i$i125 = (($197) + -4|0);
     $199 = (0 - ($__new_last2$i$i$i$i$i124))|0;
     $uglygep$i$i$i$i$i127 = (($scevgep$i$i$i$i$i125) + ($199)|0);
     $uglygep3$i$i$i$i$i128 = $uglygep$i$i$i$i$i127;
     $200 = $uglygep3$i$i$i$i$i128 >>> 2;
     $201 = $200 ^ -1;
     $scevgep4$i$i$i$i$i129 = (($197) + ($201<<2)|0);
     HEAP32[$196>>2] = $scevgep4$i$i$i$i$i129;
    }
    __ZdlPv($194);
   }
   $202 = (($this) + 92|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = ($203|0)==(0|0);
   if (!($204)) {
    $205 = (($this) + 96|0);
    $206 = HEAP32[$205>>2]|0;
    $207 = ($206|0)==($203|0);
    if (!($207)) {
     $__new_last2$i$i$i$i$i133 = $203;
     $scevgep$i$i$i$i$i134 = (($206) + -12|0);
     $208 = (0 - ($__new_last2$i$i$i$i$i133))|0;
     $uglygep$i$i$i$i$i136 = (($scevgep$i$i$i$i$i134) + ($208)|0);
     $uglygep3$i$i$i$i$i137 = $uglygep$i$i$i$i$i136;
     $209 = (($uglygep3$i$i$i$i$i137>>>0) / 12)&-1;
     $210 = $209 ^ -1;
     $scevgep4$i$i$i$i$i138 = (($206) + (($210*12)|0)|0);
     HEAP32[$205>>2] = $scevgep4$i$i$i$i$i138;
    }
    __ZdlPv($203);
   }
   $211 = (($this) + 80|0);
   $212 = HEAP32[$211>>2]|0;
   $213 = ($212|0)==(0|0);
   if (!($213)) {
    $214 = (($this) + 84|0);
    $215 = HEAP32[$214>>2]|0;
    $216 = ($215|0)==($212|0);
    if ($216) {
     $238 = $212;
    } else {
     $218 = $215;
     while(1) {
      $217 = (($218) + -72|0);
      HEAP32[$214>>2] = $217;
      $219 = (($218) + -12|0);
      $220 = (($218) + -4|0);
      $221 = HEAP32[$220>>2]|0;
      $222 = ($221|0)==(0);
      if (!($222)) {
       $225 = (($218) + -8|0);
       $226 = HEAP32[$225>>2]|0;
       $227 = HEAP32[$219>>2]|0;
       $228 = (($227) + 4|0);
       $229 = HEAP32[$228>>2]|0;
       $230 = HEAP32[$226>>2]|0;
       $231 = (($230) + 4|0);
       HEAP32[$231>>2] = $229;
       $232 = HEAP32[$226>>2]|0;
       $233 = HEAP32[$228>>2]|0;
       HEAP32[$233>>2] = $232;
       HEAP32[$220>>2] = 0;
       $234 = ($226|0)==($219|0);
       if (!($234)) {
        $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i144 = $226;
        while(1) {
         $235 = (($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i144) + 4|0);
         $236 = HEAP32[$235>>2]|0;
         __ZdlPv($__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i144);
         $237 = ($236|0)==($219|0);
         if ($237) {
          break;
         } else {
          $__f$01$i$i$i$i$i$i$i$i$i$i$i$i$i144 = $236;
         }
        }
       }
      }
      $223 = HEAP32[$214>>2]|0;
      $224 = ($223|0)==($212|0);
      if ($224) {
       break;
      } else {
       $218 = $223;
      }
     }
     $$pre$i$i$i146 = HEAP32[$211>>2]|0;
     $238 = $$pre$i$i$i146;
    }
    __ZdlPv($238);
   }
   $239 = (($this) + 68|0);
   $240 = HEAP32[$239>>2]|0;
   $241 = ($240|0)==(0|0);
   if (!($241)) {
    $242 = (($this) + 72|0);
    $243 = HEAP32[$242>>2]|0;
    $244 = ($243|0)==($240|0);
    if (!($244)) {
     $__new_last2$i$i$i$i$i150 = $240;
     $scevgep$i$i$i$i$i151 = (($243) + -12|0);
     $245 = (0 - ($__new_last2$i$i$i$i$i150))|0;
     $uglygep$i$i$i$i$i153 = (($scevgep$i$i$i$i$i151) + ($245)|0);
     $uglygep3$i$i$i$i$i154 = $uglygep$i$i$i$i$i153;
     $246 = (($uglygep3$i$i$i$i$i154>>>0) / 12)&-1;
     $247 = $246 ^ -1;
     $scevgep4$i$i$i$i$i155 = (($243) + (($247*12)|0)|0);
     HEAP32[$242>>2] = $scevgep4$i$i$i$i$i155;
    }
    __ZdlPv($240);
   }
   HEAP32[$this>>2] = ((561192 + 8|0));
   __THREW__ = 0;
   $248 = __THREW__; __THREW__ = 0;
   $249 = $248&1;
   if (!($249)) {
    HEAP32[$this>>2] = ((561376 + 8|0));
    __THREW__ = 0;
    $250 = __THREW__; __THREW__ = 0;
    $251 = $250&1;
    if (!($251)) {
     __THREW__ = 0;
     $258 = __THREW__; __THREW__ = 0;
     $259 = $258&1;
     if ($259) {
      break;
     }
     ___resumeException($$712|0);
     // unreachable;
    }
    $252 = ___cxa_find_matching_catch(0|0)|0;
    $253 = tempRet0;
    __THREW__ = 0;
    $254 = __THREW__; __THREW__ = 0;
    $255 = $254&1;
    if ($255) {
     $256 = ___cxa_find_matching_catch(0|0)|0;
     $257 = tempRet0;
     ___clang_call_terminate($256);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $252;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   $260 = ___cxa_find_matching_catch(0|0)|0;
   $261 = tempRet0;
   HEAP32[$this>>2] = ((561376 + 8|0));
   __THREW__ = 0;
   $262 = __THREW__; __THREW__ = 0;
   $263 = $262&1;
   if ($263) {
    $266 = ___cxa_find_matching_catch(0|0)|0;
    $267 = tempRet0;
    __THREW__ = 0;
    $268 = __THREW__; __THREW__ = 0;
    $269 = $268&1;
    if ($269) {
     $270 = ___cxa_find_matching_catch(0|0)|0;
     $271 = tempRet0;
     ___clang_call_terminate($270);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $266;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $264 = __THREW__; __THREW__ = 0;
   $265 = $264&1;
   if (!($265)) {
    $eh$lpad$body$indexZ2D = $260;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $272 = ___cxa_find_matching_catch(0|0)|0;
   $273 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $272;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 $274 = ___cxa_find_matching_catch(0|0)|0;
 $275 = tempRet0;
 $eh$lpad$body$indexZ2D = $274;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN10CastFilter9preFilterERKN5physx12PxFilterDataEPKNS0_7PxShapeEPKNS0_12PxRigidActorERNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEE($this,$filterData,$shape,$actor,$filterFlags) {
 $this = $this|0;
 $filterData = $filterData|0;
 $shape = $shape|0;
 $actor = $actor|0;
 $filterFlags = $filterFlags|0;
 var $$0 = 0, $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $or$cond$i = 0, $otherData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $otherData = sp;
 $1 = sp + 16|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($actor|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__Z21GetManagerFromContexti(9)|0);
 $6 = (($5) + 56|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $9 = HEAP32[$shape>>2]|0;
  $10 = (($9) + 136|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($0,$shape);
  $12 = HEAP8[$0>>0]|0;
  $13 = $12 & 4;
  $14 = ($13<<24>>24)==(0);
  if (!($14)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $15 = HEAP32[$shape>>2]|0;
 $16 = (($15) + 92|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($otherData,$shape);
 $18 = (($filterData) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($filterData) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__ZN8Collider14WordsToPointerEjj($19,$21)|0);
 $23 = (($otherData) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($otherData) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (__ZN8Collider14WordsToPointerEjj($24,$26)|0);
 $28 = ($22|0)==(0|0);
 $29 = ($27|0)==(0|0);
 $or$cond$i = $28 | $29;
 if ($or$cond$i) {
  $$0$i1 = 0;
 } else {
  $30 = (__ZNK8Collider21ShouldIgnoreCollisionEPS_($22,$27)|0);
  $$0$i1 = $30;
 }
 $31 = (($this) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$shape>>2]|0;
 $34 = (($33) + 92|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$35 & 4095]($1,$shape);
 $36 = HEAP32[$1>>2]|0;
 $37 = $36 & 255;
 $38 = 1 << $37;
 $39 = $38 & $32;
 $40 = ($39|0)==(0);
 $brmerge = $40 | $$0$i1;
 if ($brmerge) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = (($this) + 16|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)!=(0);
 $44 = $43 ? 2 : 1;
 $$0 = $44;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10CastFilter10postFilterERKN5physx12PxFilterDataERKNS0_10PxQueryHitE($this,$filterData,$hit) {
 $this = $this|0;
 $filterData = $filterData|0;
 $hit = $hit|0;
 var $$0 = 0, $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hit) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 > Math_fround(0.0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10CastFilterD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN14PhysicsManager11SweepShapesD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i11 = 0, $__new_last2$i$i$i$i$i18 = 0, $__new_last2$i$i$i$i$i4 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i12 = 0, $scevgep$i$i$i$i$i19 = 0, $scevgep$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i16 = 0, $scevgep4$i$i$i$i$i23 = 0, $scevgep4$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i14 = 0, $uglygep$i$i$i$i$i21 = 0, $uglygep$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i15 = 0, $uglygep3$i$i$i$i$i22 = 0;
 var $uglygep3$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 52|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($1|0);
  if (!($5)) {
   HEAP32[$3>>2] = $1;
  }
  __ZdlPv($1);
 }
 $6 = (($this) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 40|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($7|0);
  if (!($11)) {
   $__new_last2$i$i$i$i$i = $7;
   $scevgep$i$i$i$i$i = (($10) + -16|0);
   $12 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($12)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $13 = $uglygep3$i$i$i$i$i >>> 4;
   $14 = $13 ^ -1;
   $scevgep4$i$i$i$i$i = (($10) + ($14<<4)|0);
   HEAP32[$9>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($7);
 }
 $15 = (($this) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  $18 = (($this) + 28|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($16|0);
  if (!($20)) {
   $__new_last2$i$i$i$i$i4 = $16;
   $scevgep$i$i$i$i$i5 = (($19) + -28|0);
   $21 = (0 - ($__new_last2$i$i$i$i$i4))|0;
   $uglygep$i$i$i$i$i7 = (($scevgep$i$i$i$i$i5) + ($21)|0);
   $uglygep3$i$i$i$i$i8 = $uglygep$i$i$i$i$i7;
   $22 = (($uglygep3$i$i$i$i$i8>>>0) / 28)&-1;
   $23 = $22 ^ -1;
   $scevgep4$i$i$i$i$i9 = (($19) + (($23*28)|0)|0);
   HEAP32[$18>>2] = $scevgep4$i$i$i$i$i9;
  }
  __ZdlPv($16);
 }
 $24 = (($this) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (($this) + 16|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($25|0);
  if (!($29)) {
   $__new_last2$i$i$i$i$i11 = $25;
   $scevgep$i$i$i$i$i12 = (($28) + -4|0);
   $30 = (0 - ($__new_last2$i$i$i$i$i11))|0;
   $uglygep$i$i$i$i$i14 = (($scevgep$i$i$i$i$i12) + ($30)|0);
   $uglygep3$i$i$i$i$i15 = $uglygep$i$i$i$i$i14;
   $31 = $uglygep3$i$i$i$i$i15 >>> 2;
   $32 = $31 ^ -1;
   $scevgep4$i$i$i$i$i16 = (($28) + ($32<<2)|0);
   HEAP32[$27>>2] = $scevgep4$i$i$i$i$i16;
  }
  __ZdlPv($25);
 }
 $33 = HEAP32[$this>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  STACKTOP = sp;return;
 }
 $35 = (($this) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==($33|0);
 if (!($37)) {
  $__new_last2$i$i$i$i$i18 = $33;
  $scevgep$i$i$i$i$i19 = (($36) + -4|0);
  $38 = (0 - ($__new_last2$i$i$i$i$i18))|0;
  $uglygep$i$i$i$i$i21 = (($scevgep$i$i$i$i$i19) + ($38)|0);
  $uglygep3$i$i$i$i$i22 = $uglygep$i$i$i$i$i21;
  $39 = $uglygep3$i$i$i$i$i22 >>> 2;
  $40 = $39 ^ -1;
  $scevgep4$i$i$i$i$i23 = (($36) + ($40<<2)|0);
  HEAP32[$35>>2] = $scevgep4$i$i$i$i$i23;
 }
 __ZdlPv($33);
 STACKTOP = sp;return;
}
function __ZL28VehicleWheelRaycastPreFilterN5physx12PxFilterDataES0_PKvjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEE($filterData0,$filterData1,$constantBlock,$constantBlockSize,$queryFlags) {
 $filterData0 = $filterData0|0;
 $filterData1 = $filterData1|0;
 $constantBlock = $constantBlock|0;
 $constantBlockSize = $constantBlockSize|0;
 $queryFlags = $queryFlags|0;
 var $$ = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0;
 var $brmerge1 = 0, $or$cond = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($filterData0) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -65536;
 $3 = (($filterData1) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & -65536;
 $6 = ($2|0)!=($5|0);
 $7 = ($2|0)==(0);
 $or$cond = $6 | $7;
 if (!($or$cond)) {
  STACKTOP = sp;return 0;
 }
 $8 = (($filterData1) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($filterData1) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (__ZN8Collider14WordsToPointerEjj($9,$11)|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 124|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
 if ($16) {
  STACKTOP = sp;return 0;
 }
 $17 = (__Z21GetManagerFromContexti(9)|0);
 $18 = HEAP32[$filterData0>>2]|0;
 $19 = $18 & 255;
 $20 = HEAP32[$filterData1>>2]|0;
 $21 = $20 & 255;
 $22 = (__ZN14PhysicsManager18GetIgnoreCollisionEii($17,$19,$21)|0);
 $23 = (($filterData0) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($filterData0) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (__ZN8Collider14WordsToPointerEjj($24,$26)|0);
 $28 = (__ZN8Collider14WordsToPointerEjj($9,$11)|0);
 $29 = ($27|0)==(0|0);
 $30 = ($28|0)==(0|0);
 $or$cond$i = $29 | $30;
 if ($or$cond$i) {
  $$0$i = 0;
 } else {
  $31 = (__ZNK8Collider21ShouldIgnoreCollisionEPS_($27,$28)|0);
  $$0$i = $31;
 }
 $32 = $1 & 16;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $36 = 1;
  $brmerge = $22 | $$0$i;
  $brmerge1 = $brmerge | $36;
  $$ = $brmerge1 ? 0 : 2;
  STACKTOP = sp;return ($$|0);
 }
 $34 = $4 & 16;
 $35 = ($34|0)!=(0);
 $36 = $35;
 $brmerge = $22 | $$0$i;
 $brmerge1 = $brmerge | $36;
 $$ = $brmerge1 ? 0 : 2;
 STACKTOP = sp;return ($$|0);
}
function __ZN18PhysxJobDispatcher10submitTaskERN5physx10PxBaseTaskE($this,$task) {
 $this = $this|0;
 $task = $task|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$task>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($task);
 $3 = HEAP32[$task>>2]|0;
 $4 = (($3) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($task);
 STACKTOP = sp;return;
}
function __ZNK18PhysxJobDispatcher14getWorkerCountEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN18PhysxJobDispatcherD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16NovodexAllocatorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16NovodexAllocator8allocateEjPKcS1_i($this,$size,$typeName,$filename,$line) {
 $this = $this|0;
 $size = $size|0;
 $typeName = $typeName|0;
 $filename = $filename|0;
 $line = $line|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Z15malloc_internaljj10MemLabelIdiPKci($size,16,$$byval_copy,0,690112,310)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN16NovodexAllocator10deallocateEPv($this,$ptr) {
 $this = $this|0;
 $ptr = $ptr|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($ptr,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN11ErrorStreamD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN11ErrorStream11reportErrorEN5physx11PxErrorCode4EnumEPKcS4_i($this,$code,$message,$file,$line) {
 $this = $this|0;
 $code = $code|0;
 $message = $message|0;
 $file = $file|0;
 $line = $line|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 if ((($code|0) == 1)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE($message,0,690112,327,4,0,0,0);
 } else if ((($code|0) == 2) | (($code|0) == 128)) {
  STACKTOP = sp;return;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE($message,0,$file,$line,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody17MainThreadCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Rigidbody15CleanupInternalEb($this,0);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody15CleanupInternalEb($this,$recreateColliders) {
 $this = $this|0;
 $recreateColliders = $recreateColliders|0;
 var $$1 = 0, $$12 = 0, $$byval_copy16 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0, $allocPtr2$0 = 0, $i$024 = 0, $i3$019 = 0, $i4$014 = 0, $i5$09 = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $wheelColliders = 0;
 var $wheelCount$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy16 = sp + 104|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $wheelColliders = sp + 24|0;
 $5 = (($this) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 L1: do {
  if (!($7)) {
   $8 = HEAP32[$6>>2]|0;
   $9 = (($8) + 104|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($6)|0);
   $12 = $11 << 2;
   $13 = (($12) + 15)|0;
   $14 = ($13>>>0)<(2000);
   $15 = ($11|0)!=(0);
   if ($14) {
    if ($15) {
     $16 = STACKTOP; STACKTOP = STACKTOP + ((((1*$13)|0)+15)&-16)|0;;
     $129 = 0;$allocPtr$0 = $16;
     label = 8;
    } else {
     $129 = 0;$allocPtr$0 = 0;
     label = 8;
    }
   } else {
    if ($15) {
     $17 = HEAP32[628512>>2]|0;
     HEAP32[$3>>2] = $17;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$3+0>>2]|0;
     $18 = (invoke_iiiiiii(102,($13|0),16,($$byval_copy16|0),0,(691024|0),225)|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      $161 = 0;
      label = 7;
     } else {
      $129 = $18;$allocPtr$0 = $18;
      label = 8;
     }
    } else {
     $129 = 0;$allocPtr$0 = 0;
     label = 8;
    }
   }
   L8: do {
    if ((label|0) == 8) {
     $23 = $allocPtr$0;
     $24 = (($23) + 15)|0;
     $25 = $24 & -16;
     $26 = $25;
     $27 = HEAP32[$5>>2]|0;
     $28 = HEAP32[$27>>2]|0;
     $29 = (($28) + 108|0);
     $30 = HEAP32[$29>>2]|0;
     __THREW__ = 0;
     (invoke_iiiii($30|0,($27|0),($26|0),($11|0),0)|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $161 = $129;
      label = 7;
     } else {
      if ($14) {
       if ($15) {
        $33 = STACKTOP; STACKTOP = STACKTOP + ((((1*$13)|0)+15)&-16)|0;;
        $163 = 0;$allocPtr2$0 = $33;
        label = 15;
       } else {
        $124 = 0;$162 = 0;$95 = 0;
        label = 18;
       }
      } else {
       if ($15) {
        $34 = HEAP32[628512>>2]|0;
        HEAP32[$4>>2] = $34;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$4+0>>2]|0;
        $35 = (invoke_iiiiiii(102,($13|0),16,($$byval_copy16|0),0,(691024|0),229)|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         $38 = ___cxa_find_matching_catch()|0;
         $39 = tempRet0;
         $164 = $1;$165 = $39;$166 = $38;
        } else {
         $163 = $35;$allocPtr2$0 = $35;
         label = 15;
        }
       } else {
        $124 = 0;$162 = 0;$95 = 0;
        label = 18;
       }
      }
      L17: do {
       if ((label|0) == 15) {
        $40 = $allocPtr2$0;
        $41 = (($40) + 15)|0;
        $42 = $41 & -16;
        $43 = $42;
        $44 = ($11|0)>(0);
        if ($44) {
         $i$024 = 0;
         while(1) {
          $45 = (($26) + ($i$024<<2)|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = (($46) + 8|0);
          $48 = HEAP32[$47>>2]|0;
          $49 = (($43) + ($i$024<<2)|0);
          HEAP32[$49>>2] = $48;
          $50 = HEAP32[$48>>2]|0;
          $51 = (($50) + 144|0);
          $52 = HEAP32[$51>>2]|0;
          __THREW__ = 0;
          invoke_vi($52|0,($48|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break;
          }
          $55 = (($i$024) + 1)|0;
          $56 = ($55|0)<($11|0);
          if ($56) {
           $i$024 = $55;
          } else {
           $124 = $163;$162 = $44;$95 = $43;
           label = 18;
           break L17;
          }
         }
         $137 = ___cxa_find_matching_catch()|0;
         $138 = tempRet0;
         $142 = $163;$lpad$phi$index = $137;$lpad$phi$index5 = $138;
         label = 48;
        } else {
         $124 = $163;$162 = 0;$95 = $43;
         label = 18;
        }
       }
      } while(0);
      L23: do {
       if ((label|0) == 18) {
        $57 = (($this) + 44|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = ($58|0)==(0|0);
        L25: do {
         if ($59) {
          $wheelCount$0 = 0;
         } else {
          $60 = (($58) + 48|0);
          $61 = HEAP32[$60>>2]|0;
          $62 = ($61|0)==(0);
          if ($62) {
           $wheelCount$0 = 0;
          } else {
           $64 = $58;$i3$019 = 0;
           while(1) {
            $63 = (($64) + 72|0);
            __THREW__ = 0;
            $65 = (invoke_iii(2556,($63|0),($i3$019|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            $68 = (($wheelColliders) + ($i3$019<<2)|0);
            HEAP32[$68>>2] = $65;
            $69 = HEAP32[$65>>2]|0;
            $70 = (($69) + 144|0);
            $71 = HEAP32[$70>>2]|0;
            __THREW__ = 0;
            invoke_vi($71|0,($65|0));
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if ($73) {
             break;
            }
            $74 = (($i3$019) + 1)|0;
            $75 = ($74>>>0)<($61>>>0);
            if (!($75)) {
             $wheelCount$0 = $61;
             break L25;
            }
            $$pre = HEAP32[$57>>2]|0;
            $64 = $$pre;$i3$019 = $74;
           }
           $135 = ___cxa_find_matching_catch()|0;
           $136 = tempRet0;
           $142 = $124;$lpad$phi$index = $135;$lpad$phi$index5 = $136;
           label = 48;
           break L23;
          }
         }
        } while(0);
        $76 = (($this) + 68|0);
        $77 = HEAP8[$76>>0]|0;
        $78 = ($77<<24>>24)==(0);
        if ($78) {
         label = 27;
        } else {
         __THREW__ = 0;
         $79 = (invoke_i(116)|0);
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if (!($81)) {
          $82 = HEAP32[$79>>2]|0;
          $83 = (($82) + 52|0);
          $84 = HEAP32[$83>>2]|0;
          $85 = HEAP32[$5>>2]|0;
          __THREW__ = 0;
          invoke_viii($84|0,($79|0),($85|0),1);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if (!($87)) {
           label = 27;
          }
         }
        }
        if ((label|0) == 27) {
         $88 = HEAP32[$5>>2]|0;
         $89 = HEAP32[$88>>2]|0;
         $90 = HEAP32[$89>>2]|0;
         __THREW__ = 0;
         invoke_vi($90|0,($88|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if (!($92)) {
          HEAP32[$5>>2] = 0;
          L40: do {
           if ($recreateColliders) {
            L42: do {
             if ($162) {
              $i4$014 = 0;
              while(1) {
               $94 = (($95) + ($i4$014<<2)|0);
               $96 = HEAP32[$94>>2]|0;
               __THREW__ = 0;
               invoke_vii(3328,($96|0),($this|0));
               $97 = __THREW__; __THREW__ = 0;
               $98 = $97&1;
               if ($98) {
                break;
               }
               $99 = (($i4$014) + 1)|0;
               $100 = ($99|0)<($11|0);
               if ($100) {
                $i4$014 = $99;
               } else {
                break L42;
               }
              }
              $133 = ___cxa_find_matching_catch()|0;
              $134 = tempRet0;
              $142 = $124;$lpad$phi$index = $133;$lpad$phi$index5 = $134;
              label = 48;
              break L23;
             }
            } while(0);
            $93 = ($wheelCount$0|0)==(0);
            if (!($93)) {
             $i5$09 = 0;
             while(1) {
              $101 = (($wheelColliders) + ($i5$09<<2)|0);
              $102 = HEAP32[$101>>2]|0;
              __THREW__ = 0;
              invoke_vii(3329,($102|0),($this|0));
              $103 = __THREW__; __THREW__ = 0;
              $104 = $103&1;
              if ($104) {
               break;
              }
              $105 = (($i5$09) + 1)|0;
              $106 = ($105>>>0)<($wheelCount$0>>>0);
              if ($106) {
               $i5$09 = $105;
              } else {
               break L40;
              }
             }
             $131 = ___cxa_find_matching_catch()|0;
             $132 = tempRet0;
             $142 = $124;$lpad$phi$index = $131;$lpad$phi$index5 = $132;
             label = 48;
             break L23;
            }
           }
          } while(0);
          $107 = (($this) + 92|0);
          $108 = HEAP32[$107>>2]|0;
          $109 = ($108|0)==(0|0);
          if (!($109)) {
           $110 = HEAP32[$108>>2]|0;
           $111 = ($110|0)==(0|0);
           if (!($111)) {
            $112 = (($108) + 4|0);
            $113 = HEAP32[$112>>2]|0;
            $114 = (($110) + 4|0);
            HEAP32[$114>>2] = $113;
            $115 = HEAP32[$108>>2]|0;
            $116 = HEAP32[$112>>2]|0;
            HEAP32[$116>>2] = $115;
           }
           __ZdlPv($108);
          }
          HEAP32[$107>>2] = 0;
          $117 = (($this) + 76|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = (($this) + 80|0);
          HEAP32[$119>>2] = $118;
          $120 = (($this) + 84|0);
          $121 = HEAP8[$120>>0]|0;
          $122 = (($this) + 85|0);
          HEAP8[$122>>0] = $121;
          $123 = ($124|0)==(0|0);
          if (!($123)) {
           $125 = HEAP32[628512>>2]|0;
           HEAP32[$0>>2] = $125;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($124|0),($$byval_copy16|0));
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            $161 = $129;
            label = 7;
            break L8;
           }
          }
          $128 = ($129|0)==(0|0);
          if ($128) {
           break L1;
          }
          $130 = HEAP32[628512>>2]|0;
          HEAP32[$0>>2] = $130;
          ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
          __Z19free_alloc_internalPv10MemLabelId($129,$$byval_copy16);
          break L1;
         }
        }
        $139 = ___cxa_find_matching_catch()|0;
        $140 = tempRet0;
        $142 = $124;$lpad$phi$index = $139;$lpad$phi$index5 = $140;
        label = 48;
       }
      } while(0);
      if ((label|0) == 48) {
       $141 = ($142|0)==(0|0);
       if ($141) {
        $164 = $1;$165 = $lpad$phi$index5;$166 = $lpad$phi$index;
       } else {
        $143 = HEAP32[628512>>2]|0;
        HEAP32[$1>>2] = $143;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($142|0),($$byval_copy16|0));
        $144 = __THREW__; __THREW__ = 0;
        $145 = $144&1;
        if ($145) {
         $159 = ___cxa_find_matching_catch(0|0)|0;
         $160 = tempRet0;
         ___clang_call_terminate($159);
         // unreachable;
        } else {
         $164 = $1;$165 = $lpad$phi$index5;$166 = $lpad$phi$index;
        }
       }
      }
      $$1 = $166;$$12 = $165;$147 = $129;
     }
    }
   } while(0);
   if ((label|0) == 7) {
    $21 = ___cxa_find_matching_catch()|0;
    $22 = tempRet0;
    $$1 = $21;$$12 = $22;$147 = $161;
   }
   $146 = ($147|0)==(0|0);
   if ($146) {
    ___resumeException($$1|0);
    // unreachable;
   }
   $148 = HEAP32[628512>>2]|0;
   HEAP32[$2>>2] = $148;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($147|0),($$byval_copy16|0));
   $149 = __THREW__; __THREW__ = 0;
   $150 = $149&1;
   if ($150) {
    $159 = ___cxa_find_matching_catch(0|0)|0;
    $160 = tempRet0;
    ___clang_call_terminate($159);
    // unreachable;
   } else {
    ___resumeException($$1|0);
    // unreachable;
   }
  }
 } while(0);
 $151 = (($this) + 28|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = ($152|0)==(0|0);
 if ($153) {
  STACKTOP = sp;return;
 }
 $154 = (($this) + 32|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = (($152) + 4|0);
 HEAP32[$156>>2] = $155;
 $157 = HEAP32[$151>>2]|0;
 $158 = HEAP32[$154>>2]|0;
 HEAP32[$158>>2] = $157;
 HEAP32[$151>>2] = 0;
 HEAP32[$154>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody5ResetEv($this) {
 $this = $this|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = (($this) + 56|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 if ($2) {
  $72 = (($this) + 64|0);
  HEAPF32[$72>>2] = Math_fround(0.0500000007450580596924);
  $73 = (($this) + 60|0);
  HEAPF32[$73>>2] = Math_fround(0.0);
  $74 = (($this) + 72|0);
  HEAP32[$74>>2] = 0;
  $75 = (($this) + 71|0);
  HEAP8[$75>>0] = 0;
  $76 = (($this) + 70|0);
  HEAP8[$76>>0] = 1;
  $77 = (($this) + 76|0);
  HEAP32[$77>>2] = 0;
  $78 = (($this) + 80|0);
  HEAP32[$78>>2] = 0;
  $79 = (($this) + 84|0);
  HEAP8[$79>>0] = 1;
  $80 = (($this) + 85|0);
  HEAP8[$80>>0] = 1;
  $81 = (($this) + 86|0);
  HEAP8[$81>>0] = 0;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 69|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = HEAP32[$1>>2]|0;
  $8 = (($7) + 128|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vif[$9 & 255]($1,Math_fround(1.0));
 } else {
  __ZN9Rigidbody22UpdateMassDistributionEv($this);
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  $13 = Math_fround(HEAPF32[$3>>2]);
  __ZN13WheelCollider37UpdateVehicleSpringCMOffsetsAndMassesEP9RigidbodyPN5physx16PxVehicleNoDriveEf($this,$11,$13);
 }
 $14 = (($this) + 64|0);
 HEAPF32[$14>>2] = Math_fround(0.0500000007450580596924);
 $15 = HEAP32[$0>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 240|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vif[$18 & 255]($15,Math_fround(0.0500000007450580596924));
 $19 = (($this) + 60|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = HEAP32[$0>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 232|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_vif[$23 & 255]($20,Math_fround(0.0));
 $24 = (($this) + 72|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = HEAP32[$0>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 28|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 4095]($27)|0);
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   $33 = (($this) + 71|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    $36 = HEAP32[$0>>2]|0;
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + 284|0);
    $39 = HEAP32[$38>>2]|0;
    FUNCTION_TABLE_vi[$39 & 4095]($36);
   }
  }
  $$pr = HEAP32[$24>>2]|0;
  $40 = ($$pr|0)==(0);
  if (!($40)) {
   $41 = HEAP32[$0>>2]|0;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 28|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (FUNCTION_TABLE_ii[$44 & 4095]($41)|0);
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    $47 = (($this) + 71|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = ($48<<24>>24)==(0);
    if ($49) {
     $50 = HEAP32[$0>>2]|0;
     $51 = HEAP32[$50>>2]|0;
     $52 = (($51) + 284|0);
     $53 = HEAP32[$52>>2]|0;
     FUNCTION_TABLE_vi[$53 & 4095]($50);
    }
   }
  }
 }
 HEAP32[$24>>2] = 0;
 __ZN9Rigidbody14SetIsKinematicEb($this,0);
 $54 = HEAP32[$0>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 28|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (FUNCTION_TABLE_ii[$57 & 4095]($54)|0);
 $59 = ($58|0)==(0|0);
 if (!($59)) {
  $60 = (($this) + 71|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $63 = HEAP32[$0>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($64) + 284|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vi[$66 & 4095]($63);
  }
 }
 $67 = HEAP32[$0>>2]|0;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($68) + 44|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_viii[$70 & 4095]($67,2,0);
 $71 = (($this) + 70|0);
 HEAP8[$71>>0] = 1;
 __ZN9Rigidbody25SetCollisionDetectionModeEi($this,0);
 $81 = (($this) + 86|0);
 HEAP8[$81>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody14SetIsKinematicEb($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $data = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 13|0;
 $data = sp;
 $1 = sp + 12|0;
 $2 = (($this) + 71|0);
 $3 = $value&1;
 HEAP8[$2>>0] = $3;
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 200|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095]($0,$5);
 $9 = HEAP8[$0>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)!=(0);
 $tmp = $11 ^ $value;
 if (!($tmp)) {
  STACKTOP = sp;return;
 }
 $12 = (($data) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = (($data) + 4|0);
 HEAP32[$13>>2] = 0;
 HEAP32[$data>>2] = 0;
 if ($value) {
  $24 = HEAP32[$4>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 184|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_viii[$27 & 4095]($24,1,1);
  $$pre = (($this) + 68|0);
  $28 = HEAP8[$$pre>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if (!($29)) {
   $30 = (($this) + 24|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($31)|0);
   __ZN9Transform19BroadcastMessageAnyERK17MessageIdentifierR11MessageData($32,565120,$data);
  }
 } else {
  $14 = (($this) + 68|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   $17 = (($this) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($18)|0);
   __ZN9Transform19BroadcastMessageAnyERK17MessageIdentifierR11MessageData($19,565120,$data);
  }
  $20 = HEAP32[$4>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 184|0);
  $23 = HEAP32[$22>>2]|0;
  FUNCTION_TABLE_viii[$23 & 4095]($20,1,0);
 }
 __ZN9Rigidbody23UpdateInterpolationNodeEv($this);
 $33 = HEAP32[$4>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 200|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($1,$33);
 $37 = HEAP8[$1>>0]|0;
 $38 = $37 & 1;
 HEAP8[$2>>0] = $38;
 $39 = (($this) + 88|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = $40 & -2;
 HEAP32[$39>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody25SetCollisionDetectionModeEi($this,$ccd) {
 $this = $this|0;
 $ccd = $ccd|0;
 var $$byval_copy14 = 0, $$index = 0, $$index8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $allocPtr$0 = 0, $i$02 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy14 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($ccd|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 76|0);
 HEAP32[$5>>2] = $ccd;
 HEAP32[$2>>2] = $ccd;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + 104|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_ii[$11 & 4095]($7)|0);
 $13 = $12 << 2;
 $14 = (($13) + 15)|0;
 $15 = ($14>>>0)<(2000);
 $16 = ($12|0)!=(0);
 if ($15) {
  if ($16) {
   $17 = STACKTOP; STACKTOP = STACKTOP + ((((1*$14)|0)+15)&-16)|0;;
   $29 = 0;$allocPtr$0 = $17;
  } else {
   $29 = 0;$allocPtr$0 = 0;
  }
 } else {
  if ($16) {
   $18 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
   $19 = (invoke_iiiiiii(102,($14|0),16,($$byval_copy14|0),0,(691024|0),1311)|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $$index = $22;$$index8 = $23;$59 = $0;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $29 = $19;$allocPtr$0 = $19;
   }
  } else {
   $29 = 0;$allocPtr$0 = 0;
  }
 }
 $33 = $allocPtr$0;
 $34 = (($33) + 15)|0;
 $35 = $34 & -16;
 $36 = $35;
 $37 = HEAP32[$6>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 108|0);
 $40 = HEAP32[$39>>2]|0;
 __THREW__ = 0;
 (invoke_iiiii($40|0,($37|0),($36|0),($12|0),0)|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 L15: do {
  if ($42) {
   $26 = ___cxa_find_matching_catch()|0;
   $27 = tempRet0;
   $lpad$phi$index = $26;$lpad$phi$index2 = $27;
  } else {
   $43 = ($12|0)>(0);
   L18: do {
    if ($43) {
     $i$02 = 0;
     while(1) {
      $44 = (($36) + ($i$02<<2)|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = (($45) + 8|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = HEAP32[$47>>2]|0;
      $49 = (($48) + 148|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_vi($50|0,($47|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = (($i$02) + 1)|0;
      $54 = ($53|0)<($12|0);
      if ($54) {
       $i$02 = $53;
      } else {
       break L18;
      }
     }
     $24 = ___cxa_find_matching_catch()|0;
     $25 = tempRet0;
     $lpad$phi$index = $24;$lpad$phi$index2 = $25;
     break L15;
    }
   } while(0);
   $55 = ($29|0)==(0|0);
   if ($55) {
    STACKTOP = sp;return;
   }
   $56 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $56;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($29,$$byval_copy14);
   STACKTOP = sp;return;
  }
 } while(0);
 $28 = ($29|0)==(0|0);
 if ($28) {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$59 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $30 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy14|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $57 = ___cxa_find_matching_catch(0|0)|0;
  $58 = tempRet0;
  ___clang_call_terminate($57);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$59 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __ZN9Rigidbody16CheckConsistencyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component16CheckConsistencyEv($this);
 $0 = (($this) + 56|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 > Math_fround(1.00000001168609742308E-7);
 $3 = $2 ? $1 : Math_fround(1.00000001168609742308E-7);
 HEAPF32[$0>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody6CreateEb($this,$isActive) {
 $this = $this|0;
 $isActive = $isActive|0;
 var $$$i$i = Math_fround(0), $$0$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0;
 var $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0);
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $av = 0, $min2$i = 0, $pose$i1 = 0, $t = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $pose$i1 = sp + 80|0;
 $min2$i = sp;
 $0 = sp + 4|0;
 $t = sp + 32|0;
 $v = sp + 44|0;
 $av = sp + 56|0;
 $1 = sp + 68|0;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($this) + 68|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6&255;
  $8 = $isActive&1;
  $9 = ($7|0)==($8|0);
  if ($9) {
   STACKTOP = sp;return;
  }
 }
 $10 = (__Z17GetPhysicsManagerv()|0);
 $11 = (($10) + 104|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (Math_fround(__ZN14PhysicsManager17GetSleepThresholdEv($10)));
 $14 = (__Z14GetDynamicsSDKv()|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 108|0);
 $17 = HEAP32[$16>>2]|0;
 HEAPF32[$0>>2] = Math_fround(0.0);
 $18 = (($0) + 4|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($0) + 8|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($0) + 12|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($0) + 16|0);
 HEAPF32[$21>>2] = Math_fround(0.0);
 $22 = (($0) + 20|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($0) + 24|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (FUNCTION_TABLE_iii[$17 & 4095]($14,$0)|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 292|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_viii[$27 & 4095]($24,$12,1);
 $28 = HEAP32[$24>>2]|0;
 $29 = (($28) + 260|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vif[$30 & 255]($24,$13);
 $31 = (($24) + 8|0);
 HEAP32[$31>>2] = $this;
 $32 = HEAP32[$2>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  HEAP32[$2>>2] = $24;
  $212 = HEAP32[$24>>2]|0;
  $213 = (($212) + 140|0);
  $214 = HEAP32[$213>>2]|0;
  HEAPF32[$1>>2] = Math_fround(1.0);
  $215 = (($1) + 4|0);
  HEAPF32[$215>>2] = Math_fround(1.0);
  $216 = (($1) + 8|0);
  HEAPF32[$216>>2] = Math_fround(1.0);
  FUNCTION_TABLE_vii[$214 & 4095]($24,$1);
  $217 = HEAP32[$2>>2]|0;
  $218 = HEAP32[$217>>2]|0;
  $219 = (($218) + 128|0);
  $220 = HEAP32[$219>>2]|0;
  $221 = (($this) + 56|0);
  $222 = Math_fround(HEAPF32[$221>>2]);
  FUNCTION_TABLE_vif[$220 & 255]($217,$222);
  $223 = HEAP32[$2>>2]|0;
  $224 = HEAP32[$223>>2]|0;
  $225 = (($224) + 232|0);
  $226 = HEAP32[$225>>2]|0;
  $227 = (($this) + 60|0);
  $228 = Math_fround(HEAPF32[$227>>2]);
  FUNCTION_TABLE_vif[$226 & 255]($223,$228);
  $229 = HEAP32[$2>>2]|0;
  $230 = HEAP32[$229>>2]|0;
  $231 = (($230) + 240|0);
  $232 = HEAP32[$231>>2]|0;
  $233 = (($this) + 64|0);
  $234 = Math_fround(HEAPF32[$233>>2]);
  FUNCTION_TABLE_vif[$232 & 255]($229,$234);
  $235 = HEAP32[$2>>2]|0;
  $236 = HEAP32[$235>>2]|0;
  $237 = (($236) + 44|0);
  $238 = HEAP32[$237>>2]|0;
  $239 = (($this) + 70|0);
  $240 = HEAP8[$239>>0]|0;
  $241 = ($240<<24>>24)==(0);
  FUNCTION_TABLE_viii[$238 & 4095]($235,2,$241);
  $242 = HEAP32[$2>>2]|0;
  $243 = HEAP32[$242>>2]|0;
  $244 = (($243) + 184|0);
  $245 = HEAP32[$244>>2]|0;
  $246 = (($this) + 71|0);
  $247 = HEAP8[$246>>0]|0;
  $248 = ($247<<24>>24)!=(0);
  FUNCTION_TABLE_viii[$245 & 4095]($242,1,$248);
 } else {
  $34 = HEAP32[$32>>2]|0;
  $35 = (($34) + 124|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_vii[$36 & 4095]($pose$i1,$32);
  $37 = (($pose$i1) + 16|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($pose$i1) + 20|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($pose$i1) + 24|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = HEAP32[$2>>2]|0;
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 124|0);
  $46 = HEAP32[$45>>2]|0;
  FUNCTION_TABLE_vii[$46 & 4095]($pose$i1,$43);
  $47 = Math_fround(HEAPF32[$pose$i1>>2]);
  $48 = (($pose$i1) + 4|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($pose$i1) + 8|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($pose$i1) + 12|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = HEAP32[$2>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + 144|0);
  $57 = HEAP32[$56>>2]|0;
  FUNCTION_TABLE_vii[$57 & 4095]($pose$i1,$54);
  $58 = Math_fround(HEAPF32[$pose$i1>>2]);
  $59 = (($pose$i1) + 4|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($pose$i1) + 8|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$t>>2] = $58;
  $63 = (($t) + 4|0);
  HEAPF32[$63>>2] = $60;
  $64 = (($t) + 8|0);
  HEAPF32[$64>>2] = $62;
  $65 = HEAP32[$2>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + 152|0);
  $68 = HEAP32[$67>>2]|0;
  FUNCTION_TABLE_vii[$68 & 4095]($pose$i1,$65);
  $69 = Math_fround(HEAPF32[$pose$i1>>2]);
  $70 = (($pose$i1) + 4|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = (($pose$i1) + 8|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  HEAPF32[$v>>2] = $69;
  $74 = (($v) + 4|0);
  HEAPF32[$74>>2] = $71;
  $75 = (($v) + 8|0);
  HEAPF32[$75>>2] = $73;
  $76 = HEAP32[$2>>2]|0;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($77) + 160|0);
  $79 = HEAP32[$78>>2]|0;
  FUNCTION_TABLE_vii[$79 & 4095]($pose$i1,$76);
  $80 = Math_fround(HEAPF32[$pose$i1>>2]);
  $81 = (($pose$i1) + 4|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = (($pose$i1) + 8|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$av>>2] = $80;
  $85 = (($av) + 4|0);
  HEAPF32[$85>>2] = $82;
  $86 = (($av) + 8|0);
  HEAPF32[$86>>2] = $84;
  $87 = HEAP32[$2>>2]|0;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($88) + 296|0);
  $90 = HEAP32[$89>>2]|0;
  FUNCTION_TABLE_viii[$90 & 4095]($87,$pose$i1,$min2$i);
  $91 = HEAP32[$pose$i1>>2]|0;
  $92 = HEAP32[$2>>2]|0;
  $93 = HEAP32[$92>>2]|0;
  $94 = (($93) + 264|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (Math_fround(FUNCTION_TABLE_fi[$95 & 255]($92)));
  __ZN9Rigidbody15CleanupInternalEb($this,1);
  HEAP32[$2>>2] = $24;
  $97 = (($this) + 69|0);
  $98 = HEAP8[$97>>0]|0;
  $99 = ($98<<24>>24)==(0);
  do {
   if ($99) {
    $100 = HEAP32[$24>>2]|0;
    $101 = (($100) + 124|0);
    $102 = HEAP32[$101>>2]|0;
    FUNCTION_TABLE_vii[$102 & 4095]($pose$i1,$24);
    $103 = (($pose$i1) + 16|0);
    HEAPF32[$103>>2] = $38;
    $104 = (($pose$i1) + 20|0);
    HEAPF32[$104>>2] = $40;
    $105 = (($pose$i1) + 24|0);
    HEAPF32[$105>>2] = $42;
    $106 = HEAP32[$2>>2]|0;
    $107 = HEAP32[$106>>2]|0;
    $108 = (($107) + 120|0);
    $109 = HEAP32[$108>>2]|0;
    FUNCTION_TABLE_vii[$109 & 4095]($106,$pose$i1);
    HEAP8[$97>>0] = 0;
    $110 = (($this) + 44|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = ($111|0)==(0|0);
    if (!($112)) {
     $113 = (($this) + 56|0);
     $114 = Math_fround(HEAPF32[$113>>2]);
     __ZN13WheelCollider37UpdateVehicleSpringCMOffsetsAndMassesEP9RigidbodyPN5physx16PxVehicleNoDriveEf($this,$111,$114);
    }
    HEAP8[$97>>0] = 0;
    $115 = HEAP32[$2>>2]|0;
    $116 = HEAP32[$115>>2]|0;
    $117 = (($116) + 124|0);
    $118 = HEAP32[$117>>2]|0;
    FUNCTION_TABLE_vii[$118 & 4095]($pose$i1,$115);
    HEAPF32[$pose$i1>>2] = $47;
    $119 = (($pose$i1) + 4|0);
    HEAPF32[$119>>2] = $49;
    $120 = (($pose$i1) + 8|0);
    HEAPF32[$120>>2] = $51;
    $121 = (($pose$i1) + 12|0);
    HEAPF32[$121>>2] = $53;
    $122 = HEAP32[$2>>2]|0;
    $123 = HEAP32[$122>>2]|0;
    $124 = (($123) + 120|0);
    $125 = HEAP32[$124>>2]|0;
    FUNCTION_TABLE_vii[$125 & 4095]($122,$pose$i1);
    $126 = HEAP32[$110>>2]|0;
    $127 = ($126|0)==(0|0);
    if (!($127)) {
     $128 = (($this) + 56|0);
     $129 = Math_fround(HEAPF32[$128>>2]);
     __ZN13WheelCollider37UpdateVehicleSpringCMOffsetsAndMassesEP9RigidbodyPN5physx16PxVehicleNoDriveEf($this,$126,$129);
    }
    HEAP8[$97>>0] = 0;
    $130 = Math_fround(HEAPF32[$t>>2]);
    $131 = $130 > Math_fround(1.1920928955078125E-7);
    if ($131) {
     $132 = Math_fround(HEAPF32[$63>>2]);
     $133 = $132 > Math_fround(1.1920928955078125E-7);
     if ($133) {
      $134 = Math_fround(HEAPF32[$64>>2]);
      $135 = $134 > Math_fround(1.1920928955078125E-7);
      if ($135) {
       $136 = HEAP32[$2>>2]|0;
       $137 = HEAP32[$136>>2]|0;
       $138 = (($137) + 140|0);
       $139 = HEAP32[$138>>2]|0;
       FUNCTION_TABLE_vii[$139 & 4095]($136,$t);
       break;
      }
     }
    }
    $140 = (($this) + 4|0);
    $141 = HEAP32[$140>>2]|0;
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(691032,0,691024,694,1,$141,0,0);
   }
  } while(0);
  $142 = HEAP32[$2>>2]|0;
  $143 = HEAP32[$142>>2]|0;
  $144 = (($143) + 156|0);
  $145 = HEAP32[$144>>2]|0;
  FUNCTION_TABLE_viii[$145 & 4095]($142,$v,1);
  $146 = HEAP32[$2>>2]|0;
  $147 = HEAP32[$146>>2]|0;
  $148 = (($147) + 164|0);
  $149 = HEAP32[$148>>2]|0;
  FUNCTION_TABLE_viii[$149 & 4095]($146,$av,1);
  $150 = HEAP32[$2>>2]|0;
  $151 = HEAP32[$150>>2]|0;
  $152 = (($151) + 292|0);
  $153 = HEAP32[$152>>2]|0;
  FUNCTION_TABLE_viii[$153 & 4095]($150,$91,1);
  $154 = HEAP32[$2>>2]|0;
  $155 = HEAP32[$154>>2]|0;
  $156 = (($155) + 260|0);
  $157 = HEAP32[$156>>2]|0;
  FUNCTION_TABLE_vif[$157 & 255]($154,$96);
  $158 = (($this) + 71|0);
  $159 = HEAP8[$158>>0]|0;
  $160 = ($159<<24>>24)!=(0);
  __ZN9Rigidbody14SetIsKinematicEb($this,$160);
  $161 = (($this) + 56|0);
  $162 = Math_fround(HEAPF32[$161>>2]);
  $163 = $162 < Math_fround(1.00000001168609742308E-7);
  if ($163) {
   $$0$i$i = Math_fround(1.00000001168609742308E-7);
  } else {
   $164 = $162 > Math_fround(1.0E+9);
   $$$i$i = $164 ? Math_fround(1.0E+9) : $162;
   $$0$i$i = $$$i$i;
  }
  HEAPF32[$161>>2] = $$0$i$i;
  $165 = HEAP8[$97>>0]|0;
  $166 = ($165<<24>>24)==(0);
  if ($166) {
   $167 = HEAP32[$2>>2]|0;
   $168 = HEAP32[$167>>2]|0;
   $169 = (($168) + 128|0);
   $170 = HEAP32[$169>>2]|0;
   FUNCTION_TABLE_vif[$170 & 255]($167,$162);
  } else {
   __ZN9Rigidbody22UpdateMassDistributionEv($this);
  }
  $171 = (($this) + 44|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = ($172|0)==(0|0);
  if (!($173)) {
   $174 = Math_fround(HEAPF32[$161>>2]);
   __ZN13WheelCollider37UpdateVehicleSpringCMOffsetsAndMassesEP9RigidbodyPN5physx16PxVehicleNoDriveEf($this,$172,$174);
  }
  $175 = (($this) + 60|0);
  $176 = Math_fround(HEAPF32[$175>>2]);
  $177 = HEAP32[$2>>2]|0;
  $178 = HEAP32[$177>>2]|0;
  $179 = (($178) + 232|0);
  $180 = HEAP32[$179>>2]|0;
  FUNCTION_TABLE_vif[$180 & 255]($177,$176);
  $181 = (($this) + 64|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = HEAP32[$2>>2]|0;
  $184 = HEAP32[$183>>2]|0;
  $185 = (($184) + 240|0);
  $186 = HEAP32[$185>>2]|0;
  FUNCTION_TABLE_vif[$186 & 255]($183,$182);
  $187 = (($this) + 70|0);
  $188 = HEAP8[$187>>0]|0;
  $189 = ($188<<24>>24)!=(0);
  if ($189) {
   $190 = HEAP32[$2>>2]|0;
   $191 = HEAP32[$190>>2]|0;
   $192 = (($191) + 28|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = (FUNCTION_TABLE_ii[$193 & 4095]($190)|0);
   $195 = ($194|0)==(0|0);
   if (!($195)) {
    $196 = HEAP8[$158>>0]|0;
    $197 = ($196<<24>>24)==(0);
    if ($197) {
     $198 = HEAP32[$2>>2]|0;
     $199 = HEAP32[$198>>2]|0;
     $200 = (($199) + 284|0);
     $201 = HEAP32[$200>>2]|0;
     FUNCTION_TABLE_vi[$201 & 4095]($198);
    }
   }
  }
  $202 = HEAP32[$2>>2]|0;
  $203 = HEAP32[$202>>2]|0;
  $204 = (($203) + 44|0);
  $205 = HEAP32[$204>>2]|0;
  $206 = $189 ^ 1;
  FUNCTION_TABLE_viii[$205 & 4095]($202,2,$206);
  HEAP8[$187>>0] = $188;
  $207 = (($this) + 76|0);
  $208 = HEAP32[$207>>2]|0;
  __ZN9Rigidbody25SetCollisionDetectionModeEi($this,$208);
  $209 = (($this) + 84|0);
  $210 = HEAP8[$209>>0]|0;
  $211 = ($210<<24>>24)!=(0);
  __ZN9Rigidbody19SetDetectCollisionsEb($this,$211);
 }
 if ($isActive) {
  $249 = (__Z16GetDynamicsScenev()|0);
  $250 = HEAP32[$249>>2]|0;
  $251 = (($250) + 44|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = HEAP32[$2>>2]|0;
  FUNCTION_TABLE_vii[$252 & 4095]($249,$253);
  $254 = HEAP32[$this>>2]|0;
  $255 = (($254) + 96|0);
  $256 = HEAP32[$255>>2]|0;
  $257 = (($this) + 24|0);
  $258 = HEAP32[$257>>2]|0;
  $259 = (($258) + 52|0);
  $260 = HEAP32[$259>>2]|0;
  FUNCTION_TABLE_vii[$256 & 4095]($this,$260);
 }
 $261 = (($this) + 68|0);
 $262 = $isActive&1;
 HEAP8[$261>>0] = $262;
 __ZN9Rigidbody23UpdateInterpolationNodeEv($this);
 STACKTOP = sp;return;
}
function __ZNK9Rigidbody15GetCenterOfMassEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = (($0) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($0) + 20|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($0) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$agg$result>>2] = $7;
 $12 = (($agg$result) + 4|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($agg$result) + 8|0);
 HEAPF32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __ZNK9Rigidbody11GetVelocityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 152|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = Math_fround(HEAPF32[$0>>2]);
 $7 = (($0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$agg$result>>2] = $6;
 $11 = (($agg$result) + 4|0);
 HEAPF32[$11>>2] = $8;
 $12 = (($agg$result) + 8|0);
 HEAPF32[$12>>2] = $10;
 STACKTOP = sp;return;
}
function __ZNK9Rigidbody18GetAngularVelocityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 160|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = Math_fround(HEAPF32[$0>>2]);
 $7 = (($0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 HEAPF32[$agg$result>>2] = $6;
 $11 = (($agg$result) + 4|0);
 HEAPF32[$11>>2] = $8;
 $12 = (($agg$result) + 8|0);
 HEAPF32[$12>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody11SetVelocityERK8Vector3f($this,$velocity) {
 $this = $this|0;
 $velocity = $velocity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viii[$4 & 4095]($1,$velocity,1);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody18SetAngularVelocityERK8Vector3f($this,$velocity) {
 $this = $this|0;
 $velocity = $velocity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 164|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viii[$4 & 4095]($1,$velocity,1);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody19SetDetectCollisionsEb($this,$detectCollisions) {
 $this = $this|0;
 $detectCollisions = $detectCollisions|0;
 var $$byval_copy14 = 0, $$index = 0, $$index8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $allocPtr$0 = 0, $i$02 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy14 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = $detectCollisions&1;
 $3 = (($this) + 85|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = ($2|0)==($5|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 84|0);
 $8 = $detectCollisions&1;
 HEAP8[$7>>0] = $8;
 HEAP8[$3>>0] = $8;
 $9 = (($this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + 104|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($10)|0);
 $16 = $15 << 2;
 $17 = (($16) + 15)|0;
 $18 = ($17>>>0)<(2000);
 $19 = ($15|0)!=(0);
 if ($18) {
  if ($19) {
   $20 = STACKTOP; STACKTOP = STACKTOP + ((((1*$17)|0)+15)&-16)|0;;
   $32 = 0;$allocPtr$0 = $20;
  } else {
   $32 = 0;$allocPtr$0 = 0;
  }
 } else {
  if ($19) {
   $21 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
   $22 = (invoke_iiiiiii(102,($17|0),16,($$byval_copy14|0),0,(691024|0),1336)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $25 = ___cxa_find_matching_catch()|0;
    $26 = tempRet0;
    $$index = $25;$$index8 = $26;$62 = $0;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $32 = $22;$allocPtr$0 = $22;
   }
  } else {
   $32 = 0;$allocPtr$0 = 0;
  }
 }
 $36 = $allocPtr$0;
 $37 = (($36) + 15)|0;
 $38 = $37 & -16;
 $39 = $38;
 $40 = HEAP32[$9>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 108|0);
 $43 = HEAP32[$42>>2]|0;
 __THREW__ = 0;
 (invoke_iiiii($43|0,($40|0),($39|0),($15|0),0)|0);
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 L15: do {
  if ($45) {
   $29 = ___cxa_find_matching_catch()|0;
   $30 = tempRet0;
   $lpad$phi$index = $29;$lpad$phi$index2 = $30;
  } else {
   $46 = ($15|0)>(0);
   L17: do {
    if ($46) {
     $i$02 = 0;
     while(1) {
      $47 = (($39) + ($i$02<<2)|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = (($48) + 8|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = HEAP32[$50>>2]|0;
      $52 = (($51) + 148|0);
      $53 = HEAP32[$52>>2]|0;
      __THREW__ = 0;
      invoke_vi($53|0,($50|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      $56 = (($i$02) + 1)|0;
      $57 = ($56|0)<($15|0);
      if ($57) {
       $i$02 = $56;
      } else {
       break L17;
      }
     }
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     $lpad$phi$index = $27;$lpad$phi$index2 = $28;
     break L15;
    }
   } while(0);
   $58 = ($32|0)==(0|0);
   if ($58) {
    STACKTOP = sp;return;
   }
   $59 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $59;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($32,$$byval_copy14);
   STACKTOP = sp;return;
  }
 } while(0);
 $31 = ($32|0)==(0|0);
 if ($31) {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$62 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $33 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $33;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy14|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $60 = ___cxa_find_matching_catch(0|0)|0;
  $61 = tempRet0;
  ___clang_call_terminate($60);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$62 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __ZN9Rigidbody23UpdateInterpolationNodeEv($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 86|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 68|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if (!($5)) {
   $16 = (($this) + 92|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    STACKTOP = sp;return;
   }
   $19 = (__Znwj(44)|0);
   dest=$19+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $20 = $19;
   $21 = $20;
   HEAP32[$21>>2] = 0;
   $22 = (($20) + 4)|0;
   $23 = $22;
   HEAP32[$23>>2] = 0;
   HEAP32[$16>>2] = $19;
   $24 = (($19) + 36|0);
   HEAP32[$24>>2] = $this;
   $25 = (($19) + 40|0);
   HEAP32[$25>>2] = 1;
   $26 = (($19) + 8|0);
   ;HEAP32[$26+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[616680+8>>2]|0;
   $27 = (($19) + 20|0);
   HEAPF32[$27>>2] = Math_fround(0.0);
   $28 = (($19) + 24|0);
   HEAPF32[$28>>2] = Math_fround(0.0);
   $29 = (($19) + 28|0);
   HEAPF32[$29>>2] = Math_fround(0.0);
   $30 = (($19) + 32|0);
   HEAPF32[$30>>2] = Math_fround(1.0);
   $31 = (__Z17GetPhysicsManagerv()|0);
   $32 = (($31) + 120|0);
   $33 = HEAP32[$16>>2]|0;
   $34 = ($33|0)==($32|0);
   if ($34) {
    STACKTOP = sp;return;
   }
   $35 = HEAP32[$33>>2]|0;
   $36 = ($35|0)==(0|0);
   $$pre$i$i = (($33) + 4|0);
   if (!($36)) {
    $37 = HEAP32[$$pre$i$i>>2]|0;
    $38 = (($35) + 4|0);
    HEAP32[$38>>2] = $37;
    $39 = HEAP32[$33>>2]|0;
    $40 = HEAP32[$$pre$i$i>>2]|0;
    HEAP32[$40>>2] = $39;
    HEAP32[$33>>2] = 0;
    HEAP32[$$pre$i$i>>2] = 0;
   }
   $41 = HEAP32[$32>>2]|0;
   HEAP32[$33>>2] = $41;
   HEAP32[$$pre$i$i>>2] = $32;
   $42 = (($41) + 4|0);
   HEAP32[$42>>2] = $33;
   $43 = HEAP32[$$pre$i$i>>2]|0;
   HEAP32[$43>>2] = $33;
   STACKTOP = sp;return;
  }
 }
 $6 = (($this) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$7>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = (($7) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($9) + 4|0);
   HEAP32[$13>>2] = $12;
   $14 = HEAP32[$7>>2]|0;
   $15 = HEAP32[$11>>2]|0;
   HEAP32[$15>>2] = $14;
  }
  __ZdlPv($7);
 }
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody26SupportedMessagesDidChangeEi($this,$supported) {
 $this = $this|0;
 $supported = $supported|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $numProcessedShapes$02 = 0, $shapes = 0, $simFilterData = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $shapes = sp + 16|0;
 $simFilterData = sp;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = $supported & 1;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = $supported & 3;
  $6 = ($5|0)==(0);
  $$ = $6 ? 0 : 136192;
  $26 = $$;
 } else {
  $26 = 138240;
 }
 $7 = HEAP32[$1>>2]|0;
 $8 = (($7) + 104|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($1)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $numProcessedShapes$02 = 0;
 while(1) {
  $12 = HEAP32[$0>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 108|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_iiiii[$15 & 511]($12,$shapes,8,$numProcessedShapes$02)|0);
  $17 = ($16|0)==(0);
  if (!($17)) {
   $i$01 = 0;
   while(1) {
    $18 = (($shapes) + ($i$01<<2)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 80|0);
    $22 = HEAP32[$21>>2]|0;
    FUNCTION_TABLE_vii[$22 & 4095]($simFilterData,$19);
    $23 = HEAP32[$simFilterData>>2]|0;
    $24 = $23 & 255;
    $25 = $24 | $26;
    HEAP32[$simFilterData>>2] = $25;
    $27 = HEAP32[$18>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 76|0);
    $30 = HEAP32[$29>>2]|0;
    FUNCTION_TABLE_vii[$30 & 4095]($27,$simFilterData);
    $31 = (($i$01) + 1)|0;
    $exitcond = ($31|0)==($16|0);
    if ($exitcond) {
     break;
    } else {
     $i$01 = $31;
    }
   }
  }
  $32 = (($16) + ($numProcessedShapes$02))|0;
  $33 = ($32>>>0)<($10>>>0);
  if ($33) {
   $numProcessedShapes$02 = $32;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Rigidbody10DeactivateEN5Unity19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($operation|0)==(2);
 if (!($0)) {
  __ZN9Rigidbody6CreateEb($this,0);
 }
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$4>>2]|0;
 HEAP32[$8>>2] = $7;
 HEAP32[$1>>2] = 0;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$$i$i = Math_fround(0), $$0$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
 } else {
  $3 = (__ZNK5Unity10GameObject8IsActiveEv($1)|0);
  $4 = $3;
 }
 __ZN9Rigidbody6CreateEb($this,$4);
 $5 = $awakeMode & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (($this) + 71|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)!=(0);
  __ZN9Rigidbody14SetIsKinematicEb($this,$9);
  $10 = (($this) + 56|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = $11 < Math_fround(1.00000001168609742308E-7);
  if ($12) {
   $$0$i$i = Math_fround(1.00000001168609742308E-7);
  } else {
   $13 = $11 > Math_fround(1.0E+9);
   $$$i$i = $13 ? Math_fround(1.0E+9) : $11;
   $$0$i$i = $$$i$i;
  }
  HEAPF32[$10>>2] = $$0$i$i;
  $14 = (($this) + 69|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $17 = (($this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 128|0);
   $21 = HEAP32[$20>>2]|0;
   FUNCTION_TABLE_vif[$21 & 255]($18,$11);
  } else {
   __ZN9Rigidbody22UpdateMassDistributionEv($this);
  }
  $22 = (($this) + 44|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   $25 = Math_fround(HEAPF32[$10>>2]);
   __ZN13WheelCollider37UpdateVehicleSpringCMOffsetsAndMassesEP9RigidbodyPN5physx16PxVehicleNoDriveEf($this,$23,$25);
  }
  $26 = (($this) + 60|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($this) + 40|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 232|0);
  $32 = HEAP32[$31>>2]|0;
  FUNCTION_TABLE_vif[$32 & 255]($29,$27);
  $33 = (($this) + 64|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = HEAP32[$28>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 240|0);
  $38 = HEAP32[$37>>2]|0;
  FUNCTION_TABLE_vif[$38 & 255]($35,$34);
  $39 = (($this) + 70|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = ($40<<24>>24)!=(0);
  if ($41) {
   $42 = HEAP32[$28>>2]|0;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($43) + 28|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (FUNCTION_TABLE_ii[$45 & 4095]($42)|0);
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    $48 = HEAP8[$7>>0]|0;
    $49 = ($48<<24>>24)==(0);
    if ($49) {
     $50 = HEAP32[$28>>2]|0;
     $51 = HEAP32[$50>>2]|0;
     $52 = (($51) + 284|0);
     $53 = HEAP32[$52>>2]|0;
     FUNCTION_TABLE_vi[$53 & 4095]($50);
    }
   }
  }
  $54 = HEAP32[$28>>2]|0;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + 44|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = $41 ^ 1;
  FUNCTION_TABLE_viii[$57 & 4095]($54,2,$58);
  HEAP8[$39>>0] = $40;
  $59 = (($this) + 76|0);
  $60 = HEAP32[$59>>2]|0;
  __ZN9Rigidbody25SetCollisionDetectionModeEi($this,$60);
  $61 = (($this) + 84|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = ($62<<24>>24)!=(0);
  __ZN9Rigidbody19SetDetectCollisionsEb($this,$63);
 }
 __ZN9Rigidbody23UpdateInterpolationNodeEv($this);
 $64 = HEAP32[$0>>2]|0;
 $65 = ($64|0)==(0|0);
 if (!($65)) {
  $66 = (__ZNK5Unity10GameObject8IsActiveEv($64)|0);
  if ($66) {
   __ZN9Rigidbody22FetchPoseFromTransformEv($this);
  }
 }
 $67 = (($this) + 71|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = ($68<<24>>24)==(0);
 if ($69) {
  $70 = (($this) + 88|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = $71 & -2;
  HEAP32[$70>>2] = $72;
 }
 $73 = $awakeMode & 8;
 $74 = ($73|0)==(0);
 if (!($74)) {
  $75 = (($data) + 8|0);
  HEAP32[$75>>2] = 0;
  $76 = (($data) + 4|0);
  HEAP32[$76>>2] = 0;
  HEAP32[$data>>2] = 0;
  $77 = HEAP32[$0>>2]|0;
  $78 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($77)|0);
  __ZN9Transform19BroadcastMessageAnyERK17MessageIdentifierR11MessageData($78,565120,$data);
 }
 $79 = (($this) + 28|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(0|0);
 if (!($81)) {
  $82 = (($this) + 32|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($80) + 4|0);
  HEAP32[$84>>2] = $83;
  $85 = HEAP32[$79>>2]|0;
  $86 = HEAP32[$82>>2]|0;
  HEAP32[$86>>2] = $85;
  HEAP32[$79>>2] = 0;
  HEAP32[$82>>2] = 0;
 }
 $87 = (($this) + 68|0);
 $88 = HEAP8[$87>>0]|0;
 $89 = ($88<<24>>24)==(0);
 if ($89) {
  STACKTOP = sp;return;
 }
 $90 = (__Z17GetPhysicsManagerv()|0);
 $91 = HEAP32[$0>>2]|0;
 $92 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($91)|0);
 $93 = (__Z17GetTransformDepthR9Transform($92)|0);
 __ZN14PhysicsManager7AddBodyEiR8ListNodeI9RigidbodyE($90,$93,$79);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody22FetchPoseFromTransformEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0;
 var $pos = 0, $pose = 0, $rot = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos = sp + 44|0;
 $rot = sp;
 $pose = sp + 16|0;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($1)|0);
 __ZNK9Transform11GetPositionEv($pos,$2);
 __ZNK9Transform11GetRotationEv($rot,$2);
 $3 = Math_fround(HEAPF32[$pos>>2]);
 $4 = (($pos) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($pos) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround(HEAPF32[$rot>>2]);
 $9 = (($rot) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($rot) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($rot) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAPF32[$pose>>2] = $8;
 $15 = (($pose) + 4|0);
 HEAPF32[$15>>2] = $10;
 $16 = (($pose) + 8|0);
 HEAPF32[$16>>2] = $12;
 $17 = (($pose) + 12|0);
 HEAPF32[$17>>2] = $14;
 $18 = (($pose) + 16|0);
 HEAPF32[$18>>2] = $3;
 $19 = (($pose) + 20|0);
 HEAPF32[$19>>2] = $5;
 $20 = (($pose) + 24|0);
 HEAPF32[$20>>2] = $7;
 $21 = (($this) + 71|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $35 = (($this) + 40|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 88|0);
  $39 = HEAP32[$38>>2]|0;
  FUNCTION_TABLE_viii[$39 & 4095]($36,$pose,1);
  STACKTOP = sp;return;
 }
 $24 = (($this) + 68|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if (!($26)) {
  $27 = (($this) + 40|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 224|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 4095]($28,$pose);
 }
 $32 = (($this) + 88|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 | 1;
 HEAP32[$32>>2] = $34;
 $35 = (($this) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 88|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($36,$pose,1);
 STACKTOP = sp;return;
}
function __ZNK9Rigidbody14GetIsKinematicEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 71|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN9Rigidbody15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(54,564104,1980,100000);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(54,565032,1981,100006);
 STACKTOP = sp;return;
}
function __ZZN9Rigidbody15InitializeClassEvEN39FunctorImpl_Rigidbody_kTransformChanged4CallEPviR11MessageData($object,$messageID,$messageData) {
 $object = $object|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($messageData) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN9Rigidbody16TransformChangedEi($object,$1);
 STACKTOP = sp;return;
}
function __ZZN9Rigidbody15InitializeClassEvEN42FunctorImpl_Rigidbody_kAnimatorMoveBuiltin4CallE_0PviR11MessageData($object,$messageID,$messageData) {
 $object = $object|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($messageData) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN9Rigidbody22ApplyRootMotionBuiltinEP14RootMotionData($object,$1);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody17SetFreezeRotationEb($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $$not = 0, $$not3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 if ($value) {
  $2 = $1 | 112;
  $3 = ($1|0)==($2|0);
  if (!($3)) {
   $4 = (($this) + 40|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 28|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (FUNCTION_TABLE_ii[$8 & 4095]($5)|0);
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($this) + 71|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = ($12<<24>>24)==(0);
    if ($13) {
     $14 = HEAP32[$4>>2]|0;
     $15 = HEAP32[$14>>2]|0;
     $16 = (($15) + 284|0);
     $17 = HEAP32[$16>>2]|0;
     FUNCTION_TABLE_vi[$17 & 4095]($14);
    }
   }
  }
  $18 = HEAP32[$0>>2]|0;
  $$not3 = $1 & -113;
  $19 = $$not3 ^ -113;
  $20 = $18 & $19;
  $21 = ($20|0)==(0);
  if ($21) {
   $storemerge = $2;
   HEAP32[$0>>2] = $storemerge;
   STACKTOP = sp;return;
  }
  $22 = (($this) + 40|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (FUNCTION_TABLE_ii[$26 & 4095]($23)|0);
  $28 = ($27|0)==(0|0);
  if ($28) {
   $storemerge = $2;
   HEAP32[$0>>2] = $storemerge;
   STACKTOP = sp;return;
  }
  $29 = (($this) + 71|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if (!($31)) {
   $storemerge = $2;
   HEAP32[$0>>2] = $storemerge;
   STACKTOP = sp;return;
  }
  $32 = HEAP32[$22>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 284|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vi[$35 & 4095]($32);
  $storemerge = $2;
  HEAP32[$0>>2] = $storemerge;
  STACKTOP = sp;return;
 } else {
  $36 = $1 & -113;
  $37 = ($1|0)==($36|0);
  if (!($37)) {
   $38 = (($this) + 40|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$39>>2]|0;
   $41 = (($40) + 28|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (FUNCTION_TABLE_ii[$42 & 4095]($39)|0);
   $44 = ($43|0)==(0|0);
   if (!($44)) {
    $45 = (($this) + 71|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $48 = HEAP32[$38>>2]|0;
     $49 = HEAP32[$48>>2]|0;
     $50 = (($49) + 284|0);
     $51 = HEAP32[$50>>2]|0;
     FUNCTION_TABLE_vi[$51 & 4095]($48);
    }
   }
  }
  $52 = HEAP32[$0>>2]|0;
  $$not = $1 | 112;
  $53 = $$not ^ -113;
  $54 = $52 & $53;
  $55 = ($54|0)==(0);
  if ($55) {
   $storemerge = $36;
   HEAP32[$0>>2] = $storemerge;
   STACKTOP = sp;return;
  }
  $56 = (($this) + 40|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + 28|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (FUNCTION_TABLE_ii[$60 & 4095]($57)|0);
  $62 = ($61|0)==(0|0);
  if ($62) {
   $storemerge = $36;
   HEAP32[$0>>2] = $storemerge;
   STACKTOP = sp;return;
  }
  $63 = (($this) + 71|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = ($64<<24>>24)==(0);
  if (!($65)) {
   $storemerge = $36;
   HEAP32[$0>>2] = $storemerge;
   STACKTOP = sp;return;
  }
  $66 = HEAP32[$56>>2]|0;
  $67 = HEAP32[$66>>2]|0;
  $68 = (($67) + 284|0);
  $69 = HEAP32[$68>>2]|0;
  FUNCTION_TABLE_vi[$69 & 4095]($66);
  $storemerge = $36;
  HEAP32[$0>>2] = $storemerge;
  STACKTOP = sp;return;
 }
}
function __ZN9Rigidbody22UpdateMassDistributionEv($this) {
 $this = $this|0;
 var $$byval_copy16 = 0, $$index = 0, $$index8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $allocPtr$0 = 0, $i$06 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $pose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy16 = sp + 44|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 48|0;
 $pose = sp + 16|0;
 $5 = (($this) + 71|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($this) + 40|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 128|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($this) + 56|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  FUNCTION_TABLE_vif[$12 & 255]($9,$14);
  STACKTOP = sp;return;
 }
 $15 = (($this) + 69|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 L5: do {
  if (!($17)) {
   $18 = (($this) + 40|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 104|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (FUNCTION_TABLE_ii[$22 & 4095]($19)|0);
   $24 = $23 << 2;
   $25 = (($24) + 15)|0;
   $26 = ($25>>>0)<(2000);
   $27 = ($23|0)!=(0);
   if ($26) {
    if ($27) {
     $28 = STACKTOP; STACKTOP = STACKTOP + ((((1*$25)|0)+15)&-16)|0;;
     $40 = 0;$allocPtr$0 = $28;
    } else {
     $40 = 0;$allocPtr$0 = 0;
    }
   } else {
    if ($27) {
     $29 = HEAP32[628512>>2]|0;
     HEAP32[$3>>2] = $29;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$3+0>>2]|0;
     $30 = (invoke_iiiiiii(102,($25|0),16,($$byval_copy16|0),0,(691024|0),582)|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      $33 = ___cxa_find_matching_catch()|0;
      $34 = tempRet0;
      $$index = $33;$$index8 = $34;$133 = $0;
      ___resumeException($$index|0);
      // unreachable;
     } else {
      $40 = $30;$allocPtr$0 = $30;
     }
    } else {
     $40 = 0;$allocPtr$0 = 0;
    }
   }
   $44 = $allocPtr$0;
   $45 = (($44) + 15)|0;
   $46 = $45 & -16;
   $47 = $46;
   $48 = HEAP32[$18>>2]|0;
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + 108|0);
   $51 = HEAP32[$50>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($51|0,($48|0),($47|0),($23|0),0)|0);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   L15: do {
    if ($53) {
     label = 11;
    } else {
     $54 = ($23|0)>(0);
     L17: do {
      if ($54) {
       $i$06 = 0;
       while(1) {
        $57 = (($47) + ($i$06<<2)|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = HEAP32[$58>>2]|0;
        $60 = (($59) + 136|0);
        $61 = HEAP32[$60>>2]|0;
        __THREW__ = 0;
        invoke_vii($61|0,($4|0),($58|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 10;
         break;
        }
        $64 = HEAP8[$4>>0]|0;
        $65 = $64 & 4;
        $66 = ($65<<24>>24)==(0);
        $56 = (($i$06) + 1)|0;
        if ($66) {
         break;
        }
        $55 = ($56|0)<($23|0);
        if ($55) {
         $i$06 = $56;
        } else {
         break L17;
        }
       }
       if ((label|0) == 10) {
        $35 = ___cxa_find_matching_catch()|0;
        $36 = tempRet0;
        $lpad$phi$index = $35;$lpad$phi$index2 = $36;
        break L15;
       }
       $67 = HEAP32[$18>>2]|0;
       $68 = (($this) + 56|0);
       $69 = Math_fround(HEAPF32[$68>>2]);
       __THREW__ = 0;
       (invoke_iifii(1,($67|0),(+$69),(0|0),0)|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 11;
        break L15;
       }
       $72 = (($this) + 44|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($73|0)==(0|0);
       if (!($74)) {
        $75 = Math_fround(HEAPF32[$68>>2]);
        __THREW__ = 0;
        invoke_viif(44,($this|0),($73|0),(+$75));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 11;
         break L15;
        }
       }
       $78 = (($this) + 72|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = ($79|0)==(0);
       if ($80) {
        $127 = ($40|0)==(0|0);
        if ($127) {
         STACKTOP = sp;return;
        }
        $128 = HEAP32[628512>>2]|0;
        HEAP32[$1>>2] = $128;
        ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
        __Z19free_alloc_internalPv10MemLabelId($40,$$byval_copy16);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       invoke_vi(3640,($this|0));
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        label = 11;
        break L15;
       }
       $129 = ($40|0)==(0|0);
       if ($129) {
        STACKTOP = sp;return;
       }
       $130 = HEAP32[628512>>2]|0;
       HEAP32[$2>>2] = $130;
       ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$2+0>>2]|0;
       __Z19free_alloc_internalPv10MemLabelId($40,$$byval_copy16);
       STACKTOP = sp;return;
      }
     } while(0);
     $83 = HEAP32[$18>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = (($84) + 128|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($this) + 56|0);
     $88 = Math_fround(HEAPF32[$87>>2]);
     __THREW__ = 0;
     invoke_vif($86|0,($83|0),(+$88));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 11;
     } else {
      $91 = HEAP32[$18>>2]|0;
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 124|0);
      $94 = HEAP32[$93>>2]|0;
      __THREW__ = 0;
      invoke_vii($94|0,($pose|0),($91|0));
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 11;
      } else {
       $97 = Math_fround(HEAPF32[616680>>2]);
       $98 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
       $99 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
       $100 = (($pose) + 16|0);
       HEAPF32[$100>>2] = $97;
       $101 = (($pose) + 20|0);
       HEAPF32[$101>>2] = $98;
       $102 = (($pose) + 24|0);
       HEAPF32[$102>>2] = $99;
       $103 = HEAP32[$18>>2]|0;
       $104 = HEAP32[$103>>2]|0;
       $105 = (($104) + 120|0);
       $106 = HEAP32[$105>>2]|0;
       __THREW__ = 0;
       invoke_vii($106|0,($103|0),($pose|0));
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        label = 11;
       } else {
        $109 = HEAP32[$18>>2]|0;
        $110 = HEAP32[$109>>2]|0;
        $111 = (($110) + 140|0);
        $112 = HEAP32[$111>>2]|0;
        __THREW__ = 0;
        invoke_vii($112|0,($109|0),(616696|0));
        $113 = __THREW__; __THREW__ = 0;
        $114 = $113&1;
        if ($114) {
         label = 11;
        } else {
         $115 = (($this) + 72|0);
         $116 = HEAP32[$115>>2]|0;
         $117 = ($116|0)==(0);
         if (!($117)) {
          __THREW__ = 0;
          invoke_vi(3640,($this|0));
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          if ($119) {
           label = 11;
           break;
          }
         }
         $120 = ($40|0)==(0|0);
         if ($120) {
          break L5;
         }
         $121 = HEAP32[628512>>2]|0;
         HEAP32[$0>>2] = $121;
         ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
         __Z19free_alloc_internalPv10MemLabelId($40,$$byval_copy16);
         break L5;
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 11) {
    $37 = ___cxa_find_matching_catch()|0;
    $38 = tempRet0;
    $lpad$phi$index = $37;$lpad$phi$index2 = $38;
   }
   $39 = ($40|0)==(0|0);
   if ($39) {
    $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$133 = $0;
    ___resumeException($$index|0);
    // unreachable;
   }
   $41 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $41;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($40|0),($$byval_copy16|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    $131 = ___cxa_find_matching_catch(0|0)|0;
    $132 = tempRet0;
    ___clang_call_terminate($131);
    // unreachable;
   } else {
    $$index = $lpad$phi$index;$$index8 = $lpad$phi$index2;$133 = $0;
    ___resumeException($$index|0);
    // unreachable;
   }
  }
 } while(0);
 $122 = (($this) + 44|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ($123|0)==(0|0);
 if ($124) {
  STACKTOP = sp;return;
 }
 $125 = (($this) + 56|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 __ZN13WheelCollider37UpdateVehicleSpringCMOffsetsAndMassesEP9RigidbodyPN5physx16PxVehicleNoDriveEf($this,$123,$126);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody16ApplyConstraintsEv($this) {
 $this = $this|0;
 var $$pre = Math_fround(0), $$pre$phi12Z2D = Math_fround(0), $$pre11 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0;
 var $15 = Math_fround(0), $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0;
 var $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0);
 var $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0);
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0);
 var $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0);
 var $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0);
 var $33 = Math_fround(0), $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0);
 var $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0);
 var $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0);
 var $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $cmassLocalPose = 0, $inertia = 0, $inertiaChanged$0$off0 = 0, $inertiaChanged$1$off0 = 0, $linearVelocity = 0, $newActorPose = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $cmassLocalPose = sp + 132|0;
 $0 = sp + 120|0;
 $1 = sp + 104|0;
 $newActorPose = sp + 76|0;
 $linearVelocity = sp + 64|0;
 $2 = sp + 24|0;
 $inertia = sp + 12|0;
 $3 = sp;
 $4 = sp + 36|0;
 $5 = (($this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($8)|0);
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 124|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($cmassLocalPose,$11);
 __ZNK9Transform11GetPositionEv($0,$9);
 $15 = Math_fround(HEAPF32[$0>>2]);
 $16 = (($0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 __ZNK9Transform11GetRotationEv($1,$9);
 $20 = Math_fround(HEAPF32[$1>>2]);
 $21 = (($1) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($1) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($1) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = HEAP32[$10>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 84|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($newActorPose,$27);
 $31 = (($cmassLocalPose) + 16|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(2.0));
 $34 = (($cmassLocalPose) + 20|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * Math_fround(2.0));
 $37 = (($cmassLocalPose) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($38 * Math_fround(2.0));
 $40 = Math_fround($26 * $26);
 $41 = Math_fround($40 + Math_fround(-0.5));
 $42 = Math_fround($20 * $33);
 $43 = Math_fround($22 * $36);
 $44 = Math_fround($42 + $43);
 $45 = Math_fround($24 * $39);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($41 * $36);
 $48 = Math_fround($24 * $33);
 $49 = Math_fround($20 * $39);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($26 * $50);
 $52 = Math_fround($47 + $51);
 $53 = Math_fround($22 * $46);
 $54 = Math_fround($53 + $52);
 $55 = Math_fround($41 * $39);
 $56 = Math_fround($20 * $36);
 $57 = Math_fround($22 * $33);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($26 * $58);
 $60 = Math_fround($55 + $59);
 $61 = Math_fround($24 * $46);
 $62 = Math_fround($60 + $61);
 $63 = Math_fround($17 + $54);
 $64 = Math_fround($19 + $62);
 $65 = Math_fround(HEAPF32[$cmassLocalPose>>2]);
 $66 = (($cmassLocalPose) + 12|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($cmassLocalPose) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($cmassLocalPose) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($newActorPose) + 12|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 * $73);
 $75 = Math_fround($74 + Math_fround(-0.5));
 $76 = Math_fround(HEAPF32[$newActorPose>>2]);
 $77 = Math_fround($33 * $76);
 $78 = (($newActorPose) + 4|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($36 * $79);
 $81 = Math_fround($77 + $80);
 $82 = (($newActorPose) + 8|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($39 * $83);
 $85 = Math_fround($81 + $84);
 $86 = Math_fround($33 * $75);
 $87 = Math_fround($39 * $79);
 $88 = Math_fround($36 * $83);
 $89 = Math_fround($87 - $88);
 $90 = Math_fround($73 * $89);
 $91 = Math_fround($86 + $90);
 $92 = Math_fround($76 * $85);
 $93 = Math_fround($92 + $91);
 $94 = Math_fround($36 * $75);
 $95 = Math_fround($33 * $83);
 $96 = Math_fround($39 * $76);
 $97 = Math_fround($95 - $96);
 $98 = Math_fround($73 * $97);
 $99 = Math_fround($94 + $98);
 $100 = Math_fround($79 * $85);
 $101 = Math_fround($100 + $99);
 $102 = Math_fround($39 * $75);
 $103 = Math_fround($36 * $76);
 $104 = Math_fround($33 * $79);
 $105 = Math_fround($103 - $104);
 $106 = Math_fround($73 * $105);
 $107 = Math_fround($102 + $106);
 $108 = Math_fround($83 * $85);
 $109 = Math_fround($107 + $108);
 $110 = (($newActorPose) + 16|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($111 + $93);
 $113 = (($newActorPose) + 20|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($114 + $101);
 $116 = (($newActorPose) + 24|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround($117 + $109);
 $119 = Math_fround($65 * $73);
 $120 = Math_fround($67 * $76);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($69 * $79);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($71 * $83);
 $125 = Math_fround($123 - $124);
 $126 = Math_fround($71 * $73);
 $127 = Math_fround($67 * $79);
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($65 * $83);
 $130 = Math_fround($129 + $128);
 $131 = Math_fround($69 * $76);
 $132 = Math_fround($130 - $131);
 $133 = Math_fround($69 * $73);
 $134 = Math_fround($67 * $83);
 $135 = Math_fround($133 + $134);
 $136 = Math_fround($71 * $76);
 $137 = Math_fround($136 + $135);
 $138 = Math_fround($65 * $79);
 $139 = Math_fround($137 - $138);
 $140 = Math_fround($67 * $73);
 $141 = Math_fround($65 * $76);
 $142 = Math_fround($140 - $141);
 $143 = Math_fround($71 * $79);
 $144 = Math_fround($142 - $143);
 $145 = Math_fround($69 * $83);
 $146 = Math_fround($144 - $145);
 $147 = HEAP32[$10>>2]|0;
 $148 = HEAP32[$147>>2]|0;
 $149 = (($148) + 152|0);
 $150 = HEAP32[$149>>2]|0;
 FUNCTION_TABLE_vii[$150 & 4095]($linearVelocity,$147);
 $151 = $6 & 2;
 $152 = ($151|0)==(0);
 if ($152) {
  $366 = $112;
 } else {
  $153 = Math_fround($24 * $36);
  $154 = Math_fround($22 * $39);
  $155 = Math_fround($154 - $153);
  $156 = Math_fround($26 * $155);
  $157 = Math_fround($41 * $33);
  $158 = Math_fround($20 * $46);
  $159 = Math_fround($157 + $156);
  $160 = Math_fround($158 + $159);
  $161 = Math_fround($15 + $160);
  HEAPF32[$linearVelocity>>2] = Math_fround(0.0);
  $366 = $161;
 }
 $162 = $6 & 4;
 $163 = ($162|0)==(0);
 if ($163) {
  $368 = $115;
 } else {
  $164 = (($linearVelocity) + 4|0);
  HEAPF32[$164>>2] = Math_fround(0.0);
  $368 = $63;
 }
 $165 = $6 & 8;
 $166 = ($165|0)==(0);
 if ($166) {
  $370 = $118;
 } else {
  $167 = (($linearVelocity) + 8|0);
  HEAPF32[$167>>2] = Math_fround(0.0);
  $370 = $64;
 }
 $168 = (($this) + 71|0);
 $169 = HEAP8[$168>>0]|0;
 $170 = ($169<<24>>24)==(0);
 if ($170) {
  $171 = HEAP32[$10>>2]|0;
  $172 = HEAP32[$171>>2]|0;
  $173 = (($172) + 156|0);
  $174 = HEAP32[$173>>2]|0;
  FUNCTION_TABLE_viii[$174 & 4095]($171,$linearVelocity,0);
 }
 $175 = $6 & 112;
 $176 = ($175|0)==(0);
 do {
  if ($176) {
   $$pre = Math_fround($146 * $146);
   $$pre11 = Math_fround($$pre + Math_fround(-0.5));
   $$pre$phi12Z2D = $$pre11;
  } else {
   $177 = HEAP32[$10>>2]|0;
   $178 = HEAP32[$177>>2]|0;
   $179 = (($178) + 160|0);
   $180 = HEAP32[$179>>2]|0;
   FUNCTION_TABLE_vii[$180 & 4095]($2,$177);
   $181 = Math_fround(HEAPF32[$2>>2]);
   $182 = Math_fround($181 * Math_fround(2.0));
   $183 = (($2) + 4|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = Math_fround($184 * Math_fround(2.0));
   $186 = (($2) + 8|0);
   $187 = Math_fround(HEAPF32[$186>>2]);
   $188 = Math_fround($187 * Math_fround(2.0));
   $189 = Math_fround($146 * $146);
   $190 = Math_fround($189 + Math_fround(-0.5));
   $191 = Math_fround($125 * $182);
   $192 = Math_fround($132 * $185);
   $193 = Math_fround($191 + $192);
   $194 = Math_fround($139 * $188);
   $195 = Math_fround($193 + $194);
   $196 = Math_fround($190 * $182);
   $197 = Math_fround($132 * $188);
   $198 = Math_fround($139 * $185);
   $199 = Math_fround($197 - $198);
   $200 = Math_fround($146 * $199);
   $201 = Math_fround($196 - $200);
   $202 = Math_fround($125 * $195);
   $203 = Math_fround($202 + $201);
   $204 = Math_fround($190 * $185);
   $205 = Math_fround($139 * $182);
   $206 = Math_fround($125 * $188);
   $207 = Math_fround($205 - $206);
   $208 = Math_fround($146 * $207);
   $209 = Math_fround($204 - $208);
   $210 = Math_fround($132 * $195);
   $211 = Math_fround($210 + $209);
   $212 = Math_fround($190 * $188);
   $213 = Math_fround($125 * $185);
   $214 = Math_fround($132 * $182);
   $215 = Math_fround($213 - $214);
   $216 = Math_fround($146 * $215);
   $217 = Math_fround($212 - $216);
   $218 = Math_fround($139 * $195);
   $219 = Math_fround($217 + $218);
   $220 = HEAP32[$10>>2]|0;
   $221 = HEAP32[$220>>2]|0;
   $222 = (($221) + 144|0);
   $223 = HEAP32[$222>>2]|0;
   FUNCTION_TABLE_vii[$223 & 4095]($inertia,$220);
   $224 = $6 & 16;
   $225 = ($224|0)==(0);
   if ($225) {
    $249 = $203;$inertiaChanged$0$off0 = 0;
   } else {
    $226 = Math_fround(HEAPF32[$inertia>>2]);
    $227 = $226 > Math_fround(0.0);
    if ($227) {
     HEAPF32[$inertia>>2] = Math_fround(0.0);
     $249 = Math_fround(0.0);$inertiaChanged$0$off0 = 1;
    } else {
     $249 = $203;$inertiaChanged$0$off0 = 0;
    }
   }
   $228 = $6 & 32;
   $229 = ($228|0)==(0);
   if ($229) {
    $251 = $211;$inertiaChanged$1$off0 = $inertiaChanged$0$off0;
   } else {
    $230 = (($inertia) + 4|0);
    $231 = Math_fround(HEAPF32[$230>>2]);
    $232 = $231 > Math_fround(0.0);
    if ($232) {
     HEAPF32[$230>>2] = Math_fround(0.0);
     $251 = Math_fround(0.0);$inertiaChanged$1$off0 = 1;
    } else {
     $251 = $211;$inertiaChanged$1$off0 = $inertiaChanged$0$off0;
    }
   }
   $233 = $6 & 64;
   $234 = ($233|0)==(0);
   if ($234) {
    label = 20;
   } else {
    $235 = (($inertia) + 8|0);
    $236 = Math_fround(HEAPF32[$235>>2]);
    $237 = $236 > Math_fround(0.0);
    if ($237) {
     HEAPF32[$235>>2] = Math_fround(0.0);
     $253 = Math_fround(0.0);
    } else {
     label = 20;
    }
   }
   if ((label|0) == 20) {
    if ($inertiaChanged$1$off0) {
     $253 = $219;
    } else {
     $$pre$phi12Z2D = $190;
     break;
    }
   }
   $238 = HEAP32[$10>>2]|0;
   $239 = HEAP32[$238>>2]|0;
   $240 = (($239) + 140|0);
   $241 = HEAP32[$240>>2]|0;
   FUNCTION_TABLE_vii[$241 & 4095]($238,$inertia);
   $242 = HEAP8[$168>>0]|0;
   $243 = ($242<<24>>24)==(0);
   if ($243) {
    $244 = HEAP32[$10>>2]|0;
    $245 = HEAP32[$244>>2]|0;
    $246 = (($245) + 164|0);
    $247 = HEAP32[$246>>2]|0;
    $248 = Math_fround($249 * Math_fround(2.0));
    $250 = Math_fround($251 * Math_fround(2.0));
    $252 = Math_fround($253 * Math_fround(2.0));
    $254 = Math_fround($125 * $248);
    $255 = Math_fround($132 * $250);
    $256 = Math_fround($254 + $255);
    $257 = Math_fround($139 * $252);
    $258 = Math_fround($256 + $257);
    $259 = Math_fround($190 * $248);
    $260 = Math_fround($132 * $252);
    $261 = Math_fround($139 * $250);
    $262 = Math_fround($260 - $261);
    $263 = Math_fround($146 * $262);
    $264 = Math_fround($259 + $263);
    $265 = Math_fround($125 * $258);
    $266 = Math_fround($265 + $264);
    $267 = Math_fround($190 * $250);
    $268 = Math_fround($139 * $248);
    $269 = Math_fround($125 * $252);
    $270 = Math_fround($268 - $269);
    $271 = Math_fround($146 * $270);
    $272 = Math_fround($267 + $271);
    $273 = Math_fround($132 * $258);
    $274 = Math_fround($273 + $272);
    $275 = Math_fround($190 * $252);
    $276 = Math_fround($125 * $250);
    $277 = Math_fround($132 * $248);
    $278 = Math_fround($276 - $277);
    $279 = Math_fround($146 * $278);
    $280 = Math_fround($279 + $275);
    $281 = Math_fround($139 * $258);
    $282 = Math_fround($280 + $281);
    HEAPF32[$3>>2] = $266;
    $283 = (($3) + 4|0);
    HEAPF32[$283>>2] = $274;
    $284 = (($3) + 8|0);
    HEAPF32[$284>>2] = $282;
    FUNCTION_TABLE_viii[$247 & 4095]($244,$3,1);
    $$pre$phi12Z2D = $190;
   } else {
    $$pre$phi12Z2D = $190;
   }
  }
 } while(0);
 $285 = HEAP32[$10>>2]|0;
 $286 = HEAP32[$285>>2]|0;
 $287 = (($286) + 88|0);
 $288 = HEAP32[$287>>2]|0;
 $289 = Math_fround(HEAPF32[$31>>2]);
 $290 = Math_fround(HEAPF32[$34>>2]);
 $291 = Math_fround(HEAPF32[$37>>2]);
 $292 = Math_fround($289 * Math_fround(-2.0));
 $293 = Math_fround($290 * Math_fround(-2.0));
 $294 = Math_fround($291 * Math_fround(-2.0));
 $295 = Math_fround(HEAPF32[$66>>2]);
 $296 = Math_fround($295 * $295);
 $297 = Math_fround($296 + Math_fround(-0.5));
 $298 = Math_fround(HEAPF32[$cmassLocalPose>>2]);
 $299 = Math_fround($292 * $298);
 $300 = Math_fround(HEAPF32[$70>>2]);
 $301 = Math_fround($293 * $300);
 $302 = Math_fround($299 + $301);
 $303 = Math_fround(HEAPF32[$68>>2]);
 $304 = Math_fround($294 * $303);
 $305 = Math_fround($302 + $304);
 $306 = Math_fround($292 * $297);
 $307 = Math_fround($294 * $300);
 $308 = Math_fround($293 * $303);
 $309 = Math_fround($307 - $308);
 $310 = Math_fround($295 * $309);
 $311 = Math_fround($306 - $310);
 $312 = Math_fround($298 * $305);
 $313 = Math_fround($312 + $311);
 $314 = Math_fround($293 * $297);
 $315 = Math_fround($292 * $303);
 $316 = Math_fround($294 * $298);
 $317 = Math_fround($315 - $316);
 $318 = Math_fround($295 * $317);
 $319 = Math_fround($314 - $318);
 $320 = Math_fround($300 * $305);
 $321 = Math_fround($320 + $319);
 $322 = Math_fround($294 * $297);
 $323 = Math_fround($293 * $298);
 $324 = Math_fround($292 * $300);
 $325 = Math_fround($323 - $324);
 $326 = Math_fround($295 * $325);
 $327 = Math_fround($322 - $326);
 $328 = Math_fround($303 * $305);
 $329 = Math_fround($327 + $328);
 $330 = Math_fround(-$298);
 $331 = Math_fround(-$300);
 $332 = Math_fround(-$303);
 $333 = Math_fround($313 * Math_fround(2.0));
 $334 = Math_fround($321 * Math_fround(2.0));
 $335 = Math_fround($329 * Math_fround(2.0));
 $336 = Math_fround($125 * $333);
 $337 = Math_fround($132 * $334);
 $338 = Math_fround($336 + $337);
 $339 = Math_fround($139 * $335);
 $340 = Math_fround($339 + $338);
 $341 = Math_fround($$pre$phi12Z2D * $333);
 $342 = Math_fround($132 * $335);
 $343 = Math_fround($139 * $334);
 $344 = Math_fround($342 - $343);
 $345 = Math_fround($146 * $344);
 $346 = Math_fround($341 + $345);
 $347 = Math_fround($125 * $340);
 $348 = Math_fround($347 + $346);
 $349 = Math_fround($$pre$phi12Z2D * $334);
 $350 = Math_fround($139 * $333);
 $351 = Math_fround($125 * $335);
 $352 = Math_fround($350 - $351);
 $353 = Math_fround($146 * $352);
 $354 = Math_fround($349 + $353);
 $355 = Math_fround($132 * $340);
 $356 = Math_fround($355 + $354);
 $357 = Math_fround($$pre$phi12Z2D * $335);
 $358 = Math_fround($125 * $334);
 $359 = Math_fround($132 * $333);
 $360 = Math_fround($358 - $359);
 $361 = Math_fround($146 * $360);
 $362 = Math_fround($357 + $361);
 $363 = Math_fround($139 * $340);
 $364 = Math_fround($362 + $363);
 $365 = Math_fround($366 + $348);
 $367 = Math_fround($368 + $356);
 $369 = Math_fround($370 + $364);
 $371 = Math_fround($146 * $330);
 $372 = Math_fround($125 * $295);
 $373 = Math_fround($372 + $371);
 $374 = Math_fround($132 * $332);
 $375 = Math_fround($373 + $374);
 $376 = Math_fround($139 * $331);
 $377 = Math_fround($375 - $376);
 $378 = Math_fround($146 * $331);
 $379 = Math_fround($132 * $295);
 $380 = Math_fround($379 + $378);
 $381 = Math_fround($139 * $330);
 $382 = Math_fround($381 + $380);
 $383 = Math_fround($125 * $332);
 $384 = Math_fround($382 - $383);
 $385 = Math_fround($146 * $332);
 $386 = Math_fround($139 * $295);
 $387 = Math_fround($386 + $385);
 $388 = Math_fround($125 * $331);
 $389 = Math_fround($388 + $387);
 $390 = Math_fround($132 * $330);
 $391 = Math_fround($389 - $390);
 $392 = Math_fround($146 * $295);
 $393 = Math_fround($125 * $330);
 $394 = Math_fround($392 - $393);
 $395 = Math_fround($132 * $331);
 $396 = Math_fround($394 - $395);
 $397 = Math_fround($139 * $332);
 $398 = Math_fround($396 - $397);
 HEAPF32[$4>>2] = $377;
 $399 = (($4) + 4|0);
 HEAPF32[$399>>2] = $384;
 $400 = (($4) + 8|0);
 HEAPF32[$400>>2] = $391;
 $401 = (($4) + 12|0);
 HEAPF32[$401>>2] = $398;
 $402 = (($4) + 16|0);
 HEAPF32[$402>>2] = $365;
 $403 = (($4) + 20|0);
 HEAPF32[$403>>2] = $367;
 $404 = (($4) + 24|0);
 HEAPF32[$404>>2] = $369;
 FUNCTION_TABLE_viii[$288 & 4095]($285,$4,0);
 STACKTOP = sp;return;
}
function __ZNK9Rigidbody7GetMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 132|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$4 & 255]($1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN9Rigidbody16TransformChangedEi($this,$mask) {
 $this = $this|0;
 $mask = $mask|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0);
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $pos = 0, $pos4 = 0, $pose = 0, $pose$i2 = 0, $pose1 = 0;
 var $pose3 = 0, $rot = 0, $rot2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $0 = sp + 176|0;
 $pose$i2 = sp + 148|0;
 $pos = sp + 136|0;
 $rot = sp + 120|0;
 $pose = sp + 88|0;
 $pose1 = sp + 48|0;
 $rot2 = sp + 32|0;
 $pose3 = sp;
 $pos4 = sp + 76|0;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 71|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (__Z17GetPhysicsManagerv()|0);
 $8 = (($7) + 58|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 | $5;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $12 = HEAP32[$1>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 256|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_ii[$15 & 4095]($12)|0);
  if (!($16)) {
   STACKTOP = sp;return;
  }
 }
 $17 = (($this) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($18)|0);
 $20 = $mask & 3;
 $21 = ($20|0)!=(3);
 $22 = $mask & 8;
 $23 = ($22|0)==(0);
 $or$cond = $21 & $23;
 if (!($or$cond)) {
  __ZNK9Transform11GetPositionEv($pos,$19);
  __ZNK9Transform11GetRotationEv($rot,$19);
  $24 = Math_fround(HEAPF32[$pos>>2]);
  $25 = (($pos) + 4|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($pos) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround(HEAPF32[$rot>>2]);
  $30 = (($rot) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($rot) + 8|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($rot) + 12|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  HEAPF32[$pose>>2] = $29;
  $36 = (($pose) + 4|0);
  HEAPF32[$36>>2] = $31;
  $37 = (($pose) + 8|0);
  HEAPF32[$37>>2] = $33;
  $38 = (($pose) + 12|0);
  HEAPF32[$38>>2] = $35;
  $39 = (($pose) + 16|0);
  HEAPF32[$39>>2] = $24;
  $40 = (($pose) + 20|0);
  HEAPF32[$40>>2] = $26;
  $41 = (($pose) + 24|0);
  HEAPF32[$41>>2] = $28;
  if (!($6)) {
   $58 = HEAP32[$1>>2]|0;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 88|0);
   $61 = HEAP32[$60>>2]|0;
   FUNCTION_TABLE_viii[$61 & 4095]($58,$pose,1);
   $62 = (($this) + 92|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($63|0)==(0|0);
   if ($64) {
    STACKTOP = sp;return;
   }
   $65 = (($63) + 40|0);
   HEAP32[$65>>2] = 1;
   STACKTOP = sp;return;
  }
  $42 = $mask & 16;
  $43 = ($42|0)==(0);
  if ($43) {
   $44 = HEAP32[$1>>2]|0;
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 88|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_viii[$47 & 4095]($44,$pose,1);
  }
  $48 = (($this) + 68|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = ($49<<24>>24)==(0);
  if (!($50)) {
   $51 = HEAP32[$1>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + 224|0);
   $54 = HEAP32[$53>>2]|0;
   FUNCTION_TABLE_vii[$54 & 4095]($51,$pose);
  }
  $55 = (($this) + 88|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = $56 | 1;
  HEAP32[$55>>2] = $57;
  STACKTOP = sp;return;
 }
 $66 = $mask & 2;
 $67 = ($66|0)==(0);
 if (!($67)) {
  $68 = HEAP32[$1>>2]|0;
  $69 = HEAP32[$68>>2]|0;
  $70 = (($69) + 84|0);
  $71 = HEAP32[$70>>2]|0;
  FUNCTION_TABLE_vii[$71 & 4095]($pose1,$68);
  __ZNK9Transform11GetRotationEv($rot2,$19);
  $72 = Math_fround(HEAPF32[$rot2>>2]);
  $73 = (($rot2) + 4|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = (($rot2) + 8|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($rot2) + 12|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  HEAPF32[$pose1>>2] = $72;
  $79 = (($pose1) + 4|0);
  HEAPF32[$79>>2] = $74;
  $80 = (($pose1) + 8|0);
  HEAPF32[$80>>2] = $76;
  $81 = (($pose1) + 12|0);
  HEAPF32[$81>>2] = $78;
  if (!($6)) {
   $123 = HEAP32[$1>>2]|0;
   $124 = HEAP32[$123>>2]|0;
   $125 = (($124) + 88|0);
   $126 = HEAP32[$125>>2]|0;
   FUNCTION_TABLE_viii[$126 & 4095]($123,$pose1,1);
   $127 = (($this) + 92|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = ($128|0)==(0|0);
   if ($129) {
    STACKTOP = sp;return;
   }
   $130 = (($128) + 40|0);
   HEAP32[$130>>2] = 1;
   STACKTOP = sp;return;
  }
  $82 = $mask & 16;
  $83 = ($82|0)==(0);
  if ($83) {
   $84 = HEAP32[$1>>2]|0;
   $85 = HEAP32[$84>>2]|0;
   $86 = (($85) + 88|0);
   $87 = HEAP32[$86>>2]|0;
   FUNCTION_TABLE_viii[$87 & 4095]($84,$pose1,1);
  }
  $88 = (($this) + 68|0);
  $89 = HEAP8[$88>>0]|0;
  $90 = ($89<<24>>24)==(0);
  if (!($90)) {
   $91 = HEAP32[$1>>2]|0;
   $92 = HEAP32[$91>>2]|0;
   $93 = (($92) + 228|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (FUNCTION_TABLE_iii[$94 & 4095]($91,$pose$i2)|0);
   if (!($95)) {
    $96 = HEAP32[$1>>2]|0;
    $97 = HEAP32[$96>>2]|0;
    $98 = (($97) + 84|0);
    $99 = HEAP32[$98>>2]|0;
    FUNCTION_TABLE_vii[$99 & 4095]($0,$96);
    $100 = (($0) + 16|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = (($0) + 20|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = (($0) + 24|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = (($pose$i2) + 16|0);
    HEAPF32[$106>>2] = $101;
    $107 = (($pose$i2) + 20|0);
    HEAPF32[$107>>2] = $103;
    $108 = (($pose$i2) + 24|0);
    HEAPF32[$108>>2] = $105;
   }
   $109 = Math_fround(HEAPF32[$pose1>>2]);
   HEAPF32[$pose$i2>>2] = $109;
   $110 = Math_fround(HEAPF32[$79>>2]);
   $111 = (($pose$i2) + 4|0);
   HEAPF32[$111>>2] = $110;
   $112 = Math_fround(HEAPF32[$80>>2]);
   $113 = (($pose$i2) + 8|0);
   HEAPF32[$113>>2] = $112;
   $114 = Math_fround(HEAPF32[$81>>2]);
   $115 = (($pose$i2) + 12|0);
   HEAPF32[$115>>2] = $114;
   $116 = HEAP32[$1>>2]|0;
   $117 = HEAP32[$116>>2]|0;
   $118 = (($117) + 224|0);
   $119 = HEAP32[$118>>2]|0;
   FUNCTION_TABLE_vii[$119 & 4095]($116,$pose$i2);
  }
  $120 = (($this) + 88|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = $121 | 1;
  HEAP32[$120>>2] = $122;
  STACKTOP = sp;return;
 }
 $131 = $mask & 1;
 $132 = ($131|0)==(0);
 if ($132) {
  STACKTOP = sp;return;
 }
 $133 = HEAP32[$1>>2]|0;
 $134 = HEAP32[$133>>2]|0;
 $135 = (($134) + 84|0);
 $136 = HEAP32[$135>>2]|0;
 FUNCTION_TABLE_vii[$136 & 4095]($pose3,$133);
 __ZNK9Transform11GetPositionEv($pos4,$19);
 $137 = Math_fround(HEAPF32[$pos4>>2]);
 $138 = (($pos4) + 4|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = (($pos4) + 8|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($pose3) + 16|0);
 HEAPF32[$142>>2] = $137;
 $143 = (($pose3) + 20|0);
 HEAPF32[$143>>2] = $139;
 $144 = (($pose3) + 24|0);
 HEAPF32[$144>>2] = $141;
 if (!($6)) {
  $186 = HEAP32[$1>>2]|0;
  $187 = HEAP32[$186>>2]|0;
  $188 = (($187) + 88|0);
  $189 = HEAP32[$188>>2]|0;
  FUNCTION_TABLE_viii[$189 & 4095]($186,$pose3,1);
  $190 = (($this) + 92|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = ($191|0)==(0|0);
  if ($192) {
   STACKTOP = sp;return;
  }
  $193 = (($191) + 40|0);
  HEAP32[$193>>2] = 1;
  STACKTOP = sp;return;
 }
 $145 = $mask & 16;
 $146 = ($145|0)==(0);
 if ($146) {
  $147 = HEAP32[$1>>2]|0;
  $148 = HEAP32[$147>>2]|0;
  $149 = (($148) + 88|0);
  $150 = HEAP32[$149>>2]|0;
  FUNCTION_TABLE_viii[$150 & 4095]($147,$pose3,1);
 }
 $151 = (($this) + 68|0);
 $152 = HEAP8[$151>>0]|0;
 $153 = ($152<<24>>24)==(0);
 if (!($153)) {
  $154 = HEAP32[$1>>2]|0;
  $155 = HEAP32[$154>>2]|0;
  $156 = (($155) + 228|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = (FUNCTION_TABLE_iii[$157 & 4095]($154,$pose$i2)|0);
  if (!($158)) {
   $159 = HEAP32[$1>>2]|0;
   $160 = HEAP32[$159>>2]|0;
   $161 = (($160) + 84|0);
   $162 = HEAP32[$161>>2]|0;
   FUNCTION_TABLE_vii[$162 & 4095]($0,$159);
   $163 = Math_fround(HEAPF32[$0>>2]);
   $164 = (($0) + 4|0);
   $165 = Math_fround(HEAPF32[$164>>2]);
   $166 = (($0) + 8|0);
   $167 = Math_fround(HEAPF32[$166>>2]);
   $168 = (($0) + 12|0);
   $169 = Math_fround(HEAPF32[$168>>2]);
   HEAPF32[$pose$i2>>2] = $163;
   $170 = (($pose$i2) + 4|0);
   HEAPF32[$170>>2] = $165;
   $171 = (($pose$i2) + 8|0);
   HEAPF32[$171>>2] = $167;
   $172 = (($pose$i2) + 12|0);
   HEAPF32[$172>>2] = $169;
  }
  $173 = Math_fround(HEAPF32[$142>>2]);
  $174 = (($pose$i2) + 16|0);
  HEAPF32[$174>>2] = $173;
  $175 = Math_fround(HEAPF32[$143>>2]);
  $176 = (($pose$i2) + 20|0);
  HEAPF32[$176>>2] = $175;
  $177 = Math_fround(HEAPF32[$144>>2]);
  $178 = (($pose$i2) + 24|0);
  HEAPF32[$178>>2] = $177;
  $179 = HEAP32[$1>>2]|0;
  $180 = HEAP32[$179>>2]|0;
  $181 = (($180) + 224|0);
  $182 = HEAP32[$181>>2]|0;
  FUNCTION_TABLE_vii[$182 & 4095]($179,$pose$i2);
 }
 $183 = (($this) + 88|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = $184 | 1;
 HEAP32[$183>>2] = $185;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody22ApplyRootMotionBuiltinEP14RootMotionData($this,$rootMotion) {
 $this = $this|0;
 $rootMotion = $rootMotion|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0);
 var $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $globalVelocity = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $globalVelocity = sp + 36|0;
 $4 = (($this) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($rootMotion) + 32|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 71|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $33 = HEAP32[$5>>2]|0;
  $34 = (($33) + 84|0);
  $35 = HEAP32[$34>>2]|0;
  FUNCTION_TABLE_vii[$35 & 4095]($0,$5);
  $36 = Math_fround(HEAPF32[$0>>2]);
  $37 = (($0) + 4|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($0) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($0) + 12|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(-$36);
  $44 = Math_fround(-$38);
  $45 = HEAP32[$4>>2]|0;
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + 152|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 4095]($0,$45);
  $49 = Math_fround(HEAPF32[$0>>2]);
  $50 = (($0) + 4|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($0) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($36 * Math_fround(-2.0));
  $55 = Math_fround($38 * Math_fround(-2.0));
  $56 = Math_fround($40 * Math_fround(-2.0));
  $57 = Math_fround($54 * $43);
  $58 = Math_fround($55 * $44);
  $59 = Math_fround($40 * $56);
  $60 = Math_fround($55 * $43);
  $61 = Math_fround($56 * $43);
  $62 = Math_fround($56 * $44);
  $63 = Math_fround($54 * $42);
  $64 = Math_fround($55 * $42);
  $65 = Math_fround($42 * $56);
  $66 = Math_fround($58 - $59);
  $67 = Math_fround(Math_fround(1.0) - $66);
  $68 = Math_fround($60 - $65);
  $69 = Math_fround($61 + $64);
  $70 = Math_fround($60 + $65);
  $71 = Math_fround($70 * $49);
  $72 = Math_fround($57 - $59);
  $73 = Math_fround(Math_fround(1.0) - $72);
  $74 = Math_fround($73 * $51);
  $75 = Math_fround($71 + $74);
  $76 = Math_fround($62 - $63);
  $77 = Math_fround($76 * $53);
  $78 = Math_fround($75 + $77);
  $79 = Math_fround($61 - $64);
  $80 = Math_fround($62 + $63);
  $81 = Math_fround($57 + $58);
  $82 = Math_fround(Math_fround(1.0) - $81);
  $83 = (__Z14GetTimeManagerv()|0);
  $84 = (($83) + 116|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround(HEAPF32[$rootMotion>>2]);
  $87 = Math_fround($85 * $86);
  $88 = (($rootMotion) + 4|0);
  $89 = Math_fround(HEAPF32[$88>>2]);
  $90 = Math_fround($85 * $89);
  $91 = (($rootMotion) + 8|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = Math_fround($85 * $92);
  $94 = Math_fround($67 * $87);
  $95 = Math_fround($68 * $90);
  $96 = Math_fround($94 + $95);
  $97 = Math_fround($69 * $93);
  $98 = Math_fround($97 + $96);
  $99 = Math_fround($70 * $87);
  $100 = Math_fround($73 * $90);
  $101 = Math_fround($99 + $100);
  $102 = Math_fround($76 * $93);
  $103 = Math_fround($101 + $102);
  $104 = Math_fround($79 * $87);
  $105 = Math_fround($80 * $90);
  $106 = Math_fround($104 + $105);
  $107 = Math_fround($82 * $93);
  $108 = Math_fround($106 + $107);
  $109 = (($rootMotion) + 28|0);
  $110 = Math_fround(HEAPF32[$109>>2]);
  $111 = Math_fround($78 * $110);
  $112 = Math_fround(Math_fround(1.0) - $110);
  $113 = Math_fround($112 * $103);
  $114 = Math_fround($111 + $113);
  $115 = HEAP32[$4>>2]|0;
  $116 = HEAP32[$115>>2]|0;
  $117 = (($116) + 52|0);
  $118 = HEAP32[$117>>2]|0;
  FUNCTION_TABLE_vii[$118 & 4095]($0,$115);
  $119 = HEAP16[$0>>1]|0;
  $120 = $119 & 2;
  $121 = ($120<<16>>16)==(0);
  if ($121) {
   $122 = (__Z17GetPhysicsManagerv()|0);
   __ZN14PhysicsManager10GetGravityEv($3,$122);
   $123 = Math_fround(HEAPF32[$109>>2]);
   $124 = Math_fround($123 * Math_fround(0.0));
   $125 = Math_fround(Math_fround(1.0) - $123);
   $126 = Math_fround($124 + $125);
   $127 = Math_fround(-$126);
   $128 = Math_fround(HEAPF32[$3>>2]);
   $129 = Math_fround($128 * $127);
   $130 = (($3) + 4|0);
   $131 = Math_fround(HEAPF32[$130>>2]);
   $132 = Math_fround($131 * $127);
   $133 = (($3) + 8|0);
   $134 = Math_fround(HEAPF32[$133>>2]);
   $135 = Math_fround($134 * $127);
   $136 = (($this) + 68|0);
   $137 = HEAP8[$136>>0]|0;
   $138 = ($137<<24>>24)==(0);
   if (!($138)) {
    $139 = HEAP32[$4>>2]|0;
    $140 = HEAP32[$139>>2]|0;
    $141 = (($140) + 200|0);
    $142 = HEAP32[$141>>2]|0;
    FUNCTION_TABLE_vii[$142 & 4095]($0,$139);
    $143 = HEAP8[$0>>0]|0;
    $144 = $143 & 1;
    $145 = ($144<<24>>24)==(0);
    if ($145) {
     $146 = HEAP32[$4>>2]|0;
     $147 = HEAP32[$146>>2]|0;
     $148 = (($147) + 168|0);
     $149 = HEAP32[$148>>2]|0;
     HEAPF32[$1>>2] = $129;
     $150 = (($1) + 4|0);
     HEAPF32[$150>>2] = $132;
     $151 = (($1) + 8|0);
     HEAPF32[$151>>2] = $135;
     FUNCTION_TABLE_viiii[$149 & 511]($146,$1,0,1);
    }
   }
  }
  $152 = Math_fround($36 * Math_fround(2.0));
  $153 = Math_fround($38 * Math_fround(2.0));
  $154 = Math_fround($40 * Math_fround(2.0));
  $155 = Math_fround($36 * $152);
  $156 = Math_fround($38 * $153);
  $157 = Math_fround($40 * $154);
  $158 = Math_fround($36 * $153);
  $159 = Math_fround($36 * $154);
  $160 = Math_fround($38 * $154);
  $161 = Math_fround($152 * $42);
  $162 = Math_fround($153 * $42);
  $163 = Math_fround($42 * $154);
  $164 = (($globalVelocity) + 4|0);
  $165 = (($globalVelocity) + 8|0);
  $166 = Math_fround($156 + $157);
  $167 = Math_fround(Math_fround(1.0) - $166);
  $168 = Math_fround($167 * $98);
  $169 = Math_fround($158 - $163);
  $170 = Math_fround($169 * $114);
  $171 = Math_fround($168 + $170);
  $172 = Math_fround($159 + $162);
  $173 = Math_fround($172 * $108);
  $174 = Math_fround($173 + $171);
  HEAPF32[$globalVelocity>>2] = $174;
  $175 = Math_fround($158 + $163);
  $176 = Math_fround($175 * $98);
  $177 = Math_fround($155 + $157);
  $178 = Math_fround(Math_fround(1.0) - $177);
  $179 = Math_fround($178 * $114);
  $180 = Math_fround($176 + $179);
  $181 = Math_fround($160 - $161);
  $182 = Math_fround($181 * $108);
  $183 = Math_fround($182 + $180);
  HEAPF32[$164>>2] = $183;
  $184 = Math_fround($159 - $162);
  $185 = Math_fround($184 * $98);
  $186 = Math_fround($160 + $161);
  $187 = Math_fround($186 * $114);
  $188 = Math_fround($185 + $187);
  $189 = Math_fround($155 + $156);
  $190 = Math_fround(Math_fround(1.0) - $189);
  $191 = Math_fround($190 * $108);
  $192 = Math_fround($191 + $188);
  HEAPF32[$165>>2] = $192;
  $193 = HEAP32[$4>>2]|0;
  $194 = HEAP32[$193>>2]|0;
  $195 = (($194) + 156|0);
  $196 = HEAP32[$195>>2]|0;
  FUNCTION_TABLE_viii[$196 & 4095]($193,$globalVelocity,1);
  $197 = (($rootMotion) + 12|0);
  __ZN9Rigidbody12MoveRotationERK11Quaternionf($this,$197);
 } else {
  $13 = HEAP32[$5>>2]|0;
  $14 = (($13) + 84|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vii[$15 & 4095]($0,$5);
  $16 = (($0) + 16|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($0) + 20|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($0) + 24|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround(HEAPF32[$rootMotion>>2]);
  $23 = Math_fround($17 + $22);
  $24 = (($rootMotion) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = Math_fround($19 + $25);
  $27 = (($rootMotion) + 8|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround($21 + $28);
  HEAPF32[$2>>2] = $23;
  $30 = (($2) + 4|0);
  HEAPF32[$30>>2] = $26;
  $31 = (($2) + 8|0);
  HEAPF32[$31>>2] = $29;
  __ZN9Rigidbody11SetPositionERK8Vector3f($this,$2);
  $32 = (($rootMotion) + 12|0);
  __ZN9Rigidbody11SetRotationERK11Quaternionf($this,$32);
 }
 HEAP8[$7>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody11SetPositionERK8Vector3f($this,$position) {
 $this = $this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0;
 var $pose = 0, $pose$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 56|0;
 $pose$i = sp;
 $pose = sp + 28|0;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($pose,$2);
 $6 = Math_fround(HEAPF32[$position>>2]);
 $7 = (($position) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($position) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($pose) + 16|0);
 HEAPF32[$11>>2] = $6;
 $12 = (($pose) + 20|0);
 HEAPF32[$12>>2] = $8;
 $13 = (($pose) + 24|0);
 HEAPF32[$13>>2] = $10;
 $14 = (($this) + 71|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $52 = (($this) + 92|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $56 = HEAP32[$1>>2]|0;
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 88|0);
   $59 = HEAP32[$58>>2]|0;
   FUNCTION_TABLE_viii[$59 & 4095]($56,$pose,1);
   STACKTOP = sp;return;
  }
  $55 = (($53) + 40|0);
  HEAP32[$55>>2] = 1;
  $56 = HEAP32[$1>>2]|0;
  $57 = HEAP32[$56>>2]|0;
  $58 = (($57) + 88|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_viii[$59 & 4095]($56,$pose,1);
  STACKTOP = sp;return;
 }
 $17 = (($this) + 68|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if (!($19)) {
  $20 = HEAP32[$1>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 228|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (FUNCTION_TABLE_iii[$23 & 4095]($20,$pose$i)|0);
  if (!($24)) {
   $25 = HEAP32[$1>>2]|0;
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + 84|0);
   $28 = HEAP32[$27>>2]|0;
   FUNCTION_TABLE_vii[$28 & 4095]($0,$25);
   $29 = Math_fround(HEAPF32[$0>>2]);
   $30 = (($0) + 4|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = (($0) + 8|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = (($0) + 12|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   HEAPF32[$pose$i>>2] = $29;
   $36 = (($pose$i) + 4|0);
   HEAPF32[$36>>2] = $31;
   $37 = (($pose$i) + 8|0);
   HEAPF32[$37>>2] = $33;
   $38 = (($pose$i) + 12|0);
   HEAPF32[$38>>2] = $35;
  }
  $39 = Math_fround(HEAPF32[$11>>2]);
  $40 = (($pose$i) + 16|0);
  HEAPF32[$40>>2] = $39;
  $41 = Math_fround(HEAPF32[$12>>2]);
  $42 = (($pose$i) + 20|0);
  HEAPF32[$42>>2] = $41;
  $43 = Math_fround(HEAPF32[$13>>2]);
  $44 = (($pose$i) + 24|0);
  HEAPF32[$44>>2] = $43;
  $45 = HEAP32[$1>>2]|0;
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + 224|0);
  $48 = HEAP32[$47>>2]|0;
  FUNCTION_TABLE_vii[$48 & 4095]($45,$pose$i);
 }
 $49 = (($this) + 88|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & -2;
 HEAP32[$49>>2] = $51;
 $56 = HEAP32[$1>>2]|0;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 88|0);
 $59 = HEAP32[$58>>2]|0;
 FUNCTION_TABLE_viii[$59 & 4095]($56,$pose,1);
 STACKTOP = sp;return;
}
function __ZNK9Rigidbody11GetPositionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = (($0) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($0) + 20|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($0) + 24|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 HEAPF32[$agg$result>>2] = $7;
 $12 = (($agg$result) + 4|0);
 HEAPF32[$12>>2] = $9;
 $13 = (($agg$result) + 8|0);
 HEAPF32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody11SetRotationERK11Quaternionf($this,$rotation) {
 $this = $this|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $7 = 0;
 var $8 = Math_fround(0), $9 = 0, $pose = 0, $pose$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 56|0;
 $pose$i = sp;
 $pose = sp + 28|0;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($pose,$2);
 $6 = Math_fround(HEAPF32[$rotation>>2]);
 $7 = (($rotation) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($rotation) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($rotation) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$pose>>2] = $6;
 $13 = (($pose) + 4|0);
 HEAPF32[$13>>2] = $8;
 $14 = (($pose) + 8|0);
 HEAPF32[$14>>2] = $10;
 $15 = (($pose) + 12|0);
 HEAPF32[$15>>2] = $12;
 $16 = (($this) + 71|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $54 = (($this) + 92|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(0|0);
  if ($56) {
   $58 = HEAP32[$1>>2]|0;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($59) + 88|0);
   $61 = HEAP32[$60>>2]|0;
   FUNCTION_TABLE_viii[$61 & 4095]($58,$pose,1);
   STACKTOP = sp;return;
  }
  $57 = (($55) + 40|0);
  HEAP32[$57>>2] = 1;
  $58 = HEAP32[$1>>2]|0;
  $59 = HEAP32[$58>>2]|0;
  $60 = (($59) + 88|0);
  $61 = HEAP32[$60>>2]|0;
  FUNCTION_TABLE_viii[$61 & 4095]($58,$pose,1);
  STACKTOP = sp;return;
 }
 $19 = (($this) + 68|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 228|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (FUNCTION_TABLE_iii[$25 & 4095]($22,$pose$i)|0);
  if (!($26)) {
   $27 = HEAP32[$1>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) + 84|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vii[$30 & 4095]($0,$27);
   $31 = (($0) + 16|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = (($0) + 20|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = (($0) + 24|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = (($pose$i) + 16|0);
   HEAPF32[$37>>2] = $32;
   $38 = (($pose$i) + 20|0);
   HEAPF32[$38>>2] = $34;
   $39 = (($pose$i) + 24|0);
   HEAPF32[$39>>2] = $36;
  }
  $40 = Math_fround(HEAPF32[$pose>>2]);
  HEAPF32[$pose$i>>2] = $40;
  $41 = Math_fround(HEAPF32[$13>>2]);
  $42 = (($pose$i) + 4|0);
  HEAPF32[$42>>2] = $41;
  $43 = Math_fround(HEAPF32[$14>>2]);
  $44 = (($pose$i) + 8|0);
  HEAPF32[$44>>2] = $43;
  $45 = Math_fround(HEAPF32[$15>>2]);
  $46 = (($pose$i) + 12|0);
  HEAPF32[$46>>2] = $45;
  $47 = HEAP32[$1>>2]|0;
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + 224|0);
  $50 = HEAP32[$49>>2]|0;
  FUNCTION_TABLE_vii[$50 & 4095]($47,$pose$i);
 }
 $51 = (($this) + 88|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 & -2;
 HEAP32[$51>>2] = $53;
 $58 = HEAP32[$1>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 88|0);
 $61 = HEAP32[$60>>2]|0;
 FUNCTION_TABLE_viii[$61 & 4095]($58,$pose,1);
 STACKTOP = sp;return;
}
function __ZNK9Rigidbody11GetRotationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = Math_fround(HEAPF32[$0>>2]);
 $7 = (($0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($0) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($0) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 HEAPF32[$agg$result>>2] = $6;
 $13 = (($agg$result) + 4|0);
 HEAPF32[$13>>2] = $8;
 $14 = (($agg$result) + 8|0);
 HEAPF32[$14>>2] = $10;
 $15 = (($agg$result) + 12|0);
 HEAPF32[$15>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody12MoveRotationERK11Quaternionf($this,$rotation) {
 $this = $this|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $pose$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 84|0;
 $pose$i = sp;
 $1 = sp + 28|0;
 $2 = sp + 56|0;
 $3 = (($this) + 71|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $45 = (($this) + 40|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$46>>2]|0;
  $48 = (($47) + 88|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($47) + 84|0);
  $51 = HEAP32[$50>>2]|0;
  FUNCTION_TABLE_vii[$51 & 4095]($2,$46);
  $52 = Math_fround(HEAPF32[$rotation>>2]);
  $53 = (($rotation) + 4|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($rotation) + 8|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($rotation) + 12|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$1>>2] = $52;
  $59 = (($1) + 4|0);
  HEAPF32[$59>>2] = $54;
  $60 = (($1) + 8|0);
  HEAPF32[$60>>2] = $56;
  $61 = (($1) + 12|0);
  HEAPF32[$61>>2] = $58;
  $62 = (($1) + 16|0);
  $63 = (($2) + 16|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  HEAPF32[$62>>2] = $64;
  $65 = (($1) + 20|0);
  $66 = (($2) + 20|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$65>>2] = $67;
  $68 = (($1) + 24|0);
  $69 = (($2) + 24|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  HEAPF32[$68>>2] = $70;
  FUNCTION_TABLE_viii[$49 & 4095]($46,$1,1);
  STACKTOP = sp;return;
 }
 $6 = Math_fround(HEAPF32[$rotation>>2]);
 $7 = (($rotation) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($rotation) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($rotation) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($this) + 68|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  $16 = (($this) + 40|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 228|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_iii[$20 & 4095]($17,$pose$i)|0);
  if (!($21)) {
   $22 = HEAP32[$16>>2]|0;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 84|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vii[$25 & 4095]($0,$22);
   $26 = (($0) + 16|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = (($0) + 20|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = (($0) + 24|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = (($pose$i) + 16|0);
   HEAPF32[$32>>2] = $27;
   $33 = (($pose$i) + 20|0);
   HEAPF32[$33>>2] = $29;
   $34 = (($pose$i) + 24|0);
   HEAPF32[$34>>2] = $31;
  }
  HEAPF32[$pose$i>>2] = $6;
  $35 = (($pose$i) + 4|0);
  HEAPF32[$35>>2] = $8;
  $36 = (($pose$i) + 8|0);
  HEAPF32[$36>>2] = $10;
  $37 = (($pose$i) + 12|0);
  HEAPF32[$37>>2] = $12;
  $38 = HEAP32[$16>>2]|0;
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 224|0);
  $41 = HEAP32[$40>>2]|0;
  FUNCTION_TABLE_vii[$41 & 4095]($38,$pose$i);
 }
 $42 = (($this) + 88|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 & -2;
 HEAP32[$42>>2] = $44;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody10IsSleepingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 256|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK9Rigidbody19GetDetectCollisionsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __Z23RegisterClass_Rigidbodyv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(54,205,206,0,207);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(2)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity9Component13RegisterClassEv();
 }
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=691096+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,54,2,($0|0),96,(2557|0),0,1);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN9Rigidbody12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9Rigidbody7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(96,$$byval_copy2,1,16,691024,35)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((690904 + 8|0));
  $6 = (($3) + 28|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 32|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 36|0);
  HEAP32[$8>>2] = $3;
  $9 = (($3) + 40|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 69|0);
  HEAP8[$10>>0] = 1;
  $11 = (($3) + 92|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 88|0);
  HEAP32[$12>>2] = 0;
  $13 = (($3) + 76|0);
  HEAP32[$13>>2] = 0;
  $14 = (($3) + 80|0);
  HEAP32[$14>>2] = 0;
  $15 = (($3) + 84|0);
  HEAP8[$15>>0] = 1;
  $16 = (($3) + 85|0);
  HEAP8[$16>>0] = 1;
  $17 = (($3) + 44|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 48|0);
  HEAP32[$18>>2] = 0;
  $19 = (($3) + 52|0);
  HEAP32[$19>>2] = -1;
  STACKTOP = sp;return ($3|0);
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(691024|0),35);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch(0|0)|0;
  $25 = tempRet0;
  ___clang_call_terminate($24);
  // unreachable;
 } else {
  ___resumeException($20|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK9Rigidbody25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 54;
}
function __ZN9Rigidbody23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691112,691096,$this,0);
 __ZN9Rigidbody8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,691112,691096,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9Rigidbody8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Rigidbody8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Rigidbody8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Rigidbody8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Rigidbody23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9RigidbodyD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((562072 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   STACKTOP = sp;return;
  }
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __THREW__ = 0;
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $8 = ___cxa_find_matching_catch(0|0)|0;
   $9 = tempRet0;
   ___clang_call_terminate($8);
   // unreachable;
  } else {
   ___resumeException($4|0);
   // unreachable;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 HEAP32[$this>>2] = ((560936 + 8|0));
 __THREW__ = 0;
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  __THREW__ = 0;
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch(0|0)|0;
   $21 = tempRet0;
   ___clang_call_terminate($20);
   // unreachable;
  } else {
   $eh$lpad$body$i$i$indexZ2D = $16;
   ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
   // unreachable;
  }
 }
 __THREW__ = 0;
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  ___resumeException($10|0);
  // unreachable;
 }
 $22 = ___cxa_find_matching_catch(0|0)|0;
 $23 = tempRet0;
 $eh$lpad$body$i$i$indexZ2D = $22;
 ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
 // unreachable;
}
function __ZN9RigidbodyD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((562072 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $16 = ___cxa_find_matching_catch(0|0)|0;
   $17 = tempRet0;
   __THREW__ = 0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $20 = ___cxa_find_matching_catch(0|0)|0;
    $21 = tempRet0;
    ___clang_call_terminate($20);
    // unreachable;
   } else {
    $eh$lpad$body$i$i$i$indexZ2D = $16;
    ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $eh$lpad$body$index8Z2D = $11;$eh$lpad$body$indexZ2D = $10;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $22 = ___cxa_find_matching_catch(0|0)|0;
  $23 = tempRet0;
  $eh$lpad$body$i$i$i$indexZ2D = $22;
  ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   $4 = ___cxa_find_matching_catch()|0;
   $5 = tempRet0;
   __THREW__ = 0;
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $8 = ___cxa_find_matching_catch(0|0)|0;
    $9 = tempRet0;
    ___clang_call_terminate($8);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $5;$eh$lpad$body$indexZ2D = $4;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $eh$lpad$body$index8Z2D = $27;$eh$lpad$body$indexZ2D = $26;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN9Rigidbody8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$0>>2]);
  HEAPF32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre5;
 }
 $8 = (($this) + 60|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre6 = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $16 = $$pre6;$18 = $$pre7;
 }
 $14 = (($this) + 64|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre8 = HEAP32[$1>>2]|0;
  $$pre9 = HEAP32[$4>>2]|0;
  $22 = $$pre8;$24 = $$pre9;
 }
 $20 = (($this) + 70|0);
 $21 = (($22) + 1|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = HEAP8[$20>>0]|0;
  HEAP8[$22>>0] = $25;
  $26 = HEAP32[$1>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$1>>2] = $27;
  $30 = $27;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,1);
  $$pre10 = HEAP32[$1>>2]|0;
  $30 = $$pre10;
 }
 $28 = (($this) + 71|0);
 $29 = (($30) + 1|0);
 $31 = HEAP32[$4>>2]|0;
 $32 = ($29>>>0)<($31>>>0);
 if ($32) {
  $33 = HEAP8[$28>>0]|0;
  HEAP8[$30>>0] = $33;
  $34 = HEAP32[$1>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$1>>2] = $35;
  $38 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$28,1);
  $$pre11 = HEAP32[$1>>2]|0;
  $38 = $$pre11;
 }
 $36 = (($this) + 86|0);
 $37 = (($38) + 1|0);
 $39 = HEAP32[$4>>2]|0;
 $40 = ($37>>>0)<($39>>>0);
 if ($40) {
  $41 = HEAP8[$36>>0]|0;
  HEAP8[$38>>0] = $41;
  $42 = HEAP32[$1>>2]|0;
  $43 = (($42) + 1|0);
  HEAP32[$1>>2] = $43;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$36,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $44 = (($this) + 72|0);
 $45 = HEAP32[$1>>2]|0;
 $46 = (($45) + 4|0);
 $47 = HEAP32[$4>>2]|0;
 $48 = ($46>>>0)<($47>>>0);
 if ($48) {
  $49 = HEAP32[$44>>2]|0;
  HEAP32[$45>>2] = $49;
  HEAP32[$1>>2] = $46;
  $52 = $46;$54 = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$44,4);
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $52 = $$pre12;$54 = $$pre13;
 }
 $50 = (($this) + 76|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)<($54>>>0);
 if ($53) {
  $55 = HEAP32[$50>>2]|0;
  HEAP32[$52>>2] = $55;
  HEAP32[$1>>2] = $51;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$50,4);
  STACKTOP = sp;return;
 }
}
function __ZN9Rigidbody8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i9 = 0, $$pre$phi$i$i$i10Z2D = 0, $$pre$phi$i$i$i5Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $0;$13 = $$pre;$15 = $$pre15;$9 = $$pre$i$i$i1;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $0;$13 = $3;$15 = $5;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $10;
 $11 = (($this) + 60|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i4 = HEAP32[$11>>2]|0;
  $$pre16 = HEAP32[$1>>2]|0;
  $$pre17 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i5Z2D = $11;$18 = $$pre$i$i$i4;$22 = $$pre16;$24 = $$pre17;
 } else {
  $16 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$1>>2] = $12;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i5Z2D = $11;$18 = $17;$22 = $12;$24 = $15;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$i5Z2D>>2] = $19;
 $20 = (($this) + 64|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre$i$i$i9 = HEAP32[$20>>2]|0;
  $$pre18 = HEAP32[$1>>2]|0;
  $$pre19 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i10Z2D = $20;$27 = $$pre$i$i$i9;$31 = $$pre18;$33 = $$pre19;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $26 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i10Z2D = $20;$27 = $26;$31 = $21;$33 = $24;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$$pre$phi$i$i$i10Z2D>>2] = $28;
 $29 = (($this) + 70|0);
 $30 = (($31) + 1|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$29,1);
  $$pre20 = HEAP32[$1>>2]|0;
  $39 = $$pre20;
 } else {
  $34 = HEAP8[$31>>0]|0;
  HEAP8[$29>>0] = $34;
  $35 = HEAP32[$1>>2]|0;
  $36 = (($35) + 1|0);
  HEAP32[$1>>2] = $36;
  $39 = $36;
 }
 $37 = (($this) + 71|0);
 $38 = (($39) + 1|0);
 $40 = HEAP32[$4>>2]|0;
 $41 = ($38>>>0)>($40>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$37,1);
  $$pre21 = HEAP32[$1>>2]|0;
  $47 = $$pre21;
 } else {
  $42 = HEAP8[$39>>0]|0;
  HEAP8[$37>>0] = $42;
  $43 = HEAP32[$1>>2]|0;
  $44 = (($43) + 1|0);
  HEAP32[$1>>2] = $44;
  $47 = $44;
 }
 $45 = (($this) + 86|0);
 $46 = (($47) + 1|0);
 $48 = HEAP32[$4>>2]|0;
 $49 = ($46>>>0)>($48>>>0);
 if ($49) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$45,1);
 } else {
  $50 = HEAP8[$47>>0]|0;
  HEAP8[$45>>0] = $50;
  $51 = HEAP32[$1>>2]|0;
  $52 = (($51) + 1|0);
  HEAP32[$1>>2] = $52;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $53 = (($this) + 72|0);
 $54 = HEAP32[$1>>2]|0;
 $55 = (($54) + 4|0);
 $56 = HEAP32[$4>>2]|0;
 $57 = ($55>>>0)>($56>>>0);
 if ($57) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$53,4);
  $$pre$i$i$i13 = HEAP32[$53>>2]|0;
  $$pre22 = HEAP32[$1>>2]|0;
  $$pre23 = HEAP32[$4>>2]|0;
  $59 = $$pre$i$i$i13;$63 = $$pre22;$65 = $$pre23;
 } else {
  $58 = HEAP32[$54>>2]|0;
  HEAP32[$53>>2] = $58;
  HEAP32[$1>>2] = $55;
  $59 = $58;$63 = $55;$65 = $56;
 }
 $60 = (_llvm_bswap_i32(($59|0))|0);
 HEAP32[$53>>2] = $60;
 $61 = (($this) + 76|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)>($65>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$61,4);
  $$pre$i$i$i = HEAP32[$61>>2]|0;
  $67 = $$pre$i$i$i;
  $68 = (_llvm_bswap_i32(($67|0))|0);
  HEAP32[$61>>2] = $68;
  STACKTOP = sp;return;
 } else {
  $66 = HEAP32[$63>>2]|0;
  HEAP32[$61>>2] = $66;
  HEAP32[$1>>2] = $62;
  $67 = $66;
  $68 = (_llvm_bswap_i32(($67|0))|0);
  HEAP32[$61>>2] = $68;
  STACKTOP = sp;return;
 }
}
function __ZN9Rigidbody8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre5;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 60|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre6 = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $16 = $$pre6;$18 = $$pre7;
 } else {
  $13 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 64|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  $$pre8 = HEAP32[$1>>2]|0;
  $$pre9 = HEAP32[$4>>2]|0;
  $22 = $$pre8;$24 = $$pre9;
 } else {
  $19 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 }
 $20 = (($this) + 70|0);
 $21 = (($22) + 1|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,1);
  $$pre10 = HEAP32[$1>>2]|0;
  $30 = $$pre10;
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$1>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$1>>2] = $27;
  $30 = $27;
 }
 $28 = (($this) + 71|0);
 $29 = (($30) + 1|0);
 $31 = HEAP32[$4>>2]|0;
 $32 = ($29>>>0)>($31>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$28,1);
  $$pre11 = HEAP32[$1>>2]|0;
  $38 = $$pre11;
 } else {
  $33 = HEAP8[$30>>0]|0;
  HEAP8[$28>>0] = $33;
  $34 = HEAP32[$1>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$1>>2] = $35;
  $38 = $35;
 }
 $36 = (($this) + 86|0);
 $37 = (($38) + 1|0);
 $39 = HEAP32[$4>>2]|0;
 $40 = ($37>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$36,1);
 } else {
  $41 = HEAP8[$38>>0]|0;
  HEAP8[$36>>0] = $41;
  $42 = HEAP32[$1>>2]|0;
  $43 = (($42) + 1|0);
  HEAP32[$1>>2] = $43;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $44 = (($this) + 72|0);
 $45 = HEAP32[$1>>2]|0;
 $46 = (($45) + 4|0);
 $47 = HEAP32[$4>>2]|0;
 $48 = ($46>>>0)>($47>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$44,4);
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $52 = $$pre12;$54 = $$pre13;
 } else {
  $49 = HEAP32[$45>>2]|0;
  HEAP32[$44>>2] = $49;
  HEAP32[$1>>2] = $46;
  $52 = $46;$54 = $47;
 }
 $50 = (($this) + 76|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)>($54>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$50,4);
  STACKTOP = sp;return;
 } else {
  $55 = HEAP32[$52>>2]|0;
  HEAP32[$50>>2] = $55;
  HEAP32[$1>>2] = $51;
  STACKTOP = sp;return;
 }
}
function __ZN9Rigidbody8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i10 = 0, $$sum$i$i$i$i$i2 = 0, $$sum$i$i$i$i$i7 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i11 = 0, $$sum1$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i9 = 0, $freezeRotation = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i9 = sp;
 $freezeRotation = sp + 4|0;
 __ZN5Unity9Component8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,691120,0);
 $1 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,691128,0);
 $2 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$2,691136,0);
 $3 = (($this) + 70|0);
 $4 = HEAP32[580544>>2]|0;
 $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,691152,$4,$converter$i$i9,0)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = ($5|0)>(0);
  do {
   if ($7) {
    $8 = (($transfer) + 12|0);
    $9 = (($transfer) + 80|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($transfer) + 16|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($transfer) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($transfer) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = Math_imul($18, $16)|0;
    $$sum$i$i$i$i$i = (($12) - ($19))|0;
    $20 = (($14) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$8>>2] = $20;
    $21 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($21)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $22 = (($14) + ($$sum1$i$i$i$i$i)|0);
     $23 = (($transfer) + 20|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($22>>>0)>($24>>>0);
     if (!($25)) {
      $26 = HEAP8[$20>>0]|0;
      HEAP8[$3>>0] = $26;
      $27 = HEAP32[$8>>2]|0;
      $28 = (($27) + 1|0);
      HEAP32[$8>>2] = $28;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($8,$3,1);
   } else {
    $29 = HEAP32[$converter$i$i9>>2]|0;
    $30 = ($29|0)==(0|0);
    if (!($30)) {
     (FUNCTION_TABLE_iii[$29 & 4095]($3,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $31 = (($this) + 71|0);
 $32 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,691168,$4,$converter$i$i9,0)|0);
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = ($32|0)>(0);
  do {
   if ($34) {
    $35 = (($transfer) + 12|0);
    $36 = (($transfer) + 80|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($transfer) + 16|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($transfer) + 28|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($transfer) + 32|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = Math_imul($45, $43)|0;
    $$sum$i$i$i$i$i2 = (($39) - ($46))|0;
    $47 = (($41) + ($$sum$i$i$i$i$i2)|0);
    HEAP32[$35>>2] = $47;
    $48 = ($$sum$i$i$i$i$i2|0)<(0);
    if (!($48)) {
     $$sum1$i$i$i$i$i3 = (($$sum$i$i$i$i$i2) + 1)|0;
     $49 = (($41) + ($$sum1$i$i$i$i$i3)|0);
     $50 = (($transfer) + 20|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($49>>>0)>($51>>>0);
     if (!($52)) {
      $53 = HEAP8[$47>>0]|0;
      HEAP8[$31>>0] = $53;
      $54 = HEAP32[$35>>2]|0;
      $55 = (($54) + 1|0);
      HEAP32[$35>>2] = $55;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($35,$31,1);
   } else {
    $56 = HEAP32[$converter$i$i9>>2]|0;
    $57 = ($56|0)==(0|0);
    if (!($57)) {
     (FUNCTION_TABLE_iii[$56 & 4095]($31,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $58 = (($this) + 86|0);
 $59 = HEAP32[580744>>2]|0;
 $60 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,691184,$59,$converter$i$i9,0)|0);
 $61 = ($60|0)==(0);
 if (!($61)) {
  $62 = ($60|0)>(0);
  do {
   if ($62) {
    $63 = (($transfer) + 12|0);
    $64 = (($transfer) + 80|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($65) + 12|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($transfer) + 16|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($transfer) + 28|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($transfer) + 32|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = Math_imul($73, $71)|0;
    $$sum$i$i$i$i$i7 = (($67) - ($74))|0;
    $75 = (($69) + ($$sum$i$i$i$i$i7)|0);
    HEAP32[$63>>2] = $75;
    $76 = ($$sum$i$i$i$i$i7|0)<(0);
    if (!($76)) {
     $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
     $77 = (($69) + ($$sum1$i$i$i$i$i8)|0);
     $78 = (($transfer) + 20|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($77>>>0)>($79>>>0);
     if (!($80)) {
      $81 = HEAP8[$75>>0]|0;
      HEAP8[$58>>0] = $81;
      $82 = HEAP32[$63>>2]|0;
      $83 = (($82) + 1|0);
      HEAP32[$63>>2] = $83;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($63,$58,1);
   } else {
    $84 = HEAP32[$converter$i$i9>>2]|0;
    $85 = ($84|0)==(0|0);
    if (!($85)) {
     (FUNCTION_TABLE_iii[$84 & 4095]($58,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $86 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,1)|0);
 if (!($86)) {
  $115 = (($this) + 72|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$115,691224,0);
  $116 = (($this) + 76|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$116,691240,0);
  STACKTOP = sp;return;
 }
 $87 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,691200,$4,$converter$i$i9,0)|0);
 $88 = ($87|0)==(0);
 if (!($88)) {
  $89 = ($87|0)>(0);
  do {
   if ($89) {
    $90 = (($transfer) + 12|0);
    $91 = (($transfer) + 80|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = (($92) + 12|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($transfer) + 16|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($transfer) + 28|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (($transfer) + 32|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = Math_imul($100, $98)|0;
    $$sum$i$i$i$i$i10 = (($94) - ($101))|0;
    $102 = (($96) + ($$sum$i$i$i$i$i10)|0);
    HEAP32[$90>>2] = $102;
    $103 = ($$sum$i$i$i$i$i10|0)<(0);
    if (!($103)) {
     $$sum1$i$i$i$i$i11 = (($$sum$i$i$i$i$i10) + 1)|0;
     $104 = (($96) + ($$sum1$i$i$i$i$i11)|0);
     $105 = (($transfer) + 20|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ($104>>>0)>($106>>>0);
     if (!($107)) {
      $108 = HEAP8[$102>>0]|0;
      HEAP8[$freezeRotation>>0] = $108;
      $$sum = (($$sum$i$i$i$i$i10) + 1)|0;
      $109 = (($96) + ($$sum)|0);
      HEAP32[$90>>2] = $109;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($90,$freezeRotation,1);
   } else {
    $110 = HEAP32[$converter$i$i9>>2]|0;
    $111 = ($110|0)==(0|0);
    if (!($111)) {
     (FUNCTION_TABLE_iii[$110 & 4095]($freezeRotation,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $112 = HEAP8[$freezeRotation>>0]|0;
 $113 = ($112<<24>>24)==(0);
 $114 = (($this) + 72|0);
 if ($113) {
  HEAP32[$114>>2] = 0;
  $116 = (($this) + 76|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$116,691240,0);
  STACKTOP = sp;return;
 } else {
  HEAP32[$114>>2] = 112;
  $116 = (($this) + 76|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$116,691240,0);
  STACKTOP = sp;return;
 }
}
function __ZN9Rigidbody8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 56|0);
 $1 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691120,$1,$0,2048);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691128,$1,$8,2048);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691136,$1,$13,2048);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 70|0);
 $19 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691152,$19,$18,2048);
 $20 = HEAP32[$2>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$5>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($this) + 71|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691168,$19,$24,0);
 $25 = HEAP32[$2>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$5>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 86|0);
 $30 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691184,$30,$29,0);
 $31 = HEAP32[$2>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$5>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $35 = (($this) + 72|0);
 $36 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691224,$36,$35,4194305);
 $37 = HEAP32[$2>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$5>>2]|0;
 $40 = ((($38) + (($39*24)|0)|0) + 12|0);
 HEAP32[$40>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $41 = (($this) + 76|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,691240,$36,$41,0);
 $42 = HEAP32[$2>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$5>>2]|0;
 $45 = ((($43) + (($44*24)|0)|0) + 12|0);
 HEAP32[$45>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNK14SphereCollider15GetScaledRadiusERK8Vector3f($this,$additionalScale) {
 $this = $this|0;
 $additionalScale = $additionalScale|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($2)|0);
 __ZNK9Transform18GetWorldScaleLossyEv($0,$3);
 $4 = Math_fround(HEAPF32[$0>>2]);
 $5 = Math_fround(HEAPF32[$additionalScale>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($additionalScale) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = (($0) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($additionalScale) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($13 * $15);
 $17 = $6 < Math_fround(0.0);
 if ($17) {
  $18 = Math_fround(-$6);
  $22 = $18;
 } else {
  $22 = $6;
 }
 $19 = $11 < Math_fround(0.0);
 if ($19) {
  $20 = Math_fround(-$11);
  $23 = $20;
 } else {
  $23 = $11;
 }
 $21 = $22 < $23;
 $24 = $16 < Math_fround(0.0);
 if ($24) {
  $25 = Math_fround(-$16);
  $28 = $25;
 } else {
  $28 = $16;
 }
 $26 = $21 ? $23 : $22;
 $27 = $26 < $28;
 $29 = $27 ? $28 : $26;
 $30 = (($this) + 52|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $29);
 $33 = $32 < Math_fround(0.0);
 if (!($33)) {
  $36 = $32;
  $35 = $36 < Math_fround(9.99999974737875163555E-6);
  $37 = $35 ? Math_fround(9.99999974737875163555E-6) : $36;
  STACKTOP = sp;return (Math_fround($37));
 }
 $34 = Math_fround(-$32);
 $36 = $34;
 $35 = $36 < Math_fround(9.99999974737875163555E-6);
 $37 = $35 ? Math_fround(9.99999974737875163555E-6) : $36;
 STACKTOP = sp;return (Math_fround($37));
}
function __ZNK14SphereCollider15GetGlobalCenterEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($1)|0);
 $3 = (($this) + 56|0);
 __ZNK9Transform14TransformPointERK8Vector3f($agg$result,$2,$3);
 STACKTOP = sp;return;
}
function __ZN13WheelCollider16RecreateColliderEPK9Rigidbody($this,$ignoreCollider) {
 $this = $this|0;
 $ignoreCollider = $ignoreCollider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZNK5Unity10GameObject8IsActiveEv($1)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 37|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 136|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($this,$ignoreCollider);
 STACKTOP = sp;return;
}
function __ZN13WheelCollider37UpdateVehicleSpringCMOffsetsAndMassesEP9RigidbodyPN5physx16PxVehicleNoDriveEf($rigidBody,$vehicleNoDrive,$actorMass) {
 $rigidBody = $rigidBody|0;
 $vehicleNoDrive = $vehicleNoDrive|0;
 $actorMass = Math_fround($actorMass);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $9 = 0, $exitcond = 0, $exitcond18 = 0, $exitcond19 = 0, $forceAppPointCMOffset = 0, $i$013 = 0, $i1$08 = 0, $i2$03 = 0, $j$04 = 0, $numActiveWheels$0$lcssa = 0, $numActiveWheels$014 = 0, $numActiveWheels$1 = 0, $scale$i2 = 0;
 var $sprungMassCoordinates = 0, $suspData = 0, $wheelCMOfffset = 0, $wheelIds = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 496|0;
 $scale$i2 = sp + 416|0;
 $sprungMassCoordinates = sp;
 $wheelIds = sp + 240|0;
 $wheelCMOfffset = sp + 320|0;
 $forceAppPointCMOffset = sp + 332|0;
 $0 = sp + 344|0;
 $1 = sp + 356|0;
 $suspData = sp + 368|0;
 $2 = (($vehicleNoDrive) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($vehicleNoDrive) + 8|0);
 $5 = ($3|0)==(0);
 if ($5) {
  $numActiveWheels$0$lcssa = 0;
 } else {
  $6 = (($vehicleNoDrive) + 72|0);
  $7 = (($scale$i2) + 4|0);
  $8 = (($scale$i2) + 4|0);
  $9 = (($scale$i2) + 4|0);
  $10 = (($wheelCMOfffset) + 4|0);
  $11 = (($wheelCMOfffset) + 8|0);
  $i$013 = 0;$numActiveWheels$014 = 0;
  while(1) {
   $12 = (__ZNK5physx22PxVehicleWheelsSimData18getIsWheelDisabledEj($4,$i$013)|0);
   if ($12) {
    $numActiveWheels$1 = $numActiveWheels$014;
   } else {
    $13 = (__ZNK5physx22PxVehicleWheelsDynData11getUserDataEj($6,$i$013)|0);
    $14 = (($13) + 140|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (__ZNK5physx22PxVehicleWheelsSimData22getSuspTravelDirectionEj($4,$15)|0);
    $17 = (($13) + 76|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = (($13) + 24|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($20)|0);
    __ZNK9Transform18GetWorldScaleLossyEv($scale$i2,$21);
    $22 = (($13) + 80|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = Math_fround(HEAPF32[$7>>2]);
    $25 = Math_fround($23 * $24);
    $26 = $25 < Math_fround(0.0);
    if ($26) {
     $27 = Math_fround(-$25);
     $29 = $27;
    } else {
     $29 = $25;
    }
    $28 = $29 < Math_fround(9.99999974737875163555E-6);
    $30 = $28 ? Math_fround(9.99999974737875163555E-6) : $29;
    $31 = HEAP32[$19>>2]|0;
    $32 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($31)|0);
    __ZNK9Transform18GetWorldScaleLossyEv($scale$i2,$32);
    $33 = (($13) + 64|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = Math_fround(HEAPF32[$8>>2]);
    $36 = Math_fround($34 * $35);
    $37 = $36 < Math_fround(0.0);
    if ($37) {
     $38 = Math_fround(-$36);
     $40 = $38;
    } else {
     $40 = $36;
    }
    $39 = $40 < Math_fround(9.99999974737875163555E-6);
    $41 = $39 ? Math_fround(9.99999974737875163555E-6) : $40;
    $42 = HEAP32[$19>>2]|0;
    $43 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($42)|0);
    __ZNK9Transform18GetWorldScaleLossyEv($scale$i2,$43);
    $44 = (($13) + 84|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = Math_fround(HEAPF32[$9>>2]);
    $47 = Math_fround($45 * $46);
    $48 = $47 < Math_fround(0.0);
    if ($48) {
     $49 = Math_fround(-$47);
     $51 = $49;
    } else {
     $51 = $47;
    }
    $50 = $51 < Math_fround(9.99999974737875163555E-6);
    $52 = $50 ? Math_fround(9.99999974737875163555E-6) : $51;
    __ZN13WheelCollider30ComputeWheelCentreOfMassOffsetEP9RigidbodyRKN5physx6PxVec3EffffRS3_S6_($13,$rigidBody,$16,$18,$30,$52,$41,$wheelCMOfffset,$forceAppPointCMOffset);
    __ZN5physx22PxVehicleWheelsSimData20setWheelCentreOffsetEjRKNS_6PxVec3E($4,$15,$wheelCMOfffset);
    __ZN5physx22PxVehicleWheelsSimData26setTireForceAppPointOffsetEjRKNS_6PxVec3E($4,$15,$forceAppPointCMOffset);
    __ZN5physx22PxVehicleWheelsSimData26setSuspForceAppPointOffsetEjRKNS_6PxVec3E($4,$15,$forceAppPointCMOffset);
    $53 = Math_fround(HEAPF32[$wheelCMOfffset>>2]);
    $54 = (($sprungMassCoordinates) + (($numActiveWheels$014*12)|0)|0);
    HEAPF32[$54>>2] = $53;
    $55 = Math_fround(HEAPF32[$10>>2]);
    $56 = ((($sprungMassCoordinates) + (($numActiveWheels$014*12)|0)|0) + 4|0);
    HEAPF32[$56>>2] = $55;
    $57 = Math_fround(HEAPF32[$11>>2]);
    $58 = ((($sprungMassCoordinates) + (($numActiveWheels$014*12)|0)|0) + 8|0);
    HEAPF32[$58>>2] = $57;
    $59 = (($wheelIds) + ($numActiveWheels$014<<2)|0);
    HEAP32[$59>>2] = $15;
    $60 = (($numActiveWheels$014) + 1)|0;
    $numActiveWheels$1 = $60;
   }
   $61 = (($i$013) + 1)|0;
   $exitcond19 = ($61|0)==($3|0);
   if ($exitcond19) {
    $numActiveWheels$0$lcssa = $numActiveWheels$1;
    break;
   } else {
    $i$013 = $61;$numActiveWheels$014 = $numActiveWheels$1;
   }
  }
 }
 __ZNK9Rigidbody15GetCenterOfMassEv($1,$rigidBody);
 $62 = Math_fround(HEAPF32[$1>>2]);
 $63 = (($1) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($1) + 8|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 HEAPF32[$0>>2] = $62;
 $67 = (($0) + 4|0);
 HEAPF32[$67>>2] = $64;
 $68 = (($0) + 8|0);
 HEAPF32[$68>>2] = $66;
 __ZN5physx28PxVehicleComputeSprungMassesEjPKNS_6PxVec3ERS1_fjPf($numActiveWheels$0$lcssa,$sprungMassCoordinates,$0,$actorMass,1,$scale$i2);
 $69 = ($numActiveWheels$0$lcssa|0)==(0);
 if ($69) {
  STACKTOP = sp;return;
 } else {
  $i1$08 = 0;
 }
 while(1) {
  $73 = (($scale$i2) + ($i1$08<<2)|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = $74 < Math_fround(0.0);
  $71 = (($i1$08) + 1)|0;
  if ($75) {
   label = 17;
   break;
  }
  $70 = ($71>>>0)<($numActiveWheels$0$lcssa>>>0);
  if ($70) {
   $i1$08 = $71;
  } else {
   break;
  }
 }
 if ((label|0) == 17) {
  $76 = (Math_fround(($numActiveWheels$0$lcssa>>>0)));
  $77 = Math_fround($actorMass / $76);
  $j$04 = 0;
  while(1) {
   $78 = (($scale$i2) + ($j$04<<2)|0);
   HEAPF32[$78>>2] = $77;
   $79 = (($j$04) + 1)|0;
   $exitcond18 = ($79|0)==($numActiveWheels$0$lcssa|0);
   if ($exitcond18) {
    break;
   } else {
    $j$04 = $79;
   }
  }
 }
 if ($69) {
  STACKTOP = sp;return;
 }
 $72 = (($suspData) + 16|0);
 $i2$03 = 0;
 while(1) {
  $80 = (($wheelIds) + ($i2$03<<2)|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($scale$i2) + ($i2$03<<2)|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (__ZNK5physx22PxVehicleWheelsSimData17getSuspensionDataEj($4,$81)|0);
  dest=$suspData+0|0; src=$84+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $85 = $83 < Math_fround(9.99999974737875163555E-6);
  $86 = $85 ? Math_fround(9.99999974737875163555E-6) : $83;
  HEAPF32[$72>>2] = $86;
  __ZN5physx22PxVehicleWheelsSimData17setSuspensionDataEjRKNS_23PxVehicleSuspensionDataE($4,$81,$suspData);
  $87 = (($i2$03) + 1)|0;
  $exitcond = ($87|0)==($numActiveWheels$0$lcssa|0);
  if ($exitcond) {
   break;
  } else {
   $i2$03 = $87;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13WheelCollider30ComputeWheelCentreOfMassOffsetEP9RigidbodyRKN5physx6PxVec3EffffRS3_S6_($this,$rigidbody,$suspTravelDirection,$springTargetPosition,$suspensionDistance,$forceAppPointDistance,$wheelRadius,$wheelCMOffset,$forceAppCMOffset) {
 $this = $this|0;
 $rigidbody = $rigidbody|0;
 $suspTravelDirection = $suspTravelDirection|0;
 $springTargetPosition = Math_fround($springTargetPosition);
 $suspensionDistance = Math_fround($suspensionDistance);
 $forceAppPointDistance = Math_fround($forceAppPointDistance);
 $wheelRadius = Math_fround($wheelRadius);
 $wheelCMOffset = $wheelCMOffset|0;
 $forceAppCMOffset = $forceAppCMOffset|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $a = 0, $bodyToWheel = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $a = sp + 28|0;
 $bodyToWheel = sp;
 $0 = (($rigidbody) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($a,$1);
 __ZNK13WheelCollider29FindRigidBodyToWheelTransformEPK9Rigidbody($bodyToWheel,$this,0);
 $5 = (($this) + 52|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 56|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 60|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($6 * Math_fround(2.0));
 $12 = Math_fround($8 * Math_fround(2.0));
 $13 = Math_fround($10 * Math_fround(2.0));
 $14 = (($bodyToWheel) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 * $15);
 $17 = Math_fround($16 + Math_fround(-0.5));
 $18 = Math_fround(HEAPF32[$bodyToWheel>>2]);
 $19 = Math_fround($11 * $18);
 $20 = (($bodyToWheel) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($12 * $21);
 $23 = Math_fround($19 + $22);
 $24 = (($bodyToWheel) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($13 * $25);
 $27 = Math_fround($23 + $26);
 $28 = Math_fround($11 * $17);
 $29 = Math_fround($13 * $21);
 $30 = Math_fround($12 * $25);
 $31 = Math_fround($29 - $30);
 $32 = Math_fround($15 * $31);
 $33 = Math_fround($28 + $32);
 $34 = Math_fround($18 * $27);
 $35 = Math_fround($34 + $33);
 $36 = Math_fround($12 * $17);
 $37 = Math_fround($11 * $25);
 $38 = Math_fround($13 * $18);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($15 * $39);
 $41 = Math_fround($36 + $40);
 $42 = Math_fround($21 * $27);
 $43 = Math_fround($42 + $41);
 $44 = Math_fround($13 * $17);
 $45 = Math_fround($12 * $18);
 $46 = Math_fround($11 * $21);
 $47 = Math_fround($45 - $46);
 $48 = Math_fround($15 * $47);
 $49 = Math_fround($44 + $48);
 $50 = Math_fround($25 * $27);
 $51 = Math_fround($49 + $50);
 $52 = (($bodyToWheel) + 16|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = Math_fround($53 + $35);
 $55 = (($bodyToWheel) + 20|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 + $43);
 $58 = (($bodyToWheel) + 24|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 + $51);
 $61 = (($a) + 16|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($a) + 20|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($a) + 24|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($62 * Math_fround(-2.0));
 $68 = Math_fround($64 * Math_fround(-2.0));
 $69 = Math_fround($66 * Math_fround(-2.0));
 $70 = (($a) + 12|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = Math_fround($71 * $71);
 $73 = Math_fround($72 + Math_fround(-0.5));
 $74 = Math_fround(HEAPF32[$a>>2]);
 $75 = Math_fround($67 * $74);
 $76 = (($a) + 4|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($68 * $77);
 $79 = Math_fround($75 + $78);
 $80 = (($a) + 8|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($69 * $81);
 $83 = Math_fround($79 + $82);
 $84 = Math_fround($67 * $73);
 $85 = Math_fround($69 * $77);
 $86 = Math_fround($68 * $81);
 $87 = Math_fround($85 - $86);
 $88 = Math_fround($71 * $87);
 $89 = Math_fround($84 - $88);
 $90 = Math_fround($74 * $83);
 $91 = Math_fround($90 + $89);
 $92 = Math_fround($68 * $73);
 $93 = Math_fround($67 * $81);
 $94 = Math_fround($69 * $74);
 $95 = Math_fround($93 - $94);
 $96 = Math_fround($71 * $95);
 $97 = Math_fround($92 - $96);
 $98 = Math_fround($77 * $83);
 $99 = Math_fround($98 + $97);
 $100 = Math_fround($69 * $73);
 $101 = Math_fround($68 * $74);
 $102 = Math_fround($67 * $77);
 $103 = Math_fround($101 - $102);
 $104 = Math_fround($71 * $103);
 $105 = Math_fround($100 - $104);
 $106 = Math_fround($81 * $83);
 $107 = Math_fround($105 + $106);
 $108 = Math_fround(-$74);
 $109 = Math_fround(-$77);
 $110 = Math_fround(-$81);
 $111 = Math_fround($54 * Math_fround(2.0));
 $112 = Math_fround($57 * Math_fround(2.0));
 $113 = Math_fround($60 * Math_fround(2.0));
 $114 = Math_fround($111 * $108);
 $115 = Math_fround($112 * $109);
 $116 = Math_fround($114 + $115);
 $117 = Math_fround($113 * $110);
 $118 = Math_fround($116 + $117);
 $119 = Math_fround($111 * $73);
 $120 = Math_fround($113 * $109);
 $121 = Math_fround($112 * $110);
 $122 = Math_fround($120 - $121);
 $123 = Math_fround($71 * $122);
 $124 = Math_fround($119 + $123);
 $125 = Math_fround($118 * $108);
 $126 = Math_fround($125 + $124);
 $127 = Math_fround($112 * $73);
 $128 = Math_fround($111 * $110);
 $129 = Math_fround($113 * $108);
 $130 = Math_fround($128 - $129);
 $131 = Math_fround($71 * $130);
 $132 = Math_fround($127 + $131);
 $133 = Math_fround($118 * $109);
 $134 = Math_fround($133 + $132);
 $135 = Math_fround($113 * $73);
 $136 = Math_fround($112 * $108);
 $137 = Math_fround($111 * $109);
 $138 = Math_fround($136 - $137);
 $139 = Math_fround($71 * $138);
 $140 = Math_fround($135 + $139);
 $141 = Math_fround($118 * $110);
 $142 = Math_fround($140 + $141);
 $143 = Math_fround($91 + $126);
 $144 = Math_fround($99 + $134);
 $145 = Math_fround($107 + $142);
 HEAPF32[$wheelCMOffset>>2] = $143;
 $146 = (($wheelCMOffset) + 4|0);
 HEAPF32[$146>>2] = $144;
 $147 = (($wheelCMOffset) + 8|0);
 HEAPF32[$147>>2] = $145;
 $148 = Math_fround(Math_fround(1.0) - $springTargetPosition);
 $149 = Math_fround(HEAPF32[$suspTravelDirection>>2]);
 $150 = Math_fround($148 * $149);
 $151 = (($suspTravelDirection) + 4|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = Math_fround($148 * $152);
 $154 = (($suspTravelDirection) + 8|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = Math_fround($148 * $155);
 $157 = Math_fround($150 * $suspensionDistance);
 $158 = Math_fround($153 * $suspensionDistance);
 $159 = Math_fround($156 * $suspensionDistance);
 $160 = Math_fround($157 + $143);
 HEAPF32[$wheelCMOffset>>2] = $160;
 $161 = Math_fround($158 + $144);
 HEAPF32[$146>>2] = $161;
 $162 = Math_fround($159 + $145);
 HEAPF32[$147>>2] = $162;
 $163 = Math_fround($wheelRadius - $forceAppPointDistance);
 $164 = Math_fround(HEAPF32[$suspTravelDirection>>2]);
 $165 = Math_fround($163 * $164);
 $166 = Math_fround(HEAPF32[$151>>2]);
 $167 = Math_fround($163 * $166);
 $168 = Math_fround(HEAPF32[$154>>2]);
 $169 = Math_fround($163 * $168);
 $170 = Math_fround($165 + $160);
 $171 = Math_fround($167 + $161);
 $172 = Math_fround($162 + $169);
 HEAPF32[$forceAppCMOffset>>2] = $170;
 $173 = (($forceAppCMOffset) + 4|0);
 HEAPF32[$173>>2] = $171;
 $174 = (($forceAppCMOffset) + 8|0);
 HEAPF32[$174>>2] = $172;
 STACKTOP = sp;return;
}
function __ZNK13WheelCollider29FindRigidBodyToWheelTransformEPK9Rigidbody($agg$result,$this,$ignoreAttachRigidbody) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $ignoreAttachRigidbody = $ignoreAttachRigidbody|0;
 var $$not = 0, $$not1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0);
 var $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0);
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0);
 var $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $child$031 = 0, $child$031$phi = 0, $or$cond = 0;
 var $or$cond2 = 0, $parent$0 = 0, $parent$0$in = 0, $parent$0$in29 = 0, $parent$030 = 0, $parent$032 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $0 = (($agg$result) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($agg$result) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($agg$result) + 12|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 16|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($agg$result) + 20|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($agg$result) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($7,54)|0);
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = (($8) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = (__ZNK5Unity10GameObject8IsActiveEv($11)|0);
   $$not = $13 ^ 1;
   $14 = ($8|0)==($ignoreAttachRigidbody|0);
   $or$cond = $14 | $$not;
   if (!($or$cond)) {
    STACKTOP = sp;return;
   }
  }
 }
 $15 = HEAP32[$6>>2]|0;
 $16 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($15)|0);
 $parent$0$in29 = (($16) + 156|0);
 $parent$030 = HEAP32[$parent$0$in29>>2]|0;
 $17 = ($parent$030|0)==(0|0);
 if ($17) {
  STACKTOP = sp;return;
 } else {
  $33 = Math_fround(0.0);$35 = Math_fround(0.0);$37 = Math_fround(0.0);$73 = Math_fround(0.0);$75 = Math_fround(1.0);$78 = Math_fround(0.0);$81 = Math_fround(0.0);$child$031 = $16;$parent$032 = $parent$030;
 }
 while(1) {
  $18 = (($child$031) + 44|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($child$031) + 48|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (($child$031) + 52|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($child$031) + 28|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($child$031) + 32|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($child$031) + 36|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($child$031) + 40|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($33 * Math_fround(2.0));
  $34 = Math_fround($35 * Math_fround(2.0));
  $36 = Math_fround($37 * Math_fround(2.0));
  $38 = Math_fround($31 * $31);
  $39 = Math_fround($38 + Math_fround(-0.5));
  $40 = Math_fround($25 * $32);
  $41 = Math_fround($27 * $34);
  $42 = Math_fround($40 + $41);
  $43 = Math_fround($29 * $36);
  $44 = Math_fround($42 + $43);
  $45 = Math_fround($32 * $39);
  $46 = Math_fround($27 * $36);
  $47 = Math_fround($29 * $34);
  $48 = Math_fround($46 - $47);
  $49 = Math_fround($31 * $48);
  $50 = Math_fround($45 + $49);
  $51 = Math_fround($25 * $44);
  $52 = Math_fround($51 + $50);
  $53 = Math_fround($39 * $34);
  $54 = Math_fround($29 * $32);
  $55 = Math_fround($25 * $36);
  $56 = Math_fround($54 - $55);
  $57 = Math_fround($31 * $56);
  $58 = Math_fround($53 + $57);
  $59 = Math_fround($27 * $44);
  $60 = Math_fround($59 + $58);
  $61 = Math_fround($39 * $36);
  $62 = Math_fround($25 * $34);
  $63 = Math_fround($27 * $32);
  $64 = Math_fround($62 - $63);
  $65 = Math_fround($31 * $64);
  $66 = Math_fround($61 + $65);
  $67 = Math_fround($29 * $44);
  $68 = Math_fround($66 + $67);
  $69 = Math_fround($19 + $52);
  $70 = Math_fround($21 + $60);
  $71 = Math_fround($23 + $68);
  $72 = Math_fround($31 * $73);
  $74 = Math_fround($25 * $75);
  $76 = Math_fround($72 + $74);
  $77 = Math_fround($27 * $78);
  $79 = Math_fround($76 + $77);
  $80 = Math_fround($29 * $81);
  $82 = Math_fround($79 - $80);
  $83 = Math_fround($31 * $81);
  $84 = Math_fround($27 * $75);
  $85 = Math_fround($84 + $83);
  $86 = Math_fround($29 * $73);
  $87 = Math_fround($86 + $85);
  $88 = Math_fround($25 * $78);
  $89 = Math_fround($87 - $88);
  $90 = Math_fround($31 * $78);
  $91 = Math_fround($29 * $75);
  $92 = Math_fround($91 + $90);
  $93 = Math_fround($25 * $81);
  $94 = Math_fround($93 + $92);
  $95 = Math_fround($27 * $73);
  $96 = Math_fround($94 - $95);
  $97 = Math_fround($31 * $75);
  $98 = Math_fround($25 * $73);
  $99 = Math_fround($97 - $98);
  $100 = Math_fround($27 * $81);
  $101 = Math_fround($99 - $100);
  $102 = Math_fround($29 * $78);
  $103 = Math_fround($101 - $102);
  HEAPF32[$agg$result>>2] = $82;
  HEAPF32[$0>>2] = $89;
  HEAPF32[$1>>2] = $96;
  HEAPF32[$2>>2] = $103;
  HEAPF32[$3>>2] = $69;
  HEAPF32[$4>>2] = $70;
  HEAPF32[$5>>2] = $71;
  $104 = (($parent$032) + 24|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = ($105|0)==(0|0);
  if (!($106)) {
   $107 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($105,54)|0);
   $108 = ($107|0)==(0|0);
   if (!($108)) {
    $109 = (($107) + 24|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ($110|0)==(0|0);
    if (!($111)) {
     $113 = (__ZNK5Unity10GameObject8IsActiveEv($110)|0);
     $$not1 = $113 ^ 1;
     $114 = ($107|0)==($ignoreAttachRigidbody|0);
     $or$cond2 = $114 | $$not1;
     if (!($or$cond2)) {
      label = 10;
      break;
     }
    }
   }
  }
  $parent$0$in = (($parent$032) + 156|0);
  $parent$0 = HEAP32[$parent$0$in>>2]|0;
  $112 = ($parent$0|0)==(0|0);
  if ($112) {
   label = 10;
   break;
  } else {
   $child$031$phi = $parent$032;$33 = $69;$35 = $70;$37 = $71;$73 = $82;$75 = $103;$78 = $96;$81 = $89;$parent$032 = $parent$0;$child$031 = $child$031$phi;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return;
 }
}
function __ZN12PhysXRaycast15InitializeClassEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(4)|0);
 HEAP32[$0>>2] = ((691264 + 8|0));
 __Z19SetRaycastInterfaceP8IRaycast($0);
 STACKTOP = sp;return;
}
function __ZN12PhysXRaycast12CleanupClassEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetRaycastInterfacev()|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[$0>>2]|0;
  $3 = (($2) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095]($0);
 }
 __Z19SetRaycastInterfaceP8IRaycast(0);
 STACKTOP = sp;return;
}
function __ZN12PhysXRaycast7RaycastERK3RayfiR10RaycastHit($this,$ray,$distance,$mask,$output) {
 $this = $this|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $mask = $mask|0;
 $output = $output|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z17GetPhysicsManagerv()|0);
 $1 = (__ZN14PhysicsManager7RaycastERK3RayfR10RaycastHiti($0,$ray,$distance,$output,$mask)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12PhysXRaycast10RaycastAllERK3RayfiR13dynamic_arrayI10RaycastHitLj4EE($this,$ray,$distance,$mask,$result) {
 $this = $this|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $mask = $mask|0;
 $result = $result|0;
 var $$byval_copy3 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (__Z17GetPhysicsManagerv()|0);
 $2 = (__ZN14PhysicsManager10RaycastAllERK3Rayfi($1,$ray,$distance,$mask)|0);
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 44)&-1;
 $10 = (($result) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 2147483647;
 $13 = ($12>>>0)<($9>>>0);
 do {
  if ($13) {
   $14 = ($11|0)>(-1);
   if ($14) {
    HEAP32[$10>>2] = $9;
    $15 = HEAP32[$result>>2]|0;
    $16 = (($result) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($15,$8,4,$$byval_copy3,0,691296,370)|0);
    HEAP32[$result>>2] = $18;
    break;
   } else {
    $19 = (($result) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    HEAP32[$0>>2] = $20;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($8,4,$$byval_copy3,0,691296,352)|0);
    $22 = HEAP32[$result>>2]|0;
    $23 = (($result) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24*44)|0;
    _memcpy(($21|0),($22|0),($25|0))|0;
    HEAP32[$10>>2] = $9;
    HEAP32[$result>>2] = $21;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$3>>2]|0;
 $27 = HEAP32[$2>>2]|0;
 $28 = ($26|0)==($27|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (($result) + 8|0);
 $30 = (($result) + 4|0);
 $32 = $27;$i$02 = 0;
 while(1) {
  $31 = (($32) + (($i$02*44)|0)|0);
  $33 = HEAP32[$29>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$29>>2] = $34;
  $35 = HEAP32[$10>>2]|0;
  $36 = $35 & 2147483647;
  $37 = ($34>>>0)>($36>>>0);
  if ($37) {
   $38 = $35 << 1;
   $39 = ($38|0)==(0);
   $40 = $39 ? 1 : $38;
   $41 = ($36>>>0)<($40>>>0);
   do {
    if ($41) {
     $42 = ($35|0)>(-1);
     if ($42) {
      HEAP32[$10>>2] = $40;
      $43 = HEAP32[$result>>2]|0;
      $44 = ($40*44)|0;
      $45 = HEAP32[$30>>2]|0;
      HEAP32[$0>>2] = $45;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $46 = (__Z16realloc_internalPvji10MemLabelIdiPKci($43,$44,4,$$byval_copy3,0,691296,370)|0);
      HEAP32[$result>>2] = $46;
      break;
     } else {
      $47 = ($40*44)|0;
      $48 = HEAP32[$30>>2]|0;
      HEAP32[$0>>2] = $48;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $49 = (__Z15malloc_internaljj10MemLabelIdiPKci($47,4,$$byval_copy3,0,691296,352)|0);
      $50 = HEAP32[$result>>2]|0;
      $51 = HEAP32[$29>>2]|0;
      $52 = ($51*44)|0;
      _memcpy(($49|0),($50|0),($52|0))|0;
      HEAP32[$10>>2] = $40;
      HEAP32[$result>>2] = $49;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$29>>2]|0;
   $54 = $$pre$i$i;
  } else {
   $54 = $34;
  }
  $53 = (($54) + -1)|0;
  $55 = HEAP32[$result>>2]|0;
  $56 = (($55) + (($53*44)|0)|0);
  dest=$56+0|0; src=$31+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $57 = (($i$02) + 1)|0;
  $58 = HEAP32[$3>>2]|0;
  $59 = HEAP32[$2>>2]|0;
  $60 = $58;
  $61 = $59;
  $62 = (($60) - ($61))|0;
  $63 = (($62|0) / 44)&-1;
  $64 = ($57|0)==($63|0);
  if ($64) {
   break;
  } else {
   $32 = $59;$i$02 = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK12PhysXRaycast9IntersectERK3RayfPN5physx12PxOverlapHitEP4AABBjR20BatchedRaycastResult($this,$ray,$maxDist,$hits,$shapeBounds,$shapeCount,$hit) {
 $this = $this|0;
 $ray = $ray|0;
 $maxDist = Math_fround($maxDist);
 $hits = $hits|0;
 $shapeBounds = $shapeBounds|0;
 $shapeCount = $shapeCount|0;
 $hit = $hit|0;
 var $$0$i = 0, $$0$in$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0);
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0);
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0);
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $collisionSqrDist$0$lcssa = Math_fround(0), $collisionSqrDist$012 = Math_fround(0), $collisionSqrDist$3 = Math_fround(0), $exitcond = 0, $rayBounds = 0, $rayHit = 0, $s$011 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $0 = sp + 192|0;
 $1 = sp;
 $2 = sp + 32|0;
 $3 = sp + 72|0;
 $4 = sp + 220|0;
 $rayBounds = sp + 168|0;
 $rayHit = sp + 104|0;
 $5 = (($ray) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $maxDist);
 $8 = (($ray) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * $maxDist);
 $11 = (($ray) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 * $maxDist);
 $14 = Math_fround($7 * Math_fround(0.5));
 $15 = Math_fround($10 * Math_fround(0.5));
 $16 = Math_fround($13 * Math_fround(0.5));
 $17 = Math_fround(HEAPF32[$ray>>2]);
 $18 = Math_fround($14 + $17);
 $19 = (($ray) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($15 + $20);
 $22 = (($ray) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($16 + $23);
 $25 = $14 < Math_fround(0.0);
 if ($25) {
  $26 = Math_fround(-$14);
  $37 = $26;
 } else {
  $37 = $14;
 }
 $27 = $15 < Math_fround(0.0);
 if ($27) {
  $28 = Math_fround(-$15);
  $39 = $28;
 } else {
  $39 = $15;
 }
 $29 = $16 < Math_fround(0.0);
 if ($29) {
  $30 = Math_fround(-$16);
  $41 = $30;
 } else {
  $41 = $16;
 }
 ;HEAP32[$rayBounds+0>>2]=0|0;HEAP32[$rayBounds+4>>2]=0|0;HEAP32[$rayBounds+8>>2]=0|0;HEAP32[$rayBounds+12>>2]=0|0;
 HEAPF32[$rayBounds>>2] = $18;
 $31 = (($rayBounds) + 4|0);
 HEAPF32[$31>>2] = $21;
 $32 = (($rayBounds) + 8|0);
 HEAPF32[$32>>2] = $24;
 $33 = (($rayBounds) + 12|0);
 $34 = (($rayBounds) + 16|0);
 $35 = (($rayBounds) + 20|0);
 $36 = Math_fround($37 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$33>>2] = $36;
 $38 = Math_fround($39 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$34>>2] = $38;
 $40 = Math_fround($41 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$35>>2] = $40;
 $42 = ($shapeCount|0)==(0);
 if ($42) {
  $collisionSqrDist$0$lcssa = Math_fround(inf);
  $209 = $collisionSqrDist$0$lcssa < Math_fround(inf);
  STACKTOP = sp;return ($209|0);
 }
 $43 = (($rayHit) + 4|0);
 $44 = (($rayHit) + 8|0);
 $45 = (($rayHit) + 12|0);
 $46 = (($rayHit) + 16|0);
 $47 = (($rayHit) + 40|0);
 $48 = (($rayHit) + 44|0);
 $49 = (($rayHit) + 48|0);
 $50 = (($1) + 16|0);
 $51 = (($1) + 20|0);
 $52 = (($1) + 24|0);
 $53 = (($0) + 12|0);
 $54 = (($0) + 4|0);
 $55 = (($0) + 8|0);
 $56 = (($0) + 16|0);
 $57 = (($0) + 20|0);
 $58 = (($0) + 24|0);
 $59 = (($1) + 12|0);
 $60 = (($1) + 8|0);
 $61 = (($1) + 4|0);
 $62 = (($3) + 4|0);
 $63 = (($3) + 8|0);
 $64 = (($3) + 12|0);
 $65 = (($3) + 16|0);
 $66 = (($3) + 20|0);
 $67 = (($3) + 24|0);
 $68 = (($rayHit) + 20|0);
 $69 = (($rayHit) + 24|0);
 $70 = (($hit) + 28|0);
 $71 = (($hit) + 32|0);
 $72 = (($hit) + 4|0);
 $73 = (($hit) + 8|0);
 $74 = (($hit) + 12|0);
 $75 = (($hit) + 16|0);
 $76 = (($rayHit) + 28|0);
 $collisionSqrDist$012 = Math_fround(inf);$s$011 = 0;
 while(1) {
  $77 = (($shapeBounds) + (($s$011*24)|0)|0);
  $78 = (__Z26IntersectAABBAABBInclusiveRK4AABBS1_($rayBounds,$77)|0);
  do {
   if ($78) {
    $79 = ((($hits) + ($s$011<<4)|0) + 4|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ($80|0)==(0|0);
    if ($81) {
     $collisionSqrDist$3 = $collisionSqrDist$012;
    } else {
     $82 = (($hits) + ($s$011<<4)|0);
     $83 = HEAP32[$82>>2]|0;
     HEAP32[$rayHit>>2] = 0;
     HEAP32[$43>>2] = 0;
     HEAP32[$44>>2] = -1;
     HEAP16[$45>>1] = 0;
     ;HEAP32[$46+0>>2]=0|0;HEAP32[$46+4>>2]=0|0;HEAP32[$46+8>>2]=0|0;HEAP32[$46+12>>2]=0|0;HEAP32[$46+16>>2]=0|0;HEAP32[$46+20>>2]=0|0;
     HEAPF32[$47>>2] = Math_fround(3.40282346638528859812E+38);
     HEAPF32[$48>>2] = Math_fround(0.0);
     HEAPF32[$49>>2] = Math_fround(0.0);
     $84 = HEAP32[$80>>2]|0;
     $85 = (($84) + 32|0);
     $86 = HEAP32[$85>>2]|0;
     FUNCTION_TABLE_vii[$86 & 4095]($2,$80);
     $87 = HEAP32[$83>>2]|0;
     $88 = (($87) + 84|0);
     $89 = HEAP32[$88>>2]|0;
     FUNCTION_TABLE_vii[$89 & 4095]($0,$83);
     $90 = HEAP32[$80>>2]|0;
     $91 = (($90) + 72|0);
     $92 = HEAP32[$91>>2]|0;
     FUNCTION_TABLE_vii[$92 & 4095]($1,$80);
     $93 = Math_fround(HEAPF32[$50>>2]);
     $94 = Math_fround($93 * Math_fround(2.0));
     $95 = Math_fround(HEAPF32[$51>>2]);
     $96 = Math_fround($95 * Math_fround(2.0));
     $97 = Math_fround(HEAPF32[$52>>2]);
     $98 = Math_fround($97 * Math_fround(2.0));
     $99 = Math_fround(HEAPF32[$53>>2]);
     $100 = Math_fround($99 * $99);
     $101 = Math_fround($100 + Math_fround(-0.5));
     $102 = Math_fround(HEAPF32[$0>>2]);
     $103 = Math_fround($94 * $102);
     $104 = Math_fround(HEAPF32[$54>>2]);
     $105 = Math_fround($96 * $104);
     $106 = Math_fround($103 + $105);
     $107 = Math_fround(HEAPF32[$55>>2]);
     $108 = Math_fround($98 * $107);
     $109 = Math_fround($106 + $108);
     $110 = Math_fround($94 * $101);
     $111 = Math_fround($98 * $104);
     $112 = Math_fround($96 * $107);
     $113 = Math_fround($111 - $112);
     $114 = Math_fround($99 * $113);
     $115 = Math_fround($110 + $114);
     $116 = Math_fround($102 * $109);
     $117 = Math_fround($116 + $115);
     $118 = Math_fround($96 * $101);
     $119 = Math_fround($94 * $107);
     $120 = Math_fround($98 * $102);
     $121 = Math_fround($119 - $120);
     $122 = Math_fround($99 * $121);
     $123 = Math_fround($118 + $122);
     $124 = Math_fround($104 * $109);
     $125 = Math_fround($124 + $123);
     $126 = Math_fround($98 * $101);
     $127 = Math_fround($96 * $102);
     $128 = Math_fround($94 * $104);
     $129 = Math_fround($127 - $128);
     $130 = Math_fround($99 * $129);
     $131 = Math_fround($126 + $130);
     $132 = Math_fround($107 * $109);
     $133 = Math_fround($131 + $132);
     $134 = Math_fround(HEAPF32[$56>>2]);
     $135 = Math_fround($134 + $117);
     $136 = Math_fround(HEAPF32[$57>>2]);
     $137 = Math_fround($136 + $125);
     $138 = Math_fround(HEAPF32[$58>>2]);
     $139 = Math_fround($138 + $133);
     $140 = Math_fround(HEAPF32[$1>>2]);
     $141 = Math_fround($99 * $140);
     $142 = Math_fround(HEAPF32[$59>>2]);
     $143 = Math_fround($102 * $142);
     $144 = Math_fround($141 + $143);
     $145 = Math_fround(HEAPF32[$60>>2]);
     $146 = Math_fround($104 * $145);
     $147 = Math_fround($144 + $146);
     $148 = Math_fround(HEAPF32[$61>>2]);
     $149 = Math_fround($107 * $148);
     $150 = Math_fround($147 - $149);
     $151 = Math_fround($99 * $148);
     $152 = Math_fround($104 * $142);
     $153 = Math_fround($152 + $151);
     $154 = Math_fround($107 * $140);
     $155 = Math_fround($154 + $153);
     $156 = Math_fround($102 * $145);
     $157 = Math_fround($155 - $156);
     $158 = Math_fround($99 * $145);
     $159 = Math_fround($107 * $142);
     $160 = Math_fround($159 + $158);
     $161 = Math_fround($102 * $148);
     $162 = Math_fround($161 + $160);
     $163 = Math_fround($104 * $140);
     $164 = Math_fround($162 - $163);
     $165 = Math_fround($99 * $142);
     $166 = Math_fround($102 * $140);
     $167 = Math_fround($165 - $166);
     $168 = Math_fround($104 * $148);
     $169 = Math_fround($167 - $168);
     $170 = Math_fround($107 * $145);
     $171 = Math_fround($169 - $170);
     HEAPF32[$3>>2] = $150;
     HEAPF32[$62>>2] = $157;
     HEAPF32[$63>>2] = $164;
     HEAPF32[$64>>2] = $171;
     HEAPF32[$65>>2] = $135;
     HEAPF32[$66>>2] = $137;
     HEAPF32[$67>>2] = $139;
     HEAP16[$4>>1] = 3;
     $172 = (__ZN5physx15PxGeometryQuery7raycastERKNS_6PxVec3ES3_RKNS_10PxGeometryERKNS_11PxTransformEfNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEb($ray,$5,$2,$3,$maxDist,$4,1,$rayHit,0)|0);
     $173 = ($172|0)==(0);
     if ($173) {
      $collisionSqrDist$3 = $collisionSqrDist$012;
     } else {
      $174 = Math_fround(HEAPF32[$46>>2]);
      $175 = Math_fround(HEAPF32[$68>>2]);
      $176 = Math_fround(HEAPF32[$69>>2]);
      $177 = Math_fround(HEAPF32[$ray>>2]);
      $178 = Math_fround($177 - $174);
      $179 = Math_fround(HEAPF32[$19>>2]);
      $180 = Math_fround($179 - $175);
      $181 = Math_fround(HEAPF32[$22>>2]);
      $182 = Math_fround($181 - $176);
      $183 = Math_fround($178 * $178);
      $184 = Math_fround($180 * $180);
      $185 = Math_fround($183 + $184);
      $186 = Math_fround($182 * $182);
      $187 = Math_fround($185 + $186);
      $188 = $187 < $collisionSqrDist$012;
      if ($188) {
       $189 = (($80) + 8|0);
       $190 = HEAP32[$189>>2]|0;
       $191 = ($190|0)==(0|0);
       if ($191) {
        $collisionSqrDist$3 = $collisionSqrDist$012;
       } else {
        $192 = HEAP32[$190>>2]|0;
        $193 = (($192) + 116|0);
        $194 = HEAP32[$193>>2]|0;
        $195 = (FUNCTION_TABLE_ii[$194 & 4095]($190)|0);
        if ($195) {
         $196 = HEAP32[$190>>2]|0;
         $197 = (($196) + 124|0);
         $198 = HEAP32[$197>>2]|0;
         $199 = (FUNCTION_TABLE_ii[$198 & 4095]($190)|0);
         if ($199) {
          $collisionSqrDist$3 = $collisionSqrDist$012;
          break;
         }
        }
        $200 = (($190) + 4|0);
        $201 = HEAP32[$200>>2]|0;
        HEAP32[$70>>2] = $201;
        $202 = HEAP32[$190>>2]|0;
        $203 = (($202) + 128|0);
        $204 = HEAP32[$203>>2]|0;
        $205 = (FUNCTION_TABLE_ii[$204 & 4095]($190)|0);
        $206 = ($205|0)==(0|0);
        $207 = (($205) + 4|0);
        $$0$in$i = $206 ? $200 : $207;
        $$0$i = HEAP32[$$0$in$i>>2]|0;
        HEAP32[$71>>2] = $$0$i;
        HEAPF32[$72>>2] = $174;
        HEAPF32[$73>>2] = $175;
        HEAPF32[$74>>2] = $176;
        ;HEAP32[$75+0>>2]=HEAP32[$76+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$76+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$76+8>>2]|0;
        $collisionSqrDist$3 = $187;
       }
      } else {
       $collisionSqrDist$3 = $collisionSqrDist$012;
      }
     }
    }
   } else {
    $collisionSqrDist$3 = $collisionSqrDist$012;
   }
  } while(0);
  $208 = (($s$011) + 1)|0;
  $exitcond = ($208|0)==($shapeCount|0);
  if ($exitcond) {
   $collisionSqrDist$0$lcssa = $collisionSqrDist$3;
   break;
  } else {
   $collisionSqrDist$012 = $collisionSqrDist$3;$s$011 = $208;
  }
 }
 $209 = $collisionSqrDist$0$lcssa < Math_fround(inf);
 STACKTOP = sp;return ($209|0);
}
function __ZNK12PhysXRaycast17BroadPhaseCullingER13dynamic_arrayIN5physx12PxOverlapHitELj4EERS0_I4AABBLj4EERK10MinMaxAABBib($this,$hits,$aabbs,$particleSystemAABB,$filter,$staticOnly) {
 $this = $this|0;
 $hits = $hits|0;
 $aabbs = $aabbs|0;
 $particleSystemAABB = $particleSystemAABB|0;
 $filter = $filter|0;
 $staticOnly = $staticOnly|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $castFilter$i = 0, $exitcond = 0, $filterData$i = 0, $i$01 = 0, $overlaps$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $filterData$i = sp + 100|0;
 $castFilter$i = sp;
 $overlaps$i = sp + 20|0;
 $0 = sp + 56|0;
 $1 = sp + 72|0;
 $2 = (($particleSystemAABB) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(HEAPF32[$particleSystemAABB>>2]);
 $5 = Math_fround($3 + $4);
 $6 = (($particleSystemAABB) + 16|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($particleSystemAABB) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 + $9);
 $11 = (($particleSystemAABB) + 20|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($particleSystemAABB) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 + $14);
 $16 = Math_fround($5 * Math_fround(0.5));
 $17 = Math_fround($10 * Math_fround(0.5));
 $18 = Math_fround($15 * Math_fround(0.5));
 $19 = Math_fround($3 - $4);
 $20 = Math_fround($7 - $9);
 $21 = Math_fround($12 - $14);
 $22 = Math_fround($19 * Math_fround(0.5));
 $23 = Math_fround($20 * Math_fround(0.5));
 $24 = Math_fround($21 * Math_fround(0.5));
 $25 = HEAP32[$hits>>2]|0;
 $26 = $staticOnly ? 5 : 7;
 ;HEAP32[$filterData$i+0>>2]=0|0;HEAP32[$filterData$i+4>>2]=0|0;HEAP32[$filterData$i+8>>2]=0|0;HEAP32[$filterData$i+12>>2]=0|0;
 $27 = (($filterData$i) + 16|0);
 HEAP16[$27>>1] = $26;
 $28 = (($filterData$i) + 18|0);
 HEAP8[$28>>0] = 0;
 HEAP32[$castFilter$i>>2] = ((690808 + 8|0));
 $29 = (($castFilter$i) + 4|0);
 HEAP32[$29>>2] = 1;
 $30 = (($castFilter$i) + 8|0);
 HEAP32[$30>>2] = 0;
 $31 = (($castFilter$i) + 12|0);
 HEAP32[$31>>2] = $filter;
 $32 = (($castFilter$i) + 16|0);
 HEAP8[$32>>0] = 0;
 $33 = (($overlaps$i) + 4|0);
 HEAP32[$33>>2] = 0;
 $34 = (($overlaps$i) + 8|0);
 HEAP32[$34>>2] = 0;
 $35 = (($overlaps$i) + 12|0);
 HEAP32[$35>>2] = -1;
 $36 = (($overlaps$i) + 20|0);
 HEAP8[$36>>0] = 0;
 $37 = (($overlaps$i) + 24|0);
 HEAP32[$37>>2] = $25;
 $38 = (($overlaps$i) + 28|0);
 HEAP32[$38>>2] = 256;
 $39 = (($overlaps$i) + 32|0);
 HEAP32[$39>>2] = 0;
 HEAP32[$overlaps$i>>2] = ((404640 + 8|0));
 $40 = (__Z16GetDynamicsScenev()|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 356|0);
 $43 = HEAP32[$42>>2]|0;
 HEAP32[$0>>2] = 3;
 $44 = (($0) + 4|0);
 HEAPF32[$44>>2] = $22;
 $45 = (($0) + 8|0);
 HEAPF32[$45>>2] = $23;
 $46 = (($0) + 12|0);
 HEAPF32[$46>>2] = $24;
 HEAPF32[$1>>2] = Math_fround(0.0);
 $47 = (($1) + 4|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($1) + 8|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($1) + 12|0);
 HEAPF32[$49>>2] = Math_fround(1.0);
 $50 = (($1) + 16|0);
 HEAPF32[$50>>2] = $16;
 $51 = (($1) + 20|0);
 HEAPF32[$51>>2] = $17;
 $52 = (($1) + 24|0);
 HEAPF32[$52>>2] = $18;
 (FUNCTION_TABLE_iiiiiii[$43 & 255]($40,$0,$1,$overlaps$i,$filterData$i,$castFilter$i)|0);
 $53 = HEAP32[$39>>2]|0;
 $54 = HEAP8[$36>>0]|0;
 $55 = $54&255;
 $56 = (($55) + ($53))|0;
 $57 = ($56|0)==(0);
 if ($57) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $i$01 = 0;
 while(1) {
  $58 = HEAP32[$aabbs>>2]|0;
  $59 = (($58) + (($i$01*24)|0)|0);
  $60 = HEAP32[$hits>>2]|0;
  $61 = (($60) + ($i$01<<4)|0);
  __ZNK12PhysXRaycast7GetAABBER4AABBRKN5physx12PxOverlapHitE(0,$59,$61);
  $62 = (($i$01) + 1)|0;
  $exitcond = ($62|0)==($56|0);
  if ($exitcond) {
   $$0 = $56;
   break;
  } else {
   $i$01 = $62;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK12PhysXRaycast7GetAABBER4AABBRKN5physx12PxOverlapHitE($this,$bounds,$hit) {
 $this = $this|0;
 $bounds = $bounds|0;
 $hit = $hit|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $physicsBounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 128|0;
 $1 = sp;
 $2 = sp + 32|0;
 $3 = sp + 72|0;
 $physicsBounds = sp + 104|0;
 $4 = (($hit) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$hit>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095]($2,$5);
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_vii[$12 & 4095]($0,$6);
 $13 = HEAP32[$5>>2]|0;
 $14 = (($13) + 72|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_vii[$15 & 4095]($1,$5);
 $16 = (($1) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 * Math_fround(2.0));
 $19 = (($1) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * Math_fround(2.0));
 $22 = (($1) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * Math_fround(2.0));
 $25 = (($0) + 12|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $26);
 $28 = Math_fround($27 + Math_fround(-0.5));
 $29 = Math_fround(HEAPF32[$0>>2]);
 $30 = Math_fround($18 * $29);
 $31 = (($0) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($21 * $32);
 $34 = Math_fround($30 + $33);
 $35 = (($0) + 8|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($24 * $36);
 $38 = Math_fround($34 + $37);
 $39 = Math_fround($18 * $28);
 $40 = Math_fround($24 * $32);
 $41 = Math_fround($21 * $36);
 $42 = Math_fround($40 - $41);
 $43 = Math_fround($26 * $42);
 $44 = Math_fround($39 + $43);
 $45 = Math_fround($29 * $38);
 $46 = Math_fround($45 + $44);
 $47 = Math_fround($21 * $28);
 $48 = Math_fround($18 * $36);
 $49 = Math_fround($24 * $29);
 $50 = Math_fround($48 - $49);
 $51 = Math_fround($26 * $50);
 $52 = Math_fround($47 + $51);
 $53 = Math_fround($32 * $38);
 $54 = Math_fround($53 + $52);
 $55 = Math_fround($24 * $28);
 $56 = Math_fround($21 * $29);
 $57 = Math_fround($18 * $32);
 $58 = Math_fround($56 - $57);
 $59 = Math_fround($26 * $58);
 $60 = Math_fround($55 + $59);
 $61 = Math_fround($36 * $38);
 $62 = Math_fround($60 + $61);
 $63 = (($0) + 16|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 + $46);
 $66 = (($0) + 20|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 + $54);
 $69 = (($0) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 + $62);
 $72 = Math_fround(HEAPF32[$1>>2]);
 $73 = Math_fround($26 * $72);
 $74 = (($1) + 12|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($29 * $75);
 $77 = Math_fround($73 + $76);
 $78 = (($1) + 8|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($32 * $79);
 $81 = Math_fround($77 + $80);
 $82 = (($1) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($36 * $83);
 $85 = Math_fround($81 - $84);
 $86 = Math_fround($26 * $83);
 $87 = Math_fround($32 * $75);
 $88 = Math_fround($87 + $86);
 $89 = Math_fround($36 * $72);
 $90 = Math_fround($89 + $88);
 $91 = Math_fround($29 * $79);
 $92 = Math_fround($90 - $91);
 $93 = Math_fround($26 * $79);
 $94 = Math_fround($36 * $75);
 $95 = Math_fround($94 + $93);
 $96 = Math_fround($29 * $83);
 $97 = Math_fround($96 + $95);
 $98 = Math_fround($32 * $72);
 $99 = Math_fround($97 - $98);
 $100 = Math_fround($26 * $75);
 $101 = Math_fround($29 * $72);
 $102 = Math_fround($100 - $101);
 $103 = Math_fround($32 * $83);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($36 * $79);
 $106 = Math_fround($104 - $105);
 HEAPF32[$3>>2] = $85;
 $107 = (($3) + 4|0);
 HEAPF32[$107>>2] = $92;
 $108 = (($3) + 8|0);
 HEAPF32[$108>>2] = $99;
 $109 = (($3) + 12|0);
 HEAPF32[$109>>2] = $106;
 $110 = (($3) + 16|0);
 HEAPF32[$110>>2] = $65;
 $111 = (($3) + 20|0);
 HEAPF32[$111>>2] = $68;
 $112 = (($3) + 24|0);
 HEAPF32[$112>>2] = $71;
 __ZN5physx15PxGeometryQuery14getWorldBoundsERKNS_10PxGeometryERKNS_11PxTransformEf($physicsBounds,$2,$3,Math_fround(1.00999999046325683594));
 $113 = Math_fround(HEAPF32[$physicsBounds>>2]);
 $114 = (($physicsBounds) + 12|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($113 + $115);
 $117 = (($physicsBounds) + 4|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($physicsBounds) + 16|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = Math_fround($118 + $120);
 $122 = (($physicsBounds) + 8|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($physicsBounds) + 20|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = Math_fround($123 + $125);
 $127 = Math_fround($116 * Math_fround(0.5));
 $128 = Math_fround($121 * Math_fround(0.5));
 $129 = Math_fround($126 * Math_fround(0.5));
 $130 = Math_fround($115 - $113);
 $131 = Math_fround($120 - $118);
 $132 = Math_fround($125 - $123);
 $133 = Math_fround($130 * Math_fround(0.5));
 $134 = Math_fround($131 * Math_fround(0.5));
 $135 = Math_fround($132 * Math_fround(0.5));
 HEAPF32[$bounds>>2] = $127;
 $136 = (($bounds) + 4|0);
 HEAPF32[$136>>2] = $128;
 $137 = (($bounds) + 8|0);
 HEAPF32[$137>>2] = $129;
 $138 = (($bounds) + 12|0);
 $139 = (($bounds) + 16|0);
 $140 = (($bounds) + 20|0);
 $141 = Math_fround($133 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$138>>2] = $141;
 $142 = Math_fround($134 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$139>>2] = $142;
 $143 = Math_fround($135 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$140>>2] = $143;
 STACKTOP = sp;return;
}
function __ZNK12PhysXRaycast14BatchIntersectERK13dynamic_arrayI14BatchedRaycastLj4EERS0_I20BatchedRaycastResultLj4EEjb($this,$raycasts,$results,$filter,$staticOnly) {
 $this = $this|0;
 $raycasts = $raycasts|0;
 $results = $results|0;
 $filter = $filter|0;
 $staticOnly = $staticOnly|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy10 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aabb = 0;
 var $aabbs = 0, $hit = 0, $hits = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $numIntersections$015 = 0, $numIntersections$2 = 0, $pointsRay = 0, $r$016 = 0, $ray = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy10 = sp + 168|0;
 $0 = sp + 164|0;
 $1 = sp + 160|0;
 $2 = sp + 156|0;
 $3 = sp + 152|0;
 $aabb = sp + 128|0;
 $hits = sp + 72|0;
 $aabbs = sp + 56|0;
 $pointsRay = sp + 24|0;
 $ray = sp;
 $hit = sp + 88|0;
 __ZN8IRaycast16ComputeBatchAABBERK13dynamic_arrayI14BatchedRaycastLj4EE($aabb,$raycasts);
 $4 = Math_fround(HEAPF32[$aabb>>2]);
 $5 = Math_fround($4 + Math_fround(-9.99999974737875163555E-6));
 HEAPF32[$aabb>>2] = $5;
 $6 = (($aabb) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 + Math_fround(-9.99999974737875163555E-6));
 HEAPF32[$6>>2] = $8;
 $9 = (($aabb) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 + Math_fround(-9.99999974737875163555E-6));
 HEAPF32[$9>>2] = $11;
 $12 = (($aabb) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$12>>2] = $14;
 $15 = (($aabb) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$15>>2] = $17;
 $18 = (($aabb) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 + Math_fround(9.99999974737875163555E-6));
 HEAPF32[$18>>2] = $20;
 $21 = HEAP32[628512>>2]|0;
 $22 = (($hits) + 4|0);
 HEAP32[$22>>2] = $21;
 $23 = (($hits) + 8|0);
 HEAP32[$23>>2] = 256;
 $24 = (($hits) + 12|0);
 HEAP32[$24>>2] = 256;
 HEAP32[$0>>2] = $21;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
 $25 = (__Z15malloc_internaljj10MemLabelIdiPKci(4096,4,$$byval_copy10,0,691296,352)|0);
 HEAP32[$hits>>2] = $25;
 $26 = HEAP32[628512>>2]|0;
 $27 = (($aabbs) + 4|0);
 HEAP32[$27>>2] = $26;
 $28 = (($aabbs) + 8|0);
 HEAP32[$28>>2] = 256;
 $29 = (($aabbs) + 12|0);
 HEAP32[$29>>2] = 256;
 HEAP32[$3>>2] = $26;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
 $30 = (invoke_iiiiiii(102,6144,4,($$byval_copy10|0),0,(691296|0),352)|0);
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 L1: do {
  if ($32) {
   label = 6;
  } else {
   HEAP32[$aabbs>>2] = $30;
   __THREW__ = 0;
   $33 = (invoke_iiiiiii(113,($this|0),($hits|0),($aabbs|0),($aabb|0),($filter|0),($staticOnly|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   L3: do {
    if ($35) {
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     $lpad$phi$index = $56;$lpad$phi$index2 = $57;
    } else {
     $36 = ($33|0)==(0);
     L5: do {
      if ($36) {
       $$0 = 0;
      } else {
       $37 = (($raycasts) + 8|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = ($38|0)==(0);
       if ($39) {
        $$0 = 0;
       } else {
        $40 = HEAP32[$aabbs>>2]|0;
        $41 = (($pointsRay) + 4|0);
        $42 = (($pointsRay) + 16|0);
        $43 = (($pointsRay) + 20|0);
        $44 = (($pointsRay) + 8|0);
        $45 = (($pointsRay) + 24|0);
        $46 = (($pointsRay) + 12|0);
        $47 = (($ray) + 12|0);
        $48 = (($ray) + 16|0);
        $49 = (($ray) + 20|0);
        $50 = (($hit) + 4|0);
        $51 = HEAP32[$hits>>2]|0;
        $numIntersections$015 = 0;$r$016 = 0;
        while(1) {
         $64 = HEAP32[$raycasts>>2]|0;
         $65 = (($64) + (($r$016*28)|0)|0);
         ;HEAP32[$pointsRay+0>>2]=HEAP32[$65+0>>2]|0;HEAP32[$pointsRay+4>>2]=HEAP32[$65+4>>2]|0;HEAP32[$pointsRay+8>>2]=HEAP32[$65+8>>2]|0;HEAP32[$pointsRay+12>>2]=HEAP32[$65+12>>2]|0;HEAP32[$pointsRay+16>>2]=HEAP32[$65+16>>2]|0;HEAP32[$pointsRay+20>>2]=HEAP32[$65+20>>2]|0;HEAP32[$pointsRay+24>>2]=HEAP32[$65+24>>2]|0;
         __THREW__ = 0;
         $66 = (invoke_iiii(1575,($pointsRay|0),($40|0),($33|0))|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          break;
         }
         if ($66) {
          $69 = Math_fround(HEAPF32[$42>>2]);
          $70 = Math_fround(HEAPF32[$41>>2]);
          $71 = Math_fround($69 - $70);
          $72 = Math_fround(HEAPF32[$43>>2]);
          $73 = Math_fround(HEAPF32[$44>>2]);
          $74 = Math_fround($72 - $73);
          $75 = Math_fround(HEAPF32[$45>>2]);
          $76 = Math_fround(HEAPF32[$46>>2]);
          $77 = Math_fround($75 - $76);
          $78 = Math_fround($71 * $71);
          $79 = Math_fround($74 * $74);
          $80 = Math_fround($78 + $79);
          $81 = Math_fround($77 * $77);
          $82 = Math_fround($80 + $81);
          $83 = (Math_fround(Math_sqrt((Math_fround($82)))));
          $84 = !($83 <= Math_fround(9.99999997475242707878E-7));
          if ($84) {
           $85 = Math_fround($71 / $83);
           $86 = Math_fround($74 / $83);
           $87 = Math_fround($77 / $83);
           ;HEAP32[$ray+0>>2]=0|0;HEAP32[$ray+4>>2]=0|0;HEAP32[$ray+8>>2]=0|0;HEAP32[$ray+12>>2]=0|0;HEAP32[$ray+16>>2]=0|0;
           ;HEAP32[$ray+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$ray+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$ray+8>>2]=HEAP32[$41+8>>2]|0;
           HEAPF32[$47>>2] = $85;
           HEAPF32[$48>>2] = $86;
           HEAPF32[$49>>2] = $87;
           HEAP32[$hit>>2] = $r$016;
           ;HEAP32[$50+0>>2]=0|0;HEAP32[$50+4>>2]=0|0;HEAP32[$50+8>>2]=0|0;HEAP32[$50+12>>2]=0|0;HEAP32[$50+16>>2]=0|0;HEAP32[$50+20>>2]=0|0;
           __THREW__ = 0;
           $88 = (invoke_iiifiiii(1,0,($ray|0),(+$83),($51|0),($40|0),($33|0),($hit|0))|0);
           $89 = __THREW__; __THREW__ = 0;
           $90 = $89&1;
           if ($90) {
            break;
           }
           if ($88) {
            $91 = HEAP32[$results>>2]|0;
            $92 = (($91) + (($numIntersections$015*36)|0)|0);
            dest=$92+0|0; src=$hit+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
            $93 = (($numIntersections$015) + 1)|0;
            $numIntersections$2 = $93;
           } else {
            $numIntersections$2 = $numIntersections$015;
           }
          } else {
           $numIntersections$2 = $numIntersections$015;
          }
         } else {
          $numIntersections$2 = $numIntersections$015;
         }
         $94 = (($r$016) + 1)|0;
         $95 = HEAP32[$37>>2]|0;
         $96 = ($94>>>0)<($95>>>0);
         if ($96) {
          $numIntersections$015 = $numIntersections$2;$r$016 = $94;
         } else {
          $$0 = $numIntersections$2;
          break L5;
         }
        }
        $54 = ___cxa_find_matching_catch()|0;
        $55 = tempRet0;
        $lpad$phi$index = $54;$lpad$phi$index2 = $55;
        break L3;
       }
      }
     } while(0);
     $97 = HEAP32[$29>>2]|0;
     $98 = ($97|0)>(-1);
     if ($98) {
      $99 = HEAP32[$aabbs>>2]|0;
      $100 = HEAP32[$27>>2]|0;
      HEAP32[$0>>2] = $100;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($99|0),($$byval_copy10|0));
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       label = 6;
       break L1;
      }
      HEAP32[$aabbs>>2] = 0;
     }
     $103 = HEAP32[$24>>2]|0;
     $104 = ($103|0)>(-1);
     if (!($104)) {
      STACKTOP = sp;return ($$0|0);
     }
     $105 = HEAP32[$hits>>2]|0;
     $106 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $106;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($105,$$byval_copy10);
     HEAP32[$hits>>2] = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $58 = HEAP32[$29>>2]|0;
   $59 = ($58|0)>(-1);
   if ($59) {
    $60 = HEAP32[$aabbs>>2]|0;
    $61 = HEAP32[$27>>2]|0;
    HEAP32[$2>>2] = $61;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($60|0),($$byval_copy10|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $113 = ___cxa_find_matching_catch(0|0)|0;
     $114 = tempRet0;
     ___clang_call_terminate($113);
     // unreachable;
    } else {
     HEAP32[$aabbs>>2] = 0;
     $$01 = $lpad$phi$index;$$02 = $lpad$phi$index2;
     break;
    }
   } else {
    $$01 = $lpad$phi$index;$$02 = $lpad$phi$index2;
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $52 = ___cxa_find_matching_catch()|0;
  $53 = tempRet0;
  $$01 = $52;$$02 = $53;
 }
 $107 = HEAP32[$24>>2]|0;
 $108 = ($107|0)>(-1);
 if (!($108)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $109 = HEAP32[$hits>>2]|0;
 $110 = HEAP32[$22>>2]|0;
 HEAP32[$1>>2] = $110;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($109|0),($$byval_copy10|0));
 $111 = __THREW__; __THREW__ = 0;
 $112 = $111&1;
 if ($112) {
  $113 = ___cxa_find_matching_catch(0|0)|0;
  $114 = tempRet0;
  ___clang_call_terminate($113);
  // unreachable;
 }
 HEAP32[$hits>>2] = 0;
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __ZN12PhysXRaycast26GetGameObjectForRaycastHitERK10RaycastHit($this,$hit) {
 $this = $this|0;
 $hit = $hit|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hit) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($1)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $10 = (($1) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 } else {
  $8 = (($6) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN12PhysXRaycastD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12PhysXRaycastD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __Z22RegisterModule_Physicsv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $i$01$i$i1 = 0;
 var $i$01$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i = 0;
 while(1) {
  $3 = ((($0) + ($i$01$i$i<<2)|0) + 64|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  $2 = (($i$01$i$i) + 1)|0;
  if ($5) {
   label = 4;
   break;
  }
  $1 = ($2|0)<(16);
  if ($1) {
   $i$01$i$i = $2;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$3>>2] = 208;
 }
 $6 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i2 = 0;
 while(1) {
  $9 = (($6) + ($i$01$i$i2<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  $8 = (($i$01$i$i2) + 1)|0;
  if ($11) {
   label = 8;
   break;
  }
  $7 = ($8|0)<(16);
  if ($7) {
   $i$01$i$i2 = $8;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  HEAP32[$9>>2] = 209;
 }
 $12 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i1 = 0;
 while(1) {
  $15 = ((($12) + ($i$01$i$i1<<2)|0) + 128|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  $14 = (($i$01$i$i1) + 1)|0;
  if ($17) {
   break;
  }
  $13 = ($14|0)<(16);
  if ($13) {
   $i$01$i$i1 = $14;
  } else {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
 HEAP32[$15>>2] = 210;
 STACKTOP = sp;return;
}
function __ZL28RegisterModuleICalls_Physicsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL24InitializeModule_Physicsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z23InitializePhysicsModulev();
 STACKTOP = sp;return;
}
function __ZL21CleanupModule_Physicsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z20CleanupPhysicsModulev();
 STACKTOP = sp;return;
}
function __Z23InitializePhysicsModulev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy,1,16,691304,140)|0);
 HEAP32[$2>>2] = ((691312 + 8|0));
 __Z11SetIPhysicsP8IPhysics($2);
 STACKTOP = sp;return;
}
function __Z20CleanupPhysicsModulev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z11GetIPhysicsv()|0);
 $2 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 __Z11SetIPhysicsP8IPhysics(0);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule17SetRigidBodyStateER9RigidbodyRKN8IPhysics14RigidBodyStateE($this,$rigidbody,$state) {
 $this = $this|0;
 $rigidbody = $rigidbody|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Rigidbody11SetPositionERK8Vector3f($rigidbody,$state);
 $0 = (($state) + 12|0);
 __ZN9Rigidbody11SetRotationERK11Quaternionf($rigidbody,$0);
 $1 = (($state) + 28|0);
 __ZN9Rigidbody11SetVelocityERK8Vector3f($rigidbody,$1);
 $2 = (($state) + 40|0);
 __ZN9Rigidbody18SetAngularVelocityERK8Vector3f($rigidbody,$2);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule17GetRigidBodyStateERK9RigidbodyPN8IPhysics14RigidBodyStateE($this,$rigidbody,$result) {
 $this = $this|0;
 $rigidbody = $rigidbody|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 40|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 __ZNK9Rigidbody11GetPositionEv($0,$rigidbody);
 ;HEAP32[$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$result+8>>2]=HEAP32[$0+8>>2]|0;
 $4 = (($result) + 12|0);
 __ZNK9Rigidbody11GetRotationEv($1,$rigidbody);
 ;HEAP32[$4+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$1+12>>2]|0;
 $5 = (($result) + 28|0);
 __ZNK9Rigidbody11GetVelocityEv($2,$rigidbody);
 ;HEAP32[$5+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$2+8>>2]|0;
 $6 = (($result) + 40|0);
 __ZNK9Rigidbody18GetAngularVelocityEv($3,$rigidbody);
 ;HEAP32[$6+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$3+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule20GetRigidBodyVelocityERK9Rigidbody($agg$result,$this,$rigidbody) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $rigidbody = $rigidbody|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK9Rigidbody11GetVelocityEv($agg$result,$rigidbody);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule10GetGravityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z17GetPhysicsManagerv()|0);
 __ZN14PhysicsManager10GetGravityEv($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule24CapsuleColliderSetHeightER15CapsuleColliderf($this,$collider,$height) {
 $this = $this|0;
 $collider = $collider|0;
 $height = Math_fround($height);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15CapsuleCollider9SetHeightEf($collider,$height);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule20ConvertContactToMonoEP9Collision($this,$input) {
 $this = $this|0;
 $input = $input|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20ConvertContactToMonoP9Collision($input)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13PhysicsModule29GetColliderMaterialInstanceIDER8Collider($this,$collider) {
 $this = $this|0;
 $collider = $collider|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN8Collider11GetMaterialEv($0,$collider);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN13PhysicsModule31GetColliderSharedMeshInstanceIDER12MeshCollider($this,$collider) {
 $this = $this|0;
 $collider = $collider|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN12MeshCollider13GetSharedMeshEv($0,$collider);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN13PhysicsModule25CreateNxMeshFromUnityMeshEP4MeshbRK10Matrix4x4f13TransformType($this,$mesh,$convex,$scalematrix,$transformType) {
 $this = $this|0;
 $mesh = $mesh|0;
 $convex = $convex|0;
 $scalematrix = $scalematrix|0;
 $transformType = $transformType|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z25CreatePxMeshFromUnityMeshP4MeshbRK10Matrix4x4f13TransformType($mesh,$convex,$scalematrix,$transformType)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13PhysicsModule29BakeNxMeshStreamFromUnityMeshEP4MeshbbR13dynamic_arrayIhLj1EE($this,$mesh,$convex,$bigEndian,$outstream) {
 $this = $this|0;
 $mesh = $mesh|0;
 $convex = $convex|0;
 $bigEndian = $bigEndian|0;
 $outstream = $outstream|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z29BakePxMeshStreamFromUnityMeshP4MeshbbR13dynamic_arrayIhLj1EE($mesh,$convex,$bigEndian,$outstream);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule33SetUpSkinnedBuffersOnSkinnedClothERN5Unity5ClothEPvS3_S3_jb($this,$cloth,$vertices,$normals,$tangents,$bufferStride,$readback) {
 $this = $this|0;
 $cloth = $cloth|0;
 $vertices = $vertices|0;
 $normals = $normals|0;
 $tangents = $tangents|0;
 $bufferStride = $bufferStride|0;
 $readback = $readback|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity5Cloth19SetUpSkinnedBuffersEPvS1_S1_j($cloth,$vertices,$normals,$tangents,$bufferStride);
 if (!($readback)) {
  STACKTOP = sp;return;
 }
 __ZN5Unity5Cloth22ReadBackSkinnedBuffersEv($cloth);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule18ReleaseHeightFieldEPv($this,$hf) {
 $this = $this|0;
 $hf = $hf|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$hf>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vi[$1 & 4095]($hf);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule19CreateNxHeightFieldEPv($this,$descr) {
 $this = $this|0;
 $descr = $descr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z14GetDynamicsSDKv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iii[$3 & 4095]($0,$descr)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN13PhysicsModule21ReleaseNxTriangleMeshEP17PhysicsModuleMesh($this,$voidmesh) {
 $this = $this|0;
 $voidmesh = $voidmesh|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$voidmesh>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vi[$1 & 4095]($voidmesh);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule19ReleaseNxConvexMeshEP17PhysicsModuleMesh($this,$voidmesh) {
 $this = $this|0;
 $voidmesh = $voidmesh|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$voidmesh>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vi[$1 & 4095]($voidmesh);
 STACKTOP = sp;return;
}
function __ZN13PhysicsModule24CreateNxMeshFromNxStreamEbPKvj($this,$convex,$data,$size) {
 $this = $this|0;
 $convex = $convex|0;
 $data = $data|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $stream = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $stream = sp;
 __ZN12MemoryStreamC2EPhj($stream,$data,$size);
 if ($convex) {
  __THREW__ = 0;
  $0 = (invoke_i(115)|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   $3 = HEAP32[$0>>2]|0;
   $4 = (($3) + 64|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($stream) + 4|0);
   __THREW__ = 0;
   $7 = (invoke_iii($5|0,($0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $20 = $7;
    __ZN12MemoryStreamD2Ev($stream);
    STACKTOP = sp;return ($20|0);
   }
  }
 } else {
  __THREW__ = 0;
  $10 = (invoke_i(115)|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP32[$10>>2]|0;
   $14 = (($13) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($stream) + 4|0);
   __THREW__ = 0;
   $17 = (invoke_iii($15|0,($10|0),($16|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = $17;
    __ZN12MemoryStreamD2Ev($stream);
    STACKTOP = sp;return ($20|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1242,($stream|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($21|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN13PhysicsModule18DeleteMemoryStreamEP19PhysicsModuleStream($this,$stream) {
 $this = $this|0;
 $stream = $stream|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($stream|0)==(0|0);
 if (!($0)) {
  __ZdlPv($stream);
 }
 STACKTOP = sp;return;
}
function __Z27CreatePxStreamFromUnityMeshP4MeshbRK10Matrix4x4f13TransformTypeR12MemoryStream($mesh,$convex,$scalematrix,$transformType,$stream) {
 $mesh = $mesh|0;
 $convex = $convex|0;
 $scalematrix = $scalematrix|0;
 $transformType = $transformType|0;
 $stream = $stream|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $desc = 0, $desc1 = 0, $remap = 0, $triangles = 0, $vertices = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy7 = sp + 176|0;
 $0 = sp + 172|0;
 $1 = sp + 168|0;
 $2 = sp + 164|0;
 $3 = sp + 160|0;
 $4 = sp + 156|0;
 $5 = sp + 152|0;
 $6 = sp + 104|0;
 $vertices = sp + 88|0;
 $triangles = sp + 72|0;
 $remap = sp + 56|0;
 $desc = sp;
 $desc1 = sp + 112|0;
 $7 = HEAP32[628512>>2]|0;
 HEAP32[$vertices>>2] = 0;
 $8 = (($vertices) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = (($vertices) + 8|0);
 HEAP32[$9>>2] = 0;
 $10 = (($vertices) + 12|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$triangles>>2] = 0;
 $11 = (($triangles) + 4|0);
 HEAP32[$11>>2] = $7;
 $12 = (($triangles) + 8|0);
 HEAP32[$12>>2] = 0;
 $13 = (($triangles) + 12|0);
 HEAP32[$13>>2] = 0;
 HEAP32[$remap>>2] = 0;
 $14 = (($remap) + 4|0);
 HEAP32[$14>>2] = $7;
 $15 = (($remap) + 8|0);
 HEAP32[$15>>2] = 0;
 $16 = (($remap) + 12|0);
 HEAP32[$16>>2] = 0;
 __THREW__ = 0;
 $17 = (invoke_iiiii(260,($mesh|0),($vertices|0),($triangles|0),($remap|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L1: do {
  if ($19) {
   label = 6;
  } else {
   do {
    if ($17) {
     $34 = HEAP32[$9>>2]|0;
     $35 = ($transformType|0)==(0);
     if (!($35)) {
      $36 = HEAP32[$vertices>>2]|0;
      __THREW__ = 0;
      invoke_viiiiii(129,($scalematrix|0),($36|0),12,($36|0),12,($34|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 6;
       break L1;
      }
     }
     if ($convex) {
      $39 = (($desc) + 50|0);
      dest=$desc+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
      HEAP16[$39>>1] = 256;
      $40 = (($desc) + 48|0);
      HEAP16[$40>>1] = 4;
      $41 = (($desc) + 8|0);
      HEAP32[$41>>2] = $34;
      $42 = HEAP32[$vertices>>2]|0;
      $43 = (($desc) + 4|0);
      HEAP32[$43>>2] = $42;
      HEAP32[$desc>>2] = 12;
      __THREW__ = 0;
      $44 = (invoke_i(117)|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 6;
       break L1;
      }
      $47 = HEAP32[$44>>2]|0;
      $48 = (($47) + 28|0);
      $49 = HEAP32[$48>>2]|0;
      __THREW__ = 0;
      $50 = (invoke_iiiii($49|0,($44|0),($desc|0),($stream|0),(0|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 6;
       break L1;
      } else {
       $$0 = $50;
       break;
      }
     } else {
      $53 = (($desc1) + 28|0);
      HEAP32[$53>>2] = 0;
      $54 = (($desc1) + 32|0);
      HEAP32[$54>>2] = 0;
      ;HEAP32[$$byval_copy7+0>>2]=0|0;HEAP32[$$byval_copy7+4>>2]=0|0;HEAP32[$$byval_copy7+8>>2]=0|0;HEAP32[$$byval_copy7+12>>2]=0|0;HEAP32[$$byval_copy7+16>>2]=0|0;HEAP32[$$byval_copy7+20>>2]=0|0;HEAP16[$$byval_copy7+24>>1]=0|0;
      ;HEAP32[$desc1+0>>2]=HEAP32[$$byval_copy7+0>>2]|0;HEAP32[$desc1+4>>2]=HEAP32[$$byval_copy7+4>>2]|0;HEAP32[$desc1+8>>2]=HEAP32[$$byval_copy7+8>>2]|0;HEAP32[$desc1+12>>2]=HEAP32[$$byval_copy7+12>>2]|0;HEAP32[$desc1+16>>2]=HEAP32[$$byval_copy7+16>>2]|0;HEAP32[$desc1+20>>2]=HEAP32[$$byval_copy7+20>>2]|0;
      $55 = (($desc1) + 36|0);
      HEAPF32[$55>>2] = Math_fround(0.00100000004749745130539);
      $56 = (($desc1) + 8|0);
      HEAP32[$56>>2] = $34;
      $57 = HEAP32[$vertices>>2]|0;
      $58 = (($desc1) + 4|0);
      HEAP32[$58>>2] = $57;
      HEAP32[$desc1>>2] = 12;
      $59 = HEAP32[$12>>2]|0;
      $60 = (($59>>>0) / 3)&-1;
      $61 = (($desc1) + 20|0);
      HEAP32[$61>>2] = $60;
      $62 = HEAP32[$triangles>>2]|0;
      $63 = (($desc1) + 16|0);
      HEAP32[$63>>2] = $62;
      $64 = (($desc1) + 12|0);
      HEAP32[$64>>2] = 6;
      $65 = (($desc1) + 24|0);
      $66 = $transformType & 4;
      $67 = ($66|0)==(0);
      $$ = $67 ? 2 : 3;
      HEAP16[$65>>1] = $$;
      __THREW__ = 0;
      $68 = (invoke_i(117)|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 6;
       break L1;
      }
      $71 = HEAP32[$68>>2]|0;
      $72 = (($71) + 16|0);
      $73 = HEAP32[$72>>2]|0;
      __THREW__ = 0;
      $74 = (invoke_iiii($73|0,($68|0),($desc1|0),($stream|0))|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 6;
       break L1;
      } else {
       $$0 = $74;
       break;
      }
     }
    } else {
     $$0 = 0;
    }
   } while(0);
   $77 = HEAP32[$16>>2]|0;
   $78 = ($77|0)>(-1);
   do {
    if ($78) {
     $79 = HEAP32[$remap>>2]|0;
     $80 = HEAP32[$14>>2]|0;
     HEAP32[$0>>2] = $80;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($79|0),($$byval_copy7|0));
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if ($82) {
      $24 = ___cxa_find_matching_catch()|0;
      $25 = tempRet0;
      $$01 = $24;$$02 = $25;
      label = 23;
      break L1;
     } else {
      HEAP32[$remap>>2] = 0;
      break;
     }
    }
   } while(0);
   $83 = HEAP32[$13>>2]|0;
   $84 = ($83|0)>(-1);
   do {
    if ($84) {
     $85 = HEAP32[$triangles>>2]|0;
     $86 = HEAP32[$11>>2]|0;
     HEAP32[$1>>2] = $86;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($85|0),($$byval_copy7|0));
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      $22 = ___cxa_find_matching_catch()|0;
      $23 = tempRet0;
      $$1 = $22;$$13 = $23;
      label = 29;
      break L1;
     } else {
      HEAP32[$triangles>>2] = 0;
      break;
     }
    }
   } while(0);
   HEAP32[$2>>2] = $7;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,(0|0),($$byval_copy7|0));
   $89 = __THREW__; __THREW__ = 0;
   $90 = $89&1;
   if ($90) {
    $20 = ___cxa_find_matching_catch()|0;
    $21 = tempRet0;
    $$2 = $20;$$24 = $21;
    break;
   }
   $97 = HEAP32[$10>>2]|0;
   $98 = ($97|0)>(-1);
   if (!($98)) {
    STACKTOP = sp;return ($$0|0);
   }
   $99 = HEAP32[$vertices>>2]|0;
   $100 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $100;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($99,$$byval_copy7);
   HEAP32[$vertices>>2] = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 do {
  if ((label|0) == 6) {
   $26 = ___cxa_find_matching_catch()|0;
   $27 = tempRet0;
   $28 = HEAP32[$16>>2]|0;
   $29 = ($28|0)>(-1);
   if ($29) {
    $30 = HEAP32[$remap>>2]|0;
    $31 = HEAP32[$14>>2]|0;
    HEAP32[$4>>2] = $31;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($30|0),($$byval_copy7|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     $109 = ___cxa_find_matching_catch(0|0)|0;
     $110 = tempRet0;
     ___clang_call_terminate($109);
     // unreachable;
    } else {
     HEAP32[$remap>>2] = 0;
     $$01 = $26;$$02 = $27;
     label = 23;
     break;
    }
   } else {
    $$01 = $26;$$02 = $27;
    label = 23;
   }
  }
 } while(0);
 do {
  if ((label|0) == 23) {
   $91 = HEAP32[$13>>2]|0;
   $92 = ($91|0)>(-1);
   if ($92) {
    $93 = HEAP32[$triangles>>2]|0;
    $94 = HEAP32[$11>>2]|0;
    HEAP32[$3>>2] = $94;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($93|0),($$byval_copy7|0));
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if ($96) {
     $109 = ___cxa_find_matching_catch(0|0)|0;
     $110 = tempRet0;
     ___clang_call_terminate($109);
     // unreachable;
    } else {
     HEAP32[$triangles>>2] = 0;
     $$1 = $$01;$$13 = $$02;
     label = 29;
     break;
    }
   } else {
    $$1 = $$01;$$13 = $$02;
    label = 29;
   }
  }
 } while(0);
 if ((label|0) == 29) {
  HEAP32[$5>>2] = $7;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,(0|0),($$byval_copy7|0));
  $101 = __THREW__; __THREW__ = 0;
  $102 = $101&1;
  if ($102) {
   $109 = ___cxa_find_matching_catch(0|0)|0;
   $110 = tempRet0;
   ___clang_call_terminate($109);
   // unreachable;
  } else {
   $$2 = $$1;$$24 = $$13;
  }
 }
 $103 = HEAP32[$10>>2]|0;
 $104 = ($103|0)>(-1);
 if (!($104)) {
  ___resumeException($$2|0);
  // unreachable;
 }
 $105 = HEAP32[$vertices>>2]|0;
 $106 = HEAP32[$8>>2]|0;
 HEAP32[$6>>2] = $106;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_vii(2591,($105|0),($$byval_copy7|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch(0|0)|0;
  $110 = tempRet0;
  ___clang_call_terminate($109);
  // unreachable;
 }
 HEAP32[$vertices>>2] = 0;
 ___resumeException($$2|0);
 // unreachable;
 return 0|0;
}
function __Z25CreatePxMeshFromUnityMeshP4MeshbRK10Matrix4x4f13TransformType($mesh,$convex,$scalematrix,$transformType) {
 $mesh = $mesh|0;
 $convex = $convex|0;
 $scalematrix = $scalematrix|0;
 $transformType = $transformType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $stream = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $stream = sp;
 __ZN12MemoryStreamC2EPhj($stream,0,0);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(209,($mesh|0),($convex|0),($scalematrix|0),($transformType|0),($stream|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if (!($0)) {
    $$0 = 0;
    __ZN12MemoryStreamD2Ev($stream);
    STACKTOP = sp;return ($$0|0);
   }
   if ($convex) {
    __THREW__ = 0;
    $7 = (invoke_i(115)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[$7>>2]|0;
    $11 = (($10) + 64|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($stream) + 4|0);
    __THREW__ = 0;
    $14 = (invoke_iii($12|0,($7|0),($13|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $$0 = $14;
    __ZN12MemoryStreamD2Ev($stream);
    STACKTOP = sp;return ($$0|0);
   } else {
    __THREW__ = 0;
    $17 = (invoke_i(115)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = HEAP32[$17>>2]|0;
    $21 = (($20) + 36|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($stream) + 4|0);
    __THREW__ = 0;
    $24 = (invoke_iii($22|0,($17|0),($23|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $$0 = $24;
    __ZN12MemoryStreamD2Ev($stream);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1242,($stream|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $27 = ___cxa_find_matching_catch(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($3|0);
  // unreachable;
 }
 return 0|0;
}
function __Z29BakePxMeshStreamFromUnityMeshP4MeshbbR13dynamic_arrayIhLj1EE($mesh,$convex,$bigEndian,$outstream) {
 $mesh = $mesh|0;
 $convex = $convex|0;
 $bigEndian = $bigEndian|0;
 $outstream = $outstream|0;
 var $$ = 0, $$byval_copy2 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $matrix = 0, $memoryStream = 0, $oldParams = 0, $params = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy2 = sp + 192|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $oldParams = sp + 12|0;
 $params = sp + 56|0;
 $memoryStream = sp + 100|0;
 $matrix = sp + 128|0;
 $3 = (__Z10GetCookingv()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($3)|0);
 ;HEAP32[$oldParams+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$oldParams+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$oldParams+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$oldParams+12>>2]=HEAP32[$7+12>>2]|0;HEAP32[$oldParams+16>>2]=HEAP32[$7+16>>2]|0;HEAP32[$oldParams+20>>2]=HEAP32[$7+20>>2]|0;HEAP32[$oldParams+24>>2]=HEAP32[$7+24>>2]|0;
 $8 = (($7) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($oldParams) + 28|0);
 HEAP32[$10>>2] = $9;
 $11 = (($oldParams) + 32|0);
 $12 = (($7) + 32|0);
 ;HEAP32[$11+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$12+8>>2]|0;
 ;HEAP32[$params+0>>2]=HEAP32[$oldParams+0>>2]|0;HEAP32[$params+4>>2]=HEAP32[$oldParams+4>>2]|0;HEAP32[$params+8>>2]=HEAP32[$oldParams+8>>2]|0;HEAP32[$params+12>>2]=HEAP32[$oldParams+12>>2]|0;HEAP32[$params+16>>2]=HEAP32[$oldParams+16>>2]|0;HEAP32[$params+20>>2]=HEAP32[$oldParams+20>>2]|0;HEAP32[$params+24>>2]=HEAP32[$oldParams+24>>2]|0;
 $13 = (($params) + 28|0);
 HEAP32[$13>>2] = $9;
 $14 = (($params) + 32|0);
 ;HEAP32[$14+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$11+8>>2]|0;
 $$ = $bigEndian&1;
 HEAP32[$params>>2] = $$;
 $15 = (__Z10GetCookingv()|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($15,$params);
 __ZN12MemoryStreamC2EPhj($memoryStream,0,0);
 __THREW__ = 0;
 $19 = (invoke_iiiiii(209,($mesh|0),($convex|0),($matrix|0),0,($memoryStream|0))|0);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L1: do {
  if (!($21)) {
   if ($19) {
    $22 = (($memoryStream) + 24|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($memoryStream) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($outstream) + 8|0);
    HEAP32[$26>>2] = $25;
    $27 = (($outstream) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = $28 & 2147483647;
    $30 = ($29>>>0)<($25>>>0);
    do {
     if ($30) {
      $31 = ($28|0)>(-1);
      if ($31) {
       HEAP32[$27>>2] = $25;
       $32 = HEAP32[$outstream>>2]|0;
       $33 = (($outstream) + 4|0);
       $34 = HEAP32[$33>>2]|0;
       HEAP32[$0>>2] = $34;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       $35 = (invoke_iiiiiiii(108,($32|0),($25|0),1,($$byval_copy2|0),0,(691392|0),370)|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break L1;
       }
       HEAP32[$outstream>>2] = $35;
       $46 = $35;
       break;
      } else {
       $38 = (($outstream) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       HEAP32[$1>>2] = $39;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
       $40 = (invoke_iiiiiii(102,($25|0),1,($$byval_copy2|0),0,(691392|0),352)|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break L1;
       }
       $43 = HEAP32[$outstream>>2]|0;
       $44 = HEAP32[$26>>2]|0;
       _memcpy(($40|0),($43|0),($44|0))|0;
       HEAP32[$27>>2] = $25;
       HEAP32[$outstream>>2] = $40;
       $46 = $40;
       break;
      }
     } else {
      $$pre$i = HEAP32[$outstream>>2]|0;
      $46 = $$pre$i;
     }
    } while(0);
    $45 = HEAP32[$26>>2]|0;
    _memcpy(($46|0),($23|0),($45|0))|0;
   } else {
    $51 = (($outstream) + 12|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)>(-1);
    if ($53) {
     $54 = HEAP32[$outstream>>2]|0;
     $55 = (($outstream) + 4|0);
     $56 = HEAP32[$55>>2]|0;
     HEAP32[$2>>2] = $56;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($54|0),($$byval_copy2|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     HEAP32[$outstream>>2] = 0;
    }
    $59 = (($outstream) + 8|0);
    HEAP32[$59>>2] = 0;
    HEAP32[$51>>2] = 0;
   }
   __THREW__ = 0;
   $60 = (invoke_i(117)|0);
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if (!($62)) {
    $63 = HEAP32[$60>>2]|0;
    $64 = (($63) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    __THREW__ = 0;
    invoke_vii($65|0,($60|0),($oldParams|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if (!($67)) {
     __ZN12MemoryStreamD2Ev($memoryStream);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $47 = ___cxa_find_matching_catch()|0;
 $48 = tempRet0;
 __THREW__ = 0;
 invoke_vi(1242,($memoryStream|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $68 = ___cxa_find_matching_catch(0|0)|0;
  $69 = tempRet0;
  ___clang_call_terminate($68);
  // unreachable;
 } else {
  ___resumeException($47|0);
  // unreachable;
 }
}
function __Z19ExtractDataFromMeshR4MeshR13dynamic_arrayI8Vector3fLj4EERS1_ItLj2EES6_($mesh,$vertices,$triangles,$remap) {
 $mesh = $mesh|0;
 $vertices = $vertices|0;
 $triangles = $triangles|0;
 $remap = $remap|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $submesh$011 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy7 = sp;
 $0 = sp + 28|0;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = (($mesh) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 100|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($4) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $11 = ($mesh|0)==(0|0);
  if ($11) {
   $14 = 0;
  } else {
   $12 = (($mesh) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(691400,0,691496,17,1,$14,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($vertices) + 8|0);
 HEAP32[$15>>2] = $6;
 $16 = (($vertices) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 2147483647;
 $19 = ($18>>>0)<($6>>>0);
 do {
  if ($19) {
   $20 = ($17|0)>(-1);
   if ($20) {
    HEAP32[$16>>2] = $6;
    $21 = HEAP32[$vertices>>2]|0;
    $22 = ($6*12)|0;
    $23 = (($vertices) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = $24;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    $25 = (__Z16realloc_internalPvji10MemLabelIdiPKci($21,$22,4,$$byval_copy7,0,691496,370)|0);
    HEAP32[$vertices>>2] = $25;
    $33 = $25;
    break;
   } else {
    $26 = ($6*12)|0;
    $27 = (($vertices) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$0>>2] = $28;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($26,4,$$byval_copy7,0,691496,352)|0);
    $30 = HEAP32[$vertices>>2]|0;
    $31 = HEAP32[$15>>2]|0;
    $32 = ($31*12)|0;
    _memcpy(($29|0),($30|0),($32|0))|0;
    HEAP32[$16>>2] = $6;
    HEAP32[$vertices>>2] = $29;
    $33 = $29;
    break;
   }
  } else {
   $$pre = HEAP32[$vertices>>2]|0;
   $33 = $$pre;
  }
 } while(0);
 __ZNK4Mesh18ExtractVertexArrayEP8Vector3f($mesh,$33);
 $34 = (($triangles) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)>(-1);
 if ($36) {
  $37 = HEAP32[$triangles>>2]|0;
  $38 = (($triangles) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  HEAP32[$0>>2] = $39;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy7);
  HEAP32[$triangles>>2] = 0;
 }
 $40 = (($triangles) + 8|0);
 HEAP32[$40>>2] = 0;
 HEAP32[$34>>2] = 0;
 $41 = (__ZNK4Mesh15GetSubMeshCountEv($mesh)|0);
 $42 = ($41|0)==(0);
 L21: do {
  if (!($42)) {
   $43 = (($mesh) + 44|0);
   $44 = (($triangles) + 4|0);
   $submesh$011 = 0;
   while(1) {
    $45 = (__ZNK4Mesh15GetSubMeshCountEv($mesh)|0);
    $46 = ($submesh$011>>>0)<($45>>>0);
    if (!($46)) {
     label = 16;
     break;
    }
    $72 = (__ZN4Mesh18GetSubMeshBuffer16Ei($mesh,$submesh$011)|0);
    $73 = ($72|0)==(0|0);
    if ($73) {
     label = 27;
     break;
    }
    $99 = HEAP32[$43>>2]|0;
    $100 = (($99) + (($submesh$011*56)|0)|0);
    $101 = HEAP32[$100>>2]|0;
    if ((($101|0) == 0)) {
     $125 = HEAP32[$triangles>>2]|0;
     $126 = HEAP32[$40>>2]|0;
     $127 = (($125) + ($126<<1)|0);
     $128 = ((($99) + (($submesh$011*56)|0)|0) + 8|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = (($72) + ($129<<1)|0);
     (__ZN13dynamic_arrayItLj2EE6insertEPtPKtS3_($triangles,$127,$72,$130)|0);
    } else if ((($101|0) == 1)) {
     $102 = HEAP32[$40>>2]|0;
     $103 = ((($99) + (($submesh$011*56)|0)|0) + 8|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = (__Z21CountTrianglesInStripItEiPKT_i($72,$104)|0);
     $106 = ($105*3)|0;
     $107 = (($106) + ($102))|0;
     HEAP32[$40>>2] = $107;
     $108 = HEAP32[$34>>2]|0;
     $109 = $108 & 2147483647;
     $110 = ($109>>>0)<($107>>>0);
     do {
      if ($110) {
       $111 = ($108|0)>(-1);
       if ($111) {
        HEAP32[$34>>2] = $107;
        $112 = HEAP32[$triangles>>2]|0;
        $113 = $107 << 1;
        $114 = HEAP32[$44>>2]|0;
        HEAP32[$0>>2] = $114;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
        $115 = (__Z16realloc_internalPvji10MemLabelIdiPKci($112,$113,2,$$byval_copy7,0,691496,370)|0);
        HEAP32[$triangles>>2] = $115;
        $124 = $115;
        break;
       } else {
        $116 = $107 << 1;
        $117 = HEAP32[$44>>2]|0;
        HEAP32[$0>>2] = $117;
        ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
        $118 = (__Z15malloc_internaljj10MemLabelIdiPKci($116,2,$$byval_copy7,0,691496,352)|0);
        $119 = HEAP32[$triangles>>2]|0;
        $120 = HEAP32[$40>>2]|0;
        $121 = $120 << 1;
        _memcpy(($118|0),($119|0),($121|0))|0;
        HEAP32[$34>>2] = $107;
        HEAP32[$triangles>>2] = $118;
        $124 = $118;
        break;
       }
      } else {
       $$pre15 = HEAP32[$triangles>>2]|0;
       $124 = $$pre15;
      }
     } while(0);
     $122 = HEAP32[$103>>2]|0;
     $123 = (($124) + ($102<<1)|0);
     __Z10DestripifyIttEvPKT_iPT0_i($72,$122,$123,$105);
    } else {
     label = 45;
     break;
    }
    $135 = (($submesh$011) + 1)|0;
    $136 = (__ZNK4Mesh15GetSubMeshCountEv($mesh)|0);
    $137 = ($135>>>0)<($136>>>0);
    if ($137) {
     $submesh$011 = $135;
    } else {
     break L21;
    }
   }
   if ((label|0) == 16) {
    HEAP32[$$byval_copy7>>2] = $submesh$011;
    __Z6FormatPKcz($1,691504,$$byval_copy7);
    $47 = ($mesh|0)==(0|0);
    if ($47) {
     $57 = 0;
    } else {
     $48 = (($mesh) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $57 = $49;
    }
    $50 = HEAP8[$1>>0]|0;
    $51 = $50 & 1;
    $52 = ($51<<24>>24)==(0);
    if ($52) {
     $55 = (($1) + 1|0);
     $56 = $55;
    } else {
     $53 = (($1) + 8|0);
     $54 = HEAP32[$53>>2]|0;
     $56 = $54;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($56|0),0,(691496|0),29,1,($57|0),0,(0|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     $65 = ___cxa_find_matching_catch()|0;
     $66 = tempRet0;
     $67 = HEAP8[$1>>0]|0;
     $68 = $67 & 1;
     $69 = ($68<<24>>24)==(0);
     if ($69) {
      $$01 = $65;$$02 = $66;
      ___resumeException($$01|0);
      // unreachable;
     }
     $70 = (($1) + 8|0);
     $71 = HEAP32[$70>>2]|0;
     __ZdlPv($71);
     $$01 = $65;$$02 = $66;
     ___resumeException($$01|0);
     // unreachable;
    } else {
     $60 = HEAP8[$1>>0]|0;
     $61 = $60 & 1;
     $62 = ($61<<24>>24)==(0);
     if ($62) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $63 = (($1) + 8|0);
     $64 = HEAP32[$63>>2]|0;
     __ZdlPv($64);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   else if ((label|0) == 27) {
    HEAP32[$$byval_copy7>>2] = $submesh$011;
    __Z6FormatPKcz($2,691568,$$byval_copy7);
    $74 = ($mesh|0)==(0|0);
    if ($74) {
     $84 = 0;
    } else {
     $75 = (($mesh) + 4|0);
     $76 = HEAP32[$75>>2]|0;
     $84 = $76;
    }
    $77 = HEAP8[$2>>0]|0;
    $78 = $77 & 1;
    $79 = ($78<<24>>24)==(0);
    if ($79) {
     $82 = (($2) + 1|0);
     $83 = $82;
    } else {
     $80 = (($2) + 8|0);
     $81 = HEAP32[$80>>2]|0;
     $83 = $81;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($83|0),0,(691496|0),36,1,($84|0),0,(0|0));
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     $92 = ___cxa_find_matching_catch()|0;
     $93 = tempRet0;
     $94 = HEAP8[$2>>0]|0;
     $95 = $94 & 1;
     $96 = ($95<<24>>24)==(0);
     if ($96) {
      $$01 = $92;$$02 = $93;
      ___resumeException($$01|0);
      // unreachable;
     }
     $97 = (($2) + 8|0);
     $98 = HEAP32[$97>>2]|0;
     __ZdlPv($98);
     $$01 = $92;$$02 = $93;
     ___resumeException($$01|0);
     // unreachable;
    } else {
     $87 = HEAP8[$2>>0]|0;
     $88 = $87 & 1;
     $89 = ($88<<24>>24)==(0);
     if ($89) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $90 = (($2) + 8|0);
     $91 = HEAP32[$90>>2]|0;
     __ZdlPv($91);
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   else if ((label|0) == 45) {
    $131 = ($mesh|0)==(0|0);
    if ($131) {
     $134 = 0;
    } else {
     $132 = (($mesh) + 4|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = $133;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(691624,0,691496,54,1,$134,0,0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 (__Z15WeldVertexArrayR13dynamic_arrayI8Vector3fLj4EERS_ItLj2EES4_($vertices,$triangles,$remap)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13dynamic_arrayItLj2EE6insertEPtPKtS3_($this,$insert_before,$input_begin,$input_end) {
 $this = $this|0;
 $insert_before = $insert_before|0;
 $input_begin = $input_begin|0;
 $input_end = $input_end|0;
 var $$byval_copy1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = $insert_before;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 1;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) - ($5))|0;
 $9 = $input_end;
 $10 = $input_begin;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 1;
 $13 = (($7) + ($12))|0;
 HEAP32[$6>>2] = $13;
 $14 = (($this) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($13>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $13;
    $19 = $13 << 1;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$19,2,$$byval_copy1,0,691496,370)|0);
    HEAP32[$this>>2] = $22;
    $31 = $22;
    break;
   } else {
    $23 = $13 << 1;
    $24 = (($this) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    HEAP32[$0>>2] = $25;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,2,$$byval_copy1,0,691496,352)|0);
    $27 = HEAP32[$this>>2]|0;
    $28 = HEAP32[$6>>2]|0;
    $29 = $28 << 1;
    _memcpy(($26|0),($27|0),($29|0))|0;
    HEAP32[$14>>2] = $13;
    HEAP32[$this>>2] = $26;
    $31 = $26;
    break;
   }
  } else {
   $31 = $1;
  }
 } while(0);
 $30 = (($31) + ($5<<1)|0);
 $$sum = (($5) + ($12))|0;
 $32 = (($31) + ($$sum<<1)|0);
 $33 = $8 << 1;
 _memmove(($32|0),($30|0),($33|0))|0;
 _memcpy(($30|0),($input_begin|0),($11|0))|0;
 STACKTOP = sp;return ($30|0);
}
function __ZN12MemoryStreamC2EPhj($this,$data,$len) {
 $this = $this|0;
 $data = $data|0;
 $len = $len|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 HEAP32[$this>>2] = ((691680 + 8|0));
 HEAP32[$1>>2] = ((691680 + 32|0));
 $2 = ($data|0)==(0|0);
 if ($2) {
  $5 = HEAP32[628408>>2]|0;
  HEAP32[$0>>2] = $5;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $6 = (__Z15malloc_internaljj10MemLabelIdiPKci($len,16,$$byval_copy,0,691728,25)|0);
  $7 = (($this) + 24|0);
  HEAP32[$7>>2] = $6;
  $8 = (($this) + 8|0);
  HEAP8[$8>>0] = 1;
 } else {
  $3 = (($this) + 24|0);
  HEAP32[$3>>2] = $data;
  $4 = (($this) + 8|0);
  HEAP8[$4>>0] = 0;
 }
 $9 = (($this) + 12|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 16|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 20|0);
 HEAP32[$11>>2] = $len;
 STACKTOP = sp;return;
}
function __ZN12MemoryStreamD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((691680 + 8|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = ((691680 + 32|0));
 $2 = (($this) + 8|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[628408>>2]|0;
 HEAP32[$0>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($6|0),($$byval_copy|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZdlPv($this);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZThn4_N12MemoryStreamD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + -4|0);
 HEAP32[$1>>2] = ((691680 + 8|0));
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = ((691680 + 32|0));
 $3 = (($1) + 8|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  __ZdlPv($1);
  STACKTOP = sp;return;
 }
 $6 = (($1) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[628408>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($7|0),($$byval_copy|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZdlPv($1);
  ___resumeException($11|0);
  // unreachable;
 } else {
  __ZdlPv($1);
  STACKTOP = sp;return;
 }
}
function __ZN12MemoryStreamD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((691680 + 8|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = ((691680 + 32|0));
 $2 = (($this) + 8|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[628408>>2]|0;
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZThn4_N12MemoryStreamD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + -4|0);
 HEAP32[$1>>2] = ((691680 + 8|0));
 $2 = (($1) + 4|0);
 HEAP32[$2>>2] = ((691680 + 32|0));
 $3 = (($1) + 8|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($1) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[628408>>2]|0;
 HEAP32[$0>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN12MemoryStream4readEPvj($this,$buffer,$size) {
 $this = $this|0;
 $buffer = $buffer|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($size))|0;
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 $6 = (($4) - ($1))|0;
 $7 = $5 ? $6 : $size;
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($1)|0);
 _memcpy(($buffer|0),($10|0),($7|0))|0;
 $11 = HEAP32[$0>>2]|0;
 $12 = (($11) + ($7))|0;
 HEAP32[$0>>2] = $12;
 STACKTOP = sp;return ($7|0);
}
function __ZThn4_N12MemoryStream4readEPvj($this,$buffer,$size) {
 $this = $this|0;
 $buffer = $buffer|0;
 $size = $size|0;
 var $$c = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -4|0);
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($size))|0;
 $4 = (($0) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 $7 = (($5) - ($2))|0;
 $8 = $6 ? $7 : $size;
 $9 = (($0) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($2)|0);
 _memcpy(($buffer|0),($11|0),($8|0))|0;
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + ($8))|0;
 $$c = $13;
 HEAP32[$1>>2] = $$c;
 STACKTOP = sp;return ($8|0);
}
function __ZN12MemoryStream5writeEPKvj($this,$buffer,$size) {
 $this = $this|0;
 $buffer = $buffer|0;
 $size = $size|0;
 var $$ = 0, $$byval_copy1 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($size))|0;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  $$phi$trans$insert = (($this) + 24|0);
  $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
  $21 = $$pre1;$22 = $3;
  $20 = (($21) + ($22)|0);
  _memcpy(($20|0),($buffer|0),($size|0))|0;
  $23 = HEAP32[$2>>2]|0;
  $24 = (($23) + ($size))|0;
  HEAP32[$2>>2] = $24;
  STACKTOP = sp;return ($size|0);
 } else {
  $8 = ($size>>>0)>(4096);
  $9 = $size << 1;
  $$ = $8 ? $9 : 4096;
  $10 = (($6) + ($$))|0;
  $11 = HEAP32[628408>>2]|0;
  HEAP32[$0>>2] = $11;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $12 = (__Z15malloc_internaljj10MemLabelIdiPKci($10,16,$$byval_copy1,0,691728,61)|0);
  $13 = (($this) + 24|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$2>>2]|0;
  _memcpy(($12|0),($14|0),($15|0))|0;
  $16 = HEAP32[$13>>2]|0;
  $17 = HEAP32[628408>>2]|0;
  HEAP32[$1>>2] = $17;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($16,$$byval_copy1);
  HEAP32[$13>>2] = $12;
  $18 = HEAP32[$5>>2]|0;
  $19 = (($18) + ($$))|0;
  HEAP32[$5>>2] = $19;
  $$pre = HEAP32[$2>>2]|0;
  $21 = $12;$22 = $$pre;
  $20 = (($21) + ($22)|0);
  _memcpy(($20|0),($buffer|0),($size|0))|0;
  $23 = HEAP32[$2>>2]|0;
  $24 = (($23) + ($size))|0;
  HEAP32[$2>>2] = $24;
  STACKTOP = sp;return ($size|0);
 }
 return 0|0;
}
function __Z39Rigidbody_Set_Custom_PropFreezeRotationP15ScriptingObjecth($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = ($value<<24>>24)!=(0);
   __ZN9Rigidbody17SetFreezeRotationEb($1,$4);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z31Collider_Set_Custom_PropEnabledP15ScriptingObjecth($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = HEAP32[$1>>2]|0;
   $5 = (($4) + 108|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($value<<24>>24)!=(0);
   FUNCTION_TABLE_vii[$6 & 4095]($1,$7);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z35Collider_CUSTOM_INTERNAL_get_boundsP15ScriptingObjectR4AABB($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  $5 = HEAP32[$2>>2]|0;
  $6 = (($5) + 132|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 4095]($0,$2);
  ;HEAP32[$value+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$value+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$value+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$value+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$value+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$value+20>>2]=HEAP32[$0+20>>2]|0;
  STACKTOP = sp;return;
 }
}
function __Z45CharacterController_CUSTOM_INTERNAL_CALL_MoveP15ScriptingObjectRK8Vector3f($self_,$motion) {
 $self_ = $self_|0;
 $motion = $motion|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (__ZN19CharacterController4MoveERK8Vector3f($1,$motion)|0);
   STACKTOP = sp;return ($4|0);
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return 0|0;
}
function __Z48CharacterController_CUSTOM_INTERNAL_get_velocityP15ScriptingObjectR8Vector3f($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 } else {
  __ZN19CharacterController11GetVelocityEv($0,$2);
  ;HEAP32[$value+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$value+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$value+8>>2]=HEAP32[$0+8>>2]|0;
  STACKTOP = sp;return;
 }
}
function __Z41CharacterController_Get_Custom_PropRadiusP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 84|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   STACKTOP = sp;return (Math_fround($5));
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return Math_fround(0);
}
function __Z41CharacterController_Get_Custom_PropHeightP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 80|0);
   $5 = Math_fround(HEAPF32[$4>>2]);
   STACKTOP = sp;return (Math_fround($5));
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return Math_fround(0);
}
function __Z46CharacterController_CUSTOM_INTERNAL_get_centerP15ScriptingObjectR8Vector3f($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
 } else {
  $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $3 = ($2|0)==(0|0);
  if ($3) {
   $4 = $self_;
  } else {
   __ZN19CharacterController9GetCenterEv($0,$2);
   ;HEAP32[$value+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$value+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$value+8>>2]=HEAP32[$0+8>>2]|0;
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
 // unreachable;
}
function __Z45CharacterController_Get_Custom_PropSlopeLimitP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (Math_fround(__ZN19CharacterController13GetSlopeLimitEv($1)));
   STACKTOP = sp;return (Math_fround($4));
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return Math_fround(0);
}
function __Z45CharacterController_Get_Custom_PropStepOffsetP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (Math_fround(__ZN19CharacterController13GetStepOffsetEv($1)));
   STACKTOP = sp;return (Math_fround($4));
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return Math_fround(0);
}
function __Z49Register_UnityEngine_Rigidbody_set_freezeRotationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(691736,3330);
 STACKTOP = sp;return;
}
function __Z41Register_UnityEngine_Collider_set_enabledv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(691784,3331);
 STACKTOP = sp;return;
}
function __Z49Register_UnityEngine_Collider_INTERNAL_get_boundsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(691824,3332);
 STACKTOP = sp;return;
}
function __Z59Register_UnityEngine_CharacterController_INTERNAL_CALL_Movev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(691872,2558);
 STACKTOP = sp;return;
}
function __Z62Register_UnityEngine_CharacterController_INTERNAL_get_velocityv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(691928,3333);
 STACKTOP = sp;return;
}
function __Z51Register_UnityEngine_CharacterController_get_radiusv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(691984,233);
 STACKTOP = sp;return;
}
function __Z51Register_UnityEngine_CharacterController_get_heightv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(692032,234);
 STACKTOP = sp;return;
}
function __Z60Register_UnityEngine_CharacterController_INTERNAL_get_centerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(692080,3334);
 STACKTOP = sp;return;
}
function __Z55Register_UnityEngine_CharacterController_get_slopeLimitv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(692136,235);
 STACKTOP = sp;return;
}
function __Z55Register_UnityEngine_CharacterController_get_stepOffsetv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(692184,236);
 STACKTOP = sp;return;
}
function __ZNK10Collider2D12GetRigidbodyEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (($this) + 52|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0 = 0;
  } else {
   $9 = HEAP32[$7>>2]|0;
   $10 = ($9|0)==(0);
   if ($10) {
    $$0 = 0;
   } else {
    $11 = (($7) + 148|0);
    $12 = HEAP32[$11>>2]|0;
    $$0 = $12;
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK10Collider2D7GetBodyEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN19CollisionListener2DC2Ev($this) {
 $this = $this|0;
 var $$01$i$i$i$i = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy2 = sp + 160|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 80|0;
 $3 = sp + 152|0;
 $4 = sp + 156|0;
 HEAP32[$this>>2] = ((692232 + 8|0));
 $5 = (($this) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 12|0);
 HEAP8[$6>>0] = 0;
 $7 = (($this) + 13|0);
 $8 = (($this) + 16|0);
 $9 = (($this) + 80|0);
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;HEAP32[$8+28>>2]=0|0;
 $10 = (($this) + 160|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;
 $11 = (($this) + 180|0);
 HEAP32[$11>>2] = 32;
 $12 = (($this) + 184|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 192|0);
 HEAP32[$13>>2] = 16;
 $14 = (($this) + 188|0);
 HEAP32[$14>>2] = 6;
 $15 = (($this) + 196|0);
 HEAP8[$15>>0] = 0;
 $16 = (($this) + 200|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 208|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 212|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 204|0);
 HEAP32[$19>>2] = 61;
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 $20 = (($1) + 56|0);
 ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;
 HEAP8[$7>>0] = 1;
 $21 = (($this) + 96|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 104|0);
 dest=$26+0|0; src=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$0>>2] = 58;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $27 = (invoke_iiiiiii(102,2560,16,($$byval_copy2|0),0,(692264|0),79)|0);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  $30 = (($this) + 176|0);
  HEAP32[$30>>2] = $27;
  $31 = HEAP32[$11>>2]|0;
  $32 = (($27) + (($31*80)|0)|0);
  $33 = ($27|0)==($32|0);
  if (!($33)) {
   $$01$i$i$i$i = $27;
   while(1) {
    $34 = ($$01$i$i$i$i|0)==(0|0);
    if (!($34)) {
     dest=$$01$i$i$i$i+0|0; src=$21+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    }
    $35 = (($$01$i$i$i$i) + 80|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $$01$i$i$i$i = $35;
    }
   }
  }
  $37 = (($this) + 4|0);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
  $38 = (($2) + 56|0);
  ;HEAP32[$38+0>>2]=0|0;HEAP32[$38+4>>2]=0|0;HEAP32[$38+8>>2]=0|0;HEAP32[$38+12>>2]=0|0;
  __THREW__ = 0;
  invoke_vi(3641,($37|0));
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if (!($40)) {
   HEAP8[$6>>0] = 1;
   $41 = $8;
   $42 = $41;
   HEAP32[$42>>2] = -1;
   $43 = (($41) + 4)|0;
   $44 = $43;
   HEAP32[$44>>2] = -1;
   $45 = (($this) + 24|0);
   dest=$45+0|0; src=$2+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   STACKTOP = sp;return;
  }
 }
 $46 = ___cxa_find_matching_catch()|0;
 $47 = tempRet0;
 $48 = HEAP32[$18>>2]|0;
 $49 = ($48|0)>(-1);
 do {
  if ($49) {
   $50 = HEAP32[$16>>2]|0;
   $51 = HEAP32[$19>>2]|0;
   HEAP32[$3>>2] = $51;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($50|0),($$byval_copy2|0));
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $59 = ___cxa_find_matching_catch(0|0)|0;
    $60 = tempRet0;
    ___clang_call_terminate($59);
    // unreachable;
   } else {
    HEAP32[$16>>2] = 0;
    break;
   }
  }
 } while(0);
 $54 = (($this) + 176|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($46|0);
  // unreachable;
 }
 HEAP32[$4>>2] = 58;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$4+0>>2]|0;
 invoke_vii(2591,($55|0),($$byval_copy2|0));
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if ($58) {
  $59 = ___cxa_find_matching_catch(0|0)|0;
  $60 = tempRet0;
  ___clang_call_terminate($59);
  // unreachable;
 } else {
  ___resumeException($46|0);
  // unreachable;
 }
}
function __ZN19CollisionListener2D8PreSolveEP9b2ContactPK10b2Manifold($this,$contact,$oldManifold) {
 $this = $this|0;
 $contact = $contact|0;
 $oldManifold = $oldManifold|0;
 var $$ = 0, $$1 = 0, $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0;
 var $99 = Math_fround(0), $contactPair = 0, $pos$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i = sp + 8|0;
 $contactPair = sp;
 $0 = (($contact) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($contact) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)>($11|0);
 $$ = $12 ? $7 : $5;
 $$1 = $12 ? $5 : $7;
 HEAP32[$contactPair>>2] = $$;
 $13 = (($contactPair) + 4|0);
 HEAP32[$13>>2] = $$1;
 $14 = (($this) + 184|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 do {
  if ($18) {
   $19 = (($this) + 176|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 180|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + (($22*80)|0)|0);
   $36 = $23;
  } else {
   $24 = (($this) + 4|0);
   __ZNK15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E13find_positionERS5_($pos$i$i,$24,$contactPair);
   $25 = HEAP32[$pos$i$i>>2]|0;
   $26 = ($25|0)==(-1);
   $27 = (($this) + 176|0);
   $28 = HEAP32[$27>>2]|0;
   if ($26) {
    $29 = (($this) + 180|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + (($30*80)|0)|0);
    $36 = $31;
    break;
   } else {
    $32 = (($28) + (($25*80)|0)|0);
    $36 = $32;
    break;
   }
  }
 } while(0);
 __ZN10Effector2D15PreSolveContactEP9b2Contact($contact);
 $33 = (($contact) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($36) + 79|0);
 $37 = $34 >>> 2;
 $$lobit = $37 & 1;
 $38 = $$lobit&255;
 HEAP8[$35>>0] = $38;
 $39 = (($36) + 72|0);
 $40 = HEAP32[$39>>2]|0;
 if (!((($40|0) == 4) | (($40|0) == 3) | (($40|0) == 1))) {
  STACKTOP = sp;return;
 }
 $41 = (($contact) + 64|0);
 $42 = (($contact) + 124|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($36) + 24|0);
 HEAP32[$44>>2] = $43;
 $45 = (($36) + 32|0);
 $46 = HEAP32[$0>>2]|0;
 $47 = (($46) + 8|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$2>>2]|0;
 $50 = (($49) + 8|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($46) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($49) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($48) + 12|0);
 $57 = (($53) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($51) + 12|0);
 $60 = (($55) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 __ZN15b2WorldManifold10InitializeEPK10b2ManifoldRK11b2TransformfS5_f($45,$41,$56,$58,$59,$61);
 $62 = ($5|0)==(0|0);
 if ($62) {
  $67 = 0;
 } else {
  $63 = (__ZNK10Collider2D12GetRigidbodyEv($5)|0);
  $67 = $63;
 }
 $64 = ($7|0)==(0|0);
 if ($64) {
  $72 = 0;
 } else {
  $65 = (__ZNK10Collider2D12GetRigidbodyEv($7)|0);
  $72 = $65;
 }
 $66 = ($67|0)==(0|0);
 if ($66) {
  $70 = (__Z22GetPhysicsGroundBody2Dv()|0);
  $77 = $70;
 } else {
  $68 = (($67) + 64|0);
  $69 = HEAP32[$68>>2]|0;
  $77 = $69;
 }
 $71 = ($72|0)==(0|0);
 if ($71) {
  $75 = (__Z22GetPhysicsGroundBody2Dv()|0);
  $98 = $75;
 } else {
  $73 = (($72) + 64|0);
  $74 = HEAP32[$73>>2]|0;
  $98 = $74;
 }
 $76 = (($77) + 72|0);
 $78 = Math_fround(HEAPF32[$76>>2]);
 $79 = (($36) + 40|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($77) + 44|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = Math_fround($80 - $82);
 $84 = (($36) + 44|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($77) + 48|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($85 - $87);
 $89 = Math_fround($78 * $88);
 $90 = Math_fround($78 * $83);
 $91 = (($77) + 64|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($92 - $89);
 $94 = (($77) + 68|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($90 + $95);
 $97 = (($98) + 72|0);
 $99 = Math_fround(HEAPF32[$97>>2]);
 $100 = (($98) + 44|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = Math_fround($80 - $101);
 $103 = (($98) + 48|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = Math_fround($85 - $104);
 $106 = Math_fround($99 * $105);
 $107 = Math_fround($99 * $102);
 $108 = (($98) + 64|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($109 - $106);
 $111 = (($98) + 68|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($107 + $112);
 $114 = Math_fround($110 - $93);
 $115 = Math_fround($113 - $96);
 $116 = (($36) + 64|0);
 HEAPF32[$116>>2] = $114;
 $117 = (($36) + 68|0);
 HEAPF32[$117>>2] = $115;
 STACKTOP = sp;return;
}
function __ZN19CollisionListener2D12BeginContactEP9b2Contact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var $$ = 0, $$1 = 0, $$lobit = 0, $$lobit2 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $collision$0 = 0, $contactPair = 0, $persistedContact$0$off0 = 0, $pos$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i = sp + 8|0;
 $contactPair = sp;
 __ZN10Effector2D12BeginContactEP9b2Contact($contact);
 $0 = (($contact) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = (($contact) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($contact) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12|0)>($14|0);
 $$ = $15 ? $10 : $8;
 $$1 = $15 ? $8 : $10;
 HEAP32[$contactPair>>2] = $$;
 $16 = (($contactPair) + 4|0);
 HEAP32[$16>>2] = $$1;
 $17 = (($this) + 4|0);
 $18 = (($this) + 184|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($19|0)==($21|0);
 do {
  if ($22) {
   $23 = (($this) + 176|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($this) + 180|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) + (($26*80)|0)|0);
   $37 = $24;$38 = $26;$40 = $27;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E13find_positionERS5_($pos$i$i,$17,$contactPair);
   $28 = HEAP32[$pos$i$i>>2]|0;
   $29 = ($28|0)==(-1);
   $30 = (($this) + 176|0);
   $31 = HEAP32[$30>>2]|0;
   if ($29) {
    $32 = (($this) + 180|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($31) + (($33*80)|0)|0);
    $37 = $31;$38 = $33;$40 = $34;
    break;
   } else {
    $35 = (($31) + (($28*80)|0)|0);
    $$phi$trans$insert = (($this) + 180|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $37 = $31;$38 = $$pre;$40 = $35;
    break;
   }
  }
 } while(0);
 $36 = (($37) + (($38*80)|0)|0);
 $39 = ($40|0)==($36|0);
 do {
  if ($39) {
   $50 = (__ZN14dense_hash_mapINSt3__14pairIP10Collider2DS3_EE11Collision2DNS2_23ColliderPairHashFunctorENS0_8equal_toIS4_EE13stl_allocatorINS1_IKS4_S5_EEL18MemLabelIdentifier58ELi16EEEixERSA_($17,$contactPair)|0);
   $collision$0 = $50;$persistedContact$0$off0 = 0;
  } else {
   $41 = (($40) + 8|0);
   $42 = (($40) + 79|0);
   $$lobit2 = $2 >>> 2;
   $43 = $$lobit2&255;
   HEAP8[$42>>0] = $43;
   $44 = (($40) + 72|0);
   $45 = HEAP32[$44>>2]|0;
   if ((($45|0) == 4)) {
    $collision$0 = $41;$persistedContact$0$off0 = 1;
    break;
   } else if (!((($45|0) == 1))) {
    $46 = ($45|0)==(3);
    if (!($46)) {
     $collision$0 = $41;$persistedContact$0$off0 = 0;
     break;
    }
   }
   $47 = (($40) + 28|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($48) + 1)|0;
   HEAP32[$47>>2] = $49;
   STACKTOP = sp;return;
  }
 } while(0);
 $51 = ($8|0)==(0|0);
 if ($51) {
  $59 = 0;
 } else {
  $52 = (__ZNK10Collider2D12GetRigidbodyEv($8)|0);
  $59 = $52;
 }
 $53 = ($10|0)==(0|0);
 if ($53) {
  $61 = 0;
 } else {
  $54 = (__ZNK10Collider2D12GetRigidbodyEv($10)|0);
  $61 = $54;
 }
 if (!($persistedContact$0$off0)) {
  $55 = (($collision$0) + 70|0);
  HEAP8[$55>>0] = 0;
 }
 $56 = (($collision$0) + 71|0);
 $$lobit = $2 >>> 2;
 $57 = $$lobit&255;
 HEAP8[$56>>0] = $57;
 $58 = (($collision$0) + 20|0);
 HEAP32[$58>>2] = 1;
 HEAP32[$collision$0>>2] = $59;
 $60 = (($collision$0) + 4|0);
 HEAP32[$60>>2] = $61;
 $62 = (($collision$0) + 8|0);
 HEAP32[$62>>2] = $8;
 $63 = (($collision$0) + 12|0);
 HEAP32[$63>>2] = $10;
 $64 = (($collision$0) + 68|0);
 HEAP8[$64>>0] = 0;
 $65 = $persistedContact$0$off0 ? 3 : 1;
 $66 = (($collision$0) + 64|0);
 HEAP32[$66>>2] = $65;
 $67 = (($4) + 38|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = ($68<<24>>24)==(0);
 if ($69) {
  $70 = (($6) + 38|0);
  $71 = HEAP8[$70>>0]|0;
  $73 = $71;
 } else {
  $73 = 1;
 }
 $72 = (($collision$0) + 69|0);
 HEAP8[$72>>0] = $73;
 $74 = (($collision$0) + 16|0);
 HEAP32[$74>>2] = 0;
 $75 = (($collision$0) + 56|0);
 $76 = 616640;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = (($76) + 4)|0;
 $80 = $79;
 $81 = HEAP32[$80>>2]|0;
 $82 = $75;
 $83 = $82;
 HEAP32[$83>>2] = $78;
 $84 = (($82) + 4)|0;
 $85 = $84;
 HEAP32[$85>>2] = $81;
 STACKTOP = sp;return;
}
function __ZN14dense_hash_mapINSt3__14pairIP10Collider2DS3_EE11Collision2DNS2_23ColliderPairHashFunctorENS0_8equal_toIS4_EE13stl_allocatorINS1_IKS4_S5_EEL18MemLabelIdentifier58ELi16EEEixERSA_($this,$key) {
 $this = $this|0;
 $key = $key|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pn = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $pos$i$i = sp + 168|0;
 $0 = sp;
 $1 = sp + 80|0;
 $2 = sp + 152|0;
 $3 = (($this) + 180|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 do {
  if ($7) {
   $8 = (($this) + 172|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 176|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + (($11*80)|0)|0);
   $22 = $9;$23 = $11;$25 = $12;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E13find_positionERS5_($pos$i$i,$this,$key);
   $13 = HEAP32[$pos$i$i>>2]|0;
   $14 = ($13|0)==(-1);
   $15 = (($this) + 172|0);
   $16 = HEAP32[$15>>2]|0;
   if ($14) {
    $17 = (($this) + 176|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + (($18*80)|0)|0);
    $22 = $16;$23 = $18;$25 = $19;
    break;
   } else {
    $20 = (($16) + (($13*80)|0)|0);
    $$phi$trans$insert = (($this) + 176|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $22 = $16;$23 = $$pre;$25 = $20;
    break;
   }
  }
 } while(0);
 $21 = (($22) + (($23*80)|0)|0);
 $24 = ($25|0)==($21|0);
 if (!($24)) {
  $$pn = $25;
  $$0 = (($$pn) + 8|0);
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 $26 = (($1) + 56|0);
 ;HEAP32[$26+0>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;HEAP32[$26+12>>2]=0|0;
 $27 = $key;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + 4)|0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = $0;
 $34 = $33;
 HEAP32[$34>>2] = $29;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $32;
 $37 = (($0) + 8|0);
 dest=$37+0|0; src=$1+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E12resize_deltaEjj($this,1,0);
 __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E15insert_noresizeERKS7_($2,$this,$0);
 $38 = (($2) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $$pn = $39;
 $$0 = (($$pn) + 8|0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN19CollisionListener2D10EndContactEP9b2Contact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var $$ = 0, $$6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $contactPair = 0, $phitmp$i$i$i = 0, $pos$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i = sp + 8|0;
 $contactPair = sp;
 __ZN10Effector2D10EndContactEP9b2Contact($contact);
 $0 = (($contact) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 | 4;
 HEAP32[$0>>2] = $2;
 $3 = (($contact) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($contact) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 40|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12|0)>($14|0);
 $$ = $15 ? $10 : $8;
 $$6 = $15 ? $8 : $10;
 HEAP32[$contactPair>>2] = $$;
 $16 = (($contactPair) + 4|0);
 HEAP32[$16>>2] = $$6;
 $17 = (($this) + 184|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18|0)==($20|0);
 do {
  if ($21) {
   $22 = (($this) + 176|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($this) + 180|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($23) + (($25*80)|0)|0);
   $37 = $26;
  } else {
   $27 = (($this) + 4|0);
   __ZNK15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E13find_positionERS5_($pos$i$i,$27,$contactPair);
   $28 = HEAP32[$pos$i$i>>2]|0;
   $29 = ($28|0)==(-1);
   $30 = (($this) + 176|0);
   $31 = HEAP32[$30>>2]|0;
   if ($29) {
    $32 = (($this) + 180|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($31) + (($33*80)|0)|0);
    $37 = $34;
    break;
   } else {
    $35 = (($31) + (($28*80)|0)|0);
    $37 = $35;
    break;
   }
  }
 } while(0);
 $36 = (($37) + 28|0);
 $38 = HEAP32[$36>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$36>>2] = $39;
 $40 = ($39|0)==(0);
 if (!($40)) {
  STACKTOP = sp;return;
 }
 $41 = (($37) + 72|0);
 $42 = (($8) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = (__ZNK5Unity10GameObject8IsActiveEv($43)|0);
  if ($45) {
   $46 = (($8) + 28|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)==(0);
   if (!($48)) {
    $49 = (($10) + 24|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==(0|0);
    if (!($51)) {
     $52 = (__ZNK5Unity10GameObject8IsActiveEv($50)|0);
     if ($52) {
      $53 = (($10) + 28|0);
      $54 = HEAP8[$53>>0]|0;
      $55 = ($54<<24>>24)==(0);
      if (!($55)) {
       $56 = HEAP32[$41>>2]|0;
       if ((($56|0) == 0) | (($56|0) == 4)) {
        STACKTOP = sp;return;
       }
       $57 = (($37) + 78|0);
       $58 = HEAP8[$57>>0]|0;
       $59 = ($58<<24>>24)==(0);
       if (!($59)) {
        HEAP32[$41>>2] = 2;
        STACKTOP = sp;return;
       }
       $60 = (($this) + 176|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($this) + 180|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = (($61) + (($63*80)|0)|0);
       $65 = ($37|0)==($64|0);
       if ($65) {
        STACKTOP = sp;return;
       }
       $66 = (($this) + 12|0);
       $67 = HEAP8[$66>>0]|0;
       $68 = ($67<<24>>24)==(0);
       if ($68) {
        $84 = 1;
       } else {
        $69 = HEAP32[$19>>2]|0;
        $70 = ($69|0)==(0);
        if ($70) {
         $84 = 1;
        } else {
         $71 = (($this) + 16|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = HEAP32[$37>>2]|0;
         $74 = ($72|0)==($73|0);
         if ($74) {
          $75 = (($this) + 20|0);
          $76 = HEAP32[$75>>2]|0;
          $77 = (($37) + 4|0);
          $78 = HEAP32[$77>>2]|0;
          $phitmp$i$i$i = ($76|0)!=($78|0);
          $84 = $phitmp$i$i$i;
         } else {
          $84 = 1;
         }
        }
       }
       $79 = ($37|0)==(0|0);
       if (!($79)) {
        $80 = (($this) + 16|0);
        dest=$37+0|0; src=$80+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       }
       if (!($84)) {
        STACKTOP = sp;return;
       }
       $81 = HEAP32[$19>>2]|0;
       $82 = (($81) + 1)|0;
       HEAP32[$19>>2] = $82;
       $83 = (($this) + 196|0);
       HEAP8[$83>>0] = 1;
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 HEAP32[$41>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN19CollisionListener2DD1Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$01$i = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((692232 + 8|0));
 $3 = (($this) + 212|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 do {
  if ($5) {
   $6 = (($this) + 200|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($this) + 204|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$2>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($7|0),($$byval_copy2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$6>>2] = 0;
    break;
   }
   $17 = ___cxa_find_matching_catch()|0;
   $18 = tempRet0;
   $19 = (($this) + 176|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0$i = $18;$$01$i = $17;
    ___resumeException($$01$i|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 58;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($20|0),($$byval_copy2|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $26 = ___cxa_find_matching_catch(0|0)|0;
    $27 = tempRet0;
    ___clang_call_terminate($26);
    // unreachable;
   } else {
    $$0$i = $18;$$01$i = $17;
    ___resumeException($$01$i|0);
    // unreachable;
   }
  }
 } while(0);
 $12 = (($this) + 176|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 58;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy2|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  STACKTOP = sp;return;
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $$0$i = $25;$$01$i = $24;
 ___resumeException($$01$i|0);
 // unreachable;
}
function __ZN19CollisionListener2DD0Ev($this) {
 $this = $this|0;
 var $$0$i$i = 0, $$01$i$i = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((692232 + 8|0));
 $3 = (($this) + 212|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 do {
  if ($5) {
   $6 = (($this) + 200|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($this) + 204|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$2>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($7|0),($$byval_copy2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$6>>2] = 0;
    break;
   }
   $17 = ___cxa_find_matching_catch()|0;
   $18 = tempRet0;
   $19 = (($this) + 176|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$0$i$i = $18;$$01$i$i = $17;
    __ZdlPv($this);
    ___resumeException($$01$i$i|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 58;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($20|0),($$byval_copy2|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $26 = ___cxa_find_matching_catch(0|0)|0;
    $27 = tempRet0;
    ___clang_call_terminate($26);
    // unreachable;
   } else {
    $$0$i$i = $18;$$01$i$i = $17;
    __ZdlPv($this);
    ___resumeException($$01$i$i|0);
    // unreachable;
   }
  }
 } while(0);
 $12 = (($this) + 176|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 58;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy2|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $$0$i$i = $25;$$01$i$i = $24;
 __ZdlPv($this);
 ___resumeException($$01$i$i|0);
 // unreachable;
}
function __ZN17b2ContactListener9PostSolveEP9b2ContactPK16b2ContactImpulse($this,$contact,$impulse) {
 $this = $this|0;
 $contact = $contact|0;
 $impulse = $impulse|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E13find_positionERS5_($agg$result,$this,$key) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $key = $key|0;
 var $$ = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $num_probes$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 176|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$key>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($key) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + 2127912214)|0;
 $11 = $5 << 12;
 $12 = (($10) + ($11))|0;
 $13 = $12 ^ -949894596;
 $14 = $12 >>> 19;
 $15 = $13 ^ $9;
 $16 = $15 ^ $14;
 $17 = (($16) + 374761393)|0;
 $18 = $16 << 5;
 $19 = (($17) + ($18))|0;
 $20 = (($19) + -744332180)|0;
 $21 = $19 << 9;
 $22 = $20 ^ $21;
 $23 = (($this) + 172|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 92|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 96|0);
 $28 = (($this) + 8|0);
 $29 = (($this) + 4|0);
 $30 = (($this) + 12|0);
 $31 = (($this) + 16|0);
 $$sink = $22;$41 = -1;$num_probes$0 = 0;
 while(1) {
  $32 = $$sink & $2;
  $33 = (($24) + (($32*80)|0)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($26|0)==($34|0);
  if ($35) {
   $36 = HEAP32[$27>>2]|0;
   $37 = ((($24) + (($32*80)|0)|0) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($36|0)==($38|0);
   if ($39) {
    break;
   }
  }
  $43 = HEAP8[$28>>0]|0;
  $44 = ($43<<24>>24)==(0);
  if ($44) {
   label = 12;
  } else {
   $45 = HEAP32[$29>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    label = 12;
   } else {
    $47 = HEAP32[$30>>2]|0;
    $48 = ($47|0)==($34|0);
    if ($48) {
     $49 = HEAP32[$31>>2]|0;
     $50 = ((($24) + (($32*80)|0)|0) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($49|0)==($51|0);
     if ($52) {
      $53 = ($41|0)==(-1);
      $$ = $53 ? $32 : $41;
      $61 = $$;
     } else {
      label = 12;
     }
    } else {
     label = 12;
    }
   }
  }
  if ((label|0) == 12) {
   label = 0;
   $54 = ($3|0)==($34|0);
   if ($54) {
    $55 = ((($24) + (($32*80)|0)|0) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($7|0)==($56|0);
    if ($57) {
     label = 14;
     break;
    } else {
     $61 = $41;
    }
   } else {
    $61 = $41;
   }
  }
  $59 = (($num_probes$0) + 1)|0;
  $60 = (($59) + ($32))|0;
  $$sink = $60;$41 = $61;$num_probes$0 = $59;
 }
 if ((label|0) == 14) {
  HEAP32[$agg$result>>2] = $32;
  $58 = (($agg$result) + 4|0);
  HEAP32[$58>>2] = -1;
  STACKTOP = sp;return;
 }
 $40 = ($41|0)==(-1);
 HEAP32[$agg$result>>2] = -1;
 $42 = (($agg$result) + 4|0);
 if ($40) {
  HEAP32[$42>>2] = $32;
  STACKTOP = sp;return;
 } else {
  HEAP32[$42>>2] = $41;
  STACKTOP = sp;return;
 }
}
function __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E12resize_deltaEjj($this,$delta,$min_buckets_wanted) {
 $this = $this|0;
 $delta = $delta|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $sz$0$i = 0, $sz$0$i1 = 0, $tmp = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy = sp + 200|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 192|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E12maybe_shrinkEv($this);
 }
 $4 = (($this) + 176|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)>($min_buckets_wanted>>>0);
 $7 = (($this) + 180|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  $9 = (($8) + ($delta))|0;
  $10 = (($this) + 188|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9>>>0)>($11>>>0);
  if (!($12)) {
   STACKTOP = sp;return;
  }
 }
 $13 = (($this) + 180|0);
 $14 = (($8) + ($delta))|0;
 $15 = (Math_fround(($14>>>0)));
 $sz$0$i = 32;
 while(1) {
  $16 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($16)) {
   $17 = (Math_fround(($sz$0$i>>>0)));
   $18 = Math_fround($17 * Math_fround(0.5));
   $19 = !($15 >= $18);
   if ($19) {
    break;
   }
  }
  $20 = $sz$0$i << 1;
  $sz$0$i = $20;
 }
 $21 = ($sz$0$i>>>0)>($5>>>0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($14) - ($23))|0;
 $25 = (Math_fround(($24>>>0)));
 $sz$0$i1 = 32;
 while(1) {
  $26 = ($sz$0$i1>>>0)<($min_buckets_wanted>>>0);
  if (!($26)) {
   $27 = (Math_fround(($sz$0$i1>>>0)));
   $28 = Math_fround($27 * Math_fround(0.5));
   $29 = !($25 >= $28);
   if ($29) {
    break;
   }
  }
  $30 = $sz$0$i1 << 1;
  $sz$0$i1 = $30;
 }
 $31 = (($tmp) + 4|0);
 HEAP32[$31>>2] = 0;
 $32 = (($tmp) + 8|0);
 $33 = (($this) + 8|0);
 $34 = HEAP8[$33>>0]|0;
 HEAP8[$32>>0] = $34;
 $35 = (($tmp) + 9|0);
 $36 = (($this) + 9|0);
 $37 = HEAP8[$36>>0]|0;
 HEAP8[$35>>0] = $37;
 $38 = (($tmp) + 12|0);
 $39 = (($this) + 12|0);
 dest=$38+0|0; src=$39+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $40 = (($tmp) + 92|0);
 $41 = (($this) + 92|0);
 dest=$40+0|0; src=$41+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $42 = (($tmp) + 172|0);
 ;HEAP32[$42+0>>2]=0|0;HEAP32[$42+4>>2]=0|0;HEAP32[$42+8>>2]=0|0;HEAP32[$42+12>>2]=0|0;HEAP32[$42+16>>2]=0|0;HEAP8[$42+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E9copy_fromERKSH_j($tmp,$this,$sz$0$i1);
 $43 = HEAP32[$22>>2]|0;
 $44 = HEAP32[$31>>2]|0;
 HEAP32[$22>>2] = $44;
 HEAP32[$31>>2] = $43;
 $45 = HEAP8[$33>>0]|0;
 $46 = HEAP16[$32>>1]|0;
 $47 = $46&255;
 HEAP8[$33>>0] = $47;
 HEAP8[$32>>0] = $45;
 $48 = HEAP8[$36>>0]|0;
 $49 = ($46&65535) >>> 8;
 $50 = $49&255;
 HEAP8[$36>>0] = $50;
 HEAP8[$35>>0] = $48;
 dest=$$byval_copy+0|0; src=$39+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$39+0|0; src=$38+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$38+0|0; src=$$byval_copy+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$$byval_copy+0|0; src=$41+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$41+0|0; src=$40+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$40+0|0; src=$$byval_copy+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $51 = (($this) + 172|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$42>>2]|0;
 HEAP32[$51>>2] = $53;
 HEAP32[$42>>2] = $52;
 $54 = (($tmp) + 176|0);
 $55 = HEAP32[$4>>2]|0;
 $56 = HEAP32[$54>>2]|0;
 HEAP32[$4>>2] = $56;
 HEAP32[$54>>2] = $55;
 $57 = (($tmp) + 180|0);
 $58 = HEAP32[$13>>2]|0;
 $59 = HEAP32[$57>>2]|0;
 HEAP32[$13>>2] = $59;
 HEAP32[$57>>2] = $58;
 $60 = (Math_fround(($56>>>0)));
 $61 = Math_fround($60 * Math_fround(0.5));
 $62 = (~~(($61))>>>0);
 $63 = (($this) + 188|0);
 HEAP32[$63>>2] = $62;
 $64 = Math_fround($60 * Math_fround(0.20000000298023223877));
 $65 = (~~(($64))>>>0);
 $66 = (($this) + 184|0);
 HEAP32[$66>>2] = $65;
 HEAP8[$1>>0] = 0;
 $67 = (Math_fround(($55>>>0)));
 $68 = Math_fround($67 * Math_fround(0.5));
 $69 = (~~(($68))>>>0);
 $70 = (($tmp) + 188|0);
 HEAP32[$70>>2] = $69;
 $71 = Math_fround($67 * Math_fround(0.20000000298023223877));
 $72 = (~~(($71))>>>0);
 $73 = (($tmp) + 184|0);
 HEAP32[$73>>2] = $72;
 $74 = (($tmp) + 192|0);
 HEAP8[$74>>0] = 0;
 $75 = ($52|0)==(0|0);
 if ($75) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($52,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E15insert_noresizeERKS7_($agg$result,$this,$obj) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $obj = $obj|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos = sp;
 __ZNK15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E13find_positionERS5_($pos,$this,$obj);
 $0 = HEAP32[$pos>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  $2 = (($this) + 172|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + (($0*80)|0)|0);
  $5 = (($this) + 176|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + (($6*80)|0)|0);
  HEAP32[$agg$result>>2] = $this;
  $8 = (($agg$result) + 4|0);
  HEAP32[$8>>2] = $4;
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $7;
  $10 = (($agg$result) + 12|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($pos) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  label = 8;
 } else {
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if ($18) {
   label = 8;
  } else {
   $19 = (($this) + 172|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + (($12*80)|0)|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22|0)==($24|0);
   if ($25) {
    $26 = (($this) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($20) + (($12*80)|0)|0) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27|0)==($29|0);
    if ($30) {
     $31 = (($17) + -1)|0;
     HEAP32[$16>>2] = $31;
     $37 = $20;
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  }
 }
 if ((label|0) == 8) {
  $32 = (($this) + 180|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $$phi$trans$insert = (($this) + 172|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $37 = $$pre;
 }
 $35 = (($this) + 172|0);
 $36 = (($37) + (($12*80)|0)|0);
 $38 = ($36|0)==(0|0);
 if (!($38)) {
  dest=$36+0|0; src=$obj+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $39 = HEAP32[$35>>2]|0;
 $40 = (($39) + (($12*80)|0)|0);
 $41 = (($this) + 176|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($39) + (($42*80)|0)|0);
 HEAP32[$agg$result>>2] = $this;
 $44 = (($agg$result) + 4|0);
 HEAP32[$44>>2] = $40;
 $45 = (($agg$result) + 8|0);
 HEAP32[$45>>2] = $43;
 $46 = (($agg$result) + 12|0);
 HEAP8[$46>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E12maybe_shrinkEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $sz$0 = 0, $sz$0$in = 0, $tmp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy = sp + 200|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 180|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) - ($4))|0;
 $6 = (($this) + 184|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if (!($8)) {
  $62 = (($this) + 192|0);
  HEAP8[$62>>0] = 0;
  STACKTOP = sp;return;
 }
 $9 = (($this) + 176|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)>(32);
 if ($11) {
  $sz$0$in = $10;
 } else {
  $62 = (($this) + 192|0);
  HEAP8[$62>>0] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $sz$0 = $sz$0$in >>> 1;
  $12 = ($sz$0$in>>>0)<(66);
  if ($12) {
   break;
  }
  $13 = (Math_fround(($5>>>0)));
  $14 = (Math_fround(($sz$0>>>0)));
  $15 = Math_fround($14 * Math_fround(0.20000000298023223877));
  $16 = $13 < $15;
  if ($16) {
   $sz$0$in = $sz$0;
  } else {
   break;
  }
 }
 $17 = (($tmp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($tmp) + 8|0);
 $19 = (($this) + 8|0);
 $20 = HEAP8[$19>>0]|0;
 HEAP8[$18>>0] = $20;
 $21 = (($tmp) + 9|0);
 $22 = (($this) + 9|0);
 $23 = HEAP8[$22>>0]|0;
 HEAP8[$21>>0] = $23;
 $24 = (($tmp) + 12|0);
 $25 = (($this) + 12|0);
 dest=$24+0|0; src=$25+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $26 = (($tmp) + 92|0);
 $27 = (($this) + 92|0);
 dest=$26+0|0; src=$27+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $28 = (($tmp) + 172|0);
 ;HEAP32[$28+0>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;HEAP32[$28+12>>2]=0|0;HEAP32[$28+16>>2]=0|0;HEAP8[$28+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E9copy_fromERKSH_j($tmp,$this,$sz$0);
 $29 = HEAP32[$3>>2]|0;
 $30 = HEAP32[$17>>2]|0;
 HEAP32[$3>>2] = $30;
 HEAP32[$17>>2] = $29;
 $31 = HEAP8[$19>>0]|0;
 $32 = HEAP16[$18>>1]|0;
 $33 = $32&255;
 HEAP8[$19>>0] = $33;
 HEAP8[$18>>0] = $31;
 $34 = HEAP8[$22>>0]|0;
 $35 = ($32&65535) >>> 8;
 $36 = $35&255;
 HEAP8[$22>>0] = $36;
 HEAP8[$21>>0] = $34;
 dest=$$byval_copy+0|0; src=$25+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$25+0|0; src=$24+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$24+0|0; src=$$byval_copy+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$$byval_copy+0|0; src=$27+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$27+0|0; src=$26+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$26+0|0; src=$$byval_copy+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $37 = (($this) + 172|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$28>>2]|0;
 HEAP32[$37>>2] = $39;
 HEAP32[$28>>2] = $38;
 $40 = (($tmp) + 176|0);
 $41 = HEAP32[$9>>2]|0;
 $42 = HEAP32[$40>>2]|0;
 HEAP32[$9>>2] = $42;
 HEAP32[$40>>2] = $41;
 $43 = (($tmp) + 180|0);
 $44 = HEAP32[$1>>2]|0;
 $45 = HEAP32[$43>>2]|0;
 HEAP32[$1>>2] = $45;
 HEAP32[$43>>2] = $44;
 $46 = (Math_fround(($42>>>0)));
 $47 = Math_fround($46 * Math_fround(0.5));
 $48 = (~~(($47))>>>0);
 $49 = (($this) + 188|0);
 HEAP32[$49>>2] = $48;
 $50 = Math_fround($46 * Math_fround(0.20000000298023223877));
 $51 = (~~(($50))>>>0);
 HEAP32[$6>>2] = $51;
 $52 = (($this) + 192|0);
 HEAP8[$52>>0] = 0;
 $53 = (Math_fround(($41>>>0)));
 $54 = Math_fround($53 * Math_fround(0.5));
 $55 = (~~(($54))>>>0);
 $56 = (($tmp) + 188|0);
 HEAP32[$56>>2] = $55;
 $57 = Math_fround($53 * Math_fround(0.20000000298023223877));
 $58 = (~~(($57))>>>0);
 $59 = (($tmp) + 184|0);
 HEAP32[$59>>2] = $58;
 $60 = (($tmp) + 192|0);
 HEAP8[$60>>0] = 0;
 $61 = ($38|0)==(0|0);
 if ($61) {
  $62 = (($this) + 192|0);
  HEAP8[$62>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($38,$$byval_copy);
 $62 = (($this) + 192|0);
 HEAP8[$62>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E9copy_fromERKSH_j($this,$ht,$min_buckets_wanted) {
 $this = $this|0;
 $ht = $ht|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$01$i$i$i = 0, $$01$i$i$i5 = 0, $$012$i$i = 0, $$03$i$i = 0, $$be = 0, $$byval_copy3 = 0, $$ph8 = 0, $$pn = 0, $$pre = 0, $$pre$i = 0, $$pre$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucknum$0 = 0, $num_probes$0 = 0, $sz$0$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 172|0);
 $2 = (($this) + 176|0);
 HEAP32[$2>>2] = 32;
 $3 = (($this) + 188|0);
 HEAP32[$3>>2] = 16;
 $4 = (($this) + 184|0);
 HEAP32[$4>>2] = 6;
 $5 = (($this) + 192|0);
 HEAP8[$5>>0] = 0;
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Z15malloc_internaljj10MemLabelIdiPKci(2560,16,$$byval_copy3,0,692264,79)|0);
 $7 = HEAP32[$1>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy3);
 }
 HEAP32[$1>>2] = $6;
 $9 = HEAP32[$2>>2]|0;
 $10 = (($6) + (($9*80)|0)|0);
 $11 = ($6|0)==($10|0);
 if (!($11)) {
  $12 = (($this) + 92|0);
  $$01$i$i$i = $6;
  while(1) {
   $13 = ($$01$i$i$i|0)==(0|0);
   if (!($13)) {
    dest=$$01$i$i$i+0|0; src=$12+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $14 = (($$01$i$i$i) + 80|0);
   $15 = ($14|0)==($10|0);
   if ($15) {
    break;
   } else {
    $$01$i$i$i = $14;
   }
  }
 }
 $16 = (($this) + 180|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($ht) + 180|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($ht) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) - ($21))|0;
 $23 = (Math_fround(($22>>>0)));
 $sz$0$i = 32;
 while(1) {
  $24 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($24)) {
   $25 = (Math_fround(($sz$0$i>>>0)));
   $26 = Math_fround($25 * Math_fround(0.5));
   $27 = !($23 >= $26);
   if ($27) {
    break;
   }
  }
  $28 = $sz$0$i << 1;
  $sz$0$i = $28;
 }
 $29 = HEAP32[$2>>2]|0;
 $30 = ($sz$0$i>>>0)>($29>>>0);
 if ($30) {
  $31 = ($sz$0$i*80)|0;
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $32 = (__Z15malloc_internaljj10MemLabelIdiPKci($31,16,$$byval_copy3,0,692264,79)|0);
  $33 = HEAP32[$1>>2]|0;
  $34 = HEAP32[$2>>2]|0;
  $35 = ($34>>>0)>($sz$0$i>>>0);
  $36 = $35 ? $sz$0$i : $34;
  $37 = (($33) + (($36*80)|0)|0);
  $38 = ($36|0)==(0);
  if ($38) {
   $45 = $34;
  } else {
   $$012$i$i = $32;$$03$i$i = $33;
   while(1) {
    $39 = ($$012$i$i|0)==(0|0);
    if (!($39)) {
     dest=$$012$i$i+0|0; src=$$03$i$i+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    }
    $40 = (($$03$i$i) + 80|0);
    $41 = (($$012$i$i) + 80|0);
    $42 = ($40|0)==($37|0);
    if ($42) {
     break;
    } else {
     $$012$i$i = $41;$$03$i$i = $40;
    }
   }
   $$pre$i3 = HEAP32[$2>>2]|0;
   $45 = $$pre$i3;
  }
  $43 = (($32) + (($sz$0$i*80)|0)|0);
  $44 = ($45|0)==($sz$0$i|0);
  if (!($44)) {
   $46 = (($32) + (($45*80)|0)|0);
   $47 = (($this) + 92|0);
   $$01$i$i$i5 = $46;
   while(1) {
    $48 = ($$01$i$i$i5|0)==(0|0);
    if (!($48)) {
     dest=$$01$i$i$i5+0|0; src=$47+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    }
    $49 = (($$01$i$i$i5) + 80|0);
    $50 = ($49|0)==($43|0);
    if ($50) {
     break;
    } else {
     $$01$i$i$i5 = $49;
    }
   }
  }
  $51 = HEAP32[$1>>2]|0;
  HEAP32[$0>>2] = 58;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($51,$$byval_copy3);
  HEAP32[$1>>2] = $32;
  HEAP32[$2>>2] = $sz$0$i;
  $52 = (~~(($26))>>>0);
  HEAP32[$3>>2] = $52;
  $53 = Math_fround($25 * Math_fround(0.20000000298023223877));
  $54 = (~~(($53))>>>0);
  HEAP32[$4>>2] = $54;
  HEAP8[$5>>0] = 0;
  $157 = $sz$0$i;
 } else {
  $157 = $29;
 }
 $55 = (($ht) + 172|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($ht) + 176|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($56) + (($58*80)|0)|0);
 $60 = ($58|0)==(0);
 L37: do {
  if ($60) {
   $$ph8 = $56;
  } else {
   $61 = (($ht) + 12|0);
   $62 = (($ht) + 16|0);
   $63 = (($ht) + 92|0);
   $64 = (($ht) + 96|0);
   $65 = (($ht) + 8|0);
   $$pre$i = HEAP32[$63>>2]|0;
   $67 = $56;
   while(1) {
    $66 = HEAP32[$67>>2]|0;
    $68 = ($$pre$i|0)==($66|0);
    if ($68) {
     $69 = HEAP32[$64>>2]|0;
     $70 = (($67) + 4|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = ($69|0)==($71|0);
     if (!($72)) {
      label = 28;
     }
    } else {
     label = 28;
    }
    if ((label|0) == 28) {
     label = 0;
     $73 = HEAP8[$65>>0]|0;
     $74 = ($73<<24>>24)==(0);
     if ($74) {
      $$ph8 = $67;
      break L37;
     }
     $75 = HEAP32[$20>>2]|0;
     $76 = ($75|0)==(0);
     if ($76) {
      $$ph8 = $67;
      break L37;
     }
     $77 = HEAP32[$61>>2]|0;
     $78 = ($77|0)==($66|0);
     if (!($78)) {
      $$ph8 = $67;
      break L37;
     }
     $79 = HEAP32[$62>>2]|0;
     $80 = (($67) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = ($79|0)==($81|0);
     if (!($82)) {
      $$ph8 = $67;
      break L37;
     }
    }
    $83 = (($67) + 80|0);
    $84 = ($83|0)==($59|0);
    if ($84) {
     break;
    } else {
     $67 = $83;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $85 = ($$ph8|0)==($59|0);
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = (($this) + 96|0);
 $87 = (($this) + 92|0);
 $88 = (($ht) + 12|0);
 $89 = (($ht) + 16|0);
 $90 = (($ht) + 92|0);
 $91 = (($ht) + 96|0);
 $92 = (($ht) + 8|0);
 $94 = $157;$96 = $$ph8;
 while(1) {
  $93 = (($94) + -1)|0;
  $95 = HEAP32[$96>>2]|0;
  $97 = (($95) + 4|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = (($96) + 4|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($100) + 4|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($98) + 2127912214)|0;
  $104 = $98 << 12;
  $105 = (($103) + ($104))|0;
  $106 = $105 ^ -949894596;
  $107 = $105 >>> 19;
  $108 = $106 ^ $102;
  $109 = $108 ^ $107;
  $110 = (($109) + 374761393)|0;
  $111 = $109 << 5;
  $112 = (($110) + ($111))|0;
  $113 = (($112) + -744332180)|0;
  $114 = $112 << 9;
  $115 = $113 ^ $114;
  $116 = HEAP32[$1>>2]|0;
  $117 = HEAP32[$87>>2]|0;
  $118 = HEAP32[$86>>2]|0;
  $$pn = $115;$num_probes$0 = 0;
  while(1) {
   $bucknum$0 = $$pn & $93;
   $119 = (($116) + (($bucknum$0*80)|0)|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ($117|0)==($120|0);
   if ($121) {
    $122 = ((($116) + (($bucknum$0*80)|0)|0) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = ($118|0)==($123|0);
    if ($124) {
     break;
    }
   }
   $125 = (($num_probes$0) + 1)|0;
   $126 = (($125) + ($bucknum$0))|0;
   $$pn = $126;$num_probes$0 = $125;
  }
  $127 = (($116) + (($bucknum$0*80)|0)|0);
  $128 = ($127|0)==(0|0);
  if (!($128)) {
   dest=$127+0|0; src=$96+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $129 = HEAP32[$16>>2]|0;
  $130 = (($129) + 1)|0;
  HEAP32[$16>>2] = $130;
  $131 = (($96) + 80|0);
  $132 = ($131|0)==($59|0);
  L65: do {
   if ($132) {
    $$be = $59;
   } else {
    $137 = HEAP32[$90>>2]|0;
    $139 = $131;
    while(1) {
     $138 = HEAP32[$139>>2]|0;
     $140 = ($137|0)==($138|0);
     if ($140) {
      $141 = HEAP32[$91>>2]|0;
      $142 = (($139) + 4|0);
      $143 = HEAP32[$142>>2]|0;
      $144 = ($141|0)==($143|0);
      if (!($144)) {
       label = 47;
      }
     } else {
      label = 47;
     }
     if ((label|0) == 47) {
      label = 0;
      $145 = HEAP8[$92>>0]|0;
      $146 = ($145<<24>>24)==(0);
      if ($146) {
       $$be = $139;
       break L65;
      }
      $147 = HEAP32[$20>>2]|0;
      $148 = ($147|0)==(0);
      if ($148) {
       $$be = $139;
       break L65;
      }
      $149 = HEAP32[$88>>2]|0;
      $150 = ($149|0)==($138|0);
      if (!($150)) {
       $$be = $139;
       break L65;
      }
      $151 = HEAP32[$89>>2]|0;
      $152 = (($139) + 4|0);
      $153 = HEAP32[$152>>2]|0;
      $154 = ($151|0)==($153|0);
      if (!($154)) {
       $$be = $139;
       break L65;
      }
     }
     $155 = (($139) + 80|0);
     $156 = ($155|0)==($59|0);
     if ($156) {
      $$be = $59;
      break;
     } else {
      $139 = $155;
     }
    }
   }
  } while(0);
  $133 = HEAP32[$55>>2]|0;
  $134 = HEAP32[$57>>2]|0;
  $135 = (($133) + (($134*80)|0)|0);
  $136 = ($$be|0)==($135|0);
  if ($136) {
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $94 = $$pre;$96 = $$be;
 }
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E14squash_deletedEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy = sp + 200|0;
 $0 = sp;
 $tmp = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($tmp) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($tmp) + 8|0);
 $6 = (($this) + 8|0);
 $7 = HEAP8[$6>>0]|0;
 HEAP8[$5>>0] = $7;
 $8 = (($tmp) + 9|0);
 $9 = (($this) + 9|0);
 $10 = HEAP8[$9>>0]|0;
 HEAP8[$8>>0] = $10;
 $11 = (($tmp) + 12|0);
 $12 = (($this) + 12|0);
 dest=$11+0|0; src=$12+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $13 = (($tmp) + 92|0);
 $14 = (($this) + 92|0);
 dest=$13+0|0; src=$14+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $15 = (($tmp) + 172|0);
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP8[$15+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E9copy_fromERKSH_j($tmp,$this,0);
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$4>>2]|0;
 HEAP32[$1>>2] = $17;
 HEAP32[$4>>2] = $16;
 $18 = HEAP8[$6>>0]|0;
 $19 = HEAP16[$5>>1]|0;
 $20 = $19&255;
 HEAP8[$6>>0] = $20;
 HEAP8[$5>>0] = $18;
 $21 = HEAP8[$9>>0]|0;
 $22 = ($19&65535) >>> 8;
 $23 = $22&255;
 HEAP8[$9>>0] = $23;
 HEAP8[$8>>0] = $21;
 dest=$$byval_copy+0|0; src=$12+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$12+0|0; src=$11+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$11+0|0; src=$$byval_copy+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$$byval_copy+0|0; src=$14+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$14+0|0; src=$13+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$13+0|0; src=$$byval_copy+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $24 = (($this) + 172|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$15>>2]|0;
 HEAP32[$24>>2] = $26;
 HEAP32[$15>>2] = $25;
 $27 = (($this) + 176|0);
 $28 = (($tmp) + 176|0);
 $29 = HEAP32[$27>>2]|0;
 $30 = HEAP32[$28>>2]|0;
 HEAP32[$27>>2] = $30;
 HEAP32[$28>>2] = $29;
 $31 = (($this) + 180|0);
 $32 = (($tmp) + 180|0);
 $33 = HEAP32[$31>>2]|0;
 $34 = HEAP32[$32>>2]|0;
 HEAP32[$31>>2] = $34;
 HEAP32[$32>>2] = $33;
 $35 = (Math_fround(($30>>>0)));
 $36 = Math_fround($35 * Math_fround(0.5));
 $37 = (~~(($36))>>>0);
 $38 = (($this) + 188|0);
 HEAP32[$38>>2] = $37;
 $39 = Math_fround($35 * Math_fround(0.20000000298023223877));
 $40 = (~~(($39))>>>0);
 $41 = (($this) + 184|0);
 HEAP32[$41>>2] = $40;
 $42 = (($this) + 192|0);
 HEAP8[$42>>0] = 0;
 $43 = (Math_fround(($29>>>0)));
 $44 = Math_fround($43 * Math_fround(0.5));
 $45 = (~~(($44))>>>0);
 $46 = (($tmp) + 188|0);
 HEAP32[$46>>2] = $45;
 $47 = Math_fround($43 * Math_fround(0.20000000298023223877));
 $48 = (~~(($47))>>>0);
 $49 = (($tmp) + 184|0);
 HEAP32[$49>>2] = $48;
 $50 = (($tmp) + 192|0);
 HEAP8[$50>>0] = 0;
 $51 = ($25|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 58;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z22GetPhysicsGroundBody2Dv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((692272 + 8|0))>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNK15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EEjEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_jS7_NS0_8equal_toIS4_EE13stl_allocatorIS6_L18MemLabelIdentifier58ELi16EEE9SelectKeyESA_SD_E13find_positionERS5_($agg$result,$this,$key) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $key = $key|0;
 var $$ = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $num_probes$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$key>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($key) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($5) + 2127912214)|0;
 $11 = $5 << 12;
 $12 = (($10) + ($11))|0;
 $13 = $12 ^ -949894596;
 $14 = $12 >>> 19;
 $15 = $13 ^ $9;
 $16 = $15 ^ $14;
 $17 = (($16) + 374761393)|0;
 $18 = $16 << 5;
 $19 = (($17) + ($18))|0;
 $20 = (($19) + -744332180)|0;
 $21 = $19 << 9;
 $22 = $20 ^ $21;
 $23 = (($this) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 28|0);
 $28 = (($this) + 8|0);
 $29 = (($this) + 4|0);
 $30 = (($this) + 12|0);
 $31 = (($this) + 16|0);
 $$sink = $22;$41 = -1;$num_probes$0 = 0;
 while(1) {
  $32 = $$sink & $2;
  $33 = (($24) + (($32*12)|0)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($26|0)==($34|0);
  if ($35) {
   $36 = HEAP32[$27>>2]|0;
   $37 = ((($24) + (($32*12)|0)|0) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($36|0)==($38|0);
   if ($39) {
    break;
   }
  }
  $43 = HEAP8[$28>>0]|0;
  $44 = ($43<<24>>24)==(0);
  if ($44) {
   label = 12;
  } else {
   $45 = HEAP32[$29>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    label = 12;
   } else {
    $47 = HEAP32[$30>>2]|0;
    $48 = ($47|0)==($34|0);
    if ($48) {
     $49 = HEAP32[$31>>2]|0;
     $50 = ((($24) + (($32*12)|0)|0) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($49|0)==($51|0);
     if ($52) {
      $53 = ($41|0)==(-1);
      $$ = $53 ? $32 : $41;
      $61 = $$;
     } else {
      label = 12;
     }
    } else {
     label = 12;
    }
   }
  }
  if ((label|0) == 12) {
   label = 0;
   $54 = ($3|0)==($34|0);
   if ($54) {
    $55 = ((($24) + (($32*12)|0)|0) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ($7|0)==($56|0);
    if ($57) {
     label = 14;
     break;
    } else {
     $61 = $41;
    }
   } else {
    $61 = $41;
   }
  }
  $59 = (($num_probes$0) + 1)|0;
  $60 = (($59) + ($32))|0;
  $$sink = $60;$41 = $61;$num_probes$0 = $59;
 }
 if ((label|0) == 14) {
  HEAP32[$agg$result>>2] = $32;
  $58 = (($agg$result) + 4|0);
  HEAP32[$58>>2] = -1;
  STACKTOP = sp;return;
 }
 $40 = ($41|0)==(-1);
 HEAP32[$agg$result>>2] = -1;
 $42 = (($agg$result) + 4|0);
 if ($40) {
  HEAP32[$42>>2] = $32;
  STACKTOP = sp;return;
 } else {
  HEAP32[$42>>2] = $41;
  STACKTOP = sp;return;
 }
}
function __ZN15ContactFilter2DD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15ContactFilter2DD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN15ContactFilter2D13ShouldCollideEP9b2FixtureS1_($this,$fixtureA,$fixtureB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $fixtureB = $fixtureB|0;
 var $$0 = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $collider1$collider2$i = 0, $collider2$collider1$i = 0, $colliderPair$i = 0;
 var $or$cond$i = 0, $or$cond1$i = 0, $phitmp = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $colliderPair$i = sp;
 $0 = (($fixtureA) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(2);
 if (!($3)) {
  $4 = (($fixtureB) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(2);
  if (!($7)) {
   $8 = (($fixtureA) + 38|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $11 = (($fixtureB) + 38|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = ($12<<24>>24)==(0);
    if ($13) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $14 = (($fixtureA) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($fixtureB) + 40|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 28|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($17) + 28|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = (($15) + 45|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $27 = (($17) + 45|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   $31 = (($15) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + 40|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($17) + 24|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 40|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (__Z20GetPhysics2DSettingsv()|0);
   $40 = (__ZNK17Physics2DSettings23GetIgnoreLayerCollisionEii($39,$34,$38)|0);
   if ($40) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   label = 9;
  }
 } else {
  label = 9;
 }
 if ((label|0) == 9) {
  $30 = (__ZN10Effector2D25CheckEffectorColliderMaskEP10Collider2DS1_($15,$17)|0);
  if (!($30)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $41 = HEAP32[692272>>2]|0;
 $42 = ($15|0)==(0|0);
 $43 = ($17|0)==(0|0);
 $or$cond$i = $42 | $43;
 $44 = ($15|0)==($17|0);
 $or$cond1$i = $or$cond$i | $44;
 if ($or$cond1$i) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($15) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($17) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($46|0)>($48|0);
 $collider2$collider1$i = $49 ? $17 : $15;
 $collider1$collider2$i = $49 ? $15 : $17;
 HEAP32[$colliderPair$i>>2] = $collider2$collider1$i;
 $50 = (($colliderPair$i) + 4|0);
 HEAP32[$50>>2] = $collider1$collider2$i;
 $51 = (($41) + 48|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($41) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($52|0)==($54|0);
 do {
  if ($55) {
   $56 = (($41) + 40|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($41) + 44|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + (($59*12)|0)|0);
   $71 = $57;$72 = $59;$73 = $60;
  } else {
   $61 = (($41) + 4|0);
   __ZNK15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EEjEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_jS7_NS0_8equal_toIS4_EE13stl_allocatorIS6_L18MemLabelIdentifier58ELi16EEE9SelectKeyESA_SD_E13find_positionERS5_($pos$i$i$i,$61,$colliderPair$i);
   $62 = HEAP32[$pos$i$i$i>>2]|0;
   $63 = ($62|0)==(-1);
   $64 = (($41) + 40|0);
   $65 = HEAP32[$64>>2]|0;
   if ($63) {
    $66 = (($41) + 44|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($65) + (($67*12)|0)|0);
    $71 = $65;$72 = $67;$73 = $68;
    break;
   } else {
    $69 = (($65) + (($62*12)|0)|0);
    $$phi$trans$insert$i = (($41) + 44|0);
    $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $71 = $65;$72 = $$pre$i;$73 = $69;
    break;
   }
  }
 } while(0);
 $70 = (($71) + (($72*12)|0)|0);
 $phitmp = ($73|0)==($70|0);
 $$0 = $phitmp;
 STACKTOP = sp;return ($$0|0);
}
function __GLOBAL__I_a13766() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[692272>>2] = 0;
 HEAP32[((692272 + 4|0))>>2] = 0;
 HEAP32[((692272 + 8|0))>>2] = 0;
 __ZN19CollisionListener2DC2Ev(((692272 + 12|0)));
 HEAP32[((692272 + 228|0))>>2] = ((692504 + 8|0));
 STACKTOP = sp;return;
}
function __ZNK17Physics2DSettings23GetIgnoreLayerCollisionEii($this,$layer1,$layer2) {
 $this = $this|0;
 $layer1 = $layer1|0;
 $layer2 = $layer2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond1 = 0, $or$cond2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = $layer2 | $layer1;
 $2 = ($1|0)<(0);
 $3 = ($layer1|0)>(31);
 $or$cond1 = $2 | $3;
 $4 = ($layer2|0)>(31);
 $or$cond2 = $or$cond1 | $4;
 if (!($or$cond2)) {
  $26 = (($this) + 24|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + ($layer1<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = 1 << $layer2;
  $31 = $29 & $30;
  $32 = ($31|0)==(0);
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = 31;
 __Z6FormatPKcz($0,692536,$vararg_buffer);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (($0) + 1|0);
  $11 = $10;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($11|0),0,(692528|0),295,1,0,0,(0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP8[$0>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   ___resumeException($19|0);
   // unreachable;
  }
  $24 = (($0) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  __ZdlPv($25);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z20GetPhysics2DSettingsv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(14)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN10Effector2D12BeginContactEP9b2Contact($contact) {
 $contact = $contact|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($contact) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($contact) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN10Effector2D19ProcessBeginContactEP10Collider2DS1_P9b2Contact($3,$7,$contact);
 __ZN10Effector2D19ProcessBeginContactEP10Collider2DS1_P9b2Contact($7,$3,$contact);
 STACKTOP = sp;return;
}
function __ZN10Effector2D19ProcessBeginContactEP10Collider2DS1_P9b2Contact($source,$target,$contact) {
 $source = $source|0;
 $target = $target|0;
 $contact = $contact|0;
 var $$byval_copy1 = 0, $$c = 0, $$c1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $effectorContact = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $0 = sp;
 $effectorContact = sp + 8|0;
 $1 = (($source) + 45|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($source) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($5,248)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($effectorContact) + 36|0);
 HEAP8[$8>>0] = 0;
 $9 = (($effectorContact) + 32|0);
 HEAP32[$9>>2] = $contact;
 $10 = (($effectorContact) + 4|0);
 HEAP32[$10>>2] = $source;
 $11 = (($contact) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($effectorContact) + 8|0);
 HEAP32[$13>>2] = $12;
 $14 = (($contact) + 56|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($effectorContact) + 12|0);
 HEAP32[$16>>2] = $15;
 $17 = (($effectorContact) + 20|0);
 HEAP32[$17>>2] = $target;
 $18 = (($contact) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($effectorContact) + 24|0);
 HEAP32[$20>>2] = $19;
 $21 = (($contact) + 60|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($effectorContact) + 28|0);
 HEAP32[$23>>2] = $22;
 $24 = (__ZNK10Collider2D7GetBodyEv($source)|0);
 HEAP32[$effectorContact>>2] = $24;
 $25 = (__ZNK10Collider2D7GetBodyEv($target)|0);
 $26 = (($effectorContact) + 16|0);
 HEAP32[$26>>2] = $25;
 $27 = HEAP32[$6>>2]|0;
 $28 = (($27) + 144|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (FUNCTION_TABLE_ii[$29 & 4095]($6)|0);
 if ($30) {
  $31 = (($6) + 32|0);
  $32 = (($31) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $35 = (($31) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = $36 & 2147483647;
  $38 = ($34>>>0)>($37>>>0);
  if ($38) {
   $39 = $36 << 1;
   $40 = ($39|0)==(0);
   $41 = $40 ? 1 : $39;
   $42 = ($37>>>0)<($41>>>0);
   do {
    if ($42) {
     $43 = ($36|0)>(-1);
     if ($43) {
      HEAP32[$35>>2] = $41;
      $44 = HEAP32[$31>>2]|0;
      $45 = ($41*40)|0;
      $46 = (($31) + 4|0);
      $47 = HEAP32[$46>>2]|0;
      HEAP32[$0>>2] = $47;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $48 = (__Z16realloc_internalPvji10MemLabelIdiPKci($44,$45,4,$$byval_copy1,0,692608,370)|0);
      $$c1 = $48;
      HEAP32[$31>>2] = $$c1;
      break;
     } else {
      $49 = ($41*40)|0;
      $50 = (($31) + 4|0);
      $51 = HEAP32[$50>>2]|0;
      HEAP32[$0>>2] = $51;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $52 = (__Z15malloc_internaljj10MemLabelIdiPKci($49,4,$$byval_copy1,0,692608,352)|0);
      $53 = HEAP32[$31>>2]|0;
      $54 = HEAP32[$32>>2]|0;
      $55 = ($54*40)|0;
      _memcpy(($52|0),($53|0),($55|0))|0;
      HEAP32[$35>>2] = $41;
      $$c = $52;
      HEAP32[$31>>2] = $$c;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$32>>2]|0;
   $57 = $$pre$i$i;
  } else {
   $57 = $34;
  }
  $56 = (($57) + -1)|0;
  $58 = HEAP32[$31>>2]|0;
  $59 = (($58) + (($56*40)|0)|0);
  dest=$59+0|0; src=$effectorContact+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP8[$59+36>>0]=HEAP8[$effectorContact+36>>0]|0;
 }
 $60 = HEAP32[$6>>2]|0;
 $61 = (($60) + 132|0);
 $62 = HEAP32[$61>>2]|0;
 FUNCTION_TABLE_vii[$62 & 4095]($6,$effectorContact);
 STACKTOP = sp;return;
}
function __ZN10Effector2D15PreSolveContactEP9b2Contact($contact) {
 $contact = $contact|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $effectorContact$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $effectorContact$i1 = sp;
 $0 = (($contact) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($contact) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($3) + 45|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = (($3) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($12,248)|0);
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = (($effectorContact$i1) + 36|0);
   HEAP8[$15>>0] = 0;
   $16 = (($effectorContact$i1) + 32|0);
   HEAP32[$16>>2] = $contact;
   $17 = (($effectorContact$i1) + 4|0);
   HEAP32[$17>>2] = $3;
   $18 = HEAP32[$0>>2]|0;
   $19 = (($effectorContact$i1) + 8|0);
   HEAP32[$19>>2] = $18;
   $20 = (($contact) + 56|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($effectorContact$i1) + 12|0);
   HEAP32[$22>>2] = $21;
   $23 = (($effectorContact$i1) + 20|0);
   HEAP32[$23>>2] = $7;
   $24 = HEAP32[$4>>2]|0;
   $25 = (($effectorContact$i1) + 24|0);
   HEAP32[$25>>2] = $24;
   $26 = (($contact) + 60|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($effectorContact$i1) + 28|0);
   HEAP32[$28>>2] = $27;
   $29 = (__ZNK10Collider2D7GetBodyEv($3)|0);
   HEAP32[$effectorContact$i1>>2] = $29;
   $30 = (__ZNK10Collider2D7GetBodyEv($7)|0);
   $31 = (($effectorContact$i1) + 16|0);
   HEAP32[$31>>2] = $30;
   $32 = HEAP32[$13>>2]|0;
   $33 = (($32) + 136|0);
   $34 = HEAP32[$33>>2]|0;
   FUNCTION_TABLE_vii[$34 & 4095]($13,$effectorContact$i1);
  }
 }
 $35 = (($7) + 45|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = (($7) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($39,248)|0);
 $41 = ($40|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($effectorContact$i1) + 36|0);
 HEAP8[$42>>0] = 0;
 $43 = (($effectorContact$i1) + 32|0);
 HEAP32[$43>>2] = $contact;
 $44 = (($effectorContact$i1) + 4|0);
 HEAP32[$44>>2] = $7;
 $45 = HEAP32[$0>>2]|0;
 $46 = (($effectorContact$i1) + 8|0);
 HEAP32[$46>>2] = $45;
 $47 = (($contact) + 56|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($effectorContact$i1) + 12|0);
 HEAP32[$49>>2] = $48;
 $50 = (($effectorContact$i1) + 20|0);
 HEAP32[$50>>2] = $3;
 $51 = HEAP32[$4>>2]|0;
 $52 = (($effectorContact$i1) + 24|0);
 HEAP32[$52>>2] = $51;
 $53 = (($contact) + 60|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($effectorContact$i1) + 28|0);
 HEAP32[$55>>2] = $54;
 $56 = (__ZNK10Collider2D7GetBodyEv($7)|0);
 HEAP32[$effectorContact$i1>>2] = $56;
 $57 = (__ZNK10Collider2D7GetBodyEv($3)|0);
 $58 = (($effectorContact$i1) + 16|0);
 HEAP32[$58>>2] = $57;
 $59 = HEAP32[$40>>2]|0;
 $60 = (($59) + 136|0);
 $61 = HEAP32[$60>>2]|0;
 FUNCTION_TABLE_vii[$61 & 4095]($40,$effectorContact$i1);
 STACKTOP = sp;return;
}
function __ZN10Effector2D10EndContactEP9b2Contact($contact) {
 $contact = $contact|0;
 var $$c$i = 0, $$c$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $contactsItr$0$i$i = 0, $contactsItr$0$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($contact) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($contact) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($3) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($9,248)|0);
 $11 = ($10|0)==(0|0);
 L1: do {
  if (!($11)) {
   $12 = (($10) + 32|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($10) + 40|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($13) + (($15*40)|0)|0);
   $contactsItr$0$i$i1 = $13;
   while(1) {
    $17 = ($contactsItr$0$i$i1|0)==($16|0);
    if ($17) {
     break L1;
    }
    $18 = (($contactsItr$0$i$i1) + 32|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($contact|0);
    $21 = (($contactsItr$0$i$i1) + 40|0);
    if ($20) {
     break;
    } else {
     $contactsItr$0$i$i1 = $21;
    }
   }
   $22 = $16;
   $23 = $21;
   $24 = (($22) - ($23))|0;
   _memmove(($contactsItr$0$i$i1|0),($21|0),($24|0))|0;
   $25 = HEAP32[$14>>2]|0;
   $26 = (($25) + -1)|0;
   $$c$i2 = $26;
   HEAP32[$14>>2] = $$c$i2;
  }
 } while(0);
 $27 = (($7) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($28,248)|0);
 $30 = ($29|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($29) + 32|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($29) + 40|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + (($34*40)|0)|0);
 $contactsItr$0$i$i = $32;
 while(1) {
  $36 = ($contactsItr$0$i$i|0)==($35|0);
  if ($36) {
   label = 11;
   break;
  }
  $37 = (($contactsItr$0$i$i) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==($contact|0);
  $40 = (($contactsItr$0$i$i) + 40|0);
  if ($39) {
   break;
  } else {
   $contactsItr$0$i$i = $40;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return;
 }
 $41 = $35;
 $42 = $40;
 $43 = (($41) - ($42))|0;
 _memmove(($contactsItr$0$i$i|0),($40|0),($43|0))|0;
 $44 = HEAP32[$33>>2]|0;
 $45 = (($44) + -1)|0;
 $$c$i = $45;
 HEAP32[$33>>2] = $$c$i;
 STACKTOP = sp;return;
}
function __ZN10Effector2D25CheckEffectorColliderMaskEP10Collider2DS1_($colliderA,$colliderB) {
 $colliderA = $colliderA|0;
 $colliderB = $colliderB|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $not$$i = 0, $not$$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($colliderA) + 28|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($colliderB) + 28|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($colliderA) + 45|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($colliderA) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($10,248)|0);
  $12 = ($11|0)==(0|0);
  if ($12) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $13 = (($11) + 48|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($colliderB) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 40|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = 1 << $18;
  $20 = $19 & $14;
  $21 = ($20|0)==(0);
  if ($21) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $22 = (__ZNK10Collider2D7GetBodyEv($colliderB)|0);
  $23 = HEAP32[$22>>2]|0;
  $not$$i1 = ($23|0)==(0);
  if ($not$$i1) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $24 = (($colliderB) + 45|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = (($colliderB) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($28,248)|0);
 $30 = ($29|0)==(0|0);
 if ($30) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (($29) + 48|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($colliderA) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 40|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = 1 << $36;
 $38 = $37 & $32;
 $39 = ($38|0)==(0);
 if ($39) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = (__ZNK10Collider2D7GetBodyEv($colliderA)|0);
 $41 = HEAP32[$40>>2]|0;
 $not$$i = ($41|0)!=(0);
 $$0 = $not$$i;
 STACKTOP = sp;return ($$0|0);
}
function __ZN15b2WorldManifold10InitializeEPK10b2ManifoldRK11b2TransformfS5_f($this,$manifold,$xfA,$radiusA,$xfB,$radiusB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $radiusA = Math_fround($radiusA);
 $xfB = $xfB|0;
 $radiusB = Math_fround($radiusB);
 var $$pre54 = Math_fround(0), $$pre55 = Math_fround(0), $$pre56 = Math_fround(0), $$pre57 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0);
 var $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0);
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0);
 var $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0;
 var $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0);
 var $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0;
 var $i$047 = 0, $i4$048 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($manifold) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($manifold) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 if ((($4|0) == 0)) {
  HEAPF32[$this>>2] = Math_fround(1.0);
  $5 = (($this) + 4|0);
  HEAPF32[$5>>2] = Math_fround(0.0);
  $6 = (($xfA) + 12|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = (($manifold) + 48|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround($7 * $9);
  $11 = (($xfA) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($manifold) + 52|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = Math_fround($12 * $14);
  $16 = Math_fround($10 - $15);
  $17 = Math_fround(HEAPF32[$xfA>>2]);
  $18 = Math_fround($17 + $16);
  $19 = Math_fround($9 * $12);
  $20 = Math_fround($7 * $14);
  $21 = Math_fround($19 + $20);
  $22 = (($xfA) + 4|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($21 + $23);
  $25 = (($xfB) + 12|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = Math_fround(HEAPF32[$manifold>>2]);
  $28 = Math_fround($26 * $27);
  $29 = (($xfB) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($manifold) + 4|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($30 * $32);
  $34 = Math_fround($28 - $33);
  $35 = Math_fround(HEAPF32[$xfB>>2]);
  $36 = Math_fround($35 + $34);
  $37 = Math_fround($27 * $30);
  $38 = Math_fround($26 * $32);
  $39 = Math_fround($37 + $38);
  $40 = (($xfB) + 4|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($39 + $41);
  $43 = Math_fround($18 - $36);
  $44 = Math_fround($24 - $42);
  $45 = Math_fround($43 * $43);
  $46 = Math_fround($44 * $44);
  $47 = Math_fround($45 + $46);
  $48 = $47 > Math_fround(1.42108547152020037174E-14);
  if ($48) {
   $49 = Math_fround($36 - $18);
   $50 = Math_fround($42 - $24);
   $51 = (HEAPF32[tempDoublePtr>>2]=$49,HEAP32[tempDoublePtr>>2]|0);
   $52 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
   $53 = $this;
   $54 = $53;
   HEAP32[$54>>2] = $51;
   $55 = (($53) + 4)|0;
   $56 = $55;
   HEAP32[$56>>2] = $52;
   $57 = Math_fround($49 * $49);
   $58 = Math_fround($50 * $50);
   $59 = Math_fround($57 + $58);
   $60 = (Math_fround(Math_sqrt((Math_fround($59)))));
   $61 = $60 < Math_fround(1.1920928955078125E-7);
   if ($61) {
    $66 = $49;$68 = $50;
   } else {
    $62 = Math_fround(Math_fround(1.0) / $60);
    $63 = Math_fround($49 * $62);
    HEAPF32[$this>>2] = $63;
    $64 = Math_fround($50 * $62);
    HEAPF32[$5>>2] = $64;
    $66 = $63;$68 = $64;
   }
  } else {
   $66 = Math_fround(1.0);$68 = Math_fround(0.0);
  }
  $65 = Math_fround($66 * $radiusA);
  $67 = Math_fround($68 * $radiusA);
  $69 = Math_fround($18 + $65);
  $70 = Math_fround($24 + $67);
  $71 = Math_fround($66 * $radiusB);
  $72 = Math_fround($68 * $radiusB);
  $73 = Math_fround($36 - $71);
  $74 = Math_fround($42 - $72);
  $75 = (($this) + 8|0);
  $76 = Math_fround($69 + $73);
  $77 = Math_fround($70 + $74);
  $78 = Math_fround($76 * Math_fround(0.5));
  $79 = Math_fround($77 * Math_fround(0.5));
  $80 = (HEAPF32[tempDoublePtr>>2]=$78,HEAP32[tempDoublePtr>>2]|0);
  $81 = (HEAPF32[tempDoublePtr>>2]=$79,HEAP32[tempDoublePtr>>2]|0);
  $82 = $75;
  $83 = $82;
  HEAP32[$83>>2] = $80;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $81;
  $86 = Math_fround($73 - $69);
  $87 = Math_fround($74 - $70);
  $88 = Math_fround($66 * $86);
  $89 = Math_fround($68 * $87);
  $90 = Math_fround($88 + $89);
  $91 = (($this) + 24|0);
  HEAPF32[$91>>2] = $90;
  STACKTOP = sp;return;
 } else if ((($4|0) == 2)) {
  $189 = (($xfB) + 12|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($manifold) + 40|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = Math_fround($190 * $192);
  $194 = (($xfB) + 8|0);
  $195 = Math_fround(HEAPF32[$194>>2]);
  $196 = (($manifold) + 44|0);
  $197 = Math_fround(HEAPF32[$196>>2]);
  $198 = Math_fround($195 * $197);
  $199 = Math_fround($193 - $198);
  $200 = Math_fround($192 * $195);
  $201 = Math_fround($190 * $197);
  $202 = Math_fround($200 + $201);
  $203 = (HEAPF32[tempDoublePtr>>2]=$199,HEAP32[tempDoublePtr>>2]|0);
  $204 = (HEAPF32[tempDoublePtr>>2]=$202,HEAP32[tempDoublePtr>>2]|0);
  $205 = $this;
  $206 = $205;
  HEAP32[$206>>2] = $203;
  $207 = (($205) + 4)|0;
  $208 = $207;
  HEAP32[$208>>2] = $204;
  $209 = Math_fround(HEAPF32[$189>>2]);
  $210 = (($manifold) + 48|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = Math_fround($209 * $211);
  $213 = Math_fround(HEAPF32[$194>>2]);
  $214 = (($manifold) + 52|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = Math_fround($213 * $215);
  $217 = Math_fround($212 - $216);
  $218 = Math_fround(HEAPF32[$xfB>>2]);
  $219 = Math_fround($218 + $217);
  $220 = Math_fround($211 * $213);
  $221 = Math_fround($209 * $215);
  $222 = Math_fround($220 + $221);
  $223 = (($xfB) + 4|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = Math_fround($222 + $224);
  $226 = HEAP32[$0>>2]|0;
  $227 = ($226|0)>(0);
  if ($227) {
   $228 = (($xfA) + 12|0);
   $229 = (($xfA) + 8|0);
   $230 = (($xfA) + 4|0);
   $231 = (($this) + 4|0);
   $251 = $199;$253 = $202;$i4$048 = 0;
   while(1) {
    $232 = Math_fround(HEAPF32[$228>>2]);
    $233 = (($manifold) + (($i4$048*20)|0)|0);
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = Math_fround($232 * $234);
    $236 = Math_fround(HEAPF32[$229>>2]);
    $237 = ((($manifold) + (($i4$048*20)|0)|0) + 4|0);
    $238 = Math_fround(HEAPF32[$237>>2]);
    $239 = Math_fround($236 * $238);
    $240 = Math_fround($235 - $239);
    $241 = Math_fround(HEAPF32[$xfA>>2]);
    $242 = Math_fround($241 + $240);
    $243 = Math_fround($234 * $236);
    $244 = Math_fround($232 * $238);
    $245 = Math_fround($243 + $244);
    $246 = Math_fround(HEAPF32[$230>>2]);
    $247 = Math_fround($245 + $246);
    $248 = Math_fround($242 - $219);
    $249 = Math_fround($247 - $225);
    $250 = Math_fround($251 * $248);
    $252 = Math_fround($249 * $253);
    $254 = Math_fround($250 + $252);
    $255 = Math_fround($radiusB - $254);
    $256 = Math_fround($251 * $255);
    $257 = Math_fround($253 * $255);
    $258 = Math_fround($242 + $256);
    $259 = Math_fround($247 + $257);
    $260 = Math_fround($251 * $radiusA);
    $261 = Math_fround($253 * $radiusA);
    $262 = Math_fround($242 - $260);
    $263 = Math_fround($247 - $261);
    $264 = ((($this) + ($i4$048<<3)|0) + 8|0);
    $265 = Math_fround($262 + $258);
    $266 = Math_fround($263 + $259);
    $267 = Math_fround($265 * Math_fround(0.5));
    $268 = Math_fround($266 * Math_fround(0.5));
    $269 = (HEAPF32[tempDoublePtr>>2]=$267,HEAP32[tempDoublePtr>>2]|0);
    $270 = (HEAPF32[tempDoublePtr>>2]=$268,HEAP32[tempDoublePtr>>2]|0);
    $271 = $264;
    $272 = $271;
    HEAP32[$272>>2] = $269;
    $273 = (($271) + 4)|0;
    $274 = $273;
    HEAP32[$274>>2] = $270;
    $275 = Math_fround($262 - $258);
    $276 = Math_fround($263 - $259);
    $277 = Math_fround(HEAPF32[$this>>2]);
    $278 = Math_fround($277 * $275);
    $279 = Math_fround(HEAPF32[$231>>2]);
    $280 = Math_fround($279 * $276);
    $281 = Math_fround($278 + $280);
    $282 = ((($this) + ($i4$048<<2)|0) + 24|0);
    HEAPF32[$282>>2] = $281;
    $283 = (($i4$048) + 1)|0;
    $284 = HEAP32[$0>>2]|0;
    $285 = ($283|0)<($284|0);
    $$pre56 = Math_fround(HEAPF32[$this>>2]);
    $$pre57 = Math_fround(HEAPF32[$231>>2]);
    if ($285) {
     $251 = $$pre56;$253 = $$pre57;$i4$048 = $283;
    } else {
     $287 = $$pre56;$289 = $$pre57;
     break;
    }
   }
  } else {
   $287 = $199;$289 = $202;
  }
  $286 = Math_fround(-$287);
  $288 = Math_fround(-$289);
  $290 = (HEAPF32[tempDoublePtr>>2]=$286,HEAP32[tempDoublePtr>>2]|0);
  $291 = (HEAPF32[tempDoublePtr>>2]=$288,HEAP32[tempDoublePtr>>2]|0);
  $292 = $this;
  $293 = $292;
  HEAP32[$293>>2] = $290;
  $294 = (($292) + 4)|0;
  $295 = $294;
  HEAP32[$295>>2] = $291;
  STACKTOP = sp;return;
 } else if ((($4|0) == 1)) {
  $92 = (($xfA) + 12|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = (($manifold) + 40|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = Math_fround($93 * $95);
  $97 = (($xfA) + 8|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($manifold) + 44|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = Math_fround($98 * $100);
  $102 = Math_fround($96 - $101);
  $103 = Math_fround($95 * $98);
  $104 = Math_fround($93 * $100);
  $105 = Math_fround($103 + $104);
  $106 = (HEAPF32[tempDoublePtr>>2]=$102,HEAP32[tempDoublePtr>>2]|0);
  $107 = (HEAPF32[tempDoublePtr>>2]=$105,HEAP32[tempDoublePtr>>2]|0);
  $108 = $this;
  $109 = $108;
  HEAP32[$109>>2] = $106;
  $110 = (($108) + 4)|0;
  $111 = $110;
  HEAP32[$111>>2] = $107;
  $112 = Math_fround(HEAPF32[$92>>2]);
  $113 = (($manifold) + 48|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = Math_fround($112 * $114);
  $116 = Math_fround(HEAPF32[$97>>2]);
  $117 = (($manifold) + 52|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = Math_fround($116 * $118);
  $120 = Math_fround($115 - $119);
  $121 = Math_fround(HEAPF32[$xfA>>2]);
  $122 = Math_fround($121 + $120);
  $123 = Math_fround($114 * $116);
  $124 = Math_fround($112 * $118);
  $125 = Math_fround($123 + $124);
  $126 = (($xfA) + 4|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = Math_fround($125 + $127);
  $129 = HEAP32[$0>>2]|0;
  $130 = ($129|0)>(0);
  if (!($130)) {
   STACKTOP = sp;return;
  }
  $131 = (($xfB) + 12|0);
  $132 = (($xfB) + 8|0);
  $133 = (($xfB) + 4|0);
  $134 = (($this) + 4|0);
  $154 = $102;$156 = $105;$i$047 = 0;
  while(1) {
   $135 = Math_fround(HEAPF32[$131>>2]);
   $136 = (($manifold) + (($i$047*20)|0)|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = Math_fround($135 * $137);
   $139 = Math_fround(HEAPF32[$132>>2]);
   $140 = ((($manifold) + (($i$047*20)|0)|0) + 4|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = Math_fround($139 * $141);
   $143 = Math_fround($138 - $142);
   $144 = Math_fround(HEAPF32[$xfB>>2]);
   $145 = Math_fround($144 + $143);
   $146 = Math_fround($137 * $139);
   $147 = Math_fround($135 * $141);
   $148 = Math_fround($146 + $147);
   $149 = Math_fround(HEAPF32[$133>>2]);
   $150 = Math_fround($148 + $149);
   $151 = Math_fround($145 - $122);
   $152 = Math_fround($150 - $128);
   $153 = Math_fround($154 * $151);
   $155 = Math_fround($152 * $156);
   $157 = Math_fround($153 + $155);
   $158 = Math_fround($radiusA - $157);
   $159 = Math_fround($154 * $158);
   $160 = Math_fround($156 * $158);
   $161 = Math_fround($145 + $159);
   $162 = Math_fround($150 + $160);
   $163 = Math_fround($154 * $radiusB);
   $164 = Math_fround($156 * $radiusB);
   $165 = Math_fround($145 - $163);
   $166 = Math_fround($150 - $164);
   $167 = ((($this) + ($i$047<<3)|0) + 8|0);
   $168 = Math_fround($165 + $161);
   $169 = Math_fround($166 + $162);
   $170 = Math_fround($168 * Math_fround(0.5));
   $171 = Math_fround($169 * Math_fround(0.5));
   $172 = (HEAPF32[tempDoublePtr>>2]=$170,HEAP32[tempDoublePtr>>2]|0);
   $173 = (HEAPF32[tempDoublePtr>>2]=$171,HEAP32[tempDoublePtr>>2]|0);
   $174 = $167;
   $175 = $174;
   HEAP32[$175>>2] = $172;
   $176 = (($174) + 4)|0;
   $177 = $176;
   HEAP32[$177>>2] = $173;
   $178 = Math_fround($165 - $161);
   $179 = Math_fround($166 - $162);
   $180 = Math_fround(HEAPF32[$this>>2]);
   $181 = Math_fround($180 * $178);
   $182 = Math_fround(HEAPF32[$134>>2]);
   $183 = Math_fround($182 * $179);
   $184 = Math_fround($181 + $183);
   $185 = ((($this) + ($i$047<<2)|0) + 24|0);
   HEAPF32[$185>>2] = $184;
   $186 = (($i$047) + 1)|0;
   $187 = HEAP32[$0>>2]|0;
   $188 = ($186|0)<($187|0);
   if (!($188)) {
    break;
   }
   $$pre54 = Math_fround(HEAPF32[$this>>2]);
   $$pre55 = Math_fround(HEAPF32[$134>>2]);
   $154 = $$pre54;$156 = $$pre55;$i$047 = $186;
  }
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z28RegisterClass_AudioBehaviourv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(180,211,0,0,0);
 STACKTOP = sp;return;
}
function __ZN14AudioBehaviour13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 14;
 dest=$3+0|0; src=692616+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 14|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,180,8,($0|0),32,(2559|0),1,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN14AudioBehaviour7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK14AudioBehaviour25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 180;
}
function __ZN14AudioBehaviourC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 $2 = (($this) + 28|0);
 HEAP8[$2>>0] = 1;
 $3 = (($this) + 29|0);
 HEAP8[$3>>0] = 0;
 HEAP32[$this>>2] = ((692632 + 8|0));
 STACKTOP = sp;return;
}
function __ZN14AudioBehaviour15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN14AudioBehaviourD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((589992 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __ZN5Unity9ComponentD2Ev($this);
  STACKTOP = sp;return;
 }
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3394,($this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch(0|0)|0;
  $7 = tempRet0;
  ___clang_call_terminate($6);
  // unreachable;
 } else {
  ___resumeException($2|0);
  // unreachable;
 }
}
function __ZN14AudioBehaviourD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$i5$indexZ2D = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body8$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((589992 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  HEAP32[$this>>2] = ((562072 + 8|0));
  __THREW__ = 0;
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $16 = ___cxa_find_matching_catch(0|0)|0;
   $17 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $22 = ___cxa_find_matching_catch(0|0)|0;
    $23 = tempRet0;
    __THREW__ = 0;
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     $26 = ___cxa_find_matching_catch(0|0)|0;
     $27 = tempRet0;
     ___clang_call_terminate($26);
     // unreachable;
    } else {
     $eh$lpad$body$i5$indexZ2D = $22;
     ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $eh$lpad$body8$indexZ2D = $16;
    ___clang_call_terminate($eh$lpad$body8$indexZ2D);
    // unreachable;
   }
   $28 = ___cxa_find_matching_catch(0|0)|0;
   $29 = tempRet0;
   $eh$lpad$body$i5$indexZ2D = $28;
   ___clang_call_terminate($eh$lpad$body$i5$indexZ2D);
   // unreachable;
  } else {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    $8 = ___cxa_find_matching_catch(0|0)|0;
    $9 = tempRet0;
    __THREW__ = 0;
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     $12 = ___cxa_find_matching_catch(0|0)|0;
     $13 = tempRet0;
     ___clang_call_terminate($12);
     // unreachable;
    } else {
     $eh$lpad$body8$indexZ2D = $8;
     ___clang_call_terminate($eh$lpad$body8$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $eh$lpad$body$index21Z2D = $3;$eh$lpad$body$indexZ2D = $2;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $30 = ___cxa_find_matching_catch(0|0)|0;
   $31 = tempRet0;
   $eh$lpad$body8$indexZ2D = $30;
   ___clang_call_terminate($eh$lpad$body8$indexZ2D);
   // unreachable;
  }
 } else {
  HEAP32[$this>>2] = ((562072 + 8|0));
  __THREW__ = 0;
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $50 = ___cxa_find_matching_catch(0|0)|0;
    $51 = tempRet0;
    __THREW__ = 0;
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch(0|0)|0;
     $55 = tempRet0;
     ___clang_call_terminate($54);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $50;
     ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    $eh$lpad$body$index21Z2D = $45;$eh$lpad$body$indexZ2D = $44;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
   $56 = ___cxa_find_matching_catch(0|0)|0;
   $57 = tempRet0;
   $eh$lpad$body$i$indexZ2D = $56;
   ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
   // unreachable;
  } else {
   HEAP32[$this>>2] = ((560936 + 8|0));
   __THREW__ = 0;
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $36 = ___cxa_find_matching_catch()|0;
    $37 = tempRet0;
    __THREW__ = 0;
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     $40 = ___cxa_find_matching_catch(0|0)|0;
     $41 = tempRet0;
     ___clang_call_terminate($40);
     // unreachable;
    } else {
     $eh$lpad$body$index21Z2D = $37;$eh$lpad$body$indexZ2D = $36;
     __ZdlPv($this);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
   }
   __THREW__ = 0;
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    __ZdlPv($this);
    STACKTOP = sp;return;
   }
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $eh$lpad$body$index21Z2D = $59;$eh$lpad$body$indexZ2D = $58;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
}
function __ZN9AudioClip7WWWOpenEPKciPjPPvS4_($wwwstream,$unicode,$filesize,$handle,$userdata) {
 $wwwstream = $wwwstream|0;
 $unicode = $unicode|0;
 $filesize = $filesize|0;
 $handle = $handle|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($wwwstream|0)==(0|0);
 if ($0) {
  $$0 = 37;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$wwwstream>>2]|0;
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($wwwstream);
 $4 = HEAP32[$wwwstream>>2]|0;
 $5 = (($4) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($wwwstream)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  $9 = HEAP32[$wwwstream>>2]|0;
  $10 = (($9) + 24|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($wwwstream);
  $$0 = 54;
  STACKTOP = sp;return ($$0|0);
 } else {
  $12 = HEAP32[$wwwstream>>2]|0;
  $13 = (($12) + 32|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (Math_fround(FUNCTION_TABLE_fi[$14 & 255]($wwwstream)));
  $16 = +$15;
  $17 = 1.0 / $16;
  $18 = HEAP32[$wwwstream>>2]|0;
  $19 = (($18) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (FUNCTION_TABLE_ii[$20 & 4095]($wwwstream)|0);
  $22 = (+($21>>>0));
  $23 = $17 * $22;
  $24 = (~~(($23))>>>0);
  HEAP32[$filesize>>2] = $24;
  $25 = (__Znwj(16)|0);
  $26 = (($25) + 12|0);
  ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;
  HEAP32[$26>>2] = $24;
  $27 = (($25) + 4|0);
  HEAP32[$27>>2] = $wwwstream;
  HEAP32[$userdata>>2] = $25;
  HEAP32[$handle>>2] = $wwwstream;
  $28 = HEAP32[$wwwstream>>2]|0;
  $29 = (($28) + 24|0);
  $30 = HEAP32[$29>>2]|0;
  FUNCTION_TABLE_vi[$30 & 4095]($wwwstream);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9AudioClip8WWWCloseEPvS0_($handle,$userdata) {
 $handle = $handle|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($handle|0)==(0|0);
 if ($0) {
  $$0 = 37;
 } else {
  $1 = ($userdata|0)==(0|0);
  if ($1) {
   $$0 = 0;
  } else {
   __ZdlPv($userdata);
   $$0 = 0;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN9AudioClip7WWWReadEPvS0_jPjS0_($handle,$buffer,$sizebytes,$bytesread,$userdata) {
 $handle = $handle|0;
 $buffer = $buffer|0;
 $sizebytes = $sizebytes|0;
 $bytesread = $bytesread|0;
 $userdata = $userdata|0;
 var $$ = 0, $$0 = 0, $$sizebytes = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($handle|0)==(0|0);
 if ($0) {
  $$0 = 37;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($userdata) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($2);
 $6 = HEAP32[$1>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = HEAP32[$1>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
 $16 = (($userdata) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17>>>0)>($15>>>0);
 if (!($18)) {
  $23 = (($15) - ($17))|0;
  $24 = ($23>>>0)<($sizebytes>>>0);
  $$sizebytes = $24 ? $23 : $sizebytes;
  HEAP32[$bytesread>>2] = $$sizebytes;
  $25 = HEAP32[$16>>2]|0;
  $26 = (($10) + ($25)|0);
  _memcpy(($buffer|0),($26|0),($$sizebytes|0))|0;
  $27 = HEAP32[$16>>2]|0;
  $28 = HEAP32[$bytesread>>2]|0;
  $29 = (($28) + ($27))|0;
  HEAP32[$16>>2] = $29;
  $30 = HEAP32[$1>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 24|0);
  $33 = HEAP32[$32>>2]|0;
  FUNCTION_TABLE_vi[$33 & 4095]($30);
  $34 = HEAP32[$bytesread>>2]|0;
  $35 = ($34>>>0)<($sizebytes>>>0);
  $$ = $35 ? 22 : 0;
  STACKTOP = sp;return ($$|0);
 }
 $19 = HEAP32[$1>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($19);
 $$0 = 54;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9AudioClip7WWWSeekEPvjS0_($handle,$pos,$userdata) {
 $handle = $handle|0;
 $pos = $pos|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($handle|0)==(0|0);
 if ($0) {
  $$0 = 37;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($userdata) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($2);
 $6 = HEAP32[$1>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 $11 = ($10>>>0)<($pos>>>0);
 if (!($11)) {
  $12 = (($userdata) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13>>>0)<($pos>>>0);
  if (!($14)) {
   $19 = (($userdata) + 8|0);
   HEAP32[$19>>2] = $pos;
   $20 = HEAP32[$1>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 24|0);
   $23 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vi[$23 & 4095]($20);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vi[$18 & 4095]($15);
 $$0 = 20;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9AudioClip7pcmreadEP10FMOD_SOUNDPvj($sound,$data,$datalen) {
 $sound = $sound|0;
 $data = $data|0;
 $datalen = $datalen|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $userdata = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 20|0;
 $userdata = sp + 4|0;
 $1 = sp + 8|0;
 HEAP32[$0>>2] = $data;
 HEAP32[$userdata>>2] = 0;
 (__ZN4FMOD5Sound11getUserDataEPPv($sound,$userdata)|0);
 $2 = HEAP32[$userdata>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 23;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($2) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   HEAP32[$vararg_buffer>>2] = 692824;
   __Z6FormatPKcz($1,692776,$vararg_buffer);
   $7 = (($2) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP8[$1>>0]|0;
   $10 = $9 & 1;
   $11 = ($10<<24>>24)==(0);
   if ($11) {
    $14 = (($1) + 1|0);
    $15 = $14;
   } else {
    $12 = (($1) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $15 = $13;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($15|0),0,(692904|0),180,1,($8|0),0,(0|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP8[$1>>0]|0;
    $19 = $18 & 1;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     break;
    }
    $21 = (($1) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    __ZdlPv($22);
    break;
   }
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   $25 = HEAP8[$1>>0]|0;
   $26 = $25 & 1;
   $27 = ($26<<24>>24)==(0);
   if ($27) {
    ___resumeException($23|0);
    // unreachable;
   }
   $28 = (($1) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   __ZdlPv($29);
   ___resumeException($23|0);
   // unreachable;
  }
 } while(0);
 $30 = (__ZN9AudioClip18GetQueuedAudioDataEPPvj($2,$0,$datalen)|0);
 $$ = $30 ? 0 : 54;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9AudioClip21ScriptPCMReadCallbackEP10FMOD_SOUNDPvj($sound,$data,$datalen) {
 $sound = $sound|0;
 $data = $data|0;
 $datalen = $datalen|0;
 var $$0 = 0, $$02$i$i$i$i$i$i$i$i = 0, $$1 = 0, $$13 = 0, $$masked$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $array = 0, $exception = 0, $exitcond$i$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i$i = 0, $i$03$i$i$i$i$i$i$i$i = 0, $invocation = 0, $p$01$i$i$i$i$i$i$i = 0, $reflection$01$i$i$i$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i$i$i$i = 0, $tmpcast$byval_copy = 0, $userdata = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $tmpcast$byval_copy = sp + 208|0;
 $userdata = sp + 248|0;
 $0 = sp + 224|0;
 $array = sp + 220|0;
 $exception = sp + 216|0;
 $invocation = sp + 8|0;
 $1 = sp;
 $2 = sp + 236|0;
 (__ZN4FMOD5Sound11getUserDataEPPv($sound,$userdata)|0);
 $3 = HEAP32[$userdata>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 22;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = HEAP8[693120>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $$02$i$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i$i = 0;
  while(1) {
   $8 = $$02$i$i$i$i$i$i$i$i & 1;
   $9 = ($8|0)==(0);
   if ($9) {
    $reflection$1$i$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i$i;
   } else {
    $10 = (31 - ($i$03$i$i$i$i$i$i$i$i))|0;
    $11 = 1 << $10;
    $12 = $11 | $reflection$01$i$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i$i = $12;
   }
   $13 = (($i$03$i$i$i$i$i$i$i$i) + 1)|0;
   $14 = $$02$i$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i$i = ($13|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i$i) {
    $18 = $reflection$1$i$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i$i = 693128;
    break;
   } else {
    $$02$i$i$i$i$i$i$i$i = $14;$i$03$i$i$i$i$i$i$i$i = $13;$reflection$01$i$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $15 = HEAP8[$p$01$i$i$i$i$i$i$i>>0]|0;
   $16 = $15&255;
   $17 = $18 >>> 8;
   $$masked$i$i$i$i$i$i$i = $18 & 255;
   $19 = $16 ^ $$masked$i$i$i$i$i$i$i;
   $20 = (584048 + ($19<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $21 ^ $17;
   $23 = (($p$01$i$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i$i = ($23|0)==(((693128 + 88|0))|0);
   if ($exitcond$i$i$i$i$i$i$i) {
    break;
   } else {
    $18 = $22;$p$01$i$i$i$i$i$i$i = $23;
   }
  }
  $24 = $22 ^ -1;
  HEAP32[693112>>2] = $24;
  $25 = 693120;
  $26 = $25;
  HEAP32[$26>>2] = 1;
  $27 = (($25) + 4)|0;
  $28 = $27;
  HEAP32[$28>>2] = 0;
  $30 = $24;
 } else {
  $$pre$i$i$i$i = HEAP32[693112>>2]|0;
  $30 = $$pre$i$i$i$i;
 }
 $29 = ($5|0)==($30|0);
 if ($29) {
  $31 = (($3) + 4|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $32;
 } else {
  $33 = 0;
 }
 $34 = (__Z39GetPreResolvedSampleClipPtrFromInstancePN11SoundHandle8InstanceE($33)|0);
 $35 = ($34|0)==(0|0);
 if ($35) {
  $$0 = 22;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = (($34) + 128|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 do {
  if ($38) {
   HEAP32[$tmpcast$byval_copy>>2] = 692912;
   __Z6FormatPKcz($0,692776,$tmpcast$byval_copy);
   $39 = (($34) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP8[$0>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $46 = (($0) + 1|0);
    $47 = $46;
   } else {
    $44 = (($0) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $47 = $45;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($47|0),0,(692904|0),214,1,($40|0),0,(0|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    $50 = HEAP8[$0>>0]|0;
    $51 = $50 & 1;
    $52 = ($51<<24>>24)==(0);
    if ($52) {
     break;
    }
    $53 = (($0) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    __ZdlPv($54);
    break;
   }
   $55 = ___cxa_find_matching_catch()|0;
   $56 = tempRet0;
   $57 = HEAP8[$0>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    $$1 = $55;$$13 = $56;
    ___resumeException($$1|0);
    // unreachable;
   }
   $60 = (($0) + 8|0);
   $61 = HEAP32[$60>>2]|0;
   __ZdlPv($61);
   $$1 = $55;$$13 = $56;
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $62 = (__Z15GetAudioManagerv()|0);
 $63 = (__ZN12AudioManager22GetScriptBufferManagerEv($62)|0);
 HEAP32[$array>>2] = 0;
 $64 = $datalen >>> 2;
 __THREW__ = 0;
 invoke_viii(1982,($63|0),($64|0),($array|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 do {
  if (!($66)) {
   __THREW__ = 0;
   $67 = (invoke_ii(3302,($34|0))|0);
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if (!($69)) {
    $70 = HEAP32[$36>>2]|0;
    $71 = (($70) + 56|0);
    $72 = $71;
    $73 = $72;
    $74 = HEAP32[$73>>2]|0;
    $75 = (($72) + 4)|0;
    $76 = $75;
    $77 = HEAP32[$76>>2]|0;
    $78 = $1;
    $79 = $78;
    HEAP32[$79>>2] = $74;
    $80 = (($78) + 4)|0;
    $81 = $80;
    HEAP32[$81>>2] = $77;
    __THREW__ = 0;
    ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
    invoke_vii(2785,($invocation|0),($tmpcast$byval_copy|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if (!($83)) {
     $84 = HEAP32[$array>>2]|0;
     $85 = (($invocation) + 32|0);
     __THREW__ = 0;
     invoke_vii(3335,($85|0),($84|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if (!($87)) {
      $88 = (($invocation) + 12|0);
      HEAP32[$88>>2] = $67;
      __THREW__ = 0;
      (invoke_iii(166,($invocation|0),($exception|0))|0);
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      if (!($90)) {
       $91 = HEAP32[$exception>>2]|0;
       $92 = ($91|0)==(0|0);
       if ($92) {
        $112 = HEAP32[$array>>2]|0;
        __THREW__ = 0;
        $113 = (invoke_iiii(1555,($112|0),0,4)|0);
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if ($115) {
         break;
        }
        _memcpy(($data|0),($113|0),($datalen|0))|0;
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       $93 = (invoke_ii(3362,($67|0))|0);
       $94 = __THREW__; __THREW__ = 0;
       $95 = $94&1;
       if (!($95)) {
        ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
        __THREW__ = 0;
        invoke_viii(1731,($91|0),($93|0),($2|0));
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         $105 = ___cxa_find_matching_catch()|0;
         $106 = tempRet0;
         $107 = HEAP8[$2>>0]|0;
         $108 = $107 & 1;
         $109 = ($108<<24>>24)==(0);
         if ($109) {
          $$1 = $105;$$13 = $106;
          ___resumeException($$1|0);
          // unreachable;
         }
         $110 = (($2) + 8|0);
         $111 = HEAP32[$110>>2]|0;
         __ZdlPv($111);
         $$1 = $105;$$13 = $106;
         ___resumeException($$1|0);
         // unreachable;
        } else {
         $98 = HEAP8[$2>>0]|0;
         $99 = $98 & 1;
         $100 = ($99<<24>>24)==(0);
         if ($100) {
          $$0 = 0;
          STACKTOP = sp;return ($$0|0);
         }
         $101 = (($2) + 8|0);
         $102 = HEAP32[$101>>2]|0;
         __ZdlPv($102);
         $$0 = 0;
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $103 = ___cxa_find_matching_catch()|0;
 $104 = tempRet0;
 $$1 = $103;$$13 = $104;
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __ZN9AudioClip28ScriptPCMSetPositionCallbackEP10FMOD_SOUNDijj($sound,$subsound,$position,$postype) {
 $sound = $sound|0;
 $subsound = $subsound|0;
 $position = $position|0;
 $postype = $postype|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$02$i$i$i$i$i$i$i$i = 0, $$masked$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $exception = 0, $exitcond$i$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i$i = 0, $i$03$i$i$i$i$i$i$i$i = 0, $invocation = 0, $p$01$i$i$i$i$i$i$i = 0, $reflection$01$i$i$i$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i$i$i$i = 0, $tmpcast$byval_copy = 0, $userdata = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $tmpcast$byval_copy = sp + 208|0;
 $userdata = sp + 244|0;
 $0 = sp + 220|0;
 $exception = sp + 216|0;
 $invocation = sp + 8|0;
 $1 = sp;
 $2 = sp + 232|0;
 (__ZN4FMOD5Sound11getUserDataEPPv($sound,$userdata)|0);
 $3 = HEAP32[$userdata>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = HEAP8[693120>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $$02$i$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i$i = 0;
  while(1) {
   $8 = $$02$i$i$i$i$i$i$i$i & 1;
   $9 = ($8|0)==(0);
   if ($9) {
    $reflection$1$i$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i$i;
   } else {
    $10 = (31 - ($i$03$i$i$i$i$i$i$i$i))|0;
    $11 = 1 << $10;
    $12 = $11 | $reflection$01$i$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i$i = $12;
   }
   $13 = (($i$03$i$i$i$i$i$i$i$i) + 1)|0;
   $14 = $$02$i$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i$i = ($13|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i$i) {
    $18 = $reflection$1$i$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i$i = 693128;
    break;
   } else {
    $$02$i$i$i$i$i$i$i$i = $14;$i$03$i$i$i$i$i$i$i$i = $13;$reflection$01$i$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $15 = HEAP8[$p$01$i$i$i$i$i$i$i>>0]|0;
   $16 = $15&255;
   $17 = $18 >>> 8;
   $$masked$i$i$i$i$i$i$i = $18 & 255;
   $19 = $16 ^ $$masked$i$i$i$i$i$i$i;
   $20 = (584048 + ($19<<2)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $21 ^ $17;
   $23 = (($p$01$i$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i$i = ($23|0)==(((693128 + 88|0))|0);
   if ($exitcond$i$i$i$i$i$i$i) {
    break;
   } else {
    $18 = $22;$p$01$i$i$i$i$i$i$i = $23;
   }
  }
  $24 = $22 ^ -1;
  HEAP32[693112>>2] = $24;
  $25 = 693120;
  $26 = $25;
  HEAP32[$26>>2] = 1;
  $27 = (($25) + 4)|0;
  $28 = $27;
  HEAP32[$28>>2] = 0;
  $30 = $24;
 } else {
  $$pre$i$i$i$i = HEAP32[693112>>2]|0;
  $30 = $$pre$i$i$i$i;
 }
 $29 = ($5|0)==($30|0);
 if ($29) {
  $31 = (($3) + 4|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $32;
 } else {
  $33 = 0;
 }
 $34 = (__Z39GetPreResolvedSampleClipPtrFromInstancePN11SoundHandle8InstanceE($33)|0);
 $35 = ($34|0)==(0|0);
 if ($35) {
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = (($34) + 128|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 do {
  if ($38) {
   HEAP32[$tmpcast$byval_copy>>2] = 693000;
   __Z6FormatPKcz($0,692776,$tmpcast$byval_copy);
   $39 = (($34) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = HEAP8[$0>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $46 = (($0) + 1|0);
    $47 = $46;
   } else {
    $44 = (($0) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $47 = $45;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($47|0),0,(692904|0),270,1,($40|0),0,(0|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if (!($49)) {
    $50 = HEAP8[$0>>0]|0;
    $51 = $50 & 1;
    $52 = ($51<<24>>24)==(0);
    if ($52) {
     break;
    }
    $53 = (($0) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    __ZdlPv($54);
    break;
   }
   $55 = ___cxa_find_matching_catch()|0;
   $56 = tempRet0;
   $57 = HEAP8[$0>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    $$01 = $55;$$02 = $56;
    ___resumeException($$01|0);
    // unreachable;
   }
   $60 = (($0) + 8|0);
   $61 = HEAP32[$60>>2]|0;
   __ZdlPv($61);
   $$01 = $55;$$02 = $56;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $62 = (__ZN9Scripting19ScriptingWrapperForEP6Object($34)|0);
 $63 = HEAP32[$36>>2]|0;
 $64 = (($63) + 64|0);
 $65 = $64;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = (($65) + 4)|0;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = $1;
 $72 = $71;
 HEAP32[$72>>2] = $67;
 $73 = (($71) + 4)|0;
 $74 = $73;
 HEAP32[$74>>2] = $70;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
 $75 = (($invocation) + 32|0);
 __ZN18ScriptingArguments6AddIntEi($75,$position);
 $76 = (($invocation) + 12|0);
 HEAP32[$76>>2] = $62;
 (__ZN19ScriptingInvocation6InvokeEPP18ScriptingException($invocation,$exception)|0);
 $77 = HEAP32[$exception>>2]|0;
 $78 = ($77|0)==(0|0);
 if ($78) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $79 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($62)|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(1731,($77|0),($79|0),($2|0));
 $80 = __THREW__; __THREW__ = 0;
 $81 = $80&1;
 if ($81) {
  $87 = ___cxa_find_matching_catch()|0;
  $88 = tempRet0;
  $89 = HEAP8[$2>>0]|0;
  $90 = $89 & 1;
  $91 = ($90<<24>>24)==(0);
  if ($91) {
   $$01 = $87;$$02 = $88;
   ___resumeException($$01|0);
   // unreachable;
  }
  $92 = (($2) + 8|0);
  $93 = HEAP32[$92>>2]|0;
  __ZdlPv($93);
  $$01 = $87;$$02 = $88;
  ___resumeException($$01|0);
  // unreachable;
 } else {
  $82 = HEAP8[$2>>0]|0;
  $83 = $82 & 1;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $85 = (($2) + 8|0);
  $86 = HEAP32[$85>>2]|0;
  __ZdlPv($86);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10SampleClip20ResolveFMODSoundTypeENS_9SoundTypeE($type) {
 $type = $type|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($type|0) {
 case 8:  {
  $$0 = 10;
  break;
 }
 case 2:  {
  $$0 = 20;
  break;
 }
 case 4:  {
  $$0 = 13;
  break;
 }
 case 9:  {
  $$0 = 12;
  break;
 }
 case 7:  {
  $$0 = 17;
  break;
 }
 case 5:  {
  $$0 = 14;
  break;
 }
 case 3:  {
  $$0 = 2;
  break;
 }
 case 1:  {
  $$0 = 8;
  break;
 }
 case 6:  {
  $$0 = 21;
  break;
 }
 default: {
  $$0 = 0;
 }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN10SampleClip17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $6;
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10SampleClip13LoadAudioDataEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 124|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 100|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP8[$0>>0] = 1;
 __ZN10SampleClip13LoadBaseSoundEv($this);
 $6 = (__Z15GetSoundManagerv()|0);
 __ZN12SoundManager20RegisterModifiedClipEP10SampleClip($6,$this);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10SampleClip13LoadBaseSoundEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$2 = 0, $$3 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $actualLoadType$0 = 0, $flags$1 = 0;
 var $mode$0 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 56|0;
 $1 = sp;
 $2 = sp + 8|0;
 $3 = sp + 24|0;
 $4 = sp + 32|0;
 $5 = sp + 48|0;
 $6 = (($this) + 100|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $9 = (($this) + 124|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
 }
 $12 = (($this) + 48|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $18 = $13&255;
  $19 = $18 >>> 1;
  $21 = $19;
 } else {
  $16 = (($this) + 52|0);
  $17 = HEAP32[$16>>2]|0;
  $21 = $17;
 }
 $20 = ($21|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 1;
 $25 = ($24|0)==(0);
 if ($25) {
  $36 = (($this) + 101|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($37<<24>>24)==(0);
  $$2 = $38 ? 82 : 65618;
  $$pre = (($this) + 72|0);
  $$pre$phiZ2D = $$pre;$flags$1 = 0;$mode$0 = $$2;
 } else {
  $26 = (($this) + 72|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(1);
  $$ = $28 ? 2 : 0;
  $29 = (($this) + 101|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $$pre$phiZ2D = $26;$flags$1 = $$;$mode$0 = 16466;
  } else {
   $32 = ($this|0)==(0|0);
   if ($32) {
    $35 = 0;
   } else {
    $33 = (($this) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = $34;
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(693816,0,693424,202,1,$35,0,0);
   $$pre$phiZ2D = $26;$flags$1 = $$;$mode$0 = 16466;
  }
 }
 $39 = HEAP32[$$pre$phiZ2D>>2]|0;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)>(2);
 if ($42) {
  $43 = (($this) + 76|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)!=(-1);
  $46 = ($39|0)==(1);
  $or$cond = $45 & $46;
  $$3 = $or$cond ? 2 : $39;
  $actualLoadType$0 = $$3;
 } else {
  $actualLoadType$0 = $39;
 }
 if ((($actualLoadType$0|0) == 1)) {
  $61 = (($this) + 80|0);
  $62 = (__Z15GetSoundManagerv()|0);
  $63 = (($this) + 96|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = $mode$0 | 512;
  $66 = ($this|0)==(0|0);
  if ($66) {
   HEAP32[$3>>2] = 0;
  } else {
   $67 = (($this) + 4|0);
   $68 = HEAP32[$67>>2]|0;
   HEAP32[$3>>2] = $68;
  }
  __ZN12SoundManager9GetHandleERK16StreamedResourceijj4PPtrI10SampleClipEb($2,$62,$12,$64,$65,$flags$1,$3,0);
  __THREW__ = 0;
  invoke_vii(3336,($61|0),($2|0));
  $69 = __THREW__; __THREW__ = 0;
  $70 = $69&1;
  if (!($70)) {
   __ZN11SoundHandleD2Ev($2);
   STACKTOP = sp;return;
  }
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3642,($2|0));
  $73 = __THREW__; __THREW__ = 0;
  $74 = $73&1;
  if ($74) {
   $89 = ___cxa_find_matching_catch(0|0)|0;
   $90 = tempRet0;
   ___clang_call_terminate($89);
   // unreachable;
  } else {
   $$0 = $72;$$01 = $71;
   ___resumeException($$01|0);
   // unreachable;
  }
 } else if ((($actualLoadType$0|0) == 0)) {
  $47 = (($this) + 80|0);
  $48 = (__Z15GetSoundManagerv()|0);
  $49 = (($this) + 96|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $mode$0 | 256;
  $52 = ($this|0)==(0|0);
  if ($52) {
   HEAP32[$1>>2] = 0;
  } else {
   $53 = (($this) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$1>>2] = $54;
  }
  __ZN12SoundManager9GetHandleERK16StreamedResourceijj4PPtrI10SampleClipEb($0,$48,$12,$50,$51,$flags$1,$1,0);
  __THREW__ = 0;
  invoke_vii(3336,($47|0),($0|0));
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if (!($56)) {
   __ZN11SoundHandleD2Ev($0);
   STACKTOP = sp;return;
  }
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3642,($0|0));
  $59 = __THREW__; __THREW__ = 0;
  $60 = $59&1;
  if ($60) {
   $89 = ___cxa_find_matching_catch(0|0)|0;
   $90 = tempRet0;
   ___clang_call_terminate($89);
   // unreachable;
  } else {
   $$0 = $58;$$01 = $57;
   ___resumeException($$01|0);
   // unreachable;
  }
 } else if ((($actualLoadType$0|0) == 2)) {
  $75 = (($this) + 80|0);
  $76 = (__Z15GetSoundManagerv()|0);
  $77 = (($this) + 96|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = $mode$0 | 128;
  $80 = ($this|0)==(0|0);
  if ($80) {
   HEAP32[$5>>2] = 0;
  } else {
   $81 = (($this) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   HEAP32[$5>>2] = $82;
  }
  __ZN12SoundManager9GetHandleERK16StreamedResourceijj4PPtrI10SampleClipEb($4,$76,$12,$78,$79,2,$5,0);
  __THREW__ = 0;
  invoke_vii(3336,($75|0),($4|0));
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if (!($84)) {
   __ZN11SoundHandleD2Ev($4);
   STACKTOP = sp;return;
  }
  $85 = ___cxa_find_matching_catch()|0;
  $86 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3642,($4|0));
  $87 = __THREW__; __THREW__ = 0;
  $88 = $87&1;
  if ($88) {
   $89 = ___cxa_find_matching_catch(0|0)|0;
   $90 = tempRet0;
   ___clang_call_terminate($89);
   // unreachable;
  } else {
   $$0 = $86;$$01 = $85;
   ___resumeException($$01|0);
   // unreachable;
  }
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN10SampleClip15UnloadAudioDataEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(693336,0,693424,135,1,$4,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 124|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = (__ZNK14SoundHandleAPI12GetLoadStateEv($9)|0);
  $12 = ($11|0)==(3);
  if (!($12)) {
   $13 = HEAP32[$8>>2]|0;
   $14 = (__ZNK14SoundHandleAPI12GetLoadStateEv($13)|0);
   $15 = ($14|0)==(4);
   if (!($15)) {
    $16 = ($this|0)==(0|0);
    if ($16) {
     $19 = 0;
    } else {
     $17 = (($this) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = $18;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(693432,0,693424,147,512,$19,0,0);
   }
  }
 }
 HEAP8[$5>>0] = 0;
 $20 = (__Z15GetSoundManagerv()|0);
 __ZN12SoundManager17UnloadDynamicClipEP10SampleClip($20,$this);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK10SampleClip12GetLoadStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK14SoundHandleAPI12GetLoadStateEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN10SampleClip15AllocateChannelEby($agg$result,$this,$paused,$0,$1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $paused = $paused|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$not = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (($this) + 80|0);
 $3 = (($this) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN10SampleClip13LoadBaseSoundEv($this);
 }
 __ZN11SoundHandle13CreateChannelEb($agg$result,$2,$paused);
 $6 = (($agg$result) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $$not = ($7|0)==(0|0);
 $8 = ($0|0)==(0);
 $9 = ($1|0)==(0);
 $10 = $8 & $9;
 $or$cond = $$not | $10;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 $11 = (invoke_iiiii(261,($7|0),1,($1|0),($0|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  __THREW__ = 0;
  (invoke_iiiii(262,($11|0),(693640|0),173,(693712|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   STACKTOP = sp;return;
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 HEAP32[$6>>2] = 0;
 $18 = HEAP32[$agg$result>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  ___resumeException($16|0);
  // unreachable;
 }
 $20 = (($agg$result) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($18) + 4|0);
 HEAP32[$22>>2] = $21;
 $23 = HEAP32[$agg$result>>2]|0;
 $24 = HEAP32[$20>>2]|0;
 HEAP32[$24>>2] = $23;
 HEAP32[$agg$result>>2] = 0;
 HEAP32[$20>>2] = 0;
 ___resumeException($16|0);
 // unreachable;
}
function __Z15_CheckFMODError11FMOD_RESULTPKciS1_($result,$filename,$line,$funcname) {
 $result = $result|0;
 $filename = $filename|0;
 $line = $line|0;
 $funcname = $funcname|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 16|0;
 do {
  switch ($result|0) {
  case 83:  {
   $$0$i = 696592;
   break;
  }
  case 90:  {
   $$0$i = 697200;
   break;
  }
  case 12:  {
   $$0$i = 695640;
   break;
  }
  case 39:  {
   $$0$i = 698528;
   break;
  }
  case 41:  {
   $$0$i = 698672;
   break;
  }
  case 9:  {
   $$0$i = 695504;
   break;
  }
  case 42:  {
   $$0$i = 698736;
   break;
  }
  case 14:  {
   $$0$i = 695848;
   break;
  }
  case 11:  {
   $$0$i = 695576;
   break;
  }
  case 85:  {
   $$0$i = 696808;
   break;
  }
  case 7:  {
   $$0$i = 695424;
   break;
  }
  case 88:  {
   $$0$i = 697152;
   break;
  }
  case 31:  {
   $$0$i = 698040;
   break;
  }
  case 25:  {
   $$0$i = 697704;
   break;
  }
  case 6:  {
   $$0$i = 695384;
   break;
  }
  case 8:  {
   $$0$i = 695456;
   break;
  }
  case 89:  {
   $$0$i = 697288;
   break;
  }
  case 21:  {
   $$0$i = 697512;
   break;
  }
  case 26:  {
   $$0$i = 697744;
   break;
  }
  case 84:  {
   $$0$i = 696752;
   break;
  }
  case 28:  {
   $$0$i = 697904;
   break;
  }
  case 33:  {
   $$0$i = 698152;
   break;
  }
  case 18:  {
   $$0$i = 696352;
   break;
  }
  case 3:  {
   $$0$i = 695232;
   break;
  }
  case 16:  {
   $$0$i = 696096;
   break;
  }
  case 87:  {
   $$0$i = 696984;
   break;
  }
  case 4:  {
   $$0$i = 695280;
   break;
  }
  case 92:  {
   $$0$i = 696456;
   break;
  }
  case 2:  {
   $$0$i = 695096;
   break;
  }
  case 15:  {
   $$0$i = 695992;
   break;
  }
  case 23:  {
   $$0$i = 697648;
   break;
  }
  case 5:  {
   $$0$i = 695344;
   break;
  }
  case 13:  {
   $$0$i = 695792;
   break;
  }
  case 17:  {
   $$0$i = 696160;
   break;
  }
  case 91:  {
   $$0$i = 696704;
   break;
  }
  case 86:  {
   $$0$i = 696880;
   break;
  }
  case 24:  {
   $$0$i = 697672;
   break;
  }
  case 10:  {
   $$0$i = 695536;
   break;
  }
  case 29:  {
   $$0$i = 697976;
   break;
  }
  case 30:  {
   $$0$i = 698008;
   break;
  }
  case 32:  {
   $$0$i = 698104;
   break;
  }
  case 20:  {
   $$0$i = 697400;
   break;
  }
  case 34:  {
   $$0$i = 698216;
   break;
  }
  case 36:  {
   $$0$i = 698376;
   break;
  }
  case 37:  {
   $$0$i = 698416;
   break;
  }
  case 38:  {
   $$0$i = 698472;
   break;
  }
  case 22:  {
   $$0$i = 697552;
   break;
  }
  case 35:  {
   $$0$i = 698320;
   break;
  }
  case 27:  {
   $$0$i = 697832;
   break;
  }
  case 40:  {
   $$0$i = 698616;
   break;
  }
  case 19:  {
   $$0$i = 697376;
   break;
  }
  case 65:  {
   $$0$i = 700944;
   break;
  }
  case 77:  {
   $$0$i = 702368;
   break;
  }
  case 70:  {
   $$0$i = 701400;
   break;
  }
  case 62:  {
   $$0$i = 700720;
   break;
  }
  case 94:  {
   $$0$i = 699096;
   break;
  }
  case 49:  {
   $$0$i = 699512;
   break;
  }
  case 43:  {
   $$0$i = 698808;
   break;
  }
  case 73:  {
   $$0$i = 702048;
   break;
  }
  case 78:  {
   $$0$i = 702520;
   break;
  }
  case 44:  {
   $$0$i = 698848;
   break;
  }
  case 93:  {
   $$0$i = 699144;
   break;
  }
  case 56:  {
   $$0$i = 700176;
   break;
  }
  case 57:  {
   $$0$i = 700216;
   break;
  }
  case 61:  {
   $$0$i = 700616;
   break;
  }
  case 68:  {
   $$0$i = 701168;
   break;
  }
  case 74:  {
   $$0$i = 702168;
   break;
  }
  case 79:  {
   $$0$i = 702600;
   break;
  }
  case 69:  {
   $$0$i = 701288;
   break;
  }
  case 1:  {
   $$0$i = 695032;
   break;
  }
  case 60:  {
   $$0$i = 700576;
   break;
  }
  case 67:  {
   $$0$i = 701072;
   break;
  }
  case 48:  {
   $$0$i = 699384;
   break;
  }
  case 54:  {
   $$0$i = 699968;
   break;
  }
  case 64:  {
   $$0$i = 700872;
   break;
  }
  case 46:  {
   $$0$i = 699224;
   break;
  }
  case 47:  {
   $$0$i = 699304;
   break;
  }
  case 45:  {
   $$0$i = 698976;
   break;
  }
  case 52:  {
   $$0$i = 699848;
   break;
  }
  case 55:  {
   $$0$i = 700056;
   break;
  }
  case 59:  {
   $$0$i = 700472;
   break;
  }
  case 75:  {
   $$0$i = 701608;
   break;
  }
  case 72:  {
   $$0$i = 701896;
   break;
  }
  case 66:  {
   $$0$i = 701008;
   break;
  }
  case 50:  {
   $$0$i = 699704;
   break;
  }
  case 71:  {
   $$0$i = 701464;
   break;
  }
  case 76:  {
   $$0$i = 702304;
   break;
  }
  case 80:  {
   $$0$i = 702680;
   break;
  }
  case 81:  {
   $$0$i = 702792;
   break;
  }
  case 82:  {
   $$0$i = 702840;
   break;
  }
  case 95:  {
   $$0$i = 699032;
   break;
  }
  case 53:  {
   $$0$i = 699896;
   break;
  }
  case 63:  {
   $$0$i = 700816;
   break;
  }
  case 51:  {
   $$0$i = 699752;
   break;
  }
  case 58:  {
   $$0$i = 700352;
   break;
  }
  case 0:  {
   STACKTOP = sp;return ($result|0);
   break;
  }
  default: {
   $$0$i = 702904;
  }
  }
 } while(0);
 HEAP32[$vararg_buffer>>2] = $filename;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $line;
 $vararg_ptr2 = (($vararg_buffer) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $funcname;
 $vararg_ptr3 = (($vararg_buffer) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $$0$i;
 __Z6FormatPKcz($0,694992,$vararg_buffer);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($0) + 1|0);
  $7 = $6;
 } else {
  $4 = (($0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($7|0),0,(693424|0),21,1,0,0,(0|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP8[$0>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   ___resumeException($15|0);
   // unreachable;
  }
  $20 = (($0) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  __ZdlPv($21);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $10 = HEAP8[$0>>0]|0;
  $11 = $10 & 1;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   STACKTOP = sp;return ($result|0);
  }
  $13 = (($0) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  __ZdlPv($14);
  STACKTOP = sp;return ($result|0);
 }
 return 0|0;
}
function __ZN10SampleClip20AllocatePreviewSoundEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Z15GetSoundManagerv()|0);
 $2 = (($this) + 48|0);
 $3 = (($this) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($this|0)==(0|0);
 if ($5) {
  HEAP32[$0>>2] = 0;
 } else {
  $6 = (($this) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
 }
 __ZN12SoundManager9GetHandleERK16StreamedResourceijj4PPtrI10SampleClipEb($agg$result,$1,$2,$4,202,0,$0,1);
 STACKTOP = sp;return;
}
function __ZN10SampleClip7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$label>>2]|0;
 HEAP32[$2>>2] = $3;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
 $4 = (__Znwj10MemLabelIdbiPKci(128,$$byval_copy8,1,16,693424,86)|0);
 HEAP32[$1>>2] = $3;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1685,($4|0),($$byval_copy8|0),($mode|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  $eh$lpad$body$index2Z2D = $45;$eh$lpad$body$indexZ2D = $44;
 } else {
  HEAP32[$4>>2] = ((693224 + 8|0));
  $7 = (($4) + 28|0);
  $8 = (($4) + 64|0);
  $9 = $8;
  $10 = $9;
  HEAP32[$10>>2] = 0;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = 0;
  $13 = (($4) + 72|0);
  HEAP32[$13>>2] = 0;
  $14 = (($4) + 76|0);
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;HEAP32[$7+24>>2]=0|0;HEAP32[$7+28>>2]=0|0;
  HEAP32[$14>>2] = -1;
  $15 = (($4) + 80|0);
  __THREW__ = 0;
  invoke_vi(3643,($15|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $34 = (($4) + 96|0);
   HEAP32[$34>>2] = 0;
   $35 = (($4) + 100|0);
   HEAP8[$35>>0] = 1;
   $36 = (($4) + 101|0);
   HEAP8[$36>>0] = 0;
   $37 = (($4) + 102|0);
   HEAP8[$37>>0] = 0;
   $38 = (($4) + 104|0);
   HEAP32[$38>>2] = 0;
   $39 = (($4) + 108|0);
   HEAP32[$39>>2] = 0;
   $40 = (($4) + 112|0);
   HEAP32[$40>>2] = 0;
   $41 = (($4) + 116|0);
   HEAP32[$41>>2] = $4;
   $42 = (($4) + 120|0);
   HEAP32[$42>>2] = 0;
   $43 = (($4) + 124|0);
   HEAP8[$43>>0] = 0;
   STACKTOP = sp;return ($4|0);
  }
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $20 = (($4) + 48|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if (!($23)) {
   $24 = (($4) + 56|0);
   $25 = HEAP32[$24>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($25|0),($$byval_copy8|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
  }
  __THREW__ = 0;
  invoke_vi(3423,($4|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch(0|0)|0;
   $33 = tempRet0;
   ___clang_call_terminate($32);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
  }
 }
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_viiiiii(97,($4|0),($$byval_copy8|0),1,16,(693424|0),86);
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch(0|0)|0;
  $49 = tempRet0;
  ___clang_call_terminate($48);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK10SampleClip25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 271;
}
function __ZN10SampleClip23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694048,694032,$this,0);
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10SampleClip23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,694048,694032,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10SampleClip23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10SampleClip23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10SampleClip23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10SampleClip23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9AudioClipC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy1,$mode);
 HEAP32[$this>>2] = ((693224 + 8|0));
 $3 = (($this) + 28|0);
 $4 = (($this) + 64|0);
 $5 = $4;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 72|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 76|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;HEAP32[$3+24>>2]=0|0;HEAP32[$3+28>>2]=0|0;
 HEAP32[$10>>2] = -1;
 $11 = (($this) + 80|0);
 __THREW__ = 0;
 invoke_vi(3643,($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  $30 = (($this) + 96|0);
  HEAP32[$30>>2] = 0;
  $31 = (($this) + 100|0);
  HEAP8[$31>>0] = 1;
  $32 = (($this) + 101|0);
  HEAP8[$32>>0] = 0;
  $33 = (($this) + 102|0);
  HEAP8[$33>>0] = 0;
  $34 = (($this) + 104|0);
  HEAP32[$34>>2] = 0;
  $35 = (($this) + 108|0);
  HEAP32[$35>>2] = 0;
  $36 = (($this) + 112|0);
  HEAP32[$36>>2] = 0;
  $37 = (($this) + 116|0);
  HEAP32[$37>>2] = $this;
  $38 = (($this) + 120|0);
  HEAP32[$38>>2] = 0;
  $39 = (($this) + 124|0);
  HEAP8[$39>>0] = 0;
  HEAP32[$this>>2] = ((694056 + 8|0));
  $40 = (($this) + 125|0);
  HEAP8[$40>>0] = 1;
  $41 = (($this) + 128|0);
  HEAP32[$41>>2] = 0;
  STACKTOP = sp;return;
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $16 = (($this) + 48|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if (!($19)) {
  $20 = (($this) + 56|0);
  $21 = HEAP32[$20>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($21|0),($$byval_copy1|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   ___cxa_call_unexpected(($24|0));
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZN9AudioClip15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9AudioClip16EnableLegacyModeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__Znwj(80)|0);
 dest=$3+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$0>>2] = $3;
 HEAP32[$3>>2] = 0;
 $4 = (($3) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 20|0);
 HEAP8[$5>>0] = 0;
 $6 = (($3) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($3) + 28|0);
 HEAP8[$7>>0] = 1;
 $8 = (($3) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = (($3) + 36|0);
 HEAP8[$9>>0] = 0;
 $10 = (($3) + 40|0);
 HEAP32[$10>>2] = 0;
 $11 = (($3) + 44|0);
 HEAP32[$11>>2] = 3;
 $12 = (($3) + 48|0);
 HEAP32[$12>>2] = 0;
 $13 = (($3) + 52|0);
 HEAP32[$13>>2] = 0;
 $14 = (($3) + 56|0);
 ;HEAP32[$14+0>>2]=HEAP32[599912+0>>2]|0;HEAP8[$14+4>>0]=HEAP8[599912+4>>0]|0;
 $15 = (($3) + 64|0);
 ;HEAP32[$15+0>>2]=HEAP32[599912+0>>2]|0;HEAP8[$15+4>>0]=HEAP8[599912+4>>0]|0;
 $16 = (($3) + 72|0);
 HEAP32[$16>>2] = 0;
 $17 = (($3) + 76|0);
 HEAP8[$17>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9AudioClip10InitStreamEP3WWWP13MoviePlaybackb15FMOD_SOUND_TYPE($this,$streamData,$movie,$realStream,$fmodSoundType) {
 $this = $this|0;
 $streamData = $streamData|0;
 $movie = $movie|0;
 $realStream = $realStream|0;
 $fmodSoundType = $fmodSoundType|0;
 var $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$16 = 0, $$2 = 0, $$24 = 0, $$byval_copy9 = 0, $$pre$i = 0, $$pre1$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $ext = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy9 = sp;
 $0 = sp + 80|0;
 $1 = sp + 16|0;
 $ext = sp + 20|0;
 $2 = sp + 32|0;
 $3 = sp + 44|0;
 $4 = sp + 56|0;
 $5 = sp + 68|0;
 $6 = (($this) + 128|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (__Znwj(80)|0);
  dest=$9+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$6>>2] = $9;
  HEAP32[$9>>2] = 0;
  $10 = (($9) + 4|0);
  HEAP32[$10>>2] = 0;
  $11 = (($9) + 20|0);
  HEAP8[$11>>0] = 0;
  $12 = (($9) + 24|0);
  HEAP32[$12>>2] = 0;
  $13 = (($9) + 28|0);
  HEAP8[$13>>0] = 1;
  $14 = (($9) + 32|0);
  HEAP32[$14>>2] = 0;
  $15 = (($9) + 36|0);
  HEAP8[$15>>0] = 0;
  $16 = (($9) + 40|0);
  HEAP32[$16>>2] = 0;
  $17 = (($9) + 44|0);
  HEAP32[$17>>2] = 3;
  $18 = (($9) + 48|0);
  HEAP32[$18>>2] = 0;
  $19 = (($9) + 52|0);
  HEAP32[$19>>2] = 0;
  $20 = (($9) + 56|0);
  ;HEAP32[$20+0>>2]=HEAP32[599912+0>>2]|0;HEAP8[$20+4>>0]=HEAP8[599912+4>>0]|0;
  $21 = (($9) + 64|0);
  ;HEAP32[$21+0>>2]=HEAP32[599912+0>>2]|0;HEAP8[$21+4>>0]=HEAP8[599912+4>>0]|0;
  $22 = (($9) + 72|0);
  HEAP32[$22>>2] = 0;
  $23 = (($9) + 76|0);
  HEAP8[$23>>0] = 0;
 }
 $24 = ($streamData|0)==(0|0);
 L4: do {
  if (!($24)) {
   $25 = HEAP32[$streamData>>2]|0;
   $26 = (($25) + 48|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (FUNCTION_TABLE_ii[$27 & 4095]($streamData)|0);
   $29 = (_strlen(($28|0))|0);
   $30 = ($29>>>0)>(4294967279);
   if ($30) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $31 = ($29>>>0)<(11);
   if ($31) {
    $32 = $29 << 1;
    $33 = $32&255;
    HEAP8[$3>>0] = $33;
    $34 = (($3) + 1|0);
    $__p$0$i$i$i = $34;
   } else {
    $35 = (($29) + 16)|0;
    $36 = $35 & -16;
    $37 = (__Znwj($36)|0);
    $38 = (($3) + 8|0);
    HEAP32[$38>>2] = $37;
    $39 = $36 | 1;
    HEAP32[$3>>2] = $39;
    $40 = (($3) + 4|0);
    HEAP32[$40>>2] = $29;
    $__p$0$i$i$i = $37;
   }
   _memcpy(($__p$0$i$i$i|0),($28|0),($29|0))|0;
   $41 = (($__p$0$i$i$i) + ($29)|0);
   HEAP8[$41>>0] = 0;
   __THREW__ = 0;
   invoke_vii(2752,($2|0),($3|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   do {
    if ($43) {
     $61 = ___cxa_find_matching_catch()|0;
     $62 = tempRet0;
     $$01 = $62;$$02 = $61;
    } else {
     __THREW__ = 0;
     invoke_vii(3282,($ext|0),($2|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      $63 = ___cxa_find_matching_catch()|0;
      $64 = tempRet0;
      $65 = HEAP8[$2>>0]|0;
      $66 = $65 & 1;
      $67 = ($66<<24>>24)==(0);
      if ($67) {
       $$01 = $64;$$02 = $63;
       break;
      }
      $68 = (($2) + 8|0);
      $69 = HEAP32[$68>>2]|0;
      __ZdlPv($69);
      $$01 = $64;$$02 = $63;
      break;
     }
     $46 = HEAP8[$2>>0]|0;
     $47 = $46 & 1;
     $48 = ($47<<24>>24)==(0);
     if (!($48)) {
      $49 = (($2) + 8|0);
      $50 = HEAP32[$49>>2]|0;
      __ZdlPv($50);
     }
     $51 = HEAP8[$3>>0]|0;
     $52 = $51 & 1;
     $53 = ($52<<24>>24)==(0);
     if (!($53)) {
      $54 = (($3) + 8|0);
      $55 = HEAP32[$54>>2]|0;
      __ZdlPv($55);
     }
     $56 = ($fmodSoundType|0)==(0);
     if ($56) {
      __THREW__ = 0;
      $57 = (invoke_ii(3375,($ext|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 23;
      } else {
       $60 = HEAP32[$6>>2]|0;
       HEAP32[$60>>2] = $57;
       $131 = $60;$79 = $57;
       label = 26;
      }
     } else {
      $77 = HEAP32[$6>>2]|0;
      HEAP32[$77>>2] = $fmodSoundType;
      $131 = $77;$79 = $fmodSoundType;
      label = 26;
     }
     L30: do {
      if ((label|0) == 26) {
       $78 = ($79|0)==(0);
       if ($78) {
        $80 = HEAP32[$streamData>>2]|0;
        $81 = (($80) + 48|0);
        $82 = HEAP32[$81>>2]|0;
        __THREW__ = 0;
        $83 = (invoke_ii($82|0,($streamData|0))|0);
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         label = 23;
         break;
        }
        __THREW__ = 0;
        HEAP32[$$byval_copy9>>2] = $83;
        invoke_viii(1617,($4|0),(694168|0),($$byval_copy9|0));
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         label = 23;
         break;
        }
        $88 = ($this|0)==(0|0);
        if ($88) {
         $98 = 0;
        } else {
         $89 = (($this) + 4|0);
         $90 = HEAP32[$89>>2]|0;
         $98 = $90;
        }
        $91 = HEAP8[$4>>0]|0;
        $92 = $91 & 1;
        $93 = ($92<<24>>24)==(0);
        if ($93) {
         $96 = (($4) + 1|0);
         $97 = $96;
        } else {
         $94 = (($4) + 8|0);
         $95 = HEAP32[$94>>2]|0;
         $97 = $95;
        }
        __THREW__ = 0;
        invoke_viiiiiiii(21,($97|0),0,(693424|0),308,1,($98|0),0,(0|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         $111 = ___cxa_find_matching_catch()|0;
         $112 = tempRet0;
         $113 = HEAP8[$4>>0]|0;
         $114 = $113 & 1;
         $115 = ($114<<24>>24)==(0);
         if ($115) {
          $$1 = $112;$$13 = $111;
          break;
         }
         $116 = (($4) + 8|0);
         $117 = HEAP32[$116>>2]|0;
         __ZdlPv($117);
         $$1 = $112;$$13 = $111;
         break;
        }
        $101 = HEAP8[$4>>0]|0;
        $102 = $101 & 1;
        $103 = ($102<<24>>24)==(0);
        if (!($103)) {
         $104 = (($4) + 8|0);
         $105 = HEAP32[$104>>2]|0;
         __ZdlPv($105);
        }
        $106 = HEAP8[$ext>>0]|0;
        $107 = $106 & 1;
        $108 = ($107<<24>>24)==(0);
        if ($108) {
         $$16 = 0;
         STACKTOP = sp;return ($$16|0);
        }
        $109 = (($ext) + 8|0);
        $110 = HEAP32[$109>>2]|0;
        __ZdlPv($110);
        $$16 = 0;
        STACKTOP = sp;return ($$16|0);
       }
       L55: do {
        if ($realStream) {
         switch ($79|0) {
         case 14:  {
          break L55;
          break;
         }
         case 17: case 12: case 10: case 21:  {
          break;
         }
         default: {
          label = 49;
          break L55;
         }
         }
         $118 = ($this|0)==(0|0);
         if ($118) {
          $121 = 0;
         } else {
          $119 = (($this) + 4|0);
          $120 = HEAP32[$119>>2]|0;
          $121 = $120;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,(694248|0),0,(693424|0),318,1,($121|0),0,(0|0));
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 23;
          break L30;
         }
         $124 = HEAP8[$ext>>0]|0;
         $125 = $124 & 1;
         $126 = ($125<<24>>24)==(0);
         if ($126) {
          $$16 = 0;
          STACKTOP = sp;return ($$16|0);
         }
         $127 = (($ext) + 8|0);
         $128 = HEAP32[$127>>2]|0;
         __ZdlPv($128);
         $$16 = 0;
         STACKTOP = sp;return ($$16|0);
        } else {
         $129 = ($79|0)==(14);
         if (!($129)) {
          label = 49;
         }
        }
       } while(0);
       if ((label|0) == 49) {
        $130 = (($131) + 32|0);
        HEAP32[$130>>2] = $streamData;
        $132 = HEAP32[$6>>2]|0;
        $133 = (($132) + 32|0);
        $134 = HEAP32[$133>>2]|0;
        $135 = (($134) + 16|0);
        HEAP32[$135>>2] = $this;
        $136 = HEAP32[$6>>2]|0;
        $137 = (($136) + 32|0);
        $138 = HEAP32[$137>>2]|0;
        __THREW__ = 0;
        invoke_vi(3644,($138|0));
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         label = 23;
         break;
        }
        $180 = HEAP32[$6>>2]|0;
        $181 = (($180) + 36|0);
        HEAP8[$181>>0] = 1;
        $182 = (($180) + 76|0);
        $183 = $realStream&1;
        HEAP8[$182>>0] = $183;
        $184 = (($180) + 16|0);
        $185 = HEAP32[$184>>2]|0;
        $186 = (($180) + 8|0);
        $187 = HEAP32[$186>>2]|0;
        $188 = $185;
        $189 = $187;
        $190 = (($188) - ($189))|0;
        $191 = ($190>>>0)<(65536);
        do {
         if ($191) {
          $192 = (($180) + 12|0);
          $193 = HEAP32[$192>>2]|0;
          $194 = $193;
          $195 = (($194) - ($189))|0;
          HEAP32[$0>>2] = 20;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
          $196 = (invoke_iiiiiii(102,65536,16,($$byval_copy9|0),0,(693424|0),79)|0);
          $197 = __THREW__; __THREW__ = 0;
          $198 = $197&1;
          if ($198) {
           label = 23;
           break L30;
          }
          $$pre$i = HEAP32[$186>>2]|0;
          $$pre1$i = HEAP32[$192>>2]|0;
          $199 = (($196) + ($195)|0);
          $200 = (($196) + 65536|0);
          $201 = $$pre1$i;
          $202 = $$pre$i;
          $203 = (($201) - ($202))|0;
          $$sum$i = (($195) - ($203))|0;
          $204 = (($196) + ($$sum$i)|0);
          _memcpy(($204|0),($$pre$i|0),($203|0))|0;
          $205 = HEAP32[$186>>2]|0;
          HEAP32[$186>>2] = $204;
          HEAP32[$192>>2] = $199;
          HEAP32[$184>>2] = $200;
          $206 = ($205|0)==(0|0);
          if (!($206)) {
           HEAP32[$1>>2] = 20;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
           invoke_vii(2591,($205|0),($$byval_copy9|0));
           $207 = __THREW__; __THREW__ = 0;
           $208 = $207&1;
           if (!($208)) {
            break;
           }
           $209 = ___cxa_find_matching_catch()|0;
           $210 = tempRet0;
           ___cxa_call_unexpected(($209|0));
           // unreachable;
          }
         }
        } while(0);
        $211 = (($this) + 80|0);
        __THREW__ = 0;
        invoke_vi(3645,($211|0));
        $212 = __THREW__; __THREW__ = 0;
        $213 = $212&1;
        if ($213) {
         label = 23;
         break;
        }
        __THREW__ = 0;
        invoke_vii(3337,($$byval_copy9|0),($this|0));
        $214 = __THREW__; __THREW__ = 0;
        $215 = $214&1;
        if ($215) {
         label = 23;
         break;
        }
        __THREW__ = 0;
        invoke_vii(3336,($211|0),($$byval_copy9|0));
        $216 = __THREW__; __THREW__ = 0;
        $217 = $216&1;
        if ($217) {
         $223 = ___cxa_find_matching_catch()|0;
         $224 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3642,($$byval_copy9|0));
         $225 = __THREW__; __THREW__ = 0;
         $226 = $225&1;
         if (!($226)) {
          $eh$lpad$body$index2Z2D = $224;$eh$lpad$body$indexZ2D = $223;
          label = 24;
          break;
         }
         $230 = ___cxa_find_matching_catch(0|0)|0;
         $231 = tempRet0;
         ___clang_call_terminate($230);
         // unreachable;
        }
        __THREW__ = 0;
        invoke_vi(3642,($$byval_copy9|0));
        $218 = __THREW__; __THREW__ = 0;
        $219 = $218&1;
        if ($219) {
         label = 23;
         break;
        }
        $220 = (($this) + 92|0);
        $221 = HEAP32[$220>>2]|0;
        $222 = ($221|0)==(0|0);
        do {
         if (!($222)) {
          $227 = HEAP32[$6>>2]|0;
          $228 = ($227|0)==(0|0);
          if ($228) {
           break;
          }
          $229 = (($227) + 44|0);
          HEAP32[$229>>2] = 0;
         }
        } while(0);
        $232 = HEAP8[$ext>>0]|0;
        $233 = $232 & 1;
        $234 = ($233<<24>>24)==(0);
        if ($234) {
         break L4;
        }
        $235 = (($ext) + 8|0);
        $236 = HEAP32[$235>>2]|0;
        __ZdlPv($236);
        break L4;
       }
       $141 = HEAP8[$ext>>0]|0;
       $142 = $141 & 1;
       $143 = ($142<<24>>24)==(0);
       if ($143) {
        $146 = (($ext) + 1|0);
        $147 = $146;
       } else {
        $144 = (($ext) + 8|0);
        $145 = HEAP32[$144>>2]|0;
        $147 = $145;
       }
       __THREW__ = 0;
       HEAP32[$$byval_copy9>>2] = $147;
       invoke_viii(1617,($5|0),(694360|0),($$byval_copy9|0));
       $148 = __THREW__; __THREW__ = 0;
       $149 = $148&1;
       if ($149) {
        label = 23;
       } else {
        $150 = ($this|0)==(0|0);
        if ($150) {
         $160 = 0;
        } else {
         $151 = (($this) + 4|0);
         $152 = HEAP32[$151>>2]|0;
         $160 = $152;
        }
        $153 = HEAP8[$5>>0]|0;
        $154 = $153 & 1;
        $155 = ($154<<24>>24)==(0);
        if ($155) {
         $158 = (($5) + 1|0);
         $159 = $158;
        } else {
         $156 = (($5) + 8|0);
         $157 = HEAP32[$156>>2]|0;
         $159 = $157;
        }
        __THREW__ = 0;
        invoke_viiiiiiii(21,($159|0),0,(693424|0),339,1,($160|0),0,(0|0));
        $161 = __THREW__; __THREW__ = 0;
        $162 = $161&1;
        if ($162) {
         $173 = ___cxa_find_matching_catch()|0;
         $174 = tempRet0;
         $175 = HEAP8[$5>>0]|0;
         $176 = $175 & 1;
         $177 = ($176<<24>>24)==(0);
         if ($177) {
          $$1 = $174;$$13 = $173;
          break;
         }
         $178 = (($5) + 8|0);
         $179 = HEAP32[$178>>2]|0;
         __ZdlPv($179);
         $$1 = $174;$$13 = $173;
         break;
        }
        $163 = HEAP8[$5>>0]|0;
        $164 = $163 & 1;
        $165 = ($164<<24>>24)==(0);
        if (!($165)) {
         $166 = (($5) + 8|0);
         $167 = HEAP32[$166>>2]|0;
         __ZdlPv($167);
        }
        $168 = HEAP8[$ext>>0]|0;
        $169 = $168 & 1;
        $170 = ($169<<24>>24)==(0);
        if ($170) {
         $$16 = 0;
         STACKTOP = sp;return ($$16|0);
        }
        $171 = (($ext) + 8|0);
        $172 = HEAP32[$171>>2]|0;
        __ZdlPv($172);
        $$16 = 0;
        STACKTOP = sp;return ($$16|0);
       }
      }
     } while(0);
     if ((label|0) == 23) {
      $75 = ___cxa_find_matching_catch()|0;
      $76 = tempRet0;
      $eh$lpad$body$index2Z2D = $76;$eh$lpad$body$indexZ2D = $75;
      label = 24;
     }
     if ((label|0) == 24) {
      $$1 = $eh$lpad$body$index2Z2D;$$13 = $eh$lpad$body$indexZ2D;
     }
     $237 = HEAP8[$ext>>0]|0;
     $238 = $237 & 1;
     $239 = ($238<<24>>24)==(0);
     if ($239) {
      $$2 = $$1;$$24 = $$13;
      ___resumeException($$24|0);
      // unreachable;
     }
     $240 = (($ext) + 8|0);
     $241 = HEAP32[$240>>2]|0;
     __ZdlPv($241);
     $$2 = $$1;$$24 = $$13;
     ___resumeException($$24|0);
     // unreachable;
    }
   } while(0);
   $70 = HEAP8[$3>>0]|0;
   $71 = $70 & 1;
   $72 = ($71<<24>>24)==(0);
   if ($72) {
    $$2 = $$01;$$24 = $$02;
    ___resumeException($$24|0);
    // unreachable;
   }
   $73 = (($3) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   __ZdlPv($74);
   $$2 = $$01;$$24 = $$02;
   ___resumeException($$24|0);
   // unreachable;
  }
 } while(0);
 $242 = HEAP32[$6>>2]|0;
 $243 = (($242) + 40|0);
 HEAP32[$243>>2] = $movie;
 $244 = ($movie|0)==(0|0);
 if ($244) {
  $$16 = 1;
  STACKTOP = sp;return ($$16|0);
 }
 $245 = HEAP32[$6>>2]|0;
 $246 = (($245) + 36|0);
 HEAP8[$246>>0] = 1;
 $247 = (($this) + 80|0);
 __ZN11SoundHandle7ReleaseEv($247);
 __ZN9AudioClip11CreateSoundEv($$byval_copy9,$this);
 __THREW__ = 0;
 invoke_vii(3336,($247|0),($$byval_copy9|0));
 $248 = __THREW__; __THREW__ = 0;
 $249 = $248&1;
 if ($249) {
  $253 = ___cxa_find_matching_catch()|0;
  $254 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3642,($$byval_copy9|0));
  $255 = __THREW__; __THREW__ = 0;
  $256 = $255&1;
  if ($256) {
   $260 = ___cxa_find_matching_catch(0|0)|0;
   $261 = tempRet0;
   ___clang_call_terminate($260);
   // unreachable;
  } else {
   ___resumeException($253|0);
   // unreachable;
  }
 }
 __ZN11SoundHandleD2Ev($$byval_copy9);
 $250 = (($this) + 92|0);
 $251 = HEAP32[$250>>2]|0;
 $252 = ($251|0)==(0|0);
 if ($252) {
  $$16 = 1;
  STACKTOP = sp;return ($$16|0);
 }
 $257 = HEAP32[$6>>2]|0;
 $258 = ($257|0)==(0|0);
 if ($258) {
  $$16 = 1;
  STACKTOP = sp;return ($$16|0);
 }
 $259 = (($257) + 44|0);
 HEAP32[$259>>2] = 0;
 $$16 = 1;
 STACKTOP = sp;return ($$16|0);
}
function __ZN9AudioClip22GetFormatFromExtensionERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($ext) {
 $ext = $ext|0;
 var $$ = 0, $$$$i$i$i41 = 0, $$$i$i$i40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ext_lower = 0, $not$ = 0, $not$43 = 0, $not$44 = 0, $not$45 = 0, $not$46 = 0, $not$47 = 0, $not$48 = 0, $type$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ext_lower = sp;
 __Z7ToLowerINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_($ext_lower,$ext);
 $0 = HEAP8[$ext_lower>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = $0&255;
  $8 = $7 >>> 1;
  $9 = (($ext_lower) + 1|0);
  $11 = $8;$13 = $9;
 } else {
  $3 = (($ext_lower) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($ext_lower) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $11 = $4;$13 = $6;
 }
 $10 = ($11>>>0)>(3);
 $12 = $10 ? 3 : $11;
 $14 = (_memcmp($13,694416,$12)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  $16 = $10 ^ 1;
  $not$48 = ($11>>>0)>(2);
  $17 = $not$48 & $16;
  if ($17) {
   $type$0 = 14;
  } else {
   label = 6;
  }
 } else {
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   if ($2) {
    $22 = $0&255;
    $23 = $22 >>> 1;
    $24 = (($ext_lower) + 1|0);
    $26 = $23;$28 = $24;
   } else {
    $18 = (($ext_lower) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($ext_lower) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $26 = $19;$28 = $21;
   }
   $25 = ($26>>>0)>(3);
   $27 = $25 ? 3 : $26;
   $29 = (_memcmp($28,694424,$27)|0);
   $30 = ($29|0)==(0);
   if ($30) {
    $31 = $25 ^ 1;
    $not$47 = ($26>>>0)>(2);
    $32 = $not$47 & $31;
    if ($32) {
     $type$0 = 13;
     break;
    }
   }
   if ($2) {
    $37 = $0&255;
    $38 = $37 >>> 1;
    $39 = (($ext_lower) + 1|0);
    $41 = $38;$43 = $39;
   } else {
    $33 = (($ext_lower) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($ext_lower) + 8|0);
    $36 = HEAP32[$35>>2]|0;
    $41 = $34;$43 = $36;
   }
   $40 = ($41>>>0)>(3);
   $42 = $40 ? 3 : $41;
   $44 = (_memcmp($43,694432,$42)|0);
   $45 = ($44|0)==(0);
   if ($45) {
    $46 = $40 ^ 1;
    $not$46 = ($41>>>0)>(2);
    $47 = $not$46 & $46;
    if ($47) {
     $type$0 = 13;
     break;
    }
   }
   if ($2) {
    $52 = $0&255;
    $53 = $52 >>> 1;
    $54 = (($ext_lower) + 1|0);
    $56 = $53;$58 = $54;
   } else {
    $48 = (($ext_lower) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($ext_lower) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $56 = $49;$58 = $51;
   }
   $55 = ($56>>>0)>(3);
   $57 = $55 ? 3 : $56;
   $59 = (_memcmp($58,694440,$57)|0);
   $60 = ($59|0)==(0);
   if ($60) {
    $61 = $55 ^ 1;
    $not$45 = ($56>>>0)>(2);
    $62 = $not$45 & $61;
    if ($62) {
     $type$0 = 20;
     break;
    }
   }
   if ($2) {
    $67 = $0&255;
    $68 = $67 >>> 1;
    $69 = (($ext_lower) + 1|0);
    $71 = $68;$73 = $69;
   } else {
    $63 = (($ext_lower) + 4|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($ext_lower) + 8|0);
    $66 = HEAP32[$65>>2]|0;
    $71 = $64;$73 = $66;
   }
   $70 = ($71>>>0)>(2);
   $72 = $70 ? 2 : $71;
   $74 = (_memcmp($73,694448,$72)|0);
   $75 = ($74|0)==(0);
   if ($75) {
    $76 = $70 ^ 1;
    $not$44 = ($71>>>0)>(1);
    $77 = $not$44 & $76;
    if ($77) {
     $type$0 = 10;
     break;
    }
   }
   if ($2) {
    $82 = $0&255;
    $83 = $82 >>> 1;
    $84 = (($ext_lower) + 1|0);
    $86 = $83;$88 = $84;
   } else {
    $78 = (($ext_lower) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($ext_lower) + 8|0);
    $81 = HEAP32[$80>>2]|0;
    $86 = $79;$88 = $81;
   }
   $85 = ($86>>>0)>(2);
   $87 = $85 ? 2 : $86;
   $89 = (_memcmp($88,694456,$87)|0);
   $90 = ($89|0)==(0);
   if ($90) {
    $91 = $85 ^ 1;
    $not$43 = ($86>>>0)>(1);
    $92 = $not$43 & $91;
    if ($92) {
     $type$0 = 21;
     break;
    }
   }
   if ($2) {
    $97 = $0&255;
    $98 = $97 >>> 1;
    $99 = (($ext_lower) + 1|0);
    $101 = $98;$103 = $99;
   } else {
    $93 = (($ext_lower) + 4|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($ext_lower) + 8|0);
    $96 = HEAP32[$95>>2]|0;
    $101 = $94;$103 = $96;
   }
   $100 = ($101>>>0)>(3);
   $102 = $100 ? 3 : $101;
   $104 = (_memcmp($103,694464,$102)|0);
   $105 = ($104|0)==(0);
   if ($105) {
    $106 = $100 ^ 1;
    $not$ = ($101>>>0)>(2);
    $107 = $not$ & $106;
    if ($107) {
     $type$0 = 17;
     break;
    }
   }
   if ($2) {
    $112 = $0&255;
    $113 = $112 >>> 1;
    $114 = (($ext_lower) + 1|0);
    $116 = $113;$118 = $114;
   } else {
    $108 = (($ext_lower) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($ext_lower) + 8|0);
    $111 = HEAP32[$110>>2]|0;
    $116 = $109;$118 = $111;
   }
   $115 = ($116>>>0)>(3);
   $117 = $115 ? 3 : $116;
   $119 = (_memcmp($118,694472,$117)|0);
   $120 = ($119|0)==(0);
   if ($120) {
    $121 = ($116>>>0)<(3);
    $$$i$i$i40 = $115&1;
    $$$$i$i$i41 = $121 ? -1 : $$$i$i$i40;
    $123 = $$$$i$i$i41;
   } else {
    $123 = $119;
   }
   $122 = ($123|0)==(0);
   $$ = $122 ? 12 : 0;
   $type$0 = $$;
  }
 } while(0);
 if ($2) {
  STACKTOP = sp;return ($type$0|0);
 }
 $124 = (($ext_lower) + 8|0);
 $125 = HEAP32[$124>>2]|0;
 __ZdlPv($125);
 STACKTOP = sp;return ($type$0|0);
}
function __ZN9AudioClip7CleanupEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 __ZN11SoundHandle7ReleaseEv($0);
 STACKTOP = sp;return;
}
function __ZN9AudioClip11CreateSoundEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, $exinfo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 148|0;
 $1 = sp;
 $exinfo = sp + 8|0;
 $2 = sp + 144|0;
 $3 = (($this) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   label = 21;
  } else {
   $6 = (($4) + 36|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    $48 = (($4) + 20|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = ($49<<24>>24)==(0);
    if ($50) {
     label = 21;
     break;
    }
    _memset(($exinfo|0),0,136)|0;
    HEAP32[$exinfo>>2] = 136;
    $51 = HEAP32[$4>>2]|0;
    $52 = (($exinfo) + 72|0);
    HEAP32[$52>>2] = $51;
    $53 = (($4) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($exinfo) + 20|0);
    HEAP32[$55>>2] = $54;
    $56 = (($this) + 28|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($exinfo) + 16|0);
    HEAP32[$58>>2] = $57;
    $59 = (($this) + 32|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($exinfo) + 12|0);
    HEAP32[$61>>2] = $60;
    $62 = (($4) + 24|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = $63 << 2;
    $65 = Math_imul($64, $60)|0;
    $66 = (($exinfo) + 4|0);
    HEAP32[$66>>2] = $65;
    $67 = (($exinfo) + 44|0);
    HEAP32[$67>>2] = 1576;
    $68 = (($exinfo) + 48|0);
    HEAP32[$68>>2] = 263;
    $69 = (($4) + 28|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = ($70<<24>>24)!=(0);
    $72 = $71 ? 1234 : 1362;
    $73 = (__Z15GetSoundManagerv()|0);
    $74 = HEAP32[$this>>2]|0;
    $75 = (($74) + 32|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = (FUNCTION_TABLE_ii[$76 & 4095]($this)|0);
    $78 = (($this) + 80|0);
    $79 = ($this|0)==(0|0);
    if ($79) {
     HEAP32[$2>>2] = 0;
    } else {
     $80 = (($this) + 4|0);
     $81 = HEAP32[$80>>2]|0;
     HEAP32[$2>>2] = $81;
    }
    $82 = (__ZN12SoundManager11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOR11SoundHandlej4PPtrI10SampleClipE($73,$77,$72,$exinfo,$78,0,$2)|0);
    (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($82,693640,776,694592)|0);
    break;
   }
   $9 = (($4) + 32|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $39 = (($4) + 40|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==(0|0);
    if ($41) {
     break;
    }
    $42 = (__Z15GetSoundManagerv()|0);
    $43 = (__Z15GetAudioManagerv()|0);
    $44 = (__ZN12AudioManager24CreateFMODSoundFromMovieEP9AudioClip($43,$this)|0);
    $45 = ($this|0)==(0|0);
    if ($45) {
     HEAP32[$1>>2] = 0;
    } else {
     $46 = (($this) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$1>>2] = $47;
    }
    __ZN12SoundManager22GetHandleFromFMODSoundEPN4FMOD5SoundEj4PPtrI10SampleClipE($agg$result,$42,$44,0,$1);
    STACKTOP = sp;return;
   }
   $12 = (($4) + 76|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $15 = HEAP32[$10>>2]|0;
    $16 = (($15) + 32|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (Math_fround(FUNCTION_TABLE_fi[$17 & 255]($10)));
    $19 = $18 != Math_fround(1.0);
    if ($19) {
     __ZN11SoundHandleC2Ev($agg$result);
     STACKTOP = sp;return;
    }
   }
   $20 = (__Z15GetSoundManagerv()|0);
   $21 = (__Z15GetAudioManagerv()|0);
   $22 = HEAP32[$3>>2]|0;
   $23 = (($22) + 32|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$22>>2]|0;
   $26 = (($22) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($this) + 28|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($this) + 32|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($22) + 76|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = ($33<<24>>24)!=(0);
   $35 = (__ZN12AudioManager22CreateFMODSoundFromWWWEP3WWW15FMOD_SOUND_TYPE17FMOD_SOUND_FORMATjjbPv($21,$24,$25,$27,$29,$31,$34,$this)|0);
   $36 = ($this|0)==(0|0);
   if ($36) {
    HEAP32[$0>>2] = 0;
   } else {
    $37 = (($this) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$0>>2] = $38;
   }
   __ZN12SoundManager22GetHandleFromFMODSoundEPN4FMOD5SoundEj4PPtrI10SampleClipE($agg$result,$20,$35,0,$0);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 21) {
  __ZN10SampleClip13LoadBaseSoundEv($this);
 }
 $83 = (($this) + 80|0);
 __ZN11SoundHandleC2ERKS_($agg$result,$83);
 STACKTOP = sp;return;
}
function __ZN9AudioClip17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 __ZN11SoundHandle7ReleaseEv($0);
 $1 = (($this) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = (($5) + 16|0);
   HEAP32[$7>>2] = 0;
   $8 = HEAP32[$1>>2]|0;
   $9 = (($8) + 32|0);
   $10 = HEAP32[$9>>2]|0;
   __ZN3WWW7ReleaseEv($10);
  }
 }
 $11 = (($this) + 108|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 112|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($12) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = HEAP32[$11>>2]|0;
 $18 = HEAP32[$14>>2]|0;
 HEAP32[$18>>2] = $17;
 HEAP32[$11>>2] = 0;
 HEAP32[$14>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9AudioClip27IsFormatSupportedByPlatformERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($ext) {
 $ext = $ext|0;
 var $$0 = 0, $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9AudioClip22GetFormatFromExtensionERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($ext)|0);
 if ((($0|0) == 13) | (($0|0) == 0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9AudioClip12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9AudioClip18GetQueuedAudioDataEPPvj($this,$buf,$size) {
 $this = $this|0;
 $buf = $buf|0;
 $size = $size|0;
 var $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   HEAP32[$vararg_buffer>>2] = 694528;
   __Z6FormatPKcz($0,694480,$vararg_buffer);
   $4 = (($this) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = HEAP8[$0>>0]|0;
   $7 = $6 & 1;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    $11 = (($0) + 1|0);
    $12 = $11;
   } else {
    $9 = (($0) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $12 = $10;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($12|0),0,(693424|0),621,1,($5|0),0,(0|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP8[$0>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     break;
    }
    $18 = (($0) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($19);
    break;
   }
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   $22 = HEAP8[$0>>0]|0;
   $23 = $22 & 1;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    ___resumeException($20|0);
    // unreachable;
   }
   $25 = (($0) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   __ZdlPv($26);
   ___resumeException($20|0);
   // unreachable;
  }
 } while(0);
 $27 = HEAP32[$1>>2]|0;
 $28 = (($27) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $29;
 $33 = $31;
 $34 = (($32) - ($33))|0;
 $35 = ($34>>>0)<($size>>>0);
 if ($35) {
  $$02 = 0;
  STACKTOP = sp;return ($$02|0);
 }
 $36 = HEAP32[$buf>>2]|0;
 _memcpy(($36|0),($31|0),($size|0))|0;
 $37 = HEAP32[$1>>2]|0;
 $38 = (($37) + 8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($size|0)==(0);
 if ($40) {
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
 }
 $41 = (($39) + ($size)|0);
 $42 = (($37) + 12|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43;
 $45 = $41;
 $46 = (($44) - ($45))|0;
 _memmove(($39|0),($41|0),($46|0))|0;
 $47 = (($39) + ($46)|0);
 $48 = HEAP32[$42>>2]|0;
 $49 = ($48|0)==($47|0);
 if ($49) {
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
 }
 HEAP32[$42>>2] = $47;
 $$02 = 1;
 STACKTOP = sp;return ($$02|0);
}
function __ZNK9AudioClip8GetMovieEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = 0;
 } else {
  $3 = (($1) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4;
 }
 STACKTOP = sp;return ($5|0);
}
function __ZN9AudioClip6ReloadEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 112|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (__Z20GetPersistentManagerv()|0);
 (__ZN17PersistentManager14ReloadFromDiskER6Object($8,$this)|0);
 STACKTOP = sp;return;
}
function __ZN9AudioClip21AwakeFromLoadThreadedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN9AudioClip13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 80|0);
 __ZN11SoundHandle7ReleaseEv($1);
 __ZN9AudioClip11CreateSoundEv($0,$this);
 __THREW__ = 0;
 invoke_vii(3336,($1|0),($0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3642,($0|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $15 = ___cxa_find_matching_catch(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   ___resumeException($7|0);
   // unreachable;
  }
 }
 __ZN11SoundHandleD2Ev($0);
 $4 = (($this) + 92|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 128|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($12) + 44|0);
 HEAP32[$14>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9AudioClip20AllocatePreviewSoundEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 128|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $12 = (__Z15GetSoundManagerv()|0);
  $13 = (($this) + 48|0);
  $14 = (($this) + 96|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$0>>2] = $17;
  __ZN12SoundManager9GetHandleERK16StreamedResourceijj4PPtrI10SampleClipEb($agg$result,$12,$13,$15,202,0,$0,1);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 80|0);
 __ZN9AudioClip11CreateSoundEv($1,$this);
 __THREW__ = 0;
 invoke_vii(3336,($5|0),($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  __ZN11SoundHandleD2Ev($1);
  __ZN11SoundHandleC2ERKS_($agg$result,$5);
  STACKTOP = sp;return;
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3642,($1|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $18 = ___cxa_find_matching_catch(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($8|0);
  // unreachable;
 }
}
function __Z23RegisterClass_AudioClipv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(83,212,213,0,214);
 STACKTOP = sp;return;
}
function __ZN9AudioClip13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (__ZN6Object13ClassIDToRTTIEi(271)|0);
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $4 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
   $5 = ($4|0)==(0|0);
   if ($5) {
    __ZN11NamedObject13RegisterClassEv();
   }
   HEAP8[$0>>0] = 20;
   $6 = (($0) + 1|0);
   dest=$6+0|0; src=694032+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $7 = (($0) + 11|0);
   HEAP8[$7>>0] = 0;
   __THREW__ = 0;
   invoke_viiiiiii(63,271,130,($0|0),128,(2560|0),0,0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP8[$0>>0]|0;
    $11 = $10 & 1;
    $12 = ($11<<24>>24)==(0);
    if ($12) {
     break;
    }
    $13 = (($0) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    __ZdlPv($14);
    break;
   }
   $15 = ___cxa_find_matching_catch()|0;
   $16 = tempRet0;
   $17 = HEAP8[$0>>0]|0;
   $18 = $17 & 1;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    ___resumeException($15|0);
    // unreachable;
   }
   $20 = (($0) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   __ZdlPv($21);
   ___resumeException($15|0);
   // unreachable;
  }
 } while(0);
 HEAP8[$1>>0] = 18;
 $22 = (($1) + 1|0);
 dest=$22+0|0; src=694672+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $23 = (($1) + 10|0);
 HEAP8[$23>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,83,271,($1|0),136,(2561|0),0,0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $33 = HEAP8[$1>>0]|0;
  $34 = $33 & 1;
  $35 = ($34<<24>>24)==(0);
  if ($35) {
   ___resumeException($31|0);
   // unreachable;
  }
  $36 = (($1) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  __ZdlPv($37);
  ___resumeException($31|0);
  // unreachable;
 } else {
  $26 = HEAP8[$1>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   STACKTOP = sp;return;
  }
  $29 = (($1) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  __ZdlPv($30);
  STACKTOP = sp;return;
 }
}
function __ZN9AudioClip7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy2,1,16,693424,156)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1983,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(693424|0),156);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK9AudioClip25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 83;
}
function __ZN9AudioClip23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694048,694672,$this,0);
 __ZN9AudioClip8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9AudioClip23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,694048,694672,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9AudioClip8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9AudioClip23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9AudioClip8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9AudioClip23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9AudioClip8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9AudioClip23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9AudioClip8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9AudioClip23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN10SampleClipD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10SampleClipD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN10SampleClipD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3646,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9AudioClipD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((694056 + 8|0));
 $1 = (($this) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN10SampleClipD2Ev($this);
  STACKTOP = sp;return;
 }
 $4 = (($2) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($2) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  if (!($9)) {
   HEAP32[$7>>2] = $5;
  }
  HEAP32[$0>>2] = 20;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($5|0),($$byval_copy|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   ___cxa_call_unexpected(($12|0));
   // unreachable;
  }
 }
 __ZdlPv($2);
 __ZN10SampleClipD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN9AudioClipD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((694056 + 8|0));
 $1 = (($this) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = (($2) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==($5|0);
   if (!($9)) {
    HEAP32[$7>>2] = $5;
   }
   HEAP32[$0>>2] = 20;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($5|0),($$byval_copy|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    $12 = ___cxa_find_matching_catch()|0;
    $13 = tempRet0;
    ___cxa_call_unexpected(($12|0));
    // unreachable;
   }
  }
  __ZdlPv($2);
 }
 __THREW__ = 0;
 invoke_vi(3646,($this|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZdlPv($this);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9AudioClip8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre10;
 }
 $8 = (($this) + 76|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = HEAP32[$8>>2]|0;
  HEAP32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $16 = $$pre11;$18 = $$pre12;
 }
 $14 = (($this) + 32|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = HEAP32[$14>>2]|0;
  HEAP32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $22 = $$pre13;$24 = $$pre14;
 }
 $20 = (($this) + 28|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = HEAP32[$20>>2]|0;
  HEAP32[$22>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $28 = $$pre15;$30 = $$pre16;
 }
 $26 = (($this) + 36|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)<($30>>>0);
 if ($29) {
  $31 = HEAP32[$26>>2]|0;
  HEAP32[$28>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,4);
  $$pre17 = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $34 = $$pre17;$36 = $$pre18;
 }
 $32 = (($this) + 44|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)<($36>>>0);
 if ($35) {
  $37 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$34>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$32,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $40 = $$pre19;$42 = $$pre20;
 }
 $38 = (($this) + 40|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)<($42>>>0);
 if ($41) {
  $43 = HEAP32[$38>>2]|0;
  HEAP32[$40>>2] = $43;
  HEAP32[$1>>2] = $39;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$38,4);
 }
 $44 = (($this) + 48|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$44,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $45 = (($this) + 64|0);
 $46 = HEAP32[$1>>2]|0;
 $47 = (($46) + 8|0);
 $48 = HEAP32[$4>>2]|0;
 $49 = ($47>>>0)<($48>>>0);
 if ($49) {
  $50 = $45;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = (($50) + 4)|0;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = $46;
  $57 = $56;
  HEAP32[$57>>2] = $52;
  $58 = (($56) + 4)|0;
  $59 = $58;
  HEAP32[$59>>2] = $55;
  HEAP32[$1>>2] = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$45,8);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $60 = (($this) + 96|0);
 $61 = HEAP32[$1>>2]|0;
 $62 = (($61) + 4|0);
 $63 = HEAP32[$4>>2]|0;
 $64 = ($62>>>0)<($63>>>0);
 if ($64) {
  $65 = HEAP32[$60>>2]|0;
  HEAP32[$61>>2] = $65;
  HEAP32[$1>>2] = $62;
  $68 = $62;$70 = $63;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$60,4);
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $68 = $$pre21;$70 = $$pre22;
 }
 $66 = (($this) + 100|0);
 $67 = (($68) + 1|0);
 $69 = ($67>>>0)<($70>>>0);
 if ($69) {
  $71 = HEAP8[$66>>0]|0;
  HEAP8[$68>>0] = $71;
  $72 = HEAP32[$1>>2]|0;
  $73 = (($72) + 1|0);
  HEAP32[$1>>2] = $73;
  $76 = $73;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$66,1);
  $$pre23 = HEAP32[$1>>2]|0;
  $76 = $$pre23;
 }
 $74 = (($this) + 101|0);
 $75 = (($76) + 1|0);
 $77 = HEAP32[$4>>2]|0;
 $78 = ($75>>>0)<($77>>>0);
 if ($78) {
  $79 = HEAP8[$74>>0]|0;
  HEAP8[$76>>0] = $79;
  $80 = HEAP32[$1>>2]|0;
  $81 = (($80) + 1|0);
  HEAP32[$1>>2] = $81;
  $84 = $81;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$74,1);
  $$pre24 = HEAP32[$1>>2]|0;
  $84 = $$pre24;
 }
 $82 = (($this) + 102|0);
 $83 = (($84) + 1|0);
 $85 = HEAP32[$4>>2]|0;
 $86 = ($83>>>0)<($85>>>0);
 if ($86) {
  $87 = HEAP8[$82>>0]|0;
  HEAP8[$84>>0] = $87;
  $88 = HEAP32[$1>>2]|0;
  $89 = (($88) + 1|0);
  HEAP32[$1>>2] = $89;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$82,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $90 = (($this) + 104|0);
 $91 = HEAP32[$1>>2]|0;
 $92 = (($91) + 4|0);
 $93 = HEAP32[$4>>2]|0;
 $94 = ($92>>>0)<($93>>>0);
 if ($94) {
  $95 = HEAP32[$90>>2]|0;
  HEAP32[$91>>2] = $95;
  HEAP32[$1>>2] = $92;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$90,4);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9AudioClip8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i12 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre$i$i$i7 = 0, $$pre$i$i$i9 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i$i$i$iZ2D = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0;
 var $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre3$i$i$i$i$i$i = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre5$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $12 = $$pre;$14 = $$pre18;$8 = $$pre$i$i$i;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $12 = $3;$14 = $5;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 76|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$10,4);
  $$pre$i$i$i1 = HEAP32[$10>>2]|0;
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $16 = $$pre$i$i$i1;$20 = $$pre19;$22 = $$pre20;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$1>>2] = $11;
  $16 = $15;$20 = $11;$22 = $14;
 }
 $17 = (_llvm_bswap_i32(($16|0))|0);
 HEAP32[$10>>2] = $17;
 $18 = (($this) + 32|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)>($22>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$18,4);
  $$pre$i$i$i3 = HEAP32[$18>>2]|0;
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $24 = $$pre$i$i$i3;$28 = $$pre21;$30 = $$pre22;
 } else {
  $23 = HEAP32[$20>>2]|0;
  HEAP32[$18>>2] = $23;
  HEAP32[$1>>2] = $19;
  $24 = $23;$28 = $19;$30 = $22;
 }
 $25 = (_llvm_bswap_i32(($24|0))|0);
 HEAP32[$18>>2] = $25;
 $26 = (($this) + 28|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre$i$i$i5 = HEAP32[$26>>2]|0;
  $$pre23 = HEAP32[$1>>2]|0;
  $$pre24 = HEAP32[$4>>2]|0;
  $32 = $$pre$i$i$i5;$36 = $$pre23;$38 = $$pre24;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $32 = $31;$36 = $27;$38 = $30;
 }
 $33 = (_llvm_bswap_i32(($32|0))|0);
 HEAP32[$26>>2] = $33;
 $34 = (($this) + 36|0);
 $35 = (($36) + 4|0);
 $37 = ($35>>>0)>($38>>>0);
 if ($37) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$34,4);
  $$pre$i$i$i7 = HEAP32[$34>>2]|0;
  $$pre25 = HEAP32[$1>>2]|0;
  $$pre26 = HEAP32[$4>>2]|0;
  $40 = $$pre$i$i$i7;$44 = $$pre25;$46 = $$pre26;
 } else {
  $39 = HEAP32[$36>>2]|0;
  HEAP32[$34>>2] = $39;
  HEAP32[$1>>2] = $35;
  $40 = $39;$44 = $35;$46 = $38;
 }
 $41 = (_llvm_bswap_i32(($40|0))|0);
 HEAP32[$34>>2] = $41;
 $42 = (($this) + 44|0);
 $43 = (($44) + 4|0);
 $45 = ($43>>>0)>($46>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$42,4);
  $$pre$i$i$i9 = HEAP32[$42>>2]|0;
  $$pre27 = HEAP32[$1>>2]|0;
  $$pre28 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $42;$49 = $$pre$i$i$i9;$53 = $$pre27;$55 = $$pre28;
 } else {
  $47 = Math_fround(HEAPF32[$44>>2]);
  HEAPF32[$42>>2] = $47;
  HEAP32[$1>>2] = $43;
  $48 = (HEAPF32[tempDoublePtr>>2]=$47,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $42;$49 = $48;$53 = $43;$55 = $46;
 }
 $50 = (_llvm_bswap_i32(($49|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $50;
 $51 = (($this) + 40|0);
 $52 = (($53) + 4|0);
 $54 = ($52>>>0)>($55>>>0);
 if ($54) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$51,4);
  $$pre$i$i$i10 = HEAP32[$51>>2]|0;
  $57 = $$pre$i$i$i10;
 } else {
  $56 = HEAP32[$53>>2]|0;
  HEAP32[$51>>2] = $56;
  HEAP32[$1>>2] = $52;
  $57 = $56;
 }
 $58 = (_llvm_bswap_i32(($57|0))|0);
 HEAP32[$51>>2] = $58;
 $59 = (($this) + 48|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$59,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $60 = (($this) + 64|0);
 $61 = HEAP32[$1>>2]|0;
 $62 = (($61) + 8|0);
 $63 = HEAP32[$4>>2]|0;
 $64 = ($62>>>0)>($63>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$60,8);
  $$pre$i$i$i$i$i$i = HEAP32[$60>>2]|0;
  $$phi$trans$insert2$i$i$i$i$i$i = (($this) + 68|0);
  $$pre3$i$i$i$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i$i$i$i>>2]|0;
  $$pre$phi$i$i$i$i$i$iZ2D = $60;$$pre$phi6$i$i$i$i$i$iZ2D = $$phi$trans$insert2$i$i$i$i$i$i;$75 = $$pre$i$i$i$i$i$i;$77 = $$pre3$i$i$i$i$i$i;
 } else {
  $65 = $61;
  $66 = $65;
  $67 = HEAP32[$66>>2]|0;
  $68 = (($65) + 4)|0;
  $69 = $68;
  $70 = HEAP32[$69>>2]|0;
  $71 = $60;
  $72 = $71;
  HEAP32[$72>>2] = $67;
  $73 = (($71) + 4)|0;
  $74 = $73;
  HEAP32[$74>>2] = $70;
  HEAP32[$1>>2] = $62;
  $$pre5$i$i$i$i$i$i = (($this) + 68|0);
  $$pre$phi$i$i$i$i$i$iZ2D = $60;$$pre$phi6$i$i$i$i$i$iZ2D = $$pre5$i$i$i$i$i$i;$75 = $67;$77 = $70;
 }
 $76 = (_llvm_bswap_i32(($75|0))|0);
 $78 = (_llvm_bswap_i32(($77|0))|0);
 HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $78;
 HEAP32[$$pre$phi6$i$i$i$i$i$iZ2D>>2] = $76;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $79 = (($this) + 96|0);
 $80 = HEAP32[$1>>2]|0;
 $81 = (($80) + 4|0);
 $82 = HEAP32[$4>>2]|0;
 $83 = ($81>>>0)>($82>>>0);
 if ($83) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$79,4);
  $$pre$i$i$i12 = HEAP32[$79>>2]|0;
  $$pre29 = HEAP32[$1>>2]|0;
  $$pre30 = HEAP32[$4>>2]|0;
  $85 = $$pre$i$i$i12;$89 = $$pre29;$91 = $$pre30;
 } else {
  $84 = HEAP32[$80>>2]|0;
  HEAP32[$79>>2] = $84;
  HEAP32[$1>>2] = $81;
  $85 = $84;$89 = $81;$91 = $82;
 }
 $86 = (_llvm_bswap_i32(($85|0))|0);
 HEAP32[$79>>2] = $86;
 $87 = (($this) + 100|0);
 $88 = (($89) + 1|0);
 $90 = ($88>>>0)>($91>>>0);
 if ($90) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$87,1);
  $$pre31 = HEAP32[$1>>2]|0;
  $97 = $$pre31;
 } else {
  $92 = HEAP8[$89>>0]|0;
  HEAP8[$87>>0] = $92;
  $93 = HEAP32[$1>>2]|0;
  $94 = (($93) + 1|0);
  HEAP32[$1>>2] = $94;
  $97 = $94;
 }
 $95 = (($this) + 101|0);
 $96 = (($97) + 1|0);
 $98 = HEAP32[$4>>2]|0;
 $99 = ($96>>>0)>($98>>>0);
 if ($99) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$95,1);
  $$pre32 = HEAP32[$1>>2]|0;
  $105 = $$pre32;
 } else {
  $100 = HEAP8[$97>>0]|0;
  HEAP8[$95>>0] = $100;
  $101 = HEAP32[$1>>2]|0;
  $102 = (($101) + 1|0);
  HEAP32[$1>>2] = $102;
  $105 = $102;
 }
 $103 = (($this) + 102|0);
 $104 = (($105) + 1|0);
 $106 = HEAP32[$4>>2]|0;
 $107 = ($104>>>0)>($106>>>0);
 if ($107) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$103,1);
 } else {
  $108 = HEAP8[$105>>0]|0;
  HEAP8[$103>>0] = $108;
  $109 = HEAP32[$1>>2]|0;
  $110 = (($109) + 1|0);
  HEAP32[$1>>2] = $110;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $111 = (($this) + 104|0);
 $112 = HEAP32[$1>>2]|0;
 $113 = (($112) + 4|0);
 $114 = HEAP32[$4>>2]|0;
 $115 = ($113>>>0)>($114>>>0);
 if ($115) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$111,4);
  $$pre$i$i$i16 = HEAP32[$111>>2]|0;
  $117 = $$pre$i$i$i16;
  $118 = (_llvm_bswap_i32(($117|0))|0);
  HEAP32[$111>>2] = $118;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $116 = HEAP32[$112>>2]|0;
  HEAP32[$111>>2] = $116;
  HEAP32[$1>>2] = $113;
  $117 = $116;
  $118 = (_llvm_bswap_i32(($117|0))|0);
  HEAP32[$111>>2] = $118;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9AudioClip8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre10;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 76|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre11 = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $16 = $$pre11;$18 = $$pre12;
 } else {
  $13 = HEAP32[$10>>2]|0;
  HEAP32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 32|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $22 = $$pre13;$24 = $$pre14;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 }
 $20 = (($this) + 28|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $28 = $$pre15;$30 = $$pre16;
 } else {
  $25 = HEAP32[$22>>2]|0;
  HEAP32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 }
 $26 = (($this) + 36|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre17 = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $34 = $$pre17;$36 = $$pre18;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 }
 $32 = (($this) + 44|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$32,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $40 = $$pre19;$42 = $$pre20;
 } else {
  $37 = Math_fround(HEAPF32[$34>>2]);
  HEAPF32[$32>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 }
 $38 = (($this) + 40|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)>($42>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
 } else {
  $43 = HEAP32[$40>>2]|0;
  HEAP32[$38>>2] = $43;
  HEAP32[$1>>2] = $39;
 }
 $44 = (($this) + 48|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$44,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $45 = (($this) + 64|0);
 $46 = HEAP32[$1>>2]|0;
 $47 = (($46) + 8|0);
 $48 = HEAP32[$4>>2]|0;
 $49 = ($47>>>0)>($48>>>0);
 if ($49) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$45,8);
 } else {
  $50 = $46;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = (($50) + 4)|0;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = $45;
  $57 = $56;
  HEAP32[$57>>2] = $52;
  $58 = (($56) + 4)|0;
  $59 = $58;
  HEAP32[$59>>2] = $55;
  HEAP32[$1>>2] = $47;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $60 = (($this) + 96|0);
 $61 = HEAP32[$1>>2]|0;
 $62 = (($61) + 4|0);
 $63 = HEAP32[$4>>2]|0;
 $64 = ($62>>>0)>($63>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$60,4);
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $68 = $$pre21;$70 = $$pre22;
 } else {
  $65 = HEAP32[$61>>2]|0;
  HEAP32[$60>>2] = $65;
  HEAP32[$1>>2] = $62;
  $68 = $62;$70 = $63;
 }
 $66 = (($this) + 100|0);
 $67 = (($68) + 1|0);
 $69 = ($67>>>0)>($70>>>0);
 if ($69) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$66,1);
  $$pre23 = HEAP32[$1>>2]|0;
  $76 = $$pre23;
 } else {
  $71 = HEAP8[$68>>0]|0;
  HEAP8[$66>>0] = $71;
  $72 = HEAP32[$1>>2]|0;
  $73 = (($72) + 1|0);
  HEAP32[$1>>2] = $73;
  $76 = $73;
 }
 $74 = (($this) + 101|0);
 $75 = (($76) + 1|0);
 $77 = HEAP32[$4>>2]|0;
 $78 = ($75>>>0)>($77>>>0);
 if ($78) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$74,1);
  $$pre24 = HEAP32[$1>>2]|0;
  $84 = $$pre24;
 } else {
  $79 = HEAP8[$76>>0]|0;
  HEAP8[$74>>0] = $79;
  $80 = HEAP32[$1>>2]|0;
  $81 = (($80) + 1|0);
  HEAP32[$1>>2] = $81;
  $84 = $81;
 }
 $82 = (($this) + 102|0);
 $83 = (($84) + 1|0);
 $85 = HEAP32[$4>>2]|0;
 $86 = ($83>>>0)>($85>>>0);
 if ($86) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$82,1);
 } else {
  $87 = HEAP8[$84>>0]|0;
  HEAP8[$82>>0] = $87;
  $88 = HEAP32[$1>>2]|0;
  $89 = (($88) + 1|0);
  HEAP32[$1>>2] = $89;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $90 = (($this) + 104|0);
 $91 = HEAP32[$1>>2]|0;
 $92 = (($91) + 4|0);
 $93 = HEAP32[$4>>2]|0;
 $94 = ($92>>>0)>($93>>>0);
 if ($94) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$90,4);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $95 = HEAP32[$91>>2]|0;
  HEAP32[$90>>2] = $95;
  HEAP32[$1>>2] = $92;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN9AudioClip8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i3 = 0, $$sum$i$i$i$i$i8 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i4 = 0, $$sum1$i$i$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $converter$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i7 = sp;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$0,694688,0);
 $1 = (($this) + 76|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$1,694704,0);
 $2 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$2,694720,0);
 $3 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$3,694736,0);
 $4 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$4,694752,0);
 $5 = (($this) + 44|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,694768,0);
 $6 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$6,694784,0);
 $7 = (($this) + 48|0);
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,694808,694960,$converter$i$i7,1)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($8|0)>(0);
  if ($10) {
   __ZN16StreamedResource8TransferI14SafeBinaryReadEEvRT_($7,$transfer);
  } else {
   $11 = HEAP32[$converter$i$i7>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    (FUNCTION_TABLE_iii[$11 & 4095]($7,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $13 = (($this) + 96|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$13,694824,0);
 $14 = (($this) + 100|0);
 $15 = HEAP32[580544>>2]|0;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,694840,$15,$converter$i$i7,0)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  do {
   if ($18) {
    $19 = (($transfer) + 12|0);
    $20 = (($transfer) + 80|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($transfer) + 16|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($transfer) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($transfer) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = Math_imul($29, $27)|0;
    $$sum$i$i$i$i$i = (($23) - ($30))|0;
    $31 = (($25) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$19>>2] = $31;
    $32 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($32)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $33 = (($25) + ($$sum1$i$i$i$i$i)|0);
     $34 = (($transfer) + 20|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($33>>>0)>($35>>>0);
     if (!($36)) {
      $37 = HEAP8[$31>>0]|0;
      HEAP8[$14>>0] = $37;
      $38 = HEAP32[$19>>2]|0;
      $39 = (($38) + 1|0);
      HEAP32[$19>>2] = $39;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($19,$14,1);
   } else {
    $40 = HEAP32[$converter$i$i7>>2]|0;
    $41 = ($40|0)==(0|0);
    if (!($41)) {
     (FUNCTION_TABLE_iii[$40 & 4095]($14,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $42 = (($this) + 101|0);
 $43 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,694864,$15,$converter$i$i7,0)|0);
 $44 = ($43|0)==(0);
 if (!($44)) {
  $45 = ($43|0)>(0);
  do {
   if ($45) {
    $46 = (($transfer) + 12|0);
    $47 = (($transfer) + 80|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($transfer) + 16|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($transfer) + 28|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($transfer) + 32|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = Math_imul($56, $54)|0;
    $$sum$i$i$i$i$i3 = (($50) - ($57))|0;
    $58 = (($52) + ($$sum$i$i$i$i$i3)|0);
    HEAP32[$46>>2] = $58;
    $59 = ($$sum$i$i$i$i$i3|0)<(0);
    if (!($59)) {
     $$sum1$i$i$i$i$i4 = (($$sum$i$i$i$i$i3) + 1)|0;
     $60 = (($52) + ($$sum1$i$i$i$i$i4)|0);
     $61 = (($transfer) + 20|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($60>>>0)>($62>>>0);
     if (!($63)) {
      $64 = HEAP8[$58>>0]|0;
      HEAP8[$42>>0] = $64;
      $65 = HEAP32[$46>>2]|0;
      $66 = (($65) + 1|0);
      HEAP32[$46>>2] = $66;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($46,$42,1);
   } else {
    $67 = HEAP32[$converter$i$i7>>2]|0;
    $68 = ($67|0)==(0|0);
    if (!($68)) {
     (FUNCTION_TABLE_iii[$67 & 4095]($42,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $69 = (($this) + 102|0);
 $70 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,694888,$15,$converter$i$i7,0)|0);
 $71 = ($70|0)==(0);
 if ($71) {
  $96 = (($this) + 104|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$96,694904,0);
  STACKTOP = sp;return;
 }
 $72 = ($70|0)>(0);
 do {
  if ($72) {
   $73 = (($transfer) + 12|0);
   $74 = (($transfer) + 80|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($75) + 12|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = (($transfer) + 16|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($transfer) + 28|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($transfer) + 32|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = Math_imul($83, $81)|0;
   $$sum$i$i$i$i$i8 = (($77) - ($84))|0;
   $85 = (($79) + ($$sum$i$i$i$i$i8)|0);
   HEAP32[$73>>2] = $85;
   $86 = ($$sum$i$i$i$i$i8|0)<(0);
   if (!($86)) {
    $$sum1$i$i$i$i$i9 = (($$sum$i$i$i$i$i8) + 1)|0;
    $87 = (($79) + ($$sum1$i$i$i$i$i9)|0);
    $88 = (($transfer) + 20|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ($87>>>0)>($89>>>0);
    if (!($90)) {
     $91 = HEAP8[$85>>0]|0;
     HEAP8[$69>>0] = $91;
     $92 = HEAP32[$73>>2]|0;
     $93 = (($92) + 1|0);
     HEAP32[$73>>2] = $93;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($73,$69,1);
  } else {
   $94 = HEAP32[$converter$i$i7>>2]|0;
   $95 = ($94|0)==(0|0);
   if (!($95)) {
    (FUNCTION_TABLE_iii[$94 & 4095]($69,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $96 = (($this) + 104|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$96,694904,0);
 STACKTOP = sp;return;
}
function __ZN16StreamedResource8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580712>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,694920,$0,$converter$i$i1,0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 16|0);
 $7 = HEAP32[580736>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,694936,$7,$converter$i$i1,0)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  $11 = (($transfer) + 12|0);
  $12 = (($transfer) + 80|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($transfer) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($transfer) + 28|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($transfer) + 32|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = Math_imul($21, $19)|0;
  $$sum$i$i$i = (($15) - ($22))|0;
  $23 = (($17) + ($$sum$i$i$i)|0);
  HEAP32[$11>>2] = $23;
  $24 = ($$sum$i$i$i|0)<(0);
  if ($24) {
   label = 12;
  } else {
   $$sum1$i$i$i = (($$sum$i$i$i) + 8)|0;
   $25 = (($17) + ($$sum1$i$i$i)|0);
   $26 = (($transfer) + 20|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($25>>>0)>($27>>>0);
   if ($28) {
    label = 12;
   } else {
    $29 = $23;
    $30 = $29;
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + 4)|0;
    $33 = $32;
    $34 = HEAP32[$33>>2]|0;
    $35 = $6;
    $36 = $35;
    HEAP32[$36>>2] = $31;
    $37 = (($35) + 4)|0;
    $38 = $37;
    HEAP32[$38>>2] = $34;
    HEAP32[$11>>2] = $25;
   }
  }
  if ((label|0) == 12) {
   __ZN12CachedReader15UpdateReadCacheEPvj($11,$6,8);
  }
  $39 = HEAP32[$transfer>>2]|0;
  $40 = $39 & 512;
  $41 = ($40|0)==(0);
  if (!($41)) {
   $42 = HEAP32[$6>>2]|0;
   $43 = (_llvm_bswap_i32(($42|0))|0);
   $44 = (($6) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (_llvm_bswap_i32(($45|0))|0);
   HEAP32[$6>>2] = $46;
   HEAP32[$44>>2] = $43;
  }
 } else {
  $47 = HEAP32[$converter$i$i1>>2]|0;
  $48 = ($47|0)==(0|0);
  if (!($48)) {
   (FUNCTION_TABLE_iii[$47 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9AudioClip8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0;
 var $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 4|0;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 $1 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694688,$1,$0,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 76|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694704,$1,$8,0);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694720,$1,$13,0);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694736,$1,$18,0);
 $19 = HEAP32[$2>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694752,$1,$23,0);
 $24 = HEAP32[$2>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$5>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 44|0);
 $29 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694768,$29,$28,0);
 $30 = HEAP32[$2>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$5>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $34 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694784,$1,$34,0);
 $35 = HEAP32[$2>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$5>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $39 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694808,694960,$39,0);
 $40 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694920,$40,$39,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,694984,694984,$size$i$i$i$i,1);
 $41 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694952,$41,$p$i$i$i,0);
 $42 = HEAP32[$2>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$5>>2]|0;
 $45 = ((($43) + (($44*24)|0)|0) + 12|0);
 HEAP32[$45>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $46 = (($this) + 64|0);
 $47 = HEAP32[580736>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694936,$47,$46,1);
 $48 = HEAP32[$2>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$5>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $52 = (($this) + 96|0);
 $53 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694824,$53,$52,0);
 $54 = HEAP32[$2>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$5>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $58 = (($this) + 100|0);
 $59 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694840,$59,$58,0);
 $60 = HEAP32[$2>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$5>>2]|0;
 $63 = ((($61) + (($62*24)|0)|0) + 12|0);
 HEAP32[$63>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $64 = (($this) + 101|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694864,$59,$64,0);
 $65 = HEAP32[$2>>2]|0;
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$5>>2]|0;
 $68 = ((($66) + (($67*24)|0)|0) + 12|0);
 HEAP32[$68>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $69 = (($this) + 102|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694888,$59,$69,0);
 $70 = HEAP32[$2>>2]|0;
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$5>>2]|0;
 $73 = ((($71) + (($72*24)|0)|0) + 12|0);
 HEAP32[$73>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $74 = (($this) + 104|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,694904,$53,$74,0);
 $75 = HEAP32[$2>>2]|0;
 $76 = HEAP32[$75>>2]|0;
 $77 = HEAP32[$5>>2]|0;
 $78 = ((($76) + (($77*24)|0)|0) + 12|0);
 HEAP32[$78>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN10SampleClipD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((693224 + 8|0));
 $1 = (($this) + 80|0);
 __THREW__ = 0;
 invoke_vi(3642,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($this) + 48|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
  $8 = (($this) + 56|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($9|0),($$byval_copy1|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   ___cxa_call_unexpected(($12|0));
   // unreachable;
  } else {
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $16 = (($this) + 48|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if (!($19)) {
  $20 = (($this) + 56|0);
  $21 = HEAP32[$20>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($21|0),($$byval_copy1|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   ___cxa_call_unexpected(($24|0));
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZN30AudioEffectInternalDescriptionC2EP26UnityAudioEffectDefinition($this,$from) {
 $this = $this|0;
 $from = $from|0;
 var $$arith = 0, $$arith2 = 0, $$overflow = 0, $$overflow3 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $n$01 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 200|0);
 HEAP32[$0>>2] = 0;
 dest=$this+0|0; stop=dest+92|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $1 = (($this) + 96|0);
 dest=$1+0|0; src=$from+0|0; stop=dest+104|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($from) + 32|0);
 (_strncpy(($this|0),($2|0),32)|0);
 $3 = (($this) + 128|0);
 (_strncpy(($3|0),($2|0),32)|0);
 $4 = (($from) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 60|0);
 HEAP32[$6>>2] = $5;
 $$arith2 = ($5*48)|0;
 $$overflow3 = ($5>>>0)>(89478485);
 $7 = $$overflow3 ? -1 : $$arith2;
 $8 = (__Znaj($7)|0);
 $9 = (($this) + 64|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$4>>2]|0;
 $11 = ($10*48)|0;
 _memset(($8|0),0,($11|0))|0;
 $12 = (($this) + 40|0);
 HEAP32[$12>>2] = 3376;
 $13 = (($this) + 44|0);
 HEAP32[$13>>2] = 3377;
 $14 = (($this) + 48|0);
 HEAP32[$14>>2] = 3378;
 $15 = (($this) + 52|0);
 HEAP32[$15>>2] = 114;
 $16 = (($this) + 56|0);
 HEAP32[$16>>2] = 2562;
 $17 = (($this) + 68|0);
 HEAP32[$17>>2] = 2;
 $18 = (($this) + 72|0);
 HEAP32[$18>>2] = 264;
 $$arith = ($10*56)|0;
 $$overflow = ($10>>>0)>(76695844);
 $19 = $$overflow ? -1 : $$arith;
 $20 = (__Znaj($19)|0);
 $21 = (($this) + 180|0);
 HEAP32[$21>>2] = $20;
 $22 = (($from) + 84|0);
 $23 = HEAP32[$22>>2]|0;
 _memcpy(($20|0),($23|0),($$arith|0))|0;
 $24 = ($10|0)==(0);
 if ($24) {
  STACKTOP = sp;return;
 } else {
  $26 = $23;$29 = $8;$32 = $20;$n$01 = 0;
 }
 while(1) {
  $25 = ((($26) + (($n$01*56)|0)|0) + 44|0);
  $27 = Math_fround(HEAPF32[$25>>2]);
  $28 = ((($29) + (($n$01*48)|0)|0) + 8|0);
  HEAPF32[$28>>2] = $27;
  $30 = Math_fround(HEAPF32[$25>>2]);
  $31 = ((($32) + (($n$01*56)|0)|0) + 44|0);
  HEAPF32[$31>>2] = $30;
  $33 = ((($26) + (($n$01*56)|0)|0) + 32|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (_strlen(($34|0))|0);
  $36 = (($35) + 1)|0;
  $37 = (__Znaj($36)|0);
  $38 = ((($29) + (($n$01*48)|0)|0) + 44|0);
  HEAP32[$38>>2] = $37;
  $39 = HEAP32[$9>>2]|0;
  $40 = ((($39) + (($n$01*48)|0)|0) + 44|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = HEAP32[$22>>2]|0;
  $43 = ((($42) + (($n$01*56)|0)|0) + 32|0);
  $44 = HEAP32[$43>>2]|0;
  (_strncpy(($41|0),($44|0),($36|0))|0);
  $45 = HEAP32[$9>>2]|0;
  $46 = ((($45) + (($n$01*48)|0)|0) + 28|0);
  $47 = HEAP32[$22>>2]|0;
  $48 = ((($47) + (($n$01*56)|0)|0) + 16|0);
  (_strncpy(($46|0),($48|0),16)|0);
  $49 = HEAP32[$22>>2]|0;
  $50 = ((($49) + (($n$01*56)|0)|0) + 36|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = HEAP32[$9>>2]|0;
  $53 = (($52) + (($n$01*48)|0)|0);
  HEAPF32[$53>>2] = $51;
  $54 = ((($49) + (($n$01*56)|0)|0) + 40|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = ((($52) + (($n$01*48)|0)|0) + 4|0);
  HEAPF32[$56>>2] = $55;
  $57 = ((($52) + (($n$01*48)|0)|0) + 12|0);
  $58 = (($49) + (($n$01*56)|0)|0);
  (_strncpy(($57|0),($58|0),16)|0);
  $59 = (($n$01) + 1)|0;
  $60 = HEAP32[$4>>2]|0;
  $61 = ($59>>>0)<($60>>>0);
  if (!($61)) {
   break;
  }
  $$pre = HEAP32[$22>>2]|0;
  $$pre3 = HEAP32[$9>>2]|0;
  $$pre4 = HEAP32[$21>>2]|0;
  $26 = $$pre;$29 = $$pre3;$32 = $$pre4;$n$01 = $59;
 }
 STACKTOP = sp;return;
}
function __ZL39UnityAudioEffect_InternalCreateCallbackP14FMOD_DSP_STATE($dsp_state) {
 $dsp_state = $dsp_state|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $instance = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $instance = sp;
 HEAP32[$instance>>2] = 0;
 $0 = HEAP32[$dsp_state>>2]|0;
 $1 = (__ZN4FMOD3DSP11getUserDataEPPv($0,$instance)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$instance>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($3) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($3) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & -4;
 $12 = (($8) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 3;
 $15 = $14 | $11;
 HEAP32[$9>>2] = $15;
 $16 = $8;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($3) + 8|0);
 $23 = $22;
 $24 = $23;
 HEAP32[$24>>2] = $18;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($8) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($3) + 4|0);
 HEAP32[$29>>2] = $28;
 $30 = (($6) + 160|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $36 = $3;$37 = 0;
 } else {
  $33 = (FUNCTION_TABLE_ii[$31 & 4095]($3)|0);
  $34 = ($33|0)==(0);
  $phitmp = $34 ? 0 : 80;
  $$pre = HEAP32[$instance>>2]|0;
  $36 = $$pre;$37 = $phitmp;
 }
 $35 = (($dsp_state) + 4|0);
 HEAP32[$35>>2] = $36;
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function __ZL40UnityAudioEffect_InternalReleaseCallbackP14FMOD_DSP_STATE($dsp_state) {
 $dsp_state = $dsp_state|0;
 var $$0 = 0, $$byval_copy1 = 0, $$lcssa$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre3$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $instance = 0, $n$01$i$i$i$i$i$i = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $instance = sp + 8|0;
 HEAP32[$instance>>2] = 0;
 $2 = HEAP32[$dsp_state>>2]|0;
 $3 = (__ZN4FMOD3DSP11getUserDataEPPv($2,$instance)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$instance>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($5) + 72|0);
 $8 = HEAP32[$7>>2]|0;
 (__ZN4FMOD3DSP11setUserDataEPv($2,0)|0);
 $9 = (($8) + 164|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $54 = 0;
 } else {
  $12 = HEAP32[$instance>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$10 & 4095]($12)|0);
  $14 = ($13|0)==(0);
  $phitmp = $14 ? 0 : 80;
  $54 = $phitmp;
 }
 $15 = HEAP32[$instance>>2]|0;
 $16 = (($15) + 68|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 64|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 68|0);
 HEAP32[$20>>2] = $17;
 $21 = HEAP32[$instance>>2]|0;
 $22 = (($21) + 64|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 68|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 64|0);
 HEAP32[$26>>2] = $23;
 $27 = HEAP32[$instance>>2]|0;
 $28 = HEAP32[628304>>2]|0;
 $29 = ($27|0)==(0|0);
 if (!($29)) {
  $30 = (($27) + 72|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   $33 = (($31) + 200|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + -1)|0;
   HEAP32[$33>>2] = $35;
   $36 = ($35|0)==(0);
   if ($36) {
    $37 = (($31) + 60|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)>(0);
    $40 = (($31) + 64|0);
    $41 = HEAP32[$40>>2]|0;
    if ($39) {
     $43 = $41;$55 = $38;$n$01$i$i$i$i$i$i = 0;
     while(1) {
      $42 = ((($43) + (($n$01$i$i$i$i$i$i*48)|0)|0) + 44|0);
      $44 = HEAP32[$42>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $48 = $55;$56 = $43;
      } else {
       __ZdaPv($44);
       $$pre$i$i$i$i$i$i = HEAP32[$37>>2]|0;
       $$pre3$i$i$i$i$i$i = HEAP32[$40>>2]|0;
       $48 = $$pre$i$i$i$i$i$i;$56 = $$pre3$i$i$i$i$i$i;
      }
      $46 = (($n$01$i$i$i$i$i$i) + 1)|0;
      $47 = ($46|0)<($48|0);
      if ($47) {
       $43 = $56;$55 = $48;$n$01$i$i$i$i$i$i = $46;
      } else {
       $$lcssa$i$i$i$i$i$i = $56;
       break;
      }
     }
    } else {
     $$lcssa$i$i$i$i$i$i = $41;
    }
    $49 = ($$lcssa$i$i$i$i$i$i|0)==(0|0);
    if (!($49)) {
     __ZdaPv($$lcssa$i$i$i$i$i$i);
    }
    $50 = (($31) + 180|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)==(0|0);
    if (!($52)) {
     __ZdaPv($51);
    }
    $53 = HEAP32[628304>>2]|0;
    HEAP32[$0>>2] = $53;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy1);
   }
  }
  HEAP32[$30>>2] = 0;
 }
 HEAP32[$1>>2] = $28;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy1);
 HEAP32[$instance>>2] = 0;
 $$0 = $54;
 STACKTOP = sp;return ($$0|0);
}
function __ZL38UnityAudioEffect_InternalResetCallbackP14FMOD_DSP_STATE($dsp_state) {
 $dsp_state = $dsp_state|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $instance = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $instance = sp;
 HEAP32[$instance>>2] = 0;
 $0 = HEAP32[$dsp_state>>2]|0;
 $1 = (__ZN4FMOD3DSP11getUserDataEPPv($0,$instance)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = HEAP32[$instance>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0 = 36;
  } else {
   $5 = (($3) + 72|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 168|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0 = 0;
   } else {
    $10 = (FUNCTION_TABLE_ii[$8 & 4095]($3)|0);
    $11 = ($10|0)==(0);
    $phitmp = $11 ? 0 : 80;
    $$0 = $phitmp;
   }
  }
 } else {
  $$0 = $1;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL37UnityAudioEffect_InternalReadCallbackP14FMOD_DSP_STATEPfS1_jii($dsp_state,$inbuffer,$outbuffer,$length,$inchannels,$outchannels) {
 $dsp_state = $dsp_state|0;
 $inbuffer = $inbuffer|0;
 $outbuffer = $outbuffer|0;
 $length = $length|0;
 $inchannels = $inchannels|0;
 $outchannels = $outchannels|0;
 var $$0 = 0, $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $extract$t = 0, $instance = 0, $phitmp = 0, $sideChainNeedsClearing$0$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $instance = sp;
 HEAP32[$instance>>2] = 0;
 $0 = HEAP32[$dsp_state>>2]|0;
 $1 = (__ZN4FMOD3DSP11getUserDataEPPv($0,$instance)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$instance>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($3) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($3) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($3) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & -4;
 $12 = (($8) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 3;
 $15 = $14 | $11;
 HEAP32[$9>>2] = $15;
 $16 = $8;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($3) + 8|0);
 $23 = $22;
 $24 = $23;
 HEAP32[$24>>2] = $18;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($8) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($3) + 4|0);
 HEAP32[$29>>2] = $28;
 $30 = (($3) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $sideChainNeedsClearing$0$off0 = 0;
 } else {
  $$lobit = $10 & 8;
  $extract$t = ($$lobit|0)==(0);
  if ($extract$t) {
   $sideChainNeedsClearing$0$off0 = 0;
  } else {
   $33 = (($3) + 16|0);
   $34 = $33;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = (_i64Subtract(($18|0),($21|0),($36|0),($39|0))|0);
   $41 = tempRet0;
   $42 = ($40|0)==($length|0);
   $43 = ($41|0)==(0);
   $44 = $42 & $43;
   if ($44) {
    $sideChainNeedsClearing$0$off0 = 1;
   } else {
    $45 = $length << 2;
    $46 = Math_imul($45, $inchannels)|0;
    _memset(($31|0),0,($46|0))|0;
    $sideChainNeedsClearing$0$off0 = 0;
   }
  }
 }
 $47 = (($6) + 172|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  $70 = 0;
 } else {
  $50 = HEAP32[$instance>>2]|0;
  $51 = (FUNCTION_TABLE_iiiiiii[$48 & 255]($50,$inbuffer,$outbuffer,$length,$inchannels,$outchannels)|0);
  $52 = ($51|0)==(0);
  $phitmp = $52 ? 0 : 80;
  $70 = $phitmp;
 }
 $53 = HEAP32[$instance>>2]|0;
 $54 = (($53) + 8|0);
 $55 = $54;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = (($53) + 16|0);
 $62 = $61;
 $63 = $62;
 HEAP32[$63>>2] = $57;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = $60;
 if (!($sideChainNeedsClearing$0$off0)) {
  $$0 = $70;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = (($53) + 24|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = $length << 2;
 $69 = Math_imul($68, $inchannels)|0;
 _memset(($67|0),0,($69|0))|0;
 $$0 = $70;
 STACKTOP = sp;return ($$0|0);
}
function __ZL44UnityAudioEffect_InternalSetPositionCallbackP14FMOD_DSP_STATEj($dsp_state,$pos) {
 $dsp_state = $dsp_state|0;
 $pos = $pos|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $instance = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $instance = sp;
 HEAP32[$instance>>2] = 0;
 $0 = HEAP32[$dsp_state>>2]|0;
 $1 = (__ZN4FMOD3DSP11getUserDataEPPv($0,$instance)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = HEAP32[$instance>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0 = 36;
  } else {
   $5 = (($3) + 72|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 176|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0 = 0;
   } else {
    $10 = (FUNCTION_TABLE_iii[$8 & 4095]($3,$pos)|0);
    $11 = ($10|0)==(0);
    $phitmp = $11 ? 0 : 80;
    $$0 = $phitmp;
   }
  }
 } else {
  $$0 = $1;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL50UnityAudioEffect_InternalSetFloatParameterCallbackP14FMOD_DSP_STATEif($dsp_state,$index,$value) {
 $dsp_state = $dsp_state|0;
 $index = $index|0;
 $value = Math_fround($value);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $instance = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $instance = sp;
 HEAP32[$instance>>2] = 0;
 $0 = HEAP32[$dsp_state>>2]|0;
 $1 = (__ZN4FMOD3DSP11getUserDataEPPv($0,$instance)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = HEAP32[$instance>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0 = 36;
  } else {
   $5 = (($3) + 72|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 184|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0 = 0;
   } else {
    $10 = (FUNCTION_TABLE_iiif[$8 & 3]($3,$index,$value)|0);
    $11 = ($10|0)==(0);
    $phitmp = $11 ? 0 : 80;
    $$0 = $phitmp;
   }
  }
 } else {
  $$0 = $1;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZL50UnityAudioEffect_InternalGetFloatParameterCallbackP14FMOD_DSP_STATEiPfPc($dsp_state,$index,$value,$valuestr) {
 $dsp_state = $dsp_state|0;
 $index = $index|0;
 $value = $value|0;
 $valuestr = $valuestr|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $instance = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $instance = sp;
 HEAP32[$instance>>2] = 0;
 $0 = HEAP32[$dsp_state>>2]|0;
 $1 = (__ZN4FMOD3DSP11getUserDataEPPv($0,$instance)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$instance>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($3) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 188|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (FUNCTION_TABLE_iiiii[$8 & 511]($3,$index,$value,$valuestr)|0);
 $11 = ($10|0)==(0);
 $phitmp = $11 ? 0 : 80;
 $$0 = $phitmp;
 STACKTOP = sp;return ($$0|0);
}
function __ZN29AudioEffectInternalDefinitionC2EP26UnityAudioEffectDefinitionb($this,$from,$registerDefinition) {
 $this = $this|0;
 $from = $from|0;
 $registerDefinition = $registerDefinition|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $$lcssa$i$i = 0, $$lcssa$i$i$i$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre3$i$i = 0, $$pre3$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $n$01$i$i = 0, $n$01$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 HEAP32[$this>>2] = 0;
 $4 = (($this) + 4|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 5|0);
 HEAP8[$5>>0] = 1;
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 12|0);
 HEAP32[$7>>2] = 0;
 if ($registerDefinition) {
  $8 = HEAP32[628304>>2]|0;
  HEAP32[$2>>2] = $8;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
  $9 = (invoke_iiiiiii(103,80,($$byval_copy4|0),0,16,(702936|0),285)|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   label = 4;
  } else {
   $12 = (($9) + 72|0);
   HEAP32[$12>>2] = 0;
   HEAP32[$7>>2] = $9;
   HEAP32[$9>>2] = 0;
   $13 = (($9) + 64|0);
   HEAP32[$13>>2] = $9;
   $14 = HEAP32[$7>>2]|0;
   $15 = (($14) + 68|0);
   HEAP32[$15>>2] = $14;
   label = 5;
  }
 } else {
  label = 5;
 }
 do {
  if ((label|0) == 5) {
   $18 = HEAP32[628304>>2]|0;
   HEAP32[$3>>2] = $18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   $19 = (invoke_iiiiiii(103,208,($$byval_copy4|0),0,16,(702936|0),291)|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    label = 4;
   } else {
    __THREW__ = 0;
    invoke_vii(3338,($19|0),($from|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     $53 = ___cxa_find_matching_catch()|0;
     $54 = tempRet0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_viiiiii(97,($19|0),($$byval_copy4|0),0,16,(702936|0),291);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      $$0 = $54;$$01 = $53;
      break;
     }
     $82 = ___cxa_find_matching_catch(0|0)|0;
     $83 = tempRet0;
     ___clang_call_terminate($82);
     // unreachable;
    }
    $24 = ($19|0)==(0|0);
    if (!($24)) {
     $25 = (($19) + 200|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($26) + 1)|0;
     HEAP32[$25>>2] = $27;
    }
    $28 = HEAP32[$this>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     HEAP32[$this>>2] = $19;
     STACKTOP = sp;return;
    }
    $30 = (($28) + 200|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + -1)|0;
    HEAP32[$30>>2] = $32;
    $33 = ($32|0)==(0);
    if (!($33)) {
     HEAP32[$this>>2] = $19;
     STACKTOP = sp;return;
    }
    $34 = (($28) + 60|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($35|0)>(0);
    $37 = (($28) + 64|0);
    $38 = HEAP32[$37>>2]|0;
    if ($36) {
     $40 = $38;$84 = $35;$n$01$i$i = 0;
     while(1) {
      $39 = ((($40) + (($n$01$i$i*48)|0)|0) + 44|0);
      $41 = HEAP32[$39>>2]|0;
      $42 = ($41|0)==(0|0);
      if ($42) {
       $45 = $84;$85 = $40;
      } else {
       __ZdaPv($41);
       $$pre$i$i = HEAP32[$34>>2]|0;
       $$pre3$i$i = HEAP32[$37>>2]|0;
       $45 = $$pre$i$i;$85 = $$pre3$i$i;
      }
      $43 = (($n$01$i$i) + 1)|0;
      $44 = ($43|0)<($45|0);
      if ($44) {
       $40 = $85;$84 = $45;$n$01$i$i = $43;
      } else {
       $$lcssa$i$i = $85;
       break;
      }
     }
    } else {
     $$lcssa$i$i = $38;
    }
    $46 = ($$lcssa$i$i|0)==(0|0);
    if (!($46)) {
     __ZdaPv($$lcssa$i$i);
    }
    $47 = (($28) + 180|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if (!($49)) {
     __ZdaPv($48);
    }
    $50 = HEAP32[628304>>2]|0;
    HEAP32[$0>>2] = $50;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($28|0),($$byval_copy4|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     label = 4;
    } else {
     HEAP32[$this>>2] = $19;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $$0 = $17;$$01 = $16;
 }
 $57 = HEAP32[$this>>2]|0;
 $58 = ($57|0)==(0|0);
 if ($58) {
  HEAP32[$this>>2] = 0;
  ___resumeException($$01|0);
  // unreachable;
 }
 $59 = (($57) + 200|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + -1)|0;
 HEAP32[$59>>2] = $61;
 $62 = ($61|0)==(0);
 if (!($62)) {
  HEAP32[$this>>2] = 0;
  ___resumeException($$01|0);
  // unreachable;
 }
 $63 = (($57) + 60|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)>(0);
 $66 = (($57) + 64|0);
 $67 = HEAP32[$66>>2]|0;
 if ($65) {
  $69 = $67;$86 = $64;$n$01$i$i$i$i = 0;
  while(1) {
   $68 = ((($69) + (($n$01$i$i$i$i*48)|0)|0) + 44|0);
   $70 = HEAP32[$68>>2]|0;
   $71 = ($70|0)==(0|0);
   if ($71) {
    $74 = $86;$87 = $69;
   } else {
    __ZdaPv($70);
    $$pre$i$i$i$i = HEAP32[$63>>2]|0;
    $$pre3$i$i$i$i = HEAP32[$66>>2]|0;
    $74 = $$pre$i$i$i$i;$87 = $$pre3$i$i$i$i;
   }
   $72 = (($n$01$i$i$i$i) + 1)|0;
   $73 = ($72|0)<($74|0);
   if ($73) {
    $69 = $87;$86 = $74;$n$01$i$i$i$i = $72;
   } else {
    $$lcssa$i$i$i$i = $87;
    break;
   }
  }
 } else {
  $$lcssa$i$i$i$i = $67;
 }
 $75 = ($$lcssa$i$i$i$i|0)==(0|0);
 if (!($75)) {
  __ZdaPv($$lcssa$i$i$i$i);
 }
 $76 = (($57) + 180|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  __ZdaPv($77);
 }
 $79 = HEAP32[628304>>2]|0;
 HEAP32[$1>>2] = $79;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($57|0),($$byval_copy4|0));
 $80 = __THREW__; __THREW__ = 0;
 $81 = $80&1;
 if ($81) {
  $82 = ___cxa_find_matching_catch(0|0)|0;
  $83 = tempRet0;
  ___clang_call_terminate($82);
  // unreachable;
 } else {
  HEAP32[$this>>2] = 0;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN29AudioEffectInternalDefinitionD2Ev($this) {
 $this = $this|0;
 var $$byval_copy8 = 0, $$lcssa$i$i$i$i = 0, $$lcssa$i$i$i$i$i$i = 0, $$lcssa$i$i$i$i8 = 0, $$pre = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i6 = 0, $$pre3$i$i$i$i = 0, $$pre3$i$i$i$i$i$i = 0, $$pre3$i$i$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $n$01$i$i$i$i = 0;
 var $n$01$i$i$i$i$i$i = 0, $n$01$i$i$i$i4 = 0, $s$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if (!($5)) {
   $6 = (($4) + 68|0);
   $7 = HEAP32[$6>>2]|0;
   $9 = $4;$s$0 = $7;
   while(1) {
    $8 = ($s$0|0)==($9|0);
    if ($8) {
     label = 19;
     break;
    }
    $10 = (($s$0) + 68|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($s$0) + 76|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    (invoke_ii(3379,($13|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     label = 6;
     break;
    }
    $$pre = HEAP32[$3>>2]|0;
    $9 = $$pre;$s$0 = $11;
   }
   if ((label|0) == 6) {
    $16 = ___cxa_find_matching_catch()|0;
    $17 = tempRet0;
    $lpad$phi$index = $16;$lpad$phi$index2 = $17;
   }
   else if ((label|0) == 19) {
    $45 = HEAP32[628304>>2]|0;
    $46 = ($9|0)==(0|0);
    do {
     if ($46) {
      label = 32;
     } else {
      $47 = (($9) + 72|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)==(0|0);
      if (!($49)) {
       $50 = (($48) + 200|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + -1)|0;
       HEAP32[$50>>2] = $52;
       $53 = ($52|0)==(0);
       if ($53) {
        $54 = (($48) + 60|0);
        $55 = HEAP32[$54>>2]|0;
        $56 = ($55|0)>(0);
        $57 = (($48) + 64|0);
        $58 = HEAP32[$57>>2]|0;
        if ($56) {
         $102 = $55;$60 = $58;$n$01$i$i$i$i$i$i = 0;
         while(1) {
          $59 = ((($60) + (($n$01$i$i$i$i$i$i*48)|0)|0) + 44|0);
          $61 = HEAP32[$59>>2]|0;
          $62 = ($61|0)==(0|0);
          if ($62) {
           $103 = $60;$65 = $102;
          } else {
           __ZdaPv($61);
           $$pre$i$i$i$i$i$i = HEAP32[$54>>2]|0;
           $$pre3$i$i$i$i$i$i = HEAP32[$57>>2]|0;
           $103 = $$pre3$i$i$i$i$i$i;$65 = $$pre$i$i$i$i$i$i;
          }
          $63 = (($n$01$i$i$i$i$i$i) + 1)|0;
          $64 = ($63|0)<($65|0);
          if ($64) {
           $102 = $65;$60 = $103;$n$01$i$i$i$i$i$i = $63;
          } else {
           $$lcssa$i$i$i$i$i$i = $103;
           break;
          }
         }
        } else {
         $$lcssa$i$i$i$i$i$i = $58;
        }
        $66 = ($$lcssa$i$i$i$i$i$i|0)==(0|0);
        if (!($66)) {
         __ZdaPv($$lcssa$i$i$i$i$i$i);
        }
        $67 = (($48) + 180|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = ($68|0)==(0|0);
        if (!($69)) {
         __ZdaPv($68);
        }
        $70 = HEAP32[628304>>2]|0;
        HEAP32[$0>>2] = $70;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($48|0),($$byval_copy8|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         break;
        }
       }
      }
      HEAP32[$47>>2] = 0;
      label = 32;
     }
    } while(0);
    if ((label|0) == 32) {
     HEAP32[$1>>2] = $45;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($9|0),($$byval_copy8|0));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if (!($74)) {
      HEAP32[$3>>2] = 0;
      break;
     }
    }
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    $lpad$phi$index = $18;$lpad$phi$index2 = $19;
   }
   $20 = HEAP32[$this>>2]|0;
   $21 = ($20|0)==(0|0);
   if ($21) {
    HEAP32[$this>>2] = 0;
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $22 = (($20) + 200|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + -1)|0;
   HEAP32[$22>>2] = $24;
   $25 = ($24|0)==(0);
   if (!($25)) {
    HEAP32[$this>>2] = 0;
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $26 = (($20) + 60|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)>(0);
   $29 = (($20) + 64|0);
   $30 = HEAP32[$29>>2]|0;
   if ($28) {
    $100 = $27;$32 = $30;$n$01$i$i$i$i = 0;
    while(1) {
     $31 = ((($32) + (($n$01$i$i$i$i*48)|0)|0) + 44|0);
     $33 = HEAP32[$31>>2]|0;
     $34 = ($33|0)==(0|0);
     if ($34) {
      $101 = $32;$37 = $100;
     } else {
      __ZdaPv($33);
      $$pre$i$i$i$i = HEAP32[$26>>2]|0;
      $$pre3$i$i$i$i = HEAP32[$29>>2]|0;
      $101 = $$pre3$i$i$i$i;$37 = $$pre$i$i$i$i;
     }
     $35 = (($n$01$i$i$i$i) + 1)|0;
     $36 = ($35|0)<($37|0);
     if ($36) {
      $100 = $37;$32 = $101;$n$01$i$i$i$i = $35;
     } else {
      $$lcssa$i$i$i$i = $101;
      break;
     }
    }
   } else {
    $$lcssa$i$i$i$i = $30;
   }
   $38 = ($$lcssa$i$i$i$i|0)==(0|0);
   if (!($38)) {
    __ZdaPv($$lcssa$i$i$i$i);
   }
   $39 = (($20) + 180|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if (!($41)) {
    __ZdaPv($40);
   }
   $42 = HEAP32[628304>>2]|0;
   HEAP32[$2>>2] = $42;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($20|0),($$byval_copy8|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $98 = ___cxa_find_matching_catch(0|0)|0;
    $99 = tempRet0;
    ___clang_call_terminate($98);
    // unreachable;
   } else {
    HEAP32[$this>>2] = 0;
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
  }
 } while(0);
 $75 = HEAP32[$this>>2]|0;
 $76 = ($75|0)==(0|0);
 if ($76) {
  HEAP32[$this>>2] = 0;
  STACKTOP = sp;return;
 }
 $77 = (($75) + 200|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + -1)|0;
 HEAP32[$77>>2] = $79;
 $80 = ($79|0)==(0);
 if (!($80)) {
  HEAP32[$this>>2] = 0;
  STACKTOP = sp;return;
 }
 $81 = (($75) + 60|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)>(0);
 $84 = (($75) + 64|0);
 $85 = HEAP32[$84>>2]|0;
 if ($83) {
  $104 = $82;$87 = $85;$n$01$i$i$i$i4 = 0;
  while(1) {
   $86 = ((($87) + (($n$01$i$i$i$i4*48)|0)|0) + 44|0);
   $88 = HEAP32[$86>>2]|0;
   $89 = ($88|0)==(0|0);
   if ($89) {
    $105 = $87;$92 = $104;
   } else {
    __ZdaPv($88);
    $$pre$i$i$i$i6 = HEAP32[$81>>2]|0;
    $$pre3$i$i$i$i7 = HEAP32[$84>>2]|0;
    $105 = $$pre3$i$i$i$i7;$92 = $$pre$i$i$i$i6;
   }
   $90 = (($n$01$i$i$i$i4) + 1)|0;
   $91 = ($90|0)<($92|0);
   if ($91) {
    $104 = $92;$87 = $105;$n$01$i$i$i$i4 = $90;
   } else {
    $$lcssa$i$i$i$i8 = $105;
    break;
   }
  }
 } else {
  $$lcssa$i$i$i$i8 = $85;
 }
 $93 = ($$lcssa$i$i$i$i8|0)==(0|0);
 if (!($93)) {
  __ZdaPv($$lcssa$i$i$i$i8);
 }
 $94 = (($75) + 180|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 if (!($96)) {
  __ZdaPv($95);
 }
 $97 = HEAP32[628304>>2]|0;
 HEAP32[$0>>2] = $97;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($75,$$byval_copy8);
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN29AudioEffectInternalDefinition9CreateDSPEPN4FMOD6SystemEPvPf($this,$system,$effectdata,$sideChainBuffer) {
 $this = $this|0;
 $system = $system|0;
 $effectdata = $effectdata|0;
 $sideChainBuffer = $sideChainBuffer|0;
 var $$0 = 0, $$byval_copy2 = 0, $$lcssa$i$i$i$i$i$i = 0, $$pre = 0, $$pre$ = 0, $$pre$i$i$i$i$i$i = 0, $$pre3$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $dsp = 0, $n$01$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $dsp = sp + 8|0;
 $2 = sp + 12|0;
 HEAP32[$dsp>>2] = 0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $78 = (__ZN4FMOD6System15createDSPByTypeE13FMOD_DSP_TYPEPPNS_3DSPE($system,$4,$dsp)|0);
  $79 = ($78|0)==(0);
  $$pre = HEAP32[$dsp>>2]|0;
  $$pre$ = $79 ? $$pre : 0;
  STACKTOP = sp;return ($$pre$|0);
 }
 $6 = HEAP32[628304>>2]|0;
 HEAP32[$2>>2] = $6;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 $7 = (__Znwj10MemLabelIdbiPKci(80,$$byval_copy2,0,16,702936,314)|0);
 $8 = (($7) + 72|0);
 dest=$7+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$7>>2] = 64;
 $9 = (($7) + 28|0);
 HEAP32[$9>>2] = $effectdata;
 __ZN33AudioEffectInternalDescriptionPtraSERKS_($8,$this);
 $10 = (($7) + 24|0);
 HEAP32[$10>>2] = $sideChainBuffer;
 $11 = (($7) + 36|0);
 HEAP32[$11>>2] = 702920;
 $12 = HEAP32[$this>>2]|0;
 $13 = (($12) + 120|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $16 & 1;
 $21 = ($20|0)==(0);
 $22 = (0)==(0);
 $23 = $21 & $22;
 if (!($23)) {
  $24 = (($7) + 32|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $25 | 8;
  HEAP32[$24>>2] = $26;
 }
 $27 = (($this) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $41 = (($7) + 64|0);
  HEAP32[$41>>2] = $7;
  $42 = (($7) + 68|0);
  HEAP32[$42>>2] = $7;
 } else {
  $30 = (($28) + 64|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($7) + 64|0);
  HEAP32[$32>>2] = $31;
  $33 = HEAP32[$27>>2]|0;
  $34 = (($7) + 68|0);
  HEAP32[$34>>2] = $33;
  $35 = HEAP32[$27>>2]|0;
  $36 = (($35) + 64|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($37) + 68|0);
  HEAP32[$38>>2] = $7;
  $39 = HEAP32[$27>>2]|0;
  $40 = (($39) + 64|0);
  HEAP32[$40>>2] = $7;
 }
 $43 = HEAP32[$this>>2]|0;
 $44 = (($43) + 88|0);
 HEAP32[$44>>2] = $7;
 $45 = HEAP32[$this>>2]|0;
 $46 = (($7) + 76|0);
 $47 = (__ZN4FMOD6System9createDSPEP20FMOD_DSP_DESCRIPTIONPPNS_3DSPE($system,$45,$46)|0);
 $48 = ($47|0)==(0);
 do {
  if ($48) {
   $49 = HEAP32[$46>>2]|0;
   $50 = ($49|0)==(0|0);
   if ($50) {
    $51 = HEAP32[628304>>2]|0;
    $80 = $1;$81 = $51;
    label = 11;
    break;
   }
   HEAP32[$dsp>>2] = $49;
   $$0 = $49;
   STACKTOP = sp;return ($$0|0);
  } else {
   $52 = HEAP32[628304>>2]|0;
   $53 = ($7|0)==(0|0);
   if ($53) {
    $77 = $52;$82 = $1;
   } else {
    $80 = $1;$81 = $52;
    label = 11;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $54 = HEAP32[$8>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = (($54) + 200|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + -1)|0;
   HEAP32[$56>>2] = $58;
   $59 = ($58|0)==(0);
   if ($59) {
    $60 = (($54) + 60|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)>(0);
    $63 = (($54) + 64|0);
    $64 = HEAP32[$63>>2]|0;
    if ($62) {
     $66 = $64;$83 = $61;$n$01$i$i$i$i$i$i = 0;
     while(1) {
      $65 = ((($66) + (($n$01$i$i$i$i$i$i*48)|0)|0) + 44|0);
      $67 = HEAP32[$65>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       $71 = $83;$84 = $66;
      } else {
       __ZdaPv($67);
       $$pre$i$i$i$i$i$i = HEAP32[$60>>2]|0;
       $$pre3$i$i$i$i$i$i = HEAP32[$63>>2]|0;
       $71 = $$pre$i$i$i$i$i$i;$84 = $$pre3$i$i$i$i$i$i;
      }
      $69 = (($n$01$i$i$i$i$i$i) + 1)|0;
      $70 = ($69|0)<($71|0);
      if ($70) {
       $66 = $84;$83 = $71;$n$01$i$i$i$i$i$i = $69;
      } else {
       $$lcssa$i$i$i$i$i$i = $84;
       break;
      }
     }
    } else {
     $$lcssa$i$i$i$i$i$i = $64;
    }
    $72 = ($$lcssa$i$i$i$i$i$i|0)==(0|0);
    if (!($72)) {
     __ZdaPv($$lcssa$i$i$i$i$i$i);
    }
    $73 = (($54) + 180|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)==(0|0);
    if (!($75)) {
     __ZdaPv($74);
    }
    $76 = HEAP32[628304>>2]|0;
    HEAP32[$0>>2] = $76;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($54,$$byval_copy2);
   }
  }
  HEAP32[$8>>2] = 0;
  $77 = $81;$82 = $80;
 }
 HEAP32[$1>>2] = $77;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy2);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN33AudioEffectInternalDescriptionPtraSERKS_($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$byval_copy = 0, $$lcssa$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$p>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 200|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 1)|0;
  HEAP32[$3>>2] = $5;
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $29 = $1;
  HEAP32[$this>>2] = $29;
  STACKTOP = sp;return;
 }
 $8 = (($6) + 200|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + -1)|0;
 HEAP32[$8>>2] = $10;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $29 = $1;
  HEAP32[$this>>2] = $29;
  STACKTOP = sp;return;
 }
 $12 = (($6) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)>(0);
 $15 = (($6) + 64|0);
 $16 = HEAP32[$15>>2]|0;
 if ($14) {
  $18 = $16;$30 = $13;$n$01$i$i = 0;
  while(1) {
   $17 = ((($18) + (($n$01$i$i*48)|0)|0) + 44|0);
   $19 = HEAP32[$17>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $23 = $30;$31 = $18;
   } else {
    __ZdaPv($19);
    $$pre$i$i = HEAP32[$12>>2]|0;
    $$pre3$i$i = HEAP32[$15>>2]|0;
    $23 = $$pre$i$i;$31 = $$pre3$i$i;
   }
   $21 = (($n$01$i$i) + 1)|0;
   $22 = ($21|0)<($23|0);
   if ($22) {
    $18 = $31;$30 = $23;$n$01$i$i = $21;
   } else {
    $$lcssa$i$i = $31;
    break;
   }
  }
 } else {
  $$lcssa$i$i = $16;
 }
 $24 = ($$lcssa$i$i|0)==(0|0);
 if (!($24)) {
  __ZdaPv($$lcssa$i$i);
 }
 $25 = (($6) + 180|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  __ZdaPv($26);
 }
 $28 = HEAP32[628304>>2]|0;
 HEAP32[$0>>2] = $28;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy);
 $$pre = HEAP32[$p>>2]|0;
 $29 = $$pre;
 HEAP32[$this>>2] = $29;
 STACKTOP = sp;return;
}
function __Z25GetAudioEffectDefinitionsPi($numDefs) {
 $numDefs = $numDefs|0;
 var $$ = 0, $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $i3$03 = 0, $i3$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = HEAP8[702976>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  HEAP32[702944>>2] = 0;
  HEAP32[702960>>2] = 0;
  HEAP32[702968>>2] = 0;
  HEAP32[702952>>2] = 61;
  HEAP8[702976>>0] = 1;
 }
 $3 = HEAP32[702968>>2]|0;
 $4 = $3 & 2147483647;
 $5 = ($4|0)==(0);
 do {
  if ($5) {
   $6 = ($3|0)>(-1);
   if ($6) {
    HEAP32[702968>>2] = 1024;
    $7 = HEAP32[702944>>2]|0;
    $8 = HEAP32[702952>>2]|0;
    HEAP32[$0>>2] = $8;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $9 = (__Z16realloc_internalPvji10MemLabelIdiPKci($7,4096,4,$$byval_copy2,0,702936,370)|0);
    HEAP32[702944>>2] = $9;
    break;
   } else {
    $10 = HEAP32[702952>>2]|0;
    HEAP32[$0>>2] = $10;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $11 = (__Z15malloc_internaljj10MemLabelIdiPKci(4096,4,$$byval_copy2,0,702936,352)|0);
    $12 = HEAP32[702944>>2]|0;
    $13 = HEAP32[702960>>2]|0;
    $14 = $13 << 2;
    _memcpy(($11|0),($12|0),($14|0))|0;
    HEAP32[702968>>2] = 1024;
    HEAP32[702944>>2] = $11;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[702960>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $49 = 0;
 } else {
  $17 = HEAP32[702944>>2]|0;
  $i$04 = 0;
  while(1) {
   $19 = (($17) + ($i$04<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)!=(0);
   $24 = (($20) + 5|0);
   $25 = $23&1;
   HEAP8[$24>>0] = $25;
   $26 = (($i$04) + 1)|0;
   $27 = ($26>>>0)<($15>>>0);
   if ($27) {
    $i$04 = $26;
   } else {
    break;
   }
  }
  $18 = ($15|0)==(0);
  if ($18) {
   $49 = 0;
  } else {
   $53 = $15;$i3$03 = 0;
   while(1) {
    $28 = HEAP32[702944>>2]|0;
    $29 = (($28) + ($i3$03<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + 5|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = ($32<<24>>24)==(0);
    if ($33) {
     $34 = HEAP32[628304>>2]|0;
     $35 = ($30|0)==(0|0);
     if (!($35)) {
      __ZN29AudioEffectInternalDefinitionD2Ev($30);
     }
     HEAP32[$0>>2] = $34;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($30,$$byval_copy2);
     $36 = HEAP32[702944>>2]|0;
     $37 = (($36) + ($i3$03<<2)|0);
     HEAP32[$37>>2] = 0;
     $38 = HEAP32[702960>>2]|0;
     $39 = (($38) + -1)|0;
     $40 = HEAP32[702944>>2]|0;
     $41 = (($40) + ($39<<2)|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($i3$03) + -1)|0;
     $44 = (($40) + ($i3$03<<2)|0);
     HEAP32[$44>>2] = $42;
     HEAP32[702960>>2] = $39;
     $47 = $39;$i3$1 = $43;
    } else {
     $47 = $53;$i3$1 = $i3$03;
    }
    $45 = (($i3$1) + 1)|0;
    $46 = ($45>>>0)<($47>>>0);
    if ($46) {
     $53 = $47;$i3$03 = $45;
    } else {
     $49 = $47;
     break;
    }
   }
  }
 }
 $48 = ($numDefs|0)==(0|0);
 if ($48) {
  $51 = $49;
  $50 = ($51|0)==(0);
  $52 = HEAP32[702944>>2]|0;
  $$ = $50 ? 0 : $52;
  STACKTOP = sp;return ($$|0);
 }
 HEAP32[$numDefs>>2] = $49;
 $$pre = HEAP32[702960>>2]|0;
 $51 = $$pre;
 $50 = ($51|0)==(0);
 $52 = HEAP32[702944>>2]|0;
 $$ = $50 ? 0 : $52;
 STACKTOP = sp;return ($$|0);
}
function __ZN13AudioListener7CleanupEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($1) + 24|0);
 $29 = $4;$i$01 = 0;
 while(1) {
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7) + ($i$01<<3)|0) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $28 = $29;
  } else {
   $11 = (($9) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = $12 >>> 21;
   $14 = HEAP32[560640>>2]|0;
   $15 = Math_imul($14, $13)|0;
   $16 = (($15) + 181)|0;
   $17 = $16 >> 5;
   $18 = $17 << 5;
   $19 = (($16) - ($18))|0;
   $20 = HEAP32[560632>>2]|0;
   $21 = (($20) + ($17<<2)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = 1 << $19;
   $24 = $23 & $22;
   $25 = ($24|0)==(0);
   if ($25) {
    $28 = $29;
   } else {
    __ZN11AudioFilter7CleanupEv($9);
    $$pre = HEAP32[$3>>2]|0;
    $28 = $$pre;
   }
  }
  $26 = (($i$01) + 1)|0;
  $27 = ($26|0)<($28|0);
  if ($27) {
   $29 = $28;$i$01 = $26;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13AudioListener17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetAudioManagerv()|0);
 __ZN12AudioManager19RemoveAudioListenerEP13AudioListener($0,$this);
 STACKTOP = sp;return;
}
function __ZN13AudioListener12AddToManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($3)|0);
 __ZNK9Transform11GetPositionEv($0,$4);
 ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;
 $5 = (__Z15GetAudioManagerv()|0);
 __ZN12AudioManager16AddAudioListenerEP13AudioListener($5,$this);
 __ZN13AudioListener12ApplyFiltersEv($this);
 STACKTOP = sp;return;
}
function __ZN13AudioListener12ApplyFiltersEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $customFilter = 0, $dsp$15 = 0, $i$07 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $customFilter = sp + 16|0;
 $0 = sp + 4|0;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($2) + 24|0);
 $7 = (($0) + 1|0);
 $8 = (($0) + 8|0);
 $9 = (($this) + 4|0);
 $i$07 = 0;
 L4: while(1) {
  $10 = HEAP32[$6>>2]|0;
  $11 = ((($10) + ($i$07<<3)|0) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 7;
  } else {
   $14 = (($12) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = $15 >>> 21;
   $17 = HEAP32[560640>>2]|0;
   $18 = Math_imul($17, $16)|0;
   $19 = (($18) + 181)|0;
   $20 = $19 >> 5;
   $21 = $20 << 5;
   $22 = (($19) - ($21))|0;
   $23 = HEAP32[560632>>2]|0;
   $24 = (($23) + ($20<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = 1 << $22;
   $27 = $26 & $25;
   $28 = ($27|0)==(0);
   if ($28) {
    label = 7;
   } else {
    $29 = (__Z16GetBuildSettingsv()|0);
    $30 = (($29) + 94|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     label = 7;
    } else {
     $33 = (__ZN11AudioFilter6GetDSPEv($12)|0);
     $34 = ($33|0)==(0|0);
     if ($34) {
      label = 7;
     } else {
      $dsp$15 = $33;
      label = 10;
     }
    }
   }
  }
  if ((label|0) == 7) {
   label = 0;
   $35 = HEAP32[$6>>2]|0;
   $36 = ((($35) + ($i$07<<3)|0) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    $39 = (($37) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = $40 >>> 21;
    $42 = HEAP32[560640>>2]|0;
    $43 = Math_imul($42, $41)|0;
    $44 = (($43) + 114)|0;
    $45 = $44 >> 5;
    $46 = $45 << 5;
    $47 = (($44) - ($46))|0;
    $48 = HEAP32[560632>>2]|0;
    $49 = (($48) + ($45<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = 1 << $47;
    $52 = $51 & $50;
    $53 = ($52|0)==(0);
    if (!($53)) {
     $54 = (__ZN13MonoBehaviour14GetOrCreateDSPEv($37)|0);
     $55 = ($54|0)==(0|0);
     if (!($55)) {
      $dsp$15 = $54;
      label = 10;
     }
    }
   }
  }
  L14: do {
   if ((label|0) == 10) {
    label = 0;
    HEAP32[$customFilter>>2] = 0;
    (__ZN4FMOD3DSP11getUserDataEPPv($dsp$15,$customFilter)|0);
    $56 = HEAP32[$customFilter>>2]|0;
    $57 = ($56|0)==(0|0);
    do {
     if (!($57)) {
      $58 = (($56) + 16|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($59|0)==(0|0);
      if ($60) {
       $79 = (($56) + 20|0);
       HEAP32[$79>>2] = $this;
       break;
      }
      __Z6FormatPKcz($0,703128,$vararg_buffer);
      $61 = HEAP32[$9>>2]|0;
      $62 = HEAP8[$0>>0]|0;
      $63 = $62 & 1;
      $64 = ($63<<24>>24)==(0);
      $65 = HEAP32[$8>>2]|0;
      $66 = $64 ? $7 : $65;
      __THREW__ = 0;
      invoke_viiiiiiii(21,($66|0),0,(703464|0),139,512,($61|0),0,(0|0));
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break L4;
      }
      $69 = HEAP8[$0>>0]|0;
      $70 = $69 & 1;
      $71 = ($70<<24>>24)==(0);
      if ($71) {
       break L14;
      }
      $72 = HEAP32[$8>>2]|0;
      __ZdlPv($72);
      break L14;
     }
    } while(0);
    $80 = (__ZN4FMOD3DSP6removeEv($dsp$15)|0);
    (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($80,703472,146,703544)|0);
    $81 = (__Z15GetAudioManagerv()|0);
    $82 = (($81) + 100|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (__ZN4FMOD12ChannelGroup6addDSPEPNS_3DSPEPPNS_13DSPConnectionE($83,$dsp$15,0)|0);
    (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($84,703472,147,703560)|0);
   }
  } while(0);
  $85 = (($i$07) + 1)|0;
  $86 = HEAP32[$3>>2]|0;
  $87 = ($85|0)<($86|0);
  if ($87) {
   $i$07 = $85;
  } else {
   label = 20;
   break;
  }
 }
 if ((label|0) == 20) {
  STACKTOP = sp;return;
 }
 $73 = ___cxa_find_matching_catch()|0;
 $74 = tempRet0;
 $75 = HEAP8[$0>>0]|0;
 $76 = $75 & 1;
 $77 = ($76<<24>>24)==(0);
 if ($77) {
  ___resumeException($73|0);
  // unreachable;
 }
 $78 = HEAP32[$8>>2]|0;
 __ZdlPv($78);
 ___resumeException($73|0);
 // unreachable;
}
function __ZN13AudioListener13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 STACKTOP = sp;return;
}
function __ZN13AudioListener8DoUpdateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $8 = 0, $9 = 0, $pos = 0, $vel = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $pos = sp + 84|0;
 $vel = sp;
 $0 = sp + 12|0;
 $1 = sp + 24|0;
 $2 = sp + 36|0;
 $3 = sp + 48|0;
 $4 = sp + 60|0;
 $5 = sp + 72|0;
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($7)|0);
 __ZNK9Transform11GetPositionEv($pos,$8);
 $9 = (($this) + 32|0);
 $10 = Math_fround(HEAPF32[$pos>>2]);
 $11 = Math_fround(HEAPF32[$9>>2]);
 $12 = Math_fround($10 - $11);
 $13 = (($pos) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 36|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 - $16);
 $18 = (($pos) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($this) + 40|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($19 - $21);
 $23 = (__Z14GetTimeManagerv()|0);
 $24 = (($23) + 116|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($12 * $25);
 $27 = Math_fround($17 * $25);
 $28 = Math_fround($22 * $25);
 HEAPF32[$vel>>2] = $26;
 $29 = (($vel) + 4|0);
 HEAPF32[$29>>2] = $27;
 $30 = (($vel) + 8|0);
 HEAPF32[$30>>2] = $28;
 $31 = (__Z15GetAudioManagerv()|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $32 = (($2) + 4|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $33 = (($2) + 8|0);
 HEAPF32[$33>>2] = Math_fround(0.0);
 __ZNK9Transform18TransformDirectionERK8Vector3f($1,$8,$2);
 $34 = Math_fround(HEAPF32[$1>>2]);
 $35 = Math_fround($34 * $34);
 $36 = (($1) + 4|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * $37);
 $39 = Math_fround($35 + $38);
 $40 = (($1) + 8|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (Math_fround(Math_sqrt((Math_fround($43)))));
 $45 = Math_fround(HEAPF32[616648>>2]);
 $46 = $44 > $45;
 if ($46) {
  ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
  $47 = Math_fround(HEAPF32[$0>>2]);
  $48 = Math_fround($47 / $44);
  HEAPF32[$0>>2] = $48;
  $49 = (($0) + 4|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($50 / $44);
  HEAPF32[$49>>2] = $51;
  $52 = (($0) + 8|0);
  $53 = Math_fround(HEAPF32[$52>>2]);
  $54 = Math_fround($53 / $44);
  HEAPF32[$52>>2] = $54;
 } else {
  ;HEAP32[$0+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[616680+8>>2]|0;
 }
 HEAPF32[$5>>2] = Math_fround(0.0);
 $55 = (($5) + 4|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($5) + 8|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 __ZNK9Transform18TransformDirectionERK8Vector3f($4,$8,$5);
 $57 = Math_fround(HEAPF32[$4>>2]);
 $58 = Math_fround($57 * $57);
 $59 = (($4) + 4|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 * $60);
 $62 = Math_fround($58 + $61);
 $63 = (($4) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 * $64);
 $66 = Math_fround($62 + $65);
 $67 = (Math_fround(Math_sqrt((Math_fround($66)))));
 $68 = $67 > $45;
 if ($68) {
  ;HEAP32[$3+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$4+8>>2]|0;
  $69 = Math_fround(HEAPF32[$3>>2]);
  $70 = Math_fround($69 / $67);
  HEAPF32[$3>>2] = $70;
  $71 = (($3) + 4|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = Math_fround($72 / $67);
  HEAPF32[$71>>2] = $73;
  $74 = (($3) + 8|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($75 / $67);
  HEAPF32[$74>>2] = $76;
  __ZN12AudioManager14UpdateListenerERK8Vector3fS2_S2_S2_($31,$pos,$vel,$0,$3);
  ;HEAP32[$9+0>>2]=HEAP32[$pos+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$pos+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$pos+8>>2]|0;
  STACKTOP = sp;return;
 } else {
  ;HEAP32[$3+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[616680+8>>2]|0;
  __ZN12AudioManager14UpdateListenerERK8Vector3fS2_S2_S2_($31,$pos,$vel,$0,$3);
  ;HEAP32[$9+0>>2]=HEAP32[$pos+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$pos+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$pos+8>>2]|0;
  STACKTOP = sp;return;
 }
}
function __ZN13AudioListener6UpdateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (__Z15GetAudioManagerv()|0);
  $4 = (($this) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (__ZN12AudioManager22GetAutomaticUpdateModeEPN5Unity10GameObjectE($3,$5)|0);
  HEAP32[$0>>2] = $6;
  $8 = $6;
 } else {
  $8 = $1;
 }
 $7 = ($8|0)==(2);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 __ZN13AudioListener8DoUpdateEv($this);
 STACKTOP = sp;return;
}
function __ZN13AudioListener11FixedUpdateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (__Z15GetAudioManagerv()|0);
  $4 = (($this) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (__ZN12AudioManager22GetAutomaticUpdateModeEPN5Unity10GameObjectE($3,$5)|0);
  HEAP32[$0>>2] = $6;
  $8 = $6;
 } else {
  $8 = $1;
 }
 $7 = ($8|0)==(1);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 __ZN13AudioListener8DoUpdateEv($this);
 STACKTOP = sp;return;
}
function __ZN13AudioListener15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(81,564640,1984,0);
 STACKTOP = sp;return;
}
function __ZZN13AudioListener15InitializeClassEvEN42FunctorImpl_AudioListener_kDidAddComponent4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13AudioListener12ApplyFiltersEv($object);
 STACKTOP = sp;return;
}
function __ZN13AudioListener12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z27RegisterClass_AudioListenerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(81,215,216,0,217);
 STACKTOP = sp;return;
}
function __ZN13AudioListener13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(180)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN14AudioBehaviour13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 13;
 dest=$3+0|0; src=703632+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 13|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,81,180,($0|0),64,(2563|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN13AudioListener7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(64,$$byval_copy2,1,16,703464,16)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1985,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((702984 + 8|0));
  $6 = (($3) + 32|0);
  $7 = (($3) + 60|0);
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;HEAP32[$6+24>>2]=0|0;
  HEAP32[$7>>2] = $3;
  STACKTOP = sp;return ($3|0);
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(703464|0),16);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  ___resumeException($8|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK13AudioListener25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 81;
}
function __ZN13AudioListener23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,703648,703632,$this,0);
 __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13AudioListener23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,703648,703632,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13AudioListener23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13AudioListener23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13AudioListener23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13AudioListener23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13AudioListenerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((692632 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __ZN9BehaviourD2Ev($this);
  STACKTOP = sp;return;
 }
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch(0|0)|0;
  $7 = tempRet0;
  ___clang_call_terminate($6);
  // unreachable;
 } else {
  ___resumeException($2|0);
  // unreachable;
 }
}
function __ZN13AudioListenerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((692632 + 8|0));
 __THREW__ = 0;
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3410,($this|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch(0|0)|0;
   $7 = tempRet0;
   ___clang_call_terminate($6);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $3;$eh$lpad$body$indexZ2D = $2;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
 __ZdlPv($this);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN18AudioLowPassFilter26GetCustomLowpassLevelCurveEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12AudioManager14systemCallbackEP11FMOD_SYSTEM24FMOD_SYSTEM_CALLBACKTYPEPvS3_($c_system,$type,$data1,$data2) {
 $c_system = $c_system|0;
 $type = $type|0;
 $data1 = $data1|0;
 $data2 = $data2|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $numDrivers = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $numDrivers = sp + 16|0;
 $0 = sp + 4|0;
 $cond = ($type|0)==(0);
 if (!($cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN4FMOD6System13getNumDriversEPi($c_system,$numDrivers)|0);
 $2 = ($1|0)!=(0);
 $3 = HEAP32[$numDrivers>>2]|0;
 $4 = ($3|0)==(0);
 $or$cond = $2 | $4;
 if ($or$cond) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__ZN4FMOD6System9setDriverEi($c_system,0)|0);
 do {
  switch ($5|0) {
  case 5:  {
   $$0$i = 704416;
   break;
  }
  case 3:  {
   $$0$i = 704304;
   break;
  }
  case 7:  {
   $$0$i = 704496;
   break;
  }
  case 10:  {
   $$0$i = 704608;
   break;
  }
  case 12:  {
   $$0$i = 704712;
   break;
  }
  case 13:  {
   $$0$i = 704864;
   break;
  }
  case 14:  {
   $$0$i = 704920;
   break;
  }
  case 11:  {
   $$0$i = 704648;
   break;
  }
  case 2:  {
   $$0$i = 704168;
   break;
  }
  case 6:  {
   $$0$i = 704456;
   break;
  }
  case 8:  {
   $$0$i = 704528;
   break;
  }
  case 9:  {
   $$0$i = 704576;
   break;
  }
  case 4:  {
   $$0$i = 704352;
   break;
  }
  case 91:  {
   $$0$i = 705776;
   break;
  }
  case 85:  {
   $$0$i = 705880;
   break;
  }
  case 90:  {
   $$0$i = 706272;
   break;
  }
  case 89:  {
   $$0$i = 706360;
   break;
  }
  case 15:  {
   $$0$i = 705064;
   break;
  }
  case 83:  {
   $$0$i = 705664;
   break;
  }
  case 86:  {
   $$0$i = 705952;
   break;
  }
  case 19:  {
   $$0$i = 706448;
   break;
  }
  case 20:  {
   $$0$i = 706472;
   break;
  }
  case 17:  {
   $$0$i = 705232;
   break;
  }
  case 84:  {
   $$0$i = 705824;
   break;
  }
  case 18:  {
   $$0$i = 705424;
   break;
  }
  case 88:  {
   $$0$i = 706224;
   break;
  }
  case 87:  {
   $$0$i = 706056;
   break;
  }
  case 16:  {
   $$0$i = 705168;
   break;
  }
  case 92:  {
   $$0$i = 705528;
   break;
  }
  case 31:  {
   $$0$i = 707112;
   break;
  }
  case 35:  {
   $$0$i = 707392;
   break;
  }
  case 34:  {
   $$0$i = 707288;
   break;
  }
  case 38:  {
   $$0$i = 707544;
   break;
  }
  case 37:  {
   $$0$i = 707488;
   break;
  }
  case 39:  {
   $$0$i = 707600;
   break;
  }
  case 40:  {
   $$0$i = 707688;
   break;
  }
  case 24:  {
   $$0$i = 706744;
   break;
  }
  case 21:  {
   $$0$i = 706584;
   break;
  }
  case 29:  {
   $$0$i = 707048;
   break;
  }
  case 27:  {
   $$0$i = 706904;
   break;
  }
  case 36:  {
   $$0$i = 707448;
   break;
  }
  case 32:  {
   $$0$i = 707176;
   break;
  }
  case 41:  {
   $$0$i = 707744;
   break;
  }
  case 28:  {
   $$0$i = 706976;
   break;
  }
  case 42:  {
   $$0$i = 707808;
   break;
  }
  case 33:  {
   $$0$i = 707224;
   break;
  }
  case 25:  {
   $$0$i = 706776;
   break;
  }
  case 30:  {
   $$0$i = 707080;
   break;
  }
  case 22:  {
   $$0$i = 706624;
   break;
  }
  case 23:  {
   $$0$i = 706720;
   break;
  }
  case 26:  {
   $$0$i = 706816;
   break;
  }
  case 95:  {
   $$0$i = 708104;
   break;
  }
  case 46:  {
   $$0$i = 708296;
   break;
  }
  case 48:  {
   $$0$i = 708456;
   break;
  }
  case 53:  {
   $$0$i = 708968;
   break;
  }
  case 54:  {
   $$0$i = 709040;
   break;
  }
  case 93:  {
   $$0$i = 708216;
   break;
  }
  case 52:  {
   $$0$i = 708920;
   break;
  }
  case 94:  {
   $$0$i = 708168;
   break;
  }
  case 49:  {
   $$0$i = 708584;
   break;
  }
  case 55:  {
   $$0$i = 709128;
   break;
  }
  case 57:  {
   $$0$i = 709288;
   break;
  }
  case 44:  {
   $$0$i = 707920;
   break;
  }
  case 51:  {
   $$0$i = 708824;
   break;
  }
  case 47:  {
   $$0$i = 708376;
   break;
  }
  case 58:  {
   $$0$i = 709424;
   break;
  }
  case 43:  {
   $$0$i = 707880;
   break;
  }
  case 50:  {
   $$0$i = 708776;
   break;
  }
  case 56:  {
   $$0$i = 709248;
   break;
  }
  case 45:  {
   $$0$i = 708048;
   break;
  }
  case 77:  {
   $$0$i = 711440;
   break;
  }
  case 71:  {
   $$0$i = 710536;
   break;
  }
  case 68:  {
   $$0$i = 710240;
   break;
  }
  case 59:  {
   $$0$i = 709544;
   break;
  }
  case 70:  {
   $$0$i = 710472;
   break;
  }
  case 66:  {
   $$0$i = 710080;
   break;
  }
  case 72:  {
   $$0$i = 710968;
   break;
  }
  case 65:  {
   $$0$i = 710016;
   break;
  }
  case 67:  {
   $$0$i = 710144;
   break;
  }
  case 78:  {
   $$0$i = 711592;
   break;
  }
  case 62:  {
   $$0$i = 709792;
   break;
  }
  case 74:  {
   $$0$i = 711240;
   break;
  }
  case 79:  {
   $$0$i = 711672;
   break;
  }
  case 61:  {
   $$0$i = 709688;
   break;
  }
  case 63:  {
   $$0$i = 709888;
   break;
  }
  case 64:  {
   $$0$i = 709944;
   break;
  }
  case 69:  {
   $$0$i = 710360;
   break;
  }
  case 60:  {
   $$0$i = 709648;
   break;
  }
  case 75:  {
   $$0$i = 710680;
   break;
  }
  case 73:  {
   $$0$i = 711120;
   break;
  }
  case 76:  {
   $$0$i = 711376;
   break;
  }
  case 80:  {
   $$0$i = 711752;
   break;
  }
  case 82:  {
   $$0$i = 711912;
   break;
  }
  case 1:  {
   $$0$i = 704104;
   break;
  }
  case 81:  {
   $$0$i = 711864;
   break;
  }
  case 0:  {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  default: {
   $$0$i = 711976;
  }
  }
 } while(0);
 HEAP32[$vararg_buffer>>2] = $$0$i;
 __Z6FormatPKcz($0,703656,$vararg_buffer);
 $6 = HEAP8[$0>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $11 = (($0) + 1|0);
  $12 = $11;
 } else {
  $9 = (($0) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $12 = $10;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($12|0),0,(704096|0),26,1,0,0,(0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $22 = HEAP8[$0>>0]|0;
  $23 = $22 & 1;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   ___resumeException($20|0);
   // unreachable;
  }
  $25 = (($0) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  __ZdlPv($26);
  ___resumeException($20|0);
  // unreachable;
 } else {
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
  $18 = (($0) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  __ZdlPv($19);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z15FMODMemoryAllocjjPKc($size,$type,$sourcestr) {
 $size = $size|0;
 $type = $type|0;
 $sourcestr = $sourcestr|0;
 var $$byval_copy = 0, $$in$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = $type & 65535;
 if ((($1|0) == 4)) {
  $$in$i = 628328;
 } else if ((($1|0) == 2) | (($1|0) == 1)) {
  $$in$i = 628320;
 } else if ((($1|0) == 8)) {
  $$in$i = 628336;
 } else {
  $$in$i = 628312;
 }
 $2 = HEAP32[$$in$i>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Z15malloc_internaljj10MemLabelIdiPKci($size,16,$$byval_copy,0,711992,175)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z17FMODMemoryReallocPvjjPKc($ptr,$size,$type,$sourcestr) {
 $ptr = $ptr|0;
 $size = $size|0;
 $type = $type|0;
 $sourcestr = $sourcestr|0;
 var $$byval_copy = 0, $$in$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = $type & 65535;
 if ((($1|0) == 4)) {
  $$in$i = 628328;
 } else if ((($1|0) == 2) | (($1|0) == 1)) {
  $$in$i = 628320;
 } else if ((($1|0) == 8)) {
  $$in$i = 628336;
 } else {
  $$in$i = 628312;
 }
 $2 = HEAP32[$$in$i>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Z16realloc_internalPvji10MemLabelIdiPKci($ptr,$size,16,$$byval_copy,0,711992,229)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z14FMODMemoryFreePvjPKc($ptr,$type,$sourcestr) {
 $ptr = $ptr|0;
 $type = $type|0;
 $sourcestr = $sourcestr|0;
 var $$byval_copy = 0, $$in$i = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = $type & 65535;
 if ((($1|0) == 4)) {
  $$in$i = 628328;
 } else if ((($1|0) == 2) | (($1|0) == 1)) {
  $$in$i = 628320;
 } else if ((($1|0) == 8)) {
  $$in$i = 628336;
 } else {
  $$in$i = 628312;
 }
 $2 = HEAP32[$$in$i>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($ptr,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z14FMOD_FILE_OpenPKciPjPPvS3_($name,$unicode,$filesize,$handle,$userdata) {
 $name = $name|0;
 $unicode = $unicode|0;
 $filesize = $filesize|0;
 $handle = $handle|0;
 $userdata = $userdata|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $$byval_copy14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $entry = 0, $or$cond$i = 0, $resource = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1152|0;
 $$byval_copy14 = sp + 1136|0;
 $0 = sp + 1132|0;
 $1 = sp + 1128|0;
 $2 = sp + 1124|0;
 $3 = sp + 1120|0;
 $4 = sp + 1108|0;
 $resource = sp;
 $5 = sp + 1080|0;
 $entry = sp + 24|0;
 $6 = sp + 1084|0;
 $7 = sp + 1096|0;
 ;HEAP32[$resource+0>>2]=0|0;HEAP32[$resource+4>>2]=0|0;HEAP32[$resource+8>>2]=0|0;
 $8 = (($resource) + 16|0);
 $9 = $8;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = 0;
 $13 = (_strchr($name,58)|0);
 $14 = (_strrchr($name,58)|0);
 $15 = ($13|0)==(0|0);
 $16 = ($13|0)==($14|0);
 $or$cond$i = $15 | $16;
 L1: do {
  if ($or$cond$i) {
   $17 = (_strlen(($name|0))|0);
   $18 = ($17>>>0)>(2147483631);
   if ($18) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 23;
     break;
    }
    // unreachable;
   }
   $21 = ($17>>>0)<(11);
   if ($21) {
    $22 = $17 << 1;
    $23 = $22&255;
    HEAP8[$4>>0] = $23;
    $24 = (($4) + 1|0);
    $__p$0$i$i$i$i$i = $24;
   } else {
    $25 = (($17) + 16)|0;
    $26 = $25 & -16;
    HEAP32[$3>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
    $27 = (invoke_iiiiiii(102,($26|0),16,($$byval_copy14|0),0,(711992|0),79)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 23;
     break;
    }
    $30 = (($4) + 8|0);
    HEAP32[$30>>2] = $27;
    $31 = $26 | 1;
    HEAP32[$4>>2] = $31;
    $32 = (($4) + 4|0);
    HEAP32[$32>>2] = $17;
    $__p$0$i$i$i$i$i = $27;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($name|0),($17|0))|0;
   $33 = (($__p$0$i$i$i$i$i) + ($17)|0);
   HEAP8[$33>>0] = 0;
   __THREW__ = 0;
   (invoke_iii(2359,($resource|0),($4|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $45 = ___cxa_find_matching_catch()|0;
    $46 = tempRet0;
    $47 = HEAP8[$4>>0]|0;
    $48 = $47 & 1;
    $49 = ($48<<24>>24)==(0);
    if ($49) {
     $eh$lpad$body$index3Z2D = $46;$eh$lpad$body$indexZ2D = $45;
     label = 24;
     break;
    }
    $50 = (($4) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($51|0),($$byval_copy14|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if (!($53)) {
     $eh$lpad$body$index3Z2D = $46;$eh$lpad$body$indexZ2D = $45;
     label = 24;
     break;
    }
    $54 = ___cxa_find_matching_catch()|0;
    $55 = tempRet0;
    ___cxa_call_unexpected(($54|0));
    // unreachable;
   }
   $36 = HEAP8[$4>>0]|0;
   $37 = $36 & 1;
   $38 = ($37<<24>>24)==(0);
   if (!($38)) {
    $39 = (($4) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($40|0),($$byval_copy14|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     $43 = ___cxa_find_matching_catch()|0;
     $44 = tempRet0;
     ___cxa_call_unexpected(($43|0));
     // unreachable;
    }
   }
   $78 = $8;
   $79 = $78;
   HEAP32[$79>>2] = 0;
   $80 = (($78) + 4)|0;
   $81 = $80;
   HEAP32[$81>>2] = 0;
   $$14 = 33;
   label = 65;
  } else {
   $56 = (($13) + 1|0);
   $57 = $14;
   $58 = $13;
   $59 = (($57) - ($58))|0;
   $60 = (($59) + -1)|0;
   $61 = ($60>>>0)>(10);
   do {
    if ($61) {
     $70 = (($59) + -11)|0;
     __THREW__ = 0;
     invoke_viiiiiiii(22,($resource|0),10,($70|0),0,0,0,($60|0),($56|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      label = 23;
      break L1;
     }
    } else {
     $62 = (($resource) + 1|0);
     _memmove(($62|0),($56|0),($60|0))|0;
     $63 = ((($resource) + ($60)|0) + 1|0);
     HEAP8[$63>>0] = 0;
     $64 = HEAP8[$resource>>0]|0;
     $65 = $64 & 1;
     $66 = ($65<<24>>24)==(0);
     if ($66) {
      $68 = $60 << 1;
      $69 = $68&255;
      HEAP8[$resource>>0] = $69;
      break;
     } else {
      $67 = (($resource) + 4|0);
      HEAP32[$67>>2] = $60;
      break;
     }
    }
   } while(0);
   $73 = (($14) + 1|0);
   __THREW__ = 0;
   $74 = (invoke_ii(3380,($73|0))|0);
   $75 = tempRet0;
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 23;
   } else {
    $84 = $8;
    $85 = $84;
    HEAP32[$85>>2] = $74;
    $86 = (($84) + 4)|0;
    $87 = $86;
    HEAP32[$87>>2] = $75;
    $88 = HEAP32[628304>>2]|0;
    HEAP32[$5>>2] = $88;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
    $89 = (invoke_iiiiiii(103,1080,($$byval_copy14|0),0,16,(711992|0),280)|0);
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if ($91) {
     label = 23;
    } else {
     __THREW__ = 0;
     invoke_vi(3584,($89|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      $95 = ___cxa_find_matching_catch()|0;
      $96 = tempRet0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_viiiiii(97,($89|0),($$byval_copy14|0),0,16,(711992|0),280);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       $216 = ___cxa_find_matching_catch(0|0)|0;
       $217 = tempRet0;
       ___clang_call_terminate($216);
       // unreachable;
      } else {
       $$1 = $96;$$12 = $95;
       break;
      }
     }
     $94 = ($89|0)==(0|0);
     if ($94) {
      $$14 = 43;
      label = 65;
     } else {
      $99 = HEAP8[$resource>>0]|0;
      $100 = $99 & 1;
      $101 = ($100<<24>>24)==(0);
      if ($101) {
       $102 = (($resource) + 1|0);
       $103 = $99&255;
       $104 = $103 >>> 1;
       $113 = $104;$125 = $102;
      } else {
       $105 = (($resource) + 8|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = (($resource) + 4|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ($108>>>0)>(4294967279);
       if ($109) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         label = 23;
         break;
        }
        // unreachable;
       } else {
        $113 = $108;$125 = $106;
       }
      }
      $112 = ($113>>>0)<(11);
      if ($112) {
       $114 = $113 << 1;
       $115 = $114&255;
       HEAP8[$7>>0] = $115;
       $116 = (($7) + 1|0);
       $__p$0$i$i$i$i = $116;
      } else {
       $117 = (($113) + 16)|0;
       $118 = $117 & -16;
       __THREW__ = 0;
       $119 = (invoke_ii(2988,($118|0))|0);
       $120 = __THREW__; __THREW__ = 0;
       $121 = $120&1;
       if ($121) {
        label = 23;
        break;
       }
       $122 = (($7) + 8|0);
       HEAP32[$122>>2] = $119;
       $123 = $118 | 1;
       HEAP32[$7>>2] = $123;
       $124 = (($7) + 4|0);
       HEAP32[$124>>2] = $113;
       $__p$0$i$i$i$i = $119;
      }
      _memcpy(($__p$0$i$i$i$i|0),($125|0),($113|0))|0;
      $126 = (($__p$0$i$i$i$i) + ($113)|0);
      HEAP8[$126>>0] = 0;
      __THREW__ = 0;
      invoke_vii(3226,($6|0),($7|0));
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      do {
       if ($128) {
        $156 = ___cxa_find_matching_catch()|0;
        $157 = tempRet0;
        $$0 = $157;$$01 = $156;
       } else {
        $129 = HEAP8[$6>>0]|0;
        $130 = $129 & 1;
        $131 = ($130<<24>>24)==(0);
        if ($131) {
         $134 = (($6) + 1|0);
         $135 = $134;
        } else {
         $132 = (($6) + 8|0);
         $133 = HEAP32[$132>>2]|0;
         $135 = $133;
        }
        __THREW__ = 0;
        invoke_vii(3227,($entry|0),($135|0));
        $136 = __THREW__; __THREW__ = 0;
        $137 = $136&1;
        if ($137) {
         $158 = ___cxa_find_matching_catch()|0;
         $159 = tempRet0;
         $160 = HEAP8[$6>>0]|0;
         $161 = $160 & 1;
         $162 = ($161<<24>>24)==(0);
         if ($162) {
          $$0 = $159;$$01 = $158;
          break;
         }
         $163 = (($6) + 8|0);
         $164 = HEAP32[$163>>2]|0;
         __ZdlPv($164);
         $$0 = $159;$$01 = $158;
         break;
        }
        $138 = HEAP8[$6>>0]|0;
        $139 = $138 & 1;
        $140 = ($139<<24>>24)==(0);
        if (!($140)) {
         $141 = (($6) + 8|0);
         $142 = HEAP32[$141>>2]|0;
         __ZdlPv($142);
        }
        $143 = HEAP8[$7>>0]|0;
        $144 = $143 & 1;
        $145 = ($144<<24>>24)==(0);
        if (!($145)) {
         $146 = (($7) + 8|0);
         $147 = HEAP32[$146>>2]|0;
         __ZdlPv($147);
        }
        __THREW__ = 0;
        $148 = (invoke_iiiii(252,($89|0),($entry|0),0,0)|0);
        $149 = __THREW__; __THREW__ = 0;
        $150 = $149&1;
        L46: do {
         if (!($150)) {
          do {
           if ($148) {
            $174 = $8;
            $175 = $174;
            $176 = HEAP32[$175>>2]|0;
            $177 = (($174) + 4)|0;
            $178 = $177;
            $179 = HEAP32[$178>>2]|0;
            $180 = (($89) + 1064|0);
            $181 = $180;
            $182 = $181;
            HEAP32[$182>>2] = $176;
            $183 = (($181) + 4)|0;
            $184 = $183;
            HEAP32[$184>>2] = $179;
            $185 = (($89) + 1072|0);
            $186 = $185;
            $187 = $186;
            HEAP32[$187>>2] = 0;
            $188 = (($186) + 4)|0;
            $189 = $188;
            HEAP32[$189>>2] = 0;
            $190 = ($filesize|0)==(0|0);
            if (!($190)) {
             __THREW__ = 0;
             $191 = (invoke_ii(3306,($entry|0))|0);
             $192 = tempRet0;
             $193 = __THREW__; __THREW__ = 0;
             $194 = $193&1;
             if ($194) {
              break L46;
             }
             HEAP32[$filesize>>2] = $191;
            }
            $195 = ($handle|0)==(0|0);
            if ($195) {
             $$03 = 0;
             break;
            }
            HEAP32[$handle>>2] = $89;
            $$03 = 0;
           } else {
            $151 = HEAP32[628304>>2]|0;
            __THREW__ = 0;
            invoke_vi(1174,($89|0));
            $152 = __THREW__; __THREW__ = 0;
            $153 = $152&1;
            if ($153) {
             break L46;
            }
            HEAP32[$1>>2] = $151;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
            invoke_vii(2591,($89|0),($$byval_copy14|0));
            $154 = __THREW__; __THREW__ = 0;
            $155 = $154&1;
            if ($155) {
             break L46;
            } else {
             $$03 = 23;
            }
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3572,($entry|0));
          $196 = __THREW__; __THREW__ = 0;
          $197 = $196&1;
          if ($197) {
           label = 23;
           break L1;
          } else {
           $$14 = $$03;
           label = 65;
           break L1;
          }
         }
        } while(0);
        $170 = ___cxa_find_matching_catch()|0;
        $171 = tempRet0;
        __THREW__ = 0;
        invoke_vi(3572,($entry|0));
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         $216 = ___cxa_find_matching_catch(0|0)|0;
         $217 = tempRet0;
         ___clang_call_terminate($216);
         // unreachable;
        } else {
         $$1 = $171;$$12 = $170;
         break L1;
        }
       }
      } while(0);
      $165 = HEAP8[$7>>0]|0;
      $166 = $165 & 1;
      $167 = ($166<<24>>24)==(0);
      if ($167) {
       $$1 = $$0;$$12 = $$01;
      } else {
       $168 = (($7) + 8|0);
       $169 = HEAP32[$168>>2]|0;
       __ZdlPv($169);
       $$1 = $$0;$$12 = $$01;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $82 = ___cxa_find_matching_catch()|0;
  $83 = tempRet0;
  $eh$lpad$body$index3Z2D = $83;$eh$lpad$body$indexZ2D = $82;
  label = 24;
 }
 else if ((label|0) == 65) {
  $198 = HEAP8[$resource>>0]|0;
  $199 = $198 & 1;
  $200 = ($199<<24>>24)==(0);
  if ($200) {
   STACKTOP = sp;return ($$14|0);
  }
  $201 = (($resource) + 8|0);
  $202 = HEAP32[$201>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($202|0),($$byval_copy14|0));
  $203 = __THREW__; __THREW__ = 0;
  $204 = $203&1;
  if ($204) {
   $205 = ___cxa_find_matching_catch()|0;
   $206 = tempRet0;
   ___cxa_call_unexpected(($205|0));
   // unreachable;
  } else {
   STACKTOP = sp;return ($$14|0);
  }
 }
 if ((label|0) == 24) {
  $$1 = $eh$lpad$body$index3Z2D;$$12 = $eh$lpad$body$indexZ2D;
 }
 $207 = HEAP8[$resource>>0]|0;
 $208 = $207 & 1;
 $209 = ($208<<24>>24)==(0);
 if ($209) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $210 = (($resource) + 8|0);
 $211 = HEAP32[$210>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($211|0),($$byval_copy14|0));
 $212 = __THREW__; __THREW__ = 0;
 $213 = $212&1;
 if ($213) {
  $214 = ___cxa_find_matching_catch()|0;
  $215 = tempRet0;
  ___cxa_call_unexpected(($214|0));
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
 return 0|0;
}
function __Z15FMOD_FILE_ClosePvS_($handle,$userdata) {
 $handle = $handle|0;
 $userdata = $userdata|0;
 var $$ = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $result$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($handle|0)==(0|0);
 if ($1) {
  $2 = HEAP32[628304>>2]|0;
  $5 = $2;$6 = $0;$result$04 = 19;
 } else {
  $3 = (__ZN12FileAccessor5CloseEv($handle)|0);
  $4 = HEAP32[628304>>2]|0;
  $$ = $3 ? 0 : 19;
  __ZN12FileAccessorD2Ev($handle);
  $5 = $4;$6 = $0;$result$04 = $$;
 }
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($handle,$$byval_copy);
 STACKTOP = sp;return ($result$04|0);
}
function __Z14FMOD_FILE_ReadPvS_jPjS_($handle,$buffer,$sizebytes,$bytesread,$userdata) {
 $handle = $handle|0;
 $buffer = $buffer|0;
 $sizebytes = $sizebytes|0;
 $bytesread = $bytesread|0;
 $userdata = $userdata|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $actual = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $actual = sp;
 $0 = ($handle|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = $actual;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($handle) + 1064|0);
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($handle) + 1072|0);
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (_i64Add(($15|0),($18|0),($8|0),($11|0))|0);
 $20 = tempRet0;
 $21 = (__ZN12FileAccessor4ReadEyyPvPy($handle,$19,$20,$sizebytes,0,$buffer,$actual)|0);
 if (!($21)) {
  $$0 = 19;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = ($bytesread|0)==(0|0);
 $23 = $actual;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 if (!($22)) {
  HEAP32[$bytesread>>2] = $25;
 }
 $29 = $12;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (_i64Add(($31|0),($34|0),($25|0),($28|0))|0);
 $36 = tempRet0;
 $37 = $12;
 $38 = $37;
 HEAP32[$38>>2] = $35;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 $41 = ($28>>>0)<(0);
 $42 = ($28|0)==(0);
 $43 = ($25>>>0)<($sizebytes>>>0);
 $44 = $42 & $43;
 $45 = $41 | $44;
 $$ = $45 ? 22 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __Z14FMOD_FILE_SeekPvjS_($handle,$pos,$userdata) {
 $handle = $handle|0;
 $pos = $pos|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($handle|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($handle) + 1072|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = $pos;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __Z32AudioMeasurement_GetTimeConstantff($accuracy,$numSamples) {
 $accuracy = Math_fround($accuracy);
 $numSamples = Math_fround($numSamples);
 var $$0 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = !($numSamples <= Math_fround(0.0));
 if (!($0)) {
  $$0 = Math_fround(1.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $1 = Math_fround(Math_fround(1.0) - $accuracy);
 $2 = Math_fround(Math_fround(1.0) / $numSamples);
 $3 = (Math_fround(+(_log2f((+$1)))));
 $4 = Math_fround($2 * $3);
 $5 = (Math_fround(+(_exp2f((+$4)))));
 $6 = Math_fround(Math_fround(1.0) - $5);
 $$0 = $6;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN12AudioManager15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12AudioManager12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12AudioManager17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $node$01$i = 0, $node$01$i1 = 0, $node$01$i3 = 0, $node$01$i5 = 0, $node$01$i7 = 0, $node$01$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if (!($3)) {
  $node$01$i = $2;
  while(1) {
   $4 = (($node$01$i) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   HEAP32[$node$01$i>>2] = 0;
   HEAP32[$4>>2] = 0;
   $6 = ($5|0)==($0|0);
   if ($6) {
    break;
   } else {
    $node$01$i = $5;
   }
  }
 }
 HEAP32[$1>>2] = $0;
 HEAP32[$0>>2] = $0;
 $7 = (($this) + 40|0);
 $8 = (($this) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($7|0);
 if (!($10)) {
  $node$01$i1 = $9;
  while(1) {
   $11 = (($node$01$i1) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$node$01$i1>>2] = 0;
   HEAP32[$11>>2] = 0;
   $13 = ($12|0)==($7|0);
   if ($13) {
    break;
   } else {
    $node$01$i1 = $12;
   }
  }
 }
 HEAP32[$8>>2] = $7;
 HEAP32[$7>>2] = $7;
 $14 = (($this) + 48|0);
 $15 = (($this) + 52|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==($14|0);
 if (!($17)) {
  $node$01$i9 = $16;
  while(1) {
   $18 = (($node$01$i9) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$node$01$i9>>2] = 0;
   HEAP32[$18>>2] = 0;
   $20 = ($19|0)==($14|0);
   if ($20) {
    break;
   } else {
    $node$01$i9 = $19;
   }
  }
 }
 HEAP32[$15>>2] = $14;
 HEAP32[$14>>2] = $14;
 $21 = (($this) + 56|0);
 $22 = (($this) + 60|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==($21|0);
 if (!($24)) {
  $node$01$i7 = $23;
  while(1) {
   $25 = (($node$01$i7) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   HEAP32[$node$01$i7>>2] = 0;
   HEAP32[$25>>2] = 0;
   $27 = ($26|0)==($21|0);
   if ($27) {
    break;
   } else {
    $node$01$i7 = $26;
   }
  }
 }
 HEAP32[$22>>2] = $21;
 HEAP32[$21>>2] = $21;
 $28 = (($this) + 64|0);
 $29 = (($this) + 68|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==($28|0);
 if (!($31)) {
  $node$01$i5 = $30;
  while(1) {
   $32 = (($node$01$i5) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   HEAP32[$node$01$i5>>2] = 0;
   HEAP32[$32>>2] = 0;
   $34 = ($33|0)==($28|0);
   if ($34) {
    break;
   } else {
    $node$01$i5 = $33;
   }
  }
 }
 HEAP32[$29>>2] = $28;
 HEAP32[$28>>2] = $28;
 $35 = (($this) + 72|0);
 $36 = (($this) + 76|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($35|0);
 if (!($38)) {
  $node$01$i3 = $37;
  while(1) {
   $39 = (($node$01$i3) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   HEAP32[$node$01$i3>>2] = 0;
   HEAP32[$39>>2] = 0;
   $41 = ($40|0)==($35|0);
   if ($41) {
    break;
   } else {
    $node$01$i3 = $40;
   }
  }
 }
 HEAP32[$36>>2] = $35;
 HEAP32[$35>>2] = $35;
 __ZN12AudioManager9CloseFMODEv($this);
 $42 = (($this) + 92|0);
 $43 = HEAP32[$42>>2]|0;
 (__ZN4FMOD6System7releaseEv($43)|0);
 HEAP32[$42>>2] = 0;
 $44 = (($this) + 208|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if ($46) {
  __ZN11GameManager17MainThreadCleanupEv($this);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  __ZdlPv($45);
  ___resumeException($49|0);
  // unreachable;
 }
 __ZdlPv($45);
 HEAP32[$44>>2] = 0;
 __ZN11GameManager17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN12AudioManager9CloseFMODEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$154 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i13 = 0, $__new_last2$i$i$i$i$i20 = 0;
 var $__new_last2$i$i$i$i$i27 = 0, $__new_last2$i$i$i$i$i43 = 0, $__new_last2$i$i$i$i$i52 = 0, $__new_last2$i$i$i$i$i6 = 0, $__new_last2$i$i$i$i$i61 = 0, $__new_last2$i$i$i$i$i70 = 0, $__new_last2$i$i$i$i$i79 = 0, $__new_last2$i$i$i$i$i88 = 0, $__new_last2$i$i$i$i$i99 = 0, $audioClips = 0, $audioListeners = 0, $audioMixers = 0, $audioReverbZones = 0, $audioSources = 0, $customFilter = 0, $eh$lpad$body$index6Z2D = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$index = 0, $lpad$phi$index35 = 0, $lpad$phi121$index = 0;
 var $lpad$phi121$index30 = 0, $lpad$phi128$index = 0, $lpad$phi128$index25 = 0, $lpad$phi135$index = 0, $lpad$phi135$index20 = 0, $lpad$phi142$index = 0, $lpad$phi142$index15 = 0, $monoBehaviours = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i100 = 0, $scevgep$i$i$i$i$i14 = 0, $scevgep$i$i$i$i$i21 = 0, $scevgep$i$i$i$i$i28 = 0, $scevgep$i$i$i$i$i44 = 0, $scevgep$i$i$i$i$i53 = 0, $scevgep$i$i$i$i$i62 = 0, $scevgep$i$i$i$i$i7 = 0, $scevgep$i$i$i$i$i71 = 0, $scevgep$i$i$i$i$i80 = 0, $scevgep$i$i$i$i$i89 = 0;
 var $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i104 = 0, $scevgep4$i$i$i$i$i11 = 0, $scevgep4$i$i$i$i$i18 = 0, $scevgep4$i$i$i$i$i25 = 0, $scevgep4$i$i$i$i$i32 = 0, $scevgep4$i$i$i$i$i48 = 0, $scevgep4$i$i$i$i$i57 = 0, $scevgep4$i$i$i$i$i66 = 0, $scevgep4$i$i$i$i$i75 = 0, $scevgep4$i$i$i$i$i84 = 0, $scevgep4$i$i$i$i$i93 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i102 = 0, $uglygep$i$i$i$i$i16 = 0, $uglygep$i$i$i$i$i23 = 0, $uglygep$i$i$i$i$i30 = 0, $uglygep$i$i$i$i$i46 = 0, $uglygep$i$i$i$i$i55 = 0, $uglygep$i$i$i$i$i64 = 0;
 var $uglygep$i$i$i$i$i73 = 0, $uglygep$i$i$i$i$i82 = 0, $uglygep$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i91 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i10 = 0, $uglygep3$i$i$i$i$i103 = 0, $uglygep3$i$i$i$i$i17 = 0, $uglygep3$i$i$i$i$i24 = 0, $uglygep3$i$i$i$i$i31 = 0, $uglygep3$i$i$i$i$i47 = 0, $uglygep3$i$i$i$i$i56 = 0, $uglygep3$i$i$i$i$i65 = 0, $uglygep3$i$i$i$i$i74 = 0, $uglygep3$i$i$i$i$i83 = 0, $uglygep3$i$i$i$i$i92 = 0, $vararg_ptr39 = 0, $vararg_ptr40 = 0, $vararg_ptr41 = 0, $vararg_ptr45 = 0;
 var $vararg_ptr46 = 0, $vararg_ptr47 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp;
 $0 = sp + 112|0;
 $1 = sp + 100|0;
 $2 = sp + 88|0;
 $monoBehaviours = sp + 76|0;
 $customFilter = sp + 116|0;
 $audioSources = sp + 40|0;
 $audioListeners = sp + 28|0;
 $audioReverbZones = sp + 16|0;
 $audioMixers = sp + 52|0;
 $audioClips = sp + 64|0;
 $3 = (($this) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 HEAP32[$monoBehaviours>>2] = 0;
 $6 = (($monoBehaviours) + 4|0);
 HEAP32[$6>>2] = 0;
 $7 = (($monoBehaviours) + 8|0);
 HEAP32[$7>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,114,($monoBehaviours|0),0)|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L4: do {
  if ($9) {
   $73 = ___cxa_find_matching_catch()|0;
   $74 = tempRet0;
   $eh$lpad$body$index6Z2D = $74;$eh$lpad$body$indexZ2D = $73;
   label = 25;
  } else {
   $10 = HEAP32[$monoBehaviours>>2]|0;
   $11 = HEAP32[$6>>2]|0;
   $12 = ($10|0)==($11|0);
   L6: do {
    if (!($12)) {
     $13 = (($1) + 1|0);
     $14 = (($1) + 8|0);
     $15 = (($2) + 1|0);
     $16 = (($2) + 8|0);
     $18 = $10;
     L8: while(1) {
      $17 = HEAP32[$18>>2]|0;
      __THREW__ = 0;
      $19 = (invoke_ii(3381,($17|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       label = 23;
       break;
      }
      $22 = ($19|0)==(0|0);
      do {
       if (!($22)) {
        HEAP32[$customFilter>>2] = 0;
        __THREW__ = 0;
        $23 = (invoke_iii(2564,($19|0),($customFilter|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 23;
         break L8;
        }
        $26 = ($23|0)==(0);
        if (!($26)) {
         $27 = (__ZL16FMOD_ErrorString11FMOD_RESULT($23)|0);
         __THREW__ = 0;
         HEAP32[$$byval_copy>>2] = 712328;
         $vararg_ptr39 = (($$byval_copy) + 4|0);
         HEAP32[$vararg_ptr39>>2] = 1046;
         $vararg_ptr40 = (($$byval_copy) + 8|0);
         HEAP32[$vararg_ptr40>>2] = 713000;
         $vararg_ptr41 = (($$byval_copy) + 12|0);
         HEAP32[$vararg_ptr41>>2] = $27;
         invoke_viii(1617,($2|0),(713760|0),($$byval_copy|0));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          label = 23;
          break L8;
         }
         $30 = HEAP8[$2>>0]|0;
         $31 = $30 & 1;
         $32 = ($31<<24>>24)==(0);
         $33 = HEAP32[$16>>2]|0;
         $$ = $32 ? $15 : $33;
         __THREW__ = 0;
         invoke_viiiiiiii(21,($$|0),0,(711992|0),21,1,0,0,(0|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          label = 13;
          break L8;
         }
         $36 = HEAP8[$2>>0]|0;
         $37 = $36 & 1;
         $38 = ($37<<24>>24)==(0);
         if ($38) {
          break;
         }
         $39 = HEAP32[$16>>2]|0;
         __ZdlPv($39);
         break;
        }
        $46 = HEAP32[$customFilter>>2]|0;
        $47 = (($46) + 13|0);
        __THREW__ = 0;
        $48 = (invoke_iii(2565,($19|0),($47|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 23;
         break L8;
        }
        $51 = ($48|0)==(0);
        if (!($51)) {
         $52 = (__ZL16FMOD_ErrorString11FMOD_RESULT($48)|0);
         __THREW__ = 0;
         HEAP32[$$byval_copy>>2] = 712328;
         $vararg_ptr45 = (($$byval_copy) + 4|0);
         HEAP32[$vararg_ptr45>>2] = 1048;
         $vararg_ptr46 = (($$byval_copy) + 8|0);
         HEAP32[$vararg_ptr46>>2] = 713504;
         $vararg_ptr47 = (($$byval_copy) + 12|0);
         HEAP32[$vararg_ptr47>>2] = $52;
         invoke_viii(1617,($1|0),(713760|0),($$byval_copy|0));
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          label = 23;
          break L8;
         }
         $55 = HEAP8[$1>>0]|0;
         $56 = $55 & 1;
         $57 = ($56<<24>>24)==(0);
         $58 = HEAP32[$14>>2]|0;
         $$154 = $57 ? $13 : $58;
         __THREW__ = 0;
         invoke_viiiiiiii(21,($$154|0),0,(711992|0),21,1,0,0,(0|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
          break L8;
         }
         $61 = HEAP8[$1>>0]|0;
         $62 = $61 & 1;
         $63 = ($62<<24>>24)==(0);
         if (!($63)) {
          $64 = HEAP32[$14>>2]|0;
          __ZdlPv($64);
         }
        }
       }
      } while(0);
      $75 = (($18) + 4|0);
      $76 = HEAP32[$6>>2]|0;
      $77 = ($75|0)==($76|0);
      if ($77) {
       break L6;
      } else {
       $18 = $75;
      }
     }
     if ((label|0) == 13) {
      $40 = ___cxa_find_matching_catch()|0;
      $41 = tempRet0;
      $42 = HEAP8[$2>>0]|0;
      $43 = $42 & 1;
      $44 = ($43<<24>>24)==(0);
      if ($44) {
       $eh$lpad$body$index6Z2D = $41;$eh$lpad$body$indexZ2D = $40;
       label = 25;
       break L4;
      }
      $45 = HEAP32[$16>>2]|0;
      __ZdlPv($45);
      $eh$lpad$body$index6Z2D = $41;$eh$lpad$body$indexZ2D = $40;
      label = 25;
      break L4;
     }
     else if ((label|0) == 21) {
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      $67 = HEAP8[$1>>0]|0;
      $68 = $67 & 1;
      $69 = ($68<<24>>24)==(0);
      if ($69) {
       $eh$lpad$body$index6Z2D = $66;$eh$lpad$body$indexZ2D = $65;
       label = 25;
       break L4;
      }
      $70 = HEAP32[$14>>2]|0;
      __ZdlPv($70);
      $eh$lpad$body$index6Z2D = $66;$eh$lpad$body$indexZ2D = $65;
      label = 25;
      break L4;
     }
     else if ((label|0) == 23) {
      $71 = ___cxa_find_matching_catch()|0;
      $72 = tempRet0;
      $eh$lpad$body$index6Z2D = $72;$eh$lpad$body$indexZ2D = $71;
      label = 25;
      break L4;
     }
    }
   } while(0);
   HEAP32[$audioSources>>2] = 0;
   $78 = (($audioSources) + 4|0);
   HEAP32[$78>>2] = 0;
   $79 = (($audioSources) + 8|0);
   HEAP32[$79>>2] = 0;
   __THREW__ = 0;
   (invoke_iiii(1530,82,($audioSources|0),0)|0);
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   L33: do {
    if ($81) {
     $94 = ___cxa_find_matching_catch()|0;
     $95 = tempRet0;
     $lpad$phi142$index = $94;$lpad$phi142$index15 = $95;
     label = 33;
    } else {
     $82 = HEAP32[$audioSources>>2]|0;
     $83 = HEAP32[$78>>2]|0;
     $84 = ($82|0)==($83|0);
     L35: do {
      if (!($84)) {
       $86 = $82;
       while(1) {
        $85 = HEAP32[$86>>2]|0;
        __THREW__ = 0;
        invoke_vi(3647,($85|0));
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         break;
        }
        $89 = (($86) + 4|0);
        $90 = HEAP32[$78>>2]|0;
        $91 = ($89|0)==($90|0);
        if ($91) {
         break L35;
        } else {
         $86 = $89;
        }
       }
       $92 = ___cxa_find_matching_catch()|0;
       $93 = tempRet0;
       $lpad$phi142$index = $92;$lpad$phi142$index15 = $93;
       label = 33;
       break L33;
      }
     } while(0);
     HEAP32[$audioListeners>>2] = 0;
     $96 = (($audioListeners) + 4|0);
     HEAP32[$96>>2] = 0;
     $97 = (($audioListeners) + 8|0);
     HEAP32[$97>>2] = 0;
     __THREW__ = 0;
     (invoke_iiii(1530,81,($audioListeners|0),0)|0);
     $98 = __THREW__; __THREW__ = 0;
     $99 = $98&1;
     L41: do {
      if ($99) {
       $112 = ___cxa_find_matching_catch()|0;
       $113 = tempRet0;
       $lpad$phi135$index = $112;$lpad$phi135$index20 = $113;
       label = 40;
      } else {
       $100 = HEAP32[$audioListeners>>2]|0;
       $101 = HEAP32[$96>>2]|0;
       $102 = ($100|0)==($101|0);
       L43: do {
        if (!($102)) {
         $104 = $100;
         while(1) {
          $103 = HEAP32[$104>>2]|0;
          __THREW__ = 0;
          invoke_vi(3648,($103|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break;
          }
          $107 = (($104) + 4|0);
          $108 = HEAP32[$96>>2]|0;
          $109 = ($107|0)==($108|0);
          if ($109) {
           break L43;
          } else {
           $104 = $107;
          }
         }
         $110 = ___cxa_find_matching_catch()|0;
         $111 = tempRet0;
         $lpad$phi135$index = $110;$lpad$phi135$index20 = $111;
         label = 40;
         break L41;
        }
       } while(0);
       HEAP32[$audioReverbZones>>2] = 0;
       $114 = (($audioReverbZones) + 4|0);
       HEAP32[$114>>2] = 0;
       $115 = (($audioReverbZones) + 8|0);
       HEAP32[$115>>2] = 0;
       __THREW__ = 0;
       (invoke_iiii(1530,167,($audioReverbZones|0),0)|0);
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       L49: do {
        if ($117) {
         $130 = ___cxa_find_matching_catch()|0;
         $131 = tempRet0;
         $lpad$phi128$index = $130;$lpad$phi128$index25 = $131;
         label = 47;
        } else {
         $118 = HEAP32[$audioReverbZones>>2]|0;
         $119 = HEAP32[$114>>2]|0;
         $120 = ($118|0)==($119|0);
         L51: do {
          if (!($120)) {
           $122 = $118;
           while(1) {
            $121 = HEAP32[$122>>2]|0;
            __THREW__ = 0;
            invoke_vi(3649,($121|0));
            $123 = __THREW__; __THREW__ = 0;
            $124 = $123&1;
            if ($124) {
             break;
            }
            $125 = (($122) + 4|0);
            $126 = HEAP32[$114>>2]|0;
            $127 = ($125|0)==($126|0);
            if ($127) {
             break L51;
            } else {
             $122 = $125;
            }
           }
           $128 = ___cxa_find_matching_catch()|0;
           $129 = tempRet0;
           $lpad$phi128$index = $128;$lpad$phi128$index25 = $129;
           label = 47;
           break L49;
          }
         } while(0);
         HEAP32[$audioMixers>>2] = 0;
         $132 = (($audioMixers) + 4|0);
         HEAP32[$132>>2] = 0;
         $133 = (($audioMixers) + 8|0);
         HEAP32[$133>>2] = 0;
         __THREW__ = 0;
         (invoke_iiii(1530,240,($audioMixers|0),0)|0);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         L57: do {
          if ($135) {
           label = 53;
          } else {
           $136 = HEAP32[$audioMixers>>2]|0;
           $137 = HEAP32[$132>>2]|0;
           $138 = ($136|0)==($137|0);
           L59: do {
            if (!($138)) {
             $140 = $136;
             while(1) {
              $139 = HEAP32[$140>>2]|0;
              __THREW__ = 0;
              invoke_vi(3650,($139|0));
              $141 = __THREW__; __THREW__ = 0;
              $142 = $141&1;
              if ($142) {
               break;
              }
              $143 = (($140) + 4|0);
              $144 = HEAP32[$132>>2]|0;
              $145 = ($143|0)==($144|0);
              if ($145) {
               break L59;
              } else {
               $140 = $143;
              }
             }
             $146 = ___cxa_find_matching_catch()|0;
             $147 = tempRet0;
             $lpad$phi121$index = $146;$lpad$phi121$index30 = $147;
             label = 54;
             break L57;
            }
           } while(0);
           $150 = (($this) + 100|0);
           $151 = HEAP32[$150>>2]|0;
           $152 = ($151|0)==(0|0);
           if (!($152)) {
            __THREW__ = 0;
            (invoke_ii(3382,($151|0))|0);
            $153 = __THREW__; __THREW__ = 0;
            $154 = $153&1;
            if ($154) {
             label = 53;
             break;
            }
            HEAP32[$150>>2] = 0;
           }
           $155 = (($this) + 108|0);
           $156 = HEAP32[$155>>2]|0;
           $157 = ($156|0)==(0|0);
           if (!($157)) {
            __THREW__ = 0;
            (invoke_ii(3382,($156|0))|0);
            $158 = __THREW__; __THREW__ = 0;
            $159 = $158&1;
            if ($159) {
             label = 53;
             break;
            }
            HEAP32[$155>>2] = 0;
           }
           $160 = (($this) + 104|0);
           $161 = HEAP32[$160>>2]|0;
           $162 = ($161|0)==(0|0);
           if (!($162)) {
            __THREW__ = 0;
            (invoke_ii(3382,($161|0))|0);
            $163 = __THREW__; __THREW__ = 0;
            $164 = $163&1;
            if ($164) {
             label = 53;
             break;
            }
            HEAP32[$160>>2] = 0;
           }
           $165 = (($this) + 112|0);
           $166 = HEAP32[$165>>2]|0;
           $167 = ($166|0)==(0|0);
           if (!($167)) {
            __THREW__ = 0;
            (invoke_ii(3382,($166|0))|0);
            $168 = __THREW__; __THREW__ = 0;
            $169 = $168&1;
            if ($169) {
             label = 53;
             break;
            }
            HEAP32[$165>>2] = 0;
           }
           $170 = (($this) + 96|0);
           HEAP32[$170>>2] = 0;
           HEAP32[$audioClips>>2] = 0;
           $171 = (($audioClips) + 4|0);
           HEAP32[$171>>2] = 0;
           $172 = (($audioClips) + 8|0);
           HEAP32[$172>>2] = 0;
           __THREW__ = 0;
           (invoke_iiii(1530,83,($audioClips|0),0)|0);
           $173 = __THREW__; __THREW__ = 0;
           $174 = $173&1;
           L81: do {
            if ($174) {
             label = 72;
            } else {
             $175 = HEAP32[$audioClips>>2]|0;
             $176 = HEAP32[$171>>2]|0;
             $177 = ($175|0)==($176|0);
             L83: do {
              if (!($177)) {
               $179 = $175;
               while(1) {
                $178 = HEAP32[$179>>2]|0;
                __THREW__ = 0;
                invoke_vi(3651,($178|0));
                $180 = __THREW__; __THREW__ = 0;
                $181 = $180&1;
                if ($181) {
                 break;
                }
                $182 = (($179) + 4|0);
                $183 = HEAP32[$171>>2]|0;
                $184 = ($182|0)==($183|0);
                if ($184) {
                 break L83;
                } else {
                 $179 = $182;
                }
               }
               $185 = ___cxa_find_matching_catch()|0;
               $186 = tempRet0;
               $lpad$phi$index = $185;$lpad$phi$index35 = $186;
               break L81;
              }
             } while(0);
             $196 = (($this) + 200|0);
             $197 = HEAP32[$196>>2]|0;
             $198 = ($197|0)==(0|0);
             if (!($198)) {
              $199 = HEAP32[628304>>2]|0;
              __THREW__ = 0;
              invoke_vi(3652,($197|0));
              $200 = __THREW__; __THREW__ = 0;
              $201 = $200&1;
              if ($201) {
               label = 72;
               break;
              }
              HEAP32[$0>>2] = $199;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
              invoke_vii(2591,($197|0),($$byval_copy|0));
              $202 = __THREW__; __THREW__ = 0;
              $203 = $202&1;
              if ($203) {
               label = 72;
               break;
              }
              HEAP32[$196>>2] = 0;
             }
             $204 = HEAP32[$3>>2]|0;
             __THREW__ = 0;
             (invoke_ii(3383,($204|0))|0);
             $205 = __THREW__; __THREW__ = 0;
             $206 = $205&1;
             if ($206) {
              label = 72;
              break;
             }
             $207 = HEAP32[$audioClips>>2]|0;
             $208 = ($207|0)==(0|0);
             if (!($208)) {
              $209 = HEAP32[$171>>2]|0;
              $210 = ($209|0)==($207|0);
              if (!($210)) {
               $__new_last2$i$i$i$i$i88 = $207;
               $scevgep$i$i$i$i$i89 = (($209) + -4|0);
               $211 = (0 - ($__new_last2$i$i$i$i$i88))|0;
               $uglygep$i$i$i$i$i91 = (($scevgep$i$i$i$i$i89) + ($211)|0);
               $uglygep3$i$i$i$i$i92 = $uglygep$i$i$i$i$i91;
               $212 = $uglygep3$i$i$i$i$i92 >>> 2;
               $213 = $212 ^ -1;
               $scevgep4$i$i$i$i$i93 = (($209) + ($213<<2)|0);
               HEAP32[$171>>2] = $scevgep4$i$i$i$i$i93;
              }
              __ZdlPv($207);
             }
             $214 = HEAP32[$audioMixers>>2]|0;
             $215 = ($214|0)==(0|0);
             if (!($215)) {
              $216 = HEAP32[$132>>2]|0;
              $217 = ($216|0)==($214|0);
              if (!($217)) {
               $__new_last2$i$i$i$i$i79 = $214;
               $scevgep$i$i$i$i$i80 = (($216) + -4|0);
               $218 = (0 - ($__new_last2$i$i$i$i$i79))|0;
               $uglygep$i$i$i$i$i82 = (($scevgep$i$i$i$i$i80) + ($218)|0);
               $uglygep3$i$i$i$i$i83 = $uglygep$i$i$i$i$i82;
               $219 = $uglygep3$i$i$i$i$i83 >>> 2;
               $220 = $219 ^ -1;
               $scevgep4$i$i$i$i$i84 = (($216) + ($220<<2)|0);
               HEAP32[$132>>2] = $scevgep4$i$i$i$i$i84;
              }
              __ZdlPv($214);
             }
             $221 = HEAP32[$audioReverbZones>>2]|0;
             $222 = ($221|0)==(0|0);
             if (!($222)) {
              $223 = HEAP32[$114>>2]|0;
              $224 = ($223|0)==($221|0);
              if (!($224)) {
               $__new_last2$i$i$i$i$i70 = $221;
               $scevgep$i$i$i$i$i71 = (($223) + -4|0);
               $225 = (0 - ($__new_last2$i$i$i$i$i70))|0;
               $uglygep$i$i$i$i$i73 = (($scevgep$i$i$i$i$i71) + ($225)|0);
               $uglygep3$i$i$i$i$i74 = $uglygep$i$i$i$i$i73;
               $226 = $uglygep3$i$i$i$i$i74 >>> 2;
               $227 = $226 ^ -1;
               $scevgep4$i$i$i$i$i75 = (($223) + ($227<<2)|0);
               HEAP32[$114>>2] = $scevgep4$i$i$i$i$i75;
              }
              __ZdlPv($221);
             }
             $228 = HEAP32[$audioListeners>>2]|0;
             $229 = ($228|0)==(0|0);
             if (!($229)) {
              $230 = HEAP32[$96>>2]|0;
              $231 = ($230|0)==($228|0);
              if (!($231)) {
               $__new_last2$i$i$i$i$i61 = $228;
               $scevgep$i$i$i$i$i62 = (($230) + -4|0);
               $232 = (0 - ($__new_last2$i$i$i$i$i61))|0;
               $uglygep$i$i$i$i$i64 = (($scevgep$i$i$i$i$i62) + ($232)|0);
               $uglygep3$i$i$i$i$i65 = $uglygep$i$i$i$i$i64;
               $233 = $uglygep3$i$i$i$i$i65 >>> 2;
               $234 = $233 ^ -1;
               $scevgep4$i$i$i$i$i66 = (($230) + ($234<<2)|0);
               HEAP32[$96>>2] = $scevgep4$i$i$i$i$i66;
              }
              __ZdlPv($228);
             }
             $235 = HEAP32[$audioSources>>2]|0;
             $236 = ($235|0)==(0|0);
             if (!($236)) {
              $237 = HEAP32[$78>>2]|0;
              $238 = ($237|0)==($235|0);
              if (!($238)) {
               $__new_last2$i$i$i$i$i52 = $235;
               $scevgep$i$i$i$i$i53 = (($237) + -4|0);
               $239 = (0 - ($__new_last2$i$i$i$i$i52))|0;
               $uglygep$i$i$i$i$i55 = (($scevgep$i$i$i$i$i53) + ($239)|0);
               $uglygep3$i$i$i$i$i56 = $uglygep$i$i$i$i$i55;
               $240 = $uglygep3$i$i$i$i$i56 >>> 2;
               $241 = $240 ^ -1;
               $scevgep4$i$i$i$i$i57 = (($237) + ($241<<2)|0);
               HEAP32[$78>>2] = $scevgep4$i$i$i$i$i57;
              }
              __ZdlPv($235);
             }
             $242 = HEAP32[$monoBehaviours>>2]|0;
             $243 = ($242|0)==(0|0);
             if ($243) {
              STACKTOP = sp;return;
             }
             $244 = HEAP32[$6>>2]|0;
             $245 = ($244|0)==($242|0);
             if (!($245)) {
              $__new_last2$i$i$i$i$i43 = $242;
              $scevgep$i$i$i$i$i44 = (($244) + -4|0);
              $246 = (0 - ($__new_last2$i$i$i$i$i43))|0;
              $uglygep$i$i$i$i$i46 = (($scevgep$i$i$i$i$i44) + ($246)|0);
              $uglygep3$i$i$i$i$i47 = $uglygep$i$i$i$i$i46;
              $247 = $uglygep3$i$i$i$i$i47 >>> 2;
              $248 = $247 ^ -1;
              $scevgep4$i$i$i$i$i48 = (($244) + ($248<<2)|0);
              HEAP32[$6>>2] = $scevgep4$i$i$i$i$i48;
             }
             __ZdlPv($242);
             STACKTOP = sp;return;
            }
           } while(0);
           if ((label|0) == 72) {
            $187 = ___cxa_find_matching_catch()|0;
            $188 = tempRet0;
            $lpad$phi$index = $187;$lpad$phi$index35 = $188;
           }
           $189 = HEAP32[$audioClips>>2]|0;
           $190 = ($189|0)==(0|0);
           if ($190) {
            $$0 = $lpad$phi$index;$$01 = $lpad$phi$index35;
            break;
           }
           $191 = HEAP32[$171>>2]|0;
           $192 = ($191|0)==($189|0);
           if (!($192)) {
            $__new_last2$i$i$i$i$i99 = $189;
            $scevgep$i$i$i$i$i100 = (($191) + -4|0);
            $193 = (0 - ($__new_last2$i$i$i$i$i99))|0;
            $uglygep$i$i$i$i$i102 = (($scevgep$i$i$i$i$i100) + ($193)|0);
            $uglygep3$i$i$i$i$i103 = $uglygep$i$i$i$i$i102;
            $194 = $uglygep3$i$i$i$i$i103 >>> 2;
            $195 = $194 ^ -1;
            $scevgep4$i$i$i$i$i104 = (($191) + ($195<<2)|0);
            HEAP32[$171>>2] = $scevgep4$i$i$i$i$i104;
           }
           __ZdlPv($189);
           $$0 = $lpad$phi$index;$$01 = $lpad$phi$index35;
          }
         } while(0);
         if ((label|0) == 53) {
          $148 = ___cxa_find_matching_catch()|0;
          $149 = tempRet0;
          $lpad$phi121$index = $148;$lpad$phi121$index30 = $149;
          label = 54;
         }
         if ((label|0) == 54) {
          $$0 = $lpad$phi121$index;$$01 = $lpad$phi121$index30;
         }
         $249 = HEAP32[$audioMixers>>2]|0;
         $250 = ($249|0)==(0|0);
         if ($250) {
          $$1 = $$0;$$12 = $$01;
         } else {
          $251 = HEAP32[$132>>2]|0;
          $252 = ($251|0)==($249|0);
          if (!($252)) {
           $__new_last2$i$i$i$i$i27 = $249;
           $scevgep$i$i$i$i$i28 = (($251) + -4|0);
           $253 = (0 - ($__new_last2$i$i$i$i$i27))|0;
           $uglygep$i$i$i$i$i30 = (($scevgep$i$i$i$i$i28) + ($253)|0);
           $uglygep3$i$i$i$i$i31 = $uglygep$i$i$i$i$i30;
           $254 = $uglygep3$i$i$i$i$i31 >>> 2;
           $255 = $254 ^ -1;
           $scevgep4$i$i$i$i$i32 = (($251) + ($255<<2)|0);
           HEAP32[$132>>2] = $scevgep4$i$i$i$i$i32;
          }
          __ZdlPv($249);
          $$1 = $$0;$$12 = $$01;
         }
        }
       } while(0);
       if ((label|0) == 47) {
        $$1 = $lpad$phi128$index;$$12 = $lpad$phi128$index25;
       }
       $256 = HEAP32[$audioReverbZones>>2]|0;
       $257 = ($256|0)==(0|0);
       if ($257) {
        $$2 = $$1;$$23 = $$12;
       } else {
        $258 = HEAP32[$114>>2]|0;
        $259 = ($258|0)==($256|0);
        if (!($259)) {
         $__new_last2$i$i$i$i$i20 = $256;
         $scevgep$i$i$i$i$i21 = (($258) + -4|0);
         $260 = (0 - ($__new_last2$i$i$i$i$i20))|0;
         $uglygep$i$i$i$i$i23 = (($scevgep$i$i$i$i$i21) + ($260)|0);
         $uglygep3$i$i$i$i$i24 = $uglygep$i$i$i$i$i23;
         $261 = $uglygep3$i$i$i$i$i24 >>> 2;
         $262 = $261 ^ -1;
         $scevgep4$i$i$i$i$i25 = (($258) + ($262<<2)|0);
         HEAP32[$114>>2] = $scevgep4$i$i$i$i$i25;
        }
        __ZdlPv($256);
        $$2 = $$1;$$23 = $$12;
       }
      }
     } while(0);
     if ((label|0) == 40) {
      $$2 = $lpad$phi135$index;$$23 = $lpad$phi135$index20;
     }
     $263 = HEAP32[$audioListeners>>2]|0;
     $264 = ($263|0)==(0|0);
     if ($264) {
      $$3 = $$2;$$34 = $$23;
     } else {
      $265 = HEAP32[$96>>2]|0;
      $266 = ($265|0)==($263|0);
      if (!($266)) {
       $__new_last2$i$i$i$i$i13 = $263;
       $scevgep$i$i$i$i$i14 = (($265) + -4|0);
       $267 = (0 - ($__new_last2$i$i$i$i$i13))|0;
       $uglygep$i$i$i$i$i16 = (($scevgep$i$i$i$i$i14) + ($267)|0);
       $uglygep3$i$i$i$i$i17 = $uglygep$i$i$i$i$i16;
       $268 = $uglygep3$i$i$i$i$i17 >>> 2;
       $269 = $268 ^ -1;
       $scevgep4$i$i$i$i$i18 = (($265) + ($269<<2)|0);
       HEAP32[$96>>2] = $scevgep4$i$i$i$i$i18;
      }
      __ZdlPv($263);
      $$3 = $$2;$$34 = $$23;
     }
    }
   } while(0);
   if ((label|0) == 33) {
    $$3 = $lpad$phi142$index;$$34 = $lpad$phi142$index15;
   }
   $270 = HEAP32[$audioSources>>2]|0;
   $271 = ($270|0)==(0|0);
   if ($271) {
    $$4 = $$3;$$45 = $$34;
   } else {
    $272 = HEAP32[$78>>2]|0;
    $273 = ($272|0)==($270|0);
    if (!($273)) {
     $__new_last2$i$i$i$i$i6 = $270;
     $scevgep$i$i$i$i$i7 = (($272) + -4|0);
     $274 = (0 - ($__new_last2$i$i$i$i$i6))|0;
     $uglygep$i$i$i$i$i9 = (($scevgep$i$i$i$i$i7) + ($274)|0);
     $uglygep3$i$i$i$i$i10 = $uglygep$i$i$i$i$i9;
     $275 = $uglygep3$i$i$i$i$i10 >>> 2;
     $276 = $275 ^ -1;
     $scevgep4$i$i$i$i$i11 = (($272) + ($276<<2)|0);
     HEAP32[$78>>2] = $scevgep4$i$i$i$i$i11;
    }
    __ZdlPv($270);
    $$4 = $$3;$$45 = $$34;
   }
  }
 } while(0);
 if ((label|0) == 25) {
  $$4 = $eh$lpad$body$indexZ2D;$$45 = $eh$lpad$body$index6Z2D;
 }
 $277 = HEAP32[$monoBehaviours>>2]|0;
 $278 = ($277|0)==(0|0);
 if ($278) {
  ___resumeException($$4|0);
  // unreachable;
 }
 $279 = HEAP32[$6>>2]|0;
 $280 = ($279|0)==($277|0);
 if (!($280)) {
  $__new_last2$i$i$i$i$i = $277;
  $scevgep$i$i$i$i$i = (($279) + -4|0);
  $281 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($281)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $282 = $uglygep3$i$i$i$i$i >>> 2;
  $283 = $282 ^ -1;
  $scevgep4$i$i$i$i$i = (($279) + ($283<<2)|0);
  HEAP32[$6>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($277);
 ___resumeException($$4|0);
 // unreachable;
}
function __ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$result,$errmsg) {
 $this = $this|0;
 $result = $result|0;
 $errmsg = $errmsg|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = ($result|0)==(0);
 if ($2) {
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
 }
 $3 = (($this) + 164|0);
 $4 = (__ZL16FMOD_ErrorString11FMOD_RESULT($result)|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($3,$4)|0);
 $5 = (($this) + 176|0);
 HEAP32[$5>>2] = $result;
 $6 = (_strlen(($errmsg|0))|0);
 $7 = ($6>>>0)>(4294967279);
 if ($7) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $8 = ($6>>>0)<(11);
 if ($8) {
  $9 = $6 << 1;
  $10 = $9&255;
  HEAP8[$1>>0] = $10;
  $11 = (($1) + 1|0);
  $__p$0$i$i$i = $11;
 } else {
  $12 = (($6) + 16)|0;
  $13 = $12 & -16;
  $14 = (__Znwj($13)|0);
  $15 = (($1) + 8|0);
  HEAP32[$15>>2] = $14;
  $16 = $13 | 1;
  HEAP32[$1>>2] = $16;
  $17 = (($1) + 4|0);
  HEAP32[$17>>2] = $6;
  $__p$0$i$i$i = $14;
 }
 _memcpy(($__p$0$i$i$i|0),($errmsg|0),($6|0))|0;
 $18 = (($__p$0$i$i$i) + ($6)|0);
 HEAP8[$18>>0] = 0;
 __THREW__ = 0;
 invoke_viii(1774,($0|0),($1|0),($3|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if ($20) {
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $$0 = $41;$$01 = $40;
  } else {
   $21 = HEAP8[$0>>0]|0;
   $22 = $21 & 1;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $26 = (($0) + 1|0);
    $27 = $26;
   } else {
    $24 = (($0) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $27 = $25;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($27|0),0,(711992|0),487,1,0,0,(0|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    $42 = ___cxa_find_matching_catch()|0;
    $43 = tempRet0;
    $44 = HEAP8[$0>>0]|0;
    $45 = $44 & 1;
    $46 = ($45<<24>>24)==(0);
    if ($46) {
     $$0 = $43;$$01 = $42;
     break;
    }
    $47 = (($0) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    __ZdlPv($48);
    $$0 = $43;$$01 = $42;
    break;
   }
   $30 = HEAP8[$0>>0]|0;
   $31 = $30 & 1;
   $32 = ($31<<24>>24)==(0);
   if (!($32)) {
    $33 = (($0) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    __ZdlPv($34);
   }
   $35 = HEAP8[$1>>0]|0;
   $36 = $35 & 1;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    $$02 = 0;
    STACKTOP = sp;return ($$02|0);
   }
   $38 = (($1) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   __ZdlPv($39);
   $$02 = 0;
   STACKTOP = sp;return ($$02|0);
  }
 } while(0);
 $49 = HEAP8[$1>>0]|0;
 $50 = $49 & 1;
 $51 = ($50<<24>>24)==(0);
 if ($51) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $52 = (($1) + 8|0);
 $53 = HEAP32[$52>>2]|0;
 __ZdlPv($53);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __ZL16FMOD_ErrorString11FMOD_RESULT($errcode) {
 $errcode = $errcode|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($errcode|0) {
  case 10:  {
   $$0 = 714304;
   break;
  }
  case 84:  {
   $$0 = 715520;
   break;
  }
  case 15:  {
   $$0 = 714760;
   break;
  }
  case 7:  {
   $$0 = 714192;
   break;
  }
  case 83:  {
   $$0 = 715360;
   break;
  }
  case 88:  {
   $$0 = 715920;
   break;
  }
  case 18:  {
   $$0 = 715120;
   break;
  }
  case 91:  {
   $$0 = 715472;
   break;
  }
  case 21:  {
   $$0 = 716280;
   break;
  }
  case 23:  {
   $$0 = 716416;
   break;
  }
  case 13:  {
   $$0 = 714560;
   break;
  }
  case 26:  {
   $$0 = 716512;
   break;
  }
  case 28:  {
   $$0 = 716672;
   break;
  }
  case 6:  {
   $$0 = 714152;
   break;
  }
  case 19:  {
   $$0 = 716144;
   break;
  }
  case 25:  {
   $$0 = 716472;
   break;
  }
  case 29:  {
   $$0 = 716744;
   break;
  }
  case 92:  {
   $$0 = 715224;
   break;
  }
  case 14:  {
   $$0 = 714616;
   break;
  }
  case 30:  {
   $$0 = 716776;
   break;
  }
  case 31:  {
   $$0 = 716808;
   break;
  }
  case 32:  {
   $$0 = 716872;
   break;
  }
  case 22:  {
   $$0 = 716320;
   break;
  }
  case 5:  {
   $$0 = 714112;
   break;
  }
  case 12:  {
   $$0 = 714408;
   break;
  }
  case 85:  {
   $$0 = 715576;
   break;
  }
  case 27:  {
   $$0 = 716600;
   break;
  }
  case 34:  {
   $$0 = 716984;
   break;
  }
  case 35:  {
   $$0 = 717088;
   break;
  }
  case 9:  {
   $$0 = 714272;
   break;
  }
  case 24:  {
   $$0 = 716440;
   break;
  }
  case 3:  {
   $$0 = 714000;
   break;
  }
  case 33:  {
   $$0 = 716920;
   break;
  }
  case 4:  {
   $$0 = 714048;
   break;
  }
  case 16:  {
   $$0 = 714864;
   break;
  }
  case 90:  {
   $$0 = 715968;
   break;
  }
  case 11:  {
   $$0 = 714344;
   break;
  }
  case 86:  {
   $$0 = 715648;
   break;
  }
  case 17:  {
   $$0 = 714928;
   break;
  }
  case 8:  {
   $$0 = 714224;
   break;
  }
  case 87:  {
   $$0 = 715752;
   break;
  }
  case 89:  {
   $$0 = 716056;
   break;
  }
  case 20:  {
   $$0 = 716168;
   break;
  }
  case 2:  {
   $$0 = 713864;
   break;
  }
  case 78:  {
   $$0 = 721288;
   break;
  }
  case 45:  {
   $$0 = 717744;
   break;
  }
  case 61:  {
   $$0 = 719384;
   break;
  }
  case 76:  {
   $$0 = 721072;
   break;
  }
  case 79:  {
   $$0 = 721368;
   break;
  }
  case 36:  {
   $$0 = 717144;
   break;
  }
  case 60:  {
   $$0 = 719344;
   break;
  }
  case 80:  {
   $$0 = 721448;
   break;
  }
  case 81:  {
   $$0 = 721560;
   break;
  }
  case 82:  {
   $$0 = 721608;
   break;
  }
  case 46:  {
   $$0 = 717992;
   break;
  }
  case 47:  {
   $$0 = 718072;
   break;
  }
  case 41:  {
   $$0 = 717440;
   break;
  }
  case 95:  {
   $$0 = 717800;
   break;
  }
  case 52:  {
   $$0 = 718616;
   break;
  }
  case 64:  {
   $$0 = 719640;
   break;
  }
  case 56:  {
   $$0 = 718944;
   break;
  }
  case 44:  {
   $$0 = 717616;
   break;
  }
  case 75:  {
   $$0 = 720376;
   break;
  }
  case 43:  {
   $$0 = 717576;
   break;
  }
  case 73:  {
   $$0 = 720816;
   break;
  }
  case 40:  {
   $$0 = 717384;
   break;
  }
  case 42:  {
   $$0 = 717504;
   break;
  }
  case 38:  {
   $$0 = 717240;
   break;
  }
  case 53:  {
   $$0 = 718664;
   break;
  }
  case 58:  {
   $$0 = 719120;
   break;
  }
  case 67:  {
   $$0 = 719840;
   break;
  }
  case 69:  {
   $$0 = 720056;
   break;
  }
  case 71:  {
   $$0 = 720232;
   break;
  }
  case 55:  {
   $$0 = 718824;
   break;
  }
  case 49:  {
   $$0 = 718280;
   break;
  }
  case 48:  {
   $$0 = 718152;
   break;
  }
  case 72:  {
   $$0 = 720664;
   break;
  }
  case 37:  {
   $$0 = 717184;
   break;
  }
  case 74:  {
   $$0 = 720936;
   break;
  }
  case 54:  {
   $$0 = 718736;
   break;
  }
  case 62:  {
   $$0 = 719488;
   break;
  }
  case 57:  {
   $$0 = 718984;
   break;
  }
  case 63:  {
   $$0 = 719584;
   break;
  }
  case 94:  {
   $$0 = 717864;
   break;
  }
  case 66:  {
   $$0 = 719776;
   break;
  }
  case 68:  {
   $$0 = 719936;
   break;
  }
  case 77:  {
   $$0 = 721136;
   break;
  }
  case 59:  {
   $$0 = 719240;
   break;
  }
  case 39:  {
   $$0 = 717296;
   break;
  }
  case 51:  {
   $$0 = 718520;
   break;
  }
  case 65:  {
   $$0 = 719712;
   break;
  }
  case 70:  {
   $$0 = 720168;
   break;
  }
  case 50:  {
   $$0 = 718472;
   break;
  }
  case 93:  {
   $$0 = 717912;
   break;
  }
  case 0:  {
   $$0 = 721672;
   break;
  }
  case 1:  {
   $$0 = 713800;
   break;
  }
  default: {
   $$0 = 721688;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN12AudioManager8InitFMODEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $$2 = 0, $$25 = 0, $$byval_copy11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $clockHi = 0, $clockLo = 0, $effectdef = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $fmoddebuglevel = 0;
 var $internalDef = 0, $samplerate = 0, $vararg_ptr10 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy11 = sp + 104|0;
 $0 = sp + 176|0;
 $fmoddebuglevel = sp + 164|0;
 $1 = sp + 152|0;
 $samplerate = sp + 148|0;
 $clockLo = sp + 188|0;
 $clockHi = sp + 120|0;
 $effectdef = sp;
 $internalDef = sp + 128|0;
 $2 = sp + 144|0;
 $3 = (__Znwj(16)|0);
 $4 = (($1) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$1>>2] = 17;
 $5 = (($1) + 4|0);
 HEAP32[$5>>2] = 14;
 dest=$3+0|0; src=712120+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 14|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_vii(3339,($fmoddebuglevel|0),($1|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  $30 = HEAP8[$1>>0]|0;
  $31 = $30 & 1;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   $$2 = $29;$$25 = $28;
   ___resumeException($$25|0);
   // unreachable;
  }
  $33 = HEAP32[$4>>2]|0;
  __ZdlPv($33);
  $$2 = $29;$$25 = $28;
  ___resumeException($$25|0);
  // unreachable;
 }
 $9 = HEAP8[$1>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
 }
 $13 = HEAP8[$fmoddebuglevel>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $18 = $13&255;
  $19 = $18 >>> 1;
  $21 = $19;
 } else {
  $16 = (($fmoddebuglevel) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $21 = $17;
 }
 $20 = ($21|0)==(0);
 if ($20) {
  __THREW__ = 0;
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   label = 14;
  } else {
   label = 16;
  }
 } else {
  if ($15) {
   $24 = (($fmoddebuglevel) + 1|0);
   $25 = $24;
  } else {
   $22 = (($fmoddebuglevel) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $25 = $23;
  }
  (_atoi($25)|0);
  __THREW__ = 0;
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   label = 14;
  } else {
   label = 16;
  }
 }
 L22: do {
  if ((label|0) == 16) {
   $38 = (($this) + 92|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if ($40) {
    __THREW__ = 0;
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 14;
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_ii(3384,($38|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     label = 14;
     break;
    }
    __THREW__ = 0;
    $46 = (invoke_iiii(1577,($this|0),($43|0),(712136|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 14;
     break;
    }
    if ($46) {
     $49 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     (invoke_iiiiiiiii(42,($49|0),(210|0),(2566|0),(211|0),(1578|0),(0|0),(0|0),-1)|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 14;
      break;
     } else {
      label = 22;
     }
    } else {
     $$1 = 0;
    }
   } else {
    label = 22;
   }
   L30: do {
    if ((label|0) == 22) {
     __THREW__ = 0;
     $52 = (invoke_ii(3385,($this|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      label = 14;
      break L22;
     }
     if ($52) {
      $55 = HEAP32[$38>>2]|0;
      __THREW__ = 0;
      $56 = (invoke_iiii(1579,($55|0),64000,8)|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 14;
       break L22;
      }
      __THREW__ = 0;
      $59 = (invoke_iiii(1577,($this|0),($56|0),(712136|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       label = 14;
       break L22;
      }
      if ($59) {
       $62 = HEAP32[$38>>2]|0;
       __THREW__ = 0;
       $63 = (invoke_iii(2567,($62|0),(265|0))|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        label = 14;
        break L22;
       }
       __THREW__ = 0;
       $66 = (invoke_iiii(1577,($this|0),($63|0),(712168|0))|0);
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        label = 14;
        break L22;
       }
       if ($66) {
        $69 = HEAP32[$38>>2]|0;
        __THREW__ = 0;
        $70 = (invoke_iii(2568,($69|0),(15|0))|0);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 14;
         break L22;
        }
        __THREW__ = 0;
        $73 = (invoke_iiii(1577,($this|0),($70|0),(712216|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 14;
         break L22;
        }
        if ($73) {
         $76 = HEAP32[$38>>2]|0;
         $77 = (($this) + 96|0);
         __THREW__ = 0;
         $78 = (invoke_iii(2569,($76|0),($77|0))|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          label = 14;
          break L22;
         }
         __THREW__ = 0;
         $81 = (invoke_iiii(1577,($this|0),($78|0),(712264|0))|0);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          label = 14;
          break L22;
         }
         if (!($81)) {
          $$1 = 0;
          break;
         }
         HEAP32[$samplerate>>2] = 0;
         $84 = HEAP32[$38>>2]|0;
         __THREW__ = 0;
         (invoke_iiiiiiii(114,($84|0),($samplerate|0),(0|0),(0|0),(0|0),(0|0),(0|0))|0);
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          label = 14;
          break L22;
         }
         $87 = HEAP32[$samplerate>>2]|0;
         HEAP32[((702920 + 12|0))>>2] = $87;
         $88 = HEAP32[$38>>2]|0;
         __THREW__ = 0;
         (invoke_iiii(1580,($88|0),($clockHi|0),($clockLo|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 14;
          break L22;
         }
         $91 = HEAP32[$clockHi>>2]|0;
         $92 = HEAP32[$clockLo>>2]|0;
         $93 = 702920;
         $94 = $93;
         HEAP32[$94>>2] = $92;
         $95 = (($93) + 4)|0;
         $96 = $95;
         HEAP32[$96>>2] = $91;
         dest=$effectdef+0|0; stop=dest+104|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
         $97 = (($effectdef) + 32|0);
         dest=$97+0|0; src=712312+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
         HEAP32[$effectdef>>2] = 104;
         $98 = (($effectdef) + 4|0);
         HEAP32[$98>>2] = 56;
         $99 = (($effectdef) + 76|0);
         HEAP32[$99>>2] = 115;
         __THREW__ = 0;
         invoke_viii(1986,($internalDef|0),($effectdef|0),0);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          label = 14;
          break L22;
         }
         $102 = HEAP32[$38>>2]|0;
         __THREW__ = 0;
         $103 = (invoke_iiiii(266,($internalDef|0),($102|0),(702920|0),(0|0))|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         L49: do {
          if ($105) {
           label = 54;
          } else {
           $106 = HEAP32[$77>>2]|0;
           __THREW__ = 0;
           $107 = (invoke_iiii(1581,($106|0),($103|0),(0|0))|0);
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            label = 54;
            break;
           }
           $110 = ($107|0)==(0);
           do {
            if (!($110)) {
             $111 = (__ZL16FMOD_ErrorString11FMOD_RESULT($107)|0);
             __THREW__ = 0;
             HEAP32[$$byval_copy11>>2] = 712328;
             $vararg_ptr8 = (($$byval_copy11) + 4|0);
             HEAP32[$vararg_ptr8>>2] = 631;
             $vararg_ptr9 = (($$byval_copy11) + 8|0);
             HEAP32[$vararg_ptr9>>2] = 712400;
             $vararg_ptr10 = (($$byval_copy11) + 12|0);
             HEAP32[$vararg_ptr10>>2] = $111;
             invoke_viii(1617,($0|0),(713760|0),($$byval_copy11|0));
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if ($113) {
              label = 54;
              break L49;
             }
             $114 = HEAP8[$0>>0]|0;
             $115 = $114 & 1;
             $116 = ($115<<24>>24)==(0);
             if ($116) {
              $119 = (($0) + 1|0);
              $120 = $119;
             } else {
              $117 = (($0) + 8|0);
              $118 = HEAP32[$117>>2]|0;
              $120 = $118;
             }
             __THREW__ = 0;
             invoke_viiiiiiii(21,($120|0),0,(711992|0),21,1,0,0,(0|0));
             $121 = __THREW__; __THREW__ = 0;
             $122 = $121&1;
             if ($122) {
              $128 = ___cxa_find_matching_catch()|0;
              $129 = tempRet0;
              $130 = HEAP8[$0>>0]|0;
              $131 = $130 & 1;
              $132 = ($131<<24>>24)==(0);
              if ($132) {
               $eh$lpad$body$index3Z2D = $129;$eh$lpad$body$indexZ2D = $128;
               label = 55;
               break L49;
              }
              $133 = (($0) + 8|0);
              $134 = HEAP32[$133>>2]|0;
              __ZdlPv($134);
              $eh$lpad$body$index3Z2D = $129;$eh$lpad$body$indexZ2D = $128;
              label = 55;
              break L49;
             } else {
              $123 = HEAP8[$0>>0]|0;
              $124 = $123 & 1;
              $125 = ($124<<24>>24)==(0);
              if ($125) {
               break;
              }
              $126 = (($0) + 8|0);
              $127 = HEAP32[$126>>2]|0;
              __ZdlPv($127);
              break;
             }
            }
           } while(0);
           $135 = HEAP32[$38>>2]|0;
           $136 = (($this) + 100|0);
           __THREW__ = 0;
           $137 = (invoke_iiii(1582,($135|0),(712456|0),($136|0))|0);
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            label = 54;
            break;
           }
           __THREW__ = 0;
           $140 = (invoke_iiii(1577,($this|0),($137|0),(712264|0))|0);
           $141 = __THREW__; __THREW__ = 0;
           $142 = $141&1;
           if ($142) {
            label = 54;
            break;
           }
           do {
            if ($140) {
             $145 = HEAP32[$38>>2]|0;
             $146 = (($this) + 104|0);
             __THREW__ = 0;
             $147 = (invoke_iiii(1582,($145|0),(712472|0),($146|0))|0);
             $148 = __THREW__; __THREW__ = 0;
             $149 = $148&1;
             if ($149) {
              label = 54;
              break L49;
             }
             __THREW__ = 0;
             $150 = (invoke_iiii(1577,($this|0),($147|0),(712264|0))|0);
             $151 = __THREW__; __THREW__ = 0;
             $152 = $151&1;
             if ($152) {
              label = 54;
              break L49;
             }
             if (!($150)) {
              $$0 = 0;
              break;
             }
             $153 = HEAP32[$38>>2]|0;
             $154 = (($this) + 108|0);
             __THREW__ = 0;
             $155 = (invoke_iiii(1582,($153|0),(712488|0),($154|0))|0);
             $156 = __THREW__; __THREW__ = 0;
             $157 = $156&1;
             if ($157) {
              label = 54;
              break L49;
             }
             __THREW__ = 0;
             $158 = (invoke_iiii(1577,($this|0),($155|0),(712264|0))|0);
             $159 = __THREW__; __THREW__ = 0;
             $160 = $159&1;
             if ($160) {
              label = 54;
              break L49;
             }
             if (!($158)) {
              $$0 = 0;
              break;
             }
             $161 = HEAP32[$38>>2]|0;
             $162 = (($this) + 112|0);
             __THREW__ = 0;
             $163 = (invoke_iiii(1582,($161|0),(712504|0),($162|0))|0);
             $164 = __THREW__; __THREW__ = 0;
             $165 = $164&1;
             if ($165) {
              label = 54;
              break L49;
             }
             __THREW__ = 0;
             $166 = (invoke_iiii(1577,($this|0),($163|0),(712264|0))|0);
             $167 = __THREW__; __THREW__ = 0;
             $168 = $167&1;
             if ($168) {
              label = 54;
              break L49;
             }
             if (!($166)) {
              $$0 = 0;
              break;
             }
             $169 = HEAP32[$77>>2]|0;
             $170 = HEAP32[$136>>2]|0;
             __THREW__ = 0;
             $171 = (invoke_iii(2570,($169|0),($170|0))|0);
             $172 = __THREW__; __THREW__ = 0;
             $173 = $172&1;
             if ($173) {
              label = 54;
              break L49;
             }
             __THREW__ = 0;
             $174 = (invoke_iiii(1577,($this|0),($171|0),(712264|0))|0);
             $175 = __THREW__; __THREW__ = 0;
             $176 = $175&1;
             if ($176) {
              label = 54;
              break L49;
             }
             if (!($174)) {
              $$0 = 0;
              break;
             }
             $177 = HEAP32[$136>>2]|0;
             $178 = HEAP32[$146>>2]|0;
             __THREW__ = 0;
             $179 = (invoke_iii(2570,($177|0),($178|0))|0);
             $180 = __THREW__; __THREW__ = 0;
             $181 = $180&1;
             if ($181) {
              label = 54;
              break L49;
             }
             __THREW__ = 0;
             $182 = (invoke_iiii(1577,($this|0),($179|0),(712264|0))|0);
             $183 = __THREW__; __THREW__ = 0;
             $184 = $183&1;
             if ($184) {
              label = 54;
              break L49;
             }
             if (!($182)) {
              $$0 = 0;
              break;
             }
             $185 = HEAP32[$77>>2]|0;
             $186 = HEAP32[$154>>2]|0;
             __THREW__ = 0;
             $187 = (invoke_iii(2570,($185|0),($186|0))|0);
             $188 = __THREW__; __THREW__ = 0;
             $189 = $188&1;
             if ($189) {
              label = 54;
              break L49;
             }
             __THREW__ = 0;
             $190 = (invoke_iiii(1577,($this|0),($187|0),(712264|0))|0);
             $191 = __THREW__; __THREW__ = 0;
             $192 = $191&1;
             if ($192) {
              label = 54;
              break L49;
             }
             if (!($190)) {
              $$0 = 0;
              break;
             }
             $193 = HEAP32[$154>>2]|0;
             $194 = HEAP32[$162>>2]|0;
             __THREW__ = 0;
             $195 = (invoke_iii(2570,($193|0),($194|0))|0);
             $196 = __THREW__; __THREW__ = 0;
             $197 = $196&1;
             if ($197) {
              label = 54;
              break L49;
             }
             __THREW__ = 0;
             $198 = (invoke_iiii(1577,($this|0),($195|0),(712264|0))|0);
             $199 = __THREW__; __THREW__ = 0;
             $200 = $199&1;
             if ($200) {
              label = 54;
              break L49;
             }
             if (!($198)) {
              $$0 = 0;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3653,($this|0));
             $201 = __THREW__; __THREW__ = 0;
             $202 = $201&1;
             if ($202) {
              label = 54;
              break L49;
             }
             $203 = (($this) + 128|0);
             $204 = HEAP32[$203>>2]|0;
             $205 = (($this) + 148|0);
             HEAP32[$205>>2] = $204;
             $206 = (($this) + 132|0);
             $207 = HEAP32[$206>>2]|0;
             $208 = (($this) + 152|0);
             HEAP32[$208>>2] = $207;
             $209 = (($this) + 124|0);
             $210 = HEAP32[$209>>2]|0;
             $211 = (($this) + 144|0);
             HEAP32[$211>>2] = $210;
             $212 = (($this) + 136|0);
             $213 = HEAP32[$212>>2]|0;
             $214 = (($this) + 156|0);
             HEAP32[$214>>2] = $213;
             $215 = (($this) + 140|0);
             $216 = HEAP32[$215>>2]|0;
             $217 = (($this) + 160|0);
             HEAP32[$217>>2] = $216;
             $218 = HEAP32[628304>>2]|0;
             HEAP32[$2>>2] = $218;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
             $219 = (invoke_iiiiiii(103,56,($$byval_copy11|0),0,16,(711992|0),675)|0);
             $220 = __THREW__; __THREW__ = 0;
             $221 = $220&1;
             if ($221) {
              label = 54;
              break L49;
             }
             __THREW__ = 0;
             invoke_vi(3654,($219|0));
             $222 = __THREW__; __THREW__ = 0;
             $223 = $222&1;
             if (!($223)) {
              $224 = (($this) + 200|0);
              HEAP32[$224>>2] = $219;
              $$0 = 1;
              break;
             }
             $225 = ___cxa_find_matching_catch()|0;
             $226 = tempRet0;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
             invoke_viiiiii(97,($219|0),($$byval_copy11|0),0,16,(711992|0),675);
             $227 = __THREW__; __THREW__ = 0;
             $228 = $227&1;
             if (!($228)) {
              $$01 = $226;$$03 = $225;
              break L49;
             }
             $243 = ___cxa_find_matching_catch(0|0)|0;
             $244 = tempRet0;
             ___clang_call_terminate($243);
             // unreachable;
            } else {
             $$0 = 0;
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(3655,($internalDef|0));
           $229 = __THREW__; __THREW__ = 0;
           $230 = $229&1;
           if ($230) {
            label = 14;
            break L22;
           } else {
            $$1 = $$0;
            break L30;
           }
          }
         } while(0);
         if ((label|0) == 54) {
          $143 = ___cxa_find_matching_catch()|0;
          $144 = tempRet0;
          $eh$lpad$body$index3Z2D = $144;$eh$lpad$body$indexZ2D = $143;
          label = 55;
         }
         if ((label|0) == 55) {
          $$01 = $eh$lpad$body$index3Z2D;$$03 = $eh$lpad$body$indexZ2D;
         }
         __THREW__ = 0;
         invoke_vi(3655,($internalDef|0));
         $231 = __THREW__; __THREW__ = 0;
         $232 = $231&1;
         if (!($232)) {
          $$12 = $$01;$$14 = $$03;
          break L22;
         }
         $243 = ___cxa_find_matching_catch(0|0)|0;
         $244 = tempRet0;
         ___clang_call_terminate($243);
         // unreachable;
        } else {
         $$1 = 0;
        }
       } else {
        $$1 = 0;
       }
      } else {
       $$1 = 0;
      }
     } else {
      $$1 = 0;
     }
    }
   } while(0);
   $233 = HEAP8[$fmoddebuglevel>>0]|0;
   $234 = $233 & 1;
   $235 = ($234<<24>>24)==(0);
   if ($235) {
    STACKTOP = sp;return ($$1|0);
   }
   $236 = (($fmoddebuglevel) + 8|0);
   $237 = HEAP32[$236>>2]|0;
   __ZdlPv($237);
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 if ((label|0) == 14) {
  $34 = ___cxa_find_matching_catch()|0;
  $35 = tempRet0;
  $$12 = $35;$$14 = $34;
 }
 $238 = HEAP8[$fmoddebuglevel>>0]|0;
 $239 = $238 & 1;
 $240 = ($239<<24>>24)==(0);
 if ($240) {
  $$2 = $$12;$$25 = $$14;
  ___resumeException($$25|0);
  // unreachable;
 }
 $241 = (($fmoddebuglevel) + 8|0);
 $242 = HEAP32[$241>>2]|0;
 __ZdlPv($242);
 $$2 = $$12;$$25 = $$14;
 ___resumeException($$25|0);
 // unreachable;
 return 0|0;
}
function __ZN12AudioManager10InitNormalEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $currsamplerate = 0, $driverID = 0, $format = 0, $initFlags$1 = 0, $numDrivers = 0, $or$cond = 0, $resampler = 0, $result$0 = 0, $result$1 = 0, $result$2 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $numDrivers = sp + 44|0;
 $driverID = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 20|0;
 $currsamplerate = sp + 32|0;
 $format = sp + 36|0;
 $resampler = sp + 40|0;
 $2 = (($this) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN4FMOD6System13getNumDriversEPi($3,$numDrivers)|0);
 $5 = (__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$4,713160)|0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$numDrivers>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = HEAP32[$2>>2]|0;
  $9 = (__ZN4FMOD6System9setOutputE15FMOD_OUTPUTTYPE($8,2)|0);
  $10 = (__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$9,713208)|0);
  if (!($10)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $11 = HEAP32[$2>>2]|0;
 (__ZN4FMOD6System9getDriverEPi($11,$driverID)|0);
 $12 = HEAP32[$2>>2]|0;
 $13 = HEAP32[$driverID>>2]|0;
 $14 = (($this) + 116|0);
 $15 = (($this) + 120|0);
 $16 = (__ZN4FMOD6System13getDriverCapsEiPjPiP16FMOD_SPEAKERMODE($12,$13,$14,0,$15)|0);
 $17 = (__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$16,713256)|0);
 if (!($17)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($this) + 128|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 148|0);
 HEAP32[$20>>2] = $19;
 $21 = (($this) + 132|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 152|0);
 HEAP32[$23>>2] = $22;
 $24 = (($this) + 124|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 144|0);
 HEAP32[$26>>2] = $25;
 $27 = (($this) + 136|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 156|0);
 HEAP32[$29>>2] = $28;
 $30 = (($this) + 140|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 160|0);
 HEAP32[$32>>2] = $31;
 $33 = HEAP32[$15>>2]|0;
 $34 = ($33|0)>=($25|0);
 $35 = ($25|0)==(7);
 $or$cond = $34 | $35;
 if (!($or$cond)) {
  HEAP32[$26>>2] = $33;
 }
 $36 = (__Znwj(16)|0);
 $37 = (($0) + 8|0);
 HEAP32[$37>>2] = $36;
 HEAP32[$0>>2] = 17;
 $38 = (($0) + 4|0);
 HEAP32[$38>>2] = 12;
 dest=$36+0|0; src=713304+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $39 = (($36) + 12|0);
 HEAP8[$39>>0] = 0;
 __THREW__ = 0;
 $40 = (invoke_ii(3324,($0|0))|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  $53 = HEAP8[$0>>0]|0;
  $54 = $53 & 1;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   $$01 = $52;$$02 = $51;
   ___resumeException($$02|0);
   // unreachable;
  }
  $56 = HEAP32[$37>>2]|0;
  __ZdlPv($56);
  $$01 = $52;$$02 = $51;
  ___resumeException($$02|0);
  // unreachable;
 }
 $43 = HEAP8[$0>>0]|0;
 $44 = $43 & 1;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  $46 = HEAP32[$37>>2]|0;
  __ZdlPv($46);
 }
 $$ = $40 ? 32 : 0;
 $47 = HEAP32[$26>>2]|0;
 $48 = HEAP32[$2>>2]|0;
 $49 = (__ZN4FMOD6System14setSpeakerModeE16FMOD_SPEAKERMODE($48,$47)|0);
 $50 = ($49|0)==(0);
 do {
  if ($50) {
   $result$0 = 0;
  } else {
   __Z6FormatPKcz($1,713320,$vararg_buffer);
   $57 = HEAP8[$1>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    $62 = (($1) + 1|0);
    $63 = $62;
   } else {
    $60 = (($1) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    $63 = $61;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($63|0),0,(711992|0),983,512,0,0,(0|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if (!($65)) {
    $66 = HEAP8[$1>>0]|0;
    $67 = $66 & 1;
    $68 = ($67<<24>>24)==(0);
    if (!($68)) {
     $69 = (($1) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     __ZdlPv($70);
    }
    $71 = HEAP32[$2>>2]|0;
    $72 = (__ZN4FMOD6System14setSpeakerModeE16FMOD_SPEAKERMODE($71,2)|0);
    $result$0 = $72;
    break;
   }
   $73 = ___cxa_find_matching_catch()|0;
   $74 = tempRet0;
   $75 = HEAP8[$1>>0]|0;
   $76 = $75 & 1;
   $77 = ($76<<24>>24)==(0);
   if ($77) {
    $$01 = $74;$$02 = $73;
    ___resumeException($$02|0);
    // unreachable;
   }
   $78 = (($1) + 8|0);
   $79 = HEAP32[$78>>2]|0;
   __ZdlPv($79);
   $$01 = $74;$$02 = $73;
   ___resumeException($$02|0);
   // unreachable;
  }
 } while(0);
 $80 = (__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$result$0,713424)|0);
 if (!($80)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $81 = HEAP32[$21>>2]|0;
 $82 = ($81|0)==(0);
 if (!($82)) {
  $83 = HEAP32[$2>>2]|0;
  $84 = (__ZN4FMOD6System16setDSPBufferSizeEji($83,$81,4)|0);
  $85 = (__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$84,713464)|0);
  if (!($85)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $86 = HEAP32[$2>>2]|0;
 $87 = (__ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($86,$currsamplerate,$format,0,0,$resampler,0)|0);
 $88 = (__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$87,713256)|0);
 if (!($88)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $89 = HEAP32[$2>>2]|0;
 $90 = HEAP32[$20>>2]|0;
 $91 = ($90|0)==(0);
 $92 = HEAP32[$currsamplerate>>2]|0;
 $93 = $91 ? $92 : $90;
 $94 = HEAP32[$format>>2]|0;
 $95 = HEAP32[$resampler>>2]|0;
 $96 = (__ZN4FMOD6System17setSoftwareFormatEi17FMOD_SOUND_FORMATii18FMOD_DSP_RESAMPLER($89,$93,$94,0,8,$95)|0);
 $97 = ($96|0)==(37);
 if ($97) {
  $98 = HEAP32[$2>>2]|0;
  $99 = HEAP32[$currsamplerate>>2]|0;
  $100 = HEAP32[$format>>2]|0;
  $101 = HEAP32[$resampler>>2]|0;
  $102 = (__ZN4FMOD6System17setSoftwareFormatEi17FMOD_SOUND_FORMATii18FMOD_DSP_RESAMPLER($98,$99,$100,0,8,$101)|0);
  $result$1 = $102;
 } else {
  $result$1 = $96;
 }
 $103 = (__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$result$1,713256)|0);
 if (!($103)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $104 = HEAP32[$2>>2]|0;
 $105 = HEAP32[$30>>2]|0;
 (__ZN4FMOD6System19setSoftwareChannelsEi($104,$105)|0);
 $106 = HEAP32[$2>>2]|0;
 $107 = HEAP32[$27>>2]|0;
 $108 = (__ZN4FMOD6System4initEijPv($106,$107,$$,0)|0);
 $109 = ($108|0)==(51);
 if ($109) {
  $110 = HEAP32[$2>>2]|0;
  $111 = HEAP32[$27>>2]|0;
  $112 = (__ZN4FMOD6System4initEijPv($110,$111,0,0)|0);
  $initFlags$1 = 0;$result$2 = $112;
 } else {
  $initFlags$1 = $$;$result$2 = $108;
 }
 $113 = (__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc($this,$result$2,712136)|0);
 if (!($113)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $114 = (($this) + 37|0);
 $115 = $initFlags$1 >>> 5;
 $116 = $115&255;
 HEAP8[$114>>0] = $116;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12AudioManager21FixMasterGroupRoutingEv($this) {
 $this = $this|0;
 var $$ = 0, $$43 = 0, $$44 = 0, $$45 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dspMaster = 0, $dspMasterParent = 0;
 var $dspTarget = 0, $dspToBeRerouted = 0, $n$042 = 0, $namebuf = 0, $numInputs = 0, $vararg_buffer46 = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr2 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr25 = 0, $vararg_ptr26 = 0, $vararg_ptr27 = 0, $vararg_ptr3 = 0, $vararg_ptr31 = 0, $vararg_ptr32 = 0;
 var $vararg_ptr33 = 0, $vararg_ptr37 = 0, $vararg_ptr38 = 0, $vararg_ptr39 = 0, $vararg_ptr43 = 0, $vararg_ptr44 = 0, $vararg_ptr45 = 0, $vararg_ptr49 = 0, $vararg_ptr50 = 0, $vararg_ptr51 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $vararg_buffer46 = sp;
 $0 = sp + 56|0;
 $1 = sp + 44|0;
 $2 = sp + 32|0;
 $dspMaster = sp + 24|0;
 $dspMasterParent = sp + 68|0;
 $dspTarget = sp + 16|0;
 $namebuf = sp + 72|0;
 $numInputs = sp + 28|0;
 $dspToBeRerouted = sp + 20|0;
 $3 = (($this) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 (__ZN4FMOD6System6updateEv($4)|0);
 HEAP32[$dspMaster>>2] = 0;
 $5 = (($this) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN4FMOD12ChannelGroup10getDSPHeadEPPNS_3DSPE($6,$dspMaster)|0);
 $8 = ($7|0)==(0);
 do {
  if (!($8)) {
   $9 = (__ZL16FMOD_ErrorString11FMOD_RESULT($7)|0);
   HEAP32[$vararg_buffer46>>2] = 712328;
   $vararg_ptr1 = (($vararg_buffer46) + 4|0);
   HEAP32[$vararg_ptr1>>2] = 688;
   $vararg_ptr2 = (($vararg_buffer46) + 8|0);
   HEAP32[$vararg_ptr2>>2] = 712520;
   $vararg_ptr3 = (($vararg_buffer46) + 12|0);
   HEAP32[$vararg_ptr3>>2] = $9;
   __Z6FormatPKcz($0,713760,$vararg_buffer46);
   $10 = HEAP8[$0>>0]|0;
   $11 = $10 & 1;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    $15 = (($0) + 1|0);
    $16 = $15;
   } else {
    $13 = (($0) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $16 = $14;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($16|0),0,(711992|0),21,1,0,0,(0|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP8[$0>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     break;
    }
    $22 = (($0) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    __ZdlPv($23);
    break;
   }
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $26 = HEAP8[$0>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    ___resumeException($24|0);
    // unreachable;
   }
   $29 = (($0) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   __ZdlPv($30);
   ___resumeException($24|0);
   // unreachable;
  }
 } while(0);
 $31 = HEAP32[$dspMaster>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$dspMasterParent>>2] = 0;
 $33 = (__ZN4FMOD3DSP9getOutputEiPPS0_PPNS_13DSPConnectionE($31,0,$dspMasterParent,0)|0);
 $34 = ($33|0)==(0);
 do {
  if (!($34)) {
   $35 = (__ZL16FMOD_ErrorString11FMOD_RESULT($33)|0);
   HEAP32[$vararg_buffer46>>2] = 712328;
   $vararg_ptr7 = (($vararg_buffer46) + 4|0);
   HEAP32[$vararg_ptr7>>2] = 693;
   $vararg_ptr8 = (($vararg_buffer46) + 8|0);
   HEAP32[$vararg_ptr8>>2] = 712576;
   $vararg_ptr9 = (($vararg_buffer46) + 12|0);
   HEAP32[$vararg_ptr9>>2] = $35;
   __Z6FormatPKcz($0,713760,$vararg_buffer46);
   $36 = HEAP8[$0>>0]|0;
   $37 = $36 & 1;
   $38 = ($37<<24>>24)==(0);
   if ($38) {
    $41 = (($0) + 1|0);
    $42 = $41;
   } else {
    $39 = (($0) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $42 = $40;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($42|0),0,(711992|0),21,1,0,0,(0|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    $45 = HEAP8[$0>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     break;
    }
    $48 = (($0) + 8|0);
    $49 = HEAP32[$48>>2]|0;
    __ZdlPv($49);
    break;
   }
   $50 = ___cxa_find_matching_catch()|0;
   $51 = tempRet0;
   $52 = HEAP8[$0>>0]|0;
   $53 = $52 & 1;
   $54 = ($53<<24>>24)==(0);
   if ($54) {
    ___resumeException($50|0);
    // unreachable;
   }
   $55 = (($0) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   __ZdlPv($56);
   ___resumeException($50|0);
   // unreachable;
  }
 } while(0);
 $57 = HEAP32[$dspMasterParent>>2]|0;
 $58 = ($57|0)==(0|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 HEAP32[$dspTarget>>2] = 0;
 $59 = HEAP32[$dspMaster>>2]|0;
 $60 = (__ZN4FMOD3DSP8getInputEiPPS0_PPNS_13DSPConnectionE($59,0,$dspTarget,0)|0);
 $61 = ($60|0)==(0);
 do {
  if (!($61)) {
   $62 = (__ZL16FMOD_ErrorString11FMOD_RESULT($60)|0);
   HEAP32[$vararg_buffer46>>2] = 712328;
   $vararg_ptr13 = (($vararg_buffer46) + 4|0);
   HEAP32[$vararg_ptr13>>2] = 698;
   $vararg_ptr14 = (($vararg_buffer46) + 8|0);
   HEAP32[$vararg_ptr14>>2] = 712624;
   $vararg_ptr15 = (($vararg_buffer46) + 12|0);
   HEAP32[$vararg_ptr15>>2] = $62;
   __Z6FormatPKcz($0,713760,$vararg_buffer46);
   $63 = HEAP8[$0>>0]|0;
   $64 = $63 & 1;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    $68 = (($0) + 1|0);
    $69 = $68;
   } else {
    $66 = (($0) + 8|0);
    $67 = HEAP32[$66>>2]|0;
    $69 = $67;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($69|0),0,(711992|0),21,1,0,0,(0|0));
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if (!($71)) {
    $72 = HEAP8[$0>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    if ($74) {
     break;
    }
    $75 = (($0) + 8|0);
    $76 = HEAP32[$75>>2]|0;
    __ZdlPv($76);
    break;
   }
   $77 = ___cxa_find_matching_catch()|0;
   $78 = tempRet0;
   $79 = HEAP8[$0>>0]|0;
   $80 = $79 & 1;
   $81 = ($80<<24>>24)==(0);
   if ($81) {
    ___resumeException($77|0);
    // unreachable;
   }
   $82 = (($0) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   __ZdlPv($83);
   ___resumeException($77|0);
   // unreachable;
  }
 } while(0);
 $84 = HEAP32[$dspTarget>>2]|0;
 $85 = ($84|0)==(0|0);
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = (__ZN4FMOD3DSP8getInputEiPPS0_PPNS_13DSPConnectionE($84,0,$dspTarget,0)|0);
 $87 = ($86|0)==(0);
 do {
  if (!($87)) {
   $88 = (__ZL16FMOD_ErrorString11FMOD_RESULT($86)|0);
   HEAP32[$vararg_buffer46>>2] = 712328;
   $vararg_ptr19 = (($vararg_buffer46) + 4|0);
   HEAP32[$vararg_ptr19>>2] = 701;
   $vararg_ptr20 = (($vararg_buffer46) + 8|0);
   HEAP32[$vararg_ptr20>>2] = 712672;
   $vararg_ptr21 = (($vararg_buffer46) + 12|0);
   HEAP32[$vararg_ptr21>>2] = $88;
   __Z6FormatPKcz($0,713760,$vararg_buffer46);
   $89 = HEAP8[$0>>0]|0;
   $90 = $89 & 1;
   $91 = ($90<<24>>24)==(0);
   if ($91) {
    $94 = (($0) + 1|0);
    $95 = $94;
   } else {
    $92 = (($0) + 8|0);
    $93 = HEAP32[$92>>2]|0;
    $95 = $93;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($95|0),0,(711992|0),21,1,0,0,(0|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if (!($97)) {
    $98 = HEAP8[$0>>0]|0;
    $99 = $98 & 1;
    $100 = ($99<<24>>24)==(0);
    if ($100) {
     break;
    }
    $101 = (($0) + 8|0);
    $102 = HEAP32[$101>>2]|0;
    __ZdlPv($102);
    break;
   }
   $103 = ___cxa_find_matching_catch()|0;
   $104 = tempRet0;
   $105 = HEAP8[$0>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    ___resumeException($103|0);
    // unreachable;
   }
   $108 = (($0) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   __ZdlPv($109);
   ___resumeException($103|0);
   // unreachable;
  }
 } while(0);
 $110 = HEAP32[$dspTarget>>2]|0;
 $111 = ($110|0)==(0|0);
 if ($111) {
  STACKTOP = sp;return;
 }
 HEAP32[$numInputs>>2] = 0;
 $112 = HEAP32[$dspMasterParent>>2]|0;
 $113 = (__ZN4FMOD3DSP12getNumInputsEPi($112,$numInputs)|0);
 $114 = ($113|0)==(0);
 do {
  if (!($114)) {
   $115 = (__ZL16FMOD_ErrorString11FMOD_RESULT($113)|0);
   HEAP32[$vararg_buffer46>>2] = 712328;
   $vararg_ptr25 = (($vararg_buffer46) + 4|0);
   HEAP32[$vararg_ptr25>>2] = 707;
   $vararg_ptr26 = (($vararg_buffer46) + 8|0);
   HEAP32[$vararg_ptr26>>2] = 712720;
   $vararg_ptr27 = (($vararg_buffer46) + 12|0);
   HEAP32[$vararg_ptr27>>2] = $115;
   __Z6FormatPKcz($2,713760,$vararg_buffer46);
   $116 = HEAP8[$2>>0]|0;
   $117 = $116 & 1;
   $118 = ($117<<24>>24)==(0);
   if ($118) {
    $121 = (($2) + 1|0);
    $122 = $121;
   } else {
    $119 = (($2) + 8|0);
    $120 = HEAP32[$119>>2]|0;
    $122 = $120;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($122|0),0,(711992|0),21,1,0,0,(0|0));
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if (!($124)) {
    $125 = HEAP8[$2>>0]|0;
    $126 = $125 & 1;
    $127 = ($126<<24>>24)==(0);
    if ($127) {
     break;
    }
    $128 = (($2) + 8|0);
    $129 = HEAP32[$128>>2]|0;
    __ZdlPv($129);
    break;
   }
   $140 = ___cxa_find_matching_catch()|0;
   $141 = tempRet0;
   $142 = HEAP8[$2>>0]|0;
   $143 = $142 & 1;
   $144 = ($143<<24>>24)==(0);
   if ($144) {
    ___resumeException($140|0);
    // unreachable;
   }
   $145 = (($2) + 8|0);
   $146 = HEAP32[$145>>2]|0;
   __ZdlPv($146);
   ___resumeException($140|0);
   // unreachable;
  }
 } while(0);
 $130 = HEAP32[$numInputs>>2]|0;
 $131 = ($130|0)>(0);
 if (!($131)) {
  STACKTOP = sp;return;
 }
 $132 = (($0) + 1|0);
 $133 = (($0) + 8|0);
 $134 = (($1) + 1|0);
 $135 = (($1) + 8|0);
 $136 = (($1) + 1|0);
 $137 = (($1) + 8|0);
 $138 = (($1) + 1|0);
 $139 = (($1) + 8|0);
 $n$042 = 0;
 while(1) {
  HEAP32[$dspToBeRerouted>>2] = 0;
  $147 = HEAP32[$dspMasterParent>>2]|0;
  $148 = (__ZN4FMOD3DSP8getInputEiPPS0_PPNS_13DSPConnectionE($147,$n$042,$dspToBeRerouted,0)|0);
  $149 = ($148|0)==(0);
  if (!($149)) {
   $150 = (__ZL16FMOD_ErrorString11FMOD_RESULT($148)|0);
   HEAP32[$vararg_buffer46>>2] = 712328;
   $vararg_ptr31 = (($vararg_buffer46) + 4|0);
   HEAP32[$vararg_ptr31>>2] = 711;
   $vararg_ptr32 = (($vararg_buffer46) + 8|0);
   HEAP32[$vararg_ptr32>>2] = 712768;
   $vararg_ptr33 = (($vararg_buffer46) + 12|0);
   HEAP32[$vararg_ptr33>>2] = $150;
   __Z6FormatPKcz($1,713760,$vararg_buffer46);
   $151 = HEAP8[$1>>0]|0;
   $152 = $151 & 1;
   $153 = ($152<<24>>24)==(0);
   $154 = HEAP32[$139>>2]|0;
   $$ = $153 ? $138 : $154;
   __THREW__ = 0;
   invoke_viiiiiiii(21,($$|0),0,(711992|0),21,1,0,0,(0|0));
   $155 = __THREW__; __THREW__ = 0;
   $156 = $155&1;
   if ($156) {
    label = 61;
    break;
   }
   $157 = HEAP8[$1>>0]|0;
   $158 = $157 & 1;
   $159 = ($158<<24>>24)==(0);
   if (!($159)) {
    $160 = HEAP32[$139>>2]|0;
    __ZdlPv($160);
   }
  }
  $167 = HEAP32[$dspToBeRerouted>>2]|0;
  $168 = ($167|0)==(0|0);
  if (!($168)) {
   $169 = (__ZN4FMOD3DSP7getInfoEPcPjPiS3_S3_($167,$namebuf,0,0,0,0)|0);
   $170 = ($169|0)==(0);
   if (!($170)) {
    $171 = (__ZL16FMOD_ErrorString11FMOD_RESULT($169)|0);
    HEAP32[$vararg_buffer46>>2] = 712328;
    $vararg_ptr37 = (($vararg_buffer46) + 4|0);
    HEAP32[$vararg_ptr37>>2] = 714;
    $vararg_ptr38 = (($vararg_buffer46) + 8|0);
    HEAP32[$vararg_ptr38>>2] = 712824;
    $vararg_ptr39 = (($vararg_buffer46) + 12|0);
    HEAP32[$vararg_ptr39>>2] = $171;
    __Z6FormatPKcz($1,713760,$vararg_buffer46);
    $172 = HEAP8[$1>>0]|0;
    $173 = $172 & 1;
    $174 = ($173<<24>>24)==(0);
    $175 = HEAP32[$137>>2]|0;
    $$43 = $174 ? $136 : $175;
    __THREW__ = 0;
    invoke_viiiiiiii(21,($$43|0),0,(711992|0),21,1,0,0,(0|0));
    $176 = __THREW__; __THREW__ = 0;
    $177 = $176&1;
    if ($177) {
     label = 69;
     break;
    }
    $178 = HEAP8[$1>>0]|0;
    $179 = $178 & 1;
    $180 = ($179<<24>>24)==(0);
    if (!($180)) {
     $181 = HEAP32[$137>>2]|0;
     __ZdlPv($181);
    }
   }
   $188 = (_memcmp($namebuf,712888,11)|0);
   $189 = ($188|0)==(0);
   if ($189) {
    $190 = HEAP32[$dspToBeRerouted>>2]|0;
    $191 = (__ZN4FMOD3DSP13disconnectAllEbb($190,0,1)|0);
    $192 = ($191|0)==(0);
    if (!($192)) {
     $193 = (__ZL16FMOD_ErrorString11FMOD_RESULT($191)|0);
     HEAP32[$vararg_buffer46>>2] = 712328;
     $vararg_ptr43 = (($vararg_buffer46) + 4|0);
     HEAP32[$vararg_ptr43>>2] = 717;
     $vararg_ptr44 = (($vararg_buffer46) + 8|0);
     HEAP32[$vararg_ptr44>>2] = 712904;
     $vararg_ptr45 = (($vararg_buffer46) + 12|0);
     HEAP32[$vararg_ptr45>>2] = $193;
     __Z6FormatPKcz($1,713760,$vararg_buffer46);
     $194 = HEAP8[$1>>0]|0;
     $195 = $194 & 1;
     $196 = ($195<<24>>24)==(0);
     $197 = HEAP32[$135>>2]|0;
     $$44 = $196 ? $134 : $197;
     __THREW__ = 0;
     invoke_viiiiiiii(21,($$44|0),0,(711992|0),21,1,0,0,(0|0));
     $198 = __THREW__; __THREW__ = 0;
     $199 = $198&1;
     if ($199) {
      label = 77;
      break;
     }
     $200 = HEAP8[$1>>0]|0;
     $201 = $200 & 1;
     $202 = ($201<<24>>24)==(0);
     if (!($202)) {
      $203 = HEAP32[$135>>2]|0;
      __ZdlPv($203);
     }
    }
    $210 = HEAP32[$dspTarget>>2]|0;
    $211 = HEAP32[$dspToBeRerouted>>2]|0;
    $212 = (__ZN4FMOD3DSP8addInputEPS0_PPNS_13DSPConnectionE($210,$211,0)|0);
    $213 = ($212|0)==(0);
    if (!($213)) {
     $214 = (__ZL16FMOD_ErrorString11FMOD_RESULT($212)|0);
     HEAP32[$vararg_buffer46>>2] = 712328;
     $vararg_ptr49 = (($vararg_buffer46) + 4|0);
     HEAP32[$vararg_ptr49>>2] = 718;
     $vararg_ptr50 = (($vararg_buffer46) + 8|0);
     HEAP32[$vararg_ptr50>>2] = 712952;
     $vararg_ptr51 = (($vararg_buffer46) + 12|0);
     HEAP32[$vararg_ptr51>>2] = $214;
     __Z6FormatPKcz($0,713760,$vararg_buffer46);
     $215 = HEAP8[$0>>0]|0;
     $216 = $215 & 1;
     $217 = ($216<<24>>24)==(0);
     $218 = HEAP32[$133>>2]|0;
     $$45 = $217 ? $132 : $218;
     __THREW__ = 0;
     invoke_viiiiiiii(21,($$45|0),0,(711992|0),21,1,0,0,(0|0));
     $219 = __THREW__; __THREW__ = 0;
     $220 = $219&1;
     if ($220) {
      label = 84;
      break;
     }
     $221 = HEAP8[$0>>0]|0;
     $222 = $221 & 1;
     $223 = ($222<<24>>24)==(0);
     if (!($223)) {
      $224 = HEAP32[$133>>2]|0;
      __ZdlPv($224);
     }
    }
   }
  }
  $231 = (($n$042) + 1)|0;
  $232 = HEAP32[$numInputs>>2]|0;
  $233 = ($231|0)<($232|0);
  if ($233) {
   $n$042 = $231;
  } else {
   label = 88;
   break;
  }
 }
 if ((label|0) == 61) {
  $161 = ___cxa_find_matching_catch()|0;
  $162 = tempRet0;
  $163 = HEAP8[$1>>0]|0;
  $164 = $163 & 1;
  $165 = ($164<<24>>24)==(0);
  if ($165) {
   ___resumeException($161|0);
   // unreachable;
  }
  $166 = HEAP32[$139>>2]|0;
  __ZdlPv($166);
  ___resumeException($161|0);
  // unreachable;
 }
 else if ((label|0) == 69) {
  $182 = ___cxa_find_matching_catch()|0;
  $183 = tempRet0;
  $184 = HEAP8[$1>>0]|0;
  $185 = $184 & 1;
  $186 = ($185<<24>>24)==(0);
  if ($186) {
   ___resumeException($182|0);
   // unreachable;
  }
  $187 = HEAP32[$137>>2]|0;
  __ZdlPv($187);
  ___resumeException($182|0);
  // unreachable;
 }
 else if ((label|0) == 77) {
  $204 = ___cxa_find_matching_catch()|0;
  $205 = tempRet0;
  $206 = HEAP8[$1>>0]|0;
  $207 = $206 & 1;
  $208 = ($207<<24>>24)==(0);
  if ($208) {
   ___resumeException($204|0);
   // unreachable;
  }
  $209 = HEAP32[$135>>2]|0;
  __ZdlPv($209);
  ___resumeException($204|0);
  // unreachable;
 }
 else if ((label|0) == 84) {
  $225 = ___cxa_find_matching_catch()|0;
  $226 = tempRet0;
  $227 = HEAP8[$0>>0]|0;
  $228 = $227 & 1;
  $229 = ($228<<24>>24)==(0);
  if ($229) {
   ___resumeException($225|0);
   // unreachable;
  }
  $230 = HEAP32[$133>>2]|0;
  __ZdlPv($230);
  ___resumeException($225|0);
  // unreachable;
 }
 else if ((label|0) == 88) {
  STACKTOP = sp;return;
 }
}
function __ZN12AudioManager29ShutdownReinitializeAndReloadEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$93 = 0, $$94 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $__new_last2$i$i$i$i$i19 = 0, $__new_last2$i$i$i$i$i28 = 0, $__new_last2$i$i$i$i$i3 = 0, $__new_last2$i$i$i$i$i36 = 0, $audioClips = 0, $audioSources = 0, $customFilter = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi77$index = 0, $lpad$phi77$index8 = 0, $lpad$phi89$index = 0, $lpad$phi89$index2 = 0, $monoBehaviours = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep$i$i$i$i$i20 = 0;
 var $scevgep$i$i$i$i$i29 = 0, $scevgep$i$i$i$i$i37 = 0, $scevgep$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0, $scevgep4$i$i$i$i$i24 = 0, $scevgep4$i$i$i$i$i33 = 0, $scevgep4$i$i$i$i$i41 = 0, $scevgep4$i$i$i$i$i8 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep$i$i$i$i$i31 = 0, $uglygep$i$i$i$i$i39 = 0, $uglygep$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep3$i$i$i$i$i32 = 0, $uglygep3$i$i$i$i$i40 = 0;
 var $uglygep3$i$i$i$i$i7 = 0, $vararg_buffer41 = 0, $vararg_ptr32 = 0, $vararg_ptr33 = 0, $vararg_ptr34 = 0, $vararg_ptr38 = 0, $vararg_ptr39 = 0, $vararg_ptr40 = 0, $vararg_ptr44 = 0, $vararg_ptr45 = 0, $vararg_ptr46 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $vararg_buffer41 = sp;
 $0 = sp + 80|0;
 $1 = sp + 16|0;
 $2 = sp + 28|0;
 $audioClips = sp + 40|0;
 $audioSources = sp + 52|0;
 $monoBehaviours = sp + 64|0;
 $customFilter = sp + 76|0;
 __ZN12AudioManager9CloseFMODEv($this);
 (__ZN12AudioManager8InitFMODEv($this)|0);
 HEAP32[$audioClips>>2] = 0;
 $3 = (($audioClips) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($audioClips) + 8|0);
 HEAP32[$4>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,83,($audioClips|0),0)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   $19 = ___cxa_find_matching_catch()|0;
   $20 = tempRet0;
   $lpad$phi89$index = $19;$lpad$phi89$index2 = $20;
   label = 7;
  } else {
   $7 = HEAP32[$audioClips>>2]|0;
   $8 = HEAP32[$3>>2]|0;
   $9 = ($7|0)==($8|0);
   L4: do {
    if (!($9)) {
     $11 = $7;
     while(1) {
      $10 = HEAP32[$11>>2]|0;
      __THREW__ = 0;
      invoke_vi(3656,($10|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      $14 = (($11) + 4|0);
      $15 = HEAP32[$3>>2]|0;
      $16 = ($14|0)==($15|0);
      if ($16) {
       break L4;
      } else {
       $11 = $14;
      }
     }
     $17 = ___cxa_find_matching_catch()|0;
     $18 = tempRet0;
     $lpad$phi89$index = $17;$lpad$phi89$index2 = $18;
     label = 7;
     break L1;
    }
   } while(0);
   HEAP32[$audioSources>>2] = 0;
   $21 = (($audioSources) + 4|0);
   HEAP32[$21>>2] = 0;
   $22 = (($audioSources) + 8|0);
   HEAP32[$22>>2] = 0;
   __THREW__ = 0;
   (invoke_iiii(1530,82,($audioSources|0),0)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   L10: do {
    if ($24) {
     $42 = ___cxa_find_matching_catch()|0;
     $43 = tempRet0;
     $lpad$phi77$index = $42;$lpad$phi77$index8 = $43;
     label = 15;
    } else {
     $25 = HEAP32[$audioSources>>2]|0;
     $26 = HEAP32[$21>>2]|0;
     $27 = ($25|0)==($26|0);
     L13: do {
      if (!($27)) {
       $29 = $25;
       while(1) {
        $28 = HEAP32[$29>>2]|0;
        $30 = HEAP32[$28>>2]|0;
        $31 = (($30) + 12|0);
        $32 = HEAP32[$31>>2]|0;
        __THREW__ = 0;
        invoke_vii($32|0,($28|0),0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break;
        }
        $35 = (($29) + 4|0);
        $36 = HEAP32[$21>>2]|0;
        $37 = ($35|0)==($36|0);
        if ($37) {
         break L13;
        } else {
         $29 = $35;
        }
       }
       $40 = ___cxa_find_matching_catch()|0;
       $41 = tempRet0;
       $lpad$phi77$index = $40;$lpad$phi77$index8 = $41;
       label = 15;
       break L10;
      }
     } while(0);
     $44 = (($this) + 60|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($this) + 56|0);
     $47 = ($45|0)==($46|0);
     L19: do {
      if (!($47)) {
       $49 = $45;
       while(1) {
        $48 = (($49) + 8|0);
        $50 = HEAP32[$48>>2]|0;
        __THREW__ = 0;
        invoke_vi(3657,($50|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
        $53 = (($49) + 4|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = ($54|0)==($46|0);
        if ($55) {
         break L19;
        } else {
         $49 = $54;
        }
       }
       $38 = ___cxa_find_matching_catch()|0;
       $39 = tempRet0;
       $lpad$phi77$index = $38;$lpad$phi77$index8 = $39;
       label = 15;
       break L10;
      }
     } while(0);
     HEAP32[$monoBehaviours>>2] = 0;
     $56 = (($monoBehaviours) + 4|0);
     HEAP32[$56>>2] = 0;
     $57 = (($monoBehaviours) + 8|0);
     HEAP32[$57>>2] = 0;
     __THREW__ = 0;
     (invoke_iiii(1530,114,($monoBehaviours|0),0)|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     L25: do {
      if ($59) {
       $129 = ___cxa_find_matching_catch()|0;
       $130 = tempRet0;
       $eh$lpad$body$index21Z2D = $130;$eh$lpad$body$indexZ2D = $129;
      } else {
       $60 = HEAP32[$monoBehaviours>>2]|0;
       $61 = HEAP32[$56>>2]|0;
       $62 = ($60|0)==($61|0);
       L28: do {
        if (!($62)) {
         $63 = (($1) + 1|0);
         $64 = (($1) + 8|0);
         $65 = (($0) + 1|0);
         $66 = (($2) + 1|0);
         $67 = (($2) + 8|0);
         $68 = (($0) + 8|0);
         $70 = $60;
         L30: while(1) {
          $69 = HEAP32[$70>>2]|0;
          __THREW__ = 0;
          $71 = (invoke_ii(3386,($69|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           label = 41;
           break;
          }
          $74 = ($71|0)==(0|0);
          do {
           if (!($74)) {
            HEAP32[$customFilter>>2] = 0;
            __THREW__ = 0;
            $75 = (invoke_iii(2564,($71|0),($customFilter|0))|0);
            $76 = __THREW__; __THREW__ = 0;
            $77 = $76&1;
            if ($77) {
             label = 41;
             break L30;
            }
            $78 = ($75|0)==(0);
            if ($78) {
             $98 = HEAP32[$customFilter>>2]|0;
             $99 = (($98) + 13|0);
             $100 = HEAP8[$99>>0]|0;
             $101 = ($100<<24>>24)!=(0);
             __THREW__ = 0;
             $102 = (invoke_iii(2571,($71|0),($101|0))|0);
             $103 = __THREW__; __THREW__ = 0;
             $104 = $103&1;
             if ($104) {
              label = 41;
              break L30;
             }
             $105 = ($102|0)==(0);
             if ($105) {
              break;
             }
             $106 = (__ZL16FMOD_ErrorString11FMOD_RESULT($102)|0);
             __THREW__ = 0;
             HEAP32[$vararg_buffer41>>2] = 712328;
             $vararg_ptr38 = (($vararg_buffer41) + 4|0);
             HEAP32[$vararg_ptr38>>2] = 770;
             $vararg_ptr39 = (($vararg_buffer41) + 8|0);
             HEAP32[$vararg_ptr39>>2] = 713056;
             $vararg_ptr40 = (($vararg_buffer41) + 12|0);
             HEAP32[$vararg_ptr40>>2] = $106;
             invoke_viii(1617,($1|0),(713760|0),($vararg_buffer41|0));
             $107 = __THREW__; __THREW__ = 0;
             $108 = $107&1;
             if ($108) {
              label = 41;
              break L30;
             }
             $109 = HEAP8[$1>>0]|0;
             $110 = $109 & 1;
             $111 = ($110<<24>>24)==(0);
             $112 = HEAP32[$64>>2]|0;
             $$93 = $111 ? $63 : $112;
             __THREW__ = 0;
             invoke_viiiiiiii(21,($$93|0),0,(711992|0),21,1,0,0,(0|0));
             $113 = __THREW__; __THREW__ = 0;
             $114 = $113&1;
             if ($114) {
              label = 38;
              break L30;
             }
             $115 = HEAP8[$1>>0]|0;
             $116 = $115 & 1;
             $117 = ($116<<24>>24)==(0);
             if ($117) {
              break;
             }
             $118 = HEAP32[$64>>2]|0;
             __ZdlPv($118);
             break;
            }
            $79 = (__ZL16FMOD_ErrorString11FMOD_RESULT($75)|0);
            __THREW__ = 0;
            HEAP32[$vararg_buffer41>>2] = 712328;
            $vararg_ptr32 = (($vararg_buffer41) + 4|0);
            HEAP32[$vararg_ptr32>>2] = 768;
            $vararg_ptr33 = (($vararg_buffer41) + 8|0);
            HEAP32[$vararg_ptr33>>2] = 713000;
            $vararg_ptr34 = (($vararg_buffer41) + 12|0);
            HEAP32[$vararg_ptr34>>2] = $79;
            invoke_viii(1617,($0|0),(713760|0),($vararg_buffer41|0));
            $80 = __THREW__; __THREW__ = 0;
            $81 = $80&1;
            if ($81) {
             label = 41;
             break L30;
            }
            $82 = HEAP8[$0>>0]|0;
            $83 = $82 & 1;
            $84 = ($83<<24>>24)==(0);
            $85 = HEAP32[$68>>2]|0;
            $$ = $84 ? $65 : $85;
            __THREW__ = 0;
            invoke_viiiiiiii(21,($$|0),0,(711992|0),21,1,0,0,(0|0));
            $86 = __THREW__; __THREW__ = 0;
            $87 = $86&1;
            if ($87) {
             label = 30;
             break L30;
            }
            $88 = HEAP8[$0>>0]|0;
            $89 = $88 & 1;
            $90 = ($89<<24>>24)==(0);
            if (!($90)) {
             $91 = HEAP32[$68>>2]|0;
             __ZdlPv($91);
            }
            $138 = (($69) + 28|0);
            $139 = HEAP8[$138>>0]|0;
            $140 = ($139<<24>>24)==(0);
            __THREW__ = 0;
            $141 = (invoke_iii(2571,($71|0),($140|0))|0);
            $142 = __THREW__; __THREW__ = 0;
            $143 = $142&1;
            if ($143) {
             label = 41;
             break L30;
            }
            $144 = ($141|0)==(0);
            if ($144) {
             break;
            }
            $145 = (__ZL16FMOD_ErrorString11FMOD_RESULT($141)|0);
            __THREW__ = 0;
            HEAP32[$vararg_buffer41>>2] = 712328;
            $vararg_ptr44 = (($vararg_buffer41) + 4|0);
            HEAP32[$vararg_ptr44>>2] = 772;
            $vararg_ptr45 = (($vararg_buffer41) + 8|0);
            HEAP32[$vararg_ptr45>>2] = 713112;
            $vararg_ptr46 = (($vararg_buffer41) + 12|0);
            HEAP32[$vararg_ptr46>>2] = $145;
            invoke_viii(1617,($2|0),(713760|0),($vararg_buffer41|0));
            $146 = __THREW__; __THREW__ = 0;
            $147 = $146&1;
            if ($147) {
             label = 41;
             break L30;
            }
            $148 = HEAP8[$2>>0]|0;
            $149 = $148 & 1;
            $150 = ($149<<24>>24)==(0);
            $151 = HEAP32[$67>>2]|0;
            $$94 = $150 ? $66 : $151;
            __THREW__ = 0;
            invoke_viiiiiiii(21,($$94|0),0,(711992|0),21,1,0,0,(0|0));
            $152 = __THREW__; __THREW__ = 0;
            $153 = $152&1;
            if ($153) {
             label = 53;
             break L30;
            }
            $154 = HEAP8[$2>>0]|0;
            $155 = $154 & 1;
            $156 = ($155<<24>>24)==(0);
            if ($156) {
             break;
            }
            $157 = HEAP32[$67>>2]|0;
            __ZdlPv($157);
           }
          } while(0);
          $164 = (($70) + 4|0);
          $165 = HEAP32[$56>>2]|0;
          $166 = ($164|0)==($165|0);
          if ($166) {
           break L28;
          } else {
           $70 = $164;
          }
         }
         if ((label|0) == 30) {
          $92 = ___cxa_find_matching_catch()|0;
          $93 = tempRet0;
          $94 = HEAP8[$0>>0]|0;
          $95 = $94 & 1;
          $96 = ($95<<24>>24)==(0);
          if ($96) {
           $eh$lpad$body$index21Z2D = $93;$eh$lpad$body$indexZ2D = $92;
           break L25;
          }
          $97 = HEAP32[$68>>2]|0;
          __ZdlPv($97);
          $eh$lpad$body$index21Z2D = $93;$eh$lpad$body$indexZ2D = $92;
          break L25;
         }
         else if ((label|0) == 38) {
          $119 = ___cxa_find_matching_catch()|0;
          $120 = tempRet0;
          $121 = HEAP8[$1>>0]|0;
          $122 = $121 & 1;
          $123 = ($122<<24>>24)==(0);
          if ($123) {
           $eh$lpad$body$index21Z2D = $120;$eh$lpad$body$indexZ2D = $119;
           break L25;
          }
          $124 = HEAP32[$64>>2]|0;
          __ZdlPv($124);
          $eh$lpad$body$index21Z2D = $120;$eh$lpad$body$indexZ2D = $119;
          break L25;
         }
         else if ((label|0) == 41) {
          $127 = ___cxa_find_matching_catch()|0;
          $128 = tempRet0;
          $eh$lpad$body$index21Z2D = $128;$eh$lpad$body$indexZ2D = $127;
          break L25;
         }
         else if ((label|0) == 53) {
          $158 = ___cxa_find_matching_catch()|0;
          $159 = tempRet0;
          $160 = HEAP8[$2>>0]|0;
          $161 = $160 & 1;
          $162 = ($161<<24>>24)==(0);
          if ($162) {
           $eh$lpad$body$index21Z2D = $159;$eh$lpad$body$indexZ2D = $158;
           break L25;
          }
          $163 = HEAP32[$67>>2]|0;
          __ZdlPv($163);
          $eh$lpad$body$index21Z2D = $159;$eh$lpad$body$indexZ2D = $158;
          break L25;
         }
        }
       } while(0);
       $167 = (($this) + 88|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = (($this) + 84|0);
       $170 = ($168|0)==($169|0);
       L64: do {
        if (!($170)) {
         $172 = $168;
         while(1) {
          $171 = (($172) + 8|0);
          $173 = HEAP32[$171>>2]|0;
          __THREW__ = 0;
          invoke_vi(3658,($173|0));
          $174 = __THREW__; __THREW__ = 0;
          $175 = $174&1;
          if ($175) {
           break;
          }
          $176 = (($172) + 4|0);
          $177 = HEAP32[$176>>2]|0;
          $178 = ($177|0)==($169|0);
          if ($178) {
           break L64;
          } else {
           $172 = $177;
          }
         }
         $125 = ___cxa_find_matching_catch()|0;
         $126 = tempRet0;
         $eh$lpad$body$index21Z2D = $126;$eh$lpad$body$indexZ2D = $125;
         break L25;
        }
       } while(0);
       $179 = HEAP32[$monoBehaviours>>2]|0;
       $180 = ($179|0)==(0|0);
       if (!($180)) {
        $181 = HEAP32[$56>>2]|0;
        $182 = ($181|0)==($179|0);
        if (!($182)) {
         $__new_last2$i$i$i$i$i28 = $179;
         $scevgep$i$i$i$i$i29 = (($181) + -4|0);
         $183 = (0 - ($__new_last2$i$i$i$i$i28))|0;
         $uglygep$i$i$i$i$i31 = (($scevgep$i$i$i$i$i29) + ($183)|0);
         $uglygep3$i$i$i$i$i32 = $uglygep$i$i$i$i$i31;
         $184 = $uglygep3$i$i$i$i$i32 >>> 2;
         $185 = $184 ^ -1;
         $scevgep4$i$i$i$i$i33 = (($181) + ($185<<2)|0);
         HEAP32[$56>>2] = $scevgep4$i$i$i$i$i33;
        }
        __ZdlPv($179);
       }
       $186 = HEAP32[$audioSources>>2]|0;
       $187 = ($186|0)==(0|0);
       if (!($187)) {
        $188 = HEAP32[$21>>2]|0;
        $189 = ($188|0)==($186|0);
        if (!($189)) {
         $__new_last2$i$i$i$i$i19 = $186;
         $scevgep$i$i$i$i$i20 = (($188) + -4|0);
         $190 = (0 - ($__new_last2$i$i$i$i$i19))|0;
         $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($190)|0);
         $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
         $191 = $uglygep3$i$i$i$i$i23 >>> 2;
         $192 = $191 ^ -1;
         $scevgep4$i$i$i$i$i24 = (($188) + ($192<<2)|0);
         HEAP32[$21>>2] = $scevgep4$i$i$i$i$i24;
        }
        __ZdlPv($186);
       }
       $193 = HEAP32[$audioClips>>2]|0;
       $194 = ($193|0)==(0|0);
       if ($194) {
        STACKTOP = sp;return;
       }
       $195 = HEAP32[$3>>2]|0;
       $196 = ($195|0)==($193|0);
       if (!($196)) {
        $__new_last2$i$i$i$i$i10 = $193;
        $scevgep$i$i$i$i$i11 = (($195) + -4|0);
        $197 = (0 - ($__new_last2$i$i$i$i$i10))|0;
        $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($197)|0);
        $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
        $198 = $uglygep3$i$i$i$i$i14 >>> 2;
        $199 = $198 ^ -1;
        $scevgep4$i$i$i$i$i15 = (($195) + ($199<<2)|0);
        HEAP32[$3>>2] = $scevgep4$i$i$i$i$i15;
       }
       __ZdlPv($193);
       STACKTOP = sp;return;
      }
     } while(0);
     $131 = HEAP32[$monoBehaviours>>2]|0;
     $132 = ($131|0)==(0|0);
     if ($132) {
      $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index21Z2D;
     } else {
      $133 = HEAP32[$56>>2]|0;
      $134 = ($133|0)==($131|0);
      if (!($134)) {
       $__new_last2$i$i$i$i$i36 = $131;
       $scevgep$i$i$i$i$i37 = (($133) + -4|0);
       $135 = (0 - ($__new_last2$i$i$i$i$i36))|0;
       $uglygep$i$i$i$i$i39 = (($scevgep$i$i$i$i$i37) + ($135)|0);
       $uglygep3$i$i$i$i$i40 = $uglygep$i$i$i$i$i39;
       $136 = $uglygep3$i$i$i$i$i40 >>> 2;
       $137 = $136 ^ -1;
       $scevgep4$i$i$i$i$i41 = (($133) + ($137<<2)|0);
       HEAP32[$56>>2] = $scevgep4$i$i$i$i$i41;
      }
      __ZdlPv($131);
      $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index21Z2D;
     }
    }
   } while(0);
   if ((label|0) == 15) {
    $$0 = $lpad$phi77$index;$$01 = $lpad$phi77$index8;
   }
   $200 = HEAP32[$audioSources>>2]|0;
   $201 = ($200|0)==(0|0);
   if ($201) {
    $$1 = $$0;$$12 = $$01;
   } else {
    $202 = HEAP32[$21>>2]|0;
    $203 = ($202|0)==($200|0);
    if (!($203)) {
     $__new_last2$i$i$i$i$i3 = $200;
     $scevgep$i$i$i$i$i4 = (($202) + -4|0);
     $204 = (0 - ($__new_last2$i$i$i$i$i3))|0;
     $uglygep$i$i$i$i$i6 = (($scevgep$i$i$i$i$i4) + ($204)|0);
     $uglygep3$i$i$i$i$i7 = $uglygep$i$i$i$i$i6;
     $205 = $uglygep3$i$i$i$i$i7 >>> 2;
     $206 = $205 ^ -1;
     $scevgep4$i$i$i$i$i8 = (($202) + ($206<<2)|0);
     HEAP32[$21>>2] = $scevgep4$i$i$i$i$i8;
    }
    __ZdlPv($200);
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $$1 = $lpad$phi89$index;$$12 = $lpad$phi89$index2;
 }
 $207 = HEAP32[$audioClips>>2]|0;
 $208 = ($207|0)==(0|0);
 if ($208) {
  ___resumeException($$1|0);
  // unreachable;
 }
 $209 = HEAP32[$3>>2]|0;
 $210 = ($209|0)==($207|0);
 if (!($210)) {
  $__new_last2$i$i$i$i$i = $207;
  $scevgep$i$i$i$i$i = (($209) + -4|0);
  $211 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($211)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $212 = $uglygep3$i$i$i$i$i >>> 2;
  $213 = $212 ^ -1;
  $scevgep4$i$i$i$i$i = (($209) + ($213<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($207);
 ___resumeException($$1|0);
 // unreachable;
}
function __ZN12AudioManager22CreateFMODSoundFromWWWEP3WWW15FMOD_SOUND_TYPE17FMOD_SOUND_FORMATjjbPv($this,$webStream,$suggestedtype,$format,$freq,$channels,$stream,$allocationRoot) {
 $this = $this|0;
 $webStream = $webStream|0;
 $suggestedtype = $suggestedtype|0;
 $format = $format|0;
 $freq = $freq|0;
 $channels = $channels|0;
 $stream = $stream|0;
 $allocationRoot = $allocationRoot|0;
 var $$ = 0, $$$v = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exInfo = 0, $sound = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $sound = sp + 136|0;
 $exInfo = sp;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 HEAP32[$sound>>2] = 0;
 _memset(($exInfo|0),0,136)|0;
 HEAP32[$exInfo>>2] = 136;
 $3 = (($exInfo) + 24|0);
 HEAP32[$3>>2] = 16384;
 $4 = (($exInfo) + 72|0);
 HEAP32[$4>>2] = $suggestedtype;
 $5 = (($exInfo) + 20|0);
 HEAP32[$5>>2] = $format;
 $6 = (($exInfo) + 16|0);
 HEAP32[$6>>2] = $freq;
 $7 = (($exInfo) + 12|0);
 HEAP32[$7>>2] = $channels;
 $8 = (($exInfo) + 76|0);
 HEAP32[$8>>2] = 212;
 $9 = (($exInfo) + 80|0);
 HEAP32[$9>>2] = 2572;
 $10 = (($exInfo) + 84|0);
 HEAP32[$10>>2] = 213;
 $11 = (($exInfo) + 88|0);
 HEAP32[$11>>2] = 1583;
 $12 = (($exInfo) + 68|0);
 HEAP32[$12>>2] = $webStream;
 $13 = $stream ? 208 : 336;
 $14 = ($suggestedtype|0)==(13);
 $15 = $14 ? 32768 : 33554432;
 $16 = ($suggestedtype|0)==(16);
 $$$v = $16 ? 4098 : 2;
 $17 = $$$v | $15;
 $$ = $17 | $13;
 $18 = (__ZN4FMOD6System11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOPPNS_5SoundE($1,$webStream,$$,$exInfo,$sound)|0);
 $19 = ($18|0)==(0);
 if ($19) {
  $23 = HEAP32[$sound>>2]|0;
  (__ZN4FMOD5Sound7setModeEj($23,1)|0);
  $24 = HEAP32[$sound>>2]|0;
  $$1 = $24;
  STACKTOP = sp;return ($$1|0);
 } else {
  $20 = (($this) + 164|0);
  $21 = (__ZL16FMOD_ErrorString11FMOD_RESULT($18)|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($20,$21)|0);
  $22 = (($this) + 176|0);
  HEAP32[$22>>2] = $18;
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZN12AudioManager24CreateFMODSoundFromMovieEP9AudioClip($this,$clip) {
 $this = $this|0;
 $clip = $clip|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exInfo = 0;
 var $sound = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $sound = sp + 136|0;
 $exInfo = sp;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 HEAP32[$sound>>2] = 0;
 _memset(($exInfo|0),0,136)|0;
 HEAP32[$exInfo>>2] = 136;
 $3 = (($exInfo) + 4|0);
 HEAP32[$3>>2] = -1;
 $4 = (($exInfo) + 24|0);
 HEAP32[$4>>2] = 4096;
 $5 = (($exInfo) + 20|0);
 HEAP32[$5>>2] = 2;
 $6 = (($exInfo) + 16|0);
 HEAP32[$6>>2] = 22050;
 $7 = (($exInfo) + 12|0);
 HEAP32[$7>>2] = 1;
 $8 = (($exInfo) + 44|0);
 HEAP32[$8>>2] = 1584;
 $9 = (($exInfo) + 68|0);
 HEAP32[$9>>2] = $clip;
 $10 = HEAP32[$0>>2]|0;
 $11 = (__ZN4FMOD6System11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOPPNS_5SoundE($10,0,33555666,$exInfo,$sound)|0);
 $12 = ($11|0)==(0);
 if ($12) {
  $16 = HEAP32[$sound>>2]|0;
  (__ZN4FMOD5Sound7setModeEj($16,1)|0);
  $17 = HEAP32[$sound>>2]|0;
  $$1 = $17;
  STACKTOP = sp;return ($$1|0);
 } else {
  $13 = (($this) + 164|0);
  $14 = (__ZL16FMOD_ErrorString11FMOD_RESULT($11)|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($13,$14)|0);
  $15 = (($this) + 176|0);
  HEAP32[$15>>2] = $11;
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 return 0|0;
}
function __ZN12AudioManager14UpdateListenerERK8Vector3fS2_S2_S2_($this,$position,$velocity,$up,$forward) {
 $this = $this|0;
 $position = $position|0;
 $velocity = $velocity|0;
 $up = $up|0;
 $forward = $forward|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 (__ZN4FMOD6System23set3DListenerAttributesEiPK11FMOD_VECTORS3_S3_S3_($1,0,$position,$velocity,$forward,$up)|0);
 STACKTOP = sp;return;
}
function __ZN12AudioManager22GetAutomaticUpdateModeEPN5Unity10GameObjectE($this,$go) {
 $this = $this|0;
 $go = $go|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $parent$0 = 0, $parent$0$in = 0, $parent$0$in1 = 0, $parent$02 = 0, $parent$03 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($go,54)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($go)|0);
 $parent$0$in1 = (($2) + 156|0);
 $parent$02 = HEAP32[$parent$0$in1>>2]|0;
 $3 = ($parent$02|0)==(0|0);
 if ($3) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 } else {
  $parent$03 = $parent$02;
 }
 while(1) {
  $4 = (($parent$03) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($5,54)|0);
   $phitmp = ($7|0)==(0|0);
   if (!($phitmp)) {
    $$0 = 1;
    label = 6;
    break;
   }
  }
  $parent$0$in = (($parent$03) + 156|0);
  $parent$0 = HEAP32[$parent$0$in>>2]|0;
  $8 = ($parent$0|0)==(0|0);
  if ($8) {
   $$0 = 2;
   label = 6;
   break;
  } else {
   $parent$03 = $parent$0;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN12AudioManager8SetPauseEb($this,$pause) {
 $this = $this|0;
 $pause = $pause|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $clockHi = 0, $clockLo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $clockLo = sp + 4|0;
 $clockHi = sp;
 $0 = (($this) + 36|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $pause&1;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $pause&1;
 HEAP8[$0>>0] = $5;
 $6 = (($this) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 (__ZN4FMOD6System11getDSPClockEPjS1_($7,$clockHi,$clockLo)|0);
 $8 = HEAP32[$clockHi>>2]|0;
 $9 = HEAP32[$clockLo>>2]|0;
 $10 = HEAP8[$0>>0]|0;
 $11 = ($10<<24>>24)==(0);
 $12 = (($this) + 192|0);
 if ($11) {
  $40 = $12;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = (_i64Subtract(($9|0),($8|0),($42|0),($45|0))|0);
  $47 = tempRet0;
  $48 = (($this) + 184|0);
  $49 = $48;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = (_i64Add(($51|0),($54|0),($46|0),($47|0))|0);
  $56 = tempRet0;
  $57 = $48;
  $58 = $57;
  HEAP32[$58>>2] = $55;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $61 = (($this) + 52|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($this) + 48|0);
  $64 = ($62|0)==($63|0);
  if (!($64)) {
   $66 = $62;
   while(1) {
    $65 = (($66) + 4|0);
    $67 = HEAP32[$65>>2]|0;
    $68 = (($66) + 8|0);
    $69 = HEAP32[$68>>2]|0;
    __ZN11AudioSource4PlayEd($69,0.0);
    $70 = (($69) + 482|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = (($69) + 483|0);
    $73 = HEAP8[$72>>0]|0;
    $74 = $73 | $71;
    $75 = ($74<<24>>24)==(0);
    if (!($75)) {
     __ZN11AudioSource32CorrectScheduledTimeAfterUnpauseEy($69,$46,$47);
    }
    $76 = ($67|0)==($63|0);
    if ($76) {
     break;
    } else {
     $66 = $67;
    }
   }
  }
  $77 = (($this) + 44|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($this) + 40|0);
  $80 = ($78|0)==($79|0);
  if ($80) {
   STACKTOP = sp;return;
  } else {
   $82 = $78;
  }
  while(1) {
   $81 = (($82) + 4|0);
   $83 = HEAP32[$81>>2]|0;
   $84 = (($82) + 8|0);
   $85 = HEAP32[$84>>2]|0;
   __ZN11AudioSource14ResumeOneShotsEv($85);
   $86 = ($83|0)==($79|0);
   if ($86) {
    break;
   } else {
    $82 = $83;
   }
  }
  STACKTOP = sp;return;
 }
 $13 = $12;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $8;
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = ($18|0)==($19|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 48|0);
 $23 = $18;
 while(1) {
  $22 = (($23) + 4|0);
  $24 = HEAP32[$22>>2]|0;
  $25 = (($23) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__ZNK11AudioSource9IsPlayingEv($26)|0);
  if ($27) {
   __ZN11AudioSource5PauseEv($26);
   $28 = (($26) + 420|0);
   $29 = ($28|0)==($21|0);
   if (!($29)) {
    $30 = HEAP32[$28>>2]|0;
    $31 = ($30|0)==(0|0);
    $$pre$i$i = (($26) + 424|0);
    if (!($31)) {
     $32 = HEAP32[$$pre$i$i>>2]|0;
     $33 = (($30) + 4|0);
     HEAP32[$33>>2] = $32;
     $34 = HEAP32[$28>>2]|0;
     $35 = HEAP32[$$pre$i$i>>2]|0;
     HEAP32[$35>>2] = $34;
     HEAP32[$28>>2] = 0;
     HEAP32[$$pre$i$i>>2] = 0;
    }
    $36 = HEAP32[$21>>2]|0;
    HEAP32[$28>>2] = $36;
    HEAP32[$$pre$i$i>>2] = $21;
    $37 = (($36) + 4|0);
    HEAP32[$37>>2] = $28;
    $38 = HEAP32[$$pre$i$i>>2]|0;
    HEAP32[$38>>2] = $28;
   }
  }
  __ZN11AudioSource13PauseOneShotsEv($26);
  $39 = ($24|0)==($19|0);
  if ($39) {
   break;
  } else {
   $23 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12AudioManager16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$$i = 0, $$$i1 = 0, $$$i10 = 0, $$$i12 = Math_fround(0), $$$i14 = Math_fround(0), $$$i17 = Math_fround(0), $$$i4 = 0, $$$i7 = 0, $$0$i = 0, $$0$i11 = 0, $$0$i13 = Math_fround(0), $$0$i15 = Math_fround(0), $$0$i18 = Math_fround(0), $$0$i2 = 0, $$0$i5 = 0, $$0$i8 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 < Math_fround(0.0);
 if ($2) {
  $$0$i18 = Math_fround(0.0);
 } else {
  $3 = $1 > Math_fround(1.0);
  $$$i17 = $3 ? Math_fround(1.0) : $1;
  $$0$i18 = $$$i17;
 }
 HEAPF32[$0>>2] = $$0$i18;
 $4 = (($this) + 32|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 < Math_fround(0.0);
 if ($6) {
  $$0$i15 = Math_fround(0.0);
 } else {
  $7 = $5 > Math_fround(10.0);
  $$$i14 = $7 ? Math_fround(10.0) : $5;
  $$0$i15 = $$$i14;
 }
 HEAPF32[$4>>2] = $$0$i15;
 $8 = (($this) + 80|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = $9 < Math_fround(0.0);
 if ($10) {
  $$0$i13 = Math_fround(0.0);
 } else {
  $11 = $9 > Math_fround(10.0);
  $$$i12 = $11 ? Math_fround(10.0) : $9;
  $$0$i13 = $$$i12;
 }
 HEAPF32[$8>>2] = $$0$i13;
 $12 = (($this) + 124|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)<(1);
 if ($14) {
  $$0$i11 = 1;
 } else {
  $15 = ($13|0)>(7);
  $$$i10 = $15 ? 7 : $13;
  $$0$i11 = $$$i10;
 }
 HEAP32[$12>>2] = $$0$i11;
 $16 = (($this) + 128|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)<(0);
 if ($18) {
  $$0$i8 = 0;
 } else {
  $19 = ($17|0)>(96000);
  $$$i7 = $19 ? 96000 : $17;
  $$0$i8 = $$$i7;
 }
 HEAP32[$16>>2] = $$0$i8;
 $20 = (($this) + 132|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)<(0);
 if ($22) {
  $$0$i5 = 0;
 } else {
  $23 = ($21|0)>(8192);
  $$$i4 = $23 ? 8192 : $21;
  $$0$i5 = $$$i4;
 }
 HEAP32[$20>>2] = $$0$i5;
 $24 = (($this) + 136|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)<(1);
 if ($26) {
  $$0$i2 = 1;
 } else {
  $27 = ($25|0)>(4095);
  $$$i1 = $27 ? 4095 : $25;
  $$0$i2 = $$$i1;
 }
 HEAP32[$24>>2] = $$0$i2;
 $28 = (($this) + 140|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)<(1);
 if ($30) {
  $$0$i = 1;
  HEAP32[$28>>2] = $$0$i;
  STACKTOP = sp;return;
 }
 $31 = ($29|0)>(255);
 $$$i = $31 ? 255 : $29;
 $$0$i = $$$i;
 HEAP32[$28>>2] = $$0$i;
 STACKTOP = sp;return;
}
function __ZN12AudioManager13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  (__ZN12AudioManager8InitFMODEv($this)|0);
  $3 = (($this) + 36|0);
  HEAP8[$3>>0] = 0;
  $$pr = HEAP32[$0>>2]|0;
  $4 = ($$pr|0)==(0|0);
  if ($4) {
   STACKTOP = sp;return;
  }
 }
 $5 = (($this) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 128|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  $10 = (($this) + 152|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($this) + 132|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  if ($14) {
   $15 = (($this) + 144|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($this) + 124|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)==($18|0);
   if ($19) {
    $20 = (($this) + 156|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($this) + 136|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($21|0)==($23|0);
    if ($24) {
     $25 = (($this) + 160|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($this) + 140|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($26|0)==($28|0);
     if (!($29)) {
      label = 8;
     }
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  __ZN12AudioManager29ShutdownReinitializeAndReloadEv($this);
  $30 = HEAP32[$0>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   STACKTOP = sp;return;
  }
 }
 $32 = (($this) + 24|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = (($this) + 28|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($this) + 104|0);
 $36 = HEAP32[$35>>2]|0;
 (__ZN4FMOD12ChannelGroup9setVolumeEf($36,$33)|0);
 $37 = (($this) + 112|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = Math_fround(HEAPF32[$34>>2]);
 (__ZN4FMOD12ChannelGroup9setVolumeEf($38,$39)|0);
 $40 = HEAP32[$0>>2]|0;
 $41 = (($this) + 80|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 32|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 (__ZN4FMOD6System13set3DSettingsEfff($40,$42,Math_fround(1.0),$44)|0);
 STACKTOP = sp;return;
}
function __ZN12AudioManager23ProcessScheduledSourcesEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $hiclock = 0, $loclock = 0, $node$01$i = 0, $sampleRate = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $hiclock = sp + 8|0;
 $loclock = sp;
 $sampleRate = sp + 4|0;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 (__ZN4FMOD6System11getDSPClockEPjS1_($1,$hiclock,$loclock)|0);
 $2 = (($this) + 64|0);
 $3 = (($this) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if ($5) {
  $85 = $4;
 } else {
  $6 = (($this) + 184|0);
  $7 = (($this) + 36|0);
  $8 = (($this) + 48|0);
  $9 = (($this) + 40|0);
  $11 = $4;
  while(1) {
   $10 = (($11) + 8|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = (($11) + 16|0);
   $14 = +HEAPF64[$13>>3];
   $15 = $14 != 0.0;
   if ($15) {
    $16 = HEAP32[$0>>2]|0;
    (__ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($16,$sampleRate,0,0,0,0,0)|0);
    $17 = +HEAPF64[$13>>3];
    $18 = $17 > 0.0;
    if ($18) {
     $19 = HEAP32[$sampleRate>>2]|0;
     $20 = (+($19|0));
     $21 = $17 * $20;
     $22 = (~~$21)>>>0;
     $23 = +Math_abs($21) >= 1.0 ? $21 > 0.0 ? (Math_min(+Math_floor($21 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($21 - +(~~$21 >>> 0)) / 4294967296.0) >>> 0 : 0;
     $24 = $6;
     $25 = $24;
     $26 = HEAP32[$25>>2]|0;
     $27 = (($24) + 4)|0;
     $28 = $27;
     $29 = HEAP32[$28>>2]|0;
     $30 = (_i64Add(($22|0),($23|0),($26|0),($29|0))|0);
     $31 = tempRet0;
     $32 = (($12) + 444|0);
     $33 = HEAP32[$32>>2]|0;
     (__ZN20SoundChannelInstance8setDelayE14FMOD_DELAYTYPEjj($33,1,$31,$30)|0);
    } else {
     $34 = HEAP32[$hiclock>>2]|0;
     $35 = HEAP32[$loclock>>2]|0;
     $36 = HEAP32[$sampleRate>>2]|0;
     $37 = (+($36|0));
     $38 = $17 * $37;
     $39 = -$38;
     $40 = (~~$39)>>>0;
     $41 = +Math_abs($39) >= 1.0 ? $39 > 0.0 ? (Math_min(+Math_floor($39 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($39 - +(~~$39 >>> 0)) / 4294967296.0) >>> 0 : 0;
     $42 = (_i64Add(($40|0),($41|0),($35|0),($34|0))|0);
     $43 = tempRet0;
     $44 = (($12) + 444|0);
     $45 = HEAP32[$44>>2]|0;
     (__ZN20SoundChannelInstance8setDelayE14FMOD_DELAYTYPEjj($45,1,$43,$42)|0);
    }
    $46 = (($12) + 482|0);
    HEAP8[$46>>0] = 1;
   }
   $47 = (($12) + 504|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    $50 = HEAP8[$7>>0]|0;
    $51 = ($50<<24>>24)==(0);
    if ($51) {
     $59 = 0;
    } else {
     $52 = (($12) + 401|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = ($53<<24>>24)==(0);
     $59 = $54;
    }
   } else {
    $59 = 1;
   }
   $55 = (($12) + 444|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($56) + 276|0);
   $58 = $59&1;
   HEAP8[$57>>0] = $58;
   __ZN20SoundChannelInstance16UpdatePauseStateEv($56);
   $60 = (($12) + 420|0);
   if ($59) {
    $61 = ($60|0)==($8|0);
    if (!($61)) {
     $62 = HEAP32[$60>>2]|0;
     $63 = ($62|0)==(0|0);
     $$pre$i$i$i = (($12) + 424|0);
     if (!($63)) {
      $64 = HEAP32[$$pre$i$i$i>>2]|0;
      $65 = (($62) + 4|0);
      HEAP32[$65>>2] = $64;
      $66 = HEAP32[$60>>2]|0;
      $67 = HEAP32[$$pre$i$i$i>>2]|0;
      HEAP32[$67>>2] = $66;
      HEAP32[$60>>2] = 0;
      HEAP32[$$pre$i$i$i>>2] = 0;
     }
     $68 = HEAP32[$8>>2]|0;
     HEAP32[$60>>2] = $68;
     HEAP32[$$pre$i$i$i>>2] = $8;
     $69 = (($68) + 4|0);
     HEAP32[$69>>2] = $60;
     $70 = HEAP32[$$pre$i$i$i>>2]|0;
     HEAP32[$70>>2] = $60;
    }
   } else {
    $71 = ($60|0)==($9|0);
    if (!($71)) {
     $72 = HEAP32[$60>>2]|0;
     $73 = ($72|0)==(0|0);
     $$pre$i$i1$i = (($12) + 424|0);
     if (!($73)) {
      $74 = HEAP32[$$pre$i$i1$i>>2]|0;
      $75 = (($72) + 4|0);
      HEAP32[$75>>2] = $74;
      $76 = HEAP32[$60>>2]|0;
      $77 = HEAP32[$$pre$i$i1$i>>2]|0;
      HEAP32[$77>>2] = $76;
      HEAP32[$60>>2] = 0;
      HEAP32[$$pre$i$i1$i>>2] = 0;
     }
     $78 = HEAP32[$9>>2]|0;
     HEAP32[$60>>2] = $78;
     HEAP32[$$pre$i$i1$i>>2] = $9;
     $79 = (($78) + 4|0);
     HEAP32[$79>>2] = $60;
     $80 = HEAP32[$$pre$i$i1$i>>2]|0;
     HEAP32[$80>>2] = $60;
    }
   }
   $81 = (($11) + 4|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==($2|0);
   if ($83) {
    break;
   } else {
    $11 = $82;
   }
  }
  $$pre = HEAP32[$3>>2]|0;
  $85 = $$pre;
 }
 $84 = ($85|0)==($2|0);
 if ($84) {
  HEAP32[$3>>2] = $2;
  HEAP32[$2>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $node$01$i = $85;
 }
 while(1) {
  $86 = (($node$01$i) + 4|0);
  $87 = HEAP32[$86>>2]|0;
  HEAP32[$node$01$i>>2] = 0;
  HEAP32[$86>>2] = 0;
  $88 = ($87|0)==($2|0);
  if ($88) {
   break;
  } else {
   $node$01$i = $87;
  }
 }
 HEAP32[$3>>2] = $2;
 HEAP32[$2>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN12AudioManager14AddAudioSourceEP11AudioSourceb($this,$s,$paused) {
 $this = $this|0;
 $s = $s|0;
 $paused = $paused|0;
 var $$pre$i$i = 0, $$pre$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($paused) {
  $0 = (($this) + 48|0);
  $1 = (($s) + 420|0);
  $2 = ($1|0)==($0|0);
  if ($2) {
   STACKTOP = sp;return;
  }
  $3 = HEAP32[$1>>2]|0;
  $4 = ($3|0)==(0|0);
  $$pre$i$i = (($s) + 424|0);
  if (!($4)) {
   $5 = HEAP32[$$pre$i$i>>2]|0;
   $6 = (($3) + 4|0);
   HEAP32[$6>>2] = $5;
   $7 = HEAP32[$1>>2]|0;
   $8 = HEAP32[$$pre$i$i>>2]|0;
   HEAP32[$8>>2] = $7;
   HEAP32[$1>>2] = 0;
   HEAP32[$$pre$i$i>>2] = 0;
  }
  $9 = HEAP32[$0>>2]|0;
  HEAP32[$1>>2] = $9;
  HEAP32[$$pre$i$i>>2] = $0;
  $10 = (($9) + 4|0);
  HEAP32[$10>>2] = $1;
  $11 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$11>>2] = $1;
  STACKTOP = sp;return;
 } else {
  $12 = (($this) + 40|0);
  $13 = (($s) + 420|0);
  $14 = ($13|0)==($12|0);
  if ($14) {
   STACKTOP = sp;return;
  }
  $15 = HEAP32[$13>>2]|0;
  $16 = ($15|0)==(0|0);
  $$pre$i$i1 = (($s) + 424|0);
  if (!($16)) {
   $17 = HEAP32[$$pre$i$i1>>2]|0;
   $18 = (($15) + 4|0);
   HEAP32[$18>>2] = $17;
   $19 = HEAP32[$13>>2]|0;
   $20 = HEAP32[$$pre$i$i1>>2]|0;
   HEAP32[$20>>2] = $19;
   HEAP32[$13>>2] = 0;
   HEAP32[$$pre$i$i1>>2] = 0;
  }
  $21 = HEAP32[$12>>2]|0;
  HEAP32[$13>>2] = $21;
  HEAP32[$$pre$i$i1>>2] = $12;
  $22 = (($21) + 4|0);
  HEAP32[$22>>2] = $13;
  $23 = HEAP32[$$pre$i$i1>>2]|0;
  HEAP32[$23>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __ZN12AudioManager6UpdateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $samplerate = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $samplerate = sp;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__Z14GetTimeManagerv()|0);
 $4 = (($3) + 104|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 76|0);
 $7 = (($this) + 72|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = ($8|0)==($7|0);
 if (!($9)) {
  $11 = $8;
  while(1) {
   $10 = (($11) + 8|0);
   $12 = HEAP32[$10>>2]|0;
   __ZN10AudioMixer6UpdateEf($12,$5);
   $13 = (($11) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($7|0);
   if ($15) {
    break;
   } else {
    $11 = $14;
   }
  }
 }
 __ZN12AudioManager23ProcessScheduledSourcesEv($this);
 $16 = (($this) + 60|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 56|0);
 $19 = ($17|0)==($18|0);
 if (!($19)) {
  $21 = $17;
  while(1) {
   $20 = (($21) + 8|0);
   $22 = HEAP32[$20>>2]|0;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 108|0);
   $25 = HEAP32[$24>>2]|0;
   FUNCTION_TABLE_vi[$25 & 4095]($22);
   $26 = (($21) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==($18|0);
   if ($28) {
    break;
   } else {
    $21 = $27;
   }
  }
 }
 $29 = (($this) + 44|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 40|0);
 $32 = ($30|0)==($31|0);
 if (!($32)) {
  $34 = $30;
  while(1) {
   $33 = (($34) + 8|0);
   $35 = HEAP32[$33>>2]|0;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 108|0);
   $38 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vi[$38 & 4095]($35);
   $39 = (($34) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==($31|0);
   if ($41) {
    break;
   } else {
    $34 = $40;
   }
  }
 }
 $42 = (($this) + 88|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 84|0);
 $45 = ($43|0)==($44|0);
 if (!($45)) {
  $47 = $43;
  while(1) {
   $46 = (($47) + 8|0);
   $48 = HEAP32[$46>>2]|0;
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + 108|0);
   $51 = HEAP32[$50>>2]|0;
   FUNCTION_TABLE_vi[$51 & 4095]($48);
   $52 = (($47) + 4|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==($44|0);
   if ($54) {
    break;
   } else {
    $47 = $53;
   }
  }
 }
 HEAP32[$samplerate>>2] = 0;
 $55 = HEAP32[$0>>2]|0;
 (__ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($55,$samplerate,0,0,0,0,0)|0);
 $56 = HEAP32[$samplerate>>2]|0;
 HEAP32[((702920 + 12|0))>>2] = $56;
 $57 = HEAP32[((702920 + 8|0))>>2]|0;
 $58 = $57 & -4;
 $59 = (__Z14GetPlayerPausev()|0);
 $60 = ($59|0)!=(0);
 $61 = $60 ? 2 : 0;
 $62 = $58 | $61;
 $63 = $62 | 1;
 HEAP32[((702920 + 8|0))>>2] = $63;
 $64 = HEAP32[$0>>2]|0;
 (__ZN4FMOD6System6updateEv($64)|0);
 STACKTOP = sp;return;
}
function __ZN12AudioManager11FixedUpdateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 56|0);
 $6 = ($4|0)==($5|0);
 if (!($6)) {
  $8 = $4;
  while(1) {
   $7 = (($8) + 8|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 112|0);
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vi[$12 & 4095]($9);
   $13 = (($8) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==($5|0);
   if ($15) {
    break;
   } else {
    $8 = $14;
   }
  }
 }
 $16 = (($this) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 40|0);
 $19 = ($17|0)==($18|0);
 if ($19) {
  STACKTOP = sp;return;
 } else {
  $21 = $17;
 }
 while(1) {
  $20 = (($21) + 8|0);
  $22 = HEAP32[$20>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 112|0);
  $25 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_vi[$25 & 4095]($22);
  $26 = (($21) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($18|0);
  if ($28) {
   break;
  } else {
   $21 = $27;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12AudioManager17RemoveAudioSourceEP11AudioSource($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 448|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($s) + 452|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (($s) + 420|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($s) + 424|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($9) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$8>>2]|0;
 $15 = HEAP32[$11>>2]|0;
 HEAP32[$15>>2] = $14;
 HEAP32[$8>>2] = 0;
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12AudioManager16UnScheduleSourceEP11AudioSource($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 448|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($s) + 452|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $6;
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12AudioManager14OnMixerChangedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = (($this) + 40|0);
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==($1|0);
 if (!($3)) {
  $5 = $2;
  while(1) {
   $4 = (($5) + 8|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = (__ZNK11AudioSource27AreChannelOrOneshotsPlayingEv($6)|0);
   if ($7) {
    __ZN11AudioSource11SetupGroupsEv($6);
   }
   $8 = (($5) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==($1|0);
   if ($10) {
    break;
   } else {
    $5 = $9;
   }
  }
 }
 $11 = (($this) + 52|0);
 $12 = (($this) + 48|0);
 $13 = HEAP32[$11>>2]|0;
 $14 = ($13|0)==($12|0);
 if (!($14)) {
  $16 = $13;
  while(1) {
   $15 = (($16) + 8|0);
   $17 = HEAP32[$15>>2]|0;
   $18 = (__ZNK11AudioSource27AreChannelOrOneshotsPlayingEv($17)|0);
   if ($18) {
    __ZN11AudioSource11SetupGroupsEv($17);
   }
   $19 = (($16) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==($12|0);
   if ($21) {
    break;
   } else {
    $16 = $20;
   }
  }
 }
 $22 = (($this) + 76|0);
 $23 = (($this) + 72|0);
 $24 = HEAP32[$22>>2]|0;
 $25 = ($24|0)==($23|0);
 if ($25) {
  STACKTOP = sp;return;
 } else {
  $27 = $24;
 }
 while(1) {
  $26 = (($27) + 8|0);
  $28 = HEAP32[$26>>2]|0;
  __ZN10AudioMixer11SetupGroupsEv($28);
  $29 = (($27) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==($23|0);
  if ($31) {
   break;
  } else {
   $27 = $30;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12AudioManager16AddAudioListenerEP13AudioListener($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = (($s) + 52|0);
 $2 = ($1|0)==($0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0|0);
 $$pre$i$i = (($s) + 56|0);
 if (!($4)) {
  $5 = HEAP32[$$pre$i$i>>2]|0;
  $6 = (($3) + 4|0);
  HEAP32[$6>>2] = $5;
  $7 = HEAP32[$1>>2]|0;
  $8 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$8>>2] = $7;
  HEAP32[$1>>2] = 0;
  HEAP32[$$pre$i$i>>2] = 0;
 }
 $9 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = $9;
 HEAP32[$$pre$i$i>>2] = $0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $1;
 $11 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$11>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN12AudioManager19RemoveAudioListenerEP13AudioListener($this,$s) {
 $this = $this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($s) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $6;
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK12AudioManager16GetAudioListenerEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = (($this) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12AudioManager14ScheduleSourceEP11AudioSourced($this,$s,$time) {
 $this = $this|0;
 $s = $s|0;
 $time = +$time;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + 448|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($s) + 452|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (($s) + 464|0);
 HEAPF64[$8>>3] = $time;
 $9 = (($this) + 64|0);
 $10 = ($0|0)==($9|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $$pre$i$i = (($s) + 452|0);
 $11 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = $11;
 HEAP32[$$pre$i$i>>2] = $9;
 $12 = (($11) + 4|0);
 HEAP32[$12>>2] = $0;
 $13 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$13>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN12AudioManager22GetScriptBufferManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 208|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $8 = $1;
  STACKTOP = sp;return ($8|0);
 }
 $3 = (__Znwj(28)|0);
 __THREW__ = 0;
 invoke_vi(3659,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZdlPv($3);
  ___resumeException($6|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $3;
 $8 = $3;
 STACKTOP = sp;return ($8|0);
}
function __ZN12AudioManager15GetSoundManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z26RegisterClass_AudioManagerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(11,218,219,0,220);
 STACKTOP = sp;return;
}
function __ZN12AudioManager13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(6)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN17GlobalGameManager13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 12;
 dest=$3+0|0; src=713568+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 12|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,11,6,($0|0),216,(2573|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN12AudioManager7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(216,$$byval_copy2,1,16,711992,49)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1678,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((712000 + 8|0));
  $6 = (($3) + 24|0);
  HEAPF32[$6>>2] = Math_fround(1.0);
  $7 = (($3) + 28|0);
  HEAPF32[$7>>2] = Math_fround(1.0);
  $8 = (($3) + 32|0);
  HEAPF32[$8>>2] = Math_fround(1.0);
  $9 = (($3) + 36|0);
  HEAP8[$9>>0] = 0;
  $10 = (($3) + 40|0);
  $11 = (($3) + 44|0);
  HEAP32[$10>>2] = $10;
  HEAP32[$11>>2] = $10;
  $12 = (($3) + 48|0);
  $13 = (($3) + 52|0);
  HEAP32[$12>>2] = $12;
  HEAP32[$13>>2] = $12;
  $14 = (($3) + 56|0);
  $15 = (($3) + 60|0);
  HEAP32[$14>>2] = $14;
  HEAP32[$15>>2] = $14;
  $16 = (($3) + 64|0);
  $17 = (($3) + 68|0);
  HEAP32[$16>>2] = $16;
  HEAP32[$17>>2] = $16;
  $18 = (($3) + 72|0);
  $19 = (($3) + 76|0);
  HEAP32[$18>>2] = $18;
  HEAP32[$19>>2] = $18;
  $20 = (($3) + 80|0);
  HEAPF32[$20>>2] = Math_fround(1.0);
  $21 = (($3) + 84|0);
  $22 = (($3) + 88|0);
  HEAP32[$21>>2] = $21;
  HEAP32[$22>>2] = $21;
  $23 = (($3) + 92|0);
  $24 = (($3) + 120|0);
  ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;HEAP32[$23+16>>2]=0|0;HEAP32[$23+20>>2]=0|0;HEAP32[$23+24>>2]=0|0;
  HEAP32[$24>>2] = 2;
  $25 = (($3) + 124|0);
  HEAP32[$25>>2] = 2;
  $26 = (($3) + 128|0);
  HEAP32[$26>>2] = 0;
  $27 = (($3) + 132|0);
  HEAP32[$27>>2] = 0;
  $28 = (($3) + 136|0);
  HEAP32[$28>>2] = 512;
  $29 = (($3) + 140|0);
  HEAP32[$29>>2] = 32;
  $30 = (($3) + 144|0);
  HEAP32[$30>>2] = 2;
  $31 = (($3) + 148|0);
  HEAP32[$31>>2] = 0;
  $32 = (($3) + 152|0);
  HEAP32[$32>>2] = 0;
  $33 = (($3) + 156|0);
  HEAP32[$33>>2] = 512;
  $34 = (($3) + 160|0);
  HEAP32[$34>>2] = 32;
  $35 = (($3) + 164|0);
  ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;
  $36 = (($3) + 184|0);
  $37 = (($3) + 208|0);
  HEAP32[$37>>2] = 0;
  ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;HEAP32[$36+16>>2]=0|0;HEAP8[$36+20>>0]=0|0;
  HEAP32[712112>>2] = $3;
  STACKTOP = sp;return ($3|0);
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(711992|0),49);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  ___resumeException($38|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK12AudioManager25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 11;
}
function __ZN12AudioManager23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713584,713568,$this,0);
 __ZN12AudioManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12AudioManager23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,713584,713568,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN12AudioManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12AudioManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12AudioManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN12AudioManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12AudioManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN12AudioManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12AudioManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN12AudioManager23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z15GetAudioManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z21GetManagerFromContexti(3)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12AudioManagerD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((712000 + 8|0));
 $0 = (($this) + 164|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 172|0);
  $5 = HEAP32[$4>>2]|0;
  __ZdlPv($5);
 }
 $6 = (($this) + 88|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 84|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 40|0);
 dest=$8+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN17GlobalGameManagerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN12AudioManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((712000 + 8|0));
 $0 = (($this) + 164|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 172|0);
  $5 = HEAP32[$4>>2]|0;
  __ZdlPv($5);
 }
 $6 = (($this) + 88|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 84|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 40|0);
 dest=$8+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$this>>2] = ((561192 + 8|0));
 __THREW__ = 0;
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $27 = ___cxa_find_matching_catch(0|0)|0;
   $28 = tempRet0;
   __THREW__ = 0;
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    $31 = ___cxa_find_matching_catch(0|0)|0;
    $32 = tempRet0;
    ___clang_call_terminate($31);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $27;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   $eh$lpad$body$index8Z2D = $22;$eh$lpad$body$indexZ2D = $21;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $33 = ___cxa_find_matching_catch(0|0)|0;
  $34 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $33;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((561376 + 8|0));
  __THREW__ = 0;
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   __THREW__ = 0;
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $17 = ___cxa_find_matching_catch(0|0)|0;
    $18 = tempRet0;
    ___clang_call_terminate($17);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $14;$eh$lpad$body$indexZ2D = $13;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  $eh$lpad$body$index8Z2D = $36;$eh$lpad$body$indexZ2D = $35;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN12AudioManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = Math_fround(HEAPF32[$0>>2]);
  HEAPF32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre7;
 }
 $8 = (($this) + 32|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre8 = HEAP32[$1>>2]|0;
  $$pre9 = HEAP32[$4>>2]|0;
  $16 = $$pre8;$18 = $$pre9;
 }
 $14 = (($this) + 80|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre10 = HEAP32[$1>>2]|0;
  $$pre11 = HEAP32[$4>>2]|0;
  $22 = $$pre10;$24 = $$pre11;
 }
 $20 = (($this) + 124|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = HEAP32[$20>>2]|0;
  HEAP32[$22>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,4);
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $28 = $$pre12;$30 = $$pre13;
 }
 $26 = (($this) + 128|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)<($30>>>0);
 if ($29) {
  $31 = HEAP32[$26>>2]|0;
  HEAP32[$28>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,4);
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $34 = $$pre14;$36 = $$pre15;
 }
 $32 = (($this) + 132|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)<($36>>>0);
 if ($35) {
  $37 = HEAP32[$32>>2]|0;
  HEAP32[$34>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$32,4);
  $$pre16 = HEAP32[$1>>2]|0;
  $$pre17 = HEAP32[$4>>2]|0;
  $40 = $$pre16;$42 = $$pre17;
 }
 $38 = (($this) + 136|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)<($42>>>0);
 if ($41) {
  $43 = HEAP32[$38>>2]|0;
  HEAP32[$40>>2] = $43;
  HEAP32[$1>>2] = $39;
  $46 = $39;$48 = $42;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$38,4);
  $$pre18 = HEAP32[$1>>2]|0;
  $$pre19 = HEAP32[$4>>2]|0;
  $46 = $$pre18;$48 = $$pre19;
 }
 $44 = (($this) + 140|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)<($48>>>0);
 if ($47) {
  $49 = HEAP32[$44>>2]|0;
  HEAP32[$46>>2] = $49;
  HEAP32[$1>>2] = $45;
  $52 = $45;$54 = $48;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$44,4);
  $$pre20 = HEAP32[$1>>2]|0;
  $$pre21 = HEAP32[$4>>2]|0;
  $52 = $$pre20;$54 = $$pre21;
 }
 $50 = (($this) + 204|0);
 $51 = (($52) + 1|0);
 $53 = ($51>>>0)<($54>>>0);
 if ($53) {
  $55 = HEAP8[$50>>0]|0;
  HEAP8[$52>>0] = $55;
  $56 = HEAP32[$1>>2]|0;
  $57 = (($56) + 1|0);
  HEAP32[$1>>2] = $57;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$50,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN12AudioManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i12 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0;
 var $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $0;$13 = $$pre;$15 = $$pre20;$9 = $$pre$i$i$i;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $0;$13 = $3;$15 = $5;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $10;
 $11 = (($this) + 32|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i3 = HEAP32[$11>>2]|0;
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i4Z2D = $11;$18 = $$pre$i$i$i3;$22 = $$pre21;$24 = $$pre22;
 } else {
  $16 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$1>>2] = $12;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $11;$18 = $17;$22 = $12;$24 = $15;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $19;
 $20 = (($this) + 80|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre$i$i$i8 = HEAP32[$20>>2]|0;
  $$pre23 = HEAP32[$1>>2]|0;
  $$pre24 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i9Z2D = $20;$27 = $$pre$i$i$i8;$31 = $$pre23;$33 = $$pre24;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $26 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $20;$27 = $26;$31 = $21;$33 = $24;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $28;
 $29 = (($this) + 124|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$29,4);
  $$pre$i$i$i11 = HEAP32[$29>>2]|0;
  $$pre25 = HEAP32[$1>>2]|0;
  $$pre26 = HEAP32[$4>>2]|0;
  $35 = $$pre$i$i$i11;$39 = $$pre25;$41 = $$pre26;
 } else {
  $34 = HEAP32[$31>>2]|0;
  HEAP32[$29>>2] = $34;
  HEAP32[$1>>2] = $30;
  $35 = $34;$39 = $30;$41 = $33;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$29>>2] = $36;
 $37 = (($this) + 128|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$37,4);
  $$pre$i$i$i12 = HEAP32[$37>>2]|0;
  $$pre27 = HEAP32[$1>>2]|0;
  $$pre28 = HEAP32[$4>>2]|0;
  $43 = $$pre$i$i$i12;$47 = $$pre27;$49 = $$pre28;
 } else {
  $42 = HEAP32[$39>>2]|0;
  HEAP32[$37>>2] = $42;
  HEAP32[$1>>2] = $38;
  $43 = $42;$47 = $38;$49 = $41;
 }
 $44 = (_llvm_bswap_i32(($43|0))|0);
 HEAP32[$37>>2] = $44;
 $45 = (($this) + 132|0);
 $46 = (($47) + 4|0);
 $48 = ($46>>>0)>($49>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$45,4);
  $$pre$i$i$i14 = HEAP32[$45>>2]|0;
  $$pre29 = HEAP32[$1>>2]|0;
  $$pre30 = HEAP32[$4>>2]|0;
  $51 = $$pre$i$i$i14;$55 = $$pre29;$57 = $$pre30;
 } else {
  $50 = HEAP32[$47>>2]|0;
  HEAP32[$45>>2] = $50;
  HEAP32[$1>>2] = $46;
  $51 = $50;$55 = $46;$57 = $49;
 }
 $52 = (_llvm_bswap_i32(($51|0))|0);
 HEAP32[$45>>2] = $52;
 $53 = (($this) + 136|0);
 $54 = (($55) + 4|0);
 $56 = ($54>>>0)>($57>>>0);
 if ($56) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$53,4);
  $$pre$i$i$i16 = HEAP32[$53>>2]|0;
  $$pre31 = HEAP32[$1>>2]|0;
  $$pre32 = HEAP32[$4>>2]|0;
  $59 = $$pre$i$i$i16;$63 = $$pre31;$65 = $$pre32;
 } else {
  $58 = HEAP32[$55>>2]|0;
  HEAP32[$53>>2] = $58;
  HEAP32[$1>>2] = $54;
  $59 = $58;$63 = $54;$65 = $57;
 }
 $60 = (_llvm_bswap_i32(($59|0))|0);
 HEAP32[$53>>2] = $60;
 $61 = (($this) + 140|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)>($65>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$61,4);
  $$pre$i$i$i18 = HEAP32[$61>>2]|0;
  $$pre33 = HEAP32[$1>>2]|0;
  $$pre34 = HEAP32[$4>>2]|0;
  $67 = $$pre$i$i$i18;$71 = $$pre33;$73 = $$pre34;
 } else {
  $66 = HEAP32[$63>>2]|0;
  HEAP32[$61>>2] = $66;
  HEAP32[$1>>2] = $62;
  $67 = $66;$71 = $62;$73 = $65;
 }
 $68 = (_llvm_bswap_i32(($67|0))|0);
 HEAP32[$61>>2] = $68;
 $69 = (($this) + 204|0);
 $70 = (($71) + 1|0);
 $72 = ($70>>>0)>($73>>>0);
 if ($72) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$69,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $74 = HEAP8[$71>>0]|0;
  HEAP8[$69>>0] = $74;
  $75 = HEAP32[$1>>2]|0;
  $76 = (($75) + 1|0);
  HEAP32[$1>>2] = $76;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN12AudioManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre7;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 32|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre8 = HEAP32[$1>>2]|0;
  $$pre9 = HEAP32[$4>>2]|0;
  $16 = $$pre8;$18 = $$pre9;
 } else {
  $13 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 80|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  $$pre10 = HEAP32[$1>>2]|0;
  $$pre11 = HEAP32[$4>>2]|0;
  $22 = $$pre10;$24 = $$pre11;
 } else {
  $19 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 }
 $20 = (($this) + 124|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre12 = HEAP32[$1>>2]|0;
  $$pre13 = HEAP32[$4>>2]|0;
  $28 = $$pre12;$30 = $$pre13;
 } else {
  $25 = HEAP32[$22>>2]|0;
  HEAP32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 }
 $26 = (($this) + 128|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre14 = HEAP32[$1>>2]|0;
  $$pre15 = HEAP32[$4>>2]|0;
  $34 = $$pre14;$36 = $$pre15;
 } else {
  $31 = HEAP32[$28>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 }
 $32 = (($this) + 132|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$32,4);
  $$pre16 = HEAP32[$1>>2]|0;
  $$pre17 = HEAP32[$4>>2]|0;
  $40 = $$pre16;$42 = $$pre17;
 } else {
  $37 = HEAP32[$34>>2]|0;
  HEAP32[$32>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 }
 $38 = (($this) + 136|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)>($42>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
  $$pre18 = HEAP32[$1>>2]|0;
  $$pre19 = HEAP32[$4>>2]|0;
  $46 = $$pre18;$48 = $$pre19;
 } else {
  $43 = HEAP32[$40>>2]|0;
  HEAP32[$38>>2] = $43;
  HEAP32[$1>>2] = $39;
  $46 = $39;$48 = $42;
 }
 $44 = (($this) + 140|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)>($48>>>0);
 if ($47) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$44,4);
  $$pre20 = HEAP32[$1>>2]|0;
  $$pre21 = HEAP32[$4>>2]|0;
  $52 = $$pre20;$54 = $$pre21;
 } else {
  $49 = HEAP32[$46>>2]|0;
  HEAP32[$44>>2] = $49;
  HEAP32[$1>>2] = $45;
  $52 = $45;$54 = $48;
 }
 $50 = (($this) + 204|0);
 $51 = (($52) + 1|0);
 $53 = ($51>>>0)>($54>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$50,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $55 = HEAP8[$52>>0]|0;
  HEAP8[$50>>0] = $55;
  $56 = HEAP32[$1>>2]|0;
  $57 = (($56) + 1|0);
  HEAP32[$1>>2] = $57;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN12AudioManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN17GlobalGameManager8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,713592,0);
 $1 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,713608,0);
 $2 = (($this) + 80|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$2,713624,0);
 $3 = (($this) + 124|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$3,713640,0);
 $4 = (($this) + 128|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$4,713664,0);
 $5 = (($this) + 132|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$5,713680,0);
 $6 = (($this) + 136|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$6,713696,0);
 $7 = (($this) + 140|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$7,713720,0);
 $8 = (($this) + 204|0);
 $9 = HEAP32[580544>>2]|0;
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,713744,$9,$converter$i$i,0)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($10|0)>(0);
 do {
  if ($12) {
   $13 = (($transfer) + 12|0);
   $14 = (($transfer) + 80|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($transfer) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($transfer) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($transfer) + 32|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = Math_imul($23, $21)|0;
   $$sum$i$i$i$i$i = (($17) - ($24))|0;
   $25 = (($19) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$13>>2] = $25;
   $26 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($26)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $27 = (($19) + ($$sum1$i$i$i$i$i)|0);
    $28 = (($transfer) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27>>>0)>($29>>>0);
    if (!($30)) {
     $31 = HEAP8[$25>>0]|0;
     HEAP8[$8>>0] = $31;
     $32 = HEAP32[$13>>2]|0;
     $33 = (($32) + 1|0);
     HEAP32[$13>>2] = $33;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($13,$8,1);
  } else {
   $34 = HEAP32[$converter$i$i>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    (FUNCTION_TABLE_iii[$34 & 4095]($8,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN12AudioManager8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17GlobalGameManager8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 24|0);
 $1 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713592,$1,$0,2048);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713608,$1,$8,0);
 $9 = HEAP32[$2>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 80|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713624,$1,$13,0);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 124|0);
 $19 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713640,$19,$18,0);
 $20 = HEAP32[$2>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$5>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($this) + 128|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713664,$19,$24,0);
 $25 = HEAP32[$2>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$5>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 132|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713680,$19,$29,0);
 $30 = HEAP32[$2>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$5>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $34 = (($this) + 136|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713696,$19,$34,0);
 $35 = HEAP32[$2>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$5>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $39 = (($this) + 140|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713720,$19,$39,0);
 $40 = HEAP32[$2>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$5>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = (($this) + 204|0);
 $45 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,713744,$45,$44,0);
 $46 = HEAP32[$2>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$5>>2]|0;
 $49 = ((($47) + (($48*24)|0)|0) + 12|0);
 HEAP32[$49>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __Z29AudioMasterDSPProcessCallbackP21UnityAudioEffectStatePfS1_jii($state,$inbuffer,$outbuffer,$length,$inchannels,$outchannels) {
 $state = $state|0;
 $inbuffer = $inbuffer|0;
 $outbuffer = $outbuffer|0;
 $length = $length|0;
 $inchannels = $inchannels|0;
 $outchannels = $outchannels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 702920;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (_i64Add(($2|0),($5|0),($length|0),0)|0);
 $7 = tempRet0;
 $8 = 702920;
 $9 = $8;
 HEAP32[$9>>2] = $6;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = $length << 2;
 $13 = Math_imul($12, $inchannels)|0;
 _memcpy(($outbuffer|0),($inbuffer|0),($13|0))|0;
 STACKTOP = sp;return 0;
}
function __ZN15AudioReverbZone7CleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 (__ZN4FMOD6Reverb7releaseEv($1)|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15AudioReverbZone4InitEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   $3 = (__Z15GetAudioManagerv()|0);
   $4 = (($3) + 92|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (__ZN4FMOD6System12createReverbEPPNS_6ReverbE($5,$0)|0);
   do {
    switch ($6|0) {
    case 9:  {
     $$0$i = 724440;
     break;
    }
    case 14:  {
     $$0$i = 724784;
     break;
    }
    case 6:  {
     $$0$i = 724320;
     break;
    }
    case 5:  {
     $$0$i = 724280;
     break;
    }
    case 12:  {
     $$0$i = 724576;
     break;
    }
    case 17:  {
     $$0$i = 725096;
     break;
    }
    case 13:  {
     $$0$i = 724728;
     break;
    }
    case 18:  {
     $$0$i = 725288;
     break;
    }
    case 4:  {
     $$0$i = 724216;
     break;
    }
    case 11:  {
     $$0$i = 724512;
     break;
    }
    case 2:  {
     $$0$i = 724032;
     break;
    }
    case 8:  {
     $$0$i = 724392;
     break;
    }
    case 3:  {
     $$0$i = 724168;
     break;
    }
    case 15:  {
     $$0$i = 724928;
     break;
    }
    case 10:  {
     $$0$i = 724472;
     break;
    }
    case 92:  {
     $$0$i = 725392;
     break;
    }
    case 83:  {
     $$0$i = 725528;
     break;
    }
    case 7:  {
     $$0$i = 724360;
     break;
    }
    case 16:  {
     $$0$i = 725032;
     break;
    }
    case 91:  {
     $$0$i = 725640;
     break;
    }
    case 87:  {
     $$0$i = 725920;
     break;
    }
    case 20:  {
     $$0$i = 726336;
     break;
    }
    case 25:  {
     $$0$i = 726640;
     break;
    }
    case 27:  {
     $$0$i = 726768;
     break;
    }
    case 89:  {
     $$0$i = 726224;
     break;
    }
    case 24:  {
     $$0$i = 726608;
     break;
    }
    case 28:  {
     $$0$i = 726840;
     break;
    }
    case 29:  {
     $$0$i = 726912;
     break;
    }
    case 84:  {
     $$0$i = 725688;
     break;
    }
    case 21:  {
     $$0$i = 726448;
     break;
    }
    case 23:  {
     $$0$i = 726584;
     break;
    }
    case 26:  {
     $$0$i = 726680;
     break;
    }
    case 30:  {
     $$0$i = 726944;
     break;
    }
    case 19:  {
     $$0$i = 726312;
     break;
    }
    case 88:  {
     $$0$i = 726088;
     break;
    }
    case 22:  {
     $$0$i = 726488;
     break;
    }
    case 86:  {
     $$0$i = 725816;
     break;
    }
    case 85:  {
     $$0$i = 725744;
     break;
    }
    case 90:  {
     $$0$i = 726136;
     break;
    }
    case 34:  {
     $$0$i = 727152;
     break;
    }
    case 31:  {
     $$0$i = 726976;
     break;
    }
    case 35:  {
     $$0$i = 727256;
     break;
    }
    case 44:  {
     $$0$i = 727784;
     break;
    }
    case 93:  {
     $$0$i = 728080;
     break;
    }
    case 40:  {
     $$0$i = 727552;
     break;
    }
    case 45:  {
     $$0$i = 727912;
     break;
    }
    case 46:  {
     $$0$i = 728160;
     break;
    }
    case 43:  {
     $$0$i = 727744;
     break;
    }
    case 39:  {
     $$0$i = 727464;
     break;
    }
    case 37:  {
     $$0$i = 727352;
     break;
    }
    case 41:  {
     $$0$i = 727608;
     break;
    }
    case 42:  {
     $$0$i = 727672;
     break;
    }
    case 32:  {
     $$0$i = 727040;
     break;
    }
    case 36:  {
     $$0$i = 727312;
     break;
    }
    case 95:  {
     $$0$i = 727968;
     break;
    }
    case 33:  {
     $$0$i = 727088;
     break;
    }
    case 38:  {
     $$0$i = 727408;
     break;
    }
    case 47:  {
     $$0$i = 728240;
     break;
    }
    case 48:  {
     $$0$i = 728320;
     break;
    }
    case 94:  {
     $$0$i = 728032;
     break;
    }
    case 74:  {
     $$0$i = 731104;
     break;
    }
    case 60:  {
     $$0$i = 729512;
     break;
    }
    case 59:  {
     $$0$i = 729408;
     break;
    }
    case 63:  {
     $$0$i = 729752;
     break;
    }
    case 80:  {
     $$0$i = 731616;
     break;
    }
    case 51:  {
     $$0$i = 728688;
     break;
    }
    case 79:  {
     $$0$i = 731536;
     break;
    }
    case 71:  {
     $$0$i = 730400;
     break;
    }
    case 76:  {
     $$0$i = 731240;
     break;
    }
    case 55:  {
     $$0$i = 728992;
     break;
    }
    case 1:  {
     $$0$i = 723968;
     break;
    }
    case 73:  {
     $$0$i = 730984;
     break;
    }
    case 52:  {
     $$0$i = 728784;
     break;
    }
    case 57:  {
     $$0$i = 729152;
     break;
    }
    case 66:  {
     $$0$i = 729944;
     break;
    }
    case 68:  {
     $$0$i = 730104;
     break;
    }
    case 70:  {
     $$0$i = 730336;
     break;
    }
    case 75:  {
     $$0$i = 730544;
     break;
    }
    case 54:  {
     $$0$i = 728904;
     break;
    }
    case 72:  {
     $$0$i = 730832;
     break;
    }
    case 81:  {
     $$0$i = 731728;
     break;
    }
    case 82:  {
     $$0$i = 731776;
     break;
    }
    case 0:  {
     break L1;
     break;
    }
    case 61:  {
     $$0$i = 729552;
     break;
    }
    case 53:  {
     $$0$i = 728832;
     break;
    }
    case 62:  {
     $$0$i = 729656;
     break;
    }
    case 56:  {
     $$0$i = 729112;
     break;
    }
    case 67:  {
     $$0$i = 730008;
     break;
    }
    case 77:  {
     $$0$i = 731304;
     break;
    }
    case 65:  {
     $$0$i = 729880;
     break;
    }
    case 50:  {
     $$0$i = 728640;
     break;
    }
    case 58:  {
     $$0$i = 729288;
     break;
    }
    case 69:  {
     $$0$i = 730224;
     break;
    }
    case 64:  {
     $$0$i = 729808;
     break;
    }
    case 49:  {
     $$0$i = 728448;
     break;
    }
    case 78:  {
     $$0$i = 731456;
     break;
    }
    default: {
     $$0$i = 731840;
    }
    }
   } while(0);
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE($$0$i,0,723880,109,1,0,0,0);
  }
 } while(0);
 $7 = HEAP32[$0>>2]|0;
 (__ZN4FMOD6Reverb9setActiveEb($7,1)|0);
 $8 = (__Z15GetAudioManagerv()|0);
 __ZN12AudioManager21FixMasterGroupRoutingEv($8);
 __ZN15AudioReverbZone13SetFMODValuesEv($this);
 $9 = (__Z15GetAudioManagerv()|0);
 $10 = (($9) + 92|0);
 $11 = HEAP32[$10>>2]|0;
 (__ZN4FMOD6System6updateEv($11)|0);
 STACKTOP = sp;return;
}
function __ZN15AudioReverbZone13SetFMODValuesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = Math_fround(0), $9 = 0, $p = 0, $prop = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $p = sp + 80|0;
 $prop = sp;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($4)|0);
 __ZNK9Transform11GetPositionEv($p,$5);
 $6 = HEAP32[$0>>2]|0;
 $7 = (($this) + 44|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 48|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 (__ZN4FMOD6Reverb15set3DAttributesEPK11FMOD_VECTORff($6,$p,$8,$10)|0);
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)<(27);
 if ($13) {
  $14 = (721720 + (($12*80)|0)|0);
  dest=$prop+0|0; src=$14+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 } else {
  $15 = (($this) + 56|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($this) + 60|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($this) + 68|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($this) + 72|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($this) + 76|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($this) + 80|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($this) + 84|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($this) + 88|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($this) + 92|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($this) + 104|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($this) + 108|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($this) + 64|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($this) + 96|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  ;HEAP32[$prop+0>>2]=HEAP32[723888+0>>2]|0;HEAP32[$prop+4>>2]=HEAP32[723888+4>>2]|0;HEAP32[$prop+8>>2]=HEAP32[723888+8>>2]|0;
  $41 = (($prop) + 12|0);
  HEAP32[$41>>2] = $16;
  $42 = (($prop) + 16|0);
  HEAP32[$42>>2] = $18;
  $43 = (($prop) + 20|0);
  HEAP32[$43>>2] = $38;
  $44 = (($prop) + 24|0);
  HEAPF32[$44>>2] = $20;
  $45 = (($prop) + 28|0);
  HEAPF32[$45>>2] = $22;
  $46 = (($prop) + 32|0);
  HEAPF32[$46>>2] = Math_fround(1.0);
  $47 = (($prop) + 36|0);
  HEAP32[$47>>2] = $24;
  $48 = (($prop) + 40|0);
  HEAPF32[$48>>2] = $26;
  $49 = (($prop) + 44|0);
  HEAP32[$49>>2] = $28;
  $50 = (($prop) + 48|0);
  HEAPF32[$50>>2] = $30;
  $51 = (($prop) + 52|0);
  $52 = $51;
  $53 = $52;
  HEAP32[$53>>2] = 1048576000;
  $54 = (($52) + 4)|0;
  $55 = $54;
  HEAP32[$55>>2] = 0;
  $56 = (($prop) + 60|0);
  HEAPF32[$56>>2] = $32;
  $57 = (($prop) + 64|0);
  HEAPF32[$57>>2] = $40;
  $58 = (($prop) + 68|0);
  HEAPF32[$58>>2] = $34;
  $59 = (($prop) + 72|0);
  HEAPF32[$59>>2] = $36;
  $60 = (($prop) + 76|0);
  HEAP32[$60>>2] = 831;
 }
 $61 = HEAP32[$0>>2]|0;
 (__ZN4FMOD6Reverb13setPropertiesEPK22FMOD_REVERB_PROPERTIES($61,$prop)|0);
 STACKTOP = sp;return;
}
function __ZN11AudioSource34CalculateVolumeModifierForDistanceEf($this,$distance) {
 $this = $this|0;
 $distance = Math_fround($distance);
 var $$0 = Math_fround(0), $$1 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = Math_fround(0), $4 = Math_fround(0);
 var $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $gain$0 = Math_fround(0), $gain$1 = Math_fround(0), $gain$2 = Math_fround(0), $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetAudioManagerv()|0);
 $1 = (($0) + 32|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (Math_fround(__ZNK11AudioSource14GetMaxDistanceEv($this)));
 $4 = (Math_fround(__ZNK11AudioSource14GetMinDistanceEv($this)));
 $5 = (__ZNK11AudioSource14GetRolloffModeEv($this)|0);
 if ((($5|0) == 1)) {
  $6 = Math_fround($3 - $4);
  $7 = !($6 <= Math_fround(0.0));
  if ($7) {
   $8 = Math_fround($3 - $distance);
   $9 = Math_fround($8 / $6);
   $gain$0 = $9;
  } else {
   $gain$0 = Math_fround(1.0);
  }
 } else if ((($5|0) == 0)) {
  $10 = $4 < $distance;
  $11 = $2 != Math_fround(1.0);
  $or$cond = $10 & $11;
  if ($or$cond) {
   $12 = Math_fround($distance - $4);
   $13 = Math_fround($2 * $12);
   $14 = Math_fround($4 + $13);
   $$0 = $14;
  } else {
   $$0 = $distance;
  }
  $15 = $$0 < Math_fround(9.99999997475242707878E-7);
  $$1 = $15 ? Math_fround(9.99999997475242707878E-7) : $$0;
  $16 = Math_fround($4 / $$1);
  $gain$0 = $16;
 } else if ((($5|0) == 2)) {
  $17 = $3 > Math_fround(0.0);
  if ($17) {
   $18 = (__ZN11AudioSource21GetCustomRolloffCurveEv($this)|0);
   $19 = Math_fround($distance / $3);
   $20 = (Math_fround(__ZNK17AnimationCurveTplIfE8EvaluateEf($18,$19)));
   $gain$0 = $20;
  } else {
   $gain$0 = Math_fround(1.0);
  }
 } else {
  $gain$0 = Math_fround(1.0);
 }
 $21 = $gain$0 < Math_fround(0.0);
 $gain$1 = $21 ? Math_fround(0.0) : $gain$0;
 $22 = $gain$1 > Math_fround(1.0);
 $gain$2 = $22 ? Math_fround(1.0) : $gain$1;
 STACKTOP = sp;return (Math_fround($gain$2));
}
function __ZN11AudioSource15rolloffCallbackEP12FMOD_CHANNELf($c_channel,$distance) {
 $c_channel = $c_channel|0;
 $distance = Math_fround($distance);
 var $$0 = Math_fround(0), $$02$i$i$i$i$i$i$i = 0, $$02$i$i$i$i$i$i$i$i = 0, $$masked$i$i$i$i$i$i = 0, $$masked$i$i$i$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i1 = 0, $i$03$i$i$i$i$i$i$i = 0, $i$03$i$i$i$i$i$i$i$i = 0, $p$01$i$i$i$i$i$i = 0, $p$01$i$i$i$i$i$i$i = 0, $reflection$01$i$i$i$i$i$i$i = 0, $reflection$01$i$i$i$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i$i$i$i = 0, $userData = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $userData = sp;
 HEAP32[$userData>>2] = 0;
 (__ZN4FMOD7Channel11getUserDataEPPv($c_channel,$userData)|0);
 $0 = HEAP32[$userData>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = Math_fround(1.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = HEAP8[721712>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$02$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i = 0;
  while(1) {
   $5 = $$02$i$i$i$i$i$i$i & 1;
   $6 = ($5|0)==(0);
   if ($6) {
    $reflection$1$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i;
   } else {
    $7 = (31 - ($i$03$i$i$i$i$i$i$i))|0;
    $8 = 1 << $7;
    $9 = $8 | $reflection$01$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i = $9;
   }
   $10 = (($i$03$i$i$i$i$i$i$i) + 1)|0;
   $11 = $$02$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i = ($10|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i) {
    $15 = $reflection$1$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i = 731856;
    break;
   } else {
    $$02$i$i$i$i$i$i$i = $11;$i$03$i$i$i$i$i$i$i = $10;$reflection$01$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $12 = HEAP8[$p$01$i$i$i$i$i$i>>0]|0;
   $13 = $12&255;
   $14 = $15 >>> 8;
   $$masked$i$i$i$i$i$i = $15 & 255;
   $16 = $13 ^ $$masked$i$i$i$i$i$i;
   $17 = (584048 + ($16<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = $18 ^ $14;
   $20 = (($p$01$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i = ($20|0)==(((731856 + 87|0))|0);
   if ($exitcond$i$i$i$i$i$i) {
    break;
   } else {
    $15 = $19;$p$01$i$i$i$i$i$i = $20;
   }
  }
  $21 = $19 ^ -1;
  HEAP32[721704>>2] = $21;
  $22 = 721712;
  $23 = $22;
  HEAP32[$23>>2] = 1;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = 0;
  $27 = $21;$32 = 1;
 } else {
  $$pre$i$i$i = HEAP32[721704>>2]|0;
  $27 = $$pre$i$i$i;$32 = $3;
 }
 $26 = ($2|0)==($27|0);
 if (!($26)) {
  $$0 = Math_fround(1.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $28 = (($0) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  $$0 = Math_fround(1.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $31 = ($32<<24>>24)==(0);
 if ($31) {
  $$02$i$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i$i = 0;
  while(1) {
   $33 = $$02$i$i$i$i$i$i$i$i & 1;
   $34 = ($33|0)==(0);
   if ($34) {
    $reflection$1$i$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i$i;
   } else {
    $35 = (31 - ($i$03$i$i$i$i$i$i$i$i))|0;
    $36 = 1 << $35;
    $37 = $36 | $reflection$01$i$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i$i = $37;
   }
   $38 = (($i$03$i$i$i$i$i$i$i$i) + 1)|0;
   $39 = $$02$i$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i$i = ($38|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i$i) {
    $43 = $reflection$1$i$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i$i = 731856;
    break;
   } else {
    $$02$i$i$i$i$i$i$i$i = $39;$i$03$i$i$i$i$i$i$i$i = $38;$reflection$01$i$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $40 = HEAP8[$p$01$i$i$i$i$i$i$i>>0]|0;
   $41 = $40&255;
   $42 = $43 >>> 8;
   $$masked$i$i$i$i$i$i$i = $43 & 255;
   $44 = $41 ^ $$masked$i$i$i$i$i$i$i;
   $45 = (584048 + ($44<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = $46 ^ $42;
   $48 = (($p$01$i$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i$i1 = ($48|0)==(((731856 + 87|0))|0);
   if ($exitcond$i$i$i$i$i$i$i1) {
    break;
   } else {
    $43 = $47;$p$01$i$i$i$i$i$i$i = $48;
   }
  }
  $49 = $47 ^ -1;
  HEAP32[721704>>2] = $49;
  $50 = 721712;
  $51 = $50;
  HEAP32[$51>>2] = 1;
  $52 = (($50) + 4)|0;
  $53 = $52;
  HEAP32[$53>>2] = 0;
  $$pre = HEAP32[$28>>2]|0;
  $55 = $$pre;
 } else {
  $55 = $29;
 }
 $54 = (($55) + 280|0);
 $56 = HEAP32[$54>>2]|0;
 $57 = ($56|0)==(0|0);
 if ($57) {
  $$0 = Math_fround(1.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $58 = (Math_fround(__ZN11AudioSource34CalculateVolumeModifierForDistanceEf($56,$distance)));
 $$0 = $58;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN11AudioSource11AssignPropsEv($this) {
 $this = $this|0;
 var $$$i$i = Math_fround(0), $$$i$i14 = Math_fround(0), $$$i$i5 = Math_fround(0), $$$i$i8 = 0, $$0$i$i = Math_fround(0), $$0$i$i15 = Math_fround(0), $$0$i$i6 = Math_fround(0), $$0$i$i9 = 0, $$pre = 0, $$pre20 = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0);
 var $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $isPlaying$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $isPlaying$i = sp;
 $0 = (($this) + 356|0);
 $1 = (($this) + 444|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = Math_fround(HEAPF32[$0>>2]);
  $5 = (($this) + 352|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($this) + 360|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  (__ZN20SoundChannelInstance17set3DConeSettingsEfff($2,$6,$4,$8)|0);
 }
 $9 = (($this) + 408|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 404|0);
 $12 = ($10|0)==($11|0);
 $$pre = (($this) + 352|0);
 if (!($12)) {
  $13 = (($this) + 360|0);
  $15 = $10;
  while(1) {
   $14 = (($15) + 8|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = (($16) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = Math_fround(HEAPF32[$$pre>>2]);
   $20 = Math_fround(HEAPF32[$0>>2]);
   $21 = Math_fround(HEAPF32[$13>>2]);
   (__ZN20SoundChannelInstance17set3DConeSettingsEfff($18,$19,$20,$21)|0);
   $22 = (($15) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==($11|0);
   if ($24) {
    break;
   } else {
    $15 = $23;
   }
  }
 }
 $25 = HEAP32[$1>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = Math_fround(HEAPF32[$$pre>>2]);
  $28 = Math_fround(HEAPF32[$0>>2]);
  $29 = (($this) + 360|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  (__ZN20SoundChannelInstance17set3DConeSettingsEfff($25,$27,$28,$30)|0);
 }
 $31 = HEAP32[$9>>2]|0;
 $32 = ($31|0)==($11|0);
 $$pre22 = (($this) + 360|0);
 if (!($32)) {
  $34 = $31;
  while(1) {
   $33 = (($34) + 8|0);
   $35 = HEAP32[$33>>2]|0;
   $36 = (($35) + 24|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = Math_fround(HEAPF32[$$pre>>2]);
   $39 = Math_fround(HEAPF32[$0>>2]);
   $40 = Math_fround(HEAPF32[$$pre22>>2]);
   (__ZN20SoundChannelInstance17set3DConeSettingsEfff($37,$38,$39,$40)|0);
   $41 = (($34) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==($11|0);
   if ($43) {
    break;
   } else {
    $34 = $42;
   }
  }
 }
 $44 = Math_fround(HEAPF32[$$pre22>>2]);
 $45 = $44 < Math_fround(0.0);
 if ($45) {
  $$0$i$i = Math_fround(0.0);
 } else {
  $46 = $44 > Math_fround(1.0);
  $$$i$i = $46 ? Math_fround(1.0) : $44;
  $$0$i$i = $$$i$i;
 }
 HEAPF32[$$pre22>>2] = $$0$i$i;
 $47 = HEAP32[$1>>2]|0;
 $48 = ($47|0)==(0|0);
 if (!($48)) {
  $49 = Math_fround(HEAPF32[$$pre>>2]);
  $50 = Math_fround(HEAPF32[$0>>2]);
  (__ZN20SoundChannelInstance17set3DConeSettingsEfff($47,$49,$50,$$0$i$i)|0);
 }
 $51 = HEAP32[$9>>2]|0;
 $52 = ($51|0)==($11|0);
 if (!($52)) {
  $54 = $51;
  while(1) {
   $53 = (($54) + 8|0);
   $55 = HEAP32[$53>>2]|0;
   $56 = (($55) + 24|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = Math_fround(HEAPF32[$$pre>>2]);
   $59 = Math_fround(HEAPF32[$0>>2]);
   $60 = Math_fround(HEAPF32[$$pre22>>2]);
   (__ZN20SoundChannelInstance17set3DConeSettingsEfff($57,$58,$59,$60)|0);
   $61 = (($54) + 4|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==($11|0);
   if ($63) {
    break;
   } else {
    $54 = $62;
   }
  }
 }
 $64 = HEAP32[$1>>2]|0;
 $65 = ($64|0)==(0|0);
 if ($65) {
  label = 18;
 } else {
  $66 = (__ZN20SoundChannelInstance9isPlayingEPb($64,$isPlaying$i)|0);
  $67 = ($66|0)!=(0);
  $68 = HEAP8[$isPlaying$i>>0]|0;
  $69 = ($68<<24>>24)==(0);
  $or$cond$i = $67 | $69;
  if ($or$cond$i) {
   label = 18;
  } else {
   label = 19;
  }
 }
 if ((label|0) == 18) {
  $70 = HEAP32[$9>>2]|0;
  $71 = ($70|0)==($11|0);
  if (!($71)) {
   label = 19;
  }
 }
 if ((label|0) == 19) {
  __ZN11AudioSource11SetupGroupsEv($this);
 }
 $72 = (($this) + 368|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = $73 < Math_fround(0.0);
 if ($74) {
  $$0$i$i6 = Math_fround(0.0);
 } else {
  $75 = $73 > Math_fround(5.0);
  $$$i$i5 = $75 ? Math_fround(5.0) : $73;
  $$0$i$i6 = $$$i$i5;
 }
 HEAPF32[$72>>2] = $$0$i$i6;
 $76 = HEAP32[$1>>2]|0;
 $77 = ($76|0)==(0|0);
 if (!($77)) {
  (__ZN20SoundChannelInstance17set3DDopplerLevelEf($76,$$0$i$i6)|0);
 }
 $78 = HEAP32[$9>>2]|0;
 $79 = ($78|0)==($11|0);
 if (!($79)) {
  $81 = $78;
  while(1) {
   $80 = (($81) + 8|0);
   $82 = HEAP32[$80>>2]|0;
   $83 = (($82) + 24|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = Math_fround(HEAPF32[$72>>2]);
   (__ZN20SoundChannelInstance17set3DDopplerLevelEf($84,$85)|0);
   $86 = (($81) + 4|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)==($11|0);
   if ($88) {
    break;
   } else {
    $81 = $87;
   }
  }
 }
 $89 = (($this) + 384|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 __ZN11AudioSource8SetPitchEf($this,$90);
 $91 = (($this) + 364|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)<(0);
 if ($93) {
  $$0$i$i9 = 0;
 } else {
  $94 = ($92|0)>(255);
  $$$i$i8 = $94 ? 255 : $92;
  $$0$i$i9 = $$$i$i8;
 }
 HEAP32[$91>>2] = $$0$i$i9;
 $95 = HEAP32[$1>>2]|0;
 $96 = ($95|0)==(0|0);
 if (!($96)) {
  (__ZN20SoundChannelInstance11setPriorityEi($95,$$0$i$i9)|0);
 }
 $97 = HEAP32[$9>>2]|0;
 $98 = ($97|0)==($11|0);
 if (!($98)) {
  $100 = $97;
  while(1) {
   $99 = (($100) + 8|0);
   $101 = HEAP32[$99>>2]|0;
   $102 = (($101) + 24|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = HEAP32[$91>>2]|0;
   (__ZN20SoundChannelInstance11setPriorityEi($103,$104)|0);
   $105 = (($100) + 4|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = ($106|0)==($11|0);
   if ($107) {
    break;
   } else {
    $100 = $106;
   }
  }
 }
 $108 = (($this) + 372|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = $109 < Math_fround(0.0);
 $111 = $110 ? Math_fround(0.0) : $109;
 HEAPF32[$108>>2] = $111;
 $112 = HEAP32[$1>>2]|0;
 $113 = ($112|0)==(0|0);
 if (!($113)) {
  $114 = (($this) + 376|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  (__ZN20SoundChannelInstance19set3DMinMaxDistanceEff($112,$111,$115)|0);
 }
 $116 = HEAP32[$9>>2]|0;
 $117 = ($116|0)==($11|0);
 $$pre20 = (($this) + 376|0);
 if (!($117)) {
  $119 = $116;
  while(1) {
   $118 = (($119) + 8|0);
   $120 = HEAP32[$118>>2]|0;
   $121 = (($120) + 24|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = Math_fround(HEAPF32[$108>>2]);
   $124 = Math_fround(HEAPF32[$$pre20>>2]);
   (__ZN20SoundChannelInstance19set3DMinMaxDistanceEff($122,$123,$124)|0);
   $125 = (($119) + 4|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($126|0)==($11|0);
   if ($127) {
    break;
   } else {
    $119 = $126;
   }
  }
 }
 $128 = Math_fround(HEAPF32[$$pre20>>2]);
 $129 = Math_fround(HEAPF32[$108>>2]);
 $130 = $129 > $128;
 $131 = $130 ? $129 : $128;
 HEAPF32[$$pre20>>2] = $131;
 $132 = HEAP32[$1>>2]|0;
 $133 = ($132|0)==(0|0);
 if (!($133)) {
  (__ZN20SoundChannelInstance19set3DMinMaxDistanceEff($132,$129,$131)|0);
 }
 $134 = HEAP32[$9>>2]|0;
 $135 = ($134|0)==($11|0);
 if (!($135)) {
  $137 = $134;
  while(1) {
   $136 = (($137) + 8|0);
   $138 = HEAP32[$136>>2]|0;
   $139 = (($138) + 24|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = Math_fround(HEAPF32[$108>>2]);
   $142 = Math_fround(HEAPF32[$$pre20>>2]);
   (__ZN20SoundChannelInstance19set3DMinMaxDistanceEff($140,$141,$142)|0);
   $143 = (($137) + 4|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ($144|0)==($11|0);
   if ($145) {
    break;
   } else {
    $137 = $144;
   }
  }
 }
 $146 = (($this) + 380|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = $147 < Math_fround(-1.0);
 if ($148) {
  $$0$i$i15 = Math_fround(-1.0);
 } else {
  $149 = $147 > Math_fround(1.0);
  $$$i$i14 = $149 ? Math_fround(1.0) : $147;
  $$0$i$i15 = $$$i$i14;
 }
 HEAPF32[$146>>2] = $$0$i$i15;
 $150 = HEAP32[$1>>2]|0;
 $151 = ($150|0)==(0|0);
 if (!($151)) {
  (__ZN20SoundChannelInstance6setPanEf($150,$$0$i$i15)|0);
 }
 $152 = HEAP32[$9>>2]|0;
 $153 = ($152|0)==($11|0);
 if (!($153)) {
  $155 = $152;
  while(1) {
   $154 = (($155) + 8|0);
   $156 = HEAP32[$154>>2]|0;
   $157 = (($156) + 24|0);
   $158 = HEAP32[$157>>2]|0;
   $159 = Math_fround(HEAPF32[$146>>2]);
   (__ZN20SoundChannelInstance6setPanEf($158,$159)|0);
   $160 = (($155) + 4|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = ($161|0)==($11|0);
   if ($162) {
    break;
   } else {
    $155 = $161;
   }
  }
 }
 $163 = (($this) + 388|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 __ZN11AudioSource9SetVolumeEf($this,$164);
 $165 = (($this) + 396|0);
 $166 = HEAP8[$165>>0]|0;
 $167 = HEAP32[$1>>2]|0;
 $168 = ($167|0)==(0|0);
 if (!($168)) {
  $169 = ($166<<24>>24)!=(0);
  (__ZN20SoundChannelInstance7SetLoopEb($167,$169)|0);
 }
 $170 = HEAP32[$9>>2]|0;
 $171 = ($170|0)==($11|0);
 if (!($171)) {
  $173 = $170;
  while(1) {
   $172 = (($173) + 8|0);
   $174 = HEAP32[$172>>2]|0;
   $175 = (($174) + 24|0);
   $176 = HEAP32[$175>>2]|0;
   (__ZN20SoundChannelInstance7SetLoopEb($176,0)|0);
   $177 = (($173) + 4|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = ($178|0)==($11|0);
   if ($179) {
    break;
   } else {
    $173 = $178;
   }
  }
 }
 HEAP8[$165>>0] = $166;
 $180 = (($this) + 397|0);
 $181 = HEAP8[$180>>0]|0;
 $182 = ($181<<24>>24)!=(0);
 $183 = HEAP32[$1>>2]|0;
 $184 = ($183|0)==(0|0);
 if (!($184)) {
  (__ZN20SoundChannelInstance7setMuteEb($183,$182)|0);
 }
 $185 = HEAP32[$9>>2]|0;
 $186 = ($185|0)==($11|0);
 if ($186) {
  STACKTOP = sp;return;
 } else {
  $188 = $185;
 }
 while(1) {
  $187 = (($188) + 8|0);
  $189 = HEAP32[$187>>2]|0;
  $190 = (($189) + 24|0);
  $191 = HEAP32[$190>>2]|0;
  (__ZN20SoundChannelInstance7setMuteEb($191,$182)|0);
  $192 = (($188) + 4|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = ($193|0)==($11|0);
  if ($194) {
   break;
  } else {
   $188 = $193;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK11AudioSource27AreChannelOrOneshotsPlayingEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isPlaying = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $isPlaying = sp;
 $0 = (($this) + 444|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__ZN20SoundChannelInstance9isPlayingEPb($1,$isPlaying)|0);
  $4 = ($3|0)!=(0);
  $5 = HEAP8[$isPlaying>>0]|0;
  $6 = ($5<<24>>24)==(0);
  $or$cond = $4 | $6;
  if (!($or$cond)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $7 = (($this) + 408|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 404|0);
 $10 = ($8|0)!=($9|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11AudioSource11SetupGroupsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dsphead = 0, $i$046 = 0, $newParentGroup$1 = 0, $parentGroup = 0, $parentGroup1 = 0, $phitmp$i = 0;
 var $temp$0$i = 0, $temp$0$i17 = 0, $temp$0$i22 = 0, $vararg_buffer40 = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr2 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr25 = 0, $vararg_ptr26 = 0, $vararg_ptr27 = 0, $vararg_ptr3 = 0, $vararg_ptr31 = 0, $vararg_ptr32 = 0, $vararg_ptr33 = 0, $vararg_ptr37 = 0;
 var $vararg_ptr38 = 0, $vararg_ptr39 = 0, $vararg_ptr43 = 0, $vararg_ptr44 = 0, $vararg_ptr45 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $vararg_buffer40 = sp;
 $0 = sp + 68|0;
 $1 = sp + 64|0;
 $2 = sp + 60|0;
 $3 = sp + 56|0;
 $4 = sp + 52|0;
 $5 = sp + 80|0;
 $6 = sp + 32|0;
 $7 = sp + 20|0;
 $parentGroup = sp + 16|0;
 $dsphead = sp + 44|0;
 $parentGroup1 = sp + 48|0;
 $8 = (($this) + 472|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 do {
  if ($10) {
   $11 = (__Z15GetAudioManagerv()|0);
   $12 = (($11) + 92|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (__ZN4FMOD6System18createChannelGroupEPKcPPNS_12ChannelGroupE($13,731944,$8)|0);
   $15 = ($14|0)==(0);
   if (!($15)) {
    $16 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($14)|0);
    HEAP32[$vararg_buffer40>>2] = 731960;
    $vararg_ptr1 = (($vararg_buffer40) + 4|0);
    HEAP32[$vararg_ptr1>>2] = 309;
    $vararg_ptr2 = (($vararg_buffer40) + 8|0);
    HEAP32[$vararg_ptr2>>2] = 732032;
    $vararg_ptr3 = (($vararg_buffer40) + 12|0);
    HEAP32[$vararg_ptr3>>2] = $16;
    __Z6FormatPKcz($6,741616,$vararg_buffer40);
    $17 = HEAP8[$6>>0]|0;
    $18 = $17 & 1;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     $22 = (($6) + 1|0);
     $23 = $22;
    } else {
     $20 = (($6) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $23 = $21;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($23|0),0,(732472|0),21,1,0,0,(0|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = HEAP8[$6>>0]|0;
     $27 = $26 & 1;
     $28 = ($27<<24>>24)==(0);
     if ($28) {
      break;
     }
     $29 = (($6) + 8|0);
     $30 = HEAP32[$29>>2]|0;
     __ZdlPv($30);
     break;
    }
    $31 = ___cxa_find_matching_catch()|0;
    $32 = tempRet0;
    $33 = HEAP8[$6>>0]|0;
    $34 = $33 & 1;
    $35 = ($34<<24>>24)==(0);
    if ($35) {
     ___resumeException($31|0);
     // unreachable;
    }
    $36 = (($6) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    __ZdlPv($37);
    ___resumeException($31|0);
    // unreachable;
   }
  }
 } while(0);
 $38 = (($this) + 476|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 do {
  if ($40) {
   $41 = (__Z15GetAudioManagerv()|0);
   $42 = (($41) + 92|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__ZN4FMOD6System18createChannelGroupEPKcPPNS_12ChannelGroupE($43,732120,$38)|0);
   $45 = ($44|0)==(0);
   if (!($45)) {
    $46 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($44)|0);
    HEAP32[$vararg_buffer40>>2] = 731960;
    $vararg_ptr7 = (($vararg_buffer40) + 4|0);
    HEAP32[$vararg_ptr7>>2] = 314;
    $vararg_ptr8 = (($vararg_buffer40) + 8|0);
    HEAP32[$vararg_ptr8>>2] = 732136;
    $vararg_ptr9 = (($vararg_buffer40) + 12|0);
    HEAP32[$vararg_ptr9>>2] = $46;
    __Z6FormatPKcz($5,741616,$vararg_buffer40);
    $47 = HEAP8[$5>>0]|0;
    $48 = $47 & 1;
    $49 = ($48<<24>>24)==(0);
    if ($49) {
     $52 = (($5) + 1|0);
     $53 = $52;
    } else {
     $50 = (($5) + 8|0);
     $51 = HEAP32[$50>>2]|0;
     $53 = $51;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($53|0),0,(732472|0),21,1,0,0,(0|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     $56 = HEAP8[$5>>0]|0;
     $57 = $56 & 1;
     $58 = ($57<<24>>24)==(0);
     if ($58) {
      break;
     }
     $59 = (($5) + 8|0);
     $60 = HEAP32[$59>>2]|0;
     __ZdlPv($60);
     break;
    }
    $61 = ___cxa_find_matching_catch()|0;
    $62 = tempRet0;
    $63 = HEAP8[$5>>0]|0;
    $64 = $63 & 1;
    $65 = ($64<<24>>24)==(0);
    if ($65) {
     ___resumeException($61|0);
     // unreachable;
    }
    $66 = (($5) + 8|0);
    $67 = HEAP32[$66>>2]|0;
    __ZdlPv($67);
    ___resumeException($61|0);
    // unreachable;
   }
  }
 } while(0);
 $68 = (($this) + 416|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0);
 do {
  if ($70) {
   label = 62;
  } else {
   HEAP32[$4>>2] = $69;
   $71 = HEAP32[560624>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    label = 32;
   } else {
    $73 = (($71) + 36|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = (($71) + 4|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($74|0)==($76|0);
    do {
     if ($77) {
      $78 = (($71) + 28|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = (($71) + 32|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = (($79) + ($81<<3)|0);
      $98 = $82;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer40,$71,$4);
      $83 = HEAP32[$vararg_buffer40>>2]|0;
      $84 = ($83|0)==(-1);
      $85 = (($71) + 28|0);
      $86 = HEAP32[$85>>2]|0;
      if ($84) {
       $87 = (($71) + 32|0);
       $88 = HEAP32[$87>>2]|0;
       $89 = (($86) + ($88<<3)|0);
       $98 = $89;
       break;
      } else {
       $90 = (($86) + ($83<<3)|0);
       $98 = $90;
       break;
      }
     }
    } while(0);
    $91 = HEAP32[560624>>2]|0;
    $92 = (($91) + 28|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($91) + 32|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($93) + ($95<<3)|0);
    $97 = ($98|0)==($96|0);
    if ($97) {
     label = 32;
    } else {
     $99 = (($98) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = ($100|0)==(0|0);
     if ($101) {
      label = 32;
     } else {
      $106 = $91;
     }
    }
   }
   if ((label|0) == 32) {
    $102 = HEAP32[$68>>2]|0;
    $103 = (__Z31ReadObjectFromPersistentManageri($102)|0);
    $phitmp$i = ($103|0)==(0|0);
    if ($phitmp$i) {
     label = 62;
     break;
    }
    $$pre49 = HEAP32[560624>>2]|0;
    $106 = $$pre49;
   }
   $104 = HEAP32[$68>>2]|0;
   HEAP32[$3>>2] = $104;
   $105 = ($106|0)==(0|0);
   if ($105) {
    label = 42;
   } else {
    $107 = (($106) + 36|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = (($106) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ($108|0)==($110|0);
    do {
     if ($111) {
      $112 = (($106) + 28|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = (($106) + 32|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = (($113) + ($115<<3)|0);
      $132 = $116;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer40,$106,$3);
      $117 = HEAP32[$vararg_buffer40>>2]|0;
      $118 = ($117|0)==(-1);
      $119 = (($106) + 28|0);
      $120 = HEAP32[$119>>2]|0;
      if ($118) {
       $121 = (($106) + 32|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = (($120) + ($122<<3)|0);
       $132 = $123;
       break;
      } else {
       $124 = (($120) + ($117<<3)|0);
       $132 = $124;
       break;
      }
     }
    } while(0);
    $125 = HEAP32[560624>>2]|0;
    $126 = (($125) + 28|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = (($125) + 32|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = (($127) + ($129<<3)|0);
    $131 = ($132|0)==($130|0);
    if ($131) {
     label = 42;
    } else {
     $133 = (($132) + 4|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = ($134|0)==(0|0);
     if ($135) {
      label = 42;
     } else {
      $141 = $125;$temp$0$i = $134;
     }
    }
   }
   if ((label|0) == 42) {
    $136 = HEAP32[$68>>2]|0;
    $137 = (__Z31ReadObjectFromPersistentManageri($136)|0);
    $$pre47 = HEAP32[560624>>2]|0;
    $141 = $$pre47;$temp$0$i = $137;
   }
   $138 = (($temp$0$i) + 44|0);
   $139 = HEAP32[$138>>2]|0;
   HEAP32[$2>>2] = $139;
   $140 = ($141|0)==(0|0);
   if ($140) {
    label = 51;
   } else {
    $142 = (($141) + 36|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = (($141) + 4|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = ($143|0)==($145|0);
    do {
     if ($146) {
      $147 = (($141) + 28|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = (($141) + 32|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = (($148) + ($150<<3)|0);
      $167 = $151;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer40,$141,$2);
      $152 = HEAP32[$vararg_buffer40>>2]|0;
      $153 = ($152|0)==(-1);
      $154 = (($141) + 28|0);
      $155 = HEAP32[$154>>2]|0;
      if ($153) {
       $156 = (($141) + 32|0);
       $157 = HEAP32[$156>>2]|0;
       $158 = (($155) + ($157<<3)|0);
       $167 = $158;
       break;
      } else {
       $159 = (($155) + ($152<<3)|0);
       $167 = $159;
       break;
      }
     }
    } while(0);
    $160 = HEAP32[560624>>2]|0;
    $161 = (($160) + 28|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = (($160) + 32|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = (($162) + ($164<<3)|0);
    $166 = ($167|0)==($165|0);
    if ($166) {
     label = 51;
    } else {
     $168 = (($167) + 4|0);
     $169 = HEAP32[$168>>2]|0;
     $170 = ($169|0)==(0|0);
     if ($170) {
      label = 51;
     } else {
      $174 = $160;$temp$0$i17 = $169;
     }
    }
   }
   if ((label|0) == 51) {
    $171 = (__Z31ReadObjectFromPersistentManageri($139)|0);
    $$pre48 = HEAP32[560624>>2]|0;
    $174 = $$pre48;$temp$0$i17 = $171;
   }
   $172 = HEAP32[$68>>2]|0;
   HEAP32[$1>>2] = $172;
   $173 = ($174|0)==(0|0);
   if ($173) {
    label = 60;
   } else {
    $175 = (($174) + 36|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = (($174) + 4|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = ($176|0)==($178|0);
    do {
     if ($179) {
      $180 = (($174) + 28|0);
      $181 = HEAP32[$180>>2]|0;
      $182 = (($174) + 32|0);
      $183 = HEAP32[$182>>2]|0;
      $184 = (($181) + ($183<<3)|0);
      $200 = $184;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer40,$174,$1);
      $185 = HEAP32[$vararg_buffer40>>2]|0;
      $186 = ($185|0)==(-1);
      $187 = (($174) + 28|0);
      $188 = HEAP32[$187>>2]|0;
      if ($186) {
       $189 = (($174) + 32|0);
       $190 = HEAP32[$189>>2]|0;
       $191 = (($188) + ($190<<3)|0);
       $200 = $191;
       break;
      } else {
       $192 = (($188) + ($185<<3)|0);
       $200 = $192;
       break;
      }
     }
    } while(0);
    $193 = HEAP32[560624>>2]|0;
    $194 = (($193) + 28|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = (($193) + 32|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = (($195) + ($197<<3)|0);
    $199 = ($200|0)==($198|0);
    if ($199) {
     label = 60;
    } else {
     $201 = (($200) + 4|0);
     $202 = HEAP32[$201>>2]|0;
     $203 = ($202|0)==(0|0);
     if ($203) {
      label = 60;
     } else {
      $temp$0$i22 = $202;
     }
    }
   }
   if ((label|0) == 60) {
    $204 = HEAP32[$68>>2]|0;
    $205 = (__Z31ReadObjectFromPersistentManageri($204)|0);
    $temp$0$i22 = $205;
   }
   $206 = (($temp$0$i22) + 48|0);
   $207 = (__ZN10AudioMixer19GetFMODChannelGroupERK9UnityGUID($temp$0$i17,$206)|0);
   $208 = ($207|0)==(0|0);
   if ($208) {
    label = 62;
   } else {
    $newParentGroup$1 = $207;
   }
  }
 } while(0);
 do {
  if ((label|0) == 62) {
   $209 = (($this) + 399|0);
   $210 = HEAP8[$209>>0]|0;
   $211 = ($210<<24>>24)==(0);
   $212 = (($this) + 480|0);
   $213 = HEAP8[$212>>0]|0;
   $214 = ($213<<24>>24)!=(0);
   $215 = (__Z15GetAudioManagerv()|0);
   if ($211) {
    if ($214) {
     $220 = (($215) + 100|0);
     $221 = HEAP32[$220>>2]|0;
     $newParentGroup$1 = $221;
     break;
    } else {
     $222 = (($215) + 104|0);
     $223 = HEAP32[$222>>2]|0;
     $newParentGroup$1 = $223;
     break;
    }
   } else {
    if ($214) {
     $216 = (($215) + 108|0);
     $217 = HEAP32[$216>>2]|0;
     $newParentGroup$1 = $217;
     break;
    } else {
     $218 = (($215) + 112|0);
     $219 = HEAP32[$218>>2]|0;
     $newParentGroup$1 = $219;
     break;
    }
   }
  }
 } while(0);
 $224 = (($this) + 398|0);
 $225 = HEAP8[$224>>0]|0;
 $226 = ($225<<24>>24)==(0);
 $227 = HEAP32[$8>>2]|0;
 do {
  if ($226) {
   $302 = (__ZN4FMOD12ChannelGroup14getParentGroupEPPS0_($227,$parentGroup1)|0);
   $303 = ($302|0)==(0);
   do {
    if (!($303)) {
     $304 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($302)|0);
     HEAP32[$vararg_buffer40>>2] = 731960;
     $vararg_ptr31 = (($vararg_buffer40) + 4|0);
     HEAP32[$vararg_ptr31>>2] = 353;
     $vararg_ptr32 = (($vararg_buffer40) + 8|0);
     HEAP32[$vararg_ptr32>>2] = 732224;
     $vararg_ptr33 = (($vararg_buffer40) + 12|0);
     HEAP32[$vararg_ptr33>>2] = $304;
     __Z6FormatPKcz($0,741616,$vararg_buffer40);
     $305 = HEAP8[$0>>0]|0;
     $306 = $305 & 1;
     $307 = ($306<<24>>24)==(0);
     if ($307) {
      $310 = (($0) + 1|0);
      $311 = $310;
     } else {
      $308 = (($0) + 8|0);
      $309 = HEAP32[$308>>2]|0;
      $311 = $309;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($311|0),0,(732472|0),21,1,0,0,(0|0));
     $312 = __THREW__; __THREW__ = 0;
     $313 = $312&1;
     if (!($313)) {
      $314 = HEAP8[$0>>0]|0;
      $315 = $314 & 1;
      $316 = ($315<<24>>24)==(0);
      if ($316) {
       break;
      }
      $317 = (($0) + 8|0);
      $318 = HEAP32[$317>>2]|0;
      __ZdlPv($318);
      break;
     }
     $319 = ___cxa_find_matching_catch()|0;
     $320 = tempRet0;
     $321 = HEAP8[$0>>0]|0;
     $322 = $321 & 1;
     $323 = ($322<<24>>24)==(0);
     if ($323) {
      ___resumeException($319|0);
      // unreachable;
     }
     $324 = (($0) + 8|0);
     $325 = HEAP32[$324>>2]|0;
     __ZdlPv($325);
     ___resumeException($319|0);
     // unreachable;
    }
   } while(0);
   $326 = HEAP32[$38>>2]|0;
   $327 = HEAP32[$8>>2]|0;
   $328 = (__ZN4FMOD12ChannelGroup8addGroupEPS0_($326,$327)|0);
   $329 = ($328|0)==(0);
   do {
    if (!($329)) {
     $330 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($328)|0);
     HEAP32[$vararg_buffer40>>2] = 731960;
     $vararg_ptr37 = (($vararg_buffer40) + 4|0);
     HEAP32[$vararg_ptr37>>2] = 354;
     $vararg_ptr38 = (($vararg_buffer40) + 8|0);
     HEAP32[$vararg_ptr38>>2] = 732352;
     $vararg_ptr39 = (($vararg_buffer40) + 12|0);
     HEAP32[$vararg_ptr39>>2] = $330;
     __Z6FormatPKcz($0,741616,$vararg_buffer40);
     $331 = HEAP8[$0>>0]|0;
     $332 = $331 & 1;
     $333 = ($332<<24>>24)==(0);
     if ($333) {
      $336 = (($0) + 1|0);
      $337 = $336;
     } else {
      $334 = (($0) + 8|0);
      $335 = HEAP32[$334>>2]|0;
      $337 = $335;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($337|0),0,(732472|0),21,1,0,0,(0|0));
     $338 = __THREW__; __THREW__ = 0;
     $339 = $338&1;
     if (!($339)) {
      $340 = HEAP8[$0>>0]|0;
      $341 = $340 & 1;
      $342 = ($341<<24>>24)==(0);
      if ($342) {
       break;
      }
      $343 = (($0) + 8|0);
      $344 = HEAP32[$343>>2]|0;
      __ZdlPv($344);
      break;
     }
     $345 = ___cxa_find_matching_catch()|0;
     $346 = tempRet0;
     $347 = HEAP8[$0>>0]|0;
     $348 = $347 & 1;
     $349 = ($348<<24>>24)==(0);
     if ($349) {
      ___resumeException($345|0);
      // unreachable;
     }
     $350 = (($0) + 8|0);
     $351 = HEAP32[$350>>2]|0;
     __ZdlPv($351);
     ___resumeException($345|0);
     // unreachable;
    }
   } while(0);
   $352 = HEAP32[$38>>2]|0;
   $353 = (__ZN4FMOD12ChannelGroup8addGroupEPS0_($newParentGroup$1,$352)|0);
   $354 = ($353|0)==(0);
   if (!($354)) {
    $355 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($353)|0);
    HEAP32[$vararg_buffer40>>2] = 731960;
    $vararg_ptr43 = (($vararg_buffer40) + 4|0);
    HEAP32[$vararg_ptr43>>2] = 356;
    $vararg_ptr44 = (($vararg_buffer40) + 8|0);
    HEAP32[$vararg_ptr44>>2] = 732392;
    $vararg_ptr45 = (($vararg_buffer40) + 12|0);
    HEAP32[$vararg_ptr45>>2] = $355;
    __Z6FormatPKcz($7,741616,$vararg_buffer40);
    $356 = HEAP8[$7>>0]|0;
    $357 = $356 & 1;
    $358 = ($357<<24>>24)==(0);
    if ($358) {
     $361 = (($7) + 1|0);
     $362 = $361;
    } else {
     $359 = (($7) + 8|0);
     $360 = HEAP32[$359>>2]|0;
     $362 = $360;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($362|0),0,(732472|0),21,1,0,0,(0|0));
    $363 = __THREW__; __THREW__ = 0;
    $364 = $363&1;
    if (!($364)) {
     $365 = HEAP8[$7>>0]|0;
     $366 = $365 & 1;
     $367 = ($366<<24>>24)==(0);
     if ($367) {
      break;
     }
     $368 = (($7) + 8|0);
     $369 = HEAP32[$368>>2]|0;
     __ZdlPv($369);
     break;
    }
    $370 = ___cxa_find_matching_catch()|0;
    $371 = tempRet0;
    $372 = HEAP8[$7>>0]|0;
    $373 = $372 & 1;
    $374 = ($373<<24>>24)==(0);
    if ($374) {
     ___resumeException($370|0);
     // unreachable;
    }
    $375 = (($7) + 8|0);
    $376 = HEAP32[$375>>2]|0;
    __ZdlPv($376);
    ___resumeException($370|0);
    // unreachable;
   }
  } else {
   $228 = (__ZN4FMOD12ChannelGroup14getParentGroupEPPS0_($227,$parentGroup)|0);
   $229 = ($228|0)==(0);
   do {
    if (!($229)) {
     $230 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($228)|0);
     HEAP32[$vararg_buffer40>>2] = 731960;
     $vararg_ptr13 = (($vararg_buffer40) + 4|0);
     HEAP32[$vararg_ptr13>>2] = 344;
     $vararg_ptr14 = (($vararg_buffer40) + 8|0);
     HEAP32[$vararg_ptr14>>2] = 732224;
     $vararg_ptr15 = (($vararg_buffer40) + 12|0);
     HEAP32[$vararg_ptr15>>2] = $230;
     __Z6FormatPKcz($0,741616,$vararg_buffer40);
     $231 = HEAP8[$0>>0]|0;
     $232 = $231 & 1;
     $233 = ($232<<24>>24)==(0);
     if ($233) {
      $236 = (($0) + 1|0);
      $237 = $236;
     } else {
      $234 = (($0) + 8|0);
      $235 = HEAP32[$234>>2]|0;
      $237 = $235;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($237|0),0,(732472|0),21,1,0,0,(0|0));
     $238 = __THREW__; __THREW__ = 0;
     $239 = $238&1;
     if (!($239)) {
      $240 = HEAP8[$0>>0]|0;
      $241 = $240 & 1;
      $242 = ($241<<24>>24)==(0);
      if ($242) {
       break;
      }
      $243 = (($0) + 8|0);
      $244 = HEAP32[$243>>2]|0;
      __ZdlPv($244);
      break;
     }
     $245 = ___cxa_find_matching_catch()|0;
     $246 = tempRet0;
     $247 = HEAP8[$0>>0]|0;
     $248 = $247 & 1;
     $249 = ($248<<24>>24)==(0);
     if ($249) {
      ___resumeException($245|0);
      // unreachable;
     }
     $250 = (($0) + 8|0);
     $251 = HEAP32[$250>>2]|0;
     __ZdlPv($251);
     ___resumeException($245|0);
     // unreachable;
    }
   } while(0);
   $252 = HEAP32[$8>>2]|0;
   $253 = (__ZN4FMOD12ChannelGroup8addGroupEPS0_($newParentGroup$1,$252)|0);
   $254 = ($253|0)==(0);
   do {
    if (!($254)) {
     $255 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($253)|0);
     HEAP32[$vararg_buffer40>>2] = 731960;
     $vararg_ptr19 = (($vararg_buffer40) + 4|0);
     HEAP32[$vararg_ptr19>>2] = 345;
     $vararg_ptr20 = (($vararg_buffer40) + 8|0);
     HEAP32[$vararg_ptr20>>2] = 732272;
     $vararg_ptr21 = (($vararg_buffer40) + 12|0);
     HEAP32[$vararg_ptr21>>2] = $255;
     __Z6FormatPKcz($0,741616,$vararg_buffer40);
     $256 = HEAP8[$0>>0]|0;
     $257 = $256 & 1;
     $258 = ($257<<24>>24)==(0);
     if ($258) {
      $261 = (($0) + 1|0);
      $262 = $261;
     } else {
      $259 = (($0) + 8|0);
      $260 = HEAP32[$259>>2]|0;
      $262 = $260;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($262|0),0,(732472|0),21,1,0,0,(0|0));
     $263 = __THREW__; __THREW__ = 0;
     $264 = $263&1;
     if (!($264)) {
      $265 = HEAP8[$0>>0]|0;
      $266 = $265 & 1;
      $267 = ($266<<24>>24)==(0);
      if ($267) {
       break;
      }
      $268 = (($0) + 8|0);
      $269 = HEAP32[$268>>2]|0;
      __ZdlPv($269);
      break;
     }
     $270 = ___cxa_find_matching_catch()|0;
     $271 = tempRet0;
     $272 = HEAP8[$0>>0]|0;
     $273 = $272 & 1;
     $274 = ($273<<24>>24)==(0);
     if ($274) {
      ___resumeException($270|0);
      // unreachable;
     }
     $275 = (($0) + 8|0);
     $276 = HEAP32[$275>>2]|0;
     __ZdlPv($276);
     ___resumeException($270|0);
     // unreachable;
    }
   } while(0);
   HEAP32[$dsphead>>2] = 0;
   $277 = HEAP32[$38>>2]|0;
   $278 = (__ZN4FMOD12ChannelGroup10getDSPHeadEPPNS_3DSPE($277,$dsphead)|0);
   $279 = ($278|0)==(0);
   if (!($279)) {
    $280 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($278)|0);
    HEAP32[$vararg_buffer40>>2] = 731960;
    $vararg_ptr25 = (($vararg_buffer40) + 4|0);
    HEAP32[$vararg_ptr25>>2] = 347;
    $vararg_ptr26 = (($vararg_buffer40) + 8|0);
    HEAP32[$vararg_ptr26>>2] = 732312;
    $vararg_ptr27 = (($vararg_buffer40) + 12|0);
    HEAP32[$vararg_ptr27>>2] = $280;
    __Z6FormatPKcz($0,741616,$vararg_buffer40);
    $281 = HEAP8[$0>>0]|0;
    $282 = $281 & 1;
    $283 = ($282<<24>>24)==(0);
    if ($283) {
     $286 = (($0) + 1|0);
     $287 = $286;
    } else {
     $284 = (($0) + 8|0);
     $285 = HEAP32[$284>>2]|0;
     $287 = $285;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($287|0),0,(732472|0),21,1,0,0,(0|0));
    $288 = __THREW__; __THREW__ = 0;
    $289 = $288&1;
    if (!($289)) {
     $290 = HEAP8[$0>>0]|0;
     $291 = $290 & 1;
     $292 = ($291<<24>>24)==(0);
     if ($292) {
      break;
     }
     $293 = (($0) + 8|0);
     $294 = HEAP32[$293>>2]|0;
     __ZdlPv($294);
     break;
    }
    $295 = ___cxa_find_matching_catch()|0;
    $296 = tempRet0;
    $297 = HEAP8[$0>>0]|0;
    $298 = $297 & 1;
    $299 = ($298<<24>>24)==(0);
    if ($299) {
     ___resumeException($295|0);
     // unreachable;
    }
    $300 = (($0) + 8|0);
    $301 = HEAP32[$300>>2]|0;
    __ZdlPv($301);
    ___resumeException($295|0);
    // unreachable;
   }
  }
 } while(0);
 $377 = (($this) + 24|0);
 $378 = HEAP32[$377>>2]|0;
 $379 = ($378|0)==(0|0);
 if ($379) {
  STACKTOP = sp;return;
 }
 $380 = (($378) + 32|0);
 $381 = HEAP32[$380>>2]|0;
 $382 = ($381|0)>(0);
 if (!($382)) {
  STACKTOP = sp;return;
 }
 $383 = (($378) + 24|0);
 $409 = $381;$i$046 = 0;
 while(1) {
  $384 = HEAP32[$383>>2]|0;
  $385 = ((($384) + ($i$046<<3)|0) + 4|0);
  $386 = HEAP32[$385>>2]|0;
  $387 = ($386|0)==(0|0);
  if ($387) {
   $408 = $409;
  } else {
   $388 = (($386) + 8|0);
   $389 = HEAP32[$388>>2]|0;
   $390 = $389 >>> 21;
   $391 = HEAP32[560640>>2]|0;
   $392 = Math_imul($391, $390)|0;
   $393 = (($392) + 181)|0;
   $394 = $393 >> 5;
   $395 = $394 << 5;
   $396 = (($393) - ($395))|0;
   $397 = HEAP32[560632>>2]|0;
   $398 = (($397) + ($394<<2)|0);
   $399 = HEAP32[$398>>2]|0;
   $400 = 1 << $396;
   $401 = $400 & $399;
   $402 = ($401|0)==(0);
   if ($402) {
    $408 = $409;
   } else {
    $403 = (__ZN11AudioFilter6GetDSPEv($386)|0);
    $404 = HEAP8[$224>>0]|0;
    $405 = ($404<<24>>24)==(0);
    (__ZN4FMOD3DSP9setActiveEb($403,$405)|0);
    $$pre = HEAP32[$380>>2]|0;
    $408 = $$pre;
   }
  }
  $406 = (($i$046) + 1)|0;
  $407 = ($406|0)<($408|0);
  if ($407) {
   $409 = $408;$i$046 = $406;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11AudioSource8SetPitchEf($this,$pitch) {
 $this = $this|0;
 $pitch = Math_fround($pitch);
 var $$0$i = 0, $$mux = 0, $$pr$pre = 0, $$pr7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0;
 var $c = 0, $phitmp = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 24|0;
 $0 = sp;
 $c = sp + 8|0;
 $1 = (HEAPF32[tempDoublePtr>>2]=$pitch,HEAP32[tempDoublePtr>>2]|0);
 $2 = (($this) + 412|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $3;
  $5 = HEAP32[560624>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   label = 10;
  } else {
   $7 = (($5) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   do {
    if ($11) {
     $12 = (($5) + 28|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($5) + 32|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($13) + ($15<<3)|0);
     $32 = $16;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$0);
     $17 = HEAP32[$pos$i$i$i$i>>2]|0;
     $18 = ($17|0)==(-1);
     $19 = (($5) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     if ($18) {
      $21 = (($5) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $32 = $23;
      break;
     } else {
      $24 = (($20) + ($17<<3)|0);
      $32 = $24;
      break;
     }
    }
   } while(0);
   $25 = HEAP32[560624>>2]|0;
   $26 = (($25) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 32|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + ($29<<3)|0);
   $31 = ($32|0)==($30|0);
   if ($31) {
    label = 10;
   } else {
    $33 = (($32) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 10;
    } else {
     $temp$0$i = $34;
    }
   }
  }
  if ((label|0) == 10) {
   $36 = HEAP32[$2>>2]|0;
   $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
   $temp$0$i = $37;
  }
  $$0$i = $temp$0$i;
 }
 $38 = $1 & 2139095040;
 $39 = ($38|0)==(2139095040);
 if ($39) {
  $40 = ($this|0)==(0|0);
  if ($40) {
   $43 = 0;
  } else {
   $41 = (($this) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = $42;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(733328,0,732472,887,512,$43,0,0);
  STACKTOP = sp;return;
 }
 $44 = $1 & 2147483647;
 $45 = ($44>>>0)>(2139095040);
 if ($45) {
  $46 = ($this|0)==(0|0);
  if ($46) {
   $49 = 0;
  } else {
   $47 = (($this) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = $48;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(733408,0,732472,892,512,$49,0,0);
  STACKTOP = sp;return;
 }
 $50 = $pitch < Math_fround(0.0);
 if ($50) {
  $51 = (($$0$i) + 76|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(-1);
  if ($53) {
   label = 26;
  } else {
   $54 = (($$0$i) + 72|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55|0)==(0);
   if ($56) {
    label = 27;
   } else {
    $57 = ($this|0)==(0|0);
    if ($57) {
     $60 = 0;
    } else {
     $58 = (($this) + 4|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = $59;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(733480,0,732472,897,512,$60,0,0);
    STACKTOP = sp;return;
   }
  }
 } else {
  label = 26;
 }
 if ((label|0) == 26) {
  $61 = ($$0$i|0)==(0|0);
  if ($61) {
   $70 = $1;
  } else {
   label = 27;
  }
 }
 if ((label|0) == 27) {
  $62 = (($$0$i) + 128|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($63|0)==(0|0);
  if ($64) {
   $70 = $1;
  } else {
   $65 = (($63) + 40|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   $brmerge = $67 | $50;
   $$mux = $67 ? $1 : 0;
   if ($brmerge) {
    $70 = $$mux;
   } else {
    $68 = $pitch > Math_fround(3.0);
    $phitmp = $68 ? 1077936128 : $1;
    $70 = $phitmp;
   }
  }
 }
 $69 = (HEAP32[tempDoublePtr>>2]=$70,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $71 = (($this) + 384|0);
 HEAPF32[$71>>2] = $69;
 $72 = (($this) + 444|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(0|0);
 if (!($74)) {
  $75 = (($73) + 268|0);
  HEAPF32[$75>>2] = $69;
  __ZN20SoundChannelInstance11UpdatePitchEv($73);
 }
 $76 = (($this) + 408|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($this) + 404|0);
 $79 = ($77|0)==($78|0);
 if ($79) {
  STACKTOP = sp;return;
 }
 $80 = (($c) + 4|0);
 $81 = (($c) + 8|0);
 $82 = (($c) + 12|0);
 $84 = $77;
 L52: while(1) {
  $83 = (($84) + 8|0);
  $85 = HEAP32[$83>>2]|0;
  HEAP32[$c>>2] = 0;
  HEAP32[$80>>2] = 0;
  HEAP32[$81>>2] = $c;
  $86 = (($85) + 24|0);
  $87 = HEAP32[$86>>2]|0;
  HEAP32[$82>>2] = $87;
  $88 = ($87|0)==(0|0);
  do {
   if (!($88)) {
    $89 = (($87) + 208|0);
    $90 = ($c|0)==($89|0);
    if ($90) {
     $$pr7 = $87;
    } else {
     $91 = HEAP32[$89>>2]|0;
     HEAP32[$c>>2] = $91;
     HEAP32[$80>>2] = $89;
     $92 = (($91) + 4|0);
     HEAP32[$92>>2] = $c;
     $93 = HEAP32[$80>>2]|0;
     HEAP32[$93>>2] = $c;
     $$pr$pre = HEAP32[$82>>2]|0;
     $94 = ($$pr$pre|0)==(0|0);
     if ($94) {
      break;
     } else {
      $$pr7 = $$pr$pre;
     }
    }
    $95 = (($$pr7) + 268|0);
    HEAPF32[$95>>2] = $69;
    __THREW__ = 0;
    invoke_vi(3660,($$pr7|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     break L52;
    }
   }
  } while(0);
  HEAP32[$82>>2] = 0;
  $106 = HEAP32[$c>>2]|0;
  $107 = ($106|0)==(0|0);
  if (!($107)) {
   $108 = HEAP32[$80>>2]|0;
   $109 = (($106) + 4|0);
   HEAP32[$109>>2] = $108;
   $110 = HEAP32[$c>>2]|0;
   $111 = HEAP32[$80>>2]|0;
   HEAP32[$111>>2] = $110;
   HEAP32[$c>>2] = 0;
   HEAP32[$80>>2] = 0;
  }
  $112 = (($84) + 4|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ($113|0)==($78|0);
  if ($114) {
   label = 43;
   break;
  } else {
   $84 = $113;
  }
 }
 if ((label|0) == 43) {
  STACKTOP = sp;return;
 }
 $98 = ___cxa_find_matching_catch()|0;
 $99 = tempRet0;
 HEAP32[$82>>2] = 0;
 $100 = HEAP32[$c>>2]|0;
 $101 = ($100|0)==(0|0);
 if ($101) {
  ___resumeException($98|0);
  // unreachable;
 }
 $102 = HEAP32[$80>>2]|0;
 $103 = (($100) + 4|0);
 HEAP32[$103>>2] = $102;
 $104 = HEAP32[$c>>2]|0;
 $105 = HEAP32[$80>>2]|0;
 HEAP32[$105>>2] = $104;
 HEAP32[$c>>2] = 0;
 HEAP32[$80>>2] = 0;
 ___resumeException($98|0);
 // unreachable;
}
function __ZN11AudioSource9SetVolumeEf($this,$gain) {
 $this = $this|0;
 $gain = Math_fround($gain);
 var $$$i = Math_fround(0), $$0$i = Math_fround(0), $$pr$pre = 0, $$pr5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $c = sp;
 $0 = $gain < Math_fround(0.0);
 if ($0) {
  $$0$i = Math_fround(0.0);
 } else {
  $1 = $gain > Math_fround(1.0);
  $$$i = $1 ? Math_fround(1.0) : $gain;
  $$0$i = $$$i;
 }
 $2 = (($this) + 388|0);
 HEAPF32[$2>>2] = $$0$i;
 $3 = (($this) + 444|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($4) + 260|0);
  HEAPF32[$6>>2] = $$0$i;
  __ZN20SoundChannelInstance12UpdateVolumeEv($4);
 }
 $7 = (($this) + 408|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 404|0);
 $10 = ($8|0)==($9|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($c) + 4|0);
 $12 = (($c) + 8|0);
 $13 = (($c) + 12|0);
 $15 = $8;
 L10: while(1) {
  $14 = (($15) + 8|0);
  $16 = HEAP32[$14>>2]|0;
  HEAP32[$c>>2] = 0;
  HEAP32[$11>>2] = 0;
  HEAP32[$12>>2] = $c;
  $17 = (($16) + 24|0);
  $18 = HEAP32[$17>>2]|0;
  HEAP32[$13>>2] = $18;
  $19 = ($18|0)==(0|0);
  do {
   if (!($19)) {
    $20 = (($18) + 208|0);
    $21 = ($c|0)==($20|0);
    if ($21) {
     $$pr5 = $18;
    } else {
     $22 = HEAP32[$20>>2]|0;
     HEAP32[$c>>2] = $22;
     HEAP32[$11>>2] = $20;
     $23 = (($22) + 4|0);
     HEAP32[$23>>2] = $c;
     $24 = HEAP32[$11>>2]|0;
     HEAP32[$24>>2] = $c;
     $$pr$pre = HEAP32[$13>>2]|0;
     $25 = ($$pr$pre|0)==(0|0);
     if ($25) {
      break;
     } else {
      $$pr5 = $$pr$pre;
     }
    }
    $26 = Math_fround(HEAPF32[$2>>2]);
    $27 = (($$pr5) + 260|0);
    HEAPF32[$27>>2] = $26;
    __THREW__ = 0;
    invoke_vi(3661,($$pr5|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break L10;
    }
   }
  } while(0);
  HEAP32[$13>>2] = 0;
  $38 = HEAP32[$c>>2]|0;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   $40 = HEAP32[$11>>2]|0;
   $41 = (($38) + 4|0);
   HEAP32[$41>>2] = $40;
   $42 = HEAP32[$c>>2]|0;
   $43 = HEAP32[$11>>2]|0;
   HEAP32[$43>>2] = $42;
   HEAP32[$c>>2] = 0;
   HEAP32[$11>>2] = 0;
  }
  $44 = (($15) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==($9|0);
  if ($46) {
   label = 16;
   break;
  } else {
   $15 = $45;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 HEAP32[$13>>2] = 0;
 $32 = HEAP32[$c>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  ___resumeException($30|0);
  // unreachable;
 }
 $34 = HEAP32[$11>>2]|0;
 $35 = (($32) + 4|0);
 HEAP32[$35>>2] = $34;
 $36 = HEAP32[$c>>2]|0;
 $37 = HEAP32[$11>>2]|0;
 HEAP32[$37>>2] = $36;
 HEAP32[$c>>2] = 0;
 HEAP32[$11>>2] = 0;
 ___resumeException($30|0);
 // unreachable;
}
function __ZN11AudioSource32CorrectScheduledTimeAfterUnpauseEy($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $hiclock = 0, $loclock = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $hiclock = sp + 4|0;
 $loclock = sp;
 $2 = (($this) + 444|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 482|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  (__ZN20SoundChannelInstance8getDelayE14FMOD_DELAYTYPEPjS1_($3,1,$hiclock,$loclock)|0);
  $8 = HEAP32[$loclock>>2]|0;
  $9 = (($8) + ($0))|0;
  $10 = ($9>>>0)<($8>>>0);
  $11 = $10&1;
  $12 = HEAP32[$hiclock>>2]|0;
  $13 = (($12) + ($1))|0;
  $14 = (($13) + ($11))|0;
  HEAP32[$hiclock>>2] = $14;
  HEAP32[$loclock>>2] = $9;
  $15 = HEAP32[$2>>2]|0;
  (__ZN20SoundChannelInstance8setDelayE14FMOD_DELAYTYPEjj($15,1,$14,$9)|0);
 }
 $16 = (($this) + 483|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$2>>2]|0;
 (__ZN20SoundChannelInstance8getDelayE14FMOD_DELAYTYPEPjS1_($19,2,$hiclock,$loclock)|0);
 $20 = HEAP32[$loclock>>2]|0;
 $21 = (($20) + ($0))|0;
 $22 = ($21>>>0)<($20>>>0);
 $23 = $22&1;
 $24 = HEAP32[$hiclock>>2]|0;
 $25 = (($24) + ($1))|0;
 $26 = (($25) + ($23))|0;
 HEAP32[$hiclock>>2] = $26;
 HEAP32[$loclock>>2] = $21;
 $27 = HEAP32[$2>>2]|0;
 (__ZN20SoundChannelInstance8setDelayE14FMOD_DELAYTYPEjj($27,2,$26,$21)|0);
 STACKTOP = sp;return;
}
function __ZN11AudioSource4StopEb($this,$stopOneShots) {
 $this = $this|0;
 $stopOneShots = $stopOneShots|0;
 var $$ = 0, $$byval_copy25 = 0, $$ph = 0, $$pr = 0, $$pre = 0, $$pre34 = 0, $$pre35$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $eh$lpad$body$index4Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond = 0;
 var $filter = 0, $filters = 0, $n$01$i$i = 0, $n$04$i = 0, $node$0$i = 0, $node$01$i = 0, $node$03$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $size$02$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0;
 var $vararg_ptr10 = 0, $vararg_ptr11 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, $vararg_ptr17 = 0, $vararg_ptr18 = 0, $vararg_ptr22 = 0, $vararg_ptr23 = 0, $vararg_ptr24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy25 = sp;
 $0 = sp + 64|0;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 $3 = sp + 32|0;
 $filter = sp + 48|0;
 $filters = sp + 52|0;
 $4 = (($this) + 482|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 483|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 444|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  __ZN20SoundChannelInstance4StopEv($7);
 }
 HEAP32[$3>>2] = 0;
 $9 = (($3) + 4|0);
 HEAP32[$9>>2] = 0;
 $10 = (($3) + 8|0);
 HEAP32[$10>>2] = $3;
 $11 = (($3) + 12|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$6>>2] = 0;
 $12 = (($this) + 432|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  HEAP32[$11>>2] = 0;
 } else {
  $15 = (($this) + 436|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($13) + 4|0);
  HEAP32[$17>>2] = $16;
  $18 = HEAP32[$12>>2]|0;
  $19 = HEAP32[$15>>2]|0;
  HEAP32[$19>>2] = $18;
  HEAP32[$12>>2] = 0;
  HEAP32[$15>>2] = 0;
  $$pre = HEAP32[$3>>2]|0;
  HEAP32[$11>>2] = 0;
  $20 = ($$pre|0)==(0|0);
  if (!($20)) {
   $21 = HEAP32[$9>>2]|0;
   $22 = (($$pre) + 4|0);
   HEAP32[$22>>2] = $21;
   $23 = HEAP32[$3>>2]|0;
   $24 = HEAP32[$9>>2]|0;
   HEAP32[$24>>2] = $23;
   HEAP32[$3>>2] = 0;
   HEAP32[$9>>2] = 0;
  }
 }
 if ($stopOneShots) {
  $25 = (($this) + 404|0);
  $26 = (($this) + 408|0);
  $node$01$i = HEAP32[$26>>2]|0;
  $27 = ($node$01$i|0)==($25|0);
  if ($27) {
   $$ph = 0;
   label = 19;
  } else {
   $node$03$i = $node$01$i;$size$02$i = 0;
   while(1) {
    $28 = (($node$03$i) + 4|0);
    $29 = (($size$02$i) + 1)|0;
    $node$0$i = HEAP32[$28>>2]|0;
    $30 = ($node$0$i|0)==($25|0);
    if ($30) {
     break;
    } else {
     $node$03$i = $node$0$i;$size$02$i = $29;
    }
   }
   $31 = ($29|0)<(1);
   if ($31) {
    $36 = $node$01$i;$46 = 0;
   } else {
    $32 = $29 << 2;
    $33 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $33;
    ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$0+0>>2]|0;
    $34 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,16,$$byval_copy25,0,732472,338)|0);
    $$pre34 = HEAP32[$26>>2]|0;
    $36 = $$pre34;$46 = $34;
   }
   $35 = ($36|0)==($25|0);
   if ($35) {
    $$ph = $46;
    label = 19;
   } else {
    $38 = $36;$42 = 0;
    while(1) {
     $37 = (($38) + 8|0);
     $39 = HEAP32[$37>>2]|0;
     $40 = (($39) + 12|0);
     $41 = ($42|0)>(0);
     L20: do {
      if ($41) {
       $n$04$i = 0;
       while(1) {
        $45 = (($46) + ($n$04$i<<2)|0);
        $47 = HEAP32[$45>>2]|0;
        $48 = ($47|0)==($40|0);
        $44 = (($n$04$i) + 1)|0;
        if ($48) {
         $55 = $42;
         break L20;
        }
        $43 = ($44|0)<($42|0);
        if ($43) {
         $n$04$i = $44;
        } else {
         label = 17;
         break;
        }
       }
      } else {
       label = 17;
      }
     } while(0);
     if ((label|0) == 17) {
      label = 0;
      $49 = (($42) + 1)|0;
      $50 = (($46) + ($42<<2)|0);
      HEAP32[$50>>2] = $40;
      $55 = $49;
     }
     $51 = (($38) + 4|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==($25|0);
     if ($53) {
      break;
     } else {
      $38 = $52;$42 = $55;
     }
    }
    $54 = ($55|0)>(0);
    if ($54) {
     $n$01$i$i = 0;
     while(1) {
      $56 = (($46) + ($n$01$i$i<<2)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($57) + 12|0);
      $59 = HEAP32[$58>>2]|0;
      __ZN20SoundChannelInstance4StopEv($59);
      $60 = (($n$01$i$i) + 1)|0;
      $exitcond = ($60|0)==($55|0);
      if ($exitcond) {
       $186 = $1;$62 = $46;
       break;
      } else {
       $n$01$i$i = $60;
      }
     }
    } else {
     $186 = $1;$62 = $46;
    }
   }
  }
  if ((label|0) == 19) {
   $186 = $1;$62 = $$ph;
  }
  $61 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $61;
  ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($62,$$byval_copy25);
 }
 $63 = (($this) + 508|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(0|0);
 do {
  if (!($65)) {
   $66 = (__ZN4FMOD3DSP6removeEv($64)|0);
   $67 = ($66|0)==(0);
   if (!($67)) {
    $68 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($66)|0);
    HEAP32[$$byval_copy25>>2] = 731960;
    $vararg_ptr10 = (($$byval_copy25) + 4|0);
    HEAP32[$vararg_ptr10>>2] = 595;
    $vararg_ptr11 = (($$byval_copy25) + 8|0);
    HEAP32[$vararg_ptr11>>2] = 732816;
    $vararg_ptr12 = (($$byval_copy25) + 12|0);
    HEAP32[$vararg_ptr12>>2] = $68;
    __Z6FormatPKcz($0,741616,$$byval_copy25);
    $69 = HEAP8[$0>>0]|0;
    $70 = $69 & 1;
    $71 = ($70<<24>>24)==(0);
    if ($71) {
     $74 = (($0) + 1|0);
     $75 = $74;
    } else {
     $72 = (($0) + 8|0);
     $73 = HEAP32[$72>>2]|0;
     $75 = $73;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($75|0),0,(732472|0),21,1,0,0,(0|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if (!($77)) {
     $78 = HEAP8[$0>>0]|0;
     $79 = $78 & 1;
     $80 = ($79<<24>>24)==(0);
     if ($80) {
      break;
     }
     $81 = (($0) + 8|0);
     $82 = HEAP32[$81>>2]|0;
     __ZdlPv($82);
     break;
    }
    $83 = ___cxa_find_matching_catch()|0;
    $84 = tempRet0;
    $85 = HEAP8[$0>>0]|0;
    $86 = $85 & 1;
    $87 = ($86<<24>>24)==(0);
    if ($87) {
     ___resumeException($83|0);
     // unreachable;
    }
    $88 = (($0) + 8|0);
    $89 = HEAP32[$88>>2]|0;
    __ZdlPv($89);
    ___resumeException($83|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$filter>>2] = 0;
 $90 = HEAP32[$63>>2]|0;
 $91 = ($90|0)==(0|0);
 if (!($91)) {
  $92 = (__ZN4FMOD3DSP11getUserDataEPPv($90,$filter)|0);
  $93 = ($92|0)==(0);
  do {
   if (!($93)) {
    $94 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($92)|0);
    HEAP32[$$byval_copy25>>2] = 731960;
    $vararg_ptr16 = (($$byval_copy25) + 4|0);
    HEAP32[$vararg_ptr16>>2] = 599;
    $vararg_ptr17 = (($$byval_copy25) + 8|0);
    HEAP32[$vararg_ptr17>>2] = 733264;
    $vararg_ptr18 = (($$byval_copy25) + 12|0);
    HEAP32[$vararg_ptr18>>2] = $94;
    __Z6FormatPKcz($2,741616,$$byval_copy25);
    $95 = HEAP8[$2>>0]|0;
    $96 = $95 & 1;
    $97 = ($96<<24>>24)==(0);
    if ($97) {
     $100 = (($2) + 1|0);
     $101 = $100;
    } else {
     $98 = (($2) + 8|0);
     $99 = HEAP32[$98>>2]|0;
     $101 = $99;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($101|0),0,(732472|0),21,1,0,0,(0|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if (!($103)) {
     $104 = HEAP8[$2>>0]|0;
     $105 = $104 & 1;
     $106 = ($105<<24>>24)==(0);
     if ($106) {
      break;
     }
     $107 = (($2) + 8|0);
     $108 = HEAP32[$107>>2]|0;
     __ZdlPv($108);
     break;
    }
    $109 = ___cxa_find_matching_catch()|0;
    $110 = tempRet0;
    $111 = HEAP8[$2>>0]|0;
    $112 = $111 & 1;
    $113 = ($112<<24>>24)==(0);
    if ($113) {
     ___resumeException($109|0);
     // unreachable;
    }
    $114 = (($2) + 8|0);
    $115 = HEAP32[$114>>2]|0;
    __ZdlPv($115);
    ___resumeException($109|0);
    // unreachable;
   }
  } while(0);
  $$pr = HEAP32[$filter>>2]|0;
  $116 = ($$pr|0)==(0|0);
  if (!($116)) {
   $117 = (($$pr) + 16|0);
   HEAP32[$117>>2] = 0;
  }
 }
 HEAP32[$63>>2] = 0;
 $118 = (($this) + 408|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (($this) + 404|0);
 $121 = ($119|0)==($120|0);
 if (!($121)) {
  STACKTOP = sp;return;
 }
 HEAP32[$filters>>2] = 0;
 $122 = (($filters) + 4|0);
 HEAP32[$122>>2] = 0;
 $123 = (($filters) + 8|0);
 HEAP32[$123>>2] = 0;
 __THREW__ = 0;
 $124 = (invoke_iiii(1585,($this|0),($filters|0),0)|0);
 $125 = __THREW__; __THREW__ = 0;
 $126 = $125&1;
 L73: do {
  if ($126) {
   label = 62;
  } else {
   do {
    if ($124) {
     $127 = HEAP32[$filters>>2]|0;
     $128 = HEAP32[$122>>2]|0;
     $129 = ($127|0)==($128|0);
     if (!($129)) {
      $130 = (($2) + 1|0);
      $131 = (($2) + 8|0);
      $133 = $127;
      while(1) {
       $132 = HEAP32[$133>>2]|0;
       __THREW__ = 0;
       $134 = (invoke_ii(3387,($132|0))|0);
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if ($136) {
        label = 61;
        break;
       }
       $137 = ($134|0)==(0);
       if (!($137)) {
        $138 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($134)|0);
        __THREW__ = 0;
        HEAP32[$$byval_copy25>>2] = 731960;
        $vararg_ptr22 = (($$byval_copy25) + 4|0);
        HEAP32[$vararg_ptr22>>2] = 614;
        $vararg_ptr23 = (($$byval_copy25) + 8|0);
        HEAP32[$vararg_ptr23>>2] = 733312;
        $vararg_ptr24 = (($$byval_copy25) + 12|0);
        HEAP32[$vararg_ptr24>>2] = $138;
        invoke_viii(1617,($2|0),(741616|0),($$byval_copy25|0));
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         label = 61;
         break;
        }
        $141 = HEAP8[$2>>0]|0;
        $142 = $141 & 1;
        $143 = ($142<<24>>24)==(0);
        $144 = HEAP32[$131>>2]|0;
        $$ = $143 ? $130 : $144;
        __THREW__ = 0;
        invoke_viiiiiiii(21,($$|0),0,(732472|0),21,1,0,0,(0|0));
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 58;
         break;
        }
        $147 = HEAP8[$2>>0]|0;
        $148 = $147 & 1;
        $149 = ($148<<24>>24)==(0);
        if (!($149)) {
         $150 = HEAP32[$131>>2]|0;
         __ZdlPv($150);
        }
       }
       $157 = (($133) + 4|0);
       $158 = ($157|0)==($128|0);
       if ($158) {
        label = 67;
        break;
       } else {
        $133 = $157;
       }
      }
      if ((label|0) == 58) {
       $151 = ___cxa_find_matching_catch()|0;
       $152 = tempRet0;
       $153 = HEAP8[$2>>0]|0;
       $154 = $153 & 1;
       $155 = ($154<<24>>24)==(0);
       if ($155) {
        $164 = $127;$eh$lpad$body$index4Z2D = $152;$eh$lpad$body$indexZ2D = $151;
        break L73;
       }
       $156 = HEAP32[$131>>2]|0;
       __ZdlPv($156);
       $164 = $127;$eh$lpad$body$index4Z2D = $152;$eh$lpad$body$indexZ2D = $151;
       break L73;
      }
      else if ((label|0) == 61) {
       $159 = ___cxa_find_matching_catch()|0;
       $160 = tempRet0;
       $164 = $127;$eh$lpad$body$index4Z2D = $160;$eh$lpad$body$indexZ2D = $159;
       break L73;
      }
      else if ((label|0) == 67) {
       $170 = ($128|0)==($127|0);
       if ($170) {
        break;
       }
       $__new_last2$i$i$i = $127;
       $scevgep$i$i$i = (($128) + -4|0);
       $171 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($171)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $172 = $uglygep3$i$i$i >>> 2;
       $173 = $172 ^ -1;
       $scevgep4$i$i$i = (($128) + ($173<<2)|0);
       HEAP32[$122>>2] = $scevgep4$i$i$i;
       break;
      }
     }
    }
   } while(0);
   __THREW__ = 0;
   $174 = (invoke_i(118)|0);
   $175 = __THREW__; __THREW__ = 0;
   $176 = $175&1;
   if ($176) {
    label = 62;
   } else {
    __THREW__ = 0;
    invoke_vii(3340,($174|0),($this|0));
    $177 = __THREW__; __THREW__ = 0;
    $178 = $177&1;
    if ($178) {
     label = 62;
    } else {
     $179 = HEAP32[$filters>>2]|0;
     $180 = ($179|0)==(0|0);
     if ($180) {
      STACKTOP = sp;return;
     }
     $181 = HEAP32[$122>>2]|0;
     $182 = ($181|0)==($179|0);
     if (!($182)) {
      $__new_last2$i$i$i$i$i = $179;
      $scevgep$i$i$i$i$i = (($181) + -4|0);
      $183 = (0 - ($__new_last2$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($183)|0);
      $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
      $184 = $uglygep3$i$i$i$i$i >>> 2;
      $185 = $184 ^ -1;
      $scevgep4$i$i$i$i$i = (($181) + ($185<<2)|0);
      HEAP32[$122>>2] = $scevgep4$i$i$i$i$i;
     }
     __ZdlPv($179);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 62) {
  $161 = ___cxa_find_matching_catch()|0;
  $162 = tempRet0;
  $$pre35$pre = HEAP32[$filters>>2]|0;
  $164 = $$pre35$pre;$eh$lpad$body$index4Z2D = $162;$eh$lpad$body$indexZ2D = $161;
 }
 $163 = ($164|0)==(0|0);
 if ($163) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $165 = HEAP32[$122>>2]|0;
 $166 = ($165|0)==($164|0);
 if (!($166)) {
  $__new_last2$i$i$i$i$i2 = $164;
  $scevgep$i$i$i$i$i3 = (($165) + -4|0);
  $167 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($167)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $168 = $uglygep3$i$i$i$i$i6 >>> 2;
  $169 = $168 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($165) + ($169<<2)|0);
  HEAP32[$122>>2] = $scevgep4$i$i$i$i$i7;
 }
 __ZdlPv($164);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN11AudioSource7CleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $i$07 = 0, $vararg_buffer4 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer4 = sp;
 $0 = sp + 16|0;
 __ZN11AudioSource4StopEb($this,1);
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)>(0);
  if ($6) {
   $7 = (($2) + 24|0);
   $i$07 = 0;
   while(1) {
    $8 = HEAP32[$7>>2]|0;
    $9 = ((($8) + ($i$07<<3)|0) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    do {
     if (!($11)) {
      $12 = (($10) + 8|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = $13 >>> 21;
      $15 = HEAP32[560640>>2]|0;
      $16 = Math_imul($15, $14)|0;
      $17 = (($16) + 181)|0;
      $18 = $17 >> 5;
      $19 = $18 << 5;
      $20 = (($17) - ($19))|0;
      $21 = HEAP32[560632>>2]|0;
      $22 = (($21) + ($18<<2)|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = 1 << $20;
      $25 = $24 & $23;
      $26 = ($25|0)==(0);
      if (!($26)) {
       __ZN11AudioFilter7CleanupEv($10);
       break;
      }
      $27 = (($10) + 8|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = $28 >>> 21;
      $30 = HEAP32[560640>>2]|0;
      $31 = Math_imul($30, $29)|0;
      $32 = (($31) + 114)|0;
      $33 = $32 >> 5;
      $34 = $33 << 5;
      $35 = (($32) - ($34))|0;
      $36 = HEAP32[560632>>2]|0;
      $37 = (($36) + ($33<<2)|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = 1 << $35;
      $40 = $39 & $38;
      $41 = ($40|0)==(0);
      if (!($41)) {
       $42 = (($10) + 132|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = ($43|0)==(0|0);
       if (!($44)) {
        __ZN17AudioCustomFilter7CleanupEv($43);
       }
      }
     }
    } while(0);
    $45 = (($i$07) + 1)|0;
    $46 = HEAP32[$4>>2]|0;
    $47 = ($45|0)<($46|0);
    if ($47) {
     $i$07 = $45;
    } else {
     break;
    }
   }
  }
 }
 $48 = (($this) + 472|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = (__ZN4FMOD12ChannelGroup7releaseEv($49)|0);
  $52 = ($51|0)==(0);
  do {
   if (!($52)) {
    $53 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($51)|0);
    HEAP32[$vararg_buffer4>>2] = 731960;
    $vararg_ptr1 = (($vararg_buffer4) + 4|0);
    HEAP32[$vararg_ptr1>>2] = 566;
    $vararg_ptr2 = (($vararg_buffer4) + 8|0);
    HEAP32[$vararg_ptr2>>2] = 733216;
    $vararg_ptr3 = (($vararg_buffer4) + 12|0);
    HEAP32[$vararg_ptr3>>2] = $53;
    __Z6FormatPKcz($0,741616,$vararg_buffer4);
    $54 = HEAP8[$0>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if ($56) {
     $59 = (($0) + 1|0);
     $60 = $59;
    } else {
     $57 = (($0) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     $60 = $58;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,($60|0),0,(732472|0),21,1,0,0,(0|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if (!($62)) {
     $63 = HEAP8[$0>>0]|0;
     $64 = $63 & 1;
     $65 = ($64<<24>>24)==(0);
     if ($65) {
      break;
     }
     $66 = (($0) + 8|0);
     $67 = HEAP32[$66>>2]|0;
     __ZdlPv($67);
     break;
    }
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    $70 = HEAP8[$0>>0]|0;
    $71 = $70 & 1;
    $72 = ($71<<24>>24)==(0);
    if ($72) {
     ___resumeException($68|0);
     // unreachable;
    }
    $73 = (($0) + 8|0);
    $74 = HEAP32[$73>>2]|0;
    __ZdlPv($74);
    ___resumeException($68|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$48>>2] = 0;
 }
 $75 = (($this) + 476|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0|0);
 if ($77) {
  STACKTOP = sp;return;
 }
 $78 = (__ZN4FMOD12ChannelGroup7releaseEv($76)|0);
 $79 = ($78|0)==(0);
 do {
  if (!($79)) {
   $80 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($78)|0);
   HEAP32[$vararg_buffer4>>2] = 731960;
   $vararg_ptr7 = (($vararg_buffer4) + 4|0);
   HEAP32[$vararg_ptr7>>2] = 572;
   $vararg_ptr8 = (($vararg_buffer4) + 8|0);
   HEAP32[$vararg_ptr8>>2] = 733240;
   $vararg_ptr9 = (($vararg_buffer4) + 12|0);
   HEAP32[$vararg_ptr9>>2] = $80;
   __Z6FormatPKcz($0,741616,$vararg_buffer4);
   $81 = HEAP8[$0>>0]|0;
   $82 = $81 & 1;
   $83 = ($82<<24>>24)==(0);
   if ($83) {
    $86 = (($0) + 1|0);
    $87 = $86;
   } else {
    $84 = (($0) + 8|0);
    $85 = HEAP32[$84>>2]|0;
    $87 = $85;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($87|0),0,(732472|0),21,1,0,0,(0|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if (!($89)) {
    $90 = HEAP8[$0>>0]|0;
    $91 = $90 & 1;
    $92 = ($91<<24>>24)==(0);
    if ($92) {
     break;
    }
    $93 = (($0) + 8|0);
    $94 = HEAP32[$93>>2]|0;
    __ZdlPv($94);
    break;
   }
   $95 = ___cxa_find_matching_catch()|0;
   $96 = tempRet0;
   $97 = HEAP8[$0>>0]|0;
   $98 = $97 & 1;
   $99 = ($98<<24>>24)==(0);
   if ($99) {
    ___resumeException($95|0);
    // unreachable;
   }
   $100 = (($0) + 8|0);
   $101 = HEAP32[$100>>2]|0;
   __ZdlPv($101);
   ___resumeException($95|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$75>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11AudioSource4PlayEd($this,$time) {
 $this = $this|0;
 $time = +$time;
 var $$0$i2082 = 0, $$015$i = 0, $$016$i = 0, $$023$i = 0, $$024$i = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy54 = 0, $$in = 0, $$pr = 0, $$pr83 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i42 = 0, $$pre$phiZ2D = 0, $$pre$pre = 0, $$pre86 = 0, $$pre87 = 0;
 var $$pre88 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = Math_fround(0);
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i21 = 0, $__new_last2$i$i$i$i$i30 = 0, $customFilter = 0, $eh$lpad$body$index21Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body53$index9Z2D = 0, $eh$lpad$body53$indexZ2D = 0, $filters = 0, $fmodChannel = 0, $phitmp$i = 0, $samplerate = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i22 = 0, $scevgep$i$i$i$i$i31 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i26 = 0, $scevgep4$i$i$i$i$i35 = 0, $temp$0$i = 0, $temp$0$i1489 = 0;
 var $temp$0$i1991 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i24 = 0, $uglygep$i$i$i$i$i33 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i25 = 0, $uglygep3$i$i$i$i$i34 = 0, $vararg_ptr27 = 0, $vararg_ptr28 = 0, $vararg_ptr29 = 0, $vararg_ptr36 = 0, $vararg_ptr37 = 0, $vararg_ptr38 = 0, $vararg_ptr42 = 0, $vararg_ptr43 = 0, $vararg_ptr44 = 0, $vararg_ptr48 = 0, $vararg_ptr49 = 0, $vararg_ptr50 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $$byval_copy54 = sp;
 $0 = sp + 200|0;
 $1 = sp + 188|0;
 $2 = sp + 176|0;
 $3 = sp + 164|0;
 $4 = sp + 160|0;
 $5 = sp + 144|0;
 $6 = sp + 140|0;
 $7 = sp + 136|0;
 $8 = sp + 132|0;
 $9 = sp + 128|0;
 $10 = sp + 216|0;
 $filters = sp + 36|0;
 $customFilter = sp + 32|0;
 $11 = sp + 16|0;
 $fmodChannel = sp + 28|0;
 $12 = sp + 100|0;
 $samplerate = sp + 48|0;
 $13 = sp + 56|0;
 $14 = sp + 72|0;
 $15 = sp + 88|0;
 $16 = sp + 112|0;
 $17 = (__Z15GetAudioManagerv()|0);
 $18 = (($17) + 204|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 28|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $28 = ($this|0)==(0|0);
  if ($28) {
   $31 = 0;
  } else {
   label = 6;
  }
 } else {
  $24 = (($this) + 24|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   label = 6;
  } else {
   $27 = (__ZNK5Unity10GameObject8IsActiveEv($25)|0);
   if ($27) {
    __ZN11AudioSource11SetupGroupsEv($this);
    $32 = (($this) + 416|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0);
    do {
     if (!($34)) {
      HEAP32[$9>>2] = $33;
      $35 = HEAP32[560624>>2]|0;
      $36 = ($35|0)==(0|0);
      if ($36) {
       label = 17;
      } else {
       $37 = (($35) + 36|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = (($35) + 4|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = ($38|0)==($40|0);
       do {
        if ($41) {
         $42 = (($35) + 28|0);
         $43 = HEAP32[$42>>2]|0;
         $44 = (($35) + 32|0);
         $45 = HEAP32[$44>>2]|0;
         $46 = (($43) + ($45<<3)|0);
         $62 = $46;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy54,$35,$9);
         $47 = HEAP32[$$byval_copy54>>2]|0;
         $48 = ($47|0)==(-1);
         $49 = (($35) + 28|0);
         $50 = HEAP32[$49>>2]|0;
         if ($48) {
          $51 = (($35) + 32|0);
          $52 = HEAP32[$51>>2]|0;
          $53 = (($50) + ($52<<3)|0);
          $62 = $53;
          break;
         } else {
          $54 = (($50) + ($47<<3)|0);
          $62 = $54;
          break;
         }
        }
       } while(0);
       $55 = HEAP32[560624>>2]|0;
       $56 = (($55) + 28|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = (($55) + 32|0);
       $59 = HEAP32[$58>>2]|0;
       $60 = (($57) + ($59<<3)|0);
       $61 = ($62|0)==($60|0);
       if ($61) {
        label = 17;
       } else {
        $63 = (($62) + 4|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = ($64|0)==(0|0);
        if ($65) {
         label = 17;
        } else {
         $70 = $55;
        }
       }
      }
      if ((label|0) == 17) {
       $66 = HEAP32[$32>>2]|0;
       $67 = (__Z31ReadObjectFromPersistentManageri($66)|0);
       $phitmp$i = ($67|0)==(0|0);
       if ($phitmp$i) {
        break;
       }
       $$pre87 = HEAP32[560624>>2]|0;
       $70 = $$pre87;
      }
      $68 = HEAP32[$32>>2]|0;
      HEAP32[$8>>2] = $68;
      $69 = ($70|0)==(0|0);
      if ($69) {
       label = 27;
      } else {
       $71 = (($70) + 36|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = (($70) + 4|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($72|0)==($74|0);
       do {
        if ($75) {
         $76 = (($70) + 28|0);
         $77 = HEAP32[$76>>2]|0;
         $78 = (($70) + 32|0);
         $79 = HEAP32[$78>>2]|0;
         $80 = (($77) + ($79<<3)|0);
         $96 = $80;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy54,$70,$8);
         $81 = HEAP32[$$byval_copy54>>2]|0;
         $82 = ($81|0)==(-1);
         $83 = (($70) + 28|0);
         $84 = HEAP32[$83>>2]|0;
         if ($82) {
          $85 = (($70) + 32|0);
          $86 = HEAP32[$85>>2]|0;
          $87 = (($84) + ($86<<3)|0);
          $96 = $87;
          break;
         } else {
          $88 = (($84) + ($81<<3)|0);
          $96 = $88;
          break;
         }
        }
       } while(0);
       $89 = HEAP32[560624>>2]|0;
       $90 = (($89) + 28|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = (($89) + 32|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = (($91) + ($93<<3)|0);
       $95 = ($96|0)==($94|0);
       if ($95) {
        label = 27;
       } else {
        $97 = (($96) + 4|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = ($98|0)==(0|0);
        if ($99) {
         label = 27;
        } else {
         $temp$0$i = $98;
        }
       }
      }
      if ((label|0) == 27) {
       $100 = HEAP32[$32>>2]|0;
       $101 = (__Z31ReadObjectFromPersistentManageri($100)|0);
       $temp$0$i = $101;
      }
      $102 = (($temp$0$i) + 44|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = ($103|0)==(0);
      if (!($104)) {
       HEAP32[$7>>2] = $103;
       $105 = HEAP32[560624>>2]|0;
       $106 = ($105|0)==(0|0);
       if ($106) {
        label = 37;
       } else {
        $107 = (($105) + 36|0);
        $108 = HEAP32[$107>>2]|0;
        $109 = (($105) + 4|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = ($108|0)==($110|0);
        do {
         if ($111) {
          $112 = (($105) + 28|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = (($105) + 32|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = (($113) + ($115<<3)|0);
          $132 = $116;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy54,$105,$7);
          $117 = HEAP32[$$byval_copy54>>2]|0;
          $118 = ($117|0)==(-1);
          $119 = (($105) + 28|0);
          $120 = HEAP32[$119>>2]|0;
          if ($118) {
           $121 = (($105) + 32|0);
           $122 = HEAP32[$121>>2]|0;
           $123 = (($120) + ($122<<3)|0);
           $132 = $123;
           break;
          } else {
           $124 = (($120) + ($117<<3)|0);
           $132 = $124;
           break;
          }
         }
        } while(0);
        $125 = HEAP32[560624>>2]|0;
        $126 = (($125) + 28|0);
        $127 = HEAP32[$126>>2]|0;
        $128 = (($125) + 32|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = (($127) + ($129<<3)|0);
        $131 = ($132|0)==($130|0);
        if ($131) {
         label = 37;
        } else {
         $133 = (($132) + 4|0);
         $134 = HEAP32[$133>>2]|0;
         $135 = ($134|0)==(0|0);
         if ($135) {
          label = 37;
         } else {
          $temp$0$i1489 = $134;
         }
        }
       }
       if ((label|0) == 37) {
        $136 = (__Z31ReadObjectFromPersistentManageri($103)|0);
        $137 = ($136|0)==(0|0);
        if ($137) {
         break;
        } else {
         $temp$0$i1489 = $136;
        }
       }
       __ZN10AudioMixer16ResumeProcessingEv($temp$0$i1489);
      }
     }
    } while(0);
    $138 = (($this) + 412|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = ($139|0)==(0);
    do {
     if ($140) {
      $$0$i2082 = 0;$618 = 0;
     } else {
      HEAP32[$6>>2] = $139;
      $141 = HEAP32[560624>>2]|0;
      $142 = ($141|0)==(0|0);
      if ($142) {
       label = 49;
      } else {
       $143 = (($141) + 36|0);
       $144 = HEAP32[$143>>2]|0;
       $145 = (($141) + 4|0);
       $146 = HEAP32[$145>>2]|0;
       $147 = ($144|0)==($146|0);
       do {
        if ($147) {
         $148 = (($141) + 28|0);
         $149 = HEAP32[$148>>2]|0;
         $150 = (($141) + 32|0);
         $151 = HEAP32[$150>>2]|0;
         $152 = (($149) + ($151<<3)|0);
         $168 = $152;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy54,$141,$6);
         $153 = HEAP32[$$byval_copy54>>2]|0;
         $154 = ($153|0)==(-1);
         $155 = (($141) + 28|0);
         $156 = HEAP32[$155>>2]|0;
         if ($154) {
          $157 = (($141) + 32|0);
          $158 = HEAP32[$157>>2]|0;
          $159 = (($156) + ($158<<3)|0);
          $168 = $159;
          break;
         } else {
          $160 = (($156) + ($153<<3)|0);
          $168 = $160;
          break;
         }
        }
       } while(0);
       $161 = HEAP32[560624>>2]|0;
       $162 = (($161) + 28|0);
       $163 = HEAP32[$162>>2]|0;
       $164 = (($161) + 32|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = (($163) + ($165<<3)|0);
       $167 = ($168|0)==($166|0);
       if ($167) {
        label = 49;
       } else {
        $169 = (($168) + 4|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = ($170|0)==(0|0);
        if ($171) {
         label = 49;
        } else {
         $$in = $170;$temp$0$i1991 = $170;
        }
       }
      }
      if ((label|0) == 49) {
       $172 = HEAP32[$138>>2]|0;
       $173 = (__Z31ReadObjectFromPersistentManageri($172)|0);
       $174 = ($173|0)==(0|0);
       if ($174) {
        $$0$i2082 = 0;$618 = 0;
        break;
       } else {
        $$in = $173;$temp$0$i1991 = $173;
       }
      }
      $175 = HEAP32[$temp$0$i1991>>2]|0;
      $176 = (($175) + 92|0);
      $177 = HEAP32[$176>>2]|0;
      $178 = (FUNCTION_TABLE_ii[$177 & 4095]($temp$0$i1991)|0);
      $179 = ($178|0)==(0);
      if ($179) {
       (__ZN10SampleClip13LoadAudioDataEv($temp$0$i1991)|0);
       $$0$i2082 = $$in;$618 = 1;
      } else {
       $$0$i2082 = $$in;$618 = 1;
      }
     }
    } while(0);
    $180 = (($this) + 432|0);
    $181 = (($this) + 444|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = ($182|0)==(0|0);
    do {
     if ($183) {
      label = 58;
     } else {
      $184 = (($this) + 472|0);
      $185 = HEAP32[$184>>2]|0;
      (__ZN20SoundChannelInstance15setChannelGroupEPN4FMOD12ChannelGroupE($182,$185)|0);
      $186 = HEAP32[$181>>2]|0;
      $187 = (($186) + 276|0);
      $188 = HEAP8[$187>>0]|0;
      $189 = ($188<<24>>24)==(0);
      if ($189) {
       __ZN11AudioSource4StopEb($this,0);
       $$pr = HEAP32[$181>>2]|0;
       $202 = ($$pr|0)==(0|0);
       if ($202) {
        label = 58;
        break;
       } else {
        $$pre$phiZ2D = $184;$569 = $$pr;
        break;
       }
      }
      __ZN11AudioSource11AssignPropsEv($this);
      $190 = (__Z15GetAudioManagerv()|0);
      $191 = (($190) + 36|0);
      $192 = HEAP8[$191>>0]|0;
      $193 = ($192<<24>>24)==(0);
      if ($193) {
       $200 = 0;
      } else {
       $194 = (($this) + 401|0);
       $195 = HEAP8[$194>>0]|0;
       $196 = ($195<<24>>24)==(0);
       $200 = $196;
      }
      $197 = HEAP32[$181>>2]|0;
      $198 = (($197) + 276|0);
      $199 = $200&1;
      HEAP8[$198>>0] = $199;
      __ZN20SoundChannelInstance16UpdatePauseStateEv($197);
      $201 = (__Z15GetAudioManagerv()|0);
      __ZN12AudioManager14AddAudioSourceEP11AudioSourceb($201,$this,$200);
      STACKTOP = sp;return;
     }
    } while(0);
    do {
     if ((label|0) == 58) {
      L82: do {
       if ($618) {
        __ZN10SampleClip15AllocateChannelEby($10,$$0$i2082,1,0,0);
        $203 = (($10) + 12|0);
        $204 = HEAP32[$203>>2]|0;
        HEAP32[$181>>2] = $204;
        $205 = ($204|0)==(0|0);
        if ($205) {
         $217 = HEAP32[$180>>2]|0;
         $218 = ($217|0)==(0|0);
         if (!($218)) {
          $219 = (($this) + 436|0);
          $220 = HEAP32[$219>>2]|0;
          $221 = (($217) + 4|0);
          HEAP32[$221>>2] = $220;
          $222 = HEAP32[$180>>2]|0;
          $223 = HEAP32[$219>>2]|0;
          HEAP32[$223>>2] = $222;
          HEAP32[$180>>2] = 0;
          HEAP32[$219>>2] = 0;
         }
        } else {
         $206 = (($204) + 208|0);
         $207 = ($180|0)==($206|0);
         if (!($207)) {
          $208 = HEAP32[$180>>2]|0;
          $209 = ($208|0)==(0|0);
          $$pre$i$i$i = (($this) + 436|0);
          if (!($209)) {
           $210 = HEAP32[$$pre$i$i$i>>2]|0;
           $211 = (($208) + 4|0);
           HEAP32[$211>>2] = $210;
           $212 = HEAP32[$180>>2]|0;
           $213 = HEAP32[$$pre$i$i$i>>2]|0;
           HEAP32[$213>>2] = $212;
           HEAP32[$180>>2] = 0;
           HEAP32[$$pre$i$i$i>>2] = 0;
          }
          $214 = HEAP32[$206>>2]|0;
          HEAP32[$180>>2] = $214;
          HEAP32[$$pre$i$i$i>>2] = $206;
          $215 = (($214) + 4|0);
          HEAP32[$215>>2] = $180;
          $216 = HEAP32[$$pre$i$i$i>>2]|0;
          HEAP32[$216>>2] = $180;
         }
        }
        HEAP32[$203>>2] = 0;
        $224 = HEAP32[$10>>2]|0;
        $225 = ($224|0)==(0|0);
        if (!($225)) {
         $226 = (($10) + 4|0);
         $227 = HEAP32[$226>>2]|0;
         $228 = (($224) + 4|0);
         HEAP32[$228>>2] = $227;
         $229 = HEAP32[$10>>2]|0;
         $230 = HEAP32[$226>>2]|0;
         HEAP32[$230>>2] = $229;
         HEAP32[$10>>2] = 0;
         HEAP32[$226>>2] = 0;
        }
        $231 = HEAP32[$181>>2]|0;
        $232 = ($231|0)==(0|0);
        if ($232) {
         STACKTOP = sp;return;
        } else {
         $233 = (($$0$i2082) + 120|0);
         $234 = HEAP32[$233>>2]|0;
         $235 = (($234) + 1)|0;
         HEAP32[$233>>2] = $235;
         $236 = HEAP32[$233>>2]|0;
         $237 = HEAP32[$181>>2]|0;
         $238 = (($237) + 280|0);
         HEAP32[$238>>2] = $this;
         break;
        }
       } else {
        HEAP32[$filters>>2] = 0;
        $239 = (($filters) + 4|0);
        HEAP32[$239>>2] = 0;
        $240 = (($filters) + 8|0);
        HEAP32[$240>>2] = 0;
        __THREW__ = 0;
        $241 = (invoke_iiii(1585,($this|0),($filters|0),1)|0);
        $242 = __THREW__; __THREW__ = 0;
        $243 = $242&1;
        L100: do {
         if ($243) {
          label = 85;
         } else {
          L102: do {
           if ($241) {
            HEAP32[$customFilter>>2] = 0;
            $244 = HEAP32[$filters>>2]|0;
            $245 = HEAP32[$244>>2]|0;
            __THREW__ = 0;
            (invoke_iii(2564,($245|0),($customFilter|0))|0);
            $246 = __THREW__; __THREW__ = 0;
            $247 = $246&1;
            if ($247) {
             label = 85;
             break L100;
            }
            $248 = HEAP32[$customFilter>>2]|0;
            $249 = ($248|0)==(0|0);
            if ($249) {
             $521 = HEAP32[$24>>2]|0;
             $522 = ($521|0)==(0|0);
             if ($522) {
              $529 = 732472;
             } else {
              $523 = HEAP32[$521>>2]|0;
              $524 = (($523) + 32|0);
              $525 = HEAP32[$524>>2]|0;
              __THREW__ = 0;
              $526 = (invoke_ii($525|0,($521|0))|0);
              $527 = __THREW__; __THREW__ = 0;
              $528 = $527&1;
              if ($528) {
               label = 85;
               break L100;
              } else {
               $529 = $526;
              }
             }
             __THREW__ = 0;
             HEAP32[$$byval_copy54>>2] = $529;
             invoke_viii(1617,($15|0),(733112|0),($$byval_copy54|0));
             $530 = __THREW__; __THREW__ = 0;
             $531 = $530&1;
             if ($531) {
              label = 85;
              break L100;
             }
             $532 = HEAP8[$15>>0]|0;
             $533 = $532 & 1;
             $534 = ($533<<24>>24)==(0);
             if ($534) {
              $537 = (($15) + 1|0);
              $538 = $537;
             } else {
              $535 = (($15) + 8|0);
              $536 = HEAP32[$535>>2]|0;
              $538 = $536;
             }
             __THREW__ = 0;
             invoke_viiiiiiii(21,($538|0),0,(732472|0),469,512,0,0,(0|0));
             $539 = __THREW__; __THREW__ = 0;
             $540 = $539&1;
             if ($540) {
              $546 = ___cxa_find_matching_catch()|0;
              $547 = tempRet0;
              $548 = HEAP8[$15>>0]|0;
              $549 = $548 & 1;
              $550 = ($549<<24>>24)==(0);
              if ($550) {
               $$1 = $546;$$12 = $547;$561 = $244;
               break L100;
              }
              $551 = (($15) + 8|0);
              $552 = HEAP32[$551>>2]|0;
              __ZdlPv($552);
              $$1 = $546;$$12 = $547;$561 = $244;
              break L100;
             } else {
              $541 = HEAP8[$15>>0]|0;
              $542 = $541 & 1;
              $543 = ($542<<24>>24)==(0);
              if ($543) {
               $554 = $244;
               break;
              }
              $544 = (($15) + 8|0);
              $545 = HEAP32[$544>>2]|0;
              __ZdlPv($545);
              $554 = $244;
              break;
             }
            }
            $250 = (($248) + 20|0);
            $251 = HEAP32[$250>>2]|0;
            $252 = ($251|0)==(0|0);
            if (!($252)) {
             __THREW__ = 0;
             invoke_viii(1617,($11|0),(732480|0),($$byval_copy54|0));
             $253 = __THREW__; __THREW__ = 0;
             $254 = $253&1;
             if ($254) {
              label = 85;
              break L100;
             }
             $255 = ($this|0)==(0|0);
             if ($255) {
              $265 = 0;
             } else {
              $256 = (($this) + 4|0);
              $257 = HEAP32[$256>>2]|0;
              $265 = $257;
             }
             $258 = HEAP8[$11>>0]|0;
             $259 = $258 & 1;
             $260 = ($259<<24>>24)==(0);
             if ($260) {
              $263 = (($11) + 1|0);
              $264 = $263;
             } else {
              $261 = (($11) + 8|0);
              $262 = HEAP32[$261>>2]|0;
              $264 = $262;
             }
             __THREW__ = 0;
             invoke_viiiiiiii(21,($264|0),0,(732472|0),439,512,($265|0),0,(0|0));
             $266 = __THREW__; __THREW__ = 0;
             $267 = $266&1;
             if ($267) {
              $275 = ___cxa_find_matching_catch()|0;
              $276 = tempRet0;
              $277 = HEAP8[$11>>0]|0;
              $278 = $277 & 1;
              $279 = ($278<<24>>24)==(0);
              if ($279) {
               $$1 = $275;$$12 = $276;$561 = $244;
               break L100;
              }
              $280 = (($11) + 8|0);
              $281 = HEAP32[$280>>2]|0;
              __ZdlPv($281);
              $$1 = $275;$$12 = $276;$561 = $244;
              break L100;
             }
             $268 = HEAP8[$11>>0]|0;
             $269 = $268 & 1;
             $270 = ($269<<24>>24)==(0);
             if (!($270)) {
              $271 = (($11) + 8|0);
              $272 = HEAP32[$271>>2]|0;
              __ZdlPv($272);
             }
             $610 = ($244|0)==(0|0);
             if ($610) {
              STACKTOP = sp;return;
             }
             $611 = HEAP32[$239>>2]|0;
             $612 = ($611|0)==($244|0);
             if (!($612)) {
              $__new_last2$i$i$i$i$i = $244;
              $scevgep$i$i$i$i$i = (($611) + -4|0);
              $613 = (0 - ($__new_last2$i$i$i$i$i))|0;
              $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($613)|0);
              $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
              $614 = $uglygep3$i$i$i$i$i >>> 2;
              $615 = $614 ^ -1;
              $scevgep4$i$i$i$i$i = (($611) + ($615<<2)|0);
              HEAP32[$239>>2] = $scevgep4$i$i$i$i$i;
             }
             __ZdlPv($244);
             STACKTOP = sp;return;
            }
            $282 = (($248) + 16|0);
            HEAP32[$282>>2] = $this;
            $283 = HEAP32[$244>>2]|0;
            $284 = (($this) + 508|0);
            HEAP32[$284>>2] = $283;
            __THREW__ = 0;
            $285 = (invoke_ii(3387,($283|0))|0);
            $286 = __THREW__; __THREW__ = 0;
            $287 = $286&1;
            if ($287) {
             label = 85;
             break L100;
            }
            $288 = ($285|0)==(0);
            do {
             if (!($288)) {
              $289 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($285)|0);
              __THREW__ = 0;
              HEAP32[$$byval_copy54>>2] = 731960;
              $vararg_ptr27 = (($$byval_copy54) + 4|0);
              HEAP32[$vararg_ptr27>>2] = 444;
              $vararg_ptr28 = (($$byval_copy54) + 8|0);
              HEAP32[$vararg_ptr28>>2] = 732816;
              $vararg_ptr29 = (($$byval_copy54) + 12|0);
              HEAP32[$vararg_ptr29>>2] = $289;
              invoke_viii(1617,($2|0),(741616|0),($$byval_copy54|0));
              $290 = __THREW__; __THREW__ = 0;
              $291 = $290&1;
              if ($291) {
               label = 85;
               break L100;
              }
              $292 = HEAP8[$2>>0]|0;
              $293 = $292 & 1;
              $294 = ($293<<24>>24)==(0);
              if ($294) {
               $297 = (($2) + 1|0);
               $298 = $297;
              } else {
               $295 = (($2) + 8|0);
               $296 = HEAP32[$295>>2]|0;
               $298 = $296;
              }
              __THREW__ = 0;
              invoke_viiiiiiii(21,($298|0),0,(732472|0),21,1,0,0,(0|0));
              $299 = __THREW__; __THREW__ = 0;
              $300 = $299&1;
              if ($300) {
               $306 = ___cxa_find_matching_catch()|0;
               $307 = tempRet0;
               $308 = HEAP8[$2>>0]|0;
               $309 = $308 & 1;
               $310 = ($309<<24>>24)==(0);
               if ($310) {
                $$pre = $244;$eh$lpad$body53$index9Z2D = $307;$eh$lpad$body53$indexZ2D = $306;
                label = 86;
                break L100;
               }
               $311 = (($2) + 8|0);
               $312 = HEAP32[$311>>2]|0;
               __ZdlPv($312);
               $$pre = $244;$eh$lpad$body53$index9Z2D = $307;$eh$lpad$body53$indexZ2D = $306;
               label = 86;
               break L100;
              } else {
               $301 = HEAP8[$2>>0]|0;
               $302 = $301 & 1;
               $303 = ($302<<24>>24)==(0);
               if ($303) {
                break;
               }
               $304 = (($2) + 8|0);
               $305 = HEAP32[$304>>2]|0;
               __ZdlPv($305);
               break;
              }
             }
            } while(0);
            __THREW__ = 0;
            $313 = (invoke_i(118)|0);
            $314 = __THREW__; __THREW__ = 0;
            $315 = $314&1;
            if ($315) {
             label = 85;
             break L100;
            }
            $316 = (($313) + 92|0);
            $317 = HEAP32[$316>>2]|0;
            $318 = HEAP32[$244>>2]|0;
            __THREW__ = 0;
            $319 = (invoke_iiiiii(214,($317|0),-1,($318|0),1,($fmodChannel|0))|0);
            $320 = __THREW__; __THREW__ = 0;
            $321 = $320&1;
            if ($321) {
             label = 85;
             break L100;
            }
            if ((($319|0) == 10)) {
             $322 = ($this|0)==(0|0);
             if ($322) {
              $325 = 0;
             } else {
              $323 = (($this) + 4|0);
              $324 = HEAP32[$323>>2]|0;
              $325 = $324;
             }
             __THREW__ = 0;
             invoke_viiiiiiii(21,(732840|0),0,(732472|0),448,512,($325|0),0,(0|0));
             $326 = __THREW__; __THREW__ = 0;
             $327 = $326&1;
             if ($327) {
              label = 85;
              break L100;
             } else {
              $554 = $244;
              break;
             }
            } else if ((($319|0) == 0)) {
             $356 = HEAP32[$fmodChannel>>2]|0;
             __THREW__ = 0;
             $357 = (invoke_iii(2574,($356|0),82)|0);
             $358 = __THREW__; __THREW__ = 0;
             $359 = $358&1;
             if ($359) {
              label = 85;
              break L100;
             }
             $360 = ($357|0)==(0);
             do {
              if (!($360)) {
               $361 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($357)|0);
               __THREW__ = 0;
               HEAP32[$$byval_copy54>>2] = 731960;
               $vararg_ptr36 = (($$byval_copy54) + 4|0);
               HEAP32[$vararg_ptr36>>2] = 454;
               $vararg_ptr37 = (($$byval_copy54) + 8|0);
               HEAP32[$vararg_ptr37>>2] = 732944;
               $vararg_ptr38 = (($$byval_copy54) + 12|0);
               HEAP32[$vararg_ptr38>>2] = $361;
               invoke_viii(1617,($1|0),(741616|0),($$byval_copy54|0));
               $362 = __THREW__; __THREW__ = 0;
               $363 = $362&1;
               if ($363) {
                label = 85;
                break L100;
               }
               $364 = HEAP8[$1>>0]|0;
               $365 = $364 & 1;
               $366 = ($365<<24>>24)==(0);
               if ($366) {
                $369 = (($1) + 1|0);
                $370 = $369;
               } else {
                $367 = (($1) + 8|0);
                $368 = HEAP32[$367>>2]|0;
                $370 = $368;
               }
               __THREW__ = 0;
               invoke_viiiiiiii(21,($370|0),0,(732472|0),21,1,0,0,(0|0));
               $371 = __THREW__; __THREW__ = 0;
               $372 = $371&1;
               if ($372) {
                $378 = ___cxa_find_matching_catch()|0;
                $379 = tempRet0;
                $380 = HEAP8[$1>>0]|0;
                $381 = $380 & 1;
                $382 = ($381<<24>>24)==(0);
                if ($382) {
                 $$pre = $244;$eh$lpad$body53$index9Z2D = $379;$eh$lpad$body53$indexZ2D = $378;
                 label = 86;
                 break L100;
                }
                $383 = (($1) + 8|0);
                $384 = HEAP32[$383>>2]|0;
                __ZdlPv($384);
                $$pre = $244;$eh$lpad$body53$index9Z2D = $379;$eh$lpad$body53$indexZ2D = $378;
                label = 86;
                break L100;
               } else {
                $373 = HEAP8[$1>>0]|0;
                $374 = $373 & 1;
                $375 = ($374<<24>>24)==(0);
                if ($375) {
                 break;
                }
                $376 = (($1) + 8|0);
                $377 = HEAP32[$376>>2]|0;
                __ZdlPv($377);
                break;
               }
              }
             } while(0);
             __THREW__ = 0;
             $385 = (invoke_i(118)|0);
             $386 = __THREW__; __THREW__ = 0;
             $387 = $386&1;
             if ($387) {
              label = 85;
              break L100;
             }
             $388 = (($385) + 92|0);
             $389 = HEAP32[$388>>2]|0;
             __THREW__ = 0;
             $390 = (invoke_iiiiiiii(114,($389|0),($samplerate|0),(0|0),(0|0),(0|0),(0|0),(0|0))|0);
             $391 = __THREW__; __THREW__ = 0;
             $392 = $391&1;
             if ($392) {
              label = 85;
              break L100;
             }
             $393 = ($390|0)==(0);
             do {
              if (!($393)) {
               $394 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($390)|0);
               __THREW__ = 0;
               HEAP32[$$byval_copy54>>2] = 731960;
               $vararg_ptr42 = (($$byval_copy54) + 4|0);
               HEAP32[$vararg_ptr42>>2] = 457;
               $vararg_ptr43 = (($$byval_copy54) + 8|0);
               HEAP32[$vararg_ptr43>>2] = 732976;
               $vararg_ptr44 = (($$byval_copy54) + 12|0);
               HEAP32[$vararg_ptr44>>2] = $394;
               invoke_viii(1617,($0|0),(741616|0),($$byval_copy54|0));
               $395 = __THREW__; __THREW__ = 0;
               $396 = $395&1;
               if ($396) {
                label = 85;
                break L100;
               }
               $397 = HEAP8[$0>>0]|0;
               $398 = $397 & 1;
               $399 = ($398<<24>>24)==(0);
               if ($399) {
                $402 = (($0) + 1|0);
                $403 = $402;
               } else {
                $400 = (($0) + 8|0);
                $401 = HEAP32[$400>>2]|0;
                $403 = $401;
               }
               __THREW__ = 0;
               invoke_viiiiiiii(21,($403|0),0,(732472|0),21,1,0,0,(0|0));
               $404 = __THREW__; __THREW__ = 0;
               $405 = $404&1;
               if ($405) {
                $411 = ___cxa_find_matching_catch()|0;
                $412 = tempRet0;
                $413 = HEAP8[$0>>0]|0;
                $414 = $413 & 1;
                $415 = ($414<<24>>24)==(0);
                if ($415) {
                 $$pre = $244;$eh$lpad$body53$index9Z2D = $412;$eh$lpad$body53$indexZ2D = $411;
                 label = 86;
                 break L100;
                }
                $416 = (($0) + 8|0);
                $417 = HEAP32[$416>>2]|0;
                __ZdlPv($417);
                $$pre = $244;$eh$lpad$body53$index9Z2D = $412;$eh$lpad$body53$indexZ2D = $411;
                label = 86;
                break L100;
               } else {
                $406 = HEAP8[$0>>0]|0;
                $407 = $406 & 1;
                $408 = ($407<<24>>24)==(0);
                if ($408) {
                 break;
                }
                $409 = (($0) + 8|0);
                $410 = HEAP32[$409>>2]|0;
                __ZdlPv($410);
                break;
               }
              }
             } while(0);
             $418 = HEAP32[$fmodChannel>>2]|0;
             $419 = HEAP32[$samplerate>>2]|0;
             $420 = (Math_fround(($419|0)));
             __THREW__ = 0;
             $421 = (invoke_iif(29,($418|0),(+$420))|0);
             $422 = __THREW__; __THREW__ = 0;
             $423 = $422&1;
             if ($423) {
              label = 85;
              break L100;
             }
             $424 = ($421|0)==(0);
             do {
              if (!($424)) {
               $425 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($421)|0);
               __THREW__ = 0;
               HEAP32[$$byval_copy54>>2] = 731960;
               $vararg_ptr48 = (($$byval_copy54) + 4|0);
               HEAP32[$vararg_ptr48>>2] = 458;
               $vararg_ptr49 = (($$byval_copy54) + 8|0);
               HEAP32[$vararg_ptr49>>2] = 733072;
               $vararg_ptr50 = (($$byval_copy54) + 12|0);
               HEAP32[$vararg_ptr50>>2] = $425;
               invoke_viii(1617,($3|0),(741616|0),($$byval_copy54|0));
               $426 = __THREW__; __THREW__ = 0;
               $427 = $426&1;
               if ($427) {
                label = 85;
                break L100;
               }
               $428 = HEAP8[$3>>0]|0;
               $429 = $428 & 1;
               $430 = ($429<<24>>24)==(0);
               if ($430) {
                $433 = (($3) + 1|0);
                $434 = $433;
               } else {
                $431 = (($3) + 8|0);
                $432 = HEAP32[$431>>2]|0;
                $434 = $432;
               }
               __THREW__ = 0;
               invoke_viiiiiiii(21,($434|0),0,(732472|0),21,1,0,0,(0|0));
               $435 = __THREW__; __THREW__ = 0;
               $436 = $435&1;
               if ($436) {
                $442 = ___cxa_find_matching_catch()|0;
                $443 = tempRet0;
                $444 = HEAP8[$3>>0]|0;
                $445 = $444 & 1;
                $446 = ($445<<24>>24)==(0);
                if ($446) {
                 $$pre = $244;$eh$lpad$body53$index9Z2D = $443;$eh$lpad$body53$indexZ2D = $442;
                 label = 86;
                 break L100;
                }
                $447 = (($3) + 8|0);
                $448 = HEAP32[$447>>2]|0;
                __ZdlPv($448);
                $$pre = $244;$eh$lpad$body53$index9Z2D = $443;$eh$lpad$body53$indexZ2D = $442;
                label = 86;
                break L100;
               } else {
                $437 = HEAP8[$3>>0]|0;
                $438 = $437 & 1;
                $439 = ($438<<24>>24)==(0);
                if ($439) {
                 break;
                }
                $440 = (($3) + 8|0);
                $441 = HEAP32[$440>>2]|0;
                __ZdlPv($441);
                break;
               }
              }
             } while(0);
             __THREW__ = 0;
             invoke_vi(3643,($14|0));
             $449 = __THREW__; __THREW__ = 0;
             $450 = $449&1;
             if ($450) {
              label = 85;
              break L100;
             }
             $451 = HEAP32[628304>>2]|0;
             HEAP32[$4>>2] = $451;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy54+0>>2]=HEAP32[$4+0>>2]|0;
             $452 = (invoke_iiiiiii(103,288,($$byval_copy54|0),0,16,(732472|0),306)|0);
             $453 = __THREW__; __THREW__ = 0;
             $454 = $453&1;
             if ($454) {
              $517 = ___cxa_find_matching_catch()|0;
              $518 = tempRet0;
              $eh$lpad$body$index21Z2D = $518;$eh$lpad$body$indexZ2D = $517;
             } else {
              __THREW__ = 0;
              invoke_vii(3341,($5|0),($14|0));
              $455 = __THREW__; __THREW__ = 0;
              $456 = $455&1;
              do {
               if ($456) {
                $457 = ___cxa_find_matching_catch()|0;
                $458 = tempRet0;
                $$016$i = $458;$$024$i = $457;
                label = 162;
               } else {
                __THREW__ = 0;
                invoke_viii(1987,($452|0),($5|0),1);
                $459 = __THREW__; __THREW__ = 0;
                $460 = $459&1;
                if ($460) {
                 $472 = ___cxa_find_matching_catch()|0;
                 $473 = tempRet0;
                 __THREW__ = 0;
                 invoke_vi(3642,($5|0));
                 $474 = __THREW__; __THREW__ = 0;
                 $475 = $474&1;
                 if (!($475)) {
                  $$016$i = $473;$$024$i = $472;
                  label = 162;
                  break;
                 }
                 $480 = ___cxa_find_matching_catch(0|0)|0;
                 $481 = tempRet0;
                 ___clang_call_terminate($480);
                 // unreachable;
                }
                HEAP32[$13>>2] = 0;
                $461 = (($13) + 4|0);
                HEAP32[$461>>2] = 0;
                $462 = (($13) + 8|0);
                HEAP32[$462>>2] = $13;
                $463 = (($13) + 12|0);
                HEAP32[$463>>2] = $452;
                $464 = ($452|0)==(0|0);
                do {
                 if (!($464)) {
                  $465 = (($452) + 208|0);
                  $466 = ($13|0)==($465|0);
                  if ($466) {
                   break;
                  }
                  $467 = HEAP32[$465>>2]|0;
                  HEAP32[$13>>2] = $467;
                  HEAP32[$461>>2] = $465;
                  $468 = (($467) + 4|0);
                  HEAP32[$468>>2] = $13;
                  $469 = HEAP32[$461>>2]|0;
                  HEAP32[$469>>2] = $13;
                 }
                } while(0);
                __THREW__ = 0;
                invoke_vi(3642,($5|0));
                $470 = __THREW__; __THREW__ = 0;
                $471 = $470&1;
                if ($471) {
                 $476 = ___cxa_find_matching_catch()|0;
                 $477 = tempRet0;
                 $$015$i = $477;$$023$i = $476;
                 break;
                }
                $482 = HEAP32[$463>>2]|0;
                HEAP32[$181>>2] = $482;
                $483 = ($482|0)==(0|0);
                do {
                 if ($483) {
                  $495 = HEAP32[$180>>2]|0;
                  $496 = ($495|0)==(0|0);
                  if ($496) {
                   break;
                  }
                  $497 = (($this) + 436|0);
                  $498 = HEAP32[$497>>2]|0;
                  $499 = (($495) + 4|0);
                  HEAP32[$499>>2] = $498;
                  $500 = HEAP32[$180>>2]|0;
                  $501 = HEAP32[$497>>2]|0;
                  HEAP32[$501>>2] = $500;
                  HEAP32[$180>>2] = 0;
                  HEAP32[$497>>2] = 0;
                 } else {
                  $484 = (($482) + 208|0);
                  $485 = ($180|0)==($484|0);
                  if ($485) {
                   break;
                  }
                  $486 = HEAP32[$180>>2]|0;
                  $487 = ($486|0)==(0|0);
                  $$pre$i$i$i42 = (($this) + 436|0);
                  if (!($487)) {
                   $488 = HEAP32[$$pre$i$i$i42>>2]|0;
                   $489 = (($486) + 4|0);
                   HEAP32[$489>>2] = $488;
                   $490 = HEAP32[$180>>2]|0;
                   $491 = HEAP32[$$pre$i$i$i42>>2]|0;
                   HEAP32[$491>>2] = $490;
                   HEAP32[$180>>2] = 0;
                   HEAP32[$$pre$i$i$i42>>2] = 0;
                  }
                  $492 = HEAP32[$484>>2]|0;
                  HEAP32[$180>>2] = $492;
                  HEAP32[$$pre$i$i$i42>>2] = $484;
                  $493 = (($492) + 4|0);
                  HEAP32[$493>>2] = $180;
                  $494 = HEAP32[$$pre$i$i$i42>>2]|0;
                  HEAP32[$494>>2] = $180;
                 }
                } while(0);
                HEAP32[$463>>2] = 0;
                $502 = HEAP32[$13>>2]|0;
                $503 = ($502|0)==(0|0);
                if (!($503)) {
                 $504 = HEAP32[$461>>2]|0;
                 $505 = (($502) + 4|0);
                 HEAP32[$505>>2] = $504;
                 $506 = HEAP32[$13>>2]|0;
                 $507 = HEAP32[$461>>2]|0;
                 HEAP32[$507>>2] = $506;
                 HEAP32[$13>>2] = 0;
                 HEAP32[$461>>2] = 0;
                }
                __THREW__ = 0;
                invoke_vi(3642,($14|0));
                $508 = __THREW__; __THREW__ = 0;
                $509 = $508&1;
                if ($509) {
                 label = 85;
                 break L100;
                }
                $510 = HEAP32[$181>>2]|0;
                $511 = ($510|0)==(0|0);
                if ($511) {
                 $554 = $244;
                 break L102;
                }
                $512 = HEAP32[$fmodChannel>>2]|0;
                __THREW__ = 0;
                invoke_vii(3342,($510|0),($512|0));
                $513 = __THREW__; __THREW__ = 0;
                $514 = $513&1;
                if ($514) {
                 label = 85;
                 break L100;
                }
                $515 = HEAP32[$181>>2]|0;
                $516 = (($515) + 280|0);
                HEAP32[$516>>2] = $this;
                $554 = $244;
                break L102;
               }
              } while(0);
              do {
               if ((label|0) == 162) {
                __THREW__ = 0;
                ;HEAP32[$$byval_copy54+0>>2]=HEAP32[$4+0>>2]|0;
                invoke_viiiiii(97,($452|0),($$byval_copy54|0),0,16,(732472|0),306);
                $478 = __THREW__; __THREW__ = 0;
                $479 = $478&1;
                if (!($479)) {
                 $$015$i = $$016$i;$$023$i = $$024$i;
                 break;
                }
                $480 = ___cxa_find_matching_catch(0|0)|0;
                $481 = tempRet0;
                ___clang_call_terminate($480);
                // unreachable;
               }
              } while(0);
              $eh$lpad$body$index21Z2D = $$015$i;$eh$lpad$body$indexZ2D = $$023$i;
             }
             __THREW__ = 0;
             invoke_vi(3642,($14|0));
             $519 = __THREW__; __THREW__ = 0;
             $520 = $519&1;
             if (!($520)) {
              $$1 = $eh$lpad$body$indexZ2D;$$12 = $eh$lpad$body$index21Z2D;$561 = $244;
              break L100;
             }
             $616 = ___cxa_find_matching_catch(0|0)|0;
             $617 = tempRet0;
             ___clang_call_terminate($616);
             // unreachable;
            } else {
             $328 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($319)|0);
             __THREW__ = 0;
             HEAP32[$$byval_copy54>>2] = $328;
             invoke_viii(1617,($12|0),(732896|0),($$byval_copy54|0));
             $329 = __THREW__; __THREW__ = 0;
             $330 = $329&1;
             if ($330) {
              label = 85;
              break L100;
             }
             $331 = ($this|0)==(0|0);
             if ($331) {
              $341 = 0;
             } else {
              $332 = (($this) + 4|0);
              $333 = HEAP32[$332>>2]|0;
              $341 = $333;
             }
             $334 = HEAP8[$12>>0]|0;
             $335 = $334 & 1;
             $336 = ($335<<24>>24)==(0);
             if ($336) {
              $339 = (($12) + 1|0);
              $340 = $339;
             } else {
              $337 = (($12) + 8|0);
              $338 = HEAP32[$337>>2]|0;
              $340 = $338;
             }
             __THREW__ = 0;
             invoke_viiiiiiii(21,($340|0),0,(732472|0),450,1,($341|0),0,(0|0));
             $342 = __THREW__; __THREW__ = 0;
             $343 = $342&1;
             if ($343) {
              $349 = ___cxa_find_matching_catch()|0;
              $350 = tempRet0;
              $351 = HEAP8[$12>>0]|0;
              $352 = $351 & 1;
              $353 = ($352<<24>>24)==(0);
              if ($353) {
               $$1 = $349;$$12 = $350;$561 = $244;
               break L100;
              }
              $354 = (($12) + 8|0);
              $355 = HEAP32[$354>>2]|0;
              __ZdlPv($355);
              $$1 = $349;$$12 = $350;$561 = $244;
              break L100;
             } else {
              $344 = HEAP8[$12>>0]|0;
              $345 = $344 & 1;
              $346 = ($345<<24>>24)==(0);
              if ($346) {
               $554 = $244;
               break;
              }
              $347 = (($12) + 8|0);
              $348 = HEAP32[$347>>2]|0;
              __ZdlPv($348);
              $554 = $244;
              break;
             }
            }
           } else {
            $$pre86 = HEAP32[$filters>>2]|0;
            $554 = $$pre86;
           }
          } while(0);
          $553 = ($554|0)==(0|0);
          if ($553) {
           break L82;
          }
          $555 = HEAP32[$239>>2]|0;
          $556 = ($555|0)==($554|0);
          if (!($556)) {
           $__new_last2$i$i$i$i$i30 = $554;
           $scevgep$i$i$i$i$i31 = (($555) + -4|0);
           $557 = (0 - ($__new_last2$i$i$i$i$i30))|0;
           $uglygep$i$i$i$i$i33 = (($scevgep$i$i$i$i$i31) + ($557)|0);
           $uglygep3$i$i$i$i$i34 = $uglygep$i$i$i$i$i33;
           $558 = $uglygep3$i$i$i$i$i34 >>> 2;
           $559 = $558 ^ -1;
           $scevgep4$i$i$i$i$i35 = (($555) + ($559<<2)|0);
           HEAP32[$239>>2] = $scevgep4$i$i$i$i$i35;
          }
          __ZdlPv($554);
          break L82;
         }
        } while(0);
        if ((label|0) == 85) {
         $273 = ___cxa_find_matching_catch()|0;
         $274 = tempRet0;
         $$pre$pre = HEAP32[$filters>>2]|0;
         $$pre = $$pre$pre;$eh$lpad$body53$index9Z2D = $274;$eh$lpad$body53$indexZ2D = $273;
         label = 86;
        }
        if ((label|0) == 86) {
         $$1 = $eh$lpad$body53$indexZ2D;$$12 = $eh$lpad$body53$index9Z2D;$561 = $$pre;
        }
        $560 = ($561|0)==(0|0);
        if ($560) {
         $$2 = $$1;$$23 = $$12;
         ___resumeException($$2|0);
         // unreachable;
        }
        $562 = HEAP32[$239>>2]|0;
        $563 = ($562|0)==($561|0);
        if (!($563)) {
         $__new_last2$i$i$i$i$i21 = $561;
         $scevgep$i$i$i$i$i22 = (($562) + -4|0);
         $564 = (0 - ($__new_last2$i$i$i$i$i21))|0;
         $uglygep$i$i$i$i$i24 = (($scevgep$i$i$i$i$i22) + ($564)|0);
         $uglygep3$i$i$i$i$i25 = $uglygep$i$i$i$i$i24;
         $565 = $uglygep3$i$i$i$i$i25 >>> 2;
         $566 = $565 ^ -1;
         $scevgep4$i$i$i$i$i26 = (($562) + ($566<<2)|0);
         HEAP32[$239>>2] = $scevgep4$i$i$i$i$i26;
        }
        __ZdlPv($561);
        $$2 = $$1;$$23 = $$12;
        ___resumeException($$2|0);
        // unreachable;
       }
      } while(0);
      $$pr83 = HEAP32[$181>>2]|0;
      $567 = ($$pr83|0)==(0|0);
      if ($567) {
       STACKTOP = sp;return;
      } else {
       $$pre88 = (($this) + 472|0);
       $$pre$phiZ2D = $$pre88;$569 = $$pr83;
       break;
      }
     }
    } while(0);
    $568 = HEAP32[$$pre$phiZ2D>>2]|0;
    (__ZN20SoundChannelInstance15setChannelGroupEPN4FMOD12ChannelGroupE($569,$568)|0);
    __ZN11AudioSource12ApplyFiltersEv($this);
    __ZN11AudioSource11AssignPropsEv($this);
    HEAP32[$16>>2] = 0;
    $570 = (($16) + 4|0);
    HEAP32[$570>>2] = 0;
    $571 = (($16) + 8|0);
    HEAP32[$571>>2] = $16;
    $572 = (($16) + 12|0);
    $573 = HEAP32[$181>>2]|0;
    HEAP32[$572>>2] = $573;
    $574 = ($573|0)==(0|0);
    if (!($574)) {
     $575 = (($573) + 208|0);
     $576 = ($16|0)==($575|0);
     if (!($576)) {
      $577 = HEAP32[$575>>2]|0;
      HEAP32[$16>>2] = $577;
      HEAP32[$570>>2] = $575;
      $578 = (($577) + 4|0);
      HEAP32[$578>>2] = $16;
      $579 = HEAP32[$570>>2]|0;
      HEAP32[$579>>2] = $16;
     }
    }
    __THREW__ = 0;
    (invoke_iii(2575,($this|0),($16|0))|0);
    $580 = __THREW__; __THREW__ = 0;
    $581 = $580&1;
    if ($581) {
     $602 = ___cxa_find_matching_catch()|0;
     $603 = tempRet0;
     HEAP32[$572>>2] = 0;
     $604 = HEAP32[$16>>2]|0;
     $605 = ($604|0)==(0|0);
     if ($605) {
      $$2 = $602;$$23 = $603;
      ___resumeException($$2|0);
      // unreachable;
     }
     $606 = HEAP32[$570>>2]|0;
     $607 = (($604) + 4|0);
     HEAP32[$607>>2] = $606;
     $608 = HEAP32[$16>>2]|0;
     $609 = HEAP32[$570>>2]|0;
     HEAP32[$609>>2] = $608;
     HEAP32[$16>>2] = 0;
     HEAP32[$570>>2] = 0;
     $$2 = $602;$$23 = $603;
     ___resumeException($$2|0);
     // unreachable;
    }
    HEAP32[$572>>2] = 0;
    $582 = HEAP32[$16>>2]|0;
    $583 = ($582|0)==(0|0);
    if (!($583)) {
     $584 = HEAP32[$570>>2]|0;
     $585 = (($582) + 4|0);
     HEAP32[$585>>2] = $584;
     $586 = HEAP32[$16>>2]|0;
     $587 = HEAP32[$570>>2]|0;
     HEAP32[$587>>2] = $586;
     HEAP32[$16>>2] = 0;
     HEAP32[$570>>2] = 0;
    }
    $588 = HEAP32[$181>>2]|0;
    $589 = (($this) + 500|0);
    $590 = HEAP32[$589>>2]|0;
    (__ZN20SoundChannelInstance14SetPositionPCMEj($588,$590)|0);
    $591 = (__Z15GetAudioManagerv()|0);
    __ZN12AudioManager14ScheduleSourceEP11AudioSourced($591,$this,$time);
    $592 = (($this) + 504|0);
    HEAP8[$592>>0] = 0;
    $593 = (__Z15GetAudioManagerv()|0);
    $594 = (($593) + 36|0);
    $595 = HEAP8[$594>>0]|0;
    $596 = ($595<<24>>24)==(0);
    if ($596) {
     $601 = 0;
    } else {
     $597 = (($this) + 401|0);
     $598 = HEAP8[$597>>0]|0;
     $599 = ($598<<24>>24)==(0);
     $601 = $599;
    }
    $600 = (__Z15GetAudioManagerv()|0);
    __ZN12AudioManager14AddAudioSourceEP11AudioSourceb($600,$this,$601);
    STACKTOP = sp;return;
   } else {
    label = 6;
   }
  }
 }
 if ((label|0) == 6) {
  $29 = (($this) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = $30;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(732432,0,732472,378,512,$31,0,0);
 STACKTOP = sp;return;
}
function __ZNK11AudioSource19GetFilterComponentsERNSt3__16vectorIPN4FMOD3DSPENS0_9allocatorIS4_EEEEb($this,$filters,$create) {
 $this = $this|0;
 $filters = $filters|0;
 $create = $create|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $$pre$phi9Z2D = 0, $$pre$phiZ2D = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($1) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 L4: do {
  if ($5) {
   $6 = (($1) + 24|0);
   $7 = (($filters) + 4|0);
   $8 = (($filters) + 8|0);
   $i$04 = 0;
   L7: while(1) {
    $9 = HEAP32[$6>>2]|0;
    $10 = ((($9) + ($i$04<<3)|0) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 9;
    } else {
     $13 = (($11) + 8|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = $14 >>> 21;
     $16 = HEAP32[560640>>2]|0;
     $17 = Math_imul($16, $15)|0;
     $18 = (($17) + 181)|0;
     $19 = $18 >> 5;
     $20 = $19 << 5;
     $21 = (($18) - ($20))|0;
     $22 = HEAP32[560632>>2]|0;
     $23 = (($22) + ($19<<2)|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = 1 << $21;
     $26 = $25 & $24;
     $27 = ($26|0)==(0);
     if ($27) {
      label = 9;
     } else {
      $28 = (__Z16GetBuildSettingsv()|0);
      $29 = (($28) + 94|0);
      $30 = HEAP8[$29>>0]|0;
      $31 = ($30<<24>>24)==(0);
      if ($31) {
       label = 9;
      } else {
       $32 = (__ZN11AudioFilter6GetDSPEv($11)|0);
       $33 = ($32|0)==(0|0);
       if ($33) {
        label = 9;
       } else {
        $61 = $32;
        label = 15;
       }
      }
     }
    }
    if ((label|0) == 9) {
     label = 0;
     $34 = HEAP32[$6>>2]|0;
     $35 = ((($34) + ($i$04<<3)|0) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if (!($37)) {
      $38 = (($36) + 8|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = $39 >>> 21;
      $41 = HEAP32[560640>>2]|0;
      $42 = Math_imul($41, $40)|0;
      $43 = (($42) + 114)|0;
      $44 = $43 >> 5;
      $45 = $44 << 5;
      $46 = (($43) - ($45))|0;
      $47 = HEAP32[560632>>2]|0;
      $48 = (($47) + ($44<<2)|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = 1 << $46;
      $51 = $50 & $49;
      $52 = ($51|0)==(0);
      if (!($52)) {
       if ($create) {
        $53 = (__ZN13MonoBehaviour14GetOrCreateDSPEv($36)|0);
        $56 = $53;
       } else {
        $54 = (__ZNK13MonoBehaviour6GetDSPEv($36)|0);
        $56 = $54;
       }
       $55 = ($56|0)==(0|0);
       if (!($55)) {
        $61 = $56;
        label = 15;
       }
      }
     }
    }
    do {
     if ((label|0) == 15) {
      label = 0;
      $57 = HEAP32[$7>>2]|0;
      $58 = HEAP32[$8>>2]|0;
      $59 = ($57|0)==($58|0);
      if (!($59)) {
       $60 = ($57|0)==(0|0);
       if ($60) {
        $63 = 0;
       } else {
        HEAP32[$57>>2] = $61;
        $$pre$i = HEAP32[$7>>2]|0;
        $63 = $$pre$i;
       }
       $62 = (($63) + 4|0);
       HEAP32[$7>>2] = $62;
       break;
      }
      $64 = HEAP32[$filters>>2]|0;
      $65 = $57;
      $66 = $64;
      $67 = (($65) - ($66))|0;
      $68 = $67 >> 2;
      $69 = (($68) + 1)|0;
      $70 = ($69>>>0)>(1073741823);
      if ($70) {
       break L7;
      }
      $71 = ($68>>>0)<(536870911);
      if ($71) {
       $72 = $67 >> 1;
       $73 = ($72>>>0)<($69>>>0);
       $74 = $73 ? $69 : $72;
       $75 = ($74|0)==(0);
       if ($75) {
        $$0$i3$i$i = 0;$79 = 0;
       } else {
        $$0$i2$i$i = $74;
        label = 23;
       }
      } else {
       $$0$i2$i$i = 1073741823;
       label = 23;
      }
      if ((label|0) == 23) {
       label = 0;
       $76 = $$0$i2$i$i << 2;
       $77 = (__Znwj($76)|0);
       $$0$i3$i$i = $$0$i2$i$i;$79 = $77;
      }
      $78 = (($79) + ($68<<2)|0);
      $80 = (($79) + ($$0$i3$i$i<<2)|0);
      $81 = ($78|0)==(0|0);
      if (!($81)) {
       HEAP32[$78>>2] = $61;
      }
      $82 = (($79) + ($69<<2)|0);
      _memcpy(($79|0),($64|0),($67|0))|0;
      HEAP32[$filters>>2] = $79;
      HEAP32[$7>>2] = $82;
      HEAP32[$8>>2] = $80;
      $83 = ($64|0)==(0|0);
      if (!($83)) {
       __ZdlPv($64);
      }
     }
    } while(0);
    $84 = (($i$04) + 1)|0;
    $85 = HEAP32[$3>>2]|0;
    $86 = ($84|0)<($85|0);
    if ($86) {
     $i$04 = $84;
    } else {
     $$pre$phi9Z2D = $7;$$pre$phiZ2D = $filters;
     break L4;
    }
   }
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$pre8 = (($filters) + 4|0);
   $$pre$phi9Z2D = $$pre8;$$pre$phiZ2D = $filters;
  }
 } while(0);
 $87 = HEAP32[$$pre$phiZ2D>>2]|0;
 $88 = HEAP32[$$pre$phi9Z2D>>2]|0;
 $89 = ($87|0)!=($88|0);
 $$0 = $89;
 STACKTOP = sp;return ($$0|0);
}
function __ZL16FMOD_ErrorString11FMOD_RESULT16238($errcode) {
 $errcode = $errcode|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($errcode|0) {
  case 5:  {
   $$0 = 734024;
   break;
  }
  case 6:  {
   $$0 = 734064;
   break;
  }
  case 9:  {
   $$0 = 734184;
   break;
  }
  case 15:  {
   $$0 = 734672;
   break;
  }
  case 17:  {
   $$0 = 734840;
   break;
  }
  case 3:  {
   $$0 = 733912;
   break;
  }
  case 12:  {
   $$0 = 734320;
   break;
  }
  case 14:  {
   $$0 = 734528;
   break;
  }
  case 16:  {
   $$0 = 734776;
   break;
  }
  case 7:  {
   $$0 = 734104;
   break;
  }
  case 8:  {
   $$0 = 734136;
   break;
  }
  case 13:  {
   $$0 = 734472;
   break;
  }
  case 2:  {
   $$0 = 733776;
   break;
  }
  case 4:  {
   $$0 = 733960;
   break;
  }
  case 10:  {
   $$0 = 734216;
   break;
  }
  case 11:  {
   $$0 = 734256;
   break;
  }
  case 84:  {
   $$0 = 735432;
   break;
  }
  case 87:  {
   $$0 = 735664;
   break;
  }
  case 89:  {
   $$0 = 735968;
   break;
  }
  case 85:  {
   $$0 = 735488;
   break;
  }
  case 86:  {
   $$0 = 735560;
   break;
  }
  case 88:  {
   $$0 = 735832;
   break;
  }
  case 90:  {
   $$0 = 735880;
   break;
  }
  case 19:  {
   $$0 = 736056;
   break;
  }
  case 20:  {
   $$0 = 736080;
   break;
  }
  case 21:  {
   $$0 = 736192;
   break;
  }
  case 22:  {
   $$0 = 736232;
   break;
  }
  case 23:  {
   $$0 = 736328;
   break;
  }
  case 18:  {
   $$0 = 735032;
   break;
  }
  case 92:  {
   $$0 = 735136;
   break;
  }
  case 91:  {
   $$0 = 735384;
   break;
  }
  case 83:  {
   $$0 = 735272;
   break;
  }
  case 35:  {
   $$0 = 737000;
   break;
  }
  case 36:  {
   $$0 = 737056;
   break;
  }
  case 37:  {
   $$0 = 737096;
   break;
  }
  case 38:  {
   $$0 = 737152;
   break;
  }
  case 40:  {
   $$0 = 737296;
   break;
  }
  case 42:  {
   $$0 = 737416;
   break;
  }
  case 43:  {
   $$0 = 737488;
   break;
  }
  case 44:  {
   $$0 = 737528;
   break;
  }
  case 26:  {
   $$0 = 736424;
   break;
  }
  case 27:  {
   $$0 = 736512;
   break;
  }
  case 29:  {
   $$0 = 736656;
   break;
  }
  case 31:  {
   $$0 = 736720;
   break;
  }
  case 41:  {
   $$0 = 737352;
   break;
  }
  case 30:  {
   $$0 = 736688;
   break;
  }
  case 39:  {
   $$0 = 737208;
   break;
  }
  case 45:  {
   $$0 = 737656;
   break;
  }
  case 34:  {
   $$0 = 736896;
   break;
  }
  case 25:  {
   $$0 = 736384;
   break;
  }
  case 32:  {
   $$0 = 736784;
   break;
  }
  case 24:  {
   $$0 = 736352;
   break;
  }
  case 28:  {
   $$0 = 736584;
   break;
  }
  case 33:  {
   $$0 = 736832;
   break;
  }
  case 93:  {
   $$0 = 737824;
   break;
  }
  case 52:  {
   $$0 = 738528;
   break;
  }
  case 55:  {
   $$0 = 738736;
   break;
  }
  case 94:  {
   $$0 = 737776;
   break;
  }
  case 49:  {
   $$0 = 738192;
   break;
  }
  case 47:  {
   $$0 = 737984;
   break;
  }
  case 53:  {
   $$0 = 738576;
   break;
  }
  case 56:  {
   $$0 = 738856;
   break;
  }
  case 48:  {
   $$0 = 738064;
   break;
  }
  case 57:  {
   $$0 = 738896;
   break;
  }
  case 58:  {
   $$0 = 739032;
   break;
  }
  case 59:  {
   $$0 = 739152;
   break;
  }
  case 60:  {
   $$0 = 739256;
   break;
  }
  case 61:  {
   $$0 = 739296;
   break;
  }
  case 50:  {
   $$0 = 738384;
   break;
  }
  case 46:  {
   $$0 = 737904;
   break;
  }
  case 95:  {
   $$0 = 737712;
   break;
  }
  case 54:  {
   $$0 = 738648;
   break;
  }
  case 51:  {
   $$0 = 738432;
   break;
  }
  case 74:  {
   $$0 = 740848;
   break;
  }
  case 77:  {
   $$0 = 741048;
   break;
  }
  case 79:  {
   $$0 = 741280;
   break;
  }
  case 65:  {
   $$0 = 739624;
   break;
  }
  case 78:  {
   $$0 = 741200;
   break;
  }
  case 80:  {
   $$0 = 741360;
   break;
  }
  case 81:  {
   $$0 = 741472;
   break;
  }
  case 75:  {
   $$0 = 740288;
   break;
  }
  case 82:  {
   $$0 = 741520;
   break;
  }
  case 76:  {
   $$0 = 740984;
   break;
  }
  case 66:  {
   $$0 = 739688;
   break;
  }
  case 63:  {
   $$0 = 739496;
   break;
  }
  case 67:  {
   $$0 = 739752;
   break;
  }
  case 62:  {
   $$0 = 739400;
   break;
  }
  case 64:  {
   $$0 = 739552;
   break;
  }
  case 69:  {
   $$0 = 739968;
   break;
  }
  case 70:  {
   $$0 = 740080;
   break;
  }
  case 68:  {
   $$0 = 739848;
   break;
  }
  case 71:  {
   $$0 = 740144;
   break;
  }
  case 72:  {
   $$0 = 740576;
   break;
  }
  case 73:  {
   $$0 = 740728;
   break;
  }
  case 0:  {
   $$0 = 741584;
   break;
  }
  case 1:  {
   $$0 = 733712;
   break;
  }
  default: {
   $$0 = 741600;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN11AudioSource12ApplyFiltersEv($this) {
 $this = $this|0;
 var $$ = 0, $$27 = 0, $$lcssa = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $eh$lpad$body$index6Z2D = 0, $eh$lpad$body$indexZ2D = 0, $filters = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, $vararg_buffer17 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr16 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr22 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer17 = sp;
 $0 = sp + 40|0;
 $1 = sp + 16|0;
 $filters = sp + 28|0;
 $2 = (($this) + 476|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 HEAP32[$filters>>2] = 0;
 $5 = (($filters) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($filters) + 8|0);
 HEAP32[$6>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1585,($this|0),($filters|0),1)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 L4: do {
  if ($8) {
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   $$pre$pre = HEAP32[$filters>>2]|0;
   $26 = $$pre$pre;$eh$lpad$body$index6Z2D = $24;$eh$lpad$body$indexZ2D = $23;
  } else {
   $9 = HEAP32[$filters>>2]|0;
   $10 = HEAP32[$5>>2]|0;
   $11 = ($9|0)==($10|0);
   L6: do {
    if ($11) {
     $$lcssa = $9;
    } else {
     $12 = (($this) + 508|0);
     $13 = (($1) + 1|0);
     $14 = (($1) + 8|0);
     $15 = (($0) + 1|0);
     $16 = (($0) + 8|0);
     $18 = $9;
     while(1) {
      $17 = HEAP32[$18>>2]|0;
      $19 = HEAP32[$12>>2]|0;
      $20 = ($17|0)==($19|0);
      if (!($20)) {
       __THREW__ = 0;
       $32 = (invoke_ii(3387,($17|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        label = 6;
        break;
       }
       $35 = ($32|0)==(0);
       if (!($35)) {
        $36 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($32)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer17>>2] = 731960;
        $vararg_ptr14 = (($vararg_buffer17) + 4|0);
        HEAP32[$vararg_ptr14>>2] = 1366;
        $vararg_ptr15 = (($vararg_buffer17) + 8|0);
        HEAP32[$vararg_ptr15>>2] = 733312;
        $vararg_ptr16 = (($vararg_buffer17) + 12|0);
        HEAP32[$vararg_ptr16>>2] = $36;
        invoke_viii(1617,($0|0),(741616|0),($vararg_buffer17|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         label = 6;
         break;
        }
        $39 = HEAP8[$0>>0]|0;
        $40 = $39 & 1;
        $41 = ($40<<24>>24)==(0);
        $42 = HEAP32[$16>>2]|0;
        $$ = $41 ? $15 : $42;
        __THREW__ = 0;
        invoke_viiiiiiii(21,($$|0),0,(732472|0),21,1,0,0,(0|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 18;
         break;
        }
        $45 = HEAP8[$0>>0]|0;
        $46 = $45 & 1;
        $47 = ($46<<24>>24)==(0);
        if (!($47)) {
         $48 = HEAP32[$16>>2]|0;
         __ZdlPv($48);
        }
       }
       $55 = HEAP32[$2>>2]|0;
       __THREW__ = 0;
       $56 = (invoke_iiii(1581,($55|0),($17|0),(0|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 6;
        break;
       }
       $59 = ($56|0)==(0);
       if (!($59)) {
        $60 = (__ZL16FMOD_ErrorString11FMOD_RESULT16238($56)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer17>>2] = 731960;
        $vararg_ptr20 = (($vararg_buffer17) + 4|0);
        HEAP32[$vararg_ptr20>>2] = 1367;
        $vararg_ptr21 = (($vararg_buffer17) + 8|0);
        HEAP32[$vararg_ptr21>>2] = 733680;
        $vararg_ptr22 = (($vararg_buffer17) + 12|0);
        HEAP32[$vararg_ptr22>>2] = $60;
        invoke_viii(1617,($1|0),(741616|0),($vararg_buffer17|0));
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 6;
         break;
        }
        $63 = HEAP8[$1>>0]|0;
        $64 = $63 & 1;
        $65 = ($64<<24>>24)==(0);
        $66 = HEAP32[$14>>2]|0;
        $$27 = $65 ? $13 : $66;
        __THREW__ = 0;
        invoke_viiiiiiii(21,($$27|0),0,(732472|0),21,1,0,0,(0|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         label = 26;
         break;
        }
        $69 = HEAP8[$1>>0]|0;
        $70 = $69 & 1;
        $71 = ($70<<24>>24)==(0);
        if (!($71)) {
         $72 = HEAP32[$14>>2]|0;
         __ZdlPv($72);
        }
       }
      }
      $79 = (($18) + 4|0);
      $80 = ($79|0)==($10|0);
      if ($80) {
       $$lcssa = $10;
       break L6;
      } else {
       $18 = $79;
      }
     }
     if ((label|0) == 6) {
      $21 = ___cxa_find_matching_catch()|0;
      $22 = tempRet0;
      $26 = $9;$eh$lpad$body$index6Z2D = $22;$eh$lpad$body$indexZ2D = $21;
      break L4;
     }
     else if ((label|0) == 18) {
      $49 = ___cxa_find_matching_catch()|0;
      $50 = tempRet0;
      $51 = HEAP8[$0>>0]|0;
      $52 = $51 & 1;
      $53 = ($52<<24>>24)==(0);
      if ($53) {
       $26 = $9;$eh$lpad$body$index6Z2D = $50;$eh$lpad$body$indexZ2D = $49;
       break L4;
      }
      $54 = HEAP32[$16>>2]|0;
      __ZdlPv($54);
      $26 = $9;$eh$lpad$body$index6Z2D = $50;$eh$lpad$body$indexZ2D = $49;
      break L4;
     }
     else if ((label|0) == 26) {
      $73 = ___cxa_find_matching_catch()|0;
      $74 = tempRet0;
      $75 = HEAP8[$1>>0]|0;
      $76 = $75 & 1;
      $77 = ($76<<24>>24)==(0);
      if ($77) {
       $26 = $9;$eh$lpad$body$index6Z2D = $74;$eh$lpad$body$indexZ2D = $73;
       break L4;
      }
      $78 = HEAP32[$14>>2]|0;
      __ZdlPv($78);
      $26 = $9;$eh$lpad$body$index6Z2D = $74;$eh$lpad$body$indexZ2D = $73;
      break L4;
     }
    }
   } while(0);
   $81 = ($9|0)==(0|0);
   if ($81) {
    STACKTOP = sp;return;
   }
   $82 = ($$lcssa|0)==($9|0);
   if (!($82)) {
    $__new_last2$i$i$i$i$i = $9;
    $scevgep$i$i$i$i$i = (($$lcssa) + -4|0);
    $83 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($83)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $84 = $uglygep3$i$i$i$i$i >>> 2;
    $85 = $84 ^ -1;
    $scevgep4$i$i$i$i$i = (($$lcssa) + ($85<<2)|0);
    HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($9);
   STACKTOP = sp;return;
  }
 } while(0);
 $25 = ($26|0)==(0|0);
 if ($25) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $27 = HEAP32[$5>>2]|0;
 $28 = ($27|0)==($26|0);
 if (!($28)) {
  $__new_last2$i$i$i$i$i1 = $26;
  $scevgep$i$i$i$i$i2 = (($27) + -4|0);
  $29 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($29)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $30 = $uglygep3$i$i$i$i$i5 >>> 2;
  $31 = $30 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($27) + ($31<<2)|0);
  HEAP32[$5>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($26);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN11AudioSource16UpdateParametersE12SoundChannel($this,$channel) {
 $this = $this|0;
 $channel = $channel|0;
 var $$$i = Math_fround(0), $$$i1 = Math_fround(0), $$$i4 = Math_fround(0), $$$i7 = Math_fround(0), $$0 = 0, $$0$i = Math_fround(0), $$0$i2 = Math_fround(0), $$0$i5 = Math_fround(0), $$0$i8 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0);
 var $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0;
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0;
 var $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $curverange = 0, $curverange1 = 0, $curverange2 = 0, $curverange4 = 0, $isPlaying = 0, $orient = 0, $p = 0, $phitmp = 0, $phitmp$i = 0, $pos$i$i$i$i$i = 0, $props = 0;
 var $reverbZoneMix$0 = Math_fround(0), $reverbZoneMix$0$ = Math_fround(0), $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $pos$i$i$i$i$i = sp + 128|0;
 $0 = sp + 124|0;
 $isPlaying = sp + 136|0;
 $p = sp + 112|0;
 $v = sp + 100|0;
 $1 = sp + 88|0;
 $orient = sp + 76|0;
 $2 = sp + 64|0;
 $3 = sp + 40|0;
 $curverange = sp + 32|0;
 $curverange1 = sp + 24|0;
 $props = sp + 8|0;
 $curverange2 = sp;
 $curverange4 = sp + 56|0;
 HEAP8[$isPlaying>>0] = 0;
 $4 = (($channel) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__ZN20SoundChannelInstance9isPlayingEPb($5,$isPlaying)|0);
 $phitmp = ($7|0)==(36);
 if ($phitmp) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($9)|0);
 __ZNK9Transform11GetPositionEv($p,$10);
 HEAPF32[$v>>2] = Math_fround(0.0);
 $11 = (($v) + 4|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($v) + 8|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = HEAP32[$8>>2]|0;
 $14 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($13,54)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $20 = Math_fround(HEAPF32[$p>>2]);
  $21 = (($this) + 488|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($20 - $22);
  $24 = (($p) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($this) + 492|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($25 - $27);
  $29 = (($p) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($this) + 496|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($30 - $32);
  $34 = (__Z14GetTimeManagerv()|0);
  $35 = (($34) + 116|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = Math_fround($23 * $36);
  $38 = Math_fround($28 * $36);
  $39 = Math_fround($33 * $36);
  HEAPF32[$v>>2] = $37;
  HEAPF32[$11>>2] = $38;
  HEAPF32[$12>>2] = $39;
 } else {
  $16 = (__Z11GetIPhysicsv()|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_viii[$19 & 4095]($1,$16,$14);
  ;HEAP32[$v+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$v+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$v+8>>2]=HEAP32[$1+8>>2]|0;
 }
 $40 = HEAP32[$8>>2]|0;
 $41 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($40)|0);
 __ZNK9Transform11GetRotationEv($3,$41);
 __Z17QuaternionToEulerRK11Quaternionf($2,$3);
 $42 = Math_fround(HEAPF32[$2>>2]);
 $43 = Math_fround($42 * $42);
 $44 = (($2) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 * $45);
 $47 = Math_fround($43 + $46);
 $48 = (($2) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * $49);
 $51 = Math_fround($47 + $50);
 $52 = (Math_fround(Math_sqrt((Math_fround($51)))));
 $53 = Math_fround(HEAPF32[616648>>2]);
 $54 = $52 > $53;
 if ($54) {
  ;HEAP32[$orient+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$orient+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$orient+8>>2]=HEAP32[$2+8>>2]|0;
  $55 = Math_fround(HEAPF32[$orient>>2]);
  $56 = Math_fround($55 / $52);
  HEAPF32[$orient>>2] = $56;
  $57 = (($orient) + 4|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = Math_fround($58 / $52);
  HEAPF32[$57>>2] = $59;
  $60 = (($orient) + 8|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = Math_fround($61 / $52);
  HEAPF32[$60>>2] = $62;
 } else {
  ;HEAP32[$orient+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$orient+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$orient+8>>2]=HEAP32[616680+8>>2]|0;
 }
 $63 = HEAP32[$4>>2]|0;
 (__ZN20SoundChannelInstance20set3DConeOrientationEP11FMOD_VECTOR($63,$orient)|0);
 $64 = HEAP32[$4>>2]|0;
 (__ZN20SoundChannelInstance15set3DAttributesEPK11FMOD_VECTORS2_($64,$p,$v)|0);
 $65 = (__Z15GetAudioManagerv()|0);
 $66 = (__ZNK12AudioManager16GetAudioListenerEv($65)|0);
 $67 = ($66|0)==(0|0);
 if (!($67)) {
  $68 = Math_fround(HEAPF32[$p>>2]);
  $69 = (($66) + 32|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($68 - $70);
  $72 = (($p) + 4|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = (($66) + 36|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($73 - $75);
  $77 = (($p) + 8|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($66) + 40|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = Math_fround($78 - $80);
  $82 = Math_fround($71 * $71);
  $83 = Math_fround($76 * $76);
  $84 = Math_fround($82 + $83);
  $85 = Math_fround($81 * $81);
  $86 = Math_fround($84 + $85);
  $87 = (Math_fround(Math_sqrt((Math_fround($86)))));
  $88 = (($this) + 32|0);
  $89 = (($this) + 96|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($90|0)==(1);
  if ($91) {
   $102 = HEAP32[$4>>2]|0;
   $103 = (($this) + 88|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = (($104) + 4|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   (__ZN20SoundChannelInstance13set3DPanLevelEf($102,$106)|0);
  } else {
   __ZNK17AnimationCurveTplIfE8GetRangeEv($curverange,$88);
   $92 = (($this) + 376|0);
   $93 = Math_fround(HEAPF32[$92>>2]);
   $94 = Math_fround($87 / $93);
   $95 = Math_fround(HEAPF32[$curverange>>2]);
   $96 = $94 < $95;
   if ($96) {
    $$0$i8 = $95;
   } else {
    $97 = (($curverange) + 4|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = $94 > $98;
    $$$i7 = $99 ? $98 : $94;
    $$0$i8 = $$$i7;
   }
   $100 = (Math_fround(__ZNK17AnimationCurveTplIfE8EvaluateEf($88,$$0$i8)));
   $101 = HEAP32[$4>>2]|0;
   (__ZN20SoundChannelInstance13set3DPanLevelEf($101,$100)|0);
  }
  $107 = (($this) + 112|0);
  $108 = (($this) + 176|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = ($109|0)==(1);
  if ($110) {
   $120 = (($this) + 168|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = (($121) + 4|0);
   $123 = Math_fround(HEAPF32[$122>>2]);
   $reverbZoneMix$0 = $123;
  } else {
   __ZNK17AnimationCurveTplIfE8GetRangeEv($curverange1,$107);
   $111 = (($this) + 376|0);
   $112 = Math_fround(HEAPF32[$111>>2]);
   $113 = Math_fround($87 / $112);
   $114 = Math_fround(HEAPF32[$curverange1>>2]);
   $115 = $113 < $114;
   if ($115) {
    $$0$i5 = $114;
   } else {
    $116 = (($curverange1) + 4|0);
    $117 = Math_fround(HEAPF32[$116>>2]);
    $118 = $113 > $117;
    $$$i4 = $118 ? $117 : $113;
    $$0$i5 = $$$i4;
   }
   $119 = (Math_fround(__ZNK17AnimationCurveTplIfE8EvaluateEf($107,$$0$i5)));
   $reverbZoneMix$0 = $119;
  }
  $124 = (($this) + 400|0);
  $125 = HEAP8[$124>>0]|0;
  $126 = ($125<<24>>24)==(0);
  $reverbZoneMix$0$ = $126 ? $reverbZoneMix$0 : Math_fround(0.0);
  $127 = HEAP32[$4>>2]|0;
  (__ZN20SoundChannelInstance19getReverbPropertiesEP29FMOD_REVERB_CHANNELPROPERTIES($127,$props)|0);
  $128 = $reverbZoneMix$0$ > Math_fround(1.0);
  do {
   if ($128) {
    $129 = Math_fround($reverbZoneMix$0$ + Math_fround(-1.0));
    $130 = Math_fround($129 * Math_fround(1.0E+4));
    $131 = (~~(($130)));
    $132 = (($props) + 4|0);
    HEAP32[$132>>2] = $131;
   } else {
    $133 = $reverbZoneMix$0$ > Math_fround(0.0);
    if ($133) {
     $134 = (Math_fround(+(_log10f((+$reverbZoneMix$0$)))));
     $135 = Math_fround($134 * Math_fround(2000.0));
     $136 = (~~(($135)));
     $137 = (($props) + 4|0);
     HEAP32[$137>>2] = $136;
     break;
    } else {
     $138 = (($props) + 4|0);
     HEAP32[$138>>2] = -10000;
     break;
    }
   }
  } while(0);
  $139 = HEAP32[$4>>2]|0;
  (__ZN20SoundChannelInstance19setReverbPropertiesEP29FMOD_REVERB_CHANNELPROPERTIES($139,$props)|0);
  $140 = (($this) + 412|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = ($141|0)==(0);
  do {
   if (!($142)) {
    HEAP32[$0>>2] = $141;
    $143 = HEAP32[560624>>2]|0;
    $144 = ($143|0)==(0|0);
    if ($144) {
     label = 34;
    } else {
     $145 = (($143) + 36|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = (($143) + 4|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = ($146|0)==($148|0);
     do {
      if ($149) {
       $150 = (($143) + 28|0);
       $151 = HEAP32[$150>>2]|0;
       $152 = (($143) + 32|0);
       $153 = HEAP32[$152>>2]|0;
       $154 = (($151) + ($153<<3)|0);
       $170 = $154;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$143,$0);
       $155 = HEAP32[$pos$i$i$i$i$i>>2]|0;
       $156 = ($155|0)==(-1);
       $157 = (($143) + 28|0);
       $158 = HEAP32[$157>>2]|0;
       if ($156) {
        $159 = (($143) + 32|0);
        $160 = HEAP32[$159>>2]|0;
        $161 = (($158) + ($160<<3)|0);
        $170 = $161;
        break;
       } else {
        $162 = (($158) + ($155<<3)|0);
        $170 = $162;
        break;
       }
      }
     } while(0);
     $163 = HEAP32[560624>>2]|0;
     $164 = (($163) + 28|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = (($163) + 32|0);
     $167 = HEAP32[$166>>2]|0;
     $168 = (($165) + ($167<<3)|0);
     $169 = ($170|0)==($168|0);
     if ($169) {
      label = 34;
     } else {
      $171 = (($170) + 4|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = ($172|0)==(0|0);
      if ($173) {
       label = 34;
      }
     }
    }
    if ((label|0) == 34) {
     $174 = HEAP32[$140>>2]|0;
     $175 = (__Z31ReadObjectFromPersistentManageri($174)|0);
     $phitmp$i = ($175|0)==(0|0);
     if ($phitmp$i) {
      break;
     }
    }
    $176 = (($this) + 192|0);
    $177 = (($this) + 256|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = ($178|0)==(1);
    if ($179) {
     $191 = HEAP32[$4>>2]|0;
     $192 = (($this) + 248|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = (($193) + 4|0);
     $195 = Math_fround(HEAPF32[$194>>2]);
     $196 = Math_fround($195 * Math_fround(360.0));
     (__ZN20SoundChannelInstance11set3DSpreadEf($191,$196)|0);
     break;
    }
    __ZNK17AnimationCurveTplIfE8GetRangeEv($curverange2,$176);
    $180 = (($this) + 376|0);
    $181 = Math_fround(HEAPF32[$180>>2]);
    $182 = Math_fround($87 / $181);
    $183 = Math_fround(HEAPF32[$curverange2>>2]);
    $184 = $182 < $183;
    if ($184) {
     $$0$i2 = $183;
    } else {
     $185 = (($curverange2) + 4|0);
     $186 = Math_fround(HEAPF32[$185>>2]);
     $187 = $182 > $186;
     $$$i1 = $187 ? $186 : $182;
     $$0$i2 = $$$i1;
    }
    $188 = (Math_fround(__ZNK17AnimationCurveTplIfE8EvaluateEf($176,$$0$i2)));
    $189 = HEAP32[$4>>2]|0;
    $190 = Math_fround($188 * Math_fround(360.0));
    (__ZN20SoundChannelInstance11set3DSpreadEf($189,$190)|0);
   }
  } while(0);
  $197 = HEAP32[$8>>2]|0;
  $198 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($197,169)|0);
  $199 = ($198|0)==(0|0);
  if (!($199)) {
   $200 = (__ZN18AudioLowPassFilter26GetCustomLowpassLevelCurveEv($198)|0);
   $201 = (($200) + 64|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = ($202|0)>(1);
   if ($203) {
    __ZNK17AnimationCurveTplIfE8GetRangeEv($curverange4,$200);
    $204 = (($this) + 376|0);
    $205 = Math_fround(HEAPF32[$204>>2]);
    $206 = Math_fround($87 / $205);
    $207 = Math_fround(HEAPF32[$curverange4>>2]);
    $208 = $206 < $207;
    if ($208) {
     $$0$i = $207;
    } else {
     $209 = (($curverange4) + 4|0);
     $210 = Math_fround(HEAPF32[$209>>2]);
     $211 = $206 > $210;
     $$$i = $211 ? $210 : $206;
     $$0$i = $$$i;
    }
    $212 = (Math_fround(__ZNK17AnimationCurveTplIfE8EvaluateEf($200,$$0$i)));
    $213 = Math_fround($212 * Math_fround(21990.0));
    $214 = Math_fround(Math_fround(22000.0) - $213);
    $215 = (($198) + 120|0);
    HEAPF32[$215>>2] = $214;
    $216 = HEAP32[$198>>2]|0;
    $217 = (($216) + 108|0);
    $218 = HEAP32[$217>>2]|0;
    FUNCTION_TABLE_vi[$218 & 4095]($198);
   }
  }
 }
 $219 = (($this) + 488|0);
 ;HEAP32[$219+0>>2]=HEAP32[$p+0>>2]|0;HEAP32[$219+4>>2]=HEAP32[$p+4>>2]|0;HEAP32[$219+8>>2]=HEAP32[$p+8>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11AudioSource5PauseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 504|0);
 HEAP8[$0>>0] = 1;
 $1 = (($this) + 444|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 276|0);
 HEAP8[$4>>0] = 1;
 __ZN20SoundChannelInstance16UpdatePauseStateEv($2);
 STACKTOP = sp;return;
}
function __ZN11AudioSource13PauseOneShotsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 408|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 404|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $1;
 }
 while(1) {
  $4 = (($5) + 8|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = (($6) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 276|0);
  HEAP8[$9>>0] = 1;
  __ZN20SoundChannelInstance16UpdatePauseStateEv($8);
  $10 = (($5) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==($2|0);
  if ($12) {
   break;
  } else {
   $5 = $11;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11AudioSource14ResumeOneShotsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 408|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 404|0);
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 401|0);
 $6 = $1;
 while(1) {
  $5 = (($6) + 8|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (__Z15GetAudioManagerv()|0);
  $11 = (($10) + 36|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $17 = 0;
  } else {
   $14 = HEAP8[$4>>0]|0;
   $15 = $14 ^ 1;
   $17 = $15;
  }
  $16 = (($9) + 276|0);
  HEAP8[$16>>0] = $17;
  __ZN20SoundChannelInstance16UpdatePauseStateEv($9);
  $18 = (($6) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($2|0);
  if ($20) {
   break;
  } else {
   $6 = $19;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK11AudioSource9IsPlayingEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isPlaying = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $isPlaying = sp;
 $0 = (($this) + 444|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
 } else {
  $3 = (__ZN20SoundChannelInstance9isPlayingEPb($1,$isPlaying)|0);
  $4 = ($3|0)==(0);
  if ($4) {
   $5 = (($this) + 504|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $$0 = 1;
   } else {
    $8 = HEAP8[$isPlaying>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $$0 = 0;
    } else {
     $10 = HEAP32[$0>>2]|0;
     $11 = (($10) + 276|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($12<<24>>24)==(0);
     $$0 = $13;
    }
   }
  } else {
   $$0 = 0;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNK11AudioSource14GetMinDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 372|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK11AudioSource14GetMaxDistanceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 376|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 STACKTOP = sp;return (Math_fround($1));
}
function __ZNK11AudioSource14GetRolloffModeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 392|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN11AudioSource21GetCustomRolloffCurveEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 272|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN11AudioSource25UnbindFromChannelInstanceEP20SoundChannelInstance($this,$instance) {
 $this = $this|0;
 $instance = $instance|0;
 var $$byval_copy1 = 0, $$ph = 0, $$pre = 0, $$pre10 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 40|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 24|0;
 HEAP32[$1>>2] = 0;
 $3 = (($1) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($1) + 8|0);
 HEAP32[$4>>2] = $1;
 $5 = (($1) + 12|0);
 HEAP32[$5>>2] = $instance;
 $6 = ($instance|0)==(0|0);
 do {
  if ($6) {
   $$ph = 0;
   label = 3;
  } else {
   $7 = (($instance) + 208|0);
   $8 = ($1|0)==($7|0);
   if ($8) {
    $$ph = $instance;
    label = 3;
   } else {
    $12 = HEAP32[$7>>2]|0;
    HEAP32[$1>>2] = $12;
    HEAP32[$3>>2] = $7;
    $13 = (($12) + 4|0);
    HEAP32[$13>>2] = $1;
    $14 = HEAP32[$3>>2]|0;
    HEAP32[$14>>2] = $1;
    $$pre = HEAP32[$5>>2]|0;
    $$pre8 = HEAP32[$1>>2]|0;
    $15 = (($this) + 444|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($$pre|0);
    HEAP32[$5>>2] = 0;
    $18 = ($$pre8|0)==(0|0);
    if ($18) {
     if ($17) {
      $31 = $15;
      label = 7;
      break;
     } else {
      break;
     }
    } else {
     $19 = HEAP32[$3>>2]|0;
     $20 = (($$pre8) + 4|0);
     HEAP32[$20>>2] = $19;
     $21 = HEAP32[$1>>2]|0;
     $22 = HEAP32[$3>>2]|0;
     HEAP32[$22>>2] = $21;
     HEAP32[$1>>2] = 0;
     HEAP32[$3>>2] = 0;
     if ($17) {
      $31 = $15;
      label = 7;
      break;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $9 = (($this) + 444|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($$ph|0);
  HEAP32[$5>>2] = 0;
  if ($11) {
   $31 = $9;
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $23 = (($this) + 432|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   $26 = (($this) + 436|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($24) + 4|0);
   HEAP32[$28>>2] = $27;
   $29 = HEAP32[$23>>2]|0;
   $30 = HEAP32[$26>>2]|0;
   HEAP32[$30>>2] = $29;
   HEAP32[$23>>2] = 0;
   HEAP32[$26>>2] = 0;
  }
  HEAP32[$31>>2] = 0;
 }
 $32 = (($this) + 482|0);
 HEAP8[$32>>0] = 0;
 $33 = (($this) + 483|0);
 HEAP8[$33>>0] = 0;
 $34 = (__Z15GetAudioManagerv()|0);
 __ZN12AudioManager16UnScheduleSourceEP11AudioSource($34,$this);
 $35 = (($this) + 408|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 404|0);
 $38 = ($36|0)==($37|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (($2) + 4|0);
 $40 = (($2) + 8|0);
 $41 = (($2) + 12|0);
 $42 = (($instance) + 208|0);
 $43 = ($2|0)==($42|0);
 if ($6) {
  $45 = $36;
  while(1) {
   $44 = (($45) + 4|0);
   $46 = HEAP32[$44>>2]|0;
   $47 = (($45) + 8|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$2>>2] = 0;
   HEAP32[$39>>2] = 0;
   HEAP32[$40>>2] = $2;
   HEAP32[$41>>2] = 0;
   $49 = (($48) + 24|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0|0);
   HEAP32[$41>>2] = 0;
   if ($51) {
    $52 = HEAP32[628304>>2]|0;
    $53 = ($48|0)==(0|0);
    if (!($53)) {
     $54 = HEAP32[$48>>2]|0;
     $55 = ($54|0)==(0|0);
     if (!($55)) {
      $56 = (($48) + 4|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($54) + 4|0);
      HEAP32[$58>>2] = $57;
      $59 = HEAP32[$48>>2]|0;
      $60 = HEAP32[$56>>2]|0;
      HEAP32[$60>>2] = $59;
      HEAP32[$48>>2] = 0;
      HEAP32[$56>>2] = 0;
     }
     HEAP32[$49>>2] = 0;
     $61 = (($48) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($62|0)==(0|0);
     if (!($63)) {
      $64 = (($48) + 16|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($62) + 4|0);
      HEAP32[$66>>2] = $65;
      $67 = HEAP32[$61>>2]|0;
      $68 = HEAP32[$64>>2]|0;
      HEAP32[$68>>2] = $67;
      HEAP32[$61>>2] = 0;
      HEAP32[$64>>2] = 0;
     }
    }
    HEAP32[$0>>2] = $52;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($48,$$byval_copy1);
   }
   $69 = ($46|0)==($37|0);
   if ($69) {
    break;
   } else {
    $45 = $46;
   }
  }
  STACKTOP = sp;return;
 } else {
  $71 = $36;
 }
 while(1) {
  $70 = (($71) + 4|0);
  $72 = HEAP32[$70>>2]|0;
  $73 = (($71) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  HEAP32[$2>>2] = 0;
  HEAP32[$39>>2] = 0;
  HEAP32[$40>>2] = $2;
  HEAP32[$41>>2] = $instance;
  do {
   if ($43) {
    $75 = (($74) + 24|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($76|0)==($instance|0);
    HEAP32[$41>>2] = 0;
    if ($77) {
     $78 = HEAP32[628304>>2]|0;
     $110 = $78;$99 = $75;
     label = 27;
    }
   } else {
    $79 = HEAP32[$42>>2]|0;
    HEAP32[$2>>2] = $79;
    HEAP32[$39>>2] = $42;
    $80 = (($79) + 4|0);
    HEAP32[$80>>2] = $2;
    $81 = HEAP32[$39>>2]|0;
    HEAP32[$81>>2] = $2;
    $$pre9 = HEAP32[$41>>2]|0;
    $$pre10 = HEAP32[$2>>2]|0;
    $82 = (($74) + 24|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($83|0)==($$pre9|0);
    HEAP32[$41>>2] = 0;
    $85 = ($$pre10|0)==(0|0);
    if ($85) {
     if (!($84)) {
      break;
     }
    } else {
     $86 = HEAP32[$39>>2]|0;
     $87 = (($$pre10) + 4|0);
     HEAP32[$87>>2] = $86;
     $88 = HEAP32[$2>>2]|0;
     $89 = HEAP32[$39>>2]|0;
     HEAP32[$89>>2] = $88;
     HEAP32[$2>>2] = 0;
     HEAP32[$39>>2] = 0;
     if (!($84)) {
      break;
     }
    }
    $90 = HEAP32[628304>>2]|0;
    $91 = ($74|0)==(0|0);
    if ($91) {
     $108 = $90;
     label = 31;
    } else {
     $110 = $90;$99 = $82;
     label = 27;
    }
   }
  } while(0);
  if ((label|0) == 27) {
   label = 0;
   $92 = HEAP32[$74>>2]|0;
   $93 = ($92|0)==(0|0);
   if (!($93)) {
    $94 = (($74) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($92) + 4|0);
    HEAP32[$96>>2] = $95;
    $97 = HEAP32[$74>>2]|0;
    $98 = HEAP32[$94>>2]|0;
    HEAP32[$98>>2] = $97;
    HEAP32[$74>>2] = 0;
    HEAP32[$94>>2] = 0;
   }
   HEAP32[$99>>2] = 0;
   $100 = (($74) + 12|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = ($101|0)==(0|0);
   if ($102) {
    $108 = $110;
    label = 31;
   } else {
    $103 = (($74) + 16|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($101) + 4|0);
    HEAP32[$105>>2] = $104;
    $106 = HEAP32[$100>>2]|0;
    $107 = HEAP32[$103>>2]|0;
    HEAP32[$107>>2] = $106;
    HEAP32[$100>>2] = 0;
    HEAP32[$103>>2] = 0;
    $108 = $110;
    label = 31;
   }
  }
  if ((label|0) == 31) {
   label = 0;
   HEAP32[$0>>2] = $108;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($74,$$byval_copy1);
  }
  $109 = ($72|0)==($37|0);
  if ($109) {
   break;
  } else {
   $71 = $72;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11AudioFilter7CleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 (__ZN4FMOD3DSP7releaseEv($1)|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11AudioFilter6GetDSPEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $14 = $1;
  STACKTOP = sp;return ($14|0);
 }
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(65536);
 if ($5) {
  $14 = 0;
  STACKTOP = sp;return ($14|0);
 }
 $6 = (__Z15GetAudioManagerv()|0);
 $7 = (($6) + 92|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$3>>2]|0;
 (__ZN4FMOD6System15createDSPByTypeE13FMOD_DSP_TYPEPPNS_3DSPE($8,$9,$0)|0);
 $10 = HEAP32[$0>>2]|0;
 $11 = (($this) + 28|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 (__ZN4FMOD3DSP9setBypassEb($10,$13)|0);
 $$pre = HEAP32[$0>>2]|0;
 $14 = $$pre;
 STACKTOP = sp;return ($14|0);
}
function __ZN17AudioCustomFilterC2EP13MonoBehaviour($this,$behaviour) {
 $this = $this|0;
 $behaviour = $behaviour|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dspdesc$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $dspdesc$i = sp;
 HEAP32[$this>>2] = ((741656 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $behaviour;
 $2 = (($this) + 12|0);
 HEAP8[$2>>0] = 0;
 $3 = (($this) + 13|0);
 HEAP8[$3>>0] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 20|0);
 HEAP32[$5>>2] = 0;
 $6 = (($dspdesc$i) + 52|0);
 dest=$dspdesc$i+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$6>>2] = 116;
 $7 = (($dspdesc$i) + 88|0);
 HEAP32[$7>>2] = $this;
 $8 = (__Z15GetAudioManagerv()|0);
 $9 = (($8) + 92|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__ZN4FMOD6System9createDSPEP20FMOD_DSP_DESCRIPTIONPPNS_3DSPE($10,$dspdesc$i,$0)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($11,741672,68,741752)|0);
 $12 = HEAP32[$0>>2]|0;
 (__ZN4FMOD3DSP9setBypassEb($12,1)|0);
 STACKTOP = sp;return;
}
function __ZN17AudioCustomFilterD0Ev($this) {
 $this = $this|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((741656 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $8 = $1;
  label = 5;
 } else {
  __THREW__ = 0;
  invoke_vii(3343,($4|0),1);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $$pre$i$i = HEAP32[$0>>2]|0;
   $8 = $$pre$i$i;
   label = 5;
  }
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $9 = (invoke_ii(3379,($8|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   (invoke_iiiii(262,($9|0),(741672|0),89,(741816|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __ZdlPv($this);
    STACKTOP = sp;return;
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZdlPv($this);
 ___resumeException($14|0);
 // unreachable;
}
function __ZN17AudioCustomFilterD2Ev($this) {
 $this = $this|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((741656 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = $1;
 } else {
  __ZN11AudioSource4StopEb($4,1);
  $$pre$i = HEAP32[$0>>2]|0;
  $6 = $$pre$i;
 }
 $7 = (__ZN4FMOD3DSP7releaseEv($6)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($7,741672,89,741816)|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17AudioCustomFilter7CleanupEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = $1;
 } else {
  __ZN11AudioSource4StopEb($4,1);
  $$pre = HEAP32[$0>>2]|0;
  $6 = $$pre;
 }
 $7 = (__ZN4FMOD3DSP7releaseEv($6)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($7,741672,89,741816)|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17AudioCustomFilter12readCallbackEP14FMOD_DSP_STATEPfS2_jii($dsp_state,$inbuffer,$outbuffer,$length,$inchannels,$outchannels) {
 $dsp_state = $dsp_state|0;
 $inbuffer = $inbuffer|0;
 $outbuffer = $outbuffer|0;
 $length = $length|0;
 $inchannels = $inchannels|0;
 $outchannels = $outchannels|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN17AudioCustomFilter14GetOrCreateDSPEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dspdesc$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $dspdesc$i = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $10 = $1;
  STACKTOP = sp;return ($10|0);
 }
 $3 = (($dspdesc$i) + 52|0);
 dest=$dspdesc$i+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$3>>2] = 116;
 $4 = (($dspdesc$i) + 88|0);
 HEAP32[$4>>2] = $this;
 $5 = (__Z15GetAudioManagerv()|0);
 $6 = (($5) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN4FMOD6System9createDSPEP20FMOD_DSP_DESCRIPTIONPPNS_3DSPE($7,$dspdesc$i,$0)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($8,741672,68,741752)|0);
 $9 = HEAP32[$0>>2]|0;
 (__ZN4FMOD3DSP9setBypassEb($9,1)|0);
 $$pre = HEAP32[$0>>2]|0;
 $10 = $$pre;
 STACKTOP = sp;return ($10|0);
}
function __ZN17AudioCustomFilter6GetDSPEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN24AudioScriptBufferManagerC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;
 __ZN24AudioScriptBufferManager4InitEv($this);
 STACKTOP = sp;return;
}
function __ZN24AudioScriptBufferManager4InitEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $DSPBufferSize = 0, $maxInputChannels = 0, $maxOutputChannels = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $DSPBufferSize = sp + 8|0;
 $maxOutputChannels = sp;
 $maxInputChannels = sp + 4|0;
 $0 = (__Z15GetAudioManagerv()|0);
 $1 = (($0) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 (__ZN4FMOD6System16getDSPBufferSizeEPjPi($2,$DSPBufferSize,0)|0);
 (__ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($2,0,0,$maxOutputChannels,$maxInputChannels,0,0)|0);
 $3 = HEAP32[$DSPBufferSize>>2]|0;
 $4 = HEAP32[$maxOutputChannels>>2]|0;
 $5 = HEAP32[$maxInputChannels>>2]|0;
 $6 = ($4|0)<($5|0);
 $7 = $6 ? $5 : $4;
 $8 = Math_imul($7, $3)|0;
 $9 = (($this) + 8|0);
 HEAP32[$9>>2] = 4096;
 $10 = (__Z19GetScriptingManagerv()|0);
 $11 = (($10) + 208|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$9>>2]|0;
 $14 = (__Z19scripting_array_newP14ScriptingClassjj($12,4,$13)|0);
 HEAP32[$this>>2] = $14;
 $15 = (__Z22scripting_gchandle_newP15ScriptingObject($14)|0);
 $16 = (($this) + 4|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 20|0);
 HEAP32[$17>>2] = $8;
 $18 = (__Z19scripting_array_newP14ScriptingClassjj($12,4,$8)|0);
 $19 = (($this) + 12|0);
 HEAP32[$19>>2] = $18;
 $20 = (__Z22scripting_gchandle_newP15ScriptingObject($18)|0);
 $21 = (($this) + 16|0);
 HEAP32[$21>>2] = $20;
 STACKTOP = sp;return;
}
function __ZN24AudioScriptBufferManagerD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN24AudioScriptBufferManager15GetPCMReadArrayEjRP14ScriptingArray($this,$length,$array) {
 $this = $this|0;
 $length = $length|0;
 $array = $array|0;
 var $$count$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__Z21GetScriptingArraySizeP14ScriptingArray($0)|0);
 $2 = ($1|0)==($length|0);
 if ($2) {
  $12 = HEAP32[$this>>2]|0;
  $storemerge = $12;
  HEAP32[$array>>2] = $storemerge;
  STACKTOP = sp;return;
 } else {
  $3 = (__Z19GetScriptingManagerv()|0);
  $4 = (($3) + 208|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$this>>2]|0;
  $7 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($6,0,4)|0);
  $8 = ($7|0)==(0|0);
  $$count$i = $8 ? 0 : $length;
  $9 = (__Z19scripting_array_newP14ScriptingClassjj($5,4,$$count$i)|0);
  $10 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($9,0,4)|0);
  $11 = $$count$i << 2;
  _memcpy(($10|0),($7|0),($11|0))|0;
  $storemerge = $9;
  HEAP32[$array>>2] = $storemerge;
  STACKTOP = sp;return;
 }
}
function __ZN10AudioMixer13CleanupMemoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__Z15GetAudioManagerv()|0);
 $6 = (($5) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 28|0);
 __ZN5audio5mixer23DestroyAudioMixerMemoryEPNS0_16AudioMixerMemoryERKNS0_18AudioMixerConstantEPN4FMOD6SystemERN7mecanim6memory9AllocatorE($1,$4,$7,$8);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10AudioMixer18EnsureValidRuntimeEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  $7 = (($6) + 124|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (FUNCTION_TABLE_ii[$8 & 4095]($this)|0);
  HEAP32[$3>>2] = $9;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $22 = $9;
  }
 } else {
  $22 = $4;
 }
 $11 = (__Z15GetAudioManagerv()|0);
 $12 = (($11) + 92|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 28|0);
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 108|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($this)|0);
 $19 = (($this) + 88|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $23 = (__ZN5audio5mixer22CreateAudioMixerMemoryERKNS0_18AudioMixerConstantEPN4FMOD6SystemERN7mecanim6memory9AllocatorEib($22,$13,$14,$18,$21)|0);
 HEAP32[$0>>2] = $23;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + 112|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vi[$27 & 4095]($this);
 __ZN10AudioMixer14UpdateMuteSoloEv($this);
 $28 = HEAP32[$3>>2]|0;
 $29 = HEAP32[$0>>2]|0;
 __ZN5audio5mixer12UpdateBypassERNS0_18AudioMixerConstantERNS0_16AudioMixerMemoryE($28,$29);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10AudioMixer14UpdateMuteSoloEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $anyGroupSoloed$0$off07 = 0, $index$0$us = 0, $index$1 = 0, $n$08 = 0, $n1$05 = 0, $n1$05$us = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = $2;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($3) + ($4))|0;
 $6 = $5;
 $7 = (($1) + 8|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$0>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $anyGroupSoloed$0$off07 = 0;$n$08 = 0;
  while(1) {
   $23 = ((($6) + ($n$08<<4)|0) + 13|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24&255;
   $26 = $anyGroupSoloed$0$off07&1;
   $27 = $25 | $26;
   $28 = ($27|0)!=(0);
   $29 = (($n$08) + 1)|0;
   $30 = ($29>>>0)<($9>>>0);
   if ($30) {
    $anyGroupSoloed$0$off07 = $28;$n$08 = $29;
   } else {
    break;
   }
  }
  $phitmp = ($9|0)==(0);
  if (!($phitmp)) {
   $11 = (($this) + 64|0);
   if ($28) {
    $19 = $8;$n1$05$us = 0;
    while(1) {
     $index$0$us = $n1$05$us;
     while(1) {
      $12 = ((($6) + ($index$0$us<<4)|0) + 13|0);
      $13 = HEAP8[$12>>0]|0;
      $14 = ($13<<24>>24)==(0);
      if (!($14)) {
       break;
      }
      $15 = (($6) + ($index$0$us<<4)|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)>(-1);
      if ($17) {
       $index$0$us = $16;
      } else {
       break;
      }
     }
     $18 = HEAP32[$11>>2]|0;
     __ZN5audio5mixer21SetResultingMuteStateERKNS0_18AudioMixerConstantERKNS0_16AudioMixerMemoryEib($19,$18,$n1$05$us,$14);
     $$pre = HEAP32[$0>>2]|0;
     $20 = (($n1$05$us) + 1)|0;
     $21 = HEAP32[$$pre>>2]|0;
     $22 = ($20>>>0)<($21>>>0);
     if ($22) {
      $19 = $$pre;$n1$05$us = $20;
     } else {
      break;
     }
    }
   } else {
    $39 = $8;$n1$05 = 0;
    while(1) {
     $index$1 = $n1$05;
     while(1) {
      $31 = ((($6) + ($index$1<<4)|0) + 12|0);
      $32 = HEAP8[$31>>0]|0;
      $33 = ($32<<24>>24)==(0);
      if (!($33)) {
       break;
      }
      $34 = (($6) + ($index$1<<4)|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)>(-1);
      if ($36) {
       $index$1 = $35;
      } else {
       break;
      }
     }
     $37 = HEAP32[$11>>2]|0;
     $38 = ($32<<24>>24)!=(0);
     __ZN5audio5mixer21SetResultingMuteStateERKNS0_18AudioMixerConstantERKNS0_16AudioMixerMemoryEib($39,$37,$n1$05,$38);
     $$pre13 = HEAP32[$0>>2]|0;
     $40 = (($n1$05) + 1)|0;
     $41 = HEAP32[$$pre13>>2]|0;
     $42 = ($40>>>0)<($41>>>0);
     if ($42) {
      $39 = $$pre13;$n1$05 = $40;
     } else {
      break;
     }
    }
   }
  }
 }
 $43 = (__Z15GetAudioManagerv()|0);
 __ZN12AudioManager14OnMixerChangedEv($43);
 STACKTOP = sp;return;
}
function __ZN10AudioMixer11SetupGroupsEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $outputGroup$0 = 0, $phitmp$i = 0, $temp$0$i = 0, $temp$0$i10 = 0, $temp$0$i5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $0 = sp + 32|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = (__ZN10AudioMixer18EnsureValidRuntimeEv($this)|0);
 if (!($5)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(741840,0,741872,205,1,0,0,0);
  STACKTOP = sp;return;
 }
 $6 = (__Z15GetAudioManagerv()|0);
 $7 = (($6) + 104|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 80|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 do {
  if ($11) {
   $outputGroup$0 = $8;
  } else {
   HEAP32[$3>>2] = $10;
   $12 = HEAP32[560624>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    label = 12;
   } else {
    $14 = (($12) + 36|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($12) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($15|0)==($17|0);
    do {
     if ($18) {
      $19 = (($12) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($12) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $39 = $23;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$12,$3);
      $24 = HEAP32[$vararg_buffer>>2]|0;
      $25 = ($24|0)==(-1);
      $26 = (($12) + 28|0);
      $27 = HEAP32[$26>>2]|0;
      if ($25) {
       $28 = (($12) + 32|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($27) + ($29<<3)|0);
       $39 = $30;
       break;
      } else {
       $31 = (($27) + ($24<<3)|0);
       $39 = $31;
       break;
      }
     }
    } while(0);
    $32 = HEAP32[560624>>2]|0;
    $33 = (($32) + 28|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($32) + 32|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + ($36<<3)|0);
    $38 = ($39|0)==($37|0);
    if ($38) {
     label = 12;
    } else {
     $40 = (($39) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      label = 12;
     } else {
      $47 = $32;
     }
    }
   }
   if ((label|0) == 12) {
    $43 = HEAP32[$9>>2]|0;
    $44 = (__Z31ReadObjectFromPersistentManageri($43)|0);
    $phitmp$i = ($44|0)==(0|0);
    if ($phitmp$i) {
     $outputGroup$0 = $8;
     break;
    }
    $$pre16 = HEAP32[560624>>2]|0;
    $47 = $$pre16;
   }
   $45 = HEAP32[$9>>2]|0;
   HEAP32[$2>>2] = $45;
   $46 = ($47|0)==(0|0);
   if ($46) {
    label = 22;
   } else {
    $48 = (($47) + 36|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($47) + 4|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($49|0)==($51|0);
    do {
     if ($52) {
      $53 = (($47) + 28|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = (($47) + 32|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = (($54) + ($56<<3)|0);
      $73 = $57;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$47,$2);
      $58 = HEAP32[$vararg_buffer>>2]|0;
      $59 = ($58|0)==(-1);
      $60 = (($47) + 28|0);
      $61 = HEAP32[$60>>2]|0;
      if ($59) {
       $62 = (($47) + 32|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = (($61) + ($63<<3)|0);
       $73 = $64;
       break;
      } else {
       $65 = (($61) + ($58<<3)|0);
       $73 = $65;
       break;
      }
     }
    } while(0);
    $66 = HEAP32[560624>>2]|0;
    $67 = (($66) + 28|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + 32|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($68) + ($70<<3)|0);
    $72 = ($73|0)==($71|0);
    if ($72) {
     label = 22;
    } else {
     $74 = (($73) + 4|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = ($75|0)==(0|0);
     if ($76) {
      label = 22;
     } else {
      $82 = $66;$temp$0$i = $75;
     }
    }
   }
   if ((label|0) == 22) {
    $77 = HEAP32[$9>>2]|0;
    $78 = (__Z31ReadObjectFromPersistentManageri($77)|0);
    $$pre = HEAP32[560624>>2]|0;
    $82 = $$pre;$temp$0$i = $78;
   }
   $79 = (($temp$0$i) + 44|0);
   $80 = HEAP32[$79>>2]|0;
   HEAP32[$1>>2] = $80;
   $81 = ($82|0)==(0|0);
   if ($81) {
    label = 31;
   } else {
    $83 = (($82) + 36|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($82) + 4|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($84|0)==($86|0);
    do {
     if ($87) {
      $88 = (($82) + 28|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = (($82) + 32|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($89) + ($91<<3)|0);
      $108 = $92;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$82,$1);
      $93 = HEAP32[$vararg_buffer>>2]|0;
      $94 = ($93|0)==(-1);
      $95 = (($82) + 28|0);
      $96 = HEAP32[$95>>2]|0;
      if ($94) {
       $97 = (($82) + 32|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = (($96) + ($98<<3)|0);
       $108 = $99;
       break;
      } else {
       $100 = (($96) + ($93<<3)|0);
       $108 = $100;
       break;
      }
     }
    } while(0);
    $101 = HEAP32[560624>>2]|0;
    $102 = (($101) + 28|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($101) + 32|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($103) + ($105<<3)|0);
    $107 = ($108|0)==($106|0);
    if ($107) {
     label = 31;
    } else {
     $109 = (($108) + 4|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0|0);
     if ($111) {
      label = 31;
     } else {
      $115 = $101;$temp$0$i5 = $110;
     }
    }
   }
   if ((label|0) == 31) {
    $112 = (__Z31ReadObjectFromPersistentManageri($80)|0);
    $$pre15 = HEAP32[560624>>2]|0;
    $115 = $$pre15;$temp$0$i5 = $112;
   }
   $113 = HEAP32[$9>>2]|0;
   HEAP32[$0>>2] = $113;
   $114 = ($115|0)==(0|0);
   if ($114) {
    label = 40;
   } else {
    $116 = (($115) + 36|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = (($115) + 4|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($117|0)==($119|0);
    do {
     if ($120) {
      $121 = (($115) + 28|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = (($115) + 32|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = (($122) + ($124<<3)|0);
      $141 = $125;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$115,$0);
      $126 = HEAP32[$vararg_buffer>>2]|0;
      $127 = ($126|0)==(-1);
      $128 = (($115) + 28|0);
      $129 = HEAP32[$128>>2]|0;
      if ($127) {
       $130 = (($115) + 32|0);
       $131 = HEAP32[$130>>2]|0;
       $132 = (($129) + ($131<<3)|0);
       $141 = $132;
       break;
      } else {
       $133 = (($129) + ($126<<3)|0);
       $141 = $133;
       break;
      }
     }
    } while(0);
    $134 = HEAP32[560624>>2]|0;
    $135 = (($134) + 28|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = (($134) + 32|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = (($136) + ($138<<3)|0);
    $140 = ($141|0)==($139|0);
    if ($140) {
     label = 40;
    } else {
     $142 = (($141) + 4|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = ($143|0)==(0|0);
     if ($144) {
      label = 40;
     } else {
      $temp$0$i10 = $143;
     }
    }
   }
   if ((label|0) == 40) {
    $145 = HEAP32[$9>>2]|0;
    $146 = (__Z31ReadObjectFromPersistentManageri($145)|0);
    $temp$0$i10 = $146;
   }
   $147 = (__ZN10AudioMixer18EnsureValidRuntimeEv($temp$0$i5)|0);
   if ($147) {
    $148 = (($temp$0$i10) + 48|0);
    $149 = (($temp$0$i5) + 60|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = (($temp$0$i5) + 64|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = (__ZN5audio5mixer16FindChannelGroupERKNS0_18AudioMixerConstantERKNS0_16AudioMixerMemoryERK9UnityGUID($150,$152,$148)|0);
    $154 = ($153|0)==(0|0);
    if (!($154)) {
     $outputGroup$0 = $153;
     break;
    }
   } else {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(741840,0,741872,377,1,0,0,0);
   }
   $155 = HEAP32[$this>>2]|0;
   $156 = (($155) + 32|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (FUNCTION_TABLE_ii[$157 & 4095]($this)|0);
   HEAP32[$vararg_buffer>>2] = $158;
   __Z6FormatPKcz($4,741880,$vararg_buffer);
   $159 = HEAP8[$4>>0]|0;
   $160 = $159 & 1;
   $161 = ($160<<24>>24)==(0);
   if ($161) {
    $164 = (($4) + 1|0);
    $165 = $164;
   } else {
    $162 = (($4) + 8|0);
    $163 = HEAP32[$162>>2]|0;
    $165 = $163;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($165|0),0,(741872|0),217,1,0,0,(0|0));
   $166 = __THREW__; __THREW__ = 0;
   $167 = $166&1;
   if (!($167)) {
    $168 = HEAP8[$4>>0]|0;
    $169 = $168 & 1;
    $170 = ($169<<24>>24)==(0);
    if ($170) {
     $outputGroup$0 = $8;
     break;
    }
    $171 = (($4) + 8|0);
    $172 = HEAP32[$171>>2]|0;
    __ZdlPv($172);
    $outputGroup$0 = $8;
    break;
   }
   $173 = ___cxa_find_matching_catch()|0;
   $174 = tempRet0;
   $175 = HEAP8[$4>>0]|0;
   $176 = $175 & 1;
   $177 = ($176<<24>>24)==(0);
   if ($177) {
    ___resumeException($173|0);
    // unreachable;
   }
   $178 = (($4) + 8|0);
   $179 = HEAP32[$178>>2]|0;
   __ZdlPv($179);
   ___resumeException($173|0);
   // unreachable;
  }
 } while(0);
 $180 = (($this) + 60|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = (($this) + 64|0);
 $183 = HEAP32[$182>>2]|0;
 __ZN5audio5mixer17AssignOutputGroupERKNS0_18AudioMixerConstantERKNS0_16AudioMixerMemoryEPN4FMOD12ChannelGroupE($181,$183,$outputGroup$0);
 STACKTOP = sp;return;
}
function __ZN10AudioMixer19GetFMODChannelGroupERK9UnityGUID($this,$guid) {
 $this = $this|0;
 $guid = $guid|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN10AudioMixer18EnsureValidRuntimeEv($this)|0);
 if ($0) {
  $1 = (($this) + 60|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($this) + 64|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN5audio5mixer16FindChannelGroupERKNS0_18AudioMixerConstantERKNS0_16AudioMixerMemoryERK9UnityGUID($2,$4,$guid)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(741840,0,741872,377,1,0,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10AudioMixer16ResumeProcessingEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $pos$i$i$i$i1 = 0, $temp$0$i = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (__ZN10AudioMixer18EnsureValidRuntimeEv($this)|0);
 if (!($3)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(741840,0,741872,228,1,0,0,0);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN5audio5mixer12SetSuspendedERNS0_16AudioMixerMemoryEb($5,0);
 $6 = (($this) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $7;
 $9 = HEAP32[560624>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  label = 12;
 } else {
  $11 = (($9) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($9) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($12|0)==($14|0);
  do {
   if ($15) {
    $16 = (($9) + 28|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($9) + 32|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($17) + ($19<<3)|0);
    $36 = $20;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$9,$2);
    $21 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $22 = ($21|0)==(-1);
    $23 = (($9) + 28|0);
    $24 = HEAP32[$23>>2]|0;
    if ($22) {
     $25 = (($9) + 32|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($24) + ($26<<3)|0);
     $36 = $27;
     break;
    } else {
     $28 = (($24) + ($21<<3)|0);
     $36 = $28;
     break;
    }
   }
  } while(0);
  $29 = HEAP32[560624>>2]|0;
  $30 = (($29) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 32|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + ($33<<3)|0);
  $35 = ($36|0)==($34|0);
  if ($35) {
   label = 12;
  } else {
   $37 = (($36) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if ($39) {
    label = 12;
   } else {
    $44 = $29;
   }
  }
 }
 do {
  if ((label|0) == 12) {
   $40 = HEAP32[$6>>2]|0;
   $41 = (__Z31ReadObjectFromPersistentManageri($40)|0);
   $phitmp$i = ($41|0)==(0|0);
   if ($phitmp$i) {
    STACKTOP = sp;return;
   } else {
    $$pre8 = HEAP32[560624>>2]|0;
    $44 = $$pre8;
    break;
   }
  }
 } while(0);
 $42 = HEAP32[$6>>2]|0;
 HEAP32[$1>>2] = $42;
 $43 = ($44|0)==(0|0);
 if ($43) {
  label = 22;
 } else {
  $45 = (($44) + 36|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($44) + 4|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($46|0)==($48|0);
  do {
   if ($49) {
    $50 = (($44) + 28|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($44) + 32|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($51) + ($53<<3)|0);
    $70 = $54;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$44,$1);
    $55 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $56 = ($55|0)==(-1);
    $57 = (($44) + 28|0);
    $58 = HEAP32[$57>>2]|0;
    if ($56) {
     $59 = (($44) + 32|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (($58) + ($60<<3)|0);
     $70 = $61;
     break;
    } else {
     $62 = (($58) + ($55<<3)|0);
     $70 = $62;
     break;
    }
   }
  } while(0);
  $63 = HEAP32[560624>>2]|0;
  $64 = (($63) + 28|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = (($63) + 32|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($65) + ($67<<3)|0);
  $69 = ($70|0)==($68|0);
  if ($69) {
   label = 22;
  } else {
   $71 = (($70) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0|0);
   if ($73) {
    label = 22;
   } else {
    $79 = $63;$temp$0$i = $72;
   }
  }
 }
 if ((label|0) == 22) {
  $74 = HEAP32[$6>>2]|0;
  $75 = (__Z31ReadObjectFromPersistentManageri($74)|0);
  $$pre = HEAP32[560624>>2]|0;
  $79 = $$pre;$temp$0$i = $75;
 }
 $76 = (($temp$0$i) + 44|0);
 $77 = HEAP32[$76>>2]|0;
 HEAP32[$0>>2] = $77;
 $78 = ($79|0)==(0|0);
 if ($78) {
  label = 31;
 } else {
  $80 = (($79) + 36|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($79) + 4|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = ($81|0)==($83|0);
  do {
   if ($84) {
    $85 = (($79) + 28|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($79) + 32|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = (($86) + ($88<<3)|0);
    $105 = $89;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$79,$0);
    $90 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $91 = ($90|0)==(-1);
    $92 = (($79) + 28|0);
    $93 = HEAP32[$92>>2]|0;
    if ($91) {
     $94 = (($79) + 32|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = (($93) + ($95<<3)|0);
     $105 = $96;
     break;
    } else {
     $97 = (($93) + ($90<<3)|0);
     $105 = $97;
     break;
    }
   }
  } while(0);
  $98 = HEAP32[560624>>2]|0;
  $99 = (($98) + 28|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($98) + 32|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($100) + ($102<<3)|0);
  $104 = ($105|0)==($103|0);
  if ($104) {
   label = 31;
  } else {
   $106 = (($105) + 4|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($107|0)==(0|0);
   if ($108) {
    label = 31;
   } else {
    $temp$0$i5 = $107;
   }
  }
 }
 if ((label|0) == 31) {
  $109 = (__Z31ReadObjectFromPersistentManageri($77)|0);
  $temp$0$i5 = $109;
 }
 __ZN10AudioMixer16ResumeProcessingEv($temp$0$i5);
 STACKTOP = sp;return;
}
function __ZN10AudioMixer6UpdateEf($this,$deltaTime) {
 $this = $this|0;
 $deltaTime = Math_fround($deltaTime);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN10AudioMixer18EnsureValidRuntimeEv($this)|0);
 if ($0) {
  $1 = (($this) + 84|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $3 = Math_fround($2 * Math_fround(0.100000001490116119385));
  $4 = (Math_fround(+(_log2f(10.0))));
  $5 = Math_fround($4 * $3);
  $6 = (Math_fround(+(_exp2f((+$5)))));
  $7 = (($this) + 60|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 64|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__Z15GetAudioManagerv()|0);
  $12 = (($11) + 92|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 88|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)!=(0);
  $17 = $16 ? $6 : Math_fround(0.0);
  __ZN5audio5mixer22UpdateAudioMixerMemoryERKNS0_18AudioMixerConstantERNS0_16AudioMixerMemoryEfPN4FMOD6SystemEf($8,$10,$deltaTime,$13,$17);
  STACKTOP = sp;return;
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(741840,0,741872,306,1,0,0,0);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $i$08 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i3 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i3;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i6 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i6;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $41 = (($28) + 4|0);
  HEAP32[$41>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 2;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $39 = 0;
  } else {
   $36 = $34;
   $37 = $28;
   $38 = (($36) - ($37))|0;
   $39 = $38;
  }
  HEAP32[$28>>2] = $39;
  $40 = (($28) + 4|0);
  HEAP32[$40>>2] = $34;
 }
 $42 = HEAP32[$data>>2]|0;
 $43 = $42;
 $44 = HEAP32[$42>>2]|0;
 $45 = (($44) + ($43))|0;
 $46 = $45;
 $47 = (($42) + 4|0);
 HEAP32[$47>>2] = $46;
 $48 = HEAP32[$25>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($46) + ($49<<2)|0);
 $51 = HEAP32[$data>>2]|0;
 $52 = $51;
 $53 = HEAP32[$51>>2]|0;
 $54 = (($53) + ($52))|0;
 $55 = $54;
 $56 = (($51) + 4|0);
 HEAP32[$56>>2] = $55;
 $57 = ($55|0)==($50|0);
 if ($57) {
  STACKTOP = sp;return;
 } else {
  $i$08 = $55;
 }
 while(1) {
  $58 = HEAP32[$1>>2]|0;
  $59 = (($58) + 4|0);
  $60 = HEAP32[$7>>2]|0;
  $61 = ($59>>>0)>($60>>>0);
  if ($61) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$08,4);
   $$pre$i$i$i = HEAP32[$i$08>>2]|0;
   $63 = $$pre$i$i$i;
  } else {
   $62 = HEAP32[$58>>2]|0;
   HEAP32[$i$08>>2] = $62;
   HEAP32[$1>>2] = $59;
   $63 = $62;
  }
  $64 = (_llvm_bswap_i32(($63|0))|0);
  HEAP32[$i$08>>2] = $64;
  $65 = (($i$08) + 4|0);
  $66 = ($65|0)==($50|0);
  if ($66) {
   break;
  } else {
   $i$08 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $i$07 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $41 = (($28) + 4|0);
  HEAP32[$41>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 2;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $39 = 0;
  } else {
   $36 = $34;
   $37 = $28;
   $38 = (($36) - ($37))|0;
   $39 = $38;
  }
  HEAP32[$28>>2] = $39;
  $40 = (($28) + 4|0);
  HEAP32[$40>>2] = $34;
 }
 $42 = HEAP32[$data>>2]|0;
 $43 = $42;
 $44 = HEAP32[$42>>2]|0;
 $45 = (($44) + ($43))|0;
 $46 = $45;
 $47 = (($42) + 4|0);
 HEAP32[$47>>2] = $46;
 $48 = HEAP32[$25>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($46) + ($49<<2)|0);
 $51 = HEAP32[$data>>2]|0;
 $52 = $51;
 $53 = HEAP32[$51>>2]|0;
 $54 = (($53) + ($52))|0;
 $55 = $54;
 $56 = (($51) + 4|0);
 HEAP32[$56>>2] = $55;
 $57 = ($55|0)==($50|0);
 if ($57) {
  STACKTOP = sp;return;
 } else {
  $i$07 = $55;
 }
 while(1) {
  $58 = HEAP32[$1>>2]|0;
  $59 = (($58) + 4|0);
  $60 = HEAP32[$7>>2]|0;
  $61 = ($59>>>0)>($60>>>0);
  if ($61) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$07,4);
   $$pre$i$i$i = HEAP32[$i$07>>2]|0;
   $$pre$phi$i$i$iZ2D = $i$07;$64 = $$pre$i$i$i;
  } else {
   $62 = Math_fround(HEAPF32[$58>>2]);
   HEAPF32[$i$07>>2] = $62;
   HEAP32[$1>>2] = $59;
   $63 = (HEAPF32[tempDoublePtr>>2]=$62,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$iZ2D = $i$07;$64 = $63;
  }
  $65 = (_llvm_bswap_i32(($64|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $65;
  $66 = (($i$07) + 4|0);
  $67 = ($66|0)==($50|0);
  if ($67) {
   break;
  } else {
   $i$07 = $66;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre4 = HEAP32[$1>>2]|0;
   $$pre5 = HEAP32[$7>>2]|0;
   $12 = $$pre4;$14 = $$pre5;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre6 = HEAP32[$offset>>2]|0;
   $18 = $$pre6;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $37 = (($24) + 4|0);
  HEAP32[$37>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 2;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $35 = 0;
  } else {
   $32 = $30;
   $33 = $24;
   $34 = (($32) - ($33))|0;
   $35 = $34;
  }
  HEAP32[$24>>2] = $35;
  $36 = (($24) + 4|0);
  HEAP32[$36>>2] = $30;
 }
 $38 = HEAP32[$size1>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$data>>2]|0;
 $41 = $40;
 $42 = HEAP32[$40>>2]|0;
 $43 = (($42) + ($41))|0;
 $44 = $43;
 $45 = (($40) + 4|0);
 HEAP32[$45>>2] = $44;
 $46 = $43;
 $47 = $38 << 2;
 __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$46,$47);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre4 = HEAP32[$1>>2]|0;
   $$pre5 = HEAP32[$7>>2]|0;
   $12 = $$pre4;$14 = $$pre5;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre6 = HEAP32[$offset>>2]|0;
   $18 = $$pre6;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $37 = (($24) + 4|0);
  HEAP32[$37>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 2;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $35 = 0;
  } else {
   $32 = $30;
   $33 = $24;
   $34 = (($32) - ($33))|0;
   $35 = $34;
  }
  HEAP32[$24>>2] = $35;
  $36 = (($24) + 4|0);
  HEAP32[$36>>2] = $30;
 }
 $38 = HEAP32[$size1>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$data>>2]|0;
 $41 = $40;
 $42 = HEAP32[$40>>2]|0;
 $43 = (($42) + ($41))|0;
 $44 = $43;
 $45 = (($40) + 4|0);
 HEAP32[$45>>2] = $44;
 $46 = $43;
 $47 = $38 << 2;
 __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$46,$47);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$03 = 0, $i$15 = 0, $size = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,741976,741976,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $22 = (($9) + 4|0);
  HEAP32[$22>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 2;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $20 = 0;
  } else {
   $17 = $15;
   $18 = $9;
   $19 = (($17) - ($18))|0;
   $20 = $19;
  }
  HEAP32[$9>>2] = $20;
  $21 = (($9) + 4|0);
  HEAP32[$21>>2] = $15;
 }
 $23 = HEAP32[$data>>2]|0;
 $24 = $23;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = $26;
 $28 = (($23) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[$2>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($27) + ($30<<2)|0);
 $32 = HEAP32[$size>>2]|0;
 $33 = ($32|0)==(0);
 L11: do {
  if (!($33)) {
   $34 = HEAP32[$data>>2]|0;
   $35 = $34;
   $36 = HEAP32[$34>>2]|0;
   $37 = (($36) + ($35))|0;
   $38 = $37;
   $39 = (($34) + 4|0);
   HEAP32[$39>>2] = $38;
   $40 = HEAP32[580752>>2]|0;
   $41 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,741968,$40,0,0)|0);
   $42 = (($this) + 80|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__ZNK16TypeTreeIterator7GetNodeEv($43)|0);
   $45 = (($44) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($this) + 84|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$48>>2] = 0;
   $49 = ($41|0)==(2);
   if (!($49)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $106 = HEAP32[$data>>2]|0;
    $107 = $106;
    $108 = HEAP32[$106>>2]|0;
    $109 = (($108) + ($107))|0;
    $110 = $109;
    $111 = (($106) + 4|0);
    HEAP32[$111>>2] = $110;
    $112 = ($110|0)==($31|0);
    if ($112) {
     break;
    } else {
     $i$15 = $110;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$i$15,741968,0);
     $113 = (($i$15) + 4|0);
     $114 = ($113|0)==($31|0);
     if ($114) {
      break L11;
     } else {
      $i$15 = $113;
     }
    }
   }
   $50 = HEAP32[$42>>2]|0;
   $51 = (($50) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$data>>2]|0;
   $54 = $53;
   $55 = HEAP32[$53>>2]|0;
   $56 = (($55) + ($54))|0;
   $57 = $56;
   $58 = (($53) + 4|0);
   HEAP32[$58>>2] = $57;
   $59 = ($57|0)==($31|0);
   if (!($59)) {
    $60 = (($this) + 12|0);
    $61 = (($this) + 16|0);
    $62 = (($this) + 28|0);
    $63 = (($this) + 32|0);
    $64 = (($this) + 20|0);
    $i$03 = $57;
    while(1) {
     $65 = HEAP32[$47>>2]|0;
     $66 = HEAP32[$65>>2]|0;
     $67 = Math_imul($66, $46)|0;
     $68 = (($67) + ($52))|0;
     $69 = HEAP32[$42>>2]|0;
     $70 = (($69) + 20|0);
     HEAP32[$70>>2] = $68;
     $71 = (($69) + 12|0);
     HEAP32[$71>>2] = $68;
     $72 = (($69) + 24|0);
     __ZNK16TypeTreeIterator8ChildrenEv($1,$69);
     $73 = $1;
     $74 = $73;
     $75 = HEAP32[$74>>2]|0;
     $76 = (($73) + 4)|0;
     $77 = $76;
     $78 = HEAP32[$77>>2]|0;
     $79 = $72;
     $80 = $79;
     HEAP32[$80>>2] = $75;
     $81 = (($79) + 4)|0;
     $82 = $81;
     HEAP32[$82>>2] = $78;
     $83 = HEAP32[$47>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = (($84) + 1)|0;
     HEAP32[$83>>2] = $85;
     $86 = HEAP32[$42>>2]|0;
     $87 = (($86) + 12|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = HEAP32[$61>>2]|0;
     $90 = HEAP32[$62>>2]|0;
     $91 = HEAP32[$63>>2]|0;
     $92 = Math_imul($91, $90)|0;
     $$sum$i$i$i = (($88) - ($92))|0;
     $93 = (($89) + ($$sum$i$i$i)|0);
     HEAP32[$60>>2] = $93;
     $94 = ($$sum$i$i$i|0)<(0);
     if ($94) {
      label = 14;
     } else {
      $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
      $95 = (($89) + ($$sum1$i$i$i)|0);
      $96 = HEAP32[$64>>2]|0;
      $97 = ($95>>>0)>($96>>>0);
      if ($97) {
       label = 14;
      } else {
       $98 = HEAP32[$93>>2]|0;
       HEAP32[$i$03>>2] = $98;
       HEAP32[$60>>2] = $95;
      }
     }
     if ((label|0) == 14) {
      label = 0;
      __ZN12CachedReader15UpdateReadCacheEPvj($60,$i$03,4);
     }
     $99 = HEAP32[$this>>2]|0;
     $100 = $99 & 512;
     $101 = ($100|0)==(0);
     if (!($101)) {
      $102 = HEAP32[$i$03>>2]|0;
      $103 = (_llvm_bswap_i32(($102|0))|0);
      HEAP32[$i$03>>2] = $103;
     }
     $104 = (($i$03) + 4|0);
     $105 = ($104|0)==($31|0);
     if ($105) {
      break;
     } else {
      $i$03 = $104;
     }
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $i$03 = 0, $i$15 = 0, $size = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,741976,741976,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $22 = (($9) + 4|0);
  HEAP32[$22>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 2;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $20 = 0;
  } else {
   $17 = $15;
   $18 = $9;
   $19 = (($17) - ($18))|0;
   $20 = $19;
  }
  HEAP32[$9>>2] = $20;
  $21 = (($9) + 4|0);
  HEAP32[$21>>2] = $15;
 }
 $23 = HEAP32[$data>>2]|0;
 $24 = $23;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = $26;
 $28 = (($23) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[$2>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($27) + ($30<<2)|0);
 $32 = HEAP32[$size>>2]|0;
 $33 = ($32|0)==(0);
 L11: do {
  if (!($33)) {
   $34 = HEAP32[$data>>2]|0;
   $35 = $34;
   $36 = HEAP32[$34>>2]|0;
   $37 = (($36) + ($35))|0;
   $38 = $37;
   $39 = (($34) + 4|0);
   HEAP32[$39>>2] = $38;
   $40 = HEAP32[580584>>2]|0;
   $41 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,741968,$40,0,0)|0);
   $42 = (($this) + 80|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__ZNK16TypeTreeIterator7GetNodeEv($43)|0);
   $45 = (($44) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($this) + 84|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$48>>2] = 0;
   $49 = ($41|0)==(2);
   if (!($49)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $106 = HEAP32[$data>>2]|0;
    $107 = $106;
    $108 = HEAP32[$106>>2]|0;
    $109 = (($108) + ($107))|0;
    $110 = $109;
    $111 = (($106) + 4|0);
    HEAP32[$111>>2] = $110;
    $112 = ($110|0)==($31|0);
    if ($112) {
     break;
    } else {
     $i$15 = $110;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$15,741968,0);
     $113 = (($i$15) + 4|0);
     $114 = ($113|0)==($31|0);
     if ($114) {
      break L11;
     } else {
      $i$15 = $113;
     }
    }
   }
   $50 = HEAP32[$42>>2]|0;
   $51 = (($50) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$data>>2]|0;
   $54 = $53;
   $55 = HEAP32[$53>>2]|0;
   $56 = (($55) + ($54))|0;
   $57 = $56;
   $58 = (($53) + 4|0);
   HEAP32[$58>>2] = $57;
   $59 = ($57|0)==($31|0);
   if (!($59)) {
    $60 = (($this) + 12|0);
    $61 = (($this) + 16|0);
    $62 = (($this) + 28|0);
    $63 = (($this) + 32|0);
    $64 = (($this) + 20|0);
    $i$03 = $57;
    while(1) {
     $65 = HEAP32[$47>>2]|0;
     $66 = HEAP32[$65>>2]|0;
     $67 = Math_imul($66, $46)|0;
     $68 = (($67) + ($52))|0;
     $69 = HEAP32[$42>>2]|0;
     $70 = (($69) + 20|0);
     HEAP32[$70>>2] = $68;
     $71 = (($69) + 12|0);
     HEAP32[$71>>2] = $68;
     $72 = (($69) + 24|0);
     __ZNK16TypeTreeIterator8ChildrenEv($1,$69);
     $73 = $1;
     $74 = $73;
     $75 = HEAP32[$74>>2]|0;
     $76 = (($73) + 4)|0;
     $77 = $76;
     $78 = HEAP32[$77>>2]|0;
     $79 = $72;
     $80 = $79;
     HEAP32[$80>>2] = $75;
     $81 = (($79) + 4)|0;
     $82 = $81;
     HEAP32[$82>>2] = $78;
     $83 = HEAP32[$47>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = (($84) + 1)|0;
     HEAP32[$83>>2] = $85;
     $86 = HEAP32[$42>>2]|0;
     $87 = (($86) + 12|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = HEAP32[$61>>2]|0;
     $90 = HEAP32[$62>>2]|0;
     $91 = HEAP32[$63>>2]|0;
     $92 = Math_imul($91, $90)|0;
     $$sum$i$i$i = (($88) - ($92))|0;
     $93 = (($89) + ($$sum$i$i$i)|0);
     HEAP32[$60>>2] = $93;
     $94 = ($$sum$i$i$i|0)<(0);
     if ($94) {
      label = 14;
     } else {
      $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
      $95 = (($89) + ($$sum1$i$i$i)|0);
      $96 = HEAP32[$64>>2]|0;
      $97 = ($95>>>0)>($96>>>0);
      if ($97) {
       label = 14;
      } else {
       $98 = Math_fround(HEAPF32[$93>>2]);
       HEAPF32[$i$03>>2] = $98;
       HEAP32[$60>>2] = $95;
      }
     }
     if ((label|0) == 14) {
      label = 0;
      __ZN12CachedReader15UpdateReadCacheEPvj($60,$i$03,4);
     }
     $99 = HEAP32[$this>>2]|0;
     $100 = $99 & 512;
     $101 = ($100|0)==(0);
     if (!($101)) {
      $102 = HEAP32[$i$03>>2]|0;
      $103 = (_llvm_bswap_i32(($102|0))|0);
      HEAP32[$i$03>>2] = $103;
     }
     $104 = (($i$03) + 4|0);
     $105 = ($104|0)==($31|0);
     if ($105) {
      break;
     } else {
      $i$03 = $104;
     }
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim6memory16MecanimAllocator8AllocateEjj($this,$size,$align) {
 $this = $this|0;
 $size = $size|0;
 $align = $align|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Z15malloc_internaljj10MemLabelIdiPKci($size,$align,$$byval_copy,0,741872,395)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN7mecanim6memory16MecanimAllocator10DeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($p,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN5audio5mixer22CreateAudioMixerMemoryERKNS0_18AudioMixerConstantEPN4FMOD6SystemERN7mecanim6memory9AllocatorEib($constant,$system,$alloc,$snapshotIndex,$enableSuspend) {
 $constant = $constant|0;
 $system = $system|0;
 $alloc = $alloc|0;
 $snapshotIndex = $snapshotIndex|0;
 $enableSuspend = $enableSuspend|0;
 var $$ = 0, $$$i = 0, $$0 = 0, $$0$i = 0, $$0$i10 = 0, $$0$i12 = 0, $$0$i15 = 0, $$0$i2 = 0, $$0$i3 = 0, $$0$i6 = 0, $$0$i7 = 0, $$0$i8 = 0, $$01 = 0, $$014$i = 0, $$014$i$i = 0, $$101 = 0, $$off = 0, $$pre = 0, $$pre87 = 0, $$pre88 = 0;
 var $$pre89 = 0, $$pre90 = 0, $$pre91 = 0, $$pre92 = 0, $$type$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0);
 var $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = Math_fround(0), $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dspBlockSize = 0, $dspInput = 0, $dspOutput = 0, $effectName$0$lcssa$i = 0, $effectName$0$lcssa$i$i = 0, $effectName$05$i = 0, $effectName$05$i$i = 0, $effectdef = 0, $effectdef14 = 0;
 var $effectdef19 = 0, $effectdef24 = 0, $effectdef34 = 0, $group = 0, $i$075 = 0, $i32$049 = 0, $i38$044 = 0, $i42$040 = 0, $i43$037 = 0, $i44$034 = 0, $i46$033 = 0, $i6$072 = 0, $i8$066 = 0, $i9$057 = 0, $internalDef = 0, $internalDef15 = 0, $internalDef20 = 0, $internalDef25 = 0, $internalDef35 = 0, $maxSpeakers = 0;
 var $n$02$i = 0, $n$02$i$i = 0, $nameBlob$076 = 0, $numDefs$i = 0, $numDefs$i$i = 0, $phitmp = 0, $phitmp100 = 0, $sampleRate = 0, $sideChainPtr$068 = 0, $sideChainPtr$1 = 0, $switch = 0, $type$off$i = 0, $vararg_buffer142 = 0, $vararg_ptr1 = 0, $vararg_ptr100 = 0, $vararg_ptr101 = 0, $vararg_ptr102 = 0, $vararg_ptr109 = 0, $vararg_ptr110 = 0, $vararg_ptr111 = 0;
 var $vararg_ptr115 = 0, $vararg_ptr116 = 0, $vararg_ptr117 = 0, $vararg_ptr121 = 0, $vararg_ptr122 = 0, $vararg_ptr123 = 0, $vararg_ptr127 = 0, $vararg_ptr128 = 0, $vararg_ptr129 = 0, $vararg_ptr13 = 0, $vararg_ptr133 = 0, $vararg_ptr134 = 0, $vararg_ptr135 = 0, $vararg_ptr139 = 0, $vararg_ptr14 = 0, $vararg_ptr140 = 0, $vararg_ptr141 = 0, $vararg_ptr145 = 0, $vararg_ptr146 = 0, $vararg_ptr147 = 0;
 var $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr2 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0, $vararg_ptr25 = 0, $vararg_ptr26 = 0, $vararg_ptr27 = 0, $vararg_ptr3 = 0, $vararg_ptr31 = 0, $vararg_ptr32 = 0, $vararg_ptr33 = 0, $vararg_ptr37 = 0, $vararg_ptr38 = 0, $vararg_ptr39 = 0, $vararg_ptr43 = 0, $vararg_ptr44 = 0, $vararg_ptr45 = 0, $vararg_ptr49 = 0, $vararg_ptr50 = 0;
 var $vararg_ptr51 = 0, $vararg_ptr55 = 0, $vararg_ptr56 = 0, $vararg_ptr57 = 0, $vararg_ptr61 = 0, $vararg_ptr62 = 0, $vararg_ptr63 = 0, $vararg_ptr67 = 0, $vararg_ptr68 = 0, $vararg_ptr69 = 0, $vararg_ptr7 = 0, $vararg_ptr73 = 0, $vararg_ptr74 = 0, $vararg_ptr75 = 0, $vararg_ptr79 = 0, $vararg_ptr8 = 0, $vararg_ptr80 = 0, $vararg_ptr81 = 0, $vararg_ptr85 = 0, $vararg_ptr86 = 0;
 var $vararg_ptr87 = 0, $vararg_ptr9 = 0, $vararg_ptr91 = 0, $vararg_ptr92 = 0, $vararg_ptr93 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 688|0;
 $vararg_buffer142 = sp + 520|0;
 $numDefs$i = sp + 660|0;
 $numDefs$i$i = sp + 656|0;
 $sampleRate = sp + 652|0;
 $maxSpeakers = sp + 648|0;
 $dspBlockSize = sp + 644|0;
 $group = sp + 640|0;
 $effectdef = sp + 104|0;
 $internalDef = sp + 624|0;
 $effectdef14 = sp + 312|0;
 $internalDef15 = sp + 664|0;
 $effectdef19 = sp;
 $internalDef20 = sp + 536|0;
 $effectdef24 = sp + 416|0;
 $internalDef25 = sp + 608|0;
 $0 = sp + 556|0;
 $1 = sp + 568|0;
 $effectdef34 = sp + 208|0;
 $internalDef35 = sp + 584|0;
 $dspInput = sp + 600|0;
 $dspOutput = sp + 552|0;
 $2 = (($constant) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 $5 = ($snapshotIndex|0)<(0);
 if ($5) {
  $$0$i = 0;
 } else {
  $6 = ($4|0)<($snapshotIndex|0);
  $$$i = $6 ? $4 : $snapshotIndex;
  $$0$i = $$$i;
 }
 $7 = (($constant) + 52|0);
 $8 = $7;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$alloc>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_iiii[$15 & 2047]($alloc,80,4)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  $26 = 0;
 } else {
  $26 = $16;
 }
 $18 = HEAP32[$constant>>2]|0;
 $19 = ($18|0)==(0);
 if ($19) {
  $$0$i2 = 0;
 } else {
  $20 = HEAP32[$alloc>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = $18 << 8;
  $23 = (FUNCTION_TABLE_iiii[$21 & 2047]($alloc,$22,4)|0);
  $24 = ($23|0)==(0|0);
  if ($24) {
   $$0$i2 = 0;
  } else {
   $$0$i2 = $23;
  }
 }
 $25 = (($26) + 8|0);
 HEAP32[$25>>2] = $$0$i2;
 $27 = HEAP32[$constant>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  $$0$i3 = 0;
 } else {
  $29 = HEAP32[$alloc>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = $27 << 8;
  $32 = (FUNCTION_TABLE_iiii[$30 & 2047]($alloc,$31,4)|0);
  $33 = ($32|0)==(0|0);
  if ($33) {
   $$0$i3 = 0;
  } else {
   $$0$i3 = $32;
  }
 }
 $34 = (($26) + 12|0);
 HEAP32[$34>>2] = $$0$i3;
 $35 = HEAP32[$constant>>2]|0;
 $36 = ($35|0)==(0);
 if ($36) {
  HEAP32[$26>>2] = 0;
  $$0$i6 = 0;$103 = $26;$47 = 0;
 } else {
  $37 = HEAP32[$alloc>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  $39 = $35 << 2;
  $40 = (FUNCTION_TABLE_iiii[$38 & 2047]($alloc,$39,4)|0);
  $$pre = HEAP32[$constant>>2]|0;
  HEAP32[$26>>2] = $40;
  $41 = ($$pre|0)==(0);
  if ($41) {
   $$0$i6 = 0;$103 = $26;$47 = 0;
  } else {
   $42 = HEAP32[$alloc>>2]|0;
   $43 = HEAP32[$42>>2]|0;
   $44 = $$pre << 2;
   $45 = (FUNCTION_TABLE_iiii[$43 & 2047]($alloc,$44,4)|0);
   $$pre87 = HEAP32[$constant>>2]|0;
   $phitmp = $$pre87 << 2;
   $$0$i6 = $45;$103 = $26;$47 = $phitmp;
  }
 }
 $46 = (($26) + 4|0);
 HEAP32[$46>>2] = $$0$i6;
 _memset(($$0$i6|0),0,($47|0))|0;
 $48 = HEAP32[$25>>2]|0;
 $49 = HEAP32[$constant>>2]|0;
 $50 = $49 << 8;
 _memset(($48|0),0,($50|0))|0;
 $51 = HEAP32[$34>>2]|0;
 $52 = HEAP32[$constant>>2]|0;
 $53 = $52 << 8;
 _memset(($51|0),0,($53|0))|0;
 $54 = (($constant) + 20|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0);
 if ($56) {
  $$0$i7 = 0;
 } else {
  $57 = HEAP32[$alloc>>2]|0;
  $58 = HEAP32[$57>>2]|0;
  $59 = $55 << 5;
  $60 = (FUNCTION_TABLE_iiii[$58 & 2047]($alloc,$59,4)|0);
  $61 = ($60|0)==(0|0);
  if ($61) {
   $$0$i7 = 0;
  } else {
   $$0$i7 = $60;
  }
 }
 $62 = (($26) + 16|0);
 HEAP32[$62>>2] = $$0$i7;
 $63 = HEAP32[$54>>2]|0;
 $64 = $63 << 5;
 _memset(($$0$i7|0),0,($64|0))|0;
 $65 = HEAP32[$constant>>2]|0;
 $66 = ($65|0)==(0);
 if ($66) {
  $$0$i8 = 0;$71 = 0;
 } else {
  $67 = HEAP32[$alloc>>2]|0;
  $68 = HEAP32[$67>>2]|0;
  $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($alloc,$65,1)|0);
  $$pre88 = HEAP32[$constant>>2]|0;
  $$0$i8 = $69;$71 = $$pre88;
 }
 $70 = (($26) + 64|0);
 HEAP32[$70>>2] = $$0$i8;
 _memset(($$0$i8|0),0,($71|0))|0;
 $72 = (($26) + 76|0);
 HEAP32[$72>>2] = $constant;
 $73 = (($26) + 68|0);
 $74 = (__ZN4FMOD6System18createChannelGroupEPKcPPNS_12ChannelGroupE($system,742000,$73)|0);
 $75 = ($74|0)==(0);
 if (!($75)) {
  $76 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($74)|0);
  HEAP32[$vararg_buffer142>>2] = 742056;
  $vararg_ptr1 = (($vararg_buffer142) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 204;
  $vararg_ptr2 = (($vararg_buffer142) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $76;
  $vararg_ptr3 = (($vararg_buffer142) + 12|0);
  HEAP32[$vararg_ptr3>>2] = $74;
  _printf_console(742016,$vararg_buffer142);
 }
 $77 = HEAP32[$73>>2]|0;
 $78 = (__ZN4FMOD12ChannelGroup7setMuteEb($77,1)|0);
 $79 = ($78|0)==(0);
 if (!($79)) {
  $80 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($78)|0);
  HEAP32[$vararg_buffer142>>2] = 742056;
  $vararg_ptr7 = (($vararg_buffer142) + 4|0);
  HEAP32[$vararg_ptr7>>2] = 205;
  $vararg_ptr8 = (($vararg_buffer142) + 8|0);
  HEAP32[$vararg_ptr8>>2] = $80;
  $vararg_ptr9 = (($vararg_buffer142) + 12|0);
  HEAP32[$vararg_ptr9>>2] = $78;
  _printf_console(742016,$vararg_buffer142);
 }
 HEAP32[$sampleRate>>2] = 48000;
 HEAP32[$maxSpeakers>>2] = 8;
 $81 = (__ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($system,$sampleRate,0,$maxSpeakers,0,0,0)|0);
 $82 = ($81|0)==(0);
 if (!($82)) {
  $83 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($81)|0);
  HEAP32[$vararg_buffer142>>2] = 742056;
  $vararg_ptr13 = (($vararg_buffer142) + 4|0);
  HEAP32[$vararg_ptr13>>2] = 209;
  $vararg_ptr14 = (($vararg_buffer142) + 8|0);
  HEAP32[$vararg_ptr14>>2] = $83;
  $vararg_ptr15 = (($vararg_buffer142) + 12|0);
  HEAP32[$vararg_ptr15>>2] = $81;
  _printf_console(742016,$vararg_buffer142);
 }
 HEAP32[$dspBlockSize>>2] = 0;
 $84 = (__ZN4FMOD6System16getDSPBufferSizeEPjPi($system,$dspBlockSize,0)|0);
 $85 = ($84|0)==(0);
 if (!($85)) {
  $86 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($84)|0);
  HEAP32[$vararg_buffer142>>2] = 742056;
  $vararg_ptr19 = (($vararg_buffer142) + 4|0);
  HEAP32[$vararg_ptr19>>2] = 212;
  $vararg_ptr20 = (($vararg_buffer142) + 8|0);
  HEAP32[$vararg_ptr20>>2] = $86;
  $vararg_ptr21 = (($vararg_buffer142) + 12|0);
  HEAP32[$vararg_ptr21>>2] = $84;
  _printf_console(742016,$vararg_buffer142);
 }
 $87 = (($constant) + 72|0);
 $88 = HEAP32[$constant>>2]|0;
 $89 = ($88|0)==(0);
 if (!($89)) {
  $90 = HEAP32[$87>>2]|0;
  $91 = $87;
  $92 = (($90) + ($91))|0;
  $93 = $92;
  $i$075 = 0;$nameBlob$076 = $93;
  while(1) {
   HEAP32[$group>>2] = 0;
   $94 = HEAP32[$34>>2]|0;
   $95 = ((($94) + ($i$075<<8)|0) + 28|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = $96 | 1;
   HEAP32[$95>>2] = $97;
   $98 = (__ZN4FMOD6System18createChannelGroupEPKcPPNS_12ChannelGroupE($system,$nameBlob$076,$group)|0);
   $99 = ($98|0)==(0);
   if (!($99)) {
    $100 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($98)|0);
    HEAP32[$vararg_buffer142>>2] = 742056;
    $vararg_ptr25 = (($vararg_buffer142) + 4|0);
    HEAP32[$vararg_ptr25>>2] = 231;
    $vararg_ptr26 = (($vararg_buffer142) + 8|0);
    HEAP32[$vararg_ptr26>>2] = $100;
    $vararg_ptr27 = (($vararg_buffer142) + 12|0);
    HEAP32[$vararg_ptr27>>2] = $98;
    _printf_console(742016,$vararg_buffer142);
   }
   $101 = HEAP32[$group>>2]|0;
   $102 = HEAP32[$103>>2]|0;
   $104 = (($102) + ($i$075<<2)|0);
   HEAP32[$104>>2] = $101;
   $105 = (_strlen(($nameBlob$076|0))|0);
   $106 = (($105) + 1)|0;
   $107 = (($nameBlob$076) + ($106)|0);
   $108 = (($i$075) + 1)|0;
   $109 = HEAP32[$constant>>2]|0;
   $110 = ($108>>>0)<($109>>>0);
   if ($110) {
    $i$075 = $108;$nameBlob$076 = $107;
   } else {
    break;
   }
  }
 }
 $111 = HEAP32[$73>>2]|0;
 $112 = HEAP32[$103>>2]|0;
 $113 = HEAP32[$112>>2]|0;
 $114 = (__ZN4FMOD12ChannelGroup8addGroupEPS0_($111,$113)|0);
 $115 = ($114|0)==(0);
 if (!($115)) {
  $116 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($114)|0);
  HEAP32[$vararg_buffer142>>2] = 742056;
  $vararg_ptr31 = (($vararg_buffer142) + 4|0);
  HEAP32[$vararg_ptr31>>2] = 237;
  $vararg_ptr32 = (($vararg_buffer142) + 8|0);
  HEAP32[$vararg_ptr32>>2] = $116;
  $vararg_ptr33 = (($vararg_buffer142) + 12|0);
  HEAP32[$vararg_ptr33>>2] = $114;
  _printf_console(742016,$vararg_buffer142);
 }
 $117 = HEAP32[$constant>>2]|0;
 $118 = ($117>>>0)>(1);
 if ($118) {
  $119 = (($constant) + 4|0);
  $120 = $119;
  $i6$072 = 1;
  while(1) {
   $121 = HEAP32[$119>>2]|0;
   $122 = (($121) + ($120))|0;
   $123 = $122;
   $124 = (($123) + ($i6$072<<4)|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = HEAP32[$103>>2]|0;
   $127 = (($126) + ($125<<2)|0);
   $128 = HEAP32[$127>>2]|0;
   $129 = (($126) + ($i6$072<<2)|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = (__ZN4FMOD12ChannelGroup8addGroupEPS0_($128,$130)|0);
   $132 = ($131|0)==(0);
   if (!($132)) {
    $133 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($131)|0);
    HEAP32[$vararg_buffer142>>2] = 742056;
    $vararg_ptr37 = (($vararg_buffer142) + 4|0);
    HEAP32[$vararg_ptr37>>2] = 243;
    $vararg_ptr38 = (($vararg_buffer142) + 8|0);
    HEAP32[$vararg_ptr38>>2] = $133;
    $vararg_ptr39 = (($vararg_buffer142) + 12|0);
    HEAP32[$vararg_ptr39>>2] = $131;
    _printf_console(742016,$vararg_buffer142);
   }
   $134 = (($i6$072) + 1)|0;
   $135 = HEAP32[$constant>>2]|0;
   $136 = ($134>>>0)<($135>>>0);
   if ($136) {
    $i6$072 = $134;
   } else {
    break;
   }
  }
 }
 $137 = HEAP32[$dspBlockSize>>2]|0;
 $138 = HEAP32[$maxSpeakers>>2]|0;
 $139 = Math_imul($138, $137)|0;
 $140 = (($constant) + 40|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = Math_imul($139, $141)|0;
 $143 = ($142|0)==(0);
 if ($143) {
  $$0$i10 = 0;$151 = $141;
 } else {
  $144 = HEAP32[$alloc>>2]|0;
  $145 = HEAP32[$144>>2]|0;
  $146 = $142 << 2;
  $147 = (FUNCTION_TABLE_iiii[$145 & 2047]($alloc,$146,4)|0);
  $$pre89 = HEAP32[$140>>2]|0;
  $$0$i10 = $147;$151 = $$pre89;
 }
 $148 = (($26) + 72|0);
 HEAP32[$148>>2] = $$0$i10;
 $149 = $139 << 2;
 $150 = Math_imul($149, $151)|0;
 _memset(($$0$i10|0),0,($150|0))|0;
 $152 = HEAP32[$54>>2]|0;
 $153 = ($152|0)==(0);
 L61: do {
  if ($153) {
   $744 = 0;
  } else {
   $154 = HEAP32[$148>>2]|0;
   $155 = (($constant) + 24|0);
   $156 = $155;
   $157 = (($constant) + 96|0);
   $158 = $157;
   $i8$066 = 0;$sideChainPtr$068 = $154;
   while(1) {
    $188 = HEAP32[$155>>2]|0;
    $189 = (($188) + ($156))|0;
    $190 = $189;
    $191 = (($190) + (($i8$066*36)|0)|0);
    $192 = HEAP32[$191>>2]|0;
    $type$off$i = (($192) + 5)|0;
    $193 = ($type$off$i>>>0)<(2);
    L65: do {
     if ($193) {
      label = 56;
     } else {
      $194 = ($192|0)<(0);
      if ($194) {
       $sideChainPtr$1 = $sideChainPtr$068;
       break;
      }
      $195 = ($192|0)>(999);
      $196 = ($192|0)==(0);
      $197 = $195 | $196;
      if (!($197)) {
       $sideChainPtr$1 = $sideChainPtr$068;
       break;
      }
      $198 = (($192) + -1000)|0;
      $199 = HEAP32[$157>>2]|0;
      $200 = (($199) + ($158))|0;
      $201 = $200;
      $202 = ($198|0)==(0);
      if ($202) {
       $effectName$0$lcssa$i$i = $201;
      } else {
       $$014$i$i = $198;$effectName$05$i$i = $201;
       while(1) {
        $203 = (_strlen(($effectName$05$i$i|0))|0);
        $204 = (($203) + 1)|0;
        $205 = (($effectName$05$i$i) + ($204)|0);
        $206 = (($$014$i$i) + -1)|0;
        $207 = ($206|0)==(0);
        if ($207) {
         $effectName$0$lcssa$i$i = $205;
         break;
        } else {
         $$014$i$i = $206;$effectName$05$i$i = $205;
        }
       }
      }
      HEAP32[$numDefs$i$i>>2] = 0;
      $208 = (__Z25GetAudioEffectDefinitionsPi($numDefs$i$i)|0);
      $209 = HEAP32[$numDefs$i$i>>2]|0;
      $210 = ($209|0)>(0);
      if ($210) {
       $n$02$i$i = 0;
      } else {
       $sideChainPtr$1 = $sideChainPtr$068;
       break;
      }
      while(1) {
       $213 = (($208) + ($n$02$i$i<<2)|0);
       $214 = HEAP32[$213>>2]|0;
       $215 = HEAP32[$214>>2]|0;
       $216 = (($215) + 128|0);
       $217 = (_strcmp($216,$effectName$0$lcssa$i$i)|0);
       $218 = ($217|0)==(0);
       $212 = (($n$02$i$i) + 1)|0;
       if ($218) {
        break;
       }
       $211 = ($212|0)<($209|0);
       if ($211) {
        $n$02$i$i = $212;
       } else {
        $sideChainPtr$1 = $sideChainPtr$068;
        break L65;
       }
      }
      $219 = ($214|0)==(0|0);
      if ($219) {
       $sideChainPtr$1 = $sideChainPtr$068;
       break;
      }
      $220 = HEAP32[$214>>2]|0;
      $221 = (($220) + 120|0);
      $222 = $221;
      $223 = $222;
      $224 = HEAP32[$223>>2]|0;
      $225 = (($222) + 4)|0;
      $226 = $225;
      $227 = HEAP32[$226>>2]|0;
      $228 = $224 & 1;
      $229 = ($228|0)==(0);
      $230 = (0)==(0);
      $231 = $229 & $230;
      if ($231) {
       $sideChainPtr$1 = $sideChainPtr$068;
      } else {
       label = 56;
      }
     }
    } while(0);
    if ((label|0) == 56) {
     label = 0;
     $232 = HEAP32[$62>>2]|0;
     $233 = ((($232) + ($i8$066<<5)|0) + 16|0);
     HEAP32[$233>>2] = $sideChainPtr$068;
     $234 = (($sideChainPtr$068) + ($139<<2)|0);
     $sideChainPtr$1 = $234;
    }
    $235 = (($i8$066) + 1)|0;
    $159 = HEAP32[$54>>2]|0;
    $236 = ($235>>>0)<($159>>>0);
    if ($236) {
     $i8$066 = $235;$sideChainPtr$068 = $sideChainPtr$1;
    } else {
     break;
    }
   }
   $phitmp100 = ($159|0)==(0);
   if ($phitmp100) {
    $744 = 0;
   } else {
    $160 = (($constant) + 24|0);
    $161 = $160;
    $162 = (($constant) + 96|0);
    $163 = $162;
    $164 = (($0) + 1|0);
    $165 = (($0) + 8|0);
    $166 = (($1) + 1|0);
    $167 = (($1) + 8|0);
    $168 = (($effectdef) + 32|0);
    $169 = (($effectdef) + 4|0);
    $170 = (($effectdef) + 76|0);
    $171 = (($effectdef14) + 32|0);
    $172 = (($effectdef14) + 4|0);
    $173 = (($effectdef14) + 24|0);
    $174 = (($effectdef14) + 76|0);
    $175 = (($effectdef19) + 32|0);
    $176 = (($effectdef19) + 4|0);
    $177 = (($effectdef19) + 24|0);
    $178 = (($effectdef19) + 64|0);
    $179 = (($effectdef19) + 68|0);
    $180 = (($effectdef19) + 88|0);
    $181 = (($effectdef19) + 96|0);
    $182 = (($effectdef19) + 20|0);
    $183 = (($effectdef19) + 84|0);
    $184 = (($effectdef19) + 76|0);
    $185 = (($effectdef24) + 32|0);
    $186 = (($effectdef24) + 4|0);
    $187 = (($effectdef24) + 76|0);
    $i9$057 = 0;
    L83: while(1) {
     $242 = HEAP32[$160>>2]|0;
     $243 = (($242) + ($161))|0;
     $244 = $243;
     $245 = (($244) + (($i9$057*36)|0)|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = ($246|0)<(0);
     if ($247) {
      $$0$i15 = 1;
     } else {
      $248 = ($246|0)>(999);
      $$type$i = $248 ? 0 : $246;
      $$0$i15 = $$type$i;
     }
     $249 = HEAP32[$62>>2]|0;
     $250 = (($249) + ($i9$057<<5)|0);
     HEAP32[$250>>2] = 0;
     L88: do {
      if ((($246|0) == -3)) {
       $251 = ((($244) + (($i9$057*36)|0)|0) + 4|0);
       $252 = HEAP32[$251>>2]|0;
       $253 = HEAP32[$103>>2]|0;
       $254 = (($253) + ($252<<2)|0);
       $255 = HEAP32[$254>>2]|0;
       $256 = ((($244) + (($i9$057*36)|0)|0) + 8|0);
       $257 = HEAP32[$256>>2]|0;
       $258 = ($257|0)==(-1);
       if ($258) {
        break;
       }
       $259 = HEAP32[$62>>2]|0;
       $260 = ((($259) + ($257<<5)|0) + 16|0);
       $261 = HEAP32[$260>>2]|0;
       $262 = ($261|0)==(0|0);
       if ($262) {
        break;
       }
       dest=$effectdef+0|0; stop=dest+104|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       ;HEAP8[$168+0>>0]=HEAP8[742144+0>>0]|0;HEAP8[$168+1>>0]=HEAP8[742144+1>>0]|0;HEAP8[$168+2>>0]=HEAP8[742144+2>>0]|0;HEAP8[$168+3>>0]=HEAP8[742144+3>>0]|0;HEAP8[$168+4>>0]=HEAP8[742144+4>>0]|0;
       $263 = HEAP32[$62>>2]|0;
       $264 = ((($263) + ($257<<5)|0) + 16|0);
       $265 = HEAP32[$264>>2]|0;
       $266 = ((($263) + ($i9$057<<5)|0) + 16|0);
       HEAP32[$266>>2] = $265;
       HEAP32[$effectdef>>2] = 104;
       HEAP32[$169>>2] = 56;
       HEAP32[$170>>2] = 117;
       __ZN29AudioEffectInternalDefinitionC2EP26UnityAudioEffectDefinitionb($internalDef,$effectdef,0);
       $267 = HEAP32[$62>>2]|0;
       $268 = (($267) + ($i9$057<<5)|0);
       $269 = ((($267) + ($i9$057<<5)|0) + 16|0);
       $270 = HEAP32[$269>>2]|0;
       __THREW__ = 0;
       $271 = (invoke_iiiii(266,($internalDef|0),($system|0),($268|0),($270|0))|0);
       $272 = __THREW__; __THREW__ = 0;
       $273 = $272&1;
       if ($273) {
        label = 69;
        break L83;
       }
       $274 = HEAP32[$62>>2]|0;
       $275 = (($274) + ($i9$057<<5)|0);
       HEAP32[$275>>2] = $271;
       $276 = HEAP32[$62>>2]|0;
       $277 = (($276) + ($i9$057<<5)|0);
       $278 = HEAP32[$277>>2]|0;
       __THREW__ = 0;
       $279 = (invoke_iii(2571,($278|0),1)|0);
       $280 = __THREW__; __THREW__ = 0;
       $281 = $280&1;
       if ($281) {
        label = 69;
        break L83;
       }
       $282 = ($279|0)==(0);
       if (!($282)) {
        $283 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($279)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr43 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr43>>2] = 299;
        $vararg_ptr44 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr44>>2] = $283;
        $vararg_ptr45 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr45>>2] = $279;
        invoke_vii(2587,(742016|0),($vararg_buffer142|0));
        $284 = __THREW__; __THREW__ = 0;
        $285 = $284&1;
        if ($285) {
         label = 69;
         break L83;
        }
       }
       $290 = HEAP32[$62>>2]|0;
       $291 = (($290) + ($i9$057<<5)|0);
       $292 = HEAP32[$291>>2]|0;
       __THREW__ = 0;
       $293 = (invoke_iiii(1581,($255|0),($292|0),(0|0))|0);
       $294 = __THREW__; __THREW__ = 0;
       $295 = $294&1;
       if ($295) {
        label = 69;
        break L83;
       }
       $296 = ($293|0)==(0);
       if (!($296)) {
        $297 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($293)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr49 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr49>>2] = 301;
        $vararg_ptr50 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr50>>2] = $297;
        $vararg_ptr51 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr51>>2] = $293;
        invoke_vii(2587,(742016|0),($vararg_buffer142|0));
        $298 = __THREW__; __THREW__ = 0;
        $299 = $298&1;
        if ($299) {
         label = 69;
         break L83;
        }
       }
       __ZN29AudioEffectInternalDefinitionD2Ev($internalDef);
       label = 122;
      } else if ((($246|0) == -2)) {
       $388 = ((($244) + (($i9$057*36)|0)|0) + 4|0);
       $389 = HEAP32[$388>>2]|0;
       $390 = HEAP32[$103>>2]|0;
       $391 = (($390) + ($389<<2)|0);
       $392 = HEAP32[$391>>2]|0;
       dest=$effectdef24+0|0; stop=dest+104|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       dest=$185+0|0; src=742888+0|0; stop=dest+14|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       HEAP32[$effectdef24>>2] = 104;
       HEAP32[$186>>2] = 56;
       HEAP32[$187>>2] = 120;
       __ZN29AudioEffectInternalDefinitionC2EP26UnityAudioEffectDefinitionb($internalDef25,$effectdef24,0);
       $393 = HEAP32[$388>>2]|0;
       $394 = HEAP32[$25>>2]|0;
       $395 = (($394) + ($393<<8)|0);
       __THREW__ = 0;
       $396 = (invoke_iiiii(266,($internalDef25|0),($system|0),($395|0),(0|0))|0);
       $397 = __THREW__; __THREW__ = 0;
       $398 = $397&1;
       if ($398) {
        label = 98;
        break L83;
       }
       $399 = HEAP32[$62>>2]|0;
       $400 = (($399) + ($i9$057<<5)|0);
       HEAP32[$400>>2] = $396;
       $401 = HEAP32[$388>>2]|0;
       $402 = HEAP32[$25>>2]|0;
       $403 = HEAP32[$sampleRate>>2]|0;
       $404 = (Math_fround(($403|0)));
       $405 = Math_fround($404 * Math_fround(0.300000011920928955078));
       __THREW__ = 0;
       $406 = (Math_fround(+(invoke_fff(1,0.990000009536743164062,(+$405)))));
       $407 = __THREW__; __THREW__ = 0;
       $408 = $407&1;
       if ($408) {
        label = 98;
        break L83;
       }
       $409 = ((($402) + ($401<<8)|0) + 8|0);
       HEAPF32[$409>>2] = $406;
       $410 = Math_fround($404 * Math_fround(1.70000004768371582031));
       __THREW__ = 0;
       $411 = (Math_fround(+(invoke_fff(1,0.899999976158142089843,(+$410)))));
       $412 = __THREW__; __THREW__ = 0;
       $413 = $412&1;
       if ($413) {
        label = 98;
        break L83;
       }
       $414 = Math_fround(Math_fround(1.0) - $411);
       $415 = ((($402) + ($401<<8)|0) + 12|0);
       HEAPF32[$415>>2] = $414;
       $416 = Math_fround(Math_fround(-0.5) / $404);
       $417 = (Math_fround(+(_log2f(10.0))));
       $418 = Math_fround($416 * $417);
       $419 = (Math_fround(+(_exp2f((+$418)))));
       $420 = ((($402) + ($401<<8)|0) + 16|0);
       HEAPF32[$420>>2] = $419;
       $421 = Math_fround($404 * Math_fround(2.0));
       $422 = (~~(($421)));
       $423 = ((($402) + ($401<<8)|0) + 24|0);
       HEAP32[$423>>2] = $422;
       $424 = HEAP32[$388>>2]|0;
       $425 = HEAP32[$25>>2]|0;
       $426 = ((($425) + ($424<<8)|0) + 28|0);
       $427 = HEAP32[$426>>2]|0;
       $428 = $427 | 1;
       HEAP32[$426>>2] = $428;
       $429 = HEAP32[$388>>2]|0;
       $430 = HEAP32[$34>>2]|0;
       $431 = ((($430) + ($429<<8)|0) + 28|0);
       $432 = HEAP32[$431>>2]|0;
       $433 = $432 & -2;
       HEAP32[$431>>2] = $433;
       $434 = HEAP32[$62>>2]|0;
       $435 = (($434) + ($i9$057<<5)|0);
       $436 = HEAP32[$435>>2]|0;
       __THREW__ = 0;
       $437 = (invoke_iii(2571,($436|0),1)|0);
       $438 = __THREW__; __THREW__ = 0;
       $439 = $438&1;
       if ($439) {
        label = 98;
        break L83;
       }
       $440 = ($437|0)==(0);
       if (!($440)) {
        $441 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($437)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr79 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr79>>2] = 402;
        $vararg_ptr80 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr80>>2] = $441;
        $vararg_ptr81 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr81>>2] = $437;
        invoke_vii(2587,(742016|0),($vararg_buffer142|0));
        $442 = __THREW__; __THREW__ = 0;
        $443 = $442&1;
        if ($443) {
         label = 98;
         break L83;
        }
       }
       $448 = HEAP32[$62>>2]|0;
       $449 = (($448) + ($i9$057<<5)|0);
       $450 = HEAP32[$449>>2]|0;
       __THREW__ = 0;
       $451 = (invoke_iiii(1581,($392|0),($450|0),(0|0))|0);
       $452 = __THREW__; __THREW__ = 0;
       $453 = $452&1;
       if ($453) {
        label = 98;
        break L83;
       }
       $454 = ($451|0)==(0);
       if (!($454)) {
        $455 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($451)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr85 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr85>>2] = 404;
        $vararg_ptr86 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr86>>2] = $455;
        $vararg_ptr87 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr87>>2] = $451;
        invoke_vii(2587,(742016|0),($vararg_buffer142|0));
        $456 = __THREW__; __THREW__ = 0;
        $457 = $456&1;
        if ($457) {
         label = 98;
         break L83;
        }
       }
       __ZN29AudioEffectInternalDefinitionD2Ev($internalDef25);
       label = 122;
      } else if ((($246|0) == -5)) {
       $346 = ((($244) + (($i9$057*36)|0)|0) + 4|0);
       $347 = HEAP32[$346>>2]|0;
       $348 = HEAP32[$103>>2]|0;
       $349 = (($348) + ($347<<2)|0);
       $350 = HEAP32[$349>>2]|0;
       dest=$effectdef19+0|0; stop=dest+104|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       dest=$175+0|0; src=742152+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
       $351 = $177;
       $352 = $351;
       HEAP32[$352>>2] = 1;
       $353 = (($351) + 4)|0;
       $354 = $353;
       HEAP32[$354>>2] = 0;
       HEAP32[$effectdef19>>2] = 104;
       HEAP32[$176>>2] = 56;
       HEAP32[$178>>2] = 3388;
       HEAP32[$179>>2] = 3389;
       HEAP32[$180>>2] = 3;
       HEAP32[$181>>2] = 267;
       HEAP32[$182>>2] = 7;
       HEAP32[$183>>2] = 742168;
       HEAP32[$184>>2] = 119;
       __ZN29AudioEffectInternalDefinitionC2EP26UnityAudioEffectDefinitionb($internalDef20,$effectdef19,0);
       $355 = HEAP32[$62>>2]|0;
       $356 = (($355) + ($i9$057<<5)|0);
       $357 = ((($355) + ($i9$057<<5)|0) + 16|0);
       $358 = HEAP32[$357>>2]|0;
       __THREW__ = 0;
       $359 = (invoke_iiiii(266,($internalDef20|0),($system|0),($356|0),($358|0))|0);
       $360 = __THREW__; __THREW__ = 0;
       $361 = $360&1;
       if ($361) {
        label = 87;
        break L83;
       }
       $362 = HEAP32[$62>>2]|0;
       $363 = (($362) + ($i9$057<<5)|0);
       HEAP32[$363>>2] = $359;
       $364 = HEAP32[$62>>2]|0;
       $365 = (($364) + ($i9$057<<5)|0);
       $366 = HEAP32[$365>>2]|0;
       __THREW__ = 0;
       $367 = (invoke_iii(2571,($366|0),1)|0);
       $368 = __THREW__; __THREW__ = 0;
       $369 = $368&1;
       if ($369) {
        label = 87;
        break L83;
       }
       $370 = ($367|0)==(0);
       if (!($370)) {
        $371 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($367)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr67 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr67>>2] = 373;
        $vararg_ptr68 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr68>>2] = $371;
        $vararg_ptr69 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr69>>2] = $367;
        invoke_vii(2587,(742016|0),($vararg_buffer142|0));
        $372 = __THREW__; __THREW__ = 0;
        $373 = $372&1;
        if ($373) {
         label = 87;
         break L83;
        }
       }
       $378 = HEAP32[$62>>2]|0;
       $379 = (($378) + ($i9$057<<5)|0);
       $380 = HEAP32[$379>>2]|0;
       __THREW__ = 0;
       $381 = (invoke_iiii(1581,($350|0),($380|0),(0|0))|0);
       $382 = __THREW__; __THREW__ = 0;
       $383 = $382&1;
       if ($383) {
        label = 87;
        break L83;
       }
       $384 = ($381|0)==(0);
       if (!($384)) {
        $385 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($381)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr73 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr73>>2] = 375;
        $vararg_ptr74 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr74>>2] = $385;
        $vararg_ptr75 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr75>>2] = $381;
        invoke_vii(2587,(742016|0),($vararg_buffer142|0));
        $386 = __THREW__; __THREW__ = 0;
        $387 = $386&1;
        if ($387) {
         label = 87;
         break L83;
        }
       }
       __ZN29AudioEffectInternalDefinitionD2Ev($internalDef20);
       label = 122;
      } else if ((($246|0) == -4)) {
       $300 = ((($244) + (($i9$057*36)|0)|0) + 4|0);
       $301 = HEAP32[$300>>2]|0;
       $302 = HEAP32[$103>>2]|0;
       $303 = (($302) + ($301<<2)|0);
       $304 = HEAP32[$303>>2]|0;
       dest=$effectdef14+0|0; stop=dest+104|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
       $305 = $171;
       $306 = $305;
       HEAP32[$306>>2] = 1701012818;
       $307 = (($305) + 4)|0;
       $308 = $307;
       HEAP32[$308>>2] = 6649449;
       HEAP32[$effectdef14>>2] = 104;
       HEAP32[$172>>2] = 56;
       $309 = $173;
       $310 = $309;
       HEAP32[$310>>2] = 1;
       $311 = (($309) + 4)|0;
       $312 = $311;
       HEAP32[$312>>2] = 0;
       HEAP32[$174>>2] = 118;
       __ZN29AudioEffectInternalDefinitionC2EP26UnityAudioEffectDefinitionb($internalDef15,$effectdef14,0);
       $313 = HEAP32[$62>>2]|0;
       $314 = (($313) + ($i9$057<<5)|0);
       $315 = ((($313) + ($i9$057<<5)|0) + 16|0);
       $316 = HEAP32[$315>>2]|0;
       __THREW__ = 0;
       $317 = (invoke_iiiii(266,($internalDef15|0),($system|0),($314|0),($316|0))|0);
       $318 = __THREW__; __THREW__ = 0;
       $319 = $318&1;
       if ($319) {
        label = 78;
        break L83;
       }
       $320 = HEAP32[$62>>2]|0;
       $321 = (($320) + ($i9$057<<5)|0);
       HEAP32[$321>>2] = $317;
       $322 = HEAP32[$62>>2]|0;
       $323 = (($322) + ($i9$057<<5)|0);
       $324 = HEAP32[$323>>2]|0;
       __THREW__ = 0;
       $325 = (invoke_iii(2571,($324|0),1)|0);
       $326 = __THREW__; __THREW__ = 0;
       $327 = $326&1;
       if ($327) {
        label = 78;
        break L83;
       }
       $328 = ($325|0)==(0);
       if (!($328)) {
        $329 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($325)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr55 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr55>>2] = 327;
        $vararg_ptr56 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr56>>2] = $329;
        $vararg_ptr57 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr57>>2] = $325;
        invoke_vii(2587,(742016|0),($vararg_buffer142|0));
        $330 = __THREW__; __THREW__ = 0;
        $331 = $330&1;
        if ($331) {
         label = 78;
         break L83;
        }
       }
       $336 = HEAP32[$62>>2]|0;
       $337 = (($336) + ($i9$057<<5)|0);
       $338 = HEAP32[$337>>2]|0;
       __THREW__ = 0;
       $339 = (invoke_iiii(1581,($304|0),($338|0),(0|0))|0);
       $340 = __THREW__; __THREW__ = 0;
       $341 = $340&1;
       if ($341) {
        label = 78;
        break L83;
       }
       $342 = ($339|0)==(0);
       if (!($342)) {
        $343 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($339)|0);
        __THREW__ = 0;
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr61 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr61>>2] = 329;
        $vararg_ptr62 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr62>>2] = $343;
        $vararg_ptr63 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr63>>2] = $339;
        invoke_vii(2587,(742016|0),($vararg_buffer142|0));
        $344 = __THREW__; __THREW__ = 0;
        $345 = $344&1;
        if ($345) {
         label = 78;
         break L83;
        }
       }
       __ZN29AudioEffectInternalDefinitionD2Ev($internalDef15);
       label = 122;
      } else {
       $458 = ($$0$i15|0)==(0);
       if (!($458)) {
        $517 = HEAP32[$62>>2]|0;
        $518 = (($517) + ($i9$057<<5)|0);
        $519 = (__ZN4FMOD6System15createDSPByTypeE13FMOD_DSP_TYPEPPNS_3DSPE($system,$$0$i15,$518)|0);
        $520 = ($519|0)==(0);
        if (!($520)) {
         __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(742952,0,742944,426,1,0,0,0);
         label = 122;
         break;
        }
        $521 = ((($244) + (($i9$057*36)|0)|0) + 4|0);
        $522 = HEAP32[$521>>2]|0;
        $523 = HEAP32[$103>>2]|0;
        $524 = (($523) + ($522<<2)|0);
        $525 = HEAP32[$524>>2]|0;
        $526 = HEAP32[$62>>2]|0;
        $527 = (($526) + ($i9$057<<5)|0);
        $528 = HEAP32[$527>>2]|0;
        $529 = (__ZN4FMOD12ChannelGroup6addDSPEPNS_3DSPEPPNS_13DSPConnectionE($525,$528,0)|0);
        $530 = ($529|0)==(0);
        if ($530) {
         label = 122;
         break;
        }
        $531 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($529)|0);
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr100 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr100>>2] = 423;
        $vararg_ptr101 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr101>>2] = $531;
        $vararg_ptr102 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr102>>2] = $529;
        _printf_console(742016,$vararg_buffer142);
        label = 122;
        break;
       }
       $459 = (($246) + -1000)|0;
       $460 = HEAP32[$162>>2]|0;
       $461 = (($460) + ($163))|0;
       $462 = $461;
       $463 = ($459|0)==(0);
       if ($463) {
        $effectName$0$lcssa$i = $462;
       } else {
        $$014$i = $459;$effectName$05$i = $462;
        while(1) {
         $464 = (_strlen(($effectName$05$i|0))|0);
         $465 = (($464) + 1)|0;
         $466 = (($effectName$05$i) + ($465)|0);
         $467 = (($$014$i) + -1)|0;
         $468 = ($467|0)==(0);
         if ($468) {
          $effectName$0$lcssa$i = $466;
          break;
         } else {
          $$014$i = $467;$effectName$05$i = $466;
         }
        }
       }
       HEAP32[$numDefs$i>>2] = 0;
       $469 = (__Z25GetAudioEffectDefinitionsPi($numDefs$i)|0);
       $470 = HEAP32[$numDefs$i>>2]|0;
       $471 = ($470|0)>(0);
       if ($471) {
        $n$02$i = 0;
       } else {
        break;
       }
       while(1) {
        $474 = (($469) + ($n$02$i<<2)|0);
        $475 = HEAP32[$474>>2]|0;
        $476 = HEAP32[$475>>2]|0;
        $477 = (($476) + 128|0);
        $478 = (_strcmp($477,$effectName$0$lcssa$i)|0);
        $479 = ($478|0)==(0);
        $473 = (($n$02$i) + 1)|0;
        if ($479) {
         break;
        }
        $472 = ($473|0)<($470|0);
        if ($472) {
         $n$02$i = $473;
        } else {
         break L88;
        }
       }
       $480 = ($475|0)==(0|0);
       if ($480) {
        break;
       }
       $481 = HEAP32[$62>>2]|0;
       $482 = ((($481) + ($i9$057<<5)|0) + 16|0);
       $483 = HEAP32[$482>>2]|0;
       $484 = (__ZN29AudioEffectInternalDefinition9CreateDSPEPN4FMOD6SystemEPvPf($475,$system,0,$483)|0);
       $485 = HEAP32[$62>>2]|0;
       $486 = (($485) + ($i9$057<<5)|0);
       HEAP32[$486>>2] = $484;
       $487 = HEAP32[$62>>2]|0;
       $488 = (($487) + ($i9$057<<5)|0);
       $489 = HEAP32[$488>>2]|0;
       $490 = ($489|0)==(0|0);
       if (!($490)) {
        $491 = ((($244) + (($i9$057*36)|0)|0) + 4|0);
        $492 = HEAP32[$491>>2]|0;
        $493 = HEAP32[$103>>2]|0;
        $494 = (($493) + ($492<<2)|0);
        $495 = HEAP32[$494>>2]|0;
        $496 = (__ZN4FMOD12ChannelGroup6addDSPEPNS_3DSPEPPNS_13DSPConnectionE($495,$489,0)|0);
        $497 = ($496|0)==(0);
        if ($497) {
         label = 122;
         break;
        }
        $498 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($496)|0);
        HEAP32[$vararg_buffer142>>2] = 742056;
        $vararg_ptr91 = (($vararg_buffer142) + 4|0);
        HEAP32[$vararg_ptr91>>2] = 415;
        $vararg_ptr92 = (($vararg_buffer142) + 8|0);
        HEAP32[$vararg_ptr92>>2] = $498;
        $vararg_ptr93 = (($vararg_buffer142) + 12|0);
        HEAP32[$vararg_ptr93>>2] = $496;
        _printf_console(742016,$vararg_buffer142);
        label = 122;
        break;
       }
       $499 = HEAP32[$475>>2]|0;
       $500 = (($499) + 128|0);
       HEAP32[$vararg_buffer142>>2] = $500;
       __Z6FormatPKcz($0,742904,$vararg_buffer142);
       $501 = HEAP8[$0>>0]|0;
       $502 = $501 & 1;
       $503 = ($502<<24>>24)==(0);
       $504 = HEAP32[$165>>2]|0;
       $$ = $503 ? $164 : $504;
       __THREW__ = 0;
       invoke_viiiiiiii(21,($$|0),0,(742944|0),418,1,0,0,(0|0));
       $505 = __THREW__; __THREW__ = 0;
       $506 = $505&1;
       if ($506) {
        label = 116;
        break L83;
       }
       $507 = HEAP8[$0>>0]|0;
       $508 = $507 & 1;
       $509 = ($508<<24>>24)==(0);
       if ($509) {
        label = 122;
        break;
       }
       $510 = HEAP32[$165>>2]|0;
       __ZdlPv($510);
       label = 122;
      }
     } while(0);
     do {
      if ((label|0) == 122) {
       label = 0;
       $532 = HEAP32[$62>>2]|0;
       $533 = (($532) + ($i9$057<<5)|0);
       $534 = HEAP32[$533>>2]|0;
       $535 = ($534|0)==(0|0);
       if (!($535)) {
        break;
       }
       HEAP32[$vararg_buffer142>>2] = $$0$i15;
       __Z6FormatPKcz($1,743000,$vararg_buffer142);
       $536 = HEAP8[$1>>0]|0;
       $537 = $536 & 1;
       $538 = ($537<<24>>24)==(0);
       $539 = HEAP32[$167>>2]|0;
       $$101 = $538 ? $166 : $539;
       __THREW__ = 0;
       invoke_viiiiiiii(21,($$101|0),0,(742944|0),430,1,0,0,(0|0));
       $540 = __THREW__; __THREW__ = 0;
       $541 = $540&1;
       if ($541) {
        label = 126;
        break L83;
       }
       $542 = HEAP8[$1>>0]|0;
       $543 = $542 & 1;
       $544 = ($543<<24>>24)==(0);
       if ($544) {
        break;
       }
       $545 = HEAP32[$167>>2]|0;
       __ZdlPv($545);
      }
     } while(0);
     $552 = (($i9$057) + 1)|0;
     $553 = HEAP32[$54>>2]|0;
     $554 = ($552>>>0)<($553>>>0);
     if ($554) {
      $i9$057 = $552;
     } else {
      $744 = $553;
      break L61;
     }
    }
    if ((label|0) == 69) {
     $286 = ___cxa_find_matching_catch()|0;
     $287 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3655,($internalDef|0));
     $288 = __THREW__; __THREW__ = 0;
     $289 = $288&1;
     if ($289) {
      $742 = ___cxa_find_matching_catch(0|0)|0;
      $743 = tempRet0;
      ___clang_call_terminate($742);
      // unreachable;
     } else {
      $$0 = $286;$$01 = $287;
      ___resumeException($$0|0);
      // unreachable;
     }
    }
    else if ((label|0) == 78) {
     $332 = ___cxa_find_matching_catch()|0;
     $333 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3655,($internalDef15|0));
     $334 = __THREW__; __THREW__ = 0;
     $335 = $334&1;
     if ($335) {
      $742 = ___cxa_find_matching_catch(0|0)|0;
      $743 = tempRet0;
      ___clang_call_terminate($742);
      // unreachable;
     } else {
      $$0 = $332;$$01 = $333;
      ___resumeException($$0|0);
      // unreachable;
     }
    }
    else if ((label|0) == 87) {
     $374 = ___cxa_find_matching_catch()|0;
     $375 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3655,($internalDef20|0));
     $376 = __THREW__; __THREW__ = 0;
     $377 = $376&1;
     if ($377) {
      $742 = ___cxa_find_matching_catch(0|0)|0;
      $743 = tempRet0;
      ___clang_call_terminate($742);
      // unreachable;
     } else {
      $$0 = $374;$$01 = $375;
      ___resumeException($$0|0);
      // unreachable;
     }
    }
    else if ((label|0) == 98) {
     $444 = ___cxa_find_matching_catch()|0;
     $445 = tempRet0;
     __THREW__ = 0;
     invoke_vi(3655,($internalDef25|0));
     $446 = __THREW__; __THREW__ = 0;
     $447 = $446&1;
     if ($447) {
      $742 = ___cxa_find_matching_catch(0|0)|0;
      $743 = tempRet0;
      ___clang_call_terminate($742);
      // unreachable;
     } else {
      $$0 = $444;$$01 = $445;
      ___resumeException($$0|0);
      // unreachable;
     }
    }
    else if ((label|0) == 116) {
     $511 = ___cxa_find_matching_catch()|0;
     $512 = tempRet0;
     $513 = HEAP8[$0>>0]|0;
     $514 = $513 & 1;
     $515 = ($514<<24>>24)==(0);
     if ($515) {
      $$0 = $511;$$01 = $512;
      ___resumeException($$0|0);
      // unreachable;
     }
     $516 = HEAP32[$165>>2]|0;
     __ZdlPv($516);
     $$0 = $511;$$01 = $512;
     ___resumeException($$0|0);
     // unreachable;
    }
    else if ((label|0) == 126) {
     $546 = ___cxa_find_matching_catch()|0;
     $547 = tempRet0;
     $548 = HEAP8[$1>>0]|0;
     $549 = $548 & 1;
     $550 = ($549<<24>>24)==(0);
     if ($550) {
      $$0 = $546;$$01 = $547;
      ___resumeException($$0|0);
      // unreachable;
     }
     $551 = HEAP32[$167>>2]|0;
     __ZdlPv($551);
     $$0 = $546;$$01 = $547;
     ___resumeException($$0|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $237 = HEAP32[$constant>>2]|0;
 $238 = ($237|0)==(0);
 do {
  if ($238) {
   $556 = $744;
  } else {
   $239 = (($effectdef34) + 32|0);
   $240 = (($effectdef34) + 4|0);
   $241 = (($effectdef34) + 76|0);
   $745 = $237;$i32$049 = 0;
   while(1) {
    $559 = HEAP32[$34>>2]|0;
    $560 = ((($559) + ($i32$049<<8)|0) + 28|0);
    $561 = HEAP32[$560>>2]|0;
    $562 = $561 & 3;
    $563 = ($562|0)==(0);
    if ($563) {
     $604 = $745;
    } else {
     $564 = HEAP32[$103>>2]|0;
     $565 = (($564) + ($i32$049<<2)|0);
     $566 = HEAP32[$565>>2]|0;
     dest=$effectdef34+0|0; stop=dest+104|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     $567 = $239;
     $568 = $567;
     HEAP32[$568>>2] = 1631999318;
     $569 = (($567) + 4)|0;
     $570 = $569;
     HEAP32[$570>>2] = 7497060;
     HEAP32[$effectdef34>>2] = 104;
     HEAP32[$240>>2] = 56;
     HEAP32[$241>>2] = 120;
     __ZN29AudioEffectInternalDefinitionC2EP26UnityAudioEffectDefinitionb($internalDef35,$effectdef34,0);
     $571 = HEAP32[$34>>2]|0;
     $572 = (($571) + ($i32$049<<8)|0);
     __THREW__ = 0;
     $573 = (invoke_iiiii(266,($internalDef35|0),($system|0),($572|0),(0|0))|0);
     $574 = __THREW__; __THREW__ = 0;
     $575 = $574&1;
     if ($575) {
      break;
     }
     $576 = HEAP32[$46>>2]|0;
     $577 = (($576) + ($i32$049<<2)|0);
     HEAP32[$577>>2] = $573;
     $578 = HEAP32[$46>>2]|0;
     $579 = (($578) + ($i32$049<<2)|0);
     $580 = HEAP32[$579>>2]|0;
     __THREW__ = 0;
     $581 = (invoke_iii(2571,($580|0),1)|0);
     $582 = __THREW__; __THREW__ = 0;
     $583 = $582&1;
     if ($583) {
      break;
     }
     $584 = ($581|0)==(0);
     if (!($584)) {
      $585 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($581)|0);
      __THREW__ = 0;
      HEAP32[$vararg_buffer142>>2] = 742056;
      $vararg_ptr109 = (($vararg_buffer142) + 4|0);
      HEAP32[$vararg_ptr109>>2] = 458;
      $vararg_ptr110 = (($vararg_buffer142) + 8|0);
      HEAP32[$vararg_ptr110>>2] = $585;
      $vararg_ptr111 = (($vararg_buffer142) + 12|0);
      HEAP32[$vararg_ptr111>>2] = $581;
      invoke_vii(2587,(742016|0),($vararg_buffer142|0));
      $586 = __THREW__; __THREW__ = 0;
      $587 = $586&1;
      if ($587) {
       break;
      }
     }
     $592 = HEAP32[$46>>2]|0;
     $593 = (($592) + ($i32$049<<2)|0);
     $594 = HEAP32[$593>>2]|0;
     __THREW__ = 0;
     $595 = (invoke_iiii(1581,($566|0),($594|0),(0|0))|0);
     $596 = __THREW__; __THREW__ = 0;
     $597 = $596&1;
     if ($597) {
      break;
     }
     $598 = ($595|0)==(0);
     if (!($598)) {
      $599 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($595)|0);
      __THREW__ = 0;
      HEAP32[$vararg_buffer142>>2] = 742056;
      $vararg_ptr115 = (($vararg_buffer142) + 4|0);
      HEAP32[$vararg_ptr115>>2] = 460;
      $vararg_ptr116 = (($vararg_buffer142) + 8|0);
      HEAP32[$vararg_ptr116>>2] = $599;
      $vararg_ptr117 = (($vararg_buffer142) + 12|0);
      HEAP32[$vararg_ptr117>>2] = $595;
      invoke_vii(2587,(742016|0),($vararg_buffer142|0));
      $600 = __THREW__; __THREW__ = 0;
      $601 = $600&1;
      if ($601) {
       break;
      }
     }
     __ZN29AudioEffectInternalDefinitionD2Ev($internalDef35);
     $$pre92 = HEAP32[$constant>>2]|0;
     $604 = $$pre92;
    }
    $602 = (($i32$049) + 1)|0;
    $603 = ($602>>>0)<($604>>>0);
    if ($603) {
     $745 = $604;$i32$049 = $602;
    } else {
     label = 129;
     break;
    }
   }
   if ((label|0) == 129) {
    $$pre90 = HEAP32[$54>>2]|0;
    $556 = $$pre90;
    break;
   }
   $588 = ___cxa_find_matching_catch()|0;
   $589 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3655,($internalDef35|0));
   $590 = __THREW__; __THREW__ = 0;
   $591 = $590&1;
   if ($591) {
    $742 = ___cxa_find_matching_catch(0|0)|0;
    $743 = tempRet0;
    ___clang_call_terminate($742);
    // unreachable;
   } else {
    $$0 = $588;$$01 = $589;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $555 = ($556|0)==(0);
 if (!($555)) {
  $557 = (($constant) + 24|0);
  $558 = $557;
  $i38$044 = 0;
  while(1) {
   $605 = HEAP32[$62>>2]|0;
   $606 = ((($605) + ($i38$044<<5)|0) + 4|0);
   HEAP32[$606>>2] = 0;
   $607 = HEAP32[$62>>2]|0;
   $608 = ((($607) + ($i38$044<<5)|0) + 8|0);
   HEAP32[$608>>2] = 0;
   $609 = HEAP32[$62>>2]|0;
   $610 = (($609) + ($i38$044<<5)|0);
   $611 = HEAP32[$610>>2]|0;
   $612 = ($611|0)!=(0|0);
   $613 = $612 ? Math_fround(1.0) : Math_fround(0.0);
   $614 = ((($609) + ($i38$044<<5)|0) + 12|0);
   HEAPF32[$614>>2] = $613;
   HEAP32[$dspInput>>2] = 0;
   HEAP32[$dspOutput>>2] = 0;
   $615 = HEAP32[$557>>2]|0;
   $616 = (($615) + ($558))|0;
   $617 = $616;
   $618 = (($617) + (($i38$044*36)|0)|0);
   $619 = HEAP32[$618>>2]|0;
   $$off = (($619) + 5)|0;
   $switch = ($$off>>>0)<(3);
   do {
    if (!($switch)) {
     $620 = HEAP32[$62>>2]|0;
     $621 = (($620) + ($i38$044<<5)|0);
     $622 = HEAP32[$621>>2]|0;
     $623 = ($622|0)==(0|0);
     if ($623) {
      break;
     }
     $624 = ((($617) + (($i38$044*36)|0)|0) + 12|0);
     $625 = HEAP32[$624>>2]|0;
     $626 = ($625|0)==(-1);
     if ($626) {
      break;
     }
     $627 = (__ZN4FMOD3DSP8getInputEiPPS0_PPNS_13DSPConnectionE($622,0,$dspInput,0)|0);
     $628 = ($627|0)==(0);
     if (!($628)) {
      $629 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($627)|0);
      HEAP32[$vararg_buffer142>>2] = 742056;
      $vararg_ptr121 = (($vararg_buffer142) + 4|0);
      HEAP32[$vararg_ptr121>>2] = 482;
      $vararg_ptr122 = (($vararg_buffer142) + 8|0);
      HEAP32[$vararg_ptr122>>2] = $629;
      $vararg_ptr123 = (($vararg_buffer142) + 12|0);
      HEAP32[$vararg_ptr123>>2] = $627;
      _printf_console(742016,$vararg_buffer142);
     }
     $630 = HEAP32[$62>>2]|0;
     $631 = (($630) + ($i38$044<<5)|0);
     $632 = HEAP32[$631>>2]|0;
     $633 = ((($630) + ($i38$044<<5)|0) + 4|0);
     $634 = (__ZN4FMOD3DSP9getOutputEiPPS0_PPNS_13DSPConnectionE($632,0,$dspOutput,$633)|0);
     $635 = ($634|0)==(0);
     if (!($635)) {
      $636 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($634)|0);
      HEAP32[$vararg_buffer142>>2] = 742056;
      $vararg_ptr127 = (($vararg_buffer142) + 4|0);
      HEAP32[$vararg_ptr127>>2] = 483;
      $vararg_ptr128 = (($vararg_buffer142) + 8|0);
      HEAP32[$vararg_ptr128>>2] = $636;
      $vararg_ptr129 = (($vararg_buffer142) + 12|0);
      HEAP32[$vararg_ptr129>>2] = $634;
      _printf_console(742016,$vararg_buffer142);
     }
     $637 = HEAP32[$dspOutput>>2]|0;
     $638 = HEAP32[$dspInput>>2]|0;
     $639 = HEAP32[$62>>2]|0;
     $640 = ((($639) + ($i38$044<<5)|0) + 8|0);
     $641 = (__ZN4FMOD3DSP8addInputEPS0_PPNS_13DSPConnectionE($637,$638,$640)|0);
     $642 = ($641|0)==(0);
     if ($642) {
      break;
     }
     $643 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($641)|0);
     HEAP32[$vararg_buffer142>>2] = 742056;
     $vararg_ptr133 = (($vararg_buffer142) + 4|0);
     HEAP32[$vararg_ptr133>>2] = 484;
     $vararg_ptr134 = (($vararg_buffer142) + 8|0);
     HEAP32[$vararg_ptr134>>2] = $643;
     $vararg_ptr135 = (($vararg_buffer142) + 12|0);
     HEAP32[$vararg_ptr135>>2] = $641;
     _printf_console(742016,$vararg_buffer142);
    }
   } while(0);
   $644 = (($i38$044) + 1)|0;
   $645 = HEAP32[$54>>2]|0;
   $646 = ($644>>>0)<($645>>>0);
   if ($646) {
    $i38$044 = $644;
   } else {
    break;
   }
  }
 }
 $647 = (($26) + 60|0);
 HEAP32[$647>>2] = $$0$i;
 $648 = (($26) + 20|0);
 HEAP32[$648>>2] = $13;
 $649 = ($13|0)==(0);
 if ($649) {
  $650 = (($26) + 24|0);
  $651 = (($26) + 32|0);
  ;HEAP32[$650+0>>2]=0|0;HEAP32[$650+4>>2]=0|0;HEAP32[$650+8>>2]=0|0;HEAP32[$650+12>>2]=0|0;
  $$0$i12 = 0;$680 = $651;$701 = $650;
 } else {
  $652 = HEAP32[$alloc>>2]|0;
  $653 = HEAP32[$652>>2]|0;
  $654 = $13 << 2;
  $655 = (FUNCTION_TABLE_iiii[$653 & 2047]($alloc,$654,4)|0);
  $656 = (($26) + 24|0);
  HEAP32[$656>>2] = $655;
  $657 = HEAP32[$alloc>>2]|0;
  $658 = HEAP32[$657>>2]|0;
  $659 = (FUNCTION_TABLE_iiii[$658 & 2047]($alloc,$654,4)|0);
  $660 = (($26) + 32|0);
  HEAP32[$660>>2] = $659;
  $661 = HEAP32[$alloc>>2]|0;
  $662 = HEAP32[$661>>2]|0;
  $663 = (FUNCTION_TABLE_iiii[$662 & 2047]($alloc,$654,4)|0);
  $664 = (($26) + 28|0);
  HEAP32[$664>>2] = $663;
  $665 = HEAP32[$alloc>>2]|0;
  $666 = HEAP32[$665>>2]|0;
  $667 = (FUNCTION_TABLE_iiii[$666 & 2047]($alloc,$13,1)|0);
  $668 = (($26) + 36|0);
  HEAP32[$668>>2] = $667;
  $669 = HEAP32[$alloc>>2]|0;
  $670 = HEAP32[$669>>2]|0;
  $671 = (FUNCTION_TABLE_iiii[$670 & 2047]($alloc,$654,4)|0);
  $$0$i12 = $671;$680 = $660;$701 = $656;
 }
 $672 = (($26) + 52|0);
 HEAP32[$672>>2] = $$0$i12;
 $673 = HEAP32[$7>>2]|0;
 $674 = (($673) + ($8))|0;
 $675 = $674;
 $676 = (($675) + 4|0);
 $677 = HEAP32[$676>>2]|0;
 $678 = ($677|0)==(0);
 if (!($678)) {
  $679 = HEAP32[$680>>2]|0;
  $i42$040 = 0;
  while(1) {
   $681 = (($679) + ($i42$040<<2)|0);
   HEAPF32[$681>>2] = Math_fround(-inf);
   $682 = (($i42$040) + 1)|0;
   $683 = ($682>>>0)<($677>>>0);
   if ($683) {
    $i42$040 = $682;
   } else {
    break;
   }
  }
 }
 $684 = (($constant) + 104|0);
 $685 = HEAP32[$684>>2]|0;
 $686 = ($685|0)==(0);
 do {
  if ($686) {
   $687 = (($26) + 40|0);
   HEAP32[$687>>2] = 0;
  } else {
   $688 = HEAP32[$alloc>>2]|0;
   $689 = HEAP32[$688>>2]|0;
   $690 = $685 << 2;
   $691 = (FUNCTION_TABLE_iiii[$689 & 2047]($alloc,$690,4)|0);
   $$pre91 = HEAP32[$684>>2]|0;
   $692 = (($26) + 40|0);
   HEAP32[$692>>2] = $691;
   $693 = ($$pre91|0)==(0);
   if ($693) {
    break;
   } else {
    $i43$037 = 0;
   }
   while(1) {
    $694 = (($691) + ($i43$037<<2)|0);
    HEAPF32[$694>>2] = Math_fround(-inf);
    $695 = (($i43$037) + 1)|0;
    $696 = ($695>>>0)<($$pre91>>>0);
    if ($696) {
     $i43$037 = $695;
    } else {
     break;
    }
   }
  }
 } while(0);
 $697 = (($26) + 44|0);
 HEAPF32[$697>>2] = Math_fround(1.0);
 $698 = (($26) + 48|0);
 HEAPF32[$698>>2] = Math_fround(0.0);
 $699 = (($26) + 56|0);
 HEAP8[$699>>0] = 0;
 $700 = HEAP32[$701>>2]|0;
 $702 = HEAP32[$7>>2]|0;
 $703 = (($702) + ($8))|0;
 $704 = $703;
 $705 = (($704) + 8|0);
 $706 = $705;
 $707 = HEAP32[$705>>2]|0;
 $708 = (($706) + ($707))|0;
 $709 = $708;
 $710 = (($704) + 12|0);
 HEAP32[$710>>2] = $709;
 $711 = $708;
 $712 = HEAP32[$648>>2]|0;
 $713 = $712 << 2;
 _memcpy(($700|0),($711|0),($713|0))|0;
 $714 = HEAP32[$54>>2]|0;
 $715 = ($714|0)==(0);
 if (!($715)) {
  $i44$034 = 0;
  while(1) {
   $718 = HEAP32[$62>>2]|0;
   $719 = (($718) + ($i44$034<<5)|0);
   $720 = HEAP32[$719>>2]|0;
   $721 = ($720|0)==(0|0);
   do {
    if (!($721)) {
     $722 = (__ZN4FMOD3DSP9setBypassEb($720,0)|0);
     $723 = ($722|0)==(0);
     if ($723) {
      break;
     }
     $724 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($722)|0);
     HEAP32[$vararg_buffer142>>2] = 742056;
     $vararg_ptr139 = (($vararg_buffer142) + 4|0);
     HEAP32[$vararg_ptr139>>2] = 514;
     $vararg_ptr140 = (($vararg_buffer142) + 8|0);
     HEAP32[$vararg_ptr140>>2] = $724;
     $vararg_ptr141 = (($vararg_buffer142) + 12|0);
     HEAP32[$vararg_ptr141>>2] = $722;
     _printf_console(742016,$vararg_buffer142);
    }
   } while(0);
   $725 = (($i44$034) + 1)|0;
   $726 = HEAP32[$54>>2]|0;
   $727 = ($725>>>0)<($726>>>0);
   if ($727) {
    $i44$034 = $725;
   } else {
    break;
   }
  }
 }
 $716 = HEAP32[$constant>>2]|0;
 $717 = ($716|0)==(0);
 if (!($717)) {
  $i46$033 = 0;
  while(1) {
   $728 = HEAP32[$46>>2]|0;
   $729 = (($728) + ($i46$033<<2)|0);
   $730 = HEAP32[$729>>2]|0;
   $731 = ($730|0)==(0|0);
   do {
    if (!($731)) {
     $732 = (__ZN4FMOD3DSP9setBypassEb($730,0)|0);
     $733 = ($732|0)==(0);
     if ($733) {
      break;
     }
     $734 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($732)|0);
     HEAP32[$vararg_buffer142>>2] = 742056;
     $vararg_ptr145 = (($vararg_buffer142) + 4|0);
     HEAP32[$vararg_ptr145>>2] = 518;
     $vararg_ptr146 = (($vararg_buffer142) + 8|0);
     HEAP32[$vararg_ptr146>>2] = $734;
     $vararg_ptr147 = (($vararg_buffer142) + 12|0);
     HEAP32[$vararg_ptr147>>2] = $732;
     _printf_console(742016,$vararg_buffer142);
    }
   } while(0);
   $735 = (($i46$033) + 1)|0;
   $736 = HEAP32[$constant>>2]|0;
   $737 = ($735>>>0)<($736>>>0);
   if ($737) {
    $i46$033 = $735;
   } else {
    break;
   }
  }
 }
 if (!($enableSuspend)) {
  __ZN5audio5mixer22UpdateAudioMixerMemoryERKNS0_18AudioMixerConstantERNS0_16AudioMixerMemoryEfPN4FMOD6SystemEf($constant,$26,Math_fround(0.0),$system,Math_fround(1.0E+4));
  STACKTOP = sp;return ($26|0);
 }
 $738 = HEAP32[$34>>2]|0;
 $739 = (($738) + 28|0);
 $740 = HEAP32[$739>>2]|0;
 $741 = $740 | 4;
 HEAP32[$739>>2] = $741;
 __ZN5audio5mixer22UpdateAudioMixerMemoryERKNS0_18AudioMixerConstantERNS0_16AudioMixerMemoryEfPN4FMOD6SystemEf($constant,$26,Math_fround(0.0),$system,Math_fround(1.0E+4));
 STACKTOP = sp;return ($26|0);
}
function __ZL16FMOD_ErrorString11FMOD_RESULT16644($errcode) {
 $errcode = $errcode|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($errcode|0) {
  case 5:  {
   $$0 = 743424;
   break;
  }
  case 24:  {
   $$0 = 745752;
   break;
  }
  case 31:  {
   $$0 = 746120;
   break;
  }
  case 32:  {
   $$0 = 746184;
   break;
  }
  case 3:  {
   $$0 = 743312;
   break;
  }
  case 4:  {
   $$0 = 743360;
   break;
  }
  case 84:  {
   $$0 = 744832;
   break;
  }
  case 87:  {
   $$0 = 745064;
   break;
  }
  case 19:  {
   $$0 = 745456;
   break;
  }
  case 85:  {
   $$0 = 744888;
   break;
  }
  case 8:  {
   $$0 = 743536;
   break;
  }
  case 88:  {
   $$0 = 745232;
   break;
  }
  case 22:  {
   $$0 = 745632;
   break;
  }
  case 30:  {
   $$0 = 746088;
   break;
  }
  case 29:  {
   $$0 = 746056;
   break;
  }
  case 33:  {
   $$0 = 746232;
   break;
  }
  case 34:  {
   $$0 = 746296;
   break;
  }
  case 42:  {
   $$0 = 746816;
   break;
  }
  case 27:  {
   $$0 = 745912;
   break;
  }
  case 2:  {
   $$0 = 743176;
   break;
  }
  case 83:  {
   $$0 = 744672;
   break;
  }
  case 23:  {
   $$0 = 745728;
   break;
  }
  case 25:  {
   $$0 = 745784;
   break;
  }
  case 28:  {
   $$0 = 745984;
   break;
  }
  case 16:  {
   $$0 = 744176;
   break;
  }
  case 14:  {
   $$0 = 743928;
   break;
  }
  case 10:  {
   $$0 = 743616;
   break;
  }
  case 17:  {
   $$0 = 744240;
   break;
  }
  case 26:  {
   $$0 = 745824;
   break;
  }
  case 13:  {
   $$0 = 743872;
   break;
  }
  case 86:  {
   $$0 = 744960;
   break;
  }
  case 35:  {
   $$0 = 746400;
   break;
  }
  case 20:  {
   $$0 = 745480;
   break;
  }
  case 37:  {
   $$0 = 746496;
   break;
  }
  case 6:  {
   $$0 = 743464;
   break;
  }
  case 40:  {
   $$0 = 746696;
   break;
  }
  case 90:  {
   $$0 = 745280;
   break;
  }
  case 92:  {
   $$0 = 744536;
   break;
  }
  case 89:  {
   $$0 = 745368;
   break;
  }
  case 11:  {
   $$0 = 743656;
   break;
  }
  case 7:  {
   $$0 = 743504;
   break;
  }
  case 15:  {
   $$0 = 744072;
   break;
  }
  case 91:  {
   $$0 = 744784;
   break;
  }
  case 21:  {
   $$0 = 745592;
   break;
  }
  case 38:  {
   $$0 = 746552;
   break;
  }
  case 41:  {
   $$0 = 746752;
   break;
  }
  case 36:  {
   $$0 = 746456;
   break;
  }
  case 12:  {
   $$0 = 743720;
   break;
  }
  case 39:  {
   $$0 = 746608;
   break;
  }
  case 9:  {
   $$0 = 743584;
   break;
  }
  case 18:  {
   $$0 = 744432;
   break;
  }
  case 70:  {
   $$0 = 749480;
   break;
  }
  case 94:  {
   $$0 = 747176;
   break;
  }
  case 62:  {
   $$0 = 748800;
   break;
  }
  case 53:  {
   $$0 = 747976;
   break;
  }
  case 64:  {
   $$0 = 748952;
   break;
  }
  case 75:  {
   $$0 = 749688;
   break;
  }
  case 61:  {
   $$0 = 748696;
   break;
  }
  case 68:  {
   $$0 = 749248;
   break;
  }
  case 78:  {
   $$0 = 750600;
   break;
  }
  case 81:  {
   $$0 = 750872;
   break;
  }
  case 82:  {
   $$0 = 750920;
   break;
  }
  case 0:  {
   $$0 = 750984;
   break;
  }
  case 1:  {
   $$0 = 743112;
   break;
  }
  case 44:  {
   $$0 = 746928;
   break;
  }
  case 93:  {
   $$0 = 747224;
   break;
  }
  case 74:  {
   $$0 = 750248;
   break;
  }
  case 79:  {
   $$0 = 750680;
   break;
  }
  case 43:  {
   $$0 = 746888;
   break;
  }
  case 58:  {
   $$0 = 748432;
   break;
  }
  case 73:  {
   $$0 = 750128;
   break;
  }
  case 95:  {
   $$0 = 747112;
   break;
  }
  case 54:  {
   $$0 = 748048;
   break;
  }
  case 56:  {
   $$0 = 748256;
   break;
  }
  case 50:  {
   $$0 = 747784;
   break;
  }
  case 52:  {
   $$0 = 747928;
   break;
  }
  case 65:  {
   $$0 = 749024;
   break;
  }
  case 77:  {
   $$0 = 750448;
   break;
  }
  case 67:  {
   $$0 = 749152;
   break;
  }
  case 57:  {
   $$0 = 748296;
   break;
  }
  case 46:  {
   $$0 = 747304;
   break;
  }
  case 51:  {
   $$0 = 747832;
   break;
  }
  case 63:  {
   $$0 = 748896;
   break;
  }
  case 66:  {
   $$0 = 749088;
   break;
  }
  case 71:  {
   $$0 = 749544;
   break;
  }
  case 72:  {
   $$0 = 749976;
   break;
  }
  case 80:  {
   $$0 = 750760;
   break;
  }
  case 60:  {
   $$0 = 748656;
   break;
  }
  case 45:  {
   $$0 = 747056;
   break;
  }
  case 76:  {
   $$0 = 750384;
   break;
  }
  case 48:  {
   $$0 = 747464;
   break;
  }
  case 49:  {
   $$0 = 747592;
   break;
  }
  case 59:  {
   $$0 = 748552;
   break;
  }
  case 69:  {
   $$0 = 749368;
   break;
  }
  case 47:  {
   $$0 = 747384;
   break;
  }
  case 55:  {
   $$0 = 748136;
   break;
  }
  default: {
   $$0 = 751000;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN5audio5mixer22UpdateAudioMixerMemoryERKNS0_18AudioMixerConstantERNS0_16AudioMixerMemoryEfPN4FMOD6SystemEf($constant,$memory,$deltaTime,$system,$suspendThreshold) {
 $constant = $constant|0;
 $memory = $memory|0;
 $deltaTime = Math_fround($deltaTime);
 $system = $system|0;
 $suspendThreshold = Math_fround($suspendThreshold);
 var $$$i$i$i$i = Math_fround(0), $$$i$i$i3$i = Math_fround(0), $$0$i$i = Math_fround(0), $$0$i$i$i$us$i = Math_fround(0), $$0$i$i$i4$i = Math_fround(0), $$0$i$i4 = Math_fround(0), $$0$i1$i = Math_fround(0), $$0$i1$i5 = Math_fround(0), $$0$i1$us$i = Math_fround(0), $$0$i1$us16$i = Math_fround(0), $$0$i3$i = Math_fround(0), $$0$i8$i = Math_fround(0), $$mux$$i = 0, $$not$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0);
 var $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0);
 var $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0);
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0;
 var $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $brmerge$i = 0, $exitcond = 0, $exitcond11 = 0, $exitcond12 = 0, $exitcond13 = 0, $exitcond14 = 0, $exitcond15 = 0, $exitcond16 = 0, $from$to$i7$i = Math_fround(0), $i$01$i = 0;
 var $i$01$i2 = 0, $i$012$i = 0, $i$020$i = 0, $i3$07$i = 0, $i5$017$i = 0, $i6$010$i = 0, $i6$010$us$i = 0, $i6$010$us11$i = 0, $p$05$i = 0, $prevActiveState$i = 0, $to$from$i$us$i = Math_fround(0), $to$from$i6$i = Math_fround(0), $vararg_buffer28 = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr2 = 0, $vararg_ptr20 = 0;
 var $vararg_ptr21 = 0, $vararg_ptr25 = 0, $vararg_ptr26 = 0, $vararg_ptr27 = 0, $vararg_ptr3 = 0, $vararg_ptr31 = 0, $vararg_ptr32 = 0, $vararg_ptr33 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, $wasEffectBypassed$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer28 = sp;
 $prevActiveState$i = sp + 16|0;
 $wasEffectBypassed$i = sp + 20|0;
 $0 = (($memory) + 20|0);
 $1 = (($memory) + 48|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = !($2 <= Math_fround(0.0));
 if ($3) {
  $5 = Math_fround($deltaTime / $2);
  $6 = (($memory) + 44|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround($5 + $7);
  HEAPF32[$6>>2] = $8;
  $10 = $8;
 } else {
  $4 = (($memory) + 44|0);
  HEAPF32[$4>>2] = Math_fround(1.0);
  $10 = Math_fround(1.0);
 }
 $9 = (($memory) + 44|0);
 $11 = (Math_fround(+(_fminf(1.0,(+$10)))));
 HEAPF32[$9>>2] = $11;
 $12 = (($memory) + 56|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 L5: do {
  if ($14) {
   $33 = (($memory) + 60|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($constant) + 52|0);
   $36 = $35;
   $37 = HEAP32[$35>>2]|0;
   $38 = (($37) + ($36))|0;
   $39 = $38;
   $40 = ((($39) + (($34*40)|0)|0) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($memory) + 24|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ((($39) + (($34*40)|0)|0) + 8|0);
   $45 = $44;
   $46 = HEAP32[$44>>2]|0;
   $47 = (($45) + ($46))|0;
   $48 = $47;
   $49 = ((($39) + (($34*40)|0)|0) + 12|0);
   HEAP32[$49>>2] = $48;
   $50 = (($memory) + 28|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = HEAP32[$0>>2]|0;
   $53 = ($52|0)==(0);
   if (!($53)) {
    $54 = $11 < Math_fround(0.0);
    $55 = $11 > Math_fround(1.0);
    $$$i$i$i3$i = $55 ? Math_fround(1.0) : $11;
    $56 = Math_fround($11 * $11);
    $57 = $11 > Math_fround(9.99999971718068536574E-10);
    $58 = $11 < Math_fround(1.0);
    $$0$i$i$i4$i = $54 ? Math_fround(0.0) : $$$i$i$i3$i;
    $59 = Math_fround($$0$i$i$i4$i * Math_fround(-2.0));
    $60 = Math_fround($$0$i$i$i4$i * $59);
    $61 = Math_fround($$0$i$i$i4$i * $60);
    $62 = Math_fround($$0$i$i$i4$i * Math_fround(3.0));
    $63 = Math_fround($$0$i$i$i4$i * $62);
    $64 = Math_fround($63 + $61);
    $65 = Math_fround(Math_fround(1.0) - $64);
    $66 = Math_fround($65 * Math_fround(0.0));
    $67 = Math_fround($64 + $66);
    $i5$017$i = 0;
    while(1) {
     $146 = (($43) + ($i5$017$i<<2)|0);
     $147 = Math_fround(HEAPF32[$146>>2]);
     $148 = (($48) + ($i5$017$i<<2)|0);
     $149 = Math_fround(HEAPF32[$148>>2]);
     $150 = $147 == $149;
     L17: do {
      if ($150) {
       $$0$i8$i = $149;
      } else {
       switch ($41|0) {
       case 1:  {
        $154 = Math_fround($149 - $147);
        $155 = Math_fround($67 * $154);
        $156 = Math_fround($147 + $155);
        $$0$i8$i = $156;
        break L17;
        break;
       }
       case 2:  {
        $157 = Math_fround($149 - $147);
        $158 = Math_fround($56 * $157);
        $159 = Math_fround($147 + $158);
        $$0$i8$i = $159;
        break L17;
        break;
       }
       case 0:  {
        $151 = Math_fround($149 - $147);
        $152 = Math_fround($11 * $151);
        $153 = Math_fround($147 + $152);
        $$0$i8$i = $153;
        break L17;
        break;
       }
       case 4:  {
        $to$from$i6$i = $57 ? $149 : $147;
        $$0$i8$i = $to$from$i6$i;
        break L17;
        break;
       }
       case 3:  {
        $160 = Math_fround($149 - $147);
        $161 = (Math_fround(Math_sqrt((Math_fround($11)))));
        $162 = Math_fround($160 * $161);
        $163 = Math_fround($147 + $162);
        $$0$i8$i = $163;
        break L17;
        break;
       }
       case 5:  {
        $from$to$i7$i = $58 ? $147 : $149;
        $$0$i8$i = $from$to$i7$i;
        break L17;
        break;
       }
       default: {
        $$0$i8$i = Math_fround(0.0);
        break L17;
       }
       }
      }
     } while(0);
     $164 = (($51) + ($i5$017$i<<2)|0);
     HEAPF32[$164>>2] = $$0$i8$i;
     $165 = (($i5$017$i) + 1)|0;
     $exitcond15 = ($165|0)==($52|0);
     if ($exitcond15) {
      break;
     } else {
      $i5$017$i = $165;
     }
    }
   }
   $68 = ((($39) + (($34*40)|0)|0) + 20|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0);
   if ($70) {
    $209 = $51;$216 = $52;
   } else {
    $71 = ((($39) + (($34*40)|0)|0) + 32|0);
    $72 = $71;
    $73 = HEAP32[$71>>2]|0;
    $74 = (($73) + ($72))|0;
    $75 = $74;
    $76 = ((($39) + (($34*40)|0)|0) + 24|0);
    $77 = $76;
    $78 = $11 < Math_fround(0.0);
    $79 = $11 > Math_fround(1.0);
    $$$i$i$i$i = $79 ? Math_fround(1.0) : $11;
    $80 = Math_fround($11 * $11);
    $81 = $11 > Math_fround(9.99999971718068536574E-10);
    $82 = $11 < Math_fround(1.0);
    $$0$i$i$i$us$i = $78 ? Math_fround(0.0) : $$$i$i$i$i;
    $83 = Math_fround($$0$i$i$i$us$i * Math_fround(-2.0));
    $84 = Math_fround($$0$i$i$i$us$i * $83);
    $85 = Math_fround($$0$i$i$i$us$i * $84);
    $86 = Math_fround($$0$i$i$i$us$i * Math_fround(3.0));
    $87 = Math_fround($$0$i$i$i$us$i * $86);
    $88 = Math_fround($87 + $85);
    $89 = Math_fround(Math_fround(1.0) - $88);
    $90 = Math_fround($89 * Math_fround(0.0));
    $91 = Math_fround($88 + $90);
    if ($82) {
     $i6$010$us$i = 0;
     while(1) {
      $92 = (($75) + ($i6$010$us$i<<2)|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = (($43) + ($93<<2)|0);
      $95 = Math_fround(HEAPF32[$94>>2]);
      $96 = (($48) + ($93<<2)|0);
      $97 = Math_fround(HEAPF32[$96>>2]);
      $98 = $95 == $97;
      L32: do {
       if ($98) {
        $$0$i1$us$i = $97;
       } else {
        $99 = HEAP32[$76>>2]|0;
        $100 = (($99) + ($77))|0;
        $101 = $100;
        $102 = (($101) + ($i6$010$us$i<<2)|0);
        $103 = HEAP32[$102>>2]|0;
        switch ($103|0) {
        case 0:  {
         $114 = Math_fround($97 - $95);
         $115 = Math_fround($11 * $114);
         $116 = Math_fround($95 + $115);
         $$0$i1$us$i = $116;
         break L32;
         break;
        }
        case 1:  {
         $111 = Math_fround($97 - $95);
         $112 = Math_fround($91 * $111);
         $113 = Math_fround($95 + $112);
         $$0$i1$us$i = $113;
         break L32;
         break;
        }
        case 2:  {
         $108 = Math_fround($97 - $95);
         $109 = Math_fround($80 * $108);
         $110 = Math_fround($95 + $109);
         $$0$i1$us$i = $110;
         break L32;
         break;
        }
        case 5:  {
         $$0$i1$us$i = $95;
         break L32;
         break;
        }
        case 4:  {
         $to$from$i$us$i = $81 ? $97 : $95;
         $$0$i1$us$i = $to$from$i$us$i;
         break L32;
         break;
        }
        case 3:  {
         $104 = Math_fround($97 - $95);
         $105 = (Math_fround(Math_sqrt((Math_fround($11)))));
         $106 = Math_fround($104 * $105);
         $107 = Math_fround($95 + $106);
         $$0$i1$us$i = $107;
         break L32;
         break;
        }
        default: {
         $$0$i1$us$i = Math_fround(0.0);
         break L32;
        }
        }
       }
      } while(0);
      $117 = (($51) + ($93<<2)|0);
      HEAPF32[$117>>2] = $$0$i1$us$i;
      $118 = (($i6$010$us$i) + 1)|0;
      $exitcond12 = ($118|0)==($69|0);
      if ($exitcond12) {
       $209 = $51;$216 = $52;
       break L5;
      } else {
       $i6$010$us$i = $118;
      }
     }
    }
    if ($81) {
     $i6$010$us11$i = 0;
     while(1) {
      $119 = (($75) + ($i6$010$us11$i<<2)|0);
      $120 = HEAP32[$119>>2]|0;
      $121 = (($43) + ($120<<2)|0);
      $122 = Math_fround(HEAPF32[$121>>2]);
      $123 = (($48) + ($120<<2)|0);
      $124 = Math_fround(HEAPF32[$123>>2]);
      $125 = $122 == $124;
      L58: do {
       if ($125) {
        $$0$i1$us16$i = $124;
       } else {
        $126 = HEAP32[$76>>2]|0;
        $127 = (($126) + ($77))|0;
        $128 = $127;
        $129 = (($128) + ($i6$010$us11$i<<2)|0);
        $130 = HEAP32[$129>>2]|0;
        switch ($130|0) {
        case 5:  {
         $$0$i1$us16$i = $124;
         break L58;
         break;
        }
        case 3:  {
         $131 = Math_fround($124 - $122);
         $132 = (Math_fround(Math_sqrt((Math_fround($11)))));
         $133 = Math_fround($131 * $132);
         $134 = Math_fround($122 + $133);
         $$0$i1$us16$i = $134;
         break L58;
         break;
        }
        case 4:  {
         $$0$i1$us16$i = $124;
         break L58;
         break;
        }
        case 1:  {
         $138 = Math_fround($124 - $122);
         $139 = Math_fround($91 * $138);
         $140 = Math_fround($122 + $139);
         $$0$i1$us16$i = $140;
         break L58;
         break;
        }
        case 2:  {
         $135 = Math_fround($124 - $122);
         $136 = Math_fround($80 * $135);
         $137 = Math_fround($122 + $136);
         $$0$i1$us16$i = $137;
         break L58;
         break;
        }
        case 0:  {
         $141 = Math_fround($124 - $122);
         $142 = Math_fround($11 * $141);
         $143 = Math_fround($122 + $142);
         $$0$i1$us16$i = $143;
         break L58;
         break;
        }
        default: {
         $$0$i1$us16$i = Math_fround(0.0);
         break L58;
        }
        }
       }
      } while(0);
      $144 = (($51) + ($120<<2)|0);
      HEAPF32[$144>>2] = $$0$i1$us16$i;
      $145 = (($i6$010$us11$i) + 1)|0;
      $exitcond13 = ($145|0)==($69|0);
      if ($exitcond13) {
       $209 = $51;$216 = $52;
       break;
      } else {
       $i6$010$us11$i = $145;
      }
     }
    } else {
     $i6$010$i = 0;
     while(1) {
      $166 = (($75) + ($i6$010$i<<2)|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = (($43) + ($167<<2)|0);
      $169 = Math_fround(HEAPF32[$168>>2]);
      $170 = (($48) + ($167<<2)|0);
      $171 = Math_fround(HEAPF32[$170>>2]);
      $172 = $169 == $171;
      L46: do {
       if ($172) {
        $$0$i1$i = $171;
       } else {
        $173 = HEAP32[$76>>2]|0;
        $174 = (($173) + ($77))|0;
        $175 = $174;
        $176 = (($175) + ($i6$010$i<<2)|0);
        $177 = HEAP32[$176>>2]|0;
        switch ($177|0) {
        case 0:  {
         $178 = Math_fround($171 - $169);
         $179 = Math_fround($11 * $178);
         $180 = Math_fround($169 + $179);
         $$0$i1$i = $180;
         break L46;
         break;
        }
        case 1:  {
         $181 = Math_fround($171 - $169);
         $182 = Math_fround($91 * $181);
         $183 = Math_fround($169 + $182);
         $$0$i1$i = $183;
         break L46;
         break;
        }
        case 3:  {
         $187 = Math_fround($171 - $169);
         $188 = (Math_fround(Math_sqrt((Math_fround($11)))));
         $189 = Math_fround($187 * $188);
         $190 = Math_fround($169 + $189);
         $$0$i1$i = $190;
         break L46;
         break;
        }
        case 5:  {
         $$0$i1$i = $171;
         break L46;
         break;
        }
        case 2:  {
         $184 = Math_fround($171 - $169);
         $185 = Math_fround($80 * $184);
         $186 = Math_fround($169 + $185);
         $$0$i1$i = $186;
         break L46;
         break;
        }
        case 4:  {
         $$0$i1$i = $169;
         break L46;
         break;
        }
        default: {
         $$0$i1$i = Math_fround(0.0);
         break L46;
        }
        }
       }
      } while(0);
      $191 = (($51) + ($167<<2)|0);
      HEAPF32[$191>>2] = $$0$i1$i;
      $192 = (($i6$010$i) + 1)|0;
      $exitcond14 = ($192|0)==($69|0);
      if ($exitcond14) {
       $209 = $51;$216 = $52;
       break;
      } else {
       $i6$010$i = $192;
      }
     }
    }
   }
  } else {
   $15 = (($memory) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($memory) + 52|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($memory) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = HEAP32[$0>>2]|0;
   $22 = ($21|0)==(0);
   if ($22) {
    $209 = $20;$216 = 0;
   } else {
    $i$020$i = 0;
    while(1) {
     $23 = (($16) + ($i$020$i<<2)|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $25 = (($18) + ($i$020$i<<2)|0);
     $26 = Math_fround(HEAPF32[$25>>2]);
     $27 = $24 == $26;
     if ($27) {
      $$0$i$i = $26;
     } else {
      $28 = Math_fround($26 - $24);
      $29 = Math_fround($11 * $28);
      $30 = Math_fround($24 + $29);
      $$0$i$i = $30;
     }
     $31 = (($20) + ($i$020$i<<2)|0);
     HEAPF32[$31>>2] = $$0$i$i;
     $32 = (($i$020$i) + 1)|0;
     $exitcond16 = ($32|0)==($21|0);
     if ($exitcond16) {
      $209 = $20;$216 = $21;
      break;
     } else {
      $i$020$i = $32;
     }
    }
   }
  }
 } while(0);
 $193 = (($constant) + 104|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194|0)==(0);
 if (!($195)) {
  $196 = (($memory) + 40|0);
  $197 = HEAP32[$196>>2]|0;
  $198 = (($constant) + 116|0);
  $199 = $198;
  $i$01$i = 0;
  while(1) {
   $200 = (($197) + ($i$01$i<<2)|0);
   $201 = Math_fround(HEAPF32[$200>>2]);
   $202 = $201 == Math_fround(-inf);
   if (!($202)) {
    $203 = HEAP32[$198>>2]|0;
    $204 = (($203) + ($199))|0;
    $205 = $204;
    $206 = (($205) + ($i$01$i<<2)|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = (($209) + ($207<<2)|0);
    HEAPF32[$208>>2] = $201;
   }
   $210 = (($i$01$i) + 1)|0;
   $exitcond11 = ($210|0)==($194|0);
   if ($exitcond11) {
    break;
   } else {
    $i$01$i = $210;
   }
  }
 }
 $211 = (($memory) + 32|0);
 $212 = HEAP32[$211>>2]|0;
 $213 = (($memory) + 36|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = ($216|0)==(0);
 if (!($215)) {
  $i$01$i2 = 0;
  while(1) {
   $217 = (($209) + ($i$01$i2<<2)|0);
   $218 = Math_fround(HEAPF32[$217>>2]);
   $219 = (($212) + ($i$01$i2<<2)|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = $220 != $218;
   $222 = (($214) + ($i$01$i2)|0);
   $223 = $221&1;
   HEAP8[$222>>0] = $223;
   $224 = (($i$01$i2) + 1)|0;
   $exitcond = ($224|0)==($216|0);
   if ($exitcond) {
    break;
   } else {
    $i$01$i2 = $224;
   }
  }
 }
 HEAP32[$prevActiveState$i>>2] = 48000;
 $225 = (__ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($system,$prevActiveState$i,0,0,0,0,0)|0);
 $226 = ($225|0)==(0);
 if (!($226)) {
  $227 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($225)|0);
  HEAP32[$vararg_buffer28>>2] = 742056;
  $vararg_ptr1 = (($vararg_buffer28) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 707;
  $vararg_ptr2 = (($vararg_buffer28) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $227;
  $vararg_ptr3 = (($vararg_buffer28) + 12|0);
  HEAP32[$vararg_ptr3>>2] = $225;
  _printf_console(742016,$vararg_buffer28);
 }
 $228 = HEAP32[$constant>>2]|0;
 $229 = ($228|0)==(0);
 if (!($229)) {
  $230 = (($constant) + 4|0);
  $231 = $230;
  $232 = (($memory) + 12|0);
  $233 = (($memory) + 8|0);
  $i$012$i = 0;
  while(1) {
   $242 = HEAP32[$230>>2]|0;
   $243 = (($242) + ($231))|0;
   $244 = $243;
   $245 = ((($244) + ($i$012$i<<4)|0) + 4|0);
   $246 = HEAP32[$245>>2]|0;
   $247 = (($214) + ($246)|0);
   $248 = HEAP8[$247>>0]|0;
   $249 = ($248<<24>>24)==(0);
   if (!($249)) {
    $250 = (($209) + ($246<<2)|0);
    $251 = Math_fround(HEAPF32[$250>>2]);
    $252 = !($251 <= Math_fround(-80.0));
    if ($252) {
     $253 = Math_fround($251 * Math_fround(0.0500000007450580596924));
     $254 = (Math_fround(+(_log2f(10.0))));
     $255 = Math_fround($253 * $254);
     $256 = (Math_fround(+(_exp2f((+$255)))));
     $$0$i$i4 = $256;
    } else {
     $$0$i$i4 = Math_fround(0.0);
    }
    $257 = HEAP32[$232>>2]|0;
    $258 = ((($257) + ($i$012$i<<8)|0) + 28|0);
    $259 = HEAP32[$258>>2]|0;
    $260 = $259 & 1;
    $261 = ($260|0)==(0);
    if (!($261)) {
     $262 = (($257) + ($i$012$i<<8)|0);
     HEAPF32[$262>>2] = $$0$i$i4;
     $263 = HEAP32[$memory>>2]|0;
     $264 = (($263) + ($i$012$i<<2)|0);
     $265 = HEAP32[$264>>2]|0;
     $266 = (__ZN4FMOD12ChannelGroup19setAudibilityFactorEf($265,$$0$i$i4)|0);
     $267 = ($266|0)==(0);
     if (!($267)) {
      $268 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($266)|0);
      HEAP32[$vararg_buffer28>>2] = 742056;
      $vararg_ptr7 = (($vararg_buffer28) + 4|0);
      HEAP32[$vararg_ptr7>>2] = 720;
      $vararg_ptr8 = (($vararg_buffer28) + 8|0);
      HEAP32[$vararg_ptr8>>2] = $268;
      $vararg_ptr9 = (($vararg_buffer28) + 12|0);
      HEAP32[$vararg_ptr9>>2] = $266;
      _printf_console(742016,$vararg_buffer28);
     }
    }
    $269 = HEAP32[$233>>2]|0;
    $270 = ((($269) + ($i$012$i<<8)|0) + 28|0);
    $271 = HEAP32[$270>>2]|0;
    $272 = $271 & 1;
    $273 = ($272|0)==(0);
    if (!($273)) {
     $274 = (($269) + ($i$012$i<<8)|0);
     HEAPF32[$274>>2] = $$0$i$i4;
     $275 = HEAP32[$memory>>2]|0;
     $276 = (($275) + ($i$012$i<<2)|0);
     $277 = HEAP32[$276>>2]|0;
     $278 = (__ZN4FMOD12ChannelGroup19setAudibilityFactorEf($277,$$0$i$i4)|0);
     $279 = ($278|0)==(0);
     if (!($279)) {
      $280 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($278)|0);
      HEAP32[$vararg_buffer28>>2] = 742056;
      $vararg_ptr13 = (($vararg_buffer28) + 4|0);
      HEAP32[$vararg_ptr13>>2] = 725;
      $vararg_ptr14 = (($vararg_buffer28) + 8|0);
      HEAP32[$vararg_ptr14>>2] = $280;
      $vararg_ptr15 = (($vararg_buffer28) + 12|0);
      HEAP32[$vararg_ptr15>>2] = $278;
      _printf_console(742016,$vararg_buffer28);
     }
    }
   }
   $281 = ((($244) + ($i$012$i<<4)|0) + 8|0);
   $282 = HEAP32[$281>>2]|0;
   $283 = (($214) + ($282)|0);
   $284 = HEAP8[$283>>0]|0;
   $285 = ($284<<24>>24)==(0);
   if (!($285)) {
    $286 = HEAP32[$memory>>2]|0;
    $287 = (($286) + ($i$012$i<<2)|0);
    $288 = HEAP32[$287>>2]|0;
    $289 = (($209) + ($282<<2)|0);
    $290 = Math_fround(HEAPF32[$289>>2]);
    (__ZN4FMOD12ChannelGroup8setPitchEf($288,$290)|0);
   }
   $291 = (($i$012$i) + 1)|0;
   $292 = HEAP32[$constant>>2]|0;
   $293 = ($291>>>0)<($292>>>0);
   if ($293) {
    $i$012$i = $291;
   } else {
    break;
   }
  }
 }
 $234 = (($constant) + 20|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = ($235|0)==(0);
 if (!($236)) {
  $237 = (($constant) + 24|0);
  $238 = $237;
  $239 = (($memory) + 16|0);
  $240 = (($constant) + 4|0);
  $241 = $240;
  $i3$07$i = 0;
  while(1) {
   $294 = HEAP32[$237>>2]|0;
   $295 = (($294) + ($238))|0;
   $296 = $295;
   $297 = HEAP32[$239>>2]|0;
   $298 = (($297) + ($i3$07$i<<5)|0);
   $299 = ((($296) + (($i3$07$i*36)|0)|0) + 12|0);
   $300 = HEAP32[$299>>2]|0;
   $301 = ($300|0)==(-1);
   if (!($301)) {
    $302 = (($214) + ($300)|0);
    $303 = HEAP8[$302>>0]|0;
    $304 = ($303<<24>>24)==(0);
    if (!($304)) {
     $305 = HEAP32[$298>>2]|0;
     $306 = ($305|0)==(0|0);
     if (!($306)) {
      $307 = (($209) + ($300<<2)|0);
      $308 = Math_fround(HEAPF32[$307>>2]);
      $309 = !($308 <= Math_fround(-80.0));
      if ($309) {
       $310 = Math_fround($308 * Math_fround(0.0500000007450580596924));
       $311 = (Math_fround(+(_log2f(10.0))));
       $312 = Math_fround($310 * $311);
       $313 = (Math_fround(+(_exp2f((+$312)))));
       $$0$i3$i = $313;
      } else {
       $$0$i3$i = Math_fround(0.0);
      }
      $314 = ((($297) + ($i3$07$i<<5)|0) + 12|0);
      HEAPF32[$314>>2] = $$0$i3$i;
      $315 = ((($297) + ($i3$07$i<<5)|0) + 4|0);
      $316 = HEAP32[$315>>2]|0;
      $317 = ($316|0)==(0|0);
      if (!($317)) {
       (__ZN4FMOD13DSPConnection6setMixEf(($316|0),(+$$0$i3$i))|0);
       $318 = ((($297) + ($i3$07$i<<5)|0) + 8|0);
       $319 = HEAP32[$318>>2]|0;
       $320 = ($319|0)==(0|0);
       if (!($320)) {
        $321 = ((($296) + (($i3$07$i*36)|0)|0) + 16|0);
        $322 = HEAP32[$321>>2]|0;
        $323 = ($322|0)==(-1);
        if ($323) {
         $332 = Math_fround(0.0);
         label = 85;
        } else {
         $324 = HEAP32[$239>>2]|0;
         $325 = ((($324) + ($322<<5)|0) + 8|0);
         $326 = HEAP32[$325>>2]|0;
         $327 = ($326|0)==(0|0);
         if ($327) {
          $332 = Math_fround(0.0);
          label = 85;
         } else {
          $328 = ((($324) + ($322<<5)|0) + 12|0);
          $329 = Math_fround(HEAPF32[$328>>2]);
          $330 = !($329 <= Math_fround(-80.0));
          if ($330) {
           $332 = $329;
           label = 85;
          } else {
           $$0$i1$i5 = Math_fround(0.0);
          }
         }
        }
        if ((label|0) == 85) {
         label = 0;
         $331 = Math_fround($332 * Math_fround(0.0500000007450580596924));
         $333 = (Math_fround(+(_log2f(10.0))));
         $334 = Math_fround($331 * $333);
         $335 = (Math_fround(+(_exp2f((+$334)))));
         $$0$i1$i5 = $335;
        }
        $336 = Math_fround(Math_fround(1.0) - $$0$i3$i);
        $337 = Math_fround($336 * $$0$i1$i5);
        (__ZN4FMOD13DSPConnection6setMixEf(($319|0),(+$337))|0);
       }
      }
      $338 = $$0$i3$i == Math_fround(0.0);
      if ($338) {
       $355 = 1;
      } else {
       $339 = ((($296) + (($i3$07$i*36)|0)|0) + 4|0);
       $340 = HEAP32[$339>>2]|0;
       $341 = HEAP32[$240>>2]|0;
       $342 = (($341) + ($241))|0;
       $343 = $342;
       $344 = ((($343) + ($340<<4)|0) + 14|0);
       $345 = HEAP8[$344>>0]|0;
       $346 = ($345<<24>>24)==(0);
       if ($346) {
        $347 = ((($296) + (($i3$07$i*36)|0)|0) + 20|0);
        $348 = HEAP8[$347>>0]|0;
        $349 = ($348<<24>>24)!=(0);
        $355 = $349;
       } else {
        $355 = 1;
       }
      }
      $350 = (($296) + (($i3$07$i*36)|0)|0);
      $351 = HEAP32[$350>>2]|0;
      $352 = ($351|0)>(-1);
      $$not$i = $338 ^ 1;
      $brmerge$i = $352 | $$not$i;
      $353 = ($351|0)==(-3);
      $$mux$$i = $brmerge$i ? $352 : $353;
      $354 = $355 & $$mux$$i;
      $356 = HEAP32[$298>>2]|0;
      $357 = (__ZN4FMOD3DSP9getBypassEPb($356,$wasEffectBypassed$i)|0);
      $358 = ($357|0)==(0);
      if (!($358)) {
       $359 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($357)|0);
       HEAP32[$vararg_buffer28>>2] = 742056;
       $vararg_ptr19 = (($vararg_buffer28) + 4|0);
       HEAP32[$vararg_ptr19>>2] = 783;
       $vararg_ptr20 = (($vararg_buffer28) + 8|0);
       HEAP32[$vararg_ptr20>>2] = $359;
       $vararg_ptr21 = (($vararg_buffer28) + 12|0);
       HEAP32[$vararg_ptr21>>2] = $357;
       _printf_console(742016,$vararg_buffer28);
      }
      $360 = $354&1;
      $361 = HEAP8[$wasEffectBypassed$i>>0]|0;
      $362 = $361&255;
      $363 = ($360|0)==($362|0);
      if (!($363)) {
       $364 = HEAP32[$298>>2]|0;
       $365 = (__ZN4FMOD3DSP9setBypassEb($364,$354)|0);
       $366 = ($365|0)==(0);
       if (!($366)) {
        $367 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($365)|0);
        HEAP32[$vararg_buffer28>>2] = 742056;
        $vararg_ptr25 = (($vararg_buffer28) + 4|0);
        HEAP32[$vararg_ptr25>>2] = 785;
        $vararg_ptr26 = (($vararg_buffer28) + 8|0);
        HEAP32[$vararg_ptr26>>2] = $367;
        $vararg_ptr27 = (($vararg_buffer28) + 12|0);
        HEAP32[$vararg_ptr27>>2] = $365;
        _printf_console(742016,$vararg_buffer28);
       }
      }
     }
    }
   }
   $368 = ((($296) + (($i3$07$i*36)|0)|0) + 24|0);
   $369 = HEAP32[$368>>2]|0;
   $370 = ($369|0)==(0);
   if (!($370)) {
    $371 = ((($296) + (($i3$07$i*36)|0)|0) + 28|0);
    $372 = $371;
    $p$05$i = 0;
    while(1) {
     $373 = HEAP32[$371>>2]|0;
     $374 = (($373) + ($372))|0;
     $375 = $374;
     $376 = (($375) + ($p$05$i<<2)|0);
     $377 = HEAP32[$376>>2]|0;
     $378 = (($214) + ($377)|0);
     $379 = HEAP8[$378>>0]|0;
     $380 = ($379<<24>>24)==(0);
     if (!($380)) {
      $381 = HEAP32[$298>>2]|0;
      $382 = ($381|0)==(0|0);
      if (!($382)) {
       $383 = (($209) + ($377<<2)|0);
       $384 = Math_fround(HEAPF32[$383>>2]);
       $385 = (__ZN4FMOD3DSP12setParameterEif($381,$p$05$i,$384)|0);
       $386 = ($385|0)==(0);
       if (!($386)) {
        $387 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($385)|0);
        HEAP32[$vararg_buffer28>>2] = 742056;
        $vararg_ptr31 = (($vararg_buffer28) + 4|0);
        HEAP32[$vararg_ptr31>>2] = 792;
        $vararg_ptr32 = (($vararg_buffer28) + 8|0);
        HEAP32[$vararg_ptr32>>2] = $387;
        $vararg_ptr33 = (($vararg_buffer28) + 12|0);
        HEAP32[$vararg_ptr33>>2] = $385;
        _printf_console(742016,$vararg_buffer28);
       }
      }
     }
     $388 = (($p$05$i) + 1)|0;
     $389 = HEAP32[$368>>2]|0;
     $390 = ($388>>>0)<($389>>>0);
     if ($390) {
      $p$05$i = $388;
     } else {
      break;
     }
    }
   }
   $391 = (($i3$07$i) + 1)|0;
   $392 = HEAP32[$234>>2]|0;
   $393 = ($391>>>0)<($392>>>0);
   if ($393) {
    $i3$07$i = $391;
   } else {
    break;
   }
  }
 }
 $394 = (($memory) + 20|0);
 $395 = HEAP32[$394>>2]|0;
 $396 = $395 << 2;
 _memcpy(($212|0),($209|0),($396|0))|0;
 $397 = HEAP32[$memory>>2]|0;
 $398 = HEAP32[$397>>2]|0;
 $399 = (__ZN5audio5mixerL19IsAnyChannelPlayingEPN4FMOD12ChannelGroupE($398)|0);
 if ($399) {
  __ZN5audio5mixer12SetSuspendedERNS0_16AudioMixerMemoryEb($memory,0);
  STACKTOP = sp;return;
 }
 $400 = (($memory) + 12|0);
 $401 = HEAP32[$400>>2]|0;
 $402 = (($401) + 28|0);
 $403 = HEAP32[$402>>2]|0;
 $404 = $403 & 4;
 $405 = ($404|0)==(0);
 if ($405) {
  STACKTOP = sp;return;
 }
 $406 = (($401) + 20|0);
 $407 = Math_fround(HEAPF32[$406>>2]);
 $408 = $407 < $suspendThreshold;
 if (!($408)) {
  STACKTOP = sp;return;
 }
 $409 = (($401) + 32|0);
 $410 = HEAP32[$409>>2]|0;
 $411 = ($410|0)==(0);
 if (!($411)) {
  STACKTOP = sp;return;
 }
 HEAP32[$409>>2] = -1;
 HEAP32[$vararg_buffer28>>2] = 0;
 $412 = HEAP32[$memory>>2]|0;
 $413 = HEAP32[$412>>2]|0;
 (__ZN4FMOD12ChannelGroup10getDSPHeadEPPNS_3DSPE($413,$vararg_buffer28)|0);
 HEAP8[$prevActiveState$i>>0] = 0;
 $414 = HEAP32[$vararg_buffer28>>2]|0;
 (__ZN4FMOD3DSP9getActiveEPb($414,$prevActiveState$i)|0);
 $415 = HEAP32[$vararg_buffer28>>2]|0;
 (__ZN4FMOD3DSP9setActiveEb($415,0)|0);
 STACKTOP = sp;return;
}
function __ZN5audio5mixer23DestroyAudioMixerMemoryEPNS0_16AudioMixerMemoryERKNS0_18AudioMixerConstantEPN4FMOD6SystemERN7mecanim6memory9AllocatorE($memory,$constant,$system,$alloc) {
 $memory = $memory|0;
 $constant = $constant|0;
 $system = $system|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$03 = 0, $i1$01 = 0, $vararg_buffer22 = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr2 = 0, $vararg_ptr20 = 0, $vararg_ptr21 = 0;
 var $vararg_ptr25 = 0, $vararg_ptr26 = 0, $vararg_ptr27 = 0, $vararg_ptr3 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer22 = sp;
 $0 = ($memory|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($constant) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($memory) + 16|0);
  $i$03 = 0;
  while(1) {
   $8 = HEAP32[$4>>2]|0;
   $9 = (($8) + ($i$03<<5)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    $12 = (__ZN4FMOD3DSP7releaseEv($10)|0);
    $13 = ($12|0)==(0);
    if (!($13)) {
     $14 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($12)|0);
     HEAP32[$vararg_buffer22>>2] = 742056;
     $vararg_ptr1 = (($vararg_buffer22) + 4|0);
     HEAP32[$vararg_ptr1>>2] = 539;
     $vararg_ptr2 = (($vararg_buffer22) + 8|0);
     HEAP32[$vararg_ptr2>>2] = $14;
     $vararg_ptr3 = (($vararg_buffer22) + 12|0);
     HEAP32[$vararg_ptr3>>2] = $12;
     _printf_console(742016,$vararg_buffer22);
    }
   }
   $15 = (($i$03) + 1)|0;
   $16 = HEAP32[$1>>2]|0;
   $17 = ($15>>>0)<($16>>>0);
   if ($17) {
    $i$03 = $15;
   } else {
    break;
   }
  }
 }
 $5 = HEAP32[$constant>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($memory) + 4|0);
  $i1$01 = 0;
  while(1) {
   $18 = HEAP32[$7>>2]|0;
   $19 = (($18) + ($i1$01<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = (__ZN4FMOD3DSP7releaseEv($20)|0);
    $23 = ($22|0)==(0);
    if (!($23)) {
     $24 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($22)|0);
     HEAP32[$vararg_buffer22>>2] = 742056;
     $vararg_ptr7 = (($vararg_buffer22) + 4|0);
     HEAP32[$vararg_ptr7>>2] = 544;
     $vararg_ptr8 = (($vararg_buffer22) + 8|0);
     HEAP32[$vararg_ptr8>>2] = $24;
     $vararg_ptr9 = (($vararg_buffer22) + 12|0);
     HEAP32[$vararg_ptr9>>2] = $22;
     _printf_console(742016,$vararg_buffer22);
    }
   }
   $25 = HEAP32[$memory>>2]|0;
   $26 = (($25) + ($i1$01<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (__ZN4FMOD12ChannelGroup7releaseEv($27)|0);
   $29 = ($28|0)==(0);
   if (!($29)) {
    $30 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($28)|0);
    HEAP32[$vararg_buffer22>>2] = 742056;
    $vararg_ptr13 = (($vararg_buffer22) + 4|0);
    HEAP32[$vararg_ptr13>>2] = 545;
    $vararg_ptr14 = (($vararg_buffer22) + 8|0);
    HEAP32[$vararg_ptr14>>2] = $30;
    $vararg_ptr15 = (($vararg_buffer22) + 12|0);
    HEAP32[$vararg_ptr15>>2] = $28;
    _printf_console(742016,$vararg_buffer22);
   }
   $31 = (($i1$01) + 1)|0;
   $32 = HEAP32[$constant>>2]|0;
   $33 = ($31>>>0)<($32>>>0);
   if ($33) {
    $i1$01 = $31;
   } else {
    break;
   }
  }
 }
 $34 = (($memory) + 68|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (__ZN4FMOD12ChannelGroup7releaseEv($35)|0);
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($36)|0);
  HEAP32[$vararg_buffer22>>2] = 742056;
  $vararg_ptr19 = (($vararg_buffer22) + 4|0);
  HEAP32[$vararg_ptr19>>2] = 548;
  $vararg_ptr20 = (($vararg_buffer22) + 8|0);
  HEAP32[$vararg_ptr20>>2] = $38;
  $vararg_ptr21 = (($vararg_buffer22) + 12|0);
  HEAP32[$vararg_ptr21>>2] = $36;
  _printf_console(742016,$vararg_buffer22);
 }
 $39 = (__ZN4FMOD6System6updateEv($system)|0);
 $40 = ($39|0)==(0);
 if (!($40)) {
  $41 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($39)|0);
  HEAP32[$vararg_buffer22>>2] = 742056;
  $vararg_ptr25 = (($vararg_buffer22) + 4|0);
  HEAP32[$vararg_ptr25>>2] = 550;
  $vararg_ptr26 = (($vararg_buffer22) + 8|0);
  HEAP32[$vararg_ptr26>>2] = $41;
  $vararg_ptr27 = (($vararg_buffer22) + 12|0);
  HEAP32[$vararg_ptr27>>2] = $39;
  _printf_console(742016,$vararg_buffer22);
 }
 $42 = HEAP32[$alloc>>2]|0;
 $43 = (($42) + 4|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($memory) + 64|0);
 $46 = HEAP32[$45>>2]|0;
 FUNCTION_TABLE_vii[$44 & 4095]($alloc,$46);
 $47 = HEAP32[$alloc>>2]|0;
 $48 = (($47) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($memory) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 FUNCTION_TABLE_vii[$49 & 4095]($alloc,$51);
 $52 = HEAP32[$alloc>>2]|0;
 $53 = (($52) + 4|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($memory) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vii[$54 & 4095]($alloc,$56);
 $57 = HEAP32[$alloc>>2]|0;
 $58 = (($57) + 4|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$memory>>2]|0;
 FUNCTION_TABLE_vii[$59 & 4095]($alloc,$60);
 $61 = HEAP32[$alloc>>2]|0;
 $62 = (($61) + 4|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($memory) + 4|0);
 $65 = HEAP32[$64>>2]|0;
 FUNCTION_TABLE_vii[$63 & 4095]($alloc,$65);
 $66 = HEAP32[$alloc>>2]|0;
 $67 = (($66) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($memory) + 16|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($alloc,$70);
 $71 = HEAP32[$alloc>>2]|0;
 $72 = (($71) + 4|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($memory) + 24|0);
 $75 = HEAP32[$74>>2]|0;
 FUNCTION_TABLE_vii[$73 & 4095]($alloc,$75);
 $76 = HEAP32[$alloc>>2]|0;
 $77 = (($76) + 4|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($memory) + 28|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$78 & 4095]($alloc,$80);
 $81 = HEAP32[$alloc>>2]|0;
 $82 = (($81) + 4|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($memory) + 32|0);
 $85 = HEAP32[$84>>2]|0;
 FUNCTION_TABLE_vii[$83 & 4095]($alloc,$85);
 $86 = HEAP32[$alloc>>2]|0;
 $87 = (($86) + 4|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($memory) + 36|0);
 $90 = HEAP32[$89>>2]|0;
 FUNCTION_TABLE_vii[$88 & 4095]($alloc,$90);
 $91 = HEAP32[$alloc>>2]|0;
 $92 = (($91) + 4|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = (($memory) + 52|0);
 $95 = HEAP32[$94>>2]|0;
 FUNCTION_TABLE_vii[$93 & 4095]($alloc,$95);
 $96 = HEAP32[$alloc>>2]|0;
 $97 = (($96) + 4|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (($memory) + 40|0);
 $100 = HEAP32[$99>>2]|0;
 FUNCTION_TABLE_vii[$98 & 4095]($alloc,$100);
 $101 = HEAP32[$alloc>>2]|0;
 $102 = (($101) + 4|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($memory) + 72|0);
 $105 = HEAP32[$104>>2]|0;
 FUNCTION_TABLE_vii[$103 & 4095]($alloc,$105);
 $106 = HEAP32[$alloc>>2]|0;
 $107 = (($106) + 4|0);
 $108 = HEAP32[$107>>2]|0;
 FUNCTION_TABLE_vii[$108 & 4095]($alloc,$memory);
 STACKTOP = sp;return;
}
function __ZN5audio5mixerL19IsAnyChannelPlayingEPN4FMOD12ChannelGroupE($group) {
 $group = $group|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $channel = 0, $childGroup = 0, $i$06 = 0, $i1$02 = 0, $isPlaying = 0, $numChannels = 0, $numChildGroups = 0, $or$cond = 0, $or$cond11 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $numChannels = sp + 12|0;
 $channel = sp;
 $isPlaying = sp + 16|0;
 $numChildGroups = sp + 8|0;
 $childGroup = sp + 4|0;
 HEAP32[$numChannels>>2] = 0;
 $0 = (__ZN4FMOD12ChannelGroup14getNumChannelsEPi($group,$numChannels)|0);
 $1 = ($0|0)==(0);
 $2 = HEAP32[$numChannels>>2]|0;
 $3 = ($2|0)>(0);
 $or$cond9 = $1 & $3;
 L1: do {
  if ($or$cond9) {
   $i$06 = 0;
   while(1) {
    HEAP32[$channel>>2] = 0;
    $4 = (__ZN4FMOD12ChannelGroup10getChannelEiPPNS_7ChannelE($group,$i$06,$channel)|0);
    $5 = ($4|0)==(0);
    if ($5) {
     HEAP8[$isPlaying>>0] = 0;
     $6 = HEAP32[$channel>>2]|0;
     $7 = (__ZN4FMOD7Channel9isPlayingEPb($6,$isPlaying)|0);
     $8 = ($7|0)!=(0);
     $9 = HEAP8[$isPlaying>>0]|0;
     $10 = ($9<<24>>24)==(0);
     $or$cond = $8 | $10;
     if (!($or$cond)) {
      $$0 = 1;
      break;
     }
    }
    $11 = (($i$06) + 1)|0;
    $12 = HEAP32[$numChannels>>2]|0;
    $13 = ($11|0)<($12|0);
    if ($13) {
     $i$06 = $11;
    } else {
     break L1;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$numChildGroups>>2] = 0;
 $14 = (__ZN4FMOD12ChannelGroup12getNumGroupsEPi($group,$numChildGroups)|0);
 $15 = ($14|0)==(0);
 $16 = HEAP32[$numChildGroups>>2]|0;
 $17 = ($16|0)>(0);
 $or$cond11 = $15 & $17;
 if ($or$cond11) {
  $i1$02 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $18 = (__ZN4FMOD12ChannelGroup8getGroupEiPPS0_($group,$i1$02,$childGroup)|0);
  $19 = ($18|0)==(0);
  if ($19) {
   $20 = HEAP32[$childGroup>>2]|0;
   $21 = (__ZN5audio5mixerL19IsAnyChannelPlayingEPN4FMOD12ChannelGroupE($20)|0);
   if ($21) {
    $$0 = 1;
    label = 9;
    break;
   }
  }
  $22 = (($i1$02) + 1)|0;
  $23 = HEAP32[$numChildGroups>>2]|0;
  $24 = ($22|0)<($23|0);
  if ($24) {
   $i1$02 = $22;
  } else {
   $$0 = 0;
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN5audio5mixer12SetSuspendedERNS0_16AudioMixerMemoryEb($memory,$state) {
 $memory = $memory|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dspHead = 0, $prevActiveState = 0, $samplerate = 0, $system = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $dspHead = sp + 8|0;
 $prevActiveState = sp + 12|0;
 $system = sp + 4|0;
 $samplerate = sp;
 HEAP32[$dspHead>>2] = 0;
 $0 = HEAP32[$memory>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 (__ZN4FMOD12ChannelGroup10getDSPHeadEPPNS_3DSPE($1,$dspHead)|0);
 HEAP8[$prevActiveState>>0] = 0;
 $2 = HEAP32[$dspHead>>2]|0;
 (__ZN4FMOD3DSP9getActiveEPb($2,$prevActiveState)|0);
 if (!($state)) {
  $3 = HEAP8[$prevActiveState>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   HEAP32[$system>>2] = 0;
   $5 = HEAP32[$dspHead>>2]|0;
   (__ZN4FMOD3DSP15getSystemObjectEPPNS_6SystemE($5,$system)|0);
   $6 = HEAP32[$system>>2]|0;
   (__ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($6,$samplerate,0,0,0,0,0)|0);
   $7 = HEAP32[$samplerate>>2]|0;
   $8 = (($memory) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($9) + 32|0);
   HEAP32[$10>>2] = $7;
  }
 }
 $11 = HEAP32[$dspHead>>2]|0;
 $12 = $state ^ 1;
 (__ZN4FMOD3DSP9setActiveEb($11,$12)|0);
 STACKTOP = sp;return;
}
function __ZN5audio5mixer16FindChannelGroupERKNS0_18AudioMixerConstantERKNS0_16AudioMixerMemoryERK9UnityGUID($constant,$memory,$guid) {
 $constant = $constant|0;
 $memory = $memory|0;
 $guid = $guid|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$constant>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($constant) + 12|0);
 $3 = $2;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + ($3))|0;
 $6 = $5;
 $7 = HEAP32[$guid>>2]|0;
 $8 = (($guid) + 4|0);
 $9 = (($guid) + 8|0);
 $10 = (($guid) + 12|0);
 $i$01$i = 0;
 while(1) {
  $11 = (($6) + ($i$01$i<<4)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($7|0);
  if ($13) {
   $14 = ((($6) + ($i$01$i<<4)|0) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$8>>2]|0;
   $17 = ($15|0)==($16|0);
   if ($17) {
    $18 = ((($6) + ($i$01$i<<4)|0) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$9>>2]|0;
    $21 = ($19|0)==($20|0);
    if ($21) {
     $22 = ((($6) + ($i$01$i<<4)|0) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = HEAP32[$10>>2]|0;
     $25 = ($23|0)==($24|0);
     if ($25) {
      break;
     }
    }
   }
  }
  $26 = (($i$01$i) + 1)|0;
  $27 = ($26>>>0)<($0>>>0);
  if ($27) {
   $i$01$i = $26;
  } else {
   $$0 = 0;
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 $28 = ($i$01$i|0)==(-1);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($memory) + 64|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = (($30) + ($i$01$i)|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)==(0);
  if (!($34)) {
   $35 = (($memory) + 68|0);
   $36 = HEAP32[$35>>2]|0;
   $$0 = $36;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $37 = HEAP32[$memory>>2]|0;
 $38 = (($37) + ($i$01$i<<2)|0);
 $39 = HEAP32[$38>>2]|0;
 $$0 = $39;
 STACKTOP = sp;return ($$0|0);
}
function __ZN5audio5mixer17AssignOutputGroupERKNS0_18AudioMixerConstantERKNS0_16AudioMixerMemoryEPN4FMOD12ChannelGroupE($constant,$memory,$parent) {
 $constant = $constant|0;
 $memory = $memory|0;
 $parent = $parent|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$memory>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN4FMOD12ChannelGroup8addGroupEPS0_($parent,$1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($2)|0);
 HEAP32[$vararg_buffer>>2] = 742056;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 1065;
 $vararg_ptr2 = (($vararg_buffer) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $4;
 $vararg_ptr3 = (($vararg_buffer) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $2;
 _printf_console(742016,$vararg_buffer);
 STACKTOP = sp;return;
}
function __ZN5audio5mixer12UpdateBypassERNS0_18AudioMixerConstantERNS0_16AudioMixerMemoryE($constant,$memory) {
 $constant = $constant|0;
 $memory = $memory|0;
 var $$mux$ = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $i$01 = 0, $vararg_buffer4 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr7 = 0;
 var $vararg_ptr8 = 0, $vararg_ptr9 = 0, $wasEffectBypassed = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer4 = sp;
 $wasEffectBypassed = sp + 16|0;
 $0 = (($constant) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($constant) + 24|0);
 $4 = $3;
 $5 = (($constant) + 28|0);
 $6 = (($memory) + 16|0);
 $7 = (($constant) + 4|0);
 $8 = $7;
 $9 = (($constant) + 8|0);
 $i$01 = 0;
 while(1) {
  $10 = HEAP32[$3>>2]|0;
  $11 = (($10) + ($4))|0;
  $12 = $11;
  HEAP32[$5>>2] = $12;
  $13 = HEAP32[$6>>2]|0;
  $14 = ((($13) + ($i$01<<5)|0) + 12|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = $15 == Math_fround(0.0);
  if ($16) {
   $33 = 1;
  } else {
   $17 = ((($12) + (($i$01*36)|0)|0) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$7>>2]|0;
   $20 = (($19) + ($8))|0;
   $21 = $20;
   HEAP32[$9>>2] = $21;
   $22 = ((($21) + ($18<<4)|0) + 14|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    $25 = ((($12) + (($i$01*36)|0)|0) + 20|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)!=(0);
    $33 = $27;
   } else {
    $33 = 1;
   }
  }
  $28 = (($12) + (($i$01*36)|0)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)>(-1);
  $$not = $16 ^ 1;
  $brmerge = $30 | $$not;
  $31 = ($29|0)==(-3);
  $$mux$ = $brmerge ? $30 : $31;
  $32 = $33 & $$mux$;
  $34 = (($13) + ($i$01<<5)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   $37 = (__ZN4FMOD3DSP9getBypassEPb($35,$wasEffectBypassed)|0);
   $38 = ($37|0)==(0);
   if (!($38)) {
    $39 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($37)|0);
    HEAP32[$vararg_buffer4>>2] = 742056;
    $vararg_ptr1 = (($vararg_buffer4) + 4|0);
    HEAP32[$vararg_ptr1>>2] = 1147;
    $vararg_ptr2 = (($vararg_buffer4) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $39;
    $vararg_ptr3 = (($vararg_buffer4) + 12|0);
    HEAP32[$vararg_ptr3>>2] = $37;
    _printf_console(742016,$vararg_buffer4);
   }
   $40 = $32&1;
   $41 = HEAP8[$wasEffectBypassed>>0]|0;
   $42 = $41&255;
   $43 = ($40|0)==($42|0);
   if (!($43)) {
    $44 = HEAP32[$34>>2]|0;
    $45 = (__ZN4FMOD3DSP9setBypassEb($44,$32)|0);
    $46 = ($45|0)==(0);
    if (!($46)) {
     $47 = (__ZL16FMOD_ErrorString11FMOD_RESULT16644($45)|0);
     HEAP32[$vararg_buffer4>>2] = 742056;
     $vararg_ptr7 = (($vararg_buffer4) + 4|0);
     HEAP32[$vararg_ptr7>>2] = 1149;
     $vararg_ptr8 = (($vararg_buffer4) + 8|0);
     HEAP32[$vararg_ptr8>>2] = $47;
     $vararg_ptr9 = (($vararg_buffer4) + 12|0);
     HEAP32[$vararg_ptr9>>2] = $45;
     _printf_console(742016,$vararg_buffer4);
    }
   }
  }
  $48 = (($i$01) + 1)|0;
  $49 = HEAP32[$0>>2]|0;
  $50 = ($48>>>0)<($49>>>0);
  if ($50) {
   $i$01 = $48;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN5audio5mixer21SetResultingMuteStateERKNS0_18AudioMixerConstantERKNS0_16AudioMixerMemoryEib($constant,$memory,$index,$muted) {
 $constant = $constant|0;
 $memory = $memory|0;
 $index = $index|0;
 $muted = $muted|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$02 = 0, $or$cond = 0, $state = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $state = sp;
 $0 = (($memory) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index)|0);
 $3 = $muted&1;
 HEAP8[$2>>0] = $3;
 $4 = (($constant) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($constant) + 24|0);
 $8 = $7;
 $9 = (($memory) + 16|0);
 $n$02 = 0;
 while(1) {
  $10 = HEAP32[$7>>2]|0;
  $11 = (($10) + ($8))|0;
  $12 = $11;
  $13 = ((($12) + (($n$02*36)|0)|0) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==($index|0);
  if ($15) {
   $16 = (($12) + (($n$02*36)|0)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>(-1);
   if ($18) {
    HEAP32[$state>>2] = 0;
    $19 = HEAP32[$9>>2]|0;
    $20 = (($19) + ($n$02<<5)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if (!($22)) {
     $23 = (__ZN4FMOD3DSP11getUserDataEPPv($21,$state)|0);
     $24 = ($23|0)==(0);
     $25 = HEAP32[$state>>2]|0;
     $26 = ($25|0)!=(0|0);
     $or$cond = $24 & $26;
     if ($or$cond) {
      $27 = (($25) + 32|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = $28 | 4;
      $30 = $28 & -5;
      $31 = $muted ? $29 : $30;
      HEAP32[$27>>2] = $31;
     }
    }
   }
  }
  $32 = (($n$02) + 1)|0;
  $33 = HEAP32[$4>>2]|0;
  $34 = ($32>>>0)<($33>>>0);
  if ($34) {
   $n$02 = $32;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __Z30AudioMixerFaderProcessCallbackP21UnityAudioEffectStatePfS1_jii($state,$inbuffer,$outbuffer,$length,$inchannels,$outchannels) {
 $state = $state|0;
 $inbuffer = $inbuffer|0;
 $outbuffer = $outbuffer|0;
 $length = $length|0;
 $inchannels = $inchannels|0;
 $outchannels = $outchannels|0;
 var $$ = 0, $$pre = 0, $$pre70 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0;
 var $131 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $dst$045 = 0, $dst$1$lcssa = 0, $dst$137 = 0, $exitcond = 0, $exitcond49 = 0;
 var $exitcond52 = 0, $exitcond53 = 0, $exitcond57 = 0, $exitcond58 = 0, $exitcond62 = 0, $exitcond63 = 0, $exitcond68 = 0, $exitcond69 = 0, $globalCurrPeak$011$us = Math_fround(0), $globalCurrRMS$0$lcssa = Math_fround(0), $globalCurrRMS$023 = Math_fround(0), $globalMaxPeak$012$us = Math_fround(0), $globalMaxRMS$0$lcssa = Math_fround(0), $globalMaxRMS$024 = Math_fround(0), $i$036 = 0, $i13$03$us = 0, $i3$025 = 0, $i6$013$us = 0, $input12$02$us = Math_fround(0), $mixLevel$0$lcssa = Math_fround(0);
 var $mixLevel$044 = Math_fround(0), $n$043 = 0, $n11$07 = 0, $n11$07$us = 0, $n2$033 = 0, $n5$021 = 0, $n5$021$us = 0, $scevgep = 0, $scevgep55 = 0, $scevgep56 = 0, $scevgep61 = 0, $scevgep67 = 0, $src$046 = 0, $src$1$lcssa = 0, $src$138 = 0, $src1$034 = 0, $src1$1$lcssa = 0, $src1$126 = 0, $src1$220$us = 0, $src1$310$us = 0;
 var $src10$06$us = 0, $src10$11$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  label = 11;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  $7 = Math_fround($6 + Math_fround(-1.0));
  $8 = (Math_fround(Math_abs((Math_fround($7)))));
  $9 = !($8 >= Math_fround(0.00100000004749745130539));
  if ($9) {
   label = 11;
  } else {
   $10 = (($1) + 4|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   $12 = Math_fround($6 - $11);
   $13 = (Math_fround(($length>>>0)));
   $14 = Math_fround($12 / $13);
   $15 = ($length|0)==(0);
   if ($15) {
    $mixLevel$0$lcssa = $11;
   } else {
    $16 = ($outchannels|0)>(0);
    $dst$045 = $outbuffer;$mixLevel$044 = $11;$n$043 = 0;$src$046 = $inbuffer;
    while(1) {
     if ($16) {
      $scevgep55 = (($dst$045) + ($outchannels<<2)|0);
      $dst$137 = $dst$045;$i$036 = 0;$src$138 = $src$046;
      while(1) {
       $17 = (($src$138) + 4|0);
       $18 = Math_fround(HEAPF32[$src$138>>2]);
       $19 = Math_fround($mixLevel$044 * $18);
       $20 = (($dst$137) + 4|0);
       HEAPF32[$dst$137>>2] = $19;
       $21 = (($i$036) + 1)|0;
       $exitcond57 = ($21|0)==($outchannels|0);
       if ($exitcond57) {
        break;
       } else {
        $dst$137 = $20;$i$036 = $21;$src$138 = $17;
       }
      }
      $scevgep56 = (($src$046) + ($outchannels<<2)|0);
      $dst$1$lcssa = $scevgep55;$src$1$lcssa = $scevgep56;
     } else {
      $dst$1$lcssa = $dst$045;$src$1$lcssa = $src$046;
     }
     $22 = Math_fround($14 + $mixLevel$044);
     $23 = (($n$043) + 1)|0;
     $exitcond58 = ($23|0)==($length|0);
     if ($exitcond58) {
      $mixLevel$0$lcssa = $22;
      break;
     } else {
      $dst$045 = $dst$1$lcssa;$mixLevel$044 = $22;$n$043 = $23;$src$046 = $src$1$lcssa;
     }
    }
   }
   HEAPF32[$10>>2] = $mixLevel$0$lcssa;
   $28 = $3;
  }
 }
 if ((label|0) == 11) {
  $24 = ($outbuffer|0)==($inbuffer|0);
  if ($24) {
   $28 = $3;
  } else {
   $25 = $length << 2;
   $26 = Math_imul($25, $outchannels)|0;
   _memcpy(($outbuffer|0),($inbuffer|0),($26|0))|0;
   $$pre = HEAP32[$2>>2]|0;
   $28 = $$pre;
  }
 }
 $27 = $28 & 2;
 $29 = ($27|0)==(0);
 if ($29) {
  $101 = $28;
 } else {
  $30 = ($length|0)==(0);
  L21: do {
   if (!($30)) {
    $31 = ($outchannels|0)>(0);
    $32 = (($1) + 236|0);
    $33 = (($1) + 240|0);
    $34 = (($1) + 36|0);
    $35 = (($1) + 8|0);
    $36 = (($1) + 24|0);
    $37 = (($1) + 16|0);
    $n2$033 = 0;$src1$034 = $outbuffer;
    while(1) {
     if ($31) {
      $globalCurrRMS$023 = Math_fround(0.0);$globalMaxRMS$024 = Math_fround(0.0);$i3$025 = 0;$src1$126 = $src1$034;
      while(1) {
       $72 = (($src1$126) + 4|0);
       $73 = Math_fround(HEAPF32[$src1$126>>2]);
       $74 = Math_fround($73 * $73);
       $75 = ((($34) + (($i3$025*24)|0)|0) + 8|0);
       $76 = Math_fround(HEAPF32[$75>>2]);
       $77 = Math_fround($74 - $76);
       $78 = Math_fround(HEAPF32[$35>>2]);
       $79 = Math_fround($77 * $78);
       $80 = Math_fround($79 + Math_fround(1.00000001686238352639E-16));
       $81 = Math_fround($76 + $80);
       HEAPF32[$75>>2] = $81;
       $82 = ((($34) + (($i3$025*24)|0)|0) + 12|0);
       $83 = Math_fround(HEAPF32[$82>>2]);
       $84 = $81 > $83;
       if ($84) {
        HEAPF32[$82>>2] = $81;
        $85 = HEAP32[$36>>2]|0;
        $86 = ((($34) + (($i3$025*24)|0)|0) + 20|0);
        HEAP32[$86>>2] = $85;
        $95 = $81;
       } else {
        $87 = ((($34) + (($i3$025*24)|0)|0) + 20|0);
        $88 = HEAP32[$87>>2]|0;
        $89 = (($88) + -1)|0;
        HEAP32[$87>>2] = $89;
        $90 = ($88|0)<(1);
        if ($90) {
         $91 = Math_fround(HEAPF32[$37>>2]);
         $92 = Math_fround($83 * $91);
         $93 = Math_fround($92 + Math_fround(1.00000001686238352639E-16));
         HEAPF32[$82>>2] = $93;
         $95 = $93;
        } else {
         $95 = $83;
        }
       }
       $94 = (Math_fround(+(_fmaxf((+$globalCurrRMS$023),(+$81)))));
       $96 = (Math_fround(+(_fmaxf((+$globalMaxRMS$024),(+$95)))));
       $97 = (($i3$025) + 1)|0;
       $exitcond52 = ($97|0)==($outchannels|0);
       if ($exitcond52) {
        break;
       } else {
        $globalCurrRMS$023 = $94;$globalMaxRMS$024 = $96;$i3$025 = $97;$src1$126 = $72;
       }
      }
      $scevgep = (($src1$034) + ($outchannels<<2)|0);
      $globalCurrRMS$0$lcssa = $94;$globalMaxRMS$0$lcssa = $96;$src1$1$lcssa = $scevgep;
     } else {
      $globalCurrRMS$0$lcssa = Math_fround(0.0);$globalMaxRMS$0$lcssa = Math_fround(0.0);$src1$1$lcssa = $src1$034;
     }
     HEAPF32[$32>>2] = $globalCurrRMS$0$lcssa;
     HEAPF32[$33>>2] = $globalMaxRMS$0$lcssa;
     $98 = (($n2$033) + 1)|0;
     $exitcond53 = ($98|0)==($length|0);
     if ($exitcond53) {
      break;
     } else {
      $n2$033 = $98;$src1$034 = $src1$1$lcssa;
     }
    }
    if (!($30)) {
     $38 = ($outchannels|0)>(0);
     $39 = (($1) + 228|0);
     $40 = (($1) + 232|0);
     $41 = (($1) + 36|0);
     $42 = (($1) + 12|0);
     $43 = (($1) + 24|0);
     $44 = (($1) + 16|0);
     if ($38) {
      $n5$021$us = 0;$src1$220$us = $outbuffer;
     } else {
      $n5$021 = 0;
      while(1) {
       HEAPF32[$39>>2] = Math_fround(0.0);
       HEAPF32[$40>>2] = Math_fround(0.0);
       $99 = (($n5$021) + 1)|0;
       $exitcond49 = ($99|0)==($length|0);
       if ($exitcond49) {
        break L21;
       } else {
        $n5$021 = $99;
       }
      }
     }
     while(1) {
      $globalCurrPeak$011$us = Math_fround(0.0);$globalMaxPeak$012$us = Math_fround(0.0);$i6$013$us = 0;$src1$310$us = $src1$220$us;
      while(1) {
       $48 = (($src1$310$us) + 4|0);
       $49 = Math_fround(HEAPF32[$src1$310$us>>2]);
       $50 = (Math_fround(Math_abs((Math_fround($49)))));
       $51 = (($41) + (($i6$013$us*24)|0)|0);
       $52 = Math_fround(HEAPF32[$51>>2]);
       $53 = !($50 >= $52);
       if ($53) {
        $54 = Math_fround(HEAPF32[$42>>2]);
        $55 = Math_fround($52 * $54);
        $56 = Math_fround($55 + Math_fround(1.00000001686238352639E-16));
        $57 = $56;
       } else {
        $57 = $50;
       }
       HEAPF32[$51>>2] = $57;
       $58 = ((($41) + (($i6$013$us*24)|0)|0) + 4|0);
       $59 = Math_fround(HEAPF32[$58>>2]);
       $60 = $57 > $59;
       if ($60) {
        HEAPF32[$58>>2] = $57;
        $68 = HEAP32[$43>>2]|0;
        $69 = ((($41) + (($i6$013$us*24)|0)|0) + 16|0);
        HEAP32[$69>>2] = $68;
        $70 = $57;
       } else {
        $61 = ((($41) + (($i6$013$us*24)|0)|0) + 16|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = (($62) + -1)|0;
        HEAP32[$61>>2] = $63;
        $64 = ($62|0)<(1);
        if ($64) {
         $65 = Math_fround(HEAPF32[$44>>2]);
         $66 = Math_fround($59 * $65);
         $67 = Math_fround($66 + Math_fround(1.00000001686238352639E-16));
         HEAPF32[$58>>2] = $67;
         $70 = $67;
        } else {
         $70 = $59;
        }
       }
       $45 = (Math_fround(+(_fmaxf((+$globalCurrPeak$011$us),(+$57)))));
       $46 = (Math_fround(+(_fmaxf((+$globalMaxPeak$012$us),(+$70)))));
       $71 = (($i6$013$us) + 1)|0;
       $exitcond68 = ($71|0)==($outchannels|0);
       if ($exitcond68) {
        break;
       } else {
        $globalCurrPeak$011$us = $45;$globalMaxPeak$012$us = $46;$i6$013$us = $71;$src1$310$us = $48;
       }
      }
      $scevgep67 = (($src1$220$us) + ($outchannels<<2)|0);
      HEAPF32[$39>>2] = $45;
      HEAPF32[$40>>2] = $46;
      $47 = (($n5$021$us) + 1)|0;
      $exitcond69 = ($47|0)==($length|0);
      if ($exitcond69) {
       break;
      } else {
       $n5$021$us = $47;$src1$220$us = $scevgep67;
      }
     }
    }
   }
  } while(0);
  $$pre70 = HEAP32[$2>>2]|0;
  $101 = $$pre70;
 }
 $100 = $101 & 4;
 $102 = ($100|0)==(0);
 if ($102) {
  STACKTOP = sp;return 0;
 }
 $103 = ($length|0)==(0);
 L58: do {
  if (!($103)) {
   $104 = ($outchannels|0)>(0);
   $105 = (($1) + 20|0);
   $106 = (($1) + 8|0);
   if ($104) {
    $n11$07$us = 0;$src10$06$us = $outbuffer;
   } else {
    $n11$07 = 0;
    while(1) {
     $120 = Math_fround(HEAPF32[$105>>2]);
     $121 = Math_fround(Math_fround(0.0) - $120);
     $122 = Math_fround(HEAPF32[$106>>2]);
     $123 = Math_fround($121 * $122);
     $124 = Math_fround($123 + Math_fround(1.00000001686238352639E-16));
     $125 = Math_fround($120 + $124);
     HEAPF32[$105>>2] = $125;
     $126 = (($n11$07) + 1)|0;
     $exitcond = ($126|0)==($length|0);
     if ($exitcond) {
      break L58;
     } else {
      $n11$07 = $126;
     }
    }
   }
   while(1) {
    $i13$03$us = 0;$input12$02$us = Math_fround(0.0);$src10$11$us = $src10$06$us;
    while(1) {
     $116 = (($src10$11$us) + 4|0);
     $117 = Math_fround(HEAPF32[$src10$11$us>>2]);
     $118 = (Math_fround(Math_abs((Math_fround($117)))));
     $108 = (Math_fround(+(_fmaxf((+$input12$02$us),(+$118)))));
     $119 = (($i13$03$us) + 1)|0;
     $exitcond62 = ($119|0)==($outchannels|0);
     if ($exitcond62) {
      break;
     } else {
      $i13$03$us = $119;$input12$02$us = $108;$src10$11$us = $116;
     }
    }
    $scevgep61 = (($src10$06$us) + ($outchannels<<2)|0);
    $107 = Math_fround($108 * $108);
    $109 = Math_fround(HEAPF32[$105>>2]);
    $110 = Math_fround($107 - $109);
    $111 = Math_fround(HEAPF32[$106>>2]);
    $112 = Math_fround($110 * $111);
    $113 = Math_fround($112 + Math_fround(1.00000001686238352639E-16));
    $114 = Math_fround($109 + $113);
    HEAPF32[$105>>2] = $114;
    $115 = (($n11$07$us) + 1)|0;
    $exitcond63 = ($115|0)==($length|0);
    if ($exitcond63) {
     break;
    } else {
     $n11$07$us = $115;$src10$06$us = $scevgep61;
    }
   }
  }
 } while(0);
 $127 = (($1) + 32|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = ($128|0)>(0);
 if ($129) {
  $130 = (($128) - ($length))|0;
  $131 = ($130|0)<(0);
  $$ = $131 ? 0 : $130;
  HEAP32[$127>>2] = $$;
  STACKTOP = sp;return 0;
 } else {
  STACKTOP = sp;return 0;
 }
 return 0|0;
}
function __Z31AudioMixerDuckingCreateCallbackP21UnityAudioEffectState($state) {
 $state = $state|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628304>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(64,$$byval_copy,0,16,751016,66)|0);
 $3 = (($state) + 28|0);
 HEAP32[$3>>2] = $2;
 dest=$2+0|0; stop=dest+64|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return 0;
}
function __Z32AudioMixerDuckingDestroyCallbackP21UnityAudioEffectState($state) {
 $state = $state|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($state) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[628304>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return 0;
}
function __Z37AudioMixerDuckingSetParameterCallbackP21UnityAudioEffectStateif($state,$index,$value) {
 $state = $state|0;
 $index = $index|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if (!($2)) {
   switch ($index|0) {
   case 5:  {
    $8 = (($1) + 28|0);
    HEAPF32[$8>>2] = $value;
    break L1;
    break;
   }
   case 0:  {
    $3 = (($1) + 8|0);
    HEAPF32[$3>>2] = $value;
    break L1;
    break;
   }
   case 1:  {
    $4 = (($1) + 12|0);
    HEAPF32[$4>>2] = $value;
    break L1;
    break;
   }
   case 6:  {
    $9 = (($1) + 32|0);
    HEAPF32[$9>>2] = $value;
    break L1;
    break;
   }
   case 2:  {
    $5 = (($1) + 16|0);
    HEAPF32[$5>>2] = $value;
    break L1;
    break;
   }
   case 3:  {
    $6 = (($1) + 20|0);
    HEAPF32[$6>>2] = $value;
    break L1;
    break;
   }
   case 4:  {
    $7 = (($1) + 24|0);
    HEAPF32[$7>>2] = $value;
    break L1;
    break;
   }
   default: {
    break L1;
   }
   }
  }
 } while(0);
 STACKTOP = sp;return 0;
}
function __Z39AudioMixerDuckingGetFloatBufferCallbackP21UnityAudioEffectStatePKcPfi($state,$name,$buffer,$numsamples) {
 $state = $state|0;
 $name = $name|0;
 $buffer = $buffer|0;
 $numsamples = $numsamples|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (Math_fround(+(_log10f((+$2)))));
 $4 = Math_fround($3 * Math_fround(10.0));
 HEAPF32[$buffer>>2] = $4;
 $5 = (($1) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (Math_fround(+(_log10f((+$6)))));
 $8 = Math_fround($7 * Math_fround(20.0));
 $9 = (($buffer) + 4|0);
 HEAPF32[$9>>2] = $8;
 STACKTOP = sp;return 0;
}
function __Z32AudioMixerDuckingProcessCallbackP21UnityAudioEffectStatePfS1_jii($state,$inbuffer,$outbuffer,$length,$inchannels,$outchannels) {
 $state = $state|0;
 $inbuffer = $inbuffer|0;
 $outbuffer = $outbuffer|0;
 $length = $length|0;
 $inchannels = $inchannels|0;
 $outchannels = $outchannels|0;
 var $$0$i = Math_fround(0), $$0$i1 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0;
 var $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0);
 var $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0);
 var $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = 0, $exitcond = 0, $gain$0 = Math_fround(0), $n$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($state) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 16|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($state) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (Math_fround(($7>>>0)));
 $9 = Math_fround($5 * $8);
 $10 = (Math_fround(($inchannels|0)));
 $11 = Math_fround($10 * $9);
 $12 = !($11 <= Math_fround(0.0));
 if ($12) {
  $13 = Math_fround(Math_fround(1.0) / $11);
  $14 = (Math_fround(+(_log2f(0.0099999904632568359375))));
  $15 = Math_fround($13 * $14);
  $16 = (Math_fround(+(_exp2f((+$15)))));
  $17 = Math_fround(Math_fround(1.0) - $16);
  $$0$i = $17;
 } else {
  $$0$i = Math_fround(1.0);
 }
 $18 = (($1) + 20|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $8);
 $21 = Math_fround($10 * $20);
 $22 = !($21 <= Math_fround(0.0));
 if ($22) {
  $23 = Math_fround(Math_fround(1.0) / $21);
  $24 = (Math_fround(+(_log2f(0.0099999904632568359375))));
  $25 = Math_fround($23 * $24);
  $26 = (Math_fround(+(_exp2f((+$25)))));
  $27 = Math_fround(Math_fround(1.0) - $26);
  $$0$i1 = $27;
 } else {
  $$0$i1 = Math_fround(1.0);
 }
 $28 = (($1) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * Math_fround(0.0500000007450580596924));
 $31 = (Math_fround(+(_log2f(10.0))));
 $32 = Math_fround($31 * $30);
 $33 = (Math_fround(+(_exp2f((+$32)))));
 $34 = (($1) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround(Math_fround(1.0) / $35);
 $37 = Math_fround($36 + Math_fround(-1.0));
 $38 = Math_fround($37 * Math_fround(0.0500000007450580596924));
 $39 = Math_fround($38 * Math_fround(0.25));
 $40 = (($1) + 28|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = $41 > Math_fround(0.0);
 $43 = $42 ? $41 : Math_fround(1.0);
 $44 = Math_fround($39 / $43);
 $45 = Math_fround($31 * $44);
 $46 = (Math_fround(+(_exp2f((+$45)))));
 $47 = Math_fround($31 * $38);
 $48 = (Math_fround(+(_exp2f((+$47)))));
 $49 = Math_imul($inchannels, $length)|0;
 $50 = ($49|0)==(0);
 if ($50) {
  STACKTOP = sp;return 0;
 }
 $51 = (($1) + 32|0);
 $52 = (($1) + 8|0);
 $53 = (($1) + 4|0);
 $n$03 = 0;
 while(1) {
  $54 = (($inbuffer) + ($n$03<<2)|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($3) + ($n$03<<2)|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = Math_fround($57 - $55);
  $59 = Math_fround(HEAPF32[$51>>2]);
  $60 = Math_fround($58 * $59);
  $61 = Math_fround($55 + $60);
  $62 = Math_fround($61 * $61);
  $63 = Math_fround($62 + Math_fround(9.9999999600419720025E-12));
  $64 = Math_fround(HEAPF32[$1>>2]);
  $65 = $63 > $64;
  $66 = $65 ? $$0$i : $$0$i1;
  $67 = Math_fround($63 - $64);
  $68 = Math_fround($67 * $66);
  $69 = Math_fround($68 + Math_fround(1.00000001686238352639E-16));
  $70 = Math_fround($64 + $69);
  HEAPF32[$1>>2] = $70;
  $71 = (Math_fround(+(_log10f((+$70)))));
  $72 = Math_fround($71 * Math_fround(10.0));
  $73 = Math_fround(HEAPF32[$52>>2]);
  $74 = Math_fround($72 - $73);
  $75 = (Math_fround(Math_abs((Math_fround($74)))));
  $76 = Math_fround(HEAPF32[$40>>2]);
  $77 = $75 < $76;
  if ($77) {
   $78 = Math_fround($74 + $76);
   $79 = Math_fround($78 * $78);
   $80 = (Math_fround(+(_log2f((+$46)))));
   $81 = Math_fround($79 * $80);
   $82 = (Math_fround(+(_exp2f((+$81)))));
   $83 = Math_fround($33 * $82);
   $gain$0 = $83;
  } else {
   $84 = $74 > Math_fround(0.0);
   if ($84) {
    $85 = (Math_fround(+(_log2f((+$48)))));
    $86 = Math_fround($74 * $85);
    $87 = (Math_fround(+(_exp2f((+$86)))));
    $88 = Math_fround($33 * $87);
    $gain$0 = $88;
   } else {
    $gain$0 = $33;
   }
  }
  HEAPF32[$53>>2] = $gain$0;
  $89 = Math_fround($55 * $gain$0);
  $90 = (($outbuffer) + ($n$03<<2)|0);
  HEAPF32[$90>>2] = $89;
  $91 = (($n$03) + 1)|0;
  $exitcond = ($91|0)==($49|0);
  if ($exitcond) {
   break;
  } else {
   $n$03 = $91;
  }
 }
 STACKTOP = sp;return 0;
}
function __Z32AudioMixerReceiveProcessCallbackP21UnityAudioEffectStatePfS1_jii($state,$inbuffer,$outbuffer,$length,$inchannels,$outchannels) {
 $state = $state|0;
 $inbuffer = $inbuffer|0;
 $outbuffer = $outbuffer|0;
 $length = $length|0;
 $inchannels = $inchannels|0;
 $outchannels = $outchannels|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $exitcond = 0, $n$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_imul($inchannels, $length)|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return 0;
 } else {
  $n$01 = 0;
 }
 while(1) {
  $4 = (($inbuffer) + ($n$01<<2)|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($1) + ($n$01<<2)|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround($5 + $7);
  $9 = (($outbuffer) + ($n$01<<2)|0);
  HEAPF32[$9>>2] = $8;
  $10 = (($n$01) + 1)|0;
  $exitcond = ($10|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $n$01 = $10;
  }
 }
 STACKTOP = sp;return 0;
}
function __Z29AudioMixerSendProcessCallbackP21UnityAudioEffectStatePfS1_jii($state,$inbuffer,$outbuffer,$length,$inchannels,$outchannels) {
 $state = $state|0;
 $inbuffer = $inbuffer|0;
 $outbuffer = $outbuffer|0;
 $length = $length|0;
 $inchannels = $inchannels|0;
 $outchannels = $outchannels|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $exitcond = 0, $n$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($state) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = Math_imul($inchannels, $length)|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return 0;
 } else {
  $n$01 = 0;
 }
 while(1) {
  $8 = (($inbuffer) + ($n$01<<2)|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($outbuffer) + ($n$01<<2)|0);
  HEAPF32[$10>>2] = $9;
  $11 = Math_fround($3 * $9);
  $12 = (($5) + ($n$01<<2)|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($13 + $11);
  HEAPF32[$12>>2] = $14;
  $15 = (($n$01) + 1)|0;
  $exitcond = ($15|0)==($6|0);
  if ($exitcond) {
   break;
  } else {
   $n$01 = $15;
  }
 }
 STACKTOP = sp;return 0;
}
function __ZN20SoundChannelInstance19FMODChannelCallbackEP12FMOD_CHANNEL25FMOD_CHANNEL_CALLBACKTYPEPvS3_($channel,$type,$commanddata1,$commanddata2) {
 $channel = $channel|0;
 $type = $type|0;
 $commanddata1 = $commanddata1|0;
 $commanddata2 = $commanddata2|0;
 var $$02$i$i$i$i$i$i$i = 0, $$byval_copy = 0, $$masked$i$i$i$i$i$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i = 0, $i$03$i$i$i$i$i$i$i = 0, $or$cond = 0, $p$01$i$i$i$i$i$i = 0, $reflection$01$i$i$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i$i$i = 0, $userData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $userData = sp;
 $0 = sp + 4|0;
 HEAP32[$userData>>2] = 0;
 $1 = (__ZN4FMOD7Channel11getUserDataEPPv($channel,$userData)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($1,751024,16,751104)|0);
 $2 = HEAP32[$userData>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[721712>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $$02$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i = 0;
  while(1) {
   $6 = $$02$i$i$i$i$i$i$i & 1;
   $7 = ($6|0)==(0);
   if ($7) {
    $reflection$1$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i;
   } else {
    $8 = (31 - ($i$03$i$i$i$i$i$i$i))|0;
    $9 = 1 << $8;
    $10 = $9 | $reflection$01$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i = $10;
   }
   $11 = (($i$03$i$i$i$i$i$i$i) + 1)|0;
   $12 = $$02$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i = ($11|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i) {
    $16 = $reflection$1$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i = 753360;
    break;
   } else {
    $$02$i$i$i$i$i$i$i = $12;$i$03$i$i$i$i$i$i$i = $11;$reflection$01$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $13 = HEAP8[$p$01$i$i$i$i$i$i>>0]|0;
   $14 = $13&255;
   $15 = $16 >>> 8;
   $$masked$i$i$i$i$i$i = $16 & 255;
   $17 = $14 ^ $$masked$i$i$i$i$i$i;
   $18 = (584048 + ($17<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = $19 ^ $15;
   $21 = (($p$01$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i = ($21|0)==(((753360 + 87|0))|0);
   if ($exitcond$i$i$i$i$i$i) {
    break;
   } else {
    $16 = $20;$p$01$i$i$i$i$i$i = $21;
   }
  }
  $22 = $20 ^ -1;
  HEAP32[721704>>2] = $22;
  $23 = 721712;
  $24 = $23;
  HEAP32[$24>>2] = 1;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = 0;
  $28 = $22;
 } else {
  $$pre$i$i$i = HEAP32[721704>>2]|0;
  $28 = $$pre$i$i$i;
 }
 $27 = ($3|0)==($28|0);
 if (!($27)) {
  STACKTOP = sp;return 0;
 }
 $29 = (($2) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)!=(0|0);
 $32 = ($type|0)==(0);
 $or$cond = $31 & $32;
 if (!($or$cond)) {
  STACKTOP = sp;return 0;
 }
 $33 = (__ZN4FMOD7Channel11setUserDataEPv($channel,0)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($33,751024,28,751152)|0);
 $34 = HEAP32[$30>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vi[$35 & 4095]($30);
 $36 = HEAP32[628304>>2]|0;
 HEAP32[$0>>2] = $36;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($30,$$byval_copy);
 STACKTOP = sp;return 0;
}
function __ZN20SoundChannelInstanceC2E11SoundHandleb($this,$sound,$paused) {
 $this = $this|0;
 $sound = $sound|0;
 $paused = $paused|0;
 var $$02$i$i$i$i$i$i$i = 0, $$masked$i$i$i$i$i$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i = 0, $i$03$i$i$i$i$i$i$i = 0, $p$01$i$i$i$i$i$i = 0, $reflection$01$i$i$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i$i$i = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((751184 + 8|0));
 $0 = (($this) + 4|0);
 _memset(($0|0),0,171)|0;
 $1 = HEAP8[721712>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$02$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i = 0;
  while(1) {
   $3 = $$02$i$i$i$i$i$i$i & 1;
   $4 = ($3|0)==(0);
   if ($4) {
    $reflection$1$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i;
   } else {
    $5 = (31 - ($i$03$i$i$i$i$i$i$i))|0;
    $6 = 1 << $5;
    $7 = $6 | $reflection$01$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i = $7;
   }
   $8 = (($i$03$i$i$i$i$i$i$i) + 1)|0;
   $9 = $$02$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i = ($8|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i) {
    $13 = $reflection$1$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i = 753360;
    break;
   } else {
    $$02$i$i$i$i$i$i$i = $9;$i$03$i$i$i$i$i$i$i = $8;$reflection$01$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $10 = HEAP8[$p$01$i$i$i$i$i$i>>0]|0;
   $11 = $10&255;
   $12 = $13 >>> 8;
   $$masked$i$i$i$i$i$i = $13 & 255;
   $14 = $11 ^ $$masked$i$i$i$i$i$i;
   $15 = (584048 + ($14<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16 ^ $12;
   $18 = (($p$01$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i = ($18|0)==(((753360 + 87|0))|0);
   if ($exitcond$i$i$i$i$i$i) {
    break;
   } else {
    $13 = $17;$p$01$i$i$i$i$i$i = $18;
   }
  }
  $19 = $17 ^ -1;
  HEAP32[721704>>2] = $19;
  $20 = 721712;
  $21 = $20;
  HEAP32[$21>>2] = 1;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = 0;
  $25 = $19;
 } else {
  $$pre$i$i$i = HEAP32[721704>>2]|0;
  $25 = $$pre$i$i$i;
 }
 $24 = (($this) + 176|0);
 HEAP32[$24>>2] = $25;
 $26 = (($this) + 180|0);
 HEAP32[$26>>2] = $this;
 $27 = (($this) + 184|0);
 HEAP32[$27>>2] = 753360;
 $28 = (($this) + 188|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 192|0);
 __ZN11SoundHandleC2ERKS_($29,$sound);
 $30 = (($this) + 208|0);
 $31 = (($this) + 212|0);
 HEAP32[$30>>2] = $30;
 HEAP32[$31>>2] = $30;
 $32 = (($this) + 216|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 220|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 224|0);
 HEAP32[$34>>2] = $this;
 $35 = (($this) + 228|0);
 HEAP32[$35>>2] = 0;
 $36 = (($this) + 232|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 236|0);
 HEAP32[$37>>2] = $this;
 $38 = (($this) + 240|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 244|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 248|0);
 HEAP32[$40>>2] = $this;
 $41 = (($this) + 252|0);
 HEAPF32[$41>>2] = Math_fround(1.0);
 $42 = (($this) + 256|0);
 HEAPF32[$42>>2] = Math_fround(1.0);
 $43 = (($this) + 260|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 $44 = (($this) + 264|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 $45 = (($this) + 268|0);
 HEAPF32[$45>>2] = Math_fround(1.0);
 $46 = (($this) + 272|0);
 HEAPF32[$46>>2] = Math_fround(1.0);
 $47 = (($this) + 276|0);
 $48 = $paused&1;
 HEAP8[$47>>0] = $48;
 $49 = (($this) + 277|0);
 dest=$49+0|0; stop=dest+11|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 $50 = (invoke_i(119)|0);
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $63 = ___cxa_find_matching_catch()|0;
  $64 = tempRet0;
  HEAP32[$31>>2] = 0;
  HEAP32[$30>>2] = 0;
  __THREW__ = 0;
  invoke_vi(3642,($29|0));
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if ($66) {
   $67 = ___cxa_find_matching_catch(0|0)|0;
   $68 = tempRet0;
   ___clang_call_terminate($67);
   // unreachable;
  } else {
   ___resumeException($63|0);
   // unreachable;
  }
 }
 $53 = ($38|0)==($50|0);
 if ($53) {
  STACKTOP = sp;return;
 }
 $54 = HEAP32[$38>>2]|0;
 $55 = ($54|0)==(0|0);
 if (!($55)) {
  $56 = HEAP32[$39>>2]|0;
  $57 = (($54) + 4|0);
  HEAP32[$57>>2] = $56;
  $58 = HEAP32[$38>>2]|0;
  $59 = HEAP32[$39>>2]|0;
  HEAP32[$59>>2] = $58;
  HEAP32[$38>>2] = 0;
  HEAP32[$39>>2] = 0;
 }
 $60 = HEAP32[$50>>2]|0;
 HEAP32[$38>>2] = $60;
 HEAP32[$39>>2] = $50;
 $61 = (($60) + 4|0);
 HEAP32[$61>>2] = $38;
 $62 = HEAP32[$39>>2]|0;
 HEAP32[$62>>2] = $38;
 STACKTOP = sp;return;
}
function __ZN20SoundChannelInstanceD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1271,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN20SoundChannelInstanceD2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $watchdog = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $watchdog = sp;
 HEAP32[$this>>2] = ((751184 + 8|0));
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 3;
 } else {
  __THREW__ = 0;
  invoke_vii(3344,($1|0),($this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   label = 17;
  } else {
   label = 3;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   __THREW__ = 0;
   $5 = (+invoke_d(1));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 17;
   } else {
    HEAPF64[$watchdog>>3] = $5;
    $8 = (($this) + 208|0);
    $9 = (($this) + 212|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($8|0);
    L6: do {
     if (!($11)) {
      while(1) {
       __THREW__ = 0;
       invoke_viii(1988,($watchdog|0),(751024|0),81);
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if ($13) {
        break;
       }
       $14 = HEAP32[$9>>2]|0;
       $15 = (($14) + 8|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = HEAP32[$16>>2]|0;
       $18 = ($17|0)==(0|0);
       if (!($18)) {
        $19 = (($16) + 4|0);
        $20 = HEAP32[$19>>2]|0;
        $21 = (($17) + 4|0);
        HEAP32[$21>>2] = $20;
        $22 = HEAP32[$16>>2]|0;
        $23 = HEAP32[$19>>2]|0;
        HEAP32[$23>>2] = $22;
        HEAP32[$16>>2] = 0;
        HEAP32[$19>>2] = 0;
       }
       $24 = (($16) + 12|0);
       HEAP32[$24>>2] = 0;
       $25 = HEAP32[$9>>2]|0;
       $26 = ($25|0)==($8|0);
       if ($26) {
        break L6;
       }
      }
      $52 = ___cxa_find_matching_catch()|0;
      $53 = tempRet0;
      $$pre$phiZ2D = $9;$lpad$phi$index = $52;$lpad$phi$index2 = $53;
      break L3;
     }
    } while(0);
    HEAP32[$9>>2] = $8;
    HEAP32[$8>>2] = $8;
    $27 = (($this) + 216|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     $30 = (($this) + 220|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($28) + 4|0);
     HEAP32[$32>>2] = $31;
     $33 = HEAP32[$27>>2]|0;
     $34 = HEAP32[$30>>2]|0;
     HEAP32[$34>>2] = $33;
     HEAP32[$27>>2] = 0;
     HEAP32[$30>>2] = 0;
    }
    $35 = (($this) + 228|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==(0|0);
    if (!($37)) {
     $38 = (($this) + 232|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($36) + 4|0);
     HEAP32[$40>>2] = $39;
     $41 = HEAP32[$35>>2]|0;
     $42 = HEAP32[$38>>2]|0;
     HEAP32[$42>>2] = $41;
     HEAP32[$35>>2] = 0;
     HEAP32[$38>>2] = 0;
    }
    $43 = (($this) + 240|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     HEAP32[$9>>2] = 0;
     HEAP32[$8>>2] = 0;
     $51 = (($this) + 192|0);
     __ZN11SoundHandleD2Ev($51);
     STACKTOP = sp;return;
    }
    $46 = (($this) + 244|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($44) + 4|0);
    HEAP32[$48>>2] = $47;
    $49 = HEAP32[$43>>2]|0;
    $50 = HEAP32[$46>>2]|0;
    HEAP32[$50>>2] = $49;
    HEAP32[$43>>2] = 0;
    HEAP32[$46>>2] = 0;
    HEAP32[$9>>2] = 0;
    HEAP32[$8>>2] = 0;
    $51 = (($this) + 192|0);
    __ZN11SoundHandleD2Ev($51);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  $$pre = (($this) + 212|0);
  $$pre$phiZ2D = $$pre;$lpad$phi$index = $54;$lpad$phi$index2 = $55;
 }
 HEAP32[$$pre$phiZ2D>>2] = 0;
 $56 = (($this) + 208|0);
 HEAP32[$56>>2] = 0;
 $57 = (($this) + 192|0);
 __THREW__ = 0;
 invoke_vi(3642,($57|0));
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if ($59) {
  $60 = ___cxa_find_matching_catch(0|0)|0;
  $61 = tempRet0;
  ___clang_call_terminate($60);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN20SoundManagerWatchDog6UpdateEPKci($this,$filename,$line) {
 $this = $this|0;
 $filename = $filename|0;
 $line = $line|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0.0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer2 = sp;
 $0 = sp + 8|0;
 $1 = (+__Z19GetTimeSinceStartupv());
 $2 = +HEAPF64[$this>>3];
 $3 = $1 - $2;
 $4 = $3 > 15.0;
 if (!($4)) {
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer2>>2] = $filename;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $line;
 _printf_console(753448,$vararg_buffer2);
 HEAP32[$vararg_buffer2>>2] = $filename;
 $vararg_ptr5 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr5>>2] = $line;
 __Z6FormatPKcz($0,753448,$vararg_buffer2);
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (($0) + 1|0);
  $11 = $10;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $11 = $9;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($11|0),0,(753480|0),27,1,0,0,(0|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = HEAP8[$0>>0]|0;
  $22 = $21 & 1;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   ___resumeException($19|0);
   // unreachable;
  }
  $24 = (($0) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  __ZdlPv($25);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   _exit(1);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  _exit(1);
  // unreachable;
 }
}
function __ZN20SoundChannelInstance14SetFMODChannelEPN4FMOD7ChannelE($this,$fmodchannel) {
 $this = $this|0;
 $fmodchannel = $fmodchannel|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 188|0);
 HEAP32[$1>>2] = $fmodchannel;
 $2 = ($fmodchannel|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 176|0);
 $4 = (__ZN4FMOD7Channel11setUserDataEPv($fmodchannel,$3)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($4,751024,100,751200)|0);
 $5 = (__ZN4FMOD7Channel11setCallbackEPF11FMOD_RESULTP12FMOD_CHANNEL25FMOD_CHANNEL_CALLBACKTYPEPvS5_E($fmodchannel,268)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($5,751024,101,751240)|0);
 $6 = (($this) + 272|0);
 $7 = (__ZN4FMOD7Channel12getFrequencyEPf($fmodchannel,$6)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($7,751024,102,751288)|0);
 __ZN20SoundChannelInstance23ApplyBufferedParametersEv($this);
 STACKTOP = sp;return;
}
function __ZN20SoundChannelInstance23ApplyBufferedParametersEv($this) {
 $this = $this|0;
 var $$pr = 0, $$pr1 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0);
 var $9 = 0, $mixVolume$0$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 __ZN20SoundChannelInstance15ParameterBuffer5ApplyEPN4FMOD7ChannelE($4,$2);
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 260|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 252|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = (($this) + 256|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 * $13);
 $15 = (($this) + 284|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & 1;
 $18 = ($17|0)==(0);
 if ($18) {
  $mixVolume$0$i = $14;
 } else {
  $19 = (($this) + 264|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = Math_fround($14 * $20);
  $mixVolume$0$i = $21;
 }
 $22 = (__ZN4FMOD7Channel9setVolumeEf($5,$mixVolume$0$i)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($22,751024,438,752184)|0);
 $$pr1 = HEAP32[$1>>2]|0;
 $23 = ($$pr1|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 268|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($this) + 272|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 * $27);
 $29 = (__ZN4FMOD7Channel12setFrequencyEf($$pr1,$28)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($29,751024,449,752224)|0);
 $$pr = HEAP32[$1>>2]|0;
 $30 = ($$pr|0)==(0|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 276|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  $34 = (($this) + 277|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = ($35<<24>>24)!=(0);
  $37 = $36;
 } else {
  $37 = 1;
 }
 $38 = (__ZN4FMOD7Channel9setPausedEb($$pr,$37)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($38,751024,462,752280)|0);
 STACKTOP = sp;return;
}
function __ZN20SoundChannelInstance8getDelayE14FMOD_DELAYTYPEPjS1_($this,$delaytype,$delayhi,$delaylo) {
 $this = $this|0;
 $delaytype = $delaytype|0;
 $delayhi = $delayhi|0;
 $delaylo = $delaylo|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ((($this) + ($delaytype<<2)|0) + 94|0);
 $2 = HEAPU8[$1>>0]|(HEAPU8[$1+1>>0]<<8)|(HEAPU8[$1+2>>0]<<16)|(HEAPU8[$1+3>>0]<<24);
 HEAP32[$delayhi>>2] = $2;
 $3 = ((($this) + ($delaytype<<2)|0) + 114|0);
 $4 = HEAPU8[$3>>0]|(HEAPU8[$3+1>>0]<<8)|(HEAPU8[$3+2>>0]<<16)|(HEAPU8[$3+3>>0]<<24);
 HEAP32[$delaylo>>2] = $4;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance9isPlayingEPb($this,$playing) {
 $this = $this|0;
 $playing = $playing|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 do {
  if ($0) {
   $$0 = 36;
  } else {
   $1 = (($this) + 188|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    HEAP8[$playing>>0] = 0;
    $$0 = 0;
    break;
   } else {
    $4 = (__ZN4FMOD7Channel9isPlayingEPb($2,$playing)|0);
    $5 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($4,751024,145,751336)|0);
    $$0 = $5;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance15set3DAttributesEPK11FMOD_VECTORS2_($this,$pos,$vel) {
 $this = $this|0;
 $pos = $pos|0;
 $vel = $vel|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($pos|0)==(0|0);
 if (!($1)) {
  $2 = (($this) + 188|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  $5 = $4&1;
  $6 = (($this) + 4|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  $9 = $8 | $5;
  $10 = $9&255;
  HEAP8[$6>>0] = $10;
  $11 = (($this) + 5|0);
  dest=$11+0|0; src=$pos+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $12 = (($this) + 17|0);
  $13 = $4&1;
  HEAP8[$12>>0] = $13;
 }
 $14 = ($vel|0)==(0|0);
 $$phi$trans$insert = (($this) + 188|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if (!($14)) {
  $15 = ($$pre|0)==(0|0);
  $16 = $15&1;
  $17 = (($this) + 4|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $19 | $16;
  $21 = $20&255;
  HEAP8[$17>>0] = $21;
  $22 = (($this) + 18|0);
  dest=$22+0|0; src=$vel+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $23 = (($this) + 30|0);
  $24 = $15&1;
  HEAP8[$23>>0] = $24;
 }
 $25 = ($$pre|0)==(0|0);
 if ($25) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = (__ZN4FMOD7Channel15set3DAttributesEPK11FMOD_VECTORS3_($$pre,$pos,$vel)|0);
 $27 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($26,751024,156,751376)|0);
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance20set3DConeOrientationEP11FMOD_VECTOR($this,$orientation) {
 $this = $this|0;
 $orientation = $orientation|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($orientation|0)==(0|0);
 $$phi$trans$insert = (($this) + 188|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if (!($1)) {
  $2 = ($$pre|0)==(0|0);
  $3 = $2&1;
  $4 = (($this) + 4|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 | $3;
  $8 = $7&255;
  HEAP8[$4>>0] = $8;
  $9 = (($this) + 31|0);
  dest=$9+0|0; src=$orientation+0|0; stop=dest+12|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $10 = (($this) + 43|0);
  $11 = $2&1;
  HEAP8[$10>>0] = $11;
 }
 $12 = ($$pre|0)==(0|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (__ZN4FMOD7Channel20set3DConeOrientationEP11FMOD_VECTOR($$pre,$orientation)|0);
 $14 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($13,751024,166,751424)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance17set3DConeSettingsEfff($this,$insideconeangle,$outsideconeangle,$outsidevolume) {
 $this = $this|0;
 $insideconeangle = Math_fround($insideconeangle);
 $outsideconeangle = Math_fround($outsideconeangle);
 $outsidevolume = Math_fround($outsidevolume);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = (($this) + 44|0);
 HEAPF32[tempDoublePtr>>2]=$insideconeangle;HEAP8[$8>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$8+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$8+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$8+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $9 = (($this) + 48|0);
 $10 = $3&1;
 HEAP8[$9>>0] = $10;
 $11 = (($this) + 49|0);
 HEAPF32[tempDoublePtr>>2]=$outsideconeangle;HEAP8[$11>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$11+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$11+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$11+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $12 = (($this) + 53|0);
 HEAP8[$12>>0] = $10;
 $13 = $7 | $4;
 $14 = $13&255;
 HEAP8[$5>>0] = $14;
 $15 = (($this) + 54|0);
 HEAPF32[tempDoublePtr>>2]=$outsidevolume;HEAP8[$15>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$15+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$15+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$15+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $16 = (($this) + 58|0);
 HEAP8[$16>>0] = $10;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = (__ZN4FMOD7Channel17set3DConeSettingsEfff($2,$insideconeangle,$outsideconeangle,$outsidevolume)|0);
 $18 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($17,751024,178,751480)|0);
 $$0 = $18;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance17set3DDopplerLevelEf($this,$dopplerlevel) {
 $this = $this|0;
 $dopplerlevel = Math_fround($dopplerlevel);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (($this) + 59|0);
 HEAPF32[tempDoublePtr>>2]=$dopplerlevel;HEAP8[$10>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$10+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$10+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$10+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $11 = (($this) + 63|0);
 $12 = $3&1;
 HEAP8[$11>>0] = $12;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (__ZN4FMOD7Channel17set3DDopplerLevelEf($2,$dopplerlevel)|0);
 $14 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($13,751024,188,751568)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance19set3DMinMaxDistanceEff($this,$minDist,$maxDist) {
 $this = $this|0;
 $minDist = Math_fround($minDist);
 $maxDist = Math_fround($maxDist);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = (($this) + 64|0);
 HEAPF32[tempDoublePtr>>2]=$minDist;HEAP8[$8>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$8+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$8+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$8+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $9 = (($this) + 68|0);
 $10 = $3&1;
 HEAP8[$9>>0] = $10;
 $11 = $7 | $4;
 $12 = $11&255;
 HEAP8[$5>>0] = $12;
 $13 = (($this) + 69|0);
 HEAPF32[tempDoublePtr>>2]=$maxDist;HEAP8[$13>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$13+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$13+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$13+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $14 = (($this) + 73|0);
 HEAP8[$14>>0] = $10;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (__ZN4FMOD7Channel19set3DMinMaxDistanceEff($2,$minDist,$maxDist)|0);
 $16 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($15,751024,199,751616)|0);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance13set3DPanLevelEf($this,$panlevel) {
 $this = $this|0;
 $panlevel = Math_fround($panlevel);
 var $$$i = Math_fround(0), $$0 = 0, $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (($this) + 74|0);
 HEAPF32[tempDoublePtr>>2]=$panlevel;HEAP8[$10>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$10+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$10+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$10+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $11 = (($this) + 78|0);
 $12 = $3&1;
 HEAP8[$11>>0] = $12;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = $panlevel < Math_fround(0.0);
 if ($13) {
  $$0$i = Math_fround(0.0);
 } else {
  $14 = $panlevel > Math_fround(1.0);
  $$$i = $14 ? Math_fround(1.0) : $panlevel;
  $$0$i = $$$i;
 }
 $15 = (__ZN4FMOD7Channel13set3DPanLevelEf($2,$$0$i)|0);
 $16 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($15,751024,209,751672)|0);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance11set3DSpreadEf($this,$spread) {
 $this = $this|0;
 $spread = Math_fround($spread);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (($this) + 79|0);
 HEAPF32[tempDoublePtr>>2]=$spread;HEAP8[$10>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$10+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$10+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$10+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $11 = (($this) + 83|0);
 $12 = $3&1;
 HEAP8[$11>>0] = $12;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (__ZN4FMOD7Channel11set3DSpreadEf($2,$spread)|0);
 $14 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($13,751024,219,751736)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance15setChannelGroupEPN4FMOD12ChannelGroupE($this,$group) {
 $this = $this|0;
 $group = $group|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (($this) + 89|0);
 HEAP8[$10>>0]=$group&255;HEAP8[$10+1>>0]=($group>>8)&255;HEAP8[$10+2>>0]=($group>>16)&255;HEAP8[$10+3>>0]=$group>>24;
 $11 = (($this) + 93|0);
 $12 = $3&1;
 HEAP8[$11>>0] = $12;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (__ZN4FMOD7Channel15setChannelGroupEPNS_12ChannelGroupE($2,$group)|0);
 $14 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($13,751024,239,751776)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance8setDelayE14FMOD_DELAYTYPEjj($this,$delaytype,$delayhi,$delaylo) {
 $this = $this|0;
 $delaytype = $delaytype|0;
 $delayhi = $delayhi|0;
 $delaylo = $delaylo|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = ((($this) + ($delaytype<<2)|0) + 94|0);
 HEAP8[$10>>0]=$delayhi&255;HEAP8[$10+1>>0]=($delayhi>>8)&255;HEAP8[$10+2>>0]=($delayhi>>16)&255;HEAP8[$10+3>>0]=$delayhi>>24;
 $11 = HEAP32[$1>>2]|0;
 $12 = ($11|0)==(0|0);
 $13 = ((($this) + ($delaytype)|0) + 110|0);
 $14 = $12&1;
 HEAP8[$13>>0] = $14;
 $15 = HEAP32[$1>>2]|0;
 $16 = ($15|0)==(0|0);
 $17 = $16&1;
 $18 = HEAP8[$5>>0]|0;
 $19 = $18&255;
 $20 = $19 | $17;
 $21 = $20&255;
 HEAP8[$5>>0] = $21;
 $22 = ((($this) + ($delaytype<<2)|0) + 114|0);
 HEAP8[$22>>0]=$delaylo&255;HEAP8[$22+1>>0]=($delaylo>>8)&255;HEAP8[$22+2>>0]=($delaylo>>16)&255;HEAP8[$22+3>>0]=$delaylo>>24;
 $23 = HEAP32[$1>>2]|0;
 $24 = ($23|0)==(0|0);
 $25 = ((($this) + ($delaytype)|0) + 130|0);
 $26 = $24&1;
 HEAP8[$25>>0] = $26;
 $27 = HEAP32[$1>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (__ZN4FMOD7Channel8setDelayE14FMOD_DELAYTYPEjj($27,$delaytype,$delayhi,$delaylo)|0);
 $30 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($29,751024,250,751816)|0);
 $$0 = $30;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance7setMuteEb($this,$mute) {
 $this = $this|0;
 $mute = $mute|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (($this) + 139|0);
 $11 = $mute&1;
 HEAP8[$10>>0] = $11;
 $12 = (($this) + 140|0);
 $13 = $3&1;
 HEAP8[$12>>0] = $13;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (__ZN4FMOD7Channel7setMuteEb($2,$mute)|0);
 $15 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($14,751024,260,751872)|0);
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance6setPanEf($this,$pan) {
 $this = $this|0;
 $pan = Math_fround($pan);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (($this) + 134|0);
 HEAPF32[tempDoublePtr>>2]=$pan;HEAP8[$10>>0]=HEAP8[tempDoublePtr>>0];HEAP8[$10+1>>0]=HEAP8[tempDoublePtr+1>>0];HEAP8[$10+2>>0]=HEAP8[tempDoublePtr+2>>0];HEAP8[$10+3>>0]=HEAP8[tempDoublePtr+3>>0];
 $11 = (($this) + 138|0);
 $12 = $3&1;
 HEAP8[$11>>0] = $12;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (__ZN4FMOD7Channel6setPanEf($2,$pan)|0);
 $14 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($13,751024,270,751904)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance11setPriorityEi($this,$priority) {
 $this = $this|0;
 $priority = $priority|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (($this) + 153|0);
 HEAP8[$10>>0]=$priority&255;HEAP8[$10+1>>0]=($priority>>8)&255;HEAP8[$10+2>>0]=($priority>>16)&255;HEAP8[$10+3>>0]=$priority>>24;
 $11 = (($this) + 157|0);
 $12 = $3&1;
 HEAP8[$11>>0] = $12;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (__ZN4FMOD7Channel11setPriorityEi($2,$priority)|0);
 $14 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($13,751024,280,751936)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance19setReverbPropertiesEP29FMOD_REVERB_CHANNELPROPERTIES($this,$reverbproperties) {
 $this = $this|0;
 $reverbproperties = $reverbproperties|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($reverbproperties|0)==(0|0);
 $$phi$trans$insert = (($this) + 188|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if (!($1)) {
  $2 = ($$pre|0)==(0|0);
  $3 = $2&1;
  $4 = (($this) + 4|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5&255;
  $7 = $6 | $3;
  $8 = $7&255;
  HEAP8[$4>>0] = $8;
  $9 = (($this) + 158|0);
  dest=$9+0|0; src=$reverbproperties+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $10 = (($this) + 174|0);
  $11 = $2&1;
  HEAP8[$10>>0] = $11;
 }
 $12 = ($$pre|0)==(0|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (__ZN4FMOD7Channel19setReverbPropertiesEPK29FMOD_REVERB_CHANNELPROPERTIES($$pre,$reverbproperties)|0);
 $14 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($13,751024,290,751976)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance19getReverbPropertiesEP29FMOD_REVERB_CHANNELPROPERTIES($this,$reverbproperties) {
 $this = $this|0;
 $reverbproperties = $reverbproperties|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($reverbproperties|0)==(0|0);
 if (!($1)) {
  $2 = (($this) + 158|0);
  dest=$reverbproperties+0|0; src=$2+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 }
 $3 = (($this) + 188|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__ZN4FMOD7Channel19getReverbPropertiesEP29FMOD_REVERB_CHANNELPROPERTIES($4,$reverbproperties)|0);
 $7 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($6,751024,300,752032)|0);
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance14SetPositionPCMEj($this,$position_pcm) {
 $this = $this|0;
 $position_pcm = $position_pcm|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 152|0);
 HEAP8[$1>>0] = 0;
 $2 = (($this) + 188|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = $4&1;
 $6 = (($this) + 4|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 | $5;
 $10 = $9&255;
 HEAP8[$6>>0] = $10;
 $11 = (($this) + 143|0);
 HEAP8[$11>>0]=$position_pcm&255;HEAP8[$11+1>>0]=($position_pcm>>8)&255;HEAP8[$11+2>>0]=($position_pcm>>16)&255;HEAP8[$11+3>>0]=$position_pcm>>24;
 $12 = (($this) + 147|0);
 $13 = $4&1;
 HEAP8[$12>>0] = $13;
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (__ZN4FMOD7Channel11setPositionEjj($3,$position_pcm,2)|0);
 if ((($14|0) == 0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($14|0) == 54)) {
  HEAP8[$6>>0] = 1;
  HEAP8[$12>>0] = 1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($14,751024,347,752088)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN20SoundChannelInstance7SetLoopEb($this,$loop) {
 $this = $this|0;
 $loop = $loop|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 $4 = $3&1;
 $5 = (($this) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $10 = (($this) + 141|0);
 $11 = $loop&1;
 HEAP8[$10>>0] = $11;
 $12 = (($this) + 142|0);
 $13 = $3&1;
 HEAP8[$12>>0] = $13;
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = $loop ? 2 : 1;
 $15 = (__ZN4FMOD7Channel7setModeEj($2,$14)|0);
 $16 = (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($15,751024,382,752096)|0);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20SoundChannelInstance15ParameterBuffer5ApplyEPN4FMOD7ChannelE($this,$channel) {
 $this = $this|0;
 $channel = $channel|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 HEAP8[$this>>0] = 0;
 $2 = (($this) + 136|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = (($this) + 135|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = (__ZN4FMOD7Channel7setMuteEb($channel,$7)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($8,751024,483,752320)|0);
  HEAP8[$2>>0] = 0;
 }
 $9 = (($this) + 84|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = (($this) + 80|0);
  $13 = HEAPU8[$12>>0]|(HEAPU8[$12+1>>0]<<8)|(HEAPU8[$12+2>>0]<<16)|(HEAPU8[$12+3>>0]<<24);
  $14 = (__ZN4FMOD7Channel11setCallbackEPF11FMOD_RESULTP12FMOD_CHANNEL25FMOD_CHANNEL_CALLBACKTYPEPvS5_E($channel,$13)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($14,751024,484,752344)|0);
  HEAP8[$9>>0] = 0;
 }
 $15 = (($this) + 138|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if (!($17)) {
  $18 = (($this) + 137|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)!=(0);
  $21 = $20 ? 2 : 1;
  (__ZN4FMOD7Channel7setModeEj($channel,$21)|0);
  HEAP8[$15>>0] = 0;
 }
 $22 = (($this) + 143|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if (!($24)) {
  $25 = (($this) + 139|0);
  $26 = HEAPU8[$25>>0]|(HEAPU8[$25+1>>0]<<8)|(HEAPU8[$25+2>>0]<<16)|(HEAPU8[$25+3>>0]<<24);
  $27 = (__ZN4FMOD7Channel11setPositionEjj($channel,$26,2)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($27,751024,486,752376)|0);
  HEAP8[$22>>0] = 0;
 }
 $28 = (($this) + 148|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = (($this) + 144|0);
  $32 = HEAPU8[$31>>0]|(HEAPU8[$31+1>>0]<<8)|(HEAPU8[$31+2>>0]<<16)|(HEAPU8[$31+3>>0]<<24);
  $33 = (__ZN4FMOD7Channel11setPositionEjj($channel,$32,1)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($33,751024,487,752432)|0);
  HEAP8[$28>>0] = 0;
 }
 $34 = (($this) + 89|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = ($35<<24>>24)==(0);
 if (!($36)) {
  $37 = (($this) + 85|0);
  $38 = HEAPU8[$37>>0]|(HEAPU8[$37+1>>0]<<8)|(HEAPU8[$37+2>>0]<<16)|(HEAPU8[$37+3>>0]<<24);
  $39 = (__ZN4FMOD7Channel15setChannelGroupEPNS_12ChannelGroupE($channel,$38)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($39,751024,488,752488)|0);
  HEAP8[$34>>0] = 0;
 }
 $40 = (($this) + 153|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = ($41<<24>>24)==(0);
 if (!($42)) {
  $43 = (($this) + 149|0);
  $44 = HEAPU8[$43>>0]|(HEAPU8[$43+1>>0]<<8)|(HEAPU8[$43+2>>0]<<16)|(HEAPU8[$43+3>>0]<<24);
  $45 = (__ZN4FMOD7Channel11setPriorityEi($channel,$44)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($45,751024,489,752520)|0);
  HEAP8[$40>>0] = 0;
 }
 $46 = (($this) + 170|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = ($47<<24>>24)==(0);
 if (!($48)) {
  $49 = (($this) + 154|0);
  $50 = (__ZN4FMOD7Channel19setReverbPropertiesEPK29FMOD_REVERB_CHANNELPROPERTIES($channel,$49)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($50,751024,490,752552)|0);
  HEAP8[$46>>0] = 0;
 }
 $51 = (($this) + 107|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = ($52<<24>>24)==(0);
 if (!($53)) {
  $54 = (($this) + 94|0);
  $55 = HEAPU8[$54>>0]|(HEAPU8[$54+1>>0]<<8)|(HEAPU8[$54+2>>0]<<16)|(HEAPU8[$54+3>>0]<<24);
  $56 = (($this) + 114|0);
  $57 = HEAPU8[$56>>0]|(HEAPU8[$56+1>>0]<<8)|(HEAPU8[$56+2>>0]<<16)|(HEAPU8[$56+3>>0]<<24);
  $58 = (__ZN4FMOD7Channel8setDelayE14FMOD_DELAYTYPEjj($channel,1,$55,$57)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($58,751024,491,752600)|0);
  HEAP8[$51>>0] = 0;
  $59 = (($this) + 127|0);
  HEAP8[$59>>0] = 0;
 }
 $60 = (($this) + 108|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = ($61<<24>>24)==(0);
 if (!($62)) {
  $63 = (($this) + 98|0);
  $64 = HEAPU8[$63>>0]|(HEAPU8[$63+1>>0]<<8)|(HEAPU8[$63+2>>0]<<16)|(HEAPU8[$63+3>>0]<<24);
  $65 = (($this) + 118|0);
  $66 = HEAPU8[$65>>0]|(HEAPU8[$65+1>>0]<<8)|(HEAPU8[$65+2>>0]<<16)|(HEAPU8[$65+3>>0]<<24);
  $67 = (__ZN4FMOD7Channel8setDelayE14FMOD_DELAYTYPEjj($channel,2,$64,$66)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($67,751024,492,752736)|0);
  HEAP8[$60>>0] = 0;
  $68 = (($this) + 128|0);
  HEAP8[$68>>0] = 0;
 }
 $69 = (($this) + 109|0);
 $70 = HEAP8[$69>>0]|0;
 $71 = ($70<<24>>24)==(0);
 if (!($71)) {
  $72 = (($this) + 102|0);
  $73 = HEAPU8[$72>>0]|(HEAPU8[$72+1>>0]<<8)|(HEAPU8[$72+2>>0]<<16)|(HEAPU8[$72+3>>0]<<24);
  $74 = (($this) + 122|0);
  $75 = HEAPU8[$74>>0]|(HEAPU8[$74+1>>0]<<8)|(HEAPU8[$74+2>>0]<<16)|(HEAPU8[$74+3>>0]<<24);
  $76 = (__ZN4FMOD7Channel8setDelayE14FMOD_DELAYTYPEjj($channel,3,$73,$75)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($76,751024,493,752864)|0);
  HEAP8[$69>>0] = 0;
  $77 = (($this) + 129|0);
  HEAP8[$77>>0] = 0;
 }
 $78 = (($this) + 134|0);
 $79 = HEAP8[$78>>0]|0;
 $80 = ($79<<24>>24)==(0);
 if (!($80)) {
  $81 = (($this) + 130|0);
  HEAP8[tempDoublePtr>>0]=HEAP8[$81>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$81+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$81+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$81+3>>0];$82 = Math_fround(HEAPF32[tempDoublePtr>>2]);
  $83 = (__ZN4FMOD7Channel6setPanEf($channel,$82)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($83,751024,494,753000)|0);
  HEAP8[$78>>0] = 0;
 }
 $84 = (($this) + 13|0);
 $85 = HEAP8[$84>>0]|0;
 $86 = ($85<<24>>24)==(0);
 if (!($86)) {
  $87 = (($this) + 1|0);
  $88 = (($this) + 14|0);
  $89 = (__ZN4FMOD7Channel15set3DAttributesEPK11FMOD_VECTORS3_($channel,$87,$88)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($89,751024,496,753024)|0);
  HEAP8[$84>>0] = 0;
  $90 = (($this) + 26|0);
  HEAP8[$90>>0] = 0;
 }
 $91 = (($this) + 39|0);
 $92 = HEAP8[$91>>0]|0;
 $93 = ($92<<24>>24)==(0);
 if (!($93)) {
  $94 = (($this) + 27|0);
  $95 = (__ZN4FMOD7Channel20set3DConeOrientationEP11FMOD_VECTOR($channel,$94)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($95,751024,497,753064)|0);
  HEAP8[$91>>0] = 0;
 }
 $96 = (($this) + 44|0);
 $97 = HEAP8[$96>>0]|0;
 $98 = ($97<<24>>24)==(0);
 if (!($98)) {
  $99 = (($this) + 40|0);
  HEAP8[tempDoublePtr>>0]=HEAP8[$99>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$99+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$99+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$99+3>>0];$100 = Math_fround(HEAPF32[tempDoublePtr>>2]);
  $101 = (($this) + 45|0);
  HEAP8[tempDoublePtr>>0]=HEAP8[$101>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$101+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$101+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$101+3>>0];$102 = Math_fround(HEAPF32[tempDoublePtr>>2]);
  $103 = (($this) + 50|0);
  HEAP8[tempDoublePtr>>0]=HEAP8[$103>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$103+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$103+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$103+3>>0];$104 = Math_fround(HEAPF32[tempDoublePtr>>2]);
  $105 = (__ZN4FMOD7Channel17set3DConeSettingsEfff($channel,$100,$102,$104)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($105,751024,498,753112)|0);
  HEAP8[$96>>0] = 0;
  $106 = (($this) + 49|0);
  HEAP8[$106>>0] = 0;
  $107 = (($this) + 54|0);
  HEAP8[$107>>0] = 0;
 }
 $108 = (($this) + 59|0);
 $109 = HEAP8[$108>>0]|0;
 $110 = ($109<<24>>24)==(0);
 if (!($110)) {
  $111 = (($this) + 55|0);
  HEAP8[tempDoublePtr>>0]=HEAP8[$111>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$111+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$111+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$111+3>>0];$112 = Math_fround(HEAPF32[tempDoublePtr>>2]);
  $113 = (__ZN4FMOD7Channel17set3DDopplerLevelEf($channel,$112)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($113,751024,499,753192)|0);
  HEAP8[$108>>0] = 0;
 }
 $114 = (($this) + 64|0);
 $115 = HEAP8[$114>>0]|0;
 $116 = ($115<<24>>24)==(0);
 if (!($116)) {
  $117 = (($this) + 60|0);
  HEAP8[tempDoublePtr>>0]=HEAP8[$117>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$117+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$117+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$117+3>>0];$118 = Math_fround(HEAPF32[tempDoublePtr>>2]);
  $119 = (($this) + 65|0);
  HEAP8[tempDoublePtr>>0]=HEAP8[$119>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$119+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$119+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$119+3>>0];$120 = Math_fround(HEAPF32[tempDoublePtr>>2]);
  $121 = (__ZN4FMOD7Channel19set3DMinMaxDistanceEff($channel,$118,$120)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($121,751024,500,753240)|0);
  HEAP8[$114>>0] = 0;
  $122 = (($this) + 69|0);
  HEAP8[$122>>0] = 0;
 }
 $123 = (($this) + 74|0);
 $124 = HEAP8[$123>>0]|0;
 $125 = ($124<<24>>24)==(0);
 if (!($125)) {
  $126 = (($this) + 70|0);
  HEAP8[tempDoublePtr>>0]=HEAP8[$126>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$126+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$126+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$126+3>>0];$127 = Math_fround(HEAPF32[tempDoublePtr>>2]);
  $128 = (__ZN4FMOD7Channel13set3DPanLevelEf($channel,$127)|0);
  (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($128,751024,501,753288)|0);
  HEAP8[$123>>0] = 0;
 }
 $129 = (($this) + 79|0);
 $130 = HEAP8[$129>>0]|0;
 $131 = ($130<<24>>24)==(0);
 if ($131) {
  STACKTOP = sp;return;
 }
 $132 = (($this) + 75|0);
 HEAP8[tempDoublePtr>>0]=HEAP8[$132>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$132+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$132+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$132+3>>0];$133 = Math_fround(HEAPF32[tempDoublePtr>>2]);
 $134 = (__ZN4FMOD7Channel11set3DSpreadEf($channel,$133)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($134,751024,502,753328)|0);
 HEAP8[$129>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN20SoundChannelInstance12UpdateVolumeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0;
 var $mixVolume$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 260|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 252|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = (($this) + 256|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = (($this) + 284|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 1;
 $15 = ($14|0)==(0);
 if ($15) {
  $mixVolume$0 = $11;
 } else {
  $16 = (($this) + 264|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($11 * $17);
  $mixVolume$0 = $18;
 }
 $19 = (__ZN4FMOD7Channel9setVolumeEf($2,$mixVolume$0)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($19,751024,438,752184)|0);
 STACKTOP = sp;return;
}
function __ZN20SoundChannelInstance11UpdatePitchEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 268|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 272|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = (__ZN4FMOD7Channel12setFrequencyEf($2,$8)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($9,751024,449,752224)|0);
 STACKTOP = sp;return;
}
function __ZN20SoundChannelInstance16UpdatePauseStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 188|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 276|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $7 = (($this) + 277|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)!=(0);
  $10 = $9;
 } else {
  $10 = 1;
 }
 $11 = (__ZN4FMOD7Channel9setPausedEb($2,$10)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($11,751024,462,752280)|0);
 STACKTOP = sp;return;
}
function __ZN20SoundChannelInstance4StopEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 228|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 279|0);
  HEAP8[$4>>0] = 1;
 }
 $5 = (($this) + 188|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (__ZN4FMOD7Channel4stopEv($6)|0);
 (__Z15_CheckFMODError11FMOD_RESULTPKciS1_($8,751024,421,752160)|0);
 STACKTOP = sp;return;
}
function __ZN20SoundChannelInstance6UpdateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 188|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 147|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($this) + 143|0);
  $7 = HEAPU8[$6>>0]|(HEAPU8[$6+1>>0]<<8)|(HEAPU8[$6+2>>0]<<16)|(HEAPU8[$6+3>>0]<<24);
  $8 = (__ZN4FMOD7Channel11setPositionEjj($1,$7,2)|0);
  $9 = ($8|0)==(0);
  if ($9) {
   HEAP8[$3>>0] = 0;
  }
 }
 $10 = (($this) + 152|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = (($this) + 148|0);
 $15 = HEAPU8[$14>>0]|(HEAPU8[$14+1>>0]<<8)|(HEAPU8[$14+2>>0]<<16)|(HEAPU8[$14+3>>0]<<24);
 $16 = (__ZN4FMOD7Channel11setPositionEjj($13,$15,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 HEAP8[$10>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN11SoundHandle8InstanceD2Ev($this) {
 $this = $this|0;
 var $$byval_copy25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index7Z2D = 0, $eh$lpad$body$indexZ2D = 0, $node$01$i = 0, $node$01$i6 = 0, $node$01$i9 = 0, $vararg_ptr16 = 0;
 var $vararg_ptr17 = 0, $vararg_ptr18 = 0, $vararg_ptr22 = 0, $vararg_ptr23 = 0, $vararg_ptr24 = 0, $watchdog = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy25 = sp + 8|0;
 $0 = sp + 40|0;
 $1 = sp + 28|0;
 $2 = sp + 24|0;
 $watchdog = sp;
 __THREW__ = 0;
 $3 = (+invoke_d(1));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   label = 8;
  } else {
   HEAPF64[$watchdog>>3] = $3;
   $6 = (($this) + 36|0);
   $7 = (($this) + 40|0);
   while(1) {
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==($6|0);
    if ($9) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(1988,($watchdog|0),(753488|0),108);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     label = 7;
     break;
    }
    $12 = HEAP32[$7>>2]|0;
    $13 = (($12) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_vi(3662,($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     label = 7;
     break;
    }
   }
   if ((label|0) == 7) {
    $19 = ___cxa_find_matching_catch()|0;
    $20 = tempRet0;
    $eh$lpad$body$index7Z2D = $20;$eh$lpad$body$indexZ2D = $19;
    break;
   }
   $23 = (($this) + 28|0);
   $24 = (($this) + 32|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==($23|0);
   L10: do {
    if (!($26)) {
     $30 = $25;
     while(1) {
      __THREW__ = 0;
      invoke_viii(1988,($watchdog|0),(753488|0),116);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = (($30) + 8|0);
      $31 = HEAP32[$29>>2]|0;
      $32 = (($31) + 12|0);
      HEAP32[$32>>2] = 0;
      $33 = (($30) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==($23|0);
      if ($35) {
       break L10;
      } else {
       $30 = $34;
      }
     }
     $17 = ___cxa_find_matching_catch()|0;
     $18 = tempRet0;
     $eh$lpad$body$index7Z2D = $18;$eh$lpad$body$indexZ2D = $17;
     break L1;
    }
   } while(0);
   $36 = (($this) + 108|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($this) + 104|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 108|0);
   HEAP32[$40>>2] = $37;
   $41 = HEAP32[$38>>2]|0;
   $42 = HEAP32[$36>>2]|0;
   $43 = (($42) + 104|0);
   HEAP32[$43>>2] = $41;
   $44 = (($this) + 44|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   do {
    if ($46) {
     $75 = (($this) + 48|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==(0|0);
     if (!($77)) {
      __THREW__ = 0;
      $78 = (invoke_ii(3390,($76|0))|0);
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       label = 8;
       break L1;
      }
      $81 = ($78|0)==(0);
      if (!($81)) {
       $82 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($78)|0);
       __THREW__ = 0;
       HEAP32[$$byval_copy25>>2] = 753488;
       $vararg_ptr22 = (($$byval_copy25) + 4|0);
       HEAP32[$vararg_ptr22>>2] = 128;
       $vararg_ptr23 = (($$byval_copy25) + 8|0);
       HEAP32[$vararg_ptr23>>2] = 753592;
       $vararg_ptr24 = (($$byval_copy25) + 12|0);
       HEAP32[$vararg_ptr24>>2] = $82;
       invoke_viii(1617,($1|0),(761968|0),($$byval_copy25|0));
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        label = 8;
        break L1;
       }
       $85 = HEAP8[$1>>0]|0;
       $86 = $85 & 1;
       $87 = ($86<<24>>24)==(0);
       if ($87) {
        $90 = (($1) + 1|0);
        $91 = $90;
       } else {
        $88 = (($1) + 8|0);
        $89 = HEAP32[$88>>2]|0;
        $91 = $89;
       }
       __THREW__ = 0;
       invoke_viiiiiiii(21,($91|0),0,(753784|0),21,1,0,0,(0|0));
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        $99 = ___cxa_find_matching_catch()|0;
        $100 = tempRet0;
        $101 = HEAP8[$1>>0]|0;
        $102 = $101 & 1;
        $103 = ($102<<24>>24)==(0);
        if ($103) {
         $eh$lpad$body$index7Z2D = $100;$eh$lpad$body$indexZ2D = $99;
         break L1;
        }
        $104 = (($1) + 8|0);
        $105 = HEAP32[$104>>2]|0;
        __ZdlPv($105);
        $eh$lpad$body$index7Z2D = $100;$eh$lpad$body$indexZ2D = $99;
        break L1;
       } else {
        $94 = HEAP8[$1>>0]|0;
        $95 = $94 & 1;
        $96 = ($95<<24>>24)==(0);
        if ($96) {
         break;
        }
        $97 = (($1) + 8|0);
        $98 = HEAP32[$97>>2]|0;
        __ZdlPv($98);
        break;
       }
      }
     }
    } else {
     __THREW__ = 0;
     $47 = (invoke_ii(3390,($45|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      label = 8;
      break L1;
     }
     $50 = ($47|0)==(0);
     if (!($50)) {
      $51 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($47)|0);
      __THREW__ = 0;
      HEAP32[$$byval_copy25>>2] = 753488;
      $vararg_ptr16 = (($$byval_copy25) + 4|0);
      HEAP32[$vararg_ptr16>>2] = 126;
      $vararg_ptr17 = (($$byval_copy25) + 8|0);
      HEAP32[$vararg_ptr17>>2] = 753568;
      $vararg_ptr18 = (($$byval_copy25) + 12|0);
      HEAP32[$vararg_ptr18>>2] = $51;
      invoke_viii(1617,($0|0),(761968|0),($$byval_copy25|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 8;
       break L1;
      }
      $54 = HEAP8[$0>>0]|0;
      $55 = $54 & 1;
      $56 = ($55<<24>>24)==(0);
      if ($56) {
       $59 = (($0) + 1|0);
       $60 = $59;
      } else {
       $57 = (($0) + 8|0);
       $58 = HEAP32[$57>>2]|0;
       $60 = $58;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($60|0),0,(753784|0),21,1,0,0,(0|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       $68 = ___cxa_find_matching_catch()|0;
       $69 = tempRet0;
       $70 = HEAP8[$0>>0]|0;
       $71 = $70 & 1;
       $72 = ($71<<24>>24)==(0);
       if ($72) {
        $eh$lpad$body$index7Z2D = $69;$eh$lpad$body$indexZ2D = $68;
        break L1;
       }
       $73 = (($0) + 8|0);
       $74 = HEAP32[$73>>2]|0;
       __ZdlPv($74);
       $eh$lpad$body$index7Z2D = $69;$eh$lpad$body$indexZ2D = $68;
       break L1;
      } else {
       $63 = HEAP8[$0>>0]|0;
       $64 = $63 & 1;
       $65 = ($64<<24>>24)==(0);
       if ($65) {
        break;
       }
       $66 = (($0) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       __ZdlPv($67);
       break;
      }
     }
    }
   } while(0);
   $106 = HEAP32[$this>>2]|0;
   $107 = ($106|0)==(0|0);
   if (!($107)) {
    $108 = (($this) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($106) + 4|0);
    HEAP32[$110>>2] = $109;
    $111 = HEAP32[$this>>2]|0;
    $112 = HEAP32[$108>>2]|0;
    HEAP32[$112>>2] = $111;
    HEAP32[$this>>2] = 0;
    HEAP32[$108>>2] = 0;
   }
   $113 = HEAP32[$24>>2]|0;
   $114 = ($113|0)==($23|0);
   if (!($114)) {
    $node$01$i9 = $113;
    while(1) {
     $115 = (($node$01$i9) + 4|0);
     $116 = HEAP32[$115>>2]|0;
     HEAP32[$node$01$i9>>2] = 0;
     HEAP32[$115>>2] = 0;
     $117 = ($116|0)==($23|0);
     if ($117) {
      break;
     } else {
      $node$01$i9 = $116;
     }
    }
   }
   HEAP32[$24>>2] = $23;
   HEAP32[$23>>2] = $23;
   $118 = HEAP32[$7>>2]|0;
   $119 = ($118|0)==($6|0);
   if (!($119)) {
    $node$01$i6 = $118;
    while(1) {
     $120 = (($node$01$i6) + 4|0);
     $121 = HEAP32[$120>>2]|0;
     HEAP32[$node$01$i6>>2] = 0;
     HEAP32[$120>>2] = 0;
     $122 = ($121|0)==($6|0);
     if ($122) {
      break;
     } else {
      $node$01$i6 = $121;
     }
    }
   }
   HEAP32[$7>>2] = $6;
   HEAP32[$6>>2] = $6;
   $123 = (($this) + 96|0);
   $124 = (($this) + 100|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = ($125|0)==($123|0);
   if (!($126)) {
    $node$01$i = $125;
    while(1) {
     $127 = (($node$01$i) + 4|0);
     $128 = HEAP32[$127>>2]|0;
     HEAP32[$node$01$i>>2] = 0;
     HEAP32[$127>>2] = 0;
     $129 = ($128|0)==($123|0);
     if ($129) {
      break;
     } else {
      $node$01$i = $128;
     }
    }
   }
   HEAP32[$124>>2] = 0;
   HEAP32[$123>>2] = 0;
   $130 = (($this) + 72|0);
   $131 = HEAP8[$130>>0]|0;
   $132 = $131 & 1;
   $133 = ($132<<24>>24)==(0);
   if ($133) {
    ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;
    STACKTOP = sp;return;
   }
   $134 = (($this) + 80|0);
   $135 = HEAP32[$134>>2]|0;
   HEAP32[$2>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($135|0),($$byval_copy25|0));
   $136 = __THREW__; __THREW__ = 0;
   $137 = $136&1;
   if ($137) {
    $138 = ___cxa_find_matching_catch()|0;
    $139 = tempRet0;
    ___cxa_call_unexpected(($138|0));
    // unreachable;
   } else {
    ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  $eh$lpad$body$index7Z2D = $22;$eh$lpad$body$indexZ2D = $21;
 }
 $140 = (($this) + 100|0);
 HEAP32[$140>>2] = 0;
 $141 = (($this) + 96|0);
 HEAP32[$141>>2] = 0;
 $142 = (($this) + 72|0);
 $143 = HEAP8[$142>>0]|0;
 $144 = $143 & 1;
 $145 = ($144<<24>>24)==(0);
 if ($145) {
  $152 = (($this) + 28|0);
  ;HEAP32[$152+0>>2]=0|0;HEAP32[$152+4>>2]=0|0;HEAP32[$152+8>>2]=0|0;HEAP32[$152+12>>2]=0|0;
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $146 = (($this) + 80|0);
 $147 = HEAP32[$146>>2]|0;
 HEAP32[$2>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($147|0),($$byval_copy25|0));
 $148 = __THREW__; __THREW__ = 0;
 $149 = $148&1;
 if ($149) {
  $150 = ___cxa_find_matching_catch()|0;
  $151 = tempRet0;
  ___cxa_call_unexpected(($150|0));
  // unreachable;
 } else {
  $152 = (($this) + 28|0);
  ;HEAP32[$152+0>>2]=0|0;HEAP32[$152+4>>2]=0|0;HEAP32[$152+8>>2]=0|0;HEAP32[$152+12>>2]=0|0;
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __Z15GetSoundManagerv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetAudioManagerv()|0);
 $1 = (__ZN12AudioManager15GetSoundManagerEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN11SoundHandle8Instance7DisposeEv($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $tmphandle = 0, $watchdog = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $watchdog = sp;
 $tmphandle = sp + 8|0;
 $0 = (+__Z19GetTimeSinceStartupv());
 HEAPF64[$watchdog>>3] = $0;
 HEAP32[$tmphandle>>2] = 0;
 $1 = (($tmphandle) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($tmphandle) + 8|0);
 HEAP32[$2>>2] = $tmphandle;
 $3 = (($tmphandle) + 12|0);
 HEAP32[$3>>2] = $this;
 $4 = ($this|0)==(0|0);
 if (!($4)) {
  $5 = (($this) + 28|0);
  $6 = ($tmphandle|0)==($5|0);
  if (!($6)) {
   $7 = HEAP32[$5>>2]|0;
   HEAP32[$tmphandle>>2] = $7;
   HEAP32[$1>>2] = $5;
   $8 = (($7) + 4|0);
   HEAP32[$8>>2] = $tmphandle;
   $9 = HEAP32[$1>>2]|0;
   HEAP32[$9>>2] = $tmphandle;
  }
 }
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 36|0);
 $14 = $11;
 while(1) {
  $13 = ($14|0)==($12|0);
  if ($13) {
   label = 12;
   break;
  }
  __THREW__ = 0;
  invoke_viii(1988,($watchdog|0),(753488|0),164);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   label = 9;
   break;
  }
  $17 = (($14) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($14) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  __THREW__ = 0;
  invoke_vi(3662,($20|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   label = 9;
   break;
  } else {
   $14 = $18;
  }
 }
 L9: do {
  if ((label|0) == 9) {
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   $lpad$phi$index = $25;$lpad$phi$index3 = $26;
  }
  else if ((label|0) == 12) {
   $31 = (($this) + 32|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($this) + 28|0);
   $34 = ($32|0)==($33|0);
   L11: do {
    if (!($34)) {
     $38 = $32;
     while(1) {
      __THREW__ = 0;
      invoke_viii(1988,($watchdog|0),(753488|0),173);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = (($38) + 8|0);
      $39 = HEAP32[$37>>2]|0;
      $40 = (($39) + 12|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($41|0)==(0|0);
      if (!($42)) {
       HEAP32[$40>>2] = 0;
      }
      $43 = (($38) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==($33|0);
      if ($45) {
       break L11;
      } else {
       $38 = $44;
      }
     }
     $23 = ___cxa_find_matching_catch()|0;
     $24 = tempRet0;
     $lpad$phi$index = $23;$lpad$phi$index3 = $24;
     break L9;
    }
   } while(0);
   $46 = (($this) + 108|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($this) + 104|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($49) + 108|0);
   HEAP32[$50>>2] = $47;
   $51 = HEAP32[$48>>2]|0;
   $52 = HEAP32[$46>>2]|0;
   $53 = (($52) + 104|0);
   HEAP32[$53>>2] = $51;
   HEAP32[$48>>2] = $this;
   HEAP32[$46>>2] = $this;
   __THREW__ = 0;
   $54 = (invoke_i(118)|0);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if (!($56)) {
    __THREW__ = 0;
    $57 = (invoke_ii(3391,($54|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if (!($59)) {
     $60 = (($57) + 24|0);
     $61 = ($this|0)==($60|0);
     if ($61) {
      $71 = (($this) + 116|0);
      HEAP8[$71>>0] = 1;
      __ZN11SoundHandleD2Ev($tmphandle);
      STACKTOP = sp;return;
     }
     $62 = HEAP32[$this>>2]|0;
     $63 = ($62|0)==(0|0);
     $$pre$i$i$i = (($this) + 4|0);
     if (!($63)) {
      $64 = HEAP32[$$pre$i$i$i>>2]|0;
      $65 = (($62) + 4|0);
      HEAP32[$65>>2] = $64;
      $66 = HEAP32[$this>>2]|0;
      $67 = HEAP32[$$pre$i$i$i>>2]|0;
      HEAP32[$67>>2] = $66;
      HEAP32[$this>>2] = 0;
      HEAP32[$$pre$i$i$i>>2] = 0;
     }
     $68 = HEAP32[$60>>2]|0;
     HEAP32[$this>>2] = $68;
     HEAP32[$$pre$i$i$i>>2] = $60;
     $69 = (($68) + 4|0);
     HEAP32[$69>>2] = $this;
     $70 = HEAP32[$$pre$i$i$i>>2]|0;
     HEAP32[$70>>2] = $this;
     $71 = (($this) + 116|0);
     HEAP8[$71>>0] = 1;
     __ZN11SoundHandleD2Ev($tmphandle);
     STACKTOP = sp;return;
    }
   }
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   $lpad$phi$index = $27;$lpad$phi$index3 = $28;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3642,($tmphandle|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $72 = ___cxa_find_matching_catch(0|0)|0;
  $73 = tempRet0;
  ___clang_call_terminate($72);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN11SoundHandle8Instance15UpdateLoadStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $diskbusy = 0, $numSubSounds = 0, $openstate = 0, $pctbuffered = 0, $starving = 0, $vararg_buffer10 = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer10 = sp;
 $0 = sp + 28|0;
 $openstate = sp + 16|0;
 $pctbuffered = sp + 20|0;
 $starving = sp + 41|0;
 $diskbusy = sp + 40|0;
 $numSubSounds = sp + 24|0;
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 if ((($2|0) == 1)) {
  $3 = (($this) + 44|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN4FMOD5Sound12getOpenStateEP14FMOD_OPENSTATEPjPbS4_($4,$openstate,$pctbuffered,$starving,$diskbusy)|0);
  $6 = ($5|0)==(0);
  if (!($6)) {
   STACKTOP = sp;return;
  }
  $7 = HEAP32[$openstate>>2]|0;
  if ((($7|0) == 2)) {
   HEAP32[$1>>2] = 4;
   STACKTOP = sp;return;
  } else if ((($7|0) == 0)) {
   $8 = HEAP32[$3>>2]|0;
   $9 = (($this) + 12|0);
   $10 = (__ZN4FMOD5Sound11setUserDataEPv($8,$9)|0);
   $11 = ($10|0)==(0);
   do {
    if (!($11)) {
     $12 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($10)|0);
     HEAP32[$vararg_buffer10>>2] = 753488;
     $vararg_ptr1 = (($vararg_buffer10) + 4|0);
     HEAP32[$vararg_ptr1>>2] = 209;
     $vararg_ptr2 = (($vararg_buffer10) + 8|0);
     HEAP32[$vararg_ptr2>>2] = 753616;
     $vararg_ptr3 = (($vararg_buffer10) + 12|0);
     HEAP32[$vararg_ptr3>>2] = $12;
     __Z6FormatPKcz($0,761968,$vararg_buffer10);
     $13 = HEAP8[$0>>0]|0;
     $14 = $13 & 1;
     $15 = ($14<<24>>24)==(0);
     if ($15) {
      $18 = (($0) + 1|0);
      $19 = $18;
     } else {
      $16 = (($0) + 8|0);
      $17 = HEAP32[$16>>2]|0;
      $19 = $17;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($19|0),0,(753784|0),21,1,0,0,(0|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP8[$0>>0]|0;
      $23 = $22 & 1;
      $24 = ($23<<24>>24)==(0);
      if ($24) {
       break;
      }
      $25 = (($0) + 8|0);
      $26 = HEAP32[$25>>2]|0;
      __ZdlPv($26);
      break;
     }
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     $29 = HEAP8[$0>>0]|0;
     $30 = $29 & 1;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      ___resumeException($27|0);
      // unreachable;
     }
     $32 = (($0) + 8|0);
     $33 = HEAP32[$32>>2]|0;
     __ZdlPv($33);
     ___resumeException($27|0);
     // unreachable;
    }
   } while(0);
   HEAP32[$numSubSounds>>2] = 0;
   $34 = HEAP32[$3>>2]|0;
   $35 = (__ZN4FMOD5Sound15getNumSubSoundsEPi($34,$numSubSounds)|0);
   $36 = ($35|0)==(0);
   do {
    if (!($36)) {
     $37 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($35)|0);
     HEAP32[$vararg_buffer10>>2] = 753488;
     $vararg_ptr7 = (($vararg_buffer10) + 4|0);
     HEAP32[$vararg_ptr7>>2] = 211;
     $vararg_ptr8 = (($vararg_buffer10) + 8|0);
     HEAP32[$vararg_ptr8>>2] = 753648;
     $vararg_ptr9 = (($vararg_buffer10) + 12|0);
     HEAP32[$vararg_ptr9>>2] = $37;
     __Z6FormatPKcz($0,761968,$vararg_buffer10);
     $38 = HEAP8[$0>>0]|0;
     $39 = $38 & 1;
     $40 = ($39<<24>>24)==(0);
     if ($40) {
      $43 = (($0) + 1|0);
      $44 = $43;
     } else {
      $41 = (($0) + 8|0);
      $42 = HEAP32[$41>>2]|0;
      $44 = $42;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($44|0),0,(753784|0),21,1,0,0,(0|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      $47 = HEAP8[$0>>0]|0;
      $48 = $47 & 1;
      $49 = ($48<<24>>24)==(0);
      if ($49) {
       break;
      }
      $50 = (($0) + 8|0);
      $51 = HEAP32[$50>>2]|0;
      __ZdlPv($51);
      break;
     }
     $52 = ___cxa_find_matching_catch()|0;
     $53 = tempRet0;
     $54 = HEAP8[$0>>0]|0;
     $55 = $54 & 1;
     $56 = ($55<<24>>24)==(0);
     if ($56) {
      ___resumeException($52|0);
      // unreachable;
     }
     $57 = (($0) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     __ZdlPv($58);
     ___resumeException($52|0);
     // unreachable;
    }
   } while(0);
   $59 = HEAP32[$numSubSounds>>2]|0;
   $60 = ($59|0)>(0);
   if (!($60)) {
    HEAP32[$1>>2] = 3;
    $67 = HEAP32[$3>>2]|0;
    $68 = (($this) + 48|0);
    HEAP32[$68>>2] = $67;
    HEAP32[$3>>2] = 0;
    STACKTOP = sp;return;
   }
   $61 = HEAP32[$3>>2]|0;
   $62 = (($this) + 24|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($this) + 48|0);
   $65 = (__ZN4FMOD5Sound11getSubSoundEiPPS0_($61,$63,$64)|0);
   $66 = ($65|0)==(0);
   if (!($66)) {
    STACKTOP = sp;return;
   }
   HEAP32[$1>>2] = 2;
   STACKTOP = sp;return;
  } else {
   STACKTOP = sp;return;
  }
 } else if ((($2|0) == 2)) {
  $69 = (($this) + 48|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (__ZN4FMOD5Sound12getOpenStateEP14FMOD_OPENSTATEPjPbS4_($70,$openstate,$pctbuffered,$starving,$diskbusy)|0);
  $72 = ($71|0)==(0);
  if (!($72)) {
   STACKTOP = sp;return;
  }
  $73 = HEAP32[$openstate>>2]|0;
  if ((($73|0) == 2)) {
   HEAP32[$1>>2] = 4;
   STACKTOP = sp;return;
  } else if ((($73|0) == 0)) {
   $74 = HEAP32[$69>>2]|0;
   $75 = (($this) + 12|0);
   $76 = (__ZN4FMOD5Sound11setUserDataEPv($74,$75)|0);
   $77 = ($76|0)==(0);
   do {
    if (!($77)) {
     $78 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($76)|0);
     HEAP32[$vararg_buffer10>>2] = 753488;
     $vararg_ptr13 = (($vararg_buffer10) + 4|0);
     HEAP32[$vararg_ptr13>>2] = 245;
     $vararg_ptr14 = (($vararg_buffer10) + 8|0);
     HEAP32[$vararg_ptr14>>2] = 753688;
     $vararg_ptr15 = (($vararg_buffer10) + 12|0);
     HEAP32[$vararg_ptr15>>2] = $78;
     __Z6FormatPKcz($0,761968,$vararg_buffer10);
     $79 = HEAP8[$0>>0]|0;
     $80 = $79 & 1;
     $81 = ($80<<24>>24)==(0);
     if ($81) {
      $84 = (($0) + 1|0);
      $85 = $84;
     } else {
      $82 = (($0) + 8|0);
      $83 = HEAP32[$82>>2]|0;
      $85 = $83;
     }
     __THREW__ = 0;
     invoke_viiiiiiii(21,($85|0),0,(753784|0),21,1,0,0,(0|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if (!($87)) {
      $88 = HEAP8[$0>>0]|0;
      $89 = $88 & 1;
      $90 = ($89<<24>>24)==(0);
      if ($90) {
       break;
      }
      $91 = (($0) + 8|0);
      $92 = HEAP32[$91>>2]|0;
      __ZdlPv($92);
      break;
     }
     $93 = ___cxa_find_matching_catch()|0;
     $94 = tempRet0;
     $95 = HEAP8[$0>>0]|0;
     $96 = $95 & 1;
     $97 = ($96<<24>>24)==(0);
     if ($97) {
      ___resumeException($93|0);
      // unreachable;
     }
     $98 = (($0) + 8|0);
     $99 = HEAP32[$98>>2]|0;
     __ZdlPv($99);
     ___resumeException($93|0);
     // unreachable;
    }
   } while(0);
   HEAP32[$1>>2] = 3;
   STACKTOP = sp;return;
  } else {
   STACKTOP = sp;return;
  }
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN11SoundHandle8Instance13CreateChannelERS_b($agg$result,$this,$requester,$paused) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $requester = $requester|0;
 $paused = $paused|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i14 = 0, $$pre$i$i35 = 0, $$pre$i$i46 = 0, $$pre$i$i6 = 0, $$pre$phiZ2D = 0, $$pre66 = 0, $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $channel = 0, $channel1 = 0, $channel2 = 0, $clone = 0;
 var $fmodchannel = 0, $or$cond = 0, $temp$0$i = 0, $temp$0$i43 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $vararg_buffer = sp;
 $0 = sp + 140|0;
 $1 = sp + 136|0;
 $2 = sp + 132|0;
 $3 = sp + 128|0;
 $clone = sp + 112|0;
 $4 = sp + 104|0;
 $channel = sp + 144|0;
 $5 = sp + 56|0;
 $channel1 = sp + 40|0;
 $6 = sp + 24|0;
 $fmodchannel = sp + 20|0;
 $7 = sp + 8|0;
 $channel2 = sp + 72|0;
 $8 = sp + 88|0;
 $9 = ($this|0)==(0|0);
 if (!($9)) {
  $10 = (($this) + 52|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(4);
  if ($12) {
   HEAP32[$agg$result>>2] = 0;
   $13 = (($agg$result) + 4|0);
   HEAP32[$13>>2] = 0;
   $14 = (($agg$result) + 8|0);
   HEAP32[$14>>2] = $agg$result;
   $15 = (($agg$result) + 12|0);
   HEAP32[$15>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $16 = (($this) + 116|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if (!($18)) {
  HEAP32[$agg$result>>2] = 0;
  $19 = (($agg$result) + 4|0);
  HEAP32[$19>>2] = 0;
  $20 = (($agg$result) + 8|0);
  HEAP32[$20>>2] = $agg$result;
  $21 = (($agg$result) + 12|0);
  HEAP32[$21>>2] = 0;
  STACKTOP = sp;return;
 }
 $22 = (($this) + 68|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2;
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = (($this) + 40|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($this) + 36|0);
  $29 = ($27|0)==($28|0);
  if (!($29)) {
   $30 = (__Z15GetAudioManagerv()|0);
   $31 = (__ZN12AudioManager15GetSoundManagerEv($30)|0);
   $32 = (($this) + 72|0);
   $33 = (($this) + 24|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($this) + 56|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = HEAP32[$22>>2]|0;
   $38 = (($this) + 60|0);
   $39 = HEAP32[$38>>2]|0;
   HEAP32[$4>>2] = $39;
   __ZN12SoundManager9GetHandleERK16StreamedResourceijj4PPtrI10SampleClipEb($clone,$31,$32,$34,$36,$37,$4,1);
   $40 = (($clone) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0|0);
   L13: do {
    if ($42) {
     HEAP32[$agg$result>>2] = 0;
     $43 = (($agg$result) + 4|0);
     HEAP32[$43>>2] = 0;
     $44 = (($agg$result) + 8|0);
     HEAP32[$44>>2] = $agg$result;
     $45 = (($agg$result) + 12|0);
     HEAP32[$45>>2] = 0;
    } else {
     $48 = (($41) + 104|0);
     HEAP32[$48>>2] = $this;
     $49 = (($this) + 108|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (($41) + 108|0);
     HEAP32[$51>>2] = $50;
     $52 = HEAP32[$49>>2]|0;
     $53 = (($52) + 104|0);
     HEAP32[$53>>2] = $41;
     HEAP32[$49>>2] = $41;
     $54 = HEAP32[$40>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      label = 20;
     } else {
      $56 = (($54) + 52|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(4);
      if ($58) {
       __THREW__ = 0;
       $59 = (invoke_i(118)|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 10;
       } else {
        __THREW__ = 0;
        $62 = (invoke_ii(3391,($59|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 10;
        } else {
         $65 = (($62) + 24|0);
         $66 = ($41|0)==($65|0);
         if (!($66)) {
          $67 = HEAP32[$41>>2]|0;
          $68 = ($67|0)==(0|0);
          $$pre$i$i$i = (($41) + 4|0);
          if (!($68)) {
           $69 = HEAP32[$$pre$i$i$i>>2]|0;
           $70 = (($67) + 4|0);
           HEAP32[$70>>2] = $69;
           $71 = HEAP32[$41>>2]|0;
           $72 = HEAP32[$$pre$i$i$i>>2]|0;
           HEAP32[$72>>2] = $71;
           HEAP32[$41>>2] = 0;
           HEAP32[$$pre$i$i$i>>2] = 0;
          }
          $73 = HEAP32[$65>>2]|0;
          HEAP32[$41>>2] = $73;
          HEAP32[$$pre$i$i$i>>2] = $65;
          $74 = (($73) + 4|0);
          HEAP32[$74>>2] = $41;
          $75 = HEAP32[$$pre$i$i$i>>2]|0;
          HEAP32[$75>>2] = $41;
         }
         $76 = (($41) + 116|0);
         HEAP8[$76>>0] = 1;
         HEAP32[$agg$result>>2] = 0;
         $77 = (($agg$result) + 4|0);
         HEAP32[$77>>2] = 0;
         $78 = (($agg$result) + 8|0);
         HEAP32[$78>>2] = $agg$result;
         $79 = (($agg$result) + 12|0);
         HEAP32[$79>>2] = 0;
         break;
        }
       }
      } else {
       label = 20;
      }
     }
     do {
      if ((label|0) == 20) {
       __THREW__ = 0;
       invoke_vii(3336,($requester|0),($clone|0));
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        label = 10;
       } else {
        $82 = HEAP32[$40>>2]|0;
        $83 = ($82|0)==(0|0);
        if (!($83)) {
         $84 = (($82) + 52|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = ($85|0)==(3);
         if ($86) {
          __THREW__ = 0;
          invoke_viiii(410,($agg$result|0),($41|0),($requester|0),($paused|0));
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           label = 10;
           break;
          } else {
           break L13;
          }
         }
        }
        HEAP32[$5>>2] = 0;
        $89 = (($5) + 4|0);
        HEAP32[$89>>2] = 0;
        $90 = (($5) + 8|0);
        HEAP32[$90>>2] = $5;
        $91 = (($5) + 12|0);
        HEAP32[$91>>2] = $82;
        if (!($83)) {
         $92 = (($82) + 28|0);
         $93 = ($5|0)==($92|0);
         if (!($93)) {
          $94 = HEAP32[$92>>2]|0;
          HEAP32[$5>>2] = $94;
          HEAP32[$89>>2] = $92;
          $95 = (($94) + 4|0);
          HEAP32[$95>>2] = $5;
          $96 = HEAP32[$89>>2]|0;
          HEAP32[$96>>2] = $5;
         }
        }
        __THREW__ = 0;
        invoke_viii(1989,($channel|0),($5|0),($paused|0));
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if ($98) {
         $145 = ___cxa_find_matching_catch()|0;
         $146 = tempRet0;
         __THREW__ = 0;
         invoke_vi(3642,($5|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if (!($148)) {
          $$0 = $145;$$01 = $146;
          break;
         }
         $475 = ___cxa_find_matching_catch(0|0)|0;
         $476 = tempRet0;
         ___clang_call_terminate($475);
         // unreachable;
        }
        __THREW__ = 0;
        invoke_vi(3642,($5|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 10;
        } else {
         $101 = (($41) + 96|0);
         $102 = (($channel) + 12|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = (($103) + 228|0);
         $105 = ($104|0)==($101|0);
         if ($105) {
          $117 = $103;
         } else {
          $106 = HEAP32[$104>>2]|0;
          $107 = ($106|0)==(0|0);
          $$pre$i$i35 = (($103) + 232|0);
          if (!($107)) {
           $108 = HEAP32[$$pre$i$i35>>2]|0;
           $109 = (($106) + 4|0);
           HEAP32[$109>>2] = $108;
           $110 = HEAP32[$104>>2]|0;
           $111 = HEAP32[$$pre$i$i35>>2]|0;
           HEAP32[$111>>2] = $110;
           HEAP32[$104>>2] = 0;
           HEAP32[$$pre$i$i35>>2] = 0;
          }
          $112 = HEAP32[$101>>2]|0;
          HEAP32[$104>>2] = $112;
          HEAP32[$$pre$i$i35>>2] = $101;
          $113 = (($112) + 4|0);
          HEAP32[$113>>2] = $104;
          $114 = HEAP32[$$pre$i$i35>>2]|0;
          HEAP32[$114>>2] = $104;
          $$pre68 = HEAP32[$102>>2]|0;
          $117 = $$pre68;
         }
         $115 = (($41) + 36|0);
         $116 = (($117) + 216|0);
         $118 = ($116|0)==($115|0);
         if ($118) {
          $131 = $117;
         } else {
          $119 = HEAP32[$116>>2]|0;
          $120 = ($119|0)==(0|0);
          $$pre$i$i46 = (($117) + 220|0);
          if (!($120)) {
           $121 = HEAP32[$$pre$i$i46>>2]|0;
           $122 = (($119) + 4|0);
           HEAP32[$122>>2] = $121;
           $123 = HEAP32[$116>>2]|0;
           $124 = HEAP32[$$pre$i$i46>>2]|0;
           HEAP32[$124>>2] = $123;
           HEAP32[$116>>2] = 0;
           HEAP32[$$pre$i$i46>>2] = 0;
          }
          $125 = HEAP32[$115>>2]|0;
          HEAP32[$116>>2] = $125;
          HEAP32[$$pre$i$i46>>2] = $115;
          $126 = (($125) + 4|0);
          HEAP32[$126>>2] = $116;
          $127 = HEAP32[$$pre$i$i46>>2]|0;
          HEAP32[$127>>2] = $116;
          $$pre69 = HEAP32[$102>>2]|0;
          $131 = $$pre69;
         }
         HEAP32[$agg$result>>2] = 0;
         $128 = (($agg$result) + 4|0);
         HEAP32[$128>>2] = 0;
         $129 = (($agg$result) + 8|0);
         HEAP32[$129>>2] = $agg$result;
         $130 = (($agg$result) + 12|0);
         HEAP32[$130>>2] = $131;
         $132 = ($131|0)==(0|0);
         if (!($132)) {
          $133 = (($131) + 208|0);
          $134 = ($agg$result|0)==($133|0);
          if (!($134)) {
           $135 = HEAP32[$133>>2]|0;
           HEAP32[$agg$result>>2] = $135;
           HEAP32[$128>>2] = $133;
           $136 = (($135) + 4|0);
           HEAP32[$136>>2] = $agg$result;
           $137 = HEAP32[$128>>2]|0;
           HEAP32[$137>>2] = $agg$result;
          }
         }
         HEAP32[$102>>2] = 0;
         $138 = HEAP32[$channel>>2]|0;
         $139 = ($138|0)==(0|0);
         if ($139) {
          break L13;
         }
         $140 = (($channel) + 4|0);
         $141 = HEAP32[$140>>2]|0;
         $142 = (($138) + 4|0);
         HEAP32[$142>>2] = $141;
         $143 = HEAP32[$channel>>2]|0;
         $144 = HEAP32[$140>>2]|0;
         HEAP32[$144>>2] = $143;
         HEAP32[$channel>>2] = 0;
         HEAP32[$140>>2] = 0;
         break L13;
        }
       }
      }
     } while(0);
     if ((label|0) == 10) {
      $46 = ___cxa_find_matching_catch()|0;
      $47 = tempRet0;
      $$0 = $46;$$01 = $47;
     }
     __THREW__ = 0;
     invoke_vi(3642,($clone|0));
     $149 = __THREW__; __THREW__ = 0;
     $150 = $149&1;
     if ($150) {
      $475 = ___cxa_find_matching_catch(0|0)|0;
      $476 = tempRet0;
      ___clang_call_terminate($475);
      // unreachable;
     } else {
      $$2 = $$0;$$23 = $$01;
      ___resumeException($$2|0);
      // unreachable;
     }
    }
   } while(0);
   __ZN11SoundHandleD2Ev($clone);
   STACKTOP = sp;return;
  }
 }
 if (!($9)) {
  $151 = (($this) + 52|0);
  $152 = HEAP32[$151>>2]|0;
  $153 = ($152|0)==(3);
  if ($153) {
   HEAP32[$6>>2] = 0;
   $154 = (($6) + 4|0);
   HEAP32[$154>>2] = 0;
   $155 = (($6) + 8|0);
   HEAP32[$155>>2] = $6;
   $156 = (($requester) + 12|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($6) + 12|0);
   HEAP32[$158>>2] = $157;
   $159 = ($157|0)==(0|0);
   if (!($159)) {
    $160 = (($157) + 28|0);
    $161 = ($6|0)==($160|0);
    if (!($161)) {
     $162 = HEAP32[$160>>2]|0;
     HEAP32[$6>>2] = $162;
     HEAP32[$154>>2] = $160;
     $163 = (($162) + 4|0);
     HEAP32[$163>>2] = $6;
     $164 = HEAP32[$154>>2]|0;
     HEAP32[$164>>2] = $6;
    }
   }
   __THREW__ = 0;
   invoke_viii(1989,($channel1|0),($6|0),($paused|0));
   $165 = __THREW__; __THREW__ = 0;
   $166 = $165&1;
   if ($166) {
    $261 = ___cxa_find_matching_catch()|0;
    $262 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3642,($6|0));
    $263 = __THREW__; __THREW__ = 0;
    $264 = $263&1;
    if ($264) {
     $475 = ___cxa_find_matching_catch(0|0)|0;
     $476 = tempRet0;
     ___clang_call_terminate($475);
     // unreachable;
    } else {
     $$2 = $261;$$23 = $262;
     ___resumeException($$2|0);
     // unreachable;
    }
   }
   __ZN11SoundHandleD2Ev($6);
   HEAP32[$fmodchannel>>2] = 0;
   __THREW__ = 0;
   $167 = (invoke_i(118)|0);
   $168 = __THREW__; __THREW__ = 0;
   $169 = $168&1;
   L82: do {
    if ($169) {
     label = 78;
    } else {
     $170 = (($167) + 92|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = (($this) + 48|0);
     $173 = HEAP32[$172>>2]|0;
     __THREW__ = 0;
     $174 = (invoke_iiiiii(215,($171|0),-1,($173|0),1,($fmodchannel|0))|0);
     $175 = __THREW__; __THREW__ = 0;
     $176 = $175&1;
     if ($176) {
      label = 78;
     } else {
      $177 = ($174|0)!=(0);
      $178 = HEAP32[$fmodchannel>>2]|0;
      $179 = ($178|0)==(0|0);
      $or$cond = $177 | $179;
      if ($or$cond) {
       $180 = ($174|0)==(10);
       do {
        if ($180) {
         $181 = (($this) + 60|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = ($182|0)==(0);
         do {
          if ($183) {
           $258 = 0;
          } else {
           HEAP32[$0>>2] = $182;
           $184 = HEAP32[560624>>2]|0;
           $185 = ($184|0)==(0|0);
           do {
            if ($185) {
             label = 64;
            } else {
             $186 = (($184) + 36|0);
             $187 = HEAP32[$186>>2]|0;
             $188 = (($184) + 4|0);
             $189 = HEAP32[$188>>2]|0;
             $190 = ($187|0)==($189|0);
             do {
              if ($190) {
               $191 = (($184) + 28|0);
               $192 = HEAP32[$191>>2]|0;
               $193 = (($184) + 32|0);
               $194 = HEAP32[$193>>2]|0;
               $195 = (($192) + ($194<<3)|0);
               $211 = $195;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$184,$0);
               $196 = HEAP32[$vararg_buffer>>2]|0;
               $197 = ($196|0)==(-1);
               $198 = (($184) + 28|0);
               $199 = HEAP32[$198>>2]|0;
               if ($197) {
                $200 = (($184) + 32|0);
                $201 = HEAP32[$200>>2]|0;
                $202 = (($199) + ($201<<3)|0);
                $211 = $202;
                break;
               } else {
                $203 = (($199) + ($196<<3)|0);
                $211 = $203;
                break;
               }
              }
             } while(0);
             $204 = HEAP32[560624>>2]|0;
             $205 = (($204) + 28|0);
             $206 = HEAP32[$205>>2]|0;
             $207 = (($204) + 32|0);
             $208 = HEAP32[$207>>2]|0;
             $209 = (($206) + ($208<<3)|0);
             $210 = ($211|0)==($209|0);
             if ($210) {
              label = 64;
              break;
             }
             $212 = (($211) + 4|0);
             $213 = HEAP32[$212>>2]|0;
             $214 = ($213|0)==(0|0);
             if ($214) {
              label = 64;
             }
            }
           } while(0);
           if ((label|0) == 64) {
            $215 = HEAP32[$181>>2]|0;
            __THREW__ = 0;
            $216 = (invoke_ii(3215,($215|0))|0);
            $217 = __THREW__; __THREW__ = 0;
            $218 = $217&1;
            if ($218) {
             label = 78;
             break L82;
            }
            $219 = ($216|0)==(0|0);
            if ($219) {
             $258 = 0;
             break;
            }
           }
           $220 = HEAP32[$181>>2]|0;
           HEAP32[$1>>2] = $220;
           $221 = HEAP32[560624>>2]|0;
           $222 = ($221|0)==(0|0);
           do {
            if ($222) {
             label = 74;
            } else {
             $223 = (($221) + 36|0);
             $224 = HEAP32[$223>>2]|0;
             $225 = (($221) + 4|0);
             $226 = HEAP32[$225>>2]|0;
             $227 = ($224|0)==($226|0);
             do {
              if ($227) {
               $228 = (($221) + 28|0);
               $229 = HEAP32[$228>>2]|0;
               $230 = (($221) + 32|0);
               $231 = HEAP32[$230>>2]|0;
               $232 = (($229) + ($231<<3)|0);
               $248 = $232;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$221,$1);
               $233 = HEAP32[$vararg_buffer>>2]|0;
               $234 = ($233|0)==(-1);
               $235 = (($221) + 28|0);
               $236 = HEAP32[$235>>2]|0;
               if ($234) {
                $237 = (($221) + 32|0);
                $238 = HEAP32[$237>>2]|0;
                $239 = (($236) + ($238<<3)|0);
                $248 = $239;
                break;
               } else {
                $240 = (($236) + ($233<<3)|0);
                $248 = $240;
                break;
               }
              }
             } while(0);
             $241 = HEAP32[560624>>2]|0;
             $242 = (($241) + 28|0);
             $243 = HEAP32[$242>>2]|0;
             $244 = (($241) + 32|0);
             $245 = HEAP32[$244>>2]|0;
             $246 = (($243) + ($245<<3)|0);
             $247 = ($248|0)==($246|0);
             if ($247) {
              label = 74;
              break;
             }
             $249 = (($248) + 4|0);
             $250 = HEAP32[$249>>2]|0;
             $251 = ($250|0)==(0|0);
             if ($251) {
              label = 74;
             } else {
              $temp$0$i43 = $250;
             }
            }
           } while(0);
           if ((label|0) == 74) {
            $252 = HEAP32[$181>>2]|0;
            __THREW__ = 0;
            $253 = (invoke_ii(3215,($252|0))|0);
            $254 = __THREW__; __THREW__ = 0;
            $255 = $254&1;
            if ($255) {
             label = 78;
             break L82;
            } else {
             $temp$0$i43 = $253;
            }
           }
           $256 = (($temp$0$i43) + 4|0);
           $257 = HEAP32[$256>>2]|0;
           $258 = $257;
          }
         } while(0);
         __THREW__ = 0;
         invoke_viiiiiiii(21,(753728|0),0,(753784|0),301,512,($258|0),0,(0|0));
         $259 = __THREW__; __THREW__ = 0;
         $260 = $259&1;
         if ($260) {
          label = 78;
          break L82;
         }
        } else {
         $267 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($174)|0);
         __THREW__ = 0;
         HEAP32[$vararg_buffer>>2] = $267;
         invoke_viii(1617,($7|0),(753792|0),($vararg_buffer|0));
         $268 = __THREW__; __THREW__ = 0;
         $269 = $268&1;
         if ($269) {
          label = 78;
          break L82;
         }
         $270 = (($this) + 60|0);
         $271 = HEAP32[$270>>2]|0;
         $272 = ($271|0)==(0);
         do {
          if ($272) {
           $354 = 0;
           label = 101;
          } else {
           HEAP32[$2>>2] = $271;
           $273 = HEAP32[560624>>2]|0;
           $274 = ($273|0)==(0|0);
           do {
            if ($274) {
             label = 89;
            } else {
             $275 = (($273) + 36|0);
             $276 = HEAP32[$275>>2]|0;
             $277 = (($273) + 4|0);
             $278 = HEAP32[$277>>2]|0;
             $279 = ($276|0)==($278|0);
             do {
              if ($279) {
               $280 = (($273) + 28|0);
               $281 = HEAP32[$280>>2]|0;
               $282 = (($273) + 32|0);
               $283 = HEAP32[$282>>2]|0;
               $284 = (($281) + ($283<<3)|0);
               $300 = $284;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$273,$2);
               $285 = HEAP32[$vararg_buffer>>2]|0;
               $286 = ($285|0)==(-1);
               $287 = (($273) + 28|0);
               $288 = HEAP32[$287>>2]|0;
               if ($286) {
                $289 = (($273) + 32|0);
                $290 = HEAP32[$289>>2]|0;
                $291 = (($288) + ($290<<3)|0);
                $300 = $291;
                break;
               } else {
                $292 = (($288) + ($285<<3)|0);
                $300 = $292;
                break;
               }
              }
             } while(0);
             $293 = HEAP32[560624>>2]|0;
             $294 = (($293) + 28|0);
             $295 = HEAP32[$294>>2]|0;
             $296 = (($293) + 32|0);
             $297 = HEAP32[$296>>2]|0;
             $298 = (($295) + ($297<<3)|0);
             $299 = ($300|0)==($298|0);
             if ($299) {
              label = 89;
              break;
             }
             $301 = (($300) + 4|0);
             $302 = HEAP32[$301>>2]|0;
             $303 = ($302|0)==(0|0);
             if ($303) {
              label = 89;
             }
            }
           } while(0);
           if ((label|0) == 89) {
            $304 = HEAP32[$270>>2]|0;
            __THREW__ = 0;
            $305 = (invoke_ii(3215,($304|0))|0);
            $306 = __THREW__; __THREW__ = 0;
            $307 = $306&1;
            if ($307) {
             break;
            }
            $308 = ($305|0)==(0|0);
            if ($308) {
             $354 = 0;
             label = 101;
             break;
            }
           }
           $309 = HEAP32[$270>>2]|0;
           HEAP32[$3>>2] = $309;
           $310 = HEAP32[560624>>2]|0;
           $311 = ($310|0)==(0|0);
           do {
            if ($311) {
             label = 99;
            } else {
             $312 = (($310) + 36|0);
             $313 = HEAP32[$312>>2]|0;
             $314 = (($310) + 4|0);
             $315 = HEAP32[$314>>2]|0;
             $316 = ($313|0)==($315|0);
             do {
              if ($316) {
               $317 = (($310) + 28|0);
               $318 = HEAP32[$317>>2]|0;
               $319 = (($310) + 32|0);
               $320 = HEAP32[$319>>2]|0;
               $321 = (($318) + ($320<<3)|0);
               $337 = $321;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($vararg_buffer,$310,$3);
               $322 = HEAP32[$vararg_buffer>>2]|0;
               $323 = ($322|0)==(-1);
               $324 = (($310) + 28|0);
               $325 = HEAP32[$324>>2]|0;
               if ($323) {
                $326 = (($310) + 32|0);
                $327 = HEAP32[$326>>2]|0;
                $328 = (($325) + ($327<<3)|0);
                $337 = $328;
                break;
               } else {
                $329 = (($325) + ($322<<3)|0);
                $337 = $329;
                break;
               }
              }
             } while(0);
             $330 = HEAP32[560624>>2]|0;
             $331 = (($330) + 28|0);
             $332 = HEAP32[$331>>2]|0;
             $333 = (($330) + 32|0);
             $334 = HEAP32[$333>>2]|0;
             $335 = (($332) + ($334<<3)|0);
             $336 = ($337|0)==($335|0);
             if ($336) {
              label = 99;
              break;
             }
             $338 = (($337) + 4|0);
             $339 = HEAP32[$338>>2]|0;
             $340 = ($339|0)==(0|0);
             if ($340) {
              label = 99;
             } else {
              $temp$0$i = $339;
             }
            }
           } while(0);
           if ((label|0) == 99) {
            $341 = HEAP32[$270>>2]|0;
            __THREW__ = 0;
            $342 = (invoke_ii(3215,($341|0))|0);
            $343 = __THREW__; __THREW__ = 0;
            $344 = $343&1;
            if ($344) {
             break;
            } else {
             $temp$0$i = $342;
            }
           }
           $345 = (($temp$0$i) + 4|0);
           $346 = HEAP32[$345>>2]|0;
           $354 = $346;
           label = 101;
          }
         } while(0);
         if ((label|0) == 101) {
          $347 = HEAP8[$7>>0]|0;
          $348 = $347 & 1;
          $349 = ($348<<24>>24)==(0);
          if ($349) {
           $352 = (($7) + 1|0);
           $353 = $352;
          } else {
           $350 = (($7) + 8|0);
           $351 = HEAP32[$350>>2]|0;
           $353 = $351;
          }
          __THREW__ = 0;
          invoke_viiiiiiii(21,($353|0),0,(753784|0),303,1,($354|0),0,(0|0));
          $355 = __THREW__; __THREW__ = 0;
          $356 = $355&1;
          if (!($356)) {
           $357 = HEAP8[$7>>0]|0;
           $358 = $357 & 1;
           $359 = ($358<<24>>24)==(0);
           if ($359) {
            break;
           }
           $360 = (($7) + 8|0);
           $361 = HEAP32[$360>>2]|0;
           __ZdlPv($361);
           break;
          }
         }
         $362 = ___cxa_find_matching_catch()|0;
         $363 = tempRet0;
         $364 = HEAP8[$7>>0]|0;
         $365 = $364 & 1;
         $366 = ($365<<24>>24)==(0);
         if ($366) {
          $$1 = $362;$$12 = $363;
          break L82;
         }
         $367 = (($7) + 8|0);
         $368 = HEAP32[$367>>2]|0;
         __ZdlPv($368);
         $$1 = $362;$$12 = $363;
         break L82;
        }
       } while(0);
       HEAP32[$agg$result>>2] = 0;
       $369 = (($agg$result) + 4|0);
       HEAP32[$369>>2] = 0;
       $370 = (($agg$result) + 8|0);
       HEAP32[$370>>2] = $agg$result;
       $371 = (($agg$result) + 12|0);
       HEAP32[$371>>2] = 0;
       $$pre70 = (($channel1) + 12|0);
       $$pre$phiZ2D = $$pre70;
      } else {
       $372 = (($channel1) + 12|0);
       $373 = HEAP32[$372>>2]|0;
       __THREW__ = 0;
       invoke_vii(3342,($373|0),($178|0));
       $374 = __THREW__; __THREW__ = 0;
       $375 = $374&1;
       if ($375) {
        label = 78;
        break;
       }
       $376 = (($this) + 36|0);
       $377 = HEAP32[$372>>2]|0;
       $378 = (($377) + 216|0);
       $379 = ($378|0)==($376|0);
       if ($379) {
        $392 = $377;
       } else {
        $380 = HEAP32[$378>>2]|0;
        $381 = ($380|0)==(0|0);
        $$pre$i$i14 = (($377) + 220|0);
        if (!($381)) {
         $382 = HEAP32[$$pre$i$i14>>2]|0;
         $383 = (($380) + 4|0);
         HEAP32[$383>>2] = $382;
         $384 = HEAP32[$378>>2]|0;
         $385 = HEAP32[$$pre$i$i14>>2]|0;
         HEAP32[$385>>2] = $384;
         HEAP32[$378>>2] = 0;
         HEAP32[$$pre$i$i14>>2] = 0;
        }
        $386 = HEAP32[$376>>2]|0;
        HEAP32[$378>>2] = $386;
        HEAP32[$$pre$i$i14>>2] = $376;
        $387 = (($386) + 4|0);
        HEAP32[$387>>2] = $378;
        $388 = HEAP32[$$pre$i$i14>>2]|0;
        HEAP32[$388>>2] = $378;
        $$pre67 = HEAP32[$372>>2]|0;
        $392 = $$pre67;
       }
       HEAP32[$agg$result>>2] = 0;
       $389 = (($agg$result) + 4|0);
       HEAP32[$389>>2] = 0;
       $390 = (($agg$result) + 8|0);
       HEAP32[$390>>2] = $agg$result;
       $391 = (($agg$result) + 12|0);
       HEAP32[$391>>2] = $392;
       $393 = ($392|0)==(0|0);
       if ($393) {
        $$pre$phiZ2D = $372;
       } else {
        $394 = (($392) + 208|0);
        $395 = ($agg$result|0)==($394|0);
        if ($395) {
         $$pre$phiZ2D = $372;
        } else {
         $396 = HEAP32[$394>>2]|0;
         HEAP32[$agg$result>>2] = $396;
         HEAP32[$389>>2] = $394;
         $397 = (($396) + 4|0);
         HEAP32[$397>>2] = $agg$result;
         $398 = HEAP32[$389>>2]|0;
         HEAP32[$398>>2] = $agg$result;
         $$pre$phiZ2D = $372;
        }
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = 0;
      $399 = HEAP32[$channel1>>2]|0;
      $400 = ($399|0)==(0|0);
      if ($400) {
       STACKTOP = sp;return;
      }
      $401 = (($channel1) + 4|0);
      $402 = HEAP32[$401>>2]|0;
      $403 = (($399) + 4|0);
      HEAP32[$403>>2] = $402;
      $404 = HEAP32[$channel1>>2]|0;
      $405 = HEAP32[$401>>2]|0;
      HEAP32[$405>>2] = $404;
      HEAP32[$channel1>>2] = 0;
      HEAP32[$401>>2] = 0;
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 78) {
    $265 = ___cxa_find_matching_catch()|0;
    $266 = tempRet0;
    $$1 = $265;$$12 = $266;
   }
   $406 = (($channel1) + 12|0);
   HEAP32[$406>>2] = 0;
   $407 = HEAP32[$channel1>>2]|0;
   $408 = ($407|0)==(0|0);
   if ($408) {
    $$2 = $$1;$$23 = $$12;
    ___resumeException($$2|0);
    // unreachable;
   }
   $409 = (($channel1) + 4|0);
   $410 = HEAP32[$409>>2]|0;
   $411 = (($407) + 4|0);
   HEAP32[$411>>2] = $410;
   $412 = HEAP32[$channel1>>2]|0;
   $413 = HEAP32[$409>>2]|0;
   HEAP32[$413>>2] = $412;
   HEAP32[$channel1>>2] = 0;
   HEAP32[$409>>2] = 0;
   $$2 = $$1;$$23 = $$12;
   ___resumeException($$2|0);
   // unreachable;
  }
 }
 HEAP32[$8>>2] = 0;
 $414 = (($8) + 4|0);
 HEAP32[$414>>2] = 0;
 $415 = (($8) + 8|0);
 HEAP32[$415>>2] = $8;
 $416 = (($requester) + 12|0);
 $417 = HEAP32[$416>>2]|0;
 $418 = (($8) + 12|0);
 HEAP32[$418>>2] = $417;
 $419 = ($417|0)==(0|0);
 if (!($419)) {
  $420 = (($417) + 28|0);
  $421 = ($8|0)==($420|0);
  if (!($421)) {
   $422 = HEAP32[$420>>2]|0;
   HEAP32[$8>>2] = $422;
   HEAP32[$414>>2] = $420;
   $423 = (($422) + 4|0);
   HEAP32[$423>>2] = $8;
   $424 = HEAP32[$414>>2]|0;
   HEAP32[$424>>2] = $8;
  }
 }
 __THREW__ = 0;
 invoke_viii(1989,($channel2|0),($8|0),($paused|0));
 $425 = __THREW__; __THREW__ = 0;
 $426 = $425&1;
 if ($426) {
  $471 = ___cxa_find_matching_catch()|0;
  $472 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3642,($8|0));
  $473 = __THREW__; __THREW__ = 0;
  $474 = $473&1;
  if ($474) {
   $475 = ___cxa_find_matching_catch(0|0)|0;
   $476 = tempRet0;
   ___clang_call_terminate($475);
   // unreachable;
  } else {
   $$2 = $471;$$23 = $472;
   ___resumeException($$2|0);
   // unreachable;
  }
 }
 __ZN11SoundHandleD2Ev($8);
 $427 = (($this) + 96|0);
 $428 = (($channel2) + 12|0);
 $429 = HEAP32[$428>>2]|0;
 $430 = (($429) + 228|0);
 $431 = ($430|0)==($427|0);
 if ($431) {
  $443 = $429;
 } else {
  $432 = HEAP32[$430>>2]|0;
  $433 = ($432|0)==(0|0);
  $$pre$i$i6 = (($429) + 232|0);
  if (!($433)) {
   $434 = HEAP32[$$pre$i$i6>>2]|0;
   $435 = (($432) + 4|0);
   HEAP32[$435>>2] = $434;
   $436 = HEAP32[$430>>2]|0;
   $437 = HEAP32[$$pre$i$i6>>2]|0;
   HEAP32[$437>>2] = $436;
   HEAP32[$430>>2] = 0;
   HEAP32[$$pre$i$i6>>2] = 0;
  }
  $438 = HEAP32[$427>>2]|0;
  HEAP32[$430>>2] = $438;
  HEAP32[$$pre$i$i6>>2] = $427;
  $439 = (($438) + 4|0);
  HEAP32[$439>>2] = $430;
  $440 = HEAP32[$$pre$i$i6>>2]|0;
  HEAP32[$440>>2] = $430;
  $$pre = HEAP32[$428>>2]|0;
  $443 = $$pre;
 }
 $441 = (($this) + 36|0);
 $442 = (($443) + 216|0);
 $444 = ($442|0)==($441|0);
 if ($444) {
  $457 = $443;
 } else {
  $445 = HEAP32[$442>>2]|0;
  $446 = ($445|0)==(0|0);
  $$pre$i$i = (($443) + 220|0);
  if (!($446)) {
   $447 = HEAP32[$$pre$i$i>>2]|0;
   $448 = (($445) + 4|0);
   HEAP32[$448>>2] = $447;
   $449 = HEAP32[$442>>2]|0;
   $450 = HEAP32[$$pre$i$i>>2]|0;
   HEAP32[$450>>2] = $449;
   HEAP32[$442>>2] = 0;
   HEAP32[$$pre$i$i>>2] = 0;
  }
  $451 = HEAP32[$441>>2]|0;
  HEAP32[$442>>2] = $451;
  HEAP32[$$pre$i$i>>2] = $441;
  $452 = (($451) + 4|0);
  HEAP32[$452>>2] = $442;
  $453 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$453>>2] = $442;
  $$pre66 = HEAP32[$428>>2]|0;
  $457 = $$pre66;
 }
 HEAP32[$agg$result>>2] = 0;
 $454 = (($agg$result) + 4|0);
 HEAP32[$454>>2] = 0;
 $455 = (($agg$result) + 8|0);
 HEAP32[$455>>2] = $agg$result;
 $456 = (($agg$result) + 12|0);
 HEAP32[$456>>2] = $457;
 $458 = ($457|0)==(0|0);
 if (!($458)) {
  $459 = (($457) + 208|0);
  $460 = ($agg$result|0)==($459|0);
  if (!($460)) {
   $461 = HEAP32[$459>>2]|0;
   HEAP32[$agg$result>>2] = $461;
   HEAP32[$454>>2] = $459;
   $462 = (($461) + 4|0);
   HEAP32[$462>>2] = $agg$result;
   $463 = HEAP32[$454>>2]|0;
   HEAP32[$463>>2] = $agg$result;
  }
 }
 HEAP32[$428>>2] = 0;
 $464 = HEAP32[$channel2>>2]|0;
 $465 = ($464|0)==(0|0);
 if ($465) {
  STACKTOP = sp;return;
 }
 $466 = (($channel2) + 4|0);
 $467 = HEAP32[$466>>2]|0;
 $468 = (($464) + 4|0);
 HEAP32[$468>>2] = $467;
 $469 = HEAP32[$channel2>>2]|0;
 $470 = HEAP32[$466>>2]|0;
 HEAP32[$470>>2] = $469;
 HEAP32[$channel2>>2] = 0;
 HEAP32[$466>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK14SoundHandleAPI12GetLoadStateEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (($this) + 52|0);
  $2 = HEAP32[$1>>2]|0;
  $$0 = $2;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN12SoundManager9GetHandleERK16StreamedResourceijj4PPtrI10SampleClipEb($agg$result,$this,$resource,$subsound,$mode,$flags,$ownerClip,$forceInstantiate) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $resource = $resource|0;
 $subsound = $subsound|0;
 $mode = $mode|0;
 $flags = $flags|0;
 $ownerClip = $ownerClip|0;
 $forceInstantiate = $forceInstantiate|0;
 var $$0 = 0, $$0$i = 0, $$0$i17 = 0, $$01 = 0, $$01$i = 0, $$02$i$i$i$i$i$i$i$i = 0, $$byval_copy3 = 0, $$masked$i$i$i$i$i$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0;
 var $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0;
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exinfo = 0, $exitcond$i$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i$i = 0, $i$03$i$i$i$i$i$i$i$i = 0, $p$01$i$i$i$i$i$i$i = 0, $phitmp$i = 0, $phitmp$i18 = 0, $reflection$01$i$i$i$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i$i$i$i = 0;
 var $resourcePath = 0, $result$0 = 0, $temp$0$i = 0, $temp$0$i24 = 0, $vararg_ptr1 = 0, $watchdog = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy3 = sp + 8|0;
 $0 = sp + 196|0;
 $1 = sp + 192|0;
 $2 = sp + 188|0;
 $3 = sp + 184|0;
 $4 = sp + 200|0;
 $watchdog = sp;
 $5 = sp + 20|0;
 $exinfo = sp + 24|0;
 $resourcePath = sp + 160|0;
 $6 = sp + 172|0;
 L1: do {
  if (!($forceInstantiate)) {
   $7 = (+__Z19GetTimeSinceStartupv());
   HEAPF64[$watchdog>>3] = $7;
   $8 = (($this) + 20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 16|0);
   $11 = ($9|0)==($10|0);
   if (!($11)) {
    $12 = (($resource) + 1|0);
    $13 = (($resource) + 16|0);
    $14 = (($resource) + 8|0);
    $15 = (($resource) + 4|0);
    $17 = $9;
    while(1) {
     __ZN20SoundManagerWatchDog6UpdateEPKci($watchdog,753488,761);
     $16 = (($17) + 8|0);
     $18 = HEAP32[$16>>2]|0;
     $19 = (($18) + 72|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = $20 & 1;
     $22 = ($21<<24>>24)==(0);
     if ($22) {
      $25 = $20&255;
      $26 = $25 >>> 1;
      $34 = $26;
     } else {
      $23 = (($18) + 76|0);
      $24 = HEAP32[$23>>2]|0;
      $34 = $24;
     }
     $27 = HEAP8[$resource>>0]|0;
     $28 = $27 & 1;
     $29 = ($28<<24>>24)==(0);
     if ($29) {
      $31 = $27&255;
      $32 = $31 >>> 1;
      $35 = $32;
     } else {
      $30 = HEAP32[$15>>2]|0;
      $35 = $30;
     }
     $33 = ($34|0)==($35|0);
     if ($33) {
      if ($22) {
       $38 = (($19) + 1|0);
       $44 = $38;
      } else {
       $36 = (($18) + 80|0);
       $37 = HEAP32[$36>>2]|0;
       $44 = $37;
      }
      if ($29) {
       $45 = $12;
      } else {
       $39 = HEAP32[$14>>2]|0;
       $45 = $39;
      }
      if ($22) {
       $42 = $20&255;
       $43 = $42 >>> 1;
       $46 = $43;
      } else {
       $40 = (($18) + 76|0);
       $41 = HEAP32[$40>>2]|0;
       $46 = $41;
      }
      $47 = (_strncmp($44,$45,$46)|0);
      $48 = ($47|0)==(0);
      if ($48) {
       $49 = (($18) + 88|0);
       $50 = $49;
       $51 = $50;
       $52 = HEAP32[$51>>2]|0;
       $53 = (($50) + 4)|0;
       $54 = $53;
       $55 = HEAP32[$54>>2]|0;
       $56 = $13;
       $57 = $56;
       $58 = HEAP32[$57>>2]|0;
       $59 = (($56) + 4)|0;
       $60 = $59;
       $61 = HEAP32[$60>>2]|0;
       $62 = ($52|0)==($58|0);
       $63 = ($55|0)==($61|0);
       $64 = $62 & $63;
       if ($64) {
        $65 = (($18) + 24|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = ($66|0)==($subsound|0);
        if ($67) {
         $68 = (($18) + 56|0);
         $69 = HEAP32[$68>>2]|0;
         $70 = ($69|0)==($mode|0);
         if ($70) {
          $71 = (($18) + 68|0);
          $72 = HEAP32[$71>>2]|0;
          $73 = $72 & 1;
          $74 = ($73|0)==(0);
          if (!($74)) {
           break;
          }
         }
        }
       }
      }
     }
     $84 = (($17) + 4|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ($85|0)==($10|0);
     if ($86) {
      break L1;
     } else {
      $17 = $85;
     }
    }
    HEAP32[$agg$result>>2] = 0;
    $75 = (($agg$result) + 4|0);
    HEAP32[$75>>2] = 0;
    $76 = (($agg$result) + 8|0);
    HEAP32[$76>>2] = $agg$result;
    $77 = (($agg$result) + 12|0);
    HEAP32[$77>>2] = $18;
    $78 = ($18|0)==(0|0);
    if ($78) {
     STACKTOP = sp;return;
    }
    $79 = (($18) + 28|0);
    $80 = ($agg$result|0)==($79|0);
    if ($80) {
     STACKTOP = sp;return;
    }
    $81 = HEAP32[$79>>2]|0;
    HEAP32[$agg$result>>2] = $81;
    HEAP32[$75>>2] = $79;
    $82 = (($81) + 4|0);
    HEAP32[$82>>2] = $agg$result;
    $83 = HEAP32[$75>>2]|0;
    HEAP32[$83>>2] = $agg$result;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $87 = HEAP32[628304>>2]|0;
 HEAP32[$5>>2] = $87;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$5+0>>2]|0;
 $88 = (__Znwj10MemLabelIdbiPKci(120,$$byval_copy3,0,16,753784,775)|0);
 HEAP32[$88>>2] = 0;
 $89 = (($88) + 4|0);
 HEAP32[$89>>2] = 0;
 $90 = (($88) + 8|0);
 HEAP32[$90>>2] = $88;
 $91 = HEAP8[693120>>0]|0;
 $92 = ($91<<24>>24)==(0);
 if ($92) {
  $$02$i$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i$i = 0;
  while(1) {
   $93 = $$02$i$i$i$i$i$i$i$i & 1;
   $94 = ($93|0)==(0);
   if ($94) {
    $reflection$1$i$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i$i;
   } else {
    $95 = (31 - ($i$03$i$i$i$i$i$i$i$i))|0;
    $96 = 1 << $95;
    $97 = $96 | $reflection$01$i$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i$i = $97;
   }
   $98 = (($i$03$i$i$i$i$i$i$i$i) + 1)|0;
   $99 = $$02$i$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i$i = ($98|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i$i) {
    $103 = $reflection$1$i$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i$i = 753944;
    break;
   } else {
    $$02$i$i$i$i$i$i$i$i = $99;$i$03$i$i$i$i$i$i$i$i = $98;$reflection$01$i$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $100 = HEAP8[$p$01$i$i$i$i$i$i$i>>0]|0;
   $101 = $100&255;
   $102 = $103 >>> 8;
   $$masked$i$i$i$i$i$i$i = $103 & 255;
   $104 = $101 ^ $$masked$i$i$i$i$i$i$i;
   $105 = (584048 + ($104<<2)|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = $106 ^ $102;
   $108 = (($p$01$i$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i$i = ($108|0)==(((753944 + 88|0))|0);
   if ($exitcond$i$i$i$i$i$i$i) {
    break;
   } else {
    $103 = $107;$p$01$i$i$i$i$i$i$i = $108;
   }
  }
  $109 = $107 ^ -1;
  HEAP32[693112>>2] = $109;
  $110 = 693120;
  $111 = $110;
  HEAP32[$111>>2] = 1;
  $112 = (($110) + 4)|0;
  $113 = $112;
  HEAP32[$113>>2] = 0;
  $115 = $109;
 } else {
  $$pre$i$i$i$i = HEAP32[693112>>2]|0;
  $115 = $$pre$i$i$i$i;
 }
 $114 = (($88) + 12|0);
 HEAP32[$114>>2] = $115;
 $116 = (($88) + 16|0);
 HEAP32[$116>>2] = $88;
 $117 = (($88) + 20|0);
 HEAP32[$117>>2] = 753944;
 $118 = (($88) + 24|0);
 $119 = (($88) + 28|0);
 $120 = (($88) + 32|0);
 HEAP32[$119>>2] = $119;
 HEAP32[$120>>2] = $119;
 $121 = (($88) + 36|0);
 $122 = (($88) + 40|0);
 HEAP32[$121>>2] = $121;
 HEAP32[$122>>2] = $121;
 $123 = (($88) + 44|0);
 $124 = (($88) + 88|0);
 $125 = $124;
 $126 = $125;
 HEAP32[$126>>2] = 0;
 $127 = (($125) + 4)|0;
 $128 = $127;
 HEAP32[$128>>2] = 0;
 $129 = (($88) + 96|0);
 $130 = (($88) + 100|0);
 dest=$123+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$129>>2] = $129;
 HEAP32[$130>>2] = $129;
 $131 = (($88) + 104|0);
 HEAP32[$131>>2] = $88;
 $132 = (($88) + 108|0);
 HEAP32[$132>>2] = $88;
 $133 = (($88) + 112|0);
 HEAP32[$133>>2] = 0;
 $134 = (($88) + 116|0);
 HEAP8[$134>>0] = 0;
 HEAP32[$118>>2] = $subsound;
 $135 = (($88) + 52|0);
 HEAP32[$135>>2] = 1;
 $136 = (($88) + 56|0);
 HEAP32[$136>>2] = $mode;
 $137 = (($88) + 68|0);
 HEAP32[$137>>2] = $flags;
 $138 = (($88) + 72|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($138,$resource)|0);
 $139 = (($resource) + 16|0);
 $140 = $139;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $124;
 $147 = $146;
 HEAP32[$147>>2] = $142;
 $148 = (($146) + 4)|0;
 $149 = $148;
 HEAP32[$149>>2] = $145;
 $150 = (($88) + 60|0);
 $151 = HEAP32[$ownerClip>>2]|0;
 HEAP32[$150>>2] = $151;
 $152 = HEAP32[$ownerClip>>2]|0;
 $153 = ($152|0)==(0);
 if ($153) {
  $$0$i = 0;
 } else {
  HEAP32[$3>>2] = $152;
  $154 = HEAP32[560624>>2]|0;
  $155 = ($154|0)==(0|0);
  if ($155) {
   label = 44;
  } else {
   $156 = (($154) + 36|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($154) + 4|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = ($157|0)==($159|0);
   do {
    if ($160) {
     $161 = (($154) + 28|0);
     $162 = HEAP32[$161>>2]|0;
     $163 = (($154) + 32|0);
     $164 = HEAP32[$163>>2]|0;
     $165 = (($162) + ($164<<3)|0);
     $181 = $165;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$154,$3);
     $166 = HEAP32[$$byval_copy3>>2]|0;
     $167 = ($166|0)==(-1);
     $168 = (($154) + 28|0);
     $169 = HEAP32[$168>>2]|0;
     if ($167) {
      $170 = (($154) + 32|0);
      $171 = HEAP32[$170>>2]|0;
      $172 = (($169) + ($171<<3)|0);
      $181 = $172;
      break;
     } else {
      $173 = (($169) + ($166<<3)|0);
      $181 = $173;
      break;
     }
    }
   } while(0);
   $174 = HEAP32[560624>>2]|0;
   $175 = (($174) + 28|0);
   $176 = HEAP32[$175>>2]|0;
   $177 = (($174) + 32|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = (($176) + ($178<<3)|0);
   $180 = ($181|0)==($179|0);
   if ($180) {
    label = 44;
   } else {
    $182 = (($181) + 4|0);
    $183 = HEAP32[$182>>2]|0;
    $184 = ($183|0)==(0|0);
    if ($184) {
     label = 44;
    } else {
     $temp$0$i = $183;
    }
   }
  }
  if ((label|0) == 44) {
   $185 = HEAP32[$ownerClip>>2]|0;
   $186 = (__Z31ReadObjectFromPersistentManageri($185)|0);
   $temp$0$i = $186;
  }
  $$0$i = $temp$0$i;
 }
 $187 = (($88) + 64|0);
 HEAP32[$187>>2] = $$0$i;
 $188 = $mode & 65536;
 $189 = ($188|0)!=(0);
 do {
  if ($189) {
   $190 = (($this) + 8|0);
   $191 = ($88|0)==($190|0);
   if ($191) {
    _memset(($exinfo|0),0,136)|0;
    HEAP32[$exinfo>>2] = 136;
    break;
   }
   $192 = HEAP32[$88>>2]|0;
   $193 = ($192|0)==(0|0);
   if (!($193)) {
    $194 = HEAP32[$89>>2]|0;
    $195 = (($192) + 4|0);
    HEAP32[$195>>2] = $194;
    $196 = HEAP32[$88>>2]|0;
    $197 = HEAP32[$89>>2]|0;
    HEAP32[$197>>2] = $196;
    HEAP32[$88>>2] = 0;
    HEAP32[$89>>2] = 0;
   }
   $198 = HEAP32[$190>>2]|0;
   HEAP32[$88>>2] = $198;
   HEAP32[$89>>2] = $190;
   $199 = (($198) + 4|0);
   HEAP32[$199>>2] = $88;
   $200 = HEAP32[$89>>2]|0;
   HEAP32[$200>>2] = $88;
   label = 57;
  } else {
   $201 = (($this) + 16|0);
   $202 = ($88|0)==($201|0);
   if ($202) {
    _memset(($exinfo|0),0,136)|0;
    HEAP32[$exinfo>>2] = 136;
    label = 58;
    break;
   }
   $203 = HEAP32[$88>>2]|0;
   $204 = ($203|0)==(0|0);
   if (!($204)) {
    $205 = HEAP32[$89>>2]|0;
    $206 = (($203) + 4|0);
    HEAP32[$206>>2] = $205;
    $207 = HEAP32[$88>>2]|0;
    $208 = HEAP32[$89>>2]|0;
    HEAP32[$208>>2] = $207;
    HEAP32[$88>>2] = 0;
    HEAP32[$89>>2] = 0;
   }
   $209 = HEAP32[$201>>2]|0;
   HEAP32[$88>>2] = $209;
   HEAP32[$89>>2] = $201;
   $210 = (($209) + 4|0);
   HEAP32[$210>>2] = $88;
   $211 = HEAP32[$89>>2]|0;
   HEAP32[$211>>2] = $88;
   label = 57;
  }
 } while(0);
 if ((label|0) == 57) {
  _memset(($exinfo|0),0,136)|0;
  HEAP32[$exinfo>>2] = 136;
  if (!($189)) {
   label = 58;
  }
 }
 if ((label|0) == 58) {
  $212 = (($exinfo) + 72|0);
  HEAP32[$212>>2] = 8;
 }
 $213 = (($exinfo) + 68|0);
 HEAP32[$213>>2] = $114;
 HEAP8[$resourcePath>>0] = 18;
 $214 = (($resourcePath) + 1|0);
 dest=$214+0|0; src=754040+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $215 = (($resourcePath) + 10|0);
 HEAP8[$215>>0] = 0;
 $216 = HEAP8[$resource>>0]|0;
 $217 = $216 & 1;
 $218 = ($217<<24>>24)==(0);
 if ($218) {
  $221 = (($resource) + 1|0);
  $222 = $221;
 } else {
  $219 = (($resource) + 8|0);
  $220 = HEAP32[$219>>2]|0;
  $222 = $220;
 }
 $223 = (_strlen(($222|0))|0);
 __THREW__ = 0;
 (invoke_iiii(1480,($resourcePath|0),($222|0),($223|0))|0);
 $224 = __THREW__; __THREW__ = 0;
 $225 = $224&1;
 do {
  if ($225) {
   label = 71;
  } else {
   __THREW__ = 0;
   (invoke_iiii(1480,($resourcePath|0),(754056|0),1)|0);
   $226 = __THREW__; __THREW__ = 0;
   $227 = $226&1;
   if ($227) {
    label = 71;
   } else {
    $228 = $139;
    $229 = $228;
    $230 = HEAP32[$229>>2]|0;
    $231 = (($228) + 4)|0;
    $232 = $231;
    $233 = HEAP32[$232>>2]|0;
    __THREW__ = 0;
    invoke_viii(1990,($$byval_copy3|0),($230|0),($233|0));
    $234 = __THREW__; __THREW__ = 0;
    $235 = $234&1;
    if ($235) {
     label = 71;
    } else {
     $236 = HEAP8[$$byval_copy3>>0]|0;
     $237 = $236 & 1;
     $238 = ($237<<24>>24)==(0);
     if ($238) {
      $243 = (($$byval_copy3) + 1|0);
      $244 = $236&255;
      $245 = $244 >>> 1;
      $246 = $243;$247 = $245;
     } else {
      $239 = (($$byval_copy3) + 8|0);
      $240 = HEAP32[$239>>2]|0;
      $241 = (($$byval_copy3) + 4|0);
      $242 = HEAP32[$241>>2]|0;
      $246 = $240;$247 = $242;
     }
     __THREW__ = 0;
     (invoke_iiii(1480,($resourcePath|0),($246|0),($247|0))|0);
     $248 = __THREW__; __THREW__ = 0;
     $249 = $248&1;
     if ($249) {
      $257 = ___cxa_find_matching_catch()|0;
      $258 = tempRet0;
      $259 = HEAP8[$$byval_copy3>>0]|0;
      $260 = $259 & 1;
      $261 = ($260<<24>>24)==(0);
      if ($261) {
       $$0$i17 = $258;$$01$i = $257;
       break;
      }
      $262 = (($$byval_copy3) + 8|0);
      $263 = HEAP32[$262>>2]|0;
      __ZdlPv($263);
      $$0$i17 = $258;$$01$i = $257;
      break;
     }
     $250 = HEAP8[$$byval_copy3>>0]|0;
     $251 = $250 & 1;
     $252 = ($251<<24>>24)==(0);
     if (!($252)) {
      $253 = (($$byval_copy3) + 8|0);
      $254 = HEAP32[$253>>2]|0;
      __ZdlPv($254);
     }
     __THREW__ = 0;
     $269 = (invoke_i(118)|0);
     $270 = __THREW__; __THREW__ = 0;
     $271 = $270&1;
     L107: do {
      if ($271) {
       label = 108;
      } else {
       $272 = (($269) + 92|0);
       $273 = HEAP32[$272>>2]|0;
       $274 = HEAP8[$resourcePath>>0]|0;
       $275 = $274 & 1;
       $276 = ($275<<24>>24)==(0);
       if ($276) {
        $280 = $214;
       } else {
        $277 = (($resourcePath) + 8|0);
        $278 = HEAP32[$277>>2]|0;
        $280 = $278;
       }
       $279 = HEAP32[$136>>2]|0;
       __THREW__ = 0;
       $281 = (invoke_iiiiii(216,($273|0),($280|0),($279|0),($exinfo|0),($123|0))|0);
       $282 = __THREW__; __THREW__ = 0;
       $283 = $282&1;
       if ($283) {
        label = 108;
       } else {
        $284 = ($281|0)==(25);
        if ($284) {
         $285 = HEAP32[$ownerClip>>2]|0;
         $286 = ($285|0)==(0);
         do {
          if ($286) {
           $364 = 0;
          } else {
           HEAP32[$2>>2] = $285;
           $287 = HEAP32[560624>>2]|0;
           $288 = ($287|0)==(0|0);
           do {
            if ($288) {
             label = 91;
            } else {
             $289 = (($287) + 36|0);
             $290 = HEAP32[$289>>2]|0;
             $291 = (($287) + 4|0);
             $292 = HEAP32[$291>>2]|0;
             $293 = ($290|0)==($292|0);
             do {
              if ($293) {
               $294 = (($287) + 28|0);
               $295 = HEAP32[$294>>2]|0;
               $296 = (($287) + 32|0);
               $297 = HEAP32[$296>>2]|0;
               $298 = (($295) + ($297<<3)|0);
               $314 = $298;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$287,$2);
               $299 = HEAP32[$$byval_copy3>>2]|0;
               $300 = ($299|0)==(-1);
               $301 = (($287) + 28|0);
               $302 = HEAP32[$301>>2]|0;
               if ($300) {
                $303 = (($287) + 32|0);
                $304 = HEAP32[$303>>2]|0;
                $305 = (($302) + ($304<<3)|0);
                $314 = $305;
                break;
               } else {
                $306 = (($302) + ($299<<3)|0);
                $314 = $306;
                break;
               }
              }
             } while(0);
             $307 = HEAP32[560624>>2]|0;
             $308 = (($307) + 28|0);
             $309 = HEAP32[$308>>2]|0;
             $310 = (($307) + 32|0);
             $311 = HEAP32[$310>>2]|0;
             $312 = (($309) + ($311<<3)|0);
             $313 = ($314|0)==($312|0);
             if ($313) {
              label = 91;
              break;
             }
             $315 = (($314) + 4|0);
             $316 = HEAP32[$315>>2]|0;
             $317 = ($316|0)==(0|0);
             if ($317) {
              label = 91;
             } else {
              $324 = $307;
             }
            }
           } while(0);
           if ((label|0) == 91) {
            $318 = HEAP32[$ownerClip>>2]|0;
            __THREW__ = 0;
            $319 = (invoke_ii(3215,($318|0))|0);
            $320 = __THREW__; __THREW__ = 0;
            $321 = $320&1;
            if ($321) {
             label = 108;
             break L107;
            }
            $phitmp$i18 = ($319|0)==(0|0);
            if ($phitmp$i18) {
             $364 = 0;
             break;
            }
            $$pre = HEAP32[560624>>2]|0;
            $324 = $$pre;
           }
           $322 = HEAP32[$ownerClip>>2]|0;
           HEAP32[$1>>2] = $322;
           $323 = ($324|0)==(0|0);
           do {
            if ($323) {
             label = 102;
            } else {
             $325 = (($324) + 36|0);
             $326 = HEAP32[$325>>2]|0;
             $327 = (($324) + 4|0);
             $328 = HEAP32[$327>>2]|0;
             $329 = ($326|0)==($328|0);
             do {
              if ($329) {
               $330 = (($324) + 28|0);
               $331 = HEAP32[$330>>2]|0;
               $332 = (($324) + 32|0);
               $333 = HEAP32[$332>>2]|0;
               $334 = (($331) + ($333<<3)|0);
               $350 = $334;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$324,$1);
               $335 = HEAP32[$$byval_copy3>>2]|0;
               $336 = ($335|0)==(-1);
               $337 = (($324) + 28|0);
               $338 = HEAP32[$337>>2]|0;
               if ($336) {
                $339 = (($324) + 32|0);
                $340 = HEAP32[$339>>2]|0;
                $341 = (($338) + ($340<<3)|0);
                $350 = $341;
                break;
               } else {
                $342 = (($338) + ($335<<3)|0);
                $350 = $342;
                break;
               }
              }
             } while(0);
             $343 = HEAP32[560624>>2]|0;
             $344 = (($343) + 28|0);
             $345 = HEAP32[$344>>2]|0;
             $346 = (($343) + 32|0);
             $347 = HEAP32[$346>>2]|0;
             $348 = (($345) + ($347<<3)|0);
             $349 = ($350|0)==($348|0);
             if ($349) {
              label = 102;
              break;
             }
             $351 = (($350) + 4|0);
             $352 = HEAP32[$351>>2]|0;
             $353 = ($352|0)==(0|0);
             if ($353) {
              label = 102;
             } else {
              $temp$0$i24 = $352;
             }
            }
           } while(0);
           if ((label|0) == 102) {
            $354 = HEAP32[$ownerClip>>2]|0;
            __THREW__ = 0;
            $355 = (invoke_ii(3215,($354|0))|0);
            $356 = __THREW__; __THREW__ = 0;
            $357 = $356&1;
            if ($357) {
             label = 108;
             break L107;
            } else {
             $temp$0$i24 = $355;
            }
           }
           $358 = (($temp$0$i24) + 104|0);
           $359 = HEAP32[$358>>2]|0;
           __THREW__ = 0;
           $360 = (invoke_ii(3392,($359|0))|0);
           $361 = __THREW__; __THREW__ = 0;
           $362 = $361&1;
           if ($362) {
            label = 108;
            break L107;
           } else {
            $364 = $360;
           }
          }
         } while(0);
         $363 = (($exinfo) + 72|0);
         HEAP32[$363>>2] = $364;
         __THREW__ = 0;
         $365 = (invoke_i(118)|0);
         $366 = __THREW__; __THREW__ = 0;
         $367 = $366&1;
         if ($367) {
          label = 108;
          break;
         }
         $368 = (($365) + 92|0);
         $369 = HEAP32[$368>>2]|0;
         $370 = HEAP8[$resourcePath>>0]|0;
         $371 = $370 & 1;
         $372 = ($371<<24>>24)==(0);
         if ($372) {
          $376 = $214;
         } else {
          $373 = (($resourcePath) + 8|0);
          $374 = HEAP32[$373>>2]|0;
          $376 = $374;
         }
         $375 = HEAP32[$136>>2]|0;
         __THREW__ = 0;
         $377 = (invoke_iiiiii(216,($369|0),($376|0),($375|0),($exinfo|0),($123|0))|0);
         $378 = __THREW__; __THREW__ = 0;
         $379 = $378&1;
         if ($379) {
          label = 108;
          break;
         } else {
          $result$0 = $377;
         }
        } else {
         $result$0 = $281;
        }
        $382 = ($result$0|0)==(0);
        L151: do {
         if ($382) {
          $422 = ($188|0)==(0);
          L173: do {
           if ($422) {
            $423 = ($88|0)==(0|0);
            if ($423) {
             __THREW__ = 0;
             invoke_vi(3664,(0|0));
             $430 = __THREW__; __THREW__ = 0;
             $431 = $430&1;
             if ($431) {
              label = 108;
              break L107;
             }
             __THREW__ = 0;
             invoke_vi(3664,(0|0));
             $432 = __THREW__; __THREW__ = 0;
             $433 = $432&1;
             if ($433) {
              label = 108;
              break L107;
             } else {
              break;
             }
            }
            $424 = HEAP32[$135>>2]|0;
            do {
             if ((($424|0) == 3)) {
              break L173;
             } else if (!((($424|0) == 4))) {
              __THREW__ = 0;
              invoke_vi(3664,($88|0));
              $425 = __THREW__; __THREW__ = 0;
              $426 = $425&1;
              if ($426) {
               label = 108;
               break L107;
              }
              $427 = HEAP32[$135>>2]|0;
              if ((($427|0) == 4)) {
               break;
              } else if ((($427|0) == 3)) {
               break L173;
              }
              __THREW__ = 0;
              invoke_vi(3664,($88|0));
              $428 = __THREW__; __THREW__ = 0;
              $429 = $428&1;
              if ($429) {
               label = 108;
               break L107;
              }
              $$pre$i = HEAP32[$135>>2]|0;
              $phitmp$i = ($$pre$i|0)==(4);
              if (!($phitmp$i)) {
               break L173;
              }
             }
            } while(0);
            $434 = HEAP32[628304>>2]|0;
            __THREW__ = 0;
            invoke_vi(3663,($88|0));
            $435 = __THREW__; __THREW__ = 0;
            $436 = $435&1;
            if ($436) {
             label = 108;
             break L107;
            }
            HEAP32[$4>>2] = $434;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;
            invoke_vii(2591,($88|0),($$byval_copy3|0));
            $437 = __THREW__; __THREW__ = 0;
            $438 = $437&1;
            if ($438) {
             label = 108;
             break L107;
            }
            HEAP32[$agg$result>>2] = 0;
            $439 = (($agg$result) + 4|0);
            HEAP32[$439>>2] = 0;
            $440 = (($agg$result) + 8|0);
            HEAP32[$440>>2] = $agg$result;
            $441 = (($agg$result) + 12|0);
            HEAP32[$441>>2] = 0;
            break L151;
           }
          } while(0);
          HEAP32[$agg$result>>2] = 0;
          $442 = (($agg$result) + 4|0);
          HEAP32[$442>>2] = 0;
          $443 = (($agg$result) + 8|0);
          HEAP32[$443>>2] = $agg$result;
          $444 = (($agg$result) + 12|0);
          HEAP32[$444>>2] = $88;
          $445 = ($88|0)==(0|0);
          if ($445) {
           break;
          }
          $446 = ($agg$result|0)==($119|0);
          if ($446) {
           break;
          }
          $447 = HEAP32[$119>>2]|0;
          HEAP32[$agg$result>>2] = $447;
          HEAP32[$442>>2] = $119;
          $448 = (($447) + 4|0);
          HEAP32[$448>>2] = $agg$result;
          $449 = HEAP32[$442>>2]|0;
          HEAP32[$449>>2] = $agg$result;
         } else {
          $383 = HEAP8[$resourcePath>>0]|0;
          $384 = $383 & 1;
          $385 = ($384<<24>>24)==(0);
          if ($385) {
           $389 = $214;
          } else {
           $386 = (($resourcePath) + 8|0);
           $387 = HEAP32[$386>>2]|0;
           $389 = $387;
          }
          $388 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($result$0)|0);
          __THREW__ = 0;
          HEAP32[$$byval_copy3>>2] = $389;
          $vararg_ptr1 = (($$byval_copy3) + 4|0);
          HEAP32[$vararg_ptr1>>2] = $388;
          invoke_viii(1617,($6|0),(753840|0),($$byval_copy3|0));
          $390 = __THREW__; __THREW__ = 0;
          $391 = $390&1;
          if ($391) {
           label = 108;
           break L107;
          }
          $392 = HEAP8[$6>>0]|0;
          $393 = $392 & 1;
          $394 = ($393<<24>>24)==(0);
          if ($394) {
           $397 = (($6) + 1|0);
           $398 = $397;
          } else {
           $395 = (($6) + 8|0);
           $396 = HEAP32[$395>>2]|0;
           $398 = $396;
          }
          __THREW__ = 0;
          invoke_viiiiiiii(21,($398|0),0,(753784|0),808,1,0,0,(0|0));
          $399 = __THREW__; __THREW__ = 0;
          $400 = $399&1;
          if ($400) {
           $415 = ___cxa_find_matching_catch()|0;
           $416 = tempRet0;
           $417 = HEAP8[$6>>0]|0;
           $418 = $417 & 1;
           $419 = ($418<<24>>24)==(0);
           if ($419) {
            $$0 = $416;$$01 = $415;
            break L107;
           }
           $420 = (($6) + 8|0);
           $421 = HEAP32[$420>>2]|0;
           __ZdlPv($421);
           $$0 = $416;$$01 = $415;
           break L107;
          }
          $401 = HEAP8[$6>>0]|0;
          $402 = $401 & 1;
          $403 = ($402<<24>>24)==(0);
          if (!($403)) {
           $404 = (($6) + 8|0);
           $405 = HEAP32[$404>>2]|0;
           __ZdlPv($405);
          }
          $406 = HEAP32[628304>>2]|0;
          $407 = ($88|0)==(0|0);
          if (!($407)) {
           __THREW__ = 0;
           invoke_vi(3663,($88|0));
           $408 = __THREW__; __THREW__ = 0;
           $409 = $408&1;
           if ($409) {
            label = 108;
            break L107;
           }
          }
          HEAP32[$0>>2] = $406;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($88|0),($$byval_copy3|0));
          $410 = __THREW__; __THREW__ = 0;
          $411 = $410&1;
          if ($411) {
           label = 108;
           break L107;
          }
          HEAP32[$agg$result>>2] = 0;
          $412 = (($agg$result) + 4|0);
          HEAP32[$412>>2] = 0;
          $413 = (($agg$result) + 8|0);
          HEAP32[$413>>2] = $agg$result;
          $414 = (($agg$result) + 12|0);
          HEAP32[$414>>2] = 0;
         }
        } while(0);
        $450 = HEAP8[$resourcePath>>0]|0;
        $451 = $450 & 1;
        $452 = ($451<<24>>24)==(0);
        if ($452) {
         STACKTOP = sp;return;
        }
        $453 = (($resourcePath) + 8|0);
        $454 = HEAP32[$453>>2]|0;
        __ZdlPv($454);
        STACKTOP = sp;return;
       }
      }
     } while(0);
     if ((label|0) == 108) {
      $380 = ___cxa_find_matching_catch()|0;
      $381 = tempRet0;
      $$0 = $381;$$01 = $380;
     }
     $455 = HEAP8[$resourcePath>>0]|0;
     $456 = $455 & 1;
     $457 = ($456<<24>>24)==(0);
     if ($457) {
      ___resumeException($$01|0);
      // unreachable;
     }
     $458 = (($resourcePath) + 8|0);
     $459 = HEAP32[$458>>2]|0;
     __ZdlPv($459);
     ___resumeException($$01|0);
     // unreachable;
    }
   }
  }
 } while(0);
 if ((label|0) == 71) {
  $255 = ___cxa_find_matching_catch()|0;
  $256 = tempRet0;
  $$0$i17 = $256;$$01$i = $255;
 }
 $264 = HEAP8[$resourcePath>>0]|0;
 $265 = $264 & 1;
 $266 = ($265<<24>>24)==(0);
 if ($266) {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 $267 = (($resourcePath) + 8|0);
 $268 = HEAP32[$267>>2]|0;
 __ZdlPv($268);
 ___resumeException($$01$i|0);
 // unreachable;
}
function __ZN11SoundHandleaSERKS_($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$off$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $switch$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($handle) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $46 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $46;
  STACKTOP = sp;return;
 }
 $5 = ($3|0)==(0|0);
 if ($5) {
  $17 = HEAP32[$this>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = (($this) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($17) + 4|0);
   HEAP32[$21>>2] = $20;
   $22 = HEAP32[$this>>2]|0;
   $23 = HEAP32[$19>>2]|0;
   HEAP32[$23>>2] = $22;
   HEAP32[$this>>2] = 0;
   HEAP32[$19>>2] = 0;
  }
 } else {
  $6 = (($3) + 28|0);
  $7 = ($this|0)==($6|0);
  if (!($7)) {
   $8 = HEAP32[$this>>2]|0;
   $9 = ($8|0)==(0|0);
   $$pre$i$i = (($this) + 4|0);
   if (!($9)) {
    $10 = HEAP32[$$pre$i$i>>2]|0;
    $11 = (($8) + 4|0);
    HEAP32[$11>>2] = $10;
    $12 = HEAP32[$this>>2]|0;
    $13 = HEAP32[$$pre$i$i>>2]|0;
    HEAP32[$13>>2] = $12;
    HEAP32[$this>>2] = 0;
    HEAP32[$$pre$i$i>>2] = 0;
   }
   $14 = HEAP32[$6>>2]|0;
   HEAP32[$this>>2] = $14;
   HEAP32[$$pre$i$i>>2] = $6;
   $15 = (($14) + 4|0);
   HEAP32[$15>>2] = $this;
   $16 = HEAP32[$$pre$i$i>>2]|0;
   HEAP32[$16>>2] = $this;
  }
 }
 $24 = HEAP32[$0>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $46 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $46;
  STACKTOP = sp;return;
 }
 $26 = (($24) + 32|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($24) + 28|0);
 $29 = ($27|0)==($28|0);
 if (!($29)) {
  $46 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $46;
  STACKTOP = sp;return;
 }
 $30 = (($24) + 52|0);
 $31 = HEAP32[$30>>2]|0;
 $$off$i = (($31) + -3)|0;
 $switch$i = ($$off$i>>>0)<(2);
 if (!($switch$i)) {
  $46 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $46;
  STACKTOP = sp;return;
 }
 $32 = (__Z15GetAudioManagerv()|0);
 $33 = (__ZN12AudioManager15GetSoundManagerEv($32)|0);
 $34 = (($33) + 24|0);
 $35 = ($24|0)==($34|0);
 if (!($35)) {
  $36 = HEAP32[$24>>2]|0;
  $37 = ($36|0)==(0|0);
  $$pre$i$i$i$i = (($24) + 4|0);
  if (!($37)) {
   $38 = HEAP32[$$pre$i$i$i$i>>2]|0;
   $39 = (($36) + 4|0);
   HEAP32[$39>>2] = $38;
   $40 = HEAP32[$24>>2]|0;
   $41 = HEAP32[$$pre$i$i$i$i>>2]|0;
   HEAP32[$41>>2] = $40;
   HEAP32[$24>>2] = 0;
   HEAP32[$$pre$i$i$i$i>>2] = 0;
  }
  $42 = HEAP32[$34>>2]|0;
  HEAP32[$24>>2] = $42;
  HEAP32[$$pre$i$i$i$i>>2] = $34;
  $43 = (($42) + 4|0);
  HEAP32[$43>>2] = $24;
  $44 = HEAP32[$$pre$i$i$i$i>>2]|0;
  HEAP32[$44>>2] = $24;
 }
 $45 = (($24) + 116|0);
 HEAP8[$45>>0] = 1;
 $46 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $46;
 STACKTOP = sp;return;
}
function __ZN12SoundChannel6CreateE11SoundHandleb($agg$result,$sound,$paused) {
 $agg$result = $agg$result|0;
 $sound = $sound|0;
 $paused = $paused|0;
 var $$015 = 0, $$023 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = HEAP32[628304>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(288,$$byval_copy1,0,16,753784,306)|0);
 HEAP32[$1>>2] = 0;
 $4 = (($1) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($1) + 8|0);
 HEAP32[$5>>2] = $1;
 $6 = (($sound) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($1) + 12|0);
 HEAP32[$8>>2] = $7;
 $9 = ($7|0)==(0|0);
 if (!($9)) {
  $10 = (($7) + 28|0);
  $11 = ($1|0)==($10|0);
  if (!($11)) {
   $12 = HEAP32[$10>>2]|0;
   HEAP32[$1>>2] = $12;
   HEAP32[$4>>2] = $10;
   $13 = (($12) + 4|0);
   HEAP32[$13>>2] = $1;
   $14 = HEAP32[$4>>2]|0;
   HEAP32[$14>>2] = $1;
  }
 }
 __THREW__ = 0;
 invoke_viii(1987,($3|0),($1|0),($paused|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3642,($1|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $36 = ___cxa_find_matching_catch(0|0)|0;
   $37 = tempRet0;
   ___clang_call_terminate($36);
   // unreachable;
  }
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy1|0),0,16,(753784|0),306);
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $36 = ___cxa_find_matching_catch(0|0)|0;
   $37 = tempRet0;
   ___clang_call_terminate($36);
   // unreachable;
  } else {
   $$015 = $29;$$023 = $28;
   ___resumeException($$023|0);
   // unreachable;
  }
 }
 HEAP32[$agg$result>>2] = 0;
 $17 = (($agg$result) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($agg$result) + 8|0);
 HEAP32[$18>>2] = $agg$result;
 $19 = (($agg$result) + 12|0);
 HEAP32[$19>>2] = $3;
 $20 = ($3|0)==(0|0);
 if (!($20)) {
  $21 = (($3) + 208|0);
  $22 = ($agg$result|0)==($21|0);
  if (!($22)) {
   $23 = HEAP32[$21>>2]|0;
   HEAP32[$agg$result>>2] = $23;
   HEAP32[$17>>2] = $21;
   $24 = (($23) + 4|0);
   HEAP32[$24>>2] = $agg$result;
   $25 = HEAP32[$17>>2]|0;
   HEAP32[$25>>2] = $agg$result;
  }
 }
 __THREW__ = 0;
 invoke_vi(3642,($1|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if (!($27)) {
  STACKTOP = sp;return;
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 $$015 = $33;$$023 = $32;
 ___resumeException($$023|0);
 // unreachable;
}
function __ZL16FMOD_ErrorString11FMOD_RESULT17059($errcode) {
 $errcode = $errcode|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($errcode|0) {
  case 15:  {
   $$0 = 755024;
   break;
  }
  case 85:  {
   $$0 = 755840;
   break;
  }
  case 88:  {
   $$0 = 756184;
   break;
  }
  case 90:  {
   $$0 = 756232;
   break;
  }
  case 89:  {
   $$0 = 756320;
   break;
  }
  case 21:  {
   $$0 = 756544;
   break;
  }
  case 22:  {
   $$0 = 756584;
   break;
  }
  case 11:  {
   $$0 = 754608;
   break;
  }
  case 23:  {
   $$0 = 756680;
   break;
  }
  case 9:  {
   $$0 = 754536;
   break;
  }
  case 13:  {
   $$0 = 754824;
   break;
  }
  case 24:  {
   $$0 = 756704;
   break;
  }
  case 19:  {
   $$0 = 756408;
   break;
  }
  case 20:  {
   $$0 = 756432;
   break;
  }
  case 86:  {
   $$0 = 755912;
   break;
  }
  case 25:  {
   $$0 = 756736;
   break;
  }
  case 8:  {
   $$0 = 754488;
   break;
  }
  case 3:  {
   $$0 = 754264;
   break;
  }
  case 26:  {
   $$0 = 756776;
   break;
  }
  case 27:  {
   $$0 = 756864;
   break;
  }
  case 28:  {
   $$0 = 756936;
   break;
  }
  case 29:  {
   $$0 = 757008;
   break;
  }
  case 12:  {
   $$0 = 754672;
   break;
  }
  case 87:  {
   $$0 = 756016;
   break;
  }
  case 30:  {
   $$0 = 757040;
   break;
  }
  case 83:  {
   $$0 = 755624;
   break;
  }
  case 31:  {
   $$0 = 757072;
   break;
  }
  case 4:  {
   $$0 = 754312;
   break;
  }
  case 32:  {
   $$0 = 757136;
   break;
  }
  case 33:  {
   $$0 = 757184;
   break;
  }
  case 16:  {
   $$0 = 755128;
   break;
  }
  case 34:  {
   $$0 = 757248;
   break;
  }
  case 2:  {
   $$0 = 754128;
   break;
  }
  case 5:  {
   $$0 = 754376;
   break;
  }
  case 7:  {
   $$0 = 754456;
   break;
  }
  case 10:  {
   $$0 = 754568;
   break;
  }
  case 14:  {
   $$0 = 754880;
   break;
  }
  case 6:  {
   $$0 = 754416;
   break;
  }
  case 17:  {
   $$0 = 755192;
   break;
  }
  case 92:  {
   $$0 = 755488;
   break;
  }
  case 18:  {
   $$0 = 755384;
   break;
  }
  case 91:  {
   $$0 = 755736;
   break;
  }
  case 84:  {
   $$0 = 755784;
   break;
  }
  case 38:  {
   $$0 = 757504;
   break;
  }
  case 93:  {
   $$0 = 758176;
   break;
  }
  case 61:  {
   $$0 = 759648;
   break;
  }
  case 69:  {
   $$0 = 760320;
   break;
  }
  case 40:  {
   $$0 = 757648;
   break;
  }
  case 49:  {
   $$0 = 758544;
   break;
  }
  case 52:  {
   $$0 = 758880;
   break;
  }
  case 56:  {
   $$0 = 759208;
   break;
  }
  case 59:  {
   $$0 = 759504;
   break;
  }
  case 35:  {
   $$0 = 757352;
   break;
  }
  case 39:  {
   $$0 = 757560;
   break;
  }
  case 50:  {
   $$0 = 758736;
   break;
  }
  case 53:  {
   $$0 = 758928;
   break;
  }
  case 66:  {
   $$0 = 760040;
   break;
  }
  case 67:  {
   $$0 = 760104;
   break;
  }
  case 70:  {
   $$0 = 760432;
   break;
  }
  case 71:  {
   $$0 = 760496;
   break;
  }
  case 64:  {
   $$0 = 759904;
   break;
  }
  case 72:  {
   $$0 = 760928;
   break;
  }
  case 47:  {
   $$0 = 758336;
   break;
  }
  case 79:  {
   $$0 = 761632;
   break;
  }
  case 60:  {
   $$0 = 759608;
   break;
  }
  case 45:  {
   $$0 = 758008;
   break;
  }
  case 43:  {
   $$0 = 757840;
   break;
  }
  case 62:  {
   $$0 = 759752;
   break;
  }
  case 65:  {
   $$0 = 759976;
   break;
  }
  case 95:  {
   $$0 = 758064;
   break;
  }
  case 73:  {
   $$0 = 761080;
   break;
  }
  case 76:  {
   $$0 = 761336;
   break;
  }
  case 94:  {
   $$0 = 758128;
   break;
  }
  case 41:  {
   $$0 = 757704;
   break;
  }
  case 63:  {
   $$0 = 759848;
   break;
  }
  case 75:  {
   $$0 = 760640;
   break;
  }
  case 77:  {
   $$0 = 761400;
   break;
  }
  case 78:  {
   $$0 = 761552;
   break;
  }
  case 80:  {
   $$0 = 761712;
   break;
  }
  case 51:  {
   $$0 = 758784;
   break;
  }
  case 57:  {
   $$0 = 759248;
   break;
  }
  case 81:  {
   $$0 = 761824;
   break;
  }
  case 36:  {
   $$0 = 757408;
   break;
  }
  case 44:  {
   $$0 = 757880;
   break;
  }
  case 54:  {
   $$0 = 759000;
   break;
  }
  case 46:  {
   $$0 = 758256;
   break;
  }
  case 55:  {
   $$0 = 759088;
   break;
  }
  case 37:  {
   $$0 = 757448;
   break;
  }
  case 48:  {
   $$0 = 758416;
   break;
  }
  case 58:  {
   $$0 = 759384;
   break;
  }
  case 74:  {
   $$0 = 761200;
   break;
  }
  case 42:  {
   $$0 = 757768;
   break;
  }
  case 68:  {
   $$0 = 760200;
   break;
  }
  case 0:  {
   $$0 = 761936;
   break;
  }
  case 1:  {
   $$0 = 754064;
   break;
  }
  case 82:  {
   $$0 = 761872;
   break;
  }
  default: {
   $$0 = 761952;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN11SoundHandleC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $this;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11SoundHandleC2ERKS_($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $this;
 $2 = (($handle) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = $3;
 $5 = ($3|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($3) + 28|0);
 $7 = ($this|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$6>>2]|0;
 HEAP32[$this>>2] = $8;
 HEAP32[$0>>2] = $6;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $this;
 $10 = HEAP32[$0>>2]|0;
 HEAP32[$10>>2] = $this;
 STACKTOP = sp;return;
}
function __ZN11SoundHandleD2Ev($this) {
 $this = $this|0;
 var $$off$i = 0, $$pre = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $switch$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $11 = $1;
  } else {
   $5 = (($this) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($3) + 4|0);
   HEAP32[$7>>2] = $6;
   $8 = HEAP32[$this>>2]|0;
   $9 = HEAP32[$5>>2]|0;
   HEAP32[$9>>2] = $8;
   HEAP32[$this>>2] = 0;
   HEAP32[$5>>2] = 0;
   $$pre = HEAP32[$0>>2]|0;
   $11 = $$pre;
  }
  $10 = (($11) + 32|0);
  $12 = HEAP32[$10>>2]|0;
  $13 = (($11) + 28|0);
  $14 = ($12|0)==($13|0);
  if ($14) {
   $15 = (($11) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   $$off$i = (($16) + -3)|0;
   $switch$i = ($$off$i>>>0)<(2);
   if ($switch$i) {
    $17 = (__Z15GetAudioManagerv()|0);
    $18 = (__ZN12AudioManager15GetSoundManagerEv($17)|0);
    $19 = (($18) + 24|0);
    $20 = ($11|0)==($19|0);
    if (!($20)) {
     $21 = HEAP32[$11>>2]|0;
     $22 = ($21|0)==(0|0);
     $$pre$i$i$i$i = (($11) + 4|0);
     if (!($22)) {
      $23 = HEAP32[$$pre$i$i$i$i>>2]|0;
      $24 = (($21) + 4|0);
      HEAP32[$24>>2] = $23;
      $25 = HEAP32[$11>>2]|0;
      $26 = HEAP32[$$pre$i$i$i$i>>2]|0;
      HEAP32[$26>>2] = $25;
      HEAP32[$11>>2] = 0;
      HEAP32[$$pre$i$i$i$i>>2] = 0;
     }
     $27 = HEAP32[$19>>2]|0;
     HEAP32[$11>>2] = $27;
     HEAP32[$$pre$i$i$i$i>>2] = $19;
     $28 = (($27) + 4|0);
     HEAP32[$28>>2] = $11;
     $29 = HEAP32[$$pre$i$i$i$i>>2]|0;
     HEAP32[$29>>2] = $11;
    }
    $30 = (($11) + 116|0);
    HEAP8[$30>>0] = 1;
   }
  }
 }
 $31 = HEAP32[$this>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($31) + 4|0);
 HEAP32[$35>>2] = $34;
 $36 = HEAP32[$this>>2]|0;
 $37 = HEAP32[$33>>2]|0;
 HEAP32[$37>>2] = $36;
 HEAP32[$this>>2] = 0;
 HEAP32[$33>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11SoundHandle7ReleaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = 0;
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 8|0);
 HEAP32[$2>>2] = $0;
 $3 = (($0) + 12|0);
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3336,($this|0),($0|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __ZN11SoundHandleD2Ev($0);
  STACKTOP = sp;return;
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3642,($0|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
}
function __ZN11SoundHandle13CreateChannelEb($agg$result,$this,$paused) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $paused = $paused|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$agg$result>>2] = 0;
  $3 = (($agg$result) + 4|0);
  HEAP32[$3>>2] = 0;
  $4 = (($agg$result) + 8|0);
  HEAP32[$4>>2] = $agg$result;
  $5 = (($agg$result) + 12|0);
  HEAP32[$5>>2] = 0;
  STACKTOP = sp;return;
 }
 $6 = (($1) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(4);
 if ($8) {
  HEAP32[$agg$result>>2] = 0;
  $9 = (($agg$result) + 4|0);
  HEAP32[$9>>2] = 0;
  $10 = (($agg$result) + 8|0);
  HEAP32[$10>>2] = $agg$result;
  $11 = (($agg$result) + 12|0);
  HEAP32[$11>>2] = 0;
  STACKTOP = sp;return;
 } else {
  __ZN11SoundHandle8Instance13CreateChannelERS_b($agg$result,$1,$this,$paused);
  STACKTOP = sp;return;
 }
}
function __ZN12SoundManagerC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$this>>2] = $this;
 HEAP32[$0>>2] = $this;
 $1 = (($this) + 8|0);
 $2 = (($this) + 12|0);
 HEAP32[$1>>2] = $1;
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 16|0);
 $4 = (($this) + 20|0);
 HEAP32[$3>>2] = $3;
 HEAP32[$4>>2] = $3;
 $5 = (($this) + 24|0);
 $6 = (($this) + 28|0);
 HEAP32[$5>>2] = $5;
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 32|0);
 $8 = (($this) + 48|0);
 $9 = (($this) + 52|0);
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
 HEAP32[$8>>2] = $8;
 HEAP32[$9>>2] = $8;
 __THREW__ = 0;
 $10 = (invoke_i(78)|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  HEAP32[$9>>2] = 0;
  HEAP32[$8>>2] = 0;
  ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
  ___resumeException($18|0);
  // unreachable;
 } else {
  $i$01$i = 0;
 }
 while(1) {
  $15 = ((($10) + ($i$01$i<<2)|0) + 832|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  $14 = (($i$01$i) + 1)|0;
  if ($17) {
   break;
  }
  $13 = ($14|0)<(16);
  if ($13) {
   $i$01$i = $14;
  } else {
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return;
 }
 HEAP32[$15>>2] = 221;
 STACKTOP = sp;return;
}
function __ZN12SoundManager20OnExitPlayModeStaticEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $watchdog$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $watchdog$i = sp;
 $0 = (__Z15GetAudioManagerv()|0);
 $1 = (__ZN12AudioManager15GetSoundManagerEv($0)|0);
 $2 = (+__Z19GetTimeSinceStartupv());
 HEAPF64[$watchdog$i>>3] = $2;
 $3 = (($1) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 48|0);
 $6 = ($4|0)==($5|0);
 if ($6) {
  STACKTOP = sp;return;
 } else {
  $8 = $4;
 }
 while(1) {
  __ZN20SoundManagerWatchDog6UpdateEPKci($watchdog$i,753488,1122);
  $7 = (($8) + 4|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = (($8) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 100|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $15 = (($11) + 124|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    label = 5;
   } else {
    (__ZN10SampleClip15UnloadAudioDataEv($11)|0);
   }
  } else {
   label = 5;
  }
  if ((label|0) == 5) {
   label = 0;
   __ZN9AudioClip6ReloadEv($11);
  }
  $18 = ($9|0)==($5|0);
  if ($18) {
   break;
  } else {
   $8 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12SoundManagerD2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$phi24Z2D = 0, $$pre$phi26Z2D = 0, $$pre$phiZ2D = 0, $$pre23$pre = 0, $$pre23$pre$phiZZ2D = 0, $$pre25$pre$phiZZ2D = 0, $$pre25$pre$pre = 0, $$pre25$pre$pre$phiZZZ2D = 0, $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $lpad$phi$index = 0, $lpad$phi$index12 = 0, $lpad$phi17$index = 0, $lpad$phi17$index7 = 0, $lpad$phi19$index = 0, $lpad$phi19$index2 = 0, $node$01$i = 0, $node$01$i5 = 0, $watchdog = 0, $watchdog$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $watchdog$i = sp + 8|0;
 $watchdog = sp;
 __THREW__ = 0;
 $0 = (+invoke_d(1));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 32;
  } else {
   HEAPF64[$watchdog>>3] = $0;
   __THREW__ = 0;
   $3 = (invoke_i(78)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    label = 32;
   } else {
    $6 = (($3) + 832|0);
    __ZN17CallbackArrayBaseIPFvvEE10UnregisterES1_($6,221);
    $7 = (($this) + 12|0);
    $8 = (($this) + 8|0);
    while(1) {
     $9 = HEAP32[$7>>2]|0;
     $10 = ($9|0)==($8|0);
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(1988,($watchdog|0),(753488|0),731);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 31;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3665,($this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 31;
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_i(118)|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 31;
      break;
     }
     $18 = (($15) + 92|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     (invoke_ii(3393,($19|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      label = 31;
      break;
     }
    }
    if ((label|0) == 31) {
     $83 = ___cxa_find_matching_catch()|0;
     $84 = tempRet0;
     $$pre25$pre$pre$phiZZZ2D = $7;$lpad$phi19$index = $83;$lpad$phi19$index2 = $84;
     label = 33;
     break;
    }
    $22 = (($this) + 20|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($this) + 16|0);
    $25 = ($23|0)==($24|0);
    L13: do {
     if (!($25)) {
      $26 = (($this) + 24|0);
      $30 = $23;
      while(1) {
       __THREW__ = 0;
       invoke_viii(1988,($watchdog|0),(753488|0),740);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       $29 = (($30) + 4|0);
       $31 = HEAP32[$29>>2]|0;
       $32 = (($30) + 8|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = ($33|0)==($26|0);
       if (!($34)) {
        $35 = HEAP32[$33>>2]|0;
        $36 = ($35|0)==(0|0);
        $$pre$i$i$i = (($33) + 4|0);
        if (!($36)) {
         $37 = HEAP32[$$pre$i$i$i>>2]|0;
         $38 = (($35) + 4|0);
         HEAP32[$38>>2] = $37;
         $39 = HEAP32[$33>>2]|0;
         $40 = HEAP32[$$pre$i$i$i>>2]|0;
         HEAP32[$40>>2] = $39;
         HEAP32[$33>>2] = 0;
         HEAP32[$$pre$i$i$i>>2] = 0;
        }
        $41 = HEAP32[$26>>2]|0;
        HEAP32[$33>>2] = $41;
        HEAP32[$$pre$i$i$i>>2] = $26;
        $42 = (($41) + 4|0);
        HEAP32[$42>>2] = $33;
        $43 = HEAP32[$$pre$i$i$i>>2]|0;
        HEAP32[$43>>2] = $33;
       }
       $44 = (($33) + 116|0);
       HEAP8[$44>>0] = 1;
       $45 = ($31|0)==($24|0);
       if ($45) {
        break L13;
       } else {
        $30 = $31;
       }
      }
      $81 = ___cxa_find_matching_catch()|0;
      $82 = tempRet0;
      $$pre23$pre$phiZZ2D = $22;$$pre25$pre$phiZZ2D = $7;$lpad$phi17$index = $81;$lpad$phi17$index7 = $82;
      break L1;
     }
    } while(0);
    __THREW__ = 0;
    $46 = (+invoke_d(1));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 32;
    } else {
     HEAPF64[$watchdog$i>>3] = $46;
     $49 = (($this) + 28|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (($this) + 24|0);
     $52 = ($50|0)==($51|0);
     L27: do {
      if (!($52)) {
       while(1) {
        __THREW__ = 0;
        invoke_viii(1988,($watchdog$i|0),(753488|0),1055);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3665,($this|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
        __THREW__ = 0;
        $57 = (invoke_i(118)|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
        $60 = (($57) + 92|0);
        $61 = HEAP32[$60>>2]|0;
        __THREW__ = 0;
        (invoke_ii(3393,($61|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[$49>>2]|0;
        $65 = ($64|0)==($51|0);
        if ($65) {
         break L27;
        }
       }
       $79 = ___cxa_find_matching_catch()|0;
       $80 = tempRet0;
       $$pre$phi24Z2D = $22;$$pre$phi26Z2D = $7;$$pre$phiZ2D = $49;$lpad$phi$index = $79;$lpad$phi$index12 = $80;
       $87 = (($this) + 52|0);
       HEAP32[$87>>2] = 0;
       $88 = (($this) + 48|0);
       HEAP32[$88>>2] = 0;
       HEAP32[$$pre$phiZ2D>>2] = 0;
       $89 = (($this) + 24|0);
       HEAP32[$89>>2] = 0;
       HEAP32[$$pre$phi24Z2D>>2] = 0;
       $90 = (($this) + 16|0);
       HEAP32[$90>>2] = 0;
       HEAP32[$$pre$phi26Z2D>>2] = 0;
       $91 = (($this) + 8|0);
       HEAP32[$91>>2] = 0;
       $92 = (($this) + 4|0);
       HEAP32[$92>>2] = 0;
       HEAP32[$this>>2] = 0;
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     } while(0);
     $66 = (($this) + 4|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($67|0)==($this|0);
     if (!($68)) {
      $node$01$i5 = $67;
      while(1) {
       $69 = (($node$01$i5) + 4|0);
       $70 = HEAP32[$69>>2]|0;
       HEAP32[$node$01$i5>>2] = 0;
       HEAP32[$69>>2] = 0;
       $71 = ($70|0)==($this|0);
       if ($71) {
        break;
       } else {
        $node$01$i5 = $70;
       }
      }
     }
     HEAP32[$66>>2] = $this;
     HEAP32[$this>>2] = $this;
     $72 = (($this) + 48|0);
     $73 = (($this) + 52|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==($72|0);
     if ($75) {
      HEAP32[$73>>2] = 0;
      HEAP32[$72>>2] = 0;
      ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
      STACKTOP = sp;return;
     } else {
      $node$01$i = $74;
     }
     while(1) {
      $76 = (($node$01$i) + 4|0);
      $77 = HEAP32[$76>>2]|0;
      HEAP32[$node$01$i>>2] = 0;
      HEAP32[$76>>2] = 0;
      $78 = ($77|0)==($72|0);
      if ($78) {
       break;
      } else {
       $node$01$i = $77;
      }
     }
     HEAP32[$73>>2] = 0;
     HEAP32[$72>>2] = 0;
     ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;HEAP32[$this+28>>2]=0|0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 32) {
  $85 = ___cxa_find_matching_catch()|0;
  $86 = tempRet0;
  $$pre25$pre$pre = (($this) + 12|0);
  $$pre25$pre$pre$phiZZZ2D = $$pre25$pre$pre;$lpad$phi19$index = $85;$lpad$phi19$index2 = $86;
  label = 33;
 }
 if ((label|0) == 33) {
  $$pre23$pre = (($this) + 20|0);
  $$pre23$pre$phiZZ2D = $$pre23$pre;$$pre25$pre$phiZZ2D = $$pre25$pre$pre$phiZZZ2D;$lpad$phi17$index = $lpad$phi19$index;$lpad$phi17$index7 = $lpad$phi19$index2;
 }
 $$pre = (($this) + 28|0);
 $$pre$phi24Z2D = $$pre23$pre$phiZZ2D;$$pre$phi26Z2D = $$pre25$pre$phiZZ2D;$$pre$phiZ2D = $$pre;$lpad$phi$index = $lpad$phi17$index;$lpad$phi$index12 = $lpad$phi17$index7;
 $87 = (($this) + 52|0);
 HEAP32[$87>>2] = 0;
 $88 = (($this) + 48|0);
 HEAP32[$88>>2] = 0;
 HEAP32[$$pre$phiZ2D>>2] = 0;
 $89 = (($this) + 24|0);
 HEAP32[$89>>2] = 0;
 HEAP32[$$pre$phi24Z2D>>2] = 0;
 $90 = (($this) + 16|0);
 HEAP32[$90>>2] = 0;
 HEAP32[$$pre$phi26Z2D>>2] = 0;
 $91 = (($this) + 8|0);
 HEAP32[$91>>2] = 0;
 $92 = (($this) + 4|0);
 HEAP32[$92>>2] = 0;
 HEAP32[$this>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN12SoundManager6UpdateEv($this) {
 $this = $this|0;
 var $$ = 0, $$byval_copy = 0, $$off = 0, $$ph65 = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i27 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0.0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fmodchannel = 0, $node$0$i = 0, $node$01$i = 0, $node$01$i3 = 0, $node$03$i = 0, $numDisposedSoundInstances$0$lcssa = 0;
 var $numDisposedSoundInstances$0$ph66 = 0, $numDisposedSoundInstances$052 = 0, $numPendingSoundInstances$0$lcssa = 0, $numPendingSoundInstances$057 = 0, $numPendingUnloads$0$ph62 = 0, $numPendingUnloads$0$ph67 = 0, $or$cond = 0, $size$0$lcssa$i = 0, $size$02$i = 0, $switch = 0, $temp$0$i = 0, $temp$0$i25 = 0, $watchdog = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 8|0;
 $0 = sp + 44|0;
 $1 = sp + 40|0;
 $2 = sp + 36|0;
 $3 = sp + 48|0;
 $4 = sp + 16|0;
 $watchdog = sp;
 $fmodchannel = sp + 20|0;
 $5 = sp + 24|0;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($this|0);
 if (!($8)) {
  $10 = $7;
  while(1) {
   $9 = (($10) + 4|0);
   $11 = HEAP32[$9>>2]|0;
   $12 = (($10) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   __ZN20SoundChannelInstance6UpdateEv($13);
   $14 = ($11|0)==($this|0);
   if ($14) {
    break;
   } else {
    $10 = $11;
   }
  }
 }
 $15 = (+__Z19GetTimeSinceStartupv());
 HEAPF64[$watchdog>>3] = $15;
 $16 = (($this) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 8|0);
 $19 = ($17|0)==($18|0);
 L5: do {
  if ($19) {
   $numPendingSoundInstances$0$lcssa = 0;
  } else {
   $20 = (($this) + 16|0);
   $21 = (($5) + 1|0);
   $22 = (($5) + 8|0);
   $25 = $17;$numPendingSoundInstances$057 = 0;
   L7: while(1) {
    __ZN20SoundManagerWatchDog6UpdateEPKci($watchdog,753488,902);
    $23 = (($numPendingSoundInstances$057) + 1)|0;
    $24 = (($25) + 4|0);
    $26 = HEAP32[$24>>2]|0;
    $27 = (($25) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 112|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + 1)|0;
    HEAP32[$29>>2] = $31;
    __ZN11SoundHandle8Instance15UpdateLoadStateEv($28);
    $32 = ($28|0)==(0|0);
    do {
     if (!($32)) {
      $33 = (($28) + 52|0);
      $34 = HEAP32[$33>>2]|0;
      if ((($34|0) == 4)) {
       $260 = (__Z15GetAudioManagerv()|0);
       $261 = (__ZN12AudioManager15GetSoundManagerEv($260)|0);
       $262 = (($261) + 24|0);
       $263 = ($28|0)==($262|0);
       if (!($263)) {
        $264 = HEAP32[$28>>2]|0;
        $265 = ($264|0)==(0|0);
        $$pre$i$i$i = (($28) + 4|0);
        if (!($265)) {
         $266 = HEAP32[$$pre$i$i$i>>2]|0;
         $267 = (($264) + 4|0);
         HEAP32[$267>>2] = $266;
         $268 = HEAP32[$28>>2]|0;
         $269 = HEAP32[$$pre$i$i$i>>2]|0;
         HEAP32[$269>>2] = $268;
         HEAP32[$28>>2] = 0;
         HEAP32[$$pre$i$i$i>>2] = 0;
        }
        $270 = HEAP32[$262>>2]|0;
        HEAP32[$28>>2] = $270;
        HEAP32[$$pre$i$i$i>>2] = $262;
        $271 = (($270) + 4|0);
        HEAP32[$271>>2] = $28;
        $272 = HEAP32[$$pre$i$i$i>>2]|0;
        HEAP32[$272>>2] = $28;
       }
       $273 = (($28) + 116|0);
       HEAP8[$273>>0] = 1;
       break;
      } else if (!((($34|0) == 3))) {
       break;
      }
      $35 = (($28) + 100|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($28) + 96|0);
      $38 = ($36|0)==($37|0);
      if ($38) {
       $$pre$phiZ2D = $28;
      } else {
       $39 = (($28) + 48|0);
       $40 = (($28) + 60|0);
       $41 = (($28) + 116|0);
       $$pre$i$i$i27 = (($28) + 4|0);
       $43 = $36;
       while(1) {
        __ZN20SoundManagerWatchDog6UpdateEPKci($watchdog,753488,912);
        $42 = (($43) + 4|0);
        $44 = HEAP32[$42>>2]|0;
        HEAP32[$fmodchannel>>2] = 0;
        $45 = (($43) + 8|0);
        $46 = HEAP32[$45>>2]|0;
        $47 = (($46) + 279|0);
        $48 = HEAP8[$47>>0]|0;
        $49 = ($48<<24>>24)==(0);
        $50 = (__Z15GetAudioManagerv()|0);
        do {
         if ($49) {
          $63 = (($50) + 92|0);
          $64 = HEAP32[$63>>2]|0;
          $65 = HEAP32[$39>>2]|0;
          $66 = (__ZN4FMOD6System9playSoundE17FMOD_CHANNELINDEXPNS_5SoundEbPPNS_7ChannelE($64,-1,$65,1,$fmodchannel)|0);
          $67 = ($66|0)!=(0);
          $68 = HEAP32[$fmodchannel>>2]|0;
          $69 = ($68|0)==(0|0);
          $or$cond = $67 | $69;
          if (!($or$cond)) {
           $238 = HEAP32[$45>>2]|0;
           __ZN20SoundChannelInstance14SetFMODChannelEPN4FMOD7ChannelE($238,$68);
           $239 = HEAP32[$45>>2]|0;
           __ZN20SoundChannelInstance23ApplyBufferedParametersEv($239);
           $240 = HEAP32[$45>>2]|0;
           __ZN20SoundChannelInstance12UpdateVolumeEv($240);
           $241 = HEAP32[$45>>2]|0;
           __ZN20SoundChannelInstance16UpdatePauseStateEv($241);
           break;
          }
          $70 = ($66|0)==(10);
          if ($70) {
           $71 = HEAP32[$40>>2]|0;
           $72 = ($71|0)==(0);
           do {
            if ($72) {
             $143 = 0;
            } else {
             HEAP32[$0>>2] = $71;
             $73 = HEAP32[560624>>2]|0;
             $74 = ($73|0)==(0|0);
             if ($74) {
              label = 27;
             } else {
              $75 = (($73) + 36|0);
              $76 = HEAP32[$75>>2]|0;
              $77 = (($73) + 4|0);
              $78 = HEAP32[$77>>2]|0;
              $79 = ($76|0)==($78|0);
              do {
               if ($79) {
                $80 = (($73) + 28|0);
                $81 = HEAP32[$80>>2]|0;
                $82 = (($73) + 32|0);
                $83 = HEAP32[$82>>2]|0;
                $84 = (($81) + ($83<<3)|0);
                $100 = $84;
               } else {
                __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$73,$0);
                $85 = HEAP32[$$byval_copy>>2]|0;
                $86 = ($85|0)==(-1);
                $87 = (($73) + 28|0);
                $88 = HEAP32[$87>>2]|0;
                if ($86) {
                 $89 = (($73) + 32|0);
                 $90 = HEAP32[$89>>2]|0;
                 $91 = (($88) + ($90<<3)|0);
                 $100 = $91;
                 break;
                } else {
                 $92 = (($88) + ($85<<3)|0);
                 $100 = $92;
                 break;
                }
               }
              } while(0);
              $93 = HEAP32[560624>>2]|0;
              $94 = (($93) + 28|0);
              $95 = HEAP32[$94>>2]|0;
              $96 = (($93) + 32|0);
              $97 = HEAP32[$96>>2]|0;
              $98 = (($95) + ($97<<3)|0);
              $99 = ($100|0)==($98|0);
              if ($99) {
               label = 27;
              } else {
               $101 = (($100) + 4|0);
               $102 = HEAP32[$101>>2]|0;
               $103 = ($102|0)==(0|0);
               if ($103) {
                label = 27;
               }
              }
             }
             if ((label|0) == 27) {
              label = 0;
              $104 = HEAP32[$40>>2]|0;
              $105 = (__Z31ReadObjectFromPersistentManageri($104)|0);
              $106 = ($105|0)==(0|0);
              if ($106) {
               $143 = 0;
               break;
              }
             }
             $107 = HEAP32[$40>>2]|0;
             HEAP32[$1>>2] = $107;
             $108 = HEAP32[560624>>2]|0;
             $109 = ($108|0)==(0|0);
             do {
              if ($109) {
               label = 36;
              } else {
               $110 = (($108) + 36|0);
               $111 = HEAP32[$110>>2]|0;
               $112 = (($108) + 4|0);
               $113 = HEAP32[$112>>2]|0;
               $114 = ($111|0)==($113|0);
               do {
                if ($114) {
                 $115 = (($108) + 28|0);
                 $116 = HEAP32[$115>>2]|0;
                 $117 = (($108) + 32|0);
                 $118 = HEAP32[$117>>2]|0;
                 $119 = (($116) + ($118<<3)|0);
                 $135 = $119;
                } else {
                 __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$108,$1);
                 $120 = HEAP32[$$byval_copy>>2]|0;
                 $121 = ($120|0)==(-1);
                 $122 = (($108) + 28|0);
                 $123 = HEAP32[$122>>2]|0;
                 if ($121) {
                  $124 = (($108) + 32|0);
                  $125 = HEAP32[$124>>2]|0;
                  $126 = (($123) + ($125<<3)|0);
                  $135 = $126;
                  break;
                 } else {
                  $127 = (($123) + ($120<<3)|0);
                  $135 = $127;
                  break;
                 }
                }
               } while(0);
               $128 = HEAP32[560624>>2]|0;
               $129 = (($128) + 28|0);
               $130 = HEAP32[$129>>2]|0;
               $131 = (($128) + 32|0);
               $132 = HEAP32[$131>>2]|0;
               $133 = (($130) + ($132<<3)|0);
               $134 = ($135|0)==($133|0);
               if ($134) {
                label = 36;
                break;
               }
               $136 = (($135) + 4|0);
               $137 = HEAP32[$136>>2]|0;
               $138 = ($137|0)==(0|0);
               if ($138) {
                label = 36;
               } else {
                $temp$0$i25 = $137;
               }
              }
             } while(0);
             if ((label|0) == 36) {
              label = 0;
              $139 = HEAP32[$40>>2]|0;
              $140 = (__Z31ReadObjectFromPersistentManageri($139)|0);
              $temp$0$i25 = $140;
             }
             $141 = (($temp$0$i25) + 4|0);
             $142 = HEAP32[$141>>2]|0;
             $143 = $142;
            }
           } while(0);
           __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(753728,0,753784,925,512,$143,0,0);
           break;
          }
          $144 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($66)|0);
          HEAP32[$$byval_copy>>2] = $144;
          __Z6FormatPKcz($5,753792,$$byval_copy);
          $145 = HEAP32[$40>>2]|0;
          $146 = ($145|0)==(0);
          do {
           if ($146) {
            $225 = 0;
           } else {
            HEAP32[$2>>2] = $145;
            $147 = HEAP32[560624>>2]|0;
            $148 = ($147|0)==(0|0);
            if ($148) {
             label = 48;
            } else {
             $149 = (($147) + 36|0);
             $150 = HEAP32[$149>>2]|0;
             $151 = (($147) + 4|0);
             $152 = HEAP32[$151>>2]|0;
             $153 = ($150|0)==($152|0);
             do {
              if ($153) {
               $154 = (($147) + 28|0);
               $155 = HEAP32[$154>>2]|0;
               $156 = (($147) + 32|0);
               $157 = HEAP32[$156>>2]|0;
               $158 = (($155) + ($157<<3)|0);
               $174 = $158;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$147,$2);
               $159 = HEAP32[$$byval_copy>>2]|0;
               $160 = ($159|0)==(-1);
               $161 = (($147) + 28|0);
               $162 = HEAP32[$161>>2]|0;
               if ($160) {
                $163 = (($147) + 32|0);
                $164 = HEAP32[$163>>2]|0;
                $165 = (($162) + ($164<<3)|0);
                $174 = $165;
                break;
               } else {
                $166 = (($162) + ($159<<3)|0);
                $174 = $166;
                break;
               }
              }
             } while(0);
             $167 = HEAP32[560624>>2]|0;
             $168 = (($167) + 28|0);
             $169 = HEAP32[$168>>2]|0;
             $170 = (($167) + 32|0);
             $171 = HEAP32[$170>>2]|0;
             $172 = (($169) + ($171<<3)|0);
             $173 = ($174|0)==($172|0);
             if ($173) {
              label = 48;
             } else {
              $175 = (($174) + 4|0);
              $176 = HEAP32[$175>>2]|0;
              $177 = ($176|0)==(0|0);
              if ($177) {
               label = 48;
              }
             }
            }
            if ((label|0) == 48) {
             label = 0;
             $178 = HEAP32[$40>>2]|0;
             __THREW__ = 0;
             $179 = (invoke_ii(3215,($178|0))|0);
             $180 = __THREW__; __THREW__ = 0;
             $181 = $180&1;
             if ($181) {
              break L7;
             }
             $182 = ($179|0)==(0|0);
             if ($182) {
              $225 = 0;
              break;
             }
            }
            $183 = HEAP32[$40>>2]|0;
            HEAP32[$3>>2] = $183;
            $184 = HEAP32[560624>>2]|0;
            $185 = ($184|0)==(0|0);
            if ($185) {
             label = 58;
            } else {
             $186 = (($184) + 36|0);
             $187 = HEAP32[$186>>2]|0;
             $188 = (($184) + 4|0);
             $189 = HEAP32[$188>>2]|0;
             $190 = ($187|0)==($189|0);
             do {
              if ($190) {
               $191 = (($184) + 28|0);
               $192 = HEAP32[$191>>2]|0;
               $193 = (($184) + 32|0);
               $194 = HEAP32[$193>>2]|0;
               $195 = (($192) + ($194<<3)|0);
               $211 = $195;
              } else {
               __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$184,$3);
               $196 = HEAP32[$$byval_copy>>2]|0;
               $197 = ($196|0)==(-1);
               $198 = (($184) + 28|0);
               $199 = HEAP32[$198>>2]|0;
               if ($197) {
                $200 = (($184) + 32|0);
                $201 = HEAP32[$200>>2]|0;
                $202 = (($199) + ($201<<3)|0);
                $211 = $202;
                break;
               } else {
                $203 = (($199) + ($196<<3)|0);
                $211 = $203;
                break;
               }
              }
             } while(0);
             $204 = HEAP32[560624>>2]|0;
             $205 = (($204) + 28|0);
             $206 = HEAP32[$205>>2]|0;
             $207 = (($204) + 32|0);
             $208 = HEAP32[$207>>2]|0;
             $209 = (($206) + ($208<<3)|0);
             $210 = ($211|0)==($209|0);
             if ($210) {
              label = 58;
             } else {
              $212 = (($211) + 4|0);
              $213 = HEAP32[$212>>2]|0;
              $214 = ($213|0)==(0|0);
              if ($214) {
               label = 58;
              } else {
               $temp$0$i = $213;
              }
             }
            }
            if ((label|0) == 58) {
             label = 0;
             $215 = HEAP32[$40>>2]|0;
             __THREW__ = 0;
             $216 = (invoke_ii(3215,($215|0))|0);
             $217 = __THREW__; __THREW__ = 0;
             $218 = $217&1;
             if ($218) {
              break L7;
             } else {
              $temp$0$i = $216;
             }
            }
            $219 = (($temp$0$i) + 4|0);
            $220 = HEAP32[$219>>2]|0;
            $225 = $220;
           }
          } while(0);
          $221 = HEAP8[$5>>0]|0;
          $222 = $221 & 1;
          $223 = ($222<<24>>24)==(0);
          $224 = HEAP32[$22>>2]|0;
          $$ = $223 ? $21 : $224;
          __THREW__ = 0;
          invoke_viiiiiiii(21,($$|0),0,(753784|0),927,1,($225|0),0,(0|0));
          $226 = __THREW__; __THREW__ = 0;
          $227 = $226&1;
          if ($227) {
           break L7;
          }
          $228 = HEAP8[$5>>0]|0;
          $229 = $228 & 1;
          $230 = ($229<<24>>24)==(0);
          if (!($230)) {
           $231 = HEAP32[$22>>2]|0;
           __ZdlPv($231);
          }
         } else {
          $51 = (__ZN12AudioManager15GetSoundManagerEv($50)|0);
          $52 = (($51) + 24|0);
          $53 = ($28|0)==($52|0);
          if (!($53)) {
           $54 = HEAP32[$28>>2]|0;
           $55 = ($54|0)==(0|0);
           if (!($55)) {
            $56 = HEAP32[$$pre$i$i$i27>>2]|0;
            $57 = (($54) + 4|0);
            HEAP32[$57>>2] = $56;
            $58 = HEAP32[$28>>2]|0;
            $59 = HEAP32[$$pre$i$i$i27>>2]|0;
            HEAP32[$59>>2] = $58;
            HEAP32[$28>>2] = 0;
            HEAP32[$$pre$i$i$i27>>2] = 0;
           }
           $60 = HEAP32[$52>>2]|0;
           HEAP32[$28>>2] = $60;
           HEAP32[$$pre$i$i$i27>>2] = $52;
           $61 = (($60) + 4|0);
           HEAP32[$61>>2] = $28;
           $62 = HEAP32[$$pre$i$i$i27>>2]|0;
           HEAP32[$62>>2] = $28;
          }
          HEAP8[$41>>0] = 1;
         }
        } while(0);
        $242 = HEAP32[$43>>2]|0;
        $243 = ($242|0)==(0|0);
        if (!($243)) {
         $245 = HEAP32[$42>>2]|0;
         $246 = (($242) + 4|0);
         HEAP32[$246>>2] = $245;
         $247 = HEAP32[$43>>2]|0;
         $248 = HEAP32[$42>>2]|0;
         HEAP32[$248>>2] = $247;
         HEAP32[$43>>2] = 0;
         HEAP32[$42>>2] = 0;
        }
        $244 = ($44|0)==($37|0);
        if ($244) {
         $$pre$phiZ2D = $28;
         break;
        } else {
         $43 = $44;
        }
       }
      }
      $249 = ($$pre$phiZ2D|0)==($20|0);
      if (!($249)) {
       $250 = HEAP32[$28>>2]|0;
       $251 = ($250|0)==(0|0);
       $$pre$i$i = (($28) + 4|0);
       if (!($251)) {
        $252 = HEAP32[$$pre$i$i>>2]|0;
        $253 = (($250) + 4|0);
        HEAP32[$253>>2] = $252;
        $254 = HEAP32[$28>>2]|0;
        $255 = HEAP32[$$pre$i$i>>2]|0;
        HEAP32[$255>>2] = $254;
        HEAP32[$28>>2] = 0;
        HEAP32[$$pre$i$i>>2] = 0;
       }
       $256 = HEAP32[$20>>2]|0;
       HEAP32[$28>>2] = $256;
       HEAP32[$$pre$i$i>>2] = $20;
       $257 = (($256) + 4|0);
       HEAP32[$257>>2] = $$pre$phiZ2D;
       $258 = HEAP32[$$pre$i$i>>2]|0;
       HEAP32[$258>>2] = $$pre$phiZ2D;
      }
     }
    } while(0);
    $259 = ($26|0)==($18|0);
    if ($259) {
     $numPendingSoundInstances$0$lcssa = $23;
     break L5;
    } else {
     $25 = $26;$numPendingSoundInstances$057 = $23;
    }
   }
   $232 = ___cxa_find_matching_catch()|0;
   $233 = tempRet0;
   $234 = HEAP8[$5>>0]|0;
   $235 = $234 & 1;
   $236 = ($235<<24>>24)==(0);
   if ($236) {
    ___resumeException($232|0);
    // unreachable;
   }
   $237 = HEAP32[$22>>2]|0;
   __ZdlPv($237);
   ___resumeException($232|0);
   // unreachable;
  }
 } while(0);
 $274 = (($this) + 24|0);
 $275 = (($this) + 28|0);
 $276 = HEAP32[$275>>2]|0;
 $277 = ($276|0)==($274|0);
 L117: do {
  if ($277) {
   $numDisposedSoundInstances$0$lcssa = 0;$numPendingUnloads$0$ph62 = 0;
  } else {
   $$ph65 = $276;$numDisposedSoundInstances$0$ph66 = 0;$numPendingUnloads$0$ph67 = 0;
   while(1) {
    $280 = $$ph65;$numDisposedSoundInstances$052 = $numDisposedSoundInstances$0$ph66;
    while(1) {
     __ZN20SoundManagerWatchDog6UpdateEPKci($watchdog,753488,953);
     $278 = (($numDisposedSoundInstances$052) + 1)|0;
     $279 = (($280) + 4|0);
     $281 = HEAP32[$279>>2]|0;
     $282 = (($280) + 8|0);
     $283 = HEAP32[$282>>2]|0;
     $284 = ($283|0)==(0|0);
     if ($284) {
      break;
     }
     $285 = (($283) + 52|0);
     $286 = HEAP32[$285>>2]|0;
     $$off = (($286) + -3)|0;
     $switch = ($$off>>>0)<(2);
     if (!($switch)) {
      break;
     }
     $287 = HEAP32[628304>>2]|0;
     __ZN11SoundHandle8InstanceD2Ev($283);
     HEAP32[$4>>2] = $287;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($283,$$byval_copy);
     $288 = ($281|0)==($274|0);
     if ($288) {
      $numDisposedSoundInstances$0$lcssa = $278;$numPendingUnloads$0$ph62 = $numPendingUnloads$0$ph67;
      break L117;
     } else {
      $280 = $281;$numDisposedSoundInstances$052 = $278;
     }
    }
    $289 = (($numPendingUnloads$0$ph67) + 1)|0;
    $290 = ($281|0)==($274|0);
    if ($290) {
     $numDisposedSoundInstances$0$lcssa = $278;$numPendingUnloads$0$ph62 = $289;
     break;
    } else {
     $$ph65 = $281;$numDisposedSoundInstances$0$ph66 = $278;$numPendingUnloads$0$ph67 = $289;
    }
   }
  }
 } while(0);
 $291 = (($this) + 16|0);
 $292 = (($this) + 20|0);
 $node$01$i3 = HEAP32[$292>>2]|0;
 $293 = ($node$01$i3|0)==($291|0);
 if ($293) {
  $size$0$lcssa$i = 0;
 } else {
  $node$03$i = $node$01$i3;$size$02$i = 0;
  while(1) {
   $294 = (($node$03$i) + 4|0);
   $295 = (($size$02$i) + 1)|0;
   $node$0$i = HEAP32[$294>>2]|0;
   $296 = ($node$0$i|0)==($291|0);
   if ($296) {
    $size$0$lcssa$i = $295;
    break;
   } else {
    $node$03$i = $node$0$i;$size$02$i = $295;
   }
  }
 }
 $297 = (($this) + 36|0);
 HEAP32[$297>>2] = $size$0$lcssa$i;
 $298 = (($this) + 32|0);
 HEAP32[$298>>2] = $numPendingSoundInstances$0$lcssa;
 $299 = (($this) + 40|0);
 HEAP32[$299>>2] = $numDisposedSoundInstances$0$lcssa;
 $300 = (($this) + 44|0);
 HEAP32[$300>>2] = $numPendingUnloads$0$ph62;
 $301 = HEAP32[$275>>2]|0;
 $302 = ($301|0)==($274|0);
 if ($302) {
  HEAP32[$275>>2] = $274;
  HEAP32[$274>>2] = $274;
  STACKTOP = sp;return;
 } else {
  $node$01$i = $301;
 }
 while(1) {
  $303 = (($node$01$i) + 4|0);
  $304 = HEAP32[$303>>2]|0;
  HEAP32[$node$01$i>>2] = 0;
  HEAP32[$303>>2] = 0;
  $305 = ($304|0)==($274|0);
  if ($305) {
   break;
  } else {
   $node$01$i = $304;
  }
 }
 HEAP32[$275>>2] = $274;
 HEAP32[$274>>2] = $274;
 STACKTOP = sp;return;
}
function __ZN12SoundManager22GetHandleFromFMODSoundEPN4FMOD5SoundEj4PPtrI10SampleClipE($agg$result,$this,$sound,$flags,$ownerClip) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $sound = $sound|0;
 $flags = $flags|0;
 $ownerClip = $ownerClip|0;
 var $$0$i = 0, $$02$i$i$i$i$i$i$i$i = 0, $$byval_copy = 0, $$masked$i$i$i$i$i$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i$i = 0, $i$03$i$i$i$i$i$i$i$i = 0, $p$01$i$i$i$i$i$i$i = 0, $reflection$01$i$i$i$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i$i$i$i = 0, $temp$0$i = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0;
 var $watchdog = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 8|0;
 $0 = sp + 40|0;
 $1 = sp + 24|0;
 $watchdog = sp;
 $2 = sp + 36|0;
 $3 = ($sound|0)==(0|0);
 if ($3) {
  HEAP32[$agg$result>>2] = 0;
  $4 = (($agg$result) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($agg$result) + 8|0);
  HEAP32[$5>>2] = $agg$result;
  $6 = (($agg$result) + 12|0);
  HEAP32[$6>>2] = 0;
  STACKTOP = sp;return;
 }
 $7 = (+__Z19GetTimeSinceStartupv());
 HEAPF64[$watchdog>>3] = $7;
 $8 = (($this) + 16|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($8|0);
 L5: do {
  if (!($11)) {
   $13 = $10;
   while(1) {
    __ZN20SoundManagerWatchDog6UpdateEPKci($watchdog,753488,830);
    $12 = (($13) + 8|0);
    $14 = HEAP32[$12>>2]|0;
    $15 = (($14) + 52|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(3);
    if ($17) {
     $18 = (($14) + 48|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)==($sound|0);
     if ($20) {
      break;
     }
    }
    $30 = (($13) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==($8|0);
    if ($32) {
     break L5;
    } else {
     $13 = $31;
    }
   }
   HEAP32[$agg$result>>2] = 0;
   $21 = (($agg$result) + 4|0);
   HEAP32[$21>>2] = 0;
   $22 = (($agg$result) + 8|0);
   HEAP32[$22>>2] = $agg$result;
   $23 = (($agg$result) + 12|0);
   HEAP32[$23>>2] = $14;
   $24 = ($14|0)==(0|0);
   if ($24) {
    STACKTOP = sp;return;
   }
   $25 = (($14) + 28|0);
   $26 = ($agg$result|0)==($25|0);
   if ($26) {
    STACKTOP = sp;return;
   }
   $27 = HEAP32[$25>>2]|0;
   HEAP32[$agg$result>>2] = $27;
   HEAP32[$21>>2] = $25;
   $28 = (($27) + 4|0);
   HEAP32[$28>>2] = $agg$result;
   $29 = HEAP32[$21>>2]|0;
   HEAP32[$29>>2] = $agg$result;
   STACKTOP = sp;return;
  }
 } while(0);
 $33 = HEAP32[628304>>2]|0;
 HEAP32[$2>>2] = $33;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
 $34 = (__Znwj10MemLabelIdbiPKci(120,$$byval_copy,0,16,753784,836)|0);
 HEAP32[$34>>2] = 0;
 $35 = (($34) + 4|0);
 HEAP32[$35>>2] = 0;
 $36 = (($34) + 8|0);
 HEAP32[$36>>2] = $34;
 $37 = HEAP8[693120>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  $$02$i$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i$i = 0;
  while(1) {
   $39 = $$02$i$i$i$i$i$i$i$i & 1;
   $40 = ($39|0)==(0);
   if ($40) {
    $reflection$1$i$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i$i;
   } else {
    $41 = (31 - ($i$03$i$i$i$i$i$i$i$i))|0;
    $42 = 1 << $41;
    $43 = $42 | $reflection$01$i$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i$i = $43;
   }
   $44 = (($i$03$i$i$i$i$i$i$i$i) + 1)|0;
   $45 = $$02$i$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i$i = ($44|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i$i) {
    $49 = $reflection$1$i$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i$i = 753944;
    break;
   } else {
    $$02$i$i$i$i$i$i$i$i = $45;$i$03$i$i$i$i$i$i$i$i = $44;$reflection$01$i$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $46 = HEAP8[$p$01$i$i$i$i$i$i$i>>0]|0;
   $47 = $46&255;
   $48 = $49 >>> 8;
   $$masked$i$i$i$i$i$i$i = $49 & 255;
   $50 = $47 ^ $$masked$i$i$i$i$i$i$i;
   $51 = (584048 + ($50<<2)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = $52 ^ $48;
   $54 = (($p$01$i$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i$i = ($54|0)==(((753944 + 88|0))|0);
   if ($exitcond$i$i$i$i$i$i$i) {
    break;
   } else {
    $49 = $53;$p$01$i$i$i$i$i$i$i = $54;
   }
  }
  $55 = $53 ^ -1;
  HEAP32[693112>>2] = $55;
  $56 = 693120;
  $57 = $56;
  HEAP32[$57>>2] = 1;
  $58 = (($56) + 4)|0;
  $59 = $58;
  HEAP32[$59>>2] = 0;
  $61 = $55;
 } else {
  $$pre$i$i$i$i = HEAP32[693112>>2]|0;
  $61 = $$pre$i$i$i$i;
 }
 $60 = (($34) + 12|0);
 HEAP32[$60>>2] = $61;
 $62 = (($34) + 16|0);
 HEAP32[$62>>2] = $34;
 $63 = (($34) + 20|0);
 HEAP32[$63>>2] = 753944;
 $64 = (($34) + 24|0);
 HEAP32[$64>>2] = -1;
 $65 = (($34) + 28|0);
 $66 = (($34) + 32|0);
 HEAP32[$65>>2] = $65;
 HEAP32[$66>>2] = $65;
 $67 = (($34) + 36|0);
 $68 = (($34) + 40|0);
 HEAP32[$67>>2] = $67;
 HEAP32[$68>>2] = $67;
 $69 = (($34) + 44|0);
 $70 = (($34) + 88|0);
 $71 = $70;
 $72 = $71;
 HEAP32[$72>>2] = 0;
 $73 = (($71) + 4)|0;
 $74 = $73;
 HEAP32[$74>>2] = 0;
 $75 = (($34) + 96|0);
 $76 = (($34) + 100|0);
 dest=$69+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$75>>2] = $75;
 HEAP32[$76>>2] = $75;
 $77 = (($34) + 104|0);
 HEAP32[$77>>2] = $34;
 $78 = (($34) + 108|0);
 HEAP32[$78>>2] = $34;
 $79 = (($34) + 112|0);
 HEAP32[$79>>2] = 0;
 $80 = (($34) + 116|0);
 HEAP8[$80>>0] = 0;
 $81 = (($34) + 48|0);
 HEAP32[$81>>2] = $sound;
 $82 = (($34) + 52|0);
 HEAP32[$82>>2] = 3;
 $83 = (($34) + 68|0);
 HEAP32[$83>>2] = $flags;
 $84 = (($34) + 60|0);
 $85 = HEAP32[$ownerClip>>2]|0;
 HEAP32[$84>>2] = $85;
 $86 = HEAP32[$ownerClip>>2]|0;
 $87 = ($86|0)==(0);
 if ($87) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $86;
  $88 = HEAP32[560624>>2]|0;
  $89 = ($88|0)==(0|0);
  if ($89) {
   label = 26;
  } else {
   $90 = (($88) + 36|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = (($88) + 4|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($91|0)==($93|0);
   do {
    if ($94) {
     $95 = (($88) + 28|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($88) + 32|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($96) + ($98<<3)|0);
     $115 = $99;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$88,$0);
     $100 = HEAP32[$$byval_copy>>2]|0;
     $101 = ($100|0)==(-1);
     $102 = (($88) + 28|0);
     $103 = HEAP32[$102>>2]|0;
     if ($101) {
      $104 = (($88) + 32|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = (($103) + ($105<<3)|0);
      $115 = $106;
      break;
     } else {
      $107 = (($103) + ($100<<3)|0);
      $115 = $107;
      break;
     }
    }
   } while(0);
   $108 = HEAP32[560624>>2]|0;
   $109 = (($108) + 28|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = (($108) + 32|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = (($110) + ($112<<3)|0);
   $114 = ($115|0)==($113|0);
   if ($114) {
    label = 26;
   } else {
    $116 = (($115) + 4|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = ($117|0)==(0|0);
    if ($118) {
     label = 26;
    } else {
     $temp$0$i = $117;
    }
   }
  }
  if ((label|0) == 26) {
   $119 = HEAP32[$ownerClip>>2]|0;
   $120 = (__Z31ReadObjectFromPersistentManageri($119)|0);
   $temp$0$i = $120;
  }
  $$0$i = $temp$0$i;
 }
 $121 = (($34) + 64|0);
 HEAP32[$121>>2] = $$0$i;
 $122 = (($34) + 56|0);
 $123 = (__ZN4FMOD5Sound7getModeEPj($sound,$122)|0);
 $124 = ($123|0)==(0);
 do {
  if (!($124)) {
   $125 = (__ZL16FMOD_ErrorString11FMOD_RESULT17059($123)|0);
   HEAP32[$$byval_copy>>2] = 753488;
   $vararg_ptr1 = (($$byval_copy) + 4|0);
   HEAP32[$vararg_ptr1>>2] = 842;
   $vararg_ptr2 = (($$byval_copy) + 8|0);
   HEAP32[$vararg_ptr2>>2] = 753904;
   $vararg_ptr3 = (($$byval_copy) + 12|0);
   HEAP32[$vararg_ptr3>>2] = $125;
   __Z6FormatPKcz($1,761968,$$byval_copy);
   $126 = HEAP8[$1>>0]|0;
   $127 = $126 & 1;
   $128 = ($127<<24>>24)==(0);
   if ($128) {
    $131 = (($1) + 1|0);
    $132 = $131;
   } else {
    $129 = (($1) + 8|0);
    $130 = HEAP32[$129>>2]|0;
    $132 = $130;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($132|0),0,(753784|0),21,1,0,0,(0|0));
   $133 = __THREW__; __THREW__ = 0;
   $134 = $133&1;
   if (!($134)) {
    $135 = HEAP8[$1>>0]|0;
    $136 = $135 & 1;
    $137 = ($136<<24>>24)==(0);
    if ($137) {
     break;
    }
    $138 = (($1) + 8|0);
    $139 = HEAP32[$138>>2]|0;
    __ZdlPv($139);
    break;
   }
   $140 = ___cxa_find_matching_catch()|0;
   $141 = tempRet0;
   $142 = HEAP8[$1>>0]|0;
   $143 = $142 & 1;
   $144 = ($143<<24>>24)==(0);
   if ($144) {
    ___resumeException($140|0);
    // unreachable;
   }
   $145 = (($1) + 8|0);
   $146 = HEAP32[$145>>2]|0;
   __ZdlPv($146);
   ___resumeException($140|0);
   // unreachable;
  }
 } while(0);
 $147 = ($34|0)==($8|0);
 if (!($147)) {
  $148 = HEAP32[$34>>2]|0;
  $149 = ($148|0)==(0|0);
  if (!($149)) {
   $150 = HEAP32[$35>>2]|0;
   $151 = (($148) + 4|0);
   HEAP32[$151>>2] = $150;
   $152 = HEAP32[$34>>2]|0;
   $153 = HEAP32[$35>>2]|0;
   HEAP32[$153>>2] = $152;
   HEAP32[$34>>2] = 0;
   HEAP32[$35>>2] = 0;
  }
  $154 = HEAP32[$8>>2]|0;
  HEAP32[$34>>2] = $154;
  HEAP32[$35>>2] = $8;
  $155 = (($154) + 4|0);
  HEAP32[$155>>2] = $34;
  $156 = HEAP32[$35>>2]|0;
  HEAP32[$156>>2] = $34;
 }
 HEAP32[$agg$result>>2] = 0;
 $157 = (($agg$result) + 4|0);
 HEAP32[$157>>2] = 0;
 $158 = (($agg$result) + 8|0);
 HEAP32[$158>>2] = $agg$result;
 $159 = (($agg$result) + 12|0);
 HEAP32[$159>>2] = $34;
 $160 = ($34|0)==(0|0);
 if ($160) {
  STACKTOP = sp;return;
 }
 $161 = ($agg$result|0)==($65|0);
 if ($161) {
  STACKTOP = sp;return;
 }
 $162 = HEAP32[$65>>2]|0;
 HEAP32[$agg$result>>2] = $162;
 HEAP32[$157>>2] = $65;
 $163 = (($162) + 4|0);
 HEAP32[$163>>2] = $agg$result;
 $164 = HEAP32[$157>>2]|0;
 HEAP32[$164>>2] = $agg$result;
 STACKTOP = sp;return;
}
function __ZN12SoundManager11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOR11SoundHandlej4PPtrI10SampleClipE($this,$name_or_data,$mode,$exinfo,$handle,$flags,$ownerClip) {
 $this = $this|0;
 $name_or_data = $name_or_data|0;
 $mode = $mode|0;
 $exinfo = $exinfo|0;
 $handle = $handle|0;
 $flags = $flags|0;
 $ownerClip = $ownerClip|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$02 = 0, $$02$i$i$i$i$i$i$i$i = 0, $$byval_copy1 = 0, $$masked$i$i$i$i$i$i$i = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i$i$i$i$i = 0, $exitcond$i$i$i$i$i$i$i$i = 0, $i$03$i$i$i$i$i$i$i$i = 0, $p$01$i$i$i$i$i$i$i = 0, $phitmp$i = 0, $reflection$01$i$i$i$i$i$i$i$i = 0;
 var $reflection$1$i$i$i$i$i$i$i$i = 0, $temp$0$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 64|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 16|0;
 $4 = sp + 32|0;
 $5 = sp + 48|0;
 $6 = HEAP32[628304>>2]|0;
 HEAP32[$2>>2] = $6;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 $7 = (__Znwj10MemLabelIdbiPKci(120,$$byval_copy1,0,16,753784,849)|0);
 HEAP32[$7>>2] = 0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($7) + 8|0);
 HEAP32[$9>>2] = $7;
 $10 = HEAP8[693120>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $$02$i$i$i$i$i$i$i$i = -1;$i$03$i$i$i$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i$i$i$i = 0;
  while(1) {
   $12 = $$02$i$i$i$i$i$i$i$i & 1;
   $13 = ($12|0)==(0);
   if ($13) {
    $reflection$1$i$i$i$i$i$i$i$i = $reflection$01$i$i$i$i$i$i$i$i;
   } else {
    $14 = (31 - ($i$03$i$i$i$i$i$i$i$i))|0;
    $15 = 1 << $14;
    $16 = $15 | $reflection$01$i$i$i$i$i$i$i$i;
    $reflection$1$i$i$i$i$i$i$i$i = $16;
   }
   $17 = (($i$03$i$i$i$i$i$i$i$i) + 1)|0;
   $18 = $$02$i$i$i$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i$i$i$i = ($17|0)==(32);
   if ($exitcond$i$i$i$i$i$i$i$i) {
    $22 = $reflection$1$i$i$i$i$i$i$i$i;$p$01$i$i$i$i$i$i$i = 753944;
    break;
   } else {
    $$02$i$i$i$i$i$i$i$i = $18;$i$03$i$i$i$i$i$i$i$i = $17;$reflection$01$i$i$i$i$i$i$i$i = $reflection$1$i$i$i$i$i$i$i$i;
   }
  }
  while(1) {
   $19 = HEAP8[$p$01$i$i$i$i$i$i$i>>0]|0;
   $20 = $19&255;
   $21 = $22 >>> 8;
   $$masked$i$i$i$i$i$i$i = $22 & 255;
   $23 = $20 ^ $$masked$i$i$i$i$i$i$i;
   $24 = (584048 + ($23<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 ^ $21;
   $27 = (($p$01$i$i$i$i$i$i$i) + 1|0);
   $exitcond$i$i$i$i$i$i$i = ($27|0)==(((753944 + 88|0))|0);
   if ($exitcond$i$i$i$i$i$i$i) {
    break;
   } else {
    $22 = $26;$p$01$i$i$i$i$i$i$i = $27;
   }
  }
  $28 = $26 ^ -1;
  HEAP32[693112>>2] = $28;
  $29 = 693120;
  $30 = $29;
  HEAP32[$30>>2] = 1;
  $31 = (($29) + 4)|0;
  $32 = $31;
  HEAP32[$32>>2] = 0;
  $34 = $28;
 } else {
  $$pre$i$i$i$i = HEAP32[693112>>2]|0;
  $34 = $$pre$i$i$i$i;
 }
 $33 = (($7) + 12|0);
 HEAP32[$33>>2] = $34;
 $35 = (($7) + 16|0);
 HEAP32[$35>>2] = $7;
 $36 = (($7) + 20|0);
 HEAP32[$36>>2] = 753944;
 $37 = (($7) + 24|0);
 HEAP32[$37>>2] = -1;
 $38 = (($7) + 28|0);
 $39 = (($7) + 32|0);
 HEAP32[$38>>2] = $38;
 HEAP32[$39>>2] = $38;
 $40 = (($7) + 36|0);
 $41 = (($7) + 40|0);
 HEAP32[$40>>2] = $40;
 HEAP32[$41>>2] = $40;
 $42 = (($7) + 44|0);
 $43 = (($7) + 88|0);
 $44 = $43;
 $45 = $44;
 HEAP32[$45>>2] = 0;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = 0;
 $48 = (($7) + 96|0);
 $49 = (($7) + 100|0);
 dest=$42+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$48>>2] = $48;
 HEAP32[$49>>2] = $48;
 $50 = (($7) + 104|0);
 HEAP32[$50>>2] = $7;
 $51 = (($7) + 108|0);
 HEAP32[$51>>2] = $7;
 $52 = (($7) + 112|0);
 HEAP32[$52>>2] = 0;
 $53 = (($7) + 116|0);
 HEAP8[$53>>0] = 0;
 $54 = (($7) + 52|0);
 HEAP32[$54>>2] = 3;
 $55 = (($7) + 68|0);
 HEAP32[$55>>2] = $flags;
 $56 = (($7) + 60|0);
 $57 = HEAP32[$ownerClip>>2]|0;
 HEAP32[$56>>2] = $57;
 $58 = HEAP32[$ownerClip>>2]|0;
 $59 = ($58|0)==(0);
 if ($59) {
  $$0$i = 0;
 } else {
  HEAP32[$1>>2] = $58;
  $60 = HEAP32[560624>>2]|0;
  $61 = ($60|0)==(0|0);
  if ($61) {
   label = 17;
  } else {
   $62 = (($60) + 36|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($60) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($63|0)==($65|0);
   do {
    if ($66) {
     $67 = (($60) + 28|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($60) + 32|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($68) + ($70<<3)|0);
     $87 = $71;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$60,$1);
     $72 = HEAP32[$$byval_copy1>>2]|0;
     $73 = ($72|0)==(-1);
     $74 = (($60) + 28|0);
     $75 = HEAP32[$74>>2]|0;
     if ($73) {
      $76 = (($60) + 32|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($75) + ($77<<3)|0);
      $87 = $78;
      break;
     } else {
      $79 = (($75) + ($72<<3)|0);
      $87 = $79;
      break;
     }
    }
   } while(0);
   $80 = HEAP32[560624>>2]|0;
   $81 = (($80) + 28|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($80) + 32|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($82) + ($84<<3)|0);
   $86 = ($87|0)==($85|0);
   if ($86) {
    label = 17;
   } else {
    $88 = (($87) + 4|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = ($89|0)==(0|0);
    if ($90) {
     label = 17;
    } else {
     $temp$0$i = $89;
    }
   }
  }
  if ((label|0) == 17) {
   $91 = HEAP32[$ownerClip>>2]|0;
   $92 = (__Z31ReadObjectFromPersistentManageri($91)|0);
   $temp$0$i = $92;
  }
  $$0$i = $temp$0$i;
 }
 $93 = (($7) + 64|0);
 HEAP32[$93>>2] = $$0$i;
 $94 = (($7) + 56|0);
 HEAP32[$94>>2] = $mode;
 $95 = $mode & 65536;
 $96 = ($95|0)==(0);
 if ($96) {
  $108 = (($this) + 16|0);
  $109 = ($7|0)==($108|0);
  if (!($109)) {
   $110 = HEAP32[$7>>2]|0;
   $111 = ($110|0)==(0|0);
   if (!($111)) {
    $112 = HEAP32[$8>>2]|0;
    $113 = (($110) + 4|0);
    HEAP32[$113>>2] = $112;
    $114 = HEAP32[$7>>2]|0;
    $115 = HEAP32[$8>>2]|0;
    HEAP32[$115>>2] = $114;
    HEAP32[$7>>2] = 0;
    HEAP32[$8>>2] = 0;
   }
   $116 = HEAP32[$108>>2]|0;
   HEAP32[$7>>2] = $116;
   HEAP32[$8>>2] = $108;
   $117 = (($116) + 4|0);
   HEAP32[$117>>2] = $7;
   $118 = HEAP32[$8>>2]|0;
   HEAP32[$118>>2] = $7;
  }
 } else {
  $97 = (($this) + 8|0);
  $98 = ($7|0)==($97|0);
  if (!($98)) {
   $99 = HEAP32[$7>>2]|0;
   $100 = ($99|0)==(0|0);
   if (!($100)) {
    $101 = HEAP32[$8>>2]|0;
    $102 = (($99) + 4|0);
    HEAP32[$102>>2] = $101;
    $103 = HEAP32[$7>>2]|0;
    $104 = HEAP32[$8>>2]|0;
    HEAP32[$104>>2] = $103;
    HEAP32[$7>>2] = 0;
    HEAP32[$8>>2] = 0;
   }
   $105 = HEAP32[$97>>2]|0;
   HEAP32[$7>>2] = $105;
   HEAP32[$8>>2] = $97;
   $106 = (($105) + 4|0);
   HEAP32[$106>>2] = $7;
   $107 = HEAP32[$8>>2]|0;
   HEAP32[$107>>2] = $7;
  }
 }
 $119 = ($exinfo|0)==(0|0);
 if (!($119)) {
  $120 = (($exinfo) + 68|0);
  HEAP32[$120>>2] = $33;
 }
 $121 = (__Z15GetAudioManagerv()|0);
 $122 = (($121) + 92|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($7) + 48|0);
 $125 = (__ZN4FMOD6System11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOPPNS_5SoundE($123,$name_or_data,$mode,$exinfo,$124)|0);
 $126 = ($125|0)==(0);
 if (!($126)) {
  HEAP32[$3>>2] = 0;
  $127 = (($3) + 4|0);
  HEAP32[$127>>2] = 0;
  $128 = (($3) + 8|0);
  HEAP32[$128>>2] = $3;
  $129 = (($3) + 12|0);
  HEAP32[$129>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3336,($handle|0),($3|0));
  $130 = __THREW__; __THREW__ = 0;
  $131 = $130&1;
  if (!($131)) {
   __ZN11SoundHandleD2Ev($3);
   $$0 = $125;
   STACKTOP = sp;return ($$0|0);
  }
  $132 = ___cxa_find_matching_catch()|0;
  $133 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3642,($3|0));
  $134 = __THREW__; __THREW__ = 0;
  $135 = $134&1;
  if ($135) {
   $163 = ___cxa_find_matching_catch(0|0)|0;
   $164 = tempRet0;
   ___clang_call_terminate($163);
   // unreachable;
  } else {
   $$01 = $133;$$02 = $132;
   ___resumeException($$02|0);
   // unreachable;
  }
 }
 L53: do {
  if ($96) {
   $136 = ($7|0)==(0|0);
   if ($136) {
    __ZN11SoundHandle8Instance15UpdateLoadStateEv(0);
    __ZN11SoundHandle8Instance15UpdateLoadStateEv(0);
    break;
   }
   $137 = HEAP32[$54>>2]|0;
   do {
    if ((($137|0) == 3)) {
     break L53;
    } else if (!((($137|0) == 4))) {
     __ZN11SoundHandle8Instance15UpdateLoadStateEv($7);
     $138 = HEAP32[$54>>2]|0;
     if ((($138|0) == 3)) {
      break L53;
     } else if ((($138|0) == 4)) {
      break;
     }
     __ZN11SoundHandle8Instance15UpdateLoadStateEv($7);
     $$pre$i = HEAP32[$54>>2]|0;
     $phitmp$i = ($$pre$i|0)==(4);
     if (!($phitmp$i)) {
      break L53;
     }
    }
   } while(0);
   $139 = HEAP32[628304>>2]|0;
   __ZN11SoundHandle8InstanceD2Ev($7);
   HEAP32[$0>>2] = $139;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy1);
   HEAP32[$4>>2] = 0;
   $140 = (($4) + 4|0);
   HEAP32[$140>>2] = 0;
   $141 = (($4) + 8|0);
   HEAP32[$141>>2] = $4;
   $142 = (($4) + 12|0);
   HEAP32[$142>>2] = 0;
   __THREW__ = 0;
   invoke_vii(3336,($handle|0),($4|0));
   $143 = __THREW__; __THREW__ = 0;
   $144 = $143&1;
   if (!($144)) {
    __ZN11SoundHandleD2Ev($4);
    $$0 = 23;
    STACKTOP = sp;return ($$0|0);
   }
   $145 = ___cxa_find_matching_catch()|0;
   $146 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3642,($4|0));
   $147 = __THREW__; __THREW__ = 0;
   $148 = $147&1;
   if ($148) {
    $163 = ___cxa_find_matching_catch(0|0)|0;
    $164 = tempRet0;
    ___clang_call_terminate($163);
    // unreachable;
   } else {
    $$01 = $146;$$02 = $145;
    ___resumeException($$02|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$5>>2] = 0;
 $149 = (($5) + 4|0);
 HEAP32[$149>>2] = 0;
 $150 = (($5) + 8|0);
 HEAP32[$150>>2] = $5;
 $151 = (($5) + 12|0);
 HEAP32[$151>>2] = $7;
 $152 = ($7|0)==(0|0);
 if (!($152)) {
  $153 = ($5|0)==($38|0);
  if (!($153)) {
   $154 = HEAP32[$38>>2]|0;
   HEAP32[$5>>2] = $154;
   HEAP32[$149>>2] = $38;
   $155 = (($154) + 4|0);
   HEAP32[$155>>2] = $5;
   $156 = HEAP32[$149>>2]|0;
   HEAP32[$156>>2] = $5;
  }
 }
 __THREW__ = 0;
 invoke_vii(3336,($handle|0),($5|0));
 $157 = __THREW__; __THREW__ = 0;
 $158 = $157&1;
 if (!($158)) {
  __ZN11SoundHandleD2Ev($5);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $159 = ___cxa_find_matching_catch()|0;
 $160 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3642,($5|0));
 $161 = __THREW__; __THREW__ = 0;
 $162 = $161&1;
 if ($162) {
  $163 = ___cxa_find_matching_catch(0|0)|0;
  $164 = tempRet0;
  ___clang_call_terminate($163);
  // unreachable;
 } else {
  $$01 = $160;$$02 = $159;
  ___resumeException($$02|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN12SoundManager20RegisterModifiedClipEP10SampleClip($this,$clip) {
 $this = $this|0;
 $clip = $clip|0;
 var $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = (($clip) + 108|0);
 $2 = ($1|0)==($0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0|0);
 $$pre$i$i = (($clip) + 112|0);
 if (!($4)) {
  $5 = HEAP32[$$pre$i$i>>2]|0;
  $6 = (($3) + 4|0);
  HEAP32[$6>>2] = $5;
  $7 = HEAP32[$1>>2]|0;
  $8 = HEAP32[$$pre$i$i>>2]|0;
  HEAP32[$8>>2] = $7;
  HEAP32[$1>>2] = 0;
  HEAP32[$$pre$i$i>>2] = 0;
 }
 $9 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = $9;
 HEAP32[$$pre$i$i>>2] = $0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $1;
 $11 = HEAP32[$$pre$i$i>>2]|0;
 HEAP32[$11>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN12SoundManager17UnloadDynamicClipEP10SampleClip($this,$clip) {
 $this = $this|0;
 $clip = $clip|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $watchdog$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $watchdog$i = sp;
 $0 = ($clip|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($clip) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (+__Z19GetTimeSinceStartupv());
  HEAPF64[$watchdog$i>>3] = $4;
  $$0$i1 = $2;
  while(1) {
   __ZN20SoundManagerWatchDog6UpdateEPKci($watchdog$i,753488,1102);
   $5 = (($$0$i1) + 108|0);
   $6 = HEAP32[$5>>2]|0;
   __ZN11SoundHandle8Instance7DisposeEv($$0$i1);
   $7 = ($$0$i1|0)==($6|0);
   if ($7) {
    break;
   } else {
    $$0$i1 = $6;
   }
  }
 }
 $8 = (($clip) + 108|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($clip) + 112|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($9) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$8>>2]|0;
 $15 = HEAP32[$11>>2]|0;
 HEAP32[$15>>2] = $14;
 HEAP32[$8>>2] = 0;
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return;
}
function __Z39GetPreResolvedSampleClipPtrFromInstancePN11SoundHandle8InstanceE($instance) {
 $instance = $instance|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($instance) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __Z20RegisterModule_Audiov() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $i$01$i$i1 = 0;
 var $i$01$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i = 0;
 while(1) {
  $3 = ((($0) + ($i$01$i$i<<2)|0) + 64|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  $2 = (($i$01$i$i) + 1)|0;
  if ($5) {
   label = 4;
   break;
  }
  $1 = ($2|0)<(16);
  if ($1) {
   $i$01$i$i = $2;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$3>>2] = 222;
 }
 $6 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i2 = 0;
 while(1) {
  $9 = (($6) + ($i$01$i$i2<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  $8 = (($i$01$i$i2) + 1)|0;
  if ($11) {
   label = 8;
   break;
  }
  $7 = ($8|0)<(16);
  if ($7) {
   $i$01$i$i2 = $8;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  HEAP32[$9>>2] = 223;
 }
 $12 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i1 = 0;
 while(1) {
  $15 = ((($12) + ($i$01$i$i1<<2)|0) + 128|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  $14 = (($i$01$i$i1) + 1)|0;
  if ($17) {
   break;
  }
  $13 = ($14|0)<(16);
  if ($13) {
   $i$01$i$i1 = $14;
  } else {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
 HEAP32[$15>>2] = 224;
 STACKTOP = sp;return;
}
function __ZL26RegisterModuleICalls_Audiov() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL22InitializeModule_Audiov() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z21InitializeAudioModulev();
 STACKTOP = sp;return;
}
function __ZL19CleanupModule_Audiov() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z18CleanupAudioModulev();
 STACKTOP = sp;return;
}
function __Z21InitializeAudioModulev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628304>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy,1,16,762008,144)|0);
 HEAP32[$2>>2] = ((762016 + 8|0));
 __Z9SetIAudioP6IAudio($2);
 STACKTOP = sp;return;
}
function __Z18CleanupAudioModulev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z9GetIAudiov()|0);
 $2 = HEAP32[628304>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 __Z9SetIAudioP6IAudio(0);
 STACKTOP = sp;return;
}
function __ZN11AudioModule8SetPauseEb($this,$paused) {
 $this = $this|0;
 $paused = $paused|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetAudioManagerv()|0);
 __ZN12AudioManager8SetPauseEb($0,$paused);
 STACKTOP = sp;return;
}
function __ZN11AudioModule11FixedUpdateEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetAudioManagerv()|0);
 __ZN12AudioManager11FixedUpdateEv($0);
 STACKTOP = sp;return;
}
function __ZN11AudioModule6UpdateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetAudioManagerv()|0);
 __ZN12AudioManager6UpdateEv($0);
 $1 = (__Z15GetSoundManagerv()|0);
 __ZN12SoundManager6UpdateEv($1);
 STACKTOP = sp;return;
}
function __ZN11AudioModule17StopVideoTexturesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16BaseVideoTexture17StopVideoTexturesEv();
 STACKTOP = sp;return;
}
function __ZN11AudioModule19UpdateVideoTexturesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16BaseVideoTexture19UpdateVideoTexturesEv();
 STACKTOP = sp;return;
}
function __ZN11AudioModule18PauseVideoTexturesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16BaseVideoTexture18PauseVideoTexturesEv();
 STACKTOP = sp;return;
}
function __ZN11AudioModule20SuspendVideoTexturesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16BaseVideoTexture20SuspendVideoTexturesEv();
 STACKTOP = sp;return;
}
function __ZN11AudioModule19ResumeVideoTexturesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16BaseVideoTexture19ResumeVideoTexturesEv();
 STACKTOP = sp;return;
}
function __ZN11AudioModule22CreateAudioClipFromWWWER3WWWbi($this,$www,$stream,$audioType) {
 $this = $this|0;
 $www = $www|0;
 $stream = $stream|0;
 $audioType = $audioType|0;
 var $$0 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy2,1,16,762008,65)|0);
 $4 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1983,($3|0),($$byval_copy2|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(762008|0),65);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   $23 = ___cxa_find_matching_catch(0|0)|0;
   $24 = tempRet0;
   ___clang_call_terminate($23);
   // unreachable;
  } else {
   ___resumeException($14|0);
   // unreachable;
  }
 }
 $7 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
 $8 = HEAP32[$www>>2]|0;
 $9 = (($8) + 64|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($www)|0);
 $12 = ($11|0)==(1);
 if (!($12)) {
  $13 = (($7) + 125|0);
  HEAP8[$13>>0] = 0;
 }
 $18 = (__ZNK3WWW6IsDoneEv($www)|0);
 if (!($18)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(762088,0,762008,75,1,0,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN9AudioClip16EnableLegacyModeEv($7);
 $19 = HEAP32[$7>>2]|0;
 $20 = (($19) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vi[$21 & 4095]($7);
 $22 = (__ZN9AudioClip10InitStreamEP3WWWP13MoviePlaybackb15FMOD_SOUND_TYPE($7,$www,0,$stream,$audioType)|0);
 if ($22) {
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 __Z19DestroySingleObjectP6Object($7);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11AudioModule27IsFormatSupportedByPlatformEPKc($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (_strlen(($type|0))|0);
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$0>>0] = $5;
  $6 = (($0) + 1|0);
  $__p$0$i$i$i = $6;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  $10 = (($0) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$0>>2] = $11;
  $12 = (($0) + 4|0);
  HEAP32[$12>>2] = $1;
  $__p$0$i$i$i = $9;
 }
 _memcpy(($__p$0$i$i$i|0),($type|0),($1|0))|0;
 $13 = (($__p$0$i$i$i) + ($1)|0);
 HEAP8[$13>>0] = 0;
 __THREW__ = 0;
 $14 = (invoke_ii(3394,($0|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $24 = HEAP8[$0>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   ___resumeException($22|0);
   // unreachable;
  }
  $27 = (($0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __ZdlPv($28);
  ___resumeException($22|0);
  // unreachable;
 } else {
  $17 = HEAP8[$0>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   STACKTOP = sp;return ($14|0);
  }
  $20 = (($0) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  __ZdlPv($21);
  STACKTOP = sp;return ($14|0);
 }
 return 0|0;
}
function __ZN11AudioModule30GetOrCreateDSPFromCustomFilterEP17AudioCustomFilter($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN17AudioCustomFilter14GetOrCreateDSPEv($filter)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN11AudioModule23CreateAudioCustomFilterEP13MonoBehaviour($this,$mb) {
 $this = $this|0;
 $mb = $mb|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(24)|0);
 __THREW__ = 0;
 invoke_vii(3345,($0|0),($mb|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN11AudioModule23DeleteAudioCustomFilterEP17AudioCustomFilter($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($filter|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$filter>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($filter);
 STACKTOP = sp;return;
}
function __ZN11AudioModule27GetDSPFromAudioCustomFilterEP17AudioCustomFilter($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN17AudioCustomFilter6GetDSPEv($filter)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN11AudioModule14SetBypassOnDSPEPN4FMOD3DSPEb($this,$dsp,$state) {
 $this = $this|0;
 $dsp = $dsp|0;
 $state = $state|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN4FMOD3DSP9setBypassEb($dsp,$state)|0);
 STACKTOP = sp;return;
}
function __ZN11AudioModule25AudioManagerAwakeFromLoadE17AwakeFromLoadMode($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z15GetAudioManagerv()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$mode);
 STACKTOP = sp;return;
}
function __ZN16BaseVideoTexture19UpdateVideoTexturesEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $13 = 0;$2 = 0;
 }
 while(1) {
  $1 = HEAP32[$2>>2]|0;
  $3 = (($1) + 129|0);
  HEAP8[$3>>0] = 0;
  $4 = (($1) + 128|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   $12 = $13;
  } else {
   $7 = HEAP32[$1>>2]|0;
   $8 = (($7) + 156|0);
   $9 = HEAP32[$8>>2]|0;
   FUNCTION_TABLE_vi[$9 & 4095]($1);
   $12 = 0;
  }
  $10 = (($2) + 4|0);
  $11 = ($10|0)==($12|0);
  if ($11) {
   break;
  } else {
   $13 = $12;$2 = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16BaseVideoTexture18PauseVideoTexturesEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $2 = 0;
 }
 while(1) {
  $1 = HEAP32[$2>>2]|0;
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 164|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
  $6 = (($2) + 4|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   break;
  } else {
   $2 = $6;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16BaseVideoTexture17StopVideoTexturesEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $2 = 0;
 }
 while(1) {
  $1 = HEAP32[$2>>2]|0;
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 168|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
  $6 = HEAP32[$2>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 136|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$9 & 4095]($6,0);
  $10 = HEAP32[$2>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 140|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($10);
  $14 = (($2) + 4|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   break;
  } else {
   $2 = $14;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16BaseVideoTexture20SuspendVideoTexturesEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $2 = 0;
 }
 while(1) {
  $1 = HEAP32[$2>>2]|0;
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 176|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
  $6 = (($2) + 4|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   break;
  } else {
   $2 = $6;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16BaseVideoTexture19ResumeVideoTexturesEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $2 = 0;
 }
 while(1) {
  $1 = HEAP32[$2>>2]|0;
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 180|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
  $6 = (($2) + 4|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   break;
  } else {
   $2 = $6;
  }
 }
 STACKTOP = sp;return;
}
function _FMOD_System_Create($handle) {
 $handle = $handle|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(344)|0);
 $1 = HEAP32[762232>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[762232>>2] = $2;
 __THREW__ = 0;
 invoke_vii(3346,($0|0),($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZdlPv($0);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $5 = HEAP32[762232>>2]|0;
  $6 = (762240 + ($5<<2)|0);
  HEAP32[$6>>2] = $0;
  $7 = (($0) + 8|0);
  HEAP32[$7>>2] = $5;
  $8 = (($0) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $5 << 28;
  $11 = $9 & 65535;
  $12 = $11 | $10;
  $13 = $12;
  $14 = (($0) + 20|0);
  HEAP32[$14>>2] = $13;
  $15 = $12;
  HEAP32[$handle>>2] = $15;
  STACKTOP = sp;return 0;
 }
 return 0|0;
}
function _FMOD_Debug_SetLevel($level) {
 $level = $level|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _FMOD_Memory_Initialize($poolmem,$poollen,$useralloc,$userrealloc,$userfree,$memtypeflags) {
 $poolmem = $poolmem|0;
 $poollen = $poollen|0;
 $useralloc = $useralloc|0;
 $userrealloc = $userrealloc|0;
 $userfree = $userfree|0;
 $memtypeflags = $memtypeflags|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($handle) {
 $handle = $handle|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $handle;
 $1 = $0 >>> 28;
 $2 = (762240 + ($1<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN4FMOD7SystemIC2Ei($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 HEAP8[$0>>0] = 1;
 $1 = (($this) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 24|0);
 HEAP32[$2>>2] = $this;
 $3 = (($this) + 28|0);
 HEAP32[$3>>2] = $2;
 $4 = (($this) + 32|0);
 HEAP32[$4>>2] = $2;
 $5 = (($this) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 40|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 44|0);
 HEAP32[$7>>2] = 1024;
 $8 = (($this) + 48|0);
 HEAP32[$8>>2] = 2;
 $9 = (($this) + 52|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 56|0);
 HEAP32[$10>>2] = $9;
 $11 = (($this) + 60|0);
 HEAP32[$11>>2] = $9;
 $12 = (($this) + 64|0);
 HEAP32[$12>>2] = $this;
 $13 = (($this) + 68|0);
 $14 = (($this) + 80|0);
 $15 = (($this) + 84|0);
 ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 88|0);
 HEAP32[$16>>2] = $14;
 $17 = (($this) + 92|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 96|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 100|0);
 HEAP32[$19>>2] = $17;
 $20 = (($this) + 104|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 108|0);
 HEAP32[$21>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3347,($12|0),1024);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  $26 = HEAP32[$20>>2]|0;
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   __ZdaPv($26);
  }
  $28 = HEAP32[$19>>2]|0;
  $29 = ($28|0)==($17|0);
  if (!($29)) {
   $30 = HEAP32[$18>>2]|0;
   $31 = (($30) + 8|0);
   HEAP32[$31>>2] = $28;
   $32 = HEAP32[$18>>2]|0;
   $33 = HEAP32[$19>>2]|0;
   $34 = (($33) + 4|0);
   HEAP32[$34>>2] = $32;
   HEAP32[$18>>2] = $17;
   HEAP32[$19>>2] = $17;
  }
  $35 = HEAP32[$16>>2]|0;
  $36 = ($35|0)==($14|0);
  if (!($36)) {
   $37 = HEAP32[$15>>2]|0;
   $38 = (($37) + 8|0);
   HEAP32[$38>>2] = $35;
   $39 = HEAP32[$15>>2]|0;
   $40 = HEAP32[$16>>2]|0;
   $41 = (($40) + 4|0);
   HEAP32[$41>>2] = $39;
   HEAP32[$15>>2] = $14;
   HEAP32[$16>>2] = $14;
  }
  $$4 = $25;$$45 = $24;
 } else {
  $42 = (($this) + 112|0);
  HEAP32[$42>>2] = $this;
  $43 = (($this) + 116|0);
  $44 = (($this) + 128|0);
  $45 = (($this) + 132|0);
  ;HEAP32[$43+0>>2]=0|0;HEAP32[$43+4>>2]=0|0;HEAP32[$43+8>>2]=0|0;HEAP32[$43+12>>2]=0|0;
  HEAP32[$45>>2] = $44;
  $46 = (($this) + 136|0);
  HEAP32[$46>>2] = $44;
  $47 = (($this) + 140|0);
  HEAP32[$47>>2] = 0;
  $48 = (($this) + 144|0);
  HEAP32[$48>>2] = $47;
  $49 = (($this) + 148|0);
  HEAP32[$49>>2] = $47;
  $50 = (($this) + 152|0);
  HEAP32[$50>>2] = 0;
  $51 = (($this) + 156|0);
  HEAP32[$51>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3348,($42|0),512);
  $52 = __THREW__; __THREW__ = 0;
  $53 = $52&1;
  if ($53) {
   $54 = ___cxa_find_matching_catch()|0;
   $55 = tempRet0;
   $56 = HEAP32[$50>>2]|0;
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    __ZdaPv($56);
   }
   $58 = HEAP32[$49>>2]|0;
   $59 = ($58|0)==($47|0);
   if (!($59)) {
    $60 = HEAP32[$48>>2]|0;
    $61 = (($60) + 8|0);
    HEAP32[$61>>2] = $58;
    $62 = HEAP32[$48>>2]|0;
    $63 = HEAP32[$49>>2]|0;
    $64 = (($63) + 4|0);
    HEAP32[$64>>2] = $62;
    HEAP32[$48>>2] = $47;
    HEAP32[$49>>2] = $47;
   }
   $65 = HEAP32[$46>>2]|0;
   $66 = ($65|0)==($44|0);
   if (!($66)) {
    $67 = HEAP32[$45>>2]|0;
    $68 = (($67) + 8|0);
    HEAP32[$68>>2] = $65;
    $69 = HEAP32[$45>>2]|0;
    $70 = HEAP32[$46>>2]|0;
    $71 = (($70) + 4|0);
    HEAP32[$71>>2] = $69;
    HEAP32[$45>>2] = $44;
    HEAP32[$46>>2] = $44;
   }
   $$3 = $55;$$34 = $54;
  } else {
   $72 = (($this) + 160|0);
   HEAP32[$72>>2] = $this;
   $73 = (($this) + 164|0);
   $74 = (($this) + 176|0);
   $75 = (($this) + 180|0);
   ;HEAP32[$73+0>>2]=0|0;HEAP32[$73+4>>2]=0|0;HEAP32[$73+8>>2]=0|0;HEAP32[$73+12>>2]=0|0;
   HEAP32[$75>>2] = $74;
   $76 = (($this) + 184|0);
   HEAP32[$76>>2] = $74;
   $77 = (($this) + 188|0);
   HEAP32[$77>>2] = 0;
   $78 = (($this) + 192|0);
   HEAP32[$78>>2] = $77;
   $79 = (($this) + 196|0);
   HEAP32[$79>>2] = $77;
   $80 = (($this) + 200|0);
   HEAP32[$80>>2] = 0;
   $81 = (($this) + 204|0);
   HEAP32[$81>>2] = 0;
   __THREW__ = 0;
   invoke_vii(3349,($72|0),4096);
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    $84 = ___cxa_find_matching_catch()|0;
    $85 = tempRet0;
    $86 = HEAP32[$80>>2]|0;
    $87 = ($86|0)==(0|0);
    if (!($87)) {
     __ZdaPv($86);
    }
    $88 = HEAP32[$79>>2]|0;
    $89 = ($88|0)==($77|0);
    if (!($89)) {
     $90 = HEAP32[$78>>2]|0;
     $91 = (($90) + 8|0);
     HEAP32[$91>>2] = $88;
     $92 = HEAP32[$78>>2]|0;
     $93 = HEAP32[$79>>2]|0;
     $94 = (($93) + 4|0);
     HEAP32[$94>>2] = $92;
     HEAP32[$78>>2] = $77;
     HEAP32[$79>>2] = $77;
    }
    $95 = HEAP32[$76>>2]|0;
    $96 = ($95|0)==($74|0);
    if (!($96)) {
     $97 = HEAP32[$75>>2]|0;
     $98 = (($97) + 8|0);
     HEAP32[$98>>2] = $95;
     $99 = HEAP32[$75>>2]|0;
     $100 = HEAP32[$76>>2]|0;
     $101 = (($100) + 4|0);
     HEAP32[$101>>2] = $99;
     HEAP32[$75>>2] = $74;
     HEAP32[$76>>2] = $74;
    }
    $$2 = $85;$$23 = $84;
   } else {
    $102 = (($this) + 208|0);
    HEAP32[$102>>2] = $this;
    $103 = (($this) + 212|0);
    $104 = (($this) + 224|0);
    $105 = (($this) + 228|0);
    ;HEAP32[$103+0>>2]=0|0;HEAP32[$103+4>>2]=0|0;HEAP32[$103+8>>2]=0|0;HEAP32[$103+12>>2]=0|0;
    HEAP32[$105>>2] = $104;
    $106 = (($this) + 232|0);
    HEAP32[$106>>2] = $104;
    $107 = (($this) + 236|0);
    HEAP32[$107>>2] = 0;
    $108 = (($this) + 240|0);
    HEAP32[$108>>2] = $107;
    $109 = (($this) + 244|0);
    HEAP32[$109>>2] = $107;
    $110 = (($this) + 248|0);
    HEAP32[$110>>2] = 0;
    $111 = (($this) + 252|0);
    HEAP32[$111>>2] = 0;
    __THREW__ = 0;
    invoke_vii(3350,($102|0),1024);
    $112 = __THREW__; __THREW__ = 0;
    $113 = $112&1;
    if ($113) {
     $114 = ___cxa_find_matching_catch()|0;
     $115 = tempRet0;
     $116 = HEAP32[$110>>2]|0;
     $117 = ($116|0)==(0|0);
     if (!($117)) {
      __ZdaPv($116);
     }
     $118 = HEAP32[$109>>2]|0;
     $119 = ($118|0)==($107|0);
     if (!($119)) {
      $120 = HEAP32[$108>>2]|0;
      $121 = (($120) + 8|0);
      HEAP32[$121>>2] = $118;
      $122 = HEAP32[$108>>2]|0;
      $123 = HEAP32[$109>>2]|0;
      $124 = (($123) + 4|0);
      HEAP32[$124>>2] = $122;
      HEAP32[$108>>2] = $107;
      HEAP32[$109>>2] = $107;
     }
     $125 = HEAP32[$106>>2]|0;
     $126 = ($125|0)==($104|0);
     if (!($126)) {
      $127 = HEAP32[$105>>2]|0;
      $128 = (($127) + 8|0);
      HEAP32[$128>>2] = $125;
      $129 = HEAP32[$105>>2]|0;
      $130 = HEAP32[$106>>2]|0;
      $131 = (($130) + 4|0);
      HEAP32[$131>>2] = $129;
      HEAP32[$105>>2] = $104;
      HEAP32[$106>>2] = $104;
     }
     $$1 = $115;$$12 = $114;
    } else {
     $132 = (($this) + 256|0);
     HEAP32[$132>>2] = $this;
     $133 = (($this) + 260|0);
     $134 = (($this) + 272|0);
     $135 = (($this) + 276|0);
     ;HEAP32[$133+0>>2]=0|0;HEAP32[$133+4>>2]=0|0;HEAP32[$133+8>>2]=0|0;HEAP32[$133+12>>2]=0|0;
     HEAP32[$135>>2] = $134;
     $136 = (($this) + 280|0);
     HEAP32[$136>>2] = $134;
     $137 = (($this) + 284|0);
     HEAP32[$137>>2] = 0;
     $138 = (($this) + 288|0);
     HEAP32[$138>>2] = $137;
     $139 = (($this) + 292|0);
     HEAP32[$139>>2] = $137;
     $140 = (($this) + 296|0);
     HEAP32[$140>>2] = 0;
     $141 = (($this) + 300|0);
     HEAP32[$141>>2] = 0;
     __THREW__ = 0;
     invoke_vii(3351,($132|0),1024);
     $142 = __THREW__; __THREW__ = 0;
     $143 = $142&1;
     if (!($143)) {
      $162 = (($this) + 304|0);
      ;HEAP32[$162+0>>2]=0|0;HEAP32[$162+4>>2]=0|0;HEAP32[$162+8>>2]=0|0;HEAP32[$162+12>>2]=0|0;HEAP32[$162+16>>2]=0|0;HEAP32[$162+20>>2]=0|0;
      HEAP32[$6>>2] = 32;
      STACKTOP = sp;return;
     }
     $144 = ___cxa_find_matching_catch()|0;
     $145 = tempRet0;
     $146 = HEAP32[$140>>2]|0;
     $147 = ($146|0)==(0|0);
     if (!($147)) {
      __ZdaPv($146);
     }
     $148 = HEAP32[$139>>2]|0;
     $149 = ($148|0)==($137|0);
     if (!($149)) {
      $150 = HEAP32[$138>>2]|0;
      $151 = (($150) + 8|0);
      HEAP32[$151>>2] = $148;
      $152 = HEAP32[$138>>2]|0;
      $153 = HEAP32[$139>>2]|0;
      $154 = (($153) + 4|0);
      HEAP32[$154>>2] = $152;
      HEAP32[$138>>2] = $137;
      HEAP32[$139>>2] = $137;
     }
     $155 = HEAP32[$136>>2]|0;
     $156 = ($155|0)==($134|0);
     if (!($156)) {
      $157 = HEAP32[$135>>2]|0;
      $158 = (($157) + 8|0);
      HEAP32[$158>>2] = $155;
      $159 = HEAP32[$135>>2]|0;
      $160 = HEAP32[$136>>2]|0;
      $161 = (($160) + 4|0);
      HEAP32[$161>>2] = $159;
      HEAP32[$135>>2] = $134;
      HEAP32[$136>>2] = $134;
     }
     __THREW__ = 0;
     invoke_vi(3666,($102|0));
     $163 = __THREW__; __THREW__ = 0;
     $164 = $163&1;
     if ($164) {
      $185 = ___cxa_find_matching_catch(0|0)|0;
      $186 = tempRet0;
      ___clang_call_terminate($185);
      // unreachable;
     } else {
      $$1 = $145;$$12 = $144;
     }
    }
    __THREW__ = 0;
    invoke_vi(3667,($72|0));
    $165 = __THREW__; __THREW__ = 0;
    $166 = $165&1;
    if ($166) {
     $185 = ___cxa_find_matching_catch(0|0)|0;
     $186 = tempRet0;
     ___clang_call_terminate($185);
     // unreachable;
    } else {
     $$2 = $$1;$$23 = $$12;
    }
   }
   __THREW__ = 0;
   invoke_vi(3668,($42|0));
   $167 = __THREW__; __THREW__ = 0;
   $168 = $167&1;
   if ($168) {
    $185 = ___cxa_find_matching_catch(0|0)|0;
    $186 = tempRet0;
    ___clang_call_terminate($185);
    // unreachable;
   } else {
    $$3 = $$2;$$34 = $$23;
   }
  }
  __THREW__ = 0;
  invoke_vi(3669,($12|0));
  $169 = __THREW__; __THREW__ = 0;
  $170 = $169&1;
  if ($170) {
   $185 = ___cxa_find_matching_catch(0|0)|0;
   $186 = tempRet0;
   ___clang_call_terminate($185);
   // unreachable;
  } else {
   $$4 = $$3;$$45 = $$34;
  }
 }
 $171 = HEAP32[$11>>2]|0;
 $172 = ($171|0)==($9|0);
 if (!($172)) {
  $173 = HEAP32[$10>>2]|0;
  $174 = (($173) + 8|0);
  HEAP32[$174>>2] = $171;
  $175 = HEAP32[$10>>2]|0;
  $176 = HEAP32[$11>>2]|0;
  $177 = (($176) + 4|0);
  HEAP32[$177>>2] = $175;
  HEAP32[$10>>2] = $9;
  HEAP32[$11>>2] = $9;
 }
 $178 = HEAP32[$4>>2]|0;
 $179 = ($178|0)==($2|0);
 if ($179) {
  ___resumeException($$45|0);
  // unreachable;
 }
 $180 = HEAP32[$3>>2]|0;
 $181 = (($180) + 8|0);
 HEAP32[$181>>2] = $178;
 $182 = HEAP32[$3>>2]|0;
 $183 = HEAP32[$4>>2]|0;
 $184 = (($183) + 4|0);
 HEAP32[$184>>2] = $182;
 HEAP32[$3>>2] = $2;
 HEAP32[$4>>2] = $2;
 ___resumeException($$45|0);
 // unreachable;
}
function __ZN4FMOD7SystemI19setSoftwareChannelsEi($this,$numsoftwarechannels) {
 $this = $this|0;
 $numsoftwarechannels = $numsoftwarechannels|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = $numsoftwarechannels;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD6SoundIC2EPNS_7SystemIE($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $system;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = $this;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $5;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 44|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 48|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = $10;
 $13 = (($this) + 320|0);
 HEAP32[$13>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4FMOD6SoundID2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(3395,($1|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   $7 = (($this) + 44|0);
   $8 = (($this) + 52|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==($7|0);
   if (!($10)) {
    $11 = (($this) + 48|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 8|0);
    HEAP32[$13>>2] = $9;
    $14 = HEAP32[$11>>2]|0;
    $15 = HEAP32[$8>>2]|0;
    $16 = (($15) + 4|0);
    HEAP32[$16>>2] = $14;
    HEAP32[$11>>2] = $7;
    HEAP32[$8>>2] = $7;
   }
   $37 = (($this) + 24|0);
   $38 = (($this) + 32|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==($37|0);
   if ($40) {
    ___resumeException($5|0);
    // unreachable;
   }
   $41 = (($this) + 28|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($42) + 8|0);
   HEAP32[$43>>2] = $39;
   $44 = HEAP32[$41>>2]|0;
   $45 = HEAP32[$38>>2]|0;
   $46 = (($45) + 4|0);
   HEAP32[$46>>2] = $44;
   HEAP32[$41>>2] = $37;
   HEAP32[$38>>2] = $37;
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $17 = (($this) + 44|0);
 $18 = (($this) + 52|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==($17|0);
 if (!($20)) {
  $21 = (($this) + 48|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 8|0);
  HEAP32[$23>>2] = $19;
  $24 = HEAP32[$21>>2]|0;
  $25 = HEAP32[$18>>2]|0;
  $26 = (($25) + 4|0);
  HEAP32[$26>>2] = $24;
  HEAP32[$21>>2] = $17;
  HEAP32[$18>>2] = $17;
 }
 $27 = (($this) + 24|0);
 $28 = (($this) + 32|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==($27|0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $31 = (($this) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 8|0);
 HEAP32[$33>>2] = $29;
 $34 = HEAP32[$31>>2]|0;
 $35 = HEAP32[$28>>2]|0;
 $36 = (($35) + 4|0);
 HEAP32[$36>>2] = $34;
 HEAP32[$31>>2] = $27;
 HEAP32[$28>>2] = $27;
 STACKTOP = sp;return;
}
function __ZN4FMOD8ChannelI4stopEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 _JS_Sound_Stop(($1|0));
 __ZN4FMOD8ChannelI11EndCallbackEv($this);
 STACKTOP = sp;return 0;
}
function __ZN4FMOD22FakeModChannelCallbackEPv($channel) {
 $channel = $channel|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4FMOD8ChannelI11EndCallbackEv($channel);
 STACKTOP = sp;return;
}
function __ZN4FMOD8ChannelI11EndCallbackEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0$i = 0;
 } else {
  $4 = (($2) + 64|0);
  $5 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($4,$1)|0);
  $$0$i = $5;
 }
 $6 = ($$0$i|0)==($this|0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 40|0);
 $8 = (($this) + 48|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 8|0);
 HEAP32[$12>>2] = $9;
 $13 = HEAP32[$10>>2]|0;
 $14 = HEAP32[$8>>2]|0;
 $15 = (($14) + 4|0);
 HEAP32[$15>>2] = $13;
 HEAP32[$10>>2] = $7;
 HEAP32[$8>>2] = $7;
 $16 = (($this) + 52|0);
 $17 = (($this) + 60|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 56|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 8|0);
 HEAP32[$21>>2] = $18;
 $22 = HEAP32[$19>>2]|0;
 $23 = HEAP32[$17>>2]|0;
 $24 = (($23) + 4|0);
 HEAP32[$24>>2] = $22;
 HEAP32[$19>>2] = $16;
 HEAP32[$17>>2] = $16;
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + -1)|0;
 HEAP32[$26>>2] = $28;
 $29 = (($this) + 64|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = (($30) + 36|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + -1)|0;
  HEAP32[$32>>2] = $34;
  HEAP32[$29>>2] = 0;
 }
 $35 = (($this) + 120|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $40 = $25;
 } else {
  $38 = HEAP32[$0>>2]|0;
  (FUNCTION_TABLE_iiiii[$36 & 511]($38,0,0,0)|0);
  $$pre = HEAP32[$this>>2]|0;
  $40 = $$pre;
 }
 $39 = (($40) + 64|0);
 (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE7ReleaseEPS2_($39,$this)|0);
 STACKTOP = sp;return;
}
function __ZN4FMOD8ChannelIC2EPNS_7SystemIE($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $system;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = $this;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $5;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = $this;
 $9 = (($this) + 44|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 48|0);
 HEAP32[$10>>2] = $8;
 $11 = (($this) + 52|0);
 HEAP32[$11>>2] = $this;
 $12 = (($this) + 56|0);
 HEAP32[$12>>2] = $11;
 $13 = (($this) + 60|0);
 HEAP32[$13>>2] = $11;
 $14 = (($this) + 64|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 68|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 72|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 88|0);
 $18 = (($this) + 104|0);
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 108|0);
 HEAPF32[$19>>2] = Math_fround(48000.0);
 $20 = (($this) + 112|0);
 HEAP8[$20>>0] = 0;
 $21 = (($this) + 113|0);
 HEAP8[$21>>0] = 0;
 $22 = (($this) + 114|0);
 HEAP8[$22>>0] = 0;
 $23 = (($this) + 120|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 76|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($this) + 80|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($this) + 84|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 __THREW__ = 0;
 $27 = (invoke_iii(2576,(3670|0),($this|0))|0);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if (!($29)) {
  $30 = (($this) + 116|0);
  HEAP32[$30>>2] = $27;
  __THREW__ = 0;
  $31 = (invoke_i(120)|0);
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if (!($33)) {
   $34 = (($31|0) % 1000)&-1;
   $35 = (Math_fround(($34|0)));
   $36 = Math_fround($35 * Math_fround(0.00100000004749745130539));
   $37 = (($this) + 36|0);
   HEAPF32[$37>>2] = $36;
   STACKTOP = sp;return;
  }
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 $40 = HEAP32[$13>>2]|0;
 $41 = ($40|0)==($11|0);
 if (!($41)) {
  $42 = HEAP32[$12>>2]|0;
  $43 = (($42) + 8|0);
  HEAP32[$43>>2] = $40;
  $44 = HEAP32[$12>>2]|0;
  $45 = HEAP32[$13>>2]|0;
  $46 = (($45) + 4|0);
  HEAP32[$46>>2] = $44;
  HEAP32[$12>>2] = $11;
  HEAP32[$13>>2] = $11;
 }
 $47 = HEAP32[$10>>2]|0;
 $48 = ($47|0)==($8|0);
 if (!($48)) {
  $49 = HEAP32[$9>>2]|0;
  $50 = (($49) + 8|0);
  HEAP32[$50>>2] = $47;
  $51 = HEAP32[$9>>2]|0;
  $52 = HEAP32[$10>>2]|0;
  $53 = (($52) + 4|0);
  HEAP32[$53>>2] = $51;
  HEAP32[$9>>2] = $8;
  HEAP32[$10>>2] = $8;
 }
 $54 = HEAP32[$7>>2]|0;
 $55 = ($54|0)==($5|0);
 if ($55) {
  ___resumeException($38|0);
  // unreachable;
 }
 $56 = HEAP32[$6>>2]|0;
 $57 = (($56) + 8|0);
 HEAP32[$57>>2] = $54;
 $58 = HEAP32[$6>>2]|0;
 $59 = HEAP32[$7>>2]|0;
 $60 = (($59) + 4|0);
 HEAP32[$60>>2] = $58;
 HEAP32[$6>>2] = $5;
 HEAP32[$7>>2] = $5;
 ___resumeException($38|0);
 // unreachable;
}
function __ZN4FMOD8ChannelID2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(3395,($1|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   $7 = (($this) + 52|0);
   $8 = (($this) + 60|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==($7|0);
   if (!($10)) {
    $11 = (($this) + 56|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 8|0);
    HEAP32[$13>>2] = $9;
    $14 = HEAP32[$11>>2]|0;
    $15 = HEAP32[$8>>2]|0;
    $16 = (($15) + 4|0);
    HEAP32[$16>>2] = $14;
    HEAP32[$11>>2] = $7;
    HEAP32[$8>>2] = $7;
   }
   $47 = (($this) + 40|0);
   $48 = (($this) + 48|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==($47|0);
   if (!($50)) {
    $51 = (($this) + 44|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($52) + 8|0);
    HEAP32[$53>>2] = $49;
    $54 = HEAP32[$51>>2]|0;
    $55 = HEAP32[$48>>2]|0;
    $56 = (($55) + 4|0);
    HEAP32[$56>>2] = $54;
    HEAP32[$51>>2] = $47;
    HEAP32[$48>>2] = $47;
   }
   $57 = (($this) + 24|0);
   $58 = (($this) + 32|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==($57|0);
   if ($60) {
    ___resumeException($5|0);
    // unreachable;
   }
   $61 = (($this) + 28|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($62) + 8|0);
   HEAP32[$63>>2] = $59;
   $64 = HEAP32[$61>>2]|0;
   $65 = HEAP32[$58>>2]|0;
   $66 = (($65) + 4|0);
   HEAP32[$66>>2] = $64;
   HEAP32[$61>>2] = $57;
   HEAP32[$58>>2] = $57;
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $17 = (($this) + 52|0);
 $18 = (($this) + 60|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==($17|0);
 if (!($20)) {
  $21 = (($this) + 56|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + 8|0);
  HEAP32[$23>>2] = $19;
  $24 = HEAP32[$21>>2]|0;
  $25 = HEAP32[$18>>2]|0;
  $26 = (($25) + 4|0);
  HEAP32[$26>>2] = $24;
  HEAP32[$21>>2] = $17;
  HEAP32[$18>>2] = $17;
 }
 $27 = (($this) + 40|0);
 $28 = (($this) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==($27|0);
 if (!($30)) {
  $31 = (($this) + 44|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 8|0);
  HEAP32[$33>>2] = $29;
  $34 = HEAP32[$31>>2]|0;
  $35 = HEAP32[$28>>2]|0;
  $36 = (($35) + 4|0);
  HEAP32[$36>>2] = $34;
  HEAP32[$31>>2] = $27;
  HEAP32[$28>>2] = $27;
 }
 $37 = (($this) + 24|0);
 $38 = (($this) + 32|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==($37|0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 28|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 8|0);
 HEAP32[$43>>2] = $39;
 $44 = HEAP32[$41>>2]|0;
 $45 = HEAP32[$38>>2]|0;
 $46 = (($45) + 4|0);
 HEAP32[$46>>2] = $44;
 HEAP32[$41>>2] = $37;
 HEAP32[$38>>2] = $37;
 STACKTOP = sp;return;
}
function __ZN4FMOD13ChannelGroupIC2EPNS_7SystemIE($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $system;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = $this;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $5;
 $8 = (($this) + 40|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 44|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 48|0);
 HEAP32[$10>>2] = $this;
 $11 = (($this) + 52|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 56|0);
 HEAP32[$12>>2] = $10;
 $13 = (($this) + 60|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 64|0);
 HEAP32[$14>>2] = $13;
 $15 = (($this) + 68|0);
 HEAP32[$15>>2] = $13;
 $16 = (($this) + 72|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 76|0);
 HEAP32[$17>>2] = $16;
 $18 = (($this) + 80|0);
 HEAP32[$18>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN4FMOD13ChannelGroupID2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = (($this) + 80|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if (!($3)) {
  $4 = (($this) + 76|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 8|0);
  HEAP32[$6>>2] = $2;
  $7 = HEAP32[$4>>2]|0;
  $8 = HEAP32[$1>>2]|0;
  $9 = (($8) + 4|0);
  HEAP32[$9>>2] = $7;
  HEAP32[$4>>2] = $0;
  HEAP32[$1>>2] = $0;
 }
 $10 = (($this) + 60|0);
 $11 = (($this) + 68|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($10|0);
 if (!($13)) {
  $14 = (($this) + 64|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 8|0);
  HEAP32[$16>>2] = $12;
  $17 = HEAP32[$14>>2]|0;
  $18 = HEAP32[$11>>2]|0;
  $19 = (($18) + 4|0);
  HEAP32[$19>>2] = $17;
  HEAP32[$14>>2] = $10;
  HEAP32[$11>>2] = $10;
 }
 $20 = (($this) + 48|0);
 $21 = (($this) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==($20|0);
 if (!($23)) {
  $24 = (($this) + 52|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 8|0);
  HEAP32[$26>>2] = $22;
  $27 = HEAP32[$24>>2]|0;
  $28 = HEAP32[$21>>2]|0;
  $29 = (($28) + 4|0);
  HEAP32[$29>>2] = $27;
  HEAP32[$24>>2] = $20;
  HEAP32[$21>>2] = $20;
 }
 $30 = (($this) + 24|0);
 $31 = (($this) + 32|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==($30|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = (($this) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + 8|0);
 HEAP32[$36>>2] = $32;
 $37 = HEAP32[$34>>2]|0;
 $38 = HEAP32[$31>>2]|0;
 $39 = (($38) + 4|0);
 HEAP32[$39>>2] = $37;
 HEAP32[$34>>2] = $30;
 HEAP32[$31>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN4FMOD4DSPIC2EPNS_7SystemIE($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $system;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = $this;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN4FMOD4DSPID2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 HEAP32[$6>>2] = $2;
 $7 = HEAP32[$4>>2]|0;
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 HEAP32[$4>>2] = $0;
 HEAP32[$1>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN4FMOD7ReverbIC2EPNS_7SystemIE($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $system;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = $this;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN4FMOD7ReverbID2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 HEAP32[$6>>2] = $2;
 $7 = HEAP32[$4>>2]|0;
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 HEAP32[$4>>2] = $0;
 HEAP32[$1>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN4FMOD13ChannelGroupI6addDSPEPNS_3DSPEPPNS_13DSPConnectionE($this,$dsp,$con) {
 $this = $this|0;
 $dsp = $dsp|0;
 $con = $con|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD13ChannelGroupI8addGroupEPNS_12ChannelGroupE($this,$group) {
 $this = $this|0;
 $group = $group|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($group)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return 0;
 }
 $2 = (($0) + 112|0);
 $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$group)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return 0;
 }
 $5 = (($this) + 60|0);
 $6 = (($3) + 48|0);
 $7 = (($3) + 56|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($3) + 52|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 HEAP32[$11>>2] = $8;
 $12 = HEAP32[$9>>2]|0;
 $13 = HEAP32[$7>>2]|0;
 $14 = (($13) + 4|0);
 HEAP32[$14>>2] = $12;
 HEAP32[$9>>2] = $6;
 HEAP32[$7>>2] = $6;
 $15 = (($this) + 64|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$9>>2] = $16;
 HEAP32[$7>>2] = $5;
 $17 = HEAP32[$15>>2]|0;
 $18 = (($17) + 8|0);
 HEAP32[$18>>2] = $6;
 HEAP32[$15>>2] = $6;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD13ChannelGroupI10getChannelEiPPNS_7ChannelE($this,$index,$channel) {
 $this = $this|0;
 $index = $index|0;
 $channel = $channel|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762328;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD13ChannelGroupI10getDSPHeadEPPNS_3DSPE($this,$dsp) {
 $this = $this|0;
 $dsp = $dsp|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$dsp>>2] = 0;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD13ChannelGroupI8getGroupEiPPNS_12ChannelGroupE($this,$index,$group) {
 $this = $this|0;
 $index = $index|0;
 $group = $group|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762344;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD13ChannelGroupI14getNumChannelsEPi($this,$numchannels) {
 $this = $this|0;
 $numchannels = $numchannels|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762360;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD13ChannelGroupI12getNumGroupsEPi($this,$numgroups) {
 $this = $this|0;
 $numgroups = $numgroups|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762376;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD13ChannelGroupI14getParentGroupEPPNS_12ChannelGroupE($this,$group) {
 $this = $this|0;
 $group = $group|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = 0;
 } else {
  $3 = (($1) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4;
 }
 HEAP32[$group>>2] = $5;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD13ChannelGroupI7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 112|0);
 (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE7ReleaseEPS2_($1,$this)|0);
 STACKTOP = sp;return 0;
}
function __ZN4FMOD13ChannelGroupI19setAudibilityFactorEf($this,$factor) {
 $this = $this|0;
 $factor = Math_fround($factor);
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762408;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD13ChannelGroupI7setMuteEb($this,$mute) {
 $this = $this|0;
 $mute = $mute|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762432;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD13ChannelGroupI8setPitchEf($this,$pitch) {
 $this = $this|0;
 $pitch = Math_fround($pitch);
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762440;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD13ChannelGroupI9setVolumeEf($this,$volume) {
 $this = $this|0;
 $volume = Math_fround($volume);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAPF32[$0>>2] = $volume;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI12getFrequencyEPf($this,$frequency) {
 $this = $this|0;
 $frequency = $frequency|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$frequency>>2] = $1;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI19getReverbPropertiesEP29FMOD_REVERB_CHANNELPROPERTIES($this,$props) {
 $this = $this|0;
 $props = $props|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI11getUserDataEPPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$userdata>>2] = $1;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI9isPlayingEPb($this,$isplaying) {
 $this = $this|0;
 $isplaying = $isplaying|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = 0;
 } else {
  $3 = (($this) + 113|0);
  $4 = HEAP8[$3>>0]|0;
  $phitmp = $4 ^ 1;
  $5 = $phitmp;
 }
 HEAP8[$isplaying>>0] = $5;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI15set3DAttributesEPK11FMOD_VECTORS3_($this,$pos,$vel) {
 $this = $this|0;
 $pos = $pos|0;
 $vel = $vel|0;
 var $$0$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0.0, $17 = 0, $18 = Math_fround(0), $19 = 0.0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0.0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0.0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0.0, $6 = 0, $7 = Math_fround(0), $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($pos|0)==(0|0);
 if (!($0)) {
  $1 = (($this) + 76|0);
  ;HEAP32[$1+0>>2]=HEAP32[$pos+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$pos+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$pos+8>>2]|0;
  $2 = (($this) + 116|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = Math_fround(HEAPF32[$pos>>2]);
  $5 = +$4;
  $6 = (($pos) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = +$7;
  $9 = (($pos) + 8|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = +$10;
  _JS_Sound_SetPosition(($3|0),(+$5),(+$8),(+$11));
 }
 $12 = ($vel|0)==(0|0);
 if (!($12)) {
  $13 = (($this) + 116|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = Math_fround(HEAPF32[$vel>>2]);
  $16 = +$15;
  $17 = (($vel) + 4|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = +$18;
  $20 = (($vel) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = +$21;
  _JS_Sound_SetVelocity(($14|0),(+$16),(+$19),(+$22));
 }
 $23 = (($this) + 104|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + 320|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $$0$i = $24;
  $54 = (($this) + 116|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = +$$0$i;
  _JS_Sound_SetVolume(($55|0),(+$56));
  STACKTOP = sp;return 0;
 }
 $29 = (($this) + 76|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($25) + 308|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($30 - $32);
 $34 = (($this) + 80|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($25) + 312|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($35 - $37);
 $39 = (($this) + 84|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($25) + 316|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($40 - $42);
 $44 = Math_fround($33 * $33);
 $45 = Math_fround($38 * $38);
 $46 = Math_fround($44 + $45);
 $47 = Math_fround($43 * $43);
 $48 = Math_fround($46 + $47);
 $49 = (Math_fround(Math_sqrt((Math_fround($48)))));
 $50 = (($this) + 20|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (Math_fround(FUNCTION_TABLE_fif[$27 & 31]($51,$49)));
 $53 = Math_fround($24 * $52);
 $$0$i = $53;
 $54 = (($this) + 116|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = +$$0$i;
 _JS_Sound_SetVolume(($55|0),(+$56));
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI9setVolumeEf($this,$volume) {
 $this = $this|0;
 $volume = Math_fround($volume);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 HEAPF32[$0>>2] = $volume;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 320|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = $volume;
  $30 = (($this) + 116|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = +$$0;
  _JS_Sound_SetVolume(($31|0),(+$32));
  STACKTOP = sp;return 0;
 }
 $5 = (($this) + 76|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($1) + 308|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($this) + 80|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($1) + 312|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($this) + 84|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($1) + 316|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 - $18);
 $20 = Math_fround($9 * $9);
 $21 = Math_fround($14 * $14);
 $22 = Math_fround($20 + $21);
 $23 = Math_fround($19 * $19);
 $24 = Math_fround($22 + $23);
 $25 = (Math_fround(Math_sqrt((Math_fround($24)))));
 $26 = (($this) + 20|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (Math_fround(FUNCTION_TABLE_fif[$3 & 31]($27,$25)));
 $29 = Math_fround($28 * $volume);
 $$0 = $29;
 $30 = (($this) + 116|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = +$$0;
 _JS_Sound_SetVolume(($31|0),(+$32));
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI20set3DConeOrientationEP11FMOD_VECTOR($this,$pos) {
 $this = $this|0;
 $pos = $pos|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI17set3DConeSettingsEfff($this,$insideconeangle,$outsideconeangle,$outsidevolume) {
 $this = $this|0;
 $insideconeangle = Math_fround($insideconeangle);
 $outsideconeangle = Math_fround($outsideconeangle);
 $outsidevolume = Math_fround($outsidevolume);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI17set3DDopplerLevelEf($this,$dopplerlevel) {
 $this = $this|0;
 $dopplerlevel = Math_fround($dopplerlevel);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI19set3DMinMaxDistanceEff($this,$mindistance,$maxdistance) {
 $this = $this|0;
 $mindistance = Math_fround($mindistance);
 $maxdistance = Math_fround($maxdistance);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI13set3DPanLevelEf($this,$panlevel) {
 $this = $this|0;
 $panlevel = Math_fround($panlevel);
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $panlevel > Math_fround(0.0);
 _JS_Sound_Set3D(($1|0),($2|0));
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI11set3DSpreadEf($this,$spread) {
 $this = $this|0;
 $spread = Math_fround($spread);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI11setCallbackEPF11FMOD_RESULTP12FMOD_CHANNEL25FMOD_CHANNEL_CALLBACKTYPEPvS5_E($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 HEAP32[$0>>2] = $callback;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI15setChannelGroupEPNS_12ChannelGroupE($this,$channelgroup) {
 $this = $this|0;
 $channelgroup = $channelgroup|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($channelgroup)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0$i = 0;
 } else {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$channelgroup)|0);
  $$0$i = $3;
 }
 $4 = (($this) + 68|0);
 HEAP32[$4>>2] = $$0$i;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI8setDelayE14FMOD_DELAYTYPEjj($this,$delaytype,$delay_hi,$delay_lo) {
 $this = $this|0;
 $delaytype = $delaytype|0;
 $delay_hi = $delay_hi|0;
 $delay_lo = $delay_lo|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI12setFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 HEAPF32[$0>>2] = $frequency;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI7setModeEj($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $mode & 3;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return 0;
 }
 $2 = (($this) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & -4;
 $5 = $4 | $0;
 HEAP32[$2>>2] = $5;
 $6 = (($this) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $mode & 2;
 $9 = ($8|0)!=(0);
 _JS_Sound_SetLoop(($7|0),($9|0));
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI7setMuteEb($this,$muted) {
 $this = $this|0;
 $muted = $muted|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = $muted&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI6setPanEf($this,$pan) {
 $this = $this|0;
 $pan = Math_fround($pan);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI9setPausedEb($this,$paused) {
 $this = $this|0;
 $paused = $paused|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 113|0);
 $1 = $paused&1;
 HEAP8[$0>>0] = $1;
 $2 = (($this) + 116|0);
 $3 = HEAP32[$2>>2]|0;
 _JS_Sound_SetPaused(($3|0),($paused|0));
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI11setPositionEjj($this,$position,$timeunit) {
 $this = $this|0;
 $position = $position|0;
 $timeunit = $timeunit|0;
 var $$0 = 0, $$position = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0.0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 if ((($timeunit|0) == 1)) {
  $25 = (+_emscripten_get_now());
  $26 = $25 * 1.0E+6;
  $27 = (~~$26)>>>0;
  $28 = +Math_abs($26) >= 1.0 ? $26 > 0.0 ? (Math_min(+Math_floor($26 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($26 - +(~~$26 >>> 0)) / 4294967296.0) >>> 0 : 0;
  $29 = (__Z14GetProfileTimey($27,$28)|0);
  $30 = tempRet0;
  $31 = (+($29>>>0)) + (4294967296.0*(+($30>>>0)));
  $32 = (+($position>>>0));
  $33 = $32 * 48.0;
  $34 = $31 - $33;
  $35 = (~~$34)>>>0;
  $36 = +Math_abs($34) >= 1.0 ? $34 > 0.0 ? (Math_min(+Math_floor($34 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($34 - +(~~$34 >>> 0)) / 4294967296.0) >>> 0 : 0;
  $37 = (($this) + 88|0);
  $38 = $37;
  $39 = $38;
  HEAP32[$39>>2] = $35;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $36;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($timeunit|0) == 2)) {
  $0 = (($this) + 96|0);
  $1 = $0;
  $2 = $1;
  $3 = HEAP32[$2>>2]|0;
  $4 = (($1) + 4)|0;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (0)>($6>>>0);
  $8 = (0)==($6|0);
  $9 = ($position>>>0)>($3>>>0);
  $10 = $8 & $9;
  $11 = $7 | $10;
  $$position = $11 ? $3 : $position;
  $12 = (+_emscripten_get_now());
  $13 = $12 * 1.0E+6;
  $14 = (~~$13)>>>0;
  $15 = +Math_abs($13) >= 1.0 ? $13 > 0.0 ? (Math_min(+Math_floor($13 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($13 - +(~~$13 >>> 0)) / 4294967296.0) >>> 0 : 0;
  $16 = (__Z14GetProfileTimey($14,$15)|0);
  $17 = tempRet0;
  $18 = (_i64Subtract(($16|0),($17|0),($$position|0),0)|0);
  $19 = tempRet0;
  $20 = (($this) + 88|0);
  $21 = $20;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $23 = (($21) + 4)|0;
  $24 = $23;
  HEAP32[$24>>2] = $19;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$vararg_buffer2>>2] = 762600;
  $vararg_ptr1 = (($vararg_buffer2) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 740;
  (_printf((762472|0),($vararg_buffer2|0))|0);
  HEAP32[$vararg_buffer2>>2] = 37;
  $vararg_ptr5 = (($vararg_buffer2) + 4|0);
  HEAP32[$vararg_ptr5>>2] = 762600;
  (_printf((762528|0),($vararg_buffer2|0))|0);
  $$0 = 37;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN4FMOD8ChannelI11setPriorityEi($this,$priority) {
 $this = $this|0;
 $priority = $priority|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI19setReverbPropertiesEPK29FMOD_REVERB_CHANNELPROPERTIES($this,$props) {
 $this = $this|0;
 $props = $props|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD8ChannelI11setUserDataEPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $userdata;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI8addInputEPNS_3DSPEPPNS_13DSPConnectionE($this,$target,$connection) {
 $this = $this|0;
 $target = $target|0;
 $connection = $connection|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762616;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD4DSPI13disconnectAllEbb($this,$inputs,$outputs) {
 $this = $this|0;
 $inputs = $inputs|0;
 $outputs = $outputs|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI9getActiveEPb($this,$active) {
 $this = $this|0;
 $active = $active|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$active>>0] = 0;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI9getBypassEPb($this,$bypass) {
 $this = $this|0;
 $bypass = $bypass|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$bypass>>0] = 0;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI7getInfoEPcPjPiS3_S3_($this,$name,$version,$channels,$configwidth,$configheight) {
 $this = $this|0;
 $name = $name|0;
 $version = $version|0;
 $channels = $channels|0;
 $configwidth = $configwidth|0;
 $configheight = $configheight|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762632;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD4DSPI8getInputEiPPNS_3DSPEPPNS_13DSPConnectionE($this,$index,$input,$inputconnection) {
 $this = $this|0;
 $index = $index|0;
 $input = $input|0;
 $inputconnection = $inputconnection|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762640;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD4DSPI12getNumInputsEPi($this,$numinputs) {
 $this = $this|0;
 $numinputs = $numinputs|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762656;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD4DSPI9getOutputEiPPNS_3DSPEPPNS_13DSPConnectionE($this,$index,$output,$outputconnection) {
 $this = $this|0;
 $index = $index|0;
 $output = $output|0;
 $outputconnection = $outputconnection|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762672;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD4DSPI15getSystemObjectEPPNS_6SystemE($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762392;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD4DSPI11getUserDataEPPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$userdata>>2] = $1;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 208|0);
 (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE7ReleaseEPS2_($1,$this)|0);
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI6removeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI9setActiveEb($this,$active) {
 $this = $this|0;
 $active = $active|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI9setBypassEb($this,$bypass) {
 $this = $this|0;
 $bypass = $bypass|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI12setParameterEif($this,$index,$value) {
 $this = $this|0;
 $index = $index|0;
 $value = Math_fround($value);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD4DSPI11setUserDataEPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762456;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD7ReverbI7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 256|0);
 (__ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE7ReleaseEPS2_($1,$this)|0);
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7ReverbI15set3DAttributesEPK11FMOD_VECTORff($this,$pos,$mindistance,$maxdistance) {
 $this = $this|0;
 $pos = $pos|0;
 $mindistance = Math_fround($mindistance);
 $maxdistance = Math_fround($maxdistance);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7ReverbI9setActiveEb($this,$active) {
 $this = $this|0;
 $active = $active|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7ReverbI13setPropertiesEPK22FMOD_REVERB_PROPERTIES($this,$prop) {
 $this = $this|0;
 $prop = $prop|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD6SoundI7getModeEPj($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$mode>>2] = 0;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD6SoundI15getNumSubSoundsEPi($this,$numsubsounds) {
 $this = $this|0;
 $numsubsounds = $numsubsounds|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$numsubsounds>>2] = 0;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD6SoundI12getOpenStateEP14FMOD_OPENSTATEPjPbS4_($this,$openstate,$percentbuffered,$starving,$diskbusy) {
 $this = $this|0;
 $openstate = $openstate|0;
 $percentbuffered = $percentbuffered|0;
 $starving = $starving|0;
 $diskbusy = $diskbusy|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($openstate|0)==(0|0);
 if (!($0)) {
  HEAP32[$openstate>>2] = 0;
 }
 $1 = ($percentbuffered|0)==(0|0);
 if (!($1)) {
  HEAP32[$percentbuffered>>2] = 100;
 }
 $2 = ($starving|0)==(0|0);
 if (!($2)) {
  HEAP8[$starving>>0] = 0;
 }
 $3 = ($diskbusy|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 0;
 }
 HEAP8[$diskbusy>>0] = 0;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD6SoundI11getSubSoundEiPPNS_5SoundE($this,$index,$subsound) {
 $this = $this|0;
 $index = $index|0;
 $subsound = $subsound|0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 78;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762688;
 (_printf((762256|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return 78;
}
function __ZN4FMOD6SoundI11getUserDataEPPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$userdata>>2] = $1;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD6SoundI7releaseEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = (($this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if (!($3)) {
  $5 = $2;
  while(1) {
   $4 = HEAP32[$5>>2]|0;
   $6 = (($4) + 116|0);
   $7 = HEAP32[$6>>2]|0;
   _JS_Sound_Stop(($7|0));
   __ZN4FMOD8ChannelI11EndCallbackEv($4);
   $8 = HEAP32[$1>>2]|0;
   $9 = ($8|0)==($0|0);
   if ($9) {
    break;
   } else {
    $5 = $8;
   }
  }
 }
 $10 = (($this) + 320|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  (_JS_Sound_ReleaseInstance(($11|0))|0);
 }
 HEAP32[$10>>2] = 0;
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 160|0);
 (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE7ReleaseEPS2_($14,$this)|0);
 STACKTOP = sp;return 0;
}
function __ZN4FMOD6SoundI7setModeEj($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = $mode;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD6SoundI11setUserDataEPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $userdata;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI5closeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI18createChannelGroupEPKcPPNS_12ChannelGroupE($this,$name,$handle) {
 $this = $this|0;
 $name = $name|0;
 $handle = $handle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 112|0);
 $1 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE7GetFreeEi($0,-1)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 36;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 762776;
  (_printf((762704|0),($vararg_buffer|0))|0);
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (($1) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP32[$handle>>2] = $4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN4FMOD7SystemI9createDSPEP20FMOD_DSP_DESCRIPTIONPPNS_3DSPE($this,$desc,$dsp) {
 $this = $this|0;
 $desc = $desc|0;
 $dsp = $dsp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 208|0);
 $1 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE7GetFreeEi($0,-1)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 37;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 762800;
  (_printf((762528|0),($vararg_buffer|0))|0);
  $$0 = 37;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (($1) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP32[$dsp>>2] = $4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN4FMOD7SystemI15createDSPByTypeE13FMOD_DSP_TYPEPPNS_3DSPE($this,$type,$dsp) {
 $this = $this|0;
 $type = $type|0;
 $dsp = $dsp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 208|0);
 $1 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE7GetFreeEi($0,-1)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 37;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 762816;
  (_printf((762528|0),($vararg_buffer|0))|0);
  $$0 = 37;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (($1) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP32[$dsp>>2] = $4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN4FMOD7SystemI12createReverbEPPNS_6ReverbE($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($this) + 256|0);
 $1 = (__ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE7GetFreeEi($0,-1)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 36;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 762832;
  (_printf((762704|0),($vararg_buffer|0))|0);
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (($1) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP32[$handle>>2] = $4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN4FMOD7SystemI11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOPPNS_5SoundE($this,$name,$mode,$exinfo,$handle) {
 $this = $this|0;
 $name = $name|0;
 $mode = $mode|0;
 $exinfo = $exinfo|0;
 $handle = $handle|0;
 var $$0 = 0, $$byval_copy6 = 0, $$lcssa7 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $channel$05$us = 0, $filesize = 0, $handle2 = 0;
 var $i$08 = 0, $i1$02$us = 0, $or$cond = 0, $pos$01 = 0, $read = 0, $res3$0 = 0, $res3$1 = 0, $res3$2 = 0, $userdata = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp;
 $0 = sp + 40|0;
 $1 = sp + 36|0;
 $2 = sp + 32|0;
 $3 = sp + 28|0;
 $handle2 = sp + 44|0;
 $userdata = sp + 16|0;
 $filesize = sp + 12|0;
 $4 = sp + 8|0;
 $read = sp + 20|0;
 $5 = sp + 24|0;
 $6 = (($this) + 160|0);
 $7 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE7GetFreeEi($6,-1)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP32[$$byval_copy6>>2] = 36;
  $vararg_ptr1 = (($$byval_copy6) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 762848;
  (_printf((762704|0),($$byval_copy6|0))|0);
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($7) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$handle>>2] = $10;
 $11 = (($exinfo) + 68|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($7) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = $mode & 2048;
 $15 = ($14|0)==(0);
 do {
  if ($15) {
   $21 = $mode & 256;
   $22 = ($21|0)==(0);
   if (!($22)) {
    $23 = (($exinfo) + 44|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0|0);
    if (!($25)) {
     $26 = (($exinfo) + 4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = HEAP32[628512>>2]|0;
     HEAP32[$0>>2] = $28;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($27,16,$$byval_copy6,0,762864,1367)|0);
     $30 = HEAP32[$26>>2]|0;
     $31 = ($30|0)==(0);
     if ($31) {
      $$pre = (($exinfo) + 12|0);
      $$lcssa7 = 0;$$pre$phiZ2D = $$pre;
     } else {
      $32 = (($exinfo) + 48|0);
      $33 = (($exinfo) + 12|0);
      $35 = $30;$37 = 16384;$i$08 = 0;
      while(1) {
       $34 = (($35) - ($i$08))|0;
       $36 = ($34>>>0)<($37>>>0);
       $38 = $36 ? $34 : $37;
       $39 = HEAP32[$23>>2]|0;
       $40 = HEAP32[$handle>>2]|0;
       $41 = (($29) + ($i$08)|0);
       (FUNCTION_TABLE_iiii[$39 & 2047]($40,$41,$38)|0);
       $42 = HEAP32[$32>>2]|0;
       $43 = HEAP32[$handle>>2]|0;
       $44 = (($38) + ($i$08))|0;
       $45 = HEAP32[$33>>2]|0;
       $46 = $45 << 2;
       $47 = (($44>>>0) / ($46>>>0))&-1;
       (FUNCTION_TABLE_iiiii[$42 & 511]($43,0,$47,2)|0);
       $48 = HEAP32[$26>>2]|0;
       $49 = ($44>>>0)<($48>>>0);
       if ($49) {
        $35 = $48;$37 = $38;$i$08 = $44;
       } else {
        $$lcssa7 = $48;$$pre$phiZ2D = $33;
        break;
       }
      }
     }
     $50 = HEAP32[628512>>2]|0;
     HEAP32[$1>>2] = $50;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
     $51 = (__Z15malloc_internaljj10MemLabelIdiPKci($$lcssa7,16,$$byval_copy6,0,762864,1376)|0);
     $52 = HEAP32[$26>>2]|0;
     $53 = HEAP32[$$pre$phiZ2D>>2]|0;
     $54 = $53 << 2;
     $55 = (($52>>>0) / ($54>>>0))&-1;
     $56 = ($53|0)<(1);
     $57 = ($55|0)==(0);
     $or$cond = $56 | $57;
     if (!($or$cond)) {
      $channel$05$us = 0;
      while(1) {
       $65 = Math_imul($channel$05$us, $55)|0;
       $i1$02$us = 0;
       while(1) {
        $60 = Math_imul($53, $i1$02$us)|0;
        $61 = (($60) + ($channel$05$us))|0;
        $62 = (($29) + ($61<<2)|0);
        $63 = Math_fround(HEAPF32[$62>>2]);
        $64 = (($i1$02$us) + ($65))|0;
        $66 = (($51) + ($64<<2)|0);
        HEAPF32[$66>>2] = $63;
        $67 = (($i1$02$us) + 1)|0;
        $68 = ($67>>>0)<($55>>>0);
        if ($68) {
         $i1$02$us = $67;
        } else {
         break;
        }
       }
       $58 = (($channel$05$us) + 1)|0;
       $59 = ($58|0)<($53|0);
       if ($59) {
        $channel$05$us = $58;
       } else {
        break;
       }
      }
     }
     $69 = (($exinfo) + 16|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (_JS_Sound_Load_PCM(($53|0),($55|0),($70|0),($51|0))|0);
     $72 = (($7) + 320|0);
     HEAP32[$72>>2] = $71;
     $73 = HEAP32[628512>>2]|0;
     HEAP32[$2>>2] = $73;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($29,$$byval_copy6);
     $74 = HEAP32[628512>>2]|0;
     HEAP32[$3>>2] = $74;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($51,$$byval_copy6);
     $75 = (($7) + 56|0);
     (_strcpy(($75|0),($name|0))|0);
     break;
    }
   }
   $76 = (($exinfo) + 76|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if ($78) {
    $80 = (($this) + 328|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (FUNCTION_TABLE_iiiiii[$81 & 255]($name,0,$filesize,$handle2,$userdata)|0);
    $res3$0 = $82;
   } else {
    $79 = (FUNCTION_TABLE_iiiiii[$77 & 255]($name,0,$filesize,$handle2,$userdata)|0);
    $res3$0 = $79;
   }
   $83 = ($res3$0|0)==(0);
   if (!($83)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $84 = HEAP32[$filesize>>2]|0;
   $85 = HEAP32[628512>>2]|0;
   HEAP32[$4>>2] = $85;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
   $86 = (__Z15malloc_internaljj10MemLabelIdiPKci($84,16,$$byval_copy6,0,762864,1404)|0);
   $87 = HEAP32[$filesize>>2]|0;
   $88 = ($87|0)==(0);
   L31: do {
    if (!($88)) {
     $89 = (($exinfo) + 84|0);
     $90 = (($this) + 336|0);
     $96 = $87;$pos$01 = 0;
     while(1) {
      $91 = HEAP32[$89>>2]|0;
      $92 = ($91|0)==(0|0);
      if ($92) {
       $99 = HEAP32[$90>>2]|0;
       $100 = HEAP32[$handle2>>2]|0;
       $101 = (($86) + ($pos$01)|0);
       $102 = (($96) - ($pos$01))|0;
       $103 = HEAP32[$userdata>>2]|0;
       $104 = (FUNCTION_TABLE_iiiiii[$99 & 255]($100,$101,$102,$read,$103)|0);
       $res3$1 = $104;
      } else {
       $93 = HEAP32[$handle2>>2]|0;
       $94 = (($86) + ($pos$01)|0);
       $95 = (($96) - ($pos$01))|0;
       $97 = HEAP32[$userdata>>2]|0;
       $98 = (FUNCTION_TABLE_iiiiii[$91 & 255]($93,$94,$95,$read,$97)|0);
       $res3$1 = $98;
      }
      $105 = ($res3$1|0)==(0);
      if (!($105)) {
       $$0 = 0;
       break;
      }
      $106 = HEAP32[$read>>2]|0;
      $107 = (($106) + ($pos$01))|0;
      $108 = HEAP32[$filesize>>2]|0;
      $109 = ($107>>>0)<($108>>>0);
      if ($109) {
       $96 = $108;$pos$01 = $107;
      } else {
       break L31;
      }
     }
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $110 = (($exinfo) + 80|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($111|0)==(0|0);
   if ($112) {
    $116 = (($this) + 332|0);
    $117 = HEAP32[$116>>2]|0;
    $118 = HEAP32[$handle2>>2]|0;
    $119 = HEAP32[$userdata>>2]|0;
    $120 = (FUNCTION_TABLE_iii[$117 & 4095]($118,$119)|0);
    $res3$2 = $120;
   } else {
    $113 = HEAP32[$handle2>>2]|0;
    $114 = HEAP32[$userdata>>2]|0;
    $115 = (FUNCTION_TABLE_iii[$111 & 4095]($113,$114)|0);
    $res3$2 = $115;
   }
   $121 = ($res3$2|0)==(0);
   if ($121) {
    $122 = HEAP32[$filesize>>2]|0;
    $123 = (_JS_Sound_Load(($86|0),($122|0))|0);
    $124 = (($7) + 320|0);
    HEAP32[$124>>2] = $123;
    $125 = HEAP32[628512>>2]|0;
    HEAP32[$5>>2] = $125;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($86,$$byval_copy6);
    $126 = (($7) + 56|0);
    (_strcpy(($126|0),($name|0))|0);
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $16 = (($exinfo) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (_JS_Sound_Load(($name|0),($17|0))|0);
   $19 = (($7) + 320|0);
   HEAP32[$19>>2] = $18;
   $20 = (($7) + 56|0);
   HEAP8[$20>>0] = 0;
  }
 } while(0);
 $127 = (($7) + 312|0);
 $128 = $127;
 $129 = $128;
 HEAP32[$129>>2] = 96000;
 $130 = (($128) + 4)|0;
 $131 = $130;
 HEAP32[$131>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7SystemI9getDriverEPi($this,$driver) {
 $this = $this|0;
 $driver = $driver|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$driver>>2] = 0;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI13getDriverCapsEiPjPiP16FMOD_SPEAKERMODE($this,$id,$caps,$controlpaneloutputrate,$controlpanelspeakermode) {
 $this = $this|0;
 $id = $id|0;
 $caps = $caps|0;
 $controlpaneloutputrate = $controlpaneloutputrate|0;
 $controlpanelspeakermode = $controlpanelspeakermode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$controlpanelspeakermode>>2] = 2;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI16getDSPBufferSizeEPjPi($this,$bufferlength,$numbuffers) {
 $this = $this|0;
 $bufferlength = $bufferlength|0;
 $numbuffers = $numbuffers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bufferlength|0)==(0|0);
 if (!($0)) {
  $1 = (($this) + 44|0);
  $2 = HEAP32[$1>>2]|0;
  HEAP32[$bufferlength>>2] = $2;
 }
 $3 = ($numbuffers|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 0;
 }
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$numbuffers>>2] = $5;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI11getDSPClockEPjS1_($this,$clock_hi,$clock_lo) {
 $this = $this|0;
 $clock_hi = $clock_hi|0;
 $clock_lo = $clock_lo|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_emscripten_get_now());
 $1 = $0 * 1.0E+6;
 $2 = (~~$1)>>>0;
 $3 = +Math_abs($1) >= 1.0 ? $1 > 0.0 ? (Math_min(+Math_floor($1 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($1 - +(~~$1 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $4 = (__Z14GetProfileTimey($2,$3)|0);
 $5 = tempRet0;
 HEAP32[$clock_hi>>2] = $5;
 HEAP32[$clock_lo>>2] = $4;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI21getMasterChannelGroupEPPNS_12ChannelGroupE($this,$channelgroup) {
 $this = $this|0;
 $channelgroup = $channelgroup|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 304|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$channelgroup>>2] = $3;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI13getNumDriversEPi($this,$numdrivers) {
 $this = $this|0;
 $numdrivers = $numdrivers|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$numdrivers>>2] = 1;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($this,$samplerate,$format,$numoutputchannels,$maxinputchannels,$resamplemethod,$bits) {
 $this = $this|0;
 $samplerate = $samplerate|0;
 $format = $format|0;
 $numoutputchannels = $numoutputchannels|0;
 $maxinputchannels = $maxinputchannels|0;
 $resamplemethod = $resamplemethod|0;
 $bits = $bits|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($samplerate|0)==(0|0);
 if (!($0)) {
  HEAP32[$samplerate>>2] = 44100;
 }
 $1 = ($numoutputchannels|0)==(0|0);
 if (!($1)) {
  HEAP32[$numoutputchannels>>2] = 2;
 }
 $2 = ($maxinputchannels|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return 0;
 }
 HEAP32[$maxinputchannels>>2] = 2;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI4initEijPv($this,$maxchannels,$flags,$extradriverdata) {
 $this = $this|0;
 $maxchannels = $maxchannels|0;
 $flags = $flags|0;
 $extradriverdata = $extradriverdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 _JS_Sound_Init();
 $0 = (($this) + 64|0);
 __ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE7SetSizeEi($0,$maxchannels);
 $1 = (($this) + 112|0);
 $2 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE7GetFreeEi($1,-1)|0);
 $3 = (($this) + 304|0);
 HEAP32[$3>>2] = $2;
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$vararg_buffer>>2] = 33;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762936;
 (_printf((762872|0),($vararg_buffer|0))|0);
 $$0 = 33;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7SystemI7playDSPE17FMOD_CHANNELINDEXPNS_3DSPEbPPNS_7ChannelE($this,$channelindex,$dsp,$paused,$handle) {
 $this = $this|0;
 $channelindex = $channelindex|0;
 $dsp = $dsp|0;
 $paused = $paused|0;
 $handle = $handle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($dsp)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$dsp)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($this) + 64|0);
   $6 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE7GetFreeEi($5,-1)|0);
   $7 = ($6|0)==(0|0);
   if ($7) {
    HEAP32[$vararg_buffer2>>2] = 10;
    $vararg_ptr5 = (($vararg_buffer2) + 4|0);
    HEAP32[$vararg_ptr5>>2] = 762944;
    (_printf((762952|0),($vararg_buffer2|0))|0);
    $$0 = 10;
    STACKTOP = sp;return ($$0|0);
   } else {
    $8 = (($6) + 20|0);
    $9 = HEAP32[$8>>2]|0;
    HEAP32[$handle>>2] = $9;
    $10 = (($6) + 64|0);
    HEAP32[$10>>2] = 0;
    $11 = (($6) + 68|0);
    HEAP32[$11>>2] = 0;
    $12 = (($6) + 96|0);
    $13 = $12;
    $14 = $13;
    HEAP32[$14>>2] = 48000;
    $15 = (($13) + 4)|0;
    $16 = $15;
    HEAP32[$16>>2] = 0;
    $17 = (+_emscripten_get_now());
    $18 = $17 * 1.0E+6;
    $19 = (~~$18)>>>0;
    $20 = +Math_abs($18) >= 1.0 ? $18 > 0.0 ? (Math_min(+Math_floor($18 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($18 - +(~~$18 >>> 0)) / 4294967296.0) >>> 0 : 0;
    $21 = (__Z14GetProfileTimey($19,$20)|0);
    $22 = tempRet0;
    $23 = (($6) + 88|0);
    $24 = $23;
    $25 = $24;
    HEAP32[$25>>2] = $21;
    $26 = (($24) + 4)|0;
    $27 = $26;
    HEAP32[$27>>2] = $22;
    $28 = (($this) + 52|0);
    $29 = (($6) + 52|0);
    $30 = (($6) + 60|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($6) + 56|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 8|0);
    HEAP32[$34>>2] = $31;
    $35 = HEAP32[$32>>2]|0;
    $36 = HEAP32[$30>>2]|0;
    $37 = (($36) + 4|0);
    HEAP32[$37>>2] = $35;
    HEAP32[$32>>2] = $29;
    HEAP32[$30>>2] = $29;
    $38 = (($this) + 56|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$32>>2] = $39;
    HEAP32[$30>>2] = $28;
    $40 = HEAP32[$38>>2]|0;
    $41 = (($40) + 8|0);
    HEAP32[$41>>2] = $29;
    HEAP32[$38>>2] = $29;
    $42 = (($this) + 36|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 1)|0;
    HEAP32[$42>>2] = $44;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 762944;
 (_printf((762704|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7SystemI9playSoundE17FMOD_CHANNELINDEXPNS_5SoundEbPPNS_7ChannelE($this,$channelindex,$sound,$paused,$handle) {
 $this = $this|0;
 $channelindex = $channelindex|0;
 $sound = $sound|0;
 $paused = $paused|0;
 $handle = $handle|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($sound)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$sound)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($this) + 64|0);
   $6 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE7GetFreeEi($5,-1)|0);
   $7 = ($6|0)==(0|0);
   if ($7) {
    HEAP32[$vararg_buffer2>>2] = 10;
    $vararg_ptr5 = (($vararg_buffer2) + 4|0);
    HEAP32[$vararg_ptr5>>2] = 763024;
    (_printf((762952|0),($vararg_buffer2|0))|0);
    $$0 = 10;
    STACKTOP = sp;return ($$0|0);
   } else {
    $8 = (($6) + 20|0);
    $9 = HEAP32[$8>>2]|0;
    HEAP32[$handle>>2] = $9;
    $10 = (($3) + 44|0);
    $11 = (($6) + 40|0);
    $12 = (($6) + 48|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($6) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($15) + 8|0);
    HEAP32[$16>>2] = $13;
    $17 = HEAP32[$14>>2]|0;
    $18 = HEAP32[$12>>2]|0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = $17;
    HEAP32[$14>>2] = $11;
    HEAP32[$12>>2] = $11;
    $20 = (($3) + 48|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$14>>2] = $21;
    HEAP32[$12>>2] = $10;
    $22 = HEAP32[$20>>2]|0;
    $23 = (($22) + 8|0);
    HEAP32[$23>>2] = $11;
    HEAP32[$20>>2] = $11;
    $24 = (($3) + 36|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 1)|0;
    HEAP32[$24>>2] = $26;
    $27 = (($3) + 320|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($6) + 116|0);
    $30 = HEAP32[$29>>2]|0;
    _JS_Sound_Play(($28|0),($30|0));
    $31 = (($6) + 64|0);
    HEAP32[$31>>2] = $3;
    $32 = (($6) + 68|0);
    HEAP32[$32>>2] = 0;
    $33 = (($3) + 312|0);
    $34 = $33;
    $35 = $34;
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + 4)|0;
    $38 = $37;
    $39 = HEAP32[$38>>2]|0;
    $40 = (($6) + 96|0);
    $41 = $40;
    $42 = $41;
    HEAP32[$42>>2] = $36;
    $43 = (($41) + 4)|0;
    $44 = $43;
    HEAP32[$44>>2] = $39;
    $45 = (+_emscripten_get_now());
    $46 = $45 * 1.0E+6;
    $47 = (~~$46)>>>0;
    $48 = +Math_abs($46) >= 1.0 ? $46 > 0.0 ? (Math_min(+Math_floor($46 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($46 - +(~~$46 >>> 0)) / 4294967296.0) >>> 0 : 0;
    $49 = (__Z14GetProfileTimey($47,$48)|0);
    $50 = tempRet0;
    $51 = (($6) + 88|0);
    $52 = $51;
    $53 = $52;
    HEAP32[$53>>2] = $49;
    $54 = (($52) + 4)|0;
    $55 = $54;
    HEAP32[$55>>2] = $50;
    $56 = (($this) + 52|0);
    $57 = (($6) + 52|0);
    $58 = (($6) + 60|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($6) + 56|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($61) + 8|0);
    HEAP32[$62>>2] = $59;
    $63 = HEAP32[$60>>2]|0;
    $64 = HEAP32[$58>>2]|0;
    $65 = (($64) + 4|0);
    HEAP32[$65>>2] = $63;
    HEAP32[$60>>2] = $57;
    HEAP32[$58>>2] = $57;
    $66 = (($this) + 56|0);
    $67 = HEAP32[$66>>2]|0;
    HEAP32[$60>>2] = $67;
    HEAP32[$58>>2] = $56;
    $68 = HEAP32[$66>>2]|0;
    $69 = (($68) + 8|0);
    HEAP32[$69>>2] = $57;
    HEAP32[$66>>2] = $57;
    $70 = (($this) + 36|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($71) + 1)|0;
    HEAP32[$70>>2] = $72;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763024;
 (_printf((762704|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7SystemI7releaseEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI23set3DListenerAttributesEiPK11FMOD_VECTORS3_S3_S3_($this,$listener,$pos,$vel,$forward,$up) {
 $this = $this|0;
 $listener = $listener|0;
 $pos = $pos|0;
 $vel = $vel|0;
 $forward = $forward|0;
 $up = $up|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0.0, $11 = 0, $12 = Math_fround(0), $13 = 0.0, $14 = 0, $15 = Math_fround(0), $16 = 0.0, $17 = Math_fround(0), $18 = 0.0, $19 = 0, $2 = 0.0, $20 = Math_fround(0), $21 = 0.0, $22 = 0, $23 = Math_fround(0), $24 = 0.0, $25 = Math_fround(0), $26 = 0.0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0.0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0.0, $4 = Math_fround(0), $5 = 0.0, $6 = 0, $7 = Math_fround(0), $8 = 0.0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 308|0);
 ;HEAP32[$0+0>>2]=HEAP32[$pos+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$pos+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$pos+8>>2]|0;
 $1 = Math_fround(HEAPF32[$pos>>2]);
 $2 = +$1;
 $3 = (($pos) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = +$4;
 $6 = (($pos) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = +$7;
 _JS_Sound_SetListenerPosition((+$2),(+$5),(+$8));
 $9 = Math_fround(HEAPF32[$vel>>2]);
 $10 = +$9;
 $11 = (($vel) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = +$12;
 $14 = (($vel) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = +$15;
 _JS_Sound_SetListenerVelocity((+$10),(+$13),(+$16));
 $17 = Math_fround(HEAPF32[$forward>>2]);
 $18 = +$17;
 $19 = (($forward) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = +$20;
 $22 = (($forward) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = +$23;
 $25 = Math_fround(HEAPF32[$up>>2]);
 $26 = +$25;
 $27 = (($up) + 4|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = +$28;
 $30 = (($up) + 8|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = +$31;
 _JS_Sound_SetListenerOrientation((+$18),(+$21),(+$24),(+$26),(+$29),(+$32));
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI20set3DRolloffCallbackEPFfP12FMOD_CHANNELfE($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 HEAP32[$0>>2] = $callback;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI13set3DSettingsEfff($this,$dopplerscale,$distancefactor,$rolloffscale) {
 $this = $this|0;
 $dopplerscale = Math_fround($dopplerscale);
 $distancefactor = Math_fround($distancefactor);
 $rolloffscale = Math_fround($rolloffscale);
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI11setCallbackEPF11FMOD_RESULTP11FMOD_SYSTEM24FMOD_SYSTEM_CALLBACKTYPEPvS5_E($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 324|0);
 HEAP32[$0>>2] = $callback;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI9setDriverEi($this,$driver) {
 $this = $this|0;
 $driver = $driver|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI16setDSPBufferSizeEji($this,$bufferlength,$numbuffers) {
 $this = $this|0;
 $bufferlength = $bufferlength|0;
 $numbuffers = $numbuffers|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 HEAP32[$0>>2] = $bufferlength;
 $1 = (($this) + 48|0);
 HEAP32[$1>>2] = $numbuffers;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI13setFileSystemEPF11FMOD_RESULTPKciPjPPvS6_EPFS1_S5_S5_EPFS1_S5_S5_jS4_S5_EPFS1_S5_jS5_EPFS1_P18FMOD_ASYNCREADINFOS5_ESA_i($this,$useropen,$userclose,$userread,$userseek,$userasyncread,$userasynccancel,$blockalign) {
 $this = $this|0;
 $useropen = $useropen|0;
 $userclose = $userclose|0;
 $userread = $userread|0;
 $userseek = $userseek|0;
 $userasyncread = $userasyncread|0;
 $userasynccancel = $userasynccancel|0;
 $blockalign = $blockalign|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 328|0);
 HEAP32[$0>>2] = $useropen;
 $1 = (($this) + 332|0);
 HEAP32[$1>>2] = $userclose;
 $2 = (($this) + 336|0);
 HEAP32[$2>>2] = $userread;
 $3 = (($this) + 340|0);
 HEAP32[$3>>2] = $userseek;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI9setOutputE15FMOD_OUTPUTTYPE($this,$outputtype) {
 $this = $this|0;
 $outputtype = $outputtype|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI17setSoftwareFormatEi17FMOD_SOUND_FORMATii18FMOD_DSP_RESAMPLER($this,$samplerate,$format,$numoutputchannels,$maxinputchannels,$resamplemethod) {
 $this = $this|0;
 $samplerate = $samplerate|0;
 $format = $format|0;
 $numoutputchannels = $numoutputchannels|0;
 $maxinputchannels = $maxinputchannels|0;
 $resamplemethod = $resamplemethod|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI14setSpeakerModeE16FMOD_SPEAKERMODE($this,$speakermode) {
 $this = $this|0;
 $speakermode = $speakermode|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI19setStreamBufferSizeEjj($this,$filebuffersize,$filebuffersizetype) {
 $this = $this|0;
 $filebuffersize = $filebuffersize|0;
 $filebuffersizetype = $filebuffersizetype|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4FMOD7SystemI6updateEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE7SetSizeEi($this,$newsize) {
 $this = $this|0;
 $newsize = $newsize|0;
 var $$arith = 0, $$lcssa5 = 0, $$overflow = 0, $$pre = 0, $$pre16 = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$08 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa5 = $4;
  } else {
   $32 = $1;$6 = $4;$i$08 = 0;
   while(1) {
    $5 = (($6) + ($i$08<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $13 = $32;$33 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3671,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre16 = HEAP32[$3>>2]|0;
     $13 = $$pre;$33 = $$pre16;
    }
    $11 = (($i$08) + 1)|0;
    $12 = ($11>>>0)<($13>>>0);
    if ($12) {
     $32 = $13;$6 = $33;$i$08 = $11;
    } else {
     $$lcssa5 = $33;
     break L1;
    }
   }
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __ZdlPv($7);
   ___resumeException($14|0);
   // unreachable;
  }
 } while(0);
 $16 = ($$lcssa5|0)==(0|0);
 if (!($16)) {
  __ZdaPv($$lcssa5);
 }
 $$arith = $newsize<<2;
 $$overflow = ($newsize>>>0)>(1073741823);
 $17 = $$overflow ? -1 : $$arith;
 $18 = (__Znaj($17)|0);
 HEAP32[$3>>2] = $18;
 HEAP32[$0>>2] = $newsize;
 $19 = ($newsize|0)>(0);
 L13: do {
  if ($19) {
   $21 = $18;$i1$01 = 0;
   while(1) {
    $20 = (($21) + ($i1$01<<2)|0);
    HEAP32[$20>>2] = 0;
    $22 = (($i1$01) + 1)|0;
    $exitcond = ($22|0)==($newsize|0);
    if ($exitcond) {
     break L13;
    }
    $$pre18 = HEAP32[$3>>2]|0;
    $21 = $$pre18;$i1$01 = $22;
   }
  }
 } while(0);
 $23 = (($this) + 28|0);
 $24 = (($this) + 32|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 36|0);
 HEAP32[$25>>2] = $23;
 $26 = (($this) + 16|0);
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = $26;
 $28 = (($this) + 24|0);
 HEAP32[$28>>2] = $26;
 $29 = (($this) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 8|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 12|0);
 HEAP32[$31>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEED2Ev($this) {
 $this = $this|0;
 var $$lcssa = 0, $$pre = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $n$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa = $4;
  } else {
   $59 = $1;$6 = $4;$n$010 = 0;
   while(1) {
    $5 = (($6) + ($n$010<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $17 = $59;$60 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3671,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre14 = HEAP32[$3>>2]|0;
     $17 = $$pre;$60 = $$pre14;
    }
    $15 = (($n$010) + 1)|0;
    $16 = ($15>>>0)<($17>>>0);
    if ($16) {
     $59 = $17;$6 = $60;$n$010 = $15;
    } else {
     $$lcssa = $60;
     break L1;
    }
   }
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   __ZdlPv($7);
   $13 = HEAP32[$3>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    __ZdaPv($13);
   }
   $39 = (($this) + 28|0);
   $40 = (($this) + 36|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($39|0);
   if (!($42)) {
    $43 = (($this) + 32|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + 8|0);
    HEAP32[$45>>2] = $41;
    $46 = HEAP32[$43>>2]|0;
    $47 = HEAP32[$40>>2]|0;
    $48 = (($47) + 4|0);
    HEAP32[$48>>2] = $46;
    HEAP32[$43>>2] = $39;
    HEAP32[$40>>2] = $39;
   }
   $49 = (($this) + 16|0);
   $50 = (($this) + 24|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==($49|0);
   if ($52) {
    ___resumeException($11|0);
    // unreachable;
   }
   $53 = (($this) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 8|0);
   HEAP32[$55>>2] = $51;
   $56 = HEAP32[$53>>2]|0;
   $57 = HEAP32[$50>>2]|0;
   $58 = (($57) + 4|0);
   HEAP32[$58>>2] = $56;
   HEAP32[$53>>2] = $49;
   HEAP32[$50>>2] = $49;
   ___resumeException($11|0);
   // unreachable;
  }
 } while(0);
 $18 = ($$lcssa|0)==(0|0);
 if (!($18)) {
  __ZdaPv($$lcssa);
 }
 $19 = (($this) + 28|0);
 $20 = (($this) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($19|0);
 if (!($22)) {
  $23 = (($this) + 32|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 8|0);
  HEAP32[$25>>2] = $21;
  $26 = HEAP32[$23>>2]|0;
  $27 = HEAP32[$20>>2]|0;
  $28 = (($27) + 4|0);
  HEAP32[$28>>2] = $26;
  HEAP32[$23>>2] = $19;
  HEAP32[$20>>2] = $19;
 }
 $29 = (($this) + 16|0);
 $30 = (($this) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==($29|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 8|0);
 HEAP32[$35>>2] = $31;
 $36 = HEAP32[$33>>2]|0;
 $37 = HEAP32[$30>>2]|0;
 $38 = (($37) + 4|0);
 HEAP32[$38>>2] = $36;
 HEAP32[$33>>2] = $29;
 HEAP32[$30>>2] = $29;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE7GetFreeEi($this,$reuseindex) {
 $this = $this|0;
 $reuseindex = $reuseindex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, $p$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($reuseindex|0)==(-1);
 if ($0) {
  $6 = (($this) + 16|0);
  $7 = (($this) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($6|0);
  if ($9) {
   label = 5;
  } else {
   $10 = HEAP32[$8>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    label = 5;
   } else {
    $29 = (($this) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + -1)|0;
    HEAP32[$29>>2] = $31;
    $p$0 = $10;
   }
  }
  do {
   if ((label|0) == 5) {
    $12 = (($this) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($this) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13>>>0)<($15>>>0);
    if (!($16)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $17 = (__Znwj(128)|0);
    $18 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    invoke_vii(3352,($17|0),($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     __ZdlPv($17);
     ___resumeException($27|0);
     // unreachable;
    } else {
     $21 = HEAP32[$12>>2]|0;
     $22 = (($17) + 8|0);
     HEAP32[$22>>2] = $21;
     $23 = (($21) + 1)|0;
     HEAP32[$12>>2] = $23;
     $24 = (($this) + 40|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($25) + ($21<<2)|0);
     HEAP32[$26>>2] = $17;
     $p$0 = $17;
     break;
    }
   }
  } while(0);
  $32 = (($this) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $35 = (($this) + 28|0);
  $36 = (($p$0) + 24|0);
  $37 = (($p$0) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($p$0) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 8|0);
  HEAP32[$41>>2] = $38;
  $42 = HEAP32[$39>>2]|0;
  $43 = HEAP32[$37>>2]|0;
  $44 = (($43) + 4|0);
  HEAP32[$44>>2] = $42;
  HEAP32[$39>>2] = $36;
  HEAP32[$37>>2] = $36;
  $45 = (($this) + 32|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$39>>2] = $46;
  HEAP32[$37>>2] = $35;
  $47 = HEAP32[$45>>2]|0;
  $48 = (($47) + 8|0);
  HEAP32[$48>>2] = $36;
  HEAP32[$45>>2] = $36;
  $p$1 = $p$0;
 } else {
  $1 = (($this) + 40|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($reuseindex<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $p$1 = $4;
  }
 }
 $49 = (($p$1) + 16|0);
 HEAP8[$49>>0] = 0;
 $50 = HEAP32[$this>>2]|0;
 $51 = (($50) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($p$1) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($p$1) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$55>>2] = $57;
 $58 = $52 << 28;
 $59 = $54 << 16;
 $60 = $59 & 268369920;
 $61 = $60 | $58;
 $62 = $57 & 65535;
 $63 = $61 | $62;
 $64 = $63;
 $65 = (($p$1) + 20|0);
 HEAP32[$65>>2] = $64;
 $$0 = $p$1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($handle)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $handle;
 $3 = $2 >>> 16;
 $4 = $3 & 4095;
 $5 = (($0) + 104|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($8) + 16|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = $2 & 65535;
 $14 = (($8) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($13|0);
 $$ = $16 ? $8 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE5CheckEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE7ReleaseEPS2_($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($p|0)==(0|0);
 if ($0) {
  HEAP32[$vararg_buffer>>2] = 36;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 763112;
  (_printf((763040|0),($vararg_buffer|0))|0);
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 } else {
  $1 = (($p) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($this) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($2<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$7>>2] = $9;
  $10 = (($6) + 16|0);
  HEAP8[$10>>0] = 1;
  $11 = (($this) + 16|0);
  $12 = (($6) + 24|0);
  $13 = (($6) + 32|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($6) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  HEAP32[$17>>2] = $14;
  $18 = HEAP32[$15>>2]|0;
  $19 = HEAP32[$13>>2]|0;
  $20 = (($19) + 4|0);
  HEAP32[$20>>2] = $18;
  HEAP32[$15>>2] = $12;
  HEAP32[$13>>2] = $12;
  $21 = (($this) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$13>>2] = $11;
  $23 = HEAP32[$21>>2]|0;
  $24 = (($23) + 8|0);
  HEAP32[$24>>2] = $12;
  HEAP32[$21>>2] = $12;
  $25 = (($this) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + -1)|0;
  HEAP32[$25>>2] = $27;
  $28 = (($this) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 1)|0;
  HEAP32[$28>>2] = $30;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE7SetSizeEi($this,$newsize) {
 $this = $this|0;
 $newsize = $newsize|0;
 var $$arith = 0, $$lcssa5 = 0, $$overflow = 0, $$pre = 0, $$pre16 = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$08 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa5 = $4;
  } else {
   $32 = $1;$6 = $4;$i$08 = 0;
   while(1) {
    $5 = (($6) + ($i$08<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $13 = $32;$33 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3672,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre16 = HEAP32[$3>>2]|0;
     $13 = $$pre;$33 = $$pre16;
    }
    $11 = (($i$08) + 1)|0;
    $12 = ($11>>>0)<($13>>>0);
    if ($12) {
     $32 = $13;$6 = $33;$i$08 = $11;
    } else {
     $$lcssa5 = $33;
     break L1;
    }
   }
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __ZdlPv($7);
   ___resumeException($14|0);
   // unreachable;
  }
 } while(0);
 $16 = ($$lcssa5|0)==(0|0);
 if (!($16)) {
  __ZdaPv($$lcssa5);
 }
 $$arith = $newsize<<2;
 $$overflow = ($newsize>>>0)>(1073741823);
 $17 = $$overflow ? -1 : $$arith;
 $18 = (__Znaj($17)|0);
 HEAP32[$3>>2] = $18;
 HEAP32[$0>>2] = $newsize;
 $19 = ($newsize|0)>(0);
 L13: do {
  if ($19) {
   $21 = $18;$i1$01 = 0;
   while(1) {
    $20 = (($21) + ($i1$01<<2)|0);
    HEAP32[$20>>2] = 0;
    $22 = (($i1$01) + 1)|0;
    $exitcond = ($22|0)==($newsize|0);
    if ($exitcond) {
     break L13;
    }
    $$pre18 = HEAP32[$3>>2]|0;
    $21 = $$pre18;$i1$01 = $22;
   }
  }
 } while(0);
 $23 = (($this) + 28|0);
 $24 = (($this) + 32|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 36|0);
 HEAP32[$25>>2] = $23;
 $26 = (($this) + 16|0);
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = $26;
 $28 = (($this) + 24|0);
 HEAP32[$28>>2] = $26;
 $29 = (($this) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 8|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 12|0);
 HEAP32[$31>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEED2Ev($this) {
 $this = $this|0;
 var $$lcssa = 0, $$pre = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $n$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa = $4;
  } else {
   $59 = $1;$6 = $4;$n$010 = 0;
   while(1) {
    $5 = (($6) + ($n$010<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $17 = $59;$60 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3672,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre14 = HEAP32[$3>>2]|0;
     $17 = $$pre;$60 = $$pre14;
    }
    $15 = (($n$010) + 1)|0;
    $16 = ($15>>>0)<($17>>>0);
    if ($16) {
     $59 = $17;$6 = $60;$n$010 = $15;
    } else {
     $$lcssa = $60;
     break L1;
    }
   }
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   __ZdlPv($7);
   $13 = HEAP32[$3>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    __ZdaPv($13);
   }
   $39 = (($this) + 28|0);
   $40 = (($this) + 36|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($39|0);
   if (!($42)) {
    $43 = (($this) + 32|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + 8|0);
    HEAP32[$45>>2] = $41;
    $46 = HEAP32[$43>>2]|0;
    $47 = HEAP32[$40>>2]|0;
    $48 = (($47) + 4|0);
    HEAP32[$48>>2] = $46;
    HEAP32[$43>>2] = $39;
    HEAP32[$40>>2] = $39;
   }
   $49 = (($this) + 16|0);
   $50 = (($this) + 24|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==($49|0);
   if ($52) {
    ___resumeException($11|0);
    // unreachable;
   }
   $53 = (($this) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 8|0);
   HEAP32[$55>>2] = $51;
   $56 = HEAP32[$53>>2]|0;
   $57 = HEAP32[$50>>2]|0;
   $58 = (($57) + 4|0);
   HEAP32[$58>>2] = $56;
   HEAP32[$53>>2] = $49;
   HEAP32[$50>>2] = $49;
   ___resumeException($11|0);
   // unreachable;
  }
 } while(0);
 $18 = ($$lcssa|0)==(0|0);
 if (!($18)) {
  __ZdaPv($$lcssa);
 }
 $19 = (($this) + 28|0);
 $20 = (($this) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($19|0);
 if (!($22)) {
  $23 = (($this) + 32|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 8|0);
  HEAP32[$25>>2] = $21;
  $26 = HEAP32[$23>>2]|0;
  $27 = HEAP32[$20>>2]|0;
  $28 = (($27) + 4|0);
  HEAP32[$28>>2] = $26;
  HEAP32[$23>>2] = $19;
  HEAP32[$20>>2] = $19;
 }
 $29 = (($this) + 16|0);
 $30 = (($this) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==($29|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 8|0);
 HEAP32[$35>>2] = $31;
 $36 = HEAP32[$33>>2]|0;
 $37 = HEAP32[$30>>2]|0;
 $38 = (($37) + 4|0);
 HEAP32[$38>>2] = $36;
 HEAP32[$33>>2] = $29;
 HEAP32[$30>>2] = $29;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE7GetFreeEi($this,$reuseindex) {
 $this = $this|0;
 $reuseindex = $reuseindex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, $p$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($reuseindex|0)==(-1);
 if ($0) {
  $6 = (($this) + 16|0);
  $7 = (($this) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($6|0);
  if ($9) {
   label = 5;
  } else {
   $10 = HEAP32[$8>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    label = 5;
   } else {
    $29 = (($this) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + -1)|0;
    HEAP32[$29>>2] = $31;
    $p$0 = $10;
   }
  }
  do {
   if ((label|0) == 5) {
    $12 = (($this) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($this) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13>>>0)<($15>>>0);
    if (!($16)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $17 = (__Znwj(84)|0);
    $18 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    invoke_vii(3353,($17|0),($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     __ZdlPv($17);
     ___resumeException($27|0);
     // unreachable;
    } else {
     $21 = HEAP32[$12>>2]|0;
     $22 = (($17) + 8|0);
     HEAP32[$22>>2] = $21;
     $23 = (($21) + 1)|0;
     HEAP32[$12>>2] = $23;
     $24 = (($this) + 40|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($25) + ($21<<2)|0);
     HEAP32[$26>>2] = $17;
     $p$0 = $17;
     break;
    }
   }
  } while(0);
  $32 = (($this) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $35 = (($this) + 28|0);
  $36 = (($p$0) + 24|0);
  $37 = (($p$0) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($p$0) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 8|0);
  HEAP32[$41>>2] = $38;
  $42 = HEAP32[$39>>2]|0;
  $43 = HEAP32[$37>>2]|0;
  $44 = (($43) + 4|0);
  HEAP32[$44>>2] = $42;
  HEAP32[$39>>2] = $36;
  HEAP32[$37>>2] = $36;
  $45 = (($this) + 32|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$39>>2] = $46;
  HEAP32[$37>>2] = $35;
  $47 = HEAP32[$45>>2]|0;
  $48 = (($47) + 8|0);
  HEAP32[$48>>2] = $36;
  HEAP32[$45>>2] = $36;
  $p$1 = $p$0;
 } else {
  $1 = (($this) + 40|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($reuseindex<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $p$1 = $4;
  }
 }
 $49 = (($p$1) + 16|0);
 HEAP8[$49>>0] = 0;
 $50 = HEAP32[$this>>2]|0;
 $51 = (($50) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($p$1) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($p$1) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$55>>2] = $57;
 $58 = $52 << 28;
 $59 = $54 << 16;
 $60 = $59 & 268369920;
 $61 = $60 | $58;
 $62 = $57 & 65535;
 $63 = $61 | $62;
 $64 = $63;
 $65 = (($p$1) + 20|0);
 HEAP32[$65>>2] = $64;
 $$0 = $p$1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($handle)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $handle;
 $3 = $2 >>> 16;
 $4 = $3 & 4095;
 $5 = (($0) + 152|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($8) + 16|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = $2 & 65535;
 $14 = (($8) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($13|0);
 $$ = $16 ? $8 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE5CheckEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE7ReleaseEPS2_($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($p|0)==(0|0);
 if ($0) {
  HEAP32[$vararg_buffer>>2] = 36;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 763112;
  (_printf((763040|0),($vararg_buffer|0))|0);
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 } else {
  $1 = (($p) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($this) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($2<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$7>>2] = $9;
  $10 = (($6) + 16|0);
  HEAP8[$10>>0] = 1;
  $11 = (($this) + 16|0);
  $12 = (($6) + 24|0);
  $13 = (($6) + 32|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($6) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  HEAP32[$17>>2] = $14;
  $18 = HEAP32[$15>>2]|0;
  $19 = HEAP32[$13>>2]|0;
  $20 = (($19) + 4|0);
  HEAP32[$20>>2] = $18;
  HEAP32[$15>>2] = $12;
  HEAP32[$13>>2] = $12;
  $21 = (($this) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$13>>2] = $11;
  $23 = HEAP32[$21>>2]|0;
  $24 = (($23) + 8|0);
  HEAP32[$24>>2] = $12;
  HEAP32[$21>>2] = $12;
  $25 = (($this) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + -1)|0;
  HEAP32[$25>>2] = $27;
  $28 = (($this) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 1)|0;
  HEAP32[$28>>2] = $30;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE7SetSizeEi($this,$newsize) {
 $this = $this|0;
 $newsize = $newsize|0;
 var $$arith = 0, $$lcssa5 = 0, $$overflow = 0, $$pre = 0, $$pre16 = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$08 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa5 = $4;
  } else {
   $32 = $1;$6 = $4;$i$08 = 0;
   while(1) {
    $5 = (($6) + ($i$08<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $13 = $32;$33 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3673,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre16 = HEAP32[$3>>2]|0;
     $13 = $$pre;$33 = $$pre16;
    }
    $11 = (($i$08) + 1)|0;
    $12 = ($11>>>0)<($13>>>0);
    if ($12) {
     $32 = $13;$6 = $33;$i$08 = $11;
    } else {
     $$lcssa5 = $33;
     break L1;
    }
   }
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __ZdlPv($7);
   ___resumeException($14|0);
   // unreachable;
  }
 } while(0);
 $16 = ($$lcssa5|0)==(0|0);
 if (!($16)) {
  __ZdaPv($$lcssa5);
 }
 $$arith = $newsize<<2;
 $$overflow = ($newsize>>>0)>(1073741823);
 $17 = $$overflow ? -1 : $$arith;
 $18 = (__Znaj($17)|0);
 HEAP32[$3>>2] = $18;
 HEAP32[$0>>2] = $newsize;
 $19 = ($newsize|0)>(0);
 L13: do {
  if ($19) {
   $21 = $18;$i1$01 = 0;
   while(1) {
    $20 = (($21) + ($i1$01<<2)|0);
    HEAP32[$20>>2] = 0;
    $22 = (($i1$01) + 1)|0;
    $exitcond = ($22|0)==($newsize|0);
    if ($exitcond) {
     break L13;
    }
    $$pre18 = HEAP32[$3>>2]|0;
    $21 = $$pre18;$i1$01 = $22;
   }
  }
 } while(0);
 $23 = (($this) + 28|0);
 $24 = (($this) + 32|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 36|0);
 HEAP32[$25>>2] = $23;
 $26 = (($this) + 16|0);
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = $26;
 $28 = (($this) + 24|0);
 HEAP32[$28>>2] = $26;
 $29 = (($this) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 8|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 12|0);
 HEAP32[$31>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEED2Ev($this) {
 $this = $this|0;
 var $$lcssa = 0, $$pre = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $n$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa = $4;
  } else {
   $59 = $1;$6 = $4;$n$010 = 0;
   while(1) {
    $5 = (($6) + ($n$010<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $17 = $59;$60 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3673,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre14 = HEAP32[$3>>2]|0;
     $17 = $$pre;$60 = $$pre14;
    }
    $15 = (($n$010) + 1)|0;
    $16 = ($15>>>0)<($17>>>0);
    if ($16) {
     $59 = $17;$6 = $60;$n$010 = $15;
    } else {
     $$lcssa = $60;
     break L1;
    }
   }
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   __ZdlPv($7);
   $13 = HEAP32[$3>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    __ZdaPv($13);
   }
   $39 = (($this) + 28|0);
   $40 = (($this) + 36|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($39|0);
   if (!($42)) {
    $43 = (($this) + 32|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + 8|0);
    HEAP32[$45>>2] = $41;
    $46 = HEAP32[$43>>2]|0;
    $47 = HEAP32[$40>>2]|0;
    $48 = (($47) + 4|0);
    HEAP32[$48>>2] = $46;
    HEAP32[$43>>2] = $39;
    HEAP32[$40>>2] = $39;
   }
   $49 = (($this) + 16|0);
   $50 = (($this) + 24|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==($49|0);
   if ($52) {
    ___resumeException($11|0);
    // unreachable;
   }
   $53 = (($this) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 8|0);
   HEAP32[$55>>2] = $51;
   $56 = HEAP32[$53>>2]|0;
   $57 = HEAP32[$50>>2]|0;
   $58 = (($57) + 4|0);
   HEAP32[$58>>2] = $56;
   HEAP32[$53>>2] = $49;
   HEAP32[$50>>2] = $49;
   ___resumeException($11|0);
   // unreachable;
  }
 } while(0);
 $18 = ($$lcssa|0)==(0|0);
 if (!($18)) {
  __ZdaPv($$lcssa);
 }
 $19 = (($this) + 28|0);
 $20 = (($this) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($19|0);
 if (!($22)) {
  $23 = (($this) + 32|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 8|0);
  HEAP32[$25>>2] = $21;
  $26 = HEAP32[$23>>2]|0;
  $27 = HEAP32[$20>>2]|0;
  $28 = (($27) + 4|0);
  HEAP32[$28>>2] = $26;
  HEAP32[$23>>2] = $19;
  HEAP32[$20>>2] = $19;
 }
 $29 = (($this) + 16|0);
 $30 = (($this) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==($29|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 8|0);
 HEAP32[$35>>2] = $31;
 $36 = HEAP32[$33>>2]|0;
 $37 = HEAP32[$30>>2]|0;
 $38 = (($37) + 4|0);
 HEAP32[$38>>2] = $36;
 HEAP32[$33>>2] = $29;
 HEAP32[$30>>2] = $29;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE7GetFreeEi($this,$reuseindex) {
 $this = $this|0;
 $reuseindex = $reuseindex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, $p$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($reuseindex|0)==(-1);
 if ($0) {
  $6 = (($this) + 16|0);
  $7 = (($this) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($6|0);
  if ($9) {
   label = 5;
  } else {
   $10 = HEAP32[$8>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    label = 5;
   } else {
    $29 = (($this) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + -1)|0;
    HEAP32[$29>>2] = $31;
    $p$0 = $10;
   }
  }
  do {
   if ((label|0) == 5) {
    $12 = (($this) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($this) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13>>>0)<($15>>>0);
    if (!($16)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $17 = (__Znwj(328)|0);
    $18 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    invoke_vii(3354,($17|0),($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     __ZdlPv($17);
     ___resumeException($27|0);
     // unreachable;
    } else {
     $21 = HEAP32[$12>>2]|0;
     $22 = (($17) + 8|0);
     HEAP32[$22>>2] = $21;
     $23 = (($21) + 1)|0;
     HEAP32[$12>>2] = $23;
     $24 = (($this) + 40|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($25) + ($21<<2)|0);
     HEAP32[$26>>2] = $17;
     $p$0 = $17;
     break;
    }
   }
  } while(0);
  $32 = (($this) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $35 = (($this) + 28|0);
  $36 = (($p$0) + 24|0);
  $37 = (($p$0) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($p$0) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 8|0);
  HEAP32[$41>>2] = $38;
  $42 = HEAP32[$39>>2]|0;
  $43 = HEAP32[$37>>2]|0;
  $44 = (($43) + 4|0);
  HEAP32[$44>>2] = $42;
  HEAP32[$39>>2] = $36;
  HEAP32[$37>>2] = $36;
  $45 = (($this) + 32|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$39>>2] = $46;
  HEAP32[$37>>2] = $35;
  $47 = HEAP32[$45>>2]|0;
  $48 = (($47) + 8|0);
  HEAP32[$48>>2] = $36;
  HEAP32[$45>>2] = $36;
  $p$1 = $p$0;
 } else {
  $1 = (($this) + 40|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($reuseindex<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $p$1 = $4;
  }
 }
 $49 = (($p$1) + 16|0);
 HEAP8[$49>>0] = 0;
 $50 = HEAP32[$this>>2]|0;
 $51 = (($50) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($p$1) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($p$1) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$55>>2] = $57;
 $58 = $52 << 28;
 $59 = $54 << 16;
 $60 = $59 & 268369920;
 $61 = $60 | $58;
 $62 = $57 & 65535;
 $63 = $61 | $62;
 $64 = $63;
 $65 = (($p$1) + 20|0);
 HEAP32[$65>>2] = $64;
 $$0 = $p$1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($handle)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $handle;
 $3 = $2 >>> 16;
 $4 = $3 & 4095;
 $5 = (($0) + 200|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($8) + 16|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = $2 & 65535;
 $14 = (($8) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($13|0);
 $$ = $16 ? $8 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE5CheckEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE7ReleaseEPS2_($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($p|0)==(0|0);
 if ($0) {
  HEAP32[$vararg_buffer>>2] = 36;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 763112;
  (_printf((763040|0),($vararg_buffer|0))|0);
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 } else {
  $1 = (($p) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($this) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($2<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$7>>2] = $9;
  $10 = (($6) + 16|0);
  HEAP8[$10>>0] = 1;
  $11 = (($this) + 16|0);
  $12 = (($6) + 24|0);
  $13 = (($6) + 32|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($6) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  HEAP32[$17>>2] = $14;
  $18 = HEAP32[$15>>2]|0;
  $19 = HEAP32[$13>>2]|0;
  $20 = (($19) + 4|0);
  HEAP32[$20>>2] = $18;
  HEAP32[$15>>2] = $12;
  HEAP32[$13>>2] = $12;
  $21 = (($this) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$13>>2] = $11;
  $23 = HEAP32[$21>>2]|0;
  $24 = (($23) + 8|0);
  HEAP32[$24>>2] = $12;
  HEAP32[$21>>2] = $12;
  $25 = (($this) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + -1)|0;
  HEAP32[$25>>2] = $27;
  $28 = (($this) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 1)|0;
  HEAP32[$28>>2] = $30;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE7SetSizeEi($this,$newsize) {
 $this = $this|0;
 $newsize = $newsize|0;
 var $$arith = 0, $$lcssa5 = 0, $$overflow = 0, $$pre = 0, $$pre16 = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$08 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa5 = $4;
  } else {
   $32 = $1;$6 = $4;$i$08 = 0;
   while(1) {
    $5 = (($6) + ($i$08<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $13 = $32;$33 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3674,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre16 = HEAP32[$3>>2]|0;
     $13 = $$pre;$33 = $$pre16;
    }
    $11 = (($i$08) + 1)|0;
    $12 = ($11>>>0)<($13>>>0);
    if ($12) {
     $32 = $13;$6 = $33;$i$08 = $11;
    } else {
     $$lcssa5 = $33;
     break L1;
    }
   }
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __ZdlPv($7);
   ___resumeException($14|0);
   // unreachable;
  }
 } while(0);
 $16 = ($$lcssa5|0)==(0|0);
 if (!($16)) {
  __ZdaPv($$lcssa5);
 }
 $$arith = $newsize<<2;
 $$overflow = ($newsize>>>0)>(1073741823);
 $17 = $$overflow ? -1 : $$arith;
 $18 = (__Znaj($17)|0);
 HEAP32[$3>>2] = $18;
 HEAP32[$0>>2] = $newsize;
 $19 = ($newsize|0)>(0);
 L13: do {
  if ($19) {
   $21 = $18;$i1$01 = 0;
   while(1) {
    $20 = (($21) + ($i1$01<<2)|0);
    HEAP32[$20>>2] = 0;
    $22 = (($i1$01) + 1)|0;
    $exitcond = ($22|0)==($newsize|0);
    if ($exitcond) {
     break L13;
    }
    $$pre18 = HEAP32[$3>>2]|0;
    $21 = $$pre18;$i1$01 = $22;
   }
  }
 } while(0);
 $23 = (($this) + 28|0);
 $24 = (($this) + 32|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 36|0);
 HEAP32[$25>>2] = $23;
 $26 = (($this) + 16|0);
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = $26;
 $28 = (($this) + 24|0);
 HEAP32[$28>>2] = $26;
 $29 = (($this) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 8|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 12|0);
 HEAP32[$31>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEED2Ev($this) {
 $this = $this|0;
 var $$lcssa = 0, $$pre = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $n$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa = $4;
  } else {
   $59 = $1;$6 = $4;$n$010 = 0;
   while(1) {
    $5 = (($6) + ($n$010<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $17 = $59;$60 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3674,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre14 = HEAP32[$3>>2]|0;
     $17 = $$pre;$60 = $$pre14;
    }
    $15 = (($n$010) + 1)|0;
    $16 = ($15>>>0)<($17>>>0);
    if ($16) {
     $59 = $17;$6 = $60;$n$010 = $15;
    } else {
     $$lcssa = $60;
     break L1;
    }
   }
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   __ZdlPv($7);
   $13 = HEAP32[$3>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    __ZdaPv($13);
   }
   $39 = (($this) + 28|0);
   $40 = (($this) + 36|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($39|0);
   if (!($42)) {
    $43 = (($this) + 32|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($44) + 8|0);
    HEAP32[$45>>2] = $41;
    $46 = HEAP32[$43>>2]|0;
    $47 = HEAP32[$40>>2]|0;
    $48 = (($47) + 4|0);
    HEAP32[$48>>2] = $46;
    HEAP32[$43>>2] = $39;
    HEAP32[$40>>2] = $39;
   }
   $49 = (($this) + 16|0);
   $50 = (($this) + 24|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==($49|0);
   if ($52) {
    ___resumeException($11|0);
    // unreachable;
   }
   $53 = (($this) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 8|0);
   HEAP32[$55>>2] = $51;
   $56 = HEAP32[$53>>2]|0;
   $57 = HEAP32[$50>>2]|0;
   $58 = (($57) + 4|0);
   HEAP32[$58>>2] = $56;
   HEAP32[$53>>2] = $49;
   HEAP32[$50>>2] = $49;
   ___resumeException($11|0);
   // unreachable;
  }
 } while(0);
 $18 = ($$lcssa|0)==(0|0);
 if (!($18)) {
  __ZdaPv($$lcssa);
 }
 $19 = (($this) + 28|0);
 $20 = (($this) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==($19|0);
 if (!($22)) {
  $23 = (($this) + 32|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + 8|0);
  HEAP32[$25>>2] = $21;
  $26 = HEAP32[$23>>2]|0;
  $27 = HEAP32[$20>>2]|0;
  $28 = (($27) + 4|0);
  HEAP32[$28>>2] = $26;
  HEAP32[$23>>2] = $19;
  HEAP32[$20>>2] = $19;
 }
 $29 = (($this) + 16|0);
 $30 = (($this) + 24|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==($29|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 8|0);
 HEAP32[$35>>2] = $31;
 $36 = HEAP32[$33>>2]|0;
 $37 = HEAP32[$30>>2]|0;
 $38 = (($37) + 4|0);
 HEAP32[$38>>2] = $36;
 HEAP32[$33>>2] = $29;
 HEAP32[$30>>2] = $29;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE7GetFreeEi($this,$reuseindex) {
 $this = $this|0;
 $reuseindex = $reuseindex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, $p$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($reuseindex|0)==(-1);
 if ($0) {
  $6 = (($this) + 16|0);
  $7 = (($this) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($6|0);
  if ($9) {
   label = 5;
  } else {
   $10 = HEAP32[$8>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    label = 5;
   } else {
    $29 = (($this) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + -1)|0;
    HEAP32[$29>>2] = $31;
    $p$0 = $10;
   }
  }
  do {
   if ((label|0) == 5) {
    $12 = (($this) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($this) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13>>>0)<($15>>>0);
    if (!($16)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $17 = (__Znwj(36)|0);
    $18 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    invoke_vii(3355,($17|0),($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     __ZdlPv($17);
     ___resumeException($27|0);
     // unreachable;
    } else {
     $21 = HEAP32[$12>>2]|0;
     $22 = (($17) + 8|0);
     HEAP32[$22>>2] = $21;
     $23 = (($21) + 1)|0;
     HEAP32[$12>>2] = $23;
     $24 = (($this) + 40|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($25) + ($21<<2)|0);
     HEAP32[$26>>2] = $17;
     $p$0 = $17;
     break;
    }
   }
  } while(0);
  $32 = (($this) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $35 = (($this) + 28|0);
  $36 = (($p$0) + 24|0);
  $37 = (($p$0) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($p$0) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 8|0);
  HEAP32[$41>>2] = $38;
  $42 = HEAP32[$39>>2]|0;
  $43 = HEAP32[$37>>2]|0;
  $44 = (($43) + 4|0);
  HEAP32[$44>>2] = $42;
  HEAP32[$39>>2] = $36;
  HEAP32[$37>>2] = $36;
  $45 = (($this) + 32|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$39>>2] = $46;
  HEAP32[$37>>2] = $35;
  $47 = HEAP32[$45>>2]|0;
  $48 = (($47) + 8|0);
  HEAP32[$48>>2] = $36;
  HEAP32[$45>>2] = $36;
  $p$1 = $p$0;
 } else {
  $1 = (($this) + 40|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($reuseindex<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $p$1 = $4;
  }
 }
 $49 = (($p$1) + 16|0);
 HEAP8[$49>>0] = 0;
 $50 = HEAP32[$this>>2]|0;
 $51 = (($50) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($p$1) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($p$1) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$55>>2] = $57;
 $58 = $52 << 28;
 $59 = $54 << 16;
 $60 = $59 & 268369920;
 $61 = $60 | $58;
 $62 = $57 & 65535;
 $63 = $61 | $62;
 $64 = $63;
 $65 = (($p$1) + 20|0);
 HEAP32[$65>>2] = $64;
 $$0 = $p$1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($handle)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $handle;
 $3 = $2 >>> 16;
 $4 = $3 & 4095;
 $5 = (($0) + 248|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($8) + 16|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = $2 & 65535;
 $14 = (($8) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($13|0);
 $$ = $16 ? $8 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE5CheckEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE7ReleaseEPS2_($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($p|0)==(0|0);
 if ($0) {
  HEAP32[$vararg_buffer>>2] = 36;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 763112;
  (_printf((763040|0),($vararg_buffer|0))|0);
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 } else {
  $1 = (($p) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($this) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($2<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$7>>2] = $9;
  $10 = (($6) + 16|0);
  HEAP8[$10>>0] = 1;
  $11 = (($this) + 16|0);
  $12 = (($6) + 24|0);
  $13 = (($6) + 32|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($6) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  HEAP32[$17>>2] = $14;
  $18 = HEAP32[$15>>2]|0;
  $19 = HEAP32[$13>>2]|0;
  $20 = (($19) + 4|0);
  HEAP32[$20>>2] = $18;
  HEAP32[$15>>2] = $12;
  HEAP32[$13>>2] = $12;
  $21 = (($this) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$13>>2] = $11;
  $23 = HEAP32[$21>>2]|0;
  $24 = (($23) + 8|0);
  HEAP32[$24>>2] = $12;
  HEAP32[$21>>2] = $12;
  $25 = (($this) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + -1)|0;
  HEAP32[$25>>2] = $27;
  $28 = (($this) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 1)|0;
  HEAP32[$28>>2] = $30;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE7SetSizeEi($this,$newsize) {
 $this = $this|0;
 $newsize = $newsize|0;
 var $$arith = 0, $$lcssa5 = 0, $$overflow = 0, $$pre = 0, $$pre16 = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$08 = 0, $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = (($this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 L1: do {
  if ($2) {
   $$lcssa5 = $4;
  } else {
   $32 = $1;$6 = $4;$i$08 = 0;
   while(1) {
    $5 = (($6) + ($i$08<<2)|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     $13 = $32;$33 = $6;
    } else {
     __THREW__ = 0;
     invoke_vi(3675,($7|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZdlPv($7);
     $$pre = HEAP32[$0>>2]|0;
     $$pre16 = HEAP32[$3>>2]|0;
     $13 = $$pre;$33 = $$pre16;
    }
    $11 = (($i$08) + 1)|0;
    $12 = ($11>>>0)<($13>>>0);
    if ($12) {
     $32 = $13;$6 = $33;$i$08 = $11;
    } else {
     $$lcssa5 = $33;
     break L1;
    }
   }
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __ZdlPv($7);
   ___resumeException($14|0);
   // unreachable;
  }
 } while(0);
 $16 = ($$lcssa5|0)==(0|0);
 if (!($16)) {
  __ZdaPv($$lcssa5);
 }
 $$arith = $newsize<<2;
 $$overflow = ($newsize>>>0)>(1073741823);
 $17 = $$overflow ? -1 : $$arith;
 $18 = (__Znaj($17)|0);
 HEAP32[$3>>2] = $18;
 HEAP32[$0>>2] = $newsize;
 $19 = ($newsize|0)>(0);
 L13: do {
  if ($19) {
   $21 = $18;$i1$01 = 0;
   while(1) {
    $20 = (($21) + ($i1$01<<2)|0);
    HEAP32[$20>>2] = 0;
    $22 = (($i1$01) + 1)|0;
    $exitcond = ($22|0)==($newsize|0);
    if ($exitcond) {
     break L13;
    }
    $$pre18 = HEAP32[$3>>2]|0;
    $21 = $$pre18;$i1$01 = $22;
   }
  }
 } while(0);
 $23 = (($this) + 28|0);
 $24 = (($this) + 32|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 36|0);
 HEAP32[$25>>2] = $23;
 $26 = (($this) + 16|0);
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = $26;
 $28 = (($this) + 24|0);
 HEAP32[$28>>2] = $26;
 $29 = (($this) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 8|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 12|0);
 HEAP32[$31>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE7GetFreeEi($this,$reuseindex) {
 $this = $this|0;
 $reuseindex = $reuseindex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, $p$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($reuseindex|0)==(-1);
 if ($0) {
  $6 = (($this) + 16|0);
  $7 = (($this) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($6|0);
  if ($9) {
   label = 5;
  } else {
   $10 = HEAP32[$8>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    label = 5;
   } else {
    $29 = (($this) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + -1)|0;
    HEAP32[$29>>2] = $31;
    $p$0 = $10;
   }
  }
  do {
   if ((label|0) == 5) {
    $12 = (($this) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($this) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13>>>0)<($15>>>0);
    if (!($16)) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $17 = (__Znwj(36)|0);
    $18 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    invoke_vii(3356,($17|0),($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $27 = ___cxa_find_matching_catch()|0;
     $28 = tempRet0;
     __ZdlPv($17);
     ___resumeException($27|0);
     // unreachable;
    } else {
     $21 = HEAP32[$12>>2]|0;
     $22 = (($17) + 8|0);
     HEAP32[$22>>2] = $21;
     $23 = (($21) + 1)|0;
     HEAP32[$12>>2] = $23;
     $24 = (($this) + 40|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($25) + ($21<<2)|0);
     HEAP32[$26>>2] = $17;
     $p$0 = $17;
     break;
    }
   }
  } while(0);
  $32 = (($this) + 12|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$32>>2] = $34;
  $35 = (($this) + 28|0);
  $36 = (($p$0) + 24|0);
  $37 = (($p$0) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($p$0) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($40) + 8|0);
  HEAP32[$41>>2] = $38;
  $42 = HEAP32[$39>>2]|0;
  $43 = HEAP32[$37>>2]|0;
  $44 = (($43) + 4|0);
  HEAP32[$44>>2] = $42;
  HEAP32[$39>>2] = $36;
  HEAP32[$37>>2] = $36;
  $45 = (($this) + 32|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$39>>2] = $46;
  HEAP32[$37>>2] = $35;
  $47 = HEAP32[$45>>2]|0;
  $48 = (($47) + 8|0);
  HEAP32[$48>>2] = $36;
  HEAP32[$45>>2] = $36;
  $p$1 = $p$0;
 } else {
  $1 = (($this) + 40|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($reuseindex<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $p$1 = $4;
  }
 }
 $49 = (($p$1) + 16|0);
 HEAP8[$49>>0] = 0;
 $50 = HEAP32[$this>>2]|0;
 $51 = (($50) + 8|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($p$1) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($p$1) + 12|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$55>>2] = $57;
 $58 = $52 << 28;
 $59 = $54 << 16;
 $60 = $59 & 268369920;
 $61 = $60 | $58;
 $62 = $57 & 65535;
 $63 = $61 | $62;
 $64 = $63;
 $65 = (($p$1) + 20|0);
 HEAP32[$65>>2] = $64;
 $$0 = $p$1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE8ValidateEPS1_($this,$handle) {
 $this = $this|0;
 $handle = $handle|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($handle)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $handle;
 $3 = $2 >>> 16;
 $4 = $3 & 4095;
 $5 = (($0) + 296|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($8) + 16|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = $2 & 65535;
 $14 = (($8) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($13|0);
 $$ = $16 ? $8 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE5CheckEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE7ReleaseEPS2_($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($p|0)==(0|0);
 if ($0) {
  HEAP32[$vararg_buffer>>2] = 36;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 763112;
  (_printf((763040|0),($vararg_buffer|0))|0);
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 } else {
  $1 = (($p) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($this) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($2<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 1)|0;
  HEAP32[$7>>2] = $9;
  $10 = (($6) + 16|0);
  HEAP8[$10>>0] = 1;
  $11 = (($this) + 16|0);
  $12 = (($6) + 24|0);
  $13 = (($6) + 32|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($6) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  HEAP32[$17>>2] = $14;
  $18 = HEAP32[$15>>2]|0;
  $19 = HEAP32[$13>>2]|0;
  $20 = (($19) + 4|0);
  HEAP32[$20>>2] = $18;
  HEAP32[$15>>2] = $12;
  HEAP32[$13>>2] = $12;
  $21 = (($this) + 20|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$13>>2] = $11;
  $23 = HEAP32[$21>>2]|0;
  $24 = (($23) + 8|0);
  HEAP32[$24>>2] = $12;
  HEAP32[$21>>2] = $12;
  $25 = (($this) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + -1)|0;
  HEAP32[$25>>2] = $27;
  $28 = (($this) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + 1)|0;
  HEAP32[$28>>2] = $30;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN4FMOD7Channel4stopEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI4stopEv($3)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763256;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763256;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel9setPausedEb($this,$paused) {
 $this = $this|0;
 $paused = $paused|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI9setPausedEb($3,$paused)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763264;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763264;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel9setVolumeEf($this,$volume) {
 $this = $this|0;
 $volume = Math_fround($volume);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI9setVolumeEf($3,$volume)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763280;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763280;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel12setFrequencyEf($this,$frequency) {
 $this = $this|0;
 $frequency = Math_fround($frequency);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI12setFrequencyEf($3,$frequency)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763296;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763296;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel12getFrequencyEPf($this,$frequency) {
 $this = $this|0;
 $frequency = $frequency|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI12getFrequencyEPf($3,$frequency)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763312;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763312;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel6setPanEf($this,$pan) {
 $this = $this|0;
 $pan = Math_fround($pan);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI6setPanEf($3,$pan)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763328;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763328;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel8setDelayE14FMOD_DELAYTYPEjj($this,$delaytype,$delayhi,$delaylo) {
 $this = $this|0;
 $delaytype = $delaytype|0;
 $delayhi = $delayhi|0;
 $delaylo = $delaylo|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI8setDelayE14FMOD_DELAYTYPEjj($3,$delaytype,$delayhi,$delaylo)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763336;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763336;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel7setMuteEb($this,$mute) {
 $this = $this|0;
 $mute = $mute|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI7setMuteEb($3,$mute)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763352;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763352;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel11setPriorityEi($this,$priority) {
 $this = $this|0;
 $priority = $priority|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI11setPriorityEi($3,$priority)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763360;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763360;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel11setPositionEjj($this,$position,$postype) {
 $this = $this|0;
 $position = $position|0;
 $postype = $postype|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI11setPositionEjj($3,$position,$postype)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763376;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763376;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel19setReverbPropertiesEPK29FMOD_REVERB_CHANNELPROPERTIES($this,$prop) {
 $this = $this|0;
 $prop = $prop|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI19setReverbPropertiesEPK29FMOD_REVERB_CHANNELPROPERTIES($3,$prop)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763392;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763392;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel19getReverbPropertiesEP29FMOD_REVERB_CHANNELPROPERTIES($this,$prop) {
 $this = $this|0;
 $prop = $prop|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI19getReverbPropertiesEP29FMOD_REVERB_CHANNELPROPERTIES($3,$prop)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763416;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763416;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel15setChannelGroupEPNS_12ChannelGroupE($this,$channelgroup) {
 $this = $this|0;
 $channelgroup = $channelgroup|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI15setChannelGroupEPNS_12ChannelGroupE($3,$channelgroup)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763440;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763440;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel11setCallbackEPF11FMOD_RESULTP12FMOD_CHANNEL25FMOD_CHANNEL_CALLBACKTYPEPvS5_E($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI11setCallbackEPF11FMOD_RESULTP12FMOD_CHANNEL25FMOD_CHANNEL_CALLBACKTYPEPvS5_E($3,$callback)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763456;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763456;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel15set3DAttributesEPK11FMOD_VECTORS3_($this,$pos,$vel) {
 $this = $this|0;
 $pos = $pos|0;
 $vel = $vel|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI15set3DAttributesEPK11FMOD_VECTORS3_($3,$pos,$vel)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763472;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763472;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel19set3DMinMaxDistanceEff($this,$mindistance,$maxdistance) {
 $this = $this|0;
 $mindistance = Math_fround($mindistance);
 $maxdistance = Math_fround($maxdistance);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI19set3DMinMaxDistanceEff($3,$mindistance,$maxdistance)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763488;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763488;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel17set3DConeSettingsEfff($this,$insideconeangle,$outsideconeangle,$outsidevolume) {
 $this = $this|0;
 $insideconeangle = Math_fround($insideconeangle);
 $outsideconeangle = Math_fround($outsideconeangle);
 $outsidevolume = Math_fround($outsidevolume);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI17set3DConeSettingsEfff($3,$insideconeangle,$outsideconeangle,$outsidevolume)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763512;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763512;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel20set3DConeOrientationEP11FMOD_VECTOR($this,$orientation) {
 $this = $this|0;
 $orientation = $orientation|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI20set3DConeOrientationEP11FMOD_VECTOR($3,$orientation)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763536;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763536;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel11set3DSpreadEf($this,$angle) {
 $this = $this|0;
 $angle = Math_fround($angle);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI11set3DSpreadEf($3,$angle)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763560;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763560;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel13set3DPanLevelEf($this,$level) {
 $this = $this|0;
 $level = Math_fround($level);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI13set3DPanLevelEf($3,$level)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763576;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763576;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel17set3DDopplerLevelEf($this,$level) {
 $this = $this|0;
 $level = Math_fround($level);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI17set3DDopplerLevelEf($3,$level)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763592;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763592;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel9isPlayingEPb($this,$isplaying) {
 $this = $this|0;
 $isplaying = $isplaying|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI9isPlayingEPb($3,$isplaying)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763640;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763640;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel7setModeEj($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI7setModeEj($3,$mode)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763656;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763656;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel11setUserDataEPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI11setUserDataEPv($3,$userdata)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763672;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763672;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD7Channel11getUserDataEPPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 64|0);
  $3 = (__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD8ChannelI11getUserDataEPPv($3,$userdata)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763688;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763688;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup7releaseEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI7releaseEv($3)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763704;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763704;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup19setAudibilityFactorEf($this,$factor) {
 $this = $this|0;
 $factor = Math_fround($factor);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI19setAudibilityFactorEf($3,$factor)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763712;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763712;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup9setVolumeEf($this,$volume) {
 $this = $this|0;
 $volume = Math_fround($volume);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI9setVolumeEf($3,$volume)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763280;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763280;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup8setPitchEf($this,$pitch) {
 $this = $this|0;
 $pitch = Math_fround($pitch);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI8setPitchEf($3,$pitch)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763736;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763736;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup7setMuteEb($this,$mute) {
 $this = $this|0;
 $mute = $mute|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI7setMuteEb($3,$mute)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763352;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763352;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup8addGroupEPS0_($this,$group) {
 $this = $this|0;
 $group = $group|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI8addGroupEPNS_12ChannelGroupE($3,$group)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763752;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763752;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup12getNumGroupsEPi($this,$numgroups) {
 $this = $this|0;
 $numgroups = $numgroups|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI12getNumGroupsEPi($3,$numgroups)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763768;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763768;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup8getGroupEiPPS0_($this,$index,$group) {
 $this = $this|0;
 $index = $index|0;
 $group = $group|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI8getGroupEiPPNS_12ChannelGroupE($3,$index,$group)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763784;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763784;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup14getParentGroupEPPS0_($this,$group) {
 $this = $this|0;
 $group = $group|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI14getParentGroupEPPNS_12ChannelGroupE($3,$group)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763800;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763800;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup10getDSPHeadEPPNS_3DSPE($this,$dsp) {
 $this = $this|0;
 $dsp = $dsp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI10getDSPHeadEPPNS_3DSPE($3,$dsp)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763616;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763616;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup6addDSPEPNS_3DSPEPPNS_13DSPConnectionE($this,$dsp,$connection) {
 $this = $this|0;
 $dsp = $dsp|0;
 $connection = $connection|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI6addDSPEPNS_3DSPEPPNS_13DSPConnectionE($3,$dsp,$connection)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763632;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763632;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup14getNumChannelsEPi($this,$numchannels) {
 $this = $this|0;
 $numchannels = $numchannels|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI14getNumChannelsEPi($3,$numchannels)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763816;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763816;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD12ChannelGroup10getChannelEiPPNS_7ChannelE($this,$index,$channel) {
 $this = $this|0;
 $index = $index|0;
 $channel = $channel|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 112|0);
  $3 = (__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD13ChannelGroupI10getChannelEiPPNS_7ChannelE($3,$index,$channel)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763832;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763832;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP7releaseEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI7releaseEv($3)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763704;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763704;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP15getSystemObjectEPPNS_6SystemE($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI15getSystemObjectEPPNS_6SystemE($3,$system)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763192;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763192;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP8addInputEPS0_PPNS_13DSPConnectionE($this,$target,$connection) {
 $this = $this|0;
 $target = $target|0;
 $connection = $connection|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI8addInputEPNS_3DSPEPPNS_13DSPConnectionE($3,$target,$connection)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763848;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763848;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP13disconnectAllEbb($this,$inputs,$outputs) {
 $this = $this|0;
 $inputs = $inputs|0;
 $outputs = $outputs|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI13disconnectAllEbb($3,$inputs,$outputs)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763864;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763864;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP6removeEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI6removeEv($3)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763880;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763880;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP12getNumInputsEPi($this,$numinputs) {
 $this = $this|0;
 $numinputs = $numinputs|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI12getNumInputsEPi($3,$numinputs)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763888;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763888;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP8getInputEiPPS0_PPNS_13DSPConnectionE($this,$index,$input,$inputconnection) {
 $this = $this|0;
 $index = $index|0;
 $input = $input|0;
 $inputconnection = $inputconnection|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI8getInputEiPPNS_3DSPEPPNS_13DSPConnectionE($3,$index,$input,$inputconnection)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763904;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763904;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP9getOutputEiPPS0_PPNS_13DSPConnectionE($this,$index,$output,$outputconnection) {
 $this = $this|0;
 $index = $index|0;
 $output = $output|0;
 $outputconnection = $outputconnection|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI9getOutputEiPPNS_3DSPEPPNS_13DSPConnectionE($3,$index,$output,$outputconnection)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763920;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763920;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP9setActiveEb($this,$active) {
 $this = $this|0;
 $active = $active|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI9setActiveEb($3,$active)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763936;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763936;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP9getActiveEPb($this,$active) {
 $this = $this|0;
 $active = $active|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI9getActiveEPb($3,$active)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763952;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763952;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP9setBypassEb($this,$bypass) {
 $this = $this|0;
 $bypass = $bypass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI9setBypassEb($3,$bypass)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763968;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763968;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP9getBypassEPb($this,$bypass) {
 $this = $this|0;
 $bypass = $bypass|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI9getBypassEPb($3,$bypass)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763984;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763984;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP12setParameterEif($this,$index,$value) {
 $this = $this|0;
 $index = $index|0;
 $value = Math_fround($value);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI12setParameterEif($3,$index,$value)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764000;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764000;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP7getInfoEPcPjPiS3_S3_($this,$name,$version,$channels,$configwidth,$configheight) {
 $this = $this|0;
 $name = $name|0;
 $version = $version|0;
 $channels = $channels|0;
 $configwidth = $configwidth|0;
 $configheight = $configheight|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI7getInfoEPcPjPiS3_S3_($3,$name,$version,$channels,$configwidth,$configheight)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764016;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764016;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP11setUserDataEPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI11setUserDataEPv($3,$userdata)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763672;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763672;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD3DSP11getUserDataEPPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 208|0);
  $3 = (__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD4DSPI11getUserDataEPPv($3,$userdata)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763688;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763688;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6Reverb7releaseEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 256|0);
  $3 = (__ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD7ReverbI7releaseEv($3)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763704;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763704;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6Reverb15set3DAttributesEPK11FMOD_VECTORff($this,$position,$mindistance,$maxdistance) {
 $this = $this|0;
 $position = $position|0;
 $mindistance = Math_fround($mindistance);
 $maxdistance = Math_fround($maxdistance);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 256|0);
  $3 = (__ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD7ReverbI15set3DAttributesEPK11FMOD_VECTORff($3,$position,$mindistance,$maxdistance)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763472;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763472;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6Reverb13setPropertiesEPK22FMOD_REVERB_PROPERTIES($this,$properties) {
 $this = $this|0;
 $properties = $properties|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 256|0);
  $3 = (__ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD7ReverbI13setPropertiesEPK22FMOD_REVERB_PROPERTIES($3,$properties)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764024;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764024;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6Reverb9setActiveEb($this,$active) {
 $this = $this|0;
 $active = $active|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 256|0);
  $3 = (__ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD7ReverbI9setActiveEb($3,$active)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763936;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763936;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD5Sound7releaseEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD6SoundI7releaseEv($3)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763704;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763704;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD5Sound11getSubSoundEiPPS0_($this,$index,$subsound) {
 $this = $this|0;
 $index = $index|0;
 $subsound = $subsound|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD6SoundI11getSubSoundEiPPNS_5SoundE($3,$index,$subsound)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764040;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764040;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD5Sound15getNumSubSoundsEPi($this,$numsubsounds) {
 $this = $this|0;
 $numsubsounds = $numsubsounds|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD6SoundI15getNumSubSoundsEPi($3,$numsubsounds)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764056;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764056;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD5Sound12getOpenStateEP14FMOD_OPENSTATEPjPbS4_($this,$openstate,$percentbuffered,$starving,$diskbusy) {
 $this = $this|0;
 $openstate = $openstate|0;
 $percentbuffered = $percentbuffered|0;
 $starving = $starving|0;
 $diskbusy = $diskbusy|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD6SoundI12getOpenStateEP14FMOD_OPENSTATEPjPbS4_($3,$openstate,$percentbuffered,$starving,$diskbusy)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764072;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764072;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD5Sound7setModeEj($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD6SoundI7setModeEj($3,$mode)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763656;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763656;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD5Sound7getModeEPj($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD6SoundI7getModeEPj($3,$mode)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763664;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763664;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD5Sound11setUserDataEPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD6SoundI11setUserDataEPv($3,$userdata)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763672;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763672;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD5Sound11getUserDataEPPv($this,$userdata) {
 $this = $this|0;
 $userdata = $userdata|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (($0) + 160|0);
  $3 = (__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE8ValidateEPS1_($2,$this)|0);
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (__ZN4FMOD6SoundI11getUserDataEPPv($3,$userdata)|0);
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $5;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763688;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763688;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System7releaseEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI7releaseEv($$$i)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763704;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763704;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System9setOutputE15FMOD_OUTPUTTYPE($this,$output) {
 $this = $this|0;
 $output = $output|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI9setOutputE15FMOD_OUTPUTTYPE($$$i,$output)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764088;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764088;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System13getNumDriversEPi($this,$numdrivers) {
 $this = $this|0;
 $numdrivers = $numdrivers|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI13getNumDriversEPi($$$i,$numdrivers)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764104;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764104;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System13getDriverCapsEiPjPiP16FMOD_SPEAKERMODE($this,$id,$caps,$controlpaneloutputrate,$controlpanelspeakermode) {
 $this = $this|0;
 $id = $id|0;
 $caps = $caps|0;
 $controlpaneloutputrate = $controlpaneloutputrate|0;
 $controlpanelspeakermode = $controlpanelspeakermode|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI13getDriverCapsEiPjPiP16FMOD_SPEAKERMODE($$$i,$id,$caps,$controlpaneloutputrate,$controlpanelspeakermode)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764120;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764120;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System9setDriverEi($this,$driver) {
 $this = $this|0;
 $driver = $driver|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI9setDriverEi($$$i,$driver)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764136;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764136;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System9getDriverEPi($this,$driver) {
 $this = $this|0;
 $driver = $driver|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI9getDriverEPi($$$i,$driver)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764152;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764152;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System19setSoftwareChannelsEi($this,$numsoftwarechannels) {
 $this = $this|0;
 $numsoftwarechannels = $numsoftwarechannels|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI19setSoftwareChannelsEi($$$i,$numsoftwarechannels)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764168;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764168;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System17setSoftwareFormatEi17FMOD_SOUND_FORMATii18FMOD_DSP_RESAMPLER($this,$samplerate,$format,$numoutputchannels,$maxinputchannels,$resamplemethod) {
 $this = $this|0;
 $samplerate = $samplerate|0;
 $format = $format|0;
 $numoutputchannels = $numoutputchannels|0;
 $maxinputchannels = $maxinputchannels|0;
 $resamplemethod = $resamplemethod|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI17setSoftwareFormatEi17FMOD_SOUND_FORMATii18FMOD_DSP_RESAMPLER($$$i,$samplerate,$format,$numoutputchannels,$maxinputchannels,$resamplemethod)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764192;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764192;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($this,$samplerate,$format,$numoutputchannels,$maxinputchannels,$resamplemethod,$bits) {
 $this = $this|0;
 $samplerate = $samplerate|0;
 $format = $format|0;
 $numoutputchannels = $numoutputchannels|0;
 $maxinputchannels = $maxinputchannels|0;
 $resamplemethod = $resamplemethod|0;
 $bits = $bits|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_($$$i,$samplerate,$format,$numoutputchannels,$maxinputchannels,$resamplemethod,$bits)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764216;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764216;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System16setDSPBufferSizeEji($this,$bufferlength,$numbuffers) {
 $this = $this|0;
 $bufferlength = $bufferlength|0;
 $numbuffers = $numbuffers|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI16setDSPBufferSizeEji($$$i,$bufferlength,$numbuffers)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764240;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764240;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System16getDSPBufferSizeEPjPi($this,$bufferlength,$numbuffers) {
 $this = $this|0;
 $bufferlength = $bufferlength|0;
 $numbuffers = $numbuffers|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI16getDSPBufferSizeEPjPi($$$i,$bufferlength,$numbuffers)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764264;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764264;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System13setFileSystemEPF11FMOD_RESULTPKciPjPPvS6_EPFS1_S5_S5_EPFS1_S5_S5_jS4_S5_EPFS1_S5_jS5_EPFS1_P18FMOD_ASYNCREADINFOS5_ESA_i($this,$useropen,$userclose,$userread,$userseek,$userasyncread,$userasynccancel,$blockalign) {
 $this = $this|0;
 $useropen = $useropen|0;
 $userclose = $userclose|0;
 $userread = $userread|0;
 $userseek = $userseek|0;
 $userasyncread = $userasyncread|0;
 $userasynccancel = $userasynccancel|0;
 $blockalign = $blockalign|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI13setFileSystemEPF11FMOD_RESULTPKciPjPPvS6_EPFS1_S5_S5_EPFS1_S5_S5_jS4_S5_EPFS1_S5_jS5_EPFS1_P18FMOD_ASYNCREADINFOS5_ESA_i($$$i,$useropen,$userclose,$userread,$userseek,$userasyncread,$userasynccancel,$blockalign)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764288;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764288;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System14setSpeakerModeE16FMOD_SPEAKERMODE($this,$speakermode) {
 $this = $this|0;
 $speakermode = $speakermode|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI14setSpeakerModeE16FMOD_SPEAKERMODE($$$i,$speakermode)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764304;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764304;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System11setCallbackEPF11FMOD_RESULTP11FMOD_SYSTEM24FMOD_SYSTEM_CALLBACKTYPEPvS5_E($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI11setCallbackEPF11FMOD_RESULTP11FMOD_SYSTEM24FMOD_SYSTEM_CALLBACKTYPEPvS5_E($$$i,$callback)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 763456;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 763456;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System4initEijPv($this,$maxchannels,$flags,$extradriverdata) {
 $this = $this|0;
 $maxchannels = $maxchannels|0;
 $flags = $flags|0;
 $extradriverdata = $extradriverdata|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI4initEijPv($$$i,$maxchannels,$flags,$extradriverdata)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764320;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764320;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System5closeEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI5closeEv($$$i)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764328;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764328;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System6updateEv($this) {
 $this = $this|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI6updateEv($$$i)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764336;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764336;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System13set3DSettingsEfff($this,$dopplerscale,$distancefactor,$rolloffscale) {
 $this = $this|0;
 $dopplerscale = Math_fround($dopplerscale);
 $distancefactor = Math_fround($distancefactor);
 $rolloffscale = Math_fround($rolloffscale);
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI13set3DSettingsEfff($$$i,$dopplerscale,$distancefactor,$rolloffscale)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764344;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764344;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System23set3DListenerAttributesEiPK11FMOD_VECTORS3_S3_S3_($this,$listener,$pos,$vel,$forward,$up) {
 $this = $this|0;
 $listener = $listener|0;
 $pos = $pos|0;
 $vel = $vel|0;
 $forward = $forward|0;
 $up = $up|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI23set3DListenerAttributesEiPK11FMOD_VECTORS3_S3_S3_($$$i,$listener,$pos,$vel,$forward,$up)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764360;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764360;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System20set3DRolloffCallbackEPFfP12FMOD_CHANNELfE($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI20set3DRolloffCallbackEPFfP12FMOD_CHANNELfE($$$i,$callback)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764384;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764384;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System19setStreamBufferSizeEjj($this,$filebuffersize,$filebuffersizetype) {
 $this = $this|0;
 $filebuffersize = $filebuffersize|0;
 $filebuffersizetype = $filebuffersizetype|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI19setStreamBufferSizeEjj($$$i,$filebuffersize,$filebuffersizetype)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764408;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764408;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOPPNS_5SoundE($this,$name_or_data,$mode,$exinfo,$sound) {
 $this = $this|0;
 $name_or_data = $name_or_data|0;
 $mode = $mode|0;
 $exinfo = $exinfo|0;
 $sound = $sound|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOPPNS_5SoundE($$$i,$name_or_data,$mode,$exinfo,$sound)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764432;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764432;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System9createDSPEP20FMOD_DSP_DESCRIPTIONPPNS_3DSPE($this,$description,$dsp) {
 $this = $this|0;
 $description = $description|0;
 $dsp = $dsp|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI9createDSPEP20FMOD_DSP_DESCRIPTIONPPNS_3DSPE($$$i,$description,$dsp)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764448;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764448;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System15createDSPByTypeE13FMOD_DSP_TYPEPPNS_3DSPE($this,$type,$dsp) {
 $this = $this|0;
 $type = $type|0;
 $dsp = $dsp|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI15createDSPByTypeE13FMOD_DSP_TYPEPPNS_3DSPE($$$i,$type,$dsp)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764464;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764464;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System18createChannelGroupEPKcPPNS_12ChannelGroupE($this,$name,$channelgroup) {
 $this = $this|0;
 $name = $name|0;
 $channelgroup = $channelgroup|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI18createChannelGroupEPKcPPNS_12ChannelGroupE($$$i,$name,$channelgroup)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764480;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764480;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System12createReverbEPPNS_6ReverbE($this,$reverb) {
 $this = $this|0;
 $reverb = $reverb|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI12createReverbEPPNS_6ReverbE($$$i,$reverb)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764504;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764504;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System9playSoundE17FMOD_CHANNELINDEXPNS_5SoundEbPPNS_7ChannelE($this,$channelid,$sound,$paused,$channel) {
 $this = $this|0;
 $channelid = $channelid|0;
 $sound = $sound|0;
 $paused = $paused|0;
 $channel = $channel|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI9playSoundE17FMOD_CHANNELINDEXPNS_5SoundEbPPNS_7ChannelE($$$i,$channelid,$sound,$paused,$channel)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764520;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764520;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System7playDSPE17FMOD_CHANNELINDEXPNS_3DSPEbPPNS_7ChannelE($this,$channelid,$dsp,$paused,$channel) {
 $this = $this|0;
 $channelid = $channelid|0;
 $dsp = $dsp|0;
 $paused = $paused|0;
 $channel = $channel|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI7playDSPE17FMOD_CHANNELINDEXPNS_3DSPEbPPNS_7ChannelE($$$i,$channelid,$dsp,$paused,$channel)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764536;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764536;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System21getMasterChannelGroupEPPNS_12ChannelGroupE($this,$channelgroup) {
 $this = $this|0;
 $channelgroup = $channelgroup|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI21getMasterChannelGroupEPPNS_12ChannelGroupE($$$i,$channelgroup)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764544;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764544;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4FMOD6System11getDSPClockEPjS1_($this,$hi,$lo) {
 $this = $this|0;
 $hi = $hi|0;
 $lo = $lo|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__ZN4FMOD7SystemI28GetSystemFromNonSystemHandleEPv($this)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = $this;
  $3 = $2 & 65535;
  $4 = (($0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($3|0);
  $$$i = $6 ? $0 : 0;
  $7 = ($$$i|0)==(0|0);
  if (!($7)) {
   $8 = (__ZN4FMOD7SystemI11getDSPClockEPjS1_($$$i,$hi,$lo)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$vararg_buffer2>>2] = $8;
   $vararg_ptr5 = (($vararg_buffer2) + 4|0);
   HEAP32[$vararg_ptr5>>2] = 764568;
   (_printf((763208|0),($vararg_buffer2|0))|0);
   $$0 = $8;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$vararg_buffer2>>2] = 36;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 764568;
 (_printf((763120|0),($vararg_buffer2|0))|0);
 $$0 = 36;
 STACKTOP = sp;return ($$0|0);
}
function __Z24RegisterModule_Animationv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $i$01$i$i1 = 0;
 var $i$01$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i = 0;
 while(1) {
  $3 = ((($0) + ($i$01$i$i<<2)|0) + 64|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  $2 = (($i$01$i$i) + 1)|0;
  if ($5) {
   label = 4;
   break;
  }
  $1 = ($2|0)<(16);
  if ($1) {
   $i$01$i$i = $2;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$3>>2] = 225;
 }
 $6 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i2 = 0;
 while(1) {
  $9 = (($6) + ($i$01$i$i2<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  $8 = (($i$01$i$i2) + 1)|0;
  if ($11) {
   label = 8;
   break;
  }
  $7 = ($8|0)<(16);
  if ($7) {
   $i$01$i$i2 = $8;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  HEAP32[$9>>2] = 226;
 }
 $12 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i1 = 0;
 while(1) {
  $15 = ((($12) + ($i$01$i$i1<<2)|0) + 128|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  $14 = (($i$01$i$i1) + 1)|0;
  if ($17) {
   break;
  }
  $13 = ($14|0)<(16);
  if ($13) {
   $i$01$i$i1 = $14;
  } else {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
 HEAP32[$15>>2] = 227;
 STACKTOP = sp;return;
}
function __ZL30RegisterModuleICalls_Animationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL26InitializeModule_Animationv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[616152>>2] = 3676;
 $1 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy,1,16,764584,19)|0);
 HEAP32[$2>>2] = ((774872 + 8|0));
 __Z13SetIAnimationP10IAnimation($2);
 STACKTOP = sp;return;
}
function __ZL23CleanupModule_Animationv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[616152>>2] = 0;
 $1 = (__Z13GetIAnimationv()|0);
 $2 = HEAP32[628296>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$1>>2]|0;
  $5 = (($4) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 __Z13SetIAnimationP10IAnimation(0);
 STACKTOP = sp;return;
}
function __ZN16MecanimAnimationD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16MecanimAnimationD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __Z39InitializeAnimationStateNetworkProviderv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy,1,16,764592,43)|0);
 HEAP32[$2>>2] = ((764600 + 8|0));
 __Z33SetIAnimationStateNetworkProviderP30IAnimationStateNetworkProvider($2);
 STACKTOP = sp;return;
}
function __Z36CleanupAnimationStateNetworkProviderv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z33GetIAnimationStateNetworkProviderv()|0);
 $2 = HEAP32[628352>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 __Z33SetIAnimationStateNetworkProviderP30IAnimationStateNetworkProvider(0);
 STACKTOP = sp;return;
}
function __ZN29AnimationStateNetworkProvider29GetNetworkAnimationStateCountER9Animation($this,$animation) {
 $this = $this|0;
 $animation = $animation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Animation20BuildAnimationStatesEv($animation);
 $0 = (($animation) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($animation) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 STACKTOP = sp;return ($7|0);
}
function __ZN29AnimationStateNetworkProvider24GetNetworkAnimationStateER9AnimationP24AnimationStateForNetworki($this,$animation,$output,$count) {
 $this = $this|0;
 $animation = $animation|0;
 $output = $output|0;
 $count = $count|0;
 var $$tr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0.0, $15 = Math_fround(0), $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)>(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($animation) + 88|0);
 $i$01 = 0;
 while(1) {
  __ZN9Animation20BuildAnimationStatesEv($animation);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($i$01<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 56|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = (($output) + (($i$01*12)|0)|0);
  $8 = ($6&65535) >>> 1;
  $$tr = $8&255;
  $9 = $$tr & 1;
  HEAP8[$7>>0] = $9;
  $10 = (($4) + 8|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = ((($output) + (($i$01*12)|0)|0) + 4|0);
  HEAPF32[$12>>2] = $11;
  $13 = (($4) + 16|0);
  $14 = +HEAPF64[$13>>3];
  $15 = Math_fround($14);
  $16 = ((($output) + (($i$01*12)|0)|0) + 8|0);
  HEAPF32[$16>>2] = $15;
  $17 = (($i$01) + 1)|0;
  $exitcond = ($17|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $17;
  }
 }
 STACKTOP = sp;return;
}
function __ZN29AnimationStateNetworkProvider24SetNetworkAnimationStateER9AnimationPK24AnimationStateForNetworki($this,$animation,$serialize,$count) {
 $this = $this|0;
 $animation = $animation|0;
 $serialize = $serialize|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)>(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($animation) + 88|0);
 $i$01 = 0;
 while(1) {
  __ZN9Animation20BuildAnimationStatesEv($animation);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($i$01<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($serialize) + (($i$01*12)|0)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  __ZN14AnimationState10SetEnabledEb($4,$7);
  $8 = ((($serialize) + (($i$01*12)|0)|0) + 4|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($4) + 8|0);
  HEAPF32[$10>>2] = $9;
  $11 = ((($serialize) + (($i$01*12)|0)|0) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  __ZN14AnimationState7SetTimeEf($4,$12);
  $13 = (($i$01) + 1)|0;
  $exitcond = ($13|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $13;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Animation15ThreadedCleanupEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre$i = 0, $$pre$i2 = 0, $$pre1$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $__new_last2$i$i$i$i3 = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i4 = 0, $scevgep4$i$i$i$i = 0, $scevgep4$i$i$i$i8 = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i$i$i6 = 0;
 var $uglygep3$i$i$i$i = 0, $uglygep3$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $7 = $4;
  while(1) {
   $6 = HEAP32[$7>>2]|0;
   __ZN6Object11RemoveEventEPFvPvS0_iES0_($6,1991,$this);
   $8 = (($7) + 4|0);
   $9 = ($8|0)==($2|0);
   if ($9) {
    break;
   } else {
    $7 = $8;
   }
  }
  $$pre$i = HEAP32[$3>>2]|0;
  $$pre1$i = HEAP32[$1>>2]|0;
  $10 = ($$pre1$i|0)==($$pre$i|0);
  if (!($10)) {
   $__new_last2$i$i$i$i = $$pre$i;
   $scevgep$i$i$i$i = (($$pre1$i) + -4|0);
   $11 = (0 - ($__new_last2$i$i$i$i))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($11)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $12 = $uglygep3$i$i$i$i >>> 2;
   $13 = $12 ^ -1;
   $scevgep4$i$i$i$i = (($$pre1$i) + ($13<<2)|0);
   HEAP32[$1>>2] = $scevgep4$i$i$i$i;
  }
 }
 $14 = (($this) + 88|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 92|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 if (!($18)) {
  $20 = $15;$46 = $17;
  while(1) {
   $19 = HEAP32[$20>>2]|0;
   $21 = ($19|0)==(0|0);
   if ($21) {
    $26 = $46;
   } else {
    __THREW__ = 0;
    invoke_vi(3677,($19|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 11;
     break;
    }
    __ZdlPv($19);
    $$pre9$i = HEAP32[$16>>2]|0;
    $26 = $$pre9$i;
   }
   $24 = (($20) + 4|0);
   $25 = ($24|0)==($26|0);
   if ($25) {
    break;
   } else {
    $20 = $24;$46 = $26;
   }
  }
  if ((label|0) == 11) {
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   __ZdlPv($19);
   ___resumeException($27|0);
   // unreachable;
  }
  $$pre$i2 = HEAP32[$14>>2]|0;
  $29 = ($26|0)==($$pre$i2|0);
  if (!($29)) {
   $__new_last2$i$i$i$i3 = $$pre$i2;
   $scevgep$i$i$i$i4 = (($26) + -4|0);
   $30 = (0 - ($__new_last2$i$i$i$i3))|0;
   $uglygep$i$i$i$i6 = (($scevgep$i$i$i$i4) + ($30)|0);
   $uglygep3$i$i$i$i7 = $uglygep$i$i$i$i6;
   $31 = $uglygep3$i$i$i$i7 >>> 2;
   $32 = $31 ^ -1;
   $scevgep4$i$i$i$i8 = (($26) + ($32<<2)|0);
   HEAP32[$16>>2] = $scevgep4$i$i$i$i8;
  }
 }
 $33 = (($this) + 80|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = (($this) + 84|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)>(-1);
 if ($38) {
  $39 = (($this) + 72|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($this) + 76|0);
  $42 = HEAP32[$41>>2]|0;
  HEAP32[$0>>2] = $42;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($40,$$byval_copy);
  HEAP32[$39>>2] = 0;
 }
 HEAP32[$33>>2] = 0;
 HEAP32[$36>>2] = 0;
 $43 = (($this) + 232|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44 | 1;
 HEAP32[$43>>2] = $45;
 STACKTOP = sp;return;
}
function __ZN9Animation17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 236|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 240|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $6;
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9Animation13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$pre$i = 0, $$pre$i$i = 0, $$pre1$i = 0, $$pre1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode);
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if ($4) {
  $22 = $1;$23 = $1;
 } else {
  $6 = $3;
  while(1) {
   $5 = HEAP32[$6>>2]|0;
   __ZN6Object11RemoveEventEPFvPvS0_iES0_($5,1991,$this);
   $7 = (($6) + 4|0);
   $8 = ($7|0)==($1|0);
   if ($8) {
    break;
   } else {
    $6 = $7;
   }
  }
  $$pre$i = HEAP32[$2>>2]|0;
  $$pre1$i = HEAP32[$0>>2]|0;
  $9 = ($$pre1$i|0)==($$pre$i|0);
  if ($9) {
   $22 = $$pre$i;$23 = $$pre$i;
  } else {
   $__new_last2$i$i$i$i = $$pre$i;
   $scevgep$i$i$i$i = (($$pre1$i) + -4|0);
   $10 = (0 - ($__new_last2$i$i$i$i))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($10)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $11 = $uglygep3$i$i$i$i >>> 2;
   $12 = $11 ^ -1;
   $scevgep4$i$i$i$i = (($$pre1$i) + ($12<<2)|0);
   HEAP32[$0>>2] = $scevgep4$i$i$i$i;
   $22 = $$pre$i;$23 = $scevgep4$i$i$i$i;
  }
 }
 $13 = (($this) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(1);
 if ($15) {
  $16 = (($this) + 88|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($this) + 92|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($17|0)==($19|0);
  if (!($20)) {
   $21 = ($22|0)==($23|0);
   if (!($21)) {
    $25 = $22;
    while(1) {
     $24 = HEAP32[$25>>2]|0;
     __ZN6Object11RemoveEventEPFvPvS0_iES0_($24,1991,$this);
     $26 = (($25) + 4|0);
     $27 = ($26|0)==($23|0);
     if ($27) {
      break;
     } else {
      $25 = $26;
     }
    }
    $$pre$i$i = HEAP32[$2>>2]|0;
    $$pre1$i$i = HEAP32[$0>>2]|0;
    $28 = ($$pre1$i$i|0)==($$pre$i$i|0);
    if (!($28)) {
     $__new_last2$i$i$i$i$i = $$pre$i$i;
     $scevgep$i$i$i$i$i = (($$pre1$i$i) + -4|0);
     $29 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($29)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $30 = $uglygep3$i$i$i$i$i >>> 2;
     $31 = $30 ^ -1;
     $scevgep4$i$i$i$i$i = (($$pre1$i$i) + ($31<<2)|0);
     HEAP32[$0>>2] = $scevgep4$i$i$i$i$i;
    }
   }
   $32 = (($this) + 24|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($33)|0);
   __ZN9Animation34RecomputeContainedRenderersRecurseER9Transform($this,$34);
   __ZN9Animation25CheckRendererVisibleStateEv($this);
  }
 }
 $35 = (($this) + 36|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = ($36<<24>>24)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = $awakeMode & 13;
 $39 = ($38|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = (($this) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = (__ZNK5Unity10GameObject8IsActiveEv($41)|0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 $44 = (__Z14IsWorldPlayingv()|0);
 if (!($44)) {
  STACKTOP = sp;return;
 }
 (__ZN9Animation4PlayEi($this,4)|0);
 STACKTOP = sp;return;
}
function __ZN9Animation4PlayEi($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $$0 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 260|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 11;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 11;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 11;
   } else {
    $$in = $33;
   }
  }
 }
 if ((label|0) == 11) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $37 = ($36|0)==(0|0);
  if ($37) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$in = $36;
  }
 }
 __ZN9Animation20BuildAnimationStatesEv($this);
 $38 = (($this) + 88|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($this) + 92|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($39|0)==($41|0);
 L19: do {
  if (!($42)) {
   $46 = $39;
   while(1) {
    $45 = HEAP32[$46>>2]|0;
    $47 = (($45) + 96|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==($$in|0);
    $44 = (($46) + 4|0);
    if ($49) {
     break;
    }
    $43 = ($44|0)==($41|0);
    if ($43) {
     break L19;
    } else {
     $46 = $44;
    }
   }
   $50 = ($45|0)==(0|0);
   if (!($50)) {
    $51 = ($mode|0)==(1);
    if ($51) {
     (__ZN9Animation14QueueCrossFadeER14AnimationStatefii($this,$45,Math_fround(0.0),0,0)|0);
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    } else {
     __ZN9Animation9CrossFadeER14AnimationStatefib($this,$45,Math_fround(0.0),$mode,1);
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $52 = ($this|0)==(0|0);
 if ($52) {
  $55 = 0;
 } else {
  $53 = (($this) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = $54;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(765160,0,765224,400,4,$55,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Animation10DeactivateEN5Unity19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  $7 = $2;
  while(1) {
   $6 = HEAP32[$7>>2]|0;
   __ZN14AnimationState4StopEv($6);
   $8 = (($7) + 4|0);
   $9 = HEAP32[$3>>2]|0;
   $10 = ($8|0)==($9|0);
   if ($10) {
    break;
   } else {
    $7 = $8;
   }
  }
 }
 $11 = (($this) + 276|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 280|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==($12|0);
 if (!($15)) {
  $__new_last2$i$i$i$i = $12;
  $scevgep$i$i$i$i = (($14) + -16|0);
  $16 = (0 - ($__new_last2$i$i$i$i))|0;
  $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($16)|0);
  $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
  $17 = $uglygep3$i$i$i$i >>> 4;
  $18 = $17 ^ -1;
  $scevgep4$i$i$i$i = (($14) + ($18<<4)|0);
  HEAP32[$13>>2] = $scevgep4$i$i$i$i;
 }
 $19 = (($this) + 80|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 84|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = (($this) + 72|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($this) + 76|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$0>>2] = $28;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($26,$$byval_copy);
  HEAP32[$25>>2] = 0;
 }
 HEAP32[$19>>2] = 0;
 HEAP32[$22>>2] = 0;
 $29 = (($this) + 232|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 | 1;
 HEAP32[$29>>2] = $31;
 STACKTOP = sp;return;
}
function __ZN9Animation8GetStateERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name) {
 $this = $this|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Animation20BuildAnimationStatesEv($this);
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP8[$name>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 $8 = $5&255;
 $9 = $8 >>> 1;
 $10 = (($name) + 1|0);
 $11 = (($name) + 8|0);
 $12 = (($name) + 4|0);
 $14 = $1;
 while(1) {
  $13 = HEAP32[$14>>2]|0;
  $15 = (($13) + 112|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16 & 1;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $21 = $16&255;
   $22 = $21 >>> 1;
   $25 = $22;
  } else {
   $19 = (($13) + 116|0);
   $20 = HEAP32[$19>>2]|0;
   $25 = $20;
  }
  if ($7) {
   $26 = $9;
  } else {
   $23 = HEAP32[$12>>2]|0;
   $26 = $23;
  }
  $24 = ($25|0)==($26|0);
  if ($24) {
   if ($18) {
    $29 = (($15) + 1|0);
    $35 = $29;
   } else {
    $27 = (($13) + 120|0);
    $28 = HEAP32[$27>>2]|0;
    $35 = $28;
   }
   if ($7) {
    $36 = $10;
   } else {
    $30 = HEAP32[$11>>2]|0;
    $36 = $30;
   }
   if ($18) {
    $33 = $16&255;
    $34 = $33 >>> 1;
    $37 = $34;
   } else {
    $31 = (($13) + 116|0);
    $32 = HEAP32[$31>>2]|0;
    $37 = $32;
   }
   $38 = (_strncmp($35,$36,$37)|0);
   $39 = ($38|0)==(0);
   if ($39) {
    $$0 = $13;
    label = 19;
    break;
   }
  }
  $40 = (($14) + 4|0);
  $41 = ($40|0)==($3|0);
  if ($41) {
   $$0 = 0;
   label = 19;
   break;
  } else {
   $14 = $40;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z23RegisterClass_Animationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(111,228,229,0,230);
 STACKTOP = sp;return;
}
function __ZN9Animation13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 HEAP8[$0>>0] = 18;
 $3 = (($0) + 1|0);
 dest=$3+0|0; src=764768+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $4 = (($0) + 10|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,111,8,($0|0),288,(2577|0),0,1);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN9Animation15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14AnimationState15InitializeClassEv();
 __ZN16AnimationManager15InitializeClassEv();
 __Z27RegisterAllowNameConversionPKcS0_S0_(764768,765384,765408);
 __Z27RegisterAllowNameConversionPKcS0_S0_(764768,765432,765456);
 STACKTOP = sp;return;
}
function __ZN9Animation12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14AnimationState12CleanupClassEv();
 __ZN16AnimationManager12CleanupClassEv();
 STACKTOP = sp;return;
}
function __ZN9Animation7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(288,$$byval_copy2,1,16,765224,84)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = (($3) + 28|0);
  HEAP8[$6>>0] = 1;
  $7 = (($3) + 29|0);
  HEAP8[$7>>0] = 0;
  HEAP32[$3>>2] = ((764624 + 8|0));
  $8 = (($3) + 40|0);
  $9 = (($3) + 60|0);
  $10 = (($3) + 76|0);
  ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;
  ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
  HEAP32[$10>>2] = $2;
  $11 = (($3) + 80|0);
  $12 = (($3) + 228|0);
  HEAP32[$12>>2] = 0;
  $13 = (($3) + 236|0);
  HEAP32[$13>>2] = 0;
  $14 = (($3) + 240|0);
  HEAP32[$14>>2] = 0;
  $15 = (($3) + 244|0);
  ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;
  HEAP32[$15>>2] = $3;
  $16 = (($3) + 248|0);
  $17 = (($3) + 32|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 36|0);
  dest=$16+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP8[$18>>0] = 1;
  $19 = (($3) + 37|0);
  HEAP8[$19>>0] = 0;
  $20 = (($3) + 232|0);
  HEAP32[$20>>2] = 0;
  $21 = (($3) + 38|0);
  HEAP8[$21>>0] = 0;
  $22 = (($3) + 100|0);
  dest=$22+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return ($3|0);
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(765224|0),84);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK9Animation25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 111;
}
function __ZN9Animation23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,764784,764768,$this,0);
 __ZN9Animation8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Animation23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,764784,764768,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN9Animation8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Animation23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Animation8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Animation23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Animation8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Animation23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Animation8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Animation23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Animation8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN9Animation12AddToManagerEv($this) {
 $this = $this|0;
 var $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 236|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 240|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($1) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = HEAP32[$0>>2]|0;
  $7 = HEAP32[$3>>2]|0;
  HEAP32[$7>>2] = $6;
  HEAP32[$0>>2] = 0;
  HEAP32[$3>>2] = 0;
 }
 $8 = (__Z14IsWorldPlayingv()|0);
 if (!($8)) {
  $52 = (($this) + 24|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   STACKTOP = sp;return;
  }
  $55 = (__ZNK5Unity10GameObject8IsActiveEv($53)|0);
  if (!($55)) {
   STACKTOP = sp;return;
  }
  $56 = (__Z19GetAnimationManagerv()|0);
  $57 = ($0|0)==($56|0);
  if ($57) {
   STACKTOP = sp;return;
  }
  $58 = HEAP32[$0>>2]|0;
  $59 = ($58|0)==(0|0);
  $$pre$i$i$i = (($this) + 240|0);
  if (!($59)) {
   $60 = HEAP32[$$pre$i$i$i>>2]|0;
   $61 = (($58) + 4|0);
   HEAP32[$61>>2] = $60;
   $62 = HEAP32[$0>>2]|0;
   $63 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$63>>2] = $62;
   HEAP32[$0>>2] = 0;
   HEAP32[$$pre$i$i$i>>2] = 0;
  }
  $64 = HEAP32[$56>>2]|0;
  HEAP32[$0>>2] = $64;
  HEAP32[$$pre$i$i$i>>2] = $56;
  $65 = (($64) + 4|0);
  HEAP32[$65>>2] = $0;
  $66 = HEAP32[$$pre$i$i$i>>2]|0;
  HEAP32[$66>>2] = $0;
  STACKTOP = sp;return;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 38|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $15 = (($this) + 40|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0);
  if (!($17)) {
   STACKTOP = sp;return;
  }
 }
 $18 = (($this) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $21 = (__ZNK5Unity10GameObject8IsActiveEv($19)|0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 88|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 92|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($23|0)==($25|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (($this) + 37|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 $30 = (__Z19GetAnimationManagerv()|0);
 if ($29) {
  $31 = ($0|0)==($30|0);
  if ($31) {
   STACKTOP = sp;return;
  }
  $32 = HEAP32[$0>>2]|0;
  $33 = ($32|0)==(0|0);
  $$pre$i$i$i4 = (($this) + 240|0);
  if (!($33)) {
   $34 = HEAP32[$$pre$i$i$i4>>2]|0;
   $35 = (($32) + 4|0);
   HEAP32[$35>>2] = $34;
   $36 = HEAP32[$0>>2]|0;
   $37 = HEAP32[$$pre$i$i$i4>>2]|0;
   HEAP32[$37>>2] = $36;
   HEAP32[$0>>2] = 0;
   HEAP32[$$pre$i$i$i4>>2] = 0;
  }
  $38 = HEAP32[$30>>2]|0;
  HEAP32[$0>>2] = $38;
  HEAP32[$$pre$i$i$i4>>2] = $30;
  $39 = (($38) + 4|0);
  HEAP32[$39>>2] = $0;
  $40 = HEAP32[$$pre$i$i$i4>>2]|0;
  HEAP32[$40>>2] = $0;
  STACKTOP = sp;return;
 } else {
  $41 = (($30) + 8|0);
  $42 = ($0|0)==($41|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $43 = HEAP32[$0>>2]|0;
  $44 = ($43|0)==(0|0);
  $$pre$i$i$i1 = (($this) + 240|0);
  if (!($44)) {
   $45 = HEAP32[$$pre$i$i$i1>>2]|0;
   $46 = (($43) + 4|0);
   HEAP32[$46>>2] = $45;
   $47 = HEAP32[$0>>2]|0;
   $48 = HEAP32[$$pre$i$i$i1>>2]|0;
   HEAP32[$48>>2] = $47;
   HEAP32[$0>>2] = 0;
   HEAP32[$$pre$i$i$i1>>2] = 0;
  }
  $49 = HEAP32[$41>>2]|0;
  HEAP32[$0>>2] = $49;
  HEAP32[$$pre$i$i$i1>>2] = $41;
  $50 = (($49) + 4|0);
  HEAP32[$50>>2] = $0;
  $51 = HEAP32[$$pre$i$i$i1>>2]|0;
  HEAP32[$51>>2] = $0;
  STACKTOP = sp;return;
 }
}
function __ZN9Animation17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 236|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 240|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $6;
 HEAP32[$0>>2] = 0;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9Animation9CrossFadeERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEfi($this,$name,$time,$mode) {
 $this = $this|0;
 $name = $name|0;
 $time = Math_fround($time);
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 8|0;
 $1 = (__ZN9Animation8GetStateERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$name)|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN9Animation9CrossFadeER14AnimationStatefib($this,$1,$time,$mode,1);
  STACKTOP = sp;return;
 }
 $3 = HEAP8[$name>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = (($name) + 1|0);
  $9 = (($name) + 1|0);
  $10 = $8;$11 = $9;
 } else {
  $6 = (($name) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $10 = $7;$11 = $7;
 }
 HEAP32[$vararg_buffer>>2] = $10;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $11;
 __Z6FormatPKcz($0,764792,$vararg_buffer);
 $12 = ($this|0)==(0|0);
 if ($12) {
  $22 = 0;
 } else {
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $22 = $14;
 }
 $15 = HEAP8[$0>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $20 = (($0) + 1|0);
  $21 = $20;
 } else {
  $18 = (($0) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $21 = $19;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($21|0),0,(765224|0),421,1,($22|0),0,(0|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $32 = HEAP8[$0>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   ___resumeException($30|0);
   // unreachable;
  }
  $35 = (($0) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  __ZdlPv($36);
  ___resumeException($30|0);
  // unreachable;
 } else {
  $25 = HEAP8[$0>>0]|0;
  $26 = $25 & 1;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   STACKTOP = sp;return;
  }
  $28 = (($0) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  __ZdlPv($29);
  STACKTOP = sp;return;
 }
}
function __ZN9Animation14QueueCrossFadeER14AnimationStatefii($this,$originalState,$time,$queueMode,$mode) {
 $this = $this|0;
 $originalState = $originalState|0;
 $time = Math_fround($time);
 $queueMode = $queueMode|0;
 $mode = $mode|0;
 var $$0 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $queue = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $0 = sp + 24|0;
 $queue = sp + 8|0;
 $1 = (__ZN9Animation14CloneAnimationEP14AnimationState($this,$originalState)|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $36 = (($1) + 56|0);
  $37 = HEAP16[$36>>1]|0;
  $38 = $37 | 8;
  HEAP16[$36>>1] = $38;
  $39 = ($queueMode|0)==(0);
  if (!($39)) {
   __ZN9Animation9CrossFadeER14AnimationStatefib($this,$1,$time,$mode,1);
   $$0 = $1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$queue>>2] = $mode;
  $40 = (($queue) + 4|0);
  HEAP32[$40>>2] = 0;
  $41 = (($queue) + 8|0);
  HEAPF32[$41>>2] = $time;
  $42 = (($queue) + 12|0);
  HEAP32[$42>>2] = $1;
  $43 = (($this) + 280|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($this) + 284|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($44|0)==($46|0);
  if ($47) {
   $51 = (($this) + 276|0);
   __ZNSt3__16vectorI15QueuedAnimation13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($51,$queue);
   $$0 = $1;
   STACKTOP = sp;return ($$0|0);
  }
  $48 = ($44|0)==(0|0);
  if ($48) {
   $50 = 0;
  } else {
   ;HEAP32[$44+0>>2]=HEAP32[$queue+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$queue+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$queue+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$queue+12>>2]|0;
   $$pre$i = HEAP32[$43>>2]|0;
   $50 = $$pre$i;
  }
  $49 = (($50) + 16|0);
  HEAP32[$43>>2] = $49;
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($originalState) + 112|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $9 = (($3) + 1|0);
  $10 = $9;
 } else {
  $7 = (($originalState) + 120|0);
  $8 = HEAP32[$7>>2]|0;
  $10 = $8;
 }
 HEAP32[$vararg_buffer>>2] = $10;
 __Z6FormatPKcz($0,764968,$vararg_buffer);
 $11 = ($this|0)==(0|0);
 if ($11) {
  $21 = 0;
 } else {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $21 = $13;
 }
 $14 = HEAP8[$0>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $19 = (($0) + 1|0);
  $20 = $19;
 } else {
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $20 = $18;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($20|0),0,(765224|0),524,1,($21|0),0,(0|0));
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  $31 = HEAP8[$0>>0]|0;
  $32 = $31 & 1;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   ___resumeException($29|0);
   // unreachable;
  }
  $34 = (($0) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  __ZdlPv($35);
  ___resumeException($29|0);
  // unreachable;
 } else {
  $24 = HEAP8[$0>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $27 = (($0) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  __ZdlPv($28);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9Animation9CrossFadeER14AnimationStatefib($this,$playState,$time,$mode,$clearQueuedAnimations) {
 $this = $this|0;
 $playState = $playState|0;
 $time = Math_fround($time);
 $mode = $mode|0;
 $clearQueuedAnimations = $clearQueuedAnimations|0;
 var $$idx = 0, $$sum$i = 0, $$sum1$i = 0, $$sum1$i$us = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$us = 0, $found$0$off0$lcssa = 0, $found$0$off012 = 0, $found$0$off012$us = 0, $found$1$off0 = 0, $found$1$off0$us = 0, $i1$0$ph14 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$us = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$us = 0, $uglygep$i$i$i = 0;
 var $uglygep$i$i$i$us = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$us = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 L1: do {
  if ($5) {
   $found$0$off0$lcssa = 0;
  } else {
   $6 = $mode & 4;
   $7 = ($6|0)==(0);
   $8 = (($playState) + 32|0);
   $9 = $time > Math_fround(0.00100000004749745130539);
   if ($7) {
    $11 = $2;$found$0$off012$us = 0;
   } else {
    $22 = $2;$found$0$off012 = 0;
    while(1) {
     $21 = HEAP32[$22>>2]|0;
     $23 = ($21|0)==($playState|0);
     do {
      if ($23) {
       __ZN14AnimationState10SetEnabledEb($playState,1);
       if ($9) {
        __ZN14AnimationState15SetWeightTargetEffb($playState,Math_fround(1.0),$time,0);
       } else {
        __ZN14AnimationState24SetWeightTargetImmediateEfb($playState,Math_fround(1.0),0);
       }
       __ZN14AnimationState12SetupFadeoutEf($playState,$time);
       $found$1$off0 = 1;
      } else {
       if ($9) {
        __ZN14AnimationState15SetWeightTargetEffb($21,Math_fround(0.0),$time,1);
        $found$1$off0 = $found$0$off012;
        break;
       } else {
        __ZN14AnimationState4StopEv($21);
        $24 = (($21) + 8|0);
        HEAPF32[$24>>2] = Math_fround(0.0);
        $found$1$off0 = $found$0$off012;
        break;
       }
      }
     } while(0);
     $25 = (($22) + 4|0);
     $26 = HEAP32[$3>>2]|0;
     $27 = ($25|0)==($26|0);
     if ($27) {
      $found$0$off0$lcssa = $found$1$off0;
      break L1;
     } else {
      $22 = $25;$found$0$off012 = $found$1$off0;
     }
    }
   }
   while(1) {
    $10 = HEAP32[$11>>2]|0;
    $12 = (($10) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[$8>>2]|0;
    $15 = ($13|0)==($14|0);
    do {
     if ($15) {
      $16 = ($10|0)==($playState|0);
      if (!($16)) {
       if ($9) {
        __ZN14AnimationState15SetWeightTargetEffb($10,Math_fround(0.0),$time,1);
        $found$1$off0$us = $found$0$off012$us;
        break;
       } else {
        __ZN14AnimationState4StopEv($10);
        $17 = (($10) + 8|0);
        HEAPF32[$17>>2] = Math_fround(0.0);
        $found$1$off0$us = $found$0$off012$us;
        break;
       }
      }
      __ZN14AnimationState10SetEnabledEb($playState,1);
      if ($9) {
       __ZN14AnimationState15SetWeightTargetEffb($playState,Math_fround(1.0),$time,0);
      } else {
       __ZN14AnimationState24SetWeightTargetImmediateEfb($playState,Math_fround(1.0),0);
      }
      __ZN14AnimationState12SetupFadeoutEf($playState,$time);
      $found$1$off0$us = 1;
     } else {
      $found$1$off0$us = $found$0$off012$us;
     }
    } while(0);
    $18 = (($11) + 4|0);
    $19 = HEAP32[$3>>2]|0;
    $20 = ($18|0)==($19|0);
    if ($20) {
     $found$0$off0$lcssa = $found$1$off0$us;
     break;
    } else {
     $11 = $18;$found$0$off012$us = $found$1$off0$us;
    }
   }
  }
 } while(0);
 L33: do {
  if ($clearQueuedAnimations) {
   $28 = (($this) + 280|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($this) + 276|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($29|0)==($31|0);
   if (!($32)) {
    $33 = $mode & 4;
    $34 = ($33|0)==(0);
    $35 = (($playState) + 32|0);
    $141 = $29;$142 = $31;$i1$0$ph14 = 0;
    while(1) {
     $$idx = $i1$0$ph14 << 4;
     $36 = $$idx >> 4;
     $$sum$i = (($36) + 1)|0;
     if ($34) {
      $38 = $142;$73 = $141;
     } else {
      $79 = $142;
      break;
     }
     while(1) {
      $37 = ((($38) + ($i1$0$ph14<<4)|0) + 12|0);
      $39 = HEAP32[$37>>2]|0;
      $40 = (($39) + 32|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = HEAP32[$35>>2]|0;
      $43 = ($41|0)==($42|0);
      if (!($43)) {
       break;
      }
      __ZN14AnimationState4StopEv($39);
      $44 = HEAP32[$30>>2]|0;
      $45 = ((($44) + ($i1$0$ph14<<4)|0) + 12|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = (($46) + 56|0);
      $48 = HEAP16[$47>>1]|0;
      $49 = $48 | 72;
      HEAP16[$47>>1] = $49;
      $50 = HEAP32[$30>>2]|0;
      $51 = (($50) + ($36<<4)|0);
      $52 = (($50) + ($$sum$i<<4)|0);
      $53 = HEAP32[$28>>2]|0;
      $54 = $53;
      $55 = $52;
      $56 = (($54) - ($55))|0;
      $57 = $56 >> 4;
      _memmove(($51|0),($52|0),($56|0))|0;
      $$sum1$i$us = (($57) + ($36))|0;
      $58 = (($50) + ($$sum1$i$us<<4)|0);
      $59 = HEAP32[$28>>2]|0;
      $60 = ($59|0)==($58|0);
      if ($60) {
       $66 = $58;
      } else {
       $__new_last2$i$i$i$us = $58;
       $scevgep$i$i$i$us = (($59) + -16|0);
       $61 = (0 - ($__new_last2$i$i$i$us))|0;
       $uglygep$i$i$i$us = (($scevgep$i$i$i$us) + ($61)|0);
       $uglygep3$i$i$i$us = $uglygep$i$i$i$us;
       $62 = $uglygep3$i$i$i$us >>> 4;
       $63 = $62 ^ -1;
       $scevgep4$i$i$i$us = (($59) + ($63<<4)|0);
       HEAP32[$28>>2] = $scevgep4$i$i$i$us;
       $66 = $scevgep4$i$i$i$us;
      }
      $64 = HEAP32[$30>>2]|0;
      $65 = $66;
      $67 = $64;
      $68 = (($65) - ($67))|0;
      $69 = $68 >> 4;
      $70 = ($i1$0$ph14>>>0)<($69>>>0);
      if ($70) {
       $38 = $64;$73 = $66;
      } else {
       break L33;
      }
     }
     $71 = (($i1$0$ph14) + 1)|0;
     $72 = $73;
     $74 = $38;
     $75 = (($72) - ($74))|0;
     $76 = $75 >> 4;
     $77 = ($71>>>0)<($76>>>0);
     if ($77) {
      $141 = $73;$142 = $38;$i1$0$ph14 = $71;
     } else {
      break L33;
     }
    }
    while(1) {
     $78 = ((($79) + ($i1$0$ph14<<4)|0) + 12|0);
     $80 = HEAP32[$78>>2]|0;
     __ZN14AnimationState4StopEv($80);
     $81 = HEAP32[$30>>2]|0;
     $82 = ((($81) + ($i1$0$ph14<<4)|0) + 12|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = (($83) + 56|0);
     $85 = HEAP16[$84>>1]|0;
     $86 = $85 | 72;
     HEAP16[$84>>1] = $86;
     $87 = HEAP32[$30>>2]|0;
     $88 = (($87) + ($36<<4)|0);
     $89 = (($87) + ($$sum$i<<4)|0);
     $90 = HEAP32[$28>>2]|0;
     $91 = $90;
     $92 = $89;
     $93 = (($91) - ($92))|0;
     $94 = $93 >> 4;
     _memmove(($88|0),($89|0),($93|0))|0;
     $$sum1$i = (($94) + ($36))|0;
     $95 = (($87) + ($$sum1$i<<4)|0);
     $96 = HEAP32[$28>>2]|0;
     $97 = ($96|0)==($95|0);
     if ($97) {
      $100 = $95;
     } else {
      $__new_last2$i$i$i = $95;
      $scevgep$i$i$i = (($96) + -16|0);
      $105 = (0 - ($__new_last2$i$i$i))|0;
      $uglygep$i$i$i = (($scevgep$i$i$i) + ($105)|0);
      $uglygep3$i$i$i = $uglygep$i$i$i;
      $106 = $uglygep3$i$i$i >>> 4;
      $107 = $106 ^ -1;
      $scevgep4$i$i$i = (($96) + ($107<<4)|0);
      HEAP32[$28>>2] = $scevgep4$i$i$i;
      $100 = $scevgep4$i$i$i;
     }
     $98 = HEAP32[$30>>2]|0;
     $99 = $100;
     $101 = $98;
     $102 = (($99) - ($101))|0;
     $103 = $102 >> 4;
     $104 = ($i1$0$ph14>>>0)<($103>>>0);
     if ($104) {
      $79 = $98;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 if ($found$0$off0$lcssa) {
  STACKTOP = sp;return;
 }
 $108 = (($playState) + 112|0);
 $109 = HEAP8[$108>>0]|0;
 $110 = $109 & 1;
 $111 = ($110<<24>>24)==(0);
 if ($111) {
  $114 = (($108) + 1|0);
  $115 = $114;
 } else {
  $112 = (($playState) + 120|0);
  $113 = HEAP32[$112>>2]|0;
  $115 = $113;
 }
 HEAP32[$vararg_buffer>>2] = $115;
 __Z6FormatPKcz($0,764968,$vararg_buffer);
 $116 = ($this|0)==(0|0);
 if ($116) {
  $126 = 0;
 } else {
  $117 = (($this) + 4|0);
  $118 = HEAP32[$117>>2]|0;
  $126 = $118;
 }
 $119 = HEAP8[$0>>0]|0;
 $120 = $119 & 1;
 $121 = ($120<<24>>24)==(0);
 if ($121) {
  $124 = (($0) + 1|0);
  $125 = $124;
 } else {
  $122 = (($0) + 8|0);
  $123 = HEAP32[$122>>2]|0;
  $125 = $123;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($125|0),0,(765224|0),516,1,($126|0),0,(0|0));
 $127 = __THREW__; __THREW__ = 0;
 $128 = $127&1;
 if ($128) {
  $134 = ___cxa_find_matching_catch()|0;
  $135 = tempRet0;
  $136 = HEAP8[$0>>0]|0;
  $137 = $136 & 1;
  $138 = ($137<<24>>24)==(0);
  if ($138) {
   ___resumeException($134|0);
   // unreachable;
  }
  $139 = (($0) + 8|0);
  $140 = HEAP32[$139>>2]|0;
  __ZdlPv($140);
  ___resumeException($134|0);
  // unreachable;
 } else {
  $129 = HEAP8[$0>>0]|0;
  $130 = $129 & 1;
  $131 = ($130<<24>>24)==(0);
  if ($131) {
   STACKTOP = sp;return;
  }
  $132 = (($0) + 8|0);
  $133 = HEAP32[$132>>2]|0;
  __ZdlPv($133);
  STACKTOP = sp;return;
 }
}
function __ZN9Animation14CloneAnimationEP14AnimationState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$byval_copy4 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $clone = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy4 = sp + 40|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $clone = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 28|0;
 __ZN9Animation20BuildAnimationStatesEv($this);
 $5 = (($this) + 88|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 92|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  $$03 = 0;
  STACKTOP = sp;return ($$03|0);
 } else {
  $13 = $6;
 }
 while(1) {
  $12 = HEAP32[$13>>2]|0;
  $14 = ($12|0)==($state|0);
  $11 = (($13) + 4|0);
  if ($14) {
   break;
  }
  $10 = ($11|0)==($8|0);
  if ($10) {
   $$03 = 0;
   label = 38;
   break;
  } else {
   $13 = $11;
  }
 }
 if ((label|0) == 38) {
  STACKTOP = sp;return ($$03|0);
 }
 $15 = ($state|0)==(0|0);
 if ($15) {
  $$03 = 0;
  STACKTOP = sp;return ($$03|0);
 }
 $16 = (__Znwj(152)|0);
 __THREW__ = 0;
 invoke_vi(3678,($16|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $95 = ___cxa_find_matching_catch()|0;
  $96 = tempRet0;
  __ZdlPv($16);
  $$1 = $96;$$12 = $95;
  ___resumeException($$12|0);
  // unreachable;
 }
 HEAP32[$clone>>2] = $16;
 $19 = (($state) + 112|0);
 __ZNSt3__1plIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEENS_12basic_stringIT_T0_T1_EERKSA_PKS7_($4,$19,765368);
 $20 = HEAP8[$4>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $27 = (($4) + 1|0);
  $28 = $20&255;
  $29 = $28 >>> 1;
  $31 = $29;$46 = $27;
 } else {
  $23 = (($4) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($4) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $31 = $26;$46 = $24;
 }
 $30 = ($31>>>0)>(2147483631);
 do {
  if ($30) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    label = 31;
   } else {
    // unreachable;
   }
  } else {
   $34 = ($31>>>0)<(11);
   if ($34) {
    $35 = $31 << 1;
    $36 = $35&255;
    HEAP8[$3>>0] = $36;
    $37 = (($3) + 1|0);
    $__p$0$i$i$i$i = $37;
   } else {
    $38 = (($31) + 16)|0;
    $39 = $38 & -16;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    $40 = (invoke_iiiiiii(102,($39|0),16,($$byval_copy4|0),0,(765224|0),79)|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 31;
     break;
    }
    $43 = (($3) + 8|0);
    HEAP32[$43>>2] = $40;
    $44 = $39 | 1;
    HEAP32[$3>>2] = $44;
    $45 = (($3) + 4|0);
    HEAP32[$45>>2] = $31;
    $__p$0$i$i$i$i = $40;
   }
   _memcpy(($__p$0$i$i$i$i|0),($46|0),($31|0))|0;
   $47 = (($__p$0$i$i$i$i) + ($31)|0);
   HEAP8[$47>>0] = 0;
   $48 = (($state) + 96|0);
   $49 = HEAP32[$48>>2]|0;
   __THREW__ = 0;
   $50 = (invoke_i(87)|0);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if (!($52)) {
    $53 = (($50) + 88|0);
    $54 = +HEAPF64[$53>>3];
    $55 = (($state) + 68|0);
    $56 = HEAP32[$55>>2]|0;
    __THREW__ = 0;
    invoke_viiidii(1,($16|0),($3|0),($49|0),(+$54),($56|0),1);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if (!($58)) {
     $59 = HEAP8[$3>>0]|0;
     $60 = $59 & 1;
     $61 = ($60<<24>>24)==(0);
     if (!($61)) {
      $62 = (($3) + 8|0);
      $63 = HEAP32[$62>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($63|0),($$byval_copy4|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       $66 = ___cxa_find_matching_catch()|0;
       $67 = tempRet0;
       ___cxa_call_unexpected(($66|0));
       // unreachable;
      }
     }
     $68 = HEAP8[$4>>0]|0;
     $69 = $68 & 1;
     $70 = ($69<<24>>24)==(0);
     if (!($70)) {
      $71 = (($4) + 8|0);
      $72 = HEAP32[$71>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($72|0),($$byval_copy4|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       $75 = ___cxa_find_matching_catch()|0;
       $76 = tempRet0;
       ___cxa_call_unexpected(($75|0));
       // unreachable;
      }
     }
     $77 = (($16) + 124|0);
     (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($77,$19)|0);
     $78 = (($state) + 32|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($16) + 32|0);
     HEAP32[$80>>2] = $79;
     $81 = (($16) + 64|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = $82 | 2;
     HEAP32[$81>>2] = $83;
     __ZN14AnimationState15SetClonedCurvesERS_($16,$state);
     HEAP32[$81>>2] = 0;
     $84 = HEAP32[$7>>2]|0;
     $85 = (($this) + 96|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($84|0)==($86|0);
     if ($87) {
      $91 = (($this) + 88|0);
      __ZNSt3__16vectorIP14AnimationState13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($91,$clone);
      $$pre = HEAP32[$clone>>2]|0;
      $119 = $$pre;
     } else {
      $88 = ($84|0)==(0|0);
      if ($88) {
       $90 = 0;
      } else {
       HEAP32[$84>>2] = $16;
       $$pre$i = HEAP32[$7>>2]|0;
       $90 = $$pre$i;
      }
      $89 = (($90) + 4|0);
      HEAP32[$7>>2] = $89;
      $119 = $16;
     }
     $92 = (($this) + 232|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = $93 | 2;
     HEAP32[$92>>2] = $94;
     $$03 = $119;
     STACKTOP = sp;return ($$03|0);
    }
   }
   $99 = ___cxa_find_matching_catch()|0;
   $100 = tempRet0;
   $101 = HEAP8[$3>>0]|0;
   $102 = $101 & 1;
   $103 = ($102<<24>>24)==(0);
   if ($103) {
    $$0 = $100;$$01 = $99;
   } else {
    $104 = (($3) + 8|0);
    $105 = HEAP32[$104>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($105|0),($$byval_copy4|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     $108 = ___cxa_find_matching_catch()|0;
     $109 = tempRet0;
     ___cxa_call_unexpected(($108|0));
     // unreachable;
    } else {
     $$0 = $100;$$01 = $99;
    }
   }
  }
 } while(0);
 if ((label|0) == 31) {
  $97 = ___cxa_find_matching_catch()|0;
  $98 = tempRet0;
  $$0 = $98;$$01 = $97;
 }
 $110 = HEAP8[$4>>0]|0;
 $111 = $110 & 1;
 $112 = ($111<<24>>24)==(0);
 if ($112) {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$12|0);
  // unreachable;
 }
 $113 = (($4) + 8|0);
 $114 = HEAP32[$113>>2]|0;
 HEAP32[$2>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($114|0),($$byval_copy4|0));
 $115 = __THREW__; __THREW__ = 0;
 $116 = $115&1;
 if ($116) {
  $117 = ___cxa_find_matching_catch()|0;
  $118 = tempRet0;
  ___cxa_call_unexpected(($117|0));
  // unreachable;
 } else {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$12|0);
  // unreachable;
 }
 return 0|0;
}
function __Z27InsertAnimationClipCurveIDsR14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS0_EE13stl_allocatorINS2_4pairIKS0_jEEL18MemLabelIdentifier90ELi16EEER13AnimationClip($curveIDLookup,$clip) {
 $curveIDLookup = $curveIDLookup|0;
 $clip = $clip|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $curveID = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 24|0;
 $0 = sp;
 $curveID = sp + 4|0;
 $1 = (($clip) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($clip) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  $6 = (($curveID) + 4|0);
  $7 = (($curveID) + 8|0);
  $8 = (($curveID) + 12|0);
  $9 = (($curveID) + 16|0);
  $11 = $2;
  while(1) {
   $10 = HEAP8[$11>>0]|0;
   $12 = $10 & 1;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    $16 = (($11) + 1|0);
    $19 = $16;
   } else {
    $14 = (($11) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $19 = $15;
   }
   $17 = (($11) + 188|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$curveID>>2] = $19;
   HEAP32[$6>>2] = 4;
   HEAP32[$7>>2] = 765232;
   HEAP32[$8>>2] = 0;
   HEAP32[$9>>2] = $18;
   $20 = HEAP32[$17>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    __ZN7CurveID13CalculateHashEv($curveID);
    $22 = HEAP32[$9>>2]|0;
    HEAP32[$17>>2] = $22;
   }
   (__ZN15AnimationBinder23InsertCurveIDIntoLookupER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEERS8_($curveIDLookup,$curveID)|0);
   $23 = (($11) + 192|0);
   $24 = HEAP32[$3>>2]|0;
   $25 = ($23|0)==($24|0);
   if ($25) {
    break;
   } else {
    $11 = $23;
   }
  }
 }
 $26 = (($clip) + 104|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($clip) + 108|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27|0)==($29|0);
 if (!($30)) {
  $31 = (($curveID) + 4|0);
  $32 = (($curveID) + 8|0);
  $33 = (($curveID) + 12|0);
  $34 = (($curveID) + 16|0);
  $36 = $27;
  while(1) {
   $35 = HEAP8[$36>>0]|0;
   $37 = $35 & 1;
   $38 = ($37<<24>>24)==(0);
   if ($38) {
    $41 = (($36) + 1|0);
    $44 = $41;
   } else {
    $39 = (($36) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $44 = $40;
   }
   $42 = (($36) + 156|0);
   $43 = HEAP32[$42>>2]|0;
   HEAP32[$curveID>>2] = $44;
   HEAP32[$31>>2] = 4;
   HEAP32[$32>>2] = 765248;
   HEAP32[$33>>2] = 0;
   HEAP32[$34>>2] = $43;
   $45 = HEAP32[$42>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    __ZN7CurveID13CalculateHashEv($curveID);
    $47 = HEAP32[$34>>2]|0;
    HEAP32[$42>>2] = $47;
   }
   (__ZN15AnimationBinder23InsertCurveIDIntoLookupER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEERS8_($curveIDLookup,$curveID)|0);
   $48 = (($36) + 160|0);
   $49 = HEAP32[$28>>2]|0;
   $50 = ($48|0)==($49|0);
   if ($50) {
    break;
   } else {
    $36 = $48;
   }
  }
 }
 $51 = (($clip) + 116|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($clip) + 120|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($52|0)==($54|0);
 if (!($55)) {
  $56 = (($curveID) + 4|0);
  $57 = (($curveID) + 8|0);
  $58 = (($curveID) + 12|0);
  $59 = (($curveID) + 16|0);
  $61 = $52;
  while(1) {
   $60 = HEAP8[$61>>0]|0;
   $62 = $60 & 1;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    $66 = (($61) + 1|0);
    $69 = $66;
   } else {
    $64 = (($61) + 8|0);
    $65 = HEAP32[$64>>2]|0;
    $69 = $65;
   }
   $67 = (($61) + 156|0);
   $68 = HEAP32[$67>>2]|0;
   HEAP32[$curveID>>2] = $69;
   HEAP32[$56>>2] = 4;
   HEAP32[$57>>2] = 765264;
   HEAP32[$58>>2] = 0;
   HEAP32[$59>>2] = $68;
   $70 = HEAP32[$67>>2]|0;
   $71 = ($70|0)==(0);
   if ($71) {
    __ZN7CurveID13CalculateHashEv($curveID);
    $72 = HEAP32[$59>>2]|0;
    HEAP32[$67>>2] = $72;
   }
   (__ZN15AnimationBinder23InsertCurveIDIntoLookupER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEERS8_($curveIDLookup,$curveID)|0);
   $73 = (($61) + 160|0);
   $74 = HEAP32[$53>>2]|0;
   $75 = ($73|0)==($74|0);
   if ($75) {
    break;
   } else {
    $61 = $73;
   }
  }
 }
 $76 = (($clip) + 128|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($clip) + 132|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($77|0)==($79|0);
 if ($80) {
  STACKTOP = sp;return;
 }
 $81 = (($curveID) + 4|0);
 $82 = (($curveID) + 8|0);
 $83 = (($curveID) + 12|0);
 $84 = (($curveID) + 16|0);
 $86 = $77;
 while(1) {
  $85 = HEAP8[$86>>0]|0;
  $87 = $85 & 1;
  $88 = ($87<<24>>24)==(0);
  if ($88) {
   $91 = (($86) + 1|0);
   $139 = $91;
  } else {
   $89 = (($86) + 8|0);
   $90 = HEAP32[$89>>2]|0;
   $139 = $90;
  }
  $92 = (($86) + 24|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (($86) + 28|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ($95|0)==(0);
  if ($96) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $95;
   $97 = HEAP32[560624>>2]|0;
   $98 = ($97|0)==(0|0);
   if ($98) {
    label = 39;
   } else {
    $99 = (($97) + 36|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (($97) + 4|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ($100|0)==($102|0);
    do {
     if ($103) {
      $104 = (($97) + 28|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = (($97) + 32|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = (($105) + ($107<<3)|0);
      $124 = $108;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$97,$0);
      $109 = HEAP32[$pos$i$i$i$i>>2]|0;
      $110 = ($109|0)==(-1);
      $111 = (($97) + 28|0);
      $112 = HEAP32[$111>>2]|0;
      if ($110) {
       $113 = (($97) + 32|0);
       $114 = HEAP32[$113>>2]|0;
       $115 = (($112) + ($114<<3)|0);
       $124 = $115;
       break;
      } else {
       $116 = (($112) + ($109<<3)|0);
       $124 = $116;
       break;
      }
     }
    } while(0);
    $117 = HEAP32[560624>>2]|0;
    $118 = (($117) + 28|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($117) + 32|0);
    $121 = HEAP32[$120>>2]|0;
    $122 = (($119) + ($121<<3)|0);
    $123 = ($124|0)==($122|0);
    if ($123) {
     label = 39;
    } else {
     $125 = (($124) + 4|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = ($126|0)==(0|0);
     if ($127) {
      label = 39;
     } else {
      $temp$0$i = $126;
     }
    }
   }
   if ((label|0) == 39) {
    label = 0;
    $128 = HEAP32[$94>>2]|0;
    $129 = (__Z31ReadObjectFromPersistentManageri($128)|0);
    $temp$0$i = $129;
   }
   $$0$i = $temp$0$i;
  }
  $130 = (($86) + 12|0);
  $131 = HEAP8[$130>>0]|0;
  $132 = $131 & 1;
  $133 = ($132<<24>>24)==(0);
  if ($133) {
   $136 = (($130) + 1|0);
   $140 = $136;
  } else {
   $134 = (($86) + 20|0);
   $135 = HEAP32[$134>>2]|0;
   $140 = $135;
  }
  $137 = (($86) + 112|0);
  $138 = HEAP32[$137>>2]|0;
  HEAP32[$curveID>>2] = $139;
  HEAP32[$81>>2] = $93;
  HEAP32[$82>>2] = $140;
  HEAP32[$83>>2] = $$0$i;
  HEAP32[$84>>2] = $138;
  $141 = HEAP32[$137>>2]|0;
  $142 = ($141|0)==(0);
  if ($142) {
   __ZN7CurveID13CalculateHashEv($curveID);
   $143 = HEAP32[$84>>2]|0;
   HEAP32[$137>>2] = $143;
  }
  (__ZN15AnimationBinder23InsertCurveIDIntoLookupER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEERS8_($curveIDLookup,$curveID)|0);
  $144 = (($86) + 116|0);
  $145 = HEAP32[$78>>2]|0;
  $146 = ($144|0)==($145|0);
  if ($146) {
   break;
  } else {
   $86 = $144;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Animation19ValidateBoundCurvesEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + (($4*20)|0)|0);
 $6 = ($4|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $$pre = HEAP32[560624>>2]|0;
 $11 = $$pre;$i$01 = $2;
 while(1) {
  $9 = HEAP32[$i$01>>2]|0;
  HEAP32[$0>>2] = $9;
  $10 = ($11|0)==(0|0);
  if ($10) {
   $$0$i = 0;$54 = 0;
  } else {
   $12 = (($11) + 36|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($13|0)==($15|0);
   do {
    if ($16) {
     $17 = (($11) + 28|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($11) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $37 = $21;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$11,$0);
     $22 = HEAP32[$$byval_copy>>2]|0;
     $23 = ($22|0)==(-1);
     $24 = (($11) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     if ($23) {
      $26 = (($11) + 32|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = (($25) + ($27<<3)|0);
      $37 = $28;
      break;
     } else {
      $29 = (($25) + ($22<<3)|0);
      $37 = $29;
      break;
     }
    }
   } while(0);
   $30 = HEAP32[560624>>2]|0;
   $31 = (($30) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 32|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($32) + ($34<<3)|0);
   $36 = ($37|0)==($35|0);
   if ($36) {
    $$0$i = 0;$54 = $30;
   } else {
    $38 = (($37) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $$0$i = $39;$54 = $30;
   }
  }
  $40 = (($i$01) + 16|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($$0$i|0)==($41|0);
  $8 = (($i$01) + 20|0);
  if (!($42)) {
   break;
  }
  $7 = ($8|0)==($5|0);
  if ($7) {
   label = 17;
   break;
  } else {
   $11 = $54;$i$01 = $8;
  }
 }
 if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
 $43 = HEAP32[$3>>2]|0;
 $44 = ($43|0)==(0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = (($this) + 84|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)>(-1);
 if ($47) {
  $48 = HEAP32[$1>>2]|0;
  $49 = (($this) + 76|0);
  $50 = HEAP32[$49>>2]|0;
  HEAP32[$0>>2] = $50;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($48,$$byval_copy);
  HEAP32[$1>>2] = 0;
 }
 HEAP32[$3>>2] = 0;
 HEAP32[$45>>2] = 0;
 $51 = (($this) + 232|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 | 1;
 HEAP32[$51>>2] = $53;
 STACKTOP = sp;return;
}
function __ZN9Animation25RebuildStateForEverythingEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i$i = 0, $$byval_copy21 = 0, $$pre = 0, $$pre$i = 0, $$pre35 = 0, $$pre37$i = 0, $$pre38$i = 0, $$pre39$i = 0, $$sink$index17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $curveID$i = 0, $curveIDLookup = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0, $s$028 = 0, $s1$020 = 0, $temp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy21 = sp + 112|0;
 $0 = sp;
 $curveID$i = sp + 4|0;
 $1 = sp + 24|0;
 $curveIDLookup = sp + 28|0;
 $2 = (($curveIDLookup) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($curveIDLookup) + 8|0);
 HEAP8[$3>>0] = 0;
 $4 = (($curveIDLookup) + 9|0);
 HEAP8[$4>>0] = 0;
 $5 = (($curveIDLookup) + 32|0);
 HEAP32[$5>>2] = 0;
 $6 = (($curveIDLookup) + 56|0);
 HEAP32[$6>>2] = 0;
 $7 = (($curveIDLookup) + 60|0);
 HEAP32[$7>>2] = 0;
 $8 = (($curveIDLookup) + 64|0);
 HEAP32[$8>>2] = 32;
 $9 = (($curveIDLookup) + 68|0);
 HEAP32[$9>>2] = 0;
 $10 = (($curveIDLookup) + 76|0);
 HEAP32[$10>>2] = 16;
 $11 = (($curveIDLookup) + 72|0);
 HEAP32[$11>>2] = 6;
 $12 = (($curveIDLookup) + 80|0);
 HEAP8[$12>>0] = 0;
 __THREW__ = 0;
 invoke_vi(3679,($curveIDLookup|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  $$0 = $32;$$sink$index17 = $33;
 } else {
  $15 = (($this) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_ii(3220,($16|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  L4: do {
   if ($19) {
    label = 13;
   } else {
    $20 = ($17|0)==(0|0);
    L6: do {
     if (!($20)) {
      $21 = (($this) + 92|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($this) + 88|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($22|0)==($24|0);
      L8: do {
       if (!($25)) {
        $252 = $22;$27 = $24;$s$028 = 0;
        while(1) {
         $26 = (($27) + ($s$028<<2)|0);
         $28 = HEAP32[$26>>2]|0;
         $29 = (($28) + 96|0);
         $30 = HEAP32[$29>>2]|0;
         $31 = ($30|0)==(0|0);
         if ($31) {
          $52 = $252;$54 = $27;
         } else {
          __THREW__ = 0;
          invoke_vii(3357,($curveIDLookup|0),($30|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          $$pre = HEAP32[$21>>2]|0;
          $$pre35 = HEAP32[$23>>2]|0;
          $52 = $$pre;$54 = $$pre35;
         }
         $50 = (($s$028) + 1)|0;
         $51 = $52;
         $53 = $54;
         $55 = (($51) - ($53))|0;
         $56 = $55 >> 2;
         $57 = ($50>>>0)<($56>>>0);
         if ($57) {
          $252 = $52;$27 = $54;$s$028 = $50;
         } else {
          break L8;
         }
        }
        $44 = ___cxa_find_matching_catch()|0;
        $45 = tempRet0;
        $lpad$phi$index = $44;$lpad$phi$index7 = $45;
        break L4;
       }
      } while(0);
      __THREW__ = 0;
      $58 = (invoke_i(121)|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 13;
       break L4;
      }
      $61 = (($this) + 72|0);
      $62 = (($this) + 44|0);
      $63 = (($this) + 56|0);
      __THREW__ = 0;
      invoke_viiiiii(130,($58|0),($curveIDLookup|0),($17|0),($61|0),($62|0),($63|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 13;
       break L4;
      }
      __THREW__ = 0;
      invoke_vii(3358,($curveIDLookup|0),($61|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 13;
       break L4;
      }
      $68 = HEAP32[$21>>2]|0;
      $69 = HEAP32[$23>>2]|0;
      $70 = ($68|0)==($69|0);
      if (!($70)) {
       $71 = (($curveID$i) + 4|0);
       $72 = (($curveID$i) + 8|0);
       $73 = (($curveID$i) + 12|0);
       $74 = (($curveID$i) + 16|0);
       $76 = $69;$s1$020 = 0;
       L21: while(1) {
        $75 = (($76) + ($s1$020<<2)|0);
        $77 = HEAP32[$75>>2]|0;
        __THREW__ = 0;
        invoke_vi(3680,($77|0));
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 11;
         break;
        }
        $80 = HEAP32[$9>>2]|0;
        $81 = HEAP32[$2>>2]|0;
        $82 = (($80) - ($81))|0;
        __THREW__ = 0;
        invoke_vii(3359,($77|0),($82|0));
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 11;
         break;
        }
        $85 = (($77) + 96|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = ($86|0)==(0|0);
        if (!($87)) {
         $88 = (($86) + 92|0);
         $89 = HEAP32[$88>>2]|0;
         $90 = (($86) + 96|0);
         $91 = HEAP32[$90>>2]|0;
         $92 = ($89|0)==($91|0);
         if (!($92)) {
          $253 = $91;$94 = $89;
          while(1) {
           $93 = (($94) + 12|0);
           $95 = (($94) + 172|0);
           $96 = HEAP32[$95>>2]|0;
           $97 = ($96|0)==(0);
           if ($97) {
            $111 = $253;
           } else {
            $98 = HEAP8[$94>>0]|0;
            $99 = $98 & 1;
            $100 = ($99<<24>>24)==(0);
            if ($100) {
             $103 = (($94) + 1|0);
             $106 = $103;
            } else {
             $101 = (($94) + 8|0);
             $102 = HEAP32[$101>>2]|0;
             $106 = $102;
            }
            $104 = (($94) + 188|0);
            $105 = HEAP32[$104>>2]|0;
            HEAP32[$curveID$i>>2] = $106;
            HEAP32[$71>>2] = 4;
            HEAP32[$72>>2] = 765232;
            HEAP32[$73>>2] = 0;
            HEAP32[$74>>2] = $105;
            __THREW__ = 0;
            invoke_viiiii(108,($curveIDLookup|0),($curveID$i|0),($93|0),($61|0),($77|0));
            $107 = __THREW__; __THREW__ = 0;
            $108 = $107&1;
            if ($108) {
             label = 7;
             break L21;
            }
            $$pre39$i = HEAP32[$90>>2]|0;
            $111 = $$pre39$i;
           }
           $109 = (($94) + 192|0);
           $110 = ($109|0)==($111|0);
           if ($110) {
            break;
           } else {
            $253 = $111;$94 = $109;
           }
          }
         }
         $112 = (($86) + 104|0);
         $113 = HEAP32[$112>>2]|0;
         $114 = (($86) + 108|0);
         $115 = HEAP32[$114>>2]|0;
         $116 = ($113|0)==($115|0);
         if (!($116)) {
          $118 = $113;$254 = $115;
          while(1) {
           $117 = (($118) + 12|0);
           $119 = (($118) + 140|0);
           $120 = HEAP32[$119>>2]|0;
           $121 = ($120|0)==(0);
           if ($121) {
            $135 = $254;
           } else {
            $122 = HEAP8[$118>>0]|0;
            $123 = $122 & 1;
            $124 = ($123<<24>>24)==(0);
            if ($124) {
             $127 = (($118) + 1|0);
             $130 = $127;
            } else {
             $125 = (($118) + 8|0);
             $126 = HEAP32[$125>>2]|0;
             $130 = $126;
            }
            $128 = (($118) + 156|0);
            $129 = HEAP32[$128>>2]|0;
            HEAP32[$curveID$i>>2] = $130;
            HEAP32[$71>>2] = 4;
            HEAP32[$72>>2] = 765248;
            HEAP32[$73>>2] = 0;
            HEAP32[$74>>2] = $129;
            __THREW__ = 0;
            invoke_viiiii(108,($curveIDLookup|0),($curveID$i|0),($117|0),($61|0),($77|0));
            $131 = __THREW__; __THREW__ = 0;
            $132 = $131&1;
            if ($132) {
             label = 8;
             break L21;
            }
            $$pre38$i = HEAP32[$114>>2]|0;
            $135 = $$pre38$i;
           }
           $133 = (($118) + 160|0);
           $134 = ($133|0)==($135|0);
           if ($134) {
            break;
           } else {
            $118 = $133;$254 = $135;
           }
          }
         }
         $136 = (($86) + 116|0);
         $137 = HEAP32[$136>>2]|0;
         $138 = (($86) + 120|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = ($137|0)==($139|0);
         if (!($140)) {
          $142 = $137;$255 = $139;
          while(1) {
           $141 = (($142) + 12|0);
           $143 = (($142) + 140|0);
           $144 = HEAP32[$143>>2]|0;
           $145 = ($144|0)==(0);
           if ($145) {
            $159 = $255;
           } else {
            $146 = HEAP8[$142>>0]|0;
            $147 = $146 & 1;
            $148 = ($147<<24>>24)==(0);
            if ($148) {
             $151 = (($142) + 1|0);
             $154 = $151;
            } else {
             $149 = (($142) + 8|0);
             $150 = HEAP32[$149>>2]|0;
             $154 = $150;
            }
            $152 = (($142) + 156|0);
            $153 = HEAP32[$152>>2]|0;
            HEAP32[$curveID$i>>2] = $154;
            HEAP32[$71>>2] = 4;
            HEAP32[$72>>2] = 765264;
            HEAP32[$73>>2] = 0;
            HEAP32[$74>>2] = $153;
            __THREW__ = 0;
            invoke_viiiii(108,($curveIDLookup|0),($curveID$i|0),($141|0),($61|0),($77|0));
            $155 = __THREW__; __THREW__ = 0;
            $156 = $155&1;
            if ($156) {
             label = 9;
             break L21;
            }
            $$pre37$i = HEAP32[$138>>2]|0;
            $159 = $$pre37$i;
           }
           $157 = (($142) + 160|0);
           $158 = ($157|0)==($159|0);
           if ($158) {
            break;
           } else {
            $142 = $157;$255 = $159;
           }
          }
         }
         $160 = (($86) + 128|0);
         $161 = HEAP32[$160>>2]|0;
         $162 = (($86) + 132|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = ($161|0)==($163|0);
         if (!($164)) {
          $166 = $161;$256 = $163;
          while(1) {
           $165 = (($166) + 32|0);
           $167 = (($166) + 96|0);
           $168 = HEAP32[$167>>2]|0;
           $169 = ($168|0)==(0);
           if ($169) {
            $231 = $256;
           } else {
            $170 = HEAP8[$166>>0]|0;
            $171 = $170 & 1;
            $172 = ($171<<24>>24)==(0);
            if ($172) {
             $175 = (($166) + 1|0);
             $225 = $175;
            } else {
             $173 = (($166) + 8|0);
             $174 = HEAP32[$173>>2]|0;
             $225 = $174;
            }
            $176 = (($166) + 24|0);
            $177 = HEAP32[$176>>2]|0;
            $178 = (($166) + 28|0);
            $179 = HEAP32[$178>>2]|0;
            $180 = ($179|0)==(0);
            if ($180) {
             $$0$i$i = 0;
            } else {
             HEAP32[$0>>2] = $179;
             $181 = HEAP32[560624>>2]|0;
             $182 = ($181|0)==(0|0);
             do {
              if ($182) {
               label = 64;
              } else {
               $183 = (($181) + 36|0);
               $184 = HEAP32[$183>>2]|0;
               $185 = (($181) + 4|0);
               $186 = HEAP32[$185>>2]|0;
               $187 = ($184|0)==($186|0);
               do {
                if ($187) {
                 $188 = (($181) + 28|0);
                 $189 = HEAP32[$188>>2]|0;
                 $190 = (($181) + 32|0);
                 $191 = HEAP32[$190>>2]|0;
                 $192 = (($189) + ($191<<3)|0);
                 $208 = $192;
                } else {
                 __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy21,$181,$0);
                 $193 = HEAP32[$$byval_copy21>>2]|0;
                 $194 = ($193|0)==(-1);
                 $195 = (($181) + 28|0);
                 $196 = HEAP32[$195>>2]|0;
                 if ($194) {
                  $197 = (($181) + 32|0);
                  $198 = HEAP32[$197>>2]|0;
                  $199 = (($196) + ($198<<3)|0);
                  $208 = $199;
                  break;
                 } else {
                  $200 = (($196) + ($193<<3)|0);
                  $208 = $200;
                  break;
                 }
                }
               } while(0);
               $201 = HEAP32[560624>>2]|0;
               $202 = (($201) + 28|0);
               $203 = HEAP32[$202>>2]|0;
               $204 = (($201) + 32|0);
               $205 = HEAP32[$204>>2]|0;
               $206 = (($203) + ($205<<3)|0);
               $207 = ($208|0)==($206|0);
               if ($207) {
                label = 64;
                break;
               }
               $209 = (($208) + 4|0);
               $210 = HEAP32[$209>>2]|0;
               $211 = ($210|0)==(0|0);
               if ($211) {
                label = 64;
               } else {
                $temp$0$i$i = $210;
               }
              }
             } while(0);
             if ((label|0) == 64) {
              label = 0;
              $212 = HEAP32[$178>>2]|0;
              __THREW__ = 0;
              $213 = (invoke_ii(3215,($212|0))|0);
              $214 = __THREW__; __THREW__ = 0;
              $215 = $214&1;
              if ($215) {
               label = 10;
               break L21;
              } else {
               $temp$0$i$i = $213;
              }
             }
             $$0$i$i = $temp$0$i$i;
            }
            $216 = (($166) + 12|0);
            $217 = HEAP8[$216>>0]|0;
            $218 = $217 & 1;
            $219 = ($218<<24>>24)==(0);
            if ($219) {
             $222 = (($216) + 1|0);
             $226 = $222;
            } else {
             $220 = (($166) + 20|0);
             $221 = HEAP32[$220>>2]|0;
             $226 = $221;
            }
            $223 = (($166) + 112|0);
            $224 = HEAP32[$223>>2]|0;
            HEAP32[$curveID$i>>2] = $225;
            HEAP32[$71>>2] = $177;
            HEAP32[$72>>2] = $226;
            HEAP32[$73>>2] = $$0$i$i;
            HEAP32[$74>>2] = $224;
            __THREW__ = 0;
            invoke_viiiii(108,($curveIDLookup|0),($curveID$i|0),($165|0),($61|0),($77|0));
            $227 = __THREW__; __THREW__ = 0;
            $228 = $227&1;
            if ($228) {
             label = 10;
             break L21;
            }
            $$pre$i = HEAP32[$162>>2]|0;
            $231 = $$pre$i;
           }
           $229 = (($166) + 116|0);
           $230 = ($229|0)==($231|0);
           if ($230) {
            break;
           } else {
            $166 = $229;$256 = $231;
           }
          }
         }
        }
        $232 = (($s1$020) + 1)|0;
        $233 = HEAP32[$21>>2]|0;
        $234 = HEAP32[$23>>2]|0;
        $235 = $233;
        $236 = $234;
        $237 = (($235) - ($236))|0;
        $238 = $237 >> 2;
        $239 = ($232>>>0)<($238>>>0);
        if ($239) {
         $76 = $234;$s1$020 = $232;
        } else {
         break L6;
        }
       }
       if ((label|0) == 7) {
        $34 = ___cxa_find_matching_catch()|0;
        $35 = tempRet0;
        $lpad$phi$index = $34;$lpad$phi$index7 = $35;
        break L4;
       }
       else if ((label|0) == 8) {
        $36 = ___cxa_find_matching_catch()|0;
        $37 = tempRet0;
        $lpad$phi$index = $36;$lpad$phi$index7 = $37;
        break L4;
       }
       else if ((label|0) == 9) {
        $38 = ___cxa_find_matching_catch()|0;
        $39 = tempRet0;
        $lpad$phi$index = $38;$lpad$phi$index7 = $39;
        break L4;
       }
       else if ((label|0) == 10) {
        $40 = ___cxa_find_matching_catch()|0;
        $41 = tempRet0;
        $lpad$phi$index = $40;$lpad$phi$index7 = $41;
        break L4;
       }
       else if ((label|0) == 11) {
        $42 = ___cxa_find_matching_catch()|0;
        $43 = tempRet0;
        $lpad$phi$index = $42;$lpad$phi$index7 = $43;
        break L4;
       }
      }
     }
    } while(0);
    $240 = (($this) + 228|0);
    HEAP32[$240>>2] = 0;
    $241 = (($this) + 232|0);
    $242 = HEAP32[$241>>2]|0;
    $243 = $242 & -2;
    HEAP32[$241>>2] = $243;
    $244 = HEAP32[$7>>2]|0;
    $245 = ($244|0)==(0|0);
    if ($245) {
     STACKTOP = sp;return;
    }
    HEAP32[$1>>2] = 90;
    ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($244,$$byval_copy21);
    STACKTOP = sp;return;
   }
  } while(0);
  if ((label|0) == 13) {
   $46 = ___cxa_find_matching_catch()|0;
   $47 = tempRet0;
   $lpad$phi$index = $46;$lpad$phi$index7 = $47;
  }
  $$0 = $lpad$phi$index;$$sink$index17 = $lpad$phi$index7;
 }
 $246 = HEAP32[$7>>2]|0;
 $247 = ($246|0)==(0|0);
 if ($247) {
  ___resumeException($$0|0);
  // unreachable;
 }
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($246|0),($$byval_copy21|0));
 $248 = __THREW__; __THREW__ = 0;
 $249 = $248&1;
 if ($249) {
  $250 = ___cxa_find_matching_catch(0|0)|0;
  $251 = tempRet0;
  ___clang_call_terminate($250);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __ZN9Animation21RebuildBoundStateMaskEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $activeStateCount$0$lcssa22 = 0, $activeStateCount$011 = 0, $activeStateCount$1 = 0, $i$05 = 0, $or$cond = 0, $requireRebuild$0$off0$lcssa23 = 0, $requireRebuild$0$off09 = 0, $requireRebuild$1$off0 = 0, $s$010 = 0;
 var $s1$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 88|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $activeStateCount$0$lcssa22 = 0;$requireRebuild$0$off0$lcssa23 = 0;
 } else {
  $6 = $3;$63 = $1;$activeStateCount$011 = 0;$requireRebuild$0$off09 = 0;$s$010 = 0;
  while(1) {
   $5 = (($6) + ($s$010<<2)|0);
   $7 = HEAP32[$5>>2]|0;
   $8 = (($7) + 96|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $28 = $63;$30 = $6;$activeStateCount$1 = $activeStateCount$011;$requireRebuild$1$off0 = $requireRebuild$0$off09;
   } else {
    $11 = (($7) + 56|0);
    $12 = HEAP16[$11>>1]|0;
    $13 = $12 & 2;
    $14 = ($13<<16>>16)==(0);
    if ($14) {
     $28 = $63;$30 = $6;$activeStateCount$1 = $activeStateCount$011;$requireRebuild$1$off0 = $requireRebuild$0$off09;
    } else {
     $15 = (($7) + 8|0);
     $16 = Math_fround(HEAPF32[$15>>2]);
     $17 = $16 > Math_fround(9.99999974737875163555E-5);
     if ($17) {
      $18 = (($7) + 72|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = ($19|0)==(0);
      if ($20) {
       $21 = ((($this) + ($activeStateCount$011<<2)|0) + 100|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($22|0)!=($7|0);
       $24 = $requireRebuild$0$off09 | $23;
       HEAP32[$21>>2] = $7;
       $25 = (($activeStateCount$011) + 1)|0;
       $$pre20 = HEAP32[$0>>2]|0;
       $$pre21 = HEAP32[$2>>2]|0;
       $28 = $$pre20;$30 = $$pre21;$activeStateCount$1 = $25;$requireRebuild$1$off0 = $24;
      } else {
       $28 = $63;$30 = $6;$activeStateCount$1 = $activeStateCount$011;$requireRebuild$1$off0 = $requireRebuild$0$off09;
      }
     } else {
      $28 = $63;$30 = $6;$activeStateCount$1 = $activeStateCount$011;$requireRebuild$1$off0 = $requireRebuild$0$off09;
     }
    }
   }
   $26 = (($s$010) + 1)|0;
   $27 = $28;
   $29 = $30;
   $31 = (($27) - ($29))|0;
   $32 = $31 >> 2;
   $33 = ($26>>>0)<($32>>>0);
   $34 = ($activeStateCount$1|0)<(32);
   $or$cond = $33 & $34;
   if ($or$cond) {
    $6 = $30;$63 = $28;$activeStateCount$011 = $activeStateCount$1;$requireRebuild$0$off09 = $requireRebuild$1$off0;$s$010 = $26;
   } else {
    break;
   }
  }
  $35 = ($26|0)==($32|0);
  if ($35) {
   $activeStateCount$0$lcssa22 = $activeStateCount$1;$requireRebuild$0$off0$lcssa23 = $requireRebuild$1$off0;
  } else {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $36 = (($this) + 228|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($activeStateCount$0$lcssa22|0)!=($37|0);
 $39 = $requireRebuild$0$off0$lcssa23 | $38;
 if (!($39)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$36>>2] = $activeStateCount$0$lcssa22;
 $40 = (($this) + 80|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==(0);
 if ($42) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = (($this) + 72|0);
 $$pre = HEAP32[$43>>2]|0;
 $i$05 = 0;
 while(1) {
  $44 = ((($$pre) + (($i$05*20)|0)|0) + 12|0);
  HEAP32[$44>>2] = 0;
  $45 = HEAP32[$36>>2]|0;
  $46 = ($45|0)>(0);
  if ($46) {
   $56 = 0;$64 = $45;$s1$04 = 0;
   while(1) {
    $47 = ((($this) + ($s1$04<<2)|0) + 100|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + ($i$05<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==(0|0);
    if ($53) {
     $59 = $64;$65 = $56;
    } else {
     $54 = 1 << $s1$04;
     $55 = $56 | $54;
     HEAP32[$44>>2] = $55;
     $$pre19 = HEAP32[$36>>2]|0;
     $59 = $$pre19;$65 = $55;
    }
    $57 = (($s1$04) + 1)|0;
    $58 = ($57|0)<($59|0);
    if ($58) {
     $56 = $65;$64 = $59;$s1$04 = $57;
    } else {
     break;
    }
   }
  }
  $60 = (($i$05) + 1)|0;
  $61 = HEAP32[$40>>2]|0;
  $62 = ($60>>>0)<($61>>>0);
  if ($62) {
   $i$05 = $60;
  } else {
   $$0 = 1;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN9Animation14BlendOptimizedEv($this) {
 $this = $this|0;
 var $$$i = Math_fround(0), $$byval_copy22 = 0, $$index = 0, $$index16 = 0, $$lcssa = Math_fround(0), $$lcssa19 = Math_fround(0), $$lcssa21 = Math_fround(0), $$lcssa31 = Math_fround(0), $$lcssa33 = Math_fround(0), $$lcssa35 = Math_fround(0), $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0);
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0;
 var $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0);
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = Math_fround(0), $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0;
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $allocPtr$0 = 0;
 var $c$070 = 0, $i$046 = 0, $i12$058 = 0, $i3$038 = 0, $i7$024 = 0, $lastAffectedStateMask$073 = 0, $lastAffectedStateMask$1 = 0, $lpad$phi$index = 0, $lpad$phi$index6 = 0, $result10$0$lcssa = Math_fround(0), $result10$056 = Math_fround(0), $result10$1 = Math_fround(0), $sample = 0, $sample4 = 0, $sample9 = 0, $stateBit$047 = 0, $stateBit11$057 = 0, $stateBit2$037 = 0, $stateBit6$023 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy22 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $sample = sp + 8|0;
 $sample4 = sp + 24|0;
 $sample9 = sp + 36|0;
 $2 = (($this) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 100|0);
 $5 = (($this) + 228|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 << 2;
 $8 = (($7) + 15)|0;
 $9 = ($8>>>0)<(2000);
 $10 = ($6|0)!=(0);
 if ($9) {
  if ($10) {
   $11 = STACKTOP; STACKTOP = STACKTOP + ((((1*$8)|0)+15)&-16)|0;;
   $31 = 0;$allocPtr$0 = $11;
  } else {
   $31 = 0;$allocPtr$0 = 0;
  }
 } else {
  if ($10) {
   $12 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $12;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
   $13 = (invoke_iiiiiii(102,($8|0),16,($$byval_copy22|0),0,(765224|0),1019)|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $16 = ___cxa_find_matching_catch()|0;
    $17 = tempRet0;
    $$index = $16;$$index16 = $17;$253 = $0;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $31 = $13;$allocPtr$0 = $13;
   }
  } else {
   $31 = 0;$allocPtr$0 = 0;
  }
 }
 $35 = $allocPtr$0;
 $36 = (($35) + 15)|0;
 $37 = $36 & -16;
 $38 = $37;
 $39 = (($this) + 72|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(109,($4|0),($6|0),0,($38|0),($42|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 L9: do {
  if ($44) {
   label = 12;
  } else {
   $45 = HEAP32[$39>>2]|0;
   $46 = ($3|0)>(0);
   do {
    if ($46) {
     $47 = ($6|0)>(0);
     $48 = Math_fround(HEAPF32[616648>>2]);
     $49 = (($sample) + 4|0);
     $50 = (($sample) + 8|0);
     $51 = (($sample) + 12|0);
     $52 = (($sample9) + 4|0);
     $53 = (($sample9) + 8|0);
     $54 = (($sample4) + 4|0);
     $55 = (($sample4) + 8|0);
     $233 = 0;$c$070 = 0;$lastAffectedStateMask$073 = $42;
     L13: while(1) {
      $56 = (($45) + (($c$070*20)|0)|0);
      $57 = ((($45) + (($c$070*20)|0)|0) + 12|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($lastAffectedStateMask$073|0)==($58|0);
      if ($59) {
       $lastAffectedStateMask$1 = $lastAffectedStateMask$073;
      } else {
       __THREW__ = 0;
       invoke_viiiii(109,($4|0),($6|0),0,($38|0),($58|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 11;
        break;
       } else {
        $lastAffectedStateMask$1 = $58;
       }
      }
      $62 = ($lastAffectedStateMask$1|0)==(0);
      do {
       if ($62) {
        $243 = $233;
       } else {
        $63 = ((($45) + (($c$070*20)|0)|0) + 8|0);
        $64 = HEAP32[$63>>2]|0;
        if ((($64|0) == 1)) {
         if ($47) {
          $157 = Math_fround(0.0);$159 = Math_fround(0.0);$161 = Math_fround(0.0);$i3$038 = 0;$stateBit2$037 = 1;
          while(1) {
           $136 = $stateBit2$037 & $lastAffectedStateMask$1;
           $137 = ($136|0)==(0);
           if ($137) {
            $262 = $161;$263 = $159;$264 = $157;
           } else {
            $138 = ((($this) + ($i3$038<<2)|0) + 100|0);
            $139 = HEAP32[$138>>2]|0;
            $140 = (($139) + 4|0);
            $141 = HEAP32[$140>>2]|0;
            $142 = (($141) + ($c$070<<2)|0);
            $143 = HEAP32[$142>>2]|0;
            $144 = (($139) + 12|0);
            $145 = Math_fround(HEAPF32[$144>>2]);
            __THREW__ = 0;
            invoke_viif(46,($sample4|0),($143|0),(+$145));
            $146 = __THREW__; __THREW__ = 0;
            $147 = $146&1;
            if ($147) {
             label = 8;
             break L13;
            }
            $148 = (($38) + ($i3$038<<2)|0);
            $149 = Math_fround(HEAPF32[$148>>2]);
            $150 = Math_fround(HEAPF32[$sample4>>2]);
            $151 = Math_fround($149 * $150);
            $152 = Math_fround(HEAPF32[$54>>2]);
            $153 = Math_fround($149 * $152);
            $154 = Math_fround(HEAPF32[$55>>2]);
            $155 = Math_fround($149 * $154);
            $156 = Math_fround($157 + $151);
            $158 = Math_fround($159 + $153);
            $160 = Math_fround($161 + $155);
            $262 = $160;$263 = $158;$264 = $156;
           }
           $162 = $stateBit2$037 << 1;
           $163 = (($i3$038) + 1)|0;
           $164 = ($163|0)<($6|0);
           if ($164) {
            $157 = $264;$159 = $263;$161 = $262;$i3$038 = $163;$stateBit2$037 = $162;
           } else {
            $$lcssa31 = $262;$$lcssa33 = $263;$$lcssa35 = $264;
            break;
           }
          }
         } else {
          $$lcssa31 = Math_fround(0.0);$$lcssa33 = Math_fround(0.0);$$lcssa35 = Math_fround(0.0);
         }
         $165 = ((($45) + (($c$070*20)|0)|0) + 4|0);
         $166 = HEAP32[$165>>2]|0;
         HEAPF32[$166>>2] = $$lcssa35;
         $167 = (($166) + 4|0);
         HEAPF32[$167>>2] = $$lcssa33;
         $168 = (($166) + 8|0);
         HEAPF32[$168>>2] = $$lcssa31;
         $243 = $233;
         break;
        } else if ((($64|0) == 2)) {
         $65 = ((($45) + (($c$070*20)|0)|0) + 4|0);
         $66 = HEAP32[$65>>2]|0;
         $67 = (($66) + 4|0);
         $68 = (($66) + 8|0);
         $69 = (($66) + 12|0);
         ;HEAP32[$66+0>>2]=0|0;HEAP32[$66+4>>2]=0|0;HEAP32[$66+8>>2]=0|0;HEAP32[$66+12>>2]=0|0;
         if ($47) {
          $254 = Math_fround(0.0);$255 = Math_fround(0.0);$256 = Math_fround(0.0);$257 = Math_fround(0.0);$i$046 = 0;$stateBit$047 = 1;
          while(1) {
           $70 = $stateBit$047 & $lastAffectedStateMask$1;
           $71 = ($70|0)==(0);
           if ($71) {
            $258 = $254;$259 = $255;$260 = $256;$261 = $257;
           } else {
            $72 = ((($this) + ($i$046<<2)|0) + 100|0);
            $73 = HEAP32[$72>>2]|0;
            $74 = (($73) + 4|0);
            $75 = HEAP32[$74>>2]|0;
            $76 = (($75) + ($c$070<<2)|0);
            $77 = HEAP32[$76>>2]|0;
            $78 = (($73) + 12|0);
            $79 = Math_fround(HEAPF32[$78>>2]);
            __THREW__ = 0;
            invoke_viif(45,($sample|0),($77|0),(+$79));
            $80 = __THREW__; __THREW__ = 0;
            $81 = $80&1;
            if ($81) {
             label = 9;
             break L13;
            }
            $82 = Math_fround(HEAPF32[$sample>>2]);
            $83 = Math_fround(HEAPF32[$66>>2]);
            $84 = Math_fround($82 * $83);
            $85 = Math_fround(HEAPF32[$49>>2]);
            $86 = Math_fround(HEAPF32[$67>>2]);
            $87 = Math_fround($85 * $86);
            $88 = Math_fround($84 + $87);
            $89 = Math_fround(HEAPF32[$50>>2]);
            $90 = Math_fround(HEAPF32[$68>>2]);
            $91 = Math_fround($89 * $90);
            $92 = Math_fround($88 + $91);
            $93 = Math_fround(HEAPF32[$51>>2]);
            $94 = Math_fround(HEAPF32[$69>>2]);
            $95 = Math_fround($93 * $94);
            $96 = Math_fround($92 + $95);
            $97 = $96 < Math_fround(0.0);
            $$$i = $97 ? Math_fround(-1.0) : Math_fround(1.0);
            $98 = Math_fround($82 * $$$i);
            $99 = Math_fround($85 * $$$i);
            $100 = Math_fround($89 * $$$i);
            $101 = Math_fround($93 * $$$i);
            $102 = (($38) + ($i$046<<2)|0);
            $103 = Math_fround(HEAPF32[$102>>2]);
            $104 = Math_fround($103 * $98);
            $105 = Math_fround($103 * $99);
            $106 = Math_fround($103 * $100);
            $107 = Math_fround($103 * $101);
            $108 = Math_fround($83 + $104);
            HEAPF32[$66>>2] = $108;
            $109 = Math_fround($86 + $105);
            HEAPF32[$67>>2] = $109;
            $110 = Math_fround($90 + $106);
            HEAPF32[$68>>2] = $110;
            $111 = Math_fround($94 + $107);
            HEAPF32[$69>>2] = $111;
            $258 = $111;$259 = $110;$260 = $109;$261 = $108;
           }
           $112 = $stateBit$047 << 1;
           $113 = (($i$046) + 1)|0;
           $114 = ($113|0)<($6|0);
           if ($114) {
            $254 = $258;$255 = $259;$256 = $260;$257 = $261;$i$046 = $113;$stateBit$047 = $112;
           } else {
            $116 = $261;$118 = $260;$121 = $259;$124 = $258;
            break;
           }
          }
         } else {
          $116 = Math_fround(0.0);$118 = Math_fround(0.0);$121 = Math_fround(0.0);$124 = Math_fround(0.0);
         }
         $115 = Math_fround($116 * $116);
         $117 = Math_fround($118 * $118);
         $119 = Math_fround($115 + $117);
         $120 = Math_fround($121 * $121);
         $122 = Math_fround($119 + $120);
         $123 = Math_fround($124 * $124);
         $125 = Math_fround($122 + $123);
         $126 = (Math_fround(Math_sqrt((Math_fround($125)))));
         $127 = $126 < $48;
         if ($127) {
          $132 = Math_fround(0.0);$133 = Math_fround(0.0);$134 = Math_fround(0.0);$135 = Math_fround(1.0);
         } else {
          $128 = Math_fround($116 / $126);
          $129 = Math_fround($118 / $126);
          $130 = Math_fround($121 / $126);
          $131 = Math_fround($124 / $126);
          $132 = $128;$133 = $129;$134 = $130;$135 = $131;
         }
         HEAPF32[$66>>2] = $132;
         HEAPF32[$67>>2] = $133;
         HEAPF32[$68>>2] = $134;
         HEAPF32[$69>>2] = $135;
         $243 = $233;
         break;
        } else if ((($64|0) == 3)) {
         if ($47) {
          $190 = Math_fround(0.0);$192 = Math_fround(0.0);$194 = Math_fround(0.0);$i7$024 = 0;$stateBit6$023 = 1;
          while(1) {
           $169 = $stateBit6$023 & $lastAffectedStateMask$1;
           $170 = ($169|0)==(0);
           if ($170) {
            $265 = $194;$266 = $192;$267 = $190;
           } else {
            $171 = ((($this) + ($i7$024<<2)|0) + 100|0);
            $172 = HEAP32[$171>>2]|0;
            $173 = (($172) + 4|0);
            $174 = HEAP32[$173>>2]|0;
            $175 = (($174) + ($c$070<<2)|0);
            $176 = HEAP32[$175>>2]|0;
            $177 = (($172) + 12|0);
            $178 = Math_fround(HEAPF32[$177>>2]);
            __THREW__ = 0;
            invoke_viif(46,($sample9|0),($176|0),(+$178));
            $179 = __THREW__; __THREW__ = 0;
            $180 = $179&1;
            if ($180) {
             label = 7;
             break L13;
            }
            $181 = (($38) + ($i7$024<<2)|0);
            $182 = Math_fround(HEAPF32[$181>>2]);
            $183 = Math_fround(HEAPF32[$sample9>>2]);
            $184 = Math_fround($182 * $183);
            $185 = Math_fround(HEAPF32[$52>>2]);
            $186 = Math_fround($182 * $185);
            $187 = Math_fround(HEAPF32[$53>>2]);
            $188 = Math_fround($182 * $187);
            $189 = Math_fround($190 + $184);
            $191 = Math_fround($192 + $186);
            $193 = Math_fround($194 + $188);
            $265 = $193;$266 = $191;$267 = $189;
           }
           $195 = $stateBit6$023 << 1;
           $196 = (($i7$024) + 1)|0;
           $197 = ($196|0)<($6|0);
           if ($197) {
            $190 = $267;$192 = $266;$194 = $265;$i7$024 = $196;$stateBit6$023 = $195;
           } else {
            $$lcssa = $265;$$lcssa19 = $266;$$lcssa21 = $267;
            break;
           }
          }
         } else {
          $$lcssa = Math_fround(0.0);$$lcssa19 = Math_fround(0.0);$$lcssa21 = Math_fround(0.0);
         }
         $198 = ((($45) + (($c$070*20)|0)|0) + 4|0);
         $199 = HEAP32[$198>>2]|0;
         HEAPF32[$199>>2] = $$lcssa21;
         $200 = (($199) + 4|0);
         HEAPF32[$200>>2] = $$lcssa19;
         $201 = (($199) + 8|0);
         HEAPF32[$201>>2] = $$lcssa;
         $202 = ((($45) + (($c$070*20)|0)|0) + 16|0);
         $203 = HEAP32[$202>>2]|0;
         __THREW__ = 0;
         invoke_vi(3681,($203|0));
         $204 = __THREW__; __THREW__ = 0;
         $205 = $204&1;
         if ($205) {
          label = 11;
          break L13;
         } else {
          $243 = $233;
          break;
         }
        } else if ((($64|0) == 0)) {
         $243 = $233;
         break;
        } else {
         if ($47) {
          $i12$058 = 0;$result10$056 = Math_fround(0.0);$stateBit11$057 = 1;
          while(1) {
           $206 = $stateBit11$057 & $lastAffectedStateMask$1;
           $207 = ($206|0)==(0);
           if ($207) {
            $result10$1 = $result10$056;
           } else {
            $208 = ((($this) + ($i12$058<<2)|0) + 100|0);
            $209 = HEAP32[$208>>2]|0;
            $210 = (($209) + 4|0);
            $211 = HEAP32[$210>>2]|0;
            $212 = (($211) + ($c$070<<2)|0);
            $213 = HEAP32[$212>>2]|0;
            $214 = (($209) + 12|0);
            $215 = Math_fround(HEAPF32[$214>>2]);
            __THREW__ = 0;
            $216 = (Math_fround(+(invoke_fif(16,($213|0),(+$215)))));
            $217 = __THREW__; __THREW__ = 0;
            $218 = $217&1;
            if ($218) {
             label = 10;
             break L13;
            }
            $219 = (($38) + ($i12$058<<2)|0);
            $220 = Math_fround(HEAPF32[$219>>2]);
            $221 = Math_fround($216 * $220);
            $222 = Math_fround($result10$056 + $221);
            $result10$1 = $222;
           }
           $223 = $stateBit11$057 << 1;
           $224 = (($i12$058) + 1)|0;
           $225 = ($224|0)<($6|0);
           if ($225) {
            $i12$058 = $224;$result10$056 = $result10$1;$stateBit11$057 = $223;
           } else {
            $result10$0$lcssa = $result10$1;
            break;
           }
          }
         } else {
          $result10$0$lcssa = Math_fround(0.0);
         }
         __THREW__ = 0;
         (invoke_iif(30,($56|0),(+$result10$0$lcssa))|0);
         $226 = __THREW__; __THREW__ = 0;
         $227 = $226&1;
         if ($227) {
          label = 11;
          break L13;
         }
         $228 = HEAP32[$63>>2]|0;
         $$off$i = (($228) + -5)|0;
         $229 = ($$off$i>>>0)<(2);
         if (!($229)) {
          $243 = $233;
          break;
         }
         $230 = ((($45) + (($c$070*20)|0)|0) + 16|0);
         $231 = HEAP32[$230>>2]|0;
         $232 = ($233|0)==($231|0);
         if ($232) {
          $243 = $233;
          break;
         }
         $234 = ($233|0)==(0|0);
         if ($234) {
          $243 = $231;
          break;
         }
         $235 = HEAP32[$233>>2]|0;
         $236 = (($235) + 12|0);
         $237 = HEAP32[$236>>2]|0;
         __THREW__ = 0;
         invoke_vii($237|0,($233|0),0);
         $238 = __THREW__; __THREW__ = 0;
         $239 = $238&1;
         if ($239) {
          label = 11;
          break L13;
         } else {
          $243 = $231;
          break;
         }
        }
       }
      } while(0);
      $240 = (($c$070) + 1)|0;
      $241 = ($240|0)<($3|0);
      if ($241) {
       $233 = $243;$c$070 = $240;$lastAffectedStateMask$073 = $lastAffectedStateMask$1;
      } else {
       label = 53;
       break;
      }
     }
     if ((label|0) == 7) {
      $18 = ___cxa_find_matching_catch()|0;
      $19 = tempRet0;
      $lpad$phi$index = $18;$lpad$phi$index6 = $19;
      break L9;
     }
     else if ((label|0) == 8) {
      $20 = ___cxa_find_matching_catch()|0;
      $21 = tempRet0;
      $lpad$phi$index = $20;$lpad$phi$index6 = $21;
      break L9;
     }
     else if ((label|0) == 9) {
      $22 = ___cxa_find_matching_catch()|0;
      $23 = tempRet0;
      $lpad$phi$index = $22;$lpad$phi$index6 = $23;
      break L9;
     }
     else if ((label|0) == 10) {
      $24 = ___cxa_find_matching_catch()|0;
      $25 = tempRet0;
      $lpad$phi$index = $24;$lpad$phi$index6 = $25;
      break L9;
     }
     else if ((label|0) == 11) {
      $26 = ___cxa_find_matching_catch()|0;
      $27 = tempRet0;
      $lpad$phi$index = $26;$lpad$phi$index6 = $27;
      break L9;
     }
     else if ((label|0) == 53) {
      $242 = ($243|0)==(0|0);
      if ($242) {
       break;
      }
      $244 = HEAP32[$243>>2]|0;
      $245 = (($244) + 12|0);
      $246 = HEAP32[$245>>2]|0;
      __THREW__ = 0;
      invoke_vii($246|0,($243|0),0);
      $247 = __THREW__; __THREW__ = 0;
      $248 = $247&1;
      if ($248) {
       label = 12;
       break L9;
      } else {
       break;
      }
     }
    }
   } while(0);
   $249 = ($31|0)==(0|0);
   if ($249) {
    STACKTOP = sp;return;
   }
   $250 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $250;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy22);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 12) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  $lpad$phi$index = $28;$lpad$phi$index6 = $29;
 }
 $30 = ($31|0)==(0|0);
 if ($30) {
  $$index = $lpad$phi$index;$$index16 = $lpad$phi$index6;$253 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $32 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $32;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($31|0),($$byval_copy22|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $251 = ___cxa_find_matching_catch(0|0)|0;
  $252 = tempRet0;
  ___clang_call_terminate($251);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index16 = $lpad$phi$index6;$253 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __Z16CalculateWeightsILb1EEvPP14AnimationStateiiPfi($states,$stateCount,$curveIndex,$outWeights,$mask) {
 $states = $states|0;
 $stateCount = $stateCount|0;
 $curveIndex = $curveIndex|0;
 $outWeights = $outWeights|0;
 $mask = $mask|0;
 var $$0 = 0, $$1 = 0, $$12 = 0, $$byval_copy12 = 0, $$phi$trans$insert = 0, $$pre = 0, $$sink$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0);
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $allocPtr2$0 = 0, $allocPtr5$0 = 0, $exitcond = 0, $exitcond37 = 0, $exitcond38 = 0, $exitcond39 = 0, $i3$030 = 0, $i6$023 = 0, $i7$020 = 0, $i8$018 = 0, $layerIndex$0$ = 0, $layerIndex$0$lcssa = 0, $layerIndex$028 = 0, $layerIndex$2 = 0;
 var $not$ = 0, $prevLayer$027 = 0, $stateBit$029 = 0, $summedWeight$019 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy12 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = sp + 24|0;
 $7 = $stateCount << 2;
 $8 = (($7) + 15)|0;
 $9 = ($8>>>0)<(2000);
 $10 = ($stateCount|0)!=(0);
 if ($9) {
  if ($10) {
   $17 = STACKTOP; STACKTOP = STACKTOP + ((((1*$8)|0)+15)&-16)|0;;
   $18 = $17;
   $19 = (($18) + 15)|0;
   $20 = $19 & -16;
   $21 = $20;
   $22 = STACKTOP; STACKTOP = STACKTOP + ((((1*$8)|0)+15)&-16)|0;;
   $116 = 0;$121 = 0;$56 = $21;$allocPtr2$0 = $22;
   label = 9;
  } else {
   $116 = 0;$121 = 0;$56 = 0;$allocPtr2$0 = 0;
   label = 9;
  }
 } else {
  if ($10) {
   $11 = HEAP32[628512>>2]|0;
   HEAP32[$4>>2] = $11;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
   $12 = (invoke_iiiiiii(102,($8|0),16,($$byval_copy12|0),0,(765224|0),836)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $135 = 0;
    label = 5;
   } else {
    $23 = $12;
    $24 = (($23) + 15)|0;
    $25 = $24 & -16;
    $26 = $25;
    $27 = HEAP32[628512>>2]|0;
    HEAP32[$5>>2] = $27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$5+0>>2]|0;
    $28 = (invoke_iiiiiii(102,($8|0),16,($$byval_copy12|0),0,(765224|0),839)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $136 = $12;$137 = 0;
     label = 8;
    } else {
     $116 = $28;$121 = $12;$56 = $26;$allocPtr2$0 = $28;
     label = 9;
    }
   }
  } else {
   $116 = 0;$121 = 0;$56 = 0;$allocPtr2$0 = 0;
   label = 9;
  }
 }
 do {
  if ((label|0) == 9) {
   $33 = $allocPtr2$0;
   $34 = (($33) + 15)|0;
   $35 = $34 & -16;
   $36 = $35;
   $37 = ($stateCount|0)>(0);
   if ($37) {
    $38 = HEAP32[$states>>2]|0;
    $39 = (($38) + 32|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = $35;
    $42 = $stateCount << 2;
    _memset(($41|0),0,($42|0))|0;
    $i3$030 = 0;$layerIndex$028 = 0;$prevLayer$027 = $40;$stateBit$029 = 1;
    while(1) {
     $43 = $stateBit$029 & $mask;
     $44 = ($43|0)==(0);
     if ($44) {
      $59 = (($outWeights) + ($i3$030<<2)|0);
      HEAPF32[$59>>2] = Math_fround(0.0);
      $60 = (($56) + ($i3$030<<2)|0);
      HEAP32[$60>>2] = 0;
      $$phi$trans$insert = (($states) + ($i3$030<<2)|0);
      $$pre = HEAP32[$$phi$trans$insert>>2]|0;
      $63 = $$pre;$layerIndex$2 = $layerIndex$028;
     } else {
      $45 = (($states) + ($i3$030<<2)|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = (($46) + 32|0);
      $48 = HEAP32[$47>>2]|0;
      $not$ = ($prevLayer$027|0)!=($48|0);
      $49 = $not$&1;
      $layerIndex$0$ = (($49) + ($layerIndex$028))|0;
      $50 = (($46) + 8|0);
      $51 = Math_fround(HEAPF32[$50>>2]);
      $52 = (($36) + ($layerIndex$0$<<2)|0);
      $53 = Math_fround(HEAPF32[$52>>2]);
      $54 = Math_fround($51 + $53);
      HEAPF32[$52>>2] = $54;
      $55 = (($56) + ($i3$030<<2)|0);
      HEAP32[$55>>2] = $layerIndex$0$;
      $57 = Math_fround(HEAPF32[$50>>2]);
      $58 = (($outWeights) + ($i3$030<<2)|0);
      HEAPF32[$58>>2] = $57;
      $63 = $46;$layerIndex$2 = $layerIndex$0$;
     }
     $61 = $stateBit$029 << 1;
     $62 = (($63) + 32|0);
     $64 = HEAP32[$62>>2]|0;
     $65 = (($i3$030) + 1)|0;
     $exitcond39 = ($65|0)==($stateCount|0);
     if ($exitcond39) {
      $layerIndex$0$lcssa = $layerIndex$2;
      break;
     } else {
      $i3$030 = $65;$layerIndex$028 = $layerIndex$2;$prevLayer$027 = $64;$stateBit$029 = $61;
     }
    }
   } else {
    $layerIndex$0$lcssa = 0;
   }
   if ($9) {
    if ($10) {
     $66 = STACKTOP; STACKTOP = STACKTOP + ((((1*$8)|0)+15)&-16)|0;;
     $111 = 0;$allocPtr5$0 = $66;
    } else {
     $111 = 0;$allocPtr5$0 = 0;
    }
   } else {
    if ($10) {
     $67 = HEAP32[628512>>2]|0;
     HEAP32[$6>>2] = $67;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$6+0>>2]|0;
     $68 = (invoke_iiiiiii(102,($8|0),16,($$byval_copy12|0),0,(765224|0),902)|0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      $71 = ___cxa_find_matching_catch()|0;
      $72 = tempRet0;
      $$0 = $71;$$sink$index2 = $72;$124 = $116;$138 = $121;
      label = 38;
      break;
     } else {
      $111 = $68;$allocPtr5$0 = $68;
     }
    } else {
     $111 = 0;$allocPtr5$0 = 0;
    }
   }
   $73 = $allocPtr5$0;
   $74 = (($73) + 15)|0;
   $75 = $74 & -16;
   $76 = $75;
   $77 = ($layerIndex$0$lcssa|0)>(-1);
   if ($77) {
    $86 = Math_fround(1.0);$i6$023 = 0;
    while(1) {
     $78 = (($36) + ($i6$023<<2)|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $80 = $79 > Math_fround(1.0);
     $81 = $80 ? $79 : Math_fround(1.0);
     $82 = $81 > Math_fround(9.99999974737875163555E-5);
     if ($82) {
      $83 = Math_fround(Math_fround(1.0) / $81);
      $85 = $83;
     } else {
      $85 = Math_fround(0.0);
     }
     $84 = Math_fround($86 * $85);
     $87 = (($76) + ($i6$023<<2)|0);
     HEAPF32[$87>>2] = $84;
     $88 = Math_fround(HEAPF32[$78>>2]);
     $89 = Math_fround($86 * $88);
     $90 = Math_fround($86 - $89);
     $91 = $90 > Math_fround(0.0);
     $92 = $91 ? $90 : Math_fround(0.0);
     $93 = (($i6$023) + 1)|0;
     $exitcond38 = ($i6$023|0)==($layerIndex$0$lcssa|0);
     if ($exitcond38) {
      break;
     } else {
      $86 = $92;$i6$023 = $93;
     }
    }
   }
   if ($37) {
    $i7$020 = 0;$summedWeight$019 = Math_fround(0.0);
    while(1) {
     $94 = (($56) + ($i7$020<<2)|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = (($76) + ($95<<2)|0);
     $97 = Math_fround(HEAPF32[$96>>2]);
     $98 = (($outWeights) + ($i7$020<<2)|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     $100 = Math_fround($97 * $99);
     HEAPF32[$98>>2] = $100;
     $101 = Math_fround($summedWeight$019 + $100);
     $102 = (($i7$020) + 1)|0;
     $exitcond37 = ($102|0)==($stateCount|0);
     if ($exitcond37) {
      break;
     } else {
      $i7$020 = $102;$summedWeight$019 = $101;
     }
    }
    $103 = $101 > Math_fround(9.99999974737875163555E-5);
    if ($103) {
     $104 = Math_fround(Math_fround(1.0) / $101);
     $108 = $104;
    } else {
     $108 = Math_fround(0.0);
    }
    if ($37) {
     $i8$018 = 0;
     while(1) {
      $105 = (($outWeights) + ($i8$018<<2)|0);
      $106 = Math_fround(HEAPF32[$105>>2]);
      $107 = Math_fround($108 * $106);
      HEAPF32[$105>>2] = $107;
      $109 = (($i8$018) + 1)|0;
      $exitcond = ($109|0)==($stateCount|0);
      if ($exitcond) {
       break;
      } else {
       $i8$018 = $109;
      }
     }
    }
   }
   $110 = ($111|0)==(0|0);
   if (!($110)) {
    $112 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $112;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($111|0),($$byval_copy12|0));
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    if ($114) {
     $136 = $121;$137 = $116;
     label = 8;
     break;
    }
   }
   $115 = ($116|0)==(0|0);
   if (!($115)) {
    $117 = HEAP32[628512>>2]|0;
    HEAP32[$1>>2] = $117;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($116|0),($$byval_copy12|0));
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     $135 = $121;
     label = 5;
     break;
    }
   }
   $120 = ($121|0)==(0|0);
   if ($120) {
    STACKTOP = sp;return;
   }
   $122 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $122;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($121,$$byval_copy12);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 5) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $$1 = $15;$$12 = $16;$129 = $135;
 }
 else if ((label|0) == 8) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $$0 = $31;$$sink$index2 = $32;$124 = $137;$138 = $136;
  label = 38;
 }
 if ((label|0) == 38) {
  $123 = ($124|0)==(0|0);
  if ($123) {
   $$1 = $$0;$$12 = $$sink$index2;$129 = $138;
  } else {
   $125 = HEAP32[628512>>2]|0;
   HEAP32[$2>>2] = $125;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($124|0),($$byval_copy12|0));
   $126 = __THREW__; __THREW__ = 0;
   $127 = $126&1;
   if ($127) {
    $133 = ___cxa_find_matching_catch(0|0)|0;
    $134 = tempRet0;
    ___clang_call_terminate($133);
    // unreachable;
   } else {
    $$1 = $$0;$$12 = $$sink$index2;$129 = $138;
   }
  }
 }
 $128 = ($129|0)==(0|0);
 if ($128) {
  ___resumeException($$1|0);
  // unreachable;
 }
 $130 = HEAP32[628512>>2]|0;
 HEAP32[$3>>2] = $130;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($129|0),($$byval_copy12|0));
 $131 = __THREW__; __THREW__ = 0;
 $132 = $131&1;
 if ($132) {
  $133 = ___cxa_find_matching_catch(0|0)|0;
  $134 = tempRet0;
  ___clang_call_terminate($133);
  // unreachable;
 } else {
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZN9Animation12BlendGenericEv($this) {
 $this = $this|0;
 var $$byval_copy22 = 0, $$index = 0, $$index16 = 0, $$lcssa55 = Math_fround(0), $$lcssa57 = Math_fround(0), $$lcssa59 = Math_fround(0), $$lcssa61 = Math_fround(0), $$not = 0, $$not115 = 0, $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0);
 var $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0;
 var $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0);
 var $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0);
 var $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0);
 var $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0);
 var $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0;
 var $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0;
 var $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0;
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $allocPtr$0 = 0, $brmerge = 0, $c$094 = 0, $didSample$0$off0$lcssa = 0, $didSample$0$off065 = 0, $didSample$1$off0 = 0, $didSample$2$off045 = 0, $didSample$3$off0 = 0, $didSample$4$off028 = 0, $didSample$5$off0 = 0, $didSample$6$off079 = 0, $didSample$7$off0 = 0, $i$064 = 0;
 var $i2$044 = 0, $i5$029 = 0, $i9$081 = 0, $lpad$phi$index = 0, $lpad$phi$index6 = 0, $result8$080 = Math_fround(0), $result8$1 = Math_fround(0), $sample = 0, $sample3 = 0, $sample7 = 0, $weight$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy22 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $sample = sp + 8|0;
 $sample3 = sp + 24|0;
 $sample7 = sp + 36|0;
 $2 = (($this) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 92|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $5;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = (($10) + 15)|0;
 $13 = ($12>>>0)<(2000);
 $14 = ($11|0)!=(0);
 if ($13) {
  if ($14) {
   $15 = STACKTOP; STACKTOP = STACKTOP + ((((1*$12)|0)+15)&-16)|0;;
   $35 = 0;$allocPtr$0 = $15;
  } else {
   $35 = 0;$allocPtr$0 = 0;
  }
 } else {
  if ($14) {
   $16 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $16;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
   $17 = (invoke_iiiiiii(102,($12|0),16,($$byval_copy22|0),0,(765224|0),1173)|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    $20 = ___cxa_find_matching_catch()|0;
    $21 = tempRet0;
    $$index = $20;$$index16 = $21;$252 = $0;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $35 = $17;$allocPtr$0 = $17;
   }
  } else {
   $35 = 0;$allocPtr$0 = 0;
  }
 }
 $39 = $allocPtr$0;
 $40 = (($39) + 15)|0;
 $41 = $40 & -16;
 $42 = $41;
 $43 = ($3|0)>(0);
 do {
  if ($43) {
   $44 = (($this) + 72|0);
   $45 = ($10|0)>(0);
   $46 = (($sample7) + 4|0);
   $47 = (($sample7) + 8|0);
   $48 = (($sample3) + 4|0);
   $49 = (($sample3) + 8|0);
   $50 = Math_fround(HEAPF32[616648>>2]);
   $51 = (($sample) + 4|0);
   $52 = (($sample) + 8|0);
   $53 = (($sample) + 12|0);
   $232 = 0;$c$094 = 0;
   L11: while(1) {
    $54 = HEAP32[$44>>2]|0;
    $55 = (($54) + (($c$094*20)|0)|0);
    $56 = HEAP32[$6>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(110,($56|0),($11|0),($c$094|0),($42|0),0);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     label = 11;
     break;
    }
    $59 = ((($54) + (($c$094*20)|0)|0) + 8|0);
    $60 = HEAP32[$59>>2]|0;
    if ((($60|0) == 1)) {
     if ($45) {
      $149 = Math_fround(0.0);$151 = Math_fround(0.0);$153 = Math_fround(0.0);$didSample$2$off045 = 0;$i2$044 = 0;
      while(1) {
       $126 = HEAP32[$6>>2]|0;
       $127 = (($126) + ($i2$044<<2)|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = (($128) + 4|0);
       $130 = HEAP32[$129>>2]|0;
       $131 = (($130) + ($c$094<<2)|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = ($132|0)==(0|0);
       if ($133) {
        $158 = $149;$160 = $151;$162 = $153;$didSample$3$off0 = $didSample$2$off045;
       } else {
        $134 = (($42) + ($i2$044<<2)|0);
        $135 = Math_fround(HEAPF32[$134>>2]);
        $136 = $135 > Math_fround(9.99999974737875163555E-5);
        if ($136) {
         $137 = (($128) + 12|0);
         $138 = Math_fround(HEAPF32[$137>>2]);
         __THREW__ = 0;
         invoke_viif(46,($sample3|0),($132|0),(+$138));
         $139 = __THREW__; __THREW__ = 0;
         $140 = $139&1;
         if ($140) {
          label = 8;
          break L11;
         }
         $141 = Math_fround(HEAPF32[$134>>2]);
         $142 = Math_fround(HEAPF32[$sample3>>2]);
         $143 = Math_fround($141 * $142);
         $144 = Math_fround(HEAPF32[$48>>2]);
         $145 = Math_fround($141 * $144);
         $146 = Math_fround(HEAPF32[$49>>2]);
         $147 = Math_fround($141 * $146);
         $148 = Math_fround($149 + $143);
         $150 = Math_fround($151 + $145);
         $152 = Math_fround($153 + $147);
         $158 = $148;$160 = $150;$162 = $152;$didSample$3$off0 = 1;
        } else {
         $158 = $149;$160 = $151;$162 = $153;$didSample$3$off0 = $didSample$2$off045;
        }
       }
       $154 = (($i2$044) + 1)|0;
       $155 = ($154|0)<($11|0);
       if ($155) {
        $149 = $158;$151 = $160;$153 = $162;$didSample$2$off045 = $didSample$3$off0;$i2$044 = $154;
       } else {
        break;
       }
      }
      if ($didSample$3$off0) {
       $156 = ((($54) + (($c$094*20)|0)|0) + 4|0);
       $157 = HEAP32[$156>>2]|0;
       HEAPF32[$157>>2] = $158;
       $159 = (($157) + 4|0);
       HEAPF32[$159>>2] = $160;
       $161 = (($157) + 8|0);
       HEAPF32[$161>>2] = $162;
       $242 = $232;
      } else {
       $242 = $232;
      }
     } else {
      $242 = $232;
     }
    } else if ((($60|0) == 3)) {
     if ($45) {
      $186 = Math_fround(0.0);$188 = Math_fround(0.0);$190 = Math_fround(0.0);$didSample$4$off028 = 0;$i5$029 = 0;
      while(1) {
       $163 = HEAP32[$6>>2]|0;
       $164 = (($163) + ($i5$029<<2)|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = (($165) + 4|0);
       $167 = HEAP32[$166>>2]|0;
       $168 = (($167) + ($c$094<<2)|0);
       $169 = HEAP32[$168>>2]|0;
       $170 = ($169|0)==(0|0);
       if ($170) {
        $195 = $186;$197 = $188;$199 = $190;$didSample$5$off0 = $didSample$4$off028;
       } else {
        $171 = (($42) + ($i5$029<<2)|0);
        $172 = Math_fround(HEAPF32[$171>>2]);
        $173 = $172 > Math_fround(9.99999974737875163555E-5);
        if ($173) {
         $174 = (($165) + 12|0);
         $175 = Math_fround(HEAPF32[$174>>2]);
         __THREW__ = 0;
         invoke_viif(46,($sample7|0),($169|0),(+$175));
         $176 = __THREW__; __THREW__ = 0;
         $177 = $176&1;
         if ($177) {
          label = 7;
          break L11;
         }
         $178 = Math_fround(HEAPF32[$171>>2]);
         $179 = Math_fround(HEAPF32[$sample7>>2]);
         $180 = Math_fround($178 * $179);
         $181 = Math_fround(HEAPF32[$46>>2]);
         $182 = Math_fround($178 * $181);
         $183 = Math_fround(HEAPF32[$47>>2]);
         $184 = Math_fround($178 * $183);
         $185 = Math_fround($186 + $180);
         $187 = Math_fround($188 + $182);
         $189 = Math_fround($190 + $184);
         $195 = $185;$197 = $187;$199 = $189;$didSample$5$off0 = 1;
        } else {
         $195 = $186;$197 = $188;$199 = $190;$didSample$5$off0 = $didSample$4$off028;
        }
       }
       $191 = (($i5$029) + 1)|0;
       $192 = ($191|0)<($11|0);
       if ($192) {
        $186 = $195;$188 = $197;$190 = $199;$didSample$4$off028 = $didSample$5$off0;$i5$029 = $191;
       } else {
        break;
       }
      }
      if ($didSample$5$off0) {
       $193 = ((($54) + (($c$094*20)|0)|0) + 4|0);
       $194 = HEAP32[$193>>2]|0;
       HEAPF32[$194>>2] = $195;
       $196 = (($194) + 4|0);
       HEAPF32[$196>>2] = $197;
       $198 = (($194) + 8|0);
       HEAPF32[$198>>2] = $199;
       $200 = ((($54) + (($c$094*20)|0)|0) + 16|0);
       $201 = HEAP32[$200>>2]|0;
       __THREW__ = 0;
       invoke_vi(3681,($201|0));
       $202 = __THREW__; __THREW__ = 0;
       $203 = $202&1;
       if ($203) {
        label = 11;
        break;
       } else {
        $242 = $232;
       }
      } else {
       $242 = $232;
      }
     } else {
      $242 = $232;
     }
    } else if ((($60|0) == 2)) {
     if ($45) {
      $79 = Math_fround(0.0);$82 = Math_fround(0.0);$86 = Math_fround(0.0);$90 = Math_fround(0.0);$didSample$0$off065 = 0;$i$064 = 0;
      while(1) {
       $61 = HEAP32[$6>>2]|0;
       $62 = (($61) + ($i$064<<2)|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = (($63) + 4|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = (($65) + ($c$094<<2)|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = ($67|0)==(0|0);
       if ($68) {
        $253 = $90;$254 = $86;$255 = $82;$256 = $79;$didSample$1$off0 = $didSample$0$off065;
       } else {
        $69 = (($42) + ($i$064<<2)|0);
        $70 = Math_fround(HEAPF32[$69>>2]);
        $71 = $70 > Math_fround(9.99999974737875163555E-5);
        if ($71) {
         $72 = (($63) + 12|0);
         $73 = Math_fround(HEAPF32[$72>>2]);
         __THREW__ = 0;
         invoke_viif(45,($sample|0),($67|0),(+$73));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          label = 9;
          break L11;
         }
         $76 = Math_fround(HEAPF32[$69>>2]);
         $77 = Math_fround(HEAPF32[$sample>>2]);
         $78 = Math_fround($79 * $77);
         $80 = Math_fround(HEAPF32[$51>>2]);
         $81 = Math_fround($82 * $80);
         $83 = Math_fround($78 + $81);
         $84 = Math_fround(HEAPF32[$52>>2]);
         $85 = Math_fround($86 * $84);
         $87 = Math_fround($83 + $85);
         $88 = Math_fround(HEAPF32[$53>>2]);
         $89 = Math_fround($90 * $88);
         $91 = Math_fround($87 + $89);
         $92 = $91 < Math_fround(0.0);
         if ($92) {
          $93 = Math_fround(-$76);
          $weight$0 = $93;
         } else {
          $weight$0 = $76;
         }
         $94 = Math_fround($weight$0 * $77);
         $95 = Math_fround($weight$0 * $80);
         $96 = Math_fround($weight$0 * $84);
         $97 = Math_fround($weight$0 * $88);
         $98 = Math_fround($79 + $94);
         $99 = Math_fround($82 + $95);
         $100 = Math_fround($86 + $96);
         $101 = Math_fround($90 + $97);
         $253 = $101;$254 = $100;$255 = $99;$256 = $98;$didSample$1$off0 = 1;
        } else {
         $253 = $90;$254 = $86;$255 = $82;$256 = $79;$didSample$1$off0 = $didSample$0$off065;
        }
       }
       $102 = (($i$064) + 1)|0;
       $103 = ($102|0)<($11|0);
       if ($103) {
        $79 = $256;$82 = $255;$86 = $254;$90 = $253;$didSample$0$off065 = $didSample$1$off0;$i$064 = $102;
       } else {
        $$lcssa55 = $253;$$lcssa57 = $254;$$lcssa59 = $255;$$lcssa61 = $256;$didSample$0$off0$lcssa = $didSample$1$off0;
        break;
       }
      }
     } else {
      $$lcssa55 = Math_fround(0.0);$$lcssa57 = Math_fround(0.0);$$lcssa59 = Math_fround(0.0);$$lcssa61 = Math_fround(0.0);$didSample$0$off0$lcssa = 0;
     }
     $104 = Math_fround($$lcssa61 * $$lcssa61);
     $105 = Math_fround($$lcssa59 * $$lcssa59);
     $106 = Math_fround($105 + $104);
     $107 = Math_fround($$lcssa57 * $$lcssa57);
     $108 = Math_fround($107 + $106);
     $109 = Math_fround($$lcssa55 * $$lcssa55);
     $110 = Math_fround($109 + $108);
     $111 = (Math_fround(Math_sqrt((Math_fround($110)))));
     $112 = $111 < $50;
     if ($112) {
      $119 = Math_fround(0.0);$121 = Math_fround(0.0);$123 = Math_fround(0.0);$125 = Math_fround(1.0);
     } else {
      $113 = Math_fround($$lcssa61 / $111);
      $114 = Math_fround($$lcssa59 / $111);
      $115 = Math_fround($$lcssa57 / $111);
      $116 = Math_fround($$lcssa55 / $111);
      $119 = $113;$121 = $114;$123 = $115;$125 = $116;
     }
     if ($didSample$0$off0$lcssa) {
      $117 = ((($54) + (($c$094*20)|0)|0) + 4|0);
      $118 = HEAP32[$117>>2]|0;
      HEAPF32[$118>>2] = $119;
      $120 = (($118) + 4|0);
      HEAPF32[$120>>2] = $121;
      $122 = (($118) + 8|0);
      HEAPF32[$122>>2] = $123;
      $124 = (($118) + 12|0);
      HEAPF32[$124>>2] = $125;
      $242 = $232;
     } else {
      $242 = $232;
     }
    } else {
     $$not = ($60|0)<(1);
     $$not115 = $45 ^ 1;
     $brmerge = $$not | $$not115;
     if ($brmerge) {
      $242 = $232;
     } else {
      $didSample$6$off079 = 0;$i9$081 = 0;$result8$080 = Math_fround(0.0);
      while(1) {
       $204 = HEAP32[$6>>2]|0;
       $205 = (($204) + ($i9$081<<2)|0);
       $206 = HEAP32[$205>>2]|0;
       $207 = (($206) + 4|0);
       $208 = HEAP32[$207>>2]|0;
       $209 = (($208) + ($c$094<<2)|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = ($210|0)==(0|0);
       if ($211) {
        $didSample$7$off0 = $didSample$6$off079;$result8$1 = $result8$080;
       } else {
        $212 = (($42) + ($i9$081<<2)|0);
        $213 = Math_fround(HEAPF32[$212>>2]);
        $214 = $213 > Math_fround(9.99999974737875163555E-5);
        if ($214) {
         $215 = (($206) + 12|0);
         $216 = Math_fround(HEAPF32[$215>>2]);
         __THREW__ = 0;
         $217 = (Math_fround(+(invoke_fif(16,($210|0),(+$216)))));
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if ($219) {
          label = 10;
          break L11;
         }
         $220 = Math_fround(HEAPF32[$212>>2]);
         $221 = Math_fround($217 * $220);
         $222 = Math_fround($result8$080 + $221);
         $didSample$7$off0 = 1;$result8$1 = $222;
        } else {
         $didSample$7$off0 = $didSample$6$off079;$result8$1 = $result8$080;
        }
       }
       $223 = (($i9$081) + 1)|0;
       $224 = ($223|0)<($11|0);
       if ($224) {
        $didSample$6$off079 = $didSample$7$off0;$i9$081 = $223;$result8$080 = $result8$1;
       } else {
        break;
       }
      }
      if ($didSample$7$off0) {
       __THREW__ = 0;
       (invoke_iif(30,($55|0),(+$result8$1))|0);
       $225 = __THREW__; __THREW__ = 0;
       $226 = $225&1;
       if ($226) {
        label = 11;
        break;
       }
       $227 = HEAP32[$59>>2]|0;
       $$off$i = (($227) + -5)|0;
       $228 = ($$off$i>>>0)<(2);
       if ($228) {
        $229 = ((($54) + (($c$094*20)|0)|0) + 16|0);
        $230 = HEAP32[$229>>2]|0;
        $231 = ($232|0)==($230|0);
        if ($231) {
         $242 = $232;
        } else {
         $233 = ($232|0)==(0|0);
         if ($233) {
          $242 = $230;
         } else {
          $234 = HEAP32[$232>>2]|0;
          $235 = (($234) + 12|0);
          $236 = HEAP32[$235>>2]|0;
          __THREW__ = 0;
          invoke_vii($236|0,($232|0),0);
          $237 = __THREW__; __THREW__ = 0;
          $238 = $237&1;
          if ($238) {
           label = 11;
           break;
          } else {
           $242 = $230;
          }
         }
        }
       } else {
        $242 = $232;
       }
      } else {
       $242 = $232;
      }
     }
    }
    $239 = (($c$094) + 1)|0;
    $240 = ($239|0)<($3|0);
    if ($240) {
     $232 = $242;$c$094 = $239;
    } else {
     label = 60;
     break;
    }
   }
   if ((label|0) == 7) {
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $lpad$phi$index = $22;$lpad$phi$index6 = $23;
   }
   else if ((label|0) == 8) {
    $24 = ___cxa_find_matching_catch()|0;
    $25 = tempRet0;
    $lpad$phi$index = $24;$lpad$phi$index6 = $25;
   }
   else if ((label|0) == 9) {
    $26 = ___cxa_find_matching_catch()|0;
    $27 = tempRet0;
    $lpad$phi$index = $26;$lpad$phi$index6 = $27;
   }
   else if ((label|0) == 10) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    $lpad$phi$index = $28;$lpad$phi$index6 = $29;
   }
   else if ((label|0) == 11) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    $lpad$phi$index = $30;$lpad$phi$index6 = $31;
   }
   else if ((label|0) == 60) {
    $241 = ($242|0)==(0|0);
    if ($241) {
     break;
    }
    $243 = HEAP32[$242>>2]|0;
    $244 = (($243) + 12|0);
    $245 = HEAP32[$244>>2]|0;
    __THREW__ = 0;
    invoke_vii($245|0,($242|0),0);
    $246 = __THREW__; __THREW__ = 0;
    $247 = $246&1;
    if (!($247)) {
     break;
    }
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    $lpad$phi$index = $32;$lpad$phi$index6 = $33;
   }
   $34 = ($35|0)==(0|0);
   if ($34) {
    $$index = $lpad$phi$index;$$index16 = $lpad$phi$index6;$252 = $0;
    ___resumeException($$index|0);
    // unreachable;
   }
   $36 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $36;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($35|0),($$byval_copy22|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $250 = ___cxa_find_matching_catch(0|0)|0;
    $251 = tempRet0;
    ___clang_call_terminate($250);
    // unreachable;
   } else {
    $$index = $lpad$phi$index;$$index16 = $lpad$phi$index6;$252 = $0;
    ___resumeException($$index|0);
    // unreachable;
   }
  }
 } while(0);
 $248 = ($35|0)==(0|0);
 if ($248) {
  STACKTOP = sp;return;
 }
 $249 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $249;
 ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($35,$$byval_copy22);
 STACKTOP = sp;return;
}
function __Z16CalculateWeightsILb0EEvPP14AnimationStateiiPfi($states,$stateCount,$curveIndex,$outWeights,$mask) {
 $states = $states|0;
 $stateCount = $stateCount|0;
 $curveIndex = $curveIndex|0;
 $outWeights = $outWeights|0;
 $mask = $mask|0;
 var $$0 = 0, $$1 = 0, $$12 = 0, $$byval_copy12 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sink$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0;
 var $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $allocPtr2$0 = 0, $allocPtr5$0 = 0, $exitcond = 0;
 var $exitcond37 = 0, $exitcond38 = 0, $exitcond39 = 0, $i3$029 = 0, $i6$023 = 0, $i7$020 = 0, $i8$018 = 0, $layerIndex$0$ = 0, $layerIndex$0$lcssa = 0, $layerIndex$028 = 0, $layerIndex$2 = 0, $not$ = 0, $prevLayer$027 = 0, $summedWeight$019 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy12 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = sp + 24|0;
 $7 = $stateCount << 2;
 $8 = (($7) + 15)|0;
 $9 = ($8>>>0)<(2000);
 $10 = ($stateCount|0)!=(0);
 if ($9) {
  if ($10) {
   $17 = STACKTOP; STACKTOP = STACKTOP + ((((1*$8)|0)+15)&-16)|0;;
   $18 = $17;
   $19 = (($18) + 15)|0;
   $20 = $19 & -16;
   $21 = $20;
   $22 = STACKTOP; STACKTOP = STACKTOP + ((((1*$8)|0)+15)&-16)|0;;
   $127 = 0;$132 = 0;$70 = $21;$allocPtr2$0 = $22;
   label = 9;
  } else {
   $127 = 0;$132 = 0;$70 = 0;$allocPtr2$0 = 0;
   label = 9;
  }
 } else {
  if ($10) {
   $11 = HEAP32[628512>>2]|0;
   HEAP32[$4>>2] = $11;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
   $12 = (invoke_iiiiiii(102,($8|0),16,($$byval_copy12|0),0,(765224|0),836)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $146 = 0;
    label = 5;
   } else {
    $23 = $12;
    $24 = (($23) + 15)|0;
    $25 = $24 & -16;
    $26 = $25;
    $27 = HEAP32[628512>>2]|0;
    HEAP32[$5>>2] = $27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$5+0>>2]|0;
    $28 = (invoke_iiiiiii(102,($8|0),16,($$byval_copy12|0),0,(765224|0),839)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $147 = $12;$148 = 0;
     label = 8;
    } else {
     $127 = $28;$132 = $12;$70 = $26;$allocPtr2$0 = $28;
     label = 9;
    }
   }
  } else {
   $127 = 0;$132 = 0;$70 = 0;$allocPtr2$0 = 0;
   label = 9;
  }
 }
 do {
  if ((label|0) == 9) {
   $33 = $allocPtr2$0;
   $34 = (($33) + 15)|0;
   $35 = $34 & -16;
   $36 = $35;
   $37 = ($stateCount|0)>(0);
   L9: do {
    if ($37) {
     $38 = HEAP32[$states>>2]|0;
     $39 = (($38) + 32|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = $35;
     $42 = $stateCount << 2;
     _memset(($41|0),0,($42|0))|0;
     $i3$029 = 0;$layerIndex$028 = 0;$prevLayer$027 = $40;
     while(1) {
      $43 = (($states) + ($i3$029<<2)|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = (($44) + 96|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(0|0);
      if ($47) {
       label = 17;
      } else {
       $48 = (($44) + 56|0);
       $49 = HEAP16[$48>>1]|0;
       $50 = $49 & 2;
       $51 = ($50<<16>>16)==(0);
       if ($51) {
        label = 17;
       } else {
        $52 = (($44) + 8|0);
        $53 = Math_fround(HEAPF32[$52>>2]);
        $54 = $53 > Math_fround(9.99999974737875163555E-5);
        if ($54) {
         $55 = (($44) + 4|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = (($56) + ($curveIndex<<2)|0);
         $58 = HEAP32[$57>>2]|0;
         $59 = ($58|0)==(0|0);
         if ($59) {
          label = 17;
         } else {
          $60 = (($44) + 72|0);
          $61 = HEAP32[$60>>2]|0;
          $62 = ($61|0)==(0);
          if ($62) {
           $63 = (($44) + 32|0);
           $64 = HEAP32[$63>>2]|0;
           $not$ = ($prevLayer$027|0)!=($64|0);
           $65 = $not$&1;
           $layerIndex$0$ = (($65) + ($layerIndex$028))|0;
           $66 = (($36) + ($layerIndex$0$<<2)|0);
           $67 = Math_fround(HEAPF32[$66>>2]);
           $68 = Math_fround($53 + $67);
           HEAPF32[$66>>2] = $68;
           $69 = (($70) + ($i3$029<<2)|0);
           HEAP32[$69>>2] = $layerIndex$0$;
           $71 = Math_fround(HEAPF32[$52>>2]);
           $72 = (($outWeights) + ($i3$029<<2)|0);
           HEAPF32[$72>>2] = $71;
           $$pre$phiZ2D = $63;$layerIndex$2 = $layerIndex$0$;
          } else {
           label = 17;
          }
         }
        } else {
         label = 17;
        }
       }
      }
      if ((label|0) == 17) {
       label = 0;
       $73 = (($outWeights) + ($i3$029<<2)|0);
       HEAPF32[$73>>2] = Math_fround(0.0);
       $74 = (($70) + ($i3$029<<2)|0);
       HEAP32[$74>>2] = 0;
       $$pre = (($44) + 32|0);
       $$pre$phiZ2D = $$pre;$layerIndex$2 = $layerIndex$028;
      }
      $75 = (($i3$029) + 1)|0;
      $exitcond39 = ($75|0)==($stateCount|0);
      if ($exitcond39) {
       $layerIndex$0$lcssa = $layerIndex$2;
       break L9;
      }
      $76 = HEAP32[$$pre$phiZ2D>>2]|0;
      $i3$029 = $75;$layerIndex$028 = $layerIndex$2;$prevLayer$027 = $76;
     }
    } else {
     $layerIndex$0$lcssa = 0;
    }
   } while(0);
   if ($9) {
    if ($10) {
     $77 = STACKTOP; STACKTOP = STACKTOP + ((((1*$8)|0)+15)&-16)|0;;
     $122 = 0;$allocPtr5$0 = $77;
    } else {
     $122 = 0;$allocPtr5$0 = 0;
    }
   } else {
    if ($10) {
     $78 = HEAP32[628512>>2]|0;
     HEAP32[$6>>2] = $78;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$6+0>>2]|0;
     $79 = (invoke_iiiiiii(102,($8|0),16,($$byval_copy12|0),0,(765224|0),902)|0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      $82 = ___cxa_find_matching_catch()|0;
      $83 = tempRet0;
      $$0 = $82;$$sink$index2 = $83;$135 = $127;$149 = $132;
      label = 43;
      break;
     } else {
      $122 = $79;$allocPtr5$0 = $79;
     }
    } else {
     $122 = 0;$allocPtr5$0 = 0;
    }
   }
   $84 = $allocPtr5$0;
   $85 = (($84) + 15)|0;
   $86 = $85 & -16;
   $87 = $86;
   $88 = ($layerIndex$0$lcssa|0)>(-1);
   if ($88) {
    $97 = Math_fround(1.0);$i6$023 = 0;
    while(1) {
     $89 = (($36) + ($i6$023<<2)|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     $91 = $90 > Math_fround(1.0);
     $92 = $91 ? $90 : Math_fround(1.0);
     $93 = $92 > Math_fround(9.99999974737875163555E-5);
     if ($93) {
      $94 = Math_fround(Math_fround(1.0) / $92);
      $96 = $94;
     } else {
      $96 = Math_fround(0.0);
     }
     $95 = Math_fround($97 * $96);
     $98 = (($87) + ($i6$023<<2)|0);
     HEAPF32[$98>>2] = $95;
     $99 = Math_fround(HEAPF32[$89>>2]);
     $100 = Math_fround($97 * $99);
     $101 = Math_fround($97 - $100);
     $102 = $101 > Math_fround(0.0);
     $103 = $102 ? $101 : Math_fround(0.0);
     $104 = (($i6$023) + 1)|0;
     $exitcond38 = ($i6$023|0)==($layerIndex$0$lcssa|0);
     if ($exitcond38) {
      break;
     } else {
      $97 = $103;$i6$023 = $104;
     }
    }
   }
   if ($37) {
    $i7$020 = 0;$summedWeight$019 = Math_fround(0.0);
    while(1) {
     $105 = (($70) + ($i7$020<<2)|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = (($87) + ($106<<2)|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     $109 = (($outWeights) + ($i7$020<<2)|0);
     $110 = Math_fround(HEAPF32[$109>>2]);
     $111 = Math_fround($108 * $110);
     HEAPF32[$109>>2] = $111;
     $112 = Math_fround($summedWeight$019 + $111);
     $113 = (($i7$020) + 1)|0;
     $exitcond37 = ($113|0)==($stateCount|0);
     if ($exitcond37) {
      break;
     } else {
      $i7$020 = $113;$summedWeight$019 = $112;
     }
    }
    $114 = $112 > Math_fround(9.99999974737875163555E-5);
    if ($114) {
     $115 = Math_fround(Math_fround(1.0) / $112);
     $119 = $115;
    } else {
     $119 = Math_fround(0.0);
    }
    if ($37) {
     $i8$018 = 0;
     while(1) {
      $116 = (($outWeights) + ($i8$018<<2)|0);
      $117 = Math_fround(HEAPF32[$116>>2]);
      $118 = Math_fround($119 * $117);
      HEAPF32[$116>>2] = $118;
      $120 = (($i8$018) + 1)|0;
      $exitcond = ($120|0)==($stateCount|0);
      if ($exitcond) {
       break;
      } else {
       $i8$018 = $120;
      }
     }
    }
   }
   $121 = ($122|0)==(0|0);
   if (!($121)) {
    $123 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $123;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($122|0),($$byval_copy12|0));
    $124 = __THREW__; __THREW__ = 0;
    $125 = $124&1;
    if ($125) {
     $147 = $132;$148 = $127;
     label = 8;
     break;
    }
   }
   $126 = ($127|0)==(0|0);
   if (!($126)) {
    $128 = HEAP32[628512>>2]|0;
    HEAP32[$1>>2] = $128;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($127|0),($$byval_copy12|0));
    $129 = __THREW__; __THREW__ = 0;
    $130 = $129&1;
    if ($130) {
     $146 = $132;
     label = 5;
     break;
    }
   }
   $131 = ($132|0)==(0|0);
   if ($131) {
    STACKTOP = sp;return;
   }
   $133 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $133;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($132,$$byval_copy12);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 5) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $$1 = $15;$$12 = $16;$140 = $146;
 }
 else if ((label|0) == 8) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $$0 = $31;$$sink$index2 = $32;$135 = $148;$149 = $147;
  label = 43;
 }
 if ((label|0) == 43) {
  $134 = ($135|0)==(0|0);
  if ($134) {
   $$1 = $$0;$$12 = $$sink$index2;$140 = $149;
  } else {
   $136 = HEAP32[628512>>2]|0;
   HEAP32[$2>>2] = $136;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($135|0),($$byval_copy12|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if ($138) {
    $144 = ___cxa_find_matching_catch(0|0)|0;
    $145 = tempRet0;
    ___clang_call_terminate($144);
    // unreachable;
   } else {
    $$1 = $$0;$$12 = $$sink$index2;$140 = $149;
   }
  }
 }
 $139 = ($140|0)==(0|0);
 if ($139) {
  ___resumeException($$1|0);
  // unreachable;
 }
 $141 = HEAP32[628512>>2]|0;
 HEAP32[$3>>2] = $141;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($140|0),($$byval_copy12|0));
 $142 = __THREW__; __THREW__ = 0;
 $143 = $142&1;
 if ($143) {
  $144 = ___cxa_find_matching_catch(0|0)|0;
  $145 = tempRet0;
  ___clang_call_terminate($144);
  // unreachable;
 } else {
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZN9Animation13BlendAdditiveEv($this) {
 $this = $this|0;
 var $$$i = Math_fround(0), $$$i5 = Math_fround(0), $$$i8 = Math_fround(0), $$0$i = Math_fround(0), $$0$i6 = Math_fround(0), $$0$i9 = Math_fround(0), $$byval_copy18 = 0, $$index = 0, $$index12 = 0, $$lcssa61 = Math_fround(0), $$lcssa63 = Math_fround(0), $$lcssa65 = Math_fround(0), $$lcssa67 = Math_fround(0), $$pn$i = Math_fround(0), $$pn2$i = Math_fround(0), $$pn3$i = Math_fround(0), $$pn7$i = Math_fround(0), $$pn8$i = Math_fround(0), $$pn9$i = Math_fround(0), $$sink$i = Math_fround(0);
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0;
 var $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0);
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0;
 var $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0;
 var $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0;
 var $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0;
 var $350 = Math_fround(0), $351 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $activeStateSize$087 = 0, $activeStateSize$1 = 0, $allocPtr$0 = 0, $c$081 = 0, $didSample$0$off0$lcssa = 0, $didSample$0$off070 = 0, $didSample$1$off0 = 0, $didSample$2$off050 = 0;
 var $didSample$3$off0 = 0, $didSample$4$off035 = 0, $didSample$5$off0 = 0, $i$086 = 0, $i1$071 = 0, $i3$051 = 0, $i6$036 = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy18 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = (($this) + 92|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 88|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = (($11) + 15)|0;
 $14 = ($13>>>0)<(2000);
 $15 = ($12|0)!=(0);
 if ($14) {
  if ($15) {
   $16 = STACKTOP; STACKTOP = STACKTOP + ((((1*$13)|0)+15)&-16)|0;;
   $32 = 0;$allocPtr$0 = $16;
  } else {
   $32 = 0;$allocPtr$0 = 0;
  }
 } else {
  if ($15) {
   $17 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $17;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$1+0>>2]|0;
   $18 = (invoke_iiiiiii(102,($13|0),16,($$byval_copy18|0),0,(765224|0),1316)|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    $21 = ___cxa_find_matching_catch()|0;
    $22 = tempRet0;
    $$index = $21;$$index12 = $22;$347 = $0;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $32 = $18;$allocPtr$0 = $18;
   }
  } else {
   $32 = 0;$allocPtr$0 = 0;
  }
 }
 $36 = $allocPtr$0;
 $37 = (($36) + 15)|0;
 $38 = $37 & -16;
 $39 = $38;
 $40 = ($11|0)>(0);
 L9: do {
  if ($40) {
   $activeStateSize$087 = 0;$i$086 = 0;
   while(1) {
    $41 = HEAP32[$7>>2]|0;
    $42 = (($41) + ($i$086<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + 72|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==(1);
    if ($46) {
     $47 = (($43) + 96|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(0|0);
     if ($49) {
      $activeStateSize$1 = $activeStateSize$087;
     } else {
      $50 = (($43) + 56|0);
      $51 = HEAP16[$50>>1]|0;
      $52 = $51 & 2;
      $53 = ($52<<16>>16)==(0);
      if ($53) {
       $activeStateSize$1 = $activeStateSize$087;
      } else {
       $54 = (($43) + 8|0);
       $55 = Math_fround(HEAPF32[$54>>2]);
       $56 = $55 > Math_fround(9.99999974737875163555E-5);
       if ($56) {
        $57 = (($39) + ($activeStateSize$087<<2)|0);
        HEAP32[$57>>2] = $43;
        $58 = (($activeStateSize$087) + 1)|0;
        $activeStateSize$1 = $58;
       } else {
        $activeStateSize$1 = $activeStateSize$087;
       }
      }
     }
    } else {
     $activeStateSize$1 = $activeStateSize$087;
    }
    $59 = (($i$086) + 1)|0;
    $60 = ($59|0)<($12|0);
    if ($60) {
     $activeStateSize$087 = $activeStateSize$1;$i$086 = $59;
    } else {
     break;
    }
   }
   $61 = ($activeStateSize$1|0)==(0);
   if (!($61)) {
    $62 = (($this) + 80|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($this) + 72|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($63|0)>(0);
    if ($66) {
     $67 = ($activeStateSize$1|0)>(0);
     $68 = Math_fround(HEAPF32[616648>>2]);
     $69 = (($2) + 12|0);
     $70 = (($2) + 8|0);
     $71 = (($2) + 4|0);
     $72 = (($3) + 4|0);
     $73 = (($3) + 8|0);
     $74 = (($4) + 4|0);
     $75 = (($4) + 8|0);
     $c$081 = 0;
     L21: while(1) {
      $76 = ((($65) + (($c$081*20)|0)|0) + 8|0);
      $77 = HEAP32[$76>>2]|0;
      if ((($77|0) == 1)) {
       $231 = ((($65) + (($c$081*20)|0)|0) + 4|0);
       $232 = HEAP32[$231>>2]|0;
       $233 = Math_fround(HEAPF32[$232>>2]);
       $234 = (($232) + 4|0);
       $235 = Math_fround(HEAPF32[$234>>2]);
       $236 = (($232) + 8|0);
       $237 = Math_fround(HEAPF32[$236>>2]);
       if ($67) {
        $271 = $233;$273 = $235;$275 = $237;$didSample$2$off050 = 0;$i3$051 = 0;
        while(1) {
         $238 = (($39) + ($i3$051<<2)|0);
         $239 = HEAP32[$238>>2]|0;
         $240 = (($239) + 8|0);
         $241 = Math_fround(HEAPF32[$240>>2]);
         $242 = $241 < Math_fround(0.0);
         if ($242) {
          $$0$i6 = Math_fround(0.0);
         } else {
          $243 = $241 > Math_fround(1.0);
          $$$i5 = $243 ? Math_fround(1.0) : $241;
          $$0$i6 = $$$i5;
         }
         $244 = (($239) + 4|0);
         $245 = HEAP32[$244>>2]|0;
         $246 = (($245) + ($c$081<<2)|0);
         $247 = HEAP32[$246>>2]|0;
         $248 = ($247|0)==(0|0);
         if ($248) {
          $279 = $271;$281 = $273;$283 = $275;$didSample$3$off0 = $didSample$2$off050;
         } else {
          $249 = (($239) + 12|0);
          $250 = Math_fround(HEAPF32[$249>>2]);
          __THREW__ = 0;
          invoke_viif(46,($3|0),($247|0),(+$250));
          $251 = __THREW__; __THREW__ = 0;
          $252 = $251&1;
          if ($252) {
           label = 8;
           break L21;
          }
          $253 = (($247) + 120|0);
          $254 = HEAP32[$253>>2]|0;
          $255 = Math_fround(HEAPF32[$3>>2]);
          $256 = (($254) + 4|0);
          $257 = Math_fround(HEAPF32[$256>>2]);
          $258 = Math_fround($255 - $257);
          $259 = Math_fround(HEAPF32[$72>>2]);
          $260 = (($254) + 8|0);
          $261 = Math_fround(HEAPF32[$260>>2]);
          $262 = Math_fround($259 - $261);
          $263 = Math_fround(HEAPF32[$73>>2]);
          $264 = (($254) + 12|0);
          $265 = Math_fround(HEAPF32[$264>>2]);
          $266 = Math_fround($263 - $265);
          $267 = Math_fround($$0$i6 * $258);
          $268 = Math_fround($$0$i6 * $262);
          $269 = Math_fround($$0$i6 * $266);
          $270 = Math_fround($271 + $267);
          $272 = Math_fround($273 + $268);
          $274 = Math_fround($275 + $269);
          $279 = $270;$281 = $272;$283 = $274;$didSample$3$off0 = 1;
         }
         $276 = (($i3$051) + 1)|0;
         $277 = ($276|0)<($activeStateSize$1|0);
         if ($277) {
          $271 = $279;$273 = $281;$275 = $283;$didSample$2$off050 = $didSample$3$off0;$i3$051 = $276;
         } else {
          break;
         }
        }
        if ($didSample$3$off0) {
         $278 = HEAP32[$231>>2]|0;
         HEAPF32[$278>>2] = $279;
         $280 = (($278) + 4|0);
         HEAPF32[$280>>2] = $281;
         $282 = (($278) + 8|0);
         HEAPF32[$282>>2] = $283;
        }
       }
      } else if ((($77|0) == 2)) {
       $78 = ((($65) + (($c$081*20)|0)|0) + 4|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = Math_fround(HEAPF32[$79>>2]);
       $81 = (($79) + 4|0);
       $82 = Math_fround(HEAPF32[$81>>2]);
       $83 = (($79) + 8|0);
       $84 = Math_fround(HEAPF32[$83>>2]);
       $85 = (($79) + 12|0);
       $86 = Math_fround(HEAPF32[$85>>2]);
       if ($67) {
        $177 = $86;$179 = $80;$182 = $82;$185 = $84;$didSample$0$off070 = 0;$i1$071 = 0;
        while(1) {
         $87 = (($39) + ($i1$071<<2)|0);
         $88 = HEAP32[$87>>2]|0;
         $89 = (($88) + 8|0);
         $90 = Math_fround(HEAPF32[$89>>2]);
         $91 = $90 < Math_fround(0.0);
         if ($91) {
          $$0$i9 = Math_fround(0.0);
         } else {
          $92 = $90 > Math_fround(1.0);
          $$$i8 = $92 ? Math_fround(1.0) : $90;
          $$0$i9 = $$$i8;
         }
         $93 = (($88) + 4|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = (($94) + ($c$081<<2)|0);
         $96 = HEAP32[$95>>2]|0;
         $97 = ($96|0)==(0|0);
         if ($97) {
          $348 = $177;$349 = $185;$350 = $182;$351 = $179;$didSample$1$off0 = $didSample$0$off070;
         } else {
          $98 = (($96) + 152|0);
          $99 = HEAP32[$98>>2]|0;
          $100 = (($99) + 4|0);
          $101 = Math_fround(HEAPF32[$100>>2]);
          $102 = Math_fround(-$101);
          $103 = (($99) + 8|0);
          $104 = Math_fround(HEAPF32[$103>>2]);
          $105 = Math_fround(-$104);
          $106 = (($99) + 12|0);
          $107 = Math_fround(HEAPF32[$106>>2]);
          $108 = Math_fround(-$107);
          $109 = (($99) + 16|0);
          $110 = Math_fround(HEAPF32[$109>>2]);
          $111 = (($88) + 12|0);
          $112 = Math_fround(HEAPF32[$111>>2]);
          __THREW__ = 0;
          invoke_viif(45,($2|0),($96|0),(+$112));
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           label = 9;
           break L21;
          }
          $115 = Math_fround(HEAPF32[$2>>2]);
          $116 = Math_fround($110 * $115);
          $117 = Math_fround(HEAPF32[$69>>2]);
          $118 = Math_fround($117 * $102);
          $119 = Math_fround($116 + $118);
          $120 = Math_fround(HEAPF32[$70>>2]);
          $121 = Math_fround($120 * $105);
          $122 = Math_fround($119 + $121);
          $123 = Math_fround(HEAPF32[$71>>2]);
          $124 = Math_fround($123 * $108);
          $125 = Math_fround($122 - $124);
          $126 = Math_fround($110 * $123);
          $127 = Math_fround($117 * $105);
          $128 = Math_fround($127 + $126);
          $129 = Math_fround($115 * $108);
          $130 = Math_fround($129 + $128);
          $131 = Math_fround($120 * $102);
          $132 = Math_fround($130 - $131);
          $133 = Math_fround($110 * $120);
          $134 = Math_fround($117 * $108);
          $135 = Math_fround($134 + $133);
          $136 = Math_fround($123 * $102);
          $137 = Math_fround($135 + $136);
          $138 = Math_fround($115 * $105);
          $139 = Math_fround($137 - $138);
          $140 = Math_fround($110 * $117);
          $141 = Math_fround($115 * $102);
          $142 = Math_fround($140 - $141);
          $143 = Math_fround($123 * $105);
          $144 = Math_fround($142 - $143);
          $145 = Math_fround($120 * $108);
          $146 = Math_fround($144 - $145);
          $147 = Math_fround($125 * Math_fround(0.0));
          $148 = Math_fround($132 * Math_fround(0.0));
          $149 = Math_fround($147 + $148);
          $150 = Math_fround($139 * Math_fround(0.0));
          $151 = Math_fround($150 + $149);
          $152 = Math_fround($146 + $151);
          $153 = $152 < Math_fround(0.0);
          if ($153) {
           $154 = Math_fround(-$125);
           $155 = Math_fround(-$132);
           $156 = Math_fround(-$139);
           $157 = Math_fround(-$146);
           $$pn7$i = $156;$$pn8$i = $155;$$pn9$i = $154;$$sink$i = $157;
          } else {
           $$pn7$i = $139;$$pn8$i = $132;$$pn9$i = $125;$$sink$i = $146;
          }
          $$pn3$i = Math_fround($$0$i9 * $$pn9$i);
          $$pn2$i = Math_fround($$0$i9 * $$pn8$i);
          $$pn$i = Math_fround($$0$i9 * $$pn7$i);
          $158 = Math_fround($$pn3$i + Math_fround(0.0));
          $159 = Math_fround($$pn2$i + Math_fround(0.0));
          $160 = Math_fround($$pn$i + Math_fround(0.0));
          $161 = Math_fround($$sink$i + Math_fround(-1.0));
          $162 = Math_fround($$0$i9 * $161);
          $163 = Math_fround($162 + Math_fround(1.0));
          $164 = Math_fround($158 * $158);
          $165 = Math_fround($159 * $159);
          $166 = Math_fround($165 + $164);
          $167 = Math_fround($160 * $160);
          $168 = Math_fround($167 + $166);
          $169 = Math_fround($163 * $163);
          $170 = Math_fround($169 + $168);
          $171 = (Math_fround(Math_sqrt((Math_fround($170)))));
          $172 = Math_fround($158 / $171);
          $173 = Math_fround($159 / $171);
          $174 = Math_fround($160 / $171);
          $175 = Math_fround($163 / $171);
          $176 = Math_fround($177 * $172);
          $178 = Math_fround($179 * $175);
          $180 = Math_fround($176 + $178);
          $181 = Math_fround($182 * $174);
          $183 = Math_fround($181 + $180);
          $184 = Math_fround($185 * $173);
          $186 = Math_fround($183 - $184);
          $187 = Math_fround($177 * $173);
          $188 = Math_fround($182 * $175);
          $189 = Math_fround($187 + $188);
          $190 = Math_fround($185 * $172);
          $191 = Math_fround($190 + $189);
          $192 = Math_fround($179 * $174);
          $193 = Math_fround($191 - $192);
          $194 = Math_fround($177 * $174);
          $195 = Math_fround($185 * $175);
          $196 = Math_fround($194 + $195);
          $197 = Math_fround($179 * $173);
          $198 = Math_fround($197 + $196);
          $199 = Math_fround($182 * $172);
          $200 = Math_fround($198 - $199);
          $201 = Math_fround($177 * $175);
          $202 = Math_fround($179 * $172);
          $203 = Math_fround($201 - $202);
          $204 = Math_fround($182 * $173);
          $205 = Math_fround($203 - $204);
          $206 = Math_fround($185 * $174);
          $207 = Math_fround($205 - $206);
          $348 = $207;$349 = $200;$350 = $193;$351 = $186;$didSample$1$off0 = 1;
         }
         $208 = (($i1$071) + 1)|0;
         $209 = ($208|0)<($activeStateSize$1|0);
         if ($209) {
          $177 = $348;$179 = $351;$182 = $350;$185 = $349;$didSample$0$off070 = $didSample$1$off0;$i1$071 = $208;
         } else {
          $$lcssa61 = $348;$$lcssa63 = $349;$$lcssa65 = $350;$$lcssa67 = $351;$didSample$0$off0$lcssa = $didSample$1$off0;
          break;
         }
        }
       } else {
        $$lcssa61 = $86;$$lcssa63 = $84;$$lcssa65 = $82;$$lcssa67 = $80;$didSample$0$off0$lcssa = 0;
       }
       $210 = Math_fround($$lcssa67 * $$lcssa67);
       $211 = Math_fround($$lcssa65 * $$lcssa65);
       $212 = Math_fround($211 + $210);
       $213 = Math_fround($$lcssa63 * $$lcssa63);
       $214 = Math_fround($213 + $212);
       $215 = Math_fround($$lcssa61 * $$lcssa61);
       $216 = Math_fround($215 + $214);
       $217 = (Math_fround(Math_sqrt((Math_fround($216)))));
       $218 = $217 < $68;
       if ($218) {
        $224 = Math_fround(0.0);$226 = Math_fround(0.0);$228 = Math_fround(0.0);$230 = Math_fround(1.0);
       } else {
        $219 = Math_fround($$lcssa67 / $217);
        $220 = Math_fround($$lcssa65 / $217);
        $221 = Math_fround($$lcssa63 / $217);
        $222 = Math_fround($$lcssa61 / $217);
        $224 = $219;$226 = $220;$228 = $221;$230 = $222;
       }
       if ($didSample$0$off0$lcssa) {
        $223 = HEAP32[$78>>2]|0;
        HEAPF32[$223>>2] = $224;
        $225 = (($223) + 4|0);
        HEAPF32[$225>>2] = $226;
        $227 = (($223) + 8|0);
        HEAPF32[$227>>2] = $228;
        $229 = (($223) + 12|0);
        HEAPF32[$229>>2] = $230;
       }
      } else if ((($77|0) == 3)) {
       $284 = ((($65) + (($c$081*20)|0)|0) + 4|0);
       $285 = HEAP32[$284>>2]|0;
       $286 = Math_fround(HEAPF32[$285>>2]);
       $287 = (($285) + 4|0);
       $288 = Math_fround(HEAPF32[$287>>2]);
       $289 = (($285) + 8|0);
       $290 = Math_fround(HEAPF32[$289>>2]);
       if ($67) {
        $324 = $286;$326 = $288;$328 = $290;$didSample$4$off035 = 0;$i6$036 = 0;
        while(1) {
         $291 = (($39) + ($i6$036<<2)|0);
         $292 = HEAP32[$291>>2]|0;
         $293 = (($292) + 8|0);
         $294 = Math_fround(HEAPF32[$293>>2]);
         $295 = $294 < Math_fround(0.0);
         if ($295) {
          $$0$i = Math_fround(0.0);
         } else {
          $296 = $294 > Math_fround(1.0);
          $$$i = $296 ? Math_fround(1.0) : $294;
          $$0$i = $$$i;
         }
         $297 = (($292) + 4|0);
         $298 = HEAP32[$297>>2]|0;
         $299 = (($298) + ($c$081<<2)|0);
         $300 = HEAP32[$299>>2]|0;
         $301 = ($300|0)==(0|0);
         if ($301) {
          $332 = $324;$334 = $326;$336 = $328;$didSample$5$off0 = $didSample$4$off035;
         } else {
          $302 = (($292) + 12|0);
          $303 = Math_fround(HEAPF32[$302>>2]);
          __THREW__ = 0;
          invoke_viif(46,($4|0),($300|0),(+$303));
          $304 = __THREW__; __THREW__ = 0;
          $305 = $304&1;
          if ($305) {
           label = 7;
           break L21;
          }
          $306 = (($300) + 120|0);
          $307 = HEAP32[$306>>2]|0;
          $308 = Math_fround(HEAPF32[$4>>2]);
          $309 = (($307) + 4|0);
          $310 = Math_fround(HEAPF32[$309>>2]);
          $311 = Math_fround($308 - $310);
          $312 = Math_fround(HEAPF32[$74>>2]);
          $313 = (($307) + 8|0);
          $314 = Math_fround(HEAPF32[$313>>2]);
          $315 = Math_fround($312 - $314);
          $316 = Math_fround(HEAPF32[$75>>2]);
          $317 = (($307) + 12|0);
          $318 = Math_fround(HEAPF32[$317>>2]);
          $319 = Math_fround($316 - $318);
          $320 = Math_fround($$0$i * $311);
          $321 = Math_fround($$0$i * $315);
          $322 = Math_fround($$0$i * $319);
          $323 = Math_fround($324 + $320);
          $325 = Math_fround($326 + $321);
          $327 = Math_fround($328 + $322);
          $332 = $323;$334 = $325;$336 = $327;$didSample$5$off0 = 1;
         }
         $329 = (($i6$036) + 1)|0;
         $330 = ($329|0)<($activeStateSize$1|0);
         if ($330) {
          $324 = $332;$326 = $334;$328 = $336;$didSample$4$off035 = $didSample$5$off0;$i6$036 = $329;
         } else {
          break;
         }
        }
        if ($didSample$5$off0) {
         $331 = HEAP32[$284>>2]|0;
         HEAPF32[$331>>2] = $332;
         $333 = (($331) + 4|0);
         HEAPF32[$333>>2] = $334;
         $335 = (($331) + 8|0);
         HEAPF32[$335>>2] = $336;
         $337 = ((($65) + (($c$081*20)|0)|0) + 16|0);
         $338 = HEAP32[$337>>2]|0;
         __THREW__ = 0;
         invoke_vi(3681,($338|0));
         $339 = __THREW__; __THREW__ = 0;
         $340 = $339&1;
         if ($340) {
          label = 10;
          break;
         }
        }
       }
      }
      $341 = (($c$081) + 1)|0;
      $342 = ($341|0)<($63|0);
      if ($342) {
       $c$081 = $341;
      } else {
       break L9;
      }
     }
     if ((label|0) == 7) {
      $23 = ___cxa_find_matching_catch()|0;
      $24 = tempRet0;
      $lpad$phi$index = $23;$lpad$phi$index4 = $24;
     }
     else if ((label|0) == 8) {
      $25 = ___cxa_find_matching_catch()|0;
      $26 = tempRet0;
      $lpad$phi$index = $25;$lpad$phi$index4 = $26;
     }
     else if ((label|0) == 9) {
      $27 = ___cxa_find_matching_catch()|0;
      $28 = tempRet0;
      $lpad$phi$index = $27;$lpad$phi$index4 = $28;
     }
     else if ((label|0) == 10) {
      $29 = ___cxa_find_matching_catch()|0;
      $30 = tempRet0;
      $lpad$phi$index = $29;$lpad$phi$index4 = $30;
     }
     $31 = ($32|0)==(0|0);
     if ($31) {
      $$index = $lpad$phi$index;$$index12 = $lpad$phi$index4;$347 = $0;
      ___resumeException($$index|0);
      // unreachable;
     }
     $33 = HEAP32[628512>>2]|0;
     HEAP32[$0>>2] = $33;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($32|0),($$byval_copy18|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      $345 = ___cxa_find_matching_catch(0|0)|0;
      $346 = tempRet0;
      ___clang_call_terminate($345);
      // unreachable;
     } else {
      $$index = $lpad$phi$index;$$index12 = $lpad$phi$index4;$347 = $0;
      ___resumeException($$index|0);
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $343 = ($32|0)==(0|0);
 if ($343) {
  STACKTOP = sp;return;
 }
 $344 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $344;
 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($32,$$byval_copy18);
 STACKTOP = sp;return;
}
function __ZL27AnimationVisibilityCallbackPvS_i($userData,$senderUserData,$visibilityEvent) {
 $userData = $userData|0;
 $senderUserData = $senderUserData|0;
 $visibilityEvent = $visibilityEvent|0;
 var $$not$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $brmerge$i$i = 0;
 var $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($visibilityEvent|0) == 1)) {
  __ZN9Animation25CheckRendererVisibleStateEv($userData);
  STACKTOP = sp;return;
 } else if ((($visibilityEvent|0) == 0)) {
  $0 = (($userData) + 38|0);
  HEAP8[$0>>0] = 1;
  $1 = (__Z14IsWorldPlayingv()|0);
  if (!($1)) {
   STACKTOP = sp;return;
  }
  $2 = (($userData) + 236|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)!=(0|0);
  $5 = HEAP32[$userData>>2]|0;
  $6 = (($5) + 124|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 4095]($userData);
  $8 = HEAP32[$2>>2]|0;
  $$not$i$i = ($8|0)==(0|0);
  $brmerge$i$i = $$not$i$i | $4;
  if ($brmerge$i$i) {
   STACKTOP = sp;return;
  }
  $9 = (__Z14GetTimeManagerv()|0);
  $10 = (($9) + 88|0);
  $11 = +HEAPF64[$10>>3];
  __ZN9Animation15UpdateAnimationEd($userData,$11);
  STACKTOP = sp;return;
 } else if ((($visibilityEvent|0) == 2)) {
  $12 = (($userData) + 60|0);
  $13 = (($userData) + 64|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$12>>2]|0;
  $16 = ($15|0)==($14|0);
  L13: do {
   if (!($16)) {
    $20 = $15;
    while(1) {
     $19 = HEAP32[$20>>2]|0;
     $21 = ($19|0)==($senderUserData|0);
     $18 = (($20) + 4|0);
     if ($21) {
      break;
     }
     $17 = ($18|0)==($14|0);
     if ($17) {
      break L13;
     } else {
      $20 = $18;
     }
    }
    $22 = (($14) + -4|0);
    $23 = HEAP32[$22>>2]|0;
    HEAP32[$20>>2] = $23;
    $24 = HEAP32[$13>>2]|0;
    $25 = HEAP32[$12>>2]|0;
    $26 = $24;
    $27 = $25;
    $28 = (($26) - ($27))|0;
    $29 = $28 >> 2;
    $30 = ($29|0)==(0);
    if ($30) {
     __ZNSt3__16vectorIP8Renderer13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($12,-1);
     break;
    }
    $31 = (($29) + -1)|0;
    $32 = (($25) + ($31<<2)|0);
    $33 = ($24|0)==($32|0);
    if (!($33)) {
     $__new_last2$i$i$i$i = $32;
     $scevgep$i$i$i$i = (($24) + -4|0);
     $34 = (0 - ($__new_last2$i$i$i$i))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($34)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $35 = $uglygep3$i$i$i$i >>> 2;
     $36 = $35 ^ -1;
     $scevgep4$i$i$i$i = (($24) + ($36<<2)|0);
     HEAP32[$13>>2] = $scevgep4$i$i$i$i;
    }
   }
  } while(0);
  __ZN9Animation25CheckRendererVisibleStateEv($userData);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN9Animation34RecomputeContainedRenderersRecurseER9Transform($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $renderer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $renderer = sp;
 $0 = (($transform) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($1,25)|0);
 HEAP32[$renderer>>2] = $2;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 64|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 68|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($5|0)==($7|0);
  if ($8) {
   $12 = (($this) + 60|0);
   __ZNSt3__16vectorIP8Renderer13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($12,$renderer);
   $$pre = HEAP32[$renderer>>2]|0;
   $13 = $$pre;
  } else {
   $9 = ($5|0)==(0|0);
   if ($9) {
    $11 = 0;
   } else {
    HEAP32[$5>>2] = $2;
    $$pre$i = HEAP32[$4>>2]|0;
    $11 = $$pre$i;
   }
   $10 = (($11) + 4|0);
   HEAP32[$4>>2] = $10;
   $13 = $2;
  }
  __ZN6Object8AddEventEPFvPvS0_iES0_($13,1991,$this);
 }
 $14 = (($transform) + 140|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($transform) + 148|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + ($17<<2)|0);
 $19 = ($17|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $15;
 }
 while(1) {
  $20 = HEAP32[$i$01>>2]|0;
  __ZN9Animation34RecomputeContainedRenderersRecurseER9Transform($this,$20);
  $21 = (($i$01) + 4|0);
  $22 = ($21|0)==($18|0);
  if ($22) {
   break;
  } else {
   $i$01 = $21;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Animation25CheckRendererVisibleStateEv($this) {
 $this = $this|0;
 var $$not$i$i = 0, $$not$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge$i$i = 0, $brmerge$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 L1: do {
  if (!($4)) {
   $8 = $3;
   while(1) {
    $7 = HEAP32[$8>>2]|0;
    $9 = (__ZNK8Renderer16IsVisibleInSceneEv($7)|0);
    $6 = (($8) + 4|0);
    if ($9) {
     break;
    }
    $5 = ($6|0)==($1|0);
    if ($5) {
     break L1;
    } else {
     $8 = $6;
    }
   }
   $10 = (($this) + 38|0);
   HEAP8[$10>>0] = 1;
   $11 = (__Z14IsWorldPlayingv()|0);
   if (!($11)) {
    STACKTOP = sp;return;
   }
   $12 = (($this) + 236|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)!=(0|0);
   $15 = HEAP32[$this>>2]|0;
   $16 = (($15) + 124|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_vi[$17 & 4095]($this);
   $18 = HEAP32[$12>>2]|0;
   $$not$i$i1 = ($18|0)==(0|0);
   $brmerge$i$i2 = $$not$i$i1 | $14;
   if ($brmerge$i$i2) {
    STACKTOP = sp;return;
   }
   $19 = (__Z14GetTimeManagerv()|0);
   $20 = (($19) + 88|0);
   $21 = +HEAPF64[$20>>3];
   __ZN9Animation15UpdateAnimationEd($this,$21);
   STACKTOP = sp;return;
  }
 } while(0);
 $22 = (($this) + 38|0);
 HEAP8[$22>>0] = 0;
 $23 = (__Z14IsWorldPlayingv()|0);
 if (!($23)) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 236|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)!=(0|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + 124|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vi[$29 & 4095]($this);
 $30 = HEAP32[$24>>2]|0;
 $$not$i$i = ($30|0)==(0|0);
 $brmerge$i$i = $$not$i$i | $26;
 if ($brmerge$i$i) {
  STACKTOP = sp;return;
 }
 $31 = (__Z14GetTimeManagerv()|0);
 $32 = (($31) + 88|0);
 $33 = +HEAPF64[$32>>3];
 __ZN9Animation15UpdateAnimationEd($this,$33);
 STACKTOP = sp;return;
}
function __ZN9Animation15UpdateAnimationEd($this,$time) {
 $this = $this|0;
 $time = +$time;
 var $$0 = 0, $$01 = 0, $$byval_copy11 = 0, $$idx = 0, $$ph$ph$ph = 0, $$pr = 0, $$pre = 0, $$pre45 = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $allocPtr$0 = 0, $i$0$ph35 = 0, $i1$015 = 0, $i2$010 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index4 = 0, $needsUpdate = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $stoppedAnimationCount$0$lcssa = 0, $stoppedAnimationCount$0$ph36 = 0, $stoppedAnimationCount$025 = 0, $stoppedAnimationCount$1 = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy11 = sp + 8|0;
 $0 = sp;
 $needsUpdate = sp + 12|0;
 $1 = sp + 4|0;
 HEAP8[$needsUpdate>>0] = 0;
 $2 = (($this) + 248|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 252|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $8 = $3;
  while(1) {
   $7 = HEAP32[$8>>2]|0;
   __ZN9Animation13SyncLayerTimeEi($this,$7);
   $9 = (($8) + 4|0);
   $10 = HEAP32[$4>>2]|0;
   $11 = ($9|0)==($10|0);
   if ($11) {
    break;
   } else {
    $8 = $9;
   }
  }
 }
 $12 = (($this) + 92|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 88|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $13;
 $17 = $15;
 $18 = (($16) - ($17))|0;
 $19 = (($18) + 15)|0;
 $20 = ($19>>>0)<(2000);
 $21 = ($13|0)!=($15|0);
 if ($20) {
  if ($21) {
   $22 = STACKTOP; STACKTOP = STACKTOP + ((((1*$19)|0)+15)&-16)|0;;
   $141 = 0;$40 = $13;$41 = $15;$allocPtr$0 = $22;
   label = 14;
  } else {
   $116 = 0;$132 = 0;$stoppedAnimationCount$0$lcssa = 0;
   label = 35;
  }
 } else {
  if ($21) {
   $23 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
   $24 = (invoke_iiiiiii(102,($19|0),16,($$byval_copy11|0),0,(765224|0),1806)|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $$ph$ph$ph = 0;
    label = 12;
   } else {
    $$pre = HEAP32[$12>>2]|0;
    $$pre45 = HEAP32[$14>>2]|0;
    $141 = $24;$40 = $$pre;$41 = $$pre45;$allocPtr$0 = $24;
    label = 14;
   }
  } else {
   $116 = 0;$132 = 0;$stoppedAnimationCount$0$lcssa = 0;
   label = 35;
  }
 }
 L11: do {
  if ((label|0) == 14) {
   $35 = $allocPtr$0;
   $36 = (($35) + 15)|0;
   $37 = $36 & -16;
   $38 = $37;
   $39 = ($40|0)==($41|0);
   if ($39) {
    $116 = $38;$132 = $141;$stoppedAnimationCount$0$lcssa = 0;
    label = 35;
   } else {
    $42 = (($this) + 232|0);
    $43 = (($this) + 228|0);
    $143 = $41;$i$0$ph35 = 0;$stoppedAnimationCount$0$ph36 = 0;
    L14: while(1) {
     $$idx = $i$0$ph35 << 2;
     $44 = $$idx >> 2;
     $$sum$i = (($44) + 1)|0;
     $46 = $143;$stoppedAnimationCount$025 = $stoppedAnimationCount$0$ph36;
     while(1) {
      $45 = (($46) + ($i$0$ph35<<2)|0);
      $47 = HEAP32[$45>>2]|0;
      $48 = (($47) + 56|0);
      $49 = HEAP16[$48>>1]|0;
      $50 = $49 & 2;
      $51 = ($50<<16>>16)==(0);
      if ($51) {
       $stoppedAnimationCount$1 = $stoppedAnimationCount$025;
      } else {
       __THREW__ = 0;
       $52 = (invoke_iidi(3,($47|0),(+$time),($this|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 11;
        break L14;
       }
       if ($52) {
        $55 = HEAP16[$48>>1]|0;
        $56 = $55 & 64;
        $57 = ($56<<16>>16)==(0);
        if ($57) {
         $58 = (($stoppedAnimationCount$025) + 1)|0;
         $59 = (($38) + ($stoppedAnimationCount$025<<2)|0);
         HEAP32[$59>>2] = $47;
         $stoppedAnimationCount$1 = $58;
        } else {
         $stoppedAnimationCount$1 = $stoppedAnimationCount$025;
        }
       } else {
        $stoppedAnimationCount$1 = $stoppedAnimationCount$025;
       }
      }
      $60 = (($47) + 96|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if (!($62)) {
       $63 = HEAP16[$48>>1]|0;
       $64 = $63 & 2;
       $65 = ($64<<16>>16)==(0);
       if (!($65)) {
        $66 = (($47) + 8|0);
        $67 = Math_fround(HEAPF32[$66>>2]);
        $68 = $67 > Math_fround(9.99999974737875163555E-5);
        if ($68) {
         HEAP8[$needsUpdate>>0] = 1;
        }
       }
      }
      $69 = (($47) + 64|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = HEAP32[$42>>2]|0;
      $72 = $71 | $70;
      HEAP32[$42>>2] = $72;
      HEAP32[$69>>2] = 0;
      $73 = HEAP16[$48>>1]|0;
      $74 = $73 & 64;
      $75 = ($74<<16>>16)==(0);
      if ($75) {
       break;
      }
      $76 = ($47|0)==(0|0);
      if (!($76)) {
       __THREW__ = 0;
       invoke_vi(3677,($47|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        label = 33;
        break L14;
       }
       __ZdlPv($47);
      }
      $79 = HEAP32[$42>>2]|0;
      $80 = $79 | 2;
      HEAP32[$42>>2] = $80;
      $81 = HEAP32[$14>>2]|0;
      $82 = (($81) + ($44<<2)|0);
      $83 = (($81) + ($$sum$i<<2)|0);
      $84 = HEAP32[$12>>2]|0;
      $85 = $84;
      $86 = $83;
      $87 = (($85) - ($86))|0;
      $88 = $87 >> 2;
      _memmove(($82|0),($83|0),($87|0))|0;
      $$sum1$i = (($88) + ($44))|0;
      $89 = (($81) + ($$sum1$i<<2)|0);
      $90 = HEAP32[$12>>2]|0;
      $91 = ($90|0)==($89|0);
      if ($91) {
       $97 = $89;
      } else {
       $__new_last2$i$i$i = $89;
       $scevgep$i$i$i = (($90) + -4|0);
       $92 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($92)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $93 = $uglygep3$i$i$i >>> 2;
       $94 = $93 ^ -1;
       $scevgep4$i$i$i = (($90) + ($94<<2)|0);
       HEAP32[$12>>2] = $scevgep4$i$i$i;
       $97 = $scevgep4$i$i$i;
      }
      HEAP32[$43>>2] = 0;
      $95 = HEAP32[$14>>2]|0;
      $96 = $97;
      $98 = $95;
      $99 = (($96) - ($98))|0;
      $100 = $99 >> 2;
      $101 = ($i$0$ph35>>>0)<($100>>>0);
      if ($101) {
       $46 = $95;$stoppedAnimationCount$025 = $stoppedAnimationCount$1;
      } else {
       $116 = $38;$132 = $141;$stoppedAnimationCount$0$lcssa = $stoppedAnimationCount$1;
       label = 35;
       break L11;
      }
     }
     $104 = (($i$0$ph35) + 1)|0;
     $105 = HEAP32[$12>>2]|0;
     $106 = HEAP32[$14>>2]|0;
     $107 = $105;
     $108 = $106;
     $109 = (($107) - ($108))|0;
     $110 = $109 >> 2;
     $111 = ($104>>>0)<($110>>>0);
     if ($111) {
      $143 = $106;$i$0$ph35 = $104;$stoppedAnimationCount$0$ph36 = $stoppedAnimationCount$1;
     } else {
      $116 = $38;$132 = $141;$stoppedAnimationCount$0$lcssa = $stoppedAnimationCount$1;
      label = 35;
      break L11;
     }
    }
    if ((label|0) == 11) {
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     $142 = $141;$lpad$phi$index = $31;$lpad$phi$index4 = $32;
     label = 13;
     break;
    }
    else if ((label|0) == 33) {
     $102 = ___cxa_find_matching_catch()|0;
     $103 = tempRet0;
     __ZdlPv($47);
     $$0 = $103;$$01 = $102;$135 = $141;
     break;
    }
   }
  }
 } while(0);
 L41: do {
  if ((label|0) == 35) {
   __THREW__ = 0;
   invoke_vii(3360,($this|0),($needsUpdate|0));
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if ($113) {
    $$ph$ph$ph = $132;
    label = 12;
   } else {
    $114 = ($stoppedAnimationCount$0$lcssa|0)>(0);
    do {
     if ($114) {
      $i1$015 = 0;
      while(1) {
       $115 = (($116) + ($i1$015<<2)|0);
       $117 = HEAP32[$115>>2]|0;
       __THREW__ = 0;
       invoke_vi(3682,($117|0));
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        label = 10;
        break;
       }
       $120 = (($i1$015) + 1)|0;
       $121 = ($120|0)<($stoppedAnimationCount$0$lcssa|0);
       if ($121) {
        $i1$015 = $120;
       } else {
        label = 39;
        break;
       }
      }
      if ((label|0) == 10) {
       $29 = ___cxa_find_matching_catch()|0;
       $30 = tempRet0;
       $142 = $132;$lpad$phi$index = $29;$lpad$phi$index4 = $30;
       label = 13;
       break L41;
      }
      else if ((label|0) == 39) {
       HEAP8[$needsUpdate>>0] = 1;
       label = 41;
       break;
      }
     } else {
      $$pr = HEAP8[$needsUpdate>>0]|0;
      $122 = ($$pr<<24>>24)==(0);
      if (!($122)) {
       label = 41;
      }
     }
    } while(0);
    L52: do {
     if ((label|0) == 41) {
      __THREW__ = 0;
      invoke_vi(3683,($this|0));
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       $$ph$ph$ph = $132;
       label = 12;
       break L41;
      }
      if ($114) {
       $i2$010 = 0;
       while(1) {
        $125 = (($116) + ($i2$010<<2)|0);
        $126 = HEAP32[$125>>2]|0;
        __THREW__ = 0;
        invoke_vi(3684,($126|0));
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if ($128) {
         break;
        }
        $129 = (($i2$010) + 1)|0;
        $130 = ($129|0)<($stoppedAnimationCount$0$lcssa|0);
        if ($130) {
         $i2$010 = $129;
        } else {
         break L52;
        }
       }
       $27 = ___cxa_find_matching_catch()|0;
       $28 = tempRet0;
       $142 = $132;$lpad$phi$index = $27;$lpad$phi$index4 = $28;
       label = 13;
       break L41;
      }
     }
    } while(0);
    $131 = ($132|0)==(0|0);
    if ($131) {
     STACKTOP = sp;return;
    }
    $133 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $133;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($132,$$byval_copy11);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $142 = $$ph$ph$ph;$lpad$phi$index = $33;$lpad$phi$index4 = $34;
  label = 13;
 }
 if ((label|0) == 13) {
  $$0 = $lpad$phi$index4;$$01 = $lpad$phi$index;$135 = $142;
 }
 $134 = ($135|0)==(0|0);
 if ($134) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $136 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $136;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($135|0),($$byval_copy11|0));
 $137 = __THREW__; __THREW__ = 0;
 $138 = $137&1;
 if ($138) {
  $139 = ___cxa_find_matching_catch(0|0)|0;
  $140 = tempRet0;
  ___clang_call_terminate($139);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN9Animation13SyncLayerTimeEi($this,$layer) {
 $this = $this|0;
 $layer = $layer|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $normalizedSpeed$06 = Math_fround(0), $normalizedSpeed$1 = Math_fround(0);
 var $normalizedTime$05 = Math_fround(0), $normalizedTime$1 = Math_fround(0), $summedLayerWeight$04 = Math_fround(0), $summedLayerWeight$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $6 = $1;$normalizedSpeed$06 = Math_fround(0.0);$normalizedTime$05 = Math_fround(0.0);$summedLayerWeight$04 = Math_fround(0.0);
 }
 while(1) {
  $5 = HEAP32[$6>>2]|0;
  $7 = (($5) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($layer|0);
  if ($9) {
   $10 = (($5) + 56|0);
   $11 = HEAP16[$10>>1]|0;
   $12 = $11 & 2;
   $13 = ($12<<16>>16)==(0);
   if ($13) {
    $normalizedSpeed$1 = $normalizedSpeed$06;$normalizedTime$1 = $normalizedTime$05;$summedLayerWeight$1 = $summedLayerWeight$04;
   } else {
    $14 = (($5) + 8|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = $15 < Math_fround(0.0);
    $17 = $16 ? Math_fround(0.0) : $15;
    $18 = (($5) + 36|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = (($5) + 92|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = Math_fround($19 / $21);
    $23 = Math_fround($17 * $22);
    $24 = Math_fround($normalizedSpeed$06 + $23);
    $25 = (($5) + 16|0);
    $26 = +HEAPF64[$25>>3];
    $27 = +$21;
    $28 = $26 / $27;
    $29 = Math_fround($28);
    $30 = Math_fround($17 * $29);
    $31 = Math_fround($normalizedTime$05 + $30);
    $32 = Math_fround($summedLayerWeight$04 + $17);
    $normalizedSpeed$1 = $24;$normalizedTime$1 = $31;$summedLayerWeight$1 = $32;
   }
  } else {
   $normalizedSpeed$1 = $normalizedSpeed$06;$normalizedTime$1 = $normalizedTime$05;$summedLayerWeight$1 = $summedLayerWeight$04;
  }
  $33 = (($6) + 4|0);
  $34 = ($33|0)==($3|0);
  if ($34) {
   break;
  } else {
   $6 = $33;$normalizedSpeed$06 = $normalizedSpeed$1;$normalizedTime$05 = $normalizedTime$1;$summedLayerWeight$04 = $summedLayerWeight$1;
  }
 }
 $35 = $summedLayerWeight$1 > Math_fround(9.99999974737875163555E-5);
 if (!($35)) {
  STACKTOP = sp;return;
 }
 $36 = Math_fround($normalizedSpeed$1 / $summedLayerWeight$1);
 $37 = Math_fround($normalizedTime$1 / $summedLayerWeight$1);
 $38 = ($1|0)==($3|0);
 if ($38) {
  STACKTOP = sp;return;
 } else {
  $40 = $1;$56 = $3;
 }
 while(1) {
  $39 = HEAP32[$40>>2]|0;
  $41 = (($39) + 32|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==($layer|0);
  if ($43) {
   $44 = (($39) + 56|0);
   $45 = HEAP16[$44>>1]|0;
   $46 = $45 & 2;
   $47 = ($46<<16>>16)==(0);
   if ($47) {
    $55 = $56;
   } else {
    $48 = (($39) + 92|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = Math_fround($36 * $49);
    $51 = (($39) + 40|0);
    HEAPF32[$51>>2] = $50;
    $52 = Math_fround($37 * $49);
    __ZN14AnimationState7SetTimeEf($39,$52);
    $$pre = HEAP32[$2>>2]|0;
    $55 = $$pre;
   }
  } else {
   $55 = $56;
  }
  $53 = (($40) + 4|0);
  $54 = ($53|0)==($55|0);
  if ($54) {
   break;
  } else {
   $40 = $53;$56 = $55;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Animation14SampleInternalEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN9Animation19ValidateBoundCurvesEv($this);
 $1 = (($this) + 232|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = $2 & 1;
  $5 = ($4|0)==(0);
  if ($5) {
   $7 = $2;
  } else {
   __ZN9Animation25RebuildStateForEverythingEv($this);
   $$pre = HEAP32[$1>>2]|0;
   $7 = $$pre;
  }
  $6 = $7 & 2;
  $8 = ($6|0)==(0);
  if (!($8)) {
   $9 = (($this) + 88|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 92|0);
   $12 = HEAP32[$11>>2]|0;
   __ZNSt3__16__sortIR12GreaterLayerPP14AnimationStateEEvT0_S6_T_($10,$12,$0);
   $13 = HEAP32[$1>>2]|0;
   $14 = $13 & -3;
   HEAP32[$1>>2] = $14;
   $15 = (($this) + 228|0);
   HEAP32[$15>>2] = 0;
  }
 }
 $16 = (($this) + 80|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (__ZN9Animation21RebuildBoundStateMaskEv($this)|0);
 if ($19) {
  $20 = (($this) + 228|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0);
  if (!($22)) {
   __ZN9Animation14BlendOptimizedEv($this);
  }
 } else {
  __ZN9Animation12BlendGenericEv($this);
 }
 __ZN9Animation13BlendAdditiveEv($this);
 $23 = (($this) + 37|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)!=(0);
 $26 = $25 ? 16 : 0;
 $27 = (($this) + 48|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($this) + 44|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $28;
 $32 = $30;
 $33 = (($31) - ($32))|0;
 $34 = $33 >> 2;
 $35 = ($33|0)>(0);
 if (!($35)) {
  STACKTOP = sp;return;
 }
 $36 = (($this) + 56|0);
 $37 = HEAP32[$30>>2]|0;
 $38 = HEAP32[$36>>2]|0;
 $39 = $38 | $26;
 __ZN9Transform20SendTransformChangedEi($37,$39);
 $40 = ($33|0)>(4);
 if ($40) {
  $42 = 1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $$pre$i = HEAP32[$29>>2]|0;
  $41 = (($$pre$i) + ($42<<2)|0);
  $43 = HEAP32[$41>>2]|0;
  $44 = HEAP32[$36>>2]|0;
  $45 = $44 | $26;
  __ZN9Transform20SendTransformChangedEi($43,$45);
  $46 = (($42) + 1)|0;
  $47 = ($46|0)<($34|0);
  if ($47) {
   $42 = $46;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Animation22UpdateQueuedAnimationsERb($this,$needsUpdate) {
 $this = $this|0;
 $needsUpdate = $needsUpdate|0;
 var $$ = Math_fround(0), $$10 = Math_fround(0), $$be = Math_fround(0), $$be15 = Math_fround(0), $$be16 = 0, $$idx$val = 0, $$idx1$val = 0, $$idx2 = 0, $$idx2$val = 0, $$idx3 = 0, $$idx3$val = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0);
 var $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0.0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0);
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0.0;
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $__new_last2$i$i$i = 0, $lastLayer$017 = 0;
 var $lastLayer$3 = 0, $or$cond = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $startNow$0$in = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 276|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 280|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $$idx2 = (($this) + 88|0);
 $$idx3 = (($this) + 92|0);
 $15 = Math_fround(-1.0);$46 = Math_fround(-1.0);$6 = $1;$97 = $3;$lastLayer$017 = -1;
 while(1) {
  $5 = (($6) + 8|0);
  $7 = Math_fround(HEAPF32[$5>>2]);
  $8 = (($6) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$6>>2]|0;
  $13 = ($12|0)==(4);
  if ($13) {
   $14 = $15 < Math_fround(0.0);
   if ($14) {
    $$idx2$val = HEAP32[$$idx2>>2]|0;
    $$idx3$val = HEAP32[$$idx3>>2]|0;
    $16 = ($$idx2$val|0)==($$idx3$val|0);
    if ($16) {
     $75 = Math_fround(0.0);$98 = Math_fround(0.0);$99 = Math_fround(0.0);$lastLayer$3 = $11;
    } else {
     $18 = $$idx2$val;$29 = Math_fround(0.0);$37 = Math_fround(0.0);
     while(1) {
      $17 = HEAP32[$18>>2]|0;
      $19 = (($17) + 56|0);
      $20 = HEAP16[$19>>1]|0;
      $21 = $20 & 2;
      $22 = ($21<<16>>16)==(0);
      do {
       if ($22) {
        $100 = $37;$101 = $29;
       } else {
        $23 = (($17) + 32|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = (($17) + 68|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = ($26>>>0)>(1);
        if ($27) {
         $28 = ($24|0)==($11|0);
         $$ = $28 ? Math_fround(inf) : $29;
         $100 = Math_fround(inf);$101 = $$;
         break;
        }
        $30 = (($17) + 92|0);
        $31 = Math_fround(HEAPF32[$30>>2]);
        $32 = (($17) + 16|0);
        $33 = +HEAPF64[$32>>3];
        $34 = Math_fround($33);
        $35 = Math_fround($31 - $34);
        $36 = $37 < $35;
        $38 = $36 ? $35 : $37;
        $39 = ($24|0)==($11|0);
        if ($39) {
         $40 = $29 < $35;
         $41 = $40 ? $35 : $29;
         $100 = $38;$101 = $41;
        } else {
         $100 = $38;$101 = $29;
        }
       }
      } while(0);
      $42 = (($18) + 4|0);
      $43 = ($42|0)==($$idx3$val|0);
      if ($43) {
       $75 = $100;$98 = $100;$99 = $101;$lastLayer$3 = $11;
       break;
      } else {
       $18 = $42;$29 = $101;$37 = $100;
      }
     }
    }
   } else {
    $75 = $15;$98 = $15;$99 = $46;$lastLayer$3 = $lastLayer$017;
   }
  } else {
   $44 = ($lastLayer$017|0)!=($11|0);
   $45 = $46 < Math_fround(0.0);
   $or$cond = $44 | $45;
   if ($or$cond) {
    $$idx$val = HEAP32[$$idx2>>2]|0;
    $$idx1$val = HEAP32[$$idx3>>2]|0;
    $47 = ($$idx$val|0)==($$idx1$val|0);
    if ($47) {
     $75 = Math_fround(0.0);$98 = Math_fround(0.0);$99 = Math_fround(0.0);$lastLayer$3 = $11;
    } else {
     $49 = $$idx$val;$60 = Math_fround(0.0);$68 = Math_fround(0.0);
     while(1) {
      $48 = HEAP32[$49>>2]|0;
      $50 = (($48) + 56|0);
      $51 = HEAP16[$50>>1]|0;
      $52 = $51 & 2;
      $53 = ($52<<16>>16)==(0);
      do {
       if ($53) {
        $102 = $68;$103 = $60;
       } else {
        $54 = (($48) + 32|0);
        $55 = HEAP32[$54>>2]|0;
        $56 = (($48) + 68|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57>>>0)>(1);
        if ($58) {
         $59 = ($55|0)==($11|0);
         $$10 = $59 ? Math_fround(inf) : $60;
         $102 = Math_fround(inf);$103 = $$10;
         break;
        }
        $61 = (($48) + 92|0);
        $62 = Math_fround(HEAPF32[$61>>2]);
        $63 = (($48) + 16|0);
        $64 = +HEAPF64[$63>>3];
        $65 = Math_fround($64);
        $66 = Math_fround($62 - $65);
        $67 = $68 < $66;
        $69 = $67 ? $66 : $68;
        $70 = ($55|0)==($11|0);
        if ($70) {
         $71 = $60 < $66;
         $72 = $71 ? $66 : $60;
         $102 = $69;$103 = $72;
        } else {
         $102 = $69;$103 = $60;
        }
       }
      } while(0);
      $73 = (($49) + 4|0);
      $74 = ($73|0)==($$idx1$val|0);
      if ($74) {
       $75 = $103;$98 = $102;$99 = $103;$lastLayer$3 = $11;
       break;
      } else {
       $49 = $73;$60 = $103;$68 = $102;
      }
     }
    }
   } else {
    $75 = $46;$98 = $15;$99 = $46;$lastLayer$3 = $lastLayer$017;
   }
  }
  $startNow$0$in = !($7 >= $75);
  if ($startNow$0$in) {
   $94 = (($6) + 16|0);
   $$be = $98;$$be15 = $99;$$be16 = $94;$96 = $97;
  } else {
   __ZN9Animation9CrossFadeER14AnimationStatefib($this,$9,$7,$12,0);
   $76 = HEAP32[$0>>2]|0;
   $77 = $6;
   $78 = $76;
   $79 = (($77) - ($78))|0;
   $80 = $79 >> 4;
   $81 = (($76) + ($80<<4)|0);
   $$sum$i = (($80) + 1)|0;
   $82 = (($76) + ($$sum$i<<4)|0);
   $83 = HEAP32[$2>>2]|0;
   $84 = $83;
   $85 = $82;
   $86 = (($84) - ($85))|0;
   $87 = $86 >> 4;
   _memmove(($81|0),($82|0),($86|0))|0;
   $$sum1$i = (($87) + ($80))|0;
   $88 = (($76) + ($$sum1$i<<4)|0);
   $89 = HEAP32[$2>>2]|0;
   $90 = ($89|0)==($88|0);
   if ($90) {
    $104 = $88;
   } else {
    $__new_last2$i$i$i = $88;
    $scevgep$i$i$i = (($89) + -16|0);
    $91 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($91)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $92 = $uglygep3$i$i$i >>> 4;
    $93 = $92 ^ -1;
    $scevgep4$i$i$i = (($89) + ($93<<4)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i;
    $104 = $scevgep4$i$i$i;
   }
   HEAP8[$needsUpdate>>0] = 1;
   $$be = Math_fround(-1.0);$$be15 = Math_fround(-1.0);$$be16 = $81;$96 = $104;
  }
  $95 = ($$be16|0)==($96|0);
  if ($95) {
   break;
  } else {
   $15 = $$be;$46 = $$be15;$6 = $$be16;$97 = $96;$lastLayer$017 = $lastLayer$3;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9Animation20GetClipLegacyWarningEP13AnimationClip($this,$clip) {
 $this = $this|0;
 $clip = $clip|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 8|0;
 $1 = ($clip|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP32[$clip>>2]|0;
 $3 = (($2) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($clip)|0);
 if ($5) {
  $$0 = $clip;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$clip>>2]|0;
 $7 = (($6) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($clip)|0);
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($this)|0);
 HEAP32[$vararg_buffer>>2] = $9;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $13;
 __Z6FormatPKcz($0,765280,$vararg_buffer);
 $14 = (($clip) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$0>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $21 = (($0) + 1|0);
  $22 = $21;
 } else {
  $19 = (($0) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $22 = $20;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($22|0),0,(765224|0),1901,512,($15|0),0,(0|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $32 = HEAP8[$0>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   ___resumeException($30|0);
   // unreachable;
  }
  $35 = (($0) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  __ZdlPv($36);
  ___resumeException($30|0);
  // unreachable;
 } else {
  $25 = HEAP8[$0>>0]|0;
  $26 = $25 & 1;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $28 = (($0) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  __ZdlPv($29);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN9Animation20BuildAnimationStatesEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$byval_copy4 = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i2 = 0, $$pre$i3 = 0, $$pre1$i = 0, $$pre1$i$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__p$0$i$i$i$i = 0, $animationWrapMode$clipWrapMode$i = 0, $i$08 = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $temp$0$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy4 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = (($this) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 92|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 264|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 268|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12|0)==($14|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$13>>2]|0;
 $17 = HEAP32[$11>>2]|0;
 $18 = $16;
 $19 = $17;
 $20 = (($18) - ($19))|0;
 $21 = $20 >> 2;
 $22 = (($this) + 96|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23;
 $25 = $7;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 2;
 $28 = ($27>>>0)<($21>>>0);
 if ($28) {
  $29 = ($21|0)==(0);
  if ($29) {
   $32 = 0;$34 = $7;$36 = $7;
  } else {
   HEAP32[$0>>2] = 18;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy4,0,765224,79)|0);
   $$pre$i2 = HEAP32[$6>>2]|0;
   $$pre1$i = HEAP32[$8>>2]|0;
   $32 = $30;$34 = $$pre1$i;$36 = $$pre$i2;
  }
  $31 = (($32) + ($21<<2)|0);
  $33 = $34;
  $35 = $36;
  $37 = (($33) - ($35))|0;
  $38 = $37 >> 2;
  $$sum$i = (0 - ($38))|0;
  $39 = (($32) + ($$sum$i<<2)|0);
  _memcpy(($39|0),($36|0),($37|0))|0;
  $40 = HEAP32[$6>>2]|0;
  HEAP32[$6>>2] = $39;
  HEAP32[$8>>2] = $32;
  HEAP32[$22>>2] = $31;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   HEAP32[$3>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($40|0),($$byval_copy4|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    $44 = ___cxa_find_matching_catch()|0;
    $45 = tempRet0;
    ___cxa_call_unexpected(($44|0));
    // unreachable;
   }
  }
 }
 $46 = (__Z14GetTimeManagerv()|0);
 $47 = (($46) + 88|0);
 $48 = +HEAPF64[$47>>3];
 $49 = HEAP32[$13>>2]|0;
 $50 = HEAP32[$11>>2]|0;
 $51 = ($49|0)==($50|0);
 L15: do {
  if (!($51)) {
   $52 = (($5) + 1|0);
   $53 = (($this) + 32|0);
   $54 = (($5) + 8|0);
   $55 = (($5) + 4|0);
   $57 = $50;$i$08 = 0;
   while(1) {
    $56 = (($57) + ($i$08<<2)|0);
    $58 = HEAP32[$56>>2]|0;
    $59 = ($58|0)==(0);
    if ($59) {
     $$0$i = 0;
    } else {
     HEAP32[$2>>2] = $58;
     $60 = HEAP32[560624>>2]|0;
     $61 = ($60|0)==(0|0);
     if ($61) {
      label = 20;
     } else {
      $62 = (($60) + 36|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($60) + 4|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = ($63|0)==($65|0);
      do {
       if ($66) {
        $67 = (($60) + 28|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = (($60) + 32|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = (($68) + ($70<<3)|0);
        $87 = $71;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$60,$2);
        $72 = HEAP32[$$byval_copy4>>2]|0;
        $73 = ($72|0)==(-1);
        $74 = (($60) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        if ($73) {
         $76 = (($60) + 32|0);
         $77 = HEAP32[$76>>2]|0;
         $78 = (($75) + ($77<<3)|0);
         $87 = $78;
         break;
        } else {
         $79 = (($75) + ($72<<3)|0);
         $87 = $79;
         break;
        }
       }
      } while(0);
      $80 = HEAP32[560624>>2]|0;
      $81 = (($80) + 28|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($80) + 32|0);
      $84 = HEAP32[$83>>2]|0;
      $85 = (($82) + ($84<<3)|0);
      $86 = ($87|0)==($85|0);
      if ($86) {
       label = 20;
      } else {
       $88 = (($87) + 4|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = ($89|0)==(0|0);
       if ($90) {
        label = 20;
       } else {
        $temp$0$i = $89;
       }
      }
     }
     if ((label|0) == 20) {
      label = 0;
      $91 = HEAP32[$56>>2]|0;
      $92 = (__Z31ReadObjectFromPersistentManageri($91)|0);
      $temp$0$i = $92;
     }
     $$0$i = $temp$0$i;
    }
    $93 = (__ZN9Animation20GetClipLegacyWarningEP13AnimationClip($this,$$0$i)|0);
    $94 = ($93|0)==(0|0);
    if (!($94)) {
     $95 = (__Znwj(152)|0);
     __THREW__ = 0;
     invoke_vi(3678,($95|0));
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      label = 38;
      break;
     }
     HEAP32[$4>>2] = $95;
     $98 = HEAP32[$8>>2]|0;
     $99 = HEAP32[$22>>2]|0;
     $100 = ($98|0)==($99|0);
     if ($100) {
      __ZNSt3__16vectorIP14AnimationState13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($6,$4);
      $$pre = HEAP32[$8>>2]|0;
      $105 = $$pre;
     } else {
      $101 = ($98|0)==(0|0);
      if ($101) {
       $103 = 0;
      } else {
       HEAP32[$98>>2] = $95;
       $$pre$i3 = HEAP32[$8>>2]|0;
       $103 = $$pre$i3;
      }
      $102 = (($103) + 4|0);
      HEAP32[$8>>2] = $102;
      $105 = $102;
     }
     $104 = (($105) + -4|0);
     $106 = HEAP32[$104>>2]|0;
     $107 = HEAP32[$93>>2]|0;
     $108 = (($107) + 32|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = (FUNCTION_TABLE_ii[$109 & 4095]($93)|0);
     $111 = (_strlen(($110|0))|0);
     $112 = ($111>>>0)>(2147483631);
     if ($112) {
      label = 30;
      break;
     }
     $113 = ($111>>>0)<(11);
     if ($113) {
      $114 = $111 << 1;
      $115 = $114&255;
      HEAP8[$5>>0] = $115;
      $__p$0$i$i$i$i = $52;
     } else {
      $116 = (($111) + 16)|0;
      $117 = $116 & -16;
      HEAP32[$0>>2] = 59;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
      $118 = (__Z15malloc_internaljj10MemLabelIdiPKci($117,16,$$byval_copy4,0,765224,79)|0);
      HEAP32[$54>>2] = $118;
      $119 = $117 | 1;
      HEAP32[$5>>2] = $119;
      HEAP32[$55>>2] = $111;
      $__p$0$i$i$i$i = $118;
     }
     _memcpy(($__p$0$i$i$i$i|0),($110|0),($111|0))|0;
     $120 = (($__p$0$i$i$i$i) + ($111)|0);
     HEAP8[$120>>0] = 0;
     $121 = (($93) + 88|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = HEAP32[$53>>2]|0;
     $124 = ($122|0)==(0);
     $animationWrapMode$clipWrapMode$i = $124 ? $123 : $122;
     __THREW__ = 0;
     invoke_viiidii(1,($106|0),($5|0),($93|0),(+$48),($animationWrapMode$clipWrapMode$i|0),0);
     $125 = __THREW__; __THREW__ = 0;
     $126 = $125&1;
     if ($126) {
      label = 39;
      break;
     }
     $127 = HEAP8[$5>>0]|0;
     $128 = $127 & 1;
     $129 = ($128<<24>>24)==(0);
     if (!($129)) {
      $130 = HEAP32[$54>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($130|0),($$byval_copy4|0));
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       label = 37;
       break;
      }
     }
    }
    $147 = (($i$08) + 1)|0;
    $148 = HEAP32[$13>>2]|0;
    $149 = HEAP32[$11>>2]|0;
    $150 = $148;
    $151 = $149;
    $152 = (($150) - ($151))|0;
    $153 = $152 >> 2;
    $154 = ($147>>>0)<($153>>>0);
    if ($154) {
     $57 = $149;$i$08 = $147;
    } else {
     break L15;
    }
   }
   if ((label|0) == 30) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 37) {
    $133 = ___cxa_find_matching_catch()|0;
    $134 = tempRet0;
    ___cxa_call_unexpected(($133|0));
    // unreachable;
   }
   else if ((label|0) == 38) {
    $135 = ___cxa_find_matching_catch()|0;
    $136 = tempRet0;
    __ZdlPv($95);
    $$0 = $136;$$01 = $135;
    ___resumeException($$01|0);
    // unreachable;
   }
   else if ((label|0) == 39) {
    $137 = ___cxa_find_matching_catch()|0;
    $138 = tempRet0;
    $139 = HEAP8[$5>>0]|0;
    $140 = $139 & 1;
    $141 = ($140<<24>>24)==(0);
    if ($141) {
     $$0 = $138;$$01 = $137;
     ___resumeException($$01|0);
     // unreachable;
    }
    $142 = HEAP32[$54>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($142|0),($$byval_copy4|0));
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if ($144) {
     $145 = ___cxa_find_matching_catch()|0;
     $146 = tempRet0;
     ___cxa_call_unexpected(($145|0));
     // unreachable;
    } else {
     $$0 = $138;$$01 = $137;
     ___resumeException($$01|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $155 = (($this) + 40|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = ($156|0)==(1);
 if ($157) {
  $158 = (($this) + 64|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = (($this) + 60|0);
  $161 = HEAP32[$160>>2]|0;
  $162 = ($161|0)==($159|0);
  if (!($162)) {
   $164 = $161;
   while(1) {
    $163 = HEAP32[$164>>2]|0;
    __ZN6Object11RemoveEventEPFvPvS0_iES0_($163,1991,$this);
    $165 = (($164) + 4|0);
    $166 = ($165|0)==($159|0);
    if ($166) {
     break;
    } else {
     $164 = $165;
    }
   }
   $$pre$i$i = HEAP32[$160>>2]|0;
   $$pre1$i$i = HEAP32[$158>>2]|0;
   $167 = ($$pre1$i$i|0)==($$pre$i$i|0);
   if (!($167)) {
    $__new_last2$i$i$i$i$i = $$pre$i$i;
    $scevgep$i$i$i$i$i = (($$pre1$i$i) + -4|0);
    $168 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($168)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $169 = $uglygep3$i$i$i$i$i >>> 2;
    $170 = $169 ^ -1;
    $scevgep4$i$i$i$i$i = (($$pre1$i$i) + ($170<<2)|0);
    HEAP32[$158>>2] = $scevgep4$i$i$i$i$i;
   }
  }
  $171 = (($this) + 24|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($172)|0);
  __ZN9Animation34RecomputeContainedRenderersRecurseER9Transform($this,$173);
  __ZN9Animation25CheckRendererVisibleStateEv($this);
 }
 $174 = (($this) + 232|0);
 $175 = HEAP32[$174>>2]|0;
 $176 = $175 | 1;
 HEAP32[$174>>2] = $176;
 $177 = HEAP32[$this>>2]|0;
 $178 = (($177) + 124|0);
 $179 = HEAP32[$178>>2]|0;
 FUNCTION_TABLE_vi[$179 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN9AnimationD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9AnimationD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN9AnimationD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3685,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIP14AnimationState13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 2;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,765224,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<2)|0);
 $24 = (($23) + ($$0$i3<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$__x>>2]|0;
  HEAP32[$22>>2] = $26;
 }
 $27 = (($23) + ($8<<2)|0);
 $28 = HEAP32[$this>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = $29;
 $31 = $28;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $$sum1 = (($7) - ($33))|0;
 $34 = (($23) + ($$sum1<<2)|0);
 _memcpy(($34|0),($28|0),($32|0))|0;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $34;
 HEAP32[$1>>2] = $27;
 HEAP32[$10>>2] = $24;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__sortIR12GreaterLayerPP14AnimationStateEEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i14 = 0, $$$$i$i$i$i22 = 0, $$$$i$i$i$i30 = 0, $$$$i$i$i$i38 = 0, $$$$i$i$i$i46 = 0, $$$$i$i$i$i54 = 0, $$$$i$i$i$i6 = 0, $$$$i$i$i$i62 = 0, $$$$i$i$i$i70 = 0, $$$i$i$i$i = 0, $$$i$i$i$i13 = 0, $$$i$i$i$i21 = 0, $$$i$i$i$i29 = 0, $$$i$i$i$i37 = 0, $$$i$i$i$i45 = 0, $$$i$i$i$i5 = 0, $$$i$i$i$i53 = 0, $$$i$i$i$i61 = 0, $$$i$i$i$i69 = 0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$077 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0;
 var $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $2 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $3 = $$0;
   $4 = (($0) - ($3))|0;
   $5 = $4 >> 2;
   switch ($5|0) {
   case 1: case 0:  {
    label = 204;
    break L1;
    break;
   }
   case 5:  {
    label = 24;
    break L1;
    break;
   }
   case 3:  {
    label = 22;
    break L1;
    break;
   }
   case 4:  {
    label = 23;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   default: {
   }
   }
   $53 = ($4|0)<(124);
   if ($53) {
    label = 26;
    break L1;
   }
   $54 = ($4|0)>(3996);
   $55 = (($5|0) / 2)&-1;
   $56 = (($$0) + ($55<<2)|0);
   if ($54) {
    $57 = (($5|0) / 4)&-1;
    $58 = (($$0) + ($57<<2)|0);
    $$sum = (($57) + ($55))|0;
    $59 = (($$0) + ($$sum<<2)|0);
    $60 = (__ZNSt3__17__sort5IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_S6_S6_T_($$0,$58,$56,$59,$1,0)|0);
    $__n_swaps$0 = $60;
   } else {
    $61 = (__ZNSt3__17__sort3IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_T_($$0,$56,$1,0)|0);
    $__n_swaps$0 = $61;
   }
   $62 = HEAP32[$$0>>2]|0;
   $63 = HEAP32[$56>>2]|0;
   $64 = (($62) + 32|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($63) + 32|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($65|0)==($67|0);
   if ($68) {
    $70 = (($62) + 112|0);
    $71 = (($63) + 112|0);
    $72 = HEAP8[$71>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    if ($74) {
     $77 = $72&255;
     $78 = $77 >>> 1;
     $94 = $78;
    } else {
     $75 = (($63) + 116|0);
     $76 = HEAP32[$75>>2]|0;
     $94 = $76;
    }
    $79 = HEAP8[$70>>0]|0;
    $80 = $79 & 1;
    $81 = ($80<<24>>24)==(0);
    if ($81) {
     $84 = $79&255;
     $85 = $84 >>> 1;
     $93 = $85;
    } else {
     $82 = (($62) + 116|0);
     $83 = HEAP32[$82>>2]|0;
     $93 = $83;
    }
    if ($74) {
     $88 = (($71) + 1|0);
     $96 = $88;
    } else {
     $86 = (($63) + 120|0);
     $87 = HEAP32[$86>>2]|0;
     $96 = $87;
    }
    if ($81) {
     $91 = (($70) + 1|0);
     $97 = $91;
    } else {
     $89 = (($62) + 120|0);
     $90 = HEAP32[$89>>2]|0;
     $97 = $90;
    }
    $92 = ($93>>>0)<($94>>>0);
    $95 = $92 ? $93 : $94;
    $98 = (_memcmp($96,$97,$95)|0);
    $99 = ($98|0)==(0);
    if ($99) {
     $100 = ($94>>>0)<($93>>>0);
     $$$i$i$i$i5 = $92&1;
     $$$$i$i$i$i6 = $100 ? -1 : $$$i$i$i$i5;
     $102 = $$$$i$i$i$i6;
    } else {
     $102 = $98;
    }
    $101 = ($102|0)<(0);
    if ($101) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     label = 47;
    }
   } else {
    $69 = ($65|0)>($67|0);
    if ($69) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     label = 47;
    }
   }
   L33: do {
    if ((label|0) == 47) {
     label = 0;
     $103 = ($$0|0)==($2|0);
     L35: do {
      if (!($103)) {
       $104 = (($63) + 112|0);
       $105 = (($104) + 1|0);
       $106 = (($63) + 120|0);
       $107 = (($63) + 116|0);
       $270 = $2;
       while(1) {
        $269 = HEAP32[$270>>2]|0;
        $271 = (($269) + 32|0);
        $272 = HEAP32[$271>>2]|0;
        $273 = ($272|0)==($67|0);
        if ($273) {
         $275 = (($269) + 112|0);
         $276 = HEAP8[$104>>0]|0;
         $277 = $276 & 1;
         $278 = ($277<<24>>24)==(0);
         if ($278) {
          $280 = $276&255;
          $281 = $280 >>> 1;
          $295 = $281;
         } else {
          $279 = HEAP32[$107>>2]|0;
          $295 = $279;
         }
         $282 = HEAP8[$275>>0]|0;
         $283 = $282 & 1;
         $284 = ($283<<24>>24)==(0);
         if ($284) {
          $287 = $282&255;
          $288 = $287 >>> 1;
          $294 = $288;
         } else {
          $285 = (($269) + 116|0);
          $286 = HEAP32[$285>>2]|0;
          $294 = $286;
         }
         if ($278) {
          $297 = $105;
         } else {
          $289 = HEAP32[$106>>2]|0;
          $297 = $289;
         }
         if ($284) {
          $292 = (($275) + 1|0);
          $298 = $292;
         } else {
          $290 = (($269) + 120|0);
          $291 = HEAP32[$290>>2]|0;
          $298 = $291;
         }
         $293 = ($294>>>0)<($295>>>0);
         $296 = $293 ? $294 : $295;
         $299 = (_memcmp($297,$298,$296)|0);
         $300 = ($299|0)==(0);
         if ($300) {
          $301 = ($295>>>0)<($294>>>0);
          $$$i$i$i$i45 = $293&1;
          $$$$i$i$i$i46 = $301 ? -1 : $$$i$i$i$i45;
          $303 = $$$$i$i$i$i46;
         } else {
          $303 = $299;
         }
         $302 = ($303|0)<(0);
         if ($302) {
          break;
         }
        } else {
         $274 = ($272|0)>($67|0);
         if ($274) {
          break;
         }
        }
        $304 = (($270) + -4|0);
        $305 = ($$0|0)==($304|0);
        if ($305) {
         break L35;
        } else {
         $270 = $304;
        }
       }
       HEAP32[$$0>>2] = $269;
       HEAP32[$270>>2] = $62;
       $306 = (($__n_swaps$0) + 1)|0;
       $__j$3 = $270;$__n_swaps$3 = $306;
       break L33;
      }
     } while(0);
     $108 = (($$0) + 4|0);
     $109 = HEAP32[$1>>2]|0;
     $110 = (($109) + 32|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ($65|0)==($111|0);
     if ($112) {
      $114 = (($62) + 112|0);
      $115 = (($109) + 112|0);
      $116 = HEAP8[$115>>0]|0;
      $117 = $116 & 1;
      $118 = ($117<<24>>24)==(0);
      if ($118) {
       $121 = $116&255;
       $122 = $121 >>> 1;
       $138 = $122;
      } else {
       $119 = (($109) + 116|0);
       $120 = HEAP32[$119>>2]|0;
       $138 = $120;
      }
      $123 = HEAP8[$114>>0]|0;
      $124 = $123 & 1;
      $125 = ($124<<24>>24)==(0);
      if ($125) {
       $128 = $123&255;
       $129 = $128 >>> 1;
       $137 = $129;
      } else {
       $126 = (($62) + 116|0);
       $127 = HEAP32[$126>>2]|0;
       $137 = $127;
      }
      if ($118) {
       $132 = (($115) + 1|0);
       $140 = $132;
      } else {
       $130 = (($109) + 120|0);
       $131 = HEAP32[$130>>2]|0;
       $140 = $131;
      }
      if ($125) {
       $135 = (($114) + 1|0);
       $141 = $135;
      } else {
       $133 = (($62) + 120|0);
       $134 = HEAP32[$133>>2]|0;
       $141 = $134;
      }
      $136 = ($137>>>0)<($138>>>0);
      $139 = $136 ? $137 : $138;
      $142 = (_memcmp($140,$141,$139)|0);
      $143 = ($142|0)==(0);
      if ($143) {
       $144 = ($138>>>0)<($137>>>0);
       $$$i$i$i$i13 = $136&1;
       $$$$i$i$i$i14 = $144 ? -1 : $$$i$i$i$i13;
       $146 = $$$$i$i$i$i14;
      } else {
       $146 = $142;
      }
      $145 = ($146|0)<(0);
      if ($145) {
       $__i$1 = $108;
      } else {
       label = 66;
      }
     } else {
      $113 = ($65|0)>($111|0);
      if ($113) {
       $__i$1 = $108;
      } else {
       label = 66;
      }
     }
     if ((label|0) == 66) {
      label = 0;
      $147 = ($108|0)==($1|0);
      if ($147) {
       label = 204;
       break L1;
      }
      $148 = (($62) + 112|0);
      $149 = (($148) + 1|0);
      $150 = (($62) + 120|0);
      $151 = (($62) + 116|0);
      $__i$077 = $108;
      while(1) {
       $152 = HEAP32[$__i$077>>2]|0;
       $153 = (($152) + 32|0);
       $154 = HEAP32[$153>>2]|0;
       $155 = ($65|0)==($154|0);
       if ($155) {
        $157 = (($152) + 112|0);
        $158 = HEAP8[$157>>0]|0;
        $159 = $158 & 1;
        $160 = ($159<<24>>24)==(0);
        if ($160) {
         $163 = $158&255;
         $164 = $163 >>> 1;
         $177 = $164;
        } else {
         $161 = (($152) + 116|0);
         $162 = HEAP32[$161>>2]|0;
         $177 = $162;
        }
        $165 = HEAP8[$148>>0]|0;
        $166 = $165 & 1;
        $167 = ($166<<24>>24)==(0);
        if ($167) {
         $169 = $165&255;
         $170 = $169 >>> 1;
         $176 = $170;
        } else {
         $168 = HEAP32[$151>>2]|0;
         $176 = $168;
        }
        if ($160) {
         $173 = (($157) + 1|0);
         $179 = $173;
        } else {
         $171 = (($152) + 120|0);
         $172 = HEAP32[$171>>2]|0;
         $179 = $172;
        }
        if ($167) {
         $180 = $149;
        } else {
         $174 = HEAP32[$150>>2]|0;
         $180 = $174;
        }
        $175 = ($176>>>0)<($177>>>0);
        $178 = $175 ? $176 : $177;
        $181 = (_memcmp($179,$180,$178)|0);
        $182 = ($181|0)==(0);
        if ($182) {
         $183 = ($177>>>0)<($176>>>0);
         $$$i$i$i$i21 = $175&1;
         $$$$i$i$i$i22 = $183 ? -1 : $$$i$i$i$i21;
         $185 = $$$$i$i$i$i22;
        } else {
         $185 = $181;
        }
        $184 = ($185|0)<(0);
        if ($184) {
         break;
        }
       } else {
        $156 = ($65|0)>($154|0);
        if ($156) {
         break;
        }
       }
       $187 = (($__i$077) + 4|0);
       $188 = ($187|0)==($1|0);
       if ($188) {
        label = 204;
        break L1;
       } else {
        $__i$077 = $187;
       }
      }
      HEAP32[$__i$077>>2] = $109;
      HEAP32[$1>>2] = $152;
      $186 = (($__i$077) + 4|0);
      $__i$1 = $186;
     }
     $189 = ($__i$1|0)==($1|0);
     if ($189) {
      label = 204;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $190 = HEAP32[$$0>>2]|0;
      $191 = (($190) + 32|0);
      $192 = HEAP32[$191>>2]|0;
      $193 = (($190) + 112|0);
      $194 = (($193) + 1|0);
      $195 = (($190) + 120|0);
      $196 = (($190) + 116|0);
      $__i$2 = $__i$2$ph;
      while(1) {
       $197 = HEAP32[$__i$2>>2]|0;
       $198 = (($197) + 32|0);
       $199 = HEAP32[$198>>2]|0;
       $200 = ($192|0)==($199|0);
       if ($200) {
        $202 = (($197) + 112|0);
        $203 = HEAP8[$202>>0]|0;
        $204 = $203 & 1;
        $205 = ($204<<24>>24)==(0);
        if ($205) {
         $208 = $203&255;
         $209 = $208 >>> 1;
         $222 = $209;
        } else {
         $206 = (($197) + 116|0);
         $207 = HEAP32[$206>>2]|0;
         $222 = $207;
        }
        $210 = HEAP8[$193>>0]|0;
        $211 = $210 & 1;
        $212 = ($211<<24>>24)==(0);
        if ($212) {
         $214 = $210&255;
         $215 = $214 >>> 1;
         $221 = $215;
        } else {
         $213 = HEAP32[$196>>2]|0;
         $221 = $213;
        }
        if ($205) {
         $218 = (($202) + 1|0);
         $224 = $218;
        } else {
         $216 = (($197) + 120|0);
         $217 = HEAP32[$216>>2]|0;
         $224 = $217;
        }
        if ($212) {
         $225 = $194;
        } else {
         $219 = HEAP32[$195>>2]|0;
         $225 = $219;
        }
        $220 = ($221>>>0)<($222>>>0);
        $223 = $220 ? $221 : $222;
        $226 = (_memcmp($224,$225,$223)|0);
        $227 = ($226|0)==(0);
        if ($227) {
         $228 = ($222>>>0)<($221>>>0);
         $$$i$i$i$i29 = $220&1;
         $$$$i$i$i$i30 = $228 ? -1 : $$$i$i$i$i29;
         $230 = $$$$i$i$i$i30;
        } else {
         $230 = $226;
        }
        $229 = ($230|0)<(0);
        if ($229) {
         $__j$2 = $__j$1$ph;
         break;
        }
       } else {
        $201 = ($192|0)>($199|0);
        if ($201) {
         $__j$2 = $__j$1$ph;
         break;
        }
       }
       $231 = (($__i$2) + 4|0);
       $__i$2 = $231;
      }
      while(1) {
       $232 = (($__j$2) + -4|0);
       $233 = HEAP32[$232>>2]|0;
       $234 = (($233) + 32|0);
       $235 = HEAP32[$234>>2]|0;
       $236 = ($192|0)==($235|0);
       if (!($236)) {
        $237 = ($192|0)>($235|0);
        if ($237) {
         $__j$2 = $232;
         continue;
        } else {
         break;
        }
       }
       $238 = (($233) + 112|0);
       $239 = HEAP8[$238>>0]|0;
       $240 = $239 & 1;
       $241 = ($240<<24>>24)==(0);
       if ($241) {
        $244 = $239&255;
        $245 = $244 >>> 1;
        $258 = $245;
       } else {
        $242 = (($233) + 116|0);
        $243 = HEAP32[$242>>2]|0;
        $258 = $243;
       }
       $246 = HEAP8[$193>>0]|0;
       $247 = $246 & 1;
       $248 = ($247<<24>>24)==(0);
       if ($248) {
        $250 = $246&255;
        $251 = $250 >>> 1;
        $257 = $251;
       } else {
        $249 = HEAP32[$196>>2]|0;
        $257 = $249;
       }
       if ($241) {
        $254 = (($238) + 1|0);
        $260 = $254;
       } else {
        $252 = (($233) + 120|0);
        $253 = HEAP32[$252>>2]|0;
        $260 = $253;
       }
       if ($248) {
        $261 = $194;
       } else {
        $255 = HEAP32[$195>>2]|0;
        $261 = $255;
       }
       $256 = ($257>>>0)<($258>>>0);
       $259 = $256 ? $257 : $258;
       $262 = (_memcmp($260,$261,$259)|0);
       $263 = ($262|0)==(0);
       if ($263) {
        $264 = ($258>>>0)<($257>>>0);
        $$$i$i$i$i37 = $256&1;
        $$$$i$i$i$i38 = $264 ? -1 : $$$i$i$i$i37;
        $266 = $$$$i$i$i$i38;
       } else {
        $266 = $262;
       }
       $265 = ($266|0)<(0);
       if ($265) {
        $__j$2 = $232;
       } else {
        break;
       }
      }
      $267 = ($__i$2>>>0)<($232>>>0);
      if (!($267)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__i$2>>2] = $233;
      HEAP32[$232>>2] = $197;
      $268 = (($__i$2) + 4|0);
      $__i$2$ph = $268;$__j$1$ph = $232;
     }
    }
   } while(0);
   $307 = (($$0) + 4|0);
   $308 = ($307>>>0)<($__j$3>>>0);
   L166: do {
    if ($308) {
     $__i$3$ph = $307;$__j$4$ph = $__j$3;$__m$0$ph = $56;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $309 = HEAP32[$__m$0$ph>>2]|0;
      $310 = (($309) + 32|0);
      $311 = HEAP32[$310>>2]|0;
      $312 = (($309) + 112|0);
      $313 = (($312) + 1|0);
      $314 = (($309) + 120|0);
      $315 = (($309) + 116|0);
      $__i$3 = $__i$3$ph;
      while(1) {
       $316 = HEAP32[$__i$3>>2]|0;
       $317 = (($316) + 32|0);
       $318 = HEAP32[$317>>2]|0;
       $319 = ($318|0)==($311|0);
       if ($319) {
        $321 = (($316) + 112|0);
        $322 = HEAP8[$312>>0]|0;
        $323 = $322 & 1;
        $324 = ($323<<24>>24)==(0);
        if ($324) {
         $326 = $322&255;
         $327 = $326 >>> 1;
         $341 = $327;
        } else {
         $325 = HEAP32[$315>>2]|0;
         $341 = $325;
        }
        $328 = HEAP8[$321>>0]|0;
        $329 = $328 & 1;
        $330 = ($329<<24>>24)==(0);
        if ($330) {
         $333 = $328&255;
         $334 = $333 >>> 1;
         $340 = $334;
        } else {
         $331 = (($316) + 116|0);
         $332 = HEAP32[$331>>2]|0;
         $340 = $332;
        }
        if ($324) {
         $343 = $313;
        } else {
         $335 = HEAP32[$314>>2]|0;
         $343 = $335;
        }
        if ($330) {
         $338 = (($321) + 1|0);
         $344 = $338;
        } else {
         $336 = (($316) + 120|0);
         $337 = HEAP32[$336>>2]|0;
         $344 = $337;
        }
        $339 = ($340>>>0)<($341>>>0);
        $342 = $339 ? $340 : $341;
        $345 = (_memcmp($343,$344,$342)|0);
        $346 = ($345|0)==(0);
        if ($346) {
         $347 = ($341>>>0)<($340>>>0);
         $$$i$i$i$i53 = $339&1;
         $$$$i$i$i$i54 = $347 ? -1 : $$$i$i$i$i53;
         $349 = $$$$i$i$i$i54;
        } else {
         $349 = $345;
        }
        $348 = ($349|0)<(0);
        if (!($348)) {
         $__j$5 = $__j$4$ph;
         break;
        }
       } else {
        $320 = ($318|0)>($311|0);
        if (!($320)) {
         $__j$5 = $__j$4$ph;
         break;
        }
       }
       $350 = (($__i$3) + 4|0);
       $__i$3 = $350;
      }
      while(1) {
       $351 = (($__j$5) + -4|0);
       $352 = HEAP32[$351>>2]|0;
       $353 = (($352) + 32|0);
       $354 = HEAP32[$353>>2]|0;
       $355 = ($354|0)==($311|0);
       if (!($355)) {
        $356 = ($354|0)>($311|0);
        if ($356) {
         break;
        } else {
         $__j$5 = $351;
         continue;
        }
       }
       $357 = (($352) + 112|0);
       $358 = HEAP8[$312>>0]|0;
       $359 = $358 & 1;
       $360 = ($359<<24>>24)==(0);
       if ($360) {
        $362 = $358&255;
        $363 = $362 >>> 1;
        $377 = $363;
       } else {
        $361 = HEAP32[$315>>2]|0;
        $377 = $361;
       }
       $364 = HEAP8[$357>>0]|0;
       $365 = $364 & 1;
       $366 = ($365<<24>>24)==(0);
       if ($366) {
        $369 = $364&255;
        $370 = $369 >>> 1;
        $376 = $370;
       } else {
        $367 = (($352) + 116|0);
        $368 = HEAP32[$367>>2]|0;
        $376 = $368;
       }
       if ($360) {
        $379 = $313;
       } else {
        $371 = HEAP32[$314>>2]|0;
        $379 = $371;
       }
       if ($366) {
        $374 = (($357) + 1|0);
        $380 = $374;
       } else {
        $372 = (($352) + 120|0);
        $373 = HEAP32[$372>>2]|0;
        $380 = $373;
       }
       $375 = ($376>>>0)<($377>>>0);
       $378 = $375 ? $376 : $377;
       $381 = (_memcmp($379,$380,$378)|0);
       $382 = ($381|0)==(0);
       if ($382) {
        $383 = ($377>>>0)<($376>>>0);
        $$$i$i$i$i61 = $375&1;
        $$$$i$i$i$i62 = $383 ? -1 : $$$i$i$i$i61;
        $385 = $$$$i$i$i$i62;
       } else {
        $385 = $381;
       }
       $384 = ($385|0)<(0);
       if ($384) {
        break;
       } else {
        $__j$5 = $351;
       }
      }
      $386 = ($__i$3>>>0)>($351>>>0);
      if ($386) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L166;
      }
      HEAP32[$__i$3>>2] = $352;
      HEAP32[$351>>2] = $316;
      $387 = (($__n_swaps$4$ph) + 1)|0;
      $388 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $388 ? $351 : $__m$0$ph;
      $389 = (($__i$3) + 4|0);
      $__i$3$ph = $389;$__j$4$ph = $351;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $387;
     }
    } else {
     $__i$4 = $307;$__m$2 = $56;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $390 = ($__i$4|0)==($__m$2|0);
   do {
    if ($390) {
     $__n_swaps$6 = $__n_swaps$5;
    } else {
     $391 = HEAP32[$__m$2>>2]|0;
     $392 = HEAP32[$__i$4>>2]|0;
     $393 = (($391) + 32|0);
     $394 = HEAP32[$393>>2]|0;
     $395 = (($392) + 32|0);
     $396 = HEAP32[$395>>2]|0;
     $397 = ($394|0)==($396|0);
     if ($397) {
      $399 = (($391) + 112|0);
      $400 = (($392) + 112|0);
      $401 = HEAP8[$400>>0]|0;
      $402 = $401 & 1;
      $403 = ($402<<24>>24)==(0);
      if ($403) {
       $406 = $401&255;
       $407 = $406 >>> 1;
       $423 = $407;
      } else {
       $404 = (($392) + 116|0);
       $405 = HEAP32[$404>>2]|0;
       $423 = $405;
      }
      $408 = HEAP8[$399>>0]|0;
      $409 = $408 & 1;
      $410 = ($409<<24>>24)==(0);
      if ($410) {
       $413 = $408&255;
       $414 = $413 >>> 1;
       $422 = $414;
      } else {
       $411 = (($391) + 116|0);
       $412 = HEAP32[$411>>2]|0;
       $422 = $412;
      }
      if ($403) {
       $417 = (($400) + 1|0);
       $425 = $417;
      } else {
       $415 = (($392) + 120|0);
       $416 = HEAP32[$415>>2]|0;
       $425 = $416;
      }
      if ($410) {
       $420 = (($399) + 1|0);
       $426 = $420;
      } else {
       $418 = (($391) + 120|0);
       $419 = HEAP32[$418>>2]|0;
       $426 = $419;
      }
      $421 = ($422>>>0)<($423>>>0);
      $424 = $421 ? $422 : $423;
      $427 = (_memcmp($425,$426,$424)|0);
      $428 = ($427|0)==(0);
      if ($428) {
       $429 = ($423>>>0)<($422>>>0);
       $$$i$i$i$i69 = $421&1;
       $$$$i$i$i$i70 = $429 ? -1 : $$$i$i$i$i69;
       $431 = $$$$i$i$i$i70;
      } else {
       $431 = $427;
      }
      $430 = ($431|0)<(0);
      if (!($430)) {
       $__n_swaps$6 = $__n_swaps$5;
       break;
      }
     } else {
      $398 = ($394|0)>($396|0);
      if (!($398)) {
       $__n_swaps$6 = $__n_swaps$5;
       break;
      }
     }
     HEAP32[$__i$4>>2] = $391;
     HEAP32[$__m$2>>2] = $392;
     $432 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $432;
    }
   } while(0);
   $433 = ($__n_swaps$6|0)==(0);
   if ($433) {
    $434 = (__ZNSt3__127__insertion_sort_incompleteIR12GreaterLayerPP14AnimationStateEEbT0_S6_T_($$0,$__i$4,0)|0);
    $435 = (($__i$4) + 4|0);
    $436 = (__ZNSt3__127__insertion_sort_incompleteIR12GreaterLayerPP14AnimationStateEEbT0_S6_T_($435,$$01$ph,0)|0);
    if ($436) {
     label = 199;
     break;
    }
    if ($434) {
     $$0 = $435;
     continue;
    }
   }
   $437 = $__i$4;
   $438 = (($437) - ($3))|0;
   $439 = (($0) - ($437))|0;
   $440 = ($438|0)<($439|0);
   if (!($440)) {
    label = 203;
    break;
   }
   __ZNSt3__16__sortIR12GreaterLayerPP14AnimationStateEEvT0_S6_T_($$0,$__i$4,$__comp);
   $441 = (($__i$4) + 4|0);
   $$0 = $441;
  }
  if ((label|0) == 199) {
   label = 0;
   if ($434) {
    label = 204;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 203) {
   label = 0;
   $442 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIR12GreaterLayerPP14AnimationStateEEvT0_S6_T_($442,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $6 = HEAP32[$1>>2]|0;
  $7 = HEAP32[$$0>>2]|0;
  $8 = (($6) + 32|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 32|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  if ($12) {
   $14 = (($6) + 112|0);
   $15 = (($7) + 112|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if ($18) {
    $21 = $16&255;
    $22 = $21 >>> 1;
    $38 = $22;
   } else {
    $19 = (($7) + 116|0);
    $20 = HEAP32[$19>>2]|0;
    $38 = $20;
   }
   $23 = HEAP8[$14>>0]|0;
   $24 = $23 & 1;
   $25 = ($24<<24>>24)==(0);
   if ($25) {
    $28 = $23&255;
    $29 = $28 >>> 1;
    $37 = $29;
   } else {
    $26 = (($6) + 116|0);
    $27 = HEAP32[$26>>2]|0;
    $37 = $27;
   }
   if ($18) {
    $32 = (($15) + 1|0);
    $40 = $32;
   } else {
    $30 = (($7) + 120|0);
    $31 = HEAP32[$30>>2]|0;
    $40 = $31;
   }
   if ($25) {
    $35 = (($14) + 1|0);
    $41 = $35;
   } else {
    $33 = (($6) + 120|0);
    $34 = HEAP32[$33>>2]|0;
    $41 = $34;
   }
   $36 = ($37>>>0)<($38>>>0);
   $39 = $36 ? $37 : $38;
   $42 = (_memcmp($40,$41,$39)|0);
   $43 = ($42|0)==(0);
   if ($43) {
    $44 = ($38>>>0)<($37>>>0);
    $$$i$i$i$i = $36&1;
    $$$$i$i$i$i = $44 ? -1 : $$$i$i$i$i;
    $46 = $$$$i$i$i$i;
   } else {
    $46 = $42;
   }
   $45 = ($46|0)<(0);
   if (!($45)) {
    STACKTOP = sp;return;
   }
  } else {
   $13 = ($9|0)>($11|0);
   if (!($13)) {
    STACKTOP = sp;return;
   }
  }
  HEAP32[$$0>>2] = $6;
  HEAP32[$1>>2] = $7;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 22) {
  $47 = (($$0) + 4|0);
  (__ZNSt3__17__sort3IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_T_($$0,$47,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 23) {
  $48 = (($$0) + 4|0);
  $49 = (($$0) + 8|0);
  (__ZNSt3__17__sort4IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_S6_T_($$0,$48,$49,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 24) {
  $50 = (($$0) + 4|0);
  $51 = (($$0) + 8|0);
  $52 = (($$0) + 12|0);
  (__ZNSt3__17__sort5IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_S6_S6_T_($$0,$50,$51,$52,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 26) {
  __ZNSt3__118__insertion_sort_3IR12GreaterLayerPP14AnimationStateEEvT0_S6_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 204) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i13 = 0, $$$$i$i$i$i21 = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i12 = 0, $$$i$i$i$i20 = 0, $$$i$i$i$i4 = 0, $$0 = 0, $$0$i = 0, $$0$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__y>>2]|0;
 $1 = HEAP32[$__x>>2]|0;
 $2 = (($0) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  $8 = (($0) + 112|0);
  $9 = (($1) + 112|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10 & 1;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $15 = $10&255;
   $16 = $15 >>> 1;
   $32 = $16;
  } else {
   $13 = (($1) + 116|0);
   $14 = HEAP32[$13>>2]|0;
   $32 = $14;
  }
  $17 = HEAP8[$8>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $22 = $17&255;
   $23 = $22 >>> 1;
   $31 = $23;
  } else {
   $20 = (($0) + 116|0);
   $21 = HEAP32[$20>>2]|0;
   $31 = $21;
  }
  if ($12) {
   $26 = (($9) + 1|0);
   $34 = $26;
  } else {
   $24 = (($1) + 120|0);
   $25 = HEAP32[$24>>2]|0;
   $34 = $25;
  }
  if ($19) {
   $29 = (($8) + 1|0);
   $35 = $29;
  } else {
   $27 = (($0) + 120|0);
   $28 = HEAP32[$27>>2]|0;
   $35 = $28;
  }
  $30 = ($31>>>0)<($32>>>0);
  $33 = $30 ? $31 : $32;
  $36 = (_memcmp($34,$35,$33)|0);
  $37 = ($36|0)==(0);
  if ($37) {
   $38 = ($32>>>0)<($31>>>0);
   $$$i$i$i$i = $30&1;
   $$$$i$i$i$i = $38 ? -1 : $$$i$i$i$i;
   $40 = $$$$i$i$i$i;
  } else {
   $40 = $36;
  }
  $39 = ($40|0)<(0);
  $$0$i = $39;
 } else {
  $7 = ($3|0)>($5|0);
  $$0$i = $7;
 }
 $41 = HEAP32[$__z>>2]|0;
 $42 = (($41) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==($3|0);
 if ($44) {
  $46 = (($41) + 112|0);
  $47 = (($0) + 112|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = $48 & 1;
  $50 = ($49<<24>>24)==(0);
  if ($50) {
   $53 = $48&255;
   $54 = $53 >>> 1;
   $70 = $54;
  } else {
   $51 = (($0) + 116|0);
   $52 = HEAP32[$51>>2]|0;
   $70 = $52;
  }
  $55 = HEAP8[$46>>0]|0;
  $56 = $55 & 1;
  $57 = ($56<<24>>24)==(0);
  if ($57) {
   $60 = $55&255;
   $61 = $60 >>> 1;
   $69 = $61;
  } else {
   $58 = (($41) + 116|0);
   $59 = HEAP32[$58>>2]|0;
   $69 = $59;
  }
  if ($50) {
   $64 = (($47) + 1|0);
   $72 = $64;
  } else {
   $62 = (($0) + 120|0);
   $63 = HEAP32[$62>>2]|0;
   $72 = $63;
  }
  if ($57) {
   $67 = (($46) + 1|0);
   $73 = $67;
  } else {
   $65 = (($41) + 120|0);
   $66 = HEAP32[$65>>2]|0;
   $73 = $66;
  }
  $68 = ($69>>>0)<($70>>>0);
  $71 = $68 ? $69 : $70;
  $74 = (_memcmp($72,$73,$71)|0);
  $75 = ($74|0)==(0);
  if ($75) {
   $76 = ($70>>>0)<($69>>>0);
   $$$i$i$i$i4 = $68&1;
   $$$$i$i$i$i5 = $76 ? -1 : $$$i$i$i$i4;
   $78 = $$$$i$i$i$i5;
  } else {
   $78 = $74;
  }
  $77 = ($78|0)<(0);
  $$0$i7 = $77;
 } else {
  $45 = ($43|0)>($3|0);
  $$0$i7 = $45;
 }
 if (!($$0$i)) {
  if (!($$0$i7)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__y>>2] = $41;
  HEAP32[$__z>>2] = $0;
  $79 = HEAP32[$__y>>2]|0;
  $80 = HEAP32[$__x>>2]|0;
  $81 = (($79) + 32|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($80) + 32|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ($82|0)==($84|0);
  if ($85) {
   $87 = (($79) + 112|0);
   $88 = (($80) + 112|0);
   $89 = HEAP8[$88>>0]|0;
   $90 = $89 & 1;
   $91 = ($90<<24>>24)==(0);
   if ($91) {
    $94 = $89&255;
    $95 = $94 >>> 1;
    $111 = $95;
   } else {
    $92 = (($80) + 116|0);
    $93 = HEAP32[$92>>2]|0;
    $111 = $93;
   }
   $96 = HEAP8[$87>>0]|0;
   $97 = $96 & 1;
   $98 = ($97<<24>>24)==(0);
   if ($98) {
    $101 = $96&255;
    $102 = $101 >>> 1;
    $110 = $102;
   } else {
    $99 = (($79) + 116|0);
    $100 = HEAP32[$99>>2]|0;
    $110 = $100;
   }
   if ($91) {
    $105 = (($88) + 1|0);
    $113 = $105;
   } else {
    $103 = (($80) + 120|0);
    $104 = HEAP32[$103>>2]|0;
    $113 = $104;
   }
   if ($98) {
    $108 = (($87) + 1|0);
    $114 = $108;
   } else {
    $106 = (($79) + 120|0);
    $107 = HEAP32[$106>>2]|0;
    $114 = $107;
   }
   $109 = ($110>>>0)<($111>>>0);
   $112 = $109 ? $110 : $111;
   $115 = (_memcmp($113,$114,$112)|0);
   $116 = ($115|0)==(0);
   if ($116) {
    $117 = ($111>>>0)<($110>>>0);
    $$$i$i$i$i20 = $109&1;
    $$$$i$i$i$i21 = $117 ? -1 : $$$i$i$i$i20;
    $119 = $$$$i$i$i$i21;
   } else {
    $119 = $115;
   }
   $118 = ($119|0)<(0);
   if (!($118)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $86 = ($82|0)>($84|0);
   if (!($86)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  HEAP32[$__x>>2] = $79;
  HEAP32[$__y>>2] = $80;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($$0$i7) {
  HEAP32[$__x>>2] = $41;
  HEAP32[$__z>>2] = $1;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$__x>>2] = $0;
 HEAP32[$__y>>2] = $1;
 $120 = HEAP32[$__z>>2]|0;
 $121 = (($120) + 32|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($122|0)==($5|0);
 if ($123) {
  $125 = (($120) + 112|0);
  $126 = (($1) + 112|0);
  $127 = HEAP8[$126>>0]|0;
  $128 = $127 & 1;
  $129 = ($128<<24>>24)==(0);
  if ($129) {
   $132 = $127&255;
   $133 = $132 >>> 1;
   $149 = $133;
  } else {
   $130 = (($1) + 116|0);
   $131 = HEAP32[$130>>2]|0;
   $149 = $131;
  }
  $134 = HEAP8[$125>>0]|0;
  $135 = $134 & 1;
  $136 = ($135<<24>>24)==(0);
  if ($136) {
   $139 = $134&255;
   $140 = $139 >>> 1;
   $148 = $140;
  } else {
   $137 = (($120) + 116|0);
   $138 = HEAP32[$137>>2]|0;
   $148 = $138;
  }
  if ($129) {
   $143 = (($126) + 1|0);
   $151 = $143;
  } else {
   $141 = (($1) + 120|0);
   $142 = HEAP32[$141>>2]|0;
   $151 = $142;
  }
  if ($136) {
   $146 = (($125) + 1|0);
   $152 = $146;
  } else {
   $144 = (($120) + 120|0);
   $145 = HEAP32[$144>>2]|0;
   $152 = $145;
  }
  $147 = ($148>>>0)<($149>>>0);
  $150 = $147 ? $148 : $149;
  $153 = (_memcmp($151,$152,$150)|0);
  $154 = ($153|0)==(0);
  if ($154) {
   $155 = ($149>>>0)<($148>>>0);
   $$$i$i$i$i12 = $147&1;
   $$$$i$i$i$i13 = $155 ? -1 : $$$i$i$i$i12;
   $157 = $$$$i$i$i$i13;
  } else {
   $157 = $153;
  }
  $156 = ($157|0)<(0);
  if (!($156)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $124 = ($122|0)>($5|0);
  if (!($124)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$__y>>2] = $120;
 HEAP32[$__z>>2] = $1;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i13 = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i12 = 0, $$$i$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_T_($__x1,$__x2,$__x3,0)|0);
 $1 = HEAP32[$__x4>>2]|0;
 $2 = HEAP32[$__x3>>2]|0;
 $3 = (($1) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $9 = (($1) + 112|0);
  $10 = (($2) + 112|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $16 = $11&255;
   $17 = $16 >>> 1;
   $33 = $17;
  } else {
   $14 = (($2) + 116|0);
   $15 = HEAP32[$14>>2]|0;
   $33 = $15;
  }
  $18 = HEAP8[$9>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   $23 = $18&255;
   $24 = $23 >>> 1;
   $32 = $24;
  } else {
   $21 = (($1) + 116|0);
   $22 = HEAP32[$21>>2]|0;
   $32 = $22;
  }
  if ($13) {
   $27 = (($10) + 1|0);
   $35 = $27;
  } else {
   $25 = (($2) + 120|0);
   $26 = HEAP32[$25>>2]|0;
   $35 = $26;
  }
  if ($20) {
   $30 = (($9) + 1|0);
   $36 = $30;
  } else {
   $28 = (($1) + 120|0);
   $29 = HEAP32[$28>>2]|0;
   $36 = $29;
  }
  $31 = ($32>>>0)<($33>>>0);
  $34 = $31 ? $32 : $33;
  $37 = (_memcmp($35,$36,$34)|0);
  $38 = ($37|0)==(0);
  if ($38) {
   $39 = ($33>>>0)<($32>>>0);
   $$$i$i$i$i = $31&1;
   $$$$i$i$i$i = $39 ? -1 : $$$i$i$i$i;
   $41 = $$$$i$i$i$i;
  } else {
   $41 = $37;
  }
  $40 = ($41|0)<(0);
  if (!($40)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $8 = ($4|0)>($6|0);
  if (!($8)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 HEAP32[$__x3>>2] = $1;
 HEAP32[$__x4>>2] = $2;
 $42 = (($0) + 1)|0;
 $43 = HEAP32[$__x3>>2]|0;
 $44 = HEAP32[$__x2>>2]|0;
 $45 = (($43) + 32|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($44) + 32|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($46|0)==($48|0);
 if ($49) {
  $51 = (($43) + 112|0);
  $52 = (($44) + 112|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53 & 1;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   $58 = $53&255;
   $59 = $58 >>> 1;
   $75 = $59;
  } else {
   $56 = (($44) + 116|0);
   $57 = HEAP32[$56>>2]|0;
   $75 = $57;
  }
  $60 = HEAP8[$51>>0]|0;
  $61 = $60 & 1;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $65 = $60&255;
   $66 = $65 >>> 1;
   $74 = $66;
  } else {
   $63 = (($43) + 116|0);
   $64 = HEAP32[$63>>2]|0;
   $74 = $64;
  }
  if ($55) {
   $69 = (($52) + 1|0);
   $77 = $69;
  } else {
   $67 = (($44) + 120|0);
   $68 = HEAP32[$67>>2]|0;
   $77 = $68;
  }
  if ($62) {
   $72 = (($51) + 1|0);
   $78 = $72;
  } else {
   $70 = (($43) + 120|0);
   $71 = HEAP32[$70>>2]|0;
   $78 = $71;
  }
  $73 = ($74>>>0)<($75>>>0);
  $76 = $73 ? $74 : $75;
  $79 = (_memcmp($77,$78,$76)|0);
  $80 = ($79|0)==(0);
  if ($80) {
   $81 = ($75>>>0)<($74>>>0);
   $$$i$i$i$i12 = $73&1;
   $$$$i$i$i$i13 = $81 ? -1 : $$$i$i$i$i12;
   $83 = $$$$i$i$i$i13;
  } else {
   $83 = $79;
  }
  $82 = ($83|0)<(0);
  if (!($82)) {
   $__r$0 = $42;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $50 = ($46|0)>($48|0);
  if (!($50)) {
   $__r$0 = $42;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 HEAP32[$__x2>>2] = $43;
 HEAP32[$__x3>>2] = $44;
 $84 = (($0) + 2)|0;
 $85 = HEAP32[$__x2>>2]|0;
 $86 = HEAP32[$__x1>>2]|0;
 $87 = (($85) + 32|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($86) + 32|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($88|0)==($90|0);
 if ($91) {
  $93 = (($85) + 112|0);
  $94 = (($86) + 112|0);
  $95 = HEAP8[$94>>0]|0;
  $96 = $95 & 1;
  $97 = ($96<<24>>24)==(0);
  if ($97) {
   $100 = $95&255;
   $101 = $100 >>> 1;
   $117 = $101;
  } else {
   $98 = (($86) + 116|0);
   $99 = HEAP32[$98>>2]|0;
   $117 = $99;
  }
  $102 = HEAP8[$93>>0]|0;
  $103 = $102 & 1;
  $104 = ($103<<24>>24)==(0);
  if ($104) {
   $107 = $102&255;
   $108 = $107 >>> 1;
   $116 = $108;
  } else {
   $105 = (($85) + 116|0);
   $106 = HEAP32[$105>>2]|0;
   $116 = $106;
  }
  if ($97) {
   $111 = (($94) + 1|0);
   $119 = $111;
  } else {
   $109 = (($86) + 120|0);
   $110 = HEAP32[$109>>2]|0;
   $119 = $110;
  }
  if ($104) {
   $114 = (($93) + 1|0);
   $120 = $114;
  } else {
   $112 = (($85) + 120|0);
   $113 = HEAP32[$112>>2]|0;
   $120 = $113;
  }
  $115 = ($116>>>0)<($117>>>0);
  $118 = $115 ? $116 : $117;
  $121 = (_memcmp($119,$120,$118)|0);
  $122 = ($121|0)==(0);
  if ($122) {
   $123 = ($117>>>0)<($116>>>0);
   $$$i$i$i$i4 = $115&1;
   $$$$i$i$i$i5 = $123 ? -1 : $$$i$i$i$i4;
   $125 = $$$$i$i$i$i5;
  } else {
   $125 = $121;
  }
  $124 = ($125|0)<(0);
  if (!($124)) {
   $__r$0 = $84;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $92 = ($88|0)>($90|0);
  if (!($92)) {
   $__r$0 = $84;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 HEAP32[$__x1>>2] = $85;
 HEAP32[$__x2>>2] = $86;
 $126 = (($0) + 3)|0;
 $__r$0 = $126;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i13 = 0, $$$$i$i$i$i21 = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i12 = 0, $$$i$i$i$i20 = 0, $$$i$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_S6_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = HEAP32[$__x5>>2]|0;
 $2 = HEAP32[$__x4>>2]|0;
 $3 = (($1) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $9 = (($1) + 112|0);
  $10 = (($2) + 112|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $16 = $11&255;
   $17 = $16 >>> 1;
   $33 = $17;
  } else {
   $14 = (($2) + 116|0);
   $15 = HEAP32[$14>>2]|0;
   $33 = $15;
  }
  $18 = HEAP8[$9>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   $23 = $18&255;
   $24 = $23 >>> 1;
   $32 = $24;
  } else {
   $21 = (($1) + 116|0);
   $22 = HEAP32[$21>>2]|0;
   $32 = $22;
  }
  if ($13) {
   $27 = (($10) + 1|0);
   $35 = $27;
  } else {
   $25 = (($2) + 120|0);
   $26 = HEAP32[$25>>2]|0;
   $35 = $26;
  }
  if ($20) {
   $30 = (($9) + 1|0);
   $36 = $30;
  } else {
   $28 = (($1) + 120|0);
   $29 = HEAP32[$28>>2]|0;
   $36 = $29;
  }
  $31 = ($32>>>0)<($33>>>0);
  $34 = $31 ? $32 : $33;
  $37 = (_memcmp($35,$36,$34)|0);
  $38 = ($37|0)==(0);
  if ($38) {
   $39 = ($33>>>0)<($32>>>0);
   $$$i$i$i$i = $31&1;
   $$$$i$i$i$i = $39 ? -1 : $$$i$i$i$i;
   $41 = $$$$i$i$i$i;
  } else {
   $41 = $37;
  }
  $40 = ($41|0)<(0);
  if (!($40)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $8 = ($4|0)>($6|0);
  if (!($8)) {
   $__r$0 = $0;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 HEAP32[$__x4>>2] = $1;
 HEAP32[$__x5>>2] = $2;
 $42 = (($0) + 1)|0;
 $43 = HEAP32[$__x4>>2]|0;
 $44 = HEAP32[$__x3>>2]|0;
 $45 = (($43) + 32|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($44) + 32|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($46|0)==($48|0);
 if ($49) {
  $51 = (($43) + 112|0);
  $52 = (($44) + 112|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53 & 1;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   $58 = $53&255;
   $59 = $58 >>> 1;
   $75 = $59;
  } else {
   $56 = (($44) + 116|0);
   $57 = HEAP32[$56>>2]|0;
   $75 = $57;
  }
  $60 = HEAP8[$51>>0]|0;
  $61 = $60 & 1;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   $65 = $60&255;
   $66 = $65 >>> 1;
   $74 = $66;
  } else {
   $63 = (($43) + 116|0);
   $64 = HEAP32[$63>>2]|0;
   $74 = $64;
  }
  if ($55) {
   $69 = (($52) + 1|0);
   $77 = $69;
  } else {
   $67 = (($44) + 120|0);
   $68 = HEAP32[$67>>2]|0;
   $77 = $68;
  }
  if ($62) {
   $72 = (($51) + 1|0);
   $78 = $72;
  } else {
   $70 = (($43) + 120|0);
   $71 = HEAP32[$70>>2]|0;
   $78 = $71;
  }
  $73 = ($74>>>0)<($75>>>0);
  $76 = $73 ? $74 : $75;
  $79 = (_memcmp($77,$78,$76)|0);
  $80 = ($79|0)==(0);
  if ($80) {
   $81 = ($75>>>0)<($74>>>0);
   $$$i$i$i$i12 = $73&1;
   $$$$i$i$i$i13 = $81 ? -1 : $$$i$i$i$i12;
   $83 = $$$$i$i$i$i13;
  } else {
   $83 = $79;
  }
  $82 = ($83|0)<(0);
  if (!($82)) {
   $__r$0 = $42;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $50 = ($46|0)>($48|0);
  if (!($50)) {
   $__r$0 = $42;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 HEAP32[$__x3>>2] = $43;
 HEAP32[$__x4>>2] = $44;
 $84 = (($0) + 2)|0;
 $85 = HEAP32[$__x3>>2]|0;
 $86 = HEAP32[$__x2>>2]|0;
 $87 = (($85) + 32|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($86) + 32|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($88|0)==($90|0);
 if ($91) {
  $93 = (($85) + 112|0);
  $94 = (($86) + 112|0);
  $95 = HEAP8[$94>>0]|0;
  $96 = $95 & 1;
  $97 = ($96<<24>>24)==(0);
  if ($97) {
   $100 = $95&255;
   $101 = $100 >>> 1;
   $117 = $101;
  } else {
   $98 = (($86) + 116|0);
   $99 = HEAP32[$98>>2]|0;
   $117 = $99;
  }
  $102 = HEAP8[$93>>0]|0;
  $103 = $102 & 1;
  $104 = ($103<<24>>24)==(0);
  if ($104) {
   $107 = $102&255;
   $108 = $107 >>> 1;
   $116 = $108;
  } else {
   $105 = (($85) + 116|0);
   $106 = HEAP32[$105>>2]|0;
   $116 = $106;
  }
  if ($97) {
   $111 = (($94) + 1|0);
   $119 = $111;
  } else {
   $109 = (($86) + 120|0);
   $110 = HEAP32[$109>>2]|0;
   $119 = $110;
  }
  if ($104) {
   $114 = (($93) + 1|0);
   $120 = $114;
  } else {
   $112 = (($85) + 120|0);
   $113 = HEAP32[$112>>2]|0;
   $120 = $113;
  }
  $115 = ($116>>>0)<($117>>>0);
  $118 = $115 ? $116 : $117;
  $121 = (_memcmp($119,$120,$118)|0);
  $122 = ($121|0)==(0);
  if ($122) {
   $123 = ($117>>>0)<($116>>>0);
   $$$i$i$i$i20 = $115&1;
   $$$$i$i$i$i21 = $123 ? -1 : $$$i$i$i$i20;
   $125 = $$$$i$i$i$i21;
  } else {
   $125 = $121;
  }
  $124 = ($125|0)<(0);
  if (!($124)) {
   $__r$0 = $84;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $92 = ($88|0)>($90|0);
  if (!($92)) {
   $__r$0 = $84;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 HEAP32[$__x2>>2] = $85;
 HEAP32[$__x3>>2] = $86;
 $126 = (($0) + 3)|0;
 $127 = HEAP32[$__x2>>2]|0;
 $128 = HEAP32[$__x1>>2]|0;
 $129 = (($127) + 32|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (($128) + 32|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($130|0)==($132|0);
 if ($133) {
  $135 = (($127) + 112|0);
  $136 = (($128) + 112|0);
  $137 = HEAP8[$136>>0]|0;
  $138 = $137 & 1;
  $139 = ($138<<24>>24)==(0);
  if ($139) {
   $142 = $137&255;
   $143 = $142 >>> 1;
   $159 = $143;
  } else {
   $140 = (($128) + 116|0);
   $141 = HEAP32[$140>>2]|0;
   $159 = $141;
  }
  $144 = HEAP8[$135>>0]|0;
  $145 = $144 & 1;
  $146 = ($145<<24>>24)==(0);
  if ($146) {
   $149 = $144&255;
   $150 = $149 >>> 1;
   $158 = $150;
  } else {
   $147 = (($127) + 116|0);
   $148 = HEAP32[$147>>2]|0;
   $158 = $148;
  }
  if ($139) {
   $153 = (($136) + 1|0);
   $161 = $153;
  } else {
   $151 = (($128) + 120|0);
   $152 = HEAP32[$151>>2]|0;
   $161 = $152;
  }
  if ($146) {
   $156 = (($135) + 1|0);
   $162 = $156;
  } else {
   $154 = (($127) + 120|0);
   $155 = HEAP32[$154>>2]|0;
   $162 = $155;
  }
  $157 = ($158>>>0)<($159>>>0);
  $160 = $157 ? $158 : $159;
  $163 = (_memcmp($161,$162,$160)|0);
  $164 = ($163|0)==(0);
  if ($164) {
   $165 = ($159>>>0)<($158>>>0);
   $$$i$i$i$i4 = $157&1;
   $$$$i$i$i$i5 = $165 ? -1 : $$$i$i$i$i4;
   $167 = $$$$i$i$i$i5;
  } else {
   $167 = $163;
  }
  $166 = ($167|0)<(0);
  if (!($166)) {
   $__r$0 = $126;
   STACKTOP = sp;return ($__r$0|0);
  }
 } else {
  $134 = ($130|0)>($132|0);
  if (!($134)) {
   $__r$0 = $126;
   STACKTOP = sp;return ($__r$0|0);
  }
 }
 HEAP32[$__x1>>2] = $127;
 HEAP32[$__x2>>2] = $128;
 $168 = (($0) + 4)|0;
 $__r$0 = $168;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IR12GreaterLayerPP14AnimationStateEEvT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $__i$011 = 0, $__j$010 = 0, $__j$010$phi = 0, $__k$0$lcssa = 0, $__k$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 8|0);
 $1 = (($__first) + 4|0);
 (__ZNSt3__17__sort3IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 12|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$011 = $2;$__j$010 = $0;
 }
 while(1) {
  $4 = HEAP32[$__i$011>>2]|0;
  $5 = HEAP32[$__j$010>>2]|0;
  $6 = (($4) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) + 32|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  if ($10) {
   $12 = (($4) + 112|0);
   $13 = (($5) + 112|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 1;
   $16 = ($15<<24>>24)==(0);
   if ($16) {
    $19 = $14&255;
    $20 = $19 >>> 1;
    $36 = $20;
   } else {
    $17 = (($5) + 116|0);
    $18 = HEAP32[$17>>2]|0;
    $36 = $18;
   }
   $21 = HEAP8[$12>>0]|0;
   $22 = $21 & 1;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $26 = $21&255;
    $27 = $26 >>> 1;
    $35 = $27;
   } else {
    $24 = (($4) + 116|0);
    $25 = HEAP32[$24>>2]|0;
    $35 = $25;
   }
   if ($16) {
    $30 = (($13) + 1|0);
    $38 = $30;
   } else {
    $28 = (($5) + 120|0);
    $29 = HEAP32[$28>>2]|0;
    $38 = $29;
   }
   if ($23) {
    $33 = (($12) + 1|0);
    $39 = $33;
   } else {
    $31 = (($4) + 120|0);
    $32 = HEAP32[$31>>2]|0;
    $39 = $32;
   }
   $34 = ($35>>>0)<($36>>>0);
   $37 = $34 ? $35 : $36;
   $40 = (_memcmp($38,$39,$37)|0);
   $41 = ($40|0)==(0);
   if ($41) {
    $42 = ($36>>>0)<($35>>>0);
    $$$i$i$i$i = $34&1;
    $$$$i$i$i$i = $42 ? -1 : $$$i$i$i$i;
    $44 = $$$$i$i$i$i;
   } else {
    $44 = $40;
   }
   $43 = ($44|0)<(0);
   if ($43) {
    label = 19;
   }
  } else {
   $11 = ($7|0)>($9|0);
   if ($11) {
    label = 19;
   }
  }
  if ((label|0) == 19) {
   label = 0;
   HEAP32[$__i$011>>2] = $5;
   $45 = ($__j$010|0)==($__first|0);
   L29: do {
    if ($45) {
     $__k$0$lcssa = $__first;
    } else {
     $46 = (($4) + 112|0);
     $47 = (($46) + 1|0);
     $48 = (($4) + 120|0);
     $49 = (($4) + 116|0);
     $__k$09 = $__j$010;
     while(1) {
      $50 = (($__k$09) + -4|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = (($51) + 32|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($7|0)==($53|0);
      if ($54) {
       $56 = (($51) + 112|0);
       $57 = HEAP8[$56>>0]|0;
       $58 = $57 & 1;
       $59 = ($58<<24>>24)==(0);
       if ($59) {
        $62 = $57&255;
        $63 = $62 >>> 1;
        $76 = $63;
       } else {
        $60 = (($51) + 116|0);
        $61 = HEAP32[$60>>2]|0;
        $76 = $61;
       }
       $64 = HEAP8[$46>>0]|0;
       $65 = $64 & 1;
       $66 = ($65<<24>>24)==(0);
       if ($66) {
        $68 = $64&255;
        $69 = $68 >>> 1;
        $75 = $69;
       } else {
        $67 = HEAP32[$49>>2]|0;
        $75 = $67;
       }
       if ($59) {
        $72 = (($56) + 1|0);
        $78 = $72;
       } else {
        $70 = (($51) + 120|0);
        $71 = HEAP32[$70>>2]|0;
        $78 = $71;
       }
       if ($66) {
        $79 = $47;
       } else {
        $73 = HEAP32[$48>>2]|0;
        $79 = $73;
       }
       $74 = ($75>>>0)<($76>>>0);
       $77 = $74 ? $75 : $76;
       $80 = (_memcmp($78,$79,$77)|0);
       $81 = ($80|0)==(0);
       if ($81) {
        $82 = ($76>>>0)<($75>>>0);
        $$$i$i$i$i4 = $74&1;
        $$$$i$i$i$i5 = $82 ? -1 : $$$i$i$i$i4;
        $84 = $$$$i$i$i$i5;
       } else {
        $84 = $80;
       }
       $83 = ($84|0)<(0);
       if (!($83)) {
        $__k$0$lcssa = $__k$09;
        break L29;
       }
      } else {
       $55 = ($7|0)>($53|0);
       if (!($55)) {
        $__k$0$lcssa = $__k$09;
        break L29;
       }
      }
      HEAP32[$__k$09>>2] = $51;
      $85 = ($50|0)==($__first|0);
      if ($85) {
       $__k$0$lcssa = $__first;
       break;
      } else {
       $__k$09 = $50;
      }
     }
    }
   } while(0);
   HEAP32[$__k$0$lcssa>>2] = $4;
  }
  $86 = (($__i$011) + 4|0);
  $87 = ($86|0)==($__last|0);
  if ($87) {
   break;
  } else {
   $__j$010$phi = $__i$011;$__i$011 = $86;$__j$010 = $__j$010$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIR12GreaterLayerPP14AnimationStateEEbT0_S6_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i13 = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i12 = 0, $$$i$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$020 = 0, $__count$1 = 0, $__i$022 = 0, $__j$019 = 0, $__j$019$phi = 0, $__k$0$lcssa = 0;
 var $__k$017 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 3:  {
  $46 = (($__first) + 4|0);
  $47 = (($__last) + -4|0);
  (__ZNSt3__17__sort3IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_T_($__first,$46,$47,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $48 = (($__first) + 4|0);
  $49 = (($__first) + 8|0);
  $50 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_S6_T_($__first,$48,$49,$50,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = (($5) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 32|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  if ($11) {
   $13 = (($5) + 112|0);
   $14 = (($6) + 112|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = $15 & 1;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    $20 = $15&255;
    $21 = $20 >>> 1;
    $37 = $21;
   } else {
    $18 = (($6) + 116|0);
    $19 = HEAP32[$18>>2]|0;
    $37 = $19;
   }
   $22 = HEAP8[$13>>0]|0;
   $23 = $22 & 1;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    $27 = $22&255;
    $28 = $27 >>> 1;
    $36 = $28;
   } else {
    $25 = (($5) + 116|0);
    $26 = HEAP32[$25>>2]|0;
    $36 = $26;
   }
   if ($17) {
    $31 = (($14) + 1|0);
    $39 = $31;
   } else {
    $29 = (($6) + 120|0);
    $30 = HEAP32[$29>>2]|0;
    $39 = $30;
   }
   if ($24) {
    $34 = (($13) + 1|0);
    $40 = $34;
   } else {
    $32 = (($5) + 120|0);
    $33 = HEAP32[$32>>2]|0;
    $40 = $33;
   }
   $35 = ($36>>>0)<($37>>>0);
   $38 = $35 ? $36 : $37;
   $41 = (_memcmp($39,$40,$38)|0);
   $42 = ($41|0)==(0);
   if ($42) {
    $43 = ($37>>>0)<($36>>>0);
    $$$i$i$i$i = $35&1;
    $$$$i$i$i$i = $43 ? -1 : $$$i$i$i$i;
    $45 = $$$$i$i$i$i;
   } else {
    $45 = $41;
   }
   $44 = ($45|0)<(0);
   if (!($44)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $12 = ($8|0)>($10|0);
   if (!($12)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $51 = (($__first) + 4|0);
  $52 = (($__first) + 8|0);
  $53 = (($__first) + 12|0);
  $54 = (($__last) + -4|0);
  (__ZNSt3__17__sort5IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_S6_S6_T_($__first,$51,$52,$53,$54,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $55 = (($__first) + 8|0);
  $56 = (($__first) + 4|0);
  (__ZNSt3__17__sort3IR12GreaterLayerPP14AnimationStateEEjT0_S6_S6_T_($__first,$56,$55,0)|0);
  $57 = (($__first) + 12|0);
  $58 = ($57|0)==($__last|0);
  if ($58) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$020 = 0;$__i$022 = $57;$__j$019 = $55;
  }
  while(1) {
   $59 = HEAP32[$__i$022>>2]|0;
   $60 = HEAP32[$__j$019>>2]|0;
   $61 = (($59) + 32|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($60) + 32|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($62|0)==($64|0);
   if ($65) {
    $67 = (($59) + 112|0);
    $68 = (($60) + 112|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = $69 & 1;
    $71 = ($70<<24>>24)==(0);
    if ($71) {
     $74 = $69&255;
     $75 = $74 >>> 1;
     $91 = $75;
    } else {
     $72 = (($60) + 116|0);
     $73 = HEAP32[$72>>2]|0;
     $91 = $73;
    }
    $76 = HEAP8[$67>>0]|0;
    $77 = $76 & 1;
    $78 = ($77<<24>>24)==(0);
    if ($78) {
     $81 = $76&255;
     $82 = $81 >>> 1;
     $90 = $82;
    } else {
     $79 = (($59) + 116|0);
     $80 = HEAP32[$79>>2]|0;
     $90 = $80;
    }
    if ($71) {
     $85 = (($68) + 1|0);
     $93 = $85;
    } else {
     $83 = (($60) + 120|0);
     $84 = HEAP32[$83>>2]|0;
     $93 = $84;
    }
    if ($78) {
     $88 = (($67) + 1|0);
     $94 = $88;
    } else {
     $86 = (($59) + 120|0);
     $87 = HEAP32[$86>>2]|0;
     $94 = $87;
    }
    $89 = ($90>>>0)<($91>>>0);
    $92 = $89 ? $90 : $91;
    $95 = (_memcmp($93,$94,$92)|0);
    $96 = ($95|0)==(0);
    if ($96) {
     $97 = ($91>>>0)<($90>>>0);
     $$$i$i$i$i12 = $89&1;
     $$$$i$i$i$i13 = $97 ? -1 : $$$i$i$i$i12;
     $99 = $$$$i$i$i$i13;
    } else {
     $99 = $95;
    }
    $98 = ($99|0)<(0);
    if ($98) {
     label = 41;
    } else {
     $__count$1 = $__count$020;
    }
   } else {
    $66 = ($62|0)>($64|0);
    if ($66) {
     label = 41;
    } else {
     $__count$1 = $__count$020;
    }
   }
   if ((label|0) == 41) {
    label = 0;
    HEAP32[$__i$022>>2] = $60;
    $100 = ($__j$019|0)==($__first|0);
    L64: do {
     if ($100) {
      $__k$0$lcssa = $__first;
     } else {
      $101 = (($59) + 112|0);
      $102 = (($101) + 1|0);
      $103 = (($59) + 120|0);
      $104 = (($59) + 116|0);
      $__k$017 = $__j$019;
      while(1) {
       $105 = (($__k$017) + -4|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = (($106) + 32|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ($62|0)==($108|0);
       if ($109) {
        $111 = (($106) + 112|0);
        $112 = HEAP8[$111>>0]|0;
        $113 = $112 & 1;
        $114 = ($113<<24>>24)==(0);
        if ($114) {
         $117 = $112&255;
         $118 = $117 >>> 1;
         $131 = $118;
        } else {
         $115 = (($106) + 116|0);
         $116 = HEAP32[$115>>2]|0;
         $131 = $116;
        }
        $119 = HEAP8[$101>>0]|0;
        $120 = $119 & 1;
        $121 = ($120<<24>>24)==(0);
        if ($121) {
         $123 = $119&255;
         $124 = $123 >>> 1;
         $130 = $124;
        } else {
         $122 = HEAP32[$104>>2]|0;
         $130 = $122;
        }
        if ($114) {
         $127 = (($111) + 1|0);
         $133 = $127;
        } else {
         $125 = (($106) + 120|0);
         $126 = HEAP32[$125>>2]|0;
         $133 = $126;
        }
        if ($121) {
         $134 = $102;
        } else {
         $128 = HEAP32[$103>>2]|0;
         $134 = $128;
        }
        $129 = ($130>>>0)<($131>>>0);
        $132 = $129 ? $130 : $131;
        $135 = (_memcmp($133,$134,$132)|0);
        $136 = ($135|0)==(0);
        if ($136) {
         $137 = ($131>>>0)<($130>>>0);
         $$$i$i$i$i4 = $129&1;
         $$$$i$i$i$i5 = $137 ? -1 : $$$i$i$i$i4;
         $139 = $$$$i$i$i$i5;
        } else {
         $139 = $135;
        }
        $138 = ($139|0)<(0);
        if (!($138)) {
         $__k$0$lcssa = $__k$017;
         break L64;
        }
       } else {
        $110 = ($62|0)>($108|0);
        if (!($110)) {
         $__k$0$lcssa = $__k$017;
         break L64;
        }
       }
       HEAP32[$__k$017>>2] = $106;
       $140 = ($105|0)==($__first|0);
       if ($140) {
        $__k$0$lcssa = $__first;
        break;
       } else {
        $__k$017 = $105;
       }
      }
     }
    } while(0);
    HEAP32[$__k$0$lcssa>>2] = $59;
    $141 = (($__count$020) + 1)|0;
    $142 = ($141|0)==(8);
    if ($142) {
     break;
    } else {
     $__count$1 = $141;
    }
   }
   $145 = (($__i$022) + 4|0);
   $146 = ($145|0)==($__last|0);
   if ($146) {
    $$0 = 1;
    label = 63;
    break;
   } else {
    $__j$019$phi = $__i$022;$__count$020 = $__count$1;$__i$022 = $145;$__j$019 = $__j$019$phi;
   }
  }
  if ((label|0) == 63) {
   STACKTOP = sp;return ($$0|0);
  }
  $143 = (($__i$022) + 4|0);
  $144 = ($143|0)==($__last|0);
  $$0 = $144;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__16vectorIP8Renderer13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 2;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,765224,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<2)|0);
 $24 = (($23) + ($$0$i3<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$__x>>2]|0;
  HEAP32[$22>>2] = $26;
 }
 $27 = (($23) + ($8<<2)|0);
 $28 = HEAP32[$this>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = $29;
 $31 = $28;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $$sum1 = (($7) - ($33))|0;
 $34 = (($23) + ($$sum1<<2)|0);
 _memcpy(($34|0),($28|0),($32|0))|0;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $34;
 HEAP32[$1>>2] = $27;
 HEAP32[$10>>2] = $24;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIP8Renderer13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $13 = 0;
   } else {
    HEAP32[$11>>2] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 4|0);
   HEAP32[$3>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = $18 >> 2;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = $22 >> 2;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $22 >> 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $29 = $$0$i56 << 2;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,765224,79)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + ($19<<2)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $36 = 0;
  } else {
   HEAP32[$34>>2] = 0;
   $36 = $34;
  }
  $35 = (($36) + 4|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $35;
  }
 }
 $39 = (($32) + ($$0$i57<<2)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = $44 >> 2;
 $$sum = (($19) - ($45))|0;
 $46 = (($32) + ($$sum<<2)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $35;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI15QueuedAnimation13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 4;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 3;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 4;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,765224,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<4)|0);
 $24 = (($23) + ($$0$i3<<4)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  ;HEAP32[$22+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__x+12>>2]|0;
 }
 $26 = (($23) + ($8<<4)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = $28;
 $30 = $27;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 4;
 $$sum1 = (($7) - ($32))|0;
 $33 = (($23) + ($$sum1<<4)|0);
 _memcpy(($33|0),($27|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$1>>2] = $26;
 HEAP32[$10>>2] = $24;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN9Animation8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $12 = (($this) + 264|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 268|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)==($15|0);
 if ($16) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  STACKTOP = sp;return;
 } else {
  $18 = $13;
 }
 while(1) {
  $17 = HEAP32[$18>>2]|0;
  $19 = HEAP32[$2>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = HEAP32[$6>>2]|0;
  $23 = (FUNCTION_TABLE_iiii[$21 & 2047]($19,$17,$22)|0);
  $24 = HEAP8[$9>>0]|0;
  $25 = ($24<<24>>24)==(0);
  if (!($25)) {
   HEAP32[$18>>2] = $23;
  }
  $26 = (($18) + 4|0);
  $27 = ($26|0)==($15|0);
  if ($27) {
   break;
  } else {
   $18 = $26;
  }
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9Animation8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 260|0);
 __ZN4PPtrI13AnimationClipE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 268|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size$i$i$i>>2] = $8;
 $9 = (($transfer) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = (($transfer) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  HEAP32[$10>>2] = $8;
  HEAP32[$9>>2] = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$size$i$i$i,4);
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = HEAP32[$3>>2]|0;
 $17 = ($16|0)==($15|0);
 if (!($17)) {
  $18 = $16;
  while(1) {
   __ZN4PPtrI13AnimationClipE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($18,$transfer);
   $19 = (($18) + 4|0);
   $20 = ($19|0)==($15|0);
   if ($20) {
    break;
   } else {
    $18 = $19;
   }
  }
 }
 $21 = (($this) + 32|0);
 $22 = HEAP32[$9>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$12>>2]|0;
 $25 = ($23>>>0)<($24>>>0);
 if ($25) {
  $26 = HEAP32[$21>>2]|0;
  HEAP32[$22>>2] = $26;
  HEAP32[$9>>2] = $23;
  $29 = $23;$31 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$21,4);
  $$pre = HEAP32[$9>>2]|0;
  $$pre3 = HEAP32[$12>>2]|0;
  $29 = $$pre;$31 = $$pre3;
 }
 $27 = (($this) + 36|0);
 $28 = (($29) + 1|0);
 $30 = ($28>>>0)<($31>>>0);
 if ($30) {
  $32 = HEAP8[$27>>0]|0;
  HEAP8[$29>>0] = $32;
  $33 = HEAP32[$9>>2]|0;
  $34 = (($33) + 1|0);
  HEAP32[$9>>2] = $34;
  $37 = $34;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$27,1);
  $$pre4 = HEAP32[$9>>2]|0;
  $37 = $$pre4;
 }
 $35 = (($this) + 37|0);
 $36 = (($37) + 1|0);
 $38 = HEAP32[$12>>2]|0;
 $39 = ($36>>>0)<($38>>>0);
 if ($39) {
  $40 = HEAP8[$35>>0]|0;
  HEAP8[$37>>0] = $40;
  $41 = HEAP32[$9>>2]|0;
  $42 = (($41) + 1|0);
  HEAP32[$9>>2] = $42;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$35,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $43 = (($this) + 40|0);
 $44 = HEAP32[$9>>2]|0;
 $45 = (($44) + 4|0);
 $46 = HEAP32[$12>>2]|0;
 $47 = ($45>>>0)<($46>>>0);
 if ($47) {
  $48 = HEAP32[$43>>2]|0;
  HEAP32[$44>>2] = $48;
  HEAP32[$9>>2] = $45;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$43,4);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI13AnimationClipE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN9Animation8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre4 = 0, $$pre5 = 0, $$type$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 260|0);
 __ZN4PPtrI13AnimationClipE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($this) + 264|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS6_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 32|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i1 = HEAP32[$2>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$6>>2]|0;
  $10 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre4;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;$14 = $5;$16 = $7;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$2>>2] = $11;
 $12 = (($this) + 36|0);
 $13 = (($14) + 1|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$12,1);
  $$pre5 = HEAP32[$3>>2]|0;
  $22 = $$pre5;
 } else {
  $17 = HEAP8[$14>>0]|0;
  HEAP8[$12>>0] = $17;
  $18 = HEAP32[$3>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$3>>2] = $19;
  $22 = $19;
 }
 $20 = (($this) + 37|0);
 $21 = (($22) + 1|0);
 $23 = HEAP32[$6>>2]|0;
 $24 = ($21>>>0)>($23>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$20,1);
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$3>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$3>>2] = $27;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $28 = (($this) + 40|0);
 $29 = HEAP32[$3>>2]|0;
 $30 = (($29) + 4|0);
 $31 = HEAP32[$6>>2]|0;
 $32 = ($30>>>0)>($31>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$28,4);
  $$pre$i$i$i = HEAP32[$28>>2]|0;
  $34 = $$pre$i$i$i;
  $35 = (_llvm_bswap_i32(($34|0))|0);
  $36 = $35 & -2;
  $37 = ($36|0)==(2);
  $$type$i = $37 ? 1 : $35;
  HEAP32[$28>>2] = $$type$i;
  STACKTOP = sp;return;
 } else {
  $33 = HEAP32[$29>>2]|0;
  HEAP32[$28>>2] = $33;
  HEAP32[$3>>2] = $30;
  $34 = $33;
  $35 = (_llvm_bswap_i32(($34|0))|0);
  $36 = $35 & -2;
  $37 = ($36|0)==(2);
  $$type$i = $37 ? 1 : $35;
  HEAP32[$28>>2] = $$type$i;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS6_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI13AnimationClipE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy5 = 0, $$idx = 0, $$pre = 0, $$pre43 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i17 = 0, $__new_last2$i$i$i$i$i26 = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i18 = 0, $scevgep$i$i$i$i$i27 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i22 = 0;
 var $scevgep4$i$i$i$i$i31 = 0, $scevgep8$i$i = 0, $scevgep8$i$i41 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i20 = 0, $uglygep$i$i$i$i$i29 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i21 = 0, $uglygep3$i$i$i$i$i30 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $temp = sp + 8|0;
 $1 = sp + 20|0;
 $2 = sp + 24|0;
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$v>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)<($sz>>>0);
 if (!($10)) {
  $70 = ($9>>>0)>($sz>>>0);
  if (!($70)) {
   STACKTOP = sp;return;
  }
  $71 = (($5) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $72 = $$idx >> 2;
  $73 = ($72|0)==(0);
  do {
   if ($73) {
    $93 = 0;$95 = 0;$scevgep8$i$i41 = 0;
   } else {
    $74 = ($$idx|0)<(0);
    if ($74) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if (!($76)) {
      // unreachable;
     }
    } else {
     HEAP32[$0>>2] = 18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $77 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy5|0),0,(765224|0),79)|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if (!($79)) {
      $80 = (($77) + ($72<<2)|0);
      $81 = ($sz|0)==(0);
      if ($81) {
       $93 = $77;$95 = $80;$scevgep8$i$i41 = $77;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($5) + ($$sum<<2)|0);
      $82 = (0 - ($7))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($82)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $84 = $77;$86 = $5;
      while(1) {
       $83 = ($84|0)==(0|0);
       if (!($83)) {
        $85 = HEAP32[$86>>2]|0;
        HEAP32[$84>>2] = $85;
       }
       $87 = (($84) + 4|0);
       $88 = (($86) + 4|0);
       $89 = ($88|0)==($71|0);
       if ($89) {
        break;
       } else {
        $84 = $87;$86 = $88;
       }
      }
      $90 = $uglygep6$i$i >>> 2;
      $91 = (($90) + 1)|0;
      $scevgep8$i$i = (($77) + ($91<<2)|0);
      $93 = $77;$95 = $80;$scevgep8$i$i41 = $scevgep8$i$i;
      break;
     }
    }
    $101 = ___cxa_find_matching_catch()|0;
    $102 = tempRet0;
    $$0 = $102;$$01 = $101;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $92 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $93;
  HEAP32[$3>>2] = $scevgep8$i$i41;
  $94 = (($v) + 8|0);
  HEAP32[$94>>2] = $95;
  $96 = ($92|0)==(0|0);
  if ($96) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 18;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($92|0),($$byval_copy5|0));
  $97 = __THREW__; __THREW__ = 0;
  $98 = $97&1;
  if ($98) {
   $99 = ___cxa_find_matching_catch()|0;
   $100 = tempRet0;
   ___cxa_call_unexpected(($99|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $11 = (($v) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($7))|0;
 $15 = $14 >> 2;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $69 = (($sz) - ($9))|0;
  __ZNSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEE8__appendEj($v,$69);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3361,($temp|0),($sz|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if (!($20)) {
   $21 = HEAP32[$v>>2]|0;
   HEAP32[$1>>2] = $21;
   $22 = HEAP32[$3>>2]|0;
   HEAP32[$2>>2] = $22;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viii(1992,($temp|0),($$byval_copy|0),($$byval_copy5|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$17>>2]|0;
    $26 = HEAP32[$temp>>2]|0;
    $27 = $25;
    $28 = $26;
    $29 = (($27) - ($28))|0;
    $30 = $29 >> 2;
    $31 = ($30>>>0)<($sz>>>0);
    if ($31) {
     $32 = (($sz) - ($30))|0;
     __THREW__ = 0;
     invoke_vii(3362,($temp|0),($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre43 = HEAP32[$17>>2]|0;
     $42 = $$pre;$44 = $$pre43;
    } else {
     $35 = ($30>>>0)>($sz>>>0);
     if ($35) {
      $36 = (($26) + ($sz<<2)|0);
      $37 = ($25|0)==($36|0);
      if ($37) {
       $42 = $26;$44 = $25;
      } else {
       $__new_last2$i$i$i = $36;
       $scevgep$i$i$i = (($25) + -4|0);
       $38 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($38)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $39 = $uglygep3$i$i$i >>> 2;
       $40 = $39 ^ -1;
       $scevgep4$i$i$i = (($25) + ($40<<2)|0);
       HEAP32[$17>>2] = $scevgep4$i$i$i;
       $42 = $26;$44 = $scevgep4$i$i$i;
      }
     } else {
      $42 = $26;$44 = $25;
     }
    }
    $41 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $41;
    HEAP32[$v>>2] = $42;
    $43 = HEAP32[$3>>2]|0;
    HEAP32[$17>>2] = $43;
    HEAP32[$3>>2] = $44;
    $45 = HEAP32[$18>>2]|0;
    $46 = HEAP32[$11>>2]|0;
    HEAP32[$18>>2] = $46;
    HEAP32[$11>>2] = $45;
    $47 = ($41|0)==(0|0);
    if ($47) {
     STACKTOP = sp;return;
    }
    $48 = ($43|0)==($41|0);
    if (!($48)) {
     $__new_last2$i$i$i$i$i17 = $41;
     $scevgep$i$i$i$i$i18 = (($43) + -4|0);
     $49 = (0 - ($__new_last2$i$i$i$i$i17))|0;
     $uglygep$i$i$i$i$i20 = (($scevgep$i$i$i$i$i18) + ($49)|0);
     $uglygep3$i$i$i$i$i21 = $uglygep$i$i$i$i$i20;
     $50 = $uglygep3$i$i$i$i$i21 >>> 2;
     $51 = $50 ^ -1;
     $scevgep4$i$i$i$i$i22 = (($43) + ($51<<2)|0);
     HEAP32[$17>>2] = $scevgep4$i$i$i$i$i22;
    }
    HEAP32[$$byval_copy>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($41|0),($$byval_copy5|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     ___cxa_call_unexpected(($54|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 $58 = HEAP32[$temp>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
 $60 = HEAP32[$17>>2]|0;
 $61 = ($60|0)==($58|0);
 if (!($61)) {
  $__new_last2$i$i$i$i$i26 = $58;
  $scevgep$i$i$i$i$i27 = (($60) + -4|0);
  $62 = (0 - ($__new_last2$i$i$i$i$i26))|0;
  $uglygep$i$i$i$i$i29 = (($scevgep$i$i$i$i$i27) + ($62)|0);
  $uglygep3$i$i$i$i$i30 = $uglygep$i$i$i$i$i29;
  $63 = $uglygep3$i$i$i$i$i30 >>> 2;
  $64 = $63 ^ -1;
  $scevgep4$i$i$i$i$i31 = (($60) + ($64<<2)|0);
  HEAP32[$17>>2] = $scevgep4$i$i$i$i$i31;
 }
 HEAP32[$$byval_copy>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($58|0),($$byval_copy5|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  ___cxa_call_unexpected(($67|0));
  // unreachable;
 } else {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = $12 >> 2;
 $14 = ($__n|0)==(0);
 if ($14) {
  $$pre$i = $3;$18 = 0;$21 = $10;
 } else {
  $15 = $__n << 2;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy1,0,765224,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre1 = HEAP32[$9>>2]|0;
  $$pre$i = $$pre;$18 = $16;$21 = $$pre1;
 }
 $17 = (($18) + ($13<<2)|0);
 $19 = (($18) + ($__n<<2)|0);
 $20 = ($21|0)==($$pre$i|0);
 if ($20) {
  $31 = $17;$33 = $21;
 } else {
  $__begin13$i$i = $$pre$i;
  $scevgep$i$i = (($21) + -4|0);
  $22 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($22)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $21;$26 = $17;
  while(1) {
   $23 = (($$01$i$i) + -4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($26) + -4|0);
   HEAP32[$25>>2] = $24;
   $27 = (($26) + -4|0);
   $28 = ($23|0)==($$pre$i|0);
   if ($28) {
    break;
   } else {
    $$01$i$i = $23;$26 = $27;
   }
  }
  $29 = $uglygep4$i$i >>> 2;
  $30 = $29 ^ -1;
  $$sum = (($13) + ($30))|0;
  $scevgep5$i$i = (($18) + ($$sum<<2)|0);
  $31 = $scevgep5$i$i;$33 = $$pre$i;
 }
 HEAP32[$this>>2] = $31;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $32 = ($33|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$promoted15$i16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i8 = 0, $scevgep$i17 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i24 = 0, $uglygep$i = 0;
 var $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i9 = 0, $uglygep$i19 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $47 = ($9|0)==(0|0);
  do {
   if ($47) {
    $60 = $8;
   } else {
    $48 = (($this) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($9|0);
    if (!($50)) {
     $scevgep$i$i$i$i = (($49) + -4|0);
     $51 = (0 - ($11))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($51)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $52 = $uglygep3$i$i$i$i >>> 2;
     $53 = $52 ^ -1;
     $scevgep4$i$i$i$i = (($49) + ($53<<2)|0);
     HEAP32[$48>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$0>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy1|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     ___cxa_call_unexpected(($56|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$48>>2] = 0;
     HEAP32[$this>>2] = 0;
     $60 = 0;
     break;
    }
   }
  } while(0);
  $58 = ($5|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $59 = $60;
  $61 = $59 >> 2;
  $62 = ($61>>>0)<(1073741823);
  if ($62) {
   $63 = $59 >> 1;
   $64 = ($63>>>0)<($6>>>0);
   $65 = $64 ? $6 : $63;
   $66 = ($65|0)<(0);
   if ($66) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $65;
   }
  } else {
   $$0$i40 = 2147483647;
  }
  $67 = $$0$i40 << 2;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $68 = (__Z15malloc_internaljj10MemLabelIdiPKci($67,16,$$byval_copy1,0,765224,79)|0);
  $69 = (($this) + 4|0);
  HEAP32[$69>>2] = $68;
  HEAP32[$this>>2] = $68;
  $70 = (($68) + ($$0$i40<<2)|0);
  HEAP32[$7>>2] = $70;
  $71 = ($1|0)==($2|0);
  if ($71) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($2) + -4|0);
  $72 = (0 - ($4))|0;
  $uglygep$i = (($scevgep$i) + ($72)|0);
  $uglygep6$i = $uglygep$i;
  $73 = $uglygep6$i >>> 2;
  $75 = $68;$77 = $1;
  while(1) {
   $74 = ($75|0)==(0|0);
   if (!($74)) {
    $76 = HEAP32[$77>>2]|0;
    HEAP32[$75>>2] = $76;
   }
   $78 = (($75) + 4|0);
   $79 = (($77) + 4|0);
   $80 = ($79|0)==($2|0);
   if ($80) {
    break;
   } else {
    $75 = $78;$77 = $79;
   }
  }
  $81 = (($73) + 1)|0;
  $scevgep8$i = (($68) + ($81<<2)|0);
  HEAP32[$69>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 } else {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + ($19<<2)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i$i = (($23) + -4|0);
   $24 = (0 - ($4))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($24)|0);
   $uglygep5$i$i = $uglygep$i$i;
   $25 = $uglygep5$i$i >>> 2;
   $$01$i$i = $9;$27 = $1;
   while(1) {
    $26 = HEAP32[$27>>2]|0;
    HEAP32[$$01$i$i>>2] = $26;
    $28 = (($27) + 4|0);
    $29 = (($$01$i$i) + 4|0);
    $30 = ($28|0)==($23|0);
    if ($30) {
     break;
    } else {
     $$01$i$i = $29;$27 = $28;
    }
   }
   $31 = (($25) + 1)|0;
   $scevgep6$i$i = (($9) + ($31<<2)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  if (!($__growing$0$off0)) {
   $43 = ($16|0)==($$0$lcssa$i$i|0);
   if ($43) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $$0$lcssa$i$i;
   $scevgep$i$i8 = (($16) + -4|0);
   $44 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i9 = (($scevgep$i$i8) + ($44)|0);
   $uglygep3$i$i = $uglygep$i$i9;
   $45 = $uglygep3$i$i >>> 2;
   $46 = $45 ^ -1;
   $scevgep4$i$i = (($16) + ($46<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $32 = ($23|0)==($2|0);
  if ($32) {
   STACKTOP = sp;return;
  }
  $$promoted15$i16 = $23;
  $scevgep$i17 = (($2) + -4|0);
  $33 = (0 - ($$promoted15$i16))|0;
  $uglygep$i19 = (($scevgep$i17) + ($33)|0);
  $uglygep6$i20 = $uglygep$i19;
  $34 = $uglygep6$i20 >>> 2;
  $36 = $16;$38 = $23;
  while(1) {
   $35 = ($36|0)==(0|0);
   if (!($35)) {
    $37 = HEAP32[$38>>2]|0;
    HEAP32[$36>>2] = $37;
   }
   $39 = (($36) + 4|0);
   $40 = (($38) + 4|0);
   $41 = ($40|0)==($2|0);
   if ($41) {
    break;
   } else {
    $36 = $39;$38 = $40;
   }
  }
  $42 = (($34) + 1)|0;
  $scevgep8$i24 = (($16) + ($42<<2)|0);
  HEAP32[$15>>2] = $scevgep8$i24;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP32[$11>>2] = 0;
   }
   $12 = (($11) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<2)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy1,0,765224,79)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAP32[$33>>2] = 0;
  }
  $34 = (($33) + 4|0);
  $35 = (($$0$i2) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i2 = $35;$33 = $34;
  }
 }
 $37 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 $38 = HEAP32[$this>>2]|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = ($39|0)==($38|0);
 if ($40) {
  $50 = $30;
 } else {
  $__begin13$i$i = $38;
  $scevgep$i$i = (($39) + -4|0);
  $41 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($41)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $39;$45 = $30;
  while(1) {
   $42 = (($$01$i$i) + -4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($45) + -4|0);
   HEAP32[$44>>2] = $43;
   $46 = (($45) + -4|0);
   $47 = ($42|0)==($38|0);
   if ($47) {
    break;
   } else {
    $$01$i$i = $42;$45 = $46;
   }
  }
  $48 = $uglygep4$i$i >>> 2;
  $49 = $48 ^ -1;
  $$sum6 = (($18) + ($49))|0;
  $scevgep5$i$i = (($31) + ($$sum6<<2)|0);
  $50 = $scevgep5$i$i;
 }
 HEAP32[$this>>2] = $50;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $37;
 $51 = ($38|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($38|0),($$byval_copy1|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  ___cxa_call_unexpected(($54|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI13AnimationClipE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN9Animation8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$type$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 260|0);
 __ZN4PPtrI13AnimationClipE8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 264|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS6_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 32|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre3 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre3;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($this) + 36|0);
 $11 = (($12) + 1|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,1);
  $$pre4 = HEAP32[$3>>2]|0;
  $20 = $$pre4;
 } else {
  $15 = HEAP8[$12>>0]|0;
  HEAP8[$10>>0] = $15;
  $16 = HEAP32[$3>>2]|0;
  $17 = (($16) + 1|0);
  HEAP32[$3>>2] = $17;
  $20 = $17;
 }
 $18 = (($this) + 37|0);
 $19 = (($20) + 1|0);
 $21 = HEAP32[$6>>2]|0;
 $22 = ($19>>>0)>($21>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$18,1);
 } else {
  $23 = HEAP8[$20>>0]|0;
  HEAP8[$18>>0] = $23;
  $24 = HEAP32[$3>>2]|0;
  $25 = (($24) + 1|0);
  HEAP32[$3>>2] = $25;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $26 = (($this) + 40|0);
 $27 = HEAP32[$3>>2]|0;
 $28 = (($27) + 4|0);
 $29 = HEAP32[$6>>2]|0;
 $30 = ($28>>>0)>($29>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$26,4);
  $$pre5 = HEAP32[$26>>2]|0;
  $33 = $$pre5;
  $32 = $33 & -2;
  $34 = ($32|0)==(2);
  $$type$i = $34 ? 1 : $33;
  HEAP32[$26>>2] = $$type$i;
  STACKTOP = sp;return;
 } else {
  $31 = HEAP32[$27>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$3>>2] = $28;
  $33 = $31;
  $32 = $33 & -2;
  $34 = ($32|0)==(2);
  $$type$i = $34 ? 1 : $33;
  HEAP32[$26>>2] = $$type$i;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS6_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI13AnimationClipE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI13AnimationClipE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN9Animation8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$sum = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i4 = 0, $$sum$i$i$i$i$i9 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i10 = 0, $$sum1$i$i$i$i$i5 = 0, $$type$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $animateOnlyIfVisible = 0, $converter$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i8 = sp;
 $animateOnlyIfVisible = sp + 4|0;
 __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,3);
 $0 = (($this) + 260|0);
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,765480,765616,$converter$i$i8,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN4PPtrI13AnimationClipE8TransferI14SafeBinaryReadEEvRT_($0,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i8>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 264|0);
 $7 = HEAP32[580760>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,765496,$7,$converter$i$i8,1)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($8|0)>(0);
  if ($10) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$6,0);
  } else {
   $11 = HEAP32[$converter$i$i8>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    (FUNCTION_TABLE_iii[$11 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $13 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$13,765512,0);
 $14 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,2)|0);
 if ($14) {
  HEAP8[$animateOnlyIfVisible>>0] = 0;
  $15 = HEAP32[580544>>2]|0;
  $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,765456,$15,$converter$i$i8,0)|0);
  $17 = ($16|0)==(0);
  if (!($17)) {
   $18 = ($16|0)>(0);
   do {
    if ($18) {
     $19 = (($transfer) + 12|0);
     $20 = (($transfer) + 80|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($21) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($transfer) + 16|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($transfer) + 28|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($transfer) + 32|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = Math_imul($29, $27)|0;
     $$sum$i$i$i$i$i = (($23) - ($30))|0;
     $31 = (($25) + ($$sum$i$i$i$i$i)|0);
     HEAP32[$19>>2] = $31;
     $32 = ($$sum$i$i$i$i$i|0)<(0);
     if (!($32)) {
      $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
      $33 = (($25) + ($$sum1$i$i$i$i$i)|0);
      $34 = (($transfer) + 20|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($33>>>0)>($35>>>0);
      if (!($36)) {
       $37 = HEAP8[$31>>0]|0;
       HEAP8[$animateOnlyIfVisible>>0] = $37;
       $$sum = (($$sum$i$i$i$i$i) + 1)|0;
       $38 = (($25) + ($$sum)|0);
       HEAP32[$19>>2] = $38;
       break;
      }
     }
     __ZN12CachedReader15UpdateReadCacheEPvj($19,$animateOnlyIfVisible,1);
    } else {
     $39 = HEAP32[$converter$i$i8>>2]|0;
     $40 = ($39|0)==(0|0);
     if (!($40)) {
      (FUNCTION_TABLE_iii[$39 & 4095]($animateOnlyIfVisible,$transfer)|0);
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
  $41 = HEAP8[$animateOnlyIfVisible>>0]|0;
  $42 = $41&255;
  $43 = (($this) + 40|0);
  HEAP32[$43>>2] = $42;
  $45 = $15;
 } else {
  $$pre = HEAP32[580544>>2]|0;
  $45 = $$pre;
 }
 $44 = (($this) + 36|0);
 $46 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,765528,$45,$converter$i$i8,0)|0);
 $47 = ($46|0)==(0);
 if (!($47)) {
  $48 = ($46|0)>(0);
  do {
   if ($48) {
    $49 = (($transfer) + 12|0);
    $50 = (($transfer) + 80|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) + 12|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($transfer) + 16|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($transfer) + 28|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($transfer) + 32|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = Math_imul($59, $57)|0;
    $$sum$i$i$i$i$i4 = (($53) - ($60))|0;
    $61 = (($55) + ($$sum$i$i$i$i$i4)|0);
    HEAP32[$49>>2] = $61;
    $62 = ($$sum$i$i$i$i$i4|0)<(0);
    if (!($62)) {
     $$sum1$i$i$i$i$i5 = (($$sum$i$i$i$i$i4) + 1)|0;
     $63 = (($55) + ($$sum1$i$i$i$i$i5)|0);
     $64 = (($transfer) + 20|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = ($63>>>0)>($65>>>0);
     if (!($66)) {
      $67 = HEAP8[$61>>0]|0;
      HEAP8[$44>>0] = $67;
      $68 = HEAP32[$49>>2]|0;
      $69 = (($68) + 1|0);
      HEAP32[$49>>2] = $69;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($49,$44,1);
   } else {
    $70 = HEAP32[$converter$i$i8>>2]|0;
    $71 = ($70|0)==(0|0);
    if (!($71)) {
     (FUNCTION_TABLE_iii[$70 & 4095]($44,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $72 = (($this) + 37|0);
 $73 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,765408,$45,$converter$i$i8,0)|0);
 $74 = ($73|0)==(0);
 if ($74) {
  $99 = (($this) + 40|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$99,765552,0);
  $100 = HEAP32[$99>>2]|0;
  $101 = $100 & -2;
  $102 = ($101|0)==(2);
  $$type$i = $102 ? 1 : $100;
  HEAP32[$99>>2] = $$type$i;
  STACKTOP = sp;return;
 }
 $75 = ($73|0)>(0);
 do {
  if ($75) {
   $76 = (($transfer) + 12|0);
   $77 = (($transfer) + 80|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (($78) + 12|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($transfer) + 16|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($transfer) + 28|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($transfer) + 32|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $84)|0;
   $$sum$i$i$i$i$i9 = (($80) - ($87))|0;
   $88 = (($82) + ($$sum$i$i$i$i$i9)|0);
   HEAP32[$76>>2] = $88;
   $89 = ($$sum$i$i$i$i$i9|0)<(0);
   if (!($89)) {
    $$sum1$i$i$i$i$i10 = (($$sum$i$i$i$i$i9) + 1)|0;
    $90 = (($82) + ($$sum1$i$i$i$i$i10)|0);
    $91 = (($transfer) + 20|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($90>>>0)>($92>>>0);
    if (!($93)) {
     $94 = HEAP8[$88>>0]|0;
     HEAP8[$72>>0] = $94;
     $95 = HEAP32[$76>>2]|0;
     $96 = (($95) + 1|0);
     HEAP32[$76>>2] = $96;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($76,$72,1);
  } else {
   $97 = HEAP32[$converter$i$i8>>2]|0;
   $98 = ($97|0)==(0|0);
   if (!($98)) {
    (FUNCTION_TABLE_iii[$97 & 4095]($72,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $99 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$99,765552,0);
 $100 = HEAP32[$99>>2]|0;
 $101 = $100 & -2;
 $102 = ($101|0)==(2);
 $$type$i = $102 ? 1 : $100;
 HEAP32[$99>>2] = $$type$i;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,765608,765608,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,765568,765616,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4PPtrI13AnimationClipE8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 4|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,765568,765616,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4PPtrI13AnimationClipE8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 4|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI13AnimationClipE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,765576,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,765592,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,765576,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,765592,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN9Animation8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i$i = 0, $p$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 $size$i$i$i = sp + 20|0;
 $p$i$i = sp + 16|0;
 __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,3);
 $0 = (($this) + 260|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765480,765616,$0,2048);
 $1 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765576,$6,$0,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765592,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 264|0);
 $19 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765496,$19,$18,2048);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,765608,765608,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765568,765616,$p$i$i,0);
 $20 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $21 = $20;
 $22 = $21;
 HEAP32[$22>>2] = 0;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765576,$6,$p$i$i,1);
 $25 = HEAP32[$7>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$10>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765592,$13,$20,1);
 $29 = HEAP32[$7>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$10>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765512,$6,$33,0);
 $34 = HEAP32[$7>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$10>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($this) + 36|0);
 $39 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765528,$39,$38,2048);
 $40 = HEAP32[$7>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$10>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = (($this) + 37|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765408,$39,$44,0);
 $45 = HEAP32[$7>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$10>>2]|0;
 $48 = ((($46) + (($47*24)|0)|0) + 12|0);
 HEAP32[$48>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $49 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,765552,$6,$49,0);
 $50 = HEAP32[$7>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = HEAP32[$10>>2]|0;
 $53 = ((($51) + (($52*24)|0)|0) + 12|0);
 HEAP32[$53>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN9AnimationD2Ev($this) {
 $this = $this|0;
 var $$5 = 0, $$56 = 0, $$byval_copy11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i55 = 0, $__new_last2$i$i$i$i$i16 = 0, $__new_last2$i$i$i$i$i23 = 0, $__new_last2$i$i$i$i$i30 = 0, $__new_last2$i$i$i$i$i37 = 0, $__new_last2$i$i$i$i$i46 = 0, $__new_last2$i$i$i$i$i64 = 0, $__new_last2$i$i$i$i$i75 = 0, $__new_last2$i$i$i$i$i84 = 0;
 var $__new_last2$i$i$i$i$i9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i56 = 0, $scevgep$i$i$i$i$i10 = 0, $scevgep$i$i$i$i$i17 = 0, $scevgep$i$i$i$i$i24 = 0, $scevgep$i$i$i$i$i31 = 0, $scevgep$i$i$i$i$i38 = 0, $scevgep$i$i$i$i$i47 = 0, $scevgep$i$i$i$i$i65 = 0, $scevgep$i$i$i$i$i76 = 0, $scevgep$i$i$i$i$i85 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i60 = 0, $scevgep4$i$i$i$i$i14 = 0, $scevgep4$i$i$i$i$i21 = 0, $scevgep4$i$i$i$i$i28 = 0, $scevgep4$i$i$i$i$i35 = 0;
 var $scevgep4$i$i$i$i$i42 = 0, $scevgep4$i$i$i$i$i51 = 0, $scevgep4$i$i$i$i$i69 = 0, $scevgep4$i$i$i$i$i80 = 0, $scevgep4$i$i$i$i$i89 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i58 = 0, $uglygep$i$i$i$i$i12 = 0, $uglygep$i$i$i$i$i19 = 0, $uglygep$i$i$i$i$i26 = 0, $uglygep$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i40 = 0, $uglygep$i$i$i$i$i49 = 0, $uglygep$i$i$i$i$i67 = 0, $uglygep$i$i$i$i$i78 = 0, $uglygep$i$i$i$i$i87 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i59 = 0;
 var $uglygep3$i$i$i$i$i13 = 0, $uglygep3$i$i$i$i$i20 = 0, $uglygep3$i$i$i$i$i27 = 0, $uglygep3$i$i$i$i$i34 = 0, $uglygep3$i$i$i$i$i41 = 0, $uglygep3$i$i$i$i$i50 = 0, $uglygep3$i$i$i$i$i68 = 0, $uglygep3$i$i$i$i$i79 = 0, $uglygep3$i$i$i$i$i88 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy11 = sp + 40|0;
 $0 = sp + 36|0;
 $1 = sp + 32|0;
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = sp + 20|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 $9 = sp + 16|0;
 HEAP32[$this>>2] = ((764624 + 8|0));
 __THREW__ = 0;
 invoke_vi(3686,($this|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   $95 = ___cxa_find_matching_catch()|0;
   $96 = tempRet0;
   $97 = (($this) + 276|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==(0|0);
   if (!($99)) {
    $100 = (($this) + 280|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ($101|0)==($98|0);
    if (!($102)) {
     $__new_last2$i$i$i$i$i37 = $98;
     $scevgep$i$i$i$i$i38 = (($101) + -16|0);
     $103 = (0 - ($__new_last2$i$i$i$i$i37))|0;
     $uglygep$i$i$i$i$i40 = (($scevgep$i$i$i$i$i38) + ($103)|0);
     $uglygep3$i$i$i$i$i41 = $uglygep$i$i$i$i$i40;
     $104 = $uglygep3$i$i$i$i$i41 >>> 4;
     $105 = $104 ^ -1;
     $scevgep4$i$i$i$i$i42 = (($101) + ($105<<4)|0);
     HEAP32[$100>>2] = $scevgep4$i$i$i$i$i42;
    }
    HEAP32[$5>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($98|0),($$byval_copy11|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     $108 = ___cxa_find_matching_catch()|0;
     $109 = tempRet0;
     ___cxa_call_unexpected(($108|0));
     // unreachable;
    }
   }
   $110 = (($this) + 264|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = ($111|0)==(0|0);
   if (!($112)) {
    $113 = (($this) + 268|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = ($114|0)==($111|0);
    if (!($115)) {
     $__new_last2$i$i$i$i$i46 = $111;
     $scevgep$i$i$i$i$i47 = (($114) + -4|0);
     $116 = (0 - ($__new_last2$i$i$i$i$i46))|0;
     $uglygep$i$i$i$i$i49 = (($scevgep$i$i$i$i$i47) + ($116)|0);
     $uglygep3$i$i$i$i$i50 = $uglygep$i$i$i$i$i49;
     $117 = $uglygep3$i$i$i$i$i50 >>> 2;
     $118 = $117 ^ -1;
     $scevgep4$i$i$i$i$i51 = (($114) + ($118<<2)|0);
     HEAP32[$113>>2] = $scevgep4$i$i$i$i$i51;
    }
    HEAP32[$4>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($111|0),($$byval_copy11|0));
    $119 = __THREW__; __THREW__ = 0;
    $120 = $119&1;
    if ($120) {
     $121 = ___cxa_find_matching_catch()|0;
     $122 = tempRet0;
     ___cxa_call_unexpected(($121|0));
     // unreachable;
    }
   }
   $123 = (($this) + 248|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)==(0|0);
   if (!($125)) {
    $126 = (($this) + 252|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ($127|0)==($124|0);
    if (!($128)) {
     $__new_last2$i$i$i$i$i$i$i$i$i55 = $124;
     $scevgep$i$i$i$i$i$i$i$i$i56 = (($127) + -4|0);
     $129 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i55))|0;
     $uglygep$i$i$i$i$i$i$i$i$i58 = (($scevgep$i$i$i$i$i$i$i$i$i56) + ($129)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i59 = $uglygep$i$i$i$i$i$i$i$i$i58;
     $130 = $uglygep3$i$i$i$i$i$i$i$i$i59 >>> 2;
     $131 = $130 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i60 = (($127) + ($131<<2)|0);
     HEAP32[$126>>2] = $scevgep4$i$i$i$i$i$i$i$i$i60;
    }
    __ZdlPv($124);
   }
   $132 = (($this) + 88|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($133|0)==(0|0);
   if (!($134)) {
    $135 = (($this) + 92|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = ($136|0)==($133|0);
    if (!($137)) {
     $__new_last2$i$i$i$i$i64 = $133;
     $scevgep$i$i$i$i$i65 = (($136) + -4|0);
     $138 = (0 - ($__new_last2$i$i$i$i$i64))|0;
     $uglygep$i$i$i$i$i67 = (($scevgep$i$i$i$i$i65) + ($138)|0);
     $uglygep3$i$i$i$i$i68 = $uglygep$i$i$i$i$i67;
     $139 = $uglygep3$i$i$i$i$i68 >>> 2;
     $140 = $139 ^ -1;
     $scevgep4$i$i$i$i$i69 = (($136) + ($140<<2)|0);
     HEAP32[$135>>2] = $scevgep4$i$i$i$i$i69;
    }
    HEAP32[$3>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($133|0),($$byval_copy11|0));
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if ($142) {
     $143 = ___cxa_find_matching_catch()|0;
     $144 = tempRet0;
     ___cxa_call_unexpected(($143|0));
     // unreachable;
    }
   }
   $147 = (($this) + 84|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = ($148|0)>(-1);
   if ($149) {
    $150 = (($this) + 72|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = (($this) + 76|0);
    $153 = HEAP32[$152>>2]|0;
    HEAP32[$2>>2] = $153;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($151|0),($$byval_copy11|0));
    $154 = __THREW__; __THREW__ = 0;
    $155 = $154&1;
    if ($155) {
     $184 = ___cxa_find_matching_catch(0|0)|0;
     $185 = tempRet0;
     ___clang_call_terminate($184);
     // unreachable;
    } else {
     HEAP32[$150>>2] = 0;
     $$5 = $96;$$56 = $95;
     break;
    }
   } else {
    $$5 = $96;$$56 = $95;
   }
  } else {
   $12 = (($this) + 276|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    $15 = (($this) + 280|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($13|0);
    if (!($17)) {
     $__new_last2$i$i$i$i$i = $13;
     $scevgep$i$i$i$i$i = (($16) + -16|0);
     $18 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($18)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $19 = $uglygep3$i$i$i$i$i >>> 4;
     $20 = $19 ^ -1;
     $scevgep4$i$i$i$i$i = (($16) + ($20<<4)|0);
     HEAP32[$15>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$9>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$9+0>>2]|0;
    invoke_vii(2591,($13|0),($$byval_copy11|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $23 = ___cxa_find_matching_catch()|0;
     $24 = tempRet0;
     ___cxa_call_unexpected(($23|0));
     // unreachable;
    }
   }
   $25 = (($this) + 264|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if (!($27)) {
    $28 = (($this) + 268|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==($26|0);
    if (!($30)) {
     $__new_last2$i$i$i$i$i9 = $26;
     $scevgep$i$i$i$i$i10 = (($29) + -4|0);
     $31 = (0 - ($__new_last2$i$i$i$i$i9))|0;
     $uglygep$i$i$i$i$i12 = (($scevgep$i$i$i$i$i10) + ($31)|0);
     $uglygep3$i$i$i$i$i13 = $uglygep$i$i$i$i$i12;
     $32 = $uglygep3$i$i$i$i$i13 >>> 2;
     $33 = $32 ^ -1;
     $scevgep4$i$i$i$i$i14 = (($29) + ($33<<2)|0);
     HEAP32[$28>>2] = $scevgep4$i$i$i$i$i14;
    }
    HEAP32[$8>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$8+0>>2]|0;
    invoke_vii(2591,($26|0),($$byval_copy11|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     $36 = ___cxa_find_matching_catch()|0;
     $37 = tempRet0;
     ___cxa_call_unexpected(($36|0));
     // unreachable;
    }
   }
   $38 = (($this) + 248|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    $41 = (($this) + 252|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==($39|0);
    if (!($43)) {
     $__new_last2$i$i$i$i$i$i$i$i$i = $39;
     $scevgep$i$i$i$i$i$i$i$i$i = (($42) + -4|0);
     $44 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($44)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
     $45 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 2;
     $46 = $45 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i = (($42) + ($46<<2)|0);
     HEAP32[$41>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($39);
   }
   $47 = (($this) + 88|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   if (!($49)) {
    $50 = (($this) + 92|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)==($48|0);
    if (!($52)) {
     $__new_last2$i$i$i$i$i16 = $48;
     $scevgep$i$i$i$i$i17 = (($51) + -4|0);
     $53 = (0 - ($__new_last2$i$i$i$i$i16))|0;
     $uglygep$i$i$i$i$i19 = (($scevgep$i$i$i$i$i17) + ($53)|0);
     $uglygep3$i$i$i$i$i20 = $uglygep$i$i$i$i$i19;
     $54 = $uglygep3$i$i$i$i$i20 >>> 2;
     $55 = $54 ^ -1;
     $scevgep4$i$i$i$i$i21 = (($51) + ($55<<2)|0);
     HEAP32[$50>>2] = $scevgep4$i$i$i$i$i21;
    }
    HEAP32[$7>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$7+0>>2]|0;
    invoke_vii(2591,($48|0),($$byval_copy11|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     ___cxa_call_unexpected(($58|0));
     // unreachable;
    }
   }
   $60 = (($this) + 84|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)>(-1);
   do {
    if ($62) {
     $63 = (($this) + 72|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($this) + 76|0);
     $66 = HEAP32[$65>>2]|0;
     HEAP32[$6>>2] = $66;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($64|0),($$byval_copy11|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      $145 = ___cxa_find_matching_catch()|0;
      $146 = tempRet0;
      $$5 = $146;$$56 = $145;
      break L1;
     } else {
      HEAP32[$63>>2] = 0;
      break;
     }
    }
   } while(0);
   $69 = (($this) + 60|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==(0|0);
   if (!($71)) {
    $72 = (($this) + 64|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73|0)==($70|0);
    if (!($74)) {
     $__new_last2$i$i$i$i$i23 = $70;
     $scevgep$i$i$i$i$i24 = (($73) + -4|0);
     $75 = (0 - ($__new_last2$i$i$i$i$i23))|0;
     $uglygep$i$i$i$i$i26 = (($scevgep$i$i$i$i$i24) + ($75)|0);
     $uglygep3$i$i$i$i$i27 = $uglygep$i$i$i$i$i26;
     $76 = $uglygep3$i$i$i$i$i27 >>> 2;
     $77 = $76 ^ -1;
     $scevgep4$i$i$i$i$i28 = (($73) + ($77<<2)|0);
     HEAP32[$72>>2] = $scevgep4$i$i$i$i$i28;
    }
    HEAP32[$1>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($70|0),($$byval_copy11|0));
    $78 = __THREW__; __THREW__ = 0;
    $79 = $78&1;
    if ($79) {
     $80 = ___cxa_find_matching_catch()|0;
     $81 = tempRet0;
     ___cxa_call_unexpected(($80|0));
     // unreachable;
    }
   }
   $82 = (($this) + 44|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($83|0)==(0|0);
   if ($84) {
    __ZN9BehaviourD2Ev($this);
    STACKTOP = sp;return;
   }
   $85 = (($this) + 48|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ($86|0)==($83|0);
   if (!($87)) {
    $__new_last2$i$i$i$i$i30 = $83;
    $scevgep$i$i$i$i$i31 = (($86) + -4|0);
    $88 = (0 - ($__new_last2$i$i$i$i$i30))|0;
    $uglygep$i$i$i$i$i33 = (($scevgep$i$i$i$i$i31) + ($88)|0);
    $uglygep3$i$i$i$i$i34 = $uglygep$i$i$i$i$i33;
    $89 = $uglygep3$i$i$i$i$i34 >>> 2;
    $90 = $89 ^ -1;
    $scevgep4$i$i$i$i$i35 = (($86) + ($90<<2)|0);
    HEAP32[$85>>2] = $scevgep4$i$i$i$i$i35;
   }
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($83|0),($$byval_copy11|0));
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   if ($92) {
    $93 = ___cxa_find_matching_catch()|0;
    $94 = tempRet0;
    ___cxa_call_unexpected(($93|0));
    // unreachable;
   } else {
    __ZN9BehaviourD2Ev($this);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $156 = (($this) + 60|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = ($157|0)==(0|0);
 if (!($158)) {
  $159 = (($this) + 64|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = ($160|0)==($157|0);
  if (!($161)) {
   $__new_last2$i$i$i$i$i75 = $157;
   $scevgep$i$i$i$i$i76 = (($160) + -4|0);
   $162 = (0 - ($__new_last2$i$i$i$i$i75))|0;
   $uglygep$i$i$i$i$i78 = (($scevgep$i$i$i$i$i76) + ($162)|0);
   $uglygep3$i$i$i$i$i79 = $uglygep$i$i$i$i$i78;
   $163 = $uglygep3$i$i$i$i$i79 >>> 2;
   $164 = $163 ^ -1;
   $scevgep4$i$i$i$i$i80 = (($160) + ($164<<2)|0);
   HEAP32[$159>>2] = $scevgep4$i$i$i$i$i80;
  }
  HEAP32[$1>>2] = 18;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($157|0),($$byval_copy11|0));
  $165 = __THREW__; __THREW__ = 0;
  $166 = $165&1;
  if ($166) {
   $167 = ___cxa_find_matching_catch()|0;
   $168 = tempRet0;
   ___cxa_call_unexpected(($167|0));
   // unreachable;
  }
 }
 $169 = (($this) + 44|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = ($170|0)==(0|0);
 if (!($171)) {
  $172 = (($this) + 48|0);
  $173 = HEAP32[$172>>2]|0;
  $174 = ($173|0)==($170|0);
  if (!($174)) {
   $__new_last2$i$i$i$i$i84 = $170;
   $scevgep$i$i$i$i$i85 = (($173) + -4|0);
   $175 = (0 - ($__new_last2$i$i$i$i$i84))|0;
   $uglygep$i$i$i$i$i87 = (($scevgep$i$i$i$i$i85) + ($175)|0);
   $uglygep3$i$i$i$i$i88 = $uglygep$i$i$i$i$i87;
   $176 = $uglygep3$i$i$i$i$i88 >>> 2;
   $177 = $176 ^ -1;
   $scevgep4$i$i$i$i$i89 = (($173) + ($177<<2)|0);
   HEAP32[$172>>2] = $scevgep4$i$i$i$i$i89;
  }
  HEAP32[$0>>2] = 18;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($170|0),($$byval_copy11|0));
  $178 = __THREW__; __THREW__ = 0;
  $179 = $178&1;
  if ($179) {
   $180 = ___cxa_find_matching_catch()|0;
   $181 = tempRet0;
   ___cxa_call_unexpected(($180|0));
   // unreachable;
  }
 }
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $182 = __THREW__; __THREW__ = 0;
 $183 = $182&1;
 if ($183) {
  $184 = ___cxa_find_matching_catch(0|0)|0;
  $185 = tempRet0;
  ___clang_call_terminate($184);
  // unreachable;
 } else {
  ___resumeException($$56|0);
  // unreachable;
 }
}
function __ZL16AssignBoundCurveRK14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS0_EE13stl_allocatorINS2_4pairIKS0_jEEL18MemLabelIdentifier90ELi16EEERS7_P17AnimationCurveTplIfERK13dynamic_arrayI20BoundCurveDeprecatedLj4EER14AnimationState($curveIDLookup,$curveID,$curve,$boundCurves,$state) {
 $curveIDLookup = $curveIDLookup|0;
 $curveID = $curveID|0;
 $curve = $curve|0;
 $boundCurves = $boundCurves|0;
 $state = $state|0;
 var $$off$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $boundCurves$idx$val = 0, $pos$i$i = 0, $switch$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i = sp + 24|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = (($curveIDLookup) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($curveIDLookup) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 do {
  if ($6) {
   $7 = (($curveIDLookup) + 60|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($curveIDLookup) + 64|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($8) + (($10*24)|0)|0);
   __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_EC1EPK15dense_hashtableIS4_S2_S5_SD_S8_SB_EPKS4_SK_b($0,$curveIDLookup,$11,$11,1);
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E13find_positionERS3_($pos$i$i,$curveIDLookup,$curveID);
   $12 = HEAP32[$pos$i$i>>2]|0;
   $13 = ($12|0)==(-1);
   $14 = (($curveIDLookup) + 60|0);
   $15 = HEAP32[$14>>2]|0;
   if ($13) {
    $16 = (($curveIDLookup) + 64|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + (($17*24)|0)|0);
    __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_EC1EPK15dense_hashtableIS4_S2_S5_SD_S8_SB_EPKS4_SK_b($0,$curveIDLookup,$18,$18,1);
    break;
   } else {
    $19 = (($15) + (($12*24)|0)|0);
    $20 = (($curveIDLookup) + 64|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($15) + (($21*24)|0)|0);
    HEAP32[$0>>2] = $curveIDLookup;
    $23 = (($0) + 4|0);
    HEAP32[$23>>2] = $19;
    $24 = (($0) + 8|0);
    HEAP32[$24>>2] = $22;
    break;
   }
  }
 } while(0);
 $25 = (($0) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($curveIDLookup) + 60|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($curveIDLookup) + 64|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + (($30*24)|0)|0);
 __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_EC1EPK15dense_hashtableIS4_S2_S5_SD_S8_SB_EPKS4_SK_b($1,$curveIDLookup,$31,$31,1);
 $32 = (($1) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($26|0)==($33|0);
 if ($34) {
  STACKTOP = sp;return;
 }
 $35 = (($26) + 20|0);
 $36 = HEAP32[$35>>2]|0;
 $boundCurves$idx$val = HEAP32[$boundCurves>>2]|0;
 $37 = ((($boundCurves$idx$val) + (($36*20)|0)|0) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $$off$i = (($38) + -1)|0;
 $switch$i = ($$off$i>>>0)<(3);
 do {
  if ($switch$i) {
   $39 = ((($boundCurves$idx$val) + (($36*20)|0)|0) + 16|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (__ZN14AnimationState18ShouldMixTransformER9Transform($state,$40)|0);
   if ($41) {
    $$pre = HEAP32[$35>>2]|0;
    $45 = $$pre;
    break;
   } else {
    STACKTOP = sp;return;
   }
  } else {
   $45 = $36;
  }
 } while(0);
 $42 = (($state) + 4|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + ($45<<2)|0);
 HEAP32[$44>>2] = $curve;
 STACKTOP = sp;return;
}
function __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_EC1EPK15dense_hashtableIS4_S2_S5_SD_S8_SB_EPKS4_SK_b($this,$h,$it,$it_end,$advance) {
 $this = $this|0;
 $h = $h|0;
 $it = $it|0;
 $it_end = $it_end|0;
 $advance = $advance|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $advance$not$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $h;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $it;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $it_end;
 $advance$not$i = $advance ^ 1;
 $2 = ($it|0)==($it_end|0);
 $or$cond$i = $2 | $advance$not$i;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 }
 $3 = (($h) + 4|0);
 $4 = (($h) + 16|0);
 $5 = (($h) + 12|0);
 $6 = (($h) + 20|0);
 $7 = (($h) + 24|0);
 $8 = (($h) + 52|0);
 $9 = (($h) + 40|0);
 $10 = (($h) + 36|0);
 $11 = (($h) + 44|0);
 $12 = (($h) + 48|0);
 $13 = (($h) + 8|0);
 $14 = (($h) + 28|0);
 $$pre = HEAP32[$8>>2]|0;
 $16 = $it;
 while(1) {
  $15 = (($16) + 16|0);
  $17 = HEAP32[$15>>2]|0;
  $18 = ($$pre|0)==($17|0);
  if ($18) {
   $19 = HEAP32[$9>>2]|0;
   $20 = (($16) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)==($21|0);
   if ($22) {
    $23 = HEAP32[$10>>2]|0;
    $24 = HEAP32[$16>>2]|0;
    $25 = (_strcmp($23,$24)|0);
    $26 = ($25|0)==(0);
    if ($26) {
     $27 = HEAP32[$11>>2]|0;
     $28 = (($16) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (_strcmp($27,$29)|0);
     $31 = ($30|0)==(0);
     if ($31) {
      $32 = HEAP32[$12>>2]|0;
      $33 = (($16) + 12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($32|0)==($34|0);
      if (!($35)) {
       label = 8;
      }
     } else {
      label = 8;
     }
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
  if ((label|0) == 8) {
   label = 0;
   $36 = HEAP8[$13>>0]|0;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    label = 16;
    break;
   }
   $38 = HEAP32[$3>>2]|0;
   $39 = ($38|0)==(0);
   if ($39) {
    label = 16;
    break;
   }
   $40 = HEAP32[$14>>2]|0;
   $41 = ($40|0)==($17|0);
   if (!($41)) {
    label = 16;
    break;
   }
   $42 = HEAP32[$4>>2]|0;
   $43 = (($16) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($42|0)==($44|0);
   if (!($45)) {
    label = 16;
    break;
   }
   $46 = HEAP32[$5>>2]|0;
   $47 = HEAP32[$16>>2]|0;
   $48 = (_strcmp($46,$47)|0);
   $49 = ($48|0)==(0);
   if (!($49)) {
    label = 16;
    break;
   }
   $50 = HEAP32[$6>>2]|0;
   $51 = (($16) + 8|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (_strcmp($50,$52)|0);
   $54 = ($53|0)==(0);
   if (!($54)) {
    label = 16;
    break;
   }
   $55 = HEAP32[$7>>2]|0;
   $56 = (($16) + 12|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($55|0)==($57|0);
   if (!($58)) {
    label = 16;
    break;
   }
  }
  $59 = (($16) + 24|0);
  HEAP32[$0>>2] = $59;
  $60 = ($59|0)==($it_end|0);
  if ($60) {
   label = 16;
   break;
  } else {
   $16 = $59;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZNK15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E13find_positionERS3_($agg$result,$this,$key) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $key = $key|0;
 var $$ = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $num_probes$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = (($key) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 40|0);
 $10 = (($this) + 36|0);
 $11 = (($this) + 44|0);
 $12 = (($this) + 48|0);
 $13 = (($this) + 8|0);
 $14 = (($key) + 4|0);
 $15 = (($key) + 8|0);
 $16 = (($key) + 12|0);
 $17 = (($this) + 4|0);
 $18 = (($this) + 28|0);
 $19 = (($this) + 16|0);
 $20 = (($this) + 12|0);
 $21 = (($this) + 20|0);
 $22 = (($this) + 24|0);
 $$sink = $4;$46 = -1;$num_probes$0 = 0;
 while(1) {
  $23 = $$sink & $2;
  $24 = ((($6) + (($23*24)|0)|0) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($8|0)==($25|0);
  if ($26) {
   $27 = HEAP32[$9>>2]|0;
   $28 = ((($6) + (($23*24)|0)|0) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)==($29|0);
   if ($30) {
    $31 = HEAP32[$10>>2]|0;
    $32 = (($6) + (($23*24)|0)|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (_strcmp($31,$33)|0);
    $35 = ($34|0)==(0);
    if ($35) {
     $36 = HEAP32[$11>>2]|0;
     $37 = ((($6) + (($23*24)|0)|0) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (_strcmp($36,$38)|0);
     $40 = ($39|0)==(0);
     if ($40) {
      $41 = HEAP32[$12>>2]|0;
      $42 = ((($6) + (($23*24)|0)|0) + 12|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = ($41|0)==($43|0);
      if ($44) {
       break;
      }
     }
    }
   }
  }
  $48 = HEAP8[$13>>0]|0;
  $49 = ($48<<24>>24)==(0);
  if ($49) {
   label = 18;
  } else {
   $50 = HEAP32[$17>>2]|0;
   $51 = ($50|0)==(0);
   if ($51) {
    label = 18;
   } else {
    $52 = HEAP32[$18>>2]|0;
    $53 = ($52|0)==($25|0);
    if ($53) {
     $54 = HEAP32[$19>>2]|0;
     $55 = ((($6) + (($23*24)|0)|0) + 4|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($54|0)==($56|0);
     if ($57) {
      $58 = HEAP32[$20>>2]|0;
      $59 = (($6) + (($23*24)|0)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = (_strcmp($58,$60)|0);
      $62 = ($61|0)==(0);
      if ($62) {
       $63 = HEAP32[$21>>2]|0;
       $64 = ((($6) + (($23*24)|0)|0) + 8|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = (_strcmp($63,$65)|0);
       $67 = ($66|0)==(0);
       if ($67) {
        $68 = HEAP32[$22>>2]|0;
        $69 = ((($6) + (($23*24)|0)|0) + 12|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($68|0)==($70|0);
        if ($71) {
         $72 = ($46|0)==(-1);
         $$ = $72 ? $23 : $46;
         $95 = $$;
        } else {
         label = 18;
        }
       } else {
        label = 18;
       }
      } else {
       label = 18;
      }
     } else {
      label = 18;
     }
    } else {
     label = 18;
    }
   }
  }
  if ((label|0) == 18) {
   label = 0;
   $73 = ($4|0)==($25|0);
   if ($73) {
    $74 = HEAP32[$14>>2]|0;
    $75 = ((($6) + (($23*24)|0)|0) + 4|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($74|0)==($76|0);
    if ($77) {
     $78 = HEAP32[$key>>2]|0;
     $79 = (($6) + (($23*24)|0)|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (_strcmp($78,$80)|0);
     $82 = ($81|0)==(0);
     if ($82) {
      $83 = HEAP32[$15>>2]|0;
      $84 = ((($6) + (($23*24)|0)|0) + 8|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = (_strcmp($83,$85)|0);
      $87 = ($86|0)==(0);
      if ($87) {
       $88 = HEAP32[$16>>2]|0;
       $89 = ((($6) + (($23*24)|0)|0) + 12|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = ($88|0)==($90|0);
       if ($91) {
        label = 23;
        break;
       } else {
        $95 = $46;
       }
      } else {
       $95 = $46;
      }
     } else {
      $95 = $46;
     }
    } else {
     $95 = $46;
    }
   } else {
    $95 = $46;
   }
  }
  $93 = (($num_probes$0) + 1)|0;
  $94 = (($93) + ($23))|0;
  $$sink = $94;$46 = $95;$num_probes$0 = $93;
 }
 if ((label|0) == 23) {
  HEAP32[$agg$result>>2] = $23;
  $92 = (($agg$result) + 4|0);
  HEAP32[$92>>2] = -1;
  STACKTOP = sp;return;
 }
 $45 = ($46|0)==(-1);
 HEAP32[$agg$result>>2] = -1;
 $47 = (($agg$result) + 4|0);
 if ($45) {
  HEAP32[$47>>2] = $23;
  STACKTOP = sp;return;
 } else {
  HEAP32[$47>>2] = $46;
  STACKTOP = sp;return;
 }
}
function __ZN15AnimationBinder17InitCurveIDLookupER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEE($curveIDLookup) {
 $curveIDLookup = $curveIDLookup|0;
 var $$01$i$i$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($curveIDLookup) + 9|0);
 HEAP8[$2>>0] = 1;
 $3 = (($curveIDLookup) + 36|0);
 $4 = (($curveIDLookup) + 36|0);
 HEAP32[$4>>2] = 765640;
 $5 = (($curveIDLookup) + 40|0);
 HEAP32[$5>>2] = -1;
 $6 = (($curveIDLookup) + 44|0);
 HEAP32[$6>>2] = 765640;
 $7 = (($curveIDLookup) + 48|0);
 HEAP32[$7>>2] = 0;
 $8 = (($curveIDLookup) + 52|0);
 HEAP32[$8>>2] = 0;
 $9 = (($curveIDLookup) + 56|0);
 HEAP32[$9>>2] = 0;
 $10 = (($curveIDLookup) + 64|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11*24)|0;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $13 = (__Z15malloc_internaljj10MemLabelIdiPKci($12,16,$$byval_copy,0,765640,79)|0);
 $14 = (($curveIDLookup) + 60|0);
 HEAP32[$14>>2] = $13;
 $15 = HEAP32[$10>>2]|0;
 $16 = (($13) + (($15*24)|0)|0);
 $17 = ($13|0)==($16|0);
 if (!($17)) {
  $$01$i$i$i$i = $13;
  while(1) {
   $18 = ($$01$i$i$i$i|0)==(0|0);
   if (!($18)) {
    ;HEAP32[$$01$i$i$i$i+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$01$i$i$i$i+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$01$i$i$i$i+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$01$i$i$i$i+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$$01$i$i$i$i+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$$01$i$i$i$i+20>>2]=HEAP32[$3+20>>2]|0;
   }
   $19 = (($$01$i$i$i$i) + 24|0);
   $20 = ($19|0)==($16|0);
   if ($20) {
    break;
   } else {
    $$01$i$i$i$i = $19;
   }
  }
 }
 HEAP32[$1>>2] = 765640;
 $21 = (($1) + 8|0);
 HEAP32[$21>>2] = 765640;
 $22 = (($1) + 4|0);
 HEAP32[$22>>2] = -1;
 $23 = (($1) + 12|0);
 HEAP32[$23>>2] = 0;
 $24 = (($1) + 16|0);
 HEAP32[$24>>2] = 1;
 __ZN14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS0_EE13stl_allocatorINS2_4pairIKS0_jEEL18MemLabelIdentifier90ELi16EEE15set_deleted_keyERS7_($curveIDLookup,$1);
 $25 = (($curveIDLookup) + 80|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if (!($27)) {
  __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E12maybe_shrinkEv($curveIDLookup);
 }
 $28 = (($curveIDLookup) + 68|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29>>>0)<(1024);
 if (!($30)) {
  STACKTOP = sp;return;
 }
 $31 = (1024 - ($29))|0;
 __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E12resize_deltaEjj($curveIDLookup,$31,0);
 STACKTOP = sp;return;
}
function __ZN14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS0_EE13stl_allocatorINS2_4pairIKS0_jEEL18MemLabelIdentifier90ELi16EEE15set_deleted_keyERS7_($this,$key) {
 $this = $this|0;
 $key = $key|0;
 var $$byval_copy = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre$phi4$iZ2D = 0, $$pre1$i = 0, $$sroa$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp$i$i = 0, $tmp1$sroa$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy = sp + 48|0;
 $tmp1$sroa$0$i = sp;
 $tmp$i$i = sp + 68|0;
 $$sroa$0 = sp + 24|0;
 ;HEAP32[$$sroa$0+0>>2]=HEAP32[$key+0>>2]|0;HEAP32[$$sroa$0+4>>2]=HEAP32[$key+4>>2]|0;HEAP32[$$sroa$0+8>>2]=HEAP32[$key+8>>2]|0;HEAP32[$$sroa$0+12>>2]=HEAP32[$key+12>>2]|0;HEAP32[$$sroa$0+16>>2]=HEAP32[$key+16>>2]|0;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$pre$i = (($this) + 8|0);
  $$pre1$i = (($this) + 12|0);
  $$pre$phi$iZ2D = $$pre$i;$$pre$phi4$iZ2D = $$pre1$i;
  HEAP8[$$pre$phi$iZ2D>>0] = 1;
  ;HEAP32[$$pre$phi4$iZ2D+0>>2]=HEAP32[$$sroa$0+0>>2]|0;HEAP32[$$pre$phi4$iZ2D+4>>2]=HEAP32[$$sroa$0+4>>2]|0;HEAP32[$$pre$phi4$iZ2D+8>>2]=HEAP32[$$sroa$0+8>>2]|0;HEAP32[$$pre$phi4$iZ2D+12>>2]=HEAP32[$$sroa$0+12>>2]|0;HEAP32[$$pre$phi4$iZ2D+16>>2]=HEAP32[$$sroa$0+16>>2]|0;
  $57 = (($$pre$phi4$iZ2D) + 20|0);
  HEAP32[$57>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($tmp$i$i) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tmp$i$i) + 8|0);
 $5 = (($this) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 HEAP8[$4>>0] = $6;
 $7 = (($tmp$i$i) + 9|0);
 $8 = (($this) + 9|0);
 $9 = HEAP8[$8>>0]|0;
 HEAP8[$7>>0] = $9;
 $10 = (($tmp$i$i) + 12|0);
 $11 = (($this) + 12|0);
 ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$10+16>>2]=HEAP32[$11+16>>2]|0;HEAP32[$10+20>>2]=HEAP32[$11+20>>2]|0;
 $12 = (($tmp$i$i) + 36|0);
 $13 = (($this) + 36|0);
 ;HEAP32[$12+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$13+16>>2]|0;HEAP32[$12+20>>2]=HEAP32[$13+20>>2]|0;
 $14 = (($tmp$i$i) + 60|0);
 ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;HEAP32[$14+16>>2]=0|0;HEAP8[$14+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E9copy_fromERKSE_j($tmp$i$i,$this,0);
 $15 = HEAP32[$0>>2]|0;
 $16 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $16;
 HEAP32[$3>>2] = $15;
 $17 = HEAP8[$5>>0]|0;
 $18 = HEAP16[$4>>1]|0;
 $19 = $18&255;
 HEAP8[$5>>0] = $19;
 HEAP8[$4>>0] = $17;
 $20 = HEAP8[$8>>0]|0;
 $21 = ($18&65535) >>> 8;
 $22 = $21&255;
 HEAP8[$8>>0] = $22;
 HEAP8[$7>>0] = $20;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$11+16>>2]|0;
 $23 = (($this) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 ;HEAP32[$11+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$11+16>>2]=HEAP32[$10+16>>2]|0;HEAP32[$11+20>>2]=HEAP32[$10+20>>2]|0;
 ;HEAP32[$10+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$$byval_copy+12>>2]|0;HEAP32[$10+16>>2]=HEAP32[$$byval_copy+16>>2]|0;
 $25 = (($tmp$i$i) + 32|0);
 HEAP32[$25>>2] = $24;
 ;HEAP32[$tmp1$sroa$0$i+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$tmp1$sroa$0$i+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$tmp1$sroa$0$i+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$tmp1$sroa$0$i+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$tmp1$sroa$0$i+16>>2]=HEAP32[$13+16>>2]|0;
 $26 = (($this) + 56|0);
 $27 = HEAP32[$26>>2]|0;
 ;HEAP32[$13+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$13+16>>2]=HEAP32[$12+16>>2]|0;HEAP32[$13+20>>2]=HEAP32[$12+20>>2]|0;
 ;HEAP32[$12+0>>2]=HEAP32[$tmp1$sroa$0$i+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$tmp1$sroa$0$i+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$tmp1$sroa$0$i+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$tmp1$sroa$0$i+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$tmp1$sroa$0$i+16>>2]|0;
 $28 = (($tmp$i$i) + 56|0);
 HEAP32[$28>>2] = $27;
 $29 = (($this) + 60|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$14>>2]|0;
 HEAP32[$29>>2] = $31;
 HEAP32[$14>>2] = $30;
 $32 = (($this) + 64|0);
 $33 = (($tmp$i$i) + 64|0);
 $34 = HEAP32[$32>>2]|0;
 $35 = HEAP32[$33>>2]|0;
 HEAP32[$32>>2] = $35;
 HEAP32[$33>>2] = $34;
 $36 = (($this) + 68|0);
 $37 = (($tmp$i$i) + 68|0);
 $38 = HEAP32[$36>>2]|0;
 $39 = HEAP32[$37>>2]|0;
 HEAP32[$36>>2] = $39;
 HEAP32[$37>>2] = $38;
 $40 = (Math_fround(($35>>>0)));
 $41 = Math_fround($40 * Math_fround(0.5));
 $42 = (~~(($41))>>>0);
 $43 = (($this) + 76|0);
 HEAP32[$43>>2] = $42;
 $44 = Math_fround($40 * Math_fround(0.20000000298023223877));
 $45 = (~~(($44))>>>0);
 $46 = (($this) + 72|0);
 HEAP32[$46>>2] = $45;
 $47 = (($this) + 80|0);
 HEAP8[$47>>0] = 0;
 $48 = (Math_fround(($34>>>0)));
 $49 = Math_fround($48 * Math_fround(0.5));
 $50 = (~~(($49))>>>0);
 $51 = (($tmp$i$i) + 76|0);
 HEAP32[$51>>2] = $50;
 $52 = Math_fround($48 * Math_fround(0.20000000298023223877));
 $53 = (~~(($52))>>>0);
 $54 = (($tmp$i$i) + 72|0);
 HEAP32[$54>>2] = $53;
 $55 = (($tmp$i$i) + 80|0);
 HEAP8[$55>>0] = 0;
 $56 = ($30|0)==(0|0);
 if ($56) {
  $$pre$phi$iZ2D = $5;$$pre$phi4$iZ2D = $11;
  HEAP8[$$pre$phi$iZ2D>>0] = 1;
  ;HEAP32[$$pre$phi4$iZ2D+0>>2]=HEAP32[$$sroa$0+0>>2]|0;HEAP32[$$pre$phi4$iZ2D+4>>2]=HEAP32[$$sroa$0+4>>2]|0;HEAP32[$$pre$phi4$iZ2D+8>>2]=HEAP32[$$sroa$0+8>>2]|0;HEAP32[$$pre$phi4$iZ2D+12>>2]=HEAP32[$$sroa$0+12>>2]|0;HEAP32[$$pre$phi4$iZ2D+16>>2]=HEAP32[$$sroa$0+16>>2]|0;
  $57 = (($$pre$phi4$iZ2D) + 20|0);
  HEAP32[$57>>2] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$tmp1$sroa$0$i>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$tmp1$sroa$0$i+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($30,$$byval_copy);
 $$pre$phi$iZ2D = $5;$$pre$phi4$iZ2D = $11;
 HEAP8[$$pre$phi$iZ2D>>0] = 1;
 ;HEAP32[$$pre$phi4$iZ2D+0>>2]=HEAP32[$$sroa$0+0>>2]|0;HEAP32[$$pre$phi4$iZ2D+4>>2]=HEAP32[$$sroa$0+4>>2]|0;HEAP32[$$pre$phi4$iZ2D+8>>2]=HEAP32[$$sroa$0+8>>2]|0;HEAP32[$$pre$phi4$iZ2D+12>>2]=HEAP32[$$sroa$0+12>>2]|0;HEAP32[$$pre$phi4$iZ2D+16>>2]=HEAP32[$$sroa$0+16>>2]|0;
 $57 = (($$pre$phi4$iZ2D) + 20|0);
 HEAP32[$57>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15AnimationBinder18CalculateTargetPtrEiP6ObjectPKcPPvPi($this,$classID,$targetObject,$attribute,$targetPtr,$type) {
 $this = $this|0;
 $classID = $classID|0;
 $targetObject = $targetObject|0;
 $attribute = $attribute|0;
 $targetPtr = $targetPtr|0;
 $type = $type|0;
 var $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i15 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$02 = 0, $$02$i$i$i = 0, $$03 = 0, $$04 = 0, $$byval_copy2 = 0, $$pn$i$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$lcssa$i$i$i = 0, $__p$0$ph$i$i$i = 0, $__p$01$i$i$i = 0, $__rt$0$in$i$i = 0, $__rt$0$in$in$be$i$i = 0, $__rt$0$in1$i$i = 0, $__rt$0$in2$i$i = 0, $a$0 = 0, $a$1 = 0, $a$2 = 0, $dotIndex$0 = 0, $dotIndex$1 = 0, $materialIndex$0 = 0, $newTargetType$017 = 0, $not$ = 0, $phitmp = 0;
 var $scevgep$i$i$i = 0, $scevgep3$i$i$i = 0, $scevgep4$i$i$i = 0, $shaderPropertyIndex$018 = 0, $targetIndex$016 = 0, $typeTree$0 = 0, $variable$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp + 56|0;
 $0 = sp;
 $variable$i = sp + 8|0;
 $1 = sp + 16|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $4 = sp + 40|0;
 $5 = sp + 52|0;
 HEAP32[$2>>2] = $classID;
 L1: do {
  if ((($classID|0) == 4)) {
   $6 = (_strcmp($attribute,765648)|0);
   $7 = ($6|0)==(0);
   if ($7) {
    HEAP32[$type>>2] = 1;
    $8 = (($targetObject) + 44|0);
    HEAP32[$targetPtr>>2] = $8;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $9 = (_strcmp($attribute,765664)|0);
   $10 = ($9|0)==(0);
   if ($10) {
    HEAP32[$type>>2] = 3;
    $11 = (($targetObject) + 56|0);
    HEAP32[$targetPtr>>2] = $11;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $12 = (_strcmp($attribute,765680)|0);
   $13 = ($12|0)==(0);
   if ($13) {
    HEAP32[$type>>2] = 2;
    $14 = (($targetObject) + 28|0);
    HEAP32[$targetPtr>>2] = $14;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  } else if ((($classID|0) == 21)) {
   $15 = HEAP8[$attribute>>0]|0;
   $16 = ($15<<24>>24)==(91);
   do {
    if ($16) {
     $185 = 91;$a$0 = $attribute;
     while(1) {
      if ((($185<<24>>24) == 46)) {
       label = 11;
       break;
      } else if ((($185<<24>>24) == 0)) {
       $$0 = 0;
       label = 97;
       break;
      }
      $17 = (($a$0) + 1|0);
      $$pre = HEAP8[$17>>0]|0;
      $185 = $$pre;$a$0 = $17;
     }
     if ((label|0) == 11) {
      $18 = (($attribute) + 1|0);
      $19 = (__Z11StringToIntPKc($18)|0);
      $20 = (($a$0) + 1|0);
      $phitmp = $19;
      $$02 = $20;$a$1 = $a$0;$materialIndex$0 = $phitmp;
      break;
     }
     else if ((label|0) == 97) {
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     $$02 = $attribute;$a$1 = $attribute;$materialIndex$0 = 0;
    }
   } while(0);
   $21 = $$02;
   $a$2 = $a$1;$dotIndex$0 = -1;
   while(1) {
    $22 = HEAP8[$a$2>>0]|0;
    if ((($22<<24>>24) == 0)) {
     break;
    } else if ((($22<<24>>24) == 46)) {
     $23 = ($dotIndex$0|0)==(-1);
     if ($23) {
      $24 = $a$2;
      $25 = (($24) - ($21))|0;
      $dotIndex$1 = $25;
     } else {
      $dotIndex$1 = $dotIndex$0;
     }
    } else {
     $dotIndex$1 = $dotIndex$0;
    }
    $26 = (($a$2) + 1|0);
    $a$2 = $26;$dotIndex$0 = $dotIndex$1;
   }
   $27 = (($a$2) + -1|0);
   $28 = ($dotIndex$0|0)==(-1);
   L29: do {
    if ($28) {
     HEAP32[$$byval_copy2>>2] = -1;
     __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy2,$$02);
     $29 = HEAP32[$$byval_copy2>>2]|0;
     $newTargetType$017 = 11;$shaderPropertyIndex$018 = $29;$targetIndex$016 = 0;
    } else {
     $30 = (($$02) + ($dotIndex$0)|0);
     $31 = ($dotIndex$0>>>0)>(4294967279);
     if ($31) {
      __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
      // unreachable;
     }
     $32 = ($dotIndex$0>>>0)<(11);
     if ($32) {
      $33 = $dotIndex$0 << 1;
      $34 = $33&255;
      HEAP8[$3>>0] = $34;
      $35 = (($3) + 1|0);
      $__p$0$ph$i$i$i = $35;
     } else {
      $36 = (($dotIndex$0) + 16)|0;
      $37 = $36 & -16;
      $38 = (__Znwj($37)|0);
      $39 = (($3) + 8|0);
      HEAP32[$39>>2] = $38;
      $40 = $37 | 1;
      HEAP32[$3>>2] = $40;
      $41 = (($3) + 4|0);
      HEAP32[$41>>2] = $dotIndex$0;
      $__p$0$ph$i$i$i = $38;
     }
     $42 = ($dotIndex$0|0)==(0);
     if ($42) {
      $__p$0$lcssa$i$i$i = $__p$0$ph$i$i$i;
     } else {
      $$02$i$i$i = $$02;$__p$01$i$i$i = $__p$0$ph$i$i$i;
      while(1) {
       $43 = HEAP8[$$02$i$i$i>>0]|0;
       HEAP8[$__p$01$i$i$i>>0] = $43;
       $44 = (($$02$i$i$i) + 1|0);
       $45 = (($__p$01$i$i$i) + 1|0);
       $46 = ($44|0)==($30|0);
       if ($46) {
        break;
       } else {
        $$02$i$i$i = $44;$__p$01$i$i$i = $45;
       }
      }
      $$sum = (($dotIndex$0) - ($21))|0;
      $scevgep$i$i$i = (($$02) + ($$sum)|0);
      $scevgep3$i$i$i = $scevgep$i$i$i;
      $scevgep4$i$i$i = (($__p$0$ph$i$i$i) + ($scevgep3$i$i$i)|0);
      $__p$0$lcssa$i$i$i = $scevgep4$i$i$i;
     }
     HEAP8[$__p$0$lcssa$i$i$i>>0] = 0;
     HEAP32[$$byval_copy2>>2] = -1;
     $47 = HEAP8[$3>>0]|0;
     $48 = $47 & 1;
     $49 = ($48<<24>>24)==(0);
     if ($49) {
      $52 = (($3) + 1|0);
      $53 = $52;
     } else {
      $50 = (($3) + 8|0);
      $51 = HEAP32[$50>>2]|0;
      $53 = $51;
     }
     __THREW__ = 0;
     invoke_vii(2618,($$byval_copy2|0),($53|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      $66 = ___cxa_find_matching_catch()|0;
      $67 = tempRet0;
      $68 = HEAP8[$3>>0]|0;
      $69 = $68 & 1;
      $70 = ($69<<24>>24)==(0);
      if ($70) {
       $$03 = $67;$$04 = $66;
       ___resumeException($$04|0);
       // unreachable;
      }
      $71 = (($3) + 8|0);
      $72 = HEAP32[$71>>2]|0;
      __ZdlPv($72);
      $$03 = $67;$$04 = $66;
      ___resumeException($$04|0);
      // unreachable;
     }
     $56 = HEAP32[$$byval_copy2>>2]|0;
     $57 = HEAP8[$3>>0]|0;
     $58 = $57 & 1;
     $59 = ($58<<24>>24)==(0);
     if (!($59)) {
      $60 = (($3) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      __ZdlPv($61);
     }
     $62 = (($dotIndex$0) + 1)|0;
     $63 = (($$02) + ($62)|0);
     $64 = HEAP8[$63>>0]|0;
     $65 = $64 << 24 >> 24;
     switch ($65|0) {
     case 119: case 97:  {
      $newTargetType$017 = 12;$shaderPropertyIndex$018 = $56;$targetIndex$016 = 805306368;
      break L29;
      break;
     }
     case 115:  {
      $73 = HEAP8[$27>>0]|0;
      $74 = ($73<<24>>24)==(120);
      $75 = $74 ? 0 : 268435456;
      $newTargetType$017 = 13;$shaderPropertyIndex$018 = $56;$targetIndex$016 = $75;
      break L29;
      break;
     }
     case 111:  {
      $76 = HEAP8[$27>>0]|0;
      $77 = ($76<<24>>24)==(120);
      $78 = $77 ? 536870912 : 805306368;
      $newTargetType$017 = 13;$shaderPropertyIndex$018 = $56;$targetIndex$016 = $78;
      break L29;
      break;
     }
     case 120:  {
      $newTargetType$017 = 12;$shaderPropertyIndex$018 = $56;$targetIndex$016 = 0;
      break L29;
      break;
     }
     case 122: case 98:  {
      $newTargetType$017 = 12;$shaderPropertyIndex$018 = $56;$targetIndex$016 = 536870912;
      break L29;
      break;
     }
     case 114:  {
      $not$ = ($27|0)==($63|0);
      if ($not$) {
       $newTargetType$017 = 12;$shaderPropertyIndex$018 = $56;$targetIndex$016 = 0;
       break L29;
      }
      break;
     }
     case 121: case 103:  {
      $newTargetType$017 = 12;$shaderPropertyIndex$018 = $56;$targetIndex$016 = 268435456;
      break L29;
      break;
     }
     default: {
     }
     }
     HEAP32[$targetPtr>>2] = 0;
     HEAP32[$type>>2] = 0;
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $79 = $shaderPropertyIndex$018 << 4;
   $80 = $79 | $newTargetType$017;
   $81 = $80 | $targetIndex$016;
   HEAP32[$targetPtr>>2] = $materialIndex$0;
   HEAP32[$type>>2] = $81;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else if ((($classID|0) == 137)) {
   $84 = (_strlen(($attribute|0))|0);
   $85 = ($84>>>0)>(4294967279);
   if ($85) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $86 = ($84>>>0)<(11);
   if ($86) {
    $87 = $84 << 1;
    $88 = $87&255;
    HEAP8[$4>>0] = $88;
    $89 = (($4) + 1|0);
    $$pre$phiZ2D = $4;$99 = $88;$__p$0$i$i$i = $89;
   } else {
    $90 = (($84) + 16)|0;
    $91 = $90 & -16;
    $92 = (__Znwj($91)|0);
    $93 = (($4) + 8|0);
    HEAP32[$93>>2] = $92;
    $94 = $91 | 1;
    HEAP32[$4>>2] = $94;
    $95 = (($4) + 4|0);
    HEAP32[$95>>2] = $84;
    $96 = $94&255;
    $$pre$phiZ2D = $4;$99 = $96;$__p$0$i$i$i = $92;
   }
   _memcpy(($__p$0$i$i$i|0),($attribute|0),($84|0))|0;
   $97 = (($__p$0$i$i$i) + ($84)|0);
   HEAP8[$97>>0] = 0;
   $98 = $99 & 1;
   $100 = ($98<<24>>24)==(0);
   if ($100) {
    $103 = (($4) + 1|0);
    $104 = $103;
   } else {
    $101 = (($4) + 8|0);
    $102 = HEAP32[$101>>2]|0;
    $104 = $102;
   }
   __THREW__ = 0;
   $105 = (invoke_iii(2578,($104|0),(765720|0))|0);
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   do {
    if (!($107)) {
     $108 = (($104) + 11|0);
     $$0$i$i = $105 ? $108 : 0;
     $109 = ($$0$i$i|0)==(0|0);
     if ($109) {
      $$0$i = 0;
     } else {
      __THREW__ = 0;
      $110 = (invoke_ii(3396,($targetObject|0))|0);
      $111 = __THREW__; __THREW__ = 0;
      $112 = $111&1;
      if ($112) {
       break;
      }
      $113 = ($110|0)==(0|0);
      if ($113) {
       $$0$i = 0;
      } else {
       $114 = (($110) + 56|0);
       __THREW__ = 0;
       $115 = (invoke_iii(2579,($114|0),($$0$i$i|0))|0);
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        break;
       }
       $118 = ($115|0)==(-1);
       if ($118) {
        $$0$i = 0;
       } else {
        $119 = $115 << 4;
        $120 = $119 | 7;
        HEAP32[$type>>2] = $120;
        HEAP32[$targetPtr>>2] = $targetObject;
        $$0$i = 1;
       }
      }
     }
     $121 = HEAP8[$$pre$phiZ2D>>0]|0;
     $122 = $121 & 1;
     $123 = ($122<<24>>24)==(0);
     if (!($123)) {
      $124 = (($4) + 8|0);
      $125 = HEAP32[$124>>2]|0;
      __ZdlPv($125);
     }
     if ($$0$i) {
      $$0 = 1;
     } else {
      break L1;
     }
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $126 = ___cxa_find_matching_catch()|0;
   $127 = tempRet0;
   $128 = HEAP8[$$pre$phiZ2D>>0]|0;
   $129 = $128 & 1;
   $130 = ($129<<24>>24)==(0);
   if ($130) {
    $$03 = $127;$$04 = $126;
    ___resumeException($$04|0);
    // unreachable;
   }
   $131 = (($4) + 8|0);
   $132 = HEAP32[$131>>2]|0;
   __ZdlPv($132);
   $$03 = $127;$$04 = $126;
   ___resumeException($$04|0);
   // unreachable;
  } else if ((($classID|0) == 1)) {
   $82 = (_strcmp($attribute,765696)|0);
   $83 = ($82|0)==(0);
   if ($83) {
    HEAP32[$type>>2] = 8;
    HEAP32[$targetPtr>>2] = $targetObject;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $133 = ($classID|0)==(114);
 $134 = (($this) + 4|0);
 $__rt$0$in1$i$i = HEAP32[$134>>2]|0;
 $135 = ($__rt$0$in1$i$i|0)==(0|0);
 L103: do {
  if ($135) {
   label = 81;
  } else {
   $__rt$0$in2$i$i = $__rt$0$in1$i$i;
   while(1) {
    $136 = (($__rt$0$in2$i$i) + 16|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = ($137|0)>($classID|0);
    if ($138) {
     $__rt$0$in$in$be$i$i = $__rt$0$in2$i$i;
    } else {
     $139 = ($137|0)<($classID|0);
     if (!($139)) {
      break;
     }
     $140 = (($__rt$0$in2$i$i) + 4|0);
     $__rt$0$in$in$be$i$i = $140;
    }
    $__rt$0$in$i$i = HEAP32[$__rt$0$in$in$be$i$i>>2]|0;
    $141 = ($__rt$0$in$i$i|0)==(0|0);
    if ($141) {
     label = 81;
     break L103;
    } else {
     $__rt$0$in2$i$i = $__rt$0$in$i$i;
    }
   }
   $142 = (($this) + 4|0);
   $$0$ph7$i$i$i = $142;$$01$ph6$i$in$i$i = $__rt$0$in1$i$i;
   L112: while(1) {
    $$013$i$in$i$i = $$01$ph6$i$in$i$i;
    while(1) {
     $143 = (($$013$i$in$i$i) + 16|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = ($144|0)<($classID|0);
     if (!($145)) {
      break;
     }
     $148 = (($$013$i$in$i$i) + 4|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ($149|0)==(0|0);
     if ($150) {
      $$0$ph5$i$i$i = $$0$ph7$i$i$i;
      break L112;
     } else {
      $$013$i$in$i$i = $149;
     }
    }
    $146 = HEAP32[$$013$i$in$i$i>>2]|0;
    $147 = ($146|0)==(0|0);
    if ($147) {
     $$0$ph5$i$i$i = $$013$i$in$i$i;
     break;
    } else {
     $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $146;
    }
   }
   $151 = ($$0$ph5$i$i$i|0)==($142|0);
   if ($151) {
    label = 79;
   } else {
    $152 = (($$0$ph5$i$i$i) + 16|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = ($153|0)>($classID|0);
    if ($154) {
     label = 79;
    } else {
     $156 = $$0$ph5$i$i$i;
    }
   }
   if ((label|0) == 79) {
    $156 = $142;
   }
   $155 = (($156) + 20|0);
   $157 = HEAP32[$155>>2]|0;
   $typeTree$0 = $157;
  }
 } while(0);
 do {
  if ((label|0) == 81) {
   $158 = HEAP32[628488>>2]|0;
   HEAP32[$5>>2] = $158;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$5+0>>2]|0;
   $159 = (__Znwj10MemLabelIdbiPKci(48,$$byval_copy2,0,16,765640,345)|0);
   __THREW__ = 0;
   invoke_vi(3568,($159|0));
   $160 = __THREW__; __THREW__ = 0;
   $161 = $160&1;
   if (!($161)) {
    __Z16GenerateTypeTreeR6ObjectP8TypeTree24TransferInstructionFlags($targetObject,$159,0);
    if ($133) {
     $typeTree$0 = $159;
     break;
    }
    $162 = (__ZNSt3__13mapIiPK8TypeTreeNS_4lessIiEENS_9allocatorINS_4pairIKiS3_EEEEEixERS8_($this,$2)|0);
    HEAP32[$162>>2] = $159;
    $typeTree$0 = $159;
    break;
   }
   $163 = ___cxa_find_matching_catch()|0;
   $164 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_viiiiii(97,($159|0),($$byval_copy2|0),0,16,(765640|0),345);
   $165 = __THREW__; __THREW__ = 0;
   $166 = $165&1;
   if ($166) {
    $183 = ___cxa_find_matching_catch(0|0)|0;
    $184 = tempRet0;
    ___clang_call_terminate($183);
    // unreachable;
   } else {
    $$03 = $164;$$04 = $163;
    ___resumeException($$04|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$type>>2] = 0;
 HEAP32[$targetPtr>>2] = 0;
 HEAP32[$1>>2] = $typeTree$0;
 $167 = (($1) + 4|0);
 HEAP32[$167>>2] = 0;
 __Z31FindAttributeInTypeTreeNoArraysRK16TypeTreeIteratorPKc($variable$i,$1,$attribute);
 $168 = HEAP32[$variable$i>>2]|0;
 $169 = ($168|0)==(0|0);
 if (!($169)) {
  $170 = (__ZNK16TypeTreeIterator10ByteOffsetEv($variable$i)|0);
  $171 = ($170|0)==(-1);
  if (!($171)) {
   $172 = (__Z21GetAnimatableBindTypeRK16TypeTreeIterator($variable$i)|0);
   HEAP32[$type>>2] = $172;
   $173 = ($172|0)==(0);
   if (!($173)) {
    $174 = (__ZNK16TypeTreeIterator10ByteOffsetEv($variable$i)|0);
    $175 = $174 & 2147483647;
    $176 = ($174|0)<(0);
    if ($176) {
     $177 = (($targetObject) + 20|0);
     $178 = HEAP32[$177>>2]|0;
     $$pn$i$i = $178;
    } else {
     $$pn$i$i = $targetObject;
    }
    $$0$i$i15 = (($$pn$i$i) + ($175)|0);
    HEAP32[$targetPtr>>2] = $$0$i$i15;
   }
  }
 }
 if ($133) {
  $179 = HEAP32[628488>>2]|0;
  $180 = ($typeTree$0|0)==(0|0);
  if (!($180)) {
   __ZN8TypeTreeD2Ev($typeTree$0);
  }
  HEAP32[$0>>2] = $179;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($typeTree$0,$$byval_copy2);
 }
 $181 = HEAP32[$type>>2]|0;
 $182 = ($181|0)!=(0);
 $$0 = $182;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__13mapIiPK8TypeTreeNS_4lessIiEENS_9allocatorINS_4pairIKiS3_EEEEEixERS8_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$22 = $13;
  } else {
   $3 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $4 = (($__nd$0$in$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)<($5|0);
    if ($6) {
     $7 = HEAP32[$__nd$0$in$i>>2]|0;
     $8 = ($7|0)==(0|0);
     if ($8) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $7;
      continue;
     }
    }
    $9 = ($5|0)<($3|0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$22 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$22 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $__r$0 = $14;
  $31 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($31|0);
 }
 $16 = (__Znwj(24)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__k>>2]|0;
 HEAP32[$17>>2] = $18;
 $19 = (($16) + 20|0);
 HEAP32[$19>>2] = 0;
 HEAP32[$16>>2] = 0;
 $20 = (($16) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($16) + 8|0);
 HEAP32[$21>>2] = $22;
 HEAP32[$$0$i>>2] = $16;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  $27 = $16;
 } else {
  HEAP32[$this>>2] = $24;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $27 = $$pre$i;
 }
 $26 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($26,$27);
 $28 = (($this) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + 1)|0;
 HEAP32[$28>>2] = $30;
 $__r$0 = $16;
 $31 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($31|0);
}
function __ZN15AnimationBinder19RemoveUnboundCurvesER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEER13dynamic_arrayI20BoundCurveDeprecatedLj4EE($lookup,$outBoundCurves) {
 $lookup = $lookup|0;
 $outBoundCurves = $outBoundCurves|0;
 var $$0 = 0, $$01 = 0, $$byval_copy3 = 0, $$pre = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i6 = 0, $i = 0, $j$016 = 0, $remap = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i7 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i11 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i9 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i10 = 0, $validCount$015 = 0, $validCount$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 56|0;
 $0 = sp;
 $1 = sp + 4|0;
 $i = sp + 8|0;
 $remap = sp + 20|0;
 $2 = sp + 32|0;
 $3 = sp + 44|0;
 $4 = (($lookup) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($lookup) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) - ($7))|0;
 $9 = (($outBoundCurves) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($5|0)==($7|0);
 if ($12) {
  $13 = (($outBoundCurves) + 12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)>(-1);
  if ($15) {
   $16 = HEAP32[$outBoundCurves>>2]|0;
   $17 = (($outBoundCurves) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$0>>2] = $18;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($16,$$byval_copy3);
   HEAP32[$outBoundCurves>>2] = 0;
  }
  HEAP32[$9>>2] = 0;
  HEAP32[$13>>2] = 0;
  STACKTOP = sp;return;
 }
 $19 = ($8*20)|0;
 HEAP32[$0>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $20 = (invoke_iiiiiiii(108,(0|0),($19|0),4,($$byval_copy3|0),0,(765640|0),370)|0);
 $21 = __THREW__; __THREW__ = 0;
 $22 = $21&1;
 do {
  if ($22) {
   $38 = ___cxa_find_matching_catch()|0;
   $39 = tempRet0;
   $$0 = $39;$$01 = $38;$95 = 0;
  } else {
   $$pre = HEAP32[$9>>2]|0;
   HEAP32[$remap>>2] = 0;
   $23 = (($remap) + 4|0);
   HEAP32[$23>>2] = 0;
   $24 = (($remap) + 8|0);
   HEAP32[$24>>2] = 0;
   $25 = ($$pre|0)==(0);
   if (!($25)) {
    __THREW__ = 0;
    invoke_vii(2697,($remap|0),($$pre|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     $40 = ___cxa_find_matching_catch()|0;
     $41 = tempRet0;
     $42 = HEAP32[$remap>>2]|0;
     $43 = ($42|0)==(0|0);
     if ($43) {
      $$0 = $41;$$01 = $40;$95 = $20;
      break;
     }
     $44 = HEAP32[$23>>2]|0;
     $45 = ($44|0)==($42|0);
     if (!($45)) {
      $__new_last2$i$i$i$i$i6 = $42;
      $scevgep$i$i$i$i$i7 = (($44) + -4|0);
      $46 = (0 - ($__new_last2$i$i$i$i$i6))|0;
      $uglygep$i$i$i$i$i9 = (($scevgep$i$i$i$i$i7) + ($46)|0);
      $uglygep3$i$i$i$i$i10 = $uglygep$i$i$i$i$i9;
      $47 = $uglygep3$i$i$i$i$i10 >>> 2;
      $48 = $47 ^ -1;
      $scevgep4$i$i$i$i$i11 = (($44) + ($48<<2)|0);
      HEAP32[$23>>2] = $scevgep4$i$i$i$i$i11;
     }
     __ZdlPv($42);
     $$0 = $41;$$01 = $40;$95 = $20;
     break;
    }
    $$pre19 = HEAP32[$9>>2]|0;
    $28 = ($$pre19|0)==(0);
    if (!($28)) {
     $29 = HEAP32[$remap>>2]|0;
     $j$016 = 0;$validCount$015 = 0;
     while(1) {
      $30 = (($29) + ($j$016<<2)|0);
      HEAP32[$30>>2] = $validCount$015;
      $31 = HEAP32[$outBoundCurves>>2]|0;
      $32 = ((($31) + (($j$016*20)|0)|0) + 8|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($33|0)==(0);
      if ($34) {
       $validCount$1 = $validCount$015;
      } else {
       $35 = (($31) + (($j$016*20)|0)|0);
       $36 = (($20) + (($validCount$015*20)|0)|0);
       ;HEAP32[$36+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$35+12>>2]|0;HEAP32[$36+16>>2]=HEAP32[$35+16>>2]|0;
       $37 = (($validCount$015) + 1)|0;
       $validCount$1 = $37;
      }
      $49 = (($j$016) + 1)|0;
      $50 = HEAP32[$9>>2]|0;
      $51 = ($49>>>0)<($50>>>0);
      if ($51) {
       $j$016 = $49;$validCount$015 = $validCount$1;
      } else {
       break;
      }
     }
    }
   }
   $52 = (($lookup) + 60|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($lookup) + 64|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($53) + (($55*24)|0)|0);
   HEAP32[$2>>2] = $lookup;
   $57 = (($2) + 4|0);
   HEAP32[$57>>2] = $53;
   $58 = (($2) + 8|0);
   HEAP32[$58>>2] = $56;
   __ZN24dense_hashtable_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($2);
   ;HEAP32[$i+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$i+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$i+8>>2]=HEAP32[$2+8>>2]|0;
   $59 = HEAP32[$52>>2]|0;
   $60 = HEAP32[$54>>2]|0;
   $61 = (($59) + (($60*24)|0)|0);
   HEAP32[$3>>2] = $lookup;
   $62 = (($3) + 4|0);
   HEAP32[$62>>2] = $61;
   $63 = (($3) + 8|0);
   HEAP32[$63>>2] = $61;
   __ZN24dense_hashtable_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($3);
   $64 = (($i) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[$62>>2]|0;
   $67 = ($65|0)==($66|0);
   if (!($67)) {
    $69 = $65;
    while(1) {
     $68 = (($69) + 20|0);
     $70 = HEAP32[$68>>2]|0;
     $71 = HEAP32[$remap>>2]|0;
     $72 = (($71) + ($70<<2)|0);
     $73 = HEAP32[$72>>2]|0;
     HEAP32[$68>>2] = $73;
     $74 = (($69) + 24|0);
     HEAP32[$64>>2] = $74;
     __ZN24dense_hashtable_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($i);
     $75 = HEAP32[$52>>2]|0;
     $76 = HEAP32[$54>>2]|0;
     $77 = (($75) + (($76*24)|0)|0);
     HEAP32[$3>>2] = $lookup;
     HEAP32[$62>>2] = $77;
     HEAP32[$63>>2] = $77;
     __ZN24dense_hashtable_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($3);
     $78 = HEAP32[$64>>2]|0;
     $79 = HEAP32[$62>>2]|0;
     $80 = ($78|0)==($79|0);
     if ($80) {
      break;
     } else {
      $69 = $78;
     }
    }
   }
   $81 = HEAP32[$outBoundCurves>>2]|0;
   HEAP32[$outBoundCurves>>2] = $20;
   HEAP32[$9>>2] = $8;
   $82 = (($outBoundCurves) + 12|0);
   $83 = HEAP32[$82>>2]|0;
   HEAP32[$82>>2] = $8;
   $84 = (($outBoundCurves) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   HEAP32[$84>>2] = 61;
   $86 = HEAP32[$remap>>2]|0;
   $87 = ($86|0)==(0|0);
   if (!($87)) {
    $88 = HEAP32[$23>>2]|0;
    $89 = ($88|0)==($86|0);
    if (!($89)) {
     $__new_last2$i$i$i$i$i = $86;
     $scevgep$i$i$i$i$i = (($88) + -4|0);
     $90 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($90)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $91 = $uglygep3$i$i$i$i$i >>> 2;
     $92 = $91 ^ -1;
     $scevgep4$i$i$i$i$i = (($88) + ($92<<2)|0);
     HEAP32[$23>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($86);
   }
   $93 = ($83|0)>(-1);
   if (!($93)) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = $85;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($81,$$byval_copy3);
   STACKTOP = sp;return;
  }
 } while(0);
 $94 = ($8|0)>(-1);
 if (!($94)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 HEAP32[$1>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($95|0),($$byval_copy3|0));
 $96 = __THREW__; __THREW__ = 0;
 $97 = $96&1;
 if ($97) {
  $98 = ___cxa_find_matching_catch(0|0)|0;
  $99 = tempRet0;
  ___clang_call_terminate($98);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN15AnimationBinder10BindCurvesERK14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEER9TransformR13dynamic_arrayI20BoundCurveDeprecatedLj4EERNS3_6vectorIPSF_S6_ISM_LSA_18ELi16EEEERi($this,$lookup,$transform,$outBoundCurves,$affectedRootTransforms,$transformChangedMask) {
 $this = $this|0;
 $lookup = $lookup|0;
 $transform = $transform|0;
 $outBoundCurves = $outBoundCurves|0;
 $affectedRootTransforms = $affectedRootTransforms|0;
 $transformChangedMask = $transformChangedMask|0;
 var $$byval_copy1 = 0, $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $go$0 = 0, $go$0$in = 0, $next = 0, $scevgep$i$i$i = 0;
 var $scevgep4$i$i$i = 0, $targetObject$0 = 0, $targetPtr = 0, $type = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $0 = sp;
 $next = sp + 4|0;
 $1 = sp + 16|0;
 $2 = sp + 28|0;
 $type = sp + 40|0;
 $targetPtr = sp + 44|0;
 $3 = (($lookup) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($lookup) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) - ($6))|0;
 $8 = (($outBoundCurves) + 8|0);
 HEAP32[$8>>2] = $7;
 $9 = (($outBoundCurves) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11>>>0)<($7>>>0);
 do {
  if ($12) {
   $13 = ($10|0)>(-1);
   if ($13) {
    HEAP32[$9>>2] = $7;
    $14 = HEAP32[$outBoundCurves>>2]|0;
    $15 = ($7*20)|0;
    $16 = (($outBoundCurves) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy1,0,765640,370)|0);
    HEAP32[$outBoundCurves>>2] = $18;
    break;
   } else {
    $19 = ($7*20)|0;
    $20 = (($outBoundCurves) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,765640,352)|0);
    $23 = HEAP32[$outBoundCurves>>2]|0;
    $24 = HEAP32[$8>>2]|0;
    $25 = ($24*20)|0;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$9>>2] = $7;
    HEAP32[$outBoundCurves>>2] = $22;
    break;
   }
  }
 } while(0);
 $26 = HEAP32[$affectedRootTransforms>>2]|0;
 $27 = (($affectedRootTransforms) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==($26|0);
 if (!($29)) {
  $__new_last2$i$i$i = $26;
  $scevgep$i$i$i = (($28) + -4|0);
  $30 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($30)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $31 = $uglygep3$i$i$i >>> 2;
  $32 = $31 ^ -1;
  $scevgep4$i$i$i = (($28) + ($32<<2)|0);
  HEAP32[$27>>2] = $scevgep4$i$i$i;
 }
 HEAP32[$transformChangedMask>>2] = 0;
 __ZL27ClearTransformTemporaryFlagR9Transform($transform);
 $33 = (($lookup) + 60|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($lookup) + 64|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + (($36*24)|0)|0);
 HEAP32[$1>>2] = $lookup;
 $38 = (($1) + 4|0);
 HEAP32[$38>>2] = $34;
 $39 = (($1) + 8|0);
 HEAP32[$39>>2] = $37;
 __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($1);
 $40 = HEAP32[$1>>2]|0;
 $41 = HEAP32[$38>>2]|0;
 $42 = HEAP32[$39>>2]|0;
 $43 = HEAP32[$33>>2]|0;
 $44 = HEAP32[$35>>2]|0;
 $45 = (($43) + (($44*24)|0)|0);
 HEAP32[$2>>2] = $lookup;
 $46 = (($2) + 4|0);
 HEAP32[$46>>2] = $45;
 $47 = (($2) + 8|0);
 HEAP32[$47>>2] = $45;
 __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($2);
 $48 = HEAP32[$46>>2]|0;
 $49 = ($41|0)==($48|0);
 if ($49) {
  __ZL23CalculateTransformRootsR9TransformRNSt3__16vectorIPS_13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEE($transform,$affectedRootTransforms);
  STACKTOP = sp;return;
 }
 $50 = (($next) + 4|0);
 $51 = (($next) + 8|0);
 $52 = $40;$53 = $42;$55 = $41;
 while(1) {
  HEAP32[$next>>2] = $52;
  HEAP32[$51>>2] = $53;
  $54 = (($55) + 24|0);
  HEAP32[$50>>2] = $54;
  __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($next);
  $56 = (($55) + 20|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = HEAP32[$outBoundCurves>>2]|0;
  $59 = ((($58) + (($57*20)|0)|0) + 4|0);
  HEAP32[$59>>2] = 0;
  $60 = HEAP32[$outBoundCurves>>2]|0;
  $61 = ((($60) + (($57*20)|0)|0) + 16|0);
  HEAP32[$61>>2] = 0;
  $62 = HEAP32[$outBoundCurves>>2]|0;
  $63 = (($62) + (($57*20)|0)|0);
  HEAP32[$63>>2] = 0;
  $64 = ((($62) + (($57*20)|0)|0) + 8|0);
  HEAP32[$64>>2] = 0;
  $65 = ((($62) + (($57*20)|0)|0) + 16|0);
  HEAP32[$65>>2] = 0;
  $66 = HEAP32[$outBoundCurves>>2]|0;
  $67 = (($66) + (($57*20)|0)|0);
  HEAP32[$67>>2] = 0;
  $68 = HEAP32[$55>>2]|0;
  $69 = HEAP8[$68>>0]|0;
  $70 = ($69<<24>>24)==(0);
  if ($70) {
   $$pn = $transform;
   label = 11;
  } else {
   $71 = (__Z29FindRelativeTransformWithPathR9TransformPKcb($transform,$68,0)|0);
   $72 = ($71|0)==(0|0);
   if (!($72)) {
    $$pn = $71;
    label = 11;
   }
  }
  do {
   if ((label|0) == 11) {
    label = 0;
    $go$0$in = (($$pn) + 24|0);
    $go$0 = HEAP32[$go$0$in>>2]|0;
    $73 = (($55) + 4|0);
    $74 = HEAP32[$73>>2]|0;
    if ((($74|0) == 1)) {
     $targetObject$0 = $go$0;
    } else if ((($74|0) == 21)) {
     $79 = (($55) + 12|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (__Z22GetComponentWithScriptRN5Unity10GameObjectEiP10MonoScript($go$0,25,$80)|0);
     $82 = ($81|0)==(0|0);
     if ($82) {
      break;
     }
     $targetObject$0 = $81;
    } else {
     $75 = (($55) + 12|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = (__Z22GetComponentWithScriptRN5Unity10GameObjectEiP10MonoScript($go$0,$74,$76)|0);
     $78 = ($77|0)==(0|0);
     if ($78) {
      break;
     }
     $targetObject$0 = $77;
    }
    $83 = HEAP32[$73>>2]|0;
    $84 = (($55) + 8|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (__ZN15AnimationBinder18CalculateTargetPtrEiP6ObjectPKcPPvPi($this,$83,$targetObject$0,$85,$targetPtr,$type)|0);
    if ($86) {
     $87 = HEAP32[$73>>2]|0;
     $88 = ($87|0)==(4);
     if ($88) {
      $89 = (($targetObject$0) + 8|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = $90 | 8192;
      HEAP32[$89>>2] = $91;
      $92 = HEAP32[$transformChangedMask>>2]|0;
      $93 = $92 & 2;
      $94 = ($93|0)==(0);
      if ($94) {
       $95 = HEAP32[$84>>2]|0;
       $96 = (__Z10BeginsWithPKcS0_($95,765680)|0);
       $97 = HEAP32[$transformChangedMask>>2]|0;
       if ($96) {
        $98 = $97 | 2;
        HEAP32[$transformChangedMask>>2] = $98;
        $100 = $98;
       } else {
        $100 = $97;
       }
      } else {
       $100 = $92;
      }
      $99 = $100 & 1;
      $101 = ($99|0)==(0);
      if ($101) {
       $102 = HEAP32[$84>>2]|0;
       $103 = (__Z10BeginsWithPKcS0_($102,765648)|0);
       $104 = HEAP32[$transformChangedMask>>2]|0;
       if ($103) {
        $105 = $104 | 1;
        HEAP32[$transformChangedMask>>2] = $105;
        $107 = $105;
       } else {
        $107 = $104;
       }
      } else {
       $107 = $100;
      }
      $106 = $107 & 8;
      $108 = ($106|0)==(0);
      if ($108) {
       $109 = HEAP32[$84>>2]|0;
       $110 = (__Z10BeginsWithPKcS0_($109,765664)|0);
       if ($110) {
        $111 = HEAP32[$transformChangedMask>>2]|0;
        $112 = $111 | 8;
        HEAP32[$transformChangedMask>>2] = $112;
       }
      }
     }
     $113 = HEAP32[$targetPtr>>2]|0;
     $114 = HEAP32[$outBoundCurves>>2]|0;
     $115 = ((($114) + (($57*20)|0)|0) + 4|0);
     HEAP32[$115>>2] = $113;
     $116 = HEAP32[$type>>2]|0;
     $117 = HEAP32[$outBoundCurves>>2]|0;
     $118 = ((($117) + (($57*20)|0)|0) + 8|0);
     HEAP32[$118>>2] = $116;
     $119 = ((($117) + (($57*20)|0)|0) + 16|0);
     HEAP32[$119>>2] = $targetObject$0;
     $120 = (($targetObject$0) + 4|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = HEAP32[$outBoundCurves>>2]|0;
     $123 = (($122) + (($57*20)|0)|0);
     HEAP32[$123>>2] = $121;
     $124 = HEAP32[$120>>2]|0;
     HEAP32[$123>>2] = $124;
    }
   }
  } while(0);
  $125 = HEAP32[$next>>2]|0;
  $126 = HEAP32[$50>>2]|0;
  $127 = HEAP32[$51>>2]|0;
  $128 = HEAP32[$33>>2]|0;
  $129 = HEAP32[$35>>2]|0;
  $130 = (($128) + (($129*24)|0)|0);
  HEAP32[$2>>2] = $lookup;
  HEAP32[$46>>2] = $130;
  HEAP32[$47>>2] = $130;
  __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($2);
  $131 = HEAP32[$46>>2]|0;
  $132 = ($126|0)==($131|0);
  if ($132) {
   break;
  } else {
   $52 = $125;$53 = $127;$55 = $126;
  }
 }
 __ZL23CalculateTransformRootsR9TransformRNSt3__16vectorIPS_13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEE($transform,$affectedRootTransforms);
 STACKTOP = sp;return;
}
function __ZL27ClearTransformTemporaryFlagR9Transform($transform) {
 $transform = $transform|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transform) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -8193;
 HEAP32[$0>>2] = $2;
 $3 = (($transform) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transform) + 148|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + ($6<<2)|0);
 $8 = ($6|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $4;
 }
 while(1) {
  $9 = HEAP32[$i$01>>2]|0;
  __ZL27ClearTransformTemporaryFlagR9Transform($9);
  $10 = (($i$01) + 4|0);
  $11 = ($10|0)==($7|0);
  if ($11) {
   break;
  } else {
   $i$01 = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23CalculateTransformRootsR9TransformRNSt3__16vectorIPS_13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEE($transform,$affectedRootTransforms) {
 $transform = $transform|0;
 $affectedRootTransforms = $affectedRootTransforms|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($transform) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 8192;
 $4 = ($3|0)==(0);
 if ($4) {
  $13 = (($transform) + 140|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($transform) + 148|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + ($16<<2)|0);
  $18 = ($16|0)==(0);
  if ($18) {
   STACKTOP = sp;return;
  } else {
   $i$01 = $14;
  }
  while(1) {
   $19 = HEAP32[$i$01>>2]|0;
   __ZL23CalculateTransformRootsR9TransformRNSt3__16vectorIPS_13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEE($19,$affectedRootTransforms);
   $20 = (($i$01) + 4|0);
   $21 = ($20|0)==($17|0);
   if ($21) {
    break;
   } else {
    $i$01 = $20;
   }
  }
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $transform;
 $5 = (($affectedRootTransforms) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($affectedRootTransforms) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  __ZNSt3__16vectorIP9Transform13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($affectedRootTransforms,$0);
  STACKTOP = sp;return;
 }
 $10 = ($6|0)==(0|0);
 if ($10) {
  $12 = 0;
 } else {
  HEAP32[$6>>2] = $transform;
  $$pre$i = HEAP32[$5>>2]|0;
  $12 = $$pre$i;
 }
 $11 = (($12) + 4|0);
 HEAP32[$5>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN15AnimationBinder16StaticInitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,765640,625)|0);
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[$2>>2] = $3;
 HEAP32[765712>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN15AnimationBinder13StaticDestroyEv() {
 var $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$01$i$i$i$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[765712>>2]|0;
 $3 = HEAP32[628296>>2]|0;
 $4 = ($2|0)==(0|0);
 if ($4) {
  HEAP32[$1>>2] = $3;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy1);
  HEAP32[765712>>2] = 0;
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$2>>2]|0;
 $6 = (($2) + 4|0);
 $7 = ($5|0)==($6|0);
 L4: do {
  if (!($7)) {
   $9 = $5;
   while(1) {
    $8 = (($9) + 20|0);
    $10 = HEAP32[$8>>2]|0;
    $11 = HEAP32[628488>>2]|0;
    $12 = ($10|0)==(0|0);
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3569,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    HEAP32[$0>>2] = $11;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($10|0),($$byval_copy1|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    HEAP32[$8>>2] = 0;
    $17 = (($9) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $$01$i$i$i$i$i = $9;
     while(1) {
      $22 = (($$01$i$i$i$i$i) + 8|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24|0)==($$01$i$i$i$i$i|0);
      if ($25) {
       $$0$i$i$i$i$i = $23;
       break;
      } else {
       $$01$i$i$i$i$i = $23;
      }
     }
    } else {
     $$0$i$i$i$i$i$i = $18;
     while(1) {
      $20 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
      $21 = ($20|0)==(0|0);
      if ($21) {
       $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i$i = $20;
      }
     }
    }
    $26 = ($$0$i$i$i$i$i|0)==($6|0);
    if ($26) {
     break L4;
    } else {
     $9 = $$0$i$i$i$i$i;
    }
   }
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   $29 = (($2) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIiPK8TypeTreeEENS_19__map_value_compareIiS5_NS_4lessIiEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($2,$30);
   ___resumeException($27|0);
   // unreachable;
  }
 } while(0);
 $31 = (($2) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiPK8TypeTreeEENS_19__map_value_compareIiS5_NS_4lessIiEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($2,$32);
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy1);
 HEAP32[765712>>2] = 0;
 STACKTOP = sp;return;
}
function __Z18GetAnimationBinderv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[765712>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN15AnimationBinder13SetFloatValueERK20BoundCurveDeprecatedf($bind,$value) {
 $bind = $bind|0;
 $value = Math_fround($value);
 var $$0 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($bind) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 15;
 if ((($5|0) == 8)) {
  $8 = $value > Math_fround(0.00100000004749745130539);
  if ($8) {
   $12 = 1;
  } else {
   $9 = $value < Math_fround(-0.00100000004749745130539);
   $12 = $9;
  }
  $10 = (($bind) + 16|0);
  $11 = HEAP32[$10>>2]|0;
  __ZN5Unity10GameObject13SetSelfActiveEb($11,$12);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($5|0) == 6)) {
  $13 = $value > Math_fround(0.00100000004749745130539);
  if ($13) {
   $17 = 1;
  } else {
   $14 = $value < Math_fround(-0.00100000004749745130539);
   $phitmp = $14&1;
   $17 = $phitmp;
  }
  $15 = (($bind) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP8[$16>>0] = $17;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($5|0) == 7)) {
  $18 = (($bind) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $4 >>> 4;
  __ZN19SkinnedMeshRenderer19SetBlendShapeWeightEjf($19,$20,$value);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($5|0) == 5)) {
  $6 = (($bind) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  HEAPF32[$7>>2] = $value;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $21 = (($bind) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = $22;
  $24 = (($bind) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 128|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (FUNCTION_TABLE_ii[$28 & 4095]($25)|0);
  $30 = ($23|0)<($29|0);
  if (!($30)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $31 = (__ZN8Renderer32GetAndAssignInstantiatedMaterialEib($25,$23,1)|0);
  $32 = ($31|0)==(0|0);
  if ($32) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $33 = HEAP32[$3>>2]|0;
  $34 = $33 >>> 28;
  $35 = $33 >>> 4;
  $36 = $35 & 16777215;
  $37 = $33 & 15;
  if ((($37|0) == 11)) {
   HEAP32[$0>>2] = $36;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __ZN5Unity8Material8SetFloatEN9ShaderLab16FastPropertyNameEf($31,$$byval_copy2,$value);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else if ((($37|0) == 12)) {
   HEAP32[$2>>2] = $36;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   __ZN5Unity8Material15SetColorIndexedEN9ShaderLab16FastPropertyNameEif($31,$$byval_copy2,$34,$value);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else if ((($37|0) == 13)) {
   HEAP32[$1>>2] = $36;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   __ZN5Unity8Material31SetTextureScaleAndOffsetIndexedEN9ShaderLab16FastPropertyNameEif($31,$$byval_copy2,$34,$value);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 return 0|0;
}
function __ZN15AnimationBinder23InsertCurveIDIntoLookupER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEERS8_($curveIDLookup,$curveID) {
 $curveIDLookup = $curveIDLookup|0;
 $curveID = $curveID|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp;
 $1 = sp + 24|0;
 ;HEAP32[$0+0>>2]=HEAP32[$curveID+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$curveID+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$curveID+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$curveID+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$curveID+16>>2]|0;
 $2 = (($curveIDLookup) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($curveIDLookup) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = (($0) + 20|0);
 HEAP32[$7>>2] = $6;
 __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E12resize_deltaEjj($curveIDLookup,1,0);
 __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E15insert_noresizeERKS4_($1,$curveIDLookup,$0);
 $8 = (($1) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 STACKTOP = sp;return ($11|0);
}
function __ZN7CurveID13CalculateHashEv($this) {
 $this = $this|0;
 var $$02$i = 0, $$02$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0$lcssa$i = 0, $h$0$lcssa$i4 = 0, $h$01$i = 0, $h$01$i2 = 0, $phitmp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $h$0$lcssa$i = 4;
 } else {
  $$02$i = $0;$4 = $1;$h$01$i = 0;
  while(1) {
   $3 = $4 << 24 >> 24;
   $5 = $h$01$i << 4;
   $6 = (($5) + ($3))|0;
   $7 = $6 & -268435456;
   $8 = $7 >>> 24;
   $9 = $8 | $7;
   $10 = $9 ^ $6;
   $11 = (($$02$i) + 1|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    break;
   } else {
    $$02$i = $11;$4 = $12;$h$01$i = $10;
   }
  }
  $phitmp = $10 ^ 4;
  $h$0$lcssa$i = $phitmp;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $h$0$lcssa$i4 = 0;
  $29 = $h$0$lcssa$i ^ $h$0$lcssa$i4;
  $30 = ($29>>>0)<(2);
  $31 = $30 ? 2 : $29;
  $32 = (($this) + 16|0);
  HEAP32[$32>>2] = $31;
  STACKTOP = sp;return;
 } else {
  $$02$i1 = $15;$19 = $16;$h$01$i2 = 0;
 }
 while(1) {
  $18 = $19 << 24 >> 24;
  $20 = $h$01$i2 << 4;
  $21 = (($20) + ($18))|0;
  $22 = $21 & -268435456;
  $23 = $22 >>> 24;
  $24 = $23 | $22;
  $25 = $24 ^ $21;
  $26 = (($$02$i1) + 1|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)==(0);
  if ($28) {
   $h$0$lcssa$i4 = $25;
   break;
  } else {
   $$02$i1 = $26;$19 = $27;$h$01$i2 = $25;
  }
 }
 $29 = $h$0$lcssa$i ^ $h$0$lcssa$i4;
 $30 = ($29>>>0)<(2);
 $31 = $30 ? 2 : $29;
 $32 = (($this) + 16|0);
 HEAP32[$32>>2] = $31;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E12resize_deltaEjj($this,$delta,$min_buckets_wanted) {
 $this = $this|0;
 $delta = $delta|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $sz$0$i = 0, $sz$0$i1 = 0, $tmp = 0, $tmp1$sroa$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp + 24|0;
 $tmp1$sroa$0$i = sp;
 $tmp = sp + 44|0;
 $0 = (($this) + 80|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E12maybe_shrinkEv($this);
 }
 $3 = (($this) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4>>>0)>($min_buckets_wanted>>>0);
 $6 = (($this) + 68|0);
 $7 = HEAP32[$6>>2]|0;
 if ($5) {
  $8 = (($7) + ($delta))|0;
  $9 = (($this) + 76|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8>>>0)>($10>>>0);
  if (!($11)) {
   STACKTOP = sp;return;
  }
 }
 $12 = (($this) + 68|0);
 $13 = (($7) + ($delta))|0;
 $14 = (Math_fround(($13>>>0)));
 $sz$0$i = 32;
 while(1) {
  $15 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($15)) {
   $16 = (Math_fround(($sz$0$i>>>0)));
   $17 = Math_fround($16 * Math_fround(0.5));
   $18 = !($14 >= $17);
   if ($18) {
    break;
   }
  }
  $19 = $sz$0$i << 1;
  $sz$0$i = $19;
 }
 $20 = ($sz$0$i>>>0)>($4>>>0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($13) - ($22))|0;
 $24 = (Math_fround(($23>>>0)));
 $sz$0$i1 = 32;
 while(1) {
  $25 = ($sz$0$i1>>>0)<($min_buckets_wanted>>>0);
  if (!($25)) {
   $26 = (Math_fround(($sz$0$i1>>>0)));
   $27 = Math_fround($26 * Math_fround(0.5));
   $28 = !($24 >= $27);
   if ($28) {
    break;
   }
  }
  $29 = $sz$0$i1 << 1;
  $sz$0$i1 = $29;
 }
 $30 = (($tmp) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = (($tmp) + 8|0);
 $32 = (($this) + 8|0);
 $33 = HEAP8[$32>>0]|0;
 HEAP8[$31>>0] = $33;
 $34 = (($tmp) + 9|0);
 $35 = (($this) + 9|0);
 $36 = HEAP8[$35>>0]|0;
 HEAP8[$34>>0] = $36;
 $37 = (($tmp) + 12|0);
 $38 = (($this) + 12|0);
 ;HEAP32[$37+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$38+12>>2]|0;HEAP32[$37+16>>2]=HEAP32[$38+16>>2]|0;HEAP32[$37+20>>2]=HEAP32[$38+20>>2]|0;
 $39 = (($tmp) + 36|0);
 $40 = (($this) + 36|0);
 ;HEAP32[$39+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$40+16>>2]|0;HEAP32[$39+20>>2]=HEAP32[$40+20>>2]|0;
 $41 = (($tmp) + 60|0);
 ;HEAP32[$41+0>>2]=0|0;HEAP32[$41+4>>2]=0|0;HEAP32[$41+8>>2]=0|0;HEAP32[$41+12>>2]=0|0;HEAP32[$41+16>>2]=0|0;HEAP8[$41+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E9copy_fromERKSE_j($tmp,$this,$sz$0$i1);
 $42 = HEAP32[$21>>2]|0;
 $43 = HEAP32[$30>>2]|0;
 HEAP32[$21>>2] = $43;
 HEAP32[$30>>2] = $42;
 $44 = HEAP8[$32>>0]|0;
 $45 = HEAP16[$31>>1]|0;
 $46 = $45&255;
 HEAP8[$32>>0] = $46;
 HEAP8[$31>>0] = $44;
 $47 = HEAP8[$35>>0]|0;
 $48 = ($45&65535) >>> 8;
 $49 = $48&255;
 HEAP8[$35>>0] = $49;
 HEAP8[$34>>0] = $47;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$38+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$38+16>>2]|0;
 $50 = (($this) + 32|0);
 $51 = HEAP32[$50>>2]|0;
 ;HEAP32[$38+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$37+12>>2]|0;HEAP32[$38+16>>2]=HEAP32[$37+16>>2]|0;HEAP32[$38+20>>2]=HEAP32[$37+20>>2]|0;
 ;HEAP32[$37+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$$byval_copy+12>>2]|0;HEAP32[$37+16>>2]=HEAP32[$$byval_copy+16>>2]|0;
 $52 = (($tmp) + 32|0);
 HEAP32[$52>>2] = $51;
 ;HEAP32[$tmp1$sroa$0$i+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$tmp1$sroa$0$i+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$tmp1$sroa$0$i+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$tmp1$sroa$0$i+12>>2]=HEAP32[$40+12>>2]|0;HEAP32[$tmp1$sroa$0$i+16>>2]=HEAP32[$40+16>>2]|0;
 $53 = (($this) + 56|0);
 $54 = HEAP32[$53>>2]|0;
 ;HEAP32[$40+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$39+12>>2]|0;HEAP32[$40+16>>2]=HEAP32[$39+16>>2]|0;HEAP32[$40+20>>2]=HEAP32[$39+20>>2]|0;
 ;HEAP32[$39+0>>2]=HEAP32[$tmp1$sroa$0$i+0>>2]|0;HEAP32[$39+4>>2]=HEAP32[$tmp1$sroa$0$i+4>>2]|0;HEAP32[$39+8>>2]=HEAP32[$tmp1$sroa$0$i+8>>2]|0;HEAP32[$39+12>>2]=HEAP32[$tmp1$sroa$0$i+12>>2]|0;HEAP32[$39+16>>2]=HEAP32[$tmp1$sroa$0$i+16>>2]|0;
 $55 = (($tmp) + 56|0);
 HEAP32[$55>>2] = $54;
 $56 = (($this) + 60|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = HEAP32[$41>>2]|0;
 HEAP32[$56>>2] = $58;
 HEAP32[$41>>2] = $57;
 $59 = (($tmp) + 64|0);
 $60 = HEAP32[$3>>2]|0;
 $61 = HEAP32[$59>>2]|0;
 HEAP32[$3>>2] = $61;
 HEAP32[$59>>2] = $60;
 $62 = (($tmp) + 68|0);
 $63 = HEAP32[$12>>2]|0;
 $64 = HEAP32[$62>>2]|0;
 HEAP32[$12>>2] = $64;
 HEAP32[$62>>2] = $63;
 $65 = (Math_fround(($61>>>0)));
 $66 = Math_fround($65 * Math_fround(0.5));
 $67 = (~~(($66))>>>0);
 $68 = (($this) + 76|0);
 HEAP32[$68>>2] = $67;
 $69 = Math_fround($65 * Math_fround(0.20000000298023223877));
 $70 = (~~(($69))>>>0);
 $71 = (($this) + 72|0);
 HEAP32[$71>>2] = $70;
 HEAP8[$0>>0] = 0;
 $72 = (Math_fround(($60>>>0)));
 $73 = Math_fround($72 * Math_fround(0.5));
 $74 = (~~(($73))>>>0);
 $75 = (($tmp) + 76|0);
 HEAP32[$75>>2] = $74;
 $76 = Math_fround($72 * Math_fround(0.20000000298023223877));
 $77 = (~~(($76))>>>0);
 $78 = (($tmp) + 72|0);
 HEAP32[$78>>2] = $77;
 $79 = (($tmp) + 80|0);
 HEAP8[$79>>0] = 0;
 $80 = ($57|0)==(0|0);
 if ($80) {
  STACKTOP = sp;return;
 }
 HEAP32[$tmp1$sroa$0$i>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$tmp1$sroa$0$i+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($57,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E15insert_noresizeERKS4_($agg$result,$this,$obj) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $obj = $obj|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $pos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos = sp;
 __ZNK15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E13find_positionERS3_($pos,$this,$obj);
 $0 = HEAP32[$pos>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  $2 = (($this) + 60|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + (($0*24)|0)|0);
  $5 = (($this) + 64|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + (($6*24)|0)|0);
  HEAP32[$agg$result>>2] = $this;
  $8 = (($agg$result) + 4|0);
  HEAP32[$8>>2] = $4;
  $9 = (($agg$result) + 8|0);
  HEAP32[$9>>2] = $7;
  $10 = (($agg$result) + 12|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 }
 $11 = (($pos) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  label = 11;
 } else {
  $16 = (($this) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0);
  if ($18) {
   label = 11;
  } else {
   $19 = (($this) + 60|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 28|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($20) + (($12*24)|0)|0) + 16|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($22|0)==($24|0);
   if ($25) {
    $26 = (($this) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($20) + (($12*24)|0)|0) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27|0)==($29|0);
    if ($30) {
     $31 = (($this) + 12|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($20) + (($12*24)|0)|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (_strcmp($32,$34)|0);
     $36 = ($35|0)==(0);
     if ($36) {
      $37 = (($this) + 20|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ((($20) + (($12*24)|0)|0) + 8|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (_strcmp($38,$40)|0);
      $42 = ($41|0)==(0);
      if ($42) {
       $43 = (($this) + 24|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = ((($20) + (($12*24)|0)|0) + 12|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ($44|0)==($46|0);
       if ($47) {
        $48 = (($17) + -1)|0;
        HEAP32[$16>>2] = $48;
        $54 = $20;
       } else {
        label = 11;
       }
      } else {
       label = 11;
      }
     } else {
      label = 11;
     }
    } else {
     label = 11;
    }
   } else {
    label = 11;
   }
  }
 }
 if ((label|0) == 11) {
  $49 = (($this) + 68|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + 1)|0;
  HEAP32[$49>>2] = $51;
  $$phi$trans$insert = (($this) + 60|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $54 = $$pre;
 }
 $52 = (($this) + 60|0);
 $53 = (($54) + (($12*24)|0)|0);
 $55 = ($53|0)==(0|0);
 if (!($55)) {
  ;HEAP32[$53+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$53+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$53+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$53+12>>2]=HEAP32[$obj+12>>2]|0;HEAP32[$53+16>>2]=HEAP32[$obj+16>>2]|0;HEAP32[$53+20>>2]=HEAP32[$obj+20>>2]|0;
 }
 $56 = HEAP32[$52>>2]|0;
 $57 = (($56) + (($12*24)|0)|0);
 $58 = (($this) + 64|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($56) + (($59*24)|0)|0);
 HEAP32[$agg$result>>2] = $this;
 $61 = (($agg$result) + 4|0);
 HEAP32[$61>>2] = $57;
 $62 = (($agg$result) + 8|0);
 HEAP32[$62>>2] = $60;
 $63 = (($agg$result) + 12|0);
 HEAP8[$63>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $$pre = HEAP32[$this>>2]|0;
 $$phi$trans$insert = (($$pre) + 52|0);
 $$pre5 = HEAP32[$$phi$trans$insert>>2]|0;
 $6 = $1;
 while(1) {
  $5 = (($6) + 16|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($$pre5|0)==($7|0);
  if ($8) {
   $9 = (($$pre) + 40|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($6) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($10|0)==($12|0);
   if ($13) {
    $14 = (($$pre) + 36|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = HEAP32[$6>>2]|0;
    $17 = (_strcmp($15,$16)|0);
    $18 = ($17|0)==(0);
    if ($18) {
     $19 = (($$pre) + 44|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($6) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (_strcmp($20,$22)|0);
     $24 = ($23|0)==(0);
     if ($24) {
      $25 = (($$pre) + 48|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($6) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($26|0)==($28|0);
      if (!($29)) {
       label = 8;
      }
     } else {
      label = 8;
     }
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
  if ((label|0) == 8) {
   label = 0;
   $30 = (($$pre) + 8|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    label = 16;
    break;
   }
   $33 = (($$pre) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0);
   if ($35) {
    label = 16;
    break;
   }
   $36 = (($$pre) + 28|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==($7|0);
   if (!($38)) {
    label = 16;
    break;
   }
   $39 = (($$pre) + 16|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($6) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($40|0)==($42|0);
   if (!($43)) {
    label = 16;
    break;
   }
   $44 = (($$pre) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$6>>2]|0;
   $47 = (_strcmp($45,$46)|0);
   $48 = ($47|0)==(0);
   if (!($48)) {
    label = 16;
    break;
   }
   $49 = (($$pre) + 20|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($6) + 8|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (_strcmp($50,$52)|0);
   $54 = ($53|0)==(0);
   if (!($54)) {
    label = 16;
    break;
   }
   $55 = (($$pre) + 24|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($6) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($56|0)==($58|0);
   if (!($59)) {
    label = 16;
    break;
   }
  }
  $60 = (($6) + 24|0);
  HEAP32[$0>>2] = $60;
  $61 = ($60|0)==($3|0);
  if ($61) {
   label = 16;
   break;
  } else {
   $6 = $60;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZN24dense_hashtable_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $$pre = HEAP32[$this>>2]|0;
 $$phi$trans$insert = (($$pre) + 52|0);
 $$pre5 = HEAP32[$$phi$trans$insert>>2]|0;
 $6 = $1;
 while(1) {
  $5 = (($6) + 16|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($$pre5|0)==($7|0);
  if ($8) {
   $9 = (($$pre) + 40|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($6) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($10|0)==($12|0);
   if ($13) {
    $14 = (($$pre) + 36|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = HEAP32[$6>>2]|0;
    $17 = (_strcmp($15,$16)|0);
    $18 = ($17|0)==(0);
    if ($18) {
     $19 = (($$pre) + 44|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($6) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (_strcmp($20,$22)|0);
     $24 = ($23|0)==(0);
     if ($24) {
      $25 = (($$pre) + 48|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($6) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($26|0)==($28|0);
      if (!($29)) {
       label = 8;
      }
     } else {
      label = 8;
     }
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
  if ((label|0) == 8) {
   label = 0;
   $30 = (($$pre) + 8|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    label = 16;
    break;
   }
   $33 = (($$pre) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0);
   if ($35) {
    label = 16;
    break;
   }
   $36 = (($$pre) + 28|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==($7|0);
   if (!($38)) {
    label = 16;
    break;
   }
   $39 = (($$pre) + 16|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($6) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($40|0)==($42|0);
   if (!($43)) {
    label = 16;
    break;
   }
   $44 = (($$pre) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$6>>2]|0;
   $47 = (_strcmp($45,$46)|0);
   $48 = ($47|0)==(0);
   if (!($48)) {
    label = 16;
    break;
   }
   $49 = (($$pre) + 20|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($6) + 8|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (_strcmp($50,$52)|0);
   $54 = ($53|0)==(0);
   if (!($54)) {
    label = 16;
    break;
   }
   $55 = (($$pre) + 24|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($6) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($56|0)==($58|0);
   if (!($59)) {
    label = 16;
    break;
   }
  }
  $60 = (($6) + 24|0);
  HEAP32[$0>>2] = $60;
  $61 = ($60|0)==($3|0);
  if ($61) {
   label = 16;
   break;
  } else {
   $6 = $60;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E12maybe_shrinkEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $sz$0 = 0, $sz$0$in = 0, $tmp = 0, $tmp1$sroa$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp + 24|0;
 $tmp1$sroa$0$i = sp;
 $tmp = sp + 44|0;
 $0 = (($this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($3))|0;
 $5 = (($this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if (!($7)) {
  $67 = (($this) + 80|0);
  HEAP8[$67>>0] = 0;
  STACKTOP = sp;return;
 }
 $8 = (($this) + 64|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9>>>0)>(32);
 if ($10) {
  $sz$0$in = $9;
 } else {
  $67 = (($this) + 80|0);
  HEAP8[$67>>0] = 0;
  STACKTOP = sp;return;
 }
 while(1) {
  $sz$0 = $sz$0$in >>> 1;
  $11 = ($sz$0$in>>>0)<(66);
  if ($11) {
   break;
  }
  $12 = (Math_fround(($4>>>0)));
  $13 = (Math_fround(($sz$0>>>0)));
  $14 = Math_fround($13 * Math_fround(0.20000000298023223877));
  $15 = $12 < $14;
  if ($15) {
   $sz$0$in = $sz$0;
  } else {
   break;
  }
 }
 $16 = (($tmp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($tmp) + 8|0);
 $18 = (($this) + 8|0);
 $19 = HEAP8[$18>>0]|0;
 HEAP8[$17>>0] = $19;
 $20 = (($tmp) + 9|0);
 $21 = (($this) + 9|0);
 $22 = HEAP8[$21>>0]|0;
 HEAP8[$20>>0] = $22;
 $23 = (($tmp) + 12|0);
 $24 = (($this) + 12|0);
 ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$24+16>>2]|0;HEAP32[$23+20>>2]=HEAP32[$24+20>>2]|0;
 $25 = (($tmp) + 36|0);
 $26 = (($this) + 36|0);
 ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$25+20>>2]=HEAP32[$26+20>>2]|0;
 $27 = (($tmp) + 60|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;HEAP32[$27+16>>2]=0|0;HEAP8[$27+20>>0]=0|0;
 __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E9copy_fromERKSE_j($tmp,$this,$sz$0);
 $28 = HEAP32[$2>>2]|0;
 $29 = HEAP32[$16>>2]|0;
 HEAP32[$2>>2] = $29;
 HEAP32[$16>>2] = $28;
 $30 = HEAP8[$18>>0]|0;
 $31 = HEAP16[$17>>1]|0;
 $32 = $31&255;
 HEAP8[$18>>0] = $32;
 HEAP8[$17>>0] = $30;
 $33 = HEAP8[$21>>0]|0;
 $34 = ($31&65535) >>> 8;
 $35 = $34&255;
 HEAP8[$21>>0] = $35;
 HEAP8[$20>>0] = $33;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$24+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$24+16>>2]|0;
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 ;HEAP32[$24+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$23+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$23+20>>2]|0;
 ;HEAP32[$23+0>>2]=HEAP32[$$byval_copy+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$$byval_copy+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$$byval_copy+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$$byval_copy+12>>2]|0;HEAP32[$23+16>>2]=HEAP32[$$byval_copy+16>>2]|0;
 $38 = (($tmp) + 32|0);
 HEAP32[$38>>2] = $37;
 ;HEAP32[$tmp1$sroa$0$i+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$tmp1$sroa$0$i+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$tmp1$sroa$0$i+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$tmp1$sroa$0$i+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$tmp1$sroa$0$i+16>>2]=HEAP32[$26+16>>2]|0;
 $39 = (($this) + 56|0);
 $40 = HEAP32[$39>>2]|0;
 ;HEAP32[$26+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$25+12>>2]|0;HEAP32[$26+16>>2]=HEAP32[$25+16>>2]|0;HEAP32[$26+20>>2]=HEAP32[$25+20>>2]|0;
 ;HEAP32[$25+0>>2]=HEAP32[$tmp1$sroa$0$i+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$tmp1$sroa$0$i+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$tmp1$sroa$0$i+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$tmp1$sroa$0$i+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$tmp1$sroa$0$i+16>>2]|0;
 $41 = (($tmp) + 56|0);
 HEAP32[$41>>2] = $40;
 $42 = (($this) + 60|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$27>>2]|0;
 HEAP32[$42>>2] = $44;
 HEAP32[$27>>2] = $43;
 $45 = (($tmp) + 64|0);
 $46 = HEAP32[$8>>2]|0;
 $47 = HEAP32[$45>>2]|0;
 HEAP32[$8>>2] = $47;
 HEAP32[$45>>2] = $46;
 $48 = (($tmp) + 68|0);
 $49 = HEAP32[$0>>2]|0;
 $50 = HEAP32[$48>>2]|0;
 HEAP32[$0>>2] = $50;
 HEAP32[$48>>2] = $49;
 $51 = (Math_fround(($47>>>0)));
 $52 = Math_fround($51 * Math_fround(0.5));
 $53 = (~~(($52))>>>0);
 $54 = (($this) + 76|0);
 HEAP32[$54>>2] = $53;
 $55 = Math_fround($51 * Math_fround(0.20000000298023223877));
 $56 = (~~(($55))>>>0);
 HEAP32[$5>>2] = $56;
 $57 = (($this) + 80|0);
 HEAP8[$57>>0] = 0;
 $58 = (Math_fround(($46>>>0)));
 $59 = Math_fround($58 * Math_fround(0.5));
 $60 = (~~(($59))>>>0);
 $61 = (($tmp) + 76|0);
 HEAP32[$61>>2] = $60;
 $62 = Math_fround($58 * Math_fround(0.20000000298023223877));
 $63 = (~~(($62))>>>0);
 $64 = (($tmp) + 72|0);
 HEAP32[$64>>2] = $63;
 $65 = (($tmp) + 80|0);
 HEAP8[$65>>0] = 0;
 $66 = ($43|0)==(0|0);
 if ($66) {
  $67 = (($this) + 80|0);
  HEAP8[$67>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$tmp1$sroa$0$i>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$tmp1$sroa$0$i+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($43,$$byval_copy);
 $67 = (($this) + 80|0);
 HEAP8[$67>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN15dense_hashtableINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E9copy_fromERKSE_j($this,$ht,$min_buckets_wanted) {
 $this = $this|0;
 $ht = $ht|0;
 $min_buckets_wanted = $min_buckets_wanted|0;
 var $$01$i$i$i = 0, $$01$i$i$i3 = 0, $$012$i$i = 0, $$03$i$i = 0, $$byval_copy3 = 0, $$pn = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bucknum$0 = 0, $it = 0, $num_probes$0 = 0, $sz$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 28|0;
 $0 = sp;
 $it = sp + 4|0;
 $1 = sp + 16|0;
 $2 = (($this) + 60|0);
 $3 = (($this) + 64|0);
 HEAP32[$3>>2] = 32;
 $4 = (($this) + 76|0);
 HEAP32[$4>>2] = 16;
 $5 = (($this) + 72|0);
 HEAP32[$5>>2] = 6;
 $6 = (($this) + 80|0);
 HEAP8[$6>>0] = 0;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $7 = (__Z15malloc_internaljj10MemLabelIdiPKci(768,16,$$byval_copy3,0,765640,79)|0);
 $8 = HEAP32[$2>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($8,$$byval_copy3);
 }
 HEAP32[$2>>2] = $7;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($7) + (($10*24)|0)|0);
 $12 = ($7|0)==($11|0);
 if (!($12)) {
  $13 = (($this) + 36|0);
  $$01$i$i$i = $7;
  while(1) {
   $14 = ($$01$i$i$i|0)==(0|0);
   if (!($14)) {
    ;HEAP32[$$01$i$i$i+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$$01$i$i$i+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$$01$i$i$i+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$$01$i$i$i+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$$01$i$i$i+16>>2]=HEAP32[$13+16>>2]|0;HEAP32[$$01$i$i$i+20>>2]=HEAP32[$13+20>>2]|0;
   }
   $15 = (($$01$i$i$i) + 24|0);
   $16 = ($15|0)==($11|0);
   if ($16) {
    break;
   } else {
    $$01$i$i$i = $15;
   }
  }
 }
 $17 = (($this) + 68|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($ht) + 68|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($ht) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) - ($22))|0;
 $24 = (Math_fround(($23>>>0)));
 $sz$0$i = 32;
 while(1) {
  $25 = ($sz$0$i>>>0)<($min_buckets_wanted>>>0);
  if (!($25)) {
   $26 = (Math_fround(($sz$0$i>>>0)));
   $27 = Math_fround($26 * Math_fround(0.5));
   $28 = !($24 >= $27);
   if ($28) {
    break;
   }
  }
  $29 = $sz$0$i << 1;
  $sz$0$i = $29;
 }
 $30 = HEAP32[$3>>2]|0;
 $31 = ($sz$0$i>>>0)>($30>>>0);
 if ($31) {
  $32 = ($sz$0$i*24)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,16,$$byval_copy3,0,765640,79)|0);
  $34 = HEAP32[$2>>2]|0;
  $35 = HEAP32[$3>>2]|0;
  $36 = ($35>>>0)>($sz$0$i>>>0);
  $37 = $36 ? $sz$0$i : $35;
  $38 = (($34) + (($37*24)|0)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   $46 = $35;
  } else {
   $$012$i$i = $33;$$03$i$i = $34;
   while(1) {
    $40 = ($$012$i$i|0)==(0|0);
    if (!($40)) {
     ;HEAP32[$$012$i$i+0>>2]=HEAP32[$$03$i$i+0>>2]|0;HEAP32[$$012$i$i+4>>2]=HEAP32[$$03$i$i+4>>2]|0;HEAP32[$$012$i$i+8>>2]=HEAP32[$$03$i$i+8>>2]|0;HEAP32[$$012$i$i+12>>2]=HEAP32[$$03$i$i+12>>2]|0;HEAP32[$$012$i$i+16>>2]=HEAP32[$$03$i$i+16>>2]|0;HEAP32[$$012$i$i+20>>2]=HEAP32[$$03$i$i+20>>2]|0;
    }
    $41 = (($$03$i$i) + 24|0);
    $42 = (($$012$i$i) + 24|0);
    $43 = ($41|0)==($38|0);
    if ($43) {
     break;
    } else {
     $$012$i$i = $42;$$03$i$i = $41;
    }
   }
   $$pre$i = HEAP32[$3>>2]|0;
   $46 = $$pre$i;
  }
  $44 = (($33) + (($sz$0$i*24)|0)|0);
  $45 = ($46|0)==($sz$0$i|0);
  if (!($45)) {
   $47 = (($33) + (($46*24)|0)|0);
   $48 = (($this) + 36|0);
   $$01$i$i$i3 = $47;
   while(1) {
    $49 = ($$01$i$i$i3|0)==(0|0);
    if (!($49)) {
     ;HEAP32[$$01$i$i$i3+0>>2]=HEAP32[$48+0>>2]|0;HEAP32[$$01$i$i$i3+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$$01$i$i$i3+8>>2]=HEAP32[$48+8>>2]|0;HEAP32[$$01$i$i$i3+12>>2]=HEAP32[$48+12>>2]|0;HEAP32[$$01$i$i$i3+16>>2]=HEAP32[$48+16>>2]|0;HEAP32[$$01$i$i$i3+20>>2]=HEAP32[$48+20>>2]|0;
    }
    $50 = (($$01$i$i$i3) + 24|0);
    $51 = ($50|0)==($44|0);
    if ($51) {
     break;
    } else {
     $$01$i$i$i3 = $50;
    }
   }
  }
  $52 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($52,$$byval_copy3);
  HEAP32[$2>>2] = $33;
  HEAP32[$3>>2] = $sz$0$i;
  $53 = (~~(($27))>>>0);
  HEAP32[$4>>2] = $53;
  $54 = Math_fround($26 * Math_fround(0.20000000298023223877));
  $55 = (~~(($54))>>>0);
  HEAP32[$5>>2] = $55;
  HEAP8[$6>>0] = 0;
 }
 $56 = (($ht) + 60|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($ht) + 64|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($57) + (($59*24)|0)|0);
 HEAP32[$it>>2] = $ht;
 $61 = (($it) + 4|0);
 HEAP32[$61>>2] = $57;
 $62 = (($it) + 8|0);
 HEAP32[$62>>2] = $60;
 __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($it);
 $63 = HEAP32[$56>>2]|0;
 $64 = HEAP32[$58>>2]|0;
 $65 = (($63) + (($64*24)|0)|0);
 HEAP32[$1>>2] = $ht;
 $66 = (($1) + 4|0);
 HEAP32[$66>>2] = $65;
 $67 = (($1) + 8|0);
 HEAP32[$67>>2] = $65;
 __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($1);
 $68 = HEAP32[$61>>2]|0;
 $69 = HEAP32[$66>>2]|0;
 $70 = ($68|0)==($69|0);
 if ($70) {
  STACKTOP = sp;return;
 }
 $71 = (($this) + 48|0);
 $72 = (($this) + 52|0);
 $73 = (($this) + 40|0);
 $74 = (($this) + 36|0);
 $75 = (($this) + 44|0);
 $79 = $68;
 while(1) {
  $76 = HEAP32[$3>>2]|0;
  $77 = (($76) + -1)|0;
  $78 = (($79) + 16|0);
  $80 = HEAP32[$78>>2]|0;
  $81 = HEAP32[$2>>2]|0;
  $82 = HEAP32[$72>>2]|0;
  $83 = HEAP32[$73>>2]|0;
  $84 = HEAP32[$74>>2]|0;
  $85 = HEAP32[$75>>2]|0;
  $86 = HEAP32[$71>>2]|0;
  $$pn = $80;$num_probes$0 = 0;
  while(1) {
   $bucknum$0 = $$pn & $77;
   $87 = ((($81) + (($bucknum$0*24)|0)|0) + 16|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($82|0)==($88|0);
   if ($89) {
    $90 = ((($81) + (($bucknum$0*24)|0)|0) + 4|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($83|0)==($91|0);
    if ($92) {
     $93 = (($81) + (($bucknum$0*24)|0)|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = (_strcmp($84,$94)|0);
     $96 = ($95|0)==(0);
     if ($96) {
      $97 = ((($81) + (($bucknum$0*24)|0)|0) + 8|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (_strcmp($85,$98)|0);
      $100 = ($99|0)==(0);
      if ($100) {
       $101 = ((($81) + (($bucknum$0*24)|0)|0) + 12|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ($86|0)==($102|0);
       if ($103) {
        break;
       }
      }
     }
    }
   }
   $104 = (($num_probes$0) + 1)|0;
   $105 = (($104) + ($bucknum$0))|0;
   $$pn = $105;$num_probes$0 = $104;
  }
  $106 = (($81) + (($bucknum$0*24)|0)|0);
  $107 = ($106|0)==(0|0);
  if (!($107)) {
   ;HEAP32[$106+0>>2]=HEAP32[$79+0>>2]|0;HEAP32[$106+4>>2]=HEAP32[$79+4>>2]|0;HEAP32[$106+8>>2]=HEAP32[$79+8>>2]|0;HEAP32[$106+12>>2]=HEAP32[$79+12>>2]|0;HEAP32[$106+16>>2]=HEAP32[$79+16>>2]|0;HEAP32[$106+20>>2]=HEAP32[$79+20>>2]|0;
  }
  $108 = HEAP32[$17>>2]|0;
  $109 = (($108) + 1)|0;
  HEAP32[$17>>2] = $109;
  $110 = (($79) + 24|0);
  HEAP32[$61>>2] = $110;
  __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($it);
  $111 = HEAP32[$56>>2]|0;
  $112 = HEAP32[$58>>2]|0;
  $113 = (($111) + (($112*24)|0)|0);
  HEAP32[$1>>2] = $ht;
  HEAP32[$66>>2] = $113;
  HEAP32[$67>>2] = $113;
  __ZN30dense_hashtable_const_iteratorINSt3__14pairIK7CurveIDjEES2_10hash_curveN14dense_hash_mapIS2_jS5_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEE9SelectKeyES8_SB_E30advance_past_empty_and_deletedEv($1);
  $114 = HEAP32[$61>>2]|0;
  $115 = HEAP32[$66>>2]|0;
  $116 = ($114|0)==($115|0);
  if ($116) {
   break;
  } else {
   $79 = $114;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIP9Transform13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 2;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,765640,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<2)|0);
 $24 = (($23) + ($$0$i3<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$__x>>2]|0;
  HEAP32[$22>>2] = $26;
 }
 $27 = (($23) + ($8<<2)|0);
 $28 = HEAP32[$this>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = $29;
 $31 = $28;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $$sum1 = (($7) - ($33))|0;
 $34 = (($23) + ($$sum1<<2)|0);
 _memcpy(($34|0),($28|0),($32|0))|0;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $34;
 HEAP32[$1>>2] = $27;
 HEAP32[$10>>2] = $24;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z21GetAnimatableBindTypeRK16TypeTreeIterator($variable) {
 $variable = $variable|0;
 var $$ = 0, $$0 = 0, $$0$i35 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond$i13 = 0, $or$cond$i22 = 0, $or$cond$i31 = 0, $or$cond$i4 = 0, $or$cond5$i = 0, $or$cond5$i14 = 0, $or$cond5$i23 = 0, $or$cond5$i32 = 0, $or$cond5$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16TypeTreeIterator4TypeEv($variable)|0);
 $1 = HEAP32[580584>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $5 = $0;
   label = 3;
  } else {
   $3 = ($0|0)==(0|0);
   if ($3) {
    $5 = 0;
    label = 3;
   } else {
    $6 = HEAP32[580528>>2]|0;
    $7 = ($6>>>0)<=($0>>>0);
    $8 = HEAP32[580536>>2]|0;
    $9 = ($8>>>0)>($0>>>0);
    $or$cond$i = $7 & $9;
    if ($or$cond$i) {
     $10 = ($6>>>0)<=($1>>>0);
     $11 = ($8>>>0)>($1>>>0);
     $or$cond5$i = $10 & $11;
     if ($or$cond5$i) {
      $12 = ($0|0)==($1|0);
      if ($12) {
       $$0 = 5;
      } else {
       break;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $13 = (_strcmp($1,$0)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     $$0 = 5;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $4 = ($5|0)==($1|0);
  if ($4) {
   $$0 = 5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $15 = (__ZNK16TypeTreeIterator4TypeEv($variable)|0);
 $16 = HEAP32[580544>>2]|0;
 $17 = ($16|0)==(0|0);
 do {
  if ($17) {
   $20 = $15;
   label = 10;
  } else {
   $18 = ($15|0)==(0|0);
   if ($18) {
    $20 = 0;
    label = 10;
   } else {
    $21 = HEAP32[580528>>2]|0;
    $22 = ($21>>>0)<=($15>>>0);
    $23 = HEAP32[580536>>2]|0;
    $24 = ($23>>>0)>($15>>>0);
    $or$cond$i4 = $22 & $24;
    if ($or$cond$i4) {
     $25 = ($21>>>0)<=($16>>>0);
     $26 = ($23>>>0)>($16>>>0);
     $or$cond5$i5 = $25 & $26;
     if ($or$cond5$i5) {
      $27 = ($15|0)==($16|0);
      if ($27) {
       $$0 = 6;
      } else {
       break;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $28 = (_strcmp($16,$15)|0);
    $29 = ($28|0)==(0);
    if ($29) {
     $$0 = 6;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $19 = ($20|0)==($16|0);
  if ($19) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $30 = (__ZNK16TypeTreeIterator4TypeEv($variable)|0);
 $31 = HEAP32[580744>>2]|0;
 $32 = ($31|0)==(0|0);
 do {
  if ($32) {
   $35 = $30;
   label = 17;
  } else {
   $33 = ($30|0)==(0|0);
   if ($33) {
    $35 = 0;
    label = 17;
   } else {
    $36 = HEAP32[580528>>2]|0;
    $37 = ($36>>>0)<=($30>>>0);
    $38 = HEAP32[580536>>2]|0;
    $39 = ($38>>>0)>($30>>>0);
    $or$cond$i13 = $37 & $39;
    if ($or$cond$i13) {
     $40 = ($36>>>0)<=($31>>>0);
     $41 = ($38>>>0)>($31>>>0);
     $or$cond5$i14 = $40 & $41;
     if ($or$cond5$i14) {
      $42 = ($30|0)==($31|0);
      if ($42) {
       label = 22;
       break;
      } else {
       break;
      }
     }
    }
    $43 = (_strcmp($31,$30)|0);
    $44 = ($43|0)==(0);
    if ($44) {
     label = 22;
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $34 = ($35|0)==($31|0);
  if ($34) {
   label = 22;
  }
 }
 if ((label|0) == 22) {
  $45 = (__ZNK16TypeTreeIterator7GetNodeEv($variable)|0);
  $46 = (($45) + 20|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = $47 & 256;
  $49 = ($48|0)==(0);
  if (!($49)) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $50 = (__ZNK16TypeTreeIterator4TypeEv($variable)|0);
 $51 = HEAP32[580616>>2]|0;
 $52 = ($51|0)==(0|0);
 do {
  if ($52) {
   $55 = $50;
   label = 25;
  } else {
   $53 = ($50|0)==(0|0);
   if ($53) {
    $55 = 0;
    label = 25;
   } else {
    $56 = HEAP32[580528>>2]|0;
    $57 = ($56>>>0)<=($50>>>0);
    $58 = HEAP32[580536>>2]|0;
    $59 = ($58>>>0)>($50>>>0);
    $or$cond$i22 = $57 & $59;
    if ($or$cond$i22) {
     $60 = ($56>>>0)<=($51>>>0);
     $61 = ($58>>>0)>($51>>>0);
     $or$cond5$i23 = $60 & $61;
     if ($or$cond5$i23) {
      $62 = ($50|0)==($51|0);
      if ($62) {
       $$0 = 9;
      } else {
       break;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $63 = (_strcmp($51,$50)|0);
    $64 = ($63|0)==(0);
    if ($64) {
     $$0 = 9;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 25) {
  $54 = ($55|0)==($51|0);
  if ($54) {
   $$0 = 9;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $65 = (__ZNK16TypeTreeIterator4TypeEv($variable)|0);
 $66 = HEAP32[580632>>2]|0;
 $67 = ($66|0)==(0|0);
 do {
  if ($67) {
   $70 = $65;
   label = 32;
  } else {
   $68 = ($65|0)==(0|0);
   if ($68) {
    $70 = 0;
    label = 32;
   } else {
    $71 = HEAP32[580528>>2]|0;
    $72 = ($71>>>0)<=($65>>>0);
    $73 = HEAP32[580536>>2]|0;
    $74 = ($73>>>0)>($65>>>0);
    $or$cond$i31 = $72 & $74;
    if ($or$cond$i31) {
     $75 = ($71>>>0)<=($66>>>0);
     $76 = ($73>>>0)>($66>>>0);
     $or$cond5$i32 = $75 & $76;
     if ($or$cond5$i32) {
      $77 = ($65|0)==($66|0);
      $$0$i35 = $77;
      break;
     }
    }
    $78 = (_strcmp($66,$65)|0);
    $79 = ($78|0)==(0);
    $$0$i35 = $79;
   }
  }
 } while(0);
 if ((label|0) == 32) {
  $69 = ($70|0)==($66|0);
  $$0$i35 = $69;
 }
 $$ = $$0$i35 ? 10 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__16__treeINS_12__value_typeIiPK8TypeTreeEENS_19__map_value_compareIiS5_NS_4lessIiEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiPK8TypeTreeEENS_19__map_value_compareIiS5_NS_4lessIiEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiPK8TypeTreeEENS_19__map_value_compareIiS5_NS_4lessIiEELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN11UnityEngine9Animation36GenerateTransformBindingMapRecursiveER9TransformRKN7mecanim5crc32ER13dynamic_arrayINS0_14BoundTransformELj4EEPKNS3_9animation14AvatarConstantEb($transform,$nameHash,$bindings,$avatar,$hasTransformHierarchy) {
 $transform = $transform|0;
 $nameHash = $nameHash|0;
 $bindings = $bindings|0;
 $avatar = $avatar|0;
 $hasTransformHierarchy = $hasTransformHierarchy|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $childNameHash = 0, $i$01 = 0, $i$02$i = 0, $not$$i = 0, $ret$0$lcssa$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $childNameHash = sp + 4|0;
 $1 = $avatar;
 $2 = HEAP32[$avatar>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($avatar) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($bindings) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 HEAP32[$6>>2] = $8;
 $9 = (($bindings) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($8>>>0)>($11>>>0);
 if ($12) {
  $13 = $10 << 1;
  $14 = ($13|0)==(0);
  $15 = $14 ? 1 : $13;
  $16 = ($11>>>0)<($15>>>0);
  do {
   if ($16) {
    $17 = ($10|0)>(-1);
    if ($17) {
     HEAP32[$9>>2] = $15;
     $18 = HEAP32[$bindings>>2]|0;
     $19 = ($15*12)|0;
     $20 = (($bindings) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     HEAP32[$0>>2] = $21;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($18,$19,4,$$byval_copy1,0,765736,370)|0);
     HEAP32[$bindings>>2] = $22;
     break;
    } else {
     $23 = ($15*12)|0;
     $24 = (($bindings) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$0>>2] = $25;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,4,$$byval_copy1,0,765736,352)|0);
     $27 = HEAP32[$bindings>>2]|0;
     $28 = HEAP32[$6>>2]|0;
     $29 = ($28*12)|0;
     _memcpy(($26|0),($27|0),($29|0))|0;
     HEAP32[$9>>2] = $15;
     HEAP32[$bindings>>2] = $26;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$6>>2]|0;
  $31 = $$pre$i;
 } else {
  $31 = $8;
 }
 $30 = (($31) + -1)|0;
 $32 = HEAP32[$bindings>>2]|0;
 $33 = HEAP32[$nameHash>>2]|0;
 $34 = $33 ^ -1;
 $35 = (($32) + (($30*12)|0)|0);
 HEAP32[$35>>2] = $34;
 $36 = ((($32) + (($30*12)|0)|0) + 4|0);
 HEAP32[$36>>2] = $transform;
 if ($hasTransformHierarchy) {
  $37 = ($3|0)==(0);
  if ($37) {
   $40 = -1;
  } else {
   $38 = (__ZN7mecanim8skeleton16SkeletonFindNodeEPKNS0_8SkeletonEj($4,$34)|0);
   $40 = $38;
  }
  $39 = ((($32) + (($30*12)|0)|0) + 8|0);
  HEAP32[$39>>2] = $40;
 } else {
  $41 = (($avatar) + 24|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($avatar) + 28|0);
  $44 = $43;
  $i$02$i = 0;
  while(1) {
   $45 = ($i$02$i|0)<($42|0);
   if (!($45)) {
    $ret$0$lcssa$i = -1;
    break;
   }
   $46 = HEAP32[$43>>2]|0;
   $47 = (($46) + ($44))|0;
   $48 = $47;
   $49 = (($48) + ($i$02$i<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($i$02$i) + 1)|0;
   $not$$i = ($50|0)==($34|0);
   if ($not$$i) {
    $ret$0$lcssa$i = $i$02$i;
    break;
   } else {
    $i$02$i = $51;
   }
  }
  $52 = ((($32) + (($30*12)|0)|0) + 8|0);
  HEAP32[$52>>2] = $ret$0$lcssa$i;
 }
 $53 = (($transform) + 140|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($transform) + 148|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($54) + ($56<<2)|0);
 $58 = ($56|0)==(0);
 if ($58) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $54;
 }
 while(1) {
  $59 = HEAP32[$i$01>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + 32|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($59)|0);
  __Z16AppendPathToHashRKN7mecanim5crc32EPKc($childNameHash,$nameHash,$63);
  __ZN11UnityEngine9Animation36GenerateTransformBindingMapRecursiveER9TransformRKN7mecanim5crc32ER13dynamic_arrayINS0_14BoundTransformELj4EEPKNS3_9animation14AvatarConstantEb($59,$childNameHash,$bindings,$avatar,$hasTransformHierarchy);
  $64 = (($i$01) + 4|0);
  $65 = ($64|0)==($57|0);
  if ($65) {
   break;
  } else {
   $i$01 = $64;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation31CreateControllerBindingConstantEPKN7mecanim9animation18ControllerConstantEPKNS2_12AnimationSetEPNS1_18ValueArrayConstantEjPKNS2_14AvatarConstantERNS1_6memory9AllocatorE($controller,$animationSet,$valueArrayConstant,$valueArrayConstantSize,$avatar,$alloc) {
 $controller = $controller|0;
 $animationSet = $animationSet|0;
 $valueArrayConstant = $valueArrayConstant|0;
 $valueArrayConstantSize = $valueArrayConstantSize|0;
 $avatar = $avatar|0;
 $alloc = $alloc|0;
 var $$0$i = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $exitcond = 0, $layerIter$07$i = 0, $mask$0$off0$lcssa$i = 0, $maskIter$06$i5 = 0, $phitmp = 0, $phitmp$i = 0, $rootMotionNodePathHash$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,28,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
 } else {
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;
  $5 = $2;
 }
 $4 = (($5) + 16|0);
 HEAP32[$4>>2] = $avatar;
 $6 = (($5) + 20|0);
 HEAP32[$6>>2] = $controller;
 $7 = (($5) + 24|0);
 HEAP32[$7>>2] = $animationSet;
 $8 = HEAP32[$avatar>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = $avatar;
  $11 = (($8) + ($10))|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $phitmp = ($13|0)>(0);
  if ($phitmp) {
   $14 = HEAP32[$alloc>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   $16 = ($13*12)|0;
   $17 = (FUNCTION_TABLE_iiii[$15 & 2047]($alloc,$16,4)|0);
   $18 = ($17|0)==(0|0);
   if ($18) {
    $$0$i2 = 0;
   } else {
    $19 = (($17) + (($13*12)|0)|0);
    $20 = $17;
    while(1) {
     HEAP32[$20>>2] = -1;
     $21 = (($20) + 4|0);
     HEAP32[$21>>2] = -1;
     $22 = (($20) + 8|0);
     HEAP32[$22>>2] = -1;
     $23 = (($20) + 12|0);
     $24 = ($23|0)==($19|0);
     if ($24) {
      $$0$i2 = $17;
      break;
     } else {
      $20 = $23;
     }
    }
   }
   $25 = (($5) + 8|0);
   HEAP32[$25>>2] = $$0$i2;
  }
 }
 $26 = (__ZN7mecanim28CreateValueArrayConstantCopyEPKNS_18ValueArrayConstantEjRNS_6memory9AllocatorE($valueArrayConstant,$valueArrayConstantSize,$alloc)|0);
 HEAP32[$5>>2] = $26;
 $27 = (__ZN7mecanim16CreateValueArrayEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($26,$alloc)|0);
 $28 = (($5) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[$controller>>2]|0;
 $30 = ($29|0)==(0);
 if ($30) {
  $$0$i = 0;
 } else {
  $31 = HEAP32[$alloc>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = (FUNCTION_TABLE_iiii[$32 & 2047]($alloc,$29,1)|0);
  $$0$i = $33;
 }
 $34 = (($5) + 12|0);
 HEAP32[$34>>2] = $$0$i;
 $35 = (($avatar) + 68|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(-1);
 if ($37) {
  $rootMotionNodePathHash$0$i = 0;
 } else {
  $38 = $avatar;
  $39 = HEAP32[$avatar>>2]|0;
  $40 = (($39) + ($38))|0;
  $41 = $40;
  $42 = (($41) + 12|0);
  $43 = $42;
  $44 = HEAP32[$42>>2]|0;
  $45 = (($43) + ($44))|0;
  $46 = $45;
  $47 = (($46) + ($36<<2)|0);
  $48 = HEAP32[$47>>2]|0;
  $rootMotionNodePathHash$0$i = $48;
 }
 $49 = HEAP32[$controller>>2]|0;
 $50 = ($49|0)==(0);
 if ($50) {
  STACKTOP = sp;return ($5|0);
 }
 $51 = (($controller) + 4|0);
 $52 = $51;
 $53 = HEAP32[$51>>2]|0;
 $54 = (($53) + ($52))|0;
 $55 = $54;
 $layerIter$07$i = 0;
 while(1) {
  $56 = (($55) + ($layerIter$07$i<<3)|0);
  $57 = $56;
  $58 = HEAP32[$56>>2]|0;
  $59 = (($57) + ($58))|0;
  $60 = $59;
  $61 = (($60) + 16|0);
  $62 = $61;
  $63 = HEAP32[$61>>2]|0;
  $64 = (($62) + ($63))|0;
  $65 = $64;
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==(0);
  L24: do {
   if ($67) {
    $mask$0$off0$lcssa$i = 1;
   } else {
    $68 = (($65) + 4|0);
    $69 = $68;
    $70 = HEAP32[$68>>2]|0;
    $71 = (($70) + ($69))|0;
    $72 = $71;
    $maskIter$06$i5 = 0;
    while(1) {
     $75 = (($72) + ($maskIter$06$i5<<3)|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==($rootMotionNodePathHash$0$i|0);
     $74 = (($maskIter$06$i5) + 1)|0;
     if ($77) {
      break;
     }
     $73 = ($74>>>0)<($66>>>0);
     if ($73) {
      $maskIter$06$i5 = $74;
     } else {
      $mask$0$off0$lcssa$i = 0;
      break L24;
     }
    }
    $78 = ((($72) + ($maskIter$06$i5<<3)|0) + 4|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = $79 > Math_fround(0.0);
    $phitmp$i = $80&1;
    $mask$0$off0$lcssa$i = $phitmp$i;
   }
  } while(0);
  $81 = (($$0$i) + ($layerIter$07$i)|0);
  HEAP8[$81>>0] = $mask$0$off0$lcssa$i;
  $82 = (($layerIter$07$i) + 1)|0;
  $exitcond = ($82|0)==($49|0);
  if ($exitcond) {
   break;
  } else {
   $layerIter$07$i = $82;
  }
 }
 STACKTOP = sp;return ($5|0);
}
function __ZN11UnityEngine9Animation21AvatarBindingCallbackEPvS1_i($userData,$sender,$eventType) {
 $userData = $userData|0;
 $sender = $sender|0;
 $eventType = $eventType|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond$i$i = 0;
 var $i$01$i = 0, $iter$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($eventType|0)==(2);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($userData) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$userData>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $iter$01$i$i = 0;
  while(1) {
   $5 = (($2) + ($iter$01$i$i<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==($sender|0);
   if ($7) {
    HEAP32[$5>>2] = 0;
   }
   $8 = (($iter$01$i$i) + 1)|0;
   $exitcond$i$i = ($8|0)==($3|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $iter$01$i$i = $8;
   }
  }
 }
 $9 = (($userData) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($userData) + 20|0);
 $i$01$i = 0;
 while(1) {
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + (($i$01$i*12)|0)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($sender|0);
  if ($16) {
   HEAP32[$14>>2] = 0;
  }
  $17 = (($i$01$i) + 1)|0;
  $exitcond = ($17|0)==($10|0);
  if ($exitcond) {
   break;
  } else {
   $i$01$i = $17;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation28RegisterAvatarBindingObjectsEPNS0_21AvatarBindingConstantE($bindingConstant) {
 $bindingConstant = $bindingConstant|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01 = 0, $iter$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bindingConstant) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$bindingConstant>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $iter$01$i = 0;
  while(1) {
   $4 = (($1) + ($iter$01$i<<2)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = (__ZNK6Object8HasEventEPFvPvS0_iEPKv($5,1993,$bindingConstant)|0);
    if (!($7)) {
     $8 = HEAP32[$4>>2]|0;
     __ZN6Object8AddEventEPFvPvS0_iES0_($8,1993,$bindingConstant);
    }
   }
   $9 = (($iter$01$i) + 1)|0;
   $exitcond$i = ($9|0)==($2|0);
   if ($exitcond$i) {
    break;
   } else {
    $iter$01$i = $9;
   }
  }
 }
 $10 = (($bindingConstant) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($bindingConstant) + 20|0);
 $i$01 = 0;
 while(1) {
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + (($i$01*12)|0)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  if (!($17)) {
   $18 = (__ZNK6Object8HasEventEPFvPvS0_iEPKv($16,1993,$bindingConstant)|0);
   if (!($18)) {
    $19 = HEAP32[$13>>2]|0;
    $20 = (($19) + (($i$01*12)|0)|0);
    $21 = HEAP32[$20>>2]|0;
    __ZN6Object8AddEventEPFvPvS0_iES0_($21,1993,$bindingConstant);
   }
  }
  $22 = (($i$01) + 1)|0;
  $23 = HEAP32[$10>>2]|0;
  $24 = ($22>>>0)<($23>>>0);
  if ($24) {
   $i$01 = $22;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation30UnregisterAvatarBindingObjectsEPNS0_21AvatarBindingConstantE($bindingConstant) {
 $bindingConstant = $bindingConstant|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exitcond$i = 0, $i$01 = 0, $iter$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bindingConstant) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$bindingConstant>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $iter$01$i = 0;
  while(1) {
   $4 = (($1) + ($iter$01$i<<2)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    __ZN6Object11RemoveEventEPFvPvS0_iES0_($5,1993,$bindingConstant);
   }
   $7 = (($iter$01$i) + 1)|0;
   $exitcond$i = ($7|0)==($2|0);
   if ($exitcond$i) {
    break;
   } else {
    $iter$01$i = $7;
   }
  }
 }
 $8 = (($bindingConstant) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($bindingConstant) + 20|0);
 $19 = $9;$i$01 = 0;
 while(1) {
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + (($i$01*12)|0)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $18 = $19;
  } else {
   __ZN6Object11RemoveEventEPFvPvS0_iES0_($14,1993,$bindingConstant);
   $$pre = HEAP32[$8>>2]|0;
   $18 = $$pre;
  }
  $16 = (($i$01) + 1)|0;
  $17 = ($16>>>0)<($18>>>0);
  if ($17) {
   $19 = $18;$i$01 = $16;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation31UnregisterGenericBindingObjectsEPNS0_30AnimatorGenericBindingConstantE($bindingConstant) {
 $bindingConstant = $bindingConstant|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i3 = 0, $exitcond$i7 = 0, $iter$01$i = 0, $iter$01$i2 = 0, $iter$01$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bindingConstant) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$bindingConstant>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $iter$01$i = 0;
  while(1) {
   $4 = ((($1) + ($iter$01$i<<4)|0) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    __ZN6Object11RemoveEventEPFvPvS0_iES0_($5,1994,$bindingConstant);
   }
   $7 = (($iter$01$i) + 1)|0;
   $exitcond$i = ($7|0)==($2|0);
   if ($exitcond$i) {
    break;
   } else {
    $iter$01$i = $7;
   }
  }
 }
 $8 = (($bindingConstant) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($bindingConstant) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)>(0);
 if ($12) {
  $iter$01$i2 = 0;
  while(1) {
   $13 = ((($9) + ($iter$01$i2<<4)|0) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    __ZN6Object11RemoveEventEPFvPvS0_iES0_($14,1994,$bindingConstant);
   }
   $16 = (($iter$01$i2) + 1)|0;
   $exitcond$i3 = ($16|0)==($11|0);
   if ($exitcond$i3) {
    break;
   } else {
    $iter$01$i2 = $16;
   }
  }
 }
 $17 = (($bindingConstant) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($bindingConstant) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>(0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $iter$01$i6 = 0;
 while(1) {
  $22 = ((($18) + ($iter$01$i6<<4)|0) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   __ZN6Object11RemoveEventEPFvPvS0_iES0_($23,1994,$bindingConstant);
  }
  $25 = (($iter$01$i6) + 1)|0;
  $exitcond$i7 = ($25|0)==($20|0);
  if ($exitcond$i7) {
   break;
  } else {
   $iter$01$i6 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation27CreateAvatarBindingConstantER9TransformPKN7mecanim9animation14AvatarConstantERNS3_6memory9AllocatorE($root,$avatar,$allocator) {
 $root = $root|0;
 $avatar = $avatar|0;
 $allocator = $allocator|0;
 var $$0 = 0, $$0$i$i = 0, $$01 = 0, $$02$i$i$i = 0, $$byval_copy1 = 0, $$ph = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i = 0, $humanSkIndexIter$013 = 0, $i$011 = 0, $i$03$i$i$i = 0, $i1$08 = 0, $nodeIndex$tr1$i = 0, $phitmp = 0, $reflection$01$i$i$i = 0, $reflection$1$i$i$i = 0, $transformBindingCache = 0, $transformChangedMask$0$lcssa = 0, $transformChangedMask$010 = 0;
 var $transformChangedMask$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 28|0;
 $0 = sp;
 $transformBindingCache = sp + 8|0;
 $1 = sp + 24|0;
 $2 = HEAP32[628512>>2]|0;
 HEAP32[$transformBindingCache>>2] = 0;
 $3 = (($transformBindingCache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (($transformBindingCache) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($transformBindingCache) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = $avatar;
 $7 = HEAP32[$avatar>>2]|0;
 $8 = (($7) + ($6))|0;
 $9 = $8;
 $10 = (($avatar) + 4|0);
 HEAP32[$10>>2] = $9;
 $$02$i$i$i = -1;$i$03$i$i$i = 0;$reflection$01$i$i$i = 0;
 while(1) {
  $11 = $$02$i$i$i & 1;
  $12 = ($11|0)==(0);
  if ($12) {
   $reflection$1$i$i$i = $reflection$01$i$i$i;
  } else {
   $13 = (31 - ($i$03$i$i$i))|0;
   $14 = 1 << $13;
   $15 = $14 | $reflection$01$i$i$i;
   $reflection$1$i$i$i = $15;
  }
  $16 = (($i$03$i$i$i) + 1)|0;
  $17 = $$02$i$i$i >>> 1;
  $exitcond$i$i$i = ($16|0)==(32);
  if ($exitcond$i$i$i) {
   break;
  } else {
   $$02$i$i$i = $17;$i$03$i$i$i = $16;$reflection$01$i$i$i = $reflection$1$i$i$i;
  }
 }
 HEAP32[$1>>2] = $reflection$1$i$i$i;
 __THREW__ = 0;
 invoke_viiiii(111,($root|0),($1|0),($transformBindingCache|0),($avatar|0),1);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L7: do {
  if (!($19)) {
   $20 = HEAP32[$allocator>>2]|0;
   $21 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iiii($21|0,($allocator|0),24,4)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = ($22|0)==(0|0);
    if ($25) {
     $27 = 0;
    } else {
     $27 = $22;
    }
    $26 = (($27) + 16|0);
    HEAP32[$26>>2] = 0;
    $28 = (($27) + 20|0);
    HEAP32[$28>>2] = 0;
    $29 = (($root) + 24|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     $$0$i$i = 0;
    } else {
     $32 = (($30) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $$0$i$i = $33;
    }
    $34 = (($27) + 12|0);
    HEAP32[$34>>2] = $$0$i$i;
    $35 = ($8|0)==(0);
    L16: do {
     if ($35) {
      HEAP32[$27>>2] = 0;
      $$ph = $27;
      label = 15;
     } else {
      $36 = HEAP32[$9>>2]|0;
      HEAP32[$27>>2] = $36;
      $37 = ($36|0)==(0);
      if ($37) {
       $$ph = $27;
       label = 15;
      } else {
       $38 = HEAP32[$allocator>>2]|0;
       $39 = HEAP32[$38>>2]|0;
       $40 = $36 << 2;
       __THREW__ = 0;
       $41 = (invoke_iiii($39|0,($allocator|0),($40|0),4)|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break L7;
       }
       $$pre = HEAP32[$27>>2]|0;
       $45 = (($27) + 4|0);
       HEAP32[$45>>2] = $41;
       $46 = ($$pre|0)==(0);
       if ($46) {
        $87 = $27;$93 = $45;
       } else {
        $47 = $$pre << 2;
        _memset(($41|0),0,($47|0))|0;
        $48 = (($avatar) + 44|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = ($49|0)==(0);
        if ($50) {
         $87 = $27;$93 = $45;
        } else {
         $51 = (($avatar) + 48|0);
         $52 = $51;
         $53 = HEAP32[$51>>2]|0;
         $54 = (($53) + ($52))|0;
         $55 = $54;
         $56 = HEAP32[$55>>2]|0;
         $57 = HEAP32[$45>>2]|0;
         $58 = ($56|0)==(-1);
         if ($58) {
          $72 = -1;$humanSkIndexIter$013 = 1;
         } else {
          $59 = (($9) + 4|0);
          $60 = $59;
          $61 = HEAP32[$59>>2]|0;
          $62 = (($61) + ($60))|0;
          $63 = $62;
          $nodeIndex$tr1$i = $56;
          while(1) {
           $64 = (($57) + ($nodeIndex$tr1$i<<2)|0);
           HEAP32[$64>>2] = (-1);
           $65 = (($63) + ($nodeIndex$tr1$i<<3)|0);
           $66 = HEAP32[$65>>2]|0;
           $67 = ($66|0)==(-1);
           if ($67) {
            $72 = $56;$humanSkIndexIter$013 = 1;
            break;
           } else {
            $nodeIndex$tr1$i = $66;
           }
          }
         }
         while(1) {
          $71 = ($72|0)==(-1);
          if (!($71)) {
           $73 = HEAP32[$45>>2]|0;
           $74 = (($73) + ($72<<2)|0);
           HEAP32[$74>>2] = (-1);
          }
          $85 = ($humanSkIndexIter$013>>>0)<($49>>>0);
          if (!($85)) {
           $87 = $27;$93 = $45;
           break L16;
          }
          $$phi$trans$insert = (($55) + ($humanSkIndexIter$013<<2)|0);
          $$pre16 = HEAP32[$$phi$trans$insert>>2]|0;
          $phitmp = (($humanSkIndexIter$013) + 1)|0;
          $72 = $$pre16;$humanSkIndexIter$013 = $phitmp;
         }
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 15) {
     $44 = (($27) + 4|0);
     HEAP32[$44>>2] = 0;
     $87 = $$ph;$93 = $44;
    }
    $68 = HEAP32[$4>>2]|0;
    $69 = ($68|0)==(0);
    if ($69) {
     $transformChangedMask$0$lcssa = 0;
    } else {
     $70 = HEAP32[$transformBindingCache>>2]|0;
     $i$011 = 0;$transformChangedMask$010 = 0;
     while(1) {
      $89 = ((($70) + (($i$011*12)|0)|0) + 8|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = ($90|0)==(-1);
      if ($91) {
       $transformChangedMask$1 = $transformChangedMask$010;
      } else {
       $92 = HEAP32[$93>>2]|0;
       $94 = (($92) + ($90<<2)|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = ($95|0)==((-1)|0);
       if ($96) {
        $97 = ((($70) + (($i$011*12)|0)|0) + 4|0);
        $98 = HEAP32[$97>>2]|0;
        HEAP32[$94>>2] = $98;
        $99 = $transformChangedMask$010 | 3;
        $transformChangedMask$1 = $99;
       } else {
        $transformChangedMask$1 = $transformChangedMask$010;
       }
      }
      $100 = (($i$011) + 1)|0;
      $101 = ($100>>>0)<($68>>>0);
      if ($101) {
       $i$011 = $100;$transformChangedMask$010 = $transformChangedMask$1;
      } else {
       $transformChangedMask$0$lcssa = $transformChangedMask$1;
       break;
      }
     }
    }
    $86 = HEAP32[$87>>2]|0;
    $88 = ($86|0)==(0);
    if (!($88)) {
     $i1$08 = 0;
     while(1) {
      $102 = HEAP32[$93>>2]|0;
      $103 = (($102) + ($i1$08<<2)|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = ($104|0)==((-1)|0);
      if ($105) {
       HEAP32[$103>>2] = 0;
      }
      $106 = (($i1$08) + 1)|0;
      $107 = ($106>>>0)<($86>>>0);
      if ($107) {
       $i1$08 = $106;
      } else {
       break;
      }
     }
    }
    $108 = (($27) + 8|0);
    HEAP32[$108>>2] = $transformChangedMask$0$lcssa;
    __THREW__ = 0;
    invoke_vi(3687,($27|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if (!($110)) {
     $111 = HEAP32[$5>>2]|0;
     $112 = ($111|0)>(-1);
     if (!($112)) {
      STACKTOP = sp;return ($27|0);
     }
     $113 = HEAP32[$transformBindingCache>>2]|0;
     $114 = HEAP32[$3>>2]|0;
     HEAP32[$0>>2] = $114;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($113|0),($$byval_copy1|0));
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     if ($116) {
      $75 = ___cxa_find_matching_catch()|0;
      $76 = tempRet0;
      $$0 = $75;$$01 = $76;
      ___resumeException($$0|0);
      // unreachable;
     } else {
      HEAP32[$transformBindingCache>>2] = 0;
      STACKTOP = sp;return ($27|0);
     }
    }
   }
  }
 } while(0);
 $77 = ___cxa_find_matching_catch()|0;
 $78 = tempRet0;
 $79 = HEAP32[$5>>2]|0;
 $80 = ($79|0)>(-1);
 if (!($80)) {
  $$0 = $77;$$01 = $78;
  ___resumeException($$0|0);
  // unreachable;
 }
 $81 = HEAP32[$transformBindingCache>>2]|0;
 $82 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $82;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($81|0),($$byval_copy1|0));
 $83 = __THREW__; __THREW__ = 0;
 $84 = $83&1;
 if ($84) {
  $117 = ___cxa_find_matching_catch(0|0)|0;
  $118 = tempRet0;
  ___clang_call_terminate($117);
  // unreachable;
 }
 HEAP32[$transformBindingCache>>2] = 0;
 $$0 = $77;$$01 = $78;
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __ZN11UnityEngine9Animation30CreateAvatarBindingConstantOptER9TransformPKN7mecanim9animation14AvatarConstantERNS3_6memory9AllocatorE($root,$avatar,$allocator) {
 $root = $root|0;
 $avatar = $avatar|0;
 $allocator = $allocator|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$02$i$i$i = 0, $$1 = 0, $$12 = 0, $$byval_copy11 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i$i$i = 0, $exposedCount$0$ = 0;
 var $exposedCount$0$$us = 0, $exposedCount$0$lcssa = 0, $exposedCount$021 = 0, $exposedCount$021$us = 0, $exposedCount$1 = 0, $exposedCount$1$us = 0, $i$020 = 0, $i$020$us = 0, $i$03$i$i$i = 0, $i1$018 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $not$ = 0, $not$$us = 0, $reflection$01$i$i$i = 0, $reflection$1$i$i$i = 0, $transformBindingCache = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy11 = sp + 36|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $transformBindingCache = sp + 16|0;
 $4 = sp + 32|0;
 $5 = HEAP32[628512>>2]|0;
 HEAP32[$transformBindingCache>>2] = 0;
 $6 = (($transformBindingCache) + 4|0);
 HEAP32[$6>>2] = $5;
 $7 = (($transformBindingCache) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($transformBindingCache) + 12|0);
 HEAP32[$8>>2] = 0;
 $$02$i$i$i = -1;$i$03$i$i$i = 0;$reflection$01$i$i$i = 0;
 while(1) {
  $9 = $$02$i$i$i & 1;
  $10 = ($9|0)==(0);
  if ($10) {
   $reflection$1$i$i$i = $reflection$01$i$i$i;
  } else {
   $11 = (31 - ($i$03$i$i$i))|0;
   $12 = 1 << $11;
   $13 = $12 | $reflection$01$i$i$i;
   $reflection$1$i$i$i = $13;
  }
  $14 = (($i$03$i$i$i) + 1)|0;
  $15 = $$02$i$i$i >>> 1;
  $exitcond$i$i$i = ($14|0)==(32);
  if ($exitcond$i$i$i) {
   break;
  } else {
   $$02$i$i$i = $15;$i$03$i$i$i = $14;$reflection$01$i$i$i = $reflection$1$i$i$i;
  }
 }
 HEAP32[$4>>2] = $reflection$1$i$i$i;
 __THREW__ = 0;
 invoke_viiiii(111,($root|0),($4|0),($transformBindingCache|0),($avatar|0),0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if ($17) {
   label = 24;
  } else {
   $18 = $avatar;
   $19 = HEAP32[$avatar>>2]|0;
   $20 = (($19) + ($18))|0;
   $21 = $20;
   $22 = (($avatar) + 4|0);
   HEAP32[$22>>2] = $21;
   $23 = HEAP32[$allocator>>2]|0;
   $24 = HEAP32[$23>>2]|0;
   __THREW__ = 0;
   $25 = (invoke_iiii($24|0,($allocator|0),24,4)|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 24;
   } else {
    $28 = ($25|0)==(0|0);
    if ($28) {
     $29 = 0;
    } else {
     $29 = $25;
    }
    HEAP32[$29>>2] = 0;
    $30 = (($29) + 4|0);
    HEAP32[$30>>2] = 0;
    $31 = (($29) + 8|0);
    HEAP32[$31>>2] = 0;
    $32 = HEAP32[$7>>2]|0;
    $33 = HEAP32[628512>>2]|0;
    $34 = ($32*12)|0;
    HEAP32[$1>>2] = $33;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
    $35 = (invoke_iiiiiii(102,($34|0),4,($$byval_copy11|0),0,(765736|0),352)|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 24;
    } else {
     $38 = ($32|0)>(0);
     L14: do {
      if ($38) {
       $40 = HEAP32[$transformBindingCache>>2]|0;
       $41 = ($20|0)==(0);
       L17: do {
        if ($41) {
         $exposedCount$021$us = 0;$i$020$us = 0;
         while(1) {
          $42 = ((($40) + (($i$020$us*12)|0)|0) + 4|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = (($43) + 156|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = ($45|0)==($root|0);
          if ($46) {
           $47 = (($35) + (($exposedCount$021$us*12)|0)|0);
           HEAP32[$47>>2] = $43;
           $48 = ((($35) + (($exposedCount$021$us*12)|0)|0) + 4|0);
           HEAP32[$48>>2] = -1;
           $49 = ((($35) + (($exposedCount$021$us*12)|0)|0) + 8|0);
           HEAP32[$49>>2] = -1;
           $50 = ((($40) + (($i$020$us*12)|0)|0) + 8|0);
           $51 = HEAP32[$50>>2]|0;
           $52 = ($51|0)==(-1);
           if (!($52)) {
            HEAP32[$48>>2] = $51;
            $53 = HEAP32[$50>>2]|0;
            HEAP32[$49>>2] = $53;
           }
           $54 = HEAP32[$42>>2]|0;
           $55 = (($54) + 24|0);
           $56 = HEAP32[$55>>2]|0;
           __THREW__ = 0;
           $57 = (invoke_iii(2580,($56|0),137)|0);
           $58 = __THREW__; __THREW__ = 0;
           $59 = $58&1;
           if ($59) {
            break;
           }
           $60 = ($57|0)==(0|0);
           if (!($60)) {
            __THREW__ = 0;
            (invoke_ii(3396,($57|0))|0);
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             break;
            }
           }
           $63 = HEAP32[$49>>2]|0;
           $not$$us = ($63|0)!=(-1);
           $64 = $not$$us&1;
           $exposedCount$0$$us = (($64) + ($exposedCount$021$us))|0;
           $exposedCount$1$us = $exposedCount$0$$us;
          } else {
           $exposedCount$1$us = $exposedCount$021$us;
          }
          $65 = (($i$020$us) + 1)|0;
          $66 = ($65|0)<($32|0);
          if ($66) {
           $exposedCount$021$us = $exposedCount$1$us;$i$020$us = $65;
          } else {
           $exposedCount$0$lcssa = $exposedCount$1$us;
           break L17;
          }
         }
         $67 = ___cxa_find_matching_catch()|0;
         $68 = tempRet0;
         $lpad$phi$index = $67;$lpad$phi$index3 = $68;
         break L14;
        } else {
         $exposedCount$021 = 0;$i$020 = 0;
         L18: while(1) {
          $69 = ((($40) + (($i$020*12)|0)|0) + 4|0);
          $70 = HEAP32[$69>>2]|0;
          $71 = (($70) + 156|0);
          $72 = HEAP32[$71>>2]|0;
          $73 = ($72|0)==($root|0);
          if ($73) {
           $85 = (($35) + (($exposedCount$021*12)|0)|0);
           HEAP32[$85>>2] = $70;
           $86 = ((($35) + (($exposedCount$021*12)|0)|0) + 4|0);
           HEAP32[$86>>2] = -1;
           $87 = ((($35) + (($exposedCount$021*12)|0)|0) + 8|0);
           HEAP32[$87>>2] = -1;
           $88 = ((($40) + (($i$020*12)|0)|0) + 8|0);
           $89 = HEAP32[$88>>2]|0;
           $90 = ($89|0)==(-1);
           if (!($90)) {
            HEAP32[$86>>2] = $89;
            $91 = HEAP32[$88>>2]|0;
            HEAP32[$87>>2] = $91;
           }
           $92 = HEAP32[$69>>2]|0;
           $93 = (($92) + 24|0);
           $94 = HEAP32[$93>>2]|0;
           __THREW__ = 0;
           $95 = (invoke_iii(2580,($94|0),137)|0);
           $96 = __THREW__; __THREW__ = 0;
           $97 = $96&1;
           if ($97) {
            break;
           }
           $98 = ($95|0)==(0|0);
           do {
            if (!($98)) {
             __THREW__ = 0;
             $99 = (invoke_ii(3396,($95|0))|0);
             $100 = __THREW__; __THREW__ = 0;
             $101 = $100&1;
             if ($101) {
              break L18;
             }
             $102 = ($99|0)==(0|0);
             if (!($102)) {
              $103 = (($99) + 132|0);
              $104 = HEAP32[$103>>2]|0;
              $105 = ($104|0)==(0);
              if (!($105)) {
               __THREW__ = 0;
               $106 = (invoke_iii(2581,($21|0),($104|0))|0);
               $107 = __THREW__; __THREW__ = 0;
               $108 = $107&1;
               if ($108) {
                break L18;
               }
               $109 = ($106|0)==(-1);
               if ($109) {
                break;
               }
               HEAP32[$87>>2] = $106;
              }
             }
            }
           } while(0);
           $110 = HEAP32[$87>>2]|0;
           $not$ = ($110|0)!=(-1);
           $111 = $not$&1;
           $exposedCount$0$ = (($111) + ($exposedCount$021))|0;
           $exposedCount$1 = $exposedCount$0$;
          } else {
           $exposedCount$1 = $exposedCount$021;
          }
          $112 = (($i$020) + 1)|0;
          $113 = ($112|0)<($32|0);
          if ($113) {
           $exposedCount$021 = $exposedCount$1;$i$020 = $112;
          } else {
           $exposedCount$0$lcssa = $exposedCount$1;
           break L17;
          }
         }
         $78 = ___cxa_find_matching_catch()|0;
         $79 = tempRet0;
         $lpad$phi$index = $78;$lpad$phi$index3 = $79;
         break L14;
        }
       } while(0);
       $114 = (($29) + 16|0);
       HEAP32[$114>>2] = $exposedCount$0$lcssa;
       $115 = ($exposedCount$0$lcssa|0)==(0);
       if ($115) {
        label = 45;
       } else {
        $116 = HEAP32[$allocator>>2]|0;
        $117 = HEAP32[$116>>2]|0;
        $118 = ($exposedCount$0$lcssa*12)|0;
        __THREW__ = 0;
        $119 = (invoke_iiii($117|0,($allocator|0),($118|0),4)|0);
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if ($121) {
         label = 26;
        } else {
         $122 = ($119|0)==(0|0);
         if ($122) {
          $$0$i = 0;
         } else {
          $$0$i = $119;
         }
         $124 = (($29) + 20|0);
         HEAP32[$124>>2] = $$0$i;
         $125 = ($exposedCount$0$lcssa|0)>(0);
         if ($125) {
          $127 = $$0$i;$i1$018 = 0;
          while(1) {
           $126 = (($127) + (($i1$018*12)|0)|0);
           $128 = (($35) + (($i1$018*12)|0)|0);
           ;HEAP32[$126+0>>2]=HEAP32[$128+0>>2]|0;HEAP32[$126+4>>2]=HEAP32[$128+4>>2]|0;HEAP32[$126+8>>2]=HEAP32[$128+8>>2]|0;
           $129 = (($i1$018) + 1)|0;
           $exitcond = ($129|0)==($exposedCount$0$lcssa|0);
           if ($exitcond) {
            label = 49;
            break L14;
           }
           $$pre = HEAP32[$124>>2]|0;
           $127 = $$pre;$i1$018 = $129;
          }
         } else {
          label = 49;
         }
        }
       }
      } else {
       $39 = (($29) + 16|0);
       HEAP32[$39>>2] = 0;
       label = 45;
      }
     } while(0);
     if ((label|0) == 45) {
      $123 = (($29) + 20|0);
      HEAP32[$123>>2] = 0;
      label = 49;
     }
     if ((label|0) == 49) {
      __THREW__ = 0;
      invoke_vi(3687,($29|0));
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       label = 26;
      } else {
       $132 = ($32|0)>(-1);
       if ($132) {
        HEAP32[$2>>2] = $33;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($35|0),($$byval_copy11|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         label = 24;
         break;
        }
       }
       $135 = HEAP32[$8>>2]|0;
       $136 = ($135|0)>(-1);
       if (!($136)) {
        STACKTOP = sp;return ($29|0);
       }
       $137 = HEAP32[$transformBindingCache>>2]|0;
       $138 = HEAP32[$6>>2]|0;
       HEAP32[$3>>2] = $138;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
       invoke_vii(2591,($137|0),($$byval_copy11|0));
       $139 = __THREW__; __THREW__ = 0;
       $140 = $139&1;
       if ($140) {
        $74 = ___cxa_find_matching_catch()|0;
        $75 = tempRet0;
        $$1 = $74;$$12 = $75;
        ___resumeException($$1|0);
        // unreachable;
       } else {
        HEAP32[$transformBindingCache>>2] = 0;
        STACKTOP = sp;return ($29|0);
       }
      }
     }
     if ((label|0) == 26) {
      $80 = ___cxa_find_matching_catch()|0;
      $81 = tempRet0;
      $lpad$phi$index = $80;$lpad$phi$index3 = $81;
     }
     $82 = ($32|0)>(-1);
     if ($82) {
      HEAP32[$0>>2] = $33;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($35|0),($$byval_copy11|0));
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if ($84) {
       $147 = ___cxa_find_matching_catch(0|0)|0;
       $148 = tempRet0;
       ___clang_call_terminate($147);
       // unreachable;
      } else {
       $$0 = $lpad$phi$index;$$01 = $lpad$phi$index3;
      }
     } else {
      $$0 = $lpad$phi$index;$$01 = $lpad$phi$index3;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $76 = ___cxa_find_matching_catch()|0;
  $77 = tempRet0;
  $$0 = $76;$$01 = $77;
 }
 $141 = HEAP32[$8>>2]|0;
 $142 = ($141|0)>(-1);
 if (!($142)) {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$1|0);
  // unreachable;
 }
 $143 = HEAP32[$transformBindingCache>>2]|0;
 $144 = HEAP32[$6>>2]|0;
 HEAP32[$3>>2] = $144;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($143|0),($$byval_copy11|0));
 $145 = __THREW__; __THREW__ = 0;
 $146 = $145&1;
 if ($146) {
  $147 = ___cxa_find_matching_catch(0|0)|0;
  $148 = tempRet0;
  ___clang_call_terminate($147);
  // unreachable;
 }
 HEAP32[$transformBindingCache>>2] = 0;
 $$1 = $$0;$$12 = $$01;
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __ZN11UnityEngine9Animation28DestroyAvatarBindingConstantEPNS0_21AvatarBindingConstantERN7mecanim6memory9AllocatorE($bindingConstant,$allocator) {
 $bindingConstant = $bindingConstant|0;
 $allocator = $allocator|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $i$01$i = 0, $iter$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bindingConstant|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($bindingConstant) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$bindingConstant>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $iter$01$i$i = 0;
  while(1) {
   $5 = (($2) + ($iter$01$i$i<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    __ZN6Object11RemoveEventEPFvPvS0_iES0_($6,1993,$bindingConstant);
   }
   $8 = (($iter$01$i$i) + 1)|0;
   $exitcond$i$i = ($8|0)==($3|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $iter$01$i$i = $8;
   }
  }
 }
 $9 = (($bindingConstant) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 $$pre = (($bindingConstant) + 20|0);
 if (!($11)) {
  $30 = $10;$i$01$i = 0;
  while(1) {
   $12 = HEAP32[$$pre>>2]|0;
   $13 = (($12) + (($i$01$i*12)|0)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    $18 = $30;
   } else {
    __ZN6Object11RemoveEventEPFvPvS0_iES0_($14,1993,$bindingConstant);
    $$pre$i = HEAP32[$9>>2]|0;
    $18 = $$pre$i;
   }
   $16 = (($i$01$i) + 1)|0;
   $17 = ($16>>>0)<($18>>>0);
   if ($17) {
    $30 = $18;$i$01$i = $16;
   } else {
    break;
   }
  }
 }
 $19 = HEAP32[$allocator>>2]|0;
 $20 = (($19) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$21 & 4095]($allocator,$22);
 $23 = HEAP32[$allocator>>2]|0;
 $24 = (($23) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$$pre>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095]($allocator,$26);
 $27 = HEAP32[$allocator>>2]|0;
 $28 = (($27) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$29 & 4095]($allocator,$bindingConstant);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation29CreateAnimatorGenericBindingsERKNS0_20AnimationSetBindingsER9TransformPKN7mecanim9animation14AvatarConstantEPKNS7_18ControllerConstantEbRNS6_6memory9AllocatorE($animationSet,$root,$avatar,$controller,$allowConstantClipSamplingOptimization,$allocator) {
 $animationSet = $animationSet|0;
 $root = $root|0;
 $avatar = $avatar|0;
 $controller = $controller|0;
 $allowConstantClipSamplingOptimization = $allowConstantClipSamplingOptimization|0;
 $allocator = $allocator|0;
 var $$ = 0, $$$v = 0, $$0 = 0, $$0$i = 0, $$0$i22 = 0, $$0$i24 = 0, $$0$i27 = 0, $$01 = 0, $$02$i$i$i = 0, $$1 = 0, $$12 = 0, $$byval_copy17 = 0, $$mask = 0, $$off0 = 0, $$ph$ph$ph$ph$ph = 0, $$ph51$ph$ph$ph$ph = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre82 = 0;
 var $$pre83 = 0, $$pre84 = 0, $$pre88 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0;
 var $exitcond$i$i = 0, $exitcond$i$i$i = 0, $exitcond$i32 = 0, $exitcond5$i = 0, $i$01$i = 0, $i$01$i38 = 0, $i$01$i42 = 0, $i$03$i$i$i = 0, $i$075 = 0, $i1$071 = 0, $i2$065 = 0, $i3$061 = 0, $iter$01$i = 0, $iter$01$i$i = 0, $iter$01$i31 = 0, $lpad$phi$index = 0, $lpad$phi$index6 = 0, $or$cond$i = 0, $phitmp = 0, $phitmp89 = 0;
 var $positionCount$03$us$i = 0, $positionCount$1$us$i = 0, $positionIndex$069 = 0, $positionIndex$1 = 0, $reflection$01$i$i$i = 0, $reflection$1$i$i$i = 0, $rotationCount$04$us$i = 0, $rotationCount$1$us$i = 0, $rotationIndex$068 = 0, $rotationIndex$1 = 0, $scaleCount$02$us$i = 0, $scaleCount$1$us$i = 0, $scaleIndex$070 = 0, $scaleIndex$1 = 0, $transformBindingCache = 0, $transformChangedMask$0$lcssa = 0, $transformChangedMask$072 = 0, $transformChangedMask$149 = 0, $transformIter$01$us$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy17 = sp + 36|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $transformBindingCache = sp + 16|0;
 $4 = sp + 32|0;
 __THREW__ = 0;
 $5 = (invoke_i(122)|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if (!($7)) {
   $8 = $avatar;
   $9 = HEAP32[$avatar>>2]|0;
   $10 = (($9) + ($8))|0;
   $11 = $10;
   $12 = (($avatar) + 4|0);
   HEAP32[$12>>2] = $11;
   $13 = HEAP32[628512>>2]|0;
   HEAP32[$transformBindingCache>>2] = 0;
   $14 = (($transformBindingCache) + 4|0);
   HEAP32[$14>>2] = $13;
   $15 = (($transformBindingCache) + 8|0);
   HEAP32[$15>>2] = 0;
   $16 = (($transformBindingCache) + 12|0);
   HEAP32[$16>>2] = 0;
   $$02$i$i$i = -1;$i$03$i$i$i = 0;$reflection$01$i$i$i = 0;
   while(1) {
    $17 = $$02$i$i$i & 1;
    $18 = ($17|0)==(0);
    if ($18) {
     $reflection$1$i$i$i = $reflection$01$i$i$i;
    } else {
     $19 = (31 - ($i$03$i$i$i))|0;
     $20 = 1 << $19;
     $21 = $20 | $reflection$01$i$i$i;
     $reflection$1$i$i$i = $21;
    }
    $22 = (($i$03$i$i$i) + 1)|0;
    $23 = $$02$i$i$i >>> 1;
    $exitcond$i$i$i = ($22|0)==(32);
    if ($exitcond$i$i$i) {
     break;
    } else {
     $$02$i$i$i = $23;$i$03$i$i$i = $22;$reflection$01$i$i$i = $reflection$1$i$i$i;
    }
   }
   HEAP32[$4>>2] = $reflection$1$i$i$i;
   __THREW__ = 0;
   invoke_viiiii(111,($root|0),($4|0),($transformBindingCache|0),($avatar|0),1);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   L9: do {
    if ($25) {
     $26 = ___cxa_find_matching_catch()|0;
     $27 = tempRet0;
     $329 = $27;$330 = $26;$69 = 0;
     label = 25;
    } else {
     $28 = (($animationSet) + 20|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($29|0)==(0);
     if ($30) {
      $313 = 0;$331 = 0;$72 = 0;
      label = 26;
     } else {
      $31 = $29 << 2;
      HEAP32[$1>>2] = $13;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$1+0>>2]|0;
      $32 = (invoke_iiiiiiii(108,(0|0),($31|0),4,($$byval_copy17|0),0,(765736|0),370)|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       $$ph$ph$ph$ph$ph = $29;$$ph51$ph$ph$ph$ph = 0;
       label = 23;
      } else {
       $$pre = HEAP32[$28>>2]|0;
       $phitmp89 = ($$pre|0)==(0);
       if ($phitmp89) {
        $313 = $29;$331 = 0;$72 = $32;
        label = 26;
       } else {
        $35 = (($animationSet) + 24|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = HEAP32[$15>>2]|0;
        $38 = ($37|0)==(0);
        $39 = HEAP32[$transformBindingCache>>2]|0;
        $i$075 = 0;
        while(1) {
         $40 = (($36) + ($i$075<<3)|0);
         $41 = HEAP32[$40>>2]|0;
         L17: do {
          if ($38) {
           $$0$i = -1;
          } else {
           $i$01$i = 0;
           while(1) {
            $44 = (($39) + (($i$01$i*12)|0)|0);
            $45 = HEAP32[$44>>2]|0;
            $46 = ($45|0)==($41|0);
            $43 = (($i$01$i) + 1)|0;
            if ($46) {
             $$0$i = $i$01$i;
             break L17;
            }
            $42 = ($43>>>0)<($37>>>0);
            if ($42) {
             $i$01$i = $43;
            } else {
             $$0$i = -1;
             break;
            }
           }
          }
         } while(0);
         $47 = (($32) + ($i$075<<2)|0);
         HEAP32[$47>>2] = $$0$i;
         $48 = (($i$075) + 1)|0;
         $49 = HEAP32[$28>>2]|0;
         $50 = ($48>>>0)<($49>>>0);
         if ($50) {
          $i$075 = $48;
         } else {
          $313 = $29;$331 = $49;$72 = $32;
          label = 26;
          break;
         }
        }
       }
      }
     }
     L22: do {
      if ((label|0) == 26) {
       if ($allowConstantClipSamplingOptimization) {
        __THREW__ = 0;
        $73 = (invoke_iiiiii(217,($animationSet|0),($transformBindingCache|0),($72|0),($avatar|0),1)|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         $$ph$ph$ph$ph$ph = $313;$$ph51$ph$ph$ph$ph = $72;
         label = 23;
         break;
        }
        $$pre88 = HEAP32[$28>>2]|0;
        $82 = $73;$84 = $$pre88;
       } else {
        $82 = $331;$84 = $331;
       }
       $76 = (($animationSet) + 36|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = (($77) + 24|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = HEAP32[$79>>2]|0;
       $81 = (($80) + ($82))|0;
       $83 = (($81) - ($84))|0;
       if ($allowConstantClipSamplingOptimization) {
        $85 = (($animationSet) + 16|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = ($82|0)==($86|0);
        $phitmp = $87&1;
        $143 = $phitmp;
       } else {
        $143 = 0;
       }
       $88 = HEAP32[$allocator>>2]|0;
       $89 = HEAP32[$88>>2]|0;
       __THREW__ = 0;
       $90 = (invoke_iiii($89|0,($allocator|0),52,4)|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        $$ph$ph$ph$ph$ph = $313;$$ph51$ph$ph$ph$ph = $72;
        label = 23;
       } else {
        $93 = ($90|0)==(0|0);
        if ($93) {
         $94 = 0;
        } else {
         $94 = $90;
        }
        HEAP32[$94>>2] = $82;
        $95 = ($82|0)==(0);
        if ($95) {
         $$0$i22 = 0;
        } else {
         $96 = HEAP32[$allocator>>2]|0;
         $97 = HEAP32[$96>>2]|0;
         $98 = $82 << 4;
         __THREW__ = 0;
         $99 = (invoke_iiii($97|0,($allocator|0),($98|0),4)|0);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          $$ph$ph$ph$ph$ph = $313;$$ph51$ph$ph$ph$ph = $72;
          label = 23;
          break;
         }
         $102 = ($99|0)==(0|0);
         if ($102) {
          $$0$i22 = 0;
         } else {
          $103 = (($99) + ($82<<4)|0);
          $104 = $99;
          while(1) {
           ;HEAP32[$104+0>>2]=0|0;HEAP32[$104+4>>2]=0|0;HEAP32[$104+8>>2]=0|0;HEAP32[$104+12>>2]=0|0;
           $105 = (($104) + 16|0);
           $106 = ($105|0)==($103|0);
           if ($106) {
            $$0$i22 = $99;
            break;
           } else {
            $104 = $105;
           }
          }
         }
        }
        $107 = (($94) + 4|0);
        HEAP32[$107>>2] = $$0$i22;
        $108 = (($94) + 40|0);
        HEAP32[$108>>2] = -1;
        $109 = (($94) + 44|0);
        HEAP32[$109>>2] = -1;
        $110 = (($94) + 48|0);
        HEAP32[$110>>2] = -1;
        $111 = HEAP32[$animationSet>>2]|0;
        $112 = (($94) + 8|0);
        HEAP32[$112>>2] = $111;
        $113 = ($111|0)==(0);
        if ($113) {
         $$0$i24 = 0;
        } else {
         $114 = HEAP32[$allocator>>2]|0;
         $115 = HEAP32[$114>>2]|0;
         $116 = $111 << 4;
         __THREW__ = 0;
         $117 = (invoke_iiii($115|0,($allocator|0),($116|0),4)|0);
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          $$ph$ph$ph$ph$ph = $313;$$ph51$ph$ph$ph$ph = $72;
          label = 23;
          break;
         }
         $120 = ($117|0)==(0|0);
         if ($120) {
          $$0$i24 = 0;
         } else {
          $121 = (($117) + ($111<<4)|0);
          $122 = $117;
          while(1) {
           ;HEAP32[$122+0>>2]=0|0;HEAP32[$122+4>>2]=0|0;HEAP32[$122+8>>2]=0|0;HEAP32[$122+12>>2]=0|0;
           $123 = (($122) + 16|0);
           $124 = ($123|0)==($121|0);
           if ($124) {
            $$0$i24 = $117;
            break;
           } else {
            $122 = $123;
           }
          }
         }
        }
        $125 = (($94) + 12|0);
        HEAP32[$125>>2] = $$0$i24;
        $126 = (($animationSet) + 8|0);
        $127 = HEAP32[$126>>2]|0;
        $128 = (($94) + 16|0);
        HEAP32[$128>>2] = $127;
        $129 = ($127|0)==(0);
        if ($129) {
         $$0$i27 = 0;
        } else {
         $130 = HEAP32[$allocator>>2]|0;
         $131 = HEAP32[$130>>2]|0;
         $132 = $127 << 4;
         __THREW__ = 0;
         $133 = (invoke_iiii($131|0,($allocator|0),($132|0),4)|0);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          $$ph$ph$ph$ph$ph = $313;$$ph51$ph$ph$ph$ph = $72;
          label = 23;
          break;
         }
         $136 = ($133|0)==(0|0);
         if ($136) {
          $$0$i27 = 0;
         } else {
          $137 = (($133) + ($127<<4)|0);
          $138 = $133;
          while(1) {
           ;HEAP32[$138+0>>2]=0|0;HEAP32[$138+4>>2]=0|0;HEAP32[$138+8>>2]=0|0;HEAP32[$138+12>>2]=0|0;
           $139 = (($138) + 16|0);
           $140 = ($139|0)==($137|0);
           if ($140) {
            $$0$i27 = $133;
            break;
           } else {
            $138 = $139;
           }
          }
         }
        }
        $141 = (($94) + 20|0);
        HEAP32[$141>>2] = $$0$i27;
        $142 = (($94) + 36|0);
        HEAP8[$142>>0] = $143;
        $144 = (($94) + 28|0);
        HEAP8[$144>>0] = 0;
        $145 = HEAP32[$94>>2]|0;
        $146 = ($145|0)==(0);
        if ($146) {
         $transformChangedMask$0$lcssa = 0;
        } else {
         $147 = (($animationSet) + 24|0);
         $148 = HEAP32[$transformBindingCache>>2]|0;
         $$pre82 = HEAP32[$147>>2]|0;
         $152 = $$pre82;$169 = 0;$i1$071 = 0;$positionIndex$069 = 0;$rotationIndex$068 = 0;$scaleIndex$070 = 0;$transformChangedMask$072 = 0;
         while(1) {
          $149 = (($72) + ($i1$071<<2)|0);
          $150 = HEAP32[$149>>2]|0;
          $151 = ((($152) + ($i1$071<<3)|0) + 4|0);
          $153 = HEAP32[$151>>2]|0;
          $154 = HEAP32[$107>>2]|0;
          $155 = ((($154) + ($i1$071<<4)|0) + 4|0);
          HEAP32[$155>>2] = $153;
          $156 = ($150|0)==(-1);
          if ($156) {
           $157 = ((($154) + ($i1$071<<4)|0) + 12|0);
           HEAP32[$157>>2] = 0;
           $$pre83 = HEAP32[$147>>2]|0;
           $$phi$trans$insert = ((($$pre83) + ($i1$071<<3)|0) + 4|0);
           $$pre84 = HEAP32[$$phi$trans$insert>>2]|0;
           $$off0 = 0;$333 = $169;$334 = $$pre84;$335 = $$pre83;$transformChangedMask$149 = $transformChangedMask$072;
          } else {
           $158 = ((($148) + (($150*12)|0)|0) + 4|0);
           $159 = HEAP32[$158>>2]|0;
           $160 = ((($154) + ($i1$071<<4)|0) + 12|0);
           HEAP32[$160>>2] = $159;
           $161 = HEAP32[$107>>2]|0;
           $162 = ((($161) + ($i1$071<<4)|0) + 12|0);
           $163 = HEAP32[$162>>2]|0;
           $164 = (($163) + 8|0);
           $165 = HEAP32[$164>>2]|0;
           $$mask = $165 & -2097152;
           $166 = ($$mask|0)==(469762048);
           $167 = $166&1;
           $168 = $169&255;
           $170 = $167 | $168;
           $171 = $170&255;
           HEAP8[$144>>0] = $171;
           $172 = HEAP32[$147>>2]|0;
           $173 = ((($172) + ($i1$071<<3)|0) + 4|0);
           $174 = HEAP32[$173>>2]|0;
           $175 = ($174|0)==(3);
           $$$v = $175 ? 11 : 3;
           $$ = $$$v | $transformChangedMask$072;
           $176 = HEAP32[$158>>2]|0;
           $177 = ($176|0)==($root|0);
           $$off0 = $177;$333 = $171;$334 = $174;$335 = $172;$transformChangedMask$149 = $$;
          }
          if ((($334|0) == 2)) {
           if ($$off0) {
            HEAP32[$109>>2] = $rotationIndex$068;
           }
           $179 = (($rotationIndex$068) + 1)|0;
           $positionIndex$1 = $positionIndex$069;$rotationIndex$1 = $179;$scaleIndex$1 = $scaleIndex$070;
          } else if ((($334|0) == 1)) {
           if ($$off0) {
            HEAP32[$108>>2] = $positionIndex$069;
           }
           $178 = (($positionIndex$069) + 1)|0;
           $positionIndex$1 = $178;$rotationIndex$1 = $rotationIndex$068;$scaleIndex$1 = $scaleIndex$070;
          } else if ((($334|0) == 3)) {
           if ($$off0) {
            HEAP32[$110>>2] = $scaleIndex$070;
           }
           $180 = (($scaleIndex$070) + 1)|0;
           $positionIndex$1 = $positionIndex$069;$rotationIndex$1 = $rotationIndex$068;$scaleIndex$1 = $180;
          } else {
           $positionIndex$1 = $positionIndex$069;$rotationIndex$1 = $rotationIndex$068;$scaleIndex$1 = $scaleIndex$070;
          }
          $181 = (($i1$071) + 1)|0;
          $182 = HEAP32[$94>>2]|0;
          $183 = ($181>>>0)<($182>>>0);
          if ($183) {
           $152 = $335;$169 = $333;$i1$071 = $181;$positionIndex$069 = $positionIndex$1;$rotationIndex$068 = $rotationIndex$1;$scaleIndex$070 = $scaleIndex$1;$transformChangedMask$072 = $transformChangedMask$149;
          } else {
           $transformChangedMask$0$lcssa = $transformChangedMask$149;
           break;
          }
         }
        }
        $184 = (($94) + 24|0);
        HEAP32[$184>>2] = $transformChangedMask$0$lcssa;
        $185 = HEAP32[$112>>2]|0;
        $186 = ($185|0)==(0);
        L79: do {
         if (!($186)) {
          $187 = (($animationSet) + 4|0);
          $188 = HEAP32[$15>>2]|0;
          $189 = ($188|0)==(0);
          $190 = HEAP32[$transformBindingCache>>2]|0;
          $i2$065 = 0;
          L81: while(1) {
           $197 = HEAP32[$125>>2]|0;
           $198 = ((($197) + ($i2$065<<4)|0) + 12|0);
           HEAP32[$198>>2] = 0;
           $199 = HEAP32[$125>>2]|0;
           $200 = ((($199) + ($i2$065<<4)|0) + 4|0);
           HEAP32[$200>>2] = 0;
           $201 = HEAP32[$187>>2]|0;
           $202 = (($201) + ($i2$065<<4)|0);
           $203 = HEAP32[$202>>2]|0;
           L83: do {
            if (!($189)) {
             $i$01$i38 = 0;
             while(1) {
              $206 = (($190) + (($i$01$i38*12)|0)|0);
              $207 = HEAP32[$206>>2]|0;
              $208 = ($207|0)==($203|0);
              $205 = (($i$01$i38) + 1)|0;
              if ($208) {
               break;
              }
              $204 = ($205>>>0)<($188>>>0);
              if ($204) {
               $i$01$i38 = $205;
              } else {
               break L83;
              }
             }
             $209 = ($i$01$i38|0)==(-1);
             if (!($209)) {
              $210 = (($201) + ($i2$065<<4)|0);
              $211 = ((($190) + (($i$01$i38*12)|0)|0) + 4|0);
              $212 = HEAP32[$211>>2]|0;
              $213 = (($199) + ($i2$065<<4)|0);
              __THREW__ = 0;
              (invoke_iiiii(269,($5|0),($210|0),($212|0),($213|0))|0);
              $214 = __THREW__; __THREW__ = 0;
              $215 = $214&1;
              if ($215) {
               break L81;
              }
             }
            }
           } while(0);
           $216 = (($i2$065) + 1)|0;
           $217 = HEAP32[$112>>2]|0;
           $218 = ($216>>>0)<($217>>>0);
           if ($218) {
            $i2$065 = $216;
           } else {
            break L79;
           }
          }
          $63 = ___cxa_find_matching_catch()|0;
          $64 = tempRet0;
          $332 = $72;$68 = $313;$lpad$phi$index = $63;$lpad$phi$index6 = $64;
          break L22;
         }
        } while(0);
        $191 = HEAP32[$128>>2]|0;
        $192 = ($191|0)==(0);
        L92: do {
         if (!($192)) {
          $193 = (($animationSet) + 12|0);
          $194 = HEAP32[$15>>2]|0;
          $195 = ($194|0)==(0);
          $196 = HEAP32[$transformBindingCache>>2]|0;
          $i3$061 = 0;
          L94: while(1) {
           $219 = HEAP32[$141>>2]|0;
           $220 = ((($219) + ($i3$061<<4)|0) + 12|0);
           HEAP32[$220>>2] = 0;
           $221 = HEAP32[$141>>2]|0;
           $222 = ((($221) + ($i3$061<<4)|0) + 4|0);
           HEAP32[$222>>2] = 0;
           $223 = HEAP32[$193>>2]|0;
           $224 = (($223) + ($i3$061<<4)|0);
           $225 = HEAP32[$224>>2]|0;
           L96: do {
            if (!($195)) {
             $i$01$i42 = 0;
             while(1) {
              $228 = (($196) + (($i$01$i42*12)|0)|0);
              $229 = HEAP32[$228>>2]|0;
              $230 = ($229|0)==($225|0);
              $227 = (($i$01$i42) + 1)|0;
              if ($230) {
               break;
              }
              $226 = ($227>>>0)<($194>>>0);
              if ($226) {
               $i$01$i42 = $227;
              } else {
               break L96;
              }
             }
             $231 = ($i$01$i42|0)==(-1);
             if ($231) {
              break;
             }
             $232 = (($223) + ($i3$061<<4)|0);
             $233 = ((($196) + (($i$01$i42*12)|0)|0) + 4|0);
             $234 = HEAP32[$233>>2]|0;
             $235 = (($221) + ($i3$061<<4)|0);
             __THREW__ = 0;
             (invoke_iiiii(270,($5|0),($232|0),($234|0),($235|0))|0);
             $236 = __THREW__; __THREW__ = 0;
             $237 = $236&1;
             if ($237) {
              break L94;
             }
            }
           } while(0);
           $238 = (($i3$061) + 1)|0;
           $239 = HEAP32[$128>>2]|0;
           $240 = ($238>>>0)<($239>>>0);
           if ($240) {
            $i3$061 = $238;
           } else {
            break L92;
           }
          }
          $61 = ___cxa_find_matching_catch()|0;
          $62 = tempRet0;
          $332 = $72;$68 = $313;$lpad$phi$index = $61;$lpad$phi$index6 = $62;
          break L22;
         }
        } while(0);
        $241 = HEAP32[$76>>2]|0;
        $242 = (($241) + 24|0);
        $243 = HEAP32[$242>>2]|0;
        __THREW__ = 0;
        $244 = (invoke_iiiiiii(121,($controller|0),($241|0),($243|0),($83|0),($avatar|0),($allocator|0))|0);
        $245 = __THREW__; __THREW__ = 0;
        $246 = $245&1;
        if ($246) {
         $$ph$ph$ph$ph$ph = $313;$$ph51$ph$ph$ph$ph = $72;
         label = 23;
        } else {
         $247 = (($94) + 32|0);
         HEAP32[$247>>2] = $244;
         $248 = HEAP32[$transformBindingCache>>2]|0;
         $249 = (($244) + 8|0);
         $250 = HEAP32[$249>>2]|0;
         $251 = ($250|0)!=(0|0);
         $252 = ($82|0)>(0);
         $or$cond$i = $251 & $252;
         if ($or$cond$i) {
          $253 = (($animationSet) + 24|0);
          $$pre$i = HEAP32[$253>>2]|0;
          $positionCount$03$us$i = -1;$rotationCount$04$us$i = -1;$scaleCount$02$us$i = -1;$transformIter$01$us$i = 0;
          while(1) {
           $254 = ((($$pre$i) + ($transformIter$01$us$i<<3)|0) + 4|0);
           $255 = HEAP32[$254>>2]|0;
           $256 = ($255|0)==(3);
           do {
            if ($256) {
             $259 = (($scaleCount$02$us$i) + 1)|0;
             $positionCount$1$us$i = $positionCount$03$us$i;$rotationCount$1$us$i = $rotationCount$04$us$i;$scaleCount$1$us$i = $259;
            } else {
             if ((($255|0) == 1)) {
              $257 = (($positionCount$03$us$i) + 1)|0;
              $positionCount$1$us$i = $257;$rotationCount$1$us$i = $rotationCount$04$us$i;$scaleCount$1$us$i = $scaleCount$02$us$i;
              break;
             } else if ((($255|0) == 2)) {
              $258 = (($rotationCount$04$us$i) + 1)|0;
              $positionCount$1$us$i = $positionCount$03$us$i;$rotationCount$1$us$i = $258;$scaleCount$1$us$i = $scaleCount$02$us$i;
              break;
             } else {
              $positionCount$1$us$i = $positionCount$03$us$i;$rotationCount$1$us$i = $rotationCount$04$us$i;$scaleCount$1$us$i = $scaleCount$02$us$i;
              break;
             }
            }
           } while(0);
           $260 = (($72) + ($transformIter$01$us$i<<2)|0);
           $261 = HEAP32[$260>>2]|0;
           $262 = ($261|0)==(-1);
           do {
            if (!($262)) {
             $263 = ((($248) + (($261*12)|0)|0) + 8|0);
             $264 = HEAP32[$263>>2]|0;
             $265 = ($264|0)==(-1);
             if ($265) {
              break;
             }
             if ($256) {
              $268 = ((($250) + (($264*12)|0)|0) + 8|0);
              HEAP32[$268>>2] = $scaleCount$1$us$i;
              break;
             }
             if ((($255|0) == 2)) {
              $267 = ((($250) + (($264*12)|0)|0) + 4|0);
              HEAP32[$267>>2] = $rotationCount$1$us$i;
              break;
             } else if ((($255|0) == 1)) {
              $266 = (($250) + (($264*12)|0)|0);
              HEAP32[$266>>2] = $positionCount$1$us$i;
              break;
             } else {
              break;
             }
            }
           } while(0);
           $269 = (($transformIter$01$us$i) + 1)|0;
           $exitcond5$i = ($269|0)==($82|0);
           if ($exitcond5$i) {
            break;
           } else {
            $positionCount$03$us$i = $positionCount$1$us$i;$rotationCount$04$us$i = $rotationCount$1$us$i;$scaleCount$02$us$i = $scaleCount$1$us$i;$transformIter$01$us$i = $269;
           }
          }
         }
         $270 = HEAP32[$107>>2]|0;
         $271 = HEAP32[$94>>2]|0;
         $272 = ($271|0)>(0);
         L128: do {
          if ($272) {
           $iter$01$i$i = 0;
           L130: while(1) {
            $273 = ((($270) + ($iter$01$i$i<<4)|0) + 12|0);
            $274 = HEAP32[$273>>2]|0;
            $275 = ($274|0)==(0|0);
            do {
             if (!($275)) {
              __THREW__ = 0;
              $276 = (invoke_iiii(1586,($274|0),(1994|0),($94|0))|0);
              $277 = __THREW__; __THREW__ = 0;
              $278 = $277&1;
              if ($278) {
               break L130;
              }
              if ($276) {
               break;
              }
              $279 = HEAP32[$273>>2]|0;
              __THREW__ = 0;
              invoke_viii(1995,($279|0),(1994|0),($94|0));
              $280 = __THREW__; __THREW__ = 0;
              $281 = $280&1;
              if ($281) {
               break L130;
              }
             }
            } while(0);
            $282 = (($iter$01$i$i) + 1)|0;
            $exitcond$i$i = ($282|0)==($271|0);
            if ($exitcond$i$i) {
             break L128;
            } else {
             $iter$01$i$i = $282;
            }
           }
           $59 = ___cxa_find_matching_catch()|0;
           $60 = tempRet0;
           $332 = $72;$68 = $313;$lpad$phi$index = $59;$lpad$phi$index6 = $60;
           break L22;
          }
         } while(0);
         $283 = HEAP32[$125>>2]|0;
         $284 = HEAP32[$112>>2]|0;
         $285 = ($284|0)>(0);
         L139: do {
          if ($285) {
           $iter$01$i31 = 0;
           L141: while(1) {
            $286 = ((($283) + ($iter$01$i31<<4)|0) + 12|0);
            $287 = HEAP32[$286>>2]|0;
            $288 = ($287|0)==(0|0);
            do {
             if (!($288)) {
              __THREW__ = 0;
              $289 = (invoke_iiii(1586,($287|0),(1994|0),($94|0))|0);
              $290 = __THREW__; __THREW__ = 0;
              $291 = $290&1;
              if ($291) {
               break L141;
              }
              if ($289) {
               break;
              }
              $292 = HEAP32[$286>>2]|0;
              __THREW__ = 0;
              invoke_viii(1995,($292|0),(1994|0),($94|0));
              $293 = __THREW__; __THREW__ = 0;
              $294 = $293&1;
              if ($294) {
               break L141;
              }
             }
            } while(0);
            $295 = (($iter$01$i31) + 1)|0;
            $exitcond$i32 = ($295|0)==($284|0);
            if ($exitcond$i32) {
             break L139;
            } else {
             $iter$01$i31 = $295;
            }
           }
           $57 = ___cxa_find_matching_catch()|0;
           $58 = tempRet0;
           $332 = $72;$68 = $313;$lpad$phi$index = $57;$lpad$phi$index6 = $58;
           break L22;
          }
         } while(0);
         $296 = HEAP32[$141>>2]|0;
         $297 = HEAP32[$128>>2]|0;
         $298 = ($297|0)>(0);
         L150: do {
          if ($298) {
           $iter$01$i = 0;
           L152: while(1) {
            $299 = ((($296) + ($iter$01$i<<4)|0) + 12|0);
            $300 = HEAP32[$299>>2]|0;
            $301 = ($300|0)==(0|0);
            do {
             if (!($301)) {
              __THREW__ = 0;
              $302 = (invoke_iiii(1586,($300|0),(1994|0),($94|0))|0);
              $303 = __THREW__; __THREW__ = 0;
              $304 = $303&1;
              if ($304) {
               break L152;
              }
              if ($302) {
               break;
              }
              $305 = HEAP32[$299>>2]|0;
              __THREW__ = 0;
              invoke_viii(1995,($305|0),(1994|0),($94|0));
              $306 = __THREW__; __THREW__ = 0;
              $307 = $306&1;
              if ($307) {
               break L152;
              }
             }
            } while(0);
            $308 = (($iter$01$i) + 1)|0;
            $exitcond$i = ($308|0)==($297|0);
            if ($exitcond$i) {
             break L150;
            } else {
             $iter$01$i = $308;
            }
           }
           $55 = ___cxa_find_matching_catch()|0;
           $56 = tempRet0;
           $332 = $72;$68 = $313;$lpad$phi$index = $55;$lpad$phi$index6 = $56;
           break L22;
          }
         } while(0);
         $309 = HEAP32[$247>>2]|0;
         __THREW__ = 0;
         invoke_viiii(411,($94|0),($avatar|0),1,($309|0));
         $310 = __THREW__; __THREW__ = 0;
         $311 = $310&1;
         if ($311) {
          $$ph$ph$ph$ph$ph = $313;$$ph51$ph$ph$ph$ph = $72;
          label = 23;
          break;
         }
         $312 = ($313|0)>(-1);
         do {
          if ($312) {
           HEAP32[$2>>2] = $13;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$2+0>>2]|0;
           invoke_vii(2591,($72|0),($$byval_copy17|0));
           $314 = __THREW__; __THREW__ = 0;
           $315 = $314&1;
           if (!($315)) {
            break;
           }
           $53 = ___cxa_find_matching_catch()|0;
           $54 = tempRet0;
           $$0 = $53;$$01 = $54;
           break L9;
          }
         } while(0);
         $316 = HEAP32[$16>>2]|0;
         $317 = ($316|0)>(-1);
         if (!($317)) {
          STACKTOP = sp;return ($94|0);
         }
         $318 = HEAP32[$14>>2]|0;
         HEAP32[$3>>2] = $318;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$3+0>>2]|0;
         invoke_vii(2591,($248|0),($$byval_copy17|0));
         $319 = __THREW__; __THREW__ = 0;
         $320 = $319&1;
         if ($320) {
          break L1;
         }
         HEAP32[$transformBindingCache>>2] = 0;
         STACKTOP = sp;return ($94|0);
        }
       }
      }
     } while(0);
     if ((label|0) == 23) {
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      $332 = $$ph51$ph$ph$ph$ph;$68 = $$ph$ph$ph$ph$ph;$lpad$phi$index = $65;$lpad$phi$index6 = $66;
     }
     $67 = ($68|0)>(-1);
     if ($67) {
      $329 = $lpad$phi$index6;$330 = $lpad$phi$index;$69 = $332;
      label = 25;
     } else {
      $$0 = $lpad$phi$index;$$01 = $lpad$phi$index6;
     }
    }
   } while(0);
   if ((label|0) == 25) {
    HEAP32[$0>>2] = $13;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($69|0),($$byval_copy17|0));
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $327 = ___cxa_find_matching_catch(0|0)|0;
     $328 = tempRet0;
     ___clang_call_terminate($327);
     // unreachable;
    } else {
     $$0 = $330;$$01 = $329;
    }
   }
   $321 = HEAP32[$16>>2]|0;
   $322 = ($321|0)>(-1);
   if (!($322)) {
    $$1 = $$0;$$12 = $$01;
    ___resumeException($$1|0);
    // unreachable;
   }
   $323 = HEAP32[$transformBindingCache>>2]|0;
   $324 = HEAP32[$14>>2]|0;
   HEAP32[$3>>2] = $324;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($323|0),($$byval_copy17|0));
   $325 = __THREW__; __THREW__ = 0;
   $326 = $325&1;
   if ($326) {
    $327 = ___cxa_find_matching_catch(0|0)|0;
    $328 = tempRet0;
    ___clang_call_terminate($327);
    // unreachable;
   }
   HEAP32[$transformBindingCache>>2] = 0;
   $$1 = $$0;$$12 = $$01;
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $51 = ___cxa_find_matching_catch()|0;
 $52 = tempRet0;
 $$1 = $51;$$12 = $52;
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __ZN11UnityEngine9AnimationL56CalculateTransformBindingSizeBasedOnConstantOptimizationERKNS0_20AnimationSetBindingsERK13dynamic_arrayINS0_14BoundTransformELj4EEPKiPKN7mecanim9animation14AvatarConstantEb($animationSet,$transformBindingCache,$genericTransformBindingToBindingCache,$avatar,$hasTransformHierarchy) {
 $animationSet = $animationSet|0;
 $transformBindingCache = $transformBindingCache|0;
 $genericTransformBindingToBindingCache = $genericTransformBindingToBindingCache|0;
 $avatar = $avatar|0;
 $hasTransformHierarchy = $hasTransformHierarchy|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $constantDefaultValueIndex$07 = 0, $constantDefaultValueIndex$11 = 0, $constantDefaultValueIndex$2 = 0, $exitcond = 0, $highestMismatch$0$lcssa = 0, $highestMismatch$08 = 0, $highestMismatch$1$ = 0, $highestMismatch$13 = 0, $highestMismatch$3 = 0;
 var $i$05 = 0, $k$02 = 0, $values = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $values = sp;
 if ($hasTransformHierarchy) {
  $18 = 0;$41 = 0;
 } else {
  $0 = $avatar;
  $1 = HEAP32[$avatar>>2]|0;
  $2 = (($1) + ($0))|0;
  $3 = $2;
  $4 = (($avatar) + 4|0);
  HEAP32[$4>>2] = $3;
  $5 = (($avatar) + 8|0);
  $6 = $5;
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + ($6))|0;
  $9 = $8;
  $10 = (($avatar) + 12|0);
  HEAP32[$10>>2] = $9;
  $18 = $9;$41 = $3;
 }
 $11 = (($animationSet) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($animationSet) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)<($14>>>0);
 if (!($15)) {
  $highestMismatch$0$lcssa = $12;
  STACKTOP = sp;return ($highestMismatch$0$lcssa|0);
 }
 $16 = (($animationSet) + 24|0);
 $17 = (($18) + 4|0);
 $19 = $17;
 $20 = (($values) + 4|0);
 $21 = (($values) + 8|0);
 $22 = (($values) + 12|0);
 $23 = (($animationSet) + 32|0);
 $constantDefaultValueIndex$07 = 0;$highestMismatch$08 = $12;$i$05 = $12;
 while(1) {
  $24 = HEAP32[$16>>2]|0;
  $25 = ((($24) + ($i$05<<3)|0) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__ZN11UnityEngine9Animation27GetCurveCountForBindingTypeEj($26)|0);
  do {
   if ($hasTransformHierarchy) {
    $28 = (($genericTransformBindingToBindingCache) + ($i$05<<2)|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==(-1);
    if ($30) {
     $31 = (($27) + ($constantDefaultValueIndex$07))|0;
     $constantDefaultValueIndex$2 = $31;$highestMismatch$3 = $highestMismatch$08;
     break;
    }
    $32 = HEAP32[$transformBindingCache>>2]|0;
    $33 = ((($32) + (($29*12)|0)|0) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$25>>2]|0;
    if ((($35|0) == 1)) {
     $36 = (($34) + 44|0);
     ;HEAP32[$values+0>>2]=HEAP32[$36+0>>2]|0;HEAP32[$values+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$values+8>>2]=HEAP32[$36+8>>2]|0;
     label = 18;
     break;
    } else if ((($35|0) == 3)) {
     $38 = (($34) + 56|0);
     ;HEAP32[$values+0>>2]=HEAP32[$38+0>>2]|0;HEAP32[$values+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$values+8>>2]=HEAP32[$38+8>>2]|0;
     label = 18;
     break;
    } else if ((($35|0) == 2)) {
     $37 = (($34) + 28|0);
     ;HEAP32[$values+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$values+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$values+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$values+12>>2]=HEAP32[$37+12>>2]|0;
     label = 18;
     break;
    } else {
     label = 18;
     break;
    }
   } else {
    $39 = (($24) + ($i$05<<3)|0);
    $40 = HEAP32[$39>>2]|0;
    $42 = (__ZN7mecanim8skeleton16SkeletonFindNodeEPKNS0_8SkeletonEj($41,$40)|0);
    $43 = ($42|0)==(-1);
    if ($43) {
     $44 = (($27) + ($constantDefaultValueIndex$07))|0;
     $constantDefaultValueIndex$2 = $44;$highestMismatch$3 = $highestMismatch$08;
     break;
    }
    $45 = HEAP32[$17>>2]|0;
    $46 = (($45) + ($19))|0;
    $47 = $46;
    $48 = HEAP32[$25>>2]|0;
    if ((($48|0) == 2)) {
     $57 = ((($47) + (($42*48)|0)|0) + 16|0);
     $58 = Math_fround(HEAPF32[$57>>2]);
     HEAPF32[$values>>2] = $58;
     $59 = ((($47) + (($42*48)|0)|0) + 20|0);
     $60 = Math_fround(HEAPF32[$59>>2]);
     HEAPF32[$20>>2] = $60;
     $61 = ((($47) + (($42*48)|0)|0) + 24|0);
     $62 = Math_fround(HEAPF32[$61>>2]);
     HEAPF32[$21>>2] = $62;
     $63 = ((($47) + (($42*48)|0)|0) + 28|0);
     $64 = Math_fround(HEAPF32[$63>>2]);
     HEAPF32[$22>>2] = $64;
     label = 18;
     break;
    } else if ((($48|0) == 3)) {
     $65 = ((($47) + (($42*48)|0)|0) + 32|0);
     $66 = Math_fround(HEAPF32[$65>>2]);
     HEAPF32[$values>>2] = $66;
     $67 = ((($47) + (($42*48)|0)|0) + 36|0);
     $68 = Math_fround(HEAPF32[$67>>2]);
     HEAPF32[$20>>2] = $68;
     $69 = ((($47) + (($42*48)|0)|0) + 40|0);
     $70 = Math_fround(HEAPF32[$69>>2]);
     HEAPF32[$21>>2] = $70;
     $71 = ((($47) + (($42*48)|0)|0) + 44|0);
     $72 = Math_fround(HEAPF32[$71>>2]);
     HEAPF32[$22>>2] = $72;
     label = 18;
     break;
    } else if ((($48|0) == 1)) {
     $49 = (($47) + (($42*48)|0)|0);
     $50 = Math_fround(HEAPF32[$49>>2]);
     HEAPF32[$values>>2] = $50;
     $51 = ((($47) + (($42*48)|0)|0) + 4|0);
     $52 = Math_fround(HEAPF32[$51>>2]);
     HEAPF32[$20>>2] = $52;
     $53 = ((($47) + (($42*48)|0)|0) + 8|0);
     $54 = Math_fround(HEAPF32[$53>>2]);
     HEAPF32[$21>>2] = $54;
     $55 = ((($47) + (($42*48)|0)|0) + 12|0);
     $56 = Math_fround(HEAPF32[$55>>2]);
     HEAPF32[$22>>2] = $56;
     label = 18;
     break;
    } else {
     label = 18;
     break;
    }
   }
  } while(0);
  if ((label|0) == 18) {
   label = 0;
   $73 = ($27|0)>(0);
   if ($73) {
    $74 = HEAP32[$23>>2]|0;
    $75 = (($i$05) + 1)|0;
    $constantDefaultValueIndex$11 = $constantDefaultValueIndex$07;$highestMismatch$13 = $highestMismatch$08;$k$02 = 0;
    while(1) {
     $76 = (($74) + ($constantDefaultValueIndex$11<<2)|0);
     $77 = Math_fround(HEAPF32[$76>>2]);
     $78 = (($values) + ($k$02<<2)|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $80 = Math_fround($77 - $79);
     $81 = $80 < Math_fround(0.0);
     if ($81) {
      $82 = Math_fround(-$80);
      $84 = $82;
     } else {
      $84 = $80;
     }
     $83 = $84 <= Math_fround(9.99999974737875163555E-6);
     $highestMismatch$1$ = $83 ? $highestMismatch$13 : $75;
     $85 = (($k$02) + 1)|0;
     $exitcond = ($85|0)==($27|0);
     if ($exitcond) {
      break;
     }
     $86 = (($constantDefaultValueIndex$11) + 1)|0;
     $constantDefaultValueIndex$11 = $86;$highestMismatch$13 = $highestMismatch$1$;$k$02 = $85;
    }
    $87 = (($27) + ($constantDefaultValueIndex$07))|0;
    $constantDefaultValueIndex$2 = $87;$highestMismatch$3 = $highestMismatch$1$;
   } else {
    $constantDefaultValueIndex$2 = $constantDefaultValueIndex$07;$highestMismatch$3 = $highestMismatch$08;
   }
  }
  $88 = (($i$05) + 1)|0;
  $89 = HEAP32[$13>>2]|0;
  $90 = ($88>>>0)<($89>>>0);
  if ($90) {
   $constantDefaultValueIndex$07 = $constantDefaultValueIndex$2;$highestMismatch$08 = $highestMismatch$3;$i$05 = $88;
  } else {
   $highestMismatch$0$lcssa = $highestMismatch$3;
   break;
  }
 }
 STACKTOP = sp;return ($highestMismatch$0$lcssa|0);
}
function __ZN11UnityEngine9AnimationL23InitializeDefaultValuesERKNS0_30AnimatorGenericBindingConstantEPKN7mecanim9animation14AvatarConstantEbRNS5_25ControllerBindingConstantE($genericBinding,$avatar,$hasTransformHierarchy,$controllerBindingConstant) {
 $genericBinding = $genericBinding|0;
 $avatar = $avatar|0;
 $hasTransformHierarchy = $hasTransformHierarchy|0;
 $controllerBindingConstant = $controllerBindingConstant|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i4 = 0, $$pre$phiZ2D = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0;
 var $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0;
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $bindIndex$01$i = 0, $bindIndex$01$i2 = 0, $bindIndex$025$i = 0, $exitcond$i = 0, $or$cond = 0, $positionIndex$027$i = 0, $positionIndex$1$i = 0;
 var $rotationIndex$026$i = 0, $rotationIndex$1$i = 0, $scaleIndex$024$i = 0, $scaleIndex$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $avatar;
 $1 = HEAP32[$avatar>>2]|0;
 $2 = (($1) + ($0))|0;
 $3 = $2;
 $4 = (($avatar) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($avatar) + 8|0);
 $6 = $5;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + ($6))|0;
 $9 = $8;
 $10 = (($avatar) + 12|0);
 HEAP32[$10>>2] = $9;
 $11 = (($controllerBindingConstant) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 do {
  if ($hasTransformHierarchy) {
   $13 = (($genericBinding) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$genericBinding>>2]|0;
   $16 = (($controllerBindingConstant) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($15|0)==(0);
   if ($18) {
    $$pre$phiZ2D = $16;
   } else {
    $19 = (($17) + 40|0);
    $20 = $19;
    $21 = (($17) + 44|0);
    $22 = (($17) + 52|0);
    $23 = $22;
    $24 = (($17) + 56|0);
    $25 = (($17) + 64|0);
    $26 = $25;
    $27 = (($17) + 68|0);
    $bindIndex$025$i = 0;$positionIndex$027$i = 0;$rotationIndex$026$i = 0;$scaleIndex$024$i = 0;
    while(1) {
     $28 = ((($14) + ($bindIndex$025$i<<4)|0) + 12|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ((($14) + ($bindIndex$025$i<<4)|0) + 4|0);
     $31 = HEAP32[$30>>2]|0;
     if ((($31|0) == 1)) {
      $32 = ($29|0)==(0|0);
      if (!($32)) {
       $33 = (($29) + 44|0);
       $34 = Math_fround(HEAPF32[$33>>2]);
       $35 = (($29) + 48|0);
       $36 = Math_fround(HEAPF32[$35>>2]);
       $37 = (($29) + 52|0);
       $38 = Math_fround(HEAPF32[$37>>2]);
       $39 = HEAP32[$19>>2]|0;
       $40 = (($39) + ($20))|0;
       $41 = $40;
       HEAP32[$21>>2] = $41;
       $42 = (($41) + ($positionIndex$027$i<<4)|0);
       HEAPF32[$42>>2] = $34;
       $43 = ((($41) + ($positionIndex$027$i<<4)|0) + 4|0);
       HEAPF32[$43>>2] = $36;
       $44 = ((($41) + ($positionIndex$027$i<<4)|0) + 8|0);
       HEAPF32[$44>>2] = $38;
       $45 = ((($41) + ($positionIndex$027$i<<4)|0) + 12|0);
       HEAPF32[$45>>2] = Math_fround(0.0);
      }
      $46 = (($positionIndex$027$i) + 1)|0;
      $positionIndex$1$i = $46;$rotationIndex$1$i = $rotationIndex$026$i;$scaleIndex$1$i = $scaleIndex$024$i;
     } else if ((($31|0) == 3)) {
      $64 = ($29|0)==(0|0);
      if (!($64)) {
       $65 = (($29) + 56|0);
       $66 = Math_fround(HEAPF32[$65>>2]);
       $67 = (($29) + 60|0);
       $68 = Math_fround(HEAPF32[$67>>2]);
       $69 = (($29) + 64|0);
       $70 = Math_fround(HEAPF32[$69>>2]);
       $71 = HEAP32[$25>>2]|0;
       $72 = (($71) + ($26))|0;
       $73 = $72;
       HEAP32[$27>>2] = $73;
       $74 = (($73) + ($scaleIndex$024$i<<4)|0);
       HEAPF32[$74>>2] = $66;
       $75 = ((($73) + ($scaleIndex$024$i<<4)|0) + 4|0);
       HEAPF32[$75>>2] = $68;
       $76 = ((($73) + ($scaleIndex$024$i<<4)|0) + 8|0);
       HEAPF32[$76>>2] = $70;
       $77 = ((($73) + ($scaleIndex$024$i<<4)|0) + 12|0);
       HEAPF32[$77>>2] = Math_fround(1.0);
      }
      $78 = (($scaleIndex$024$i) + 1)|0;
      $positionIndex$1$i = $positionIndex$027$i;$rotationIndex$1$i = $rotationIndex$026$i;$scaleIndex$1$i = $78;
     } else if ((($31|0) == 2)) {
      $47 = ($29|0)==(0|0);
      if (!($47)) {
       $48 = (($29) + 28|0);
       $49 = Math_fround(HEAPF32[$48>>2]);
       $50 = (($29) + 32|0);
       $51 = Math_fround(HEAPF32[$50>>2]);
       $52 = (($29) + 36|0);
       $53 = Math_fround(HEAPF32[$52>>2]);
       $54 = (($29) + 40|0);
       $55 = Math_fround(HEAPF32[$54>>2]);
       $56 = HEAP32[$22>>2]|0;
       $57 = (($56) + ($23))|0;
       $58 = $57;
       HEAP32[$24>>2] = $58;
       $59 = (($58) + ($rotationIndex$026$i<<4)|0);
       HEAPF32[$59>>2] = $49;
       $60 = ((($58) + ($rotationIndex$026$i<<4)|0) + 4|0);
       HEAPF32[$60>>2] = $51;
       $61 = ((($58) + ($rotationIndex$026$i<<4)|0) + 8|0);
       HEAPF32[$61>>2] = $53;
       $62 = ((($58) + ($rotationIndex$026$i<<4)|0) + 12|0);
       HEAPF32[$62>>2] = $55;
      }
      $63 = (($rotationIndex$026$i) + 1)|0;
      $positionIndex$1$i = $positionIndex$027$i;$rotationIndex$1$i = $63;$scaleIndex$1$i = $scaleIndex$024$i;
     } else {
      $positionIndex$1$i = $positionIndex$027$i;$rotationIndex$1$i = $rotationIndex$026$i;$scaleIndex$1$i = $scaleIndex$024$i;
     }
     $79 = (($bindIndex$025$i) + 1)|0;
     $exitcond$i = ($79|0)==($15|0);
     if ($exitcond$i) {
      $$pre$phiZ2D = $16;
      break;
     } else {
      $bindIndex$025$i = $79;$positionIndex$027$i = $positionIndex$1$i;$rotationIndex$026$i = $rotationIndex$1$i;$scaleIndex$024$i = $scaleIndex$1$i;
     }
    }
   }
  } else {
   $80 = ($2|0)==(0);
   $81 = ($8|0)==(0);
   $or$cond = $80 | $81;
   if ($or$cond) {
    $$pre6 = (($controllerBindingConstant) + 4|0);
    $$pre$phiZ2D = $$pre6;
    break;
   } else {
    $82 = (($controllerBindingConstant) + 8|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($controllerBindingConstant) + 4|0);
    $85 = HEAP32[$84>>2]|0;
    __ZN7mecanim9animation21ValueFromSkeletonPoseERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseEPKNS0_14SkeletonTQSMapERNS_10ValueArrayE($3,$9,$83,$85);
    $$pre$phiZ2D = $84;
    break;
   }
  }
 } while(0);
 $86 = HEAP32[$$pre$phiZ2D>>2]|0;
 $87 = (($genericBinding) + 8|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($88|0)==(0);
 if ($89) {
  $112 = $86;
 } else {
  $90 = (($genericBinding) + 12|0);
  $91 = (($86) + 28|0);
  $92 = $91;
  $93 = (($86) + 32|0);
  $146 = $88;$bindIndex$01$i2 = 0;
  while(1) {
   $94 = HEAP32[$90>>2]|0;
   $95 = ((($94) + ($bindIndex$01$i2<<4)|0) + 4|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0);
   if ($97) {
    $106 = $146;
   } else {
    $98 = (($94) + ($bindIndex$01$i2<<4)|0);
    $99 = (Math_fround(__ZN11UnityEngine9Animation23GetBoundCurveFloatValueERKNS0_10BoundCurveE($98)));
    $100 = HEAP32[$91>>2]|0;
    $101 = (($100) + ($92))|0;
    $102 = $101;
    HEAP32[$93>>2] = $102;
    $103 = (($102) + ($bindIndex$01$i2<<2)|0);
    HEAPF32[$103>>2] = $99;
    $$pre$i4 = HEAP32[$87>>2]|0;
    $106 = $$pre$i4;
   }
   $104 = (($bindIndex$01$i2) + 1)|0;
   $105 = ($104>>>0)<($106>>>0);
   if ($105) {
    $146 = $106;$bindIndex$01$i2 = $104;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$$pre$phiZ2D>>2]|0;
  $112 = $$pre;
 }
 $107 = (($genericBinding) + 16|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108|0)==(0);
 if ($109) {
  $128 = (($controllerBindingConstant) + 20|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (($129) + 24|0);
  $131 = $130;
  $132 = HEAP32[$130>>2]|0;
  $133 = (($131) + ($132))|0;
  $134 = $133;
  $135 = (($129) + 28|0);
  HEAP32[$135>>2] = $134;
  $136 = (($129) + 32|0);
  $137 = $136;
  $138 = HEAP32[$136>>2]|0;
  $139 = (($138) + ($137))|0;
  $140 = $139;
  $141 = (($129) + 36|0);
  HEAP32[$141>>2] = $140;
  $142 = HEAP32[$controllerBindingConstant>>2]|0;
  $143 = HEAP32[$$pre$phiZ2D>>2]|0;
  $144 = (($12) + 20|0);
  $145 = HEAP32[$144>>2]|0;
  __ZN7mecanim21ValueArrayReverseCopyEPKNS_18ValueArrayConstantEPKNS_10ValueArrayES2_PS3_PKi($134,$140,$142,$143,$145);
  STACKTOP = sp;return;
 }
 $110 = (($genericBinding) + 20|0);
 $111 = (($112) + 16|0);
 $113 = $111;
 $114 = (($112) + 20|0);
 $147 = $108;$bindIndex$01$i = 0;
 while(1) {
  $115 = HEAP32[$110>>2]|0;
  $116 = ((($115) + ($bindIndex$01$i<<4)|0) + 4|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = ($117|0)==(0);
  if ($118) {
   $127 = $147;
  } else {
   $119 = (($115) + ($bindIndex$01$i<<4)|0);
   $120 = (__ZN11UnityEngine9Animation21GetBoundCurveIntValueERKNS0_10BoundCurveE($119)|0);
   $121 = HEAP32[$111>>2]|0;
   $122 = (($121) + ($113))|0;
   $123 = $122;
   HEAP32[$114>>2] = $123;
   $124 = (($123) + ($bindIndex$01$i<<2)|0);
   HEAP32[$124>>2] = $120;
   $$pre$i = HEAP32[$107>>2]|0;
   $127 = $$pre$i;
  }
  $125 = (($bindIndex$01$i) + 1)|0;
  $126 = ($125>>>0)<($127>>>0);
  if ($126) {
   $147 = $127;$bindIndex$01$i = $125;
  } else {
   break;
  }
 }
 $128 = (($controllerBindingConstant) + 20|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = (($129) + 24|0);
 $131 = $130;
 $132 = HEAP32[$130>>2]|0;
 $133 = (($131) + ($132))|0;
 $134 = $133;
 $135 = (($129) + 28|0);
 HEAP32[$135>>2] = $134;
 $136 = (($129) + 32|0);
 $137 = $136;
 $138 = HEAP32[$136>>2]|0;
 $139 = (($138) + ($137))|0;
 $140 = $139;
 $141 = (($129) + 36|0);
 HEAP32[$141>>2] = $140;
 $142 = HEAP32[$controllerBindingConstant>>2]|0;
 $143 = HEAP32[$$pre$phiZ2D>>2]|0;
 $144 = (($12) + 20|0);
 $145 = HEAP32[$144>>2]|0;
 __ZN7mecanim21ValueArrayReverseCopyEPKNS_18ValueArrayConstantEPKNS_10ValueArrayES2_PS3_PKi($134,$140,$142,$143,$145);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation32CreateAnimatorGenericBindingsOptERKNS0_20AnimationSetBindingsER9TransformPKN7mecanim9animation14AvatarConstantEPKNS7_18ControllerConstantEbRNS6_6memory9AllocatorE($animationSet,$root,$avatar,$controller,$allowConstantClipSamplingOptimization,$allocator) {
 $animationSet = $animationSet|0;
 $root = $root|0;
 $avatar = $avatar|0;
 $controller = $controller|0;
 $allowConstantClipSamplingOptimization = $allowConstantClipSamplingOptimization|0;
 $allocator = $allocator|0;
 var $$0$i = 0, $$0$i3 = 0, $$02$i$i$i = 0, $$byval_copy16 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i$i$i = 0, $exitcond$i22 = 0, $exitcond$i27 = 0;
 var $i$01$i = 0, $i$01$i17 = 0, $i$03$i$i$i = 0, $i$046 = 0, $i1$041 = 0, $iter$01$i = 0, $iter$01$i$i = 0, $iter$01$i21 = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0, $or$cond$i = 0, $phitmp = 0, $positionCount$03$i = 0, $positionCount$1$i = 0, $reflection$01$i$i$i = 0, $reflection$1$i$i$i = 0, $rotationCount$04$i = 0, $rotationCount$1$i = 0, $scaleCount$02$i = 0, $scaleCount$1$i = 0;
 var $transformBindingCache = 0, $transformIter$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy16 = sp + 28|0;
 $0 = sp;
 $transformBindingCache = sp + 8|0;
 $1 = sp + 24|0;
 $2 = (__ZN11UnityEngine9Animation31GetGenericAnimationBindingCacheEv()|0);
 $3 = $avatar;
 $4 = HEAP32[$avatar>>2]|0;
 $5 = (($4) + ($3))|0;
 $6 = $5;
 $7 = (($avatar) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[628512>>2]|0;
 HEAP32[$transformBindingCache>>2] = 0;
 $9 = (($transformBindingCache) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = (($transformBindingCache) + 8|0);
 HEAP32[$10>>2] = 0;
 $11 = (($transformBindingCache) + 12|0);
 HEAP32[$11>>2] = 0;
 $$02$i$i$i = -1;$i$03$i$i$i = 0;$reflection$01$i$i$i = 0;
 while(1) {
  $12 = $$02$i$i$i & 1;
  $13 = ($12|0)==(0);
  if ($13) {
   $reflection$1$i$i$i = $reflection$01$i$i$i;
  } else {
   $14 = (31 - ($i$03$i$i$i))|0;
   $15 = 1 << $14;
   $16 = $15 | $reflection$01$i$i$i;
   $reflection$1$i$i$i = $16;
  }
  $17 = (($i$03$i$i$i) + 1)|0;
  $18 = $$02$i$i$i >>> 1;
  $exitcond$i$i$i = ($17|0)==(32);
  if ($exitcond$i$i$i) {
   break;
  } else {
   $$02$i$i$i = $18;$i$03$i$i$i = $17;$reflection$01$i$i$i = $reflection$1$i$i$i;
  }
 }
 HEAP32[$1>>2] = $reflection$1$i$i$i;
 __THREW__ = 0;
 invoke_viiiii(111,($root|0),($1|0),($transformBindingCache|0),($avatar|0),0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 L7: do {
  if ($20) {
   label = 41;
  } else {
   if ($allowConstantClipSamplingOptimization) {
    __THREW__ = 0;
    $21 = (invoke_iiiiii(217,($animationSet|0),($transformBindingCache|0),(0|0),($avatar|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 41;
     break;
    }
    $$phi$trans$insert = (($animationSet) + 20|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $32 = $21;$34 = $$pre;
   } else {
    $24 = (($animationSet) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    $32 = $25;$34 = $25;
   }
   $26 = (($animationSet) + 36|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 24|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + ($32))|0;
   $33 = (($31) - ($34))|0;
   if ($allowConstantClipSamplingOptimization) {
    $35 = (($animationSet) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($32|0)==($36|0);
    $phitmp = $37&1;
    $81 = $phitmp;
   } else {
    $81 = 0;
   }
   $38 = HEAP32[$allocator>>2]|0;
   $39 = HEAP32[$38>>2]|0;
   __THREW__ = 0;
   $40 = (invoke_iiii($39|0,($allocator|0),52,4)|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    label = 41;
   } else {
    $43 = ($40|0)==(0|0);
    if ($43) {
     $44 = 0;
    } else {
     $44 = $40;
    }
    HEAP32[$44>>2] = 0;
    $45 = (($44) + 4|0);
    HEAP32[$45>>2] = 0;
    $46 = (($44) + 40|0);
    HEAP32[$46>>2] = -1;
    $47 = (($44) + 44|0);
    HEAP32[$47>>2] = -1;
    $48 = (($44) + 48|0);
    HEAP32[$48>>2] = -1;
    $49 = HEAP32[$animationSet>>2]|0;
    $50 = (($44) + 8|0);
    HEAP32[$50>>2] = $49;
    $51 = ($49|0)==(0);
    if ($51) {
     $$0$i = 0;
    } else {
     $52 = HEAP32[$allocator>>2]|0;
     $53 = HEAP32[$52>>2]|0;
     $54 = $49 << 4;
     __THREW__ = 0;
     $55 = (invoke_iiii($53|0,($allocator|0),($54|0),4)|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 41;
      break;
     }
     $58 = ($55|0)==(0|0);
     if ($58) {
      $$0$i = 0;
     } else {
      $59 = (($55) + ($49<<4)|0);
      $60 = $55;
      while(1) {
       ;HEAP32[$60+0>>2]=0|0;HEAP32[$60+4>>2]=0|0;HEAP32[$60+8>>2]=0|0;HEAP32[$60+12>>2]=0|0;
       $61 = (($60) + 16|0);
       $62 = ($61|0)==($59|0);
       if ($62) {
        $$0$i = $55;
        break;
       } else {
        $60 = $61;
       }
      }
     }
    }
    $63 = (($44) + 12|0);
    HEAP32[$63>>2] = $$0$i;
    $64 = (($animationSet) + 8|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (($44) + 16|0);
    HEAP32[$66>>2] = $65;
    $67 = ($65|0)==(0);
    if ($67) {
     $$0$i3 = 0;
    } else {
     $68 = HEAP32[$allocator>>2]|0;
     $69 = HEAP32[$68>>2]|0;
     $70 = $65 << 4;
     __THREW__ = 0;
     $71 = (invoke_iiii($69|0,($allocator|0),($70|0),4)|0);
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      label = 41;
      break;
     }
     $74 = ($71|0)==(0|0);
     if ($74) {
      $$0$i3 = 0;
     } else {
      $75 = (($71) + ($65<<4)|0);
      $76 = $71;
      while(1) {
       ;HEAP32[$76+0>>2]=0|0;HEAP32[$76+4>>2]=0|0;HEAP32[$76+8>>2]=0|0;HEAP32[$76+12>>2]=0|0;
       $77 = (($76) + 16|0);
       $78 = ($77|0)==($75|0);
       if ($78) {
        $$0$i3 = $71;
        break;
       } else {
        $76 = $77;
       }
      }
     }
    }
    $79 = (($44) + 20|0);
    HEAP32[$79>>2] = $$0$i3;
    $80 = (($44) + 36|0);
    HEAP8[$80>>0] = $81;
    $82 = (($44) + 28|0);
    HEAP8[$82>>0] = 0;
    $83 = HEAP32[$50>>2]|0;
    $84 = ($83|0)==(0);
    L35: do {
     if (!($84)) {
      $85 = (($animationSet) + 4|0);
      $86 = HEAP32[$10>>2]|0;
      $87 = ($86|0)==(0);
      $88 = HEAP32[$transformBindingCache>>2]|0;
      $i$046 = 0;
      L37: while(1) {
       $95 = HEAP32[$63>>2]|0;
       $96 = ((($95) + ($i$046<<4)|0) + 12|0);
       HEAP32[$96>>2] = 0;
       $97 = HEAP32[$63>>2]|0;
       $98 = ((($97) + ($i$046<<4)|0) + 4|0);
       HEAP32[$98>>2] = 0;
       $99 = HEAP32[$85>>2]|0;
       $100 = (($99) + ($i$046<<4)|0);
       $101 = HEAP32[$100>>2]|0;
       __THREW__ = 0;
       $102 = (invoke_iii(2581,($6|0),($101|0))|0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        break;
       }
       L40: do {
        if (!($87)) {
         $i$01$i = 0;
         while(1) {
          $107 = ((($88) + (($i$01$i*12)|0)|0) + 8|0);
          $108 = HEAP32[$107>>2]|0;
          $109 = ($108|0)==($102|0);
          $106 = (($i$01$i) + 1)|0;
          if ($109) {
           break;
          }
          $105 = ($106>>>0)<($86>>>0);
          if ($105) {
           $i$01$i = $106;
          } else {
           break L40;
          }
         }
         $110 = ($i$01$i|0)==(-1);
         if (!($110)) {
          $111 = HEAP32[$85>>2]|0;
          $112 = (($111) + ($i$046<<4)|0);
          $113 = ((($88) + (($i$01$i*12)|0)|0) + 4|0);
          $114 = HEAP32[$113>>2]|0;
          $115 = HEAP32[$63>>2]|0;
          $116 = (($115) + ($i$046<<4)|0);
          __THREW__ = 0;
          (invoke_iiiii(269,($2|0),($112|0),($114|0),($116|0))|0);
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           break L37;
          }
         }
        }
       } while(0);
       $139 = (($i$046) + 1)|0;
       $140 = HEAP32[$50>>2]|0;
       $141 = ($139>>>0)<($140>>>0);
       if ($141) {
        $i$046 = $139;
       } else {
        break L35;
       }
      }
      $129 = ___cxa_find_matching_catch()|0;
      $130 = tempRet0;
      $lpad$phi$index = $129;$lpad$phi$index7 = $130;
      break L7;
     }
    } while(0);
    $89 = HEAP32[$66>>2]|0;
    $90 = ($89|0)==(0);
    L49: do {
     if (!($90)) {
      $91 = (($animationSet) + 12|0);
      $92 = HEAP32[$10>>2]|0;
      $93 = ($92|0)==(0);
      $94 = HEAP32[$transformBindingCache>>2]|0;
      $i1$041 = 0;
      L51: while(1) {
       $142 = HEAP32[$79>>2]|0;
       $143 = ((($142) + ($i1$041<<4)|0) + 12|0);
       HEAP32[$143>>2] = 0;
       $144 = HEAP32[$79>>2]|0;
       $145 = ((($144) + ($i1$041<<4)|0) + 4|0);
       HEAP32[$145>>2] = 0;
       $146 = HEAP32[$91>>2]|0;
       $147 = (($146) + ($i1$041<<4)|0);
       $148 = HEAP32[$147>>2]|0;
       __THREW__ = 0;
       $149 = (invoke_iii(2581,($6|0),($148|0))|0);
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        break;
       }
       L54: do {
        if (!($93)) {
         $i$01$i17 = 0;
         while(1) {
          $154 = ((($94) + (($i$01$i17*12)|0)|0) + 8|0);
          $155 = HEAP32[$154>>2]|0;
          $156 = ($155|0)==($149|0);
          $153 = (($i$01$i17) + 1)|0;
          if ($156) {
           break;
          }
          $152 = ($153>>>0)<($92>>>0);
          if ($152) {
           $i$01$i17 = $153;
          } else {
           break L54;
          }
         }
         $157 = ($i$01$i17|0)==(-1);
         if (!($157)) {
          $158 = HEAP32[$91>>2]|0;
          $159 = (($158) + ($i1$041<<4)|0);
          $160 = ((($94) + (($i$01$i17*12)|0)|0) + 4|0);
          $161 = HEAP32[$160>>2]|0;
          $162 = HEAP32[$79>>2]|0;
          $163 = (($162) + ($i1$041<<4)|0);
          __THREW__ = 0;
          (invoke_iiiii(270,($2|0),($159|0),($161|0),($163|0))|0);
          $164 = __THREW__; __THREW__ = 0;
          $165 = $164&1;
          if ($165) {
           break L51;
          }
         }
        }
       } while(0);
       $166 = (($i1$041) + 1)|0;
       $167 = HEAP32[$66>>2]|0;
       $168 = ($166>>>0)<($167>>>0);
       if ($168) {
        $i1$041 = $166;
       } else {
        break L49;
       }
      }
      $127 = ___cxa_find_matching_catch()|0;
      $128 = tempRet0;
      $lpad$phi$index = $127;$lpad$phi$index7 = $128;
      break L7;
     }
    } while(0);
    $169 = HEAP32[$26>>2]|0;
    $170 = (($169) + 24|0);
    $171 = HEAP32[$170>>2]|0;
    __THREW__ = 0;
    $172 = (invoke_iiiiiii(121,($controller|0),($169|0),($171|0),($33|0),($avatar|0),($allocator|0))|0);
    $173 = __THREW__; __THREW__ = 0;
    $174 = $173&1;
    if ($174) {
     label = 41;
    } else {
     $175 = (($44) + 32|0);
     HEAP32[$175>>2] = $172;
     $176 = (($172) + 8|0);
     $177 = HEAP32[$176>>2]|0;
     $178 = ($177|0)!=(0|0);
     $179 = ($32|0)>(0);
     $or$cond$i = $178 & $179;
     L64: do {
      if ($or$cond$i) {
       $180 = (($animationSet) + 24|0);
       $positionCount$03$i = -1;$rotationCount$04$i = -1;$scaleCount$02$i = -1;$transformIter$01$i = 0;
       while(1) {
        $181 = HEAP32[$180>>2]|0;
        $182 = ((($181) + ($transformIter$01$i<<3)|0) + 4|0);
        $183 = HEAP32[$182>>2]|0;
        $184 = ($183|0)==(3);
        do {
         if ($184) {
          $185 = (($scaleCount$02$i) + 1)|0;
          $positionCount$1$i = $positionCount$03$i;$rotationCount$1$i = $rotationCount$04$i;$scaleCount$1$i = $185;
         } else {
          if ((($183|0) == 1)) {
           $187 = (($positionCount$03$i) + 1)|0;
           $positionCount$1$i = $187;$rotationCount$1$i = $rotationCount$04$i;$scaleCount$1$i = $scaleCount$02$i;
           break;
          } else if ((($183|0) == 2)) {
           $186 = (($rotationCount$04$i) + 1)|0;
           $positionCount$1$i = $positionCount$03$i;$rotationCount$1$i = $186;$scaleCount$1$i = $scaleCount$02$i;
           break;
          } else {
           $positionCount$1$i = $positionCount$03$i;$rotationCount$1$i = $rotationCount$04$i;$scaleCount$1$i = $scaleCount$02$i;
           break;
          }
         }
        } while(0);
        $188 = (($181) + ($transformIter$01$i<<3)|0);
        $189 = HEAP32[$188>>2]|0;
        __THREW__ = 0;
        $190 = (invoke_iii(2581,($6|0),($189|0))|0);
        $191 = __THREW__; __THREW__ = 0;
        $192 = $191&1;
        if ($192) {
         break;
        }
        $193 = ($190|0)==(-1);
        do {
         if (!($193)) {
          if ($184) {
           $194 = HEAP32[$176>>2]|0;
           $195 = ((($194) + (($190*12)|0)|0) + 8|0);
           HEAP32[$195>>2] = $scaleCount$1$i;
           break;
          }
          if ((($183|0) == 2)) {
           $196 = HEAP32[$176>>2]|0;
           $197 = ((($196) + (($190*12)|0)|0) + 4|0);
           HEAP32[$197>>2] = $rotationCount$1$i;
           break;
          } else if ((($183|0) == 1)) {
           $198 = HEAP32[$176>>2]|0;
           $199 = (($198) + (($190*12)|0)|0);
           HEAP32[$199>>2] = $positionCount$1$i;
           break;
          } else {
           break;
          }
         }
        } while(0);
        $200 = (($transformIter$01$i) + 1)|0;
        $exitcond$i27 = ($200|0)==($32|0);
        if ($exitcond$i27) {
         break L64;
        } else {
         $positionCount$03$i = $positionCount$1$i;$rotationCount$04$i = $rotationCount$1$i;$scaleCount$02$i = $scaleCount$1$i;$transformIter$01$i = $200;
        }
       }
       $125 = ___cxa_find_matching_catch()|0;
       $126 = tempRet0;
       $lpad$phi$index = $125;$lpad$phi$index7 = $126;
       break L7;
      }
     } while(0);
     $201 = HEAP32[$45>>2]|0;
     $202 = HEAP32[$44>>2]|0;
     $203 = ($202|0)>(0);
     L87: do {
      if ($203) {
       $iter$01$i$i = 0;
       while(1) {
        $204 = ((($201) + ($iter$01$i$i<<4)|0) + 12|0);
        $205 = HEAP32[$204>>2]|0;
        $206 = ($205|0)==(0|0);
        if (!($206)) {
         __THREW__ = 0;
         $207 = (invoke_iiii(1586,($205|0),(1994|0),($44|0))|0);
         $208 = __THREW__; __THREW__ = 0;
         $209 = $208&1;
         if ($209) {
          break;
         }
         if (!($207)) {
          $210 = HEAP32[$204>>2]|0;
          __THREW__ = 0;
          invoke_viii(1995,($210|0),(1994|0),($44|0));
          $211 = __THREW__; __THREW__ = 0;
          $212 = $211&1;
          if ($212) {
           break;
          }
         }
        }
        $213 = (($iter$01$i$i) + 1)|0;
        $exitcond$i$i = ($213|0)==($202|0);
        if ($exitcond$i$i) {
         break L87;
        } else {
         $iter$01$i$i = $213;
        }
       }
       $123 = ___cxa_find_matching_catch()|0;
       $124 = tempRet0;
       $lpad$phi$index = $123;$lpad$phi$index7 = $124;
       break L7;
      }
     } while(0);
     $214 = HEAP32[$63>>2]|0;
     $215 = HEAP32[$50>>2]|0;
     $216 = ($215|0)>(0);
     L98: do {
      if ($216) {
       $iter$01$i21 = 0;
       while(1) {
        $217 = ((($214) + ($iter$01$i21<<4)|0) + 12|0);
        $218 = HEAP32[$217>>2]|0;
        $219 = ($218|0)==(0|0);
        if (!($219)) {
         __THREW__ = 0;
         $220 = (invoke_iiii(1586,($218|0),(1994|0),($44|0))|0);
         $221 = __THREW__; __THREW__ = 0;
         $222 = $221&1;
         if ($222) {
          break;
         }
         if (!($220)) {
          $223 = HEAP32[$217>>2]|0;
          __THREW__ = 0;
          invoke_viii(1995,($223|0),(1994|0),($44|0));
          $224 = __THREW__; __THREW__ = 0;
          $225 = $224&1;
          if ($225) {
           break;
          }
         }
        }
        $226 = (($iter$01$i21) + 1)|0;
        $exitcond$i22 = ($226|0)==($215|0);
        if ($exitcond$i22) {
         break L98;
        } else {
         $iter$01$i21 = $226;
        }
       }
       $121 = ___cxa_find_matching_catch()|0;
       $122 = tempRet0;
       $lpad$phi$index = $121;$lpad$phi$index7 = $122;
       break L7;
      }
     } while(0);
     $227 = HEAP32[$79>>2]|0;
     $228 = HEAP32[$66>>2]|0;
     $229 = ($228|0)>(0);
     L109: do {
      if ($229) {
       $iter$01$i = 0;
       L111: while(1) {
        $230 = ((($227) + ($iter$01$i<<4)|0) + 12|0);
        $231 = HEAP32[$230>>2]|0;
        $232 = ($231|0)==(0|0);
        do {
         if (!($232)) {
          __THREW__ = 0;
          $233 = (invoke_iiii(1586,($231|0),(1994|0),($44|0))|0);
          $234 = __THREW__; __THREW__ = 0;
          $235 = $234&1;
          if ($235) {
           break L111;
          }
          if ($233) {
           break;
          }
          $236 = HEAP32[$230>>2]|0;
          __THREW__ = 0;
          invoke_viii(1995,($236|0),(1994|0),($44|0));
          $237 = __THREW__; __THREW__ = 0;
          $238 = $237&1;
          if ($238) {
           break L111;
          }
         }
        } while(0);
        $239 = (($iter$01$i) + 1)|0;
        $exitcond$i = ($239|0)==($228|0);
        if ($exitcond$i) {
         break L109;
        } else {
         $iter$01$i = $239;
        }
       }
       $119 = ___cxa_find_matching_catch()|0;
       $120 = tempRet0;
       $lpad$phi$index = $119;$lpad$phi$index7 = $120;
       break L7;
      }
     } while(0);
     $240 = HEAP32[$175>>2]|0;
     __THREW__ = 0;
     invoke_viiii(411,($44|0),($avatar|0),0,($240|0));
     $241 = __THREW__; __THREW__ = 0;
     $242 = $241&1;
     if ($242) {
      label = 41;
     } else {
      $243 = HEAP32[$11>>2]|0;
      $244 = ($243|0)>(-1);
      if (!($244)) {
       STACKTOP = sp;return ($44|0);
      }
      $245 = HEAP32[$transformBindingCache>>2]|0;
      $246 = HEAP32[$9>>2]|0;
      HEAP32[$0>>2] = $246;
      ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($245,$$byval_copy16);
      HEAP32[$transformBindingCache>>2] = 0;
      STACKTOP = sp;return ($44|0);
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 41) {
  $131 = ___cxa_find_matching_catch()|0;
  $132 = tempRet0;
  $lpad$phi$index = $131;$lpad$phi$index7 = $132;
 }
 $133 = HEAP32[$11>>2]|0;
 $134 = ($133|0)>(-1);
 if (!($134)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $135 = HEAP32[$transformBindingCache>>2]|0;
 $136 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = $136;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($135|0),($$byval_copy16|0));
 $137 = __THREW__; __THREW__ = 0;
 $138 = $137&1;
 if ($138) {
  $247 = ___cxa_find_matching_catch(0|0)|0;
  $248 = tempRet0;
  ___clang_call_terminate($247);
  // unreachable;
 }
 HEAP32[$transformBindingCache>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN11UnityEngine9Animation30DestroyAnimatorGenericBindingsEPNS0_30AnimatorGenericBindingConstantERN7mecanim6memory9AllocatorE($bindingConstant,$allocator) {
 $bindingConstant = $bindingConstant|0;
 $allocator = $allocator|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($bindingConstant|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 __ZN11UnityEngine9Animation31UnregisterGenericBindingObjectsEPNS0_30AnimatorGenericBindingConstantE($bindingConstant);
 $1 = (($bindingConstant) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$pre$phiZ2D = $allocator;
 } else {
  $4 = (($2) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($5,$allocator);
  $6 = HEAP32[$2>>2]|0;
  __ZN7mecanim25DestroyValueArrayConstantEPNS_18ValueArrayConstantERNS_6memory9AllocatorE($6,$allocator);
  $7 = HEAP32[$allocator>>2]|0;
  $8 = (($7) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($2) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vii[$9 & 4095]($allocator,$11);
  $12 = HEAP32[$allocator>>2]|0;
  $13 = (($12) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($2) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_vii[$14 & 4095]($allocator,$16);
  $17 = HEAP32[$allocator>>2]|0;
  $18 = (($17) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vii[$19 & 4095]($allocator,$2);
  $$pre$phiZ2D = $allocator;
 }
 $20 = (($bindingConstant) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$$pre$phiZ2D>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_vii[$24 & 4095]($allocator,$21);
 $25 = (($bindingConstant) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$$pre$phiZ2D>>2]|0;
 $28 = (($27) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_vii[$29 & 4095]($allocator,$26);
 $30 = (($bindingConstant) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$$pre$phiZ2D>>2]|0;
 $33 = (($32) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 FUNCTION_TABLE_vii[$34 & 4095]($allocator,$31);
 $35 = HEAP32[$$pre$phiZ2D>>2]|0;
 $36 = (($35) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095]($allocator,$bindingConstant);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation28SetGenericPPtrPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayE($bindings,$values) {
 $bindings = $bindings|0;
 $values = $values|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bindIndex$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bindings) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($bindings) + 20|0);
 $4 = (($values) + 16|0);
 $5 = $4;
 $20 = 0;$bindIndex$01 = 0;
 while(1) {
  $6 = HEAP32[$3>>2]|0;
  $7 = ((($6) + ($bindIndex$01<<4)|0) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $26 = $20;
  } else {
   $10 = (($6) + ($bindIndex$01<<4)|0);
   $11 = HEAP32[$4>>2]|0;
   $12 = (($11) + ($5))|0;
   $13 = $12;
   $14 = (($13) + ($bindIndex$01<<2)|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (__ZN11UnityEngine9Animation21SetBoundCurveIntValueERKNS0_10BoundCurveEi($10,$15)|0);
   if ($16) {
    $17 = ((($6) + ($bindIndex$01<<4)|0) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($20|0)==($18|0);
    if ($19) {
     $26 = $20;
    } else {
     $21 = ($20|0)==(0|0);
     if ($21) {
      $26 = $18;
     } else {
      __ZN11UnityEngine9Animation27BoundCurveValueAwakeGenericER6Object($20);
      $$pre$i = HEAP32[$17>>2]|0;
      $26 = $$pre$i;
     }
    }
   } else {
    $26 = $20;
   }
  }
  $22 = (($bindIndex$01) + 1)|0;
  $23 = HEAP32[$0>>2]|0;
  $24 = ($22|0)==($23|0);
  if ($24) {
   break;
  } else {
   $20 = $26;$bindIndex$01 = $22;
  }
 }
 $25 = ($26|0)==(0|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 __ZN11UnityEngine9Animation27BoundCurveValueAwakeGenericER6Object($26);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation29SetGenericFloatPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayE($bindings,$values) {
 $bindings = $bindings|0;
 $values = $values|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bindIndex$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bindings) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($bindings) + 12|0);
 $4 = (($values) + 28|0);
 $5 = $4;
 $20 = 0;$bindIndex$01 = 0;
 while(1) {
  $6 = HEAP32[$3>>2]|0;
  $7 = ((($6) + ($bindIndex$01<<4)|0) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $26 = $20;
  } else {
   $10 = (($6) + ($bindIndex$01<<4)|0);
   $11 = HEAP32[$4>>2]|0;
   $12 = (($11) + ($5))|0;
   $13 = $12;
   $14 = (($13) + ($bindIndex$01<<2)|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = (__ZN11UnityEngine9Animation23SetBoundCurveFloatValueERKNS0_10BoundCurveEf($10,$15)|0);
   if ($16) {
    $17 = ((($6) + ($bindIndex$01<<4)|0) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($20|0)==($18|0);
    if ($19) {
     $26 = $20;
    } else {
     $21 = ($20|0)==(0|0);
     if ($21) {
      $26 = $18;
     } else {
      __ZN11UnityEngine9Animation27BoundCurveValueAwakeGenericER6Object($20);
      $$pre$i = HEAP32[$17>>2]|0;
      $26 = $$pre$i;
     }
    }
   } else {
    $26 = $20;
   }
  }
  $22 = (($bindIndex$01) + 1)|0;
  $23 = HEAP32[$0>>2]|0;
  $24 = ($22|0)==($23|0);
  if ($24) {
   break;
  } else {
   $20 = $26;$bindIndex$01 = $22;
  }
 }
 $25 = ($26|0)==(0|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 __ZN11UnityEngine9Animation27BoundCurveValueAwakeGenericER6Object($26);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation35SetTransformPropertyApplyMainThreadER9TransformRKNS0_30AnimatorGenericBindingConstantERKNS0_21AvatarBindingConstantE($root,$bindings,$avatarBindings) {
 $root = $root|0;
 $bindings = $bindings|0;
 $avatarBindings = $avatarBindings|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bindings) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($avatarBindings) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 | $1;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 __ZN9Transform40SendTransformChangedToModifiedTransformsEv($root);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation31SetHumanTransformPropertyValuesERKNS0_21AvatarBindingConstantERKN7mecanim8skeleton12SkeletonPoseE($bindings,$pose) {
 $bindings = $bindings|0;
 $pose = $pose|0;
 var $$idx = 0, $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$bindings>>2]|0;
 $1 = ($0|0)>(1);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (($bindings) + 4|0);
 $3 = (($pose) + 4|0);
 $4 = $3;
 $i$03 = 1;
 while(1) {
  $5 = HEAP32[$2>>2]|0;
  $6 = (($5) + ($i$03<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = HEAP32[$3>>2]|0;
   $10 = (($9) + ($4))|0;
   $11 = $10;
   $$idx = (($11) + (($i$03*48)|0)|0);
   $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
   $$idx1 = ((($11) + (($i$03*48)|0)|0) + 4|0);
   $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
   $$idx2 = ((($11) + (($i$03*48)|0)|0) + 8|0);
   $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
   $12 = (($7) + 44|0);
   HEAPF32[$12>>2] = $$idx$val;
   $13 = (($7) + 48|0);
   HEAPF32[$13>>2] = $$idx1$val;
   $14 = (($7) + 52|0);
   HEAPF32[$14>>2] = $$idx2$val;
   $15 = (($7) + 135|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = $16&255;
   $18 = $17 | 1;
   $19 = $18&255;
   HEAP8[$15>>0] = $19;
   $20 = HEAP32[$3>>2]|0;
   $21 = (($20) + ($4))|0;
   $22 = $21;
   $23 = ((($22) + (($i$03*48)|0)|0) + 16|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($24 * $24);
   $26 = ((($22) + (($i$03*48)|0)|0) + 20|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($27 * $27);
   $29 = ((($22) + (($i$03*48)|0)|0) + 24|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = Math_fround($30 * $30);
   $32 = ((($22) + (($i$03*48)|0)|0) + 28|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = Math_fround($33 * $33);
   $35 = Math_fround($25 + $28);
   $36 = Math_fround($31 + $34);
   $37 = Math_fround($35 + $36);
   $38 = (Math_fround(Math_sqrt((Math_fround($37)))));
   $39 = Math_fround(Math_fround(1.0) / $38);
   $40 = Math_fround($24 * $39);
   $41 = Math_fround($27 * $39);
   $42 = Math_fround($30 * $39);
   $43 = Math_fround($33 * $39);
   $44 = (($7) + 28|0);
   HEAPF32[$44>>2] = $40;
   $45 = (($7) + 32|0);
   HEAPF32[$45>>2] = $41;
   $46 = (($7) + 36|0);
   HEAPF32[$46>>2] = $42;
   $47 = (($7) + 40|0);
   HEAPF32[$47>>2] = $43;
   $48 = $17 | 3;
   $49 = $48&255;
   HEAP8[$15>>0] = $49;
  }
  $50 = (($i$03) + 1)|0;
  $exitcond = ($50|0)==($0|0);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $50;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation40SetFlattenedSkeletonTransformsMainThreadERKNS0_21AvatarBindingConstantERKN7mecanim8skeleton12SkeletonPoseERKNS4_9animation14AvatarConstantE($bindings,$globalSpacePose,$avatar) {
 $bindings = $bindings|0;
 $globalSpacePose = $globalSpacePose|0;
 $avatar = $avatar|0;
 var $$idx = 0, $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($bindings) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($bindings) + 20|0);
 $6 = (($globalSpacePose) + 4|0);
 $7 = $6;
 $8 = (($0) + 4|0);
 $9 = (($0) + 8|0);
 $10 = (($1) + 4|0);
 $11 = (($1) + 8|0);
 $12 = (($1) + 12|0);
 $46 = $3;$i$03 = 0;
 while(1) {
  $13 = HEAP32[$5>>2]|0;
  $14 = (($13) + (($i$03*12)|0)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   $45 = $46;
  } else {
   $17 = ((($13) + (($i$03*12)|0)|0) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$6>>2]|0;
   $20 = (($19) + ($7))|0;
   $21 = $20;
   $$idx = (($21) + (($18*48)|0)|0);
   $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
   $$idx1 = ((($21) + (($18*48)|0)|0) + 4|0);
   $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
   $$idx2 = ((($21) + (($18*48)|0)|0) + 8|0);
   $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
   HEAPF32[$0>>2] = $$idx$val;
   HEAPF32[$8>>2] = $$idx1$val;
   HEAPF32[$9>>2] = $$idx2$val;
   $22 = ((($21) + (($18*48)|0)|0) + 16|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($23 * $23);
   $25 = ((($21) + (($18*48)|0)|0) + 20|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = Math_fround($26 * $26);
   $28 = ((($21) + (($18*48)|0)|0) + 24|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = Math_fround($29 * $29);
   $31 = ((($21) + (($18*48)|0)|0) + 28|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = Math_fround($32 * $32);
   $34 = Math_fround($24 + $27);
   $35 = Math_fround($30 + $33);
   $36 = Math_fround($34 + $35);
   $37 = (Math_fround(Math_sqrt((Math_fround($36)))));
   $38 = Math_fround(Math_fround(1.0) / $37);
   $39 = Math_fround($23 * $38);
   $40 = Math_fround($26 * $38);
   $41 = Math_fround($29 * $38);
   $42 = Math_fround($32 * $38);
   HEAPF32[$1>>2] = $39;
   HEAPF32[$10>>2] = $40;
   HEAPF32[$11>>2] = $41;
   HEAPF32[$12>>2] = $42;
   __ZN9Transform26SetPositionAndRotationSafeERK8Vector3fRK11Quaternionf($15,$0,$1);
   $$pre = HEAP32[$2>>2]|0;
   $45 = $$pre;
  }
  $43 = (($i$03) + 1)|0;
  $44 = ($43>>>0)<($45>>>0);
  if ($44) {
   $46 = $45;$i$03 = $43;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation37HasGenericRootTransformPropertyValuesERKNS0_30AnimatorGenericBindingConstantEb($bindings,$scaleOnly) {
 $bindings = $bindings|0;
 $scaleOnly = $scaleOnly|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($scaleOnly) {
  label = 4;
 } else {
  $0 = (($bindings) + 40|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(-1);
  if ($2) {
   $3 = (($bindings) + 44|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(-1);
   if ($5) {
    label = 4;
   } else {
    $9 = 1;
   }
  } else {
   $9 = 1;
  }
 }
 if ((label|0) == 4) {
  $6 = (($bindings) + 48|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)!=(-1);
  $9 = $8;
 }
 STACKTOP = sp;return ($9|0);
}
function __ZN11UnityEngine9Animation37SetGenericRootTransformPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayER9Transformb($bindings,$values,$rootTransform,$scaleOnly) {
 $bindings = $bindings|0;
 $values = $values|0;
 $rootTransform = $rootTransform|0;
 $scaleOnly = $scaleOnly|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0);
 var $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 28|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = (($bindings) + 28|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  if (!($scaleOnly)) {
   $70 = (($bindings) + 40|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(-1);
   if (!($72)) {
    $73 = (($values) + 40|0);
    $74 = $73;
    $75 = HEAP32[$73>>2]|0;
    $76 = (($75) + ($74))|0;
    $77 = $76;
    $78 = (($77) + ($71<<4)|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = ((($77) + ($71<<4)|0) + 4|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = ((($77) + ($71<<4)|0) + 8|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = (($rootTransform) + 44|0);
    HEAPF32[$84>>2] = $79;
    $85 = (($rootTransform) + 48|0);
    HEAPF32[$85>>2] = $81;
    $86 = (($rootTransform) + 52|0);
    HEAPF32[$86>>2] = $83;
    $87 = (($rootTransform) + 135|0);
    $88 = HEAP8[$87>>0]|0;
    $89 = $88&255;
    $90 = $89 | 1;
    $91 = $90&255;
    HEAP8[$87>>0] = $91;
   }
   $92 = (($bindings) + 44|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(-1);
   if (!($94)) {
    $95 = (($values) + 52|0);
    $96 = $95;
    $97 = HEAP32[$95>>2]|0;
    $98 = (($97) + ($96))|0;
    $99 = $98;
    $100 = (($99) + ($93<<4)|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = ((($99) + ($93<<4)|0) + 4|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = ((($99) + ($93<<4)|0) + 8|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = ((($99) + ($93<<4)|0) + 12|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = Math_fround($101 * $101);
    $109 = Math_fround($103 * $103);
    $110 = Math_fround($105 * $105);
    $111 = Math_fround($107 * $107);
    $112 = Math_fround($108 + $109);
    $113 = Math_fround($110 + $111);
    $114 = Math_fround($112 + $113);
    $115 = (Math_fround(Math_sqrt((Math_fround($114)))));
    $116 = Math_fround(Math_fround(1.0) / $115);
    $117 = Math_fround($101 * $116);
    $118 = Math_fround($103 * $116);
    $119 = Math_fround($105 * $116);
    $120 = Math_fround($107 * $116);
    $121 = (($rootTransform) + 28|0);
    HEAPF32[$121>>2] = $117;
    $122 = (($rootTransform) + 32|0);
    HEAPF32[$122>>2] = $118;
    $123 = (($rootTransform) + 36|0);
    HEAPF32[$123>>2] = $119;
    $124 = (($rootTransform) + 40|0);
    HEAPF32[$124>>2] = $120;
    $125 = (($rootTransform) + 135|0);
    $126 = HEAP8[$125>>0]|0;
    $127 = $126&255;
    $128 = $127 | 2;
    $129 = $128&255;
    HEAP8[$125>>0] = $129;
   }
  }
  $130 = (($bindings) + 48|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ($131|0)==(-1);
  if ($132) {
   __ZN9Transform40SendTransformChangedToModifiedTransformsEv($rootTransform);
   STACKTOP = sp;return;
  }
  $133 = (($values) + 64|0);
  $134 = $133;
  $135 = HEAP32[$133>>2]|0;
  $136 = (($135) + ($134))|0;
  $137 = $136;
  $138 = (($137) + ($131<<4)|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = ((($137) + ($131<<4)|0) + 4|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = ((($137) + ($131<<4)|0) + 8|0);
  $143 = Math_fround(HEAPF32[$142>>2]);
  $144 = (($rootTransform) + 56|0);
  HEAPF32[$144>>2] = $139;
  $145 = (($rootTransform) + 60|0);
  HEAPF32[$145>>2] = $141;
  $146 = (($rootTransform) + 64|0);
  HEAPF32[$146>>2] = $143;
  $147 = (($rootTransform) + 135|0);
  $148 = HEAP8[$147>>0]|0;
  $149 = $148&255;
  $150 = $149 | 8;
  $151 = $150&255;
  HEAP8[$147>>0] = $151;
  __ZN9Transform24RecalculateTransformTypeEv($rootTransform);
  __ZN9Transform40SendTransformChangedToModifiedTransformsEv($rootTransform);
  STACKTOP = sp;return;
 } else {
  if (!($scaleOnly)) {
   $6 = (($bindings) + 40|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(-1);
   if (!($8)) {
    $9 = (($values) + 40|0);
    $10 = $9;
    $11 = HEAP32[$9>>2]|0;
    $12 = (($11) + ($10))|0;
    $13 = $12;
    $14 = (($13) + ($7<<4)|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = ((($13) + ($7<<4)|0) + 4|0);
    $17 = Math_fround(HEAPF32[$16>>2]);
    $18 = ((($13) + ($7<<4)|0) + 8|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    HEAPF32[$0>>2] = $15;
    $20 = (($0) + 4|0);
    HEAPF32[$20>>2] = $17;
    $21 = (($0) + 8|0);
    HEAPF32[$21>>2] = $19;
    __ZN9Transform44SetLocalPositionOnCompareWithoutNotificationERK8Vector3f($rootTransform,$0);
   }
   $22 = (($bindings) + 44|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(-1);
   if (!($24)) {
    $25 = (($values) + 52|0);
    $26 = $25;
    $27 = HEAP32[$25>>2]|0;
    $28 = (($27) + ($26))|0;
    $29 = $28;
    $30 = (($29) + ($23<<4)|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = ((($29) + ($23<<4)|0) + 4|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = ((($29) + ($23<<4)|0) + 8|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = ((($29) + ($23<<4)|0) + 12|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = Math_fround($31 * $31);
    $39 = Math_fround($33 * $33);
    $40 = Math_fround($35 * $35);
    $41 = Math_fround($37 * $37);
    $42 = Math_fround($38 + $39);
    $43 = Math_fround($40 + $41);
    $44 = Math_fround($42 + $43);
    $45 = (Math_fround(Math_sqrt((Math_fround($44)))));
    $46 = Math_fround(Math_fround(1.0) / $45);
    $47 = Math_fround($31 * $46);
    $48 = Math_fround($33 * $46);
    $49 = Math_fround($35 * $46);
    $50 = Math_fround($37 * $46);
    HEAPF32[$1>>2] = $47;
    $51 = (($1) + 4|0);
    HEAPF32[$51>>2] = $48;
    $52 = (($1) + 8|0);
    HEAPF32[$52>>2] = $49;
    $53 = (($1) + 12|0);
    HEAPF32[$53>>2] = $50;
    __ZN9Transform44SetLocalRotationOnCompareWithoutNotificationERK11Quaternionf($rootTransform,$1);
   }
  }
  $54 = (($bindings) + 48|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==(-1);
  if ($56) {
   __ZN9Transform40SendTransformChangedToModifiedTransformsEv($rootTransform);
   STACKTOP = sp;return;
  }
  $57 = (($values) + 64|0);
  $58 = $57;
  $59 = HEAP32[$57>>2]|0;
  $60 = (($59) + ($58))|0;
  $61 = $60;
  $62 = (($61) + ($55<<4)|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = ((($61) + ($55<<4)|0) + 4|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($61) + ($55<<4)|0) + 8|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$2>>2] = $63;
  $68 = (($2) + 4|0);
  HEAPF32[$68>>2] = $65;
  $69 = (($2) + 8|0);
  HEAPF32[$69>>2] = $67;
  __ZN9Transform41SetLocalScaleOnCompareWithoutNotificationERK8Vector3f($rootTransform,$2);
  __ZN9Transform40SendTransformChangedToModifiedTransformsEv($rootTransform);
  STACKTOP = sp;return;
 }
}
function __ZN11UnityEngine9Animation33SetGenericTransformPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayEP9Transform($bindings,$values,$skipTransform) {
 $bindings = $bindings|0;
 $values = $values|0;
 $skipTransform = $skipTransform|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0;
 var $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $bindIndex$026 = 0, $bindIndex3$020 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0;
 var $positionIndex$028 = 0, $positionIndex$1 = 0, $positionIndex$222 = 0, $positionIndex$3 = 0, $rotationIndex$029 = 0, $rotationIndex$1 = 0, $rotationIndex$223 = 0, $rotationIndex$3 = 0, $scaleIndex$027 = 0, $scaleIndex$1 = 0, $scaleIndex$221 = 0, $scaleIndex$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = (($bindings) + 28|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = HEAP32[$bindings>>2]|0;
 $7 = ($6|0)==(0);
 if ($5) {
  if ($7) {
   STACKTOP = sp;return;
  }
  $22 = (($bindings) + 4|0);
  $23 = (($values) + 52|0);
  $24 = $23;
  $25 = (($values) + 40|0);
  $26 = $25;
  $27 = (($values) + 64|0);
  $28 = $27;
  $bindIndex3$020 = 0;$positionIndex$222 = 0;$rotationIndex$223 = 0;$scaleIndex$221 = 0;
  while(1) {
   $88 = HEAP32[$22>>2]|0;
   $89 = ((($88) + ($bindIndex3$020<<4)|0) + 4|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ((($88) + ($bindIndex3$020<<4)|0) + 12|0);
   $92 = HEAP32[$91>>2]|0;
   if ((($90|0) == 2)) {
    $93 = ($92|0)==(0|0);
    $94 = ($92|0)==($skipTransform|0);
    $or$cond3 = $93 | $94;
    if (!($or$cond3)) {
     $95 = HEAP32[$23>>2]|0;
     $96 = (($95) + ($24))|0;
     $97 = $96;
     $98 = (($97) + ($rotationIndex$223<<4)|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     $100 = ((($97) + ($rotationIndex$223<<4)|0) + 4|0);
     $101 = Math_fround(HEAPF32[$100>>2]);
     $102 = ((($97) + ($rotationIndex$223<<4)|0) + 8|0);
     $103 = Math_fround(HEAPF32[$102>>2]);
     $104 = ((($97) + ($rotationIndex$223<<4)|0) + 12|0);
     $105 = Math_fround(HEAPF32[$104>>2]);
     $106 = Math_fround($99 * $99);
     $107 = Math_fround($101 * $101);
     $108 = Math_fround($103 * $103);
     $109 = Math_fround($105 * $105);
     $110 = Math_fround($106 + $107);
     $111 = Math_fround($108 + $109);
     $112 = Math_fround($110 + $111);
     $113 = (Math_fround(Math_sqrt((Math_fround($112)))));
     $114 = Math_fround(Math_fround(1.0) / $113);
     $115 = Math_fround($99 * $114);
     $116 = Math_fround($101 * $114);
     $117 = Math_fround($103 * $114);
     $118 = Math_fround($105 * $114);
     $119 = (($92) + 28|0);
     HEAPF32[$119>>2] = $115;
     $120 = (($92) + 32|0);
     HEAPF32[$120>>2] = $116;
     $121 = (($92) + 36|0);
     HEAPF32[$121>>2] = $117;
     $122 = (($92) + 40|0);
     HEAPF32[$122>>2] = $118;
     $123 = (($92) + 135|0);
     $124 = HEAP8[$123>>0]|0;
     $125 = $124&255;
     $126 = $125 | 2;
     $127 = $126&255;
     HEAP8[$123>>0] = $127;
    }
    $128 = (($rotationIndex$223) + 1)|0;
    $positionIndex$3 = $positionIndex$222;$rotationIndex$3 = $128;$scaleIndex$3 = $scaleIndex$221;
   } else if ((($90|0) == 1)) {
    $129 = ($92|0)==(0|0);
    $130 = ($92|0)==($skipTransform|0);
    $or$cond4 = $129 | $130;
    if (!($or$cond4)) {
     $131 = HEAP32[$25>>2]|0;
     $132 = (($131) + ($26))|0;
     $133 = $132;
     $134 = (($133) + ($positionIndex$222<<4)|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     $136 = ((($133) + ($positionIndex$222<<4)|0) + 4|0);
     $137 = Math_fround(HEAPF32[$136>>2]);
     $138 = ((($133) + ($positionIndex$222<<4)|0) + 8|0);
     $139 = Math_fround(HEAPF32[$138>>2]);
     $140 = (($92) + 44|0);
     HEAPF32[$140>>2] = $135;
     $141 = (($92) + 48|0);
     HEAPF32[$141>>2] = $137;
     $142 = (($92) + 52|0);
     HEAPF32[$142>>2] = $139;
     $143 = (($92) + 135|0);
     $144 = HEAP8[$143>>0]|0;
     $145 = $144&255;
     $146 = $145 | 1;
     $147 = $146&255;
     HEAP8[$143>>0] = $147;
    }
    $148 = (($positionIndex$222) + 1)|0;
    $positionIndex$3 = $148;$rotationIndex$3 = $rotationIndex$223;$scaleIndex$3 = $scaleIndex$221;
   } else if ((($90|0) == 3)) {
    $149 = ($92|0)==(0|0);
    $150 = ($92|0)==($skipTransform|0);
    $or$cond5 = $149 | $150;
    if (!($or$cond5)) {
     $151 = HEAP32[$27>>2]|0;
     $152 = (($151) + ($28))|0;
     $153 = $152;
     $154 = (($153) + ($scaleIndex$221<<4)|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = ((($153) + ($scaleIndex$221<<4)|0) + 4|0);
     $157 = Math_fround(HEAPF32[$156>>2]);
     $158 = ((($153) + ($scaleIndex$221<<4)|0) + 8|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = (($92) + 56|0);
     HEAPF32[$160>>2] = $155;
     $161 = (($92) + 60|0);
     HEAPF32[$161>>2] = $157;
     $162 = (($92) + 64|0);
     HEAPF32[$162>>2] = $159;
     $163 = (($92) + 135|0);
     $164 = HEAP8[$163>>0]|0;
     $165 = $164&255;
     $166 = $165 | 8;
     $167 = $166&255;
     HEAP8[$163>>0] = $167;
     __ZN9Transform24RecalculateTransformTypeEv($92);
    }
    $168 = (($scaleIndex$221) + 1)|0;
    $positionIndex$3 = $positionIndex$222;$rotationIndex$3 = $rotationIndex$223;$scaleIndex$3 = $168;
   } else {
    $positionIndex$3 = $positionIndex$222;$rotationIndex$3 = $rotationIndex$223;$scaleIndex$3 = $scaleIndex$221;
   }
   $169 = (($bindIndex3$020) + 1)|0;
   $170 = HEAP32[$bindings>>2]|0;
   $171 = ($169|0)==($170|0);
   if ($171) {
    break;
   } else {
    $bindIndex3$020 = $169;$positionIndex$222 = $positionIndex$3;$rotationIndex$223 = $rotationIndex$3;$scaleIndex$221 = $scaleIndex$3;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($7) {
   STACKTOP = sp;return;
  }
  $8 = (($bindings) + 4|0);
  $9 = (($values) + 52|0);
  $10 = $9;
  $11 = (($0) + 4|0);
  $12 = (($0) + 8|0);
  $13 = (($0) + 12|0);
  $14 = (($values) + 40|0);
  $15 = $14;
  $16 = (($1) + 4|0);
  $17 = (($1) + 8|0);
  $18 = (($values) + 64|0);
  $19 = $18;
  $20 = (($2) + 4|0);
  $21 = (($2) + 8|0);
  $bindIndex$026 = 0;$positionIndex$028 = 0;$rotationIndex$029 = 0;$scaleIndex$027 = 0;
  while(1) {
   $29 = HEAP32[$8>>2]|0;
   $30 = ((($29) + ($bindIndex$026<<4)|0) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ((($29) + ($bindIndex$026<<4)|0) + 12|0);
   $33 = HEAP32[$32>>2]|0;
   if ((($31|0) == 1)) {
    $61 = ($33|0)==(0|0);
    $62 = ($33|0)==($skipTransform|0);
    $or$cond1 = $61 | $62;
    if (!($or$cond1)) {
     $63 = HEAP32[$14>>2]|0;
     $64 = (($63) + ($15))|0;
     $65 = $64;
     $66 = (($65) + ($positionIndex$028<<4)|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = ((($65) + ($positionIndex$028<<4)|0) + 4|0);
     $69 = Math_fround(HEAPF32[$68>>2]);
     $70 = ((($65) + ($positionIndex$028<<4)|0) + 8|0);
     $71 = Math_fround(HEAPF32[$70>>2]);
     HEAPF32[$1>>2] = $67;
     HEAPF32[$16>>2] = $69;
     HEAPF32[$17>>2] = $71;
     __ZN9Transform44SetLocalPositionOnCompareWithoutNotificationERK8Vector3f($33,$1);
    }
    $72 = (($positionIndex$028) + 1)|0;
    $positionIndex$1 = $72;$rotationIndex$1 = $rotationIndex$029;$scaleIndex$1 = $scaleIndex$027;
   } else if ((($31|0) == 3)) {
    $73 = ($33|0)==(0|0);
    $74 = ($33|0)==($skipTransform|0);
    $or$cond2 = $73 | $74;
    if (!($or$cond2)) {
     $75 = HEAP32[$18>>2]|0;
     $76 = (($75) + ($19))|0;
     $77 = $76;
     $78 = (($77) + ($scaleIndex$027<<4)|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $80 = ((($77) + ($scaleIndex$027<<4)|0) + 4|0);
     $81 = Math_fround(HEAPF32[$80>>2]);
     $82 = ((($77) + ($scaleIndex$027<<4)|0) + 8|0);
     $83 = Math_fround(HEAPF32[$82>>2]);
     HEAPF32[$2>>2] = $79;
     HEAPF32[$20>>2] = $81;
     HEAPF32[$21>>2] = $83;
     __ZN9Transform41SetLocalScaleOnCompareWithoutNotificationERK8Vector3f($33,$2);
    }
    $84 = (($scaleIndex$027) + 1)|0;
    $positionIndex$1 = $positionIndex$028;$rotationIndex$1 = $rotationIndex$029;$scaleIndex$1 = $84;
   } else if ((($31|0) == 2)) {
    $34 = ($33|0)==(0|0);
    $35 = ($33|0)==($skipTransform|0);
    $or$cond = $34 | $35;
    if (!($or$cond)) {
     $36 = HEAP32[$9>>2]|0;
     $37 = (($36) + ($10))|0;
     $38 = $37;
     $39 = (($38) + ($rotationIndex$029<<4)|0);
     $40 = Math_fround(HEAPF32[$39>>2]);
     $41 = ((($38) + ($rotationIndex$029<<4)|0) + 4|0);
     $42 = Math_fround(HEAPF32[$41>>2]);
     $43 = ((($38) + ($rotationIndex$029<<4)|0) + 8|0);
     $44 = Math_fround(HEAPF32[$43>>2]);
     $45 = ((($38) + ($rotationIndex$029<<4)|0) + 12|0);
     $46 = Math_fround(HEAPF32[$45>>2]);
     $47 = Math_fround($40 * $40);
     $48 = Math_fround($42 * $42);
     $49 = Math_fround($44 * $44);
     $50 = Math_fround($46 * $46);
     $51 = Math_fround($47 + $48);
     $52 = Math_fround($49 + $50);
     $53 = Math_fround($51 + $52);
     $54 = (Math_fround(Math_sqrt((Math_fround($53)))));
     $55 = Math_fround(Math_fround(1.0) / $54);
     $56 = Math_fround($40 * $55);
     $57 = Math_fround($42 * $55);
     $58 = Math_fround($44 * $55);
     $59 = Math_fround($46 * $55);
     HEAPF32[$0>>2] = $56;
     HEAPF32[$11>>2] = $57;
     HEAPF32[$12>>2] = $58;
     HEAPF32[$13>>2] = $59;
     __ZN9Transform44SetLocalRotationOnCompareWithoutNotificationERK11Quaternionf($33,$0);
    }
    $60 = (($rotationIndex$029) + 1)|0;
    $positionIndex$1 = $positionIndex$028;$rotationIndex$1 = $60;$scaleIndex$1 = $scaleIndex$027;
   } else {
    $positionIndex$1 = $positionIndex$028;$rotationIndex$1 = $rotationIndex$029;$scaleIndex$1 = $scaleIndex$027;
   }
   $85 = (($bindIndex$026) + 1)|0;
   $86 = HEAP32[$bindings>>2]|0;
   $87 = ($85|0)==($86|0);
   if ($87) {
    break;
   } else {
    $bindIndex$026 = $85;$positionIndex$028 = $positionIndex$1;$rotationIndex$029 = $rotationIndex$1;$scaleIndex$027 = $scaleIndex$1;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN11UnityEngine9AnimationL22GenericBindingCallbackEPvS1_i($userData,$sender,$eventType) {
 $userData = $userData|0;
 $sender = $sender|0;
 $eventType = $eventType|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $exitcond$i3$i = 0, $exitcond$i7$i = 0, $iter$01$i$i = 0, $iter$01$i2$i = 0, $iter$01$i6$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($eventType|0)==(2);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (($userData) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$userData>>2]|0;
 $5 = ($4|0)>(0);
 if ($5) {
  $iter$01$i$i = 0;
  while(1) {
   $6 = ((($3) + ($iter$01$i$i<<4)|0) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($sender|0);
   if ($8) {
    $9 = (($3) + ($iter$01$i$i<<4)|0);
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    ;HEAP32[$9+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$0+12>>2]|0;
   }
   $10 = (($iter$01$i$i) + 1)|0;
   $exitcond$i$i = ($10|0)==($4|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $iter$01$i$i = $10;
   }
  }
 }
 $11 = (($userData) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($userData) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(0);
 if ($15) {
  $iter$01$i6$i = 0;
  while(1) {
   $16 = ((($12) + ($iter$01$i6$i<<4)|0) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==($sender|0);
   if ($18) {
    $19 = (($12) + ($iter$01$i6$i<<4)|0);
    ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
    ;HEAP32[$19+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$0+12>>2]|0;
   }
   $20 = (($iter$01$i6$i) + 1)|0;
   $exitcond$i7$i = ($20|0)==($14|0);
   if ($exitcond$i7$i) {
    break;
   } else {
    $iter$01$i6$i = $20;
   }
  }
 }
 $21 = (($userData) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($userData) + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(0);
 if ($25) {
  $iter$01$i2$i = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $26 = ((($22) + ($iter$01$i2$i<<4)|0) + 12|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($sender|0);
  if ($28) {
   $29 = (($22) + ($iter$01$i2$i<<4)|0);
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   ;HEAP32[$29+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$29+12>>2]=HEAP32[$0+12>>2]|0;
  }
  $30 = (($iter$01$i2$i) + 1)|0;
  $exitcond$i3$i = ($30|0)==($24|0);
  if ($exitcond$i3$i) {
   break;
  } else {
   $iter$01$i2$i = $30;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation15IsMuscleBindingERKNS0_14GenericBindingE($binding) {
 $binding = $binding|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($binding) + 12|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(95);
 if (!($2)) {
  $6 = 0;
  STACKTOP = sp;return ($6|0);
 }
 $3 = (($binding) + 14|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(8);
 $6 = $5;
 STACKTOP = sp;return ($6|0);
}
function __ZN11UnityEngine9Animation28GenericAnimationBindingCache15DidReloadDomainEv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[765744>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($2) + 48|0);
 $5 = (($2) + 56|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $i$01$i = 0;
  while(1) {
   $8 = HEAP32[$4>>2]|0;
   $9 = (($8) + ($i$01$i<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[628296>>2]|0;
   HEAP32[$1>>2] = $11;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($10,$$byval_copy1);
   $12 = (($i$01$i) + 1)|0;
   $13 = HEAP32[$5>>2]|0;
   $14 = ($12>>>0)<($13>>>0);
   if ($14) {
    $i$01$i = $12;
   } else {
    break;
   }
  }
 }
 $15 = (($2) + 60|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)>(-1);
 if ($17) {
  $18 = HEAP32[$4>>2]|0;
  $19 = (($2) + 52|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$0>>2] = $20;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($18,$$byval_copy1);
  HEAP32[$4>>2] = 0;
 }
 HEAP32[$5>>2] = 0;
 HEAP32[$15>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation38InitializeGenericAnimationBindingCacheEv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 __ZN7mecanim13crc32_table_tILj79764919EE10init_tableEv();
 $1 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(68,$$byval_copy1,1,16,765752,401)|0);
 __THREW__ = 0;
 invoke_vi(3688,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_viiiiii(97,($2|0),($$byval_copy1|0),1,16,(765752|0),401);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch(0|0)|0;
   $16 = tempRet0;
   ___clang_call_terminate($15);
   // unreachable;
  } else {
   ___resumeException($11|0);
   // unreachable;
  }
 }
 HEAP32[765744>>2] = $2;
 $5 = (__ZN15GlobalCallbacks3GetEv()|0);
 $i$01$i = 0;
 while(1) {
  $8 = ((($5) + ($i$01$i<<2)|0) + 64|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  $7 = (($i$01$i) + 1)|0;
  if ($10) {
   break;
  }
  $6 = ($7|0)<(16);
  if ($6) {
   $i$01$i = $7;
  } else {
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
 HEAP32[$8>>2] = 231;
 STACKTOP = sp;return;
}
function __ZN7mecanim13crc32_table_tILj79764919EE10init_tableEv() {
 var $$02$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dividend$0 = 0, $exitcond$i = 0, $i$03$i = 0, $not$ = 0, $reflection$01$i = 0, $reflection$1$i = 0, $remainder$0$$3 = 0, $remainder$0$$4 = 0, $remainder$0$$5 = 0, $remainder$0$$6 = 0;
 var $remainder$0$$7 = 0, $remainder$2 = 0, $remainder$2$1 = 0, $remainder$2$2 = 0, $remainder$2$3 = 0, $remainder$2$4 = 0, $remainder$2$5 = 0, $remainder$2$6 = 0, $remainder$2$7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $dividend$0 = 0;
 while(1) {
  $not$ = ($dividend$0<<24>>24)<(0);
  $remainder$2 = $not$ ? 159529838 : 0;
  $0 = $dividend$0 & 64;
  $1 = ($0<<24>>24)!=(0);
  $2 = $remainder$2 ^ 79764919;
  $remainder$2$1 = $1 ? $2 : $remainder$2;
  $3 = $dividend$0 & 32;
  $4 = ($3<<24>>24)!=(0);
  $5 = $remainder$2$1 << 1;
  $6 = $5 ^ 79764919;
  $remainder$2$2 = $4 ? $6 : $5;
  $7 = $dividend$0 & 16;
  $8 = ($7<<24>>24)==(0);
  $9 = $remainder$2$2 ^ -2147483648;
  $remainder$0$$3 = $8 ? $remainder$2$2 : $9;
  $10 = ($remainder$0$$3|0)<(0);
  $11 = $remainder$0$$3 << 1;
  $12 = $11 ^ 79764919;
  $remainder$2$3 = $10 ? $12 : $11;
  $13 = $dividend$0 & 8;
  $14 = ($13<<24>>24)==(0);
  $15 = $remainder$2$3 ^ -2147483648;
  $remainder$0$$4 = $14 ? $remainder$2$3 : $15;
  $16 = ($remainder$0$$4|0)<(0);
  $17 = $remainder$0$$4 << 1;
  $18 = $17 ^ 79764919;
  $remainder$2$4 = $16 ? $18 : $17;
  $19 = $dividend$0 & 4;
  $20 = ($19<<24>>24)==(0);
  $21 = $remainder$2$4 ^ -2147483648;
  $remainder$0$$5 = $20 ? $remainder$2$4 : $21;
  $22 = ($remainder$0$$5|0)<(0);
  $23 = $remainder$0$$5 << 1;
  $24 = $23 ^ 79764919;
  $remainder$2$5 = $22 ? $24 : $23;
  $25 = $dividend$0 & 2;
  $26 = ($25<<24>>24)==(0);
  $27 = $remainder$2$5 ^ -2147483648;
  $remainder$0$$6 = $26 ? $remainder$2$5 : $27;
  $28 = ($remainder$0$$6|0)<(0);
  $29 = $remainder$0$$6 << 1;
  $30 = $29 ^ 79764919;
  $remainder$2$6 = $28 ? $30 : $29;
  $31 = $dividend$0 & 1;
  $32 = ($31<<24>>24)==(0);
  $33 = $remainder$2$6 ^ -2147483648;
  $remainder$0$$7 = $32 ? $remainder$2$6 : $33;
  $34 = ($remainder$0$$7|0)<(0);
  $35 = $remainder$0$$7 << 1;
  $36 = $35 ^ 79764919;
  $remainder$2$7 = $34 ? $36 : $35;
  $$02$i = $remainder$2$7;$i$03$i = 0;$reflection$01$i = 0;
  while(1) {
   $37 = $$02$i & 1;
   $38 = ($37|0)==(0);
   if ($38) {
    $reflection$1$i = $reflection$01$i;
   } else {
    $39 = (31 - ($i$03$i))|0;
    $40 = 1 << $39;
    $41 = $40 | $reflection$01$i;
    $reflection$1$i = $41;
   }
   $42 = (($i$03$i) + 1)|0;
   $43 = $$02$i >>> 1;
   $exitcond$i = ($42|0)==(32);
   if ($exitcond$i) {
    break;
   } else {
    $$02$i = $43;$i$03$i = $42;$reflection$01$i = $reflection$1$i;
   }
  }
  $44 = (__ZN7mecanim9reflectorILj8EE7reflectEh($dividend$0)|0);
  $45 = $44&255;
  $46 = (584048 + ($45<<2)|0);
  HEAP32[$46>>2] = $reflection$1$i;
  $47 = (($dividend$0) + 1)<<24>>24;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   break;
  } else {
   $dividend$0 = $47;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation35CleanupGenericAnimationBindingCacheEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[765744>>2]|0;
 $2 = HEAP32[628296>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN11UnityEngine9Animation28GenericAnimationBindingCacheD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[765744>>2] = 0;
 $4 = (__ZN15GlobalCallbacks3GetEv()|0);
 $5 = (($4) + 64|0);
 __ZN17CallbackArrayBaseIPFvvEE10UnregisterES1_($5,231);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation31GetGenericAnimationBindingCacheEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[765744>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN11UnityEngine9Animation28GenericAnimationBindingCacheC2Ev($this) {
 $this = $this|0;
 var $$01$i$i = 0, $$01$i$i10 = 0, $$02$i$i$i$i = 0, $$byval_copy6 = 0, $$masked$i$i$i = 0, $$masked$i$i$i$1 = 0, $$masked$i$i$i$2 = 0, $$masked$i$i$i$3 = 0, $$masked$i$i$i$4 = 0, $$masked$i$i$i$5 = 0, $$masked$i$i$i$6 = 0, $$masked$i$i$i$7 = 0, $$masked$i$i$i$8 = 0, $$masked$i$i$i$9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i$i$i$i = 0, $i$03$i$i$i$i = 0, $reflection$01$i$i$i$i = 0;
 var $reflection$1$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = sp + 24|0;
 HEAP32[$this>>2] = 0;
 $7 = (($this) + 8|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 12|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 4|0);
 HEAP32[$9>>2] = 61;
 $10 = (($this) + 16|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 24|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 28|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 20|0);
 HEAP32[$13>>2] = 61;
 $14 = (($this) + 32|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 40|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 44|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 36|0);
 HEAP32[$17>>2] = 61;
 $18 = (($this) + 48|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 56|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 60|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 52|0);
 HEAP32[$21>>2] = 61;
 $$02$i$i$i$i = -1;$i$03$i$i$i$i = 0;$reflection$01$i$i$i$i = 0;
 while(1) {
  $22 = $$02$i$i$i$i & 1;
  $23 = ($22|0)==(0);
  if ($23) {
   $reflection$1$i$i$i$i = $reflection$01$i$i$i$i;
  } else {
   $24 = (31 - ($i$03$i$i$i$i))|0;
   $25 = 1 << $24;
   $26 = $25 | $reflection$01$i$i$i$i;
   $reflection$1$i$i$i$i = $26;
  }
  $27 = (($i$03$i$i$i$i) + 1)|0;
  $28 = $$02$i$i$i$i >>> 1;
  $exitcond$i$i$i$i = ($27|0)==(32);
  if ($exitcond$i$i$i$i) {
   break;
  } else {
   $$02$i$i$i$i = $28;$i$03$i$i$i$i = $27;$reflection$01$i$i$i$i = $reflection$1$i$i$i$i;
  }
 }
 $29 = $reflection$1$i$i$i$i >>> 8;
 $$masked$i$i$i = $reflection$1$i$i$i$i & 255;
 $30 = $$masked$i$i$i ^ 109;
 $31 = (584048 + ($30<<2)|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 ^ $29;
 $34 = $33 >>> 8;
 $$masked$i$i$i$1 = $33 & 255;
 $35 = $$masked$i$i$i$1 ^ 95;
 $36 = (584048 + ($35<<2)|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 ^ $34;
 $39 = $38 >>> 8;
 $$masked$i$i$i$2 = $38 & 255;
 $40 = $$masked$i$i$i$2 ^ 73;
 $41 = (584048 + ($40<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 ^ $39;
 $44 = $43 >>> 8;
 $$masked$i$i$i$3 = $43 & 255;
 $45 = $$masked$i$i$i$3 ^ 115;
 $46 = (584048 + ($45<<2)|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 ^ $44;
 $49 = $48 >>> 8;
 $$masked$i$i$i$4 = $48 & 255;
 $50 = $$masked$i$i$i$4 ^ 65;
 $51 = (584048 + ($50<<2)|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 ^ $49;
 $54 = $53 >>> 8;
 $$masked$i$i$i$5 = $53 & 255;
 $55 = $$masked$i$i$i$5 ^ 99;
 $56 = (584048 + ($55<<2)|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $57 ^ $54;
 $59 = $58 >>> 8;
 $$masked$i$i$i$6 = $58 & 255;
 $60 = $$masked$i$i$i$6 ^ 116;
 $61 = (584048 + ($60<<2)|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = $62 ^ $59;
 $64 = $63 >>> 8;
 $$masked$i$i$i$7 = $63 & 255;
 $65 = $$masked$i$i$i$7 ^ 105;
 $66 = (584048 + ($65<<2)|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = $67 ^ $64;
 $69 = $68 >>> 8;
 $$masked$i$i$i$8 = $68 & 255;
 $70 = $$masked$i$i$i$8 ^ 118;
 $71 = (584048 + ($70<<2)|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $72 ^ $69;
 $74 = $73 >>> 8;
 $$masked$i$i$i$9 = $73 & 255;
 $75 = $$masked$i$i$i$9 ^ 101;
 $76 = (584048 + ($75<<2)|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = $77 ^ $74;
 $79 = $78 ^ -1;
 $80 = (($this) + 64|0);
 HEAP32[$80>>2] = $79;
 HEAP32[$16>>2] = 291;
 HEAP32[$3>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
 $81 = (invoke_iiiiiiii(108,(0|0),1164,4,($$byval_copy6|0),0,(765752|0),370)|0);
 $82 = __THREW__; __THREW__ = 0;
 $83 = $82&1;
 L7: do {
  if (!($83)) {
   HEAP32[$14>>2] = $81;
   $84 = HEAP32[$15>>2]|0;
   $85 = ($84>>>0)<(291);
   if ($85) {
    $86 = (($81) + 1164|0);
    $87 = (($81) + ($84<<2)|0);
    $$01$i$i = $87;
    while(1) {
     $88 = ($$01$i$i|0)==(0|0);
     if (!($88)) {
      HEAP32[$$01$i$i>>2] = 0;
     }
     $89 = (($$01$i$i) + 4|0);
     $90 = ($89|0)==($86|0);
     if ($90) {
      break;
     } else {
      $$01$i$i = $89;
     }
    }
   }
   HEAP32[$15>>2] = 291;
   $91 = HEAP32[$12>>2]|0;
   $92 = $91 & 2147483647;
   $93 = ($92>>>0)<(25);
   do {
    if ($93) {
     $94 = ($91|0)>(-1);
     if ($94) {
      HEAP32[$12>>2] = 25;
      $95 = HEAP32[$10>>2]|0;
      $96 = HEAP32[$13>>2]|0;
      HEAP32[$1>>2] = $96;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
      $97 = (invoke_iiiiiiii(108,($95|0),100,4,($$byval_copy6|0),0,(765752|0),370)|0);
      $98 = __THREW__; __THREW__ = 0;
      $99 = $98&1;
      if ($99) {
       break L7;
      }
      HEAP32[$10>>2] = $97;
      break;
     } else {
      $100 = HEAP32[$13>>2]|0;
      HEAP32[$2>>2] = $100;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$2+0>>2]|0;
      $101 = (invoke_iiiiiii(102,100,4,($$byval_copy6|0),0,(765752|0),352)|0);
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       break L7;
      }
      $104 = HEAP32[$10>>2]|0;
      $105 = HEAP32[$11>>2]|0;
      $106 = $105 << 2;
      _memcpy(($101|0),($104|0),($106|0))|0;
      HEAP32[$12>>2] = 25;
      HEAP32[$10>>2] = $101;
      break;
     }
    }
   } while(0);
   $107 = HEAP32[$11>>2]|0;
   $108 = ($107>>>0)<(25);
   if (!($108)) {
    HEAP32[$11>>2] = 25;
    STACKTOP = sp;return;
   }
   $109 = HEAP32[$10>>2]|0;
   $110 = (($109) + 100|0);
   $111 = (($109) + ($107<<2)|0);
   $$01$i$i10 = $111;
   while(1) {
    $112 = ($$01$i$i10|0)==(0|0);
    if (!($112)) {
     HEAP32[$$01$i$i10>>2] = 0;
    }
    $113 = (($$01$i$i10) + 4|0);
    $114 = ($113|0)==($110|0);
    if ($114) {
     break;
    } else {
     $$01$i$i10 = $113;
    }
   }
   HEAP32[$11>>2] = 25;
   STACKTOP = sp;return;
  }
 } while(0);
 $115 = ___cxa_find_matching_catch()|0;
 $116 = tempRet0;
 $117 = HEAP32[$20>>2]|0;
 $118 = ($117|0)>(-1);
 do {
  if ($118) {
   $119 = HEAP32[$18>>2]|0;
   $120 = HEAP32[$21>>2]|0;
   HEAP32[$0>>2] = $120;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($119|0),($$byval_copy6|0));
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if ($122) {
    $141 = ___cxa_find_matching_catch(0|0)|0;
    $142 = tempRet0;
    ___clang_call_terminate($141);
    // unreachable;
   } else {
    HEAP32[$18>>2] = 0;
    break;
   }
  }
 } while(0);
 $123 = HEAP32[$16>>2]|0;
 $124 = ($123|0)>(-1);
 do {
  if ($124) {
   $125 = HEAP32[$14>>2]|0;
   $126 = HEAP32[$17>>2]|0;
   HEAP32[$4>>2] = $126;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($125|0),($$byval_copy6|0));
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if ($128) {
    $141 = ___cxa_find_matching_catch(0|0)|0;
    $142 = tempRet0;
    ___clang_call_terminate($141);
    // unreachable;
   } else {
    HEAP32[$14>>2] = 0;
    break;
   }
  }
 } while(0);
 $129 = HEAP32[$12>>2]|0;
 $130 = ($129|0)>(-1);
 do {
  if ($130) {
   $131 = HEAP32[$10>>2]|0;
   $132 = HEAP32[$13>>2]|0;
   HEAP32[$5>>2] = $132;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($131|0),($$byval_copy6|0));
   $133 = __THREW__; __THREW__ = 0;
   $134 = $133&1;
   if ($134) {
    $141 = ___cxa_find_matching_catch(0|0)|0;
    $142 = tempRet0;
    ___clang_call_terminate($141);
    // unreachable;
   } else {
    HEAP32[$10>>2] = 0;
    break;
   }
  }
 } while(0);
 $135 = HEAP32[$8>>2]|0;
 $136 = ($135|0)>(-1);
 if (!($136)) {
  ___resumeException($115|0);
  // unreachable;
 }
 $137 = HEAP32[$this>>2]|0;
 $138 = HEAP32[$9>>2]|0;
 HEAP32[$6>>2] = $138;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_vii(2591,($137|0),($$byval_copy6|0));
 $139 = __THREW__; __THREW__ = 0;
 $140 = $139&1;
 if ($140) {
  $141 = ___cxa_find_matching_catch(0|0)|0;
  $142 = tempRet0;
  ___clang_call_terminate($141);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($115|0);
 // unreachable;
}
function __ZN11UnityEngine9Animation28GenericAnimationBindingCacheD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$01$i = 0, $i$01$i6 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy18 = sp + 44|0;
 $0 = sp + 40|0;
 $1 = sp + 36|0;
 $2 = sp + 32|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $5 = sp + 20|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = sp + 16|0;
 $11 = (($this) + 32|0);
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 L1: do {
  if ($14) {
   label = 5;
  } else {
   $i$01$i = 0;
   while(1) {
    $15 = HEAP32[$11>>2]|0;
    $16 = (($15) + ($i$01$i<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[628296>>2]|0;
    HEAP32[$10>>2] = $18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$10+0>>2]|0;
    invoke_vii(2591,($17|0),($$byval_copy18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = (($i$01$i) + 1)|0;
    $22 = HEAP32[$12>>2]|0;
    $23 = ($21>>>0)<($22>>>0);
    if ($23) {
     $i$01$i = $21;
    } else {
     label = 5;
     break L1;
    }
   }
   $82 = ___cxa_find_matching_catch()|0;
   $83 = tempRet0;
   $lpad$phi$index = $82;$lpad$phi$index3 = $83;
   label = 28;
  }
 } while(0);
 L7: do {
  if ((label|0) == 5) {
   $24 = (($this) + 44|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(-1);
   if ($26) {
    $27 = HEAP32[$11>>2]|0;
    $28 = (($this) + 36|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$9>>2] = $29;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$9+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy18|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     HEAP32[$11>>2] = 0;
     label = 8;
    }
   } else {
    label = 8;
   }
   do {
    if ((label|0) == 8) {
     HEAP32[$12>>2] = 0;
     HEAP32[$24>>2] = 0;
     $32 = (($this) + 48|0);
     $33 = (($this) + 56|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0);
     L14: do {
      if (!($35)) {
       $i$01$i6 = 0;
       while(1) {
        $36 = HEAP32[$32>>2]|0;
        $37 = (($36) + ($i$01$i6<<2)|0);
        $38 = HEAP32[$37>>2]|0;
        $39 = HEAP32[628296>>2]|0;
        HEAP32[$8>>2] = $39;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$8+0>>2]|0;
        invoke_vii(2591,($38|0),($$byval_copy18|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        $42 = (($i$01$i6) + 1)|0;
        $43 = HEAP32[$33>>2]|0;
        $44 = ($42>>>0)<($43>>>0);
        if ($44) {
         $i$01$i6 = $42;
        } else {
         break L14;
        }
       }
       $80 = ___cxa_find_matching_catch()|0;
       $81 = tempRet0;
       $lpad$phi$index = $80;$lpad$phi$index3 = $81;
       label = 28;
       break L7;
      }
     } while(0);
     $45 = (($this) + 60|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)>(-1);
     if ($47) {
      $48 = HEAP32[$32>>2]|0;
      $49 = (($this) + 52|0);
      $50 = HEAP32[$49>>2]|0;
      HEAP32[$7>>2] = $50;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$7+0>>2]|0;
      invoke_vii(2591,($48|0),($$byval_copy18|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      HEAP32[$32>>2] = 0;
     }
     HEAP32[$33>>2] = 0;
     HEAP32[$45>>2] = 0;
     $53 = HEAP32[$32>>2]|0;
     $54 = (($this) + 52|0);
     $55 = HEAP32[$54>>2]|0;
     HEAP32[$6>>2] = $55;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($53|0),($$byval_copy18|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      $95 = ___cxa_find_matching_catch()|0;
      $96 = tempRet0;
      $$0 = $96;$$01 = $95;
      label = 33;
      break L7;
     }
     HEAP32[$32>>2] = 0;
     $58 = HEAP32[$24>>2]|0;
     $59 = ($58|0)>(-1);
     do {
      if ($59) {
       $60 = HEAP32[$11>>2]|0;
       $61 = (($this) + 36|0);
       $62 = HEAP32[$61>>2]|0;
       HEAP32[$5>>2] = $62;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$5+0>>2]|0;
       invoke_vii(2591,($60|0),($$byval_copy18|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        $97 = ___cxa_find_matching_catch()|0;
        $98 = tempRet0;
        $$1 = $98;$$12 = $97;
        label = 37;
        break L7;
       } else {
        HEAP32[$11>>2] = 0;
        break;
       }
      }
     } while(0);
     $65 = (($this) + 28|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ($66|0)>(-1);
     do {
      if ($67) {
       $68 = (($this) + 16|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = (($this) + 20|0);
       $71 = HEAP32[$70>>2]|0;
       HEAP32[$4>>2] = $71;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$4+0>>2]|0;
       invoke_vii(2591,($69|0),($$byval_copy18|0));
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        $107 = ___cxa_find_matching_catch()|0;
        $108 = tempRet0;
        $$2 = $108;$$23 = $107;
        break L7;
       } else {
        HEAP32[$68>>2] = 0;
        break;
       }
      }
     } while(0);
     $74 = (($this) + 12|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = ($75|0)>(-1);
     if (!($76)) {
      STACKTOP = sp;return;
     }
     $77 = HEAP32[$this>>2]|0;
     $78 = (($this) + 4|0);
     $79 = HEAP32[$78>>2]|0;
     HEAP32[$0>>2] = $79;
     ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($77,$$byval_copy18);
     HEAP32[$this>>2] = 0;
     STACKTOP = sp;return;
    }
   } while(0);
   $84 = ___cxa_find_matching_catch()|0;
   $85 = tempRet0;
   $lpad$phi$index = $84;$lpad$phi$index3 = $85;
   label = 28;
  }
 } while(0);
 do {
  if ((label|0) == 28) {
   $86 = (($this) + 60|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)>(-1);
   if ($88) {
    $89 = (($this) + 48|0);
    $90 = HEAP32[$89>>2]|0;
    $91 = (($this) + 52|0);
    $92 = HEAP32[$91>>2]|0;
    HEAP32[$3>>2] = $92;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($90|0),($$byval_copy18|0));
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     $126 = ___cxa_find_matching_catch(0|0)|0;
     $127 = tempRet0;
     ___clang_call_terminate($126);
     // unreachable;
    } else {
     HEAP32[$89>>2] = 0;
     $$0 = $lpad$phi$index3;$$01 = $lpad$phi$index;
     label = 33;
     break;
    }
   } else {
    $$0 = $lpad$phi$index3;$$01 = $lpad$phi$index;
    label = 33;
   }
  }
 } while(0);
 do {
  if ((label|0) == 33) {
   $99 = (($this) + 44|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)>(-1);
   if ($101) {
    $102 = HEAP32[$11>>2]|0;
    $103 = (($this) + 36|0);
    $104 = HEAP32[$103>>2]|0;
    HEAP32[$2>>2] = $104;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($102|0),($$byval_copy18|0));
    $105 = __THREW__; __THREW__ = 0;
    $106 = $105&1;
    if ($106) {
     $126 = ___cxa_find_matching_catch(0|0)|0;
     $127 = tempRet0;
     ___clang_call_terminate($126);
     // unreachable;
    } else {
     HEAP32[$11>>2] = 0;
     $$1 = $$0;$$12 = $$01;
     label = 37;
     break;
    }
   } else {
    $$1 = $$0;$$12 = $$01;
    label = 37;
   }
  }
 } while(0);
 do {
  if ((label|0) == 37) {
   $109 = (($this) + 28|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ($110|0)>(-1);
   if ($111) {
    $112 = (($this) + 16|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = (($this) + 20|0);
    $115 = HEAP32[$114>>2]|0;
    HEAP32[$1>>2] = $115;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($113|0),($$byval_copy18|0));
    $116 = __THREW__; __THREW__ = 0;
    $117 = $116&1;
    if ($117) {
     $126 = ___cxa_find_matching_catch(0|0)|0;
     $127 = tempRet0;
     ___clang_call_terminate($126);
     // unreachable;
    } else {
     HEAP32[$112>>2] = 0;
     $$2 = $$1;$$23 = $$12;
     break;
    }
   } else {
    $$2 = $$1;$$23 = $$12;
   }
  }
 } while(0);
 $118 = (($this) + 12|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = ($119|0)>(-1);
 if (!($120)) {
  ___resumeException($$23|0);
  // unreachable;
 }
 $121 = HEAP32[$this>>2]|0;
 $122 = (($this) + 4|0);
 $123 = HEAP32[$122>>2]|0;
 HEAP32[$0>>2] = $123;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($121|0),($$byval_copy18|0));
 $124 = __THREW__; __THREW__ = 0;
 $125 = $124&1;
 if ($125) {
  $126 = ___cxa_find_matching_catch(0|0)|0;
  $127 = tempRet0;
  ___clang_call_terminate($126);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$23|0);
 // unreachable;
}
function __ZN11UnityEngine9Animation28GenericAnimationBindingCache10BindScriptERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound) {
 $this = $this|0;
 $inputBinding = $inputBinding|0;
 $transform = $transform|0;
 $bound = $bound|0;
 var $$$i$i$i = 0, $$0 = 0, $$0$i$i$i = 0, $$0$i36 = 0, $$0$ph$i$i$i$i$i$i = 0, $$byval_copy1 = 0, $$idx$i$i$i = 0, $$idx1 = 0, $$idx1$val = 0, $$idx2 = 0, $$idx2$val = 0, $$neg1$i$i$i$i$i$i = 0, $$pre$i$i = 0, $$pre$phiZ2D = 0, $$sum$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$i$i$i$i$i$i = 0, $__len$0$ph$i$i$i$i$i$i = 0, $i$014 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($inputBinding) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   label = 12;
  } else {
   HEAP32[$0>>2] = $3;
   $5 = HEAP32[560624>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    label = 10;
   } else {
    $7 = (($5) + 36|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($5) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    do {
     if ($11) {
      $12 = (($5) + 28|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($5) + 32|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($13) + ($15<<3)|0);
      $32 = $16;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$5,$0);
      $17 = HEAP32[$$byval_copy1>>2]|0;
      $18 = ($17|0)==(-1);
      $19 = (($5) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      if ($18) {
       $21 = (($5) + 32|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + ($22<<3)|0);
       $32 = $23;
       break;
      } else {
       $24 = (($20) + ($17<<3)|0);
       $32 = $24;
       break;
      }
     }
    } while(0);
    $25 = HEAP32[560624>>2]|0;
    $26 = (($25) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + ($29<<3)|0);
    $31 = ($32|0)==($30|0);
    if ($31) {
     label = 10;
    } else {
     $33 = (($32) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      label = 10;
     } else {
      $$0$i36 = $34;
     }
    }
   }
   if ((label|0) == 10) {
    $36 = (__Z31ReadObjectFromPersistentManageri($3)|0);
    $37 = ($36|0)==(0|0);
    if ($37) {
     label = 12;
     break;
    } else {
     $$0$i36 = $36;
    }
   }
   $38 = (($$0$i36) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = $39 >>> 21;
   $41 = HEAP32[560640>>2]|0;
   $42 = Math_imul($41, $40)|0;
   $43 = (($42) + 115)|0;
   $44 = $43 >> 5;
   $45 = $44 << 5;
   $46 = (($43) - ($45))|0;
   $47 = HEAP32[560632>>2]|0;
   $48 = (($47) + ($44<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = 1 << $46;
   $51 = $50 & $49;
   $52 = ($51|0)==(0);
   if ($52) {
    label = 12;
   } else {
    $$0$i$i$i = $$0$i36;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $$0$i$i$i = 0;
 }
 $53 = (($transform) + 24|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (__Z22GetComponentWithScriptRN5Unity10GameObjectEiP10MonoScript($54,114,$$0$i$i$i)|0);
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = (($55) + 20|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if (!($59)) {
   $61 = (__ZNK13MonoBehaviour8GetClassEv($55)|0);
   $62 = (($this) + 48|0);
   $63 = (($this) + 56|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ($64|0)==(0);
   L22: do {
    if ($65) {
     label = 22;
    } else {
     $66 = HEAP32[$62>>2]|0;
     $i$014 = 0;
     while(1) {
      $69 = (($66) + ($i$014<<2)|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = HEAP32[$70>>2]|0;
      $72 = ($71|0)==($61|0);
      $68 = (($i$014) + 1)|0;
      if ($72) {
       break;
      }
      $67 = ($68>>>0)<($64>>>0);
      if ($67) {
       $i$014 = $68;
      } else {
       label = 22;
       break L22;
      }
     }
     $73 = ($70|0)==(0|0);
     if ($73) {
      label = 22;
     } else {
      $$pre$phiZ2D = $55;$105 = $70;
     }
    }
   } while(0);
   if ((label|0) == 22) {
    $74 = (($inputBinding) + 12|0);
    $75 = HEAP16[$74>>1]|0;
    $76 = $75&65535;
    $77 = (__ZN11UnityEngine9AnimationL24GenerateComponentBindingEiP15ScriptingObjectP14ScriptingClassP6Object($76,$58,$61,$55)|0);
    $78 = HEAP32[$63>>2]|0;
    $79 = (($78) + 1)|0;
    HEAP32[$63>>2] = $79;
    $80 = (($this) + 60|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = $81 & 2147483647;
    $83 = ($79>>>0)>($82>>>0);
    if ($83) {
     $84 = $81 << 1;
     $85 = ($84|0)==(0);
     $86 = $85 ? 1 : $84;
     $87 = ($82>>>0)<($86>>>0);
     do {
      if ($87) {
       $88 = ($81|0)>(-1);
       if ($88) {
        HEAP32[$80>>2] = $86;
        $89 = HEAP32[$62>>2]|0;
        $90 = $86 << 2;
        $91 = (($this) + 52|0);
        $92 = HEAP32[$91>>2]|0;
        HEAP32[$1>>2] = $92;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
        $93 = (__Z16realloc_internalPvji10MemLabelIdiPKci($89,$90,4,$$byval_copy1,0,765752,370)|0);
        HEAP32[$62>>2] = $93;
        break;
       } else {
        $94 = $86 << 2;
        $95 = (($this) + 52|0);
        $96 = HEAP32[$95>>2]|0;
        HEAP32[$1>>2] = $96;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
        $97 = (__Z15malloc_internaljj10MemLabelIdiPKci($94,4,$$byval_copy1,0,765752,352)|0);
        $98 = HEAP32[$62>>2]|0;
        $99 = HEAP32[$63>>2]|0;
        $100 = $99 << 2;
        _memcpy(($97|0),($98|0),($100|0))|0;
        HEAP32[$80>>2] = $86;
        HEAP32[$62>>2] = $97;
        break;
       }
      }
     } while(0);
     $$pre$i$i = HEAP32[$63>>2]|0;
     $102 = $$pre$i$i;
    } else {
     $102 = $79;
    }
    $101 = (($102) + -1)|0;
    $103 = HEAP32[$62>>2]|0;
    $104 = (($103) + ($101<<2)|0);
    HEAP32[$104>>2] = $77;
    $$pre$phiZ2D = $55;$105 = $77;
   }
   $$idx1 = (($105) + 8|0);
   $$idx1$val = HEAP32[$$idx1>>2]|0;
   $$idx2 = (($105) + 12|0);
   $$idx2$val = HEAP32[$$idx2>>2]|0;
   $106 = (($inputBinding) + 4|0);
   $107 = HEAP32[$106>>2]|0;
   $$idx$i$i$i = $$idx1$val << 4;
   $108 = $$idx$i$i$i >> 4;
   $$0$ph$i$i$i$i$i$i = $$idx2$val;$__len$0$ph$i$i$i$i$i$i = $108;
   L41: while(1) {
    $__len$0$i$i$i$i$i$i = $__len$0$ph$i$i$i$i$i$i;
    while(1) {
     $109 = ($__len$0$i$i$i$i$i$i|0)==(0);
     if ($109) {
      break L41;
     }
     $110 = (($__len$0$i$i$i$i$i$i|0) / 2)&-1;
     $111 = (($$0$ph$i$i$i$i$i$i) + ($110<<4)|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ($112>>>0)<($107>>>0);
     if ($113) {
      break;
     } else {
      $__len$0$i$i$i$i$i$i = $110;
     }
    }
    $$sum$i$i$i$i$i$i = (($110) + 1)|0;
    $114 = (($$0$ph$i$i$i$i$i$i) + ($$sum$i$i$i$i$i$i<<4)|0);
    $$neg1$i$i$i$i$i$i = (($__len$0$i$i$i$i$i$i) + -1)|0;
    $115 = (($$neg1$i$i$i$i$i$i) - ($110))|0;
    $$0$ph$i$i$i$i$i$i = $114;$__len$0$ph$i$i$i$i$i$i = $115;
   }
   $116 = (($$idx2$val) + ($$idx1$val<<4)|0);
   $117 = ($$0$ph$i$i$i$i$i$i|0)==($116|0);
   if (!($117)) {
    $118 = HEAP32[$$0$ph$i$i$i$i$i$i>>2]|0;
    $119 = ($118>>>0)>($107>>>0);
    $$$i$i$i = $119 ? 0 : $$0$ph$i$i$i$i$i$i;
    $120 = ($$$i$i$i|0)==(0|0);
    if (!($120)) {
     $122 = (($bound) + 12|0);
     HEAP32[$122>>2] = $$pre$phiZ2D;
     $123 = (($$$i$i$i) + 4|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = (($58) + ($124)|0);
     HEAP32[$bound>>2] = $125;
     $126 = (($$$i$i$i) + 8|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = (($bound) + 4|0);
     HEAP32[$128>>2] = $127;
     $129 = (($inputBinding) + 15|0);
     $130 = HEAP8[$129>>0]|0;
     $131 = ($130<<24>>24)==(0);
     $132 = HEAP32[$126>>2]|0;
     do {
      if ($131) {
       if ((($132|0) == 6)) {
        $$0 = 100001;
        STACKTOP = sp;return ($$0|0);
       } else if (!((($132|0) == 5))) {
        break;
       }
       $$0 = 100002;
       STACKTOP = sp;return ($$0|0);
      } else {
       $133 = ($132|0)==(9);
       if ($133) {
        $134 = (($$$i$i$i) + 12|0);
        $135 = HEAP32[$134>>2]|0;
        $$0 = $135;
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     HEAP32[$122>>2] = 0;
     HEAP32[$bound>>2] = 0;
     HEAP32[$128>>2] = 0;
     $$0 = -1;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $121 = (($bound) + 4|0);
   HEAP32[$121>>2] = 0;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $60 = (($bound) + 4|0);
 HEAP32[$60>>2] = 0;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11UnityEngine9AnimationL24GenerateComponentBindingEiP15ScriptingObjectP14ScriptingClassP6Object($classID,$scriptingInstance,$scriptingClass,$targetObject) {
 $classID = $classID|0;
 $scriptingInstance = $scriptingInstance|0;
 $scriptingClass = $scriptingClass|0;
 $targetObject = $targetObject|0;
 var $$ = 0, $$0$i14 = 0, $$0$i19 = 0, $$01$i = 0, $$01$i13 = 0, $$02$i$i$i = 0, $$1 = 0, $$12 = 0, $$byval_copy22 = 0, $$pre = 0, $$pre26 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bindings = 0;
 var $eh$lpad$body$indexZ2D = 0, $exitcond$i$i$i = 0, $i = 0, $i$03$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $reflection$01$i$i$i = 0, $reflection$1$i$i$i = 0, $typeTree = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy22 = sp + 16|0;
 $0 = sp + 68|0;
 $1 = sp + 64|0;
 $2 = sp + 60|0;
 $3 = sp + 56|0;
 $4 = sp + 52|0;
 $typeTree = sp + 72|0;
 $bindings = sp + 24|0;
 $i = sp + 8|0;
 $5 = sp + 40|0;
 $6 = sp;
 $7 = sp + 48|0;
 __ZN8TypeTreeC2Ev($typeTree);
 __THREW__ = 0;
 invoke_viii(1996,($targetObject|0),($typeTree|0),0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if ($9) {
   label = 10;
  } else {
   $10 = HEAP32[628512>>2]|0;
   HEAP32[$bindings>>2] = 0;
   $11 = (($bindings) + 4|0);
   HEAP32[$11>>2] = $10;
   $12 = (($bindings) + 8|0);
   HEAP32[$12>>2] = 0;
   $13 = (($bindings) + 12|0);
   HEAP32[$13>>2] = 0;
   HEAP32[$5>>2] = $typeTree;
   $14 = (($5) + 4|0);
   HEAP32[$14>>2] = 0;
   __THREW__ = 0;
   invoke_vii(3363,($i|0),($5|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   L3: do {
    if ($16) {
     label = 12;
    } else {
     $17 = HEAP32[$i>>2]|0;
     $18 = ($17|0)==(0|0);
     do {
      if ($18) {
       $48 = 0;$49 = 0;
      } else {
       $$02$i$i$i = -1;$i$03$i$i$i = 0;$reflection$01$i$i$i = 0;
       while(1) {
        $19 = $$02$i$i$i & 1;
        $20 = ($19|0)==(0);
        if ($20) {
         $reflection$1$i$i$i = $reflection$01$i$i$i;
        } else {
         $21 = (31 - ($i$03$i$i$i))|0;
         $22 = 1 << $21;
         $23 = $22 | $reflection$01$i$i$i;
         $reflection$1$i$i$i = $23;
        }
        $24 = (($i$03$i$i$i) + 1)|0;
        $25 = $$02$i$i$i >>> 1;
        $exitcond$i$i$i = ($24|0)==(32);
        if (!($exitcond$i$i$i)) {
         $$02$i$i$i = $25;$i$03$i$i$i = $24;$reflection$01$i$i$i = $reflection$1$i$i$i;
         continue;
        }
        __THREW__ = 0;
        invoke_viiii(412,($i|0),($scriptingInstance|0),($reflection$1$i$i$i|0),($bindings|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         label = 11;
         break;
        }
        __THREW__ = 0;
        invoke_vii(3364,($6|0),($i|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         label = 11;
         break;
        }
        $30 = $6;
        $31 = $30;
        $32 = HEAP32[$31>>2]|0;
        $33 = (($30) + 4)|0;
        $34 = $33;
        $35 = HEAP32[$34>>2]|0;
        $36 = $i;
        $37 = $36;
        HEAP32[$37>>2] = $32;
        $38 = (($36) + 4)|0;
        $39 = $38;
        HEAP32[$39>>2] = $35;
        $40 = ($32|0)==(0);
        if ($40) {
         label = 13;
         break;
        } else {
         $$02$i$i$i = -1;$i$03$i$i$i = 0;$reflection$01$i$i$i = 0;
        }
       }
       if ((label|0) == 11) {
        $43 = ___cxa_find_matching_catch()|0;
        $44 = tempRet0;
        $lpad$phi$index = $43;$lpad$phi$index2 = $44;
        break L3;
       }
       else if ((label|0) == 13) {
        $$pre = HEAP32[$bindings>>2]|0;
        $$pre26 = HEAP32[$12>>2]|0;
        $48 = $$pre;$49 = $$pre26;
        break;
       }
      }
     } while(0);
     $47 = (($48) + ($49<<4)|0);
     __ZNSt3__16__sortIRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEvT0_S8_T_($48,$47,$$byval_copy22);
     $50 = $49 << 4;
     $51 = (($50) + 16)|0;
     $52 = HEAP32[628296>>2]|0;
     HEAP32[$7>>2] = $52;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$7+0>>2]|0;
     $53 = (invoke_iiiiiii(102,($51|0),16,($$byval_copy22|0),0,(765752|0),379)|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      label = 12;
     } else {
      $56 = $53;
      $57 = (0 - ($56))|0;
      $58 = $57 & 3;
      $59 = (($58) + ($56))|0;
      $60 = $59;
      $61 = (($60) + 16|0);
      $62 = (($53) + ($51)|0);
      $63 = ($61>>>0)>($62>>>0);
      if ($63) {
       $67 = 0;$71 = $53;
      } else {
       $64 = ($59|0)==(0);
       if ($64) {
        $67 = 0;$71 = $61;
       } else {
        $65 = $59;
        $67 = $65;$71 = $61;
       }
      }
      $66 = (($67) + 4|0);
      HEAP32[$66>>2] = $classID;
      HEAP32[$67>>2] = $scriptingClass;
      $68 = (($67) + 8|0);
      HEAP32[$68>>2] = $49;
      $69 = ($49|0)==(0);
      if ($69) {
       $$0$i19 = 0;
      } else {
       $70 = $71;
       $72 = (0 - ($70))|0;
       $73 = $72 & 3;
       $74 = (($73) + ($70))|0;
       $75 = $74;
       $76 = (($75) + ($50)|0);
       $77 = ($76>>>0)>($62>>>0);
       $$ = $77 ? 0 : $75;
       _memcpy(($$|0),($48|0),($50|0))|0;
       $$0$i19 = $$;
      }
      $78 = (($67) + 12|0);
      HEAP32[$78>>2] = $$0$i19;
      $79 = HEAP32[$13>>2]|0;
      $80 = ($79|0)>(-1);
      if ($80) {
       $81 = HEAP32[$11>>2]|0;
       HEAP32[$0>>2] = $81;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($48|0),($$byval_copy22|0));
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        label = 10;
        break L1;
       }
       HEAP32[$bindings>>2] = 0;
      }
      $84 = (($typeTree) + 44|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ($85|0)>(-1);
      do {
       if ($86) {
        $87 = (($typeTree) + 32|0);
        $88 = HEAP32[$87>>2]|0;
        $89 = (($typeTree) + 36|0);
        $90 = HEAP32[$89>>2]|0;
        HEAP32[$3>>2] = $90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($88|0),($$byval_copy22|0));
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if (!($92)) {
         HEAP32[$87>>2] = 0;
         label = 26;
         break;
        }
        $108 = ___cxa_find_matching_catch()|0;
        $109 = tempRet0;
        $110 = (($typeTree) + 28|0);
        $111 = HEAP32[$110>>2]|0;
        $112 = ($111|0)>(-1);
        if ($112) {
         $113 = (($typeTree) + 16|0);
         $114 = HEAP32[$113>>2]|0;
         $115 = (($typeTree) + 20|0);
         $116 = HEAP32[$115>>2]|0;
         HEAP32[$1>>2] = $116;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
         invoke_vii(2591,($114|0),($$byval_copy22|0));
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          $129 = ___cxa_find_matching_catch(0|0)|0;
          $130 = tempRet0;
          ___clang_call_terminate($129);
          // unreachable;
         } else {
          HEAP32[$113>>2] = 0;
          $$0$i14 = $109;$$01$i13 = $108;
          break;
         }
        } else {
         $$0$i14 = $109;$$01$i13 = $108;
        }
       } else {
        label = 26;
       }
      } while(0);
      L39: do {
       if ((label|0) == 26) {
        $93 = (($typeTree) + 28|0);
        $94 = HEAP32[$93>>2]|0;
        $95 = ($94|0)>(-1);
        do {
         if ($95) {
          $96 = (($typeTree) + 16|0);
          $97 = HEAP32[$96>>2]|0;
          $98 = (($typeTree) + 20|0);
          $99 = HEAP32[$98>>2]|0;
          HEAP32[$2>>2] = $99;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$2+0>>2]|0;
          invoke_vii(2591,($97|0),($$byval_copy22|0));
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           $119 = ___cxa_find_matching_catch()|0;
           $120 = tempRet0;
           $$0$i14 = $120;$$01$i13 = $119;
           break L39;
          } else {
           HEAP32[$96>>2] = 0;
           break;
          }
         }
        } while(0);
        $102 = (($typeTree) + 12|0);
        $103 = HEAP32[$102>>2]|0;
        $104 = ($103|0)>(-1);
        if (!($104)) {
         STACKTOP = sp;return ($67|0);
        }
        $105 = HEAP32[$typeTree>>2]|0;
        $106 = (($typeTree) + 4|0);
        $107 = HEAP32[$106>>2]|0;
        HEAP32[$0>>2] = $107;
        ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
        __Z19free_alloc_internalPv10MemLabelId($105,$$byval_copy22);
        HEAP32[$typeTree>>2] = 0;
        STACKTOP = sp;return ($67|0);
       }
      } while(0);
      $121 = (($typeTree) + 12|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = ($122|0)>(-1);
      if (!($123)) {
       ___resumeException($$01$i13|0);
       // unreachable;
      }
      $124 = HEAP32[$typeTree>>2]|0;
      $125 = (($typeTree) + 4|0);
      $126 = HEAP32[$125>>2]|0;
      HEAP32[$0>>2] = $126;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($124|0),($$byval_copy22|0));
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       $129 = ___cxa_find_matching_catch(0|0)|0;
       $130 = tempRet0;
       ___clang_call_terminate($129);
       // unreachable;
      }
      HEAP32[$typeTree>>2] = 0;
      ___resumeException($$01$i13|0);
      // unreachable;
     }
    }
   } while(0);
   if ((label|0) == 12) {
    $45 = ___cxa_find_matching_catch()|0;
    $46 = tempRet0;
    $lpad$phi$index = $45;$lpad$phi$index2 = $46;
   }
   $131 = HEAP32[$13>>2]|0;
   $132 = ($131|0)>(-1);
   if ($132) {
    $133 = HEAP32[$bindings>>2]|0;
    $134 = HEAP32[$11>>2]|0;
    HEAP32[$1>>2] = $134;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($133|0),($$byval_copy22|0));
    $135 = __THREW__; __THREW__ = 0;
    $136 = $135&1;
    if (!($136)) {
     HEAP32[$bindings>>2] = 0;
     $$1 = $lpad$phi$index;$$12 = $lpad$phi$index2;
     label = 44;
    }
   } else {
    $$1 = $lpad$phi$index;$$12 = $lpad$phi$index2;
    label = 44;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  $$1 = $41;$$12 = $42;
  label = 44;
 }
 L66: do {
  if ((label|0) == 44) {
   $137 = (($typeTree) + 44|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ($138|0)>(-1);
   do {
    if ($139) {
     $140 = (($typeTree) + 32|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = (($typeTree) + 36|0);
     $143 = HEAP32[$142>>2]|0;
     HEAP32[$4>>2] = $143;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($141|0),($$byval_copy22|0));
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if (!($145)) {
      HEAP32[$140>>2] = 0;
      label = 47;
      break;
     }
     $163 = ___cxa_find_matching_catch(0|0)|0;
     $164 = tempRet0;
     $165 = (($typeTree) + 28|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = ($166|0)>(-1);
     if ($167) {
      $168 = (($typeTree) + 16|0);
      $169 = HEAP32[$168>>2]|0;
      $170 = (($typeTree) + 20|0);
      $171 = HEAP32[$170>>2]|0;
      HEAP32[$2>>2] = $171;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($169|0),($$byval_copy22|0));
      $172 = __THREW__; __THREW__ = 0;
      $173 = $172&1;
      if ($173) {
       $184 = ___cxa_find_matching_catch(0|0)|0;
       $185 = tempRet0;
       ___clang_call_terminate($184);
       // unreachable;
      } else {
       HEAP32[$168>>2] = 0;
       $$01$i = $163;
       break;
      }
     } else {
      $$01$i = $163;
     }
    } else {
     label = 47;
    }
   } while(0);
   L77: do {
    if ((label|0) == 47) {
     $146 = (($typeTree) + 28|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = ($147|0)>(-1);
     do {
      if ($148) {
       $149 = (($typeTree) + 16|0);
       $150 = HEAP32[$149>>2]|0;
       $151 = (($typeTree) + 20|0);
       $152 = HEAP32[$151>>2]|0;
       HEAP32[$3>>2] = $152;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$3+0>>2]|0;
       invoke_vii(2591,($150|0),($$byval_copy22|0));
       $153 = __THREW__; __THREW__ = 0;
       $154 = $153&1;
       if ($154) {
        $174 = ___cxa_find_matching_catch(0|0)|0;
        $175 = tempRet0;
        $$01$i = $174;
        break L77;
       } else {
        HEAP32[$149>>2] = 0;
        break;
       }
      }
     } while(0);
     $155 = (($typeTree) + 12|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = ($156|0)>(-1);
     if (!($157)) {
      ___resumeException($$1|0);
      // unreachable;
     }
     $158 = HEAP32[$typeTree>>2]|0;
     $159 = (($typeTree) + 4|0);
     $160 = HEAP32[$159>>2]|0;
     HEAP32[$2>>2] = $160;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($158|0),($$byval_copy22|0));
     $161 = __THREW__; __THREW__ = 0;
     $162 = $161&1;
     if ($162) {
      break L66;
     }
     HEAP32[$typeTree>>2] = 0;
     ___resumeException($$1|0);
     // unreachable;
    }
   } while(0);
   $176 = (($typeTree) + 12|0);
   $177 = HEAP32[$176>>2]|0;
   $178 = ($177|0)>(-1);
   do {
    if ($178) {
     $179 = HEAP32[$typeTree>>2]|0;
     $180 = (($typeTree) + 4|0);
     $181 = HEAP32[$180>>2]|0;
     HEAP32[$1>>2] = $181;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($179|0),($$byval_copy22|0));
     $182 = __THREW__; __THREW__ = 0;
     $183 = $182&1;
     if ($183) {
      $184 = ___cxa_find_matching_catch(0|0)|0;
      $185 = tempRet0;
      ___clang_call_terminate($184);
      // unreachable;
     } else {
      HEAP32[$typeTree>>2] = 0;
      break;
     }
    }
   } while(0);
   $eh$lpad$body$indexZ2D = $$01$i;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 $186 = ___cxa_find_matching_catch(0|0)|0;
 $187 = tempRet0;
 $eh$lpad$body$indexZ2D = $186;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
 return 0|0;
}
function __ZN11UnityEngine9Animation28GenericAnimationBindingCache20BindGenericComponentERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound) {
 $this = $this|0;
 $inputBinding = $inputBinding|0;
 $transform = $transform|0;
 $bound = $bound|0;
 var $$$i$i$i = 0, $$0 = 0, $$0$ph$i$i$i$i$i$i = 0, $$idx = 0, $$idx$i$i$i = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$neg1$i$i$i$i$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre4 = 0, $$sum$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__len$0$i$i$i$i$i$i = 0, $__len$0$ph$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transform) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($inputBinding) + 12|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($1,$4)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP16[$2>>1]|0;
 $8 = $7&65535;
 $9 = (($this) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($8<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $14 = (__ZN11UnityEngine9AnimationL24GenerateComponentBindingEiP15ScriptingObjectP14ScriptingClassP6Object($8,0,0,$5)|0);
  $15 = HEAP16[$2>>1]|0;
  $16 = $15&65535;
  $17 = HEAP32[$9>>2]|0;
  $18 = (($17) + ($16<<2)|0);
  HEAP32[$18>>2] = $14;
  $$pre = HEAP32[$9>>2]|0;
  $$phi$trans$insert = (($$pre) + ($16<<2)|0);
  $$pre4 = HEAP32[$$phi$trans$insert>>2]|0;
  $19 = $$pre4;
 } else {
  $19 = $12;
 }
 $$idx = (($19) + 8|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $$idx1 = (($19) + 12|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $20 = (($inputBinding) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $$idx$i$i$i = $$idx$val << 4;
 $22 = $$idx$i$i$i >> 4;
 $$0$ph$i$i$i$i$i$i = $$idx1$val;$__len$0$ph$i$i$i$i$i$i = $22;
 L7: while(1) {
  $__len$0$i$i$i$i$i$i = $__len$0$ph$i$i$i$i$i$i;
  while(1) {
   $23 = ($__len$0$i$i$i$i$i$i|0)==(0);
   if ($23) {
    break L7;
   }
   $24 = (($__len$0$i$i$i$i$i$i|0) / 2)&-1;
   $25 = (($$0$ph$i$i$i$i$i$i) + ($24<<4)|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26>>>0)<($21>>>0);
   if ($27) {
    break;
   } else {
    $__len$0$i$i$i$i$i$i = $24;
   }
  }
  $$sum$i$i$i$i$i$i = (($24) + 1)|0;
  $28 = (($$0$ph$i$i$i$i$i$i) + ($$sum$i$i$i$i$i$i<<4)|0);
  $$neg1$i$i$i$i$i$i = (($__len$0$i$i$i$i$i$i) + -1)|0;
  $29 = (($$neg1$i$i$i$i$i$i) - ($24))|0;
  $$0$ph$i$i$i$i$i$i = $28;$__len$0$ph$i$i$i$i$i$i = $29;
 }
 $30 = (($$idx1$val) + ($$idx$val<<4)|0);
 $31 = ($$0$ph$i$i$i$i$i$i|0)==($30|0);
 if (!($31)) {
  $32 = HEAP32[$$0$ph$i$i$i$i$i$i>>2]|0;
  $33 = ($32>>>0)>($21>>>0);
  $$$i$i$i = $33 ? 0 : $$0$ph$i$i$i$i$i$i;
  $34 = ($$$i$i$i|0)==(0|0);
  if (!($34)) {
   $36 = (($bound) + 12|0);
   HEAP32[$36>>2] = $5;
   $37 = (($$$i$i$i) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = (($5) + ($38)|0);
   HEAP32[$bound>>2] = $39;
   $40 = (($$$i$i$i) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($bound) + 4|0);
   HEAP32[$42>>2] = $41;
   $43 = (($inputBinding) + 15|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($44<<24>>24)==(0);
   $46 = HEAP32[$40>>2]|0;
   do {
    if ($45) {
     if ((($46|0) == 6)) {
      $$0 = 100001;
      STACKTOP = sp;return ($$0|0);
     } else if (!((($46|0) == 5))) {
      break;
     }
     $$0 = 100002;
     STACKTOP = sp;return ($$0|0);
    } else {
     $47 = ($46|0)==(9);
     if ($47) {
      $48 = (($$$i$i$i) + 12|0);
      $49 = HEAP32[$48>>2]|0;
      $$0 = $49;
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   HEAP32[$36>>2] = 0;
   HEAP32[$bound>>2] = 0;
   HEAP32[$42>>2] = 0;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $35 = (($bound) + 4|0);
 HEAP32[$35>>2] = 0;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11UnityEngine9Animation28GenericAnimationBindingCache15BindPPtrGenericERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound) {
 $this = $this|0;
 $inputBinding = $inputBinding|0;
 $transform = $transform|0;
 $bound = $bound|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inputBinding) + 14|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (__ZNK11UnityEngine9Animation28GenericAnimationBindingCache10BindCustomERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($inputBinding) + 12|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = ($5<<16>>16)==(114);
 if (!($6)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__ZN11UnityEngine9Animation28GenericAnimationBindingCache10BindScriptERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound)|0);
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK11UnityEngine9Animation28GenericAnimationBindingCache10BindCustomERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound) {
 $this = $this|0;
 $inputBinding = $inputBinding|0;
 $transform = $transform|0;
 $bound = $bound|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $pos$i$i$i$i = 0, $target$0 = 0, $tempBound = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 24|0;
 $0 = sp;
 $tempBound = sp + 8|0;
 $1 = (($inputBinding) + 12|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(114);
 if ($3) {
  $4 = (($inputBinding) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0);
  do {
   if ($6) {
    label = 13;
   } else {
    HEAP32[$0>>2] = $5;
    $7 = HEAP32[560624>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     label = 11;
    } else {
     $9 = (($7) + 36|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = (($7) + 4|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($10|0)==($12|0);
     do {
      if ($13) {
       $14 = (($7) + 28|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($7) + 32|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = (($15) + ($17<<3)|0);
       $34 = $18;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$7,$0);
       $19 = HEAP32[$pos$i$i$i$i>>2]|0;
       $20 = ($19|0)==(-1);
       $21 = (($7) + 28|0);
       $22 = HEAP32[$21>>2]|0;
       if ($20) {
        $23 = (($7) + 32|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = (($22) + ($24<<3)|0);
        $34 = $25;
        break;
       } else {
        $26 = (($22) + ($19<<3)|0);
        $34 = $26;
        break;
       }
      }
     } while(0);
     $27 = HEAP32[560624>>2]|0;
     $28 = (($27) + 28|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + 32|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($29) + ($31<<3)|0);
     $33 = ($34|0)==($32|0);
     if ($33) {
      label = 11;
     } else {
      $35 = (($34) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = ($36|0)==(0|0);
      if ($37) {
       label = 11;
      } else {
       $$0$i3 = $36;
      }
     }
    }
    if ((label|0) == 11) {
     $38 = (__Z31ReadObjectFromPersistentManageri($5)|0);
     $39 = ($38|0)==(0|0);
     if ($39) {
      label = 13;
      break;
     } else {
      $$0$i3 = $38;
     }
    }
    $40 = (($$0$i3) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $41 >>> 21;
    $43 = HEAP32[560640>>2]|0;
    $44 = Math_imul($43, $42)|0;
    $45 = (($44) + 115)|0;
    $46 = $45 >> 5;
    $47 = $46 << 5;
    $48 = (($45) - ($47))|0;
    $49 = HEAP32[560632>>2]|0;
    $50 = (($49) + ($46<<2)|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = 1 << $48;
    $53 = $52 & $51;
    $54 = ($53|0)==(0);
    if ($54) {
     label = 13;
    } else {
     $$0$i$i$i = $$0$i3;
    }
   }
  } while(0);
  if ((label|0) == 13) {
   $$0$i$i$i = 0;
  }
  $55 = (($transform) + 24|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (__Z22GetComponentWithScriptRN5Unity10GameObjectEiP10MonoScript($56,114,$$0$i$i$i)|0);
  $target$0 = $57;
 } else {
  $58 = (($transform) + 24|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = $2&65535;
  $61 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($59,$60)|0);
  $target$0 = $61;
 }
 $62 = (($inputBinding) + 14|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = $63&255;
 $65 = (($this) + 16|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($64<<2)|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0|0);
 $70 = ($target$0|0)==(0|0);
 $or$cond = $69 | $70;
 if ($or$cond) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$tempBound+0>>2]=0|0;HEAP32[$tempBound+4>>2]=0|0;HEAP32[$tempBound+8>>2]=0|0;
 $71 = (($tempBound) + 4|0);
 HEAP32[$71>>2] = $64;
 $72 = (($tempBound) + 8|0);
 HEAP32[$72>>2] = $68;
 $73 = (($tempBound) + 12|0);
 HEAP32[$73>>2] = $target$0;
 $74 = HEAP32[$68>>2]|0;
 $75 = (($74) + 20|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (FUNCTION_TABLE_iiiii[$76 & 511]($68,$target$0,$inputBinding,$tempBound)|0);
 $78 = ($77|0)==(-1);
 if ($78) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$bound+0>>2]=HEAP32[$tempBound+0>>2]|0;HEAP32[$bound+4>>2]=HEAP32[$tempBound+4>>2]|0;HEAP32[$bound+8>>2]=HEAP32[$tempBound+8>>2]|0;HEAP32[$bound+12>>2]=HEAP32[$tempBound+12>>2]|0;
 $$0 = $77;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11UnityEngine9Animation28GenericAnimationBindingCache11BindGenericERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound) {
 $this = $this|0;
 $inputBinding = $inputBinding|0;
 $transform = $transform|0;
 $bound = $bound|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($inputBinding) + 14|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (__ZNK11UnityEngine9Animation28GenericAnimationBindingCache10BindCustomERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($inputBinding) + 12|0);
 $5 = HEAP16[$4>>1]|0;
 if ((($5<<16>>16) == 114)) {
  $17 = (__ZN11UnityEngine9Animation28GenericAnimationBindingCache10BindScriptERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound)|0);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 } else if ((($5<<16>>16) == 95)) {
  $$0 = 100002;
  STACKTOP = sp;return ($$0|0);
 } else if ((($5<<16>>16) == 1)) {
  $6 = (($inputBinding) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($this) + 64|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  if (!($10)) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $11 = HEAP32[$inputBinding>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$bound>>2] = 0;
  $13 = (($bound) + 4|0);
  HEAP32[$13>>2] = 7;
  $14 = (($transform) + 24|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($bound) + 12|0);
  HEAP32[$16>>2] = $15;
  $$0 = 100001;
  STACKTOP = sp;return ($$0|0);
 } else {
  $18 = (__ZN11UnityEngine9Animation28GenericAnimationBindingCache20BindGenericComponentERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE($this,$inputBinding,$transform,$bound)|0);
  $$0 = $18;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN11UnityEngine9Animation28GenericAnimationBindingCache25RegisterIAnimationBindingE11ClassIDTypeiP17IAnimationBinding($this,$classID,$customBindingType,$customBinding) {
 $this = $this|0;
 $classID = $classID|0;
 $customBindingType = $customBindingType|0;
 $customBinding = $customBinding|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = $5 << 1;
  $9 = ($8|0)==(0);
  $10 = $9 ? 1 : $8;
  $11 = ($6>>>0)<($10>>>0);
  do {
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = $10 << 3;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,765752,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = $10 << 3;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,765752,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = $23 << 3;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$1>>2]|0;
  $26 = $$pre$i$i;
 } else {
  $26 = $3;
 }
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + ($25<<3)|0);
 $29 = $28;
 $30 = $29;
 HEAP32[$30>>2] = $classID;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $customBindingType;
 $33 = (($this) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + ($customBindingType<<2)|0);
 HEAP32[$35>>2] = $customBinding;
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation21GetBoundCurveIntValueERKNS0_10BoundCurveE($bind) {
 $bind = $bind|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bind) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(9);
 if ($2) {
  $3 = HEAP32[$bind>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($4)|0);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 } else {
  $6 = (($bind) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (FUNCTION_TABLE_iii[$10 & 4095]($7,$bind)|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN11UnityEngine9Animation21SetBoundCurveIntValueERKNS0_10BoundCurveEi($bind,$value) {
 $bind = $bind|0;
 $value = $value|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($bind) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(9);
 if (!($3)) {
  $41 = (($bind) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  FUNCTION_TABLE_viii[$45 & 4095]($42,$bind,$value);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ($value|0)==(0);
 do {
  if ($4) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $value;
   $5 = HEAP32[560624>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = (($5) + 36|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($5) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    do {
     if ($11) {
      $12 = (($5) + 28|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($5) + 32|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($13) + ($15<<3)|0);
      $32 = $16;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$0);
      $17 = HEAP32[$pos$i$i$i$i>>2]|0;
      $18 = ($17|0)==(-1);
      $19 = (($5) + 28|0);
      $20 = HEAP32[$19>>2]|0;
      if ($18) {
       $21 = (($5) + 32|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + ($22<<3)|0);
       $32 = $23;
       break;
      } else {
       $24 = (($20) + ($17<<3)|0);
       $32 = $24;
       break;
      }
     }
    } while(0);
    $25 = HEAP32[560624>>2]|0;
    $26 = (($25) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + ($29<<3)|0);
    $31 = ($32|0)==($30|0);
    if (!($31)) {
     $33 = (($32) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if (!($35)) {
      $$0$i = $34;
      break;
     }
    }
   }
   $36 = (__Z31ReadObjectFromPersistentManageri($value)|0);
   $$0$i = $36;
  }
 } while(0);
 $37 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i)|0);
 $38 = HEAP32[$bind>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = ($37|0)==($39|0);
 HEAP32[$38>>2] = $37;
 $$0 = $40;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11UnityEngine9Animation23SetBoundCurveFloatValueERKNS0_10BoundCurveEf($bind,$value) {
 $bind = $bind|0;
 $value = Math_fround($value);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = Math_fround(0), $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bind) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 5)) {
  $2 = HEAP32[$bind>>2]|0;
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = $3 != $value;
  HEAPF32[$2>>2] = $value;
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 } else if ((($1|0) == 7)) {
  $14 = (($bind) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $value > Math_fround(0.00100000004749745130539);
  if ($16) {
   $18 = 1;
  } else {
   $17 = $value < Math_fround(-0.00100000004749745130539);
   $18 = $17;
  }
  __ZN5Unity10GameObject13SetSelfActiveEb($15,$18);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($1|0) == 6)) {
  $5 = HEAP32[$bind>>2]|0;
  $6 = $value > Math_fround(0.00100000004749745130539);
  if ($6) {
   $9 = 1;
  } else {
   $7 = $value < Math_fround(-0.00100000004749745130539);
   $9 = $7;
  }
  $8 = $9&1;
  $10 = HEAP8[$5>>0]|0;
  $11 = $10&255;
  $12 = $9&1;
  $13 = ($11|0)!=($12|0);
  HEAP8[$5>>0] = $8;
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 } else {
  $19 = (($bind) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  FUNCTION_TABLE_viif[$23 & 63]($20,$bind,$value);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN11UnityEngine9Animation23GetBoundCurveFloatValueERKNS0_10BoundCurveE($bind) {
 $bind = $bind|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bind) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 7)) {
  $8 = (($bind) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 46|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)!=(0);
  $13 = $12 ? Math_fround(1.0) : Math_fround(0.0);
  $$0 = $13;
 } else if ((($1|0) == 5)) {
  $2 = HEAP32[$bind>>2]|0;
  $3 = Math_fround(HEAPF32[$2>>2]);
  $$0 = $3;
 } else if ((($1|0) == 6)) {
  $4 = HEAP32[$bind>>2]|0;
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)!=(0);
  $7 = $6 ? Math_fround(1.0) : Math_fround(0.0);
  $$0 = $7;
 } else {
  $14 = (($bind) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$16>>2]|0;
  $18 = (Math_fround(FUNCTION_TABLE_fii[$17 & 63]($15,$bind)));
  $$0 = $18;
 }
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN11UnityEngine9Animation27BoundCurveValueAwakeGenericER6Object($targetObject) {
 $targetObject = $targetObject|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$targetObject>>2]|0;
 $1 = (($0) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($targetObject,16);
 STACKTOP = sp;return;
}
function __ZN7mecanim9reflectorILj8EE7reflectEh($x) {
 $x = $x|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $reflection$1$1 = 0, $reflection$1$2 = 0, $reflection$1$3 = 0, $reflection$1$4 = 0, $reflection$1$5 = 0;
 var $reflection$1$6 = 0, $reflection$1$7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($x << 7)&255;
 $1 = $x & 2;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $reflection$1$1 = $0;
 } else {
  $3 = $0&255;
  $4 = $3 | 64;
  $5 = $4&255;
  $reflection$1$1 = $5;
 }
 $6 = $x & 4;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $reflection$1$2 = $reflection$1$1;
 } else {
  $8 = $reflection$1$1&255;
  $9 = $8 | 32;
  $10 = $9&255;
  $reflection$1$2 = $10;
 }
 $11 = $x & 8;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $reflection$1$3 = $reflection$1$2;
 } else {
  $13 = $reflection$1$2&255;
  $14 = $13 | 16;
  $15 = $14&255;
  $reflection$1$3 = $15;
 }
 $16 = $x & 16;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $reflection$1$4 = $reflection$1$3;
 } else {
  $18 = $reflection$1$3&255;
  $19 = $18 | 8;
  $20 = $19&255;
  $reflection$1$4 = $20;
 }
 $21 = $x & 32;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $reflection$1$5 = $reflection$1$4;
 } else {
  $23 = $reflection$1$4&255;
  $24 = $23 | 4;
  $25 = $24&255;
  $reflection$1$5 = $25;
 }
 $26 = $x & 64;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $reflection$1$6 = $reflection$1$5;
 } else {
  $28 = $reflection$1$5&255;
  $29 = $28 | 2;
  $30 = $29&255;
  $reflection$1$6 = $30;
 }
 $31 = ($x<<24>>24)>(-1);
 if ($31) {
  $reflection$1$7 = $reflection$1$6;
  STACKTOP = sp;return ($reflection$1$7|0);
 }
 $32 = $reflection$1$6&255;
 $33 = $32 | 1;
 $34 = $33&255;
 $reflection$1$7 = $34;
 STACKTOP = sp;return ($reflection$1$7|0);
}
function __ZN11UnityEngine9AnimationL22GenerateBindingRecurseERK16TypeTreeIteratorP15ScriptingObjectN7mecanim5crc32ER13dynamic_arrayINS0_13CachedBindingELj4EE($type,$scriptingInstance,$attributeHash$0,$bindings) {
 $type = $type|0;
 $scriptingInstance = $scriptingInstance|0;
 $attributeHash$0 = $attributeHash$0|0;
 $bindings = $bindings|0;
 var $$$i = 0, $$1$i = 0, $$byval_copy1 = 0, $$lobit$i = 0, $$masked$i$i = 0, $$masked$i$i4 = 0, $$off$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $exitcond$i$i5 = 0, $i = 0, $p$01$i$i3 = 0, $switch$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $0 = sp + 24|0;
 $1 = sp + 16|0;
 $i = sp;
 $2 = sp + 8|0;
 $3 = ($attributeHash$0|0)==(-1);
 if ($3) {
  $98 = -1;
 } else {
  $4 = $attributeHash$0 >>> 8;
  $$masked$i$i = $attributeHash$0 & 255;
  $5 = $$masked$i$i ^ 46;
  $6 = (584048 + ($5<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 ^ $4;
  $98 = $8;
 }
 $9 = (__ZNK16TypeTreeIterator4NameEv($type)|0);
 $10 = (__ZNK16TypeTreeIterator4NameEv($type)|0);
 $11 = (_strlen(($10|0))|0);
 $12 = (($9) + ($11)|0);
 $13 = ($11|0)>(0);
 if ($13) {
  $17 = $98;$p$01$i$i3 = $9;
  while(1) {
   $14 = HEAP8[$p$01$i$i3>>0]|0;
   $15 = $14&255;
   $16 = $17 >>> 8;
   $$masked$i$i4 = $17 & 255;
   $18 = $15 ^ $$masked$i$i4;
   $19 = (584048 + ($18<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20 ^ $16;
   $22 = (($p$01$i$i3) + 1|0);
   $exitcond$i$i5 = ($22|0)==($12|0);
   if ($exitcond$i$i5) {
    $78 = $21;
    break;
   } else {
    $17 = $21;$p$01$i$i3 = $22;
   }
  }
 } else {
  $78 = $98;
 }
 $23 = (__ZNK16TypeTreeIterator10ByteOffsetEv($type)|0);
 $$lobit$i = $23 >>> 31;
 $24 = ($scriptingInstance|0)!=(0|0);
 $25 = $24&1;
 $26 = ($$lobit$i|0)==($25|0);
 L8: do {
  if ($26) {
   do {
    if ($24) {
     $27 = (__ZN11UnityEngine9AnimationL19GetTypeTreeBindTypeERK16TypeTreeIterator($type)|0);
     $$off$i = (($27) + -5)|0;
     $switch$i = ($$off$i>>>0)<(2);
     if ($switch$i) {
      $28 = ($23|0)==(-1);
      $29 = $23 & 2147483647;
      $$$i = $28 ? -1 : $29;
      $49 = $$$i;$82 = $27;$84 = -1;
      break;
     }
     __ZNK16TypeTreeIterator6FatherEv($$byval_copy1,$type);
     $30 = HEAP32[$$byval_copy1>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      break L8;
     }
     __ZNK16TypeTreeIterator6FatherEv($0,$type);
     __ZNK16TypeTreeIterator6FatherEv($1,$0);
     $32 = HEAP32[$1>>2]|0;
     $33 = ($32|0)==(0|0);
     if (!($33)) {
      break L8;
     }
     $34 = (__Z26scripting_object_get_classP15ScriptingObject($scriptingInstance)|0);
     $35 = (__ZNK16TypeTreeIterator4NameEv($type)|0);
     $36 = (__Z35scripting_class_get_field_from_nameP14ScriptingClassPKc($34,$35)|0);
     $37 = ($36|0)==(0|0);
     if ($37) {
      break L8;
     }
     $38 = (__Z24scripting_field_get_typeP14ScriptingField($36)|0);
     $39 = (__Z23scripting_type_get_typeP13ScriptingType($38)|0);
     $40 = ($39|0)==(18);
     if (!($40)) {
      break L8;
     }
     $41 = (__Z25scripting_class_from_typeP13ScriptingType($38)|0);
     $42 = (__ZN9Scripting28GetClassIDFromScriptingClassEP14ScriptingClass($41)|0);
     if ((($42|0) == 114) | (($42|0) == 0) | (($42|0) == -1)) {
      break L8;
     }
     $43 = (__Z26scripting_field_get_offsetP14ScriptingField($36)|0);
     $49 = $43;$82 = 9;$84 = $42;
    } else {
     $44 = ($23|0)==(-1);
     if ($44) {
      break L8;
     }
     $45 = (__ZN11UnityEngine9AnimationL19GetTypeTreeBindTypeERK16TypeTreeIterator($type)|0);
     $46 = ($45|0)==(0);
     $47 = $23 & 2147483647;
     $$1$i = $46 ? -1 : $47;
     $49 = $$1$i;$82 = $45;$84 = -1;
    }
   } while(0);
   $48 = ($49|0)==(-1);
   if (!($48)) {
    $50 = (($bindings) + 8|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) + 1)|0;
    HEAP32[$50>>2] = $52;
    $53 = (($bindings) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = $54 & 2147483647;
    $56 = ($52>>>0)>($55>>>0);
    if ($56) {
     $57 = $54 << 1;
     $58 = ($57|0)==(0);
     $59 = $58 ? 1 : $57;
     $60 = ($55>>>0)<($59>>>0);
     do {
      if ($60) {
       $61 = ($54|0)>(-1);
       if ($61) {
        HEAP32[$53>>2] = $59;
        $62 = HEAP32[$bindings>>2]|0;
        $63 = $59 << 4;
        $64 = (($bindings) + 4|0);
        $65 = HEAP32[$64>>2]|0;
        HEAP32[$0>>2] = $65;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
        $66 = (__Z16realloc_internalPvji10MemLabelIdiPKci($62,$63,4,$$byval_copy1,0,765752,370)|0);
        HEAP32[$bindings>>2] = $66;
        break;
       } else {
        $67 = $59 << 4;
        $68 = (($bindings) + 4|0);
        $69 = HEAP32[$68>>2]|0;
        HEAP32[$0>>2] = $69;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
        $70 = (__Z15malloc_internaljj10MemLabelIdiPKci($67,4,$$byval_copy1,0,765752,352)|0);
        $71 = HEAP32[$bindings>>2]|0;
        $72 = HEAP32[$50>>2]|0;
        $73 = $72 << 4;
        _memcpy(($70|0),($71|0),($73|0))|0;
        HEAP32[$53>>2] = $59;
        HEAP32[$bindings>>2] = $70;
        break;
       }
      }
     } while(0);
     $$pre$i = HEAP32[$50>>2]|0;
     $75 = $$pre$i;
    } else {
     $75 = $52;
    }
    $74 = (($75) + -1)|0;
    $76 = HEAP32[$bindings>>2]|0;
    $77 = $78 ^ -1;
    $79 = (($76) + ($74<<4)|0);
    HEAP32[$79>>2] = $77;
    $80 = ((($76) + ($74<<4)|0) + 4|0);
    HEAP32[$80>>2] = $49;
    $81 = ((($76) + ($74<<4)|0) + 8|0);
    HEAP32[$81>>2] = $82;
    $83 = ((($76) + ($74<<4)|0) + 12|0);
    HEAP32[$83>>2] = $84;
   }
  }
 } while(0);
 __ZNK16TypeTreeIterator8ChildrenEv($i,$type);
 $85 = HEAP32[$i>>2]|0;
 $86 = ($85|0)==(0|0);
 if ($86) {
  STACKTOP = sp;return;
 }
 while(1) {
  __ZN11UnityEngine9AnimationL22GenerateBindingRecurseERK16TypeTreeIteratorP15ScriptingObjectN7mecanim5crc32ER13dynamic_arrayINS0_13CachedBindingELj4EE($i,$scriptingInstance,$78,$bindings);
  __ZNK16TypeTreeIterator4NextEv($2,$i);
  $87 = $2;
  $88 = $87;
  $89 = HEAP32[$88>>2]|0;
  $90 = (($87) + 4)|0;
  $91 = $90;
  $92 = HEAP32[$91>>2]|0;
  $93 = $i;
  $94 = $93;
  HEAP32[$94>>2] = $89;
  $95 = (($93) + 4)|0;
  $96 = $95;
  HEAP32[$96>>2] = $92;
  $97 = ($89|0)==(0);
  if ($97) {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$027 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0;
 var $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i23 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -16|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 4;
   switch ($4|0) {
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 71;
    break L1;
    break;
   }
   default: {
   }
   }
   $37 = ($3|0)<(496);
   if ($37) {
    label = 21;
    break L1;
   }
   $38 = ($3|0)>(15984);
   $39 = (($4|0) / 2)&-1;
   $40 = (($$0) + ($39<<4)|0);
   do {
    if ($38) {
     $41 = (($4|0) / 4)&-1;
     $42 = (($$0) + ($41<<4)|0);
     $$sum = (($41) + ($39))|0;
     $43 = (($$0) + ($$sum<<4)|0);
     $44 = (__ZNSt3__17__sort4IRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEjT0_S8_S8_S8_T_($$0,$42,$40,$43,0)|0);
     $45 = HEAP32[$1>>2]|0;
     $46 = HEAP32[$43>>2]|0;
     $47 = ($45>>>0)<($46>>>0);
     if (!($47)) {
      $$pre$phiZ2D = $40;$__n_swaps$0 = $44;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$43+12>>2]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$1+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $48 = HEAP32[$43>>2]|0;
     $49 = HEAP32[$40>>2]|0;
     $50 = ($48>>>0)<($49>>>0);
     if (!($50)) {
      $51 = (($44) + 1)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $51;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$43+12>>2]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $52 = HEAP32[$40>>2]|0;
     $53 = HEAP32[$42>>2]|0;
     $54 = ($52>>>0)<($53>>>0);
     if (!($54)) {
      $55 = (($44) + 2)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $55;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$42+12>>2]|0;
     ;HEAP32[$42+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $56 = HEAP32[$42>>2]|0;
     $57 = HEAP32[$$0>>2]|0;
     $58 = ($56>>>0)<($57>>>0);
     if ($58) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$42+12>>2]|0;
      ;HEAP32[$42+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $60 = (($44) + 4)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $60;
      break;
     } else {
      $59 = (($44) + 3)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $59;
      break;
     }
    } else {
     $61 = HEAP32[$40>>2]|0;
     $62 = HEAP32[$$0>>2]|0;
     $63 = ($61>>>0)<($62>>>0);
     $64 = HEAP32[$1>>2]|0;
     $65 = ($64>>>0)<($61>>>0);
     if (!($63)) {
      if (!($65)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 0;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $66 = HEAP32[$40>>2]|0;
      $67 = HEAP32[$$0>>2]|0;
      $68 = ($66>>>0)<($67>>>0);
      if (!($68)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
      break;
     }
     if ($65) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
     ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $69 = HEAP32[$1>>2]|0;
     $70 = HEAP32[$40>>2]|0;
     $71 = ($69>>>0)<($70>>>0);
     if ($71) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $72 = HEAP32[$$0>>2]|0;
   $73 = HEAP32[$$pre$phiZ2D>>2]|0;
   $74 = ($72>>>0)<($73>>>0);
   do {
    if ($74) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $75 = (($__j$0) + -16|0);
      $76 = ($$0|0)==($75|0);
      if ($76) {
       break;
      }
      $94 = HEAP32[$75>>2]|0;
      $95 = ($94>>>0)<($73>>>0);
      if ($95) {
       label = 54;
       break;
      } else {
       $__j$0 = $75;
      }
     }
     if ((label|0) == 54) {
      label = 0;
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$75+12>>2]|0;
      ;HEAP32[$75+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $96 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $75;$__n_swaps$3 = $96;
      break;
     }
     $77 = (($$0) + 16|0);
     $78 = HEAP32[$1>>2]|0;
     $79 = ($72>>>0)<($78>>>0);
     if ($79) {
      $__i$1 = $77;
     } else {
      $80 = ($77|0)==($1|0);
      if ($80) {
       label = 71;
       break L1;
      } else {
       $__i$027 = $77;
      }
      while(1) {
       $83 = HEAP32[$__i$027>>2]|0;
       $84 = ($72>>>0)<($83>>>0);
       $82 = (($__i$027) + 16|0);
       if ($84) {
        break;
       }
       $81 = ($82|0)==($1|0);
       if ($81) {
        label = 71;
        break L1;
       } else {
        $__i$027 = $82;
       }
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$027+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$027+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$027+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$027+12>>2]|0;
      ;HEAP32[$__i$027+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$027+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$027+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$027+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $__i$1 = $82;
     }
     $85 = ($__i$1|0)==($1|0);
     if ($85) {
      label = 71;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $86 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $87 = HEAP32[$__i$2>>2]|0;
       $88 = ($86>>>0)<($87>>>0);
       $89 = (($__i$2) + 16|0);
       if ($88) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $89;
       }
      }
      while(1) {
       $90 = (($__j$2) + -16|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = ($86>>>0)<($91>>>0);
       if ($92) {
        $__j$2 = $90;
       } else {
        break;
       }
      }
      $93 = ($__i$2>>>0)<($90>>>0);
      if (!($93)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$2+12>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$90+12>>2]|0;
      ;HEAP32[$90+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $__i$2$ph = $89;$__j$1$ph = $90;
     }
    }
   } while(0);
   $97 = (($$0) + 16|0);
   $98 = ($97>>>0)<($__j$3>>>0);
   L55: do {
    if ($98) {
     $__i$3$ph = $97;$__j$4$ph = $__j$3;$__m$0$ph = $40;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $99 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $100 = HEAP32[$__i$3>>2]|0;
       $101 = ($100>>>0)<($99>>>0);
       $102 = (($__i$3) + 16|0);
       if ($101) {
        $__i$3 = $102;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $103 = (($__j$5) + -16|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = ($104>>>0)<($99>>>0);
       if ($105) {
        break;
       } else {
        $__j$5 = $103;
       }
      }
      $106 = ($__i$3>>>0)>($103>>>0);
      if ($106) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L55;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$3+12>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$103+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$103+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$103+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$103+12>>2]|0;
      ;HEAP32[$103+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $107 = (($__n_swaps$4$ph) + 1)|0;
      $108 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $108 ? $103 : $__m$0$ph;
      $__i$3$ph = $102;$__j$4$ph = $103;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $107;
     }
    } else {
     $__i$4 = $97;$__m$2 = $40;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $109 = ($__i$4|0)==($__m$2|0);
   if ($109) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $110 = HEAP32[$__m$2>>2]|0;
    $111 = HEAP32[$__i$4>>2]|0;
    $112 = ($110>>>0)<($111>>>0);
    if ($112) {
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$4+12>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $113 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $113;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $114 = ($__n_swaps$6|0)==(0);
   if ($114) {
    $115 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEbT0_S8_T_($$0,$__i$4,0)|0);
    $116 = (($__i$4) + 16|0);
    $117 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEbT0_S8_T_($116,$$01$ph,0)|0);
    if ($117) {
     label = 66;
     break;
    }
    if ($115) {
     $$0 = $116;
     continue;
    }
   }
   $118 = $__i$4;
   $119 = (($118) - ($2))|0;
   $120 = (($0) - ($118))|0;
   $121 = ($119|0)<($120|0);
   if (!($121)) {
    label = 70;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEvT0_S8_T_($$0,$__i$4,$__comp);
   $122 = (($__i$4) + 16|0);
   $$0 = $122;
  }
  if ((label|0) == 66) {
   label = 0;
   if ($115) {
    label = 71;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 70) {
   label = 0;
   $123 = (($__i$4) + 16|0);
   __ZNSt3__16__sortIRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEvT0_S8_T_($123,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = ($5>>>0)<($6>>>0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $8 = (($$0) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$$0>>2]|0;
  $11 = ($9>>>0)<($10>>>0);
  $12 = HEAP32[$1>>2]|0;
  $13 = ($12>>>0)<($9>>>0);
  if (!($11)) {
   if (!($13)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   $14 = HEAP32[$8>>2]|0;
   $15 = HEAP32[$$0>>2]|0;
   $16 = ($14>>>0)<($15>>>0);
   if (!($16)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   STACKTOP = sp;return;
  }
  if ($13) {
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $17 = HEAP32[$1>>2]|0;
  $18 = HEAP32[$8>>2]|0;
  $19 = ($17>>>0)<($18>>>0);
  if (!($19)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $20 = (($$0) + 16|0);
  $21 = (($$0) + 32|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEjT0_S8_S8_S8_T_($$0,$20,$21,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $22 = (($$0) + 16|0);
  $23 = (($$0) + 32|0);
  $24 = (($$0) + 48|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEjT0_S8_S8_S8_T_($$0,$22,$23,$24,0)|0);
  $25 = HEAP32[$1>>2]|0;
  $26 = HEAP32[$24>>2]|0;
  $27 = ($25>>>0)<($26>>>0);
  if (!($27)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $28 = HEAP32[$24>>2]|0;
  $29 = HEAP32[$23>>2]|0;
  $30 = ($28>>>0)<($29>>>0);
  if (!($30)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$23+12>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $31 = HEAP32[$23>>2]|0;
  $32 = HEAP32[$22>>2]|0;
  $33 = ($31>>>0)<($32>>>0);
  if (!($33)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $34 = HEAP32[$22>>2]|0;
  $35 = HEAP32[$$0>>2]|0;
  $36 = ($34>>>0)<($35>>>0);
  if (!($36)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEvT0_S8_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 71) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEjT0_S8_S8_S8_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i2 = sp;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = ($0>>>0)<($1>>>0);
 $3 = HEAP32[$__x3>>2]|0;
 $4 = ($3>>>0)<($0>>>0);
 do {
  if ($2) {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
    ;HEAP32[$__x1+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $$0$i = 1;
    break;
   }
   ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
   ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
   ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
   $8 = HEAP32[$__x3>>2]|0;
   $9 = HEAP32[$__x2>>2]|0;
   $10 = ($8>>>0)<($9>>>0);
   if ($10) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $5 = HEAP32[$__x2>>2]|0;
    $6 = HEAP32[$__x1>>2]|0;
    $7 = ($5>>>0)<($6>>>0);
    if ($7) {
     ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
     ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
     ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $11 = HEAP32[$__x4>>2]|0;
 $12 = HEAP32[$__x3>>2]|0;
 $13 = ($11>>>0)<($12>>>0);
 if (!($13)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x3+12>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $14 = (($$0$i) + 1)|0;
 $15 = HEAP32[$__x3>>2]|0;
 $16 = HEAP32[$__x2>>2]|0;
 $17 = ($15>>>0)<($16>>>0);
 if (!($17)) {
  $__r$0 = $14;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $18 = (($$0$i) + 2)|0;
 $19 = HEAP32[$__x2>>2]|0;
 $20 = HEAP32[$__x1>>2]|0;
 $21 = ($19>>>0)<($20>>>0);
 if (!($21)) {
  $__r$0 = $18;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $22 = (($$0$i) + 3)|0;
 $__r$0 = $22;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i = 0, $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4$i = sp + 16|0;
 $__t$sroa$1 = sp;
 $0 = (($__first) + 32|0);
 $1 = (($__first) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = ($2>>>0)<($3>>>0);
 $5 = HEAP32[$0>>2]|0;
 $6 = ($5>>>0)<($2>>>0);
 do {
  if ($4) {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    break;
   }
   ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
   $9 = HEAP32[$1>>2]|0;
   $10 = ($5>>>0)<($9>>>0);
   if ($10) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
   }
  } else {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    $7 = HEAP32[$1>>2]|0;
    $8 = ($7>>>0)<($3>>>0);
    if ($8) {
     ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    }
   }
  }
 } while(0);
 $11 = (($__first) + 48|0);
 $12 = ($11|0)==($__last|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $__i$02 = $11;$__j$01 = $0;
 while(1) {
  $13 = HEAP32[$__i$02>>2]|0;
  $14 = HEAP32[$__j$01>>2]|0;
  $15 = ($13>>>0)<($14>>>0);
  if ($15) {
   $16 = (($__i$02) + 4|0);
   ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$16+8>>2]|0;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;
    $17 = ($__k$0|0)==($__first|0);
    if ($17) {
     $__k$0$lcssa = $__first;
     break;
    }
    $18 = (($__k$0) + -16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($13>>>0)<($19>>>0);
    if ($20) {
     $__j$1$phi = $__k$0;$__k$0 = $18;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAP32[$__k$0$lcssa>>2] = $13;
   $21 = (($__k$0$lcssa) + 4|0);
   ;HEAP32[$21+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;
  }
  $22 = (($__i$02) + 16|0);
  $23 = ($22|0)==($__last|0);
  if ($23) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $22;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEbT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$014 = 0, $__count$1 = 0, $__i$015 = 0, $__j$013 = 0, $__j$013$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i5 = 0, $__t$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4$i5 = sp + 16|0;
 $__t$sroa$1 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 4;
 switch ($3|0) {
 case 3:  {
  $8 = (($__first) + 16|0);
  $9 = (($__last) + -16|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = HEAP32[$__first>>2]|0;
  $12 = ($10>>>0)<($11>>>0);
  $13 = HEAP32[$9>>2]|0;
  $14 = ($13>>>0)<($10>>>0);
  if (!($12)) {
   if (!($14)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $15 = HEAP32[$8>>2]|0;
   $16 = HEAP32[$__first>>2]|0;
   $17 = ($15>>>0)<($16>>>0);
   if (!($17)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($14) {
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$9+12>>2]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $18 = HEAP32[$9>>2]|0;
  $19 = HEAP32[$8>>2]|0;
  $20 = ($18>>>0)<($19>>>0);
  if (!($20)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
  ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $21 = (($__first) + 16|0);
  $22 = (($__first) + 32|0);
  $23 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEjT0_S8_S8_S8_T_($__first,$21,$22,$23,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5>>>0)<($6>>>0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $24 = (($__first) + 16|0);
  $25 = (($__first) + 32|0);
  $26 = (($__first) + 48|0);
  $27 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN11UnityEngine9Animation13CachedBindingES4_EEPS4_EEjT0_S8_S8_S8_T_($__first,$24,$25,$26,0)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$26>>2]|0;
  $30 = ($28>>>0)<($29>>>0);
  if (!($30)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$26+12>>2]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$27+12>>2]|0;
  ;HEAP32[$27+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $31 = HEAP32[$26>>2]|0;
  $32 = HEAP32[$25>>2]|0;
  $33 = ($31>>>0)<($32>>>0);
  if (!($33)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$25+12>>2]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $34 = HEAP32[$25>>2]|0;
  $35 = HEAP32[$24>>2]|0;
  $36 = ($34>>>0)<($35>>>0);
  if (!($36)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $37 = HEAP32[$24>>2]|0;
  $38 = HEAP32[$__first>>2]|0;
  $39 = ($37>>>0)<($38>>>0);
  if (!($39)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $40 = (($__first) + 32|0);
  $41 = (($__first) + 16|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = HEAP32[$__first>>2]|0;
  $44 = ($42>>>0)<($43>>>0);
  $45 = HEAP32[$40>>2]|0;
  $46 = ($45>>>0)<($42>>>0);
  do {
   if ($44) {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     break;
    }
    ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;
    ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
    $49 = HEAP32[$41>>2]|0;
    $50 = ($45>>>0)<($49>>>0);
    if ($50) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
    }
   } else {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     $47 = HEAP32[$41>>2]|0;
     $48 = ($47>>>0)<($43>>>0);
     if ($48) {
      ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
      ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;
      ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     }
    }
   }
  } while(0);
  $51 = (($__first) + 48|0);
  $52 = ($51|0)==($__last|0);
  if ($52) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$014 = 0;$__i$015 = $51;$__j$013 = $40;
  while(1) {
   $53 = HEAP32[$__i$015>>2]|0;
   $54 = HEAP32[$__j$013>>2]|0;
   $55 = ($53>>>0)<($54>>>0);
   if ($55) {
    $56 = (($__i$015) + 4|0);
    ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$56+8>>2]|0;
    $__j$1 = $__i$015;$__k$0 = $__j$013;
    while(1) {
     ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;
     $57 = ($__k$0|0)==($__first|0);
     if ($57) {
      $__k$0$lcssa = $__first;
      break;
     }
     $58 = (($__k$0) + -16|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($53>>>0)<($59>>>0);
     if ($60) {
      $__j$1$phi = $__k$0;$__k$0 = $58;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $53;
    $61 = (($__k$0$lcssa) + 4|0);
    ;HEAP32[$61+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;
    $62 = (($__count$014) + 1)|0;
    $63 = ($62|0)==(8);
    if ($63) {
     break;
    } else {
     $__count$1 = $62;
    }
   } else {
    $__count$1 = $__count$014;
   }
   $66 = (($__i$015) + 16|0);
   $67 = ($66|0)==($__last|0);
   if ($67) {
    $$0 = 1;
    label = 35;
    break;
   } else {
    $__j$013$phi = $__i$015;$__count$014 = $__count$1;$__i$015 = $66;$__j$013 = $__j$013$phi;
   }
  }
  if ((label|0) == 35) {
   STACKTOP = sp;return ($$0|0);
  }
  $64 = (($__i$015) + 16|0);
  $65 = ($64|0)==($__last|0);
  $$0 = $65;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN11UnityEngine9AnimationL19GetTypeTreeBindTypeERK16TypeTreeIterator($variable) {
 $variable = $variable|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond$i13 = 0, $or$cond$i4 = 0, $or$cond5$i = 0;
 var $or$cond5$i14 = 0, $or$cond5$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16TypeTreeIterator7GetNodeEv($variable)|0);
 $1 = (($0) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 8388608;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (__ZNK16TypeTreeIterator4TypeEv($variable)|0);
 $6 = HEAP32[580584>>2]|0;
 $7 = ($6|0)==(0|0);
 do {
  if ($7) {
   $10 = $5;
   label = 4;
  } else {
   $8 = ($5|0)==(0|0);
   if ($8) {
    $10 = 0;
    label = 4;
   } else {
    $11 = HEAP32[580528>>2]|0;
    $12 = ($11>>>0)<=($5>>>0);
    $13 = HEAP32[580536>>2]|0;
    $14 = ($13>>>0)>($5>>>0);
    $or$cond$i = $12 & $14;
    if ($or$cond$i) {
     $15 = ($11>>>0)<=($6>>>0);
     $16 = ($13>>>0)>($6>>>0);
     $or$cond5$i = $15 & $16;
     if ($or$cond5$i) {
      $17 = ($5|0)==($6|0);
      if ($17) {
       $$0 = 5;
      } else {
       break;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $18 = (_strcmp($6,$5)|0);
    $19 = ($18|0)==(0);
    if ($19) {
     $$0 = 5;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $9 = ($10|0)==($6|0);
  if ($9) {
   $$0 = 5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $20 = (__ZNK16TypeTreeIterator4TypeEv($variable)|0);
 $21 = HEAP32[580544>>2]|0;
 $22 = ($21|0)==(0|0);
 do {
  if ($22) {
   $25 = $20;
   label = 11;
  } else {
   $23 = ($20|0)==(0|0);
   if ($23) {
    $25 = 0;
    label = 11;
   } else {
    $26 = HEAP32[580528>>2]|0;
    $27 = ($26>>>0)<=($20>>>0);
    $28 = HEAP32[580536>>2]|0;
    $29 = ($28>>>0)>($20>>>0);
    $or$cond$i4 = $27 & $29;
    if ($or$cond$i4) {
     $30 = ($26>>>0)<=($21>>>0);
     $31 = ($28>>>0)>($21>>>0);
     $or$cond5$i5 = $30 & $31;
     if ($or$cond5$i5) {
      $32 = ($20|0)==($21|0);
      if ($32) {
       $$0 = 6;
      } else {
       break;
      }
      STACKTOP = sp;return ($$0|0);
     }
    }
    $33 = (_strcmp($21,$20)|0);
    $34 = ($33|0)==(0);
    if ($34) {
     $$0 = 6;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $24 = ($25|0)==($21|0);
  if ($24) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $35 = (__ZNK16TypeTreeIterator4TypeEv($variable)|0);
 $36 = HEAP32[580744>>2]|0;
 $37 = ($36|0)==(0|0);
 do {
  if ($37) {
   $40 = $35;
   label = 18;
  } else {
   $38 = ($35|0)==(0|0);
   if ($38) {
    $40 = 0;
    label = 18;
   } else {
    $41 = HEAP32[580528>>2]|0;
    $42 = ($41>>>0)<=($35>>>0);
    $43 = HEAP32[580536>>2]|0;
    $44 = ($43>>>0)>($35>>>0);
    $or$cond$i13 = $42 & $44;
    if ($or$cond$i13) {
     $45 = ($41>>>0)<=($36>>>0);
     $46 = ($43>>>0)>($36>>>0);
     $or$cond5$i14 = $45 & $46;
     if ($or$cond5$i14) {
      $47 = ($35|0)==($36|0);
      if ($47) {
       label = 23;
       break;
      } else {
       break;
      }
     }
    }
    $48 = (_strcmp($36,$35)|0);
    $49 = ($48|0)==(0);
    if ($49) {
     label = 23;
    }
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $39 = ($40|0)==($36|0);
  if ($39) {
   label = 23;
  }
 }
 if ((label|0) == 23) {
  $50 = (__ZNK16TypeTreeIterator7GetNodeEv($variable)|0);
  $51 = (($50) + 20|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = $52 & 256;
  $54 = ($53|0)==(0);
  if (!($54)) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN11UnityEngine9Animation26CreateAnimationSetBindingsEPKN7mecanim9animation18ControllerConstantERK13dynamic_arrayI4PPtrI13AnimationClipELj4EERNS1_6memory9AllocatorE($controller,$clips,$allocator) {
 $controller = $controller|0;
 $clips = $clips|0;
 $allocator = $allocator|0;
 var $$$i = 0, $$$i$i$i$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i$i$i$i30$i = 0, $$0$i$i$i$i34$i = 0, $$0$i12$i = 0, $$0$i17$i = 0, $$0$i39 = 0, $$0$i6$i = 0, $$0$i60 = 0, $$0$i62 = 0, $$0$i64 = 0, $$0$i67 = 0, $$0$i9$i = 0, $$0$i91 = 0, $$01 = 0;
 var $$01$i = 0, $$01$i$i$i$i$i = 0, $$01$i$i$i$i32$i = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$46 = 0, $$5 = 0, $$57 = 0, $$6 = 0, $$68 = 0, $$byval_copy60 = 0, $$in = 0, $$lcssa$i = 0, $$ph = 0;
 var $$ph130 = 0, $$ph131 = 0, $$pr$pre = 0, $$pre = 0, $$pre$i = 0, $$pre$i49 = 0, $$pre125$i = 0, $$pre127$i = 0, $$sroa$4$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0;
 var $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0;
 var $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0;
 var $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0;
 var $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0;
 var $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0;
 var $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0;
 var $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0;
 var $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0;
 var $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0;
 var $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0;
 var $720 = 0, $721 = Math_fround(0), $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0;
 var $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0;
 var $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0;
 var $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0;
 var $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0;
 var $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0;
 var $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0;
 var $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0;
 var $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0;
 var $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0;
 var $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0;
 var $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0;
 var $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0;
 var $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $97 = 0, $98 = 0, $99 = 0, $bindingMap$i = 0, $bindingsSorted$i = 0, $c$022$i$i = 0;
 var $c$067$i = 0, $clipIter$0134 = 0, $curveIndex$021$i$i = 0, $curveIndex$061$i = 0, $eh$lpad$body$index29Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i45 = 0, $exitcond15$i = 0, $exitcond16$i = 0, $found$i = 0, $genericBindings = 0, $genericCount$0$lcssa$i169 = 0, $genericCount$0$lcssa$i169172 = 0, $genericCount$093$i = 0, $genericCount$1$i = 0, $genericIter$01$i = 0, $genericPPtrBindings = 0;
 var $genericPPtrCount$0$lcssa$i170171 = 0, $genericPPtrCount$092$i = 0, $genericPPtrCount$1$i = 0, $i$011$i = 0, $i$020$i$i = 0, $i1$08$i = 0, $i10$062$i = 0, $i2$05$i = 0, $i2$091$i = 0, $i3$079$i = 0, $k$075$i = 0, $layerIter$097 = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index17 = 0, $lpad$phi120$i$index = 0, $lpad$phi120$i$index7 = 0, $lpad$phi133$index = 0, $lpad$phi133$index2 = 0, $m$065$i = 0, $maskIter$05$i = 0;
 var $maskValue$0$off0$i$ph = 0, $maskValue$0$off0$i92 = 0, $positionCount$0$lcssa$i166175 = 0, $positionCount$02$i = 0, $positionCount$096$i = 0, $positionCount$1$i = 0, $positionCount$1$i42 = 0, $rotationCount$0$lcssa$i167174 = 0, $rotationCount$03$i = 0, $rotationCount$095$i = 0, $rotationCount$1$i = 0, $rotationCount$1$i43 = 0, $scaleCount$0$lcssa$i168173 = 0, $scaleCount$04$i = 0, $scaleCount$094$i = 0, $scaleCount$1$i = 0, $scaleCount$1$i44 = 0, $skIter$04$i$be = 0, $skIter$04$i93 = 0, $valueIndex$0$lcssa$i = 0;
 var $valueIndex$1$lcssa$i = 0, $valueIndex$17$i = 0, $valueIndex$21$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy60 = sp + 296|0;
 $0 = sp + 292|0;
 $1 = sp + 288|0;
 $2 = sp + 284|0;
 $3 = sp + 280|0;
 $4 = sp + 276|0;
 $5 = sp + 272|0;
 $6 = sp + 268|0;
 $7 = sp + 264|0;
 $8 = sp + 260|0;
 $9 = sp + 256|0;
 $10 = sp + 248|0;
 $11 = sp + 48|0;
 $$sroa$4$i$i = sp + 232|0;
 $bindingMap$i = sp + 216|0;
 $bindingsSorted$i = sp + 200|0;
 $12 = sp;
 $13 = sp + 24|0;
 $found$i = sp + 120|0;
 $14 = sp + 96|0;
 $15 = sp + 100|0;
 $16 = sp + 116|0;
 $17 = sp + 104|0;
 $18 = sp + 108|0;
 $19 = sp + 112|0;
 $20 = sp + 124|0;
 $21 = sp + 128|0;
 $22 = sp + 132|0;
 $23 = sp + 136|0;
 $24 = sp + 140|0;
 $25 = sp + 144|0;
 $26 = sp + 148|0;
 $27 = sp + 152|0;
 $28 = sp + 156|0;
 $29 = sp + 160|0;
 $genericBindings = sp + 168|0;
 $genericPPtrBindings = sp + 184|0;
 $30 = ($controller|0)==(0|0);
 if ($30) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (($clips) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 << 2;
 $34 = (($33) + 15)|0;
 $35 = ($34>>>0)<(2000);
 $36 = ($32|0)!=(0);
 if ($35) {
  if ($36) {
   $51 = STACKTOP; STACKTOP = STACKTOP + ((((1*$34)|0)+15)&-16)|0;;
   $52 = $51;
   $53 = (($52) + 15)|0;
   $54 = $53 & -16;
   $55 = $54;
   $56 = STACKTOP; STACKTOP = STACKTOP + ((((1*$34)|0)+15)&-16)|0;;
   $57 = $56;
   $58 = (($57) + 15)|0;
   $59 = $58 & -16;
   $60 = $59;
   $134 = $55;$137 = $60;$888 = 0;$899 = 0;$909 = 0;
   label = 15;
  } else {
   $134 = 0;$137 = 0;$888 = 0;$899 = 0;$909 = 0;
   label = 15;
  }
 } else {
  if ($36) {
   $39 = HEAP32[628512>>2]|0;
   HEAP32[$27>>2] = $39;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$27+0>>2]|0;
   $40 = (invoke_iiiiiii(102,($34|0),16,($$byval_copy60|0),0,(765760|0),56)|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $925 = 0;
    label = 7;
   } else {
    $45 = HEAP32[628512>>2]|0;
    HEAP32[$28>>2] = $45;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$28+0>>2]|0;
    $46 = (invoke_iiiiiii(102,($34|0),16,($$byval_copy60|0),0,(765760|0),59)|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     $926 = $40;$927 = 0;
     label = 9;
    } else {
     $61 = $40;
     $62 = (($61) + 15)|0;
     $63 = $62 & -16;
     $64 = $63;
     $65 = $46;
     $66 = (($65) + 15)|0;
     $67 = $66 & -16;
     $68 = $67;
     $69 = HEAP32[628512>>2]|0;
     HEAP32[$29>>2] = $69;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$29+0>>2]|0;
     $70 = (invoke_iiiiiii(102,($34|0),16,($$byval_copy60|0),0,(765760|0),62)|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      $$ph = $46;$$ph130 = $40;$$ph131 = 0;
      label = 13;
     } else {
      $134 = $64;$137 = $68;$888 = $70;$899 = $46;$909 = $40;
      label = 15;
     }
    }
   }
  } else {
   $134 = 0;$137 = 0;$888 = 0;$899 = 0;$909 = 0;
   label = 15;
  }
 }
 L11: do {
  if ((label|0) == 15) {
   __THREW__ = 0;
   $77 = (invoke_iiii(1587,($controller|0),($32|0),($allocator|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    $$ph = $899;$$ph130 = $909;$$ph131 = $888;
    label = 13;
   } else {
    $80 = (($77) + 36|0);
    HEAP32[$80>>2] = 4;
    $81 = (($77) + 8|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ($82|0)==(0);
    L14: do {
     if (!($83)) {
      $84 = (($77) + 12|0);
      $clipIter$0134 = 0;
      L16: while(1) {
       $85 = HEAP32[$clips>>2]|0;
       $86 = (($85) + ($clipIter$0134<<2)|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($87|0)==(0);
       do {
        if ($88) {
         $$0$i91 = 0;$130 = 0;
        } else {
         HEAP32[$19>>2] = $87;
         $89 = HEAP32[560624>>2]|0;
         $90 = ($89|0)==(0|0);
         if ($90) {
          label = 28;
         } else {
          $91 = (($89) + 36|0);
          $92 = HEAP32[$91>>2]|0;
          $93 = (($89) + 4|0);
          $94 = HEAP32[$93>>2]|0;
          $95 = ($92|0)==($94|0);
          do {
           if ($95) {
            $96 = (($89) + 28|0);
            $97 = HEAP32[$96>>2]|0;
            $98 = (($89) + 32|0);
            $99 = HEAP32[$98>>2]|0;
            $100 = (($97) + ($99<<3)|0);
            $116 = $100;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy60,$89,$19);
            $101 = HEAP32[$$byval_copy60>>2]|0;
            $102 = ($101|0)==(-1);
            $103 = (($89) + 28|0);
            $104 = HEAP32[$103>>2]|0;
            if ($102) {
             $105 = (($89) + 32|0);
             $106 = HEAP32[$105>>2]|0;
             $107 = (($104) + ($106<<3)|0);
             $116 = $107;
             break;
            } else {
             $108 = (($104) + ($101<<3)|0);
             $116 = $108;
             break;
            }
           }
          } while(0);
          $109 = HEAP32[560624>>2]|0;
          $110 = (($109) + 28|0);
          $111 = HEAP32[$110>>2]|0;
          $112 = (($109) + 32|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = (($111) + ($113<<3)|0);
          $115 = ($116|0)==($114|0);
          if ($115) {
           label = 28;
          } else {
           $117 = (($116) + 4|0);
           $118 = HEAP32[$117>>2]|0;
           $119 = ($118|0)==(0|0);
           if ($119) {
            label = 28;
           } else {
            $$in = $118;
           }
          }
         }
         if ((label|0) == 28) {
          label = 0;
          $120 = HEAP32[$86>>2]|0;
          __THREW__ = 0;
          $121 = (invoke_ii(3215,($120|0))|0);
          $122 = __THREW__; __THREW__ = 0;
          $123 = $122&1;
          if ($123) {
           break L16;
          }
          $124 = ($121|0)==(0|0);
          if ($124) {
           $$0$i91 = 0;$130 = 0;
           break;
          } else {
           $$in = $121;
          }
         }
         __THREW__ = 0;
         $125 = (invoke_ii(3397,($$in|0))|0);
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if ($127) {
          break L16;
         } else {
          $$0$i91 = $$in;$130 = $125;
         }
        }
       } while(0);
       $128 = HEAP32[$84>>2]|0;
       $129 = (($128) + (($clipIter$0134*36)|0)|0);
       HEAP32[$129>>2] = $130;
       $131 = ((($128) + (($clipIter$0134*36)|0)|0) + 4|0);
       HEAP32[$131>>2] = $clipIter$0134;
       $132 = ($130|0)==(0|0);
       $133 = (($134) + ($clipIter$0134<<2)|0);
       if ($132) {
        HEAP32[$133>>2] = 0;
        $141 = (($137) + ($clipIter$0134<<2)|0);
        HEAP32[$141>>2] = 0;
        $142 = ((($128) + (($clipIter$0134*36)|0)|0) + 32|0);
        HEAP32[$142>>2] = 0;
       } else {
        HEAP32[$133>>2] = $129;
        $135 = (($$0$i91) + 176|0);
        $136 = (($137) + ($clipIter$0134<<2)|0);
        HEAP32[$136>>2] = $135;
        $138 = (($$0$i91) + 192|0);
        $139 = HEAP32[$138>>2]|0;
        $140 = ((($128) + (($clipIter$0134*36)|0)|0) + 32|0);
        HEAP32[$140>>2] = $139;
       }
       $143 = (($clipIter$0134) + 1)|0;
       $144 = HEAP32[$81>>2]|0;
       $145 = ($143>>>0)<($144>>>0);
       if ($145) {
        $clipIter$0134 = $143;
       } else {
        break L14;
       }
      }
      $73 = ___cxa_find_matching_catch()|0;
      $74 = tempRet0;
      $929 = $899;$930 = $909;$931 = $888;$lpad$phi133$index = $73;$lpad$phi133$index2 = $74;
      label = 14;
      break L11;
     }
    } while(0);
    $146 = HEAP32[628512>>2]|0;
    HEAP32[$genericBindings>>2] = 0;
    $147 = (($genericBindings) + 4|0);
    HEAP32[$147>>2] = $146;
    $148 = (($genericBindings) + 8|0);
    HEAP32[$148>>2] = 0;
    $149 = (($genericBindings) + 12|0);
    HEAP32[$149>>2] = 0;
    HEAP32[$genericPPtrBindings>>2] = 0;
    $150 = (($genericPPtrBindings) + 4|0);
    HEAP32[$150>>2] = $146;
    $151 = (($genericPPtrBindings) + 8|0);
    HEAP32[$151>>2] = 0;
    $152 = (($genericPPtrBindings) + 12|0);
    HEAP32[$152>>2] = 0;
    $153 = (($bindingMap$i) + 4|0);
    HEAP32[$153>>2] = 0;
    $154 = (($bindingMap$i) + 8|0);
    HEAP32[$154>>2] = 0;
    $155 = (($bindingMap$i) + 4|0);
    HEAP32[$bindingMap$i>>2] = $155;
    $156 = ($32|0)==(0);
    do {
     if ($156) {
      $238 = 0;
      label = 54;
     } else {
      $157 = (($11) + 8|0);
      $158 = (($11) + 12|0);
      $159 = (($11) + 16|0);
      $160 = (($11) + 20|0);
      $161 = (($11) + 24|0);
      $162 = (($11) + 28|0);
      $163 = (($11) + 32|0);
      $c$022$i$i = 0;
      L44: while(1) {
       $164 = (($137) + ($c$022$i$i<<2)|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ($165|0)==(0|0);
       if (!($166)) {
        $167 = (($134) + ($c$022$i$i<<2)|0);
        $168 = HEAP32[$167>>2]|0;
        $169 = HEAP32[$168>>2]|0;
        $170 = (($169) + 1040|0);
        $171 = $170;
        $172 = HEAP32[$170>>2]|0;
        $173 = (($171) + ($172))|0;
        $174 = $173;
        $175 = (($169) + 1044|0);
        HEAP32[$175>>2] = $174;
        $176 = (($174) + 12|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = (($174) + 20|0);
        $179 = HEAP32[$178>>2]|0;
        $180 = (($179) + ($177))|0;
        $181 = (($165) + 8|0);
        $182 = HEAP32[$181>>2]|0;
        $183 = ($182|0)==(0);
        if (!($183)) {
         $184 = (($174) + 48|0);
         $185 = $184;
         $curveIndex$021$i$i = 0;$i$020$i$i = 0;
         while(1) {
          $186 = HEAP32[$165>>2]|0;
          $187 = (($186) + ($i$020$i$i<<4)|0);
          $188 = ((($186) + ($i$020$i$i<<4)|0) + 12|0);
          $189 = HEAP16[$188>>1]|0;
          $190 = ($189<<16>>16)==(4);
          if ($190) {
           $191 = ((($186) + ($i$020$i$i<<4)|0) + 4|0);
           $192 = HEAP32[$191>>2]|0;
           $193 = ($192|0)==(2);
           if ($193) {
            $$0$i$i$i = 4;
           } else {
            $194 = $192 & -3;
            $195 = ($194|0)==(1);
            $$$i$i$i$i = $195 ? 3 : 1;
            $$0$i$i$i = $$$i$i$i$i;
           }
          } else {
           $$0$i$i$i = 1;
          }
          $196 = $187;
          $197 = $196;
          $198 = HEAP32[$197>>2]|0;
          $199 = (($196) + 4)|0;
          $200 = $199;
          $201 = HEAP32[$200>>2]|0;
          $202 = ((($186) + ($i$020$i$i<<4)|0) + 8|0);
          $203 = HEAP32[$202>>2]|0;
          $204 = HEAPU16[$188>>1]|(HEAPU16[$188+2>>1]<<16);
          $205 = $11;
          $206 = $205;
          HEAP32[$206>>2] = $198;
          $207 = (($205) + 4)|0;
          $208 = $207;
          HEAP32[$208>>2] = $201;
          HEAP32[$157>>2] = $203;
          HEAP32[$158>>2] = $204;
          HEAP32[$159>>2] = 10;
          HEAP32[$160>>2] = -1;
          HEAP32[$161>>2] = -1;
          HEAP32[$162>>2] = 0;
          ;HEAP32[$163+0>>2]=HEAP32[$$sroa$4$i$i+0>>2]|0;HEAP32[$163+4>>2]=HEAP32[$$sroa$4$i$i+4>>2]|0;HEAP32[$163+8>>2]=HEAP32[$$sroa$4$i$i+8>>2]|0;HEAP32[$163+12>>2]=HEAP32[$$sroa$4$i$i+12>>2]|0;
          __THREW__ = 0;
          invoke_viii(1997,($10|0),($bindingMap$i|0),($11|0));
          $209 = __THREW__; __THREW__ = 0;
          $210 = $209&1;
          if ($210) {
           label = 61;
           break L44;
          }
          $211 = HEAP32[$10>>2]|0;
          $212 = ($curveIndex$021$i$i>>>0)<($180>>>0);
          do {
           if ($212) {
            label = 50;
           } else {
            $213 = HEAP16[$188>>1]|0;
            $214 = ($213<<16>>16)==(4);
            if ($214) {
             $215 = (($curveIndex$021$i$i) - ($180))|0;
             $216 = HEAP32[$184>>2]|0;
             $217 = (($216) + ($185))|0;
             $218 = $217;
             $219 = (($218) + ($215<<2)|0);
             $220 = (($211) + 44|0);
             $221 = HEAP32[$220>>2]|0;
             if ((($221|0) == 0)) {
              HEAP32[$220>>2] = 2;
              $222 = (($211) + 48|0);
              $223 = $$0$i$i$i << 2;
              _memcpy(($222|0),($219|0),($223|0))|0;
              break;
             } else if (!((($221|0) == 2))) {
              break;
             }
             $224 = (($211) + 48|0);
             $225 = $$0$i$i$i << 2;
             $226 = (_memcmp($224,$219,$225)|0);
             $227 = ($226|0)==(0);
             if (!($227)) {
              HEAP32[$220>>2] = 3;
             }
            } else {
             label = 50;
            }
           }
          } while(0);
          if ((label|0) == 50) {
           label = 0;
           $228 = (($211) + 44|0);
           HEAP32[$228>>2] = 3;
          }
          $229 = (($$0$i$i$i) + ($curveIndex$021$i$i))|0;
          $230 = (($i$020$i$i) + 1)|0;
          $231 = HEAP32[$181>>2]|0;
          $232 = ($230>>>0)<($231>>>0);
          if ($232) {
           $curveIndex$021$i$i = $229;$i$020$i$i = $230;
          } else {
           break;
          }
         }
        }
       }
       $233 = (($c$022$i$i) + 1)|0;
       $exitcond$i$i = ($233|0)==($32|0);
       if ($exitcond$i$i) {
        label = 53;
        break;
       } else {
        $c$022$i$i = $233;
       }
      }
      if ((label|0) == 53) {
       $$pre$i = HEAP32[$154>>2]|0;
       $238 = $$pre$i;
       label = 54;
       break;
      }
      else if ((label|0) == 61) {
       $270 = ___cxa_find_matching_catch()|0;
       $271 = tempRet0;
       $935 = 0;$936 = 0;$937 = 0;$938 = 0;$lpad$phi120$i$index = $270;$lpad$phi120$i$index7 = $271;
       label = 63;
       break;
      }
     }
    } while(0);
    L70: do {
     if ((label|0) == 54) {
      HEAP32[$bindingsSorted$i>>2] = 0;
      $234 = (($bindingsSorted$i) + 8|0);
      HEAP32[$234>>2] = 0;
      $235 = (($bindingsSorted$i) + 12|0);
      HEAP32[$235>>2] = 0;
      $236 = (($bindingsSorted$i) + 4|0);
      HEAP32[$236>>2] = 61;
      $237 = ($238|0)==(0);
      if ($237) {
       label = 57;
      } else {
       HEAP32[$235>>2] = $238;
       $239 = ($238*20)|0;
       HEAP32[$9>>2] = 61;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$9+0>>2]|0;
       $240 = (invoke_iiiiiiii(108,(0|0),($239|0),4,($$byval_copy60|0),0,(765760|0),370)|0);
       $241 = __THREW__; __THREW__ = 0;
       $242 = $241&1;
       if ($242) {
        $934 = 0;
        label = 70;
       } else {
        HEAP32[$bindingsSorted$i>>2] = $240;
        label = 57;
       }
      }
      L75: do {
       if ((label|0) == 57) {
        $243 = HEAP32[$bindingMap$i>>2]|0;
        $244 = ($243|0)==($155|0);
        L77: do {
         if (!($244)) {
          $245 = (($12) + 8|0);
          $246 = (($12) + 12|0);
          $247 = (($12) + 16|0);
          $249 = $243;
          while(1) {
           $248 = (($249) + 44|0);
           $250 = HEAP32[$248>>2]|0;
           $251 = ($250|0)==(3);
           if ($251) {
            $252 = (($249) + 16|0);
            $253 = $252;
            $254 = $253;
            $255 = HEAP32[$254>>2]|0;
            $256 = (($253) + 4)|0;
            $257 = $256;
            $258 = HEAP32[$257>>2]|0;
            $259 = (($249) + 24|0);
            $260 = HEAP32[$259>>2]|0;
            $261 = (($249) + 28|0);
            $262 = HEAPU16[$261>>1]|(HEAPU16[$261+2>>1]<<16);
            $263 = (($249) + 32|0);
            $264 = $12;
            $265 = $264;
            HEAP32[$265>>2] = $255;
            $266 = (($264) + 4)|0;
            $267 = $266;
            HEAP32[$267>>2] = $258;
            HEAP32[$245>>2] = $260;
            HEAP32[$246>>2] = $262;
            HEAP32[$247>>2] = $263;
            __THREW__ = 0;
            invoke_vii(3365,($bindingsSorted$i|0),($12|0));
            $268 = __THREW__; __THREW__ = 0;
            $269 = $268&1;
            if ($269) {
             label = 69;
             break;
            }
           }
           $294 = (($249) + 4|0);
           $295 = HEAP32[$294>>2]|0;
           $296 = ($295|0)==(0|0);
           if ($296) {
            $$01$i$i$i$i$i = $249;
            while(1) {
             $299 = (($$01$i$i$i$i$i) + 8|0);
             $300 = HEAP32[$299>>2]|0;
             $301 = HEAP32[$300>>2]|0;
             $302 = ($301|0)==($$01$i$i$i$i$i|0);
             if ($302) {
              $$0$i$i$i$i$i = $300;
              break;
             } else {
              $$01$i$i$i$i$i = $300;
             }
            }
           } else {
            $$0$i$i$i$i$i$i = $295;
            while(1) {
             $297 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
             $298 = ($297|0)==(0|0);
             if ($298) {
              $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
              break;
             } else {
              $$0$i$i$i$i$i$i = $297;
             }
            }
           }
           $303 = ($$0$i$i$i$i$i|0)==($155|0);
           if ($303) {
            break;
           } else {
            $249 = $$0$i$i$i$i$i;
           }
          }
          if ((label|0) == 69) {
           $284 = ___cxa_find_matching_catch()|0;
           $285 = tempRet0;
           $943 = 0;$944 = 0;$945 = 0;$946 = 0;$lpad$phi$i$index = $284;$lpad$phi$i$index17 = $285;
           break L75;
          }
          $$pre125$i = HEAP32[$bindingMap$i>>2]|0;
          $304 = ($$pre125$i|0)==($155|0);
          if (!($304)) {
           $305 = (($13) + 8|0);
           $306 = (($13) + 12|0);
           $307 = (($13) + 16|0);
           $312 = $$pre125$i;
           while(1) {
            $311 = (($312) + 44|0);
            $313 = HEAP32[$311>>2]|0;
            $314 = ($313|0)==(2);
            if ($314) {
             $315 = (($312) + 16|0);
             $316 = $315;
             $317 = $316;
             $318 = HEAP32[$317>>2]|0;
             $319 = (($316) + 4)|0;
             $320 = $319;
             $321 = HEAP32[$320>>2]|0;
             $322 = (($312) + 24|0);
             $323 = HEAP32[$322>>2]|0;
             $324 = (($312) + 28|0);
             $325 = HEAPU16[$324>>1]|(HEAPU16[$324+2>>1]<<16);
             $326 = (($312) + 32|0);
             $327 = $13;
             $328 = $327;
             HEAP32[$328>>2] = $318;
             $329 = (($327) + 4)|0;
             $330 = $329;
             HEAP32[$330>>2] = $321;
             HEAP32[$305>>2] = $323;
             HEAP32[$306>>2] = $325;
             HEAP32[$307>>2] = $326;
             __THREW__ = 0;
             invoke_vii(3365,($bindingsSorted$i|0),($13|0));
             $331 = __THREW__; __THREW__ = 0;
             $332 = $331&1;
             if ($332) {
              break;
             }
            }
            $333 = (($312) + 4|0);
            $334 = HEAP32[$333>>2]|0;
            $335 = ($334|0)==(0|0);
            if ($335) {
             $$01$i$i$i$i32$i = $312;
             while(1) {
              $338 = (($$01$i$i$i$i32$i) + 8|0);
              $339 = HEAP32[$338>>2]|0;
              $340 = HEAP32[$339>>2]|0;
              $341 = ($340|0)==($$01$i$i$i$i32$i|0);
              if ($341) {
               $$0$i$i$i$i34$i = $339;
               break;
              } else {
               $$01$i$i$i$i32$i = $339;
              }
             }
            } else {
             $$0$i$i$i$i$i30$i = $334;
             while(1) {
              $336 = HEAP32[$$0$i$i$i$i$i30$i>>2]|0;
              $337 = ($336|0)==(0|0);
              if ($337) {
               $$0$i$i$i$i34$i = $$0$i$i$i$i$i30$i;
               break;
              } else {
               $$0$i$i$i$i$i30$i = $336;
              }
             }
            }
            $342 = ($$0$i$i$i$i34$i|0)==($155|0);
            if ($342) {
             break L77;
            } else {
             $312 = $$0$i$i$i$i34$i;
            }
           }
           $282 = ___cxa_find_matching_catch()|0;
           $283 = tempRet0;
           $943 = 0;$944 = 0;$945 = 0;$946 = 0;$lpad$phi$i$index = $282;$lpad$phi$i$index17 = $283;
           break L75;
          }
         }
        } while(0);
        $308 = HEAP32[$234>>2]|0;
        $309 = ($308|0)==(0);
        if ($309) {
         $406 = 0;$genericCount$0$lcssa$i169172 = 0;$genericPPtrCount$0$lcssa$i170171 = 0;$positionCount$0$lcssa$i166175 = 0;$rotationCount$0$lcssa$i167174 = 0;$scaleCount$0$lcssa$i168173 = 0;
        } else {
         $310 = HEAP32[$bindingsSorted$i>>2]|0;
         $genericCount$093$i = 0;$genericPPtrCount$092$i = 0;$i2$091$i = 0;$positionCount$096$i = 0;$rotationCount$095$i = 0;$scaleCount$094$i = 0;
         L111: while(1) {
          $343 = (($310) + (($i2$091$i*20)|0)|0);
          $344 = ((($310) + (($i2$091$i*20)|0)|0) + 12|0);
          $345 = HEAP16[$344>>1]|0;
          $346 = ($345<<16>>16)==(4);
          do {
           if ($346) {
            $347 = ((($310) + (($i2$091$i*20)|0)|0) + 4|0);
            $348 = HEAP32[$347>>2]|0;
            if ((($348|0) == 2)) {
             $354 = ((($310) + (($i2$091$i*20)|0)|0) + 16|0);
             $355 = HEAP32[$354>>2]|0;
             HEAP32[$355>>2] = 7;
             $356 = (($rotationCount$095$i) + 1)|0;
             $357 = (($355) + 4|0);
             HEAP32[$357>>2] = $rotationCount$095$i;
             $358 = (($355) + 8|0);
             HEAP32[$358>>2] = 4;
             $genericCount$1$i = $genericCount$093$i;$genericPPtrCount$1$i = $genericPPtrCount$092$i;$positionCount$1$i = $positionCount$096$i;$rotationCount$1$i = $356;$scaleCount$1$i = $scaleCount$094$i;
             break;
            } else if ((($348|0) == 3)) {
             $359 = ((($310) + (($i2$091$i*20)|0)|0) + 16|0);
             $360 = HEAP32[$359>>2]|0;
             HEAP32[$360>>2] = 8;
             $361 = (($scaleCount$094$i) + 1)|0;
             $362 = (($360) + 4|0);
             HEAP32[$362>>2] = $scaleCount$094$i;
             $363 = (($360) + 8|0);
             HEAP32[$363>>2] = 3;
             $genericCount$1$i = $genericCount$093$i;$genericPPtrCount$1$i = $genericPPtrCount$092$i;$positionCount$1$i = $positionCount$096$i;$rotationCount$1$i = $rotationCount$095$i;$scaleCount$1$i = $361;
             break;
            } else if ((($348|0) == 1)) {
             $349 = ((($310) + (($i2$091$i*20)|0)|0) + 16|0);
             $350 = HEAP32[$349>>2]|0;
             HEAP32[$350>>2] = 6;
             $351 = (($positionCount$096$i) + 1)|0;
             $352 = (($350) + 4|0);
             HEAP32[$352>>2] = $positionCount$096$i;
             $353 = (($350) + 8|0);
             HEAP32[$353>>2] = 3;
             $genericCount$1$i = $genericCount$093$i;$genericPPtrCount$1$i = $genericPPtrCount$092$i;$positionCount$1$i = $351;$rotationCount$1$i = $rotationCount$095$i;$scaleCount$1$i = $scaleCount$094$i;
             break;
            } else {
             $364 = ((($310) + (($i2$091$i*20)|0)|0) + 16|0);
             $365 = HEAP32[$364>>2]|0;
             HEAP32[$365>>2] = 10;
             $366 = (($365) + 4|0);
             HEAP32[$366>>2] = -1;
             $367 = (($365) + 8|0);
             HEAP32[$367>>2] = 1;
             $genericCount$1$i = $genericCount$093$i;$genericPPtrCount$1$i = $genericPPtrCount$092$i;$positionCount$1$i = $positionCount$096$i;$rotationCount$1$i = $rotationCount$095$i;$scaleCount$1$i = $scaleCount$094$i;
             break;
            }
           } else {
            $368 = ((($310) + (($i2$091$i*20)|0)|0) + 15|0);
            $369 = HEAP8[$368>>0]|0;
            $370 = ($369<<24>>24)==(0);
            if (!($370)) {
             $371 = ((($310) + (($i2$091$i*20)|0)|0) + 16|0);
             $372 = HEAP32[$371>>2]|0;
             HEAP32[$372>>2] = 3;
             $373 = (($genericPPtrCount$092$i) + 1)|0;
             $374 = (($372) + 4|0);
             HEAP32[$374>>2] = $genericPPtrCount$092$i;
             $375 = (($372) + 8|0);
             HEAP32[$375>>2] = 1;
             $genericCount$1$i = $genericCount$093$i;$genericPPtrCount$1$i = $373;$positionCount$1$i = $positionCount$096$i;$rotationCount$1$i = $rotationCount$095$i;$scaleCount$1$i = $scaleCount$094$i;
             break;
            }
            __THREW__ = 0;
            $376 = (invoke_ii(3398,($343|0))|0);
            $377 = __THREW__; __THREW__ = 0;
            $378 = $377&1;
            if ($378) {
             label = 67;
             break L111;
            }
            $379 = ((($310) + (($i2$091$i*20)|0)|0) + 16|0);
            $380 = HEAP32[$379>>2]|0;
            if ($376) {
             HEAP32[$380>>2] = 10;
             $384 = (($380) + 4|0);
             HEAP32[$384>>2] = -1;
             $385 = (($380) + 8|0);
             HEAP32[$385>>2] = 1;
             $genericCount$1$i = $genericCount$093$i;$genericPPtrCount$1$i = $genericPPtrCount$092$i;$positionCount$1$i = $positionCount$096$i;$rotationCount$1$i = $rotationCount$095$i;$scaleCount$1$i = $scaleCount$094$i;
             break;
            } else {
             HEAP32[$380>>2] = 1;
             $381 = (($genericCount$093$i) + 1)|0;
             $382 = (($380) + 4|0);
             HEAP32[$382>>2] = $genericCount$093$i;
             $383 = (($380) + 8|0);
             HEAP32[$383>>2] = 1;
             $genericCount$1$i = $381;$genericPPtrCount$1$i = $genericPPtrCount$092$i;$positionCount$1$i = $positionCount$096$i;$rotationCount$1$i = $rotationCount$095$i;$scaleCount$1$i = $scaleCount$094$i;
             break;
            }
           }
          } while(0);
          $386 = (($i2$091$i) + 1)|0;
          $387 = ($386>>>0)<($308>>>0);
          if ($387) {
           $genericCount$093$i = $genericCount$1$i;$genericPPtrCount$092$i = $genericPPtrCount$1$i;$i2$091$i = $386;$positionCount$096$i = $positionCount$1$i;$rotationCount$095$i = $rotationCount$1$i;$scaleCount$094$i = $scaleCount$1$i;
          } else {
           break;
          }
         }
         if ((label|0) == 67) {
          $280 = ___cxa_find_matching_catch()|0;
          $281 = tempRet0;
          $943 = 0;$944 = 0;$945 = 0;$946 = 0;$lpad$phi$i$index = $280;$lpad$phi$i$index17 = $281;
          break;
         }
         $388 = ($genericCount$1$i|0)==(0);
         if ($388) {
          $genericCount$0$lcssa$i169 = 0;
         } else {
          HEAP32[$149>>2] = $genericCount$1$i;
          $389 = $genericCount$1$i << 4;
          HEAP32[$1>>2] = $146;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$1+0>>2]|0;
          $390 = (invoke_iiiiiiii(108,(0|0),($389|0),4,($$byval_copy60|0),0,(765760|0),370)|0);
          $391 = __THREW__; __THREW__ = 0;
          $392 = $391&1;
          if ($392) {
           $934 = 0;
           label = 70;
           break;
          }
          HEAP32[$genericBindings>>2] = $390;
          $genericCount$0$lcssa$i169 = $genericCount$1$i;
         }
         $393 = ($genericPPtrCount$1$i|0)==(0);
         if ($393) {
          $406 = $308;$genericCount$0$lcssa$i169172 = $genericCount$0$lcssa$i169;$genericPPtrCount$0$lcssa$i170171 = 0;$positionCount$0$lcssa$i166175 = $positionCount$1$i;$rotationCount$0$lcssa$i167174 = $rotationCount$1$i;$scaleCount$0$lcssa$i168173 = $scaleCount$1$i;
         } else {
          HEAP32[$152>>2] = $genericPPtrCount$1$i;
          $394 = $genericPPtrCount$1$i << 4;
          HEAP32[$2>>2] = $146;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$2+0>>2]|0;
          $395 = (invoke_iiiiiiii(108,(0|0),($394|0),4,($$byval_copy60|0),0,(765760|0),370)|0);
          $396 = __THREW__; __THREW__ = 0;
          $397 = $396&1;
          if ($397) {
           $934 = 0;
           label = 70;
           break;
          }
          HEAP32[$genericPPtrBindings>>2] = $395;
          $406 = $308;$genericCount$0$lcssa$i169172 = $genericCount$0$lcssa$i169;$genericPPtrCount$0$lcssa$i170171 = $genericPPtrCount$1$i;$positionCount$0$lcssa$i166175 = $positionCount$1$i;$rotationCount$0$lcssa$i167174 = $rotationCount$1$i;$scaleCount$0$lcssa$i168173 = $scaleCount$1$i;
         }
        }
        $398 = (($rotationCount$0$lcssa$i167174) + ($positionCount$0$lcssa$i166175))|0;
        $399 = (($398) + ($scaleCount$0$lcssa$i168173))|0;
        $400 = ($399|0)==(0);
        if ($400) {
         $952 = 0;$953 = 0;
        } else {
         $401 = $399 << 3;
         HEAP32[$3>>2] = $146;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$3+0>>2]|0;
         $402 = (invoke_iiiiiiii(108,(0|0),($401|0),4,($$byval_copy60|0),0,(765760|0),370)|0);
         $403 = __THREW__; __THREW__ = 0;
         $404 = $403&1;
         if ($404) {
          $934 = $399;
          label = 70;
          break;
         }
         $952 = $399;$953 = $402;
        }
        $405 = ($406|0)==(0);
        L143: do {
         if ($405) {
          $612 = 0;$641 = $953;$819 = 0;$848 = 0;$856 = 0;$859 = 0;$863 = $952;
         } else {
          $407 = HEAP32[$bindingsSorted$i>>2]|0;
          $428 = 0;$430 = $952;$438 = $953;$950 = 0;$951 = 0;$954 = 0;$955 = 0;$i3$079$i = 0;
          L145: while(1) {
           $423 = (($407) + (($i3$079$i*20)|0)|0);
           $424 = ((($407) + (($i3$079$i*20)|0)|0) + 12|0);
           $425 = HEAP16[$424>>1]|0;
           $426 = ($425<<16>>16)==(4);
           do {
            if ($426) {
             $427 = (($428) + 1)|0;
             $429 = $430 & 2147483647;
             $431 = ($427>>>0)>($429>>>0);
             do {
              if ($431) {
               $432 = $430 << 1;
               $433 = ($432|0)==(0);
               $434 = $433 ? 1 : $432;
               $435 = ($429>>>0)<($434>>>0);
               if ($435) {
                $436 = ($430|0)>(-1);
                if ($436) {
                 $437 = $434 << 3;
                 HEAP32[$4>>2] = $146;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$4+0>>2]|0;
                 $439 = (invoke_iiiiiiii(108,($438|0),($437|0),4,($$byval_copy60|0),0,(765760|0),370)|0);
                 $440 = __THREW__; __THREW__ = 0;
                 $441 = $440&1;
                 if ($441) {
                  $949 = $434;
                  label = 66;
                  break L145;
                 }
                 $449 = $439;$947 = $434;
                 break;
                } else {
                 $442 = $434 << 3;
                 HEAP32[$5>>2] = $146;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$5+0>>2]|0;
                 $443 = (invoke_iiiiiii(102,($442|0),4,($$byval_copy60|0),0,(765760|0),352)|0);
                 $444 = __THREW__; __THREW__ = 0;
                 $445 = $444&1;
                 if ($445) {
                  $949 = $430;
                  label = 66;
                  break L145;
                 }
                 $446 = $427 << 3;
                 _memcpy(($443|0),($438|0),($446|0))|0;
                 $449 = $443;$947 = $434;
                 break;
                }
               } else {
                $449 = $438;$947 = $430;
               }
              } else {
               $449 = $438;$947 = $430;
              }
             } while(0);
             $447 = HEAP32[$423>>2]|0;
             $448 = (($449) + ($428<<3)|0);
             HEAP32[$448>>2] = $447;
             $450 = ((($407) + (($i3$079$i*20)|0)|0) + 4|0);
             $451 = HEAP32[$450>>2]|0;
             $452 = ((($449) + ($428<<3)|0) + 4|0);
             HEAP32[$452>>2] = $451;
             $453 = ((($407) + (($i3$079$i*20)|0)|0) + 16|0);
             $454 = HEAP32[$453>>2]|0;
             $455 = (($454) + 12|0);
             $456 = HEAP32[$455>>2]|0;
             $457 = ($456|0)==(3);
             if ($457) {
              $956 = $947;$957 = $427;$958 = $449;$959 = $950;$960 = $954;$961 = $951;$962 = $427;
             } else {
              $458 = (($454) + 8|0);
              $459 = HEAP32[$458>>2]|0;
              $460 = ($459|0)>(0);
              if ($460) {
               $462 = $454;$465 = $954;$467 = $950;$475 = $951;$k$075$i = 0;
               while(1) {
                $461 = ((($462) + ($k$075$i<<2)|0) + 16|0);
                $463 = Math_fround(HEAPF32[$461>>2]);
                $464 = (($465) + 1)|0;
                $466 = $467 & 2147483647;
                $468 = ($464>>>0)>($466>>>0);
                if ($468) {
                 $469 = $467 << 1;
                 $470 = ($469|0)==(0);
                 $471 = $470 ? 1 : $469;
                 $472 = ($466>>>0)<($471>>>0);
                 do {
                  if ($472) {
                   $473 = ($467|0)>(-1);
                   if ($473) {
                    $474 = $471 << 2;
                    HEAP32[$6>>2] = $146;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$6+0>>2]|0;
                    $476 = (invoke_iiiiiiii(108,($475|0),($474|0),4,($$byval_copy60|0),0,(765760|0),370)|0);
                    $477 = __THREW__; __THREW__ = 0;
                    $478 = $477&1;
                    if ($478) {
                     $948 = $471;
                     label = 65;
                     break L145;
                    }
                    $964 = $471;$965 = $476;
                    break;
                   } else {
                    $479 = $471 << 2;
                    HEAP32[$7>>2] = $146;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$7+0>>2]|0;
                    $480 = (invoke_iiiiiii(102,($479|0),4,($$byval_copy60|0),0,(765760|0),352)|0);
                    $481 = __THREW__; __THREW__ = 0;
                    $482 = $481&1;
                    if ($482) {
                     $948 = $467;
                     label = 65;
                     break L145;
                    }
                    $483 = $464 << 2;
                    _memcpy(($480|0),($475|0),($483|0))|0;
                    $964 = $471;$965 = $480;
                    break;
                   }
                  } else {
                   $964 = $467;$965 = $475;
                  }
                 } while(0);
                 $$pre127$i = HEAP32[$453>>2]|0;
                 $485 = $965;$488 = $$pre127$i;$963 = $964;
                } else {
                 $485 = $475;$488 = $462;$963 = $467;
                }
                $484 = (($485) + ($465<<2)|0);
                HEAPF32[$484>>2] = $463;
                $486 = (($k$075$i) + 1)|0;
                $487 = (($488) + 8|0);
                $489 = HEAP32[$487>>2]|0;
                $490 = ($486|0)<($489|0);
                if ($490) {
                 $462 = $488;$465 = $464;$467 = $963;$475 = $485;$k$075$i = $486;
                } else {
                 $956 = $947;$957 = $427;$958 = $449;$959 = $963;$960 = $464;$961 = $485;$962 = $955;
                 break;
                }
               }
              } else {
               $956 = $947;$957 = $427;$958 = $449;$959 = $950;$960 = $954;$961 = $951;$962 = $955;
              }
             }
            } else {
             $491 = ((($407) + (($i3$079$i*20)|0)|0) + 15|0);
             $492 = HEAP8[$491>>0]|0;
             $493 = ($492<<24>>24)==(0);
             if (!($493)) {
              __THREW__ = 0;
              invoke_vii(3366,($genericPPtrBindings|0),($423|0));
              $494 = __THREW__; __THREW__ = 0;
              $495 = $494&1;
              if ($495) {
               $949 = $430;
               label = 66;
               break L145;
              } else {
               $956 = $430;$957 = $428;$958 = $438;$959 = $950;$960 = $954;$961 = $951;$962 = $955;
               break;
              }
             }
             __THREW__ = 0;
             $496 = (invoke_ii(3398,($423|0))|0);
             $497 = __THREW__; __THREW__ = 0;
             $498 = $497&1;
             if ($498) {
              $949 = $430;
              label = 66;
              break L145;
             }
             if ($496) {
              $956 = $430;$957 = $428;$958 = $438;$959 = $950;$960 = $954;$961 = $951;$962 = $955;
             } else {
              __THREW__ = 0;
              invoke_vii(3366,($genericBindings|0),($423|0));
              $499 = __THREW__; __THREW__ = 0;
              $500 = $499&1;
              if ($500) {
               $949 = $430;
               label = 66;
               break L145;
              } else {
               $956 = $430;$957 = $428;$958 = $438;$959 = $950;$960 = $954;$961 = $951;$962 = $955;
              }
             }
            }
           } while(0);
           $501 = (($i3$079$i) + 1)|0;
           $502 = ($501>>>0)<($406>>>0);
           if ($502) {
            $428 = $957;$430 = $956;$438 = $958;$950 = $959;$951 = $961;$954 = $960;$955 = $962;$i3$079$i = $501;
           } else {
            $612 = $957;$641 = $958;$819 = $962;$848 = $960;$856 = $961;$859 = $959;$863 = $956;
            break L143;
           }
          }
          if ((label|0) == 65) {
           $276 = ___cxa_find_matching_catch()|0;
           $277 = tempRet0;
           $943 = $947;$944 = $449;$945 = $948;$946 = $475;$lpad$phi$i$index = $276;$lpad$phi$i$index17 = $277;
           break L75;
          }
          else if ((label|0) == 66) {
           $278 = ___cxa_find_matching_catch()|0;
           $279 = tempRet0;
           $943 = $949;$944 = $438;$945 = $950;$946 = $951;$lpad$phi$i$index = $278;$lpad$phi$i$index17 = $279;
           break L75;
          }
         }
        } while(0);
        L183: do {
         if (!($156)) {
          $408 = ($positionCount$0$lcssa$i166175|0)==(0);
          $409 = ($rotationCount$0$lcssa$i167174|0)==(0);
          $410 = ($scaleCount$0$lcssa$i168173|0)==(0);
          $411 = ($genericCount$0$lcssa$i169172|0)==(0);
          $412 = ($genericPPtrCount$0$lcssa$i170171|0)==(0);
          $413 = ($positionCount$0$lcssa$i166175|0)>(0);
          $414 = ($rotationCount$0$lcssa$i167174|0)>(0);
          $415 = ($scaleCount$0$lcssa$i168173|0)>(0);
          $416 = ($genericCount$0$lcssa$i169172|0)>(0);
          $417 = ($genericPPtrCount$0$lcssa$i170171|0)>(0);
          $418 = $genericPPtrCount$0$lcssa$i170171 << 1;
          $419 = $genericCount$0$lcssa$i169172 << 1;
          $420 = $scaleCount$0$lcssa$i168173 << 1;
          $421 = $rotationCount$0$lcssa$i167174 << 1;
          $422 = $positionCount$0$lcssa$i166175 << 1;
          $c$067$i = 0;
          while(1) {
           $503 = (($134) + ($c$067$i<<2)|0);
           $504 = HEAP32[$503>>2]|0;
           $505 = ($504|0)==(0|0);
           if (!($505)) {
            $506 = (($137) + ($c$067$i<<2)|0);
            $507 = HEAP32[$506>>2]|0;
            if ($408) {
             $$0$i17$i = 0;
            } else {
             $508 = HEAP32[$allocator>>2]|0;
             $509 = HEAP32[$508>>2]|0;
             __THREW__ = 0;
             $510 = (invoke_iiii($509|0,($allocator|0),($422|0),2)|0);
             $511 = __THREW__; __THREW__ = 0;
             $512 = $511&1;
             if ($512) {
              break;
             }
             $$0$i17$i = $510;
            }
            $513 = (($504) + 12|0);
            HEAP32[$513>>2] = $$0$i17$i;
            if ($409) {
             $$0$i12$i = 0;
            } else {
             $514 = HEAP32[$allocator>>2]|0;
             $515 = HEAP32[$514>>2]|0;
             __THREW__ = 0;
             $516 = (invoke_iiii($515|0,($allocator|0),($421|0),2)|0);
             $517 = __THREW__; __THREW__ = 0;
             $518 = $517&1;
             if ($518) {
              break;
             }
             $$0$i12$i = $516;
            }
            $519 = (($504) + 16|0);
            HEAP32[$519>>2] = $$0$i12$i;
            if ($410) {
             $$0$i9$i = 0;
            } else {
             $520 = HEAP32[$allocator>>2]|0;
             $521 = HEAP32[$520>>2]|0;
             __THREW__ = 0;
             $522 = (invoke_iiii($521|0,($allocator|0),($420|0),2)|0);
             $523 = __THREW__; __THREW__ = 0;
             $524 = $523&1;
             if ($524) {
              break;
             }
             $$0$i9$i = $522;
            }
            $525 = (($504) + 20|0);
            HEAP32[$525>>2] = $$0$i9$i;
            if ($411) {
             $$0$i6$i = 0;
            } else {
             $526 = HEAP32[$allocator>>2]|0;
             $527 = HEAP32[$526>>2]|0;
             __THREW__ = 0;
             $528 = (invoke_iiii($527|0,($allocator|0),($419|0),2)|0);
             $529 = __THREW__; __THREW__ = 0;
             $530 = $529&1;
             if ($530) {
              break;
             }
             $$0$i6$i = $528;
            }
            $531 = (($504) + 24|0);
            HEAP32[$531>>2] = $$0$i6$i;
            if ($412) {
             $$0$i$i = 0;
            } else {
             $532 = HEAP32[$allocator>>2]|0;
             $533 = HEAP32[$532>>2]|0;
             __THREW__ = 0;
             $534 = (invoke_iiii($533|0,($allocator|0),($418|0),2)|0);
             $535 = __THREW__; __THREW__ = 0;
             $536 = $535&1;
             if ($536) {
              break;
             }
             $$0$i$i = $534;
            }
            $537 = (($504) + 28|0);
            HEAP32[$537>>2] = $$0$i$i;
            if ($413) {
             $538 = HEAP32[$513>>2]|0;
             _memset(($538|0),-1,($422|0))|0;
            }
            if ($414) {
             $539 = HEAP32[$519>>2]|0;
             _memset(($539|0),-1,($421|0))|0;
            }
            if ($415) {
             $540 = HEAP32[$525>>2]|0;
             _memset(($540|0),-1,($420|0))|0;
            }
            if ($416) {
             $541 = HEAP32[$531>>2]|0;
             _memset(($541|0),-1,($419|0))|0;
            }
            if ($417) {
             $542 = HEAP32[$537>>2]|0;
             _memset(($542|0),-1,($418|0))|0;
            }
            $543 = (($507) + 8|0);
            $544 = HEAP32[$543>>2]|0;
            $545 = ($544|0)==(0);
            L224: do {
             if ($545) {
              $$lcssa$i = 0;
             } else {
              $582 = 0;$curveIndex$061$i = 0;$i10$062$i = 0;
              while(1) {
               $546 = HEAP32[$507>>2]|0;
               $547 = (($546) + ($i10$062$i<<4)|0);
               __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE4findIS4_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_($found$i,$bindingMap$i,$547);
               $548 = HEAP32[$found$i>>2]|0;
               $549 = (($548) + 32|0);
               $550 = HEAP32[$549>>2]|0;
               switch ($550|0) {
               case 6:  {
                $551 = $curveIndex$061$i&65535;
                $552 = (($548) + 36|0);
                $553 = HEAP32[$552>>2]|0;
                $554 = HEAP32[$513>>2]|0;
                $555 = (($554) + ($553<<1)|0);
                HEAP16[$555>>1] = $551;
                break;
               }
               case 7:  {
                $556 = $curveIndex$061$i&65535;
                $557 = (($548) + 36|0);
                $558 = HEAP32[$557>>2]|0;
                $559 = HEAP32[$519>>2]|0;
                $560 = (($559) + ($558<<1)|0);
                HEAP16[$560>>1] = $556;
                break;
               }
               case 8:  {
                $561 = $curveIndex$061$i&65535;
                $562 = (($548) + 36|0);
                $563 = HEAP32[$562>>2]|0;
                $564 = HEAP32[$525>>2]|0;
                $565 = (($564) + ($563<<1)|0);
                HEAP16[$565>>1] = $561;
                break;
               }
               case 3:  {
                $571 = $curveIndex$061$i&65535;
                $572 = (($548) + 36|0);
                $573 = HEAP32[$572>>2]|0;
                $574 = HEAP32[$537>>2]|0;
                $575 = (($574) + ($573<<1)|0);
                HEAP16[$575>>1] = $571;
                break;
               }
               case 1:  {
                $566 = $curveIndex$061$i&65535;
                $567 = (($548) + 36|0);
                $568 = HEAP32[$567>>2]|0;
                $569 = HEAP32[$531>>2]|0;
                $570 = (($569) + ($568<<1)|0);
                HEAP16[$570>>1] = $566;
                break;
               }
               default: {
               }
               }
               $576 = (($548) + 40|0);
               $577 = HEAP32[$576>>2]|0;
               $578 = (($577) + ($curveIndex$061$i))|0;
               $579 = (($548) + 44|0);
               $580 = HEAP32[$579>>2]|0;
               $581 = ($580|0)==(3);
               $$$i = $581 ? $578 : $582;
               $583 = (($i10$062$i) + 1)|0;
               $584 = HEAP32[$543>>2]|0;
               $585 = ($583>>>0)<($584>>>0);
               if ($585) {
                $582 = $$$i;$curveIndex$061$i = $578;$i10$062$i = $583;
               } else {
                $$lcssa$i = $$$i;
                break L224;
               }
              }
             }
            } while(0);
            $586 = HEAP32[$504>>2]|0;
            $591 = $$lcssa$i;$m$065$i = 0;
            while(1) {
             $587 = ((($586) + ($m$065$i<<2)|0) + 1072|0);
             $588 = HEAP32[$587>>2]|0;
             $589 = (($588) + 1)|0;
             $590 = ($589|0)<($591|0);
             $592 = $590 ? $591 : $589;
             $593 = (($m$065$i) + 1)|0;
             $exitcond$i = ($593|0)==(137);
             if ($exitcond$i) {
              break;
             } else {
              $591 = $592;$m$065$i = $593;
             }
            }
            $594 = (($504) + 8|0);
            HEAP32[$594>>2] = $592;
           }
           $595 = (($c$067$i) + 1)|0;
           $596 = ($595>>>0)<($32>>>0);
           if ($596) {
            $c$067$i = $595;
           } else {
            break L183;
           }
          }
          $274 = ___cxa_find_matching_catch()|0;
          $275 = tempRet0;
          $943 = $863;$944 = $641;$945 = $859;$946 = $856;$lpad$phi$i$index = $274;$lpad$phi$i$index17 = $275;
          break L75;
         }
        } while(0);
        $597 = HEAP32[$235>>2]|0;
        $598 = ($597|0)>(-1);
        do {
         if ($598) {
          $599 = HEAP32[$bindingsSorted$i>>2]|0;
          $600 = HEAP32[$236>>2]|0;
          HEAP32[$8>>2] = $600;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$8+0>>2]|0;
          invoke_vii(2591,($599|0),($$byval_copy60|0));
          $601 = __THREW__; __THREW__ = 0;
          $602 = $601&1;
          if ($602) {
           $272 = ___cxa_find_matching_catch()|0;
           $273 = tempRet0;
           $935 = $863;$936 = $641;$937 = $859;$938 = $856;$lpad$phi120$i$index = $272;$lpad$phi120$i$index7 = $273;
           label = 63;
           break L70;
          } else {
           HEAP32[$bindingsSorted$i>>2] = 0;
           break;
          }
         }
        } while(0);
        $606 = HEAP32[$153>>2]|0;
        __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($bindingMap$i,$606);
        $607 = HEAP32[$genericBindings>>2]|0;
        $608 = HEAP32[$148>>2]|0;
        $609 = HEAP32[$genericPPtrBindings>>2]|0;
        $610 = HEAP32[$151>>2]|0;
        $611 = (($608) + ($612))|0;
        $613 = (($611) + ($610))|0;
        __THREW__ = 0;
        $614 = (invoke_iiii(1588,1,($613|0),($allocator|0))|0);
        $615 = __THREW__; __THREW__ = 0;
        $616 = $615&1;
        do {
         if (!($616)) {
          $617 = (($614) + 4|0);
          $618 = $617;
          $619 = HEAP32[$617>>2]|0;
          $620 = (($619) + ($618))|0;
          $621 = $620;
          $622 = (($614) + 8|0);
          HEAP32[$622>>2] = $621;
          $623 = ($608|0)==(0);
          if ($623) {
           $valueIndex$0$lcssa$i = 0;
          } else {
           $i$011$i = 0;
           while(1) {
            $625 = ((($607) + ($i$011$i<<4)|0) + 4|0);
            $626 = HEAP32[$625>>2]|0;
            $627 = (($621) + ($i$011$i<<4)|0);
            HEAP32[$627>>2] = $626;
            $628 = ((($621) + ($i$011$i<<4)|0) + 12|0);
            HEAP32[$628>>2] = $i$011$i;
            $629 = ((($621) + ($i$011$i<<4)|0) + 8|0);
            HEAP32[$629>>2] = 1;
            $630 = (($i$011$i) + 1)|0;
            $exitcond16$i = ($630|0)==($608|0);
            if ($exitcond16$i) {
             $valueIndex$0$lcssa$i = $608;
             break;
            } else {
             $i$011$i = $630;
            }
           }
          }
          $624 = ($610|0)==(0);
          if ($624) {
           $valueIndex$1$lcssa$i = $valueIndex$0$lcssa$i;
          } else {
           $i1$08$i = 0;$valueIndex$17$i = $valueIndex$0$lcssa$i;
           while(1) {
            $633 = ((($609) + ($i1$08$i<<4)|0) + 4|0);
            $634 = HEAP32[$633>>2]|0;
            $635 = (($621) + ($valueIndex$17$i<<4)|0);
            HEAP32[$635>>2] = $634;
            $636 = ((($621) + ($valueIndex$17$i<<4)|0) + 12|0);
            HEAP32[$636>>2] = $i1$08$i;
            $637 = ((($621) + ($valueIndex$17$i<<4)|0) + 8|0);
            HEAP32[$637>>2] = 3;
            $638 = (($i1$08$i) + 1)|0;
            $639 = (($valueIndex$17$i) + 1)|0;
            $exitcond15$i = ($638|0)==($610|0);
            if ($exitcond15$i) {
             break;
            } else {
             $i1$08$i = $638;$valueIndex$17$i = $639;
            }
           }
           $631 = (($valueIndex$0$lcssa$i) + ($610))|0;
           $valueIndex$1$lcssa$i = $631;
          }
          $632 = ($612|0)==(0);
          if (!($632)) {
           $i2$05$i = 0;$positionCount$02$i = 0;$rotationCount$03$i = 0;$scaleCount$04$i = 0;$valueIndex$21$i = $valueIndex$1$lcssa$i;
           while(1) {
            $640 = (($641) + ($i2$05$i<<3)|0);
            $642 = HEAP32[$640>>2]|0;
            $643 = (($621) + ($valueIndex$21$i<<4)|0);
            HEAP32[$643>>2] = $642;
            $644 = ((($641) + ($i2$05$i<<3)|0) + 4|0);
            $645 = HEAP32[$644>>2]|0;
            if ((($645|0) == 1)) {
             $646 = (($positionCount$02$i) + 1)|0;
             $647 = ((($621) + ($valueIndex$21$i<<4)|0) + 12|0);
             HEAP32[$647>>2] = $positionCount$02$i;
             $648 = ((($621) + ($valueIndex$21$i<<4)|0) + 8|0);
             HEAP32[$648>>2] = 6;
             $positionCount$1$i42 = $646;$rotationCount$1$i43 = $rotationCount$03$i;$scaleCount$1$i44 = $scaleCount$04$i;
            } else if ((($645|0) == 2)) {
             $649 = (($rotationCount$03$i) + 1)|0;
             $650 = ((($621) + ($valueIndex$21$i<<4)|0) + 12|0);
             HEAP32[$650>>2] = $rotationCount$03$i;
             $651 = ((($621) + ($valueIndex$21$i<<4)|0) + 8|0);
             HEAP32[$651>>2] = 7;
             $positionCount$1$i42 = $positionCount$02$i;$rotationCount$1$i43 = $649;$scaleCount$1$i44 = $scaleCount$04$i;
            } else if ((($645|0) == 3)) {
             $652 = (($scaleCount$04$i) + 1)|0;
             $653 = ((($621) + ($valueIndex$21$i<<4)|0) + 12|0);
             HEAP32[$653>>2] = $scaleCount$04$i;
             $654 = ((($621) + ($valueIndex$21$i<<4)|0) + 8|0);
             HEAP32[$654>>2] = 8;
             $positionCount$1$i42 = $positionCount$02$i;$rotationCount$1$i43 = $rotationCount$03$i;$scaleCount$1$i44 = $652;
            } else {
             $positionCount$1$i42 = $positionCount$02$i;$rotationCount$1$i43 = $rotationCount$03$i;$scaleCount$1$i44 = $scaleCount$04$i;
            }
            $655 = (($i2$05$i) + 1)|0;
            $656 = (($valueIndex$21$i) + 1)|0;
            $exitcond$i45 = ($655|0)==($612|0);
            if ($exitcond$i45) {
             break;
            } else {
             $i2$05$i = $655;$positionCount$02$i = $positionCount$1$i42;$rotationCount$03$i = $rotationCount$1$i43;$scaleCount$04$i = $scaleCount$1$i44;$valueIndex$21$i = $656;
            }
           }
          }
          $657 = (($77) + 24|0);
          HEAP32[$657>>2] = $614;
          $658 = (($77) + 4|0);
          $659 = HEAP32[$658>>2]|0;
          $660 = ($659|0)==(0);
          L268: do {
           if (!($660)) {
            $661 = (($77) + 28|0);
            $662 = (($controller) + 4|0);
            $663 = $662;
            $664 = $614;$layerIter$097 = 0;
            while(1) {
             __THREW__ = 0;
             $665 = (invoke_iii(2582,($664|0),($allocator|0))|0);
             $666 = __THREW__; __THREW__ = 0;
             $667 = $666&1;
             if ($667) {
              break;
             }
             $668 = HEAP32[$661>>2]|0;
             $669 = (($668) + ($layerIter$097<<2)|0);
             HEAP32[$669>>2] = $665;
             $670 = HEAP32[$657>>2]|0;
             $671 = HEAP32[$662>>2]|0;
             $672 = (($671) + ($663))|0;
             $673 = $672;
             $674 = (($673) + ($layerIter$097<<3)|0);
             $675 = $674;
             $676 = HEAP32[$674>>2]|0;
             $677 = (($675) + ($676))|0;
             $678 = $677;
             $679 = (($678) + 16|0);
             $680 = $679;
             $681 = HEAP32[$679>>2]|0;
             $682 = (($680) + ($681))|0;
             $683 = $682;
             $684 = HEAP32[$661>>2]|0;
             $685 = (($684) + ($layerIter$097<<2)|0);
             $686 = HEAP32[$685>>2]|0;
             $687 = HEAP32[$683>>2]|0;
             $688 = ($687|0)==(0);
             $689 = HEAP32[$670>>2]|0;
             $690 = ($689|0)==(0);
             if (!($690)) {
              $691 = (($670) + 4|0);
              $692 = $691;
              $693 = HEAP32[$691>>2]|0;
              $694 = (($693) + ($692))|0;
              $695 = $694;
              $696 = (($686) + 40|0);
              $697 = $696;
              $698 = (($686) + 44|0);
              $699 = (($686) + 52|0);
              $700 = $699;
              $701 = (($686) + 56|0);
              $702 = (($686) + 64|0);
              $703 = $702;
              $704 = (($686) + 68|0);
              $705 = (($686) + 28|0);
              $706 = $705;
              $707 = (($686) + 32|0);
              $708 = (($686) + 16|0);
              $709 = $708;
              $710 = (($686) + 20|0);
              $711 = (($683) + 4|0);
              $712 = $711;
              $maskIter$05$i = 0;
              while(1) {
               $$pre$i49 = ((($695) + ($maskIter$05$i<<4)|0) + 8|0);
               $$pr$pre = HEAP32[$$pre$i49>>2]|0;
               L277: do {
                if ($688) {
                 $maskValue$0$off0$i$ph = 1;
                 label = 209;
                } else {
                 $713 = ($$pr$pre|0)==(1);
                 if ($713) {
                  $718 = ((($695) + ($maskIter$05$i<<4)|0) + 12|0);
                  $719 = HEAP32[$718>>2]|0;
                  $746 = $719;$maskValue$0$off0$i92 = 1;
                  label = 213;
                  break;
                 }
                 $714 = (($695) + ($maskIter$05$i<<4)|0);
                 $715 = HEAP32[$711>>2]|0;
                 $716 = (($715) + ($712))|0;
                 $717 = $716;
                 $skIter$04$i93 = 0;
                 while(1) {
                  $720 = ((($717) + ($skIter$04$i93<<3)|0) + 4|0);
                  $721 = Math_fround(HEAPF32[$720>>2]);
                  $722 = $721 > Math_fround(0.0);
                  if ($722) {
                   $724 = HEAP32[$714>>2]|0;
                   $725 = (($717) + ($skIter$04$i93<<3)|0);
                   $726 = HEAP32[$725>>2]|0;
                   $727 = ($724|0)==($726|0);
                   if ($727) {
                    $maskValue$0$off0$i$ph = 1;
                    label = 209;
                    break L277;
                   }
                  }
                  $skIter$04$i$be = (($skIter$04$i93) + 1)|0;
                  $723 = ($skIter$04$i$be>>>0)<($687>>>0);
                  if ($723) {
                   $skIter$04$i93 = $skIter$04$i$be;
                  } else {
                   $maskValue$0$off0$i$ph = 0;
                   label = 209;
                   break;
                  }
                 }
                }
               } while(0);
               L287: do {
                if ((label|0) == 209) {
                 label = 0;
                 $728 = ((($695) + ($maskIter$05$i<<4)|0) + 12|0);
                 $729 = HEAP32[$728>>2]|0;
                 switch ($$pr$pre|0) {
                 case 8:  {
                  $738 = HEAP32[$702>>2]|0;
                  $739 = (($738) + ($703))|0;
                  $740 = $739;
                  HEAP32[$704>>2] = $740;
                  $741 = (($740) + ($729)|0);
                  HEAP8[$741>>0] = $maskValue$0$off0$i$ph;
                  break L287;
                  break;
                 }
                 case 3:  {
                  $747 = HEAP32[$708>>2]|0;
                  $748 = (($747) + ($709))|0;
                  $749 = $748;
                  HEAP32[$710>>2] = $749;
                  $750 = (($749) + ($729)|0);
                  HEAP8[$750>>0] = $maskValue$0$off0$i$ph;
                  break L287;
                  break;
                 }
                 case 1:  {
                  $746 = $729;$maskValue$0$off0$i92 = $maskValue$0$off0$i$ph;
                  label = 213;
                  break L287;
                  break;
                 }
                 case 6:  {
                  $730 = HEAP32[$696>>2]|0;
                  $731 = (($730) + ($697))|0;
                  $732 = $731;
                  HEAP32[$698>>2] = $732;
                  $733 = (($732) + ($729)|0);
                  HEAP8[$733>>0] = $maskValue$0$off0$i$ph;
                  break L287;
                  break;
                 }
                 case 7:  {
                  $734 = HEAP32[$699>>2]|0;
                  $735 = (($734) + ($700))|0;
                  $736 = $735;
                  HEAP32[$701>>2] = $736;
                  $737 = (($736) + ($729)|0);
                  HEAP8[$737>>0] = $maskValue$0$off0$i$ph;
                  break L287;
                  break;
                 }
                 default: {
                  break L287;
                 }
                 }
                }
               } while(0);
               if ((label|0) == 213) {
                label = 0;
                $742 = HEAP32[$705>>2]|0;
                $743 = (($742) + ($706))|0;
                $744 = $743;
                HEAP32[$707>>2] = $744;
                $745 = (($744) + ($746)|0);
                HEAP8[$745>>0] = $maskValue$0$off0$i92;
               }
               $751 = (($maskIter$05$i) + 1)|0;
               $exitcond = ($751|0)==($689|0);
               if ($exitcond) {
                break;
               } else {
                $maskIter$05$i = $751;
               }
              }
             }
             $752 = (($layerIter$097) + 1)|0;
             $753 = HEAP32[$658>>2]|0;
             $754 = ($752>>>0)<($753>>>0);
             if (!($754)) {
              break L268;
             }
             $$pre = HEAP32[$657>>2]|0;
             $664 = $$pre;$layerIter$097 = $752;
            }
            $763 = ___cxa_find_matching_catch()|0;
            $764 = tempRet0;
            $768 = $859;$769 = $856;$966 = $863;$967 = $641;$eh$lpad$body$index29Z2D = $764;$eh$lpad$body$indexZ2D = $763;
            label = 224;
            break L70;
           }
          } while(0);
          $772 = (($controller) + 24|0);
          $773 = $772;
          $774 = HEAP32[$772>>2]|0;
          $775 = (($774) + ($773))|0;
          $776 = $775;
          $777 = (($controller) + 28|0);
          HEAP32[$777>>2] = $776;
          $778 = (($77) + 20|0);
          $779 = HEAP32[$778>>2]|0;
          $780 = HEAP32[$148>>2]|0;
          $781 = ($780|0)==(0);
          L301: do {
           if ($781) {
            $828 = 0;
           } else {
            $genericIter$01$i = 0;
            L302: while(1) {
             $782 = ((($607) + ($genericIter$01$i<<4)|0) + 12|0);
             $783 = HEAP16[$782>>1]|0;
             $784 = ($783<<16>>16)==(95);
             do {
              if ($784) {
               $785 = ((($607) + ($genericIter$01$i<<4)|0) + 4|0);
               $786 = HEAP32[$785>>2]|0;
               __THREW__ = 0;
               $787 = (invoke_iii(2583,($776|0),($786|0))|0);
               $788 = __THREW__; __THREW__ = 0;
               $789 = $788&1;
               if ($789) {
                break L302;
               }
               $790 = ($787|0)==(-1);
               if ($790) {
                break;
               }
               $791 = (($779) + ($787<<2)|0);
               HEAP32[$791>>2] = $genericIter$01$i;
              }
             } while(0);
             $792 = (($genericIter$01$i) + 1)|0;
             $793 = ($792>>>0)<($780>>>0);
             if ($793) {
              $genericIter$01$i = $792;
             } else {
              $828 = $780;
              break L301;
             }
            }
            $761 = ___cxa_find_matching_catch()|0;
            $762 = tempRet0;
            $768 = $859;$769 = $856;$966 = $863;$967 = $641;$eh$lpad$body$index29Z2D = $762;$eh$lpad$body$indexZ2D = $761;
            label = 224;
            break L70;
           }
          } while(0);
          $794 = HEAP32[$657>>2]|0;
          __THREW__ = 0;
          $795 = (invoke_ii(3399,43)|0);
          $796 = __THREW__; __THREW__ = 0;
          $797 = $796&1;
          if ($797) {
           break;
          }
          __THREW__ = 0;
          $798 = (invoke_iii(2583,($794|0),($795|0))|0);
          $799 = __THREW__; __THREW__ = 0;
          $800 = $799&1;
          if ($800) {
           break;
          }
          $801 = (($77) + 32|0);
          HEAP32[$801>>2] = $798;
          $802 = ($798|0)==(-1);
          if (!($802)) {
           $803 = (($794) + 4|0);
           $804 = $803;
           $805 = HEAP32[$803>>2]|0;
           $806 = (($805) + ($804))|0;
           $807 = $806;
           $808 = ((($807) + ($798<<4)|0) + 12|0);
           $809 = HEAP32[$808>>2]|0;
           HEAP32[$801>>2] = $809;
          }
          $810 = HEAP32[$allocator>>2]|0;
          $811 = HEAP32[$810>>2]|0;
          __THREW__ = 0;
          $812 = (invoke_iiii($811|0,($allocator|0),40,4)|0);
          $813 = __THREW__; __THREW__ = 0;
          $814 = $813&1;
          if ($814) {
           break;
          }
          $815 = ($812|0)==(0|0);
          if ($815) {
           $817 = 0;
          } else {
           $817 = $812;
          }
          $816 = (($817) + 36|0);
          HEAP32[$816>>2] = $77;
          $818 = (($817) + 16|0);
          HEAP32[$818>>2] = $819;
          $820 = (($817) + 20|0);
          HEAP32[$820>>2] = $612;
          if ($632) {
           $$0$i60 = 0;
          } else {
           $821 = HEAP32[$allocator>>2]|0;
           $822 = HEAP32[$821>>2]|0;
           $823 = $612 << 3;
           __THREW__ = 0;
           $824 = (invoke_iiii($822|0,($allocator|0),($823|0),4)|0);
           $825 = __THREW__; __THREW__ = 0;
           $826 = $825&1;
           if ($826) {
            break;
           }
           _memcpy(($824|0),($641|0),($823|0))|0;
           $$0$i60 = $824;
          }
          $827 = (($817) + 24|0);
          HEAP32[$827>>2] = $$0$i60;
          HEAP32[$817>>2] = $828;
          $829 = ($828|0)==(0);
          if ($829) {
           $$0$i62 = 0;
          } else {
           $830 = HEAP32[$allocator>>2]|0;
           $831 = HEAP32[$830>>2]|0;
           $832 = $828 << 4;
           __THREW__ = 0;
           $833 = (invoke_iiii($831|0,($allocator|0),($832|0),4)|0);
           $834 = __THREW__; __THREW__ = 0;
           $835 = $834&1;
           if ($835) {
            break;
           }
           _memcpy(($833|0),($607|0),($832|0))|0;
           $$0$i62 = $833;
          }
          $836 = (($817) + 4|0);
          HEAP32[$836>>2] = $$0$i62;
          $837 = HEAP32[$151>>2]|0;
          $838 = (($817) + 8|0);
          HEAP32[$838>>2] = $837;
          $839 = ($837|0)==(0);
          if ($839) {
           $$0$i64 = 0;
          } else {
           $840 = HEAP32[$allocator>>2]|0;
           $841 = HEAP32[$840>>2]|0;
           $842 = $837 << 4;
           __THREW__ = 0;
           $843 = (invoke_iiii($841|0,($allocator|0),($842|0),4)|0);
           $844 = __THREW__; __THREW__ = 0;
           $845 = $844&1;
           if ($845) {
            break;
           }
           _memcpy(($843|0),($609|0),($842|0))|0;
           $$0$i64 = $843;
          }
          $846 = (($817) + 12|0);
          HEAP32[$846>>2] = $$0$i64;
          $847 = (($817) + 28|0);
          HEAP32[$847>>2] = $848;
          $849 = ($848|0)==(0);
          if ($849) {
           $$0$i67 = 0;
          } else {
           $850 = HEAP32[$allocator>>2]|0;
           $851 = HEAP32[$850>>2]|0;
           $852 = $848 << 2;
           __THREW__ = 0;
           $853 = (invoke_iiii($851|0,($allocator|0),($852|0),4)|0);
           $854 = __THREW__; __THREW__ = 0;
           $855 = $854&1;
           if ($855) {
            break;
           }
           _memcpy(($853|0),($856|0),($852|0))|0;
           $$0$i67 = $853;
          }
          $857 = (($817) + 32|0);
          HEAP32[$857>>2] = $$0$i67;
          $858 = ($859|0)>(-1);
          do {
           if ($858) {
            HEAP32[$14>>2] = $146;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$14+0>>2]|0;
            invoke_vii(2591,($856|0),($$byval_copy60|0));
            $860 = __THREW__; __THREW__ = 0;
            $861 = $860&1;
            if (!($861)) {
             break;
            }
            $759 = ___cxa_find_matching_catch()|0;
            $760 = tempRet0;
            $$01 = $759;$$02 = $760;$872 = $863;$873 = $641;
            label = 258;
            break L70;
           }
          } while(0);
          $862 = ($863|0)>(-1);
          do {
           if ($862) {
            HEAP32[$15>>2] = $146;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$15+0>>2]|0;
            invoke_vii(2591,($641|0),($$byval_copy60|0));
            $864 = __THREW__; __THREW__ = 0;
            $865 = $864&1;
            if (!($865)) {
             break;
            }
            $757 = ___cxa_find_matching_catch()|0;
            $758 = tempRet0;
            $$1 = $757;$$13 = $758;
            label = 263;
            break L70;
           }
          } while(0);
          $866 = HEAP32[$152>>2]|0;
          $867 = ($866|0)>(-1);
          do {
           if ($867) {
            $868 = HEAP32[$150>>2]|0;
            HEAP32[$16>>2] = $868;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$16+0>>2]|0;
            invoke_vii(2591,($609|0),($$byval_copy60|0));
            $869 = __THREW__; __THREW__ = 0;
            $870 = $869&1;
            if ($870) {
             $755 = ___cxa_find_matching_catch()|0;
             $756 = tempRet0;
             $$2 = $755;$$24 = $756;
             break L70;
            } else {
             HEAP32[$genericPPtrBindings>>2] = 0;
             break;
            }
           }
          } while(0);
          $876 = HEAP32[$149>>2]|0;
          $877 = ($876|0)>(-1);
          if ($877) {
           $878 = HEAP32[$147>>2]|0;
           HEAP32[$18>>2] = $878;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$18+0>>2]|0;
           invoke_vii(2591,($607|0),($$byval_copy60|0));
           $879 = __THREW__; __THREW__ = 0;
           $880 = $879&1;
           if ($880) {
            $$ph = $899;$$ph130 = $909;$$ph131 = $888;
            label = 13;
            break L11;
           }
           HEAP32[$genericBindings>>2] = 0;
          }
          $887 = ($888|0)==(0|0);
          if (!($887)) {
           $889 = HEAP32[628512>>2]|0;
           HEAP32[$21>>2] = $889;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$21+0>>2]|0;
           invoke_vii(2591,($888|0),($$byval_copy60|0));
           $890 = __THREW__; __THREW__ = 0;
           $891 = $890&1;
           if ($891) {
            $926 = $909;$927 = $899;
            label = 9;
            break L11;
           }
          }
          $898 = ($899|0)==(0|0);
          if (!($898)) {
           $900 = HEAP32[628512>>2]|0;
           HEAP32[$23>>2] = $900;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$23+0>>2]|0;
           invoke_vii(2591,($899|0),($$byval_copy60|0));
           $901 = __THREW__; __THREW__ = 0;
           $902 = $901&1;
           if ($902) {
            $925 = $909;
            label = 7;
            break L11;
           }
          }
          $908 = ($909|0)==(0|0);
          if ($908) {
           $$0 = $817;
           STACKTOP = sp;return ($$0|0);
          }
          $910 = HEAP32[628512>>2]|0;
          HEAP32[$20>>2] = $910;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$20+0>>2]|0;
          invoke_vii(2591,($909|0),($$byval_copy60|0));
          $911 = __THREW__; __THREW__ = 0;
          $912 = $911&1;
          if (!($912)) {
           $$0 = $817;
           STACKTOP = sp;return ($$0|0);
          }
          $37 = ___cxa_find_matching_catch()|0;
          $38 = tempRet0;
          $$6 = $37;$$68 = $38;
          ___resumeException($$6|0);
          // unreachable;
         }
        } while(0);
        $765 = ___cxa_find_matching_catch()|0;
        $766 = tempRet0;
        $768 = $859;$769 = $856;$966 = $863;$967 = $641;$eh$lpad$body$index29Z2D = $766;$eh$lpad$body$indexZ2D = $765;
        label = 224;
        break L70;
       }
      } while(0);
      if ((label|0) == 70) {
       $286 = ___cxa_find_matching_catch()|0;
       $287 = tempRet0;
       $943 = $934;$944 = 0;$945 = 0;$946 = 0;$lpad$phi$i$index = $286;$lpad$phi$i$index17 = $287;
      }
      $288 = HEAP32[$235>>2]|0;
      $289 = ($288|0)>(-1);
      if ($289) {
       $290 = HEAP32[$bindingsSorted$i>>2]|0;
       $291 = HEAP32[$236>>2]|0;
       HEAP32[$0>>2] = $291;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($290|0),($$byval_copy60|0));
       $292 = __THREW__; __THREW__ = 0;
       $293 = $292&1;
       if ($293) {
        $604 = ___cxa_find_matching_catch(0|0)|0;
        $605 = tempRet0;
        ___clang_call_terminate($604);
        // unreachable;
       } else {
        HEAP32[$bindingsSorted$i>>2] = 0;
        $$0$i39 = $lpad$phi$i$index;$$01$i = $lpad$phi$i$index17;$939 = $943;$940 = $944;$941 = $945;$942 = $946;
        label = 183;
        break;
       }
      } else {
       $$0$i39 = $lpad$phi$i$index;$$01$i = $lpad$phi$i$index17;$939 = $943;$940 = $944;$941 = $945;$942 = $946;
       label = 183;
      }
     }
    } while(0);
    if ((label|0) == 63) {
     $$0$i39 = $lpad$phi120$i$index;$$01$i = $lpad$phi120$i$index7;$939 = $935;$940 = $936;$941 = $937;$942 = $938;
     label = 183;
    }
    if ((label|0) == 183) {
     $603 = HEAP32[$153>>2]|0;
     __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($bindingMap$i,$603);
     $768 = $941;$769 = $942;$966 = $939;$967 = $940;$eh$lpad$body$index29Z2D = $$01$i;$eh$lpad$body$indexZ2D = $$0$i39;
     label = 224;
    }
    if ((label|0) == 224) {
     $767 = ($768|0)>(-1);
     if ($767) {
      HEAP32[$0>>2] = $146;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($769|0),($$byval_copy60|0));
      $770 = __THREW__; __THREW__ = 0;
      $771 = $770&1;
      if ($771) {
       $923 = ___cxa_find_matching_catch(0|0)|0;
       $924 = tempRet0;
       ___clang_call_terminate($923);
       // unreachable;
      } else {
       $$01 = $eh$lpad$body$indexZ2D;$$02 = $eh$lpad$body$index29Z2D;$872 = $966;$873 = $967;
       label = 258;
      }
     } else {
      $$01 = $eh$lpad$body$indexZ2D;$$02 = $eh$lpad$body$index29Z2D;$872 = $966;$873 = $967;
      label = 258;
     }
    }
    if ((label|0) == 258) {
     $871 = ($872|0)>(-1);
     if ($871) {
      HEAP32[$17>>2] = $146;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$17+0>>2]|0;
      invoke_vii(2591,($873|0),($$byval_copy60|0));
      $874 = __THREW__; __THREW__ = 0;
      $875 = $874&1;
      if ($875) {
       $923 = ___cxa_find_matching_catch(0|0)|0;
       $924 = tempRet0;
       ___clang_call_terminate($923);
       // unreachable;
      } else {
       $$1 = $$01;$$13 = $$02;
       label = 263;
      }
     } else {
      $$1 = $$01;$$13 = $$02;
      label = 263;
     }
    }
    do {
     if ((label|0) == 263) {
      $881 = HEAP32[$152>>2]|0;
      $882 = ($881|0)>(-1);
      if ($882) {
       $883 = HEAP32[$genericPPtrBindings>>2]|0;
       $884 = HEAP32[$150>>2]|0;
       HEAP32[$20>>2] = $884;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$20+0>>2]|0;
       invoke_vii(2591,($883|0),($$byval_copy60|0));
       $885 = __THREW__; __THREW__ = 0;
       $886 = $885&1;
       if ($886) {
        $923 = ___cxa_find_matching_catch(0|0)|0;
        $924 = tempRet0;
        ___clang_call_terminate($923);
        // unreachable;
       } else {
        HEAP32[$genericPPtrBindings>>2] = 0;
        $$2 = $$1;$$24 = $$13;
        break;
       }
      } else {
       $$2 = $$1;$$24 = $$13;
      }
     }
    } while(0);
    $892 = HEAP32[$149>>2]|0;
    $893 = ($892|0)>(-1);
    if ($893) {
     $894 = HEAP32[$genericBindings>>2]|0;
     $895 = HEAP32[$147>>2]|0;
     HEAP32[$22>>2] = $895;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$22+0>>2]|0;
     invoke_vii(2591,($894|0),($$byval_copy60|0));
     $896 = __THREW__; __THREW__ = 0;
     $897 = $896&1;
     if ($897) {
      $923 = ___cxa_find_matching_catch(0|0)|0;
      $924 = tempRet0;
      ___clang_call_terminate($923);
      // unreachable;
     } else {
      HEAP32[$genericBindings>>2] = 0;
      $$3 = $$2;$$35 = $$24;$904 = $888;$932 = $909;$933 = $899;
      label = 273;
      break;
     }
    } else {
     $$3 = $$2;$$35 = $$24;$904 = $888;$932 = $909;$933 = $899;
     label = 273;
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  $$5 = $43;$$57 = $44;$919 = $925;
 }
 else if ((label|0) == 9) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  $$4 = $49;$$46 = $50;$914 = $927;$928 = $926;
  label = 277;
 }
 else if ((label|0) == 13) {
  $75 = ___cxa_find_matching_catch()|0;
  $76 = tempRet0;
  $929 = $$ph;$930 = $$ph130;$931 = $$ph131;$lpad$phi133$index = $75;$lpad$phi133$index2 = $76;
  label = 14;
 }
 if ((label|0) == 14) {
  $$3 = $lpad$phi133$index;$$35 = $lpad$phi133$index2;$904 = $931;$932 = $930;$933 = $929;
  label = 273;
 }
 if ((label|0) == 273) {
  $903 = ($904|0)==(0|0);
  if ($903) {
   $$4 = $$3;$$46 = $$35;$914 = $933;$928 = $932;
   label = 277;
  } else {
   $905 = HEAP32[628512>>2]|0;
   HEAP32[$24>>2] = $905;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$24+0>>2]|0;
   invoke_vii(2591,($904|0),($$byval_copy60|0));
   $906 = __THREW__; __THREW__ = 0;
   $907 = $906&1;
   if ($907) {
    $923 = ___cxa_find_matching_catch(0|0)|0;
    $924 = tempRet0;
    ___clang_call_terminate($923);
    // unreachable;
   } else {
    $$4 = $$3;$$46 = $$35;$914 = $933;$928 = $932;
    label = 277;
   }
  }
 }
 if ((label|0) == 277) {
  $913 = ($914|0)==(0|0);
  if ($913) {
   $$5 = $$4;$$57 = $$46;$919 = $928;
  } else {
   $915 = HEAP32[628512>>2]|0;
   HEAP32[$25>>2] = $915;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$25+0>>2]|0;
   invoke_vii(2591,($914|0),($$byval_copy60|0));
   $916 = __THREW__; __THREW__ = 0;
   $917 = $916&1;
   if ($917) {
    $923 = ___cxa_find_matching_catch(0|0)|0;
    $924 = tempRet0;
    ___clang_call_terminate($923);
    // unreachable;
   } else {
    $$5 = $$4;$$57 = $$46;$919 = $928;
   }
  }
 }
 $918 = ($919|0)==(0|0);
 if ($918) {
  $$6 = $$5;$$68 = $$57;
  ___resumeException($$6|0);
  // unreachable;
 }
 $920 = HEAP32[628512>>2]|0;
 HEAP32[$26>>2] = $920;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy60+0>>2]=HEAP32[$26+0>>2]|0;
 invoke_vii(2591,($919|0),($$byval_copy60|0));
 $921 = __THREW__; __THREW__ = 0;
 $922 = $921&1;
 if ($922) {
  $923 = ___cxa_find_matching_catch(0|0)|0;
  $924 = tempRet0;
  ___clang_call_terminate($923);
  // unreachable;
 } else {
  $$6 = $$5;$$68 = $$57;
  ___resumeException($$6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN11UnityEngine9Animation27GetCurveCountForBindingTypeEj($targetType) {
 $targetType = $targetType|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($targetType|0)==(2);
 if ($0) {
  $$0 = 4;
 } else {
  $1 = $targetType & -3;
  $2 = ($1|0)==(1);
  $$ = $2 ? 3 : 1;
  $$0 = $$;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN13dynamic_arrayINSt3__14pairIN11UnityEngine9Animation14GenericBindingEPNS3_10BoundIndexEEELj4EE9push_backERKS7_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = $5 << 1;
  $9 = ($8|0)==(0);
  $10 = $9 ? 1 : $8;
  $11 = ($6>>>0)<($10>>>0);
  do {
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*20)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,765760,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*20)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,765760,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*20)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$1>>2]|0;
  $26 = $$pre$i;
 } else {
  $26 = $3;
 }
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($25*20)|0)|0);
 $29 = $t;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $28;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = (($t) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($27) + (($25*20)|0)|0) + 8|0);
 HEAP32[$41>>2] = $40;
 $42 = ((($27) + (($25*20)|0)|0) + 12|0);
 $43 = (($t) + 12|0);
 $44 = HEAPU16[$43>>1]|(HEAPU16[$43+2>>1]<<16);
 HEAP16[$42>>1]=$44&65535;HEAP16[$42+2>>1]=$44>>>16;
 $45 = (($t) + 16|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($27) + (($25*20)|0)|0) + 16|0);
 HEAP32[$47>>2] = $46;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EE9push_backERKS2_($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = $5 << 1;
  $9 = ($8|0)==(0);
  $10 = $9 ? 1 : $8;
  $11 = ($6>>>0)<($10>>>0);
  do {
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = $10 << 4;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,765760,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = $10 << 4;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,765760,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = $23 << 4;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$1>>2]|0;
  $26 = $$pre$i;
 } else {
  $26 = $3;
 }
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + ($25<<4)|0);
 $29 = $t;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $28;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = (($t) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($27) + ($25<<4)|0) + 8|0);
 HEAP32[$41>>2] = $40;
 $42 = ((($27) + ($25<<4)|0) + 12|0);
 $43 = (($t) + 12|0);
 $44 = HEAPU16[$43>>1]|(HEAPU16[$43+2>>1]<<16);
 HEAP16[$42>>1]=$44&65535;HEAP16[$42+2>>1]=$44>>>16;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$4);
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  ___cxa_call_unexpected(($7|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE4findIS4_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p = 0, $or$cond$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE13__lower_boundIS4_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SK_SK_($__p,$this,$__v,$1,$2);
 $3 = HEAP32[$__p>>2]|0;
 $4 = ($3|0)==($2|0);
 L1: do {
  if (!($4)) {
   $5 = (($3) + 16|0);
   $6 = (($__v) + 12|0);
   $7 = HEAP16[$6>>1]|0;
   $8 = ($7<<16>>16)==(4);
   $9 = (($3) + 28|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = ($10<<16>>16)==(4);
   $or$cond$i$i$i = $8 & $11;
   do {
    if ($or$cond$i$i$i) {
     $12 = (($__v) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($3) + 20|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($13|0)==($15|0);
     if ($16) {
      $18 = HEAP32[$__v>>2]|0;
      $19 = HEAP32[$5>>2]|0;
      $20 = ($18>>>0)<($19>>>0);
      if ($20) {
       break L1;
      } else {
       break;
      }
     } else {
      $17 = ($13>>>0)<($15>>>0);
      if ($17) {
       break L1;
      } else {
       break;
      }
     }
    } else {
     $21 = $7&65535;
     $$$i$i$i = $8 ? -1 : $21;
     $22 = $10&65535;
     $23 = $11 ? -1 : $22;
     $24 = ($$$i$i$i|0)==($23|0);
     if (!($24)) {
      $25 = ($$$i$i$i|0)<($23|0);
      if ($25) {
       break L1;
      } else {
       break;
      }
     }
     $26 = (($__v) + 15|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = (($3) + 31|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = ($27<<24>>24)==($29<<24>>24);
     if (!($30)) {
      $31 = ($27&255)<($29&255);
      if ($31) {
       break L1;
      } else {
       break;
      }
     }
     $32 = (($__v) + 14|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = (($3) + 30|0);
     $35 = HEAP8[$34>>0]|0;
     $36 = ($33<<24>>24)==($35<<24>>24);
     if (!($36)) {
      $37 = ($33&255)<($35&255);
      if ($37) {
       break L1;
      } else {
       break;
      }
     }
     $38 = HEAP32[$__v>>2]|0;
     $39 = HEAP32[$5>>2]|0;
     $40 = ($38|0)==($39|0);
     if (!($40)) {
      $41 = ($38>>>0)<($39>>>0);
      if ($41) {
       break L1;
      } else {
       break;
      }
     }
     $42 = (($__v) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($3) + 24|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($43|0)==($45|0);
     if ($46) {
      $48 = (($__v) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = (($3) + 20|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = ($49>>>0)<($51>>>0);
      if ($52) {
       break L1;
      } else {
       break;
      }
     } else {
      $47 = ($43|0)<($45|0);
      if ($47) {
       break L1;
      } else {
       break;
      }
     }
    }
   } while(0);
   HEAP32[$agg$result>>2] = $3;
   STACKTOP = sp;return;
  }
 } while(0);
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE13__lower_boundIS4_EENS_15__tree_iteratorIS6_PNS_11__tree_nodeIS6_PvEEiEERKT_SK_SK_($agg$result,$this,$__v,$__root,$__result) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 $__root = $__root|0;
 $__result = $__result|0;
 var $$$i$i$i = 0, $$0$ph6 = 0, $$0$ph9 = 0, $$01$lcssa2 = 0, $$01$ph8 = 0, $$013 = 0, $$013$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__root|0)==(0|0);
 if ($0) {
  $$0$ph6 = $__result;
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
 $1 = (($__v) + 12|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)==(4);
 $4 = (($__v) + 4|0);
 $5 = $2&65535;
 $6 = $3 ? -1 : $5;
 $7 = (($__v) + 15|0);
 $8 = (($__v) + 14|0);
 $9 = (($__v) + 8|0);
 $$0$ph9 = $__result;$$01$ph8 = $__root;
 L4: while(1) {
  L6: do {
   if ($3) {
    $$013$us = $$01$ph8;
    while(1) {
     $10 = (($$013$us) + 16|0);
     $11 = (($$013$us) + 28|0);
     $12 = HEAP16[$11>>1]|0;
     $13 = ($12<<16>>16)==(4);
     do {
      if ($13) {
       $40 = (($$013$us) + 20|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = HEAP32[$4>>2]|0;
       $43 = ($41|0)==($42|0);
       if ($43) {
        $45 = HEAP32[$10>>2]|0;
        $46 = HEAP32[$__v>>2]|0;
        $47 = ($45>>>0)<($46>>>0);
        if ($47) {
         break;
        } else {
         $$01$lcssa2 = $$013$us;
         break L6;
        }
       } else {
        $44 = ($41>>>0)<($42>>>0);
        if ($44) {
         break;
        } else {
         $$01$lcssa2 = $$013$us;
         break L6;
        }
       }
      } else {
       $14 = $12&65535;
       $15 = ($14|0)==($6|0);
       if (!($15)) {
        $16 = ($14|0)<($6|0);
        if ($16) {
         break;
        } else {
         $$01$lcssa2 = $$013$us;
         break L6;
        }
       }
       $17 = (($$013$us) + 31|0);
       $18 = HEAP8[$17>>0]|0;
       $19 = HEAP8[$7>>0]|0;
       $20 = ($18<<24>>24)==($19<<24>>24);
       if (!($20)) {
        $21 = ($18&255)<($19&255);
        if ($21) {
         break;
        } else {
         $$01$lcssa2 = $$013$us;
         break L6;
        }
       }
       $22 = (($$013$us) + 30|0);
       $23 = HEAP8[$22>>0]|0;
       $24 = HEAP8[$8>>0]|0;
       $25 = ($23<<24>>24)==($24<<24>>24);
       if (!($25)) {
        $26 = ($23&255)<($24&255);
        if ($26) {
         break;
        } else {
         $$01$lcssa2 = $$013$us;
         break L6;
        }
       }
       $27 = HEAP32[$10>>2]|0;
       $28 = HEAP32[$__v>>2]|0;
       $29 = ($27|0)==($28|0);
       if (!($29)) {
        $30 = ($27>>>0)<($28>>>0);
        if ($30) {
         break;
        } else {
         $$01$lcssa2 = $$013$us;
         break L6;
        }
       }
       $31 = (($$013$us) + 24|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = HEAP32[$9>>2]|0;
       $34 = ($32|0)==($33|0);
       if ($34) {
        $36 = (($$013$us) + 20|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = HEAP32[$4>>2]|0;
        $39 = ($37>>>0)<($38>>>0);
        if ($39) {
         break;
        } else {
         $$01$lcssa2 = $$013$us;
         break L6;
        }
       } else {
        $35 = ($32|0)<($33|0);
        if ($35) {
         break;
        } else {
         $$01$lcssa2 = $$013$us;
         break L6;
        }
       }
      }
     } while(0);
     $48 = (($$013$us) + 4|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0|0);
     if ($50) {
      $$0$ph6 = $$0$ph9;
      label = 33;
      break L4;
     } else {
      $$013$us = $49;
     }
    }
   } else {
    $$013 = $$01$ph8;
    while(1) {
     $51 = (($$013) + 28|0);
     $52 = HEAP16[$51>>1]|0;
     $53 = ($52<<16>>16)==(4);
     $54 = $52&65535;
     $$$i$i$i = $53 ? -1 : $54;
     $55 = ($$$i$i$i|0)==($6|0);
     do {
      if ($55) {
       $57 = (($$013) + 31|0);
       $58 = HEAP8[$57>>0]|0;
       $59 = HEAP8[$7>>0]|0;
       $60 = ($58<<24>>24)==($59<<24>>24);
       if (!($60)) {
        $61 = ($58&255)<($59&255);
        if ($61) {
         break;
        } else {
         $$01$lcssa2 = $$013;
         break L6;
        }
       }
       $62 = (($$013) + 30|0);
       $63 = HEAP8[$62>>0]|0;
       $64 = HEAP8[$8>>0]|0;
       $65 = ($63<<24>>24)==($64<<24>>24);
       if (!($65)) {
        $66 = ($63&255)<($64&255);
        if ($66) {
         break;
        } else {
         $$01$lcssa2 = $$013;
         break L6;
        }
       }
       $67 = (($$013) + 16|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = HEAP32[$__v>>2]|0;
       $70 = ($68|0)==($69|0);
       if (!($70)) {
        $71 = ($68>>>0)<($69>>>0);
        if ($71) {
         break;
        } else {
         $$01$lcssa2 = $$013;
         break L6;
        }
       }
       $72 = (($$013) + 24|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = HEAP32[$9>>2]|0;
       $75 = ($73|0)==($74|0);
       if ($75) {
        $77 = (($$013) + 20|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = HEAP32[$4>>2]|0;
        $80 = ($78>>>0)<($79>>>0);
        if ($80) {
         break;
        } else {
         $$01$lcssa2 = $$013;
         break L6;
        }
       } else {
        $76 = ($73|0)<($74|0);
        if ($76) {
         break;
        } else {
         $$01$lcssa2 = $$013;
         break L6;
        }
       }
      } else {
       $56 = ($$$i$i$i|0)<($6|0);
       if (!($56)) {
        $$01$lcssa2 = $$013;
        break L6;
       }
      }
     } while(0);
     $83 = (($$013) + 4|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ($84|0)==(0|0);
     if ($85) {
      $$0$ph6 = $$0$ph9;
      label = 33;
      break L4;
     } else {
      $$013 = $84;
     }
    }
   }
  } while(0);
  $81 = HEAP32[$$01$lcssa2>>2]|0;
  $82 = ($81|0)==(0|0);
  if ($82) {
   $$0$ph6 = $$01$lcssa2;
   label = 33;
   break;
  } else {
   $$0$ph9 = $$01$lcssa2;$$01$ph8 = $81;
  }
 }
 if ((label|0) == 33) {
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE15__insert_uniqueERKS6_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (__ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEESK_RKT_($this,$__parent,$__v)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $37 = 0;$__r$0 = $2;
  HEAP32[$agg$result>>2] = $__r$0;
  $36 = (($agg$result) + 4|0);
  HEAP8[$36>>0] = $37;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $4 = (__Z15malloc_internaljj10MemLabelIdiPKci(64,16,$$byval_copy,0,765760,79)|0);
 $5 = (($4) + 16|0);
 $6 = $__v;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $5;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($__v) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($4) + 24|0);
 HEAP32[$18>>2] = $17;
 $19 = (($4) + 28|0);
 $20 = (($__v) + 12|0);
 $21 = HEAPU16[$20>>1]|(HEAPU16[$20+2>>1]<<16);
 HEAP16[$19>>1]=$21&65535;HEAP16[$19+2>>1]=$21>>>16;
 $22 = (($4) + 32|0);
 $23 = (($__v) + 16|0);
 ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$23+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$23+20>>2]|0;HEAP32[$22+24>>2]=HEAP32[$23+24>>2]|0;HEAP32[$22+28>>2]=HEAP32[$23+28>>2]|0;
 $24 = HEAP32[$__parent>>2]|0;
 HEAP32[$4>>2] = 0;
 $25 = (($4) + 4|0);
 HEAP32[$25>>2] = 0;
 $26 = (($4) + 8|0);
 HEAP32[$26>>2] = $24;
 HEAP32[$1>>2] = $4;
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  $32 = $4;
 } else {
  HEAP32[$this>>2] = $28;
  $$pre$i = HEAP32[$1>>2]|0;
  $32 = $$pre$i;
 }
 $30 = (($this) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($31,$32);
 $33 = (($this) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + 1)|0;
 HEAP32[$33>>2] = $35;
 $37 = 1;$__r$0 = $4;
 HEAP32[$agg$result>>2] = $__r$0;
 $36 = (($agg$result) + 4|0);
 HEAP8[$36>>0] = $37;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE12__find_equalIS6_EERPNS_16__tree_node_baseIPvEESK_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$$i$i$i = 0, $$$i$i$i2 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $__nd$0$in = 0, $or$cond$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $89 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $89;
  $$0 = $89;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__v) + 12|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(4);
 $6 = (($__v) + 4|0);
 $7 = (($__v) + 15|0);
 $8 = (($__v) + 14|0);
 $9 = (($__v) + 8|0);
 $10 = $4&65535;
 $$$i$i$i2 = $5 ? -1 : $10;
 $__nd$0$in = $1;
 L5: while(1) {
  $11 = (($__nd$0$in) + 16|0);
  $12 = (($__nd$0$in) + 28|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = ($13<<16>>16)==(4);
  $or$cond$i$i$i1 = $5 & $14;
  do {
   if ($or$cond$i$i$i1) {
    $15 = HEAP32[$6>>2]|0;
    $16 = (($__nd$0$in) + 20|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($15|0)==($17|0);
    if ($18) {
     $20 = HEAP32[$__v>>2]|0;
     $21 = HEAP32[$11>>2]|0;
     $22 = ($20>>>0)<($21>>>0);
     if ($22) {
      label = 18;
      break;
     } else {
      label = 20;
      break;
     }
    } else {
     $19 = ($15>>>0)<($17>>>0);
     if ($19) {
      label = 18;
      break;
     } else {
      label = 21;
      break;
     }
    }
   } else {
    $23 = $13&65535;
    $24 = $14 ? -1 : $23;
    $25 = ($$$i$i$i2|0)==($24|0);
    if (!($25)) {
     $26 = ($$$i$i$i2|0)<($24|0);
     if ($26) {
      label = 18;
      break;
     } else {
      label = 24;
      break;
     }
    }
    $27 = HEAP8[$7>>0]|0;
    $28 = (($11) + 15|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = ($27<<24>>24)==($29<<24>>24);
    if (!($30)) {
     $31 = ($27&255)<($29&255);
     if ($31) {
      label = 18;
      break;
     } else {
      label = 20;
      break;
     }
    }
    $32 = HEAP8[$8>>0]|0;
    $33 = (($11) + 14|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($32<<24>>24)==($34<<24>>24);
    if (!($35)) {
     $36 = ($32&255)<($34&255);
     if ($36) {
      label = 18;
      break;
     } else {
      label = 20;
      break;
     }
    }
    $37 = HEAP32[$__v>>2]|0;
    $38 = HEAP32[$11>>2]|0;
    $39 = ($37|0)==($38|0);
    if (!($39)) {
     $40 = ($37>>>0)<($38>>>0);
     if ($40) {
      label = 18;
      break;
     } else {
      label = 20;
      break;
     }
    }
    $41 = HEAP32[$9>>2]|0;
    $42 = (($__nd$0$in) + 24|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($41|0)==($43|0);
    if ($44) {
     $46 = HEAP32[$6>>2]|0;
     $47 = (($__nd$0$in) + 20|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($46>>>0)<($48>>>0);
     if ($49) {
      label = 18;
      break;
     } else {
      label = 20;
      break;
     }
    } else {
     $45 = ($41|0)<($43|0);
     if ($45) {
      label = 18;
      break;
     } else {
      label = 20;
      break;
     }
    }
   }
  } while(0);
  if ((label|0) == 18) {
   label = 0;
   $50 = HEAP32[$__nd$0$in>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    label = 19;
    break;
   } else {
    $__nd$0$in = $50;
    continue;
   }
  }
  else if ((label|0) == 20) {
   label = 0;
   if ($or$cond$i$i$i1) {
    label = 21;
   } else {
    label = 24;
   }
  }
  do {
   if ((label|0) == 21) {
    label = 0;
    $52 = (($__nd$0$in) + 20|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = HEAP32[$6>>2]|0;
    $55 = ($53|0)==($54|0);
    if ($55) {
     $57 = HEAP32[$11>>2]|0;
     $58 = HEAP32[$__v>>2]|0;
     $59 = ($57>>>0)<($58>>>0);
     if ($59) {
      break;
     } else {
      label = 37;
      break L5;
     }
    } else {
     $56 = ($53>>>0)<($54>>>0);
     if ($56) {
      break;
     } else {
      label = 37;
      break L5;
     }
    }
   }
   else if ((label|0) == 24) {
    label = 0;
    $60 = $13&65535;
    $$$i$i$i = $14 ? -1 : $60;
    $61 = ($$$i$i$i|0)==($$$i$i$i2|0);
    if (!($61)) {
     $62 = ($$$i$i$i|0)<($$$i$i$i2|0);
     if ($62) {
      break;
     } else {
      label = 37;
      break L5;
     }
    }
    $63 = (($11) + 15|0);
    $64 = HEAP8[$63>>0]|0;
    $65 = HEAP8[$7>>0]|0;
    $66 = ($64<<24>>24)==($65<<24>>24);
    if (!($66)) {
     $67 = ($64&255)<($65&255);
     if ($67) {
      break;
     } else {
      label = 37;
      break L5;
     }
    }
    $68 = (($11) + 14|0);
    $69 = HEAP8[$68>>0]|0;
    $70 = HEAP8[$8>>0]|0;
    $71 = ($69<<24>>24)==($70<<24>>24);
    if (!($71)) {
     $72 = ($69&255)<($70&255);
     if ($72) {
      break;
     } else {
      label = 37;
      break L5;
     }
    }
    $73 = HEAP32[$11>>2]|0;
    $74 = HEAP32[$__v>>2]|0;
    $75 = ($73|0)==($74|0);
    if (!($75)) {
     $76 = ($73>>>0)<($74>>>0);
     if ($76) {
      break;
     } else {
      label = 37;
      break L5;
     }
    }
    $77 = (($__nd$0$in) + 24|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = HEAP32[$9>>2]|0;
    $80 = ($78|0)==($79|0);
    if ($80) {
     $82 = (($__nd$0$in) + 20|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = HEAP32[$6>>2]|0;
     $85 = ($83>>>0)<($84>>>0);
     if ($85) {
      break;
     } else {
      label = 37;
      break L5;
     }
    } else {
     $81 = ($78|0)<($79|0);
     if ($81) {
      break;
     } else {
      label = 37;
      break L5;
     }
    }
   }
  } while(0);
  $86 = (($__nd$0$in) + 4|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = ($87|0)==(0|0);
  if ($88) {
   label = 36;
   break;
  } else {
   $__nd$0$in = $87;
  }
 }
 if ((label|0) == 19) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 36) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $86;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 37) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN25RuntimeAnimatorControllerD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 HEAP32[$this>>2] = ((771736 + 8|0));
 __THREW__ = 0;
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $26 = (($this) + 64|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)>(-1);
   if ($28) {
    $29 = (($this) + 52|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($this) + 56|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$1>>2] = $32;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($30|0),($$byval_copy3|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $50 = ___cxa_find_matching_catch(0|0)|0;
     $51 = tempRet0;
     ___clang_call_terminate($50);
     // unreachable;
    } else {
     HEAP32[$29>>2] = 0;
     $$0 = $25;$$01 = $24;
     label = 14;
     break;
    }
   } else {
    $$0 = $25;$$01 = $24;
    label = 14;
   }
  } else {
   $6 = (($this) + 64|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)>(-1);
   do {
    if ($8) {
     $9 = (($this) + 52|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = (($this) + 56|0);
     $12 = HEAP32[$11>>2]|0;
     HEAP32[$3>>2] = $12;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
     invoke_vii(2591,($10|0),($$byval_copy3|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      $35 = ___cxa_find_matching_catch()|0;
      $36 = tempRet0;
      $$0 = $36;$$01 = $35;
      label = 14;
      break L1;
     } else {
      HEAP32[$9>>2] = 0;
      break;
     }
    }
   } while(0);
   $15 = (($this) + 44|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)>(-1);
   if (!($17)) {
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
   $18 = (($this) + 32|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 36|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$2>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($19|0),($$byval_copy3|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    $37 = ___cxa_find_matching_catch()|0;
    $38 = tempRet0;
    $$1 = $38;$$12 = $37;
    break;
   }
   HEAP32[$18>>2] = 0;
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 14) {
   $39 = (($this) + 44|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)>(-1);
   if ($41) {
    $42 = (($this) + 32|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($this) + 36|0);
    $45 = HEAP32[$44>>2]|0;
    HEAP32[$0>>2] = $45;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($43|0),($$byval_copy3|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     $50 = ___cxa_find_matching_catch(0|0)|0;
     $51 = tempRet0;
     ___clang_call_terminate($50);
     // unreachable;
    } else {
     HEAP32[$42>>2] = 0;
     $$1 = $$0;$$12 = $$01;
     break;
    }
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch(0|0)|0;
  $51 = tempRet0;
  ___clang_call_terminate($50);
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZN4PPtrI25RuntimeAnimatorControllerE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI25RuntimeAnimatorControllerE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI25RuntimeAnimatorControllerE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI25RuntimeAnimatorControllerE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,765768,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,765784,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,765768,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,765784,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN25RuntimeAnimatorControllerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN25RuntimeAnimatorControllerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorControllerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3689,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK25RuntimeAnimatorController21BuildCustomControllerERK13AnimationClipRN7mecanim6memory9AllocatorE($this,$clip,$allocator) {
 $this = $this|0;
 $clip = $clip|0;
 $allocator = $allocator|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZN6MotionC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((765800 + 8|0));
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = $this;
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 40|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 44|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 36|0);
 HEAP32[$6>>2] = 61;
 STACKTOP = sp;return;
}
function __ZN6Motion15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6Motion17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 __ZN8UserList5ClearEv($0);
 STACKTOP = sp;return;
}
function __ZN6Motion17NotifyObjectUsersERK17MessageIdentifier($this,$msg) {
 $this = $this|0;
 $msg = $msg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 __ZN8UserList11SendMessageERK17MessageIdentifier($0,$msg);
 STACKTOP = sp;return;
}
function __Z20RegisterClass_Motionv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(207,232,0,0,0);
 STACKTOP = sp;return;
}
function __ZN6Motion13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 HEAP8[$0>>0] = 12;
 $3 = (($0) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[765936+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[765936+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[765936+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[765936+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[765936+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[765936+5>>0]|0;
 $4 = (($0) + 7|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,207,130,($0|0),48,(2584|0),1,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN6Motion7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK6Motion25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 207;
}
function __ZN6MotionD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((765800 + 8|0));
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if (!($3)) {
  __ZN11NamedObjectD2Ev($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 36|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($5|0),($$byval_copy|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  HEAP32[$4>>2] = 0;
  __ZN11NamedObjectD2Ev($this);
  STACKTOP = sp;return;
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN6MotionD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((765800 + 8|0));
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 do {
  if ($3) {
   $4 = (($this) + 32|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 36|0);
   $7 = HEAP32[$6>>2]|0;
   HEAP32[$0>>2] = $7;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($5|0),($$byval_copy|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    HEAP32[$4>>2] = 0;
    break;
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch(0|0)|0;
    $15 = tempRet0;
    ___clang_call_terminate($14);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
 __ZdlPv($this);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN6Motion7AddUserER8UserList($this,$dependencies) {
 $this = $this|0;
 $dependencies = $dependencies|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 __ZN8UserList7AddUserERS_($dependencies,$0);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip13AwakeFromLoadE17AwakeFromLoadMode($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6Motion17NotifyObjectUsersERK17MessageIdentifier($this,566088);
 $0 = (($this) + 208|0);
 HEAPF32[$0>>2] = Math_fround(inf);
 $1 = (($this) + 212|0);
 HEAPF32[$1>>2] = Math_fround(-inf);
 $2 = HEAP32[766080>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 72|0);
 FUNCTION_TABLE_vii[$2 & 4095]($this,$4);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip16CheckConsistencyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip18CleanupMecanimDataEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 168|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 172|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $c$01$i = $4;
  while(1) {
   $6 = HEAP32[$c$01$i>>2]|0;
   $7 = HEAP32[628296>>2]|0;
   HEAP32[$0>>2] = $7;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($c$01$i,$$byval_copy2);
   $8 = ($6|0)==(0|0);
   if ($8) {
    break;
   } else {
    $c$01$i = $6;
   }
  }
 }
 HEAP32[$3>>2] = 0;
 $9 = (($this) + 60|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 64|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 188|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)>(-1);
 if ($13) {
  $14 = (($this) + 176|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 180|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$0>>2] = $17;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($15,$$byval_copy2);
  HEAP32[$14>>2] = 0;
 }
 $18 = (($this) + 184|0);
 HEAP32[$18>>2] = 0;
 HEAP32[$11>>2] = 0;
 $19 = (($this) + 204|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)>(-1);
 if (!($21)) {
  $26 = (($this) + 200|0);
  HEAP32[$26>>2] = 0;
  HEAP32[$19>>2] = 0;
  STACKTOP = sp;return;
 }
 $22 = (($this) + 192|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 196|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$0>>2] = $25;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($23,$$byval_copy2);
 HEAP32[$22>>2] = 0;
 $26 = (($this) + 200|0);
 HEAP32[$26>>2] = 0;
 HEAP32[$19>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip18HasAnimationEventsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)!=($3|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN13AnimationClip19FireAnimationEventsEffRN5Unity9ComponentEP17AnimatorStateInfoP16AnimatorClipInfob($this,$lastTime,$now,$source,$animatorStateInfo,$animatorClipInfo,$firstEval) {
 $this = $this|0;
 $lastTime = Math_fround($lastTime);
 $now = Math_fround($now);
 $source = $source|0;
 $animatorStateInfo = $animatorStateInfo|0;
 $animatorClipInfo = $animatorClipInfo|0;
 $firstEval = $firstEval|0;
 var $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $eventIter$02 = 0, $eventIter$02$us = 0, $eventIter1$010 = 0, $eventIter2$07 = 0, $or$cond$us = 0, $or$cond1 = 0, $or$cond1$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $lastTime == $now;
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 156|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 152|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = $lastTime < $now;
 $10 = ($7|0)>(0);
 if ($9) {
  if (!($10)) {
   STACKTOP = sp;return;
  }
  if ($firstEval) {
   $eventIter$02$us = 0;
  } else {
   $eventIter$02 = 0;
   while(1) {
    $21 = HEAP32[$3>>2]|0;
    $22 = (($21) + (($eventIter$02*56)|0)|0);
    $23 = Math_fround(HEAPF32[$22>>2]);
    $24 = !($23 > $lastTime);
    $25 = !($23 <= $now);
    $or$cond1 = $24 | $25;
    if (!($or$cond1)) {
     $26 = (($21) + (($eventIter$02*56)|0)|0);
     (__Z9FireEventR14AnimationEventRN5Unity9ComponentEP14AnimationStateP17AnimatorStateInfoP16AnimatorClipInfo($26,$source,0,$animatorStateInfo,$animatorClipInfo)|0);
    }
    $27 = (($eventIter$02) + 1)|0;
    $28 = ($27|0)<($8|0);
    if ($28) {
     $eventIter$02 = $27;
    } else {
     break;
    }
   }
   STACKTOP = sp;return;
  }
  while(1) {
   $11 = HEAP32[$3>>2]|0;
   $12 = (($11) + (($eventIter$02$us*56)|0)|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = !($13 >= $lastTime);
   $15 = !($13 <= $now);
   $or$cond$us = $14 | $15;
   if ($or$cond$us) {
    $16 = !($13 > $lastTime);
    $17 = !($13 <= $now);
    $or$cond1$us = $16 | $17;
    if (!($or$cond1$us)) {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    label = 0;
    $18 = (($11) + (($eventIter$02$us*56)|0)|0);
    (__Z9FireEventR14AnimationEventRN5Unity9ComponentEP14AnimationStateP17AnimatorStateInfoP16AnimatorClipInfo($18,$source,0,$animatorStateInfo,$animatorClipInfo)|0);
   }
   $19 = (($eventIter$02$us) + 1)|0;
   $20 = ($19|0)<($8|0);
   if ($20) {
    $eventIter$02$us = $19;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($10) {
   $30 = $4;$eventIter1$010 = 0;
  } else {
   STACKTOP = sp;return;
  }
  while(1) {
   $29 = (($30) + (($eventIter1$010*56)|0)|0);
   $31 = Math_fround(HEAPF32[$29>>2]);
   $32 = $31 > $lastTime;
   if ($32) {
    (__Z9FireEventR14AnimationEventRN5Unity9ComponentEP14AnimationStateP17AnimatorStateInfoP16AnimatorClipInfo($29,$source,0,$animatorStateInfo,$animatorClipInfo)|0);
   }
   $33 = (($eventIter1$010) + 1)|0;
   $34 = ($33|0)<($8|0);
   if (!($34)) {
    break;
   }
   $$pre19 = HEAP32[$3>>2]|0;
   $30 = $$pre19;$eventIter1$010 = $33;
  }
  if ($10) {
   $eventIter2$07 = 0;
  } else {
   STACKTOP = sp;return;
  }
  while(1) {
   $35 = HEAP32[$3>>2]|0;
   $36 = (($35) + (($eventIter2$07*56)|0)|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = $37 < $now;
   if ($38) {
    (__Z9FireEventR14AnimationEventRN5Unity9ComponentEP14AnimationStateP17AnimatorStateInfoP16AnimatorClipInfo($36,$source,0,$animatorStateInfo,$animatorClipInfo)|0);
   }
   $39 = (($eventIter2$07) + 1)|0;
   $40 = ($39|0)<($8|0);
   if ($40) {
    $eventIter2$07 = $39;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip15GetRuntimeAssetEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 172|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if (!($5)) {
   $$0 = $1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13AnimationClip13IsHumanMotionEv($this) {
 $this = $this|0;
 var $$0 = 0, $$02$i$i$i$i = 0, $$masked$i$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i$i = 0, $i$03$i$i$i$i = 0, $p$01$i$i$i = 0, $reflection$01$i$i$i$i = 0, $reflection$1$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $43 = $3;$6 = $1;
 }
 while(1) {
  $5 = (($6) + 24|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(95);
  if ($8) {
   $9 = (($6) + 12|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = $10 & 1;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    $15 = (($9) + 1|0);
    $23 = $15;
   } else {
    $13 = (($6) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $23 = $14;
   }
   $$02$i$i$i$i = -1;$i$03$i$i$i$i = 0;$reflection$01$i$i$i$i = 0;
   while(1) {
    $16 = $$02$i$i$i$i & 1;
    $17 = ($16|0)==(0);
    if ($17) {
     $reflection$1$i$i$i$i = $reflection$01$i$i$i$i;
    } else {
     $18 = (31 - ($i$03$i$i$i$i))|0;
     $19 = 1 << $18;
     $20 = $19 | $reflection$01$i$i$i$i;
     $reflection$1$i$i$i$i = $20;
    }
    $21 = (($i$03$i$i$i$i) + 1)|0;
    $22 = $$02$i$i$i$i >>> 1;
    $exitcond$i$i$i$i = ($21|0)==(32);
    if ($exitcond$i$i$i$i) {
     break;
    } else {
     $$02$i$i$i$i = $22;$i$03$i$i$i$i = $21;$reflection$01$i$i$i$i = $reflection$1$i$i$i$i;
    }
   }
   $24 = (_strlen(($23|0))|0);
   $25 = (($23) + ($24)|0);
   $26 = ($24|0)>(0);
   if ($26) {
    $30 = $reflection$1$i$i$i$i;$p$01$i$i$i = $23;
    while(1) {
     $27 = HEAP8[$p$01$i$i$i>>0]|0;
     $28 = $27&255;
     $29 = $30 >>> 8;
     $$masked$i$i$i = $30 & 255;
     $31 = $28 ^ $$masked$i$i$i;
     $32 = (584048 + ($31<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = $33 ^ $29;
     $35 = (($p$01$i$i$i) + 1|0);
     $exitcond$i$i$i = ($35|0)==($25|0);
     if ($exitcond$i$i$i) {
      $37 = $34;
      break;
     } else {
      $30 = $34;$p$01$i$i$i = $35;
     }
    }
   } else {
    $37 = $reflection$1$i$i$i$i;
   }
   $36 = $37 ^ -1;
   $38 = (__ZN7mecanim9animation15FindMuscleIndexEj($36)|0);
   $39 = ($38|0)>(13);
   if ($39) {
    $$0 = 1;
    label = 15;
    break;
   }
   $$pre = HEAP32[$2>>2]|0;
   $42 = $$pre;
  } else {
   $42 = $43;
  }
  $40 = (($6) + 116|0);
  $41 = ($40|0)==($42|0);
  if ($41) {
   $$0 = 0;
   label = 15;
   break;
  } else {
   $43 = $42;$6 = $40;
  }
 }
 if ((label|0) == 15) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK13AnimationClip17GetAnimationClipsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$agg$result>>2] = 0;
 $2 = (($agg$result) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($agg$result) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($agg$result) + 4|0);
 HEAP32[$4>>2] = 61;
 $5 = ($this|0)==(0|0);
 if ($5) {
  $15 = 0;
 } else {
  $6 = (($this) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $15 = $7;
 }
 HEAP32[$2>>2] = 1;
 HEAP32[$3>>2] = 1;
 HEAP32[$0>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $8 = (invoke_iiiiiiii(108,(0|0),4,4,($$byval_copy1|0),0,(766088|0),370)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  HEAP32[$agg$result>>2] = $8;
  HEAP32[$8>>2] = $15;
  STACKTOP = sp;return;
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 HEAP32[$1>>2] = 61;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,(0|0),($$byval_copy1|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  ___clang_call_terminate($16);
  // unreachable;
 } else {
  HEAP32[$agg$result>>2] = 0;
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZN13AnimationClip18GetAverageDurationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $8 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($8));
 }
 $3 = (($1) + 1052|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($1) + 1048|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = $7;
 STACKTOP = sp;return (Math_fround($8));
}
function __ZN13AnimationClip22GetAverageAngularSpeedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = Math_fround(0.0);
 } else {
  $3 = (($1) + 1068|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = $4;
 }
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN13AnimationClip15GetAverageSpeedEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$idx = 0, $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[616680+8>>2]|0;
  STACKTOP = sp;return;
 } else {
  $$idx = (($1) + 1024|0);
  $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
  $$idx1 = (($1) + 1028|0);
  $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
  $$idx2 = (($1) + 1032|0);
  $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
  HEAPF32[$agg$result>>2] = $$idx$val;
  $3 = (($agg$result) + 4|0);
  HEAPF32[$3>>2] = $$idx1$val;
  $4 = (($agg$result) + 8|0);
  HEAPF32[$4>>2] = $$idx2$val;
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip16GetApparentSpeedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = Math_fround(0), $3 = 0, $4 = Math_fround(0);
 var $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $pow2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($0,$this);
 $4 = Math_fround(HEAPF32[$0>>2]);
 $5 = Math_fround($4 * $4);
 $6 = (($0) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (($0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($11 * $11);
 $13 = Math_fround($9 + $12);
 $14 = (Math_fround(Math_sqrt((Math_fround($13)))));
 $15 = +$14;
 $16 = HEAP32[$this>>2]|0;
 $17 = (($16) + 96|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (Math_fround(FUNCTION_TABLE_fi[$18 & 255]($this)));
 $20 = Math_fround($19 * Math_fround(0.5));
 $21 = +$20;
 $pow2 = $21 * $21;
 $22 = $pow2 + 1.0;
 $23 = $15 * $22;
 $24 = Math_fround($23);
 STACKTOP = sp;return (Math_fround($24));
}
function __ZN13AnimationClip9IsLoopingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $6 = 0;
  STACKTOP = sp;return ($6|0);
 }
 $3 = (($1) + 1633|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = $5;
 STACKTOP = sp;return ($6|0);
}
function __ZN13AnimationClip17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $node$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = (($this) + 76|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if (!($3)) {
  $node$01$i = $2;
  while(1) {
   $4 = (($node$01$i) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   HEAP32[$node$01$i>>2] = 0;
   HEAP32[$4>>2] = 0;
   $6 = ($5|0)==($0|0);
   if ($6) {
    break;
   } else {
    $node$01$i = $5;
   }
  }
 }
 HEAP32[$1>>2] = $0;
 HEAP32[$0>>2] = $0;
 $7 = HEAP32[766080>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  FUNCTION_TABLE_vii[$7 & 4095](0,$0);
 }
 __ZN6Motion17NotifyObjectUsersERK17MessageIdentifier($this,566088);
 __ZN6Motion17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip8GetRangeEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$lcssa = Math_fround(0), $$lcssa10 = Math_fround(0), $$lcssa15 = Math_fround(0), $$lcssa20 = Math_fround(0), $$lcssa25 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0);
 var $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0);
 var $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0;
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $curRange = 0;
 var $curRange2 = 0, $curRange4 = 0, $curRange6 = 0, $or$cond = 0, $phitmp$i = 0, $range$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $range$sroa$1 = sp + 32|0;
 $curRange = sp;
 $curRange2 = sp + 8|0;
 $curRange4 = sp + 16|0;
 $curRange6 = sp + 24|0;
 HEAPF32[$range$sroa$1>>2] = Math_fround(-inf);
 $0 = (($this) + 208|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == Math_fround(inf);
 if ($2) {
  $3 = (($this) + 212|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $phitmp$i = $4 != Math_fround(-inf);
  if (!($phitmp$i)) {
   $15 = (($this) + 92|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($this) + 96|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)==($18|0);
   if ($19) {
    $$lcssa25 = Math_fround(inf);$148 = Math_fround(-inf);
   } else {
    $20 = (($curRange) + 4|0);
    $22 = $16;$25 = Math_fround(inf);$29 = Math_fround(-inf);
    while(1) {
     $21 = (($22) + 12|0);
     __ZNK17AnimationCurveTplI11QuaternionfE8GetRangeEv($curRange,$21);
     $23 = Math_fround(HEAPF32[$curRange>>2]);
     $24 = $25 < $23;
     $26 = $24 ? $25 : $23;
     $27 = Math_fround(HEAPF32[$20>>2]);
     $28 = $27 < $29;
     $30 = $28 ? $29 : $27;
     HEAPF32[$range$sroa$1>>2] = $30;
     $31 = (($22) + 192|0);
     $32 = HEAP32[$17>>2]|0;
     $33 = ($31|0)==($32|0);
     if ($33) {
      $$lcssa25 = $26;$148 = $30;
      break;
     } else {
      $22 = $31;$25 = $26;$29 = $30;
     }
    }
   }
   $34 = (($this) + 104|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($this) + 108|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($35|0)==($37|0);
   if ($38) {
    $$lcssa20 = $$lcssa25;$149 = $148;
   } else {
    $39 = (($curRange2) + 4|0);
    $41 = $35;$44 = $$lcssa25;$48 = $148;
    while(1) {
     $40 = (($41) + 12|0);
     __ZNK17AnimationCurveTplI8Vector3fE8GetRangeEv($curRange2,$40);
     $42 = Math_fround(HEAPF32[$curRange2>>2]);
     $43 = $44 < $42;
     $45 = $43 ? $44 : $42;
     $46 = Math_fround(HEAPF32[$39>>2]);
     $47 = $46 < $48;
     $49 = $47 ? $48 : $46;
     HEAPF32[$range$sroa$1>>2] = $49;
     $50 = (($41) + 160|0);
     $51 = HEAP32[$36>>2]|0;
     $52 = ($50|0)==($51|0);
     if ($52) {
      $$lcssa20 = $45;$149 = $49;
      break;
     } else {
      $41 = $50;$44 = $45;$48 = $49;
     }
    }
   }
   $53 = (($this) + 116|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($this) + 120|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($54|0)==($56|0);
   if ($57) {
    $$lcssa15 = $$lcssa20;$150 = $149;
   } else {
    $58 = (($curRange4) + 4|0);
    $60 = $54;$63 = $$lcssa20;$67 = $149;
    while(1) {
     $59 = (($60) + 12|0);
     __ZNK17AnimationCurveTplI8Vector3fE8GetRangeEv($curRange4,$59);
     $61 = Math_fround(HEAPF32[$curRange4>>2]);
     $62 = $63 < $61;
     $64 = $62 ? $63 : $61;
     $65 = Math_fround(HEAPF32[$58>>2]);
     $66 = $65 < $67;
     $68 = $66 ? $67 : $65;
     HEAPF32[$range$sroa$1>>2] = $68;
     $69 = (($60) + 160|0);
     $70 = HEAP32[$55>>2]|0;
     $71 = ($69|0)==($70|0);
     if ($71) {
      $$lcssa15 = $64;$150 = $68;
      break;
     } else {
      $60 = $69;$63 = $64;$67 = $68;
     }
    }
   }
   $72 = (($this) + 128|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($this) + 132|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($73|0)==($75|0);
   if ($76) {
    $$lcssa10 = $$lcssa15;$151 = $150;
   } else {
    $77 = (($curRange6) + 4|0);
    $79 = $73;$82 = $$lcssa15;$86 = $150;
    while(1) {
     $78 = (($79) + 32|0);
     __ZNK17AnimationCurveTplIfE8GetRangeEv($curRange6,$78);
     $80 = Math_fround(HEAPF32[$curRange6>>2]);
     $81 = $82 < $80;
     $83 = $81 ? $82 : $80;
     $84 = Math_fround(HEAPF32[$77>>2]);
     $85 = $84 < $86;
     $87 = $85 ? $86 : $84;
     HEAPF32[$range$sroa$1>>2] = $87;
     $88 = (($79) + 116|0);
     $89 = HEAP32[$74>>2]|0;
     $90 = ($88|0)==($89|0);
     if ($90) {
      $$lcssa10 = $83;$151 = $87;
      break;
     } else {
      $79 = $88;$82 = $83;$86 = $87;
     }
    }
   }
   $91 = (($this) + 140|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($this) + 144|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($92|0)==($94|0);
   if ($95) {
    $$lcssa = $$lcssa10;$129 = $151;
   } else {
    $96 = (($this) + 80|0);
    $105 = $$lcssa10;$114 = $151;$98 = $92;
    while(1) {
     $97 = (($98) + 40|0);
     $99 = HEAP32[$97>>2]|0;
     $100 = ($99|0)==(0);
     if ($100) {
      $152 = $114;$153 = $105;
     } else {
      $101 = (($98) + 32|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = Math_fround(HEAPF32[$102>>2]);
      $104 = $105 < $103;
      $106 = $104 ? $105 : $103;
      $107 = (($99) + -1)|0;
      $108 = (($102) + ($107<<3)|0);
      $109 = Math_fround(HEAPF32[$108>>2]);
      $110 = Math_fround(HEAPF32[$96>>2]);
      $111 = Math_fround(Math_fround(1.0) / $110);
      $112 = Math_fround($109 + $111);
      $113 = $112 < $114;
      $115 = $113 ? $114 : $112;
      HEAPF32[$range$sroa$1>>2] = $115;
      $152 = $115;$153 = $106;
     }
     $116 = (($98) + 48|0);
     $117 = ($116|0)==($94|0);
     if ($117) {
      $$lcssa = $153;$129 = $152;
      break;
     } else {
      $105 = $153;$114 = $152;$98 = $116;
     }
    }
   }
   $118 = (($this) + 152|0);
   $119 = HEAP32[$118>>2]|0;
   $120 = (($this) + 156|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = ($119|0)==($121|0);
   if ($122) {
    $133 = $$lcssa;$135 = $129;
   } else {
    $123 = Math_fround(HEAPF32[$119>>2]);
    $124 = $$lcssa < $123;
    $125 = $124 ? $$lcssa : $123;
    $126 = (($121) + -56|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = $127 < $129;
    $130 = $128 ? $range$sroa$1 : $126;
    $131 = Math_fround(HEAPF32[$130>>2]);
    HEAPF32[$range$sroa$1>>2] = $131;
    $133 = $125;$135 = $131;
   }
   $132 = $133 == Math_fround(inf);
   $134 = $135 == Math_fround(-inf);
   $or$cond = $132 & $134;
   if ($or$cond) {
    HEAPF32[$range$sroa$1>>2] = Math_fround(1.0);
    $136 = Math_fround(0.0);$137 = Math_fround(1.0);
   } else {
    $136 = $133;$137 = $135;
   }
   HEAPF32[$0>>2] = $136;
   HEAPF32[$3>>2] = $137;
   $138 = $0;
   $139 = $138;
   $140 = HEAP32[$139>>2]|0;
   $141 = (($138) + 4)|0;
   $142 = $141;
   $143 = HEAP32[$142>>2]|0;
   $144 = $agg$result;
   $145 = $144;
   HEAP32[$145>>2] = $140;
   $146 = (($144) + 4)|0;
   $147 = $146;
   HEAP32[$147>>2] = $143;
   STACKTOP = sp;return;
  }
 }
 $5 = $0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $agg$result;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 STACKTOP = sp;return;
}
function __Z27RegisterClass_AnimationClipv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(74,233,234,0,235);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(207)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN6Motion13RegisterClassEv();
 }
 $3 = (__Znwj(16)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 17;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 13;
 dest=$3+0|0; src=766096+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 13|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,74,207,($0|0),240,(2585|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z27RegisterAllowNameConversionPKcS0_S0_(766096,766120,766144);
 __Z27RegisterAllowNameConversionPKcS0_S0_(766096,766160,766184);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(240,$$byval_copy2,1,16,766088,134)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1998,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((765944 + 8|0));
  $6 = (($3) + 48|0);
  HEAP32[$6>>2] = ((768664 + 8|0));
  $7 = (($3) + 56|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 60|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 68|0);
  HEAP32[$9>>2] = 4096;
  $10 = (($3) + 52|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 72|0);
  $12 = (($3) + 76|0);
  HEAP32[$11>>2] = $11;
  HEAP32[$12>>2] = $11;
  $13 = (($3) + 85|0);
  HEAP8[$13>>0] = 1;
  $14 = (($3) + 92|0);
  $15 = (($3) + 168|0);
  HEAP32[$15>>2] = 0;
  $16 = (($3) + 172|0);
  HEAP32[$16>>2] = 0;
  $17 = (($3) + 176|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 184|0);
  HEAP32[$18>>2] = 0;
  $19 = (($3) + 188|0);
  HEAP32[$19>>2] = 0;
  $20 = (($3) + 180|0);
  dest=$14+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$14+72>>0]=0|0;
  HEAP32[$20>>2] = 61;
  $21 = (($3) + 192|0);
  HEAP32[$21>>2] = 0;
  $22 = (($3) + 200|0);
  HEAP32[$22>>2] = 0;
  $23 = (($3) + 204|0);
  HEAP32[$23>>2] = 0;
  $24 = (($3) + 196|0);
  HEAP32[$24>>2] = 61;
  $25 = (($3) + 208|0);
  $26 = (($3) + 216|0);
  $27 = (($3) + 228|0);
  ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;HEAP32[$25+16>>2]=0|0;HEAP32[$25+20>>2]=0|0;HEAP32[$25+24>>2]=0|0;HEAP32[$25+28>>2]=0|0;
  ;HEAP32[$26+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[616680+8>>2]|0;
  ;HEAP32[$27+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[616680+8>>2]|0;
  $28 = (($3) + 80|0);
  HEAPF32[$28>>2] = Math_fround(60.0);
  $29 = (($3) + 84|0);
  HEAP8[$29>>0] = 0;
  $30 = (($3) + 88|0);
  HEAP32[$30>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(766088|0),134);
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch(0|0)|0;
  $36 = tempRet0;
  ___clang_call_terminate($35);
  // unreachable;
 } else {
  ___resumeException($31|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK13AnimationClip25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 74;
}
function __ZN13AnimationClip23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766112,766096,$this,0);
 __ZN13AnimationClip8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766112,766096,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN13AnimationClip8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13AnimationClip8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13AnimationClip8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13AnimationClip8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13AnimationClip8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip14CompressCurvesERNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEE($this,$compressedRotationCurves) {
 $this = $this|0;
 $compressedRotationCurves = $compressedRotationCurves|0;
 var $$ = 0, $$not = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var $brmerge = 0, $didShowError$0$off06 = 0, $didShowError$1$off0 = 0, $i$05 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 92|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 192)&-1;
 $9 = (($compressedRotationCurves) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$compressedRotationCurves>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 84)&-1;
 $16 = ($15>>>0)<($8>>>0);
 L1: do {
  if ($16) {
   $17 = (($8) - ($15))|0;
   __ZNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE8__appendEj($compressedRotationCurves,$17);
   $$pre = HEAP32[$9>>2]|0;
   $23 = $$pre;
  } else {
   $18 = ($15>>>0)>($8>>>0);
   if ($18) {
    $19 = (($11) + (($8*84)|0)|0);
    $20 = ($10|0)==($19|0);
    if ($20) {
     $23 = $10;
    } else {
     $29 = $10;
     while(1) {
      $28 = (($29) + -84|0);
      HEAP32[$9>>2] = $28;
      __THREW__ = 0;
      invoke_vi(3690,($28|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $$pre$i = HEAP32[$9>>2]|0;
      $32 = ($$pre$i|0)==($19|0);
      if ($32) {
       $23 = $19;
       break L1;
      } else {
       $29 = $$pre$i;
      }
     }
     $33 = ___cxa_find_matching_catch()|0;
     $34 = tempRet0;
     ___cxa_call_unexpected(($33|0));
     // unreachable;
    }
   } else {
    $23 = $10;
   }
  }
 } while(0);
 $21 = HEAP32[$compressedRotationCurves>>2]|0;
 $22 = ($23|0)==($21|0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $24 = ($this|0)==(0|0);
 $25 = (($0) + 1|0);
 $26 = (($0) + 8|0);
 $27 = (($this) + 4|0);
 $36 = $21;$didShowError$0$off06 = 0;$i$05 = 0;
 while(1) {
  $35 = (($36) + (($i$05*84)|0)|0);
  $37 = HEAP32[$3>>2]|0;
  $38 = (($37) + (($i$05*192)|0)|0);
  __ZN24CompressedAnimationCurve17CompressQuatCurveERN13AnimationClip15QuaternionCurveE($35,$38);
  $39 = HEAP32[$3>>2]|0;
  $40 = ((($39) + (($i$05*192)|0)|0) + 172|0);
  $41 = HEAP32[$40>>2]|0;
  $$not = ($41|0)<(1);
  $brmerge = $$not | $didShowError$0$off06;
  if ($brmerge) {
   $didShowError$1$off0 = $didShowError$0$off06;
  } else {
   $42 = ((($39) + (($i$05*192)|0)|0) + 164|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = $44 < Math_fround(-9.99999974737875163555E-6);
   if ($45) {
    $46 = HEAP32[$this>>2]|0;
    $47 = (($46) + 32|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (FUNCTION_TABLE_ii[$48 & 4095]($this)|0);
    HEAP32[$vararg_buffer>>2] = $49;
    __Z6FormatPKcz($0,766208,$vararg_buffer);
    if ($24) {
     $55 = 0;
    } else {
     $50 = HEAP32[$27>>2]|0;
     $55 = $50;
    }
    $51 = HEAP8[$0>>0]|0;
    $52 = $51 & 1;
    $53 = ($52<<24>>24)==(0);
    $54 = HEAP32[$26>>2]|0;
    $$ = $53 ? $25 : $54;
    __THREW__ = 0;
    invoke_viiiiiiii(21,($$|0),0,(766088|0),1913,4,($55|0),0,(0|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = HEAP8[$0>>0]|0;
    $59 = $58 & 1;
    $60 = ($59<<24>>24)==(0);
    if ($60) {
     $didShowError$1$off0 = 1;
    } else {
     $61 = HEAP32[$26>>2]|0;
     __ZdlPv($61);
     $didShowError$1$off0 = 1;
    }
   } else {
    $didShowError$1$off0 = 0;
   }
  }
  $68 = (($i$05) + 1)|0;
  $69 = HEAP32[$9>>2]|0;
  $70 = HEAP32[$compressedRotationCurves>>2]|0;
  $71 = $69;
  $72 = $70;
  $73 = (($71) - ($72))|0;
  $74 = (($73|0) / 84)&-1;
  $75 = ($68>>>0)<($74>>>0);
  if ($75) {
   $36 = $70;$didShowError$0$off06 = $didShowError$1$off0;$i$05 = $68;
  } else {
   label = 20;
   break;
  }
 }
 if ((label|0) == 20) {
  STACKTOP = sp;return;
 }
 $62 = ___cxa_find_matching_catch()|0;
 $63 = tempRet0;
 $64 = HEAP8[$0>>0]|0;
 $65 = $64 & 1;
 $66 = ($65<<24>>24)==(0);
 if ($66) {
  ___resumeException($62|0);
  // unreachable;
 }
 $67 = HEAP32[$26>>2]|0;
 __ZdlPv($67);
 ___resumeException($62|0);
 // unreachable;
}
function __ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6resizeEj($this,$__sz) {
 $this = $this|0;
 $__sz = $__sz|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 192)&-1;
 $10 = ($9>>>0)<($__sz>>>0);
 if ($10) {
  $11 = (($__sz) - ($9))|0;
  __ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$11);
  STACKTOP = sp;return;
 }
 $12 = ($9>>>0)>($__sz>>>0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($5) + (($__sz*192)|0)|0);
 $14 = ($4|0)==($13|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $16 = $4;
 while(1) {
  $15 = (($16) + -192|0);
  HEAP32[$3>>2] = $15;
  $17 = (($16) + -16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)>(-1);
  if ($19) {
   $20 = (($16) + -28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($16) + -24|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$2>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($21|0),($$byval_copy2|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 13;
    break;
   }
   HEAP32[$20>>2] = 0;
  }
  $26 = HEAP8[$15>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if (!($28)) {
   $31 = (($16) + -184|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($32|0),($$byval_copy2|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 12;
    break;
   }
  }
  $29 = HEAP32[$3>>2]|0;
  $30 = ($29|0)==($13|0);
  if ($30) {
   label = 17;
   break;
  } else {
   $16 = $29;
  }
 }
 if ((label|0) == 12) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 }
 else if ((label|0) == 13) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  $39 = HEAP8[$15>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   ___cxa_call_unexpected(($37|0));
   // unreachable;
  }
  $42 = (($16) + -184|0);
  $43 = HEAP32[$42>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($43|0),($$byval_copy2|0));
  $44 = __THREW__; __THREW__ = 0;
  $45 = $44&1;
  if ($45) {
   $46 = ___cxa_find_matching_catch()|0;
   $47 = tempRet0;
   ___cxa_call_unexpected(($46|0));
   // unreachable;
  } else {
   ___cxa_call_unexpected(($37|0));
   // unreachable;
  }
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip24SetDidModifyClipCallbackEPFvPS_R4ListI8ListNodeI14AnimationStateEEE($callback) {
 $callback = $callback|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[766080>>2] = $callback;
 STACKTOP = sp;return;
}
function __ZN13AnimationClipD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13AnimationClipD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN13AnimationClipD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3691,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK13AnimationClip8IsLegacyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 164|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i813 = 0, $$0$i814 = 0, $$01$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i2 = 0, $$pre1$i = 0, $$pre1$i1 = 0, $$pre1$i69 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $__v = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 192)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $25 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
    $12 = (($11) + 16|0);
    HEAPF32[$12>>2] = Math_fround(inf);
    $13 = (($11) + 12|0);
    HEAP32[$13>>2] = 0;
    $14 = (($11) + 20|0);
    dest=$14+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $15 = (($11) + 92|0);
    HEAPF32[$15>>2] = Math_fround(inf);
    $16 = (($11) + 88|0);
    HEAP32[$16>>2] = 0;
    $17 = (($11) + 96|0);
    $18 = (($11) + 172|0);
    HEAP32[$18>>2] = 0;
    $19 = (($11) + 176|0);
    HEAP32[$19>>2] = 0;
    $20 = (($11) + 168|0);
    dest=$17+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$20>>2] = 61;
    $21 = (($11) + 184|0);
    HEAP32[$21>>2] = 2;
    $22 = (($11) + 180|0);
    HEAP32[$22>>2] = 2;
    $23 = (($11) + 188|0);
    HEAP32[$23>>2] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $25 = $$pre1$i;
   }
   $24 = (($25) + 192|0);
   HEAP32[$3>>2] = $24;
   $26 = (($$0$i) + -1)|0;
   $27 = ($26|0)==(0);
   if ($27) {
    break;
   } else {
    $$0$i = $26;$11 = $24;
   }
  }
  STACKTOP = sp;return;
 }
 $28 = (($this) + 8|0);
 $29 = HEAP32[$this>>2]|0;
 $30 = $29;
 $31 = (($6) - ($30))|0;
 $32 = (($31|0) / 192)&-1;
 $33 = (($32) + ($__n))|0;
 $34 = ($33|0)<(0);
 if ($34) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $35 = (($5) - ($30))|0;
 $36 = (($35|0) / 192)&-1;
 $37 = ($36>>>0)<(1073741823);
 if ($37) {
  $40 = $36 << 1;
  $41 = ($40>>>0)<($33>>>0);
  $42 = $41 ? $33 : $40;
  $43 = (($__v) + 12|0);
  HEAP32[$43>>2] = 0;
  $44 = (($__v) + 16|0);
  HEAP32[$44>>2] = $28;
  $45 = ($42|0)==(0);
  if ($45) {
   $$0$i814 = 0;$48 = 0;$53 = $43;
  } else {
   $$0$i813 = $42;$90 = $43;
   label = 10;
  }
 } else {
  $38 = (($__v) + 12|0);
  HEAP32[$38>>2] = 0;
  $39 = (($__v) + 16|0);
  HEAP32[$39>>2] = $28;
  $$0$i813 = 2147483647;$90 = $38;
  label = 10;
 }
 if ((label|0) == 10) {
  $46 = ($$0$i813*192)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $47 = (__Z15malloc_internaljj10MemLabelIdiPKci($46,16,$$byval_copy,0,766088,79)|0);
  $$0$i814 = $$0$i813;$48 = $47;$53 = $90;
 }
 HEAP32[$__v>>2] = $48;
 $49 = (($48) + (($32*192)|0)|0);
 $50 = (($__v) + 8|0);
 HEAP32[$50>>2] = $49;
 $51 = (($__v) + 4|0);
 HEAP32[$51>>2] = $49;
 $52 = (($48) + (($$0$i814*192)|0)|0);
 HEAP32[$53>>2] = $52;
 $$0$i4 = $__n;$$pre1$i69 = $49;
 while(1) {
  $54 = ($$pre1$i69|0)==(0|0);
  if ($54) {
   $68 = 0;
  } else {
   ;HEAP32[$$pre1$i69+0>>2]=0|0;HEAP32[$$pre1$i69+4>>2]=0|0;HEAP32[$$pre1$i69+8>>2]=0|0;
   $55 = (($$pre1$i69) + 16|0);
   HEAPF32[$55>>2] = Math_fround(inf);
   $56 = (($$pre1$i69) + 12|0);
   HEAP32[$56>>2] = 0;
   $57 = (($$pre1$i69) + 20|0);
   dest=$57+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $58 = (($$pre1$i69) + 92|0);
   HEAPF32[$58>>2] = Math_fround(inf);
   $59 = (($$pre1$i69) + 88|0);
   HEAP32[$59>>2] = 0;
   $60 = (($$pre1$i69) + 96|0);
   $61 = (($$pre1$i69) + 172|0);
   HEAP32[$61>>2] = 0;
   $62 = (($$pre1$i69) + 176|0);
   HEAP32[$62>>2] = 0;
   $63 = (($$pre1$i69) + 168|0);
   dest=$60+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$63>>2] = 61;
   $64 = (($$pre1$i69) + 184|0);
   HEAP32[$64>>2] = 2;
   $65 = (($$pre1$i69) + 180|0);
   HEAP32[$65>>2] = 2;
   $66 = (($$pre1$i69) + 188|0);
   HEAP32[$66>>2] = 0;
   $68 = $$pre1$i69;
  }
  $67 = (($68) + 192|0);
  $69 = (($$0$i4) + -1)|0;
  $70 = ($69|0)==(0);
  if ($70) {
   break;
  } else {
   $$0$i4 = $69;$$pre1$i69 = $67;
  }
 }
 HEAP32[$50>>2] = $67;
 $71 = HEAP32[$this>>2]|0;
 $72 = HEAP32[$3>>2]|0;
 $73 = ($72|0)==($71|0);
 $$pre1$i1 = HEAP32[$51>>2]|0;
 do {
  if ($73) {
   $82 = $$pre1$i1;$83 = $71;$84 = $67;$85 = $71;
  } else {
   $$01$i$i = $72;$75 = $$pre1$i1;
   while(1) {
    $74 = (($75) + -192|0);
    $76 = (($$01$i$i) + -192|0);
    __THREW__ = 0;
    invoke_vii(3367,($74|0),($76|0));
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     label = 21;
     break;
    }
    $79 = HEAP32[$51>>2]|0;
    $80 = (($79) + -192|0);
    HEAP32[$51>>2] = $80;
    $81 = ($76|0)==($71|0);
    if ($81) {
     label = 18;
     break;
    } else {
     $$01$i$i = $76;$75 = $80;
    }
   }
   if ((label|0) == 18) {
    $$pre$i2 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$3>>2]|0;
    $$pre12 = HEAP32[$50>>2]|0;
    $82 = $80;$83 = $$pre$i2;$84 = $$pre12;$85 = $$pre;
    break;
   }
   else if ((label|0) == 21) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    __ZNSt3__114__split_bufferIN13AnimationClip15QuaternionCurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
    ___resumeException($88|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $82;
 HEAP32[$51>>2] = $83;
 HEAP32[$3>>2] = $84;
 HEAP32[$50>>2] = $85;
 $86 = HEAP32[$1>>2]|0;
 $87 = HEAP32[$53>>2]|0;
 HEAP32[$1>>2] = $87;
 HEAP32[$53>>2] = $86;
 HEAP32[$__v>>2] = $83;
 __ZNSt3__114__split_bufferIN13AnimationClip15QuaternionCurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIN13AnimationClip15QuaternionCurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 L1: do {
  if (!($7)) {
   $9 = $6;
   while(1) {
    $8 = (($9) + -192|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)>(-1);
    if ($12) {
     $13 = (($9) + -28|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($9) + -24|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$2>>2] = $16;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($14|0),($$byval_copy3|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     HEAP32[$13>>2] = 0;
    }
    $19 = HEAP8[$8>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $24 = (($9) + -184|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy3|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 9;
      break;
     }
    }
    $22 = HEAP32[$5>>2]|0;
    $23 = ($22|0)==($4|0);
    if ($23) {
     break L1;
    } else {
     $9 = $22;
    }
   }
   if ((label|0) == 9) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   $32 = HEAP8[$8>>0]|0;
   $33 = $32 & 1;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   $35 = (($9) + -184|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($36|0),($$byval_copy3|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    ___cxa_call_unexpected(($39|0));
    // unreachable;
   } else {
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
  }
 } while(0);
 $41 = HEAP32[$this>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy3|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  ___cxa_call_unexpected(($45|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip15QuaternionCurveC2ERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy2 = 0, $$idx$i$i$i$i = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = HEAP8[$0>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $10 = (($0) + 1|0);
  $11 = $3&255;
  $12 = $11 >>> 1;
  $14 = $12;$25 = $10;
 } else {
  $6 = (($0) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($0) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $14 = $9;$25 = $7;
 }
 $13 = ($14>>>0)>(2147483631);
 if ($13) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $15 = ($14>>>0)<(11);
 if ($15) {
  $16 = $14 << 1;
  $17 = $16&255;
  HEAP8[$this>>0] = $17;
  $18 = (($this) + 1|0);
  $__p$0$i$i$i$i = $18;
 } else {
  $19 = (($14) + 16)|0;
  $20 = $19 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy2,0,766088,79)|0);
  $22 = (($this) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = $20 | 1;
  HEAP32[$this>>2] = $23;
  $24 = (($this) + 4|0);
  HEAP32[$24>>2] = $14;
  $__p$0$i$i$i$i = $21;
 }
 _memcpy(($__p$0$i$i$i$i|0),($25|0),($14|0))|0;
 $26 = (($__p$0$i$i$i$i) + ($14)|0);
 HEAP8[$26>>0] = 0;
 $27 = (($this) + 12|0);
 $28 = (($0) + 12|0);
 _memcpy(($27|0),($28|0),152)|0;
 $29 = (($0) + 168|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 168|0);
 HEAP32[$31>>2] = $30;
 $32 = (($this) + 172|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 176|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 164|0);
 HEAP32[$34>>2] = 0;
 $35 = (($0) + 164|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($0) + 172|0);
 $38 = HEAP32[$37>>2]|0;
 $$idx$i$i$i$i = ($38*52)|0;
 $39 = (($$idx$i$i$i$i|0) / 52)&-1;
 HEAP32[$32>>2] = $39;
 $40 = ($$idx$i$i$i$i|0)==(0);
 if ($40) {
  $45 = $39;$46 = 0;
  $44 = ($45*52)|0;
  _memcpy(($46|0),($36|0),($44|0))|0;
  $47 = (($this) + 180|0);
  $48 = (($0) + 180|0);
  $49 = $48;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $47;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = (($this) + 188|0);
  $60 = (($0) + 188|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$59>>2] = $61;
  STACKTOP = sp;return;
 }
 HEAP32[$33>>2] = $39;
 HEAP32[$2>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 $41 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i|0),4,($$byval_copy2|0),0,(766088|0),370)|0);
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if (!($43)) {
  HEAP32[$34>>2] = $41;
  $$pre$i$i$i = HEAP32[$32>>2]|0;
  $45 = $$pre$i$i$i;$46 = $41;
  $44 = ($45*52)|0;
  _memcpy(($46|0),($36|0),($44|0))|0;
  $47 = (($this) + 180|0);
  $48 = (($0) + 180|0);
  $49 = $48;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $47;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = (($this) + 188|0);
  $60 = (($0) + 188|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$59>>2] = $61;
  STACKTOP = sp;return;
 }
 $62 = ___cxa_find_matching_catch()|0;
 $63 = tempRet0;
 $64 = HEAP8[$this>>0]|0;
 $65 = $64 & 1;
 $66 = ($65<<24>>24)==(0);
 if ($66) {
  ___resumeException($62|0);
  // unreachable;
 }
 $67 = (($this) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($68|0),($$byval_copy2|0));
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  ___cxa_call_unexpected(($71|0));
  // unreachable;
 } else {
  ___resumeException($62|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i117 = 0, $$0$i118 = 0, $$0$i6 = 0, $$01$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i10 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 84)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $16 = 0;
   } else {
    $12 = (($11) + 8|0);
    HEAP32[$11>>2] = 0;
    $13 = (($11) + 4|0);
    HEAP8[$13>>0] = 0;
    $14 = (($11) + 52|0);
    dest=$12+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$12+40>>0]=0|0;
    ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;HEAP32[$14+12>>2]=0|0;HEAP32[$14+16>>2]=0|0;HEAP32[$14+20>>2]=0|0;HEAP32[$14+24>>2]=0|0;HEAP32[$14+28>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $16 = $$pre1$i;
   }
   $15 = (($16) + 84|0);
   HEAP32[$3>>2] = $15;
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$11 = $15;
   }
  }
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = $19;
 $21 = (($6) - ($20))|0;
 $22 = (($21|0) / 84)&-1;
 $23 = (($22) + ($__n))|0;
 $24 = ($23|0)<(0);
 if ($24) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $25 = (($5) - ($20))|0;
 $26 = (($25|0) / 84)&-1;
 $27 = ($26>>>0)<(1073741823);
 if ($27) {
  $28 = $26 << 1;
  $29 = ($28>>>0)<($23>>>0);
  $30 = $29 ? $23 : $28;
  $31 = ($30|0)==(0);
  if ($31) {
   $$0$i118 = 0;$35 = 0;
  } else {
   $$0$i117 = $30;
   label = 9;
  }
 } else {
  $$0$i117 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $32 = ($$0$i117*84)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,16,$$byval_copy2,0,766088,79)|0);
  $$0$i118 = $$0$i117;$35 = $33;
 }
 $34 = (($35) + (($22*84)|0)|0);
 $$0$i6 = $__n;$37 = $34;
 while(1) {
  $36 = ($37|0)==(0|0);
  if ($36) {
   $42 = 0;
  } else {
   $38 = (($37) + 8|0);
   HEAP32[$37>>2] = 0;
   $39 = (($37) + 4|0);
   HEAP8[$39>>0] = 0;
   $40 = (($37) + 52|0);
   dest=$38+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$38+40>>0]=0|0;
   ;HEAP32[$40+0>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;HEAP32[$40+16>>2]=0|0;HEAP32[$40+20>>2]=0|0;HEAP32[$40+24>>2]=0|0;HEAP32[$40+28>>2]=0|0;
   $42 = $37;
  }
  $41 = (($42) + 84|0);
  $43 = (($$0$i6) + -1)|0;
  $44 = ($43|0)==(0);
  if ($44) {
   break;
  } else {
   $$0$i6 = $43;$37 = $41;
  }
 }
 $45 = (($35) + (($$0$i118*84)|0)|0);
 $46 = HEAP32[$this>>2]|0;
 $47 = HEAP32[$3>>2]|0;
 $48 = ($47|0)==($46|0);
 do {
  if ($48) {
   $55 = $34;$58 = $46;$83 = $46;
  } else {
   $$01$i$i = $47;$50 = $34;
   while(1) {
    $49 = (($50) + -84|0);
    $51 = (($$01$i$i) + -84|0);
    __THREW__ = 0;
    invoke_vii(3368,($49|0),($51|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    $54 = ($51|0)==($46|0);
    if ($54) {
     label = 17;
     break;
    } else {
     $$01$i$i = $51;$50 = $49;
    }
   }
   if ((label|0) == 17) {
    $$pre$i10 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$3>>2]|0;
    $55 = $49;$58 = $$pre$i10;$83 = $$pre;
    break;
   }
   $69 = ___cxa_find_matching_catch()|0;
   $70 = tempRet0;
   $72 = $41;
   while(1) {
    $71 = ($72|0)==($50|0);
    if ($71) {
     break;
    }
    $73 = (($72) + -84|0);
    __THREW__ = 0;
    invoke_vi(3690,($73|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     label = 28;
     break;
    } else {
     $72 = $73;
    }
   }
   if ((label|0) == 28) {
    $76 = ___cxa_find_matching_catch()|0;
    $77 = tempRet0;
    ___cxa_call_unexpected(($76|0));
    // unreachable;
   }
   $78 = ($35|0)==(0|0);
   if ($78) {
    ___resumeException($69|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($35|0),($$byval_copy2|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    $81 = ___cxa_find_matching_catch()|0;
    $82 = tempRet0;
    ___cxa_call_unexpected(($81|0));
    // unreachable;
   } else {
    ___resumeException($69|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $55;
 HEAP32[$3>>2] = $41;
 HEAP32[$1>>2] = $45;
 $57 = $83;
 while(1) {
  $56 = ($57|0)==($58|0);
  if ($56) {
   break;
  }
  $59 = (($57) + -84|0);
  __THREW__ = 0;
  invoke_vi(3690,($59|0));
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if ($61) {
   label = 21;
   break;
  } else {
   $57 = $59;
  }
 }
 if ((label|0) == 21) {
  $62 = ___cxa_find_matching_catch()|0;
  $63 = tempRet0;
  ___cxa_call_unexpected(($62|0));
  // unreachable;
 }
 $64 = ($58|0)==(0|0);
 if ($64) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($58|0),($$byval_copy2|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  ___cxa_call_unexpected(($67|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN24CompressedAnimationCurveD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 72|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = (($this) + 80|0);
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($6|0),($$byval_copy|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   ___cxa_call_unexpected(($9|0));
   // unreachable;
  }
 }
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = (($this) + 56|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($12|0);
  if (!($16)) {
   HEAP32[$14>>2] = $12;
  }
  __ZdlPv($12);
 }
 $17 = (($this) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = (($this) + 28|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==($18|0);
  if (!($22)) {
   HEAP32[$20>>2] = $18;
  }
  __ZdlPv($18);
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==($24|0);
 if (!($28)) {
  HEAP32[$26>>2] = $24;
 }
 __ZdlPv($24);
 STACKTOP = sp;return;
}
function __ZN24CompressedAnimationCurveC2ERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$01$i$i$i$i$i = 0, $$01$i$i$i$i$i12 = 0, $$01$i$i$i$i$i4 = 0, $$1 = 0, $$12 = 0, $$byval_copy = 0, $$pre2$i$i$i$i$i = 0, $$pre2$i$i$i$i$i14 = 0, $$pre2$i$i$i$i$i6 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $1 = sp;
 ;HEAP32[$this+0>>2]=HEAP32[$0+0>>2]|0;HEAP8[$this+4>>0]=HEAP8[$0+4>>0]|0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($0) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($0) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = ($6|0)==($8|0);
 L1: do {
  if (!($12)) {
   $13 = ($11|0)<(0);
   if ($13) {
    __THREW__ = 0;
    invoke_vi(3308,0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     // unreachable;
    }
   } else {
    __THREW__ = 0;
    $16 = (invoke_ii(2988,($11|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     HEAP32[$3>>2] = $16;
     HEAP32[$2>>2] = $16;
     $19 = (($16) + ($11)|0);
     HEAP32[$4>>2] = $19;
     $20 = HEAP32[$7>>2]|0;
     $21 = HEAP32[$5>>2]|0;
     $22 = ($20|0)==($21|0);
     if ($22) {
      break;
     } else {
      $$01$i$i$i$i$i = $20;$24 = $16;
     }
     while(1) {
      $23 = ($24|0)==(0|0);
      if ($23) {
       $27 = 0;
      } else {
       $25 = HEAP8[$$01$i$i$i$i$i>>0]|0;
       HEAP8[$24>>0] = $25;
       $$pre2$i$i$i$i$i = HEAP32[$3>>2]|0;
       $27 = $$pre2$i$i$i$i$i;
      }
      $26 = (($27) + 1|0);
      HEAP32[$3>>2] = $26;
      $28 = (($$01$i$i$i$i$i) + 1|0);
      $29 = ($28|0)==($21|0);
      if ($29) {
       break L1;
      } else {
       $$01$i$i$i$i$i = $28;$24 = $26;
      }
     }
    }
   }
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   $32 = HEAP32[$2>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    ___resumeException($30|0);
    // unreachable;
   }
   $34 = HEAP32[$3>>2]|0;
   $35 = ($34|0)==($32|0);
   if (!($35)) {
    HEAP32[$3>>2] = $32;
   }
   __ZdlPv($32);
   ___resumeException($30|0);
   // unreachable;
  }
 } while(0);
 $36 = (($this) + 20|0);
 $37 = (($0) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$36>>2] = $38;
 $39 = (($this) + 24|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 28|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 32|0);
 HEAP32[$41>>2] = 0;
 $42 = (($0) + 28|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($0) + 24|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $43;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = ($43|0)==($45|0);
 L22: do {
  if ($49) {
   label = 28;
  } else {
   $50 = ($48|0)<(0);
   if ($50) {
    __THREW__ = 0;
    invoke_vi(3308,0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if (!($52)) {
     // unreachable;
    }
   } else {
    __THREW__ = 0;
    $53 = (invoke_ii(2988,($48|0))|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     HEAP32[$40>>2] = $53;
     HEAP32[$39>>2] = $53;
     $56 = (($53) + ($48)|0);
     HEAP32[$41>>2] = $56;
     $57 = HEAP32[$44>>2]|0;
     $58 = HEAP32[$42>>2]|0;
     $59 = ($57|0)==($58|0);
     if ($59) {
      label = 28;
      break;
     } else {
      $$01$i$i$i$i$i4 = $57;$61 = $53;
     }
     while(1) {
      $60 = ($61|0)==(0|0);
      if ($60) {
       $64 = 0;
      } else {
       $62 = HEAP8[$$01$i$i$i$i$i4>>0]|0;
       HEAP8[$61>>0] = $62;
       $$pre2$i$i$i$i$i6 = HEAP32[$40>>2]|0;
       $64 = $$pre2$i$i$i$i$i6;
      }
      $63 = (($64) + 1|0);
      HEAP32[$40>>2] = $63;
      $65 = (($$01$i$i$i$i$i4) + 1|0);
      $66 = ($65|0)==($58|0);
      if ($66) {
       label = 28;
       break L22;
      } else {
       $$01$i$i$i$i$i4 = $65;$61 = $63;
      }
     }
    }
   }
   $67 = ___cxa_find_matching_catch()|0;
   $68 = tempRet0;
   $69 = HEAP32[$39>>2]|0;
   $70 = ($69|0)==(0|0);
   if (!($70)) {
    $71 = HEAP32[$40>>2]|0;
    $72 = ($71|0)==($69|0);
    if (!($72)) {
     HEAP32[$40>>2] = $69;
    }
    __ZdlPv($69);
   }
   $$1 = $68;$$12 = $67;
  }
 } while(0);
 if ((label|0) == 28) {
  $73 = HEAP32[$37>>2]|0;
  HEAP32[$36>>2] = $73;
  $74 = (($this) + 36|0);
  $75 = (($0) + 36|0);
  ;HEAP32[$74+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$75+8>>2]|0;HEAP8[$74+12>>0]=HEAP8[$75+12>>0]|0;
  $76 = (($this) + 52|0);
  HEAP32[$76>>2] = 0;
  $77 = (($this) + 56|0);
  HEAP32[$77>>2] = 0;
  $78 = (($this) + 60|0);
  HEAP32[$78>>2] = 0;
  $79 = (($0) + 56|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($0) + 52|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = $80;
  $84 = $82;
  $85 = (($83) - ($84))|0;
  $86 = ($80|0)==($82|0);
  L43: do {
   if ($86) {
    label = 41;
   } else {
    $87 = ($85|0)<(0);
    if ($87) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if (!($89)) {
      // unreachable;
     }
    } else {
     __THREW__ = 0;
     $90 = (invoke_ii(2988,($85|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      HEAP32[$77>>2] = $90;
      HEAP32[$76>>2] = $90;
      $93 = (($90) + ($85)|0);
      HEAP32[$78>>2] = $93;
      $94 = HEAP32[$81>>2]|0;
      $95 = HEAP32[$79>>2]|0;
      $96 = ($94|0)==($95|0);
      if ($96) {
       label = 41;
       break;
      } else {
       $$01$i$i$i$i$i12 = $94;$98 = $90;
      }
      while(1) {
       $97 = ($98|0)==(0|0);
       if ($97) {
        $101 = 0;
       } else {
        $99 = HEAP8[$$01$i$i$i$i$i12>>0]|0;
        HEAP8[$98>>0] = $99;
        $$pre2$i$i$i$i$i14 = HEAP32[$77>>2]|0;
        $101 = $$pre2$i$i$i$i$i14;
       }
       $100 = (($101) + 1|0);
       HEAP32[$77>>2] = $100;
       $102 = (($$01$i$i$i$i$i12) + 1|0);
       $103 = ($102|0)==($95|0);
       if ($103) {
        label = 41;
        break L43;
       } else {
        $$01$i$i$i$i$i12 = $102;$98 = $100;
       }
      }
     }
    }
    $104 = ___cxa_find_matching_catch()|0;
    $105 = tempRet0;
    $106 = HEAP32[$76>>2]|0;
    $107 = ($106|0)==(0|0);
    if (!($107)) {
     $108 = HEAP32[$77>>2]|0;
     $109 = ($108|0)==($106|0);
     if (!($109)) {
      HEAP32[$77>>2] = $106;
     }
     __ZdlPv($106);
    }
    $$0 = $105;$$01 = $104;
   }
  } while(0);
  if ((label|0) == 41) {
   $110 = (($this) + 64|0);
   $111 = (($0) + 64|0);
   $112 = $111;
   $113 = $112;
   $114 = HEAP32[$113>>2]|0;
   $115 = (($112) + 4)|0;
   $116 = $115;
   $117 = HEAP32[$116>>2]|0;
   $118 = $110;
   $119 = $118;
   HEAP32[$119>>2] = $114;
   $120 = (($118) + 4)|0;
   $121 = $120;
   HEAP32[$121>>2] = $117;
   $122 = (($this) + 72|0);
   $123 = (($0) + 72|0);
   $124 = HEAP8[$123>>0]|0;
   $125 = $124 & 1;
   $126 = ($125<<24>>24)==(0);
   if ($126) {
    $131 = (($123) + 1|0);
    $132 = $124&255;
    $133 = $132 >>> 1;
    $135 = $133;$150 = $131;
   } else {
    $127 = (($0) + 80|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = (($0) + 76|0);
    $130 = HEAP32[$129>>2]|0;
    $135 = $130;$150 = $128;
   }
   $134 = ($135>>>0)>(2147483631);
   if ($134) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if (!($137)) {
     // unreachable;
    }
   } else {
    $138 = ($135>>>0)<(11);
    if ($138) {
     $139 = $135 << 1;
     $140 = $139&255;
     HEAP8[$122>>0] = $140;
     $141 = (($122) + 1|0);
     $__p$0$i$i$i$i = $141;
     _memcpy(($__p$0$i$i$i$i|0),($150|0),($135|0))|0;
     $151 = (($__p$0$i$i$i$i) + ($135)|0);
     HEAP8[$151>>0] = 0;
     STACKTOP = sp;return;
    }
    $142 = (($135) + 16)|0;
    $143 = $142 & -16;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
    $144 = (invoke_iiiiiii(102,($143|0),16,($$byval_copy|0),0,(766088|0),79)|0);
    $145 = __THREW__; __THREW__ = 0;
    $146 = $145&1;
    if (!($146)) {
     $147 = (($this) + 80|0);
     HEAP32[$147>>2] = $144;
     $148 = $143 | 1;
     HEAP32[$122>>2] = $148;
     $149 = (($this) + 76|0);
     HEAP32[$149>>2] = $135;
     $__p$0$i$i$i$i = $144;
     _memcpy(($__p$0$i$i$i$i|0),($150|0),($135|0))|0;
     $151 = (($__p$0$i$i$i$i) + ($135)|0);
     HEAP8[$151>>0] = 0;
     STACKTOP = sp;return;
    }
   }
   $152 = ___cxa_find_matching_catch()|0;
   $153 = tempRet0;
   $154 = HEAP32[$76>>2]|0;
   $155 = ($154|0)==(0|0);
   if ($155) {
    $$0 = $153;$$01 = $152;
   } else {
    $156 = HEAP32[$77>>2]|0;
    $157 = ($156|0)==($154|0);
    if (!($157)) {
     HEAP32[$77>>2] = $154;
    }
    __ZdlPv($154);
    $$0 = $153;$$01 = $152;
   }
  }
  $158 = HEAP32[$39>>2]|0;
  $159 = ($158|0)==(0|0);
  if ($159) {
   $$1 = $$0;$$12 = $$01;
  } else {
   $160 = HEAP32[$40>>2]|0;
   $161 = ($160|0)==($158|0);
   if (!($161)) {
    HEAP32[$40>>2] = $158;
   }
   __ZdlPv($158);
   $$1 = $$0;$$12 = $$01;
  }
 }
 $162 = HEAP32[$2>>2]|0;
 $163 = ($162|0)==(0|0);
 if ($163) {
  ___resumeException($$12|0);
  // unreachable;
 }
 $164 = HEAP32[$3>>2]|0;
 $165 = ($164|0)==($162|0);
 if (!($165)) {
  HEAP32[$3>>2] = $162;
 }
 __ZdlPv($162);
 ___resumeException($$12|0);
 // unreachable;
}
function __ZN13AnimationClip8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $empty1 = 0, $i$01$i$i$i$i$i$i = 0, $i$01$i$i$i2$i$i$i = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1680|0;
 $$byval_copy1 = sp + 28|0;
 $0 = sp;
 $empty1 = sp + 4|0;
 $value = sp + 16|0;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $1 = (($this) + 84|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
   __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
   __THREW__ = 0;
   invoke_vii(2669,($transfer|0),1);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3458,($transfer|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     break;
    }
   }
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   $$1 = $9;$$12 = $8;
   ___resumeException($$12|0);
   // unreachable;
  } else {
   HEAP32[$empty1>>2] = 0;
   $10 = (($empty1) + 4|0);
   HEAP32[$10>>2] = 0;
   $11 = (($empty1) + 8|0);
   HEAP32[$11>>2] = 0;
   __THREW__ = 0;
   invoke_vii(2669,($transfer|0),1);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   L3: do {
    if ($13) {
     label = 9;
    } else {
     __THREW__ = 0;
     invoke_vi(3458,($transfer|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      label = 9;
     } else {
      $16 = HEAP32[$transfer>>2]|0;
      $17 = $16 & 33554432;
      $18 = ($17|0)==(0);
      do {
       if ($18) {
        HEAP32[$value>>2] = 0;
        $19 = (($value) + 4|0);
        HEAP32[$19>>2] = 0;
        $20 = (($value) + 8|0);
        HEAP32[$20>>2] = 0;
        __THREW__ = 0;
        invoke_vii(3369,($this|0),($value|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         invoke_vii(2669,($transfer|0),1);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          __THREW__ = 0;
          invoke_vi(3458,($transfer|0));
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if (!($44)) {
           $45 = HEAP32[$value>>2]|0;
           $46 = ($45|0)==(0|0);
           if ($46) {
            break;
           }
           while(1) {
            $47 = HEAP32[$19>>2]|0;
            $48 = ($47|0)==($45|0);
            if ($48) {
             break;
            }
            $49 = (($47) + -84|0);
            HEAP32[$19>>2] = $49;
            __THREW__ = 0;
            invoke_vi(3690,($49|0));
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if ($51) {
             label = 21;
             break;
            }
           }
           if ((label|0) == 21) {
            $52 = ___cxa_find_matching_catch()|0;
            $53 = tempRet0;
            ___cxa_call_unexpected(($52|0));
            // unreachable;
           }
           $54 = HEAP32[$value>>2]|0;
           HEAP32[$0>>2] = 18;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
           invoke_vii(2591,($54|0),($$byval_copy1|0));
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if (!($56)) {
            break;
           }
           $57 = ___cxa_find_matching_catch()|0;
           $58 = tempRet0;
           ___cxa_call_unexpected(($57|0));
           // unreachable;
          }
         }
        }
        $25 = ___cxa_find_matching_catch()|0;
        $26 = tempRet0;
        $27 = HEAP32[$value>>2]|0;
        $28 = ($27|0)==(0|0);
        if ($28) {
         $$0 = $26;$$01 = $25;
         break L3;
        }
        while(1) {
         $29 = HEAP32[$19>>2]|0;
         $30 = ($29|0)==($27|0);
         if ($30) {
          break;
         }
         $31 = (($29) + -84|0);
         HEAP32[$19>>2] = $31;
         __THREW__ = 0;
         invoke_vi(3690,($31|0));
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          label = 13;
          break;
         }
        }
        if ((label|0) == 13) {
         $34 = ___cxa_find_matching_catch()|0;
         $35 = tempRet0;
         ___cxa_call_unexpected(($34|0));
         // unreachable;
        }
        $36 = HEAP32[$value>>2]|0;
        HEAP32[$0>>2] = 18;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($36|0),($$byval_copy1|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $$0 = $26;$$01 = $25;
         break L3;
        }
        $39 = ___cxa_find_matching_catch()|0;
        $40 = tempRet0;
        ___cxa_call_unexpected(($39|0));
        // unreachable;
       }
      } while(0);
      __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
      break L1;
     }
    }
   } while(0);
   if ((label|0) == 9) {
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    $$0 = $24;$$01 = $23;
   }
   __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
   $$1 = $$0;$$12 = $$01;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
 $59 = (($this) + 128|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($this) + 132|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($60|0)==($62|0);
 if (!($63)) {
  $64 = (($transfer) + 12|0);
  $65 = (($transfer) + 28|0);
  $66 = (($transfer) + 32|0);
  $68 = $60;
  while(1) {
   $67 = (($68) + 28|0);
   $69 = HEAP32[$67>>2]|0;
   $70 = HEAP32[$64>>2]|0;
   $71 = HEAP32[$70>>2]|0;
   $72 = HEAP32[$71>>2]|0;
   $73 = HEAP32[$65>>2]|0;
   $74 = (FUNCTION_TABLE_iiii[$72 & 2047]($70,$69,$73)|0);
   $75 = HEAP8[$66>>0]|0;
   $76 = ($75<<24>>24)==(0);
   if (!($76)) {
    HEAP32[$67>>2] = $74;
   }
   $77 = (($68) + 116|0);
   $78 = ($77|0)==($62|0);
   if ($78) {
    break;
   } else {
    $68 = $77;
   }
  }
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 $79 = (($this) + 140|0);
 __ZN17RemapPPtrTransfer8TransferINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags($transfer,$79,0,1);
 $80 = (($this) + 48|0);
 $81 = (($transfer) + 4|0);
 HEAP32[$81>>2] = $80;
 __ZN7mecanim5human9HumanPoseC2Ev($$byval_copy1);
 $82 = (($this) + 176|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($this) + 184|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($83) + ($85<<4)|0);
 $87 = ($85|0)==(0);
 if (!($87)) {
  $88 = (($transfer) + 12|0);
  $89 = (($transfer) + 28|0);
  $90 = (($transfer) + 32|0);
  $i$01$i$i$i$i$i$i = $83;
  while(1) {
   $91 = (($i$01$i$i$i$i$i$i) + 8|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = HEAP32[$88>>2]|0;
   $94 = HEAP32[$93>>2]|0;
   $95 = HEAP32[$94>>2]|0;
   $96 = HEAP32[$89>>2]|0;
   $97 = (FUNCTION_TABLE_iiii[$95 & 2047]($93,$92,$96)|0);
   $98 = HEAP8[$90>>0]|0;
   $99 = ($98<<24>>24)==(0);
   if (!($99)) {
    HEAP32[$91>>2] = $97;
   }
   $100 = (($i$01$i$i$i$i$i$i) + 16|0);
   $101 = ($100|0)==($86|0);
   if ($101) {
    break;
   } else {
    $i$01$i$i$i$i$i$i = $100;
   }
  }
 }
 $102 = (($this) + 192|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($this) + 200|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($103) + ($105<<2)|0);
 $107 = ($105|0)==(0);
 if (!($107)) {
  $108 = (($transfer) + 12|0);
  $109 = (($transfer) + 28|0);
  $110 = (($transfer) + 32|0);
  $i$01$i$i$i2$i$i$i = $103;
  while(1) {
   $111 = HEAP32[$i$01$i$i$i2$i$i$i>>2]|0;
   $112 = HEAP32[$108>>2]|0;
   $113 = HEAP32[$112>>2]|0;
   $114 = HEAP32[$113>>2]|0;
   $115 = HEAP32[$109>>2]|0;
   $116 = (FUNCTION_TABLE_iiii[$114 & 2047]($112,$111,$115)|0);
   $117 = HEAP8[$110>>0]|0;
   $118 = ($117<<24>>24)==(0);
   if (!($118)) {
    HEAP32[$i$01$i$i$i2$i$i$i>>2] = $116;
   }
   $119 = (($i$01$i$i$i2$i$i$i) + 4|0);
   $120 = ($119|0)==($106|0);
   if ($120) {
    break;
   } else {
    $i$01$i$i$i2$i$i$i = $119;
   }
  }
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
 $121 = (($this) + 152|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = (($this) + 156|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = ($122|0)==($124|0);
 if ($125) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  STACKTOP = sp;return;
 } else {
  $126 = $122;
 }
 while(1) {
  __ZN14AnimationEvent8TransferI17RemapPPtrTransferEEvRT_($126,$transfer);
  $127 = (($126) + 56|0);
  $128 = ($127|0)==($124|0);
  if ($128) {
   break;
  } else {
   $126 = $127;
  }
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN17RemapPPtrTransfer8TransferINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $metaFlag = $metaFlag|0;
 var $$pre$i$i$i$i = 0, $$pre$i$i$i$i1 = 0, $$pre1$i$i$i$i = 0, $$pre1$i$i$i$i2 = 0, $$pre3$i$i$i$i = 0, $$pre3$i$i$i$i3 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i$i$i$i = 0, $i$01$i$i$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = ($metaFlag|0)==(0);
 if ($1) {
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($35|0)==($37|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  $$pre$i$i$i$i = (($this) + 12|0);
  $$pre1$i$i$i$i = (($this) + 28|0);
  $$pre3$i$i$i$i = (($this) + 32|0);
  $40 = $35;
  while(1) {
   $39 = (($40) + 32|0);
   $41 = HEAP32[$39>>2]|0;
   $42 = (($40) + 40|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + ($43<<3)|0);
   $45 = ($43|0)==(0);
   if (!($45)) {
    $i$01$i$i$i$i$i$i$i = $41;
    while(1) {
     $46 = (($i$01$i$i$i$i$i$i$i) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = HEAP32[$$pre$i$i$i$i>>2]|0;
     $49 = HEAP32[$48>>2]|0;
     $50 = HEAP32[$49>>2]|0;
     $51 = HEAP32[$$pre1$i$i$i$i>>2]|0;
     $52 = (FUNCTION_TABLE_iiii[$50 & 2047]($48,$47,$51)|0);
     $53 = HEAP8[$$pre3$i$i$i$i>>0]|0;
     $54 = ($53<<24>>24)==(0);
     if (!($54)) {
      HEAP32[$46>>2] = $52;
     }
     $55 = (($i$01$i$i$i$i$i$i$i) + 8|0);
     $56 = ($55|0)==($44|0);
     if ($56) {
      break;
     } else {
      $i$01$i$i$i$i$i$i$i = $55;
     }
    }
   }
   $57 = (($40) + 28|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = HEAP32[$$pre$i$i$i$i>>2]|0;
   $60 = HEAP32[$59>>2]|0;
   $61 = HEAP32[$60>>2]|0;
   $62 = HEAP32[$$pre1$i$i$i$i>>2]|0;
   $63 = (FUNCTION_TABLE_iiii[$61 & 2047]($59,$58,$62)|0);
   $64 = HEAP8[$$pre3$i$i$i$i>>0]|0;
   $65 = ($64<<24>>24)==(0);
   if (!($65)) {
    HEAP32[$57>>2] = $63;
   }
   $66 = (($40) + 48|0);
   $67 = ($66|0)==($37|0);
   if ($67) {
    break;
   } else {
    $40 = $66;
   }
  }
  STACKTOP = sp;return;
 } else {
  __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($this,$metaFlag);
  $2 = HEAP32[$data>>2]|0;
  $3 = (($data) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($2|0)==($4|0);
  if (!($5)) {
   $$pre$i$i$i$i1 = (($this) + 12|0);
   $$pre1$i$i$i$i2 = (($this) + 28|0);
   $$pre3$i$i$i$i3 = (($this) + 32|0);
   $7 = $2;
   while(1) {
    $6 = (($7) + 32|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = (($7) + 40|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($8) + ($10<<3)|0);
    $12 = ($10|0)==(0);
    if (!($12)) {
     $i$01$i$i$i$i$i$i$i6 = $8;
     while(1) {
      $13 = (($i$01$i$i$i$i$i$i$i6) + 4|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = HEAP32[$$pre$i$i$i$i1>>2]|0;
      $16 = HEAP32[$15>>2]|0;
      $17 = HEAP32[$16>>2]|0;
      $18 = HEAP32[$$pre1$i$i$i$i2>>2]|0;
      $19 = (FUNCTION_TABLE_iiii[$17 & 2047]($15,$14,$18)|0);
      $20 = HEAP8[$$pre3$i$i$i$i3>>0]|0;
      $21 = ($20<<24>>24)==(0);
      if (!($21)) {
       HEAP32[$13>>2] = $19;
      }
      $22 = (($i$01$i$i$i$i$i$i$i6) + 8|0);
      $23 = ($22|0)==($11|0);
      if ($23) {
       break;
      } else {
       $i$01$i$i$i$i$i$i$i6 = $22;
      }
     }
    }
    $24 = (($7) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$$pre$i$i$i$i1>>2]|0;
    $27 = HEAP32[$26>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$$pre1$i$i$i$i2>>2]|0;
    $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$25,$29)|0);
    $31 = HEAP8[$$pre3$i$i$i$i3>>0]|0;
    $32 = ($31<<24>>24)==(0);
    if (!($32)) {
     HEAP32[$24>>2] = $30;
    }
    $33 = (($7) + 48|0);
    $34 = ($33|0)==($4|0);
    if ($34) {
     break;
    } else {
     $7 = $33;
    }
   }
  }
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim6memory16ChainedAllocator7ReserveEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($size|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 $6 = (($size) + 27)|0;
 if ($5) {
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $7 = (__Z15malloc_internaljj10MemLabelIdiPKci($6,16,$$byval_copy1,0,766088,549)|0);
  $8 = ($7|0)==(0|0);
  if ($8) {
   STACKTOP = sp;return;
  }
  HEAP32[$3>>2] = $7;
  $9 = (($this) + 12|0);
  HEAP32[$9>>2] = $7;
  HEAP32[$7>>2] = 0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 8|0);
  HEAP32[$11>>2] = $size;
  $12 = (($7) + 12|0);
  $13 = $12;
  $14 = (0 - ($13))|0;
  $15 = $14 & 15;
  $16 = (($15) + ($13))|0;
  $17 = $16;
  $18 = (($10) + 4|0);
  HEAP32[$18>>2] = $17;
  $19 = (($this) + 16|0);
  HEAP32[$19>>2] = $17;
  STACKTOP = sp;return;
 } else {
  HEAP32[$1>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($6,16,$$byval_copy1,0,766088,565)|0);
  $21 = ($20|0)==(0|0);
  if ($21) {
   STACKTOP = sp;return;
  }
  $22 = (($this) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$23>>2] = $20;
  $24 = HEAP32[$22>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$22>>2] = $25;
  HEAP32[$25>>2] = 0;
  $26 = (($this) + 20|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27>>>0)<($size>>>0);
  $29 = $28 ? $size : $27;
  $30 = HEAP32[$22>>2]|0;
  $31 = (($30) + 8|0);
  HEAP32[$31>>2] = $29;
  $32 = (($20) + 12|0);
  $33 = $32;
  $34 = (0 - ($33))|0;
  $35 = $34 & 15;
  $36 = (($35) + ($33))|0;
  $37 = $36;
  $38 = (($30) + 4|0);
  HEAP32[$38>>2] = $37;
  $39 = (($this) + 16|0);
  HEAP32[$39>>2] = $37;
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy6 = 0, $$pre = 0, $$pre53 = 0, $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $$pre57 = 0, $$pre58 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $empty1 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $size$i$i$i8 = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp + 36|0;
 $0 = sp;
 $1 = sp + 4|0;
 $size$i$i$i8 = sp + 8|0;
 $empty1 = sp + 12|0;
 $value = sp + 24|0;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $2 = (($this) + 164|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = HEAP8[$2>>0]|0;
  HEAP8[$4>>0] = $9;
  $10 = HEAP32[$3>>2]|0;
  $11 = (($10) + 1|0);
  HEAP32[$3>>2] = $11;
  $14 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,1);
  $$pre = HEAP32[$3>>2]|0;
  $14 = $$pre;
 }
 $12 = (($this) + 84|0);
 $13 = (($14) + 1|0);
 $15 = HEAP32[$6>>2]|0;
 $16 = ($13>>>0)<($15>>>0);
 if ($16) {
  $17 = HEAP8[$12>>0]|0;
  HEAP8[$14>>0] = $17;
  $18 = HEAP32[$3>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$3>>2] = $19;
  $22 = $19;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$12,1);
  $$pre53 = HEAP32[$3>>2]|0;
  $22 = $$pre53;
 }
 $20 = (($this) + 85|0);
 $21 = (($22) + 1|0);
 $23 = HEAP32[$6>>2]|0;
 $24 = ($21>>>0)<($23>>>0);
 if ($24) {
  $25 = HEAP8[$20>>0]|0;
  HEAP8[$22>>0] = $25;
  $26 = HEAP32[$3>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$3>>2] = $27;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$20,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $28 = HEAP8[$12>>0]|0;
 $29 = ($28<<24>>24)==(0);
 L13: do {
  if ($29) {
   $30 = (($this) + 96|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($this) + 92|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = $31;
   $35 = $33;
   $36 = (($34) - ($35))|0;
   $37 = (($36|0) / 192)&-1;
   HEAP32[$$byval_copy6>>2] = $37;
   $38 = HEAP32[$3>>2]|0;
   $39 = (($38) + 4|0);
   $40 = HEAP32[$6>>2]|0;
   $41 = ($39>>>0)<($40>>>0);
   if ($41) {
    HEAP32[$38>>2] = $37;
    HEAP32[$3>>2] = $39;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy6,4);
   }
   $42 = HEAP32[$30>>2]|0;
   $43 = HEAP32[$32>>2]|0;
   $44 = ($43|0)==($42|0);
   if (!($44)) {
    $45 = $43;
    while(1) {
     __ZN13AnimationClip15QuaternionCurve8TransferI19StreamedBinaryWriteILb0EEEEvRT_($45,$transfer);
     $46 = (($45) + 192|0);
     $47 = ($46|0)==($42|0);
     if ($47) {
      break;
     } else {
      $45 = $46;
     }
    }
   }
   HEAP32[$size$i$i$i8>>2] = 0;
   $48 = HEAP32[$3>>2]|0;
   $49 = (($48) + 4|0);
   $50 = HEAP32[$6>>2]|0;
   $51 = ($49>>>0)<($50>>>0);
   if ($51) {
    HEAP32[$48>>2] = 0;
    HEAP32[$3>>2] = $49;
    break;
   }
   __THREW__ = 0;
   invoke_viii(1640,($3|0),($size$i$i$i8|0),4);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    $54 = ___cxa_find_matching_catch()|0;
    $55 = tempRet0;
    $$1 = $55;$$12 = $54;
    ___resumeException($$12|0);
    // unreachable;
   }
  } else {
   HEAP32[$empty1>>2] = 0;
   $56 = (($empty1) + 4|0);
   HEAP32[$56>>2] = 0;
   $57 = (($empty1) + 8|0);
   HEAP32[$57>>2] = 0;
   HEAP32[$$byval_copy6>>2] = 0;
   $58 = HEAP32[$3>>2]|0;
   $59 = (($58) + 4|0);
   $60 = HEAP32[$6>>2]|0;
   $61 = ($59>>>0)<($60>>>0);
   if ($61) {
    HEAP32[$58>>2] = 0;
    HEAP32[$3>>2] = $59;
    label = 23;
   } else {
    __THREW__ = 0;
    invoke_viii(1640,($3|0),($$byval_copy6|0),4);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $71 = ___cxa_find_matching_catch()|0;
     $72 = tempRet0;
     $$0 = $72;$$01 = $71;
    } else {
     label = 23;
    }
   }
   L19: do {
    if ((label|0) == 23) {
     $64 = HEAP32[$transfer>>2]|0;
     $65 = $64 & 33554432;
     $66 = ($65|0)==(0);
     L21: do {
      if ($66) {
       HEAP32[$value>>2] = 0;
       $67 = (($value) + 4|0);
       HEAP32[$67>>2] = 0;
       $68 = (($value) + 8|0);
       HEAP32[$68>>2] = 0;
       __THREW__ = 0;
       invoke_vii(3369,($this|0),($value|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       L23: do {
        if ($70) {
         label = 27;
        } else {
         $91 = HEAP32[$67>>2]|0;
         $92 = HEAP32[$value>>2]|0;
         $93 = $91;
         $94 = $92;
         $95 = (($93) - ($94))|0;
         $96 = (($95|0) / 84)&-1;
         HEAP32[$0>>2] = $96;
         $97 = HEAP32[$3>>2]|0;
         $98 = (($97) + 4|0);
         $99 = HEAP32[$6>>2]|0;
         $100 = ($98>>>0)<($99>>>0);
         if ($100) {
          HEAP32[$97>>2] = $96;
          HEAP32[$3>>2] = $98;
          $104 = $92;$105 = $91;
         } else {
          __THREW__ = 0;
          invoke_viii(1640,($3|0),($0|0),4);
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if ($102) {
           label = 27;
           break;
          }
          $$pre57 = HEAP32[$67>>2]|0;
          $$pre58 = HEAP32[$value>>2]|0;
          $104 = $$pre58;$105 = $$pre57;
         }
         $103 = ($104|0)==($105|0);
         do {
          if ($103) {
           $112 = $104;
          } else {
           $106 = $104;
           while(1) {
            __THREW__ = 0;
            invoke_vii(3370,($106|0),($transfer|0));
            $107 = __THREW__; __THREW__ = 0;
            $108 = $107&1;
            if ($108) {
             label = 26;
             break;
            }
            $109 = (($106) + 84|0);
            $110 = ($109|0)==($105|0);
            if ($110) {
             label = 41;
             break;
            } else {
             $106 = $109;
            }
           }
           if ((label|0) == 26) {
            $73 = ___cxa_find_matching_catch()|0;
            $74 = tempRet0;
            $lpad$phi$index = $73;$lpad$phi$index2 = $74;
            break L23;
           }
           else if ((label|0) == 41) {
            $$pre56 = HEAP32[$value>>2]|0;
            $112 = $$pre56;
            break;
           }
          }
         } while(0);
         $111 = ($112|0)==(0|0);
         if ($111) {
          break L21;
         }
         while(1) {
          $113 = HEAP32[$67>>2]|0;
          $114 = ($113|0)==($112|0);
          if ($114) {
           break;
          }
          $115 = (($113) + -84|0);
          HEAP32[$67>>2] = $115;
          __THREW__ = 0;
          invoke_vi(3690,($115|0));
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           label = 45;
           break;
          }
         }
         if ((label|0) == 45) {
          $118 = ___cxa_find_matching_catch()|0;
          $119 = tempRet0;
          ___cxa_call_unexpected(($118|0));
          // unreachable;
         }
         $120 = HEAP32[$value>>2]|0;
         HEAP32[$0>>2] = 18;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($120|0),($$byval_copy6|0));
         $121 = __THREW__; __THREW__ = 0;
         $122 = $121&1;
         if (!($122)) {
          break L21;
         }
         $123 = ___cxa_find_matching_catch()|0;
         $124 = tempRet0;
         ___cxa_call_unexpected(($123|0));
         // unreachable;
        }
       } while(0);
       if ((label|0) == 27) {
        $75 = ___cxa_find_matching_catch()|0;
        $76 = tempRet0;
        $lpad$phi$index = $75;$lpad$phi$index2 = $76;
       }
       $77 = HEAP32[$value>>2]|0;
       $78 = ($77|0)==(0|0);
       if ($78) {
        $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
        break L19;
       }
       while(1) {
        $79 = HEAP32[$67>>2]|0;
        $80 = ($79|0)==($77|0);
        if ($80) {
         break;
        }
        $81 = (($79) + -84|0);
        HEAP32[$67>>2] = $81;
        __THREW__ = 0;
        invoke_vi(3690,($81|0));
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 31;
         break;
        }
       }
       if ((label|0) == 31) {
        $84 = ___cxa_find_matching_catch()|0;
        $85 = tempRet0;
        ___cxa_call_unexpected(($84|0));
        // unreachable;
       }
       $86 = HEAP32[$value>>2]|0;
       HEAP32[$1>>2] = 18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($86|0),($$byval_copy6|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if (!($88)) {
        $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
        break L19;
       }
       $89 = ___cxa_find_matching_catch()|0;
       $90 = tempRet0;
       ___cxa_call_unexpected(($89|0));
       // unreachable;
      }
     } while(0);
     __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
     break L13;
    }
   } while(0);
   __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
   $$1 = $$0;$$12 = $$01;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $125 = (($this) + 108|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (($this) + 104|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = $126;
 $130 = $128;
 $131 = (($129) - ($130))|0;
 $132 = (($131|0) / 160)&-1;
 HEAP32[$$byval_copy6>>2] = $132;
 $133 = HEAP32[$3>>2]|0;
 $134 = (($133) + 4|0);
 $135 = HEAP32[$6>>2]|0;
 $136 = ($134>>>0)<($135>>>0);
 if ($136) {
  HEAP32[$133>>2] = $132;
  HEAP32[$3>>2] = $134;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy6,4);
 }
 $137 = HEAP32[$125>>2]|0;
 $138 = HEAP32[$127>>2]|0;
 $139 = ($138|0)==($137|0);
 if (!($139)) {
  $141 = $138;
  while(1) {
   $140 = (($141) + 12|0);
   __ZN17AnimationCurveTplI8Vector3fE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($140,$transfer);
   __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$141,0);
   __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
   $142 = (($141) + 160|0);
   $143 = ($142|0)==($137|0);
   if ($143) {
    break;
   } else {
    $141 = $142;
   }
  }
 }
 $144 = (($this) + 120|0);
 $145 = HEAP32[$144>>2]|0;
 $146 = (($this) + 116|0);
 $147 = HEAP32[$146>>2]|0;
 $148 = $145;
 $149 = $147;
 $150 = (($148) - ($149))|0;
 $151 = (($150|0) / 160)&-1;
 HEAP32[$$byval_copy6>>2] = $151;
 $152 = HEAP32[$3>>2]|0;
 $153 = (($152) + 4|0);
 $154 = HEAP32[$6>>2]|0;
 $155 = ($153>>>0)<($154>>>0);
 if ($155) {
  HEAP32[$152>>2] = $151;
  HEAP32[$3>>2] = $153;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy6,4);
 }
 $156 = HEAP32[$144>>2]|0;
 $157 = HEAP32[$146>>2]|0;
 $158 = ($157|0)==($156|0);
 if (!($158)) {
  $160 = $157;
  while(1) {
   $159 = (($160) + 12|0);
   __ZN17AnimationCurveTplI8Vector3fE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($159,$transfer);
   __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$160,0);
   __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
   $161 = (($160) + 160|0);
   $162 = ($161|0)==($156|0);
   if ($162) {
    break;
   } else {
    $160 = $161;
   }
  }
 }
 $163 = (($this) + 132|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = (($this) + 128|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = $164;
 $168 = $166;
 $169 = (($167) - ($168))|0;
 $170 = (($169|0) / 116)&-1;
 HEAP32[$$byval_copy6>>2] = $170;
 $171 = HEAP32[$3>>2]|0;
 $172 = (($171) + 4|0);
 $173 = HEAP32[$6>>2]|0;
 $174 = ($172>>>0)<($173>>>0);
 if ($174) {
  HEAP32[$171>>2] = $170;
  HEAP32[$3>>2] = $172;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy6,4);
 }
 $175 = HEAP32[$163>>2]|0;
 $176 = HEAP32[$165>>2]|0;
 $177 = ($176|0)==($175|0);
 if (!($177)) {
  $178 = $176;
  while(1) {
   __ZN13AnimationClip10FloatCurve8TransferI19StreamedBinaryWriteILb0EEEEvRT_($178,$transfer);
   $179 = (($178) + 116|0);
   $180 = ($179|0)==($175|0);
   if ($180) {
    break;
   } else {
    $178 = $179;
   }
  }
 }
 $181 = (($this) + 144|0);
 $182 = HEAP32[$181>>2]|0;
 $183 = (($this) + 140|0);
 $184 = HEAP32[$183>>2]|0;
 $185 = $182;
 $186 = $184;
 $187 = (($185) - ($186))|0;
 $188 = (($187|0) / 48)&-1;
 HEAP32[$$byval_copy6>>2] = $188;
 $189 = HEAP32[$3>>2]|0;
 $190 = (($189) + 4|0);
 $191 = HEAP32[$6>>2]|0;
 $192 = ($190>>>0)<($191>>>0);
 if ($192) {
  HEAP32[$189>>2] = $188;
  HEAP32[$3>>2] = $190;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy6,4);
 }
 $193 = HEAP32[$181>>2]|0;
 $194 = HEAP32[$183>>2]|0;
 $195 = ($194|0)==($193|0);
 if (!($195)) {
  $196 = $194;
  while(1) {
   __ZN13AnimationClip9PPtrCurve8TransferI19StreamedBinaryWriteILb0EEEEvRT_($196,$transfer);
   $197 = (($196) + 48|0);
   $198 = ($197|0)==($193|0);
   if ($198) {
    break;
   } else {
    $196 = $197;
   }
  }
 }
 $199 = (($this) + 80|0);
 $200 = HEAP32[$3>>2]|0;
 $201 = (($200) + 4|0);
 $202 = HEAP32[$6>>2]|0;
 $203 = ($201>>>0)<($202>>>0);
 if ($203) {
  $204 = Math_fround(HEAPF32[$199>>2]);
  HEAPF32[$200>>2] = $204;
  HEAP32[$3>>2] = $201;
  $207 = $201;$209 = $202;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$199,4);
  $$pre54 = HEAP32[$3>>2]|0;
  $$pre55 = HEAP32[$6>>2]|0;
  $207 = $$pre54;$209 = $$pre55;
 }
 $205 = (($this) + 88|0);
 $206 = (($207) + 4|0);
 $208 = ($206>>>0)<($209>>>0);
 if ($208) {
  $210 = HEAP32[$205>>2]|0;
  HEAP32[$207>>2] = $210;
  HEAP32[$3>>2] = $206;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$205,4);
 }
 $211 = (($this) + 216|0);
 __ZN4AABB8TransferI19StreamedBinaryWriteILb0EEEEvRT_($211,$transfer);
 $212 = (($this) + 48|0);
 $213 = (($transfer) + 4|0);
 HEAP32[$213>>2] = $212;
 $214 = (($this) + 168|0);
 $215 = (($this) + 172|0);
 __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE19StreamedBinaryWriteILb0EEEvRPT_PKcRjS9_RT0_($214,766608,$215,766624,$transfer);
 $216 = (($this) + 176|0);
 __ZN11UnityEngine9Animation28AnimationClipBindingConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($216,$transfer);
 $217 = (($this) + 156|0);
 $218 = HEAP32[$217>>2]|0;
 $219 = (($this) + 152|0);
 $220 = HEAP32[$219>>2]|0;
 $221 = $218;
 $222 = $220;
 $223 = (($221) - ($222))|0;
 $224 = (($223|0) / 56)&-1;
 HEAP32[$$byval_copy6>>2] = $224;
 $225 = HEAP32[$3>>2]|0;
 $226 = (($225) + 4|0);
 $227 = HEAP32[$6>>2]|0;
 $228 = ($226>>>0)<($227>>>0);
 if ($228) {
  HEAP32[$225>>2] = $224;
  HEAP32[$3>>2] = $226;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$$byval_copy6,4);
 }
 $229 = HEAP32[$217>>2]|0;
 $230 = HEAP32[$219>>2]|0;
 $231 = ($230|0)==($229|0);
 if ($231) {
  STACKTOP = sp;return;
 } else {
  $232 = $230;
 }
 while(1) {
  __ZN14AnimationEvent8TransferI19StreamedBinaryWriteILb0EEEEvRT_($232,$transfer);
  $233 = (($232) + 56|0);
  $234 = ($233|0)==($229|0);
  if ($234) {
   break;
  } else {
   $232 = $233;
  }
 }
 STACKTOP = sp;return;
}
function __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE19StreamedBinaryWriteILb0EEEvRPT_PKcRjS9_RT0_($data,$name,$size,$sizeName,$transfer) {
 $data = $data|0;
 $name = $name|0;
 $size = $size|0;
 $sizeName = $sizeName|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$size>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$size,4);
 }
 $7 = HEAP32[$data>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $42 = $7;
  __ZN7mecanim9animation18ClipMuscleConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($42,$transfer);
  STACKTOP = sp;return;
 }
 $9 = (($transfer) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$size>>2]|0;
 __ZN7mecanim6memory16ChainedAllocator7ReserveEj($10,$11);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiii[$13 & 2047]($10,1644,4)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $41 = 0;
 } else {
  __ZN7mecanim5human9HumanPoseC2Ev($14);
  $16 = (($14) + 880|0);
  $17 = (($14) + 908|0);
  ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;HEAP32[$16+24>>2]=0|0;
  HEAPF32[$17>>2] = Math_fround(1.0);
  $18 = (($14) + 912|0);
  HEAPF32[$18>>2] = Math_fround(1.0);
  $19 = (($14) + 916|0);
  HEAPF32[$19>>2] = Math_fround(1.0);
  $20 = (($14) + 920|0);
  HEAPF32[$20>>2] = Math_fround(1.0);
  $21 = (($14) + 924|0);
  HEAPF32[$21>>2] = Math_fround(1.0);
  $22 = (($14) + 928|0);
  $23 = (($14) + 956|0);
  ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;HEAP32[$22+16>>2]=0|0;HEAP32[$22+20>>2]=0|0;HEAP32[$22+24>>2]=0|0;
  HEAPF32[$23>>2] = Math_fround(1.0);
  $24 = (($14) + 960|0);
  HEAPF32[$24>>2] = Math_fround(1.0);
  $25 = (($14) + 964|0);
  HEAPF32[$25>>2] = Math_fround(1.0);
  $26 = (($14) + 968|0);
  HEAPF32[$26>>2] = Math_fround(1.0);
  $27 = (($14) + 972|0);
  HEAPF32[$27>>2] = Math_fround(1.0);
  $28 = (($14) + 976|0);
  $29 = (($14) + 1004|0);
  ;HEAP32[$28+0>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;HEAP32[$28+12>>2]=0|0;HEAP32[$28+16>>2]=0|0;HEAP32[$28+20>>2]=0|0;HEAP32[$28+24>>2]=0|0;
  HEAPF32[$29>>2] = Math_fround(1.0);
  $30 = (($14) + 1008|0);
  HEAPF32[$30>>2] = Math_fround(1.0);
  $31 = (($14) + 1012|0);
  HEAPF32[$31>>2] = Math_fround(1.0);
  $32 = (($14) + 1016|0);
  HEAPF32[$32>>2] = Math_fround(1.0);
  $33 = (($14) + 1020|0);
  HEAPF32[$33>>2] = Math_fround(1.0);
  $34 = (($14) + 1024|0);
  $35 = (($14) + 1052|0);
  ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;HEAP32[$34+24>>2]=0|0;
  HEAPF32[$35>>2] = Math_fround(1.0);
  $36 = (($14) + 1056|0);
  $37 = (($14) + 1620|0);
  $38 = (($14) + 1639|0);
  ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;
  ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP16[$37+16>>1]=0|0;HEAP8[$37+18>>0]=0|0;
  HEAP8[$38>>0] = 1;
  $39 = (($14) + 1640|0);
  HEAP8[$39>>0] = 0;
  $40 = (($14) + 1641|0);
  HEAP8[$40>>0] = 0;
  $scevgep$i$i$i = (($14) + 1072|0);
  _memset(($scevgep$i$i$i|0),-1,548)|0;
  $41 = $14;
 }
 HEAP32[$data>>2] = $41;
 $42 = $41;
 __ZN7mecanim9animation18ClipMuscleConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($42,$transfer);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation28AnimationClipBindingConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, $i$01$i$i$i3 = 0, $size$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i1 = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i1>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i1,4);
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($8) + ($9<<4)|0);
 $11 = ($9|0)==(0);
 if (!($11)) {
  $i$01$i$i$i = $8;
  while(1) {
   __ZN11UnityEngine9Animation14GenericBinding8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $12 = (($i$01$i$i$i) + 16|0);
   $13 = ($12|0)==($10|0);
   if ($13) {
    break;
   } else {
    $i$01$i$i$i = $12;
   }
  }
 }
 $14 = (($this) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$size$i$i$i1>>2] = $15;
 $16 = HEAP32[$2>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$5>>2]|0;
 $19 = ($17>>>0)<($18>>>0);
 if ($19) {
  HEAP32[$16>>2] = $15;
  HEAP32[$2>>2] = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i1,4);
 }
 $20 = (($this) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$14>>2]|0;
 $23 = (($21) + ($22<<2)|0);
 $24 = ($22|0)==(0);
 if ($24) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i3 = $21;
 }
 while(1) {
  __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i3,$transfer);
  $25 = (($i$01$i$i$i3) + 4|0);
  $26 = ($25|0)==($23|0);
  if ($26) {
   break;
  } else {
   $i$01$i$i$i3 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation14GenericBinding8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $11 = $$pre3;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
 }
 $13 = (($this) + 8|0);
 __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($13,$transfer);
 $14 = (($this) + 12|0);
 $15 = HEAP32[$0>>2]|0;
 $16 = (($15) + 2|0);
 $17 = HEAP32[$3>>2]|0;
 $18 = ($16>>>0)<($17>>>0);
 if ($18) {
  $19 = HEAP16[$14>>1]|0;
  HEAP16[$15>>1] = $19;
  HEAP32[$0>>2] = $16;
  $22 = $16;$24 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$14,2);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $22 = $$pre4;$24 = $$pre5;
 }
 $20 = (($this) + 14|0);
 $21 = (($22) + 1|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = HEAP8[$20>>0]|0;
  HEAP8[$22>>0] = $25;
  $26 = HEAP32[$0>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$0>>2] = $27;
  $30 = $27;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$20,1);
  $$pre6 = HEAP32[$0>>2]|0;
  $30 = $$pre6;
 }
 $28 = (($this) + 15|0);
 $29 = (($30) + 1|0);
 $31 = HEAP32[$3>>2]|0;
 $32 = ($29>>>0)<($31>>>0);
 if ($32) {
  $33 = HEAP8[$28>>0]|0;
  HEAP8[$30>>0] = $33;
  $34 = HEAP32[$0>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$0>>2] = $35;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$28,1);
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation18ClipMuscleConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0;
 var $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0);
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i = 0, $i$02$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 __ZN7mecanim5human9HumanPose8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 880|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 896|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 912|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($2,$transfer);
 $3 = (($this) + 928|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($3,$transfer);
 $4 = (($this) + 944|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($4,$transfer);
 $5 = (($this) + 960|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($5,$transfer);
 $6 = (($this) + 976|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($6,$transfer);
 $7 = (($this) + 992|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($7,$transfer);
 $8 = (($this) + 1008|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($8,$transfer);
 $9 = (($this) + 1024|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($9,$transfer);
 $10 = (($this) + 1040|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  $13 = (($transfer) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_iiii[$16 & 2047]($14,64,4)|0);
  $18 = ($17|0)==(0|0);
  if ($18) {
   $22 = 0;$24 = 0;
  } else {
   dest=$17+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $19 = $17;
   $20 = $10;
   $21 = (($19) - ($20))|0;
   $22 = $21;$24 = $17;
  }
  HEAP32[$10>>2] = $22;
  $23 = (($this) + 1044|0);
  HEAP32[$23>>2] = $24;
  $$pre$phi$i$iZ2D = $23;$27 = $22;
 } else {
  $$pre$i$i = (($this) + 1044|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$27 = $11;
 }
 $25 = $10;
 $26 = (($27) + ($25))|0;
 $28 = $26;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $28;
 __ZN7mecanim9animation4Clip8TransferI19StreamedBinaryWriteILb0EEEEvRT_($28,$transfer);
 $29 = (($this) + 1048|0);
 $30 = (($transfer) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 4|0);
 $33 = (($transfer) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32>>>0)<($34>>>0);
 if ($35) {
  $36 = Math_fround(HEAPF32[$29>>2]);
  HEAPF32[$31>>2] = $36;
  HEAP32[$30>>2] = $32;
  $39 = $32;$41 = $34;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$29,4);
  $$pre = HEAP32[$30>>2]|0;
  $$pre15 = HEAP32[$33>>2]|0;
  $39 = $$pre;$41 = $$pre15;
 }
 $37 = (($this) + 1052|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$39>>2] = $42;
  HEAP32[$30>>2] = $38;
  $45 = $38;$47 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$37,4);
  $$pre16 = HEAP32[$30>>2]|0;
  $$pre17 = HEAP32[$33>>2]|0;
  $45 = $$pre16;$47 = $$pre17;
 }
 $43 = (($this) + 1056|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)<($47>>>0);
 if ($46) {
  $48 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$45>>2] = $48;
  HEAP32[$30>>2] = $44;
  $51 = $44;$53 = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$43,4);
  $$pre18 = HEAP32[$30>>2]|0;
  $$pre19 = HEAP32[$33>>2]|0;
  $51 = $$pre18;$53 = $$pre19;
 }
 $49 = (($this) + 1060|0);
 $50 = (($51) + 4|0);
 $52 = ($50>>>0)<($53>>>0);
 if ($52) {
  $54 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$51>>2] = $54;
  HEAP32[$30>>2] = $50;
  $57 = $50;$59 = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$49,4);
  $$pre20 = HEAP32[$30>>2]|0;
  $$pre21 = HEAP32[$33>>2]|0;
  $57 = $$pre20;$59 = $$pre21;
 }
 $55 = (($this) + 1064|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)<($59>>>0);
 if ($58) {
  $60 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$57>>2] = $60;
  HEAP32[$30>>2] = $56;
  $63 = $56;$65 = $59;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$55,4);
  $$pre22 = HEAP32[$30>>2]|0;
  $$pre23 = HEAP32[$33>>2]|0;
  $63 = $$pre22;$65 = $$pre23;
 }
 $61 = (($this) + 1068|0);
 $62 = (($63) + 4|0);
 $64 = ($62>>>0)<($65>>>0);
 if ($64) {
  $66 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$63>>2] = $66;
  HEAP32[$30>>2] = $62;
  $68 = $62;$70 = $65;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$61,4);
  $$pre24 = HEAP32[$30>>2]|0;
  $$pre25 = HEAP32[$33>>2]|0;
  $68 = $$pre24;$70 = $$pre25;
 }
 HEAP32[$ArrayTransfer$i>>2] = 137;
 $67 = (($68) + 4|0);
 $69 = ($67>>>0)<($70>>>0);
 if ($69) {
  HEAP32[$68>>2] = 137;
  HEAP32[$30>>2] = $67;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$ArrayTransfer$i,4);
 }
 $71 = (($this) + 1620|0);
 $72 = (($this) + 1072|0);
 $i$02$i$i$i$i = $72;
 while(1) {
  $73 = HEAP32[$30>>2]|0;
  $74 = (($73) + 4|0);
  $75 = HEAP32[$33>>2]|0;
  $76 = ($74>>>0)<($75>>>0);
  if ($76) {
   $77 = HEAP32[$i$02$i$i$i$i>>2]|0;
   HEAP32[$73>>2] = $77;
   HEAP32[$30>>2] = $74;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$i$02$i$i$i$i,4);
  }
  $78 = (($i$02$i$i$i$i) + 4|0);
  $79 = ($78|0)==($71|0);
  if ($79) {
   break;
  } else {
   $i$02$i$i$i$i = $78;
  }
 }
 $80 = (($this) + 1624|0);
 $81 = (($this) + 1620|0);
 $82 = (($transfer) + 4|0);
 $83 = HEAP32[$82>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $80;
 $84 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$84>>2] = $81;
 $85 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$85>>2] = $83;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation10ValueDeltaEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 $86 = (($this) + 1632|0);
 $87 = HEAP32[$30>>2]|0;
 $88 = (($87) + 1|0);
 $89 = HEAP32[$33>>2]|0;
 $90 = ($88>>>0)<($89>>>0);
 if ($90) {
  $91 = HEAP8[$86>>0]|0;
  HEAP8[$87>>0] = $91;
  $92 = HEAP32[$30>>2]|0;
  $93 = (($92) + 1|0);
  HEAP32[$30>>2] = $93;
  $96 = $93;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$86,1);
  $$pre26 = HEAP32[$30>>2]|0;
  $96 = $$pre26;
 }
 $94 = (($this) + 1633|0);
 $95 = (($96) + 1|0);
 $97 = HEAP32[$33>>2]|0;
 $98 = ($95>>>0)<($97>>>0);
 if ($98) {
  $99 = HEAP8[$94>>0]|0;
  HEAP8[$96>>0] = $99;
  $100 = HEAP32[$30>>2]|0;
  $101 = (($100) + 1|0);
  HEAP32[$30>>2] = $101;
  $104 = $101;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$94,1);
  $$pre27 = HEAP32[$30>>2]|0;
  $104 = $$pre27;
 }
 $102 = (($this) + 1634|0);
 $103 = (($104) + 1|0);
 $105 = HEAP32[$33>>2]|0;
 $106 = ($103>>>0)<($105>>>0);
 if ($106) {
  $107 = HEAP8[$102>>0]|0;
  HEAP8[$104>>0] = $107;
  $108 = HEAP32[$30>>2]|0;
  $109 = (($108) + 1|0);
  HEAP32[$30>>2] = $109;
  $112 = $109;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$102,1);
  $$pre28 = HEAP32[$30>>2]|0;
  $112 = $$pre28;
 }
 $110 = (($this) + 1635|0);
 $111 = (($112) + 1|0);
 $113 = HEAP32[$33>>2]|0;
 $114 = ($111>>>0)<($113>>>0);
 if ($114) {
  $115 = HEAP8[$110>>0]|0;
  HEAP8[$112>>0] = $115;
  $116 = HEAP32[$30>>2]|0;
  $117 = (($116) + 1|0);
  HEAP32[$30>>2] = $117;
  $120 = $117;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$110,1);
  $$pre29 = HEAP32[$30>>2]|0;
  $120 = $$pre29;
 }
 $118 = (($this) + 1636|0);
 $119 = (($120) + 1|0);
 $121 = HEAP32[$33>>2]|0;
 $122 = ($119>>>0)<($121>>>0);
 if ($122) {
  $123 = HEAP8[$118>>0]|0;
  HEAP8[$120>>0] = $123;
  $124 = HEAP32[$30>>2]|0;
  $125 = (($124) + 1|0);
  HEAP32[$30>>2] = $125;
  $128 = $125;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$118,1);
  $$pre30 = HEAP32[$30>>2]|0;
  $128 = $$pre30;
 }
 $126 = (($this) + 1637|0);
 $127 = (($128) + 1|0);
 $129 = HEAP32[$33>>2]|0;
 $130 = ($127>>>0)<($129>>>0);
 if ($130) {
  $131 = HEAP8[$126>>0]|0;
  HEAP8[$128>>0] = $131;
  $132 = HEAP32[$30>>2]|0;
  $133 = (($132) + 1|0);
  HEAP32[$30>>2] = $133;
  $136 = $133;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$126,1);
  $$pre31 = HEAP32[$30>>2]|0;
  $136 = $$pre31;
 }
 $134 = (($this) + 1638|0);
 $135 = (($136) + 1|0);
 $137 = HEAP32[$33>>2]|0;
 $138 = ($135>>>0)<($137>>>0);
 if ($138) {
  $139 = HEAP8[$134>>0]|0;
  HEAP8[$136>>0] = $139;
  $140 = HEAP32[$30>>2]|0;
  $141 = (($140) + 1|0);
  HEAP32[$30>>2] = $141;
  $144 = $141;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$134,1);
  $$pre32 = HEAP32[$30>>2]|0;
  $144 = $$pre32;
 }
 $142 = (($this) + 1639|0);
 $143 = (($144) + 1|0);
 $145 = HEAP32[$33>>2]|0;
 $146 = ($143>>>0)<($145>>>0);
 if ($146) {
  $147 = HEAP8[$142>>0]|0;
  HEAP8[$144>>0] = $147;
  $148 = HEAP32[$30>>2]|0;
  $149 = (($148) + 1|0);
  HEAP32[$30>>2] = $149;
  $152 = $149;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$142,1);
  $$pre33 = HEAP32[$30>>2]|0;
  $152 = $$pre33;
 }
 $150 = (($this) + 1640|0);
 $151 = (($152) + 1|0);
 $153 = HEAP32[$33>>2]|0;
 $154 = ($151>>>0)<($153>>>0);
 if ($154) {
  $155 = HEAP8[$150>>0]|0;
  HEAP8[$152>>0] = $155;
  $156 = HEAP32[$30>>2]|0;
  $157 = (($156) + 1|0);
  HEAP32[$30>>2] = $157;
  $160 = $157;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$150,1);
  $$pre34 = HEAP32[$30>>2]|0;
  $160 = $$pre34;
 }
 $158 = (($this) + 1641|0);
 $159 = (($160) + 1|0);
 $161 = HEAP32[$33>>2]|0;
 $162 = ($159>>>0)<($161>>>0);
 if ($162) {
  $163 = HEAP8[$158>>0]|0;
  HEAP8[$160>>0] = $163;
  $164 = HEAP32[$30>>2]|0;
  $165 = (($164) + 1|0);
  HEAP32[$30>>2] = $165;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$158,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation10ValueDeltaEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $23;
 }
 while(1) {
  $26 = HEAP32[$4>>2]|0;
  $27 = (($26) + 4|0);
  $28 = HEAP32[$7>>2]|0;
  $29 = ($27>>>0)<($28>>>0);
  if ($29) {
   $30 = Math_fround(HEAPF32[$i$01>>2]);
   HEAPF32[$26>>2] = $30;
   HEAP32[$4>>2] = $27;
   $33 = $27;$35 = $28;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01,4);
   $$pre$i$i$i = HEAP32[$4>>2]|0;
   $$pre2$i$i$i = HEAP32[$7>>2]|0;
   $33 = $$pre$i$i$i;$35 = $$pre2$i$i$i;
  }
  $31 = (($i$01) + 4|0);
  $32 = (($33) + 4|0);
  $34 = ($32>>>0)<($35>>>0);
  if ($34) {
   $36 = Math_fround(HEAPF32[$31>>2]);
   HEAPF32[$33>>2] = $36;
   HEAP32[$4>>2] = $32;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$31,4);
  }
  $37 = (($i$01) + 8|0);
  $38 = ($37|0)==($18|0);
  if ($38) {
   break;
  } else {
   $i$01 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation4Clip8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i$i = sp;
 __ZN19StreamedBinaryWriteILb0EE8TransferIN7mecanim9animation12StreamedClipEEEvRT_PKc17TransferMetaFlags($transfer,$this,0,0);
 $0 = (($this) + 16|0);
 __ZN7mecanim9animation9DenseClip8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 48|0);
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size$i$i$i$i$i$i$i>>2] = $3;
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i$i$i$i$i$i,4);
 }
 $10 = $1;
 $11 = HEAP32[$1>>2]|0;
 $12 = (($11) + ($10))|0;
 $13 = $12;
 $14 = (($this) + 52|0);
 $15 = HEAP32[$2>>2]|0;
 $16 = (($13) + ($15<<2)|0);
 HEAP32[$14>>2] = $13;
 $17 = ($15|0)==(0);
 if ($17) {
  $25 = (($this) + 56|0);
  __ZN19StreamedBinaryWriteILb0EE8TransferI9OffsetPtrIN7mecanim18ValueArrayConstantEEEEvRT_PKc17TransferMetaFlags($transfer,$25,0,0);
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i$i$i$i$i = $13;
 }
 while(1) {
  $18 = HEAP32[$4>>2]|0;
  $19 = (($18) + 4|0);
  $20 = HEAP32[$7>>2]|0;
  $21 = ($19>>>0)<($20>>>0);
  if ($21) {
   $22 = Math_fround(HEAPF32[$i$01$i$i$i$i$i$i$i>>2]);
   HEAPF32[$18>>2] = $22;
   HEAP32[$4>>2] = $19;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01$i$i$i$i$i$i$i,4);
  }
  $23 = (($i$01$i$i$i$i$i$i$i) + 4|0);
  $24 = ($23|0)==($16|0);
  if ($24) {
   break;
  } else {
   $i$01$i$i$i$i$i$i$i = $23;
  }
 }
 $25 = (($this) + 56|0);
 __ZN19StreamedBinaryWriteILb0EE8TransferI9OffsetPtrIN7mecanim18ValueArrayConstantEEEEvRT_PKc17TransferMetaFlags($transfer,$25,0,0);
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE8TransferIN7mecanim9animation12StreamedClipEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$data>>2]|0;
 HEAP32[$size$i$i$i$i$i$i>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i$i$i$i$i,4);
 }
 $10 = $2;
 $11 = HEAP32[$2>>2]|0;
 $12 = (($11) + ($10))|0;
 $13 = $12;
 $14 = (($data) + 8|0);
 $15 = HEAP32[$data>>2]|0;
 $16 = (($13) + ($15<<2)|0);
 HEAP32[$14>>2] = $13;
 $17 = ($15|0)==(0);
 if (!($17)) {
  $i$01$i$i$i$i$i$i = $13;
  while(1) {
   $18 = HEAP32[$4>>2]|0;
   $19 = (($18) + 4|0);
   $20 = HEAP32[$7>>2]|0;
   $21 = ($19>>>0)<($20>>>0);
   if ($21) {
    $22 = HEAP32[$i$01$i$i$i$i$i$i>>2]|0;
    HEAP32[$18>>2] = $22;
    HEAP32[$4>>2] = $19;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01$i$i$i$i$i$i,4);
   }
   $23 = (($i$01$i$i$i$i$i$i) + 4|0);
   $24 = ($23|0)==($16|0);
   if ($24) {
    break;
   } else {
    $i$01$i$i$i$i$i$i = $23;
   }
  }
 }
 $25 = (($data) + 12|0);
 $26 = HEAP32[$4>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$7>>2]|0;
 $29 = ($27>>>0)<($28>>>0);
 if ($29) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$26>>2] = $30;
  HEAP32[$4>>2] = $27;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$25,4);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE8TransferI9OffsetPtrIN7mecanim18ValueArrayConstantEEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01$i$i$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i$i$i = sp;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_iiii[$7 & 2047]($5,12,4)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $15 = 0;$17 = 0;
  } else {
   HEAP32[$8>>2] = 0;
   $10 = (($8) + 4|0);
   HEAP32[$10>>2] = 0;
   $11 = (($8) + 8|0);
   HEAP32[$11>>2] = 0;
   $12 = $8;
   $13 = $data;
   $14 = (($12) - ($13))|0;
   $15 = $14;$17 = $8;
  }
  HEAP32[$data>>2] = $15;
  $16 = (($data) + 4|0);
  HEAP32[$16>>2] = $17;
  $$pre$phi$iZ2D = $16;$20 = $15;
 } else {
  $$pre$i = (($data) + 4|0);
  $$pre$phi$iZ2D = $$pre$i;$20 = $2;
 }
 $18 = $data;
 $19 = (($20) + ($18))|0;
 $21 = $19;
 HEAP32[$$pre$phi$iZ2D>>2] = $21;
 $22 = (($21) + 4|0);
 $23 = HEAP32[$21>>2]|0;
 HEAP32[$size$i$i$i$i$i$i$i$i>>2] = $23;
 $24 = (($this) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 4|0);
 $27 = (($this) + 20|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($26>>>0)<($28>>>0);
 if ($29) {
  HEAP32[$25>>2] = $23;
  HEAP32[$24>>2] = $26;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($24,$size$i$i$i$i$i$i$i$i,4);
 }
 $30 = $22;
 $31 = HEAP32[$22>>2]|0;
 $32 = (($31) + ($30))|0;
 $33 = $32;
 $34 = (($21) + 8|0);
 $35 = HEAP32[$21>>2]|0;
 $36 = (($33) + ($35<<4)|0);
 HEAP32[$34>>2] = $33;
 $37 = ($35|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i$i$i$i$i$i = $33;
 }
 while(1) {
  __ZN7mecanim13ValueConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i$i$i$i$i$i,$this);
  $38 = (($i$01$i$i$i$i$i$i$i$i) + 16|0);
  $39 = ($38|0)==($36|0);
  if ($39) {
   break;
  } else {
   $i$01$i$i$i$i$i$i$i$i = $38;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim13ValueConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$13>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation9DenseClip8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre2 = HEAP32[$3>>2]|0;
  $11 = $$pre2;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre3 = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $15 = $$pre3;$17 = $$pre4;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $21 = $$pre5;$23 = $$pre6;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  $29 = $20;$31 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $29 = $$pre7;$31 = $$pre8;
 }
 $25 = (($this) + 20|0);
 $26 = (($this) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$size$i$i$i$i>>2] = $27;
 $28 = (($29) + 4|0);
 $30 = ($28>>>0)<($31>>>0);
 if ($30) {
  HEAP32[$29>>2] = $27;
  HEAP32[$0>>2] = $28;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$size$i$i$i$i,4);
 }
 $32 = $25;
 $33 = HEAP32[$25>>2]|0;
 $34 = (($33) + ($32))|0;
 $35 = $34;
 $36 = (($this) + 24|0);
 $37 = HEAP32[$26>>2]|0;
 $38 = (($35) + ($37<<2)|0);
 HEAP32[$36>>2] = $35;
 $39 = ($37|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i$i = $35;
 }
 while(1) {
  $40 = HEAP32[$0>>2]|0;
  $41 = (($40) + 4|0);
  $42 = HEAP32[$3>>2]|0;
  $43 = ($41>>>0)<($42>>>0);
  if ($43) {
   $44 = Math_fround(HEAPF32[$i$01$i$i$i$i>>2]);
   HEAPF32[$40>>2] = $44;
   HEAP32[$0>>2] = $41;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$i$01$i$i$i$i,4);
  }
  $45 = (($i$01$i$i$i$i) + 4|0);
  $46 = ($45|0)==($38|0);
  if ($46) {
   break;
  } else {
   $i$01$i$i$i$i = $45;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0;
 var $9 = Math_fround(0), $buf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf = sp;
 $0 = Math_fround(HEAPF32[$data>>2]);
 HEAPF32[$buf>>2] = $0;
 $1 = (($buf) + 4|0);
 $2 = (($data) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$1>>2] = $3;
 $4 = (($buf) + 8|0);
 $5 = (($data) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($buf) + 12|0);
 $8 = (($data) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($transfer) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = (($transfer) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)<($14>>>0);
 if ($15) {
  HEAPF32[$11>>2] = $0;
  HEAP32[$10>>2] = $12;
  $17 = $12;$19 = $14;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($10,$buf,4);
  $$pre = HEAP32[$10>>2]|0;
  $$pre4 = HEAP32[$13>>2]|0;
  $17 = $$pre;$19 = $$pre4;
 }
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)<($19>>>0);
 if ($18) {
  $20 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$17>>2] = $20;
  HEAP32[$10>>2] = $16;
  $22 = $16;$24 = $19;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($10,$1,4);
  $$pre5 = HEAP32[$10>>2]|0;
  $$pre6 = HEAP32[$13>>2]|0;
  $22 = $$pre5;$24 = $$pre6;
 }
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$22>>2] = $25;
  HEAP32[$10>>2] = $21;
  $27 = $21;$29 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($10,$4,4);
  $$pre7 = HEAP32[$10>>2]|0;
  $$pre8 = HEAP32[$13>>2]|0;
  $27 = $$pre7;$29 = $$pre8;
 }
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$27>>2] = $30;
  HEAP32[$10>>2] = $26;
  $31 = Math_fround(HEAPF32[$buf>>2]);
  $32 = Math_fround(HEAPF32[$1>>2]);
  $33 = Math_fround(HEAPF32[$4>>2]);
  $34 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$data>>2] = $31;
  HEAPF32[$2>>2] = $32;
  HEAPF32[$5>>2] = $33;
  HEAPF32[$8>>2] = $34;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($10,$7,4);
  $31 = Math_fround(HEAPF32[$buf>>2]);
  $32 = Math_fround(HEAPF32[$1>>2]);
  $33 = Math_fround(HEAPF32[$4>>2]);
  $34 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$data>>2] = $31;
  HEAPF32[$2>>2] = $32;
  HEAPF32[$5>>2] = $33;
  HEAPF32[$8>>2] = $34;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim5human9HumanPose8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i = 0, $size$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i1 = sp;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 48|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($2,$transfer);
 $3 = (($this) + 64|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($3,$transfer);
 HEAP32[$size$i$i$i$i1>>2] = 4;
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = 4;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i$i$i1,4);
 }
 $10 = (($this) + 80|0);
 __ZN7mecanim5human9HumanGoal8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 156|0);
 __ZN7mecanim5human9HumanGoal8TransferI19StreamedBinaryWriteILb0EEEEvRT_($11,$transfer);
 $12 = (($this) + 232|0);
 __ZN7mecanim5human9HumanGoal8TransferI19StreamedBinaryWriteILb0EEEEvRT_($12,$transfer);
 $13 = (($this) + 308|0);
 __ZN7mecanim5human9HumanGoal8TransferI19StreamedBinaryWriteILb0EEEEvRT_($13,$transfer);
 $14 = (($this) + 384|0);
 __ZN7mecanim4hand8HandPose8TransferI19StreamedBinaryWriteILb0EEEEvRT_($14,$transfer);
 $15 = (($this) + 528|0);
 __ZN7mecanim4hand8HandPose8TransferI19StreamedBinaryWriteILb0EEEEvRT_($15,$transfer);
 HEAP32[$size$i$i$i$i1>>2] = 52;
 $16 = HEAP32[$4>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$7>>2]|0;
 $19 = ($17>>>0)<($18>>>0);
 if ($19) {
  HEAP32[$16>>2] = 52;
  HEAP32[$4>>2] = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i$i$i1,4);
 }
 $20 = (($this) + 880|0);
 $21 = (($this) + 672|0);
 $i$01$i$i$i$i = $21;
 while(1) {
  $22 = HEAP32[$4>>2]|0;
  $23 = (($22) + 4|0);
  $24 = HEAP32[$7>>2]|0;
  $25 = ($23>>>0)<($24>>>0);
  if ($25) {
   $26 = Math_fround(HEAPF32[$i$01$i$i$i$i>>2]);
   HEAPF32[$22>>2] = $26;
   HEAP32[$4>>2] = $23;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01$i$i$i$i,4);
  }
  $27 = (($i$01$i$i$i$i) + 4|0);
  $28 = ($27|0)==($20|0);
  if ($28) {
   break;
  } else {
   $i$01$i$i$i$i = $27;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim4hand8HandPose8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($1,$transfer);
 HEAP32[$size$i$i$i$i>>2] = 20;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = 20;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i,4);
 }
 $8 = (($this) + 128|0);
 $9 = (($this) + 48|0);
 $i$01$i$i$i$i = $9;
 while(1) {
  $10 = HEAP32[$2>>2]|0;
  $11 = (($10) + 4|0);
  $12 = HEAP32[$5>>2]|0;
  $13 = ($11>>>0)<($12>>>0);
  if ($13) {
   $14 = Math_fround(HEAPF32[$i$01$i$i$i$i>>2]);
   HEAPF32[$10>>2] = $14;
   HEAP32[$2>>2] = $11;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i$i,4);
  }
  $15 = (($i$01$i$i$i$i) + 4|0);
  $16 = ($15|0)==($8|0);
  if ($16) {
   break;
  } else {
   $i$01$i$i$i$i = $15;
  }
 }
 $17 = (($this) + 128|0);
 $18 = HEAP32[$2>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$5>>2]|0;
 $21 = ($19>>>0)<($20>>>0);
 if ($21) {
  $22 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$18>>2] = $22;
  HEAP32[$2>>2] = $19;
  $25 = $19;$27 = $20;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$17,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre4 = HEAP32[$5>>2]|0;
  $25 = $$pre;$27 = $$pre4;
 }
 $23 = (($this) + 132|0);
 $24 = (($25) + 4|0);
 $26 = ($24>>>0)<($27>>>0);
 if ($26) {
  $28 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$25>>2] = $28;
  HEAP32[$2>>2] = $24;
  $31 = $24;$33 = $27;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$23,4);
  $$pre5 = HEAP32[$2>>2]|0;
  $$pre6 = HEAP32[$5>>2]|0;
  $31 = $$pre5;$33 = $$pre6;
 }
 $29 = (($this) + 136|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)<($33>>>0);
 if ($32) {
  $34 = Math_fround(HEAPF32[$29>>2]);
  HEAPF32[$31>>2] = $34;
  HEAP32[$2>>2] = $30;
  $37 = $30;$39 = $33;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$29,4);
  $$pre7 = HEAP32[$2>>2]|0;
  $$pre8 = HEAP32[$5>>2]|0;
  $37 = $$pre7;$39 = $$pre8;
 }
 $35 = (($this) + 140|0);
 $36 = (($37) + 4|0);
 $38 = ($36>>>0)<($39>>>0);
 if ($38) {
  $40 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$37>>2] = $40;
  HEAP32[$2>>2] = $36;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$35,4);
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim5human9HumanGoal8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 48|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre3 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre3;
 }
 $10 = (($this) + 52|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)<($14>>>0);
 if ($13) {
  $15 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$12>>2] = $15;
  HEAP32[$3>>2] = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$10,4);
 }
 $16 = (($this) + 56|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($16,$transfer);
 $17 = (($this) + 72|0);
 $18 = HEAP32[$3>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$6>>2]|0;
 $21 = ($19>>>0)<($20>>>0);
 if ($21) {
  $22 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$18>>2] = $22;
  HEAP32[$3>>2] = $19;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$17,4);
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip9PPtrCurve8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i,4);
 }
 $8 = (($this) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = (($9) + ($10<<3)|0);
 $12 = ($10|0)==(0);
 if (!($12)) {
  $i$01$i$i$i = $9;
  while(1) {
   $13 = HEAP32[$2>>2]|0;
   $14 = (($13) + 4|0);
   $15 = HEAP32[$5>>2]|0;
   $16 = ($14>>>0)<($15>>>0);
   if ($16) {
    $17 = Math_fround(HEAPF32[$i$01$i$i$i>>2]);
    HEAPF32[$13>>2] = $17;
    HEAP32[$2>>2] = $14;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i,4);
   }
   $18 = (($i$01$i$i$i) + 4|0);
   __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($18,$transfer);
   $19 = (($i$01$i$i$i) + 8|0);
   $20 = ($19|0)==($11|0);
   if ($20) {
    break;
   } else {
    $i$01$i$i$i = $19;
   }
  }
 }
 $21 = (($this) + 12|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$21,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $22 = (($this) + 24|0);
 $23 = HEAP32[$2>>2]|0;
 $24 = (($23) + 4|0);
 $25 = HEAP32[$5>>2]|0;
 $26 = ($24>>>0)<($25>>>0);
 if ($26) {
  $27 = HEAP32[$22>>2]|0;
  HEAP32[$23>>2] = $27;
  HEAP32[$2>>2] = $24;
  $28 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($28,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$22,4);
  $28 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($28,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip10FloatCurve8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN17AnimationCurveTplIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 12|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $2 = (($this) + 24|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = HEAP32[$2>>2]|0;
  HEAP32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
  $10 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($10,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN17AnimationCurveTplI8Vector3fE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i9 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i10 = 0, $$pre3$i$i$i3 = 0, $$pre4$i$i$i = 0, $$pre4$i$i$i12 = 0, $$pre4$i$i$i5 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i13 = 0, $$pre5$i$i$i6 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $i$01$i$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$size$i$i$i>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i,4);
 }
 $8 = (($this) + 120|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$0>>2]|0;
 $11 = (($9) + (($10*40)|0)|0);
 $12 = ($10|0)==(0);
 if (!($12)) {
  $i$01$i$i$i = $9;
  while(1) {
   $13 = HEAP32[$2>>2]|0;
   $14 = (($13) + 4|0);
   $15 = HEAP32[$5>>2]|0;
   $16 = ($14>>>0)<($15>>>0);
   if ($16) {
    $17 = Math_fround(HEAPF32[$i$01$i$i$i>>2]);
    HEAPF32[$13>>2] = $17;
    HEAP32[$2>>2] = $14;
    $20 = $14;$22 = $15;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i,4);
    $$pre17 = HEAP32[$2>>2]|0;
    $$pre18 = HEAP32[$5>>2]|0;
    $20 = $$pre17;$22 = $$pre18;
   }
   $18 = (($i$01$i$i$i) + 4|0);
   $19 = (($20) + 4|0);
   $21 = ($19>>>0)<($22>>>0);
   if ($21) {
    $23 = Math_fround(HEAPF32[$18>>2]);
    HEAPF32[$20>>2] = $23;
    HEAP32[$2>>2] = $19;
    $26 = $19;$28 = $22;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$18,4);
    $$pre$i$i$i = HEAP32[$2>>2]|0;
    $$pre3$i$i$i = HEAP32[$5>>2]|0;
    $26 = $$pre$i$i$i;$28 = $$pre3$i$i$i;
   }
   $24 = (($i$01$i$i$i) + 8|0);
   $25 = (($26) + 4|0);
   $27 = ($25>>>0)<($28>>>0);
   if ($27) {
    $29 = Math_fround(HEAPF32[$24>>2]);
    HEAPF32[$26>>2] = $29;
    HEAP32[$2>>2] = $25;
    $32 = $25;$34 = $28;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$24,4);
    $$pre4$i$i$i = HEAP32[$2>>2]|0;
    $$pre5$i$i$i = HEAP32[$5>>2]|0;
    $32 = $$pre4$i$i$i;$34 = $$pre5$i$i$i;
   }
   $30 = (($i$01$i$i$i) + 12|0);
   $31 = (($32) + 4|0);
   $33 = ($31>>>0)<($34>>>0);
   if ($33) {
    $35 = Math_fround(HEAPF32[$30>>2]);
    HEAPF32[$32>>2] = $35;
    HEAP32[$2>>2] = $31;
    $38 = $31;$40 = $34;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$30,4);
    $$pre19 = HEAP32[$2>>2]|0;
    $$pre20 = HEAP32[$5>>2]|0;
    $38 = $$pre19;$40 = $$pre20;
   }
   $36 = (($i$01$i$i$i) + 16|0);
   $37 = (($38) + 4|0);
   $39 = ($37>>>0)<($40>>>0);
   if ($39) {
    $41 = Math_fround(HEAPF32[$36>>2]);
    HEAPF32[$38>>2] = $41;
    HEAP32[$2>>2] = $37;
    $44 = $37;$46 = $40;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$36,4);
    $$pre$i$i$i2 = HEAP32[$2>>2]|0;
    $$pre3$i$i$i3 = HEAP32[$5>>2]|0;
    $44 = $$pre$i$i$i2;$46 = $$pre3$i$i$i3;
   }
   $42 = (($i$01$i$i$i) + 20|0);
   $43 = (($44) + 4|0);
   $45 = ($43>>>0)<($46>>>0);
   if ($45) {
    $47 = Math_fround(HEAPF32[$42>>2]);
    HEAPF32[$44>>2] = $47;
    HEAP32[$2>>2] = $43;
    $50 = $43;$52 = $46;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$42,4);
    $$pre4$i$i$i5 = HEAP32[$2>>2]|0;
    $$pre5$i$i$i6 = HEAP32[$5>>2]|0;
    $50 = $$pre4$i$i$i5;$52 = $$pre5$i$i$i6;
   }
   $48 = (($i$01$i$i$i) + 24|0);
   $49 = (($50) + 4|0);
   $51 = ($49>>>0)<($52>>>0);
   if ($51) {
    $53 = Math_fround(HEAPF32[$48>>2]);
    HEAPF32[$50>>2] = $53;
    HEAP32[$2>>2] = $49;
    $56 = $49;$58 = $52;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$48,4);
    $$pre21 = HEAP32[$2>>2]|0;
    $$pre22 = HEAP32[$5>>2]|0;
    $56 = $$pre21;$58 = $$pre22;
   }
   $54 = (($i$01$i$i$i) + 28|0);
   $55 = (($56) + 4|0);
   $57 = ($55>>>0)<($58>>>0);
   if ($57) {
    $59 = Math_fround(HEAPF32[$54>>2]);
    HEAPF32[$56>>2] = $59;
    HEAP32[$2>>2] = $55;
    $62 = $55;$64 = $58;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$54,4);
    $$pre$i$i$i9 = HEAP32[$2>>2]|0;
    $$pre3$i$i$i10 = HEAP32[$5>>2]|0;
    $62 = $$pre$i$i$i9;$64 = $$pre3$i$i$i10;
   }
   $60 = (($i$01$i$i$i) + 32|0);
   $61 = (($62) + 4|0);
   $63 = ($61>>>0)<($64>>>0);
   if ($63) {
    $65 = Math_fround(HEAPF32[$60>>2]);
    HEAPF32[$62>>2] = $65;
    HEAP32[$2>>2] = $61;
    $68 = $61;$70 = $64;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$60,4);
    $$pre4$i$i$i12 = HEAP32[$2>>2]|0;
    $$pre5$i$i$i13 = HEAP32[$5>>2]|0;
    $68 = $$pre4$i$i$i12;$70 = $$pre5$i$i$i13;
   }
   $66 = (($i$01$i$i$i) + 36|0);
   $67 = (($68) + 4|0);
   $69 = ($67>>>0)<($70>>>0);
   if ($69) {
    $71 = Math_fround(HEAPF32[$66>>2]);
    HEAPF32[$68>>2] = $71;
    HEAP32[$2>>2] = $67;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$66,4);
   }
   $72 = (($i$01$i$i$i) + 40|0);
   $73 = ($72|0)==($11|0);
   if ($73) {
    break;
   } else {
    $i$01$i$i$i = $72;
   }
  }
 }
 $74 = (($this) + 136|0);
 $75 = HEAP32[$2>>2]|0;
 $76 = (($75) + 4|0);
 $77 = HEAP32[$5>>2]|0;
 $78 = ($76>>>0)<($77>>>0);
 if ($78) {
  $79 = HEAP32[$74>>2]|0;
  HEAP32[$75>>2] = $79;
  HEAP32[$2>>2] = $76;
  $82 = $76;$84 = $77;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$74,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre16 = HEAP32[$5>>2]|0;
  $82 = $$pre;$84 = $$pre16;
 }
 $80 = (($this) + 140|0);
 $81 = (($82) + 4|0);
 $83 = ($81>>>0)<($84>>>0);
 if ($83) {
  $85 = HEAP32[$80>>2]|0;
  HEAP32[$82>>2] = $85;
  HEAP32[$2>>2] = $81;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$80,4);
  STACKTOP = sp;return;
 }
}
function __ZN24CompressedAnimationCurve8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i = sp;
 $0 = (($this) + 72|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 __ZN15PackedIntVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $1 = (($this) + 20|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  $8 = HEAP32[$1>>2]|0;
  HEAP32[$3>>2] = $8;
  HEAP32[$2>>2] = $4;
  $17 = $4;$19 = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$1,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre2 = HEAP32[$5>>2]|0;
  $17 = $$pre;$19 = $$pre2;
 }
 $9 = (($this) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $10;
 $14 = $12;
 $15 = (($13) - ($14))|0;
 HEAP32[$size$i$i$i>>2] = $15;
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)<($19>>>0);
 if ($18) {
  HEAP32[$17>>2] = $15;
  HEAP32[$2>>2] = $16;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i,4);
 }
 $20 = HEAP32[$9>>2]|0;
 $21 = HEAP32[$11>>2]|0;
 $22 = ($21|0)==($20|0);
 if (!($22)) {
  $28 = $21;
  while(1) {
   $23 = HEAP32[$2>>2]|0;
   $24 = (($23) + 1|0);
   $25 = HEAP32[$5>>2]|0;
   $26 = ($24>>>0)<($25>>>0);
   if ($26) {
    $27 = HEAP8[$28>>0]|0;
    HEAP8[$23>>0] = $27;
    $29 = HEAP32[$2>>2]|0;
    $30 = (($29) + 1|0);
    HEAP32[$2>>2] = $30;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$28,1);
   }
   $31 = (($28) + 1|0);
   $32 = ($31|0)==($20|0);
   if ($32) {
    break;
   } else {
    $28 = $31;
   }
  }
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $33 = (($this) + 36|0);
 __ZN17PackedFloatVector8TransferI19StreamedBinaryWriteILb0EEEEvRT_($33,$transfer);
 $34 = (($this) + 64|0);
 $35 = HEAP32[$2>>2]|0;
 $36 = (($35) + 4|0);
 $37 = HEAP32[$5>>2]|0;
 $38 = ($36>>>0)<($37>>>0);
 if ($38) {
  $39 = HEAP32[$34>>2]|0;
  HEAP32[$35>>2] = $39;
  HEAP32[$2>>2] = $36;
  $42 = $36;$44 = $37;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$34,4);
  $$pre3 = HEAP32[$2>>2]|0;
  $$pre4 = HEAP32[$5>>2]|0;
  $42 = $$pre3;$44 = $$pre4;
 }
 $40 = (($this) + 68|0);
 $41 = (($42) + 4|0);
 $43 = ($41>>>0)<($44>>>0);
 if ($43) {
  $45 = HEAP32[$40>>2]|0;
  HEAP32[$42>>2] = $45;
  HEAP32[$2>>2] = $41;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$40,4);
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip15QuaternionCurve8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 164|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 180|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  $8 = HEAP32[$1>>2]|0;
  HEAP32[$3>>2] = $8;
  HEAP32[$2>>2] = $4;
  $11 = $4;$13 = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$1,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $$pre2$i$i$i = HEAP32[$5>>2]|0;
  $11 = $$pre$i$i$i;$13 = $$pre2$i$i$i;
 }
 $9 = (($this) + 184|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)<($13>>>0);
 if ($12) {
  $14 = HEAP32[$9>>2]|0;
  HEAP32[$11>>2] = $14;
  HEAP32[$2>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$9,4);
 }
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size,4);
 }
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$1>>2]|0;
 $11 = (($9) + (($10*52)|0)|0);
 $12 = ($10|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $9;
 }
 while(1) {
  $13 = HEAP32[$3>>2]|0;
  $14 = (($13) + 4|0);
  $15 = HEAP32[$6>>2]|0;
  $16 = ($14>>>0)<($15>>>0);
  if ($16) {
   $17 = Math_fround(HEAPF32[$i$01>>2]);
   HEAPF32[$13>>2] = $17;
   HEAP32[$3>>2] = $14;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$i$01,4);
  }
  $18 = (($i$01) + 4|0);
  __ZN11Quaternionf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($18,$this);
  $19 = (($i$01) + 20|0);
  __ZN11Quaternionf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($19,$this);
  $20 = (($i$01) + 36|0);
  __ZN11Quaternionf8TransferI19StreamedBinaryWriteILb0EEEEvRT_($20,$this);
  $21 = (($i$01) + 52|0);
  $22 = ($21|0)==($11|0);
  if ($22) {
   break;
  } else {
   $i$01 = $21;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13AnimationClip8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy8 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i16 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $empty = 0, $empty1 = 0, $i$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 44|0;
 $0 = sp;
 $1 = sp + 4|0;
 $empty = sp + 8|0;
 $empty1 = sp + 20|0;
 $value = sp + 32|0;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $2 = (($this) + 164|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,1);
  $$pre = HEAP32[$3>>2]|0;
  $14 = $$pre;
 } else {
  $9 = HEAP8[$4>>0]|0;
  HEAP8[$2>>0] = $9;
  $10 = HEAP32[$3>>2]|0;
  $11 = (($10) + 1|0);
  HEAP32[$3>>2] = $11;
  $14 = $11;
 }
 $12 = (($this) + 84|0);
 $13 = (($14) + 1|0);
 $15 = HEAP32[$6>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$12,1);
  $$pre17 = HEAP32[$3>>2]|0;
  $22 = $$pre17;
 } else {
  $17 = HEAP8[$14>>0]|0;
  HEAP8[$12>>0] = $17;
  $18 = HEAP32[$3>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$3>>2] = $19;
  $22 = $19;
 }
 $20 = (($this) + 85|0);
 $21 = (($22) + 1|0);
 $23 = HEAP32[$6>>2]|0;
 $24 = ($21>>>0)>($23>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$20,1);
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$3>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$3>>2] = $27;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $28 = HEAP8[$12>>0]|0;
 $29 = ($28<<24>>24)==(0);
 L13: do {
  if ($29) {
   $30 = (($this) + 92|0);
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$30,0);
   HEAP32[$empty>>2] = 0;
   $31 = (($empty) + 4|0);
   HEAP32[$31>>2] = 0;
   $32 = (($empty) + 8|0);
   HEAP32[$32>>2] = 0;
   __THREW__ = 0;
   invoke_viii(1999,($transfer|0),($empty|0),0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    $35 = HEAP32[$empty>>2]|0;
    $36 = ($35|0)==(0|0);
    if ($36) {
     break;
    }
    while(1) {
     $37 = HEAP32[$31>>2]|0;
     $38 = ($37|0)==($35|0);
     if ($38) {
      break;
     }
     $39 = (($37) + -84|0);
     HEAP32[$31>>2] = $39;
     __THREW__ = 0;
     invoke_vi(3690,($39|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      label = 15;
      break;
     }
    }
    if ((label|0) == 15) {
     $42 = ___cxa_find_matching_catch()|0;
     $43 = tempRet0;
     ___cxa_call_unexpected(($42|0));
     // unreachable;
    }
    $44 = HEAP32[$empty>>2]|0;
    HEAP32[$1>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($44|0),($$byval_copy8|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     break;
    }
    $47 = ___cxa_find_matching_catch()|0;
    $48 = tempRet0;
    ___cxa_call_unexpected(($47|0));
    // unreachable;
   }
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $51 = HEAP32[$empty>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    $$1 = $50;$$12 = $49;
    ___resumeException($$12|0);
    // unreachable;
   }
   while(1) {
    $53 = HEAP32[$31>>2]|0;
    $54 = ($53|0)==($51|0);
    if ($54) {
     break;
    }
    $55 = (($53) + -84|0);
    HEAP32[$31>>2] = $55;
    __THREW__ = 0;
    invoke_vi(3690,($55|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     label = 21;
     break;
    }
   }
   if ((label|0) == 21) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    ___cxa_call_unexpected(($58|0));
    // unreachable;
   }
   $60 = HEAP32[$empty>>2]|0;
   HEAP32[$1>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy8|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    ___cxa_call_unexpected(($63|0));
    // unreachable;
   } else {
    $$1 = $50;$$12 = $49;
    ___resumeException($$12|0);
    // unreachable;
   }
  } else {
   HEAP32[$empty1>>2] = 0;
   $65 = (($empty1) + 4|0);
   HEAP32[$65>>2] = 0;
   $66 = (($empty1) + 8|0);
   HEAP32[$66>>2] = 0;
   __THREW__ = 0;
   invoke_viii(2000,($transfer|0),($empty1|0),0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   L37: do {
    if ($68) {
     $76 = ___cxa_find_matching_catch()|0;
     $77 = tempRet0;
     $$0 = $77;$$01 = $76;
    } else {
     $69 = HEAP32[$transfer>>2]|0;
     $70 = $69 & 33554432;
     $71 = ($70|0)==(0);
     L40: do {
      if ($71) {
       HEAP32[$value>>2] = 0;
       $72 = (($value) + 4|0);
       HEAP32[$72>>2] = 0;
       $73 = (($value) + 8|0);
       HEAP32[$73>>2] = 0;
       __THREW__ = 0;
       invoke_viii(1999,($transfer|0),($value|0),0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       L42: do {
        if ($75) {
         label = 29;
        } else {
         $96 = (($this) + 92|0);
         $97 = HEAP32[$72>>2]|0;
         $98 = HEAP32[$value>>2]|0;
         $99 = $97;
         $100 = $98;
         $101 = (($99) - ($100))|0;
         $102 = (($101|0) / 84)&-1;
         __THREW__ = 0;
         invoke_vii(3371,($96|0),($102|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          label = 29;
         } else {
          $105 = HEAP32[$72>>2]|0;
          $106 = HEAP32[$value>>2]|0;
          $107 = ($105|0)==($106|0);
          L45: do {
           if ($107) {
            $123 = $105;$166 = $105;
           } else {
            $109 = $106;$i$01$i = 0;
            while(1) {
             $108 = (($109) + (($i$01$i*84)|0)|0);
             $110 = HEAP32[$96>>2]|0;
             $111 = (($110) + (($i$01$i*192)|0)|0);
             __THREW__ = 0;
             invoke_vii(3372,($108|0),($111|0));
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if ($113) {
              break;
             }
             $114 = (($i$01$i) + 1)|0;
             $115 = HEAP32[$72>>2]|0;
             $116 = HEAP32[$value>>2]|0;
             $117 = $115;
             $118 = $116;
             $119 = (($117) - ($118))|0;
             $120 = (($119|0) / 84)&-1;
             $121 = ($114>>>0)<($120>>>0);
             if ($121) {
              $109 = $116;$i$01$i = $114;
             } else {
              $123 = $116;$166 = $115;
              break L45;
             }
            }
            $78 = ___cxa_find_matching_catch()|0;
            $79 = tempRet0;
            $lpad$phi$index = $78;$lpad$phi$index2 = $79;
            break L42;
           }
          } while(0);
          $122 = ($123|0)==(0|0);
          if ($122) {
           break L40;
          } else {
           $125 = $166;
          }
          while(1) {
           $124 = ($125|0)==($123|0);
           if ($124) {
            break;
           }
           $126 = (($125) + -84|0);
           HEAP32[$72>>2] = $126;
           __THREW__ = 0;
           invoke_vi(3690,($126|0));
           $127 = __THREW__; __THREW__ = 0;
           $128 = $127&1;
           if ($128) {
            label = 45;
            break;
           }
           $$pre20 = HEAP32[$72>>2]|0;
           $125 = $$pre20;
          }
          if ((label|0) == 45) {
           $129 = ___cxa_find_matching_catch()|0;
           $130 = tempRet0;
           ___cxa_call_unexpected(($129|0));
           // unreachable;
          }
          $131 = HEAP32[$value>>2]|0;
          HEAP32[$0>>2] = 18;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($131|0),($$byval_copy8|0));
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if (!($133)) {
           break L40;
          }
          $134 = ___cxa_find_matching_catch()|0;
          $135 = tempRet0;
          ___cxa_call_unexpected(($134|0));
          // unreachable;
         }
        }
       } while(0);
       if ((label|0) == 29) {
        $80 = ___cxa_find_matching_catch()|0;
        $81 = tempRet0;
        $lpad$phi$index = $80;$lpad$phi$index2 = $81;
       }
       $82 = HEAP32[$value>>2]|0;
       $83 = ($82|0)==(0|0);
       if ($83) {
        $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
        break L37;
       }
       while(1) {
        $84 = HEAP32[$72>>2]|0;
        $85 = ($84|0)==($82|0);
        if ($85) {
         break;
        }
        $86 = (($84) + -84|0);
        HEAP32[$72>>2] = $86;
        __THREW__ = 0;
        invoke_vi(3690,($86|0));
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         label = 33;
         break;
        }
       }
       if ((label|0) == 33) {
        $89 = ___cxa_find_matching_catch()|0;
        $90 = tempRet0;
        ___cxa_call_unexpected(($89|0));
        // unreachable;
       }
       $91 = HEAP32[$value>>2]|0;
       HEAP32[$0>>2] = 18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($91|0),($$byval_copy8|0));
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if (!($93)) {
        $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
        break L37;
       }
       $94 = ___cxa_find_matching_catch()|0;
       $95 = tempRet0;
       ___cxa_call_unexpected(($94|0));
       // unreachable;
      }
     } while(0);
     __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
     break L13;
    }
   } while(0);
   __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
   $$1 = $$0;$$12 = $$01;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $136 = (($this) + 104|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$136,0);
 $137 = (($this) + 116|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$137,0);
 $138 = (($this) + 128|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$138,0);
 $139 = (($this) + 140|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$139,0);
 $140 = (($this) + 80|0);
 $141 = HEAP32[$3>>2]|0;
 $142 = (($141) + 4|0);
 $143 = HEAP32[$6>>2]|0;
 $144 = ($142>>>0)>($143>>>0);
 if ($144) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$140,4);
  $$pre$i$i$i = HEAP32[$140>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $$pre19 = HEAP32[$6>>2]|0;
  $$pre$phi$i$i$iZ2D = $140;$147 = $$pre$i$i$i;$151 = $$pre18;$153 = $$pre19;
 } else {
  $145 = Math_fround(HEAPF32[$141>>2]);
  HEAPF32[$140>>2] = $145;
  HEAP32[$3>>2] = $142;
  $146 = (HEAPF32[tempDoublePtr>>2]=$145,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $140;$147 = $146;$151 = $142;$153 = $143;
 }
 $148 = (_llvm_bswap_i32(($147|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $148;
 $149 = (($this) + 88|0);
 $150 = (($151) + 4|0);
 $152 = ($150>>>0)>($153>>>0);
 if ($152) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$149,4);
  $$pre$i$i$i16 = HEAP32[$149>>2]|0;
  $155 = $$pre$i$i$i16;
  $156 = (_llvm_bswap_i32(($155|0))|0);
  HEAP32[$149>>2] = $156;
  $157 = (($this) + 216|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$157,0,0);
  $158 = (($this) + 228|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$158,0,0);
  $159 = (($this) + 48|0);
  $160 = (($transfer) + 4|0);
  HEAP32[$160>>2] = $159;
  $161 = (($this) + 168|0);
  $162 = (($this) + 172|0);
  __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE18StreamedBinaryReadILb1EEEvRPT_PKcRjS9_RT0_($161,766608,$162,766624,$transfer);
  $163 = (($this) + 176|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEEEvRT_17TransferMetaFlags($transfer,$163,0);
  $164 = (($this) + 192|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$164,0);
  $165 = (($this) + 152|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$165,0);
  STACKTOP = sp;return;
 } else {
  $154 = HEAP32[$151>>2]|0;
  HEAP32[$149>>2] = $154;
  HEAP32[$3>>2] = $150;
  $155 = $154;
  $156 = (_llvm_bswap_i32(($155|0))|0);
  HEAP32[$149>>2] = $156;
  $157 = (($this) + 216|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$157,0,0);
  $158 = (($this) + 228|0);
  __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$158,0,0);
  $159 = (($this) + 48|0);
  $160 = (($transfer) + 4|0);
  HEAP32[$160>>2] = $159;
  $161 = (($this) + 168|0);
  $162 = (($this) + 172|0);
  __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE18StreamedBinaryReadILb1EEEvRPT_PKcRjS9_RT0_($161,766608,$162,766624,$transfer);
  $163 = (($this) + 176|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEEEvRT_17TransferMetaFlags($transfer,$163,0);
  $164 = (($this) + 192|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$164,0);
  $165 = (($this) + 152|0);
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$165,0);
  STACKTOP = sp;return;
 }
}
function __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE18StreamedBinaryReadILb1EEEvRPT_PKcRjS9_RT0_($data,$name,$size,$sizeName,$transfer) {
 $data = $data|0;
 $name = $name|0;
 $size = $size|0;
 $sizeName = $sizeName|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$size>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$size>>2] = $8;
 $9 = HEAP32[$data>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $43 = $9;
  __ZN7mecanim9animation18ClipMuscleConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($43,$transfer);
  STACKTOP = sp;return;
 }
 $11 = (($transfer) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN7mecanim6memory16ChainedAllocator7ReserveEj($12,$8);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_iiii[$14 & 2047]($12,1644,4)|0);
 $16 = ($15|0)==(0|0);
 if ($16) {
  $42 = 0;
 } else {
  __ZN7mecanim5human9HumanPoseC2Ev($15);
  $17 = (($15) + 880|0);
  $18 = (($15) + 908|0);
  ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;HEAP32[$17+16>>2]=0|0;HEAP32[$17+20>>2]=0|0;HEAP32[$17+24>>2]=0|0;
  HEAPF32[$18>>2] = Math_fround(1.0);
  $19 = (($15) + 912|0);
  HEAPF32[$19>>2] = Math_fround(1.0);
  $20 = (($15) + 916|0);
  HEAPF32[$20>>2] = Math_fround(1.0);
  $21 = (($15) + 920|0);
  HEAPF32[$21>>2] = Math_fround(1.0);
  $22 = (($15) + 924|0);
  HEAPF32[$22>>2] = Math_fround(1.0);
  $23 = (($15) + 928|0);
  $24 = (($15) + 956|0);
  ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;HEAP32[$23+16>>2]=0|0;HEAP32[$23+20>>2]=0|0;HEAP32[$23+24>>2]=0|0;
  HEAPF32[$24>>2] = Math_fround(1.0);
  $25 = (($15) + 960|0);
  HEAPF32[$25>>2] = Math_fround(1.0);
  $26 = (($15) + 964|0);
  HEAPF32[$26>>2] = Math_fround(1.0);
  $27 = (($15) + 968|0);
  HEAPF32[$27>>2] = Math_fround(1.0);
  $28 = (($15) + 972|0);
  HEAPF32[$28>>2] = Math_fround(1.0);
  $29 = (($15) + 976|0);
  $30 = (($15) + 1004|0);
  ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;HEAP32[$29+16>>2]=0|0;HEAP32[$29+20>>2]=0|0;HEAP32[$29+24>>2]=0|0;
  HEAPF32[$30>>2] = Math_fround(1.0);
  $31 = (($15) + 1008|0);
  HEAPF32[$31>>2] = Math_fround(1.0);
  $32 = (($15) + 1012|0);
  HEAPF32[$32>>2] = Math_fround(1.0);
  $33 = (($15) + 1016|0);
  HEAPF32[$33>>2] = Math_fround(1.0);
  $34 = (($15) + 1020|0);
  HEAPF32[$34>>2] = Math_fround(1.0);
  $35 = (($15) + 1024|0);
  $36 = (($15) + 1052|0);
  ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;HEAP32[$35+20>>2]=0|0;HEAP32[$35+24>>2]=0|0;
  HEAPF32[$36>>2] = Math_fround(1.0);
  $37 = (($15) + 1056|0);
  $38 = (($15) + 1620|0);
  $39 = (($15) + 1639|0);
  ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;
  ;HEAP32[$38+0>>2]=0|0;HEAP32[$38+4>>2]=0|0;HEAP32[$38+8>>2]=0|0;HEAP32[$38+12>>2]=0|0;HEAP16[$38+16>>1]=0|0;HEAP8[$38+18>>0]=0|0;
  HEAP8[$39>>0] = 1;
  $40 = (($15) + 1640|0);
  HEAP8[$40>>0] = 0;
  $41 = (($15) + 1641|0);
  HEAP8[$41>>0] = 0;
  $scevgep$i$i$i = (($15) + 1072|0);
  _memset(($scevgep$i$i$i|0),-1,548)|0;
  $42 = $15;
 }
 HEAP32[$data>>2] = $42;
 $43 = $42;
 __ZN7mecanim9animation18ClipMuscleConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($43,$transfer);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI14AnimationEvent13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN14AnimationEvent8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 56|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*56)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI14AnimationEvent13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre1$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$i$i$index = 0, $lpad$phi$i$i$index2 = 0, $temp = 0;
 var $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $temp1 = sp + 24|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = ($8>>>0)<($sz>>>0);
 if ($9) {
  $10 = (($v) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($6))|0;
  $14 = (($13|0) / 56)&-1;
  $15 = ($14|0)==($sz|0);
  if ($15) {
   __ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE6resizeEj($v,$sz);
   STACKTOP = sp;return;
  }
  HEAP32[$temp>>2] = 0;
  $16 = (($temp) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($temp) + 8|0);
  HEAP32[$17>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3373,($temp|0),($sz|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = HEAP32[$v>>2]|0;
   HEAP32[$0>>2] = $20;
   $21 = HEAP32[$2>>2]|0;
   HEAP32[$1>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(2001,($temp|0),($$byval_copy|0),($$byval_copy7|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    invoke_vii(3374,($temp|0),($sz|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = HEAP32[$temp>>2]|0;
     $27 = HEAP32[$v>>2]|0;
     HEAP32[$temp>>2] = $27;
     HEAP32[$v>>2] = $26;
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$2>>2]|0;
     HEAP32[$16>>2] = $29;
     HEAP32[$2>>2] = $28;
     $30 = HEAP32[$17>>2]|0;
     $31 = HEAP32[$10>>2]|0;
     HEAP32[$17>>2] = $31;
     HEAP32[$10>>2] = $30;
     __ZNSt3__113__vector_baseI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($temp);
     STACKTOP = sp;return;
    }
   }
  }
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  __ZNSt3__113__vector_baseI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($temp);
  $$0 = $33;$$01 = $32;
  ___resumeException($$01|0);
  // unreachable;
 }
 $34 = ($8>>>0)>($sz>>>0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 $35 = (($4) + (($sz*56)|0)|0);
 HEAP32[$temp1>>2] = 0;
 $36 = (($temp1) + 4|0);
 HEAP32[$36>>2] = 0;
 $37 = (($temp1) + 8|0);
 HEAP32[$37>>2] = 0;
 $$idx = ($sz*56)|0;
 $38 = (($$idx|0) / 56)&-1;
 $39 = ($sz|0)==(0);
 L18: do {
  if ($39) {
   $60 = $4;$61 = 0;$62 = $3;$63 = 0;$66 = 0;
  } else {
   $40 = ($$idx|0)<(0);
   do {
    if ($40) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 21;
     } else {
      // unreachable;
     }
    } else {
     HEAP32[$$byval_copy>>2] = 18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
     $43 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(766088|0),79)|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 21;
     } else {
      HEAP32[$36>>2] = $43;
      HEAP32[$temp1>>2] = $43;
      $46 = (($43) + (($38*56)|0)|0);
      HEAP32[$37>>2] = $46;
      $48 = $43;$49 = $4;
      while(1) {
       $47 = ($48|0)==(0|0);
       if ($47) {
        $53 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(3375,($48|0),($49|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 20;
         break;
        }
        $$pre1$i$i$i = HEAP32[$36>>2]|0;
        $53 = $$pre1$i$i$i;
       }
       $52 = (($53) + 56|0);
       HEAP32[$36>>2] = $52;
       $54 = (($49) + 56|0);
       $55 = ($54|0)==($35|0);
       if ($55) {
        label = 22;
        break;
       } else {
        $48 = $52;$49 = $54;
       }
      }
      if ((label|0) == 20) {
       $56 = ___cxa_find_matching_catch()|0;
       $57 = tempRet0;
       $lpad$phi$i$i$index = $56;$lpad$phi$i$i$index2 = $57;
       break;
      }
      else if ((label|0) == 22) {
       $$pre = HEAP32[$temp1>>2]|0;
       $$pre9 = HEAP32[$v>>2]|0;
       $$pre10 = HEAP32[$2>>2]|0;
       $$pre11 = HEAP32[$37>>2]|0;
       $60 = $$pre9;$61 = $$pre;$62 = $$pre10;$63 = $52;$66 = $$pre11;
       break L18;
      }
     }
    }
   } while(0);
   if ((label|0) == 21) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    $lpad$phi$i$i$index = $58;$lpad$phi$i$i$index2 = $59;
   }
   __ZNSt3__113__vector_baseI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($temp1);
   $$0 = $lpad$phi$i$i$index2;$$01 = $lpad$phi$i$i$index;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$temp1>>2] = $60;
 HEAP32[$v>>2] = $61;
 HEAP32[$36>>2] = $62;
 HEAP32[$2>>2] = $63;
 $64 = (($v) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 HEAP32[$37>>2] = $65;
 HEAP32[$64>>2] = $66;
 __ZNSt3__113__vector_baseI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($temp1);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 56)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 56)&-1;
 $15 = (($__v) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($__v) + 16|0);
 HEAP32[$16>>2] = $9;
 $17 = ($__n|0)==(0);
 if ($17) {
  $20 = 0;$26 = $11;$27 = $3;
 } else {
  $18 = ($__n*56)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $19 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,16,$$byval_copy,0,766088,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre1 = HEAP32[$10>>2]|0;
  $20 = $19;$26 = $$pre1;$27 = $$pre;
 }
 HEAP32[$__v>>2] = $20;
 $21 = (($20) + (($14*56)|0)|0);
 $22 = (($__v) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($__v) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = (($20) + (($__n*56)|0)|0);
 HEAP32[$15>>2] = $24;
 $25 = ($26|0)==($27|0);
 do {
  if ($25) {
   $36 = $21;$37 = $26;$38 = $21;$39 = $26;$41 = $24;
  } else {
   $$01$i$i = $26;$29 = $21;
   while(1) {
    $28 = (($29) + -56|0);
    $30 = (($$01$i$i) + -56|0);
    __THREW__ = 0;
    invoke_vii(3375,($28|0),($30|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     label = 10;
     break;
    }
    $33 = HEAP32[$23>>2]|0;
    $34 = (($33) + -56|0);
    HEAP32[$23>>2] = $34;
    $35 = ($30|0)==($27|0);
    if ($35) {
     label = 7;
     break;
    } else {
     $$01$i$i = $30;$29 = $34;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre2 = HEAP32[$10>>2]|0;
    $$pre3 = HEAP32[$22>>2]|0;
    $$pre4 = HEAP32[$15>>2]|0;
    $36 = $34;$37 = $$pre$i;$38 = $$pre3;$39 = $$pre2;$41 = $$pre4;
    break;
   }
   else if ((label|0) == 10) {
    $42 = ___cxa_find_matching_catch()|0;
    $43 = tempRet0;
    __ZNSt3__114__split_bufferI14AnimationEventR13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
    ___resumeException($42|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $36;
 HEAP32[$23>>2] = $37;
 HEAP32[$10>>2] = $38;
 HEAP32[$22>>2] = $39;
 $40 = HEAP32[$1>>2]|0;
 HEAP32[$1>>2] = $41;
 HEAP32[$15>>2] = $40;
 HEAP32[$__v>>2] = $37;
 __ZNSt3__114__split_bufferI14AnimationEventR13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i32 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy2 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$__first>>2]|0;
 $3 = HEAP32[$__last>>2]|0;
 $4 = $3;
 $5 = $2;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 56)&-1;
 $8 = (($this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = $9;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = (($13|0) / 56)&-1;
 $15 = ($7>>>0)>($14>>>0);
 if ($15) {
  __ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE10deallocateEv($this);
  $76 = ($6|0)<(0);
  if ($76) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $77 = HEAP32[$8>>2]|0;
  $78 = HEAP32[$this>>2]|0;
  $79 = $77;
  $80 = $78;
  $81 = (($79) - ($80))|0;
  $82 = (($81|0) / 56)&-1;
  $83 = ($82>>>0)<(1073741823);
  if ($83) {
   $84 = $82 << 1;
   $85 = ($84>>>0)<($7>>>0);
   $86 = $85 ? $7 : $84;
   $87 = ($86|0)<(0);
   if ($87) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i32 = $86;
   }
  } else {
   $$0$i32 = 2147483647;
  }
  $88 = ($$0$i32*56)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $89 = (__Z15malloc_internaljj10MemLabelIdiPKci($88,16,$$byval_copy2,0,766088,79)|0);
  $90 = (($this) + 4|0);
  HEAP32[$90>>2] = $89;
  HEAP32[$this>>2] = $89;
  $91 = (($89) + (($$0$i32*56)|0)|0);
  HEAP32[$8>>2] = $91;
  $92 = ($2|0)==($3|0);
  if ($92) {
   STACKTOP = sp;return;
  } else {
   $94 = $89;$95 = $2;
  }
  while(1) {
   $93 = ($94|0)==(0|0);
   if ($93) {
    $97 = 0;
   } else {
    __ZN14AnimationEventC1ERKS_($94,$95);
    $$pre1$i = HEAP32[$90>>2]|0;
    $97 = $$pre1$i;
   }
   $96 = (($97) + 56|0);
   HEAP32[$90>>2] = $96;
   $98 = (($95) + 56|0);
   $99 = ($98|0)==($3|0);
   if ($99) {
    break;
   } else {
    $94 = $96;$95 = $98;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17;
 $19 = (($18) - ($12))|0;
 $20 = (($19|0) / 56)&-1;
 $21 = ($7>>>0)>($20>>>0);
 if ($21) {
  $22 = (($2) + (($20*56)|0)|0);
  $24 = $22;$__growing$0$off0 = 1;
 } else {
  $24 = $3;$__growing$0$off0 = 0;
 }
 $23 = ($2|0)==($24|0);
 if ($23) {
  $$0$lcssa$i$i = $10;
 } else {
  $scevgep$i = (($24) + -56|0);
  $25 = (0 - ($5))|0;
  $uglygep$i = (($scevgep$i) + ($25)|0);
  $uglygep16$i = $uglygep$i;
  $26 = (($uglygep16$i>>>0) / 56)&-1;
  $$01$i$i = $10;$28 = $2;
  while(1) {
   $27 = Math_fround(HEAPF32[$28>>2]);
   HEAPF32[$$01$i$i>>2] = $27;
   $29 = (($$01$i$i) + 4|0);
   $30 = (($28) + 4|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($29,$30)|0);
   $31 = (($$01$i$i) + 16|0);
   $32 = (($28) + 16|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($31,$32)|0);
   $33 = (($28) + 28|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($$01$i$i) + 28|0);
   HEAP32[$35>>2] = $34;
   $36 = (($$01$i$i) + 32|0);
   $37 = (($28) + 32|0);
   ;HEAP32[$36+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$37+12>>2]|0;HEAP32[$36+16>>2]=HEAP32[$37+16>>2]|0;HEAP32[$36+20>>2]=HEAP32[$37+20>>2]|0;
   $38 = (($28) + 56|0);
   $39 = (($$01$i$i) + 56|0);
   $40 = ($38|0)==($24|0);
   if ($40) {
    break;
   } else {
    $$01$i$i = $39;$28 = $38;
   }
  }
  $41 = (($26) + 1)|0;
  $scevgep17$i = (($10) + (($41*56)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  $42 = ($24|0)==($3|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$16>>2]|0;
  $44 = $$pre$i12;$45 = $24;
  while(1) {
   $43 = ($44|0)==(0|0);
   if ($43) {
    $47 = 0;
   } else {
    __ZN14AnimationEventC1ERKS_($44,$45);
    $$pre1$i14 = HEAP32[$16>>2]|0;
    $47 = $$pre1$i14;
   }
   $46 = (($47) + 56|0);
   HEAP32[$16>>2] = $46;
   $48 = (($45) + 56|0);
   $49 = ($48|0)==($3|0);
   if ($49) {
    break;
   } else {
    $44 = $46;$45 = $48;
   }
  }
  STACKTOP = sp;return;
 }
 $50 = HEAP32[$16>>2]|0;
 $51 = ($50|0)==($$0$lcssa$i$i|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $53 = $50;
 while(1) {
  $52 = (($53) + -56|0);
  HEAP32[$16>>2] = $52;
  $54 = (($53) + -40|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55 & 1;
  $57 = ($56<<24>>24)==(0);
  if (!($57)) {
   $58 = (($53) + -32|0);
   $59 = HEAP32[$58>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($59|0),($$byval_copy2|0));
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    label = 18;
    break;
   }
  }
  $64 = (($53) + -52|0);
  $65 = HEAP8[$64>>0]|0;
  $66 = $65 & 1;
  $67 = ($66<<24>>24)==(0);
  if (!($67)) {
   $70 = (($53) + -44|0);
   $71 = HEAP32[$70>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($71|0),($$byval_copy2|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 22;
    break;
   }
  }
  $68 = HEAP32[$16>>2]|0;
  $69 = ($68|0)==($$0$lcssa$i$i|0);
  if ($69) {
   label = 32;
   break;
  } else {
   $53 = $68;
  }
 }
 if ((label|0) == 18) {
  $62 = ___cxa_find_matching_catch()|0;
  $63 = tempRet0;
  ___cxa_call_unexpected(($62|0));
  // unreachable;
 }
 else if ((label|0) == 22) {
  $74 = ___cxa_find_matching_catch()|0;
  $75 = tempRet0;
  ___cxa_call_unexpected(($74|0));
  // unreachable;
 }
 else if ((label|0) == 32) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE6resizeEj($this,$__sz) {
 $this = $this|0;
 $__sz = $__sz|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = ($8>>>0)<($__sz>>>0);
 if ($9) {
  $10 = (($__sz) - ($8))|0;
  __ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$10);
  STACKTOP = sp;return;
 }
 $11 = ($8>>>0)>($__sz>>>0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($4) + (($__sz*56)|0)|0);
 $13 = ($3|0)==($12|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $15 = $3;
 while(1) {
  $14 = (($15) + -56|0);
  HEAP32[$2>>2] = $14;
  $16 = (($15) + -40|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if (!($19)) {
   $20 = (($15) + -32|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($21|0),($$byval_copy1|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    label = 8;
    break;
   }
  }
  $26 = (($15) + -52|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27 & 1;
  $29 = ($28<<24>>24)==(0);
  if (!($29)) {
   $32 = (($15) + -44|0);
   $33 = HEAP32[$32>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($33|0),($$byval_copy1|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    label = 12;
    break;
   }
  }
  $30 = HEAP32[$2>>2]|0;
  $31 = ($30|0)==($12|0);
  if ($31) {
   label = 13;
   break;
  } else {
   $15 = $30;
  }
 }
 if ((label|0) == 8) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  ___cxa_call_unexpected(($24|0));
  // unreachable;
 }
 else if ((label|0) == 12) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 }
 else if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__vector_baseI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 do {
  if ($7) {
   $32 = $3;
  } else {
   $9 = $6;
   while(1) {
    $8 = (($9) + -56|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -40|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = (($9) + -32|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy2|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 6;
      break;
     }
    }
    $20 = (($9) + -52|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if (!($23)) {
     $26 = (($9) + -44|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($27|0),($$byval_copy2|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 10;
      break;
     }
    }
    $24 = HEAP32[$5>>2]|0;
    $25 = ($24|0)==($3|0);
    if ($25) {
     label = 11;
     break;
    } else {
     $9 = $24;
    }
   }
   if ((label|0) == 6) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 10) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   else if ((label|0) == 11) {
    $$pre = HEAP32[$this>>2]|0;
    $32 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy2|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN14AnimationEventC1ERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy2 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i4 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$this>>2] = $3;
 $4 = (($this) + 4|0);
 $5 = (($0) + 4|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $13 = (($5) + 1|0);
  $14 = $6&255;
  $15 = $14 >>> 1;
  $17 = $15;$28 = $13;
 } else {
  $9 = (($0) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($0) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $17 = $12;$28 = $10;
 }
 $16 = ($17>>>0)>(2147483631);
 if ($16) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $18 = ($17>>>0)<(11);
 if ($18) {
  $19 = $17 << 1;
  $20 = $19&255;
  HEAP8[$4>>0] = $20;
  $21 = (($4) + 1|0);
  $__p$0$i$i$i$i = $21;
 } else {
  $22 = (($17) + 16)|0;
  $23 = $22 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $24 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,16,$$byval_copy2,0,766088,79)|0);
  $25 = (($this) + 12|0);
  HEAP32[$25>>2] = $24;
  $26 = $23 | 1;
  HEAP32[$4>>2] = $26;
  $27 = (($this) + 8|0);
  HEAP32[$27>>2] = $17;
  $__p$0$i$i$i$i = $24;
 }
 _memcpy(($__p$0$i$i$i$i|0),($28|0),($17|0))|0;
 $29 = (($__p$0$i$i$i$i) + ($17)|0);
 HEAP8[$29>>0] = 0;
 $30 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$this>>2] = $30;
 $31 = (($this) + 16|0);
 $32 = (($0) + 16|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $40 = (($32) + 1|0);
  $41 = $33&255;
  $42 = $41 >>> 1;
  $44 = $42;$70 = $40;
 } else {
  $36 = (($0) + 24|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($0) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $44 = $39;$70 = $37;
 }
 $43 = ($44>>>0)>(2147483631);
 if ($43) {
  __THREW__ = 0;
  invoke_vi(3309,0);
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if (!($46)) {
   // unreachable;
  }
 } else {
  $47 = ($44>>>0)<(11);
  if ($47) {
   $48 = $44 << 1;
   $49 = $48&255;
   HEAP8[$31>>0] = $49;
   $50 = (($31) + 1|0);
   $__p$0$i$i$i$i4 = $50;
   _memcpy(($__p$0$i$i$i$i4|0),($70|0),($44|0))|0;
   $71 = (($__p$0$i$i$i$i4) + ($44)|0);
   HEAP8[$71>>0] = 0;
   $72 = Math_fround(HEAPF32[$0>>2]);
   HEAPF32[$this>>2] = $72;
   $73 = (($0) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($this) + 28|0);
   HEAP32[$75>>2] = $74;
   $76 = (($this) + 32|0);
   $77 = (($0) + 32|0);
   ;HEAP32[$76+0>>2]=HEAP32[$77+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$77+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$77+8>>2]|0;HEAP32[$76+12>>2]=HEAP32[$77+12>>2]|0;HEAP32[$76+16>>2]=HEAP32[$77+16>>2]|0;HEAP32[$76+20>>2]=HEAP32[$77+20>>2]|0;
   STACKTOP = sp;return;
  }
  $51 = (($44) + 16)|0;
  $52 = $51 & -16;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $53 = (invoke_iiiiiii(102,($52|0),16,($$byval_copy2|0),0,(766088|0),79)|0);
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if (!($55)) {
   $56 = (($this) + 24|0);
   HEAP32[$56>>2] = $53;
   $57 = $52 | 1;
   HEAP32[$31>>2] = $57;
   $58 = (($this) + 20|0);
   HEAP32[$58>>2] = $44;
   $__p$0$i$i$i$i4 = $53;
   _memcpy(($__p$0$i$i$i$i4|0),($70|0),($44|0))|0;
   $71 = (($__p$0$i$i$i$i4) + ($44)|0);
   HEAP8[$71>>0] = 0;
   $72 = Math_fround(HEAPF32[$0>>2]);
   HEAPF32[$this>>2] = $72;
   $73 = (($0) + 28|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($this) + 28|0);
   HEAP32[$75>>2] = $74;
   $76 = (($this) + 32|0);
   $77 = (($0) + 32|0);
   ;HEAP32[$76+0>>2]=HEAP32[$77+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$77+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$77+8>>2]|0;HEAP32[$76+12>>2]=HEAP32[$77+12>>2]|0;HEAP32[$76+16>>2]=HEAP32[$77+16>>2]|0;HEAP32[$76+20>>2]=HEAP32[$77+20>>2]|0;
   STACKTOP = sp;return;
  }
 }
 $59 = ___cxa_find_matching_catch()|0;
 $60 = tempRet0;
 $61 = HEAP8[$4>>0]|0;
 $62 = $61 & 1;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  ___resumeException($59|0);
  // unreachable;
 }
 $64 = (($this) + 12|0);
 $65 = HEAP32[$64>>2]|0;
 HEAP32[$2>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($65|0),($$byval_copy2|0));
 $66 = __THREW__; __THREW__ = 0;
 $67 = $66&1;
 if ($67) {
  $68 = ___cxa_find_matching_catch()|0;
  $69 = tempRet0;
  ___cxa_call_unexpected(($68|0));
  // unreachable;
 } else {
  ___resumeException($59|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i710 = 0, $$0$i79 = 0, $$01$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i2 = 0, $$pre1$i = 0, $$pre1$i1 = 0, $$pre1$i5 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $18 = 0;
   } else {
    HEAPF32[$11>>2] = Math_fround(0.0);
    $12 = (($11) + 4|0);
    HEAP8[$12>>0] = 0;
    $13 = (($12) + 1|0);
    HEAP8[$13>>0] = 0;
    $14 = (($11) + 16|0);
    HEAP8[$14>>0] = 0;
    $15 = (($14) + 1|0);
    HEAP8[$15>>0] = 0;
    $16 = (($11) + 28|0);
    ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;HEAP32[$16+24>>2]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $18 = $$pre1$i;
   }
   $17 = (($18) + 56|0);
   HEAP32[$3>>2] = $17;
   $19 = (($$0$i) + -1)|0;
   $20 = ($19|0)==(0);
   if ($20) {
    break;
   } else {
    $$0$i = $19;$11 = $17;
   }
  }
  STACKTOP = sp;return;
 }
 $21 = (($this) + 8|0);
 $22 = HEAP32[$this>>2]|0;
 $23 = $22;
 $24 = (($6) - ($23))|0;
 $25 = (($24|0) / 56)&-1;
 $26 = (($25) + ($__n))|0;
 $27 = ($26|0)<(0);
 if ($27) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $28 = (($5) - ($23))|0;
 $29 = (($28|0) / 56)&-1;
 $30 = ($29>>>0)<(1073741823);
 if ($30) {
  $33 = $29 << 1;
  $34 = ($33>>>0)<($26>>>0);
  $35 = $34 ? $26 : $33;
  $36 = (($__v) + 12|0);
  HEAP32[$36>>2] = 0;
  $37 = (($__v) + 16|0);
  HEAP32[$37>>2] = $21;
  $38 = ($35|0)==(0);
  if ($38) {
   $$0$i710 = 0;$41 = 0;$46 = $36;
  } else {
   $$0$i79 = $35;$77 = $36;
   label = 10;
  }
 } else {
  $31 = (($__v) + 12|0);
  HEAP32[$31>>2] = 0;
  $32 = (($__v) + 16|0);
  HEAP32[$32>>2] = $21;
  $$0$i79 = 2147483647;$77 = $31;
  label = 10;
 }
 if ((label|0) == 10) {
  $39 = ($$0$i79*56)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $40 = (__Z15malloc_internaljj10MemLabelIdiPKci($39,16,$$byval_copy,0,766088,79)|0);
  $$0$i710 = $$0$i79;$41 = $40;$46 = $77;
 }
 HEAP32[$__v>>2] = $41;
 $42 = (($41) + (($25*56)|0)|0);
 $43 = (($__v) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = (($__v) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($41) + (($$0$i710*56)|0)|0);
 HEAP32[$46>>2] = $45;
 $$0$i4 = $__n;$48 = $42;
 while(1) {
  $47 = ($48|0)==(0|0);
  if ($47) {
   $55 = 0;
  } else {
   HEAPF32[$48>>2] = Math_fround(0.0);
   $49 = (($48) + 4|0);
   HEAP8[$49>>0] = 0;
   $50 = (($49) + 1|0);
   HEAP8[$50>>0] = 0;
   $51 = (($48) + 16|0);
   HEAP8[$51>>0] = 0;
   $52 = (($51) + 1|0);
   HEAP8[$52>>0] = 0;
   $53 = (($48) + 28|0);
   ;HEAP32[$53+0>>2]=0|0;HEAP32[$53+4>>2]=0|0;HEAP32[$53+8>>2]=0|0;HEAP32[$53+12>>2]=0|0;HEAP32[$53+16>>2]=0|0;HEAP32[$53+20>>2]=0|0;HEAP32[$53+24>>2]=0|0;
   $$pre1$i5 = HEAP32[$43>>2]|0;
   $55 = $$pre1$i5;
  }
  $54 = (($55) + 56|0);
  HEAP32[$43>>2] = $54;
  $56 = (($$0$i4) + -1)|0;
  $57 = ($56|0)==(0);
  if ($57) {
   break;
  } else {
   $$0$i4 = $56;$48 = $54;
  }
 }
 $58 = HEAP32[$this>>2]|0;
 $59 = HEAP32[$3>>2]|0;
 $60 = ($59|0)==($58|0);
 $$pre1$i1 = HEAP32[$44>>2]|0;
 do {
  if ($60) {
   $69 = $$pre1$i1;$70 = $58;$71 = $54;$72 = $58;
  } else {
   $$01$i$i = $59;$62 = $$pre1$i1;
   while(1) {
    $61 = (($62) + -56|0);
    $63 = (($$01$i$i) + -56|0);
    __THREW__ = 0;
    invoke_vii(3375,($61|0),($63|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     label = 21;
     break;
    }
    $66 = HEAP32[$44>>2]|0;
    $67 = (($66) + -56|0);
    HEAP32[$44>>2] = $67;
    $68 = ($63|0)==($58|0);
    if ($68) {
     label = 18;
     break;
    } else {
     $$01$i$i = $63;$62 = $67;
    }
   }
   if ((label|0) == 18) {
    $$pre$i2 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$3>>2]|0;
    $$pre8 = HEAP32[$43>>2]|0;
    $69 = $67;$70 = $$pre$i2;$71 = $$pre8;$72 = $$pre;
    break;
   }
   else if ((label|0) == 21) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    __ZNSt3__114__split_bufferI14AnimationEventR13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
    ___resumeException($75|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $69;
 HEAP32[$44>>2] = $70;
 HEAP32[$3>>2] = $71;
 HEAP32[$43>>2] = $72;
 $73 = HEAP32[$1>>2]|0;
 $74 = HEAP32[$46>>2]|0;
 HEAP32[$1>>2] = $74;
 HEAP32[$46>>2] = $73;
 HEAP32[$__v>>2] = $70;
 __ZNSt3__114__split_bufferI14AnimationEventR13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferI14AnimationEventR13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 L1: do {
  if (!($7)) {
   $9 = $6;
   while(1) {
    $8 = (($9) + -56|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -40|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = (($9) + -32|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy2|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 5;
      break;
     }
    }
    $20 = (($9) + -52|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if (!($23)) {
     $26 = (($9) + -44|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($27|0),($$byval_copy2|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 9;
      break;
     }
    }
    $24 = HEAP32[$5>>2]|0;
    $25 = ($24|0)==($4|0);
    if ($25) {
     break L1;
    } else {
     $9 = $24;
    }
   }
   if ((label|0) == 5) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 9) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
  }
 } while(0);
 $32 = HEAP32[$this>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy2|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE10deallocateEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 do {
  if ($7) {
   $32 = $3;
  } else {
   $9 = $6;
   while(1) {
    $8 = (($9) + -56|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -40|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 & 1;
    $13 = ($12<<24>>24)==(0);
    if (!($13)) {
     $14 = (($9) + -32|0);
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($15|0),($$byval_copy2|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 6;
      break;
     }
    }
    $20 = (($9) + -52|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21 & 1;
    $23 = ($22<<24>>24)==(0);
    if (!($23)) {
     $26 = (($9) + -44|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($27|0),($$byval_copy2|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 10;
      break;
     }
    }
    $24 = HEAP32[$5>>2]|0;
    $25 = ($24|0)==($3|0);
    if ($25) {
     label = 11;
     break;
    } else {
     $9 = $24;
    }
   }
   if ((label|0) == 6) {
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    ___cxa_call_unexpected(($18|0));
    // unreachable;
   }
   else if ((label|0) == 10) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   else if ((label|0) == 11) {
    $$pre = HEAP32[$this>>2]|0;
    $32 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy2|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 }
 $37 = (($this) + 8|0);
 HEAP32[$37>>2] = 0;
 HEAP32[$5>>2] = 0;
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<4)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN11UnityEngine9Animation14GenericBinding8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 16|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = $23 << 4;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = $22 >> 4;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 4;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,766088,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 4;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,766088,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 4;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<4)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<4)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   ;HEAP32[$$01$i$i+0>>2]=0|0;HEAP32[$$01$i$i+4>>2]=0|0;HEAP32[$$01$i$i+8>>2]=0|0;HEAP32[$$01$i$i+12>>2]=0|0;
  }
  $30 = (($$01$i$i) + 16|0);
  $31 = ($30|0)==($25|0);
  if ($31) {
   break;
  } else {
   $$01$i$i = $30;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation14GenericBinding8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre5;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $15 = $$pre$i$i$i1;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($17,$transfer);
 $18 = (($this) + 12|0);
 $19 = HEAP32[$0>>2]|0;
 $20 = (($19) + 2|0);
 $21 = HEAP32[$3>>2]|0;
 $22 = ($20>>>0)>($21>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$18,2);
  $$pre$i$i$i3 = HEAP16[$18>>1]|0;
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $25 = $$pre$i$i$i3;$32 = $$pre6;$34 = $$pre7;
 } else {
  $23 = HEAP16[$19>>1]|0;
  HEAP16[$18>>1] = $23;
  HEAP32[$0>>2] = $20;
  $25 = $23;$32 = $20;$34 = $21;
 }
 $24 = $25&65535;
 $26 = $24 << 8;
 $27 = $24 >>> 8;
 $28 = $26 | $27;
 $29 = $28&65535;
 HEAP16[$18>>1] = $29;
 $30 = (($this) + 14|0);
 $31 = (($32) + 1|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$30,1);
  $$pre8 = HEAP32[$0>>2]|0;
  $40 = $$pre8;
 } else {
  $35 = HEAP8[$32>>0]|0;
  HEAP8[$30>>0] = $35;
  $36 = HEAP32[$0>>2]|0;
  $37 = (($36) + 1|0);
  HEAP32[$0>>2] = $37;
  $40 = $37;
 }
 $38 = (($this) + 15|0);
 $39 = (($40) + 1|0);
 $41 = HEAP32[$3>>2]|0;
 $42 = ($39>>>0)>($41>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$38,1);
  STACKTOP = sp;return;
 } else {
  $43 = HEAP8[$40>>0]|0;
  HEAP8[$38>>0] = $43;
  $44 = HEAP32[$0>>2]|0;
  $45 = (($44) + 1|0);
  HEAP32[$0>>2] = $45;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation18ClipMuscleConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i23 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i19Z2D = 0, $$pre$phi$i$i$i24Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi$i$iZ2D = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0;
 var $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i26 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i26 = sp;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 48|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($2,$transfer);
 $3 = (($this) + 64|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($3,$transfer);
 $4 = (($this) + 80|0);
 HEAP32[$ArrayTransfer$i26>>2] = 4;
 $5 = (($ArrayTransfer$i26) + 4|0);
 HEAP32[$5>>2] = $4;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI19StaticArrayTransferIN7mecanim5human9HumanGoalELi4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i26,0);
 $6 = (($this) + 384|0);
 __ZN7mecanim4hand8HandPose8TransferI18StreamedBinaryReadILb1EEEEvRT_($6,$transfer);
 $7 = (($this) + 528|0);
 __ZN7mecanim4hand8HandPose8TransferI18StreamedBinaryReadILb1EEEEvRT_($7,$transfer);
 $8 = (($this) + 672|0);
 HEAP32[$ArrayTransfer$i26>>2] = 52;
 $9 = (($ArrayTransfer$i26) + 4|0);
 HEAP32[$9>>2] = $8;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI19StaticArrayTransferIfLi52EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i26,0);
 $10 = (($this) + 880|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($10,$transfer);
 $11 = (($this) + 896|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($11,$transfer);
 $12 = (($this) + 912|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($12,$transfer);
 $13 = (($this) + 928|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($13,$transfer);
 $14 = (($this) + 944|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($14,$transfer);
 $15 = (($this) + 960|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($15,$transfer);
 $16 = (($this) + 976|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($16,$transfer);
 $17 = (($this) + 992|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($17,$transfer);
 $18 = (($this) + 1008|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($18,$transfer);
 $19 = (($this) + 1024|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($19,$transfer);
 $20 = (($this) + 1040|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $23 = (($transfer) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = (FUNCTION_TABLE_iiii[$26 & 2047]($24,64,4)|0);
  $28 = ($27|0)==(0|0);
  if ($28) {
   $32 = 0;$34 = 0;
  } else {
   dest=$27+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $29 = $27;
   $30 = $20;
   $31 = (($29) - ($30))|0;
   $32 = $31;$34 = $27;
  }
  HEAP32[$20>>2] = $32;
  $33 = (($this) + 1044|0);
  HEAP32[$33>>2] = $34;
  $$pre$phi$i$iZ2D = $33;$37 = $32;
 } else {
  $$pre$i$i = (($this) + 1044|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$37 = $21;
 }
 $35 = $20;
 $36 = (($37) + ($35))|0;
 $38 = $36;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $38;
 __ZN7mecanim9animation4Clip8TransferI18StreamedBinaryReadILb1EEEEvRT_($38,$transfer);
 $39 = (($this) + 1048|0);
 $40 = (($transfer) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 4|0);
 $43 = (($transfer) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42>>>0)>($44>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$39,4);
  $$pre$i$i$i = HEAP32[$39>>2]|0;
  $$pre = HEAP32[$40>>2]|0;
  $$pre36 = HEAP32[$43>>2]|0;
  $$pre$phi$i$i$iZ2D = $39;$48 = $$pre$i$i$i;$52 = $$pre;$54 = $$pre36;
 } else {
  $46 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$39>>2] = $46;
  HEAP32[$40>>2] = $42;
  $47 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $39;$48 = $47;$52 = $42;$54 = $44;
 }
 $49 = (_llvm_bswap_i32(($48|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $49;
 $50 = (($this) + 1052|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)>($54>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$50,4);
  $$pre$i$i$i3 = HEAP32[$50>>2]|0;
  $$pre37 = HEAP32[$40>>2]|0;
  $$pre38 = HEAP32[$43>>2]|0;
  $$pre$phi$i$i$i4Z2D = $50;$57 = $$pre$i$i$i3;$61 = $$pre37;$63 = $$pre38;
 } else {
  $55 = Math_fround(HEAPF32[$52>>2]);
  HEAPF32[$50>>2] = $55;
  HEAP32[$40>>2] = $51;
  $56 = (HEAPF32[tempDoublePtr>>2]=$55,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $50;$57 = $56;$61 = $51;$63 = $54;
 }
 $58 = (_llvm_bswap_i32(($57|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $58;
 $59 = (($this) + 1056|0);
 $60 = (($61) + 4|0);
 $62 = ($60>>>0)>($63>>>0);
 if ($62) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$59,4);
  $$pre$i$i$i8 = HEAP32[$59>>2]|0;
  $$pre39 = HEAP32[$40>>2]|0;
  $$pre40 = HEAP32[$43>>2]|0;
  $$pre$phi$i$i$i9Z2D = $59;$66 = $$pre$i$i$i8;$70 = $$pre39;$72 = $$pre40;
 } else {
  $64 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$59>>2] = $64;
  HEAP32[$40>>2] = $60;
  $65 = (HEAPF32[tempDoublePtr>>2]=$64,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $59;$66 = $65;$70 = $60;$72 = $63;
 }
 $67 = (_llvm_bswap_i32(($66|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $67;
 $68 = (($this) + 1060|0);
 $69 = (($70) + 4|0);
 $71 = ($69>>>0)>($72>>>0);
 if ($71) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$68,4);
  $$pre$i$i$i13 = HEAP32[$68>>2]|0;
  $$pre41 = HEAP32[$40>>2]|0;
  $$pre42 = HEAP32[$43>>2]|0;
  $$pre$phi$i$i$i14Z2D = $68;$75 = $$pre$i$i$i13;$79 = $$pre41;$81 = $$pre42;
 } else {
  $73 = Math_fround(HEAPF32[$70>>2]);
  HEAPF32[$68>>2] = $73;
  HEAP32[$40>>2] = $69;
  $74 = (HEAPF32[tempDoublePtr>>2]=$73,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $68;$75 = $74;$79 = $69;$81 = $72;
 }
 $76 = (_llvm_bswap_i32(($75|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $76;
 $77 = (($this) + 1064|0);
 $78 = (($79) + 4|0);
 $80 = ($78>>>0)>($81>>>0);
 if ($80) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$77,4);
  $$pre$i$i$i18 = HEAP32[$77>>2]|0;
  $$pre43 = HEAP32[$40>>2]|0;
  $$pre44 = HEAP32[$43>>2]|0;
  $$pre$phi$i$i$i19Z2D = $77;$84 = $$pre$i$i$i18;$88 = $$pre43;$90 = $$pre44;
 } else {
  $82 = Math_fround(HEAPF32[$79>>2]);
  HEAPF32[$77>>2] = $82;
  HEAP32[$40>>2] = $78;
  $83 = (HEAPF32[tempDoublePtr>>2]=$82,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i19Z2D = $77;$84 = $83;$88 = $78;$90 = $81;
 }
 $85 = (_llvm_bswap_i32(($84|0))|0);
 HEAP32[$$pre$phi$i$i$i19Z2D>>2] = $85;
 $86 = (($this) + 1068|0);
 $87 = (($88) + 4|0);
 $89 = ($87>>>0)>($90>>>0);
 if ($89) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$86,4);
  $$pre$i$i$i23 = HEAP32[$86>>2]|0;
  $$pre$phi$i$i$i24Z2D = $86;$93 = $$pre$i$i$i23;
 } else {
  $91 = Math_fround(HEAPF32[$88>>2]);
  HEAPF32[$86>>2] = $91;
  HEAP32[$40>>2] = $87;
  $92 = (HEAPF32[tempDoublePtr>>2]=$91,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i24Z2D = $86;$93 = $92;
 }
 $94 = (_llvm_bswap_i32(($93|0))|0);
 HEAP32[$$pre$phi$i$i$i24Z2D>>2] = $94;
 $95 = (($this) + 1072|0);
 HEAP32[$ArrayTransfer$i26>>2] = 137;
 $96 = (($ArrayTransfer$i26) + 4|0);
 HEAP32[$96>>2] = $95;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI19StaticArrayTransferIiLi137EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i26,0);
 $97 = (($this) + 1624|0);
 $98 = (($this) + 1620|0);
 $99 = (($transfer) + 4|0);
 $100 = HEAP32[$99>>2]|0;
 HEAP32[$ArrayTransfer$i26>>2] = $97;
 $101 = (($ArrayTransfer$i26) + 4|0);
 HEAP32[$101>>2] = $98;
 $102 = (($ArrayTransfer$i26) + 8|0);
 HEAP32[$102>>2] = $100;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation10ValueDeltaEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i26,0);
 $103 = (($this) + 1632|0);
 $104 = HEAP32[$40>>2]|0;
 $105 = (($104) + 1|0);
 $106 = HEAP32[$43>>2]|0;
 $107 = ($105>>>0)>($106>>>0);
 if ($107) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$103,1);
  $$pre45 = HEAP32[$40>>2]|0;
  $113 = $$pre45;
 } else {
  $108 = HEAP8[$104>>0]|0;
  HEAP8[$103>>0] = $108;
  $109 = HEAP32[$40>>2]|0;
  $110 = (($109) + 1|0);
  HEAP32[$40>>2] = $110;
  $113 = $110;
 }
 $111 = (($this) + 1633|0);
 $112 = (($113) + 1|0);
 $114 = HEAP32[$43>>2]|0;
 $115 = ($112>>>0)>($114>>>0);
 if ($115) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$111,1);
  $$pre46 = HEAP32[$40>>2]|0;
  $121 = $$pre46;
 } else {
  $116 = HEAP8[$113>>0]|0;
  HEAP8[$111>>0] = $116;
  $117 = HEAP32[$40>>2]|0;
  $118 = (($117) + 1|0);
  HEAP32[$40>>2] = $118;
  $121 = $118;
 }
 $119 = (($this) + 1634|0);
 $120 = (($121) + 1|0);
 $122 = HEAP32[$43>>2]|0;
 $123 = ($120>>>0)>($122>>>0);
 if ($123) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$119,1);
  $$pre47 = HEAP32[$40>>2]|0;
  $129 = $$pre47;
 } else {
  $124 = HEAP8[$121>>0]|0;
  HEAP8[$119>>0] = $124;
  $125 = HEAP32[$40>>2]|0;
  $126 = (($125) + 1|0);
  HEAP32[$40>>2] = $126;
  $129 = $126;
 }
 $127 = (($this) + 1635|0);
 $128 = (($129) + 1|0);
 $130 = HEAP32[$43>>2]|0;
 $131 = ($128>>>0)>($130>>>0);
 if ($131) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$127,1);
  $$pre48 = HEAP32[$40>>2]|0;
  $137 = $$pre48;
 } else {
  $132 = HEAP8[$129>>0]|0;
  HEAP8[$127>>0] = $132;
  $133 = HEAP32[$40>>2]|0;
  $134 = (($133) + 1|0);
  HEAP32[$40>>2] = $134;
  $137 = $134;
 }
 $135 = (($this) + 1636|0);
 $136 = (($137) + 1|0);
 $138 = HEAP32[$43>>2]|0;
 $139 = ($136>>>0)>($138>>>0);
 if ($139) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$135,1);
  $$pre49 = HEAP32[$40>>2]|0;
  $145 = $$pre49;
 } else {
  $140 = HEAP8[$137>>0]|0;
  HEAP8[$135>>0] = $140;
  $141 = HEAP32[$40>>2]|0;
  $142 = (($141) + 1|0);
  HEAP32[$40>>2] = $142;
  $145 = $142;
 }
 $143 = (($this) + 1637|0);
 $144 = (($145) + 1|0);
 $146 = HEAP32[$43>>2]|0;
 $147 = ($144>>>0)>($146>>>0);
 if ($147) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$143,1);
  $$pre50 = HEAP32[$40>>2]|0;
  $153 = $$pre50;
 } else {
  $148 = HEAP8[$145>>0]|0;
  HEAP8[$143>>0] = $148;
  $149 = HEAP32[$40>>2]|0;
  $150 = (($149) + 1|0);
  HEAP32[$40>>2] = $150;
  $153 = $150;
 }
 $151 = (($this) + 1638|0);
 $152 = (($153) + 1|0);
 $154 = HEAP32[$43>>2]|0;
 $155 = ($152>>>0)>($154>>>0);
 if ($155) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$151,1);
  $$pre51 = HEAP32[$40>>2]|0;
  $161 = $$pre51;
 } else {
  $156 = HEAP8[$153>>0]|0;
  HEAP8[$151>>0] = $156;
  $157 = HEAP32[$40>>2]|0;
  $158 = (($157) + 1|0);
  HEAP32[$40>>2] = $158;
  $161 = $158;
 }
 $159 = (($this) + 1639|0);
 $160 = (($161) + 1|0);
 $162 = HEAP32[$43>>2]|0;
 $163 = ($160>>>0)>($162>>>0);
 if ($163) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$159,1);
  $$pre52 = HEAP32[$40>>2]|0;
  $169 = $$pre52;
 } else {
  $164 = HEAP8[$161>>0]|0;
  HEAP8[$159>>0] = $164;
  $165 = HEAP32[$40>>2]|0;
  $166 = (($165) + 1|0);
  HEAP32[$40>>2] = $166;
  $169 = $166;
 }
 $167 = (($this) + 1640|0);
 $168 = (($169) + 1|0);
 $170 = HEAP32[$43>>2]|0;
 $171 = ($168>>>0)>($170>>>0);
 if ($171) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$167,1);
  $$pre53 = HEAP32[$40>>2]|0;
  $177 = $$pre53;
 } else {
  $172 = HEAP8[$169>>0]|0;
  HEAP8[$167>>0] = $172;
  $173 = HEAP32[$40>>2]|0;
  $174 = (($173) + 1|0);
  HEAP32[$40>>2] = $174;
  $177 = $174;
 }
 $175 = (($this) + 1641|0);
 $176 = (($177) + 1|0);
 $178 = HEAP32[$43>>2]|0;
 $179 = ($176>>>0)>($178>>>0);
 if ($179) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$175,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $180 = HEAP8[$177>>0]|0;
  HEAP8[$175>>0] = $180;
  $181 = HEAP32[$40>>2]|0;
  $182 = (($181) + 1|0);
  HEAP32[$40>>2] = $182;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation10ValueDeltaEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i3$i$i$i = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$i4$i$i$iZ2D = 0, $$pre6$i$i$i = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $i$07 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $41 = (($28) + 4|0);
  HEAP32[$41>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$39 = 0;
  } else {
   $36 = $34;
   $37 = $28;
   $38 = (($36) - ($37))|0;
   $$0$i1$i$i = $34;$39 = $38;
  }
  HEAP32[$28>>2] = $39;
  $40 = (($28) + 4|0);
  HEAP32[$40>>2] = $$0$i1$i$i;
 }
 $42 = HEAP32[$data>>2]|0;
 $43 = $42;
 $44 = HEAP32[$42>>2]|0;
 $45 = (($44) + ($43))|0;
 $46 = $45;
 $47 = (($42) + 4|0);
 HEAP32[$47>>2] = $46;
 $48 = HEAP32[$25>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($46) + ($49<<3)|0);
 $51 = HEAP32[$data>>2]|0;
 $52 = $51;
 $53 = HEAP32[$51>>2]|0;
 $54 = (($53) + ($52))|0;
 $55 = $54;
 $56 = (($51) + 4|0);
 HEAP32[$56>>2] = $55;
 $57 = ($55|0)==($50|0);
 if ($57) {
  STACKTOP = sp;return;
 } else {
  $i$07 = $55;
 }
 while(1) {
  $58 = HEAP32[$1>>2]|0;
  $59 = (($58) + 4|0);
  $60 = HEAP32[$7>>2]|0;
  $61 = ($59>>>0)>($60>>>0);
  if ($61) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$07,4);
   $$pre$i$i$i$i$i$i = HEAP32[$i$07>>2]|0;
   $$pre$i$i$i = HEAP32[$1>>2]|0;
   $$pre6$i$i$i = HEAP32[$7>>2]|0;
   $$pre$phi$i$i$i$i$i$iZ2D = $i$07;$64 = $$pre$i$i$i$i$i$i;$68 = $$pre$i$i$i;$70 = $$pre6$i$i$i;
  } else {
   $62 = Math_fround(HEAPF32[$58>>2]);
   HEAPF32[$i$07>>2] = $62;
   HEAP32[$1>>2] = $59;
   $63 = (HEAPF32[tempDoublePtr>>2]=$62,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$i$i$i$iZ2D = $i$07;$64 = $63;$68 = $59;$70 = $60;
  }
  $65 = (_llvm_bswap_i32(($64|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $65;
  $66 = (($i$07) + 4|0);
  $67 = (($68) + 4|0);
  $69 = ($67>>>0)>($70>>>0);
  if ($69) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$66,4);
   $$pre$i$i$i3$i$i$i = HEAP32[$66>>2]|0;
   $$pre$phi$i$i$i4$i$i$iZ2D = $66;$73 = $$pre$i$i$i3$i$i$i;
  } else {
   $71 = Math_fround(HEAPF32[$68>>2]);
   HEAPF32[$66>>2] = $71;
   HEAP32[$1>>2] = $67;
   $72 = (HEAPF32[tempDoublePtr>>2]=$71,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$i4$i$i$iZ2D = $66;$73 = $72;
  }
  $74 = (_llvm_bswap_i32(($73|0))|0);
  HEAP32[$$pre$phi$i$i$i4$i$i$iZ2D>>2] = $74;
  $75 = (($i$07) + 8|0);
  $76 = ($75|0)==($50|0);
  if ($76) {
   break;
  } else {
   $i$07 = $75;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI19StaticArrayTransferIiLi137EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$08 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = ($24>>>0)>(137);
 $26 = $25 ? 137 : $24;
 HEAP32[$data>>2] = $26;
 $27 = (($data) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 $30 = ($26|0)==(0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $i$08 = $28;
 while(1) {
  $31 = HEAP32[$1>>2]|0;
  $32 = (($31) + 4|0);
  $33 = HEAP32[$7>>2]|0;
  $34 = ($32>>>0)>($33>>>0);
  if ($34) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$08,4);
   $$pre$i$i$i = HEAP32[$i$08>>2]|0;
   $36 = $$pre$i$i$i;
  } else {
   $35 = HEAP32[$31>>2]|0;
   HEAP32[$i$08>>2] = $35;
   HEAP32[$1>>2] = $32;
   $36 = $35;
  }
  $37 = (_llvm_bswap_i32(($36|0))|0);
  HEAP32[$i$08>>2] = $37;
  $38 = (($i$08) + 4|0);
  $39 = ($38|0)==($29|0);
  if ($39) {
   break;
  } else {
   $i$08 = $38;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation4Clip8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $0;
 $3 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 $5 = (($this) + 12|0);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$5,4);
  $$pre$i$i$i$i$i$i = HEAP32[$5>>2]|0;
  $13 = $$pre$i$i$i$i$i$i;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$5>>2] = $12;
  HEAP32[$6>>2] = $8;
  $13 = $12;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$5>>2] = $14;
 $15 = (($this) + 16|0);
 __ZN7mecanim9animation9DenseClip8TransferI18StreamedBinaryReadILb1EEEEvRT_($15,$transfer);
 $16 = (($this) + 48|0);
 $17 = (($this) + 44|0);
 $18 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $16;
 $19 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$19>>2] = $17;
 $20 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$20>>2] = $18;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 $21 = (($this) + 56|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $24 = HEAP32[$1>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = (FUNCTION_TABLE_iiii[$26 & 2047]($24,12,4)|0);
  $28 = ($27|0)==(0|0);
  if ($28) {
   $34 = 0;$36 = 0;
  } else {
   HEAP32[$27>>2] = 0;
   $29 = (($27) + 4|0);
   HEAP32[$29>>2] = 0;
   $30 = (($27) + 8|0);
   HEAP32[$30>>2] = 0;
   $31 = $27;
   $32 = $21;
   $33 = (($31) - ($32))|0;
   $34 = $33;$36 = $27;
  }
  HEAP32[$21>>2] = $34;
  $35 = (($this) + 60|0);
  HEAP32[$35>>2] = $36;
  $$pre$phi$i$iZ2D = $35;$39 = $34;
 } else {
  $$pre$i$i = (($this) + 60|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$39 = $22;
 }
 $37 = $21;
 $38 = (($39) + ($37))|0;
 $40 = $38;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $40;
 $41 = (($40) + 4|0);
 $42 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $41;
 $43 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$43>>2] = $40;
 $44 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$44>>2] = $42;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim13ValueConstantEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim13ValueConstantEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $48 = (($28) + 4|0);
  HEAP32[$48>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 4;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$46 = 0;
  } else {
   $36 = (($34) + ($24<<4)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    HEAP32[$39>>2] = 10;
    $40 = (($37) + 12|0);
    HEAP32[$40>>2] = 0;
    $41 = (($37) + 16|0);
    $42 = ($41|0)==($36|0);
    if ($42) {
     break;
    } else {
     $37 = $41;
    }
   }
   $43 = $34;
   $44 = $28;
   $45 = (($43) - ($44))|0;
   $$0$i1$i$i = $34;$46 = $45;
  }
  HEAP32[$28>>2] = $46;
  $47 = (($28) + 4|0);
  HEAP32[$47>>2] = $$0$i1$i$i;
 }
 $49 = HEAP32[$data>>2]|0;
 $50 = $49;
 $51 = HEAP32[$49>>2]|0;
 $52 = (($51) + ($50))|0;
 $53 = $52;
 $54 = (($49) + 4|0);
 HEAP32[$54>>2] = $53;
 $55 = HEAP32[$25>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = (($53) + ($56<<4)|0);
 $58 = HEAP32[$data>>2]|0;
 $59 = $58;
 $60 = HEAP32[$58>>2]|0;
 $61 = (($60) + ($59))|0;
 $62 = $61;
 $63 = (($58) + 4|0);
 HEAP32[$63>>2] = $62;
 $64 = ($62|0)==($57|0);
 if ($64) {
  STACKTOP = sp;return;
 } else {
  $i$06 = $62;
 }
 while(1) {
  __ZN7mecanim13ValueConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$06,$this);
  $65 = (($i$06) + 16|0);
  $66 = ($65|0)==($57|0);
  if ($66) {
   break;
  } else {
   $i$06 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim13ValueConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre10 = 0, $$pre11 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre7;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre8;$21 = $$pre9;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $23 = $$pre$i$i$i3;$27 = $$pre10;$29 = $$pre11;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = $22;$27 = $18;$29 = $21;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$17>>2] = $24;
 $25 = (($this) + 12|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre$i$i$i5 = HEAP32[$25>>2]|0;
  $31 = $$pre$i$i$i5;
  $32 = (_llvm_bswap_i32(($31|0))|0);
  HEAP32[$25>>2] = $32;
  STACKTOP = sp;return;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = $30;
  $32 = (_llvm_bswap_i32(($31|0))|0);
  HEAP32[$25>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation9DenseClip8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i6Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre8;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre9;$21 = $$pre10;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i2 = HEAP32[$17>>2]|0;
  $$pre11 = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $17;$24 = $$pre$i$i$i2;$28 = $$pre11;$30 = $$pre12;
 } else {
  $22 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = (HEAPF32[tempDoublePtr>>2]=$22,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $17;$24 = $23;$28 = $18;$30 = $21;
 }
 $25 = (_llvm_bswap_i32(($24|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $25;
 $26 = (($this) + 12|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$26,4);
  $$pre$i$i$i5 = HEAP32[$26>>2]|0;
  $$pre$phi$i$i$i6Z2D = $26;$33 = $$pre$i$i$i5;
 } else {
  $31 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$26>>2] = $31;
  HEAP32[$0>>2] = $27;
  $32 = (HEAPF32[tempDoublePtr>>2]=$31,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i6Z2D = $26;$33 = $32;
 }
 $34 = (_llvm_bswap_i32(($33|0))|0);
 HEAP32[$$pre$phi$i$i$i6Z2D>>2] = $34;
 $35 = (($this) + 20|0);
 $36 = (($this) + 16|0);
 $37 = (($transfer) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $35;
 $39 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$39>>2] = $36;
 $40 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$40>>2] = $38;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0;
 var $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0;
 var $8 = 0, $9 = Math_fround(0), $buf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf = sp;
 $0 = Math_fround(HEAPF32[$data>>2]);
 HEAPF32[$buf>>2] = $0;
 $1 = (($buf) + 4|0);
 $2 = (($data) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$1>>2] = $3;
 $4 = (($buf) + 8|0);
 $5 = (($data) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($buf) + 12|0);
 $8 = (($data) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($transfer) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = (($transfer) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$buf,4);
  $$pre$i$i$i = HEAP32[$buf>>2]|0;
  $$pre = HEAP32[$10>>2]|0;
  $$pre16 = HEAP32[$13>>2]|0;
  $$pre$phi$i$i$iZ2D = $buf;$18 = $$pre$i$i$i;$21 = $$pre;$23 = $$pre16;
 } else {
  $16 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$buf>>2] = $16;
  HEAP32[$10>>2] = $12;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $buf;$18 = $17;$21 = $12;$23 = $14;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $19;
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$1,4);
  $$pre$i$i$i3 = HEAP32[$1>>2]|0;
  $$pre17 = HEAP32[$10>>2]|0;
  $$pre18 = HEAP32[$13>>2]|0;
  $$pre$phi$i$i$i4Z2D = $1;$26 = $$pre$i$i$i3;$29 = $$pre17;$31 = $$pre18;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$1>>2] = $24;
  HEAP32[$10>>2] = $20;
  $25 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $1;$26 = $25;$29 = $20;$31 = $23;
 }
 $27 = (_llvm_bswap_i32(($26|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $27;
 $28 = (($29) + 4|0);
 $30 = ($28>>>0)>($31>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$4,4);
  $$pre$i$i$i8 = HEAP32[$4>>2]|0;
  $$pre19 = HEAP32[$10>>2]|0;
  $$pre20 = HEAP32[$13>>2]|0;
  $$pre$phi$i$i$i9Z2D = $4;$34 = $$pre$i$i$i8;$37 = $$pre19;$39 = $$pre20;
 } else {
  $32 = Math_fround(HEAPF32[$29>>2]);
  HEAPF32[$4>>2] = $32;
  HEAP32[$10>>2] = $28;
  $33 = (HEAPF32[tempDoublePtr>>2]=$32,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $4;$34 = $33;$37 = $28;$39 = $31;
 }
 $35 = (_llvm_bswap_i32(($34|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $35;
 $36 = (($37) + 4|0);
 $38 = ($36>>>0)>($39>>>0);
 if ($38) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$7,4);
  $$pre$i$i$i13 = HEAP32[$7>>2]|0;
  $$pre$phi$i$i$i14Z2D = $7;$42 = $$pre$i$i$i13;
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $43;
  $44 = Math_fround(HEAPF32[$buf>>2]);
  $45 = Math_fround(HEAPF32[$1>>2]);
  $46 = Math_fround(HEAPF32[$4>>2]);
  $47 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$data>>2] = $44;
  HEAPF32[$2>>2] = $45;
  HEAPF32[$5>>2] = $46;
  HEAPF32[$8>>2] = $47;
  STACKTOP = sp;return;
 } else {
  $40 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$7>>2] = $40;
  HEAP32[$10>>2] = $36;
  $41 = (HEAPF32[tempDoublePtr>>2]=$40,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $7;$42 = $41;
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $43;
  $44 = Math_fround(HEAPF32[$buf>>2]);
  $45 = Math_fround(HEAPF32[$1>>2]);
  $46 = Math_fround(HEAPF32[$4>>2]);
  $47 = Math_fround(HEAPF32[$7>>2]);
  HEAPF32[$data>>2] = $44;
  HEAPF32[$2>>2] = $45;
  HEAPF32[$5>>2] = $46;
  HEAPF32[$8>>2] = $47;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI19StaticArrayTransferIfLi52EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$07 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = ($24>>>0)>(52);
 $26 = $25 ? 52 : $24;
 HEAP32[$data>>2] = $26;
 $27 = (($data) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 $30 = ($26|0)==(0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $i$07 = $28;
 while(1) {
  $31 = HEAP32[$1>>2]|0;
  $32 = (($31) + 4|0);
  $33 = HEAP32[$7>>2]|0;
  $34 = ($32>>>0)>($33>>>0);
  if ($34) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$07,4);
   $$pre$i$i$i = HEAP32[$i$07>>2]|0;
   $$pre$phi$i$i$iZ2D = $i$07;$37 = $$pre$i$i$i;
  } else {
   $35 = Math_fround(HEAPF32[$31>>2]);
   HEAPF32[$i$07>>2] = $35;
   HEAP32[$1>>2] = $32;
   $36 = (HEAPF32[tempDoublePtr>>2]=$35,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$iZ2D = $i$07;$37 = $36;
  }
  $38 = (_llvm_bswap_i32(($37|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $38;
  $39 = (($i$07) + 4|0);
  $40 = ($39|0)==($29|0);
  if ($40) {
   break;
  } else {
   $i$07 = $39;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim4hand8HandPose8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 48|0);
 HEAP32[$ArrayTransfer$i>>2] = 20;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $2;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI19StaticArrayTransferIfLi20EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 $4 = (($this) + 128|0);
 $5 = (($transfer) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($transfer) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$4,4);
  $$pre$i$i$i = HEAP32[$4>>2]|0;
  $$pre = HEAP32[$5>>2]|0;
  $$pre16 = HEAP32[$8>>2]|0;
  $$pre$phi$i$i$iZ2D = $4;$13 = $$pre$i$i$i;$17 = $$pre;$19 = $$pre16;
 } else {
  $11 = Math_fround(HEAPF32[$6>>2]);
  HEAPF32[$4>>2] = $11;
  HEAP32[$5>>2] = $7;
  $12 = (HEAPF32[tempDoublePtr>>2]=$11,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $4;$13 = $12;$17 = $7;$19 = $9;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $14;
 $15 = (($this) + 132|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$15,4);
  $$pre$i$i$i3 = HEAP32[$15>>2]|0;
  $$pre17 = HEAP32[$5>>2]|0;
  $$pre18 = HEAP32[$8>>2]|0;
  $$pre$phi$i$i$i4Z2D = $15;$22 = $$pre$i$i$i3;$26 = $$pre17;$28 = $$pre18;
 } else {
  $20 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$15>>2] = $20;
  HEAP32[$5>>2] = $16;
  $21 = (HEAPF32[tempDoublePtr>>2]=$20,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $15;$22 = $21;$26 = $16;$28 = $19;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $23;
 $24 = (($this) + 136|0);
 $25 = (($26) + 4|0);
 $27 = ($25>>>0)>($28>>>0);
 if ($27) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$24,4);
  $$pre$i$i$i8 = HEAP32[$24>>2]|0;
  $$pre19 = HEAP32[$5>>2]|0;
  $$pre20 = HEAP32[$8>>2]|0;
  $$pre$phi$i$i$i9Z2D = $24;$31 = $$pre$i$i$i8;$35 = $$pre19;$37 = $$pre20;
 } else {
  $29 = Math_fround(HEAPF32[$26>>2]);
  HEAPF32[$24>>2] = $29;
  HEAP32[$5>>2] = $25;
  $30 = (HEAPF32[tempDoublePtr>>2]=$29,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $24;$31 = $30;$35 = $25;$37 = $28;
 }
 $32 = (_llvm_bswap_i32(($31|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $32;
 $33 = (($this) + 140|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$33,4);
  $$pre$i$i$i13 = HEAP32[$33>>2]|0;
  $$pre$phi$i$i$i14Z2D = $33;$40 = $$pre$i$i$i13;
  $41 = (_llvm_bswap_i32(($40|0))|0);
  HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $41;
  STACKTOP = sp;return;
 } else {
  $38 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$33>>2] = $38;
  HEAP32[$5>>2] = $34;
  $39 = (HEAPF32[tempDoublePtr>>2]=$38,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $33;$40 = $39;
  $41 = (_llvm_bswap_i32(($40|0))|0);
  HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $41;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI19StaticArrayTransferIfLi20EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$07 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = ($24>>>0)>(20);
 $26 = $25 ? 20 : $24;
 HEAP32[$data>>2] = $26;
 $27 = (($data) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 $30 = ($26|0)==(0);
 if ($30) {
  STACKTOP = sp;return;
 }
 $i$07 = $28;
 while(1) {
  $31 = HEAP32[$1>>2]|0;
  $32 = (($31) + 4|0);
  $33 = HEAP32[$7>>2]|0;
  $34 = ($32>>>0)>($33>>>0);
  if ($34) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$07,4);
   $$pre$i$i$i = HEAP32[$i$07>>2]|0;
   $$pre$phi$i$i$iZ2D = $i$07;$37 = $$pre$i$i$i;
  } else {
   $35 = Math_fround(HEAPF32[$31>>2]);
   HEAPF32[$i$07>>2] = $35;
   HEAP32[$1>>2] = $32;
   $36 = (HEAPF32[tempDoublePtr>>2]=$35,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$iZ2D = $i$07;$37 = $36;
  }
  $38 = (_llvm_bswap_i32(($37|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $38;
  $39 = (($i$07) + 4|0);
  $40 = ($39|0)==($29|0);
  if ($40) {
   break;
  } else {
   $i$07 = $39;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI19StaticArrayTransferIN7mecanim5human9HumanGoalELi4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $offset = 0;
 var $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  $25 = ($24>>>0)>(4);
  $26 = $25 ? 4 : $24;
  HEAP32[$data>>2] = $26;
  $27 = (($data) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + (($26*76)|0)|0);
  $30 = ($26|0)==(0);
  if ($30) {
   STACKTOP = sp;return;
  }
  $i$06 = $28;
  while(1) {
   __ZN7mecanim5human9HumanGoal8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$06,$this);
   $31 = (($i$06) + 76|0);
   $32 = ($31|0)==($29|0);
   if ($32) {
    break;
   } else {
    $i$06 = $31;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = ($21*76)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim5human9HumanGoal8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 48|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre11 = HEAP32[$6>>2]|0;
  $$pre$phi$i$i$iZ2D = $2;$11 = $$pre$i$i$i;$15 = $$pre;$17 = $$pre11;
 } else {
  $9 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = (HEAPF32[tempDoublePtr>>2]=$9,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $2;$11 = $10;$15 = $5;$17 = $7;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $12;
 $13 = (($this) + 52|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$13,4);
  $$pre$i$i$i3 = HEAP32[$13>>2]|0;
  $$pre$phi$i$i$i4Z2D = $13;$20 = $$pre$i$i$i3;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$3>>2] = $14;
  $19 = (HEAPF32[tempDoublePtr>>2]=$18,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $13;$20 = $19;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $21;
 $22 = (($this) + 56|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($22,$transfer);
 $23 = (($this) + 72|0);
 $24 = HEAP32[$3>>2]|0;
 $25 = (($24) + 4|0);
 $26 = HEAP32[$6>>2]|0;
 $27 = ($25>>>0)>($26>>>0);
 if ($27) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$23,4);
  $$pre$i$i$i8 = HEAP32[$23>>2]|0;
  $$pre$phi$i$i$i9Z2D = $23;$30 = $$pre$i$i$i8;
  $31 = (_llvm_bswap_i32(($30|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $31;
  STACKTOP = sp;return;
 } else {
  $28 = Math_fround(HEAPF32[$24>>2]);
  HEAPF32[$23>>2] = $28;
  HEAP32[$3>>2] = $25;
  $29 = (HEAPF32[tempDoublePtr>>2]=$28,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $23;$30 = $29;
  $31 = (_llvm_bswap_i32(($30|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $31;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN13AnimationClip9PPtrCurve8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 48|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*48)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip9PPtrCurve8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI12PPtrKeyframeLj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 12|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $2 = (($this) + 24|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $10 = $$pre$i$i$i;
  $11 = (_llvm_bswap_i32(($10|0))|0);
  HEAP32[$2>>2] = $11;
  $12 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$transfer);
  STACKTOP = sp;return;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;
  $11 = (_llvm_bswap_i32(($10|0))|0);
  HEAP32[$2>>2] = $11;
  $12 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI12PPtrKeyframeLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI12PPtrKeyframeLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<3)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   $44 = HEAP32[$3>>2]|0;
   $45 = (($44) + 4|0);
   $46 = HEAP32[$9>>2]|0;
   $47 = ($45>>>0)>($46>>>0);
   if ($47) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$04,4);
    $$pre$i$i$i$i$i$i = HEAP32[$i$04>>2]|0;
    $$pre$phi$i$i$i$i$i$iZ2D = $i$04;$50 = $$pre$i$i$i$i$i$i;
   } else {
    $48 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$i$04>>2] = $48;
    HEAP32[$3>>2] = $45;
    $49 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
    $$pre$phi$i$i$i$i$i$iZ2D = $i$04;$50 = $49;
   }
   $51 = (_llvm_bswap_i32(($50|0))|0);
   HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $51;
   $52 = (($i$04) + 4|0);
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($52,$this);
   $53 = (($i$04) + 8|0);
   $54 = ($53|0)==($42|0);
   if ($54) {
    break;
   } else {
    $i$04 = $53;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre5 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre6 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i1;$23 = $$pre6;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = $23 << 3;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = $22 >> 3;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI13dynamic_arrayI12PPtrKeyframeLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 3;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,766088,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 3;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,766088,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 3;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<3)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<3)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   $30 = (($$01$i$i) + 4|0);
   HEAP32[$30>>2] = 0;
   HEAPF32[$$01$i$i>>2] = Math_fround(0.0);
  }
  $31 = (($$01$i$i) + 8|0);
  $32 = ($31|0)==($25|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy13 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy13 = sp + 32|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $temp = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $4 = (($v) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$v>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 48)&-1;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $82 = ($10>>>0)>($sz>>>0);
  if (!($82)) {
   STACKTOP = sp;return;
  }
  $83 = (($6) + (($sz*48)|0)|0);
  $$idx = ($sz*48)|0;
  $84 = (($$idx|0) / 48)&-1;
  $85 = ($sz|0)==(0);
  do {
   if ($85) {
    $118 = 0;$119 = 0;$121 = 0;$123 = $6;$135 = $5;
   } else {
    $86 = ($$idx|0)<(0);
    if ($86) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 37;
     } else {
      // unreachable;
     }
    } else {
     HEAP32[$1>>2] = 18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
     $89 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy13|0),0,(766088|0),79)|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 37;
     } else {
      $92 = (($89) + (($84*48)|0)|0);
      $94 = $89;$95 = $6;
      while(1) {
       $93 = ($94|0)==(0|0);
       if ($93) {
        $99 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(3378,($94|0),($95|0));
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         break;
        } else {
         $99 = $94;
        }
       }
       $98 = (($99) + 48|0);
       $100 = (($95) + 48|0);
       $101 = ($100|0)==($83|0);
       if ($101) {
        label = 44;
        break;
       } else {
        $94 = $98;$95 = $100;
       }
      }
      if ((label|0) == 44) {
       $$pre = HEAP32[$v>>2]|0;
       $$pre31 = HEAP32[$4>>2]|0;
       $118 = $89;$119 = $98;$121 = $92;$123 = $$pre;$135 = $$pre31;
       break;
      }
      $104 = ___cxa_find_matching_catch()|0;
      $105 = tempRet0;
      $106 = ($89|0)==(0|0);
      if ($106) {
       $eh$lpad$body$index3Z2D = $105;$eh$lpad$body$indexZ2D = $104;
      } else {
       $108 = $94;
       while(1) {
        $107 = ($108|0)==($89|0);
        if ($107) {
         break;
        }
        $109 = (($108) + -48|0);
        __THREW__ = 0;
        invoke_vi(3692,($109|0));
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         label = 41;
         break;
        } else {
         $108 = $109;
        }
       }
       if ((label|0) == 41) {
        $112 = ___cxa_find_matching_catch()|0;
        $113 = tempRet0;
        ___cxa_call_unexpected(($112|0));
        // unreachable;
       }
       HEAP32[$0>>2] = 18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($89|0),($$byval_copy13|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        $116 = ___cxa_find_matching_catch()|0;
        $117 = tempRet0;
        ___cxa_call_unexpected(($116|0));
        // unreachable;
       } else {
        $eh$lpad$body$index3Z2D = $105;$eh$lpad$body$indexZ2D = $104;
       }
      }
     }
    }
    if ((label|0) == 37) {
     $102 = ___cxa_find_matching_catch()|0;
     $103 = tempRet0;
     $eh$lpad$body$index3Z2D = $103;$eh$lpad$body$indexZ2D = $102;
    }
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $118;
  HEAP32[$4>>2] = $119;
  $120 = (($v) + 8|0);
  HEAP32[$120>>2] = $121;
  $122 = ($123|0)==(0|0);
  if ($122) {
   STACKTOP = sp;return;
  } else {
   $125 = $135;
  }
  while(1) {
   $124 = ($125|0)==($123|0);
   if ($124) {
    break;
   }
   $126 = (($125) + -48|0);
   __THREW__ = 0;
   invoke_vi(3692,($126|0));
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if ($128) {
    label = 48;
    break;
   } else {
    $125 = $126;
   }
  }
  if ((label|0) == 48) {
   $129 = ___cxa_find_matching_catch()|0;
   $130 = tempRet0;
   ___cxa_call_unexpected(($129|0));
   // unreachable;
  }
  HEAP32[$0>>2] = 18;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($123|0),($$byval_copy13|0));
  $131 = __THREW__; __THREW__ = 0;
  $132 = $131&1;
  if ($132) {
   $133 = ___cxa_find_matching_catch()|0;
   $134 = tempRet0;
   ___cxa_call_unexpected(($133|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 48)&-1;
 $17 = ($16|0)==($sz|0);
 if ($17) {
  $81 = (($sz) - ($10))|0;
  __ZNSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($v,$81);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $18 = (($temp) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($temp) + 8|0);
 HEAP32[$19>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3376,($temp|0),($sz|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L49: do {
  if (!($21)) {
   $22 = HEAP32[$v>>2]|0;
   HEAP32[$2>>2] = $22;
   $23 = HEAP32[$4>>2]|0;
   HEAP32[$3>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viii(2002,($temp|0),($$byval_copy|0),($$byval_copy13|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$18>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = (($30|0) / 48)&-1;
    $32 = ($31>>>0)<($sz>>>0);
    L52: do {
     if ($32) {
      $33 = (($sz) - ($31))|0;
      __THREW__ = 0;
      invoke_vii(3377,($temp|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L49;
      }
      $$pre32 = HEAP32[$18>>2]|0;
      $49 = $$pre32;
     } else {
      $36 = ($31>>>0)>($sz>>>0);
      if ($36) {
       $37 = (($27) + (($sz*48)|0)|0);
       $38 = ($26|0)==($37|0);
       if ($38) {
        $49 = $26;
       } else {
        $40 = $26;
        while(1) {
         $39 = (($40) + -48|0);
         HEAP32[$18>>2] = $39;
         __THREW__ = 0;
         invoke_vi(3692,($39|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break;
         }
         $$pre$i = HEAP32[$18>>2]|0;
         $43 = ($$pre$i|0)==($37|0);
         if ($43) {
          $49 = $37;
          break L52;
         } else {
          $40 = $$pre$i;
         }
        }
        $44 = ___cxa_find_matching_catch()|0;
        $45 = tempRet0;
        ___cxa_call_unexpected(($44|0));
        // unreachable;
       }
      } else {
       $49 = $26;
      }
     }
    } while(0);
    $46 = HEAP32[$temp>>2]|0;
    $47 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $47;
    HEAP32[$v>>2] = $46;
    $48 = HEAP32[$4>>2]|0;
    HEAP32[$18>>2] = $48;
    HEAP32[$4>>2] = $49;
    $50 = HEAP32[$19>>2]|0;
    $51 = HEAP32[$12>>2]|0;
    HEAP32[$19>>2] = $51;
    HEAP32[$12>>2] = $50;
    $52 = ($47|0)==(0|0);
    if ($52) {
     STACKTOP = sp;return;
    } else {
     $54 = $48;
    }
    while(1) {
     $53 = ($54|0)==($47|0);
     if ($53) {
      break;
     }
     $55 = (($54) + -48|0);
     HEAP32[$18>>2] = $55;
     __THREW__ = 0;
     invoke_vi(3692,($55|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 17;
      break;
     }
     $$pre33 = HEAP32[$18>>2]|0;
     $54 = $$pre33;
    }
    if ((label|0) == 17) {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     ___cxa_call_unexpected(($58|0));
     // unreachable;
    }
    $60 = HEAP32[$temp>>2]|0;
    HEAP32[$$byval_copy>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($60|0),($$byval_copy13|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $63 = ___cxa_find_matching_catch()|0;
     $64 = tempRet0;
     ___cxa_call_unexpected(($63|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $65 = ___cxa_find_matching_catch()|0;
 $66 = tempRet0;
 $67 = HEAP32[$temp>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  $$0 = $66;$$01 = $65;
  ___resumeException($$01|0);
  // unreachable;
 }
 while(1) {
  $69 = HEAP32[$18>>2]|0;
  $70 = ($69|0)==($67|0);
  if ($70) {
   break;
  }
  $71 = (($69) + -48|0);
  HEAP32[$18>>2] = $71;
  __THREW__ = 0;
  invoke_vi(3692,($71|0));
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  $74 = ___cxa_find_matching_catch()|0;
  $75 = tempRet0;
  ___cxa_call_unexpected(($74|0));
  // unreachable;
 }
 $76 = HEAP32[$temp>>2]|0;
 HEAP32[$$byval_copy>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($76|0),($$byval_copy13|0));
 $77 = __THREW__; __THREW__ = 0;
 $78 = $77&1;
 if ($78) {
  $79 = ___cxa_find_matching_catch()|0;
  $80 = tempRet0;
  ___cxa_call_unexpected(($79|0));
  // unreachable;
 } else {
  $$0 = $66;$$01 = $65;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i = 0, $$pre10 = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 48)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = (($12|0) / 48)&-1;
 $14 = ($__n|0)==(0);
 if ($14) {
  $18 = 0;$21 = $10;$22 = $3;
 } else {
  $15 = ($__n*48)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy2,0,766088,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre10 = HEAP32[$9>>2]|0;
  $18 = $16;$21 = $$pre10;$22 = $$pre;
 }
 $17 = (($18) + (($13*48)|0)|0);
 $19 = (($18) + (($__n*48)|0)|0);
 $20 = ($21|0)==($22|0);
 do {
  if ($20) {
   $29 = $17;$32 = $21;$57 = $21;
  } else {
   $$01$i$i = $21;$24 = $17;
   while(1) {
    $23 = (($24) + -48|0);
    $25 = (($$01$i$i) + -48|0);
    __THREW__ = 0;
    invoke_vii(3378,($23|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = ($25|0)==($22|0);
    if ($28) {
     label = 7;
     break;
    } else {
     $$01$i$i = $25;$24 = $23;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre11 = HEAP32[$9>>2]|0;
    $29 = $23;$32 = $$pre$i;$57 = $$pre11;
    break;
   }
   $43 = ___cxa_find_matching_catch()|0;
   $44 = tempRet0;
   $46 = $17;
   while(1) {
    $45 = ($46|0)==($24|0);
    if ($45) {
     break;
    }
    $47 = (($46) + -48|0);
    __THREW__ = 0;
    invoke_vi(3692,($47|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 18;
     break;
    } else {
     $46 = $47;
    }
   }
   if ((label|0) == 18) {
    $50 = ___cxa_find_matching_catch()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   }
   $52 = ($18|0)==(0|0);
   if ($52) {
    ___resumeException($43|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($18|0),($$byval_copy2|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    ___cxa_call_unexpected(($55|0));
    // unreachable;
   } else {
    ___resumeException($43|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $29;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $31 = $57;
 while(1) {
  $30 = ($31|0)==($32|0);
  if ($30) {
   break;
  }
  $33 = (($31) + -48|0);
  __THREW__ = 0;
  invoke_vi(3692,($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 11;
   break;
  } else {
   $31 = $33;
  }
 }
 if ((label|0) == 11) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 }
 $38 = ($32|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy2|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  ___cxa_call_unexpected(($41|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy3 = 0, $$idx$i$i = 0, $$pre$i$i$i = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 48)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 48)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $81 = ($9|0)==(0|0);
  do {
   if ($81) {
    $97 = $8;
   } else {
    $82 = (($this) + 4|0);
    while(1) {
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==($9|0);
     if ($84) {
      break;
     }
     $85 = (($83) + -48|0);
     HEAP32[$82>>2] = $85;
     __THREW__ = 0;
     invoke_vi(3692,($85|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      label = 28;
      break;
     }
    }
    if ((label|0) == 28) {
     $88 = ___cxa_find_matching_catch()|0;
     $89 = tempRet0;
     ___cxa_call_unexpected(($88|0));
     // unreachable;
    }
    $90 = HEAP32[$this>>2]|0;
    HEAP32[$0>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($90|0),($$byval_copy3|0));
    $91 = __THREW__; __THREW__ = 0;
    $92 = $91&1;
    if ($92) {
     $93 = ___cxa_find_matching_catch()|0;
     $94 = tempRet0;
     ___cxa_call_unexpected(($93|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$82>>2] = 0;
     HEAP32[$this>>2] = 0;
     $97 = 0;
     break;
    }
   }
  } while(0);
  $95 = ($5|0)<(0);
  if ($95) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $96 = $97;
  $98 = (($96|0) / 48)&-1;
  $99 = ($98>>>0)<(1073741823);
  if ($99) {
   $100 = $98 << 1;
   $101 = ($100>>>0)<($6>>>0);
   $102 = $101 ? $6 : $100;
   $103 = ($102|0)<(0);
   if ($103) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i31 = $102;
   }
  } else {
   $$0$i31 = 2147483647;
  }
  $104 = ($$0$i31*48)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $105 = (__Z15malloc_internaljj10MemLabelIdiPKci($104,16,$$byval_copy3,0,766088,79)|0);
  $106 = (($this) + 4|0);
  HEAP32[$106>>2] = $105;
  HEAP32[$this>>2] = $105;
  $107 = (($105) + (($$0$i31*48)|0)|0);
  HEAP32[$7>>2] = $107;
  $108 = ($1|0)==($2|0);
  if ($108) {
   STACKTOP = sp;return;
  } else {
   $110 = $105;$111 = $1;
  }
  while(1) {
   $109 = ($110|0)==(0|0);
   if ($109) {
    $113 = 0;
   } else {
    __ZN13AnimationClip9PPtrCurveC2ERKS0_($110,$111);
    $$pre1$i = HEAP32[$106>>2]|0;
    $113 = $$pre1$i;
   }
   $112 = (($113) + 48|0);
   HEAP32[$106>>2] = $112;
   $114 = (($111) + 48|0);
   $115 = ($114|0)==($2|0);
   if ($115) {
    break;
   } else {
    $110 = $112;$111 = $114;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16;
 $18 = (($17) - ($11))|0;
 $19 = (($18|0) / 48)&-1;
 $20 = ($6>>>0)>($19>>>0);
 if ($20) {
  $21 = (($1) + (($19*48)|0)|0);
  $23 = $21;$__growing$0$off0 = 1;
 } else {
  $23 = $2;$__growing$0$off0 = 0;
 }
 $22 = ($1|0)==($23|0);
 if ($22) {
  $$0$lcssa$i$i = $9;
 } else {
  $scevgep$i = (($23) + -48|0);
  $24 = (0 - ($4))|0;
  $uglygep$i = (($scevgep$i) + ($24)|0);
  $uglygep16$i = $uglygep$i;
  $25 = (($uglygep16$i>>>0) / 48)&-1;
  $$01$i$i = $9;$26 = $1;
  while(1) {
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($$01$i$i,$26)|0);
   $27 = (($$01$i$i) + 12|0);
   $28 = (($26) + 12|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($27,$28)|0);
   $29 = (($26) + 24|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($$01$i$i) + 24|0);
   HEAP32[$31>>2] = $30;
   $32 = (($26) + 28|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($$01$i$i) + 28|0);
   HEAP32[$34>>2] = $33;
   $35 = ($26|0)==($$01$i$i|0);
   if (!($35)) {
    $36 = (($$01$i$i) + 32|0);
    $37 = (($26) + 32|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($26) + 40|0);
    $40 = HEAP32[$39>>2]|0;
    $$idx$i$i = $40 << 3;
    $41 = $$idx$i$i >> 3;
    $42 = (($$01$i$i) + 40|0);
    HEAP32[$42>>2] = $41;
    $43 = (($$01$i$i) + 44|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = $44 & 2147483647;
    $46 = ($45>>>0)<($41>>>0);
    do {
     if ($46) {
      $47 = ($44|0)>(-1);
      if ($47) {
       HEAP32[$43>>2] = $41;
       $48 = HEAP32[$36>>2]|0;
       $49 = (($$01$i$i) + 36|0);
       $50 = HEAP32[$49>>2]|0;
       HEAP32[$0>>2] = $50;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
       $51 = (__Z16realloc_internalPvji10MemLabelIdiPKci($48,$$idx$i$i,4,$$byval_copy3,0,766088,370)|0);
       HEAP32[$36>>2] = $51;
       $60 = $51;
       break;
      } else {
       $52 = (($$01$i$i) + 36|0);
       $53 = HEAP32[$52>>2]|0;
       HEAP32[$0>>2] = $53;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
       $54 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx$i$i,4,$$byval_copy3,0,766088,352)|0);
       $55 = HEAP32[$36>>2]|0;
       $56 = HEAP32[$42>>2]|0;
       $57 = $56 << 3;
       _memcpy(($54|0),($55|0),($57|0))|0;
       HEAP32[$43>>2] = $41;
       HEAP32[$36>>2] = $54;
       $60 = $54;
       break;
      }
     } else {
      $$pre$i$i$i = HEAP32[$36>>2]|0;
      $60 = $$pre$i$i$i;
     }
    } while(0);
    $58 = HEAP32[$42>>2]|0;
    $59 = $58 << 3;
    _memcpy(($60|0),($38|0),($59|0))|0;
   }
   $61 = (($26) + 48|0);
   $62 = (($$01$i$i) + 48|0);
   $63 = ($61|0)==($23|0);
   if ($63) {
    break;
   } else {
    $$01$i$i = $62;$26 = $61;
   }
  }
  $64 = (($25) + 1)|0;
  $scevgep17$i = (($9) + (($64*48)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if (!($__growing$0$off0)) {
  while(1) {
   $74 = HEAP32[$15>>2]|0;
   $75 = ($74|0)==($$0$lcssa$i$i|0);
   if ($75) {
    label = 41;
    break;
   }
   $76 = (($74) + -48|0);
   HEAP32[$15>>2] = $76;
   __THREW__ = 0;
   invoke_vi(3692,($76|0));
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    label = 23;
    break;
   }
  }
  if ((label|0) == 23) {
   $79 = ___cxa_find_matching_catch()|0;
   $80 = tempRet0;
   ___cxa_call_unexpected(($79|0));
   // unreachable;
  }
  else if ((label|0) == 41) {
   STACKTOP = sp;return;
  }
 }
 $65 = HEAP32[$__last>>2]|0;
 $66 = ($23|0)==($65|0);
 if ($66) {
  STACKTOP = sp;return;
 }
 $$pre$i12 = HEAP32[$15>>2]|0;
 $68 = $$pre$i12;$69 = $23;
 while(1) {
  $67 = ($68|0)==(0|0);
  if ($67) {
   $71 = 0;
  } else {
   __ZN13AnimationClip9PPtrCurveC2ERKS0_($68,$69);
   $$pre1$i14 = HEAP32[$15>>2]|0;
   $71 = $$pre1$i14;
  }
  $70 = (($71) + 48|0);
  HEAP32[$15>>2] = $70;
  $72 = (($69) + 48|0);
  $73 = ($72|0)==($65|0);
  if ($73) {
   break;
  } else {
   $68 = $70;$69 = $72;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13AnimationClip9PPtrCurveD2Ev($this) {
 $this = $this|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 do {
  if ($5) {
   $6 = (($this) + 32|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($this) + 36|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$2>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($7|0),($$byval_copy4|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$6>>2] = 0;
    break;
   }
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   $33 = (($this) + 12|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34 & 1;
   $36 = ($35<<24>>24)==(0);
   if (!($36)) {
    $37 = (($this) + 20|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($38|0),($$byval_copy4|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     $41 = ___cxa_find_matching_catch()|0;
     $42 = tempRet0;
     ___cxa_call_unexpected(($41|0));
     // unreachable;
    }
   }
   $43 = HEAP8[$this>>0]|0;
   $44 = $43 & 1;
   $45 = ($44<<24>>24)==(0);
   if ($45) {
    ___resumeException($31|0);
    // unreachable;
   }
   $46 = (($this) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($47|0),($$byval_copy4|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $50 = ___cxa_find_matching_catch()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   } else {
    ___resumeException($31|0);
    // unreachable;
   }
  }
 } while(0);
 $12 = (($this) + 12|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  $16 = (($this) + 20|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($17|0),($$byval_copy4|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   ___cxa_call_unexpected(($20|0));
   // unreachable;
  }
 }
 $22 = HEAP8[$this>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (($this) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($26|0),($$byval_copy4|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  ___cxa_call_unexpected(($29|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip9PPtrCurveC2ERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $$idx$i$i = 0, $$pre$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i5 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = sp + 8|0;
 $4 = sp + 12|0;
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $12 = (($0) + 1|0);
  $13 = $5&255;
  $14 = $13 >>> 1;
  $16 = $14;$27 = $12;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $16 = $11;$27 = $9;
 }
 $15 = ($16>>>0)>(2147483631);
 if ($15) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $17 = ($16>>>0)<(11);
 if ($17) {
  $18 = $16 << 1;
  $19 = $18&255;
  HEAP8[$this>>0] = $19;
  $20 = (($this) + 1|0);
  $__p$0$i$i$i$i = $20;
 } else {
  $21 = (($16) + 16)|0;
  $22 = $21 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,16,$$byval_copy4,0,766088,79)|0);
  $24 = (($this) + 8|0);
  HEAP32[$24>>2] = $23;
  $25 = $22 | 1;
  HEAP32[$this>>2] = $25;
  $26 = (($this) + 4|0);
  HEAP32[$26>>2] = $16;
  $__p$0$i$i$i$i = $23;
 }
 _memcpy(($__p$0$i$i$i$i|0),($27|0),($16|0))|0;
 $28 = (($__p$0$i$i$i$i) + ($16)|0);
 HEAP8[$28>>0] = 0;
 $29 = (($this) + 12|0);
 $30 = (($0) + 12|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31 & 1;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  $38 = (($30) + 1|0);
  $39 = $31&255;
  $40 = $39 >>> 1;
  $42 = $40;$57 = $38;
 } else {
  $34 = (($0) + 20|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($0) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  $42 = $37;$57 = $35;
 }
 $41 = ($42>>>0)>(2147483631);
 do {
  if ($41) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    label = 23;
   } else {
    // unreachable;
   }
  } else {
   $45 = ($42>>>0)<(11);
   if ($45) {
    $46 = $42 << 1;
    $47 = $46&255;
    HEAP8[$29>>0] = $47;
    $48 = (($29) + 1|0);
    $__p$0$i$i$i$i5 = $48;
   } else {
    $49 = (($42) + 16)|0;
    $50 = $49 & -16;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
    $51 = (invoke_iiiiiii(102,($50|0),16,($$byval_copy4|0),0,(766088|0),79)|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 23;
     break;
    }
    $54 = (($this) + 20|0);
    HEAP32[$54>>2] = $51;
    $55 = $50 | 1;
    HEAP32[$29>>2] = $55;
    $56 = (($this) + 16|0);
    HEAP32[$56>>2] = $42;
    $__p$0$i$i$i$i5 = $51;
   }
   _memcpy(($__p$0$i$i$i$i5|0),($57|0),($42|0))|0;
   $58 = (($__p$0$i$i$i$i5) + ($42)|0);
   HEAP8[$58>>0] = 0;
   $59 = (($this) + 24|0);
   $60 = (($0) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   HEAP32[$59>>2] = $61;
   $62 = (($0) + 28|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($this) + 28|0);
   HEAP32[$64>>2] = $63;
   $65 = HEAP32[$60>>2]|0;
   HEAP32[$59>>2] = $65;
   $66 = (($0) + 36|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($this) + 36|0);
   HEAP32[$68>>2] = $67;
   $69 = (($this) + 40|0);
   HEAP32[$69>>2] = 0;
   $70 = (($this) + 44|0);
   HEAP32[$70>>2] = 0;
   $71 = (($this) + 32|0);
   HEAP32[$71>>2] = 0;
   $72 = (($0) + 32|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($0) + 40|0);
   $75 = HEAP32[$74>>2]|0;
   $$idx$i$i = $75 << 3;
   $76 = $$idx$i$i >> 3;
   HEAP32[$69>>2] = $76;
   $77 = ($76|0)==(0);
   if ($77) {
    $81 = 0;$82 = 0;
    _memcpy(($81|0),($73|0),($82|0))|0;
    $83 = HEAP32[$60>>2]|0;
    HEAP32[$59>>2] = $83;
    STACKTOP = sp;return;
   }
   HEAP32[$70>>2] = $76;
   HEAP32[$3>>2] = $67;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   $78 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i|0),4,($$byval_copy4|0),0,(766088|0),370)|0);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if (!($80)) {
    HEAP32[$71>>2] = $78;
    $$pre$i = HEAP32[$69>>2]|0;
    $phitmp$i = $$pre$i << 3;
    $81 = $78;$82 = $phitmp$i;
    _memcpy(($81|0),($73|0),($82|0))|0;
    $83 = HEAP32[$60>>2]|0;
    HEAP32[$59>>2] = $83;
    STACKTOP = sp;return;
   }
   $86 = ___cxa_find_matching_catch()|0;
   $87 = tempRet0;
   $88 = HEAP8[$29>>0]|0;
   $89 = $88 & 1;
   $90 = ($89<<24>>24)==(0);
   if ($90) {
    $$0 = $87;$$01 = $86;
   } else {
    $91 = (($this) + 20|0);
    $92 = HEAP32[$91>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($92|0),($$byval_copy4|0));
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     $95 = ___cxa_find_matching_catch()|0;
     $96 = tempRet0;
     ___cxa_call_unexpected(($95|0));
     // unreachable;
    } else {
     $$0 = $87;$$01 = $86;
    }
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $84 = ___cxa_find_matching_catch()|0;
  $85 = tempRet0;
  $$0 = $85;$$01 = $84;
 }
 $97 = HEAP8[$this>>0]|0;
 $98 = $97 & 1;
 $99 = ($98<<24>>24)==(0);
 if ($99) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $100 = (($this) + 8|0);
 $101 = HEAP32[$100>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($101|0),($$byval_copy4|0));
 $102 = __THREW__; __THREW__ = 0;
 $103 = $102&1;
 if ($103) {
  $104 = ___cxa_find_matching_catch()|0;
  $105 = tempRet0;
  ___cxa_call_unexpected(($104|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i117 = 0, $$0$i118 = 0, $$0$i6 = 0, $$01$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i10 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 48)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $18 = 0;
   } else {
    $12 = (($11) + 28|0);
    HEAP32[$12>>2] = 0;
    $13 = (($11) + 32|0);
    HEAP32[$13>>2] = 0;
    $14 = (($11) + 40|0);
    HEAP32[$14>>2] = 0;
    $15 = (($11) + 44|0);
    HEAP32[$15>>2] = 0;
    $16 = (($11) + 36|0);
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;
    HEAP32[$16>>2] = 61;
    $$pre1$i = HEAP32[$3>>2]|0;
    $18 = $$pre1$i;
   }
   $17 = (($18) + 48|0);
   HEAP32[$3>>2] = $17;
   $19 = (($$0$i) + -1)|0;
   $20 = ($19|0)==(0);
   if ($20) {
    break;
   } else {
    $$0$i = $19;$11 = $17;
   }
  }
  STACKTOP = sp;return;
 }
 $21 = HEAP32[$this>>2]|0;
 $22 = $21;
 $23 = (($6) - ($22))|0;
 $24 = (($23|0) / 48)&-1;
 $25 = (($24) + ($__n))|0;
 $26 = ($25|0)<(0);
 if ($26) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $27 = (($5) - ($22))|0;
 $28 = (($27|0) / 48)&-1;
 $29 = ($28>>>0)<(1073741823);
 if ($29) {
  $30 = $28 << 1;
  $31 = ($30>>>0)<($25>>>0);
  $32 = $31 ? $25 : $30;
  $33 = ($32|0)==(0);
  if ($33) {
   $$0$i118 = 0;$37 = 0;
  } else {
   $$0$i117 = $32;
   label = 9;
  }
 } else {
  $$0$i117 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $34 = ($$0$i117*48)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $35 = (__Z15malloc_internaljj10MemLabelIdiPKci($34,16,$$byval_copy2,0,766088,79)|0);
  $$0$i118 = $$0$i117;$37 = $35;
 }
 $36 = (($37) + (($24*48)|0)|0);
 $$0$i6 = $__n;$39 = $36;
 while(1) {
  $38 = ($39|0)==(0|0);
  if ($38) {
   $46 = 0;
  } else {
   $40 = (($39) + 28|0);
   HEAP32[$40>>2] = 0;
   $41 = (($39) + 32|0);
   HEAP32[$41>>2] = 0;
   $42 = (($39) + 40|0);
   HEAP32[$42>>2] = 0;
   $43 = (($39) + 44|0);
   HEAP32[$43>>2] = 0;
   $44 = (($39) + 36|0);
   ;HEAP32[$39+0>>2]=0|0;HEAP32[$39+4>>2]=0|0;HEAP32[$39+8>>2]=0|0;HEAP32[$39+12>>2]=0|0;HEAP32[$39+16>>2]=0|0;HEAP32[$39+20>>2]=0|0;
   HEAP32[$44>>2] = 61;
   $46 = $39;
  }
  $45 = (($46) + 48|0);
  $47 = (($$0$i6) + -1)|0;
  $48 = ($47|0)==(0);
  if ($48) {
   break;
  } else {
   $$0$i6 = $47;$39 = $45;
  }
 }
 $49 = (($37) + (($$0$i118*48)|0)|0);
 $50 = HEAP32[$this>>2]|0;
 $51 = HEAP32[$3>>2]|0;
 $52 = ($51|0)==($50|0);
 do {
  if ($52) {
   $59 = $36;$62 = $50;$87 = $50;
  } else {
   $$01$i$i = $51;$54 = $36;
   while(1) {
    $53 = (($54) + -48|0);
    $55 = (($$01$i$i) + -48|0);
    __THREW__ = 0;
    invoke_vii(3378,($53|0),($55|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = ($55|0)==($50|0);
    if ($58) {
     label = 17;
     break;
    } else {
     $$01$i$i = $55;$54 = $53;
    }
   }
   if ((label|0) == 17) {
    $$pre$i10 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$3>>2]|0;
    $59 = $53;$62 = $$pre$i10;$87 = $$pre;
    break;
   }
   $73 = ___cxa_find_matching_catch()|0;
   $74 = tempRet0;
   $76 = $45;
   while(1) {
    $75 = ($76|0)==($54|0);
    if ($75) {
     break;
    }
    $77 = (($76) + -48|0);
    __THREW__ = 0;
    invoke_vi(3692,($77|0));
    $78 = __THREW__; __THREW__ = 0;
    $79 = $78&1;
    if ($79) {
     label = 28;
     break;
    } else {
     $76 = $77;
    }
   }
   if ((label|0) == 28) {
    $80 = ___cxa_find_matching_catch()|0;
    $81 = tempRet0;
    ___cxa_call_unexpected(($80|0));
    // unreachable;
   }
   $82 = ($37|0)==(0|0);
   if ($82) {
    ___resumeException($73|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($37|0),($$byval_copy2|0));
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    $85 = ___cxa_find_matching_catch()|0;
    $86 = tempRet0;
    ___cxa_call_unexpected(($85|0));
    // unreachable;
   } else {
    ___resumeException($73|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $59;
 HEAP32[$3>>2] = $45;
 HEAP32[$1>>2] = $49;
 $61 = $87;
 while(1) {
  $60 = ($61|0)==($62|0);
  if ($60) {
   break;
  }
  $63 = (($61) + -48|0);
  __THREW__ = 0;
  invoke_vi(3692,($63|0));
  $64 = __THREW__; __THREW__ = 0;
  $65 = $64&1;
  if ($65) {
   label = 21;
   break;
  } else {
   $61 = $63;
  }
 }
 if ((label|0) == 21) {
  $66 = ___cxa_find_matching_catch()|0;
  $67 = tempRet0;
  ___cxa_call_unexpected(($66|0));
  // unreachable;
 }
 $68 = ($62|0)==(0|0);
 if ($68) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($62|0),($$byval_copy2|0));
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  ___cxa_call_unexpected(($71|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN13AnimationClip10FloatCurve8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 116|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*116)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip10FloatCurve8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN17AnimationCurveTplIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($this) + 12|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $2 = (($this) + 24|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $10 = $$pre$i$i$i;
  $11 = (_llvm_bswap_i32(($10|0))|0);
  HEAP32[$2>>2] = $11;
  $12 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$transfer);
  STACKTOP = sp;return;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;
  $11 = (_llvm_bswap_i32(($10|0))|0);
  HEAP32[$2>>2] = $11;
  $12 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$transfer);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy13 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy13 = sp + 32|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $temp = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $4 = (($v) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$v>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 116)&-1;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $82 = ($10>>>0)>($sz>>>0);
  if (!($82)) {
   STACKTOP = sp;return;
  }
  $83 = (($6) + (($sz*116)|0)|0);
  $$idx = ($sz*116)|0;
  $84 = (($$idx|0) / 116)&-1;
  $85 = ($sz|0)==(0);
  do {
   if ($85) {
    $118 = 0;$119 = 0;$121 = 0;$123 = $6;$135 = $5;
   } else {
    $86 = ($$idx|0)<(0);
    if ($86) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 37;
     } else {
      // unreachable;
     }
    } else {
     HEAP32[$1>>2] = 18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
     $89 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy13|0),0,(766088|0),79)|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 37;
     } else {
      $92 = (($89) + (($84*116)|0)|0);
      $94 = $89;$95 = $6;
      while(1) {
       $93 = ($94|0)==(0|0);
       if ($93) {
        $99 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(3381,($94|0),($95|0));
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         break;
        } else {
         $99 = $94;
        }
       }
       $98 = (($99) + 116|0);
       $100 = (($95) + 116|0);
       $101 = ($100|0)==($83|0);
       if ($101) {
        label = 44;
        break;
       } else {
        $94 = $98;$95 = $100;
       }
      }
      if ((label|0) == 44) {
       $$pre = HEAP32[$v>>2]|0;
       $$pre31 = HEAP32[$4>>2]|0;
       $118 = $89;$119 = $98;$121 = $92;$123 = $$pre;$135 = $$pre31;
       break;
      }
      $104 = ___cxa_find_matching_catch()|0;
      $105 = tempRet0;
      $106 = ($89|0)==(0|0);
      if ($106) {
       $eh$lpad$body$index3Z2D = $105;$eh$lpad$body$indexZ2D = $104;
      } else {
       $108 = $94;
       while(1) {
        $107 = ($108|0)==($89|0);
        if ($107) {
         break;
        }
        $109 = (($108) + -116|0);
        __THREW__ = 0;
        invoke_vi(3693,($109|0));
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         label = 41;
         break;
        } else {
         $108 = $109;
        }
       }
       if ((label|0) == 41) {
        $112 = ___cxa_find_matching_catch()|0;
        $113 = tempRet0;
        ___cxa_call_unexpected(($112|0));
        // unreachable;
       }
       HEAP32[$0>>2] = 18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($89|0),($$byval_copy13|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        $116 = ___cxa_find_matching_catch()|0;
        $117 = tempRet0;
        ___cxa_call_unexpected(($116|0));
        // unreachable;
       } else {
        $eh$lpad$body$index3Z2D = $105;$eh$lpad$body$indexZ2D = $104;
       }
      }
     }
    }
    if ((label|0) == 37) {
     $102 = ___cxa_find_matching_catch()|0;
     $103 = tempRet0;
     $eh$lpad$body$index3Z2D = $103;$eh$lpad$body$indexZ2D = $102;
    }
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $118;
  HEAP32[$4>>2] = $119;
  $120 = (($v) + 8|0);
  HEAP32[$120>>2] = $121;
  $122 = ($123|0)==(0|0);
  if ($122) {
   STACKTOP = sp;return;
  } else {
   $125 = $135;
  }
  while(1) {
   $124 = ($125|0)==($123|0);
   if ($124) {
    break;
   }
   $126 = (($125) + -116|0);
   __THREW__ = 0;
   invoke_vi(3693,($126|0));
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if ($128) {
    label = 48;
    break;
   } else {
    $125 = $126;
   }
  }
  if ((label|0) == 48) {
   $129 = ___cxa_find_matching_catch()|0;
   $130 = tempRet0;
   ___cxa_call_unexpected(($129|0));
   // unreachable;
  }
  HEAP32[$0>>2] = 18;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($123|0),($$byval_copy13|0));
  $131 = __THREW__; __THREW__ = 0;
  $132 = $131&1;
  if ($132) {
   $133 = ___cxa_find_matching_catch()|0;
   $134 = tempRet0;
   ___cxa_call_unexpected(($133|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 116)&-1;
 $17 = ($16|0)==($sz|0);
 if ($17) {
  $81 = (($sz) - ($10))|0;
  __ZNSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($v,$81);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $18 = (($temp) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($temp) + 8|0);
 HEAP32[$19>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3379,($temp|0),($sz|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L49: do {
  if (!($21)) {
   $22 = HEAP32[$v>>2]|0;
   HEAP32[$2>>2] = $22;
   $23 = HEAP32[$4>>2]|0;
   HEAP32[$3>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viii(2003,($temp|0),($$byval_copy|0),($$byval_copy13|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$18>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = (($30|0) / 116)&-1;
    $32 = ($31>>>0)<($sz>>>0);
    L52: do {
     if ($32) {
      $33 = (($sz) - ($31))|0;
      __THREW__ = 0;
      invoke_vii(3380,($temp|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L49;
      }
      $$pre32 = HEAP32[$18>>2]|0;
      $49 = $$pre32;
     } else {
      $36 = ($31>>>0)>($sz>>>0);
      if ($36) {
       $37 = (($27) + (($sz*116)|0)|0);
       $38 = ($26|0)==($37|0);
       if ($38) {
        $49 = $26;
       } else {
        $40 = $26;
        while(1) {
         $39 = (($40) + -116|0);
         HEAP32[$18>>2] = $39;
         __THREW__ = 0;
         invoke_vi(3693,($39|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break;
         }
         $$pre$i = HEAP32[$18>>2]|0;
         $43 = ($$pre$i|0)==($37|0);
         if ($43) {
          $49 = $37;
          break L52;
         } else {
          $40 = $$pre$i;
         }
        }
        $44 = ___cxa_find_matching_catch()|0;
        $45 = tempRet0;
        ___cxa_call_unexpected(($44|0));
        // unreachable;
       }
      } else {
       $49 = $26;
      }
     }
    } while(0);
    $46 = HEAP32[$temp>>2]|0;
    $47 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $47;
    HEAP32[$v>>2] = $46;
    $48 = HEAP32[$4>>2]|0;
    HEAP32[$18>>2] = $48;
    HEAP32[$4>>2] = $49;
    $50 = HEAP32[$19>>2]|0;
    $51 = HEAP32[$12>>2]|0;
    HEAP32[$19>>2] = $51;
    HEAP32[$12>>2] = $50;
    $52 = ($47|0)==(0|0);
    if ($52) {
     STACKTOP = sp;return;
    } else {
     $54 = $48;
    }
    while(1) {
     $53 = ($54|0)==($47|0);
     if ($53) {
      break;
     }
     $55 = (($54) + -116|0);
     HEAP32[$18>>2] = $55;
     __THREW__ = 0;
     invoke_vi(3693,($55|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 17;
      break;
     }
     $$pre33 = HEAP32[$18>>2]|0;
     $54 = $$pre33;
    }
    if ((label|0) == 17) {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     ___cxa_call_unexpected(($58|0));
     // unreachable;
    }
    $60 = HEAP32[$temp>>2]|0;
    HEAP32[$$byval_copy>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($60|0),($$byval_copy13|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $63 = ___cxa_find_matching_catch()|0;
     $64 = tempRet0;
     ___cxa_call_unexpected(($63|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $65 = ___cxa_find_matching_catch()|0;
 $66 = tempRet0;
 $67 = HEAP32[$temp>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  $$0 = $66;$$01 = $65;
  ___resumeException($$01|0);
  // unreachable;
 }
 while(1) {
  $69 = HEAP32[$18>>2]|0;
  $70 = ($69|0)==($67|0);
  if ($70) {
   break;
  }
  $71 = (($69) + -116|0);
  HEAP32[$18>>2] = $71;
  __THREW__ = 0;
  invoke_vi(3693,($71|0));
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  $74 = ___cxa_find_matching_catch()|0;
  $75 = tempRet0;
  ___cxa_call_unexpected(($74|0));
  // unreachable;
 }
 $76 = HEAP32[$temp>>2]|0;
 HEAP32[$$byval_copy>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($76|0),($$byval_copy13|0));
 $77 = __THREW__; __THREW__ = 0;
 $78 = $77&1;
 if ($78) {
  $79 = ___cxa_find_matching_catch()|0;
  $80 = tempRet0;
  ___cxa_call_unexpected(($79|0));
  // unreachable;
 } else {
  $$0 = $66;$$01 = $65;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i = 0, $$pre10 = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 116)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = (($12|0) / 116)&-1;
 $14 = ($__n|0)==(0);
 if ($14) {
  $18 = 0;$21 = $10;$22 = $3;
 } else {
  $15 = ($__n*116)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy2,0,766088,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre10 = HEAP32[$9>>2]|0;
  $18 = $16;$21 = $$pre10;$22 = $$pre;
 }
 $17 = (($18) + (($13*116)|0)|0);
 $19 = (($18) + (($__n*116)|0)|0);
 $20 = ($21|0)==($22|0);
 do {
  if ($20) {
   $29 = $17;$32 = $21;$57 = $21;
  } else {
   $$01$i$i = $21;$24 = $17;
   while(1) {
    $23 = (($24) + -116|0);
    $25 = (($$01$i$i) + -116|0);
    __THREW__ = 0;
    invoke_vii(3381,($23|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = ($25|0)==($22|0);
    if ($28) {
     label = 7;
     break;
    } else {
     $$01$i$i = $25;$24 = $23;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre11 = HEAP32[$9>>2]|0;
    $29 = $23;$32 = $$pre$i;$57 = $$pre11;
    break;
   }
   $43 = ___cxa_find_matching_catch()|0;
   $44 = tempRet0;
   $46 = $17;
   while(1) {
    $45 = ($46|0)==($24|0);
    if ($45) {
     break;
    }
    $47 = (($46) + -116|0);
    __THREW__ = 0;
    invoke_vi(3693,($47|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 18;
     break;
    } else {
     $46 = $47;
    }
   }
   if ((label|0) == 18) {
    $50 = ___cxa_find_matching_catch()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   }
   $52 = ($18|0)==(0|0);
   if ($52) {
    ___resumeException($43|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($18|0),($$byval_copy2|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    ___cxa_call_unexpected(($55|0));
    // unreachable;
   } else {
    ___resumeException($43|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $29;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $31 = $57;
 while(1) {
  $30 = ($31|0)==($32|0);
  if ($30) {
   break;
  }
  $33 = (($31) + -116|0);
  __THREW__ = 0;
  invoke_vi(3693,($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 11;
   break;
  } else {
   $31 = $33;
  }
 }
 if ((label|0) == 11) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 }
 $38 = ($32|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy2|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  ___cxa_call_unexpected(($41|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 116)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 116)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = (($18|0) / 116)&-1;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + (($19*116)|0)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i = (($23) + -116|0);
   $24 = (0 - ($4))|0;
   $uglygep$i = (($scevgep$i) + ($24)|0);
   $uglygep16$i = $uglygep$i;
   $25 = (($uglygep16$i>>>0) / 116)&-1;
   $$01$i$i = $9;$26 = $1;
   while(1) {
    (__ZN13AnimationClip10FloatCurveaSERKS0_($$01$i$i,$26)|0);
    $27 = (($26) + 116|0);
    $28 = (($$01$i$i) + 116|0);
    $29 = ($27|0)==($23|0);
    if ($29) {
     break;
    } else {
     $$01$i$i = $28;$26 = $27;
    }
   }
   $30 = (($25) + 1)|0;
   $scevgep17$i = (($9) + (($30*116)|0)|0);
   $$0$lcssa$i$i = $scevgep17$i;
  }
  if (!($__growing$0$off0)) {
   while(1) {
    $39 = HEAP32[$15>>2]|0;
    $40 = ($39|0)==($$0$lcssa$i$i|0);
    if ($40) {
     label = 34;
     break;
    }
    $41 = (($39) + -116|0);
    HEAP32[$15>>2] = $41;
    __THREW__ = 0;
    invoke_vi(3693,($41|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 16;
     break;
    }
   }
   if ((label|0) == 16) {
    $44 = ___cxa_find_matching_catch()|0;
    $45 = tempRet0;
    ___cxa_call_unexpected(($44|0));
    // unreachable;
   }
   else if ((label|0) == 34) {
    STACKTOP = sp;return;
   }
  }
  $31 = ($23|0)==($2|0);
  if ($31) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$15>>2]|0;
  $33 = $$pre$i12;$34 = $23;
  while(1) {
   $32 = ($33|0)==(0|0);
   if ($32) {
    $36 = 0;
   } else {
    __ZN13AnimationClip10FloatCurveC2ERKS0_($33,$34);
    $$pre1$i14 = HEAP32[$15>>2]|0;
    $36 = $$pre1$i14;
   }
   $35 = (($36) + 116|0);
   HEAP32[$15>>2] = $35;
   $37 = (($34) + 116|0);
   $38 = ($37|0)==($2|0);
   if ($38) {
    break;
   } else {
    $33 = $35;$34 = $37;
   }
  }
  STACKTOP = sp;return;
 }
 $46 = ($9|0)==(0|0);
 do {
  if ($46) {
   $62 = $8;
  } else {
   $47 = (($this) + 4|0);
   while(1) {
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==($9|0);
    if ($49) {
     break;
    }
    $50 = (($48) + -116|0);
    HEAP32[$47>>2] = $50;
    __THREW__ = 0;
    invoke_vi(3693,($50|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     label = 21;
     break;
    }
   }
   if ((label|0) == 21) {
    $53 = ___cxa_find_matching_catch()|0;
    $54 = tempRet0;
    ___cxa_call_unexpected(($53|0));
    // unreachable;
   }
   $55 = HEAP32[$this>>2]|0;
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($55|0),($$byval_copy1|0));
   $56 = __THREW__; __THREW__ = 0;
   $57 = $56&1;
   if ($57) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    ___cxa_call_unexpected(($58|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$47>>2] = 0;
    HEAP32[$this>>2] = 0;
    $62 = 0;
    break;
   }
  }
 } while(0);
 $60 = ($5|0)<(0);
 if ($60) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $61 = $62;
 $63 = (($61|0) / 116)&-1;
 $64 = ($63>>>0)<(1073741823);
 if ($64) {
  $65 = $63 << 1;
  $66 = ($65>>>0)<($6>>>0);
  $67 = $66 ? $6 : $65;
  $68 = ($67|0)<(0);
  if ($68) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i31 = $67;
  }
 } else {
  $$0$i31 = 2147483647;
 }
 $69 = ($$0$i31*116)|0;
 HEAP32[$0>>2] = 18;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $70 = (__Z15malloc_internaljj10MemLabelIdiPKci($69,16,$$byval_copy1,0,766088,79)|0);
 $71 = (($this) + 4|0);
 HEAP32[$71>>2] = $70;
 HEAP32[$this>>2] = $70;
 $72 = (($70) + (($$0$i31*116)|0)|0);
 HEAP32[$7>>2] = $72;
 $73 = ($1|0)==($2|0);
 if ($73) {
  STACKTOP = sp;return;
 } else {
  $75 = $70;$76 = $1;
 }
 while(1) {
  $74 = ($75|0)==(0|0);
  if ($74) {
   $78 = 0;
  } else {
   __ZN13AnimationClip10FloatCurveC2ERKS0_($75,$76);
   $$pre1$i = HEAP32[$71>>2]|0;
   $78 = $$pre1$i;
  }
  $77 = (($78) + 116|0);
  HEAP32[$71>>2] = $77;
  $79 = (($76) + 116|0);
  $80 = ($79|0)==($2|0);
  if ($80) {
   break;
  } else {
   $75 = $77;$76 = $79;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13AnimationClip10FloatCurveC2ERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $$idx$i$i$i$i = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i5 = 0, $phitmp$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = sp + 8|0;
 $4 = sp + 12|0;
 $5 = HEAP8[$0>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $12 = (($0) + 1|0);
  $13 = $5&255;
  $14 = $13 >>> 1;
  $16 = $14;$27 = $12;
 } else {
  $8 = (($0) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($0) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $16 = $11;$27 = $9;
 }
 $15 = ($16>>>0)>(2147483631);
 if ($15) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $17 = ($16>>>0)<(11);
 if ($17) {
  $18 = $16 << 1;
  $19 = $18&255;
  HEAP8[$this>>0] = $19;
  $20 = (($this) + 1|0);
  $__p$0$i$i$i$i = $20;
 } else {
  $21 = (($16) + 16)|0;
  $22 = $21 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,16,$$byval_copy4,0,766088,79)|0);
  $24 = (($this) + 8|0);
  HEAP32[$24>>2] = $23;
  $25 = $22 | 1;
  HEAP32[$this>>2] = $25;
  $26 = (($this) + 4|0);
  HEAP32[$26>>2] = $16;
  $__p$0$i$i$i$i = $23;
 }
 _memcpy(($__p$0$i$i$i$i|0),($27|0),($16|0))|0;
 $28 = (($__p$0$i$i$i$i) + ($16)|0);
 HEAP8[$28>>0] = 0;
 $29 = (($this) + 12|0);
 $30 = (($0) + 12|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31 & 1;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  $38 = (($30) + 1|0);
  $39 = $31&255;
  $40 = $39 >>> 1;
  $42 = $40;$57 = $38;
 } else {
  $34 = (($0) + 20|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($0) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  $42 = $37;$57 = $35;
 }
 $41 = ($42>>>0)>(2147483631);
 do {
  if ($41) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    label = 23;
   } else {
    // unreachable;
   }
  } else {
   $45 = ($42>>>0)<(11);
   if ($45) {
    $46 = $42 << 1;
    $47 = $46&255;
    HEAP8[$29>>0] = $47;
    $48 = (($29) + 1|0);
    $__p$0$i$i$i$i5 = $48;
   } else {
    $49 = (($42) + 16)|0;
    $50 = $49 & -16;
    HEAP32[$4>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
    $51 = (invoke_iiiiiii(102,($50|0),16,($$byval_copy4|0),0,(766088|0),79)|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 23;
     break;
    }
    $54 = (($this) + 20|0);
    HEAP32[$54>>2] = $51;
    $55 = $50 | 1;
    HEAP32[$29>>2] = $55;
    $56 = (($this) + 16|0);
    HEAP32[$56>>2] = $42;
    $__p$0$i$i$i$i5 = $51;
   }
   _memcpy(($__p$0$i$i$i$i5|0),($57|0),($42|0))|0;
   $58 = (($__p$0$i$i$i$i5) + ($42)|0);
   HEAP8[$58>>0] = 0;
   $59 = (($this) + 24|0);
   $60 = (($0) + 24|0);
   $61 = HEAP32[$60>>2]|0;
   HEAP32[$59>>2] = $61;
   $62 = (($0) + 28|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = (($this) + 28|0);
   HEAP32[$64>>2] = $63;
   $65 = HEAP32[$60>>2]|0;
   HEAP32[$59>>2] = $65;
   $66 = (($this) + 32|0);
   $67 = (($0) + 32|0);
   dest=$66+0|0; src=$67+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $68 = (($0) + 92|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($this) + 92|0);
   HEAP32[$70>>2] = $69;
   $71 = (($this) + 96|0);
   HEAP32[$71>>2] = 0;
   $72 = (($this) + 100|0);
   HEAP32[$72>>2] = 0;
   $73 = (($this) + 88|0);
   HEAP32[$73>>2] = 0;
   $74 = (($0) + 88|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = (($0) + 96|0);
   $77 = HEAP32[$76>>2]|0;
   $$idx$i$i$i$i = $77 << 4;
   $78 = $$idx$i$i$i$i >> 4;
   HEAP32[$71>>2] = $78;
   $79 = ($78|0)==(0);
   if ($79) {
    $83 = 0;$84 = 0;
    _memcpy(($83|0),($75|0),($84|0))|0;
    $85 = (($this) + 104|0);
    $86 = (($0) + 104|0);
    $87 = $86;
    $88 = $87;
    $89 = HEAP32[$88>>2]|0;
    $90 = (($87) + 4)|0;
    $91 = $90;
    $92 = HEAP32[$91>>2]|0;
    $93 = $85;
    $94 = $93;
    HEAP32[$94>>2] = $89;
    $95 = (($93) + 4)|0;
    $96 = $95;
    HEAP32[$96>>2] = $92;
    $97 = (($this) + 112|0);
    $98 = (($0) + 112|0);
    $99 = HEAP32[$98>>2]|0;
    HEAP32[$97>>2] = $99;
    STACKTOP = sp;return;
   }
   HEAP32[$72>>2] = $78;
   HEAP32[$3>>2] = $69;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   $80 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i|0),4,($$byval_copy4|0),0,(766088|0),370)|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if (!($82)) {
    HEAP32[$73>>2] = $80;
    $$pre$i$i$i = HEAP32[$71>>2]|0;
    $phitmp$i$i$i = $$pre$i$i$i << 4;
    $83 = $80;$84 = $phitmp$i$i$i;
    _memcpy(($83|0),($75|0),($84|0))|0;
    $85 = (($this) + 104|0);
    $86 = (($0) + 104|0);
    $87 = $86;
    $88 = $87;
    $89 = HEAP32[$88>>2]|0;
    $90 = (($87) + 4)|0;
    $91 = $90;
    $92 = HEAP32[$91>>2]|0;
    $93 = $85;
    $94 = $93;
    HEAP32[$94>>2] = $89;
    $95 = (($93) + 4)|0;
    $96 = $95;
    HEAP32[$96>>2] = $92;
    $97 = (($this) + 112|0);
    $98 = (($0) + 112|0);
    $99 = HEAP32[$98>>2]|0;
    HEAP32[$97>>2] = $99;
    STACKTOP = sp;return;
   }
   $102 = ___cxa_find_matching_catch()|0;
   $103 = tempRet0;
   $104 = HEAP8[$29>>0]|0;
   $105 = $104 & 1;
   $106 = ($105<<24>>24)==(0);
   if ($106) {
    $$0 = $103;$$01 = $102;
   } else {
    $107 = (($this) + 20|0);
    $108 = HEAP32[$107>>2]|0;
    HEAP32[$2>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($108|0),($$byval_copy4|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     $111 = ___cxa_find_matching_catch()|0;
     $112 = tempRet0;
     ___cxa_call_unexpected(($111|0));
     // unreachable;
    } else {
     $$0 = $103;$$01 = $102;
    }
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $100 = ___cxa_find_matching_catch()|0;
  $101 = tempRet0;
  $$0 = $101;$$01 = $100;
 }
 $113 = HEAP8[$this>>0]|0;
 $114 = $113 & 1;
 $115 = ($114<<24>>24)==(0);
 if ($115) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $116 = (($this) + 8|0);
 $117 = HEAP32[$116>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($117|0),($$byval_copy4|0));
 $118 = __THREW__; __THREW__ = 0;
 $119 = $118&1;
 if ($119) {
  $120 = ___cxa_find_matching_catch()|0;
  $121 = tempRet0;
  ___cxa_call_unexpected(($120|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i117 = 0, $$0$i118 = 0, $$0$i6 = 0, $$01$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i10 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 116)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $26 = 0;
   } else {
    $12 = (($11) + 28|0);
    HEAP32[$12>>2] = 0;
    $13 = (($11) + 36|0);
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;
    HEAPF32[$13>>2] = Math_fround(inf);
    $14 = (($11) + 32|0);
    HEAP32[$14>>2] = 0;
    $15 = (($11) + 40|0);
    ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;
    $16 = (($11) + 64|0);
    HEAPF32[$16>>2] = Math_fround(inf);
    $17 = (($11) + 60|0);
    HEAP32[$17>>2] = 0;
    $18 = (($11) + 68|0);
    $19 = (($11) + 96|0);
    HEAP32[$19>>2] = 0;
    $20 = (($11) + 100|0);
    HEAP32[$20>>2] = 0;
    $21 = (($11) + 92|0);
    ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;
    HEAP32[$21>>2] = 61;
    $22 = (($11) + 108|0);
    HEAP32[$22>>2] = 2;
    $23 = (($11) + 104|0);
    HEAP32[$23>>2] = 2;
    $24 = (($11) + 112|0);
    HEAP32[$24>>2] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $26 = $$pre1$i;
   }
   $25 = (($26) + 116|0);
   HEAP32[$3>>2] = $25;
   $27 = (($$0$i) + -1)|0;
   $28 = ($27|0)==(0);
   if ($28) {
    break;
   } else {
    $$0$i = $27;$11 = $25;
   }
  }
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$this>>2]|0;
 $30 = $29;
 $31 = (($6) - ($30))|0;
 $32 = (($31|0) / 116)&-1;
 $33 = (($32) + ($__n))|0;
 $34 = ($33|0)<(0);
 if ($34) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $35 = (($5) - ($30))|0;
 $36 = (($35|0) / 116)&-1;
 $37 = ($36>>>0)<(1073741823);
 if ($37) {
  $38 = $36 << 1;
  $39 = ($38>>>0)<($33>>>0);
  $40 = $39 ? $33 : $38;
  $41 = ($40|0)==(0);
  if ($41) {
   $$0$i118 = 0;$45 = 0;
  } else {
   $$0$i117 = $40;
   label = 9;
  }
 } else {
  $$0$i117 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $42 = ($$0$i117*116)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $43 = (__Z15malloc_internaljj10MemLabelIdiPKci($42,16,$$byval_copy2,0,766088,79)|0);
  $$0$i118 = $$0$i117;$45 = $43;
 }
 $44 = (($45) + (($32*116)|0)|0);
 $$0$i6 = $__n;$47 = $44;
 while(1) {
  $46 = ($47|0)==(0|0);
  if ($46) {
   $62 = 0;
  } else {
   $48 = (($47) + 28|0);
   HEAP32[$48>>2] = 0;
   $49 = (($47) + 36|0);
   ;HEAP32[$47+0>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;HEAP32[$47+12>>2]=0|0;HEAP32[$47+16>>2]=0|0;HEAP32[$47+20>>2]=0|0;
   HEAPF32[$49>>2] = Math_fround(inf);
   $50 = (($47) + 32|0);
   HEAP32[$50>>2] = 0;
   $51 = (($47) + 40|0);
   ;HEAP32[$51+0>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;HEAP32[$51+12>>2]=0|0;HEAP32[$51+16>>2]=0|0;
   $52 = (($47) + 64|0);
   HEAPF32[$52>>2] = Math_fround(inf);
   $53 = (($47) + 60|0);
   HEAP32[$53>>2] = 0;
   $54 = (($47) + 68|0);
   $55 = (($47) + 96|0);
   HEAP32[$55>>2] = 0;
   $56 = (($47) + 100|0);
   HEAP32[$56>>2] = 0;
   $57 = (($47) + 92|0);
   ;HEAP32[$54+0>>2]=0|0;HEAP32[$54+4>>2]=0|0;HEAP32[$54+8>>2]=0|0;HEAP32[$54+12>>2]=0|0;HEAP32[$54+16>>2]=0|0;HEAP32[$54+20>>2]=0|0;
   HEAP32[$57>>2] = 61;
   $58 = (($47) + 108|0);
   HEAP32[$58>>2] = 2;
   $59 = (($47) + 104|0);
   HEAP32[$59>>2] = 2;
   $60 = (($47) + 112|0);
   HEAP32[$60>>2] = 0;
   $62 = $47;
  }
  $61 = (($62) + 116|0);
  $63 = (($$0$i6) + -1)|0;
  $64 = ($63|0)==(0);
  if ($64) {
   break;
  } else {
   $$0$i6 = $63;$47 = $61;
  }
 }
 $65 = (($45) + (($$0$i118*116)|0)|0);
 $66 = HEAP32[$this>>2]|0;
 $67 = HEAP32[$3>>2]|0;
 $68 = ($67|0)==($66|0);
 do {
  if ($68) {
   $103 = $66;$75 = $44;$78 = $66;
  } else {
   $$01$i$i = $67;$70 = $44;
   while(1) {
    $69 = (($70) + -116|0);
    $71 = (($$01$i$i) + -116|0);
    __THREW__ = 0;
    invoke_vii(3381,($69|0),($71|0));
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     break;
    }
    $74 = ($71|0)==($66|0);
    if ($74) {
     label = 17;
     break;
    } else {
     $$01$i$i = $71;$70 = $69;
    }
   }
   if ((label|0) == 17) {
    $$pre$i10 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$3>>2]|0;
    $103 = $$pre;$75 = $69;$78 = $$pre$i10;
    break;
   }
   $89 = ___cxa_find_matching_catch()|0;
   $90 = tempRet0;
   $92 = $61;
   while(1) {
    $91 = ($92|0)==($70|0);
    if ($91) {
     break;
    }
    $93 = (($92) + -116|0);
    __THREW__ = 0;
    invoke_vi(3693,($93|0));
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 28;
     break;
    } else {
     $92 = $93;
    }
   }
   if ((label|0) == 28) {
    $96 = ___cxa_find_matching_catch()|0;
    $97 = tempRet0;
    ___cxa_call_unexpected(($96|0));
    // unreachable;
   }
   $98 = ($45|0)==(0|0);
   if ($98) {
    ___resumeException($89|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($45|0),($$byval_copy2|0));
   $99 = __THREW__; __THREW__ = 0;
   $100 = $99&1;
   if ($100) {
    $101 = ___cxa_find_matching_catch()|0;
    $102 = tempRet0;
    ___cxa_call_unexpected(($101|0));
    // unreachable;
   } else {
    ___resumeException($89|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $75;
 HEAP32[$3>>2] = $61;
 HEAP32[$1>>2] = $65;
 $77 = $103;
 while(1) {
  $76 = ($77|0)==($78|0);
  if ($76) {
   break;
  }
  $79 = (($77) + -116|0);
  __THREW__ = 0;
  invoke_vi(3693,($79|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   label = 21;
   break;
  } else {
   $77 = $79;
  }
 }
 if ((label|0) == 21) {
  $82 = ___cxa_find_matching_catch()|0;
  $83 = tempRet0;
  ___cxa_call_unexpected(($82|0));
  // unreachable;
 }
 $84 = ($78|0)==(0|0);
 if ($84) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($78|0),($$byval_copy2|0));
 $85 = __THREW__; __THREW__ = 0;
 $86 = $85&1;
 if ($86) {
  $87 = ___cxa_find_matching_catch()|0;
  $88 = tempRet0;
  ___cxa_call_unexpected(($87|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip10FloatCurveaSERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$idx$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $1 = sp;
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($this,$0)|0);
 $2 = (($this) + 12|0);
 $3 = (($0) + 12|0);
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($2,$3)|0);
 $4 = (($0) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 24|0);
 HEAP32[$6>>2] = $5;
 $7 = (($0) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 28|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 32|0);
 $11 = (($0) + 32|0);
 ;HEAP32[$10+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$10+16>>2]=HEAP32[$11+16>>2]|0;HEAP32[$10+20>>2]=HEAP32[$11+20>>2]|0;HEAP32[$10+24>>2]=HEAP32[$11+24>>2]|0;
 $12 = (($this) + 60|0);
 $13 = (($0) + 60|0);
 ;HEAP32[$12+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$13+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$13+16>>2]|0;HEAP32[$12+20>>2]=HEAP32[$13+20>>2]|0;HEAP32[$12+24>>2]=HEAP32[$13+24>>2]|0;
 $14 = (($this) + 88|0);
 $15 = ($0|0)==($this|0);
 if ($15) {
  $40 = (($this) + 104|0);
  $41 = (($0) + 104|0);
  $42 = $41;
  $43 = $42;
  $44 = HEAP32[$43>>2]|0;
  $45 = (($42) + 4)|0;
  $46 = $45;
  $47 = HEAP32[$46>>2]|0;
  $48 = $40;
  $49 = $48;
  HEAP32[$49>>2] = $44;
  $50 = (($48) + 4)|0;
  $51 = $50;
  HEAP32[$51>>2] = $47;
  $52 = (($0) + 112|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($this) + 112|0);
  HEAP32[$54>>2] = $53;
  STACKTOP = sp;return ($this|0);
 }
 $16 = (($0) + 88|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($0) + 96|0);
 $19 = HEAP32[$18>>2]|0;
 $$idx$i = $19 << 4;
 $20 = $$idx$i >> 4;
 $21 = (($this) + 96|0);
 HEAP32[$21>>2] = $20;
 $22 = (($this) + 100|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($24>>>0)<($20>>>0);
 do {
  if ($25) {
   $26 = ($23|0)>(-1);
   if ($26) {
    HEAP32[$22>>2] = $20;
    $27 = HEAP32[$14>>2]|0;
    $28 = (($this) + 92|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$1>>2] = $29;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $30 = (__Z16realloc_internalPvji10MemLabelIdiPKci($27,$$idx$i,4,$$byval_copy1,0,766088,370)|0);
    HEAP32[$14>>2] = $30;
    $39 = $30;
    break;
   } else {
    $31 = (($this) + 92|0);
    $32 = HEAP32[$31>>2]|0;
    HEAP32[$1>>2] = $32;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx$i,4,$$byval_copy1,0,766088,352)|0);
    $34 = HEAP32[$14>>2]|0;
    $35 = HEAP32[$21>>2]|0;
    $36 = $35 << 4;
    _memcpy(($33|0),($34|0),($36|0))|0;
    HEAP32[$22>>2] = $20;
    HEAP32[$14>>2] = $33;
    $39 = $33;
    break;
   }
  } else {
   $$pre$i$i = HEAP32[$14>>2]|0;
   $39 = $$pre$i$i;
  }
 } while(0);
 $37 = HEAP32[$21>>2]|0;
 $38 = $37 << 4;
 _memcpy(($39|0),($17|0),($38|0))|0;
 $40 = (($this) + 104|0);
 $41 = (($0) + 104|0);
 $42 = $41;
 $43 = $42;
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + 4)|0;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = $40;
 $49 = $48;
 HEAP32[$49>>2] = $44;
 $50 = (($48) + 4)|0;
 $51 = $50;
 HEAP32[$51>>2] = $47;
 $52 = (($0) + 112|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($this) + 112|0);
 HEAP32[$54>>2] = $53;
 STACKTOP = sp;return ($this|0);
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0;
 var $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i3;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $30 = $27;
  }
  while(1) {
   $29 = (($30) + 12|0);
   __ZN17AnimationCurveTplI8Vector3fE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$30,0);
   __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
   $31 = (($30) + 160|0);
   $32 = ($31|0)==($26|0);
   if ($32) {
    break;
   } else {
    $30 = $31;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*160)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplI8Vector3fE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 136|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre$i$i$i1 = HEAP32[$1>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre3 = HEAP32[$5>>2]|0;
  $13 = $$pre;$15 = $$pre3;$9 = $$pre$i$i$i1;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $13 = $4;$15 = $6;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$1>>2] = $10;
 $11 = (($this) + 140|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$11,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $17 = $$pre$i$i$i;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$11>>2] = $18;
  __ZN17AnimationCurveTplI8Vector3fE15InvalidateCacheEv($this);
  STACKTOP = sp;return;
 } else {
  $16 = HEAP32[$13>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$2>>2] = $12;
  $17 = $16;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$11>>2] = $18;
  __ZN17AnimationCurveTplI8Vector3fE15InvalidateCacheEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*40)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   $44 = HEAP32[$3>>2]|0;
   $45 = (($44) + 4|0);
   $46 = HEAP32[$9>>2]|0;
   $47 = ($45>>>0)>($46>>>0);
   if ($47) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$04,4);
    $$pre$i$i$i$i$i$i = HEAP32[$i$04>>2]|0;
    $$pre$phi$i$i$i$i$i$iZ2D = $i$04;$50 = $$pre$i$i$i$i$i$i;
   } else {
    $48 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$i$04>>2] = $48;
    HEAP32[$3>>2] = $45;
    $49 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
    $$pre$phi$i$i$i$i$i$iZ2D = $i$04;$50 = $49;
   }
   $51 = (_llvm_bswap_i32(($50|0))|0);
   HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $51;
   $52 = (($i$04) + 4|0);
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$52,0,0);
   $53 = (($i$04) + 16|0);
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$53,0,0);
   $54 = (($i$04) + 28|0);
   __ZN18StreamedBinaryReadILb1EE8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$54,0,0);
   $55 = (($i$04) + 40|0);
   $56 = ($55|0)==($42|0);
   if ($56) {
    break;
   } else {
    $i$04 = $55;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre5 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre6 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i1;$23 = $$pre6;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = ($23*40)|0;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = (($22|0) / 40)&-1;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($1) + 4|0);
 dest=$6+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $7 = (($data) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9>>>0)<($rs>>>0);
 do {
  if ($10) {
   $11 = ($8|0)>(-1);
   if ($11) {
    HEAP32[$7>>2] = $rs;
    $12 = ($rs*40)|0;
    $13 = (($data) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$0>>2] = $14;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $15 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$12,4,$$byval_copy1,0,766088,370)|0);
    HEAP32[$data>>2] = $15;
    $28 = $15;
    break;
   } else {
    $16 = ($rs*40)|0;
    $17 = (($data) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP32[$0>>2] = $18;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $19 = (__Z15malloc_internaljj10MemLabelIdiPKci($16,4,$$byval_copy1,0,766088,352)|0);
    $20 = HEAP32[$data>>2]|0;
    $21 = (($data) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22*40)|0;
    _memcpy(($19|0),($20|0),($23|0))|0;
    HEAP32[$7>>2] = $rs;
    HEAP32[$data>>2] = $19;
    $28 = $19;
    break;
   }
  } else {
   $28 = $2;
  }
 } while(0);
 $24 = (($data) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25>>>0)<($rs>>>0);
 if (!($26)) {
  HEAP32[$24>>2] = $rs;
  STACKTOP = sp;return;
 }
 $27 = (($28) + (($rs*40)|0)|0);
 $29 = ($25|0)==($rs|0);
 if ($29) {
  HEAP32[$24>>2] = $rs;
  STACKTOP = sp;return;
 }
 $30 = (($28) + (($25*40)|0)|0);
 $$01$i$i = $30;
 while(1) {
  $31 = ($$01$i$i|0)==(0|0);
  if (!($31)) {
   dest=$$01$i$i+0|0; src=$1+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $32 = (($$01$i$i) + 40|0);
  $33 = ($32|0)==($27|0);
  if ($33) {
   break;
  } else {
   $$01$i$i = $32;
  }
 }
 HEAP32[$24>>2] = $rs;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre1$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$i$i$index = 0, $lpad$phi$i$i$index2 = 0, $temp = 0;
 var $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $temp1 = sp + 24|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 160)&-1;
 $9 = ($8>>>0)<($sz>>>0);
 if ($9) {
  $10 = (($v) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($6))|0;
  $14 = (($13|0) / 160)&-1;
  $15 = ($14|0)==($sz|0);
  if ($15) {
   __ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6resizeEj($v,$sz);
   STACKTOP = sp;return;
  }
  HEAP32[$temp>>2] = 0;
  $16 = (($temp) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($temp) + 8|0);
  HEAP32[$17>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3382,($temp|0),($sz|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = HEAP32[$v>>2]|0;
   HEAP32[$0>>2] = $20;
   $21 = HEAP32[$2>>2]|0;
   HEAP32[$1>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(2004,($temp|0),($$byval_copy|0),($$byval_copy7|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    invoke_vii(3383,($temp|0),($sz|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = HEAP32[$temp>>2]|0;
     $27 = HEAP32[$v>>2]|0;
     HEAP32[$temp>>2] = $27;
     HEAP32[$v>>2] = $26;
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$2>>2]|0;
     HEAP32[$16>>2] = $29;
     HEAP32[$2>>2] = $28;
     $30 = HEAP32[$17>>2]|0;
     $31 = HEAP32[$10>>2]|0;
     HEAP32[$17>>2] = $31;
     HEAP32[$10>>2] = $30;
     __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($temp);
     STACKTOP = sp;return;
    }
   }
  }
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($temp);
  $$0 = $33;$$01 = $32;
  ___resumeException($$01|0);
  // unreachable;
 }
 $34 = ($8>>>0)>($sz>>>0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 $35 = (($4) + (($sz*160)|0)|0);
 HEAP32[$temp1>>2] = 0;
 $36 = (($temp1) + 4|0);
 HEAP32[$36>>2] = 0;
 $37 = (($temp1) + 8|0);
 HEAP32[$37>>2] = 0;
 $$idx = ($sz*160)|0;
 $38 = (($$idx|0) / 160)&-1;
 $39 = ($sz|0)==(0);
 L18: do {
  if ($39) {
   $60 = $4;$61 = 0;$62 = $3;$63 = 0;$66 = 0;
  } else {
   $40 = ($$idx|0)<(0);
   do {
    if ($40) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 21;
     } else {
      // unreachable;
     }
    } else {
     HEAP32[$$byval_copy>>2] = 18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
     $43 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(766088|0),79)|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 21;
     } else {
      HEAP32[$36>>2] = $43;
      HEAP32[$temp1>>2] = $43;
      $46 = (($43) + (($38*160)|0)|0);
      HEAP32[$37>>2] = $46;
      $48 = $43;$49 = $4;
      while(1) {
       $47 = ($48|0)==(0|0);
       if ($47) {
        $53 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(3384,($48|0),($49|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 20;
         break;
        }
        $$pre1$i$i$i = HEAP32[$36>>2]|0;
        $53 = $$pre1$i$i$i;
       }
       $52 = (($53) + 160|0);
       HEAP32[$36>>2] = $52;
       $54 = (($49) + 160|0);
       $55 = ($54|0)==($35|0);
       if ($55) {
        label = 22;
        break;
       } else {
        $48 = $52;$49 = $54;
       }
      }
      if ((label|0) == 20) {
       $56 = ___cxa_find_matching_catch()|0;
       $57 = tempRet0;
       $lpad$phi$i$i$index = $56;$lpad$phi$i$i$index2 = $57;
       break;
      }
      else if ((label|0) == 22) {
       $$pre = HEAP32[$temp1>>2]|0;
       $$pre9 = HEAP32[$v>>2]|0;
       $$pre10 = HEAP32[$2>>2]|0;
       $$pre11 = HEAP32[$37>>2]|0;
       $60 = $$pre9;$61 = $$pre;$62 = $$pre10;$63 = $52;$66 = $$pre11;
       break L18;
      }
     }
    }
   } while(0);
   if ((label|0) == 21) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    $lpad$phi$i$i$index = $58;$lpad$phi$i$i$index2 = $59;
   }
   __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($temp1);
   $$0 = $lpad$phi$i$i$index2;$$01 = $lpad$phi$i$i$index;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$temp1>>2] = $60;
 HEAP32[$v>>2] = $61;
 HEAP32[$36>>2] = $62;
 HEAP32[$2>>2] = $63;
 $64 = (($v) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 HEAP32[$37>>2] = $65;
 HEAP32[$64>>2] = $66;
 __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($temp1);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 160)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 160)&-1;
 $15 = (($__v) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($__v) + 16|0);
 HEAP32[$16>>2] = $9;
 $17 = ($__n|0)==(0);
 if ($17) {
  $20 = 0;$26 = $11;$27 = $3;
 } else {
  $18 = ($__n*160)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $19 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,16,$$byval_copy,0,766088,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre1 = HEAP32[$10>>2]|0;
  $20 = $19;$26 = $$pre1;$27 = $$pre;
 }
 HEAP32[$__v>>2] = $20;
 $21 = (($20) + (($14*160)|0)|0);
 $22 = (($__v) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($__v) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = (($20) + (($__n*160)|0)|0);
 HEAP32[$15>>2] = $24;
 $25 = ($26|0)==($27|0);
 do {
  if ($25) {
   $36 = $21;$37 = $26;$38 = $21;$39 = $26;$41 = $24;
  } else {
   $$01$i$i = $26;$29 = $21;
   while(1) {
    $28 = (($29) + -160|0);
    $30 = (($$01$i$i) + -160|0);
    __THREW__ = 0;
    invoke_vii(3384,($28|0),($30|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     label = 10;
     break;
    }
    $33 = HEAP32[$23>>2]|0;
    $34 = (($33) + -160|0);
    HEAP32[$23>>2] = $34;
    $35 = ($30|0)==($27|0);
    if ($35) {
     label = 7;
     break;
    } else {
     $$01$i$i = $30;$29 = $34;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre2 = HEAP32[$10>>2]|0;
    $$pre3 = HEAP32[$22>>2]|0;
    $$pre4 = HEAP32[$15>>2]|0;
    $36 = $34;$37 = $$pre$i;$38 = $$pre3;$39 = $$pre2;$41 = $$pre4;
    break;
   }
   else if ((label|0) == 10) {
    $42 = ___cxa_find_matching_catch()|0;
    $43 = tempRet0;
    __ZNSt3__114__split_bufferIN13AnimationClip12Vector3CurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
    ___resumeException($42|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $36;
 HEAP32[$23>>2] = $37;
 HEAP32[$10>>2] = $38;
 HEAP32[$22>>2] = $39;
 $40 = HEAP32[$1>>2]|0;
 HEAP32[$1>>2] = $41;
 HEAP32[$15>>2] = $40;
 HEAP32[$__v>>2] = $37;
 __ZNSt3__114__split_bufferIN13AnimationClip12Vector3CurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i32 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy3 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = HEAP32[$__last>>2]|0;
 $5 = $4;
 $6 = $3;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 160)&-1;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 160)&-1;
 $16 = ($8>>>0)>($15>>>0);
 if ($16) {
  __ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE10deallocateEv($this);
  $76 = ($7|0)<(0);
  if ($76) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $77 = HEAP32[$9>>2]|0;
  $78 = HEAP32[$this>>2]|0;
  $79 = $77;
  $80 = $78;
  $81 = (($79) - ($80))|0;
  $82 = (($81|0) / 160)&-1;
  $83 = ($82>>>0)<(1073741823);
  if ($83) {
   $84 = $82 << 1;
   $85 = ($84>>>0)<($8>>>0);
   $86 = $85 ? $8 : $84;
   $87 = ($86|0)<(0);
   if ($87) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i32 = $86;
   }
  } else {
   $$0$i32 = 2147483647;
  }
  $88 = ($$0$i32*160)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $89 = (__Z15malloc_internaljj10MemLabelIdiPKci($88,16,$$byval_copy3,0,766088,79)|0);
  $90 = (($this) + 4|0);
  HEAP32[$90>>2] = $89;
  HEAP32[$this>>2] = $89;
  $91 = (($89) + (($$0$i32*160)|0)|0);
  HEAP32[$9>>2] = $91;
  $92 = ($3|0)==($4|0);
  if ($92) {
   STACKTOP = sp;return;
  } else {
   $94 = $89;$95 = $3;
  }
  while(1) {
   $93 = ($94|0)==(0|0);
   if ($93) {
    $97 = 0;
   } else {
    __ZN13AnimationClip12Vector3CurveC2ERKS0_($94,$95);
    $$pre1$i = HEAP32[$90>>2]|0;
    $97 = $$pre1$i;
   }
   $96 = (($97) + 160|0);
   HEAP32[$90>>2] = $96;
   $98 = (($95) + 160|0);
   $99 = ($98|0)==($4|0);
   if ($99) {
    break;
   } else {
    $94 = $96;$95 = $98;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18;
 $20 = (($19) - ($13))|0;
 $21 = (($20|0) / 160)&-1;
 $22 = ($8>>>0)>($21>>>0);
 if ($22) {
  $23 = (($3) + (($21*160)|0)|0);
  $25 = $23;$__growing$0$off0 = 1;
 } else {
  $25 = $4;$__growing$0$off0 = 0;
 }
 $24 = ($3|0)==($25|0);
 if ($24) {
  $$0$lcssa$i$i = $11;
 } else {
  $scevgep$i = (($25) + -160|0);
  $26 = (0 - ($6))|0;
  $uglygep$i = (($scevgep$i) + ($26)|0);
  $uglygep16$i = $uglygep$i;
  $27 = (($uglygep16$i>>>0) / 160)&-1;
  $$01$i$i = $11;$28 = $3;
  while(1) {
   (__ZN13AnimationClip12Vector3CurveaSERKS0_($$01$i$i,$28)|0);
   $29 = (($28) + 160|0);
   $30 = (($$01$i$i) + 160|0);
   $31 = ($29|0)==($25|0);
   if ($31) {
    break;
   } else {
    $$01$i$i = $30;$28 = $29;
   }
  }
  $32 = (($27) + 1)|0;
  $scevgep17$i = (($11) + (($32*160)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  $33 = ($25|0)==($4|0);
  if ($33) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$17>>2]|0;
  $35 = $$pre$i12;$36 = $25;
  while(1) {
   $34 = ($35|0)==(0|0);
   if ($34) {
    $38 = 0;
   } else {
    __ZN13AnimationClip12Vector3CurveC2ERKS0_($35,$36);
    $$pre1$i14 = HEAP32[$17>>2]|0;
    $38 = $$pre1$i14;
   }
   $37 = (($38) + 160|0);
   HEAP32[$17>>2] = $37;
   $39 = (($36) + 160|0);
   $40 = ($39|0)==($4|0);
   if ($40) {
    break;
   } else {
    $35 = $37;$36 = $39;
   }
  }
  STACKTOP = sp;return;
 }
 $41 = HEAP32[$17>>2]|0;
 $42 = ($41|0)==($$0$lcssa$i$i|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $44 = $41;
 while(1) {
  $43 = (($44) + -160|0);
  HEAP32[$17>>2] = $43;
  $45 = (($44) + -16|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)>(-1);
  if ($47) {
   $48 = (($44) + -28|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($44) + -24|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$2>>2] = $51;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($49|0),($$byval_copy3|0));
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    label = 23;
    break;
   }
   HEAP32[$48>>2] = 0;
  }
  $54 = HEAP8[$43>>0]|0;
  $55 = $54 & 1;
  $56 = ($55<<24>>24)==(0);
  if (!($56)) {
   $59 = (($44) + -152|0);
   $60 = HEAP32[$59>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy3|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    label = 22;
    break;
   }
  }
  $57 = HEAP32[$17>>2]|0;
  $58 = ($57|0)==($$0$lcssa$i$i|0);
  if ($58) {
   label = 36;
   break;
  } else {
   $44 = $57;
  }
 }
 if ((label|0) == 22) {
  $63 = ___cxa_find_matching_catch()|0;
  $64 = tempRet0;
  ___cxa_call_unexpected(($63|0));
  // unreachable;
 }
 else if ((label|0) == 23) {
  $65 = ___cxa_find_matching_catch()|0;
  $66 = tempRet0;
  $67 = HEAP8[$43>>0]|0;
  $68 = $67 & 1;
  $69 = ($68<<24>>24)==(0);
  if ($69) {
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
  $70 = (($44) + -152|0);
  $71 = HEAP32[$70>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($71|0),($$byval_copy3|0));
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   $74 = ___cxa_find_matching_catch()|0;
   $75 = tempRet0;
   ___cxa_call_unexpected(($74|0));
   // unreachable;
  } else {
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 }
 else if ((label|0) == 36) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6resizeEj($this,$__sz) {
 $this = $this|0;
 $__sz = $__sz|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 160)&-1;
 $10 = ($9>>>0)<($__sz>>>0);
 if ($10) {
  $11 = (($__sz) - ($9))|0;
  __ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$11);
  STACKTOP = sp;return;
 }
 $12 = ($9>>>0)>($__sz>>>0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($5) + (($__sz*160)|0)|0);
 $14 = ($4|0)==($13|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $16 = $4;
 while(1) {
  $15 = (($16) + -160|0);
  HEAP32[$3>>2] = $15;
  $17 = (($16) + -16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)>(-1);
  if ($19) {
   $20 = (($16) + -28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($16) + -24|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$2>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($21|0),($$byval_copy2|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 13;
    break;
   }
   HEAP32[$20>>2] = 0;
  }
  $26 = HEAP8[$15>>0]|0;
  $27 = $26 & 1;
  $28 = ($27<<24>>24)==(0);
  if (!($28)) {
   $31 = (($16) + -152|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($32|0),($$byval_copy2|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 12;
    break;
   }
  }
  $29 = HEAP32[$3>>2]|0;
  $30 = ($29|0)==($13|0);
  if ($30) {
   label = 17;
   break;
  } else {
   $16 = $29;
  }
 }
 if ((label|0) == 12) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  ___cxa_call_unexpected(($35|0));
  // unreachable;
 }
 else if ((label|0) == 13) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  $39 = HEAP8[$15>>0]|0;
  $40 = $39 & 1;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   ___cxa_call_unexpected(($37|0));
   // unreachable;
  }
  $42 = (($16) + -152|0);
  $43 = HEAP32[$42>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($43|0),($$byval_copy2|0));
  $44 = __THREW__; __THREW__ = 0;
  $45 = $44&1;
  if ($45) {
   $46 = ___cxa_find_matching_catch()|0;
   $47 = tempRet0;
   ___cxa_call_unexpected(($46|0));
   // unreachable;
  } else {
   ___cxa_call_unexpected(($37|0));
   // unreachable;
  }
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 do {
  if ($7) {
   $41 = $3;
  } else {
   $9 = $6;
   while(1) {
    $8 = (($9) + -160|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)>(-1);
    if ($12) {
     $13 = (($9) + -28|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($9) + -24|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$2>>2] = $16;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($14|0),($$byval_copy3|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 11;
      break;
     }
     HEAP32[$13>>2] = 0;
    }
    $19 = HEAP8[$8>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $24 = (($9) + -152|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy3|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 10;
      break;
     }
    }
    $22 = HEAP32[$5>>2]|0;
    $23 = ($22|0)==($3|0);
    if ($23) {
     label = 15;
     break;
    } else {
     $9 = $22;
    }
   }
   if ((label|0) == 10) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   else if ((label|0) == 11) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    $32 = HEAP8[$8>>0]|0;
    $33 = $32 & 1;
    $34 = ($33<<24>>24)==(0);
    if ($34) {
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
    $35 = (($9) + -152|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($36|0),($$byval_copy3|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $39 = ___cxa_find_matching_catch()|0;
     $40 = tempRet0;
     ___cxa_call_unexpected(($39|0));
     // unreachable;
    } else {
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
   else if ((label|0) == 15) {
    $$pre = HEAP32[$this>>2]|0;
    $41 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy3|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN13AnimationClip12Vector3CurveC2ERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy2 = 0, $$idx$i$i$i$i = 0, $$pre$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = HEAP8[$0>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $10 = (($0) + 1|0);
  $11 = $3&255;
  $12 = $11 >>> 1;
  $14 = $12;$25 = $10;
 } else {
  $6 = (($0) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($0) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $14 = $9;$25 = $7;
 }
 $13 = ($14>>>0)>(2147483631);
 if ($13) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $15 = ($14>>>0)<(11);
 if ($15) {
  $16 = $14 << 1;
  $17 = $16&255;
  HEAP8[$this>>0] = $17;
  $18 = (($this) + 1|0);
  $__p$0$i$i$i$i = $18;
 } else {
  $19 = (($14) + 16)|0;
  $20 = $19 & -16;
  HEAP32[$1>>2] = 59;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy2,0,766088,79)|0);
  $22 = (($this) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = $20 | 1;
  HEAP32[$this>>2] = $23;
  $24 = (($this) + 4|0);
  HEAP32[$24>>2] = $14;
  $__p$0$i$i$i$i = $21;
 }
 _memcpy(($__p$0$i$i$i$i|0),($25|0),($14|0))|0;
 $26 = (($__p$0$i$i$i$i) + ($14)|0);
 HEAP8[$26>>0] = 0;
 $27 = (($this) + 12|0);
 $28 = (($0) + 12|0);
 dest=$27+0|0; src=$28+0|0; stop=dest+120|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $29 = (($0) + 136|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 136|0);
 HEAP32[$31>>2] = $30;
 $32 = (($this) + 140|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 144|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 132|0);
 HEAP32[$34>>2] = 0;
 $35 = (($0) + 132|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($0) + 140|0);
 $38 = HEAP32[$37>>2]|0;
 $$idx$i$i$i$i = ($38*40)|0;
 $39 = (($$idx$i$i$i$i|0) / 40)&-1;
 HEAP32[$32>>2] = $39;
 $40 = ($$idx$i$i$i$i|0)==(0);
 if ($40) {
  $45 = $39;$46 = 0;
  $44 = ($45*40)|0;
  _memcpy(($46|0),($36|0),($44|0))|0;
  $47 = (($this) + 148|0);
  $48 = (($0) + 148|0);
  $49 = $48;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $47;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = (($this) + 156|0);
  $60 = (($0) + 156|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$59>>2] = $61;
  STACKTOP = sp;return;
 }
 HEAP32[$33>>2] = $39;
 HEAP32[$2>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 $41 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i|0),4,($$byval_copy2|0),0,(766088|0),370)|0);
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if (!($43)) {
  HEAP32[$34>>2] = $41;
  $$pre$i$i$i = HEAP32[$32>>2]|0;
  $45 = $$pre$i$i$i;$46 = $41;
  $44 = ($45*40)|0;
  _memcpy(($46|0),($36|0),($44|0))|0;
  $47 = (($this) + 148|0);
  $48 = (($0) + 148|0);
  $49 = $48;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $47;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = (($this) + 156|0);
  $60 = (($0) + 156|0);
  $61 = HEAP32[$60>>2]|0;
  HEAP32[$59>>2] = $61;
  STACKTOP = sp;return;
 }
 $62 = ___cxa_find_matching_catch()|0;
 $63 = tempRet0;
 $64 = HEAP8[$this>>0]|0;
 $65 = $64 & 1;
 $66 = ($65<<24>>24)==(0);
 if ($66) {
  ___resumeException($62|0);
  // unreachable;
 }
 $67 = (($this) + 8|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($68|0),($$byval_copy2|0));
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  ___cxa_call_unexpected(($71|0));
  // unreachable;
 } else {
  ___resumeException($62|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i813 = 0, $$0$i814 = 0, $$01$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i2 = 0, $$pre1$i = 0, $$pre1$i1 = 0, $$pre1$i69 = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $__v = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 160)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $25 = 0;
   } else {
    ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
    $12 = (($11) + 16|0);
    HEAPF32[$12>>2] = Math_fround(inf);
    $13 = (($11) + 12|0);
    HEAP32[$13>>2] = 0;
    $14 = (($11) + 20|0);
    dest=$14+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $15 = (($11) + 76|0);
    HEAPF32[$15>>2] = Math_fround(inf);
    $16 = (($11) + 72|0);
    HEAP32[$16>>2] = 0;
    $17 = (($11) + 80|0);
    $18 = (($11) + 140|0);
    HEAP32[$18>>2] = 0;
    $19 = (($11) + 144|0);
    HEAP32[$19>>2] = 0;
    $20 = (($11) + 136|0);
    dest=$17+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$20>>2] = 61;
    $21 = (($11) + 152|0);
    HEAP32[$21>>2] = 2;
    $22 = (($11) + 148|0);
    HEAP32[$22>>2] = 2;
    $23 = (($11) + 156|0);
    HEAP32[$23>>2] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $25 = $$pre1$i;
   }
   $24 = (($25) + 160|0);
   HEAP32[$3>>2] = $24;
   $26 = (($$0$i) + -1)|0;
   $27 = ($26|0)==(0);
   if ($27) {
    break;
   } else {
    $$0$i = $26;$11 = $24;
   }
  }
  STACKTOP = sp;return;
 }
 $28 = (($this) + 8|0);
 $29 = HEAP32[$this>>2]|0;
 $30 = $29;
 $31 = (($6) - ($30))|0;
 $32 = (($31|0) / 160)&-1;
 $33 = (($32) + ($__n))|0;
 $34 = ($33|0)<(0);
 if ($34) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $35 = (($5) - ($30))|0;
 $36 = (($35|0) / 160)&-1;
 $37 = ($36>>>0)<(1073741823);
 if ($37) {
  $40 = $36 << 1;
  $41 = ($40>>>0)<($33>>>0);
  $42 = $41 ? $33 : $40;
  $43 = (($__v) + 12|0);
  HEAP32[$43>>2] = 0;
  $44 = (($__v) + 16|0);
  HEAP32[$44>>2] = $28;
  $45 = ($42|0)==(0);
  if ($45) {
   $$0$i814 = 0;$48 = 0;$53 = $43;
  } else {
   $$0$i813 = $42;$90 = $43;
   label = 10;
  }
 } else {
  $38 = (($__v) + 12|0);
  HEAP32[$38>>2] = 0;
  $39 = (($__v) + 16|0);
  HEAP32[$39>>2] = $28;
  $$0$i813 = 2147483647;$90 = $38;
  label = 10;
 }
 if ((label|0) == 10) {
  $46 = ($$0$i813*160)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $47 = (__Z15malloc_internaljj10MemLabelIdiPKci($46,16,$$byval_copy,0,766088,79)|0);
  $$0$i814 = $$0$i813;$48 = $47;$53 = $90;
 }
 HEAP32[$__v>>2] = $48;
 $49 = (($48) + (($32*160)|0)|0);
 $50 = (($__v) + 8|0);
 HEAP32[$50>>2] = $49;
 $51 = (($__v) + 4|0);
 HEAP32[$51>>2] = $49;
 $52 = (($48) + (($$0$i814*160)|0)|0);
 HEAP32[$53>>2] = $52;
 $$0$i4 = $__n;$$pre1$i69 = $49;
 while(1) {
  $54 = ($$pre1$i69|0)==(0|0);
  if ($54) {
   $68 = 0;
  } else {
   ;HEAP32[$$pre1$i69+0>>2]=0|0;HEAP32[$$pre1$i69+4>>2]=0|0;HEAP32[$$pre1$i69+8>>2]=0|0;
   $55 = (($$pre1$i69) + 16|0);
   HEAPF32[$55>>2] = Math_fround(inf);
   $56 = (($$pre1$i69) + 12|0);
   HEAP32[$56>>2] = 0;
   $57 = (($$pre1$i69) + 20|0);
   dest=$57+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $58 = (($$pre1$i69) + 76|0);
   HEAPF32[$58>>2] = Math_fround(inf);
   $59 = (($$pre1$i69) + 72|0);
   HEAP32[$59>>2] = 0;
   $60 = (($$pre1$i69) + 80|0);
   $61 = (($$pre1$i69) + 140|0);
   HEAP32[$61>>2] = 0;
   $62 = (($$pre1$i69) + 144|0);
   HEAP32[$62>>2] = 0;
   $63 = (($$pre1$i69) + 136|0);
   dest=$60+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$63>>2] = 61;
   $64 = (($$pre1$i69) + 152|0);
   HEAP32[$64>>2] = 2;
   $65 = (($$pre1$i69) + 148|0);
   HEAP32[$65>>2] = 2;
   $66 = (($$pre1$i69) + 156|0);
   HEAP32[$66>>2] = 0;
   $68 = $$pre1$i69;
  }
  $67 = (($68) + 160|0);
  $69 = (($$0$i4) + -1)|0;
  $70 = ($69|0)==(0);
  if ($70) {
   break;
  } else {
   $$0$i4 = $69;$$pre1$i69 = $67;
  }
 }
 HEAP32[$50>>2] = $67;
 $71 = HEAP32[$this>>2]|0;
 $72 = HEAP32[$3>>2]|0;
 $73 = ($72|0)==($71|0);
 $$pre1$i1 = HEAP32[$51>>2]|0;
 do {
  if ($73) {
   $82 = $$pre1$i1;$83 = $71;$84 = $67;$85 = $71;
  } else {
   $$01$i$i = $72;$75 = $$pre1$i1;
   while(1) {
    $74 = (($75) + -160|0);
    $76 = (($$01$i$i) + -160|0);
    __THREW__ = 0;
    invoke_vii(3384,($74|0),($76|0));
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     label = 21;
     break;
    }
    $79 = HEAP32[$51>>2]|0;
    $80 = (($79) + -160|0);
    HEAP32[$51>>2] = $80;
    $81 = ($76|0)==($71|0);
    if ($81) {
     label = 18;
     break;
    } else {
     $$01$i$i = $76;$75 = $80;
    }
   }
   if ((label|0) == 18) {
    $$pre$i2 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$3>>2]|0;
    $$pre12 = HEAP32[$50>>2]|0;
    $82 = $80;$83 = $$pre$i2;$84 = $$pre12;$85 = $$pre;
    break;
   }
   else if ((label|0) == 21) {
    $88 = ___cxa_find_matching_catch()|0;
    $89 = tempRet0;
    __ZNSt3__114__split_bufferIN13AnimationClip12Vector3CurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
    ___resumeException($88|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $82;
 HEAP32[$51>>2] = $83;
 HEAP32[$3>>2] = $84;
 HEAP32[$50>>2] = $85;
 $86 = HEAP32[$1>>2]|0;
 $87 = HEAP32[$53>>2]|0;
 HEAP32[$1>>2] = $87;
 HEAP32[$53>>2] = $86;
 HEAP32[$__v>>2] = $83;
 __ZNSt3__114__split_bufferIN13AnimationClip12Vector3CurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIN13AnimationClip12Vector3CurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($4|0);
 L1: do {
  if (!($7)) {
   $9 = $6;
   while(1) {
    $8 = (($9) + -160|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)>(-1);
    if ($12) {
     $13 = (($9) + -28|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($9) + -24|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$2>>2] = $16;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($14|0),($$byval_copy3|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     HEAP32[$13>>2] = 0;
    }
    $19 = HEAP8[$8>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $24 = (($9) + -152|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy3|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 9;
      break;
     }
    }
    $22 = HEAP32[$5>>2]|0;
    $23 = ($22|0)==($4|0);
    if ($23) {
     break L1;
    } else {
     $9 = $22;
    }
   }
   if ((label|0) == 9) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   $32 = HEAP8[$8>>0]|0;
   $33 = $32 & 1;
   $34 = ($33<<24>>24)==(0);
   if ($34) {
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
   $35 = (($9) + -152|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($36|0),($$byval_copy3|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    ___cxa_call_unexpected(($39|0));
    // unreachable;
   } else {
    ___cxa_call_unexpected(($30|0));
    // unreachable;
   }
  }
 } while(0);
 $41 = HEAP32[$this>>2]|0;
 $42 = ($41|0)==(0|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy3|0));
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  ___cxa_call_unexpected(($45|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE10deallocateEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 do {
  if ($7) {
   $41 = $3;
  } else {
   $9 = $6;
   while(1) {
    $8 = (($9) + -160|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)>(-1);
    if ($12) {
     $13 = (($9) + -28|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($9) + -24|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$2>>2] = $16;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($14|0),($$byval_copy3|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 11;
      break;
     }
     HEAP32[$13>>2] = 0;
    }
    $19 = HEAP8[$8>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $24 = (($9) + -152|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy3|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 10;
      break;
     }
    }
    $22 = HEAP32[$5>>2]|0;
    $23 = ($22|0)==($3|0);
    if ($23) {
     label = 15;
     break;
    } else {
     $9 = $22;
    }
   }
   if ((label|0) == 10) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   else if ((label|0) == 11) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    $32 = HEAP8[$8>>0]|0;
    $33 = $32 & 1;
    $34 = ($33<<24>>24)==(0);
    if ($34) {
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
    $35 = (($9) + -152|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($36|0),($$byval_copy3|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $39 = ___cxa_find_matching_catch()|0;
     $40 = tempRet0;
     ___cxa_call_unexpected(($39|0));
     // unreachable;
    } else {
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
   else if ((label|0) == 15) {
    $$pre = HEAP32[$this>>2]|0;
    $41 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy3|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 }
 $46 = (($this) + 8|0);
 HEAP32[$46>>2] = 0;
 HEAP32[$5>>2] = 0;
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip12Vector3CurveaSERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$idx$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $1 = sp;
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($this,$0)|0);
 $2 = (($this) + 12|0);
 $3 = (($0) + 12|0);
 dest=$2+0|0; src=$3+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = (($this) + 72|0);
 $5 = (($0) + 72|0);
 dest=$4+0|0; src=$5+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = (($this) + 132|0);
 $7 = ($0|0)==($this|0);
 if ($7) {
  $32 = (($this) + 148|0);
  $33 = (($0) + 148|0);
  $34 = $33;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 4)|0;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = $32;
  $41 = $40;
  HEAP32[$41>>2] = $36;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = $39;
  $44 = (($0) + 156|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($this) + 156|0);
  HEAP32[$46>>2] = $45;
  STACKTOP = sp;return ($this|0);
 }
 $8 = (($0) + 132|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($0) + 140|0);
 $11 = HEAP32[$10>>2]|0;
 $$idx$i = ($11*40)|0;
 $12 = (($$idx$i|0) / 40)&-1;
 $13 = (($this) + 140|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 144|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($12>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $12;
    $19 = HEAP32[$6>>2]|0;
    $20 = (($this) + 136|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$1>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($19,$$idx$i,4,$$byval_copy1,0,766088,370)|0);
    HEAP32[$6>>2] = $22;
    $31 = $22;
    break;
   } else {
    $23 = (($this) + 136|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$1>>2] = $24;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx$i,4,$$byval_copy1,0,766088,352)|0);
    $26 = HEAP32[$6>>2]|0;
    $27 = HEAP32[$13>>2]|0;
    $28 = ($27*40)|0;
    _memcpy(($25|0),($26|0),($28|0))|0;
    HEAP32[$14>>2] = $12;
    HEAP32[$6>>2] = $25;
    $31 = $25;
    break;
   }
  } else {
   $$pre$i$i = HEAP32[$6>>2]|0;
   $31 = $$pre$i$i;
  }
 } while(0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29*40)|0;
 _memcpy(($31|0),($9|0),($30|0))|0;
 $32 = (($this) + 148|0);
 $33 = (($0) + 148|0);
 $34 = $33;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = $32;
 $41 = $40;
 HEAP32[$41>>2] = $36;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $39;
 $44 = (($0) + 156|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($this) + 156|0);
 HEAP32[$46>>2] = $45;
 STACKTOP = sp;return ($this|0);
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN24CompressedAnimationCurve8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 84|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*84)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN24CompressedAnimationCurve8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $1 = (($this) + 20|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre$i$i$i$i$i$i = HEAP32[$1>>2]|0;
  $9 = $$pre$i$i$i$i$i$i;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$1>>2] = $10;
 $11 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIhNS2_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$11,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $12 = (($this) + 36|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$transfer);
 $13 = (($this) + 64|0);
 $14 = HEAP32[$2>>2]|0;
 $15 = (($14) + 4|0);
 $16 = HEAP32[$5>>2]|0;
 $17 = ($15>>>0)>($16>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$13,4);
  $$pre$i$i$i = HEAP32[$13>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre3 = HEAP32[$5>>2]|0;
  $19 = $$pre$i$i$i;$23 = $$pre;$25 = $$pre3;
 } else {
  $18 = HEAP32[$14>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$2>>2] = $15;
  $19 = $18;$23 = $15;$25 = $16;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$13>>2] = $20;
 $21 = (($this) + 68|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$21,4);
  $$pre$i$i$i1 = HEAP32[$21>>2]|0;
  $27 = $$pre$i$i$i1;
  $28 = (_llvm_bswap_i32(($27|0))|0);
  HEAP32[$21>>2] = $28;
  STACKTOP = sp;return;
 } else {
  $26 = HEAP32[$23>>2]|0;
  HEAP32[$21>>2] = $26;
  HEAP32[$2>>2] = $22;
  $27 = $26;
  $28 = (_llvm_bswap_i32(($27|0))|0);
  HEAP32[$21>>2] = $28;
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy13 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy13 = sp + 32|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $temp = sp + 12|0;
 $2 = sp + 24|0;
 $3 = sp + 28|0;
 $4 = (($v) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$v>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 84)&-1;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $82 = ($10>>>0)>($sz>>>0);
  if (!($82)) {
   STACKTOP = sp;return;
  }
  $83 = (($6) + (($sz*84)|0)|0);
  $$idx = ($sz*84)|0;
  $84 = (($$idx|0) / 84)&-1;
  $85 = ($sz|0)==(0);
  do {
   if ($85) {
    $118 = 0;$119 = 0;$121 = 0;$123 = $6;$135 = $5;
   } else {
    $86 = ($$idx|0)<(0);
    if ($86) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 37;
     } else {
      // unreachable;
     }
    } else {
     HEAP32[$1>>2] = 18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
     $89 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy13|0),0,(766088|0),79)|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 37;
     } else {
      $92 = (($89) + (($84*84)|0)|0);
      $94 = $89;$95 = $6;
      while(1) {
       $93 = ($94|0)==(0|0);
       if ($93) {
        $99 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(3368,($94|0),($95|0));
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         break;
        } else {
         $99 = $94;
        }
       }
       $98 = (($99) + 84|0);
       $100 = (($95) + 84|0);
       $101 = ($100|0)==($83|0);
       if ($101) {
        label = 44;
        break;
       } else {
        $94 = $98;$95 = $100;
       }
      }
      if ((label|0) == 44) {
       $$pre = HEAP32[$v>>2]|0;
       $$pre31 = HEAP32[$4>>2]|0;
       $118 = $89;$119 = $98;$121 = $92;$123 = $$pre;$135 = $$pre31;
       break;
      }
      $104 = ___cxa_find_matching_catch()|0;
      $105 = tempRet0;
      $106 = ($89|0)==(0|0);
      if ($106) {
       $eh$lpad$body$index3Z2D = $105;$eh$lpad$body$indexZ2D = $104;
      } else {
       $108 = $94;
       while(1) {
        $107 = ($108|0)==($89|0);
        if ($107) {
         break;
        }
        $109 = (($108) + -84|0);
        __THREW__ = 0;
        invoke_vi(3690,($109|0));
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         label = 41;
         break;
        } else {
         $108 = $109;
        }
       }
       if ((label|0) == 41) {
        $112 = ___cxa_find_matching_catch()|0;
        $113 = tempRet0;
        ___cxa_call_unexpected(($112|0));
        // unreachable;
       }
       HEAP32[$0>>2] = 18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($89|0),($$byval_copy13|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        $116 = ___cxa_find_matching_catch()|0;
        $117 = tempRet0;
        ___cxa_call_unexpected(($116|0));
        // unreachable;
       } else {
        $eh$lpad$body$index3Z2D = $105;$eh$lpad$body$indexZ2D = $104;
       }
      }
     }
    }
    if ((label|0) == 37) {
     $102 = ___cxa_find_matching_catch()|0;
     $103 = tempRet0;
     $eh$lpad$body$index3Z2D = $103;$eh$lpad$body$indexZ2D = $102;
    }
    $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $118;
  HEAP32[$4>>2] = $119;
  $120 = (($v) + 8|0);
  HEAP32[$120>>2] = $121;
  $122 = ($123|0)==(0|0);
  if ($122) {
   STACKTOP = sp;return;
  } else {
   $125 = $135;
  }
  while(1) {
   $124 = ($125|0)==($123|0);
   if ($124) {
    break;
   }
   $126 = (($125) + -84|0);
   __THREW__ = 0;
   invoke_vi(3690,($126|0));
   $127 = __THREW__; __THREW__ = 0;
   $128 = $127&1;
   if ($128) {
    label = 48;
    break;
   } else {
    $125 = $126;
   }
  }
  if ((label|0) == 48) {
   $129 = ___cxa_find_matching_catch()|0;
   $130 = tempRet0;
   ___cxa_call_unexpected(($129|0));
   // unreachable;
  }
  HEAP32[$0>>2] = 18;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($123|0),($$byval_copy13|0));
  $131 = __THREW__; __THREW__ = 0;
  $132 = $131&1;
  if ($132) {
   $133 = ___cxa_find_matching_catch()|0;
   $134 = tempRet0;
   ___cxa_call_unexpected(($133|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = (($15|0) / 84)&-1;
 $17 = ($16|0)==($sz|0);
 if ($17) {
  $81 = (($sz) - ($10))|0;
  __ZNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE8__appendEj($v,$81);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $18 = (($temp) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($temp) + 8|0);
 HEAP32[$19>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3385,($temp|0),($sz|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 L49: do {
  if (!($21)) {
   $22 = HEAP32[$v>>2]|0;
   HEAP32[$2>>2] = $22;
   $23 = HEAP32[$4>>2]|0;
   HEAP32[$3>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_viii(2005,($temp|0),($$byval_copy|0),($$byval_copy13|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$18>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = (($30|0) / 84)&-1;
    $32 = ($31>>>0)<($sz>>>0);
    L52: do {
     if ($32) {
      $33 = (($sz) - ($31))|0;
      __THREW__ = 0;
      invoke_vii(3386,($temp|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L49;
      }
      $$pre32 = HEAP32[$18>>2]|0;
      $49 = $$pre32;
     } else {
      $36 = ($31>>>0)>($sz>>>0);
      if ($36) {
       $37 = (($27) + (($sz*84)|0)|0);
       $38 = ($26|0)==($37|0);
       if ($38) {
        $49 = $26;
       } else {
        $40 = $26;
        while(1) {
         $39 = (($40) + -84|0);
         HEAP32[$18>>2] = $39;
         __THREW__ = 0;
         invoke_vi(3690,($39|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break;
         }
         $$pre$i = HEAP32[$18>>2]|0;
         $43 = ($$pre$i|0)==($37|0);
         if ($43) {
          $49 = $37;
          break L52;
         } else {
          $40 = $$pre$i;
         }
        }
        $44 = ___cxa_find_matching_catch()|0;
        $45 = tempRet0;
        ___cxa_call_unexpected(($44|0));
        // unreachable;
       }
      } else {
       $49 = $26;
      }
     }
    } while(0);
    $46 = HEAP32[$temp>>2]|0;
    $47 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $47;
    HEAP32[$v>>2] = $46;
    $48 = HEAP32[$4>>2]|0;
    HEAP32[$18>>2] = $48;
    HEAP32[$4>>2] = $49;
    $50 = HEAP32[$19>>2]|0;
    $51 = HEAP32[$12>>2]|0;
    HEAP32[$19>>2] = $51;
    HEAP32[$12>>2] = $50;
    $52 = ($47|0)==(0|0);
    if ($52) {
     STACKTOP = sp;return;
    } else {
     $54 = $48;
    }
    while(1) {
     $53 = ($54|0)==($47|0);
     if ($53) {
      break;
     }
     $55 = (($54) + -84|0);
     HEAP32[$18>>2] = $55;
     __THREW__ = 0;
     invoke_vi(3690,($55|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 17;
      break;
     }
     $$pre33 = HEAP32[$18>>2]|0;
     $54 = $$pre33;
    }
    if ((label|0) == 17) {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     ___cxa_call_unexpected(($58|0));
     // unreachable;
    }
    $60 = HEAP32[$temp>>2]|0;
    HEAP32[$$byval_copy>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($60|0),($$byval_copy13|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     $63 = ___cxa_find_matching_catch()|0;
     $64 = tempRet0;
     ___cxa_call_unexpected(($63|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $65 = ___cxa_find_matching_catch()|0;
 $66 = tempRet0;
 $67 = HEAP32[$temp>>2]|0;
 $68 = ($67|0)==(0|0);
 if ($68) {
  $$0 = $66;$$01 = $65;
  ___resumeException($$01|0);
  // unreachable;
 }
 while(1) {
  $69 = HEAP32[$18>>2]|0;
  $70 = ($69|0)==($67|0);
  if ($70) {
   break;
  }
  $71 = (($69) + -84|0);
  HEAP32[$18>>2] = $71;
  __THREW__ = 0;
  invoke_vi(3690,($71|0));
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  $74 = ___cxa_find_matching_catch()|0;
  $75 = tempRet0;
  ___cxa_call_unexpected(($74|0));
  // unreachable;
 }
 $76 = HEAP32[$temp>>2]|0;
 HEAP32[$$byval_copy>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($76|0),($$byval_copy13|0));
 $77 = __THREW__; __THREW__ = 0;
 $78 = $77&1;
 if ($78) {
  $79 = ___cxa_find_matching_catch()|0;
  $80 = tempRet0;
  ___cxa_call_unexpected(($79|0));
  // unreachable;
 } else {
  $$0 = $66;$$01 = $65;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i = 0, $$pre10 = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 84)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = (($12|0) / 84)&-1;
 $14 = ($__n|0)==(0);
 if ($14) {
  $18 = 0;$21 = $10;$22 = $3;
 } else {
  $15 = ($__n*84)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy2,0,766088,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre10 = HEAP32[$9>>2]|0;
  $18 = $16;$21 = $$pre10;$22 = $$pre;
 }
 $17 = (($18) + (($13*84)|0)|0);
 $19 = (($18) + (($__n*84)|0)|0);
 $20 = ($21|0)==($22|0);
 do {
  if ($20) {
   $29 = $17;$32 = $21;$57 = $21;
  } else {
   $$01$i$i = $21;$24 = $17;
   while(1) {
    $23 = (($24) + -84|0);
    $25 = (($$01$i$i) + -84|0);
    __THREW__ = 0;
    invoke_vii(3368,($23|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = ($25|0)==($22|0);
    if ($28) {
     label = 7;
     break;
    } else {
     $$01$i$i = $25;$24 = $23;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre11 = HEAP32[$9>>2]|0;
    $29 = $23;$32 = $$pre$i;$57 = $$pre11;
    break;
   }
   $43 = ___cxa_find_matching_catch()|0;
   $44 = tempRet0;
   $46 = $17;
   while(1) {
    $45 = ($46|0)==($24|0);
    if ($45) {
     break;
    }
    $47 = (($46) + -84|0);
    __THREW__ = 0;
    invoke_vi(3690,($47|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 18;
     break;
    } else {
     $46 = $47;
    }
   }
   if ((label|0) == 18) {
    $50 = ___cxa_find_matching_catch()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   }
   $52 = ($18|0)==(0|0);
   if ($52) {
    ___resumeException($43|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($18|0),($$byval_copy2|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    ___cxa_call_unexpected(($55|0));
    // unreachable;
   } else {
    ___resumeException($43|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $29;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $31 = $57;
 while(1) {
  $30 = ($31|0)==($32|0);
  if ($30) {
   break;
  }
  $33 = (($31) + -84|0);
  __THREW__ = 0;
  invoke_vi(3690,($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 11;
   break;
  } else {
   $31 = $33;
  }
 }
 if ((label|0) == 11) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 }
 $38 = ($32|0)==(0|0);
 if ($38) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($32|0),($$byval_copy2|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  ___cxa_call_unexpected(($41|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 84)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 84)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $82 = ($9|0)==(0|0);
  do {
   if ($82) {
    $98 = $8;
   } else {
    $83 = (($this) + 4|0);
    while(1) {
     $84 = HEAP32[$83>>2]|0;
     $85 = ($84|0)==($9|0);
     if ($85) {
      break;
     }
     $86 = (($84) + -84|0);
     HEAP32[$83>>2] = $86;
     __THREW__ = 0;
     invoke_vi(3690,($86|0));
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 23;
      break;
     }
    }
    if ((label|0) == 23) {
     $89 = ___cxa_find_matching_catch()|0;
     $90 = tempRet0;
     ___cxa_call_unexpected(($89|0));
     // unreachable;
    }
    $91 = HEAP32[$this>>2]|0;
    HEAP32[$0>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($91|0),($$byval_copy1|0));
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     $94 = ___cxa_find_matching_catch()|0;
     $95 = tempRet0;
     ___cxa_call_unexpected(($94|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$83>>2] = 0;
     HEAP32[$this>>2] = 0;
     $98 = 0;
     break;
    }
   }
  } while(0);
  $96 = ($5|0)<(0);
  if ($96) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $97 = $98;
  $99 = (($97|0) / 84)&-1;
  $100 = ($99>>>0)<(1073741823);
  if ($100) {
   $101 = $99 << 1;
   $102 = ($101>>>0)<($6>>>0);
   $103 = $102 ? $6 : $101;
   $104 = ($103|0)<(0);
   if ($104) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i31 = $103;
   }
  } else {
   $$0$i31 = 2147483647;
  }
  $105 = ($$0$i31*84)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $106 = (__Z15malloc_internaljj10MemLabelIdiPKci($105,16,$$byval_copy1,0,766088,79)|0);
  $107 = (($this) + 4|0);
  HEAP32[$107>>2] = $106;
  HEAP32[$this>>2] = $106;
  $108 = (($106) + (($$0$i31*84)|0)|0);
  HEAP32[$7>>2] = $108;
  $109 = ($1|0)==($2|0);
  if ($109) {
   STACKTOP = sp;return;
  } else {
   $111 = $106;$112 = $1;
  }
  while(1) {
   $110 = ($111|0)==(0|0);
   if ($110) {
    $114 = 0;
   } else {
    __ZN24CompressedAnimationCurveC2ERKS_($111,$112);
    $$pre1$i = HEAP32[$107>>2]|0;
    $114 = $$pre1$i;
   }
   $113 = (($114) + 84|0);
   HEAP32[$107>>2] = $113;
   $115 = (($112) + 84|0);
   $116 = ($115|0)==($2|0);
   if ($116) {
    break;
   } else {
    $111 = $113;$112 = $115;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16;
 $18 = (($17) - ($11))|0;
 $19 = (($18|0) / 84)&-1;
 $20 = ($6>>>0)>($19>>>0);
 if ($20) {
  $21 = (($1) + (($19*84)|0)|0);
  $23 = $21;$__growing$0$off0 = 1;
 } else {
  $23 = $2;$__growing$0$off0 = 0;
 }
 $22 = ($1|0)==($23|0);
 if ($22) {
  $$0$lcssa$i$i = $9;
 } else {
  $scevgep$i = (($23) + -84|0);
  $24 = (0 - ($4))|0;
  $uglygep$i = (($scevgep$i) + ($24)|0);
  $uglygep16$i = $uglygep$i;
  $25 = (($uglygep16$i>>>0) / 84)&-1;
  $$01$i$i = $9;$26 = $1;
  while(1) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$26+0>>2]|0;HEAP8[$$01$i$i+4>>0]=HEAP8[$26+4>>0]|0;
   $27 = ($$01$i$i|0)==($26|0);
   if (!($27)) {
    $28 = (($$01$i$i) + 8|0);
    $29 = (($26) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($26) + 12|0);
    $32 = HEAP32[$31>>2]|0;
    __ZNSt3__16vectorIhNS_9allocatorIhEEE6assignIPhEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($28,$30,$32);
    $33 = (($26) + 20|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($$01$i$i) + 20|0);
    HEAP32[$35>>2] = $34;
    $36 = (($$01$i$i) + 24|0);
    $37 = (($26) + 24|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($26) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    __ZNSt3__16vectorIhNS_9allocatorIhEEE6assignIPhEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($36,$38,$40);
    $41 = (($$01$i$i) + 36|0);
    $42 = (($26) + 36|0);
    ;HEAP32[$41+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$42+8>>2]|0;HEAP8[$41+12>>0]=HEAP8[$42+12>>0]|0;
    $43 = (($$01$i$i) + 52|0);
    $44 = (($26) + 52|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($26) + 56|0);
    $47 = HEAP32[$46>>2]|0;
    __ZNSt3__16vectorIhNS_9allocatorIhEEE6assignIPhEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($43,$45,$47);
   }
   $48 = (($$01$i$i) + 64|0);
   $49 = (($26) + 64|0);
   $50 = $49;
   $51 = $50;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($50) + 4)|0;
   $54 = $53;
   $55 = HEAP32[$54>>2]|0;
   $56 = $48;
   $57 = $56;
   HEAP32[$57>>2] = $52;
   $58 = (($56) + 4)|0;
   $59 = $58;
   HEAP32[$59>>2] = $55;
   $60 = (($$01$i$i) + 72|0);
   $61 = (($26) + 72|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($60,$61)|0);
   $62 = (($26) + 84|0);
   $63 = (($$01$i$i) + 84|0);
   $64 = ($62|0)==($23|0);
   if ($64) {
    break;
   } else {
    $$01$i$i = $63;$26 = $62;
   }
  }
  $65 = (($25) + 1)|0;
  $scevgep17$i = (($9) + (($65*84)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if (!($__growing$0$off0)) {
  while(1) {
   $75 = HEAP32[$15>>2]|0;
   $76 = ($75|0)==($$0$lcssa$i$i|0);
   if ($76) {
    label = 36;
    break;
   }
   $77 = (($75) + -84|0);
   HEAP32[$15>>2] = $77;
   __THREW__ = 0;
   invoke_vi(3690,($77|0));
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 18;
    break;
   }
  }
  if ((label|0) == 18) {
   $80 = ___cxa_find_matching_catch()|0;
   $81 = tempRet0;
   ___cxa_call_unexpected(($80|0));
   // unreachable;
  }
  else if ((label|0) == 36) {
   STACKTOP = sp;return;
  }
 }
 $66 = HEAP32[$__last>>2]|0;
 $67 = ($23|0)==($66|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $$pre$i12 = HEAP32[$15>>2]|0;
 $69 = $$pre$i12;$70 = $23;
 while(1) {
  $68 = ($69|0)==(0|0);
  if ($68) {
   $72 = 0;
  } else {
   __ZN24CompressedAnimationCurveC2ERKS_($69,$70);
   $$pre1$i14 = HEAP32[$15>>2]|0;
   $72 = $$pre1$i14;
  }
  $71 = (($72) + 84|0);
  HEAP32[$15>>2] = $71;
  $73 = (($70) + 84|0);
  $74 = ($73|0)==($66|0);
  if ($74) {
   break;
  } else {
   $69 = $71;$70 = $73;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIhNS_9allocatorIhEEE6assignIPhEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = ($2>>>0)>($8>>>0);
 if (!($9)) {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($7))|0;
  $14 = ($2>>>0)>($13>>>0);
  if (!($14)) {
   _memmove(($5|0),($__first|0),($2|0))|0;
   $24 = (($5) + ($2)|0);
   $25 = HEAP32[$10>>2]|0;
   $26 = ($25|0)==($24|0);
   if ($26) {
    STACKTOP = sp;return;
   }
   HEAP32[$10>>2] = $24;
   STACKTOP = sp;return;
  }
  $15 = (($__first) + ($13)|0);
  _memmove(($5|0),($__first|0),($13|0))|0;
  $16 = ($15|0)==($__last|0);
  if ($16) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$10>>2]|0;
  $$01$i3 = $15;$18 = $$pre$i1;
  while(1) {
   $17 = ($18|0)==(0|0);
   if ($17) {
    $21 = 0;
   } else {
    $19 = HEAP8[$$01$i3>>0]|0;
    HEAP8[$18>>0] = $19;
    $$pre2$i4 = HEAP32[$10>>2]|0;
    $21 = $$pre2$i4;
   }
   $20 = (($21) + 1|0);
   HEAP32[$10>>2] = $20;
   $22 = (($$01$i3) + 1|0);
   $23 = ($22|0)==($__last|0);
   if ($23) {
    break;
   } else {
    $$01$i3 = $22;$18 = $20;
   }
  }
  STACKTOP = sp;return;
 }
 $27 = ($5|0)==(0|0);
 if ($27) {
  $33 = $4;
 } else {
  $28 = (($this) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==($5|0);
  if (!($30)) {
   HEAP32[$28>>2] = $5;
  }
  __ZdlPv($5);
  HEAP32[$3>>2] = 0;
  HEAP32[$28>>2] = 0;
  HEAP32[$this>>2] = 0;
  $33 = 0;
 }
 $31 = ($2|0)<(0);
 if ($31) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $32 = ($33>>>0)<((1073741823)>>>0);
 if ($32) {
  $34 = $33;
  $35 = $34 << 1;
  $36 = ($35>>>0)<($2>>>0);
  $37 = $36 ? $2 : $35;
  $38 = ($37|0)<(0);
  if ($38) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $37;
  }
 } else {
  $$0$i7 = 2147483647;
 }
 $39 = (__Znwj($$0$i7)|0);
 $40 = (($this) + 4|0);
 HEAP32[$40>>2] = $39;
 HEAP32[$this>>2] = $39;
 $41 = (($39) + ($$0$i7)|0);
 HEAP32[$3>>2] = $41;
 $42 = ($__first|0)==($__last|0);
 if ($42) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$44 = $39;
 }
 while(1) {
  $43 = ($44|0)==(0|0);
  if ($43) {
   $47 = 0;
  } else {
   $45 = HEAP8[$$01$i>>0]|0;
   HEAP8[$44>>0] = $45;
   $$pre2$i = HEAP32[$40>>2]|0;
   $47 = $$pre2$i;
  }
  $46 = (($47) + 1|0);
  HEAP32[$40>>2] = $46;
  $48 = (($$01$i) + 1|0);
  $49 = ($48|0)==($__last|0);
  if ($49) {
   break;
  } else {
   $$01$i = $48;$44 = $46;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0;
 var $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i3;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $30 = $27;
  }
  while(1) {
   $29 = (($30) + 12|0);
   __ZN17AnimationCurveTplI11QuaternionfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$30,0);
   __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
   $31 = (($30) + 192|0);
   $32 = ($31|0)==($26|0);
   if ($32) {
    break;
   } else {
    $30 = $31;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*192)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplI11QuaternionfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 168|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre$i$i$i1 = HEAP32[$1>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre3 = HEAP32[$5>>2]|0;
  $13 = $$pre;$15 = $$pre3;$9 = $$pre$i$i$i1;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $13 = $4;$15 = $6;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$1>>2] = $10;
 $11 = (($this) + 172|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$11,4);
  $$pre$i$i$i = HEAP32[$11>>2]|0;
  $17 = $$pre$i$i$i;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$11>>2] = $18;
  __ZN17AnimationCurveTplI11QuaternionfE15InvalidateCacheEv($this);
  STACKTOP = sp;return;
 } else {
  $16 = HEAP32[$13>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$2>>2] = $12;
  $17 = $16;
  $18 = (_llvm_bswap_i32(($17|0))|0);
  HEAP32[$11>>2] = $18;
  __ZN17AnimationCurveTplI11QuaternionfE15InvalidateCacheEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + (($41*52)|0)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   $44 = HEAP32[$3>>2]|0;
   $45 = (($44) + 4|0);
   $46 = HEAP32[$9>>2]|0;
   $47 = ($45>>>0)>($46>>>0);
   if ($47) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$04,4);
    $$pre$i$i$i$i$i$i = HEAP32[$i$04>>2]|0;
    $$pre$phi$i$i$i$i$i$iZ2D = $i$04;$50 = $$pre$i$i$i$i$i$i;
   } else {
    $48 = Math_fround(HEAPF32[$44>>2]);
    HEAPF32[$i$04>>2] = $48;
    HEAP32[$3>>2] = $45;
    $49 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
    $$pre$phi$i$i$i$i$i$iZ2D = $i$04;$50 = $49;
   }
   $51 = (_llvm_bswap_i32(($50|0))|0);
   HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $51;
   $52 = (($i$04) + 4|0);
   __ZN11Quaternionf8TransferI18StreamedBinaryReadILb1EEEEvRT_($52,$this);
   $53 = (($i$04) + 20|0);
   __ZN11Quaternionf8TransferI18StreamedBinaryReadILb1EEEEvRT_($53,$this);
   $54 = (($i$04) + 36|0);
   __ZN11Quaternionf8TransferI18StreamedBinaryReadILb1EEEEvRT_($54,$this);
   $55 = (($i$04) + 52|0);
   $56 = ($55|0)==($42|0);
   if ($56) {
    break;
   } else {
    $i$04 = $55;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$3>>2]|0;
   $$pre5 = HEAP32[$9>>2]|0;
   $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $13 = $12;$16 = $8;$18 = $10;
  }
  $14 = (_llvm_bswap_i32(($13|0))|0);
  HEAP32[$size>>2] = $14;
  $15 = (($16) + 4|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre6 = HEAP32[$size>>2]|0;
   $20 = $$pre$i$i$i1;$23 = $$pre6;
  } else {
   $19 = HEAP32[$16>>2]|0;
   HEAP32[$offset>>2] = $19;
   HEAP32[$3>>2] = $15;
   $20 = $19;$23 = $14;
  }
  $21 = (_llvm_bswap_i32(($20|0))|0);
  HEAP32[$offset>>2] = $21;
  $22 = ($23*52)|0;
  $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
  $25 = (($data) + 12|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(-1);
  if ($27) {
   $28 = HEAP32[$data>>2]|0;
   $29 = (($data) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $30;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $31 = (($22|0) / 52)&-1;
  $32 = (($data) + 8|0);
  HEAP32[$32>>2] = $31;
  $33 = $31 | -2147483648;
  HEAP32[$25>>2] = $33;
  HEAP32[$data>>2] = $24;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 56|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$memLabel>>2]|0;
  $5 = (($data) + 4|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($data) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 2147483647;
 $9 = ($8>>>0)<($rs>>>0);
 do {
  if ($9) {
   $10 = ($7|0)>(-1);
   if ($10) {
    HEAP32[$6>>2] = $rs;
    $11 = ($rs*52)|0;
    $12 = (($data) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    HEAP32[$0>>2] = $13;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $14 = (__Z16realloc_internalPvji10MemLabelIdiPKci($2,$11,4,$$byval_copy1,0,766088,370)|0);
    HEAP32[$data>>2] = $14;
    $27 = $14;
    break;
   } else {
    $15 = ($rs*52)|0;
    $16 = (($data) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,4,$$byval_copy1,0,766088,352)|0);
    $19 = HEAP32[$data>>2]|0;
    $20 = (($data) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21*52)|0;
    _memcpy(($18|0),($19|0),($22|0))|0;
    HEAP32[$6>>2] = $rs;
    HEAP32[$data>>2] = $18;
    $27 = $18;
    break;
   }
  } else {
   $27 = $2;
  }
 } while(0);
 $23 = (($data) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24>>>0)<($rs>>>0);
 if (!($25)) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $26 = (($27) + (($rs*52)|0)|0);
 $28 = ($24|0)==($rs|0);
 if ($28) {
  HEAP32[$23>>2] = $rs;
  STACKTOP = sp;return;
 }
 $29 = (($27) + (($24*52)|0)|0);
 $$01$i$i = $29;
 while(1) {
  $30 = ($$01$i$i|0)==(0|0);
  if (!($30)) {
   dest=$$01$i$i+0|0; src=$1+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $31 = (($$01$i$i) + 52|0);
  $32 = ($31|0)==($26|0);
  if ($32) {
   break;
  } else {
   $$01$i$i = $31;
  }
 }
 HEAP32[$23>>2] = $rs;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre1$i$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $lpad$phi$i$i$index = 0, $lpad$phi$i$i$index2 = 0, $temp = 0;
 var $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $temp1 = sp + 24|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 192)&-1;
 $9 = ($8>>>0)<($sz>>>0);
 if ($9) {
  $10 = (($v) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11;
  $13 = (($12) - ($6))|0;
  $14 = (($13|0) / 192)&-1;
  $15 = ($14|0)==($sz|0);
  if ($15) {
   __ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6resizeEj($v,$sz);
   STACKTOP = sp;return;
  }
  HEAP32[$temp>>2] = 0;
  $16 = (($temp) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($temp) + 8|0);
  HEAP32[$17>>2] = 0;
  __THREW__ = 0;
  invoke_vii(3387,($temp|0),($sz|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = HEAP32[$v>>2]|0;
   HEAP32[$0>>2] = $20;
   $21 = HEAP32[$2>>2]|0;
   HEAP32[$1>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(2006,($temp|0),($$byval_copy|0),($$byval_copy7|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    invoke_vii(3371,($temp|0),($sz|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = HEAP32[$temp>>2]|0;
     $27 = HEAP32[$v>>2]|0;
     HEAP32[$temp>>2] = $27;
     HEAP32[$v>>2] = $26;
     $28 = HEAP32[$16>>2]|0;
     $29 = HEAP32[$2>>2]|0;
     HEAP32[$16>>2] = $29;
     HEAP32[$2>>2] = $28;
     $30 = HEAP32[$17>>2]|0;
     $31 = HEAP32[$10>>2]|0;
     HEAP32[$17>>2] = $31;
     HEAP32[$10>>2] = $30;
     __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($temp);
     STACKTOP = sp;return;
    }
   }
  }
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($temp);
  $$0 = $33;$$01 = $32;
  ___resumeException($$01|0);
  // unreachable;
 }
 $34 = ($8>>>0)>($sz>>>0);
 if (!($34)) {
  STACKTOP = sp;return;
 }
 $35 = (($4) + (($sz*192)|0)|0);
 HEAP32[$temp1>>2] = 0;
 $36 = (($temp1) + 4|0);
 HEAP32[$36>>2] = 0;
 $37 = (($temp1) + 8|0);
 HEAP32[$37>>2] = 0;
 $$idx = ($sz*192)|0;
 $38 = (($$idx|0) / 192)&-1;
 $39 = ($sz|0)==(0);
 L18: do {
  if ($39) {
   $60 = $4;$61 = 0;$62 = $3;$63 = 0;$66 = 0;
  } else {
   $40 = ($$idx|0)<(0);
   do {
    if ($40) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 21;
     } else {
      // unreachable;
     }
    } else {
     HEAP32[$$byval_copy>>2] = 18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
     $43 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(766088|0),79)|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 21;
     } else {
      HEAP32[$36>>2] = $43;
      HEAP32[$temp1>>2] = $43;
      $46 = (($43) + (($38*192)|0)|0);
      HEAP32[$37>>2] = $46;
      $48 = $43;$49 = $4;
      while(1) {
       $47 = ($48|0)==(0|0);
       if ($47) {
        $53 = 0;
       } else {
        __THREW__ = 0;
        invoke_vii(3367,($48|0),($49|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 20;
         break;
        }
        $$pre1$i$i$i = HEAP32[$36>>2]|0;
        $53 = $$pre1$i$i$i;
       }
       $52 = (($53) + 192|0);
       HEAP32[$36>>2] = $52;
       $54 = (($49) + 192|0);
       $55 = ($54|0)==($35|0);
       if ($55) {
        label = 22;
        break;
       } else {
        $48 = $52;$49 = $54;
       }
      }
      if ((label|0) == 20) {
       $56 = ___cxa_find_matching_catch()|0;
       $57 = tempRet0;
       $lpad$phi$i$i$index = $56;$lpad$phi$i$i$index2 = $57;
       break;
      }
      else if ((label|0) == 22) {
       $$pre = HEAP32[$temp1>>2]|0;
       $$pre9 = HEAP32[$v>>2]|0;
       $$pre10 = HEAP32[$2>>2]|0;
       $$pre11 = HEAP32[$37>>2]|0;
       $60 = $$pre9;$61 = $$pre;$62 = $$pre10;$63 = $52;$66 = $$pre11;
       break L18;
      }
     }
    }
   } while(0);
   if ((label|0) == 21) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    $lpad$phi$i$i$index = $58;$lpad$phi$i$i$index2 = $59;
   }
   __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($temp1);
   $$0 = $lpad$phi$i$i$index2;$$01 = $lpad$phi$i$i$index;
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 HEAP32[$temp1>>2] = $60;
 HEAP32[$v>>2] = $61;
 HEAP32[$36>>2] = $62;
 HEAP32[$2>>2] = $63;
 $64 = (($v) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 HEAP32[$37>>2] = $65;
 HEAP32[$64>>2] = $66;
 __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($temp1);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 192)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 192)&-1;
 $15 = (($__v) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($__v) + 16|0);
 HEAP32[$16>>2] = $9;
 $17 = ($__n|0)==(0);
 if ($17) {
  $20 = 0;$26 = $11;$27 = $3;
 } else {
  $18 = ($__n*192)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $19 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,16,$$byval_copy,0,766088,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre1 = HEAP32[$10>>2]|0;
  $20 = $19;$26 = $$pre1;$27 = $$pre;
 }
 HEAP32[$__v>>2] = $20;
 $21 = (($20) + (($14*192)|0)|0);
 $22 = (($__v) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($__v) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = (($20) + (($__n*192)|0)|0);
 HEAP32[$15>>2] = $24;
 $25 = ($26|0)==($27|0);
 do {
  if ($25) {
   $36 = $21;$37 = $26;$38 = $21;$39 = $26;$41 = $24;
  } else {
   $$01$i$i = $26;$29 = $21;
   while(1) {
    $28 = (($29) + -192|0);
    $30 = (($$01$i$i) + -192|0);
    __THREW__ = 0;
    invoke_vii(3367,($28|0),($30|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     label = 10;
     break;
    }
    $33 = HEAP32[$23>>2]|0;
    $34 = (($33) + -192|0);
    HEAP32[$23>>2] = $34;
    $35 = ($30|0)==($27|0);
    if ($35) {
     label = 7;
     break;
    } else {
     $$01$i$i = $30;$29 = $34;
    }
   }
   if ((label|0) == 7) {
    $$pre$i = HEAP32[$this>>2]|0;
    $$pre2 = HEAP32[$10>>2]|0;
    $$pre3 = HEAP32[$22>>2]|0;
    $$pre4 = HEAP32[$15>>2]|0;
    $36 = $34;$37 = $$pre$i;$38 = $$pre3;$39 = $$pre2;$41 = $$pre4;
    break;
   }
   else if ((label|0) == 10) {
    $42 = ___cxa_find_matching_catch()|0;
    $43 = tempRet0;
    __ZNSt3__114__split_bufferIN13AnimationClip15QuaternionCurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
    ___resumeException($42|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $36;
 HEAP32[$23>>2] = $37;
 HEAP32[$10>>2] = $38;
 HEAP32[$22>>2] = $39;
 $40 = HEAP32[$1>>2]|0;
 HEAP32[$1>>2] = $41;
 HEAP32[$15>>2] = $40;
 HEAP32[$__v>>2] = $37;
 __ZNSt3__114__split_bufferIN13AnimationClip15QuaternionCurveER13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i32 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy3 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$__first>>2]|0;
 $4 = HEAP32[$__last>>2]|0;
 $5 = $4;
 $6 = $3;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 192)&-1;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 192)&-1;
 $16 = ($8>>>0)>($15>>>0);
 if ($16) {
  __ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE10deallocateEv($this);
  $76 = ($7|0)<(0);
  if ($76) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $77 = HEAP32[$9>>2]|0;
  $78 = HEAP32[$this>>2]|0;
  $79 = $77;
  $80 = $78;
  $81 = (($79) - ($80))|0;
  $82 = (($81|0) / 192)&-1;
  $83 = ($82>>>0)<(1073741823);
  if ($83) {
   $84 = $82 << 1;
   $85 = ($84>>>0)<($8>>>0);
   $86 = $85 ? $8 : $84;
   $87 = ($86|0)<(0);
   if ($87) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i32 = $86;
   }
  } else {
   $$0$i32 = 2147483647;
  }
  $88 = ($$0$i32*192)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $89 = (__Z15malloc_internaljj10MemLabelIdiPKci($88,16,$$byval_copy3,0,766088,79)|0);
  $90 = (($this) + 4|0);
  HEAP32[$90>>2] = $89;
  HEAP32[$this>>2] = $89;
  $91 = (($89) + (($$0$i32*192)|0)|0);
  HEAP32[$9>>2] = $91;
  $92 = ($3|0)==($4|0);
  if ($92) {
   STACKTOP = sp;return;
  } else {
   $94 = $89;$95 = $3;
  }
  while(1) {
   $93 = ($94|0)==(0|0);
   if ($93) {
    $97 = 0;
   } else {
    __ZN13AnimationClip15QuaternionCurveC2ERKS0_($94,$95);
    $$pre1$i = HEAP32[$90>>2]|0;
    $97 = $$pre1$i;
   }
   $96 = (($97) + 192|0);
   HEAP32[$90>>2] = $96;
   $98 = (($95) + 192|0);
   $99 = ($98|0)==($4|0);
   if ($99) {
    break;
   } else {
    $94 = $96;$95 = $98;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18;
 $20 = (($19) - ($13))|0;
 $21 = (($20|0) / 192)&-1;
 $22 = ($8>>>0)>($21>>>0);
 if ($22) {
  $23 = (($3) + (($21*192)|0)|0);
  $25 = $23;$__growing$0$off0 = 1;
 } else {
  $25 = $4;$__growing$0$off0 = 0;
 }
 $24 = ($3|0)==($25|0);
 if ($24) {
  $$0$lcssa$i$i = $11;
 } else {
  $scevgep$i = (($25) + -192|0);
  $26 = (0 - ($6))|0;
  $uglygep$i = (($scevgep$i) + ($26)|0);
  $uglygep16$i = $uglygep$i;
  $27 = (($uglygep16$i>>>0) / 192)&-1;
  $$01$i$i = $11;$28 = $3;
  while(1) {
   (__ZN13AnimationClip15QuaternionCurveaSERKS0_($$01$i$i,$28)|0);
   $29 = (($28) + 192|0);
   $30 = (($$01$i$i) + 192|0);
   $31 = ($29|0)==($25|0);
   if ($31) {
    break;
   } else {
    $$01$i$i = $30;$28 = $29;
   }
  }
  $32 = (($27) + 1)|0;
  $scevgep17$i = (($11) + (($32*192)|0)|0);
  $$0$lcssa$i$i = $scevgep17$i;
 }
 if ($__growing$0$off0) {
  $33 = ($25|0)==($4|0);
  if ($33) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$17>>2]|0;
  $35 = $$pre$i12;$36 = $25;
  while(1) {
   $34 = ($35|0)==(0|0);
   if ($34) {
    $38 = 0;
   } else {
    __ZN13AnimationClip15QuaternionCurveC2ERKS0_($35,$36);
    $$pre1$i14 = HEAP32[$17>>2]|0;
    $38 = $$pre1$i14;
   }
   $37 = (($38) + 192|0);
   HEAP32[$17>>2] = $37;
   $39 = (($36) + 192|0);
   $40 = ($39|0)==($4|0);
   if ($40) {
    break;
   } else {
    $35 = $37;$36 = $39;
   }
  }
  STACKTOP = sp;return;
 }
 $41 = HEAP32[$17>>2]|0;
 $42 = ($41|0)==($$0$lcssa$i$i|0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $44 = $41;
 while(1) {
  $43 = (($44) + -192|0);
  HEAP32[$17>>2] = $43;
  $45 = (($44) + -16|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)>(-1);
  if ($47) {
   $48 = (($44) + -28|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($44) + -24|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$2>>2] = $51;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($49|0),($$byval_copy3|0));
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    label = 23;
    break;
   }
   HEAP32[$48>>2] = 0;
  }
  $54 = HEAP8[$43>>0]|0;
  $55 = $54 & 1;
  $56 = ($55<<24>>24)==(0);
  if (!($56)) {
   $59 = (($44) + -184|0);
   $60 = HEAP32[$59>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy3|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    label = 22;
    break;
   }
  }
  $57 = HEAP32[$17>>2]|0;
  $58 = ($57|0)==($$0$lcssa$i$i|0);
  if ($58) {
   label = 36;
   break;
  } else {
   $44 = $57;
  }
 }
 if ((label|0) == 22) {
  $63 = ___cxa_find_matching_catch()|0;
  $64 = tempRet0;
  ___cxa_call_unexpected(($63|0));
  // unreachable;
 }
 else if ((label|0) == 23) {
  $65 = ___cxa_find_matching_catch()|0;
  $66 = tempRet0;
  $67 = HEAP8[$43>>0]|0;
  $68 = $67 & 1;
  $69 = ($68<<24>>24)==(0);
  if ($69) {
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
  $70 = (($44) + -184|0);
  $71 = HEAP32[$70>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($71|0),($$byval_copy3|0));
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   $74 = ___cxa_find_matching_catch()|0;
   $75 = tempRet0;
   ___cxa_call_unexpected(($74|0));
   // unreachable;
  } else {
   ___cxa_call_unexpected(($65|0));
   // unreachable;
  }
 }
 else if ((label|0) == 36) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 do {
  if ($7) {
   $41 = $3;
  } else {
   $9 = $6;
   while(1) {
    $8 = (($9) + -192|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)>(-1);
    if ($12) {
     $13 = (($9) + -28|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($9) + -24|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$2>>2] = $16;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($14|0),($$byval_copy3|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 11;
      break;
     }
     HEAP32[$13>>2] = 0;
    }
    $19 = HEAP8[$8>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $24 = (($9) + -184|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy3|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 10;
      break;
     }
    }
    $22 = HEAP32[$5>>2]|0;
    $23 = ($22|0)==($3|0);
    if ($23) {
     label = 15;
     break;
    } else {
     $9 = $22;
    }
   }
   if ((label|0) == 10) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   else if ((label|0) == 11) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    $32 = HEAP8[$8>>0]|0;
    $33 = $32 & 1;
    $34 = ($33<<24>>24)==(0);
    if ($34) {
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
    $35 = (($9) + -184|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($36|0),($$byval_copy3|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $39 = ___cxa_find_matching_catch()|0;
     $40 = tempRet0;
     ___cxa_call_unexpected(($39|0));
     // unreachable;
    } else {
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
   else if ((label|0) == 15) {
    $$pre = HEAP32[$this>>2]|0;
    $41 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy3|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE10deallocateEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($3|0);
 do {
  if ($7) {
   $41 = $3;
  } else {
   $9 = $6;
   while(1) {
    $8 = (($9) + -192|0);
    HEAP32[$5>>2] = $8;
    $10 = (($9) + -16|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)>(-1);
    if ($12) {
     $13 = (($9) + -28|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($9) + -24|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$2>>2] = $16;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($14|0),($$byval_copy3|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 11;
      break;
     }
     HEAP32[$13>>2] = 0;
    }
    $19 = HEAP8[$8>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $24 = (($9) + -184|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy3|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 10;
      break;
     }
    }
    $22 = HEAP32[$5>>2]|0;
    $23 = ($22|0)==($3|0);
    if ($23) {
     label = 15;
     break;
    } else {
     $9 = $22;
    }
   }
   if ((label|0) == 10) {
    $28 = ___cxa_find_matching_catch()|0;
    $29 = tempRet0;
    ___cxa_call_unexpected(($28|0));
    // unreachable;
   }
   else if ((label|0) == 11) {
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    $32 = HEAP8[$8>>0]|0;
    $33 = $32 & 1;
    $34 = ($33<<24>>24)==(0);
    if ($34) {
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
    $35 = (($9) + -184|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($36|0),($$byval_copy3|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $39 = ___cxa_find_matching_catch()|0;
     $40 = tempRet0;
     ___cxa_call_unexpected(($39|0));
     // unreachable;
    } else {
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
   else if ((label|0) == 15) {
    $$pre = HEAP32[$this>>2]|0;
    $41 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$0>>2] = 18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($41|0),($$byval_copy3|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  ___cxa_call_unexpected(($44|0));
  // unreachable;
 }
 $46 = (($this) + 8|0);
 HEAP32[$46>>2] = 0;
 HEAP32[$5>>2] = 0;
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip15QuaternionCurveaSERKS0_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$idx$i = 0, $$pre$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $1 = sp;
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($this,$0)|0);
 $2 = (($this) + 12|0);
 $3 = (($0) + 12|0);
 dest=$2+0|0; src=$3+0|0; stop=dest+76|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = (($this) + 88|0);
 $5 = (($0) + 88|0);
 dest=$4+0|0; src=$5+0|0; stop=dest+76|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $6 = (($this) + 164|0);
 $7 = ($0|0)==($this|0);
 if ($7) {
  $32 = (($this) + 180|0);
  $33 = (($0) + 180|0);
  $34 = $33;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 4)|0;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = $32;
  $41 = $40;
  HEAP32[$41>>2] = $36;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = $39;
  $44 = (($0) + 188|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($this) + 188|0);
  HEAP32[$46>>2] = $45;
  STACKTOP = sp;return ($this|0);
 }
 $8 = (($0) + 164|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($0) + 172|0);
 $11 = HEAP32[$10>>2]|0;
 $$idx$i = ($11*52)|0;
 $12 = (($$idx$i|0) / 52)&-1;
 $13 = (($this) + 172|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 176|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($12>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $12;
    $19 = HEAP32[$6>>2]|0;
    $20 = (($this) + 168|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$1>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($19,$$idx$i,4,$$byval_copy1,0,766088,370)|0);
    HEAP32[$6>>2] = $22;
    $31 = $22;
    break;
   } else {
    $23 = (($this) + 168|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$1>>2] = $24;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx$i,4,$$byval_copy1,0,766088,352)|0);
    $26 = HEAP32[$6>>2]|0;
    $27 = HEAP32[$13>>2]|0;
    $28 = ($27*52)|0;
    _memcpy(($25|0),($26|0),($28|0))|0;
    HEAP32[$14>>2] = $12;
    HEAP32[$6>>2] = $25;
    $31 = $25;
    break;
   }
  } else {
   $$pre$i$i = HEAP32[$6>>2]|0;
   $31 = $$pre$i$i;
  }
 } while(0);
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29*52)|0;
 _memcpy(($31|0),($9|0),($30|0))|0;
 $32 = (($this) + 180|0);
 $33 = (($0) + 180|0);
 $34 = $33;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = $32;
 $41 = $40;
 HEAP32[$41>>2] = $36;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $39;
 $44 = (($0) + 188|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($this) + 188|0);
 HEAP32[$46>>2] = $45;
 STACKTOP = sp;return ($this|0);
}
function __ZN13AnimationClip8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy8 = 0, $$pre = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $empty = 0, $empty1 = 0, $i$01$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy8 = sp + 44|0;
 $0 = sp;
 $1 = sp + 4|0;
 $empty = sp + 8|0;
 $empty1 = sp + 20|0;
 $value = sp + 32|0;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $2 = (($this) + 164|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,1);
  $$pre = HEAP32[$3>>2]|0;
  $14 = $$pre;
 } else {
  $9 = HEAP8[$4>>0]|0;
  HEAP8[$2>>0] = $9;
  $10 = HEAP32[$3>>2]|0;
  $11 = (($10) + 1|0);
  HEAP32[$3>>2] = $11;
  $14 = $11;
 }
 $12 = (($this) + 84|0);
 $13 = (($14) + 1|0);
 $15 = HEAP32[$6>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$12,1);
  $$pre16 = HEAP32[$3>>2]|0;
  $22 = $$pre16;
 } else {
  $17 = HEAP8[$14>>0]|0;
  HEAP8[$12>>0] = $17;
  $18 = HEAP32[$3>>2]|0;
  $19 = (($18) + 1|0);
  HEAP32[$3>>2] = $19;
  $22 = $19;
 }
 $20 = (($this) + 85|0);
 $21 = (($22) + 1|0);
 $23 = HEAP32[$6>>2]|0;
 $24 = ($21>>>0)>($23>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$20,1);
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$3>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$3>>2] = $27;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $28 = HEAP8[$12>>0]|0;
 $29 = ($28<<24>>24)==(0);
 L13: do {
  if ($29) {
   $30 = (($this) + 92|0);
   __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$30,0);
   HEAP32[$empty>>2] = 0;
   $31 = (($empty) + 4|0);
   HEAP32[$31>>2] = 0;
   $32 = (($empty) + 8|0);
   HEAP32[$32>>2] = 0;
   __THREW__ = 0;
   invoke_viii(2007,($transfer|0),($empty|0),0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    $35 = HEAP32[$empty>>2]|0;
    $36 = ($35|0)==(0|0);
    if ($36) {
     break;
    }
    while(1) {
     $37 = HEAP32[$31>>2]|0;
     $38 = ($37|0)==($35|0);
     if ($38) {
      break;
     }
     $39 = (($37) + -84|0);
     HEAP32[$31>>2] = $39;
     __THREW__ = 0;
     invoke_vi(3690,($39|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      label = 15;
      break;
     }
    }
    if ((label|0) == 15) {
     $42 = ___cxa_find_matching_catch()|0;
     $43 = tempRet0;
     ___cxa_call_unexpected(($42|0));
     // unreachable;
    }
    $44 = HEAP32[$empty>>2]|0;
    HEAP32[$1>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($44|0),($$byval_copy8|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     break;
    }
    $47 = ___cxa_find_matching_catch()|0;
    $48 = tempRet0;
    ___cxa_call_unexpected(($47|0));
    // unreachable;
   }
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $51 = HEAP32[$empty>>2]|0;
   $52 = ($51|0)==(0|0);
   if ($52) {
    $$1 = $50;$$12 = $49;
    ___resumeException($$12|0);
    // unreachable;
   }
   while(1) {
    $53 = HEAP32[$31>>2]|0;
    $54 = ($53|0)==($51|0);
    if ($54) {
     break;
    }
    $55 = (($53) + -84|0);
    HEAP32[$31>>2] = $55;
    __THREW__ = 0;
    invoke_vi(3690,($55|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     label = 21;
     break;
    }
   }
   if ((label|0) == 21) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    ___cxa_call_unexpected(($58|0));
    // unreachable;
   }
   $60 = HEAP32[$empty>>2]|0;
   HEAP32[$1>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy8|0));
   $61 = __THREW__; __THREW__ = 0;
   $62 = $61&1;
   if ($62) {
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    ___cxa_call_unexpected(($63|0));
    // unreachable;
   } else {
    $$1 = $50;$$12 = $49;
    ___resumeException($$12|0);
    // unreachable;
   }
  } else {
   HEAP32[$empty1>>2] = 0;
   $65 = (($empty1) + 4|0);
   HEAP32[$65>>2] = 0;
   $66 = (($empty1) + 8|0);
   HEAP32[$66>>2] = 0;
   __THREW__ = 0;
   invoke_viii(2008,($transfer|0),($empty1|0),0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   L37: do {
    if ($68) {
     $76 = ___cxa_find_matching_catch()|0;
     $77 = tempRet0;
     $$0 = $77;$$01 = $76;
    } else {
     $69 = HEAP32[$transfer>>2]|0;
     $70 = $69 & 33554432;
     $71 = ($70|0)==(0);
     L40: do {
      if ($71) {
       HEAP32[$value>>2] = 0;
       $72 = (($value) + 4|0);
       HEAP32[$72>>2] = 0;
       $73 = (($value) + 8|0);
       HEAP32[$73>>2] = 0;
       __THREW__ = 0;
       invoke_viii(2007,($transfer|0),($value|0),0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       L42: do {
        if ($75) {
         label = 29;
        } else {
         $96 = (($this) + 92|0);
         $97 = HEAP32[$72>>2]|0;
         $98 = HEAP32[$value>>2]|0;
         $99 = $97;
         $100 = $98;
         $101 = (($99) - ($100))|0;
         $102 = (($101|0) / 84)&-1;
         __THREW__ = 0;
         invoke_vii(3371,($96|0),($102|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          label = 29;
         } else {
          $105 = HEAP32[$72>>2]|0;
          $106 = HEAP32[$value>>2]|0;
          $107 = ($105|0)==($106|0);
          L45: do {
           if ($107) {
            $123 = $105;$160 = $105;
           } else {
            $109 = $106;$i$01$i = 0;
            while(1) {
             $108 = (($109) + (($i$01$i*84)|0)|0);
             $110 = HEAP32[$96>>2]|0;
             $111 = (($110) + (($i$01$i*192)|0)|0);
             __THREW__ = 0;
             invoke_vii(3372,($108|0),($111|0));
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if ($113) {
              break;
             }
             $114 = (($i$01$i) + 1)|0;
             $115 = HEAP32[$72>>2]|0;
             $116 = HEAP32[$value>>2]|0;
             $117 = $115;
             $118 = $116;
             $119 = (($117) - ($118))|0;
             $120 = (($119|0) / 84)&-1;
             $121 = ($114>>>0)<($120>>>0);
             if ($121) {
              $109 = $116;$i$01$i = $114;
             } else {
              $123 = $116;$160 = $115;
              break L45;
             }
            }
            $78 = ___cxa_find_matching_catch()|0;
            $79 = tempRet0;
            $lpad$phi$index = $78;$lpad$phi$index2 = $79;
            break L42;
           }
          } while(0);
          $122 = ($123|0)==(0|0);
          if ($122) {
           break L40;
          } else {
           $125 = $160;
          }
          while(1) {
           $124 = ($125|0)==($123|0);
           if ($124) {
            break;
           }
           $126 = (($125) + -84|0);
           HEAP32[$72>>2] = $126;
           __THREW__ = 0;
           invoke_vi(3690,($126|0));
           $127 = __THREW__; __THREW__ = 0;
           $128 = $127&1;
           if ($128) {
            label = 45;
            break;
           }
           $$pre19 = HEAP32[$72>>2]|0;
           $125 = $$pre19;
          }
          if ((label|0) == 45) {
           $129 = ___cxa_find_matching_catch()|0;
           $130 = tempRet0;
           ___cxa_call_unexpected(($129|0));
           // unreachable;
          }
          $131 = HEAP32[$value>>2]|0;
          HEAP32[$0>>2] = 18;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($131|0),($$byval_copy8|0));
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if (!($133)) {
           break L40;
          }
          $134 = ___cxa_find_matching_catch()|0;
          $135 = tempRet0;
          ___cxa_call_unexpected(($134|0));
          // unreachable;
         }
        }
       } while(0);
       if ((label|0) == 29) {
        $80 = ___cxa_find_matching_catch()|0;
        $81 = tempRet0;
        $lpad$phi$index = $80;$lpad$phi$index2 = $81;
       }
       $82 = HEAP32[$value>>2]|0;
       $83 = ($82|0)==(0|0);
       if ($83) {
        $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
        break L37;
       }
       while(1) {
        $84 = HEAP32[$72>>2]|0;
        $85 = ($84|0)==($82|0);
        if ($85) {
         break;
        }
        $86 = (($84) + -84|0);
        HEAP32[$72>>2] = $86;
        __THREW__ = 0;
        invoke_vi(3690,($86|0));
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         label = 33;
         break;
        }
       }
       if ((label|0) == 33) {
        $89 = ___cxa_find_matching_catch()|0;
        $90 = tempRet0;
        ___cxa_call_unexpected(($89|0));
        // unreachable;
       }
       $91 = HEAP32[$value>>2]|0;
       HEAP32[$0>>2] = 18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($91|0),($$byval_copy8|0));
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if (!($93)) {
        $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
        break L37;
       }
       $94 = ___cxa_find_matching_catch()|0;
       $95 = tempRet0;
       ___cxa_call_unexpected(($94|0));
       // unreachable;
      }
     } while(0);
     __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
     break L13;
    }
   } while(0);
   __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
   $$1 = $$0;$$12 = $$01;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $136 = (($this) + 104|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$136,0);
 $137 = (($this) + 116|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$137,0);
 $138 = (($this) + 128|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$138,0);
 $139 = (($this) + 140|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$139,0);
 $140 = (($this) + 80|0);
 $141 = HEAP32[$3>>2]|0;
 $142 = (($141) + 4|0);
 $143 = HEAP32[$6>>2]|0;
 $144 = ($142>>>0)>($143>>>0);
 if ($144) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$140,4);
  $$pre17 = HEAP32[$3>>2]|0;
  $$pre18 = HEAP32[$6>>2]|0;
  $148 = $$pre17;$150 = $$pre18;
 } else {
  $145 = Math_fround(HEAPF32[$141>>2]);
  HEAPF32[$140>>2] = $145;
  HEAP32[$3>>2] = $142;
  $148 = $142;$150 = $143;
 }
 $146 = (($this) + 88|0);
 $147 = (($148) + 4|0);
 $149 = ($147>>>0)>($150>>>0);
 if ($149) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$146,4);
  $152 = (($this) + 216|0);
  __ZN4AABB8TransferI18StreamedBinaryReadILb0EEEEvRT_($152,$transfer);
  $153 = (($this) + 48|0);
  $154 = (($transfer) + 4|0);
  HEAP32[$154>>2] = $153;
  $155 = (($this) + 168|0);
  $156 = (($this) + 172|0);
  __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE18StreamedBinaryReadILb0EEEvRPT_PKcRjS9_RT0_($155,766608,$156,766624,$transfer);
  $157 = (($this) + 176|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEEEvRT_17TransferMetaFlags($transfer,$157,0);
  $158 = (($this) + 192|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$158,0);
  $159 = (($this) + 152|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$159,0);
  STACKTOP = sp;return;
 } else {
  $151 = HEAP32[$148>>2]|0;
  HEAP32[$146>>2] = $151;
  HEAP32[$3>>2] = $147;
  $152 = (($this) + 216|0);
  __ZN4AABB8TransferI18StreamedBinaryReadILb0EEEEvRT_($152,$transfer);
  $153 = (($this) + 48|0);
  $154 = (($transfer) + 4|0);
  HEAP32[$154>>2] = $153;
  $155 = (($this) + 168|0);
  $156 = (($this) + 172|0);
  __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE18StreamedBinaryReadILb0EEEvRPT_PKcRjS9_RT0_($155,766608,$156,766624,$transfer);
  $157 = (($this) + 176|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEEEvRT_17TransferMetaFlags($transfer,$157,0);
  $158 = (($this) + 192|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$158,0);
  $159 = (($this) + 152|0);
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$159,0);
  STACKTOP = sp;return;
 }
}
function __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE18StreamedBinaryReadILb0EEEvRPT_PKcRjS9_RT0_($data,$name,$size,$sizeName,$transfer) {
 $data = $data|0;
 $name = $name|0;
 $size = $size|0;
 $sizeName = $sizeName|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $scevgep$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$size,4);
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$size>>2] = $6;
  HEAP32[$0>>2] = $2;
 }
 $7 = HEAP32[$data>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $42 = $7;
  __ZN7mecanim9animation18ClipMuscleConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($42,$transfer);
  STACKTOP = sp;return;
 }
 $9 = (($transfer) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$size>>2]|0;
 __ZN7mecanim6memory16ChainedAllocator7ReserveEj($10,$11);
 $12 = HEAP32[$10>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiii[$13 & 2047]($10,1644,4)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $41 = 0;
 } else {
  __ZN7mecanim5human9HumanPoseC2Ev($14);
  $16 = (($14) + 880|0);
  $17 = (($14) + 908|0);
  ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;HEAP32[$16+24>>2]=0|0;
  HEAPF32[$17>>2] = Math_fround(1.0);
  $18 = (($14) + 912|0);
  HEAPF32[$18>>2] = Math_fround(1.0);
  $19 = (($14) + 916|0);
  HEAPF32[$19>>2] = Math_fround(1.0);
  $20 = (($14) + 920|0);
  HEAPF32[$20>>2] = Math_fround(1.0);
  $21 = (($14) + 924|0);
  HEAPF32[$21>>2] = Math_fround(1.0);
  $22 = (($14) + 928|0);
  $23 = (($14) + 956|0);
  ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;HEAP32[$22+16>>2]=0|0;HEAP32[$22+20>>2]=0|0;HEAP32[$22+24>>2]=0|0;
  HEAPF32[$23>>2] = Math_fround(1.0);
  $24 = (($14) + 960|0);
  HEAPF32[$24>>2] = Math_fround(1.0);
  $25 = (($14) + 964|0);
  HEAPF32[$25>>2] = Math_fround(1.0);
  $26 = (($14) + 968|0);
  HEAPF32[$26>>2] = Math_fround(1.0);
  $27 = (($14) + 972|0);
  HEAPF32[$27>>2] = Math_fround(1.0);
  $28 = (($14) + 976|0);
  $29 = (($14) + 1004|0);
  ;HEAP32[$28+0>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;HEAP32[$28+12>>2]=0|0;HEAP32[$28+16>>2]=0|0;HEAP32[$28+20>>2]=0|0;HEAP32[$28+24>>2]=0|0;
  HEAPF32[$29>>2] = Math_fround(1.0);
  $30 = (($14) + 1008|0);
  HEAPF32[$30>>2] = Math_fround(1.0);
  $31 = (($14) + 1012|0);
  HEAPF32[$31>>2] = Math_fround(1.0);
  $32 = (($14) + 1016|0);
  HEAPF32[$32>>2] = Math_fround(1.0);
  $33 = (($14) + 1020|0);
  HEAPF32[$33>>2] = Math_fround(1.0);
  $34 = (($14) + 1024|0);
  $35 = (($14) + 1052|0);
  ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;HEAP32[$34+24>>2]=0|0;
  HEAPF32[$35>>2] = Math_fround(1.0);
  $36 = (($14) + 1056|0);
  $37 = (($14) + 1620|0);
  $38 = (($14) + 1639|0);
  ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;
  ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP16[$37+16>>1]=0|0;HEAP8[$37+18>>0]=0|0;
  HEAP8[$38>>0] = 1;
  $39 = (($14) + 1640|0);
  HEAP8[$39>>0] = 0;
  $40 = (($14) + 1641|0);
  HEAP8[$40>>0] = 0;
  $scevgep$i$i$i = (($14) + 1072|0);
  _memset(($scevgep$i$i$i|0),-1,548)|0;
  $41 = $14;
 }
 HEAP32[$data>>2] = $41;
 $42 = $41;
 __ZN7mecanim9animation18ClipMuscleConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($42,$transfer);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI14AnimationEvent13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN14AnimationEvent8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 56|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*56)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<4)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN11UnityEngine9Animation14GenericBinding8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 16|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 4;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 4;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation14GenericBinding8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $11 = $$pre3;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
 }
 $13 = (($this) + 8|0);
 __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($13,$transfer);
 $14 = (($this) + 12|0);
 $15 = HEAP32[$0>>2]|0;
 $16 = (($15) + 2|0);
 $17 = HEAP32[$3>>2]|0;
 $18 = ($16>>>0)>($17>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$14,2);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $22 = $$pre4;$24 = $$pre5;
 } else {
  $19 = HEAP16[$15>>1]|0;
  HEAP16[$14>>1] = $19;
  HEAP32[$0>>2] = $16;
  $22 = $16;$24 = $17;
 }
 $20 = (($this) + 14|0);
 $21 = (($22) + 1|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$20,1);
  $$pre6 = HEAP32[$0>>2]|0;
  $30 = $$pre6;
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$0>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$0>>2] = $27;
  $30 = $27;
 }
 $28 = (($this) + 15|0);
 $29 = (($30) + 1|0);
 $31 = HEAP32[$3>>2]|0;
 $32 = ($29>>>0)>($31>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$28,1);
  STACKTOP = sp;return;
 } else {
  $33 = HEAP8[$30>>0]|0;
  HEAP8[$28>>0] = $33;
  $34 = HEAP32[$0>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$0>>2] = $35;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation18ClipMuscleConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0;
 var $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i6 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i6 = sp;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 48|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($2,$transfer);
 $3 = (($this) + 64|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($3,$transfer);
 $4 = (($this) + 80|0);
 HEAP32[$ArrayTransfer$i6>>2] = 4;
 $5 = (($ArrayTransfer$i6) + 4|0);
 HEAP32[$5>>2] = $4;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI19StaticArrayTransferIN7mecanim5human9HumanGoalELi4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i6,0);
 $6 = (($this) + 384|0);
 __ZN7mecanim4hand8HandPose8TransferI18StreamedBinaryReadILb0EEEEvRT_($6,$transfer);
 $7 = (($this) + 528|0);
 __ZN7mecanim4hand8HandPose8TransferI18StreamedBinaryReadILb0EEEEvRT_($7,$transfer);
 $8 = (($this) + 672|0);
 HEAP32[$ArrayTransfer$i6>>2] = 52;
 $9 = (($ArrayTransfer$i6) + 4|0);
 HEAP32[$9>>2] = $8;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI19StaticArrayTransferIfLi52EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i6,0);
 $10 = (($this) + 880|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($10,$transfer);
 $11 = (($this) + 896|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($11,$transfer);
 $12 = (($this) + 912|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($12,$transfer);
 $13 = (($this) + 928|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($13,$transfer);
 $14 = (($this) + 944|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($14,$transfer);
 $15 = (($this) + 960|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($15,$transfer);
 $16 = (($this) + 976|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($16,$transfer);
 $17 = (($this) + 992|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($17,$transfer);
 $18 = (($this) + 1008|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($18,$transfer);
 $19 = (($this) + 1024|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($19,$transfer);
 $20 = (($this) + 1040|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $23 = (($transfer) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = (FUNCTION_TABLE_iiii[$26 & 2047]($24,64,4)|0);
  $28 = ($27|0)==(0|0);
  if ($28) {
   $32 = 0;$34 = 0;
  } else {
   dest=$27+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $29 = $27;
   $30 = $20;
   $31 = (($29) - ($30))|0;
   $32 = $31;$34 = $27;
  }
  HEAP32[$20>>2] = $32;
  $33 = (($this) + 1044|0);
  HEAP32[$33>>2] = $34;
  $$pre$phi$i$iZ2D = $33;$37 = $32;
 } else {
  $$pre$i$i = (($this) + 1044|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$37 = $21;
 }
 $35 = $20;
 $36 = (($37) + ($35))|0;
 $38 = $36;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $38;
 __ZN7mecanim9animation4Clip8TransferI18StreamedBinaryReadILb0EEEEvRT_($38,$transfer);
 $39 = (($this) + 1048|0);
 $40 = (($transfer) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($41) + 4|0);
 $43 = (($transfer) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42>>>0)>($44>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$39,4);
  $$pre = HEAP32[$40>>2]|0;
  $$pre16 = HEAP32[$43>>2]|0;
  $49 = $$pre;$51 = $$pre16;
 } else {
  $46 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$39>>2] = $46;
  HEAP32[$40>>2] = $42;
  $49 = $42;$51 = $44;
 }
 $47 = (($this) + 1052|0);
 $48 = (($49) + 4|0);
 $50 = ($48>>>0)>($51>>>0);
 if ($50) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$47,4);
  $$pre17 = HEAP32[$40>>2]|0;
  $$pre18 = HEAP32[$43>>2]|0;
  $55 = $$pre17;$57 = $$pre18;
 } else {
  $52 = Math_fround(HEAPF32[$49>>2]);
  HEAPF32[$47>>2] = $52;
  HEAP32[$40>>2] = $48;
  $55 = $48;$57 = $51;
 }
 $53 = (($this) + 1056|0);
 $54 = (($55) + 4|0);
 $56 = ($54>>>0)>($57>>>0);
 if ($56) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$53,4);
  $$pre19 = HEAP32[$40>>2]|0;
  $$pre20 = HEAP32[$43>>2]|0;
  $61 = $$pre19;$63 = $$pre20;
 } else {
  $58 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$53>>2] = $58;
  HEAP32[$40>>2] = $54;
  $61 = $54;$63 = $57;
 }
 $59 = (($this) + 1060|0);
 $60 = (($61) + 4|0);
 $62 = ($60>>>0)>($63>>>0);
 if ($62) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$59,4);
  $$pre21 = HEAP32[$40>>2]|0;
  $$pre22 = HEAP32[$43>>2]|0;
  $67 = $$pre21;$69 = $$pre22;
 } else {
  $64 = Math_fround(HEAPF32[$61>>2]);
  HEAPF32[$59>>2] = $64;
  HEAP32[$40>>2] = $60;
  $67 = $60;$69 = $63;
 }
 $65 = (($this) + 1064|0);
 $66 = (($67) + 4|0);
 $68 = ($66>>>0)>($69>>>0);
 if ($68) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$65,4);
  $$pre23 = HEAP32[$40>>2]|0;
  $$pre24 = HEAP32[$43>>2]|0;
  $73 = $$pre23;$75 = $$pre24;
 } else {
  $70 = Math_fround(HEAPF32[$67>>2]);
  HEAPF32[$65>>2] = $70;
  HEAP32[$40>>2] = $66;
  $73 = $66;$75 = $69;
 }
 $71 = (($this) + 1068|0);
 $72 = (($73) + 4|0);
 $74 = ($72>>>0)>($75>>>0);
 if ($74) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$71,4);
 } else {
  $76 = Math_fround(HEAPF32[$73>>2]);
  HEAPF32[$71>>2] = $76;
  HEAP32[$40>>2] = $72;
 }
 $77 = (($this) + 1072|0);
 HEAP32[$ArrayTransfer$i6>>2] = 137;
 $78 = (($ArrayTransfer$i6) + 4|0);
 HEAP32[$78>>2] = $77;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI19StaticArrayTransferIiLi137EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i6,0);
 $79 = (($this) + 1624|0);
 $80 = (($this) + 1620|0);
 $81 = (($transfer) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 HEAP32[$ArrayTransfer$i6>>2] = $79;
 $83 = (($ArrayTransfer$i6) + 4|0);
 HEAP32[$83>>2] = $80;
 $84 = (($ArrayTransfer$i6) + 8|0);
 HEAP32[$84>>2] = $82;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation10ValueDeltaEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i6,0);
 $85 = (($this) + 1632|0);
 $86 = HEAP32[$40>>2]|0;
 $87 = (($86) + 1|0);
 $88 = HEAP32[$43>>2]|0;
 $89 = ($87>>>0)>($88>>>0);
 if ($89) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$85,1);
  $$pre25 = HEAP32[$40>>2]|0;
  $95 = $$pre25;
 } else {
  $90 = HEAP8[$86>>0]|0;
  HEAP8[$85>>0] = $90;
  $91 = HEAP32[$40>>2]|0;
  $92 = (($91) + 1|0);
  HEAP32[$40>>2] = $92;
  $95 = $92;
 }
 $93 = (($this) + 1633|0);
 $94 = (($95) + 1|0);
 $96 = HEAP32[$43>>2]|0;
 $97 = ($94>>>0)>($96>>>0);
 if ($97) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$93,1);
  $$pre26 = HEAP32[$40>>2]|0;
  $103 = $$pre26;
 } else {
  $98 = HEAP8[$95>>0]|0;
  HEAP8[$93>>0] = $98;
  $99 = HEAP32[$40>>2]|0;
  $100 = (($99) + 1|0);
  HEAP32[$40>>2] = $100;
  $103 = $100;
 }
 $101 = (($this) + 1634|0);
 $102 = (($103) + 1|0);
 $104 = HEAP32[$43>>2]|0;
 $105 = ($102>>>0)>($104>>>0);
 if ($105) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$101,1);
  $$pre27 = HEAP32[$40>>2]|0;
  $111 = $$pre27;
 } else {
  $106 = HEAP8[$103>>0]|0;
  HEAP8[$101>>0] = $106;
  $107 = HEAP32[$40>>2]|0;
  $108 = (($107) + 1|0);
  HEAP32[$40>>2] = $108;
  $111 = $108;
 }
 $109 = (($this) + 1635|0);
 $110 = (($111) + 1|0);
 $112 = HEAP32[$43>>2]|0;
 $113 = ($110>>>0)>($112>>>0);
 if ($113) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$109,1);
  $$pre28 = HEAP32[$40>>2]|0;
  $119 = $$pre28;
 } else {
  $114 = HEAP8[$111>>0]|0;
  HEAP8[$109>>0] = $114;
  $115 = HEAP32[$40>>2]|0;
  $116 = (($115) + 1|0);
  HEAP32[$40>>2] = $116;
  $119 = $116;
 }
 $117 = (($this) + 1636|0);
 $118 = (($119) + 1|0);
 $120 = HEAP32[$43>>2]|0;
 $121 = ($118>>>0)>($120>>>0);
 if ($121) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$117,1);
  $$pre29 = HEAP32[$40>>2]|0;
  $127 = $$pre29;
 } else {
  $122 = HEAP8[$119>>0]|0;
  HEAP8[$117>>0] = $122;
  $123 = HEAP32[$40>>2]|0;
  $124 = (($123) + 1|0);
  HEAP32[$40>>2] = $124;
  $127 = $124;
 }
 $125 = (($this) + 1637|0);
 $126 = (($127) + 1|0);
 $128 = HEAP32[$43>>2]|0;
 $129 = ($126>>>0)>($128>>>0);
 if ($129) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$125,1);
  $$pre30 = HEAP32[$40>>2]|0;
  $135 = $$pre30;
 } else {
  $130 = HEAP8[$127>>0]|0;
  HEAP8[$125>>0] = $130;
  $131 = HEAP32[$40>>2]|0;
  $132 = (($131) + 1|0);
  HEAP32[$40>>2] = $132;
  $135 = $132;
 }
 $133 = (($this) + 1638|0);
 $134 = (($135) + 1|0);
 $136 = HEAP32[$43>>2]|0;
 $137 = ($134>>>0)>($136>>>0);
 if ($137) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$133,1);
  $$pre31 = HEAP32[$40>>2]|0;
  $143 = $$pre31;
 } else {
  $138 = HEAP8[$135>>0]|0;
  HEAP8[$133>>0] = $138;
  $139 = HEAP32[$40>>2]|0;
  $140 = (($139) + 1|0);
  HEAP32[$40>>2] = $140;
  $143 = $140;
 }
 $141 = (($this) + 1639|0);
 $142 = (($143) + 1|0);
 $144 = HEAP32[$43>>2]|0;
 $145 = ($142>>>0)>($144>>>0);
 if ($145) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$141,1);
  $$pre32 = HEAP32[$40>>2]|0;
  $151 = $$pre32;
 } else {
  $146 = HEAP8[$143>>0]|0;
  HEAP8[$141>>0] = $146;
  $147 = HEAP32[$40>>2]|0;
  $148 = (($147) + 1|0);
  HEAP32[$40>>2] = $148;
  $151 = $148;
 }
 $149 = (($this) + 1640|0);
 $150 = (($151) + 1|0);
 $152 = HEAP32[$43>>2]|0;
 $153 = ($150>>>0)>($152>>>0);
 if ($153) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$149,1);
  $$pre33 = HEAP32[$40>>2]|0;
  $159 = $$pre33;
 } else {
  $154 = HEAP8[$151>>0]|0;
  HEAP8[$149>>0] = $154;
  $155 = HEAP32[$40>>2]|0;
  $156 = (($155) + 1|0);
  HEAP32[$40>>2] = $156;
  $159 = $156;
 }
 $157 = (($this) + 1641|0);
 $158 = (($159) + 1|0);
 $160 = HEAP32[$43>>2]|0;
 $161 = ($158>>>0)>($160>>>0);
 if ($161) {
  __ZN12CachedReader15UpdateReadCacheEPvj($40,$157,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $162 = HEAP8[$159>>0]|0;
  HEAP8[$157>>0] = $162;
  $163 = HEAP32[$40>>2]|0;
  $164 = (($163) + 1|0);
  HEAP32[$40>>2] = $164;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation10ValueDeltaEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $37 = (($24) + 4|0);
  HEAP32[$37>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$35 = 0;
  } else {
   $32 = $30;
   $33 = $24;
   $34 = (($32) - ($33))|0;
   $$0$i1$i$i = $30;$35 = $34;
  }
  HEAP32[$24>>2] = $35;
  $36 = (($24) + 4|0);
  HEAP32[$36>>2] = $$0$i1$i$i;
 }
 $38 = HEAP32[$data>>2]|0;
 $39 = $38;
 $40 = HEAP32[$38>>2]|0;
 $41 = (($40) + ($39))|0;
 $42 = $41;
 $43 = (($38) + 4|0);
 HEAP32[$43>>2] = $42;
 $44 = HEAP32[$20>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($42) + ($45<<3)|0);
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = ($51|0)==($46|0);
 if ($53) {
  STACKTOP = sp;return;
 } else {
  $i$04 = $51;
 }
 while(1) {
  $54 = HEAP32[$1>>2]|0;
  $55 = (($54) + 4|0);
  $56 = HEAP32[$7>>2]|0;
  $57 = ($55>>>0)>($56>>>0);
  if ($57) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$04,4);
   $$pre$i$i$i = HEAP32[$1>>2]|0;
   $$pre2$i$i$i = HEAP32[$7>>2]|0;
   $61 = $$pre$i$i$i;$63 = $$pre2$i$i$i;
  } else {
   $58 = Math_fround(HEAPF32[$54>>2]);
   HEAPF32[$i$04>>2] = $58;
   HEAP32[$1>>2] = $55;
   $61 = $55;$63 = $56;
  }
  $59 = (($i$04) + 4|0);
  $60 = (($61) + 4|0);
  $62 = ($60>>>0)>($63>>>0);
  if ($62) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$59,4);
  } else {
   $64 = Math_fround(HEAPF32[$61>>2]);
   HEAPF32[$59>>2] = $64;
   HEAP32[$1>>2] = $60;
  }
  $65 = (($i$04) + 8|0);
  $66 = ($65|0)==($46|0);
  if ($66) {
   break;
  } else {
   $i$04 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI19StaticArrayTransferIiLi137EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $21 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $21 = $19;
  }
  $20 = ($21>>>0)>(137);
  $22 = $20 ? 137 : $21;
  HEAP32[$data>>2] = $22;
  $23 = ($21|0)==(0);
  if ($23) {
   STACKTOP = sp;return;
  }
  $24 = (($data) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$25,$26);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre4 = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$7>>2]|0;
  $12 = $$pre4;$14 = $$pre5;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre6 = HEAP32[$offset>>2]|0;
  $18 = $$pre6;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation4Clip8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $0;
 $3 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 $5 = (($this) + 12|0);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$5,4);
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$5>>2] = $12;
  HEAP32[$6>>2] = $8;
 }
 $13 = (($this) + 16|0);
 __ZN7mecanim9animation9DenseClip8TransferI18StreamedBinaryReadILb0EEEEvRT_($13,$transfer);
 $14 = (($this) + 48|0);
 $15 = (($this) + 44|0);
 $16 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $14;
 $17 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$17>>2] = $15;
 $18 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$18>>2] = $16;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 $19 = (($this) + 56|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $22 = HEAP32[$1>>2]|0;
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$23>>2]|0;
  $25 = (FUNCTION_TABLE_iiii[$24 & 2047]($22,12,4)|0);
  $26 = ($25|0)==(0|0);
  if ($26) {
   $32 = 0;$34 = 0;
  } else {
   HEAP32[$25>>2] = 0;
   $27 = (($25) + 4|0);
   HEAP32[$27>>2] = 0;
   $28 = (($25) + 8|0);
   HEAP32[$28>>2] = 0;
   $29 = $25;
   $30 = $19;
   $31 = (($29) - ($30))|0;
   $32 = $31;$34 = $25;
  }
  HEAP32[$19>>2] = $32;
  $33 = (($this) + 60|0);
  HEAP32[$33>>2] = $34;
  $$pre$phi$i$iZ2D = $33;$37 = $32;
 } else {
  $$pre$i$i = (($this) + 60|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$37 = $20;
 }
 $35 = $19;
 $36 = (($37) + ($35))|0;
 $38 = $36;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $38;
 $39 = (($38) + 4|0);
 $40 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $39;
 $41 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$41>>2] = $38;
 $42 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$42>>2] = $40;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim13ValueConstantEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim13ValueConstantEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $44 = (($24) + 4|0);
  HEAP32[$44>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 4;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$42 = 0;
  } else {
   $32 = (($30) + ($22<<4)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    HEAP32[$35>>2] = 10;
    $36 = (($33) + 12|0);
    HEAP32[$36>>2] = 0;
    $37 = (($33) + 16|0);
    $38 = ($37|0)==($32|0);
    if ($38) {
     break;
    } else {
     $33 = $37;
    }
   }
   $39 = $30;
   $40 = $24;
   $41 = (($39) - ($40))|0;
   $$0$i1$i$i = $30;$42 = $41;
  }
  HEAP32[$24>>2] = $42;
  $43 = (($24) + 4|0);
  HEAP32[$43>>2] = $$0$i1$i$i;
 }
 $45 = HEAP32[$data>>2]|0;
 $46 = $45;
 $47 = HEAP32[$45>>2]|0;
 $48 = (($47) + ($46))|0;
 $49 = $48;
 $50 = (($45) + 4|0);
 HEAP32[$50>>2] = $49;
 $51 = HEAP32[$20>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($49) + ($52<<4)|0);
 $54 = HEAP32[$data>>2]|0;
 $55 = $54;
 $56 = HEAP32[$54>>2]|0;
 $57 = (($56) + ($55))|0;
 $58 = $57;
 $59 = (($54) + 4|0);
 HEAP32[$59>>2] = $58;
 $60 = ($58|0)==($53|0);
 if ($60) {
  STACKTOP = sp;return;
 } else {
  $i$04 = $58;
 }
 while(1) {
  __ZN7mecanim13ValueConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$04,$this);
  $61 = (($i$04) + 16|0);
  $62 = ($61|0)==($53|0);
  if ($62) {
   break;
  } else {
   $i$04 = $61;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim13ValueConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $11 = $$pre4;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $15 = $$pre5;$17 = $$pre6;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre7 = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $21 = $$pre7;$23 = $$pre8;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation9DenseClip8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre2 = HEAP32[$3>>2]|0;
  $11 = $$pre2;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre3 = HEAP32[$0>>2]|0;
  $$pre4 = HEAP32[$3>>2]|0;
  $15 = $$pre3;$17 = $$pre4;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre5 = HEAP32[$0>>2]|0;
  $$pre6 = HEAP32[$3>>2]|0;
  $21 = $$pre5;$23 = $$pre6;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
 }
 $25 = (($this) + 20|0);
 $26 = (($this) + 16|0);
 $27 = (($transfer) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $25;
 $29 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$29>>2] = $26;
 $30 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$30>>2] = $28;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = 0, $9 = Math_fround(0), $buf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf = sp;
 $0 = Math_fround(HEAPF32[$data>>2]);
 HEAPF32[$buf>>2] = $0;
 $1 = (($buf) + 4|0);
 $2 = (($data) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$1>>2] = $3;
 $4 = (($buf) + 8|0);
 $5 = (($data) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($buf) + 12|0);
 $8 = (($data) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = (($transfer) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = (($transfer) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$buf,4);
  $$pre = HEAP32[$10>>2]|0;
  $$pre4 = HEAP32[$13>>2]|0;
  $18 = $$pre;$20 = $$pre4;
 } else {
  $16 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$buf>>2] = $16;
  HEAP32[$10>>2] = $12;
  $18 = $12;$20 = $14;
 }
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)>($20>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$1,4);
  $$pre5 = HEAP32[$10>>2]|0;
  $$pre6 = HEAP32[$13>>2]|0;
  $23 = $$pre5;$25 = $$pre6;
 } else {
  $21 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$1>>2] = $21;
  HEAP32[$10>>2] = $17;
  $23 = $17;$25 = $20;
 }
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$4,4);
  $$pre7 = HEAP32[$10>>2]|0;
  $$pre8 = HEAP32[$13>>2]|0;
  $28 = $$pre7;$30 = $$pre8;
 } else {
  $26 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$4>>2] = $26;
  HEAP32[$10>>2] = $22;
  $28 = $22;$30 = $25;
 }
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($10,$7,4);
  $$pre9 = Math_fround(HEAPF32[$7>>2]);
  $35 = $$pre9;
  $32 = Math_fround(HEAPF32[$buf>>2]);
  $33 = Math_fround(HEAPF32[$1>>2]);
  $34 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$data>>2] = $32;
  HEAPF32[$2>>2] = $33;
  HEAPF32[$5>>2] = $34;
  HEAPF32[$8>>2] = $35;
  STACKTOP = sp;return;
 } else {
  $31 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$7>>2] = $31;
  HEAP32[$10>>2] = $27;
  $35 = $31;
  $32 = Math_fround(HEAPF32[$buf>>2]);
  $33 = Math_fround(HEAPF32[$1>>2]);
  $34 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$data>>2] = $32;
  HEAPF32[$2>>2] = $33;
  HEAPF32[$5>>2] = $34;
  HEAPF32[$8>>2] = $35;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI19StaticArrayTransferIfLi52EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $21 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $21 = $19;
  }
  $20 = ($21>>>0)>(52);
  $22 = $20 ? 52 : $21;
  HEAP32[$data>>2] = $22;
  $23 = ($21|0)==(0);
  if ($23) {
   STACKTOP = sp;return;
  }
  $24 = (($data) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$25,$26);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre4 = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$7>>2]|0;
  $12 = $$pre4;$14 = $$pre5;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre6 = HEAP32[$offset>>2]|0;
  $18 = $$pre6;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7mecanim4hand8HandPose8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 48|0);
 HEAP32[$ArrayTransfer$i>>2] = 20;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $2;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI19StaticArrayTransferIfLi20EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 $4 = (($this) + 128|0);
 $5 = (($transfer) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = (($transfer) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$4,4);
  $$pre = HEAP32[$5>>2]|0;
  $$pre4 = HEAP32[$8>>2]|0;
  $14 = $$pre;$16 = $$pre4;
 } else {
  $11 = Math_fround(HEAPF32[$6>>2]);
  HEAPF32[$4>>2] = $11;
  HEAP32[$5>>2] = $7;
  $14 = $7;$16 = $9;
 }
 $12 = (($this) + 132|0);
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$12,4);
  $$pre5 = HEAP32[$5>>2]|0;
  $$pre6 = HEAP32[$8>>2]|0;
  $20 = $$pre5;$22 = $$pre6;
 } else {
  $17 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$12>>2] = $17;
  HEAP32[$5>>2] = $13;
  $20 = $13;$22 = $16;
 }
 $18 = (($this) + 136|0);
 $19 = (($20) + 4|0);
 $21 = ($19>>>0)>($22>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$18,4);
  $$pre7 = HEAP32[$5>>2]|0;
  $$pre8 = HEAP32[$8>>2]|0;
  $26 = $$pre7;$28 = $$pre8;
 } else {
  $23 = Math_fround(HEAPF32[$20>>2]);
  HEAPF32[$18>>2] = $23;
  HEAP32[$5>>2] = $19;
  $26 = $19;$28 = $22;
 }
 $24 = (($this) + 140|0);
 $25 = (($26) + 4|0);
 $27 = ($25>>>0)>($28>>>0);
 if ($27) {
  __ZN12CachedReader15UpdateReadCacheEPvj($5,$24,4);
  STACKTOP = sp;return;
 } else {
  $29 = Math_fround(HEAPF32[$26>>2]);
  HEAPF32[$24>>2] = $29;
  HEAP32[$5>>2] = $25;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI19StaticArrayTransferIfLi20EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $21 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $21 = $19;
  }
  $20 = ($21>>>0)>(20);
  $22 = $20 ? 20 : $21;
  HEAP32[$data>>2] = $22;
  $23 = ($21|0)==(0);
  if ($23) {
   STACKTOP = sp;return;
  }
  $24 = (($data) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = $21 << 2;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$25,$26);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre4 = HEAP32[$1>>2]|0;
  $$pre5 = HEAP32[$7>>2]|0;
  $12 = $$pre4;$14 = $$pre5;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre6 = HEAP32[$offset>>2]|0;
  $18 = $$pre6;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI19StaticArrayTransferIN7mecanim5human9HumanGoalELi4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $21 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $21 = $19;
  }
  $20 = ($21>>>0)>(4);
  $22 = $20 ? 4 : $21;
  HEAP32[$data>>2] = $22;
  $23 = (($data) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($24) + (($22*76)|0)|0);
  $26 = ($22|0)==(0);
  if ($26) {
   STACKTOP = sp;return;
  }
  $i$04 = $24;
  while(1) {
   __ZN7mecanim5human9HumanGoal8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$04,$this);
   $27 = (($i$04) + 76|0);
   $28 = ($27|0)==($25|0);
   if ($28) {
    break;
   } else {
    $i$04 = $27;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = ($16*76)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim5human9HumanGoal8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($this,$transfer);
 $0 = (($this) + 16|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($0,$transfer);
 $1 = (($this) + 32|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($1,$transfer);
 $2 = (($this) + 48|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre3 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre3;
 } else {
  $9 = Math_fround(HEAPF32[$4>>2]);
  HEAPF32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($this) + 52|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,4);
 } else {
  $15 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$3>>2] = $11;
 }
 $16 = (($this) + 56|0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($16,$transfer);
 $17 = (($this) + 72|0);
 $18 = HEAP32[$3>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$6>>2]|0;
 $21 = ($19>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$17,4);
  STACKTOP = sp;return;
 } else {
  $22 = Math_fround(HEAPF32[$18>>2]);
  HEAPF32[$17>>2] = $22;
  HEAP32[$3>>2] = $19;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN13AnimationClip9PPtrCurve8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 48|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*48)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip9PPtrCurve8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI12PPtrKeyframeLj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
 $1 = (($this) + 12|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$1,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $2 = (($this) + 24|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $10 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb0EEEEvRT_($10,$transfer);
  STACKTOP = sp;return;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb0EEEEvRT_($10,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI12PPtrKeyframeLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI12PPtrKeyframeLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<3)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   $40 = HEAP32[$3>>2]|0;
   $41 = (($40) + 4|0);
   $42 = HEAP32[$9>>2]|0;
   $43 = ($41>>>0)>($42>>>0);
   if ($43) {
    __ZN12CachedReader15UpdateReadCacheEPvj($3,$i$02,4);
   } else {
    $44 = Math_fround(HEAPF32[$40>>2]);
    HEAPF32[$i$02>>2] = $44;
    HEAP32[$3>>2] = $41;
   }
   $45 = (($i$02) + 4|0);
   __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($45,$this);
   $46 = (($i$02) + 8|0);
   $47 = ($46|0)==($38|0);
   if ($47) {
    break;
   } else {
    $i$02 = $46;
   }
  }
  STACKTOP = sp;return;
 } else {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
   $$pre3 = HEAP32[$3>>2]|0;
   $$pre4 = HEAP32[$9>>2]|0;
   $14 = $$pre3;$16 = $$pre4;
  } else {
   $12 = HEAP32[$7>>2]|0;
   HEAP32[$size>>2] = $12;
   HEAP32[$3>>2] = $8;
   $14 = $8;$16 = $10;
  }
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
   $$pre5 = HEAP32[$offset>>2]|0;
   $20 = $$pre5;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$3>>2] = $13;
   $20 = $17;
  }
  $18 = HEAP32[$size>>2]|0;
  $19 = $18 << 3;
  $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
  $22 = (($data) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)>(-1);
  if ($24) {
   $25 = HEAP32[$data>>2]|0;
   $26 = (($data) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$1>>2] = $27;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
   HEAP32[$data>>2] = 0;
  }
  $28 = $19 >> 3;
  $29 = (($data) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $28 | -2147483648;
  HEAP32[$22>>2] = $30;
  HEAP32[$data>>2] = $21;
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN13AnimationClip10FloatCurve8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 116|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*116)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip10FloatCurve8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (($this) + 88|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplIfELj4EEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 104|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$3>>2]|0;
  $$pre2$i$i$i = HEAP32[$6>>2]|0;
  $12 = $$pre$i$i$i;$14 = $$pre2$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($this) + 108|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,4);
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$3>>2] = $11;
 }
 __ZN17AnimationCurveTplIfE15InvalidateCacheEv($0);
 $16 = (($this) + 12|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$16,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $17 = (($this) + 24|0);
 $18 = HEAP32[$3>>2]|0;
 $19 = (($18) + 4|0);
 $20 = HEAP32[$6>>2]|0;
 $21 = ($19>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$17,4);
  $23 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb0EEEEvRT_($23,$transfer);
  STACKTOP = sp;return;
 } else {
  $22 = HEAP32[$18>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$3>>2] = $19;
  $23 = (($this) + 28|0);
  __ZN4PPtrI10MonoScriptE8TransferI18StreamedBinaryReadILb0EEEEvRT_($23,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN13AnimationClip12Vector3Curve8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 160|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*160)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip12Vector3Curve8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 132|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 148|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$3>>2]|0;
  $$pre2$i$i$i = HEAP32[$6>>2]|0;
  $12 = $$pre$i$i$i;$14 = $$pre2$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($this) + 152|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,4);
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$3>>2] = $11;
 }
 __ZN17AnimationCurveTplI8Vector3fE15InvalidateCacheEv($0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$size1>>2]|0;
  $36 = ($35|0)==(0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $37 = HEAP32[$data>>2]|0;
  $38 = ($35*40)|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$37,$38);
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre2 = HEAP32[$3>>2]|0;
  $$pre3 = HEAP32[$9>>2]|0;
  $14 = $$pre2;$16 = $$pre3;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre4 = HEAP32[$offset>>2]|0;
  $20 = $$pre4;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = ($18*40)|0;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = (($19|0) / 40)&-1;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN24CompressedAnimationCurve8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 84|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*84)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN24CompressedAnimationCurve8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 __ZN15PackedIntVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $1 = (($this) + 20|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
 }
 $9 = (($this) + 24|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIhNS2_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$9,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $10 = (($this) + 36|0);
 __ZN17PackedFloatVector8TransferI18StreamedBinaryReadILb0EEEEvRT_($10,$transfer);
 $11 = (($this) + 64|0);
 $12 = HEAP32[$2>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$5>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$11,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre2 = HEAP32[$5>>2]|0;
  $19 = $$pre;$21 = $$pre2;
 } else {
  $16 = HEAP32[$12>>2]|0;
  HEAP32[$11>>2] = $16;
  HEAP32[$2>>2] = $13;
  $19 = $13;$21 = $14;
 }
 $17 = (($this) + 68|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$17,4);
  STACKTOP = sp;return;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$2>>2] = $18;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN13AnimationClip15QuaternionCurve8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 192|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*192)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip15QuaternionCurve8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 164|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEEEvRT_17TransferMetaFlags($transfer,$1,0);
 $2 = (($this) + 180|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$3>>2]|0;
  $$pre2$i$i$i = HEAP32[$6>>2]|0;
  $12 = $$pre$i$i$i;$14 = $$pre2$i$i$i;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($this) + 184|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,4);
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$3>>2] = $11;
 }
 __ZN17AnimationCurveTplI11QuaternionfE15InvalidateCacheEv($0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$size1>>2]|0;
  $36 = ($35|0)==(0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $37 = HEAP32[$data>>2]|0;
  $38 = ($35*52)|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$37,$38);
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre2 = HEAP32[$3>>2]|0;
  $$pre3 = HEAP32[$9>>2]|0;
  $14 = $$pre2;$16 = $$pre3;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre4 = HEAP32[$offset>>2]|0;
  $20 = $$pre4;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = ($18*52)|0;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = (($19|0) / 52)&-1;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13AnimationClip8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$01$i = 0, $$1 = 0, $$12 = 0, $$byval_copy24 = 0, $$pr$pre = 0, $$pre$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i4 = 0, $$sum$i$i$i$i$i9 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i10 = 0, $$sum1$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $curveIter$0116$i = 0, $empty = 0, $empty1 = 0, $i$0$be$i = 0, $i$01$i = 0, $i$01$i50 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $m_AnimationType = 0;
 var $value = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy24 = sp + 272|0;
 $0 = sp + 268|0;
 $1 = sp + 264|0;
 $2 = sp + 260|0;
 $3 = sp + 256|0;
 $4 = sp + 252|0;
 $5 = sp + 248|0;
 $6 = sp + 244|0;
 $7 = sp + 240|0;
 $8 = sp + 236|0;
 $9 = sp + 232|0;
 $10 = sp + 228|0;
 $11 = sp + 224|0;
 $12 = sp + 220|0;
 $13 = sp + 216|0;
 $14 = sp + 204|0;
 $15 = sp + 192|0;
 $16 = sp + 180|0;
 $17 = sp + 84|0;
 $18 = sp;
 $19 = sp + 12|0;
 $20 = sp + 24|0;
 $21 = sp + 36|0;
 $22 = sp + 48|0;
 $23 = sp + 60|0;
 $24 = sp + 72|0;
 $25 = sp + 96|0;
 $26 = sp + 108|0;
 $27 = sp + 120|0;
 $28 = sp + 132|0;
 $29 = sp + 136|0;
 $empty = sp + 140|0;
 $empty1 = sp + 152|0;
 $value = sp + 164|0;
 $m_AnimationType = sp + 176|0;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,6);
 $30 = (($this) + 164|0);
 $31 = HEAP32[580544>>2]|0;
 $32 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766376,$31,$$byval_copy24,0)|0);
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = ($32|0)>(0);
  do {
   if ($34) {
    $35 = (($transfer) + 12|0);
    $36 = (($transfer) + 80|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + 12|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($transfer) + 16|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($transfer) + 28|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($transfer) + 32|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = Math_imul($45, $43)|0;
    $$sum$i$i$i$i$i = (($39) - ($46))|0;
    $47 = (($41) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$35>>2] = $47;
    $48 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($48)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $49 = (($41) + ($$sum1$i$i$i$i$i)|0);
     $50 = (($transfer) + 20|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($49>>>0)>($51>>>0);
     if (!($52)) {
      $53 = HEAP8[$47>>0]|0;
      HEAP8[$30>>0] = $53;
      $54 = HEAP32[$35>>2]|0;
      $55 = (($54) + 1|0);
      HEAP32[$35>>2] = $55;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($35,$30,1);
   } else {
    $56 = HEAP32[$$byval_copy24>>2]|0;
    $57 = ($56|0)==(0|0);
    if (!($57)) {
     (FUNCTION_TABLE_iii[$56 & 4095]($30,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $58 = (($this) + 84|0);
 $59 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766144,$31,$$byval_copy24,0)|0);
 $60 = ($59|0)==(0);
 if (!($60)) {
  $61 = ($59|0)>(0);
  do {
   if ($61) {
    $62 = (($transfer) + 12|0);
    $63 = (($transfer) + 80|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($64) + 12|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($transfer) + 16|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (($transfer) + 28|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($transfer) + 32|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = Math_imul($72, $70)|0;
    $$sum$i$i$i$i$i4 = (($66) - ($73))|0;
    $74 = (($68) + ($$sum$i$i$i$i$i4)|0);
    HEAP32[$62>>2] = $74;
    $75 = ($$sum$i$i$i$i$i4|0)<(0);
    if (!($75)) {
     $$sum1$i$i$i$i$i5 = (($$sum$i$i$i$i$i4) + 1)|0;
     $76 = (($68) + ($$sum1$i$i$i$i$i5)|0);
     $77 = (($transfer) + 20|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ($76>>>0)>($78>>>0);
     if (!($79)) {
      $80 = HEAP8[$74>>0]|0;
      HEAP8[$58>>0] = $80;
      $81 = HEAP32[$62>>2]|0;
      $82 = (($81) + 1|0);
      HEAP32[$62>>2] = $82;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($62,$58,1);
   } else {
    $83 = HEAP32[$$byval_copy24>>2]|0;
    $84 = ($83|0)==(0|0);
    if (!($84)) {
     (FUNCTION_TABLE_iii[$83 & 4095]($58,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $85 = (($this) + 85|0);
 $86 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766392,$31,$$byval_copy24,0)|0);
 $87 = ($86|0)==(0);
 if (!($87)) {
  $88 = ($86|0)>(0);
  do {
   if ($88) {
    $89 = (($transfer) + 12|0);
    $90 = (($transfer) + 80|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($91) + 12|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($transfer) + 16|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($transfer) + 28|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($transfer) + 32|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = Math_imul($99, $97)|0;
    $$sum$i$i$i$i$i9 = (($93) - ($100))|0;
    $101 = (($95) + ($$sum$i$i$i$i$i9)|0);
    HEAP32[$89>>2] = $101;
    $102 = ($$sum$i$i$i$i$i9|0)<(0);
    if (!($102)) {
     $$sum1$i$i$i$i$i10 = (($$sum$i$i$i$i$i9) + 1)|0;
     $103 = (($95) + ($$sum1$i$i$i$i$i10)|0);
     $104 = (($transfer) + 20|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = ($103>>>0)>($105>>>0);
     if (!($106)) {
      $107 = HEAP8[$101>>0]|0;
      HEAP8[$85>>0] = $107;
      $108 = HEAP32[$89>>2]|0;
      $109 = (($108) + 1|0);
      HEAP32[$89>>2] = $109;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($89,$85,1);
   } else {
    $110 = HEAP32[$$byval_copy24>>2]|0;
    $111 = ($110|0)==(0|0);
    if (!($111)) {
     (FUNCTION_TABLE_iii[$110 & 4095]($85,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $112 = HEAP8[$58>>0]|0;
 $113 = ($112<<24>>24)==(0);
 L37: do {
  if ($113) {
   $114 = (($this) + 92|0);
   $115 = HEAP32[580760>>2]|0;
   $116 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766416,$115,$$byval_copy24,1)|0);
   $117 = ($116|0)==(0);
   if (!($117)) {
    $118 = ($116|0)>(0);
    if ($118) {
     __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$114,0);
    } else {
     $119 = HEAP32[$$byval_copy24>>2]|0;
     $120 = ($119|0)==(0|0);
     if (!($120)) {
      (FUNCTION_TABLE_iii[$119 & 4095]($114,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
   HEAP32[$empty>>2] = 0;
   $121 = (($empty) + 4|0);
   HEAP32[$121>>2] = 0;
   $122 = (($empty) + 8|0);
   HEAP32[$122>>2] = 0;
   __THREW__ = 0;
   $123 = (invoke_iiiiii(192,($transfer|0),(766440|0),($115|0),($3|0),1)|0);
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   do {
    if (!($125)) {
     $126 = ($123|0)==(0);
     if (!($126)) {
      $127 = ($123|0)>(0);
      if ($127) {
       __THREW__ = 0;
       invoke_viii(2009,($transfer|0),($empty|0),0);
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        break;
       }
      } else {
       $130 = HEAP32[$3>>2]|0;
       $131 = ($130|0)==(0|0);
       if (!($131)) {
        __THREW__ = 0;
        (invoke_iii($130|0,($empty|0),($transfer|0))|0);
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if ($133) {
         break;
        }
       }
      }
      __THREW__ = 0;
      invoke_vi(3389,($transfer|0));
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       break;
      }
     }
     $136 = HEAP32[$empty>>2]|0;
     $137 = ($136|0)==(0|0);
     if ($137) {
      $264 = $115;
      break L37;
     }
     while(1) {
      $138 = HEAP32[$121>>2]|0;
      $139 = ($138|0)==($136|0);
      if ($139) {
       break;
      }
      $140 = (($138) + -84|0);
      HEAP32[$121>>2] = $140;
      __THREW__ = 0;
      invoke_vi(3690,($140|0));
      $141 = __THREW__; __THREW__ = 0;
      $142 = $141&1;
      if ($142) {
       label = 45;
       break;
      }
     }
     if ((label|0) == 45) {
      $143 = ___cxa_find_matching_catch()|0;
      $144 = tempRet0;
      ___cxa_call_unexpected(($143|0));
      // unreachable;
     }
     $145 = HEAP32[$empty>>2]|0;
     HEAP32[$29>>2] = 18;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$29+0>>2]|0;
     invoke_vii(2591,($145|0),($$byval_copy24|0));
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if (!($147)) {
      $264 = $115;
      break L37;
     }
     $148 = ___cxa_find_matching_catch()|0;
     $149 = tempRet0;
     ___cxa_call_unexpected(($148|0));
     // unreachable;
    }
   } while(0);
   $150 = ___cxa_find_matching_catch()|0;
   $151 = tempRet0;
   $152 = HEAP32[$empty>>2]|0;
   $153 = ($152|0)==(0|0);
   if ($153) {
    $$1 = $151;$$12 = $150;
    ___resumeException($$12|0);
    // unreachable;
   }
   while(1) {
    $154 = HEAP32[$121>>2]|0;
    $155 = ($154|0)==($152|0);
    if ($155) {
     break;
    }
    $156 = (($154) + -84|0);
    HEAP32[$121>>2] = $156;
    __THREW__ = 0;
    invoke_vi(3690,($156|0));
    $157 = __THREW__; __THREW__ = 0;
    $158 = $157&1;
    if ($158) {
     label = 51;
     break;
    }
   }
   if ((label|0) == 51) {
    $159 = ___cxa_find_matching_catch()|0;
    $160 = tempRet0;
    ___cxa_call_unexpected(($159|0));
    // unreachable;
   }
   $161 = HEAP32[$empty>>2]|0;
   HEAP32[$2>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($161|0),($$byval_copy24|0));
   $162 = __THREW__; __THREW__ = 0;
   $163 = $162&1;
   if ($163) {
    $164 = ___cxa_find_matching_catch()|0;
    $165 = tempRet0;
    ___cxa_call_unexpected(($164|0));
    // unreachable;
   } else {
    $$1 = $151;$$12 = $150;
    ___resumeException($$12|0);
    // unreachable;
   }
  } else {
   HEAP32[$empty1>>2] = 0;
   $166 = (($empty1) + 4|0);
   HEAP32[$166>>2] = 0;
   $167 = (($empty1) + 8|0);
   HEAP32[$167>>2] = 0;
   $168 = HEAP32[580760>>2]|0;
   __THREW__ = 0;
   $169 = (invoke_iiiiii(192,($transfer|0),(766416|0),($168|0),($$byval_copy24|0),1)|0);
   $170 = __THREW__; __THREW__ = 0;
   $171 = $170&1;
   L77: do {
    if ($171) {
     label = 69;
    } else {
     $172 = ($169|0)==(0);
     if (!($172)) {
      $173 = ($169|0)>(0);
      if ($173) {
       __THREW__ = 0;
       invoke_viii(2010,($transfer|0),($empty1|0),0);
       $174 = __THREW__; __THREW__ = 0;
       $175 = $174&1;
       if ($175) {
        label = 69;
        break;
       }
      } else {
       $176 = HEAP32[$$byval_copy24>>2]|0;
       $177 = ($176|0)==(0|0);
       if (!($177)) {
        __THREW__ = 0;
        (invoke_iii($176|0,($empty1|0),($transfer|0))|0);
        $178 = __THREW__; __THREW__ = 0;
        $179 = $178&1;
        if ($179) {
         label = 69;
         break;
        }
       }
      }
      __THREW__ = 0;
      invoke_vi(3389,($transfer|0));
      $180 = __THREW__; __THREW__ = 0;
      $181 = $180&1;
      if ($181) {
       label = 69;
       break;
      }
     }
     $182 = HEAP32[$transfer>>2]|0;
     $183 = $182 & 33554432;
     $184 = ($183|0)==(0);
     L87: do {
      if ($184) {
       HEAP32[$value>>2] = 0;
       $185 = (($value) + 4|0);
       HEAP32[$185>>2] = 0;
       $186 = (($value) + 8|0);
       HEAP32[$186>>2] = 0;
       __THREW__ = 0;
       $187 = (invoke_iiiiii(192,($transfer|0),(766440|0),($168|0),($1|0),1)|0);
       $188 = __THREW__; __THREW__ = 0;
       $189 = $188&1;
       L89: do {
        if ($189) {
         label = 71;
        } else {
         $190 = ($187|0)==(0);
         if (!($190)) {
          $191 = ($187|0)>(0);
          if ($191) {
           __THREW__ = 0;
           invoke_viii(2009,($transfer|0),($value|0),0);
           $192 = __THREW__; __THREW__ = 0;
           $193 = $192&1;
           if ($193) {
            label = 71;
            break;
           }
          } else {
           $194 = HEAP32[$1>>2]|0;
           $195 = ($194|0)==(0|0);
           if (!($195)) {
            __THREW__ = 0;
            (invoke_iii($194|0,($value|0),($transfer|0))|0);
            $196 = __THREW__; __THREW__ = 0;
            $197 = $196&1;
            if ($197) {
             label = 71;
             break;
            }
           }
          }
          __THREW__ = 0;
          invoke_vi(3389,($transfer|0));
          $198 = __THREW__; __THREW__ = 0;
          $199 = $198&1;
          if ($199) {
           label = 71;
           break;
          }
         }
         $220 = (($transfer) + 136|0);
         $221 = HEAP8[$220>>0]|0;
         $222 = ($221<<24>>24)==(0);
         L99: do {
          if ($222) {
           $$pr$pre = HEAP32[$value>>2]|0;
           $250 = $$pr$pre;
          } else {
           $223 = (($this) + 92|0);
           $224 = HEAP32[$185>>2]|0;
           $225 = HEAP32[$value>>2]|0;
           $226 = $224;
           $227 = $225;
           $228 = (($226) - ($227))|0;
           $229 = (($228|0) / 84)&-1;
           __THREW__ = 0;
           invoke_vii(3371,($223|0),($229|0));
           $230 = __THREW__; __THREW__ = 0;
           $231 = $230&1;
           if ($231) {
            label = 71;
            break L89;
           }
           $232 = HEAP32[$185>>2]|0;
           $233 = HEAP32[$value>>2]|0;
           $234 = ($232|0)==($233|0);
           if ($234) {
            $250 = $232;
           } else {
            $236 = $233;$i$01$i = 0;
            while(1) {
             $235 = (($236) + (($i$01$i*84)|0)|0);
             $237 = HEAP32[$223>>2]|0;
             $238 = (($237) + (($i$01$i*192)|0)|0);
             __THREW__ = 0;
             invoke_vii(3372,($235|0),($238|0));
             $239 = __THREW__; __THREW__ = 0;
             $240 = $239&1;
             if ($240) {
              break;
             }
             $241 = (($i$01$i) + 1)|0;
             $242 = HEAP32[$185>>2]|0;
             $243 = HEAP32[$value>>2]|0;
             $244 = $242;
             $245 = $243;
             $246 = (($244) - ($245))|0;
             $247 = (($246|0) / 84)&-1;
             $248 = ($241>>>0)<($247>>>0);
             if ($248) {
              $236 = $243;$i$01$i = $241;
             } else {
              $250 = $243;
              break L99;
             }
            }
            $202 = ___cxa_find_matching_catch()|0;
            $203 = tempRet0;
            $lpad$phi$index = $202;$lpad$phi$index2 = $203;
            break L89;
           }
          }
         } while(0);
         $249 = ($250|0)==(0|0);
         if ($249) {
          break L87;
         }
         while(1) {
          $251 = HEAP32[$185>>2]|0;
          $252 = ($251|0)==($250|0);
          if ($252) {
           break;
          }
          $253 = (($251) + -84|0);
          HEAP32[$185>>2] = $253;
          __THREW__ = 0;
          invoke_vi(3690,($253|0));
          $254 = __THREW__; __THREW__ = 0;
          $255 = $254&1;
          if ($255) {
           label = 88;
           break;
          }
         }
         if ((label|0) == 88) {
          $256 = ___cxa_find_matching_catch()|0;
          $257 = tempRet0;
          ___cxa_call_unexpected(($256|0));
          // unreachable;
         }
         $258 = HEAP32[$value>>2]|0;
         HEAP32[$28>>2] = 18;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$28+0>>2]|0;
         invoke_vii(2591,($258|0),($$byval_copy24|0));
         $259 = __THREW__; __THREW__ = 0;
         $260 = $259&1;
         if (!($260)) {
          break L87;
         }
         $261 = ___cxa_find_matching_catch()|0;
         $262 = tempRet0;
         ___cxa_call_unexpected(($261|0));
         // unreachable;
        }
       } while(0);
       if ((label|0) == 71) {
        $204 = ___cxa_find_matching_catch()|0;
        $205 = tempRet0;
        $lpad$phi$index = $204;$lpad$phi$index2 = $205;
       }
       $206 = HEAP32[$value>>2]|0;
       $207 = ($206|0)==(0|0);
       if ($207) {
        $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
        break L77;
       }
       while(1) {
        $208 = HEAP32[$185>>2]|0;
        $209 = ($208|0)==($206|0);
        if ($209) {
         break;
        }
        $210 = (($208) + -84|0);
        HEAP32[$185>>2] = $210;
        __THREW__ = 0;
        invoke_vi(3690,($210|0));
        $211 = __THREW__; __THREW__ = 0;
        $212 = $211&1;
        if ($212) {
         label = 75;
         break;
        }
       }
       if ((label|0) == 75) {
        $213 = ___cxa_find_matching_catch()|0;
        $214 = tempRet0;
        ___cxa_call_unexpected(($213|0));
        // unreachable;
       }
       $215 = HEAP32[$value>>2]|0;
       HEAP32[$0>>2] = 18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($215|0),($$byval_copy24|0));
       $216 = __THREW__; __THREW__ = 0;
       $217 = $216&1;
       if (!($217)) {
        $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
        break L77;
       }
       $218 = ___cxa_find_matching_catch()|0;
       $219 = tempRet0;
       ___cxa_call_unexpected(($218|0));
       // unreachable;
      }
     } while(0);
     __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
     $264 = $168;
     break L37;
    }
   } while(0);
   if ((label|0) == 69) {
    $200 = ___cxa_find_matching_catch()|0;
    $201 = tempRet0;
    $$0 = $201;$$01 = $200;
   }
   __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
   $$1 = $$0;$$12 = $$01;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $263 = (($this) + 104|0);
 $265 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766472,$264,$$byval_copy24,1)|0);
 $266 = ($265|0)==(0);
 if (!($266)) {
  $267 = ($265|0)>(0);
  if ($267) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$263,0);
  } else {
   $268 = HEAP32[$$byval_copy24>>2]|0;
   $269 = ($268|0)==(0|0);
   if (!($269)) {
    (FUNCTION_TABLE_iii[$268 & 4095]($263,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $270 = (($this) + 116|0);
 $271 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766496,$264,$$byval_copy24,1)|0);
 $272 = ($271|0)==(0);
 if (!($272)) {
  $273 = ($271|0)>(0);
  if ($273) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$270,0);
  } else {
   $274 = HEAP32[$$byval_copy24>>2]|0;
   $275 = ($274|0)==(0|0);
   if (!($275)) {
    (FUNCTION_TABLE_iii[$274 & 4095]($270,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $276 = (($this) + 128|0);
 $277 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766512,$264,$$byval_copy24,1)|0);
 $278 = ($277|0)==(0);
 if (!($278)) {
  $279 = ($277|0)>(0);
  if ($279) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$276,0);
  } else {
   $280 = HEAP32[$$byval_copy24>>2]|0;
   $281 = ($280|0)==(0|0);
   if (!($281)) {
    (FUNCTION_TABLE_iii[$280 & 4095]($276,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $282 = (($this) + 140|0);
 $283 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766528,$264,$$byval_copy24,1)|0);
 $284 = ($283|0)==(0);
 if (!($284)) {
  $285 = ($283|0)>(0);
  if ($285) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$282,0);
  } else {
   $286 = HEAP32[$$byval_copy24>>2]|0;
   $287 = ($286|0)==(0|0);
   if (!($287)) {
    (FUNCTION_TABLE_iii[$286 & 4095]($282,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $288 = (($this) + 80|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$288,766544,0);
 $289 = (($this) + 88|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$289,766560,0);
 $290 = (($this) + 216|0);
 $291 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766576,768472,$$byval_copy24,1)|0);
 $292 = ($291|0)==(0);
 if (!($292)) {
  $293 = ($291|0)>(0);
  if ($293) {
   __ZN4AABB8TransferI14SafeBinaryReadEEvRT_($290,$transfer);
  } else {
   $294 = HEAP32[$$byval_copy24>>2]|0;
   $295 = ($294|0)==(0|0);
   if (!($295)) {
    (FUNCTION_TABLE_iii[$294 & 4095]($290,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $296 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,4)|0);
 L172: do {
  if ($296) {
   $297 = HEAP32[$this>>2]|0;
   $298 = (($297) + 112|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = (FUNCTION_TABLE_ii[$299 & 4095]($this)|0);
   if (!($300)) {
    $301 = (($this) + 132|0);
    $302 = HEAP32[$301>>2]|0;
    $303 = HEAP32[$276>>2]|0;
    $304 = ($302|0)==($303|0);
    if (!($304)) {
     $305 = (($14) + 1|0);
     $306 = (($14) + 10|0);
     $307 = (($15) + 1|0);
     $308 = (($15) + 8|0);
     $309 = (($16) + 1|0);
     $310 = (($16) + 10|0);
     $311 = (($17) + 1|0);
     $312 = (($17) + 8|0);
     $313 = (($18) + 1|0);
     $314 = (($18) + 10|0);
     $315 = (($19) + 1|0);
     $316 = (($19) + 8|0);
     $317 = (($20) + 1|0);
     $318 = (($20) + 10|0);
     $319 = (($21) + 1|0);
     $320 = (($21) + 8|0);
     $321 = (($22) + 1|0);
     $322 = (($22) + 10|0);
     $323 = (($23) + 1|0);
     $324 = (($23) + 8|0);
     $325 = (($24) + 1|0);
     $326 = (($24) + 10|0);
     $327 = (($25) + 1|0);
     $328 = (($25) + 8|0);
     $329 = (($26) + 1|0);
     $330 = (($26) + 10|0);
     $331 = (($27) + 1|0);
     $332 = (($27) + 8|0);
     $334 = $303;$curveIter$0116$i = 0;
     L176: while(1) {
      $333 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 24|0);
      $335 = HEAP32[$333>>2]|0;
      $336 = ($335|0)==(95);
      L178: do {
       if ($336) {
        $337 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 12|0);
        HEAP8[$14>>0] = 18;
        dest=$305+0|0; src=767824+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        HEAP8[$306>>0] = 0;
        $338 = HEAP8[$337>>0]|0;
        $339 = $338 & 1;
        $340 = ($339<<24>>24)==(0);
        if ($340) {
         $343 = $338&255;
         $344 = $343 >>> 1;
         $346 = $344;
        } else {
         $341 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
         $342 = HEAP32[$341>>2]|0;
         $346 = $342;
        }
        $345 = ($346|0)==(9);
        do {
         if ($345) {
          if ($340) {
           $351 = (($337) + 1|0);
           $352 = $338&255;
           $353 = $352 >>> 1;
           $354 = $351;$355 = $353;
          } else {
           $347 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 20|0);
           $348 = HEAP32[$347>>2]|0;
           $349 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
           $350 = HEAP32[$349>>2]|0;
           $354 = $348;$355 = $350;
          }
          $356 = (_strncmp($354,$305,$355)|0);
          $357 = ($356|0)==(0);
          if (!($357)) {
           break;
          }
          HEAP8[$15>>0] = 14;
          ;HEAP8[$307+0>>0]=HEAP8[767840+0>>0]|0;HEAP8[$307+1>>0]=HEAP8[767840+1>>0]|0;HEAP8[$307+2>>0]=HEAP8[767840+2>>0]|0;HEAP8[$307+3>>0]=HEAP8[767840+3>>0]|0;HEAP8[$307+4>>0]=HEAP8[767840+4>>0]|0;HEAP8[$307+5>>0]=HEAP8[767840+5>>0]|0;HEAP8[$307+6>>0]=HEAP8[767840+6>>0]|0;
          HEAP8[$308>>0] = 0;
          __THREW__ = 0;
          (invoke_iii(2359,($337|0),($15|0))|0);
          $358 = __THREW__; __THREW__ = 0;
          $359 = $358&1;
          if ($359) {
           label = 140;
           break L176;
          }
          $360 = HEAP8[$15>>0]|0;
          $361 = $360 & 1;
          $362 = ($361<<24>>24)==(0);
          if ($362) {
           break L178;
          }
          $363 = HEAP32[$308>>2]|0;
          HEAP32[$12>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$12+0>>2]|0;
          invoke_vii(2591,($363|0),($$byval_copy24|0));
          $364 = __THREW__; __THREW__ = 0;
          $365 = $364&1;
          if ($365) {
           label = 139;
           break L176;
          } else {
           break L178;
          }
         }
        } while(0);
        HEAP8[$16>>0] = 18;
        dest=$309+0|0; src=767848+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        HEAP8[$310>>0] = 0;
        if ($340) {
         $380 = $338&255;
         $381 = $380 >>> 1;
         $383 = $381;
        } else {
         $378 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
         $379 = HEAP32[$378>>2]|0;
         $383 = $379;
        }
        $382 = ($383|0)==(9);
        do {
         if ($382) {
          if ($340) {
           $388 = (($337) + 1|0);
           $389 = $338&255;
           $390 = $389 >>> 1;
           $391 = $388;$392 = $390;
          } else {
           $384 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 20|0);
           $385 = HEAP32[$384>>2]|0;
           $386 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
           $387 = HEAP32[$386>>2]|0;
           $391 = $385;$392 = $387;
          }
          $393 = (_strncmp($391,$309,$392)|0);
          $394 = ($393|0)==(0);
          if (!($394)) {
           break;
          }
          HEAP8[$17>>0] = 14;
          ;HEAP8[$311+0>>0]=HEAP8[767864+0>>0]|0;HEAP8[$311+1>>0]=HEAP8[767864+1>>0]|0;HEAP8[$311+2>>0]=HEAP8[767864+2>>0]|0;HEAP8[$311+3>>0]=HEAP8[767864+3>>0]|0;HEAP8[$311+4>>0]=HEAP8[767864+4>>0]|0;HEAP8[$311+5>>0]=HEAP8[767864+5>>0]|0;HEAP8[$311+6>>0]=HEAP8[767864+6>>0]|0;
          HEAP8[$312>>0] = 0;
          __THREW__ = 0;
          (invoke_iii(2359,($337|0),($17|0))|0);
          $395 = __THREW__; __THREW__ = 0;
          $396 = $395&1;
          if ($396) {
           label = 155;
           break L176;
          }
          $397 = HEAP8[$17>>0]|0;
          $398 = $397 & 1;
          $399 = ($398<<24>>24)==(0);
          if ($399) {
           break L178;
          }
          $400 = HEAP32[$312>>2]|0;
          HEAP32[$10>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$10+0>>2]|0;
          invoke_vii(2591,($400|0),($$byval_copy24|0));
          $401 = __THREW__; __THREW__ = 0;
          $402 = $401&1;
          if ($402) {
           label = 154;
           break L176;
          } else {
           break L178;
          }
         }
        } while(0);
        HEAP8[$18>>0] = 18;
        dest=$313+0|0; src=767872+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        HEAP8[$314>>0] = 0;
        if ($340) {
         $417 = $338&255;
         $418 = $417 >>> 1;
         $420 = $418;
        } else {
         $415 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
         $416 = HEAP32[$415>>2]|0;
         $420 = $416;
        }
        $419 = ($420|0)==(9);
        do {
         if ($419) {
          if ($340) {
           $425 = (($337) + 1|0);
           $426 = $338&255;
           $427 = $426 >>> 1;
           $428 = $425;$429 = $427;
          } else {
           $421 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 20|0);
           $422 = HEAP32[$421>>2]|0;
           $423 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
           $424 = HEAP32[$423>>2]|0;
           $428 = $422;$429 = $424;
          }
          $430 = (_strncmp($428,$313,$429)|0);
          $431 = ($430|0)==(0);
          if (!($431)) {
           break;
          }
          HEAP8[$19>>0] = 14;
          ;HEAP8[$315+0>>0]=HEAP8[767888+0>>0]|0;HEAP8[$315+1>>0]=HEAP8[767888+1>>0]|0;HEAP8[$315+2>>0]=HEAP8[767888+2>>0]|0;HEAP8[$315+3>>0]=HEAP8[767888+3>>0]|0;HEAP8[$315+4>>0]=HEAP8[767888+4>>0]|0;HEAP8[$315+5>>0]=HEAP8[767888+5>>0]|0;HEAP8[$315+6>>0]=HEAP8[767888+6>>0]|0;
          HEAP8[$316>>0] = 0;
          __THREW__ = 0;
          (invoke_iii(2359,($337|0),($19|0))|0);
          $432 = __THREW__; __THREW__ = 0;
          $433 = $432&1;
          if ($433) {
           label = 170;
           break L176;
          }
          $434 = HEAP8[$19>>0]|0;
          $435 = $434 & 1;
          $436 = ($435<<24>>24)==(0);
          if ($436) {
           break L178;
          }
          $437 = HEAP32[$316>>2]|0;
          HEAP32[$8>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$8+0>>2]|0;
          invoke_vii(2591,($437|0),($$byval_copy24|0));
          $438 = __THREW__; __THREW__ = 0;
          $439 = $438&1;
          if ($439) {
           label = 169;
           break L176;
          } else {
           break L178;
          }
         }
        } while(0);
        HEAP8[$20>>0] = 18;
        dest=$317+0|0; src=767896+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        HEAP8[$318>>0] = 0;
        if ($340) {
         $454 = $338&255;
         $455 = $454 >>> 1;
         $457 = $455;
        } else {
         $452 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
         $453 = HEAP32[$452>>2]|0;
         $457 = $453;
        }
        $456 = ($457|0)==(9);
        do {
         if ($456) {
          if ($340) {
           $462 = (($337) + 1|0);
           $463 = $338&255;
           $464 = $463 >>> 1;
           $465 = $462;$466 = $464;
          } else {
           $458 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 20|0);
           $459 = HEAP32[$458>>2]|0;
           $460 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
           $461 = HEAP32[$460>>2]|0;
           $465 = $459;$466 = $461;
          }
          $467 = (_strncmp($465,$317,$466)|0);
          $468 = ($467|0)==(0);
          if (!($468)) {
           break;
          }
          HEAP8[$21>>0] = 14;
          ;HEAP8[$319+0>>0]=HEAP8[767912+0>>0]|0;HEAP8[$319+1>>0]=HEAP8[767912+1>>0]|0;HEAP8[$319+2>>0]=HEAP8[767912+2>>0]|0;HEAP8[$319+3>>0]=HEAP8[767912+3>>0]|0;HEAP8[$319+4>>0]=HEAP8[767912+4>>0]|0;HEAP8[$319+5>>0]=HEAP8[767912+5>>0]|0;HEAP8[$319+6>>0]=HEAP8[767912+6>>0]|0;
          HEAP8[$320>>0] = 0;
          __THREW__ = 0;
          (invoke_iii(2359,($337|0),($21|0))|0);
          $469 = __THREW__; __THREW__ = 0;
          $470 = $469&1;
          if ($470) {
           label = 185;
           break L176;
          }
          $471 = HEAP8[$21>>0]|0;
          $472 = $471 & 1;
          $473 = ($472<<24>>24)==(0);
          if ($473) {
           break L178;
          }
          $474 = HEAP32[$320>>2]|0;
          HEAP32[$6>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$6+0>>2]|0;
          invoke_vii(2591,($474|0),($$byval_copy24|0));
          $475 = __THREW__; __THREW__ = 0;
          $476 = $475&1;
          if ($476) {
           label = 184;
           break L176;
          } else {
           break L178;
          }
         }
        } while(0);
        HEAP8[$22>>0] = 18;
        dest=$321+0|0; src=767920+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        HEAP8[$322>>0] = 0;
        if ($340) {
         $491 = $338&255;
         $492 = $491 >>> 1;
         $494 = $492;
        } else {
         $489 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
         $490 = HEAP32[$489>>2]|0;
         $494 = $490;
        }
        $493 = ($494|0)==(9);
        do {
         if ($493) {
          if ($340) {
           $499 = (($337) + 1|0);
           $500 = $338&255;
           $501 = $500 >>> 1;
           $502 = $499;$503 = $501;
          } else {
           $495 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 20|0);
           $496 = HEAP32[$495>>2]|0;
           $497 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
           $498 = HEAP32[$497>>2]|0;
           $502 = $496;$503 = $498;
          }
          $504 = (_strncmp($502,$321,$503)|0);
          $505 = ($504|0)==(0);
          if (!($505)) {
           break;
          }
          HEAP8[$23>>0] = 14;
          ;HEAP8[$323+0>>0]=HEAP8[767936+0>>0]|0;HEAP8[$323+1>>0]=HEAP8[767936+1>>0]|0;HEAP8[$323+2>>0]=HEAP8[767936+2>>0]|0;HEAP8[$323+3>>0]=HEAP8[767936+3>>0]|0;HEAP8[$323+4>>0]=HEAP8[767936+4>>0]|0;HEAP8[$323+5>>0]=HEAP8[767936+5>>0]|0;HEAP8[$323+6>>0]=HEAP8[767936+6>>0]|0;
          HEAP8[$324>>0] = 0;
          __THREW__ = 0;
          (invoke_iii(2359,($337|0),($23|0))|0);
          $506 = __THREW__; __THREW__ = 0;
          $507 = $506&1;
          if ($507) {
           label = 200;
           break L176;
          }
          $508 = HEAP8[$23>>0]|0;
          $509 = $508 & 1;
          $510 = ($509<<24>>24)==(0);
          if ($510) {
           break L178;
          }
          $511 = HEAP32[$324>>2]|0;
          HEAP32[$4>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$4+0>>2]|0;
          invoke_vii(2591,($511|0),($$byval_copy24|0));
          $512 = __THREW__; __THREW__ = 0;
          $513 = $512&1;
          if ($513) {
           label = 199;
           break L176;
          } else {
           break L178;
          }
         }
        } while(0);
        HEAP8[$24>>0] = 18;
        dest=$325+0|0; src=767944+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        HEAP8[$326>>0] = 0;
        if ($340) {
         $528 = $338&255;
         $529 = $528 >>> 1;
         $531 = $529;
        } else {
         $526 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
         $527 = HEAP32[$526>>2]|0;
         $531 = $527;
        }
        $530 = ($531|0)==(9);
        do {
         if ($530) {
          if ($340) {
           $536 = (($337) + 1|0);
           $537 = $338&255;
           $538 = $537 >>> 1;
           $539 = $536;$540 = $538;
          } else {
           $532 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 20|0);
           $533 = HEAP32[$532>>2]|0;
           $534 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
           $535 = HEAP32[$534>>2]|0;
           $539 = $533;$540 = $535;
          }
          $541 = (_strncmp($539,$325,$540)|0);
          $542 = ($541|0)==(0);
          if (!($542)) {
           break;
          }
          HEAP8[$25>>0] = 14;
          ;HEAP8[$327+0>>0]=HEAP8[767960+0>>0]|0;HEAP8[$327+1>>0]=HEAP8[767960+1>>0]|0;HEAP8[$327+2>>0]=HEAP8[767960+2>>0]|0;HEAP8[$327+3>>0]=HEAP8[767960+3>>0]|0;HEAP8[$327+4>>0]=HEAP8[767960+4>>0]|0;HEAP8[$327+5>>0]=HEAP8[767960+5>>0]|0;HEAP8[$327+6>>0]=HEAP8[767960+6>>0]|0;
          HEAP8[$328>>0] = 0;
          __THREW__ = 0;
          (invoke_iii(2359,($337|0),($25|0))|0);
          $543 = __THREW__; __THREW__ = 0;
          $544 = $543&1;
          if ($544) {
           label = 215;
           break L176;
          }
          $545 = HEAP8[$25>>0]|0;
          $546 = $545 & 1;
          $547 = ($546<<24>>24)==(0);
          if ($547) {
           break L178;
          }
          $548 = HEAP32[$328>>2]|0;
          HEAP32[$2>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;
          invoke_vii(2591,($548|0),($$byval_copy24|0));
          $549 = __THREW__; __THREW__ = 0;
          $550 = $549&1;
          if ($550) {
           label = 214;
           break L176;
          } else {
           break L178;
          }
         }
        } while(0);
        HEAP8[$26>>0] = 18;
        dest=$329+0|0; src=767968+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        HEAP8[$330>>0] = 0;
        if ($340) {
         $565 = $338&255;
         $566 = $565 >>> 1;
         $568 = $566;
        } else {
         $563 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
         $564 = HEAP32[$563>>2]|0;
         $568 = $564;
        }
        $567 = ($568|0)==(9);
        if (!($567)) {
         break;
        }
        if ($340) {
         $573 = (($337) + 1|0);
         $574 = $338&255;
         $575 = $574 >>> 1;
         $576 = $573;$577 = $575;
        } else {
         $569 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 20|0);
         $570 = HEAP32[$569>>2]|0;
         $571 = ((($334) + (($curveIter$0116$i*116)|0)|0) + 16|0);
         $572 = HEAP32[$571>>2]|0;
         $576 = $570;$577 = $572;
        }
        $578 = (_strncmp($576,$329,$577)|0);
        $579 = ($578|0)==(0);
        if (!($579)) {
         break;
        }
        HEAP8[$27>>0] = 14;
        ;HEAP8[$331+0>>0]=HEAP8[767984+0>>0]|0;HEAP8[$331+1>>0]=HEAP8[767984+1>>0]|0;HEAP8[$331+2>>0]=HEAP8[767984+2>>0]|0;HEAP8[$331+3>>0]=HEAP8[767984+3>>0]|0;HEAP8[$331+4>>0]=HEAP8[767984+4>>0]|0;HEAP8[$331+5>>0]=HEAP8[767984+5>>0]|0;HEAP8[$331+6>>0]=HEAP8[767984+6>>0]|0;
        HEAP8[$332>>0] = 0;
        __THREW__ = 0;
        (invoke_iii(2359,($337|0),($27|0))|0);
        $580 = __THREW__; __THREW__ = 0;
        $581 = $580&1;
        if ($581) {
         label = 230;
         break L176;
        }
        $582 = HEAP8[$27>>0]|0;
        $583 = $582 & 1;
        $584 = ($583<<24>>24)==(0);
        if ($584) {
         break;
        }
        $585 = HEAP32[$332>>2]|0;
        HEAP32[$1>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($585|0),($$byval_copy24|0));
        $586 = __THREW__; __THREW__ = 0;
        $587 = $586&1;
        if ($587) {
         label = 229;
         break L176;
        }
       }
      } while(0);
      $600 = (($curveIter$0116$i) + 1)|0;
      $601 = HEAP32[$301>>2]|0;
      $602 = HEAP32[$276>>2]|0;
      $603 = $601;
      $604 = $602;
      $605 = (($603) - ($604))|0;
      $606 = (($605|0) / 116)&-1;
      $607 = ($600>>>0)<($606>>>0);
      if ($607) {
       $334 = $602;$curveIter$0116$i = $600;
      } else {
       break L172;
      }
     }
     switch (label|0) {
      case 139: {
       $366 = ___cxa_find_matching_catch()|0;
       $367 = tempRet0;
       ___cxa_call_unexpected(($366|0));
       // unreachable;
       break;
      }
      case 140: {
       $368 = ___cxa_find_matching_catch()|0;
       $369 = tempRet0;
       $370 = HEAP8[$15>>0]|0;
       $371 = $370 & 1;
       $372 = ($371<<24>>24)==(0);
       if ($372) {
        $$0$i = $369;$$01$i = $368;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $373 = HEAP32[$308>>2]|0;
       HEAP32[$11>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$11+0>>2]|0;
       invoke_vii(2591,($373|0),($$byval_copy24|0));
       $374 = __THREW__; __THREW__ = 0;
       $375 = $374&1;
       if ($375) {
        $376 = ___cxa_find_matching_catch()|0;
        $377 = tempRet0;
        ___cxa_call_unexpected(($376|0));
        // unreachable;
       } else {
        $$0$i = $369;$$01$i = $368;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       break;
      }
      case 154: {
       $403 = ___cxa_find_matching_catch()|0;
       $404 = tempRet0;
       ___cxa_call_unexpected(($403|0));
       // unreachable;
       break;
      }
      case 155: {
       $405 = ___cxa_find_matching_catch()|0;
       $406 = tempRet0;
       $407 = HEAP8[$17>>0]|0;
       $408 = $407 & 1;
       $409 = ($408<<24>>24)==(0);
       if ($409) {
        $$0$i = $406;$$01$i = $405;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $410 = HEAP32[$312>>2]|0;
       HEAP32[$9>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$9+0>>2]|0;
       invoke_vii(2591,($410|0),($$byval_copy24|0));
       $411 = __THREW__; __THREW__ = 0;
       $412 = $411&1;
       if ($412) {
        $413 = ___cxa_find_matching_catch()|0;
        $414 = tempRet0;
        ___cxa_call_unexpected(($413|0));
        // unreachable;
       } else {
        $$0$i = $406;$$01$i = $405;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       break;
      }
      case 169: {
       $440 = ___cxa_find_matching_catch()|0;
       $441 = tempRet0;
       ___cxa_call_unexpected(($440|0));
       // unreachable;
       break;
      }
      case 170: {
       $442 = ___cxa_find_matching_catch()|0;
       $443 = tempRet0;
       $444 = HEAP8[$19>>0]|0;
       $445 = $444 & 1;
       $446 = ($445<<24>>24)==(0);
       if ($446) {
        $$0$i = $443;$$01$i = $442;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $447 = HEAP32[$316>>2]|0;
       HEAP32[$7>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$7+0>>2]|0;
       invoke_vii(2591,($447|0),($$byval_copy24|0));
       $448 = __THREW__; __THREW__ = 0;
       $449 = $448&1;
       if ($449) {
        $450 = ___cxa_find_matching_catch()|0;
        $451 = tempRet0;
        ___cxa_call_unexpected(($450|0));
        // unreachable;
       } else {
        $$0$i = $443;$$01$i = $442;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       break;
      }
      case 184: {
       $477 = ___cxa_find_matching_catch()|0;
       $478 = tempRet0;
       ___cxa_call_unexpected(($477|0));
       // unreachable;
       break;
      }
      case 185: {
       $479 = ___cxa_find_matching_catch()|0;
       $480 = tempRet0;
       $481 = HEAP8[$21>>0]|0;
       $482 = $481 & 1;
       $483 = ($482<<24>>24)==(0);
       if ($483) {
        $$0$i = $480;$$01$i = $479;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $484 = HEAP32[$320>>2]|0;
       HEAP32[$5>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$5+0>>2]|0;
       invoke_vii(2591,($484|0),($$byval_copy24|0));
       $485 = __THREW__; __THREW__ = 0;
       $486 = $485&1;
       if ($486) {
        $487 = ___cxa_find_matching_catch()|0;
        $488 = tempRet0;
        ___cxa_call_unexpected(($487|0));
        // unreachable;
       } else {
        $$0$i = $480;$$01$i = $479;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       break;
      }
      case 199: {
       $514 = ___cxa_find_matching_catch()|0;
       $515 = tempRet0;
       ___cxa_call_unexpected(($514|0));
       // unreachable;
       break;
      }
      case 200: {
       $516 = ___cxa_find_matching_catch()|0;
       $517 = tempRet0;
       $518 = HEAP8[$23>>0]|0;
       $519 = $518 & 1;
       $520 = ($519<<24>>24)==(0);
       if ($520) {
        $$0$i = $517;$$01$i = $516;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $521 = HEAP32[$324>>2]|0;
       HEAP32[$3>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$3+0>>2]|0;
       invoke_vii(2591,($521|0),($$byval_copy24|0));
       $522 = __THREW__; __THREW__ = 0;
       $523 = $522&1;
       if ($523) {
        $524 = ___cxa_find_matching_catch()|0;
        $525 = tempRet0;
        ___cxa_call_unexpected(($524|0));
        // unreachable;
       } else {
        $$0$i = $517;$$01$i = $516;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       break;
      }
      case 214: {
       $551 = ___cxa_find_matching_catch()|0;
       $552 = tempRet0;
       ___cxa_call_unexpected(($551|0));
       // unreachable;
       break;
      }
      case 215: {
       $553 = ___cxa_find_matching_catch()|0;
       $554 = tempRet0;
       $555 = HEAP8[$25>>0]|0;
       $556 = $555 & 1;
       $557 = ($556<<24>>24)==(0);
       if ($557) {
        $$0$i = $554;$$01$i = $553;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $558 = HEAP32[$328>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($558|0),($$byval_copy24|0));
       $559 = __THREW__; __THREW__ = 0;
       $560 = $559&1;
       if ($560) {
        $561 = ___cxa_find_matching_catch()|0;
        $562 = tempRet0;
        ___cxa_call_unexpected(($561|0));
        // unreachable;
       } else {
        $$0$i = $554;$$01$i = $553;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       break;
      }
      case 229: {
       $588 = ___cxa_find_matching_catch()|0;
       $589 = tempRet0;
       ___cxa_call_unexpected(($588|0));
       // unreachable;
       break;
      }
      case 230: {
       $590 = ___cxa_find_matching_catch()|0;
       $591 = tempRet0;
       $592 = HEAP8[$27>>0]|0;
       $593 = $592 & 1;
       $594 = ($593<<24>>24)==(0);
       if ($594) {
        $$0$i = $591;$$01$i = $590;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       $595 = HEAP32[$332>>2]|0;
       HEAP32[$13>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$13+0>>2]|0;
       invoke_vii(2591,($595|0),($$byval_copy24|0));
       $596 = __THREW__; __THREW__ = 0;
       $597 = $596&1;
       if ($597) {
        $598 = ___cxa_find_matching_catch()|0;
        $599 = tempRet0;
        ___cxa_call_unexpected(($598|0));
        // unreachable;
       } else {
        $$0$i = $591;$$01$i = $590;
        ___resumeException($$01$i|0);
        // unreachable;
       }
       break;
      }
     }
    }
   }
  }
 } while(0);
 $608 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,5)|0);
 if ($608) {
  HEAP32[$m_AnimationType>>2] = 1;
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$m_AnimationType,766592,0);
  $609 = HEAP32[$m_AnimationType>>2]|0;
  $610 = ($609|0)==(1);
  $611 = $610&1;
  HEAP8[$30>>0] = $611;
 }
 $612 = (($this) + 48|0);
 $613 = (($transfer) + 4|0);
 HEAP32[$613>>2] = $612;
 $614 = (($this) + 168|0);
 $615 = (($this) + 172|0);
 __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE14SafeBinaryReadEvRPT_PKcRjS8_RT0_($614,766608,$615,766624,$transfer);
 $616 = (($this) + 176|0);
 $617 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766648,768208,$$byval_copy24,1)|0);
 $618 = ($617|0)==(0);
 if (!($618)) {
  $619 = ($617|0)>(0);
  if ($619) {
   __ZN11UnityEngine9Animation28AnimationClipBindingConstant8TransferI14SafeBinaryReadEEvRT_($616,$transfer);
  } else {
   $620 = HEAP32[$$byval_copy24>>2]|0;
   $621 = ($620|0)==(0|0);
   if (!($621)) {
    (FUNCTION_TABLE_iii[$620 & 4095]($616,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $622 = HEAP32[$614>>2]|0;
 $623 = ($622|0)==(0|0);
 if (!($623)) {
  $624 = (($622) + 1040|0);
  $625 = HEAP32[$624>>2]|0;
  $626 = ($625|0)==(0);
  if (!($626)) {
   $627 = $624;
   $628 = (($625) + ($627))|0;
   $629 = $628;
   $630 = (($629) + 56|0);
   $631 = HEAP32[$630>>2]|0;
   $632 = ($631|0)==(0);
   if (!($632)) {
    $633 = $630;
    $634 = (($631) + ($633))|0;
    $635 = $634;
    $636 = HEAP32[$635>>2]|0;
    $637 = ($636|0)==(0);
    if (!($637)) {
     $638 = (($635) + 4|0);
     $639 = $638;
     $640 = (($this) + 184|0);
     $641 = (($this) + 188|0);
     $642 = (($this) + 180|0);
     $i$01$i50 = 0;
     while(1) {
      $643 = HEAP32[$638>>2]|0;
      $644 = (($643) + ($639))|0;
      $645 = $644;
      $646 = (($645) + ($i$01$i50<<4)|0);
      $647 = HEAP32[$646>>2]|0;
      $648 = ((($645) + ($i$01$i50<<4)|0) + 4|0);
      $649 = HEAP32[$648>>2]|0;
      $650 = HEAP32[$640>>2]|0;
      $651 = (($650) + 1)|0;
      HEAP32[$640>>2] = $651;
      $652 = HEAP32[$641>>2]|0;
      $653 = $652 & 2147483647;
      $654 = ($651>>>0)>($653>>>0);
      if ($654) {
       $655 = $652 << 1;
       $656 = ($655|0)==(0);
       $657 = $656 ? 1 : $655;
       $658 = ($653>>>0)<($657>>>0);
       do {
        if ($658) {
         $659 = ($652|0)>(-1);
         if ($659) {
          HEAP32[$641>>2] = $657;
          $660 = HEAP32[$616>>2]|0;
          $661 = $657 << 4;
          $662 = HEAP32[$642>>2]|0;
          HEAP32[$0>>2] = $662;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
          $663 = (__Z16realloc_internalPvji10MemLabelIdiPKci($660,$661,4,$$byval_copy24,0,766088,370)|0);
          HEAP32[$616>>2] = $663;
          break;
         } else {
          $664 = $657 << 4;
          $665 = HEAP32[$642>>2]|0;
          HEAP32[$0>>2] = $665;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
          $666 = (__Z15malloc_internaljj10MemLabelIdiPKci($664,4,$$byval_copy24,0,766088,352)|0);
          $667 = HEAP32[$616>>2]|0;
          $668 = HEAP32[$640>>2]|0;
          $669 = $668 << 4;
          _memcpy(($666|0),($667|0),($669|0))|0;
          HEAP32[$641>>2] = $657;
          HEAP32[$616>>2] = $666;
          break;
         }
        }
       } while(0);
       $$pre$i$i$i = HEAP32[$640>>2]|0;
       $671 = $$pre$i$i$i;
      } else {
       $671 = $651;
      }
      $670 = (($671) + -1)|0;
      $672 = HEAP32[$616>>2]|0;
      $673 = (($672) + ($670<<4)|0);
      ;HEAP32[$673+0>>2]=0|0;HEAP32[$673+4>>2]=0|0;HEAP32[$673+8>>2]=0|0;HEAP32[$673+12>>2]=0|0;
      $674 = HEAP32[$640>>2]|0;
      $675 = (($674) + -1)|0;
      $676 = HEAP32[$616>>2]|0;
      $677 = (($676) + ($675<<4)|0);
      $678 = (__ZN7mecanim6CRCKeyENS_7eStringE(92)|0);
      $679 = ($649|0)==($678|0);
      do {
       if ($679) {
        HEAP32[$677>>2] = $647;
        $680 = ((($676) + ($675<<4)|0) + 4|0);
        HEAP32[$680>>2] = 1;
        $681 = ((($676) + ($675<<4)|0) + 12|0);
        HEAP16[$681>>1] = 4;
        $682 = (($i$01$i50) + 3)|0;
        $i$0$be$i = $682;
       } else {
        $683 = (__ZN7mecanim6CRCKeyENS_7eStringE(95)|0);
        $684 = ($649|0)==($683|0);
        if ($684) {
         HEAP32[$677>>2] = $647;
         $685 = ((($676) + ($675<<4)|0) + 4|0);
         HEAP32[$685>>2] = 2;
         $686 = ((($676) + ($675<<4)|0) + 12|0);
         HEAP16[$686>>1] = 4;
         $687 = (($i$01$i50) + 4)|0;
         $i$0$be$i = $687;
         break;
        }
        $690 = (__ZN7mecanim6CRCKeyENS_7eStringE(99)|0);
        $691 = ($649|0)==($690|0);
        if ($691) {
         HEAP32[$677>>2] = $647;
         $692 = ((($676) + ($675<<4)|0) + 4|0);
         HEAP32[$692>>2] = 3;
         $693 = ((($676) + ($675<<4)|0) + 12|0);
         HEAP16[$693>>1] = 4;
         $694 = (($i$01$i50) + 3)|0;
         $i$0$be$i = $694;
         break;
        }
        $695 = (__ZN7mecanim6CRCKeyENS_7eStringE(93)|0);
        $696 = ($649|0)==($695|0);
        do {
         if (!($696)) {
          $697 = (__ZN7mecanim6CRCKeyENS_7eStringE(94)|0);
          $698 = ($649|0)==($697|0);
          if ($698) {
           break;
          }
          $699 = (__ZN7mecanim6CRCKeyENS_7eStringE(96)|0);
          $700 = ($649|0)==($699|0);
          if ($700) {
           break;
          }
          $701 = (__ZN7mecanim6CRCKeyENS_7eStringE(97)|0);
          $702 = ($649|0)==($701|0);
          if ($702) {
           break;
          }
          $703 = (__ZN7mecanim6CRCKeyENS_7eStringE(98)|0);
          $704 = ($649|0)==($703|0);
          if ($704) {
           break;
          }
          $705 = (__ZN7mecanim6CRCKeyENS_7eStringE(100)|0);
          $706 = ($649|0)==($705|0);
          if ($706) {
           break;
          }
          (__ZN7mecanim6CRCKeyENS_7eStringE(101)|0);
         }
        } while(0);
        $707 = ((($676) + ($675<<4)|0) + 12|0);
        HEAP16[$707>>1] = 95;
        HEAP32[$677>>2] = 0;
        $708 = ((($676) + ($675<<4)|0) + 4|0);
        HEAP32[$708>>2] = $647;
        $709 = (($i$01$i50) + 1)|0;
        $i$0$be$i = $709;
       }
      } while(0);
      $688 = HEAP32[$635>>2]|0;
      $689 = ($i$0$be$i>>>0)<($688>>>0);
      if ($689) {
       $i$01$i50 = $i$0$be$i;
      } else {
       break;
      }
     }
    }
   }
  }
 }
 $710 = (($this) + 152|0);
 $711 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766672,$264,$$byval_copy24,1)|0);
 $712 = ($711|0)==(0);
 if ($712) {
  STACKTOP = sp;return;
 }
 $713 = ($711|0)>(0);
 if ($713) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$710,0);
 } else {
  $714 = HEAP32[$$byval_copy24>>2]|0;
  $715 = ($714|0)==(0|0);
  if (!($715)) {
   (FUNCTION_TABLE_iii[$714 & 4095]($710,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __Z21TransferBlobSerializeIN7mecanim9animation18ClipMuscleConstantE14SafeBinaryReadEvRPT_PKcRjS8_RT0_($data,$name,$size,$sizeName,$transfer) {
 $data = $data|0;
 $name = $name|0;
 $size = $size|0;
 $sizeName = $sizeName|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $converter$i$i = 0, $scevgep$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$size,$sizeName,0);
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$size>>2]|0;
  __ZN7mecanim6memory16ChainedAllocator7ReserveEj($3,$4);
  $5 = HEAP32[$3>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiii[$6 & 2047]($3,1644,4)|0);
  $8 = ($7|0)==(0|0);
  if ($8) {
   $34 = 0;
  } else {
   __ZN7mecanim5human9HumanPoseC2Ev($7);
   $9 = (($7) + 880|0);
   $10 = (($7) + 908|0);
   ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;HEAP32[$9+24>>2]=0|0;
   HEAPF32[$10>>2] = Math_fround(1.0);
   $11 = (($7) + 912|0);
   HEAPF32[$11>>2] = Math_fround(1.0);
   $12 = (($7) + 916|0);
   HEAPF32[$12>>2] = Math_fround(1.0);
   $13 = (($7) + 920|0);
   HEAPF32[$13>>2] = Math_fround(1.0);
   $14 = (($7) + 924|0);
   HEAPF32[$14>>2] = Math_fround(1.0);
   $15 = (($7) + 928|0);
   $16 = (($7) + 956|0);
   ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP32[$15+20>>2]=0|0;HEAP32[$15+24>>2]=0|0;
   HEAPF32[$16>>2] = Math_fround(1.0);
   $17 = (($7) + 960|0);
   HEAPF32[$17>>2] = Math_fround(1.0);
   $18 = (($7) + 964|0);
   HEAPF32[$18>>2] = Math_fround(1.0);
   $19 = (($7) + 968|0);
   HEAPF32[$19>>2] = Math_fround(1.0);
   $20 = (($7) + 972|0);
   HEAPF32[$20>>2] = Math_fround(1.0);
   $21 = (($7) + 976|0);
   $22 = (($7) + 1004|0);
   ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;HEAP32[$21+16>>2]=0|0;HEAP32[$21+20>>2]=0|0;HEAP32[$21+24>>2]=0|0;
   HEAPF32[$22>>2] = Math_fround(1.0);
   $23 = (($7) + 1008|0);
   HEAPF32[$23>>2] = Math_fround(1.0);
   $24 = (($7) + 1012|0);
   HEAPF32[$24>>2] = Math_fround(1.0);
   $25 = (($7) + 1016|0);
   HEAPF32[$25>>2] = Math_fround(1.0);
   $26 = (($7) + 1020|0);
   HEAPF32[$26>>2] = Math_fround(1.0);
   $27 = (($7) + 1024|0);
   $28 = (($7) + 1052|0);
   ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;HEAP32[$27+16>>2]=0|0;HEAP32[$27+20>>2]=0|0;HEAP32[$27+24>>2]=0|0;
   HEAPF32[$28>>2] = Math_fround(1.0);
   $29 = (($7) + 1056|0);
   $30 = (($7) + 1620|0);
   $31 = (($7) + 1639|0);
   ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;
   ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP16[$30+16>>1]=0|0;HEAP8[$30+18>>0]=0|0;
   HEAP8[$31>>0] = 1;
   $32 = (($7) + 1640|0);
   HEAP8[$32>>0] = 0;
   $33 = (($7) + 1641|0);
   HEAP8[$33>>0] = 0;
   $scevgep$i$i$i = (($7) + 1072|0);
   _memset(($scevgep$i$i$i|0),-1,548)|0;
   $34 = $7;
  }
  HEAP32[$data>>2] = $34;
  $38 = $34;
 } else {
  $38 = $0;
 }
 $35 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$name,768256,$converter$i$i,1)|0);
 $36 = ($35|0)==(0);
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = ($35|0)>(0);
 if ($37) {
  __ZN7mecanim9animation18ClipMuscleConstant8TransferI14SafeBinaryReadEEvRT_($38,$transfer);
 } else {
  $39 = HEAP32[$converter$i$i>>2]|0;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   (FUNCTION_TABLE_iii[$39 & 4095]($38,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI14AnimationEvent13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768192,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN14AnimationEvent8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 56|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768192,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN14AnimationEvent8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 56|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation28AnimationClipBindingConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580760>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766696,$0,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 16|0);
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766712,$0,$converter$i$i1,1)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = ($7|0)>(0);
 if ($9) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI6ObjectELj4EEEEvRT_17TransferMetaFlags($transfer,$6,0);
 } else {
  $10 = HEAP32[$converter$i$i1>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   (FUNCTION_TABLE_iii[$10 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<4)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768240,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN11UnityEngine9Animation14GenericBinding8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 16|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768240,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN11UnityEngine9Animation14GenericBinding8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 16|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation14GenericBinding8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i4 = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,766768,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$0,766776,0);
 $1 = (($this) + 8|0);
 $2 = HEAP32[580624>>2]|0;
 $3 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766792,$2,$converter$i$i3,1)|0);
 $4 = ($3|0)==(0);
 if (!($4)) {
  $5 = ($3|0)>(0);
  if ($5) {
   __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($1,$transfer);
  } else {
   $6 = HEAP32[$converter$i$i3>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    (FUNCTION_TABLE_iii[$6 & 4095]($1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $8 = (($this) + 12|0);
 $9 = HEAP32[580720>>2]|0;
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766800,$9,$converter$i$i3,0)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ($10|0)>(0);
  if ($12) {
   $13 = (($transfer) + 12|0);
   $14 = (($transfer) + 80|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($transfer) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($transfer) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($transfer) + 32|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = Math_imul($23, $21)|0;
   $$sum$i$i$i = (($17) - ($24))|0;
   $25 = (($19) + ($$sum$i$i$i)|0);
   HEAP32[$13>>2] = $25;
   $26 = ($$sum$i$i$i|0)<(0);
   if ($26) {
    label = 12;
   } else {
    $$sum1$i$i$i = (($$sum$i$i$i) + 2)|0;
    $27 = (($19) + ($$sum1$i$i$i)|0);
    $28 = (($transfer) + 20|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($27>>>0)>($29>>>0);
    if ($30) {
     label = 12;
    } else {
     $31 = HEAP16[$25>>1]|0;
     HEAP16[$8>>1] = $31;
     HEAP32[$13>>2] = $27;
    }
   }
   if ((label|0) == 12) {
    __ZN12CachedReader15UpdateReadCacheEPvj($13,$8,2);
   }
   $32 = HEAP32[$transfer>>2]|0;
   $33 = $32 & 512;
   $34 = ($33|0)==(0);
   if (!($34)) {
    $35 = HEAP16[$8>>1]|0;
    $36 = $35&65535;
    $37 = $36 << 8;
    $38 = $36 >>> 8;
    $39 = $37 | $38;
    $40 = $39&65535;
    HEAP16[$8>>1] = $40;
   }
  } else {
   $41 = HEAP32[$converter$i$i3>>2]|0;
   $42 = ($41|0)==(0|0);
   if (!($42)) {
    (FUNCTION_TABLE_iii[$41 & 4095]($8,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $43 = (($this) + 14|0);
 $44 = HEAP32[580744>>2]|0;
 $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766808,$44,$converter$i$i3,0)|0);
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = ($45|0)>(0);
  do {
   if ($47) {
    $48 = (($transfer) + 12|0);
    $49 = (($transfer) + 80|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + 12|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($transfer) + 16|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($transfer) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($transfer) + 32|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = Math_imul($58, $56)|0;
    $$sum$i$i$i$i$i = (($52) - ($59))|0;
    $60 = (($54) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$48>>2] = $60;
    $61 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($61)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $62 = (($54) + ($$sum1$i$i$i$i$i)|0);
     $63 = (($transfer) + 20|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($62>>>0)>($64>>>0);
     if (!($65)) {
      $66 = HEAP8[$60>>0]|0;
      HEAP8[$43>>0] = $66;
      $67 = HEAP32[$48>>2]|0;
      $68 = (($67) + 1|0);
      HEAP32[$48>>2] = $68;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($48,$43,1);
   } else {
    $69 = HEAP32[$converter$i$i3>>2]|0;
    $70 = ($69|0)==(0|0);
    if (!($70)) {
     (FUNCTION_TABLE_iii[$69 & 4095]($43,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $71 = (($this) + 15|0);
 $72 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766824,$44,$converter$i$i3,0)|0);
 $73 = ($72|0)==(0);
 if ($73) {
  STACKTOP = sp;return;
 }
 $74 = ($72|0)>(0);
 do {
  if ($74) {
   $75 = (($transfer) + 12|0);
   $76 = (($transfer) + 80|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = (($77) + 12|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($transfer) + 16|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($transfer) + 28|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($transfer) + 32|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = Math_imul($85, $83)|0;
   $$sum$i$i$i$i$i4 = (($79) - ($86))|0;
   $87 = (($81) + ($$sum$i$i$i$i$i4)|0);
   HEAP32[$75>>2] = $87;
   $88 = ($$sum$i$i$i$i$i4|0)<(0);
   if (!($88)) {
    $$sum1$i$i$i$i$i5 = (($$sum$i$i$i$i$i4) + 1)|0;
    $89 = (($81) + ($$sum1$i$i$i$i$i5)|0);
    $90 = (($transfer) + 20|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($89>>>0)>($91>>>0);
    if (!($92)) {
     $93 = HEAP8[$87>>0]|0;
     HEAP8[$71>>0] = $93;
     $94 = HEAP32[$75>>2]|0;
     $95 = (($94) + 1|0);
     HEAP32[$75>>2] = $95;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($75,$71,1);
  } else {
   $96 = HEAP32[$converter$i$i3>>2]|0;
   $97 = ($96|0)==(0|0);
   if (!($97)) {
    (FUNCTION_TABLE_iii[$96 & 4095]($71,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18ClipMuscleConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$ = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $$sink = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i12 = 0, $$sum$i$i$i$i$i17 = 0, $$sum$i$i$i$i$i22 = 0, $$sum$i$i$i$i$i27 = 0, $$sum$i$i$i$i$i32 = 0, $$sum$i$i$i$i$i37 = 0, $$sum$i$i$i$i$i42 = 0, $$sum$i$i$i$i$i47 = 0, $$sum$i$i$i$i$i52 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i13 = 0, $$sum1$i$i$i$i$i18 = 0, $$sum1$i$i$i$i$i23 = 0, $$sum1$i$i$i$i$i28 = 0, $$sum1$i$i$i$i$i33 = 0;
 var $$sum1$i$i$i$i$i38 = 0, $$sum1$i$i$i$i$i43 = 0, $$sum1$i$i$i$i$i48 = 0, $$sum1$i$i$i$i$i53 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i9 = 0, $converter$i$i$i = 0, $converter$i$i51 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i51 = sp + 16|0;
 $ArrayTransfer$i9 = sp;
 $converter$i$i$i = sp + 12|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766840,768424,$converter$i$i51,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   __ZN7mecanim5human9HumanPose8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  } else {
   $3 = HEAP32[$converter$i$i51>>2]|0;
   $4 = ($3|0)==(0|0);
   if (!($4)) {
    (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $5 = (($this) + 880|0);
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766856,768416,$converter$i$i51,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$5,767568,0);
   $9 = (($this) + 896|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$9,767576,0);
   $10 = (($this) + 912|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$10,767584,0);
  } else {
   $11 = HEAP32[$converter$i$i51>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    (FUNCTION_TABLE_iii[$11 & 4095]($5,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $13 = (($this) + 928|0);
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766872,768416,$converter$i$i51,1)|0);
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = ($14|0)>(0);
  if ($16) {
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$13,767568,0);
   $17 = (($this) + 944|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$17,767576,0);
   $18 = (($this) + 960|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$18,767584,0);
  } else {
   $19 = HEAP32[$converter$i$i51>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($13,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (($this) + 976|0);
 $22 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766896,768416,$converter$i$i51,1)|0);
 $23 = ($22|0)==(0);
 if (!($23)) {
  $24 = ($22|0)>(0);
  if ($24) {
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$21,767568,0);
   $25 = (($this) + 992|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$25,767576,0);
   $26 = (($this) + 1008|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$26,767584,0);
  } else {
   $27 = HEAP32[$converter$i$i51>>2]|0;
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    (FUNCTION_TABLE_iii[$27 & 4095]($21,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $29 = (($this) + 1024|0);
 __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$29,766920,0);
 $30 = (($this) + 1040|0);
 $31 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766936,768296,$converter$i$i51,1)|0);
 $32 = ($31|0)==(0);
 if (!($32)) {
  $33 = ($31|0)>(0);
  if ($33) {
   $34 = HEAP32[$30>>2]|0;
   $35 = ($34|0)==(0);
   if ($35) {
    $36 = (($transfer) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = HEAP32[$37>>2]|0;
    $39 = HEAP32[$38>>2]|0;
    $40 = (FUNCTION_TABLE_iiii[$39 & 2047]($37,64,4)|0);
    $41 = ($40|0)==(0|0);
    if ($41) {
     $45 = 0;$47 = 0;
    } else {
     dest=$40+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     $42 = $40;
     $43 = $30;
     $44 = (($42) - ($43))|0;
     $45 = $44;$47 = $40;
    }
    HEAP32[$30>>2] = $45;
    $46 = (($this) + 1044|0);
    HEAP32[$46>>2] = $47;
    $$pre$phi$iZ2D = $46;$50 = $45;
   } else {
    $$pre$i = (($this) + 1044|0);
    $$pre$phi$iZ2D = $$pre$i;$50 = $34;
   }
   $48 = $30;
   $49 = (($50) + ($48))|0;
   $51 = $49;
   HEAP32[$$pre$phi$iZ2D>>2] = $51;
   $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766688,768312,$converter$i$i$i,1)|0);
   $53 = ($52|0)==(0);
   if (!($53)) {
    $54 = ($52|0)>(0);
    if ($54) {
     __ZN7mecanim9animation4Clip8TransferI14SafeBinaryReadEEvRT_($51,$transfer);
    } else {
     $55 = HEAP32[$converter$i$i$i>>2]|0;
     $56 = ($55|0)==(0|0);
     if (!($56)) {
      $57 = $49;
      (FUNCTION_TABLE_iii[$55 & 4095]($57,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
  } else {
   $58 = HEAP32[$converter$i$i51>>2]|0;
   $59 = ($58|0)==(0|0);
   if (!($59)) {
    (FUNCTION_TABLE_iii[$58 & 4095]($30,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $60 = (($this) + 1048|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$60,766944,0);
 $61 = (($this) + 1052|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$61,766960,0);
 $62 = (($this) + 1056|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$62,766976,0);
 $63 = (($this) + 1060|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$63,767000,0);
 $64 = (($this) + 1064|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$64,767008,0);
 $65 = (($this) + 1068|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$65,767024,0);
 $66 = (($this) + 1072|0);
 HEAP32[$ArrayTransfer$i9>>2] = 137;
 $67 = (($ArrayTransfer$i9) + 4|0);
 HEAP32[$67>>2] = $66;
 $68 = HEAP32[580704>>2]|0;
 $69 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767048,$68,$converter$i$i51,1)|0);
 $70 = ($69|0)==(0);
 if (!($70)) {
  $71 = ($69|0)>(0);
  if ($71) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI19StaticArrayTransferIiLi137EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i9,0);
  } else {
   $72 = HEAP32[$converter$i$i51>>2]|0;
   $73 = ($72|0)==(0|0);
   if (!($73)) {
    (FUNCTION_TABLE_iii[$72 & 4095]($ArrayTransfer$i9,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $74 = (($this) + 1624|0);
 $75 = (($this) + 1620|0);
 $76 = (($transfer) + 4|0);
 $77 = HEAP32[$76>>2]|0;
 HEAP32[$ArrayTransfer$i9>>2] = $74;
 $78 = (($ArrayTransfer$i9) + 4|0);
 HEAP32[$78>>2] = $75;
 $79 = (($ArrayTransfer$i9) + 8|0);
 HEAP32[$79>>2] = $77;
 $80 = HEAP32[580760>>2]|0;
 $81 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767064,$80,$converter$i$i51,1)|0);
 $82 = ($81|0)==(0);
 if (!($82)) {
  $83 = ($81|0)>(0);
  if ($83) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation10ValueDeltaEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i9,0);
  } else {
   $84 = HEAP32[$converter$i$i51>>2]|0;
   $85 = ($84|0)==(0|0);
   if (!($85)) {
    (FUNCTION_TABLE_iii[$84 & 4095]($ArrayTransfer$i9,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $86 = (($this) + 1632|0);
 $87 = HEAP32[580544>>2]|0;
 $88 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767088,$87,$converter$i$i51,0)|0);
 $89 = ($88|0)==(0);
 if (!($89)) {
  $90 = ($88|0)>(0);
  do {
   if ($90) {
    $91 = (($transfer) + 12|0);
    $92 = (($transfer) + 80|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($93) + 12|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($transfer) + 16|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($transfer) + 28|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($transfer) + 32|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = Math_imul($101, $99)|0;
    $$sum$i$i$i$i$i = (($95) - ($102))|0;
    $103 = (($97) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$91>>2] = $103;
    $104 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($104)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $105 = (($97) + ($$sum1$i$i$i$i$i)|0);
     $106 = (($transfer) + 20|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ($105>>>0)>($107>>>0);
     if (!($108)) {
      $109 = HEAP8[$103>>0]|0;
      HEAP8[$86>>0] = $109;
      $110 = HEAP32[$91>>2]|0;
      $111 = (($110) + 1|0);
      HEAP32[$91>>2] = $111;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($91,$86,1);
   } else {
    $112 = HEAP32[$converter$i$i51>>2]|0;
    $113 = ($112|0)==(0|0);
    if (!($113)) {
     (FUNCTION_TABLE_iii[$112 & 4095]($86,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $114 = (($this) + 1633|0);
 $115 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767104,$87,$converter$i$i51,0)|0);
 $116 = ($115|0)==(0);
 if (!($116)) {
  $117 = ($115|0)>(0);
  do {
   if ($117) {
    $118 = (($transfer) + 12|0);
    $119 = (($transfer) + 80|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = (($120) + 12|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = (($transfer) + 16|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (($transfer) + 28|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = (($transfer) + 32|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = Math_imul($128, $126)|0;
    $$sum$i$i$i$i$i12 = (($122) - ($129))|0;
    $130 = (($124) + ($$sum$i$i$i$i$i12)|0);
    HEAP32[$118>>2] = $130;
    $131 = ($$sum$i$i$i$i$i12|0)<(0);
    if (!($131)) {
     $$sum1$i$i$i$i$i13 = (($$sum$i$i$i$i$i12) + 1)|0;
     $132 = (($124) + ($$sum1$i$i$i$i$i13)|0);
     $133 = (($transfer) + 20|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = ($132>>>0)>($134>>>0);
     if (!($135)) {
      $136 = HEAP8[$130>>0]|0;
      HEAP8[$114>>0] = $136;
      $137 = HEAP32[$118>>2]|0;
      $138 = (($137) + 1|0);
      HEAP32[$118>>2] = $138;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($118,$114,1);
   } else {
    $139 = HEAP32[$converter$i$i51>>2]|0;
    $140 = ($139|0)==(0|0);
    if (!($140)) {
     (FUNCTION_TABLE_iii[$139 & 4095]($114,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $141 = (($this) + 1634|0);
 $142 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767120,$87,$converter$i$i51,0)|0);
 $143 = ($142|0)==(0);
 if (!($143)) {
  $144 = ($142|0)>(0);
  do {
   if ($144) {
    $145 = (($transfer) + 12|0);
    $146 = (($transfer) + 80|0);
    $147 = HEAP32[$146>>2]|0;
    $148 = (($147) + 12|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = (($transfer) + 16|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = (($transfer) + 28|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = (($transfer) + 32|0);
    $155 = HEAP32[$154>>2]|0;
    $156 = Math_imul($155, $153)|0;
    $$sum$i$i$i$i$i17 = (($149) - ($156))|0;
    $157 = (($151) + ($$sum$i$i$i$i$i17)|0);
    HEAP32[$145>>2] = $157;
    $158 = ($$sum$i$i$i$i$i17|0)<(0);
    if (!($158)) {
     $$sum1$i$i$i$i$i18 = (($$sum$i$i$i$i$i17) + 1)|0;
     $159 = (($151) + ($$sum1$i$i$i$i$i18)|0);
     $160 = (($transfer) + 20|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = ($159>>>0)>($161>>>0);
     if (!($162)) {
      $163 = HEAP8[$157>>0]|0;
      HEAP8[$141>>0] = $163;
      $164 = HEAP32[$145>>2]|0;
      $165 = (($164) + 1|0);
      HEAP32[$145>>2] = $165;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($145,$141,1);
   } else {
    $166 = HEAP32[$converter$i$i51>>2]|0;
    $167 = ($166|0)==(0|0);
    if (!($167)) {
     (FUNCTION_TABLE_iii[$166 & 4095]($141,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $168 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 $$ = $168 ? $141 : $114;
 $$sink = HEAP8[$$>>0]|0;
 $169 = $$sink & 1;
 HEAP8[$114>>0] = $169;
 $170 = (($this) + 1635|0);
 $171 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767136,$87,$converter$i$i51,0)|0);
 $172 = ($171|0)==(0);
 if (!($172)) {
  $173 = ($171|0)>(0);
  do {
   if ($173) {
    $174 = (($transfer) + 12|0);
    $175 = (($transfer) + 80|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = (($176) + 12|0);
    $178 = HEAP32[$177>>2]|0;
    $179 = (($transfer) + 16|0);
    $180 = HEAP32[$179>>2]|0;
    $181 = (($transfer) + 28|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = (($transfer) + 32|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = Math_imul($184, $182)|0;
    $$sum$i$i$i$i$i22 = (($178) - ($185))|0;
    $186 = (($180) + ($$sum$i$i$i$i$i22)|0);
    HEAP32[$174>>2] = $186;
    $187 = ($$sum$i$i$i$i$i22|0)<(0);
    if (!($187)) {
     $$sum1$i$i$i$i$i23 = (($$sum$i$i$i$i$i22) + 1)|0;
     $188 = (($180) + ($$sum1$i$i$i$i$i23)|0);
     $189 = (($transfer) + 20|0);
     $190 = HEAP32[$189>>2]|0;
     $191 = ($188>>>0)>($190>>>0);
     if (!($191)) {
      $192 = HEAP8[$186>>0]|0;
      HEAP8[$170>>0] = $192;
      $193 = HEAP32[$174>>2]|0;
      $194 = (($193) + 1|0);
      HEAP32[$174>>2] = $194;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($174,$170,1);
   } else {
    $195 = HEAP32[$converter$i$i51>>2]|0;
    $196 = ($195|0)==(0|0);
    if (!($196)) {
     (FUNCTION_TABLE_iii[$195 & 4095]($170,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $197 = (($this) + 1636|0);
 $198 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767160,$87,$converter$i$i51,0)|0);
 $199 = ($198|0)==(0);
 if (!($199)) {
  $200 = ($198|0)>(0);
  do {
   if ($200) {
    $201 = (($transfer) + 12|0);
    $202 = (($transfer) + 80|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = (($203) + 12|0);
    $205 = HEAP32[$204>>2]|0;
    $206 = (($transfer) + 16|0);
    $207 = HEAP32[$206>>2]|0;
    $208 = (($transfer) + 28|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = (($transfer) + 32|0);
    $211 = HEAP32[$210>>2]|0;
    $212 = Math_imul($211, $209)|0;
    $$sum$i$i$i$i$i27 = (($205) - ($212))|0;
    $213 = (($207) + ($$sum$i$i$i$i$i27)|0);
    HEAP32[$201>>2] = $213;
    $214 = ($$sum$i$i$i$i$i27|0)<(0);
    if (!($214)) {
     $$sum1$i$i$i$i$i28 = (($$sum$i$i$i$i$i27) + 1)|0;
     $215 = (($207) + ($$sum1$i$i$i$i$i28)|0);
     $216 = (($transfer) + 20|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = ($215>>>0)>($217>>>0);
     if (!($218)) {
      $219 = HEAP8[$213>>0]|0;
      HEAP8[$197>>0] = $219;
      $220 = HEAP32[$201>>2]|0;
      $221 = (($220) + 1|0);
      HEAP32[$201>>2] = $221;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($201,$197,1);
   } else {
    $222 = HEAP32[$converter$i$i51>>2]|0;
    $223 = ($222|0)==(0|0);
    if (!($223)) {
     (FUNCTION_TABLE_iii[$222 & 4095]($197,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $224 = (($this) + 1637|0);
 $225 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767184,$87,$converter$i$i51,0)|0);
 $226 = ($225|0)==(0);
 if (!($226)) {
  $227 = ($225|0)>(0);
  do {
   if ($227) {
    $228 = (($transfer) + 12|0);
    $229 = (($transfer) + 80|0);
    $230 = HEAP32[$229>>2]|0;
    $231 = (($230) + 12|0);
    $232 = HEAP32[$231>>2]|0;
    $233 = (($transfer) + 16|0);
    $234 = HEAP32[$233>>2]|0;
    $235 = (($transfer) + 28|0);
    $236 = HEAP32[$235>>2]|0;
    $237 = (($transfer) + 32|0);
    $238 = HEAP32[$237>>2]|0;
    $239 = Math_imul($238, $236)|0;
    $$sum$i$i$i$i$i32 = (($232) - ($239))|0;
    $240 = (($234) + ($$sum$i$i$i$i$i32)|0);
    HEAP32[$228>>2] = $240;
    $241 = ($$sum$i$i$i$i$i32|0)<(0);
    if (!($241)) {
     $$sum1$i$i$i$i$i33 = (($$sum$i$i$i$i$i32) + 1)|0;
     $242 = (($234) + ($$sum1$i$i$i$i$i33)|0);
     $243 = (($transfer) + 20|0);
     $244 = HEAP32[$243>>2]|0;
     $245 = ($242>>>0)>($244>>>0);
     if (!($245)) {
      $246 = HEAP8[$240>>0]|0;
      HEAP8[$224>>0] = $246;
      $247 = HEAP32[$228>>2]|0;
      $248 = (($247) + 1|0);
      HEAP32[$228>>2] = $248;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($228,$224,1);
   } else {
    $249 = HEAP32[$converter$i$i51>>2]|0;
    $250 = ($249|0)==(0|0);
    if (!($250)) {
     (FUNCTION_TABLE_iii[$249 & 4095]($224,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $251 = (($this) + 1638|0);
 $252 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767208,$87,$converter$i$i51,0)|0);
 $253 = ($252|0)==(0);
 if (!($253)) {
  $254 = ($252|0)>(0);
  do {
   if ($254) {
    $255 = (($transfer) + 12|0);
    $256 = (($transfer) + 80|0);
    $257 = HEAP32[$256>>2]|0;
    $258 = (($257) + 12|0);
    $259 = HEAP32[$258>>2]|0;
    $260 = (($transfer) + 16|0);
    $261 = HEAP32[$260>>2]|0;
    $262 = (($transfer) + 28|0);
    $263 = HEAP32[$262>>2]|0;
    $264 = (($transfer) + 32|0);
    $265 = HEAP32[$264>>2]|0;
    $266 = Math_imul($265, $263)|0;
    $$sum$i$i$i$i$i37 = (($259) - ($266))|0;
    $267 = (($261) + ($$sum$i$i$i$i$i37)|0);
    HEAP32[$255>>2] = $267;
    $268 = ($$sum$i$i$i$i$i37|0)<(0);
    if (!($268)) {
     $$sum1$i$i$i$i$i38 = (($$sum$i$i$i$i$i37) + 1)|0;
     $269 = (($261) + ($$sum1$i$i$i$i$i38)|0);
     $270 = (($transfer) + 20|0);
     $271 = HEAP32[$270>>2]|0;
     $272 = ($269>>>0)>($271>>>0);
     if (!($272)) {
      $273 = HEAP8[$267>>0]|0;
      HEAP8[$251>>0] = $273;
      $274 = HEAP32[$255>>2]|0;
      $275 = (($274) + 1|0);
      HEAP32[$255>>2] = $275;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($255,$251,1);
   } else {
    $276 = HEAP32[$converter$i$i51>>2]|0;
    $277 = ($276|0)==(0|0);
    if (!($277)) {
     (FUNCTION_TABLE_iii[$276 & 4095]($251,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $278 = (($this) + 1639|0);
 $279 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767240,$87,$converter$i$i51,0)|0);
 $280 = ($279|0)==(0);
 if (!($280)) {
  $281 = ($279|0)>(0);
  L156: do {
   if ($281) {
    $282 = (($transfer) + 12|0);
    $283 = (($transfer) + 80|0);
    $284 = HEAP32[$283>>2]|0;
    $285 = (($284) + 12|0);
    $286 = HEAP32[$285>>2]|0;
    $287 = (($transfer) + 16|0);
    $288 = HEAP32[$287>>2]|0;
    $289 = (($transfer) + 28|0);
    $290 = HEAP32[$289>>2]|0;
    $291 = (($transfer) + 32|0);
    $292 = HEAP32[$291>>2]|0;
    $293 = Math_imul($292, $290)|0;
    $$sum$i$i$i$i$i42 = (($286) - ($293))|0;
    $294 = (($288) + ($$sum$i$i$i$i$i42)|0);
    HEAP32[$282>>2] = $294;
    $295 = ($$sum$i$i$i$i$i42|0)<(0);
    do {
     if (!($295)) {
      $$sum1$i$i$i$i$i43 = (($$sum$i$i$i$i$i42) + 1)|0;
      $296 = (($288) + ($$sum1$i$i$i$i$i43)|0);
      $297 = (($transfer) + 20|0);
      $298 = HEAP32[$297>>2]|0;
      $299 = ($296>>>0)>($298>>>0);
      if ($299) {
       break;
      }
      $300 = HEAP8[$294>>0]|0;
      HEAP8[$278>>0] = $300;
      $301 = HEAP32[$282>>2]|0;
      $302 = (($301) + 1|0);
      HEAP32[$282>>2] = $302;
      break L156;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($282,$278,1);
   } else {
    $303 = HEAP32[$converter$i$i51>>2]|0;
    $304 = ($303|0)==(0|0);
    if (!($304)) {
     (FUNCTION_TABLE_iii[$303 & 4095]($278,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $305 = (($this) + 1640|0);
 $306 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767264,$87,$converter$i$i51,0)|0);
 $307 = ($306|0)==(0);
 if (!($307)) {
  $308 = ($306|0)>(0);
  L168: do {
   if ($308) {
    $309 = (($transfer) + 12|0);
    $310 = (($transfer) + 80|0);
    $311 = HEAP32[$310>>2]|0;
    $312 = (($311) + 12|0);
    $313 = HEAP32[$312>>2]|0;
    $314 = (($transfer) + 16|0);
    $315 = HEAP32[$314>>2]|0;
    $316 = (($transfer) + 28|0);
    $317 = HEAP32[$316>>2]|0;
    $318 = (($transfer) + 32|0);
    $319 = HEAP32[$318>>2]|0;
    $320 = Math_imul($319, $317)|0;
    $$sum$i$i$i$i$i47 = (($313) - ($320))|0;
    $321 = (($315) + ($$sum$i$i$i$i$i47)|0);
    HEAP32[$309>>2] = $321;
    $322 = ($$sum$i$i$i$i$i47|0)<(0);
    do {
     if (!($322)) {
      $$sum1$i$i$i$i$i48 = (($$sum$i$i$i$i$i47) + 1)|0;
      $323 = (($315) + ($$sum1$i$i$i$i$i48)|0);
      $324 = (($transfer) + 20|0);
      $325 = HEAP32[$324>>2]|0;
      $326 = ($323>>>0)>($325>>>0);
      if ($326) {
       break;
      }
      $327 = HEAP8[$321>>0]|0;
      HEAP8[$305>>0] = $327;
      $328 = HEAP32[$309>>2]|0;
      $329 = (($328) + 1|0);
      HEAP32[$309>>2] = $329;
      break L168;
     }
    } while(0);
    __ZN12CachedReader15UpdateReadCacheEPvj($309,$305,1);
   } else {
    $330 = HEAP32[$converter$i$i51>>2]|0;
    $331 = ($330|0)==(0|0);
    if (!($331)) {
     (FUNCTION_TABLE_iii[$330 & 4095]($305,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $332 = (($this) + 1641|0);
 $333 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767296,$87,$converter$i$i51,0)|0);
 $334 = ($333|0)==(0);
 if ($334) {
  STACKTOP = sp;return;
 }
 $335 = ($333|0)>(0);
 L181: do {
  if ($335) {
   $336 = (($transfer) + 12|0);
   $337 = (($transfer) + 80|0);
   $338 = HEAP32[$337>>2]|0;
   $339 = (($338) + 12|0);
   $340 = HEAP32[$339>>2]|0;
   $341 = (($transfer) + 16|0);
   $342 = HEAP32[$341>>2]|0;
   $343 = (($transfer) + 28|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = (($transfer) + 32|0);
   $346 = HEAP32[$345>>2]|0;
   $347 = Math_imul($346, $344)|0;
   $$sum$i$i$i$i$i52 = (($340) - ($347))|0;
   $348 = (($342) + ($$sum$i$i$i$i$i52)|0);
   HEAP32[$336>>2] = $348;
   $349 = ($$sum$i$i$i$i$i52|0)<(0);
   do {
    if (!($349)) {
     $$sum1$i$i$i$i$i53 = (($$sum$i$i$i$i$i52) + 1)|0;
     $350 = (($342) + ($$sum1$i$i$i$i$i53)|0);
     $351 = (($transfer) + 20|0);
     $352 = HEAP32[$351>>2]|0;
     $353 = ($350>>>0)>($352>>>0);
     if ($353) {
      break;
     }
     $354 = HEAP8[$348>>0]|0;
     HEAP8[$332>>0] = $354;
     $355 = HEAP32[$336>>2]|0;
     $356 = (($355) + 1|0);
     HEAP32[$336>>2] = $356;
     break L181;
    }
   } while(0);
   __ZN12CachedReader15UpdateReadCacheEPvj($336,$332,1);
  } else {
   $357 = HEAP32[$converter$i$i51>>2]|0;
   $358 = ($357|0)==(0|0);
   if (!($358)) {
    (FUNCTION_TABLE_iii[$357 & 4095]($332,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $buf$i = 0;
 var $converter$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $buf$i = sp + 8|0;
 $converter$i = sp;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$name,768408,$converter$i,1)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ($1|0)>(0);
 if ($3) {
  $4 = Math_fround(HEAPF32[$data>>2]);
  HEAPF32[$buf$i>>2] = $4;
  $5 = (($buf$i) + 4|0);
  $6 = (($data) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  HEAPF32[$5>>2] = $7;
  $8 = (($buf$i) + 8|0);
  $9 = (($data) + 8|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$8>>2] = $10;
  $11 = (($buf$i) + 12|0);
  $12 = (($data) + 12|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $13;
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$buf$i,767536,0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$5,767544,0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$8,767552,0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$11,767560,0);
  $14 = Math_fround(HEAPF32[$buf$i>>2]);
  $15 = Math_fround(HEAPF32[$5>>2]);
  $16 = Math_fround(HEAPF32[$8>>2]);
  $17 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$data>>2] = $14;
  HEAPF32[$6>>2] = $15;
  HEAPF32[$9>>2] = $16;
  HEAPF32[$12>>2] = $17;
 } else {
  $18 = HEAP32[$converter$i>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   (FUNCTION_TABLE_iii[$18 & 4095]($data,$this)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation10ValueDeltaEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $converter$i$i = 0, $i$03 = 0;
 var $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $22 = (($9) + 4|0);
  HEAP32[$22>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$20 = 0;
  } else {
   $17 = $15;
   $18 = $9;
   $19 = (($17) - ($18))|0;
   $$0$i1$i$i = $15;$20 = $19;
  }
  HEAP32[$9>>2] = $20;
  $21 = (($9) + 4|0);
  HEAP32[$21>>2] = $$0$i1$i$i;
 }
 $23 = HEAP32[$data>>2]|0;
 $24 = $23;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = $26;
 $28 = (($23) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[$2>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($27) + ($30<<3)|0);
 $32 = HEAP32[$size>>2]|0;
 $33 = ($32|0)==(0);
 do {
  if (!($33)) {
   $34 = HEAP32[$data>>2]|0;
   $35 = $34;
   $36 = HEAP32[$34>>2]|0;
   $37 = (($36) + ($35))|0;
   $38 = $37;
   $39 = (($34) + 4|0);
   HEAP32[$39>>2] = $38;
   $40 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768280,0,1)|0);
   $41 = (($this) + 80|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (__ZNK16TypeTreeIterator7GetNodeEv($42)|0);
   $44 = (($43) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($this) + 84|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$47>>2] = 0;
   $48 = ($40|0)==(2);
   if ($48) {
    $49 = HEAP32[$41>>2]|0;
    $50 = (($49) + 12|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = HEAP32[$data>>2]|0;
    $53 = $52;
    $54 = HEAP32[$52>>2]|0;
    $55 = (($54) + ($53))|0;
    $56 = $55;
    $57 = (($52) + 4|0);
    HEAP32[$57>>2] = $56;
    $58 = ($56|0)==($31|0);
    if (!($58)) {
     $i$03 = $56;
     while(1) {
      $59 = HEAP32[$46>>2]|0;
      $60 = HEAP32[$59>>2]|0;
      $61 = Math_imul($60, $45)|0;
      $62 = (($61) + ($51))|0;
      $63 = HEAP32[$41>>2]|0;
      $64 = (($63) + 20|0);
      HEAP32[$64>>2] = $62;
      $65 = (($63) + 12|0);
      HEAP32[$65>>2] = $62;
      $66 = (($63) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$63);
      $67 = $1;
      $68 = $67;
      $69 = HEAP32[$68>>2]|0;
      $70 = (($67) + 4)|0;
      $71 = $70;
      $72 = HEAP32[$71>>2]|0;
      $73 = $66;
      $74 = $73;
      HEAP32[$74>>2] = $69;
      $75 = (($73) + 4)|0;
      $76 = $75;
      HEAP32[$76>>2] = $72;
      $77 = HEAP32[$46>>2]|0;
      $78 = HEAP32[$77>>2]|0;
      $79 = (($78) + 1)|0;
      HEAP32[$77>>2] = $79;
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$03,767320,0);
      $80 = (($i$03) + 4|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$80,767328,0);
      $81 = (($i$03) + 8|0);
      $82 = ($81|0)==($31|0);
      if ($82) {
       break;
      } else {
       $i$03 = $81;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $83 = HEAP32[$data>>2]|0;
   $84 = $83;
   $85 = HEAP32[$83>>2]|0;
   $86 = (($85) + ($84))|0;
   $87 = $86;
   $88 = (($83) + 4|0);
   HEAP32[$88>>2] = $87;
   $89 = ($87|0)==($31|0);
   if (!($89)) {
    $i$14 = $87;
    while(1) {
     $90 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768280,$converter$i$i,1)|0);
     $91 = ($90|0)==(0);
     if (!($91)) {
      $92 = ($90|0)>(0);
      if ($92) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$14,767320,0);
       $93 = (($i$14) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$93,767328,0);
      } else {
       $94 = HEAP32[$converter$i$i>>2]|0;
       $95 = ($94|0)==(0|0);
       if (!($95)) {
        (FUNCTION_TABLE_iii[$94 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $96 = (($i$14) + 8|0);
     $97 = ($96|0)==($31|0);
     if ($97) {
      break;
     } else {
      $i$14 = $96;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI19StaticArrayTransferIiLi137EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $i$03 = 0;
 var $i$15 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$data>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$size>>2]|0;
 $5 = ($4>>>0)>(137);
 $6 = $5 ? 137 : $4;
 HEAP32[$data>>2] = $6;
 $7 = (($data) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = ($4|0)==(0);
 L4: do {
  if (!($10)) {
   $11 = HEAP32[580592>>2]|0;
   $12 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,$11,0,0)|0);
   $13 = (($this) + 80|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__ZNK16TypeTreeIterator7GetNodeEv($14)|0);
   $16 = (($15) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($this) + 84|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$19>>2] = 0;
   $20 = ($12|0)==(2);
   if (!($20)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $71 = HEAP32[$7>>2]|0;
    $72 = ($71|0)==($9|0);
    if ($72) {
     break;
    } else {
     $i$15 = $71;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$i$15,766688,0);
     $73 = (($i$15) + 4|0);
     $74 = ($73|0)==($9|0);
     if ($74) {
      break L4;
     } else {
      $i$15 = $73;
     }
    }
   }
   $21 = HEAP32[$13>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$7>>2]|0;
   $25 = ($24|0)==($9|0);
   L11: do {
    if (!($25)) {
     $26 = (($this) + 12|0);
     $27 = (($this) + 16|0);
     $28 = (($this) + 28|0);
     $29 = (($this) + 32|0);
     $30 = (($this) + 20|0);
     $32 = 0;$35 = $21;$i$03 = $24;
     while(1) {
      $31 = Math_imul($32, $17)|0;
      $33 = (($31) + ($23))|0;
      $34 = (($35) + 20|0);
      HEAP32[$34>>2] = $33;
      $36 = (($35) + 12|0);
      HEAP32[$36>>2] = $33;
      $37 = (($35) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$35);
      $38 = $1;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = (($38) + 4)|0;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = $37;
      $45 = $44;
      HEAP32[$45>>2] = $40;
      $46 = (($44) + 4)|0;
      $47 = $46;
      HEAP32[$47>>2] = $43;
      $48 = HEAP32[$18>>2]|0;
      $49 = HEAP32[$48>>2]|0;
      $50 = (($49) + 1)|0;
      HEAP32[$48>>2] = $50;
      $51 = HEAP32[$13>>2]|0;
      $52 = (($51) + 12|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = HEAP32[$27>>2]|0;
      $55 = HEAP32[$28>>2]|0;
      $56 = HEAP32[$29>>2]|0;
      $57 = Math_imul($56, $55)|0;
      $$sum$i$i$i = (($53) - ($57))|0;
      $58 = (($54) + ($$sum$i$i$i)|0);
      HEAP32[$26>>2] = $58;
      $59 = ($$sum$i$i$i|0)<(0);
      if ($59) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $60 = (($54) + ($$sum1$i$i$i)|0);
       $61 = HEAP32[$30>>2]|0;
       $62 = ($60>>>0)>($61>>>0);
       if ($62) {
        label = 9;
       } else {
        $63 = HEAP32[$58>>2]|0;
        HEAP32[$i$03>>2] = $63;
        HEAP32[$26>>2] = $60;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($26,$i$03,4);
      }
      $64 = HEAP32[$this>>2]|0;
      $65 = $64 & 512;
      $66 = ($65|0)==(0);
      if (!($66)) {
       $67 = HEAP32[$i$03>>2]|0;
       $68 = (_llvm_bswap_i32(($67|0))|0);
       HEAP32[$i$03>>2] = $68;
      }
      $69 = (($i$03) + 4|0);
      $70 = ($69|0)==($9|0);
      if ($70) {
       break L11;
      }
      $$pre = HEAP32[$18>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$13>>2]|0;
      $32 = $$pre8;$35 = $$pre9;$i$03 = $69;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation4Clip8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i4 = 0, $converter$i$i$i$i$i3 = 0, $converter$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i5 = sp + 24|0;
 $converter$i$i$i$i$i3 = sp;
 $ArrayTransfer$i$i$i4 = sp + 12|0;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767336,768392,$ArrayTransfer$i$i$i4,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   $3 = (($this) + 4|0);
   $4 = (($transfer) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   HEAP32[$converter$i$i$i$i$i3>>2] = $3;
   $6 = (($converter$i$i$i$i$i3) + 4|0);
   HEAP32[$6>>2] = $this;
   $7 = (($converter$i$i$i$i$i3) + 8|0);
   HEAP32[$7>>2] = $5;
   $8 = HEAP32[580760>>2]|0;
   $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766688,$8,$converter$i$i5,1)|0);
   $10 = ($9|0)==(0);
   if (!($10)) {
    $11 = ($9|0)>(0);
    if ($11) {
     __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($transfer,$converter$i$i$i$i$i3,0);
    } else {
     $12 = HEAP32[$converter$i$i5>>2]|0;
     $13 = ($12|0)==(0|0);
     if (!($13)) {
      (FUNCTION_TABLE_iii[$12 & 4095]($converter$i$i$i$i$i3,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
   $14 = (($this) + 12|0);
   __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$14,767520,0);
  } else {
   $15 = HEAP32[$ArrayTransfer$i$i$i4>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    (FUNCTION_TABLE_iii[$15 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $17 = (($this) + 16|0);
 $18 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767352,768376,$converter$i$i5,1)|0);
 $19 = ($18|0)==(0);
 if (!($19)) {
  $20 = ($18|0)>(0);
  if ($20) {
   __ZN7mecanim9animation9DenseClip8TransferI14SafeBinaryReadEEvRT_($17,$transfer);
  } else {
   $21 = HEAP32[$converter$i$i5>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    (FUNCTION_TABLE_iii[$21 & 4095]($17,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $23 = (($this) + 44|0);
 $24 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767368,768360,$converter$i$i5,1)|0);
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = ($24|0)>(0);
  if ($26) {
   $27 = (($this) + 48|0);
   $28 = (($transfer) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   HEAP32[$ArrayTransfer$i$i$i4>>2] = $27;
   $30 = (($ArrayTransfer$i$i$i4) + 4|0);
   HEAP32[$30>>2] = $23;
   $31 = (($ArrayTransfer$i$i$i4) + 8|0);
   HEAP32[$31>>2] = $29;
   $32 = HEAP32[580760>>2]|0;
   $33 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766688,$32,$converter$i$i$i$i$i3,1)|0);
   $34 = ($33|0)==(0);
   if (!($34)) {
    $35 = ($33|0)>(0);
    if ($35) {
     __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i4,0);
    } else {
     $36 = HEAP32[$converter$i$i$i$i$i3>>2]|0;
     $37 = ($36|0)==(0|0);
     if (!($37)) {
      (FUNCTION_TABLE_iii[$36 & 4095]($ArrayTransfer$i$i$i4,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
  } else {
   $38 = HEAP32[$converter$i$i5>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    (FUNCTION_TABLE_iii[$38 & 4095]($23,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $40 = (($this) + 56|0);
 $41 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767384,768296,$converter$i$i5,1)|0);
 $42 = ($41|0)==(0);
 if ($42) {
  STACKTOP = sp;return;
 }
 $43 = ($41|0)>(0);
 if ($43) {
  __ZN15SerializeTraitsI9OffsetPtrIN7mecanim18ValueArrayConstantEEE8TransferI14SafeBinaryReadEEvRS3_RT_($40,$transfer);
 } else {
  $44 = HEAP32[$converter$i$i5>>2]|0;
  $45 = ($44|0)==(0|0);
  if (!($45)) {
   (FUNCTION_TABLE_iii[$44 & 4095]($40,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim18ValueArrayConstantEEE8TransferI14SafeBinaryReadEEvRS3_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0;
 var $converter$i$i = 0, $converter$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i$i = sp + 16|0;
 $ArrayTransfer$i$i$i = sp;
 $converter$i$i = sp + 12|0;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,12,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = 0;$15 = 0;
  } else {
   HEAP32[$6>>2] = 0;
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 8|0);
   HEAP32[$9>>2] = 0;
   $10 = $6;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $6;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phiZ2D = $14;$18 = $13;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$18 = $0;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phiZ2D>>2] = $19;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766688,768320,$converter$i$i,1)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = ($20|0)>(0);
 if ($22) {
  $23 = (($19) + 4|0);
  $24 = (($transfer) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i>>2] = $23;
  $26 = (($ArrayTransfer$i$i$i) + 4|0);
  HEAP32[$26>>2] = $19;
  $27 = (($ArrayTransfer$i$i$i) + 8|0);
  HEAP32[$27>>2] = $25;
  $28 = HEAP32[580760>>2]|0;
  $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767400,$28,$converter$i$i$i$i$i,1)|0);
  $30 = ($29|0)==(0);
  if (!($30)) {
   $31 = ($29|0)>(0);
   if ($31) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim13ValueConstantEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i,0);
   } else {
    $32 = HEAP32[$converter$i$i$i$i$i>>2]|0;
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     (FUNCTION_TABLE_iii[$32 & 4095]($ArrayTransfer$i$i$i,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $34 = HEAP32[$converter$i$i>>2]|0;
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   $36 = $17;
   (FUNCTION_TABLE_iii[$34 & 4095]($36,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim13ValueConstantEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $29 = (($9) + 4|0);
  HEAP32[$29>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 4;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$27 = 0;
  } else {
   $17 = (($15) + ($6<<4)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    HEAP32[$20>>2] = 10;
    $21 = (($18) + 12|0);
    HEAP32[$21>>2] = 0;
    $22 = (($18) + 16|0);
    $23 = ($22|0)==($17|0);
    if ($23) {
     break;
    } else {
     $18 = $22;
    }
   }
   $24 = $15;
   $25 = $9;
   $26 = (($24) - ($25))|0;
   $$0$i1$i$i = $15;$27 = $26;
  }
  HEAP32[$9>>2] = $27;
  $28 = (($9) + 4|0);
  HEAP32[$28>>2] = $$0$i1$i$i;
 }
 $30 = HEAP32[$data>>2]|0;
 $31 = $30;
 $32 = HEAP32[$30>>2]|0;
 $33 = (($32) + ($31))|0;
 $34 = $33;
 $35 = (($30) + 4|0);
 HEAP32[$35>>2] = $34;
 $36 = HEAP32[$2>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($34) + ($37<<4)|0);
 $39 = HEAP32[$size>>2]|0;
 $40 = ($39|0)==(0);
 do {
  if (!($40)) {
   $41 = HEAP32[$data>>2]|0;
   $42 = $41;
   $43 = HEAP32[$41>>2]|0;
   $44 = (($43) + ($42))|0;
   $45 = $44;
   $46 = (($41) + 4|0);
   HEAP32[$46>>2] = $45;
   $47 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768344,0,1)|0);
   $48 = (($this) + 80|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (__ZNK16TypeTreeIterator7GetNodeEv($49)|0);
   $51 = (($50) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($this) + 84|0);
   $54 = HEAP32[$53>>2]|0;
   HEAP32[$54>>2] = 0;
   $55 = ($47|0)==(2);
   if ($55) {
    $56 = HEAP32[$48>>2]|0;
    $57 = (($56) + 12|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = HEAP32[$data>>2]|0;
    $60 = $59;
    $61 = HEAP32[$59>>2]|0;
    $62 = (($61) + ($60))|0;
    $63 = $62;
    $64 = (($59) + 4|0);
    HEAP32[$64>>2] = $63;
    $65 = ($63|0)==($38|0);
    if (!($65)) {
     $i$03 = $63;
     while(1) {
      $66 = HEAP32[$53>>2]|0;
      $67 = HEAP32[$66>>2]|0;
      $68 = Math_imul($67, $52)|0;
      $69 = (($68) + ($58))|0;
      $70 = HEAP32[$48>>2]|0;
      $71 = (($70) + 20|0);
      HEAP32[$71>>2] = $69;
      $72 = (($70) + 12|0);
      HEAP32[$72>>2] = $69;
      $73 = (($70) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$70);
      $74 = $1;
      $75 = $74;
      $76 = HEAP32[$75>>2]|0;
      $77 = (($74) + 4)|0;
      $78 = $77;
      $79 = HEAP32[$78>>2]|0;
      $80 = $73;
      $81 = $80;
      HEAP32[$81>>2] = $76;
      $82 = (($80) + 4)|0;
      $83 = $82;
      HEAP32[$83>>2] = $79;
      $84 = HEAP32[$53>>2]|0;
      $85 = HEAP32[$84>>2]|0;
      $86 = (($85) + 1)|0;
      HEAP32[$84>>2] = $86;
      __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$i$03,767416,0);
      $87 = (($i$03) + 4|0);
      __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$87,767424,0);
      $88 = (($i$03) + 8|0);
      __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$88,767440,0);
      $89 = (($i$03) + 12|0);
      __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$89,767448,0);
      $90 = (($i$03) + 16|0);
      $91 = ($90|0)==($38|0);
      if ($91) {
       break;
      } else {
       $i$03 = $90;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $92 = HEAP32[$data>>2]|0;
   $93 = $92;
   $94 = HEAP32[$92>>2]|0;
   $95 = (($94) + ($93))|0;
   $96 = $95;
   $97 = (($92) + 4|0);
   HEAP32[$97>>2] = $96;
   $98 = ($96|0)==($38|0);
   if (!($98)) {
    $i$14 = $96;
    while(1) {
     $99 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768344,$converter$i$i,1)|0);
     $100 = ($99|0)==(0);
     if (!($100)) {
      $101 = ($99|0)>(0);
      if ($101) {
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$i$14,767416,0);
       $102 = (($i$14) + 4|0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$102,767424,0);
       $103 = (($i$14) + 8|0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$103,767440,0);
       $104 = (($i$14) + 12|0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$104,767448,0);
      } else {
       $105 = HEAP32[$converter$i$i>>2]|0;
       $106 = ($105|0)==(0|0);
       if (!($106)) {
        (FUNCTION_TABLE_iii[$105 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $107 = (($i$14) + 16|0);
     $108 = ($107|0)==($38|0);
     if ($108) {
      break;
     } else {
      $i$14 = $107;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation9DenseClip8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, $converter$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i = sp + 12|0;
 $ArrayTransfer$i = sp;
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,767456,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$0,767472,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$1,766544,0);
 $2 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$2,767488,0);
 $3 = (($this) + 20|0);
 $4 = (($this) + 16|0);
 $5 = (($transfer) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $3;
 $7 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$7>>2] = $4;
 $8 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$8>>2] = $6;
 $9 = HEAP32[580760>>2]|0;
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767504,$9,$converter$i$i$i,1)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($10|0)>(0);
 if ($12) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 } else {
  $13 = HEAP32[$converter$i$i$i>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   (FUNCTION_TABLE_iii[$13 & 4095]($ArrayTransfer$i,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human9HumanPose8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i5 = 0, $converter$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i4 = sp + 8|0;
 $ArrayTransfer$i5 = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767592,768416,$converter$i$i$i4,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$this,767568,0);
   $3 = (($this) + 16|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$3,767576,0);
   $4 = (($this) + 32|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$4,767584,0);
  } else {
   $5 = HEAP32[$converter$i$i$i4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$7,767600,0);
 $8 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$8,767624,0);
 $9 = (($this) + 80|0);
 HEAP32[$ArrayTransfer$i5>>2] = 4;
 $10 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = HEAP32[580704>>2]|0;
 $12 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767640,$11,$converter$i$i$i4,1)|0);
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = ($12|0)>(0);
  if ($14) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI19StaticArrayTransferIN7mecanim5human9HumanGoalELi4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5,0);
  } else {
   $15 = HEAP32[$converter$i$i$i4>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    (FUNCTION_TABLE_iii[$15 & 4095]($ArrayTransfer$i5,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $17 = (($this) + 384|0);
 $18 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767656,768440,$converter$i$i$i4,1)|0);
 $19 = ($18|0)==(0);
 if (!($19)) {
  $20 = ($18|0)>(0);
  if ($20) {
   __ZN7mecanim4hand8HandPose8TransferI14SafeBinaryReadEEvRT_($17,$transfer);
  } else {
   $21 = HEAP32[$converter$i$i$i4>>2]|0;
   $22 = ($21|0)==(0|0);
   if (!($22)) {
    (FUNCTION_TABLE_iii[$21 & 4095]($17,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $23 = (($this) + 528|0);
 $24 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767672,768440,$converter$i$i$i4,1)|0);
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = ($24|0)>(0);
  if ($26) {
   __ZN7mecanim4hand8HandPose8TransferI14SafeBinaryReadEEvRT_($23,$transfer);
  } else {
   $27 = HEAP32[$converter$i$i$i4>>2]|0;
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    (FUNCTION_TABLE_iii[$27 & 4095]($23,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $29 = (($this) + 672|0);
 HEAP32[$ArrayTransfer$i5>>2] = 52;
 $30 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$30>>2] = $29;
 $31 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767688,$11,$converter$i$i$i4,1)|0);
 $32 = ($31|0)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = ($31|0)>(0);
 if ($33) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI19StaticArrayTransferIfLi52EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5,0);
 } else {
  $34 = HEAP32[$converter$i$i$i4>>2]|0;
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   (FUNCTION_TABLE_iii[$34 & 4095]($ArrayTransfer$i5,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI19StaticArrayTransferIfLi52EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $i$03 = 0;
 var $i$15 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$data>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$size>>2]|0;
 $5 = ($4>>>0)>(52);
 $6 = $5 ? 52 : $4;
 HEAP32[$data>>2] = $6;
 $7 = (($data) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = ($4|0)==(0);
 L4: do {
  if (!($10)) {
   $11 = HEAP32[580584>>2]|0;
   $12 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,$11,0,0)|0);
   $13 = (($this) + 80|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__ZNK16TypeTreeIterator7GetNodeEv($14)|0);
   $16 = (($15) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($this) + 84|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$19>>2] = 0;
   $20 = ($12|0)==(2);
   if (!($20)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $71 = HEAP32[$7>>2]|0;
    $72 = ($71|0)==($9|0);
    if ($72) {
     break;
    } else {
     $i$15 = $71;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$15,766688,0);
     $73 = (($i$15) + 4|0);
     $74 = ($73|0)==($9|0);
     if ($74) {
      break L4;
     } else {
      $i$15 = $73;
     }
    }
   }
   $21 = HEAP32[$13>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$7>>2]|0;
   $25 = ($24|0)==($9|0);
   L11: do {
    if (!($25)) {
     $26 = (($this) + 12|0);
     $27 = (($this) + 16|0);
     $28 = (($this) + 28|0);
     $29 = (($this) + 32|0);
     $30 = (($this) + 20|0);
     $32 = 0;$35 = $21;$i$03 = $24;
     while(1) {
      $31 = Math_imul($32, $17)|0;
      $33 = (($31) + ($23))|0;
      $34 = (($35) + 20|0);
      HEAP32[$34>>2] = $33;
      $36 = (($35) + 12|0);
      HEAP32[$36>>2] = $33;
      $37 = (($35) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$35);
      $38 = $1;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = (($38) + 4)|0;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = $37;
      $45 = $44;
      HEAP32[$45>>2] = $40;
      $46 = (($44) + 4)|0;
      $47 = $46;
      HEAP32[$47>>2] = $43;
      $48 = HEAP32[$18>>2]|0;
      $49 = HEAP32[$48>>2]|0;
      $50 = (($49) + 1)|0;
      HEAP32[$48>>2] = $50;
      $51 = HEAP32[$13>>2]|0;
      $52 = (($51) + 12|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = HEAP32[$27>>2]|0;
      $55 = HEAP32[$28>>2]|0;
      $56 = HEAP32[$29>>2]|0;
      $57 = Math_imul($56, $55)|0;
      $$sum$i$i$i = (($53) - ($57))|0;
      $58 = (($54) + ($$sum$i$i$i)|0);
      HEAP32[$26>>2] = $58;
      $59 = ($$sum$i$i$i|0)<(0);
      if ($59) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $60 = (($54) + ($$sum1$i$i$i)|0);
       $61 = HEAP32[$30>>2]|0;
       $62 = ($60>>>0)>($61>>>0);
       if ($62) {
        label = 9;
       } else {
        $63 = Math_fround(HEAPF32[$58>>2]);
        HEAPF32[$i$03>>2] = $63;
        HEAP32[$26>>2] = $60;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($26,$i$03,4);
      }
      $64 = HEAP32[$this>>2]|0;
      $65 = $64 & 512;
      $66 = ($65|0)==(0);
      if (!($66)) {
       $67 = HEAP32[$i$03>>2]|0;
       $68 = (_llvm_bswap_i32(($67|0))|0);
       HEAP32[$i$03>>2] = $68;
      }
      $69 = (($i$03) + 4|0);
      $70 = ($69|0)==($9|0);
      if ($70) {
       break L11;
      }
      $$pre = HEAP32[$18>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$13>>2]|0;
      $32 = $$pre8;$35 = $$pre9;$i$03 = $69;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim4hand8HandPose8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0;
 var $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 8|0;
 $ArrayTransfer$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767704,768416,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$this,767568,0);
   $3 = (($this) + 16|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$3,767576,0);
   $4 = (($this) + 32|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$4,767584,0);
  } else {
   $5 = HEAP32[$converter$i$i>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 48|0);
 HEAP32[$ArrayTransfer$i>>2] = 20;
 $8 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[580704>>2]|0;
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767688,$9,$converter$i$i,1)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ($10|0)>(0);
  if ($12) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI19StaticArrayTransferIfLi20EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
  } else {
   $13 = HEAP32[$converter$i$i>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    (FUNCTION_TABLE_iii[$13 & 4095]($ArrayTransfer$i,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $15 = (($this) + 128|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$15,767712,0);
 $16 = (($this) + 132|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,767728,0);
 $17 = (($this) + 136|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$17,767744,0);
 $18 = (($this) + 140|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$18,767752,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI19StaticArrayTransferIfLi20EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $i$03 = 0;
 var $i$15 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$data>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$size>>2]|0;
 $5 = ($4>>>0)>(20);
 $6 = $5 ? 20 : $4;
 HEAP32[$data>>2] = $6;
 $7 = (($data) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6<<2)|0);
 $10 = ($4|0)==(0);
 L4: do {
  if (!($10)) {
   $11 = HEAP32[580584>>2]|0;
   $12 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,$11,0,0)|0);
   $13 = (($this) + 80|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (__ZNK16TypeTreeIterator7GetNodeEv($14)|0);
   $16 = (($15) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($this) + 84|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$19>>2] = 0;
   $20 = ($12|0)==(2);
   if (!($20)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $71 = HEAP32[$7>>2]|0;
    $72 = ($71|0)==($9|0);
    if ($72) {
     break;
    } else {
     $i$15 = $71;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$15,766688,0);
     $73 = (($i$15) + 4|0);
     $74 = ($73|0)==($9|0);
     if ($74) {
      break L4;
     } else {
      $i$15 = $73;
     }
    }
   }
   $21 = HEAP32[$13>>2]|0;
   $22 = (($21) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$7>>2]|0;
   $25 = ($24|0)==($9|0);
   L11: do {
    if (!($25)) {
     $26 = (($this) + 12|0);
     $27 = (($this) + 16|0);
     $28 = (($this) + 28|0);
     $29 = (($this) + 32|0);
     $30 = (($this) + 20|0);
     $32 = 0;$35 = $21;$i$03 = $24;
     while(1) {
      $31 = Math_imul($32, $17)|0;
      $33 = (($31) + ($23))|0;
      $34 = (($35) + 20|0);
      HEAP32[$34>>2] = $33;
      $36 = (($35) + 12|0);
      HEAP32[$36>>2] = $33;
      $37 = (($35) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$35);
      $38 = $1;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = (($38) + 4)|0;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = $37;
      $45 = $44;
      HEAP32[$45>>2] = $40;
      $46 = (($44) + 4)|0;
      $47 = $46;
      HEAP32[$47>>2] = $43;
      $48 = HEAP32[$18>>2]|0;
      $49 = HEAP32[$48>>2]|0;
      $50 = (($49) + 1)|0;
      HEAP32[$48>>2] = $50;
      $51 = HEAP32[$13>>2]|0;
      $52 = (($51) + 12|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = HEAP32[$27>>2]|0;
      $55 = HEAP32[$28>>2]|0;
      $56 = HEAP32[$29>>2]|0;
      $57 = Math_imul($56, $55)|0;
      $$sum$i$i$i = (($53) - ($57))|0;
      $58 = (($54) + ($$sum$i$i$i)|0);
      HEAP32[$26>>2] = $58;
      $59 = ($$sum$i$i$i|0)<(0);
      if ($59) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
       $60 = (($54) + ($$sum1$i$i$i)|0);
       $61 = HEAP32[$30>>2]|0;
       $62 = ($60>>>0)>($61>>>0);
       if ($62) {
        label = 9;
       } else {
        $63 = Math_fround(HEAPF32[$58>>2]);
        HEAPF32[$i$03>>2] = $63;
        HEAP32[$26>>2] = $60;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($26,$i$03,4);
      }
      $64 = HEAP32[$this>>2]|0;
      $65 = $64 & 512;
      $66 = ($65|0)==(0);
      if (!($66)) {
       $67 = HEAP32[$i$03>>2]|0;
       $68 = (_llvm_bswap_i32(($67|0))|0);
       HEAP32[$i$03>>2] = $68;
      }
      $69 = (($i$03) + 4|0);
      $70 = ($69|0)==($9|0);
      if ($70) {
       break L11;
      }
      $$pre = HEAP32[$18>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$13>>2]|0;
      $32 = $$pre8;$35 = $$pre9;$i$03 = $69;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI19StaticArrayTransferIN7mecanim5human9HumanGoalELi4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $i$03 = 0;
 var $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$data>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$size>>2]|0;
 $5 = ($4>>>0)>(4);
 $6 = $5 ? 4 : $4;
 HEAP32[$data>>2] = $6;
 $7 = (($data) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + (($6*76)|0)|0);
 $10 = ($4|0)==(0);
 do {
  if (!($10)) {
   $11 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768456,0,1)|0);
   $12 = (($this) + 80|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (__ZNK16TypeTreeIterator7GetNodeEv($13)|0);
   $15 = (($14) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($this) + 84|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$18>>2] = 0;
   $19 = ($11|0)==(2);
   if ($19) {
    $20 = HEAP32[$12>>2]|0;
    $21 = (($20) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$7>>2]|0;
    $24 = ($23|0)==($9|0);
    L8: do {
     if (!($24)) {
      $26 = 0;$29 = $20;$i$03 = $23;
      while(1) {
       $25 = Math_imul($26, $16)|0;
       $27 = (($25) + ($22))|0;
       $28 = (($29) + 20|0);
       HEAP32[$28>>2] = $27;
       $30 = (($29) + 12|0);
       HEAP32[$30>>2] = $27;
       $31 = (($29) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$29);
       $32 = $1;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = $31;
       $39 = $38;
       HEAP32[$39>>2] = $34;
       $40 = (($38) + 4)|0;
       $41 = $40;
       HEAP32[$41>>2] = $37;
       $42 = HEAP32[$17>>2]|0;
       $43 = HEAP32[$42>>2]|0;
       $44 = (($43) + 1)|0;
       HEAP32[$42>>2] = $44;
       __ZN15SerializeTraitsIN7mecanim5human9HumanGoalEE8TransferI14SafeBinaryReadEEvRS2_RT_($i$03,$this);
       $45 = (($i$03) + 76|0);
       $46 = ($45|0)==($9|0);
       if ($46) {
        break L8;
       }
       $$pre = HEAP32[$17>>2]|0;
       $$pre8 = HEAP32[$$pre>>2]|0;
       $$pre9 = HEAP32[$12>>2]|0;
       $26 = $$pre8;$29 = $$pre9;$i$03 = $45;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $47 = HEAP32[$7>>2]|0;
   $48 = ($47|0)==($9|0);
   if (!($48)) {
    $i$14 = $47;
    while(1) {
     $49 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768456,$converter$i$i,1)|0);
     $50 = ($49|0)==(0);
     if (!($50)) {
      $51 = ($49|0)>(0);
      if ($51) {
       __ZN15SerializeTraitsIN7mecanim5human9HumanGoalEE8TransferI14SafeBinaryReadEEvRS2_RT_($i$14,$this);
      } else {
       $52 = HEAP32[$converter$i$i>>2]|0;
       $53 = ($52|0)==(0|0);
       if (!($53)) {
        (FUNCTION_TABLE_iii[$52 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $54 = (($i$14) + 76|0);
     $55 = ($54|0)==($9|0);
     if ($55) {
      break;
     } else {
      $i$14 = $54;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsIN7mecanim5human9HumanGoalEE8TransferI14SafeBinaryReadEEvRS2_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,767760,768416,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = ($0|0)>(0);
  if ($2) {
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$data,767568,0);
   $3 = (($data) + 16|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$3,767576,0);
   $4 = (($data) + 32|0);
   __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$4,767584,0);
  } else {
   $5 = HEAP32[$converter$i$i>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($data) + 48|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$7,767768,0);
 $8 = (($data) + 52|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$8,767784,0);
 $9 = (($data) + 56|0);
 __ZN14SafeBinaryRead8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$9,767800,0);
 $10 = (($data) + 72|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$10,767808,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 48)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768520,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN13AnimationClip9PPtrCurve8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 48|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768520,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN13AnimationClip9PPtrCurve8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 48|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip9PPtrCurve8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i4 = sp;
 $0 = (($this) + 32|0);
 $1 = HEAP32[580760>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768024,$1,$converter$i$i4,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI12PPtrKeyframeLj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 12|0);
 $8 = HEAP32[580712>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766776,$8,$converter$i$i4,0)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = ($9|0)>(0);
  if ($11) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$7,0);
  } else {
   $12 = HEAP32[$converter$i$i4>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    (FUNCTION_TABLE_iii[$12 & 4095]($7,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766768,$8,$converter$i$i4,0)|0);
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = ($14|0)>(0);
  if ($16) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $17 = HEAP32[$converter$i$i4>>2]|0;
   $18 = ($17|0)==(0|0);
   if (!($18)) {
    (FUNCTION_TABLE_iii[$17 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $19 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$19,766800,0);
 $20 = (($this) + 28|0);
 $21 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766792,768480,$converter$i$i4,1)|0);
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = ($21|0)>(0);
 if ($23) {
  __ZN4PPtrI10MonoScriptE8TransferI14SafeBinaryReadEEvRT_($20,$transfer);
 } else {
  $24 = HEAP32[$converter$i$i4>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   (FUNCTION_TABLE_iii[$24 & 4095]($20,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI12PPtrKeyframeLj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $converter$i$i = sp + 16|0;
 $size = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI12PPtrKeyframeLj4EEE19ResizeSTLStyleArrayERS2_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<3)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768504,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $28 = HEAP32[580624>>2]|0;
      $30 = 0;$33 = $23;$i$03 = $26;
      while(1) {
       $29 = Math_imul($30, $19)|0;
       $31 = (($29) + ($25))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$33);
       $36 = $2;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$20>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$03,768032,0);
       $49 = (($i$03) + 4|0);
       $50 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,768040,$28,$$byval_copy,1)|0);
       $51 = ($50|0)==(0);
       if (!($51)) {
        $52 = ($50|0)>(0);
        if ($52) {
         __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($49,$this);
        } else {
         $53 = HEAP32[$$byval_copy>>2]|0;
         $54 = ($53|0)==(0|0);
         if (!($54)) {
          (FUNCTION_TABLE_iii[$53 & 4095]($49,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $55 = (($i$03) + 8|0);
       $56 = ($55|0)==($11|0);
       if ($56) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre7 = HEAP32[$$pre>>2]|0;
       $$pre8 = HEAP32[$15>>2]|0;
       $30 = $$pre7;$33 = $$pre8;$i$03 = $55;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $57 = HEAP32[$data>>2]|0;
   $58 = ($57|0)==($11|0);
   if (!($58)) {
    $59 = HEAP32[580624>>2]|0;
    $i$14 = $57;
    while(1) {
     $60 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768504,$converter$i$i,1)|0);
     $61 = ($60|0)==(0);
     if (!($61)) {
      $62 = ($60|0)>(0);
      if ($62) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$14,768032,0);
       $63 = (($i$14) + 4|0);
       $64 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,768040,$59,$$byval_copy,1)|0);
       $65 = ($64|0)==(0);
       if (!($65)) {
        $66 = ($64|0)>(0);
        if ($66) {
         __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($63,$this);
        } else {
         $67 = HEAP32[$$byval_copy>>2]|0;
         $68 = ($67|0)==(0|0);
         if (!($68)) {
          (FUNCTION_TABLE_iii[$67 & 4095]($63,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $69 = HEAP32[$converter$i$i>>2]|0;
       $70 = ($69|0)==(0|0);
       if (!($70)) {
        (FUNCTION_TABLE_iii[$69 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $71 = (($i$14) + 8|0);
     $72 = ($71|0)==($11|0);
     if ($72) {
      break;
     } else {
      $i$14 = $71;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 116)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768568,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN13AnimationClip10FloatCurve8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 116|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768568,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN13AnimationClip10FloatCurve8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 116|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip10FloatCurve8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i4 = sp;
 $0 = (($this) + 32|0);
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768024,768536,$converter$i$i4,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN17AnimationCurveTplIfE8TransferI14SafeBinaryReadEEvRT_($0,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i4>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 12|0);
 $7 = HEAP32[580712>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766776,$7,$converter$i$i4,0)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($8|0)>(0);
  if ($10) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$6,0);
  } else {
   $11 = HEAP32[$converter$i$i4>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    (FUNCTION_TABLE_iii[$11 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766768,$7,$converter$i$i4,0)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $16 = HEAP32[$converter$i$i4>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    (FUNCTION_TABLE_iii[$16 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $18 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$18,766800,0);
 $19 = (($this) + 28|0);
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766792,768480,$converter$i$i4,1)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = ($20|0)>(0);
 if ($22) {
  __ZN4PPtrI10MonoScriptE8TransferI14SafeBinaryReadEEvRT_($19,$transfer);
 } else {
  $23 = HEAP32[$converter$i$i4>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   (FUNCTION_TABLE_iii[$23 & 4095]($19,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 160)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768584,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN13AnimationClip12Vector3Curve8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 160|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768584,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN13AnimationClip12Vector3Curve8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 160|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip12Vector3Curve8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = (($this) + 12|0);
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768024,768536,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN17AnimationCurveTplI8Vector3fE8TransferI14SafeBinaryReadEEvRT_($0,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = HEAP32[580712>>2]|0;
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766768,$6,$converter$i$i1,0)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = ($7|0)>(0);
 if ($9) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 } else {
  $10 = HEAP32[$converter$i$i1>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   (FUNCTION_TABLE_iii[$10 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplI8Vector3fE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 120|0);
 $1 = HEAP32[580760>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768048,$1,$converter$i$i,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 136|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$7,768056,0);
 $8 = (($this) + 140|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$8,768072,0);
 __ZN17AnimationCurveTplI8Vector3fE15InvalidateCacheEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplI8Vector3fELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*40)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768552,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN15SerializeTraitsI11KeyframeTplI8Vector3fEE8TransferI14SafeBinaryReadEEvRS2_RT_($i$01,$this);
       $48 = (($i$01) + 40|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768552,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN15SerializeTraitsI11KeyframeTplI8Vector3fEE8TransferI14SafeBinaryReadEEvRS2_RT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 40|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI11KeyframeTplI8Vector3fEE8TransferI14SafeBinaryReadEEvRS2_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$data,768032,0);
 $0 = (($data) + 4|0);
 $1 = HEAP32[580776>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768040,$1,$converter$i$i3,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$0,767536,0);
   $5 = (($data) + 8|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,767544,0);
   $6 = (($data) + 12|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$6,767552,0);
  } else {
   $7 = HEAP32[$converter$i$i3>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    (FUNCTION_TABLE_iii[$7 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $9 = (($data) + 16|0);
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768088,$1,$converter$i$i3,1)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ($10|0)>(0);
  if ($12) {
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$9,767536,0);
   $13 = (($data) + 20|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,767544,0);
   $14 = (($data) + 24|0);
   __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$14,767552,0);
  } else {
   $15 = HEAP32[$converter$i$i3>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    (FUNCTION_TABLE_iii[$15 & 4095]($9,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $17 = (($data) + 28|0);
 $18 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768096,$1,$converter$i$i3,1)|0);
 $19 = ($18|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = ($18|0)>(0);
 if ($20) {
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$17,767536,0);
  $21 = (($data) + 32|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$21,767544,0);
  $22 = (($data) + 36|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$22,767552,0);
 } else {
  $23 = HEAP32[$converter$i$i3>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   (FUNCTION_TABLE_iii[$23 & 4095]($17,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 84)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768616,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN24CompressedAnimationCurve8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 84|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768616,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN24CompressedAnimationCurve8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 84|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN24CompressedAnimationCurve8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i$i$i = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp + 4|0;
 $converter$i$i$i$i = sp;
 $0 = (($this) + 72|0);
 $1 = HEAP32[580712>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768112,$1,$converter$i$i3,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i3>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768120,768600,$converter$i$i3,1)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  if ($9) {
   __ZN15PackedIntVector8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
  } else {
   $10 = HEAP32[$converter$i$i3>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    (FUNCTION_TABLE_iii[$10 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $12 = (($this) + 20|0);
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768128,768600,$converter$i$i3,1)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$12,768160,0);
   $16 = (($this) + 24|0);
   $17 = HEAP32[580760>>2]|0;
   $18 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768176,$17,$converter$i$i$i$i,1)|0);
   $19 = ($18|0)==(0);
   if (!($19)) {
    $20 = ($18|0)>(0);
    if ($20) {
     __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIhNS1_9allocatorIhEEEEEEvRT_17TransferMetaFlags($transfer,$16,0);
    } else {
     $21 = HEAP32[$converter$i$i$i$i>>2]|0;
     $22 = ($21|0)==(0|0);
     if (!($22)) {
      (FUNCTION_TABLE_iii[$21 & 4095]($16,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
  } else {
   $23 = HEAP32[$converter$i$i3>>2]|0;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    (FUNCTION_TABLE_iii[$23 & 4095]($12,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $25 = (($this) + 36|0);
 $26 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768144,768600,$converter$i$i3,1)|0);
 $27 = ($26|0)==(0);
 if ($27) {
  $31 = (($this) + 64|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$31,768056,0);
  $32 = (($this) + 68|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$32,768072,0);
  STACKTOP = sp;return;
 }
 $28 = ($26|0)>(0);
 if ($28) {
  __ZN17PackedFloatVector8TransferI14SafeBinaryReadEEvRT_($25,$transfer);
 } else {
  $29 = HEAP32[$converter$i$i3>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   (FUNCTION_TABLE_iii[$29 & 4095]($25,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $31 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$31,768056,0);
 $32 = (($this) + 68|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$32,768072,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 192)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768648,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN13AnimationClip15QuaternionCurve8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 192|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768648,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN13AnimationClip15QuaternionCurve8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 192|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip15QuaternionCurve8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = (($this) + 12|0);
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768024,768536,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN17AnimationCurveTplI11QuaternionfE8TransferI14SafeBinaryReadEEvRT_($0,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = HEAP32[580712>>2]|0;
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,766768,$6,$converter$i$i1,0)|0);
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = ($7|0)>(0);
 if ($9) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$this,0);
 } else {
  $10 = HEAP32[$converter$i$i1>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   (FUNCTION_TABLE_iii[$10 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplI11QuaternionfE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 152|0);
 $1 = HEAP32[580760>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768048,$1,$converter$i$i,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 168|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$7,768056,0);
 $8 = (($this) + 172|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$8,768072,0);
 __ZN17AnimationCurveTplI11QuaternionfE15InvalidateCacheEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,768184,768184,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI11KeyframeTplI11QuaternionfELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + (($10*52)|0)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768552,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$01,768032,0);
       $48 = (($i$01) + 4|0);
       __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($this,$48,768040,0);
       $49 = (($i$01) + 20|0);
       __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($this,$49,768088,0);
       $50 = (($i$01) + 36|0);
       __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($this,$50,768096,0);
       $51 = (($i$01) + 52|0);
       $52 = ($51|0)==($11|0);
       if ($52) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $51;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $53 = HEAP32[$data>>2]|0;
   $54 = ($53|0)==($11|0);
   if (!($54)) {
    $i$12 = $53;
    while(1) {
     $55 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,766688,768552,$$byval_copy,1)|0);
     $56 = ($55|0)==(0);
     if (!($56)) {
      $57 = ($55|0)>(0);
      if ($57) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$12,768032,0);
       $58 = (($i$12) + 4|0);
       __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($this,$58,768040,0);
       $59 = (($i$12) + 20|0);
       __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($this,$59,768088,0);
       $60 = (($i$12) + 36|0);
       __ZN14SafeBinaryRead8TransferI11QuaternionfEEvRT_PKc17TransferMetaFlags($this,$60,768096,0);
      } else {
       $61 = HEAP32[$$byval_copy>>2]|0;
       $62 = ($61|0)==(0|0);
       if (!($62)) {
        (FUNCTION_TABLE_iii[$61 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $63 = (($i$12) + 52|0);
     $64 = ($63|0)==($11|0);
     if ($64) {
      break;
     } else {
      $i$12 = $63;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $empty = 0, $empty1 = 0, $p$i$i$i12 = 0, $scevgep$i$i$i = 0, $value = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1808|0;
 $$byval_copy3 = sp + 160|0;
 $p$i$i$i12 = sp;
 $0 = sp + 116|0;
 $1 = sp + 120|0;
 $empty = sp + 124|0;
 $empty1 = sp + 136|0;
 $value = sp + 148|0;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,6);
 $2 = (($this) + 164|0);
 $3 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766376,$3,$2,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 84|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766144,$3,$10,16);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$7>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 85|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766392,$3,$15,16);
 $16 = HEAP32[$4>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$7>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $20 = HEAP8[$10>>0]|0;
 $21 = ($20<<24>>24)==(0);
 L1: do {
  if ($21) {
   $22 = (($this) + 92|0);
   __ZN13ProxyTransfer8TransferINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags($transfer,$22,766416,1);
   HEAP32[$empty>>2] = 0;
   $23 = (($empty) + 4|0);
   HEAP32[$23>>2] = 0;
   $24 = (($empty) + 8|0);
   HEAP32[$24>>2] = 0;
   __THREW__ = 0;
   invoke_viiii(413,($transfer|0),($empty|0),(766440|0),1);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP32[$empty>>2]|0;
    $28 = ($27|0)==(0|0);
    if ($28) {
     break;
    }
    while(1) {
     $29 = HEAP32[$23>>2]|0;
     $30 = ($29|0)==($27|0);
     if ($30) {
      break;
     }
     $31 = (($29) + -84|0);
     HEAP32[$23>>2] = $31;
     __THREW__ = 0;
     invoke_vi(3690,($31|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      label = 6;
      break;
     }
    }
    if ((label|0) == 6) {
     $34 = ___cxa_find_matching_catch()|0;
     $35 = tempRet0;
     ___cxa_call_unexpected(($34|0));
     // unreachable;
    }
    $36 = HEAP32[$empty>>2]|0;
    HEAP32[$1>>2] = 18;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($36|0),($$byval_copy3|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     break;
    }
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    ___cxa_call_unexpected(($39|0));
    // unreachable;
   }
   $41 = ___cxa_find_matching_catch()|0;
   $42 = tempRet0;
   $43 = HEAP32[$empty>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    $$1 = $42;$$12 = $41;
    ___resumeException($$12|0);
    // unreachable;
   }
   while(1) {
    $45 = HEAP32[$23>>2]|0;
    $46 = ($45|0)==($43|0);
    if ($46) {
     break;
    }
    $47 = (($45) + -84|0);
    HEAP32[$23>>2] = $47;
    __THREW__ = 0;
    invoke_vi(3690,($47|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 12;
     break;
    }
   }
   if ((label|0) == 12) {
    $50 = ___cxa_find_matching_catch()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   }
   $52 = HEAP32[$empty>>2]|0;
   HEAP32[$0>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($52|0),($$byval_copy3|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    $55 = ___cxa_find_matching_catch()|0;
    $56 = tempRet0;
    ___cxa_call_unexpected(($55|0));
    // unreachable;
   } else {
    $$1 = $42;$$12 = $41;
    ___resumeException($$12|0);
    // unreachable;
   }
  } else {
   HEAP32[$empty1>>2] = 0;
   $57 = (($empty1) + 4|0);
   HEAP32[$57>>2] = 0;
   $58 = (($empty1) + 8|0);
   HEAP32[$58>>2] = 0;
   __THREW__ = 0;
   invoke_viiii(414,($transfer|0),($empty1|0),(766416|0),1);
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   L3: do {
    if ($60) {
     $68 = ___cxa_find_matching_catch()|0;
     $69 = tempRet0;
     $$0 = $69;$$01 = $68;
    } else {
     $61 = HEAP32[$transfer>>2]|0;
     $62 = $61 & 33554432;
     $63 = ($62|0)==(0);
     do {
      if ($63) {
       HEAP32[$value>>2] = 0;
       $64 = (($value) + 4|0);
       HEAP32[$64>>2] = 0;
       $65 = (($value) + 8|0);
       HEAP32[$65>>2] = 0;
       __THREW__ = 0;
       invoke_viiii(413,($transfer|0),($value|0),(766440|0),1);
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        $70 = ___cxa_find_matching_catch()|0;
        $71 = tempRet0;
        $72 = HEAP32[$value>>2]|0;
        $73 = ($72|0)==(0|0);
        if ($73) {
         $$0 = $71;$$01 = $70;
         break L3;
        }
        while(1) {
         $74 = HEAP32[$64>>2]|0;
         $75 = ($74|0)==($72|0);
         if ($75) {
          break;
         }
         $76 = (($74) + -84|0);
         HEAP32[$64>>2] = $76;
         __THREW__ = 0;
         invoke_vi(3690,($76|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          label = 22;
          break;
         }
        }
        if ((label|0) == 22) {
         $79 = ___cxa_find_matching_catch()|0;
         $80 = tempRet0;
         ___cxa_call_unexpected(($79|0));
         // unreachable;
        }
        $81 = HEAP32[$value>>2]|0;
        HEAP32[$p$i$i$i12>>2] = 18;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$p$i$i$i12+0>>2]|0;
        invoke_vii(2591,($81|0),($$byval_copy3|0));
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if (!($83)) {
         $$0 = $71;$$01 = $70;
         break L3;
        }
        $84 = ___cxa_find_matching_catch()|0;
        $85 = tempRet0;
        ___cxa_call_unexpected(($84|0));
        // unreachable;
       } else {
        $86 = HEAP32[$value>>2]|0;
        $87 = ($86|0)==(0|0);
        if ($87) {
         break;
        }
        while(1) {
         $88 = HEAP32[$64>>2]|0;
         $89 = ($88|0)==($86|0);
         if ($89) {
          break;
         }
         $90 = (($88) + -84|0);
         HEAP32[$64>>2] = $90;
         __THREW__ = 0;
         invoke_vi(3690,($90|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 28;
          break;
         }
        }
        if ((label|0) == 28) {
         $93 = ___cxa_find_matching_catch()|0;
         $94 = tempRet0;
         ___cxa_call_unexpected(($93|0));
         // unreachable;
        }
        $95 = HEAP32[$value>>2]|0;
        HEAP32[$0>>2] = 18;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($95|0),($$byval_copy3|0));
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if (!($97)) {
         break;
        }
        $98 = ___cxa_find_matching_catch()|0;
        $99 = tempRet0;
        ___cxa_call_unexpected(($98|0));
        // unreachable;
       }
      }
     } while(0);
     __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
     break L1;
    }
   } while(0);
   __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($empty1);
   $$1 = $$0;$$12 = $$01;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $100 = (($this) + 104|0);
 __ZN13ProxyTransfer8TransferINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags($transfer,$100,766472,1);
 $101 = (($this) + 116|0);
 __ZN13ProxyTransfer8TransferINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags($transfer,$101,766496,1);
 $102 = (($this) + 128|0);
 $103 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766512,$103,$102,1);
 $104 = (($p$i$i$i12) + 28|0);
 HEAP32[$104>>2] = 0;
 $105 = (($p$i$i$i12) + 36|0);
 ;HEAP32[$p$i$i$i12+0>>2]=0|0;HEAP32[$p$i$i$i12+4>>2]=0|0;HEAP32[$p$i$i$i12+8>>2]=0|0;HEAP32[$p$i$i$i12+12>>2]=0|0;HEAP32[$p$i$i$i12+16>>2]=0|0;HEAP32[$p$i$i$i12+20>>2]=0|0;
 HEAPF32[$105>>2] = Math_fround(inf);
 $106 = (($p$i$i$i12) + 32|0);
 HEAP32[$106>>2] = 0;
 $107 = (($p$i$i$i12) + 40|0);
 ;HEAP32[$107+0>>2]=0|0;HEAP32[$107+4>>2]=0|0;HEAP32[$107+8>>2]=0|0;HEAP32[$107+12>>2]=0|0;HEAP32[$107+16>>2]=0|0;
 $108 = (($p$i$i$i12) + 64|0);
 HEAPF32[$108>>2] = Math_fround(inf);
 $109 = (($p$i$i$i12) + 60|0);
 HEAP32[$109>>2] = 0;
 $110 = (($p$i$i$i12) + 68|0);
 $111 = (($p$i$i$i12) + 96|0);
 HEAP32[$111>>2] = 0;
 $112 = (($p$i$i$i12) + 100|0);
 HEAP32[$112>>2] = 0;
 $113 = (($p$i$i$i12) + 92|0);
 ;HEAP32[$110+0>>2]=0|0;HEAP32[$110+4>>2]=0|0;HEAP32[$110+8>>2]=0|0;HEAP32[$110+12>>2]=0|0;HEAP32[$110+16>>2]=0|0;HEAP32[$110+20>>2]=0|0;
 HEAP32[$113>>2] = 61;
 $114 = (($p$i$i$i12) + 108|0);
 HEAP32[$114>>2] = 2;
 $115 = (($p$i$i$i12) + 104|0);
 HEAP32[$115>>2] = 2;
 $116 = (($p$i$i$i12) + 112|0);
 HEAP32[$116>>2] = 0;
 __THREW__ = 0;
 invoke_viiiii(87,($transfer|0),(768184|0),(768184|0),($$byval_copy3|0),0);
 $117 = __THREW__; __THREW__ = 0;
 $118 = $117&1;
 if (!($118)) {
  __THREW__ = 0;
  invoke_viiiii(86,($transfer|0),(766688|0),(768568|0),($p$i$i$i12|0),0);
  $119 = __THREW__; __THREW__ = 0;
  $120 = $119&1;
  if (!($120)) {
   __THREW__ = 0;
   invoke_vii(3388,($p$i$i$i12|0),($transfer|0));
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if (!($122)) {
    __THREW__ = 0;
    invoke_vi(3390,($transfer|0));
    $123 = __THREW__; __THREW__ = 0;
    $124 = $123&1;
    if (!($124)) {
     __THREW__ = 0;
     invoke_vi(3391,($transfer|0));
     $125 = __THREW__; __THREW__ = 0;
     $126 = $125&1;
     if (!($126)) {
      __ZN13AnimationClip10FloatCurveD2Ev($p$i$i$i12);
      __ZN13ProxyTransfer11EndTransferEv($transfer);
      $133 = (($this) + 140|0);
      __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766528,$103,$133,1);
      $134 = (($p$i$i$i12) + 28|0);
      HEAP32[$134>>2] = 0;
      $135 = (($p$i$i$i12) + 32|0);
      HEAP32[$135>>2] = 0;
      $136 = (($p$i$i$i12) + 40|0);
      HEAP32[$136>>2] = 0;
      $137 = (($p$i$i$i12) + 44|0);
      HEAP32[$137>>2] = 0;
      $138 = (($p$i$i$i12) + 36|0);
      ;HEAP32[$p$i$i$i12+0>>2]=0|0;HEAP32[$p$i$i$i12+4>>2]=0|0;HEAP32[$p$i$i$i12+8>>2]=0|0;HEAP32[$p$i$i$i12+12>>2]=0|0;HEAP32[$p$i$i$i12+16>>2]=0|0;HEAP32[$p$i$i$i12+20>>2]=0|0;
      HEAP32[$138>>2] = 61;
      __THREW__ = 0;
      invoke_viiiii(87,($transfer|0),(768184|0),(768184|0),($$byval_copy3|0),0);
      $139 = __THREW__; __THREW__ = 0;
      $140 = $139&1;
      if (!($140)) {
       __THREW__ = 0;
       invoke_viiiii(86,($transfer|0),(766688|0),(768520|0),($p$i$i$i12|0),0);
       $141 = __THREW__; __THREW__ = 0;
       $142 = $141&1;
       if (!($142)) {
        __THREW__ = 0;
        invoke_vii(3389,($p$i$i$i12|0),($transfer|0));
        $143 = __THREW__; __THREW__ = 0;
        $144 = $143&1;
        if (!($144)) {
         __THREW__ = 0;
         invoke_vi(3390,($transfer|0));
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         if (!($146)) {
          __THREW__ = 0;
          invoke_vi(3391,($transfer|0));
          $147 = __THREW__; __THREW__ = 0;
          $148 = $147&1;
          if (!($148)) {
           __ZN13AnimationClip9PPtrCurveD2Ev($p$i$i$i12);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $155 = (($this) + 80|0);
           $156 = HEAP32[580584>>2]|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766544,$156,$155,0);
           $157 = HEAP32[$4>>2]|0;
           $158 = HEAP32[$157>>2]|0;
           $159 = HEAP32[$7>>2]|0;
           $160 = ((($158) + (($159*24)|0)|0) + 12|0);
           HEAP32[$160>>2] = 4;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $161 = (($this) + 88|0);
           $162 = HEAP32[580592>>2]|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766560,$162,$161,0);
           $163 = HEAP32[$4>>2]|0;
           $164 = HEAP32[$163>>2]|0;
           $165 = HEAP32[$7>>2]|0;
           $166 = ((($164) + (($165*24)|0)|0) + 12|0);
           HEAP32[$166>>2] = 4;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $167 = (($this) + 216|0);
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766576,768472,$167,0);
           __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$167,767992,0);
           $168 = (($this) + 228|0);
           __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($transfer,$168,768008,0);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $169 = (($this) + 48|0);
           $170 = (($transfer) + 4|0);
           HEAP32[$170>>2] = $169;
           $171 = (($this) + 172|0);
           $172 = HEAP32[580752>>2]|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766624,$172,$171,0);
           $173 = HEAP32[$4>>2]|0;
           $174 = HEAP32[$173>>2]|0;
           $175 = HEAP32[$7>>2]|0;
           $176 = ((($174) + (($175*24)|0)|0) + 12|0);
           HEAP32[$176>>2] = 4;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           __ZN7mecanim5human9HumanPoseC2Ev($$byval_copy3);
           $177 = (($$byval_copy3) + 880|0);
           $178 = (($$byval_copy3) + 908|0);
           ;HEAP32[$177+0>>2]=0|0;HEAP32[$177+4>>2]=0|0;HEAP32[$177+8>>2]=0|0;HEAP32[$177+12>>2]=0|0;HEAP32[$177+16>>2]=0|0;HEAP32[$177+20>>2]=0|0;HEAP32[$177+24>>2]=0|0;
           HEAPF32[$178>>2] = Math_fround(1.0);
           $179 = (($$byval_copy3) + 912|0);
           HEAPF32[$179>>2] = Math_fround(1.0);
           $180 = (($$byval_copy3) + 916|0);
           HEAPF32[$180>>2] = Math_fround(1.0);
           $181 = (($$byval_copy3) + 920|0);
           HEAPF32[$181>>2] = Math_fround(1.0);
           $182 = (($$byval_copy3) + 924|0);
           HEAPF32[$182>>2] = Math_fround(1.0);
           $183 = (($$byval_copy3) + 928|0);
           $184 = (($$byval_copy3) + 956|0);
           ;HEAP32[$183+0>>2]=0|0;HEAP32[$183+4>>2]=0|0;HEAP32[$183+8>>2]=0|0;HEAP32[$183+12>>2]=0|0;HEAP32[$183+16>>2]=0|0;HEAP32[$183+20>>2]=0|0;HEAP32[$183+24>>2]=0|0;
           HEAPF32[$184>>2] = Math_fround(1.0);
           $185 = (($$byval_copy3) + 960|0);
           HEAPF32[$185>>2] = Math_fround(1.0);
           $186 = (($$byval_copy3) + 964|0);
           HEAPF32[$186>>2] = Math_fround(1.0);
           $187 = (($$byval_copy3) + 968|0);
           HEAPF32[$187>>2] = Math_fround(1.0);
           $188 = (($$byval_copy3) + 972|0);
           HEAPF32[$188>>2] = Math_fround(1.0);
           $189 = (($$byval_copy3) + 976|0);
           $190 = (($$byval_copy3) + 1004|0);
           ;HEAP32[$189+0>>2]=0|0;HEAP32[$189+4>>2]=0|0;HEAP32[$189+8>>2]=0|0;HEAP32[$189+12>>2]=0|0;HEAP32[$189+16>>2]=0|0;HEAP32[$189+20>>2]=0|0;HEAP32[$189+24>>2]=0|0;
           HEAPF32[$190>>2] = Math_fround(1.0);
           $191 = (($$byval_copy3) + 1008|0);
           HEAPF32[$191>>2] = Math_fround(1.0);
           $192 = (($$byval_copy3) + 1012|0);
           HEAPF32[$192>>2] = Math_fround(1.0);
           $193 = (($$byval_copy3) + 1016|0);
           HEAPF32[$193>>2] = Math_fround(1.0);
           $194 = (($$byval_copy3) + 1020|0);
           HEAPF32[$194>>2] = Math_fround(1.0);
           $195 = (($$byval_copy3) + 1024|0);
           $196 = (($$byval_copy3) + 1052|0);
           ;HEAP32[$195+0>>2]=0|0;HEAP32[$195+4>>2]=0|0;HEAP32[$195+8>>2]=0|0;HEAP32[$195+12>>2]=0|0;HEAP32[$195+16>>2]=0|0;HEAP32[$195+20>>2]=0|0;HEAP32[$195+24>>2]=0|0;
           HEAPF32[$196>>2] = Math_fround(1.0);
           $197 = (($$byval_copy3) + 1056|0);
           $198 = (($$byval_copy3) + 1620|0);
           $199 = (($$byval_copy3) + 1639|0);
           ;HEAP32[$197+0>>2]=0|0;HEAP32[$197+4>>2]=0|0;HEAP32[$197+8>>2]=0|0;HEAP32[$197+12>>2]=0|0;
           ;HEAP32[$198+0>>2]=0|0;HEAP32[$198+4>>2]=0|0;HEAP32[$198+8>>2]=0|0;HEAP32[$198+12>>2]=0|0;HEAP16[$198+16>>1]=0|0;HEAP8[$198+18>>0]=0|0;
           HEAP8[$199>>0] = 1;
           $200 = (($$byval_copy3) + 1640|0);
           HEAP8[$200>>0] = 0;
           $201 = (($$byval_copy3) + 1641|0);
           HEAP8[$201>>0] = 0;
           $scevgep$i$i$i = (($$byval_copy3) + 1072|0);
           _memset(($scevgep$i$i$i|0),-1,548)|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766608,768256,$$byval_copy3,0);
           __ZN7mecanim9animation18ClipMuscleConstant8TransferI13ProxyTransferEEvRT_($$byval_copy3,$transfer);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $202 = (($this) + 176|0);
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766648,768208,$202,0);
           __ZN11UnityEngine9Animation28AnimationClipBindingConstant8TransferI13ProxyTransferEEvRT_($202,$transfer);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $203 = (($this) + 152|0);
           $204 = HEAP32[580760>>2]|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766672,$204,$203,1);
           __ZN13ProxyTransfer21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($transfer,0,0);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
      $149 = ___cxa_find_matching_catch()|0;
      $150 = tempRet0;
      __THREW__ = 0;
      invoke_vi(3692,($p$i$i$i12|0));
      $151 = __THREW__; __THREW__ = 0;
      $152 = $151&1;
      if ($152) {
       $153 = ___cxa_find_matching_catch(0|0)|0;
       $154 = tempRet0;
       ___clang_call_terminate($153);
       // unreachable;
      } else {
       ___resumeException($149|0);
       // unreachable;
      }
     }
    }
   }
  }
 }
 $127 = ___cxa_find_matching_catch()|0;
 $128 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3693,($p$i$i$i12|0));
 $129 = __THREW__; __THREW__ = 0;
 $130 = $129&1;
 if ($130) {
  $131 = ___cxa_find_matching_catch(0|0)|0;
  $132 = tempRet0;
  ___clang_call_terminate($131);
  // unreachable;
 } else {
  ___resumeException($127|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $p$i$i = 0, $p$i$i$i$i = 0, $size$i = 0, $size$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $$byval_copy5 = sp + 216|0;
 $size$i$i$i$i$i = sp;
 $p$i$i$i$i = sp + 4|0;
 $size$i = sp + 8|0;
 $0 = sp + 12|0;
 $1 = sp + 16|0;
 $p$i$i = sp + 24|0;
 $2 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$2,$data,$metaFlag);
 ;HEAP32[$p$i$i+0>>2]=0|0;HEAP32[$p$i$i+4>>2]=0|0;HEAP32[$p$i$i+8>>2]=0|0;
 $3 = (($p$i$i) + 16|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($p$i$i) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($p$i$i) + 20|0);
 dest=$5+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $6 = (($p$i$i) + 92|0);
 HEAPF32[$6>>2] = Math_fround(inf);
 $7 = (($p$i$i) + 88|0);
 HEAP32[$7>>2] = 0;
 $8 = (($p$i$i) + 96|0);
 $9 = (($p$i$i) + 172|0);
 HEAP32[$9>>2] = 0;
 $10 = (($p$i$i) + 176|0);
 HEAP32[$10>>2] = 0;
 $11 = (($p$i$i) + 168|0);
 dest=$8+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$11>>2] = 61;
 $12 = (($p$i$i) + 184|0);
 HEAP32[$12>>2] = 2;
 $13 = (($p$i$i) + 180|0);
 HEAP32[$13>>2] = 2;
 $14 = (($p$i$i) + 188|0);
 HEAP32[$14>>2] = 0;
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(768184|0),(768184|0),($size$i|0),0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(766688|0),(768648|0),($p$i$i|0),0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   $19 = (($p$i$i) + 12|0);
   __THREW__ = 0;
   invoke_viiiii(86,($this|0),(768024|0),(768536|0),($19|0),0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    invoke_vii(3390,($19|0),($this|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     invoke_vi(3390,($this|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[580712>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(86,($this|0),(766768|0),($26|0),($p$i$i|0),0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       __THREW__ = 0;
       invoke_viiiii(87,($this|0),(768184|0),(768184|0),($size$i$i$i$i$i|0),1);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = HEAP32[580552>>2]|0;
        __THREW__ = 0;
        invoke_viiiii(86,($this|0),(766688|0),($31|0),($p$i$i$i$i|0),0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         $34 = (($this) + 12|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = HEAP32[$35>>2]|0;
         $37 = (($this) + 20|0);
         $38 = HEAP32[$37>>2]|0;
         $39 = ((($36) + (($38*24)|0)|0) + 12|0);
         HEAP32[$39>>2] = 1;
         __THREW__ = 0;
         invoke_vi(3390,($this|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          __THREW__ = 0;
          invoke_vi(3391,($this|0));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if (!($43)) {
           __THREW__ = 0;
           invoke_vi(3392,($this|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if (!($45)) {
            __THREW__ = 0;
            invoke_vi(3390,($this|0));
            $46 = __THREW__; __THREW__ = 0;
            $47 = $46&1;
            if (!($47)) {
             __THREW__ = 0;
             invoke_vi(3390,($this|0));
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if (!($49)) {
              __THREW__ = 0;
              invoke_vi(3391,($this|0));
              $50 = __THREW__; __THREW__ = 0;
              $51 = $50&1;
              if (!($51)) {
               $81 = HEAP32[$10>>2]|0;
               $82 = ($81|0)>(-1);
               do {
                if ($82) {
                 $83 = (($p$i$i) + 164|0);
                 $84 = HEAP32[$83>>2]|0;
                 $85 = HEAP32[$11>>2]|0;
                 HEAP32[$p$i$i$i$i>>2] = $85;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$p$i$i$i$i+0>>2]|0;
                 invoke_vii(2591,($84|0),($$byval_copy5|0));
                 $86 = __THREW__; __THREW__ = 0;
                 $87 = $86&1;
                 if (!($87)) {
                  HEAP32[$83>>2] = 0;
                  break;
                 }
                 $97 = ___cxa_find_matching_catch()|0;
                 $98 = tempRet0;
                 $99 = HEAP8[$p$i$i>>0]|0;
                 $100 = $99 & 1;
                 $101 = ($100<<24>>24)==(0);
                 if ($101) {
                  ___resumeException($97|0);
                  // unreachable;
                 }
                 $102 = (($p$i$i) + 8|0);
                 $103 = HEAP32[$102>>2]|0;
                 HEAP32[$size$i$i$i$i$i>>2] = 59;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$size$i$i$i$i$i+0>>2]|0;
                 invoke_vii(2591,($103|0),($$byval_copy5|0));
                 $104 = __THREW__; __THREW__ = 0;
                 $105 = $104&1;
                 if ($105) {
                  $106 = ___cxa_find_matching_catch()|0;
                  $107 = tempRet0;
                  ___cxa_call_unexpected(($106|0));
                  // unreachable;
                 } else {
                  ___resumeException($97|0);
                  // unreachable;
                 }
                }
               } while(0);
               $88 = HEAP8[$p$i$i>>0]|0;
               $89 = $88 & 1;
               $90 = ($89<<24>>24)==(0);
               if ($90) {
                __ZN13ProxyTransfer11EndTransferEv($this);
                STACKTOP = sp;return;
               }
               $91 = (($p$i$i) + 8|0);
               $92 = HEAP32[$91>>2]|0;
               HEAP32[$size$i$i$i$i$i>>2] = 59;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$size$i$i$i$i$i+0>>2]|0;
               invoke_vii(2591,($92|0),($$byval_copy5|0));
               $93 = __THREW__; __THREW__ = 0;
               $94 = $93&1;
               if ($94) {
                $95 = ___cxa_find_matching_catch()|0;
                $96 = tempRet0;
                ___cxa_call_unexpected(($95|0));
                // unreachable;
               } else {
                __ZN13ProxyTransfer11EndTransferEv($this);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $52 = ___cxa_find_matching_catch()|0;
 $53 = tempRet0;
 $54 = HEAP32[$10>>2]|0;
 $55 = ($54|0)>(-1);
 do {
  if ($55) {
   $56 = (($p$i$i) + 164|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = HEAP32[$11>>2]|0;
   HEAP32[$1>>2] = $58;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($57|0),($$byval_copy5|0));
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if (!($60)) {
    HEAP32[$56>>2] = 0;
    break;
   }
   $70 = ___cxa_find_matching_catch(0|0)|0;
   $71 = tempRet0;
   $72 = HEAP8[$p$i$i>>0]|0;
   $73 = $72 & 1;
   $74 = ($73<<24>>24)==(0);
   if ($74) {
    ___clang_call_terminate($70);
    // unreachable;
   }
   $75 = (($p$i$i) + 8|0);
   $76 = HEAP32[$75>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($76|0),($$byval_copy5|0));
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    $79 = ___cxa_find_matching_catch()|0;
    $80 = tempRet0;
    ___cxa_call_unexpected(($79|0));
    // unreachable;
   } else {
    ___clang_call_terminate($70);
    // unreachable;
   }
  }
 } while(0);
 $61 = HEAP8[$p$i$i>>0]|0;
 $62 = $61 & 1;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  ___resumeException($52|0);
  // unreachable;
 }
 $64 = (($p$i$i) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($65|0),($$byval_copy5|0));
 $66 = __THREW__; __THREW__ = 0;
 $67 = $66&1;
 if ($67) {
  $68 = ___cxa_find_matching_catch()|0;
  $69 = tempRet0;
  ___cxa_call_unexpected(($68|0));
  // unreachable;
 } else {
  ___resumeException($52|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $size$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 92|0;
 $0 = sp;
 $size$i$i$i = sp + 4|0;
 $p$i$i = sp + 8|0;
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$1,$data,$metaFlag);
 $2 = (($p$i$i) + 8|0);
 HEAP32[$p$i$i>>2] = 0;
 $3 = (($p$i$i) + 4|0);
 HEAP8[$3>>0] = 0;
 $4 = (($p$i$i) + 52|0);
 dest=$2+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$2+40>>0]=0|0;
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;HEAP32[$4+28>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(768184|0),(768184|0),($size$i$i$i|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(766688|0),(768616|0),($p$i$i|0),0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vii(3391,($p$i$i|0),($this|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3390,($this|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3391,($this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $43 = (($p$i$i) + 72|0);
      $44 = HEAP8[$43>>0]|0;
      $45 = $44 & 1;
      $46 = ($45<<24>>24)==(0);
      if (!($46)) {
       $47 = (($p$i$i) + 80|0);
       $48 = HEAP32[$47>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($48|0),($$byval_copy1|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        $51 = ___cxa_find_matching_catch()|0;
        $52 = tempRet0;
        ___cxa_call_unexpected(($51|0));
        // unreachable;
       }
      }
      $53 = HEAP32[$4>>2]|0;
      $54 = ($53|0)==(0|0);
      if (!($54)) {
       $55 = (($p$i$i) + 56|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = ($56|0)==($53|0);
       if (!($57)) {
        HEAP32[$55>>2] = $53;
       }
       __ZdlPv($53);
      }
      $58 = (($p$i$i) + 24|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($59|0)==(0|0);
      if (!($60)) {
       $61 = (($p$i$i) + 28|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = ($62|0)==($59|0);
       if (!($63)) {
        HEAP32[$61>>2] = $59;
       }
       __ZdlPv($59);
      }
      $64 = HEAP32[$2>>2]|0;
      $65 = ($64|0)==(0|0);
      if ($65) {
       __ZN13ProxyTransfer11EndTransferEv($this);
       STACKTOP = sp;return;
      }
      $66 = (($p$i$i) + 12|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==($64|0);
      if (!($68)) {
       HEAP32[$66>>2] = $64;
      }
      __ZdlPv($64);
      __ZN13ProxyTransfer11EndTransferEv($this);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $17 = (($p$i$i) + 72|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  $21 = (($p$i$i) + 80|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($22|0),($$byval_copy1|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   ___cxa_call_unexpected(($25|0));
   // unreachable;
  }
 }
 $27 = HEAP32[$4>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = (($p$i$i) + 56|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($30|0)==($27|0);
  if (!($31)) {
   HEAP32[$29>>2] = $27;
  }
  __ZdlPv($27);
 }
 $32 = (($p$i$i) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = (($p$i$i) + 28|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==($33|0);
  if (!($37)) {
   HEAP32[$35>>2] = $33;
  }
  __ZdlPv($33);
 }
 $38 = HEAP32[$2>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  ___resumeException($15|0);
  // unreachable;
 }
 $40 = (($p$i$i) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==($38|0);
 if (!($42)) {
  HEAP32[$40>>2] = $38;
 }
 __ZdlPv($38);
 ___resumeException($15|0);
 // unreachable;
}
function __ZN13ProxyTransfer8TransferINSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $p$i$i = 0, $p$i$i$i$i$i = 0, $size$i = 0, $size$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy5 = sp + 184|0;
 $size$i$i$i$i$i$i = sp;
 $p$i$i$i$i$i = sp + 4|0;
 $size$i = sp + 8|0;
 $0 = sp + 12|0;
 $1 = sp + 16|0;
 $p$i$i = sp + 24|0;
 $2 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$2,$data,$metaFlag);
 ;HEAP32[$p$i$i+0>>2]=0|0;HEAP32[$p$i$i+4>>2]=0|0;HEAP32[$p$i$i+8>>2]=0|0;
 $3 = (($p$i$i) + 16|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($p$i$i) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($p$i$i) + 20|0);
 dest=$5+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $6 = (($p$i$i) + 76|0);
 HEAPF32[$6>>2] = Math_fround(inf);
 $7 = (($p$i$i) + 72|0);
 HEAP32[$7>>2] = 0;
 $8 = (($p$i$i) + 80|0);
 $9 = (($p$i$i) + 140|0);
 HEAP32[$9>>2] = 0;
 $10 = (($p$i$i) + 144|0);
 HEAP32[$10>>2] = 0;
 $11 = (($p$i$i) + 136|0);
 dest=$8+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$11>>2] = 61;
 $12 = (($p$i$i) + 152|0);
 HEAP32[$12>>2] = 2;
 $13 = (($p$i$i) + 148|0);
 HEAP32[$13>>2] = 2;
 $14 = (($p$i$i) + 156|0);
 HEAP32[$14>>2] = 0;
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(768184|0),(768184|0),($size$i|0),0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(766688|0),(768584|0),($p$i$i|0),0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   $19 = (($p$i$i) + 12|0);
   __THREW__ = 0;
   invoke_viiii(415,($this|0),($19|0),(768024|0),0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP32[580712>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($this|0),(766768|0),($22|0),($p$i$i|0),0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_viiiii(87,($this|0),(768184|0),(768184|0),($size$i$i$i$i$i$i|0),1);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[580552>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(86,($this|0),(766688|0),($27|0),($p$i$i$i$i$i|0),0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       $30 = (($this) + 12|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = HEAP32[$31>>2]|0;
       $33 = (($this) + 20|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ((($32) + (($34*24)|0)|0) + 12|0);
       HEAP32[$35>>2] = 1;
       __THREW__ = 0;
       invoke_vi(3390,($this|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __THREW__ = 0;
        invoke_vi(3391,($this|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         __THREW__ = 0;
         invoke_vi(3392,($this|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          __THREW__ = 0;
          invoke_vi(3390,($this|0));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if (!($43)) {
           __THREW__ = 0;
           invoke_vi(3390,($this|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if (!($45)) {
            __THREW__ = 0;
            invoke_vi(3391,($this|0));
            $46 = __THREW__; __THREW__ = 0;
            $47 = $46&1;
            if (!($47)) {
             $77 = HEAP32[$10>>2]|0;
             $78 = ($77|0)>(-1);
             do {
              if ($78) {
               $79 = (($p$i$i) + 132|0);
               $80 = HEAP32[$79>>2]|0;
               $81 = HEAP32[$11>>2]|0;
               HEAP32[$p$i$i$i$i$i>>2] = $81;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$p$i$i$i$i$i+0>>2]|0;
               invoke_vii(2591,($80|0),($$byval_copy5|0));
               $82 = __THREW__; __THREW__ = 0;
               $83 = $82&1;
               if (!($83)) {
                HEAP32[$79>>2] = 0;
                break;
               }
               $93 = ___cxa_find_matching_catch()|0;
               $94 = tempRet0;
               $95 = HEAP8[$p$i$i>>0]|0;
               $96 = $95 & 1;
               $97 = ($96<<24>>24)==(0);
               if ($97) {
                ___resumeException($93|0);
                // unreachable;
               }
               $98 = (($p$i$i) + 8|0);
               $99 = HEAP32[$98>>2]|0;
               HEAP32[$size$i$i$i$i$i$i>>2] = 59;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$size$i$i$i$i$i$i+0>>2]|0;
               invoke_vii(2591,($99|0),($$byval_copy5|0));
               $100 = __THREW__; __THREW__ = 0;
               $101 = $100&1;
               if ($101) {
                $102 = ___cxa_find_matching_catch()|0;
                $103 = tempRet0;
                ___cxa_call_unexpected(($102|0));
                // unreachable;
               } else {
                ___resumeException($93|0);
                // unreachable;
               }
              }
             } while(0);
             $84 = HEAP8[$p$i$i>>0]|0;
             $85 = $84 & 1;
             $86 = ($85<<24>>24)==(0);
             if ($86) {
              __ZN13ProxyTransfer11EndTransferEv($this);
              STACKTOP = sp;return;
             }
             $87 = (($p$i$i) + 8|0);
             $88 = HEAP32[$87>>2]|0;
             HEAP32[$size$i$i$i$i$i$i>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$size$i$i$i$i$i$i+0>>2]|0;
             invoke_vii(2591,($88|0),($$byval_copy5|0));
             $89 = __THREW__; __THREW__ = 0;
             $90 = $89&1;
             if ($90) {
              $91 = ___cxa_find_matching_catch()|0;
              $92 = tempRet0;
              ___cxa_call_unexpected(($91|0));
              // unreachable;
             } else {
              __ZN13ProxyTransfer11EndTransferEv($this);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $48 = ___cxa_find_matching_catch()|0;
 $49 = tempRet0;
 $50 = HEAP32[$10>>2]|0;
 $51 = ($50|0)>(-1);
 do {
  if ($51) {
   $52 = (($p$i$i) + 132|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = HEAP32[$11>>2]|0;
   HEAP32[$1>>2] = $54;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($53|0),($$byval_copy5|0));
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if (!($56)) {
    HEAP32[$52>>2] = 0;
    break;
   }
   $66 = ___cxa_find_matching_catch(0|0)|0;
   $67 = tempRet0;
   $68 = HEAP8[$p$i$i>>0]|0;
   $69 = $68 & 1;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    ___clang_call_terminate($66);
    // unreachable;
   }
   $71 = (($p$i$i) + 8|0);
   $72 = HEAP32[$71>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($72|0),($$byval_copy5|0));
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    ___cxa_call_unexpected(($75|0));
    // unreachable;
   } else {
    ___clang_call_terminate($66);
    // unreachable;
   }
  }
 } while(0);
 $57 = HEAP8[$p$i$i>>0]|0;
 $58 = $57 & 1;
 $59 = ($58<<24>>24)==(0);
 if ($59) {
  ___resumeException($48|0);
  // unreachable;
 }
 $60 = (($p$i$i) + 8|0);
 $61 = HEAP32[$60>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($61|0),($$byval_copy5|0));
 $62 = __THREW__; __THREW__ = 0;
 $63 = $62&1;
 if ($63) {
  $64 = ___cxa_find_matching_catch()|0;
  $65 = tempRet0;
  ___cxa_call_unexpected(($64|0));
  // unreachable;
 } else {
  ___resumeException($48|0);
  // unreachable;
 }
}
function __ZN13ProxyTransfer21TransferSTLStyleArrayINSt3__16vectorI14AnimationEvent13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags($this,$0,$metaFlag) {
 $this = $this|0;
 $0 = $0|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy3 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p = 0, $size$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy3 = sp + 72|0;
 $1 = sp;
 $2 = sp + 4|0;
 $size$i = sp + 8|0;
 $p = sp + 16|0;
 HEAPF32[$p>>2] = Math_fround(0.0);
 $3 = (($p) + 4|0);
 HEAP8[$3>>0] = 0;
 $4 = (($3) + 1|0);
 HEAP8[$4>>0] = 0;
 $5 = (($p) + 16|0);
 HEAP8[$5>>0] = 0;
 $6 = (($5) + 1|0);
 HEAP8[$6>>0] = 0;
 $7 = (($p) + 28|0);
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;HEAP32[$7+24>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiii(87,($this|0),(768184|0),(768184|0),($size$i|0),($metaFlag|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),(766688|0),(768192|0),($p|0),0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   invoke_vii(3392,($p|0),($this|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    invoke_vi(3390,($this|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_vi(3391,($this|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      $18 = HEAP8[$5>>0]|0;
      $19 = $18 & 1;
      $20 = ($19<<24>>24)==(0);
      if (!($20)) {
       $21 = (($p) + 24|0);
       $22 = HEAP32[$21>>2]|0;
       HEAP32[$2>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
       invoke_vii(2591,($22|0),($$byval_copy3|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        $25 = ___cxa_find_matching_catch()|0;
        $26 = tempRet0;
        ___cxa_call_unexpected(($25|0));
        // unreachable;
       }
      }
      $27 = HEAP8[$3>>0]|0;
      $28 = $27 & 1;
      $29 = ($28<<24>>24)==(0);
      if ($29) {
       STACKTOP = sp;return;
      }
      $30 = (($p) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($31|0),($$byval_copy3|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       $34 = ___cxa_find_matching_catch()|0;
       $35 = tempRet0;
       ___cxa_call_unexpected(($34|0));
       // unreachable;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = HEAP8[$5>>0]|0;
 $39 = $38 & 1;
 $40 = ($39<<24>>24)==(0);
 if (!($40)) {
  $41 = (($p) + 24|0);
  $42 = HEAP32[$41>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($42|0),($$byval_copy3|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   $45 = ___cxa_find_matching_catch()|0;
   $46 = tempRet0;
   ___cxa_call_unexpected(($45|0));
   // unreachable;
  }
 }
 $47 = HEAP8[$3>>0]|0;
 $48 = $47 & 1;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  ___resumeException($36|0);
  // unreachable;
 }
 $50 = (($p) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($51|0),($$byval_copy3|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  ___cxa_call_unexpected(($54|0));
  // unreachable;
 } else {
  ___resumeException($36|0);
  // unreachable;
 }
}
function __ZN11UnityEngine9Animation28AnimationClipBindingConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier$i$i$i$i$i$i = 0, $p$i$i = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $localIdentifier$i$i$i$i$i$i = sp;
 $size$i$i$i = sp + 24|0;
 $p$i$i = sp + 16|0;
 $0 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766696,$0,$this,0);
 ;HEAP32[$size$i$i$i+0>>2]=0|0;HEAP32[$size$i$i$i+4>>2]=0|0;HEAP32[$size$i$i$i+8>>2]=0|0;HEAP32[$size$i$i$i+12>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$localIdentifier$i$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,768240,$size$i$i$i,0);
 __ZN11UnityEngine9Animation14GenericBinding8TransferI13ProxyTransferEEvRT_($size$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $1 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766712,$0,$1,0);
 HEAP32[$p$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i,0);
 $2 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$2,$p$i$i,0);
 $3 = (($localIdentifier$i$i$i$i$i$i) + 8|0);
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i$i>>2] = 0;
 $8 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766736,$8,$p$i$i,1);
 $9 = (($transfer) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($transfer) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($11) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766752,$15,$3,1);
 $16 = HEAP32[$9>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$12>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11UnityEngine9Animation14GenericBinding8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 $0 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766768,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766776,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 $13 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766792,$13,$12,0);
 $14 = (($localIdentifier$i$i$i) + 8|0);
 $15 = $14;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $19 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766736,$19,$12,1);
 $20 = HEAP32[$1>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$4>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766752,$24,$14,1);
 $25 = HEAP32[$1>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$4>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 12|0);
 $30 = HEAP32[580720>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766800,$30,$29,0);
 $31 = HEAP32[$1>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$4>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $35 = (($this) + 14|0);
 $36 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766808,$36,$35,0);
 $37 = HEAP32[$1>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$4>>2]|0;
 $40 = ((($38) + (($39*24)|0)|0) + 12|0);
 HEAP32[$40>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $41 = (($this) + 15|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766824,$36,$41,0);
 $42 = HEAP32[$1>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$4>>2]|0;
 $45 = ((($43) + (($44*24)|0)|0) + 12|0);
 HEAP32[$45>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18ClipMuscleConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $ArrayTransfer$i1 = 0, $p$i$i2 = 0, $size$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $size$i$i$i = sp + 24|0;
 $p$i$i2 = sp;
 $ArrayTransfer$i1 = sp + 8|0;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766840,768424,$this,0);
 __ZN7mecanim5human9HumanPose8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $0 = (($this) + 880|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766856,768416,$0,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767568,768408,$0,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $1 = (($this) + 896|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767576,768408,$1,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($1,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($this) + 912|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767584,768408,$2,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($2,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $3 = (($this) + 928|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766872,768416,$3,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767568,768408,$3,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($3,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $4 = (($this) + 944|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767576,768408,$4,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($4,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $5 = (($this) + 960|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767584,768408,$5,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($5,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $6 = (($this) + 976|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766896,768416,$6,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767568,768408,$6,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($6,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 992|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767576,768408,$7,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($7,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 1008|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767584,768408,$8,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($8,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($this) + 1024|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766920,768408,$9,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($9,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 1040|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766936,768296,$10,0);
 dest=$size$i$i$i+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,768312,$size$i$i$i,0);
 __ZN7mecanim9animation4Clip8TransferI13ProxyTransferEEvRT_($size$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $11 = (($this) + 1048|0);
 $12 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766944,$12,$11,0);
 $13 = (($transfer) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($transfer) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($15) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 1052|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766960,$12,$19,0);
 $20 = HEAP32[$13>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$16>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($this) + 1056|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766976,$12,$24,0);
 $25 = HEAP32[$13>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$16>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 1060|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767000,$12,$29,0);
 $30 = HEAP32[$13>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$16>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $34 = (($this) + 1064|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767008,$12,$34,0);
 $35 = HEAP32[$13>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$16>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $39 = (($this) + 1068|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767024,$12,$39,0);
 $40 = HEAP32[$13>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$16>>2]|0;
 $43 = ((($41) + (($42*24)|0)|0) + 12|0);
 HEAP32[$43>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = (($this) + 1072|0);
 HEAP32[$ArrayTransfer$i1>>2] = 137;
 $45 = (($ArrayTransfer$i1) + 4|0);
 HEAP32[$45>>2] = $44;
 $46 = HEAP32[580704>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767048,$46,$ArrayTransfer$i1,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i,0);
 $47 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$47,$p$i$i2,0);
 $48 = HEAP32[$13>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$16>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $52 = (($this) + 1624|0);
 $53 = (($this) + 1620|0);
 $54 = (($transfer) + 4|0);
 $55 = HEAP32[$54>>2]|0;
 HEAP32[$ArrayTransfer$i1>>2] = $52;
 $56 = (($ArrayTransfer$i1) + 4|0);
 HEAP32[$56>>2] = $53;
 $57 = (($ArrayTransfer$i1) + 8|0);
 HEAP32[$57>>2] = $55;
 $58 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767064,$58,$ArrayTransfer$i1,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,768280,$p$i$i2,0);
 $59 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767320,$59,$p$i$i2,0);
 $60 = HEAP32[$13>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$16>>2]|0;
 $63 = ((($61) + (($62*24)|0)|0) + 12|0);
 HEAP32[$63>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $64 = (($p$i$i2) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767328,$59,$64,0);
 $65 = HEAP32[$13>>2]|0;
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$16>>2]|0;
 $68 = ((($66) + (($67*24)|0)|0) + 12|0);
 HEAP32[$68>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $69 = (($this) + 1632|0);
 $70 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767088,$70,$69,0);
 $71 = HEAP32[$13>>2]|0;
 $72 = HEAP32[$71>>2]|0;
 $73 = HEAP32[$16>>2]|0;
 $74 = ((($72) + (($73*24)|0)|0) + 12|0);
 HEAP32[$74>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $75 = (($this) + 1633|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767104,$70,$75,0);
 $76 = HEAP32[$13>>2]|0;
 $77 = HEAP32[$76>>2]|0;
 $78 = HEAP32[$16>>2]|0;
 $79 = ((($77) + (($78*24)|0)|0) + 12|0);
 HEAP32[$79>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $80 = (($this) + 1634|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767120,$70,$80,0);
 $81 = HEAP32[$13>>2]|0;
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$16>>2]|0;
 $84 = ((($82) + (($83*24)|0)|0) + 12|0);
 HEAP32[$84>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $85 = (($this) + 1635|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767136,$70,$85,0);
 $86 = HEAP32[$13>>2]|0;
 $87 = HEAP32[$86>>2]|0;
 $88 = HEAP32[$16>>2]|0;
 $89 = ((($87) + (($88*24)|0)|0) + 12|0);
 HEAP32[$89>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $90 = (($this) + 1636|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767160,$70,$90,0);
 $91 = HEAP32[$13>>2]|0;
 $92 = HEAP32[$91>>2]|0;
 $93 = HEAP32[$16>>2]|0;
 $94 = ((($92) + (($93*24)|0)|0) + 12|0);
 HEAP32[$94>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $95 = (($this) + 1637|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767184,$70,$95,0);
 $96 = HEAP32[$13>>2]|0;
 $97 = HEAP32[$96>>2]|0;
 $98 = HEAP32[$16>>2]|0;
 $99 = ((($97) + (($98*24)|0)|0) + 12|0);
 HEAP32[$99>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $100 = (($this) + 1638|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767208,$70,$100,0);
 $101 = HEAP32[$13>>2]|0;
 $102 = HEAP32[$101>>2]|0;
 $103 = HEAP32[$16>>2]|0;
 $104 = ((($102) + (($103*24)|0)|0) + 12|0);
 HEAP32[$104>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $105 = (($this) + 1639|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767240,$70,$105,0);
 $106 = HEAP32[$13>>2]|0;
 $107 = HEAP32[$106>>2]|0;
 $108 = HEAP32[$16>>2]|0;
 $109 = ((($107) + (($108*24)|0)|0) + 12|0);
 HEAP32[$109>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $110 = (($this) + 1640|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767264,$70,$110,0);
 $111 = HEAP32[$13>>2]|0;
 $112 = HEAP32[$111>>2]|0;
 $113 = HEAP32[$16>>2]|0;
 $114 = ((($112) + (($113*24)|0)|0) + 12|0);
 HEAP32[$114>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $115 = (($this) + 1641|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767296,$70,$115,0);
 $116 = HEAP32[$13>>2]|0;
 $117 = HEAP32[$116>>2]|0;
 $118 = HEAP32[$16>>2]|0;
 $119 = ((($117) + (($118*24)|0)|0) + 12|0);
 HEAP32[$119>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation4Clip8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0, $p$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i$i$i$i = sp + 16|0;
 $p$i$i$i$i$i$i = sp;
 $ArrayTransfer$i$i$i = sp + 4|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767336,768392,$this,0);
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i>>2] = $0;
 $3 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i$i$i) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$5,$ArrayTransfer$i$i$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i$i$i$i,0);
 $6 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$6,$p$i$i$i$i$i$i,0);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767520,$6,$13,0);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767352,768376,$18,0);
 __ZN7mecanim9animation9DenseClip8TransferI13ProxyTransferEEvRT_($18,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 44|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767368,768360,$19,0);
 $20 = (($this) + 48|0);
 $21 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i>>2] = $20;
 $22 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$22>>2] = $19;
 $23 = (($ArrayTransfer$i$i$i) + 8|0);
 HEAP32[$23>>2] = $21;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$5,$ArrayTransfer$i$i$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i$i$i$i,0);
 $24 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$24,$p$i$i$i$i$i$i,0);
 $25 = HEAP32[$7>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$10>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767384,768296,$29,0);
 __ZN15SerializeTraitsI9OffsetPtrIN7mecanim18ValueArrayConstantEEE8TransferI13ProxyTransferEEvRS3_RT_(0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim18ValueArrayConstantEEE8TransferI13ProxyTransferEEvRS3_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i = 0, $p = 0, $p$i$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $size$i$i$i$i$i$i$i$i = sp + 40|0;
 $p$i$i$i$i$i$i$i = sp;
 $ArrayTransfer$i$i$i$i = sp + 16|0;
 $p = sp + 28|0;
 HEAP32[$p>>2] = 0;
 $0 = (($p) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($p) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,768320,$p,0);
 $2 = (($p) + 4|0);
 $3 = (($transfer) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i>>2] = $2;
 $5 = (($ArrayTransfer$i$i$i$i) + 4|0);
 HEAP32[$5>>2] = $p;
 $6 = (($ArrayTransfer$i$i$i$i) + 8|0);
 HEAP32[$6>>2] = $4;
 $7 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767400,$7,$ArrayTransfer$i$i$i$i,0);
 HEAP32[$p$i$i$i$i$i$i$i>>2] = 0;
 $8 = (($p$i$i$i$i$i$i$i) + 4|0);
 HEAP32[$8>>2] = 0;
 $9 = (($p$i$i$i$i$i$i$i) + 8|0);
 HEAP32[$9>>2] = 10;
 $10 = (($p$i$i$i$i$i$i$i) + 12|0);
 HEAP32[$10>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,768344,$p$i$i$i$i$i$i$i,0);
 $11 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767416,$11,$p$i$i$i$i$i$i$i,0);
 $12 = (($transfer) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($transfer) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($14) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767424,$11,$8,0);
 $18 = HEAP32[$12>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$15>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767440,$11,$9,0);
 $22 = HEAP32[$12>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$15>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767448,$11,$10,0);
 $26 = HEAP32[$12>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$15>>2]|0;
 $29 = ((($27) + (($28*24)|0)|0) + 12|0);
 HEAP32[$29>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation9DenseClip8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, $p$i$i$i$i = 0, $size$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i$i = sp + 16|0;
 $p$i$i$i$i = sp;
 $ArrayTransfer$i = sp + 4|0;
 $0 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767456,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 $8 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767472,$8,$7,0);
 $9 = HEAP32[$1>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$4>>2]|0;
 $12 = ((($10) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 8|0);
 $14 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766544,$14,$13,0);
 $15 = HEAP32[$1>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$4>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767488,$14,$19,0);
 $20 = HEAP32[$1>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$4>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($this) + 20|0);
 $25 = (($this) + 16|0);
 $26 = (($transfer) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $24;
 $28 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$28>>2] = $25;
 $29 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$29>>2] = $27;
 $30 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767504,$30,$ArrayTransfer$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$14,$p$i$i$i$i,0);
 $31 = HEAP32[$1>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$4>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $buf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf = sp;
 $0 = Math_fround(HEAPF32[$data>>2]);
 HEAPF32[$buf>>2] = $0;
 $1 = (($buf) + 4|0);
 $2 = (($data) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$1>>2] = $3;
 $4 = (($buf) + 8|0);
 $5 = (($data) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 HEAPF32[$4>>2] = $6;
 $7 = (($buf) + 12|0);
 $8 = (($data) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 HEAPF32[$7>>2] = $9;
 $10 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767536,$10,$buf,0);
 $11 = (($transfer) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($transfer) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($13) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767544,$10,$1,0);
 $17 = HEAP32[$11>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$14>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767552,$10,$4,0);
 $21 = HEAP32[$11>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$14>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767560,$10,$7,0);
 $25 = HEAP32[$11>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$14>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = Math_fround(HEAPF32[$buf>>2]);
 $30 = Math_fround(HEAPF32[$1>>2]);
 $31 = Math_fround(HEAPF32[$4>>2]);
 $32 = Math_fround(HEAPF32[$7>>2]);
 HEAPF32[$data>>2] = $29;
 HEAPF32[$2>>2] = $30;
 HEAPF32[$5>>2] = $31;
 HEAPF32[$8>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human9HumanPose8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i3 = 0, $p$i$i$i$i2 = 0, $size$i$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $size$i$i$i$i$i1 = sp + 88|0;
 $p$i$i$i$i2 = sp;
 $ArrayTransfer$i3 = sp + 80|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767592,768416,$this,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767568,768408,$this,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $0 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767576,768408,$0,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $1 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767584,768408,$1,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($1,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767600,768408,$2,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($2,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $3 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767624,768408,$3,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($3,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $4 = (($this) + 80|0);
 HEAP32[$ArrayTransfer$i3>>2] = 4;
 $5 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[580704>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767640,$6,$ArrayTransfer$i3,0);
 $7 = (($p$i$i$i$i2) + 28|0);
 ;HEAP32[$p$i$i$i$i2+0>>2]=0|0;HEAP32[$p$i$i$i$i2+4>>2]=0|0;HEAP32[$p$i$i$i$i2+8>>2]=0|0;HEAP32[$p$i$i$i$i2+12>>2]=0|0;HEAP32[$p$i$i$i$i2+16>>2]=0|0;HEAP32[$p$i$i$i$i2+20>>2]=0|0;HEAP32[$p$i$i$i$i2+24>>2]=0|0;
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($p$i$i$i$i2) + 44|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($p$i$i$i$i2) + 40|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($p$i$i$i$i2) + 36|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($p$i$i$i$i2) + 32|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($p$i$i$i$i2) + 48|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;HEAP32[$12+20>>2]=0|0;HEAP32[$12+24>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i$i1,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,768456,$p$i$i$i$i2,0);
 __ZN7mecanim5human9HumanGoal8TransferI13ProxyTransferEEvRT_($p$i$i$i$i2,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 384|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767656,768440,$13,0);
 __ZN7mecanim4hand8HandPose8TransferI13ProxyTransferEEvRT_($13,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($this) + 528|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767672,768440,$14,0);
 __ZN7mecanim4hand8HandPose8TransferI13ProxyTransferEEvRT_($14,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 672|0);
 HEAP32[$ArrayTransfer$i3>>2] = 52;
 $16 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$16>>2] = $15;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767688,$6,$ArrayTransfer$i3,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i$i1,0);
 $17 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$17,$p$i$i$i$i2,0);
 $18 = (($transfer) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($transfer) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($20) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim4hand8HandPose8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, $p$i$i$i$i = 0, $size$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i$i = sp + 16|0;
 $p$i$i$i$i = sp;
 $ArrayTransfer$i = sp + 8|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767704,768416,$this,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767568,768408,$this,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $0 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767576,768408,$0,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $1 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767584,768408,$1,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($1,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($this) + 48|0);
 HEAP32[$ArrayTransfer$i>>2] = 20;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[580704>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767688,$4,$ArrayTransfer$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i$i,0);
 $5 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$5,$p$i$i$i$i,0);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($8) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 128|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767712,$5,$12,0);
 $13 = HEAP32[$6>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$9>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 132|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767728,$5,$17,0);
 $18 = HEAP32[$6>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$9>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 136|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767744,$5,$22,0);
 $23 = HEAP32[$6>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$9>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $27 = (($this) + 140|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767752,$5,$27,0);
 $28 = HEAP32[$6>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$9>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human9HumanGoal8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767760,768416,$this,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767568,768408,$this,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $0 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767576,768408,$0,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $1 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767584,768408,$1,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($1,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($this) + 48|0);
 $3 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767768,$3,$2,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767784,$3,$10,0);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$7>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767800,768408,$15,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($15,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 72|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,767808,$3,$16,0);
 $17 = HEAP32[$4>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$7>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip9PPtrCurve8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, $p$i$i$i = 0, $p$i$i$i4 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i = sp;
 $p$i$i$i4 = sp + 24|0;
 $p$i$i$i = sp + 16|0;
 $0 = (($this) + 32|0);
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768024,$1,$0,0);
 $2 = (($p$i$i$i) + 4|0);
 HEAP32[$2>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$p$i$i$i4,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,768504,$p$i$i$i,0);
 $3 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768032,$3,$p$i$i$i,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($p$i$i$i) + 4|0);
 $11 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768040,$11,$10,0);
 $12 = (($localIdentifier$i$i$i) + 8|0);
 $13 = $12;
 $14 = $13;
 HEAP32[$14>>2] = 0;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $17 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766736,$17,$10,1);
 $18 = HEAP32[$4>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$7>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766752,$22,$12,1);
 $23 = HEAP32[$4>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$7>>2]|0;
 $26 = ((($24) + (($25*24)|0)|0) + 12|0);
 HEAP32[$26>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $27 = (($this) + 12|0);
 $28 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766776,$28,$27,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$localIdentifier$i$i$i,1);
 $29 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$29,$p$i$i$i4,0);
 $30 = HEAP32[$4>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$7>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766768,$28,$this,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$localIdentifier$i$i$i,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$29,$p$i$i$i4,0);
 $34 = HEAP32[$4>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$7>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766800,$17,$38,0);
 $39 = HEAP32[$4>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$7>>2]|0;
 $42 = ((($40) + (($41*24)|0)|0) + 12|0);
 HEAP32[$42>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $43 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766792,768480,$43,0);
 $44 = (($localIdentifier$i$i$i) + 8|0);
 $45 = $44;
 $46 = $45;
 HEAP32[$46>>2] = 0;
 $47 = (($45) + 4)|0;
 $48 = $47;
 HEAP32[$48>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766736,$17,$43,1);
 $49 = HEAP32[$4>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$7>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766752,$22,$44,1);
 $53 = HEAP32[$4>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$7>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClip10FloatCurve8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i2 = 0, $size$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i1 = sp;
 $p$i$i$i2 = sp + 16|0;
 $0 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768024,768536,$0,0);
 __ZN17AnimationCurveTplIfE8TransferI13ProxyTransferEEvRT_($0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $1 = (($this) + 12|0);
 $2 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766776,$2,$1,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i1,1);
 $3 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$3,$p$i$i$i2,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766768,$2,$this,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i1,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$3,$p$i$i$i2,0);
 $10 = HEAP32[$4>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$7>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($this) + 24|0);
 $15 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766800,$15,$14,0);
 $16 = HEAP32[$4>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$7>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766792,768480,$20,0);
 $21 = (($size$i$i$i$i1) + 8|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 HEAP32[$size$i$i$i$i1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766736,$15,$20,1);
 $26 = HEAP32[$4>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$7>>2]|0;
 $29 = ((($27) + (($28*24)|0)|0) + 12|0);
 HEAP32[$29>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $30 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766752,$30,$21,1);
 $31 = HEAP32[$4>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$7>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI17AnimationCurveTplI8Vector3fEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $size$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $size$i$i$i = sp + 40|0;
 $p$i$i = sp;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,768536,$data,$metaFlag);
 __ZN13ProxyTransfer10SetVersionEi($this,2);
 $0 = (($data) + 120|0);
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,768048,$1,$0,1);
 $2 = (($p$i$i) + 4|0);
 dest=$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,768184,768184,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,766688,768552,$p$i$i,0);
 $3 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,768032,$3,$p$i$i,0);
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $10 = (($p$i$i) + 4|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$10,768040,0);
 $11 = (($p$i$i) + 16|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$11,768088,0);
 $12 = (($p$i$i) + 28|0);
 __ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags($this,$12,768096,0);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 $13 = (($data) + 136|0);
 $14 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,768056,$14,$13,1);
 $15 = HEAP32[$4>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$7>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $19 = (($data) + 140|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,768072,$14,$19,1);
 $20 = HEAP32[$4>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$7>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN24CompressedAnimationCurve8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i2 = 0, $size$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i1 = sp;
 $p$i$i$i2 = sp + 4|0;
 $0 = (($this) + 72|0);
 $1 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768112,$1,$0,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i1,1);
 $2 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$2,$p$i$i$i2,0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer8TransferI15PackedIntVectorEEvRT_PKc17TransferMetaFlags($transfer,$this,768120,0);
 $9 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768128,768600,$9,0);
 $10 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768160,$10,$9,0);
 $11 = HEAP32[$3>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$6>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 24|0);
 $16 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768176,$16,$15,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i1,0);
 $17 = HEAP32[580744>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,$17,$p$i$i$i2,0);
 $18 = HEAP32[$3>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$6>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768144,768600,$22,0);
 __ZN17PackedFloatVector8TransferI13ProxyTransferEEvRT_($22,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 64|0);
 $24 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768056,$24,$23,0);
 $25 = HEAP32[$3>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$6>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 68|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768072,$24,$29,0);
 $30 = HEAP32[$3>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$6>>2]|0;
 $33 = ((($31) + (($32*24)|0)|0) + 12|0);
 HEAP32[$33>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN17AnimationCurveTplI11QuaternionfE8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $size$i$i$i$i = sp + 52|0;
 $p$i$i$i = sp;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 152|0);
 $1 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768048,$1,$0,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768184,768184,$size$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,766688,768552,$p$i$i$i,0);
 __ZN11KeyframeTplI11QuaternionfE8TransferI13ProxyTransferEEvRT_($p$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $2 = (($this) + 168|0);
 $3 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768056,$3,$2,1);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 172|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768072,$3,$10,1);
 $11 = HEAP32[$4>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$7>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN11KeyframeTplI11QuaternionfE8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768032,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 $8 = HEAP32[580640>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768040,$8,$7,0);
 __ZN11Quaternionf8TransferI13ProxyTransferEEvRT_($7,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768088,$8,$9,0);
 __ZN11Quaternionf8TransferI13ProxyTransferEEvRT_($9,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768096,$8,$10,0);
 __ZN11Quaternionf8TransferI13ProxyTransferEEvRT_($10,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13AnimationClipD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$01$i = 0, $$01$i31 = 0, $$8 = 0, $$89 = 0, $$byval_copy33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$01$i$i$i = 0, $c$01$i$i$i26 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body17$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy33 = sp + 44|0;
 $0 = sp + 40|0;
 $1 = sp + 36|0;
 $2 = sp + 32|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $5 = sp + 20|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp + 4|0;
 $9 = sp;
 $10 = sp + 16|0;
 HEAP32[$this>>2] = ((765944 + 8|0));
 __THREW__ = 0;
 invoke_vi(3694,($this|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if ($12) {
   $120 = ___cxa_find_matching_catch()|0;
   $121 = tempRet0;
   $122 = (($this) + 176|0);
   $123 = (($this) + 204|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = ($124|0)>(-1);
   do {
    if ($125) {
     $126 = (($this) + 192|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = (($this) + 196|0);
     $129 = HEAP32[$128>>2]|0;
     HEAP32[$5>>2] = $129;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($127|0),($$byval_copy33|0));
     $130 = __THREW__; __THREW__ = 0;
     $131 = $130&1;
     if (!($131)) {
      HEAP32[$126>>2] = 0;
      break;
     }
     $140 = ___cxa_find_matching_catch(0|0)|0;
     $141 = tempRet0;
     $142 = (($this) + 188|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = ($143|0)>(-1);
     if (!($144)) {
      $eh$lpad$body17$indexZ2D = $140;
      ___clang_call_terminate($eh$lpad$body17$indexZ2D);
      // unreachable;
     }
     $145 = HEAP32[$122>>2]|0;
     $146 = (($this) + 180|0);
     $147 = HEAP32[$146>>2]|0;
     HEAP32[$0>>2] = $147;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($145|0),($$byval_copy33|0));
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     if ($149) {
      $150 = ___cxa_find_matching_catch(0|0)|0;
      $151 = tempRet0;
      ___clang_call_terminate($150);
      // unreachable;
     }
     HEAP32[$122>>2] = 0;
     $eh$lpad$body17$indexZ2D = $140;
     ___clang_call_terminate($eh$lpad$body17$indexZ2D);
     // unreachable;
    }
   } while(0);
   $132 = (($this) + 188|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = ($133|0)>(-1);
   if ($134) {
    $135 = HEAP32[$122>>2]|0;
    $136 = (($this) + 180|0);
    $137 = HEAP32[$136>>2]|0;
    HEAP32[$4>>2] = $137;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($135|0),($$byval_copy33|0));
    $138 = __THREW__; __THREW__ = 0;
    $139 = $138&1;
    if (!($139)) {
     HEAP32[$122>>2] = 0;
     $$0 = $121;$$01 = $120;
     label = 54;
    }
   } else {
    $$0 = $121;$$01 = $120;
    label = 54;
   }
  } else {
   $13 = (($this) + 176|0);
   $14 = (($this) + 204|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>(-1);
   do {
    if ($16) {
     $17 = (($this) + 192|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($this) + 196|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$10>>2] = $20;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$10+0>>2]|0;
     invoke_vii(2591,($18|0),($$byval_copy33|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      HEAP32[$17>>2] = 0;
      label = 5;
      break;
     }
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     $33 = (($this) + 188|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)>(-1);
     if ($35) {
      $36 = HEAP32[$13>>2]|0;
      $37 = (($this) + 180|0);
      $38 = HEAP32[$37>>2]|0;
      HEAP32[$0>>2] = $38;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($36|0),($$byval_copy33|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       $41 = ___cxa_find_matching_catch(0|0)|0;
       $42 = tempRet0;
       ___clang_call_terminate($41);
       // unreachable;
      } else {
       HEAP32[$13>>2] = 0;
       $eh$lpad$body$index3Z2D = $32;$eh$lpad$body$indexZ2D = $31;
       break;
      }
     } else {
      $eh$lpad$body$index3Z2D = $32;$eh$lpad$body$indexZ2D = $31;
     }
    } else {
     label = 5;
    }
   } while(0);
   L12: do {
    if ((label|0) == 5) {
     $23 = (($this) + 188|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($24|0)>(-1);
     do {
      if ($25) {
       $26 = HEAP32[$13>>2]|0;
       $27 = (($this) + 180|0);
       $28 = HEAP32[$27>>2]|0;
       HEAP32[$9>>2] = $28;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$9+0>>2]|0;
       invoke_vii(2591,($26|0),($$byval_copy33|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        $152 = ___cxa_find_matching_catch()|0;
        $153 = tempRet0;
        $eh$lpad$body$index3Z2D = $153;$eh$lpad$body$indexZ2D = $152;
        break L12;
       } else {
        HEAP32[$13>>2] = 0;
        break;
       }
      }
     } while(0);
     $43 = (($this) + 152|0);
     __ZNSt3__113__vector_baseI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($43);
     $44 = (($this) + 140|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45|0)==(0|0);
     if (!($46)) {
      $47 = (($this) + 144|0);
      while(1) {
       $48 = HEAP32[$47>>2]|0;
       $49 = ($48|0)==($45|0);
       if ($49) {
        break;
       }
       $50 = (($48) + -48|0);
       HEAP32[$47>>2] = $50;
       __THREW__ = 0;
       invoke_vi(3692,($50|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        label = 16;
        break;
       }
      }
      if ((label|0) == 16) {
       $53 = ___cxa_find_matching_catch()|0;
       $54 = tempRet0;
       ___cxa_call_unexpected(($53|0));
       // unreachable;
      }
      $55 = HEAP32[$44>>2]|0;
      HEAP32[$8>>2] = 18;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$8+0>>2]|0;
      invoke_vii(2591,($55|0),($$byval_copy33|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       $58 = ___cxa_find_matching_catch()|0;
       $59 = tempRet0;
       ___cxa_call_unexpected(($58|0));
       // unreachable;
      }
     }
     $60 = (($this) + 128|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = ($61|0)==(0|0);
     if (!($62)) {
      $63 = (($this) + 132|0);
      while(1) {
       $64 = HEAP32[$63>>2]|0;
       $65 = ($64|0)==($61|0);
       if ($65) {
        break;
       }
       $66 = (($64) + -116|0);
       HEAP32[$63>>2] = $66;
       __THREW__ = 0;
       invoke_vi(3693,($66|0));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        label = 23;
        break;
       }
      }
      if ((label|0) == 23) {
       $69 = ___cxa_find_matching_catch()|0;
       $70 = tempRet0;
       ___cxa_call_unexpected(($69|0));
       // unreachable;
      }
      $71 = HEAP32[$60>>2]|0;
      HEAP32[$7>>2] = 18;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$7+0>>2]|0;
      invoke_vii(2591,($71|0),($$byval_copy33|0));
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       $74 = ___cxa_find_matching_catch()|0;
       $75 = tempRet0;
       ___cxa_call_unexpected(($74|0));
       // unreachable;
      }
     }
     $76 = (($this) + 116|0);
     __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($76);
     $77 = (($this) + 104|0);
     __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($77);
     $78 = (($this) + 92|0);
     __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($78);
     $79 = (($this) + 76|0);
     HEAP32[$79>>2] = 0;
     $80 = (($this) + 72|0);
     HEAP32[$80>>2] = 0;
     $81 = (($this) + 48|0);
     HEAP32[$81>>2] = ((768664 + 8|0));
     $82 = (($this) + 56|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==(0|0);
     L40: do {
      if (!($84)) {
       $c$01$i$i$i = $83;
       while(1) {
        $85 = HEAP32[$c$01$i$i$i>>2]|0;
        $86 = HEAP32[628296>>2]|0;
        HEAP32[$6>>2] = $86;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$6+0>>2]|0;
        invoke_vii(2591,($c$01$i$i$i|0),($$byval_copy33|0));
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         break;
        }
        $89 = ($85|0)==(0|0);
        if ($89) {
         break L40;
        } else {
         $c$01$i$i$i = $85;
        }
       }
       $187 = ___cxa_find_matching_catch()|0;
       $188 = tempRet0;
       $$8 = $188;$$89 = $187;
       label = 74;
       break L1;
      }
     } while(0);
     HEAP32[$82>>2] = 0;
     $90 = (($this) + 60|0);
     HEAP32[$90>>2] = 0;
     $91 = (($this) + 64|0);
     HEAP32[$91>>2] = 0;
     HEAP32[$this>>2] = ((765800 + 8|0));
     __THREW__ = 0;
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     do {
      if ($93) {
       $103 = ___cxa_find_matching_catch()|0;
       $104 = tempRet0;
       $105 = (($this) + 44|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ($106|0)>(-1);
       if ($107) {
        $108 = (($this) + 32|0);
        $109 = HEAP32[$108>>2]|0;
        $110 = (($this) + 36|0);
        $111 = HEAP32[$110>>2]|0;
        HEAP32[$0>>2] = $111;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($109|0),($$byval_copy33|0));
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         $118 = ___cxa_find_matching_catch(0|0)|0;
         $119 = tempRet0;
         ___clang_call_terminate($118);
         // unreachable;
        } else {
         HEAP32[$108>>2] = 0;
         $$0$i = $104;$$01$i = $103;
         break;
        }
       } else {
        $$0$i = $104;$$01$i = $103;
       }
      } else {
       $94 = (($this) + 44|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = ($95|0)>(-1);
       if (!($96)) {
        __ZN11NamedObjectD2Ev($this);
        STACKTOP = sp;return;
       }
       $97 = (($this) + 32|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = (($this) + 36|0);
       $100 = HEAP32[$99>>2]|0;
       HEAP32[$1>>2] = $100;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($98|0),($$byval_copy33|0));
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        $114 = ___cxa_find_matching_catch()|0;
        $115 = tempRet0;
        $$0$i = $115;$$01$i = $114;
        break;
       }
       HEAP32[$97>>2] = 0;
       __ZN11NamedObjectD2Ev($this);
       STACKTOP = sp;return;
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3423,($this|0));
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      $118 = ___cxa_find_matching_catch(0|0)|0;
      $119 = tempRet0;
      ___clang_call_terminate($118);
      // unreachable;
     } else {
      ___resumeException($$01$i|0);
      // unreachable;
     }
    }
   } while(0);
   $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
   label = 54;
  }
 } while(0);
 if ((label|0) == 54) {
  $154 = (($this) + 152|0);
  __ZNSt3__113__vector_baseI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEED2Ev($154);
  $155 = (($this) + 140|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = ($156|0)==(0|0);
  if (!($157)) {
   $158 = (($this) + 144|0);
   while(1) {
    $159 = HEAP32[$158>>2]|0;
    $160 = ($159|0)==($156|0);
    if ($160) {
     break;
    }
    $161 = (($159) + -48|0);
    HEAP32[$158>>2] = $161;
    __THREW__ = 0;
    invoke_vi(3692,($161|0));
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if ($163) {
     label = 58;
     break;
    }
   }
   if ((label|0) == 58) {
    $164 = ___cxa_find_matching_catch()|0;
    $165 = tempRet0;
    ___cxa_call_unexpected(($164|0));
    // unreachable;
   }
   $166 = HEAP32[$155>>2]|0;
   HEAP32[$3>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($166|0),($$byval_copy33|0));
   $167 = __THREW__; __THREW__ = 0;
   $168 = $167&1;
   if ($168) {
    $169 = ___cxa_find_matching_catch()|0;
    $170 = tempRet0;
    ___cxa_call_unexpected(($169|0));
    // unreachable;
   }
  }
  $171 = (($this) + 128|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = ($172|0)==(0|0);
  if (!($173)) {
   $174 = (($this) + 132|0);
   while(1) {
    $175 = HEAP32[$174>>2]|0;
    $176 = ($175|0)==($172|0);
    if ($176) {
     break;
    }
    $177 = (($175) + -116|0);
    HEAP32[$174>>2] = $177;
    __THREW__ = 0;
    invoke_vi(3693,($177|0));
    $178 = __THREW__; __THREW__ = 0;
    $179 = $178&1;
    if ($179) {
     label = 65;
     break;
    }
   }
   if ((label|0) == 65) {
    $180 = ___cxa_find_matching_catch()|0;
    $181 = tempRet0;
    ___cxa_call_unexpected(($180|0));
    // unreachable;
   }
   $182 = HEAP32[$171>>2]|0;
   HEAP32[$2>>2] = 18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($182|0),($$byval_copy33|0));
   $183 = __THREW__; __THREW__ = 0;
   $184 = $183&1;
   if ($184) {
    $185 = ___cxa_find_matching_catch()|0;
    $186 = tempRet0;
    ___cxa_call_unexpected(($185|0));
    // unreachable;
   }
  }
  $189 = (($this) + 116|0);
  __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($189);
  $190 = (($this) + 104|0);
  __ZNSt3__113__vector_baseIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($190);
  $191 = (($this) + 92|0);
  __ZNSt3__113__vector_baseIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEED2Ev($191);
  $192 = (($this) + 76|0);
  HEAP32[$192>>2] = 0;
  $193 = (($this) + 72|0);
  HEAP32[$193>>2] = 0;
  $194 = (($this) + 48|0);
  HEAP32[$194>>2] = ((768664 + 8|0));
  $195 = (($this) + 56|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = ($196|0)==(0|0);
  L104: do {
   if (!($197)) {
    $c$01$i$i$i26 = $196;
    while(1) {
     $198 = HEAP32[$c$01$i$i$i26>>2]|0;
     $199 = HEAP32[628296>>2]|0;
     HEAP32[$0>>2] = $199;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($c$01$i$i$i26|0),($$byval_copy33|0));
     $200 = __THREW__; __THREW__ = 0;
     $201 = $200&1;
     if ($201) {
      break;
     }
     $202 = ($198|0)==(0|0);
     if ($202) {
      break L104;
     } else {
      $c$01$i$i$i26 = $198;
     }
    }
    $235 = ___cxa_find_matching_catch(0|0)|0;
    $236 = tempRet0;
    $eh$lpad$body17$indexZ2D = $235;
    ___clang_call_terminate($eh$lpad$body17$indexZ2D);
    // unreachable;
   }
  } while(0);
  HEAP32[$195>>2] = 0;
  $203 = (($this) + 60|0);
  HEAP32[$203>>2] = 0;
  $204 = (($this) + 64|0);
  HEAP32[$204>>2] = 0;
  $$8 = $$0;$$89 = $$01;
  label = 74;
 }
 L112: do {
  if ((label|0) == 74) {
   HEAP32[$this>>2] = ((765800 + 8|0));
   __THREW__ = 0;
   $205 = __THREW__; __THREW__ = 0;
   $206 = $205&1;
   L114: do {
    if ($206) {
     $218 = ___cxa_find_matching_catch(0|0)|0;
     $219 = tempRet0;
     $220 = (($this) + 44|0);
     $221 = HEAP32[$220>>2]|0;
     $222 = ($221|0)>(-1);
     if ($222) {
      $223 = (($this) + 32|0);
      $224 = HEAP32[$223>>2]|0;
      $225 = (($this) + 36|0);
      $226 = HEAP32[$225>>2]|0;
      HEAP32[$0>>2] = $226;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($224|0),($$byval_copy33|0));
      $227 = __THREW__; __THREW__ = 0;
      $228 = $227&1;
      if ($228) {
       $233 = ___cxa_find_matching_catch(0|0)|0;
       $234 = tempRet0;
       ___clang_call_terminate($233);
       // unreachable;
      } else {
       HEAP32[$223>>2] = 0;
       $$01$i31 = $218;
       break;
      }
     } else {
      $$01$i31 = $218;
     }
    } else {
     $207 = (($this) + 44|0);
     $208 = HEAP32[$207>>2]|0;
     $209 = ($208|0)>(-1);
     do {
      if ($209) {
       $210 = (($this) + 32|0);
       $211 = HEAP32[$210>>2]|0;
       $212 = (($this) + 36|0);
       $213 = HEAP32[$212>>2]|0;
       HEAP32[$1>>2] = $213;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy33+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($211|0),($$byval_copy33|0));
       $214 = __THREW__; __THREW__ = 0;
       $215 = $214&1;
       if ($215) {
        $229 = ___cxa_find_matching_catch(0|0)|0;
        $230 = tempRet0;
        $$01$i31 = $229;
        break L114;
       } else {
        HEAP32[$210>>2] = 0;
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3423,($this|0));
     $216 = __THREW__; __THREW__ = 0;
     $217 = $216&1;
     if ($217) {
      break L112;
     }
     ___resumeException($$89|0);
     // unreachable;
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3423,($this|0));
   $231 = __THREW__; __THREW__ = 0;
   $232 = $231&1;
   if ($232) {
    $233 = ___cxa_find_matching_catch(0|0)|0;
    $234 = tempRet0;
    ___clang_call_terminate($233);
    // unreachable;
   }
   $eh$lpad$body17$indexZ2D = $$01$i31;
   ___clang_call_terminate($eh$lpad$body17$indexZ2D);
   // unreachable;
  }
 } while(0);
 $237 = ___cxa_find_matching_catch(0|0)|0;
 $238 = tempRet0;
 $eh$lpad$body17$indexZ2D = $237;
 ___clang_call_terminate($eh$lpad$body17$indexZ2D);
 // unreachable;
}
function __ZN13AnimationClip10FloatCurveD2Ev($this) {
 $this = $this|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 100|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(-1);
 do {
  if ($5) {
   $6 = (($this) + 88|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($this) + 92|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$2>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($7|0),($$byval_copy4|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$6>>2] = 0;
    break;
   }
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   $33 = (($this) + 12|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34 & 1;
   $36 = ($35<<24>>24)==(0);
   if (!($36)) {
    $37 = (($this) + 20|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($38|0),($$byval_copy4|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     $41 = ___cxa_find_matching_catch()|0;
     $42 = tempRet0;
     ___cxa_call_unexpected(($41|0));
     // unreachable;
    }
   }
   $43 = HEAP8[$this>>0]|0;
   $44 = $43 & 1;
   $45 = ($44<<24>>24)==(0);
   if ($45) {
    ___resumeException($31|0);
    // unreachable;
   }
   $46 = (($this) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($47|0),($$byval_copy4|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $50 = ___cxa_find_matching_catch()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   } else {
    ___resumeException($31|0);
    // unreachable;
   }
  }
 } while(0);
 $12 = (($this) + 12|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 & 1;
 $15 = ($14<<24>>24)==(0);
 if (!($15)) {
  $16 = (($this) + 20|0);
  $17 = HEAP32[$16>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($17|0),($$byval_copy4|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   ___cxa_call_unexpected(($20|0));
   // unreachable;
  }
 }
 $22 = HEAP8[$this>>0]|0;
 $23 = $22 & 1;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (($this) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($26|0),($$byval_copy4|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  ___cxa_call_unexpected(($29|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim6memory16ChainedAllocator8AllocateEjj($this,$size,$align) {
 $this = $this|0;
 $size = $size|0;
 $align = $align|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $size$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = (($this) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 27)|0;
  HEAP32[$0>>2] = 18;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $8 = (__Z15malloc_internaljj10MemLabelIdiPKci($7,16,$$byval_copy1,0,766088,514)|0);
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   HEAP32[$2>>2] = $8;
   $10 = (($this) + 12|0);
   HEAP32[$10>>2] = $8;
   HEAP32[$8>>2] = 0;
   $11 = HEAP32[$5>>2]|0;
   $12 = HEAP32[$10>>2]|0;
   $13 = (($12) + 8|0);
   HEAP32[$13>>2] = $11;
   $14 = (($8) + 12|0);
   $15 = $14;
   $16 = (0 - ($15))|0;
   $17 = $16 & 15;
   $18 = (($17) + ($15))|0;
   $19 = $18;
   $20 = (($12) + 4|0);
   HEAP32[$20>>2] = $19;
   $21 = (($this) + 16|0);
   HEAP32[$21>>2] = $19;
  }
 }
 $22 = (($size) + -1)|0;
 $23 = (($22) + ($align))|0;
 $24 = (($this) + 16|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23)|0);
 $27 = (($this) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + ($32)|0);
 $34 = ($26>>>0)>($33>>>0);
 do {
  if ($34) {
   $35 = (($this) + 20|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36>>>0)<($size>>>0);
   $size$ = $37 ? $size : $36;
   $38 = (($size$) + 27)|0;
   HEAP32[$1>>2] = 18;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   $39 = (__Z15malloc_internaljj10MemLabelIdiPKci($38,16,$$byval_copy1,0,766088,596)|0);
   $40 = ($39|0)==(0|0);
   if ($40) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $41 = HEAP32[$27>>2]|0;
    HEAP32[$41>>2] = $39;
    $42 = HEAP32[$27>>2]|0;
    $43 = HEAP32[$42>>2]|0;
    HEAP32[$27>>2] = $43;
    HEAP32[$43>>2] = 0;
    $44 = HEAP32[$35>>2]|0;
    $45 = ($23>>>0)>($44>>>0);
    $46 = $45 ? $23 : $44;
    $47 = HEAP32[$27>>2]|0;
    $48 = (($47) + 8|0);
    HEAP32[$48>>2] = $46;
    $49 = (($39) + 12|0);
    $50 = $49;
    $51 = (0 - ($50))|0;
    $52 = $51 & 15;
    $53 = (($52) + ($50))|0;
    $54 = $53;
    $55 = (($47) + 4|0);
    HEAP32[$55>>2] = $54;
    HEAP32[$24>>2] = $54;
    $57 = $54;
    break;
   }
  } else {
   $57 = $25;
  }
 } while(0);
 $56 = $57;
 $58 = (0 - ($56))|0;
 $59 = (($align) + -1)|0;
 $60 = $59 & $58;
 $61 = (($60) + ($56))|0;
 $62 = $61;
 $63 = (($62) + ($size)|0);
 HEAP32[$24>>2] = $63;
 $$0 = $62;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7mecanim6memory16ChainedAllocator10DeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z9FireEventR14AnimationEventRN5Unity9ComponentEP14AnimationStateP17AnimatorStateInfoP16AnimatorClipInfo($event,$animation,$state,$animatorStateInfo,$animatorClipInfo) {
 $event = $event|0;
 $animation = $animation|0;
 $state = $state|0;
 $animatorStateInfo = $animatorStateInfo|0;
 $animatorClipInfo = $animatorClipInfo|0;
 var $$ = 0, $$0 = 0, $$0$i$i$i = 0, $$01$i = 0, $$02$i = 0, $$6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$05 = 0, $invocation$i = 0, $method$i = 0, $monoEvent$i = 0, $tmpcast6$i$byval_copy = 0, $vararg_ptr1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $tmpcast6$i$byval_copy = sp + 248|0;
 $0 = sp + 268|0;
 $1 = sp + 240|0;
 $2 = sp + 232|0;
 $3 = sp + 360|0;
 $method$i = sp + 216|0;
 $invocation$i = sp + 16|0;
 $4 = sp + 8|0;
 $monoEvent$i = sp + 288|0;
 $5 = sp + 256|0;
 $6 = sp;
 $7 = sp + 272|0;
 $8 = sp + 224|0;
 $9 = (($animation) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__ZNK5Unity10GameObject8IsActiveEv($10)|0);
 if (!($11)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($10) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)>(0);
 if (!($14)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($10) + 24|0);
 $16 = (($event) + 4|0);
 $17 = (($16) + 1|0);
 $18 = (($monoEvent$i) + 36|0);
 $19 = (($event) + 44|0);
 $20 = (($event) + 48|0);
 $21 = (($event) + 52|0);
 $22 = (($invocation$i) + 32|0);
 $23 = (($invocation$i) + 12|0);
 $24 = (($invocation$i) + 25|0);
 $25 = (($invocation$i) + 16|0);
 $26 = (($7) + 1|0);
 $27 = (($5) + 1|0);
 $28 = (($7) + 8|0);
 $29 = (($5) + 8|0);
 $30 = (($event) + 32|0);
 $31 = (($event) + 36|0);
 $32 = (($event) + 16|0);
 $33 = (($32) + 1|0);
 $34 = (($event) + 24|0);
 $35 = (($event) + 28|0);
 $36 = (($event) + 12|0);
 $i$05 = 0;
 L7: while(1) {
  $37 = HEAP32[$15>>2]|0;
  $38 = (($37) + ($i$05<<3)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(114);
  L9: do {
   if ($40) {
    $41 = ((($37) + ($i$05<<3)|0) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + 20|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     $46 = HEAP8[$16>>0]|0;
     $47 = $46 & 1;
     $48 = ($47<<24>>24)==(0);
     if ($48) {
      $50 = $17;
     } else {
      $49 = HEAP32[$36>>2]|0;
      $50 = $49;
     }
     __ZN13MonoBehaviour10FindMethodEPKc($method$i,$42,$50);
     $51 = HEAP32[$method$i>>2]|0;
     $52 = ($51|0)==(0|0);
     if (!($52)) {
      $53 = $method$i;
      $54 = $53;
      $55 = HEAP32[$54>>2]|0;
      $56 = (($53) + 4)|0;
      $57 = $56;
      $58 = HEAP32[$57>>2]|0;
      $59 = $4;
      $60 = $59;
      HEAP32[$60>>2] = $55;
      $61 = (($59) + 4)|0;
      $62 = $61;
      HEAP32[$62>>2] = $58;
      ;HEAP32[$tmpcast6$i$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast6$i$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
      __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i,$tmpcast6$i$byval_copy);
      ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;HEAP32[$18+24>>2]=0|0;
      HEAP32[$19>>2] = $state;
      HEAP32[$20>>2] = $animatorStateInfo;
      HEAP32[$21>>2] = $animatorClipInfo;
      __Z20AnimationEventToMonoRK14AnimationEventR18MonoAnimationEvent($event,$monoEvent$i);
      $63 = $method$i;
      $64 = $63;
      $65 = HEAP32[$64>>2]|0;
      $66 = (($63) + 4)|0;
      $67 = $66;
      $68 = HEAP32[$67>>2]|0;
      $69 = $68 & 255;
      $70 = $1;
      $71 = $70;
      HEAP32[$71>>2] = $65;
      $72 = (($70) + 4)|0;
      $73 = $72;
      HEAP32[$73>>2] = $69;
      ;HEAP32[$tmpcast6$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast6$i$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
      $74 = (__Z35scripting_method_get_argument_count21ScriptingMethodIl2Cpp($tmpcast6$i$byval_copy)|0);
      $75 = ($74|0)==(0);
      L16: do {
       if (!($75)) {
        $76 = ($74|0)>(1);
        do {
         if (!($76)) {
          $77 = $2;
          $78 = $77;
          HEAP32[$78>>2] = $65;
          $79 = (($77) + 4)|0;
          $80 = $79;
          HEAP32[$80>>2] = $69;
          ;HEAP32[$tmpcast6$i$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast6$i$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
          $81 = (__Z37scripting_method_get_nth_argumenttype21ScriptingMethodIl2Cppi($tmpcast6$i$byval_copy,0)|0);
          $82 = (__Z25scripting_class_from_typeP13ScriptingType($81)|0);
          $83 = (__Z19GetScriptingManagerv()|0);
          $84 = (($83) + 208|0);
          $85 = HEAP32[$84>>2]|0;
          $86 = ($82|0)==($85|0);
          if ($86) {
           $87 = Math_fround(HEAPF32[$30>>2]);
           __ZN18ScriptingArguments8AddFloatEf($22,$87);
           break L16;
          }
          $88 = (($83) + 200|0);
          $89 = HEAP32[$88>>2]|0;
          $90 = ($82|0)==($89|0);
          if ($90) {
           $91 = HEAP32[$31>>2]|0;
           __ZN18ScriptingArguments6AddIntEi($22,$91);
           break L16;
          }
          $92 = (($83) + 204|0);
          $93 = HEAP32[$92>>2]|0;
          $94 = ($82|0)==($93|0);
          if ($94) {
           $95 = HEAP8[$32>>0]|0;
           $96 = $95 & 1;
           $97 = ($96<<24>>24)==(0);
           if ($97) {
            $99 = $33;
           } else {
            $98 = HEAP32[$34>>2]|0;
            $99 = $98;
           }
           __ZN18ScriptingArguments9AddStringEPKc($22,$99);
           break L16;
          }
          $100 = (($83) + 468|0);
          $101 = HEAP32[$100>>2]|0;
          $102 = ($82|0)==($101|0);
          if ($102) {
           $103 = (__Z19GetScriptingManagerv()|0);
           $104 = (($103) + 468|0);
           $105 = HEAP32[$104>>2]|0;
           $106 = (_il2cpp_object_new($105)|0);
           $107 = (($106) + 8|0);
           dest=$107+0|0; src=$monoEvent$i+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($22,$106);
           break L16;
          }
          $108 = (($83) + 280|0);
          $109 = HEAP32[$108>>2]|0;
          $110 = (__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_($82,$109)|0);
          if (!($110)) {
           $147 = (__Z23scripting_class_is_enumP14ScriptingClass($82)|0);
           if (!($147)) {
            break;
           }
           $148 = HEAP32[$31>>2]|0;
           __ZN18ScriptingArguments6AddIntEi($22,$148);
           break L16;
          }
          $111 = HEAP32[$35>>2]|0;
          $112 = ($111|0)==(0);
          L39: do {
           if ($112) {
            $$0$i$i$i = 0;
           } else {
            HEAP32[$0>>2] = $111;
            $113 = HEAP32[560624>>2]|0;
            $114 = ($113|0)==(0|0);
            do {
             if (!($114)) {
              $115 = (($113) + 36|0);
              $116 = HEAP32[$115>>2]|0;
              $117 = (($113) + 4|0);
              $118 = HEAP32[$117>>2]|0;
              $119 = ($116|0)==($118|0);
              do {
               if ($119) {
                $120 = (($113) + 28|0);
                $121 = HEAP32[$120>>2]|0;
                $122 = (($113) + 32|0);
                $123 = HEAP32[$122>>2]|0;
                $124 = (($121) + ($123<<3)|0);
                $140 = $124;
               } else {
                __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast6$i$byval_copy,$113,$0);
                $125 = HEAP32[$tmpcast6$i$byval_copy>>2]|0;
                $126 = ($125|0)==(-1);
                $127 = (($113) + 28|0);
                $128 = HEAP32[$127>>2]|0;
                if ($126) {
                 $129 = (($113) + 32|0);
                 $130 = HEAP32[$129>>2]|0;
                 $131 = (($128) + ($130<<3)|0);
                 $140 = $131;
                 break;
                } else {
                 $132 = (($128) + ($125<<3)|0);
                 $140 = $132;
                 break;
                }
               }
              } while(0);
              $133 = HEAP32[560624>>2]|0;
              $134 = (($133) + 28|0);
              $135 = HEAP32[$134>>2]|0;
              $136 = (($133) + 32|0);
              $137 = HEAP32[$136>>2]|0;
              $138 = (($135) + ($137<<3)|0);
              $139 = ($140|0)==($138|0);
              if ($139) {
               break;
              }
              $141 = (($140) + 4|0);
              $142 = HEAP32[$141>>2]|0;
              $143 = ($142|0)==(0|0);
              if (!($143)) {
               $$0$i$i$i = $142;
               break L39;
              }
             }
            } while(0);
            $144 = HEAP32[$35>>2]|0;
            $145 = (__Z31ReadObjectFromPersistentManageri($144)|0);
            $$0$i$i$i = $145;
           }
          } while(0);
          $146 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i$i$i)|0);
          __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($22,$146);
          break L16;
         }
        } while(0);
        $149 = $method$i;
        $150 = $149;
        $151 = HEAP32[$150>>2]|0;
        $152 = (($149) + 4)|0;
        $153 = $152;
        $154 = HEAP32[$153>>2]|0;
        $155 = $6;
        $156 = $155;
        HEAP32[$156>>2] = $151;
        $157 = (($155) + 4)|0;
        $158 = $157;
        HEAP32[$158>>2] = $154;
        ;HEAP32[$tmpcast6$i$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast6$i$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
        $159 = (__Z25scripting_method_get_name21ScriptingMethodIl2Cpp($tmpcast6$i$byval_copy)|0);
        __ZN13MonoBehaviour18GetScriptClassNameEv($7,$42);
        $160 = HEAP8[$7>>0]|0;
        $161 = $160 & 1;
        $162 = ($161<<24>>24)==(0);
        $163 = HEAP32[$28>>2]|0;
        $$ = $162 ? $26 : $163;
        __THREW__ = 0;
        HEAP32[$tmpcast6$i$byval_copy>>2] = $159;
        $vararg_ptr1 = (($tmpcast6$i$byval_copy) + 4|0);
        HEAP32[$vararg_ptr1>>2] = $$;
        invoke_viii(1617,($5|0),(768840|0),($tmpcast6$i$byval_copy|0));
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if ($165) {
         label = 44;
         break L7;
        }
        $166 = ($42|0)==(0|0);
        if ($166) {
         $173 = 0;
        } else {
         $167 = (($42) + 4|0);
         $168 = HEAP32[$167>>2]|0;
         $173 = $168;
        }
        $169 = HEAP8[$5>>0]|0;
        $170 = $169 & 1;
        $171 = ($170<<24>>24)==(0);
        $172 = HEAP32[$29>>2]|0;
        $$6 = $171 ? $27 : $172;
        __THREW__ = 0;
        invoke_viiiiiiii(21,($$6|0),0,(768824|0),106,1,($173|0),0,(0|0));
        $174 = __THREW__; __THREW__ = 0;
        $175 = $174&1;
        if ($175) {
         label = 45;
         break L7;
        }
        $176 = HEAP8[$5>>0]|0;
        $177 = $176 & 1;
        $178 = ($177<<24>>24)==(0);
        if (!($178)) {
         $179 = HEAP32[$29>>2]|0;
         __ZdlPv($179);
        }
        $180 = HEAP8[$7>>0]|0;
        $181 = $180 & 1;
        $182 = ($181<<24>>24)==(0);
        if ($182) {
         break L9;
        }
        $183 = HEAP32[$28>>2]|0;
        HEAP32[$3>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$tmpcast6$i$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($183|0),($tmpcast6$i$byval_copy|0));
        $184 = __THREW__; __THREW__ = 0;
        $185 = $184&1;
        if ($185) {
         label = 43;
         break L7;
        } else {
         break L9;
        }
       }
      } while(0);
      $204 = (__Z30GetDisableImmediateDestructionv()|0);
      __Z30SetDisableImmediateDestructionb(1);
      HEAP32[$23>>2] = $44;
      HEAP8[$24>>0] = 1;
      $205 = (($42) + 4|0);
      $206 = HEAP32[$205>>2]|0;
      HEAP32[$25>>2] = $206;
      $207 = (__ZN19ScriptingInvocation6InvokeEv($invocation$i)|0);
      __Z30SetDisableImmediateDestructionb($204);
      $208 = ($207|0)==(0|0);
      if (!($208)) {
       $209 = $method$i;
       $210 = $209;
       $211 = HEAP32[$210>>2]|0;
       $212 = (($209) + 4)|0;
       $213 = $212;
       $214 = HEAP32[$213>>2]|0;
       $215 = $8;
       $216 = $215;
       HEAP32[$216>>2] = $211;
       $217 = (($215) + 4)|0;
       $218 = $217;
       HEAP32[$218>>2] = $214;
       ;HEAP32[$tmpcast6$i$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast6$i$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
       (__ZN13MonoBehaviour26HandleCoroutineReturnValueE21ScriptingMethodIl2CppP15ScriptingObject($42,$tmpcast6$i$byval_copy,$207)|0);
      }
      HEAP32[$19>>2] = 0;
      HEAP32[$20>>2] = 0;
      HEAP32[$21>>2] = 0;
     }
    }
   }
  } while(0);
  $219 = (($i$05) + 1)|0;
  $220 = HEAP32[$12>>2]|0;
  $221 = ($219|0)<($220|0);
  if ($221) {
   $i$05 = $219;
  } else {
   $$0 = 1;
   label = 55;
   break;
  }
 }
 if ((label|0) == 43) {
  $186 = ___cxa_find_matching_catch()|0;
  $187 = tempRet0;
  ___cxa_call_unexpected(($186|0));
  // unreachable;
 }
 else if ((label|0) == 44) {
  $188 = ___cxa_find_matching_catch()|0;
  $189 = tempRet0;
  $$01$i = $188;$$02$i = $189;
 }
 else if ((label|0) == 45) {
  $190 = ___cxa_find_matching_catch()|0;
  $191 = tempRet0;
  $192 = HEAP8[$5>>0]|0;
  $193 = $192 & 1;
  $194 = ($193<<24>>24)==(0);
  if ($194) {
   $$01$i = $190;$$02$i = $191;
  } else {
   $195 = HEAP32[$29>>2]|0;
   __ZdlPv($195);
   $$01$i = $190;$$02$i = $191;
  }
 }
 else if ((label|0) == 55) {
  STACKTOP = sp;return ($$0|0);
 }
 $196 = HEAP8[$7>>0]|0;
 $197 = $196 & 1;
 $198 = ($197<<24>>24)==(0);
 if ($198) {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 $199 = HEAP32[$28>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$tmpcast6$i$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($199|0),($tmpcast6$i$byval_copy|0));
 $200 = __THREW__; __THREW__ = 0;
 $201 = $200&1;
 if ($201) {
  $202 = ___cxa_find_matching_catch()|0;
  $203 = tempRet0;
  ___cxa_call_unexpected(($202|0));
  // unreachable;
 } else {
  ___resumeException($$01$i|0);
  // unreachable;
 }
 return 0|0;
}
function __Z20AnimationEventToMonoRK14AnimationEventR18MonoAnimationEvent($src,$dest) {
 $src = $src|0;
 $dest = $dest|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i5 = 0;
 var $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = Math_fround(HEAPF32[$src>>2]);
 HEAPF32[$dest>>2] = $3;
 $4 = (($src) + 4|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $8 = (($4) + 1|0);
  $9 = $5&255;
  $10 = $9 >>> 1;
  $17 = $10;$27 = $8;
 } else {
  $11 = (($src) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($src) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14>>>0)>(4294967279);
  if ($15) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $17 = $14;$27 = $12;
  }
 }
 $16 = ($17>>>0)<(11);
 if ($16) {
  $18 = $17 << 1;
  $19 = $18&255;
  HEAP8[$1>>0] = $19;
  $20 = (($1) + 1|0);
  $__p$0$i$i$i$i = $20;
 } else {
  $21 = (($17) + 16)|0;
  $22 = $21 & -16;
  $23 = (__Znwj($22)|0);
  $24 = (($1) + 8|0);
  HEAP32[$24>>2] = $23;
  $25 = $22 | 1;
  HEAP32[$1>>2] = $25;
  $26 = (($1) + 4|0);
  HEAP32[$26>>2] = $17;
  $__p$0$i$i$i$i = $23;
 }
 _memcpy(($__p$0$i$i$i$i|0),($27|0),($17|0))|0;
 $28 = (($__p$0$i$i$i$i) + ($17)|0);
 HEAP8[$28>>0] = 0;
 __THREW__ = 0;
 $29 = (invoke_ii(3338,($1|0))|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $137 = ___cxa_find_matching_catch()|0;
  $138 = tempRet0;
  $139 = HEAP8[$1>>0]|0;
  $140 = $139 & 1;
  $141 = ($140<<24>>24)==(0);
  if ($141) {
   $$0 = $138;$$01 = $137;
   ___resumeException($$01|0);
   // unreachable;
  }
  $142 = (($1) + 8|0);
  $143 = HEAP32[$142>>2]|0;
  __ZdlPv($143);
  $$0 = $138;$$01 = $137;
  ___resumeException($$01|0);
  // unreachable;
 }
 $32 = (($dest) + 4|0);
 HEAP32[$32>>2] = $29;
 $33 = HEAP8[$1>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if (!($35)) {
  $36 = (($1) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  __ZdlPv($37);
 }
 $38 = (($src) + 16|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  $42 = (($38) + 1|0);
  $43 = $39&255;
  $44 = $43 >>> 1;
  $51 = $44;$61 = $42;
 } else {
  $45 = (($src) + 24|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($src) + 20|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = ($48>>>0)>(4294967279);
  if ($49) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $51 = $48;$61 = $46;
  }
 }
 $50 = ($51>>>0)<(11);
 if ($50) {
  $52 = $51 << 1;
  $53 = $52&255;
  HEAP8[$2>>0] = $53;
  $54 = (($2) + 1|0);
  $__p$0$i$i$i$i5 = $54;
 } else {
  $55 = (($51) + 16)|0;
  $56 = $55 & -16;
  $57 = (__Znwj($56)|0);
  $58 = (($2) + 8|0);
  HEAP32[$58>>2] = $57;
  $59 = $56 | 1;
  HEAP32[$2>>2] = $59;
  $60 = (($2) + 4|0);
  HEAP32[$60>>2] = $51;
  $__p$0$i$i$i$i5 = $57;
 }
 _memcpy(($__p$0$i$i$i$i5|0),($61|0),($51|0))|0;
 $62 = (($__p$0$i$i$i$i5) + ($51)|0);
 HEAP8[$62>>0] = 0;
 __THREW__ = 0;
 $63 = (invoke_ii(3338,($2|0))|0);
 $64 = __THREW__; __THREW__ = 0;
 $65 = $64&1;
 if ($65) {
  $144 = ___cxa_find_matching_catch()|0;
  $145 = tempRet0;
  $146 = HEAP8[$2>>0]|0;
  $147 = $146 & 1;
  $148 = ($147<<24>>24)==(0);
  if ($148) {
   $$0 = $145;$$01 = $144;
   ___resumeException($$01|0);
   // unreachable;
  }
  $149 = (($2) + 8|0);
  $150 = HEAP32[$149>>2]|0;
  __ZdlPv($150);
  $$0 = $145;$$01 = $144;
  ___resumeException($$01|0);
  // unreachable;
 }
 $66 = (($dest) + 8|0);
 HEAP32[$66>>2] = $63;
 $67 = HEAP8[$2>>0]|0;
 $68 = $67 & 1;
 $69 = ($68<<24>>24)==(0);
 if (!($69)) {
  $70 = (($2) + 8|0);
  $71 = HEAP32[$70>>2]|0;
  __ZdlPv($71);
 }
 $72 = (($src) + 28|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)==(0);
 do {
  if ($74) {
   $$0$i = 0;
  } else {
   HEAP32[$0>>2] = $73;
   $75 = HEAP32[560624>>2]|0;
   $76 = ($75|0)==(0|0);
   if (!($76)) {
    $77 = (($75) + 36|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (($75) + 4|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = ($78|0)==($80|0);
    do {
     if ($81) {
      $82 = (($75) + 28|0);
      $83 = HEAP32[$82>>2]|0;
      $84 = (($75) + 32|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = (($83) + ($85<<3)|0);
      $102 = $86;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$75,$0);
      $87 = HEAP32[$pos$i$i$i$i>>2]|0;
      $88 = ($87|0)==(-1);
      $89 = (($75) + 28|0);
      $90 = HEAP32[$89>>2]|0;
      if ($88) {
       $91 = (($75) + 32|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = (($90) + ($92<<3)|0);
       $102 = $93;
       break;
      } else {
       $94 = (($90) + ($87<<3)|0);
       $102 = $94;
       break;
      }
     }
    } while(0);
    $95 = HEAP32[560624>>2]|0;
    $96 = (($95) + 28|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($95) + 32|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($97) + ($99<<3)|0);
    $101 = ($102|0)==($100|0);
    if (!($101)) {
     $103 = (($102) + 4|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = ($104|0)==(0|0);
     if (!($105)) {
      $$0$i = $104;
      break;
     }
    }
   }
   $106 = HEAP32[$72>>2]|0;
   $107 = (__Z31ReadObjectFromPersistentManageri($106)|0);
   $$0$i = $107;
  }
 } while(0);
 $108 = (__ZN9Scripting19ScriptingWrapperForEP6Object($$0$i)|0);
 $109 = (($dest) + 12|0);
 HEAP32[$109>>2] = $108;
 $110 = (($src) + 32|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($dest) + 16|0);
 HEAPF32[$112>>2] = $111;
 $113 = (($src) + 36|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = (($dest) + 20|0);
 HEAP32[$115>>2] = $114;
 $116 = (($src) + 40|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = (($dest) + 24|0);
 HEAP32[$118>>2] = $117;
 $119 = (($src) + 44|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($120|0)==(0|0);
 if ($121) {
  $122 = (($src) + 52|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)!=(0|0);
  $125 = $124 ? 2 : 0;
  $127 = $125;
 } else {
  $127 = 1;
 }
 $126 = (($dest) + 28|0);
 HEAP32[$126>>2] = $127;
 $128 = (__Z19GetScriptingManagerv()|0);
 $129 = (($128) + 108|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (__ZN9Scripting41TrackedReferenceBaseToScriptingObjectImplEP20TrackedReferenceBaseP14ScriptingClass($120,$130)|0);
 $132 = (($dest) + 32|0);
 HEAP32[$132>>2] = $131;
 $133 = (($src) + 48|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = ($134|0)==(0|0);
 if (!($135)) {
  $136 = (($dest) + 36|0);
  ;HEAP32[$136+0>>2]=HEAP32[$134+0>>2]|0;HEAP32[$136+4>>2]=HEAP32[$134+4>>2]|0;HEAP32[$136+8>>2]=HEAP32[$134+8>>2]|0;HEAP32[$136+12>>2]=HEAP32[$134+12>>2]|0;HEAP32[$136+16>>2]=HEAP32[$134+16>>2]|0;HEAP32[$136+20>>2]=HEAP32[$134+20>>2]|0;HEAP32[$136+24>>2]=HEAP32[$134+24>>2]|0;
 }
 $151 = (($src) + 52|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = ($152|0)==(0|0);
 if ($153) {
  STACKTOP = sp;return;
 }
 $154 = (($dest) + 64|0);
 __Z22AnimatorClipInfoToMonoRK16AnimatorClipInfoR20MonoAnimatorClipInfo($152,$154);
 STACKTOP = sp;return;
}
function __ZN14AnimationEvent8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, $p$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i = sp;
 $p$i$i$i2 = sp + 16|0;
 $0 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768680,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 $8 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768688,$8,$7,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768832,768832,$localIdentifier$i$i$i,1);
 $9 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768704,$9,$p$i$i$i2,0);
 $10 = HEAP32[$1>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$4>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768704,$8,$14,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,768832,768832,$localIdentifier$i$i$i,1);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768704,$9,$p$i$i$i2,0);
 $15 = HEAP32[$1>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$4>>2]|0;
 $18 = ((($16) + (($17*24)|0)|0) + 12|0);
 HEAP32[$18>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 28|0);
 $20 = HEAP32[580624>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768712,$20,$19,0);
 $21 = (($localIdentifier$i$i$i) + 8|0);
 $22 = $21;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 $26 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768792,$26,$19,1);
 $27 = HEAP32[$1>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$4>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $31 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768808,$31,$21,1);
 $32 = HEAP32[$1>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$4>>2]|0;
 $35 = ((($33) + (($34*24)|0)|0) + 12|0);
 HEAP32[$35>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $36 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768744,$0,$36,0);
 $37 = HEAP32[$1>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$4>>2]|0;
 $40 = ((($38) + (($39*24)|0)|0) + 12|0);
 HEAP32[$40>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $41 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768760,$26,$41,0);
 $42 = HEAP32[$1>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$4>>2]|0;
 $45 = ((($43) + (($44*24)|0)|0) + 12|0);
 HEAP32[$45>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $46 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,768776,$26,$46,0);
 $47 = HEAP32[$1>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$4>>2]|0;
 $50 = ((($48) + (($49*24)|0)|0) + 12|0);
 HEAP32[$50>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14AnimationEvent8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$this,768680,0);
 $0 = (($this) + 4|0);
 $1 = HEAP32[580712>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768688,$1,$converter$i$i3,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i3>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 16|0);
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768704,$1,$converter$i$i3,0)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($8|0)>(0);
  if ($10) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$7,0);
  } else {
   $11 = HEAP32[$converter$i$i3>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    (FUNCTION_TABLE_iii[$11 & 4095]($7,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $13 = (($this) + 28|0);
 $14 = HEAP32[580624>>2]|0;
 $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,768712,$14,$converter$i$i3,1)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = ($15|0)>(0);
  if ($17) {
   __ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_($13,$transfer);
  } else {
   $18 = HEAP32[$converter$i$i3>>2]|0;
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    (FUNCTION_TABLE_iii[$18 & 4095]($13,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $20 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$20,768744,0);
 $21 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$21,768760,0);
 $22 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$22,768776,0);
 STACKTOP = sp;return;
}
function __ZN14AnimationEvent8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
 }
 $7 = (($this) + 4|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$7,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $8 = (($this) + 16|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$8,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $9 = (($this) + 28|0);
 __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_($9,$transfer);
 $10 = (($this) + 32|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$3>>2]|0;
 $14 = ($12>>>0)>($13>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$10,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $18 = $$pre;$20 = $$pre3;
 } else {
  $15 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$10>>2] = $15;
  HEAP32[$0>>2] = $12;
  $18 = $12;$20 = $13;
 }
 $16 = (($this) + 36|0);
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)>($20>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$16,4);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $24 = $$pre4;$26 = $$pre5;
 } else {
  $21 = HEAP32[$18>>2]|0;
  HEAP32[$16>>2] = $21;
  HEAP32[$0>>2] = $17;
  $24 = $17;$26 = $20;
 }
 $22 = (($this) + 40|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)>($26>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$22,4);
  STACKTOP = sp;return;
 } else {
  $27 = HEAP32[$24>>2]|0;
  HEAP32[$22>>2] = $27;
  HEAP32[$0>>2] = $23;
  STACKTOP = sp;return;
 }
}
function __ZN14AnimationEvent8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $$pre$i$i$i7 = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre10 = 0, $$pre11 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre$phi$i$i$iZ2D = $this;$8 = $$pre$i$i$i;
 } else {
  $6 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = (HEAPF32[tempDoublePtr>>2]=$6,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $this;$8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $9;
 $10 = (($this) + 4|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$10,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $11 = (($this) + 16|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$11,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $12 = (($this) + 28|0);
 __ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_($12,$transfer);
 $13 = (($this) + 32|0);
 $14 = HEAP32[$0>>2]|0;
 $15 = (($14) + 4|0);
 $16 = HEAP32[$3>>2]|0;
 $17 = ($15>>>0)>($16>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre$i$i$i3 = HEAP32[$13>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i4Z2D = $13;$20 = $$pre$i$i$i3;$24 = $$pre;$26 = $$pre9;
 } else {
  $18 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $15;
  $19 = (HEAPF32[tempDoublePtr>>2]=$18,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $13;$20 = $19;$24 = $15;$26 = $16;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $21;
 $22 = (($this) + 36|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)>($26>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$22,4);
  $$pre$i$i$i6 = HEAP32[$22>>2]|0;
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $28 = $$pre$i$i$i6;$32 = $$pre10;$34 = $$pre11;
 } else {
  $27 = HEAP32[$24>>2]|0;
  HEAP32[$22>>2] = $27;
  HEAP32[$0>>2] = $23;
  $28 = $27;$32 = $23;$34 = $26;
 }
 $29 = (_llvm_bswap_i32(($28|0))|0);
 HEAP32[$22>>2] = $29;
 $30 = (($this) + 40|0);
 $31 = (($32) + 4|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$30,4);
  $$pre$i$i$i7 = HEAP32[$30>>2]|0;
  $36 = $$pre$i$i$i7;
  $37 = (_llvm_bswap_i32(($36|0))|0);
  HEAP32[$30>>2] = $37;
  STACKTOP = sp;return;
 } else {
  $35 = HEAP32[$32>>2]|0;
  HEAP32[$30>>2] = $35;
  HEAP32[$0>>2] = $31;
  $36 = $35;
  $37 = (_llvm_bswap_i32(($36|0))|0);
  HEAP32[$30>>2] = $37;
  STACKTOP = sp;return;
 }
}
function __ZN14AnimationEvent8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = Math_fround(HEAPF32[$this>>2]);
  HEAPF32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
 }
 $7 = (($this) + 4|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$7,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $8 = (($this) + 16|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$8,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $9 = (($this) + 28|0);
 __ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($9,$transfer);
 $10 = (($this) + 32|0);
 $11 = HEAP32[$0>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$3>>2]|0;
 $14 = ($12>>>0)<($13>>>0);
 if ($14) {
  $15 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$11>>2] = $15;
  HEAP32[$0>>2] = $12;
  $18 = $12;$20 = $13;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$10,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $18 = $$pre;$20 = $$pre3;
 }
 $16 = (($this) + 36|0);
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)<($20>>>0);
 if ($19) {
  $21 = HEAP32[$16>>2]|0;
  HEAP32[$18>>2] = $21;
  HEAP32[$0>>2] = $17;
  $24 = $17;$26 = $20;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$16,4);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $24 = $$pre4;$26 = $$pre5;
 }
 $22 = (($this) + 40|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)<($26>>>0);
 if ($25) {
  $27 = HEAP32[$22>>2]|0;
  HEAP32[$24>>2] = $27;
  HEAP32[$0>>2] = $23;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$22,4);
  STACKTOP = sp;return;
 }
}
function __ZN14AnimationEvent8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN16AnimationManager6UpdateEv($this) {
 $this = $this|0;
 var $$pre$i = 0, $$pre$i$i$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $animations$0 = 0, $j = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $j = sp;
 $0 = (__Z14GetTimeManagerv()|0);
 $1 = (($0) + 88|0);
 $2 = +HEAPF64[$1>>3];
 $3 = (__Z14GetTimeManagerv()|0);
 $4 = (($3) + 185|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($this) + 8|0);
 $animations$0 = $6 ? $7 : $this;
 $8 = (($j) + 4|0);
 $9 = (($j) + 8|0);
 HEAP32[$9>>2] = $animations$0;
 $10 = (($j) + 12|0);
 HEAP32[$10>>2] = 0;
 $11 = HEAP32[$animations$0>>2]|0;
 HEAP32[$j>>2] = $11;
 $12 = (($animations$0) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$12>>2] = $j;
 HEAP32[$8>>2] = $13;
 HEAP32[$animations$0>>2] = $animations$0;
 $14 = ($11|0)==($animations$0|0);
 if ($14) {
  HEAP32[$j>>2] = $j;
 }
 HEAP32[$12>>2] = $animations$0;
 $15 = ($13|0)==($animations$0|0);
 if ($15) {
  HEAP32[$8>>2] = $j;
 }
 $16 = (($animations$0) + 4|0);
 HEAP32[$16>>2] = $animations$0;
 HEAP32[$animations$0>>2] = $animations$0;
 $17 = HEAP32[$j>>2]|0;
 $18 = (($17) + 4|0);
 HEAP32[$18>>2] = $j;
 $19 = HEAP32[$8>>2]|0;
 HEAP32[$19>>2] = $j;
 while(1) {
  $20 = HEAP32[$8>>2]|0;
  $21 = ($20|0)==($j|0);
  if ($21) {
   break;
  }
  HEAP32[$10>>2] = $20;
  $22 = HEAP32[$20>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   $31 = $20;
  } else {
   $24 = (($20) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($22) + 4|0);
   HEAP32[$26>>2] = $25;
   $27 = HEAP32[$20>>2]|0;
   $28 = HEAP32[$24>>2]|0;
   HEAP32[$28>>2] = $27;
   HEAP32[$20>>2] = 0;
   HEAP32[$24>>2] = 0;
   $$pre3$i = HEAP32[$10>>2]|0;
   $31 = $$pre3$i;
  }
  $29 = HEAP32[$9>>2]|0;
  $30 = ($31|0)==($29|0);
  if ($30) {
   $42 = $31;
  } else {
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   $$pre$i$i$i = (($31) + 4|0);
   if (!($33)) {
    $34 = HEAP32[$$pre$i$i$i>>2]|0;
    $35 = (($32) + 4|0);
    HEAP32[$35>>2] = $34;
    $36 = HEAP32[$31>>2]|0;
    $37 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$37>>2] = $36;
    HEAP32[$31>>2] = 0;
    HEAP32[$$pre$i$i$i>>2] = 0;
   }
   $38 = HEAP32[$29>>2]|0;
   HEAP32[$31>>2] = $38;
   HEAP32[$$pre$i$i$i>>2] = $29;
   $39 = (($38) + 4|0);
   HEAP32[$39>>2] = $31;
   $40 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$40>>2] = $31;
   $$pre$i = HEAP32[$10>>2]|0;
   $42 = $$pre$i;
  }
  $41 = ($42|0)==(0|0);
  if ($41) {
   label = 16;
   break;
  }
  $43 = (($42) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  __ZN9Animation15UpdateAnimationEd($44,$2);
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16AnimationManager15InitializeClassEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy,1,16,769024,33)|0);
 $3 = (($2) + 4|0);
 HEAP32[$2>>2] = $2;
 HEAP32[$3>>2] = $2;
 $4 = (($2) + 8|0);
 $5 = (($2) + 12|0);
 HEAP32[$4>>2] = $4;
 HEAP32[$5>>2] = $4;
 HEAP32[769032>>2] = $2;
 HEAP32[579416>>2] = 157;
 __Z39InitializeAnimationStateNetworkProviderv();
 STACKTOP = sp;return;
}
function __ZZN16AnimationManager15InitializeClassEvEN21LegacyAnimationUpdate7ForwardE_0v() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[769032>>2]|0;
 __ZN16AnimationManager6UpdateEv($0);
 STACKTOP = sp;return;
}
function __ZN16AnimationManager12CleanupClassEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[769032>>2]|0;
 $2 = HEAP32[628296>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[769032>>2] = 0;
 __Z36CleanupAnimationStateNetworkProviderv();
 STACKTOP = sp;return;
}
function __Z19GetAnimationManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[769032>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN14AnimationState15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13AnimationClip24SetDidModifyClipCallbackEPFvPS_R4ListI8ListNodeI14AnimationStateEEE(3393);
 STACKTOP = sp;return;
}
function __ZN14AnimationState22DidModifyAnimationClipEP13AnimationClipR4ListI8ListNodeIS_EE($clip,$states) {
 $clip = $clip|0;
 $states = $states|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $node$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($states) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($states|0);
 if (!($3)) {
  $4 = ($clip|0)==(0|0);
  $5 = (($0) + 4|0);
  if ($4) {
   $7 = $2;
   while(1) {
    $6 = (($7) + 8|0);
    $8 = HEAP32[$6>>2]|0;
    $9 = (($8) + 96|0);
    HEAP32[$9>>2] = 0;
    $10 = (($8) + 56|0);
    $11 = HEAP16[$10>>1]|0;
    $12 = $11 & -129;
    HEAP16[$10>>1] = $12;
    $13 = (($8) + 64|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 | 1;
    HEAP32[$13>>2] = $15;
    $16 = (($7) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==($states|0);
    if ($18) {
     break;
    } else {
     $7 = $17;
    }
   }
  } else {
   $20 = $2;
   while(1) {
    $19 = (($20) + 8|0);
    $21 = HEAP32[$19>>2]|0;
    $22 = (($21) + 96|0);
    $23 = HEAP32[$22>>2]|0;
    __ZN13AnimationClip8GetRangeEv($0,$23);
    $24 = Math_fround(HEAPF32[$0>>2]);
    $25 = (($21) + 88|0);
    HEAPF32[$25>>2] = $24;
    $26 = Math_fround(HEAPF32[$5>>2]);
    $27 = (($21) + 92|0);
    HEAPF32[$27>>2] = $26;
    $28 = HEAP32[$22>>2]|0;
    $29 = (($28) + 152|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 156|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($30|0)==($32|0);
    $34 = (($21) + 56|0);
    $35 = $33&1;
    $36 = HEAP16[$34>>1]|0;
    $37 = ($35 << 7)&65535;
    $38 = $36 & -129;
    $39 = $37 | $38;
    $40 = $39 ^ 128;
    HEAP16[$34>>1] = $40;
    $41 = (($21) + 64|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42 | 1;
    HEAP32[$41>>2] = $43;
    $44 = (($20) + 4|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($45|0)==($states|0);
    if ($46) {
     break;
    } else {
     $20 = $45;
    }
   }
  }
 }
 $47 = ($clip|0)==(0|0);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$1>>2]|0;
 $49 = ($48|0)==($states|0);
 if (!($49)) {
  $node$01$i = $48;
  while(1) {
   $50 = (($node$01$i) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$node$01$i>>2] = 0;
   HEAP32[$50>>2] = 0;
   $52 = ($51|0)==($states|0);
   if ($52) {
    break;
   } else {
    $node$01$i = $51;
   }
  }
 }
 HEAP32[$1>>2] = $states;
 HEAP32[$states>>2] = $states;
 STACKTOP = sp;return;
}
function __ZN14AnimationState12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13AnimationClip24SetDidModifyClipCallbackEPFvPS_R4ListI8ListNodeI14AnimationStateEEE(0);
 STACKTOP = sp;return;
}
function __ZN14AnimationStateC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 88|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 92|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($this) + 100|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 104|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 108|0);
 HEAP32[$4>>2] = $this;
 $5 = (($this) + 112|0);
 $6 = (($this) + 140|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 144|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 140|0);
 $9 = (($this) + 136|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 96|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 56|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13 & -257;
 HEAP16[$12>>1] = $14;
 STACKTOP = sp;return;
}
function __ZN14AnimationStateD2Ev($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 96|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 136|0);
 $4 = (($this) + 140|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI9TransformEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($3,$5);
 $6 = (($this) + 144|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 140|0);
 HEAP32[$3>>2] = $7;
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 112|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $15 = (($8) + 1|0);
  HEAP8[$15>>0] = 0;
  HEAP8[$8>>0] = 0;
 } else {
  $12 = (($this) + 120|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP8[$13>>0] = 0;
  $14 = (($this) + 116|0);
  HEAP32[$14>>2] = 0;
 }
 $16 = (($this) + 56|0);
 $17 = HEAP16[$16>>1]|0;
 $18 = $17 & 16;
 $19 = ($18<<16>>16)==(0);
 $$pre$i = (($this) + 4|0);
 if (!($19)) {
  $20 = HEAP32[$$pre$i>>2]|0;
  $21 = ($20|0)==(0|0);
  if (!($21)) {
   __ZdaPv($20);
  }
 }
 HEAP32[$$pre$i>>2] = 0;
 $22 = (($this) + 100|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (($this) + 104|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($23) + 4|0);
  HEAP32[$27>>2] = $26;
  $28 = HEAP32[$22>>2]|0;
  $29 = HEAP32[$25>>2]|0;
  HEAP32[$29>>2] = $28;
  HEAP32[$22>>2] = 0;
  HEAP32[$25>>2] = 0;
 }
 $30 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI4PPtrI9TransformEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($3,$30);
 $31 = (($this) + 124|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32 & 1;
 $34 = ($33<<24>>24)==(0);
 if (!($34)) {
  $35 = (($this) + 132|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$1>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($36|0),($$byval_copy1|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   ___cxa_call_unexpected(($39|0));
   // unreachable;
  }
 }
 $41 = HEAP8[$8>>0]|0;
 $42 = $41 & 1;
 $43 = ($42<<24>>24)==(0);
 if (!($43)) {
  $44 = (($this) + 120|0);
  $45 = HEAP32[$44>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($45|0),($$byval_copy1|0));
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if ($47) {
   $48 = ___cxa_find_matching_catch()|0;
   $49 = tempRet0;
   ___cxa_call_unexpected(($48|0));
   // unreachable;
  }
 }
 $50 = HEAP32[$this>>2]|0;
 $51 = ($50|0)==(0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $52 = (__Z29scripting_gchandle_get_targeti($50)|0);
 $53 = ($52|0)==(0|0);
 if (!($53)) {
  $54 = (($52) + 8|0);
  HEAP32[$54>>2] = 0;
 }
 $55 = HEAP32[$this>>2]|0;
 __Z23scripting_gchandle_freei($55);
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14AnimationState13CleanupCurvesEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 16;
 $3 = ($2<<16>>16)==(0);
 $$pre = (($this) + 4|0);
 if ($3) {
  label = 3;
 } else {
  $4 = HEAP32[$$pre>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   label = 3;
  } else {
   __ZdaPv($4);
  }
 }
 if ((label|0) == 3) {
 }
 HEAP32[$$pre>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14AnimationState14AllocateCurvesEi($this,$count) {
 $this = $this|0;
 $count = $count|0;
 var $$arith = 0, $$overflow = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 | 16;
 HEAP16[$0>>1] = $2;
 $$arith = $count<<2;
 $$overflow = ($count>>>0)>(1073741823);
 $3 = $$overflow ? -1 : $$arith;
 $4 = (__Znaj($3)|0);
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = ($count|0)>(0);
 if ($6) {
  $8 = $4;$i$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $7 = (($8) + ($i$01<<2)|0);
  HEAP32[$7>>2] = 0;
  $9 = (($i$01) + 1)|0;
  $exitcond = ($9|0)==($count|0);
  if ($exitcond) {
   break;
  }
  $$pre = HEAP32[$5>>2]|0;
  $8 = $$pre;$i$01 = $9;
 }
 STACKTOP = sp;return;
}
function __ZN14AnimationState15SetClonedCurvesERS_($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & -17;
 HEAP16[$0>>1] = $2;
 $3 = (($state) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN14AnimationState15SetWeightTargetEffb($this,$target,$length,$stopWhenFaded) {
 $this = $this|0;
 $target = Math_fround($target);
 $length = Math_fround($length);
 $stopWhenFaded = $stopWhenFaded|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0;
 var $newWeightDelta$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +$length;
 $1 = $0 > 0.00100000000000000002082;
 $2 = (($this) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($target - $3);
 if ($1) {
  $5 = Math_fround($4 / $length);
  $newWeightDelta$0 = $5;
 } else {
  $6 = Math_fround($4 * Math_fround(1.0E+5));
  $newWeightDelta$0 = $6;
 }
 $7 = (($this) + 56|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8 & 1;
 $10 = ($9<<16>>16)==(0);
 if ($10) {
  label = 13;
 } else {
  $11 = (($this) + 52|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($12 - $target);
  $14 = $13 < Math_fround(0.0);
  if ($14) {
   $15 = Math_fround(-$13);
   $17 = $15;
  } else {
   $17 = $13;
  }
  $16 = !($17 <= Math_fround(9.99999974737875163555E-5));
  if ($16) {
   label = 13;
  } else {
   $18 = (($this) + 76|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = $19 < Math_fround(0.0);
   if ($20) {
    $21 = Math_fround(-$19);
    $25 = $21;
   } else {
    $25 = $19;
   }
   $22 = $newWeightDelta$0 < Math_fround(0.0);
   if ($22) {
    $23 = Math_fround(-$newWeightDelta$0);
    $26 = $23;
   } else {
    $26 = $newWeightDelta$0;
   }
   $24 = $25 > $26;
   if ($24) {
    $30 = $19;
   } else {
    label = 13;
   }
  }
 }
 if ((label|0) == 13) {
  $27 = (($this) + 76|0);
  HEAPF32[$27>>2] = $newWeightDelta$0;
  $30 = $newWeightDelta$0;
 }
 $28 = (($this) + 76|0);
 $29 = $30 < Math_fround(0.0);
 if ($29) {
  $31 = Math_fround(-$30);
  $33 = $31;
 } else {
  $33 = $30;
 }
 $32 = !($33 <= Math_fround(9.99999974737875163555E-5));
 if ($32) {
  $34 = (($this) + 52|0);
  HEAPF32[$34>>2] = $target;
  $35 = $stopWhenFaded&1;
  $36 = ($35 << 2)&65535;
  $37 = $8 & -38;
  $38 = $36 | $37;
  $39 = $38 | 1;
  HEAP16[$7>>1] = $39;
  STACKTOP = sp;return;
 }
 HEAPF32[$28>>2] = Math_fround(1.0E+5);
 $34 = (($this) + 52|0);
 HEAPF32[$34>>2] = $target;
 $35 = $stopWhenFaded&1;
 $36 = ($35 << 2)&65535;
 $37 = $8 & -38;
 $38 = $36 | $37;
 $39 = $38 | 1;
 HEAP16[$7>>1] = $39;
 STACKTOP = sp;return;
}
function __ZN14AnimationState24SetWeightTargetImmediateEfb($this,$target,$stopWhenFaded) {
 $this = $this|0;
 $target = Math_fround($target);
 $stopWhenFaded = $stopWhenFaded|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAPF32[$0>>2] = $target;
 $1 = (($this) + 56|0);
 $2 = $stopWhenFaded&1;
 $3 = HEAP16[$1>>1]|0;
 $4 = ($2 << 2)&65535;
 $5 = $3 & -38;
 $6 = $5 | $4;
 HEAP16[$1>>1] = $6;
 STACKTOP = sp;return;
}
function __ZN14AnimationState12SetupFadeoutEf($this,$length) {
 $this = $this|0;
 $length = Math_fround($length);
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAPF32[$0>>2] = $length;
 STACKTOP = sp;return;
}
function __ZN14AnimationState7SetTimeEf($this,$time) {
 $this = $this|0;
 $time = Math_fround($time);
 var $0 = 0.0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +$time;
 $1 = (($this) + 16|0);
 HEAPF64[$1>>3] = $0;
 $2 = (($this) + 88|0);
 $3 = (($this) + 68|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(__Z8WrapTimefRKNSt3__14pairIffEEi($time,$2,$4)));
 $6 = (($this) + 12|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 56|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8 & -1537;
 $10 = $9 | 512;
 HEAP16[$7>>1] = $10;
 STACKTOP = sp;return;
}
function __Z8WrapTimefRKNSt3__14pairIffEEi($curveT,$range,$m_WrapMode) {
 $curveT = Math_fround($curveT);
 $range = $range|0;
 $m_WrapMode = $m_WrapMode|0;
 var $$1 = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $5 = Math_fround(0);
 var $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $floorf$i$i$i = Math_fround(0), $floorf$i$i$i$i = Math_fround(0), $floorf$i$i$i$i5 = Math_fround(0), $floorf$i$i$i4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$range>>2]);
 $1 = (($range) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = !($2 <= $curveT);
 do {
  if ($3) {
   $23 = $0 > $curveT;
   if ($23) {
    if ((($m_WrapMode|0) == 1) | (($m_WrapMode|0) == 8)) {
     $$1 = $0;
     break;
    } else if ((($m_WrapMode|0) == 2)) {
     $24 = Math_fround($curveT - $0);
     $25 = Math_fround($2 - $0);
     $26 = Math_fround($24 / $25);
     $floorf$i$i$i4 = (Math_fround(Math_floor((Math_fround($26)))));
     $27 = Math_fround($25 * $floorf$i$i$i4);
     $28 = Math_fround($24 - $27);
     $29 = Math_fround($0 + $28);
     $$1 = $29;
     break;
    }
    $30 = ($m_WrapMode|0)==(4);
    if ($30) {
     $31 = Math_fround($curveT - $0);
     $32 = Math_fround($2 - $0);
     $33 = Math_fround($32 * Math_fround(2.0));
     $34 = Math_fround($31 / $33);
     $floorf$i$i$i$i5 = (Math_fround(Math_floor((Math_fround($34)))));
     $35 = Math_fround($33 * $floorf$i$i$i$i5);
     $36 = Math_fround($31 - $35);
     $37 = Math_fround($36 - $32);
     $38 = $37 < Math_fround(0.0);
     if ($38) {
      $39 = Math_fround(-$37);
      $41 = $39;
     } else {
      $41 = $37;
     }
     $40 = Math_fround($32 - $41);
     $42 = Math_fround($0 + $40);
     $$1 = $42;
    } else {
     $$1 = $curveT;
    }
   } else {
    $$1 = $curveT;
   }
  } else {
   if ((($m_WrapMode|0) == 2)) {
    $4 = Math_fround($curveT - $0);
    $5 = Math_fround($2 - $0);
    $6 = Math_fround($4 / $5);
    $floorf$i$i$i = (Math_fround(Math_floor((Math_fround($6)))));
    $7 = Math_fround($5 * $floorf$i$i$i);
    $8 = Math_fround($4 - $7);
    $9 = Math_fround($0 + $8);
    $$1 = $9;
    break;
   } else if ((($m_WrapMode|0) == 1) | (($m_WrapMode|0) == 8)) {
    $$1 = $2;
    break;
   }
   $10 = ($m_WrapMode|0)==(4);
   if ($10) {
    $11 = Math_fround($curveT - $0);
    $12 = Math_fround($2 - $0);
    $13 = Math_fround($12 * Math_fround(2.0));
    $14 = Math_fround($11 / $13);
    $floorf$i$i$i$i = (Math_fround(Math_floor((Math_fround($14)))));
    $15 = Math_fround($13 * $floorf$i$i$i$i);
    $16 = Math_fround($11 - $15);
    $17 = Math_fround($16 - $12);
    $18 = $17 < Math_fround(0.0);
    if ($18) {
     $19 = Math_fround(-$17);
     $21 = $19;
    } else {
     $21 = $17;
    }
    $20 = Math_fround($12 - $21);
    $22 = Math_fround($0 + $20);
    $$1 = $22;
   } else {
    $$1 = $curveT;
   }
  }
 } while(0);
 STACKTOP = sp;return (Math_fround($$1));
}
function __ZN14AnimationState8SetSpeedEf($this,$speed) {
 $this = $this|0;
 $speed = Math_fround($speed);
 var $$ = 0, $$0$i1 = 0, $$0$i3 = 0, $$sink$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = Math_fround(0), $19 = 0.0, $2 = 0, $20 = 0.0, $21 = Math_fround(0), $22 = 0;
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $newSpeedDirection$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 1536;
 $3 = ($2<<16>>16)==(1536);
 if ($3) {
  $4 = $speed == Math_fround(0.0);
  if (!($4)) {
   $5 = $speed > Math_fround(0.0);
   $6 = $5 ? 1 : -1;
   $7 = (($this) + 68|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(4);
   if ($9) {
    $10 = (($this) + 88|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    $12 = (($this) + 92|0);
    $13 = Math_fround(HEAPF32[$12>>2]);
    $14 = (($this) + 16|0);
    $15 = +HEAPF64[$14>>3];
    $16 = +$11;
    $17 = $15 - $16;
    $18 = Math_fround($13 - $11);
    $19 = +$18;
    $20 = $17 / $19;
    $21 = Math_fround($20);
    $22 = !($21 >= Math_fround(0.0));
    if ($22) {
     $23 = Math_fround($21 + Math_fround(-0.999999940395355224609));
     $$sink$i = $23;
    } else {
     $$sink$i = $21;
    }
    $24 = (~~(($$sink$i)));
    $25 = $24 & 1;
    $26 = ($25|0)==(0);
    $27 = (0 - ($6))|0;
    $$ = $26 ? $6 : $27;
    $newSpeedDirection$0 = $$;
   } else {
    $newSpeedDirection$0 = $6;
   }
   $28 = $1 & -1537;
   HEAP16[$0>>1] = $28;
   $29 = ($newSpeedDirection$0|0)>(0);
   $30 = $29 ? 1 : -1;
   $31 = (($this) + 60|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($32) + ($30))|0;
   HEAP32[$31>>2] = $33;
  }
 } else {
  $34 = (($this) + 36|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = $35 == Math_fround(0.0);
  if ($36) {
   $$0$i3 = 0;
  } else {
   $37 = $35 > Math_fround(0.0);
   $38 = $37 ? 1 : -1;
   $$0$i3 = $38;
  }
  $39 = $speed == Math_fround(0.0);
  if ($39) {
   $$0$i1 = 0;
  } else {
   $40 = $speed > Math_fround(0.0);
   $41 = $40 ? 1 : -1;
   $$0$i1 = $41;
  }
  $42 = ($$0$i3|0)==($$0$i1|0);
  if (!($42)) {
   $43 = $1 & -1537;
   $44 = $43 | 512;
   HEAP16[$0>>1] = $44;
  }
 }
 $45 = (($this) + 36|0);
 HEAPF32[$45>>2] = $speed;
 $46 = (($this) + 40|0);
 HEAPF32[$46>>2] = $speed;
 $47 = $speed >= Math_fround(0.0);
 $48 = (($this) + 68|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49>>>0)<(2);
 if (!($50)) {
  if ($47) {
   $56 = Math_fround(inf);
   $55 = (($this) + 44|0);
   HEAPF32[$55>>2] = $56;
   STACKTOP = sp;return;
  }
  $56 = Math_fround(-inf);
  $55 = (($this) + 44|0);
  HEAPF32[$55>>2] = $56;
  STACKTOP = sp;return;
 }
 if ($47) {
  $51 = (($this) + 92|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $56 = $52;
  $55 = (($this) + 44|0);
  HEAPF32[$55>>2] = $56;
  STACKTOP = sp;return;
 } else {
  $53 = (($this) + 88|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $56 = $54;
  $55 = (($this) + 44|0);
  HEAPF32[$55>>2] = $56;
  STACKTOP = sp;return;
 }
}
function __ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,$deltaTime,$newWrappedTime,$forward,$animation,$beginTime,$offsetTime,$reverseOffsetTime) {
 $this = $this|0;
 $deltaTime = Math_fround($deltaTime);
 $newWrappedTime = Math_fround($newWrappedTime);
 $forward = $forward|0;
 $animation = $animation|0;
 $beginTime = Math_fround($beginTime);
 $offsetTime = Math_fround($offsetTime);
 $reverseOffsetTime = $reverseOffsetTime|0;
 var $$0 = 0, $$0$i = 0, $$0$i2 = 0, $$lcssa = Math_fround(0), $$lcssa5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0);
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0);
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $forward$not = 0, $i$010 = 0, $i1$0 = 0, $i1$0$in = 0, $or$cond = 0, $or$cond1$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 152|0);
 $3 = (($this) + 56|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 & 1536;
 $6 = ($5<<16>>16)==(512);
 $7 = (($this) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 if ($6) {
  $9 = (($1) + 156|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$2>>2]|0;
  L3: do {
   if ($forward) {
    $12 = ($10|0)==($11|0);
    if ($12) {
     $35 = $4;
    } else {
     $i$010 = 0;
     while(1) {
      $19 = (($11) + (($i$010*56)|0)|0);
      $20 = Math_fround(HEAPF32[$19>>2]);
      $21 = !($20 >= $8);
      $18 = (($i$010) + 1)|0;
      if (!($21)) {
       break;
      }
      $13 = $10;
      $14 = $11;
      $15 = (($13) - ($14))|0;
      $16 = (($15|0) / 56)&-1;
      $17 = ($18>>>0)<($16>>>0);
      if ($17) {
       $i$010 = $18;
      } else {
       $35 = $4;
       break L3;
      }
     }
     $22 = (($this) + 60|0);
     HEAP32[$22>>2] = $i$010;
     $23 = $4 & -1537;
     HEAP16[$3>>1] = $23;
     $35 = $23;
    }
   } else {
    $24 = $10;
    $25 = $11;
    $26 = (($24) - ($25))|0;
    $27 = (($26|0) / 56)&-1;
    $i1$0$in = $27;
    while(1) {
     $i1$0 = (($i1$0$in) + -1)|0;
     $28 = ($i1$0$in|0)>(0);
     if (!($28)) {
      $35 = $4;
      break L3;
     }
     $29 = (($11) + (($i1$0*56)|0)|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     $31 = !($30 <= $8);
     if ($31) {
      $i1$0$in = $i1$0;
     } else {
      break;
     }
    }
    $32 = (($this) + 60|0);
    HEAP32[$32>>2] = $i1$0;
    $33 = $4 & -1537;
    HEAP16[$3>>1] = $33;
    $35 = $33;
   }
  } while(0);
  $34 = $35 & 1536;
  $36 = ($34<<16>>16)==(512);
  if ($36) {
   $37 = $35 & -1537;
   $38 = $37 | 1024;
   HEAP16[$3>>1] = $38;
  }
 }
 $39 = (($this) + 40|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($this) + 12|0);
 $42 = (($this) + 60|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)<(0);
 if ($44) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($1) + 156|0);
 $forward$not = $forward ^ 1;
 L20: do {
  if ($forward) {
   $53 = $43;
   while(1) {
    $46 = HEAP32[$45>>2]|0;
    $47 = HEAP32[$2>>2]|0;
    $48 = $46;
    $49 = $47;
    $50 = (($48) - ($49))|0;
    $51 = (($50|0) / 56)&-1;
    $52 = ($53|0)<($51|0);
    if (!($52)) {
     $$0 = 1;
     label = 34;
     break;
    }
    $54 = (($47) + (($53*56)|0)|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = $55 > $newWrappedTime;
    $57 = $55 < $newWrappedTime;
    $or$cond1$us = $57 & $forward$not;
    $or$cond = $56 | $or$cond1$us;
    if ($or$cond) {
     $$0 = 1;
     label = 34;
     break;
    }
    (__Z9FireEventR14AnimationEventRN5Unity9ComponentEP14AnimationStateP17AnimatorStateInfoP16AnimatorClipInfo($54,$animation,$this,0,0)|0);
    $58 = HEAP16[$3>>1]|0;
    $59 = $58 & 1536;
    $60 = ($59<<16>>16)==(512);
    if ($60) {
     $$lcssa = $55;$$lcssa5 = $53;$99 = $58;
     break L20;
    }
    $61 = HEAP32[$42>>2]|0;
    $62 = (($61) + 1)|0;
    HEAP32[$42>>2] = $62;
    $63 = ($62|0)<(0);
    if ($63) {
     $$0 = 1;
     label = 34;
     break;
    } else {
     $53 = $62;
    }
   }
   if ((label|0) == 34) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $71 = $43;
   while(1) {
    $64 = HEAP32[$45>>2]|0;
    $65 = HEAP32[$2>>2]|0;
    $66 = $64;
    $67 = $65;
    $68 = (($66) - ($67))|0;
    $69 = (($68|0) / 56)&-1;
    $70 = ($71|0)<($69|0);
    if (!($70)) {
     $$0 = 1;
     label = 34;
     break;
    }
    $72 = (($65) + (($71*56)|0)|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = $73 < $newWrappedTime;
    if ($74) {
     $$0 = 1;
     label = 34;
     break;
    }
    (__Z9FireEventR14AnimationEventRN5Unity9ComponentEP14AnimationStateP17AnimatorStateInfoP16AnimatorClipInfo($72,$animation,$this,0,0)|0);
    $75 = HEAP16[$3>>1]|0;
    $76 = $75 & 1536;
    $77 = ($76<<16>>16)==(512);
    if ($77) {
     $$lcssa = $73;$$lcssa5 = $71;$99 = $75;
     break L20;
    }
    $78 = HEAP32[$42>>2]|0;
    $79 = (($78) + -1)|0;
    HEAP32[$42>>2] = $79;
    $80 = ($78|0)<(1);
    if ($80) {
     $$0 = 1;
     label = 34;
     break;
    } else {
     $71 = $79;
    }
   }
   if ((label|0) == 34) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $81 = $40 == Math_fround(0.0);
 if ($81) {
  $$0$i2 = 0;
 } else {
  $82 = $40 > Math_fround(0.0);
  $83 = $82 ? 1 : -1;
  $$0$i2 = $83;
 }
 $84 = Math_fround(HEAPF32[$39>>2]);
 $85 = $84 == Math_fround(0.0);
 if ($85) {
  $$0$i = 0;
 } else {
  $86 = $84 > Math_fround(0.0);
  $87 = $86 ? 1 : -1;
  $$0$i = $87;
 }
 $88 = ($$0$i2|0)==($$0$i|0);
 if ($88) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $89 = Math_fround(HEAPF32[$41>>2]);
 $90 = $89 == $8;
 if (!($90)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $91 = Math_fround($$lcssa - $beginTime);
 if ($reverseOffsetTime) {
  $92 = Math_fround(-$91);
  $94 = $92;
 } else {
  $94 = $91;
 }
 $93 = Math_fround($94 + $offsetTime);
 $95 = +$93;
 $96 = (($this) + 16|0);
 HEAPF64[$96>>3] = $95;
 HEAPF32[$41>>2] = $$lcssa;
 $97 = ($$0$i|0)==(0);
 if ($97) {
  HEAP32[$42>>2] = $$lcssa5;
  $98 = $99 | 1536;
  HEAP16[$3>>1] = $98;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $100 = $forward ? -1 : 1;
  $101 = (($$lcssa5) + ($100))|0;
  HEAP32[$42>>2] = $101;
  $102 = $99 & -1537;
  HEAP16[$3>>1] = $102;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN14AnimationState20UpdateAnimationStateEdRN5Unity9ComponentE($this,$globalTime,$animationComponent) {
 $this = $this|0;
 $globalTime = +$globalTime;
 $animationComponent = $animationComponent|0;
 var $$ = 0, $$sink$i = Math_fround(0), $$sink$i2 = Math_fround(0), $0 = 0, $1 = 0.0, $10 = 0.0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0.0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = Math_fround(0), $130 = 0.0;
 var $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = 0.0, $136 = 0.0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0.0, $145 = 0.0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0.0, $149 = 0.0;
 var $15 = 0, $150 = 0.0, $151 = Math_fround(0), $152 = 0.0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = Math_fround(0), $167 = 0.0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0);
 var $186 = 0, $187 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = Math_fround(0), $30 = 0.0, $31 = 0.0, $32 = Math_fround(0), $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0.0, $39 = 0.0, $4 = 0, $40 = Math_fround(0), $41 = 0.0, $42 = 0.0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0.0, $51 = 0.0, $52 = 0.0;
 var $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0.0, $66 = 0.0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0);
 var $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = Math_fround(0), $93 = 0.0, $94 = 0, $95 = 0.0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $floorf$i$i$i$i = Math_fround(0), $newWrappedTime$0 = Math_fround(0), $newWrappedTime$1 = Math_fround(0), $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = +HEAPF64[$0>>3];
 $2 = $globalTime - $1;
 $3 = Math_fround($2);
 HEAPF64[$0>>3] = $globalTime;
 $4 = (($this) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($5 * $3);
 $7 = $6 != Math_fround(0.0);
 if (!($7)) {
  $187 = (__ZN14AnimationState12UpdateFadingEf($this,$3)|0);
  STACKTOP = sp;return ($187|0);
 }
 $8 = (($this) + 16|0);
 $9 = +HEAPF64[$8>>3];
 $10 = +$6;
 $11 = $10 + $9;
 HEAPF64[$8>>3] = $11;
 $12 = (($this) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($6 + $13);
 $15 = (($this) + 88|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($this) + 92|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = $5 >= Math_fround(0.0);
 $20 = (($this) + 68|0);
 $21 = HEAP32[$20>>2]|0;
 L4: do {
  switch ($21|0) {
  case 0:  {
   $103 = (($this) + 56|0);
   $104 = HEAP16[$103>>1]|0;
   $105 = $104 & 128;
   $106 = ($105<<16>>16)==(0);
   if ($106) {
    $newWrappedTime$1 = $14;
   } else {
    (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$14,$19,$animationComponent,$16,$16,0)|0);
    $newWrappedTime$1 = $14;
   }
   break;
  }
  case 2:  {
   $22 = !($14 >= $18);
   if (!($22)) {
    $23 = +$16;
    $24 = +$18;
    $25 = $11 - $23;
    $26 = $24 - $23;
    $27 = $25 / $26;
    $28 = (+Math_floor((+$27)));
    $29 = $26 * $28;
    $30 = $25 - $29;
    $31 = $23 + $30;
    $32 = Math_fround($31);
    $33 = (($this) + 56|0);
    $34 = HEAP16[$33>>1]|0;
    $35 = $34 & 128;
    $36 = ($35<<16>>16)==(0);
    if ($36) {
     $newWrappedTime$1 = $32;
     break L4;
    }
    $37 = Math_fround($32 - $16);
    $38 = +$37;
    $39 = $11 - $38;
    $40 = Math_fround($18 - $16);
    $41 = +$40;
    $42 = $39 - $41;
    $43 = Math_fround($42);
    $44 = (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$18,$19,$animationComponent,$16,$43,0)|0);
    if (!($44)) {
     $newWrappedTime$1 = $32;
     break L4;
    }
    $45 = Math_fround($40 + $43);
    $46 = (($this) + 60|0);
    HEAP32[$46>>2] = 0;
    $47 = HEAP16[$33>>1]|0;
    $48 = $47 & -1537;
    HEAP16[$33>>1] = $48;
    (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$32,$19,$animationComponent,$16,$45,0)|0);
    $newWrappedTime$1 = $32;
    break L4;
   }
   $49 = $14 < $16;
   if (!($49)) {
    $85 = (($this) + 56|0);
    $86 = HEAP16[$85>>1]|0;
    $87 = $86 & 128;
    $88 = ($87<<16>>16)==(0);
    if ($88) {
     $newWrappedTime$1 = $14;
     break L4;
    }
    $89 = Math_fround($14 - $16);
    $90 = +$89;
    $91 = $11 - $90;
    $92 = Math_fround($91);
    (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$14,$19,$animationComponent,$16,$92,0)|0);
    $newWrappedTime$1 = $14;
    break L4;
   }
   $50 = +$16;
   $51 = +$18;
   $52 = $11 - $50;
   $53 = $51 - $50;
   $54 = $52 / $53;
   $55 = (+Math_floor((+$54)));
   $56 = $53 * $55;
   $57 = $52 - $56;
   $58 = $50 + $57;
   $59 = Math_fround($58);
   $60 = (($this) + 56|0);
   $61 = HEAP16[$60>>1]|0;
   $62 = $61 & 128;
   $63 = ($62<<16>>16)==(0);
   if ($63) {
    $newWrappedTime$1 = $59;
   } else {
    $64 = Math_fround($18 - $59);
    $65 = +$64;
    $66 = $11 + $65;
    $67 = Math_fround($66);
    $68 = (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$16,$19,$animationComponent,$16,$67,0)|0);
    if ($68) {
     $69 = Math_fround($18 - $16);
     $70 = Math_fround($67 - $69);
     $71 = (($this) + 96|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = (($72) + 156|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($72) + 152|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = $74;
     $78 = $76;
     $79 = (($77) - ($78))|0;
     $80 = (($79|0) / 56)&-1;
     $81 = (($80) + -1)|0;
     $82 = (($this) + 60|0);
     HEAP32[$82>>2] = $81;
     $83 = HEAP16[$60>>1]|0;
     $84 = $83 & -1537;
     HEAP16[$60>>1] = $84;
     (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$59,$19,$animationComponent,$16,$70,0)|0);
     $newWrappedTime$1 = $59;
    } else {
     $newWrappedTime$1 = $59;
    }
   }
   break;
  }
  case 4:  {
   $107 = Math_fround($11);
   $108 = Math_fround($107 - $16);
   $109 = Math_fround($18 - $16);
   $110 = Math_fround($109 * Math_fround(2.0));
   $111 = Math_fround($108 / $110);
   $floorf$i$i$i$i = (Math_fround(Math_floor((Math_fround($111)))));
   $112 = Math_fround($110 * $floorf$i$i$i$i);
   $113 = Math_fround($108 - $112);
   $114 = Math_fround($113 - $109);
   $115 = $114 < Math_fround(0.0);
   if ($115) {
    $116 = Math_fround(-$114);
    $118 = $116;
   } else {
    $118 = $114;
   }
   $117 = Math_fround($109 - $118);
   $119 = Math_fround($16 + $117);
   $120 = (($this) + 56|0);
   $121 = HEAP16[$120>>1]|0;
   $122 = $121 & 128;
   $123 = ($122<<16>>16)==(0);
   if ($123) {
    $newWrappedTime$1 = $119;
   } else {
    $124 = (($this) + 96|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = (($125) + 152|0);
    $127 = +$16;
    $128 = $9 - $127;
    $129 = +$109;
    $130 = $128 / $129;
    $131 = Math_fround($130);
    $132 = !($131 >= Math_fround(0.0));
    if ($132) {
     $133 = Math_fround($131 + Math_fround(-0.999999940395355224609));
     $$sink$i = $133;
    } else {
     $$sink$i = $131;
    }
    $134 = (~~(($$sink$i)));
    $135 = $11 - $127;
    $136 = $135 / $129;
    $137 = Math_fround($136);
    $138 = !($137 >= Math_fround(0.0));
    if ($138) {
     $139 = Math_fround($137 + Math_fround(-0.999999940395355224609));
     $$sink$i2 = $139;
    } else {
     $$sink$i2 = $137;
    }
    $140 = (~~(($$sink$i2)));
    $141 = $140 & 1;
    $not$ = ($141|0)!=(0);
    $$ = $19 ^ $not$;
    $142 = ($134|0)==($140|0);
    if ($142) {
     $143 = Math_fround($119 - $16);
     $144 = +$143;
     $145 = $11 - $144;
     $146 = Math_fround($145);
     (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$119,$$,$animationComponent,$16,$146,0)|0);
     $newWrappedTime$1 = $119;
     break L4;
    }
    if ($$) {
     $147 = Math_fround($119 - $16);
     $148 = +$147;
     if ($19) {
      $149 = $11 - $148;
      $152 = $149;
     } else {
      $150 = $148 + $11;
      $152 = $150;
     }
     $151 = Math_fround($152);
     $153 = (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$16,0,$animationComponent,$16,$151,$19)|0);
     if (!($153)) {
      $newWrappedTime$1 = $119;
      break L4;
     }
     $154 = HEAP32[$126>>2]|0;
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = $155 == $16;
     $157 = $156&1;
     $158 = (($this) + 60|0);
     HEAP32[$158>>2] = $157;
     $159 = HEAP16[$120>>1]|0;
     $160 = $159 & -1537;
     HEAP16[$120>>1] = $160;
     $161 = $19 ^ 1;
     (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$119,1,$animationComponent,$18,$151,$161)|0);
     $newWrappedTime$1 = $119;
     break L4;
    } else {
     $162 = Math_fround($18 - $119);
     $163 = +$162;
     if ($19) {
      $164 = $11 - $163;
      $167 = $164;
     } else {
      $165 = $163 + $11;
      $167 = $165;
     }
     $166 = Math_fround($167);
     $168 = $19 ^ 1;
     $169 = (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$18,1,$animationComponent,$18,$166,$168)|0);
     if (!($169)) {
      $newWrappedTime$1 = $119;
      break L4;
     }
     $170 = (($125) + 156|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = HEAP32[$126>>2]|0;
     $173 = $171;
     $174 = $172;
     $175 = (($173) - ($174))|0;
     $176 = (($175|0) / 56)&-1;
     $177 = (($171) + -56|0);
     $178 = Math_fround(HEAPF32[$177>>2]);
     $179 = $178 == $18;
     $180 = $179 ? 2 : 1;
     $181 = (($176) - ($180))|0;
     $182 = (($this) + 60|0);
     HEAP32[$182>>2] = $181;
     $183 = HEAP16[$120>>1]|0;
     $184 = $183 & -1537;
     HEAP16[$120>>1] = $184;
     (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$119,0,$animationComponent,$16,$166,$19)|0);
     $newWrappedTime$1 = $119;
     break L4;
    }
   }
   break;
  }
  case 8: case 1:  {
   $93 = +$16;
   $94 = $11 < $93;
   if ($94) {
    $newWrappedTime$0 = $16;
   } else {
    $95 = +$18;
    $96 = $11 > $95;
    if ($96) {
     $newWrappedTime$0 = $18;
    } else {
     $97 = Math_fround($11);
     $newWrappedTime$0 = $97;
    }
   }
   $98 = (($this) + 56|0);
   $99 = HEAP16[$98>>1]|0;
   $100 = $99 & 128;
   $101 = ($100<<16>>16)==(0);
   if ($101) {
    $newWrappedTime$1 = $newWrappedTime$0;
   } else {
    $102 = Math_fround($11);
    (__ZN14AnimationState10FireEventsEffbRN5Unity9ComponentEffb($this,Math_fround(0.0),$102,$19,$animationComponent,$16,$16,0)|0);
    $newWrappedTime$1 = $newWrappedTime$0;
   }
   break;
  }
  default: {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769040,0,769064,522,1,0,0,0);
   $newWrappedTime$1 = $14;
  }
  }
 } while(0);
 $185 = Math_fround(HEAPF32[$12>>2]);
 $186 = $185 == $13;
 if (!($186)) {
  $187 = (__ZN14AnimationState12UpdateFadingEf($this,$3)|0);
  STACKTOP = sp;return ($187|0);
 }
 HEAPF32[$12>>2] = $newWrappedTime$1;
 $187 = (__ZN14AnimationState12UpdateFadingEf($this,$3)|0);
 STACKTOP = sp;return ($187|0);
}
function __ZN14AnimationState12UpdateFadingEf($this,$deltaTime) {
 $this = $this|0;
 $deltaTime = Math_fround($deltaTime);
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0.0, $25 = 0, $26 = 0.0, $27 = 0.0, $28 = Math_fround(0), $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0;
 var $97 = 0, $98 = Math_fround(0), $99 = 0, $didStopAtEnd$0$off0 = 0, $didStopAtEnd$1$off0 = 0, $newWeightDelta$0$i = Math_fround(0), $or$cond = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 32;
 $3 = ($2<<16>>16)==(0);
 do {
  if ($3) {
   $4 = (($this) + 68|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5>>>0)<(2);
   if ($6) {
    $7 = (($this) + 36|0);
    $8 = Math_fround(HEAPF32[$7>>2]);
    $9 = !($8 >= Math_fround(0.0));
    if ($9) {
     $19 = (($this) + 44|0);
     $20 = Math_fround(HEAPF32[$19>>2]);
     $21 = (($this) + 48|0);
     $22 = Math_fround(HEAPF32[$21>>2]);
     $23 = Math_fround($20 + $22);
     $24 = +$23;
     $25 = (($this) + 16|0);
     $26 = +HEAPF64[$25>>3];
     $27 = $24 - $26;
     $29 = $27;$32 = $22;
    } else {
     $10 = (($this) + 16|0);
     $11 = +HEAPF64[$10>>3];
     $12 = (($this) + 44|0);
     $13 = Math_fround(HEAPF32[$12>>2]);
     $14 = (($this) + 48|0);
     $15 = Math_fround(HEAPF32[$14>>2]);
     $16 = Math_fround($13 - $15);
     $17 = +$16;
     $18 = $11 - $17;
     $29 = $18;$32 = $15;
    }
    $28 = Math_fround($29);
    $30 = $28 > Math_fround(0.0);
    if ($30) {
     $31 = +$32;
     $33 = $31 > 0.00100000000000000002082;
     $34 = (($this) + 8|0);
     $35 = Math_fround(HEAPF32[$34>>2]);
     $36 = Math_fround(Math_fround(0.0) - $35);
     if ($33) {
      $37 = Math_fround($36 / $32);
      $newWeightDelta$0$i = $37;
     } else {
      $38 = Math_fround($36 * Math_fround(1.0E+5));
      $newWeightDelta$0$i = $38;
     }
     $39 = $1 & 1;
     $40 = ($39<<16>>16)==(0);
     if ($40) {
      label = 19;
     } else {
      $41 = (($this) + 52|0);
      $42 = Math_fround(HEAPF32[$41>>2]);
      $43 = $42 < Math_fround(0.0);
      if ($43) {
       $44 = Math_fround(-$42);
       $46 = $44;
      } else {
       $46 = $42;
      }
      $45 = !($46 <= Math_fround(9.99999974737875163555E-5));
      if ($45) {
       label = 19;
      } else {
       $47 = (($this) + 76|0);
       $48 = Math_fround(HEAPF32[$47>>2]);
       $49 = $48 < Math_fround(0.0);
       if ($49) {
        $50 = Math_fround(-$48);
        $54 = $50;
       } else {
        $54 = $48;
       }
       $51 = $newWeightDelta$0$i < Math_fround(0.0);
       if ($51) {
        $52 = Math_fround(-$newWeightDelta$0$i);
        $55 = $52;
       } else {
        $55 = $newWeightDelta$0$i;
       }
       $53 = $54 > $55;
       if ($53) {
        $59 = $48;
       } else {
        label = 19;
       }
      }
     }
     if ((label|0) == 19) {
      $56 = (($this) + 76|0);
      HEAPF32[$56>>2] = $newWeightDelta$0$i;
      $59 = $newWeightDelta$0$i;
     }
     $57 = (($this) + 76|0);
     $58 = $59 < Math_fround(0.0);
     if ($58) {
      $60 = Math_fround(-$59);
      $62 = $60;
     } else {
      $62 = $59;
     }
     $61 = !($62 <= Math_fround(9.99999974737875163555E-5));
     if ($61) {
      $67 = $59;
     } else {
      HEAPF32[$57>>2] = Math_fround(1.0E+5);
      $67 = Math_fround(1.0E+5);
     }
     $63 = (($this) + 52|0);
     HEAPF32[$63>>2] = Math_fround(0.0);
     $64 = $1 | 37;
     HEAP16[$0>>1] = $64;
     $65 = $32 == Math_fround(0.0);
     $66 = Math_fround($28 * $67);
     $68 = Math_fround($35 + $66);
     HEAPF32[$34>>2] = $68;
     if (!($65)) {
      $69 = $67 > Math_fround(0.0);
      $70 = $68 > Math_fround(0.0);
      $or$cond = $69 & $70;
      if (!($or$cond)) {
       $71 = $67 <= Math_fround(0.0);
       $72 = $68 < Math_fround(0.0);
       $or$cond7 = $71 & $72;
       if (!($or$cond7)) {
        $88 = $64;$didStopAtEnd$0$off0 = 0;
        break;
       }
      }
     }
     HEAPF32[$34>>2] = Math_fround(0.0);
     $73 = $64 & -34;
     HEAP16[$0>>1] = $73;
     $74 = (($this) + 12|0);
     $75 = Math_fround(HEAPF32[$74>>2]);
     $76 = (($this) + 80|0);
     HEAPF32[$76>>2] = $75;
     $77 = $1 & 10;
     $78 = ($77<<16>>16)==(10);
     if ($78) {
      $79 = $73 | 64;
      HEAP16[$0>>1] = $79;
      $81 = $79;
     } else {
      $81 = $73;
     }
     $80 = $81 & -3;
     HEAP16[$0>>1] = $80;
     $82 = (($this) + 16|0);
     HEAPF64[$82>>3] = 0.0;
     $83 = (($this) + 88|0);
     $84 = (Math_fround(__Z8WrapTimefRKNSt3__14pairIffEEi(Math_fround(0.0),$83,$5)));
     HEAPF32[$74>>2] = $84;
     $85 = $81 & -1544;
     $86 = $85 | 512;
     HEAP16[$0>>1] = $86;
     $88 = $86;$didStopAtEnd$0$off0 = 1;
    } else {
     $88 = $1;$didStopAtEnd$0$off0 = 0;
    }
   } else {
    $88 = $1;$didStopAtEnd$0$off0 = 0;
   }
  } else {
   $88 = $1;$didStopAtEnd$0$off0 = 0;
  }
 } while(0);
 $87 = $88 & 1;
 $89 = ($87<<16>>16)==(0);
 if ($89) {
  $didStopAtEnd$1$off0 = $didStopAtEnd$0$off0;
  STACKTOP = sp;return ($didStopAtEnd$1$off0|0);
 }
 $90 = (($this) + 76|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($91 * $deltaTime);
 $93 = (($this) + 8|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($94 + $92);
 HEAPF32[$93>>2] = $95;
 $96 = $91 > Math_fround(0.0);
 if ($96) {
  $97 = (($this) + 52|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = $95 > $98;
  if ($99) {
   $104 = $98;
  } else {
   label = 33;
  }
 } else {
  label = 33;
 }
 if ((label|0) == 33) {
  $100 = !($91 <= Math_fround(0.0));
  if ($100) {
   $didStopAtEnd$1$off0 = 0;
   STACKTOP = sp;return ($didStopAtEnd$1$off0|0);
  }
  $101 = (($this) + 52|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = $95 < $102;
  if ($103) {
   $104 = $102;
  } else {
   $didStopAtEnd$1$off0 = 0;
   STACKTOP = sp;return ($didStopAtEnd$1$off0|0);
  }
 }
 HEAPF32[$93>>2] = $104;
 $105 = $88 & -34;
 HEAP16[$0>>1] = $105;
 $106 = $88 & 4;
 $107 = ($106<<16>>16)==(0);
 if ($107) {
  $didStopAtEnd$1$off0 = 0;
  STACKTOP = sp;return ($didStopAtEnd$1$off0|0);
 }
 $108 = (($this) + 12|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($this) + 80|0);
 HEAPF32[$110>>2] = $109;
 $111 = $88 & 10;
 $112 = ($111<<16>>16)==(10);
 if ($112) {
  $113 = $105 | 64;
  HEAP16[$0>>1] = $113;
  $115 = $113;
 } else {
  $115 = $105;
 }
 $114 = $115 & -3;
 HEAP16[$0>>1] = $114;
 $116 = (($this) + 16|0);
 HEAPF64[$116>>3] = 0.0;
 $117 = (($this) + 88|0);
 $118 = (($this) + 68|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (Math_fround(__Z8WrapTimefRKNSt3__14pairIffEEi(Math_fround(0.0),$117,$119)));
 HEAPF32[$108>>2] = $120;
 $121 = $115 & -1544;
 $122 = $121 | 512;
 HEAP16[$0>>1] = $122;
 $didStopAtEnd$1$off0 = 1;
 STACKTOP = sp;return ($didStopAtEnd$1$off0|0);
}
function __ZN14AnimationState4StopEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 10;
 $3 = ($2<<16>>16)==(10);
 if ($3) {
  $4 = $1 | 64;
  HEAP16[$0>>1] = $4;
  $6 = $4;
 } else {
  $6 = $1;
 }
 $5 = $6 & -3;
 HEAP16[$0>>1] = $5;
 $7 = (($this) + 16|0);
 HEAPF64[$7>>3] = 0.0;
 $8 = (($this) + 88|0);
 $9 = (($this) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (Math_fround(__Z8WrapTimefRKNSt3__14pairIffEEi(Math_fround(0.0),$8,$10)));
 $12 = (($this) + 12|0);
 HEAPF32[$12>>2] = $11;
 $13 = $6 & -1544;
 $14 = $13 | 512;
 HEAP16[$0>>1] = $14;
 STACKTOP = sp;return;
}
function __ZN14AnimationState4InitERK8UnityStrP13AnimationClipdib($this,$name,$clip,$globalTime,$wrap,$isClone) {
 $this = $this|0;
 $name = $name|0;
 $clip = $clip|0;
 $globalTime = +$globalTime;
 $wrap = $wrap|0;
 $isClone = $isClone|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 56|0);
 $2 = $isClone&1;
 $3 = HEAP16[$1>>1]|0;
 $4 = ($2 << 8)&65535;
 $5 = $3 & -385;
 $6 = (($this) + 96|0);
 HEAP32[$6>>2] = $clip;
 $7 = $5 | $4;
 HEAP16[$1>>1] = $7;
 $8 = ($clip|0)==(0|0);
 if ($8) {
  $51 = $7;
 } else {
  __ZN13AnimationClip8GetRangeEv($0,$clip);
  $9 = Math_fround(HEAPF32[$0>>2]);
  $10 = (($this) + 88|0);
  HEAPF32[$10>>2] = $9;
  $11 = (($0) + 4|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($this) + 92|0);
  HEAPF32[$13>>2] = $12;
  $14 = HEAP32[$6>>2]|0;
  $15 = (($this) + 100|0);
  $16 = (($14) + 72|0);
  $17 = ($15|0)==($16|0);
  if (!($17)) {
   $18 = HEAP32[$15>>2]|0;
   $19 = ($18|0)==(0|0);
   $$pre$i$i$i = (($this) + 104|0);
   if (!($19)) {
    $20 = HEAP32[$$pre$i$i$i>>2]|0;
    $21 = (($18) + 4|0);
    HEAP32[$21>>2] = $20;
    $22 = HEAP32[$15>>2]|0;
    $23 = HEAP32[$$pre$i$i$i>>2]|0;
    HEAP32[$23>>2] = $22;
    HEAP32[$15>>2] = 0;
    HEAP32[$$pre$i$i$i>>2] = 0;
   }
   $24 = HEAP32[$16>>2]|0;
   HEAP32[$15>>2] = $24;
   HEAP32[$$pre$i$i$i>>2] = $16;
   $25 = (($24) + 4|0);
   HEAP32[$25>>2] = $15;
   $26 = HEAP32[$$pre$i$i$i>>2]|0;
   HEAP32[$26>>2] = $15;
  }
  $27 = (($this) + 112|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($27,$name)|0);
  $28 = HEAP32[$6>>2]|0;
  $29 = (($28) + 152|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 156|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($30|0)==($32|0);
  $34 = $33&1;
  $35 = HEAP16[$1>>1]|0;
  $36 = ($34 << 7)&65535;
  $37 = $35 & -129;
  $38 = $36 | $37;
  $39 = $38 ^ 128;
  HEAP16[$1>>1] = $39;
  $51 = $39;
 }
 $40 = (($this) + 72|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 8|0);
 HEAPF32[$41>>2] = Math_fround(0.0);
 $42 = (($this) + 48|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($this) + 12|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($this) + 60|0);
 HEAP32[$44>>2] = -1;
 $45 = (($this) + 16|0);
 HEAPF64[$45>>3] = 0.0;
 $46 = (($this) + 24|0);
 HEAPF64[$46>>3] = $globalTime;
 $47 = (($this) + 32|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 36|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($this) + 40|0);
 HEAPF32[$49>>2] = Math_fround(1.0);
 $50 = $51 & -1648;
 $52 = $50 | 512;
 HEAP16[$1>>1] = $52;
 $53 = (($this) + 68|0);
 HEAP32[$53>>2] = $wrap;
 $54 = (($this) + 88|0);
 $55 = (Math_fround(__Z8WrapTimefRKNSt3__14pairIffEEi(Math_fround(0.0),$54,$wrap)));
 HEAPF32[$43>>2] = $55;
 $56 = ($wrap>>>0)<(2);
 if (!($56)) {
  $60 = Math_fround(inf);
  $59 = (($this) + 44|0);
  HEAPF32[$59>>2] = $60;
  HEAPF64[$45>>3] = 0.0;
  $61 = (Math_fround(__Z8WrapTimefRKNSt3__14pairIffEEi(Math_fround(0.0),$54,$wrap)));
  HEAPF32[$43>>2] = $61;
  $62 = $51 & -1648;
  $63 = $62 | 512;
  HEAP16[$1>>1] = $63;
  $64 = (($this) + 64|0);
  HEAP32[$64>>2] = 3;
  STACKTOP = sp;return;
 }
 $57 = (($this) + 92|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $60 = $58;
 $59 = (($this) + 44|0);
 HEAPF32[$59>>2] = $60;
 HEAPF64[$45>>3] = 0.0;
 $61 = (Math_fround(__Z8WrapTimefRKNSt3__14pairIffEEi(Math_fround(0.0),$54,$wrap)));
 HEAPF32[$43>>2] = $61;
 $62 = $51 & -1648;
 $63 = $62 | 512;
 HEAP16[$1>>1] = $63;
 $64 = (($this) + 64|0);
 HEAP32[$64>>2] = 3;
 STACKTOP = sp;return;
}
function __ZN14AnimationState11SetWrapModeEi($this,$wrap) {
 $this = $this|0;
 $wrap = $wrap|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $2 = 0.0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 HEAP32[$0>>2] = $wrap;
 $1 = (($this) + 16|0);
 $2 = +HEAPF64[$1>>3];
 $3 = Math_fround($2);
 $4 = (($this) + 88|0);
 $5 = (Math_fround(__Z8WrapTimefRKNSt3__14pairIffEEi($3,$4,$wrap)));
 $6 = (($this) + 12|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 36|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $8 >= Math_fround(0.0);
 $10 = ($wrap>>>0)<(2);
 do {
  if ($10) {
   if ($9) {
    $11 = (($this) + 92|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    $16 = $12;
    break;
   } else {
    $13 = (($this) + 88|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $16 = $14;
    break;
   }
  } else {
   if ($9) {
    $16 = Math_fround(inf);
   } else {
    $16 = Math_fround(-inf);
   }
  }
 } while(0);
 $15 = (($this) + 44|0);
 HEAPF32[$15>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN14AnimationState10SetEnabledEb($this,$enabled) {
 $this = $this|0;
 $enabled = $enabled|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 if ($enabled) {
  $1 = HEAP16[$0>>1]|0;
  $2 = $1 & 2;
  $3 = ($2<<16>>16)==(0);
  if ($3) {
   $4 = (__Z14GetTimeManagerv()|0);
   $5 = (($4) + 88|0);
   $6 = +HEAPF64[$5>>3];
   $7 = (($this) + 24|0);
   HEAPF64[$7>>3] = $6;
  }
 }
 $8 = $enabled&1;
 $9 = HEAP16[$0>>1]|0;
 $10 = ($8 << 1)&65535;
 $11 = $9 & -3;
 $12 = $11 | $10;
 HEAP16[$0>>1] = $12;
 STACKTOP = sp;return;
}
function __ZN14AnimationState18ShouldMixTransformER9Transform($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, $temp$0$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 144|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($this) + 136|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 140|0);
 $7 = ($5|0)==($6|0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ($transform|0)==(0|0);
 $9 = (($transform) + 4|0);
 $11 = $5;
 L7: while(1) {
  $10 = (($11) + 20|0);
  $12 = HEAP8[$10>>0]|0;
  $13 = ($12<<24>>24)==(0);
  $14 = (($11) + 16|0);
  do {
   if ($13) {
    if ($8) {
     $55 = 0;
    } else {
     $52 = HEAP32[$9>>2]|0;
     $55 = $52;
    }
    $53 = HEAP32[$14>>2]|0;
    $54 = ($53|0)==($55|0);
    if ($54) {
     $$0 = 1;
     label = 24;
     break L7;
    }
   } else {
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0);
    if (!($16)) {
     HEAP32[$0>>2] = $15;
     $17 = HEAP32[560624>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      label = 14;
     } else {
      $19 = (($17) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($17) + 4|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($20|0)==($22|0);
      do {
       if ($23) {
        $24 = (($17) + 28|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = (($17) + 32|0);
        $27 = HEAP32[$26>>2]|0;
        $28 = (($25) + ($27<<3)|0);
        $44 = $28;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$17,$0);
        $29 = HEAP32[$pos$i$i$i>>2]|0;
        $30 = ($29|0)==(-1);
        $31 = (($17) + 28|0);
        $32 = HEAP32[$31>>2]|0;
        if ($30) {
         $33 = (($17) + 32|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = (($32) + ($34<<3)|0);
         $44 = $35;
         break;
        } else {
         $36 = (($32) + ($29<<3)|0);
         $44 = $36;
         break;
        }
       }
      } while(0);
      $37 = HEAP32[560624>>2]|0;
      $38 = (($37) + 28|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = (($37) + 32|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($39) + ($41<<3)|0);
      $43 = ($44|0)==($42|0);
      if ($43) {
       label = 14;
      } else {
       $45 = (($44) + 4|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ($46|0)==(0|0);
       if ($47) {
        label = 14;
       } else {
        $temp$0$i6 = $46;
       }
      }
     }
     if ((label|0) == 14) {
      label = 0;
      $48 = HEAP32[$14>>2]|0;
      $49 = (__Z31ReadObjectFromPersistentManageri($48)|0);
      $50 = ($49|0)==(0|0);
      if ($50) {
       break;
      } else {
       $temp$0$i6 = $49;
      }
     }
     $51 = (__Z22IsChildOrSameTransformR9TransformS0_($transform,$temp$0$i6)|0);
     if ($51) {
      $$0 = 1;
      label = 24;
      break L7;
     }
    }
   }
  } while(0);
  $56 = (($11) + 4|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0|0);
  if ($58) {
   $$01$i$i$i$i = $11;
   while(1) {
    $61 = (($$01$i$i$i$i) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = HEAP32[$62>>2]|0;
    $64 = ($63|0)==($$01$i$i$i$i|0);
    if ($64) {
     $$0$i$i$i$i = $62;
     break;
    } else {
     $$01$i$i$i$i = $62;
    }
   }
  } else {
   $$0$i$i$i$i$i = $57;
   while(1) {
    $59 = HEAP32[$$0$i$i$i$i$i>>2]|0;
    $60 = ($59|0)==(0|0);
    if ($60) {
     $$0$i$i$i$i = $$0$i$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i$i = $59;
    }
   }
  }
  $65 = ($$0$i$i$i$i|0)==($6|0);
  if ($65) {
   $$0 = 0;
   label = 24;
   break;
  } else {
   $11 = $$0$i$i$i$i;
  }
 }
 if ((label|0) == 24) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN14AnimationState19SetupUnstoppedStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 80|0);
 $2 = Math_fround(HEAPF32[$0>>2]);
 $3 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$0>>2] = $3;
 HEAPF32[$1>>2] = $2;
 $4 = (($this) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 84|0);
 HEAPF32[$6>>2] = $5;
 HEAPF32[$4>>2] = Math_fround(1.00100005511194467545E-4);
 $7 = (($this) + 56|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8 | 2;
 HEAP16[$7>>1] = $9;
 STACKTOP = sp;return;
}
function __ZN14AnimationState21CleanupUnstoppedStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 80|0);
 $2 = Math_fround(HEAPF32[$0>>2]);
 $3 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$0>>2] = $3;
 HEAPF32[$1>>2] = $2;
 $4 = (($this) + 84|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($this) + 8|0);
 HEAPF32[$6>>2] = $5;
 $7 = (($this) + 56|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8 & -3;
 HEAP16[$7>>1] = $9;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI4PPtrI9TransformEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI4PPtrI9TransformEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI4PPtrI9TransformEbEENS_19__map_value_compareIS4_S5_NS_4lessIS4_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp + 12|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$20 = $14;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4>>>0)<($6>>>0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6>>>0)<($4>>>0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $30 = 0;$__r$0 = $15;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE16__construct_nodeERKS3_($0,$this,$__v);
 $17 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$17>>2] = 0;
 $18 = (($17) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $17;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $17;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $17;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE16__construct_nodeERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (__Znwj(32)|0);
 $3 = $1;
 $4 = (($2) + 16|0);
 $5 = HEAP32[$__v>>2]|0;
 HEAP32[$4>>2] = $5;
 $6 = (($2) + 20|0);
 $7 = (($__v) + 4|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $15 = (($7) + 1|0);
  $16 = $8&255;
  $17 = $16 >>> 1;
  $19 = $17;$34 = $15;
 } else {
  $11 = (($__v) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($__v) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $19 = $14;$34 = $12;
 }
 $18 = ($19>>>0)>(2147483631);
 do {
  if ($18) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    // unreachable;
   }
  } else {
   $22 = ($19>>>0)<(11);
   if ($22) {
    $23 = $19 << 1;
    $24 = $23&255;
    HEAP8[$6>>0] = $24;
    $25 = (($2) + 21|0);
    $__p$0$i$i$i$i$i$i$i$i$i = $25;
   } else {
    $26 = (($19) + 16)|0;
    $27 = $26 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $28 = (invoke_iiiiiii(102,($27|0),16,($$byval_copy|0),0,(769072|0),79)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    $31 = (($2) + 28|0);
    HEAP32[$31>>2] = $28;
    $32 = $27 | 1;
    HEAP32[$6>>2] = $32;
    $33 = (($2) + 24|0);
    HEAP32[$33>>2] = $19;
    $__p$0$i$i$i$i$i$i$i$i$i = $28;
   }
   _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($34|0),($19|0))|0;
   $35 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($19)|0);
   HEAP8[$35>>0] = 0;
   $36 = HEAP32[$__v>>2]|0;
   HEAP32[$4>>2] = $36;
   HEAP32[$agg$result>>2] = $2;
   $37 = (($agg$result) + 4|0);
   $38 = $37;
   $39 = $38;
   HEAP32[$39>>2] = $3;
   $40 = (($38) + 4)|0;
   $41 = $40;
   HEAP32[$41>>2] = 1;
   STACKTOP = sp;return;
  }
 } while(0);
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 $44 = ($2|0)==(0|0);
 if ($44) {
  ___resumeException($42|0);
  // unreachable;
 }
 __ZdlPv($2);
 ___resumeException($42|0);
 // unreachable;
}
function __ZN6Avatar8GetAssetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK6Avatar7IsHumanEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $16 = 0;
  STACKTOP = sp;return ($16|0);
 }
 $3 = (($1) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $16 = 0;
  STACKTOP = sp;return ($16|0);
 }
 $6 = $3;
 $7 = (($4) + ($6))|0;
 $8 = $7;
 $9 = (($8) + 48|0);
 $10 = $9;
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11) + ($10))|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)!=(0);
 $16 = $15;
 STACKTOP = sp;return ($16|0);
}
function __ZN10HumanTrait15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10HumanTrait20InitializeMuscleNameEv();
 __ZN10HumanTrait18InitializeBoneNameEv();
 STACKTOP = sp;return;
}
function __ZN10HumanTrait20InitializeMuscleNameEv() {
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$101 = 0, $$102 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$byval_copy41 = 0, $$pre = 0, $$pre$i = 0, $$pre$i24 = 0, $$pre$i46 = 0, $$pre100 = 0, $$pre96 = 0, $$pre97 = 0, $$pre98 = 0;
 var $$pre99 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i23 = 0, $__p$0$i$i$i$i$i$i45 = 0, $__p$0$i$i$i$i16 = 0, $__p$0$i$i$i$i38 = 0;
 var $__p$0$i$i$i$i5 = 0, $i$095 = 0, $lpad$phi$index = 0, $lpad$phi$index22 = 0, $lpad$phi60$index = 0, $lpad$phi60$index27 = 0, $lpad$phi65$index = 0, $lpad$phi65$index12 = 0, $lpad$phi70$index = 0, $lpad$phi70$index17 = 0, $lpad$phi75$index = 0, $lpad$phi75$index2 = 0, $lpad$phi80$index = 0, $lpad$phi80$index7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy41 = sp + 120|0;
 $0 = sp + 116|0;
 $1 = sp + 112|0;
 $2 = sp + 108|0;
 $3 = sp + 104|0;
 $4 = sp + 100|0;
 $5 = sp + 96|0;
 $6 = sp + 92|0;
 $7 = sp + 88|0;
 $8 = sp + 84|0;
 $9 = sp + 20|0;
 $10 = sp;
 $11 = sp + 4|0;
 $12 = sp + 8|0;
 $13 = sp + 24|0;
 $14 = sp + 36|0;
 $15 = sp + 48|0;
 $16 = sp + 60|0;
 $17 = sp + 72|0;
 $18 = (__Znwj(12)|0);
 HEAP32[$18>>2] = 0;
 $19 = (($18) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($18) + 8|0);
 HEAP32[$20>>2] = 0;
 HEAP32[769080>>2] = $18;
 __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE7reserveEj($18,92);
 $21 = (($13) + 1|0);
 $22 = (($12) + 1|0);
 $23 = (($13) + 8|0);
 $24 = (($12) + 8|0);
 $25 = (($12) + 4|0);
 $26 = (($13) + 4|0);
 $27 = (($15) + 1|0);
 $28 = (($14) + 1|0);
 $29 = (($15) + 8|0);
 $30 = (($14) + 8|0);
 $31 = (($14) + 4|0);
 $32 = (($17) + 1|0);
 $33 = (($16) + 1|0);
 $34 = (($17) + 8|0);
 $35 = (($16) + 8|0);
 $36 = (($16) + 4|0);
 $i$095 = 0;
 L1: while(1) {
  $37 = ($i$095|0)<(52);
  do {
   if ($37) {
    $38 = HEAP32[769080>>2]|0;
    $39 = (__ZN7mecanim5human10MuscleNameEj($i$095)|0);
    $40 = (_strlen(($39|0))|0);
    $41 = ($40>>>0)>(4294967279);
    if ($41) {
     label = 4;
     break L1;
    }
    $42 = ($40>>>0)<(11);
    if ($42) {
     $43 = $40 << 1;
     $44 = $43&255;
     HEAP8[$13>>0] = $44;
     $52 = $44;$__p$0$i$i$i$i = $21;
    } else {
     $45 = (($40) + 16)|0;
     $46 = $45 & -16;
     $47 = (__Znwj($46)|0);
     HEAP32[$23>>2] = $47;
     $48 = $46 | 1;
     HEAP32[$13>>2] = $48;
     HEAP32[$26>>2] = $40;
     $49 = $48&255;
     $52 = $49;$__p$0$i$i$i$i = $47;
    }
    _memcpy(($__p$0$i$i$i$i|0),($39|0),($40|0))|0;
    $50 = (($__p$0$i$i$i$i) + ($40)|0);
    HEAP8[$50>>0] = 0;
    $51 = $52 & 1;
    $53 = ($51<<24>>24)==(0);
    $54 = HEAP32[$23>>2]|0;
    $$ = $53 ? $21 : $54;
    $55 = (_strlen(($$|0))|0);
    $56 = ($55>>>0)>(2147483631);
    if ($56) {
     label = 9;
     break L1;
    }
    $59 = ($55>>>0)<(11);
    if ($59) {
     $60 = $55 << 1;
     $61 = $60&255;
     HEAP8[$12>>0] = $61;
     $77 = $61;$__p$0$i$i$i$i5 = $22;
    } else {
     $62 = (($55) + 16)|0;
     $63 = $62 & -16;
     HEAP32[$11>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$11+0>>2]|0;
     $64 = (invoke_iiiiiii(102,($63|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      label = 36;
      break L1;
     }
     HEAP32[$24>>2] = $64;
     $67 = $63 | 1;
     HEAP32[$12>>2] = $67;
     HEAP32[$25>>2] = $55;
     $68 = $67&255;
     $77 = $68;$__p$0$i$i$i$i5 = $64;
    }
    _memcpy(($__p$0$i$i$i$i5|0),($$|0),($55|0))|0;
    $69 = (($__p$0$i$i$i$i5) + ($55)|0);
    HEAP8[$69>>0] = 0;
    $70 = (($38) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($38) + 8|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($71|0)==($73|0);
    if ($74) {
     __THREW__ = 0;
     invoke_vii(2602,($38|0),($12|0));
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 39;
      break L1;
     }
     $$pre98 = HEAP8[$12>>0]|0;
     $106 = $$pre98;
    } else {
     $75 = ($71|0)==(0|0);
     if ($75) {
      $102 = 0;
     } else {
      $76 = $77 & 1;
      $78 = ($76<<24>>24)==(0);
      if ($78) {
       $81 = $77&255;
       $82 = $81 >>> 1;
       $84 = $82;$99 = $22;
      } else {
       $79 = HEAP32[$24>>2]|0;
       $80 = HEAP32[$25>>2]|0;
       $84 = $80;$99 = $79;
      }
      $83 = ($84>>>0)>(2147483631);
      if ($83) {
       label = 21;
       break L1;
      }
      $87 = ($84>>>0)<(11);
      if ($87) {
       $88 = $84 << 1;
       $89 = $88&255;
       HEAP8[$71>>0] = $89;
       $90 = (($71) + 1|0);
       $__p$0$i$i$i$i$i$i = $90;
      } else {
       $91 = (($84) + 16)|0;
       $92 = $91 & -16;
       HEAP32[$10>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$10+0>>2]|0;
       $93 = (invoke_iiiiiii(102,($92|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
       $94 = __THREW__; __THREW__ = 0;
       $95 = $94&1;
       if ($95) {
        label = 39;
        break L1;
       }
       $96 = (($71) + 8|0);
       HEAP32[$96>>2] = $93;
       $97 = $92 | 1;
       HEAP32[$71>>2] = $97;
       $98 = (($71) + 4|0);
       HEAP32[$98>>2] = $84;
       $__p$0$i$i$i$i$i$i = $93;
      }
      _memcpy(($__p$0$i$i$i$i$i$i|0),($99|0),($84|0))|0;
      $100 = (($__p$0$i$i$i$i$i$i) + ($84)|0);
      HEAP8[$100>>0] = 0;
      $$pre$i = HEAP32[$70>>2]|0;
      $102 = $$pre$i;
     }
     $101 = (($102) + 12|0);
     HEAP32[$70>>2] = $101;
     $106 = $77;
    }
    $105 = $106 & 1;
    $107 = ($105<<24>>24)==(0);
    if (!($107)) {
     $108 = HEAP32[$24>>2]|0;
     HEAP32[$9>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$9+0>>2]|0;
     invoke_vii(2591,($108|0),($$byval_copy41|0));
     $109 = __THREW__; __THREW__ = 0;
     $110 = $109&1;
     if ($110) {
      label = 33;
      break L1;
     }
    }
    $113 = $52 & 1;
    $114 = ($113<<24>>24)==(0);
    if (!($114)) {
     $115 = HEAP32[$23>>2]|0;
     __ZdlPv($115);
    }
   } else {
    $135 = ($i$095|0)<(72);
    $136 = HEAP32[769080>>2]|0;
    if ($135) {
     $137 = (($i$095) + -52)|0;
     __ZN10HumanTrait19GetFingerMuscleNameEib($15,$137,1);
     $138 = HEAP8[$15>>0]|0;
     $139 = $138 & 1;
     $140 = ($139<<24>>24)==(0);
     $141 = HEAP32[$29>>2]|0;
     $$101 = $140 ? $27 : $141;
     $142 = (_strlen(($$101|0))|0);
     $143 = ($142>>>0)>(2147483631);
     if ($143) {
      label = 48;
      break L1;
     }
     $146 = ($142>>>0)<(11);
     if ($146) {
      $147 = $142 << 1;
      $148 = $147&255;
      HEAP8[$14>>0] = $148;
      $164 = $148;$__p$0$i$i$i$i16 = $28;
     } else {
      $149 = (($142) + 16)|0;
      $150 = $149 & -16;
      HEAP32[$7>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$7+0>>2]|0;
      $151 = (invoke_iiiiiii(102,($150|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       label = 75;
       break L1;
      }
      HEAP32[$30>>2] = $151;
      $154 = $150 | 1;
      HEAP32[$14>>2] = $154;
      HEAP32[$31>>2] = $142;
      $155 = $154&255;
      $164 = $155;$__p$0$i$i$i$i16 = $151;
     }
     _memcpy(($__p$0$i$i$i$i16|0),($$101|0),($142|0))|0;
     $156 = (($__p$0$i$i$i$i16) + ($142)|0);
     HEAP8[$156>>0] = 0;
     $157 = (($136) + 4|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (($136) + 8|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = ($158|0)==($160|0);
     if ($161) {
      __THREW__ = 0;
      invoke_vii(2602,($136|0),($14|0));
      $190 = __THREW__; __THREW__ = 0;
      $191 = $190&1;
      if ($191) {
       label = 78;
       break L1;
      }
      $$pre99 = HEAP8[$14>>0]|0;
      $193 = $$pre99;
     } else {
      $162 = ($158|0)==(0|0);
      if ($162) {
       $189 = 0;
      } else {
       $163 = $164 & 1;
       $165 = ($163<<24>>24)==(0);
       if ($165) {
        $168 = $164&255;
        $169 = $168 >>> 1;
        $171 = $169;$186 = $28;
       } else {
        $166 = HEAP32[$30>>2]|0;
        $167 = HEAP32[$31>>2]|0;
        $171 = $167;$186 = $166;
       }
       $170 = ($171>>>0)>(2147483631);
       if ($170) {
        label = 60;
        break L1;
       }
       $174 = ($171>>>0)<(11);
       if ($174) {
        $175 = $171 << 1;
        $176 = $175&255;
        HEAP8[$158>>0] = $176;
        $177 = (($158) + 1|0);
        $__p$0$i$i$i$i$i$i23 = $177;
       } else {
        $178 = (($171) + 16)|0;
        $179 = $178 & -16;
        HEAP32[$6>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$6+0>>2]|0;
        $180 = (invoke_iiiiiii(102,($179|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
        $181 = __THREW__; __THREW__ = 0;
        $182 = $181&1;
        if ($182) {
         label = 78;
         break L1;
        }
        $183 = (($158) + 8|0);
        HEAP32[$183>>2] = $180;
        $184 = $179 | 1;
        HEAP32[$158>>2] = $184;
        $185 = (($158) + 4|0);
        HEAP32[$185>>2] = $171;
        $__p$0$i$i$i$i$i$i23 = $180;
       }
       _memcpy(($__p$0$i$i$i$i$i$i23|0),($186|0),($171|0))|0;
       $187 = (($__p$0$i$i$i$i$i$i23) + ($171)|0);
       HEAP8[$187>>0] = 0;
       $$pre$i24 = HEAP32[$157>>2]|0;
       $189 = $$pre$i24;
      }
      $188 = (($189) + 12|0);
      HEAP32[$157>>2] = $188;
      $193 = $164;
     }
     $192 = $193 & 1;
     $194 = ($192<<24>>24)==(0);
     if (!($194)) {
      $195 = HEAP32[$30>>2]|0;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_vii(2591,($195|0),($$byval_copy41|0));
      $196 = __THREW__; __THREW__ = 0;
      $197 = $196&1;
      if ($197) {
       label = 72;
       break L1;
      }
     }
     $200 = HEAP8[$15>>0]|0;
     $201 = $200 & 1;
     $202 = ($201<<24>>24)==(0);
     if ($202) {
      break;
     }
     $203 = HEAP32[$29>>2]|0;
     __ZdlPv($203);
     break;
    } else {
     $224 = (($i$095) + -72)|0;
     __ZN10HumanTrait19GetFingerMuscleNameEib($17,$224,0);
     $225 = HEAP8[$17>>0]|0;
     $226 = $225 & 1;
     $227 = ($226<<24>>24)==(0);
     $228 = HEAP32[$34>>2]|0;
     $$102 = $227 ? $32 : $228;
     $229 = (_strlen(($$102|0))|0);
     $230 = ($229>>>0)>(2147483631);
     if ($230) {
      label = 86;
      break L1;
     }
     $233 = ($229>>>0)<(11);
     if ($233) {
      $234 = $229 << 1;
      $235 = $234&255;
      HEAP8[$16>>0] = $235;
      $251 = $235;$__p$0$i$i$i$i38 = $33;
     } else {
      $236 = (($229) + 16)|0;
      $237 = $236 & -16;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$3+0>>2]|0;
      $238 = (invoke_iiiiiii(102,($237|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
      $239 = __THREW__; __THREW__ = 0;
      $240 = $239&1;
      if ($240) {
       label = 113;
       break L1;
      }
      HEAP32[$35>>2] = $238;
      $241 = $237 | 1;
      HEAP32[$16>>2] = $241;
      HEAP32[$36>>2] = $229;
      $242 = $241&255;
      $251 = $242;$__p$0$i$i$i$i38 = $238;
     }
     _memcpy(($__p$0$i$i$i$i38|0),($$102|0),($229|0))|0;
     $243 = (($__p$0$i$i$i$i38) + ($229)|0);
     HEAP8[$243>>0] = 0;
     $244 = (($136) + 4|0);
     $245 = HEAP32[$244>>2]|0;
     $246 = (($136) + 8|0);
     $247 = HEAP32[$246>>2]|0;
     $248 = ($245|0)==($247|0);
     if ($248) {
      __THREW__ = 0;
      invoke_vii(2602,($136|0),($16|0));
      $277 = __THREW__; __THREW__ = 0;
      $278 = $277&1;
      if ($278) {
       label = 116;
       break L1;
      }
      $$pre100 = HEAP8[$16>>0]|0;
      $280 = $$pre100;
     } else {
      $249 = ($245|0)==(0|0);
      if ($249) {
       $276 = 0;
      } else {
       $250 = $251 & 1;
       $252 = ($250<<24>>24)==(0);
       if ($252) {
        $255 = $251&255;
        $256 = $255 >>> 1;
        $258 = $256;$273 = $33;
       } else {
        $253 = HEAP32[$35>>2]|0;
        $254 = HEAP32[$36>>2]|0;
        $258 = $254;$273 = $253;
       }
       $257 = ($258>>>0)>(2147483631);
       if ($257) {
        label = 98;
        break L1;
       }
       $261 = ($258>>>0)<(11);
       if ($261) {
        $262 = $258 << 1;
        $263 = $262&255;
        HEAP8[$245>>0] = $263;
        $264 = (($245) + 1|0);
        $__p$0$i$i$i$i$i$i45 = $264;
       } else {
        $265 = (($258) + 16)|0;
        $266 = $265 & -16;
        HEAP32[$2>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$2+0>>2]|0;
        $267 = (invoke_iiiiiii(102,($266|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         label = 116;
         break L1;
        }
        $270 = (($245) + 8|0);
        HEAP32[$270>>2] = $267;
        $271 = $266 | 1;
        HEAP32[$245>>2] = $271;
        $272 = (($245) + 4|0);
        HEAP32[$272>>2] = $258;
        $__p$0$i$i$i$i$i$i45 = $267;
       }
       _memcpy(($__p$0$i$i$i$i$i$i45|0),($273|0),($258|0))|0;
       $274 = (($__p$0$i$i$i$i$i$i45) + ($258)|0);
       HEAP8[$274>>0] = 0;
       $$pre$i46 = HEAP32[$244>>2]|0;
       $276 = $$pre$i46;
      }
      $275 = (($276) + 12|0);
      HEAP32[$244>>2] = $275;
      $280 = $251;
     }
     $279 = $280 & 1;
     $281 = ($279<<24>>24)==(0);
     if (!($281)) {
      $282 = HEAP32[$35>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($282|0),($$byval_copy41|0));
      $283 = __THREW__; __THREW__ = 0;
      $284 = $283&1;
      if ($284) {
       label = 110;
       break L1;
      }
     }
     $287 = HEAP8[$17>>0]|0;
     $288 = $287 & 1;
     $289 = ($288<<24>>24)==(0);
     if ($289) {
      break;
     }
     $290 = HEAP32[$34>>2]|0;
     __ZdlPv($290);
     break;
    }
   }
  } while(0);
  $311 = (($i$095) + 1)|0;
  $312 = ($311|0)<(92);
  if ($312) {
   $i$095 = $311;
  } else {
   label = 124;
   break;
  }
 }
 switch (label|0) {
  case 4: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 9: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $118 = ___cxa_find_matching_catch()|0;
    $119 = tempRet0;
    $lpad$phi75$index = $118;$lpad$phi75$index2 = $119;
    label = 38;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 21: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    $125 = $77;$lpad$phi80$index = $122;$lpad$phi80$index7 = $123;
    label = 41;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 33: {
   $111 = ___cxa_find_matching_catch()|0;
   $112 = tempRet0;
   ___cxa_call_unexpected(($111|0));
   // unreachable;
   break;
  }
  case 36: {
   $116 = ___cxa_find_matching_catch()|0;
   $117 = tempRet0;
   $lpad$phi75$index = $116;$lpad$phi75$index2 = $117;
   label = 38;
   break;
  }
  case 39: {
   $120 = ___cxa_find_matching_catch()|0;
   $121 = tempRet0;
   $$pre = HEAP8[$12>>0]|0;
   $125 = $$pre;$lpad$phi80$index = $120;$lpad$phi80$index7 = $121;
   label = 41;
   break;
  }
  case 48: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $144 = __THREW__; __THREW__ = 0;
   $145 = $144&1;
   if ($145) {
    $206 = ___cxa_find_matching_catch()|0;
    $207 = tempRet0;
    $lpad$phi65$index = $206;$lpad$phi65$index12 = $207;
    label = 77;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 60: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $172 = __THREW__; __THREW__ = 0;
   $173 = $172&1;
   if ($173) {
    $210 = ___cxa_find_matching_catch()|0;
    $211 = tempRet0;
    $213 = $164;$lpad$phi70$index = $210;$lpad$phi70$index17 = $211;
    label = 80;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 72: {
   $198 = ___cxa_find_matching_catch()|0;
   $199 = tempRet0;
   ___cxa_call_unexpected(($198|0));
   // unreachable;
   break;
  }
  case 75: {
   $204 = ___cxa_find_matching_catch()|0;
   $205 = tempRet0;
   $lpad$phi65$index = $204;$lpad$phi65$index12 = $205;
   label = 77;
   break;
  }
  case 78: {
   $208 = ___cxa_find_matching_catch()|0;
   $209 = tempRet0;
   $$pre96 = HEAP8[$14>>0]|0;
   $213 = $$pre96;$lpad$phi70$index = $208;$lpad$phi70$index17 = $209;
   label = 80;
   break;
  }
  case 86: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $231 = __THREW__; __THREW__ = 0;
   $232 = $231&1;
   if ($232) {
    $293 = ___cxa_find_matching_catch()|0;
    $294 = tempRet0;
    $lpad$phi$index = $293;$lpad$phi$index22 = $294;
    label = 115;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 98: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $259 = __THREW__; __THREW__ = 0;
   $260 = $259&1;
   if ($260) {
    $297 = ___cxa_find_matching_catch()|0;
    $298 = tempRet0;
    $300 = $251;$lpad$phi60$index = $297;$lpad$phi60$index27 = $298;
    label = 118;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 110: {
   $285 = ___cxa_find_matching_catch()|0;
   $286 = tempRet0;
   ___cxa_call_unexpected(($285|0));
   // unreachable;
   break;
  }
  case 113: {
   $291 = ___cxa_find_matching_catch()|0;
   $292 = tempRet0;
   $lpad$phi$index = $291;$lpad$phi$index22 = $292;
   label = 115;
   break;
  }
  case 116: {
   $295 = ___cxa_find_matching_catch()|0;
   $296 = tempRet0;
   $$pre97 = HEAP8[$16>>0]|0;
   $300 = $$pre97;$lpad$phi60$index = $295;$lpad$phi60$index27 = $296;
   label = 118;
   break;
  }
  case 124: {
   STACKTOP = sp;return;
   break;
  }
 }
 if ((label|0) == 38) {
  $$0 = $lpad$phi75$index2;$$01 = $lpad$phi75$index;
  label = 44;
 }
 else if ((label|0) == 41) {
  $124 = $125 & 1;
  $126 = ($124<<24>>24)==(0);
  if ($126) {
   $$0 = $lpad$phi80$index7;$$01 = $lpad$phi80$index;
   label = 44;
  } else {
   $127 = HEAP32[$24>>2]|0;
   HEAP32[$8>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$8+0>>2]|0;
   invoke_vii(2591,($127|0),($$byval_copy41|0));
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    $130 = ___cxa_find_matching_catch()|0;
    $131 = tempRet0;
    ___cxa_call_unexpected(($130|0));
    // unreachable;
   } else {
    $$0 = $lpad$phi80$index7;$$01 = $lpad$phi80$index;
    label = 44;
   }
  }
 }
 else if ((label|0) == 77) {
  $$1 = $lpad$phi65$index12;$$12 = $lpad$phi65$index;
  label = 83;
 }
 else if ((label|0) == 80) {
  $212 = $213 & 1;
  $214 = ($212<<24>>24)==(0);
  if ($214) {
   $$1 = $lpad$phi70$index17;$$12 = $lpad$phi70$index;
   label = 83;
  } else {
   $215 = HEAP32[$30>>2]|0;
   HEAP32[$4>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($215|0),($$byval_copy41|0));
   $216 = __THREW__; __THREW__ = 0;
   $217 = $216&1;
   if ($217) {
    $218 = ___cxa_find_matching_catch()|0;
    $219 = tempRet0;
    ___cxa_call_unexpected(($218|0));
    // unreachable;
   } else {
    $$1 = $lpad$phi70$index17;$$12 = $lpad$phi70$index;
    label = 83;
   }
  }
 }
 else if ((label|0) == 115) {
  $$2 = $lpad$phi$index22;$$23 = $lpad$phi$index;
  label = 121;
 }
 else if ((label|0) == 118) {
  $299 = $300 & 1;
  $301 = ($299<<24>>24)==(0);
  if ($301) {
   $$2 = $lpad$phi60$index27;$$23 = $lpad$phi60$index;
   label = 121;
  } else {
   $302 = HEAP32[$35>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($302|0),($$byval_copy41|0));
   $303 = __THREW__; __THREW__ = 0;
   $304 = $303&1;
   if ($304) {
    $305 = ___cxa_find_matching_catch()|0;
    $306 = tempRet0;
    ___cxa_call_unexpected(($305|0));
    // unreachable;
   } else {
    $$2 = $lpad$phi60$index27;$$23 = $lpad$phi60$index;
    label = 121;
   }
  }
 }
 if ((label|0) == 44) {
  $132 = $52 & 1;
  $133 = ($132<<24>>24)==(0);
  if ($133) {
   $$3 = $$0;$$34 = $$01;
   ___resumeException($$34|0);
   // unreachable;
  }
  $134 = HEAP32[$23>>2]|0;
  __ZdlPv($134);
  $$3 = $$0;$$34 = $$01;
  ___resumeException($$34|0);
  // unreachable;
 }
 else if ((label|0) == 83) {
  $220 = HEAP8[$15>>0]|0;
  $221 = $220 & 1;
  $222 = ($221<<24>>24)==(0);
  if ($222) {
   $$3 = $$1;$$34 = $$12;
   ___resumeException($$34|0);
   // unreachable;
  }
  $223 = HEAP32[$29>>2]|0;
  __ZdlPv($223);
  $$3 = $$1;$$34 = $$12;
  ___resumeException($$34|0);
  // unreachable;
 }
 else if ((label|0) == 121) {
  $307 = HEAP8[$17>>0]|0;
  $308 = $307 & 1;
  $309 = ($308<<24>>24)==(0);
  if ($309) {
   $$3 = $$2;$$34 = $$23;
   ___resumeException($$34|0);
   // unreachable;
  }
  $310 = HEAP32[$34>>2]|0;
  __ZdlPv($310);
  $$3 = $$2;$$34 = $$23;
  ___resumeException($$34|0);
  // unreachable;
 }
}
function __ZN10HumanTrait18InitializeBoneNameEv() {
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$101 = 0, $$102 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$byval_copy41 = 0, $$pre = 0, $$pre$i = 0, $$pre$i24 = 0, $$pre$i46 = 0, $$pre100 = 0, $$pre96 = 0, $$pre97 = 0, $$pre98 = 0;
 var $$pre99 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i23 = 0, $__p$0$i$i$i$i$i$i45 = 0, $__p$0$i$i$i$i16 = 0, $__p$0$i$i$i$i38 = 0;
 var $__p$0$i$i$i$i5 = 0, $i$095 = 0, $lpad$phi$index = 0, $lpad$phi$index22 = 0, $lpad$phi60$index = 0, $lpad$phi60$index27 = 0, $lpad$phi65$index = 0, $lpad$phi65$index12 = 0, $lpad$phi70$index = 0, $lpad$phi70$index17 = 0, $lpad$phi75$index = 0, $lpad$phi75$index2 = 0, $lpad$phi80$index = 0, $lpad$phi80$index7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy41 = sp + 120|0;
 $0 = sp + 116|0;
 $1 = sp + 112|0;
 $2 = sp + 108|0;
 $3 = sp + 104|0;
 $4 = sp + 100|0;
 $5 = sp + 96|0;
 $6 = sp + 92|0;
 $7 = sp + 88|0;
 $8 = sp + 84|0;
 $9 = sp + 20|0;
 $10 = sp;
 $11 = sp + 4|0;
 $12 = sp + 8|0;
 $13 = sp + 24|0;
 $14 = sp + 36|0;
 $15 = sp + 48|0;
 $16 = sp + 60|0;
 $17 = sp + 72|0;
 $18 = (__Znwj(12)|0);
 HEAP32[$18>>2] = 0;
 $19 = (($18) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($18) + 8|0);
 HEAP32[$20>>2] = 0;
 HEAP32[769088>>2] = $18;
 __ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE7reserveEj($18,54);
 $21 = (($13) + 1|0);
 $22 = (($12) + 1|0);
 $23 = (($13) + 8|0);
 $24 = (($12) + 8|0);
 $25 = (($12) + 4|0);
 $26 = (($13) + 4|0);
 $27 = (($15) + 1|0);
 $28 = (($14) + 1|0);
 $29 = (($15) + 8|0);
 $30 = (($14) + 8|0);
 $31 = (($14) + 4|0);
 $32 = (($17) + 1|0);
 $33 = (($16) + 1|0);
 $34 = (($17) + 8|0);
 $35 = (($16) + 8|0);
 $36 = (($16) + 4|0);
 $i$095 = 0;
 L1: while(1) {
  $37 = ($i$095|0)<(24);
  do {
   if ($37) {
    $38 = HEAP32[769088>>2]|0;
    $39 = (__ZN7mecanim5human8BoneNameEj($i$095)|0);
    $40 = (_strlen(($39|0))|0);
    $41 = ($40>>>0)>(4294967279);
    if ($41) {
     label = 4;
     break L1;
    }
    $42 = ($40>>>0)<(11);
    if ($42) {
     $43 = $40 << 1;
     $44 = $43&255;
     HEAP8[$13>>0] = $44;
     $52 = $44;$__p$0$i$i$i$i = $21;
    } else {
     $45 = (($40) + 16)|0;
     $46 = $45 & -16;
     $47 = (__Znwj($46)|0);
     HEAP32[$23>>2] = $47;
     $48 = $46 | 1;
     HEAP32[$13>>2] = $48;
     HEAP32[$26>>2] = $40;
     $49 = $48&255;
     $52 = $49;$__p$0$i$i$i$i = $47;
    }
    _memcpy(($__p$0$i$i$i$i|0),($39|0),($40|0))|0;
    $50 = (($__p$0$i$i$i$i) + ($40)|0);
    HEAP8[$50>>0] = 0;
    $51 = $52 & 1;
    $53 = ($51<<24>>24)==(0);
    $54 = HEAP32[$23>>2]|0;
    $$ = $53 ? $21 : $54;
    $55 = (_strlen(($$|0))|0);
    $56 = ($55>>>0)>(2147483631);
    if ($56) {
     label = 9;
     break L1;
    }
    $59 = ($55>>>0)<(11);
    if ($59) {
     $60 = $55 << 1;
     $61 = $60&255;
     HEAP8[$12>>0] = $61;
     $77 = $61;$__p$0$i$i$i$i5 = $22;
    } else {
     $62 = (($55) + 16)|0;
     $63 = $62 & -16;
     HEAP32[$11>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$11+0>>2]|0;
     $64 = (invoke_iiiiiii(102,($63|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      label = 36;
      break L1;
     }
     HEAP32[$24>>2] = $64;
     $67 = $63 | 1;
     HEAP32[$12>>2] = $67;
     HEAP32[$25>>2] = $55;
     $68 = $67&255;
     $77 = $68;$__p$0$i$i$i$i5 = $64;
    }
    _memcpy(($__p$0$i$i$i$i5|0),($$|0),($55|0))|0;
    $69 = (($__p$0$i$i$i$i5) + ($55)|0);
    HEAP8[$69>>0] = 0;
    $70 = (($38) + 4|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($38) + 8|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($71|0)==($73|0);
    if ($74) {
     __THREW__ = 0;
     invoke_vii(2602,($38|0),($12|0));
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 39;
      break L1;
     }
     $$pre98 = HEAP8[$12>>0]|0;
     $106 = $$pre98;
    } else {
     $75 = ($71|0)==(0|0);
     if ($75) {
      $102 = 0;
     } else {
      $76 = $77 & 1;
      $78 = ($76<<24>>24)==(0);
      if ($78) {
       $81 = $77&255;
       $82 = $81 >>> 1;
       $84 = $82;$99 = $22;
      } else {
       $79 = HEAP32[$24>>2]|0;
       $80 = HEAP32[$25>>2]|0;
       $84 = $80;$99 = $79;
      }
      $83 = ($84>>>0)>(2147483631);
      if ($83) {
       label = 21;
       break L1;
      }
      $87 = ($84>>>0)<(11);
      if ($87) {
       $88 = $84 << 1;
       $89 = $88&255;
       HEAP8[$71>>0] = $89;
       $90 = (($71) + 1|0);
       $__p$0$i$i$i$i$i$i = $90;
      } else {
       $91 = (($84) + 16)|0;
       $92 = $91 & -16;
       HEAP32[$10>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$10+0>>2]|0;
       $93 = (invoke_iiiiiii(102,($92|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
       $94 = __THREW__; __THREW__ = 0;
       $95 = $94&1;
       if ($95) {
        label = 39;
        break L1;
       }
       $96 = (($71) + 8|0);
       HEAP32[$96>>2] = $93;
       $97 = $92 | 1;
       HEAP32[$71>>2] = $97;
       $98 = (($71) + 4|0);
       HEAP32[$98>>2] = $84;
       $__p$0$i$i$i$i$i$i = $93;
      }
      _memcpy(($__p$0$i$i$i$i$i$i|0),($99|0),($84|0))|0;
      $100 = (($__p$0$i$i$i$i$i$i) + ($84)|0);
      HEAP8[$100>>0] = 0;
      $$pre$i = HEAP32[$70>>2]|0;
      $102 = $$pre$i;
     }
     $101 = (($102) + 12|0);
     HEAP32[$70>>2] = $101;
     $106 = $77;
    }
    $105 = $106 & 1;
    $107 = ($105<<24>>24)==(0);
    if (!($107)) {
     $108 = HEAP32[$24>>2]|0;
     HEAP32[$9>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$9+0>>2]|0;
     invoke_vii(2591,($108|0),($$byval_copy41|0));
     $109 = __THREW__; __THREW__ = 0;
     $110 = $109&1;
     if ($110) {
      label = 33;
      break L1;
     }
    }
    $113 = $52 & 1;
    $114 = ($113<<24>>24)==(0);
    if (!($114)) {
     $115 = HEAP32[$23>>2]|0;
     __ZdlPv($115);
    }
   } else {
    $135 = ($i$095|0)<(39);
    $136 = HEAP32[769088>>2]|0;
    if ($135) {
     $137 = (($i$095) + -24)|0;
     __ZN10HumanTrait13GetFingerNameEib($15,$137,1);
     $138 = HEAP8[$15>>0]|0;
     $139 = $138 & 1;
     $140 = ($139<<24>>24)==(0);
     $141 = HEAP32[$29>>2]|0;
     $$101 = $140 ? $27 : $141;
     $142 = (_strlen(($$101|0))|0);
     $143 = ($142>>>0)>(2147483631);
     if ($143) {
      label = 48;
      break L1;
     }
     $146 = ($142>>>0)<(11);
     if ($146) {
      $147 = $142 << 1;
      $148 = $147&255;
      HEAP8[$14>>0] = $148;
      $164 = $148;$__p$0$i$i$i$i16 = $28;
     } else {
      $149 = (($142) + 16)|0;
      $150 = $149 & -16;
      HEAP32[$7>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$7+0>>2]|0;
      $151 = (invoke_iiiiiii(102,($150|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       label = 75;
       break L1;
      }
      HEAP32[$30>>2] = $151;
      $154 = $150 | 1;
      HEAP32[$14>>2] = $154;
      HEAP32[$31>>2] = $142;
      $155 = $154&255;
      $164 = $155;$__p$0$i$i$i$i16 = $151;
     }
     _memcpy(($__p$0$i$i$i$i16|0),($$101|0),($142|0))|0;
     $156 = (($__p$0$i$i$i$i16) + ($142)|0);
     HEAP8[$156>>0] = 0;
     $157 = (($136) + 4|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (($136) + 8|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = ($158|0)==($160|0);
     if ($161) {
      __THREW__ = 0;
      invoke_vii(2602,($136|0),($14|0));
      $190 = __THREW__; __THREW__ = 0;
      $191 = $190&1;
      if ($191) {
       label = 78;
       break L1;
      }
      $$pre99 = HEAP8[$14>>0]|0;
      $193 = $$pre99;
     } else {
      $162 = ($158|0)==(0|0);
      if ($162) {
       $189 = 0;
      } else {
       $163 = $164 & 1;
       $165 = ($163<<24>>24)==(0);
       if ($165) {
        $168 = $164&255;
        $169 = $168 >>> 1;
        $171 = $169;$186 = $28;
       } else {
        $166 = HEAP32[$30>>2]|0;
        $167 = HEAP32[$31>>2]|0;
        $171 = $167;$186 = $166;
       }
       $170 = ($171>>>0)>(2147483631);
       if ($170) {
        label = 60;
        break L1;
       }
       $174 = ($171>>>0)<(11);
       if ($174) {
        $175 = $171 << 1;
        $176 = $175&255;
        HEAP8[$158>>0] = $176;
        $177 = (($158) + 1|0);
        $__p$0$i$i$i$i$i$i23 = $177;
       } else {
        $178 = (($171) + 16)|0;
        $179 = $178 & -16;
        HEAP32[$6>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$6+0>>2]|0;
        $180 = (invoke_iiiiiii(102,($179|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
        $181 = __THREW__; __THREW__ = 0;
        $182 = $181&1;
        if ($182) {
         label = 78;
         break L1;
        }
        $183 = (($158) + 8|0);
        HEAP32[$183>>2] = $180;
        $184 = $179 | 1;
        HEAP32[$158>>2] = $184;
        $185 = (($158) + 4|0);
        HEAP32[$185>>2] = $171;
        $__p$0$i$i$i$i$i$i23 = $180;
       }
       _memcpy(($__p$0$i$i$i$i$i$i23|0),($186|0),($171|0))|0;
       $187 = (($__p$0$i$i$i$i$i$i23) + ($171)|0);
       HEAP8[$187>>0] = 0;
       $$pre$i24 = HEAP32[$157>>2]|0;
       $189 = $$pre$i24;
      }
      $188 = (($189) + 12|0);
      HEAP32[$157>>2] = $188;
      $193 = $164;
     }
     $192 = $193 & 1;
     $194 = ($192<<24>>24)==(0);
     if (!($194)) {
      $195 = HEAP32[$30>>2]|0;
      HEAP32[$5>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_vii(2591,($195|0),($$byval_copy41|0));
      $196 = __THREW__; __THREW__ = 0;
      $197 = $196&1;
      if ($197) {
       label = 72;
       break L1;
      }
     }
     $200 = HEAP8[$15>>0]|0;
     $201 = $200 & 1;
     $202 = ($201<<24>>24)==(0);
     if ($202) {
      break;
     }
     $203 = HEAP32[$29>>2]|0;
     __ZdlPv($203);
     break;
    } else {
     $224 = (($i$095) + -39)|0;
     __ZN10HumanTrait13GetFingerNameEib($17,$224,0);
     $225 = HEAP8[$17>>0]|0;
     $226 = $225 & 1;
     $227 = ($226<<24>>24)==(0);
     $228 = HEAP32[$34>>2]|0;
     $$102 = $227 ? $32 : $228;
     $229 = (_strlen(($$102|0))|0);
     $230 = ($229>>>0)>(2147483631);
     if ($230) {
      label = 86;
      break L1;
     }
     $233 = ($229>>>0)<(11);
     if ($233) {
      $234 = $229 << 1;
      $235 = $234&255;
      HEAP8[$16>>0] = $235;
      $251 = $235;$__p$0$i$i$i$i38 = $33;
     } else {
      $236 = (($229) + 16)|0;
      $237 = $236 & -16;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$3+0>>2]|0;
      $238 = (invoke_iiiiiii(102,($237|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
      $239 = __THREW__; __THREW__ = 0;
      $240 = $239&1;
      if ($240) {
       label = 113;
       break L1;
      }
      HEAP32[$35>>2] = $238;
      $241 = $237 | 1;
      HEAP32[$16>>2] = $241;
      HEAP32[$36>>2] = $229;
      $242 = $241&255;
      $251 = $242;$__p$0$i$i$i$i38 = $238;
     }
     _memcpy(($__p$0$i$i$i$i38|0),($$102|0),($229|0))|0;
     $243 = (($__p$0$i$i$i$i38) + ($229)|0);
     HEAP8[$243>>0] = 0;
     $244 = (($136) + 4|0);
     $245 = HEAP32[$244>>2]|0;
     $246 = (($136) + 8|0);
     $247 = HEAP32[$246>>2]|0;
     $248 = ($245|0)==($247|0);
     if ($248) {
      __THREW__ = 0;
      invoke_vii(2602,($136|0),($16|0));
      $277 = __THREW__; __THREW__ = 0;
      $278 = $277&1;
      if ($278) {
       label = 116;
       break L1;
      }
      $$pre100 = HEAP8[$16>>0]|0;
      $280 = $$pre100;
     } else {
      $249 = ($245|0)==(0|0);
      if ($249) {
       $276 = 0;
      } else {
       $250 = $251 & 1;
       $252 = ($250<<24>>24)==(0);
       if ($252) {
        $255 = $251&255;
        $256 = $255 >>> 1;
        $258 = $256;$273 = $33;
       } else {
        $253 = HEAP32[$35>>2]|0;
        $254 = HEAP32[$36>>2]|0;
        $258 = $254;$273 = $253;
       }
       $257 = ($258>>>0)>(2147483631);
       if ($257) {
        label = 98;
        break L1;
       }
       $261 = ($258>>>0)<(11);
       if ($261) {
        $262 = $258 << 1;
        $263 = $262&255;
        HEAP8[$245>>0] = $263;
        $264 = (($245) + 1|0);
        $__p$0$i$i$i$i$i$i45 = $264;
       } else {
        $265 = (($258) + 16)|0;
        $266 = $265 & -16;
        HEAP32[$2>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$2+0>>2]|0;
        $267 = (invoke_iiiiiii(102,($266|0),16,($$byval_copy41|0),0,(769120|0),79)|0);
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         label = 116;
         break L1;
        }
        $270 = (($245) + 8|0);
        HEAP32[$270>>2] = $267;
        $271 = $266 | 1;
        HEAP32[$245>>2] = $271;
        $272 = (($245) + 4|0);
        HEAP32[$272>>2] = $258;
        $__p$0$i$i$i$i$i$i45 = $267;
       }
       _memcpy(($__p$0$i$i$i$i$i$i45|0),($273|0),($258|0))|0;
       $274 = (($__p$0$i$i$i$i$i$i45) + ($258)|0);
       HEAP8[$274>>0] = 0;
       $$pre$i46 = HEAP32[$244>>2]|0;
       $276 = $$pre$i46;
      }
      $275 = (($276) + 12|0);
      HEAP32[$244>>2] = $275;
      $280 = $251;
     }
     $279 = $280 & 1;
     $281 = ($279<<24>>24)==(0);
     if (!($281)) {
      $282 = HEAP32[$35>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($282|0),($$byval_copy41|0));
      $283 = __THREW__; __THREW__ = 0;
      $284 = $283&1;
      if ($284) {
       label = 110;
       break L1;
      }
     }
     $287 = HEAP8[$17>>0]|0;
     $288 = $287 & 1;
     $289 = ($288<<24>>24)==(0);
     if ($289) {
      break;
     }
     $290 = HEAP32[$34>>2]|0;
     __ZdlPv($290);
     break;
    }
   }
  } while(0);
  $311 = (($i$095) + 1)|0;
  $312 = ($311|0)<(54);
  if ($312) {
   $i$095 = $311;
  } else {
   label = 124;
   break;
  }
 }
 switch (label|0) {
  case 4: {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
   break;
  }
  case 9: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $118 = ___cxa_find_matching_catch()|0;
    $119 = tempRet0;
    $lpad$phi75$index = $118;$lpad$phi75$index2 = $119;
    label = 38;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 21: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    $125 = $77;$lpad$phi80$index = $122;$lpad$phi80$index7 = $123;
    label = 41;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 33: {
   $111 = ___cxa_find_matching_catch()|0;
   $112 = tempRet0;
   ___cxa_call_unexpected(($111|0));
   // unreachable;
   break;
  }
  case 36: {
   $116 = ___cxa_find_matching_catch()|0;
   $117 = tempRet0;
   $lpad$phi75$index = $116;$lpad$phi75$index2 = $117;
   label = 38;
   break;
  }
  case 39: {
   $120 = ___cxa_find_matching_catch()|0;
   $121 = tempRet0;
   $$pre = HEAP8[$12>>0]|0;
   $125 = $$pre;$lpad$phi80$index = $120;$lpad$phi80$index7 = $121;
   label = 41;
   break;
  }
  case 48: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $144 = __THREW__; __THREW__ = 0;
   $145 = $144&1;
   if ($145) {
    $206 = ___cxa_find_matching_catch()|0;
    $207 = tempRet0;
    $lpad$phi65$index = $206;$lpad$phi65$index12 = $207;
    label = 77;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 60: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $172 = __THREW__; __THREW__ = 0;
   $173 = $172&1;
   if ($173) {
    $210 = ___cxa_find_matching_catch()|0;
    $211 = tempRet0;
    $213 = $164;$lpad$phi70$index = $210;$lpad$phi70$index17 = $211;
    label = 80;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 72: {
   $198 = ___cxa_find_matching_catch()|0;
   $199 = tempRet0;
   ___cxa_call_unexpected(($198|0));
   // unreachable;
   break;
  }
  case 75: {
   $204 = ___cxa_find_matching_catch()|0;
   $205 = tempRet0;
   $lpad$phi65$index = $204;$lpad$phi65$index12 = $205;
   label = 77;
   break;
  }
  case 78: {
   $208 = ___cxa_find_matching_catch()|0;
   $209 = tempRet0;
   $$pre96 = HEAP8[$14>>0]|0;
   $213 = $$pre96;$lpad$phi70$index = $208;$lpad$phi70$index17 = $209;
   label = 80;
   break;
  }
  case 86: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $231 = __THREW__; __THREW__ = 0;
   $232 = $231&1;
   if ($232) {
    $293 = ___cxa_find_matching_catch()|0;
    $294 = tempRet0;
    $lpad$phi$index = $293;$lpad$phi$index22 = $294;
    label = 115;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 98: {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $259 = __THREW__; __THREW__ = 0;
   $260 = $259&1;
   if ($260) {
    $297 = ___cxa_find_matching_catch()|0;
    $298 = tempRet0;
    $300 = $251;$lpad$phi60$index = $297;$lpad$phi60$index27 = $298;
    label = 118;
    break;
   } else {
    // unreachable;
   }
   break;
  }
  case 110: {
   $285 = ___cxa_find_matching_catch()|0;
   $286 = tempRet0;
   ___cxa_call_unexpected(($285|0));
   // unreachable;
   break;
  }
  case 113: {
   $291 = ___cxa_find_matching_catch()|0;
   $292 = tempRet0;
   $lpad$phi$index = $291;$lpad$phi$index22 = $292;
   label = 115;
   break;
  }
  case 116: {
   $295 = ___cxa_find_matching_catch()|0;
   $296 = tempRet0;
   $$pre97 = HEAP8[$16>>0]|0;
   $300 = $$pre97;$lpad$phi60$index = $295;$lpad$phi60$index27 = $296;
   label = 118;
   break;
  }
  case 124: {
   STACKTOP = sp;return;
   break;
  }
 }
 if ((label|0) == 38) {
  $$0 = $lpad$phi75$index2;$$01 = $lpad$phi75$index;
  label = 44;
 }
 else if ((label|0) == 41) {
  $124 = $125 & 1;
  $126 = ($124<<24>>24)==(0);
  if ($126) {
   $$0 = $lpad$phi80$index7;$$01 = $lpad$phi80$index;
   label = 44;
  } else {
   $127 = HEAP32[$24>>2]|0;
   HEAP32[$8>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$8+0>>2]|0;
   invoke_vii(2591,($127|0),($$byval_copy41|0));
   $128 = __THREW__; __THREW__ = 0;
   $129 = $128&1;
   if ($129) {
    $130 = ___cxa_find_matching_catch()|0;
    $131 = tempRet0;
    ___cxa_call_unexpected(($130|0));
    // unreachable;
   } else {
    $$0 = $lpad$phi80$index7;$$01 = $lpad$phi80$index;
    label = 44;
   }
  }
 }
 else if ((label|0) == 77) {
  $$1 = $lpad$phi65$index12;$$12 = $lpad$phi65$index;
  label = 83;
 }
 else if ((label|0) == 80) {
  $212 = $213 & 1;
  $214 = ($212<<24>>24)==(0);
  if ($214) {
   $$1 = $lpad$phi70$index17;$$12 = $lpad$phi70$index;
   label = 83;
  } else {
   $215 = HEAP32[$30>>2]|0;
   HEAP32[$4>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($215|0),($$byval_copy41|0));
   $216 = __THREW__; __THREW__ = 0;
   $217 = $216&1;
   if ($217) {
    $218 = ___cxa_find_matching_catch()|0;
    $219 = tempRet0;
    ___cxa_call_unexpected(($218|0));
    // unreachable;
   } else {
    $$1 = $lpad$phi70$index17;$$12 = $lpad$phi70$index;
    label = 83;
   }
  }
 }
 else if ((label|0) == 115) {
  $$2 = $lpad$phi$index22;$$23 = $lpad$phi$index;
  label = 121;
 }
 else if ((label|0) == 118) {
  $299 = $300 & 1;
  $301 = ($299<<24>>24)==(0);
  if ($301) {
   $$2 = $lpad$phi60$index27;$$23 = $lpad$phi60$index;
   label = 121;
  } else {
   $302 = HEAP32[$35>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy41+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($302|0),($$byval_copy41|0));
   $303 = __THREW__; __THREW__ = 0;
   $304 = $303&1;
   if ($304) {
    $305 = ___cxa_find_matching_catch()|0;
    $306 = tempRet0;
    ___cxa_call_unexpected(($305|0));
    // unreachable;
   } else {
    $$2 = $lpad$phi60$index27;$$23 = $lpad$phi60$index;
    label = 121;
   }
  }
 }
 if ((label|0) == 44) {
  $132 = $52 & 1;
  $133 = ($132<<24>>24)==(0);
  if ($133) {
   $$3 = $$0;$$34 = $$01;
   ___resumeException($$34|0);
   // unreachable;
  }
  $134 = HEAP32[$23>>2]|0;
  __ZdlPv($134);
  $$3 = $$0;$$34 = $$01;
  ___resumeException($$34|0);
  // unreachable;
 }
 else if ((label|0) == 83) {
  $220 = HEAP8[$15>>0]|0;
  $221 = $220 & 1;
  $222 = ($221<<24>>24)==(0);
  if ($222) {
   $$3 = $$1;$$34 = $$12;
   ___resumeException($$34|0);
   // unreachable;
  }
  $223 = HEAP32[$29>>2]|0;
  __ZdlPv($223);
  $$3 = $$1;$$34 = $$12;
  ___resumeException($$34|0);
  // unreachable;
 }
 else if ((label|0) == 121) {
  $307 = HEAP8[$17>>0]|0;
  $308 = $307 & 1;
  $309 = ($308<<24>>24)==(0);
  if ($309) {
   $$3 = $$2;$$34 = $$23;
   ___resumeException($$34|0);
   // unreachable;
  }
  $310 = HEAP32[$34>>2]|0;
  __ZdlPv($310);
  $$3 = $$2;$$34 = $$23;
  ___resumeException($$34|0);
  // unreachable;
 }
}
function __ZN10HumanTrait12CleanupClassEv() {
 var $$byval_copy1 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i4 = 0, $$pre$i$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[769080>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($2) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($4|0);
   do {
    if ($8) {
     $22 = $4;
    } else {
     $10 = $7;
     while(1) {
      $9 = (($10) + -12|0);
      HEAP32[$6>>2] = $9;
      $11 = HEAP8[$9>>0]|0;
      $12 = $11 & 1;
      $13 = ($12<<24>>24)==(0);
      if ($13) {
       $15 = $9;
      } else {
       $16 = (($10) + -4|0);
       $17 = HEAP32[$16>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($17|0),($$byval_copy1|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        label = 9;
        break;
       }
       $$pre$i$i$i$i$i = HEAP32[$6>>2]|0;
       $15 = $$pre$i$i$i$i$i;
      }
      $14 = ($15|0)==($4|0);
      if ($14) {
       label = 10;
       break;
      } else {
       $10 = $15;
      }
     }
     if ((label|0) == 9) {
      $20 = ___cxa_find_matching_catch()|0;
      $21 = tempRet0;
      ___cxa_call_unexpected(($20|0));
      // unreachable;
     }
     else if ((label|0) == 10) {
      $$pre$i$i$i = HEAP32[$2>>2]|0;
      $22 = $$pre$i$i$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($22);
  }
  __ZdlPv($2);
 }
 HEAP32[769080>>2] = 0;
 $23 = HEAP32[769088>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  HEAP32[769088>>2] = 0;
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$23>>2]|0;
 $26 = ($25|0)==(0|0);
 if (!($26)) {
  $27 = (($23) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($25|0);
  do {
   if ($29) {
    $43 = $25;
   } else {
    $31 = $28;
    while(1) {
     $30 = (($31) + -12|0);
     HEAP32[$27>>2] = $30;
     $32 = HEAP8[$30>>0]|0;
     $33 = $32 & 1;
     $34 = ($33<<24>>24)==(0);
     if ($34) {
      $36 = $30;
     } else {
      $37 = (($31) + -4|0);
      $38 = HEAP32[$37>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($38|0),($$byval_copy1|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 21;
       break;
      }
      $$pre$i$i$i$i$i4 = HEAP32[$27>>2]|0;
      $36 = $$pre$i$i$i$i$i4;
     }
     $35 = ($36|0)==($25|0);
     if ($35) {
      label = 22;
      break;
     } else {
      $31 = $36;
     }
    }
    if ((label|0) == 21) {
     $41 = ___cxa_find_matching_catch()|0;
     $42 = tempRet0;
     ___cxa_call_unexpected(($41|0));
     // unreachable;
    }
    else if ((label|0) == 22) {
     $$pre$i$i$i6 = HEAP32[$23>>2]|0;
     $43 = $$pre$i$i$i6;
     break;
    }
   }
  } while(0);
  __ZdlPv($43);
 }
 __ZdlPv($23);
 HEAP32[769088>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN10HumanTrait19GetFingerMuscleNameEib($agg$result,$index,$left) {
 $agg$result = $agg$result|0;
 $index = $index|0;
 $left = $left|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = $left ? 769096 : 769104;
 $1 = (_strlen(($0|0))|0);
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$agg$result>>0] = $5;
  $6 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $6;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  $10 = (($agg$result) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$agg$result>>2] = $11;
  $12 = (($agg$result) + 4|0);
  HEAP32[$12>>2] = $1;
  $__p$0$i$i$i = $9;
 }
 _memcpy(($__p$0$i$i$i|0),($0|0),($1|0))|0;
 $13 = (($__p$0$i$i$i) + ($1)|0);
 HEAP8[$13>>0] = 0;
 $14 = ($index>>>0)<(20);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($index|0) / 4)&-1;
 $16 = (($index|0) % 4)&-1;
 __THREW__ = 0;
 $17 = (invoke_ii(3400,($15|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  $20 = (_strlen(($17|0))|0);
  __THREW__ = 0;
  (invoke_iiii(1480,($agg$result|0),($17|0),($20|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __THREW__ = 0;
   (invoke_iiii(1480,($agg$result|0),(769112|0),1)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    $25 = (invoke_ii(3401,($16|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = (_strlen(($25|0))|0);
     __THREW__ = 0;
     (invoke_iiii(1480,($agg$result|0),($25|0),($28|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $33 = HEAP8[$agg$result>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  ___resumeException($31|0);
  // unreachable;
 }
 $36 = (($agg$result) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 __ZdlPv($37);
 ___resumeException($31|0);
 // unreachable;
}
function __ZN10HumanTrait13GetFingerNameEib($agg$result,$index,$left) {
 $agg$result = $agg$result|0;
 $index = $index|0;
 $left = $left|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = $left ? 769096 : 769104;
 $1 = (_strlen(($0|0))|0);
 $2 = ($1>>>0)>(4294967279);
 if ($2) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $3 = ($1>>>0)<(11);
 if ($3) {
  $4 = $1 << 1;
  $5 = $4&255;
  HEAP8[$agg$result>>0] = $5;
  $6 = (($agg$result) + 1|0);
  $__p$0$i$i$i = $6;
 } else {
  $7 = (($1) + 16)|0;
  $8 = $7 & -16;
  $9 = (__Znwj($8)|0);
  $10 = (($agg$result) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8 | 1;
  HEAP32[$agg$result>>2] = $11;
  $12 = (($agg$result) + 4|0);
  HEAP32[$12>>2] = $1;
  $__p$0$i$i$i = $9;
 }
 _memcpy(($__p$0$i$i$i|0),($0|0),($1|0))|0;
 $13 = (($__p$0$i$i$i) + ($1)|0);
 HEAP8[$13>>0] = 0;
 $14 = ($index>>>0)<(15);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($index|0) / 3)&-1;
 $16 = (($index|0) % 3)&-1;
 __THREW__ = 0;
 $17 = (invoke_ii(3400,($15|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  $20 = (_strlen(($17|0))|0);
  __THREW__ = 0;
  (invoke_iiii(1480,($agg$result|0),($17|0),($20|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __THREW__ = 0;
   (invoke_iiii(1480,($agg$result|0),(769112|0),1)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    $25 = (invoke_ii(3402,($16|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = (_strlen(($25|0))|0);
     __THREW__ = 0;
     (invoke_iiii(1480,($agg$result|0),($25|0),($28|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $33 = HEAP8[$agg$result>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  ___resumeException($31|0);
  // unreachable;
 }
 $36 = (($agg$result) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 __ZdlPv($37);
 ___resumeException($31|0);
 // unreachable;
}
function __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$4);
 $5 = (($__nd) + 20|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 28|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($10|0),($$byval_copy|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   ___cxa_call_unexpected(($13|0));
   // unreachable;
  }
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZN9BlobWriteD1Ev($this) {
 $this = $this|0;
 var $$lcssa$i = 0, $$ph$i = 0, $$ph1$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre2$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$01$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 >>> 8;
 $5 = (($1) + ($4<<2)|0);
 $6 = (($this) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($1|0);
 if ($8) {
  $9 = (($this) + 44|0);
  $23 = 0;$32 = $9;$61 = 0;
 } else {
  $10 = HEAP32[$5>>2]|0;
  $11 = $3 & 255;
  $12 = (($10) + ($11<<4)|0);
  $13 = (($this) + 44|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($3))|0;
  $16 = $15 >>> 8;
  $17 = (($1) + ($16<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $15 & 255;
  $20 = (($18) + ($19<<4)|0);
  $23 = $20;$32 = $13;$61 = $12;
 }
 $$ph$i = $61;$$ph1$i = $5;
 L5: while(1) {
  $22 = $$ph$i;
  while(1) {
   $21 = ($22|0)==($23|0);
   if ($21) {
    break L5;
   }
   $24 = (($22) + 16|0);
   $25 = HEAP32[$$ph1$i>>2]|0;
   $26 = $24;
   $27 = $25;
   $28 = (($26) - ($27))|0;
   $29 = ($28|0)==(4096);
   if ($29) {
    break;
   } else {
    $22 = $24;
   }
  }
  $30 = (($$ph1$i) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $$ph$i = $31;$$ph1$i = $30;
 }
 HEAP32[$32>>2] = 0;
 $33 = $7;
 $34 = $1;
 $35 = (($33) - ($34))|0;
 $36 = $35 >> 2;
 $37 = ($36>>>0)>(2);
 if ($37) {
  $39 = $1;
  while(1) {
   $38 = HEAP32[$39>>2]|0;
   __ZdlPv($38);
   $40 = HEAP32[$0>>2]|0;
   $41 = (($40) + 4|0);
   HEAP32[$0>>2] = $41;
   $42 = HEAP32[$6>>2]|0;
   $43 = $42;
   $44 = $41;
   $45 = (($43) - ($44))|0;
   $46 = $45 >> 2;
   $47 = ($46>>>0)>(2);
   if ($47) {
    $39 = $41;
   } else {
    $$lcssa$i = $46;
    break;
   }
  }
 } else {
  $$lcssa$i = $36;
 }
 if ((($$lcssa$i|0) == 2)) {
  HEAP32[$2>>2] = 256;
 } else if ((($$lcssa$i|0) == 1)) {
  HEAP32[$2>>2] = 128;
 }
 $48 = HEAP32[$0>>2]|0;
 $49 = HEAP32[$6>>2]|0;
 $50 = ($48|0)==($49|0);
 if (!($50)) {
  $__i$01$i$i$i$i$i$i = $48;
  while(1) {
   $51 = HEAP32[$__i$01$i$i$i$i$i$i>>2]|0;
   __ZdlPv($51);
   $52 = (($__i$01$i$i$i$i$i$i) + 4|0);
   $53 = ($52|0)==($49|0);
   if ($53) {
    break;
   } else {
    $__i$01$i$i$i$i$i$i = $52;
   }
  }
  $$pre$i$i$i$i$i$i = HEAP32[$0>>2]|0;
  $$pre2$i$i$i$i$i$i = HEAP32[$6>>2]|0;
  $54 = ($$pre2$i$i$i$i$i$i|0)==($$pre$i$i$i$i$i$i|0);
  if (!($54)) {
   $__new_last2$i$i$i$i$i$i$i$i$i$i$i = $$pre$i$i$i$i$i$i;
   $scevgep$i$i$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i$i$i) + -4|0);
   $55 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i) + ($55)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i;
   $56 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i >>> 2;
   $57 = $56 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i$i$i = (($$pre2$i$i$i$i$i$i) + ($57<<2)|0);
   HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i;
  }
 }
 $58 = (($this) + 24|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(0|0);
 if ($60) {
  STACKTOP = sp;return;
 }
 __ZdlPv($59);
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  __ZN9BlobWrite4PushEjPKvj($this,4,$data,4);
 } else {
 }
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + -1)|0;
 $9 = (($8) + ($7))|0;
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9 >>> 8;
 $13 = (($11) + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $9 & 255;
 $16 = (($14) + ($15<<4)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($14) + ($15<<4)|0) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($17))|0;
 $21 = (0 - ($20))|0;
 $22 = $21 & 3;
 $23 = (($19) + ($22))|0;
 HEAP32[$18>>2] = $23;
 $24 = (($this) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$4>>2]|0;
 $27 = HEAP32[$6>>2]|0;
 $28 = (($26) + -1)|0;
 $29 = (($28) + ($27))|0;
 $30 = HEAP32[$10>>2]|0;
 $31 = $29 >>> 8;
 $32 = (($30) + ($31<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $29 & 255;
 $35 = (($33) + ($34<<4)|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($33) + ($34<<4)|0) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + ($36))|0;
 $40 = HEAP32[$25>>2]|0;
 $41 = (($40) + ($39)|0);
 $42 = HEAPU8[$data>>0]|(HEAPU8[$data+1>>0]<<8)|(HEAPU8[$data+2>>0]<<16)|(HEAPU8[$data+3>>0]<<24);
 HEAP8[$41>>0]=$42&255;HEAP8[$41+1>>0]=($42>>8)&255;HEAP8[$41+2>>0]=($42>>16)&255;HEAP8[$41+3>>0]=$42>>24;
 $43 = (($this) + 23|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  $46 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$41>>2] = $46;
 }
 $47 = HEAP32[$4>>2]|0;
 $48 = HEAP32[$6>>2]|0;
 $49 = (($47) + -1)|0;
 $50 = (($49) + ($48))|0;
 $51 = HEAP32[$10>>2]|0;
 $52 = $50 >>> 8;
 $53 = (($51) + ($52<<2)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $50 & 255;
 $56 = ((($54) + ($55<<4)|0) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 4)|0;
 HEAP32[$56>>2] = $58;
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $59 = HEAP32[$4>>2]|0;
 $60 = (($59) + -1)|0;
 HEAP32[$4>>2] = $60;
 $61 = (($this) + 32|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==($51|0);
 if ($63) {
  $70 = 0;
 } else {
  $64 = $62;
  $65 = $51;
  $66 = (($64) - ($65))|0;
  $67 = $66 << 6;
  $68 = (($67) + -1)|0;
  $70 = $68;
 }
 $69 = HEAP32[$6>>2]|0;
 $$neg1$i = (1 - ($59))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($70))|0;
 $71 = (($$neg2$i$i$i) - ($69))|0;
 $72 = ($71>>>0)>(511);
 if (!($72)) {
  STACKTOP = sp;return;
 }
 $73 = (($62) + -4|0);
 $74 = HEAP32[$73>>2]|0;
 __ZdlPv($74);
 $75 = HEAP32[$61>>2]|0;
 $76 = (($75) + -4|0);
 $__new_last2$i$i$i$i$i = $76;
 $77 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($76) + ($77)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $78 = $uglygep3$i$i$i$i$i >>> 2;
 $79 = $78 ^ -1;
 $scevgep4$i$i$i$i$i = (($75) + ($79<<2)|0);
 HEAP32[$61>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIiEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  __ZN9BlobWrite4PushEjPKvj($this,4,$data,4);
 } else {
 }
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + -1)|0;
 $9 = (($8) + ($7))|0;
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9 >>> 8;
 $13 = (($11) + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $9 & 255;
 $16 = (($14) + ($15<<4)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($14) + ($15<<4)|0) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($17))|0;
 $21 = (0 - ($20))|0;
 $22 = $21 & 3;
 $23 = (($19) + ($22))|0;
 HEAP32[$18>>2] = $23;
 $24 = (($this) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$4>>2]|0;
 $27 = HEAP32[$6>>2]|0;
 $28 = (($26) + -1)|0;
 $29 = (($28) + ($27))|0;
 $30 = HEAP32[$10>>2]|0;
 $31 = $29 >>> 8;
 $32 = (($30) + ($31<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $29 & 255;
 $35 = (($33) + ($34<<4)|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($33) + ($34<<4)|0) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + ($36))|0;
 $40 = HEAP32[$25>>2]|0;
 $41 = (($40) + ($39)|0);
 $42 = HEAPU8[$data>>0]|(HEAPU8[$data+1>>0]<<8)|(HEAPU8[$data+2>>0]<<16)|(HEAPU8[$data+3>>0]<<24);
 HEAP8[$41>>0]=$42&255;HEAP8[$41+1>>0]=($42>>8)&255;HEAP8[$41+2>>0]=($42>>16)&255;HEAP8[$41+3>>0]=$42>>24;
 $43 = (($this) + 23|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  $46 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$41>>2] = $46;
 }
 $47 = HEAP32[$4>>2]|0;
 $48 = HEAP32[$6>>2]|0;
 $49 = (($47) + -1)|0;
 $50 = (($49) + ($48))|0;
 $51 = HEAP32[$10>>2]|0;
 $52 = $50 >>> 8;
 $53 = (($51) + ($52<<2)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $50 & 255;
 $56 = ((($54) + ($55<<4)|0) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 4)|0;
 HEAP32[$56>>2] = $58;
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $59 = HEAP32[$4>>2]|0;
 $60 = (($59) + -1)|0;
 HEAP32[$4>>2] = $60;
 $61 = (($this) + 32|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==($51|0);
 if ($63) {
  $70 = 0;
 } else {
  $64 = $62;
  $65 = $51;
  $66 = (($64) - ($65))|0;
  $67 = $66 << 6;
  $68 = (($67) + -1)|0;
  $70 = $68;
 }
 $69 = HEAP32[$6>>2]|0;
 $$neg1$i = (1 - ($59))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($70))|0;
 $71 = (($$neg2$i$i$i) - ($69))|0;
 $72 = ($71>>>0)>(511);
 if (!($72)) {
  STACKTOP = sp;return;
 }
 $73 = (($62) + -4|0);
 $74 = HEAP32[$73>>2]|0;
 __ZdlPv($74);
 $75 = HEAP32[$61>>2]|0;
 $76 = (($75) + -4|0);
 $__new_last2$i$i$i$i$i = $76;
 $77 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($76) + ($77)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $78 = $uglygep3$i$i$i$i$i >>> 2;
 $79 = $78 ^ -1;
 $scevgep4$i$i$i$i$i = (($75) + ($79<<2)|0);
 HEAP32[$61>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$data,769128,0);
 $37 = (($data) + 16|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$37,769136,0);
 $38 = (($data) + 32|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$38,769144,0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $39 = HEAP32[$17>>2]|0;
 $40 = (($39) + -1)|0;
 HEAP32[$17>>2] = $40;
 $41 = (($this) + 32|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$23>>2]|0;
 $44 = ($42|0)==($43|0);
 if ($44) {
  $51 = 0;
 } else {
  $45 = $42;
  $46 = $43;
  $47 = (($45) - ($46))|0;
  $48 = $47 << 6;
  $49 = (($48) + -1)|0;
  $51 = $49;
 }
 $50 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($39))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($51))|0;
 $52 = (($$neg2$i$i$i) - ($50))|0;
 $53 = ($52>>>0)>(511);
 if (!($53)) {
  STACKTOP = sp;return;
 }
 $54 = (($42) + -4|0);
 $55 = HEAP32[$54>>2]|0;
 __ZdlPv($55);
 $56 = HEAP32[$41>>2]|0;
 $57 = (($56) + -4|0);
 $__new_last2$i$i$i$i$i = $57;
 $58 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($57) + ($58)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $59 = $uglygep3$i$i$i$i$i >>> 2;
 $60 = $59 ^ -1;
 $scevgep4$i$i$i$i$i = (($56) + ($60<<2)|0);
 HEAP32[$41>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i$i$i$i = 0, $buf$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  __ZN9BlobWrite4PushEjPKvj($this,16,$data,4);
 } else {
 }
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + -1)|0;
 $9 = (($8) + ($7))|0;
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9 >>> 8;
 $13 = (($11) + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $9 & 255;
 $16 = (($14) + ($15<<4)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($14) + ($15<<4)|0) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($17))|0;
 $21 = (0 - ($20))|0;
 $22 = $21 & 3;
 $23 = (($19) + ($22))|0;
 HEAP32[$18>>2] = $23;
 $24 = Math_fround(HEAPF32[$data>>2]);
 HEAPF32[$buf$i>>2] = $24;
 $25 = (($buf$i) + 4|0);
 $26 = (($data) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 HEAPF32[$25>>2] = $27;
 $28 = (($buf$i) + 8|0);
 $29 = (($data) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 HEAPF32[$28>>2] = $30;
 $31 = (($buf$i) + 12|0);
 $32 = (($data) + 12|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$31>>2] = $33;
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$buf$i,769152,0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$25,769160,0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$28,769168,0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$31,769176,0);
 $34 = Math_fround(HEAPF32[$buf$i>>2]);
 $35 = Math_fround(HEAPF32[$25>>2]);
 $36 = Math_fround(HEAPF32[$28>>2]);
 $37 = Math_fround(HEAPF32[$31>>2]);
 HEAPF32[$data>>2] = $34;
 HEAPF32[$26>>2] = $35;
 HEAPF32[$29>>2] = $36;
 HEAPF32[$32>>2] = $37;
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$4>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$4>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$10>>2]|0;
 $43 = ($41|0)==($42|0);
 if ($43) {
  $50 = 0;
 } else {
  $44 = $41;
  $45 = $42;
  $46 = (($44) - ($45))|0;
  $47 = $46 << 6;
  $48 = (($47) + -1)|0;
  $50 = $48;
 }
 $49 = HEAP32[$6>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($50))|0;
 $51 = (($$neg2$i$i$i) - ($49))|0;
 $52 = ($51>>>0)>(511);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = (($41) + -4|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 $55 = HEAP32[$40>>2]|0;
 $56 = (($55) + -4|0);
 $__new_last2$i$i$i$i$i = $56;
 $57 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($56) + ($57)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $58 = $uglygep3$i$i$i$i$i >>> 2;
 $59 = $58 ^ -1;
 $scevgep4$i$i$i$i$i = (($55) + ($59<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  __ZN9BlobWrite4PushEjPKvj($this,4,$data,4);
 } else {
 }
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + -1)|0;
 $9 = (($8) + ($7))|0;
 $10 = (($this) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9 >>> 8;
 $13 = (($11) + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $9 & 255;
 $16 = (($14) + ($15<<4)|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($14) + ($15<<4)|0) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($17))|0;
 $21 = (0 - ($20))|0;
 $22 = $21 & 3;
 $23 = (($19) + ($22))|0;
 HEAP32[$18>>2] = $23;
 $24 = (($this) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$4>>2]|0;
 $27 = HEAP32[$6>>2]|0;
 $28 = (($26) + -1)|0;
 $29 = (($28) + ($27))|0;
 $30 = HEAP32[$10>>2]|0;
 $31 = $29 >>> 8;
 $32 = (($30) + ($31<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $29 & 255;
 $35 = (($33) + ($34<<4)|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($33) + ($34<<4)|0) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + ($36))|0;
 $40 = HEAP32[$25>>2]|0;
 $41 = (($40) + ($39)|0);
 $42 = HEAPU8[$data>>0]|(HEAPU8[$data+1>>0]<<8)|(HEAPU8[$data+2>>0]<<16)|(HEAPU8[$data+3>>0]<<24);
 HEAP8[$41>>0]=$42&255;HEAP8[$41+1>>0]=($42>>8)&255;HEAP8[$41+2>>0]=($42>>16)&255;HEAP8[$41+3>>0]=$42>>24;
 $43 = (($this) + 23|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  $46 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$41>>2] = $46;
 }
 $47 = HEAP32[$4>>2]|0;
 $48 = HEAP32[$6>>2]|0;
 $49 = (($47) + -1)|0;
 $50 = (($49) + ($48))|0;
 $51 = HEAP32[$10>>2]|0;
 $52 = $50 >>> 8;
 $53 = (($51) + ($52<<2)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $50 & 255;
 $56 = ((($54) + ($55<<4)|0) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 4)|0;
 HEAP32[$56>>2] = $58;
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $59 = HEAP32[$4>>2]|0;
 $60 = (($59) + -1)|0;
 HEAP32[$4>>2] = $60;
 $61 = (($this) + 32|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==($51|0);
 if ($63) {
  $70 = 0;
 } else {
  $64 = $62;
  $65 = $51;
  $66 = (($64) - ($65))|0;
  $67 = $66 << 6;
  $68 = (($67) + -1)|0;
  $70 = $68;
 }
 $69 = HEAP32[$6>>2]|0;
 $$neg1$i = (1 - ($59))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($70))|0;
 $71 = (($$neg2$i$i$i) - ($69))|0;
 $72 = ($71>>>0)>(511);
 if (!($72)) {
  STACKTOP = sp;return;
 }
 $73 = (($62) + -4|0);
 $74 = HEAP32[$73>>2]|0;
 __ZdlPv($74);
 $75 = HEAP32[$61>>2]|0;
 $76 = (($75) + -4|0);
 $__new_last2$i$i$i$i$i = $76;
 $77 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($76) + ($77)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $78 = $uglygep3$i$i$i$i$i >>> 2;
 $79 = $78 ^ -1;
 $scevgep4$i$i$i$i$i = (($75) + ($79<<2)|0);
 HEAP32[$61>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  $8 = (0 - ($7))|0;
  $9 = $8 & 3;
  $10 = (($9) + ($7))|0;
  $11 = (($10) + 4)|0;
  $12 = (0 - ($10))|0;
  $13 = $12 & 3;
  $14 = (($11) + ($13))|0;
  $15 = (0 - ($14))|0;
  $16 = $15 & 3;
  $17 = (($16) + ($14))|0;
  $18 = (($17) + 4)|0;
  $19 = (0 - ($17))|0;
  $20 = $19 & 3;
  $21 = (($18) + ($20))|0;
  $22 = (0 - ($21))|0;
  $23 = $22 & 3;
  $24 = (($23) + ($21))|0;
  $25 = (($24) + 4)|0;
  $26 = (0 - ($24))|0;
  $27 = $26 & 3;
  $28 = (($25) + ($27))|0;
  $29 = (0 - ($28))|0;
  $30 = $29 & 3;
  $31 = (($30) + ($28))|0;
  $32 = (($31) + 4)|0;
  $33 = (0 - ($31))|0;
  $34 = $33 & 3;
  $35 = (($32) + ($34))|0;
  $36 = (0 - ($35))|0;
  $37 = $36 & 3;
  $38 = (($37) + ($35))|0;
  HEAP32[$3>>2] = $38;
  $40 = $38;
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $40 = $$pre;
 }
 $39 = (0 - ($40))|0;
 $41 = $39 & 3;
 $42 = (($41) + ($40))|0;
 $43 = (0 - ($42))|0;
 $44 = $43 & 3;
 $45 = (($44) + ($42))|0;
 $46 = (($45) + 4)|0;
 $47 = (0 - ($45))|0;
 $48 = $47 & 3;
 $49 = (($46) + ($48))|0;
 $50 = (0 - ($49))|0;
 $51 = $50 & 3;
 $52 = (($51) + ($49))|0;
 $53 = (($52) + 4)|0;
 $54 = (0 - ($52))|0;
 $55 = $54 & 3;
 $56 = (($53) + ($55))|0;
 $57 = (0 - ($56))|0;
 $58 = $57 & 3;
 $59 = (($58) + ($56))|0;
 $60 = (($59) + 4)|0;
 $61 = (0 - ($59))|0;
 $62 = $61 & 3;
 $63 = (($60) + ($62))|0;
 $64 = (0 - ($63))|0;
 $65 = $64 & 3;
 $66 = (($65) + ($63))|0;
 $67 = (($66) + 4)|0;
 $68 = (0 - ($66))|0;
 $69 = $68 & 3;
 $70 = (($67) + ($69))|0;
 $71 = (0 - ($70))|0;
 $72 = $71 & 3;
 $73 = (($72) + ($70))|0;
 $74 = (($transfer) + 12|0);
 $75 = (0 - ($73))|0;
 $76 = $75 & 3;
 $77 = (($76) + ($73))|0;
 $78 = (0 - ($77))|0;
 $79 = $78 & 3;
 $80 = (($79) + ($77))|0;
 $81 = (($80) + 4)|0;
 $82 = (0 - ($80))|0;
 $83 = $82 & 3;
 $84 = (($81) + ($83))|0;
 $85 = (0 - ($84))|0;
 $86 = $85 & 3;
 $87 = (($86) + ($84))|0;
 $88 = (($87) + 4)|0;
 $89 = (0 - ($87))|0;
 $90 = $89 & 3;
 $91 = (($88) + ($90))|0;
 $92 = (0 - ($91))|0;
 $93 = $92 & 3;
 $94 = (($93) + ($91))|0;
 $95 = (($94) + 4)|0;
 $96 = (0 - ($94))|0;
 $97 = $96 & 3;
 $98 = (($95) + ($97))|0;
 $99 = (0 - ($98))|0;
 $100 = $99 & 3;
 $101 = (($100) + ($98))|0;
 $102 = (($101) + 4)|0;
 $103 = (0 - ($101))|0;
 $104 = $103 & 3;
 $105 = (($102) + ($104))|0;
 $106 = (0 - ($105))|0;
 $107 = $106 & 3;
 $108 = (($107) + ($105))|0;
 HEAP32[$74>>2] = $108;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIiEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduceCopy$i = 0;
 var $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduceCopy$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduceCopy$i+0>>2]=0|0;HEAP32[$reduceCopy$i+4>>2]=0|0;HEAP32[$reduceCopy$i+8>>2]=0|0;
 $30 = (($data) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$33,$reduceCopy$i,4);
 __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIiEEclERS1_17TransferMetaFlagsR9BlobWrite(0,$data,0,$this);
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduceCopy$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$10>>2]|0;
 $35 = (($34) + -1)|0;
 HEAP32[$10>>2] = $35;
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$16>>2]|0;
 $39 = ($37|0)==($38|0);
 if ($39) {
  $46 = 0;
 } else {
  $40 = $37;
  $41 = $38;
  $42 = (($40) - ($41))|0;
  $43 = $42 << 6;
  $44 = (($43) + -1)|0;
  $46 = $44;
 }
 $45 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($34))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($46))|0;
 $47 = (($$neg2$i$i$i) - ($45))|0;
 $48 = ($47>>>0)>(511);
 if (!($48)) {
  STACKTOP = sp;return;
 }
 $49 = (($37) + -4|0);
 $50 = HEAP32[$49>>2]|0;
 __ZdlPv($50);
 $51 = HEAP32[$36>>2]|0;
 $52 = (($51) + -4|0);
 $__new_last2$i$i$i$i$i = $52;
 $53 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($52) + ($53)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $54 = $uglygep3$i$i$i$i$i >>> 2;
 $55 = $54 ^ -1;
 $scevgep4$i$i$i$i$i = (($51) + ($55<<2)|0);
 HEAP32[$36>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIiEEclERS1_17TransferMetaFlagsR9BlobWrite($this,$data,$metaFlags,$transfer) {
 $this = $this|0;
 $data = $data|0;
 $metaFlags = $metaFlags|0;
 $transfer = $transfer|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$02 = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$data>>2]|0;
 $5 = $4;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($4) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$0>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 << 2;
 $13 = HEAP32[$data>>2]|0;
 $14 = $13;
 $15 = HEAP32[$13>>2]|0;
 $16 = (($15) + ($14))|0;
 $17 = $16;
 $18 = (($13) + 4|0);
 HEAP32[$18>>2] = $17;
 $19 = $16;
 __ZN9BlobWrite4PushEjPKvj($transfer,$12,$19,4);
 $20 = HEAP32[$data>>2]|0;
 $21 = $20;
 $22 = HEAP32[$20>>2]|0;
 $23 = (($22) + ($21))|0;
 $24 = $23;
 $25 = (($20) + 4|0);
 HEAP32[$25>>2] = $24;
 $26 = HEAP32[$0>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($24) + ($27<<2)|0);
 $29 = HEAP32[$data>>2]|0;
 $30 = $29;
 $31 = HEAP32[$29>>2]|0;
 $32 = (($31) + ($30))|0;
 $33 = $32;
 $34 = (($29) + 4|0);
 HEAP32[$34>>2] = $33;
 $35 = ($33|0)==($28|0);
 if (!($35)) {
  $i$02 = $33;
  while(1) {
   __ZN9BlobWrite8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$i$02,769184,0);
   $36 = (($i$02) + 4|0);
   $37 = ($36|0)==($28|0);
   if ($37) {
    break;
   } else {
    $i$02 = $36;
   }
  }
 }
 $38 = (($transfer) + 44|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($transfer) + 40|0);
 $41 = (($39) + -1)|0;
 HEAP32[$38>>2] = $41;
 $42 = (($transfer) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($transfer) + 28|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($43|0)==($45|0);
 if ($46) {
  $53 = 0;
 } else {
  $47 = $43;
  $48 = $45;
  $49 = (($47) - ($48))|0;
  $50 = $49 << 6;
  $51 = (($50) + -1)|0;
  $53 = $51;
 }
 $52 = HEAP32[$40>>2]|0;
 $$neg1$i = (1 - ($39))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($53))|0;
 $54 = (($$neg2$i$i$i) - ($52))|0;
 $55 = ($54>>>0)>(511);
 if (!($55)) {
  STACKTOP = sp;return;
 }
 $56 = (($43) + -4|0);
 $57 = HEAP32[$56>>2]|0;
 __ZdlPv($57);
 $58 = HEAP32[$42>>2]|0;
 $59 = (($58) + -4|0);
 $__new_last2$i$i$i$i$i = $59;
 $60 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($59) + ($60)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $61 = $uglygep3$i$i$i$i$i >>> 2;
 $62 = $61 ^ -1;
 $scevgep4$i$i$i$i$i = (($58) + ($62<<2)|0);
 HEAP32[$42>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIbEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  __ZN9BlobWrite4PushEjPKvj($this,1,$data,1);
 }
 $4 = (($this) + 44|0);
 $5 = (($this) + 40|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$4>>2]|0;
 $9 = HEAP32[$5>>2]|0;
 $10 = (($8) + -1)|0;
 $11 = (($10) + ($9))|0;
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11 >>> 8;
 $15 = (($13) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $11 & 255;
 $18 = (($16) + ($17<<4)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($16) + ($17<<4)|0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19))|0;
 $23 = HEAP32[$7>>2]|0;
 $24 = (($23) + ($22)|0);
 $25 = HEAP8[$data>>0]|0;
 HEAP8[$24>>0] = $25;
 $26 = HEAP32[$4>>2]|0;
 $27 = HEAP32[$5>>2]|0;
 $28 = (($26) + -1)|0;
 $29 = (($28) + ($27))|0;
 $30 = HEAP32[$12>>2]|0;
 $31 = $29 >>> 8;
 $32 = (($30) + ($31<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $29 & 255;
 $35 = ((($33) + ($34<<4)|0) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$35>>2] = $37;
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$4>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$4>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==($30|0);
 if ($42) {
  $49 = 0;
 } else {
  $43 = $41;
  $44 = $30;
  $45 = (($43) - ($44))|0;
  $46 = $45 << 6;
  $47 = (($46) + -1)|0;
  $49 = $47;
 }
 $48 = HEAP32[$5>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($49))|0;
 $50 = (($$neg2$i$i$i) - ($48))|0;
 $51 = ($50>>>0)>(511);
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (($41) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 __ZdlPv($53);
 $54 = HEAP32[$40>>2]|0;
 $55 = (($54) + -4|0);
 $__new_last2$i$i$i$i$i = $55;
 $56 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($55) + ($56)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $57 = $uglygep3$i$i$i$i$i >>> 2;
 $58 = $57 ^ -1;
 $scevgep4$i$i$i$i$i = (($54) + ($58<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapIj8UnityStrNS2_4lessIjEENS2_9allocatorINS2_4pairIKjS4_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size>>2] = $2;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size,4);
 }
 $9 = (($data) + 4|0);
 $10 = HEAP32[$data>>2]|0;
 $11 = ($10|0)==($9|0);
 if ($11) {
  STACKTOP = sp;return;
 } else {
  $13 = $10;
 }
 while(1) {
  $12 = (($13) + 16|0);
  $14 = HEAP32[$3>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$6>>2]|0;
  $17 = ($15>>>0)<($16>>>0);
  if ($17) {
   $18 = HEAP32[$12>>2]|0;
   HEAP32[$14>>2] = $18;
   HEAP32[$3>>2] = $15;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$12,4);
  }
  $19 = (($13) + 20|0);
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$19,0);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($this);
  $20 = (($13) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0|0);
  if ($22) {
   $$01$i$i$i = $13;
   while(1) {
    $25 = (($$01$i$i$i) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==($$01$i$i$i|0);
    if ($28) {
     $$0$i$i$i = $26;
     break;
    } else {
     $$01$i$i$i = $26;
    }
   }
  } else {
   $$0$i$i$i$i = $21;
   while(1) {
    $23 = HEAP32[$$0$i$i$i$i>>2]|0;
    $24 = ($23|0)==(0|0);
    if ($24) {
     $$0$i$i$i = $$0$i$i$i$i;
     break;
    } else {
     $$0$i$i$i$i = $23;
    }
   }
  }
  $29 = ($$0$i$i$i|0)==($9|0);
  if ($29) {
   break;
  }
  $13 = $$0$i$i$i;
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapIj8UnityStrNS2_4lessIjEENS2_9allocatorINS2_4pairIKjS4_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy21 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$phi25Z2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$023 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy21 = sp + 92|0;
 $1 = sp + 88|0;
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 72|0;
 $6 = sp + 64|0;
 $7 = sp + 32|0;
 $8 = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 48|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i;
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$size>>2] = $17;
  HEAP32[$11>>2] = $13;
  $18 = $17;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$size>>2] = $19;
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($data,$21);
 $22 = (($data) + 8|0);
 HEAP32[$22>>2] = 0;
 $23 = (($data) + 4|0);
 HEAP32[$data>>2] = $23;
 HEAP32[$23>>2] = 0;
 $24 = HEAP32[$size>>2]|0;
 $25 = ($24|0)>(0);
 L5: do {
  if ($25) {
   $26 = (($p) + 4|0);
   $27 = (($10) + 4|0);
   $28 = (($26) + 1|0);
   $29 = (($27) + 1|0);
   $30 = (($7) + 4|0);
   $31 = (($30) + 1|0);
   $32 = (($10) + 12|0);
   $33 = (($7) + 12|0);
   $34 = (($7) + 8|0);
   $35 = (($10) + 8|0);
   $36 = (($p) + 12|0);
   $37 = (($p) + 8|0);
   $i$023 = 0;
   while(1) {
    $38 = HEAP32[$11>>2]|0;
    $39 = (($38) + 4|0);
    $40 = HEAP32[$14>>2]|0;
    $41 = ($39>>>0)>($40>>>0);
    if ($41) {
     __THREW__ = 0;
     invoke_viii(1748,($11|0),($p|0),4);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 44;
      break;
     }
     $$pre$i$i$i$i$i = HEAP32[$p>>2]|0;
     $45 = $$pre$i$i$i$i$i;
    } else {
     $42 = HEAP32[$38>>2]|0;
     HEAP32[$p>>2] = $42;
     HEAP32[$11>>2] = $39;
     $45 = $42;
    }
    $46 = (_llvm_bswap_i32(($45|0))|0);
    HEAP32[$p>>2] = $46;
    __THREW__ = 0;
    invoke_viii(1765,($this|0),($26|0),0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 44;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3377,($this|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 44;
     break;
    }
    $51 = HEAP32[$p>>2]|0;
    HEAP32[$10>>2] = $51;
    $52 = HEAP8[$26>>0]|0;
    $53 = $52 & 1;
    $54 = ($53<<24>>24)==(0);
    if ($54) {
     $57 = $52&255;
     $58 = $57 >>> 1;
     $60 = $58;$72 = $28;
    } else {
     $55 = HEAP32[$36>>2]|0;
     $56 = HEAP32[$37>>2]|0;
     $60 = $56;$72 = $55;
    }
    $59 = ($60>>>0)>(2147483631);
    if ($59) {
     label = 17;
     break;
    }
    $63 = ($60>>>0)<(11);
    if ($63) {
     $64 = $60 << 1;
     $65 = $64&255;
     HEAP8[$27>>0] = $65;
     $__p$0$i$i$i$i$i$i = $29;
    } else {
     $66 = (($60) + 16)|0;
     $67 = $66 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$8+0>>2]|0;
     $68 = (invoke_iiiiiii(102,($67|0),16,($$byval_copy21|0),0,(769120|0),79)|0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      label = 44;
      break;
     }
     HEAP32[$32>>2] = $68;
     $71 = $67 | 1;
     HEAP32[$27>>2] = $71;
     HEAP32[$35>>2] = $60;
     $__p$0$i$i$i$i$i$i = $68;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($72|0),($60|0))|0;
    $73 = (($__p$0$i$i$i$i$i$i) + ($60)|0);
    HEAP8[$73>>0] = 0;
    HEAP32[$7>>2] = $51;
    $74 = HEAP8[$27>>0]|0;
    $75 = $74 & 1;
    $76 = ($75<<24>>24)==(0);
    if ($76) {
     $79 = $74&255;
     $80 = $79 >>> 1;
     $82 = $80;$94 = $29;
    } else {
     $77 = HEAP32[$32>>2]|0;
     $78 = HEAP32[$35>>2]|0;
     $82 = $78;$94 = $77;
    }
    $81 = ($82>>>0)>(2147483631);
    if ($81) {
     label = 27;
     break;
    }
    $85 = ($82>>>0)<(11);
    if ($85) {
     $86 = $82 << 1;
     $87 = $86&255;
     HEAP8[$30>>0] = $87;
     $__p$0$i$i$i$i$i$i$i$i$i = $31;
    } else {
     $88 = (($82) + 16)|0;
     $89 = $88 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$5+0>>2]|0;
     $90 = (invoke_iiiiiii(102,($89|0),16,($$byval_copy21|0),0,(769120|0),79)|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 47;
      break;
     }
     HEAP32[$33>>2] = $90;
     $93 = $89 | 1;
     HEAP32[$30>>2] = $93;
     HEAP32[$34>>2] = $82;
     $__p$0$i$i$i$i$i$i$i$i$i = $90;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($94|0),($82|0))|0;
    $95 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($82)|0);
    HEAP8[$95>>0] = 0;
    HEAP32[$7>>2] = $51;
    __THREW__ = 0;
    invoke_viii(2011,($6|0),($data|0),($7|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 37;
     break;
    }
    $98 = HEAP8[$30>>0]|0;
    $99 = $98 & 1;
    $100 = ($99<<24>>24)==(0);
    if (!($100)) {
     $101 = HEAP32[$33>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($101|0),($$byval_copy21|0));
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 36;
      break;
     }
    }
    if (!($76)) {
     $116 = HEAP32[$32>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($116|0),($$byval_copy21|0));
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      label = 42;
      break;
     }
    }
    $121 = (($i$023) + 1)|0;
    $122 = HEAP32[$size>>2]|0;
    $123 = ($121|0)<($122|0);
    if ($123) {
     $i$023 = $121;
    } else {
     $$pre$phi25Z2D = $26;
     break L5;
    }
   }
   do {
    if ((label|0) == 17) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      $126 = ___cxa_find_matching_catch()|0;
      $127 = tempRet0;
      $lpad$phi$index = $126;$lpad$phi$index2 = $127;
      label = 46;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 27) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      $130 = ___cxa_find_matching_catch()|0;
      $131 = tempRet0;
      $eh$lpad$body$index9Z2D = $131;$eh$lpad$body$indexZ2D = $130;
      label = 49;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 36) {
     $104 = ___cxa_find_matching_catch()|0;
     $105 = tempRet0;
     ___cxa_call_unexpected(($104|0));
     // unreachable;
    }
    else if ((label|0) == 37) {
     $106 = ___cxa_find_matching_catch()|0;
     $107 = tempRet0;
     $108 = HEAP8[$30>>0]|0;
     $109 = $108 & 1;
     $110 = ($109<<24>>24)==(0);
     if ($110) {
      $eh$lpad$body$index9Z2D = $107;$eh$lpad$body$indexZ2D = $106;
      label = 49;
     } else {
      $111 = HEAP32[$33>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($111|0),($$byval_copy21|0));
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       $114 = ___cxa_find_matching_catch()|0;
       $115 = tempRet0;
       ___cxa_call_unexpected(($114|0));
       // unreachable;
      } else {
       $eh$lpad$body$index9Z2D = $107;$eh$lpad$body$indexZ2D = $106;
       label = 49;
      }
     }
    }
    else if ((label|0) == 42) {
     $119 = ___cxa_find_matching_catch()|0;
     $120 = tempRet0;
     ___cxa_call_unexpected(($119|0));
     // unreachable;
    }
    else if ((label|0) == 44) {
     $124 = ___cxa_find_matching_catch()|0;
     $125 = tempRet0;
     $lpad$phi$index = $124;$lpad$phi$index2 = $125;
     label = 46;
    }
    else if ((label|0) == 47) {
     $128 = ___cxa_find_matching_catch()|0;
     $129 = tempRet0;
     $eh$lpad$body$index9Z2D = $129;$eh$lpad$body$indexZ2D = $128;
     label = 49;
    }
   } while(0);
   if ((label|0) == 46) {
    $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
   }
   else if ((label|0) == 49) {
    if ($76) {
     $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;
    } else {
     $132 = HEAP32[$32>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($132|0),($$byval_copy21|0));
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if ($134) {
      $135 = ___cxa_find_matching_catch()|0;
      $136 = tempRet0;
      ___cxa_call_unexpected(($135|0));
      // unreachable;
     } else {
      $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
    }
   }
   $146 = HEAP8[$26>>0]|0;
   $147 = $146 & 1;
   $148 = ($147<<24>>24)==(0);
   if ($148) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $149 = HEAP32[$36>>2]|0;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($149|0),($$byval_copy21|0));
   $150 = __THREW__; __THREW__ = 0;
   $151 = $150&1;
   if ($151) {
    $152 = ___cxa_find_matching_catch()|0;
    $153 = tempRet0;
    ___cxa_call_unexpected(($152|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  } else {
   $$pre = (($p) + 4|0);
   $$pre$phi25Z2D = $$pre;
  }
 } while(0);
 $137 = HEAP8[$$pre$phi25Z2D>>0]|0;
 $138 = $137 & 1;
 $139 = ($138<<24>>24)==(0);
 if ($139) {
  STACKTOP = sp;return;
 }
 $140 = (($p) + 12|0);
 $141 = HEAP32[$140>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($141|0),($$byval_copy21|0));
 $142 = __THREW__; __THREW__ = 0;
 $143 = $142&1;
 if ($143) {
  $144 = ___cxa_find_matching_catch()|0;
  $145 = tempRet0;
  ___cxa_call_unexpected(($144|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $i$08 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $41 = (($28) + 4|0);
  HEAP32[$41>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 2;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $39 = 0;
  } else {
   $36 = $34;
   $37 = $28;
   $38 = (($36) - ($37))|0;
   $39 = $38;
  }
  HEAP32[$28>>2] = $39;
  $40 = (($28) + 4|0);
  HEAP32[$40>>2] = $34;
 }
 $42 = HEAP32[$data>>2]|0;
 $43 = $42;
 $44 = HEAP32[$42>>2]|0;
 $45 = (($44) + ($43))|0;
 $46 = $45;
 $47 = (($42) + 4|0);
 HEAP32[$47>>2] = $46;
 $48 = HEAP32[$25>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($46) + ($49<<2)|0);
 $51 = HEAP32[$data>>2]|0;
 $52 = $51;
 $53 = HEAP32[$51>>2]|0;
 $54 = (($53) + ($52))|0;
 $55 = $54;
 $56 = (($51) + 4|0);
 HEAP32[$56>>2] = $55;
 $57 = ($55|0)==($50|0);
 if ($57) {
  STACKTOP = sp;return;
 } else {
  $i$08 = $55;
 }
 while(1) {
  $58 = HEAP32[$1>>2]|0;
  $59 = (($58) + 4|0);
  $60 = HEAP32[$7>>2]|0;
  $61 = ($59>>>0)>($60>>>0);
  if ($61) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$08,4);
   $$pre$i$i$i = HEAP32[$i$08>>2]|0;
   $63 = $$pre$i$i$i;
  } else {
   $62 = HEAP32[$58>>2]|0;
   HEAP32[$i$08>>2] = $62;
   HEAP32[$1>>2] = $59;
   $63 = $62;
  }
  $64 = (_llvm_bswap_i32(($63|0))|0);
  HEAP32[$i$08>>2] = $64;
  $65 = (($i$08) + 4|0);
  $66 = ($65|0)==($50|0);
  if ($66) {
   break;
  } else {
   $i$08 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapIj8UnityStrNS2_4lessIjEENS2_9allocatorINS2_4pairIKjS4_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy21 = 0, $$pre$phi25Z2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$023 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy21 = sp + 92|0;
 $1 = sp + 88|0;
 $2 = sp + 84|0;
 $3 = sp + 80|0;
 $4 = sp + 76|0;
 $5 = sp + 72|0;
 $6 = sp + 64|0;
 $7 = sp + 32|0;
 $8 = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 48|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = (($this) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13>>>0)>($15>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($11,$size,4);
 } else {
  $17 = HEAP32[$12>>2]|0;
  HEAP32[$size>>2] = $17;
  HEAP32[$11>>2] = $13;
 }
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $18 = (($data) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($data,$19);
 $20 = (($data) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = (($data) + 4|0);
 HEAP32[$data>>2] = $21;
 HEAP32[$21>>2] = 0;
 $22 = HEAP32[$size>>2]|0;
 $23 = ($22|0)>(0);
 $24 = (($p) + 4|0);
 L5: do {
  if ($23) {
   $25 = (($10) + 4|0);
   $26 = (($24) + 1|0);
   $27 = (($25) + 1|0);
   $28 = (($7) + 4|0);
   $29 = (($28) + 1|0);
   $30 = (($10) + 12|0);
   $31 = (($7) + 12|0);
   $32 = (($7) + 8|0);
   $33 = (($10) + 8|0);
   $34 = (($p) + 12|0);
   $35 = (($p) + 8|0);
   $i$023 = 0;
   while(1) {
    $36 = HEAP32[$11>>2]|0;
    $37 = (($36) + 4|0);
    $38 = HEAP32[$14>>2]|0;
    $39 = ($37>>>0)>($38>>>0);
    if ($39) {
     __THREW__ = 0;
     invoke_viii(1748,($11|0),($p|0),4);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 43;
      break;
     }
    } else {
     $40 = HEAP32[$36>>2]|0;
     HEAP32[$p>>2] = $40;
     HEAP32[$11>>2] = $37;
    }
    __THREW__ = 0;
    invoke_viii(1767,($this|0),($24|0),0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     label = 43;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3376,($this|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     label = 43;
     break;
    }
    $47 = HEAP32[$p>>2]|0;
    HEAP32[$10>>2] = $47;
    $48 = HEAP8[$24>>0]|0;
    $49 = $48 & 1;
    $50 = ($49<<24>>24)==(0);
    if ($50) {
     $53 = $48&255;
     $54 = $53 >>> 1;
     $56 = $54;$68 = $26;
    } else {
     $51 = HEAP32[$34>>2]|0;
     $52 = HEAP32[$35>>2]|0;
     $56 = $52;$68 = $51;
    }
    $55 = ($56>>>0)>(2147483631);
    if ($55) {
     label = 16;
     break;
    }
    $59 = ($56>>>0)<(11);
    if ($59) {
     $60 = $56 << 1;
     $61 = $60&255;
     HEAP8[$25>>0] = $61;
     $__p$0$i$i$i$i$i$i = $27;
    } else {
     $62 = (($56) + 16)|0;
     $63 = $62 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$8+0>>2]|0;
     $64 = (invoke_iiiiiii(102,($63|0),16,($$byval_copy21|0),0,(769120|0),79)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      label = 43;
      break;
     }
     HEAP32[$30>>2] = $64;
     $67 = $63 | 1;
     HEAP32[$25>>2] = $67;
     HEAP32[$33>>2] = $56;
     $__p$0$i$i$i$i$i$i = $64;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($68|0),($56|0))|0;
    $69 = (($__p$0$i$i$i$i$i$i) + ($56)|0);
    HEAP8[$69>>0] = 0;
    HEAP32[$7>>2] = $47;
    $70 = HEAP8[$25>>0]|0;
    $71 = $70 & 1;
    $72 = ($71<<24>>24)==(0);
    if ($72) {
     $75 = $70&255;
     $76 = $75 >>> 1;
     $78 = $76;$90 = $27;
    } else {
     $73 = HEAP32[$30>>2]|0;
     $74 = HEAP32[$33>>2]|0;
     $78 = $74;$90 = $73;
    }
    $77 = ($78>>>0)>(2147483631);
    if ($77) {
     label = 26;
     break;
    }
    $81 = ($78>>>0)<(11);
    if ($81) {
     $82 = $78 << 1;
     $83 = $82&255;
     HEAP8[$28>>0] = $83;
     $__p$0$i$i$i$i$i$i$i$i$i = $29;
    } else {
     $84 = (($78) + 16)|0;
     $85 = $84 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$5+0>>2]|0;
     $86 = (invoke_iiiiiii(102,($85|0),16,($$byval_copy21|0),0,(769120|0),79)|0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 46;
      break;
     }
     HEAP32[$31>>2] = $86;
     $89 = $85 | 1;
     HEAP32[$28>>2] = $89;
     HEAP32[$32>>2] = $78;
     $__p$0$i$i$i$i$i$i$i$i$i = $86;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($90|0),($78|0))|0;
    $91 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($78)|0);
    HEAP8[$91>>0] = 0;
    HEAP32[$7>>2] = $47;
    __THREW__ = 0;
    invoke_viii(2011,($6|0),($data|0),($7|0));
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     label = 36;
     break;
    }
    $94 = HEAP8[$28>>0]|0;
    $95 = $94 & 1;
    $96 = ($95<<24>>24)==(0);
    if (!($96)) {
     $97 = HEAP32[$31>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($97|0),($$byval_copy21|0));
     $98 = __THREW__; __THREW__ = 0;
     $99 = $98&1;
     if ($99) {
      label = 35;
      break;
     }
    }
    if (!($72)) {
     $112 = HEAP32[$30>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($112|0),($$byval_copy21|0));
     $113 = __THREW__; __THREW__ = 0;
     $114 = $113&1;
     if ($114) {
      label = 41;
      break;
     }
    }
    $117 = (($i$023) + 1)|0;
    $118 = HEAP32[$size>>2]|0;
    $119 = ($117|0)<($118|0);
    if ($119) {
     $i$023 = $117;
    } else {
     $$pre$phi25Z2D = $24;
     break L5;
    }
   }
   do {
    if ((label|0) == 16) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      $122 = ___cxa_find_matching_catch()|0;
      $123 = tempRet0;
      $lpad$phi$index = $122;$lpad$phi$index2 = $123;
      label = 45;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 26) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if ($80) {
      $126 = ___cxa_find_matching_catch()|0;
      $127 = tempRet0;
      $eh$lpad$body$index9Z2D = $127;$eh$lpad$body$indexZ2D = $126;
      label = 48;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 35) {
     $100 = ___cxa_find_matching_catch()|0;
     $101 = tempRet0;
     ___cxa_call_unexpected(($100|0));
     // unreachable;
    }
    else if ((label|0) == 36) {
     $102 = ___cxa_find_matching_catch()|0;
     $103 = tempRet0;
     $104 = HEAP8[$28>>0]|0;
     $105 = $104 & 1;
     $106 = ($105<<24>>24)==(0);
     if ($106) {
      $eh$lpad$body$index9Z2D = $103;$eh$lpad$body$indexZ2D = $102;
      label = 48;
     } else {
      $107 = HEAP32[$31>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($107|0),($$byval_copy21|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       $110 = ___cxa_find_matching_catch()|0;
       $111 = tempRet0;
       ___cxa_call_unexpected(($110|0));
       // unreachable;
      } else {
       $eh$lpad$body$index9Z2D = $103;$eh$lpad$body$indexZ2D = $102;
       label = 48;
      }
     }
    }
    else if ((label|0) == 41) {
     $115 = ___cxa_find_matching_catch()|0;
     $116 = tempRet0;
     ___cxa_call_unexpected(($115|0));
     // unreachable;
    }
    else if ((label|0) == 43) {
     $120 = ___cxa_find_matching_catch()|0;
     $121 = tempRet0;
     $lpad$phi$index = $120;$lpad$phi$index2 = $121;
     label = 45;
    }
    else if ((label|0) == 46) {
     $124 = ___cxa_find_matching_catch()|0;
     $125 = tempRet0;
     $eh$lpad$body$index9Z2D = $125;$eh$lpad$body$indexZ2D = $124;
     label = 48;
    }
   } while(0);
   if ((label|0) == 45) {
    $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
   }
   else if ((label|0) == 48) {
    if ($72) {
     $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;
    } else {
     $128 = HEAP32[$30>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($128|0),($$byval_copy21|0));
     $129 = __THREW__; __THREW__ = 0;
     $130 = $129&1;
     if ($130) {
      $131 = ___cxa_find_matching_catch()|0;
      $132 = tempRet0;
      ___cxa_call_unexpected(($131|0));
      // unreachable;
     } else {
      $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;
     }
    }
   }
   $142 = HEAP8[$24>>0]|0;
   $143 = $142 & 1;
   $144 = ($143<<24>>24)==(0);
   if ($144) {
    ___resumeException($$01|0);
    // unreachable;
   }
   $145 = HEAP32[$34>>2]|0;
   HEAP32[$9>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($145|0),($$byval_copy21|0));
   $146 = __THREW__; __THREW__ = 0;
   $147 = $146&1;
   if ($147) {
    $148 = ___cxa_find_matching_catch()|0;
    $149 = tempRet0;
    ___cxa_call_unexpected(($148|0));
    // unreachable;
   } else {
    ___resumeException($$01|0);
    // unreachable;
   }
  } else {
   $$pre$phi25Z2D = $24;
  }
 } while(0);
 $133 = HEAP8[$$pre$phi25Z2D>>0]|0;
 $134 = $133 & 1;
 $135 = ($134<<24>>24)==(0);
 if ($135) {
  STACKTOP = sp;return;
 }
 $136 = (($p) + 12|0);
 $137 = HEAP32[$136>>2]|0;
 HEAP32[$1>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($137|0),($$byval_copy21|0));
 $138 = __THREW__; __THREW__ = 0;
 $139 = $138&1;
 if ($139) {
  $140 = ___cxa_find_matching_catch()|0;
  $141 = tempRet0;
  ___cxa_call_unexpected(($140|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre4 = HEAP32[$1>>2]|0;
   $$pre5 = HEAP32[$7>>2]|0;
   $12 = $$pre4;$14 = $$pre5;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre6 = HEAP32[$offset>>2]|0;
   $18 = $$pre6;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 2;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $37 = (($24) + 4|0);
  HEAP32[$37>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 2;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $35 = 0;
  } else {
   $32 = $30;
   $33 = $24;
   $34 = (($32) - ($33))|0;
   $35 = $34;
  }
  HEAP32[$24>>2] = $35;
  $36 = (($24) + 4|0);
  HEAP32[$36>>2] = $30;
 }
 $38 = HEAP32[$size1>>2]|0;
 $39 = ($38|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $40 = HEAP32[$data>>2]|0;
 $41 = $40;
 $42 = HEAP32[$40>>2]|0;
 $43 = (($42) + ($41))|0;
 $44 = $43;
 $45 = (($40) + 4|0);
 HEAP32[$45>>2] = $44;
 $46 = $43;
 $47 = $38 << 2;
 __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$46,$47);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapIj8UnityStrNS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0 = 0, $$01 = 0, $$byval_copy21 = 0, $$pre$phi31Z2D = 0, $$pre$pre = 0, $$pre30$pre$phiZZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i$i$i$i = 0, $converter$i$i = 0, $converter$i$i$i = 0, $eh$lpad$body$index9Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$029 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $p = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy21 = sp + 100|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 88|0;
 $4 = sp + 84|0;
 $5 = sp + 80|0;
 $6 = sp + 72|0;
 $7 = sp + 56|0;
 $8 = sp + 32|0;
 $converter$i$i$i = sp + 28|0;
 $converter$i$i = sp + 24|0;
 $9 = sp + 20|0;
 $size = sp + 16|0;
 $p = sp;
 $10 = sp + 40|0;
 $11 = (($data) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$size>>2] = $12;
 $13 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,769192,769192,$size)|0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$p+0>>2]=0|0;HEAP32[$p+4>>2]=0|0;HEAP32[$p+8>>2]=0|0;HEAP32[$p+12>>2]=0|0;
 $14 = (($data) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($data,$15);
 HEAP32[$11>>2] = 0;
 $16 = (($data) + 4|0);
 HEAP32[$data>>2] = $16;
 HEAP32[$16>>2] = 0;
 $17 = HEAP32[$size>>2]|0;
 $18 = ($17|0)>(0);
 L4: do {
  if ($18) {
   $19 = HEAP32[580608>>2]|0;
   $20 = (($10) + 4|0);
   $21 = (($p) + 4|0);
   $22 = (($21) + 1|0);
   $23 = (($20) + 1|0);
   $24 = (($7) + 4|0);
   $25 = (($24) + 1|0);
   $26 = (($10) + 12|0);
   $27 = (($7) + 12|0);
   $28 = (($7) + 8|0);
   $29 = (($10) + 8|0);
   $30 = (($p) + 12|0);
   $31 = (($p) + 8|0);
   $32 = HEAP32[580576>>2]|0;
   $33 = HEAP32[580656>>2]|0;
   $34 = HEAP32[580712>>2]|0;
   $i$029 = 0;
   while(1) {
    __THREW__ = 0;
    $35 = (invoke_iiiiii(192,($this|0),(769184|0),($19|0),($converter$i$i|0),1)|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 49;
     break;
    }
    $38 = ($35|0)==(0);
    if (!($38)) {
     $39 = ($35|0)>(0);
     if ($39) {
      __THREW__ = 0;
      invoke_viiii(416,($this|0),($p|0),($32|0),0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 49;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iiiiii(192,($this|0),($33|0),($34|0),($converter$i$i$i|0),0)|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 49;
       break;
      }
      $45 = ($42|0)==(0);
      if (!($45)) {
       $46 = ($42|0)>(0);
       if ($46) {
        __THREW__ = 0;
        invoke_viii(1652,($this|0),($21|0),0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 49;
         break;
        }
       } else {
        $49 = HEAP32[$converter$i$i$i>>2]|0;
        $50 = ($49|0)==(0|0);
        if (!($50)) {
         __THREW__ = 0;
         (invoke_iii($49|0,($21|0),($this|0))|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          label = 49;
          break;
         }
        }
       }
       __THREW__ = 0;
       invoke_vi(3389,($this|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 49;
        break;
       }
      }
     } else {
      $55 = HEAP32[$converter$i$i>>2]|0;
      $56 = ($55|0)==(0|0);
      if (!($56)) {
       __THREW__ = 0;
       (invoke_iii($55|0,($p|0),($this|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 49;
        break;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3389,($this|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 49;
      break;
     }
    }
    $61 = HEAP32[$p>>2]|0;
    HEAP32[$10>>2] = $61;
    $62 = HEAP8[$21>>0]|0;
    $63 = $62 & 1;
    $64 = ($63<<24>>24)==(0);
    if ($64) {
     $67 = $62&255;
     $68 = $67 >>> 1;
     $70 = $68;$82 = $22;
    } else {
     $65 = HEAP32[$30>>2]|0;
     $66 = HEAP32[$31>>2]|0;
     $70 = $66;$82 = $65;
    }
    $69 = ($70>>>0)>(2147483631);
    if ($69) {
     label = 22;
     break;
    }
    $73 = ($70>>>0)<(11);
    if ($73) {
     $74 = $70 << 1;
     $75 = $74&255;
     HEAP8[$20>>0] = $75;
     $__p$0$i$i$i$i$i$i = $23;
    } else {
     $76 = (($70) + 16)|0;
     $77 = $76 & -16;
     HEAP32[$8>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$8+0>>2]|0;
     $78 = (invoke_iiiiiii(102,($77|0),16,($$byval_copy21|0),0,(769120|0),79)|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if ($80) {
      label = 49;
      break;
     }
     HEAP32[$26>>2] = $78;
     $81 = $77 | 1;
     HEAP32[$20>>2] = $81;
     HEAP32[$29>>2] = $70;
     $__p$0$i$i$i$i$i$i = $78;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($82|0),($70|0))|0;
    $83 = (($__p$0$i$i$i$i$i$i) + ($70)|0);
    HEAP8[$83>>0] = 0;
    HEAP32[$7>>2] = $61;
    $84 = HEAP8[$20>>0]|0;
    $85 = $84 & 1;
    $86 = ($85<<24>>24)==(0);
    if ($86) {
     $89 = $84&255;
     $90 = $89 >>> 1;
     $104 = $23;$92 = $90;
    } else {
     $87 = HEAP32[$26>>2]|0;
     $88 = HEAP32[$29>>2]|0;
     $104 = $87;$92 = $88;
    }
    $91 = ($92>>>0)>(2147483631);
    if ($91) {
     label = 32;
     break;
    }
    $95 = ($92>>>0)<(11);
    if ($95) {
     $96 = $92 << 1;
     $97 = $96&255;
     HEAP8[$24>>0] = $97;
     $__p$0$i$i$i$i$i$i$i$i$i = $25;
    } else {
     $98 = (($92) + 16)|0;
     $99 = $98 & -16;
     HEAP32[$5>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$5+0>>2]|0;
     $100 = (invoke_iiiiiii(102,($99|0),16,($$byval_copy21|0),0,(769120|0),79)|0);
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      label = 52;
      break;
     }
     HEAP32[$27>>2] = $100;
     $103 = $99 | 1;
     HEAP32[$24>>2] = $103;
     HEAP32[$28>>2] = $92;
     $__p$0$i$i$i$i$i$i$i$i$i = $100;
    }
    _memcpy(($__p$0$i$i$i$i$i$i$i$i$i|0),($104|0),($92|0))|0;
    $105 = (($__p$0$i$i$i$i$i$i$i$i$i) + ($92)|0);
    HEAP8[$105>>0] = 0;
    HEAP32[$7>>2] = $61;
    __THREW__ = 0;
    invoke_viii(2011,($6|0),($data|0),($7|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     label = 42;
     break;
    }
    $108 = HEAP8[$24>>0]|0;
    $109 = $108 & 1;
    $110 = ($109<<24>>24)==(0);
    if (!($110)) {
     $111 = HEAP32[$27>>2]|0;
     HEAP32[$4>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,($111|0),($$byval_copy21|0));
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      label = 41;
      break;
     }
    }
    if (!($86)) {
     $126 = HEAP32[$26>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($126|0),($$byval_copy21|0));
     $127 = __THREW__; __THREW__ = 0;
     $128 = $127&1;
     if ($128) {
      label = 47;
      break;
     }
    }
    $131 = (($i$029) + 1)|0;
    $132 = HEAP32[$size>>2]|0;
    $133 = ($131|0)<($132|0);
    if ($133) {
     $i$029 = $131;
    } else {
     label = 57;
     break L4;
    }
   }
   do {
    if ((label|0) == 22) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      label = 50;
      break L4;
     }
     // unreachable;
    }
    else if ((label|0) == 32) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      $140 = ___cxa_find_matching_catch()|0;
      $141 = tempRet0;
      $eh$lpad$body$index9Z2D = $141;$eh$lpad$body$indexZ2D = $140;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 41) {
     $114 = ___cxa_find_matching_catch()|0;
     $115 = tempRet0;
     ___cxa_call_unexpected(($114|0));
     // unreachable;
    }
    else if ((label|0) == 42) {
     $116 = ___cxa_find_matching_catch()|0;
     $117 = tempRet0;
     $118 = HEAP8[$24>>0]|0;
     $119 = $118 & 1;
     $120 = ($119<<24>>24)==(0);
     if ($120) {
      $eh$lpad$body$index9Z2D = $117;$eh$lpad$body$indexZ2D = $116;
     } else {
      $121 = HEAP32[$27>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($121|0),($$byval_copy21|0));
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       $124 = ___cxa_find_matching_catch()|0;
       $125 = tempRet0;
       ___cxa_call_unexpected(($124|0));
       // unreachable;
      } else {
       $eh$lpad$body$index9Z2D = $117;$eh$lpad$body$indexZ2D = $116;
      }
     }
    }
    else if ((label|0) == 47) {
     $129 = ___cxa_find_matching_catch()|0;
     $130 = tempRet0;
     ___cxa_call_unexpected(($129|0));
     // unreachable;
    }
    else if ((label|0) == 49) {
     $134 = ___cxa_find_matching_catch()|0;
     $135 = tempRet0;
     $$pre30$pre$phiZZ2D = $21;$lpad$phi$index = $134;$lpad$phi$index2 = $135;
     label = 51;
     break L4;
    }
    else if ((label|0) == 52) {
     $138 = ___cxa_find_matching_catch()|0;
     $139 = tempRet0;
     $eh$lpad$body$index9Z2D = $139;$eh$lpad$body$indexZ2D = $138;
    }
   } while(0);
   if ($86) {
    $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;$$pre$phi31Z2D = $21;
   } else {
    $142 = HEAP32[$26>>2]|0;
    HEAP32[$1>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($142|0),($$byval_copy21|0));
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if ($144) {
     $145 = ___cxa_find_matching_catch()|0;
     $146 = tempRet0;
     ___cxa_call_unexpected(($145|0));
     // unreachable;
    } else {
     $$0 = $eh$lpad$body$index9Z2D;$$01 = $eh$lpad$body$indexZ2D;$$pre$phi31Z2D = $21;
    }
   }
  } else {
   label = 57;
  }
 } while(0);
 if ((label|0) == 57) {
  __THREW__ = 0;
  invoke_vi(3513,($this|0));
  $147 = __THREW__; __THREW__ = 0;
  $148 = $147&1;
  if ($148) {
   label = 50;
  } else {
   $149 = (($p) + 4|0);
   $150 = HEAP8[$149>>0]|0;
   $151 = $150 & 1;
   $152 = ($151<<24>>24)==(0);
   if ($152) {
    STACKTOP = sp;return;
   }
   $153 = (($p) + 12|0);
   $154 = HEAP32[$153>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($154|0),($$byval_copy21|0));
   $155 = __THREW__; __THREW__ = 0;
   $156 = $155&1;
   if ($156) {
    $157 = ___cxa_find_matching_catch()|0;
    $158 = tempRet0;
    ___cxa_call_unexpected(($157|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 50) {
  $136 = ___cxa_find_matching_catch()|0;
  $137 = tempRet0;
  $$pre$pre = (($p) + 4|0);
  $$pre30$pre$phiZZ2D = $$pre$pre;$lpad$phi$index = $136;$lpad$phi$index2 = $137;
  label = 51;
 }
 if ((label|0) == 51) {
  $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;$$pre$phi31Z2D = $$pre30$pre$phiZZ2D;
 }
 $159 = HEAP8[$$pre$phi31Z2D>>0]|0;
 $160 = $159 & 1;
 $161 = ($160<<24>>24)==(0);
 if ($161) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $162 = (($p) + 12|0);
 $163 = HEAP32[$162>>2]|0;
 HEAP32[$9>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$9+0>>2]|0;
 invoke_vii(2591,($163|0),($$byval_copy21|0));
 $164 = __THREW__; __THREW__ = 0;
 $165 = $164&1;
 if ($165) {
  $166 = ___cxa_find_matching_catch()|0;
  $167 = tempRet0;
  ___cxa_call_unexpected(($166|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$03 = 0, $i$15 = 0, $size = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,769192,769192,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $22 = (($9) + 4|0);
  HEAP32[$22>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 2;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $20 = 0;
  } else {
   $17 = $15;
   $18 = $9;
   $19 = (($17) - ($18))|0;
   $20 = $19;
  }
  HEAP32[$9>>2] = $20;
  $21 = (($9) + 4|0);
  HEAP32[$21>>2] = $15;
 }
 $23 = HEAP32[$data>>2]|0;
 $24 = $23;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = $26;
 $28 = (($23) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[$2>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($27) + ($30<<2)|0);
 $32 = HEAP32[$size>>2]|0;
 $33 = ($32|0)==(0);
 L11: do {
  if (!($33)) {
   $34 = HEAP32[$data>>2]|0;
   $35 = $34;
   $36 = HEAP32[$34>>2]|0;
   $37 = (($36) + ($35))|0;
   $38 = $37;
   $39 = (($34) + 4|0);
   HEAP32[$39>>2] = $38;
   $40 = HEAP32[580592>>2]|0;
   $41 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,769184,$40,0,0)|0);
   $42 = (($this) + 80|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__ZNK16TypeTreeIterator7GetNodeEv($43)|0);
   $45 = (($44) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($this) + 84|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$48>>2] = 0;
   $49 = ($41|0)==(2);
   if (!($49)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $106 = HEAP32[$data>>2]|0;
    $107 = $106;
    $108 = HEAP32[$106>>2]|0;
    $109 = (($108) + ($107))|0;
    $110 = $109;
    $111 = (($106) + 4|0);
    HEAP32[$111>>2] = $110;
    $112 = ($110|0)==($31|0);
    if ($112) {
     break;
    } else {
     $i$15 = $110;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$i$15,769184,0);
     $113 = (($i$15) + 4|0);
     $114 = ($113|0)==($31|0);
     if ($114) {
      break L11;
     } else {
      $i$15 = $113;
     }
    }
   }
   $50 = HEAP32[$42>>2]|0;
   $51 = (($50) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$data>>2]|0;
   $54 = $53;
   $55 = HEAP32[$53>>2]|0;
   $56 = (($55) + ($54))|0;
   $57 = $56;
   $58 = (($53) + 4|0);
   HEAP32[$58>>2] = $57;
   $59 = ($57|0)==($31|0);
   if (!($59)) {
    $60 = (($this) + 12|0);
    $61 = (($this) + 16|0);
    $62 = (($this) + 28|0);
    $63 = (($this) + 32|0);
    $64 = (($this) + 20|0);
    $i$03 = $57;
    while(1) {
     $65 = HEAP32[$47>>2]|0;
     $66 = HEAP32[$65>>2]|0;
     $67 = Math_imul($66, $46)|0;
     $68 = (($67) + ($52))|0;
     $69 = HEAP32[$42>>2]|0;
     $70 = (($69) + 20|0);
     HEAP32[$70>>2] = $68;
     $71 = (($69) + 12|0);
     HEAP32[$71>>2] = $68;
     $72 = (($69) + 24|0);
     __ZNK16TypeTreeIterator8ChildrenEv($1,$69);
     $73 = $1;
     $74 = $73;
     $75 = HEAP32[$74>>2]|0;
     $76 = (($73) + 4)|0;
     $77 = $76;
     $78 = HEAP32[$77>>2]|0;
     $79 = $72;
     $80 = $79;
     HEAP32[$80>>2] = $75;
     $81 = (($79) + 4)|0;
     $82 = $81;
     HEAP32[$82>>2] = $78;
     $83 = HEAP32[$47>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = (($84) + 1)|0;
     HEAP32[$83>>2] = $85;
     $86 = HEAP32[$42>>2]|0;
     $87 = (($86) + 12|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = HEAP32[$61>>2]|0;
     $90 = HEAP32[$62>>2]|0;
     $91 = HEAP32[$63>>2]|0;
     $92 = Math_imul($91, $90)|0;
     $$sum$i$i$i = (($88) - ($92))|0;
     $93 = (($89) + ($$sum$i$i$i)|0);
     HEAP32[$60>>2] = $93;
     $94 = ($$sum$i$i$i|0)<(0);
     if ($94) {
      label = 14;
     } else {
      $$sum1$i$i$i = (($$sum$i$i$i) + 4)|0;
      $95 = (($89) + ($$sum1$i$i$i)|0);
      $96 = HEAP32[$64>>2]|0;
      $97 = ($95>>>0)>($96>>>0);
      if ($97) {
       label = 14;
      } else {
       $98 = HEAP32[$93>>2]|0;
       HEAP32[$i$03>>2] = $98;
       HEAP32[$60>>2] = $95;
      }
     }
     if ((label|0) == 14) {
      label = 0;
      __ZN12CachedReader15UpdateReadCacheEPvj($60,$i$03,4);
     }
     $99 = HEAP32[$this>>2]|0;
     $100 = $99 & 512;
     $101 = ($100|0)==(0);
     if (!($101)) {
      $102 = HEAP32[$i$03>>2]|0;
      $103 = (_llvm_bswap_i32(($102|0))|0);
      HEAP32[$i$03>>2] = $103;
     }
     $104 = (($i$03) + 4|0);
     $105 = ($104|0)==($31|0);
     if ($105) {
      break;
     } else {
      $i$03 = $104;
     }
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferINSt3__13mapIj8UnityStrNS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i = 0, $p$i$i$i$i = 0, $size$i$i = 0, $size$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $size$i$i$i$i$i = sp;
 $p$i$i$i$i = sp + 36|0;
 $0 = sp + 24|0;
 $size$i$i = sp + 28|0;
 $p$i$i = sp + 8|0;
 $1 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$1,$data,$metaFlag);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,769192,769192,$size$i$i,0);
 ;HEAP32[$p$i$i+0>>2]=0|0;HEAP32[$p$i$i+4>>2]=0|0;HEAP32[$p$i$i+8>>2]=0|0;HEAP32[$p$i$i+12>>2]=0|0;
 $2 = HEAP32[580608>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(86,($this|0),(769184|0),($2|0),($p$i$i|0),0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = HEAP32[580576>>2]|0;
  $6 = HEAP32[580752>>2]|0;
  __THREW__ = 0;
  invoke_viiiii(86,($this|0),($5|0),($6|0),($p$i$i|0),0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = (($this) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $12 = (($this) + 20|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($11) + (($13*24)|0)|0) + 12|0);
   HEAP32[$14>>2] = 4;
   __THREW__ = 0;
   invoke_vi(3390,($this|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($p$i$i) + 4|0);
    $18 = HEAP32[580656>>2]|0;
    $19 = HEAP32[580712>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(86,($this|0),($18|0),($19|0),($17|0),0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_viiiii(87,($this|0),(769192|0),(769192|0),($size$i$i$i$i$i|0),1);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = HEAP32[580552>>2]|0;
      __THREW__ = 0;
      invoke_viiiii(86,($this|0),(769184|0),($24|0),($p$i$i$i$i|0),0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       $27 = HEAP32[$9>>2]|0;
       $28 = HEAP32[$27>>2]|0;
       $29 = HEAP32[$12>>2]|0;
       $30 = ((($28) + (($29*24)|0)|0) + 12|0);
       HEAP32[$30>>2] = 1;
       __THREW__ = 0;
       invoke_vi(3390,($this|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        __THREW__ = 0;
        invoke_vi(3391,($this|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         __THREW__ = 0;
         invoke_vi(3392,($this|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          __THREW__ = 0;
          invoke_vi(3390,($this|0));
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if (!($38)) {
           __THREW__ = 0;
           invoke_vi(3390,($this|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            __THREW__ = 0;
            invoke_vi(3391,($this|0));
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if (!($42)) {
             $43 = HEAP8[$17>>0]|0;
             $44 = $43 & 1;
             $45 = ($44<<24>>24)==(0);
             if ($45) {
              __ZN13ProxyTransfer11EndTransferEv($this);
              STACKTOP = sp;return;
             }
             $46 = (($p$i$i) + 12|0);
             $47 = HEAP32[$46>>2]|0;
             HEAP32[$size$i$i$i$i$i>>2] = 59;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$size$i$i$i$i$i+0>>2]|0;
             invoke_vii(2591,($47|0),($$byval_copy1|0));
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              $50 = ___cxa_find_matching_catch()|0;
              $51 = tempRet0;
              ___cxa_call_unexpected(($50|0));
              // unreachable;
             } else {
              __ZN13ProxyTransfer11EndTransferEv($this);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $52 = ___cxa_find_matching_catch()|0;
 $53 = tempRet0;
 $54 = (($p$i$i) + 4|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = $55 & 1;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  ___resumeException($52|0);
  // unreachable;
 }
 $58 = (($p$i$i) + 12|0);
 $59 = HEAP32[$58>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($59|0),($$byval_copy1|0));
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 if ($61) {
  $62 = ___cxa_find_matching_catch()|0;
  $63 = tempRet0;
  ___cxa_call_unexpected(($62|0));
  // unreachable;
 } else {
  ___resumeException($52|0);
  // unreachable;
 }
}
function __ZN8AnimatorC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $c$01$i$i$i = 0, $c$01$i$i$i4$i = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$i$index = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy14 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy14,$mode);
 $4 = (($this) + 28|0);
 HEAP8[$4>>0] = 1;
 $5 = (($this) + 29|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 32|0);
 HEAP32[$this>>2] = ((769200 + 8|0));
 HEAP32[$6>>2] = ((769200 + 168|0));
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = -1;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = -1;
 $9 = (($this) + 44|0);
 HEAP8[$9>>0] = 0;
 $10 = (($this) + 48|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
 $11 = HEAP32[628296>>2]|0;
 $12 = (($this) + 64|0);
 HEAP32[$12>>2] = ((741984 + 8|0));
 $13 = (($this) + 68|0);
 HEAP32[$13>>2] = $11;
 $14 = (($this) + 72|0);
 dest=$14+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$14+44>>0]=0|0;
 $15 = (($this) + 120|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 124|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 128|0);
 HEAP32[$17>>2] = ((768664 + 8|0));
 $18 = (($this) + 136|0);
 HEAP32[$18>>2] = 0;
 $19 = (($this) + 140|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 148|0);
 HEAP32[$20>>2] = 262144;
 $21 = (($this) + 132|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 152|0);
 dest=$22+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$22+44>>0]=0|0;
 $23 = (($this) + 200|0);
 ;HEAP32[$23+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[616680+8>>2]|0;
 $24 = (($this) + 212|0);
 HEAPF32[$24>>2] = Math_fround(0.0);
 $25 = (($this) + 216|0);
 HEAPF32[$25>>2] = Math_fround(0.0);
 $26 = (($this) + 220|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 224|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($this) + 228|0);
 ;HEAP32[$28+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[616680+8>>2]|0;
 $29 = (($this) + 240|0);
 ;HEAP32[$29+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[616680+8>>2]|0;
 $30 = (($this) + 252|0);
 $31 = (($this) + 292|0);
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP32[$30+16>>2]=0|0;HEAP32[$30+20>>2]=0|0;
 HEAPF32[$31>>2] = Math_fround(-1.0);
 $32 = (($this) + 296|0);
 HEAP32[$32>>2] = -1;
 $33 = (($this) + 300|0);
 ;HEAP32[$33+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[616680+8>>2]|0;
 $34 = (($this) + 312|0);
 HEAPF32[$34>>2] = Math_fround(0.0);
 $35 = (($this) + 316|0);
 HEAPF32[$35>>2] = Math_fround(0.0);
 $36 = (($this) + 320|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($this) + 324|0);
 HEAPF32[$37>>2] = Math_fround(1.0);
 $38 = (($this) + 328|0);
 _memmove(($38|0),(616696|0),12)|0;
 $39 = (($this) + 340|0);
 $40 = (($this) + 348|0);
 ;HEAP32[$39+0>>2]=0|0;HEAP16[$39+4>>1]=0|0;HEAP8[$39+6>>0]=0|0;
 HEAPF32[$40>>2] = Math_fround(1.0);
 $41 = (($this) + 352|0);
 HEAP8[$41>>0] = 1;
 $42 = (($this) + 353|0);
 HEAP8[$42>>0] = 1;
 $43 = (($this) + 356|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 364|0);
 HEAP32[$44>>2] = 0;
 $45 = (($this) + 368|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 360|0);
 HEAP32[$46>>2] = 61;
 $47 = (($this) + 372|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 376|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 380|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 384|0);
 HEAP8[$50>>0] = 1;
 $51 = (($this) + 388|0);
 HEAP32[$51>>2] = $this;
 $52 = (($this) + 392|0);
 HEAP32[$52>>2] = 0;
 $53 = (($this) + 396|0);
 HEAP32[$53>>2] = -1;
 $54 = (($this) + 400|0);
 HEAP32[$54>>2] = $this;
 $55 = (($this) + 404|0);
 HEAP32[$55>>2] = 0;
 $56 = (($this) + 408|0);
 HEAP32[$56>>2] = -1;
 $57 = (($this) + 412|0);
 $58 = HEAP32[$label>>2]|0;
 HEAP32[$2>>2] = $58;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(3394,($57|0),($$byval_copy14|0));
 $59 = __THREW__; __THREW__ = 0;
 $60 = $59&1;
 if (!($60)) {
  $61 = (($this) + 452|0);
  HEAP32[$61>>2] = 0;
  $62 = (($this) + 456|0);
  HEAPF32[$62>>2] = Math_fround(0.0);
  $63 = (($this) + 460|0);
  HEAPF32[$63>>2] = Math_fround(0.0);
  $64 = (($this) + 464|0);
  HEAP8[$64>>0] = 1;
  $65 = (($this) + 465|0);
  HEAP8[$65>>0] = 1;
  $66 = (($this) + 468|0);
  HEAP32[$66>>2] = 0;
  $67 = (($this) + 476|0);
  HEAP32[$67>>2] = 0;
  $68 = (($this) + 480|0);
  HEAP32[$68>>2] = 0;
  $69 = (($this) + 472|0);
  HEAP32[$69>>2] = 61;
  STACKTOP = sp;return;
 }
 $70 = ___cxa_find_matching_catch()|0;
 $71 = tempRet0;
 $72 = HEAP32[$47>>2]|0;
 $73 = ($72|0)==(0|0);
 if (!($73)) {
  $74 = HEAP32[$48>>2]|0;
  $75 = ($74|0)==($72|0);
  if (!($75)) {
   $__new_last2$i$i$i$i$i = $72;
   $scevgep$i$i$i$i$i = (($74) + -4|0);
   $76 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($76)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $77 = $uglygep3$i$i$i$i$i >>> 2;
   $78 = $77 ^ -1;
   $scevgep4$i$i$i$i$i = (($74) + ($78<<2)|0);
   HEAP32[$48>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($72);
 }
 $79 = HEAP32[$45>>2]|0;
 $80 = ($79|0)>(-1);
 if ($80) {
  $81 = HEAP32[$43>>2]|0;
  $82 = HEAP32[$46>>2]|0;
  HEAP32[$0>>2] = $82;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($81|0),($$byval_copy14|0));
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if (!($84)) {
   HEAP32[$43>>2] = 0;
   label = 10;
  }
 } else {
  label = 10;
 }
 L13: do {
  if ((label|0) == 10) {
   $85 = (($this) + 184|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = ($86|0)==(0|0);
   if ($87) {
    label = 12;
   } else {
    __THREW__ = 0;
    invoke_vi(3695,($86|0));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     label = 19;
    } else {
     label = 12;
    }
   }
   L17: do {
    if ((label|0) == 12) {
     $90 = (($this) + 180|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = ($91|0)==(0|0);
     if (!($92)) {
      __THREW__ = 0;
      invoke_vi(3696,($91|0));
      $93 = __THREW__; __THREW__ = 0;
      $94 = $93&1;
      if ($94) {
       label = 19;
       break;
      }
     }
     dest=$22+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$22+44>>0]=0|0;
     $95 = HEAP32[$18>>2]|0;
     $96 = ($95|0)==(0|0);
     L22: do {
      if (!($96)) {
       $c$01$i$i$i = $95;
       while(1) {
        $97 = HEAP32[$c$01$i$i$i>>2]|0;
        $98 = HEAP32[628296>>2]|0;
        HEAP32[$1>>2] = $98;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($c$01$i$i$i|0),($$byval_copy14|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         break;
        }
        $101 = ($97|0)==(0|0);
        if ($101) {
         break L22;
        } else {
         $c$01$i$i$i = $97;
        }
       }
       $102 = ___cxa_find_matching_catch(0|0)|0;
       $103 = tempRet0;
       $lpad$phi$i$index = $102;
       break L17;
      }
     } while(0);
     $116 = (($this) + 144|0);
     HEAP32[$17>>2] = ((768664 + 8|0));
     HEAP32[$18>>2] = 0;
     HEAP32[$19>>2] = 0;
     HEAP32[$116>>2] = 0;
     __THREW__ = 0;
     invoke_vi(3410,($this|0));
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      break L13;
     }
     ___resumeException($70|0);
     // unreachable;
    }
   } while(0);
   if ((label|0) == 19) {
    $104 = ___cxa_find_matching_catch(0|0)|0;
    $105 = tempRet0;
    $lpad$phi$i$index = $104;
   }
   HEAP32[$17>>2] = ((768664 + 8|0));
   $106 = HEAP32[$18>>2]|0;
   $107 = ($106|0)==(0|0);
   L33: do {
    if (!($107)) {
     $c$01$i$i$i4$i = $106;
     while(1) {
      $108 = HEAP32[$c$01$i$i$i4$i>>2]|0;
      $109 = HEAP32[628296>>2]|0;
      HEAP32[$0>>2] = $109;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($c$01$i$i$i4$i|0),($$byval_copy14|0));
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       break;
      }
      $112 = ($108|0)==(0|0);
      if ($112) {
       break L33;
      } else {
       $c$01$i$i$i4$i = $108;
      }
     }
     $114 = ___cxa_find_matching_catch(0|0)|0;
     $115 = tempRet0;
     ___clang_call_terminate($114);
     // unreachable;
    }
   } while(0);
   HEAP32[$18>>2] = 0;
   HEAP32[$19>>2] = 0;
   $113 = (($this) + 144|0);
   HEAP32[$113>>2] = 0;
   $eh$lpad$body$indexZ2D = $lpad$phi$i$index;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 $119 = ___cxa_find_matching_catch(0|0)|0;
 $120 = tempRet0;
 $eh$lpad$body$indexZ2D = $119;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN8Animator17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 388|0);
 __ZN12UserListNode5ClearEv($0);
 $1 = (($this) + 400|0);
 __ZN12UserListNode5ClearEv($1);
 STACKTOP = sp;return;
}
function __ZN8Animator13AwakeFromLoadE17AwakeFromLoadMode($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $$not$i$i = 0, $$not1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge$i$i = 0, $brmerge2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$mode);
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 2) | (($1|0) == 0)) {
  $2 = (($this) + 36|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(-1);
  if ($4) {
   $5 = ($1|0)==(1);
   if ($5) {
    label = 4;
   } else {
    label = 5;
   }
  }
 } else if ((($1|0) == 1)) {
  label = 4;
 } else {
  label = 5;
 }
 if ((label|0) == 4) {
  $6 = (($this) + 40|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(-1);
  if ($8) {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $9 = HEAP32[$this>>2]|0;
  $10 = (($9) + 128|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095]($this);
 }
 __ZN8Animator12CreateObjectEv($this);
 __ZN8Animator27InitializeVisibilityCullingEv($this);
 $12 = (($this) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $25 = 0;
 } else {
  $15 = (($this) + 29|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)!=(0);
  $25 = $17;
 }
 $18 = (($this) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(-1);
 if ($20) {
  $21 = (($this) + 40|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)!=(-1);
  $24 = $23;
 } else {
  $24 = 1;
 }
 $$not$i$i = $24 ^ 1;
 $brmerge$i$i = $25 | $$not$i$i;
 if (!($brmerge$i$i)) {
  $26 = HEAP32[$this>>2]|0;
  $27 = (($26) + 128|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vi[$28 & 4095]($this);
  STACKTOP = sp;return;
 }
 $$not1$i$i = $25 ^ 1;
 $brmerge2$i$i = $24 | $$not1$i$i;
 if ($brmerge2$i$i) {
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$this>>2]|0;
 $30 = (($29) + 124|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vi[$31 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZN8Animator16CheckConsistencyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN8Animator5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 345|0);
 HEAP8[$1>>0] = 0;
 $2 = (($this) + 52|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 465|0);
 HEAP8[$3>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN8Animator23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,769384,769392,$this,0);
 __ZN8Animator8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Animator23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,769384,769392,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN8Animator8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8Animator23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Animator8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Animator23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Animator8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Animator23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Animator8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN8Animator23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 $12 = (($this) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 $18 = (FUNCTION_TABLE_iiii[$16 & 2047]($14,$13,$17)|0);
 $19 = HEAP8[$9>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  STACKTOP = sp;return;
 }
 HEAP32[$12>>2] = $18;
 STACKTOP = sp;return;
}
function __Z22RegisterClass_Animatorv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(95,236,237,0,238);
 STACKTOP = sp;return;
}
function __ZN8Animator13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 HEAP8[$0>>0] = 16;
 $3 = (($0) + 1|0);
 $4 = $3;
 $5 = $4;
 HEAP8[$5>>0]=1835626049&255;HEAP8[$5+1>>0]=(1835626049>>8)&255;HEAP8[$5+2>>0]=(1835626049>>16)&255;HEAP8[$5+3>>0]=1835626049>>24;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP8[$7>>0]=1919906913&255;HEAP8[$7+1>>0]=(1919906913>>8)&255;HEAP8[$7+2>>0]=(1919906913>>16)&255;HEAP8[$7+3>>0]=1919906913>>24;
 $8 = (($0) + 9|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,95,8,($0|0),484,(2586|0),0,0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return;
 }
}
function __ZN8Animator15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(95,564104,2012,100000);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(95,566032,2013,0);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(95,566088,2014,0);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(95,566184,2015,0);
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(95,564640,2016,2);
 __ZN15AnimatorManager15InitializeClassEv();
 __ZN7mecanim9animation18ControllerConstant15InitializeClassEv();
 __ZN7mecanim9animation14AvatarConstant15InitializeClassEv();
 __ZN7mecanim12statemachine13StateConstant15InitializeClassEv();
 __ZN7mecanim13crc32_table_tILj79764919EE10init_tableEv();
 __ZN7mecanim9animation26InitializeMuscleClipTablesEv();
 __ZN10HumanTrait15InitializeClassEv();
 STACKTOP = sp;return;
}
function __ZN8Animator12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15AnimatorManager12CleanupClassEv();
 __ZN10HumanTrait12CleanupClassEv();
 STACKTOP = sp;return;
}
function __ZN8Animator7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(484,$$byval_copy2,1,16,769408,97)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(2017,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(769408|0),97);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK8Animator25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 95;
}
function __ZN8Animator27InitializeVisibilityCullingEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__ZNK5Unity10GameObject8IsActiveEv($2)|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 356|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 364|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + ($8<<2)|0);
 $10 = ($8|0)==(0);
 if (!($10)) {
  $i$01$i = $6;
  while(1) {
   $11 = HEAP32[$i$01$i>>2]|0;
   __ZN6Object11RemoveEventEPFvPvS0_iES0_($11,2018,$this);
   $12 = (($i$01$i) + 4|0);
   $13 = ($12|0)==($9|0);
   if ($13) {
    break;
   } else {
    $i$01$i = $12;
   }
  }
 }
 $14 = (($this) + 368|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(-1);
 if ($16) {
  $17 = HEAP32[$5>>2]|0;
  $18 = (($this) + 360|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$0>>2] = $19;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($17,$$byval_copy);
  HEAP32[$5>>2] = 0;
 }
 HEAP32[$7>>2] = 0;
 HEAP32[$14>>2] = 0;
 $20 = (($this) + 48|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $23 = (($this) + 44|0);
  HEAP8[$23>>0] = 1;
  STACKTOP = sp;return;
 }
 $24 = HEAP32[$1>>2]|0;
 $25 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($24)|0);
 __ZN8Animator34RecomputeContainedRenderersRecurseER9Transform($this,$25);
 $26 = HEAP32[$7>>2]|0;
 $27 = ($26|0)==(0);
 if (!($27)) {
  STACKTOP = sp;return;
 }
 $28 = (($this) + 44|0);
 HEAP8[$28>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN8Animator12AddToManagerEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetAnimatorManagerv()|0);
 __ZN15AnimatorManager11AddAnimatorER8Animator($0,$this);
 STACKTOP = sp;return;
}
function __ZN8Animator17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetAnimatorManagerv()|0);
 __ZN15AnimatorManager14RemoveAnimatorER8Animator($0,$this);
 STACKTOP = sp;return;
}
function __ZN8Animator10DeactivateEN5Unity19DeactivateOperationE($this,$operation) {
 $this = $this|0;
 $operation = $operation|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 __ZN9Behaviour10DeactivateEN5Unity19DeactivateOperationE($this,$operation);
 __ZN8Animator11ClearObjectEv($this);
 $1 = (($this) + 356|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 364|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + ($4<<2)|0);
 $6 = ($4|0)==(0);
 if (!($6)) {
  $i$01$i = $2;
  while(1) {
   $7 = HEAP32[$i$01$i>>2]|0;
   __ZN6Object11RemoveEventEPFvPvS0_iES0_($7,2018,$this);
   $8 = (($i$01$i) + 4|0);
   $9 = ($8|0)==($5|0);
   if ($9) {
    break;
   } else {
    $i$01$i = $8;
   }
  }
 }
 $10 = (($this) + 368|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)>(-1);
 if (!($12)) {
  HEAP32[$3>>2] = 0;
  HEAP32[$10>>2] = 0;
  STACKTOP = sp;return;
 }
 $13 = HEAP32[$1>>2]|0;
 $14 = (($this) + 360|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$0>>2] = $15;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($13,$$byval_copy);
 HEAP32[$1>>2] = 0;
 HEAP32[$3>>2] = 0;
 HEAP32[$10>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN8Animator11ClearObjectEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $c$01$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 480|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if ($3) {
  $4 = (($this) + 468|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($this) + 472|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($5,$$byval_copy1);
  HEAP32[$4>>2] = 0;
 }
 $8 = (($this) + 476|0);
 HEAP32[$8>>2] = 0;
 HEAP32[$1>>2] = 0;
 __ZN6Object11InvokeEventEi($this,3);
 $9 = (($this) + 120|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  __Z21CompleteFenceInternalR8JobFence($9);
 }
 $12 = (($this) + 96|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 64|0);
 __ZN7mecanim9animation25DestroyAnimationSetMemoryEPNS0_18AnimationSetMemoryERNS_6memory9AllocatorE($13,$14);
 $15 = (($this) + 100|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN11UnityEngine9Animation30DestroyAnimatorGenericBindingsEPNS0_30AnimatorGenericBindingConstantERN7mecanim6memory9AllocatorE($16,$14);
 $17 = (($this) + 104|0);
 $18 = HEAP32[$17>>2]|0;
 __ZN11UnityEngine9Animation28DestroyAvatarBindingConstantEPNS0_21AvatarBindingConstantERN7mecanim6memory9AllocatorE($18,$14);
 $19 = (($this) + 88|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = (($20) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  __ZN7mecanim9animation26DestroyControllerWorkspaceEPNS0_19ControllerWorkspaceERNS_6memory9AllocatorE($23,$14);
 }
 $24 = (($this) + 80|0);
 $25 = HEAP32[$24>>2]|0;
 __ZN7mecanim9animation19DestroyAvatarOutputEPNS0_12AvatarOutputERNS_6memory9AllocatorE($25,$14);
 $26 = (($this) + 76|0);
 $27 = HEAP32[$26>>2]|0;
 __ZN7mecanim9animation18DestroyAvatarInputEPNS0_11AvatarInputERNS_6memory9AllocatorE($27,$14);
 $28 = (($this) + 112|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 $31 = (($this) + 84|0);
 if ($30) {
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $34 = HEAP32[$32>>2]|0;
   $35 = ($34|0)==(0);
   if (!($35)) {
    $36 = $32;
    $37 = (($34) + ($36))|0;
    $38 = $37;
    $39 = (($32) + 4|0);
    HEAP32[$39>>2] = $38;
    __ZN7mecanim9animation23DestroyControllerMemoryEPNS0_16ControllerMemoryERNS_6memory9AllocatorE($38,$14);
   }
  }
 }
 $40 = HEAP32[$31>>2]|0;
 __ZN7mecanim9animation19DestroyAvatarMemoryEPNS0_12AvatarMemoryERNS_6memory9AllocatorE($40,$14);
 $41 = HEAP32[$19>>2]|0;
 __ZN7mecanim9animation22DestroyAvatarWorkspaceEPNS0_15AvatarWorkspaceERNS_6memory9AllocatorE($41,$14);
 $42 = (($this) + 116|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 $$pre2 = (($this) + 72|0);
 if (!($44)) {
  $45 = HEAP32[$$pre2>>2]|0;
  __ZN7mecanim9animation21DestroyAvatarConstantEPNS0_14AvatarConstantERNS_6memory9AllocatorE($45,$14);
  HEAP8[$42>>0] = 0;
 }
 HEAP32[$$pre2>>2] = 0;
 HEAP32[$31>>2] = 0;
 HEAP32[$26>>2] = 0;
 HEAP32[$24>>2] = 0;
 $46 = (($this) + 400|0);
 ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;HEAP32[$19+16>>2]=0|0;HEAP32[$19+20>>2]=0|0;HEAP32[$19+24>>2]=0|0;
 __ZN12UserListNode5ClearEv($46);
 $47 = (($this) + 388|0);
 __ZN12UserListNode5ClearEv($47);
 $48 = (($this) + 152|0);
 $49 = (($this) + 184|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  __ZN11UnityEngine9Animation30UnregisterAvatarBindingObjectsEPNS0_21AvatarBindingConstantE($50);
 }
 $52 = (($this) + 180|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if (!($54)) {
  __ZN11UnityEngine9Animation31UnregisterGenericBindingObjectsEPNS0_30AnimatorGenericBindingConstantE($53);
 }
 dest=$48+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$48+44>>0]=0|0;
 $55 = (($this) + 136|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0|0);
 if ($57) {
  HEAP32[$55>>2] = 0;
  $61 = (($this) + 140|0);
  HEAP32[$61>>2] = 0;
  $62 = (($this) + 144|0);
  HEAP32[$62>>2] = 0;
  STACKTOP = sp;return;
 }
 $c$01$i$i = $56;
 while(1) {
  $58 = HEAP32[$c$01$i$i>>2]|0;
  $59 = HEAP32[628296>>2]|0;
  HEAP32[$0>>2] = $59;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($c$01$i$i,$$byval_copy1);
  $60 = ($58|0)==(0|0);
  if ($60) {
   break;
  } else {
   $c$01$i$i = $58;
  }
 }
 HEAP32[$55>>2] = 0;
 $61 = (($this) + 140|0);
 HEAP32[$61>>2] = 0;
 $62 = (($this) + 144|0);
 HEAP32[$62>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN8Animator16TransformChangedEi($this,$change) {
 $this = $this|0;
 $change = $change|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$idx$val$i = Math_fround(0), $pos$idx1$i = 0, $pos$idx1$val$i = Math_fround(0), $pos$idx2$i = 0, $pos$idx2$val$i = Math_fround(0), $scale$idx$val$i = Math_fround(0), $scale$idx1$i = 0, $scale$idx1$val$i = Math_fround(0), $scale$idx2$i = 0, $scale$idx2$val$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 28|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 136|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($this)|0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($8)|0);
 $10 = $change & 1;
 $11 = ($10|0)==(0);
 if (!($11)) {
  __ZNK9Transform11GetPositionEv($0,$9);
  $12 = (($this) + 84|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $pos$idx$val$i = Math_fround(HEAPF32[$0>>2]);
   $pos$idx1$i = (($0) + 4|0);
   $pos$idx1$val$i = Math_fround(HEAPF32[$pos$idx1$i>>2]);
   $pos$idx2$i = (($0) + 8|0);
   $pos$idx2$val$i = Math_fround(HEAPF32[$pos$idx2$i>>2]);
   $15 = (($13) + 8|0);
   HEAPF32[$15>>2] = $pos$idx$val$i;
   $16 = (($13) + 12|0);
   HEAPF32[$16>>2] = $pos$idx1$val$i;
   $17 = (($13) + 16|0);
   HEAPF32[$17>>2] = $pos$idx2$val$i;
   $18 = (($13) + 20|0);
   HEAPF32[$18>>2] = Math_fround(0.0);
  }
 }
 $19 = $change & 2;
 $20 = ($19|0)==(0);
 if (!($20)) {
  __ZNK9Transform11GetRotationEv($1,$9);
  $21 = (($this) + 84|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $24 = Math_fround(HEAPF32[$1>>2]);
   $25 = (($1) + 4|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = (($1) + 8|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = (($1) + 12|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = (($22) + 24|0);
   HEAPF32[$31>>2] = $24;
   $32 = (($22) + 28|0);
   HEAPF32[$32>>2] = $26;
   $33 = (($22) + 32|0);
   HEAPF32[$33>>2] = $28;
   $34 = (($22) + 36|0);
   HEAPF32[$34>>2] = $30;
  }
 }
 $35 = $change & 8;
 $36 = ($35|0)==(0);
 if ($36) {
  STACKTOP = sp;return;
 }
 __ZNK9Transform18GetWorldScaleLossyEv($2,$9);
 $37 = (($this) + 84|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 }
 $scale$idx$val$i = Math_fround(HEAPF32[$2>>2]);
 $scale$idx1$i = (($2) + 4|0);
 $scale$idx1$val$i = Math_fround(HEAPF32[$scale$idx1$i>>2]);
 $scale$idx2$i = (($2) + 8|0);
 $scale$idx2$val$i = Math_fround(HEAPF32[$scale$idx2$i>>2]);
 $40 = (($38) + 40|0);
 HEAPF32[$40>>2] = $scale$idx$val$i;
 $41 = (($38) + 44|0);
 HEAPF32[$41>>2] = $scale$idx1$val$i;
 $42 = (($38) + 48|0);
 HEAPF32[$42>>2] = $scale$idx2$val$i;
 $43 = (($38) + 52|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN8Animator12CreateObjectEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre43 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $avatarConstant$0 = 0, $phitmp$i = 0, $phitmp$i15 = 0, $pos$i$i$i$i32 = 0, $temp$0$i = 0, $temp$0$i22 = 0, $temp$0$i29 = 0, $temp$0$i36 = 0, $temp$0$i6 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i32 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = sp + 20|0;
 $6 = sp + 24|0;
 $7 = (($this) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (__ZNK5Unity10GameObject8IsActiveEv($8)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 __ZN8Animator11ClearObjectEv($this);
 $11 = (($this) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if ($13) {
   $avatarConstant$0 = 0;
  } else {
   HEAP32[$6>>2] = $12;
   $14 = HEAP32[560624>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    label = 12;
   } else {
    $16 = (($14) + 36|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($14) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($17|0)==($19|0);
    do {
     if ($20) {
      $21 = (($14) + 28|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($14) + 32|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($22) + ($24<<3)|0);
      $41 = $25;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i32,$14,$6);
      $26 = HEAP32[$pos$i$i$i$i32>>2]|0;
      $27 = ($26|0)==(-1);
      $28 = (($14) + 28|0);
      $29 = HEAP32[$28>>2]|0;
      if ($27) {
       $30 = (($14) + 32|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = (($29) + ($31<<3)|0);
       $41 = $32;
       break;
      } else {
       $33 = (($29) + ($26<<3)|0);
       $41 = $33;
       break;
      }
     }
    } while(0);
    $34 = HEAP32[560624>>2]|0;
    $35 = (($34) + 28|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($34) + 32|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + ($38<<3)|0);
    $40 = ($41|0)==($39|0);
    if ($40) {
     label = 12;
    } else {
     $42 = (($41) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      label = 12;
     } else {
      $49 = $34;
     }
    }
   }
   if ((label|0) == 12) {
    $45 = HEAP32[$11>>2]|0;
    $46 = (__Z31ReadObjectFromPersistentManageri($45)|0);
    $phitmp$i = ($46|0)==(0|0);
    if ($phitmp$i) {
     $avatarConstant$0 = 0;
     break;
    }
    $$pre43 = HEAP32[560624>>2]|0;
    $49 = $$pre43;
   }
   $47 = HEAP32[$11>>2]|0;
   HEAP32[$5>>2] = $47;
   $48 = ($49|0)==(0|0);
   if ($48) {
    label = 22;
   } else {
    $50 = (($49) + 36|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($49) + 4|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($51|0)==($53|0);
    do {
     if ($54) {
      $55 = (($49) + 28|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = (($49) + 32|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (($56) + ($58<<3)|0);
      $75 = $59;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i32,$49,$5);
      $60 = HEAP32[$pos$i$i$i$i32>>2]|0;
      $61 = ($60|0)==(-1);
      $62 = (($49) + 28|0);
      $63 = HEAP32[$62>>2]|0;
      if ($61) {
       $64 = (($49) + 32|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = (($63) + ($65<<3)|0);
       $75 = $66;
       break;
      } else {
       $67 = (($63) + ($60<<3)|0);
       $75 = $67;
       break;
      }
     }
    } while(0);
    $68 = HEAP32[560624>>2]|0;
    $69 = (($68) + 28|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = (($68) + 32|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($70) + ($72<<3)|0);
    $74 = ($75|0)==($73|0);
    if ($74) {
     label = 22;
    } else {
     $76 = (($75) + 4|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      label = 22;
     } else {
      $temp$0$i = $77;
     }
    }
   }
   if ((label|0) == 22) {
    $79 = HEAP32[$11>>2]|0;
    $80 = (__Z31ReadObjectFromPersistentManageri($79)|0);
    $temp$0$i = $80;
   }
   $81 = (__ZN6Avatar8GetAssetEv($temp$0$i)|0);
   $82 = HEAP32[$11>>2]|0;
   HEAP32[$4>>2] = $82;
   $83 = HEAP32[560624>>2]|0;
   $84 = ($83|0)==(0|0);
   if ($84) {
    label = 31;
   } else {
    $85 = (($83) + 36|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($83) + 4|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = ($86|0)==($88|0);
    do {
     if ($89) {
      $90 = (($83) + 28|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = (($83) + 32|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = (($91) + ($93<<3)|0);
      $110 = $94;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i32,$83,$4);
      $95 = HEAP32[$pos$i$i$i$i32>>2]|0;
      $96 = ($95|0)==(-1);
      $97 = (($83) + 28|0);
      $98 = HEAP32[$97>>2]|0;
      if ($96) {
       $99 = (($83) + 32|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = (($98) + ($100<<3)|0);
       $110 = $101;
       break;
      } else {
       $102 = (($98) + ($95<<3)|0);
       $110 = $102;
       break;
      }
     }
    } while(0);
    $103 = HEAP32[560624>>2]|0;
    $104 = (($103) + 28|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($103) + 32|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($105) + ($107<<3)|0);
    $109 = ($110|0)==($108|0);
    if ($109) {
     label = 31;
    } else {
     $111 = (($110) + 4|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ($112|0)==(0|0);
     if ($113) {
      label = 31;
     } else {
      $temp$0$i6 = $112;
     }
    }
   }
   if ((label|0) == 31) {
    $114 = HEAP32[$11>>2]|0;
    $115 = (__Z31ReadObjectFromPersistentManageri($114)|0);
    $temp$0$i6 = $115;
   }
   $116 = (($this) + 388|0);
   $117 = (($temp$0$i6) + 72|0);
   __ZN8UserList7AddUserER12UserListNode($117,$116);
   $avatarConstant$0 = $81;
  }
 } while(0);
 $118 = (($this) + 64|0);
 $119 = (($this) + 72|0);
 __ZN8Animator25SetupAvatarMecanimDataSetEPKN7mecanim9animation14AvatarConstantERNS0_6memory9AllocatorERNS_14MecanimDataSetE($this,$avatarConstant$0,$118,$119);
 $120 = (($this) + 60|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($121|0)==(0);
 if ($122) {
  STACKTOP = sp;return;
 }
 HEAP32[$3>>2] = $121;
 $123 = HEAP32[560624>>2]|0;
 $124 = ($123|0)==(0|0);
 if ($124) {
  label = 42;
 } else {
  $125 = (($123) + 36|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (($123) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($126|0)==($128|0);
  do {
   if ($129) {
    $130 = (($123) + 28|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($123) + 32|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = (($131) + ($133<<3)|0);
    $150 = $134;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i32,$123,$3);
    $135 = HEAP32[$pos$i$i$i$i32>>2]|0;
    $136 = ($135|0)==(-1);
    $137 = (($123) + 28|0);
    $138 = HEAP32[$137>>2]|0;
    if ($136) {
     $139 = (($123) + 32|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = (($138) + ($140<<3)|0);
     $150 = $141;
     break;
    } else {
     $142 = (($138) + ($135<<3)|0);
     $150 = $142;
     break;
    }
   }
  } while(0);
  $143 = HEAP32[560624>>2]|0;
  $144 = (($143) + 28|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = (($143) + 32|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = (($145) + ($147<<3)|0);
  $149 = ($150|0)==($148|0);
  if ($149) {
   label = 42;
  } else {
   $151 = (($150) + 4|0);
   $152 = HEAP32[$151>>2]|0;
   $153 = ($152|0)==(0|0);
   if ($153) {
    label = 42;
   } else {
    $158 = $143;
   }
  }
 }
 do {
  if ((label|0) == 42) {
   $154 = HEAP32[$120>>2]|0;
   $155 = (__Z31ReadObjectFromPersistentManageri($154)|0);
   $phitmp$i15 = ($155|0)==(0|0);
   if ($phitmp$i15) {
    STACKTOP = sp;return;
   } else {
    $$pre = HEAP32[560624>>2]|0;
    $158 = $$pre;
    break;
   }
  }
 } while(0);
 $156 = HEAP32[$120>>2]|0;
 HEAP32[$2>>2] = $156;
 $157 = ($158|0)==(0|0);
 if ($157) {
  label = 52;
 } else {
  $159 = (($158) + 36|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = (($158) + 4|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = ($160|0)==($162|0);
  do {
   if ($163) {
    $164 = (($158) + 28|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = (($158) + 32|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = (($165) + ($167<<3)|0);
    $184 = $168;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i32,$158,$2);
    $169 = HEAP32[$pos$i$i$i$i32>>2]|0;
    $170 = ($169|0)==(-1);
    $171 = (($158) + 28|0);
    $172 = HEAP32[$171>>2]|0;
    if ($170) {
     $173 = (($158) + 32|0);
     $174 = HEAP32[$173>>2]|0;
     $175 = (($172) + ($174<<3)|0);
     $184 = $175;
     break;
    } else {
     $176 = (($172) + ($169<<3)|0);
     $184 = $176;
     break;
    }
   }
  } while(0);
  $177 = HEAP32[560624>>2]|0;
  $178 = (($177) + 28|0);
  $179 = HEAP32[$178>>2]|0;
  $180 = (($177) + 32|0);
  $181 = HEAP32[$180>>2]|0;
  $182 = (($179) + ($181<<3)|0);
  $183 = ($184|0)==($182|0);
  if ($183) {
   label = 52;
  } else {
   $185 = (($184) + 4|0);
   $186 = HEAP32[$185>>2]|0;
   $187 = ($186|0)==(0|0);
   if ($187) {
    label = 52;
   } else {
    $temp$0$i22 = $186;
   }
  }
 }
 if ((label|0) == 52) {
  $188 = HEAP32[$120>>2]|0;
  $189 = (__Z31ReadObjectFromPersistentManageri($188)|0);
  $temp$0$i22 = $189;
 }
 $190 = (($this) + 400|0);
 $191 = (($temp$0$i22) + 28|0);
 __ZN8UserList7AddUserER12UserListNode($191,$190);
 $192 = HEAP32[$120>>2]|0;
 HEAP32[$1>>2] = $192;
 $193 = HEAP32[560624>>2]|0;
 $194 = ($193|0)==(0|0);
 if ($194) {
  label = 61;
 } else {
  $195 = (($193) + 36|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = (($193) + 4|0);
  $198 = HEAP32[$197>>2]|0;
  $199 = ($196|0)==($198|0);
  do {
   if ($199) {
    $200 = (($193) + 28|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = (($193) + 32|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = (($201) + ($203<<3)|0);
    $220 = $204;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i32,$193,$1);
    $205 = HEAP32[$pos$i$i$i$i32>>2]|0;
    $206 = ($205|0)==(-1);
    $207 = (($193) + 28|0);
    $208 = HEAP32[$207>>2]|0;
    if ($206) {
     $209 = (($193) + 32|0);
     $210 = HEAP32[$209>>2]|0;
     $211 = (($208) + ($210<<3)|0);
     $220 = $211;
     break;
    } else {
     $212 = (($208) + ($205<<3)|0);
     $220 = $212;
     break;
    }
   }
  } while(0);
  $213 = HEAP32[560624>>2]|0;
  $214 = (($213) + 28|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = (($213) + 32|0);
  $217 = HEAP32[$216>>2]|0;
  $218 = (($215) + ($217<<3)|0);
  $219 = ($220|0)==($218|0);
  if ($219) {
   label = 61;
  } else {
   $221 = (($220) + 4|0);
   $222 = HEAP32[$221>>2]|0;
   $223 = ($222|0)==(0|0);
   if ($223) {
    label = 61;
   } else {
    $temp$0$i29 = $222;
   }
  }
 }
 if ((label|0) == 61) {
  $224 = HEAP32[$120>>2]|0;
  $225 = (__Z31ReadObjectFromPersistentManageri($224)|0);
  $temp$0$i29 = $225;
 }
 $226 = HEAP32[$temp$0$i29>>2]|0;
 $227 = (($226) + 92|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = (FUNCTION_TABLE_ii[$228 & 4095]($temp$0$i29)|0);
 $230 = HEAP32[$120>>2]|0;
 HEAP32[$0>>2] = $230;
 $231 = HEAP32[560624>>2]|0;
 $232 = ($231|0)==(0|0);
 if ($232) {
  label = 70;
 } else {
  $233 = (($231) + 36|0);
  $234 = HEAP32[$233>>2]|0;
  $235 = (($231) + 4|0);
  $236 = HEAP32[$235>>2]|0;
  $237 = ($234|0)==($236|0);
  do {
   if ($237) {
    $238 = (($231) + 28|0);
    $239 = HEAP32[$238>>2]|0;
    $240 = (($231) + 32|0);
    $241 = HEAP32[$240>>2]|0;
    $242 = (($239) + ($241<<3)|0);
    $258 = $242;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i32,$231,$0);
    $243 = HEAP32[$pos$i$i$i$i32>>2]|0;
    $244 = ($243|0)==(-1);
    $245 = (($231) + 28|0);
    $246 = HEAP32[$245>>2]|0;
    if ($244) {
     $247 = (($231) + 32|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = (($246) + ($248<<3)|0);
     $258 = $249;
     break;
    } else {
     $250 = (($246) + ($243<<3)|0);
     $258 = $250;
     break;
    }
   }
  } while(0);
  $251 = HEAP32[560624>>2]|0;
  $252 = (($251) + 28|0);
  $253 = HEAP32[$252>>2]|0;
  $254 = (($251) + 32|0);
  $255 = HEAP32[$254>>2]|0;
  $256 = (($253) + ($255<<3)|0);
  $257 = ($258|0)==($256|0);
  if ($257) {
   label = 70;
  } else {
   $259 = (($258) + 4|0);
   $260 = HEAP32[$259>>2]|0;
   $261 = ($260|0)==(0|0);
   if ($261) {
    label = 70;
   } else {
    $temp$0$i36 = $260;
   }
  }
 }
 if ((label|0) == 70) {
  $262 = HEAP32[$120>>2]|0;
  $263 = (__Z31ReadObjectFromPersistentManageri($262)|0);
  $temp$0$i36 = $263;
 }
 $264 = HEAP32[$temp$0$i36>>2]|0;
 $265 = (($264) + 96|0);
 $266 = HEAP32[$265>>2]|0;
 $267 = (FUNCTION_TABLE_ii[$266 & 4095]($temp$0$i36)|0);
 $268 = ($267|0)==(0|0);
 if ($268) {
  STACKTOP = sp;return;
 }
 __ZN8Animator29SetupControllerMecanimDataSetEPKN7mecanim9animation18ControllerConstantEPKN11UnityEngine9Animation20AnimationSetBindingsERNS0_6memory9AllocatorERNS_14MecanimDataSetE($this,$229,$267,$118,$119);
 __ZN8Animator15SetupBehavioursEv($this);
 __ZN8Animator24SetupAnimationClipsCacheEv($this);
 STACKTOP = sp;return;
}
function __ZZN8Animator15InitializeClassEvEN38FunctorImpl_Animator_kTransformChanged4CallEPviR11MessageData($object,$messageID,$messageData) {
 $object = $object|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($messageData) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$object>>2]|0;
 $3 = (($2) + 132|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($object,$1);
 STACKTOP = sp;return;
}
function __ZZN8Animator15InitializeClassEvEN49FunctorImpl_Animator_kDidModifyAnimatorController4CallE_0PviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Animator11ClearObjectEv($object);
 STACKTOP = sp;return;
}
function __ZZN8Animator15InitializeClassEvEN37FunctorImpl_Animator_kDidModifyMotion4CallE_1PviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Animator11ClearObjectEv($object);
 STACKTOP = sp;return;
}
function __ZZN8Animator15InitializeClassEvEN37FunctorImpl_Animator_kDidModifyAvatar4CallE_2PviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8Animator11ClearObjectEv($object);
 STACKTOP = sp;return;
}
function __ZZN8Animator15InitializeClassEvEN37FunctorImpl_Animator_kDidAddComponent4CallE_3PviR11MessageData($object,$messageID,$messageData) {
 $object = $object|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($messageData) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 >>> 21;
 $6 = HEAP32[560640>>2]|0;
 $7 = Math_imul($6, $5)|0;
 $8 = (($7) + 25)|0;
 $9 = $8 >> 5;
 $10 = $9 << 5;
 $11 = (($8) - ($10))|0;
 $12 = HEAP32[560632>>2]|0;
 $13 = (($12) + ($9<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = 1 << $11;
 $16 = $15 & $14;
 $17 = ($16|0)==(0);
 if ($17) {
  STACKTOP = sp;return;
 }
 __ZN8Animator27InitializeVisibilityCullingEv($object);
 STACKTOP = sp;return;
}
function __ZN8Animator25SetupAvatarMecanimDataSetEPKN7mecanim9animation14AvatarConstantERNS0_6memory9AllocatorERNS_14MecanimDataSetE($this,$avatarConstant,$allocator,$outMecanimDataSet) {
 $this = $this|0;
 $avatarConstant = $avatarConstant|0;
 $allocator = $allocator|0;
 $outMecanimDataSet = $outMecanimDataSet|0;
 var $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $$idx2 = 0, $$idx2$val = Math_fround(0), $$idx3$val = Math_fround(0), $$idx4 = 0, $$idx4$val = Math_fround(0), $$idx5 = 0, $$idx5$val = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0;
 var $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 HEAP32[$outMecanimDataSet>>2] = $avatarConstant;
 $4 = ($avatarConstant|0)==(0|0);
 if ($4) {
  $5 = (($outMecanimDataSet) + 44|0);
  HEAP8[$5>>0] = 1;
  $6 = (($0) + 28|0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;
  HEAPF32[$6>>2] = Math_fround(1.0);
  $7 = (($0) + 32|0);
  HEAPF32[$7>>2] = Math_fround(1.0);
  $8 = (($0) + 36|0);
  HEAPF32[$8>>2] = Math_fround(1.0);
  $9 = (($0) + 40|0);
  HEAPF32[$9>>2] = Math_fround(1.0);
  $10 = (($0) + 44|0);
  HEAPF32[$10>>2] = Math_fround(1.0);
  $11 = (__ZN7mecanim9animation20CreateAvatarConstantEPNS_8skeleton8SkeletonEPNS1_12SkeletonPoseES5_PNS_5human5HumanES3_iRKN4math5xformERNS_6memory9AllocatorE(0,0,0,0,0,-1,$0,$allocator)|0);
  HEAP32[$outMecanimDataSet>>2] = $11;
  $13 = $11;
 } else {
  $13 = $avatarConstant;
 }
 $12 = (($outMecanimDataSet) + 40|0);
 HEAP32[$12>>2] = 0;
 $14 = (__ZN7mecanim9animation18CreateAvatarMemoryEPKNS0_14AvatarConstantERNS_6memory9AllocatorE($13,$allocator)|0);
 $15 = (($outMecanimDataSet) + 12|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$outMecanimDataSet>>2]|0;
 $17 = (__ZN7mecanim9animation17CreateAvatarInputEPKNS0_14AvatarConstantERNS_6memory9AllocatorE($16,$allocator)|0);
 $18 = (($outMecanimDataSet) + 4|0);
 HEAP32[$18>>2] = $17;
 $19 = HEAP32[$outMecanimDataSet>>2]|0;
 $20 = (__ZN7mecanim9animation21CreateAvatarWorkspaceEPKNS0_14AvatarConstantERNS_6memory9AllocatorE($19,$allocator)|0);
 $21 = (($outMecanimDataSet) + 16|0);
 HEAP32[$21>>2] = $20;
 $22 = HEAP32[$outMecanimDataSet>>2]|0;
 $23 = (($this) + 465|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)!=(0);
 $26 = (($this) + 345|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)!=(0);
 $29 = (__ZN7mecanim9animation18CreateAvatarOutputEPKNS0_14AvatarConstantEbbRNS_6memory9AllocatorE($22,$25,$28,$allocator)|0);
 $30 = (($outMecanimDataSet) + 8|0);
 HEAP32[$30>>2] = $29;
 $31 = (__ZN8Animator13GetAvatarRootEv($this)|0);
 $32 = HEAP8[$23>>0]|0;
 $33 = ($32<<24>>24)==(0);
 $34 = HEAP32[$outMecanimDataSet>>2]|0;
 if ($33) {
  $37 = (__ZN11UnityEngine9Animation30CreateAvatarBindingConstantOptER9TransformPKN7mecanim9animation14AvatarConstantERNS3_6memory9AllocatorE($31,$34,$allocator)|0);
  $38 = (($outMecanimDataSet) + 32|0);
  HEAP32[$38>>2] = $37;
 } else {
  $35 = (__ZN11UnityEngine9Animation27CreateAvatarBindingConstantER9TransformPKN7mecanim9animation14AvatarConstantERNS3_6memory9AllocatorE($31,$34,$allocator)|0);
  $36 = (($outMecanimDataSet) + 32|0);
  HEAP32[$36>>2] = $35;
 }
 $39 = (($this) + 24|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($40)|0);
 $42 = HEAP32[$15>>2]|0;
 __ZNK9Transform11GetPositionEv($1,$41);
 $$idx3$val = Math_fround(HEAPF32[$1>>2]);
 $$idx4 = (($1) + 4|0);
 $$idx4$val = Math_fround(HEAPF32[$$idx4>>2]);
 $$idx5 = (($1) + 8|0);
 $$idx5$val = Math_fround(HEAPF32[$$idx5>>2]);
 $43 = (($42) + 8|0);
 HEAPF32[$43>>2] = $$idx3$val;
 $44 = (($42) + 12|0);
 HEAPF32[$44>>2] = $$idx4$val;
 $45 = (($42) + 16|0);
 HEAPF32[$45>>2] = $$idx5$val;
 $46 = (($42) + 20|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 $47 = HEAP32[$15>>2]|0;
 __ZNK9Transform11GetRotationEv($2,$41);
 $48 = Math_fround(HEAPF32[$2>>2]);
 $49 = (($2) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($2) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($2) + 12|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($47) + 24|0);
 HEAPF32[$55>>2] = $48;
 $56 = (($47) + 28|0);
 HEAPF32[$56>>2] = $50;
 $57 = (($47) + 32|0);
 HEAPF32[$57>>2] = $52;
 $58 = (($47) + 36|0);
 HEAPF32[$58>>2] = $54;
 $59 = HEAP32[$15>>2]|0;
 __ZNK9Transform18GetWorldScaleLossyEv($3,$41);
 $$idx$val = Math_fround(HEAPF32[$3>>2]);
 $$idx1 = (($3) + 4|0);
 $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
 $$idx2 = (($3) + 8|0);
 $$idx2$val = Math_fround(HEAPF32[$$idx2>>2]);
 $60 = (($59) + 40|0);
 HEAPF32[$60>>2] = $$idx$val;
 $61 = (($59) + 44|0);
 HEAPF32[$61>>2] = $$idx1$val;
 $62 = (($59) + 48|0);
 HEAPF32[$62>>2] = $$idx2$val;
 $63 = (($59) + 52|0);
 HEAPF32[$63>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN8Animator29SetupControllerMecanimDataSetEPKN7mecanim9animation18ControllerConstantEPKN11UnityEngine9Animation20AnimationSetBindingsERNS0_6memory9AllocatorERNS_14MecanimDataSetE($this,$controllerConstant,$animationSetBindings,$allocator,$outMecanimDataSet) {
 $this = $this|0;
 $controllerConstant = $controllerConstant|0;
 $animationSetBindings = $animationSetBindings|0;
 $allocator = $allocator|0;
 $outMecanimDataSet = $outMecanimDataSet|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $layerIter$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($outMecanimDataSet) + 20|0);
 HEAP32[$0>>2] = $controllerConstant;
 $1 = (($outMecanimDataSet) + 36|0);
 HEAP32[$1>>2] = $animationSetBindings;
 $2 = (__ZN8Animator13GetAvatarRootEv($this)|0);
 $3 = (($this) + 465|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = HEAP32[$outMecanimDataSet>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = (($this) + 464|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 if ($5) {
  $13 = (__ZN11UnityEngine9Animation32CreateAnimatorGenericBindingsOptERKNS0_20AnimationSetBindingsER9TransformPKN7mecanim9animation14AvatarConstantEPKNS7_18ControllerConstantEbRNS6_6memory9AllocatorE($animationSetBindings,$2,$6,$7,$10,$allocator)|0);
  $14 = (($outMecanimDataSet) + 28|0);
  HEAP32[$14>>2] = $13;
  $17 = $13;
 } else {
  $11 = (__ZN11UnityEngine9Animation29CreateAnimatorGenericBindingsERKNS0_20AnimationSetBindingsER9TransformPKN7mecanim9animation14AvatarConstantEPKNS7_18ControllerConstantEbRNS6_6memory9AllocatorE($animationSetBindings,$2,$6,$7,$10,$allocator)|0);
  $12 = (($outMecanimDataSet) + 28|0);
  HEAP32[$12>>2] = $11;
  $17 = $11;
 }
 $15 = (($outMecanimDataSet) + 28|0);
 $16 = (($17) + 32|0);
 $18 = HEAP32[$16>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($outMecanimDataSet) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$0>>2]|0;
 $23 = HEAP32[$outMecanimDataSet>>2]|0;
 $24 = (($animationSetBindings) + 36|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 345|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)!=(0);
 $29 = (__ZN7mecanim9animation22CreateControllerMemoryEPKNS0_18ControllerConstantEPKNS0_14AvatarConstantEPKNS0_12AnimationSetEPKNS_18ValueArrayConstantEbRNS_6memory9AllocatorE($22,$23,$25,$19,$28,$allocator)|0);
 $30 = ($29|0)==(0|0);
 if ($30) {
  $34 = 0;
 } else {
  $31 = $29;
  $32 = $21;
  $33 = (($31) - ($32))|0;
  $34 = $33;
 }
 HEAP32[$21>>2] = $34;
 $35 = (($21) + 4|0);
 HEAP32[$35>>2] = $29;
 $36 = HEAP32[$24>>2]|0;
 $37 = HEAP32[$15>>2]|0;
 $38 = (($37) + 36|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)!=(0);
 $41 = (__ZN7mecanim9animation24CreateAnimationSetMemoryEPKNS0_12AnimationSetEbRNS_6memory9AllocatorE($36,$40,$allocator)|0);
 $42 = (($outMecanimDataSet) + 24|0);
 HEAP32[$42>>2] = $41;
 $43 = HEAP32[$0>>2]|0;
 $44 = HEAP32[$outMecanimDataSet>>2]|0;
 $45 = HEAP32[$24>>2]|0;
 $46 = HEAP8[$26>>0]|0;
 $47 = ($46<<24>>24)!=(0);
 $48 = (__ZN7mecanim9animation25CreateControllerWorkspaceEPKNS0_18ControllerConstantEPKNS0_14AvatarConstantEPKNS0_12AnimationSetEPKNS_18ValueArrayConstantEbRNS_6memory9AllocatorE($43,$44,$45,$19,$47,$allocator)|0);
 $49 = (($outMecanimDataSet) + 16|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($50) + 24|0);
 HEAP32[$51>>2] = $48;
 $52 = (__ZN7mecanim16CreateValueArrayEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($19,$allocator)|0);
 $53 = (($outMecanimDataSet) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[$54>>2] = $52;
 $55 = HEAP32[$0>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0);
 if ($57) {
  $$0$i = 0;
 } else {
  $58 = HEAP32[$allocator>>2]|0;
  $59 = HEAP32[$58>>2]|0;
  $60 = ($56*20)|0;
  $61 = (FUNCTION_TABLE_iiii[$59 & 2047]($allocator,$60,4)|0);
  $62 = ($61|0)==(0|0);
  if ($62) {
   $$0$i = 0;
  } else {
   $63 = (($61) + (($56*20)|0)|0);
   $64 = $61;
   while(1) {
    ;HEAP32[$64+0>>2]=0|0;HEAP32[$64+4>>2]=0|0;HEAP32[$64+8>>2]=0|0;HEAP32[$64+12>>2]=0|0;HEAP32[$64+16>>2]=0|0;
    $65 = (($64) + 20|0);
    $66 = ($65|0)==($63|0);
    if ($66) {
     $$0$i = $61;
     break;
    } else {
     $64 = $65;
    }
   }
  }
 }
 $67 = (($outMecanimDataSet) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 HEAP32[$68>>2] = $$0$i;
 $69 = HEAP32[$15>>2]|0;
 $70 = (($69) + 32|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + 4|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$53>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_($73,$75);
 $76 = HEAP32[$0>>2]|0;
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0);
 if ($78) {
  STACKTOP = sp;return;
 } else {
  $layerIter$01 = 0;
 }
 while(1) {
  $79 = HEAP32[$15>>2]|0;
  $80 = (($79) + 32|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($81) + 4|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = HEAP32[$20>>2]|0;
  $85 = $84;
  $86 = HEAP32[$84>>2]|0;
  $87 = (($86) + ($85))|0;
  $88 = $87;
  $89 = (($84) + 4|0);
  HEAP32[$89>>2] = $88;
  $90 = (($88) + 24|0);
  $91 = $90;
  $92 = HEAP32[$90>>2]|0;
  $93 = (($91) + ($92))|0;
  $94 = $93;
  $95 = (($88) + 28|0);
  HEAP32[$95>>2] = $94;
  $96 = (($94) + (($layerIter$01*36)|0)|0);
  $97 = $96;
  $98 = HEAP32[$96>>2]|0;
  $99 = (($97) + ($98))|0;
  $100 = $99;
  $101 = ((($94) + (($layerIter$01*36)|0)|0) + 4|0);
  HEAP32[$101>>2] = $100;
  __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_($83,$100);
  $102 = (($layerIter$01) + 1)|0;
  $103 = HEAP32[$0>>2]|0;
  $104 = HEAP32[$103>>2]|0;
  $105 = ($102>>>0)<($104>>>0);
  if ($105) {
   $layerIter$01 = $102;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN8Animator13UpdateAvatarsEPPS_jfbbf($inputAvatars,$inputSize,$deltaTime,$doFKMove,$doRetargetIKWrite,$realDeltaTime) {
 $inputAvatars = $inputAvatars|0;
 $inputSize = $inputSize|0;
 $deltaTime = Math_fround($deltaTime);
 $doFKMove = $doFKMove|0;
 $doRetargetIKWrite = $doRetargetIKWrite|0;
 $realDeltaTime = Math_fround($realDeltaTime);
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy50 = 0, $$lcssa131252258269279286 = 0, $$lcssa133249259268280285 = 0, $$lcssa135246260267281284 = 0, $$lcssa137245261266 = 0, $$lcssa139242262265282283 = 0, $$lcssa194229233236 = 0, $$lcssa196227 = 0, $$lcssa198222234235 = 0, $$lcssa253257270278287 = 0, $$ph$ph$ph$ph$ph$ph$ph$ph$ph = 0, $$ph154$ph$ph$ph$ph$ph = 0, $$ph154$ph$ph$ph$ph$ph190 = 0, $$ph155$ph$ph$ph$ph$ph = 0, $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = 0;
 var $$ph76$ph$ph$ph$ph$ph$ph$ph$ph125 = 0, $$ph77$ph$ph$ph$ph$ph$ph$ph$ph = 0, $$ph77$ph$ph$ph$ph$ph$ph$ph$ph126 = 0, $$ph78$ph$ph$ph$ph$ph$ph$ph$ph = 0, $$ph78$ph$ph$ph$ph$ph$ph$ph$ph127 = 0, $$ph79$ph$ph$ph$ph$ph$ph$ph$ph = 0, $$phi$trans$insert = 0, $$phi$trans$insert219 = 0, $$pre = 0, $$pre220 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = Math_fround(0), $605 = 0, $606 = 0, $607 = Math_fround(0), $608 = 0, $609 = 0, $61 = 0, $610 = 0;
 var $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0;
 var $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0);
 var $98 = 0, $99 = 0, $allocated = 0, $data$i$i = 0, $i$0200 = 0, $i1$0186 = 0, $i11$0123 = 0, $i13$0117 = 0, $i15$0112 = 0, $i17$092 = 0, $i19$098 = 0, $i2$0180 = 0, $i21$0102 = 0, $i23$085 = 0, $i26$080 = 0, $i3$0173 = 0, $i5$0166 = 0, $i7$0159 = 0, $i9$0142 = 0, $layerCount$0143 = 0;
 var $layerCount$1 = 0, $layerIter$0106 = 0, $lpad$phi$index = 0, $lpad$phi$index25 = 0, $lpad$phi158$index = 0, $lpad$phi158$index7 = 0, $stateMachineBehaviourPlayer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy50 = sp + 80|0;
 $data$i$i = sp + 68|0;
 $0 = sp + 64|0;
 $1 = sp + 60|0;
 $2 = sp + 56|0;
 $3 = sp + 52|0;
 $4 = sp + 48|0;
 $5 = sp + 44|0;
 $6 = sp + 40|0;
 $stateMachineBehaviourPlayer$i = sp + 24|0;
 $7 = sp + 20|0;
 $8 = sp + 16|0;
 $9 = sp + 12|0;
 $10 = sp + 8|0;
 $11 = sp + 4|0;
 $12 = sp;
 $allocated = sp + 36|0;
 L1: do {
  if ($doFKMove) {
   $13 = HEAP32[628512>>2]|0;
   $14 = ($inputSize|0)==(0);
   L3: do {
    if ($14) {
     $$lcssa194229233236 = 0;$$lcssa196227 = 0;$$lcssa198222234235 = 0;$635 = 1;
     label = 47;
    } else {
     $15 = $inputSize << 2;
     HEAP32[$12>>2] = $13;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$12+0>>2]|0;
     $16 = (invoke_iiiiiiii(108,(0|0),($15|0),4,($$byval_copy50|0),0,(769408|0),370)|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      $$ph154$ph$ph$ph$ph$ph190 = $inputSize;$$ph155$ph$ph$ph$ph$ph = 0;
      label = 28;
     } else {
      $49 = 0;$51 = $inputSize;$59 = $16;$i$0200 = 0;
      L6: while(1) {
       $21 = (($inputAvatars) + ($i$0200<<2)|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = HEAP32[$22>>2]|0;
       $24 = (($23) + 136|0);
       $25 = HEAP32[$24>>2]|0;
       __THREW__ = 0;
       $26 = (invoke_ii($25|0,($22|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        $$ph154$ph$ph$ph$ph$ph = $51;
        label = 27;
        break;
       }
       if (!($26)) {
        __THREW__ = 0;
        invoke_vi(3697,($22|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         $$ph154$ph$ph$ph$ph$ph = $51;
         label = 27;
         break;
        }
       }
       $31 = HEAP32[$22>>2]|0;
       $32 = (($31) + 136|0);
       $33 = HEAP32[$32>>2]|0;
       __THREW__ = 0;
       $34 = (invoke_ii($33|0,($22|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        $$ph154$ph$ph$ph$ph$ph = $51;
        label = 27;
        break;
       }
       do {
        if ($34) {
         $37 = (($22) + 48|0);
         $38 = HEAP32[$37>>2]|0;
         $39 = ($38|0)==(2);
         if ($39) {
          $40 = (($22) + 84|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = (($41) + 172|0);
          $43 = HEAP8[$42>>0]|0;
          $44 = ($43<<24>>24)==(0);
          if ($44) {
           $45 = (($22) + 44|0);
           $46 = HEAP8[$45>>0]|0;
           $47 = ($46<<24>>24)==(0);
           if ($47) {
            $20 = $49;$636 = $51;$92 = $59;
            break;
           }
          }
         }
         $48 = (($49) + 1)|0;
         $50 = $51 & 2147483647;
         $52 = ($48>>>0)>($50>>>0);
         do {
          if ($52) {
           $53 = $51 << 1;
           $54 = ($53|0)==(0);
           $55 = $54 ? 1 : $53;
           $56 = ($50>>>0)<($55>>>0);
           if ($56) {
            $57 = ($51|0)>(-1);
            if ($57) {
             $58 = $55 << 2;
             HEAP32[$10>>2] = $13;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$10+0>>2]|0;
             $60 = (invoke_iiiiiiii(108,($59|0),($58|0),4,($$byval_copy50|0),0,(769408|0),370)|0);
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              $$ph154$ph$ph$ph$ph$ph = $55;
              label = 27;
              break L6;
             }
             $637 = $55;$69 = $60;
             break;
            } else {
             $63 = $55 << 2;
             HEAP32[$11>>2] = $13;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$11+0>>2]|0;
             $64 = (invoke_iiiiiii(102,($63|0),4,($$byval_copy50|0),0,(769408|0),352)|0);
             $65 = __THREW__; __THREW__ = 0;
             $66 = $65&1;
             if ($66) {
              $$ph154$ph$ph$ph$ph$ph = $51;
              label = 27;
              break L6;
             }
             $67 = $48 << 2;
             _memcpy(($64|0),($59|0),($67|0))|0;
             $637 = $55;$69 = $64;
             break;
            }
           } else {
            $637 = $51;$69 = $59;
           }
          } else {
           $637 = $51;$69 = $59;
          }
         } while(0);
         $68 = (($69) + ($49<<2)|0);
         HEAP32[$68>>2] = $22;
         $20 = $48;$636 = $637;$92 = $69;
        } else {
         $20 = $49;$636 = $51;$92 = $59;
        }
       } while(0);
       $89 = (($i$0200) + 1)|0;
       $90 = ($89>>>0)<($inputSize>>>0);
       if ($90) {
        $49 = $20;$51 = $636;$59 = $92;$i$0200 = $89;
       } else {
        break;
       }
      }
      if ((label|0) == 27) {
       $80 = ___cxa_find_matching_catch()|0;
       $81 = tempRet0;
       $85 = $$ph154$ph$ph$ph$ph$ph;$86 = $59;$lpad$phi158$index = $80;$lpad$phi158$index7 = $81;
       break;
      }
      $19 = ($20|0)==(0);
      if ($19) {
       $$lcssa194229233236 = $636;$$lcssa196227 = 0;$$lcssa198222234235 = $92;$635 = 1;
       label = 47;
      } else {
       $i1$0186 = 0;
       while(1) {
        $91 = (($92) + ($i1$0186<<2)|0);
        $93 = HEAP32[$91>>2]|0;
        $94 = (($93) + 52|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = ($95|0)==(2);
        $97 = $96 ? $realDeltaTime : $deltaTime;
        __THREW__ = 0;
        invoke_vif(189,($93|0),(+$97));
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         label = 26;
         break;
        }
        $100 = (($93) + 120|0);
        $101 = HEAP32[$100>>2]|0;
        $102 = ($101|0)==(0|0);
        if (!($102)) {
         __THREW__ = 0;
         invoke_vi(3402,($100|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          label = 26;
          break;
         }
        }
        $105 = (($93) + 84|0);
        $106 = HEAP32[$105>>2]|0;
        $107 = (($106) + 173|0);
        HEAP8[$107>>0] = 0;
        $108 = (($i1$0186) + 1)|0;
        $109 = ($108>>>0)<($20>>>0);
        if ($109) {
         $i1$0186 = $108;
        } else {
         break;
        }
       }
       if ((label|0) == 26) {
        $78 = ___cxa_find_matching_catch()|0;
        $79 = tempRet0;
        $85 = $636;$86 = $92;$lpad$phi158$index = $78;$lpad$phi158$index7 = $79;
        break;
       }
       if ($19) {
        $$lcssa194229233236 = $636;$$lcssa196227 = 0;$$lcssa198222234235 = $92;$635 = 1;
        label = 47;
       } else {
        $i2$0180 = 0;
        while(1) {
         $110 = (($92) + ($i2$0180<<2)|0);
         $111 = HEAP32[$110>>2]|0;
         $112 = (($111) + 384|0);
         $113 = HEAP8[$112>>0]|0;
         $114 = ($113<<24>>24)==(0);
         if ($114) {
          $115 = (($111) + 32|0);
          __THREW__ = 0;
          invoke_vii(3395,($stateMachineBehaviourPlayer$i|0),($115|0));
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           label = 25;
           break;
          }
          $118 = (($111) + 76|0);
          $119 = HEAP32[$118>>2]|0;
          $120 = (($119) + 24|0);
          HEAP32[$120>>2] = $stateMachineBehaviourPlayer$i;
          $121 = (($111) + 72|0);
          $122 = HEAP32[$121>>2]|0;
          $123 = HEAP32[$118>>2]|0;
          $124 = (($111) + 80|0);
          $125 = HEAP32[$124>>2]|0;
          $126 = (($111) + 84|0);
          $127 = HEAP32[$126>>2]|0;
          $128 = (($111) + 88|0);
          $129 = HEAP32[$128>>2]|0;
          $130 = (($111) + 92|0);
          $131 = HEAP32[$130>>2]|0;
          $132 = (($111) + 108|0);
          $133 = HEAP32[$132>>2]|0;
          $134 = (($133) + 36|0);
          $135 = HEAP32[$134>>2]|0;
          __THREW__ = 0;
          invoke_viiiiiii(69,($122|0),($123|0),($125|0),($127|0),($129|0),($131|0),($135|0));
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           label = 25;
           break;
          }
         }
         $138 = (($i2$0180) + 1)|0;
         $139 = ($138>>>0)<($20>>>0);
         if ($139) {
          $i2$0180 = $138;
         } else {
          break;
         }
        }
        if ((label|0) == 25) {
         $76 = ___cxa_find_matching_catch()|0;
         $77 = tempRet0;
         $85 = $636;$86 = $92;$lpad$phi158$index = $76;$lpad$phi158$index7 = $77;
         break;
        }
        if ($19) {
         $$lcssa194229233236 = $636;$$lcssa196227 = 0;$$lcssa198222234235 = $92;$635 = 1;
         label = 47;
        } else {
         $i3$0173 = 0;
         while(1) {
          $140 = (($92) + ($i3$0173<<2)|0);
          $141 = HEAP32[$140>>2]|0;
          $142 = HEAP32[$141>>2]|0;
          $143 = (($142) + 136|0);
          $144 = HEAP32[$143>>2]|0;
          __THREW__ = 0;
          $145 = (invoke_ii($144|0,($141|0))|0);
          $146 = __THREW__; __THREW__ = 0;
          $147 = $146&1;
          if ($147) {
           break;
          }
          if ($145) {
           __THREW__ = 0;
           invoke_vi(3698,($141|0));
           $148 = __THREW__; __THREW__ = 0;
           $149 = $148&1;
           if ($149) {
            break;
           }
          }
          $150 = (($i3$0173) + 1)|0;
          $151 = ($150>>>0)<($20>>>0);
          if ($151) {
           $i3$0173 = $150;
          } else {
           $$lcssa194229233236 = $636;$$lcssa196227 = $20;$$lcssa198222234235 = $92;$635 = $19;
           label = 47;
           break L3;
          }
         }
         $74 = ___cxa_find_matching_catch()|0;
         $75 = tempRet0;
         $85 = $636;$86 = $92;$lpad$phi158$index = $74;$lpad$phi158$index7 = $75;
        }
       }
      }
     }
    }
   } while(0);
   L58: do {
    if ((label|0) == 47) {
     __THREW__ = 0;
     $152 = (invoke_i(123)|0);
     $153 = __THREW__; __THREW__ = 0;
     $154 = $153&1;
     if ($154) {
      $$ph154$ph$ph$ph$ph$ph190 = $$lcssa194229233236;$$ph155$ph$ph$ph$ph$ph = $$lcssa198222234235;
      label = 28;
     } else {
      __THREW__ = 0;
      invoke_vi(3630,1);
      $155 = __THREW__; __THREW__ = 0;
      $156 = $155&1;
      if ($156) {
       $$ph154$ph$ph$ph$ph$ph190 = $$lcssa194229233236;$$ph155$ph$ph$ph$ph$ph = $$lcssa198222234235;
       label = 28;
      } else {
       L62: do {
        if (!($635)) {
         $i5$0166 = 0;
         while(1) {
          $157 = (($$lcssa198222234235) + ($i5$0166<<2)|0);
          $158 = HEAP32[$157>>2]|0;
          $159 = HEAP32[$158>>2]|0;
          $160 = (($159) + 136|0);
          $161 = HEAP32[$160>>2]|0;
          __THREW__ = 0;
          $162 = (invoke_ii($161|0,($158|0))|0);
          $163 = __THREW__; __THREW__ = 0;
          $164 = $163&1;
          if ($164) {
           break;
          }
          if ($162) {
           __THREW__ = 0;
           invoke_vi(3699,($158|0));
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            break;
           }
          }
          $167 = HEAP32[$158>>2]|0;
          $168 = (($167) + 136|0);
          $169 = HEAP32[$168>>2]|0;
          __THREW__ = 0;
          $170 = (invoke_ii($169|0,($158|0))|0);
          $171 = __THREW__; __THREW__ = 0;
          $172 = $171&1;
          if ($172) {
           break;
          }
          if ($170) {
           __THREW__ = 0;
           (invoke_iii(2587,($158|0),7)|0);
           $173 = __THREW__; __THREW__ = 0;
           $174 = $173&1;
           if ($174) {
            break;
           }
          }
          $175 = (($i5$0166) + 1)|0;
          $176 = ($175>>>0)<($$lcssa196227>>>0);
          if ($176) {
           $i5$0166 = $175;
          } else {
           break L62;
          }
         }
         $72 = ___cxa_find_matching_catch()|0;
         $73 = tempRet0;
         $85 = $$lcssa194229233236;$86 = $$lcssa198222234235;$lpad$phi158$index = $72;$lpad$phi158$index7 = $73;
         break L58;
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3630,($152|0));
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        $$ph154$ph$ph$ph$ph$ph190 = $$lcssa194229233236;$$ph155$ph$ph$ph$ph$ph = $$lcssa198222234235;
        label = 28;
       } else {
        L76: do {
         if (!($635)) {
          $i7$0159 = 0;
          while(1) {
           $179 = (($$lcssa198222234235) + ($i7$0159<<2)|0);
           $180 = HEAP32[$179>>2]|0;
           $181 = HEAP32[$180>>2]|0;
           $182 = (($181) + 136|0);
           $183 = HEAP32[$182>>2]|0;
           __THREW__ = 0;
           $184 = (invoke_ii($183|0,($180|0))|0);
           $185 = __THREW__; __THREW__ = 0;
           $186 = $185&1;
           if ($186) {
            break;
           }
           if ($184) {
            __THREW__ = 0;
            invoke_vi(3700,($180|0));
            $187 = __THREW__; __THREW__ = 0;
            $188 = $187&1;
            if ($188) {
             break;
            }
            $189 = (($180) + 84|0);
            $190 = HEAP32[$189>>2]|0;
            $191 = $190;
            $192 = HEAP32[$190>>2]|0;
            $193 = (($192) + ($191))|0;
            $194 = $193;
            $195 = (($190) + 4|0);
            HEAP32[$195>>2] = $194;
            $196 = (($194) + 48|0);
            $197 = HEAP32[$196>>2]|0;
            $198 = ($197|0)==(1);
            if ($198) {
             $199 = HEAP32[$189>>2]|0;
             $200 = $199;
             $201 = HEAP32[$199>>2]|0;
             $202 = (($201) + ($200))|0;
             $203 = $202;
             $204 = (($199) + 4|0);
             HEAP32[$204>>2] = $203;
             $205 = (($203) + 48|0);
             HEAP32[$205>>2] = 2;
            }
           }
           $206 = (($i7$0159) + 1)|0;
           $207 = ($206>>>0)<($$lcssa196227>>>0);
           if ($207) {
            $i7$0159 = $206;
           } else {
            break L76;
           }
          }
          $70 = ___cxa_find_matching_catch()|0;
          $71 = tempRet0;
          $85 = $$lcssa194229233236;$86 = $$lcssa198222234235;$lpad$phi158$index = $70;$lpad$phi158$index7 = $71;
          break L58;
         }
        } while(0);
        $208 = ($$lcssa194229233236|0)>(-1);
        if (!($208)) {
         break L1;
        }
        HEAP32[$data$i$i>>2] = $13;
        ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$data$i$i+0>>2]|0;
        __Z19free_alloc_internalPv10MemLabelId($$lcssa198222234235,$$byval_copy50);
        break L1;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 28) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    $85 = $$ph154$ph$ph$ph$ph$ph190;$86 = $$ph155$ph$ph$ph$ph$ph;$lpad$phi158$index = $82;$lpad$phi158$index7 = $83;
   }
   $84 = ($85|0)>(-1);
   if (!($84)) {
    $$1 = $lpad$phi158$index;$$12 = $lpad$phi158$index7;
    ___resumeException($$1|0);
    // unreachable;
   }
   HEAP32[$9>>2] = $13;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($86|0),($$byval_copy50|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if ($88) {
    $633 = ___cxa_find_matching_catch(0|0)|0;
    $634 = tempRet0;
    ___clang_call_terminate($633);
    // unreachable;
   } else {
    $$1 = $lpad$phi158$index;$$12 = $lpad$phi158$index7;
    ___resumeException($$1|0);
    // unreachable;
   }
  }
 } while(0);
 if (!($doRetargetIKWrite)) {
  STACKTOP = sp;return;
 }
 $209 = HEAP32[628512>>2]|0;
 $210 = ($inputSize|0)==(0);
 L101: do {
  if ($210) {
   $$lcssa131252258269279286 = 0;$$lcssa133249259268280285 = 0;$$lcssa135246260267281284 = 0;$$lcssa139242262265282283 = 0;$$lcssa253257270278287 = 0;$624 = $209;$638 = 1;
   label = 169;
  } else {
   $211 = $inputSize << 2;
   HEAP32[$6>>2] = $209;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$6+0>>2]|0;
   $212 = (invoke_iiiiiiii(108,(0|0),($211|0),4,($$byval_copy50|0),0,(769408|0),370)|0);
   $213 = __THREW__; __THREW__ = 0;
   $214 = $213&1;
   if ($214) {
    $639 = $inputSize;$640 = 0;
    label = 105;
   } else {
    $215 = HEAP32[628512>>2]|0;
    HEAP32[$5>>2] = $215;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$5+0>>2]|0;
    $216 = (invoke_iiiiiiii(108,(0|0),($211|0),4,($$byval_copy50|0),0,(769408|0),370)|0);
    $217 = __THREW__; __THREW__ = 0;
    $218 = $217&1;
    if ($218) {
     $$ph$ph$ph$ph$ph$ph$ph$ph$ph = $215;$$ph76$ph$ph$ph$ph$ph$ph$ph$ph125 = $inputSize;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph126 = $212;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph127 = $inputSize;$$ph79$ph$ph$ph$ph$ph$ph$ph$ph = 0;
     label = 115;
    } else {
     if ($210) {
      $$lcssa131252258269279286 = 0;$$lcssa133249259268280285 = $212;$$lcssa135246260267281284 = 0;$$lcssa139242262265282283 = $216;$$lcssa253257270278287 = 0;$624 = $215;$638 = 1;
      label = 169;
     } else {
      $260 = 0;$262 = $inputSize;$270 = $212;$285 = 0;$287 = $inputSize;$295 = $216;$i9$0142 = 0;$layerCount$0143 = 0;
      L106: while(1) {
       $221 = (($inputAvatars) + ($i9$0142<<2)|0);
       $222 = HEAP32[$221>>2]|0;
       $223 = HEAP32[$222>>2]|0;
       $224 = (($223) + 136|0);
       $225 = HEAP32[$224>>2]|0;
       __THREW__ = 0;
       $226 = (invoke_ii($225|0,($222|0))|0);
       $227 = __THREW__; __THREW__ = 0;
       $228 = $227&1;
       if ($228) {
        $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $262;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $270;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
        label = 114;
        break;
       }
       if (!($226)) {
        __THREW__ = 0;
        invoke_vi(3697,($222|0));
        $229 = __THREW__; __THREW__ = 0;
        $230 = $229&1;
        if ($230) {
         $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $262;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $270;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
         label = 114;
         break;
        }
       }
       $231 = HEAP32[$222>>2]|0;
       $232 = (($231) + 136|0);
       $233 = HEAP32[$232>>2]|0;
       __THREW__ = 0;
       $234 = (invoke_ii($233|0,($222|0))|0);
       $235 = __THREW__; __THREW__ = 0;
       $236 = $235&1;
       if ($236) {
        $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $262;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $270;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
        label = 114;
        break;
       }
       if ($234) {
        $237 = (($222) + 44|0);
        $238 = HEAP8[$237>>0]|0;
        $239 = ($238<<24>>24)==(0);
        if ($239) {
         $220 = $285;$345 = $295;$425 = $260;$533 = $270;$642 = $262;$643 = $287;$layerCount$1 = $layerCount$0143;
        } else {
         $240 = HEAP32[$222>>2]|0;
         $241 = (($240) + 136|0);
         $242 = HEAP32[$241>>2]|0;
         __THREW__ = 0;
         $243 = (invoke_ii($242|0,($222|0))|0);
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if ($245) {
          $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $262;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $270;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
          label = 114;
          break;
         }
         if ($243) {
          $246 = (($222) + 92|0);
          $247 = HEAP32[$246>>2]|0;
          $248 = HEAP32[$247>>2]|0;
          $$0$i = $248;
         } else {
          $$0$i = 0;
         }
         $249 = ($$0$i|0)>($layerCount$0143|0);
         if ($249) {
          $250 = HEAP32[$222>>2]|0;
          $251 = (($250) + 136|0);
          $252 = HEAP32[$251>>2]|0;
          __THREW__ = 0;
          $253 = (invoke_ii($252|0,($222|0))|0);
          $254 = __THREW__; __THREW__ = 0;
          $255 = $254&1;
          if ($255) {
           $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $262;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $270;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
           label = 114;
           break;
          }
          if ($253) {
           $256 = (($222) + 92|0);
           $257 = HEAP32[$256>>2]|0;
           $258 = HEAP32[$257>>2]|0;
           $644 = $258;
          } else {
           $644 = 0;
          }
         } else {
          $644 = $layerCount$0143;
         }
         $259 = (($260) + 1)|0;
         $261 = $262 & 2147483647;
         $263 = ($259>>>0)>($261>>>0);
         do {
          if ($263) {
           $264 = $262 << 1;
           $265 = ($264|0)==(0);
           $266 = $265 ? 1 : $264;
           $267 = ($261>>>0)<($266>>>0);
           if ($267) {
            $268 = ($262|0)>(-1);
            if ($268) {
             $269 = $266 << 2;
             HEAP32[$3>>2] = $209;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$3+0>>2]|0;
             $271 = (invoke_iiiiiiii(108,($270|0),($269|0),4,($$byval_copy50|0),0,(769408|0),370)|0);
             $272 = __THREW__; __THREW__ = 0;
             $273 = $272&1;
             if ($273) {
              $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $266;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $270;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
              label = 114;
              break L106;
             }
             $280 = $271;$645 = $266;
             break;
            } else {
             $274 = $266 << 2;
             HEAP32[$4>>2] = $209;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$4+0>>2]|0;
             $275 = (invoke_iiiiiii(102,($274|0),4,($$byval_copy50|0),0,(769408|0),352)|0);
             $276 = __THREW__; __THREW__ = 0;
             $277 = $276&1;
             if ($277) {
              $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $262;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $270;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
              label = 114;
              break L106;
             }
             $278 = $259 << 2;
             _memcpy(($275|0),($270|0),($278|0))|0;
             $280 = $275;$645 = $266;
             break;
            }
           } else {
            $280 = $270;$645 = $262;
           }
          } else {
           $280 = $270;$645 = $262;
          }
         } while(0);
         $279 = (($280) + ($260<<2)|0);
         HEAP32[$279>>2] = $222;
         __THREW__ = 0;
         $281 = (invoke_ii(3403,($222|0))|0);
         $282 = __THREW__; __THREW__ = 0;
         $283 = $282&1;
         if ($283) {
          $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $645;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $280;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
          label = 114;
          break;
         }
         if ($281) {
          $284 = (($285) + 1)|0;
          $286 = $287 & 2147483647;
          $288 = ($284>>>0)>($286>>>0);
          do {
           if ($288) {
            $289 = $287 << 1;
            $290 = ($289|0)==(0);
            $291 = $290 ? 1 : $289;
            $292 = ($286>>>0)<($291>>>0);
            if (!($292)) {
             $305 = $295;$649 = $287;
             break;
            }
            $293 = ($287|0)>(-1);
            if ($293) {
             $294 = $291 << 2;
             HEAP32[$1>>2] = $215;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$1+0>>2]|0;
             $296 = (invoke_iiiiiiii(108,($295|0),($294|0),4,($$byval_copy50|0),0,(769408|0),370)|0);
             $297 = __THREW__; __THREW__ = 0;
             $298 = $297&1;
             if ($298) {
              $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $645;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $280;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $291;
              label = 114;
              break L106;
             }
             $305 = $296;$649 = $291;
             break;
            } else {
             $299 = $291 << 2;
             HEAP32[$2>>2] = $215;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$2+0>>2]|0;
             $300 = (invoke_iiiiiii(102,($299|0),4,($$byval_copy50|0),0,(769408|0),352)|0);
             $301 = __THREW__; __THREW__ = 0;
             $302 = $301&1;
             if ($302) {
              $$ph76$ph$ph$ph$ph$ph$ph$ph$ph = $645;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph = $280;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph = $287;
              label = 114;
              break L106;
             }
             $303 = $284 << 2;
             _memcpy(($300|0),($295|0),($303|0))|0;
             $305 = $300;$649 = $291;
             break;
            }
           } else {
            $305 = $295;$649 = $287;
           }
          } while(0);
          $304 = (($305) + ($285<<2)|0);
          HEAP32[$304>>2] = $222;
          $306 = (($222) + 88|0);
          $307 = HEAP32[$306>>2]|0;
          $308 = (($307) + 24|0);
          $309 = HEAP32[$308>>2]|0;
          $310 = (($309) + 88|0);
          HEAP8[$310>>0] = 1;
          $311 = (($309) + 89|0);
          HEAP8[$311>>0] = 1;
          $341 = $309;$646 = $649;$647 = $284;$648 = $305;
         } else {
          $$phi$trans$insert = (($222) + 88|0);
          $$pre = HEAP32[$$phi$trans$insert>>2]|0;
          $$phi$trans$insert219 = (($$pre) + 24|0);
          $$pre220 = HEAP32[$$phi$trans$insert219>>2]|0;
          $341 = $$pre220;$646 = $287;$647 = $285;$648 = $295;
         }
         $340 = (($341) + 90|0);
         HEAP8[$340>>0] = 1;
         $220 = $647;$345 = $648;$425 = $259;$533 = $280;$642 = $645;$643 = $646;$layerCount$1 = $644;
        }
       } else {
        $220 = $285;$345 = $295;$425 = $260;$533 = $270;$642 = $262;$643 = $287;$layerCount$1 = $layerCount$0143;
       }
       $342 = (($i9$0142) + 1)|0;
       $343 = ($342>>>0)<($inputSize>>>0);
       if ($343) {
        $260 = $425;$262 = $642;$270 = $533;$285 = $220;$287 = $643;$295 = $345;$i9$0142 = $342;$layerCount$0143 = $layerCount$1;
       } else {
        break;
       }
      }
      if ((label|0) == 114) {
       $330 = ___cxa_find_matching_catch()|0;
       $331 = tempRet0;
       $335 = $$ph78$ph$ph$ph$ph$ph$ph$ph$ph;$336 = $215;$337 = $295;$650 = $$ph76$ph$ph$ph$ph$ph$ph$ph$ph;$651 = $$ph77$ph$ph$ph$ph$ph$ph$ph$ph;$lpad$phi$index = $330;$lpad$phi$index25 = $331;
       label = 116;
       break;
      }
      $219 = ($220|0)==(0);
      L152: do {
       if ($219) {
        $$lcssa137245261266 = 0;$641 = 1;
       } else {
        $i11$0123 = 0;
        while(1) {
         $344 = (($345) + ($i11$0123<<2)|0);
         $346 = HEAP32[$344>>2]|0;
         $347 = HEAP32[$346>>2]|0;
         $348 = (($347) + 136|0);
         $349 = HEAP32[$348>>2]|0;
         __THREW__ = 0;
         $350 = (invoke_ii($349|0,($346|0))|0);
         $351 = __THREW__; __THREW__ = 0;
         $352 = $351&1;
         if ($352) {
          label = 113;
          break;
         }
         if ($350) {
          $353 = (($346) + 72|0);
          $354 = HEAP32[$353>>2]|0;
          $355 = (($346) + 76|0);
          $356 = HEAP32[$355>>2]|0;
          $357 = (($346) + 80|0);
          $358 = HEAP32[$357>>2]|0;
          $359 = (($346) + 84|0);
          $360 = HEAP32[$359>>2]|0;
          $361 = (($346) + 88|0);
          $362 = HEAP32[$361>>2]|0;
          $363 = (($346) + 92|0);
          $364 = HEAP32[$363>>2]|0;
          __THREW__ = 0;
          invoke_viiiiii(131,($354|0),($356|0),($358|0),($360|0),($362|0),($364|0));
          $365 = __THREW__; __THREW__ = 0;
          $366 = $365&1;
          if ($366) {
           label = 113;
           break;
          }
         }
         $367 = (($i11$0123) + 1)|0;
         $368 = ($367>>>0)<($220>>>0);
         if ($368) {
          $i11$0123 = $367;
         } else {
          break;
         }
        }
        if ((label|0) == 113) {
         $328 = ___cxa_find_matching_catch()|0;
         $329 = tempRet0;
         $335 = $643;$336 = $215;$337 = $345;$650 = $642;$651 = $533;$lpad$phi$index = $328;$lpad$phi$index25 = $329;
         label = 116;
         break L101;
        }
        if ($219) {
         $$lcssa137245261266 = 0;$641 = 1;
        } else {
         $i13$0117 = 0;
         while(1) {
          $369 = (($345) + ($i13$0117<<2)|0);
          $370 = HEAP32[$369>>2]|0;
          $371 = HEAP32[$370>>2]|0;
          $372 = (($371) + 136|0);
          $373 = HEAP32[$372>>2]|0;
          __THREW__ = 0;
          $374 = (invoke_ii($373|0,($370|0))|0);
          $375 = __THREW__; __THREW__ = 0;
          $376 = $375&1;
          if ($376) {
           label = 112;
           break;
          }
          if ($374) {
           $377 = (($370) + 88|0);
           $378 = HEAP32[$377>>2]|0;
           $379 = (($378) + 24|0);
           $380 = HEAP32[$379>>2]|0;
           $381 = (($380) + 89|0);
           $382 = HEAP8[$381>>0]|0;
           $383 = ($382<<24>>24)==(0);
           if (!($383)) {
            $384 = (($370) + 72|0);
            $385 = HEAP32[$384>>2]|0;
            $386 = (($370) + 76|0);
            $387 = HEAP32[$386>>2]|0;
            $388 = (($370) + 80|0);
            $389 = HEAP32[$388>>2]|0;
            $390 = (($370) + 84|0);
            $391 = HEAP32[$390>>2]|0;
            $392 = (($370) + 92|0);
            $393 = HEAP32[$392>>2]|0;
            $394 = (($380) + 88|0);
            $395 = HEAP8[$394>>0]|0;
            $396 = ($395<<24>>24)!=(0);
            __THREW__ = 0;
            invoke_viiiiiii(70,($385|0),($387|0),($389|0),($391|0),($378|0),($393|0),($396|0));
            $397 = __THREW__; __THREW__ = 0;
            $398 = $397&1;
            if ($398) {
             label = 112;
             break;
            }
            $399 = HEAP32[$384>>2]|0;
            $400 = HEAP32[$386>>2]|0;
            $401 = HEAP32[$388>>2]|0;
            $402 = HEAP32[$390>>2]|0;
            $403 = HEAP32[$377>>2]|0;
            $404 = HEAP32[$392>>2]|0;
            __THREW__ = 0;
            invoke_viiiiii(132,($399|0),($400|0),($401|0),($402|0),($403|0),($404|0));
            $405 = __THREW__; __THREW__ = 0;
            $406 = $405&1;
            if ($406) {
             label = 112;
             break;
            }
           }
          }
          $407 = (($i13$0117) + 1)|0;
          $408 = ($407>>>0)<($220>>>0);
          if ($408) {
           $i13$0117 = $407;
          } else {
           break;
          }
         }
         if ((label|0) == 112) {
          $326 = ___cxa_find_matching_catch()|0;
          $327 = tempRet0;
          $335 = $643;$336 = $215;$337 = $345;$650 = $642;$651 = $533;$lpad$phi$index = $326;$lpad$phi$index25 = $327;
          label = 116;
          break L101;
         }
         if ($219) {
          $$lcssa137245261266 = 0;$641 = 1;
         } else {
          $i15$0112 = 0;
          while(1) {
           $412 = (($345) + ($i15$0112<<2)|0);
           $413 = HEAP32[$412>>2]|0;
           $414 = HEAP32[$413>>2]|0;
           $415 = (($414) + 136|0);
           $416 = HEAP32[$415>>2]|0;
           __THREW__ = 0;
           $417 = (invoke_ii($416|0,($413|0))|0);
           $418 = __THREW__; __THREW__ = 0;
           $419 = $418&1;
           if ($419) {
            break;
           }
           if ($417) {
            __THREW__ = 0;
            invoke_vi(3701,($413|0));
            $420 = __THREW__; __THREW__ = 0;
            $421 = $420&1;
            if ($421) {
             break;
            }
           }
           $422 = (($i15$0112) + 1)|0;
           $423 = ($422>>>0)<($220>>>0);
           if ($423) {
            $i15$0112 = $422;
           } else {
            $$lcssa137245261266 = $220;$641 = $219;
            break L152;
           }
          }
          $324 = ___cxa_find_matching_catch()|0;
          $325 = tempRet0;
          $335 = $643;$336 = $215;$337 = $345;$650 = $642;$651 = $533;$lpad$phi$index = $324;$lpad$phi$index25 = $325;
          label = 116;
          break L101;
         }
        }
       }
      } while(0);
      $409 = ($layerCount$1|0)>(0);
      L181: do {
       if ($409) {
        $410 = (($data$i$i) + 8|0);
        $411 = (($data$i$i) + 4|0);
        $layerIter$0106 = 0;
        L183: while(1) {
         if (!($641)) {
          $i17$092 = 0;
          while(1) {
           $426 = (($345) + ($i17$092<<2)|0);
           $427 = HEAP32[$426>>2]|0;
           $428 = HEAP32[$427>>2]|0;
           $429 = (($428) + 136|0);
           $430 = HEAP32[$429>>2]|0;
           __THREW__ = 0;
           $431 = (invoke_ii($430|0,($427|0))|0);
           $432 = __THREW__; __THREW__ = 0;
           $433 = $432&1;
           if ($433) {
            label = 108;
            break L183;
           }
           if ($431) {
            $434 = (($427) + 92|0);
            $435 = HEAP32[$434>>2]|0;
            $436 = HEAP32[$435>>2]|0;
            $437 = ($436|0)>($layerIter$0106|0);
            if ($437) {
             $438 = (($435) + 4|0);
             $439 = $438;
             $440 = HEAP32[$438>>2]|0;
             $441 = (($440) + ($439))|0;
             $442 = $441;
             $443 = (($442) + ($layerIter$0106<<3)|0);
             $444 = $443;
             $445 = HEAP32[$443>>2]|0;
             $446 = (($444) + ($445))|0;
             $447 = $446;
             $448 = (($447) + 36|0);
             $449 = HEAP8[$448>>0]|0;
             $450 = ($449<<24>>24)==(0);
             if ($450) {
              $474 = 0;
             } else {
              $451 = (($427) + 24|0);
              $452 = HEAP32[$451>>2]|0;
              $453 = (($452) + 52|0);
              $454 = HEAP32[$453>>2]|0;
              $455 = $454 & 128;
              $456 = ($455|0)==(0);
              if (!($456)) {
               HEAP32[$410>>2] = 0;
               HEAP32[$411>>2] = $layerIter$0106;
               HEAP32[$data$i$i>>2] = 100000;
               __THREW__ = 0;
               invoke_viii(1969,($427|0),(565080|0),($data$i$i|0));
               $457 = __THREW__; __THREW__ = 0;
               $458 = $457&1;
               if ($458) {
                label = 108;
                break L183;
               }
              }
              __THREW__ = 0;
              $459 = (invoke_i(123)|0);
              $460 = __THREW__; __THREW__ = 0;
              $461 = $460&1;
              if ($461) {
               label = 108;
               break L183;
              }
              __THREW__ = 0;
              invoke_vi(3630,1);
              $462 = __THREW__; __THREW__ = 0;
              $463 = $462&1;
              if ($463) {
               label = 108;
               break L183;
              }
              __THREW__ = 0;
              (invoke_iii(2587,($427|0),16)|0);
              $464 = __THREW__; __THREW__ = 0;
              $465 = $464&1;
              if ($465) {
               label = 108;
               break L183;
              }
              __THREW__ = 0;
              invoke_vi(3630,($459|0));
              $466 = __THREW__; __THREW__ = 0;
              $467 = $466&1;
              if ($467) {
               label = 108;
               break L183;
              } else {
               $474 = 1;
              }
             }
            } else {
             $474 = 0;
            }
            $468 = (($427) + 88|0);
            $469 = HEAP32[$468>>2]|0;
            $470 = (($469) + 24|0);
            $471 = HEAP32[$470>>2]|0;
            $472 = (($471) + 88|0);
            HEAP8[$472>>0] = 0;
            $473 = (($471) + 89|0);
            HEAP8[$473>>0] = $474;
            $475 = (($471) + 90|0);
            HEAP8[$475>>0] = $474;
           }
           $476 = (($i17$092) + 1)|0;
           $477 = ($476>>>0)<($$lcssa137245261266>>>0);
           if ($477) {
            $i17$092 = $476;
           } else {
            break;
           }
          }
          if (!($641)) {
           $i19$098 = 0;
           while(1) {
            $478 = (($345) + ($i19$098<<2)|0);
            $479 = HEAP32[$478>>2]|0;
            $480 = HEAP32[$479>>2]|0;
            $481 = (($480) + 136|0);
            $482 = HEAP32[$481>>2]|0;
            __THREW__ = 0;
            $483 = (invoke_ii($482|0,($479|0))|0);
            $484 = __THREW__; __THREW__ = 0;
            $485 = $484&1;
            if ($485) {
             label = 109;
             break L183;
            }
            if ($483) {
             $486 = (($479) + 88|0);
             $487 = HEAP32[$486>>2]|0;
             $488 = (($487) + 24|0);
             $489 = HEAP32[$488>>2]|0;
             $490 = (($489) + 89|0);
             $491 = HEAP8[$490>>0]|0;
             $492 = ($491<<24>>24)==(0);
             if (!($492)) {
              $493 = (($479) + 72|0);
              $494 = HEAP32[$493>>2]|0;
              $495 = (($479) + 76|0);
              $496 = HEAP32[$495>>2]|0;
              $497 = (($479) + 80|0);
              $498 = HEAP32[$497>>2]|0;
              $499 = (($479) + 84|0);
              $500 = HEAP32[$499>>2]|0;
              $501 = (($479) + 92|0);
              $502 = HEAP32[$501>>2]|0;
              $503 = (($489) + 88|0);
              $504 = HEAP8[$503>>0]|0;
              $505 = ($504<<24>>24)!=(0);
              __THREW__ = 0;
              invoke_viiiiiii(70,($494|0),($496|0),($498|0),($500|0),($487|0),($502|0),($505|0));
              $506 = __THREW__; __THREW__ = 0;
              $507 = $506&1;
              if ($507) {
               label = 109;
               break L183;
              }
              $508 = HEAP32[$493>>2]|0;
              $509 = HEAP32[$495>>2]|0;
              $510 = HEAP32[$497>>2]|0;
              $511 = HEAP32[$499>>2]|0;
              $512 = HEAP32[$486>>2]|0;
              $513 = HEAP32[$501>>2]|0;
              __THREW__ = 0;
              invoke_viiiiii(132,($508|0),($509|0),($510|0),($511|0),($512|0),($513|0));
              $514 = __THREW__; __THREW__ = 0;
              $515 = $514&1;
              if ($515) {
               label = 109;
               break L183;
              }
             }
            }
            $516 = (($i19$098) + 1)|0;
            $517 = ($516>>>0)<($$lcssa137245261266>>>0);
            if ($517) {
             $i19$098 = $516;
            } else {
             break;
            }
           }
           if (!($641)) {
            $i21$0102 = 0;
            while(1) {
             $518 = (($345) + ($i21$0102<<2)|0);
             $519 = HEAP32[$518>>2]|0;
             $520 = HEAP32[$519>>2]|0;
             $521 = (($520) + 136|0);
             $522 = HEAP32[$521>>2]|0;
             __THREW__ = 0;
             $523 = (invoke_ii($522|0,($519|0))|0);
             $524 = __THREW__; __THREW__ = 0;
             $525 = $524&1;
             if ($525) {
              label = 110;
              break L183;
             }
             if ($523) {
              __THREW__ = 0;
              invoke_vi(3701,($519|0));
              $526 = __THREW__; __THREW__ = 0;
              $527 = $526&1;
              if ($527) {
               label = 110;
               break L183;
              }
             }
             $528 = (($i21$0102) + 1)|0;
             $529 = ($528>>>0)<($$lcssa137245261266>>>0);
             if ($529) {
              $i21$0102 = $528;
             } else {
              break;
             }
            }
           }
          }
         }
         $530 = (($layerIter$0106) + 1)|0;
         $531 = ($530|0)<($layerCount$1|0);
         if ($531) {
          $layerIter$0106 = $530;
         } else {
          break L181;
         }
        }
        if ((label|0) == 108) {
         $318 = ___cxa_find_matching_catch()|0;
         $319 = tempRet0;
         $335 = $643;$336 = $215;$337 = $345;$650 = $642;$651 = $533;$lpad$phi$index = $318;$lpad$phi$index25 = $319;
         label = 116;
         break L101;
        }
        else if ((label|0) == 109) {
         $320 = ___cxa_find_matching_catch()|0;
         $321 = tempRet0;
         $335 = $643;$336 = $215;$337 = $345;$650 = $642;$651 = $533;$lpad$phi$index = $320;$lpad$phi$index25 = $321;
         label = 116;
         break L101;
        }
        else if ((label|0) == 110) {
         $322 = ___cxa_find_matching_catch()|0;
         $323 = tempRet0;
         $335 = $643;$336 = $215;$337 = $345;$650 = $642;$651 = $533;$lpad$phi$index = $322;$lpad$phi$index25 = $323;
         label = 116;
         break L101;
        }
       }
      } while(0);
      $424 = ($425|0)==(0);
      if ($424) {
       $$lcssa131252258269279286 = 0;$$lcssa133249259268280285 = $533;$$lcssa135246260267281284 = $643;$$lcssa139242262265282283 = $345;$$lcssa253257270278287 = $642;$624 = $215;$638 = 1;
       label = 169;
      } else {
       $i23$085 = 0;
       while(1) {
        $532 = (($533) + ($i23$085<<2)|0);
        $534 = HEAP32[$532>>2]|0;
        $535 = HEAP32[$534>>2]|0;
        $536 = (($535) + 136|0);
        $537 = HEAP32[$536>>2]|0;
        __THREW__ = 0;
        $538 = (invoke_ii($537|0,($534|0))|0);
        $539 = __THREW__; __THREW__ = 0;
        $540 = $539&1;
        if ($540) {
         break;
        }
        if ($538) {
         __THREW__ = 0;
         invoke_vi(3701,($534|0));
         $541 = __THREW__; __THREW__ = 0;
         $542 = $541&1;
         if ($542) {
          break;
         }
        }
        $543 = (($i23$085) + 1)|0;
        $544 = ($543>>>0)<($425>>>0);
        if ($544) {
         $i23$085 = $543;
        } else {
         $$lcssa131252258269279286 = $425;$$lcssa133249259268280285 = $533;$$lcssa135246260267281284 = $643;$$lcssa139242262265282283 = $345;$$lcssa253257270278287 = $642;$624 = $215;$638 = $424;
         label = 169;
         break L101;
        }
       }
       $316 = ___cxa_find_matching_catch()|0;
       $317 = tempRet0;
       $335 = $643;$336 = $215;$337 = $345;$650 = $642;$651 = $533;$lpad$phi$index = $316;$lpad$phi$index25 = $317;
       label = 116;
      }
     }
    }
   }
  }
 } while(0);
 L231: do {
  if ((label|0) == 169) {
   __THREW__ = 0;
   $545 = (invoke_i(123)|0);
   $546 = __THREW__; __THREW__ = 0;
   $547 = $546&1;
   if ($547) {
    $$ph$ph$ph$ph$ph$ph$ph$ph$ph = $624;$$ph76$ph$ph$ph$ph$ph$ph$ph$ph125 = $$lcssa253257270278287;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph126 = $$lcssa133249259268280285;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph127 = $$lcssa135246260267281284;$$ph79$ph$ph$ph$ph$ph$ph$ph$ph = $$lcssa139242262265282283;
    label = 115;
   } else {
    __THREW__ = 0;
    invoke_vi(3630,1);
    $548 = __THREW__; __THREW__ = 0;
    $549 = $548&1;
    if ($549) {
     $$ph$ph$ph$ph$ph$ph$ph$ph$ph = $624;$$ph76$ph$ph$ph$ph$ph$ph$ph$ph125 = $$lcssa253257270278287;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph126 = $$lcssa133249259268280285;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph127 = $$lcssa135246260267281284;$$ph79$ph$ph$ph$ph$ph$ph$ph$ph = $$lcssa139242262265282283;
     label = 115;
    } else {
     L235: do {
      if (!($638)) {
       $550 = $deltaTime == Math_fround(0.0);
       $551 = $550&1;
       $i26$080 = 0;
       while(1) {
        $552 = (($$lcssa133249259268280285) + ($i26$080<<2)|0);
        $553 = HEAP32[$552>>2]|0;
        $554 = (($553) + 24|0);
        $555 = HEAP32[$554>>2]|0;
        $556 = ($555|0)==(0|0);
        if (!($556)) {
         __THREW__ = 0;
         $557 = (invoke_ii(3251,($555|0))|0);
         $558 = __THREW__; __THREW__ = 0;
         $559 = $558&1;
         if ($559) {
          break;
         }
         if ($557) {
          $560 = (($553) + 465|0);
          $561 = HEAP8[$560>>0]|0;
          $562 = ($561<<24>>24)==(0);
          if ($562) {
           HEAP32[$allocated>>2] = 0;
           __THREW__ = 0;
           $573 = (invoke_iii(2588,($553|0),($allocated|0))|0);
           $574 = __THREW__; __THREW__ = 0;
           $575 = $574&1;
           if ($575) {
            break;
           }
           $576 = ($573|0)==(0|0);
           if (!($576)) {
            $577 = (($553) + 72|0);
            $578 = HEAP32[$577>>2]|0;
            $579 = ($578|0)==(0|0);
            if (!($579)) {
             $580 = (($553) + 104|0);
             $581 = HEAP32[$580>>2]|0;
             __THREW__ = 0;
             invoke_viii(2020,($581|0),($573|0),($578|0));
             $582 = __THREW__; __THREW__ = 0;
             $583 = $582&1;
             if ($583) {
              break;
             }
            }
           }
          } else {
           $563 = HEAP32[$554>>2]|0;
           __THREW__ = 0;
           $564 = (invoke_ii(3220,($563|0))|0);
           $565 = __THREW__; __THREW__ = 0;
           $566 = $565&1;
           if ($566) {
            break;
           }
           $567 = (($553) + 100|0);
           $568 = HEAP32[$567>>2]|0;
           $569 = (($553) + 104|0);
           $570 = HEAP32[$569>>2]|0;
           __THREW__ = 0;
           invoke_viii(2019,($564|0),($568|0),($570|0));
           $571 = __THREW__; __THREW__ = 0;
           $572 = $571&1;
           if ($572) {
            break;
           }
          }
          $584 = (($553) + 100|0);
          $585 = HEAP32[$584>>2]|0;
          $586 = (($553) + 80|0);
          $587 = HEAP32[$586>>2]|0;
          $588 = HEAP32[$587>>2]|0;
          __THREW__ = 0;
          invoke_vii(3396,($585|0),($588|0));
          $589 = __THREW__; __THREW__ = 0;
          $590 = $589&1;
          if ($590) {
           break;
          }
          $591 = HEAP32[$584>>2]|0;
          $592 = HEAP32[$586>>2]|0;
          $593 = HEAP32[$592>>2]|0;
          __THREW__ = 0;
          invoke_vii(3397,($591|0),($593|0));
          $594 = __THREW__; __THREW__ = 0;
          $595 = $594&1;
          if ($595) {
           break;
          }
          $596 = (($553) + 52|0);
          $597 = HEAP32[$596>>2]|0;
          $598 = ($597|0)==(2);
          $599 = $598 ? $realDeltaTime : $deltaTime;
          $600 = (($553) + 452|0);
          $601 = HEAP32[$600>>2]|0;
          $602 = ($601|0)==(2);
          if ($602) {
           $603 = (($553) + 348|0);
           $604 = Math_fround(HEAPF32[$603>>2]);
           $605 = !($604 >= Math_fround(0.0));
           if (!($605)) {
            $606 = (($553) + 412|0);
            $607 = Math_fround($599 * $604);
            $608 = (($553) + 84|0);
            $609 = HEAP32[$608>>2]|0;
            __THREW__ = 0;
            invoke_vifi(3,($606|0),(+$607),($609|0));
            $610 = __THREW__; __THREW__ = 0;
            $611 = $610&1;
            if ($611) {
             break;
            }
           }
          }
          $612 = (($553) + 84|0);
          $613 = HEAP32[$612>>2]|0;
          $614 = (($613) + 172|0);
          $615 = HEAP8[$614>>0]|0;
          $616 = $615&255;
          $617 = $616 & $551;
          $618 = $617&255;
          HEAP8[$614>>0] = $618;
         }
        }
        $619 = (($i26$080) + 1)|0;
        $620 = ($619>>>0)<($$lcssa131252258269279286>>>0);
        if ($620) {
         $i26$080 = $619;
        } else {
         break L235;
        }
       }
       $314 = ___cxa_find_matching_catch()|0;
       $315 = tempRet0;
       $335 = $$lcssa135246260267281284;$336 = $624;$337 = $$lcssa139242262265282283;$650 = $$lcssa253257270278287;$651 = $$lcssa133249259268280285;$lpad$phi$index = $314;$lpad$phi$index25 = $315;
       label = 116;
       break L231;
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3630,($545|0));
     $621 = __THREW__; __THREW__ = 0;
     $622 = $621&1;
     if ($622) {
      $$ph$ph$ph$ph$ph$ph$ph$ph$ph = $624;$$ph76$ph$ph$ph$ph$ph$ph$ph$ph125 = $$lcssa253257270278287;$$ph77$ph$ph$ph$ph$ph$ph$ph$ph126 = $$lcssa133249259268280285;$$ph78$ph$ph$ph$ph$ph$ph$ph$ph127 = $$lcssa135246260267281284;$$ph79$ph$ph$ph$ph$ph$ph$ph$ph = $$lcssa139242262265282283;
      label = 115;
     } else {
      $623 = ($$lcssa135246260267281284|0)>(-1);
      if ($623) {
       HEAP32[$7>>2] = $624;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$7+0>>2]|0;
       invoke_vii(2591,($$lcssa139242262265282283|0),($$byval_copy50|0));
       $625 = __THREW__; __THREW__ = 0;
       $626 = $625&1;
       if ($626) {
        $639 = $$lcssa253257270278287;$640 = $$lcssa133249259268280285;
        label = 105;
        break;
       }
      }
      $627 = ($$lcssa253257270278287|0)>(-1);
      if (!($627)) {
       STACKTOP = sp;return;
      }
      HEAP32[$0>>2] = $209;
      ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($$lcssa133249259268280285,$$byval_copy50);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 105) {
  $312 = ___cxa_find_matching_catch()|0;
  $313 = tempRet0;
  $$0 = $312;$$01 = $313;$629 = $639;$630 = $640;
 }
 else if ((label|0) == 115) {
  $332 = ___cxa_find_matching_catch()|0;
  $333 = tempRet0;
  $335 = $$ph78$ph$ph$ph$ph$ph$ph$ph$ph127;$336 = $$ph$ph$ph$ph$ph$ph$ph$ph$ph;$337 = $$ph79$ph$ph$ph$ph$ph$ph$ph$ph;$650 = $$ph76$ph$ph$ph$ph$ph$ph$ph$ph125;$651 = $$ph77$ph$ph$ph$ph$ph$ph$ph$ph126;$lpad$phi$index = $332;$lpad$phi$index25 = $333;
  label = 116;
 }
 if ((label|0) == 116) {
  $334 = ($335|0)>(-1);
  if ($334) {
   HEAP32[$0>>2] = $336;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($337|0),($$byval_copy50|0));
   $338 = __THREW__; __THREW__ = 0;
   $339 = $338&1;
   if ($339) {
    $633 = ___cxa_find_matching_catch(0|0)|0;
    $634 = tempRet0;
    ___clang_call_terminate($633);
    // unreachable;
   } else {
    $$0 = $lpad$phi$index;$$01 = $lpad$phi$index25;$629 = $650;$630 = $651;
   }
  } else {
   $$0 = $lpad$phi$index;$$01 = $lpad$phi$index25;$629 = $650;$630 = $651;
  }
 }
 $628 = ($629|0)>(-1);
 if (!($628)) {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$1|0);
  // unreachable;
 }
 HEAP32[$8>>2] = $209;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy50+0>>2]=HEAP32[$8+0>>2]|0;
 invoke_vii(2591,($630|0),($$byval_copy50|0));
 $631 = __THREW__; __THREW__ = 0;
 $632 = $631&1;
 if ($632) {
  $633 = ___cxa_find_matching_catch(0|0)|0;
  $634 = tempRet0;
  ___clang_call_terminate($633);
  // unreachable;
 } else {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZN8Animator8InitStepEf($this,$deltaTime) {
 $this = $this|0;
 $deltaTime = Math_fround($deltaTime);
 var $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 452|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2);
 $3 = (($this) + 348|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = $4 < Math_fround(0.0);
 $or$cond3 = $2 & $5;
 if ($or$cond3) {
  $6 = (($this) + 412|0);
  $7 = (Math_fround(__ZN14AvatarPlayback10CursorTimeEv($6)));
  $8 = Math_fround(HEAPF32[$3>>2]);
  $9 = Math_fround($8 * $deltaTime);
  $10 = Math_fround($7 + $9);
  __ZN8Animator23SetPlaybackTimeInternalEf($this,$10);
  $$pre = HEAP32[$0>>2]|0;
  $49 = $$pre;
 } else {
  $11 = Math_fround($4 * $deltaTime);
  $12 = (($this) + 76|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 4|0);
  HEAPF32[$14>>2] = $11;
  $49 = $1;
 }
 if ((($49|0) == 2)) {
  $15 = (($this) + 348|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = $16 < Math_fround(0.0);
  if ($17) {
   label = 6;
  }
 } else if ((($49|0) == 1)) {
  label = 6;
 }
 if ((label|0) == 6) {
  $18 = (($this) + 456|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (($this) + 76|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 4|0);
  HEAPF32[$22>>2] = $19;
  HEAPF32[$18>>2] = Math_fround(0.0);
 }
 $23 = (($this) + 84|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24;
 $26 = HEAP32[$24>>2]|0;
 $27 = (($26) + ($25))|0;
 $28 = $27;
 $29 = (($24) + 4|0);
 HEAP32[$29>>2] = $28;
 $30 = (($28) + 48|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)!=(0);
 $33 = $deltaTime == Math_fround(0.0);
 $or$cond = $32 | $33;
 if ($or$cond) {
  $41 = (($this) + 345|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = (($this) + 76|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 22|0);
  HEAP8[$45>>0] = $42;
  $46 = (($this) + 346|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = (($44) + 23|0);
  HEAP8[$48>>0] = $47;
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$23>>2]|0;
 $35 = $34;
 $36 = HEAP32[$34>>2]|0;
 $37 = (($36) + ($35))|0;
 $38 = $37;
 $39 = (($34) + 4|0);
 HEAP32[$39>>2] = $38;
 $40 = (($38) + 48|0);
 HEAP32[$40>>2] = 1;
 $41 = (($this) + 345|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = (($this) + 76|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 22|0);
 HEAP8[$45>>0] = $42;
 $46 = (($this) + 346|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = (($44) + 23|0);
 HEAP8[$48>>0] = $47;
 STACKTOP = sp;return;
}
function __ZN8Animator19FireAnimationEventsEv($this) {
 $this = $this|0;
 var $$in = 0, $$in1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $clipInfo = 0, $i$02 = 0, $stateInfo = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $stateInfo = sp + 8|0;
 $clipInfo = sp;
 $0 = (($this) + 353|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 476|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  __ZN8Animator24SetupAnimationClipsCacheEv($this);
 }
 $6 = (($this) + 88|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + 136|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($this)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 468|0);
 $12 = (($stateInfo) + 8|0);
 $13 = (($clipInfo) + 4|0);
 $i$02 = 0;
 while(1) {
  $14 = HEAP32[$6>>2]|0;
  $15 = (($14) + 24|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 56|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($i$02|0)<($18|0);
  if (!($19)) {
   label = 18;
   break;
  }
  $20 = (($16) + 60|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + ($i$02<<5)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$11>>2]|0;
  $25 = (($24) + ($23<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__ZN13AnimationClip18HasAnimationEventsEv($26)|0);
  if ($27) {
   ;HEAP32[$stateInfo+0>>2]=0|0;HEAP32[$stateInfo+4>>2]=0|0;HEAP32[$stateInfo+8>>2]=0|0;HEAP32[$stateInfo+12>>2]=0|0;HEAP32[$stateInfo+16>>2]=0|0;HEAP32[$stateInfo+20>>2]=0|0;HEAP32[$stateInfo+24>>2]=0|0;
   $28 = ((($21) + ($i$02<<5)|0) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ((($21) + ($i$02<<5)|0) + 24|0);
   $31 = HEAP32[$30>>2]|0;
   (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$29,0,$stateInfo)|0);
   $32 = HEAP32[$12>>2]|0;
   $33 = ($32|0)==($31|0);
   if (!($33)) {
    (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$29,1,$stateInfo)|0);
    $$pre$i = HEAP32[$12>>2]|0;
    $34 = ($$pre$i|0)==($31|0);
    if (!($34)) {
     (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$29,2,$stateInfo)|0);
    }
   }
   HEAP32[$clipInfo>>2] = 0;
   HEAPF32[$13>>2] = Math_fround(0.0);
   $35 = ($26|0)==(0|0);
   if ($35) {
    $storemerge = 0;
   } else {
    $36 = (($26) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $storemerge = $37;
   }
   HEAP32[$clipInfo>>2] = $storemerge;
   $38 = ((($21) + ($i$02<<5)|0) + 8|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   HEAPF32[$13>>2] = $39;
   $40 = ((($21) + ($i$02<<5)|0) + 20|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = $41 < Math_fround(0.0);
   if ($42) {
    $43 = ((($21) + ($i$02<<5)|0) + 16|0);
    $44 = ((($21) + ($i$02<<5)|0) + 12|0);
    $$in = $43;$$in1 = $44;
   } else {
    $45 = ((($21) + ($i$02<<5)|0) + 12|0);
    $46 = ((($21) + ($i$02<<5)|0) + 16|0);
    $$in = $45;$$in1 = $46;
   }
   $47 = Math_fround(HEAPF32[$$in>>2]);
   $48 = Math_fround(HEAPF32[$$in1>>2]);
   $49 = ((($21) + ($i$02<<5)|0) + 28|0);
   $50 = HEAP8[$49>>0]|0;
   $51 = ($50<<24>>24)!=(0);
   __ZN13AnimationClip19FireAnimationEventsEffRN5Unity9ComponentEP17AnimatorStateInfoP16AnimatorClipInfob($26,$47,$48,$this,$stateInfo,$clipInfo,$51);
  }
  $52 = (($i$02) + 1)|0;
  $53 = HEAP32[$this>>2]|0;
  $54 = (($53) + 136|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (FUNCTION_TABLE_ii[$55 & 4095]($this)|0);
  if ($56) {
   $i$02 = $52;
  } else {
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return;
 }
}
function __ZN8Animator14FireBehavioursEN7mecanim12statemachine19StateMachineMessageE($this,$filter) {
 $this = $this|0;
 $filter = $filter|0;
 var $$0 = 0, $$pre$i = 0, $$pre$i10 = 0, $$pre1$i = 0, $$pre1$i11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $i$017 = 0, $j$014 = 0, $ret$0$off016 = 0, $ret$1$off0$lcssa = 0, $ret$1$off013 = 0, $ret$2$off0 = 0, $ret$3$off0 = 0, $stateInfo = 0, $stateInfo1 = 0, $stateMachineBehaviourPlayer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $stateMachineBehaviourPlayer = sp + 56|0;
 $stateInfo = sp;
 $stateInfo1 = sp + 28|0;
 $0 = (($this) + 376|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 372|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + ($7))|0;
 $10 = $9;
 $11 = (($6) + 4|0);
 HEAP32[$11>>2] = $10;
 $12 = (($10) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($this) + 32|0);
 __ZN27StateMachineBehaviourPlayerC2EP28IStateMachineBehaviourSender($stateMachineBehaviourPlayer,$15);
 $16 = (($this) + 92|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = (($this) + 88|0);
 $22 = (($stateInfo1) + 8|0);
 $23 = (($stateInfo) + 8|0);
 $32 = $17;$i$017 = 0;$ret$0$off016 = 0;
 while(1) {
  $24 = HEAP32[$21>>2]|0;
  $25 = (($24) + 24|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + ($i$017<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$32>>2]|0;
  $33 = ($31|0)==(0);
  if ($33) {
   $77 = $32;$ret$1$off0$lcssa = $ret$0$off016;
  } else {
   $34 = (($30) + 20|0);
   $35 = (($30) + 44|0);
   $36 = (($30) + 40|0);
   $37 = (($30) + 16|0);
   $39 = $32;$j$014 = 0;$ret$1$off013 = $ret$0$off016;
   while(1) {
    $38 = (($39) + 4|0);
    $40 = $38;
    $41 = HEAP32[$38>>2]|0;
    $42 = (($41) + ($40))|0;
    $43 = $42;
    $44 = (($43) + ($j$014<<3)|0);
    $45 = $44;
    $46 = HEAP32[$44>>2]|0;
    $47 = (($45) + ($46))|0;
    $48 = $47;
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($i$017|0);
    do {
     if ($50) {
      $51 = HEAP32[$34>>2]|0;
      $52 = $51 & $filter;
      $53 = ($52|0)==(0);
      do {
       if ($53) {
        $ret$2$off0 = $ret$1$off013;
       } else {
        ;HEAP32[$stateInfo+0>>2]=0|0;HEAP32[$stateInfo+4>>2]=0|0;HEAP32[$stateInfo+8>>2]=0|0;HEAP32[$stateInfo+12>>2]=0|0;HEAP32[$stateInfo+16>>2]=0|0;HEAP32[$stateInfo+20>>2]=0|0;HEAP32[$stateInfo+24>>2]=0|0;
        $54 = HEAP32[$37>>2]|0;
        (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$j$014,0,$stateInfo)|0);
        $55 = HEAP32[$23>>2]|0;
        $56 = ($55|0)==($54|0);
        if (!($56)) {
         (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$j$014,1,$stateInfo)|0);
         $$pre$i10 = HEAP32[$23>>2]|0;
         $57 = ($$pre$i10|0)==($54|0);
         if (!($57)) {
          (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$j$014,2,$stateInfo)|0);
          $$pre1$i11 = HEAP32[$23>>2]|0;
          $58 = ($$pre1$i11|0)==($54|0);
          if (!($58)) {
           $ret$2$off0 = $ret$1$off013;
           break;
          }
         }
        }
        $59 = (__ZNK27StateMachineBehaviourPlayer18FireStateBehaviourER17AnimatorStateInfoiN7mecanim12statemachine19StateMachineMessageE($stateMachineBehaviourPlayer,$stateInfo,$j$014,$52)|0);
        $60 = $ret$1$off013 | $59;
        $ret$2$off0 = $60;
       }
      } while(0);
      $61 = HEAP32[$35>>2]|0;
      $62 = $61 & $filter;
      $63 = ($62|0)==(0);
      if ($63) {
       $ret$3$off0 = $ret$2$off0;
      } else {
       ;HEAP32[$stateInfo1+0>>2]=0|0;HEAP32[$stateInfo1+4>>2]=0|0;HEAP32[$stateInfo1+8>>2]=0|0;HEAP32[$stateInfo1+12>>2]=0|0;HEAP32[$stateInfo1+16>>2]=0|0;HEAP32[$stateInfo1+20>>2]=0|0;HEAP32[$stateInfo1+24>>2]=0|0;
       $64 = HEAP32[$36>>2]|0;
       (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$j$014,0,$stateInfo1)|0);
       $65 = HEAP32[$22>>2]|0;
       $66 = ($65|0)==($64|0);
       if (!($66)) {
        (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$j$014,1,$stateInfo1)|0);
        $$pre$i = HEAP32[$22>>2]|0;
        $67 = ($$pre$i|0)==($64|0);
        if (!($67)) {
         (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$j$014,2,$stateInfo1)|0);
         $$pre1$i = HEAP32[$22>>2]|0;
         $68 = ($$pre1$i|0)==($64|0);
         if (!($68)) {
          $ret$3$off0 = $ret$2$off0;
          break;
         }
        }
       }
       $69 = (__ZNK27StateMachineBehaviourPlayer18FireStateBehaviourER17AnimatorStateInfoiN7mecanim12statemachine19StateMachineMessageE($stateMachineBehaviourPlayer,$stateInfo1,$j$014,$62)|0);
       $70 = $ret$2$off0 | $69;
       $ret$3$off0 = $70;
      }
     } else {
      $ret$3$off0 = $ret$1$off013;
     }
    } while(0);
    $71 = (($j$014) + 1)|0;
    $72 = HEAP32[$16>>2]|0;
    $73 = HEAP32[$72>>2]|0;
    $74 = ($71>>>0)<($73>>>0);
    if ($74) {
     $39 = $72;$j$014 = $71;$ret$1$off013 = $ret$3$off0;
    } else {
     $77 = $72;$ret$1$off0$lcssa = $ret$3$off0;
     break;
    }
   }
  }
  $75 = (($i$017) + 1)|0;
  $76 = (($77) + 12|0);
  $78 = HEAP32[$76>>2]|0;
  $79 = ($75>>>0)<($78>>>0);
  if ($79) {
   $32 = $77;$i$017 = $75;$ret$0$off016 = $ret$1$off0$lcssa;
  } else {
   $$0 = $ret$1$off0$lcssa;
   break;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN8Animator19ApplyOnAnimatorMoveEv($this) {
 $this = $this|0;
 var $$idx$i = 0, $$idx$val$i = Math_fround(0), $$idx1$i = 0, $$idx1$val$i = Math_fround(0), $$idx2$i = 0, $$idx2$val$i = Math_fround(0), $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0;
 var $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $data$i = 0, $messageSent$0$off0 = 0, $phitmp = 0, $phitmp3 = 0, $pos$idx$val$i = Math_fround(0), $pos$idx1$i = 0, $pos$idx1$val$i = Math_fround(0), $pos$idx2$i = 0;
 var $pos$idx2$val$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = sp + 32|0;
 $3 = sp + 48|0;
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($5)|0);
 $7 = (($this) + 452|0);
 $8 = HEAP32[$7>>2]|0;
 if ((($8|0) == 2)) {
  $9 = (($this) + 348|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = $10 < Math_fround(0.0);
  if ($11) {
   label = 14;
  }
 } else if ((($8|0) == 1)) {
  label = 14;
 }
 if ((label|0) == 14) {
  $57 = (($this) + 345|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = ($58<<24>>24)==(0);
  if ($59) {
   $96 = 0;
  } else {
   $60 = (($this) + 84|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==(0|0);
   if ($62) {
    HEAPF32[$2>>2] = Math_fround(0.0);
    $63 = (($2) + 4|0);
    HEAPF32[$63>>2] = Math_fround(0.0);
    $64 = (($2) + 8|0);
    HEAPF32[$64>>2] = Math_fround(0.0);
    HEAPF32[$3>>2] = Math_fround(0.0);
    $65 = (($3) + 4|0);
    HEAPF32[$65>>2] = Math_fround(0.0);
    $66 = (($3) + 8|0);
    HEAPF32[$66>>2] = Math_fround(0.0);
    $67 = (($3) + 12|0);
    HEAPF32[$67>>2] = Math_fround(1.0);
   } else {
    $$idx$i = (($61) + 8|0);
    $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
    $$idx1$i = (($61) + 12|0);
    $$idx1$val$i = Math_fround(HEAPF32[$$idx1$i>>2]);
    $$idx2$i = (($61) + 16|0);
    $$idx2$val$i = Math_fround(HEAPF32[$$idx2$i>>2]);
    HEAPF32[$2>>2] = $$idx$val$i;
    $68 = (($2) + 4|0);
    HEAPF32[$68>>2] = $$idx1$val$i;
    $69 = (($2) + 8|0);
    HEAPF32[$69>>2] = $$idx2$val$i;
    $70 = (($61) + 24|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = Math_fround($71 * $71);
    $73 = (($61) + 28|0);
    $74 = Math_fround(HEAPF32[$73>>2]);
    $75 = Math_fround($74 * $74);
    $76 = (($61) + 32|0);
    $77 = Math_fround(HEAPF32[$76>>2]);
    $78 = Math_fround($77 * $77);
    $79 = (($61) + 36|0);
    $80 = Math_fround(HEAPF32[$79>>2]);
    $81 = Math_fround($80 * $80);
    $82 = Math_fround($72 + $75);
    $83 = Math_fround($78 + $81);
    $84 = Math_fround($82 + $83);
    $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
    $86 = Math_fround(Math_fround(1.0) / $85);
    $87 = Math_fround($71 * $86);
    $88 = Math_fround($74 * $86);
    $89 = Math_fround($77 * $86);
    $90 = Math_fround($80 * $86);
    HEAPF32[$3>>2] = $87;
    $91 = (($3) + 4|0);
    HEAPF32[$91>>2] = $88;
    $92 = (($3) + 8|0);
    HEAPF32[$92>>2] = $89;
    $93 = (($3) + 12|0);
    HEAPF32[$93>>2] = $90;
   }
   __ZN9Transform26SetPositionAndRotationSafeERK8Vector3fRK11Quaternionf($6,$2,$3);
   $$pre2 = HEAP8[$57>>0]|0;
   $phitmp3 = ($$pre2<<24>>24)!=(0);
   $96 = $phitmp3;
  }
  $94 = (($this) + 100|0);
  $95 = HEAP32[$94>>2]|0;
  $97 = (__ZN11UnityEngine9Animation37HasGenericRootTransformPropertyValuesERKNS0_30AnimatorGenericBindingConstantEb($95,$96)|0);
  if (!($97)) {
   STACKTOP = sp;return;
  }
  $98 = HEAP32[$94>>2]|0;
  $99 = (($this) + 80|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = HEAP32[$100>>2]|0;
  $102 = HEAP8[$57>>0]|0;
  $103 = ($102<<24>>24)!=(0);
  __ZN11UnityEngine9Animation37SetGenericRootTransformPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayER9Transformb($98,$101,$6,$103);
  STACKTOP = sp;return;
 }
 $12 = HEAP32[$4>>2]|0;
 $13 = (($12) + 52|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 64;
 $16 = ($15|0)==(0);
 if ($16) {
  $messageSent$0$off0 = 0;
 } else {
  $17 = (($data$i) + 8|0);
  HEAP32[$17>>2] = 0;
  $18 = (($data$i) + 4|0);
  HEAP32[$18>>2] = 0;
  HEAP32[$data$i>>2] = 0;
  __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,564992,$data$i);
  $messageSent$0$off0 = 1;
 }
 $19 = (__Z30GetDisableImmediateDestructionv()|0);
 __Z30SetDisableImmediateDestructionb(1);
 $20 = (__ZN8Animator14FireBehavioursEN7mecanim12statemachine19StateMachineMessageE($this,8)|0);
 $21 = $20&1;
 $22 = $21 | $messageSent$0$off0;
 $23 = ($22|0)==(0);
 __Z30SetDisableImmediateDestructionb($19);
 if ($23) {
  $24 = (($this) + 345|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  if ($26) {
   $29 = 0;
  } else {
   __ZN8Animator22ApplyBuiltinRootMotionEv($this);
   $$pre = HEAP8[$24>>0]|0;
   $phitmp = ($$pre<<24>>24)!=(0);
   $29 = $phitmp;
  }
  $27 = (($this) + 100|0);
  $28 = HEAP32[$27>>2]|0;
  $30 = (__ZN11UnityEngine9Animation37HasGenericRootTransformPropertyValuesERKNS0_30AnimatorGenericBindingConstantEb($28,$29)|0);
  if ($30) {
   $31 = HEAP32[$27>>2]|0;
   $32 = (($this) + 80|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP8[$24>>0]|0;
   $36 = ($35<<24>>24)!=(0);
   __ZN11UnityEngine9Animation37SetGenericRootTransformPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayER9Transformb($31,$34,$6,$36);
  }
 }
 __ZNK9Transform11GetPositionEv($0,$6);
 $37 = (($this) + 84|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $pos$idx$val$i = Math_fround(HEAPF32[$0>>2]);
  $pos$idx1$i = (($0) + 4|0);
  $pos$idx1$val$i = Math_fround(HEAPF32[$pos$idx1$i>>2]);
  $pos$idx2$i = (($0) + 8|0);
  $pos$idx2$val$i = Math_fround(HEAPF32[$pos$idx2$i>>2]);
  $40 = (($38) + 8|0);
  HEAPF32[$40>>2] = $pos$idx$val$i;
  $41 = (($38) + 12|0);
  HEAPF32[$41>>2] = $pos$idx1$val$i;
  $42 = (($38) + 16|0);
  HEAPF32[$42>>2] = $pos$idx2$val$i;
  $43 = (($38) + 20|0);
  HEAPF32[$43>>2] = Math_fround(0.0);
 }
 __ZNK9Transform11GetRotationEv($1,$6);
 $44 = HEAP32[$37>>2]|0;
 $45 = ($44|0)==(0|0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $46 = Math_fround(HEAPF32[$1>>2]);
 $47 = (($1) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($1) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($1) + 12|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($44) + 24|0);
 HEAPF32[$53>>2] = $46;
 $54 = (($44) + 28|0);
 HEAPF32[$54>>2] = $48;
 $55 = (($44) + 32|0);
 HEAPF32[$55>>2] = $50;
 $56 = (($44) + 36|0);
 HEAPF32[$56>>2] = $52;
 STACKTOP = sp;return;
}
function __ZNK8Animator7IsHumanEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $73 = 0;
  STACKTOP = sp;return ($73|0);
 }
 HEAP32[$1>>2] = $3;
 $5 = HEAP32[560624>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 10;
 } else {
  $7 = (($5) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  do {
   if ($11) {
    $12 = (($5) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($5) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + ($15<<3)|0);
    $32 = $16;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$1);
    $17 = HEAP32[$pos$i$i$i$i>>2]|0;
    $18 = ($17|0)==(-1);
    $19 = (($5) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    if ($18) {
     $21 = (($5) + 32|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + ($22<<3)|0);
     $32 = $23;
     break;
    } else {
     $24 = (($20) + ($17<<3)|0);
     $32 = $24;
     break;
    }
   }
  } while(0);
  $25 = HEAP32[560624>>2]|0;
  $26 = (($25) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 32|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + ($29<<3)|0);
  $31 = ($32|0)==($30|0);
  if ($31) {
   label = 10;
  } else {
   $33 = (($32) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    label = 10;
   } else {
    $40 = $25;
   }
  }
 }
 do {
  if ((label|0) == 10) {
   $36 = HEAP32[$2>>2]|0;
   $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
   $phitmp$i = ($37|0)==(0|0);
   if ($phitmp$i) {
    $73 = 0;
    STACKTOP = sp;return ($73|0);
   } else {
    $$pre = HEAP32[560624>>2]|0;
    $40 = $$pre;
    break;
   }
  }
 } while(0);
 $38 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $38;
 $39 = ($40|0)==(0|0);
 if ($39) {
  label = 20;
 } else {
  $41 = (($40) + 36|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42|0)==($44|0);
  do {
   if ($45) {
    $46 = (($40) + 28|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($40) + 32|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($47) + ($49<<3)|0);
    $66 = $50;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$40,$0);
    $51 = HEAP32[$pos$i$i$i$i>>2]|0;
    $52 = ($51|0)==(-1);
    $53 = (($40) + 28|0);
    $54 = HEAP32[$53>>2]|0;
    if ($52) {
     $55 = (($40) + 32|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($54) + ($56<<3)|0);
     $66 = $57;
     break;
    } else {
     $58 = (($54) + ($51<<3)|0);
     $66 = $58;
     break;
    }
   }
  } while(0);
  $59 = HEAP32[560624>>2]|0;
  $60 = (($59) + 28|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) + 32|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($61) + ($63<<3)|0);
  $65 = ($66|0)==($64|0);
  if ($65) {
   label = 20;
  } else {
   $67 = (($66) + 4|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(0|0);
   if ($69) {
    label = 20;
   } else {
    $temp$0$i = $68;
   }
  }
 }
 if ((label|0) == 20) {
  $70 = HEAP32[$2>>2]|0;
  $71 = (__Z31ReadObjectFromPersistentManageri($70)|0);
  $temp$0$i = $71;
 }
 $72 = (__ZNK6Avatar7IsHumanEv($temp$0$i)|0);
 $73 = $72;
 STACKTOP = sp;return ($73|0);
}
function __ZNK8Animator26GetGlobalSpaceSkeletonPoseEPPN7mecanim8skeleton12SkeletonPoseE($this,$tempMemory) {
 $this = $this|0;
 $tempMemory = $tempMemory|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $tempAllocator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tempAllocator = sp;
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  HEAP32[$tempMemory>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 173|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $12 = HEAP32[628512>>2]|0;
  HEAP32[$tempAllocator>>2] = ((741984 + 8|0));
  $13 = (($tempAllocator) + 4|0);
  HEAP32[$13>>2] = $12;
  $14 = $6;
  $15 = HEAP32[$6>>2]|0;
  $16 = (($15) + ($14))|0;
  $17 = $16;
  $18 = (($6) + 4|0);
  HEAP32[$18>>2] = $17;
  $19 = (__ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($17,$tempAllocator)|0);
  $20 = (($6) + 16|0);
  $21 = $20;
  $22 = HEAP32[$20>>2]|0;
  $23 = (($22) + ($21))|0;
  $24 = $23;
  $25 = (($6) + 20|0);
  HEAP32[$25>>2] = $24;
  __ZN7mecanim8skeleton16SkeletonPoseCopyEPKNS0_12SkeletonPoseEPS1_($24,$19);
  $26 = (($19) + 4|0);
  $27 = $26;
  $28 = HEAP32[$26>>2]|0;
  $29 = (($28) + ($27))|0;
  $30 = $29;
  $31 = (($19) + 8|0);
  HEAP32[$31>>2] = $30;
  $32 = HEAP32[$7>>2]|0;
  $33 = (($32) + 8|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($32) + 12|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($32) + 16|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($32) + 20|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$30>>2] = $34;
  $41 = (($30) + 4|0);
  HEAPF32[$41>>2] = $36;
  $42 = (($30) + 8|0);
  HEAPF32[$42>>2] = $38;
  $43 = (($30) + 12|0);
  HEAPF32[$43>>2] = $40;
  $44 = (($32) + 24|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($32) + 28|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = (($32) + 32|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($32) + 36|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = (($30) + 16|0);
  HEAPF32[$52>>2] = $45;
  $53 = (($30) + 20|0);
  HEAPF32[$53>>2] = $47;
  $54 = (($30) + 24|0);
  HEAPF32[$54>>2] = $49;
  $55 = (($30) + 28|0);
  HEAPF32[$55>>2] = $51;
  $56 = (($32) + 40|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($32) + 44|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($32) + 48|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($32) + 52|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($30) + 32|0);
  HEAPF32[$64>>2] = $57;
  $65 = (($30) + 36|0);
  HEAPF32[$65>>2] = $59;
  $66 = (($30) + 40|0);
  HEAPF32[$66>>2] = $61;
  $67 = (($30) + 44|0);
  HEAPF32[$67>>2] = $63;
  $68 = HEAP32[$6>>2]|0;
  $69 = (($68) + ($14))|0;
  $70 = $69;
  HEAP32[$18>>2] = $70;
  __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_($70,$19,$19);
  HEAP32[$tempMemory>>2] = $19;
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 } else {
  HEAP32[$tempMemory>>2] = 0;
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN8Animator23SetPlaybackTimeInternalEf($this,$time) {
 $this = $this|0;
 $time = Math_fround($time);
 var $$01 = 0, $$byval_copy = 0, $$pre = 0, $$pre4 = 0, $$sink$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0);
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $effectiveTime = 0, $inPlaceAlloc = 0, $inPlaceAlloc1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 40|0;
 $0 = sp;
 $effectiveTime = sp + 4|0;
 $inPlaceAlloc = sp + 8|0;
 $inPlaceAlloc1 = sp + 24|0;
 HEAPF32[$effectiveTime>>2] = Math_fround(0.0);
 $1 = (($this) + 412|0);
 $2 = (__ZN14AvatarPlayback9PlayFrameEfRf($1,$time,$effectiveTime)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $49 = (($this) + 456|0);
  HEAPF32[$49>>2] = Math_fround(0.0);
  $50 = (($this) + 460|0);
  HEAPF32[$50>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $4 = Math_fround(HEAPF32[$effectiveTime>>2]);
 $5 = $4 > $time;
 if (!($5)) {
 }
 $6 = (($this) + 84|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 $$pre4 = (($this) + 112|0);
 if ($8) {
  $16 = 0;
 } else {
  $9 = HEAP32[$$pre4>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = (($this) + 64|0);
   $12 = (__Z8CopyBlobIN7mecanim9animation12AvatarMemoryEEPT_RKS3_RNS0_6memory9AllocatorERj($7,$11,$$pre4)|0);
   HEAP32[$6>>2] = $12;
   __ZN7mecanim9animation19DestroyAvatarMemoryEPNS0_12AvatarMemoryERNS_6memory9AllocatorE($7,$11);
   $$pre = HEAP32[$6>>2]|0;
   $16 = $$pre;
  } else {
   $16 = $7;
  }
 }
 $13 = (($this) + 460|0);
 HEAPF32[$13>>2] = $time;
 $14 = HEAP32[$$pre4>>2]|0;
 HEAP32[$inPlaceAlloc>>2] = ((771560 + 8|0));
 $15 = (($inPlaceAlloc) + 4|0);
 HEAP32[$15>>2] = $16;
 $17 = (($inPlaceAlloc) + 8|0);
 HEAP32[$17>>2] = $16;
 $18 = (($inPlaceAlloc) + 12|0);
 HEAP32[$18>>2] = $14;
 __THREW__ = 0;
 $19 = (invoke_iiii(1589,($2|0),($inPlaceAlloc|0),($$pre4|0))|0);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 do {
  if (!($21)) {
   $22 = ($19|0)==(0|0);
   if ($22) {
    $25 = HEAP32[$6>>2]|0;
    $26 = (($this) + 64|0);
    __THREW__ = 0;
    invoke_vii(3398,($25|0),($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = HEAP32[$$pre4>>2]|0;
    $30 = (($this) + 68|0);
    $31 = HEAP32[$30>>2]|0;
    HEAP32[$0>>2] = $31;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $32 = (invoke_iiiiiii(102,($29|0),4,($$byval_copy|0),0,(769408|0),395)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = HEAP32[$$pre4>>2]|0;
    HEAP32[$inPlaceAlloc1>>2] = ((771560 + 8|0));
    $36 = (($inPlaceAlloc1) + 4|0);
    HEAP32[$36>>2] = $32;
    $37 = (($inPlaceAlloc1) + 8|0);
    HEAP32[$37>>2] = $32;
    $38 = (($inPlaceAlloc1) + 12|0);
    HEAP32[$38>>2] = $35;
    __THREW__ = 0;
    $39 = (invoke_iiii(1589,($2|0),($inPlaceAlloc1|0),($$pre4|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     $43 = ___cxa_find_matching_catch()|0;
     $44 = tempRet0;
     $$01 = $43;$$sink$index2 = $44;
     ___resumeException($$01|0);
     // unreachable;
    }
    HEAP32[$6>>2] = $39;
    $42 = ($39|0)==(0|0);
    if ($42) {
     $45 = (($this) + 456|0);
     HEAPF32[$45>>2] = Math_fround(0.0);
     HEAPF32[$13>>2] = Math_fround(0.0);
     STACKTOP = sp;return;
    }
   } else {
    HEAP32[$6>>2] = $19;
   }
   $46 = Math_fround(HEAPF32[$effectiveTime>>2]);
   $47 = Math_fround($time - $46);
   $48 = (($this) + 456|0);
   HEAPF32[$48>>2] = $47;
   STACKTOP = sp;return;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $$01 = $23;$$sink$index2 = $24;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN8Animator6FKStepEv($this) {
 $this = $this|0;
 var $$idx15 = 0, $$idx15$val = Math_fround(0), $$idx16 = 0, $$idx16$val = Math_fround(0), $$idx17 = 0, $$idx17$val = Math_fround(0), $$idx6 = 0, $$idx6$val = Math_fround(0), $$idx7 = 0, $$idx7$val = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0), $$phi$trans$insert174 = 0, $$pre = 0, $$pre$phi179Z2D = 0, $$pre$phi181Z2D = 0, $$pre$phi183Z2D = 0, $$pre$phi185Z2D = 0, $$pre$phiZ2D = 0, $$pre173 = 0;
 var $$pre175 = 0, $$pre177 = 0, $$pre178 = 0, $$pre180 = 0, $$pre182 = 0, $$pre184 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0;
 var $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0);
 var $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0);
 var $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0);
 var $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0);
 var $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = Math_fround(0), $397 = 0, $398 = Math_fround(0), $399 = 0;
 var $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0);
 var $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0);
 var $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0);
 var $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = 0, $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = 0, $482 = Math_fround(0), $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0);
 var $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = Math_fround(0), $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0);
 var $507 = 0, $508 = Math_fround(0), $509 = 0, $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = 0, $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0);
 var $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0);
 var $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = 0;
 var $561 = 0, $562 = 0, $563 = 0, $564 = Math_fround(0), $565 = Math_fround(0), $566 = 0, $567 = Math_fround(0), $568 = Math_fround(0), $569 = 0, $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0);
 var $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0);
 var $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0);
 var $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = Math_fround(0), $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0;
 var $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0;
 var $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = Math_fround(0), $676 = 0, $677 = Math_fround(0), $678 = Math_fround(0), $679 = 0, $68 = 0, $680 = Math_fround(0), $681 = 0, $682 = Math_fround(0), $683 = Math_fround(0), $684 = 0, $685 = Math_fround(0), $686 = 0, $687 = Math_fround(0);
 var $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = 0, $693 = Math_fround(0), $694 = Math_fround(0), $695 = 0, $696 = Math_fround(0), $697 = Math_fround(0), $698 = 0, $699 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = 0, $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0);
 var $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0);
 var $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = 0, $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = 0, $731 = Math_fround(0), $732 = Math_fround(0), $733 = 0, $734 = Math_fround(0), $735 = Math_fround(0), $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = Math_fround(0);
 var $741 = 0, $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = 0, $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = 0, $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = 0, $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0);
 var $76 = Math_fround(0), $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0);
 var $778 = Math_fround(0), $779 = Math_fround(0), $78 = Math_fround(0), $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0);
 var $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = 0, $81 = Math_fround(0), $810 = 0, $811 = 0, $812 = 0;
 var $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = Math_fround(0), $820 = 0, $821 = Math_fround(0), $822 = 0, $823 = Math_fround(0), $824 = Math_fround(0), $825 = 0, $826 = Math_fround(0), $827 = Math_fround(0), $828 = 0, $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0);
 var $831 = 0, $832 = Math_fround(0), $833 = Math_fround(0), $834 = 0, $835 = Math_fround(0), $836 = Math_fround(0), $837 = 0, $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = 0, $844 = Math_fround(0), $845 = Math_fround(0), $846 = 0, $847 = Math_fround(0), $848 = Math_fround(0), $849 = 0;
 var $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = 0, $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0);
 var $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = 0, $879 = Math_fround(0), $88 = Math_fround(0), $880 = Math_fround(0), $881 = 0, $882 = Math_fround(0), $883 = Math_fround(0), $884 = 0, $885 = Math_fround(0);
 var $886 = Math_fround(0), $887 = 0, $888 = 0, $889 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = (($this) + 200|0);
 ;HEAP32[$4+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[616680+8>>2]|0;
 $5 = (($this) + 212|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($this) + 216|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 220|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 224|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 228|0);
 ;HEAP32[$9+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[616680+8>>2]|0;
 $10 = (($this) + 240|0);
 ;HEAP32[$10+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[616680+8>>2]|0;
 $11 = (($this) + 384|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $$pre177 = (($this) + 76|0);
  $$pre178 = (($this) + 80|0);
  $$pre180 = (($this) + 84|0);
  $$pre182 = (($this) + 88|0);
  $$pre184 = (($this) + 72|0);
  $$pre$phi179Z2D = $$pre178;$$pre$phi181Z2D = $$pre180;$$pre$phi183Z2D = $$pre182;$$pre$phi185Z2D = $$pre184;$$pre$phiZ2D = $$pre177;
 } else {
  $14 = (($this) + 72|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($this) + 76|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($this) + 80|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($this) + 84|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($this) + 88|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($this) + 92|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($this) + 108|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($27) + 36|0);
  $29 = HEAP32[$28>>2]|0;
  __ZN7mecanim9animation16EvaluateAvatarSMEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantERKNS0_12AnimationSetE($15,$17,$19,$21,$23,$25,$29);
  $$pre$phi179Z2D = $18;$$pre$phi181Z2D = $20;$$pre$phi183Z2D = $22;$$pre$phi185Z2D = $14;$$pre$phiZ2D = $16;
 }
 $30 = (($this) + 100|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 32|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$$pre$phiZ2D>>2]|0;
 $35 = HEAP32[$$pre$phi179Z2D>>2]|0;
 $36 = HEAP32[$$pre$phi181Z2D>>2]|0;
 $37 = HEAP32[$$pre$phi183Z2D>>2]|0;
 $38 = (($this) + 96|0);
 $39 = HEAP32[$38>>2]|0;
 __ZN7mecanim9animation20EvaluateAvatarLayersEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPNS0_18AnimationSetMemoryE($33,$34,$35,$36,$37,$39);
 $40 = HEAP32[$$pre$phi185Z2D>>2]|0;
 $41 = (($40) + 36|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if ($43) {
  label = 13;
 } else {
  $44 = $41;
  $45 = (($44) + ($42))|0;
  $46 = $45;
  $47 = (($46) + 48|0);
  $48 = $47;
  $49 = HEAP32[$47>>2]|0;
  $50 = (($49) + ($48))|0;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==(0);
  if ($53) {
   label = 13;
  } else {
   $54 = HEAP32[$$pre$phi179Z2D>>2]|0;
   $55 = (($54) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($46) + 392|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = (($56) + 372|0);
   $60 = Math_fround(HEAPF32[$59>>2]);
   $61 = Math_fround($58 * $60);
   $62 = (($56) + 376|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = Math_fround($58 * $63);
   $65 = (($56) + 380|0);
   $66 = Math_fround(HEAPF32[$65>>2]);
   $67 = Math_fround($58 * $66);
   $68 = (($56) + 384|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = Math_fround($58 * $69);
   HEAPF32[$59>>2] = $61;
   HEAPF32[$62>>2] = $64;
   HEAPF32[$65>>2] = $67;
   HEAPF32[$68>>2] = $70;
   __ZN8Animator11TargetMatchEv($this);
   $71 = (($this) + 344|0);
   HEAP8[$71>>0] = 0;
   $72 = HEAP32[$$pre$phi181Z2D>>2]|0;
   $73 = ($72|0)==(0|0);
   if ($73) {
    $125 = Math_fround(0.0);$127 = Math_fround(0.0);$129 = Math_fround(0.0);$137 = Math_fround(1.0);
   } else {
    $74 = (($72) + 24|0);
    $75 = Math_fround(HEAPF32[$74>>2]);
    $76 = Math_fround($75 * $75);
    $77 = (($72) + 28|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = Math_fround($78 * $78);
    $80 = (($72) + 32|0);
    $81 = Math_fround(HEAPF32[$80>>2]);
    $82 = Math_fround($81 * $81);
    $83 = (($72) + 36|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = Math_fround($84 * $84);
    $86 = Math_fround($76 + $79);
    $87 = Math_fround($82 + $85);
    $88 = Math_fround($86 + $87);
    $89 = (Math_fround(Math_sqrt((Math_fround($88)))));
    $90 = Math_fround(Math_fround(1.0) / $89);
    $91 = Math_fround($75 * $90);
    $92 = Math_fround($78 * $90);
    $93 = Math_fround($81 * $90);
    $94 = Math_fround($84 * $90);
    $125 = $91;$127 = $92;$129 = $93;$137 = $94;
   }
   $95 = HEAP32[$$pre$phi179Z2D>>2]|0;
   $96 = (($95) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   __ZN7mecanim9animation28MotionOutputGetDeltaPositionEPKNS0_12MotionOutputE($0,$97);
   $98 = HEAP32[$$pre$phi181Z2D>>2]|0;
   $99 = Math_fround(HEAPF32[$0>>2]);
   $100 = (($98) + 40|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = Math_fround($99 * $101);
   $103 = (($0) + 4|0);
   $104 = Math_fround(HEAPF32[$103>>2]);
   $105 = (($98) + 44|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = Math_fround($104 * $106);
   $108 = (($0) + 8|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = (($98) + 48|0);
   $111 = Math_fround(HEAPF32[$110>>2]);
   $112 = Math_fround($109 * $111);
   $113 = HEAP32[$$pre$phi185Z2D>>2]|0;
   $114 = (($113) + 36|0);
   $115 = $114;
   $116 = HEAP32[$114>>2]|0;
   $117 = (($115) + ($116))|0;
   $118 = $117;
   $119 = (($118) + 392|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = Math_fround($102 * $120);
   $122 = Math_fround($107 * $120);
   $123 = Math_fround($112 * $120);
   $124 = Math_fround($125 * Math_fround(2.0));
   $126 = Math_fround($127 * Math_fround(2.0));
   $128 = Math_fround($129 * Math_fround(2.0));
   $130 = Math_fround($125 * $124);
   $131 = Math_fround($127 * $126);
   $132 = Math_fround($129 * $128);
   $133 = Math_fround($125 * $126);
   $134 = Math_fround($128 * $125);
   $135 = Math_fround($127 * $128);
   $136 = Math_fround($137 * $124);
   $138 = Math_fround($137 * $126);
   $139 = Math_fround($137 * $128);
   $140 = Math_fround($132 + $131);
   $141 = Math_fround(Math_fround(1.0) - $140);
   $142 = Math_fround($141 * $121);
   $143 = Math_fround($133 - $139);
   $144 = Math_fround($143 * $122);
   $145 = Math_fround($144 + $142);
   $146 = Math_fround($134 + $138);
   $147 = Math_fround($146 * $123);
   $148 = Math_fround($147 + $145);
   $149 = Math_fround($139 + $133);
   $150 = Math_fround($149 * $121);
   $151 = Math_fround($132 + $130);
   $152 = Math_fround(Math_fround(1.0) - $151);
   $153 = Math_fround($152 * $122);
   $154 = Math_fround($150 + $153);
   $155 = Math_fround($135 - $136);
   $156 = Math_fround($155 * $123);
   $157 = Math_fround($156 + $154);
   $158 = Math_fround($134 - $138);
   $159 = Math_fround($158 * $121);
   $160 = Math_fround($135 + $136);
   $161 = Math_fround($160 * $122);
   $162 = Math_fround($159 + $161);
   $163 = Math_fround($131 + $130);
   $164 = Math_fround(Math_fround(1.0) - $163);
   $165 = Math_fround($164 * $123);
   $166 = Math_fround($165 + $162);
   $167 = (($this) + 200|0);
   HEAPF32[$167>>2] = $148;
   $168 = (($this) + 204|0);
   HEAPF32[$168>>2] = $157;
   $169 = (($this) + 208|0);
   HEAPF32[$169>>2] = $166;
   $170 = HEAP32[$$pre$phi179Z2D>>2]|0;
   $171 = (($170) + 8|0);
   $172 = HEAP32[$171>>2]|0;
   __ZN7mecanim9animation28MotionOutputGetDeltaRotationEPKNS0_12MotionOutputE($1,$172);
   $173 = Math_fround(HEAPF32[$1>>2]);
   $174 = Math_fround($173 * $173);
   $175 = (($1) + 4|0);
   $176 = Math_fround(HEAPF32[$175>>2]);
   $177 = Math_fround($176 * $176);
   $178 = (($1) + 8|0);
   $179 = Math_fround(HEAPF32[$178>>2]);
   $180 = Math_fround($179 * $179);
   $181 = (($1) + 12|0);
   $182 = Math_fround(HEAPF32[$181>>2]);
   $183 = Math_fround($182 * $182);
   $184 = Math_fround($174 + $177);
   $185 = Math_fround($180 + $183);
   $186 = Math_fround($184 + $185);
   $187 = (Math_fround(Math_sqrt((Math_fround($186)))));
   $188 = Math_fround(Math_fround(1.0) / $187);
   $189 = Math_fround($173 * $188);
   $190 = Math_fround($176 * $188);
   $191 = Math_fround($179 * $188);
   $192 = Math_fround($182 * $188);
   HEAPF32[$5>>2] = $189;
   HEAPF32[$6>>2] = $190;
   HEAPF32[$7>>2] = $191;
   HEAPF32[$8>>2] = $192;
   $193 = HEAP32[$$pre$phi181Z2D>>2]|0;
   $194 = ($193|0)==(0|0);
   if ($194) {
    $246 = Math_fround(0.0);$248 = Math_fround(0.0);$250 = Math_fround(0.0);$258 = Math_fround(1.0);
   } else {
    $195 = (($193) + 24|0);
    $196 = Math_fround(HEAPF32[$195>>2]);
    $197 = Math_fround($196 * $196);
    $198 = (($193) + 28|0);
    $199 = Math_fround(HEAPF32[$198>>2]);
    $200 = Math_fround($199 * $199);
    $201 = (($193) + 32|0);
    $202 = Math_fround(HEAPF32[$201>>2]);
    $203 = Math_fround($202 * $202);
    $204 = (($193) + 36|0);
    $205 = Math_fround(HEAPF32[$204>>2]);
    $206 = Math_fround($205 * $205);
    $207 = Math_fround($197 + $200);
    $208 = Math_fround($203 + $206);
    $209 = Math_fround($207 + $208);
    $210 = (Math_fround(Math_sqrt((Math_fround($209)))));
    $211 = Math_fround(Math_fround(1.0) / $210);
    $212 = Math_fround($196 * $211);
    $213 = Math_fround($199 * $211);
    $214 = Math_fround($202 * $211);
    $215 = Math_fround($205 * $211);
    $246 = $212;$248 = $213;$250 = $214;$258 = $215;
   }
   $216 = HEAP32[$$pre$phi179Z2D>>2]|0;
   $217 = (($216) + 8|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = (($218) + 4|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = (($193) + 40|0);
   $222 = Math_fround(HEAPF32[$221>>2]);
   $223 = Math_fround($220 * $222);
   $224 = (($218) + 8|0);
   $225 = Math_fround(HEAPF32[$224>>2]);
   $226 = (($193) + 44|0);
   $227 = Math_fround(HEAPF32[$226>>2]);
   $228 = Math_fround($225 * $227);
   $229 = (($218) + 12|0);
   $230 = Math_fround(HEAPF32[$229>>2]);
   $231 = (($193) + 48|0);
   $232 = Math_fround(HEAPF32[$231>>2]);
   $233 = Math_fround($230 * $232);
   $234 = HEAP32[$$pre$phi185Z2D>>2]|0;
   $235 = (($234) + 36|0);
   $236 = $235;
   $237 = HEAP32[$235>>2]|0;
   $238 = (($236) + ($237))|0;
   $239 = $238;
   $240 = (($239) + 392|0);
   $241 = Math_fround(HEAPF32[$240>>2]);
   $242 = Math_fround($223 * $241);
   $243 = Math_fround($228 * $241);
   $244 = Math_fround($233 * $241);
   $245 = Math_fround($246 * Math_fround(2.0));
   $247 = Math_fround($248 * Math_fround(2.0));
   $249 = Math_fround($250 * Math_fround(2.0));
   $251 = Math_fround($246 * $245);
   $252 = Math_fround($248 * $247);
   $253 = Math_fround($250 * $249);
   $254 = Math_fround($246 * $247);
   $255 = Math_fround($249 * $246);
   $256 = Math_fround($248 * $249);
   $257 = Math_fround($258 * $245);
   $259 = Math_fround($258 * $247);
   $260 = Math_fround($258 * $249);
   $261 = Math_fround($253 + $252);
   $262 = Math_fround(Math_fround(1.0) - $261);
   $263 = Math_fround($262 * $242);
   $264 = Math_fround($254 - $260);
   $265 = Math_fround($264 * $243);
   $266 = Math_fround($265 + $263);
   $267 = Math_fround($255 + $259);
   $268 = Math_fround($267 * $244);
   $269 = Math_fround($268 + $266);
   $270 = Math_fround($260 + $254);
   $271 = Math_fround($270 * $242);
   $272 = Math_fround($253 + $251);
   $273 = Math_fround(Math_fround(1.0) - $272);
   $274 = Math_fround($273 * $243);
   $275 = Math_fround($271 + $274);
   $276 = Math_fround($256 - $257);
   $277 = Math_fround($276 * $244);
   $278 = Math_fround($277 + $275);
   $279 = Math_fround($255 - $259);
   $280 = Math_fround($279 * $242);
   $281 = Math_fround($256 + $257);
   $282 = Math_fround($281 * $243);
   $283 = Math_fround($280 + $282);
   $284 = Math_fround($252 + $251);
   $285 = Math_fround(Math_fround(1.0) - $284);
   $286 = Math_fround($285 * $244);
   $287 = Math_fround($286 + $283);
   $288 = (($this) + 228|0);
   HEAPF32[$288>>2] = $269;
   $289 = (($this) + 232|0);
   HEAPF32[$289>>2] = $278;
   $290 = (($this) + 236|0);
   HEAPF32[$290>>2] = $287;
   if ($194) {
    $314 = Math_fround(0.0);$316 = Math_fround(0.0);$318 = Math_fround(0.0);$326 = Math_fround(1.0);
   } else {
    $291 = (($193) + 24|0);
    $292 = Math_fround(HEAPF32[$291>>2]);
    $293 = Math_fround($292 * $292);
    $294 = (($193) + 28|0);
    $295 = Math_fround(HEAPF32[$294>>2]);
    $296 = Math_fround($295 * $295);
    $297 = (($193) + 32|0);
    $298 = Math_fround(HEAPF32[$297>>2]);
    $299 = Math_fround($298 * $298);
    $300 = (($193) + 36|0);
    $301 = Math_fround(HEAPF32[$300>>2]);
    $302 = Math_fround($301 * $301);
    $303 = Math_fround($293 + $296);
    $304 = Math_fround($299 + $302);
    $305 = Math_fround($303 + $304);
    $306 = (Math_fround(Math_sqrt((Math_fround($305)))));
    $307 = Math_fround(Math_fround(1.0) / $306);
    $308 = Math_fround($292 * $307);
    $309 = Math_fround($295 * $307);
    $310 = Math_fround($298 * $307);
    $311 = Math_fround($301 * $307);
    $314 = $308;$316 = $309;$318 = $310;$326 = $311;
   }
   $312 = HEAP32[$217>>2]|0;
   $$idx15 = (($312) + 20|0);
   $$idx15$val = Math_fround(HEAPF32[$$idx15>>2]);
   $$idx16 = (($312) + 24|0);
   $$idx16$val = Math_fround(HEAPF32[$$idx16>>2]);
   $$idx17 = (($312) + 28|0);
   $$idx17$val = Math_fround(HEAPF32[$$idx17>>2]);
   $313 = Math_fround($314 * Math_fround(2.0));
   $315 = Math_fround($316 * Math_fround(2.0));
   $317 = Math_fround($318 * Math_fround(2.0));
   $319 = Math_fround($314 * $313);
   $320 = Math_fround($316 * $315);
   $321 = Math_fround($318 * $317);
   $322 = Math_fround($314 * $315);
   $323 = Math_fround($317 * $314);
   $324 = Math_fround($316 * $317);
   $325 = Math_fround($326 * $313);
   $327 = Math_fround($326 * $315);
   $328 = Math_fround($326 * $317);
   $329 = Math_fround($321 + $320);
   $330 = Math_fround(Math_fround(1.0) - $329);
   $331 = Math_fround($$idx15$val * $330);
   $332 = Math_fround($322 - $328);
   $333 = Math_fround($332 * $$idx16$val);
   $334 = Math_fround($331 + $333);
   $335 = Math_fround($323 + $327);
   $336 = Math_fround($335 * $$idx17$val);
   $337 = Math_fround($336 + $334);
   $338 = Math_fround($328 + $322);
   $339 = Math_fround($338 * $$idx15$val);
   $340 = Math_fround($321 + $319);
   $341 = Math_fround(Math_fround(1.0) - $340);
   $342 = Math_fround($341 * $$idx16$val);
   $343 = Math_fround($339 + $342);
   $344 = Math_fround($324 - $325);
   $345 = Math_fround($344 * $$idx17$val);
   $346 = Math_fround($343 + $345);
   $347 = Math_fround($323 - $327);
   $348 = Math_fround($347 * $$idx15$val);
   $349 = Math_fround($324 + $325);
   $350 = Math_fround($349 * $$idx16$val);
   $351 = Math_fround($348 + $350);
   $352 = Math_fround($320 + $319);
   $353 = Math_fround(Math_fround(1.0) - $352);
   $354 = Math_fround($353 * $$idx17$val);
   $355 = Math_fround($351 + $354);
   $356 = (($this) + 240|0);
   HEAPF32[$356>>2] = $337;
   $357 = (($this) + 244|0);
   HEAPF32[$357>>2] = $346;
   $358 = (($this) + 248|0);
   HEAPF32[$358>>2] = $355;
   $632 = $234;
  }
 }
 do {
  if ((label|0) == 13) {
   $359 = (($40) + 68|0);
   $360 = HEAP32[$359>>2]|0;
   $361 = ($360|0)==(-1);
   if ($361) {
    $362 = HEAP32[$$pre$phiZ2D>>2]|0;
    $363 = (($362) + 22|0);
    $364 = HEAP8[$363>>0]|0;
    $365 = ($364<<24>>24)==(0);
    if ($365) {
     $632 = $40;
     break;
    }
   }
   $366 = HEAP32[$$pre$phi181Z2D>>2]|0;
   $367 = ($366|0)==(0|0);
   if ($367) {
    $408 = Math_fround(0.0);$410 = Math_fround(0.0);$412 = Math_fround(0.0);$420 = Math_fround(1.0);
   } else {
    $368 = (($366) + 24|0);
    $369 = Math_fround(HEAPF32[$368>>2]);
    $370 = Math_fround($369 * $369);
    $371 = (($366) + 28|0);
    $372 = Math_fround(HEAPF32[$371>>2]);
    $373 = Math_fround($372 * $372);
    $374 = (($366) + 32|0);
    $375 = Math_fround(HEAPF32[$374>>2]);
    $376 = Math_fround($375 * $375);
    $377 = (($366) + 36|0);
    $378 = Math_fround(HEAPF32[$377>>2]);
    $379 = Math_fround($378 * $378);
    $380 = Math_fround($370 + $373);
    $381 = Math_fround($376 + $379);
    $382 = Math_fround($380 + $381);
    $383 = (Math_fround(Math_sqrt((Math_fround($382)))));
    $384 = Math_fround(Math_fround(1.0) / $383);
    $385 = Math_fround($369 * $384);
    $386 = Math_fround($372 * $384);
    $387 = Math_fround($375 * $384);
    $388 = Math_fround($378 * $384);
    $408 = $385;$410 = $386;$412 = $387;$420 = $388;
   }
   $389 = HEAP32[$$pre$phi179Z2D>>2]|0;
   $390 = (($389) + 8|0);
   $391 = HEAP32[$390>>2]|0;
   __ZN7mecanim9animation28MotionOutputGetDeltaPositionEPKNS0_12MotionOutputE($2,$391);
   $392 = HEAP32[$$pre$phi181Z2D>>2]|0;
   $393 = Math_fround(HEAPF32[$2>>2]);
   $394 = (($392) + 40|0);
   $395 = Math_fround(HEAPF32[$394>>2]);
   $396 = Math_fround($393 * $395);
   $397 = (($2) + 4|0);
   $398 = Math_fround(HEAPF32[$397>>2]);
   $399 = (($392) + 44|0);
   $400 = Math_fround(HEAPF32[$399>>2]);
   $401 = Math_fround($398 * $400);
   $402 = (($2) + 8|0);
   $403 = Math_fround(HEAPF32[$402>>2]);
   $404 = (($392) + 48|0);
   $405 = Math_fround(HEAPF32[$404>>2]);
   $406 = Math_fround($403 * $405);
   $407 = Math_fround($408 * Math_fround(2.0));
   $409 = Math_fround($410 * Math_fround(2.0));
   $411 = Math_fround($412 * Math_fround(2.0));
   $413 = Math_fround($408 * $407);
   $414 = Math_fround($410 * $409);
   $415 = Math_fround($412 * $411);
   $416 = Math_fround($408 * $409);
   $417 = Math_fround($411 * $408);
   $418 = Math_fround($410 * $411);
   $419 = Math_fround($420 * $407);
   $421 = Math_fround($420 * $409);
   $422 = Math_fround($420 * $411);
   $423 = Math_fround($415 + $414);
   $424 = Math_fround(Math_fround(1.0) - $423);
   $425 = Math_fround($424 * $396);
   $426 = Math_fround($416 - $422);
   $427 = Math_fround($426 * $401);
   $428 = Math_fround($425 + $427);
   $429 = Math_fround($417 + $421);
   $430 = Math_fround($429 * $406);
   $431 = Math_fround($428 + $430);
   $432 = Math_fround($422 + $416);
   $433 = Math_fround($432 * $396);
   $434 = Math_fround($415 + $413);
   $435 = Math_fround(Math_fround(1.0) - $434);
   $436 = Math_fround($435 * $401);
   $437 = Math_fround($433 + $436);
   $438 = Math_fround($418 - $419);
   $439 = Math_fround($438 * $406);
   $440 = Math_fround($437 + $439);
   $441 = Math_fround($417 - $421);
   $442 = Math_fround($441 * $396);
   $443 = Math_fround($418 + $419);
   $444 = Math_fround($443 * $401);
   $445 = Math_fround($442 + $444);
   $446 = Math_fround($414 + $413);
   $447 = Math_fround(Math_fround(1.0) - $446);
   $448 = Math_fround($447 * $406);
   $449 = Math_fround($445 + $448);
   $450 = (($this) + 200|0);
   HEAPF32[$450>>2] = $431;
   $451 = (($this) + 204|0);
   HEAPF32[$451>>2] = $440;
   $452 = (($this) + 208|0);
   HEAPF32[$452>>2] = $449;
   $453 = HEAP32[$$pre$phi179Z2D>>2]|0;
   $454 = (($453) + 8|0);
   $455 = HEAP32[$454>>2]|0;
   __ZN7mecanim9animation28MotionOutputGetDeltaRotationEPKNS0_12MotionOutputE($3,$455);
   $456 = Math_fround(HEAPF32[$3>>2]);
   $457 = Math_fround($456 * $456);
   $458 = (($3) + 4|0);
   $459 = Math_fround(HEAPF32[$458>>2]);
   $460 = Math_fround($459 * $459);
   $461 = (($3) + 8|0);
   $462 = Math_fround(HEAPF32[$461>>2]);
   $463 = Math_fround($462 * $462);
   $464 = (($3) + 12|0);
   $465 = Math_fround(HEAPF32[$464>>2]);
   $466 = Math_fround($465 * $465);
   $467 = Math_fround($457 + $460);
   $468 = Math_fround($463 + $466);
   $469 = Math_fround($467 + $468);
   $470 = (Math_fround(Math_sqrt((Math_fround($469)))));
   $471 = Math_fround(Math_fround(1.0) / $470);
   $472 = Math_fround($456 * $471);
   $473 = Math_fround($459 * $471);
   $474 = Math_fround($462 * $471);
   $475 = Math_fround($465 * $471);
   HEAPF32[$5>>2] = $472;
   HEAPF32[$6>>2] = $473;
   HEAPF32[$7>>2] = $474;
   HEAPF32[$8>>2] = $475;
   $476 = HEAP32[$$pre$phi181Z2D>>2]|0;
   $477 = ($476|0)==(0|0);
   if ($477) {
    $518 = Math_fround(0.0);$520 = Math_fround(0.0);$522 = Math_fround(0.0);$530 = Math_fround(1.0);
   } else {
    $478 = (($476) + 24|0);
    $479 = Math_fround(HEAPF32[$478>>2]);
    $480 = Math_fround($479 * $479);
    $481 = (($476) + 28|0);
    $482 = Math_fround(HEAPF32[$481>>2]);
    $483 = Math_fround($482 * $482);
    $484 = (($476) + 32|0);
    $485 = Math_fround(HEAPF32[$484>>2]);
    $486 = Math_fround($485 * $485);
    $487 = (($476) + 36|0);
    $488 = Math_fround(HEAPF32[$487>>2]);
    $489 = Math_fround($488 * $488);
    $490 = Math_fround($480 + $483);
    $491 = Math_fround($486 + $489);
    $492 = Math_fround($490 + $491);
    $493 = (Math_fround(Math_sqrt((Math_fround($492)))));
    $494 = Math_fround(Math_fround(1.0) / $493);
    $495 = Math_fround($479 * $494);
    $496 = Math_fround($482 * $494);
    $497 = Math_fround($485 * $494);
    $498 = Math_fround($488 * $494);
    $518 = $495;$520 = $496;$522 = $497;$530 = $498;
   }
   $499 = HEAP32[$$pre$phi179Z2D>>2]|0;
   $500 = (($499) + 8|0);
   $501 = HEAP32[$500>>2]|0;
   $502 = (($501) + 4|0);
   $503 = Math_fround(HEAPF32[$502>>2]);
   $504 = (($476) + 40|0);
   $505 = Math_fround(HEAPF32[$504>>2]);
   $506 = Math_fround($503 * $505);
   $507 = (($501) + 8|0);
   $508 = Math_fround(HEAPF32[$507>>2]);
   $509 = (($476) + 44|0);
   $510 = Math_fround(HEAPF32[$509>>2]);
   $511 = Math_fround($508 * $510);
   $512 = (($501) + 12|0);
   $513 = Math_fround(HEAPF32[$512>>2]);
   $514 = (($476) + 48|0);
   $515 = Math_fround(HEAPF32[$514>>2]);
   $516 = Math_fround($513 * $515);
   $517 = Math_fround($518 * Math_fround(2.0));
   $519 = Math_fround($520 * Math_fround(2.0));
   $521 = Math_fround($522 * Math_fround(2.0));
   $523 = Math_fround($518 * $517);
   $524 = Math_fround($520 * $519);
   $525 = Math_fround($522 * $521);
   $526 = Math_fround($518 * $519);
   $527 = Math_fround($521 * $518);
   $528 = Math_fround($520 * $521);
   $529 = Math_fround($530 * $517);
   $531 = Math_fround($530 * $519);
   $532 = Math_fround($530 * $521);
   $533 = Math_fround($525 + $524);
   $534 = Math_fround(Math_fround(1.0) - $533);
   $535 = Math_fround($534 * $506);
   $536 = Math_fround($526 - $532);
   $537 = Math_fround($536 * $511);
   $538 = Math_fround($535 + $537);
   $539 = Math_fround($527 + $531);
   $540 = Math_fround($539 * $516);
   $541 = Math_fround($538 + $540);
   $542 = Math_fround($532 + $526);
   $543 = Math_fround($542 * $506);
   $544 = Math_fround($525 + $523);
   $545 = Math_fround(Math_fround(1.0) - $544);
   $546 = Math_fround($545 * $511);
   $547 = Math_fround($543 + $546);
   $548 = Math_fround($528 - $529);
   $549 = Math_fround($548 * $516);
   $550 = Math_fround($547 + $549);
   $551 = Math_fround($527 - $531);
   $552 = Math_fround($551 * $506);
   $553 = Math_fround($528 + $529);
   $554 = Math_fround($553 * $511);
   $555 = Math_fround($552 + $554);
   $556 = Math_fround($524 + $523);
   $557 = Math_fround(Math_fround(1.0) - $556);
   $558 = Math_fround($557 * $516);
   $559 = Math_fround($555 + $558);
   $560 = (($this) + 228|0);
   HEAPF32[$560>>2] = $541;
   $561 = (($this) + 232|0);
   HEAPF32[$561>>2] = $550;
   $562 = (($this) + 236|0);
   HEAPF32[$562>>2] = $559;
   if ($477) {
    $586 = Math_fround(0.0);$588 = Math_fround(0.0);$590 = Math_fround(0.0);$598 = Math_fround(1.0);
   } else {
    $563 = (($476) + 24|0);
    $564 = Math_fround(HEAPF32[$563>>2]);
    $565 = Math_fround($564 * $564);
    $566 = (($476) + 28|0);
    $567 = Math_fround(HEAPF32[$566>>2]);
    $568 = Math_fround($567 * $567);
    $569 = (($476) + 32|0);
    $570 = Math_fround(HEAPF32[$569>>2]);
    $571 = Math_fround($570 * $570);
    $572 = (($476) + 36|0);
    $573 = Math_fround(HEAPF32[$572>>2]);
    $574 = Math_fround($573 * $573);
    $575 = Math_fround($565 + $568);
    $576 = Math_fround($571 + $574);
    $577 = Math_fround($575 + $576);
    $578 = (Math_fround(Math_sqrt((Math_fround($577)))));
    $579 = Math_fround(Math_fround(1.0) / $578);
    $580 = Math_fround($564 * $579);
    $581 = Math_fround($567 * $579);
    $582 = Math_fround($570 * $579);
    $583 = Math_fround($573 * $579);
    $586 = $580;$588 = $581;$590 = $582;$598 = $583;
   }
   $584 = HEAP32[$500>>2]|0;
   $$idx6 = (($584) + 20|0);
   $$idx6$val = Math_fround(HEAPF32[$$idx6>>2]);
   $$idx7 = (($584) + 24|0);
   $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
   $$idx8 = (($584) + 28|0);
   $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
   $585 = Math_fround($586 * Math_fround(2.0));
   $587 = Math_fround($588 * Math_fround(2.0));
   $589 = Math_fround($590 * Math_fround(2.0));
   $591 = Math_fround($586 * $585);
   $592 = Math_fround($588 * $587);
   $593 = Math_fround($590 * $589);
   $594 = Math_fround($586 * $587);
   $595 = Math_fround($589 * $586);
   $596 = Math_fround($588 * $589);
   $597 = Math_fround($598 * $585);
   $599 = Math_fround($598 * $587);
   $600 = Math_fround($598 * $589);
   $601 = Math_fround($593 + $592);
   $602 = Math_fround(Math_fround(1.0) - $601);
   $603 = Math_fround($$idx6$val * $602);
   $604 = Math_fround($594 - $600);
   $605 = Math_fround($604 * $$idx7$val);
   $606 = Math_fround($603 + $605);
   $607 = Math_fround($595 + $599);
   $608 = Math_fround($607 * $$idx8$val);
   $609 = Math_fround($608 + $606);
   $610 = Math_fround($600 + $594);
   $611 = Math_fround($610 * $$idx6$val);
   $612 = Math_fround($593 + $591);
   $613 = Math_fround(Math_fround(1.0) - $612);
   $614 = Math_fround($613 * $$idx7$val);
   $615 = Math_fround($611 + $614);
   $616 = Math_fround($596 - $597);
   $617 = Math_fround($616 * $$idx8$val);
   $618 = Math_fround($615 + $617);
   $619 = Math_fround($595 - $599);
   $620 = Math_fround($619 * $$idx6$val);
   $621 = Math_fround($596 + $597);
   $622 = Math_fround($621 * $$idx7$val);
   $623 = Math_fround($620 + $622);
   $624 = Math_fround($592 + $591);
   $625 = Math_fround(Math_fround(1.0) - $624);
   $626 = Math_fround($625 * $$idx8$val);
   $627 = Math_fround($623 + $626);
   $628 = (($this) + 240|0);
   HEAPF32[$628>>2] = $609;
   $629 = (($this) + 244|0);
   HEAPF32[$629>>2] = $618;
   $630 = (($this) + 248|0);
   HEAPF32[$630>>2] = $627;
   $$pre = HEAP32[$$pre$phi185Z2D>>2]|0;
   $632 = $$pre;
  }
 } while(0);
 $631 = (($632) + 36|0);
 $633 = HEAP32[$631>>2]|0;
 $634 = ($633|0)==(0);
 if ($634) {
  label = 24;
 } else {
  $635 = $631;
  $636 = (($635) + ($633))|0;
  $637 = $636;
  $638 = (($637) + 48|0);
  $639 = $638;
  $640 = HEAP32[$638>>2]|0;
  $641 = (($640) + ($639))|0;
  $642 = $641;
  $643 = HEAP32[$642>>2]|0;
  $644 = ($643|0)==(0);
  if ($644) {
   label = 24;
  } else {
   label = 26;
  }
 }
 if ((label|0) == 24) {
  $645 = (($632) + 68|0);
  $646 = HEAP32[$645>>2]|0;
  $647 = ($646|0)==(-1);
  if ($647) {
   $648 = HEAP32[$$pre$phiZ2D>>2]|0;
   $649 = (($648) + 22|0);
   $650 = HEAP8[$649>>0]|0;
   $651 = ($650<<24>>24)==(0);
   if ($651) {
    $657 = $633;$659 = $632;
   } else {
    label = 26;
   }
  } else {
   label = 26;
  }
 }
 if ((label|0) == 26) {
  $652 = HEAP32[$$pre$phiZ2D>>2]|0;
  $653 = HEAP32[$$pre$phi179Z2D>>2]|0;
  $654 = HEAP32[$$pre$phi181Z2D>>2]|0;
  $655 = HEAP32[$$pre$phi183Z2D>>2]|0;
  __ZN7mecanim9animation15EvaluateAvatarXEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceE($632,$652,$653,$654,$655);
  $$pre173 = HEAP32[$$pre$phi185Z2D>>2]|0;
  $$phi$trans$insert174 = (($$pre173) + 36|0);
  $$pre175 = HEAP32[$$phi$trans$insert174>>2]|0;
  $657 = $$pre175;$659 = $$pre173;
 }
 $656 = ($657|0)==(0);
 if ($656) {
  STACKTOP = sp;return;
 }
 $658 = (($659) + 36|0);
 $660 = $658;
 $661 = (($660) + ($657))|0;
 $662 = $661;
 $663 = (($662) + 48|0);
 $664 = $663;
 $665 = HEAP32[$663>>2]|0;
 $666 = (($665) + ($664))|0;
 $667 = $666;
 $668 = HEAP32[$667>>2]|0;
 $669 = ($668|0)==(0);
 if ($669) {
  STACKTOP = sp;return;
 }
 $670 = HEAP32[$$pre$phi181Z2D>>2]|0;
 $671 = HEAP32[$$pre$phi179Z2D>>2]|0;
 $672 = (($671) + 8|0);
 $673 = HEAP32[$672>>2]|0;
 $674 = (($673) + 372|0);
 $675 = Math_fround(HEAPF32[$674>>2]);
 $676 = (($670) + 40|0);
 $677 = Math_fround(HEAPF32[$676>>2]);
 $678 = Math_fround($675 * $677);
 $679 = (($673) + 376|0);
 $680 = Math_fround(HEAPF32[$679>>2]);
 $681 = (($670) + 44|0);
 $682 = Math_fround(HEAPF32[$681>>2]);
 $683 = Math_fround($680 * $682);
 $684 = (($673) + 380|0);
 $685 = Math_fround(HEAPF32[$684>>2]);
 $686 = (($670) + 48|0);
 $687 = Math_fround(HEAPF32[$686>>2]);
 $688 = Math_fround($685 * $687);
 $689 = Math_fround($678 + $678);
 $690 = Math_fround($683 + $683);
 $691 = Math_fround($688 + $688);
 $692 = (($670) + 24|0);
 $693 = Math_fround(HEAPF32[$692>>2]);
 $694 = Math_fround($690 * $693);
 $695 = (($670) + 28|0);
 $696 = Math_fround(HEAPF32[$695>>2]);
 $697 = Math_fround($691 * $696);
 $698 = (($670) + 32|0);
 $699 = Math_fround(HEAPF32[$698>>2]);
 $700 = Math_fround($689 * $699);
 $701 = (($670) + 36|0);
 $702 = Math_fround(HEAPF32[$701>>2]);
 $703 = Math_fround($689 * $696);
 $704 = Math_fround($690 * $699);
 $705 = Math_fround($693 * $691);
 $706 = Math_fround($694 - $703);
 $707 = Math_fround($697 - $704);
 $708 = Math_fround($700 - $705);
 $709 = Math_fround($702 * $707);
 $710 = Math_fround($702 * $708);
 $711 = Math_fround($706 * $702);
 $712 = Math_fround($678 + $709);
 $713 = Math_fround($683 + $710);
 $714 = Math_fround($688 + $711);
 $715 = Math_fround($693 * $708);
 $716 = Math_fround($696 * $706);
 $717 = Math_fround($699 * $707);
 $718 = Math_fround($696 * $707);
 $719 = Math_fround($699 * $708);
 $720 = Math_fround($693 * $706);
 $721 = Math_fround($715 - $718);
 $722 = Math_fround($716 - $719);
 $723 = Math_fround($717 - $720);
 $724 = Math_fround($712 + $722);
 $725 = Math_fround($713 + $723);
 $726 = Math_fround($714 + $721);
 $727 = (($670) + 8|0);
 $728 = Math_fround(HEAPF32[$727>>2]);
 $729 = Math_fround($728 + $724);
 $730 = (($670) + 12|0);
 $731 = Math_fround(HEAPF32[$730>>2]);
 $732 = Math_fround($731 + $725);
 $733 = (($670) + 16|0);
 $734 = Math_fround(HEAPF32[$733>>2]);
 $735 = Math_fround($734 + $726);
 $736 = (($this) + 264|0);
 HEAPF32[$736>>2] = $729;
 $737 = (($this) + 268|0);
 HEAPF32[$737>>2] = $732;
 $738 = (($this) + 272|0);
 HEAPF32[$738>>2] = $735;
 $739 = HEAP32[$672>>2]|0;
 $740 = Math_fround(HEAPF32[$695>>2]);
 $741 = (($739) + 388|0);
 $742 = Math_fround(HEAPF32[$741>>2]);
 $743 = Math_fround($740 * $742);
 $744 = Math_fround(HEAPF32[$701>>2]);
 $745 = (($739) + 400|0);
 $746 = Math_fround(HEAPF32[$745>>2]);
 $747 = Math_fround($744 * $746);
 $748 = Math_fround(HEAPF32[$698>>2]);
 $749 = (($739) + 392|0);
 $750 = Math_fround(HEAPF32[$749>>2]);
 $751 = Math_fround($748 * $750);
 $752 = Math_fround(HEAPF32[$692>>2]);
 $753 = (($739) + 396|0);
 $754 = Math_fround(HEAPF32[$753>>2]);
 $755 = Math_fround($752 * $754);
 $756 = Math_fround($744 * $754);
 $757 = Math_fround($742 * $752);
 $758 = Math_fround($740 * $754);
 $759 = Math_fround($742 * $748);
 $760 = Math_fround($743 - $756);
 $761 = Math_fround($747 - $757);
 $762 = Math_fround($751 - $758);
 $763 = Math_fround($755 - $759);
 $764 = Math_fround($746 * $748);
 $765 = Math_fround($748 * $754);
 $766 = Math_fround($742 * $744);
 $767 = Math_fround($744 * $750);
 $768 = Math_fround($760 - $764);
 $769 = Math_fround($761 - $765);
 $770 = Math_fround($762 - $766);
 $771 = Math_fround($763 - $767);
 $772 = Math_fround($750 * $752);
 $773 = Math_fround($740 * $750);
 $774 = Math_fround($746 * $752);
 $775 = Math_fround($740 * $746);
 $776 = Math_fround($768 - $772);
 $777 = Math_fround($769 - $773);
 $778 = Math_fround($770 - $774);
 $779 = Math_fround($771 - $775);
 $780 = Math_fround($778 * Math_fround(-1.0));
 $781 = Math_fround($779 * Math_fround(-1.0));
 $782 = Math_fround($776 * Math_fround(-1.0));
 $783 = Math_fround($780 * $780);
 $784 = Math_fround($781 * $781);
 $785 = Math_fround($782 * $782);
 $786 = Math_fround($777 * $777);
 $787 = Math_fround($783 + $784);
 $788 = Math_fround($786 + $785);
 $789 = Math_fround($787 + $788);
 $790 = (Math_fround(Math_sqrt((Math_fround($789)))));
 $791 = Math_fround(Math_fround(1.0) / $790);
 $792 = Math_fround($791 * $780);
 $793 = Math_fround($791 * $781);
 $794 = Math_fround($791 * $782);
 $795 = Math_fround($791 * $777);
 $796 = Math_fround($792 * $792);
 $797 = Math_fround($793 * $793);
 $798 = Math_fround($794 * $794);
 $799 = Math_fround($795 * $795);
 $800 = Math_fround($796 + $797);
 $801 = Math_fround($799 + $798);
 $802 = Math_fround($800 + $801);
 $803 = (Math_fround(Math_sqrt((Math_fround($802)))));
 $804 = Math_fround(Math_fround(1.0) / $803);
 $805 = Math_fround($804 * $792);
 $806 = Math_fround($804 * $793);
 $807 = Math_fround($804 * $794);
 $808 = Math_fround($795 * $804);
 $809 = (($this) + 276|0);
 HEAPF32[$809>>2] = $805;
 $810 = (($this) + 280|0);
 HEAPF32[$810>>2] = $806;
 $811 = (($this) + 284|0);
 HEAPF32[$811>>2] = $807;
 $812 = (($this) + 288|0);
 HEAPF32[$812>>2] = $808;
 $813 = HEAP32[$$pre$phi181Z2D>>2]|0;
 $814 = HEAP32[$$pre$phi185Z2D>>2]|0;
 $815 = (($814) + 36|0);
 $816 = $815;
 $817 = HEAP32[$815>>2]|0;
 $818 = (($816) + ($817))|0;
 $819 = $818;
 $820 = (($819) + 392|0);
 $821 = Math_fround(HEAPF32[$820>>2]);
 $822 = (($813) + 152|0);
 $823 = Math_fround(HEAPF32[$822>>2]);
 $824 = Math_fround($821 * $823);
 $825 = (($813) + 156|0);
 $826 = Math_fround(HEAPF32[$825>>2]);
 $827 = Math_fround($821 * $826);
 $828 = (($813) + 160|0);
 $829 = Math_fround(HEAPF32[$828>>2]);
 $830 = Math_fround($821 * $829);
 $831 = (($813) + 40|0);
 $832 = Math_fround(HEAPF32[$831>>2]);
 $833 = Math_fround($824 * $832);
 $834 = (($813) + 44|0);
 $835 = Math_fround(HEAPF32[$834>>2]);
 $836 = Math_fround($827 * $835);
 $837 = (($813) + 48|0);
 $838 = Math_fround(HEAPF32[$837>>2]);
 $839 = Math_fround($830 * $838);
 $840 = Math_fround($833 + $833);
 $841 = Math_fround($836 + $836);
 $842 = Math_fround($839 + $839);
 $843 = (($813) + 24|0);
 $844 = Math_fround(HEAPF32[$843>>2]);
 $845 = Math_fround($841 * $844);
 $846 = (($813) + 28|0);
 $847 = Math_fround(HEAPF32[$846>>2]);
 $848 = Math_fround($842 * $847);
 $849 = (($813) + 32|0);
 $850 = Math_fround(HEAPF32[$849>>2]);
 $851 = Math_fround($840 * $850);
 $852 = (($813) + 36|0);
 $853 = Math_fround(HEAPF32[$852>>2]);
 $854 = Math_fround($840 * $847);
 $855 = Math_fround($841 * $850);
 $856 = Math_fround($844 * $842);
 $857 = Math_fround($845 - $854);
 $858 = Math_fround($848 - $855);
 $859 = Math_fround($851 - $856);
 $860 = Math_fround($853 * $858);
 $861 = Math_fround($853 * $859);
 $862 = Math_fround($857 * $853);
 $863 = Math_fround($833 + $860);
 $864 = Math_fround($836 + $861);
 $865 = Math_fround($839 + $862);
 $866 = Math_fround($844 * $859);
 $867 = Math_fround($847 * $857);
 $868 = Math_fround($850 * $858);
 $869 = Math_fround($847 * $858);
 $870 = Math_fround($850 * $859);
 $871 = Math_fround($844 * $857);
 $872 = Math_fround($866 - $869);
 $873 = Math_fround($867 - $870);
 $874 = Math_fround($868 - $871);
 $875 = Math_fround($863 + $873);
 $876 = Math_fround($864 + $874);
 $877 = Math_fround($865 + $872);
 $878 = (($813) + 8|0);
 $879 = Math_fround(HEAPF32[$878>>2]);
 $880 = Math_fround($879 + $875);
 $881 = (($813) + 12|0);
 $882 = Math_fround(HEAPF32[$881>>2]);
 $883 = Math_fround($882 + $876);
 $884 = (($813) + 16|0);
 $885 = Math_fround(HEAPF32[$884>>2]);
 $886 = Math_fround($885 + $877);
 $887 = (($this) + 252|0);
 HEAPF32[$887>>2] = $880;
 $888 = (($this) + 256|0);
 HEAPF32[$888>>2] = $883;
 $889 = (($this) + 260|0);
 HEAPF32[$889>>2] = $886;
 STACKTOP = sp;return;
}
function __ZN8Animator11TargetMatchEv($this) {
 $this = $this|0;
 var $$idx7 = 0, $$idx7$val = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0), $$idx9 = 0, $$idx9$val = Math_fround(0), $$off$pre = 0, $$off$pre$phi81ZZ2D = 0, $$off4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0);
 var $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0;
 var $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0;
 var $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0;
 var $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0);
 var $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0);
 var $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0);
 var $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0;
 var $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0);
 var $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0);
 var $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0);
 var $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = Math_fround(0);
 var $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0;
 var $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0);
 var $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = Math_fround(0), $503 = Math_fround(0);
 var $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = Math_fround(0), $515 = 0, $516 = 0, $517 = Math_fround(0), $518 = 0, $519 = 0, $52 = 0, $520 = Math_fround(0), $521 = 0;
 var $522 = 0, $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0;
 var $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = 0, $548 = Math_fround(0), $549 = 0, $55 = Math_fround(0), $550 = Math_fround(0), $551 = 0, $552 = Math_fround(0), $553 = 0, $554 = Math_fround(0), $555 = 0, $556 = Math_fround(0), $557 = 0, $558 = Math_fround(0);
 var $559 = 0, $56 = 0, $560 = Math_fround(0), $561 = 0, $562 = Math_fround(0), $563 = 0, $564 = Math_fround(0), $565 = 0, $566 = Math_fround(0), $567 = 0, $568 = Math_fround(0), $569 = 0, $57 = Math_fround(0), $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0);
 var $577 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0);
 var $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $avatarX = 0, $dx = 0, $dxn = 0, $dxo = 0, $stateDuration$0 = Math_fround(0), $stateTime$0 = Math_fround(0), $w$079 = Math_fround(0), $w$082 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $avatarX = sp + 256|0;
 $dxo = sp;
 $dx = sp + 48|0;
 $0 = sp + 96|0;
 $1 = sp + 144|0;
 $dxn = sp + 160|0;
 $2 = sp + 208|0;
 $3 = (($this) + 292|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = !($4 >= Math_fround(0.0));
 do {
  if (!($5)) {
   $6 = (($this) + 92|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 4|0);
   $9 = $8;
   $10 = HEAP32[$8>>2]|0;
   $11 = (($9) + ($10))|0;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   $14 = (($11) + ($13))|0;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(-1);
   if ($17) {
    label = 4;
   } else {
    $18 = (($this) + 84|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = $19;
    $21 = HEAP32[$19>>2]|0;
    $22 = (($21) + ($20))|0;
    $23 = $22;
    $24 = (($19) + 4|0);
    HEAP32[$24>>2] = $23;
    $25 = (($23) + 4|0);
    $26 = $25;
    $27 = HEAP32[$25>>2]|0;
    $28 = (($26) + ($27))|0;
    $29 = $28;
    $30 = (($23) + 8|0);
    HEAP32[$30>>2] = $29;
    $31 = (($29) + ($16<<3)|0);
    $32 = $31;
    $33 = HEAP32[$31>>2]|0;
    $34 = (($32) + ($33))|0;
    $35 = $34;
    $36 = ((($29) + ($16<<3)|0) + 4|0);
    HEAP32[$36>>2] = $35;
    $37 = (($35) + 73|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     label = 4;
    }
   }
   if ((label|0) == 4) {
    $40 = (__ZNK8Animator20IsInMatchTargetStateEv($this)|0);
    if ($40) {
     break;
    }
   }
   $41 = (($this) + 344|0);
   HEAP8[$41>>0] = 1;
  }
 } while(0);
 $42 = HEAP32[$this>>2]|0;
 $43 = (($42) + 136|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (FUNCTION_TABLE_ii[$44 & 4095]($this)|0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 $46 = Math_fround(HEAPF32[$3>>2]);
 $47 = !($46 >= Math_fround(0.0));
 if ($47) {
  STACKTOP = sp;return;
 }
 $48 = (($this) + 84|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + 8|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($49) + 12|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($49) + 16|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($49) + 20|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 HEAPF32[$avatarX>>2] = $51;
 $58 = (($avatarX) + 4|0);
 HEAPF32[$58>>2] = $53;
 $59 = (($avatarX) + 8|0);
 HEAPF32[$59>>2] = $55;
 $60 = (($avatarX) + 12|0);
 HEAPF32[$60>>2] = $57;
 $61 = (($49) + 24|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($49) + 28|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($49) + 32|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($49) + 36|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($avatarX) + 16|0);
 HEAPF32[$69>>2] = $62;
 $70 = (($avatarX) + 20|0);
 HEAPF32[$70>>2] = $64;
 $71 = (($avatarX) + 24|0);
 HEAPF32[$71>>2] = $66;
 $72 = (($avatarX) + 28|0);
 HEAPF32[$72>>2] = $68;
 $73 = (($49) + 40|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($49) + 44|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($49) + 48|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($49) + 52|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($avatarX) + 32|0);
 HEAPF32[$81>>2] = $74;
 $82 = (($avatarX) + 36|0);
 HEAPF32[$82>>2] = $76;
 $83 = (($avatarX) + 40|0);
 HEAPF32[$83>>2] = $78;
 $84 = (($avatarX) + 44|0);
 HEAPF32[$84>>2] = $80;
 $85 = (($this) + 72|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + 36|0);
 $88 = $87;
 $89 = HEAP32[$87>>2]|0;
 $90 = (($88) + ($89))|0;
 $91 = $90;
 $92 = (($91) + 392|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = (($this) + 80|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = (($95) + 8|0);
 $97 = HEAP32[$96>>2]|0;
 __ZN7mecanim9animation29MotionOutputGetDeltaTransformEPKNS0_12MotionOutputE($dxo,$97);
 $98 = Math_fround(HEAPF32[$dxo>>2]);
 $99 = (($dxo) + 4|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($dxo) + 8|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($dxo) + 12|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($dx) + 4|0);
 $106 = (($dx) + 8|0);
 $107 = (($dx) + 12|0);
 $108 = (($dxo) + 16|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = (($dxo) + 20|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = (($dxo) + 24|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($dxo) + 28|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($dx) + 16|0);
 HEAPF32[$116>>2] = $109;
 $117 = (($dx) + 20|0);
 HEAPF32[$117>>2] = $111;
 $118 = (($dx) + 24|0);
 HEAPF32[$118>>2] = $113;
 $119 = (($dx) + 28|0);
 HEAPF32[$119>>2] = $115;
 $120 = (($dxo) + 32|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = (($dxo) + 36|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = (($dxo) + 40|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($dxo) + 44|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($dx) + 32|0);
 HEAPF32[$128>>2] = $121;
 $129 = (($dx) + 36|0);
 HEAPF32[$129>>2] = $123;
 $130 = (($dx) + 40|0);
 HEAPF32[$130>>2] = $125;
 $131 = (($dx) + 44|0);
 HEAPF32[$131>>2] = $127;
 $132 = Math_fround($93 * $98);
 $133 = Math_fround($93 * $100);
 $134 = Math_fround($93 * $102);
 $135 = Math_fround($93 * $104);
 HEAPF32[$dx>>2] = $132;
 HEAPF32[$105>>2] = $133;
 HEAPF32[$106>>2] = $134;
 HEAPF32[$107>>2] = $135;
 __ZN4mathL8xformMulERKNS_5xformES2_($0,$avatarX,$dx);
 $136 = Math_fround(HEAPF32[$0>>2]);
 $137 = (($0) + 4|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($0) + 8|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($0) + 12|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 HEAPF32[$avatarX>>2] = $136;
 HEAPF32[$58>>2] = $138;
 HEAPF32[$59>>2] = $140;
 HEAPF32[$60>>2] = $142;
 $143 = (($0) + 16|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = (($0) + 20|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($0) + 24|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = (($0) + 28|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 HEAPF32[$69>>2] = $144;
 HEAPF32[$70>>2] = $146;
 HEAPF32[$71>>2] = $148;
 HEAPF32[$72>>2] = $150;
 $151 = (($0) + 32|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($0) + 36|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($0) + 40|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($0) + 44|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 HEAPF32[$81>>2] = $152;
 HEAPF32[$82>>2] = $154;
 HEAPF32[$83>>2] = $156;
 HEAPF32[$84>>2] = $158;
 $159 = (($this) + 92|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = HEAP32[$160>>2]|0;
 $162 = ($161|0)==(0);
 if ($162) {
  $stateDuration$0 = Math_fround(1.0);$stateTime$0 = Math_fround(0.0);
 } else {
  $163 = (($160) + 4|0);
  $164 = $163;
  $165 = HEAP32[$163>>2]|0;
  $166 = (($165) + ($164))|0;
  $167 = $166;
  $168 = HEAP32[$167>>2]|0;
  $169 = (($168) + ($166))|0;
  $170 = $169;
  $171 = HEAP32[$170>>2]|0;
  $172 = HEAP32[$48>>2]|0;
  $173 = $172;
  $174 = HEAP32[$172>>2]|0;
  $175 = (($174) + ($173))|0;
  $176 = $175;
  $177 = (($172) + 4|0);
  HEAP32[$177>>2] = $176;
  $178 = (($176) + 4|0);
  $179 = $178;
  $180 = HEAP32[$178>>2]|0;
  $181 = (($179) + ($180))|0;
  $182 = $181;
  $183 = (($176) + 8|0);
  HEAP32[$183>>2] = $182;
  $184 = (($182) + ($171<<3)|0);
  $185 = $184;
  $186 = HEAP32[$184>>2]|0;
  $187 = (($185) + ($186))|0;
  $188 = $187;
  $189 = ((($182) + ($171<<3)|0) + 4|0);
  HEAP32[$189>>2] = $188;
  $190 = (($188) + 36|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = (($188) + 44|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $stateDuration$0 = $193;$stateTime$0 = $191;
 }
 $194 = Math_fround(HEAPF32[$3>>2]);
 $195 = !($stateTime$0 >= $194);
 if ($195) {
  STACKTOP = sp;return;
 }
 $196 = (($this) + 76|0);
 $197 = HEAP32[$196>>2]|0;
 $198 = (($197) + 12|0);
 $199 = Math_fround(HEAPF32[$198>>2]);
 $200 = Math_fround($199 - $stateTime$0);
 $201 = $200 > Math_fround(0.0);
 $202 = $201 ? $200 : Math_fround(0.0);
 $203 = $202 != Math_fround(0.0);
 if ($203) {
  $204 = (($197) + 4|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = Math_fround($205 / $stateDuration$0);
  $207 = Math_fround($206 / $202);
  $268 = $207;
 } else {
  $268 = Math_fround(1.0);
 }
 $208 = HEAP32[$94>>2]|0;
 $209 = (($208) + 8|0);
 $210 = HEAP32[$209>>2]|0;
 $211 = (($210) + 372|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($210) + 376|0);
 $214 = Math_fround(HEAPF32[$213>>2]);
 $215 = (($210) + 380|0);
 $216 = Math_fround(HEAPF32[$215>>2]);
 $217 = (($210) + 384|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 $219 = (($210) + 388|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = (($210) + 392|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = (($210) + 396|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = (($210) + 400|0);
 $226 = Math_fround(HEAPF32[$225>>2]);
 $227 = (($197) + 8|0);
 $228 = HEAP32[$227>>2]|0;
 $229 = (($this) + 344|0);
 $230 = HEAP8[$229>>0]|0;
 $231 = ($230<<24>>24)==(0);
 do {
  if ($231) {
   $269 = (Math_fround(+(_fmaxf(0.0,(+$268)))));
   $270 = (Math_fround(+(_fminf(1.0,(+$269)))));
   $$off$pre = (($228) + -2)|0;
   $271 = ($$off$pre>>>0)<(4);
   if ($271) {
    $$off$pre$phi81ZZ2D = $$off$pre;$274 = $222;$278 = $226;$282 = $224;$286 = $220;$574 = $212;$575 = $214;$576 = $216;$577 = $218;$w$082 = $270;
    label = 19;
   } else {
    $432 = $212;$434 = $214;$436 = $216;$438 = $218;$448 = $220;$450 = $222;$452 = $224;$455 = $226;$w$079 = $270;
   }
  } else {
   if ((($228|0) == 1)) {
    $232 = (($208) + 16|0);
    $233 = HEAP32[$232>>2]|0;
    $234 = Math_fround(HEAPF32[$233>>2]);
    $235 = (($233) + 4|0);
    $236 = Math_fround(HEAPF32[$235>>2]);
    $237 = (($233) + 8|0);
    $238 = Math_fround(HEAPF32[$237>>2]);
    $239 = (($233) + 12|0);
    $240 = Math_fround(HEAPF32[$239>>2]);
    $241 = (($233) + 16|0);
    $242 = Math_fround(HEAPF32[$241>>2]);
    $243 = (($233) + 20|0);
    $244 = Math_fround(HEAPF32[$243>>2]);
    $245 = (($233) + 24|0);
    $246 = Math_fround(HEAPF32[$245>>2]);
    $247 = (($233) + 28|0);
    $248 = Math_fround(HEAPF32[$247>>2]);
    $432 = $234;$434 = $236;$436 = $238;$438 = $240;$448 = $242;$450 = $244;$452 = $246;$455 = $248;$w$079 = Math_fround(1.0);
    break;
   } else if ((($228|0) == 0)) {
    $432 = Math_fround(0.0);$434 = Math_fround(0.0);$436 = Math_fround(0.0);$438 = Math_fround(0.0);$448 = Math_fround(0.0);$450 = Math_fround(0.0);$452 = Math_fround(0.0);$455 = Math_fround(1.0);$w$079 = Math_fround(1.0);
    break;
   }
   $$off4 = (($228) + -2)|0;
   $249 = ($$off4>>>0)<(4);
   if ($249) {
    $250 = (($208) + 16|0);
    $251 = HEAP32[$250>>2]|0;
    $252 = ((($251) + (($$off4*76)|0)|0) + 80|0);
    $253 = Math_fround(HEAPF32[$252>>2]);
    $254 = ((($251) + (($$off4*76)|0)|0) + 84|0);
    $255 = Math_fround(HEAPF32[$254>>2]);
    $256 = ((($251) + (($$off4*76)|0)|0) + 88|0);
    $257 = Math_fround(HEAPF32[$256>>2]);
    $258 = ((($251) + (($$off4*76)|0)|0) + 92|0);
    $259 = Math_fround(HEAPF32[$258>>2]);
    $260 = ((($251) + (($$off4*76)|0)|0) + 96|0);
    $261 = Math_fround(HEAPF32[$260>>2]);
    $262 = ((($251) + (($$off4*76)|0)|0) + 100|0);
    $263 = Math_fround(HEAPF32[$262>>2]);
    $264 = ((($251) + (($$off4*76)|0)|0) + 104|0);
    $265 = Math_fround(HEAPF32[$264>>2]);
    $266 = ((($251) + (($$off4*76)|0)|0) + 108|0);
    $267 = Math_fround(HEAPF32[$266>>2]);
    $$off$pre$phi81ZZ2D = $$off4;$274 = $263;$278 = $267;$282 = $265;$286 = $261;$574 = $253;$575 = $255;$576 = $257;$577 = $259;$w$082 = Math_fround(1.0);
    label = 19;
   } else {
    $432 = $212;$434 = $214;$436 = $216;$438 = $218;$448 = $220;$450 = $222;$452 = $224;$455 = $226;$w$079 = Math_fround(1.0);
   }
  }
 } while(0);
 if ((label|0) == 19) {
  __ZN7mecanim5human29HumanGetGoalOrientationOffsetENS0_4GoalE($1,$$off$pre$phi81ZZ2D);
  $272 = Math_fround(HEAPF32[$1>>2]);
  $273 = Math_fround($274 * $272);
  $275 = (($1) + 12|0);
  $276 = Math_fround(HEAPF32[$275>>2]);
  $277 = Math_fround($278 * $276);
  $279 = (($1) + 4|0);
  $280 = Math_fround(HEAPF32[$279>>2]);
  $281 = Math_fround($282 * $280);
  $283 = (($1) + 8|0);
  $284 = Math_fround(HEAPF32[$283>>2]);
  $285 = Math_fround($286 * $284);
  $287 = Math_fround($278 * $284);
  $288 = Math_fround($286 * $272);
  $289 = Math_fround($274 * $284);
  $290 = Math_fround($282 * $272);
  $291 = Math_fround($273 - $287);
  $292 = Math_fround($277 - $288);
  $293 = Math_fround($281 - $289);
  $294 = Math_fround($285 - $290);
  $295 = Math_fround($282 * $276);
  $296 = Math_fround($282 * $284);
  $297 = Math_fround($278 * $272);
  $298 = Math_fround($278 * $280);
  $299 = Math_fround($291 - $295);
  $300 = Math_fround($292 - $296);
  $301 = Math_fround($293 - $297);
  $302 = Math_fround($294 - $298);
  $303 = Math_fround($286 * $280);
  $304 = Math_fround($274 * $280);
  $305 = Math_fround($286 * $276);
  $306 = Math_fround($274 * $276);
  $307 = Math_fround($299 - $303);
  $308 = Math_fround($300 - $304);
  $309 = Math_fround($301 - $305);
  $310 = Math_fround($302 - $306);
  $311 = Math_fround($309 * Math_fround(-1.0));
  $312 = Math_fround($310 * Math_fround(-1.0));
  $313 = Math_fround($307 * Math_fround(-1.0));
  $314 = Math_fround($311 * $311);
  $315 = Math_fround($312 * $312);
  $316 = Math_fround($313 * $313);
  $317 = Math_fround($308 * $308);
  $318 = Math_fround($314 + $315);
  $319 = Math_fround($317 + $316);
  $320 = Math_fround($318 + $319);
  $321 = (Math_fround(Math_sqrt((Math_fround($320)))));
  $322 = Math_fround(Math_fround(1.0) / $321);
  $323 = Math_fround($322 * $311);
  $324 = Math_fround($322 * $312);
  $325 = Math_fround($322 * $313);
  $326 = Math_fround($322 * $308);
  $432 = $574;$434 = $575;$436 = $576;$438 = $577;$448 = $323;$450 = $324;$452 = $325;$455 = $326;$w$079 = $w$082;
 }
 $$idx7 = (($this) + 300|0);
 $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
 $$idx8 = (($this) + 304|0);
 $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
 $$idx9 = (($this) + 308|0);
 $$idx9$val = Math_fround(HEAPF32[$$idx9>>2]);
 $327 = (($this) + 312|0);
 $328 = Math_fround(HEAPF32[$327>>2]);
 $329 = (($this) + 316|0);
 $330 = Math_fround(HEAPF32[$329>>2]);
 $331 = (($this) + 320|0);
 $332 = Math_fround(HEAPF32[$331>>2]);
 $333 = (($this) + 324|0);
 $334 = Math_fround(HEAPF32[$333>>2]);
 $335 = Math_fround($144 * Math_fround(-1.0));
 $336 = Math_fround($146 * Math_fround(-1.0));
 $337 = Math_fround($148 * Math_fround(-1.0));
 $338 = Math_fround($$idx7$val - $136);
 $339 = Math_fround($$idx8$val - $138);
 $340 = Math_fround($$idx9$val - $140);
 $341 = Math_fround(Math_fround(0.0) - $142);
 $342 = Math_fround($338 + $338);
 $343 = Math_fround($339 + $339);
 $344 = Math_fround($340 + $340);
 $345 = Math_fround($335 * $343);
 $346 = Math_fround($336 * $344);
 $347 = Math_fround($337 * $342);
 $348 = Math_fround($150 * Math_fround(0.0));
 $349 = Math_fround($336 * $342);
 $350 = Math_fround($337 * $343);
 $351 = Math_fround($335 * $344);
 $352 = Math_fround($345 - $349);
 $353 = Math_fround($346 - $350);
 $354 = Math_fround($347 - $351);
 $355 = Math_fround($348 - $348);
 $356 = Math_fround($150 * $353);
 $357 = Math_fround($150 * $354);
 $358 = Math_fround($150 * $352);
 $359 = Math_fround($150 * $355);
 $360 = Math_fround($338 + $356);
 $361 = Math_fround($339 + $357);
 $362 = Math_fround($340 + $358);
 $363 = Math_fround($359 + $341);
 $364 = Math_fround($335 * $354);
 $365 = Math_fround($336 * $352);
 $366 = Math_fround($337 * $353);
 $367 = Math_fround($336 * $353);
 $368 = Math_fround($337 * $354);
 $369 = Math_fround($335 * $352);
 $370 = Math_fround($364 - $367);
 $371 = Math_fround($365 - $368);
 $372 = Math_fround($366 - $369);
 $373 = Math_fround($359 - $359);
 $374 = Math_fround($360 + $371);
 $375 = Math_fround($361 + $372);
 $376 = Math_fround($362 + $370);
 $377 = Math_fround($373 + $363);
 $378 = Math_fround($374 / $152);
 $379 = Math_fround($375 / $154);
 $380 = Math_fround($376 / $156);
 $381 = Math_fround($377 / $158);
 $382 = Math_fround($328 * $336);
 $383 = Math_fround($334 * $150);
 $384 = Math_fround($330 * $337);
 $385 = Math_fround($332 * $335);
 $386 = Math_fround($332 * $150);
 $387 = Math_fround($328 * $335);
 $388 = Math_fround($332 * $336);
 $389 = Math_fround($328 * $337);
 $390 = Math_fround($382 - $386);
 $391 = Math_fround($383 - $387);
 $392 = Math_fround($384 - $388);
 $393 = Math_fround($385 - $389);
 $394 = Math_fround($334 * $337);
 $395 = Math_fround($332 * $337);
 $396 = Math_fround($328 * $150);
 $397 = Math_fround($330 * $150);
 $398 = Math_fround($390 - $394);
 $399 = Math_fround($391 - $395);
 $400 = Math_fround($392 - $396);
 $401 = Math_fround($393 - $397);
 $402 = Math_fround($330 * $335);
 $403 = Math_fround($330 * $336);
 $404 = Math_fround($334 * $335);
 $405 = Math_fround($334 * $336);
 $406 = Math_fround($398 - $402);
 $407 = Math_fround($399 - $403);
 $408 = Math_fround($400 - $404);
 $409 = Math_fround($401 - $405);
 $410 = Math_fround($408 * Math_fround(-1.0));
 $411 = Math_fround($409 * Math_fround(-1.0));
 $412 = Math_fround($406 * Math_fround(-1.0));
 $413 = Math_fround($410 * $410);
 $414 = Math_fround($411 * $411);
 $415 = Math_fround($412 * $412);
 $416 = Math_fround($407 * $407);
 $417 = Math_fround($413 + $414);
 $418 = Math_fround($416 + $415);
 $419 = Math_fround($417 + $418);
 $420 = (Math_fround(Math_sqrt((Math_fround($419)))));
 $421 = Math_fround(Math_fround(1.0) / $420);
 $422 = Math_fround($410 * $421);
 $423 = Math_fround($411 * $421);
 $424 = Math_fround($412 * $421);
 $425 = Math_fround($407 * $421);
 $426 = (($dxn) + 28|0);
 ;HEAP32[$dxn+0>>2]=0|0;HEAP32[$dxn+4>>2]=0|0;HEAP32[$dxn+8>>2]=0|0;HEAP32[$dxn+12>>2]=0|0;HEAP32[$dxn+16>>2]=0|0;
 $427 = (($dxn) + 44|0);
 HEAPF32[$427>>2] = Math_fround(1.0);
 $428 = (($dxn) + 40|0);
 HEAPF32[$428>>2] = Math_fround(1.0);
 $429 = (($dxn) + 36|0);
 HEAPF32[$429>>2] = Math_fround(1.0);
 $430 = (($dxn) + 32|0);
 HEAPF32[$430>>2] = Math_fround(1.0);
 $431 = Math_fround($378 - $432);
 $433 = Math_fround($379 - $434);
 $435 = Math_fround($380 - $436);
 $437 = Math_fround($381 - $438);
 $439 = (($dxn) + 4|0);
 $440 = (($dxn) + 8|0);
 $441 = (($dxn) + 12|0);
 $442 = Math_fround(Math_fround(1.0) / $93);
 $443 = Math_fround($442 * $431);
 $444 = Math_fround($442 * $433);
 $445 = Math_fround($442 * $435);
 $446 = Math_fround($442 * $437);
 $447 = Math_fround($448 * Math_fround(-1.0));
 $449 = Math_fround($450 * Math_fround(-1.0));
 $451 = Math_fround($452 * Math_fround(-1.0));
 $453 = Math_fround($447 * $423);
 $454 = Math_fround($455 * $425);
 $456 = Math_fround($449 * $424);
 $457 = Math_fround($451 * $422);
 $458 = Math_fround($451 * $425);
 $459 = Math_fround($447 * $422);
 $460 = Math_fround($451 * $423);
 $461 = Math_fround($447 * $424);
 $462 = Math_fround($453 - $458);
 $463 = Math_fround($454 - $459);
 $464 = Math_fround($456 - $460);
 $465 = Math_fround($457 - $461);
 $466 = Math_fround($455 * $424);
 $467 = Math_fround($451 * $424);
 $468 = Math_fround($447 * $425);
 $469 = Math_fround($449 * $425);
 $470 = Math_fround($462 - $466);
 $471 = Math_fround($463 - $467);
 $472 = Math_fround($464 - $468);
 $473 = Math_fround($465 - $469);
 $474 = Math_fround($449 * $422);
 $475 = Math_fround($449 * $423);
 $476 = Math_fround($455 * $422);
 $477 = Math_fround($455 * $423);
 $478 = Math_fround($470 - $474);
 $479 = Math_fround($471 - $475);
 $480 = Math_fround($472 - $476);
 $481 = Math_fround($473 - $477);
 $482 = Math_fround($480 * Math_fround(-1.0));
 $483 = Math_fround($481 * Math_fround(-1.0));
 $484 = Math_fround($478 * Math_fround(-1.0));
 $485 = (($dxn) + 16|0);
 $486 = (($dxn) + 20|0);
 $487 = (($dxn) + 24|0);
 $488 = (($this) + 328|0);
 $489 = Math_fround(HEAPF32[$488>>2]);
 $490 = Math_fround($w$079 * $489);
 $491 = (($this) + 332|0);
 $492 = Math_fround(HEAPF32[$491>>2]);
 $493 = Math_fround($w$079 * $492);
 $494 = (($this) + 336|0);
 $495 = Math_fround(HEAPF32[$494>>2]);
 $496 = Math_fround($w$079 * $495);
 $497 = Math_fround($490 * $443);
 $498 = Math_fround($493 * $444);
 $499 = Math_fround($496 * $445);
 $500 = Math_fround($446 * Math_fround(0.0));
 HEAPF32[$dxn>>2] = $497;
 HEAPF32[$439>>2] = $498;
 HEAPF32[$440>>2] = $499;
 HEAPF32[$441>>2] = $500;
 $501 = (($this) + 340|0);
 $502 = Math_fround(HEAPF32[$501>>2]);
 $503 = Math_fround($w$079 * $502);
 $504 = Math_fround($482 * Math_fround(0.0));
 $505 = Math_fround($483 * Math_fround(0.0));
 $506 = Math_fround($484 * Math_fround(0.0));
 $507 = Math_fround($504 + $505);
 $508 = Math_fround($506 + $479);
 $509 = Math_fround($507 + $508);
 $510 = (HEAPF32[tempDoublePtr>>2]=$482,HEAP32[tempDoublePtr>>2]|0);
 $511 = (HEAPF32[tempDoublePtr>>2]=$509,HEAP32[tempDoublePtr>>2]|0);
 $512 = $511 & -2147483648;
 $513 = $512 ^ $510;
 $514 = (HEAP32[tempDoublePtr>>2]=$513,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $515 = (HEAPF32[tempDoublePtr>>2]=$483,HEAP32[tempDoublePtr>>2]|0);
 $516 = $512 ^ $515;
 $517 = (HEAP32[tempDoublePtr>>2]=$516,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $518 = (HEAPF32[tempDoublePtr>>2]=$484,HEAP32[tempDoublePtr>>2]|0);
 $519 = $512 ^ $518;
 $520 = (HEAP32[tempDoublePtr>>2]=$519,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $521 = (HEAPF32[tempDoublePtr>>2]=$479,HEAP32[tempDoublePtr>>2]|0);
 $522 = $512 ^ $521;
 $523 = (HEAP32[tempDoublePtr>>2]=$522,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $524 = Math_fround($523 + Math_fround(-1.0));
 $525 = Math_fround($503 * $514);
 $526 = Math_fround($503 * $517);
 $527 = Math_fround($503 * $520);
 $528 = Math_fround($503 * $524);
 $529 = Math_fround($525 + Math_fround(0.0));
 $530 = Math_fround($526 + Math_fround(0.0));
 $531 = Math_fround($527 + Math_fround(0.0));
 $532 = Math_fround($528 + Math_fround(1.0));
 $533 = Math_fround($529 * $529);
 $534 = Math_fround($530 * $530);
 $535 = Math_fround($531 * $531);
 $536 = Math_fround($532 * $532);
 $537 = Math_fround($533 + $534);
 $538 = Math_fround($535 + $536);
 $539 = Math_fround($537 + $538);
 $540 = (Math_fround(Math_sqrt((Math_fround($539)))));
 $541 = Math_fround(Math_fround(1.0) / $540);
 $542 = Math_fround($541 * $529);
 $543 = Math_fround($541 * $530);
 $544 = Math_fround($541 * $531);
 $545 = Math_fround($541 * $532);
 HEAPF32[$485>>2] = $542;
 HEAPF32[$486>>2] = $543;
 HEAPF32[$487>>2] = $544;
 HEAPF32[$426>>2] = $545;
 __ZN4mathL8xformMulERKNS_5xformES2_($2,$dxo,$dxn);
 $546 = Math_fround(HEAPF32[$2>>2]);
 $547 = (($2) + 4|0);
 $548 = Math_fround(HEAPF32[$547>>2]);
 $549 = (($2) + 8|0);
 $550 = Math_fround(HEAPF32[$549>>2]);
 $551 = (($2) + 12|0);
 $552 = Math_fround(HEAPF32[$551>>2]);
 HEAPF32[$dx>>2] = $546;
 HEAPF32[$105>>2] = $548;
 HEAPF32[$106>>2] = $550;
 HEAPF32[$107>>2] = $552;
 $553 = (($2) + 16|0);
 $554 = Math_fround(HEAPF32[$553>>2]);
 $555 = (($2) + 20|0);
 $556 = Math_fround(HEAPF32[$555>>2]);
 $557 = (($2) + 24|0);
 $558 = Math_fround(HEAPF32[$557>>2]);
 $559 = (($2) + 28|0);
 $560 = Math_fround(HEAPF32[$559>>2]);
 HEAPF32[$116>>2] = $554;
 HEAPF32[$117>>2] = $556;
 HEAPF32[$118>>2] = $558;
 HEAPF32[$119>>2] = $560;
 $561 = (($2) + 32|0);
 $562 = Math_fround(HEAPF32[$561>>2]);
 $563 = (($2) + 36|0);
 $564 = Math_fround(HEAPF32[$563>>2]);
 $565 = (($2) + 40|0);
 $566 = Math_fround(HEAPF32[$565>>2]);
 $567 = (($2) + 44|0);
 $568 = Math_fround(HEAPF32[$567>>2]);
 HEAPF32[$128>>2] = $562;
 HEAPF32[$129>>2] = $564;
 HEAPF32[$130>>2] = $566;
 HEAPF32[$131>>2] = $568;
 $569 = HEAP32[$94>>2]|0;
 $570 = (($569) + 8|0);
 $571 = HEAP32[$570>>2]|0;
 __ZN7mecanim9animation29MotionOutputSetDeltaTransformEPNS0_12MotionOutputERKN4math5xformE($571,$dx);
 $572 = !($w$079 >= Math_fround(1.0));
 if ($572) {
  STACKTOP = sp;return;
 }
 HEAPF32[$3>>2] = Math_fround(-1.0);
 $573 = (($this) + 296|0);
 HEAP32[$573>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN8Animator15AvatarWriteStepEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0;
 var $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 90|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 HEAP8[$4>>0] = 0;
 $7 = (($this) + 465|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 $10 = (($this) + 72|0);
 $11 = HEAP32[$10>>2]|0;
 if (!($9)) {
  $12 = (($11) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if (!($14)) {
   $15 = $12;
   $16 = (($13) + ($15))|0;
   $17 = $16;
   $18 = (($17) + 48|0);
   $19 = $18;
   $20 = HEAP32[$18>>2]|0;
   $21 = (($20) + ($19))|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0);
   if (!($24)) {
    $25 = (($this) + 104|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($this) + 80|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    __ZN11UnityEngine9Animation31SetHumanTransformPropertyValuesERKNS0_21AvatarBindingConstantERKN7mecanim8skeleton12SkeletonPoseE($26,$30);
   }
  }
  $31 = (($this) + 100|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($this) + 80|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($this) + 24|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($37)|0);
  __ZN11UnityEngine9Animation33SetGenericTransformPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayEP9Transform($32,$35,$38);
  STACKTOP = sp;return;
 }
 $39 = $11;
 $40 = HEAP32[$11>>2]|0;
 $41 = (($40) + ($39))|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = (($11) + 4|0);
 HEAP32[$45>>2] = $42;
 $46 = HEAP32[$10>>2]|0;
 $47 = (($46) + 8|0);
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($48) + ($49))|0;
 $51 = $50;
 $52 = (($46) + 12|0);
 HEAP32[$52>>2] = $51;
 $53 = (($this) + 80|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($this) + 100|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + 32|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 8|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($54) + 4|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = HEAP32[$10>>2]|0;
 $65 = (($64) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0);
 if ($67) {
  $84 = 0;
 } else {
  $68 = $65;
  $69 = (($68) + ($66))|0;
  $70 = $69;
  $71 = (($70) + 48|0);
  $72 = $71;
  $73 = HEAP32[$71>>2]|0;
  $74 = (($73) + ($72))|0;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0);
  if ($77) {
   $84 = 0;
  } else {
   $78 = (($64) + 60|0);
   $79 = $78;
   $80 = HEAP32[$78>>2]|0;
   $81 = (($79) + ($80))|0;
   $82 = $81;
   $83 = (($64) + 64|0);
   HEAP32[$83>>2] = $82;
   $84 = $82;
  }
 }
 __ZN7mecanim9animation21SkeletonPoseFromValueERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseERKNS_10ValueArrayEPKNS0_14SkeletonTQSMapERS5_PKib($42,$51,$55,$61,$63,$84,1);
 $85 = HEAP32[$10>>2]|0;
 $86 = (($85) + 36|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(0);
 if ($88) {
  label = 14;
 } else {
  $89 = $86;
  $90 = (($89) + ($87))|0;
  $91 = $90;
  $92 = (($91) + 48|0);
  $93 = $92;
  $94 = HEAP32[$92>>2]|0;
  $95 = (($94) + ($93))|0;
  $96 = $95;
  $97 = HEAP32[$96>>2]|0;
  $98 = ($97|0)==(0);
  if ($98) {
   label = 14;
  } else {
   $$pre3 = (($this) + 84|0);
   $$pre$phiZ2D = $$pre3;$146 = $85;
  }
 }
 if ((label|0) == 14) {
  $99 = HEAP32[$53>>2]|0;
  $100 = (($99) + 4|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (($101) + 4|0);
  $103 = $102;
  $104 = HEAP32[$102>>2]|0;
  $105 = (($103) + ($104))|0;
  $106 = $105;
  $107 = (($101) + 8|0);
  HEAP32[$107>>2] = $106;
  $108 = (($this) + 84|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($109) + 8|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = (($109) + 12|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = (($109) + 16|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($109) + 20|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  HEAPF32[$106>>2] = $111;
  $118 = (($106) + 4|0);
  HEAPF32[$118>>2] = $113;
  $119 = (($106) + 8|0);
  HEAPF32[$119>>2] = $115;
  $120 = (($106) + 12|0);
  HEAPF32[$120>>2] = $117;
  $121 = (($109) + 24|0);
  $122 = Math_fround(HEAPF32[$121>>2]);
  $123 = (($109) + 28|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = (($109) + 32|0);
  $126 = Math_fround(HEAPF32[$125>>2]);
  $127 = (($109) + 36|0);
  $128 = Math_fround(HEAPF32[$127>>2]);
  $129 = (($106) + 16|0);
  HEAPF32[$129>>2] = $122;
  $130 = (($106) + 20|0);
  HEAPF32[$130>>2] = $124;
  $131 = (($106) + 24|0);
  HEAPF32[$131>>2] = $126;
  $132 = (($106) + 28|0);
  HEAPF32[$132>>2] = $128;
  $133 = (($109) + 40|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = (($109) + 44|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = (($109) + 48|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = (($109) + 52|0);
  $140 = Math_fround(HEAPF32[$139>>2]);
  $141 = (($106) + 32|0);
  HEAPF32[$141>>2] = $134;
  $142 = (($106) + 36|0);
  HEAPF32[$142>>2] = $136;
  $143 = (($106) + 40|0);
  HEAPF32[$143>>2] = $138;
  $144 = (($106) + 44|0);
  HEAPF32[$144>>2] = $140;
  $$pre = HEAP32[$10>>2]|0;
  $$pre$phiZ2D = $108;$146 = $$pre;
 }
 $145 = $146;
 $147 = HEAP32[$146>>2]|0;
 $148 = (($147) + ($145))|0;
 $149 = $148;
 $150 = (($146) + 4|0);
 HEAP32[$150>>2] = $149;
 $151 = HEAP32[$53>>2]|0;
 $152 = (($151) + 4|0);
 $153 = HEAP32[$152>>2]|0;
 __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_($149,$153,$153);
 $154 = HEAP32[$$pre$phiZ2D>>2]|0;
 $155 = (($154) + 173|0);
 HEAP8[$155>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN8Animator27FreeGlobalSpaceSkeletonPoseEPN7mecanim8skeleton12SkeletonPoseE($tempMemory) {
 $tempMemory = $tempMemory|0;
 var $0 = 0, $1 = 0, $2 = 0, $tempAllocator = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tempAllocator = sp;
 $0 = ($tempMemory|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[628512>>2]|0;
 HEAP32[$tempAllocator>>2] = ((741984 + 8|0));
 $2 = (($tempAllocator) + 4|0);
 HEAP32[$2>>2] = $1;
 __ZN7mecanim8skeleton19DestroySkeletonPoseEPNS0_12SkeletonPoseERNS_6memory9AllocatorE($tempMemory,$tempAllocator);
 STACKTOP = sp;return;
}
function __ZN8Animator22ApplyBuiltinRootMotionEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $$idx$i = 0, $$idx$val$i = Math_fround(0), $$idx1$i = 0, $$idx1$val$i = Math_fround(0), $$idx2$i = 0, $$idx2$val$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0;
 var $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $data$i = 0, $inData$c$i$i = 0, $motionData = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $data$i = sp + 48|0;
 $motionData = sp;
 $0 = sp + 36|0;
 $1 = (($this) + 200|0);
 ;HEAP32[$motionData+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$motionData+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$motionData+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($motionData) + 12|0);
 $3 = (($this) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $28 = Math_fround(0.0);$30 = Math_fround(0.0);$32 = Math_fround(0.0);$34 = Math_fround(1.0);
 } else {
  $6 = (($4) + 24|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround($7 * $7);
  $9 = (($4) + 28|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround($10 * $10);
  $12 = (($4) + 32|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($13 * $13);
  $15 = (($4) + 36|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($16 * $16);
  $18 = Math_fround($8 + $11);
  $19 = Math_fround($14 + $17);
  $20 = Math_fround($18 + $19);
  $21 = (Math_fround(Math_sqrt((Math_fround($20)))));
  $22 = Math_fround(Math_fround(1.0) / $21);
  $23 = Math_fround($7 * $22);
  $24 = Math_fround($10 * $22);
  $25 = Math_fround($13 * $22);
  $26 = Math_fround($16 * $22);
  $28 = $23;$30 = $24;$32 = $25;$34 = $26;
 }
 $27 = (($motionData) + 12|0);
 HEAPF32[$27>>2] = $28;
 $29 = (($motionData) + 16|0);
 HEAPF32[$29>>2] = $30;
 $31 = (($motionData) + 20|0);
 HEAPF32[$31>>2] = $32;
 $33 = (($motionData) + 24|0);
 HEAPF32[$33>>2] = $34;
 if ($5) {
  $$0$i = Math_fround(0.0);
 } else {
  $35 = (($this) + 80|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   $$0$i = Math_fround(0.0);
  } else {
   $38 = (($36) + 8|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if ($40) {
    $$0$i = Math_fround(0.0);
   } else {
    $41 = (($39) + 420|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $$0$i = $42;
   }
  }
 }
 $43 = (($motionData) + 28|0);
 HEAPF32[$43>>2] = $$0$i;
 $44 = (($motionData) + 32|0);
 HEAP8[$44>>0] = 0;
 $45 = (($data$i) + 8|0);
 HEAP32[$45>>2] = 0;
 $46 = (($data$i) + 4|0);
 $inData$c$i$i = $motionData;
 HEAP32[$46>>2] = $inData$c$i$i;
 HEAP32[$data$i>>2] = 100006;
 __ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData($this,565032,$data$i);
 $47 = HEAP8[$44>>0]|0;
 $48 = ($47<<24>>24)==(0);
 if (!($48)) {
  STACKTOP = sp;return;
 }
 $49 = (($this) + 24|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($50)|0);
 $52 = HEAP32[$3>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  HEAPF32[$0>>2] = Math_fround(0.0);
  $54 = (($0) + 4|0);
  HEAPF32[$54>>2] = Math_fround(0.0);
  $55 = (($0) + 8|0);
  HEAPF32[$55>>2] = Math_fround(0.0);
 } else {
  $$idx$i = (($52) + 8|0);
  $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
  $$idx1$i = (($52) + 12|0);
  $$idx1$val$i = Math_fround(HEAPF32[$$idx1$i>>2]);
  $$idx2$i = (($52) + 16|0);
  $$idx2$val$i = Math_fround(HEAPF32[$$idx2$i>>2]);
  HEAPF32[$0>>2] = $$idx$val$i;
  $56 = (($0) + 4|0);
  HEAPF32[$56>>2] = $$idx1$val$i;
  $57 = (($0) + 8|0);
  HEAPF32[$57>>2] = $$idx2$val$i;
 }
 __ZN9Transform26SetPositionAndRotationSafeERK8Vector3fRK11Quaternionf($51,$0,$2);
 STACKTOP = sp;return;
}
function __ZN8Animator24SetupAnimationClipsCacheEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$05 = 0, $phitmp$i = 0, $temp$0$i = 0, $temp$0$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 HEAP32[$2>>2] = $4;
 $6 = HEAP32[560624>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  label = 10;
 } else {
  $8 = (($6) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  do {
   if ($12) {
    $13 = (($6) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($6) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + ($16<<3)|0);
    $33 = $17;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$6,$2);
    $18 = HEAP32[$$byval_copy1>>2]|0;
    $19 = ($18|0)==(-1);
    $20 = (($6) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    if ($19) {
     $22 = (($6) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($21) + ($23<<3)|0);
     $33 = $24;
     break;
    } else {
     $25 = (($21) + ($18<<3)|0);
     $33 = $25;
     break;
    }
   }
  } while(0);
  $26 = HEAP32[560624>>2]|0;
  $27 = (($26) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + ($30<<3)|0);
  $32 = ($33|0)==($31|0);
  if ($32) {
   label = 10;
  } else {
   $34 = (($33) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 10;
   } else {
    $41 = $26;
   }
  }
 }
 do {
  if ((label|0) == 10) {
   $37 = HEAP32[$3>>2]|0;
   $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
   $phitmp$i = ($38|0)==(0|0);
   if ($phitmp$i) {
    STACKTOP = sp;return;
   } else {
    $$pre6 = HEAP32[560624>>2]|0;
    $41 = $$pre6;
    break;
   }
  }
 } while(0);
 $39 = HEAP32[$3>>2]|0;
 HEAP32[$1>>2] = $39;
 $40 = ($41|0)==(0|0);
 if ($40) {
  label = 20;
 } else {
  $42 = (($41) + 36|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($43|0)==($45|0);
  do {
   if ($46) {
    $47 = (($41) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($41) + 32|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($48) + ($50<<3)|0);
    $67 = $51;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$41,$1);
    $52 = HEAP32[$$byval_copy1>>2]|0;
    $53 = ($52|0)==(-1);
    $54 = (($41) + 28|0);
    $55 = HEAP32[$54>>2]|0;
    if ($53) {
     $56 = (($41) + 32|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = (($55) + ($57<<3)|0);
     $67 = $58;
     break;
    } else {
     $59 = (($55) + ($52<<3)|0);
     $67 = $59;
     break;
    }
   }
  } while(0);
  $60 = HEAP32[560624>>2]|0;
  $61 = (($60) + 28|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($60) + 32|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($62) + ($64<<3)|0);
  $66 = ($67|0)==($65|0);
  if ($66) {
   label = 20;
  } else {
   $68 = (($67) + 4|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==(0|0);
   if ($70) {
    label = 20;
   } else {
    $temp$0$i = $69;
   }
  }
 }
 if ((label|0) == 20) {
  $71 = HEAP32[$3>>2]|0;
  $72 = (__Z31ReadObjectFromPersistentManageri($71)|0);
  $temp$0$i = $72;
 }
 $73 = HEAP32[$temp$0$i>>2]|0;
 $74 = (($73) + 100|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (FUNCTION_TABLE_ii[$75 & 4095]($temp$0$i)|0);
 $77 = (($this) + 468|0);
 $78 = (($76) + 8|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = (($this) + 476|0);
 HEAP32[$80>>2] = $79;
 $81 = (($this) + 480|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = $82 & 2147483647;
 $84 = ($83>>>0)<($79>>>0);
 do {
  if ($84) {
   $85 = ($82|0)>(-1);
   if ($85) {
    HEAP32[$81>>2] = $79;
    $86 = HEAP32[$77>>2]|0;
    $87 = $79 << 2;
    $88 = (($this) + 472|0);
    $89 = HEAP32[$88>>2]|0;
    HEAP32[$0>>2] = $89;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $90 = (__Z16realloc_internalPvji10MemLabelIdiPKci($86,$87,4,$$byval_copy1,0,769408,370)|0);
    HEAP32[$77>>2] = $90;
    break;
   } else {
    $91 = $79 << 2;
    $92 = (($this) + 472|0);
    $93 = HEAP32[$92>>2]|0;
    HEAP32[$0>>2] = $93;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $94 = (__Z15malloc_internaljj10MemLabelIdiPKci($91,4,$$byval_copy1,0,769408,352)|0);
    $95 = HEAP32[$77>>2]|0;
    $96 = HEAP32[$80>>2]|0;
    $97 = $96 << 2;
    _memcpy(($94|0),($95|0),($97|0))|0;
    HEAP32[$81>>2] = $79;
    HEAP32[$77>>2] = $94;
    break;
   }
  }
 } while(0);
 $98 = HEAP32[$78>>2]|0;
 $99 = ($98|0)==(0);
 if ($99) {
  STACKTOP = sp;return;
 }
 $142 = $98;$i$05 = 0;
 while(1) {
  $100 = HEAP32[$76>>2]|0;
  $101 = (($100) + ($i$05<<2)|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = ($102|0)==(0);
  if ($103) {
   $$0$i = 0;$141 = $142;
  } else {
   HEAP32[$0>>2] = $102;
   $104 = HEAP32[560624>>2]|0;
   $105 = ($104|0)==(0|0);
   if ($105) {
    label = 36;
   } else {
    $106 = (($104) + 36|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($104) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = ($107|0)==($109|0);
    do {
     if ($110) {
      $111 = (($104) + 28|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = (($104) + 32|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = (($112) + ($114<<3)|0);
      $131 = $115;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$104,$0);
      $116 = HEAP32[$$byval_copy1>>2]|0;
      $117 = ($116|0)==(-1);
      $118 = (($104) + 28|0);
      $119 = HEAP32[$118>>2]|0;
      if ($117) {
       $120 = (($104) + 32|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = (($119) + ($121<<3)|0);
       $131 = $122;
       break;
      } else {
       $123 = (($119) + ($116<<3)|0);
       $131 = $123;
       break;
      }
     }
    } while(0);
    $124 = HEAP32[560624>>2]|0;
    $125 = (($124) + 28|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = (($124) + 32|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = (($126) + ($128<<3)|0);
    $130 = ($131|0)==($129|0);
    if ($130) {
     label = 36;
    } else {
     $132 = (($131) + 4|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($133|0)==(0|0);
     if ($134) {
      label = 36;
     } else {
      $temp$0$i1 = $133;
     }
    }
   }
   if ((label|0) == 36) {
    label = 0;
    $135 = HEAP32[$101>>2]|0;
    $136 = (__Z31ReadObjectFromPersistentManageri($135)|0);
    $temp$0$i1 = $136;
   }
   $$pre = HEAP32[$78>>2]|0;
   $$0$i = $temp$0$i1;$141 = $$pre;
  }
  $137 = HEAP32[$77>>2]|0;
  $138 = (($137) + ($i$05<<2)|0);
  HEAP32[$138>>2] = $$0$i;
  $139 = (($i$05) + 1)|0;
  $140 = ($139>>>0)<($141>>>0);
  if ($140) {
   $142 = $141;$i$05 = $139;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN8Animator15SetupBehavioursEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $pos$i$i$i$i$i = 0, $temp$0$i = 0, $temp$0$i11 = 0, $temp$0$i16 = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i$i = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = (($this) + 372|0);
 $6 = (($this) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$4>>2] = $7;
 $8 = HEAP32[560624>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 9;
 } else {
  $10 = (($8) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($8) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11|0)==($13|0);
  do {
   if ($14) {
    $15 = (($8) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($8) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + ($18<<3)|0);
    $35 = $19;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$8,$4);
    $20 = HEAP32[$pos$i$i$i$i$i>>2]|0;
    $21 = ($20|0)==(-1);
    $22 = (($8) + 28|0);
    $23 = HEAP32[$22>>2]|0;
    if ($21) {
     $24 = (($8) + 32|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($23) + ($25<<3)|0);
     $35 = $26;
     break;
    } else {
     $27 = (($23) + ($20<<3)|0);
     $35 = $27;
     break;
    }
   }
  } while(0);
  $28 = HEAP32[560624>>2]|0;
  $29 = (($28) + 28|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 32|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + ($32<<3)|0);
  $34 = ($35|0)==($33|0);
  if ($34) {
   label = 9;
  } else {
   $36 = (($35) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    label = 9;
   } else {
    $temp$0$i = $37;
   }
  }
 }
 if ((label|0) == 9) {
  $39 = HEAP32[$6>>2]|0;
  $40 = (__Z31ReadObjectFromPersistentManageri($39)|0);
  $temp$0$i = $40;
 }
 $41 = HEAP32[$temp$0$i>>2]|0;
 $42 = (($41) + 108|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (FUNCTION_TABLE_ii[$43 & 4095]($temp$0$i)|0);
 $45 = ($5|0)==($44|0);
 if (!($45)) {
  $46 = HEAP32[$44>>2]|0;
  $47 = (($44) + 4|0);
  $48 = HEAP32[$47>>2]|0;
  __ZNSt3__16vectorI25StateMachineBehaviourInfoNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($5,$46,$48);
 }
 $49 = HEAP32[$6>>2]|0;
 HEAP32[$3>>2] = $49;
 $50 = HEAP32[560624>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  label = 20;
 } else {
  $52 = (($50) + 36|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($50) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($53|0)==($55|0);
  do {
   if ($56) {
    $57 = (($50) + 28|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($50) + 32|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (($58) + ($60<<3)|0);
    $77 = $61;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$50,$3);
    $62 = HEAP32[$pos$i$i$i$i$i>>2]|0;
    $63 = ($62|0)==(-1);
    $64 = (($50) + 28|0);
    $65 = HEAP32[$64>>2]|0;
    if ($63) {
     $66 = (($50) + 32|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($65) + ($67<<3)|0);
     $77 = $68;
     break;
    } else {
     $69 = (($65) + ($62<<3)|0);
     $77 = $69;
     break;
    }
   }
  } while(0);
  $70 = HEAP32[560624>>2]|0;
  $71 = (($70) + 28|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($70) + 32|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($72) + ($74<<3)|0);
  $76 = ($77|0)==($75|0);
  if ($76) {
   label = 20;
  } else {
   $78 = (($77) + 4|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = ($79|0)==(0|0);
   if ($80) {
    label = 20;
   } else {
    $temp$0$i5 = $79;
   }
  }
 }
 if ((label|0) == 20) {
  $81 = HEAP32[$6>>2]|0;
  $82 = (__Z31ReadObjectFromPersistentManageri($81)|0);
  $temp$0$i5 = $82;
 }
 $83 = HEAP32[$temp$0$i5>>2]|0;
 $84 = (($83) + 116|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (FUNCTION_TABLE_ii[$85 & 4095]($temp$0$i5)|0);
 $87 = (($this) + 384|0);
 $88 = $86&1;
 HEAP8[$87>>0] = $88;
 $89 = HEAP32[$5>>2]|0;
 $90 = (($this) + 376|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($89|0)==($91|0);
 if ($92) {
  STACKTOP = sp;return;
 }
 $94 = $89;
 while(1) {
  $93 = HEAP32[$94>>2]|0;
  $95 = ($93|0)==(0);
  do {
   if (!($95)) {
    HEAP32[$0>>2] = $93;
    $96 = HEAP32[560624>>2]|0;
    $97 = ($96|0)==(0|0);
    if ($97) {
     label = 32;
    } else {
     $98 = (($96) + 36|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = (($96) + 4|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($99|0)==($101|0);
     do {
      if ($102) {
       $103 = (($96) + 28|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = (($96) + 32|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = (($104) + ($106<<3)|0);
       $123 = $107;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$96,$0);
       $108 = HEAP32[$pos$i$i$i$i$i>>2]|0;
       $109 = ($108|0)==(-1);
       $110 = (($96) + 28|0);
       $111 = HEAP32[$110>>2]|0;
       if ($109) {
        $112 = (($96) + 32|0);
        $113 = HEAP32[$112>>2]|0;
        $114 = (($111) + ($113<<3)|0);
        $123 = $114;
        break;
       } else {
        $115 = (($111) + ($108<<3)|0);
        $123 = $115;
        break;
       }
      }
     } while(0);
     $116 = HEAP32[560624>>2]|0;
     $117 = (($116) + 28|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = (($116) + 32|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = (($118) + ($120<<3)|0);
     $122 = ($123|0)==($121|0);
     if ($122) {
      label = 32;
     } else {
      $124 = (($123) + 4|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = ($125|0)==(0|0);
      if ($126) {
       label = 32;
      } else {
       $131 = $116;
      }
     }
    }
    if ((label|0) == 32) {
     label = 0;
     $127 = HEAP32[$94>>2]|0;
     $128 = (__Z31ReadObjectFromPersistentManageri($127)|0);
     $phitmp$i = ($128|0)==(0|0);
     if ($phitmp$i) {
      break;
     }
     $$pre = HEAP32[560624>>2]|0;
     $131 = $$pre;
    }
    $129 = HEAP32[$94>>2]|0;
    HEAP32[$1>>2] = $129;
    $130 = ($131|0)==(0|0);
    if ($130) {
     label = 42;
    } else {
     $132 = (($131) + 36|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = (($131) + 4|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($133|0)==($135|0);
     do {
      if ($136) {
       $137 = (($131) + 28|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = (($131) + 32|0);
       $140 = HEAP32[$139>>2]|0;
       $141 = (($138) + ($140<<3)|0);
       $157 = $141;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$131,$1);
       $142 = HEAP32[$pos$i$i$i$i$i>>2]|0;
       $143 = ($142|0)==(-1);
       $144 = (($131) + 28|0);
       $145 = HEAP32[$144>>2]|0;
       if ($143) {
        $146 = (($131) + 32|0);
        $147 = HEAP32[$146>>2]|0;
        $148 = (($145) + ($147<<3)|0);
        $157 = $148;
        break;
       } else {
        $149 = (($145) + ($142<<3)|0);
        $157 = $149;
        break;
       }
      }
     } while(0);
     $150 = HEAP32[560624>>2]|0;
     $151 = (($150) + 28|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = (($150) + 32|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (($152) + ($154<<3)|0);
     $156 = ($157|0)==($155|0);
     if ($156) {
      label = 42;
     } else {
      $158 = (($157) + 4|0);
      $159 = HEAP32[$158>>2]|0;
      $160 = ($159|0)==(0|0);
      if ($160) {
       label = 42;
      } else {
       $temp$0$i16 = $159;
      }
     }
    }
    if ((label|0) == 42) {
     label = 0;
     $161 = HEAP32[$94>>2]|0;
     $162 = (__Z31ReadObjectFromPersistentManageri($161)|0);
     $temp$0$i16 = $162;
    }
    $163 = (__ZNK13MonoBehaviour8GetClassEv($temp$0$i16)|0);
    $164 = ($163|0)==(0|0);
    if (!($164)) {
     $165 = (__Z19GetScriptingManagerv()|0);
     $166 = (($165) + 580|0);
     $167 = HEAP32[$166>>2]|0;
     $168 = (__Z29scripting_class_has_attributeP14ScriptingClassS0_($163,$167)|0);
     if (!($168)) {
      $169 = HEAP32[$94>>2]|0;
      HEAP32[$2>>2] = $169;
      $170 = HEAP32[560624>>2]|0;
      $171 = ($170|0)==(0|0);
      if ($171) {
       label = 53;
      } else {
       $172 = (($170) + 36|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = (($170) + 4|0);
       $175 = HEAP32[$174>>2]|0;
       $176 = ($173|0)==($175|0);
       do {
        if ($176) {
         $177 = (($170) + 28|0);
         $178 = HEAP32[$177>>2]|0;
         $179 = (($170) + 32|0);
         $180 = HEAP32[$179>>2]|0;
         $181 = (($178) + ($180<<3)|0);
         $197 = $181;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$170,$2);
         $182 = HEAP32[$pos$i$i$i$i$i>>2]|0;
         $183 = ($182|0)==(-1);
         $184 = (($170) + 28|0);
         $185 = HEAP32[$184>>2]|0;
         if ($183) {
          $186 = (($170) + 32|0);
          $187 = HEAP32[$186>>2]|0;
          $188 = (($185) + ($187<<3)|0);
          $197 = $188;
          break;
         } else {
          $189 = (($185) + ($182<<3)|0);
          $197 = $189;
          break;
         }
        }
       } while(0);
       $190 = HEAP32[560624>>2]|0;
       $191 = (($190) + 28|0);
       $192 = HEAP32[$191>>2]|0;
       $193 = (($190) + 32|0);
       $194 = HEAP32[$193>>2]|0;
       $195 = (($192) + ($194<<3)|0);
       $196 = ($197|0)==($195|0);
       if ($196) {
        label = 53;
       } else {
        $198 = (($197) + 4|0);
        $199 = HEAP32[$198>>2]|0;
        $200 = ($199|0)==(0|0);
        if ($200) {
         label = 53;
        } else {
         $temp$0$i11 = $199;
        }
       }
      }
      if ((label|0) == 53) {
       label = 0;
       $201 = HEAP32[$94>>2]|0;
       $202 = (__Z31ReadObjectFromPersistentManageri($201)|0);
       $temp$0$i11 = $202;
      }
      $203 = (__Z11CloneObjectR6Object($temp$0$i11)|0);
      $204 = ($203|0)==(0|0);
      if (!($204)) {
       $205 = (($203) + 8|0);
       $206 = HEAP32[$205>>2]|0;
       $207 = $206 >>> 21;
       $208 = HEAP32[560640>>2]|0;
       $209 = Math_imul($208, $207)|0;
       $210 = (($209) + 114)|0;
       $211 = $210 >> 5;
       $212 = $211 << 5;
       $213 = (($210) - ($212))|0;
       $214 = HEAP32[560632>>2]|0;
       $215 = (($214) + ($211<<2)|0);
       $216 = HEAP32[$215>>2]|0;
       $217 = 1 << $213;
       $218 = $217 & $216;
       $219 = ($218|0)==(0);
       if (!($219)) {
        $220 = (($203) + 4|0);
        $221 = HEAP32[$220>>2]|0;
        HEAP32[$94>>2] = $221;
        break;
       }
      }
      HEAP32[$94>>2] = 0;
     }
    }
   }
  } while(0);
  $222 = (($94) + 4|0);
  $223 = HEAP32[$90>>2]|0;
  $224 = ($222|0)==($223|0);
  if ($224) {
   break;
  } else {
   $94 = $222;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK8Animator12IsInitializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = 0;
 } else {
  $3 = HEAP32[$1>>2]|0;
  $4 = ($3|0)!=(0);
  $5 = $4;
 }
 STACKTOP = sp;return ($5|0);
}
function __ZThn32_NK8Animator12IsInitializeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -32|0);
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $6 = 0;
  STACKTOP = sp;return ($6|0);
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)!=(0);
 $6 = $5;
 STACKTOP = sp;return ($6|0);
}
function __ZNK8Animator7IsValidEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN8Animator9GetAvatarEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 56|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN8Animator17GetAvatarConstantEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN8Animator12CreateObjectEv($this);
 }
 $3 = (($this) + 72|0);
 $4 = HEAP32[$3>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN8Animator19SetVisibleRenderersEb($this,$visible) {
 $this = $this|0;
 $visible = $visible|0;
 var $$not = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $animator = 0, $brmerge = 0, $or$cond = 0;
 var $phitmp = 0, $phitmp3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $animator = sp;
 $0 = (($this) + 44|0);
 if ($visible) {
  $1 = HEAP8[$0>>0]|0;
  $phitmp = ($1<<24>>24)!=(0);
  $4 = $phitmp;
 } else {
  $4 = 1;
 }
 $2 = $visible&1;
 HEAP8[$0>>0] = $2;
 $3 = (__Z14IsWorldPlayingv()|0);
 $$not = $3 ^ 1;
 $brmerge = $4 | $$not;
 if ($brmerge) {
  STACKTOP = sp;return;
 }
 $5 = (__Z14GetTimeManagerv()|0);
 $6 = (($5) + 104|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(-1);
 if ($10) {
  $11 = (($this) + 40|0);
  $12 = HEAP32[$11>>2]|0;
  $phitmp3 = ($12|0)==(-1);
  $14 = $phitmp3;
 } else {
  $14 = 0;
 }
 $13 = $7 == Math_fround(0.0);
 $or$cond = $14 | $13;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + 136|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_ii[$17 & 4095]($this)|0);
 if (!($18)) {
  __ZN8Animator12CreateObjectEv($this);
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = (($19) + 136|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_ii[$21 & 4095]($this)|0);
 if (!($22)) {
  STACKTOP = sp;return;
 }
 HEAP32[$animator>>2] = $this;
 $23 = (($this) + 48|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(2);
 $$phi$trans$insert = (($this) + 84|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 if ($25) {
  $33 = 1;
 } else {
  $26 = (($$pre) + 172|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = ($27<<24>>24)!=(0);
  $33 = $28;
 }
 $29 = (($this) + 84|0);
 $30 = (($$pre) + 172|0);
 HEAP8[$30>>0] = 1;
 $31 = HEAP32[$29>>2]|0;
 $32 = (($31) + 173|0);
 HEAP8[$32>>0] = 0;
 __ZN8Animator13UpdateAvatarsEPPS_jfbbf($animator,1,$7,$33,1,Math_fround(0.0));
 STACKTOP = sp;return;
}
function __ZN8Animator26AnimatorVisibilityCallbackEPvS0_i($userData,$renderer,$visibilityEvent) {
 $userData = $userData|0;
 $renderer = $renderer|0;
 $visibilityEvent = $visibilityEvent|0;
 var $$0$i = 0, $$0$i4 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $i$01$i2 = 0, $i$04$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($visibilityEvent|0) == 0)) {
  __ZN8Animator19SetVisibleRenderersEb($userData,1);
  STACKTOP = sp;return;
 } else if ((($visibilityEvent|0) == 2)) {
  $10 = (($userData) + 364|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0);
  L6: do {
   if ($12) {
    $$0$i4 = 0;
   } else {
    $13 = (($userData) + 356|0);
    $14 = HEAP32[$13>>2]|0;
    $i$04$i = 0;
    while(1) {
     $17 = (($14) + ($i$04$i<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($18|0)==($renderer|0);
     $16 = (($i$04$i) + 1)|0;
     if ($19) {
      label = 11;
      break;
     }
     $15 = ($16>>>0)<($11>>>0);
     if ($15) {
      $i$04$i = $16;
     } else {
      $24 = $14;$25 = $11;
      break;
     }
    }
    if ((label|0) == 11) {
     $20 = (($11) + -1)|0;
     $21 = (($14) + ($20<<2)|0);
     $22 = HEAP32[$21>>2]|0;
     HEAP32[$17>>2] = $22;
     HEAP32[$10>>2] = $20;
     $$pre = HEAP32[$13>>2]|0;
     $24 = $$pre;$25 = $20;
    }
    $23 = (($24) + ($25<<2)|0);
    $26 = ($25|0)==(0);
    if ($26) {
     $$0$i4 = 0;
    } else {
     $i$01$i2 = $24;
     while(1) {
      $29 = HEAP32[$i$01$i2>>2]|0;
      $30 = (__ZNK8Renderer16IsVisibleInSceneEv($29)|0);
      $28 = (($i$01$i2) + 4|0);
      if ($30) {
       $$0$i4 = 1;
       break L6;
      }
      $27 = ($28|0)==($23|0);
      if ($27) {
       $$0$i4 = 0;
       break;
      } else {
       $i$01$i2 = $28;
      }
     }
    }
   }
  } while(0);
  __ZN8Animator19SetVisibleRenderersEb($userData,$$0$i4);
  STACKTOP = sp;return;
 } else if ((($visibilityEvent|0) == 1)) {
  $0 = (($userData) + 356|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($userData) + 364|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($1) + ($3<<2)|0);
  $5 = ($3|0)==(0);
  L20: do {
   if ($5) {
    $$0$i = 0;
   } else {
    $i$01$i = $1;
    while(1) {
     $8 = HEAP32[$i$01$i>>2]|0;
     $9 = (__ZNK8Renderer16IsVisibleInSceneEv($8)|0);
     $7 = (($i$01$i) + 4|0);
     if ($9) {
      $$0$i = 1;
      break L20;
     }
     $6 = ($7|0)==($4|0);
     if ($6) {
      $$0$i = 0;
      break;
     } else {
      $i$01$i = $7;
     }
    }
   }
  } while(0);
  __ZN8Animator19SetVisibleRenderersEb($userData,$$0$i);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN8Animator34RecomputeContainedRenderersRecurseER9Transform($this,$transform) {
 $this = $this|0;
 $transform = $transform|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($transform) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($2,25)|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($this) + 356|0);
  $6 = (($this) + 364|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$6>>2] = $8;
  $9 = (($this) + 368|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & 2147483647;
  $12 = ($8>>>0)>($11>>>0);
  if ($12) {
   $13 = $10 << 1;
   $14 = ($13|0)==(0);
   $15 = $14 ? 1 : $13;
   $16 = ($11>>>0)<($15>>>0);
   do {
    if ($16) {
     $17 = ($10|0)>(-1);
     if ($17) {
      HEAP32[$9>>2] = $15;
      $18 = HEAP32[$5>>2]|0;
      $19 = $15 << 2;
      $20 = (($this) + 360|0);
      $21 = HEAP32[$20>>2]|0;
      HEAP32[$0>>2] = $21;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($18,$19,4,$$byval_copy1,0,769408,370)|0);
      HEAP32[$5>>2] = $22;
      break;
     } else {
      $23 = $15 << 2;
      $24 = (($this) + 360|0);
      $25 = HEAP32[$24>>2]|0;
      HEAP32[$0>>2] = $25;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($23,4,$$byval_copy1,0,769408,352)|0);
      $27 = HEAP32[$5>>2]|0;
      $28 = HEAP32[$6>>2]|0;
      $29 = $28 << 2;
      _memcpy(($26|0),($27|0),($29|0))|0;
      HEAP32[$9>>2] = $15;
      HEAP32[$5>>2] = $26;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$6>>2]|0;
   $31 = $$pre$i$i;
  } else {
   $31 = $8;
  }
  $30 = (($31) + -1)|0;
  $32 = HEAP32[$5>>2]|0;
  $33 = (($32) + ($30<<2)|0);
  HEAP32[$33>>2] = $3;
  __ZN6Object8AddEventEPFvPvS0_iES0_($3,2018,$this);
 }
 $34 = (($transform) + 140|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($transform) + 148|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + ($37<<2)|0);
 $39 = ($37|0)==(0);
 if ($39) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $35;
 }
 while(1) {
  $40 = HEAP32[$i$01>>2]|0;
  __ZN8Animator34RecomputeContainedRenderersRecurseER9Transform($this,$40);
  $41 = (($i$01) + 4|0);
  $42 = ($41|0)==($38|0);
  if ($42) {
   break;
  } else {
   $i$01 = $41;
  }
 }
 STACKTOP = sp;return;
}
function __ZN8Animator13GetAvatarRootEv($this) {
 $this = $this|0;
 var $$effectiveRoot$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $effectiveRoot$0 = 0, $phitmp$i = 0, $pos$i$i$i$i13 = 0, $temp$0$i = 0, $temp$0$i11 = 0, $temp$0$i17 = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i13 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 $5 = (($this) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($6)|0);
 $8 = (($this) + 56|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return ($7|0);
 }
 HEAP32[$3>>2] = $9;
 $11 = HEAP32[560624>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  label = 10;
 } else {
  $13 = (($11) + 36|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($11) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14|0)==($16|0);
  do {
   if ($17) {
    $18 = (($11) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($11) + 32|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($19) + ($21<<3)|0);
    $38 = $22;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i13,$11,$3);
    $23 = HEAP32[$pos$i$i$i$i13>>2]|0;
    $24 = ($23|0)==(-1);
    $25 = (($11) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    if ($24) {
     $27 = (($11) + 32|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($26) + ($28<<3)|0);
     $38 = $29;
     break;
    } else {
     $30 = (($26) + ($23<<3)|0);
     $38 = $30;
     break;
    }
   }
  } while(0);
  $31 = HEAP32[560624>>2]|0;
  $32 = (($31) + 28|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + 32|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + ($35<<3)|0);
  $37 = ($38|0)==($36|0);
  if ($37) {
   label = 10;
  } else {
   $39 = (($38) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    label = 10;
   } else {
    $46 = $31;
   }
  }
 }
 do {
  if ((label|0) == 10) {
   $42 = HEAP32[$8>>2]|0;
   $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
   $phitmp$i = ($43|0)==(0|0);
   if ($phitmp$i) {
    STACKTOP = sp;return ($7|0);
   } else {
    $$pre = HEAP32[560624>>2]|0;
    $46 = $$pre;
    break;
   }
  }
 } while(0);
 $44 = HEAP32[$8>>2]|0;
 HEAP32[$2>>2] = $44;
 $45 = ($46|0)==(0|0);
 if ($45) {
  label = 20;
 } else {
  $47 = (($46) + 36|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($48|0)==($50|0);
  do {
   if ($51) {
    $52 = (($46) + 28|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($46) + 32|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($53) + ($55<<3)|0);
    $72 = $56;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i13,$46,$2);
    $57 = HEAP32[$pos$i$i$i$i13>>2]|0;
    $58 = ($57|0)==(-1);
    $59 = (($46) + 28|0);
    $60 = HEAP32[$59>>2]|0;
    if ($58) {
     $61 = (($46) + 32|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($60) + ($62<<3)|0);
     $72 = $63;
     break;
    } else {
     $64 = (($60) + ($57<<3)|0);
     $72 = $64;
     break;
    }
   }
  } while(0);
  $65 = HEAP32[560624>>2]|0;
  $66 = (($65) + 28|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = (($65) + 32|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($67) + ($69<<3)|0);
  $71 = ($72|0)==($70|0);
  if ($71) {
   label = 20;
  } else {
   $73 = (($72) + 4|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    label = 20;
   } else {
    $temp$0$i5 = $74;
   }
  }
 }
 if ((label|0) == 20) {
  $76 = HEAP32[$8>>2]|0;
  $77 = (__Z31ReadObjectFromPersistentManageri($76)|0);
  $temp$0$i5 = $77;
 }
 $78 = (__ZN6Avatar8GetAssetEv($temp$0$i5)|0);
 $79 = ($78|0)==(0|0);
 if ($79) {
  $effectiveRoot$0 = 0;
  $206 = ($effectiveRoot$0|0)==(0|0);
  $$effectiveRoot$0 = $206 ? $7 : $effectiveRoot$0;
  STACKTOP = sp;return ($$effectiveRoot$0|0);
 }
 $80 = HEAP32[$8>>2]|0;
 HEAP32[$1>>2] = $80;
 $81 = HEAP32[560624>>2]|0;
 $82 = ($81|0)==(0|0);
 if ($82) {
  label = 30;
 } else {
  $83 = (($81) + 36|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($81) + 4|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($84|0)==($86|0);
  do {
   if ($87) {
    $88 = (($81) + 28|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($81) + 32|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = (($89) + ($91<<3)|0);
    $108 = $92;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i13,$81,$1);
    $93 = HEAP32[$pos$i$i$i$i13>>2]|0;
    $94 = ($93|0)==(-1);
    $95 = (($81) + 28|0);
    $96 = HEAP32[$95>>2]|0;
    if ($94) {
     $97 = (($81) + 32|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = (($96) + ($98<<3)|0);
     $108 = $99;
     break;
    } else {
     $100 = (($96) + ($93<<3)|0);
     $108 = $100;
     break;
    }
   }
  } while(0);
  $101 = HEAP32[560624>>2]|0;
  $102 = (($101) + 28|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (($101) + 32|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($103) + ($105<<3)|0);
  $107 = ($108|0)==($106|0);
  if ($107) {
   label = 30;
  } else {
   $109 = (($108) + 4|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ($110|0)==(0|0);
   if ($111) {
    label = 30;
   } else {
    $temp$0$i11 = $110;
   }
  }
 }
 if ((label|0) == 30) {
  $112 = HEAP32[$8>>2]|0;
  $113 = (__Z31ReadObjectFromPersistentManageri($112)|0);
  $temp$0$i11 = $113;
 }
 $114 = (__ZN6Avatar8GetAssetEv($temp$0$i11)|0);
 $115 = $114;
 $116 = HEAP32[$114>>2]|0;
 $117 = (($116) + ($115))|0;
 $118 = $117;
 $119 = (($114) + 4|0);
 HEAP32[$119>>2] = $118;
 $120 = ($117|0)==(0);
 if ($120) {
  $effectiveRoot$0 = 0;
  $206 = ($effectiveRoot$0|0)==(0|0);
  $$effectiveRoot$0 = $206 ? $7 : $effectiveRoot$0;
  STACKTOP = sp;return ($$effectiveRoot$0|0);
 }
 $121 = HEAP32[$8>>2]|0;
 HEAP32[$0>>2] = $121;
 $122 = HEAP32[560624>>2]|0;
 $123 = ($122|0)==(0|0);
 if ($123) {
  label = 40;
 } else {
  $124 = (($122) + 36|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (($122) + 4|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ($125|0)==($127|0);
  do {
   if ($128) {
    $129 = (($122) + 28|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = (($122) + 32|0);
    $132 = HEAP32[$131>>2]|0;
    $133 = (($130) + ($132<<3)|0);
    $149 = $133;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i13,$122,$0);
    $134 = HEAP32[$pos$i$i$i$i13>>2]|0;
    $135 = ($134|0)==(-1);
    $136 = (($122) + 28|0);
    $137 = HEAP32[$136>>2]|0;
    if ($135) {
     $138 = (($122) + 32|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = (($137) + ($139<<3)|0);
     $149 = $140;
     break;
    } else {
     $141 = (($137) + ($134<<3)|0);
     $149 = $141;
     break;
    }
   }
  } while(0);
  $142 = HEAP32[560624>>2]|0;
  $143 = (($142) + 28|0);
  $144 = HEAP32[$143>>2]|0;
  $145 = (($142) + 32|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = (($144) + ($146<<3)|0);
  $148 = ($149|0)==($147|0);
  if ($148) {
   label = 40;
  } else {
   $150 = (($149) + 4|0);
   $151 = HEAP32[$150>>2]|0;
   $152 = ($151|0)==(0|0);
   if ($152) {
    label = 40;
   } else {
    $temp$0$i17 = $151;
   }
  }
 }
 if ((label|0) == 40) {
  $153 = HEAP32[$8>>2]|0;
  $154 = (__Z31ReadObjectFromPersistentManageri($153)|0);
  $temp$0$i17 = $154;
 }
 $155 = (__ZN6Avatar8GetAssetEv($temp$0$i17)|0);
 $156 = $155;
 $157 = HEAP32[$155>>2]|0;
 $158 = (($157) + ($156))|0;
 $159 = $158;
 $160 = (($155) + 4|0);
 HEAP32[$160>>2] = $159;
 $161 = HEAP32[$8>>2]|0;
 HEAP32[$4>>2] = $161;
 $162 = HEAP32[560624>>2]|0;
 $163 = ($162|0)==(0|0);
 if ($163) {
  label = 49;
 } else {
  $164 = (($162) + 36|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = (($162) + 4|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = ($165|0)==($167|0);
  do {
   if ($168) {
    $169 = (($162) + 28|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = (($162) + 32|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = (($170) + ($172<<3)|0);
    $189 = $173;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i13,$162,$4);
    $174 = HEAP32[$pos$i$i$i$i13>>2]|0;
    $175 = ($174|0)==(-1);
    $176 = (($162) + 28|0);
    $177 = HEAP32[$176>>2]|0;
    if ($175) {
     $178 = (($162) + 32|0);
     $179 = HEAP32[$178>>2]|0;
     $180 = (($177) + ($179<<3)|0);
     $189 = $180;
     break;
    } else {
     $181 = (($177) + ($174<<3)|0);
     $189 = $181;
     break;
    }
   }
  } while(0);
  $182 = HEAP32[560624>>2]|0;
  $183 = (($182) + 28|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = (($182) + 32|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = (($184) + ($186<<3)|0);
  $188 = ($189|0)==($187|0);
  if ($188) {
   label = 49;
  } else {
   $190 = (($189) + 4|0);
   $191 = HEAP32[$190>>2]|0;
   $192 = ($191|0)==(0|0);
   if ($192) {
    label = 49;
   } else {
    $temp$0$i = $191;
   }
  }
 }
 if ((label|0) == 49) {
  $193 = HEAP32[$8>>2]|0;
  $194 = (__Z31ReadObjectFromPersistentManageri($193)|0);
  $temp$0$i = $194;
 }
 $195 = (__ZN6Avatar8GetAssetEv($temp$0$i)|0);
 $196 = (($195) + 28|0);
 $197 = $196;
 $198 = HEAP32[$196>>2]|0;
 $199 = (($197) + ($198))|0;
 $200 = $199;
 $201 = (($195) + 32|0);
 HEAP32[$201>>2] = $200;
 $202 = (($this) + 465|0);
 $203 = HEAP8[$202>>0]|0;
 $204 = ($203<<24>>24)!=(0);
 $205 = (__Z14FindAvatarRootPKN7mecanim8skeleton8SkeletonEPKjR9Transformb($159,$200,$7,$204)|0);
 $effectiveRoot$0 = $205;
 $206 = ($effectiveRoot$0|0)==(0|0);
 $$effectiveRoot$0 = $206 ? $7 : $effectiveRoot$0;
 STACKTOP = sp;return ($$effectiveRoot$0|0);
}
function __Z8CopyBlobIN7mecanim9animation12AvatarMemoryEEPT_RKS3_RNS0_6memory9AllocatorERj($data,$allocator,$size) {
 $data = $data|0;
 $allocator = $allocator|0;
 $size = $size|0;
 var $$0 = 0, $$01 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $blob = 0, $blobWrite = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy1 = sp + 72|0;
 $0 = sp;
 $blob = sp + 8|0;
 $blobWrite = sp + 24|0;
 HEAP32[$blob>>2] = 0;
 $1 = (($blob) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($blob) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($blob) + 4|0);
 HEAP32[$3>>2] = 61;
 __THREW__ = 0;
 invoke_viiii(417,($blobWrite|0),($blob|0),0,-2);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $$0 = $18;$$01 = $19;
 } else {
  $6 = (($blobWrite) + 21|0);
  HEAP8[$6>>0] = 0;
  __THREW__ = 0;
  invoke_viiii(418,($blobWrite|0),($data|0),(769384|0),0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = HEAP32[$allocator>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$1>>2]|0;
   __THREW__ = 0;
   $12 = (invoke_iiii($10|0,($allocator|0),($11|0),16)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = ($12|0)==(0|0);
    if (!($15)) {
     $16 = HEAP32[$blob>>2]|0;
     $17 = HEAP32[$1>>2]|0;
     _memcpy(($12|0),($16|0),($17|0))|0;
    }
    $22 = HEAP32[$1>>2]|0;
    HEAP32[$size>>2] = $22;
    __ZN9BlobWriteD1Ev($blobWrite);
    $23 = HEAP32[$2>>2]|0;
    $24 = ($23|0)>(-1);
    if (!($24)) {
     STACKTOP = sp;return ($12|0);
    }
    $25 = HEAP32[$blob>>2]|0;
    $26 = HEAP32[$3>>2]|0;
    HEAP32[$0>>2] = $26;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
    HEAP32[$blob>>2] = 0;
    STACKTOP = sp;return ($12|0);
   }
  }
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  __ZN9BlobWriteD1Ev($blobWrite);
  $$0 = $20;$$01 = $21;
 }
 $27 = HEAP32[$2>>2]|0;
 $28 = ($27|0)>(-1);
 if (!($28)) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $29 = HEAP32[$blob>>2]|0;
 $30 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy1|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $33 = ___cxa_find_matching_catch(0|0)|0;
  $34 = tempRet0;
  ___clang_call_terminate($33);
  // unreachable;
 }
 HEAP32[$blob>>2] = 0;
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$layerIndex,$stateInfoIndex,$output) {
 $this = $this|0;
 $layerIndex = $layerIndex|0;
 $stateInfoIndex = $stateInfoIndex|0;
 $output = $output|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i1 = Math_fround(0), $$0$i3 = 0, $$0$i3$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0);
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ($layerIndex|0)<(0);
 if (!($4)) {
  $5 = HEAP32[$this>>2]|0;
  $6 = (($5) + 136|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_ii[$7 & 4095]($this)|0);
  if ($8) {
   $9 = (($this) + 92|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$10>>2]|0;
   $$0$i$i = $11;
  } else {
   $$0$i$i = 0;
  }
  $12 = ($$0$i$i|0)>($layerIndex|0);
  if ($12) {
   $13 = (($this) + 92|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 4|0);
   $16 = $15;
   $17 = HEAP32[$15>>2]|0;
   $18 = (($16) + ($17))|0;
   $19 = $18;
   $20 = (($19) + ($layerIndex<<3)|0);
   $21 = $20;
   $22 = HEAP32[$20>>2]|0;
   $23 = (($21) + ($22))|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(-1);
   if ($26) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769584,0,769408,3070,1,0,0,0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $27 = (($14) + 16|0);
   $28 = $27;
   $29 = HEAP32[$27>>2]|0;
   $30 = (($29) + ($28))|0;
   $31 = $30;
   $32 = (($31) + ($25<<3)|0);
   $33 = $32;
   $34 = HEAP32[$32>>2]|0;
   $35 = (($33) + ($34))|0;
   $36 = $35;
   $37 = (($this) + 84|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38;
   $40 = HEAP32[$38>>2]|0;
   $41 = (($40) + ($39))|0;
   $42 = $41;
   $43 = (($38) + 4|0);
   HEAP32[$43>>2] = $42;
   $44 = (($42) + 4|0);
   $45 = $44;
   $46 = HEAP32[$44>>2]|0;
   $47 = (($45) + ($46))|0;
   $48 = $47;
   $49 = (($42) + 8|0);
   HEAP32[$49>>2] = $48;
   $50 = (($48) + ($25<<3)|0);
   $51 = $50;
   $52 = HEAP32[$50>>2]|0;
   $53 = (($51) + ($52))|0;
   $54 = $53;
   $55 = ((($48) + ($25<<3)|0) + 4|0);
   HEAP32[$55>>2] = $54;
   do {
    if ((($stateInfoIndex|0) == 0)) {
     $56 = (($54) + 12|0);
     $$0$i3$in = $56;
    } else if ((($stateInfoIndex|0) == 1)) {
     $58 = (($54) + 73|0);
     $59 = HEAP8[$58>>0]|0;
     $60 = ($59<<24>>24)==(0);
     if ($60) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     } else {
      $61 = (($54) + 16|0);
      $$0$i3$in = $61;
      break;
     }
    } else if ((($stateInfoIndex|0) == 2)) {
     $57 = (($54) + 20|0);
     $$0$i3$in = $57;
    } else {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $$0$i3 = HEAP32[$$0$i3$in>>2]|0;
   $62 = HEAP32[$36>>2]|0;
   $63 = ($$0$i3>>>0)<($62>>>0);
   if (!($63)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $64 = (($36) + 4|0);
   $65 = $64;
   $66 = HEAP32[$64>>2]|0;
   $67 = (($66) + ($65))|0;
   $68 = $67;
   $69 = (($68) + ($$0$i3<<3)|0);
   $70 = $69;
   $71 = HEAP32[$69>>2]|0;
   $72 = (($70) + ($71))|0;
   $73 = $72;
   $74 = (($73) + 44|0);
   $75 = HEAP32[$74>>2]|0;
   HEAP32[$output>>2] = $75;
   $76 = HEAP32[$64>>2]|0;
   $77 = (($76) + ($65))|0;
   $78 = $77;
   $79 = (($78) + ($$0$i3<<3)|0);
   $80 = $79;
   $81 = HEAP32[$79>>2]|0;
   $82 = (($80) + ($81))|0;
   $83 = $82;
   $84 = (($83) + 48|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($output) + 4|0);
   HEAP32[$86>>2] = $85;
   $87 = HEAP32[$64>>2]|0;
   $88 = (($87) + ($65))|0;
   $89 = $88;
   $90 = (($89) + ($$0$i3<<3)|0);
   $91 = $90;
   $92 = HEAP32[$90>>2]|0;
   $93 = (($91) + ($92))|0;
   $94 = $93;
   $95 = (($94) + 52|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = (($output) + 8|0);
   HEAP32[$97>>2] = $96;
   if ((($stateInfoIndex|0) == 1)) {
    $106 = (($54) + 40|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = (($output) + 12|0);
    HEAPF32[$108>>2] = $107;
    $109 = (($54) + 48|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $$0$i1 = $110;
   } else if ((($stateInfoIndex|0) == 2)) {
    $98 = (($output) + 12|0);
    HEAPF32[$98>>2] = Math_fround(1.0);
    $99 = (($54) + 52|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $$0$i1 = $100;
   } else if ((($stateInfoIndex|0) == 0)) {
    $101 = (($54) + 36|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $103 = (($output) + 12|0);
    HEAPF32[$103>>2] = $102;
    $104 = (($54) + 44|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $$0$i1 = $105;
   } else {
    $111 = (($output) + 12|0);
    HEAPF32[$111>>2] = Math_fround(0.0);
    $$0$i1 = Math_fround(0.0);
   }
   $112 = (($output) + 16|0);
   HEAPF32[$112>>2] = $$0$i1;
   $113 = HEAP32[$64>>2]|0;
   $114 = (($113) + ($65))|0;
   $115 = $114;
   $116 = (($115) + ($$0$i3<<3)|0);
   $117 = $116;
   $118 = HEAP32[$116>>2]|0;
   $119 = (($117) + ($118))|0;
   $120 = $119;
   $121 = (($120) + 56|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = (($output) + 20|0);
   HEAP32[$123>>2] = $122;
   $124 = HEAP32[$64>>2]|0;
   $125 = (($124) + ($65))|0;
   $126 = $125;
   $127 = (($126) + ($$0$i3<<3)|0);
   $128 = $127;
   $129 = HEAP32[$127>>2]|0;
   $130 = (($128) + ($129))|0;
   $131 = $130;
   $132 = (($131) + 70|0);
   $133 = HEAP8[$132>>0]|0;
   $134 = $133&255;
   $135 = (($output) + 24|0);
   HEAP32[$135>>2] = $134;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769560,0,769408,3064,1,0,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK8Animator20IsInMatchTargetStateEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 136|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_ii[$6 & 4095]($this)|0);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = (($8) + 136|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
 if ($11) {
  $12 = (($this) + 92|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)>(0);
  if ($15) {
   $16 = (($13) + 4|0);
   $17 = $16;
   $18 = HEAP32[$16>>2]|0;
   $19 = (($17) + ($18))|0;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + ($21))|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(-1);
   if ($25) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769584,0,769408,3070,1,0,0,0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $26 = (($13) + 16|0);
   $27 = $26;
   $28 = HEAP32[$26>>2]|0;
   $29 = (($28) + ($27))|0;
   $30 = $29;
   $31 = (($30) + ($24<<3)|0);
   $32 = $31;
   $33 = HEAP32[$31>>2]|0;
   $34 = (($32) + ($33))|0;
   $35 = $34;
   $36 = ((($30) + ($24<<3)|0) + 4|0);
   HEAP32[$36>>2] = $35;
   $37 = HEAP32[$35>>2]|0;
   $38 = ($37|0)==(0);
   if ($38) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $39 = (($this) + 84|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $40;
   $42 = HEAP32[$40>>2]|0;
   $43 = (($42) + ($41))|0;
   $44 = $43;
   $45 = (($40) + 4|0);
   HEAP32[$45>>2] = $44;
   $46 = (($44) + 4|0);
   $47 = $46;
   $48 = HEAP32[$46>>2]|0;
   $49 = (($47) + ($48))|0;
   $50 = $49;
   $51 = (($44) + 8|0);
   HEAP32[$51>>2] = $50;
   $52 = (($50) + ($24<<3)|0);
   $53 = $52;
   $54 = HEAP32[$52>>2]|0;
   $55 = (($53) + ($54))|0;
   $56 = $55;
   $57 = ((($50) + ($24<<3)|0) + 4|0);
   HEAP32[$57>>2] = $56;
   $58 = (($35) + 4|0);
   $59 = (($56) + 12|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = $58;
   $62 = HEAP32[$58>>2]|0;
   $63 = (($62) + ($61))|0;
   $64 = $63;
   $65 = (($64) + ($60<<3)|0);
   $66 = $65;
   $67 = HEAP32[$65>>2]|0;
   $68 = (($66) + ($67))|0;
   $69 = $68;
   $70 = ((($64) + ($60<<3)|0) + 4|0);
   HEAP32[$70>>2] = $69;
   $71 = (($this) + 296|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($69) + 52|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==($72|0);
   if ($75) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $76 = (($69) + 48|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==($72|0);
   if ($78) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $79 = (($69) + 44|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==($72|0);
   $$0 = $81;
   STACKTOP = sp;return ($$0|0);
  }
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769560,0,769408,3064,1,0,0,0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN8Animator9GotoStateEiifff($this,$layerIndex,$stateId,$normalizedTime,$transitionDuration,$transitionTime) {
 $this = $this|0;
 $layerIndex = $layerIndex|0;
 $stateId = $stateId|0;
 $normalizedTime = Math_fround($normalizedTime);
 $transitionDuration = Math_fround($transitionDuration);
 $transitionTime = Math_fround($transitionTime);
 var $$0 = Math_fround(0), $$0$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$02$i = 0, $i$02$i3 = 0, $info = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $info = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 136|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = ($layerIndex|0)==(-1);
 L4: do {
  if ($4) {
   $5 = ($stateId|0)==(0);
   if ($5) {
    $i$02$i3 = 0;
   } else {
    $6 = (($this) + 92|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)>(0);
    if ($9) {
     $10 = (($7) + 4|0);
     $11 = $10;
     $12 = (($7) + 16|0);
     $13 = $12;
     $109 = $8;$i$02$i = 0;
     while(1) {
      $14 = HEAP32[$10>>2]|0;
      $15 = (($14) + ($11))|0;
      $16 = $15;
      $17 = (($16) + ($i$02$i<<3)|0);
      $18 = $17;
      $19 = HEAP32[$17>>2]|0;
      $20 = (($18) + ($19))|0;
      $21 = $20;
      $22 = (($21) + 4|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ($23|0)==(0);
      if ($24) {
       $25 = HEAP32[$21>>2]|0;
       $26 = HEAP32[$12>>2]|0;
       $27 = (($26) + ($13))|0;
       $28 = $27;
       $29 = (($28) + ($25<<3)|0);
       $30 = $29;
       $31 = HEAP32[$29>>2]|0;
       $32 = (($30) + ($31))|0;
       $33 = $32;
       $34 = ((($28) + ($25<<3)|0) + 4|0);
       HEAP32[$34>>2] = $33;
       $35 = (__ZN7mecanim12statemachine13GetStateIndexEPKNS0_20StateMachineConstantEj($33,$stateId)|0);
       $36 = ($35|0)==(-1);
       if (!($36)) {
        $i$02$i3 = $i$02$i;
        break L4;
       }
       $$pre$i = HEAP32[$7>>2]|0;
       $39 = $$pre$i;
      } else {
       $39 = $109;
      }
      $37 = (($i$02$i) + 1)|0;
      $38 = ($37|0)<($39|0);
      if ($38) {
       $109 = $39;$i$02$i = $37;
      } else {
       break;
      }
     }
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769416,0,769408,2273,1,0,0,0);
    $i$02$i3 = -1;
   }
  } else {
   $i$02$i3 = $layerIndex;
  }
 } while(0);
 $40 = HEAP32[$this>>2]|0;
 $41 = (($40) + 136|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (FUNCTION_TABLE_ii[$42 & 4095]($this)|0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 $44 = ($i$02$i3|0)<(0);
 if (!($44)) {
  $45 = HEAP32[$this>>2]|0;
  $46 = (($45) + 136|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (FUNCTION_TABLE_ii[$47 & 4095]($this)|0);
  if ($48) {
   $49 = (($this) + 92|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = HEAP32[$50>>2]|0;
   $$0$i$i = $51;
  } else {
   $$0$i$i = 0;
  }
  $52 = ($$0$i$i|0)>($i$02$i3|0);
  if ($52) {
   $53 = (($this) + 92|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 4|0);
   $56 = $55;
   $57 = HEAP32[$55>>2]|0;
   $58 = (($56) + ($57))|0;
   $59 = $58;
   $60 = (($59) + ($i$02$i3<<3)|0);
   $61 = $60;
   $62 = HEAP32[$60>>2]|0;
   $63 = (($61) + ($62))|0;
   $64 = $63;
   $65 = HEAP32[$64>>2]|0;
   $66 = ($65|0)==(-1);
   if ($66) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769584,0,769408,3070,1,0,0,0);
    STACKTOP = sp;return;
   }
   $67 = (($54) + 12|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($65>>>0)<($68>>>0);
   if (!($69)) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769464,0,769408,2287,1,0,0,0);
    STACKTOP = sp;return;
   }
   $70 = (($64) + 4|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0);
   if (!($72)) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769512,0,769408,2294,1,0,0,0);
    STACKTOP = sp;return;
   }
   $73 = $normalizedTime == Math_fround(-inf);
   if ($73) {
    ;HEAP32[$info+0>>2]=0|0;HEAP32[$info+4>>2]=0|0;HEAP32[$info+8>>2]=0|0;HEAP32[$info+12>>2]=0|0;HEAP32[$info+16>>2]=0|0;HEAP32[$info+20>>2]=0|0;HEAP32[$info+24>>2]=0|0;
    (__ZNK8Animator20GetAnimatorStateInfoEiNS_14StateInfoIndexER17AnimatorStateInfo($this,$i$02$i3,0,$info)|0);
    $74 = (($info) + 8|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ($75|0)==($stateId|0);
    if ($76) {
     STACKTOP = sp;return;
    }
    $77 = (($info) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ($78|0)==($stateId|0);
    if ($79) {
     STACKTOP = sp;return;
    }
    $80 = HEAP32[$info>>2]|0;
    $81 = ($80|0)==($stateId|0);
    if ($81) {
     STACKTOP = sp;return;
    } else {
     $$0 = Math_fround(0.0);
    }
   } else {
    $$0 = $normalizedTime;
   }
   $82 = (($this) + 84|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = $83;
   $85 = HEAP32[$83>>2]|0;
   $86 = (($85) + ($84))|0;
   $87 = $86;
   $88 = (($83) + 4|0);
   HEAP32[$88>>2] = $87;
   $89 = (($87) + 4|0);
   $90 = $89;
   $91 = HEAP32[$89>>2]|0;
   $92 = (($90) + ($91))|0;
   $93 = $92;
   $94 = (($87) + 8|0);
   HEAP32[$94>>2] = $93;
   $95 = (($93) + ($65<<3)|0);
   $96 = $95;
   $97 = HEAP32[$95>>2]|0;
   $98 = (($96) + ($97))|0;
   $99 = $98;
   $100 = ((($93) + ($65<<3)|0) + 4|0);
   HEAP32[$100>>2] = $99;
   $101 = (($99) + 75|0);
   HEAP8[$101>>0] = 1;
   $102 = (($this) + 76|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = HEAP32[$103>>2]|0;
   $105 = (($104) + (($i$02$i3*20)|0)|0);
   HEAP32[$105>>2] = $stateId;
   $106 = ((($104) + (($i$02$i3*20)|0)|0) + 4|0);
   HEAPF32[$106>>2] = $$0;
   $107 = ((($104) + (($i$02$i3*20)|0)|0) + 8|0);
   HEAPF32[$107>>2] = $transitionDuration;
   $108 = ((($104) + (($i$02$i3*20)|0)|0) + 12|0);
   HEAPF32[$108>>2] = $transitionTime;
   STACKTOP = sp;return;
  }
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(769560,0,769408,3064,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZN4mathL8xformMulERKNS_5xformES2_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($a) + 32|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($b) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($a) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = (($b) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = (($b) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $17);
 $19 = Math_fround($3 + $3);
 $20 = Math_fround($8 + $8);
 $21 = Math_fround($13 + $13);
 $22 = (($a) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($20 * $23);
 $25 = (($a) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($21 * $26);
 $28 = (($a) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($19 * $29);
 $31 = (($a) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(0.0));
 $34 = Math_fround($19 * $26);
 $35 = Math_fround($20 * $29);
 $36 = Math_fround($21 * $23);
 $37 = Math_fround($24 - $34);
 $38 = Math_fround($27 - $35);
 $39 = Math_fround($30 - $36);
 $40 = Math_fround($33 - $33);
 $41 = Math_fround($32 * $38);
 $42 = Math_fround($32 * $39);
 $43 = Math_fround($37 * $32);
 $44 = Math_fround($32 * $40);
 $45 = Math_fround($3 + $41);
 $46 = Math_fround($8 + $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 * $39);
 $50 = Math_fround($26 * $37);
 $51 = Math_fround($29 * $38);
 $52 = Math_fround($26 * $38);
 $53 = Math_fround($29 * $39);
 $54 = Math_fround($23 * $37);
 $55 = Math_fround($49 - $52);
 $56 = Math_fround($50 - $53);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($44 - $44);
 $59 = Math_fround($45 + $56);
 $60 = Math_fround($46 + $57);
 $61 = Math_fround($47 + $55);
 $62 = Math_fround($48 + $58);
 $63 = Math_fround(HEAPF32[$a>>2]);
 $64 = Math_fround($63 + $59);
 $65 = (($a) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 + $60);
 $68 = (($a) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $61);
 $71 = (($a) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 + $62);
 $74 = (($b) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($26 * $75);
 $77 = (($b) + 28|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($32 * $78);
 $80 = (($b) + 20|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($29 * $81);
 $83 = (($b) + 24|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($23 * $84);
 $86 = Math_fround($32 * $84);
 $87 = Math_fround($75 * $23);
 $88 = Math_fround($26 * $84);
 $89 = Math_fround($75 * $29);
 $90 = Math_fround($76 - $86);
 $91 = Math_fround($79 - $87);
 $92 = Math_fround($82 - $88);
 $93 = Math_fround($85 - $89);
 $94 = Math_fround($78 * $29);
 $95 = Math_fround($29 * $84);
 $96 = Math_fround($75 * $32);
 $97 = Math_fround($32 * $81);
 $98 = Math_fround($90 - $94);
 $99 = Math_fround($91 - $95);
 $100 = Math_fround($92 - $96);
 $101 = Math_fround($93 - $97);
 $102 = Math_fround($81 * $23);
 $103 = Math_fround($26 * $81);
 $104 = Math_fround($78 * $23);
 $105 = Math_fround($26 * $78);
 $106 = Math_fround($98 - $102);
 $107 = Math_fround($99 - $103);
 $108 = Math_fround($100 - $104);
 $109 = Math_fround($101 - $105);
 $110 = Math_fround($108 * Math_fround(-1.0));
 $111 = Math_fround($109 * Math_fround(-1.0));
 $112 = Math_fround($106 * Math_fround(-1.0));
 $113 = Math_fround($110 * $110);
 $114 = Math_fround($111 * $111);
 $115 = Math_fround($112 * $112);
 $116 = Math_fround($107 * $107);
 $117 = Math_fround($113 + $114);
 $118 = Math_fround($116 + $115);
 $119 = Math_fround($117 + $118);
 $120 = (Math_fround(Math_sqrt((Math_fround($119)))));
 $121 = Math_fround(Math_fround(1.0) / $120);
 $122 = Math_fround($121 * $110);
 $123 = Math_fround($121 * $111);
 $124 = Math_fround($121 * $112);
 $125 = Math_fround($121 * $107);
 $126 = Math_fround(HEAPF32[$1>>2]);
 $127 = (($b) + 32|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($126 * $128);
 $130 = Math_fround(HEAPF32[$6>>2]);
 $131 = (($b) + 36|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($130 * $132);
 $134 = Math_fround(HEAPF32[$11>>2]);
 $135 = (($b) + 40|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($134 * $136);
 $138 = Math_fround(HEAPF32[$16>>2]);
 $139 = (($b) + 44|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($138 * $140);
 HEAPF32[$agg$result>>2] = $64;
 $142 = (($agg$result) + 4|0);
 HEAPF32[$142>>2] = $67;
 $143 = (($agg$result) + 8|0);
 HEAPF32[$143>>2] = $70;
 $144 = (($agg$result) + 12|0);
 HEAPF32[$144>>2] = $73;
 $145 = (($agg$result) + 16|0);
 HEAPF32[$145>>2] = $122;
 $146 = (($agg$result) + 20|0);
 HEAPF32[$146>>2] = $123;
 $147 = (($agg$result) + 24|0);
 HEAPF32[$147>>2] = $124;
 $148 = (($agg$result) + 28|0);
 HEAPF32[$148>>2] = $125;
 $149 = (($agg$result) + 32|0);
 HEAPF32[$149>>2] = $129;
 $150 = (($agg$result) + 36|0);
 HEAPF32[$150>>2] = $133;
 $151 = (($agg$result) + 40|0);
 HEAPF32[$151>>2] = $137;
 $152 = (($agg$result) + 44|0);
 HEAPF32[$152>>2] = $141;
 STACKTOP = sp;return;
}
function __ZNK8Animator25GetStateMachineBehavioursEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 372|0);
 STACKTOP = sp;return ($0|0);
}
function __ZThn32_NK8Animator25GetStateMachineBehavioursEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -32|0);
 $1 = (($0) + 372|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK8Animator41GetStateMachineBehaviourVectorDescriptionEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $pos$i$i$i$i = 0;
 var $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $3;
 $5 = HEAP32[560624>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 10;
 } else {
  $7 = (($5) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  do {
   if ($11) {
    $12 = (($5) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($5) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + ($15<<3)|0);
    $32 = $16;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$1);
    $17 = HEAP32[$pos$i$i$i$i>>2]|0;
    $18 = ($17|0)==(-1);
    $19 = (($5) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    if ($18) {
     $21 = (($5) + 32|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + ($22<<3)|0);
     $32 = $23;
     break;
    } else {
     $24 = (($20) + ($17<<3)|0);
     $32 = $24;
     break;
    }
   }
  } while(0);
  $25 = HEAP32[560624>>2]|0;
  $26 = (($25) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 32|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + ($29<<3)|0);
  $31 = ($32|0)==($30|0);
  if ($31) {
   label = 10;
  } else {
   $33 = (($32) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    label = 10;
   } else {
    $40 = $25;
   }
  }
 }
 do {
  if ((label|0) == 10) {
   $36 = HEAP32[$2>>2]|0;
   $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
   $phitmp$i = ($37|0)==(0|0);
   if ($phitmp$i) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$pre = HEAP32[560624>>2]|0;
    $40 = $$pre;
    break;
   }
  }
 } while(0);
 $38 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $38;
 $39 = ($40|0)==(0|0);
 if ($39) {
  label = 20;
 } else {
  $41 = (($40) + 36|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($42|0)==($44|0);
  do {
   if ($45) {
    $46 = (($40) + 28|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($40) + 32|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($47) + ($49<<3)|0);
    $66 = $50;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$40,$0);
    $51 = HEAP32[$pos$i$i$i$i>>2]|0;
    $52 = ($51|0)==(-1);
    $53 = (($40) + 28|0);
    $54 = HEAP32[$53>>2]|0;
    if ($52) {
     $55 = (($40) + 32|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = (($54) + ($56<<3)|0);
     $66 = $57;
     break;
    } else {
     $58 = (($54) + ($51<<3)|0);
     $66 = $58;
     break;
    }
   }
  } while(0);
  $59 = HEAP32[560624>>2]|0;
  $60 = (($59) + 28|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) + 32|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = (($61) + ($63<<3)|0);
  $65 = ($66|0)==($64|0);
  if ($65) {
   label = 20;
  } else {
   $67 = (($66) + 4|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(0|0);
   if ($69) {
    label = 20;
   } else {
    $temp$0$i = $68;
   }
  }
 }
 if ((label|0) == 20) {
  $70 = HEAP32[$2>>2]|0;
  $71 = (__Z31ReadObjectFromPersistentManageri($70)|0);
  $temp$0$i = $71;
 }
 $72 = HEAP32[$temp$0$i>>2]|0;
 $73 = (($72) + 112|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (FUNCTION_TABLE_ii[$74 & 4095]($temp$0$i)|0);
 $$0 = $75;
 STACKTOP = sp;return ($$0|0);
}
function __ZThn32_NK8Animator41GetStateMachineBehaviourVectorDescriptionEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -32|0);
 $1 = (__ZNK8Animator41GetStateMachineBehaviourVectorDescriptionEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK8Animator16GetObjectPointerEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZThn32_NK8Animator16GetObjectPointerEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + -32|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN8AnimatorD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN8AnimatorD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN8AnimatorD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3702,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN9BlobWrite8TransferIN7mecanim9animation12AvatarMemoryEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim9animation12AvatarMemory8TransferI8BlobSizeEEvRT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim9animation16ControllerMemoryEEEEvRT_PKc17TransferMetaFlags($this,$data,769632,0);
 $37 = (($data) + 8|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($this,$37,769656,0);
 $38 = (($data) + 56|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($this,$38,769672,0);
 $39 = (($data) + 104|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($this,$39,769688,0);
 $40 = (($data) + 152|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$40,769704,0);
 $41 = (($data) + 168|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$41,769712,0);
 $42 = (($data) + 172|0);
 __ZN9BlobWrite8TransferIhEEvRT_PKc17TransferMetaFlags($this,$42,769728,0);
 $43 = (($data) + 173|0);
 __ZN9BlobWrite8TransferIhEEvRT_PKc17TransferMetaFlags($this,$43,769744,0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $44 = HEAP32[$17>>2]|0;
 $45 = (($44) + -1)|0;
 HEAP32[$17>>2] = $45;
 $46 = (($this) + 32|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$23>>2]|0;
 $49 = ($47|0)==($48|0);
 if ($49) {
  $56 = 0;
 } else {
  $50 = $47;
  $51 = $48;
  $52 = (($50) - ($51))|0;
  $53 = $52 << 6;
  $54 = (($53) + -1)|0;
  $56 = $54;
 }
 $55 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($44))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($56))|0;
 $57 = (($$neg2$i$i$i) - ($55))|0;
 $58 = ($57>>>0)>(511);
 if (!($58)) {
  STACKTOP = sp;return;
 }
 $59 = (($47) + -4|0);
 $60 = HEAP32[$59>>2]|0;
 __ZdlPv($60);
 $61 = HEAP32[$46>>2]|0;
 $62 = (($61) + -4|0);
 $__new_last2$i$i$i$i$i = $62;
 $63 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($62) + ($63)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $64 = $uglygep3$i$i$i$i$i >>> 2;
 $65 = $64 ^ -1;
 $scevgep4$i$i$i$i$i = (($61) + ($65<<2)|0);
 HEAP32[$46>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim9animation16ControllerMemoryEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduce$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduce$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduce$i+0>>2]=0|0;HEAP32[$reduce$i+4>>2]=0|0;HEAP32[$reduce$i+8>>2]=0|0;
 $30 = HEAP32[$data>>2]|0;
 $31 = ($30|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$31,$reduce$i,4);
 $32 = HEAP32[$data>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = $data;
  $35 = (($32) + ($34))|0;
  $36 = $35;
  $37 = (($data) + 4|0);
  HEAP32[$37>>2] = $36;
  __ZN9BlobWrite8TransferIN7mecanim9animation16ControllerMemoryEEEvRT_PKc17TransferMetaFlags($this,$36,769776,0);
 }
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduce$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$10>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$10>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$16>>2]|0;
 $43 = ($41|0)==($42|0);
 if ($43) {
  $50 = 0;
 } else {
  $44 = $41;
  $45 = $42;
  $46 = (($44) - ($45))|0;
  $47 = $46 << 6;
  $48 = (($47) + -1)|0;
  $50 = $48;
 }
 $49 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($50))|0;
 $51 = (($$neg2$i$i$i) - ($49))|0;
 $52 = ($51>>>0)>(511);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = (($41) + -4|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 $55 = HEAP32[$40>>2]|0;
 $56 = (($55) + -4|0);
 $__new_last2$i$i$i$i$i = $56;
 $57 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($56) + ($57)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $58 = $uglygep3$i$i$i$i$i >>> 2;
 $59 = $58 ^ -1;
 $scevgep4$i$i$i$i$i = (($55) + ($59<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIhEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  __ZN9BlobWrite4PushEjPKvj($this,1,$data,1);
 }
 $4 = (($this) + 44|0);
 $5 = (($this) + 40|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$4>>2]|0;
 $9 = HEAP32[$5>>2]|0;
 $10 = (($8) + -1)|0;
 $11 = (($10) + ($9))|0;
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11 >>> 8;
 $15 = (($13) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $11 & 255;
 $18 = (($16) + ($17<<4)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($16) + ($17<<4)|0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19))|0;
 $23 = HEAP32[$7>>2]|0;
 $24 = (($23) + ($22)|0);
 $25 = HEAP8[$data>>0]|0;
 HEAP8[$24>>0] = $25;
 $26 = HEAP32[$4>>2]|0;
 $27 = HEAP32[$5>>2]|0;
 $28 = (($26) + -1)|0;
 $29 = (($28) + ($27))|0;
 $30 = HEAP32[$12>>2]|0;
 $31 = $29 >>> 8;
 $32 = (($30) + ($31<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $29 & 255;
 $35 = ((($33) + ($34<<4)|0) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$35>>2] = $37;
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$4>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$4>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)==($30|0);
 if ($42) {
  $49 = 0;
 } else {
  $43 = $41;
  $44 = $30;
  $45 = (($43) - ($44))|0;
  $46 = $45 << 6;
  $47 = (($46) + -1)|0;
  $49 = $47;
 }
 $48 = HEAP32[$5>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($49))|0;
 $50 = (($$neg2$i$i$i) - ($48))|0;
 $51 = ($50>>>0)>(511);
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (($41) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 __ZdlPv($53);
 $54 = HEAP32[$40>>2]|0;
 $55 = (($54) + -4|0);
 $__new_last2$i$i$i$i$i = $55;
 $56 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($55) + ($56)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $57 = $uglygep3$i$i$i$i$i >>> 2;
 $58 = $57 ^ -1;
 $scevgep4$i$i$i$i$i = (($54) + ($58<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim9animation16ControllerMemoryEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim9animation16ControllerMemory8TransferI8BlobSizeEEvRT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN7mecanim9animation16ControllerMemory8TransferI9BlobWriteEEvRT_($data,$this);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + -1)|0;
 HEAP32[$17>>2] = $38;
 $39 = (($this) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$23>>2]|0;
 $42 = ($40|0)==($41|0);
 if ($42) {
  $49 = 0;
 } else {
  $43 = $40;
  $44 = $41;
  $45 = (($43) - ($44))|0;
  $46 = $45 << 6;
  $47 = (($46) + -1)|0;
  $49 = $47;
 }
 $48 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($37))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($49))|0;
 $50 = (($$neg2$i$i$i) - ($48))|0;
 $51 = ($50>>>0)>(511);
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (($40) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 __ZdlPv($53);
 $54 = HEAP32[$39>>2]|0;
 $55 = (($54) + -4|0);
 $__new_last2$i$i$i$i$i = $55;
 $56 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($55) + ($56)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $57 = $uglygep3$i$i$i$i$i >>> 2;
 $58 = $57 ^ -1;
 $scevgep4$i$i$i$i$i = (($54) + ($58<<2)|0);
 HEAP32[$39>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation16ControllerMemory8TransferI9BlobWriteEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ArrayTransfer$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i3 = sp;
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,769784,0);
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $0;
 $3 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18StateMachineMemoryEEEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i3,769808,0);
 $5 = (($this) + 12|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$5,769832,0);
 $6 = (($this) + 16|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $6;
 $8 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$8>>2] = $5;
 $9 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIN7mecanim9animation13BlendingStateILb0EEEEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i3,769848,0);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $10;
 $12 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$12>>2] = $5;
 $13 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$13>>2] = $11;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIN7mecanim9animation13BlendingStateILb0EEEEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i3,769896,0);
 $14 = (($this) + 32|0);
 $15 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $14;
 $16 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$16>>2] = $5;
 $17 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$17>>2] = $15;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIfEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i3,769920,0);
 $18 = (($this) + 40|0);
 __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim10ValueArrayEEEEvRT_PKc17TransferMetaFlags($transfer,$18,769936,0);
 $19 = (($this) + 48|0);
 __ZN9BlobWrite8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$19,769728,0);
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim10ValueArrayEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduce$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduce$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduce$i+0>>2]=0|0;HEAP32[$reduce$i+4>>2]=0|0;HEAP32[$reduce$i+8>>2]=0|0;
 $30 = HEAP32[$data>>2]|0;
 $31 = ($30|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$31,$reduce$i,4);
 $32 = HEAP32[$data>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = $data;
  $35 = (($32) + ($34))|0;
  $36 = $35;
  $37 = (($data) + 4|0);
  HEAP32[$37>>2] = $36;
  __ZN9BlobWrite8TransferIN7mecanim10ValueArrayEEEvRT_PKc17TransferMetaFlags($this,$36,769776,0);
 }
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduce$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$10>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$10>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$16>>2]|0;
 $43 = ($41|0)==($42|0);
 if ($43) {
  $50 = 0;
 } else {
  $44 = $41;
  $45 = $42;
  $46 = (($44) - ($45))|0;
  $47 = $46 << 6;
  $48 = (($47) + -1)|0;
  $50 = $48;
 }
 $49 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($50))|0;
 $51 = (($$neg2$i$i$i) - ($49))|0;
 $52 = ($51>>>0)>(511);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = (($41) + -4|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 $55 = HEAP32[$40>>2]|0;
 $56 = (($55) + -4|0);
 $__new_last2$i$i$i$i$i = $56;
 $57 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($56) + ($57)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $58 = $uglygep3$i$i$i$i$i >>> 2;
 $59 = $58 ^ -1;
 $scevgep4$i$i$i$i$i = (($55) + ($59<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim10ValueArrayEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim10ValueArray8TransferI8BlobSizeEEvRT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN7mecanim10ValueArray8TransferI9BlobWriteEEvRT_($data,$this);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + -1)|0;
 HEAP32[$17>>2] = $38;
 $39 = (($this) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$23>>2]|0;
 $42 = ($40|0)==($41|0);
 if ($42) {
  $49 = 0;
 } else {
  $43 = $40;
  $44 = $41;
  $45 = (($43) - ($44))|0;
  $46 = $45 << 6;
  $47 = (($46) + -1)|0;
  $49 = $47;
 }
 $48 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($37))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($49))|0;
 $50 = (($$neg2$i$i$i) - ($48))|0;
 $51 = ($50>>>0)>(511);
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (($40) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 __ZdlPv($53);
 $54 = HEAP32[$39>>2]|0;
 $55 = (($54) + -4|0);
 $__new_last2$i$i$i$i$i = $55;
 $56 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($55) + ($56)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $57 = $uglygep3$i$i$i$i$i >>> 2;
 $58 = $57 ^ -1;
 $scevgep4$i$i$i$i$i = (($54) + ($58<<2)|0);
 HEAP32[$39>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim10ValueArray8TransferI9BlobWriteEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i5 = sp;
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,769952,0);
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $0;
 $3 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIbEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,769968,0);
 $5 = (($this) + 12|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$5,769984,0);
 $6 = (($this) + 16|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $6;
 $8 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$8>>2] = $5;
 $9 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIiEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770000,0);
 $10 = (($this) + 24|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$10,770016,0);
 $11 = (($this) + 28|0);
 $12 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $11;
 $13 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$13>>2] = $10;
 $14 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$14>>2] = $12;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIfEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770032,0);
 $15 = (($this) + 36|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$15,770048,0);
 $16 = (($this) + 40|0);
 $17 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $16;
 $18 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$18>>2] = $15;
 $19 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$19>>2] = $17;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770064,0);
 $20 = (($this) + 48|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$20,770088,0);
 $21 = (($this) + 52|0);
 $22 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $21;
 $23 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$23>>2] = $20;
 $24 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$24>>2] = $22;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770112,0);
 $25 = (($this) + 60|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$25,770136,0);
 $26 = (($this) + 64|0);
 $27 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $26;
 $28 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$28>>2] = $25;
 $29 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$29>>2] = $27;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770152,0);
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduceCopy$i = 0;
 var $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduceCopy$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduceCopy$i+0>>2]=0|0;HEAP32[$reduceCopy$i+4>>2]=0|0;HEAP32[$reduceCopy$i+8>>2]=0|0;
 $30 = (($data) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$33,$reduceCopy$i,4);
 __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIKN4math7_float4EEEclERS4_17TransferMetaFlagsR9BlobWrite(0,$data,0,$this);
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduceCopy$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$10>>2]|0;
 $35 = (($34) + -1)|0;
 HEAP32[$10>>2] = $35;
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$16>>2]|0;
 $39 = ($37|0)==($38|0);
 if ($39) {
  $46 = 0;
 } else {
  $40 = $37;
  $41 = $38;
  $42 = (($40) - ($41))|0;
  $43 = $42 << 6;
  $44 = (($43) + -1)|0;
  $46 = $44;
 }
 $45 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($34))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($46))|0;
 $47 = (($$neg2$i$i$i) - ($45))|0;
 $48 = ($47>>>0)>(511);
 if (!($48)) {
  STACKTOP = sp;return;
 }
 $49 = (($37) + -4|0);
 $50 = HEAP32[$49>>2]|0;
 __ZdlPv($50);
 $51 = HEAP32[$36>>2]|0;
 $52 = (($51) + -4|0);
 $__new_last2$i$i$i$i$i = $52;
 $53 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($52) + ($53)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $54 = $uglygep3$i$i$i$i$i >>> 2;
 $55 = $54 ^ -1;
 $scevgep4$i$i$i$i$i = (($51) + ($55<<2)|0);
 HEAP32[$36>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIKN4math7_float4EEEclERS4_17TransferMetaFlagsR9BlobWrite($this,$data,$metaFlags,$transfer) {
 $this = $this|0;
 $data = $data|0;
 $metaFlags = $metaFlags|0;
 $transfer = $transfer|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$02 = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$data>>2]|0;
 $5 = $4;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($4) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$0>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 << 4;
 $13 = HEAP32[$data>>2]|0;
 $14 = $13;
 $15 = HEAP32[$13>>2]|0;
 $16 = (($15) + ($14))|0;
 $17 = $16;
 $18 = (($13) + 4|0);
 HEAP32[$18>>2] = $17;
 $19 = $16;
 __ZN9BlobWrite4PushEjPKvj($transfer,$12,$19,4);
 $20 = HEAP32[$data>>2]|0;
 $21 = $20;
 $22 = HEAP32[$20>>2]|0;
 $23 = (($22) + ($21))|0;
 $24 = $23;
 $25 = (($20) + 4|0);
 HEAP32[$25>>2] = $24;
 $26 = HEAP32[$0>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($24) + ($27<<4)|0);
 $29 = HEAP32[$data>>2]|0;
 $30 = $29;
 $31 = HEAP32[$29>>2]|0;
 $32 = (($31) + ($30))|0;
 $33 = $32;
 $34 = (($29) + 4|0);
 HEAP32[$34>>2] = $33;
 $35 = ($33|0)==($28|0);
 if (!($35)) {
  $i$02 = $33;
  while(1) {
   __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$i$02,769776,0);
   $36 = (($i$02) + 16|0);
   $37 = ($36|0)==($28|0);
   if ($37) {
    break;
   } else {
    $i$02 = $36;
   }
  }
 }
 $38 = (($transfer) + 44|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($transfer) + 40|0);
 $41 = (($39) + -1)|0;
 HEAP32[$38>>2] = $41;
 $42 = (($transfer) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($transfer) + 28|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($43|0)==($45|0);
 if ($46) {
  $53 = 0;
 } else {
  $47 = $43;
  $48 = $45;
  $49 = (($47) - ($48))|0;
  $50 = $49 << 6;
  $51 = (($50) + -1)|0;
  $53 = $51;
 }
 $52 = HEAP32[$40>>2]|0;
 $$neg1$i = (1 - ($39))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($53))|0;
 $54 = (($$neg2$i$i$i) - ($52))|0;
 $55 = ($54>>>0)>(511);
 if (!($55)) {
  STACKTOP = sp;return;
 }
 $56 = (($43) + -4|0);
 $57 = HEAP32[$56>>2]|0;
 __ZdlPv($57);
 $58 = HEAP32[$42>>2]|0;
 $59 = (($58) + -4|0);
 $__new_last2$i$i$i$i$i = $59;
 $60 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($59) + ($60)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $61 = $uglygep3$i$i$i$i$i >>> 2;
 $62 = $61 ^ -1;
 $scevgep4$i$i$i$i$i = (($58) + ($62<<2)|0);
 HEAP32[$42>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIbEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduceCopy$i = 0;
 var $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduceCopy$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduceCopy$i+0>>2]=0|0;HEAP32[$reduceCopy$i+4>>2]=0|0;HEAP32[$reduceCopy$i+8>>2]=0|0;
 $30 = (($data) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$33,$reduceCopy$i,1);
 __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIbEEclERS1_17TransferMetaFlagsR9BlobWrite(0,$data,0,$this);
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduceCopy$i,1);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$10>>2]|0;
 $35 = (($34) + -1)|0;
 HEAP32[$10>>2] = $35;
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$16>>2]|0;
 $39 = ($37|0)==($38|0);
 if ($39) {
  $46 = 0;
 } else {
  $40 = $37;
  $41 = $38;
  $42 = (($40) - ($41))|0;
  $43 = $42 << 6;
  $44 = (($43) + -1)|0;
  $46 = $44;
 }
 $45 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($34))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($46))|0;
 $47 = (($$neg2$i$i$i) - ($45))|0;
 $48 = ($47>>>0)>(511);
 if (!($48)) {
  STACKTOP = sp;return;
 }
 $49 = (($37) + -4|0);
 $50 = HEAP32[$49>>2]|0;
 __ZdlPv($50);
 $51 = HEAP32[$36>>2]|0;
 $52 = (($51) + -4|0);
 $__new_last2$i$i$i$i$i = $52;
 $53 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($52) + ($53)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $54 = $uglygep3$i$i$i$i$i >>> 2;
 $55 = $54 ^ -1;
 $scevgep4$i$i$i$i$i = (($51) + ($55<<2)|0);
 HEAP32[$36>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIbEEclERS1_17TransferMetaFlagsR9BlobWrite($this,$data,$metaFlags,$transfer) {
 $this = $this|0;
 $data = $data|0;
 $metaFlags = $metaFlags|0;
 $transfer = $transfer|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$02 = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$data>>2]|0;
 $5 = $4;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($4) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$0>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$data>>2]|0;
 $13 = $12;
 $14 = HEAP32[$12>>2]|0;
 $15 = (($14) + ($13))|0;
 $16 = $15;
 $17 = (($12) + 4|0);
 HEAP32[$17>>2] = $16;
 __ZN9BlobWrite4PushEjPKvj($transfer,$11,$16,1);
 $18 = HEAP32[$data>>2]|0;
 $19 = $18;
 $20 = HEAP32[$18>>2]|0;
 $21 = (($20) + ($19))|0;
 $22 = $21;
 $23 = (($18) + 4|0);
 HEAP32[$23>>2] = $22;
 $24 = HEAP32[$0>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($22) + ($25)|0);
 $27 = HEAP32[$data>>2]|0;
 $28 = $27;
 $29 = HEAP32[$27>>2]|0;
 $30 = (($29) + ($28))|0;
 $31 = $30;
 $32 = (($27) + 4|0);
 HEAP32[$32>>2] = $31;
 $33 = ($31|0)==($26|0);
 if (!($33)) {
  $i$02 = $31;
  while(1) {
   __ZN9BlobWrite8TransferIbEEvRT_PKc17TransferMetaFlags($transfer,$i$02,769776,0);
   $34 = (($i$02) + 1|0);
   $35 = ($34|0)==($26|0);
   if ($35) {
    break;
   } else {
    $i$02 = $34;
   }
  }
 }
 $36 = (($transfer) + 44|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($transfer) + 40|0);
 $39 = (($37) + -1)|0;
 HEAP32[$36>>2] = $39;
 $40 = (($transfer) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($transfer) + 28|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($41|0)==($43|0);
 if ($44) {
  $51 = 0;
 } else {
  $45 = $41;
  $46 = $43;
  $47 = (($45) - ($46))|0;
  $48 = $47 << 6;
  $49 = (($48) + -1)|0;
  $51 = $49;
 }
 $50 = HEAP32[$38>>2]|0;
 $$neg1$i = (1 - ($37))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($51))|0;
 $52 = (($$neg2$i$i$i) - ($50))|0;
 $53 = ($52>>>0)>(511);
 if (!($53)) {
  STACKTOP = sp;return;
 }
 $54 = (($41) + -4|0);
 $55 = HEAP32[$54>>2]|0;
 __ZdlPv($55);
 $56 = HEAP32[$40>>2]|0;
 $57 = (($56) + -4|0);
 $__new_last2$i$i$i$i$i = $57;
 $58 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($57) + ($58)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $59 = $uglygep3$i$i$i$i$i >>> 2;
 $60 = $59 ^ -1;
 $scevgep4$i$i$i$i$i = (($56) + ($60<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim10ValueArray8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$ = 0, $$49 = 0, $$50 = 0, $$phi$trans$insert = 0, $$phi$trans$insert25 = 0, $$phi$trans$insert27 = 0, $$phi$trans$insert29 = 0, $$phi$trans$insert31 = 0, $$phi$trans$insert33 = 0, $$phi$trans$insert35 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert39 = 0, $$phi$trans$insert41 = 0, $$phi$trans$insert43 = 0, $$pre = 0, $$pre26 = 0, $$pre28 = 0, $$pre30 = 0, $$pre32 = 0, $$pre34 = 0;
 var $$pre36 = 0, $$pre38 = 0, $$pre40 = 0, $$pre42 = 0, $$pre44 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  $8 = (($7) + 4)|0;
  $9 = (0 - ($7))|0;
  $10 = $9 & 3;
  $11 = (($8) + ($10))|0;
  HEAP32[$3>>2] = $11;
  $14 = $11;
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $14 = $$pre;
 }
 $12 = (($transfer) + 12|0);
 $13 = (0 - ($14))|0;
 $15 = $13 & 3;
 $16 = (($15) + ($14))|0;
 $17 = (($transfer) + 18|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)!=(0);
 $20 = $19 ? 8 : 4;
 $21 = (($16) + ($20))|0;
 HEAP32[$12>>2] = $21;
 $22 = (($transfer) + 17|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $27 = $21;
 } else {
  $25 = (($21) + 4)|0;
  HEAP32[$12>>2] = $25;
  $27 = $25;
 }
 HEAP8[$0>>0] = 0;
 $26 = (0 - ($27))|0;
 $28 = $26 & 3;
 $29 = (($28) + ($27))|0;
 $30 = (($transfer) + 12|0);
 $31 = (0 - ($29))|0;
 $32 = $31 & 3;
 $33 = (($32) + ($29))|0;
 $34 = (($33) + 4)|0;
 $35 = (0 - ($33))|0;
 $36 = $35 & 3;
 $37 = (($34) + ($36))|0;
 HEAP32[$30>>2] = $37;
 $$phi$trans$insert25 = (($transfer) + 18|0);
 $$pre26 = HEAP8[$$phi$trans$insert25>>0]|0;
 $$phi$trans$insert27 = (($transfer) + 17|0);
 $$pre28 = HEAP8[$$phi$trans$insert27>>0]|0;
 $38 = (0 - ($37))|0;
 $39 = $38 & 3;
 $40 = (($39) + ($37))|0;
 $41 = ($$pre26<<24>>24)!=(0);
 $42 = $41 ? 8 : 4;
 $43 = (($40) + ($42))|0;
 $44 = ($$pre28<<24>>24)==(0);
 $45 = (($43) + 4)|0;
 $$ = $44 ? $43 : $45;
 HEAP8[$0>>0] = 0;
 $46 = (0 - ($$))|0;
 $47 = $46 & 3;
 $48 = (($47) + ($$))|0;
 $49 = (($transfer) + 12|0);
 $50 = (0 - ($48))|0;
 $51 = $50 & 3;
 $52 = (($51) + ($48))|0;
 $53 = (($52) + 4)|0;
 $54 = (0 - ($52))|0;
 $55 = $54 & 3;
 $56 = (($53) + ($55))|0;
 HEAP32[$49>>2] = $56;
 $$phi$trans$insert29 = (($transfer) + 18|0);
 $$pre30 = HEAP8[$$phi$trans$insert29>>0]|0;
 $$phi$trans$insert31 = (($transfer) + 17|0);
 $$pre32 = HEAP8[$$phi$trans$insert31>>0]|0;
 $57 = (0 - ($56))|0;
 $58 = $57 & 3;
 $59 = (($58) + ($56))|0;
 $60 = ($$pre30<<24>>24)!=(0);
 $61 = $60 ? 8 : 4;
 $62 = (($59) + ($61))|0;
 $63 = ($$pre32<<24>>24)==(0);
 $64 = (($62) + 4)|0;
 $65 = $63 ? $62 : $64;
 HEAP8[$0>>0] = 0;
 $66 = (0 - ($65))|0;
 $67 = $66 & 3;
 $68 = (($67) + ($65))|0;
 $69 = (($transfer) + 12|0);
 $70 = (0 - ($68))|0;
 $71 = $70 & 3;
 $72 = (($71) + ($68))|0;
 $73 = (($72) + 4)|0;
 $74 = (0 - ($72))|0;
 $75 = $74 & 3;
 $76 = (($73) + ($75))|0;
 HEAP32[$69>>2] = $76;
 $$phi$trans$insert33 = (($transfer) + 18|0);
 $$pre34 = HEAP8[$$phi$trans$insert33>>0]|0;
 $$phi$trans$insert35 = (($transfer) + 17|0);
 $$pre36 = HEAP8[$$phi$trans$insert35>>0]|0;
 $77 = (0 - ($76))|0;
 $78 = $77 & 3;
 $79 = (($78) + ($76))|0;
 $80 = ($$pre34<<24>>24)!=(0);
 $81 = $80 ? 8 : 4;
 $82 = (($79) + ($81))|0;
 $83 = ($$pre36<<24>>24)==(0);
 $84 = (($82) + 4)|0;
 $$49 = $83 ? $82 : $84;
 HEAP8[$0>>0] = 0;
 $85 = (0 - ($$49))|0;
 $86 = $85 & 3;
 $87 = (($86) + ($$49))|0;
 $88 = (($transfer) + 12|0);
 $89 = (0 - ($87))|0;
 $90 = $89 & 3;
 $91 = (($90) + ($87))|0;
 $92 = (($91) + 4)|0;
 $93 = (0 - ($91))|0;
 $94 = $93 & 3;
 $95 = (($92) + ($94))|0;
 HEAP32[$88>>2] = $95;
 $$phi$trans$insert37 = (($transfer) + 18|0);
 $$pre38 = HEAP8[$$phi$trans$insert37>>0]|0;
 $$phi$trans$insert39 = (($transfer) + 17|0);
 $$pre40 = HEAP8[$$phi$trans$insert39>>0]|0;
 $96 = (0 - ($95))|0;
 $97 = $96 & 3;
 $98 = (($97) + ($95))|0;
 $99 = ($$pre38<<24>>24)!=(0);
 $100 = $99 ? 8 : 4;
 $101 = (($98) + ($100))|0;
 $102 = ($$pre40<<24>>24)==(0);
 $103 = (($101) + 4)|0;
 $104 = $102 ? $101 : $103;
 HEAP8[$0>>0] = 0;
 $105 = (0 - ($104))|0;
 $106 = $105 & 3;
 $107 = (($106) + ($104))|0;
 $108 = (($transfer) + 12|0);
 $109 = (0 - ($107))|0;
 $110 = $109 & 3;
 $111 = (($110) + ($107))|0;
 $112 = (($111) + 4)|0;
 $113 = (0 - ($111))|0;
 $114 = $113 & 3;
 $115 = (($112) + ($114))|0;
 HEAP32[$108>>2] = $115;
 $$phi$trans$insert41 = (($transfer) + 18|0);
 $$pre42 = HEAP8[$$phi$trans$insert41>>0]|0;
 $$phi$trans$insert43 = (($transfer) + 17|0);
 $$pre44 = HEAP8[$$phi$trans$insert43>>0]|0;
 $116 = (($transfer) + 12|0);
 $117 = (0 - ($115))|0;
 $118 = $117 & 3;
 $119 = (($118) + ($115))|0;
 $120 = ($$pre42<<24>>24)!=(0);
 $121 = $120 ? 8 : 4;
 $122 = (($119) + ($121))|0;
 $123 = ($$pre44<<24>>24)==(0);
 $124 = (($122) + 4)|0;
 $$50 = $123 ? $122 : $124;
 HEAP8[$0>>0] = 0;
 $125 = (0 - ($$50))|0;
 $126 = $125 & 3;
 $127 = (($126) + ($$50))|0;
 HEAP32[$116>>2] = $127;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIfEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduceCopy$i = 0;
 var $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduceCopy$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduceCopy$i+0>>2]=0|0;HEAP32[$reduceCopy$i+4>>2]=0|0;HEAP32[$reduceCopy$i+8>>2]=0|0;
 $30 = (($data) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$33,$reduceCopy$i,4);
 __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIfEEclERS1_17TransferMetaFlagsR9BlobWrite(0,$data,0,$this);
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduceCopy$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$10>>2]|0;
 $35 = (($34) + -1)|0;
 HEAP32[$10>>2] = $35;
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$16>>2]|0;
 $39 = ($37|0)==($38|0);
 if ($39) {
  $46 = 0;
 } else {
  $40 = $37;
  $41 = $38;
  $42 = (($40) - ($41))|0;
  $43 = $42 << 6;
  $44 = (($43) + -1)|0;
  $46 = $44;
 }
 $45 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($34))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($46))|0;
 $47 = (($$neg2$i$i$i) - ($45))|0;
 $48 = ($47>>>0)>(511);
 if (!($48)) {
  STACKTOP = sp;return;
 }
 $49 = (($37) + -4|0);
 $50 = HEAP32[$49>>2]|0;
 __ZdlPv($50);
 $51 = HEAP32[$36>>2]|0;
 $52 = (($51) + -4|0);
 $__new_last2$i$i$i$i$i = $52;
 $53 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($52) + ($53)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $54 = $uglygep3$i$i$i$i$i >>> 2;
 $55 = $54 ^ -1;
 $scevgep4$i$i$i$i$i = (($51) + ($55<<2)|0);
 HEAP32[$36>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIfEEclERS1_17TransferMetaFlagsR9BlobWrite($this,$data,$metaFlags,$transfer) {
 $this = $this|0;
 $data = $data|0;
 $metaFlags = $metaFlags|0;
 $transfer = $transfer|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$02 = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$data>>2]|0;
 $5 = $4;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($4) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$0>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 << 2;
 $13 = HEAP32[$data>>2]|0;
 $14 = $13;
 $15 = HEAP32[$13>>2]|0;
 $16 = (($15) + ($14))|0;
 $17 = $16;
 $18 = (($13) + 4|0);
 HEAP32[$18>>2] = $17;
 $19 = $16;
 __ZN9BlobWrite4PushEjPKvj($transfer,$12,$19,4);
 $20 = HEAP32[$data>>2]|0;
 $21 = $20;
 $22 = HEAP32[$20>>2]|0;
 $23 = (($22) + ($21))|0;
 $24 = $23;
 $25 = (($20) + 4|0);
 HEAP32[$25>>2] = $24;
 $26 = HEAP32[$0>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($24) + ($27<<2)|0);
 $29 = HEAP32[$data>>2]|0;
 $30 = $29;
 $31 = HEAP32[$29>>2]|0;
 $32 = (($31) + ($30))|0;
 $33 = $32;
 $34 = (($29) + 4|0);
 HEAP32[$34>>2] = $33;
 $35 = ($33|0)==($28|0);
 if (!($35)) {
  $i$02 = $33;
  while(1) {
   __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$i$02,769776,0);
   $36 = (($i$02) + 4|0);
   $37 = ($36|0)==($28|0);
   if ($37) {
    break;
   } else {
    $i$02 = $36;
   }
  }
 }
 $38 = (($transfer) + 44|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($transfer) + 40|0);
 $41 = (($39) + -1)|0;
 HEAP32[$38>>2] = $41;
 $42 = (($transfer) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($transfer) + 28|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($43|0)==($45|0);
 if ($46) {
  $53 = 0;
 } else {
  $47 = $43;
  $48 = $45;
  $49 = (($47) - ($48))|0;
  $50 = $49 << 6;
  $51 = (($50) + -1)|0;
  $53 = $51;
 }
 $52 = HEAP32[$40>>2]|0;
 $$neg1$i = (1 - ($39))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($53))|0;
 $54 = (($$neg2$i$i$i) - ($52))|0;
 $55 = ($54>>>0)>(511);
 if (!($55)) {
  STACKTOP = sp;return;
 }
 $56 = (($43) + -4|0);
 $57 = HEAP32[$56>>2]|0;
 __ZdlPv($57);
 $58 = HEAP32[$42>>2]|0;
 $59 = (($58) + -4|0);
 $__new_last2$i$i$i$i$i = $59;
 $60 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($59) + ($60)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $61 = $uglygep3$i$i$i$i$i >>> 2;
 $62 = $61 ^ -1;
 $scevgep4$i$i$i$i$i = (($58) + ($62<<2)|0);
 HEAP32[$42>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIN7mecanim9animation13BlendingStateILb0EEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduceCopy$i = 0;
 var $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduceCopy$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduceCopy$i+0>>2]=0|0;HEAP32[$reduceCopy$i+4>>2]=0|0;HEAP32[$reduceCopy$i+8>>2]=0|0;
 $30 = (($data) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$33,$reduceCopy$i,4);
 __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIN7mecanim9animation13BlendingStateILb0EEEEEclERS5_17TransferMetaFlagsR9BlobWrite(0,$data,0,$this);
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduceCopy$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$10>>2]|0;
 $35 = (($34) + -1)|0;
 HEAP32[$10>>2] = $35;
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$16>>2]|0;
 $39 = ($37|0)==($38|0);
 if ($39) {
  $46 = 0;
 } else {
  $40 = $37;
  $41 = $38;
  $42 = (($40) - ($41))|0;
  $43 = $42 << 6;
  $44 = (($43) + -1)|0;
  $46 = $44;
 }
 $45 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($34))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($46))|0;
 $47 = (($$neg2$i$i$i) - ($45))|0;
 $48 = ($47>>>0)>(511);
 if (!($48)) {
  STACKTOP = sp;return;
 }
 $49 = (($37) + -4|0);
 $50 = HEAP32[$49>>2]|0;
 __ZdlPv($50);
 $51 = HEAP32[$36>>2]|0;
 $52 = (($51) + -4|0);
 $__new_last2$i$i$i$i$i = $52;
 $53 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($52) + ($53)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $54 = $uglygep3$i$i$i$i$i >>> 2;
 $55 = $54 ^ -1;
 $scevgep4$i$i$i$i$i = (($51) + ($55<<2)|0);
 HEAP32[$36>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferIN7mecanim9animation13BlendingStateILb0EEEEEclERS5_17TransferMetaFlagsR9BlobWrite($this,$data,$metaFlags,$transfer) {
 $this = $this|0;
 $data = $data|0;
 $metaFlags = $metaFlags|0;
 $transfer = $transfer|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$02 = 0;
 var $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$data>>2]|0;
 $5 = $4;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($4) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($transfer)|0);
 $11 = (($transfer) + 22|0);
 $12 = HEAP8[$11>>0]|0;
 HEAP32[$sizer$i>>2] = 0;
 $13 = (($sizer$i) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($sizer$i) + 12|0);
 $15 = (($sizer$i) + 16|0);
 HEAP8[$15>>0] = 0;
 $16 = (($sizer$i) + 17|0);
 $17 = $10&1;
 HEAP8[$16>>0] = $17;
 $18 = (($sizer$i) + 18|0);
 HEAP8[$18>>0] = $12;
 HEAP32[$14>>2] = 0;
 __ZN15SerializeTraitsIN7mecanim9animation13BlendingStateILb0EEEE8TransferI8BlobSizeEEvRS3_RT_($8,$sizer$i);
 $19 = HEAP32[$14>>2]|0;
 $20 = (0 - ($19))|0;
 $21 = $20 & 3;
 $22 = (($21) + ($19))|0;
 $23 = HEAP32[$0>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = Math_imul($24, $22)|0;
 $26 = HEAP32[$data>>2]|0;
 $27 = $26;
 $28 = HEAP32[$26>>2]|0;
 $29 = (($28) + ($27))|0;
 $30 = $29;
 $31 = (($26) + 4|0);
 HEAP32[$31>>2] = $30;
 $32 = $29;
 __ZN9BlobWrite4PushEjPKvj($transfer,$25,$32,4);
 $33 = HEAP32[$data>>2]|0;
 $34 = $33;
 $35 = HEAP32[$33>>2]|0;
 $36 = (($35) + ($34))|0;
 $37 = $36;
 $38 = (($33) + 4|0);
 HEAP32[$38>>2] = $37;
 $39 = HEAP32[$0>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($37) + (($40*36)|0)|0);
 $42 = HEAP32[$data>>2]|0;
 $43 = $42;
 $44 = HEAP32[$42>>2]|0;
 $45 = (($44) + ($43))|0;
 $46 = $45;
 $47 = (($42) + 4|0);
 HEAP32[$47>>2] = $46;
 $48 = ($46|0)==($41|0);
 if (!($48)) {
  $i$02 = $46;
  while(1) {
   __ZN9BlobWrite8TransferIN7mecanim9animation13BlendingStateILb0EEEEEvRT_PKc17TransferMetaFlags($transfer,$i$02,769776,0);
   $49 = (($i$02) + 36|0);
   $50 = ($49|0)==($41|0);
   if ($50) {
    break;
   } else {
    $i$02 = $49;
   }
  }
 }
 $51 = (($transfer) + 44|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($transfer) + 40|0);
 $54 = (($52) + -1)|0;
 HEAP32[$51>>2] = $54;
 $55 = (($transfer) + 32|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($transfer) + 28|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($56|0)==($58|0);
 if ($59) {
  $66 = 0;
 } else {
  $60 = $56;
  $61 = $58;
  $62 = (($60) - ($61))|0;
  $63 = $62 << 6;
  $64 = (($63) + -1)|0;
  $66 = $64;
 }
 $65 = HEAP32[$53>>2]|0;
 $$neg1$i = (1 - ($52))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($66))|0;
 $67 = (($$neg2$i$i$i) - ($65))|0;
 $68 = ($67>>>0)>(511);
 if (!($68)) {
  STACKTOP = sp;return;
 }
 $69 = (($56) + -4|0);
 $70 = HEAP32[$69>>2]|0;
 __ZdlPv($70);
 $71 = HEAP32[$55>>2]|0;
 $72 = (($71) + -4|0);
 $__new_last2$i$i$i$i$i = $72;
 $73 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($72) + ($73)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $74 = $uglygep3$i$i$i$i$i >>> 2;
 $75 = $74 ^ -1;
 $scevgep4$i$i$i$i$i = (($71) + ($75<<2)|0);
 HEAP32[$55>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim9animation13BlendingStateILb0EEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN15SerializeTraitsIN7mecanim9animation13BlendingStateILb0EEEE8TransferI8BlobSizeEEvRS3_RT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim10ValueArrayEEEEvRT_PKc17TransferMetaFlags($this,$data,770168,0);
 $37 = (($data) + 8|0);
 __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim14ValueArrayMaskEEEEvRT_PKc17TransferMetaFlags($this,$37,770192,0);
 $38 = (($data) + 16|0);
 __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim9animation12MotionOutputEEEEvRT_PKc17TransferMetaFlags($this,$38,770224,0);
 $39 = (($data) + 24|0);
 __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim5human9HumanPoseEEEEvRT_PKc17TransferMetaFlags($this,$39,770248,0);
 $40 = (($data) + 32|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$40,770272,0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $41 = HEAP32[$17>>2]|0;
 $42 = (($41) + -1)|0;
 HEAP32[$17>>2] = $42;
 $43 = (($this) + 32|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$23>>2]|0;
 $46 = ($44|0)==($45|0);
 if ($46) {
  $53 = 0;
 } else {
  $47 = $44;
  $48 = $45;
  $49 = (($47) - ($48))|0;
  $50 = $49 << 6;
  $51 = (($50) + -1)|0;
  $53 = $51;
 }
 $52 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($41))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($53))|0;
 $54 = (($$neg2$i$i$i) - ($52))|0;
 $55 = ($54>>>0)>(511);
 if (!($55)) {
  STACKTOP = sp;return;
 }
 $56 = (($44) + -4|0);
 $57 = HEAP32[$56>>2]|0;
 __ZdlPv($57);
 $58 = HEAP32[$43>>2]|0;
 $59 = (($58) + -4|0);
 $__new_last2$i$i$i$i$i = $59;
 $60 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($59) + ($60)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $61 = $uglygep3$i$i$i$i$i >>> 2;
 $62 = $61 ^ -1;
 $scevgep4$i$i$i$i$i = (($58) + ($62<<2)|0);
 HEAP32[$43>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim14ValueArrayMaskEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduce$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduce$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduce$i+0>>2]=0|0;HEAP32[$reduce$i+4>>2]=0|0;HEAP32[$reduce$i+8>>2]=0|0;
 $30 = HEAP32[$data>>2]|0;
 $31 = ($30|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$31,$reduce$i,4);
 $32 = HEAP32[$data>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = $data;
  $35 = (($32) + ($34))|0;
  $36 = $35;
  $37 = (($data) + 4|0);
  HEAP32[$37>>2] = $36;
  __ZN9BlobWrite8TransferIN7mecanim14ValueArrayMaskEEEvRT_PKc17TransferMetaFlags($this,$36,769776,0);
 }
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduce$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$10>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$10>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$16>>2]|0;
 $43 = ($41|0)==($42|0);
 if ($43) {
  $50 = 0;
 } else {
  $44 = $41;
  $45 = $42;
  $46 = (($44) - ($45))|0;
  $47 = $46 << 6;
  $48 = (($47) + -1)|0;
  $50 = $48;
 }
 $49 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($50))|0;
 $51 = (($$neg2$i$i$i) - ($49))|0;
 $52 = ($51>>>0)>(511);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = (($41) + -4|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 $55 = HEAP32[$40>>2]|0;
 $56 = (($55) + -4|0);
 $__new_last2$i$i$i$i$i = $56;
 $57 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($56) + ($57)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $58 = $uglygep3$i$i$i$i$i >>> 2;
 $59 = $58 ^ -1;
 $scevgep4$i$i$i$i$i = (($55) + ($59<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim9animation12MotionOutputEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduce$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduce$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduce$i+0>>2]=0|0;HEAP32[$reduce$i+4>>2]=0|0;HEAP32[$reduce$i+8>>2]=0|0;
 $30 = HEAP32[$data>>2]|0;
 $31 = ($30|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$31,$reduce$i,4);
 $32 = HEAP32[$data>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = $data;
  $35 = (($32) + ($34))|0;
  $36 = $35;
  $37 = (($data) + 4|0);
  HEAP32[$37>>2] = $36;
  __ZN9BlobWrite8TransferIN7mecanim9animation12MotionOutputEEEvRT_PKc17TransferMetaFlags($this,$36,769776,0);
 }
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduce$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$10>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$10>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$16>>2]|0;
 $43 = ($41|0)==($42|0);
 if ($43) {
  $50 = 0;
 } else {
  $44 = $41;
  $45 = $42;
  $46 = (($44) - ($45))|0;
  $47 = $46 << 6;
  $48 = (($47) + -1)|0;
  $50 = $48;
 }
 $49 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($50))|0;
 $51 = (($$neg2$i$i$i) - ($49))|0;
 $52 = ($51>>>0)>(511);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = (($41) + -4|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 $55 = HEAP32[$40>>2]|0;
 $56 = (($55) + -4|0);
 $__new_last2$i$i$i$i$i = $56;
 $57 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($56) + ($57)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $58 = $uglygep3$i$i$i$i$i >>> 2;
 $59 = $58 ^ -1;
 $scevgep4$i$i$i$i$i = (($55) + ($59<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim5human9HumanPoseEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduce$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduce$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduce$i+0>>2]=0|0;HEAP32[$reduce$i+4>>2]=0|0;HEAP32[$reduce$i+8>>2]=0|0;
 $30 = HEAP32[$data>>2]|0;
 $31 = ($30|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$31,$reduce$i,4);
 $32 = HEAP32[$data>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = $data;
  $35 = (($32) + ($34))|0;
  $36 = $35;
  $37 = (($data) + 4|0);
  HEAP32[$37>>2] = $36;
  __ZN9BlobWrite8TransferIN7mecanim5human9HumanPoseEEEvRT_PKc17TransferMetaFlags($this,$36,769776,0);
 }
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduce$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$10>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$10>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$16>>2]|0;
 $43 = ($41|0)==($42|0);
 if ($43) {
  $50 = 0;
 } else {
  $44 = $41;
  $45 = $42;
  $46 = (($44) - ($45))|0;
  $47 = $46 << 6;
  $48 = (($47) + -1)|0;
  $50 = $48;
 }
 $49 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($50))|0;
 $51 = (($$neg2$i$i$i) - ($49))|0;
 $52 = ($51>>>0)>(511);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = (($41) + -4|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 $55 = HEAP32[$40>>2]|0;
 $56 = (($55) + -4|0);
 $__new_last2$i$i$i$i$i = $56;
 $57 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($56) + ($57)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $58 = $uglygep3$i$i$i$i$i >>> 2;
 $59 = $58 ^ -1;
 $scevgep4$i$i$i$i$i = (($55) + ($59<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim5human9HumanPoseEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i1$i$i = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i1$i$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$ArrayTransfer$i1$i$i>>2] = 0;
  $7 = (($ArrayTransfer$i1$i$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($ArrayTransfer$i1$i$i) + 12|0);
  $9 = (($ArrayTransfer$i1$i$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($ArrayTransfer$i1$i$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($ArrayTransfer$i1$i$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim5human9HumanPose8TransferI8BlobSizeEEvRT_($data,$ArrayTransfer$i1$i$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($this,$data,770288,0);
 $37 = (($data) + 48|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$37,770296,0);
 $38 = (($data) + 64|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$38,770320,0);
 $39 = (($data) + 80|0);
 HEAP32[$ArrayTransfer$i1$i$i>>2] = 4;
 $40 = (($ArrayTransfer$i1$i$i) + 4|0);
 HEAP32[$40>>2] = $39;
 __ZN9BlobWrite8TransferI19StaticArrayTransferIN7mecanim5human9HumanGoalELi4EEEEvRT_PKc17TransferMetaFlags($this,$ArrayTransfer$i1$i$i,770336,0);
 $41 = (($data) + 384|0);
 __ZN9BlobWrite8TransferIN7mecanim4hand8HandPoseEEEvRT_PKc17TransferMetaFlags($this,$41,770352,0);
 $42 = (($data) + 528|0);
 __ZN9BlobWrite8TransferIN7mecanim4hand8HandPoseEEEvRT_PKc17TransferMetaFlags($this,$42,770368,0);
 $43 = (($data) + 672|0);
 HEAP32[$ArrayTransfer$i1$i$i>>2] = 52;
 $44 = (($ArrayTransfer$i1$i$i) + 4|0);
 HEAP32[$44>>2] = $43;
 __ZN9BlobWrite8TransferI19StaticArrayTransferIfLi52EEEEvRT_PKc17TransferMetaFlags($this,$ArrayTransfer$i1$i$i,770384,0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$17>>2]|0;
 $46 = (($45) + -1)|0;
 HEAP32[$17>>2] = $46;
 $47 = (($this) + 32|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$23>>2]|0;
 $50 = ($48|0)==($49|0);
 if ($50) {
  $57 = 0;
 } else {
  $51 = $48;
  $52 = $49;
  $53 = (($51) - ($52))|0;
  $54 = $53 << 6;
  $55 = (($54) + -1)|0;
  $57 = $55;
 }
 $56 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($45))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($57))|0;
 $58 = (($$neg2$i$i$i) - ($56))|0;
 $59 = ($58>>>0)>(511);
 if (!($59)) {
  STACKTOP = sp;return;
 }
 $60 = (($48) + -4|0);
 $61 = HEAP32[$60>>2]|0;
 __ZdlPv($61);
 $62 = HEAP32[$47>>2]|0;
 $63 = (($62) + -4|0);
 $__new_last2$i$i$i$i$i = $63;
 $64 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($63) + ($64)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $65 = $uglygep3$i$i$i$i$i >>> 2;
 $66 = $65 ^ -1;
 $scevgep4$i$i$i$i$i = (($62) + ($66<<2)|0);
 HEAP32[$47>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim4hand8HandPoseEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$ArrayTransfer$i$i$i>>2] = 0;
  $7 = (($ArrayTransfer$i$i$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($ArrayTransfer$i$i$i) + 12|0);
  $9 = (($ArrayTransfer$i$i$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($ArrayTransfer$i$i$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($ArrayTransfer$i$i$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim4hand8HandPose8TransferI8BlobSizeEEvRT_($data,$ArrayTransfer$i$i$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($this,$data,770400,0);
 $37 = (($data) + 48|0);
 HEAP32[$ArrayTransfer$i$i$i>>2] = 20;
 $38 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$38>>2] = $37;
 __ZN9BlobWrite8TransferI19StaticArrayTransferIfLi20EEEEvRT_PKc17TransferMetaFlags($this,$ArrayTransfer$i$i$i,770384,0);
 $39 = (($data) + 128|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$39,770408,0);
 $40 = (($data) + 132|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$40,770424,0);
 $41 = (($data) + 136|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$41,770440,0);
 $42 = (($data) + 140|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$42,770448,0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $43 = HEAP32[$17>>2]|0;
 $44 = (($43) + -1)|0;
 HEAP32[$17>>2] = $44;
 $45 = (($this) + 32|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$23>>2]|0;
 $48 = ($46|0)==($47|0);
 if ($48) {
  $55 = 0;
 } else {
  $49 = $46;
  $50 = $47;
  $51 = (($49) - ($50))|0;
  $52 = $51 << 6;
  $53 = (($52) + -1)|0;
  $55 = $53;
 }
 $54 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($43))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($55))|0;
 $56 = (($$neg2$i$i$i) - ($54))|0;
 $57 = ($56>>>0)>(511);
 if (!($57)) {
  STACKTOP = sp;return;
 }
 $58 = (($46) + -4|0);
 $59 = HEAP32[$58>>2]|0;
 __ZdlPv($59);
 $60 = HEAP32[$45>>2]|0;
 $61 = (($60) + -4|0);
 $__new_last2$i$i$i$i$i = $61;
 $62 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($61) + ($62)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $63 = $uglygep3$i$i$i$i$i >>> 2;
 $64 = $63 ^ -1;
 $scevgep4$i$i$i$i$i = (($60) + ($64<<2)|0);
 HEAP32[$45>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI19StaticArrayTransferIfLi52EEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $$pre$phi4Z2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$01$i$i$i = 0, $scevgep4$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = HEAP32[$data>>2]|0;
  $5 = $4 << 2;
  __ZN9BlobWrite4PushEjPKvj($this,$5,$data,4);
  $$pre$phi4Z2D = $data;
 } else {
  $$pre$phi4Z2D = $data;
 }
 $6 = (($this) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + -1)|0;
 $11 = (($10) + ($9))|0;
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11 >>> 8;
 $15 = (($13) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $11 & 255;
 $18 = (($16) + ($17<<4)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($16) + ($17<<4)|0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19))|0;
 $23 = (0 - ($22))|0;
 $24 = $23 & 3;
 $25 = (($21) + ($24))|0;
 HEAP32[$20>>2] = $25;
 $26 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $27 = (($data) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 $30 = ($26|0)==(0);
 if (!($30)) {
  $i$01$i$i$i = $28;
  while(1) {
   __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$01$i$i$i,769776,0);
   $31 = (($i$01$i$i$i) + 4|0);
   $32 = ($31|0)==($29|0);
   if ($32) {
    break;
   } else {
    $i$01$i$i$i = $31;
   }
  }
 }
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$6>>2]|0;
 $34 = (($33) + -1)|0;
 HEAP32[$6>>2] = $34;
 $35 = (($this) + 32|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$12>>2]|0;
 $38 = ($36|0)==($37|0);
 if ($38) {
  $45 = 0;
 } else {
  $39 = $36;
  $40 = $37;
  $41 = (($39) - ($40))|0;
  $42 = $41 << 6;
  $43 = (($42) + -1)|0;
  $45 = $43;
 }
 $44 = HEAP32[$8>>2]|0;
 $$neg1$i = (1 - ($33))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($45))|0;
 $46 = (($$neg2$i$i$i) - ($44))|0;
 $47 = ($46>>>0)>(511);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (($36) + -4|0);
 $49 = HEAP32[$48>>2]|0;
 __ZdlPv($49);
 $50 = HEAP32[$35>>2]|0;
 $51 = (($50) + -4|0);
 $__new_last2$i$i$i$i$i = $51;
 $52 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($51) + ($52)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $53 = $uglygep3$i$i$i$i$i >>> 2;
 $54 = $53 ^ -1;
 $scevgep4$i$i$i$i$i = (($50) + ($54<<2)|0);
 HEAP32[$35>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI19StaticArrayTransferIfLi20EEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $$pre$phi4Z2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$01$i$i$i = 0, $scevgep4$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = HEAP32[$data>>2]|0;
  $5 = $4 << 2;
  __ZN9BlobWrite4PushEjPKvj($this,$5,$data,4);
  $$pre$phi4Z2D = $data;
 } else {
  $$pre$phi4Z2D = $data;
 }
 $6 = (($this) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + -1)|0;
 $11 = (($10) + ($9))|0;
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11 >>> 8;
 $15 = (($13) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $11 & 255;
 $18 = (($16) + ($17<<4)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($16) + ($17<<4)|0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19))|0;
 $23 = (0 - ($22))|0;
 $24 = $23 & 3;
 $25 = (($21) + ($24))|0;
 HEAP32[$20>>2] = $25;
 $26 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $27 = (($data) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 $30 = ($26|0)==(0);
 if (!($30)) {
  $i$01$i$i$i = $28;
  while(1) {
   __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$01$i$i$i,769776,0);
   $31 = (($i$01$i$i$i) + 4|0);
   $32 = ($31|0)==($29|0);
   if ($32) {
    break;
   } else {
    $i$01$i$i$i = $31;
   }
  }
 }
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$6>>2]|0;
 $34 = (($33) + -1)|0;
 HEAP32[$6>>2] = $34;
 $35 = (($this) + 32|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$12>>2]|0;
 $38 = ($36|0)==($37|0);
 if ($38) {
  $45 = 0;
 } else {
  $39 = $36;
  $40 = $37;
  $41 = (($39) - ($40))|0;
  $42 = $41 << 6;
  $43 = (($42) + -1)|0;
  $45 = $43;
 }
 $44 = HEAP32[$8>>2]|0;
 $$neg1$i = (1 - ($33))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($45))|0;
 $46 = (($$neg2$i$i$i) - ($44))|0;
 $47 = ($46>>>0)>(511);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (($36) + -4|0);
 $49 = HEAP32[$48>>2]|0;
 __ZdlPv($49);
 $50 = HEAP32[$35>>2]|0;
 $51 = (($50) + -4|0);
 $__new_last2$i$i$i$i$i = $51;
 $52 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($51) + ($52)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $53 = $uglygep3$i$i$i$i$i >>> 2;
 $54 = $53 ^ -1;
 $scevgep4$i$i$i$i$i = (($50) + ($54<<2)|0);
 HEAP32[$35>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim4hand8HandPose8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  HEAP32[$3>>2] = $7;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($this,$transfer);
  $8 = HEAP32[$3>>2]|0;
  $9 = (0 - ($8))|0;
  $10 = $9 & 3;
  $11 = (($10) + ($8))|0;
  HEAP32[$3>>2] = $11;
  $$pr = HEAP8[$0>>0]|0;
  $12 = ($$pr<<24>>24)==(0);
  if ($12) {
   $15 = $11;
   label = 5;
  } else {
   HEAP8[$0>>0] = 0;
   $26 = $11;
  }
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $15 = $$pre;
  label = 5;
 }
 if ((label|0) == 5) {
  $13 = (($transfer) + 12|0);
  $14 = (0 - ($15))|0;
  $16 = $14 & 3;
  $17 = (($16) + ($15))|0;
  $18 = (0 - ($17))|0;
  $19 = $18 & 3;
  $20 = (($19) + ($17))|0;
  $21 = (($20) + 80)|0;
  $22 = (0 - ($20))|0;
  $23 = $22 & 3;
  $24 = (($21) + ($23))|0;
  HEAP32[$13>>2] = $24;
  $26 = $24;
 }
 $25 = (0 - ($26))|0;
 $27 = $25 & 3;
 $28 = (($27) + ($26))|0;
 $29 = (($28) + 4)|0;
 $30 = (0 - ($28))|0;
 $31 = $30 & 3;
 $32 = (($29) + ($31))|0;
 $33 = (0 - ($32))|0;
 $34 = $33 & 3;
 $35 = (($34) + ($32))|0;
 $36 = (($35) + 4)|0;
 $37 = (0 - ($35))|0;
 $38 = $37 & 3;
 $39 = (($36) + ($38))|0;
 $40 = (0 - ($39))|0;
 $41 = $40 & 3;
 $42 = (($41) + ($39))|0;
 $43 = (($42) + 4)|0;
 $44 = (0 - ($42))|0;
 $45 = $44 & 3;
 $46 = (($43) + ($45))|0;
 $47 = (($transfer) + 12|0);
 $48 = (0 - ($46))|0;
 $49 = $48 & 3;
 $50 = (($49) + ($46))|0;
 $51 = (($50) + 4)|0;
 $52 = (0 - ($50))|0;
 $53 = $52 & 3;
 $54 = (($51) + ($53))|0;
 HEAP32[$47>>2] = $54;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI19StaticArrayTransferIN7mecanim5human9HumanGoalELi4EEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $$pre$phi4Z2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$01$i$i$i = 0, $scevgep4$i$i$i$i$i = 0;
 var $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = HEAP32[$data>>2]|0;
  $5 = ($4*76)|0;
  __ZN9BlobWrite4PushEjPKvj($this,$5,$data,4);
  $$pre$phi4Z2D = $data;
 } else {
  $$pre$phi4Z2D = $data;
 }
 $6 = (($this) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + -1)|0;
 $11 = (($10) + ($9))|0;
 $12 = (($this) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11 >>> 8;
 $15 = (($13) + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $11 & 255;
 $18 = (($16) + ($17<<4)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($16) + ($17<<4)|0) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19))|0;
 $23 = (0 - ($22))|0;
 $24 = $23 & 3;
 $25 = (($21) + ($24))|0;
 HEAP32[$20>>2] = $25;
 $26 = HEAP32[$$pre$phi4Z2D>>2]|0;
 $27 = (($data) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + (($26*76)|0)|0);
 $30 = ($26|0)==(0);
 if (!($30)) {
  $i$01$i$i$i = $28;
  while(1) {
   __ZN9BlobWrite8TransferIN7mecanim5human9HumanGoalEEEvRT_PKc17TransferMetaFlags($this,$i$01$i$i$i,769776,0);
   $31 = (($i$01$i$i$i) + 76|0);
   $32 = ($31|0)==($29|0);
   if ($32) {
    break;
   } else {
    $i$01$i$i$i = $31;
   }
  }
 }
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$6>>2]|0;
 $34 = (($33) + -1)|0;
 HEAP32[$6>>2] = $34;
 $35 = (($this) + 32|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$12>>2]|0;
 $38 = ($36|0)==($37|0);
 if ($38) {
  $45 = 0;
 } else {
  $39 = $36;
  $40 = $37;
  $41 = (($39) - ($40))|0;
  $42 = $41 << 6;
  $43 = (($42) + -1)|0;
  $45 = $43;
 }
 $44 = HEAP32[$8>>2]|0;
 $$neg1$i = (1 - ($33))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($45))|0;
 $46 = (($$neg2$i$i$i) - ($44))|0;
 $47 = ($46>>>0)>(511);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (($36) + -4|0);
 $49 = HEAP32[$48>>2]|0;
 __ZdlPv($49);
 $50 = HEAP32[$35>>2]|0;
 $51 = (($50) + -4|0);
 $__new_last2$i$i$i$i$i = $51;
 $52 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($51) + ($52)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $53 = $uglygep3$i$i$i$i$i >>> 2;
 $54 = $53 ^ -1;
 $scevgep4$i$i$i$i$i = (($50) + ($54<<2)|0);
 HEAP32[$35>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim5human9HumanGoalEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim5human9HumanGoal8TransferI8BlobSizeEEvRT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($this,$data,770456,0);
 $37 = (($data) + 48|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$37,770464,0);
 $38 = (($data) + 52|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$38,770480,0);
 $39 = (($data) + 56|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($this,$39,770496,0);
 $40 = (($data) + 72|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($this,$40,770504,0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $41 = HEAP32[$17>>2]|0;
 $42 = (($41) + -1)|0;
 HEAP32[$17>>2] = $42;
 $43 = (($this) + 32|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$23>>2]|0;
 $46 = ($44|0)==($45|0);
 if ($46) {
  $53 = 0;
 } else {
  $47 = $44;
  $48 = $45;
  $49 = (($47) - ($48))|0;
  $50 = $49 << 6;
  $51 = (($50) + -1)|0;
  $53 = $51;
 }
 $52 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($41))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($53))|0;
 $54 = (($$neg2$i$i$i) - ($52))|0;
 $55 = ($54>>>0)>(511);
 if (!($55)) {
  STACKTOP = sp;return;
 }
 $56 = (($44) + -4|0);
 $57 = HEAP32[$56>>2]|0;
 __ZdlPv($57);
 $58 = HEAP32[$43>>2]|0;
 $59 = (($58) + -4|0);
 $__new_last2$i$i$i$i$i = $59;
 $60 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($59) + ($60)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $61 = $uglygep3$i$i$i$i$i >>> 2;
 $62 = $61 ^ -1;
 $scevgep4$i$i$i$i$i = (($58) + ($62<<2)|0);
 HEAP32[$43>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human9HumanGoal8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  HEAP32[$3>>2] = $7;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($this,$transfer);
  $8 = HEAP32[$3>>2]|0;
  $9 = (0 - ($8))|0;
  $10 = $9 & 3;
  $11 = (($10) + ($8))|0;
  HEAP32[$3>>2] = $11;
  $$pr = HEAP8[$0>>0]|0;
  $12 = ($$pr<<24>>24)==(0);
  if ($12) {
   $15 = $11;
   label = 5;
  } else {
   HEAP8[$0>>0] = 0;
   $23 = $11;
  }
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $15 = $$pre;
  label = 5;
 }
 if ((label|0) == 5) {
  $13 = (($transfer) + 12|0);
  $14 = (0 - ($15))|0;
  $16 = $14 & 3;
  $17 = (($16) + ($15))|0;
  $18 = (($17) + 4)|0;
  $19 = (0 - ($17))|0;
  $20 = $19 & 3;
  $21 = (($18) + ($20))|0;
  HEAP32[$13>>2] = $21;
  $23 = $21;
 }
 $22 = (0 - ($23))|0;
 $24 = $22 & 3;
 $25 = (($24) + ($23))|0;
 $26 = (($25) + 4)|0;
 $27 = (0 - ($25))|0;
 $28 = $27 & 3;
 $29 = (($26) + ($28))|0;
 $30 = (0 - ($29))|0;
 $31 = $30 & 3;
 $32 = (($31) + ($29))|0;
 $33 = (0 - ($32))|0;
 $34 = $33 & 3;
 $35 = (($34) + ($32))|0;
 $36 = (($35) + 4)|0;
 $37 = (0 - ($35))|0;
 $38 = $37 & 3;
 $39 = (($36) + ($38))|0;
 $40 = (0 - ($39))|0;
 $41 = $40 & 3;
 $42 = (($41) + ($39))|0;
 $43 = (($42) + 4)|0;
 $44 = (0 - ($42))|0;
 $45 = $44 & 3;
 $46 = (($43) + ($45))|0;
 $47 = (0 - ($46))|0;
 $48 = $47 & 3;
 $49 = (($48) + ($46))|0;
 $50 = (($49) + 4)|0;
 $51 = (0 - ($49))|0;
 $52 = $51 & 3;
 $53 = (($50) + ($52))|0;
 $54 = (0 - ($53))|0;
 $55 = $54 & 3;
 $56 = (($55) + ($53))|0;
 $57 = (($56) + 4)|0;
 $58 = (0 - ($56))|0;
 $59 = $58 & 3;
 $60 = (($57) + ($59))|0;
 $61 = (0 - ($60))|0;
 $62 = $61 & 3;
 $63 = (($62) + ($60))|0;
 $64 = (($transfer) + 12|0);
 $65 = (0 - ($63))|0;
 $66 = $65 & 3;
 $67 = (($66) + ($63))|0;
 $68 = (($67) + 4)|0;
 $69 = (0 - ($67))|0;
 $70 = $69 & 3;
 $71 = (($68) + ($70))|0;
 HEAP32[$64>>2] = $71;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human9HumanPose8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert = 0, $$pr = 0, $$pr7 = 0, $$pr8 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  HEAP32[$3>>2] = $7;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($this,$transfer);
  $8 = HEAP32[$3>>2]|0;
  $9 = (0 - ($8))|0;
  $10 = $9 & 3;
  $11 = (($10) + ($8))|0;
  HEAP32[$3>>2] = $11;
  $$pr = HEAP8[$0>>0]|0;
  $12 = ($$pr<<24>>24)==(0);
  if ($12) {
   $15 = $11;
   label = 5;
  } else {
   HEAP8[$0>>0] = 0;
   $50 = $11;
  }
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $15 = $$pre;
  label = 5;
 }
 if ((label|0) == 5) {
  $13 = (($transfer) + 12|0);
  $14 = (0 - ($15))|0;
  $16 = $14 & 3;
  $17 = (($16) + ($15))|0;
  $18 = (0 - ($17))|0;
  $19 = $18 & 3;
  $20 = (($19) + ($17))|0;
  $21 = (($20) + 4)|0;
  $22 = (0 - ($20))|0;
  $23 = $22 & 3;
  $24 = (($21) + ($23))|0;
  $25 = (0 - ($24))|0;
  $26 = $25 & 3;
  $27 = (($26) + ($24))|0;
  $28 = (($27) + 4)|0;
  $29 = (0 - ($27))|0;
  $30 = $29 & 3;
  $31 = (($28) + ($30))|0;
  $32 = (0 - ($31))|0;
  $33 = $32 & 3;
  $34 = (($33) + ($31))|0;
  $35 = (($34) + 4)|0;
  $36 = (0 - ($34))|0;
  $37 = $36 & 3;
  $38 = (($35) + ($37))|0;
  $39 = (0 - ($38))|0;
  $40 = $39 & 3;
  $41 = (($40) + ($38))|0;
  $42 = (($41) + 4)|0;
  $43 = (0 - ($41))|0;
  $44 = $43 & 3;
  $45 = (($42) + ($44))|0;
  $46 = (0 - ($45))|0;
  $47 = $46 & 3;
  $48 = (($47) + ($45))|0;
  HEAP32[$13>>2] = $48;
  $50 = $48;
 }
 $49 = (0 - ($50))|0;
 $51 = $49 & 3;
 $52 = (($51) + ($50))|0;
 $53 = (0 - ($52))|0;
 $54 = $53 & 3;
 $55 = (($54) + ($52))|0;
 $56 = (($55) + 4)|0;
 $57 = (0 - ($55))|0;
 $58 = $57 & 3;
 $59 = (($56) + ($58))|0;
 $60 = (0 - ($59))|0;
 $61 = $60 & 3;
 $62 = (($61) + ($59))|0;
 $63 = (($62) + 4)|0;
 $64 = (0 - ($62))|0;
 $65 = $64 & 3;
 $66 = (($63) + ($65))|0;
 $67 = (0 - ($66))|0;
 $68 = $67 & 3;
 $69 = (($68) + ($66))|0;
 $70 = (($69) + 4)|0;
 $71 = (0 - ($69))|0;
 $72 = $71 & 3;
 $73 = (($70) + ($72))|0;
 $74 = (0 - ($73))|0;
 $75 = $74 & 3;
 $76 = (($75) + ($73))|0;
 $77 = (($76) + 4)|0;
 $78 = (0 - ($76))|0;
 $79 = $78 & 3;
 $80 = (($77) + ($79))|0;
 $81 = (0 - ($80))|0;
 $82 = $81 & 3;
 $83 = (($82) + ($80))|0;
 $84 = (0 - ($83))|0;
 $85 = $84 & 3;
 $86 = (($85) + ($83))|0;
 $87 = (0 - ($86))|0;
 $88 = $87 & 3;
 $89 = (($88) + ($86))|0;
 $90 = (($89) + 304)|0;
 $91 = (0 - ($89))|0;
 $92 = $91 & 3;
 $93 = (($90) + ($92))|0;
 $94 = (($this) + 384|0);
 $95 = (($transfer) + 12|0);
 $96 = (0 - ($93))|0;
 $97 = $96 & 3;
 $98 = (($97) + ($93))|0;
 HEAP32[$95>>2] = $98;
 __ZN7mecanim4hand8HandPose8TransferI8BlobSizeEEvRT_($94,$transfer);
 $99 = HEAP32[$95>>2]|0;
 $100 = (0 - ($99))|0;
 $101 = $100 & 3;
 $102 = (($101) + ($99))|0;
 HEAP32[$95>>2] = $102;
 $$pr7 = HEAP8[$0>>0]|0;
 $103 = ($$pr7<<24>>24)==(0);
 if ($103) {
  $104 = (($this) + 528|0);
  $105 = (($transfer) + 12|0);
  $106 = (0 - ($102))|0;
  $107 = $106 & 3;
  $108 = (($107) + ($102))|0;
  HEAP32[$105>>2] = $108;
  __ZN7mecanim4hand8HandPose8TransferI8BlobSizeEEvRT_($104,$transfer);
  $109 = HEAP32[$105>>2]|0;
  $110 = (0 - ($109))|0;
  $111 = $110 & 3;
  $112 = (($111) + ($109))|0;
  HEAP32[$105>>2] = $112;
  $$pr8 = HEAP8[$0>>0]|0;
  $113 = ($$pr8<<24>>24)==(0);
  if ($113) {
   $116 = $112;
  } else {
   HEAP8[$0>>0] = 0;
   STACKTOP = sp;return;
  }
 } else {
  HEAP8[$0>>0] = 0;
  $116 = $102;
 }
 $114 = (($transfer) + 12|0);
 $115 = (0 - ($116))|0;
 $117 = $115 & 3;
 $118 = (($117) + ($116))|0;
 $119 = (0 - ($118))|0;
 $120 = $119 & 3;
 $121 = (($120) + ($118))|0;
 $122 = (($121) + 208)|0;
 $123 = (0 - ($121))|0;
 $124 = $123 & 3;
 $125 = (($122) + ($124))|0;
 HEAP32[$114>>2] = $125;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim9animation12MotionOutputEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim9animation12MotionOutput8TransferI8BlobSizeEEvRT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN7mecanim9animation12MotionOutput8TransferI9BlobWriteEEvRT_($data,$this);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + -1)|0;
 HEAP32[$17>>2] = $38;
 $39 = (($this) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$23>>2]|0;
 $42 = ($40|0)==($41|0);
 if ($42) {
  $49 = 0;
 } else {
  $43 = $40;
  $44 = $41;
  $45 = (($43) - ($44))|0;
  $46 = $45 << 6;
  $47 = (($46) + -1)|0;
  $49 = $47;
 }
 $48 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($37))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($49))|0;
 $50 = (($$neg2$i$i$i) - ($48))|0;
 $51 = ($50>>>0)>(511);
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (($40) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 __ZdlPv($53);
 $54 = HEAP32[$39>>2]|0;
 $55 = (($54) + -4|0);
 $__new_last2$i$i$i$i$i = $55;
 $56 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($55) + ($56)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $57 = $uglygep3$i$i$i$i$i >>> 2;
 $58 = $57 ^ -1;
 $scevgep4$i$i$i$i$i = (($54) + ($58<<2)|0);
 HEAP32[$39>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12MotionOutput8TransferI9BlobWriteEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$this,770520,0);
 $0 = (($this) + 4|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$0,770536,0);
 $1 = (($this) + 20|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$1,770552,0);
 $2 = (($this) + 36|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($transfer,$2,770576,0);
 $3 = (($this) + 84|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($transfer,$3,770592,0);
 $4 = (($this) + 132|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($transfer,$4,770608,0);
 $5 = (($this) + 180|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($transfer,$5,770624,0);
 $6 = (($this) + 228|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($transfer,$6,770640,0);
 $7 = (($this) + 276|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($transfer,$7,770656,0);
 $8 = (($this) + 324|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($transfer,$8,770672,0);
 $9 = (($this) + 372|0);
 __ZN9BlobWrite8TransferIN4math5xformEEEvRT_PKc17TransferMetaFlags($transfer,$9,770696,0);
 $10 = (($this) + 420|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$10,770712,0);
 $11 = (($this) + 424|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$11,770728,0);
 $12 = (($this) + 440|0);
 __ZN9BlobWrite8TransferIKN4math7_float4EEEvRT_PKc17TransferMetaFlags($transfer,$12,769704,0);
 $13 = (($this) + 456|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,769712,0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12MotionOutput8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert = 0, $$pr18 = 0, $$pr19 = 0, $$pr20 = 0, $$pr21 = 0, $$pr22 = 0, $$pr23 = 0, $$pr24 = 0, $$pr25 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  $8 = (($7) + 4)|0;
  $9 = (0 - ($7))|0;
  $10 = $9 & 3;
  $11 = (($8) + ($10))|0;
  HEAP32[$3>>2] = $11;
  $13 = $11;
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $13 = $$pre;
 }
 $12 = (0 - ($13))|0;
 $14 = $12 & 3;
 $15 = (($14) + ($13))|0;
 $16 = (0 - ($15))|0;
 $17 = $16 & 3;
 $18 = (($17) + ($15))|0;
 $19 = (($18) + 4)|0;
 $20 = (0 - ($18))|0;
 $21 = $20 & 3;
 $22 = (($19) + ($21))|0;
 $23 = (0 - ($22))|0;
 $24 = $23 & 3;
 $25 = (($24) + ($22))|0;
 $26 = (($25) + 4)|0;
 $27 = (0 - ($25))|0;
 $28 = $27 & 3;
 $29 = (($26) + ($28))|0;
 $30 = (0 - ($29))|0;
 $31 = $30 & 3;
 $32 = (($31) + ($29))|0;
 $33 = (($32) + 4)|0;
 $34 = (0 - ($32))|0;
 $35 = $34 & 3;
 $36 = (($33) + ($35))|0;
 $37 = (0 - ($36))|0;
 $38 = $37 & 3;
 $39 = (($38) + ($36))|0;
 $40 = (($39) + 4)|0;
 $41 = (0 - ($39))|0;
 $42 = $41 & 3;
 $43 = (($40) + ($42))|0;
 $44 = (0 - ($43))|0;
 $45 = $44 & 3;
 $46 = (($45) + ($43))|0;
 $47 = (0 - ($46))|0;
 $48 = $47 & 3;
 $49 = (($48) + ($46))|0;
 $50 = (0 - ($49))|0;
 $51 = $50 & 3;
 $52 = (($51) + ($49))|0;
 $53 = (($52) + 4)|0;
 $54 = (0 - ($52))|0;
 $55 = $54 & 3;
 $56 = (($53) + ($55))|0;
 $57 = (0 - ($56))|0;
 $58 = $57 & 3;
 $59 = (($58) + ($56))|0;
 $60 = (($59) + 4)|0;
 $61 = (0 - ($59))|0;
 $62 = $61 & 3;
 $63 = (($60) + ($62))|0;
 $64 = (0 - ($63))|0;
 $65 = $64 & 3;
 $66 = (($65) + ($63))|0;
 $67 = (($66) + 4)|0;
 $68 = (0 - ($66))|0;
 $69 = $68 & 3;
 $70 = (($67) + ($69))|0;
 $71 = (0 - ($70))|0;
 $72 = $71 & 3;
 $73 = (($72) + ($70))|0;
 $74 = (($73) + 4)|0;
 $75 = (0 - ($73))|0;
 $76 = $75 & 3;
 $77 = (($74) + ($76))|0;
 $78 = (0 - ($77))|0;
 $79 = $78 & 3;
 $80 = (($79) + ($77))|0;
 $81 = (($this) + 36|0);
 $82 = (($transfer) + 12|0);
 $83 = (0 - ($80))|0;
 $84 = $83 & 3;
 $85 = (($84) + ($80))|0;
 HEAP32[$82>>2] = $85;
 __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($81,$transfer);
 $86 = HEAP32[$82>>2]|0;
 $87 = (0 - ($86))|0;
 $88 = $87 & 3;
 $89 = (($88) + ($86))|0;
 HEAP32[$82>>2] = $89;
 $$pr18 = HEAP8[$0>>0]|0;
 $90 = ($$pr18<<24>>24)==(0);
 if ($90) {
  $91 = (($this) + 84|0);
  $92 = (($transfer) + 12|0);
  $93 = (0 - ($89))|0;
  $94 = $93 & 3;
  $95 = (($94) + ($89))|0;
  HEAP32[$92>>2] = $95;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($91,$transfer);
  $96 = HEAP32[$92>>2]|0;
  $97 = (0 - ($96))|0;
  $98 = $97 & 3;
  $99 = (($98) + ($96))|0;
  HEAP32[$92>>2] = $99;
  $$pr19 = HEAP8[$0>>0]|0;
  $100 = ($$pr19<<24>>24)==(0);
  if ($100) {
   $104 = $99;
   label = 8;
  } else {
   HEAP8[$0>>0] = 0;
   $115 = $99;
   label = 10;
  }
 } else {
  HEAP8[$0>>0] = 0;
  $104 = $89;
  label = 8;
 }
 if ((label|0) == 8) {
  $101 = (($this) + 132|0);
  $102 = (($transfer) + 12|0);
  $103 = (0 - ($104))|0;
  $105 = $103 & 3;
  $106 = (($105) + ($104))|0;
  HEAP32[$102>>2] = $106;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($101,$transfer);
  $107 = HEAP32[$102>>2]|0;
  $108 = (0 - ($107))|0;
  $109 = $108 & 3;
  $110 = (($109) + ($107))|0;
  HEAP32[$102>>2] = $110;
  $$pr20 = HEAP8[$0>>0]|0;
  $111 = ($$pr20<<24>>24)==(0);
  if ($111) {
   $115 = $110;
   label = 10;
  } else {
   HEAP8[$0>>0] = 0;
   $126 = $110;
   label = 12;
  }
 }
 if ((label|0) == 10) {
  $112 = (($this) + 180|0);
  $113 = (($transfer) + 12|0);
  $114 = (0 - ($115))|0;
  $116 = $114 & 3;
  $117 = (($116) + ($115))|0;
  HEAP32[$113>>2] = $117;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($112,$transfer);
  $118 = HEAP32[$113>>2]|0;
  $119 = (0 - ($118))|0;
  $120 = $119 & 3;
  $121 = (($120) + ($118))|0;
  HEAP32[$113>>2] = $121;
  $$pr21 = HEAP8[$0>>0]|0;
  $122 = ($$pr21<<24>>24)==(0);
  if ($122) {
   $126 = $121;
   label = 12;
  } else {
   HEAP8[$0>>0] = 0;
   $137 = $121;
   label = 14;
  }
 }
 if ((label|0) == 12) {
  $123 = (($this) + 228|0);
  $124 = (($transfer) + 12|0);
  $125 = (0 - ($126))|0;
  $127 = $125 & 3;
  $128 = (($127) + ($126))|0;
  HEAP32[$124>>2] = $128;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($123,$transfer);
  $129 = HEAP32[$124>>2]|0;
  $130 = (0 - ($129))|0;
  $131 = $130 & 3;
  $132 = (($131) + ($129))|0;
  HEAP32[$124>>2] = $132;
  $$pr22 = HEAP8[$0>>0]|0;
  $133 = ($$pr22<<24>>24)==(0);
  if ($133) {
   $137 = $132;
   label = 14;
  } else {
   HEAP8[$0>>0] = 0;
   $148 = $132;
   label = 16;
  }
 }
 if ((label|0) == 14) {
  $134 = (($this) + 276|0);
  $135 = (($transfer) + 12|0);
  $136 = (0 - ($137))|0;
  $138 = $136 & 3;
  $139 = (($138) + ($137))|0;
  HEAP32[$135>>2] = $139;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($134,$transfer);
  $140 = HEAP32[$135>>2]|0;
  $141 = (0 - ($140))|0;
  $142 = $141 & 3;
  $143 = (($142) + ($140))|0;
  HEAP32[$135>>2] = $143;
  $$pr23 = HEAP8[$0>>0]|0;
  $144 = ($$pr23<<24>>24)==(0);
  if ($144) {
   $148 = $143;
   label = 16;
  } else {
   HEAP8[$0>>0] = 0;
   $159 = $143;
   label = 18;
  }
 }
 if ((label|0) == 16) {
  $145 = (($this) + 324|0);
  $146 = (($transfer) + 12|0);
  $147 = (0 - ($148))|0;
  $149 = $147 & 3;
  $150 = (($149) + ($148))|0;
  HEAP32[$146>>2] = $150;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($145,$transfer);
  $151 = HEAP32[$146>>2]|0;
  $152 = (0 - ($151))|0;
  $153 = $152 & 3;
  $154 = (($153) + ($151))|0;
  HEAP32[$146>>2] = $154;
  $$pr24 = HEAP8[$0>>0]|0;
  $155 = ($$pr24<<24>>24)==(0);
  if ($155) {
   $159 = $154;
   label = 18;
  } else {
   HEAP8[$0>>0] = 0;
   $169 = $154;
   label = 20;
  }
 }
 if ((label|0) == 18) {
  $156 = (($this) + 372|0);
  $157 = (($transfer) + 12|0);
  $158 = (0 - ($159))|0;
  $160 = $158 & 3;
  $161 = (($160) + ($159))|0;
  HEAP32[$157>>2] = $161;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($156,$transfer);
  $162 = HEAP32[$157>>2]|0;
  $163 = (0 - ($162))|0;
  $164 = $163 & 3;
  $165 = (($164) + ($162))|0;
  HEAP32[$157>>2] = $165;
  $$pr25 = HEAP8[$0>>0]|0;
  $166 = ($$pr25<<24>>24)==(0);
  if ($166) {
   $169 = $165;
   label = 20;
  } else {
   HEAP8[$0>>0] = 0;
   $177 = $165;
  }
 }
 if ((label|0) == 20) {
  $167 = (($transfer) + 12|0);
  $168 = (0 - ($169))|0;
  $170 = $168 & 3;
  $171 = (($170) + ($169))|0;
  $172 = (($171) + 4)|0;
  $173 = (0 - ($171))|0;
  $174 = $173 & 3;
  $175 = (($172) + ($174))|0;
  HEAP32[$167>>2] = $175;
  $177 = $175;
 }
 $176 = (0 - ($177))|0;
 $178 = $176 & 3;
 $179 = (($178) + ($177))|0;
 $180 = (0 - ($179))|0;
 $181 = $180 & 3;
 $182 = (($181) + ($179))|0;
 $183 = (($182) + 4)|0;
 $184 = (0 - ($182))|0;
 $185 = $184 & 3;
 $186 = (($183) + ($185))|0;
 $187 = (0 - ($186))|0;
 $188 = $187 & 3;
 $189 = (($188) + ($186))|0;
 $190 = (($189) + 4)|0;
 $191 = (0 - ($189))|0;
 $192 = $191 & 3;
 $193 = (($190) + ($192))|0;
 $194 = (0 - ($193))|0;
 $195 = $194 & 3;
 $196 = (($195) + ($193))|0;
 $197 = (($196) + 4)|0;
 $198 = (0 - ($196))|0;
 $199 = $198 & 3;
 $200 = (($197) + ($199))|0;
 $201 = (0 - ($200))|0;
 $202 = $201 & 3;
 $203 = (($202) + ($200))|0;
 $204 = (($203) + 4)|0;
 $205 = (0 - ($203))|0;
 $206 = $205 & 3;
 $207 = (($204) + ($206))|0;
 $208 = (0 - ($207))|0;
 $209 = $208 & 3;
 $210 = (($209) + ($207))|0;
 $211 = (0 - ($210))|0;
 $212 = $211 & 3;
 $213 = (($212) + ($210))|0;
 $214 = (0 - ($213))|0;
 $215 = $214 & 3;
 $216 = (($215) + ($213))|0;
 $217 = (($216) + 4)|0;
 $218 = (0 - ($216))|0;
 $219 = $218 & 3;
 $220 = (($217) + ($219))|0;
 $221 = (0 - ($220))|0;
 $222 = $221 & 3;
 $223 = (($222) + ($220))|0;
 $224 = (($223) + 4)|0;
 $225 = (0 - ($223))|0;
 $226 = $225 & 3;
 $227 = (($224) + ($226))|0;
 $228 = (0 - ($227))|0;
 $229 = $228 & 3;
 $230 = (($229) + ($227))|0;
 $231 = (($230) + 4)|0;
 $232 = (0 - ($230))|0;
 $233 = $232 & 3;
 $234 = (($231) + ($233))|0;
 $235 = (0 - ($234))|0;
 $236 = $235 & 3;
 $237 = (($236) + ($234))|0;
 $238 = (($237) + 4)|0;
 $239 = (0 - ($237))|0;
 $240 = $239 & 3;
 $241 = (($238) + ($240))|0;
 $242 = (0 - ($241))|0;
 $243 = $242 & 3;
 $244 = (($243) + ($241))|0;
 $245 = (($transfer) + 12|0);
 $246 = (0 - ($244))|0;
 $247 = $246 & 3;
 $248 = (($247) + ($244))|0;
 $249 = (($248) + 4)|0;
 $250 = (0 - ($248))|0;
 $251 = $250 & 3;
 $252 = (($249) + ($251))|0;
 HEAP32[$245>>2] = $252;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim14ValueArrayMaskEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim14ValueArrayMask8TransferI8BlobSizeEEvRT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN7mecanim14ValueArrayMask8TransferI9BlobWriteEEvRT_($data,$this);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + -1)|0;
 HEAP32[$17>>2] = $38;
 $39 = (($this) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$23>>2]|0;
 $42 = ($40|0)==($41|0);
 if ($42) {
  $49 = 0;
 } else {
  $43 = $40;
  $44 = $41;
  $45 = (($43) - ($44))|0;
  $46 = $45 << 6;
  $47 = (($46) + -1)|0;
  $49 = $47;
 }
 $48 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($37))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($49))|0;
 $50 = (($$neg2$i$i$i) - ($48))|0;
 $51 = ($50>>>0)>(511);
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (($40) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 __ZdlPv($53);
 $54 = HEAP32[$39>>2]|0;
 $55 = (($54) + -4|0);
 $__new_last2$i$i$i$i$i = $55;
 $56 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($55) + ($56)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $57 = $uglygep3$i$i$i$i$i >>> 2;
 $58 = $57 ^ -1;
 $scevgep4$i$i$i$i$i = (($54) + ($58<<2)|0);
 HEAP32[$39>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim14ValueArrayMask8TransferI9BlobWriteEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i5 = sp;
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,769952,0);
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $0;
 $3 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIbEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,769968,0);
 $5 = (($this) + 12|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$5,769984,0);
 $6 = (($this) + 16|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $6;
 $8 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$8>>2] = $5;
 $9 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIbEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770000,0);
 $10 = (($this) + 24|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$10,770016,0);
 $11 = (($this) + 28|0);
 $12 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $11;
 $13 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$13>>2] = $10;
 $14 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$14>>2] = $12;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIbEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770032,0);
 $15 = (($this) + 36|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$15,770048,0);
 $16 = (($this) + 40|0);
 $17 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $16;
 $18 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$18>>2] = $15;
 $19 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$19>>2] = $17;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIbEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770064,0);
 $20 = (($this) + 48|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$20,770088,0);
 $21 = (($this) + 52|0);
 $22 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $21;
 $23 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$23>>2] = $20;
 $24 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$24>>2] = $22;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIbEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770112,0);
 $25 = (($this) + 60|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$25,770136,0);
 $26 = (($this) + 64|0);
 $27 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5>>2] = $26;
 $28 = (($ArrayTransfer$i5) + 4|0);
 HEAP32[$28>>2] = $25;
 $29 = (($ArrayTransfer$i5) + 8|0);
 HEAP32[$29>>2] = $27;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIbEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i5,770152,0);
 STACKTOP = sp;return;
}
function __ZN7mecanim14ValueArrayMask8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$ = 0, $$55 = 0, $$56 = 0, $$phi$trans$insert = 0, $$phi$trans$insert31 = 0, $$phi$trans$insert33 = 0, $$phi$trans$insert35 = 0, $$phi$trans$insert37 = 0, $$phi$trans$insert39 = 0, $$phi$trans$insert41 = 0, $$phi$trans$insert43 = 0, $$phi$trans$insert45 = 0, $$phi$trans$insert47 = 0, $$phi$trans$insert49 = 0, $$pre = 0, $$pre32 = 0, $$pre34 = 0, $$pre36 = 0, $$pre38 = 0, $$pre40 = 0;
 var $$pre42 = 0, $$pre44 = 0, $$pre46 = 0, $$pre48 = 0, $$pre50 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  $8 = (($7) + 4)|0;
  $9 = (0 - ($7))|0;
  $10 = $9 & 3;
  $11 = (($8) + ($10))|0;
  HEAP32[$3>>2] = $11;
  $14 = $11;
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $14 = $$pre;
 }
 $12 = (($transfer) + 12|0);
 $13 = (0 - ($14))|0;
 $15 = $13 & 3;
 $16 = (($15) + ($14))|0;
 $17 = (($transfer) + 18|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)!=(0);
 $20 = $19 ? 8 : 4;
 $21 = (($16) + ($20))|0;
 HEAP32[$12>>2] = $21;
 $22 = (($transfer) + 17|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $27 = $21;
 } else {
  $25 = (($21) + 4)|0;
  HEAP32[$12>>2] = $25;
  $27 = $25;
 }
 HEAP8[$0>>0] = 0;
 $26 = (0 - ($27))|0;
 $28 = $26 & 3;
 $29 = (($28) + ($27))|0;
 $30 = (($transfer) + 12|0);
 $31 = (0 - ($29))|0;
 $32 = $31 & 3;
 $33 = (($32) + ($29))|0;
 $34 = (($33) + 4)|0;
 $35 = (0 - ($33))|0;
 $36 = $35 & 3;
 $37 = (($34) + ($36))|0;
 HEAP32[$30>>2] = $37;
 $$phi$trans$insert31 = (($transfer) + 18|0);
 $$pre32 = HEAP8[$$phi$trans$insert31>>0]|0;
 $$phi$trans$insert33 = (($transfer) + 17|0);
 $$pre34 = HEAP8[$$phi$trans$insert33>>0]|0;
 $38 = (0 - ($37))|0;
 $39 = $38 & 3;
 $40 = (($39) + ($37))|0;
 $41 = ($$pre32<<24>>24)!=(0);
 $42 = $41 ? 8 : 4;
 $43 = (($40) + ($42))|0;
 $44 = ($$pre34<<24>>24)==(0);
 $45 = (($43) + 4)|0;
 $$ = $44 ? $43 : $45;
 HEAP8[$0>>0] = 0;
 $46 = (0 - ($$))|0;
 $47 = $46 & 3;
 $48 = (($47) + ($$))|0;
 $49 = (($transfer) + 12|0);
 $50 = (0 - ($48))|0;
 $51 = $50 & 3;
 $52 = (($51) + ($48))|0;
 $53 = (($52) + 4)|0;
 $54 = (0 - ($52))|0;
 $55 = $54 & 3;
 $56 = (($53) + ($55))|0;
 HEAP32[$49>>2] = $56;
 $$phi$trans$insert35 = (($transfer) + 18|0);
 $$pre36 = HEAP8[$$phi$trans$insert35>>0]|0;
 $$phi$trans$insert37 = (($transfer) + 17|0);
 $$pre38 = HEAP8[$$phi$trans$insert37>>0]|0;
 $57 = (0 - ($56))|0;
 $58 = $57 & 3;
 $59 = (($58) + ($56))|0;
 $60 = ($$pre36<<24>>24)!=(0);
 $61 = $60 ? 8 : 4;
 $62 = (($59) + ($61))|0;
 $63 = ($$pre38<<24>>24)==(0);
 $64 = (($62) + 4)|0;
 $65 = $63 ? $62 : $64;
 HEAP8[$0>>0] = 0;
 $66 = (0 - ($65))|0;
 $67 = $66 & 3;
 $68 = (($67) + ($65))|0;
 $69 = (($transfer) + 12|0);
 $70 = (0 - ($68))|0;
 $71 = $70 & 3;
 $72 = (($71) + ($68))|0;
 $73 = (($72) + 4)|0;
 $74 = (0 - ($72))|0;
 $75 = $74 & 3;
 $76 = (($73) + ($75))|0;
 HEAP32[$69>>2] = $76;
 $$phi$trans$insert39 = (($transfer) + 18|0);
 $$pre40 = HEAP8[$$phi$trans$insert39>>0]|0;
 $$phi$trans$insert41 = (($transfer) + 17|0);
 $$pre42 = HEAP8[$$phi$trans$insert41>>0]|0;
 $77 = (0 - ($76))|0;
 $78 = $77 & 3;
 $79 = (($78) + ($76))|0;
 $80 = ($$pre40<<24>>24)!=(0);
 $81 = $80 ? 8 : 4;
 $82 = (($79) + ($81))|0;
 $83 = ($$pre42<<24>>24)==(0);
 $84 = (($82) + 4)|0;
 $$55 = $83 ? $82 : $84;
 HEAP8[$0>>0] = 0;
 $85 = (0 - ($$55))|0;
 $86 = $85 & 3;
 $87 = (($86) + ($$55))|0;
 $88 = (($transfer) + 12|0);
 $89 = (0 - ($87))|0;
 $90 = $89 & 3;
 $91 = (($90) + ($87))|0;
 $92 = (($91) + 4)|0;
 $93 = (0 - ($91))|0;
 $94 = $93 & 3;
 $95 = (($92) + ($94))|0;
 HEAP32[$88>>2] = $95;
 $$phi$trans$insert43 = (($transfer) + 18|0);
 $$pre44 = HEAP8[$$phi$trans$insert43>>0]|0;
 $$phi$trans$insert45 = (($transfer) + 17|0);
 $$pre46 = HEAP8[$$phi$trans$insert45>>0]|0;
 $96 = (0 - ($95))|0;
 $97 = $96 & 3;
 $98 = (($97) + ($95))|0;
 $99 = ($$pre44<<24>>24)!=(0);
 $100 = $99 ? 8 : 4;
 $101 = (($98) + ($100))|0;
 $102 = ($$pre46<<24>>24)==(0);
 $103 = (($101) + 4)|0;
 $104 = $102 ? $101 : $103;
 HEAP8[$0>>0] = 0;
 $105 = (0 - ($104))|0;
 $106 = $105 & 3;
 $107 = (($106) + ($104))|0;
 $108 = (($transfer) + 12|0);
 $109 = (0 - ($107))|0;
 $110 = $109 & 3;
 $111 = (($110) + ($107))|0;
 $112 = (($111) + 4)|0;
 $113 = (0 - ($111))|0;
 $114 = $113 & 3;
 $115 = (($112) + ($114))|0;
 HEAP32[$108>>2] = $115;
 $$phi$trans$insert47 = (($transfer) + 18|0);
 $$pre48 = HEAP8[$$phi$trans$insert47>>0]|0;
 $$phi$trans$insert49 = (($transfer) + 17|0);
 $$pre50 = HEAP8[$$phi$trans$insert49>>0]|0;
 $116 = (($transfer) + 12|0);
 $117 = (0 - ($115))|0;
 $118 = $117 & 3;
 $119 = (($118) + ($115))|0;
 $120 = ($$pre48<<24>>24)!=(0);
 $121 = $120 ? 8 : 4;
 $122 = (($119) + ($121))|0;
 $123 = ($$pre50<<24>>24)==(0);
 $124 = (($122) + 4)|0;
 $$56 = $123 ? $122 : $124;
 HEAP8[$0>>0] = 0;
 $125 = (0 - ($$56))|0;
 $126 = $125 & 3;
 $127 = (($126) + ($$56))|0;
 HEAP32[$116>>2] = $127;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsIN7mecanim9animation13BlendingStateILb0EEEE8TransferI8BlobSizeEEvRS3_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$ = 0, $$11 = 0, $$phi$trans$insert = 0, $$phi$trans$insert4 = 0, $$phi$trans$insert6 = 0, $$pre = 0, $$pre5 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  $8 = (($transfer) + 18|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)!=(0);
  $11 = $10 ? 8 : 4;
  $12 = (($7) + ($11))|0;
  HEAP32[$3>>2] = $12;
  $13 = (($transfer) + 17|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $12;
  } else {
   $16 = (($12) + 4)|0;
   HEAP32[$3>>2] = $16;
   $18 = $16;
  }
  $17 = (0 - ($18))|0;
  $19 = $17 & 3;
  $20 = (($19) + ($18))|0;
  HEAP32[$3>>2] = $20;
  $23 = $20;$27 = $9;$31 = $14;
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$phi$trans$insert4 = (($transfer) + 18|0);
  $$pre5 = HEAP8[$$phi$trans$insert4>>0]|0;
  $$phi$trans$insert6 = (($transfer) + 17|0);
  $$pre7 = HEAP8[$$phi$trans$insert6>>0]|0;
  $23 = $$pre;$27 = $$pre5;$31 = $$pre7;
 }
 $21 = (($transfer) + 12|0);
 $22 = (0 - ($23))|0;
 $24 = $22 & 3;
 $25 = (($24) + ($23))|0;
 $26 = ($27<<24>>24)!=(0);
 $28 = $26 ? 8 : 4;
 $29 = (($25) + ($28))|0;
 $30 = ($31<<24>>24)==(0);
 $32 = (($29) + 4)|0;
 $$ = $30 ? $29 : $32;
 $33 = (0 - ($$))|0;
 $34 = $33 & 3;
 $35 = (($34) + ($$))|0;
 HEAP32[$21>>2] = $35;
 $36 = (($transfer) + 12|0);
 $37 = (0 - ($35))|0;
 $38 = $37 & 3;
 $39 = (($38) + ($35))|0;
 $40 = ($27<<24>>24)!=(0);
 $41 = $40 ? 8 : 4;
 $42 = (($39) + ($41))|0;
 $43 = ($31<<24>>24)==(0);
 $44 = (($42) + 4)|0;
 $45 = $43 ? $42 : $44;
 $46 = (0 - ($45))|0;
 $47 = $46 & 3;
 $48 = (($47) + ($45))|0;
 HEAP32[$36>>2] = $48;
 $49 = (0 - ($48))|0;
 $50 = $49 & 3;
 $51 = (($50) + ($48))|0;
 $52 = ($27<<24>>24)!=(0);
 $53 = $52 ? 8 : 4;
 $54 = (($51) + ($53))|0;
 $55 = ($31<<24>>24)==(0);
 $56 = (($54) + 4)|0;
 $$11 = $55 ? $54 : $56;
 $57 = (0 - ($$11))|0;
 $58 = $57 & 3;
 $59 = (($58) + ($$11))|0;
 $60 = (($transfer) + 12|0);
 $61 = (0 - ($59))|0;
 $62 = $61 & 3;
 $63 = (($62) + ($59))|0;
 $64 = (($63) + 4)|0;
 $65 = (0 - ($63))|0;
 $66 = $65 & 3;
 $67 = (($64) + ($66))|0;
 HEAP32[$60>>2] = $67;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18StateMachineMemoryEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduceCopy$i = 0;
 var $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduceCopy$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduceCopy$i+0>>2]=0|0;HEAP32[$reduceCopy$i+4>>2]=0|0;HEAP32[$reduceCopy$i+8>>2]=0|0;
 $30 = (($data) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$33,$reduceCopy$i,4);
 __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18StateMachineMemoryEEEEclERS6_17TransferMetaFlagsR9BlobWrite(0,$data,0,$this);
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduceCopy$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$10>>2]|0;
 $35 = (($34) + -1)|0;
 HEAP32[$10>>2] = $35;
 $36 = (($this) + 32|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$16>>2]|0;
 $39 = ($37|0)==($38|0);
 if ($39) {
  $46 = 0;
 } else {
  $40 = $37;
  $41 = $38;
  $42 = (($40) - ($41))|0;
  $43 = $42 << 6;
  $44 = (($43) + -1)|0;
  $46 = $44;
 }
 $45 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($34))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($46))|0;
 $47 = (($$neg2$i$i$i) - ($45))|0;
 $48 = ($47>>>0)>(511);
 if (!($48)) {
  STACKTOP = sp;return;
 }
 $49 = (($37) + -4|0);
 $50 = HEAP32[$49>>2]|0;
 __ZdlPv($50);
 $51 = HEAP32[$36>>2]|0;
 $52 = (($51) + -4|0);
 $__new_last2$i$i$i$i$i = $52;
 $53 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($52) + ($53)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $54 = $uglygep3$i$i$i$i$i >>> 2;
 $55 = $54 ^ -1;
 $scevgep4$i$i$i$i$i = (($51) + ($55<<2)|0);
 HEAP32[$36>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN34BlobWriteTransferSTLStyleArrayImplI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18StateMachineMemoryEEEEclERS6_17TransferMetaFlagsR9BlobWrite($this,$data,$metaFlags,$transfer) {
 $this = $this|0;
 $data = $data|0;
 $metaFlags = $metaFlags|0;
 $transfer = $transfer|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $i$02 = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$data>>2]|0;
 $5 = $4;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($4) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($transfer)|0);
 $11 = (($transfer) + 22|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 $14 = $13 ? 8 : 4;
 $15 = (($14) + 4)|0;
 $$$i = $10 ? $15 : $14;
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = Math_imul($$$i, $17)|0;
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = $22;
 __ZN9BlobWrite4PushEjPKvj($transfer,$18,$25,4);
 $26 = HEAP32[$data>>2]|0;
 $27 = $26;
 $28 = HEAP32[$26>>2]|0;
 $29 = (($28) + ($27))|0;
 $30 = $29;
 $31 = (($26) + 4|0);
 HEAP32[$31>>2] = $30;
 $32 = HEAP32[$0>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($30) + ($33<<3)|0);
 $35 = HEAP32[$data>>2]|0;
 $36 = $35;
 $37 = HEAP32[$35>>2]|0;
 $38 = (($37) + ($36))|0;
 $39 = $38;
 $40 = (($35) + 4|0);
 HEAP32[$40>>2] = $39;
 $41 = ($39|0)==($34|0);
 if (!($41)) {
  $i$02 = $39;
  while(1) {
   __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim12statemachine18StateMachineMemoryEEEEvRT_PKc17TransferMetaFlags($transfer,$i$02,769776,0);
   $42 = (($i$02) + 8|0);
   $43 = ($42|0)==($34|0);
   if ($43) {
    break;
   } else {
    $i$02 = $42;
   }
  }
 }
 $44 = (($transfer) + 44|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($transfer) + 40|0);
 $47 = (($45) + -1)|0;
 HEAP32[$44>>2] = $47;
 $48 = (($transfer) + 32|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($transfer) + 28|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($49|0)==($51|0);
 if ($52) {
  $59 = 0;
 } else {
  $53 = $49;
  $54 = $51;
  $55 = (($53) - ($54))|0;
  $56 = $55 << 6;
  $57 = (($56) + -1)|0;
  $59 = $57;
 }
 $58 = HEAP32[$46>>2]|0;
 $$neg1$i = (1 - ($45))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($59))|0;
 $60 = (($$neg2$i$i$i) - ($58))|0;
 $61 = ($60>>>0)>(511);
 if (!($61)) {
  STACKTOP = sp;return;
 }
 $62 = (($49) + -4|0);
 $63 = HEAP32[$62>>2]|0;
 __ZdlPv($63);
 $64 = HEAP32[$48>>2]|0;
 $65 = (($64) + -4|0);
 $__new_last2$i$i$i$i$i = $65;
 $66 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($65) + ($66)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $67 = $uglygep3$i$i$i$i$i >>> 2;
 $68 = $67 ^ -1;
 $scevgep4$i$i$i$i$i = (($64) + ($68<<2)|0);
 HEAP32[$48>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferI9OffsetPtrIN7mecanim12statemachine18StateMachineMemoryEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$$i = 0, $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $reduce$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reduce$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)!=(0);
  $8 = $7 ? 8 : 4;
  $9 = (($8) + 4)|0;
  $$$i = $4 ? $9 : $8;
  __ZN9BlobWrite4PushEjPKvj($this,$$$i,$data,4);
 } else {
 }
 $10 = (($this) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + -1)|0;
 $15 = (($14) + ($13))|0;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $15 >>> 8;
 $19 = (($17) + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $15 & 255;
 $22 = (($20) + ($21<<4)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ((($20) + ($21<<4)|0) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23))|0;
 $27 = (0 - ($26))|0;
 $28 = $27 & 3;
 $29 = (($25) + ($28))|0;
 HEAP32[$24>>2] = $29;
 ;HEAP32[$reduce$i+0>>2]=0|0;HEAP32[$reduce$i+4>>2]=0|0;HEAP32[$reduce$i+8>>2]=0|0;
 $30 = HEAP32[$data>>2]|0;
 $31 = ($30|0)!=(0);
 __ZN9BlobWrite15TransferPtrImplEbP14ReduceCopyDataj($this,$31,$reduce$i,4);
 $32 = HEAP32[$data>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = $data;
  $35 = (($32) + ($34))|0;
  $36 = $35;
  $37 = (($data) + 4|0);
  HEAP32[$37>>2] = $36;
  __ZN9BlobWrite8TransferIN7mecanim12statemachine18StateMachineMemoryEEEvRT_PKc17TransferMetaFlags($this,$36,769776,0);
 }
 __ZN9BlobWrite14ReduceCopyImplERK14ReduceCopyDataj($this,$reduce$i,4);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$10>>2]|0;
 $39 = (($38) + -1)|0;
 HEAP32[$10>>2] = $39;
 $40 = (($this) + 32|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$16>>2]|0;
 $43 = ($41|0)==($42|0);
 if ($43) {
  $50 = 0;
 } else {
  $44 = $41;
  $45 = $42;
  $46 = (($44) - ($45))|0;
  $47 = $46 << 6;
  $48 = (($47) + -1)|0;
  $50 = $48;
 }
 $49 = HEAP32[$12>>2]|0;
 $$neg1$i = (1 - ($38))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($50))|0;
 $51 = (($$neg2$i$i$i) - ($49))|0;
 $52 = ($51>>>0)>(511);
 if (!($52)) {
  STACKTOP = sp;return;
 }
 $53 = (($41) + -4|0);
 $54 = HEAP32[$53>>2]|0;
 __ZdlPv($54);
 $55 = HEAP32[$40>>2]|0;
 $56 = (($55) + -4|0);
 $__new_last2$i$i$i$i$i = $56;
 $57 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($56) + ($57)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $58 = $uglygep3$i$i$i$i$i >>> 2;
 $59 = $58 ^ -1;
 $scevgep4$i$i$i$i$i = (($55) + ($59<<2)|0);
 HEAP32[$40>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN9BlobWrite8TransferIN7mecanim12statemachine18StateMachineMemoryEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$0) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $0 = $0|0;
 var $$neg1$i = 0, $$neg2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $sizer$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $sizer$i = sp;
 $1 = (($this) + 20|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($3) {
  $4 = (__ZNK9BlobWrite24HasOffsetPtrWithDebugPtrEv($this)|0);
  $5 = (($this) + 22|0);
  $6 = HEAP8[$5>>0]|0;
  HEAP32[$sizer$i>>2] = 0;
  $7 = (($sizer$i) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($sizer$i) + 12|0);
  $9 = (($sizer$i) + 16|0);
  HEAP8[$9>>0] = 0;
  $10 = (($sizer$i) + 17|0);
  $11 = $4&1;
  HEAP8[$10>>0] = $11;
  $12 = (($sizer$i) + 18|0);
  HEAP8[$12>>0] = $6;
  HEAP32[$8>>2] = 0;
  __ZN7mecanim12statemachine18StateMachineMemory8TransferI8BlobSizeEEvRT_($data,$sizer$i);
  $13 = HEAP32[$8>>2]|0;
  $14 = (0 - ($13))|0;
  $15 = $14 & 3;
  $16 = (($15) + ($13))|0;
  __ZN9BlobWrite4PushEjPKvj($this,$16,$data,4);
 } else {
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + -1)|0;
 $22 = (($21) + ($20))|0;
 $23 = (($this) + 28|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22 >>> 8;
 $26 = (($24) + ($25<<2)|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $22 & 255;
 $29 = (($27) + ($28<<4)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($27) + ($28<<4)|0) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30))|0;
 $34 = (0 - ($33))|0;
 $35 = $34 & 3;
 $36 = (($32) + ($35))|0;
 HEAP32[$31>>2] = $36;
 __ZN7mecanim12statemachine18StateMachineMemory8TransferI9BlobWriteEEvRT_($data,$this);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$17>>2]|0;
 $38 = (($37) + -1)|0;
 HEAP32[$17>>2] = $38;
 $39 = (($this) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$23>>2]|0;
 $42 = ($40|0)==($41|0);
 if ($42) {
  $49 = 0;
 } else {
  $43 = $40;
  $44 = $41;
  $45 = (($43) - ($44))|0;
  $46 = $45 << 6;
  $47 = (($46) + -1)|0;
  $49 = $47;
 }
 $48 = HEAP32[$19>>2]|0;
 $$neg1$i = (1 - ($37))|0;
 $$neg2$i$i$i = (($$neg1$i) + ($49))|0;
 $50 = (($$neg2$i$i$i) - ($48))|0;
 $51 = ($50>>>0)>(511);
 if (!($51)) {
  STACKTOP = sp;return;
 }
 $52 = (($40) + -4|0);
 $53 = HEAP32[$52>>2]|0;
 __ZdlPv($53);
 $54 = HEAP32[$39>>2]|0;
 $55 = (($54) + -4|0);
 $__new_last2$i$i$i$i$i = $55;
 $56 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($55) + ($56)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $57 = $uglygep3$i$i$i$i$i >>> 2;
 $58 = $57 ^ -1;
 $scevgep4$i$i$i$i$i = (($54) + ($58<<2)|0);
 HEAP32[$39>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine18StateMachineMemory8TransferI9BlobWriteEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,770744,0);
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $0;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN9BlobWrite8TransferI22OffsetPtrArrayTransferIfEEEvRT_PKc17TransferMetaFlags($transfer,$ArrayTransfer$i,770768,0);
 $5 = (($this) + 12|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$5,770800,0);
 $6 = (($this) + 16|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$6,770824,0);
 $7 = (($this) + 20|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$7,770848,0);
 $8 = (($this) + 24|0);
 __ZN9BlobWrite8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$8,770872,0);
 $9 = (($this) + 28|0);
 __ZN9BlobWrite8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$9,770896,0);
 $10 = (($this) + 32|0);
 __ZN9BlobWrite8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$10,770928,0);
 $11 = (($this) + 36|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$11,770952,0);
 $12 = (($this) + 40|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,770984,0);
 $13 = (($this) + 44|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,771008,0);
 $14 = (($this) + 48|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$14,771032,0);
 $15 = (($this) + 52|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$15,771056,0);
 $16 = (($this) + 56|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,771080,0);
 $17 = (($this) + 60|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$17,771104,0);
 $18 = (($this) + 64|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$18,771128,0);
 $19 = (($this) + 68|0);
 __ZN9BlobWrite8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$19,771152,0);
 $20 = (($this) + 72|0);
 __ZN9BlobWrite8TransferIbEEvRT_PKc17TransferMetaFlags($transfer,$20,771176,0);
 $21 = (($this) + 73|0);
 __ZN9BlobWrite8TransferIbEEvRT_PKc17TransferMetaFlags($transfer,$21,771208,0);
 $22 = (($this) + 74|0);
 __ZN9BlobWrite8TransferIbEEvRT_PKc17TransferMetaFlags($transfer,$22,771224,0);
 $23 = (($this) + 75|0);
 __ZN9BlobWrite8TransferIbEEvRT_PKc17TransferMetaFlags($transfer,$23,771248,0);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine18StateMachineMemory8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  $8 = (($7) + 4)|0;
  $9 = (0 - ($7))|0;
  $10 = $9 & 3;
  $11 = (($8) + ($10))|0;
  HEAP32[$3>>2] = $11;
  $14 = $11;
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $14 = $$pre;
 }
 $12 = (($transfer) + 12|0);
 $13 = (0 - ($14))|0;
 $15 = $13 & 3;
 $16 = (($15) + ($14))|0;
 $17 = (($transfer) + 18|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)!=(0);
 $20 = $19 ? 8 : 4;
 $21 = (($16) + ($20))|0;
 HEAP32[$12>>2] = $21;
 $22 = (($transfer) + 17|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $27 = $21;
 } else {
  $25 = (($21) + 4)|0;
  HEAP32[$12>>2] = $25;
  $27 = $25;
 }
 HEAP8[$0>>0] = 0;
 $26 = (0 - ($27))|0;
 $28 = $26 & 3;
 $29 = (($28) + ($27))|0;
 $30 = (0 - ($29))|0;
 $31 = $30 & 3;
 $32 = (($31) + ($29))|0;
 $33 = (($32) + 4)|0;
 $34 = (0 - ($32))|0;
 $35 = $34 & 3;
 $36 = (($33) + ($35))|0;
 $37 = (0 - ($36))|0;
 $38 = $37 & 3;
 $39 = (($38) + ($36))|0;
 $40 = (($39) + 4)|0;
 $41 = (0 - ($39))|0;
 $42 = $41 & 3;
 $43 = (($40) + ($42))|0;
 $44 = (0 - ($43))|0;
 $45 = $44 & 3;
 $46 = (($45) + ($43))|0;
 $47 = (($46) + 4)|0;
 $48 = (0 - ($46))|0;
 $49 = $48 & 3;
 $50 = (($47) + ($49))|0;
 $51 = (0 - ($50))|0;
 $52 = $51 & 3;
 $53 = (($52) + ($50))|0;
 $54 = (($53) + 4)|0;
 $55 = (0 - ($53))|0;
 $56 = $55 & 3;
 $57 = (($54) + ($56))|0;
 $58 = (0 - ($57))|0;
 $59 = $58 & 3;
 $60 = (($59) + ($57))|0;
 $61 = (($60) + 4)|0;
 $62 = (0 - ($60))|0;
 $63 = $62 & 3;
 $64 = (($61) + ($63))|0;
 $65 = (0 - ($64))|0;
 $66 = $65 & 3;
 $67 = (($66) + ($64))|0;
 $68 = (($67) + 4)|0;
 $69 = (0 - ($67))|0;
 $70 = $69 & 3;
 $71 = (($68) + ($70))|0;
 $72 = (0 - ($71))|0;
 $73 = $72 & 3;
 $74 = (($73) + ($71))|0;
 $75 = (($74) + 4)|0;
 $76 = (0 - ($74))|0;
 $77 = $76 & 3;
 $78 = (($75) + ($77))|0;
 $79 = (0 - ($78))|0;
 $80 = $79 & 3;
 $81 = (($80) + ($78))|0;
 $82 = (($81) + 4)|0;
 $83 = (0 - ($81))|0;
 $84 = $83 & 3;
 $85 = (($82) + ($84))|0;
 $86 = (0 - ($85))|0;
 $87 = $86 & 3;
 $88 = (($87) + ($85))|0;
 $89 = (($88) + 4)|0;
 $90 = (0 - ($88))|0;
 $91 = $90 & 3;
 $92 = (($89) + ($91))|0;
 $93 = (0 - ($92))|0;
 $94 = $93 & 3;
 $95 = (($94) + ($92))|0;
 $96 = (($95) + 4)|0;
 $97 = (0 - ($95))|0;
 $98 = $97 & 3;
 $99 = (($96) + ($98))|0;
 $100 = (0 - ($99))|0;
 $101 = $100 & 3;
 $102 = (($101) + ($99))|0;
 $103 = (($102) + 4)|0;
 $104 = (0 - ($102))|0;
 $105 = $104 & 3;
 $106 = (($103) + ($105))|0;
 $107 = (0 - ($106))|0;
 $108 = $107 & 3;
 $109 = (($108) + ($106))|0;
 $110 = (($109) + 4)|0;
 $111 = (0 - ($109))|0;
 $112 = $111 & 3;
 $113 = (($110) + ($112))|0;
 $114 = (0 - ($113))|0;
 $115 = $114 & 3;
 $116 = (($115) + ($113))|0;
 $117 = (($116) + 4)|0;
 $118 = (0 - ($116))|0;
 $119 = $118 & 3;
 $120 = (($117) + ($119))|0;
 $121 = (0 - ($120))|0;
 $122 = $121 & 3;
 $123 = (($122) + ($120))|0;
 $124 = (($123) + 4)|0;
 $125 = (0 - ($123))|0;
 $126 = $125 & 3;
 $127 = (($124) + ($126))|0;
 $128 = (0 - ($127))|0;
 $129 = $128 & 3;
 $130 = (($129) + ($127))|0;
 $131 = (($130) + 4)|0;
 $132 = (0 - ($130))|0;
 $133 = $132 & 3;
 $134 = (($131) + ($133))|0;
 $135 = (($transfer) + 12|0);
 $136 = (($134) + 4)|0;
 HEAP32[$135>>2] = $136;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation16ControllerMemory8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$ = 0, $$23 = 0, $$phi$trans$insert = 0, $$phi$trans$insert16 = 0, $$phi$trans$insert18 = 0, $$pre = 0, $$pre17 = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  $8 = (($7) + 4)|0;
  $9 = (0 - ($7))|0;
  $10 = $9 & 3;
  $11 = (($8) + ($10))|0;
  HEAP32[$3>>2] = $11;
  $14 = $11;
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $14 = $$pre;
 }
 $12 = (($transfer) + 12|0);
 $13 = (0 - ($14))|0;
 $15 = $13 & 3;
 $16 = (($15) + ($14))|0;
 $17 = (($transfer) + 18|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)!=(0);
 $20 = $19 ? 8 : 4;
 $21 = (($16) + ($20))|0;
 HEAP32[$12>>2] = $21;
 $22 = (($transfer) + 17|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $27 = $21;
 } else {
  $25 = (($21) + 4)|0;
  HEAP32[$12>>2] = $25;
  $27 = $25;
 }
 HEAP8[$0>>0] = 0;
 $26 = (0 - ($27))|0;
 $28 = $26 & 3;
 $29 = (($28) + ($27))|0;
 $30 = (($transfer) + 12|0);
 $31 = (0 - ($29))|0;
 $32 = $31 & 3;
 $33 = (($32) + ($29))|0;
 $34 = (($33) + 4)|0;
 $35 = (0 - ($33))|0;
 $36 = $35 & 3;
 $37 = (($34) + ($36))|0;
 HEAP32[$30>>2] = $37;
 $$phi$trans$insert16 = (($transfer) + 18|0);
 $$pre17 = HEAP8[$$phi$trans$insert16>>0]|0;
 $$phi$trans$insert18 = (($transfer) + 17|0);
 $$pre19 = HEAP8[$$phi$trans$insert18>>0]|0;
 $38 = (($transfer) + 12|0);
 $39 = (0 - ($37))|0;
 $40 = $39 & 3;
 $41 = (($40) + ($37))|0;
 $42 = ($$pre17<<24>>24)!=(0);
 $43 = $42 ? 8 : 4;
 $44 = (($41) + ($43))|0;
 $45 = ($$pre19<<24>>24)==(0);
 $46 = (($44) + 4)|0;
 $$ = $45 ? $44 : $46;
 HEAP8[$0>>0] = 0;
 $47 = (0 - ($$))|0;
 $48 = $47 & 3;
 $49 = (($48) + ($$))|0;
 HEAP32[$38>>2] = $49;
 $50 = (($transfer) + 12|0);
 $51 = (0 - ($49))|0;
 $52 = $51 & 3;
 $53 = (($52) + ($49))|0;
 $54 = ($$pre17<<24>>24)!=(0);
 $55 = $54 ? 8 : 4;
 $56 = (($53) + ($55))|0;
 $57 = ($$pre19<<24>>24)==(0);
 $58 = (($56) + 4)|0;
 $59 = $57 ? $56 : $58;
 HEAP8[$0>>0] = 0;
 $60 = (0 - ($59))|0;
 $61 = $60 & 3;
 $62 = (($61) + ($59))|0;
 HEAP32[$50>>2] = $62;
 $63 = (($transfer) + 12|0);
 $64 = (0 - ($62))|0;
 $65 = $64 & 3;
 $66 = (($65) + ($62))|0;
 $67 = ($$pre17<<24>>24)!=(0);
 $68 = $67 ? 8 : 4;
 $69 = (($66) + ($68))|0;
 $70 = ($$pre19<<24>>24)==(0);
 $71 = (($69) + 4)|0;
 $$23 = $70 ? $69 : $71;
 HEAP8[$0>>0] = 0;
 $72 = (0 - ($$23))|0;
 $73 = $72 & 3;
 $74 = (($73) + ($$23))|0;
 HEAP32[$63>>2] = $74;
 $75 = (0 - ($74))|0;
 $76 = $75 & 3;
 $77 = (($76) + ($74))|0;
 $78 = ($$pre17<<24>>24)!=(0);
 $79 = $78 ? 8 : 4;
 $80 = (($77) + ($79))|0;
 $81 = ($$pre19<<24>>24)==(0);
 $82 = (($80) + 4)|0;
 $83 = $81 ? $80 : $82;
 $84 = (0 - ($83))|0;
 $85 = $84 & 3;
 $86 = (($85) + ($83))|0;
 $87 = (($transfer) + 12|0);
 $88 = (0 - ($86))|0;
 $89 = $88 & 3;
 $90 = (($89) + ($86))|0;
 $91 = (($90) + 4)|0;
 $92 = (0 - ($90))|0;
 $93 = $92 & 3;
 $94 = (($91) + ($93))|0;
 HEAP32[$87>>2] = $94;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12AvatarMemory8TransferI8BlobSizeEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert = 0, $$pr4 = 0, $$pr5 = 0, $$pr6 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($transfer) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (0 - ($4))|0;
  $6 = $5 & 3;
  $7 = (($6) + ($4))|0;
  $8 = (($transfer) + 18|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($9<<24>>24)!=(0);
  $11 = $10 ? 8 : 4;
  $12 = (($7) + ($11))|0;
  HEAP32[$3>>2] = $12;
  $13 = (($transfer) + 17|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $12;
  } else {
   $16 = (($12) + 4)|0;
   HEAP32[$3>>2] = $16;
   $18 = $16;
  }
  $17 = (0 - ($18))|0;
  $19 = $17 & 3;
  $20 = (($19) + ($18))|0;
  HEAP32[$3>>2] = $20;
  $24 = $20;
 } else {
  HEAP8[$0>>0] = 0;
  $$phi$trans$insert = (($transfer) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $24 = $$pre;
 }
 $21 = (($this) + 8|0);
 $22 = (($transfer) + 12|0);
 $23 = (0 - ($24))|0;
 $25 = $23 & 3;
 $26 = (($25) + ($24))|0;
 HEAP32[$22>>2] = $26;
 __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($21,$transfer);
 $27 = HEAP32[$22>>2]|0;
 $28 = (0 - ($27))|0;
 $29 = $28 & 3;
 $30 = (($29) + ($27))|0;
 HEAP32[$22>>2] = $30;
 $$pr4 = HEAP8[$0>>0]|0;
 $31 = ($$pr4<<24>>24)==(0);
 if ($31) {
  $32 = (($this) + 56|0);
  $33 = (($transfer) + 12|0);
  $34 = (0 - ($30))|0;
  $35 = $34 & 3;
  $36 = (($35) + ($30))|0;
  HEAP32[$33>>2] = $36;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($32,$transfer);
  $37 = HEAP32[$33>>2]|0;
  $38 = (0 - ($37))|0;
  $39 = $38 & 3;
  $40 = (($39) + ($37))|0;
  HEAP32[$33>>2] = $40;
  $$pr5 = HEAP8[$0>>0]|0;
  $41 = ($$pr5<<24>>24)==(0);
  if ($41) {
   $45 = $40;
   label = 10;
  } else {
   HEAP8[$0>>0] = 0;
   $55 = $40;
  }
 } else {
  HEAP8[$0>>0] = 0;
  $45 = $30;
  label = 10;
 }
 if ((label|0) == 10) {
  $42 = (($this) + 104|0);
  $43 = (($transfer) + 12|0);
  $44 = (0 - ($45))|0;
  $46 = $44 & 3;
  $47 = (($46) + ($45))|0;
  HEAP32[$43>>2] = $47;
  __ZN15SerializeTraitsIN4math5xformEE8TransferI8BlobSizeEEvRS1_RT_($42,$transfer);
  $48 = HEAP32[$43>>2]|0;
  $49 = (0 - ($48))|0;
  $50 = $49 & 3;
  $51 = (($50) + ($48))|0;
  HEAP32[$43>>2] = $51;
  $$pr6 = HEAP8[$0>>0]|0;
  $52 = ($$pr6<<24>>24)==(0);
  if ($52) {
   $55 = $51;
  } else {
   HEAP8[$0>>0] = 0;
   $90 = $51;
   $89 = (0 - ($90))|0;
   $91 = $89 & 3;
   $92 = (($91) + ($90))|0;
   $93 = (($92) + 4)|0;
   $94 = (0 - ($92))|0;
   $95 = $94 & 3;
   $96 = (($93) + ($95))|0;
   $97 = (($transfer) + 12|0);
   $98 = (($96) + 2)|0;
   HEAP32[$97>>2] = $98;
   STACKTOP = sp;return;
  }
 }
 $53 = (($transfer) + 12|0);
 $54 = (0 - ($55))|0;
 $56 = $54 & 3;
 $57 = (($56) + ($55))|0;
 $58 = (0 - ($57))|0;
 $59 = $58 & 3;
 $60 = (($59) + ($57))|0;
 $61 = (($60) + 4)|0;
 $62 = (0 - ($60))|0;
 $63 = $62 & 3;
 $64 = (($61) + ($63))|0;
 $65 = (0 - ($64))|0;
 $66 = $65 & 3;
 $67 = (($66) + ($64))|0;
 $68 = (($67) + 4)|0;
 $69 = (0 - ($67))|0;
 $70 = $69 & 3;
 $71 = (($68) + ($70))|0;
 $72 = (0 - ($71))|0;
 $73 = $72 & 3;
 $74 = (($73) + ($71))|0;
 $75 = (($74) + 4)|0;
 $76 = (0 - ($74))|0;
 $77 = $76 & 3;
 $78 = (($75) + ($77))|0;
 $79 = (0 - ($78))|0;
 $80 = $79 & 3;
 $81 = (($80) + ($78))|0;
 $82 = (($81) + 4)|0;
 $83 = (0 - ($81))|0;
 $84 = $83 & 3;
 $85 = (($82) + ($84))|0;
 $86 = (0 - ($85))|0;
 $87 = $86 & 3;
 $88 = (($87) + ($85))|0;
 HEAP32[$53>>2] = $88;
 $90 = $88;
 $89 = (0 - ($90))|0;
 $91 = $89 & 3;
 $92 = (($91) + ($90))|0;
 $93 = (($92) + 4)|0;
 $94 = (0 - ($92))|0;
 $95 = $94 & 3;
 $96 = (($93) + ($95))|0;
 $97 = (($transfer) + 12|0);
 $98 = (($96) + 2)|0;
 HEAP32[$97>>2] = $98;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI25StateMachineBehaviourInfoNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i17 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i8 = 0, $$012$i$i = 0, $$03$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $__first3$i1 = 0, $__growing$0$off0 = 0;
 var $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i13 = 0, $scevgep$i3 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep5$i = 0, $scevgep5$i10 = 0, $scevgep7$i$i = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i15 = 0, $uglygep$i5 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep4$i = 0, $uglygep4$i6 = 0;
 var $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($3>>>0)>($10>>>0);
 if ($11) {
  $42 = ($6|0)==(0|0);
  if ($42) {
   $51 = $5;
  } else {
   $43 = (($this) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==($6|0);
   if (!($45)) {
    $scevgep$i$i$i$i = (($44) + -4|0);
    $46 = (0 - ($8))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($46)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $47 = $uglygep3$i$i$i$i >>> 2;
    $48 = $47 ^ -1;
    $scevgep4$i$i$i$i = (($44) + ($48<<2)|0);
    HEAP32[$43>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($6);
   HEAP32[$4>>2] = 0;
   HEAP32[$43>>2] = 0;
   HEAP32[$this>>2] = 0;
   $51 = 0;
  }
  $49 = ($3>>>0)>(1073741823);
  if ($49) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $50 = $51;
  $52 = $50 >> 2;
  $53 = ($52>>>0)<(536870911);
  if ($53) {
   $54 = $50 >> 1;
   $55 = ($54>>>0)<($3>>>0);
   $56 = $55 ? $3 : $54;
   $57 = ($56>>>0)>(1073741823);
   if ($57) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i17 = $56;
   }
  } else {
   $$0$i17 = 1073741823;
  }
  $58 = $$0$i17 << 2;
  $59 = (__Znwj($58)|0);
  $60 = (($this) + 4|0);
  HEAP32[$60>>2] = $59;
  HEAP32[$this>>2] = $59;
  $61 = (($59) + ($$0$i17<<2)|0);
  HEAP32[$4>>2] = $61;
  $62 = ($__first|0)==($__last|0);
  if ($62) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($__last) + -4|0);
  $63 = (0 - ($1))|0;
  $uglygep$i = (($scevgep$i) + ($63)|0);
  $uglygep4$i = $uglygep$i;
  $64 = $uglygep4$i >>> 2;
  $$01$i = $__first;$66 = $59;
  while(1) {
   $65 = ($66|0)==(0|0);
   if (!($65)) {
    $67 = HEAP32[$$01$i>>2]|0;
    HEAP32[$66>>2] = $67;
   }
   $68 = (($66) + 4|0);
   $69 = (($$01$i) + 4|0);
   $70 = ($69|0)==($__last|0);
   if ($70) {
    break;
   } else {
    $$01$i = $69;$66 = $68;
   }
  }
  $71 = (($64) + 1)|0;
  $scevgep5$i = (($59) + ($71<<2)|0);
  HEAP32[$60>>2] = $scevgep5$i;
  STACKTOP = sp;return;
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = $15 >> 2;
 $17 = ($3>>>0)>($16>>>0);
 if ($17) {
  $18 = (($__first) + ($16<<2)|0);
  $20 = $18;$__growing$0$off0 = 1;
 } else {
  $20 = $__last;$__growing$0$off0 = 0;
 }
 $19 = ($20|0)==($__first|0);
 if ($19) {
  $$0$lcssa$i$i = $6;
 } else {
  $scevgep$i$i13 = (($20) + -4|0);
  $21 = (0 - ($1))|0;
  $uglygep$i$i15 = (($scevgep$i$i13) + ($21)|0);
  $uglygep6$i$i = $uglygep$i$i15;
  $$012$i$i = $__first;$$03$i$i = $6;
  while(1) {
   $22 = HEAP32[$$012$i$i>>2]|0;
   HEAP32[$$03$i$i>>2] = $22;
   $23 = (($$012$i$i) + 4|0);
   $24 = (($$03$i$i) + 4|0);
   $25 = ($23|0)==($20|0);
   if ($25) {
    break;
   } else {
    $$012$i$i = $23;$$03$i$i = $24;
   }
  }
  $26 = $uglygep6$i$i >>> 2;
  $27 = (($26) + 1)|0;
  $scevgep7$i$i = (($6) + ($27<<2)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if (!($__growing$0$off0)) {
  $38 = ($13|0)==($$0$lcssa$i$i|0);
  if ($38) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($13) + -4|0);
  $39 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($39)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $40 = $uglygep3$i$i >>> 2;
  $41 = $40 ^ -1;
  $scevgep4$i$i = (($13) + ($41<<2)|0);
  HEAP32[$12>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $28 = ($20|0)==($__last|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $__first3$i1 = $20;
 $scevgep$i3 = (($__last) + -4|0);
 $29 = (0 - ($__first3$i1))|0;
 $uglygep$i5 = (($scevgep$i3) + ($29)|0);
 $uglygep4$i6 = $uglygep$i5;
 $30 = $uglygep4$i6 >>> 2;
 $$01$i8 = $20;$32 = $13;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   $33 = HEAP32[$$01$i8>>2]|0;
   HEAP32[$32>>2] = $33;
  }
  $34 = (($32) + 4|0);
  $35 = (($$01$i8) + 4|0);
  $36 = ($35|0)==($__last|0);
  if ($36) {
   break;
  } else {
   $$01$i8 = $35;$32 = $34;
  }
 }
 $37 = (($30) + 1)|0;
 $scevgep5$i10 = (($13) + ($37<<2)|0);
 HEAP32[$12>>2] = $scevgep5$i10;
 STACKTOP = sp;return;
}
function __ZN8Animator8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 __ZN4PPtrI6AvatarE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 60|0);
 __ZN4PPtrI25RuntimeAnimatorControllerE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($1,$transfer);
 $2 = (($this) + 48|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = HEAP32[$2>>2]|0;
  HEAP32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre5;
 }
 $10 = (($this) + 52|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)<($14>>>0);
 if ($13) {
  $15 = HEAP32[$10>>2]|0;
  HEAP32[$12>>2] = $15;
  HEAP32[$3>>2] = $11;
  $18 = $11;$20 = $14;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$10,4);
  $$pre6 = HEAP32[$3>>2]|0;
  $$pre7 = HEAP32[$6>>2]|0;
  $18 = $$pre6;$20 = $$pre7;
 }
 $16 = (($this) + 345|0);
 $17 = (($18) + 1|0);
 $19 = ($17>>>0)<($20>>>0);
 if ($19) {
  $21 = HEAP8[$16>>0]|0;
  HEAP8[$18>>0] = $21;
  $22 = HEAP32[$3>>2]|0;
  $23 = (($22) + 1|0);
  HEAP32[$3>>2] = $23;
  $26 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$16,1);
  $$pre8 = HEAP32[$3>>2]|0;
  $26 = $$pre8;
 }
 $24 = (($this) + 346|0);
 $25 = (($26) + 1|0);
 $27 = HEAP32[$6>>2]|0;
 $28 = ($25>>>0)<($27>>>0);
 if ($28) {
  $29 = HEAP8[$24>>0]|0;
  HEAP8[$26>>0] = $29;
  $30 = HEAP32[$3>>2]|0;
  $31 = (($30) + 1|0);
  HEAP32[$3>>2] = $31;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$24,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $32 = (($this) + 465|0);
 $33 = HEAP32[$3>>2]|0;
 $34 = (($33) + 1|0);
 $35 = HEAP32[$6>>2]|0;
 $36 = ($34>>>0)<($35>>>0);
 if ($36) {
  $37 = HEAP8[$32>>0]|0;
  HEAP8[$33>>0] = $37;
  $38 = HEAP32[$3>>2]|0;
  $39 = (($38) + 1|0);
  HEAP32[$3>>2] = $39;
  $42 = $39;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$32,1);
  $$pre9 = HEAP32[$3>>2]|0;
  $42 = $$pre9;
 }
 $40 = (($this) + 464|0);
 $41 = (($42) + 1|0);
 $43 = HEAP32[$6>>2]|0;
 $44 = ($41>>>0)<($43>>>0);
 if ($44) {
  $45 = HEAP8[$40>>0]|0;
  HEAP8[$42>>0] = $45;
  $46 = HEAP32[$3>>2]|0;
  $47 = (($46) + 1|0);
  HEAP32[$3>>2] = $47;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$40,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI6AvatarE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN8Animator8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre10 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 __ZN4PPtrI6AvatarE8TransferI18StreamedBinaryReadILb1EEEEvRT_($0,$transfer);
 $1 = (($this) + 60|0);
 __ZN4PPtrI25RuntimeAnimatorControllerE8TransferI18StreamedBinaryReadILb1EEEEvRT_($1,$transfer);
 $2 = (($this) + 48|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre$i$i$i = HEAP32[$2>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre6 = HEAP32[$6>>2]|0;
  $10 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre6;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $10 = $9;$14 = $5;$16 = $7;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$2>>2] = $11;
 $12 = (($this) + 52|0);
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$12,4);
  $$pre$i$i$i1 = HEAP32[$12>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $$pre8 = HEAP32[$6>>2]|0;
  $18 = $$pre$i$i$i1;$22 = $$pre7;$24 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$12>>2] = $17;
  HEAP32[$3>>2] = $13;
  $18 = $17;$22 = $13;$24 = $16;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$12>>2] = $19;
 $20 = (($this) + 345|0);
 $21 = (($22) + 1|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$20,1);
  $$pre9 = HEAP32[$3>>2]|0;
  $30 = $$pre9;
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$3>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$3>>2] = $27;
  $30 = $27;
 }
 $28 = (($this) + 346|0);
 $29 = (($30) + 1|0);
 $31 = HEAP32[$6>>2]|0;
 $32 = ($29>>>0)>($31>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$28,1);
 } else {
  $33 = HEAP8[$30>>0]|0;
  HEAP8[$28>>0] = $33;
  $34 = HEAP32[$3>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$3>>2] = $35;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $36 = (($this) + 465|0);
 $37 = HEAP32[$3>>2]|0;
 $38 = (($37) + 1|0);
 $39 = HEAP32[$6>>2]|0;
 $40 = ($38>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$36,1);
  $$pre10 = HEAP32[$3>>2]|0;
  $46 = $$pre10;
 } else {
  $41 = HEAP8[$37>>0]|0;
  HEAP8[$36>>0] = $41;
  $42 = HEAP32[$3>>2]|0;
  $43 = (($42) + 1|0);
  HEAP32[$3>>2] = $43;
  $46 = $43;
 }
 $44 = (($this) + 464|0);
 $45 = (($46) + 1|0);
 $47 = HEAP32[$6>>2]|0;
 $48 = ($45>>>0)>($47>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$44,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $49 = HEAP8[$46>>0]|0;
  HEAP8[$44>>0] = $49;
  $50 = HEAP32[$3>>2]|0;
  $51 = (($50) + 1|0);
  HEAP32[$3>>2] = $51;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI6AvatarE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN8Animator8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 __ZN4PPtrI6AvatarE8TransferI18StreamedBinaryReadILb0EEEEvRT_($0,$transfer);
 $1 = (($this) + 60|0);
 __ZN4PPtrI25RuntimeAnimatorControllerE8TransferI18StreamedBinaryReadILb0EEEEvRT_($1,$transfer);
 $2 = (($this) + 48|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 if ($8) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre5;
 } else {
  $9 = HEAP32[$4>>2]|0;
  HEAP32[$2>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 }
 $10 = (($this) + 52|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$10,4);
  $$pre6 = HEAP32[$3>>2]|0;
  $$pre7 = HEAP32[$6>>2]|0;
  $18 = $$pre6;$20 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$10>>2] = $15;
  HEAP32[$3>>2] = $11;
  $18 = $11;$20 = $14;
 }
 $16 = (($this) + 345|0);
 $17 = (($18) + 1|0);
 $19 = ($17>>>0)>($20>>>0);
 if ($19) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$16,1);
  $$pre8 = HEAP32[$3>>2]|0;
  $26 = $$pre8;
 } else {
  $21 = HEAP8[$18>>0]|0;
  HEAP8[$16>>0] = $21;
  $22 = HEAP32[$3>>2]|0;
  $23 = (($22) + 1|0);
  HEAP32[$3>>2] = $23;
  $26 = $23;
 }
 $24 = (($this) + 346|0);
 $25 = (($26) + 1|0);
 $27 = HEAP32[$6>>2]|0;
 $28 = ($25>>>0)>($27>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$24,1);
 } else {
  $29 = HEAP8[$26>>0]|0;
  HEAP8[$24>>0] = $29;
  $30 = HEAP32[$3>>2]|0;
  $31 = (($30) + 1|0);
  HEAP32[$3>>2] = $31;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $32 = (($this) + 465|0);
 $33 = HEAP32[$3>>2]|0;
 $34 = (($33) + 1|0);
 $35 = HEAP32[$6>>2]|0;
 $36 = ($34>>>0)>($35>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$32,1);
  $$pre9 = HEAP32[$3>>2]|0;
  $42 = $$pre9;
 } else {
  $37 = HEAP8[$33>>0]|0;
  HEAP8[$32>>0] = $37;
  $38 = HEAP32[$3>>2]|0;
  $39 = (($38) + 1|0);
  HEAP32[$3>>2] = $39;
  $42 = $39;
 }
 $40 = (($this) + 464|0);
 $41 = (($42) + 1|0);
 $43 = HEAP32[$6>>2]|0;
 $44 = ($41>>>0)>($43>>>0);
 if ($44) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$40,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $45 = HEAP8[$42>>0]|0;
  HEAP8[$40>>0] = $45;
  $46 = HEAP32[$3>>2]|0;
  $47 = (($46) + 1|0);
  HEAP32[$3>>2] = $47;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI6AvatarE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN8Animator8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i14 = 0, $$sum$i$i$i$i$i19 = 0, $$sum$i$i$i$i$i4 = 0, $$sum$i$i$i$i$i9 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i10 = 0, $$sum1$i$i$i$i$i15 = 0, $$sum1$i$i$i$i$i20 = 0, $$sum1$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $animatePhysics = 0, $converter$i$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i18 = sp;
 $animatePhysics = sp + 4|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,3);
 __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771272,771544,$converter$i$i18,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN4PPtrI6AvatarE8TransferI14SafeBinaryReadEEvRT_($0,$transfer);
  } else {
   $4 = HEAP32[$converter$i$i18>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 60|0);
 $7 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771288,771512,$converter$i$i18,1)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = ($7|0)>(0);
  if ($9) {
   __ZN4PPtrI25RuntimeAnimatorControllerE8TransferI14SafeBinaryReadEEvRT_($6,$transfer);
  } else {
   $10 = HEAP32[$converter$i$i18>>2]|0;
   $11 = ($10|0)==(0|0);
   if (!($11)) {
    (FUNCTION_TABLE_iii[$10 & 4095]($6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $12 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$12,771304,0);
 $13 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$13,771320,0);
 $14 = (($this) + 345|0);
 $15 = HEAP32[580544>>2]|0;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771336,$15,$converter$i$i18,0)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  do {
   if ($18) {
    $19 = (($transfer) + 12|0);
    $20 = (($transfer) + 80|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($transfer) + 16|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($transfer) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($transfer) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = Math_imul($29, $27)|0;
    $$sum$i$i$i$i$i = (($23) - ($30))|0;
    $31 = (($25) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$19>>2] = $31;
    $32 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($32)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $33 = (($25) + ($$sum1$i$i$i$i$i)|0);
     $34 = (($transfer) + 20|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = ($33>>>0)>($35>>>0);
     if (!($36)) {
      $37 = HEAP8[$31>>0]|0;
      HEAP8[$14>>0] = $37;
      $38 = HEAP32[$19>>2]|0;
      $39 = (($38) + 1|0);
      HEAP32[$19>>2] = $39;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($19,$14,1);
   } else {
    $40 = HEAP32[$converter$i$i18>>2]|0;
    $41 = ($40|0)==(0|0);
    if (!($41)) {
     (FUNCTION_TABLE_iii[$40 & 4095]($14,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $42 = (($this) + 346|0);
 $43 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771360,$15,$converter$i$i18,0)|0);
 $44 = ($43|0)==(0);
 if (!($44)) {
  $45 = ($43|0)>(0);
  do {
   if ($45) {
    $46 = (($transfer) + 12|0);
    $47 = (($transfer) + 80|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($transfer) + 16|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($transfer) + 28|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($transfer) + 32|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = Math_imul($56, $54)|0;
    $$sum$i$i$i$i$i4 = (($50) - ($57))|0;
    $58 = (($52) + ($$sum$i$i$i$i$i4)|0);
    HEAP32[$46>>2] = $58;
    $59 = ($$sum$i$i$i$i$i4|0)<(0);
    if (!($59)) {
     $$sum1$i$i$i$i$i5 = (($$sum$i$i$i$i$i4) + 1)|0;
     $60 = (($52) + ($$sum1$i$i$i$i$i5)|0);
     $61 = (($transfer) + 20|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($60>>>0)>($62>>>0);
     if (!($63)) {
      $64 = HEAP8[$58>>0]|0;
      HEAP8[$42>>0] = $64;
      $65 = HEAP32[$46>>2]|0;
      $66 = (($65) + 1|0);
      HEAP32[$46>>2] = $66;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($46,$42,1);
   } else {
    $67 = HEAP32[$converter$i$i18>>2]|0;
    $68 = ($67|0)==(0|0);
    if (!($68)) {
     (FUNCTION_TABLE_iii[$67 & 4095]($42,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $69 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,2)|0);
 if ($69) {
  HEAP8[$animatePhysics>>0] = 0;
  $70 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771392,$15,$converter$i$i18,0)|0);
  $71 = ($70|0)==(0);
  if (!($71)) {
   $72 = ($70|0)>(0);
   do {
    if ($72) {
     $73 = (($transfer) + 12|0);
     $74 = (($transfer) + 80|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($75) + 12|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($transfer) + 16|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = (($transfer) + 28|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = (($transfer) + 32|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = Math_imul($83, $81)|0;
     $$sum$i$i$i$i$i9 = (($77) - ($84))|0;
     $85 = (($79) + ($$sum$i$i$i$i$i9)|0);
     HEAP32[$73>>2] = $85;
     $86 = ($$sum$i$i$i$i$i9|0)<(0);
     if (!($86)) {
      $$sum1$i$i$i$i$i10 = (($$sum$i$i$i$i$i9) + 1)|0;
      $87 = (($79) + ($$sum1$i$i$i$i$i10)|0);
      $88 = (($transfer) + 20|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($87>>>0)>($89>>>0);
      if (!($90)) {
       $91 = HEAP8[$85>>0]|0;
       HEAP8[$animatePhysics>>0] = $91;
       $$sum = (($$sum$i$i$i$i$i9) + 1)|0;
       $92 = (($79) + ($$sum)|0);
       HEAP32[$73>>2] = $92;
       break;
      }
     }
     __ZN12CachedReader15UpdateReadCacheEPvj($73,$animatePhysics,1);
    } else {
     $93 = HEAP32[$converter$i$i18>>2]|0;
     $94 = ($93|0)==(0|0);
     if (!($94)) {
      (FUNCTION_TABLE_iii[$93 & 4095]($animatePhysics,$transfer)|0);
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
  $95 = HEAP8[$animatePhysics>>0]|0;
  $96 = $95&255;
  HEAP32[$13>>2] = $96;
 }
 $97 = (($this) + 465|0);
 $98 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771416,$15,$converter$i$i18,0)|0);
 $99 = ($98|0)==(0);
 if (!($99)) {
  $100 = ($98|0)>(0);
  do {
   if ($100) {
    $101 = (($transfer) + 12|0);
    $102 = (($transfer) + 80|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = (($103) + 12|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (($transfer) + 16|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($transfer) + 28|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($transfer) + 32|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = Math_imul($111, $109)|0;
    $$sum$i$i$i$i$i14 = (($105) - ($112))|0;
    $113 = (($107) + ($$sum$i$i$i$i$i14)|0);
    HEAP32[$101>>2] = $113;
    $114 = ($$sum$i$i$i$i$i14|0)<(0);
    if (!($114)) {
     $$sum1$i$i$i$i$i15 = (($$sum$i$i$i$i$i14) + 1)|0;
     $115 = (($107) + ($$sum1$i$i$i$i$i15)|0);
     $116 = (($transfer) + 20|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ($115>>>0)>($117>>>0);
     if (!($118)) {
      $119 = HEAP8[$113>>0]|0;
      HEAP8[$97>>0] = $119;
      $120 = HEAP32[$101>>2]|0;
      $121 = (($120) + 1|0);
      HEAP32[$101>>2] = $121;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($101,$97,1);
   } else {
    $122 = HEAP32[$converter$i$i18>>2]|0;
    $123 = ($122|0)==(0|0);
    if (!($123)) {
     (FUNCTION_TABLE_iii[$122 & 4095]($97,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $124 = (($this) + 464|0);
 $125 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771440,$15,$converter$i$i18,0)|0);
 $126 = ($125|0)==(0);
 if ($126) {
  STACKTOP = sp;return;
 }
 $127 = ($125|0)>(0);
 do {
  if ($127) {
   $128 = (($transfer) + 12|0);
   $129 = (($transfer) + 80|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = (($130) + 12|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = (($transfer) + 16|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = (($transfer) + 28|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = (($transfer) + 32|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = Math_imul($138, $136)|0;
   $$sum$i$i$i$i$i19 = (($132) - ($139))|0;
   $140 = (($134) + ($$sum$i$i$i$i$i19)|0);
   HEAP32[$128>>2] = $140;
   $141 = ($$sum$i$i$i$i$i19|0)<(0);
   if (!($141)) {
    $$sum1$i$i$i$i$i20 = (($$sum$i$i$i$i$i19) + 1)|0;
    $142 = (($134) + ($$sum1$i$i$i$i$i20)|0);
    $143 = (($transfer) + 20|0);
    $144 = HEAP32[$143>>2]|0;
    $145 = ($142>>>0)>($144>>>0);
    if (!($145)) {
     $146 = HEAP8[$140>>0]|0;
     HEAP8[$124>>0] = $146;
     $147 = HEAP32[$128>>2]|0;
     $148 = (($147) + 1|0);
     HEAP32[$128>>2] = $148;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($128,$124,1);
  } else {
   $149 = HEAP32[$converter$i$i18>>2]|0;
   $150 = ($149|0)==(0|0);
   if (!($150)) {
    (FUNCTION_TABLE_iii[$149 & 4095]($124,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN4PPtrI6AvatarE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,771480,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,771496,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,771480,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,771496,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN8Animator8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i1 = sp;
 __ZN13ProxyTransfer10SetVersionEi($transfer,3);
 __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771272,771544,$0,0);
 $1 = (($localIdentifier$i$i$i1) + 8|0);
 $2 = $1;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 $6 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771480,$6,$0,1);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771496,$13,$1,1);
 $14 = HEAP32[$7>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$10>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771288,771512,$18,0);
 $19 = (($localIdentifier$i$i$i1) + 8|0);
 $20 = $19;
 $21 = $20;
 HEAP32[$21>>2] = 0;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771480,$6,$18,1);
 $24 = HEAP32[$7>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$10>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771496,$13,$19,1);
 $28 = HEAP32[$7>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$10>>2]|0;
 $31 = ((($29) + (($30*24)|0)|0) + 12|0);
 HEAP32[$31>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $32 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771304,$6,$32,0);
 $33 = HEAP32[$7>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$10>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $37 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771320,$6,$37,0);
 $38 = HEAP32[$7>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$10>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $42 = (($this) + 345|0);
 $43 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771336,$43,$42,8388608);
 $44 = HEAP32[$7>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$10>>2]|0;
 $47 = ((($45) + (($46*24)|0)|0) + 12|0);
 HEAP32[$47>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $48 = (($this) + 346|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771360,$43,$48,8388608);
 $49 = HEAP32[$7>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$10>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $53 = (($this) + 465|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771416,$43,$53,8388608);
 $54 = HEAP32[$7>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$10>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $58 = (($this) + 464|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771440,$43,$58,0);
 $59 = HEAP32[$7>>2]|0;
 $60 = HEAP32[$59>>2]|0;
 $61 = HEAP32[$10>>2]|0;
 $62 = ((($60) + (($61*24)|0)|0) + 12|0);
 HEAP32[$62>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN8AnimatorD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$4 = 0, $$45 = 0, $$5 = 0, $$56 = 0, $$byval_copy21 = 0, $$pre$i = 0, $$pre$i17 = 0, $$pre$phi$i19Z2D = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i28 = 0, $c$01$i$i$i = 0, $c$01$i$i$i12 = 0, $c$01$i$i$i4$i = 0, $c$01$i$i$i4$i22 = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$i$index = 0;
 var $lpad$phi$i20$index = 0, $lpad$phi$i20$index2 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i29 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i31 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i32 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy21 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 HEAP32[$this>>2] = ((769200 + 8|0));
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = ((769200 + 168|0));
 $6 = (($this) + 480|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(-1);
 do {
  if ($8) {
   $9 = (($this) + 468|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 472|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$4>>2] = $12;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($10|0),($$byval_copy21|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $71 = ___cxa_find_matching_catch()|0;
    $72 = tempRet0;
    $73 = (($this) + 412|0);
    __THREW__ = 0;
    invoke_vi(1303,($73|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    } else {
     $$0 = $72;$$01 = $71;
     label = 30;
     break;
    }
   } else {
    HEAP32[$9>>2] = 0;
    label = 4;
    break;
   }
  } else {
   label = 4;
  }
 } while(0);
 L6: do {
  if ((label|0) == 4) {
   $15 = (($this) + 412|0);
   __THREW__ = 0;
   invoke_vi(1303,($15|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $76 = ___cxa_find_matching_catch()|0;
    $77 = tempRet0;
    $$0 = $77;$$01 = $76;
    label = 30;
    break;
   }
   $18 = (($this) + 372|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    $21 = (($this) + 376|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($19|0);
    if (!($23)) {
     $__new_last2$i$i$i$i$i = $19;
     $scevgep$i$i$i$i$i = (($22) + -4|0);
     $24 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($24)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $25 = $uglygep3$i$i$i$i$i >>> 2;
     $26 = $25 ^ -1;
     $scevgep4$i$i$i$i$i = (($22) + ($26<<2)|0);
     HEAP32[$21>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($19);
   }
   $27 = (($this) + 368|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)>(-1);
   do {
    if ($29) {
     $30 = (($this) + 356|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($this) + 360|0);
     $33 = HEAP32[$32>>2]|0;
     HEAP32[$2>>2] = $33;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($31|0),($$byval_copy21|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      $87 = ___cxa_find_matching_catch()|0;
      $88 = tempRet0;
      $$4 = $88;$$45 = $87;
      label = 39;
      break L6;
     } else {
      HEAP32[$30>>2] = 0;
      break;
     }
    }
   } while(0);
   $36 = (($this) + 128|0);
   $37 = (($this) + 152|0);
   $38 = (($this) + 184|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if ($40) {
    label = 14;
   } else {
    __THREW__ = 0;
    invoke_vi(3695,($39|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 21;
    } else {
     label = 14;
    }
   }
   do {
    if ((label|0) == 14) {
     $43 = (($this) + 180|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==(0|0);
     if (!($45)) {
      __THREW__ = 0;
      invoke_vi(3696,($44|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 21;
       break;
      }
     }
     dest=$37+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$37+44>>0]=0|0;
     $48 = (($this) + 136|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==(0|0);
     if ($50) {
      $69 = (($this) + 140|0);
      $70 = (($this) + 144|0);
      HEAP32[$36>>2] = ((768664 + 8|0));
      HEAP32[$48>>2] = 0;
      HEAP32[$69>>2] = 0;
      HEAP32[$70>>2] = 0;
      __ZN9BehaviourD2Ev($this);
      STACKTOP = sp;return;
     }
     $c$01$i$i$i12 = $49;
     while(1) {
      $51 = HEAP32[$c$01$i$i$i12>>2]|0;
      $52 = HEAP32[628296>>2]|0;
      HEAP32[$1>>2] = $52;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($c$01$i$i$i12|0),($$byval_copy21|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 20;
       break;
      }
      $55 = ($51|0)==(0|0);
      if ($55) {
       label = 27;
       break;
      } else {
       $c$01$i$i$i12 = $51;
      }
     }
     if ((label|0) == 20) {
      $56 = ___cxa_find_matching_catch()|0;
      $57 = tempRet0;
      $$pre$phi$i19Z2D = $48;$lpad$phi$i20$index = $56;$lpad$phi$i20$index2 = $57;
      break;
     }
     else if ((label|0) == 27) {
      $69 = (($this) + 140|0);
      $70 = (($this) + 144|0);
      HEAP32[$36>>2] = ((768664 + 8|0));
      HEAP32[$48>>2] = 0;
      HEAP32[$69>>2] = 0;
      HEAP32[$70>>2] = 0;
      __ZN9BehaviourD2Ev($this);
      STACKTOP = sp;return;
     }
    }
   } while(0);
   if ((label|0) == 21) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    $$pre$i17 = (($this) + 136|0);
    $$pre$phi$i19Z2D = $$pre$i17;$lpad$phi$i20$index = $58;$lpad$phi$i20$index2 = $59;
   }
   HEAP32[$36>>2] = ((768664 + 8|0));
   $60 = HEAP32[$$pre$phi$i19Z2D>>2]|0;
   $61 = ($60|0)==(0|0);
   L42: do {
    if (!($61)) {
     $c$01$i$i$i4$i22 = $60;
     while(1) {
      $62 = HEAP32[$c$01$i$i$i4$i22>>2]|0;
      $63 = HEAP32[628296>>2]|0;
      HEAP32[$0>>2] = $63;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($c$01$i$i$i4$i22|0),($$byval_copy21|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      $66 = ($62|0)==(0|0);
      if ($66) {
       break L42;
      } else {
       $c$01$i$i$i4$i22 = $62;
      }
     }
     $67 = ___cxa_find_matching_catch(0|0)|0;
     $68 = tempRet0;
     ___clang_call_terminate($67);
     // unreachable;
    }
   } while(0);
   HEAP32[$$pre$phi$i19Z2D>>2] = 0;
   $98 = (($this) + 140|0);
   HEAP32[$98>>2] = 0;
   $99 = (($this) + 144|0);
   HEAP32[$99>>2] = 0;
   $$5 = $lpad$phi$i20$index2;$$56 = $lpad$phi$i20$index;
   label = 56;
  }
 } while(0);
 if ((label|0) == 30) {
  $78 = (($this) + 372|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($79|0)==(0|0);
  if (!($80)) {
   $81 = (($this) + 376|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==($79|0);
   if (!($83)) {
    $__new_last2$i$i$i$i$i28 = $79;
    $scevgep$i$i$i$i$i29 = (($82) + -4|0);
    $84 = (0 - ($__new_last2$i$i$i$i$i28))|0;
    $uglygep$i$i$i$i$i31 = (($scevgep$i$i$i$i$i29) + ($84)|0);
    $uglygep3$i$i$i$i$i32 = $uglygep$i$i$i$i$i31;
    $85 = $uglygep3$i$i$i$i$i32 >>> 2;
    $86 = $85 ^ -1;
    $scevgep4$i$i$i$i$i33 = (($82) + ($86<<2)|0);
    HEAP32[$81>>2] = $scevgep4$i$i$i$i$i33;
   }
   __ZdlPv($79);
  }
  $89 = (($this) + 368|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($90|0)>(-1);
  if ($91) {
   $92 = (($this) + 356|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = (($this) + 360|0);
   $95 = HEAP32[$94>>2]|0;
   HEAP32[$0>>2] = $95;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($93|0),($$byval_copy21|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if (!($97)) {
    HEAP32[$92>>2] = 0;
    $$4 = $$0;$$45 = $$01;
    label = 39;
   }
  } else {
   $$4 = $$0;$$45 = $$01;
   label = 39;
  }
 }
 L59: do {
  if ((label|0) == 39) {
   $100 = (($this) + 128|0);
   $101 = (($this) + 152|0);
   $102 = (($this) + 184|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==(0|0);
   if ($104) {
    label = 41;
   } else {
    __THREW__ = 0;
    invoke_vi(3695,($103|0));
    $105 = __THREW__; __THREW__ = 0;
    $106 = $105&1;
    if ($106) {
     label = 48;
    } else {
     label = 41;
    }
   }
   L63: do {
    if ((label|0) == 41) {
     $107 = (($this) + 180|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = ($108|0)==(0|0);
     if (!($109)) {
      __THREW__ = 0;
      invoke_vi(3696,($108|0));
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       label = 48;
       break;
      }
     }
     dest=$101+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$101+44>>0]=0|0;
     $112 = (($this) + 136|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = ($113|0)==(0|0);
     L68: do {
      if (!($114)) {
       $c$01$i$i$i = $113;
       while(1) {
        $115 = HEAP32[$c$01$i$i$i>>2]|0;
        $116 = HEAP32[628296>>2]|0;
        HEAP32[$3>>2] = $116;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($c$01$i$i$i|0),($$byval_copy21|0));
        $117 = __THREW__; __THREW__ = 0;
        $118 = $117&1;
        if ($118) {
         break;
        }
        $119 = ($115|0)==(0|0);
        if ($119) {
         break L68;
        } else {
         $c$01$i$i$i = $115;
        }
       }
       $120 = ___cxa_find_matching_catch(0|0)|0;
       $121 = tempRet0;
       $$pre$phi$iZ2D = $112;$lpad$phi$i$index = $120;
       break L63;
      }
     } while(0);
     $135 = (($this) + 140|0);
     $136 = (($this) + 144|0);
     HEAP32[$100>>2] = ((768664 + 8|0));
     HEAP32[$112>>2] = 0;
     HEAP32[$135>>2] = 0;
     HEAP32[$136>>2] = 0;
     $$5 = $$4;$$56 = $$45;
     label = 56;
     break L59;
    }
   } while(0);
   if ((label|0) == 48) {
    $122 = ___cxa_find_matching_catch(0|0)|0;
    $123 = tempRet0;
    $$pre$i = (($this) + 136|0);
    $$pre$phi$iZ2D = $$pre$i;$lpad$phi$i$index = $122;
   }
   HEAP32[$100>>2] = ((768664 + 8|0));
   $124 = HEAP32[$$pre$phi$iZ2D>>2]|0;
   $125 = ($124|0)==(0|0);
   L78: do {
    if (!($125)) {
     $c$01$i$i$i4$i = $124;
     while(1) {
      $126 = HEAP32[$c$01$i$i$i4$i>>2]|0;
      $127 = HEAP32[628296>>2]|0;
      HEAP32[$0>>2] = $127;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($c$01$i$i$i4$i|0),($$byval_copy21|0));
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if ($129) {
       break;
      }
      $130 = ($126|0)==(0|0);
      if ($130) {
       break L78;
      } else {
       $c$01$i$i$i4$i = $126;
      }
     }
     $133 = ___cxa_find_matching_catch(0|0)|0;
     $134 = tempRet0;
     ___clang_call_terminate($133);
     // unreachable;
    }
   } while(0);
   HEAP32[$$pre$phi$iZ2D>>2] = 0;
   $131 = (($this) + 140|0);
   HEAP32[$131>>2] = 0;
   $132 = (($this) + 144|0);
   HEAP32[$132>>2] = 0;
   $eh$lpad$body$indexZ2D = $lpad$phi$i$index;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 56) {
  __THREW__ = 0;
  invoke_vi(3410,($this|0));
  $137 = __THREW__; __THREW__ = 0;
  $138 = $137&1;
  if (!($138)) {
   ___resumeException($$56|0);
   // unreachable;
  }
 }
 $139 = ___cxa_find_matching_catch(0|0)|0;
 $140 = tempRet0;
 $eh$lpad$body$indexZ2D = $139;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN7mecanim6memory16InPlaceAllocator8AllocateEjj($this,$n,$align) {
 $this = $this|0;
 $n = $n|0;
 $align = $align|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1;
 $3 = (0 - ($2))|0;
 $4 = (($align) + -1)|0;
 $5 = $4 & $3;
 $6 = (($5) + ($2))|0;
 $7 = $6;
 $8 = (($7) + ($n)|0);
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + ($12)|0);
 $14 = ($8>>>0)>($13>>>0);
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $8;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7mecanim6memory16InPlaceAllocator10DeallocateEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z22AnimatorClipInfoToMonoRK16AnimatorClipInfoR20MonoAnimatorClipInfo($src,$dest) {
 $src = $src|0;
 $dest = $dest|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $phitmp$i = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$src>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   $37 = 0;
  } else {
   HEAP32[$0>>2] = $1;
   $3 = HEAP32[560624>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    label = 10;
   } else {
    $5 = (($3) + 36|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($3) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($6|0)==($8|0);
    do {
     if ($9) {
      $10 = (($3) + 28|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (($3) + 32|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($11) + ($13<<3)|0);
      $30 = $14;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$3,$0);
      $15 = HEAP32[$pos$i$i$i>>2]|0;
      $16 = ($15|0)==(-1);
      $17 = (($3) + 28|0);
      $18 = HEAP32[$17>>2]|0;
      if ($16) {
       $19 = (($3) + 32|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($18) + ($20<<3)|0);
       $30 = $21;
       break;
      } else {
       $22 = (($18) + ($15<<3)|0);
       $30 = $22;
       break;
      }
     }
    } while(0);
    $23 = HEAP32[560624>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + ($27<<3)|0);
    $29 = ($30|0)==($28|0);
    if ($29) {
     label = 10;
    } else {
     $31 = (($30) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      label = 10;
     }
    }
   }
   if ((label|0) == 10) {
    $34 = HEAP32[$src>>2]|0;
    $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
    $phitmp$i = ($35|0)==(0|0);
    if ($phitmp$i) {
     $37 = 0;
     break;
    }
   }
   $36 = HEAP32[$src>>2]|0;
   $37 = $36;
  }
 } while(0);
 HEAP32[$dest>>2] = $37;
 $38 = (($src) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($dest) + 4|0);
 HEAPF32[$40>>2] = $39;
 STACKTOP = sp;return;
}
function __ZN15AnimatorManager17FixedUpdateFKMoveEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__Z14GetTimeManagerv()|0);
 $4 = (($3) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 != Math_fround(0.0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (__Z14GetTimeManagerv()|0);
 $11 = (($10) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 __ZN8Animator13UpdateAvatarsEPPS_jfbbf($8,$9,$12,1,0,Math_fround(0.0));
 STACKTOP = sp;return;
}
function __ZN15AnimatorManager26FixedUpdateRetargetIKWriteEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__Z14GetTimeManagerv()|0);
 $4 = (($3) + 40|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 != Math_fround(0.0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (__Z14GetTimeManagerv()|0);
 $11 = (($10) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 __ZN8Animator13UpdateAvatarsEPPS_jfbbf($8,$9,$12,0,1,Math_fround(0.0));
 STACKTOP = sp;return;
}
function __ZN15AnimatorManager12UpdateFKMoveEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = Math_fround(0), $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__Z14GetTimeManagerv()|0);
 $4 = (($3) + 104|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 > Math_fround(0.0);
 if (!($6)) {
  $7 = (__Z14GetTimeManagerv()|0);
  $8 = (($7) + 188|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $9 < Math_fround(0.0);
  if ($10) {
   $11 = Math_fround(-$9);
   $13 = $11;
  } else {
   $13 = $9;
  }
  $12 = !($13 <= Math_fround(9.99999997475242707878E-7));
  if ($12) {
   STACKTOP = sp;return;
  }
  $14 = (__Z14GetTimeManagerv()|0);
  $15 = (($14) + 176|0);
  $16 = +HEAPF64[$15>>3];
  $17 = $16 > 0.0;
  if (!($17)) {
   STACKTOP = sp;return;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$0>>2]|0;
 $21 = (__Z14GetTimeManagerv()|0);
 $22 = (($21) + 104|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (__Z14GetTimeManagerv()|0);
 $25 = (($24) + 176|0);
 $26 = +HEAPF64[$25>>3];
 $27 = Math_fround($26);
 __ZN8Animator13UpdateAvatarsEPPS_jfbbf($19,$20,$23,1,0,$27);
 STACKTOP = sp;return;
}
function __ZN15AnimatorManager21UpdateRetargetIKWriteEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = Math_fround(0), $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__Z14GetTimeManagerv()|0);
 $4 = (($3) + 104|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 > Math_fround(0.0);
 if (!($6)) {
  $7 = (__Z14GetTimeManagerv()|0);
  $8 = (($7) + 188|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = $9 < Math_fround(0.0);
  if ($10) {
   $11 = Math_fround(-$9);
   $13 = $11;
  } else {
   $13 = $9;
  }
  $12 = !($13 <= Math_fround(9.99999997475242707878E-7));
  if ($12) {
   STACKTOP = sp;return;
  }
  $14 = (__Z14GetTimeManagerv()|0);
  $15 = (($14) + 176|0);
  $16 = +HEAPF64[$15>>3];
  $17 = $16 > 0.0;
  if (!($17)) {
   STACKTOP = sp;return;
  }
 }
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$0>>2]|0;
 $21 = (__Z14GetTimeManagerv()|0);
 $22 = (($21) + 104|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (__Z14GetTimeManagerv()|0);
 $25 = (($24) + 176|0);
 $26 = +HEAPF64[$25>>3];
 $27 = Math_fround($26);
 __ZN8Animator13UpdateAvatarsEPPS_jfbbf($19,$20,$23,0,1,$27);
 STACKTOP = sp;return;
}
function __ZN15AnimatorManager11AddAnimatorER8Animator($this,$animator) {
 $this = $this|0;
 $animator = $animator|0;
 var $$byval_copy3 = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($animator) + 28|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($animator) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (__ZNK5Unity10GameObject8IsActiveEv($5)|0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (__ZNK8Animator7IsValidEv($animator)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($animator) + 52|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(1);
 if ($11) {
  $12 = (($this) + 20|0);
  $13 = (($this) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($animator) + 40|0);
  HEAP32[$15>>2] = $14;
  $16 = HEAP32[$13>>2]|0;
  $17 = (($16) + 1)|0;
  HEAP32[$13>>2] = $17;
  $18 = (($this) + 32|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & 2147483647;
  $21 = ($17>>>0)>($20>>>0);
  if ($21) {
   $22 = $19 << 1;
   $23 = ($22|0)==(0);
   $24 = $23 ? 1 : $22;
   $25 = ($20>>>0)<($24>>>0);
   do {
    if ($25) {
     $26 = ($19|0)>(-1);
     if ($26) {
      HEAP32[$18>>2] = $24;
      $27 = HEAP32[$12>>2]|0;
      $28 = $24 << 2;
      $29 = (($this) + 24|0);
      $30 = HEAP32[$29>>2]|0;
      HEAP32[$0>>2] = $30;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $31 = (__Z16realloc_internalPvji10MemLabelIdiPKci($27,$28,4,$$byval_copy3,0,771576,370)|0);
      HEAP32[$12>>2] = $31;
      break;
     } else {
      $32 = $24 << 2;
      $33 = (($this) + 24|0);
      $34 = HEAP32[$33>>2]|0;
      HEAP32[$0>>2] = $34;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $35 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,4,$$byval_copy3,0,771576,352)|0);
      $36 = HEAP32[$12>>2]|0;
      $37 = HEAP32[$13>>2]|0;
      $38 = $37 << 2;
      _memcpy(($35|0),($36|0),($38|0))|0;
      HEAP32[$18>>2] = $24;
      HEAP32[$12>>2] = $35;
      break;
     }
    }
   } while(0);
   $$pre$i$i1 = HEAP32[$13>>2]|0;
   $40 = $$pre$i$i1;
  } else {
   $40 = $17;
  }
  $39 = (($40) + -1)|0;
  $41 = HEAP32[$12>>2]|0;
  $42 = (($41) + ($39<<2)|0);
  HEAP32[$42>>2] = $animator;
  STACKTOP = sp;return;
 } else {
  $43 = (($this) + 4|0);
  $44 = (($this) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($animator) + 36|0);
  HEAP32[$46>>2] = $45;
  $47 = HEAP32[$44>>2]|0;
  $48 = (($47) + 1)|0;
  HEAP32[$44>>2] = $48;
  $49 = (($this) + 16|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 2147483647;
  $52 = ($48>>>0)>($51>>>0);
  if ($52) {
   $53 = $50 << 1;
   $54 = ($53|0)==(0);
   $55 = $54 ? 1 : $53;
   $56 = ($51>>>0)<($55>>>0);
   do {
    if ($56) {
     $57 = ($50|0)>(-1);
     if ($57) {
      HEAP32[$49>>2] = $55;
      $58 = HEAP32[$43>>2]|0;
      $59 = $55 << 2;
      $60 = (($this) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      HEAP32[$0>>2] = $61;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $62 = (__Z16realloc_internalPvji10MemLabelIdiPKci($58,$59,4,$$byval_copy3,0,771576,370)|0);
      HEAP32[$43>>2] = $62;
      break;
     } else {
      $63 = $55 << 2;
      $64 = (($this) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      HEAP32[$0>>2] = $65;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $66 = (__Z15malloc_internaljj10MemLabelIdiPKci($63,4,$$byval_copy3,0,771576,352)|0);
      $67 = HEAP32[$43>>2]|0;
      $68 = HEAP32[$44>>2]|0;
      $69 = $68 << 2;
      _memcpy(($66|0),($67|0),($69|0))|0;
      HEAP32[$49>>2] = $55;
      HEAP32[$43>>2] = $66;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$44>>2]|0;
   $71 = $$pre$i$i;
  } else {
   $71 = $48;
  }
  $70 = (($71) + -1)|0;
  $72 = HEAP32[$43>>2]|0;
  $73 = (($72) + ($70<<2)|0);
  HEAP32[$73>>2] = $animator;
  STACKTOP = sp;return;
 }
}
function __ZN15AnimatorManager14RemoveAnimatorER8Animator($this,$animator) {
 $this = $this|0;
 $animator = $animator|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($animator) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if (!($2)) {
  $3 = (($this) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + -1)|0;
  $6 = (($this) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + ($1<<2)|0);
  HEAP32[$10>>2] = $9;
  $11 = (($9) + 36|0);
  HEAP32[$11>>2] = $1;
  HEAP32[$0>>2] = -1;
  $12 = HEAP32[$3>>2]|0;
  $13 = (($12) + -1)|0;
  HEAP32[$3>>2] = $13;
 }
 $14 = (($animator) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(-1);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (($this) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + -1)|0;
 $20 = (($this) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19<<2)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + ($15<<2)|0);
 HEAP32[$24>>2] = $23;
 $25 = (($23) + 40|0);
 HEAP32[$25>>2] = $15;
 HEAP32[$14>>2] = -1;
 $26 = HEAP32[$17>>2]|0;
 $27 = (($26) + -1)|0;
 HEAP32[$17>>2] = $27;
 STACKTOP = sp;return;
}
function __ZN15AnimatorManager15InitializeClassEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628296>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(36,$$byval_copy,1,16,771576,95)|0);
 HEAP32[$2>>2] = ((771592 + 8|0));
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($2) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = (($2) + 8|0);
 HEAP32[$6>>2] = 61;
 $7 = (($2) + 20|0);
 HEAP32[$7>>2] = 0;
 $8 = (($2) + 28|0);
 HEAP32[$8>>2] = 0;
 $9 = (($2) + 32|0);
 HEAP32[$9>>2] = 0;
 $10 = (($2) + 24|0);
 HEAP32[$10>>2] = 61;
 HEAP32[771584>>2] = $2;
 HEAP32[579344>>2] = 159;
 HEAP32[579352>>2] = 162;
 HEAP32[579360>>2] = 161;
 HEAP32[579368>>2] = 156;
 STACKTOP = sp;return;
}
function __ZZN15AnimatorManager15InitializeClassEvEN34AnimatorFixedUpdateRetargetIKWrite7ForwardEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[771584>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZZN15AnimatorManager15InitializeClassEvEN29AnimatorUpdateRetargetIKWrite7ForwardE_0v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[771584>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZZN15AnimatorManager15InitializeClassEvEN20AnimatorUpdateFKMove7ForwardE_1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[771584>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZZN15AnimatorManager15InitializeClassEvEN25AnimatorFixedUpdateFKMove7ForwardE_2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[771584>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($0);
 STACKTOP = sp;return;
}
function __ZN15AnimatorManager12CleanupClassEv() {
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[771584>>2]|0;
 $4 = HEAP32[628296>>2]|0;
 $5 = ($3|0)==(0|0);
 if (!($5)) {
  HEAP32[$3>>2] = ((771592 + 8|0));
  $6 = (($3) + 32|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)>(-1);
  do {
   if ($8) {
    $9 = (($3) + 20|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($3) + 24|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$1>>2] = $12;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($10|0),($$byval_copy3|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     HEAP32[$9>>2] = 0;
     break;
    }
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $24 = (($3) + 16|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)>(-1);
    if (!($26)) {
     ___resumeException($22|0);
     // unreachable;
    }
    $27 = (($3) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($3) + 8|0);
    $30 = HEAP32[$29>>2]|0;
    HEAP32[$0>>2] = $30;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($28|0),($$byval_copy3|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch(0|0)|0;
     $34 = tempRet0;
     ___clang_call_terminate($33);
     // unreachable;
    }
    HEAP32[$27>>2] = 0;
    ___resumeException($22|0);
    // unreachable;
   }
  } while(0);
  $15 = (($3) + 16|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)>(-1);
  if ($17) {
   $18 = (($3) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($3) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$0>>2] = $21;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy3);
   HEAP32[$18>>2] = 0;
  }
 }
 HEAP32[$2>>2] = $4;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy3);
 HEAP32[771584>>2] = 0;
 STACKTOP = sp;return;
}
function __Z18GetAnimatorManagerv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[771584>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN14AvatarPlaybackC2E10MemLabelId($this,$label) {
 $this = $this|0;
 $label = $label|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((771616 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 ;HEAP32[$3+0>>2]=4294967295|0;HEAP32[$3+4>>2]=4294967295|0;HEAP32[$3+8>>2]=4294967295|0;HEAP32[$3+12>>2]=4294967295|0;
 $4 = HEAP32[$label>>2]|0;
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = ((741984 + 8|0));
 $6 = (($this) + 36|0);
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN14AvatarPlaybackD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1303,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN14AvatarPlaybackD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i1 = 0, $i$04$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((771616 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 do {
  if ($4) {
   $24 = $1;$26 = $1;
  } else {
   $5 = (($this) + 32|0);
   $7 = $3;$i$04$i = 0;
   while(1) {
    $6 = (($7) + ($i$04$i<<3)|0);
    $8 = HEAP32[$6>>2]|0;
    __THREW__ = 0;
    invoke_vii(3398,($8|0),($5|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = (($i$04$i) + 1)|0;
    $12 = HEAP32[$0>>2]|0;
    $13 = HEAP32[$2>>2]|0;
    $14 = $12;
    $15 = $13;
    $16 = (($14) - ($15))|0;
    $17 = $16 >> 3;
    $18 = ($11>>>0)<($17>>>0);
    if ($18) {
     $7 = $13;$i$04$i = $11;
    } else {
     label = 5;
     break;
    }
   }
   if ((label|0) == 5) {
    $19 = ($12|0)==($13|0);
    if ($19) {
     $24 = $12;$26 = $12;
     break;
    }
    $scevgep$i$i$i$i = (($12) + -8|0);
    $20 = (0 - ($15))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($20)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $21 = $uglygep3$i$i$i$i >>> 3;
    $22 = $21 ^ -1;
    $scevgep4$i$i$i$i = (($12) + ($22<<3)|0);
    HEAP32[$0>>2] = $scevgep4$i$i$i$i;
    $24 = $13;$26 = $scevgep4$i$i$i$i;
    break;
   }
   $30 = ___cxa_find_matching_catch()|0;
   $31 = tempRet0;
   $32 = HEAP32[$2>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    ___resumeException($30|0);
    // unreachable;
   }
   $34 = HEAP32[$0>>2]|0;
   $35 = ($34|0)==($32|0);
   if (!($35)) {
    $__new_last2$i$i$i$i$i1 = $32;
    $scevgep$i$i$i$i$i2 = (($34) + -8|0);
    $36 = (0 - ($__new_last2$i$i$i$i$i1))|0;
    $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($36)|0);
    $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
    $37 = $uglygep3$i$i$i$i$i5 >>> 3;
    $38 = $37 ^ -1;
    $scevgep4$i$i$i$i$i6 = (($34) + ($38<<3)|0);
    HEAP32[$0>>2] = $scevgep4$i$i$i$i$i6;
   }
   __ZdlPv($32);
   ___resumeException($30|0);
   // unreachable;
  }
 } while(0);
 $23 = ($24|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $25 = ($26|0)==($24|0);
 if (!($25)) {
  $__new_last2$i$i$i$i$i = $24;
  $scevgep$i$i$i$i$i = (($26) + -8|0);
  $27 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($27)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $28 = $uglygep3$i$i$i$i$i >>> 3;
  $29 = $28 ^ -1;
  $scevgep4$i$i$i$i$i = (($26) + ($29<<3)|0);
  HEAP32[$0>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($24);
 STACKTOP = sp;return;
}
function __ZN14AvatarPlayback9PlayFrameEfRf($this,$time,$effectiveTime) {
 $this = $this|0;
 $time = Math_fround($time);
 $effectiveTime = $effectiveTime|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $brmerge$us = 0, $frameIndex$0 = 0, $frameIndex$0$us = 0, $frameIndex$1 = 0, $frameIndex$1$lcssa = 0, $frameIndex$1$us = 0, $i$0 = 0;
 var $i$0$us = 0, $prevIndex$0 = 0, $prevIndex$0$phi = 0, $prevIndex$0$us = 0, $prevIndex$0$us$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(0);
 $8 = (($1) + 1)|0;
 if ($7) {
  $11 = (($8|0) % ($6|0))&-1;
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $frameIndex$0$us = $1;$i$0$us = $3;$prevIndex$0$us = $3;
  while(1) {
   $14 = ((($13) + ($i$0$us<<3)|0) + 4|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = $15 > $time;
   $frameIndex$1$us = $16 ? $prevIndex$0$us : $frameIndex$0$us;
   $17 = (($i$0$us) + 1)|0;
   $18 = (($17|0) % ($6|0))&-1;
   $19 = ($18|0)==($11|0);
   $brmerge$us = $19 | $16;
   if ($brmerge$us) {
    $26 = $13;$frameIndex$1$lcssa = $frameIndex$1$us;
    break;
   } else {
    $prevIndex$0$us$phi = $i$0$us;$frameIndex$0$us = $frameIndex$1$us;$i$0$us = $18;$prevIndex$0$us = $prevIndex$0$us$phi;
   }
  }
 } else {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $frameIndex$0 = $1;$i$0 = $3;$prevIndex$0 = $3;
  while(1) {
   $20 = ((($10) + ($i$0<<3)|0) + 4|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = $21 > $time;
   $frameIndex$1 = $22 ? $prevIndex$0 : $frameIndex$0;
   $23 = (($i$0) + 1)|0;
   $24 = ($23|0)==($8|0);
   $brmerge = $24 | $22;
   if ($brmerge) {
    $26 = $10;$frameIndex$1$lcssa = $frameIndex$1;
    break;
   } else {
    $prevIndex$0$phi = $i$0;$frameIndex$0 = $frameIndex$1;$i$0 = $23;$prevIndex$0 = $prevIndex$0$phi;
   }
  }
 }
 $25 = ((($26) + ($frameIndex$1$lcssa<<3)|0) + 4|0);
 $27 = Math_fround(HEAPF32[$25>>2]);
 HEAPF32[$effectiveTime>>2] = $27;
 $28 = (($this) + 28|0);
 HEAP32[$28>>2] = $frameIndex$1$lcssa;
 $29 = (($26) + ($frameIndex$1$lcssa<<3)|0);
 $30 = HEAP32[$29>>2]|0;
 $$0 = $30;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14AvatarPlayback11RecordFrameEfPKN7mecanim9animation12AvatarMemoryE($this,$deltaTime,$srcMemory) {
 $this = $this|0;
 $deltaTime = Math_fround($deltaTime);
 $srcMemory = $srcMemory|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $or$cond = 0, $phitmp = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(771640,0,771632,93,512,0,0,0);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-1);
 $$pre = (($this) + 28|0);
 if ($5) {
  $36 = 0;$41 = 0;
 } else {
  $6 = HEAP32[$$pre>>2]|0;
  $7 = (($this) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8) + ($6<<3)|0) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround($10 + $deltaTime);
  $phitmp = (HEAPF32[tempDoublePtr>>2]=$11,HEAP32[tempDoublePtr>>2]|0);
  $36 = 0;$41 = $phitmp;
 }
 HEAP32[$size>>2] = 0;
 $12 = (($this) + 32|0);
 $13 = (__Z8CopyBlobIN7mecanim9animation12AvatarMemoryEEPT_RKS3_RNS0_6memory9AllocatorERj($srcMemory,$12,$size)|0);
 $14 = HEAP32[$$pre>>2]|0;
 $15 = HEAP32[$0>>2]|0;
 $16 = ($15|0)>(0);
 $17 = (($14) + 1)|0;
 if ($16) {
  $18 = (($17|0) % ($15|0))&-1;
  $19 = $18;
 } else {
  $19 = $17;
 }
 HEAP32[$$pre>>2] = $19;
 $20 = HEAP32[$3>>2]|0;
 $21 = ($20|0)==($19|0);
 $22 = ($20|0)==(-1);
 $or$cond = $21 | $22;
 if ($or$cond) {
  $23 = (($20) + 1)|0;
  if ($16) {
   $24 = (($23|0) % ($15|0))&-1;
   $25 = $24;
  } else {
   $25 = $23;
  }
  HEAP32[$3>>2] = $25;
 }
 $26 = (($this) + 24|0);
 HEAP32[$26>>2] = $19;
 $27 = (($this) + 4|0);
 if ($16) {
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + ($19<<3)|0);
  $30 = HEAP32[$29>>2]|0;
  __ZN7mecanim9animation19DestroyAvatarMemoryEPNS0_12AvatarMemoryERNS_6memory9AllocatorE($30,$12);
  $31 = HEAP32[$$pre>>2]|0;
  $32 = HEAP32[$27>>2]|0;
  $33 = (($32) + ($31<<3)|0);
  $34 = $13;
  $35 = $34 | $36;
  $37 = $33;
  $38 = $37;
  HEAP32[$38>>2] = $35;
  $39 = (($37) + 4)|0;
  $40 = $39;
  HEAP32[$40>>2] = $41;
  STACKTOP = sp;return;
 }
 $42 = (($this) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($43|0)==($45|0);
 if (!($46)) {
  $47 = ($43|0)==(0|0);
  if ($47) {
   $55 = 0;
  } else {
   $48 = $13;
   $49 = $48 | $36;
   $50 = $43;
   $51 = $50;
   HEAP32[$51>>2] = $49;
   $52 = (($50) + 4)|0;
   $53 = $52;
   HEAP32[$53>>2] = $41;
   $$pre$i = HEAP32[$42>>2]|0;
   $55 = $$pre$i;
  }
  $54 = (($55) + 8|0);
  HEAP32[$42>>2] = $54;
  STACKTOP = sp;return;
 }
 $56 = HEAP32[$27>>2]|0;
 $57 = $43;
 $58 = $56;
 $59 = (($57) - ($58))|0;
 $60 = $59 >> 3;
 $61 = (($60) + 1)|0;
 $62 = ($61>>>0)>(536870911);
 if ($62) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $63 = ($60>>>0)<(268435455);
 if ($63) {
  $64 = $59 >> 2;
  $65 = ($64>>>0)<($61>>>0);
  $66 = $65 ? $61 : $64;
  $67 = ($66|0)==(0);
  if ($67) {
   $$0$i3$i$i = 0;$71 = 0;
  } else {
   $$0$i2$i$i = $66;
   label = 21;
  }
 } else {
  $$0$i2$i$i = 536870911;
  label = 21;
 }
 if ((label|0) == 21) {
  $68 = $$0$i2$i$i << 3;
  $69 = (__Znwj($68)|0);
  $$0$i3$i$i = $$0$i2$i$i;$71 = $69;
 }
 $70 = (($71) + ($60<<3)|0);
 $72 = (($71) + ($$0$i3$i$i<<3)|0);
 $73 = ($70|0)==(0|0);
 if (!($73)) {
  $74 = $13;
  $75 = $74 | $36;
  $76 = $70;
  $77 = $76;
  HEAP32[$77>>2] = $75;
  $78 = (($76) + 4)|0;
  $79 = $78;
  HEAP32[$79>>2] = $41;
 }
 $80 = (($71) + ($61<<3)|0);
 _memcpy(($71|0),($56|0),($59|0))|0;
 HEAP32[$27>>2] = $71;
 HEAP32[$42>>2] = $80;
 HEAP32[$44>>2] = $72;
 $81 = ($56|0)==(0|0);
 if ($81) {
  STACKTOP = sp;return;
 }
 __ZdlPv($56);
 STACKTOP = sp;return;
}
function __ZN14AvatarPlayback10CursorTimeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $7 = Math_fround(-1.0);
  STACKTOP = sp;return (Math_fround($7));
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + ($1<<3)|0) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = $6;
 STACKTOP = sp;return (Math_fround($7));
}
function __ZN14AvatarPlayback8StopTimeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $9 = Math_fround(-1.0);
  STACKTOP = sp;return (Math_fround($9));
 }
 $3 = (($this) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6) + ($4<<3)|0) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = $8;
 STACKTOP = sp;return (Math_fround($9));
}
function __ZN25RuntimeAnimatorController23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771696,771704,$this,0);
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771696,771704,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __Z39RegisterClass_RuntimeAnimatorControllerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(93,239,0,0,0);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 25;
 dest=$3+0|0; src=771704+0|0; stop=dest+25|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 25|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,93,130,($0|0),68,(2589|0),1,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN25RuntimeAnimatorController7PRODUCEE10MemLabelId18ObjectCreationMode($0,$1) {
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK25RuntimeAnimatorController25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 93;
}
function __ZN25RuntimeAnimatorControllerC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy,$mode);
 HEAP32[$this>>2] = ((771736 + 8|0));
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = $this;
 $3 = (($this) + 32|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 40|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 44|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 36|0);
 HEAP32[$6>>2] = 61;
 $7 = (($this) + 48|0);
 HEAP32[$7>>2] = $this;
 $8 = (($this) + 52|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 60|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 64|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 56|0);
 HEAP32[$11>>2] = 61;
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController15ThreadedCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 __ZN8UserList11SendMessageERK17MessageIdentifier($0,566032);
 $1 = (($this) + 48|0);
 __ZN8UserList5ClearEv($1);
 __ZN8UserList5ClearEv($0);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController17NotifyObjectUsersERK17MessageIdentifier($this,$msg) {
 $this = $this|0;
 $msg = $msg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 __ZN8UserList11SendMessageERK17MessageIdentifier($0,$msg);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController22RegisterAnimationClipsEv($this) {
 $this = $this|0;
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $clips = 0, $i$04 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $temp$0$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $clips = sp + 8|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($clips,$this);
 $5 = (($this) + 48|0);
 __THREW__ = 0;
 invoke_vi(3703,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if ($7) {
   label = 18;
  } else {
   $8 = (($clips) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vii(3399,($5|0),($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if ($11) {
    label = 18;
   } else {
    $12 = HEAP32[$8>>2]|0;
    $13 = ($12|0)==(0);
    L4: do {
     if (!($13)) {
      $i$04 = 0;
      L6: while(1) {
       $14 = HEAP32[$clips>>2]|0;
       $15 = (($14) + ($i$04<<2)|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = ($16|0)==(0);
       do {
        if (!($17)) {
         HEAP32[$0>>2] = $16;
         $18 = HEAP32[560624>>2]|0;
         $19 = ($18|0)==(0|0);
         if ($19) {
          label = 14;
         } else {
          $20 = (($18) + 36|0);
          $21 = HEAP32[$20>>2]|0;
          $22 = (($18) + 4|0);
          $23 = HEAP32[$22>>2]|0;
          $24 = ($21|0)==($23|0);
          do {
           if ($24) {
            $25 = (($18) + 28|0);
            $26 = HEAP32[$25>>2]|0;
            $27 = (($18) + 32|0);
            $28 = HEAP32[$27>>2]|0;
            $29 = (($26) + ($28<<3)|0);
            $45 = $29;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy6,$18,$0);
            $30 = HEAP32[$$byval_copy6>>2]|0;
            $31 = ($30|0)==(-1);
            $32 = (($18) + 28|0);
            $33 = HEAP32[$32>>2]|0;
            if ($31) {
             $34 = (($18) + 32|0);
             $35 = HEAP32[$34>>2]|0;
             $36 = (($33) + ($35<<3)|0);
             $45 = $36;
             break;
            } else {
             $37 = (($33) + ($30<<3)|0);
             $45 = $37;
             break;
            }
           }
          } while(0);
          $38 = HEAP32[560624>>2]|0;
          $39 = (($38) + 28|0);
          $40 = HEAP32[$39>>2]|0;
          $41 = (($38) + 32|0);
          $42 = HEAP32[$41>>2]|0;
          $43 = (($40) + ($42<<3)|0);
          $44 = ($45|0)==($43|0);
          if ($44) {
           label = 14;
          } else {
           $46 = (($45) + 4|0);
           $47 = HEAP32[$46>>2]|0;
           $48 = ($47|0)==(0|0);
           if ($48) {
            label = 14;
           } else {
            $temp$0$i6 = $47;
           }
          }
         }
         if ((label|0) == 14) {
          label = 0;
          $49 = HEAP32[$15>>2]|0;
          __THREW__ = 0;
          $50 = (invoke_ii(3215,($49|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break L6;
          }
          $53 = ($50|0)==(0|0);
          if ($53) {
           break;
          } else {
           $temp$0$i6 = $50;
          }
         }
         $54 = (($temp$0$i6) + 28|0);
         __THREW__ = 0;
         invoke_vii(3400,($54|0),($5|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break L6;
         }
        }
       } while(0);
       $69 = (($i$04) + 1)|0;
       $70 = HEAP32[$8>>2]|0;
       $71 = ($69>>>0)<($70>>>0);
       if ($71) {
        $i$04 = $69;
       } else {
        break L4;
       }
      }
      $57 = ___cxa_find_matching_catch()|0;
      $58 = tempRet0;
      $lpad$phi$index = $57;$lpad$phi$index2 = $58;
      break L1;
     }
    } while(0);
    $72 = (($clips) + 12|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73|0)>(-1);
    if (!($74)) {
     STACKTOP = sp;return;
    }
    $75 = HEAP32[$clips>>2]|0;
    $76 = (($clips) + 4|0);
    $77 = HEAP32[$76>>2]|0;
    HEAP32[$1>>2] = $77;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($75,$$byval_copy6);
    HEAP32[$clips>>2] = 0;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $lpad$phi$index = $59;$lpad$phi$index2 = $60;
 }
 $61 = (($clips) + 12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)>(-1);
 if (!($63)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $64 = HEAP32[$clips>>2]|0;
 $65 = (($clips) + 4|0);
 $66 = HEAP32[$65>>2]|0;
 HEAP32[$1>>2] = $66;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($64|0),($$byval_copy6|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $78 = ___cxa_find_matching_catch(0|0)|0;
  $79 = tempRet0;
  ___clang_call_terminate($78);
  // unreachable;
 }
 HEAP32[$clips>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN25RuntimeAnimatorController8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,771880,771888,$this,0);
 __ZN18AnimatorController8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,771880,771888,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN18AnimatorController8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18AnimatorController8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18AnimatorController8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18AnimatorController8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN25RuntimeAnimatorController8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 88|0);
 $1 = (($transfer) + 4|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($5<<2)|0);
 $7 = ($5|0)==(0);
 if (!($7)) {
  $8 = (($transfer) + 12|0);
  $9 = (($transfer) + 28|0);
  $10 = (($transfer) + 32|0);
  $i$01$i$i$i$i$i$i = $3;
  while(1) {
   $11 = HEAP32[$i$01$i$i$i$i$i$i>>2]|0;
   $12 = HEAP32[$8>>2]|0;
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$9>>2]|0;
   $16 = (FUNCTION_TABLE_iiii[$14 & 2047]($12,$11,$15)|0);
   $17 = HEAP8[$10>>0]|0;
   $18 = ($17<<24>>24)==(0);
   if (!($18)) {
    HEAP32[$i$01$i$i$i$i$i$i>>2] = $16;
   }
   $19 = (($i$01$i$i$i$i$i$i) + 4|0);
   $20 = ($19|0)==($6|0);
   if ($20) {
    break;
   } else {
    $i$01$i$i$i$i$i$i = $19;
   }
  }
 }
 $21 = (($this) + 172|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 176|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22|0)==($24|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($transfer) + 12|0);
 $27 = (($transfer) + 28|0);
 $28 = (($transfer) + 32|0);
 $30 = $22;
 while(1) {
  $29 = HEAP32[$30>>2]|0;
  $31 = HEAP32[$26>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = HEAP32[$27>>2]|0;
  $35 = (FUNCTION_TABLE_iiii[$33 & 2047]($31,$29,$34)|0);
  $36 = HEAP8[$28>>0]|0;
  $37 = ($36<<24>>24)==(0);
  if (!($37)) {
   HEAP32[$30>>2] = $35;
  }
  $38 = (($30) + 4|0);
  $39 = ($38|0)==($24|0);
  if ($39) {
   break;
  } else {
   $30 = $38;
  }
 }
 STACKTOP = sp;return;
}
function __Z32RegisterClass_AnimatorControllerv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(91,240,241,0,242);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(93)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN25RuntimeAnimatorController13RegisterClassEv();
 }
 $3 = (__Znwj(32)|0);
 $4 = (($0) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$0>>2] = 33;
 $5 = (($0) + 4|0);
 HEAP32[$5>>2] = 18;
 dest=$3+0|0; src=771888+0|0; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 18|0);
 HEAP8[$6>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,91,93,($0|0),184,(2590|0),0,0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = HEAP8[$0>>0]|0;
  $16 = $15 & 1;
  $17 = ($16<<24>>24)==(0);
  if ($17) {
   ___resumeException($13|0);
   // unreachable;
  }
  $18 = HEAP32[$4>>2]|0;
  __ZdlPv($18);
  ___resumeException($13|0);
  // unreachable;
 } else {
  $9 = HEAP8[$0>>0]|0;
  $10 = $9 & 1;
  $11 = ($10<<24>>24)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$4>>2]|0;
  __ZdlPv($12);
  STACKTOP = sp;return;
 }
}
function __ZN18AnimatorController15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(91,566088,2021,0);
 STACKTOP = sp;return;
}
function __ZN25RuntimeAnimatorController12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18AnimatorController7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(184,$$byval_copy2,1,16,772056,56)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(2022,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((771912 + 8|0));
  $6 = (($3) + 68|0);
  HEAP32[$6>>2] = 0;
  $7 = (($3) + 76|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 80|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 72|0);
  HEAP32[$9>>2] = 61;
  $10 = (($3) + 84|0);
  HEAP8[$10>>0] = 1;
  $11 = (($3) + 88|0);
  HEAP32[$11>>2] = ((768664 + 8|0));
  $12 = (($3) + 96|0);
  HEAP32[$12>>2] = 0;
  $13 = (($3) + 100|0);
  HEAP32[$13>>2] = 0;
  $14 = (($3) + 108|0);
  HEAP32[$14>>2] = 4096;
  $15 = (($3) + 92|0);
  HEAP32[$15>>2] = 0;
  $16 = (($3) + 112|0);
  HEAP32[$16>>2] = 0;
  $17 = (($3) + 116|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 120|0);
  HEAP32[$18>>2] = 0;
  $19 = (($3) + 128|0);
  HEAP32[$19>>2] = 0;
  $20 = (($3) + 132|0);
  HEAP32[$20>>2] = 0;
  $21 = (($3) + 124|0);
  HEAP32[$21>>2] = $19;
  $22 = (($3) + 136|0);
  HEAP8[$22>>0] = 1;
  $23 = (($3) + 144|0);
  $24 = (($3) + 164|0);
  HEAP32[$24>>2] = 0;
  $25 = (($3) + 168|0);
  HEAP32[$25>>2] = 0;
  $26 = (($3) + 160|0);
  ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;
  HEAP32[$26>>2] = 61;
  $27 = (($3) + 172|0);
  HEAP32[$27>>2] = 0;
  $28 = (($3) + 176|0);
  HEAP32[$28>>2] = 0;
  $29 = (($3) + 180|0);
  HEAP32[$29>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(772056|0),56);
 $32 = __THREW__; __THREW__ = 0;
 $33 = $32&1;
 if ($33) {
  $34 = ___cxa_find_matching_catch(0|0)|0;
  $35 = tempRet0;
  ___clang_call_terminate($34);
  // unreachable;
 } else {
  ___resumeException($30|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK18AnimatorController25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 91;
}
function __ZN18AnimatorController17MainThreadCleanupEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18AnimatorController10ClearAssetEv($this);
 __ZN25RuntimeAnimatorController17MainThreadCleanupEv($this);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController10ClearAssetEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i$i = 0, $c$01$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 120|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 112|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 124|0);
 $4 = (($this) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($3,$5);
 $6 = (($this) + 132|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 128|0);
 HEAP32[$3>>2] = $7;
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 96|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $c$01$i = $9;
  while(1) {
   $11 = HEAP32[$c$01$i>>2]|0;
   $12 = HEAP32[628296>>2]|0;
   HEAP32[$0>>2] = $12;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($c$01$i,$$byval_copy2);
   $13 = ($11|0)==(0|0);
   if ($13) {
    break;
   } else {
    $c$01$i = $11;
   }
  }
 }
 HEAP32[$8>>2] = 0;
 $14 = (($this) + 100|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 104|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 80|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)>(-1);
 if ($18) {
  $19 = (($this) + 68|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($this) + 72|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$0>>2] = $22;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($20,$$byval_copy2);
  HEAP32[$19>>2] = 0;
 }
 $23 = (($this) + 76|0);
 HEAP32[$23>>2] = 0;
 HEAP32[$16>>2] = 0;
 $24 = (($this) + 172|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($this) + 176|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==($25|0);
 if (!($28)) {
  $__new_last2$i$i$i = $25;
  $scevgep$i$i$i = (($27) + -4|0);
  $29 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($29)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $30 = $uglygep3$i$i$i >>> 2;
  $31 = $30 ^ -1;
  $scevgep4$i$i$i = (($27) + ($31<<2)|0);
  HEAP32[$26>>2] = $scevgep4$i$i$i;
 }
 $32 = (($this) + 144|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 148|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==($33|0);
 if (!($36)) {
  $__new_last2$i$i$i$i$i$i = $33;
  $scevgep$i$i$i$i$i$i = (($35) + -16|0);
  $37 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($37)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $38 = $uglygep3$i$i$i$i$i$i >>> 4;
  $39 = $38 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($35) + ($39<<4)|0);
  HEAP32[$34>>2] = $scevgep4$i$i$i$i$i$i;
 }
 $40 = (($this) + 168|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($41|0)>(-1);
 if (!($42)) {
  $47 = (($this) + 164|0);
  HEAP32[$47>>2] = 0;
  HEAP32[$40>>2] = 0;
  STACKTOP = sp;return;
 }
 $43 = (($this) + 156|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 160|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$0>>2] = $46;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($44,$$byval_copy2);
 HEAP32[$43>>2] = 0;
 $47 = (($this) + 164|0);
 HEAP32[$47>>2] = 0;
 HEAP32[$40>>2] = 0;
 STACKTOP = sp;return;
}
function __ZZN18AnimatorController15InitializeClassEvEN47FunctorImpl_AnimatorController_kDidModifyMotion4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN25RuntimeAnimatorController17NotifyObjectUsersERK17MessageIdentifier($object,566032);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController13AwakeFromLoadE17AwakeFromLoadMode($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 124|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 4095]($this);
 $9 = HEAP32[$3>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = (($10) + 100|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_ii[$12 & 4095]($this)|0);
 $14 = (($this) + 88|0);
 $15 = (__ZN11UnityEngine9Animation26CreateAnimationSetBindingsEPKN7mecanim9animation18ControllerConstantERK13dynamic_arrayI4PPtrI13AnimationClipELj4EERNS1_6memory9AllocatorE($9,$13,$14)|0);
 HEAP32[$0>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN18AnimatorController16CheckConsistencyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK18AnimatorController17GetAnimationClipsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 92|0);
 $2 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $3 = (($this) + 68|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNK18AnimatorController27GetAnimationClipsToRegisterEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$byval_copy = 0, $$idx$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($this)|0);
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($agg$result) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($agg$result) + 8|0);
 $9 = (($agg$result) + 12|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$agg$result>>2] = 0;
 $10 = HEAP32[$4>>2]|0;
 $11 = (($4) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $$idx$i$i = $12 << 2;
 $13 = $$idx$i$i >> 2;
 HEAP32[$8>>2] = $13;
 $14 = ($13|0)==(0);
 if ($14) {
  $16 = 0;$17 = 0;
  _memcpy(($16|0),($10|0),($17|0))|0;
  STACKTOP = sp;return;
 }
 HEAP32[$9>>2] = $13;
 HEAP32[$0>>2] = $6;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $15 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i,4,$$byval_copy,0,772056,370)|0);
 HEAP32[$agg$result>>2] = $15;
 $16 = $15;$17 = $$idx$i$i;
 _memcpy(($16|0),($10|0),($17|0))|0;
 STACKTOP = sp;return;
}
function __ZN18AnimatorController8GetAssetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN18AnimatorController23GetAnimationSetBindingsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK18AnimatorController12StringFromIDEj($agg$result,$this,$id) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $id = $id|0;
 var $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 128|0);
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $$0$ph7$i$i$i = $2;$$01$ph6$i$in$i$i = $1;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $4 = (($$013$i$in$i$i) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5>>>0)<($id>>>0);
    if (!($6)) {
     break;
    }
    $9 = (($$013$i$in$i$i) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $10;
    }
   }
   $7 = HEAP32[$$013$i$in$i$i>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $7;
   }
  }
  $12 = ($$0$ph5$i$i$i|0)==($2|0);
  if (!($12)) {
   $13 = (($$0$ph5$i$i$i) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14>>>0)>($id>>>0);
   if (!($15)) {
    $16 = (($$0$ph5$i$i$i) + 20|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = $17 & 1;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     $20 = (($16) + 1|0);
     $21 = $17&255;
     $22 = $21 >>> 1;
     $29 = $22;$39 = $20;
    } else {
     $23 = (($$0$ph5$i$i$i) + 28|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($$0$ph5$i$i$i) + 24|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26>>>0)>(4294967279);
     if ($27) {
      __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
      // unreachable;
     } else {
      $29 = $26;$39 = $24;
     }
    }
    $28 = ($29>>>0)<(11);
    if ($28) {
     $30 = $29 << 1;
     $31 = $30&255;
     HEAP8[$agg$result>>0] = $31;
     $32 = (($agg$result) + 1|0);
     $__p$0$i$i$i$i = $32;
    } else {
     $33 = (($29) + 16)|0;
     $34 = $33 & -16;
     $35 = (__Znwj($34)|0);
     $36 = (($agg$result) + 8|0);
     HEAP32[$36>>2] = $35;
     $37 = $34 | 1;
     HEAP32[$agg$result>>2] = $37;
     $38 = (($agg$result) + 4|0);
     HEAP32[$38>>2] = $29;
     $__p$0$i$i$i$i = $35;
    }
    _memcpy(($__p$0$i$i$i$i|0),($39|0),($29|0))|0;
    $40 = (($__p$0$i$i$i$i) + ($29)|0);
    HEAP8[$40>>0] = 0;
    STACKTOP = sp;return;
   }
  }
 }
 HEAP8[$agg$result>>0] = 0;
 $41 = (($agg$result) + 1|0);
 HEAP8[$41>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK18AnimatorController13GetBehavioursEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 172|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK18AnimatorController41GetStateMachineBehaviourVectorDescriptionEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN18AnimatorControllerD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN18AnimatorControllerD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN18AnimatorControllerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3704,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZNK18AnimatorController28HasMultiThreadedStateMachineEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN18AnimatorController8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01$i$i$i = 0, $size$i$i$i1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i1 = sp;
 __ZN25RuntimeAnimatorController8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 88|0);
 $1 = (($transfer) + 4|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 112|0);
 $3 = (($this) + 116|0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  $10 = HEAP32[$3>>2]|0;
  HEAP32[$5>>2] = $10;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$3,4);
 }
 $11 = HEAP32[$2>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$1>>2]|0;
  $14 = HEAP32[$3>>2]|0;
  __ZN7mecanim6memory16ChainedAllocator7ReserveEj($13,$14);
  $15 = HEAP32[$13>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_iiii[$16 & 2047]($13,40,4)|0);
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = 0;
  } else {
   dest=$17+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $19 = $17;
  }
  HEAP32[$2>>2] = $19;
  $20 = $19;
 } else {
  $20 = $11;
 }
 __ZN7mecanim9animation18ControllerConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($20,$transfer);
 $21 = (($this) + 124|0);
 __ZN19StreamedBinaryWriteILb0EE19TransferSTLStyleMapINSt3__13mapIj8UnityStrNS2_4lessIjEENS2_9allocatorINS2_4pairIKjS4_EEEEEEEEvRT_17TransferMetaFlags($transfer,$21,0);
 $22 = (($this) + 76|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$size$i$i$i1>>2] = $23;
 $24 = HEAP32[$4>>2]|0;
 $25 = (($24) + 4|0);
 $26 = HEAP32[$7>>2]|0;
 $27 = ($25>>>0)<($26>>>0);
 if ($27) {
  HEAP32[$24>>2] = $23;
  HEAP32[$4>>2] = $25;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i$i1,4);
 }
 $28 = (($this) + 68|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$22>>2]|0;
 $31 = (($29) + ($30<<2)|0);
 $32 = ($30|0)==(0);
 if (!($32)) {
  $i$01$i$i$i = $29;
  while(1) {
   __ZN4PPtrI13AnimationClipE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($i$01$i$i$i,$transfer);
   $33 = (($i$01$i$i$i) + 4|0);
   $34 = ($33|0)==($31|0);
   if ($34) {
    break;
   } else {
    $i$01$i$i$i = $33;
   }
  }
 }
 $35 = (($this) + 140|0);
 __ZN38StateMachineBehaviourVectorDescription8TransferI19StreamedBinaryWriteILb0EEEEvRT_($35,$transfer);
 $36 = (($this) + 176|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + 172|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $37;
 $41 = $39;
 $42 = (($40) - ($41))|0;
 $43 = $42 >> 2;
 HEAP32[$size$i$i$i1>>2] = $43;
 $44 = HEAP32[$4>>2]|0;
 $45 = (($44) + 4|0);
 $46 = HEAP32[$7>>2]|0;
 $47 = ($45>>>0)<($46>>>0);
 if ($47) {
  HEAP32[$44>>2] = $43;
  HEAP32[$4>>2] = $45;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i$i1,4);
 }
 $48 = HEAP32[$36>>2]|0;
 $49 = HEAP32[$38>>2]|0;
 $50 = ($49|0)==($48|0);
 if (!($50)) {
  $51 = $49;
  while(1) {
   __ZN4PPtrI13MonoBehaviourE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($51,$transfer);
   $52 = (($51) + 4|0);
   $53 = ($52|0)==($48|0);
   if ($53) {
    break;
   } else {
    $51 = $52;
   }
  }
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $54 = (($this) + 136|0);
 $55 = HEAP32[$4>>2]|0;
 $56 = (($55) + 1|0);
 $57 = HEAP32[$7>>2]|0;
 $58 = ($56>>>0)<($57>>>0);
 if ($58) {
  $59 = HEAP8[$54>>0]|0;
  HEAP8[$55>>0] = $59;
  $60 = HEAP32[$4>>2]|0;
  $61 = (($60) + 1|0);
  HEAP32[$4>>2] = $61;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$54,1);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI13MonoBehaviourE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN38StateMachineBehaviourVectorDescription8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, $size$i$i$i1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i1 = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 HEAP32[$size$i$i$i1>>2] = $7;
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i1,4);
 }
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==($14|0);
 if (!($16)) {
  $17 = $15;
  while(1) {
   __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI19StreamedBinaryWriteILb0EEEEvRS4_RT_($17,$transfer);
   $18 = (($17) + 16|0);
   $19 = ($18|0)==($14|0);
   if ($19) {
    break;
   } else {
    $17 = $18;
   }
  }
 }
 $20 = (($this) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$size$i$i$i1>>2] = $21;
 $22 = HEAP32[$8>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$11>>2]|0;
 $25 = ($23>>>0)<($24>>>0);
 if ($25) {
  HEAP32[$22>>2] = $21;
  HEAP32[$8>>2] = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$size$i$i$i1,4);
 }
 $26 = (($this) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$20>>2]|0;
 $29 = (($27) + ($28<<2)|0);
 $30 = ($28|0)==(0);
 if ($30) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i = $27;
 }
 while(1) {
  $31 = HEAP32[$8>>2]|0;
  $32 = (($31) + 4|0);
  $33 = HEAP32[$11>>2]|0;
  $34 = ($32>>>0)<($33>>>0);
  if ($34) {
   $35 = HEAP32[$i$01$i$i$i>>2]|0;
   HEAP32[$31>>2] = $35;
   HEAP32[$8>>2] = $32;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$i$01$i$i$i,4);
  }
  $36 = (($i$01$i$i$i) + 4|0);
  $37 = ($36|0)==($29|0);
  if ($37) {
   break;
  } else {
   $i$01$i$i$i = $36;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI19StreamedBinaryWriteILb0EEEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre1$i$i$i = 0, $$pre2$i$i$i = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$data>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$data,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre1$i$i$i = HEAP32[$3>>2]|0;
  $11 = $$pre1$i$i$i;$9 = $$pre$i$i$i;
 }
 $7 = (($data) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $15 = $$pre;$17 = $$pre3;
 }
 $13 = (($data) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$13>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $$pre2$i$i$i = HEAP32[$3>>2]|0;
  $21 = $$pre$i$i$i1;$23 = $$pre2$i$i$i;
 }
 $19 = (($data) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation18ControllerConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i1 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i1>>2] = $0;
 $3 = (($ArrayTransfer$i1) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i1) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation13LayerConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i1,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i1>>2] = $5;
 $8 = (($ArrayTransfer$i1) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($ArrayTransfer$i1) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine20StateMachineConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i1,0);
 $10 = (($this) + 24|0);
 __ZN19StreamedBinaryWriteILb0EE8TransferI9OffsetPtrIN7mecanim18ValueArrayConstantEEEEvRT_PKc17TransferMetaFlags($transfer,$10,0,0);
 $11 = (($this) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $$pre$i$i = (($this) + 36|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$27 = $12;
  $25 = $11;
  $26 = (($27) + ($25))|0;
  $28 = $26;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $28;
  __ZN7mecanim10ValueArray8TransferI19StreamedBinaryWriteILb0EEEEvRT_($28,$transfer);
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_iiii[$16 & 2047]($14,72,4)|0);
 $18 = ($17|0)==(0|0);
 if ($18) {
  $22 = 0;$24 = 0;
 } else {
  dest=$17+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $19 = $17;
  $20 = $11;
  $21 = (($19) - ($20))|0;
  $22 = $21;$24 = $17;
 }
 HEAP32[$11>>2] = $22;
 $23 = (($this) + 36|0);
 HEAP32[$23>>2] = $24;
 $$pre$phi$i$iZ2D = $23;$27 = $22;
 $25 = $11;
 $26 = (($27) + ($25))|0;
 $28 = $26;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $28;
 __ZN7mecanim10ValueArray8TransferI19StreamedBinaryWriteILb0EEEEvRT_($28,$transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim10ValueArray8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $i$01$i$i$i$i = 0, $i$01$i$i$i$i10 = 0, $i$01$i$i$i$i14 = 0, $i$01$i$i$i$i19 = 0, $i$01$i$i$i$i6 = 0, $i$02$i$i$i$i = 0, $size$i$i$i$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i17 = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$this>>2]|0;
 HEAP32[$size$i$i$i$i17>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i17,4);
 }
 $8 = $0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = (($this) + 8|0);
 $13 = HEAP32[$this>>2]|0;
 $14 = (($11) + ($13)|0);
 HEAP32[$12>>2] = $11;
 $15 = ($13|0)==(0);
 if (!($15)) {
  $i$01$i$i$i$i = $11;
  while(1) {
   $16 = HEAP32[$2>>2]|0;
   $17 = (($16) + 1|0);
   $18 = HEAP32[$5>>2]|0;
   $19 = ($17>>>0)<($18>>>0);
   if ($19) {
    $20 = HEAP8[$i$01$i$i$i$i>>0]|0;
    HEAP8[$16>>0] = $20;
    $21 = HEAP32[$2>>2]|0;
    $22 = (($21) + 1|0);
    HEAP32[$2>>2] = $22;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i$i,1);
   }
   $23 = (($i$01$i$i$i$i) + 1|0);
   $24 = ($23|0)==($14|0);
   if ($24) {
    break;
   } else {
    $i$01$i$i$i$i = $23;
   }
  }
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $25 = (($this) + 16|0);
 $26 = (($this) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$size$i$i$i$i17>>2] = $27;
 $28 = HEAP32[$2>>2]|0;
 $29 = (($28) + 4|0);
 $30 = HEAP32[$5>>2]|0;
 $31 = ($29>>>0)<($30>>>0);
 if ($31) {
  HEAP32[$28>>2] = $27;
  HEAP32[$2>>2] = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i17,4);
 }
 $32 = $25;
 $33 = HEAP32[$25>>2]|0;
 $34 = (($33) + ($32))|0;
 $35 = $34;
 $36 = (($this) + 20|0);
 $37 = HEAP32[$26>>2]|0;
 $38 = (($35) + ($37<<2)|0);
 HEAP32[$36>>2] = $35;
 $39 = ($37|0)==(0);
 if (!($39)) {
  $i$02$i$i$i$i = $35;
  while(1) {
   $40 = HEAP32[$2>>2]|0;
   $41 = (($40) + 4|0);
   $42 = HEAP32[$5>>2]|0;
   $43 = ($41>>>0)<($42>>>0);
   if ($43) {
    $44 = HEAP32[$i$02$i$i$i$i>>2]|0;
    HEAP32[$40>>2] = $44;
    HEAP32[$2>>2] = $41;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$02$i$i$i$i,4);
   }
   $45 = (($i$02$i$i$i$i) + 4|0);
   $46 = ($45|0)==($38|0);
   if ($46) {
    break;
   } else {
    $i$02$i$i$i$i = $45;
   }
  }
 }
 $47 = (($this) + 28|0);
 $48 = (($this) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 HEAP32[$size$i$i$i$i17>>2] = $49;
 $50 = HEAP32[$2>>2]|0;
 $51 = (($50) + 4|0);
 $52 = HEAP32[$5>>2]|0;
 $53 = ($51>>>0)<($52>>>0);
 if ($53) {
  HEAP32[$50>>2] = $49;
  HEAP32[$2>>2] = $51;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i17,4);
 }
 $54 = $47;
 $55 = HEAP32[$47>>2]|0;
 $56 = (($55) + ($54))|0;
 $57 = $56;
 $58 = (($this) + 32|0);
 $59 = HEAP32[$48>>2]|0;
 $60 = (($57) + ($59<<2)|0);
 HEAP32[$58>>2] = $57;
 $61 = ($59|0)==(0);
 if (!($61)) {
  $i$01$i$i$i$i6 = $57;
  while(1) {
   $62 = HEAP32[$2>>2]|0;
   $63 = (($62) + 4|0);
   $64 = HEAP32[$5>>2]|0;
   $65 = ($63>>>0)<($64>>>0);
   if ($65) {
    $66 = Math_fround(HEAPF32[$i$01$i$i$i$i6>>2]);
    HEAPF32[$62>>2] = $66;
    HEAP32[$2>>2] = $63;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i$i6,4);
   }
   $67 = (($i$01$i$i$i$i6) + 4|0);
   $68 = ($67|0)==($60|0);
   if ($68) {
    break;
   } else {
    $i$01$i$i$i$i6 = $67;
   }
  }
 }
 $69 = (($this) + 40|0);
 $70 = (($this) + 36|0);
 $71 = HEAP32[$70>>2]|0;
 HEAP32[$size$i$i$i$i17>>2] = $71;
 $72 = HEAP32[$2>>2]|0;
 $73 = (($72) + 4|0);
 $74 = HEAP32[$5>>2]|0;
 $75 = ($73>>>0)<($74>>>0);
 if ($75) {
  HEAP32[$72>>2] = $71;
  HEAP32[$2>>2] = $73;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i17,4);
 }
 $76 = $69;
 $77 = HEAP32[$69>>2]|0;
 $78 = (($77) + ($76))|0;
 $79 = $78;
 $80 = (($this) + 44|0);
 $81 = HEAP32[$70>>2]|0;
 $82 = (($79) + ($81<<4)|0);
 HEAP32[$80>>2] = $79;
 $83 = ($81|0)==(0);
 if (!($83)) {
  $i$01$i$i$i$i10 = $79;
  while(1) {
   __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($i$01$i$i$i$i10,$transfer);
   $84 = (($i$01$i$i$i$i10) + 16|0);
   $85 = ($84|0)==($82|0);
   if ($85) {
    break;
   } else {
    $i$01$i$i$i$i10 = $84;
   }
  }
 }
 $86 = (($this) + 52|0);
 $87 = (($this) + 48|0);
 $88 = HEAP32[$87>>2]|0;
 HEAP32[$size$i$i$i$i17>>2] = $88;
 $89 = HEAP32[$2>>2]|0;
 $90 = (($89) + 4|0);
 $91 = HEAP32[$5>>2]|0;
 $92 = ($90>>>0)<($91>>>0);
 if ($92) {
  HEAP32[$89>>2] = $88;
  HEAP32[$2>>2] = $90;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i17,4);
 }
 $93 = $86;
 $94 = HEAP32[$86>>2]|0;
 $95 = (($94) + ($93))|0;
 $96 = $95;
 $97 = (($this) + 56|0);
 $98 = HEAP32[$87>>2]|0;
 $99 = (($96) + ($98<<4)|0);
 HEAP32[$97>>2] = $96;
 $100 = ($98|0)==(0);
 if (!($100)) {
  $i$01$i$i$i$i14 = $96;
  while(1) {
   __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($i$01$i$i$i$i14,$transfer);
   $101 = (($i$01$i$i$i$i14) + 16|0);
   $102 = ($101|0)==($99|0);
   if ($102) {
    break;
   } else {
    $i$01$i$i$i$i14 = $101;
   }
  }
 }
 $103 = (($this) + 64|0);
 $104 = (($this) + 60|0);
 $105 = HEAP32[$104>>2]|0;
 HEAP32[$size$i$i$i$i17>>2] = $105;
 $106 = HEAP32[$2>>2]|0;
 $107 = (($106) + 4|0);
 $108 = HEAP32[$5>>2]|0;
 $109 = ($107>>>0)<($108>>>0);
 if ($109) {
  HEAP32[$106>>2] = $105;
  HEAP32[$2>>2] = $107;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i17,4);
 }
 $110 = $103;
 $111 = HEAP32[$103>>2]|0;
 $112 = (($111) + ($110))|0;
 $113 = $112;
 $114 = (($this) + 68|0);
 $115 = HEAP32[$104>>2]|0;
 $116 = (($113) + ($115<<4)|0);
 HEAP32[$114>>2] = $113;
 $117 = ($115|0)==(0);
 if ($117) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i$i19 = $113;
 }
 while(1) {
  __ZN15SerializeTraitsIKN4math7_float4EE8TransferI19StreamedBinaryWriteILb0EEEEvRS2_RT_($i$01$i$i$i$i19,$transfer);
  $118 = (($i$01$i$i$i$i19) + 16|0);
  $119 = ($118|0)==($116|0);
  if ($119) {
   break;
  } else {
   $i$01$i$i$i$i19 = $118;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine20StateMachineConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 4|0);
 $i$01 = $23;
 while(1) {
  $27 = HEAP32[$i$01>>2]|0;
  $28 = ($27|0)==(0);
  if ($28) {
   $29 = HEAP32[$26>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,44,4)|0);
   $33 = ($32|0)==(0|0);
   if ($33) {
    $38 = 0;$40 = 0;
   } else {
    $34 = (($32) + 28|0);
    ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;HEAP32[$32+20>>2]=0|0;
    ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
    $35 = $32;
    $36 = $i$01;
    $37 = (($35) - ($36))|0;
    $38 = $37;$40 = $32;
   }
   HEAP32[$i$01>>2] = $38;
   $39 = (($i$01) + 4|0);
   HEAP32[$39>>2] = $40;
   $$pre$phi$i$iZ2D = $39;$43 = $38;
  } else {
   $$pre$i$i = (($i$01) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$43 = $27;
  }
  $41 = $i$01;
  $42 = (($43) + ($41))|0;
  $44 = $42;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $44;
  __ZN7mecanim12statemachine20StateMachineConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($44,$this);
  $45 = (($i$01) + 8|0);
  $46 = ($45|0)==($18|0);
  if ($46) {
   break;
  } else {
   $i$01 = $45;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine20StateMachineConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size$i$i$i$i>>2] = $0;
 $3 = (($size$i$i$i$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($size$i$i$i$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine13StateConstantEEEEEvRT_17TransferMetaFlags($transfer,$size$i$i$i$i,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$size$i$i$i$i>>2] = $5;
 $8 = (($size$i$i$i$i) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($size$i$i$i$i) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$size$i$i$i$i,0);
 $10 = (($this) + 28|0);
 $11 = (($this) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$size$i$i$i$i>>2] = $12;
 $13 = (($transfer) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 4|0);
 $16 = (($transfer) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15>>>0)<($17>>>0);
 if ($18) {
  HEAP32[$14>>2] = $12;
  HEAP32[$13>>2] = $15;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$size$i$i$i$i,4);
 }
 $19 = $10;
 $20 = HEAP32[$10>>2]|0;
 $21 = (($20) + ($19))|0;
 $22 = $21;
 $23 = (($this) + 32|0);
 $24 = HEAP32[$11>>2]|0;
 $25 = (($22) + ($24<<3)|0);
 HEAP32[$23>>2] = $22;
 $26 = ($24|0)==(0);
 if (!($26)) {
  $i$01$i$i$i$i = $22;
  while(1) {
   __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEE8TransferI19StreamedBinaryWriteILb0EEEEvRS4_RT_($i$01$i$i$i$i,$transfer);
   $27 = (($i$01$i$i$i$i) + 8|0);
   $28 = ($27|0)==($25|0);
   if ($28) {
    break;
   } else {
    $i$01$i$i$i$i = $27;
   }
  }
 }
 $29 = (($this) + 36|0);
 $30 = HEAP32[$13>>2]|0;
 $31 = (($30) + 4|0);
 $32 = HEAP32[$16>>2]|0;
 $33 = ($31>>>0)<($32>>>0);
 if ($33) {
  $34 = HEAP32[$29>>2]|0;
  HEAP32[$30>>2] = $34;
  HEAP32[$13>>2] = $31;
  $37 = $31;$39 = $32;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$29,4);
  $$pre = HEAP32[$13>>2]|0;
  $$pre3 = HEAP32[$16>>2]|0;
  $37 = $$pre;$39 = $$pre3;
 }
 $35 = (($this) + 40|0);
 $36 = (($37) + 4|0);
 $38 = ($36>>>0)<($39>>>0);
 if ($38) {
  $40 = HEAP32[$35>>2]|0;
  HEAP32[$37>>2] = $40;
  HEAP32[$13>>2] = $36;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($13,$35,4);
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEE8TransferI19StreamedBinaryWriteILb0EEEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i = sp;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,20,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = 0;$15 = 0;
  } else {
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 8|0);
   HEAP32[$9>>2] = 0;
   $10 = $6;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $6;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phi2Z2D = $2;$$pre$phiZ2D = $14;$18 = $13;
 } else {
  $$pre = (($data) + 4|0);
  $$pre1 = (($transfer) + 4|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;$18 = $0;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phiZ2D>>2] = $19;
 $20 = (($19) + 4|0);
 $21 = HEAP32[$$pre$phi2Z2D>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i>>2] = $20;
 $22 = (($ArrayTransfer$i$i$i$i) + 4|0);
 HEAP32[$22>>2] = $19;
 $23 = (($ArrayTransfer$i$i$i$i) + 8|0);
 HEAP32[$23>>2] = $21;
 __ZN15SerializeTraitsI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEE8TransferI19StreamedBinaryWriteILb0EEEEvRS6_RT_($ArrayTransfer$i$i$i$i,$transfer);
 $24 = (($19) + 12|0);
 $25 = (($transfer) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 4|0);
 $28 = (($transfer) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27>>>0)<($29>>>0);
 if ($30) {
  $31 = HEAP32[$24>>2]|0;
  HEAP32[$26>>2] = $31;
  HEAP32[$25>>2] = $27;
  $34 = $27;$36 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($25,$24,4);
  $$pre$i$i$i = HEAP32[$25>>2]|0;
  $$pre1$i$i$i = HEAP32[$28>>2]|0;
  $34 = $$pre$i$i$i;$36 = $$pre1$i$i$i;
 }
 $32 = (($19) + 16|0);
 $33 = (($34) + 1|0);
 $35 = ($33>>>0)<($36>>>0);
 if ($35) {
  $37 = HEAP8[$32>>0]|0;
  HEAP8[$34>>0] = $37;
  $38 = HEAP32[$25>>2]|0;
  $39 = (($38) + 1|0);
  HEAP32[$25>>2] = $39;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($25,$32,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN15SerializeTraitsI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEE8TransferI19StreamedBinaryWriteILb0EEEEvRS6_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ArrayTransfer$i$i$i$i$i$i = 0, $i$01$i = 0, $size$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i$i = sp + 4|0;
 $size$i = sp;
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size$i>>2] = $2;
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  HEAP32[$4>>2] = $2;
  HEAP32[$3>>2] = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$size$i,4);
 }
 $9 = HEAP32[$data>>2]|0;
 $10 = $9;
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11) + ($10))|0;
 $13 = $12;
 $14 = (($9) + 4|0);
 HEAP32[$14>>2] = $13;
 $15 = HEAP32[$0>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($13) + ($16<<3)|0);
 $18 = HEAP32[$data>>2]|0;
 $19 = $18;
 $20 = HEAP32[$18>>2]|0;
 $21 = (($20) + ($19))|0;
 $22 = $21;
 $23 = (($18) + 4|0);
 HEAP32[$23>>2] = $22;
 $24 = ($22|0)==($17|0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = (($transfer) + 4|0);
 $26 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 $27 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 $i$01$i = $22;
 while(1) {
  $28 = HEAP32[$i$01$i>>2]|0;
  $29 = ($28|0)==(0);
  if ($29) {
   $30 = HEAP32[$25>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[$31>>2]|0;
   $33 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,16,4)|0);
   $34 = ($33|0)==(0|0);
   if ($34) {
    $40 = 0;$42 = 0;
   } else {
    HEAP32[$33>>2] = 0;
    $35 = (($33) + 8|0);
    HEAP32[$35>>2] = 0;
    $36 = (($33) + 12|0);
    HEAP32[$36>>2] = 0;
    $37 = $33;
    $38 = $i$01$i;
    $39 = (($37) - ($38))|0;
    $40 = $39;$42 = $33;
   }
   HEAP32[$i$01$i>>2] = $40;
   $41 = (($i$01$i) + 4|0);
   HEAP32[$41>>2] = $42;
   $$pre$phi$i$iZ2D = $41;$45 = $40;
  } else {
   $$pre$i$i = (($i$01$i) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$45 = $28;
  }
  $43 = $i$01$i;
  $44 = (($45) + ($43))|0;
  $46 = $44;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $46;
  $47 = HEAP32[$3>>2]|0;
  $48 = (($47) + 4|0);
  $49 = HEAP32[$6>>2]|0;
  $50 = ($48>>>0)<($49>>>0);
  if ($50) {
   $51 = HEAP32[$46>>2]|0;
   HEAP32[$47>>2] = $51;
   HEAP32[$3>>2] = $48;
  } else {
   $52 = $44;
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$52,4);
  }
  $53 = (($46) + 8|0);
  $54 = (($46) + 4|0);
  $55 = HEAP32[$25>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $53;
  HEAP32[$26>>2] = $54;
  HEAP32[$27>>2] = $55;
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
  $56 = (($i$01$i) + 8|0);
  $57 = ($56|0)==($17|0);
  if ($57) {
   break;
  } else {
   $i$01$i = $56;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 4|0);
 $i$01 = $23;
 while(1) {
  $27 = HEAP32[$i$01>>2]|0;
  $28 = ($27|0)==(0);
  if ($28) {
   $29 = HEAP32[$26>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,16,4)|0);
   $33 = ($32|0)==(0|0);
   if ($33) {
    $40 = 0;$42 = 0;
   } else {
    HEAP32[$32>>2] = 1;
    $34 = (($32) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($32) + 8|0);
    HEAPF32[$35>>2] = Math_fround(0.0);
    $36 = (($32) + 12|0);
    HEAPF32[$36>>2] = Math_fround(0.0);
    $37 = $32;
    $38 = $i$01;
    $39 = (($37) - ($38))|0;
    $40 = $39;$42 = $32;
   }
   HEAP32[$i$01>>2] = $40;
   $41 = (($i$01) + 4|0);
   HEAP32[$41>>2] = $42;
   $$pre$phi$i$iZ2D = $41;$45 = $40;
  } else {
   $$pre$i$i = (($i$01) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$45 = $27;
  }
  $43 = $i$01;
  $44 = (($45) + ($43))|0;
  $46 = $44;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $46;
  __ZN7mecanim12statemachine17ConditionConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($46,$this);
  $47 = (($i$01) + 8|0);
  $48 = ($47|0)==($18|0);
  if ($48) {
   break;
  } else {
   $i$01 = $47;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine17ConditionConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $11 = $$pre3;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $15 = $$pre4;$17 = $$pre5;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $21 = $$pre6;$23 = $$pre7;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $size = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 4|0);
 $i$01 = $23;
 while(1) {
  $27 = HEAP32[$i$01>>2]|0;
  $28 = ($27|0)==(0);
  if ($28) {
   $29 = HEAP32[$26>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,52,4)|0);
   $33 = ($32|0)==(0|0);
   if ($33) {
    $42 = 0;$44 = 0;
   } else {
    $34 = (($32) + 36|0);
    dest=$32+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAPF32[$34>>2] = Math_fround(0.899999976158142089843);
    $35 = (($32) + 40|0);
    HEAP8[$35>>0] = 0;
    $36 = (($32) + 44|0);
    HEAP32[$36>>2] = 0;
    $37 = (($32) + 48|0);
    HEAP8[$37>>0] = 1;
    $38 = (($32) + 49|0);
    HEAP8[$38>>0] = 0;
    $39 = $32;
    $40 = $i$01;
    $41 = (($39) - ($40))|0;
    $42 = $41;$44 = $32;
   }
   HEAP32[$i$01>>2] = $42;
   $43 = (($i$01) + 4|0);
   HEAP32[$43>>2] = $44;
   $$pre$phi$i$iZ2D = $43;$47 = $42;
  } else {
   $$pre$i$i = (($i$01) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$47 = $27;
  }
  $45 = $i$01;
  $46 = (($47) + ($45))|0;
  $48 = $46;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $48;
  __ZN7mecanim12statemachine18TransitionConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($48,$this);
  $49 = (($i$01) + 8|0);
  $50 = ($49|0)==($18|0);
  if ($50) {
   break;
  } else {
   $i$01 = $49;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine18TransitionConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $0;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 $5 = (($this) + 12|0);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)<($10>>>0);
 if ($11) {
  $12 = HEAP32[$5>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$6>>2] = $8;
  $15 = $8;$17 = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$5,4);
  $$pre = HEAP32[$6>>2]|0;
  $$pre8 = HEAP32[$9>>2]|0;
  $15 = $$pre;$17 = $$pre8;
 }
 $13 = (($this) + 16|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$13>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$6>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$13,4);
  $$pre9 = HEAP32[$6>>2]|0;
  $$pre10 = HEAP32[$9>>2]|0;
  $21 = $$pre9;$23 = $$pre10;
 }
 $19 = (($this) + 20|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$6>>2] = $20;
  $27 = $20;$29 = $23;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$19,4);
  $$pre11 = HEAP32[$6>>2]|0;
  $$pre12 = HEAP32[$9>>2]|0;
  $27 = $$pre11;$29 = $$pre12;
 }
 $25 = (($this) + 24|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)<($29>>>0);
 if ($28) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$27>>2] = $30;
  HEAP32[$6>>2] = $26;
  $33 = $26;$35 = $29;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$25,4);
  $$pre13 = HEAP32[$6>>2]|0;
  $$pre14 = HEAP32[$9>>2]|0;
  $33 = $$pre13;$35 = $$pre14;
 }
 $31 = (($this) + 28|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)<($35>>>0);
 if ($34) {
  $36 = Math_fround(HEAPF32[$31>>2]);
  HEAPF32[$33>>2] = $36;
  HEAP32[$6>>2] = $32;
  $39 = $32;$41 = $35;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$31,4);
  $$pre15 = HEAP32[$6>>2]|0;
  $$pre16 = HEAP32[$9>>2]|0;
  $39 = $$pre15;$41 = $$pre16;
 }
 $37 = (($this) + 32|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)<($41>>>0);
 if ($40) {
  $42 = Math_fround(HEAPF32[$37>>2]);
  HEAPF32[$39>>2] = $42;
  HEAP32[$6>>2] = $38;
  $45 = $38;$47 = $41;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$37,4);
  $$pre17 = HEAP32[$6>>2]|0;
  $$pre18 = HEAP32[$9>>2]|0;
  $45 = $$pre17;$47 = $$pre18;
 }
 $43 = (($this) + 36|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)<($47>>>0);
 if ($46) {
  $48 = Math_fround(HEAPF32[$43>>2]);
  HEAPF32[$45>>2] = $48;
  HEAP32[$6>>2] = $44;
  $51 = $44;$53 = $47;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$43,4);
  $$pre19 = HEAP32[$6>>2]|0;
  $$pre20 = HEAP32[$9>>2]|0;
  $51 = $$pre19;$53 = $$pre20;
 }
 $49 = (($this) + 40|0);
 $50 = (($51) + 1|0);
 $52 = ($50>>>0)<($53>>>0);
 if ($52) {
  $54 = HEAP8[$49>>0]|0;
  HEAP8[$51>>0] = $54;
  $55 = HEAP32[$6>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$6>>2] = $56;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$49,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $57 = (($this) + 44|0);
 $58 = HEAP32[$6>>2]|0;
 $59 = (($58) + 4|0);
 $60 = HEAP32[$9>>2]|0;
 $61 = ($59>>>0)<($60>>>0);
 if ($61) {
  $62 = HEAP32[$57>>2]|0;
  HEAP32[$58>>2] = $62;
  HEAP32[$6>>2] = $59;
  $65 = $59;$67 = $60;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$57,4);
  $$pre21 = HEAP32[$6>>2]|0;
  $$pre22 = HEAP32[$9>>2]|0;
  $65 = $$pre21;$67 = $$pre22;
 }
 $63 = (($this) + 48|0);
 $64 = (($65) + 1|0);
 $66 = ($64>>>0)<($67>>>0);
 if ($66) {
  $68 = HEAP8[$63>>0]|0;
  HEAP8[$65>>0] = $68;
  $69 = HEAP32[$6>>2]|0;
  $70 = (($69) + 1|0);
  HEAP32[$6>>2] = $70;
  $73 = $70;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$63,1);
  $$pre23 = HEAP32[$6>>2]|0;
  $73 = $$pre23;
 }
 $71 = (($this) + 49|0);
 $72 = (($73) + 1|0);
 $74 = HEAP32[$9>>2]|0;
 $75 = ($72>>>0)<($74>>>0);
 if ($75) {
  $76 = HEAP8[$71>>0]|0;
  HEAP8[$73>>0] = $76;
  $77 = HEAP32[$6>>2]|0;
  $78 = (($77) + 1|0);
  HEAP32[$6>>2] = $78;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($6,$71,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine13StateConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $size = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 4|0);
 $i$01 = $23;
 while(1) {
  $27 = HEAP32[$i$01>>2]|0;
  $28 = ($27|0)==(0);
  if ($28) {
   $29 = HEAP32[$26>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,72,4)|0);
   $33 = ($32|0)==(0|0);
   if ($33) {
    $43 = 0;$45 = 0;
   } else {
    $34 = (($32) + 60|0);
    dest=$32+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAPF32[$34>>2] = Math_fround(1.0);
    $35 = (($32) + 64|0);
    HEAPF32[$35>>2] = Math_fround(0.0);
    $36 = (($32) + 68|0);
    HEAP8[$36>>0] = 1;
    $37 = (($32) + 69|0);
    HEAP8[$37>>0] = 1;
    $38 = (($32) + 70|0);
    HEAP8[$38>>0] = 0;
    $39 = (($32) + 71|0);
    HEAP8[$39>>0] = 0;
    $40 = $32;
    $41 = $i$01;
    $42 = (($40) - ($41))|0;
    $43 = $42;$45 = $32;
   }
   HEAP32[$i$01>>2] = $43;
   $44 = (($i$01) + 4|0);
   HEAP32[$44>>2] = $45;
   $$pre$phi$i$iZ2D = $44;$48 = $43;
  } else {
   $$pre$i$i = (($i$01) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$48 = $27;
  }
  $46 = $i$01;
  $47 = (($48) + ($46))|0;
  $49 = $47;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $49;
  __ZN7mecanim12statemachine13StateConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($49,$this);
  $50 = (($i$01) + 8|0);
  $51 = ($50|0)==($18|0);
  if ($51) {
   break;
  } else {
   $i$01 = $50;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine13StateConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i4 = 0, $i$01$i$i$i$i = 0, $i$02$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i4 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i4>>2] = $0;
 $3 = (($ArrayTransfer$i4) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i4) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$ArrayTransfer$i4>>2] = $7;
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$ArrayTransfer$i4,4);
 }
 $14 = $5;
 $15 = HEAP32[$5>>2]|0;
 $16 = (($15) + ($14))|0;
 $17 = $16;
 $18 = (($this) + 20|0);
 $19 = HEAP32[$6>>2]|0;
 $20 = (($17) + ($19<<2)|0);
 HEAP32[$18>>2] = $17;
 $21 = ($19|0)==(0);
 if ($21) {
  $30 = 0;
 } else {
  $i$02$i$i$i$i = $17;
  while(1) {
   $22 = HEAP32[$8>>2]|0;
   $23 = (($22) + 4|0);
   $24 = HEAP32[$11>>2]|0;
   $25 = ($23>>>0)<($24>>>0);
   if ($25) {
    $26 = HEAP32[$i$02$i$i$i$i>>2]|0;
    HEAP32[$22>>2] = $26;
    HEAP32[$8>>2] = $23;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$i$02$i$i$i$i,4);
   }
   $27 = (($i$02$i$i$i$i) + 4|0);
   $28 = ($27|0)==($20|0);
   if ($28) {
    break;
   } else {
    $i$02$i$i$i$i = $27;
   }
  }
  $$pre = HEAP32[$6>>2]|0;
  $30 = $$pre;
 }
 $29 = (($this) + 24|0);
 HEAP32[$ArrayTransfer$i4>>2] = $30;
 $31 = HEAP32[$8>>2]|0;
 $32 = (($31) + 4|0);
 $33 = HEAP32[$11>>2]|0;
 $34 = ($32>>>0)<($33>>>0);
 if ($34) {
  HEAP32[$31>>2] = $30;
  HEAP32[$8>>2] = $32;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$ArrayTransfer$i4,4);
 }
 $35 = $29;
 $36 = HEAP32[$29>>2]|0;
 $37 = (($36) + ($35))|0;
 $38 = $37;
 $39 = (($this) + 28|0);
 $40 = HEAP32[$6>>2]|0;
 $41 = (($38) + ($40<<4)|0);
 HEAP32[$39>>2] = $38;
 $42 = ($40|0)==(0);
 if (!($42)) {
  $i$01$i$i$i$i = $38;
  while(1) {
   __ZN19StreamedBinaryWriteILb0EE8TransferIN7mecanim12statemachine16LeafInfoConstantEEEvRT_PKc17TransferMetaFlags($transfer,$i$01$i$i$i$i,0,0);
   $43 = (($i$01$i$i$i$i) + 16|0);
   $44 = ($43|0)==($41|0);
   if ($44) {
    break;
   } else {
    $i$01$i$i$i$i = $43;
   }
  }
 }
 $45 = (($this) + 36|0);
 $46 = (($this) + 32|0);
 $47 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i4>>2] = $45;
 $48 = (($ArrayTransfer$i4) + 4|0);
 HEAP32[$48>>2] = $46;
 $49 = (($ArrayTransfer$i4) + 8|0);
 HEAP32[$49>>2] = $47;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4,0);
 $50 = (($this) + 44|0);
 $51 = HEAP32[$8>>2]|0;
 $52 = (($51) + 4|0);
 $53 = HEAP32[$11>>2]|0;
 $54 = ($52>>>0)<($53>>>0);
 if ($54) {
  $55 = HEAP32[$50>>2]|0;
  HEAP32[$51>>2] = $55;
  HEAP32[$8>>2] = $52;
  $58 = $52;$60 = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$50,4);
  $$pre12 = HEAP32[$8>>2]|0;
  $$pre13 = HEAP32[$11>>2]|0;
  $58 = $$pre12;$60 = $$pre13;
 }
 $56 = (($this) + 48|0);
 $57 = (($58) + 4|0);
 $59 = ($57>>>0)<($60>>>0);
 if ($59) {
  $61 = HEAP32[$56>>2]|0;
  HEAP32[$58>>2] = $61;
  HEAP32[$8>>2] = $57;
  $64 = $57;$66 = $60;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$56,4);
  $$pre14 = HEAP32[$8>>2]|0;
  $$pre15 = HEAP32[$11>>2]|0;
  $64 = $$pre14;$66 = $$pre15;
 }
 $62 = (($this) + 52|0);
 $63 = (($64) + 4|0);
 $65 = ($63>>>0)<($66>>>0);
 if ($65) {
  $67 = HEAP32[$62>>2]|0;
  HEAP32[$64>>2] = $67;
  HEAP32[$8>>2] = $63;
  $70 = $63;$72 = $66;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$62,4);
  $$pre16 = HEAP32[$8>>2]|0;
  $$pre17 = HEAP32[$11>>2]|0;
  $70 = $$pre16;$72 = $$pre17;
 }
 $68 = (($this) + 56|0);
 $69 = (($70) + 4|0);
 $71 = ($69>>>0)<($72>>>0);
 if ($71) {
  $73 = HEAP32[$68>>2]|0;
  HEAP32[$70>>2] = $73;
  HEAP32[$8>>2] = $69;
  $76 = $69;$78 = $72;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$68,4);
  $$pre18 = HEAP32[$8>>2]|0;
  $$pre19 = HEAP32[$11>>2]|0;
  $76 = $$pre18;$78 = $$pre19;
 }
 $74 = (($this) + 60|0);
 $75 = (($76) + 4|0);
 $77 = ($75>>>0)<($78>>>0);
 if ($77) {
  $79 = Math_fround(HEAPF32[$74>>2]);
  HEAPF32[$76>>2] = $79;
  HEAP32[$8>>2] = $75;
  $82 = $75;$84 = $78;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$74,4);
  $$pre20 = HEAP32[$8>>2]|0;
  $$pre21 = HEAP32[$11>>2]|0;
  $82 = $$pre20;$84 = $$pre21;
 }
 $80 = (($this) + 64|0);
 $81 = (($82) + 4|0);
 $83 = ($81>>>0)<($84>>>0);
 if ($83) {
  $85 = Math_fround(HEAPF32[$80>>2]);
  HEAPF32[$82>>2] = $85;
  HEAP32[$8>>2] = $81;
  $88 = $81;$90 = $84;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$80,4);
  $$pre22 = HEAP32[$8>>2]|0;
  $$pre23 = HEAP32[$11>>2]|0;
  $88 = $$pre22;$90 = $$pre23;
 }
 $86 = (($this) + 68|0);
 $87 = (($88) + 1|0);
 $89 = ($87>>>0)<($90>>>0);
 if ($89) {
  $91 = HEAP8[$86>>0]|0;
  HEAP8[$88>>0] = $91;
  $92 = HEAP32[$8>>2]|0;
  $93 = (($92) + 1|0);
  HEAP32[$8>>2] = $93;
  $96 = $93;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$86,1);
  $$pre24 = HEAP32[$8>>2]|0;
  $96 = $$pre24;
 }
 $94 = (($this) + 69|0);
 $95 = (($96) + 1|0);
 $97 = HEAP32[$11>>2]|0;
 $98 = ($95>>>0)<($97>>>0);
 if ($98) {
  $99 = HEAP8[$94>>0]|0;
  HEAP8[$96>>0] = $99;
  $100 = HEAP32[$8>>2]|0;
  $101 = (($100) + 1|0);
  HEAP32[$8>>2] = $101;
  $104 = $101;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$94,1);
  $$pre25 = HEAP32[$8>>2]|0;
  $104 = $$pre25;
 }
 $102 = (($this) + 70|0);
 $103 = (($104) + 1|0);
 $105 = HEAP32[$11>>2]|0;
 $106 = ($103>>>0)<($105>>>0);
 if ($106) {
  $107 = HEAP8[$102>>0]|0;
  HEAP8[$104>>0] = $107;
  $108 = HEAP32[$8>>2]|0;
  $109 = (($108) + 1|0);
  HEAP32[$8>>2] = $109;
  $112 = $109;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$102,1);
  $$pre26 = HEAP32[$8>>2]|0;
  $112 = $$pre26;
 }
 $110 = (($this) + 71|0);
 $111 = (($112) + 1|0);
 $113 = HEAP32[$11>>2]|0;
 $114 = ($111>>>0)<($113>>>0);
 if ($114) {
  $115 = HEAP8[$110>>0]|0;
  HEAP8[$112>>0] = $115;
  $116 = HEAP32[$8>>2]|0;
  $117 = (($116) + 1|0);
  HEAP32[$8>>2] = $117;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$110,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i$i = sp + 4|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 4|0);
 $27 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 $28 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 $i$01 = $23;
 while(1) {
  $29 = HEAP32[$i$01>>2]|0;
  $30 = ($29|0)==(0);
  if ($30) {
   $31 = HEAP32[$26>>2]|0;
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$32>>2]|0;
   $34 = (FUNCTION_TABLE_iiii[$33 & 2047]($31,12,4)|0);
   $35 = ($34|0)==(0|0);
   if ($35) {
    $41 = 0;$43 = 0;
   } else {
    HEAP32[$34>>2] = 0;
    $36 = (($34) + 4|0);
    HEAP32[$36>>2] = 0;
    $37 = (($34) + 8|0);
    HEAP32[$37>>2] = 0;
    $38 = $34;
    $39 = $i$01;
    $40 = (($38) - ($39))|0;
    $41 = $40;$43 = $34;
   }
   HEAP32[$i$01>>2] = $41;
   $42 = (($i$01) + 4|0);
   HEAP32[$42>>2] = $43;
   $$pre$phi$i$iZ2D = $42;$46 = $41;
  } else {
   $$pre$i$i = (($i$01) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$46 = $29;
  }
  $44 = $i$01;
  $45 = (($46) + ($44))|0;
  $47 = $45;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $47;
  $48 = (($47) + 4|0);
  $49 = HEAP32[$26>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $48;
  HEAP32[$27>>2] = $47;
  HEAP32[$28>>2] = $49;
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i$i$i,0);
  $50 = (($i$01) + 8|0);
  $51 = ($50|0)==($18|0);
  if ($51) {
   break;
  } else {
   $i$01 = $50;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $size = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 4|0);
 $i$01 = $23;
 while(1) {
  $27 = HEAP32[$i$01>>2]|0;
  $28 = ($27|0)==(0);
  if ($28) {
   $29 = HEAP32[$26>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,64,4)|0);
   $33 = ($32|0)==(0|0);
   if ($33) {
    $44 = 0;$46 = 0;
   } else {
    HEAP32[$32>>2] = 0;
    $34 = (($32) + 4|0);
    HEAP32[$34>>2] = -1;
    $35 = (($32) + 8|0);
    HEAP32[$35>>2] = -1;
    $36 = (($32) + 12|0);
    $37 = (($32) + 48|0);
    dest=$36+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$37>>2] = -1;
    $38 = (($32) + 52|0);
    HEAPF32[$38>>2] = Math_fround(0.0);
    $39 = (($32) + 56|0);
    HEAPF32[$39>>2] = Math_fround(0.0);
    $40 = (($32) + 60|0);
    HEAP8[$40>>0] = 0;
    $41 = $32;
    $42 = $i$01;
    $43 = (($41) - ($42))|0;
    $44 = $43;$46 = $32;
   }
   HEAP32[$i$01>>2] = $44;
   $45 = (($i$01) + 4|0);
   HEAP32[$45>>2] = $46;
   $$pre$phi$i$iZ2D = $45;$49 = $44;
  } else {
   $$pre$i$i = (($i$01) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$49 = $27;
  }
  $47 = $i$01;
  $48 = (($49) + ($47))|0;
  $50 = $48;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $50;
  __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($50,$this);
  $51 = (($i$01) + 8|0);
  $52 = ($51|0)==($18|0);
  if ($52) {
   break;
  } else {
   $i$01 = $51;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i3 = 0, $$pre$phi$i$i5Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0);
 var $98 = 0, $99 = 0, $i$01$i$i$i$i = 0, $size$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $11 = $$pre8;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $15 = $$pre9;$17 = $$pre10;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$13>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $23 = $14;$25 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre11 = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $23 = $$pre11;$25 = $$pre12;
 }
 $19 = (($this) + 16|0);
 $20 = (($this) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$size$i$i$i$i>>2] = $21;
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)<($25>>>0);
 if ($24) {
  HEAP32[$23>>2] = $21;
  HEAP32[$0>>2] = $22;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$size$i$i$i$i,4);
 }
 $26 = $19;
 $27 = HEAP32[$19>>2]|0;
 $28 = (($27) + ($26))|0;
 $29 = $28;
 $30 = (($this) + 20|0);
 $31 = HEAP32[$20>>2]|0;
 $32 = (($29) + ($31<<2)|0);
 HEAP32[$30>>2] = $29;
 $33 = ($31|0)==(0);
 if (!($33)) {
  $i$01$i$i$i$i = $29;
  while(1) {
   $34 = HEAP32[$0>>2]|0;
   $35 = (($34) + 4|0);
   $36 = HEAP32[$3>>2]|0;
   $37 = ($35>>>0)<($36>>>0);
   if ($37) {
    $38 = HEAP32[$i$01$i$i$i$i>>2]|0;
    HEAP32[$34>>2] = $38;
    HEAP32[$0>>2] = $35;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$i$01$i$i$i$i,4);
   }
   $39 = (($i$01$i$i$i$i) + 4|0);
   $40 = ($39|0)==($32|0);
   if ($40) {
    break;
   } else {
    $i$01$i$i$i$i = $39;
   }
  }
 }
 $41 = (($this) + 24|0);
 __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation19Blend1dDataConstantEEE8TransferI19StreamedBinaryWriteILb0EEEEvRS4_RT_($41,$transfer);
 $42 = (($this) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0);
 if ($44) {
  $45 = (($transfer) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$46>>2]|0;
  $48 = HEAP32[$47>>2]|0;
  $49 = (FUNCTION_TABLE_iiii[$48 & 2047]($46,60,4)|0);
  $50 = ($49|0)==(0|0);
  if ($50) {
   $54 = 0;$56 = 0;
  } else {
   dest=$49+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $51 = $49;
   $52 = $42;
   $53 = (($51) - ($52))|0;
   $54 = $53;$56 = $49;
  }
  HEAP32[$42>>2] = $54;
  $55 = (($this) + 36|0);
  HEAP32[$55>>2] = $56;
  $$pre$phi$i$iZ2D = $55;$59 = $54;
 } else {
  $$pre$i$i = (($this) + 36|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$59 = $43;
 }
 $57 = $42;
 $58 = (($59) + ($57))|0;
 $60 = $58;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $60;
 __ZN7mecanim9animation19Blend2dDataConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($60,$transfer);
 $61 = (($this) + 40|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  $64 = (($transfer) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = HEAP32[$66>>2]|0;
  $68 = (FUNCTION_TABLE_iiii[$67 & 2047]($65,16,4)|0);
  $69 = ($68|0)==(0|0);
  if ($69) {
   $73 = 0;$75 = 0;
  } else {
   ;HEAP32[$68+0>>2]=0|0;HEAP32[$68+4>>2]=0|0;HEAP32[$68+8>>2]=0|0;HEAP8[$68+12>>0]=0|0;
   $70 = $68;
   $71 = $61;
   $72 = (($70) - ($71))|0;
   $73 = $72;$75 = $68;
  }
  HEAP32[$61>>2] = $73;
  $74 = (($this) + 44|0);
  HEAP32[$74>>2] = $75;
  $$pre$phi$i$i5Z2D = $74;$78 = $73;
 } else {
  $$pre$i$i3 = (($this) + 44|0);
  $$pre$phi$i$i5Z2D = $$pre$i$i3;$78 = $62;
 }
 $76 = $61;
 $77 = (($78) + ($76))|0;
 $79 = $77;
 HEAP32[$$pre$phi$i$i5Z2D>>2] = $79;
 __ZN7mecanim9animation23BlendDirectDataConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($79,$transfer);
 $80 = (($this) + 48|0);
 $81 = HEAP32[$0>>2]|0;
 $82 = (($81) + 4|0);
 $83 = HEAP32[$3>>2]|0;
 $84 = ($82>>>0)<($83>>>0);
 if ($84) {
  $85 = HEAP32[$80>>2]|0;
  HEAP32[$81>>2] = $85;
  HEAP32[$0>>2] = $82;
  $88 = $82;$90 = $83;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$80,4);
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $88 = $$pre13;$90 = $$pre14;
 }
 $86 = (($this) + 52|0);
 $87 = (($88) + 4|0);
 $89 = ($87>>>0)<($90>>>0);
 if ($89) {
  $91 = Math_fround(HEAPF32[$86>>2]);
  HEAPF32[$88>>2] = $91;
  HEAP32[$0>>2] = $87;
  $94 = $87;$96 = $90;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$86,4);
  $$pre15 = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $94 = $$pre15;$96 = $$pre16;
 }
 $92 = (($this) + 56|0);
 $93 = (($94) + 4|0);
 $95 = ($93>>>0)<($96>>>0);
 if ($95) {
  $97 = Math_fround(HEAPF32[$92>>2]);
  HEAPF32[$94>>2] = $97;
  HEAP32[$0>>2] = $93;
  $100 = $93;$102 = $96;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$92,4);
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $100 = $$pre17;$102 = $$pre18;
 }
 $98 = (($this) + 60|0);
 $99 = (($100) + 1|0);
 $101 = ($99>>>0)<($102>>>0);
 if ($101) {
  $103 = HEAP8[$98>>0]|0;
  HEAP8[$100>>0] = $103;
  $104 = HEAP32[$0>>2]|0;
  $105 = (($104) + 1|0);
  HEAP32[$0>>2] = $105;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$98,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation23BlendDirectDataConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$this>>2]|0;
 HEAP32[$size$i$i$i$i>>2] = $1;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  HEAP32[$3>>2] = $1;
  HEAP32[$2>>2] = $4;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$size$i$i$i$i,4);
 }
 $8 = $0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = (($this) + 8|0);
 $13 = HEAP32[$this>>2]|0;
 $14 = (($11) + ($13<<2)|0);
 HEAP32[$12>>2] = $11;
 $15 = ($13|0)==(0);
 if (!($15)) {
  $i$01$i$i$i$i = $11;
  while(1) {
   $16 = HEAP32[$2>>2]|0;
   $17 = (($16) + 4|0);
   $18 = HEAP32[$5>>2]|0;
   $19 = ($17>>>0)<($18>>>0);
   if ($19) {
    $20 = HEAP32[$i$01$i$i$i$i>>2]|0;
    HEAP32[$16>>2] = $20;
    HEAP32[$2>>2] = $17;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$i$01$i$i$i$i,4);
   }
   $21 = (($i$01$i$i$i$i) + 4|0);
   $22 = ($21|0)==($14|0);
   if ($22) {
    break;
   } else {
    $i$01$i$i$i$i = $21;
   }
  }
 }
 $23 = (($this) + 12|0);
 $24 = HEAP32[$2>>2]|0;
 $25 = (($24) + 1|0);
 $26 = HEAP32[$5>>2]|0;
 $27 = ($25>>>0)<($26>>>0);
 if ($27) {
  $28 = HEAP8[$23>>0]|0;
  HEAP8[$24>>0] = $28;
  $29 = HEAP32[$2>>2]|0;
  $30 = (($29) + 1|0);
  HEAP32[$2>>2] = $30;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$23,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation19Blend2dDataConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ArrayTransfer$i8 = 0, $i$01$i$i$i$i = 0, $i$01$i$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i8 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i8>>2] = $0;
 $3 = (($ArrayTransfer$i8) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i8) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i8,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$ArrayTransfer$i8>>2] = $7;
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  HEAP32[$9>>2] = $7;
  HEAP32[$8>>2] = $10;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$ArrayTransfer$i8,4);
 }
 $14 = $5;
 $15 = HEAP32[$5>>2]|0;
 $16 = (($15) + ($14))|0;
 $17 = $16;
 $18 = (($this) + 20|0);
 $19 = HEAP32[$6>>2]|0;
 $20 = (($17) + ($19<<2)|0);
 HEAP32[$18>>2] = $17;
 $21 = ($19|0)==(0);
 if (!($21)) {
  $i$01$i$i$i$i = $17;
  while(1) {
   $22 = HEAP32[$8>>2]|0;
   $23 = (($22) + 4|0);
   $24 = HEAP32[$11>>2]|0;
   $25 = ($23>>>0)<($24>>>0);
   if ($25) {
    $26 = Math_fround(HEAPF32[$i$01$i$i$i$i>>2]);
    HEAPF32[$22>>2] = $26;
    HEAP32[$8>>2] = $23;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$i$01$i$i$i$i,4);
   }
   $27 = (($i$01$i$i$i$i) + 4|0);
   $28 = ($27|0)==($20|0);
   if ($28) {
    break;
   } else {
    $i$01$i$i$i$i = $27;
   }
  }
 }
 $29 = (($this) + 28|0);
 $30 = (($this) + 24|0);
 $31 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i8>>2] = $29;
 $32 = (($ArrayTransfer$i8) + 4|0);
 HEAP32[$32>>2] = $30;
 $33 = (($ArrayTransfer$i8) + 8|0);
 HEAP32[$33>>2] = $31;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i8,0);
 $34 = (($this) + 40|0);
 $35 = (($this) + 36|0);
 $36 = HEAP32[$35>>2]|0;
 HEAP32[$ArrayTransfer$i8>>2] = $36;
 $37 = HEAP32[$8>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$11>>2]|0;
 $40 = ($38>>>0)<($39>>>0);
 if ($40) {
  HEAP32[$37>>2] = $36;
  HEAP32[$8>>2] = $38;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$ArrayTransfer$i8,4);
 }
 $41 = $34;
 $42 = HEAP32[$34>>2]|0;
 $43 = (($42) + ($41))|0;
 $44 = $43;
 $45 = (($this) + 44|0);
 $46 = HEAP32[$35>>2]|0;
 $47 = (($44) + ($46<<2)|0);
 HEAP32[$45>>2] = $44;
 $48 = ($46|0)==(0);
 if ($48) {
  $56 = (($this) + 52|0);
  $57 = (($this) + 48|0);
  $58 = HEAP32[$1>>2]|0;
  HEAP32[$ArrayTransfer$i8>>2] = $56;
  $59 = (($ArrayTransfer$i8) + 4|0);
  HEAP32[$59>>2] = $57;
  $60 = (($ArrayTransfer$i8) + 8|0);
  HEAP32[$60>>2] = $58;
  __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i8,0);
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i$i4 = $44;
 }
 while(1) {
  $49 = HEAP32[$8>>2]|0;
  $50 = (($49) + 4|0);
  $51 = HEAP32[$11>>2]|0;
  $52 = ($50>>>0)<($51>>>0);
  if ($52) {
   $53 = Math_fround(HEAPF32[$i$01$i$i$i$i4>>2]);
   HEAPF32[$49>>2] = $53;
   HEAP32[$8>>2] = $50;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($8,$i$01$i$i$i$i4,4);
  }
  $54 = (($i$01$i$i$i$i4) + 4|0);
  $55 = ($54|0)==($47|0);
  if ($55) {
   break;
  } else {
   $i$01$i$i$i$i4 = $54;
  }
 }
 $56 = (($this) + 52|0);
 $57 = (($this) + 48|0);
 $58 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i8>>2] = $56;
 $59 = (($ArrayTransfer$i8) + 4|0);
 HEAP32[$59>>2] = $57;
 $60 = (($ArrayTransfer$i8) + 8|0);
 HEAP32[$60>>2] = $58;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i8,0);
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$01$i$i$i$i$i$i$i = 0, $size = 0, $size$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i$i = sp + 4|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + (($17*12)|0)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $i$01 = $23;
 while(1) {
  $26 = (($i$01) + 4|0);
  $27 = HEAP32[$i$01>>2]|0;
  HEAP32[$size$i$i$i$i$i$i$i>>2] = $27;
  $28 = HEAP32[$4>>2]|0;
  $29 = (($28) + 4|0);
  $30 = HEAP32[$7>>2]|0;
  $31 = ($29>>>0)<($30>>>0);
  if ($31) {
   HEAP32[$28>>2] = $27;
   HEAP32[$4>>2] = $29;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i$i$i$i$i$i,4);
  }
  $32 = $26;
  $33 = HEAP32[$26>>2]|0;
  $34 = (($33) + ($32))|0;
  $35 = $34;
  $36 = (($i$01) + 8|0);
  $37 = HEAP32[$i$01>>2]|0;
  $38 = (($35) + ($37<<2)|0);
  HEAP32[$36>>2] = $35;
  $39 = ($37|0)==(0);
  if (!($39)) {
   $i$01$i$i$i$i$i$i$i = $35;
   while(1) {
    $40 = HEAP32[$4>>2]|0;
    $41 = (($40) + 4|0);
    $42 = HEAP32[$7>>2]|0;
    $43 = ($41>>>0)<($42>>>0);
    if ($43) {
     $44 = HEAP32[$i$01$i$i$i$i$i$i$i>>2]|0;
     HEAP32[$40>>2] = $44;
     HEAP32[$4>>2] = $41;
    } else {
     __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01$i$i$i$i$i$i$i,4);
    }
    $45 = (($i$01$i$i$i$i$i$i$i) + 4|0);
    $46 = ($45|0)==($38|0);
    if ($46) {
     break;
    } else {
     $i$01$i$i$i$i$i$i$i = $45;
    }
   }
  }
  $47 = (($i$01) + 12|0);
  $48 = ($47|0)==($18|0);
  if ($48) {
   break;
  } else {
   $i$01 = $47;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $$pre2$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $23;
 }
 while(1) {
  $26 = HEAP32[$4>>2]|0;
  $27 = (($26) + 4|0);
  $28 = HEAP32[$7>>2]|0;
  $29 = ($27>>>0)<($28>>>0);
  if ($29) {
   $30 = Math_fround(HEAPF32[$i$01>>2]);
   HEAPF32[$26>>2] = $30;
   HEAP32[$4>>2] = $27;
   $33 = $27;$35 = $28;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01,4);
   $$pre$i$i$i = HEAP32[$4>>2]|0;
   $$pre2$i$i$i = HEAP32[$7>>2]|0;
   $33 = $$pre$i$i$i;$35 = $$pre2$i$i$i;
  }
  $31 = (($i$01) + 4|0);
  $32 = (($33) + 4|0);
  $34 = ($32>>>0)<($35>>>0);
  if ($34) {
   $36 = Math_fround(HEAPF32[$31>>2]);
   HEAPF32[$33>>2] = $36;
   HEAP32[$4>>2] = $32;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$31,4);
  }
  $37 = (($i$01) + 8|0);
  $38 = ($37|0)==($18|0);
  if ($38) {
   break;
  } else {
   $i$01 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation19Blend1dDataConstantEEE8TransferI19StreamedBinaryWriteILb0EEEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i$i = sp;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,12,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = 0;$15 = 0;
  } else {
   HEAP32[$6>>2] = 0;
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 8|0);
   HEAP32[$9>>2] = 0;
   $10 = $6;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $6;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phiZ2D = $14;$18 = $13;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$18 = $0;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phiZ2D>>2] = $19;
 $20 = (($19) + 4|0);
 $21 = HEAP32[$19>>2]|0;
 HEAP32[$size$i$i$i$i$i$i$i>>2] = $21;
 $22 = (($transfer) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 4|0);
 $25 = (($transfer) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24>>>0)<($26>>>0);
 if ($27) {
  HEAP32[$23>>2] = $21;
  HEAP32[$22>>2] = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$size$i$i$i$i$i$i$i,4);
 }
 $28 = $20;
 $29 = HEAP32[$20>>2]|0;
 $30 = (($29) + ($28))|0;
 $31 = $30;
 $32 = (($19) + 8|0);
 $33 = HEAP32[$19>>2]|0;
 $34 = (($31) + ($33<<2)|0);
 HEAP32[$32>>2] = $31;
 $35 = ($33|0)==(0);
 if ($35) {
  STACKTOP = sp;return;
 } else {
  $i$01$i$i$i$i$i$i$i = $31;
 }
 while(1) {
  $36 = HEAP32[$22>>2]|0;
  $37 = (($36) + 4|0);
  $38 = HEAP32[$25>>2]|0;
  $39 = ($37>>>0)<($38>>>0);
  if ($39) {
   $40 = Math_fround(HEAPF32[$i$01$i$i$i$i$i$i$i>>2]);
   HEAPF32[$36>>2] = $40;
   HEAP32[$22>>2] = $37;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($22,$i$01$i$i$i$i$i$i$i,4);
  }
  $41 = (($i$01$i$i$i$i$i$i$i) + 4|0);
  $42 = ($41|0)==($34|0);
  if ($42) {
   break;
  } else {
   $i$01$i$i$i$i$i$i$i = $41;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19StreamedBinaryWriteILb0EE8TransferIN7mecanim12statemachine16LeafInfoConstantEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i$i$i$i = 0, $size$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i$i$i$i = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$data>>2]|0;
 HEAP32[$size$i$i$i$i$i$i>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size$i$i$i$i$i$i,4);
 }
 $10 = $2;
 $11 = HEAP32[$2>>2]|0;
 $12 = (($11) + ($10))|0;
 $13 = $12;
 $14 = (($data) + 8|0);
 $15 = HEAP32[$data>>2]|0;
 $16 = (($13) + ($15<<2)|0);
 HEAP32[$14>>2] = $13;
 $17 = ($15|0)==(0);
 if (!($17)) {
  $i$01$i$i$i$i$i$i = $13;
  while(1) {
   $18 = HEAP32[$4>>2]|0;
   $19 = (($18) + 4|0);
   $20 = HEAP32[$7>>2]|0;
   $21 = ($19>>>0)<($20>>>0);
   if ($21) {
    $22 = HEAP32[$i$01$i$i$i$i$i$i>>2]|0;
    HEAP32[$18>>2] = $22;
    HEAP32[$4>>2] = $19;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01$i$i$i$i$i$i,4);
   }
   $23 = (($i$01$i$i$i$i$i$i) + 4|0);
   $24 = ($23|0)==($16|0);
   if ($24) {
    break;
   } else {
    $i$01$i$i$i$i$i$i = $23;
   }
  }
 }
 $25 = (($data) + 12|0);
 $26 = HEAP32[$4>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$7>>2]|0;
 $29 = ($27>>>0)<($28>>>0);
 if ($29) {
  $30 = HEAP32[$25>>2]|0;
  HEAP32[$26>>2] = $30;
  HEAP32[$4>>2] = $27;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$25,4);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation13LayerConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 4|0);
 $i$01 = $23;
 while(1) {
  $27 = HEAP32[$i$01>>2]|0;
  $28 = ($27|0)==(0);
  if ($28) {
   $29 = HEAP32[$26>>2]|0;
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,40,4)|0);
   $33 = ($32|0)==(0|0);
   if ($33) {
    $41 = 0;$43 = 0;
   } else {
    $34 = (($32) + 8|0);
    $35 = (($32) + 28|0);
    HEAP32[$35>>2] = 0;
    $36 = (($32) + 36|0);
    ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
    HEAP8[$36>>0] = 1;
    $37 = (($32) + 37|0);
    HEAP8[$37>>0] = 0;
    $38 = $32;
    $39 = $i$01;
    $40 = (($38) - ($39))|0;
    $41 = $40;$43 = $32;
   }
   HEAP32[$i$01>>2] = $41;
   $42 = (($i$01) + 4|0);
   HEAP32[$42>>2] = $43;
   $$pre$phi$i$iZ2D = $42;$46 = $41;
  } else {
   $$pre$i$i = (($i$01) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$46 = $27;
  }
  $44 = $i$01;
  $45 = (($46) + ($44))|0;
  $47 = $45;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $47;
  __ZN7mecanim9animation13LayerConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($47,$this);
  $48 = (($i$01) + 8|0);
  $49 = ($48|0)==($18|0);
  if ($49) {
   break;
  } else {
   $i$01 = $48;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation13LayerConstant8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i2 = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi2$i$iZ2D = 0, $$pre1$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre2$i$i = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $11 = $$pre5;$9 = $$pre;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)<($11>>>0);
 if ($10) {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$9>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$7,4);
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $15 = $$pre6;$17 = $$pre7;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)<($17>>>0);
 if ($16) {
  $18 = HEAP32[$13>>2]|0;
  HEAP32[$15>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$13,4);
  $$pre$i$i = HEAP32[$0>>2]|0;
  $$pre2$i$i = HEAP32[$3>>2]|0;
  $21 = $$pre$i$i;$23 = $$pre2$i$i;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)<($23>>>0);
 if ($22) {
  $24 = HEAP32[$19>>2]|0;
  HEAP32[$21>>2] = $24;
  HEAP32[$0>>2] = $20;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$19,4);
 }
 $25 = (($this) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0);
 if ($27) {
  $28 = (($transfer) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,12,4)|0);
  $33 = ($32|0)==(0|0);
  if ($33) {
   $39 = 0;$41 = 0;
  } else {
   HEAP32[$32>>2] = 0;
   $34 = (($32) + 4|0);
   HEAP32[$34>>2] = 0;
   $35 = (($32) + 8|0);
   HEAP32[$35>>2] = 0;
   $36 = $32;
   $37 = $25;
   $38 = (($36) - ($37))|0;
   $39 = $38;$41 = $32;
  }
  HEAP32[$25>>2] = $39;
  $40 = (($this) + 20|0);
  HEAP32[$40>>2] = $41;
  $$pre$phi$i$iZ2D = $40;$$pre$phi2$i$iZ2D = $28;$44 = $39;
 } else {
  $$pre$i$i2 = (($this) + 20|0);
  $$pre1$i$i = (($transfer) + 4|0);
  $$pre$phi$i$iZ2D = $$pre$i$i2;$$pre$phi2$i$iZ2D = $$pre1$i$i;$44 = $26;
 }
 $42 = $25;
 $43 = (($44) + ($42))|0;
 $45 = $43;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $45;
 $46 = (($45) + 4|0);
 $47 = HEAP32[$$pre$phi2$i$iZ2D>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $46;
 $48 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$48>>2] = $45;
 $49 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$49>>2] = $47;
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim8skeleton19SkeletonMaskElementEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 $50 = (($this) + 24|0);
 $51 = HEAP32[$0>>2]|0;
 $52 = (($51) + 4|0);
 $53 = HEAP32[$3>>2]|0;
 $54 = ($52>>>0)<($53>>>0);
 if ($54) {
  $55 = HEAP32[$50>>2]|0;
  HEAP32[$51>>2] = $55;
  HEAP32[$0>>2] = $52;
  $58 = $52;$60 = $53;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$50,4);
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $58 = $$pre8;$60 = $$pre9;
 }
 $56 = (($this) + 28|0);
 $57 = (($58) + 4|0);
 $59 = ($57>>>0)<($60>>>0);
 if ($59) {
  $61 = HEAP32[$56>>2]|0;
  HEAP32[$58>>2] = $61;
  HEAP32[$0>>2] = $57;
  $64 = $57;$66 = $60;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$56,4);
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $64 = $$pre10;$66 = $$pre11;
 }
 $62 = (($this) + 32|0);
 $63 = (($64) + 4|0);
 $65 = ($63>>>0)<($66>>>0);
 if ($65) {
  $67 = Math_fround(HEAPF32[$62>>2]);
  HEAPF32[$64>>2] = $67;
  HEAP32[$0>>2] = $63;
  $70 = $63;$72 = $66;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$62,4);
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $70 = $$pre12;$72 = $$pre13;
 }
 $68 = (($this) + 36|0);
 $69 = (($70) + 1|0);
 $71 = ($69>>>0)<($72>>>0);
 if ($71) {
  $73 = HEAP8[$68>>0]|0;
  HEAP8[$70>>0] = $73;
  $74 = HEAP32[$0>>2]|0;
  $75 = (($74) + 1|0);
  HEAP32[$0>>2] = $75;
  $78 = $75;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$68,1);
  $$pre14 = HEAP32[$0>>2]|0;
  $78 = $$pre14;
 }
 $76 = (($this) + 37|0);
 $77 = (($78) + 1|0);
 $79 = HEAP32[$3>>2]|0;
 $80 = ($77>>>0)<($79>>>0);
 if ($80) {
  $81 = HEAP8[$76>>0]|0;
  HEAP8[$78>>0] = $81;
  $82 = HEAP32[$0>>2]|0;
  $83 = (($82) + 1|0);
  HEAP32[$0>>2] = $83;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$76,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim8skeleton19SkeletonMaskElementEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i$i = 0, $$pre1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$size>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)<($8>>>0);
 if ($9) {
  HEAP32[$5>>2] = $3;
  HEAP32[$4>>2] = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$size,4);
 }
 $10 = HEAP32[$data>>2]|0;
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($10) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17<<3)|0);
 $19 = HEAP32[$data>>2]|0;
 $20 = $19;
 $21 = HEAP32[$19>>2]|0;
 $22 = (($21) + ($20))|0;
 $23 = $22;
 $24 = (($19) + 4|0);
 HEAP32[$24>>2] = $23;
 $25 = ($23|0)==($18|0);
 if ($25) {
  STACKTOP = sp;return;
 } else {
  $i$01 = $23;
 }
 while(1) {
  $26 = HEAP32[$4>>2]|0;
  $27 = (($26) + 4|0);
  $28 = HEAP32[$7>>2]|0;
  $29 = ($27>>>0)<($28>>>0);
  if ($29) {
   $30 = HEAP32[$i$01>>2]|0;
   HEAP32[$26>>2] = $30;
   HEAP32[$4>>2] = $27;
   $33 = $27;$35 = $28;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$i$01,4);
   $$pre$i$i$i = HEAP32[$4>>2]|0;
   $$pre1$i$i$i = HEAP32[$7>>2]|0;
   $33 = $$pre$i$i$i;$35 = $$pre1$i$i$i;
  }
  $31 = (($i$01) + 4|0);
  $32 = (($33) + 4|0);
  $34 = ($32>>>0)<($35>>>0);
  if ($34) {
   $36 = Math_fround(HEAPF32[$31>>2]);
   HEAPF32[$33>>2] = $36;
   HEAP32[$4>>2] = $32;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($4,$31,4);
  }
  $37 = (($i$01) + 8|0);
  $38 = ($37|0)==($18|0);
  if ($38) {
   break;
  } else {
   $i$01 = $37;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AnimatorController8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN25RuntimeAnimatorController8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 88|0);
 $1 = (($transfer) + 4|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 112|0);
 $3 = (($this) + 116|0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$3,4);
  $$pre$i$i$i$i = HEAP32[$3>>2]|0;
  $11 = $$pre$i$i$i$i;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$3>>2] = $10;
  HEAP32[$4>>2] = $6;
  $11 = $10;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$3>>2] = $12;
 $13 = HEAP32[$2>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = HEAP32[$1>>2]|0;
  __ZN7mecanim6memory16ChainedAllocator7ReserveEj($15,$12);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$16>>2]|0;
  $18 = (FUNCTION_TABLE_iiii[$17 & 2047]($15,40,4)|0);
  $19 = ($18|0)==(0|0);
  if ($19) {
   $20 = 0;
  } else {
   dest=$18+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $20 = $18;
  }
  HEAP32[$2>>2] = $20;
  $21 = $20;
 } else {
  $21 = $13;
 }
 __ZN7mecanim9animation18ControllerConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($21,$transfer);
 $22 = (($this) + 124|0);
 __ZN18StreamedBinaryReadILb1EE19TransferSTLStyleMapINSt3__13mapIj8UnityStrNS2_4lessIjEENS2_9allocatorINS2_4pairIKjS4_EEEEEEEEvRT_17TransferMetaFlags($transfer,$22,0);
 $23 = (($this) + 68|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI13AnimationClipELj4EEEEvRT_17TransferMetaFlags($transfer,$23,0);
 $24 = (($this) + 140|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapI8StateKey10StateRangeNSt3__14lessIS3_EENS5_9allocatorINS5_4pairIS3_S4_EEEEEEEvRT_17TransferMetaFlags($transfer,$24,0);
 $25 = (($this) + 156|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$25,0);
 $26 = (($this) + 172|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI25StateMachineBehaviourInfoNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$26,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $27 = (($this) + 136|0);
 $28 = HEAP32[$4>>2]|0;
 $29 = (($28) + 1|0);
 $30 = HEAP32[$7>>2]|0;
 $31 = ($29>>>0)>($30>>>0);
 if ($31) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$27,1);
  STACKTOP = sp;return;
 } else {
  $32 = HEAP8[$28>>0]|0;
  HEAP8[$27>>0] = $32;
  $33 = HEAP32[$4>>2]|0;
  $34 = (($33) + 1|0);
  HEAP32[$4>>2] = $34;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI25StateMachineBehaviourInfoNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI25StateMachineBehaviourInfoNS0_9allocatorIS2_EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrI13MonoBehaviourE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI13MonoBehaviourE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI25StateMachineBehaviourInfoNS0_9allocatorIS2_EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$idx = 0, $$pre54 = 0, $$pre55 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i30 = 0, $__new_last2$i$i$i$i$i39 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i31 = 0, $scevgep$i$i$i$i$i40 = 0, $scevgep$i$i$i17 = 0, $scevgep4$i$i$i$i$i35 = 0, $scevgep4$i$i$i$i$i44 = 0;
 var $scevgep4$i$i$i19 = 0, $scevgep8$i$i$i = 0, $scevgep8$i$i$i52 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i33 = 0, $uglygep$i$i$i$i$i42 = 0, $uglygep$i$i$i18 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i34 = 0, $uglygep3$i$i$i$i$i43 = 0, $uglygep6$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $temp = sp + 4|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 $2 = (($v) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$v>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($sz>>>0);
 if (!($9)) {
  $63 = ($8>>>0)>($sz>>>0);
  if (!($63)) {
   STACKTOP = sp;return;
  }
  $64 = (($4) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $65 = $$idx >> 2;
  $66 = ($65|0)==(0);
  if ($66) {
   $81 = 0;$83 = 0;$scevgep8$i$i$i52 = 0;
  } else {
   $67 = ($65>>>0)>(1073741823);
   if ($67) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $68 = (__Znwj($$idx)|0);
   $69 = (($68) + ($65<<2)|0);
   $70 = ($sz|0)==(0);
   if ($70) {
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $68;
   } else {
    $$sum = (($sz) + -1)|0;
    $scevgep$i$i$i = (($4) + ($$sum<<2)|0);
    $71 = (0 - ($6))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($71)|0);
    $73 = $68;$75 = $4;
    while(1) {
     $72 = ($73|0)==(0|0);
     if (!($72)) {
      $74 = HEAP32[$75>>2]|0;
      HEAP32[$73>>2] = $74;
     }
     $76 = (($73) + 4|0);
     $77 = (($75) + 4|0);
     $78 = ($77|0)==($64|0);
     if ($78) {
      break;
     } else {
      $73 = $76;$75 = $77;
     }
    }
    $uglygep6$i$i$i = $uglygep$i$i$i;
    $79 = $uglygep6$i$i$i >>> 2;
    $80 = (($79) + 1)|0;
    $scevgep8$i$i$i = (($68) + ($80<<2)|0);
    $81 = $68;$83 = $69;$scevgep8$i$i$i52 = $scevgep8$i$i$i;
   }
  }
  HEAP32[$v>>2] = $81;
  HEAP32[$2>>2] = $scevgep8$i$i$i52;
  $82 = (($v) + 8|0);
  HEAP32[$82>>2] = $83;
  $84 = ($4|0)==(0|0);
  if ($84) {
   STACKTOP = sp;return;
  }
  __ZdlPv($4);
  STACKTOP = sp;return;
 }
 $10 = (($v) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($6))|0;
 $14 = $13 >> 2;
 $15 = ($14|0)==($sz|0);
 if ($15) {
  $62 = (($sz) - ($8))|0;
  __ZNSt3__16vectorI25StateMachineBehaviourInfoNS_9allocatorIS1_EEE8__appendEj($v,$62);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $16 = (($temp) + 4|0);
 HEAP32[$16>>2] = 0;
 $17 = (($temp) + 8|0);
 HEAP32[$17>>2] = 0;
 $18 = ($sz|0)==(0);
 if ($18) {
  label = 6;
 } else {
  $19 = $sz << 2;
  __THREW__ = 0;
  $20 = (invoke_ii(2988,($19|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $23 = (($20) + ($sz<<2)|0);
   HEAP32[$temp>>2] = $20;
   HEAP32[$16>>2] = $20;
   HEAP32[$17>>2] = $23;
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$0>>2] = $4;
   HEAP32[$1>>2] = $3;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(2023,($temp|0),($$byval_copy|0),($$byval_copy1|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = HEAP32[$16>>2]|0;
    $27 = HEAP32[$temp>>2]|0;
    $28 = $26;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = $30 >> 2;
    $32 = ($31>>>0)<($sz>>>0);
    if ($32) {
     $33 = (($sz) - ($31))|0;
     __THREW__ = 0;
     invoke_vii(3401,($temp|0),($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $$pre54 = HEAP32[$temp>>2]|0;
     $$pre55 = HEAP32[$16>>2]|0;
     $43 = $$pre54;$45 = $$pre55;
    } else {
     $36 = ($31>>>0)>($sz>>>0);
     if ($36) {
      $37 = (($27) + ($sz<<2)|0);
      $38 = ($26|0)==($37|0);
      if ($38) {
       $43 = $27;$45 = $26;
      } else {
       $__new_last2$i$i$i = $37;
       $scevgep$i$i$i17 = (($26) + -4|0);
       $39 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i18 = (($scevgep$i$i$i17) + ($39)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i18;
       $40 = $uglygep3$i$i$i >>> 2;
       $41 = $40 ^ -1;
       $scevgep4$i$i$i19 = (($26) + ($41<<2)|0);
       HEAP32[$16>>2] = $scevgep4$i$i$i19;
       $43 = $27;$45 = $scevgep4$i$i$i19;
      }
     } else {
      $43 = $27;$45 = $26;
     }
    }
    $42 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $42;
    HEAP32[$v>>2] = $43;
    $44 = HEAP32[$2>>2]|0;
    HEAP32[$16>>2] = $44;
    HEAP32[$2>>2] = $45;
    $46 = HEAP32[$17>>2]|0;
    $47 = HEAP32[$10>>2]|0;
    HEAP32[$17>>2] = $47;
    HEAP32[$10>>2] = $46;
    $48 = ($42|0)==(0|0);
    if ($48) {
     STACKTOP = sp;return;
    }
    $49 = ($44|0)==($42|0);
    if (!($49)) {
     $__new_last2$i$i$i$i$i30 = $42;
     $scevgep$i$i$i$i$i31 = (($44) + -4|0);
     $50 = (0 - ($__new_last2$i$i$i$i$i30))|0;
     $uglygep$i$i$i$i$i33 = (($scevgep$i$i$i$i$i31) + ($50)|0);
     $uglygep3$i$i$i$i$i34 = $uglygep$i$i$i$i$i33;
     $51 = $uglygep3$i$i$i$i$i34 >>> 2;
     $52 = $51 ^ -1;
     $scevgep4$i$i$i$i$i35 = (($44) + ($52<<2)|0);
     HEAP32[$16>>2] = $scevgep4$i$i$i$i$i35;
    }
    __ZdlPv($42);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $53 = ___cxa_find_matching_catch()|0;
 $54 = tempRet0;
 $55 = HEAP32[$temp>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  ___resumeException($53|0);
  // unreachable;
 }
 $57 = HEAP32[$16>>2]|0;
 $58 = ($57|0)==($55|0);
 if (!($58)) {
  $__new_last2$i$i$i$i$i39 = $55;
  $scevgep$i$i$i$i$i40 = (($57) + -4|0);
  $59 = (0 - ($__new_last2$i$i$i$i$i39))|0;
  $uglygep$i$i$i$i$i42 = (($scevgep$i$i$i$i$i40) + ($59)|0);
  $uglygep3$i$i$i$i$i43 = $uglygep$i$i$i$i$i42;
  $60 = $uglygep3$i$i$i$i$i43 >>> 2;
  $61 = $60 ^ -1;
  $scevgep4$i$i$i$i$i44 = (($57) + ($61<<2)|0);
  HEAP32[$16>>2] = $scevgep4$i$i$i$i$i44;
 }
 __ZdlPv($55);
 ___resumeException($53|0);
 // unreachable;
}
function __ZNSt3__16vectorI25StateMachineBehaviourInfoNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$promoted15$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0;
 var $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i24 = 0, $scevgep$i10 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i17 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i25 = 0, $uglygep$i12 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0;
 var $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $46 = ($8|0)==(0|0);
  if ($46) {
   $55 = $7;
  } else {
   $47 = (($this) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==($8|0);
   if (!($49)) {
    $scevgep$i$i$i$i = (($48) + -4|0);
    $50 = (0 - ($10))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($50)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $51 = $uglygep3$i$i$i$i >>> 2;
    $52 = $51 ^ -1;
    $scevgep4$i$i$i$i = (($48) + ($52<<2)|0);
    HEAP32[$47>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($8);
   HEAP32[$6>>2] = 0;
   HEAP32[$47>>2] = 0;
   HEAP32[$this>>2] = 0;
   $55 = 0;
  }
  $53 = ($5>>>0)>(1073741823);
  if ($53) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $54 = $55;
  $56 = $54 >> 2;
  $57 = ($56>>>0)<(536870911);
  if ($57) {
   $58 = $54 >> 1;
   $59 = ($58>>>0)<($5>>>0);
   $60 = $59 ? $5 : $58;
   $61 = ($60>>>0)>(1073741823);
   if ($61) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $60;
   }
  } else {
   $$0$i40 = 1073741823;
  }
  $62 = $$0$i40 << 2;
  $63 = (__Znwj($62)|0);
  $64 = (($this) + 4|0);
  HEAP32[$64>>2] = $63;
  HEAP32[$this>>2] = $63;
  $65 = (($63) + ($$0$i40<<2)|0);
  HEAP32[$6>>2] = $65;
  $66 = ($0|0)==($1|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($1) + -4|0);
  $67 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($67)|0);
  $uglygep6$i = $uglygep$i;
  $68 = $uglygep6$i >>> 2;
  $70 = $63;$72 = $0;
  while(1) {
   $69 = ($70|0)==(0|0);
   if (!($69)) {
    $71 = HEAP32[$72>>2]|0;
    HEAP32[$70>>2] = $71;
   }
   $73 = (($70) + 4|0);
   $74 = (($72) + 4|0);
   $75 = ($74|0)==($1|0);
   if ($75) {
    break;
   } else {
    $70 = $73;$72 = $74;
   }
  }
  $76 = (($68) + 1)|0;
  $scevgep8$i = (($63) + ($76<<2)|0);
  HEAP32[$64>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 2;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<2)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i24 = (($22) + -4|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i25 = (($scevgep$i$i24) + ($23)|0);
  $uglygep5$i$i = $uglygep$i$i25;
  $24 = $uglygep5$i$i >>> 2;
  $$01$i$i = $8;$26 = $0;
  while(1) {
   $25 = HEAP32[$26>>2]|0;
   HEAP32[$$01$i$i>>2] = $25;
   $27 = (($26) + 4|0);
   $28 = (($$01$i$i) + 4|0);
   $29 = ($27|0)==($22|0);
   if ($29) {
    break;
   } else {
    $$01$i$i = $28;$26 = $27;
   }
  }
  $30 = (($24) + 1)|0;
  $scevgep6$i$i = (($8) + ($30<<2)|0);
  $$0$lcssa$i$i = $scevgep6$i$i;
 }
 if (!($__growing$0$off0)) {
  $42 = ($15|0)==($$0$lcssa$i$i|0);
  if ($42) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($15) + -4|0);
  $43 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($43)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $44 = $uglygep3$i$i >>> 2;
  $45 = $44 ^ -1;
  $scevgep4$i$i = (($15) + ($45<<2)|0);
  HEAP32[$14>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $31 = ($22|0)==($1|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $$promoted15$i9 = $22;
 $scevgep$i10 = (($1) + -4|0);
 $32 = (0 - ($$promoted15$i9))|0;
 $uglygep$i12 = (($scevgep$i10) + ($32)|0);
 $uglygep6$i13 = $uglygep$i12;
 $33 = $uglygep6$i13 >>> 2;
 $35 = $15;$37 = $22;
 while(1) {
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   $36 = HEAP32[$37>>2]|0;
   HEAP32[$35>>2] = $36;
  }
  $38 = (($35) + 4|0);
  $39 = (($37) + 4|0);
  $40 = ($39|0)==($1|0);
  if ($40) {
   break;
  } else {
   $35 = $38;$37 = $39;
  }
 }
 $41 = (($33) + 1)|0;
 $scevgep8$i17 = (($15) + ($41<<2)|0);
 HEAP32[$14>>2] = $scevgep8$i17;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI25StateMachineBehaviourInfoNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0;
 var $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
   }
   $11 = (($10) + 4|0);
   $12 = (($$0$i) + -1)|0;
   $13 = ($12|0)==(0);
   if ($13) {
    break;
   } else {
    $$0$i = $12;$10 = $11;
   }
  }
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = $14;
 $16 = (($5) - ($15))|0;
 $17 = $16 >> 2;
 $18 = (($17) + ($__n))|0;
 $19 = ($18>>>0)>(1073741823);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($4) - ($15))|0;
 $21 = $20 >> 2;
 $22 = ($21>>>0)<(536870911);
 if ($22) {
  $23 = $20 >> 1;
  $24 = ($23>>>0)<($18>>>0);
  $25 = $24 ? $18 : $23;
  $26 = ($25|0)==(0);
  if ($26) {
   $$0$i58 = 0;$30 = 0;
  } else {
   $$0$i57 = $25;
   label = 10;
  }
 } else {
  $$0$i57 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $27 = $$0$i57 << 2;
  $28 = (__Znwj($27)|0);
  $$0$i58 = $$0$i57;$30 = $28;
 }
 $29 = (($30) + ($17<<2)|0);
 $$0$i2 = $__n;$32 = $29;
 while(1) {
  $31 = ($32|0)==(0|0);
  if (!($31)) {
   HEAP32[$32>>2] = 0;
  }
  $33 = (($32) + 4|0);
  $34 = (($$0$i2) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   break;
  } else {
   $$0$i2 = $34;$32 = $33;
  }
 }
 $36 = (($30) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($30) + ($18<<2)|0);
 $37 = ($3|0)==($14|0);
 if ($37) {
  $47 = $29;$49 = $3;
 } else {
  $scevgep$i$i = (($3) + -4|0);
  $38 = (0 - ($15))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($38)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $3;$42 = $29;
  while(1) {
   $39 = (($$01$i$i) + -4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (($42) + -4|0);
   HEAP32[$41>>2] = $40;
   $43 = (($42) + -4|0);
   $44 = ($39|0)==($14|0);
   if ($44) {
    break;
   } else {
    $$01$i$i = $39;$42 = $43;
   }
  }
  $45 = $uglygep4$i$i >>> 2;
  $46 = $45 ^ -1;
  $$sum6 = (($17) + ($46))|0;
  $scevgep5$i$i = (($30) + ($$sum6<<2)|0);
  $47 = $scevgep5$i$i;$49 = $14;
 }
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $36;
 $48 = ($49|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($49);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapI8StateKey10StateRangeNSt3__14lessIS3_EENS5_9allocatorINS5_4pairIS3_S4_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre10 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0;
 var $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre8 = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre8;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = (($data) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$25>>2]|0;
 $29 = $27;
 $30 = $28;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 4;
 $33 = ($32>>>0)<($24>>>0);
 if ($33) {
  $34 = (($24) - ($32))|0;
  __ZNSt3__16vectorINS_4pairI8StateKey10StateRangeEENS_9allocatorIS4_EEE8__appendEj($25,$34);
  $$pre = HEAP32[$26>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre7 = HEAP32[$$phi$trans$insert>>2]|0;
  $42 = $$pre7;$43 = $$pre;
 } else {
  $35 = ($32>>>0)>($24>>>0);
  if ($35) {
   $36 = (($28) + ($24<<4)|0);
   $37 = ($27|0)==($36|0);
   if ($37) {
    $42 = $28;$43 = $27;
   } else {
    $__new_last2$i$i$i$i = $36;
    $scevgep$i$i$i$i = (($27) + -16|0);
    $38 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($38)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $39 = $uglygep3$i$i$i$i >>> 4;
    $40 = $39 ^ -1;
    $scevgep4$i$i$i$i = (($27) + ($40<<4)|0);
    HEAP32[$26>>2] = $scevgep4$i$i$i$i;
    $42 = $28;$43 = $scevgep4$i$i$i$i;
   }
  } else {
   $42 = $28;$43 = $27;
  }
 }
 $41 = ($42|0)==($43|0);
 if ($41) {
  STACKTOP = sp;return;
 } else {
  $44 = $42;
 }
 while(1) {
  __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI18StreamedBinaryReadILb1EEEEvRS4_RT_($44,$this);
  $45 = (($44) + 16|0);
  $46 = ($45|0)==($43|0);
  if ($46) {
   break;
  } else {
   $44 = $45;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI18StreamedBinaryReadILb1EEEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i1 = 0, $$pre$i$i$i1$i$i$i = 0, $$pre$i$i$i1$i$i$i4 = 0, $$pre$i$i$i2 = 0, $$pre2$i$i$i = 0, $$pre3$i$i$i = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$data,4);
  $$pre$i$i$i$i$i$i = HEAP32[$data>>2]|0;
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre2$i$i$i = HEAP32[$3>>2]|0;
  $11 = $$pre$i$i$i;$13 = $$pre2$i$i$i;$7 = $$pre$i$i$i$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$data>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$data>>2] = $8;
 $9 = (($data) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1$i$i$i = HEAP32[$9>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1$i$i$i;$19 = $$pre;$21 = $$pre5;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($data) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i$i$i$i1 = HEAP32[$17>>2]|0;
  $$pre$i$i$i2 = HEAP32[$0>>2]|0;
  $$pre3$i$i$i = HEAP32[$3>>2]|0;
  $23 = $$pre$i$i$i$i$i$i1;$27 = $$pre$i$i$i2;$29 = $$pre3$i$i$i;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = $22;$27 = $18;$29 = $21;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$17>>2] = $24;
 $25 = (($data) + 12|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre$i$i$i1$i$i$i4 = HEAP32[$25>>2]|0;
  $31 = $$pre$i$i$i1$i$i$i4;
  $32 = (_llvm_bswap_i32(($31|0))|0);
  HEAP32[$25>>2] = $32;
  STACKTOP = sp;return;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = $30;
  $32 = (_llvm_bswap_i32(($31|0))|0);
  HEAP32[$25>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorINS_4pairI8StateKey10StateRangeEENS_9allocatorIS4_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if (!($9)) {
    HEAP32[$10>>2] = 0;
    $11 = (($10) + 4|0);
    HEAP32[$11>>2] = -1;
    $12 = (($10) + 8|0);
    HEAP32[$12>>2] = 0;
    $13 = (($10) + 12|0);
    HEAP32[$13>>2] = 0;
   }
   $14 = (($10) + 16|0);
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$10 = $14;
   }
  }
  $scevgep$i = (($3) + ($__n<<4)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($5) - ($18))|0;
 $20 = $19 >> 4;
 $21 = (($20) + ($__n))|0;
 $22 = ($21>>>0)>(268435455);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($4) - ($18))|0;
 $24 = $23 >> 4;
 $25 = ($24>>>0)<(134217727);
 if ($25) {
  $26 = $23 >> 3;
  $27 = ($26>>>0)<($21>>>0);
  $28 = $27 ? $21 : $26;
  $29 = ($28|0)==(0);
  if ($29) {
   $$0$i58 = 0;$33 = 0;
  } else {
   $$0$i57 = $28;
   label = 10;
  }
 } else {
  $$0$i57 = 268435455;
  label = 10;
 }
 if ((label|0) == 10) {
  $30 = $$0$i57 << 4;
  $31 = (__Znwj($30)|0);
  $$0$i58 = $$0$i57;$33 = $31;
 }
 $32 = (($33) + ($20<<4)|0);
 $$0$i2 = $__n;$35 = $32;
 while(1) {
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   HEAP32[$35>>2] = 0;
   $36 = (($35) + 4|0);
   HEAP32[$36>>2] = -1;
   $37 = (($35) + 8|0);
   HEAP32[$37>>2] = 0;
   $38 = (($35) + 12|0);
   HEAP32[$38>>2] = 0;
  }
  $39 = (($35) + 16|0);
  $40 = (($$0$i2) + -1)|0;
  $41 = ($40|0)==(0);
  if ($41) {
   break;
  } else {
   $$0$i2 = $40;$35 = $39;
  }
 }
 $42 = (($33) + ($$0$i58<<4)|0);
 $scevgep$i4 = (($33) + ($21<<4)|0);
 _memcpy(($33|0),($17|0),($19|0))|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$2>>2] = $scevgep$i4;
 HEAP32[$0>>2] = $42;
 $43 = ($17|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 __ZdlPv($17);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI13AnimationClipELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
   $35 = $$pre$i$i$i3;
  } else {
   $34 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $34;
   HEAP32[$3>>2] = $8;
   $35 = $34;
  }
  $36 = (_llvm_bswap_i32(($35|0))|0);
  HEAP32[$size1>>2] = $36;
  $37 = (($this) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  HEAP32[$2>>2] = $38;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI4PPtrI13AnimationClipELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$36,$$byval_copy1);
  $39 = HEAP32[$data>>2]|0;
  $40 = (($data) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<2)|0);
  $43 = ($41|0)==(0);
  if ($43) {
   STACKTOP = sp;return;
  } else {
   $i$04 = $39;
  }
  while(1) {
   __ZN4PPtrI13AnimationClipE8TransferI18StreamedBinaryReadILb1EEEEvRT_($i$04,$this);
   $44 = (($i$04) + 4|0);
   $45 = ($44|0)==($42|0);
   if ($45) {
    break;
   } else {
    $i$04 = $44;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$3>>2]|0;
  $$pre5 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$16 = $$pre;$18 = $$pre5;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $13 = $12;$16 = $8;$18 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$size>>2] = $14;
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre6 = HEAP32[$size>>2]|0;
  $20 = $$pre$i$i$i1;$23 = $$pre6;
 } else {
  $19 = HEAP32[$16>>2]|0;
  HEAP32[$offset>>2] = $19;
  HEAP32[$3>>2] = $15;
  $20 = $19;$23 = $14;
 }
 $21 = (_llvm_bswap_i32(($20|0))|0);
 HEAP32[$offset>>2] = $21;
 $22 = $23 << 2;
 $24 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$21,$22)|0);
 $25 = (($data) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)>(-1);
 if ($27) {
  $28 = HEAP32[$data>>2]|0;
  $29 = (($data) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$1>>2] = $30;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($28,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $31 = $22 >> 2;
 $32 = (($data) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = $31 | -2147483648;
 HEAP32[$25>>2] = $33;
 HEAP32[$data>>2] = $24;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI13dynamic_arrayI4PPtrI13AnimationClipELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$rs,$memLabel) {
 $data = $data|0;
 $rs = $rs|0;
 $memLabel = $memLabel|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$data>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = HEAP32[$memLabel>>2]|0;
  $4 = (($data) + 4|0);
  HEAP32[$4>>2] = $3;
 }
 $5 = (($data) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($7>>>0)<($rs>>>0);
 do {
  if ($8) {
   $9 = ($6|0)>(-1);
   if ($9) {
    HEAP32[$5>>2] = $rs;
    $10 = $rs << 2;
    $11 = (($data) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci($1,$10,4,$$byval_copy1,0,772056,370)|0);
    HEAP32[$data>>2] = $13;
    $26 = $13;
    break;
   } else {
    $14 = $rs << 2;
    $15 = (($data) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$0>>2] = $16;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,4,$$byval_copy1,0,772056,352)|0);
    $18 = HEAP32[$data>>2]|0;
    $19 = (($data) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $20 << 2;
    _memcpy(($17|0),($18|0),($21|0))|0;
    HEAP32[$5>>2] = $rs;
    HEAP32[$data>>2] = $17;
    $26 = $17;
    break;
   }
  } else {
   $26 = $1;
  }
 } while(0);
 $22 = (($data) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23>>>0)<($rs>>>0);
 if (!($24)) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $25 = (($26) + ($rs<<2)|0);
 $27 = ($23|0)==($rs|0);
 if ($27) {
  HEAP32[$22>>2] = $rs;
  STACKTOP = sp;return;
 }
 $28 = (($26) + ($23<<2)|0);
 $$01$i$i = $28;
 while(1) {
  $29 = ($$01$i$i|0)==(0|0);
  if (!($29)) {
   HEAP32[$$01$i$i>>2] = 0;
  }
  $30 = (($$01$i$i) + 4|0);
  $31 = ($30|0)==($25|0);
  if ($31) {
   break;
  } else {
   $$01$i$i = $30;
  }
 }
 HEAP32[$22>>2] = $rs;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18ControllerConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i = 0, $$pre$i$i2 = 0, $$pre$phi$i$i4Z2D = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $ArrayTransfer$i5$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i5$i$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $0;
 $3 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation13LayerConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $5;
 $8 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine20StateMachineConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  $13 = HEAP32[$1>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_iiii[$15 & 2047]($13,12,4)|0);
  $17 = ($16|0)==(0|0);
  if ($17) {
   $23 = 0;$25 = 0;
  } else {
   HEAP32[$16>>2] = 0;
   $18 = (($16) + 4|0);
   HEAP32[$18>>2] = 0;
   $19 = (($16) + 8|0);
   HEAP32[$19>>2] = 0;
   $20 = $16;
   $21 = $10;
   $22 = (($20) - ($21))|0;
   $23 = $22;$25 = $16;
  }
  HEAP32[$10>>2] = $23;
  $24 = (($this) + 28|0);
  HEAP32[$24>>2] = $25;
  $$pre$phi$i$iZ2D = $24;$28 = $23;
 } else {
  $$pre$i$i = (($this) + 28|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$28 = $11;
 }
 $26 = $10;
 $27 = (($28) + ($26))|0;
 $29 = $27;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $29;
 $30 = (($29) + 4|0);
 $31 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $30;
 $32 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$32>>2] = $29;
 $33 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$33>>2] = $31;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim13ValueConstantEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $34 = (($this) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0);
 if ($36) {
  $37 = HEAP32[$1>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$38>>2]|0;
  $40 = (FUNCTION_TABLE_iiii[$39 & 2047]($37,72,4)|0);
  $41 = ($40|0)==(0|0);
  if ($41) {
   $45 = 0;$47 = 0;
  } else {
   dest=$40+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $42 = $40;
   $43 = $34;
   $44 = (($42) - ($43))|0;
   $45 = $44;$47 = $40;
  }
  HEAP32[$34>>2] = $45;
  $46 = (($this) + 36|0);
  HEAP32[$46>>2] = $47;
  $$pre$phi$i$i4Z2D = $46;$50 = $45;
 } else {
  $$pre$i$i2 = (($this) + 36|0);
  $$pre$phi$i$i4Z2D = $$pre$i$i2;$50 = $35;
 }
 $48 = $34;
 $49 = (($50) + ($48))|0;
 $51 = $49;
 HEAP32[$$pre$phi$i$i4Z2D>>2] = $51;
 $52 = (($51) + 4|0);
 $53 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $52;
 $54 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$54>>2] = $51;
 $55 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$55>>2] = $53;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIbEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $56 = (($51) + 16|0);
 $57 = (($51) + 12|0);
 $58 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $56;
 $59 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$59>>2] = $57;
 $60 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$60>>2] = $58;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $61 = (($51) + 28|0);
 $62 = (($51) + 24|0);
 $63 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $61;
 $64 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$64>>2] = $62;
 $65 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$65>>2] = $63;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $66 = (($51) + 40|0);
 $67 = (($51) + 36|0);
 $68 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $66;
 $69 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$69>>2] = $67;
 $70 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$70>>2] = $68;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $71 = (($51) + 52|0);
 $72 = (($51) + 48|0);
 $73 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $71;
 $74 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$74>>2] = $72;
 $75 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$75>>2] = $73;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $76 = (($51) + 64|0);
 $77 = (($51) + 60|0);
 $78 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $76;
 $79 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$79>>2] = $77;
 $80 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$80>>2] = $78;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $41 = (($28) + 4|0);
  HEAP32[$41>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 4;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$39 = 0;
  } else {
   $36 = $34;
   $37 = $28;
   $38 = (($36) - ($37))|0;
   $$0$i1$i$i = $34;$39 = $38;
  }
  HEAP32[$28>>2] = $39;
  $40 = (($28) + 4|0);
  HEAP32[$40>>2] = $$0$i1$i$i;
 }
 $42 = HEAP32[$data>>2]|0;
 $43 = $42;
 $44 = HEAP32[$42>>2]|0;
 $45 = (($44) + ($43))|0;
 $46 = $45;
 $47 = (($42) + 4|0);
 HEAP32[$47>>2] = $46;
 $48 = HEAP32[$25>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($46) + ($49<<4)|0);
 $51 = HEAP32[$data>>2]|0;
 $52 = $51;
 $53 = HEAP32[$51>>2]|0;
 $54 = (($53) + ($52))|0;
 $55 = $54;
 $56 = (($51) + 4|0);
 HEAP32[$56>>2] = $55;
 $57 = ($55|0)==($50|0);
 if ($57) {
  STACKTOP = sp;return;
 } else {
  $i$06 = $55;
 }
 while(1) {
  __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb1EEEEvRS2_RT_($i$06,$this);
  $58 = (($i$06) + 16|0);
  $59 = ($58|0)==($50|0);
  if ($59) {
   break;
  } else {
   $i$06 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIbEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$20 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$20 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $22 = $$pre$i$i$i4;
 } else {
  $21 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $21;
  HEAP32[$1>>2] = $6;
  $22 = $21;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$size1>>2] = $23;
 $24 = (($data) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$25>>2] = $23;
 $26 = ($22|0)==(0);
 $27 = HEAP32[$data>>2]|0;
 if ($26) {
  HEAP32[$27>>2] = 0;
  $39 = (($27) + 4|0);
  HEAP32[$39>>2] = 0;
 } else {
  $28 = (($data) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,$23,1)|0);
  $33 = ($32|0)==(0|0);
  if ($33) {
   $37 = 0;
  } else {
   $34 = $32;
   $35 = $27;
   $36 = (($34) - ($35))|0;
   $37 = $36;
  }
  HEAP32[$27>>2] = $37;
  $38 = (($27) + 4|0);
  HEAP32[$38>>2] = $32;
 }
 $40 = HEAP32[$data>>2]|0;
 $41 = $40;
 $42 = HEAP32[$40>>2]|0;
 $43 = (($42) + ($41))|0;
 $44 = $43;
 $45 = (($40) + 4|0);
 HEAP32[$45>>2] = $44;
 $46 = HEAP32[$24>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($44) + ($47)|0);
 $49 = HEAP32[$data>>2]|0;
 $50 = $49;
 $51 = HEAP32[$49>>2]|0;
 $52 = (($51) + ($50))|0;
 $53 = $52;
 $54 = (($49) + 4|0);
 HEAP32[$54>>2] = $53;
 $55 = ($53|0)==($48|0);
 if ($55) {
  STACKTOP = sp;return;
 } else {
  $i$06 = $53;
 }
 while(1) {
  $56 = HEAP32[$1>>2]|0;
  $57 = (($56) + 1|0);
  $58 = HEAP32[$7>>2]|0;
  $59 = ($57>>>0)>($58>>>0);
  if ($59) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$06,1);
  } else {
   $60 = HEAP8[$56>>0]|0;
   HEAP8[$i$06>>0] = $60;
   $61 = HEAP32[$1>>2]|0;
   $62 = (($61) + 1|0);
   HEAP32[$1>>2] = $62;
  }
  $63 = (($i$06) + 1|0);
  $64 = ($63|0)==($48|0);
  if ($64) {
   break;
  } else {
   $i$06 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine20StateMachineConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $i$06 = $60;
 while(1) {
  $64 = HEAP32[$i$06>>2]|0;
  $65 = ($64|0)==(0);
  if ($65) {
   $66 = HEAP32[$63>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($66,44,4)|0);
   $70 = ($69|0)==(0|0);
   if ($70) {
    $75 = 0;$77 = 0;
   } else {
    $71 = (($69) + 28|0);
    ;HEAP32[$69+0>>2]=0|0;HEAP32[$69+4>>2]=0|0;HEAP32[$69+8>>2]=0|0;HEAP32[$69+12>>2]=0|0;HEAP32[$69+16>>2]=0|0;HEAP32[$69+20>>2]=0|0;
    ;HEAP32[$71+0>>2]=0|0;HEAP32[$71+4>>2]=0|0;HEAP32[$71+8>>2]=0|0;HEAP32[$71+12>>2]=0|0;
    $72 = $69;
    $73 = $i$06;
    $74 = (($72) - ($73))|0;
    $75 = $74;$77 = $69;
   }
   HEAP32[$i$06>>2] = $75;
   $76 = (($i$06) + 4|0);
   HEAP32[$76>>2] = $77;
   $$pre$phi$i$iZ2D = $76;$80 = $75;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$80 = $64;
  }
  $78 = $i$06;
  $79 = (($80) + ($78))|0;
  $81 = $79;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $81;
  __ZN7mecanim12statemachine20StateMachineConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($81,$this);
  $82 = (($i$06) + 8|0);
  $83 = ($82|0)==($55|0);
  if ($83) {
   break;
  } else {
   $i$06 = $82;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine20StateMachineConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i2 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i2>>2] = $0;
 $3 = (($ArrayTransfer$i2) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i2) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine13StateConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i2,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i2>>2] = $5;
 $8 = (($ArrayTransfer$i2) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($ArrayTransfer$i2) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i2,0);
 $10 = (($this) + 28|0);
 $11 = (($this) + 24|0);
 $12 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i2>>2] = $10;
 $13 = (($ArrayTransfer$i2) + 4|0);
 HEAP32[$13>>2] = $11;
 $14 = (($ArrayTransfer$i2) + 8|0);
 HEAP32[$14>>2] = $12;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i2,0);
 $15 = (($this) + 36|0);
 $16 = (($transfer) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 4|0);
 $19 = (($transfer) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$15,4);
  $$pre$i$i$i = HEAP32[$15>>2]|0;
  $$pre = HEAP32[$16>>2]|0;
  $$pre5 = HEAP32[$19>>2]|0;
  $23 = $$pre$i$i$i;$27 = $$pre;$29 = $$pre5;
 } else {
  $22 = HEAP32[$17>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$16>>2] = $18;
  $23 = $22;$27 = $18;$29 = $20;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$15>>2] = $24;
 $25 = (($this) + 40|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$25,4);
  $$pre$i$i$i3 = HEAP32[$25>>2]|0;
  $31 = $$pre$i$i$i3;
  $32 = (_llvm_bswap_i32(($31|0))|0);
  HEAP32[$25>>2] = $32;
  STACKTOP = sp;return;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$16>>2] = $26;
  $31 = $30;
  $32 = (_llvm_bswap_i32(($31|0))|0);
  HEAP32[$25>>2] = $32;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $i$06 = $60;
 while(1) {
  $64 = HEAP32[$i$06>>2]|0;
  $65 = ($64|0)==(0);
  if ($65) {
   $66 = HEAP32[$63>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($66,20,4)|0);
   $70 = ($69|0)==(0|0);
   if ($70) {
    $76 = 0;$78 = 0;
   } else {
    $71 = (($69) + 4|0);
    HEAP32[$71>>2] = 0;
    $72 = (($69) + 8|0);
    HEAP32[$72>>2] = 0;
    $73 = $69;
    $74 = $i$06;
    $75 = (($73) - ($74))|0;
    $76 = $75;$78 = $69;
   }
   HEAP32[$i$06>>2] = $76;
   $77 = (($i$06) + 4|0);
   HEAP32[$77>>2] = $78;
   $$pre$phi$i$iZ2D = $77;$81 = $76;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$81 = $64;
  }
  $79 = $i$06;
  $80 = (($81) + ($79))|0;
  $82 = $80;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $82;
  __ZN18StreamedBinaryReadILb1EE8TransferIN7mecanim12statemachine21SelectorStateConstantEEEvRT_PKc17TransferMetaFlags($this,$82,0,0);
  $83 = (($i$06) + 8|0);
  $84 = ($83|0)==($55|0);
  if ($84) {
   break;
  } else {
   $i$06 = $83;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE8TransferIN7mecanim12statemachine21SelectorStateConstantEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre1$i$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i = sp;
 $2 = (($data) + 4|0);
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i>>2] = $2;
 $5 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$5>>2] = $data;
 $6 = (($ArrayTransfer$i$i$i) + 8|0);
 HEAP32[$6>>2] = $4;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i,0);
 $7 = (($data) + 12|0);
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($this) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($8,$7,4);
  $$pre$i$i$i$i$i = HEAP32[$7>>2]|0;
  $$pre$i$i = HEAP32[$8>>2]|0;
  $$pre1$i$i = HEAP32[$11>>2]|0;
  $15 = $$pre$i$i$i$i$i;$19 = $$pre$i$i;$21 = $$pre1$i$i;
 } else {
  $14 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $14;
  HEAP32[$8>>2] = $10;
  $15 = $14;$19 = $10;$21 = $12;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$7>>2] = $16;
 $17 = (($data) + 16|0);
 $18 = (($19) + 1|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($8,$17,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
  STACKTOP = sp;return;
 } else {
  $22 = HEAP8[$19>>0]|0;
  HEAP8[$17>>0] = $22;
  $23 = HEAP32[$8>>2]|0;
  $24 = (($23) + 1|0);
  HEAP32[$8>>2] = $24;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i$i$i$i = sp + 12|0;
 $offset = sp;
 $size = sp + 4|0;
 $size1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i3 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i3;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $64 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 $65 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 $i$06 = $60;
 while(1) {
  $66 = HEAP32[$i$06>>2]|0;
  $67 = ($66|0)==(0);
  if ($67) {
   $68 = HEAP32[$63>>2]|0;
   $69 = HEAP32[$68>>2]|0;
   $70 = HEAP32[$69>>2]|0;
   $71 = (FUNCTION_TABLE_iiii[$70 & 2047]($68,16,4)|0);
   $72 = ($71|0)==(0|0);
   if ($72) {
    $78 = 0;$80 = 0;
   } else {
    HEAP32[$71>>2] = 0;
    $73 = (($71) + 8|0);
    HEAP32[$73>>2] = 0;
    $74 = (($71) + 12|0);
    HEAP32[$74>>2] = 0;
    $75 = $71;
    $76 = $i$06;
    $77 = (($75) - ($76))|0;
    $78 = $77;$80 = $71;
   }
   HEAP32[$i$06>>2] = $78;
   $79 = (($i$06) + 4|0);
   HEAP32[$79>>2] = $80;
   $$pre$phi$i$iZ2D = $79;$83 = $78;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$83 = $66;
  }
  $81 = $i$06;
  $82 = (($83) + ($81))|0;
  $84 = $82;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $84;
  $85 = HEAP32[$1>>2]|0;
  $86 = (($85) + 4|0);
  $87 = HEAP32[$7>>2]|0;
  $88 = ($86>>>0)>($87>>>0);
  if ($88) {
   $90 = $82;
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$90,4);
   $$pre$i$i$i$i$i$i$i$i = HEAP32[$84>>2]|0;
   $91 = $$pre$i$i$i$i$i$i$i$i;
  } else {
   $89 = HEAP32[$85>>2]|0;
   HEAP32[$84>>2] = $89;
   HEAP32[$1>>2] = $86;
   $91 = $89;
  }
  $92 = (_llvm_bswap_i32(($91|0))|0);
  HEAP32[$84>>2] = $92;
  $93 = (($84) + 8|0);
  $94 = (($84) + 4|0);
  $95 = HEAP32[$63>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $93;
  HEAP32[$64>>2] = $94;
  HEAP32[$65>>2] = $95;
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i$i$i,0);
  $96 = (($i$06) + 8|0);
  $97 = ($96|0)==($55|0);
  if ($97) {
   break;
  } else {
   $i$06 = $96;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $i$06 = $60;
 while(1) {
  $64 = HEAP32[$i$06>>2]|0;
  $65 = ($64|0)==(0);
  if ($65) {
   $66 = HEAP32[$63>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($66,16,4)|0);
   $70 = ($69|0)==(0|0);
   if ($70) {
    $77 = 0;$79 = 0;
   } else {
    HEAP32[$69>>2] = 1;
    $71 = (($69) + 4|0);
    HEAP32[$71>>2] = 0;
    $72 = (($69) + 8|0);
    HEAPF32[$72>>2] = Math_fround(0.0);
    $73 = (($69) + 12|0);
    HEAPF32[$73>>2] = Math_fround(0.0);
    $74 = $69;
    $75 = $i$06;
    $76 = (($74) - ($75))|0;
    $77 = $76;$79 = $69;
   }
   HEAP32[$i$06>>2] = $77;
   $78 = (($i$06) + 4|0);
   HEAP32[$78>>2] = $79;
   $$pre$phi$i$iZ2D = $78;$82 = $77;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$82 = $64;
  }
  $80 = $i$06;
  $81 = (($82) + ($80))|0;
  $83 = $81;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $83;
  __ZN7mecanim12statemachine17ConditionConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($83,$this);
  $84 = (($i$06) + 8|0);
  $85 = ($84|0)==($55|0);
  if ($85) {
   break;
  } else {
   $i$06 = $84;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine17ConditionConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i6 = 0, $$pre$phi$i$i$i7Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0;
 var $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre9;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre10;$21 = $$pre11;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $17;$24 = $$pre$i$i$i3;$28 = $$pre12;$30 = $$pre13;
 } else {
  $22 = Math_fround(HEAPF32[$19>>2]);
  HEAPF32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = (HEAPF32[tempDoublePtr>>2]=$22,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $17;$24 = $23;$28 = $18;$30 = $21;
 }
 $25 = (_llvm_bswap_i32(($24|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $25;
 $26 = (($this) + 12|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$26,4);
  $$pre$i$i$i6 = HEAP32[$26>>2]|0;
  $$pre$phi$i$i$i7Z2D = $26;$33 = $$pre$i$i$i6;
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i7Z2D>>2] = $34;
  STACKTOP = sp;return;
 } else {
  $31 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$26>>2] = $31;
  HEAP32[$0>>2] = $27;
  $32 = (HEAPF32[tempDoublePtr>>2]=$31,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i7Z2D = $26;$33 = $32;
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i7Z2D>>2] = $34;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $i$06 = $60;
 while(1) {
  $64 = HEAP32[$i$06>>2]|0;
  $65 = ($64|0)==(0);
  if ($65) {
   $66 = HEAP32[$63>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($66,52,4)|0);
   $70 = ($69|0)==(0|0);
   if ($70) {
    $79 = 0;$81 = 0;
   } else {
    $71 = (($69) + 36|0);
    dest=$69+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAPF32[$71>>2] = Math_fround(0.899999976158142089843);
    $72 = (($69) + 40|0);
    HEAP8[$72>>0] = 0;
    $73 = (($69) + 44|0);
    HEAP32[$73>>2] = 0;
    $74 = (($69) + 48|0);
    HEAP8[$74>>0] = 1;
    $75 = (($69) + 49|0);
    HEAP8[$75>>0] = 0;
    $76 = $69;
    $77 = $i$06;
    $78 = (($76) - ($77))|0;
    $79 = $78;$81 = $69;
   }
   HEAP32[$i$06>>2] = $79;
   $80 = (($i$06) + 4|0);
   HEAP32[$80>>2] = $81;
   $$pre$phi$i$iZ2D = $80;$84 = $79;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$84 = $64;
  }
  $82 = $i$06;
  $83 = (($84) + ($82))|0;
  $85 = $83;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $85;
  __ZN7mecanim12statemachine18TransitionConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($85,$this);
  $86 = (($i$06) + 8|0);
  $87 = ($86|0)==($55|0);
  if ($87) {
   break;
  } else {
   $i$06 = $86;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine18TransitionConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i5 = 0, $$pre$i$i$i7 = 0, $$pre$phi$i$i$i11Z2D = 0, $$pre$phi$i$i$i16Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0;
 var $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $ArrayTransfer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $0;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 $5 = (($this) + 12|0);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$5,4);
  $$pre$i$i$i = HEAP32[$5>>2]|0;
  $$pre = HEAP32[$6>>2]|0;
  $$pre21 = HEAP32[$9>>2]|0;
  $13 = $$pre$i$i$i;$17 = $$pre;$19 = $$pre21;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$5>>2] = $12;
  HEAP32[$6>>2] = $8;
  $13 = $12;$17 = $8;$19 = $10;
 }
 $14 = (_llvm_bswap_i32(($13|0))|0);
 HEAP32[$5>>2] = $14;
 $15 = (($this) + 16|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$15,4);
  $$pre$i$i$i1 = HEAP32[$15>>2]|0;
  $$pre22 = HEAP32[$6>>2]|0;
  $$pre23 = HEAP32[$9>>2]|0;
  $21 = $$pre$i$i$i1;$25 = $$pre22;$27 = $$pre23;
 } else {
  $20 = HEAP32[$17>>2]|0;
  HEAP32[$15>>2] = $20;
  HEAP32[$6>>2] = $16;
  $21 = $20;$25 = $16;$27 = $19;
 }
 $22 = (_llvm_bswap_i32(($21|0))|0);
 HEAP32[$15>>2] = $22;
 $23 = (($this) + 20|0);
 $24 = (($25) + 4|0);
 $26 = ($24>>>0)>($27>>>0);
 if ($26) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$23,4);
  $$pre$i$i$i3 = HEAP32[$23>>2]|0;
  $$pre24 = HEAP32[$6>>2]|0;
  $$pre25 = HEAP32[$9>>2]|0;
  $29 = $$pre$i$i$i3;$33 = $$pre24;$35 = $$pre25;
 } else {
  $28 = HEAP32[$25>>2]|0;
  HEAP32[$23>>2] = $28;
  HEAP32[$6>>2] = $24;
  $29 = $28;$33 = $24;$35 = $27;
 }
 $30 = (_llvm_bswap_i32(($29|0))|0);
 HEAP32[$23>>2] = $30;
 $31 = (($this) + 24|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$31,4);
  $$pre$i$i$i5 = HEAP32[$31>>2]|0;
  $$pre26 = HEAP32[$6>>2]|0;
  $$pre27 = HEAP32[$9>>2]|0;
  $37 = $$pre$i$i$i5;$41 = $$pre26;$43 = $$pre27;
 } else {
  $36 = HEAP32[$33>>2]|0;
  HEAP32[$31>>2] = $36;
  HEAP32[$6>>2] = $32;
  $37 = $36;$41 = $32;$43 = $35;
 }
 $38 = (_llvm_bswap_i32(($37|0))|0);
 HEAP32[$31>>2] = $38;
 $39 = (($this) + 28|0);
 $40 = (($41) + 4|0);
 $42 = ($40>>>0)>($43>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$39,4);
  $$pre$i$i$i7 = HEAP32[$39>>2]|0;
  $$pre28 = HEAP32[$6>>2]|0;
  $$pre29 = HEAP32[$9>>2]|0;
  $$pre$phi$i$i$iZ2D = $39;$46 = $$pre$i$i$i7;$50 = $$pre28;$52 = $$pre29;
 } else {
  $44 = Math_fround(HEAPF32[$41>>2]);
  HEAPF32[$39>>2] = $44;
  HEAP32[$6>>2] = $40;
  $45 = (HEAPF32[tempDoublePtr>>2]=$44,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $39;$46 = $45;$50 = $40;$52 = $43;
 }
 $47 = (_llvm_bswap_i32(($46|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $47;
 $48 = (($this) + 32|0);
 $49 = (($50) + 4|0);
 $51 = ($49>>>0)>($52>>>0);
 if ($51) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$48,4);
  $$pre$i$i$i10 = HEAP32[$48>>2]|0;
  $$pre30 = HEAP32[$6>>2]|0;
  $$pre31 = HEAP32[$9>>2]|0;
  $$pre$phi$i$i$i11Z2D = $48;$55 = $$pre$i$i$i10;$59 = $$pre30;$61 = $$pre31;
 } else {
  $53 = Math_fround(HEAPF32[$50>>2]);
  HEAPF32[$48>>2] = $53;
  HEAP32[$6>>2] = $49;
  $54 = (HEAPF32[tempDoublePtr>>2]=$53,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i11Z2D = $48;$55 = $54;$59 = $49;$61 = $52;
 }
 $56 = (_llvm_bswap_i32(($55|0))|0);
 HEAP32[$$pre$phi$i$i$i11Z2D>>2] = $56;
 $57 = (($this) + 36|0);
 $58 = (($59) + 4|0);
 $60 = ($58>>>0)>($61>>>0);
 if ($60) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$57,4);
  $$pre$i$i$i15 = HEAP32[$57>>2]|0;
  $$pre32 = HEAP32[$6>>2]|0;
  $$pre33 = HEAP32[$9>>2]|0;
  $$pre$phi$i$i$i16Z2D = $57;$64 = $$pre$i$i$i15;$68 = $$pre32;$70 = $$pre33;
 } else {
  $62 = Math_fround(HEAPF32[$59>>2]);
  HEAPF32[$57>>2] = $62;
  HEAP32[$6>>2] = $58;
  $63 = (HEAPF32[tempDoublePtr>>2]=$62,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i16Z2D = $57;$64 = $63;$68 = $58;$70 = $61;
 }
 $65 = (_llvm_bswap_i32(($64|0))|0);
 HEAP32[$$pre$phi$i$i$i16Z2D>>2] = $65;
 $66 = (($this) + 40|0);
 $67 = (($68) + 1|0);
 $69 = ($67>>>0)>($70>>>0);
 if ($69) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$66,1);
 } else {
  $71 = HEAP8[$68>>0]|0;
  HEAP8[$66>>0] = $71;
  $72 = HEAP32[$6>>2]|0;
  $73 = (($72) + 1|0);
  HEAP32[$6>>2] = $73;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $74 = (($this) + 44|0);
 $75 = HEAP32[$6>>2]|0;
 $76 = (($75) + 4|0);
 $77 = HEAP32[$9>>2]|0;
 $78 = ($76>>>0)>($77>>>0);
 if ($78) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$74,4);
  $$pre$i$i$i18 = HEAP32[$74>>2]|0;
  $$pre34 = HEAP32[$6>>2]|0;
  $$pre35 = HEAP32[$9>>2]|0;
  $80 = $$pre$i$i$i18;$84 = $$pre34;$86 = $$pre35;
 } else {
  $79 = HEAP32[$75>>2]|0;
  HEAP32[$74>>2] = $79;
  HEAP32[$6>>2] = $76;
  $80 = $79;$84 = $76;$86 = $77;
 }
 $81 = (_llvm_bswap_i32(($80|0))|0);
 HEAP32[$74>>2] = $81;
 $82 = (($this) + 48|0);
 $83 = (($84) + 1|0);
 $85 = ($83>>>0)>($86>>>0);
 if ($85) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$82,1);
  $$pre36 = HEAP32[$6>>2]|0;
  $92 = $$pre36;
 } else {
  $87 = HEAP8[$84>>0]|0;
  HEAP8[$82>>0] = $87;
  $88 = HEAP32[$6>>2]|0;
  $89 = (($88) + 1|0);
  HEAP32[$6>>2] = $89;
  $92 = $89;
 }
 $90 = (($this) + 49|0);
 $91 = (($92) + 1|0);
 $93 = HEAP32[$9>>2]|0;
 $94 = ($91>>>0)>($93>>>0);
 if ($94) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$90,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $95 = HEAP8[$92>>0]|0;
  HEAP8[$90>>0] = $95;
  $96 = HEAP32[$6>>2]|0;
  $97 = (($96) + 1|0);
  HEAP32[$6>>2] = $97;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine13StateConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0;
 var $size1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $i$06 = $60;
 while(1) {
  $64 = HEAP32[$i$06>>2]|0;
  $65 = ($64|0)==(0);
  if ($65) {
   $66 = HEAP32[$63>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($66,72,4)|0);
   $70 = ($69|0)==(0|0);
   if ($70) {
    $80 = 0;$82 = 0;
   } else {
    $71 = (($69) + 60|0);
    dest=$69+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAPF32[$71>>2] = Math_fround(1.0);
    $72 = (($69) + 64|0);
    HEAPF32[$72>>2] = Math_fround(0.0);
    $73 = (($69) + 68|0);
    HEAP8[$73>>0] = 1;
    $74 = (($69) + 69|0);
    HEAP8[$74>>0] = 1;
    $75 = (($69) + 70|0);
    HEAP8[$75>>0] = 0;
    $76 = (($69) + 71|0);
    HEAP8[$76>>0] = 0;
    $77 = $69;
    $78 = $i$06;
    $79 = (($77) - ($78))|0;
    $80 = $79;$82 = $69;
   }
   HEAP32[$i$06>>2] = $80;
   $81 = (($i$06) + 4|0);
   HEAP32[$81>>2] = $82;
   $$pre$phi$i$iZ2D = $81;$85 = $80;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$85 = $64;
  }
  $83 = $i$06;
  $84 = (($85) + ($83))|0;
  $86 = $84;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $86;
  __ZN7mecanim12statemachine13StateConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($86,$this);
  $87 = (($i$06) + 8|0);
  $88 = ($87|0)==($55|0);
  if ($88) {
   break;
  } else {
   $i$06 = $87;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine13StateConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i6 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0;
 var $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i3 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $0;
 $3 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i3,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $5;
 $8 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i3,0);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $10;
 $12 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$12>>2] = $6;
 $13 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$13>>2] = $11;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim12statemachine16LeafInfoConstantEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i3,0);
 $14 = (($this) + 36|0);
 $15 = (($this) + 32|0);
 $16 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $14;
 $17 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$17>>2] = $15;
 $18 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$18>>2] = $16;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i3,0);
 $19 = (($this) + 44|0);
 $20 = (($transfer) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 4|0);
 $23 = (($transfer) + 20|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22>>>0)>($24>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$19,4);
  $$pre$i$i$i = HEAP32[$19>>2]|0;
  $$pre = HEAP32[$20>>2]|0;
  $$pre19 = HEAP32[$23>>2]|0;
  $27 = $$pre$i$i$i;$31 = $$pre;$33 = $$pre19;
 } else {
  $26 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $26;
  HEAP32[$20>>2] = $22;
  $27 = $26;$31 = $22;$33 = $24;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$19>>2] = $28;
 $29 = (($this) + 48|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$29,4);
  $$pre$i$i$i4 = HEAP32[$29>>2]|0;
  $$pre20 = HEAP32[$20>>2]|0;
  $$pre21 = HEAP32[$23>>2]|0;
  $35 = $$pre$i$i$i4;$39 = $$pre20;$41 = $$pre21;
 } else {
  $34 = HEAP32[$31>>2]|0;
  HEAP32[$29>>2] = $34;
  HEAP32[$20>>2] = $30;
  $35 = $34;$39 = $30;$41 = $33;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$29>>2] = $36;
 $37 = (($this) + 52|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$37,4);
  $$pre$i$i$i6 = HEAP32[$37>>2]|0;
  $$pre22 = HEAP32[$20>>2]|0;
  $$pre23 = HEAP32[$23>>2]|0;
  $43 = $$pre$i$i$i6;$47 = $$pre22;$49 = $$pre23;
 } else {
  $42 = HEAP32[$39>>2]|0;
  HEAP32[$37>>2] = $42;
  HEAP32[$20>>2] = $38;
  $43 = $42;$47 = $38;$49 = $41;
 }
 $44 = (_llvm_bswap_i32(($43|0))|0);
 HEAP32[$37>>2] = $44;
 $45 = (($this) + 56|0);
 $46 = (($47) + 4|0);
 $48 = ($46>>>0)>($49>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$45,4);
  $$pre$i$i$i8 = HEAP32[$45>>2]|0;
  $$pre24 = HEAP32[$20>>2]|0;
  $$pre25 = HEAP32[$23>>2]|0;
  $51 = $$pre$i$i$i8;$55 = $$pre24;$57 = $$pre25;
 } else {
  $50 = HEAP32[$47>>2]|0;
  HEAP32[$45>>2] = $50;
  HEAP32[$20>>2] = $46;
  $51 = $50;$55 = $46;$57 = $49;
 }
 $52 = (_llvm_bswap_i32(($51|0))|0);
 HEAP32[$45>>2] = $52;
 $53 = (($this) + 60|0);
 $54 = (($55) + 4|0);
 $56 = ($54>>>0)>($57>>>0);
 if ($56) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$53,4);
  $$pre$i$i$i10 = HEAP32[$53>>2]|0;
  $$pre26 = HEAP32[$20>>2]|0;
  $$pre27 = HEAP32[$23>>2]|0;
  $$pre$phi$i$i$iZ2D = $53;$60 = $$pre$i$i$i10;$64 = $$pre26;$66 = $$pre27;
 } else {
  $58 = Math_fround(HEAPF32[$55>>2]);
  HEAPF32[$53>>2] = $58;
  HEAP32[$20>>2] = $54;
  $59 = (HEAPF32[tempDoublePtr>>2]=$58,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $53;$60 = $59;$64 = $54;$66 = $57;
 }
 $61 = (_llvm_bswap_i32(($60|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
 $62 = (($this) + 64|0);
 $63 = (($64) + 4|0);
 $65 = ($63>>>0)>($66>>>0);
 if ($65) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$62,4);
  $$pre$i$i$i13 = HEAP32[$62>>2]|0;
  $$pre28 = HEAP32[$20>>2]|0;
  $$pre29 = HEAP32[$23>>2]|0;
  $$pre$phi$i$i$i14Z2D = $62;$69 = $$pre$i$i$i13;$73 = $$pre28;$75 = $$pre29;
 } else {
  $67 = Math_fround(HEAPF32[$64>>2]);
  HEAPF32[$62>>2] = $67;
  HEAP32[$20>>2] = $63;
  $68 = (HEAPF32[tempDoublePtr>>2]=$67,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $62;$69 = $68;$73 = $63;$75 = $66;
 }
 $70 = (_llvm_bswap_i32(($69|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $70;
 $71 = (($this) + 68|0);
 $72 = (($73) + 1|0);
 $74 = ($72>>>0)>($75>>>0);
 if ($74) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$71,1);
  $$pre30 = HEAP32[$20>>2]|0;
  $81 = $$pre30;
 } else {
  $76 = HEAP8[$73>>0]|0;
  HEAP8[$71>>0] = $76;
  $77 = HEAP32[$20>>2]|0;
  $78 = (($77) + 1|0);
  HEAP32[$20>>2] = $78;
  $81 = $78;
 }
 $79 = (($this) + 69|0);
 $80 = (($81) + 1|0);
 $82 = HEAP32[$23>>2]|0;
 $83 = ($80>>>0)>($82>>>0);
 if ($83) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$79,1);
  $$pre31 = HEAP32[$20>>2]|0;
  $89 = $$pre31;
 } else {
  $84 = HEAP8[$81>>0]|0;
  HEAP8[$79>>0] = $84;
  $85 = HEAP32[$20>>2]|0;
  $86 = (($85) + 1|0);
  HEAP32[$20>>2] = $86;
  $89 = $86;
 }
 $87 = (($this) + 70|0);
 $88 = (($89) + 1|0);
 $90 = HEAP32[$23>>2]|0;
 $91 = ($88>>>0)>($90>>>0);
 if ($91) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$87,1);
  $$pre32 = HEAP32[$20>>2]|0;
  $97 = $$pre32;
 } else {
  $92 = HEAP8[$89>>0]|0;
  HEAP8[$87>>0] = $92;
  $93 = HEAP32[$20>>2]|0;
  $94 = (($93) + 1|0);
  HEAP32[$20>>2] = $94;
  $97 = $94;
 }
 $95 = (($this) + 71|0);
 $96 = (($97) + 1|0);
 $98 = HEAP32[$23>>2]|0;
 $99 = ($96>>>0)>($98>>>0);
 if ($99) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$95,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $100 = HEAP8[$97>>0]|0;
  HEAP8[$95>>0] = $100;
  $101 = HEAP32[$20>>2]|0;
  $102 = (($101) + 1|0);
  HEAP32[$20>>2] = $102;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, $i$06 = 0, $offset = 0;
 var $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i$i$i$i = sp + 12|0;
 $offset = sp;
 $size = sp + 4|0;
 $size1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $64 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 $65 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 $i$06 = $60;
 while(1) {
  $66 = HEAP32[$i$06>>2]|0;
  $67 = ($66|0)==(0);
  if ($67) {
   $68 = HEAP32[$63>>2]|0;
   $69 = HEAP32[$68>>2]|0;
   $70 = HEAP32[$69>>2]|0;
   $71 = (FUNCTION_TABLE_iiii[$70 & 2047]($68,12,4)|0);
   $72 = ($71|0)==(0|0);
   if ($72) {
    $78 = 0;$80 = 0;
   } else {
    HEAP32[$71>>2] = 0;
    $73 = (($71) + 4|0);
    HEAP32[$73>>2] = 0;
    $74 = (($71) + 8|0);
    HEAP32[$74>>2] = 0;
    $75 = $71;
    $76 = $i$06;
    $77 = (($75) - ($76))|0;
    $78 = $77;$80 = $71;
   }
   HEAP32[$i$06>>2] = $78;
   $79 = (($i$06) + 4|0);
   HEAP32[$79>>2] = $80;
   $$pre$phi$i$iZ2D = $79;$83 = $78;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$83 = $66;
  }
  $81 = $i$06;
  $82 = (($83) + ($81))|0;
  $84 = $82;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $84;
  $85 = (($84) + 4|0);
  $86 = HEAP32[$63>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $85;
  HEAP32[$64>>2] = $84;
  HEAP32[$65>>2] = $86;
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i$i$i,0);
  $87 = (($i$06) + 8|0);
  $88 = ($87|0)==($55|0);
  if ($88) {
   break;
  } else {
   $i$06 = $87;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $i$06 = 0, $offset = 0;
 var $size = 0, $size1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $i$06 = $60;
 while(1) {
  $64 = HEAP32[$i$06>>2]|0;
  $65 = ($64|0)==(0);
  if ($65) {
   $66 = HEAP32[$63>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($66,64,4)|0);
   $70 = ($69|0)==(0|0);
   if ($70) {
    $81 = 0;$83 = 0;
   } else {
    HEAP32[$69>>2] = 0;
    $71 = (($69) + 4|0);
    HEAP32[$71>>2] = -1;
    $72 = (($69) + 8|0);
    HEAP32[$72>>2] = -1;
    $73 = (($69) + 12|0);
    $74 = (($69) + 48|0);
    dest=$73+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$74>>2] = -1;
    $75 = (($69) + 52|0);
    HEAPF32[$75>>2] = Math_fround(0.0);
    $76 = (($69) + 56|0);
    HEAPF32[$76>>2] = Math_fround(0.0);
    $77 = (($69) + 60|0);
    HEAP8[$77>>0] = 0;
    $78 = $69;
    $79 = $i$06;
    $80 = (($78) - ($79))|0;
    $81 = $80;$83 = $69;
   }
   HEAP32[$i$06>>2] = $81;
   $82 = (($i$06) + 4|0);
   HEAP32[$82>>2] = $83;
   $$pre$phi$i$iZ2D = $82;$86 = $81;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$86 = $64;
  }
  $84 = $i$06;
  $85 = (($86) + ($84))|0;
  $87 = $85;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $87;
  __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($87,$this);
  $88 = (($i$06) + 8|0);
  $89 = ($88|0)==($55|0);
  if ($89) {
   break;
  } else {
   $i$06 = $88;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i13 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$i$i5 = 0, $$pre$phi$i$i$i14Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi$i$i7Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0;
 var $$pre23 = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i4$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i4$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre16;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre17 = HEAP32[$0>>2]|0;
  $$pre18 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre17;$21 = $$pre18;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i3 = HEAP32[$17>>2]|0;
  $23 = $$pre$i$i$i3;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$17>>2] = $24;
 $25 = (($this) + 16|0);
 $26 = (($this) + 12|0);
 $27 = (($transfer) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $25;
 $29 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$29>>2] = $26;
 $30 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$30>>2] = $28;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $31 = (($this) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0);
 if ($33) {
  $34 = HEAP32[$27>>2]|0;
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = (FUNCTION_TABLE_iiii[$36 & 2047]($34,12,4)|0);
  $38 = ($37|0)==(0|0);
  if ($38) {
   $44 = 0;$46 = 0;
  } else {
   HEAP32[$37>>2] = 0;
   $39 = (($37) + 4|0);
   HEAP32[$39>>2] = 0;
   $40 = (($37) + 8|0);
   HEAP32[$40>>2] = 0;
   $41 = $37;
   $42 = $31;
   $43 = (($41) - ($42))|0;
   $44 = $43;$46 = $37;
  }
  HEAP32[$31>>2] = $44;
  $45 = (($this) + 28|0);
  HEAP32[$45>>2] = $46;
  $$pre$phi$i$iZ2D = $45;$49 = $44;
 } else {
  $$pre$i$i = (($this) + 28|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$49 = $32;
 }
 $47 = $31;
 $48 = (($49) + ($47))|0;
 $50 = $48;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $50;
 $51 = (($50) + 4|0);
 $52 = HEAP32[$27>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $51;
 $53 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$53>>2] = $50;
 $54 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$54>>2] = $52;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $55 = (($this) + 32|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0);
 if ($57) {
  $58 = HEAP32[$27>>2]|0;
  $59 = HEAP32[$58>>2]|0;
  $60 = HEAP32[$59>>2]|0;
  $61 = (FUNCTION_TABLE_iiii[$60 & 2047]($58,60,4)|0);
  $62 = ($61|0)==(0|0);
  if ($62) {
   $66 = 0;$68 = 0;
  } else {
   dest=$61+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $63 = $61;
   $64 = $55;
   $65 = (($63) - ($64))|0;
   $66 = $65;$68 = $61;
  }
  HEAP32[$55>>2] = $66;
  $67 = (($this) + 36|0);
  HEAP32[$67>>2] = $68;
  $$pre$phi$i$i7Z2D = $67;$71 = $66;
 } else {
  $$pre$i$i5 = (($this) + 36|0);
  $$pre$phi$i$i7Z2D = $$pre$i$i5;$71 = $56;
 }
 $69 = $55;
 $70 = (($71) + ($69))|0;
 $72 = $70;
 HEAP32[$$pre$phi$i$i7Z2D>>2] = $72;
 $73 = (($72) + 4|0);
 $74 = HEAP32[$27>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $73;
 $75 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$75>>2] = $72;
 $76 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$76>>2] = $74;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $77 = (($72) + 16|0);
 $78 = (($72) + 12|0);
 $79 = HEAP32[$27>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $77;
 $80 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$80>>2] = $78;
 $81 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$81>>2] = $79;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $82 = (($72) + 28|0);
 $83 = (($72) + 24|0);
 $84 = HEAP32[$27>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $82;
 $85 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$85>>2] = $83;
 $86 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$86>>2] = $84;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $87 = (($72) + 40|0);
 $88 = (($72) + 36|0);
 $89 = HEAP32[$27>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $87;
 $90 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$90>>2] = $88;
 $91 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$91>>2] = $89;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $92 = (($72) + 52|0);
 $93 = (($72) + 48|0);
 $94 = HEAP32[$27>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $92;
 $95 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$95>>2] = $93;
 $96 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$96>>2] = $94;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $97 = (($this) + 40|0);
 __ZN18StreamedBinaryReadILb1EE8TransferI9OffsetPtrIN7mecanim9animation23BlendDirectDataConstantEEEEvRT_PKc17TransferMetaFlags($transfer,$97,0,0);
 $98 = (($this) + 48|0);
 $99 = HEAP32[$0>>2]|0;
 $100 = (($99) + 4|0);
 $101 = HEAP32[$3>>2]|0;
 $102 = ($100>>>0)>($101>>>0);
 if ($102) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$98,4);
  $$pre$i$i$i8 = HEAP32[$98>>2]|0;
  $$pre19 = HEAP32[$0>>2]|0;
  $$pre20 = HEAP32[$3>>2]|0;
  $104 = $$pre$i$i$i8;$108 = $$pre19;$110 = $$pre20;
 } else {
  $103 = HEAP32[$99>>2]|0;
  HEAP32[$98>>2] = $103;
  HEAP32[$0>>2] = $100;
  $104 = $103;$108 = $100;$110 = $101;
 }
 $105 = (_llvm_bswap_i32(($104|0))|0);
 HEAP32[$98>>2] = $105;
 $106 = (($this) + 52|0);
 $107 = (($108) + 4|0);
 $109 = ($107>>>0)>($110>>>0);
 if ($109) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$106,4);
  $$pre$i$i$i10 = HEAP32[$106>>2]|0;
  $$pre21 = HEAP32[$0>>2]|0;
  $$pre22 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $106;$113 = $$pre$i$i$i10;$117 = $$pre21;$119 = $$pre22;
 } else {
  $111 = Math_fround(HEAPF32[$108>>2]);
  HEAPF32[$106>>2] = $111;
  HEAP32[$0>>2] = $107;
  $112 = (HEAPF32[tempDoublePtr>>2]=$111,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $106;$113 = $112;$117 = $107;$119 = $110;
 }
 $114 = (_llvm_bswap_i32(($113|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $114;
 $115 = (($this) + 56|0);
 $116 = (($117) + 4|0);
 $118 = ($116>>>0)>($119>>>0);
 if ($118) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$115,4);
  $$pre$i$i$i13 = HEAP32[$115>>2]|0;
  $$pre23 = HEAP32[$0>>2]|0;
  $$pre24 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$i14Z2D = $115;$122 = $$pre$i$i$i13;$126 = $$pre23;$128 = $$pre24;
 } else {
  $120 = Math_fround(HEAPF32[$117>>2]);
  HEAPF32[$115>>2] = $120;
  HEAP32[$0>>2] = $116;
  $121 = (HEAPF32[tempDoublePtr>>2]=$120,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i14Z2D = $115;$122 = $121;$126 = $116;$128 = $119;
 }
 $123 = (_llvm_bswap_i32(($122|0))|0);
 HEAP32[$$pre$phi$i$i$i14Z2D>>2] = $123;
 $124 = (($this) + 60|0);
 $125 = (($126) + 1|0);
 $127 = ($125>>>0)>($128>>>0);
 if ($127) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$124,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $129 = HEAP8[$126>>0]|0;
  HEAP8[$124>>0] = $129;
  $130 = HEAP32[$0>>2]|0;
  $131 = (($130) + 1|0);
  HEAP32[$0>>2] = $131;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE8TransferI9OffsetPtrIN7mecanim9animation23BlendDirectDataConstantEEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre$phi2$iZ2D = 0, $$pre1$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i = sp;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_iiii[$7 & 2047]($5,16,4)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $13 = 0;$15 = 0;
  } else {
   ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP8[$8+12>>0]=0|0;
   $10 = $8;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $8;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phi$iZ2D = $14;$$pre$phi2$iZ2D = $4;$18 = $13;
 } else {
  $$pre$i = (($data) + 4|0);
  $$pre1$i = (($this) + 4|0);
  $$pre$phi$iZ2D = $$pre$i;$$pre$phi2$iZ2D = $$pre1$i;$18 = $2;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phi$iZ2D>>2] = $19;
 $20 = (($19) + 4|0);
 $21 = HEAP32[$$pre$phi2$iZ2D>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i>>2] = $20;
 $22 = (($ArrayTransfer$i$i$i$i$i) + 4|0);
 HEAP32[$22>>2] = $19;
 $23 = (($ArrayTransfer$i$i$i$i$i) + 8|0);
 HEAP32[$23>>2] = $21;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i$i,0);
 $24 = (($19) + 12|0);
 $25 = (($this) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1|0);
 $28 = (($this) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27>>>0)>($29>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($25,$24,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
  STACKTOP = sp;return;
 } else {
  $31 = HEAP8[$26>>0]|0;
  HEAP8[$24>>0] = $31;
  $32 = HEAP32[$25>>2]|0;
  $33 = (($32) + 1|0);
  HEAP32[$25>>2] = $33;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i = 0, $i$06 = 0, $offset = 0;
 var $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i$i = sp + 12|0;
 $offset = sp;
 $size = sp + 4|0;
 $size1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = ($21*12)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $47 = (($28) + 4|0);
  HEAP32[$47>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = ($24*12)|0;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$45 = 0;
  } else {
   $36 = (($34) + (($24*12)|0)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    HEAP32[$39>>2] = 0;
    $40 = (($37) + 12|0);
    $41 = ($40|0)==($36|0);
    if ($41) {
     break;
    } else {
     $37 = $40;
    }
   }
   $42 = $34;
   $43 = $28;
   $44 = (($42) - ($43))|0;
   $$0$i1$i$i = $34;$45 = $44;
  }
  HEAP32[$28>>2] = $45;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = $$0$i1$i$i;
 }
 $48 = HEAP32[$data>>2]|0;
 $49 = $48;
 $50 = HEAP32[$48>>2]|0;
 $51 = (($50) + ($49))|0;
 $52 = $51;
 $53 = (($48) + 4|0);
 HEAP32[$53>>2] = $52;
 $54 = HEAP32[$25>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($52) + (($55*12)|0)|0);
 $57 = HEAP32[$data>>2]|0;
 $58 = $57;
 $59 = HEAP32[$57>>2]|0;
 $60 = (($59) + ($58))|0;
 $61 = $60;
 $62 = (($57) + 4|0);
 HEAP32[$62>>2] = $61;
 $63 = ($61|0)==($56|0);
 if ($63) {
  STACKTOP = sp;return;
 }
 $64 = (($this) + 4|0);
 $65 = (($ArrayTransfer$i$i$i$i) + 4|0);
 $66 = (($ArrayTransfer$i$i$i$i) + 8|0);
 $i$06 = $61;
 while(1) {
  $67 = (($i$06) + 4|0);
  $68 = HEAP32[$64>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i>>2] = $67;
  HEAP32[$65>>2] = $i$06;
  HEAP32[$66>>2] = $68;
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i,0);
  $69 = (($i$06) + 12|0);
  $70 = ($69|0)==($56|0);
  if ($70) {
   break;
  } else {
   $i$06 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i3$i$i$i = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre$phi$i$i$i4$i$i$iZ2D = 0, $$pre6$i$i$i = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $i$07 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAPF32[$37>>2] = Math_fround(0.0);
    $38 = (($37) + 4|0);
    HEAPF32[$38>>2] = Math_fround(0.0);
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 } else {
  $i$07 = $60;
 }
 while(1) {
  $63 = HEAP32[$1>>2]|0;
  $64 = (($63) + 4|0);
  $65 = HEAP32[$7>>2]|0;
  $66 = ($64>>>0)>($65>>>0);
  if ($66) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$07,4);
   $$pre$i$i$i3$i$i$i = HEAP32[$i$07>>2]|0;
   $$pre$i$i$i = HEAP32[$1>>2]|0;
   $$pre6$i$i$i = HEAP32[$7>>2]|0;
   $$pre$phi$i$i$i4$i$i$iZ2D = $i$07;$69 = $$pre$i$i$i3$i$i$i;$73 = $$pre$i$i$i;$75 = $$pre6$i$i$i;
  } else {
   $67 = Math_fround(HEAPF32[$63>>2]);
   HEAPF32[$i$07>>2] = $67;
   HEAP32[$1>>2] = $64;
   $68 = (HEAPF32[tempDoublePtr>>2]=$67,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$i4$i$i$iZ2D = $i$07;$69 = $68;$73 = $64;$75 = $65;
  }
  $70 = (_llvm_bswap_i32(($69|0))|0);
  HEAP32[$$pre$phi$i$i$i4$i$i$iZ2D>>2] = $70;
  $71 = (($i$07) + 4|0);
  $72 = (($73) + 4|0);
  $74 = ($72>>>0)>($75>>>0);
  if ($74) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$71,4);
   $$pre$i$i$i$i$i$i = HEAP32[$71>>2]|0;
   $$pre$phi$i$i$i$i$i$iZ2D = $71;$78 = $$pre$i$i$i$i$i$i;
  } else {
   $76 = Math_fround(HEAPF32[$73>>2]);
   HEAPF32[$71>>2] = $76;
   HEAP32[$1>>2] = $72;
   $77 = (HEAPF32[tempDoublePtr>>2]=$76,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$i$i$i$iZ2D = $71;$78 = $77;
  }
  $79 = (_llvm_bswap_i32(($78|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $79;
  $80 = (($i$07) + 8|0);
  $81 = ($80|0)==($55|0);
  if ($81) {
   break;
  } else {
   $i$07 = $80;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim12statemachine16LeafInfoConstantEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i$i = sp + 12|0;
 $offset = sp;
 $size = sp + 4|0;
 $size1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 4;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$43 = 0;
  } else {
   $36 = (($34) + ($24<<4)|0);
   $37 = $34;
   while(1) {
    ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;
    $38 = (($37) + 16|0);
    $39 = ($38|0)==($36|0);
    if ($39) {
     break;
    } else {
     $37 = $38;
    }
   }
   $40 = $34;
   $41 = $28;
   $42 = (($40) - ($41))|0;
   $$0$i1$i$i = $34;$43 = $42;
  }
  HEAP32[$28>>2] = $43;
  $44 = (($28) + 4|0);
  HEAP32[$44>>2] = $$0$i1$i$i;
 }
 $46 = HEAP32[$data>>2]|0;
 $47 = $46;
 $48 = HEAP32[$46>>2]|0;
 $49 = (($48) + ($47))|0;
 $50 = $49;
 $51 = (($46) + 4|0);
 HEAP32[$51>>2] = $50;
 $52 = HEAP32[$25>>2]|0;
 $53 = HEAP32[$52>>2]|0;
 $54 = (($50) + ($53<<4)|0);
 $55 = HEAP32[$data>>2]|0;
 $56 = $55;
 $57 = HEAP32[$55>>2]|0;
 $58 = (($57) + ($56))|0;
 $59 = $58;
 $60 = (($55) + 4|0);
 HEAP32[$60>>2] = $59;
 $61 = ($59|0)==($54|0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $62 = (($this) + 4|0);
 $63 = (($ArrayTransfer$i$i$i$i) + 4|0);
 $64 = (($ArrayTransfer$i$i$i$i) + 8|0);
 $i$06 = $59;
 while(1) {
  $65 = (($i$06) + 4|0);
  $66 = HEAP32[$62>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i>>2] = $65;
  HEAP32[$63>>2] = $i$06;
  HEAP32[$64>>2] = $66;
  __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i,0);
  $67 = (($i$06) + 12|0);
  $68 = HEAP32[$1>>2]|0;
  $69 = (($68) + 4|0);
  $70 = HEAP32[$7>>2]|0;
  $71 = ($69>>>0)>($70>>>0);
  if ($71) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$67,4);
   $$pre$i$i$i$i$i$i = HEAP32[$67>>2]|0;
   $73 = $$pre$i$i$i$i$i$i;
  } else {
   $72 = HEAP32[$68>>2]|0;
   HEAP32[$67>>2] = $72;
   HEAP32[$1>>2] = $69;
   $73 = $72;
  }
  $74 = (_llvm_bswap_i32(($73|0))|0);
  HEAP32[$67>>2] = $74;
  $75 = (($i$06) + 16|0);
  $76 = ($75|0)==($54|0);
  if ($76) {
   break;
  } else {
   $i$06 = $75;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation13LayerConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre$phi$i$iZ2D = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $i$06 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($this) + 4|0);
 $i$06 = $60;
 while(1) {
  $64 = HEAP32[$i$06>>2]|0;
  $65 = ($64|0)==(0);
  if ($65) {
   $66 = HEAP32[$63>>2]|0;
   $67 = HEAP32[$66>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($66,40,4)|0);
   $70 = ($69|0)==(0|0);
   if ($70) {
    $78 = 0;$80 = 0;
   } else {
    $71 = (($69) + 8|0);
    $72 = (($69) + 28|0);
    HEAP32[$72>>2] = 0;
    $73 = (($69) + 36|0);
    ;HEAP32[$71+0>>2]=0|0;HEAP32[$71+4>>2]=0|0;HEAP32[$71+8>>2]=0|0;HEAP32[$71+12>>2]=0|0;
    HEAP8[$73>>0] = 1;
    $74 = (($69) + 37|0);
    HEAP8[$74>>0] = 0;
    $75 = $69;
    $76 = $i$06;
    $77 = (($75) - ($76))|0;
    $78 = $77;$80 = $69;
   }
   HEAP32[$i$06>>2] = $78;
   $79 = (($i$06) + 4|0);
   HEAP32[$79>>2] = $80;
   $$pre$phi$i$iZ2D = $79;$83 = $78;
  } else {
   $$pre$i$i = (($i$06) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$83 = $64;
  }
  $81 = $i$06;
  $82 = (($83) + ($81))|0;
  $84 = $82;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $84;
  __ZN7mecanim9animation13LayerConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($84,$this);
  $85 = (($i$06) + 8|0);
  $86 = ($85|0)==($55|0);
  if ($86) {
   break;
  } else {
   $i$06 = $85;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation13LayerConstant8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i1$i$i = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i6 = 0, $$pre$i$i$i7 = 0, $$pre$i$i3 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi2$i$iZ2D = 0, $$pre1$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0;
 var $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre3$i$i = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $11 = $$pre;$13 = $$pre9;$7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $2;$13 = $4;$7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre$i$i$i1 = HEAP32[$9>>2]|0;
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i$i1;$19 = $$pre10;$21 = $$pre11;
 } else {
  $14 = HEAP32[$11>>2]|0;
  HEAP32[$9>>2] = $14;
  HEAP32[$0>>2] = $10;
  $15 = $14;$19 = $10;$21 = $13;
 }
 $16 = (_llvm_bswap_i32(($15|0))|0);
 HEAP32[$9>>2] = $16;
 $17 = (($this) + 8|0);
 $18 = (($19) + 4|0);
 $20 = ($18>>>0)>($21>>>0);
 if ($20) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$17,4);
  $$pre$i$i$i1$i$i = HEAP32[$17>>2]|0;
  $$pre$i$i = HEAP32[$0>>2]|0;
  $$pre3$i$i = HEAP32[$3>>2]|0;
  $23 = $$pre$i$i$i1$i$i;$27 = $$pre$i$i;$29 = $$pre3$i$i;
 } else {
  $22 = HEAP32[$19>>2]|0;
  HEAP32[$17>>2] = $22;
  HEAP32[$0>>2] = $18;
  $23 = $22;$27 = $18;$29 = $21;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$17>>2] = $24;
 $25 = (($this) + 12|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre$i$i$i$i$i = HEAP32[$25>>2]|0;
  $31 = $$pre$i$i$i$i$i;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = $30;
 }
 $32 = (_llvm_bswap_i32(($31|0))|0);
 HEAP32[$25>>2] = $32;
 $33 = (($this) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if ($35) {
  $36 = (($transfer) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$38>>2]|0;
  $40 = (FUNCTION_TABLE_iiii[$39 & 2047]($37,12,4)|0);
  $41 = ($40|0)==(0|0);
  if ($41) {
   $47 = 0;$49 = 0;
  } else {
   HEAP32[$40>>2] = 0;
   $42 = (($40) + 4|0);
   HEAP32[$42>>2] = 0;
   $43 = (($40) + 8|0);
   HEAP32[$43>>2] = 0;
   $44 = $40;
   $45 = $33;
   $46 = (($44) - ($45))|0;
   $47 = $46;$49 = $40;
  }
  HEAP32[$33>>2] = $47;
  $48 = (($this) + 20|0);
  HEAP32[$48>>2] = $49;
  $$pre$phi$i$iZ2D = $48;$$pre$phi2$i$iZ2D = $36;$52 = $47;
 } else {
  $$pre$i$i3 = (($this) + 20|0);
  $$pre1$i$i = (($transfer) + 4|0);
  $$pre$phi$i$iZ2D = $$pre$i$i3;$$pre$phi2$i$iZ2D = $$pre1$i$i;$52 = $34;
 }
 $50 = $33;
 $51 = (($52) + ($50))|0;
 $53 = $51;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $53;
 $54 = (($53) + 4|0);
 $55 = HEAP32[$$pre$phi2$i$iZ2D>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $54;
 $56 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$56>>2] = $53;
 $57 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$57>>2] = $55;
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim8skeleton19SkeletonMaskElementEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 $58 = (($this) + 24|0);
 $59 = HEAP32[$0>>2]|0;
 $60 = (($59) + 4|0);
 $61 = HEAP32[$3>>2]|0;
 $62 = ($60>>>0)>($61>>>0);
 if ($62) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$58,4);
  $$pre$i$i$i4 = HEAP32[$58>>2]|0;
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $64 = $$pre$i$i$i4;$68 = $$pre12;$70 = $$pre13;
 } else {
  $63 = HEAP32[$59>>2]|0;
  HEAP32[$58>>2] = $63;
  HEAP32[$0>>2] = $60;
  $64 = $63;$68 = $60;$70 = $61;
 }
 $65 = (_llvm_bswap_i32(($64|0))|0);
 HEAP32[$58>>2] = $65;
 $66 = (($this) + 28|0);
 $67 = (($68) + 4|0);
 $69 = ($67>>>0)>($70>>>0);
 if ($69) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$66,4);
  $$pre$i$i$i6 = HEAP32[$66>>2]|0;
  $$pre14 = HEAP32[$0>>2]|0;
  $$pre15 = HEAP32[$3>>2]|0;
  $72 = $$pre$i$i$i6;$76 = $$pre14;$78 = $$pre15;
 } else {
  $71 = HEAP32[$68>>2]|0;
  HEAP32[$66>>2] = $71;
  HEAP32[$0>>2] = $67;
  $72 = $71;$76 = $67;$78 = $70;
 }
 $73 = (_llvm_bswap_i32(($72|0))|0);
 HEAP32[$66>>2] = $73;
 $74 = (($this) + 32|0);
 $75 = (($76) + 4|0);
 $77 = ($75>>>0)>($78>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$74,4);
  $$pre$i$i$i7 = HEAP32[$74>>2]|0;
  $$pre16 = HEAP32[$0>>2]|0;
  $$pre17 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $74;$81 = $$pre$i$i$i7;$85 = $$pre16;$87 = $$pre17;
 } else {
  $79 = Math_fround(HEAPF32[$76>>2]);
  HEAPF32[$74>>2] = $79;
  HEAP32[$0>>2] = $75;
  $80 = (HEAPF32[tempDoublePtr>>2]=$79,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $74;$81 = $80;$85 = $75;$87 = $78;
 }
 $82 = (_llvm_bswap_i32(($81|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $82;
 $83 = (($this) + 36|0);
 $84 = (($85) + 1|0);
 $86 = ($84>>>0)>($87>>>0);
 if ($86) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$83,1);
  $$pre18 = HEAP32[$0>>2]|0;
  $93 = $$pre18;
 } else {
  $88 = HEAP8[$85>>0]|0;
  HEAP8[$83>>0] = $88;
  $89 = HEAP32[$0>>2]|0;
  $90 = (($89) + 1|0);
  HEAP32[$0>>2] = $90;
  $93 = $90;
 }
 $91 = (($this) + 37|0);
 $92 = (($93) + 1|0);
 $94 = HEAP32[$3>>2]|0;
 $95 = ($92>>>0)>($94>>>0);
 if ($95) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$91,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $96 = HEAP8[$93>>0]|0;
  HEAP8[$91>>0] = $96;
  $97 = HEAP32[$0>>2]|0;
  $98 = (($97) + 1|0);
  HEAP32[$0>>2] = $98;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim8skeleton19SkeletonMaskElementEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i1$i$i$i = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i$i$i$iZ2D = 0, $$pre2$i$i$i = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $i$07 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i1 = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i1;$14 = $$pre;$16 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i2 = HEAP32[$offset>>2]|0;
   $$pre9 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i2;$21 = $$pre9;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i5 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i5;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 HEAP32[$26>>2] = $24;
 $27 = ($23|0)==(0);
 $28 = HEAP32[$data>>2]|0;
 if ($27) {
  HEAP32[$28>>2] = 0;
  $46 = (($28) + 4|0);
  HEAP32[$46>>2] = 0;
 } else {
  $29 = (($data) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = $24 << 3;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($30,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i1$i$i = 0;$44 = 0;
  } else {
   $36 = (($34) + ($24<<3)|0);
   $37 = $34;
   while(1) {
    HEAP32[$37>>2] = 0;
    $38 = (($37) + 4|0);
    HEAPF32[$38>>2] = Math_fround(0.0);
    $39 = (($37) + 8|0);
    $40 = ($39|0)==($36|0);
    if ($40) {
     break;
    } else {
     $37 = $39;
    }
   }
   $41 = $34;
   $42 = $28;
   $43 = (($41) - ($42))|0;
   $$0$i1$i$i = $34;$44 = $43;
  }
  HEAP32[$28>>2] = $44;
  $45 = (($28) + 4|0);
  HEAP32[$45>>2] = $$0$i1$i$i;
 }
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$25>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($51) + ($54<<3)|0);
 $56 = HEAP32[$data>>2]|0;
 $57 = $56;
 $58 = HEAP32[$56>>2]|0;
 $59 = (($58) + ($57))|0;
 $60 = $59;
 $61 = (($56) + 4|0);
 HEAP32[$61>>2] = $60;
 $62 = ($60|0)==($55|0);
 if ($62) {
  STACKTOP = sp;return;
 } else {
  $i$07 = $60;
 }
 while(1) {
  $63 = HEAP32[$1>>2]|0;
  $64 = (($63) + 4|0);
  $65 = HEAP32[$7>>2]|0;
  $66 = ($64>>>0)>($65>>>0);
  if ($66) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$07,4);
   $$pre$i$i$i$i$i$i = HEAP32[$i$07>>2]|0;
   $$pre$i$i$i = HEAP32[$1>>2]|0;
   $$pre2$i$i$i = HEAP32[$7>>2]|0;
   $68 = $$pre$i$i$i$i$i$i;$72 = $$pre$i$i$i;$74 = $$pre2$i$i$i;
  } else {
   $67 = HEAP32[$63>>2]|0;
   HEAP32[$i$07>>2] = $67;
   HEAP32[$1>>2] = $64;
   $68 = $67;$72 = $64;$74 = $65;
  }
  $69 = (_llvm_bswap_i32(($68|0))|0);
  HEAP32[$i$07>>2] = $69;
  $70 = (($i$07) + 4|0);
  $71 = (($72) + 4|0);
  $73 = ($71>>>0)>($74>>>0);
  if ($73) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$70,4);
   $$pre$i$i$i1$i$i$i = HEAP32[$70>>2]|0;
   $$pre$phi$i$i$i$i$i$iZ2D = $70;$77 = $$pre$i$i$i1$i$i$i;
  } else {
   $75 = Math_fround(HEAPF32[$72>>2]);
   HEAPF32[$70>>2] = $75;
   HEAP32[$1>>2] = $71;
   $76 = (HEAPF32[tempDoublePtr>>2]=$75,HEAP32[tempDoublePtr>>2]|0);
   $$pre$phi$i$i$i$i$i$iZ2D = $70;$77 = $76;
  }
  $78 = (_llvm_bswap_i32(($77|0))|0);
  HEAP32[$$pre$phi$i$i$i$i$i$iZ2D>>2] = $78;
  $79 = (($i$07) + 8|0);
  $80 = ($79|0)==($55|0);
  if ($80) {
   break;
  } else {
   $i$07 = $79;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AnimatorController8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN25RuntimeAnimatorController8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 88|0);
 $1 = (($transfer) + 4|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 112|0);
 $3 = (($this) + 116|0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$3,4);
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$3>>2] = $10;
  HEAP32[$4>>2] = $6;
 }
 $11 = HEAP32[$2>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = HEAP32[$1>>2]|0;
  $14 = HEAP32[$3>>2]|0;
  __ZN7mecanim6memory16ChainedAllocator7ReserveEj($13,$14);
  $15 = HEAP32[$13>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_iiii[$16 & 2047]($13,40,4)|0);
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = 0;
  } else {
   dest=$17+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $19 = $17;
  }
  HEAP32[$2>>2] = $19;
  $20 = $19;
 } else {
  $20 = $11;
 }
 __ZN7mecanim9animation18ControllerConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($20,$transfer);
 $21 = (($this) + 124|0);
 __ZN18StreamedBinaryReadILb0EE19TransferSTLStyleMapINSt3__13mapIj8UnityStrNS2_4lessIjEENS2_9allocatorINS2_4pairIKjS4_EEEEEEEEvRT_17TransferMetaFlags($transfer,$21,0);
 $22 = (($this) + 68|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI13AnimationClipELj4EEEEvRT_17TransferMetaFlags($transfer,$22,0);
 $23 = (($this) + 140|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapI8StateKey10StateRangeNSt3__14lessIS3_EENS5_9allocatorINS5_4pairIS3_S4_EEEEEEEvRT_17TransferMetaFlags($transfer,$23,0);
 $24 = (($this) + 156|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$24,0);
 $25 = (($this) + 172|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI25StateMachineBehaviourInfoNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($transfer,$25,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $26 = (($this) + 136|0);
 $27 = HEAP32[$4>>2]|0;
 $28 = (($27) + 1|0);
 $29 = HEAP32[$7>>2]|0;
 $30 = ($28>>>0)>($29>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($4,$26,1);
  STACKTOP = sp;return;
 } else {
  $31 = HEAP8[$27>>0]|0;
  HEAP8[$26>>0] = $31;
  $32 = HEAP32[$4>>2]|0;
  $33 = (($32) + 1|0);
  HEAP32[$4>>2] = $33;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI25StateMachineBehaviourInfoNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI25StateMachineBehaviourInfoNS0_9allocatorIS2_EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrI13MonoBehaviourE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrI13MonoBehaviourE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapI8StateKey10StateRangeNSt3__14lessIS3_EENS5_9allocatorINS5_4pairIS3_S4_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre7 = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $12 = $$pre7;$14 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre9 = HEAP32[$offset>>2]|0;
   $18 = $$pre9;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $29 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $29 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = (($data) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$20>>2]|0;
 $24 = $22;
 $25 = $23;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 4;
 $28 = ($27>>>0)<($29>>>0);
 if ($28) {
  $30 = (($29) - ($27))|0;
  __ZNSt3__16vectorINS_4pairI8StateKey10StateRangeEENS_9allocatorIS4_EEE8__appendEj($20,$30);
  $$pre5 = HEAP32[$21>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre6 = HEAP32[$$phi$trans$insert>>2]|0;
  $38 = $$pre6;$39 = $$pre5;
 } else {
  $31 = ($27>>>0)>($29>>>0);
  if ($31) {
   $32 = (($23) + ($29<<4)|0);
   $33 = ($22|0)==($32|0);
   if ($33) {
    $38 = $23;$39 = $22;
   } else {
    $__new_last2$i$i$i$i = $32;
    $scevgep$i$i$i$i = (($22) + -16|0);
    $34 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($34)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $35 = $uglygep3$i$i$i$i >>> 4;
    $36 = $35 ^ -1;
    $scevgep4$i$i$i$i = (($22) + ($36<<4)|0);
    HEAP32[$21>>2] = $scevgep4$i$i$i$i;
    $38 = $23;$39 = $scevgep4$i$i$i$i;
   }
  } else {
   $38 = $23;$39 = $22;
  }
 }
 $37 = ($38|0)==($39|0);
 if ($37) {
  STACKTOP = sp;return;
 } else {
  $40 = $38;
 }
 while(1) {
  __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI18StreamedBinaryReadILb0EEEEvRS4_RT_($40,$this);
  $41 = (($40) + 16|0);
  $42 = ($41|0)==($39|0);
  if ($42) {
   break;
  } else {
   $40 = $41;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI18StreamedBinaryReadILb0EEEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre1$i$i$i = 0, $$pre2$i$i$i = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$data,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre1$i$i$i = HEAP32[$3>>2]|0;
  $11 = $$pre1$i$i$i;$9 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$data>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($data) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $15 = $$pre;$17 = $$pre3;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($data) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $$pre2$i$i$i = HEAP32[$3>>2]|0;
  $21 = $$pre$i$i$i1;$23 = $$pre2$i$i$i;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($data) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI13AnimationClipELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $1 = sp;
 $offset = sp + 4|0;
 $size = sp + 8|0;
 $size1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($6) {
  if ($11) {
   __ZN12CachedReader15UpdateReadCacheEPvj($3,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $34 = $$pre;
  } else {
   $31 = HEAP32[$7>>2]|0;
   HEAP32[$size1>>2] = $31;
   HEAP32[$3>>2] = $8;
   $34 = $31;
  }
  $32 = (($this) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  HEAP32[$2>>2] = $33;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  __ZN15SerializeTraitsI13dynamic_arrayI4PPtrI13AnimationClipELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$34,$$byval_copy1);
  $35 = HEAP32[$data>>2]|0;
  $36 = (($data) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<2)|0);
  $39 = ($37|0)==(0);
  if ($39) {
   STACKTOP = sp;return;
  } else {
   $i$02 = $35;
  }
  while(1) {
   __ZN4PPtrI13AnimationClipE8TransferI18StreamedBinaryReadILb0EEEEvRT_($i$02,$this);
   $40 = (($i$02) + 4|0);
   $41 = ($40|0)==($38|0);
   if ($41) {
    break;
   } else {
    $i$02 = $40;
   }
  }
  STACKTOP = sp;return;
 }
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$size,4);
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre4 = HEAP32[$9>>2]|0;
  $14 = $$pre3;$16 = $$pre4;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$size>>2] = $12;
  HEAP32[$3>>2] = $8;
  $14 = $8;$16 = $10;
 }
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($3,$offset,4);
  $$pre5 = HEAP32[$offset>>2]|0;
  $20 = $$pre5;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$3>>2] = $13;
  $20 = $17;
 }
 $18 = HEAP32[$size>>2]|0;
 $19 = $18 << 2;
 $21 = (__ZN12CachedReader22FetchResourceImageDataEjj($3,$20,$19)|0);
 $22 = (($data) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)>(-1);
 if ($24) {
  $25 = HEAP32[$data>>2]|0;
  $26 = (($data) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$1>>2] = $27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy1);
  HEAP32[$data>>2] = 0;
 }
 $28 = $19 >> 2;
 $29 = (($data) + 8|0);
 HEAP32[$29>>2] = $28;
 $30 = $28 | -2147483648;
 HEAP32[$22>>2] = $30;
 HEAP32[$data>>2] = $21;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18ControllerConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i$i = 0, $$pre$i$i2 = 0, $$pre$phi$i$i4Z2D = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $ArrayTransfer$i5$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i5$i$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $0;
 $3 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation13LayerConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $5;
 $8 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine20StateMachineConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  $13 = HEAP32[$1>>2]|0;
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_iiii[$15 & 2047]($13,12,4)|0);
  $17 = ($16|0)==(0|0);
  if ($17) {
   $23 = 0;$25 = 0;
  } else {
   HEAP32[$16>>2] = 0;
   $18 = (($16) + 4|0);
   HEAP32[$18>>2] = 0;
   $19 = (($16) + 8|0);
   HEAP32[$19>>2] = 0;
   $20 = $16;
   $21 = $10;
   $22 = (($20) - ($21))|0;
   $23 = $22;$25 = $16;
  }
  HEAP32[$10>>2] = $23;
  $24 = (($this) + 28|0);
  HEAP32[$24>>2] = $25;
  $$pre$phi$i$iZ2D = $24;$28 = $23;
 } else {
  $$pre$i$i = (($this) + 28|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$28 = $11;
 }
 $26 = $10;
 $27 = (($28) + ($26))|0;
 $29 = $27;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $29;
 $30 = (($29) + 4|0);
 $31 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $30;
 $32 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$32>>2] = $29;
 $33 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$33>>2] = $31;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim13ValueConstantEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $34 = (($this) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(0);
 if ($36) {
  $37 = HEAP32[$1>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$38>>2]|0;
  $40 = (FUNCTION_TABLE_iiii[$39 & 2047]($37,72,4)|0);
  $41 = ($40|0)==(0|0);
  if ($41) {
   $45 = 0;$47 = 0;
  } else {
   dest=$40+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $42 = $40;
   $43 = $34;
   $44 = (($42) - ($43))|0;
   $45 = $44;$47 = $40;
  }
  HEAP32[$34>>2] = $45;
  $46 = (($this) + 36|0);
  HEAP32[$46>>2] = $47;
  $$pre$phi$i$i4Z2D = $46;$50 = $45;
 } else {
  $$pre$i$i2 = (($this) + 36|0);
  $$pre$phi$i$i4Z2D = $$pre$i$i2;$50 = $35;
 }
 $48 = $34;
 $49 = (($50) + ($48))|0;
 $51 = $49;
 HEAP32[$$pre$phi$i$i4Z2D>>2] = $51;
 $52 = (($51) + 4|0);
 $53 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $52;
 $54 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$54>>2] = $51;
 $55 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$55>>2] = $53;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIbEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $56 = (($51) + 16|0);
 $57 = (($51) + 12|0);
 $58 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $56;
 $59 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$59>>2] = $57;
 $60 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$60>>2] = $58;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $61 = (($51) + 28|0);
 $62 = (($51) + 24|0);
 $63 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $61;
 $64 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$64>>2] = $62;
 $65 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$65>>2] = $63;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $66 = (($51) + 40|0);
 $67 = (($51) + 36|0);
 $68 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $66;
 $69 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$69>>2] = $67;
 $70 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$70>>2] = $68;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $71 = (($51) + 52|0);
 $72 = (($51) + 48|0);
 $73 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $71;
 $74 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$74>>2] = $72;
 $75 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$75>>2] = $73;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 $76 = (($51) + 64|0);
 $77 = (($51) + 60|0);
 $78 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i5$i$i>>2] = $76;
 $79 = (($ArrayTransfer$i5$i$i) + 4|0);
 HEAP32[$79>>2] = $77;
 $80 = (($ArrayTransfer$i5$i$i) + 8|0);
 HEAP32[$80>>2] = $78;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i5$i$i,0);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $37 = (($24) + 4|0);
  HEAP32[$37>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 4;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$35 = 0;
  } else {
   $32 = $30;
   $33 = $24;
   $34 = (($32) - ($33))|0;
   $$0$i1$i$i = $30;$35 = $34;
  }
  HEAP32[$24>>2] = $35;
  $36 = (($24) + 4|0);
  HEAP32[$36>>2] = $$0$i1$i$i;
 }
 $38 = HEAP32[$data>>2]|0;
 $39 = $38;
 $40 = HEAP32[$38>>2]|0;
 $41 = (($40) + ($39))|0;
 $42 = $41;
 $43 = (($38) + 4|0);
 HEAP32[$43>>2] = $42;
 $44 = HEAP32[$20>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($42) + ($45<<4)|0);
 $47 = HEAP32[$data>>2]|0;
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = (($47) + 4|0);
 HEAP32[$52>>2] = $51;
 $53 = ($51|0)==($46|0);
 if ($53) {
  STACKTOP = sp;return;
 } else {
  $i$04 = $51;
 }
 while(1) {
  __ZN15SerializeTraitsIKN4math7_float4EE8TransferI18StreamedBinaryReadILb0EEEEvRS2_RT_($i$04,$this);
  $54 = (($i$04) + 16|0);
  $55 = ($54|0)==($46|0);
  if ($55) {
   break;
  } else {
   $i$04 = $54;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIbEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre4 = HEAP32[$1>>2]|0;
   $$pre5 = HEAP32[$7>>2]|0;
   $12 = $$pre4;$14 = $$pre5;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre6 = HEAP32[$offset>>2]|0;
   $17 = $$pre6;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $17 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$17,$16)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $21 = $$pre;
 } else {
  $18 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $18;
  HEAP32[$1>>2] = $6;
  $21 = $18;
 }
 $19 = (($data) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$20>>2] = $21;
 $22 = ($21|0)==(0);
 $23 = HEAP32[$data>>2]|0;
 if ($22) {
  HEAP32[$23>>2] = 0;
  $35 = (($23) + 4|0);
  HEAP32[$35>>2] = 0;
 } else {
  $24 = (($data) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = (FUNCTION_TABLE_iiii[$27 & 2047]($25,$21,1)|0);
  $29 = ($28|0)==(0|0);
  if ($29) {
   $33 = 0;
  } else {
   $30 = $28;
   $31 = $23;
   $32 = (($30) - ($31))|0;
   $33 = $32;
  }
  HEAP32[$23>>2] = $33;
  $34 = (($23) + 4|0);
  HEAP32[$34>>2] = $28;
 }
 $36 = HEAP32[$size1>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $38 = HEAP32[$data>>2]|0;
 $39 = $38;
 $40 = HEAP32[$38>>2]|0;
 $41 = (($40) + ($39))|0;
 $42 = $41;
 $43 = (($38) + 4|0);
 HEAP32[$43>>2] = $42;
 __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$42,$36);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine20StateMachineConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $59 = (($this) + 4|0);
 $i$04 = $56;
 while(1) {
  $60 = HEAP32[$i$04>>2]|0;
  $61 = ($60|0)==(0);
  if ($61) {
   $62 = HEAP32[$59>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (FUNCTION_TABLE_iiii[$64 & 2047]($62,44,4)|0);
   $66 = ($65|0)==(0|0);
   if ($66) {
    $71 = 0;$73 = 0;
   } else {
    $67 = (($65) + 28|0);
    ;HEAP32[$65+0>>2]=0|0;HEAP32[$65+4>>2]=0|0;HEAP32[$65+8>>2]=0|0;HEAP32[$65+12>>2]=0|0;HEAP32[$65+16>>2]=0|0;HEAP32[$65+20>>2]=0|0;
    ;HEAP32[$67+0>>2]=0|0;HEAP32[$67+4>>2]=0|0;HEAP32[$67+8>>2]=0|0;HEAP32[$67+12>>2]=0|0;
    $68 = $65;
    $69 = $i$04;
    $70 = (($68) - ($69))|0;
    $71 = $70;$73 = $65;
   }
   HEAP32[$i$04>>2] = $71;
   $72 = (($i$04) + 4|0);
   HEAP32[$72>>2] = $73;
   $$pre$phi$i$iZ2D = $72;$76 = $71;
  } else {
   $$pre$i$i = (($i$04) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$76 = $60;
  }
  $74 = $i$04;
  $75 = (($76) + ($74))|0;
  $77 = $75;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $77;
  __ZN7mecanim12statemachine20StateMachineConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($77,$this);
  $78 = (($i$04) + 8|0);
  $79 = ($78|0)==($51|0);
  if ($79) {
   break;
  } else {
   $i$04 = $78;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine20StateMachineConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i2 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i2>>2] = $0;
 $3 = (($ArrayTransfer$i2) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i2) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine13StateConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i2,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i2>>2] = $5;
 $8 = (($ArrayTransfer$i2) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($ArrayTransfer$i2) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i2,0);
 $10 = (($this) + 28|0);
 $11 = (($this) + 24|0);
 $12 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i2>>2] = $10;
 $13 = (($ArrayTransfer$i2) + 4|0);
 HEAP32[$13>>2] = $11;
 $14 = (($ArrayTransfer$i2) + 8|0);
 HEAP32[$14>>2] = $12;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i2,0);
 $15 = (($this) + 36|0);
 $16 = (($transfer) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 4|0);
 $19 = (($transfer) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18>>>0)>($20>>>0);
 if ($21) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$15,4);
  $$pre = HEAP32[$16>>2]|0;
  $$pre4 = HEAP32[$19>>2]|0;
  $25 = $$pre;$27 = $$pre4;
 } else {
  $22 = HEAP32[$17>>2]|0;
  HEAP32[$15>>2] = $22;
  HEAP32[$16>>2] = $18;
  $25 = $18;$27 = $20;
 }
 $23 = (($this) + 40|0);
 $24 = (($25) + 4|0);
 $26 = ($24>>>0)>($27>>>0);
 if ($26) {
  __ZN12CachedReader15UpdateReadCacheEPvj($16,$23,4);
  STACKTOP = sp;return;
 } else {
  $28 = HEAP32[$25>>2]|0;
  HEAP32[$23>>2] = $28;
  HEAP32[$16>>2] = $24;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 } else {
  $i$04 = $56;
 }
 while(1) {
  __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEE8TransferI18StreamedBinaryReadILb0EEEEvRS4_RT_($i$04,$this);
  $59 = (($i$04) + 8|0);
  $60 = ($59|0)==($51|0);
  if ($60) {
   break;
  } else {
   $i$04 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEE8TransferI18StreamedBinaryReadILb0EEEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre1$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i = sp;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,20,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = 0;$15 = 0;
  } else {
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 8|0);
   HEAP32[$9>>2] = 0;
   $10 = $6;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $6;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phi2Z2D = $2;$$pre$phiZ2D = $14;$18 = $13;
 } else {
  $$pre = (($data) + 4|0);
  $$pre1 = (($transfer) + 4|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;$18 = $0;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phiZ2D>>2] = $19;
 $20 = (($19) + 4|0);
 $21 = HEAP32[$$pre$phi2Z2D>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i>>2] = $20;
 $22 = (($ArrayTransfer$i$i$i$i) + 4|0);
 HEAP32[$22>>2] = $19;
 $23 = (($ArrayTransfer$i$i$i$i) + 8|0);
 HEAP32[$23>>2] = $21;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i,0);
 $24 = (($19) + 12|0);
 $25 = (($transfer) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 4|0);
 $28 = (($transfer) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27>>>0)>($29>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($25,$24,4);
  $$pre$i$i$i = HEAP32[$25>>2]|0;
  $$pre1$i$i$i = HEAP32[$28>>2]|0;
  $34 = $$pre$i$i$i;$36 = $$pre1$i$i$i;
 } else {
  $31 = HEAP32[$26>>2]|0;
  HEAP32[$24>>2] = $31;
  HEAP32[$25>>2] = $27;
  $34 = $27;$36 = $29;
 }
 $32 = (($19) + 16|0);
 $33 = (($34) + 1|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($25,$32,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $37 = HEAP8[$34>>0]|0;
  HEAP8[$32>>0] = $37;
  $38 = HEAP32[$25>>2]|0;
  $39 = (($38) + 1|0);
  HEAP32[$25>>2] = $39;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, $i$04 = 0;
 var $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i$i$i$i = sp + 12|0;
 $offset = sp;
 $size = sp + 4|0;
 $size1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $59 = (($this) + 4|0);
 $60 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 $61 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 $i$04 = $56;
 while(1) {
  $62 = HEAP32[$i$04>>2]|0;
  $63 = ($62|0)==(0);
  if ($63) {
   $64 = HEAP32[$59>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[$65>>2]|0;
   $67 = (FUNCTION_TABLE_iiii[$66 & 2047]($64,16,4)|0);
   $68 = ($67|0)==(0|0);
   if ($68) {
    $74 = 0;$76 = 0;
   } else {
    HEAP32[$67>>2] = 0;
    $69 = (($67) + 8|0);
    HEAP32[$69>>2] = 0;
    $70 = (($67) + 12|0);
    HEAP32[$70>>2] = 0;
    $71 = $67;
    $72 = $i$04;
    $73 = (($71) - ($72))|0;
    $74 = $73;$76 = $67;
   }
   HEAP32[$i$04>>2] = $74;
   $75 = (($i$04) + 4|0);
   HEAP32[$75>>2] = $76;
   $$pre$phi$i$iZ2D = $75;$79 = $74;
  } else {
   $$pre$i$i = (($i$04) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$79 = $62;
  }
  $77 = $i$04;
  $78 = (($79) + ($77))|0;
  $80 = $78;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $80;
  $81 = HEAP32[$1>>2]|0;
  $82 = (($81) + 4|0);
  $83 = HEAP32[$7>>2]|0;
  $84 = ($82>>>0)>($83>>>0);
  if ($84) {
   $86 = $78;
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$86,4);
  } else {
   $85 = HEAP32[$81>>2]|0;
   HEAP32[$80>>2] = $85;
   HEAP32[$1>>2] = $82;
  }
  $87 = (($80) + 8|0);
  $88 = (($80) + 4|0);
  $89 = HEAP32[$59>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $87;
  HEAP32[$60>>2] = $88;
  HEAP32[$61>>2] = $89;
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i$i$i,0);
  $90 = (($i$04) + 8|0);
  $91 = ($90|0)==($51|0);
  if ($91) {
   break;
  } else {
   $i$04 = $90;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $59 = (($this) + 4|0);
 $i$04 = $56;
 while(1) {
  $60 = HEAP32[$i$04>>2]|0;
  $61 = ($60|0)==(0);
  if ($61) {
   $62 = HEAP32[$59>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (FUNCTION_TABLE_iiii[$64 & 2047]($62,16,4)|0);
   $66 = ($65|0)==(0|0);
   if ($66) {
    $73 = 0;$75 = 0;
   } else {
    HEAP32[$65>>2] = 1;
    $67 = (($65) + 4|0);
    HEAP32[$67>>2] = 0;
    $68 = (($65) + 8|0);
    HEAPF32[$68>>2] = Math_fround(0.0);
    $69 = (($65) + 12|0);
    HEAPF32[$69>>2] = Math_fround(0.0);
    $70 = $65;
    $71 = $i$04;
    $72 = (($70) - ($71))|0;
    $73 = $72;$75 = $65;
   }
   HEAP32[$i$04>>2] = $73;
   $74 = (($i$04) + 4|0);
   HEAP32[$74>>2] = $75;
   $$pre$phi$i$iZ2D = $74;$78 = $73;
  } else {
   $$pre$i$i = (($i$04) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$78 = $60;
  }
  $76 = $i$04;
  $77 = (($78) + ($76))|0;
  $79 = $77;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $79;
  __ZN7mecanim12statemachine17ConditionConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($79,$this);
  $80 = (($i$04) + 8|0);
  $81 = ($80|0)==($51|0);
  if ($81) {
   break;
  } else {
   $i$04 = $80;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine17ConditionConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre3 = HEAP32[$3>>2]|0;
  $11 = $$pre3;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre4 = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $15 = $$pre4;$17 = $$pre5;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $21 = $$pre6;$23 = $$pre7;
 } else {
  $18 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
  STACKTOP = sp;return;
 } else {
  $24 = Math_fround(HEAPF32[$21>>2]);
  HEAPF32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $59 = (($this) + 4|0);
 $i$04 = $56;
 while(1) {
  $60 = HEAP32[$i$04>>2]|0;
  $61 = ($60|0)==(0);
  if ($61) {
   $62 = HEAP32[$59>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (FUNCTION_TABLE_iiii[$64 & 2047]($62,52,4)|0);
   $66 = ($65|0)==(0|0);
   if ($66) {
    $75 = 0;$77 = 0;
   } else {
    $67 = (($65) + 36|0);
    dest=$65+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAPF32[$67>>2] = Math_fround(0.899999976158142089843);
    $68 = (($65) + 40|0);
    HEAP8[$68>>0] = 0;
    $69 = (($65) + 44|0);
    HEAP32[$69>>2] = 0;
    $70 = (($65) + 48|0);
    HEAP8[$70>>0] = 1;
    $71 = (($65) + 49|0);
    HEAP8[$71>>0] = 0;
    $72 = $65;
    $73 = $i$04;
    $74 = (($72) - ($73))|0;
    $75 = $74;$77 = $65;
   }
   HEAP32[$i$04>>2] = $75;
   $76 = (($i$04) + 4|0);
   HEAP32[$76>>2] = $77;
   $$pre$phi$i$iZ2D = $76;$80 = $75;
  } else {
   $$pre$i$i = (($i$04) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$80 = $60;
  }
  $78 = $i$04;
  $79 = (($80) + ($78))|0;
  $81 = $79;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $81;
  __ZN7mecanim12statemachine18TransitionConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($81,$this);
  $82 = (($i$04) + 8|0);
  $83 = ($82|0)==($51|0);
  if ($83) {
   break;
  } else {
   $i$04 = $82;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine18TransitionConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $0;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 $5 = (($this) + 12|0);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$5,4);
  $$pre = HEAP32[$6>>2]|0;
  $$pre8 = HEAP32[$9>>2]|0;
  $15 = $$pre;$17 = $$pre8;
 } else {
  $12 = HEAP32[$7>>2]|0;
  HEAP32[$5>>2] = $12;
  HEAP32[$6>>2] = $8;
  $15 = $8;$17 = $10;
 }
 $13 = (($this) + 16|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$13,4);
  $$pre9 = HEAP32[$6>>2]|0;
  $$pre10 = HEAP32[$9>>2]|0;
  $21 = $$pre9;$23 = $$pre10;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$6>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 20|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$19,4);
  $$pre11 = HEAP32[$6>>2]|0;
  $$pre12 = HEAP32[$9>>2]|0;
  $27 = $$pre11;$29 = $$pre12;
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$6>>2] = $20;
  $27 = $20;$29 = $23;
 }
 $25 = (($this) + 24|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$25,4);
  $$pre13 = HEAP32[$6>>2]|0;
  $$pre14 = HEAP32[$9>>2]|0;
  $33 = $$pre13;$35 = $$pre14;
 } else {
  $30 = HEAP32[$27>>2]|0;
  HEAP32[$25>>2] = $30;
  HEAP32[$6>>2] = $26;
  $33 = $26;$35 = $29;
 }
 $31 = (($this) + 28|0);
 $32 = (($33) + 4|0);
 $34 = ($32>>>0)>($35>>>0);
 if ($34) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$31,4);
  $$pre15 = HEAP32[$6>>2]|0;
  $$pre16 = HEAP32[$9>>2]|0;
  $39 = $$pre15;$41 = $$pre16;
 } else {
  $36 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$31>>2] = $36;
  HEAP32[$6>>2] = $32;
  $39 = $32;$41 = $35;
 }
 $37 = (($this) + 32|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$37,4);
  $$pre17 = HEAP32[$6>>2]|0;
  $$pre18 = HEAP32[$9>>2]|0;
  $45 = $$pre17;$47 = $$pre18;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$6>>2] = $38;
  $45 = $38;$47 = $41;
 }
 $43 = (($this) + 36|0);
 $44 = (($45) + 4|0);
 $46 = ($44>>>0)>($47>>>0);
 if ($46) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$43,4);
  $$pre19 = HEAP32[$6>>2]|0;
  $$pre20 = HEAP32[$9>>2]|0;
  $51 = $$pre19;$53 = $$pre20;
 } else {
  $48 = Math_fround(HEAPF32[$45>>2]);
  HEAPF32[$43>>2] = $48;
  HEAP32[$6>>2] = $44;
  $51 = $44;$53 = $47;
 }
 $49 = (($this) + 40|0);
 $50 = (($51) + 1|0);
 $52 = ($50>>>0)>($53>>>0);
 if ($52) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$49,1);
 } else {
  $54 = HEAP8[$51>>0]|0;
  HEAP8[$49>>0] = $54;
  $55 = HEAP32[$6>>2]|0;
  $56 = (($55) + 1|0);
  HEAP32[$6>>2] = $56;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $57 = (($this) + 44|0);
 $58 = HEAP32[$6>>2]|0;
 $59 = (($58) + 4|0);
 $60 = HEAP32[$9>>2]|0;
 $61 = ($59>>>0)>($60>>>0);
 if ($61) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$57,4);
  $$pre21 = HEAP32[$6>>2]|0;
  $$pre22 = HEAP32[$9>>2]|0;
  $65 = $$pre21;$67 = $$pre22;
 } else {
  $62 = HEAP32[$58>>2]|0;
  HEAP32[$57>>2] = $62;
  HEAP32[$6>>2] = $59;
  $65 = $59;$67 = $60;
 }
 $63 = (($this) + 48|0);
 $64 = (($65) + 1|0);
 $66 = ($64>>>0)>($67>>>0);
 if ($66) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$63,1);
  $$pre23 = HEAP32[$6>>2]|0;
  $73 = $$pre23;
 } else {
  $68 = HEAP8[$65>>0]|0;
  HEAP8[$63>>0] = $68;
  $69 = HEAP32[$6>>2]|0;
  $70 = (($69) + 1|0);
  HEAP32[$6>>2] = $70;
  $73 = $70;
 }
 $71 = (($this) + 49|0);
 $72 = (($73) + 1|0);
 $74 = HEAP32[$9>>2]|0;
 $75 = ($72>>>0)>($74>>>0);
 if ($75) {
  __ZN12CachedReader15UpdateReadCacheEPvj($6,$71,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $76 = HEAP8[$73>>0]|0;
  HEAP8[$71>>0] = $76;
  $77 = HEAP32[$6>>2]|0;
  $78 = (($77) + 1|0);
  HEAP32[$6>>2] = $78;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine13StateConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $59 = (($this) + 4|0);
 $i$04 = $56;
 while(1) {
  $60 = HEAP32[$i$04>>2]|0;
  $61 = ($60|0)==(0);
  if ($61) {
   $62 = HEAP32[$59>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (FUNCTION_TABLE_iiii[$64 & 2047]($62,72,4)|0);
   $66 = ($65|0)==(0|0);
   if ($66) {
    $76 = 0;$78 = 0;
   } else {
    $67 = (($65) + 60|0);
    dest=$65+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAPF32[$67>>2] = Math_fround(1.0);
    $68 = (($65) + 64|0);
    HEAPF32[$68>>2] = Math_fround(0.0);
    $69 = (($65) + 68|0);
    HEAP8[$69>>0] = 1;
    $70 = (($65) + 69|0);
    HEAP8[$70>>0] = 1;
    $71 = (($65) + 70|0);
    HEAP8[$71>>0] = 0;
    $72 = (($65) + 71|0);
    HEAP8[$72>>0] = 0;
    $73 = $65;
    $74 = $i$04;
    $75 = (($73) - ($74))|0;
    $76 = $75;$78 = $65;
   }
   HEAP32[$i$04>>2] = $76;
   $77 = (($i$04) + 4|0);
   HEAP32[$77>>2] = $78;
   $$pre$phi$i$iZ2D = $77;$81 = $76;
  } else {
   $$pre$i$i = (($i$04) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$81 = $60;
  }
  $79 = $i$04;
  $80 = (($81) + ($79))|0;
  $82 = $80;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $82;
  __ZN7mecanim12statemachine13StateConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($82,$this);
  $83 = (($i$04) + 8|0);
  $84 = ($83|0)==($51|0);
  if ($84) {
   break;
  } else {
   $i$04 = $83;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine13StateConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $9 = 0, $ArrayTransfer$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i3 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $0;
 $3 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$4>>2] = $2;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i3,0);
 $5 = (($this) + 16|0);
 $6 = (($this) + 12|0);
 $7 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $5;
 $8 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$9>>2] = $7;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i3,0);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $10;
 $12 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$12>>2] = $6;
 $13 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$13>>2] = $11;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim12statemachine16LeafInfoConstantEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i3,0);
 $14 = (($this) + 36|0);
 $15 = (($this) + 32|0);
 $16 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i3>>2] = $14;
 $17 = (($ArrayTransfer$i3) + 4|0);
 HEAP32[$17>>2] = $15;
 $18 = (($ArrayTransfer$i3) + 8|0);
 HEAP32[$18>>2] = $16;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i3,0);
 $19 = (($this) + 44|0);
 $20 = (($transfer) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 4|0);
 $23 = (($transfer) + 20|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($22>>>0)>($24>>>0);
 if ($25) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$19,4);
  $$pre = HEAP32[$20>>2]|0;
  $$pre11 = HEAP32[$23>>2]|0;
  $29 = $$pre;$31 = $$pre11;
 } else {
  $26 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $26;
  HEAP32[$20>>2] = $22;
  $29 = $22;$31 = $24;
 }
 $27 = (($this) + 48|0);
 $28 = (($29) + 4|0);
 $30 = ($28>>>0)>($31>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$27,4);
  $$pre12 = HEAP32[$20>>2]|0;
  $$pre13 = HEAP32[$23>>2]|0;
  $35 = $$pre12;$37 = $$pre13;
 } else {
  $32 = HEAP32[$29>>2]|0;
  HEAP32[$27>>2] = $32;
  HEAP32[$20>>2] = $28;
  $35 = $28;$37 = $31;
 }
 $33 = (($this) + 52|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$33,4);
  $$pre14 = HEAP32[$20>>2]|0;
  $$pre15 = HEAP32[$23>>2]|0;
  $41 = $$pre14;$43 = $$pre15;
 } else {
  $38 = HEAP32[$35>>2]|0;
  HEAP32[$33>>2] = $38;
  HEAP32[$20>>2] = $34;
  $41 = $34;$43 = $37;
 }
 $39 = (($this) + 56|0);
 $40 = (($41) + 4|0);
 $42 = ($40>>>0)>($43>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$39,4);
  $$pre16 = HEAP32[$20>>2]|0;
  $$pre17 = HEAP32[$23>>2]|0;
  $47 = $$pre16;$49 = $$pre17;
 } else {
  $44 = HEAP32[$41>>2]|0;
  HEAP32[$39>>2] = $44;
  HEAP32[$20>>2] = $40;
  $47 = $40;$49 = $43;
 }
 $45 = (($this) + 60|0);
 $46 = (($47) + 4|0);
 $48 = ($46>>>0)>($49>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$45,4);
  $$pre18 = HEAP32[$20>>2]|0;
  $$pre19 = HEAP32[$23>>2]|0;
  $53 = $$pre18;$55 = $$pre19;
 } else {
  $50 = Math_fround(HEAPF32[$47>>2]);
  HEAPF32[$45>>2] = $50;
  HEAP32[$20>>2] = $46;
  $53 = $46;$55 = $49;
 }
 $51 = (($this) + 64|0);
 $52 = (($53) + 4|0);
 $54 = ($52>>>0)>($55>>>0);
 if ($54) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$51,4);
  $$pre20 = HEAP32[$20>>2]|0;
  $$pre21 = HEAP32[$23>>2]|0;
  $59 = $$pre20;$61 = $$pre21;
 } else {
  $56 = Math_fround(HEAPF32[$53>>2]);
  HEAPF32[$51>>2] = $56;
  HEAP32[$20>>2] = $52;
  $59 = $52;$61 = $55;
 }
 $57 = (($this) + 68|0);
 $58 = (($59) + 1|0);
 $60 = ($58>>>0)>($61>>>0);
 if ($60) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$57,1);
  $$pre22 = HEAP32[$20>>2]|0;
  $67 = $$pre22;
 } else {
  $62 = HEAP8[$59>>0]|0;
  HEAP8[$57>>0] = $62;
  $63 = HEAP32[$20>>2]|0;
  $64 = (($63) + 1|0);
  HEAP32[$20>>2] = $64;
  $67 = $64;
 }
 $65 = (($this) + 69|0);
 $66 = (($67) + 1|0);
 $68 = HEAP32[$23>>2]|0;
 $69 = ($66>>>0)>($68>>>0);
 if ($69) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$65,1);
  $$pre23 = HEAP32[$20>>2]|0;
  $75 = $$pre23;
 } else {
  $70 = HEAP8[$67>>0]|0;
  HEAP8[$65>>0] = $70;
  $71 = HEAP32[$20>>2]|0;
  $72 = (($71) + 1|0);
  HEAP32[$20>>2] = $72;
  $75 = $72;
 }
 $73 = (($this) + 70|0);
 $74 = (($75) + 1|0);
 $76 = HEAP32[$23>>2]|0;
 $77 = ($74>>>0)>($76>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$73,1);
  $$pre24 = HEAP32[$20>>2]|0;
  $83 = $$pre24;
 } else {
  $78 = HEAP8[$75>>0]|0;
  HEAP8[$73>>0] = $78;
  $79 = HEAP32[$20>>2]|0;
  $80 = (($79) + 1|0);
  HEAP32[$20>>2] = $80;
  $83 = $80;
 }
 $81 = (($this) + 71|0);
 $82 = (($83) + 1|0);
 $84 = HEAP32[$23>>2]|0;
 $85 = ($82>>>0)>($84>>>0);
 if ($85) {
  __ZN12CachedReader15UpdateReadCacheEPvj($20,$81,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $86 = HEAP8[$83>>0]|0;
  HEAP8[$81>>0] = $86;
  $87 = HEAP32[$20>>2]|0;
  $88 = (($87) + 1|0);
  HEAP32[$20>>2] = $88;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i$i$i$i = sp + 12|0;
 $offset = sp;
 $size = sp + 4|0;
 $size1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $59 = (($this) + 4|0);
 $60 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 $61 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 $i$04 = $56;
 while(1) {
  $62 = HEAP32[$i$04>>2]|0;
  $63 = ($62|0)==(0);
  if ($63) {
   $64 = HEAP32[$59>>2]|0;
   $65 = HEAP32[$64>>2]|0;
   $66 = HEAP32[$65>>2]|0;
   $67 = (FUNCTION_TABLE_iiii[$66 & 2047]($64,12,4)|0);
   $68 = ($67|0)==(0|0);
   if ($68) {
    $74 = 0;$76 = 0;
   } else {
    HEAP32[$67>>2] = 0;
    $69 = (($67) + 4|0);
    HEAP32[$69>>2] = 0;
    $70 = (($67) + 8|0);
    HEAP32[$70>>2] = 0;
    $71 = $67;
    $72 = $i$04;
    $73 = (($71) - ($72))|0;
    $74 = $73;$76 = $67;
   }
   HEAP32[$i$04>>2] = $74;
   $75 = (($i$04) + 4|0);
   HEAP32[$75>>2] = $76;
   $$pre$phi$i$iZ2D = $75;$79 = $74;
  } else {
   $$pre$i$i = (($i$04) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$79 = $62;
  }
  $77 = $i$04;
  $78 = (($79) + ($77))|0;
  $80 = $78;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $80;
  $81 = (($80) + 4|0);
  $82 = HEAP32[$59>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $81;
  HEAP32[$60>>2] = $80;
  HEAP32[$61>>2] = $82;
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i$i$i,0);
  $83 = (($i$04) + 8|0);
  $84 = ($83|0)==($51|0);
  if ($84) {
   break;
  } else {
   $i$04 = $83;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $59 = (($this) + 4|0);
 $i$04 = $56;
 while(1) {
  $60 = HEAP32[$i$04>>2]|0;
  $61 = ($60|0)==(0);
  if ($61) {
   $62 = HEAP32[$59>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (FUNCTION_TABLE_iiii[$64 & 2047]($62,64,4)|0);
   $66 = ($65|0)==(0|0);
   if ($66) {
    $77 = 0;$79 = 0;
   } else {
    HEAP32[$65>>2] = 0;
    $67 = (($65) + 4|0);
    HEAP32[$67>>2] = -1;
    $68 = (($65) + 8|0);
    HEAP32[$68>>2] = -1;
    $69 = (($65) + 12|0);
    $70 = (($65) + 48|0);
    dest=$69+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    HEAP32[$70>>2] = -1;
    $71 = (($65) + 52|0);
    HEAPF32[$71>>2] = Math_fround(0.0);
    $72 = (($65) + 56|0);
    HEAPF32[$72>>2] = Math_fround(0.0);
    $73 = (($65) + 60|0);
    HEAP8[$73>>0] = 0;
    $74 = $65;
    $75 = $i$04;
    $76 = (($74) - ($75))|0;
    $77 = $76;$79 = $65;
   }
   HEAP32[$i$04>>2] = $77;
   $78 = (($i$04) + 4|0);
   HEAP32[$78>>2] = $79;
   $$pre$phi$i$iZ2D = $78;$82 = $77;
  } else {
   $$pre$i$i = (($i$04) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$82 = $60;
  }
  $80 = $i$04;
  $81 = (($82) + ($80))|0;
  $83 = $81;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $83;
  __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($83,$this);
  $84 = (($i$04) + 8|0);
  $85 = ($84|0)==($51|0);
  if ($85) {
   break;
  } else {
   $i$04 = $84;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i3 = 0, $$pre$phi$i$i5Z2D = 0, $$pre$phi$i$iZ2D = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i4$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i4$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre8 = HEAP32[$3>>2]|0;
  $11 = $$pre8;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre9 = HEAP32[$0>>2]|0;
  $$pre10 = HEAP32[$3>>2]|0;
  $15 = $$pre9;$17 = $$pre10;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
 }
 $19 = (($this) + 16|0);
 $20 = (($this) + 12|0);
 $21 = (($transfer) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $19;
 $23 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$23>>2] = $20;
 $24 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$24>>2] = $22;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $25 = (($this) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0);
 if ($27) {
  $28 = HEAP32[$21>>2]|0;
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_iiii[$30 & 2047]($28,12,4)|0);
  $32 = ($31|0)==(0|0);
  if ($32) {
   $38 = 0;$40 = 0;
  } else {
   HEAP32[$31>>2] = 0;
   $33 = (($31) + 4|0);
   HEAP32[$33>>2] = 0;
   $34 = (($31) + 8|0);
   HEAP32[$34>>2] = 0;
   $35 = $31;
   $36 = $25;
   $37 = (($35) - ($36))|0;
   $38 = $37;$40 = $31;
  }
  HEAP32[$25>>2] = $38;
  $39 = (($this) + 28|0);
  HEAP32[$39>>2] = $40;
  $$pre$phi$i$iZ2D = $39;$43 = $38;
 } else {
  $$pre$i$i = (($this) + 28|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;$43 = $26;
 }
 $41 = $25;
 $42 = (($43) + ($41))|0;
 $44 = $42;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $44;
 $45 = (($44) + 4|0);
 $46 = HEAP32[$21>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $45;
 $47 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$47>>2] = $44;
 $48 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$48>>2] = $46;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $49 = (($this) + 32|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0);
 if ($51) {
  $52 = HEAP32[$21>>2]|0;
  $53 = HEAP32[$52>>2]|0;
  $54 = HEAP32[$53>>2]|0;
  $55 = (FUNCTION_TABLE_iiii[$54 & 2047]($52,60,4)|0);
  $56 = ($55|0)==(0|0);
  if ($56) {
   $60 = 0;$62 = 0;
  } else {
   dest=$55+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $57 = $55;
   $58 = $49;
   $59 = (($57) - ($58))|0;
   $60 = $59;$62 = $55;
  }
  HEAP32[$49>>2] = $60;
  $61 = (($this) + 36|0);
  HEAP32[$61>>2] = $62;
  $$pre$phi$i$i5Z2D = $61;$65 = $60;
 } else {
  $$pre$i$i3 = (($this) + 36|0);
  $$pre$phi$i$i5Z2D = $$pre$i$i3;$65 = $50;
 }
 $63 = $49;
 $64 = (($65) + ($63))|0;
 $66 = $64;
 HEAP32[$$pre$phi$i$i5Z2D>>2] = $66;
 $67 = (($66) + 4|0);
 $68 = HEAP32[$21>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $67;
 $69 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$69>>2] = $66;
 $70 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$70>>2] = $68;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $71 = (($66) + 16|0);
 $72 = (($66) + 12|0);
 $73 = HEAP32[$21>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $71;
 $74 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$74>>2] = $72;
 $75 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$75>>2] = $73;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $76 = (($66) + 28|0);
 $77 = (($66) + 24|0);
 $78 = HEAP32[$21>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $76;
 $79 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$79>>2] = $77;
 $80 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$80>>2] = $78;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $81 = (($66) + 40|0);
 $82 = (($66) + 36|0);
 $83 = HEAP32[$21>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $81;
 $84 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$84>>2] = $82;
 $85 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$85>>2] = $83;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $86 = (($66) + 52|0);
 $87 = (($66) + 48|0);
 $88 = HEAP32[$21>>2]|0;
 HEAP32[$ArrayTransfer$i4$i$i$i>>2] = $86;
 $89 = (($ArrayTransfer$i4$i$i$i) + 4|0);
 HEAP32[$89>>2] = $87;
 $90 = (($ArrayTransfer$i4$i$i$i) + 8|0);
 HEAP32[$90>>2] = $88;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4$i$i$i,0);
 $91 = (($this) + 40|0);
 __ZN18StreamedBinaryReadILb0EE8TransferI9OffsetPtrIN7mecanim9animation23BlendDirectDataConstantEEEEvRT_PKc17TransferMetaFlags($transfer,$91,0,0);
 $92 = (($this) + 48|0);
 $93 = HEAP32[$0>>2]|0;
 $94 = (($93) + 4|0);
 $95 = HEAP32[$3>>2]|0;
 $96 = ($94>>>0)>($95>>>0);
 if ($96) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$92,4);
  $$pre11 = HEAP32[$0>>2]|0;
  $$pre12 = HEAP32[$3>>2]|0;
  $100 = $$pre11;$102 = $$pre12;
 } else {
  $97 = HEAP32[$93>>2]|0;
  HEAP32[$92>>2] = $97;
  HEAP32[$0>>2] = $94;
  $100 = $94;$102 = $95;
 }
 $98 = (($this) + 52|0);
 $99 = (($100) + 4|0);
 $101 = ($99>>>0)>($102>>>0);
 if ($101) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$98,4);
  $$pre13 = HEAP32[$0>>2]|0;
  $$pre14 = HEAP32[$3>>2]|0;
  $106 = $$pre13;$108 = $$pre14;
 } else {
  $103 = Math_fround(HEAPF32[$100>>2]);
  HEAPF32[$98>>2] = $103;
  HEAP32[$0>>2] = $99;
  $106 = $99;$108 = $102;
 }
 $104 = (($this) + 56|0);
 $105 = (($106) + 4|0);
 $107 = ($105>>>0)>($108>>>0);
 if ($107) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$104,4);
  $$pre15 = HEAP32[$0>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $112 = $$pre15;$114 = $$pre16;
 } else {
  $109 = Math_fround(HEAPF32[$106>>2]);
  HEAPF32[$104>>2] = $109;
  HEAP32[$0>>2] = $105;
  $112 = $105;$114 = $108;
 }
 $110 = (($this) + 60|0);
 $111 = (($112) + 1|0);
 $113 = ($111>>>0)>($114>>>0);
 if ($113) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$110,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $115 = HEAP8[$112>>0]|0;
  HEAP8[$110>>0] = $115;
  $116 = HEAP32[$0>>2]|0;
  $117 = (($116) + 1|0);
  HEAP32[$0>>2] = $117;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE8TransferI9OffsetPtrIN7mecanim9animation23BlendDirectDataConstantEEEEvRT_PKc17TransferMetaFlags($this,$data,$0,$1) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $$pre$phi2$iZ2D = 0, $$pre1$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i = sp;
 $2 = HEAP32[$data>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($this) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_iiii[$7 & 2047]($5,16,4)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $13 = 0;$15 = 0;
  } else {
   ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP8[$8+12>>0]=0|0;
   $10 = $8;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $8;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phi$iZ2D = $14;$$pre$phi2$iZ2D = $4;$18 = $13;
 } else {
  $$pre$i = (($data) + 4|0);
  $$pre1$i = (($this) + 4|0);
  $$pre$phi$iZ2D = $$pre$i;$$pre$phi2$iZ2D = $$pre1$i;$18 = $2;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phi$iZ2D>>2] = $19;
 $20 = (($19) + 4|0);
 $21 = HEAP32[$$pre$phi2$iZ2D>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i>>2] = $20;
 $22 = (($ArrayTransfer$i$i$i$i$i) + 4|0);
 HEAP32[$22>>2] = $19;
 $23 = (($ArrayTransfer$i$i$i$i$i) + 8|0);
 HEAP32[$23>>2] = $21;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i$i,0);
 $24 = (($19) + 12|0);
 $25 = (($this) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1|0);
 $28 = (($this) + 20|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($27>>>0)>($29>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($25,$24,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
  STACKTOP = sp;return;
 } else {
  $31 = HEAP8[$26>>0]|0;
  HEAP8[$24>>0] = $31;
  $32 = HEAP32[$25>>2]|0;
  $33 = (($32) + 1|0);
  HEAP32[$25>>2] = $33;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i$i = sp + 12|0;
 $offset = sp;
 $size = sp + 4|0;
 $size1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = ($16*12)|0;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $43 = (($24) + 4|0);
  HEAP32[$43>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = ($22*12)|0;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$41 = 0;
  } else {
   $32 = (($30) + (($22*12)|0)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    HEAP32[$35>>2] = 0;
    $36 = (($33) + 12|0);
    $37 = ($36|0)==($32|0);
    if ($37) {
     break;
    } else {
     $33 = $36;
    }
   }
   $38 = $30;
   $39 = $24;
   $40 = (($38) - ($39))|0;
   $$0$i1$i$i = $30;$41 = $40;
  }
  HEAP32[$24>>2] = $41;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = $$0$i1$i$i;
 }
 $44 = HEAP32[$data>>2]|0;
 $45 = $44;
 $46 = HEAP32[$44>>2]|0;
 $47 = (($46) + ($45))|0;
 $48 = $47;
 $49 = (($44) + 4|0);
 HEAP32[$49>>2] = $48;
 $50 = HEAP32[$20>>2]|0;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($48) + (($51*12)|0)|0);
 $53 = HEAP32[$data>>2]|0;
 $54 = $53;
 $55 = HEAP32[$53>>2]|0;
 $56 = (($55) + ($54))|0;
 $57 = $56;
 $58 = (($53) + 4|0);
 HEAP32[$58>>2] = $57;
 $59 = ($57|0)==($52|0);
 if ($59) {
  STACKTOP = sp;return;
 }
 $60 = (($this) + 4|0);
 $61 = (($ArrayTransfer$i$i$i$i) + 4|0);
 $62 = (($ArrayTransfer$i$i$i$i) + 8|0);
 $i$04 = $57;
 while(1) {
  $63 = (($i$04) + 4|0);
  $64 = HEAP32[$60>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i>>2] = $63;
  HEAP32[$61>>2] = $i$04;
  HEAP32[$62>>2] = $64;
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i,0);
  $65 = (($i$04) + 12|0);
  $66 = ($65|0)==($52|0);
  if ($66) {
   break;
  } else {
   $i$04 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre4 = HEAP32[$1>>2]|0;
   $$pre5 = HEAP32[$7>>2]|0;
   $12 = $$pre4;$14 = $$pre5;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre6 = HEAP32[$offset>>2]|0;
   $18 = $$pre6;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAPF32[$33>>2] = Math_fround(0.0);
    $34 = (($33) + 4|0);
    HEAPF32[$34>>2] = Math_fround(0.0);
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$size1>>2]|0;
 $44 = ($43|0)==(0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = HEAP32[$data>>2]|0;
 $46 = $45;
 $47 = HEAP32[$45>>2]|0;
 $48 = (($47) + ($46))|0;
 $49 = $48;
 $50 = (($45) + 4|0);
 HEAP32[$50>>2] = $49;
 $51 = $48;
 $52 = $43 << 3;
 __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$51,$52);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim12statemachine16LeafInfoConstantEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ArrayTransfer$i$i$i$i = sp + 12|0;
 $offset = sp;
 $size = sp + 4|0;
 $size1 = sp + 8|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 4;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 4;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$39 = 0;
  } else {
   $32 = (($30) + ($22<<4)|0);
   $33 = $30;
   while(1) {
    ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;
    $34 = (($33) + 16|0);
    $35 = ($34|0)==($32|0);
    if ($35) {
     break;
    } else {
     $33 = $34;
    }
   }
   $36 = $30;
   $37 = $24;
   $38 = (($36) - ($37))|0;
   $$0$i1$i$i = $30;$39 = $38;
  }
  HEAP32[$24>>2] = $39;
  $40 = (($24) + 4|0);
  HEAP32[$40>>2] = $$0$i1$i$i;
 }
 $42 = HEAP32[$data>>2]|0;
 $43 = $42;
 $44 = HEAP32[$42>>2]|0;
 $45 = (($44) + ($43))|0;
 $46 = $45;
 $47 = (($42) + 4|0);
 HEAP32[$47>>2] = $46;
 $48 = HEAP32[$20>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = (($46) + ($49<<4)|0);
 $51 = HEAP32[$data>>2]|0;
 $52 = $51;
 $53 = HEAP32[$51>>2]|0;
 $54 = (($53) + ($52))|0;
 $55 = $54;
 $56 = (($51) + 4|0);
 HEAP32[$56>>2] = $55;
 $57 = ($55|0)==($50|0);
 if ($57) {
  STACKTOP = sp;return;
 }
 $58 = (($this) + 4|0);
 $59 = (($ArrayTransfer$i$i$i$i) + 4|0);
 $60 = (($ArrayTransfer$i$i$i$i) + 8|0);
 $i$04 = $55;
 while(1) {
  $61 = (($i$04) + 4|0);
  $62 = HEAP32[$58>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i$i>>2] = $61;
  HEAP32[$59>>2] = $i$04;
  HEAP32[$60>>2] = $62;
  __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i$i,0);
  $63 = (($i$04) + 12|0);
  $64 = HEAP32[$1>>2]|0;
  $65 = (($64) + 4|0);
  $66 = HEAP32[$7>>2]|0;
  $67 = ($65>>>0)>($66>>>0);
  if ($67) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$63,4);
  } else {
   $68 = HEAP32[$64>>2]|0;
   HEAP32[$63>>2] = $68;
   HEAP32[$1>>2] = $65;
  }
  $69 = (($i$04) + 16|0);
  $70 = ($69|0)==($50|0);
  if ($70) {
   break;
  } else {
   $i$04 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation13LayerConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $i$04 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre6 = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $12 = $$pre6;$14 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre8 = HEAP32[$offset>>2]|0;
   $18 = $$pre8;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAP32[$34>>2] = 0;
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $59 = (($this) + 4|0);
 $i$04 = $56;
 while(1) {
  $60 = HEAP32[$i$04>>2]|0;
  $61 = ($60|0)==(0);
  if ($61) {
   $62 = HEAP32[$59>>2]|0;
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$63>>2]|0;
   $65 = (FUNCTION_TABLE_iiii[$64 & 2047]($62,40,4)|0);
   $66 = ($65|0)==(0|0);
   if ($66) {
    $74 = 0;$76 = 0;
   } else {
    $67 = (($65) + 8|0);
    $68 = (($65) + 28|0);
    HEAP32[$68>>2] = 0;
    $69 = (($65) + 36|0);
    ;HEAP32[$67+0>>2]=0|0;HEAP32[$67+4>>2]=0|0;HEAP32[$67+8>>2]=0|0;HEAP32[$67+12>>2]=0|0;
    HEAP8[$69>>0] = 1;
    $70 = (($65) + 37|0);
    HEAP8[$70>>0] = 0;
    $71 = $65;
    $72 = $i$04;
    $73 = (($71) - ($72))|0;
    $74 = $73;$76 = $65;
   }
   HEAP32[$i$04>>2] = $74;
   $75 = (($i$04) + 4|0);
   HEAP32[$75>>2] = $76;
   $$pre$phi$i$iZ2D = $75;$79 = $74;
  } else {
   $$pre$i$i = (($i$04) + 4|0);
   $$pre$phi$i$iZ2D = $$pre$i$i;$79 = $60;
  }
  $77 = $i$04;
  $78 = (($79) + ($77))|0;
  $80 = $78;
  HEAP32[$$pre$phi$i$iZ2D>>2] = $80;
  __ZN7mecanim9animation13LayerConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($80,$this);
  $81 = (($i$04) + 8|0);
  $82 = ($81|0)==($51|0);
  if ($82) {
   break;
  } else {
   $i$04 = $81;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation13LayerConstant8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i2 = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi2$i$iZ2D = 0, $$pre1$i$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre2$i$i = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ArrayTransfer$i$i$i$i$i$i = sp;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre5 = HEAP32[$3>>2]|0;
  $11 = $$pre5;$9 = $$pre;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $11 = $4;$9 = $2;
 }
 $7 = (($this) + 4|0);
 $8 = (($9) + 4|0);
 $10 = ($8>>>0)>($11>>>0);
 if ($10) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$7,4);
  $$pre6 = HEAP32[$0>>2]|0;
  $$pre7 = HEAP32[$3>>2]|0;
  $15 = $$pre6;$17 = $$pre7;
 } else {
  $12 = HEAP32[$9>>2]|0;
  HEAP32[$7>>2] = $12;
  HEAP32[$0>>2] = $8;
  $15 = $8;$17 = $11;
 }
 $13 = (($this) + 8|0);
 $14 = (($15) + 4|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,4);
  $$pre$i$i = HEAP32[$0>>2]|0;
  $$pre2$i$i = HEAP32[$3>>2]|0;
  $21 = $$pre$i$i;$23 = $$pre2$i$i;
 } else {
  $18 = HEAP32[$15>>2]|0;
  HEAP32[$13>>2] = $18;
  HEAP32[$0>>2] = $14;
  $21 = $14;$23 = $17;
 }
 $19 = (($this) + 12|0);
 $20 = (($21) + 4|0);
 $22 = ($20>>>0)>($23>>>0);
 if ($22) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$19,4);
 } else {
  $24 = HEAP32[$21>>2]|0;
  HEAP32[$19>>2] = $24;
  HEAP32[$0>>2] = $20;
 }
 $25 = (($this) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0);
 if ($27) {
  $28 = (($transfer) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = HEAP32[$30>>2]|0;
  $32 = (FUNCTION_TABLE_iiii[$31 & 2047]($29,12,4)|0);
  $33 = ($32|0)==(0|0);
  if ($33) {
   $39 = 0;$41 = 0;
  } else {
   HEAP32[$32>>2] = 0;
   $34 = (($32) + 4|0);
   HEAP32[$34>>2] = 0;
   $35 = (($32) + 8|0);
   HEAP32[$35>>2] = 0;
   $36 = $32;
   $37 = $25;
   $38 = (($36) - ($37))|0;
   $39 = $38;$41 = $32;
  }
  HEAP32[$25>>2] = $39;
  $40 = (($this) + 20|0);
  HEAP32[$40>>2] = $41;
  $$pre$phi$i$iZ2D = $40;$$pre$phi2$i$iZ2D = $28;$44 = $39;
 } else {
  $$pre$i$i2 = (($this) + 20|0);
  $$pre1$i$i = (($transfer) + 4|0);
  $$pre$phi$i$iZ2D = $$pre$i$i2;$$pre$phi2$i$iZ2D = $$pre1$i$i;$44 = $26;
 }
 $42 = $25;
 $43 = (($44) + ($42))|0;
 $45 = $43;
 HEAP32[$$pre$phi$i$iZ2D>>2] = $45;
 $46 = (($45) + 4|0);
 $47 = HEAP32[$$pre$phi2$i$iZ2D>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $46;
 $48 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$48>>2] = $45;
 $49 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$49>>2] = $47;
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim8skeleton19SkeletonMaskElementEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i$i$i$i,0);
 $50 = (($this) + 24|0);
 $51 = HEAP32[$0>>2]|0;
 $52 = (($51) + 4|0);
 $53 = HEAP32[$3>>2]|0;
 $54 = ($52>>>0)>($53>>>0);
 if ($54) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$50,4);
  $$pre8 = HEAP32[$0>>2]|0;
  $$pre9 = HEAP32[$3>>2]|0;
  $58 = $$pre8;$60 = $$pre9;
 } else {
  $55 = HEAP32[$51>>2]|0;
  HEAP32[$50>>2] = $55;
  HEAP32[$0>>2] = $52;
  $58 = $52;$60 = $53;
 }
 $56 = (($this) + 28|0);
 $57 = (($58) + 4|0);
 $59 = ($57>>>0)>($60>>>0);
 if ($59) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$56,4);
  $$pre10 = HEAP32[$0>>2]|0;
  $$pre11 = HEAP32[$3>>2]|0;
  $64 = $$pre10;$66 = $$pre11;
 } else {
  $61 = HEAP32[$58>>2]|0;
  HEAP32[$56>>2] = $61;
  HEAP32[$0>>2] = $57;
  $64 = $57;$66 = $60;
 }
 $62 = (($this) + 32|0);
 $63 = (($64) + 4|0);
 $65 = ($63>>>0)>($66>>>0);
 if ($65) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$62,4);
  $$pre12 = HEAP32[$0>>2]|0;
  $$pre13 = HEAP32[$3>>2]|0;
  $70 = $$pre12;$72 = $$pre13;
 } else {
  $67 = Math_fround(HEAPF32[$64>>2]);
  HEAPF32[$62>>2] = $67;
  HEAP32[$0>>2] = $63;
  $70 = $63;$72 = $66;
 }
 $68 = (($this) + 36|0);
 $69 = (($70) + 1|0);
 $71 = ($69>>>0)>($72>>>0);
 if ($71) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$68,1);
  $$pre14 = HEAP32[$0>>2]|0;
  $78 = $$pre14;
 } else {
  $73 = HEAP8[$70>>0]|0;
  HEAP8[$68>>0] = $73;
  $74 = HEAP32[$0>>2]|0;
  $75 = (($74) + 1|0);
  HEAP32[$0>>2] = $75;
  $78 = $75;
 }
 $76 = (($this) + 37|0);
 $77 = (($78) + 1|0);
 $79 = HEAP32[$3>>2]|0;
 $80 = ($77>>>0)>($79>>>0);
 if ($80) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$76,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $81 = HEAP8[$78>>0]|0;
  HEAP8[$76>>0] = $81;
  $82 = HEAP32[$0>>2]|0;
  $83 = (($82) + 1|0);
  HEAP32[$0>>2] = $83;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim8skeleton19SkeletonMaskElementEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre1$i$i$i = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $i$04 = 0, $offset = 0;
 var $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre5 = HEAP32[$1>>2]|0;
   $$pre6 = HEAP32[$7>>2]|0;
   $12 = $$pre5;$14 = $$pre6;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre7 = HEAP32[$offset>>2]|0;
   $18 = $$pre7;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $22 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $22 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$21>>2] = $22;
 $23 = ($22|0)==(0);
 $24 = HEAP32[$data>>2]|0;
 if ($23) {
  HEAP32[$24>>2] = 0;
  $42 = (($24) + 4|0);
  HEAP32[$42>>2] = 0;
 } else {
  $25 = (($data) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22 << 3;
  $30 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,$29,4)|0);
  $31 = ($30|0)==(0|0);
  if ($31) {
   $$0$i1$i$i = 0;$40 = 0;
  } else {
   $32 = (($30) + ($22<<3)|0);
   $33 = $30;
   while(1) {
    HEAP32[$33>>2] = 0;
    $34 = (($33) + 4|0);
    HEAPF32[$34>>2] = Math_fround(0.0);
    $35 = (($33) + 8|0);
    $36 = ($35|0)==($32|0);
    if ($36) {
     break;
    } else {
     $33 = $35;
    }
   }
   $37 = $30;
   $38 = $24;
   $39 = (($37) - ($38))|0;
   $$0$i1$i$i = $30;$40 = $39;
  }
  HEAP32[$24>>2] = $40;
  $41 = (($24) + 4|0);
  HEAP32[$41>>2] = $$0$i1$i$i;
 }
 $43 = HEAP32[$data>>2]|0;
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($43) + 4|0);
 HEAP32[$48>>2] = $47;
 $49 = HEAP32[$20>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($47) + ($50<<3)|0);
 $52 = HEAP32[$data>>2]|0;
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($52) + 4|0);
 HEAP32[$57>>2] = $56;
 $58 = ($56|0)==($51|0);
 if ($58) {
  STACKTOP = sp;return;
 } else {
  $i$04 = $56;
 }
 while(1) {
  $59 = HEAP32[$1>>2]|0;
  $60 = (($59) + 4|0);
  $61 = HEAP32[$7>>2]|0;
  $62 = ($60>>>0)>($61>>>0);
  if ($62) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$i$04,4);
   $$pre$i$i$i = HEAP32[$1>>2]|0;
   $$pre1$i$i$i = HEAP32[$7>>2]|0;
   $66 = $$pre$i$i$i;$68 = $$pre1$i$i$i;
  } else {
   $63 = HEAP32[$59>>2]|0;
   HEAP32[$i$04>>2] = $63;
   HEAP32[$1>>2] = $60;
   $66 = $60;$68 = $61;
  }
  $64 = (($i$04) + 4|0);
  $65 = (($66) + 4|0);
  $67 = ($65>>>0)>($68>>>0);
  if ($67) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$64,4);
  } else {
   $69 = Math_fround(HEAPF32[$66>>2]);
   HEAPF32[$64>>2] = $69;
   HEAP32[$1>>2] = $65;
  }
  $70 = (($i$04) + 8|0);
  $71 = ($70|0)==($51|0);
  if ($71) {
   break;
  } else {
   $i$04 = $70;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18AnimatorController8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $converter$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i4 = sp;
 __ZN25RuntimeAnimatorController8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,4);
 $0 = (($this) + 88|0);
 $1 = (($transfer) + 4|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 112|0);
 $3 = (($this) + 116|0);
 __Z21TransferBlobSerializeIN7mecanim9animation18ControllerConstantE14SafeBinaryReadEvRPT_PKcRjS8_RT0_($2,772064,$3,772080,$transfer);
 $4 = (($this) + 124|0);
 $5 = HEAP32[580600>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772104,$5,$converter$i$i4,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__13mapIj8UnityStrNS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEEEEvRT_17TransferMetaFlags($transfer,$4,0);
  } else {
   $9 = HEAP32[$converter$i$i4>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($4,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 68|0);
 $12 = HEAP32[580760>>2]|0;
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772112,$12,$converter$i$i4,1)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = ($13|0)>(0);
  if ($15) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI13AnimationClipELj4EEEEvRT_17TransferMetaFlags($transfer,$11,0);
  } else {
   $16 = HEAP32[$converter$i$i4>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    (FUNCTION_TABLE_iii[$16 & 4095]($11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $18 = (($this) + 140|0);
 $19 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772136,774072,$converter$i$i4,1)|0);
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = ($19|0)>(0);
  if ($21) {
   __ZN38StateMachineBehaviourVectorDescription8TransferI14SafeBinaryReadEEvRT_($18,$transfer);
  } else {
   $22 = HEAP32[$converter$i$i4>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    (FUNCTION_TABLE_iii[$22 & 4095]($18,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $24 = (($this) + 172|0);
 $25 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772184,$12,$converter$i$i4,1)|0);
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = ($25|0)>(0);
  if ($27) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI25StateMachineBehaviourInfoNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($transfer,$24,0);
  } else {
   $28 = HEAP32[$converter$i$i4>>2]|0;
   $29 = ($28|0)==(0|0);
   if (!($29)) {
    (FUNCTION_TABLE_iii[$28 & 4095]($24,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $30 = (($this) + 136|0);
 $31 = HEAP32[580544>>2]|0;
 $32 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772200,$31,$converter$i$i4,0)|0);
 $33 = ($32|0)==(0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = ($32|0)>(0);
 do {
  if ($34) {
   $35 = (($transfer) + 12|0);
   $36 = (($transfer) + 80|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($transfer) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($transfer) + 28|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($transfer) + 32|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = Math_imul($45, $43)|0;
   $$sum$i$i$i$i$i = (($39) - ($46))|0;
   $47 = (($41) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$35>>2] = $47;
   $48 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($48)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $49 = (($41) + ($$sum1$i$i$i$i$i)|0);
    $50 = (($transfer) + 20|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($49>>>0)>($51>>>0);
    if (!($52)) {
     $53 = HEAP8[$47>>0]|0;
     HEAP8[$30>>0] = $53;
     $54 = HEAP32[$35>>2]|0;
     $55 = (($54) + 1|0);
     HEAP32[$35>>2] = $55;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$30,1);
  } else {
   $56 = HEAP32[$converter$i$i4>>2]|0;
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    (FUNCTION_TABLE_iii[$56 & 4095]($30,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __Z21TransferBlobSerializeIN7mecanim9animation18ControllerConstantE14SafeBinaryReadEvRPT_PKcRjS8_RT0_($data,$name,$size,$sizeName,$transfer) {
 $data = $data|0;
 $name = $name|0;
 $size = $size|0;
 $sizeName = $sizeName|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$size,$sizeName,0);
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$size>>2]|0;
  __ZN7mecanim6memory16ChainedAllocator7ReserveEj($3,$4);
  $5 = HEAP32[$3>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiii[$6 & 2047]($3,40,4)|0);
  $8 = ($7|0)==(0|0);
  if ($8) {
   $9 = 0;
  } else {
   dest=$7+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $9 = $7;
  }
  HEAP32[$data>>2] = $9;
  $13 = $9;
 } else {
  $13 = $0;
 }
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$name,774168,$converter$i$i,1)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($10|0)>(0);
 if ($12) {
  __ZN7mecanim9animation18ControllerConstant8TransferI14SafeBinaryReadEEvRT_($13,$transfer);
 } else {
  $14 = HEAP32[$converter$i$i>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   (FUNCTION_TABLE_iii[$14 & 4095]($13,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI25StateMachineBehaviourInfoNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $converter$i$i$i$i2 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI25StateMachineBehaviourInfoNS0_9allocatorIS2_EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774040,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$51 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       $48 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772240,774016,$converter$i$i$i$i2,1)|0);
       $49 = ($48|0)==(0);
       if (!($49)) {
        $50 = ($48|0)>(0);
        if ($50) {
         __ZN4PPtrI13MonoBehaviourE8TransferI14SafeBinaryReadEEvRT_($51,$this);
        } else {
         $52 = HEAP32[$converter$i$i$i$i2>>2]|0;
         $53 = ($52|0)==(0|0);
         if (!($53)) {
          (FUNCTION_TABLE_iii[$52 & 4095]($51,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $54 = (($51) + 4|0);
       $55 = ($54|0)==($11|0);
       if ($55) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre10 = HEAP32[$$pre>>2]|0;
       $$pre11 = HEAP32[$15>>2]|0;
       $29 = $$pre10;$32 = $$pre11;$51 = $54;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $56 = HEAP32[$data>>2]|0;
   $57 = ($56|0)==($11|0);
   if (!($57)) {
    $64 = $56;
    while(1) {
     $58 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774040,$converter$i$i,1)|0);
     $59 = ($58|0)==(0);
     if (!($59)) {
      $60 = ($58|0)>(0);
      if ($60) {
       $61 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772240,774016,$converter$i$i$i$i2,1)|0);
       $62 = ($61|0)==(0);
       if (!($62)) {
        $63 = ($61|0)>(0);
        if ($63) {
         __ZN4PPtrI13MonoBehaviourE8TransferI14SafeBinaryReadEEvRT_($64,$this);
        } else {
         $65 = HEAP32[$converter$i$i$i$i2>>2]|0;
         $66 = ($65|0)==(0|0);
         if (!($66)) {
          (FUNCTION_TABLE_iii[$65 & 4095]($64,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $67 = HEAP32[$converter$i$i>>2]|0;
       $68 = ($67|0)==(0|0);
       if (!($68)) {
        (FUNCTION_TABLE_iii[$67 & 4095]($64,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $69 = (($64) + 4|0);
     $70 = ($69|0)==($11|0);
     if ($70) {
      break;
     } else {
      $64 = $69;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrI13MonoBehaviourE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,772256,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,772272,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,772256,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,772272,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN38StateMachineBehaviourVectorDescription8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580600>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772288,$0,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapI8StateKey10StateRangeNSt3__14lessIS2_EENS4_9allocatorINS4_4pairIS2_S3_EEEEEEEvRT_17TransferMetaFlags($transfer,$this,0);
  } else {
   $4 = HEAP32[$converter$i$i1>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($this,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($this) + 16|0);
 $7 = HEAP32[580760>>2]|0;
 $8 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772320,$7,$converter$i$i1,1)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = ($8|0)>(0);
 if ($10) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIjLj4EEEEvRT_17TransferMetaFlags($transfer,$6,0);
 } else {
  $11 = HEAP32[$converter$i$i1>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   (FUNCTION_TABLE_iii[$11 & 4095]($6,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapI8StateKey10StateRangeNSt3__14lessIS2_EENS4_9allocatorINS4_4pairIS2_S3_EEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $converter$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($data) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 4;
 HEAP32[$size>>2] = $9;
 $10 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$size>>2]|0;
 $12 = (($data) + 4|0);
 $13 = HEAP32[$2>>2]|0;
 $14 = HEAP32[$12>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = $17 >> 4;
 $19 = ($18>>>0)<($11>>>0);
 if ($19) {
  $20 = (($11) - ($18))|0;
  __ZNSt3__16vectorINS_4pairI8StateKey10StateRangeEENS_9allocatorIS4_EEE8__appendEj($12,$20);
  $$pre = HEAP32[$2>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $28 = $$pre8;$44 = $$pre;
 } else {
  $21 = ($18>>>0)>($11>>>0);
  if ($21) {
   $22 = (($14) + ($11<<4)|0);
   $23 = ($13|0)==($22|0);
   if ($23) {
    $28 = $11;$44 = $13;
   } else {
    $__new_last2$i$i$i$i = $22;
    $scevgep$i$i$i$i = (($13) + -16|0);
    $24 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($24)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $25 = $uglygep3$i$i$i$i >>> 4;
    $26 = $25 ^ -1;
    $scevgep4$i$i$i$i = (($13) + ($26<<4)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i;
    $28 = $11;$44 = $scevgep4$i$i$i$i;
   }
  } else {
   $28 = $11;$44 = $13;
  }
 }
 $27 = ($28|0)==(0);
 do {
  if (!($27)) {
   $29 = HEAP32[580608>>2]|0;
   $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,$29,0,1)|0);
   $31 = (($this) + 80|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (__ZNK16TypeTreeIterator7GetNodeEv($32)|0);
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($this) + 84|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$37>>2] = 0;
   $38 = ($30|0)==(2);
   if ($38) {
    $39 = HEAP32[$31>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$4>>2]|0;
    $43 = ($42|0)==($44|0);
    L14: do {
     if (!($43)) {
      $46 = 0;$49 = $39;$65 = $42;
      while(1) {
       $45 = Math_imul($46, $35)|0;
       $47 = (($45) + ($41))|0;
       $48 = (($49) + 20|0);
       HEAP32[$48>>2] = $47;
       $50 = (($49) + 12|0);
       HEAP32[$50>>2] = $47;
       $51 = (($49) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$49);
       $52 = $1;
       $53 = $52;
       $54 = HEAP32[$53>>2]|0;
       $55 = (($52) + 4)|0;
       $56 = $55;
       $57 = HEAP32[$56>>2]|0;
       $58 = $51;
       $59 = $58;
       HEAP32[$59>>2] = $54;
       $60 = (($58) + 4)|0;
       $61 = $60;
       HEAP32[$61>>2] = $57;
       $62 = HEAP32[$36>>2]|0;
       $63 = HEAP32[$62>>2]|0;
       $64 = (($63) + 1)|0;
       HEAP32[$62>>2] = $64;
       __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI14SafeBinaryReadEEvRS4_RT_($65,$this);
       $66 = (($65) + 16|0);
       $67 = ($66|0)==($44|0);
       if ($67) {
        break L14;
       }
       $$pre10 = HEAP32[$36>>2]|0;
       $$pre11 = HEAP32[$$pre10>>2]|0;
       $$pre12 = HEAP32[$31>>2]|0;
       $46 = $$pre11;$49 = $$pre12;$65 = $66;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $68 = HEAP32[$4>>2]|0;
   $69 = ($68|0)==($44|0);
   if (!($69)) {
    $73 = $68;
    while(1) {
     $70 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,$29,$converter$i$i,1)|0);
     $71 = ($70|0)==(0);
     if (!($71)) {
      $72 = ($70|0)>(0);
      if ($72) {
       __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI14SafeBinaryReadEEvRS4_RT_($73,$this);
      } else {
       $74 = HEAP32[$converter$i$i>>2]|0;
       $75 = ($74|0)==(0|0);
       if (!($75)) {
        (FUNCTION_TABLE_iii[$74 & 4095]($73,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $76 = (($73) + 16|0);
     $77 = ($76|0)==($44|0);
     if ($77) {
      break;
     } else {
      $73 = $76;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI14SafeBinaryReadEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i1 = sp;
 $0 = HEAP32[580576>>2]|0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$0,774128,$converter$i$i1,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$data,772376,0);
   $4 = (($data) + 4|0);
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$4,772392,0);
  } else {
   $5 = HEAP32[$converter$i$i1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($data,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($data) + 8|0);
 $8 = HEAP32[580656>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,$8,774112,$converter$i$i1,1)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = ($9|0)>(0);
 if ($11) {
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$7,772352,0);
  $12 = (($data) + 12|0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$12,772368,0);
 } else {
  $13 = HEAP32[$converter$i$i1>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   (FUNCTION_TABLE_iii[$13 & 4095]($7,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI4PPtrI13AnimationClipELj4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$byval_copy = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, $i$12 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $size = sp + 12|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($data) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$1>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN15SerializeTraitsI13dynamic_arrayI4PPtrI13AnimationClipELj4EEE19ResizeSTLStyleArrayERS4_i10MemLabelId($data,$6,$$byval_copy);
 $9 = HEAP32[$data>>2]|0;
 $10 = HEAP32[$3>>2]|0;
 $11 = (($9) + ($10<<2)|0);
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774144,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$i$01 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($2,$32);
       $35 = $2;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4PPtrI13AnimationClipE8TransferI14SafeBinaryReadEEvRT_($i$01,$this);
       $48 = (($i$01) + 4|0);
       $49 = ($48|0)==($11|0);
       if ($49) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre6 = HEAP32[$$pre>>2]|0;
       $$pre7 = HEAP32[$15>>2]|0;
       $29 = $$pre6;$32 = $$pre7;$i$01 = $48;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $50 = HEAP32[$data>>2]|0;
   $51 = ($50|0)==($11|0);
   if (!($51)) {
    $i$12 = $50;
    while(1) {
     $52 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774144,$$byval_copy,1)|0);
     $53 = ($52|0)==(0);
     if (!($53)) {
      $54 = ($52|0)>(0);
      if ($54) {
       __ZN4PPtrI13AnimationClipE8TransferI14SafeBinaryReadEEvRT_($i$12,$this);
      } else {
       $55 = HEAP32[$$byval_copy>>2]|0;
       $56 = ($55|0)==(0|0);
       if (!($56)) {
        (FUNCTION_TABLE_iii[$55 & 4095]($i$12,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $57 = (($i$12) + 4|0);
     $58 = ($57|0)==($11|0);
     if ($58) {
      break;
     } else {
      $i$12 = $57;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18ControllerConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i$i4 = 0, $converter$i$i3 = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i4 = sp + 12|0;
 $converter$i$i3 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$converter$i$i3>>2] = $0;
 $3 = (($converter$i$i3) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($converter$i$i3) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772408,$5,$converter$i$i$i4,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation13LayerConstantEEEEEvRT_17TransferMetaFlags($transfer,$converter$i$i3,0);
  } else {
   $9 = HEAP32[$converter$i$i$i4>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($converter$i$i3,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 16|0);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$converter$i$i3>>2] = $11;
 $14 = (($converter$i$i3) + 4|0);
 HEAP32[$14>>2] = $12;
 $15 = (($converter$i$i3) + 8|0);
 HEAP32[$15>>2] = $13;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772424,$5,$converter$i$i$i4,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  if ($18) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine20StateMachineConstantEEEEEvRT_17TransferMetaFlags($transfer,$converter$i$i3,0);
  } else {
   $19 = HEAP32[$converter$i$i$i4>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($converter$i$i3,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (($this) + 24|0);
 $22 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772448,774192,$converter$i$i$i4,1)|0);
 $23 = ($22|0)==(0);
 if (!($23)) {
  $24 = ($22|0)>(0);
  if ($24) {
   __ZN15SerializeTraitsI9OffsetPtrIN7mecanim18ValueArrayConstantEEE8TransferI14SafeBinaryReadEEvRS3_RT_($21,$transfer);
  } else {
   $25 = HEAP32[$converter$i$i$i4>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    (FUNCTION_TABLE_iii[$25 & 4095]($21,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $27 = (($this) + 32|0);
 $28 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772464,774192,$converter$i$i3,1)|0);
 $29 = ($28|0)==(0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = ($28|0)>(0);
 if ($30) {
  $31 = HEAP32[$27>>2]|0;
  $32 = ($31|0)==(0);
  if ($32) {
   $33 = HEAP32[$1>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$34>>2]|0;
   $36 = (FUNCTION_TABLE_iiii[$35 & 2047]($33,72,4)|0);
   $37 = ($36|0)==(0|0);
   if ($37) {
    $41 = 0;$43 = 0;
   } else {
    dest=$36+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $38 = $36;
    $39 = $27;
    $40 = (($38) - ($39))|0;
    $41 = $40;$43 = $36;
   }
   HEAP32[$27>>2] = $41;
   $42 = (($this) + 36|0);
   HEAP32[$42>>2] = $43;
   $$pre$phi$iZ2D = $42;$46 = $41;
  } else {
   $$pre$i = (($this) + 36|0);
   $$pre$phi$iZ2D = $$pre$i;$46 = $31;
  }
  $44 = $27;
  $45 = (($46) + ($44))|0;
  $47 = $45;
  HEAP32[$$pre$phi$iZ2D>>2] = $47;
  $48 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774208,$converter$i$i$i4,1)|0);
  $49 = ($48|0)==(0);
  if (!($49)) {
   $50 = ($48|0)>(0);
   if ($50) {
    __ZN7mecanim10ValueArray8TransferI14SafeBinaryReadEEvRT_($47,$transfer);
   } else {
    $51 = HEAP32[$converter$i$i$i4>>2]|0;
    $52 = ($51|0)==(0|0);
    if (!($52)) {
     $53 = $45;
     (FUNCTION_TABLE_iii[$51 & 4095]($53,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $54 = HEAP32[$converter$i$i3>>2]|0;
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   (FUNCTION_TABLE_iii[$54 & 4095]($27,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim10ValueArray8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ArrayTransfer$i11 = 0, $converter$i$i$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i10 = sp + 12|0;
 $ArrayTransfer$i11 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i11>>2] = $0;
 $3 = (($ArrayTransfer$i11) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i11) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772480,$5,$converter$i$i$i10,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIbEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i11,0);
  } else {
   $9 = HEAP32[$converter$i$i$i10>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($ArrayTransfer$i11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 16|0);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i11>>2] = $11;
 $14 = (($ArrayTransfer$i11) + 4|0);
 HEAP32[$14>>2] = $12;
 $15 = (($ArrayTransfer$i11) + 8|0);
 HEAP32[$15>>2] = $13;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772496,$5,$converter$i$i$i10,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  if ($18) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i11,0);
  } else {
   $19 = HEAP32[$converter$i$i$i10>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($ArrayTransfer$i11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (($this) + 28|0);
 $22 = (($this) + 24|0);
 $23 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i11>>2] = $21;
 $24 = (($ArrayTransfer$i11) + 4|0);
 HEAP32[$24>>2] = $22;
 $25 = (($ArrayTransfer$i11) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772512,$5,$converter$i$i$i10,1)|0);
 $27 = ($26|0)==(0);
 if (!($27)) {
  $28 = ($26|0)>(0);
  if ($28) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i11,0);
  } else {
   $29 = HEAP32[$converter$i$i$i10>>2]|0;
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    (FUNCTION_TABLE_iii[$29 & 4095]($ArrayTransfer$i11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $31 = (($this) + 40|0);
 $32 = (($this) + 36|0);
 $33 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i11>>2] = $31;
 $34 = (($ArrayTransfer$i11) + 4|0);
 HEAP32[$34>>2] = $32;
 $35 = (($ArrayTransfer$i11) + 8|0);
 HEAP32[$35>>2] = $33;
 $36 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772528,$5,$converter$i$i$i10,1)|0);
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = ($36|0)>(0);
  if ($38) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i11,0);
  } else {
   $39 = HEAP32[$converter$i$i$i10>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    (FUNCTION_TABLE_iii[$39 & 4095]($ArrayTransfer$i11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $41 = (($this) + 52|0);
 $42 = (($this) + 48|0);
 $43 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i11>>2] = $41;
 $44 = (($ArrayTransfer$i11) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($ArrayTransfer$i11) + 8|0);
 HEAP32[$45>>2] = $43;
 $46 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772552,$5,$converter$i$i$i10,1)|0);
 $47 = ($46|0)==(0);
 if (!($47)) {
  $48 = ($46|0)>(0);
  if ($48) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i11,0);
  } else {
   $49 = HEAP32[$converter$i$i$i10>>2]|0;
   $50 = ($49|0)==(0|0);
   if (!($50)) {
    (FUNCTION_TABLE_iii[$49 & 4095]($ArrayTransfer$i11,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $51 = (($this) + 64|0);
 $52 = (($this) + 60|0);
 $53 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i11>>2] = $51;
 $54 = (($ArrayTransfer$i11) + 4|0);
 HEAP32[$54>>2] = $52;
 $55 = (($ArrayTransfer$i11) + 8|0);
 HEAP32[$55>>2] = $53;
 $56 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772576,$5,$converter$i$i$i10,1)|0);
 $57 = ($56|0)==(0);
 if ($57) {
  STACKTOP = sp;return;
 }
 $58 = ($56|0)>(0);
 if ($58) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i11,0);
 } else {
  $59 = HEAP32[$converter$i$i$i10>>2]|0;
  $60 = ($59|0)==(0|0);
  if (!($60)) {
   (FUNCTION_TABLE_iii[$59 & 4095]($ArrayTransfer$i11,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIKN4math7_float4EEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $buf$i2 = 0, $converter$i$i = 0, $i$04 = 0, $i$15 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $buf$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $22 = (($9) + 4|0);
  HEAP32[$22>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 4;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$20 = 0;
  } else {
   $17 = $15;
   $18 = $9;
   $19 = (($17) - ($18))|0;
   $$0$i1$i$i = $15;$20 = $19;
  }
  HEAP32[$9>>2] = $20;
  $21 = (($9) + 4|0);
  HEAP32[$21>>2] = $$0$i1$i$i;
 }
 $23 = HEAP32[$data>>2]|0;
 $24 = $23;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = $26;
 $28 = (($23) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[$2>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($27) + ($30<<4)|0);
 $32 = HEAP32[$size>>2]|0;
 $33 = ($32|0)==(0);
 do {
  if (!($33)) {
   $34 = HEAP32[$data>>2]|0;
   $35 = $34;
   $36 = HEAP32[$34>>2]|0;
   $37 = (($36) + ($35))|0;
   $38 = $37;
   $39 = (($34) + 4|0);
   HEAP32[$39>>2] = $38;
   $40 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774224,0,1)|0);
   $41 = (($this) + 80|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (__ZNK16TypeTreeIterator7GetNodeEv($42)|0);
   $44 = (($43) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($this) + 84|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$47>>2] = 0;
   $48 = ($40|0)==(2);
   if ($48) {
    $49 = HEAP32[$41>>2]|0;
    $50 = (($49) + 12|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = HEAP32[$data>>2]|0;
    $53 = $52;
    $54 = HEAP32[$52>>2]|0;
    $55 = (($54) + ($53))|0;
    $56 = $55;
    $57 = (($52) + 4|0);
    HEAP32[$57>>2] = $56;
    $58 = ($56|0)==($31|0);
    if (!($58)) {
     $59 = (($buf$i2) + 4|0);
     $60 = (($buf$i2) + 8|0);
     $61 = (($buf$i2) + 12|0);
     $i$04 = $56;
     while(1) {
      $62 = HEAP32[$46>>2]|0;
      $63 = HEAP32[$62>>2]|0;
      $64 = Math_imul($63, $45)|0;
      $65 = (($64) + ($51))|0;
      $66 = HEAP32[$41>>2]|0;
      $67 = (($66) + 20|0);
      HEAP32[$67>>2] = $65;
      $68 = (($66) + 12|0);
      HEAP32[$68>>2] = $65;
      $69 = (($66) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$66);
      $70 = $1;
      $71 = $70;
      $72 = HEAP32[$71>>2]|0;
      $73 = (($70) + 4)|0;
      $74 = $73;
      $75 = HEAP32[$74>>2]|0;
      $76 = $69;
      $77 = $76;
      HEAP32[$77>>2] = $72;
      $78 = (($76) + 4)|0;
      $79 = $78;
      HEAP32[$79>>2] = $75;
      $80 = HEAP32[$46>>2]|0;
      $81 = HEAP32[$80>>2]|0;
      $82 = (($81) + 1)|0;
      HEAP32[$80>>2] = $82;
      $83 = Math_fround(HEAPF32[$i$04>>2]);
      HEAPF32[$buf$i2>>2] = $83;
      $84 = (($i$04) + 4|0);
      $85 = Math_fround(HEAPF32[$84>>2]);
      HEAPF32[$59>>2] = $85;
      $86 = (($i$04) + 8|0);
      $87 = Math_fround(HEAPF32[$86>>2]);
      HEAPF32[$60>>2] = $87;
      $88 = (($i$04) + 12|0);
      $89 = Math_fround(HEAPF32[$88>>2]);
      HEAPF32[$61>>2] = $89;
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$buf$i2,772592,0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$59,772600,0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$60,772608,0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$61,772616,0);
      $90 = Math_fround(HEAPF32[$buf$i2>>2]);
      $91 = Math_fround(HEAPF32[$59>>2]);
      $92 = Math_fround(HEAPF32[$60>>2]);
      $93 = Math_fround(HEAPF32[$61>>2]);
      HEAPF32[$i$04>>2] = $90;
      HEAPF32[$84>>2] = $91;
      HEAPF32[$86>>2] = $92;
      HEAPF32[$88>>2] = $93;
      $94 = (($i$04) + 16|0);
      $95 = ($94|0)==($31|0);
      if ($95) {
       break;
      } else {
       $i$04 = $94;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $96 = HEAP32[$data>>2]|0;
   $97 = $96;
   $98 = HEAP32[$96>>2]|0;
   $99 = (($98) + ($97))|0;
   $100 = $99;
   $101 = (($96) + 4|0);
   HEAP32[$101>>2] = $100;
   $102 = ($100|0)==($31|0);
   if (!($102)) {
    $103 = (($buf$i2) + 4|0);
    $104 = (($buf$i2) + 8|0);
    $105 = (($buf$i2) + 12|0);
    $i$15 = $100;
    while(1) {
     $106 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774224,$converter$i$i,1)|0);
     $107 = ($106|0)==(0);
     if (!($107)) {
      $108 = ($106|0)>(0);
      if ($108) {
       $109 = Math_fround(HEAPF32[$i$15>>2]);
       HEAPF32[$buf$i2>>2] = $109;
       $110 = (($i$15) + 4|0);
       $111 = Math_fround(HEAPF32[$110>>2]);
       HEAPF32[$103>>2] = $111;
       $112 = (($i$15) + 8|0);
       $113 = Math_fround(HEAPF32[$112>>2]);
       HEAPF32[$104>>2] = $113;
       $114 = (($i$15) + 12|0);
       $115 = Math_fround(HEAPF32[$114>>2]);
       HEAPF32[$105>>2] = $115;
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$buf$i2,772592,0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$103,772600,0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$104,772608,0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$105,772616,0);
       $116 = Math_fround(HEAPF32[$buf$i2>>2]);
       $117 = Math_fround(HEAPF32[$103>>2]);
       $118 = Math_fround(HEAPF32[$104>>2]);
       $119 = Math_fround(HEAPF32[$105>>2]);
       HEAPF32[$i$15>>2] = $116;
       HEAPF32[$110>>2] = $117;
       HEAPF32[$112>>2] = $118;
       HEAPF32[$114>>2] = $119;
      } else {
       $120 = HEAP32[$converter$i$i>>2]|0;
       $121 = ($120|0)==(0|0);
       if (!($121)) {
        (FUNCTION_TABLE_iii[$120 & 4095]($i$15,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $122 = (($i$15) + 16|0);
     $123 = ($122|0)==($31|0);
     if ($123) {
      break;
     } else {
      $i$15 = $122;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIbEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0;
 var $i$03 = 0, $i$15 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $21 = (($9) + 4|0);
  HEAP32[$21>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$6,1)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $19 = 0;
  } else {
   $16 = $14;
   $17 = $9;
   $18 = (($16) - ($17))|0;
   $19 = $18;
  }
  HEAP32[$9>>2] = $19;
  $20 = (($9) + 4|0);
  HEAP32[$20>>2] = $14;
 }
 $22 = HEAP32[$data>>2]|0;
 $23 = $22;
 $24 = HEAP32[$22>>2]|0;
 $25 = (($24) + ($23))|0;
 $26 = $25;
 $27 = (($22) + 4|0);
 HEAP32[$27>>2] = $26;
 $28 = HEAP32[$2>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($26) + ($29)|0);
 $31 = HEAP32[$size>>2]|0;
 $32 = ($31|0)==(0);
 do {
  if (!($32)) {
   $33 = HEAP32[$data>>2]|0;
   $34 = $33;
   $35 = HEAP32[$33>>2]|0;
   $36 = (($35) + ($34))|0;
   $37 = $36;
   $38 = (($33) + 4|0);
   HEAP32[$38>>2] = $37;
   $39 = HEAP32[580544>>2]|0;
   $40 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,$39,0,0)|0);
   $41 = (($this) + 80|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (__ZNK16TypeTreeIterator7GetNodeEv($42)|0);
   $44 = (($43) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($this) + 84|0);
   $47 = HEAP32[$46>>2]|0;
   HEAP32[$47>>2] = 0;
   $48 = ($40|0)==(2);
   if ($48) {
    $49 = HEAP32[$41>>2]|0;
    $50 = (($49) + 12|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = HEAP32[$data>>2]|0;
    $53 = $52;
    $54 = HEAP32[$52>>2]|0;
    $55 = (($54) + ($53))|0;
    $56 = $55;
    $57 = (($52) + 4|0);
    HEAP32[$57>>2] = $56;
    $58 = ($56|0)==($30|0);
    if (!($58)) {
     $59 = (($this) + 12|0);
     $60 = (($this) + 16|0);
     $61 = (($this) + 28|0);
     $62 = (($this) + 32|0);
     $63 = (($this) + 20|0);
     $i$03 = $56;
     while(1) {
      $64 = HEAP32[$46>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $45)|0;
      $67 = (($66) + ($51))|0;
      $68 = HEAP32[$41>>2]|0;
      $69 = (($68) + 20|0);
      HEAP32[$69>>2] = $67;
      $70 = (($68) + 12|0);
      HEAP32[$70>>2] = $67;
      $71 = (($68) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$68);
      $72 = $1;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 4)|0;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = $71;
      $79 = $78;
      HEAP32[$79>>2] = $74;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = $77;
      $82 = HEAP32[$46>>2]|0;
      $83 = HEAP32[$82>>2]|0;
      $84 = (($83) + 1)|0;
      HEAP32[$82>>2] = $84;
      $85 = HEAP32[$41>>2]|0;
      $86 = (($85) + 12|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = HEAP32[$60>>2]|0;
      $89 = HEAP32[$61>>2]|0;
      $90 = HEAP32[$62>>2]|0;
      $91 = Math_imul($90, $89)|0;
      $$sum$i$i$i = (($87) - ($91))|0;
      $92 = (($88) + ($$sum$i$i$i)|0);
      HEAP32[$59>>2] = $92;
      $93 = ($$sum$i$i$i|0)<(0);
      if ($93) {
       label = 14;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
       $94 = (($88) + ($$sum1$i$i$i)|0);
       $95 = HEAP32[$63>>2]|0;
       $96 = ($94>>>0)>($95>>>0);
       if ($96) {
        label = 14;
       } else {
        $97 = HEAP8[$92>>0]|0;
        HEAP8[$i$03>>0] = $97;
        $98 = HEAP32[$59>>2]|0;
        $99 = (($98) + 1|0);
        HEAP32[$59>>2] = $99;
       }
      }
      if ((label|0) == 14) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($59,$i$03,1);
      }
      $100 = (($i$03) + 1|0);
      $101 = ($100|0)==($30|0);
      if ($101) {
       break;
      } else {
       $i$03 = $100;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $102 = HEAP32[$data>>2]|0;
   $103 = $102;
   $104 = HEAP32[$102>>2]|0;
   $105 = (($104) + ($103))|0;
   $106 = $105;
   $107 = (($102) + 4|0);
   HEAP32[$107>>2] = $106;
   $108 = ($106|0)==($30|0);
   if (!($108)) {
    $109 = (($this) + 12|0);
    $110 = (($this) + 16|0);
    $111 = (($this) + 28|0);
    $112 = (($this) + 32|0);
    $113 = (($this) + 20|0);
    $i$15 = $106;
    while(1) {
     $114 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,$39,$converter$i$i,0)|0);
     $115 = ($114|0)==(0);
     if (!($115)) {
      $116 = ($114|0)>(0);
      do {
       if ($116) {
        $117 = HEAP32[$41>>2]|0;
        $118 = (($117) + 12|0);
        $119 = HEAP32[$118>>2]|0;
        $120 = HEAP32[$110>>2]|0;
        $121 = HEAP32[$111>>2]|0;
        $122 = HEAP32[$112>>2]|0;
        $123 = Math_imul($122, $121)|0;
        $$sum$i$i$i$i$i = (($119) - ($123))|0;
        $124 = (($120) + ($$sum$i$i$i$i$i)|0);
        HEAP32[$109>>2] = $124;
        $125 = ($$sum$i$i$i$i$i|0)<(0);
        if (!($125)) {
         $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
         $126 = (($120) + ($$sum1$i$i$i$i$i)|0);
         $127 = HEAP32[$113>>2]|0;
         $128 = ($126>>>0)>($127>>>0);
         if (!($128)) {
          $129 = HEAP8[$124>>0]|0;
          HEAP8[$i$15>>0] = $129;
          $130 = HEAP32[$109>>2]|0;
          $131 = (($130) + 1|0);
          HEAP32[$109>>2] = $131;
          break;
         }
        }
        __ZN12CachedReader15UpdateReadCacheEPvj($109,$i$15,1);
       } else {
        $132 = HEAP32[$converter$i$i>>2]|0;
        $133 = ($132|0)==(0|0);
        if (!($133)) {
         (FUNCTION_TABLE_iii[$132 & 4095]($i$15,$this)|0);
        }
       }
      } while(0);
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $134 = (($i$15) + 1|0);
     $135 = ($134|0)==($30|0);
     if ($135) {
      break;
     } else {
      $i$15 = $134;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine20StateMachineConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre$phi$i7Z2D = 0, $$pre$phi$iZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $converter$i$i$i2 = 0, $i$010 = 0, $i$112 = 0, $size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $64 = (($this) + 4|0);
     $i$010 = $61;
     while(1) {
      $65 = HEAP32[$51>>2]|0;
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $50)|0;
      $68 = (($67) + ($56))|0;
      $69 = HEAP32[$46>>2]|0;
      $70 = (($69) + 20|0);
      HEAP32[$70>>2] = $68;
      $71 = (($69) + 12|0);
      HEAP32[$71>>2] = $68;
      $72 = (($69) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$69);
      $73 = $1;
      $74 = $73;
      $75 = HEAP32[$74>>2]|0;
      $76 = (($73) + 4)|0;
      $77 = $76;
      $78 = HEAP32[$77>>2]|0;
      $79 = $72;
      $80 = $79;
      HEAP32[$80>>2] = $75;
      $81 = (($79) + 4)|0;
      $82 = $81;
      HEAP32[$82>>2] = $78;
      $83 = HEAP32[$51>>2]|0;
      $84 = HEAP32[$83>>2]|0;
      $85 = (($84) + 1)|0;
      HEAP32[$83>>2] = $85;
      $86 = HEAP32[$i$010>>2]|0;
      $87 = ($86|0)==(0);
      if ($87) {
       $88 = HEAP32[$64>>2]|0;
       $89 = HEAP32[$88>>2]|0;
       $90 = HEAP32[$89>>2]|0;
       $91 = (FUNCTION_TABLE_iiii[$90 & 2047]($88,44,4)|0);
       $92 = ($91|0)==(0|0);
       if ($92) {
        $97 = 0;$99 = 0;
       } else {
        $93 = (($91) + 28|0);
        ;HEAP32[$91+0>>2]=0|0;HEAP32[$91+4>>2]=0|0;HEAP32[$91+8>>2]=0|0;HEAP32[$91+12>>2]=0|0;HEAP32[$91+16>>2]=0|0;HEAP32[$91+20>>2]=0|0;
        ;HEAP32[$93+0>>2]=0|0;HEAP32[$93+4>>2]=0|0;HEAP32[$93+8>>2]=0|0;HEAP32[$93+12>>2]=0|0;
        $94 = $91;
        $95 = $i$010;
        $96 = (($94) - ($95))|0;
        $97 = $96;$99 = $91;
       }
       HEAP32[$i$010>>2] = $97;
       $98 = (($i$010) + 4|0);
       HEAP32[$98>>2] = $99;
       $$pre$phi$i7Z2D = $98;$102 = $97;
      } else {
       $$pre$i3 = (($i$010) + 4|0);
       $$pre$phi$i7Z2D = $$pre$i3;$102 = $86;
      }
      $100 = $i$010;
      $101 = (($102) + ($100))|0;
      $103 = $101;
      HEAP32[$$pre$phi$i7Z2D>>2] = $103;
      $104 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774232,$converter$i$i$i2,1)|0);
      $105 = ($104|0)==(0);
      if (!($105)) {
       $106 = ($104|0)>(0);
       if ($106) {
        __ZN7mecanim12statemachine20StateMachineConstant8TransferI14SafeBinaryReadEEvRT_($103,$this);
       } else {
        $107 = HEAP32[$converter$i$i$i2>>2]|0;
        $108 = ($107|0)==(0|0);
        if (!($108)) {
         $109 = $101;
         (FUNCTION_TABLE_iii[$107 & 4095]($109,$this)|0);
        }
       }
       __ZN14SafeBinaryRead11EndTransferEv($this);
      }
      $110 = (($i$010) + 8|0);
      $111 = ($110|0)==($36|0);
      if ($111) {
       break;
      } else {
       $i$010 = $110;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $112 = HEAP32[$data>>2]|0;
   $113 = $112;
   $114 = HEAP32[$112>>2]|0;
   $115 = (($114) + ($113))|0;
   $116 = $115;
   $117 = (($112) + 4|0);
   HEAP32[$117>>2] = $116;
   $118 = ($116|0)==($36|0);
   if (!($118)) {
    $119 = (($this) + 4|0);
    $i$112 = $116;
    while(1) {
     $120 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $121 = ($120|0)==(0);
     if (!($121)) {
      $122 = ($120|0)>(0);
      if ($122) {
       $123 = HEAP32[$i$112>>2]|0;
       $124 = ($123|0)==(0);
       if ($124) {
        $125 = HEAP32[$119>>2]|0;
        $126 = HEAP32[$125>>2]|0;
        $127 = HEAP32[$126>>2]|0;
        $128 = (FUNCTION_TABLE_iiii[$127 & 2047]($125,44,4)|0);
        $129 = ($128|0)==(0|0);
        if ($129) {
         $134 = 0;$136 = 0;
        } else {
         $130 = (($128) + 28|0);
         ;HEAP32[$128+0>>2]=0|0;HEAP32[$128+4>>2]=0|0;HEAP32[$128+8>>2]=0|0;HEAP32[$128+12>>2]=0|0;HEAP32[$128+16>>2]=0|0;HEAP32[$128+20>>2]=0|0;
         ;HEAP32[$130+0>>2]=0|0;HEAP32[$130+4>>2]=0|0;HEAP32[$130+8>>2]=0|0;HEAP32[$130+12>>2]=0|0;
         $131 = $128;
         $132 = $i$112;
         $133 = (($131) - ($132))|0;
         $134 = $133;$136 = $128;
        }
        HEAP32[$i$112>>2] = $134;
        $135 = (($i$112) + 4|0);
        HEAP32[$135>>2] = $136;
        $$pre$phi$iZ2D = $135;$139 = $134;
       } else {
        $$pre$i = (($i$112) + 4|0);
        $$pre$phi$iZ2D = $$pre$i;$139 = $123;
       }
       $137 = $i$112;
       $138 = (($139) + ($137))|0;
       $140 = $138;
       HEAP32[$$pre$phi$iZ2D>>2] = $140;
       $141 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774232,$converter$i$i$i2,1)|0);
       $142 = ($141|0)==(0);
       if (!($142)) {
        $143 = ($141|0)>(0);
        if ($143) {
         __ZN7mecanim12statemachine20StateMachineConstant8TransferI14SafeBinaryReadEEvRT_($140,$this);
        } else {
         $144 = HEAP32[$converter$i$i$i2>>2]|0;
         $145 = ($144|0)==(0|0);
         if (!($145)) {
          $146 = $138;
          (FUNCTION_TABLE_iii[$144 & 4095]($146,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $147 = HEAP32[$converter$i$i>>2]|0;
       $148 = ($147|0)==(0|0);
       if (!($148)) {
        (FUNCTION_TABLE_iii[$147 & 4095]($i$112,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $149 = (($i$112) + 8|0);
     $150 = ($149|0)==($36|0);
     if ($150) {
      break;
     } else {
      $i$112 = $149;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine20StateMachineConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i4 = 0, $converter$i$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i3 = sp + 12|0;
 $ArrayTransfer$i4 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i4>>2] = $0;
 $3 = (($ArrayTransfer$i4) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i4) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772632,$5,$converter$i$i$i3,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine13StateConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4,0);
  } else {
   $9 = HEAP32[$converter$i$i$i3>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($ArrayTransfer$i4,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 16|0);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i4>>2] = $11;
 $14 = (($ArrayTransfer$i4) + 4|0);
 HEAP32[$14>>2] = $12;
 $15 = (($ArrayTransfer$i4) + 8|0);
 HEAP32[$15>>2] = $13;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772656,$5,$converter$i$i$i3,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  if ($18) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4,0);
  } else {
   $19 = HEAP32[$converter$i$i$i3>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($ArrayTransfer$i4,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (($this) + 28|0);
 $22 = (($this) + 24|0);
 $23 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i4>>2] = $21;
 $24 = (($ArrayTransfer$i4) + 4|0);
 HEAP32[$24>>2] = $22;
 $25 = (($ArrayTransfer$i4) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772696,$5,$converter$i$i$i3,1)|0);
 $27 = ($26|0)==(0);
 if ($27) {
  $31 = (($this) + 36|0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$31,772728,0);
  $32 = (($this) + 40|0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$32,772744,0);
  STACKTOP = sp;return;
 }
 $28 = ($26|0)>(0);
 if ($28) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i4,0);
 } else {
  $29 = HEAP32[$converter$i$i$i3>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   (FUNCTION_TABLE_iii[$29 & 4095]($ArrayTransfer$i4,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $31 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$31,772728,0);
 $32 = (($this) + 40|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$32,772744,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine21SelectorStateConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre$phi$i7Z2D = 0, $$pre$phi$iZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $converter$i$i$i2 = 0, $i$010 = 0;
 var $i$112 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $64 = (($this) + 4|0);
     $i$010 = $61;
     while(1) {
      $65 = HEAP32[$51>>2]|0;
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $50)|0;
      $68 = (($67) + ($56))|0;
      $69 = HEAP32[$46>>2]|0;
      $70 = (($69) + 20|0);
      HEAP32[$70>>2] = $68;
      $71 = (($69) + 12|0);
      HEAP32[$71>>2] = $68;
      $72 = (($69) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$69);
      $73 = $1;
      $74 = $73;
      $75 = HEAP32[$74>>2]|0;
      $76 = (($73) + 4)|0;
      $77 = $76;
      $78 = HEAP32[$77>>2]|0;
      $79 = $72;
      $80 = $79;
      HEAP32[$80>>2] = $75;
      $81 = (($79) + 4)|0;
      $82 = $81;
      HEAP32[$82>>2] = $78;
      $83 = HEAP32[$51>>2]|0;
      $84 = HEAP32[$83>>2]|0;
      $85 = (($84) + 1)|0;
      HEAP32[$83>>2] = $85;
      $86 = HEAP32[$i$010>>2]|0;
      $87 = ($86|0)==(0);
      if ($87) {
       $88 = HEAP32[$64>>2]|0;
       $89 = HEAP32[$88>>2]|0;
       $90 = HEAP32[$89>>2]|0;
       $91 = (FUNCTION_TABLE_iiii[$90 & 2047]($88,20,4)|0);
       $92 = ($91|0)==(0|0);
       if ($92) {
        $100 = 0;$98 = 0;
       } else {
        $93 = (($91) + 4|0);
        HEAP32[$93>>2] = 0;
        $94 = (($91) + 8|0);
        HEAP32[$94>>2] = 0;
        $95 = $91;
        $96 = $i$010;
        $97 = (($95) - ($96))|0;
        $100 = $91;$98 = $97;
       }
       HEAP32[$i$010>>2] = $98;
       $99 = (($i$010) + 4|0);
       HEAP32[$99>>2] = $100;
       $$pre$phi$i7Z2D = $99;$103 = $98;
      } else {
       $$pre$i3 = (($i$010) + 4|0);
       $$pre$phi$i7Z2D = $$pre$i3;$103 = $86;
      }
      $101 = $i$010;
      $102 = (($103) + ($101))|0;
      $104 = $102;
      HEAP32[$$pre$phi$i7Z2D>>2] = $104;
      $105 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774256,$converter$i$i$i2,1)|0);
      $106 = ($105|0)==(0);
      if (!($106)) {
       $107 = ($105|0)>(0);
       if ($107) {
        __ZN7mecanim12statemachine21SelectorStateConstant8TransferI14SafeBinaryReadEEvRT_($104,$this);
       } else {
        $108 = HEAP32[$converter$i$i$i2>>2]|0;
        $109 = ($108|0)==(0|0);
        if (!($109)) {
         $110 = $102;
         (FUNCTION_TABLE_iii[$108 & 4095]($110,$this)|0);
        }
       }
       __ZN14SafeBinaryRead11EndTransferEv($this);
      }
      $111 = (($i$010) + 8|0);
      $112 = ($111|0)==($36|0);
      if ($112) {
       break;
      } else {
       $i$010 = $111;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $113 = HEAP32[$data>>2]|0;
   $114 = $113;
   $115 = HEAP32[$113>>2]|0;
   $116 = (($115) + ($114))|0;
   $117 = $116;
   $118 = (($113) + 4|0);
   HEAP32[$118>>2] = $117;
   $119 = ($117|0)==($36|0);
   if (!($119)) {
    $120 = (($this) + 4|0);
    $i$112 = $117;
    while(1) {
     $121 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $122 = ($121|0)==(0);
     if (!($122)) {
      $123 = ($121|0)>(0);
      if ($123) {
       $124 = HEAP32[$i$112>>2]|0;
       $125 = ($124|0)==(0);
       if ($125) {
        $126 = HEAP32[$120>>2]|0;
        $127 = HEAP32[$126>>2]|0;
        $128 = HEAP32[$127>>2]|0;
        $129 = (FUNCTION_TABLE_iiii[$128 & 2047]($126,20,4)|0);
        $130 = ($129|0)==(0|0);
        if ($130) {
         $136 = 0;$138 = 0;
        } else {
         $131 = (($129) + 4|0);
         HEAP32[$131>>2] = 0;
         $132 = (($129) + 8|0);
         HEAP32[$132>>2] = 0;
         $133 = $129;
         $134 = $i$112;
         $135 = (($133) - ($134))|0;
         $136 = $135;$138 = $129;
        }
        HEAP32[$i$112>>2] = $136;
        $137 = (($i$112) + 4|0);
        HEAP32[$137>>2] = $138;
        $$pre$phi$iZ2D = $137;$141 = $136;
       } else {
        $$pre$i = (($i$112) + 4|0);
        $$pre$phi$iZ2D = $$pre$i;$141 = $124;
       }
       $139 = $i$112;
       $140 = (($141) + ($139))|0;
       $142 = $140;
       HEAP32[$$pre$phi$iZ2D>>2] = $142;
       $143 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774256,$converter$i$i$i2,1)|0);
       $144 = ($143|0)==(0);
       if (!($144)) {
        $145 = ($143|0)>(0);
        if ($145) {
         __ZN7mecanim12statemachine21SelectorStateConstant8TransferI14SafeBinaryReadEEvRT_($142,$this);
        } else {
         $146 = HEAP32[$converter$i$i$i2>>2]|0;
         $147 = ($146|0)==(0|0);
         if (!($147)) {
          $148 = $140;
          (FUNCTION_TABLE_iii[$146 & 4095]($148,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $149 = HEAP32[$converter$i$i>>2]|0;
       $150 = ($149|0)==(0|0);
       if (!($150)) {
        (FUNCTION_TABLE_iii[$149 & 4095]($i$112,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $151 = (($i$112) + 8|0);
     $152 = ($151|0)==($36|0);
     if ($152) {
      break;
     } else {
      $i$112 = $151;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine21SelectorStateConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ArrayTransfer$i = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $ArrayTransfer$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $0;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772768,$5,$converter$i$i,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
  } else {
   $9 = HEAP32[$converter$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($ArrayTransfer$i,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$11,772800,0);
 $12 = (($this) + 16|0);
 $13 = HEAP32[580544>>2]|0;
 $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772816,$13,$converter$i$i,0)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = ($14|0)>(0);
 do {
  if ($16) {
   $17 = (($transfer) + 12|0);
   $18 = (($transfer) + 80|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($transfer) + 16|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($transfer) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($transfer) + 32|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = Math_imul($27, $25)|0;
   $$sum$i$i$i$i$i = (($21) - ($28))|0;
   $29 = (($23) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$17>>2] = $29;
   $30 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($30)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $31 = (($23) + ($$sum1$i$i$i$i$i)|0);
    $32 = (($transfer) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($31>>>0)>($33>>>0);
    if (!($34)) {
     $35 = HEAP8[$29>>0]|0;
     HEAP8[$12>>0] = $35;
     $36 = HEAP32[$17>>2]|0;
     $37 = (($36) + 1|0);
     HEAP32[$17>>2] = $37;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($17,$12,1);
  } else {
   $38 = HEAP32[$converter$i$i>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    (FUNCTION_TABLE_iii[$38 & 4095]($12,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $i$03 = $61;
     while(1) {
      $64 = HEAP32[$51>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $50)|0;
      $67 = (($66) + ($56))|0;
      $68 = HEAP32[$46>>2]|0;
      $69 = (($68) + 20|0);
      HEAP32[$69>>2] = $67;
      $70 = (($68) + 12|0);
      HEAP32[$70>>2] = $67;
      $71 = (($68) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$68);
      $72 = $1;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 4)|0;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = $71;
      $79 = $78;
      HEAP32[$79>>2] = $74;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = $77;
      $82 = HEAP32[$51>>2]|0;
      $83 = HEAP32[$82>>2]|0;
      $84 = (($83) + 1)|0;
      HEAP32[$82>>2] = $84;
      __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$03,$this);
      $85 = (($i$03) + 8|0);
      $86 = ($85|0)==($36|0);
      if ($86) {
       break;
      } else {
       $i$03 = $85;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $87 = HEAP32[$data>>2]|0;
   $88 = $87;
   $89 = HEAP32[$87>>2]|0;
   $90 = (($89) + ($88))|0;
   $91 = $90;
   $92 = (($87) + 4|0);
   HEAP32[$92>>2] = $91;
   $93 = ($91|0)==($36|0);
   if (!($93)) {
    $i$14 = $91;
    while(1) {
     $94 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $95 = ($94|0)==(0);
     if (!($95)) {
      $96 = ($94|0)>(0);
      if ($96) {
       __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$14,$this);
      } else {
       $97 = HEAP32[$converter$i$i>>2]|0;
       $98 = ($97|0)==(0|0);
       if (!($98)) {
        (FUNCTION_TABLE_iii[$97 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($i$14) + 8|0);
     $100 = ($99|0)==($36|0);
     if ($100) {
      break;
     } else {
      $i$14 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ArrayTransfer$i$i$i = 0, $converter$i$i = 0, $converter$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i$i = sp + 16|0;
 $ArrayTransfer$i$i$i = sp;
 $converter$i$i = sp + 12|0;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,16,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = 0;$15 = 0;
  } else {
   HEAP32[$6>>2] = 0;
   $8 = (($6) + 8|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 12|0);
   HEAP32[$9>>2] = 0;
   $10 = $6;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $6;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phiZ2D = $14;$18 = $13;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$18 = $0;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phiZ2D>>2] = $19;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774280,$converter$i$i,1)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = ($20|0)>(0);
 if ($22) {
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$19,772832,0);
  $23 = (($19) + 8|0);
  $24 = (($19) + 4|0);
  $25 = (($transfer) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i>>2] = $23;
  $27 = (($ArrayTransfer$i$i$i) + 4|0);
  HEAP32[$27>>2] = $24;
  $28 = (($ArrayTransfer$i$i$i) + 8|0);
  HEAP32[$28>>2] = $26;
  $29 = HEAP32[580760>>2]|0;
  $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772848,$29,$converter$i$i$i$i$i,1)|0);
  $31 = ($30|0)==(0);
  if (!($31)) {
   $32 = ($30|0)>(0);
   if ($32) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i,0);
   } else {
    $33 = HEAP32[$converter$i$i$i$i$i>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     (FUNCTION_TABLE_iii[$33 & 4095]($ArrayTransfer$i$i$i,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $35 = HEAP32[$converter$i$i>>2]|0;
  $36 = ($35|0)==(0|0);
  if (!($36)) {
   $37 = $17;
   (FUNCTION_TABLE_iii[$35 & 4095]($37,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $i$03 = $61;
     while(1) {
      $64 = HEAP32[$51>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $50)|0;
      $67 = (($66) + ($56))|0;
      $68 = HEAP32[$46>>2]|0;
      $69 = (($68) + 20|0);
      HEAP32[$69>>2] = $67;
      $70 = (($68) + 12|0);
      HEAP32[$70>>2] = $67;
      $71 = (($68) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$68);
      $72 = $1;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 4)|0;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = $71;
      $79 = $78;
      HEAP32[$79>>2] = $74;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = $77;
      $82 = HEAP32[$51>>2]|0;
      $83 = HEAP32[$82>>2]|0;
      $84 = (($83) + 1)|0;
      HEAP32[$82>>2] = $84;
      __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$03,$this);
      $85 = (($i$03) + 8|0);
      $86 = ($85|0)==($36|0);
      if ($86) {
       break;
      } else {
       $i$03 = $85;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $87 = HEAP32[$data>>2]|0;
   $88 = $87;
   $89 = HEAP32[$87>>2]|0;
   $90 = (($89) + ($88))|0;
   $91 = $90;
   $92 = (($87) + 4|0);
   HEAP32[$92>>2] = $91;
   $93 = ($91|0)==($36|0);
   if (!($93)) {
    $i$14 = $91;
    while(1) {
     $94 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $95 = ($94|0)==(0);
     if (!($95)) {
      $96 = ($94|0)>(0);
      if ($96) {
       __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$14,$this);
      } else {
       $97 = HEAP32[$converter$i$i>>2]|0;
       $98 = ($97|0)==(0|0);
       if (!($98)) {
        (FUNCTION_TABLE_iii[$97 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($i$14) + 8|0);
     $100 = ($99|0)==($36|0);
     if ($100) {
      break;
     } else {
      $i$14 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,16,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $14 = 0;$16 = 0;
  } else {
   HEAP32[$6>>2] = 1;
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 8|0);
   HEAPF32[$9>>2] = Math_fround(0.0);
   $10 = (($6) + 12|0);
   HEAPF32[$10>>2] = Math_fround(0.0);
   $11 = $6;
   $12 = $data;
   $13 = (($11) - ($12))|0;
   $14 = $13;$16 = $6;
  }
  HEAP32[$data>>2] = $14;
  $15 = (($data) + 4|0);
  HEAP32[$15>>2] = $16;
  $$pre$phiZ2D = $15;$19 = $14;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$19 = $0;
 }
 $17 = $data;
 $18 = (($19) + ($17))|0;
 $20 = $18;
 HEAP32[$$pre$phiZ2D>>2] = $20;
 $21 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774312,$converter$i$i,1)|0);
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = ($21|0)>(0);
 if ($23) {
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$20,772880,0);
  $24 = (($20) + 4|0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$24,772896,0);
  $25 = (($20) + 8|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$25,772912,0);
  $26 = (($20) + 12|0);
  __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$26,772936,0);
 } else {
  $27 = HEAP32[$converter$i$i>>2]|0;
  $28 = ($27|0)==(0|0);
  if (!($28)) {
   $29 = $18;
   (FUNCTION_TABLE_iii[$27 & 4095]($29,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre$phi$i7Z2D = 0, $$pre$phi$iZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $converter$i$i$i2 = 0, $i$010 = 0, $i$112 = 0, $size = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $64 = (($this) + 4|0);
     $i$010 = $61;
     while(1) {
      $65 = HEAP32[$51>>2]|0;
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $50)|0;
      $68 = (($67) + ($56))|0;
      $69 = HEAP32[$46>>2]|0;
      $70 = (($69) + 20|0);
      HEAP32[$70>>2] = $68;
      $71 = (($69) + 12|0);
      HEAP32[$71>>2] = $68;
      $72 = (($69) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$69);
      $73 = $1;
      $74 = $73;
      $75 = HEAP32[$74>>2]|0;
      $76 = (($73) + 4)|0;
      $77 = $76;
      $78 = HEAP32[$77>>2]|0;
      $79 = $72;
      $80 = $79;
      HEAP32[$80>>2] = $75;
      $81 = (($79) + 4)|0;
      $82 = $81;
      HEAP32[$82>>2] = $78;
      $83 = HEAP32[$51>>2]|0;
      $84 = HEAP32[$83>>2]|0;
      $85 = (($84) + 1)|0;
      HEAP32[$83>>2] = $85;
      $86 = HEAP32[$i$010>>2]|0;
      $87 = ($86|0)==(0);
      if ($87) {
       $88 = HEAP32[$64>>2]|0;
       $89 = HEAP32[$88>>2]|0;
       $90 = HEAP32[$89>>2]|0;
       $91 = (FUNCTION_TABLE_iiii[$90 & 2047]($88,52,4)|0);
       $92 = ($91|0)==(0|0);
       if ($92) {
        $101 = 0;$103 = 0;
       } else {
        $93 = (($91) + 36|0);
        dest=$91+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
        HEAPF32[$93>>2] = Math_fround(0.899999976158142089843);
        $94 = (($91) + 40|0);
        HEAP8[$94>>0] = 0;
        $95 = (($91) + 44|0);
        HEAP32[$95>>2] = 0;
        $96 = (($91) + 48|0);
        HEAP8[$96>>0] = 1;
        $97 = (($91) + 49|0);
        HEAP8[$97>>0] = 0;
        $98 = $91;
        $99 = $i$010;
        $100 = (($98) - ($99))|0;
        $101 = $100;$103 = $91;
       }
       HEAP32[$i$010>>2] = $101;
       $102 = (($i$010) + 4|0);
       HEAP32[$102>>2] = $103;
       $$pre$phi$i7Z2D = $102;$106 = $101;
      } else {
       $$pre$i3 = (($i$010) + 4|0);
       $$pre$phi$i7Z2D = $$pre$i3;$106 = $86;
      }
      $104 = $i$010;
      $105 = (($106) + ($104))|0;
      $107 = $105;
      HEAP32[$$pre$phi$i7Z2D>>2] = $107;
      $108 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774336,$converter$i$i$i2,1)|0);
      $109 = ($108|0)==(0);
      if (!($109)) {
       $110 = ($108|0)>(0);
       if ($110) {
        __ZN7mecanim12statemachine18TransitionConstant8TransferI14SafeBinaryReadEEvRT_($107,$this);
       } else {
        $111 = HEAP32[$converter$i$i$i2>>2]|0;
        $112 = ($111|0)==(0|0);
        if (!($112)) {
         $113 = $105;
         (FUNCTION_TABLE_iii[$111 & 4095]($113,$this)|0);
        }
       }
       __ZN14SafeBinaryRead11EndTransferEv($this);
      }
      $114 = (($i$010) + 8|0);
      $115 = ($114|0)==($36|0);
      if ($115) {
       break;
      } else {
       $i$010 = $114;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $116 = HEAP32[$data>>2]|0;
   $117 = $116;
   $118 = HEAP32[$116>>2]|0;
   $119 = (($118) + ($117))|0;
   $120 = $119;
   $121 = (($116) + 4|0);
   HEAP32[$121>>2] = $120;
   $122 = ($120|0)==($36|0);
   if (!($122)) {
    $123 = (($this) + 4|0);
    $i$112 = $120;
    while(1) {
     $124 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $125 = ($124|0)==(0);
     if (!($125)) {
      $126 = ($124|0)>(0);
      if ($126) {
       $127 = HEAP32[$i$112>>2]|0;
       $128 = ($127|0)==(0);
       if ($128) {
        $129 = HEAP32[$123>>2]|0;
        $130 = HEAP32[$129>>2]|0;
        $131 = HEAP32[$130>>2]|0;
        $132 = (FUNCTION_TABLE_iiii[$131 & 2047]($129,52,4)|0);
        $133 = ($132|0)==(0|0);
        if ($133) {
         $142 = 0;$144 = 0;
        } else {
         $134 = (($132) + 36|0);
         dest=$132+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
         HEAPF32[$134>>2] = Math_fround(0.899999976158142089843);
         $135 = (($132) + 40|0);
         HEAP8[$135>>0] = 0;
         $136 = (($132) + 44|0);
         HEAP32[$136>>2] = 0;
         $137 = (($132) + 48|0);
         HEAP8[$137>>0] = 1;
         $138 = (($132) + 49|0);
         HEAP8[$138>>0] = 0;
         $139 = $132;
         $140 = $i$112;
         $141 = (($139) - ($140))|0;
         $142 = $141;$144 = $132;
        }
        HEAP32[$i$112>>2] = $142;
        $143 = (($i$112) + 4|0);
        HEAP32[$143>>2] = $144;
        $$pre$phi$iZ2D = $143;$147 = $142;
       } else {
        $$pre$i = (($i$112) + 4|0);
        $$pre$phi$iZ2D = $$pre$i;$147 = $127;
       }
       $145 = $i$112;
       $146 = (($147) + ($145))|0;
       $148 = $146;
       HEAP32[$$pre$phi$iZ2D>>2] = $148;
       $149 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774336,$converter$i$i$i2,1)|0);
       $150 = ($149|0)==(0);
       if (!($150)) {
        $151 = ($149|0)>(0);
        if ($151) {
         __ZN7mecanim12statemachine18TransitionConstant8TransferI14SafeBinaryReadEEvRT_($148,$this);
        } else {
         $152 = HEAP32[$converter$i$i$i2>>2]|0;
         $153 = ($152|0)==(0|0);
         if (!($153)) {
          $154 = $146;
          (FUNCTION_TABLE_iii[$152 & 4095]($154,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $155 = HEAP32[$converter$i$i>>2]|0;
       $156 = ($155|0)==(0|0);
       if (!($156)) {
        (FUNCTION_TABLE_iii[$155 & 4095]($i$112,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $157 = (($i$112) + 8|0);
     $158 = ($157|0)==($36|0);
     if ($158) {
      break;
     } else {
      $i$112 = $157;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine18TransitionConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i2 = 0, $$sum$i$i$i$i$i7 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i3 = 0, $$sum1$i$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i = 0, $converter$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i6 = sp + 12|0;
 $ArrayTransfer$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $0;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772848,$5,$converter$i$i6,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine17ConditionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
  } else {
   $9 = HEAP32[$converter$i$i6>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($ArrayTransfer$i,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 12|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$11,772952,0);
 $12 = (($this) + 16|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$12,772800,0);
 $13 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$13,772624,0);
 $14 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$14,772976,0);
 $15 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$15,772992,0);
 $16 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,773016,0);
 $17 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$17,772936,0);
 $18 = (($this) + 40|0);
 $19 = HEAP32[580544>>2]|0;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773040,$19,$converter$i$i6,0)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = ($20|0)>(0);
  do {
   if ($22) {
    $23 = (($transfer) + 12|0);
    $24 = (($transfer) + 80|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($transfer) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($transfer) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($transfer) + 32|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = Math_imul($33, $31)|0;
    $$sum$i$i$i$i$i = (($27) - ($34))|0;
    $35 = (($29) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$23>>2] = $35;
    $36 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($36)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $37 = (($29) + ($$sum1$i$i$i$i$i)|0);
     $38 = (($transfer) + 20|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($37>>>0)>($39>>>0);
     if (!($40)) {
      $41 = HEAP8[$35>>0]|0;
      HEAP8[$18>>0] = $41;
      $42 = HEAP32[$23>>2]|0;
      $43 = (($42) + 1|0);
      HEAP32[$23>>2] = $43;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($23,$18,1);
   } else {
    $44 = HEAP32[$converter$i$i6>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     (FUNCTION_TABLE_iii[$44 & 4095]($18,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $46 = (($this) + 44|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$46,773056,0);
 $47 = (($this) + 48|0);
 $48 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773080,$19,$converter$i$i6,0)|0);
 $49 = ($48|0)==(0);
 if (!($49)) {
  $50 = ($48|0)>(0);
  do {
   if ($50) {
    $51 = (($transfer) + 12|0);
    $52 = (($transfer) + 80|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + 12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($transfer) + 16|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($transfer) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($transfer) + 32|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = Math_imul($61, $59)|0;
    $$sum$i$i$i$i$i2 = (($55) - ($62))|0;
    $63 = (($57) + ($$sum$i$i$i$i$i2)|0);
    HEAP32[$51>>2] = $63;
    $64 = ($$sum$i$i$i$i$i2|0)<(0);
    if (!($64)) {
     $$sum1$i$i$i$i$i3 = (($$sum$i$i$i$i$i2) + 1)|0;
     $65 = (($57) + ($$sum1$i$i$i$i$i3)|0);
     $66 = (($transfer) + 20|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($65>>>0)>($67>>>0);
     if (!($68)) {
      $69 = HEAP8[$63>>0]|0;
      HEAP8[$47>>0] = $69;
      $70 = HEAP32[$51>>2]|0;
      $71 = (($70) + 1|0);
      HEAP32[$51>>2] = $71;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($51,$47,1);
   } else {
    $72 = HEAP32[$converter$i$i6>>2]|0;
    $73 = ($72|0)==(0|0);
    if (!($73)) {
     (FUNCTION_TABLE_iii[$72 & 4095]($47,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $74 = (($this) + 49|0);
 $75 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773104,$19,$converter$i$i6,0)|0);
 $76 = ($75|0)==(0);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = ($75|0)>(0);
 do {
  if ($77) {
   $78 = (($transfer) + 12|0);
   $79 = (($transfer) + 80|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($80) + 12|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($transfer) + 16|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = (($transfer) + 28|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($transfer) + 32|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = Math_imul($88, $86)|0;
   $$sum$i$i$i$i$i7 = (($82) - ($89))|0;
   $90 = (($84) + ($$sum$i$i$i$i$i7)|0);
   HEAP32[$78>>2] = $90;
   $91 = ($$sum$i$i$i$i$i7|0)<(0);
   if (!($91)) {
    $$sum1$i$i$i$i$i8 = (($$sum$i$i$i$i$i7) + 1)|0;
    $92 = (($84) + ($$sum1$i$i$i$i$i8)|0);
    $93 = (($transfer) + 20|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($92>>>0)>($94>>>0);
    if (!($95)) {
     $96 = HEAP8[$90>>0]|0;
     HEAP8[$74>>0] = $96;
     $97 = HEAP32[$78>>2]|0;
     $98 = (($97) + 1|0);
     HEAP32[$78>>2] = $98;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($78,$74,1);
  } else {
   $99 = HEAP32[$converter$i$i6>>2]|0;
   $100 = ($99|0)==(0|0);
   if (!($100)) {
    (FUNCTION_TABLE_iii[$99 & 4095]($74,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine13StateConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $i$03 = $61;
     while(1) {
      $64 = HEAP32[$51>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $50)|0;
      $67 = (($66) + ($56))|0;
      $68 = HEAP32[$46>>2]|0;
      $69 = (($68) + 20|0);
      HEAP32[$69>>2] = $67;
      $70 = (($68) + 12|0);
      HEAP32[$70>>2] = $67;
      $71 = (($68) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$68);
      $72 = $1;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 4)|0;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = $71;
      $79 = $78;
      HEAP32[$79>>2] = $74;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = $77;
      $82 = HEAP32[$51>>2]|0;
      $83 = HEAP32[$82>>2]|0;
      $84 = (($83) + 1)|0;
      HEAP32[$82>>2] = $84;
      __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine13StateConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$03,$this);
      $85 = (($i$03) + 8|0);
      $86 = ($85|0)==($36|0);
      if ($86) {
       break;
      } else {
       $i$03 = $85;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $87 = HEAP32[$data>>2]|0;
   $88 = $87;
   $89 = HEAP32[$87>>2]|0;
   $90 = (($89) + ($88))|0;
   $91 = $90;
   $92 = (($87) + 4|0);
   HEAP32[$92>>2] = $91;
   $93 = ($91|0)==($36|0);
   if (!($93)) {
    $i$14 = $91;
    while(1) {
     $94 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $95 = ($94|0)==(0);
     if (!($95)) {
      $96 = ($94|0)>(0);
      if ($96) {
       __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine13StateConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$14,$this);
      } else {
       $97 = HEAP32[$converter$i$i>>2]|0;
       $98 = ($97|0)==(0|0);
       if (!($98)) {
        (FUNCTION_TABLE_iii[$97 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($i$14) + 8|0);
     $100 = ($99|0)==($36|0);
     if ($100) {
      break;
     } else {
      $i$14 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim12statemachine13StateConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,72,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $17 = 0;$19 = 0;
  } else {
   $8 = (($6) + 60|0);
   dest=$6+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAPF32[$8>>2] = Math_fround(1.0);
   $9 = (($6) + 64|0);
   HEAPF32[$9>>2] = Math_fround(0.0);
   $10 = (($6) + 68|0);
   HEAP8[$10>>0] = 1;
   $11 = (($6) + 69|0);
   HEAP8[$11>>0] = 1;
   $12 = (($6) + 70|0);
   HEAP8[$12>>0] = 0;
   $13 = (($6) + 71|0);
   HEAP8[$13>>0] = 0;
   $14 = $6;
   $15 = $data;
   $16 = (($14) - ($15))|0;
   $17 = $16;$19 = $6;
  }
  HEAP32[$data>>2] = $17;
  $18 = (($data) + 4|0);
  HEAP32[$18>>2] = $19;
  $$pre$phiZ2D = $18;$22 = $17;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$22 = $0;
 }
 $20 = $data;
 $21 = (($22) + ($20))|0;
 $23 = $21;
 HEAP32[$$pre$phiZ2D>>2] = $23;
 $24 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774360,$converter$i$i,1)|0);
 $25 = ($24|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = ($24|0)>(0);
 if ($26) {
  __ZN7mecanim12statemachine13StateConstant8TransferI14SafeBinaryReadEEvRT_($23,$transfer);
 } else {
  $27 = HEAP32[$converter$i$i>>2]|0;
  $28 = ($27|0)==(0|0);
  if (!($28)) {
   $29 = $21;
   (FUNCTION_TABLE_iii[$27 & 4095]($29,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine13StateConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i13 = 0, $$sum$i$i$i$i$i18 = 0, $$sum$i$i$i$i$i8 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i14 = 0, $$sum1$i$i$i$i$i19 = 0, $$sum1$i$i$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i6 = 0, $converter$i$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i17 = sp + 12|0;
 $ArrayTransfer$i6 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i6>>2] = $0;
 $3 = (($ArrayTransfer$i6) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i6) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772768,$5,$converter$i$i17,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim12statemachine18TransitionConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i6,0);
  } else {
   $9 = HEAP32[$converter$i$i17>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($ArrayTransfer$i6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 16|0);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i6>>2] = $11;
 $14 = (($ArrayTransfer$i6) + 4|0);
 HEAP32[$14>>2] = $12;
 $15 = (($ArrayTransfer$i6) + 8|0);
 HEAP32[$15>>2] = $13;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773128,$5,$converter$i$i17,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  if ($18) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIiEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i6,0);
  } else {
   $19 = HEAP32[$converter$i$i17>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($ArrayTransfer$i6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (($this) + 24|0);
 $22 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i6>>2] = $21;
 $23 = (($ArrayTransfer$i6) + 4|0);
 HEAP32[$23>>2] = $12;
 $24 = (($ArrayTransfer$i6) + 8|0);
 HEAP32[$24>>2] = $22;
 $25 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773160,$5,$converter$i$i17,1)|0);
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = ($25|0)>(0);
  if ($27) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim12statemachine16LeafInfoConstantEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i6,0);
  } else {
   $28 = HEAP32[$converter$i$i17>>2]|0;
   $29 = ($28|0)==(0|0);
   if (!($29)) {
    (FUNCTION_TABLE_iii[$28 & 4095]($ArrayTransfer$i6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $30 = (($this) + 36|0);
 $31 = (($this) + 32|0);
 $32 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i6>>2] = $30;
 $33 = (($ArrayTransfer$i6) + 4|0);
 HEAP32[$33>>2] = $31;
 $34 = (($ArrayTransfer$i6) + 8|0);
 HEAP32[$34>>2] = $32;
 $35 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773176,$5,$converter$i$i17,1)|0);
 $36 = ($35|0)==(0);
 if (!($36)) {
  $37 = ($35|0)>(0);
  if ($37) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i6,0);
  } else {
   $38 = HEAP32[$converter$i$i17>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    (FUNCTION_TABLE_iii[$38 & 4095]($ArrayTransfer$i6,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $40 = (($this) + 44|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$40,773208,0);
 $41 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$41,772272,0);
 $42 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$42,772800,0);
 $43 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$43,773224,0);
 $44 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$44,773232,0);
 $45 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$45,773240,0);
 $46 = (($this) + 68|0);
 $47 = HEAP32[580544>>2]|0;
 $48 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773256,$47,$converter$i$i17,0)|0);
 $49 = ($48|0)==(0);
 if (!($49)) {
  $50 = ($48|0)>(0);
  do {
   if ($50) {
    $51 = (($transfer) + 12|0);
    $52 = (($transfer) + 80|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + 12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($transfer) + 16|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($transfer) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($transfer) + 32|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = Math_imul($61, $59)|0;
    $$sum$i$i$i$i$i = (($55) - ($62))|0;
    $63 = (($57) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$51>>2] = $63;
    $64 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($64)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $65 = (($57) + ($$sum1$i$i$i$i$i)|0);
     $66 = (($transfer) + 20|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($65>>>0)>($67>>>0);
     if (!($68)) {
      $69 = HEAP8[$63>>0]|0;
      HEAP8[$46>>0] = $69;
      $70 = HEAP32[$51>>2]|0;
      $71 = (($70) + 1|0);
      HEAP32[$51>>2] = $71;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($51,$46,1);
   } else {
    $72 = HEAP32[$converter$i$i17>>2]|0;
    $73 = ($72|0)==(0|0);
    if (!($73)) {
     (FUNCTION_TABLE_iii[$72 & 4095]($46,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $74 = (($this) + 69|0);
 $75 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773272,$47,$converter$i$i17,0)|0);
 $76 = ($75|0)==(0);
 if (!($76)) {
  $77 = ($75|0)>(0);
  do {
   if ($77) {
    $78 = (($transfer) + 12|0);
    $79 = (($transfer) + 80|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($80) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($transfer) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($transfer) + 28|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($transfer) + 32|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = Math_imul($88, $86)|0;
    $$sum$i$i$i$i$i8 = (($82) - ($89))|0;
    $90 = (($84) + ($$sum$i$i$i$i$i8)|0);
    HEAP32[$78>>2] = $90;
    $91 = ($$sum$i$i$i$i$i8|0)<(0);
    if (!($91)) {
     $$sum1$i$i$i$i$i9 = (($$sum$i$i$i$i$i8) + 1)|0;
     $92 = (($84) + ($$sum1$i$i$i$i$i9)|0);
     $93 = (($transfer) + 20|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = ($92>>>0)>($94>>>0);
     if (!($95)) {
      $96 = HEAP8[$90>>0]|0;
      HEAP8[$74>>0] = $96;
      $97 = HEAP32[$78>>2]|0;
      $98 = (($97) + 1|0);
      HEAP32[$78>>2] = $98;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($78,$74,1);
   } else {
    $99 = HEAP32[$converter$i$i17>>2]|0;
    $100 = ($99|0)==(0|0);
    if (!($100)) {
     (FUNCTION_TABLE_iii[$99 & 4095]($74,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $101 = (($this) + 70|0);
 $102 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773296,$47,$converter$i$i17,0)|0);
 $103 = ($102|0)==(0);
 if (!($103)) {
  $104 = ($102|0)>(0);
  do {
   if ($104) {
    $105 = (($transfer) + 12|0);
    $106 = (($transfer) + 80|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (($107) + 12|0);
    $109 = HEAP32[$108>>2]|0;
    $110 = (($transfer) + 16|0);
    $111 = HEAP32[$110>>2]|0;
    $112 = (($transfer) + 28|0);
    $113 = HEAP32[$112>>2]|0;
    $114 = (($transfer) + 32|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = Math_imul($115, $113)|0;
    $$sum$i$i$i$i$i13 = (($109) - ($116))|0;
    $117 = (($111) + ($$sum$i$i$i$i$i13)|0);
    HEAP32[$105>>2] = $117;
    $118 = ($$sum$i$i$i$i$i13|0)<(0);
    if (!($118)) {
     $$sum1$i$i$i$i$i14 = (($$sum$i$i$i$i$i13) + 1)|0;
     $119 = (($111) + ($$sum1$i$i$i$i$i14)|0);
     $120 = (($transfer) + 20|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = ($119>>>0)>($121>>>0);
     if (!($122)) {
      $123 = HEAP8[$117>>0]|0;
      HEAP8[$101>>0] = $123;
      $124 = HEAP32[$105>>2]|0;
      $125 = (($124) + 1|0);
      HEAP32[$105>>2] = $125;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($105,$101,1);
   } else {
    $126 = HEAP32[$converter$i$i17>>2]|0;
    $127 = ($126|0)==(0|0);
    if (!($127)) {
     (FUNCTION_TABLE_iii[$126 & 4095]($101,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $128 = (($this) + 71|0);
 $129 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773304,$47,$converter$i$i17,0)|0);
 $130 = ($129|0)==(0);
 if ($130) {
  STACKTOP = sp;return;
 }
 $131 = ($129|0)>(0);
 do {
  if ($131) {
   $132 = (($transfer) + 12|0);
   $133 = (($transfer) + 80|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = (($134) + 12|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = (($transfer) + 16|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = (($transfer) + 28|0);
   $140 = HEAP32[$139>>2]|0;
   $141 = (($transfer) + 32|0);
   $142 = HEAP32[$141>>2]|0;
   $143 = Math_imul($142, $140)|0;
   $$sum$i$i$i$i$i18 = (($136) - ($143))|0;
   $144 = (($138) + ($$sum$i$i$i$i$i18)|0);
   HEAP32[$132>>2] = $144;
   $145 = ($$sum$i$i$i$i$i18|0)<(0);
   if (!($145)) {
    $$sum1$i$i$i$i$i19 = (($$sum$i$i$i$i$i18) + 1)|0;
    $146 = (($138) + ($$sum1$i$i$i$i$i19)|0);
    $147 = (($transfer) + 20|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ($146>>>0)>($148>>>0);
    if (!($149)) {
     $150 = HEAP8[$144>>0]|0;
     HEAP8[$128>>0] = $150;
     $151 = HEAP32[$132>>2]|0;
     $152 = (($151) + 1|0);
     HEAP32[$132>>2] = $152;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($132,$128,1);
  } else {
   $153 = HEAP32[$converter$i$i17>>2]|0;
   $154 = ($153|0)==(0|0);
   if (!($154)) {
    (FUNCTION_TABLE_iii[$153 & 4095]($128,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $i$03 = $61;
     while(1) {
      $64 = HEAP32[$51>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $50)|0;
      $67 = (($66) + ($56))|0;
      $68 = HEAP32[$46>>2]|0;
      $69 = (($68) + 20|0);
      HEAP32[$69>>2] = $67;
      $70 = (($68) + 12|0);
      HEAP32[$70>>2] = $67;
      $71 = (($68) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$68);
      $72 = $1;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 4)|0;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = $71;
      $79 = $78;
      HEAP32[$79>>2] = $74;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = $77;
      $82 = HEAP32[$51>>2]|0;
      $83 = HEAP32[$82>>2]|0;
      $84 = (($83) + 1)|0;
      HEAP32[$82>>2] = $84;
      __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$03,$this);
      $85 = (($i$03) + 8|0);
      $86 = ($85|0)==($36|0);
      if ($86) {
       break;
      } else {
       $i$03 = $85;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $87 = HEAP32[$data>>2]|0;
   $88 = $87;
   $89 = HEAP32[$87>>2]|0;
   $90 = (($89) + ($88))|0;
   $91 = $90;
   $92 = (($87) + 4|0);
   HEAP32[$92>>2] = $91;
   $93 = ($91|0)==($36|0);
   if (!($93)) {
    $i$14 = $91;
    while(1) {
     $94 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $95 = ($94|0)==(0);
     if (!($95)) {
      $96 = ($94|0)>(0);
      if ($96) {
       __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$14,$this);
      } else {
       $97 = HEAP32[$converter$i$i>>2]|0;
       $98 = ($97|0)==(0|0);
       if (!($98)) {
        (FUNCTION_TABLE_iii[$97 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($i$14) + 8|0);
     $100 = ($99|0)==($36|0);
     if ($100) {
      break;
     } else {
      $i$14 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0;
 var $converter$i$i = 0, $converter$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i$i = sp + 16|0;
 $ArrayTransfer$i$i$i = sp;
 $converter$i$i = sp + 12|0;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,12,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = 0;$15 = 0;
  } else {
   HEAP32[$6>>2] = 0;
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 8|0);
   HEAP32[$9>>2] = 0;
   $10 = $6;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $6;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phiZ2D = $14;$18 = $13;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$18 = $0;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phiZ2D>>2] = $19;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774376,$converter$i$i,1)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = ($20|0)>(0);
 if ($22) {
  $23 = (($19) + 4|0);
  $24 = (($transfer) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i>>2] = $23;
  $26 = (($ArrayTransfer$i$i$i) + 4|0);
  HEAP32[$26>>2] = $19;
  $27 = (($ArrayTransfer$i$i$i) + 8|0);
  HEAP32[$27>>2] = $25;
  $28 = HEAP32[580760>>2]|0;
  $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773320,$28,$converter$i$i$i$i$i,1)|0);
  $30 = ($29|0)==(0);
  if (!($30)) {
   $31 = ($29|0)>(0);
   if ($31) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i,0);
   } else {
    $32 = HEAP32[$converter$i$i$i$i$i>>2]|0;
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     (FUNCTION_TABLE_iii[$32 & 4095]($ArrayTransfer$i$i$i,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $34 = HEAP32[$converter$i$i>>2]|0;
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   $36 = $17;
   (FUNCTION_TABLE_iii[$34 & 4095]($36,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $i$03 = $61;
     while(1) {
      $64 = HEAP32[$51>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $50)|0;
      $67 = (($66) + ($56))|0;
      $68 = HEAP32[$46>>2]|0;
      $69 = (($68) + 20|0);
      HEAP32[$69>>2] = $67;
      $70 = (($68) + 12|0);
      HEAP32[$70>>2] = $67;
      $71 = (($68) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$68);
      $72 = $1;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 4)|0;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = $71;
      $79 = $78;
      HEAP32[$79>>2] = $74;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = $77;
      $82 = HEAP32[$51>>2]|0;
      $83 = HEAP32[$82>>2]|0;
      $84 = (($83) + 1)|0;
      HEAP32[$82>>2] = $84;
      __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$03,$this);
      $85 = (($i$03) + 8|0);
      $86 = ($85|0)==($36|0);
      if ($86) {
       break;
      } else {
       $i$03 = $85;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $87 = HEAP32[$data>>2]|0;
   $88 = $87;
   $89 = HEAP32[$87>>2]|0;
   $90 = (($89) + ($88))|0;
   $91 = $90;
   $92 = (($87) + 4|0);
   HEAP32[$92>>2] = $91;
   $93 = ($91|0)==($36|0);
   if (!($93)) {
    $i$14 = $91;
    while(1) {
     $94 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $95 = ($94|0)==(0);
     if (!($95)) {
      $96 = ($94|0)>(0);
      if ($96) {
       __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($i$14,$this);
      } else {
       $97 = HEAP32[$converter$i$i>>2]|0;
       $98 = ($97|0)==(0|0);
       if (!($98)) {
        (FUNCTION_TABLE_iii[$97 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $99 = (($i$14) + 8|0);
     $100 = ($99|0)==($36|0);
     if ($100) {
      break;
     } else {
      $i$14 = $99;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation21BlendTreeNodeConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,64,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $18 = 0;$20 = 0;
  } else {
   HEAP32[$6>>2] = 0;
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = -1;
   $9 = (($6) + 8|0);
   HEAP32[$9>>2] = -1;
   $10 = (($6) + 12|0);
   $11 = (($6) + 48|0);
   dest=$10+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   HEAP32[$11>>2] = -1;
   $12 = (($6) + 52|0);
   HEAPF32[$12>>2] = Math_fround(0.0);
   $13 = (($6) + 56|0);
   HEAPF32[$13>>2] = Math_fround(0.0);
   $14 = (($6) + 60|0);
   HEAP8[$14>>0] = 0;
   $15 = $6;
   $16 = $data;
   $17 = (($15) - ($16))|0;
   $18 = $17;$20 = $6;
  }
  HEAP32[$data>>2] = $18;
  $19 = (($data) + 4|0);
  HEAP32[$19>>2] = $20;
  $$pre$phiZ2D = $19;$23 = $18;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$23 = $0;
 }
 $21 = $data;
 $22 = (($23) + ($21))|0;
 $24 = $22;
 HEAP32[$$pre$phiZ2D>>2] = $24;
 $25 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774400,$converter$i$i,1)|0);
 $26 = ($25|0)==(0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = ($25|0)>(0);
 if ($27) {
  __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI14SafeBinaryReadEEvRT_($24,$transfer);
 } else {
  $28 = HEAP32[$converter$i$i>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = $22;
   (FUNCTION_TABLE_iii[$28 & 4095]($30,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre$i = 0, $$pre$i5 = 0, $$pre$phi$i7Z2D = 0, $$pre$phi$iZ2D = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i$i2 = 0, $converter$i$i$i4 = 0, $converter$i$i8 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i8 = sp + 16|0;
 $converter$i$i$i4 = sp;
 $converter$i$i$i2 = sp + 12|0;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,773336,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$0,773352,0);
 $1 = (($this) + 8|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$1,773368,0);
 $2 = (($this) + 16|0);
 $3 = (($this) + 12|0);
 $4 = (($transfer) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$converter$i$i$i4>>2] = $2;
 $6 = (($converter$i$i$i4) + 4|0);
 HEAP32[$6>>2] = $3;
 $7 = (($converter$i$i$i4) + 8|0);
 HEAP32[$7>>2] = $5;
 $8 = HEAP32[580760>>2]|0;
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773384,$8,$converter$i$i8,1)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = ($9|0)>(0);
  if ($11) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($transfer,$converter$i$i$i4,0);
  } else {
   $12 = HEAP32[$converter$i$i8>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    (FUNCTION_TABLE_iii[$12 & 4095]($converter$i$i$i4,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $14 = (($this) + 24|0);
 $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773400,774192,$converter$i$i8,1)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = ($15|0)>(0);
  if ($17) {
   __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation19Blend1dDataConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($14,$transfer);
  } else {
   $18 = HEAP32[$converter$i$i8>>2]|0;
   $19 = ($18|0)==(0|0);
   if (!($19)) {
    (FUNCTION_TABLE_iii[$18 & 4095]($14,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $20 = (($this) + 32|0);
 $21 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773416,774192,$converter$i$i8,1)|0);
 $22 = ($21|0)==(0);
 if (!($22)) {
  $23 = ($21|0)>(0);
  if ($23) {
   $24 = HEAP32[$20>>2]|0;
   $25 = ($24|0)==(0);
   if ($25) {
    $26 = HEAP32[$4>>2]|0;
    $27 = HEAP32[$26>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    $29 = (FUNCTION_TABLE_iiii[$28 & 2047]($26,60,4)|0);
    $30 = ($29|0)==(0|0);
    if ($30) {
     $34 = 0;$36 = 0;
    } else {
     dest=$29+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     $31 = $29;
     $32 = $20;
     $33 = (($31) - ($32))|0;
     $34 = $33;$36 = $29;
    }
    HEAP32[$20>>2] = $34;
    $35 = (($this) + 36|0);
    HEAP32[$35>>2] = $36;
    $$pre$phi$iZ2D = $35;$39 = $34;
   } else {
    $$pre$i = (($this) + 36|0);
    $$pre$phi$iZ2D = $$pre$i;$39 = $24;
   }
   $37 = $20;
   $38 = (($39) + ($37))|0;
   $40 = $38;
   HEAP32[$$pre$phi$iZ2D>>2] = $40;
   $41 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774448,$converter$i$i$i2,1)|0);
   $42 = ($41|0)==(0);
   if (!($42)) {
    $43 = ($41|0)>(0);
    if ($43) {
     __ZN7mecanim9animation19Blend2dDataConstant8TransferI14SafeBinaryReadEEvRT_($40,$transfer);
    } else {
     $44 = HEAP32[$converter$i$i$i2>>2]|0;
     $45 = ($44|0)==(0|0);
     if (!($45)) {
      $46 = $38;
      (FUNCTION_TABLE_iii[$44 & 4095]($46,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
  } else {
   $47 = HEAP32[$converter$i$i8>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    (FUNCTION_TABLE_iii[$47 & 4095]($20,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $49 = (($this) + 40|0);
 $50 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773432,774192,$converter$i$i8,1)|0);
 $51 = ($50|0)==(0);
 if (!($51)) {
  $52 = ($50|0)>(0);
  if ($52) {
   $53 = HEAP32[$49>>2]|0;
   $54 = ($53|0)==(0);
   if ($54) {
    $55 = HEAP32[$4>>2]|0;
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$56>>2]|0;
    $58 = (FUNCTION_TABLE_iiii[$57 & 2047]($55,16,4)|0);
    $59 = ($58|0)==(0|0);
    if ($59) {
     $63 = 0;$65 = 0;
    } else {
     ;HEAP32[$58+0>>2]=0|0;HEAP32[$58+4>>2]=0|0;HEAP32[$58+8>>2]=0|0;HEAP8[$58+12>>0]=0|0;
     $60 = $58;
     $61 = $49;
     $62 = (($60) - ($61))|0;
     $63 = $62;$65 = $58;
    }
    HEAP32[$49>>2] = $63;
    $64 = (($this) + 44|0);
    HEAP32[$64>>2] = $65;
    $$pre$phi$i7Z2D = $64;$68 = $63;
   } else {
    $$pre$i5 = (($this) + 44|0);
    $$pre$phi$i7Z2D = $$pre$i5;$68 = $53;
   }
   $66 = $49;
   $67 = (($68) + ($66))|0;
   $69 = $67;
   HEAP32[$$pre$phi$i7Z2D>>2] = $69;
   $70 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774424,$converter$i$i$i4,1)|0);
   $71 = ($70|0)==(0);
   if (!($71)) {
    $72 = ($70|0)>(0);
    if ($72) {
     __ZN7mecanim9animation23BlendDirectDataConstant8TransferI14SafeBinaryReadEEvRT_($69,$transfer);
    } else {
     $73 = HEAP32[$converter$i$i$i4>>2]|0;
     $74 = ($73|0)==(0|0);
     if (!($74)) {
      $75 = $67;
      (FUNCTION_TABLE_iii[$73 & 4095]($75,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
  } else {
   $76 = HEAP32[$converter$i$i8>>2]|0;
   $77 = ($76|0)==(0|0);
   if (!($77)) {
    (FUNCTION_TABLE_iii[$76 & 4095]($49,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $78 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$78,773456,0);
 $79 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$79,773472,0);
 $80 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$80,773240,0);
 $81 = (($this) + 60|0);
 $82 = HEAP32[580544>>2]|0;
 $83 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773304,$82,$converter$i$i8,0)|0);
 $84 = ($83|0)==(0);
 if ($84) {
  __ZN7mecanim9animation21BlendTreeNodeConstant35Transfer_4_0_BackwardsCompatibilityI14SafeBinaryReadEEvRT_($this,$transfer);
  STACKTOP = sp;return;
 }
 $85 = ($83|0)>(0);
 do {
  if ($85) {
   $86 = (($transfer) + 12|0);
   $87 = (($transfer) + 80|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($88) + 12|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($transfer) + 16|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($transfer) + 28|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = (($transfer) + 32|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = Math_imul($96, $94)|0;
   $$sum$i$i$i$i$i = (($90) - ($97))|0;
   $98 = (($92) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$86>>2] = $98;
   $99 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($99)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $100 = (($92) + ($$sum1$i$i$i$i$i)|0);
    $101 = (($transfer) + 20|0);
    $102 = HEAP32[$101>>2]|0;
    $103 = ($100>>>0)>($102>>>0);
    if (!($103)) {
     $104 = HEAP8[$98>>0]|0;
     HEAP8[$81>>0] = $104;
     $105 = HEAP32[$86>>2]|0;
     $106 = (($105) + 1|0);
     HEAP32[$86>>2] = $106;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($86,$81,1);
  } else {
   $107 = HEAP32[$converter$i$i8>>2]|0;
   $108 = ($107|0)==(0|0);
   if (!($108)) {
    (FUNCTION_TABLE_iii[$107 & 4095]($81,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 __ZN7mecanim9animation21BlendTreeNodeConstant35Transfer_4_0_BackwardsCompatibilityI14SafeBinaryReadEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21BlendTreeNodeConstant35Transfer_4_0_BackwardsCompatibilityI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i = 0, $converter$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i = sp + 12|0;
 $ArrayTransfer$i = sp;
 $0 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,1)|0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($transfer) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_iiii[$7 & 2047]($5,12,4)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   $15 = 0;$17 = 0;
  } else {
   HEAP32[$8>>2] = 0;
   $10 = (($8) + 4|0);
   HEAP32[$10>>2] = 0;
   $11 = (($8) + 8|0);
   HEAP32[$11>>2] = 0;
   $12 = $8;
   $13 = $1;
   $14 = (($12) - ($13))|0;
   $15 = $14;$17 = $8;
  }
  HEAP32[$1>>2] = $15;
  $16 = (($this) + 28|0);
  HEAP32[$16>>2] = $17;
  $$pre$phi2Z2D = $4;$$pre$phiZ2D = $16;$20 = $15;
 } else {
  $$pre = (($this) + 28|0);
  $$pre1 = (($transfer) + 4|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;$20 = $2;
 }
 $18 = $1;
 $19 = (($20) + ($18))|0;
 $21 = $19;
 $22 = (($21) + 4|0);
 HEAP32[$$pre$phiZ2D>>2] = $21;
 $23 = HEAP32[$$pre$phi2Z2D>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $22;
 $24 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$24>>2] = $21;
 $25 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = HEAP32[580760>>2]|0;
 $27 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773488,$26,$converter$i$i$i,1)|0);
 $28 = ($27|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ($27|0)>(0);
 if ($29) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
 } else {
  $30 = HEAP32[$converter$i$i$i>>2]|0;
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   (FUNCTION_TABLE_iii[$30 & 4095]($ArrayTransfer$i,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation23BlendDirectDataConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ArrayTransfer$i = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $ArrayTransfer$i = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $0;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773512,$5,$converter$i$i,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i,0);
  } else {
   $9 = HEAP32[$converter$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($ArrayTransfer$i,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 12|0);
 $12 = HEAP32[580544>>2]|0;
 $13 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773544,$12,$converter$i$i,0)|0);
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = ($13|0)>(0);
 do {
  if ($15) {
   $16 = (($transfer) + 12|0);
   $17 = (($transfer) + 80|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($transfer) + 16|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($transfer) + 28|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($transfer) + 32|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = Math_imul($26, $24)|0;
   $$sum$i$i$i$i$i = (($20) - ($27))|0;
   $28 = (($22) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$16>>2] = $28;
   $29 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($29)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $30 = (($22) + ($$sum1$i$i$i$i$i)|0);
    $31 = (($transfer) + 20|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($30>>>0)>($32>>>0);
    if (!($33)) {
     $34 = HEAP8[$28>>0]|0;
     HEAP8[$11>>0] = $34;
     $35 = HEAP32[$16>>2]|0;
     $36 = (($35) + 1|0);
     HEAP32[$16>>2] = $36;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($16,$11,1);
  } else {
   $37 = HEAP32[$converter$i$i>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    (FUNCTION_TABLE_iii[$37 & 4095]($11,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation19Blend2dDataConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i10 = 0, $converter$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i$i9 = sp + 12|0;
 $ArrayTransfer$i10 = sp;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i10>>2] = $0;
 $3 = (($ArrayTransfer$i10) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i10) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 $6 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773568,$5,$converter$i$i$i9,1)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = ($6|0)>(0);
  if ($8) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i10,0);
  } else {
   $9 = HEAP32[$converter$i$i$i9>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    (FUNCTION_TABLE_iii[$9 & 4095]($ArrayTransfer$i10,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $11 = (($this) + 16|0);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i10>>2] = $11;
 $14 = (($ArrayTransfer$i10) + 4|0);
 HEAP32[$14>>2] = $12;
 $15 = (($ArrayTransfer$i10) + 8|0);
 HEAP32[$15>>2] = $13;
 $16 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773592,$5,$converter$i$i$i9,1)|0);
 $17 = ($16|0)==(0);
 if (!($17)) {
  $18 = ($16|0)>(0);
  if ($18) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i10,0);
  } else {
   $19 = HEAP32[$converter$i$i$i9>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    (FUNCTION_TABLE_iii[$19 & 4095]($ArrayTransfer$i10,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $21 = (($this) + 28|0);
 $22 = (($this) + 24|0);
 $23 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i10>>2] = $21;
 $24 = (($ArrayTransfer$i10) + 4|0);
 HEAP32[$24>>2] = $22;
 $25 = (($ArrayTransfer$i10) + 8|0);
 HEAP32[$25>>2] = $23;
 $26 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773616,$5,$converter$i$i$i9,1)|0);
 $27 = ($26|0)==(0);
 if (!($27)) {
  $28 = ($26|0)>(0);
  if ($28) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i10,0);
  } else {
   $29 = HEAP32[$converter$i$i$i9>>2]|0;
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    (FUNCTION_TABLE_iii[$29 & 4095]($ArrayTransfer$i10,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $31 = (($this) + 40|0);
 $32 = (($this) + 36|0);
 $33 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i10>>2] = $31;
 $34 = (($ArrayTransfer$i10) + 4|0);
 HEAP32[$34>>2] = $32;
 $35 = (($ArrayTransfer$i10) + 8|0);
 HEAP32[$35>>2] = $33;
 $36 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773640,$5,$converter$i$i$i9,1)|0);
 $37 = ($36|0)==(0);
 if (!($37)) {
  $38 = ($36|0)>(0);
  if ($38) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i10,0);
  } else {
   $39 = HEAP32[$converter$i$i$i9>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    (FUNCTION_TABLE_iii[$39 & 4095]($ArrayTransfer$i10,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $41 = (($this) + 52|0);
 $42 = (($this) + 48|0);
 $43 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i10>>2] = $41;
 $44 = (($ArrayTransfer$i10) + 4|0);
 HEAP32[$44>>2] = $42;
 $45 = (($ArrayTransfer$i10) + 8|0);
 HEAP32[$45>>2] = $43;
 $46 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773672,$5,$converter$i$i$i9,1)|0);
 $47 = ($46|0)==(0);
 if ($47) {
  STACKTOP = sp;return;
 }
 $48 = ($46|0)>(0);
 if ($48) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i10,0);
 } else {
  $49 = HEAP32[$converter$i$i$i9>>2]|0;
  $50 = ($49|0)==(0|0);
  if (!($50)) {
   (FUNCTION_TABLE_iii[$49 & 4095]($ArrayTransfer$i10,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i$i$i3 = 0, $converter$i$i = 0, $converter$i$i$i$i$i2 = 0, $i$06 = 0, $i$17 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i$i2 = sp + 28|0;
 $ArrayTransfer$i$i$i3 = sp + 16|0;
 $converter$i$i = sp + 8|0;
 $size = sp + 12|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $28 = (($9) + 4|0);
  HEAP32[$28>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = ($6*12)|0;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$26 = 0;
  } else {
   $17 = (($15) + (($6*12)|0)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    HEAP32[$20>>2] = 0;
    $21 = (($18) + 12|0);
    $22 = ($21|0)==($17|0);
    if ($22) {
     break;
    } else {
     $18 = $21;
    }
   }
   $23 = $15;
   $24 = $9;
   $25 = (($23) - ($24))|0;
   $$0$i1$i$i = $15;$26 = $25;
  }
  HEAP32[$9>>2] = $26;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = $$0$i1$i$i;
 }
 $29 = HEAP32[$data>>2]|0;
 $30 = $29;
 $31 = HEAP32[$29>>2]|0;
 $32 = (($31) + ($30))|0;
 $33 = $32;
 $34 = (($29) + 4|0);
 HEAP32[$34>>2] = $33;
 $35 = HEAP32[$2>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($33) + (($36*12)|0)|0);
 $38 = HEAP32[$size>>2]|0;
 $39 = ($38|0)==(0);
 do {
  if (!($39)) {
   $40 = HEAP32[$data>>2]|0;
   $41 = $40;
   $42 = HEAP32[$40>>2]|0;
   $43 = (($42) + ($41))|0;
   $44 = $43;
   $45 = (($40) + 4|0);
   HEAP32[$45>>2] = $44;
   $46 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774472,0,1)|0);
   $47 = (($this) + 80|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (__ZNK16TypeTreeIterator7GetNodeEv($48)|0);
   $50 = (($49) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($this) + 84|0);
   $53 = HEAP32[$52>>2]|0;
   HEAP32[$53>>2] = 0;
   $54 = ($46|0)==(2);
   if ($54) {
    $55 = HEAP32[$47>>2]|0;
    $56 = (($55) + 12|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = HEAP32[$data>>2]|0;
    $59 = $58;
    $60 = HEAP32[$58>>2]|0;
    $61 = (($60) + ($59))|0;
    $62 = $61;
    $63 = (($58) + 4|0);
    HEAP32[$63>>2] = $62;
    $64 = ($62|0)==($37|0);
    if (!($64)) {
     $65 = (($this) + 4|0);
     $66 = (($ArrayTransfer$i$i$i3) + 4|0);
     $67 = (($ArrayTransfer$i$i$i3) + 8|0);
     $68 = HEAP32[580760>>2]|0;
     $i$06 = $62;
     while(1) {
      $69 = HEAP32[$52>>2]|0;
      $70 = HEAP32[$69>>2]|0;
      $71 = Math_imul($70, $51)|0;
      $72 = (($71) + ($57))|0;
      $73 = HEAP32[$47>>2]|0;
      $74 = (($73) + 20|0);
      HEAP32[$74>>2] = $72;
      $75 = (($73) + 12|0);
      HEAP32[$75>>2] = $72;
      $76 = (($73) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$73);
      $77 = $1;
      $78 = $77;
      $79 = HEAP32[$78>>2]|0;
      $80 = (($77) + 4)|0;
      $81 = $80;
      $82 = HEAP32[$81>>2]|0;
      $83 = $76;
      $84 = $83;
      HEAP32[$84>>2] = $79;
      $85 = (($83) + 4)|0;
      $86 = $85;
      HEAP32[$86>>2] = $82;
      $87 = HEAP32[$52>>2]|0;
      $88 = HEAP32[$87>>2]|0;
      $89 = (($88) + 1)|0;
      HEAP32[$87>>2] = $89;
      $90 = (($i$06) + 4|0);
      $91 = HEAP32[$65>>2]|0;
      HEAP32[$ArrayTransfer$i$i$i3>>2] = $90;
      HEAP32[$66>>2] = $i$06;
      HEAP32[$67>>2] = $91;
      $92 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,773704,$68,$converter$i$i$i$i$i2,1)|0);
      $93 = ($92|0)==(0);
      if (!($93)) {
       $94 = ($92|0)>(0);
       if ($94) {
        __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i3,0);
       } else {
        $95 = HEAP32[$converter$i$i$i$i$i2>>2]|0;
        $96 = ($95|0)==(0|0);
        if (!($96)) {
         (FUNCTION_TABLE_iii[$95 & 4095]($ArrayTransfer$i$i$i3,$this)|0);
        }
       }
       __ZN14SafeBinaryRead11EndTransferEv($this);
      }
      $97 = (($i$06) + 12|0);
      $98 = ($97|0)==($37|0);
      if ($98) {
       break;
      } else {
       $i$06 = $97;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $99 = HEAP32[$data>>2]|0;
   $100 = $99;
   $101 = HEAP32[$99>>2]|0;
   $102 = (($101) + ($100))|0;
   $103 = $102;
   $104 = (($99) + 4|0);
   HEAP32[$104>>2] = $103;
   $105 = ($103|0)==($37|0);
   if (!($105)) {
    $106 = (($this) + 4|0);
    $107 = (($ArrayTransfer$i$i$i3) + 4|0);
    $108 = (($ArrayTransfer$i$i$i3) + 8|0);
    $109 = HEAP32[580760>>2]|0;
    $i$17 = $103;
    while(1) {
     $110 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774472,$converter$i$i,1)|0);
     $111 = ($110|0)==(0);
     if (!($111)) {
      $112 = ($110|0)>(0);
      if ($112) {
       $113 = (($i$17) + 4|0);
       $114 = HEAP32[$106>>2]|0;
       HEAP32[$ArrayTransfer$i$i$i3>>2] = $113;
       HEAP32[$107>>2] = $i$17;
       HEAP32[$108>>2] = $114;
       $115 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,773704,$109,$converter$i$i$i$i$i2,1)|0);
       $116 = ($115|0)==(0);
       if (!($116)) {
        $117 = ($115|0)>(0);
        if ($117) {
         __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i3,0);
        } else {
         $118 = HEAP32[$converter$i$i$i$i$i2>>2]|0;
         $119 = ($118|0)==(0|0);
         if (!($119)) {
          (FUNCTION_TABLE_iii[$118 & 4095]($ArrayTransfer$i$i$i3,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $120 = HEAP32[$converter$i$i>>2]|0;
       $121 = ($120|0)==(0|0);
       if (!($121)) {
        (FUNCTION_TABLE_iii[$120 & 4095]($i$17,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $122 = (($i$17) + 12|0);
     $123 = ($122|0)==($37|0);
     if ($123) {
      break;
     } else {
      $i$17 = $122;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI8Vector2fEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAPF32[$18>>2] = Math_fround(0.0);
    $19 = (($18) + 4|0);
    HEAPF32[$19>>2] = Math_fround(0.0);
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = HEAP32[580768>>2]|0;
   $46 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,$45,0,1)|0);
   $47 = (($this) + 80|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (__ZNK16TypeTreeIterator7GetNodeEv($48)|0);
   $50 = (($49) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($this) + 84|0);
   $53 = HEAP32[$52>>2]|0;
   HEAP32[$53>>2] = 0;
   $54 = ($46|0)==(2);
   if ($54) {
    $55 = HEAP32[$47>>2]|0;
    $56 = (($55) + 12|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = HEAP32[$data>>2]|0;
    $59 = $58;
    $60 = HEAP32[$58>>2]|0;
    $61 = (($60) + ($59))|0;
    $62 = $61;
    $63 = (($58) + 4|0);
    HEAP32[$63>>2] = $62;
    $64 = ($62|0)==($36|0);
    if (!($64)) {
     $i$03 = $62;
     while(1) {
      $65 = HEAP32[$52>>2]|0;
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $51)|0;
      $68 = (($67) + ($57))|0;
      $69 = HEAP32[$47>>2]|0;
      $70 = (($69) + 20|0);
      HEAP32[$70>>2] = $68;
      $71 = (($69) + 12|0);
      HEAP32[$71>>2] = $68;
      $72 = (($69) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$69);
      $73 = $1;
      $74 = $73;
      $75 = HEAP32[$74>>2]|0;
      $76 = (($73) + 4)|0;
      $77 = $76;
      $78 = HEAP32[$77>>2]|0;
      $79 = $72;
      $80 = $79;
      HEAP32[$80>>2] = $75;
      $81 = (($79) + 4)|0;
      $82 = $81;
      HEAP32[$82>>2] = $78;
      $83 = HEAP32[$52>>2]|0;
      $84 = HEAP32[$83>>2]|0;
      $85 = (($84) + 1)|0;
      HEAP32[$83>>2] = $85;
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$03,772592,0);
      $86 = (($i$03) + 4|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$86,772600,0);
      $87 = (($i$03) + 8|0);
      $88 = ($87|0)==($36|0);
      if ($88) {
       break;
      } else {
       $i$03 = $87;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $89 = HEAP32[$data>>2]|0;
   $90 = $89;
   $91 = HEAP32[$89>>2]|0;
   $92 = (($91) + ($90))|0;
   $93 = $92;
   $94 = (($89) + 4|0);
   HEAP32[$94>>2] = $93;
   $95 = ($93|0)==($36|0);
   if (!($95)) {
    $i$14 = $93;
    while(1) {
     $96 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,$45,$converter$i$i,1)|0);
     $97 = ($96|0)==(0);
     if (!($97)) {
      $98 = ($96|0)>(0);
      if ($98) {
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$i$14,772592,0);
       $99 = (($i$14) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$99,772600,0);
      } else {
       $100 = HEAP32[$converter$i$i>>2]|0;
       $101 = ($100|0)==(0|0);
       if (!($101)) {
        (FUNCTION_TABLE_iii[$100 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $102 = (($i$14) + 8|0);
     $103 = ($102|0)==($36|0);
     if ($103) {
      break;
     } else {
      $i$14 = $102;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim9animation19Blend1dDataConstantEEE8TransferI14SafeBinaryReadEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0;
 var $converter$i$i = 0, $converter$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i$i = sp + 16|0;
 $ArrayTransfer$i$i$i = sp;
 $converter$i$i = sp + 12|0;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,12,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = 0;$15 = 0;
  } else {
   HEAP32[$6>>2] = 0;
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 8|0);
   HEAP32[$9>>2] = 0;
   $10 = $6;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $6;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phiZ2D = $14;$18 = $13;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$18 = $0;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phiZ2D>>2] = $19;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774496,$converter$i$i,1)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = ($20|0)>(0);
 if ($22) {
  $23 = (($19) + 4|0);
  $24 = (($transfer) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i>>2] = $23;
  $26 = (($ArrayTransfer$i$i$i) + 4|0);
  HEAP32[$26>>2] = $19;
  $27 = (($ArrayTransfer$i$i$i) + 8|0);
  HEAP32[$27>>2] = $25;
  $28 = HEAP32[580760>>2]|0;
  $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773488,$28,$converter$i$i$i$i$i,1)|0);
  $30 = ($29|0)==(0);
  if (!($30)) {
   $31 = ($29|0)>(0);
   if ($31) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIfEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i,0);
   } else {
    $32 = HEAP32[$converter$i$i$i$i$i>>2]|0;
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     (FUNCTION_TABLE_iii[$32 & 4095]($ArrayTransfer$i$i$i,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $34 = HEAP32[$converter$i$i>>2]|0;
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   $36 = $17;
   (FUNCTION_TABLE_iii[$34 & 4095]($36,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim12statemachine16LeafInfoConstantEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ArrayTransfer$i$i$i3 = 0, $converter$i$i = 0, $converter$i$i$i$i$i2 = 0, $i$06 = 0, $i$17 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i$i2 = sp + 28|0;
 $ArrayTransfer$i$i$i3 = sp + 16|0;
 $converter$i$i = sp + 8|0;
 $size = sp + 12|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 4;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$24 = 0;
  } else {
   $17 = (($15) + ($6<<4)|0);
   $18 = $15;
   while(1) {
    ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;
    $19 = (($18) + 16|0);
    $20 = ($19|0)==($17|0);
    if ($20) {
     break;
    } else {
     $18 = $19;
    }
   }
   $21 = $15;
   $22 = $9;
   $23 = (($21) - ($22))|0;
   $$0$i1$i$i = $15;$24 = $23;
  }
  HEAP32[$9>>2] = $24;
  $25 = (($9) + 4|0);
  HEAP32[$25>>2] = $$0$i1$i$i;
 }
 $27 = HEAP32[$data>>2]|0;
 $28 = $27;
 $29 = HEAP32[$27>>2]|0;
 $30 = (($29) + ($28))|0;
 $31 = $30;
 $32 = (($27) + 4|0);
 HEAP32[$32>>2] = $31;
 $33 = HEAP32[$2>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($31) + ($34<<4)|0);
 $36 = HEAP32[$size>>2]|0;
 $37 = ($36|0)==(0);
 do {
  if (!($37)) {
   $38 = HEAP32[$data>>2]|0;
   $39 = $38;
   $40 = HEAP32[$38>>2]|0;
   $41 = (($40) + ($39))|0;
   $42 = $41;
   $43 = (($38) + 4|0);
   HEAP32[$43>>2] = $42;
   $44 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774520,0,1)|0);
   $45 = (($this) + 80|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (__ZNK16TypeTreeIterator7GetNodeEv($46)|0);
   $48 = (($47) + 12|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($this) + 84|0);
   $51 = HEAP32[$50>>2]|0;
   HEAP32[$51>>2] = 0;
   $52 = ($44|0)==(2);
   if ($52) {
    $53 = HEAP32[$45>>2]|0;
    $54 = (($53) + 12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$data>>2]|0;
    $57 = $56;
    $58 = HEAP32[$56>>2]|0;
    $59 = (($58) + ($57))|0;
    $60 = $59;
    $61 = (($56) + 4|0);
    HEAP32[$61>>2] = $60;
    $62 = ($60|0)==($35|0);
    if (!($62)) {
     $63 = (($this) + 4|0);
     $64 = (($ArrayTransfer$i$i$i3) + 4|0);
     $65 = (($ArrayTransfer$i$i$i3) + 8|0);
     $66 = HEAP32[580760>>2]|0;
     $i$06 = $60;
     while(1) {
      $67 = HEAP32[$50>>2]|0;
      $68 = HEAP32[$67>>2]|0;
      $69 = Math_imul($68, $49)|0;
      $70 = (($69) + ($55))|0;
      $71 = HEAP32[$45>>2]|0;
      $72 = (($71) + 20|0);
      HEAP32[$72>>2] = $70;
      $73 = (($71) + 12|0);
      HEAP32[$73>>2] = $70;
      $74 = (($71) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$71);
      $75 = $1;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = (($75) + 4)|0;
      $79 = $78;
      $80 = HEAP32[$79>>2]|0;
      $81 = $74;
      $82 = $81;
      HEAP32[$82>>2] = $77;
      $83 = (($81) + 4)|0;
      $84 = $83;
      HEAP32[$84>>2] = $80;
      $85 = HEAP32[$50>>2]|0;
      $86 = HEAP32[$85>>2]|0;
      $87 = (($86) + 1)|0;
      HEAP32[$85>>2] = $87;
      $88 = (($i$06) + 4|0);
      $89 = HEAP32[$63>>2]|0;
      HEAP32[$ArrayTransfer$i$i$i3>>2] = $88;
      HEAP32[$64>>2] = $i$06;
      HEAP32[$65>>2] = $89;
      $90 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,773720,$66,$converter$i$i$i$i$i2,1)|0);
      $91 = ($90|0)==(0);
      if (!($91)) {
       $92 = ($90|0)>(0);
       if ($92) {
        __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i3,0);
       } else {
        $93 = HEAP32[$converter$i$i$i$i$i2>>2]|0;
        $94 = ($93|0)==(0|0);
        if (!($94)) {
         (FUNCTION_TABLE_iii[$93 & 4095]($ArrayTransfer$i$i$i3,$this)|0);
        }
       }
       __ZN14SafeBinaryRead11EndTransferEv($this);
      }
      $95 = (($i$06) + 12|0);
      __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$95,773736,0);
      $96 = (($i$06) + 16|0);
      $97 = ($96|0)==($35|0);
      if ($97) {
       break;
      } else {
       $i$06 = $96;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $98 = HEAP32[$data>>2]|0;
   $99 = $98;
   $100 = HEAP32[$98>>2]|0;
   $101 = (($100) + ($99))|0;
   $102 = $101;
   $103 = (($98) + 4|0);
   HEAP32[$103>>2] = $102;
   $104 = ($102|0)==($35|0);
   if (!($104)) {
    $105 = (($this) + 4|0);
    $106 = (($ArrayTransfer$i$i$i3) + 4|0);
    $107 = (($ArrayTransfer$i$i$i3) + 8|0);
    $108 = HEAP32[580760>>2]|0;
    $i$17 = $102;
    while(1) {
     $109 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774520,$converter$i$i,1)|0);
     $110 = ($109|0)==(0);
     if (!($110)) {
      $111 = ($109|0)>(0);
      if ($111) {
       $112 = (($i$17) + 4|0);
       $113 = HEAP32[$105>>2]|0;
       HEAP32[$ArrayTransfer$i$i$i3>>2] = $112;
       HEAP32[$106>>2] = $i$17;
       HEAP32[$107>>2] = $113;
       $114 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,773720,$108,$converter$i$i$i$i$i2,1)|0);
       $115 = ($114|0)==(0);
       if (!($115)) {
        $116 = ($114|0)>(0);
        if ($116) {
         __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIjEEEvRT_17TransferMetaFlags($this,$ArrayTransfer$i$i$i3,0);
        } else {
         $117 = HEAP32[$converter$i$i$i$i$i2>>2]|0;
         $118 = ($117|0)==(0|0);
         if (!($118)) {
          (FUNCTION_TABLE_iii[$117 & 4095]($ArrayTransfer$i$i$i3,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $119 = (($i$17) + 12|0);
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$119,773736,0);
      } else {
       $120 = HEAP32[$converter$i$i>>2]|0;
       $121 = ($120|0)==(0|0);
       if (!($121)) {
        (FUNCTION_TABLE_iii[$120 & 4095]($i$17,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $122 = (($i$17) + 16|0);
     $123 = ($122|0)==($35|0);
     if ($123) {
      break;
     } else {
      $i$17 = $122;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation13LayerConstantEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre$phi$i7Z2D = 0, $$pre$phi$iZ2D = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $converter$i$i = 0, $converter$i$i$i2 = 0, $i$010 = 0, $i$112 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = 0;
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $64 = (($this) + 4|0);
     $i$010 = $61;
     while(1) {
      $65 = HEAP32[$51>>2]|0;
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $50)|0;
      $68 = (($67) + ($56))|0;
      $69 = HEAP32[$46>>2]|0;
      $70 = (($69) + 20|0);
      HEAP32[$70>>2] = $68;
      $71 = (($69) + 12|0);
      HEAP32[$71>>2] = $68;
      $72 = (($69) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$69);
      $73 = $1;
      $74 = $73;
      $75 = HEAP32[$74>>2]|0;
      $76 = (($73) + 4)|0;
      $77 = $76;
      $78 = HEAP32[$77>>2]|0;
      $79 = $72;
      $80 = $79;
      HEAP32[$80>>2] = $75;
      $81 = (($79) + 4)|0;
      $82 = $81;
      HEAP32[$82>>2] = $78;
      $83 = HEAP32[$51>>2]|0;
      $84 = HEAP32[$83>>2]|0;
      $85 = (($84) + 1)|0;
      HEAP32[$83>>2] = $85;
      $86 = HEAP32[$i$010>>2]|0;
      $87 = ($86|0)==(0);
      if ($87) {
       $88 = HEAP32[$64>>2]|0;
       $89 = HEAP32[$88>>2]|0;
       $90 = HEAP32[$89>>2]|0;
       $91 = (FUNCTION_TABLE_iiii[$90 & 2047]($88,40,4)|0);
       $92 = ($91|0)==(0|0);
       if ($92) {
        $100 = 0;$102 = 0;
       } else {
        $93 = (($91) + 8|0);
        $94 = (($91) + 28|0);
        HEAP32[$94>>2] = 0;
        $95 = (($91) + 36|0);
        ;HEAP32[$93+0>>2]=0|0;HEAP32[$93+4>>2]=0|0;HEAP32[$93+8>>2]=0|0;HEAP32[$93+12>>2]=0|0;
        HEAP8[$95>>0] = 1;
        $96 = (($91) + 37|0);
        HEAP8[$96>>0] = 0;
        $97 = $91;
        $98 = $i$010;
        $99 = (($97) - ($98))|0;
        $100 = $99;$102 = $91;
       }
       HEAP32[$i$010>>2] = $100;
       $101 = (($i$010) + 4|0);
       HEAP32[$101>>2] = $102;
       $$pre$phi$i7Z2D = $101;$105 = $100;
      } else {
       $$pre$i3 = (($i$010) + 4|0);
       $$pre$phi$i7Z2D = $$pre$i3;$105 = $86;
      }
      $103 = $i$010;
      $104 = (($105) + ($103))|0;
      $106 = $104;
      HEAP32[$$pre$phi$i7Z2D>>2] = $106;
      $107 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774544,$converter$i$i$i2,1)|0);
      $108 = ($107|0)==(0);
      if (!($108)) {
       $109 = ($107|0)>(0);
       if ($109) {
        __ZN7mecanim9animation13LayerConstant8TransferI14SafeBinaryReadEEvRT_($106,$this);
       } else {
        $110 = HEAP32[$converter$i$i$i2>>2]|0;
        $111 = ($110|0)==(0|0);
        if (!($111)) {
         $112 = $104;
         (FUNCTION_TABLE_iii[$110 & 4095]($112,$this)|0);
        }
       }
       __ZN14SafeBinaryRead11EndTransferEv($this);
      }
      $113 = (($i$010) + 8|0);
      $114 = ($113|0)==($36|0);
      if ($114) {
       break;
      } else {
       $i$010 = $113;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $115 = HEAP32[$data>>2]|0;
   $116 = $115;
   $117 = HEAP32[$115>>2]|0;
   $118 = (($117) + ($116))|0;
   $119 = $118;
   $120 = (($115) + 4|0);
   HEAP32[$120>>2] = $119;
   $121 = ($119|0)==($36|0);
   if (!($121)) {
    $122 = (($this) + 4|0);
    $i$112 = $119;
    while(1) {
     $123 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774192,$converter$i$i,1)|0);
     $124 = ($123|0)==(0);
     if (!($124)) {
      $125 = ($123|0)>(0);
      if ($125) {
       $126 = HEAP32[$i$112>>2]|0;
       $127 = ($126|0)==(0);
       if ($127) {
        $128 = HEAP32[$122>>2]|0;
        $129 = HEAP32[$128>>2]|0;
        $130 = HEAP32[$129>>2]|0;
        $131 = (FUNCTION_TABLE_iiii[$130 & 2047]($128,40,4)|0);
        $132 = ($131|0)==(0|0);
        if ($132) {
         $140 = 0;$142 = 0;
        } else {
         $133 = (($131) + 8|0);
         $134 = (($131) + 28|0);
         HEAP32[$134>>2] = 0;
         $135 = (($131) + 36|0);
         ;HEAP32[$133+0>>2]=0|0;HEAP32[$133+4>>2]=0|0;HEAP32[$133+8>>2]=0|0;HEAP32[$133+12>>2]=0|0;
         HEAP8[$135>>0] = 1;
         $136 = (($131) + 37|0);
         HEAP8[$136>>0] = 0;
         $137 = $131;
         $138 = $i$112;
         $139 = (($137) - ($138))|0;
         $140 = $139;$142 = $131;
        }
        HEAP32[$i$112>>2] = $140;
        $141 = (($i$112) + 4|0);
        HEAP32[$141>>2] = $142;
        $$pre$phi$iZ2D = $141;$145 = $140;
       } else {
        $$pre$i = (($i$112) + 4|0);
        $$pre$phi$iZ2D = $$pre$i;$145 = $126;
       }
       $143 = $i$112;
       $144 = (($145) + ($143))|0;
       $146 = $144;
       HEAP32[$$pre$phi$iZ2D>>2] = $146;
       $147 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774544,$converter$i$i$i2,1)|0);
       $148 = ($147|0)==(0);
       if (!($148)) {
        $149 = ($147|0)>(0);
        if ($149) {
         __ZN7mecanim9animation13LayerConstant8TransferI14SafeBinaryReadEEvRT_($146,$this);
        } else {
         $150 = HEAP32[$converter$i$i$i2>>2]|0;
         $151 = ($150|0)==(0|0);
         if (!($151)) {
          $152 = $144;
          (FUNCTION_TABLE_iii[$150 & 4095]($152,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
      } else {
       $153 = HEAP32[$converter$i$i>>2]|0;
       $154 = ($153|0)==(0|0);
       if (!($154)) {
        (FUNCTION_TABLE_iii[$153 & 4095]($i$112,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $155 = (($i$112) + 8|0);
     $156 = ($155|0)==($36|0);
     if ($156) {
      break;
     } else {
      $i$112 = $155;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation13LayerConstant8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i4 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,773752,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$0,773776,0);
 $1 = (($this) + 8|0);
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773808,774600,$converter$i$i3,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$1,773992,0);
   $5 = (($this) + 12|0);
   __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$5,774000,0);
  } else {
   $6 = HEAP32[$converter$i$i3>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    (FUNCTION_TABLE_iii[$6 & 4095]($1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $8 = (($this) + 16|0);
 $9 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773824,774192,$converter$i$i3,1)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = ($9|0)>(0);
  if ($11) {
   __ZN15SerializeTraitsI9OffsetPtrIN7mecanim8skeleton12SkeletonMaskEEE8TransferI14SafeBinaryReadEEvRS4_RT_($8,$transfer);
  } else {
   $12 = HEAP32[$converter$i$i3>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    (FUNCTION_TABLE_iii[$12 & 4095]($8,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $14 = (($this) + 24|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$14,773840,0);
 $15 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$15,773856,0);
 $16 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,773888,0);
 $17 = (($this) + 36|0);
 $18 = HEAP32[580544>>2]|0;
 $19 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773904,$18,$converter$i$i3,0)|0);
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = ($19|0)>(0);
  do {
   if ($21) {
    $22 = (($transfer) + 12|0);
    $23 = (($transfer) + 80|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($transfer) + 16|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($transfer) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($transfer) + 32|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = Math_imul($32, $30)|0;
    $$sum$i$i$i$i$i = (($26) - ($33))|0;
    $34 = (($28) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$22>>2] = $34;
    $35 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($35)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $36 = (($28) + ($$sum1$i$i$i$i$i)|0);
     $37 = (($transfer) + 20|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($36>>>0)>($38>>>0);
     if (!($39)) {
      $40 = HEAP8[$34>>0]|0;
      HEAP8[$17>>0] = $40;
      $41 = HEAP32[$22>>2]|0;
      $42 = (($41) + 1|0);
      HEAP32[$22>>2] = $42;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($22,$17,1);
   } else {
    $43 = HEAP32[$converter$i$i3>>2]|0;
    $44 = ($43|0)==(0|0);
    if (!($44)) {
     (FUNCTION_TABLE_iii[$43 & 4095]($17,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $45 = (($this) + 37|0);
 $46 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773920,$18,$converter$i$i3,0)|0);
 $47 = ($46|0)==(0);
 if ($47) {
  STACKTOP = sp;return;
 }
 $48 = ($46|0)>(0);
 do {
  if ($48) {
   $49 = (($transfer) + 12|0);
   $50 = (($transfer) + 80|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($51) + 12|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($transfer) + 16|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($transfer) + 28|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($transfer) + 32|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = Math_imul($59, $57)|0;
   $$sum$i$i$i$i$i4 = (($53) - ($60))|0;
   $61 = (($55) + ($$sum$i$i$i$i$i4)|0);
   HEAP32[$49>>2] = $61;
   $62 = ($$sum$i$i$i$i$i4|0)<(0);
   if (!($62)) {
    $$sum1$i$i$i$i$i5 = (($$sum$i$i$i$i$i4) + 1)|0;
    $63 = (($55) + ($$sum1$i$i$i$i$i5)|0);
    $64 = (($transfer) + 20|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($63>>>0)>($65>>>0);
    if (!($66)) {
     $67 = HEAP8[$61>>0]|0;
     HEAP8[$45>>0] = $67;
     $68 = HEAP32[$49>>2]|0;
     $69 = (($68) + 1|0);
     HEAP32[$49>>2] = $69;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($49,$45,1);
  } else {
   $70 = HEAP32[$converter$i$i3>>2]|0;
   $71 = ($70|0)==(0|0);
   if (!($71)) {
    (FUNCTION_TABLE_iii[$70 & 4095]($45,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsI9OffsetPtrIN7mecanim8skeleton12SkeletonMaskEEE8TransferI14SafeBinaryReadEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0;
 var $converter$i$i = 0, $converter$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i$i$i = sp + 16|0;
 $ArrayTransfer$i$i$i = sp;
 $converter$i$i = sp + 12|0;
 $0 = HEAP32[$data>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (($transfer) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,12,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $13 = 0;$15 = 0;
  } else {
   HEAP32[$6>>2] = 0;
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = (($6) + 8|0);
   HEAP32[$9>>2] = 0;
   $10 = $6;
   $11 = $data;
   $12 = (($10) - ($11))|0;
   $13 = $12;$15 = $6;
  }
  HEAP32[$data>>2] = $13;
  $14 = (($data) + 4|0);
  HEAP32[$14>>2] = $15;
  $$pre$phiZ2D = $14;$18 = $13;
 } else {
  $$pre = (($data) + 4|0);
  $$pre$phiZ2D = $$pre;$18 = $0;
 }
 $16 = $data;
 $17 = (($18) + ($16))|0;
 $19 = $17;
 HEAP32[$$pre$phiZ2D>>2] = $19;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,772232,774560,$converter$i$i,1)|0);
 $21 = ($20|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = ($20|0)>(0);
 if ($22) {
  $23 = (($19) + 4|0);
  $24 = (($transfer) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$ArrayTransfer$i$i$i>>2] = $23;
  $26 = (($ArrayTransfer$i$i$i) + 4|0);
  HEAP32[$26>>2] = $19;
  $27 = (($ArrayTransfer$i$i$i) + 8|0);
  HEAP32[$27>>2] = $25;
  $28 = HEAP32[580760>>2]|0;
  $29 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,773952,$28,$converter$i$i$i$i$i,1)|0);
  $30 = ($29|0)==(0);
  if (!($30)) {
   $31 = ($29|0)>(0);
   if ($31) {
    __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim8skeleton19SkeletonMaskElementEEEEvRT_17TransferMetaFlags($transfer,$ArrayTransfer$i$i$i,0);
   } else {
    $32 = HEAP32[$converter$i$i$i$i$i>>2]|0;
    $33 = ($32|0)==(0|0);
    if (!($33)) {
     (FUNCTION_TABLE_iii[$32 & 4095]($ArrayTransfer$i$i$i,$transfer)|0);
    }
   }
   __ZN14SafeBinaryRead11EndTransferEv($transfer);
  }
 } else {
  $34 = HEAP32[$converter$i$i>>2]|0;
  $35 = ($34|0)==(0|0);
  if (!($35)) {
   $36 = $17;
   (FUNCTION_TABLE_iii[$34 & 4095]($36,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI22OffsetPtrArrayTransferIN7mecanim8skeleton19SkeletonMaskElementEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$0$i1$i$i = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $converter$i$i = 0, $i$03 = 0, $i$14 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$size>>2] = $4;
 $5 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,774008,774008,$size)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$size>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = ($6|0)==(0);
 $9 = HEAP32[$data>>2]|0;
 if ($8) {
  HEAP32[$9>>2] = 0;
  $27 = (($9) + 4|0);
  HEAP32[$27>>2] = 0;
 } else {
  $10 = (($data) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6 << 3;
  $15 = (FUNCTION_TABLE_iiii[$13 & 2047]($11,$14,4)|0);
  $16 = ($15|0)==(0|0);
  if ($16) {
   $$0$i1$i$i = 0;$25 = 0;
  } else {
   $17 = (($15) + ($6<<3)|0);
   $18 = $15;
   while(1) {
    HEAP32[$18>>2] = 0;
    $19 = (($18) + 4|0);
    HEAPF32[$19>>2] = Math_fround(0.0);
    $20 = (($18) + 8|0);
    $21 = ($20|0)==($17|0);
    if ($21) {
     break;
    } else {
     $18 = $20;
    }
   }
   $22 = $15;
   $23 = $9;
   $24 = (($22) - ($23))|0;
   $$0$i1$i$i = $15;$25 = $24;
  }
  HEAP32[$9>>2] = $25;
  $26 = (($9) + 4|0);
  HEAP32[$26>>2] = $$0$i1$i$i;
 }
 $28 = HEAP32[$data>>2]|0;
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($28) + 4|0);
 HEAP32[$33>>2] = $32;
 $34 = HEAP32[$2>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + ($35<<3)|0);
 $37 = HEAP32[$size>>2]|0;
 $38 = ($37|0)==(0);
 do {
  if (!($38)) {
   $39 = HEAP32[$data>>2]|0;
   $40 = $39;
   $41 = HEAP32[$39>>2]|0;
   $42 = (($41) + ($40))|0;
   $43 = $42;
   $44 = (($39) + 4|0);
   HEAP32[$44>>2] = $43;
   $45 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774576,0,1)|0);
   $46 = (($this) + 80|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (__ZNK16TypeTreeIterator7GetNodeEv($47)|0);
   $49 = (($48) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($this) + 84|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$52>>2] = 0;
   $53 = ($45|0)==(2);
   if ($53) {
    $54 = HEAP32[$46>>2]|0;
    $55 = (($54) + 12|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = HEAP32[$data>>2]|0;
    $58 = $57;
    $59 = HEAP32[$57>>2]|0;
    $60 = (($59) + ($58))|0;
    $61 = $60;
    $62 = (($57) + 4|0);
    HEAP32[$62>>2] = $61;
    $63 = ($61|0)==($36|0);
    if (!($63)) {
     $i$03 = $61;
     while(1) {
      $64 = HEAP32[$51>>2]|0;
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $50)|0;
      $67 = (($66) + ($56))|0;
      $68 = HEAP32[$46>>2]|0;
      $69 = (($68) + 20|0);
      HEAP32[$69>>2] = $67;
      $70 = (($68) + 12|0);
      HEAP32[$70>>2] = $67;
      $71 = (($68) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$68);
      $72 = $1;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 4)|0;
      $76 = $75;
      $77 = HEAP32[$76>>2]|0;
      $78 = $71;
      $79 = $78;
      HEAP32[$79>>2] = $74;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = $77;
      $82 = HEAP32[$51>>2]|0;
      $83 = HEAP32[$82>>2]|0;
      $84 = (($83) + 1)|0;
      HEAP32[$82>>2] = $84;
      __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$i$03,773960,0);
      $85 = (($i$03) + 4|0);
      __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$85,773976,0);
      $86 = (($i$03) + 8|0);
      $87 = ($86|0)==($36|0);
      if ($87) {
       break;
      } else {
       $i$03 = $86;
      }
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $88 = HEAP32[$data>>2]|0;
   $89 = $88;
   $90 = HEAP32[$88>>2]|0;
   $91 = (($90) + ($89))|0;
   $92 = $91;
   $93 = (($88) + 4|0);
   HEAP32[$93>>2] = $92;
   $94 = ($92|0)==($36|0);
   if (!($94)) {
    $i$14 = $92;
    while(1) {
     $95 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,772232,774576,$converter$i$i,1)|0);
     $96 = ($95|0)==(0);
     if (!($96)) {
      $97 = ($95|0)>(0);
      if ($97) {
       __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($this,$i$14,773960,0);
       $98 = (($i$14) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$98,773976,0);
      } else {
       $99 = HEAP32[$converter$i$i>>2]|0;
       $100 = ($99|0)==(0|0);
       if (!($100)) {
        (FUNCTION_TABLE_iii[$99 & 4095]($i$14,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $101 = (($i$14) + 8|0);
     $102 = ($101|0)==($36|0);
     if ($102) {
      break;
     } else {
      $i$14 = $101;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN18AnimatorController8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i$i$i = 0, $p$i$i$i = 0, $size$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $localIdentifier$i$i$i$i$i = sp;
 $size$i$i$i$i = sp + 44|0;
 $p$i$i$i = sp + 40|0;
 __ZN25RuntimeAnimatorController8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,4);
 $0 = (($this) + 88|0);
 $1 = (($transfer) + 4|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 116|0);
 $3 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772080,$3,$2,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 dest=$localIdentifier$i$i$i$i$i+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772064,774168,$localIdentifier$i$i$i$i$i,0);
 __ZN7mecanim9animation18ControllerConstant8TransferI13ProxyTransferEEvRT_($localIdentifier$i$i$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 124|0);
 __ZN13ProxyTransfer8TransferINSt3__13mapIj8UnityStrNS1_4lessIjEENS1_9allocatorINS1_4pairIKjS3_EEEEEEEEvRT_PKc17TransferMetaFlags($transfer,$10,772104,0);
 $11 = (($this) + 68|0);
 $12 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772112,$12,$11,0);
 HEAP32[$p$i$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774144,$p$i$i$i,0);
 $13 = (($localIdentifier$i$i$i$i$i) + 8|0);
 $14 = $13;
 $15 = $14;
 HEAP32[$15>>2] = 0;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i>>2] = 0;
 $18 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772256,$18,$p$i$i$i,1);
 $19 = HEAP32[$4>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$7>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772272,$23,$13,1);
 $24 = HEAP32[$4>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$7>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 140|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772136,774072,$28,0);
 __ZN38StateMachineBehaviourVectorDescription8TransferI13ProxyTransferEEvRT_($28,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 172|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772184,$12,$29,0);
 HEAP32[$p$i$i$i>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774040,$p$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772240,774016,$p$i$i$i,0);
 $30 = (($localIdentifier$i$i$i$i$i) + 8|0);
 $31 = $30;
 $32 = $31;
 HEAP32[$32>>2] = 0;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = 0;
 HEAP32[$localIdentifier$i$i$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772256,$18,$p$i$i$i,1);
 $35 = HEAP32[$4>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$7>>2]|0;
 $38 = ((($36) + (($37*24)|0)|0) + 12|0);
 HEAP32[$38>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772272,$23,$30,1);
 $39 = HEAP32[$4>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$7>>2]|0;
 $42 = ((($40) + (($41*24)|0)|0) + 12|0);
 HEAP32[$42>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $43 = (($this) + 136|0);
 $44 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772200,$44,$43,1);
 $45 = HEAP32[$4>>2]|0;
 $46 = HEAP32[$45>>2]|0;
 $47 = HEAP32[$7>>2]|0;
 $48 = ((($46) + (($47*24)|0)|0) + 12|0);
 HEAP32[$48>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN38StateMachineBehaviourVectorDescription8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$i$i$i2 = 0, $size$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i1 = sp + 16|0;
 $p$i$i$i2 = sp;
 $0 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772288,$0,$this,0);
 HEAP32[$p$i$i$i2>>2] = 0;
 $1 = (($p$i$i$i2) + 4|0);
 HEAP32[$1>>2] = -1;
 $2 = (($p$i$i$i2) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($p$i$i$i2) + 12|0);
 HEAP32[$3>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i1,0);
 $4 = HEAP32[580608>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$4,$p$i$i$i2,0);
 __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI13ProxyTransferEEvRS4_RT_($p$i$i$i2,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $5 = (($this) + 16|0);
 $6 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772320,$6,$5,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i1,0);
 $7 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$7,$p$i$i$i2,0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($10) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairI8StateKey10StateRangeEEE8TransferI13ProxyTransferEEvRS4_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[580576>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$0,774128,$data,0);
 $1 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772376,$1,$data,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($data) + 4|0);
 $9 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772392,$9,$8,0);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$5>>2]|0;
 $13 = ((($11) + (($12*24)|0)|0) + 12|0);
 HEAP32[$13>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $14 = (($data) + 8|0);
 $15 = HEAP32[580656>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$15,774112,$14,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772352,$1,$14,0);
 $16 = HEAP32[$2>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$5>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($data) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772368,$1,$20,0);
 $21 = HEAP32[$2>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$5>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18ControllerConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ArrayTransfer$i1 = 0, $p$i$i$i$i$i$i2 = 0, $p$i$i$i4 = 0, $size$i$i$i$i3 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $p$i$i$i$i$i$i2 = sp + 32|0;
 $size$i$i$i$i3 = sp;
 $p$i$i$i4 = sp + 8|0;
 $ArrayTransfer$i1 = sp + 16|0;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i1>>2] = $0;
 $3 = (($ArrayTransfer$i1) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i1) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772408,$5,$ArrayTransfer$i1,0);
 HEAP32[$p$i$i$i4>>2] = 0;
 $6 = (($p$i$i$i4) + 4|0);
 HEAP32[$6>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i3,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774192,$p$i$i$i4,0);
 $7 = (($p$i$i$i$i$i$i2) + 8|0);
 $8 = (($p$i$i$i$i$i$i2) + 28|0);
 HEAP32[$8>>2] = 0;
 $9 = (($p$i$i$i$i$i$i2) + 36|0);
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
 HEAP8[$9>>0] = 1;
 $10 = (($p$i$i$i$i$i$i2) + 37|0);
 HEAP8[$10>>0] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774544,$p$i$i$i$i$i$i2,0);
 __ZN7mecanim9animation13LayerConstant8TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i2,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $11 = (($this) + 16|0);
 $12 = (($this) + 12|0);
 $13 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i1>>2] = $11;
 $14 = (($ArrayTransfer$i1) + 4|0);
 HEAP32[$14>>2] = $12;
 $15 = (($ArrayTransfer$i1) + 8|0);
 HEAP32[$15>>2] = $13;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772424,$5,$ArrayTransfer$i1,0);
 HEAP32[$p$i$i$i4>>2] = 0;
 $16 = (($p$i$i$i4) + 4|0);
 HEAP32[$16>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i3,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774192,$p$i$i$i4,0);
 $17 = (($p$i$i$i$i$i$i2) + 28|0);
 ;HEAP32[$p$i$i$i$i$i$i2+0>>2]=0|0;HEAP32[$p$i$i$i$i$i$i2+4>>2]=0|0;HEAP32[$p$i$i$i$i$i$i2+8>>2]=0|0;HEAP32[$p$i$i$i$i$i$i2+12>>2]=0|0;HEAP32[$p$i$i$i$i$i$i2+16>>2]=0|0;HEAP32[$p$i$i$i$i$i$i2+20>>2]=0|0;
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774232,$p$i$i$i$i$i$i2,0);
 __ZN7mecanim12statemachine20StateMachineConstant8TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i2,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772448,774192,$18,0);
 __ZN15SerializeTraitsI9OffsetPtrIN7mecanim18ValueArrayConstantEEE8TransferI13ProxyTransferEEvRS3_RT_(0,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $19 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772464,774192,$19,0);
 dest=$p$i$i$i$i$i$i2+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774208,$p$i$i$i$i$i$i2,0);
 __ZN7mecanim10ValueArray8TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i2,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim10ValueArray8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i15 = 0, $p$i$i$i$i14 = 0, $size$i$i$i$i$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i$i$i$i$i13 = sp + 28|0;
 $p$i$i$i$i14 = sp;
 $ArrayTransfer$i15 = sp + 16|0;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i15>>2] = $0;
 $3 = (($ArrayTransfer$i15) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i15) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772480,$5,$ArrayTransfer$i15,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i13,0);
 $6 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$6,$p$i$i$i$i14,0);
 $7 = (($transfer) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($transfer) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($9) + (($11*24)|0)|0) + 12|0);
 HEAP32[$12>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $13 = (($this) + 16|0);
 $14 = (($this) + 12|0);
 $15 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i15>>2] = $13;
 $16 = (($ArrayTransfer$i15) + 4|0);
 HEAP32[$16>>2] = $14;
 $17 = (($ArrayTransfer$i15) + 8|0);
 HEAP32[$17>>2] = $15;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772496,$5,$ArrayTransfer$i15,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i13,0);
 $18 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$18,$p$i$i$i$i14,0);
 $19 = HEAP32[$7>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$10>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 28|0);
 $24 = (($this) + 24|0);
 $25 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i15>>2] = $23;
 $26 = (($ArrayTransfer$i15) + 4|0);
 HEAP32[$26>>2] = $24;
 $27 = (($ArrayTransfer$i15) + 8|0);
 HEAP32[$27>>2] = $25;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772512,$5,$ArrayTransfer$i15,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i13,0);
 $28 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$28,$p$i$i$i$i14,0);
 $29 = HEAP32[$7>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$10>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = (($this) + 40|0);
 $34 = (($this) + 36|0);
 $35 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i15>>2] = $33;
 $36 = (($ArrayTransfer$i15) + 4|0);
 HEAP32[$36>>2] = $34;
 $37 = (($ArrayTransfer$i15) + 8|0);
 HEAP32[$37>>2] = $35;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772528,$5,$ArrayTransfer$i15,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i13,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774224,$p$i$i$i$i14,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($p$i$i$i$i14,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($this) + 52|0);
 $39 = (($this) + 48|0);
 $40 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i15>>2] = $38;
 $41 = (($ArrayTransfer$i15) + 4|0);
 HEAP32[$41>>2] = $39;
 $42 = (($ArrayTransfer$i15) + 8|0);
 HEAP32[$42>>2] = $40;
 $43 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772552,$43,$ArrayTransfer$i15,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i13,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774224,$p$i$i$i$i14,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($p$i$i$i$i14,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $44 = (($this) + 64|0);
 $45 = (($this) + 60|0);
 $46 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i15>>2] = $44;
 $47 = (($ArrayTransfer$i15) + 4|0);
 HEAP32[$47>>2] = $45;
 $48 = (($ArrayTransfer$i15) + 8|0);
 HEAP32[$48>>2] = $46;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772576,$43,$ArrayTransfer$i15,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i13,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774224,$p$i$i$i$i14,0);
 __ZN15SerializeTraitsIKN4math7_float4EE8TransferI13ProxyTransferEEvRS2_RT_($p$i$i$i$i14,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine20StateMachineConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0, $ArrayTransfer$i2 = 0, $p$i$i$i$i$i$i6 = 0, $p$i$i$i$i$i$i9 = 0, $p$i$i$i8 = 0, $size$i$i$i$i7 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $p$i$i$i$i$i$i9 = sp + 72|0;
 $ArrayTransfer$i$i$i = sp;
 $p$i$i$i$i$i$i6 = sp + 12|0;
 $size$i$i$i$i7 = sp + 32|0;
 $p$i$i$i8 = sp + 48|0;
 $ArrayTransfer$i2 = sp + 56|0;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size$i$i$i$i7>>2] = $0;
 $3 = (($size$i$i$i$i7) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($size$i$i$i$i7) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772632,$5,$size$i$i$i$i7,0);
 HEAP32[$p$i$i$i$i$i$i6>>2] = 0;
 $6 = (($p$i$i$i$i$i$i6) + 4|0);
 HEAP32[$6>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$ArrayTransfer$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774192,$p$i$i$i$i$i$i6,0);
 $7 = (($p$i$i$i$i$i$i9) + 60|0);
 dest=$p$i$i$i$i$i$i9+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($p$i$i$i$i$i$i9) + 64|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($p$i$i$i$i$i$i9) + 68|0);
 HEAP8[$9>>0] = 1;
 $10 = (($p$i$i$i$i$i$i9) + 69|0);
 HEAP8[$10>>0] = 1;
 $11 = (($p$i$i$i$i$i$i9) + 70|0);
 HEAP8[$11>>0] = 0;
 $12 = (($p$i$i$i$i$i$i9) + 71|0);
 HEAP8[$12>>0] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774360,$p$i$i$i$i$i$i9,0);
 __ZN7mecanim12statemachine13StateConstant8TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i9,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $13 = (($this) + 16|0);
 $14 = (($this) + 12|0);
 $15 = HEAP32[$1>>2]|0;
 HEAP32[$size$i$i$i$i7>>2] = $13;
 $16 = (($size$i$i$i$i7) + 4|0);
 HEAP32[$16>>2] = $14;
 $17 = (($size$i$i$i$i7) + 8|0);
 HEAP32[$17>>2] = $15;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772656,$5,$size$i$i$i$i7,0);
 HEAP32[$p$i$i$i$i$i$i6>>2] = 0;
 $18 = (($p$i$i$i$i$i$i6) + 4|0);
 HEAP32[$18>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$ArrayTransfer$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774192,$p$i$i$i$i$i$i6,0);
 $19 = (($p$i$i$i$i$i$i9) + 36|0);
 dest=$p$i$i$i$i$i$i9+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$19>>2] = Math_fround(0.899999976158142089843);
 $20 = (($p$i$i$i$i$i$i9) + 40|0);
 HEAP8[$20>>0] = 0;
 $21 = (($p$i$i$i$i$i$i9) + 44|0);
 HEAP32[$21>>2] = 0;
 $22 = (($p$i$i$i$i$i$i9) + 48|0);
 HEAP8[$22>>0] = 1;
 $23 = (($p$i$i$i$i$i$i9) + 49|0);
 HEAP8[$23>>0] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774336,$p$i$i$i$i$i$i9,0);
 __ZN7mecanim12statemachine18TransitionConstant8TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i9,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($this) + 28|0);
 $25 = (($this) + 24|0);
 $26 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i2>>2] = $24;
 $27 = (($ArrayTransfer$i2) + 4|0);
 HEAP32[$27>>2] = $25;
 $28 = (($ArrayTransfer$i2) + 8|0);
 HEAP32[$28>>2] = $26;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772696,$5,$ArrayTransfer$i2,0);
 HEAP32[$p$i$i$i8>>2] = 0;
 $29 = (($p$i$i$i8) + 4|0);
 HEAP32[$29>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i7,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774192,$p$i$i$i8,0);
 $30 = (($p$i$i$i$i$i$i6) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = (($p$i$i$i$i$i$i6) + 8|0);
 HEAP32[$31>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774256,$p$i$i$i$i$i$i6,0);
 $32 = (($p$i$i$i$i$i$i6) + 4|0);
 $33 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i>>2] = $32;
 $34 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$34>>2] = $p$i$i$i$i$i$i6;
 $35 = (($ArrayTransfer$i$i$i) + 8|0);
 HEAP32[$35>>2] = $33;
 $36 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772768,$36,$ArrayTransfer$i$i$i,0);
 HEAP32[$p$i$i$i$i$i$i9>>2] = 0;
 $37 = (($p$i$i$i$i$i$i9) + 4|0);
 HEAP32[$37>>2] = 0;
 __ZN13ProxyTransfer32TransferSTLStyleArrayWithElementI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEEvRT_17TransferMetaFlags($transfer,$p$i$i$i$i$i$i9,0);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($p$i$i$i$i$i$i6) + 12|0);
 $39 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772800,$39,$38,0);
 $40 = (($transfer) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($transfer) + 20|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($42) + (($44*24)|0)|0) + 12|0);
 HEAP32[$45>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $46 = (($p$i$i$i$i$i$i6) + 16|0);
 $47 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772816,$47,$46,0);
 $48 = HEAP32[$40>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$43>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $52 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772728,$39,$52,0);
 $53 = HEAP32[$40>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$43>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $57 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772744,$39,$57,0);
 $58 = HEAP32[$40>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$43>>2]|0;
 $61 = ((($59) + (($60*24)|0)|0) + 12|0);
 HEAP32[$61>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer32TransferSTLStyleArrayWithElementI9OffsetPtrIN7mecanim12statemachine26SelectorTransitionConstantEEEEvRT_17TransferMetaFlags($this,$elementType,$metaFlag) {
 $this = $this|0;
 $elementType = $elementType|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, $p$i$i = 0, $p$i$i$i = 0;
 var $p$i$i$i$i$i$i = 0, $size = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $p$i$i$i$i$i$i = sp + 56|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $ArrayTransfer$i$i$i$i$i$i = sp + 16|0;
 $p$i$i = sp + 32|0;
 $size = sp + 48|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,774008,774008,$size,$metaFlag);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774192,$elementType,0);
 HEAP32[$p$i$i>>2] = 0;
 $0 = (($p$i$i) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($p$i$i) + 12|0);
 HEAP32[$1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774280,$p$i$i,0);
 $2 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772832,$2,$p$i$i,0);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $9 = (($p$i$i) + 8|0);
 $10 = (($p$i$i) + 4|0);
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $9;
 $13 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$13>>2] = $10;
 $14 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$14>>2] = $12;
 $15 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772848,$15,$ArrayTransfer$i$i$i$i$i$i,0);
 HEAP32[$p$i$i$i>>2] = 0;
 $16 = (($p$i$i$i) + 4|0);
 HEAP32[$16>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,774008,774008,$size$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774192,$p$i$i$i,0);
 HEAP32[$p$i$i$i$i$i$i>>2] = 1;
 $17 = (($p$i$i$i$i$i$i) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($p$i$i$i$i$i$i) + 8|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($p$i$i$i$i$i$i) + 12|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774312,$p$i$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772880,$2,$p$i$i$i$i$i$i,0);
 $20 = HEAP32[$3>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$6>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772896,$2,$17,0);
 $24 = HEAP32[$3>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$6>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 $28 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772912,$28,$18,0);
 $29 = HEAP32[$3>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$6>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772936,$28,$19,0);
 $33 = HEAP32[$3>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$6>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine18TransitionConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $ArrayTransfer$i = 0, $p$i$i$i = 0, $p$i$i$i$i$i$i = 0, $size$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $p$i$i$i$i$i$i = sp + 32|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $ArrayTransfer$i = sp + 16|0;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i>>2] = $0;
 $3 = (($ArrayTransfer$i) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772848,$5,$ArrayTransfer$i,0);
 HEAP32[$p$i$i$i>>2] = 0;
 $6 = (($p$i$i$i) + 4|0);
 HEAP32[$6>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774192,$p$i$i$i,0);
 HEAP32[$p$i$i$i$i$i$i>>2] = 1;
 $7 = (($p$i$i$i$i$i$i) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($p$i$i$i$i$i$i) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($p$i$i$i$i$i$i) + 12|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774312,$p$i$i$i$i$i$i,0);
 $10 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772880,$10,$p$i$i$i$i$i$i,0);
 $11 = (($transfer) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($transfer) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ((($13) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772896,$10,$7,0);
 $17 = HEAP32[$11>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$14>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $21 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772912,$21,$8,0);
 $22 = HEAP32[$11>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$14>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772936,$21,$9,0);
 $26 = HEAP32[$11>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$14>>2]|0;
 $29 = ((($27) + (($28*24)|0)|0) + 12|0);
 HEAP32[$29>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $30 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772952,$10,$30,0);
 $31 = HEAP32[$11>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$14>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $35 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772800,$10,$35,0);
 $36 = HEAP32[$11>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$14>>2]|0;
 $39 = ((($37) + (($38*24)|0)|0) + 12|0);
 HEAP32[$39>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $40 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772624,$10,$40,0);
 $41 = HEAP32[$11>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$14>>2]|0;
 $44 = ((($42) + (($43*24)|0)|0) + 12|0);
 HEAP32[$44>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $45 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772976,$10,$45,0);
 $46 = HEAP32[$11>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 $48 = HEAP32[$14>>2]|0;
 $49 = ((($47) + (($48*24)|0)|0) + 12|0);
 HEAP32[$49>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $50 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772992,$21,$50,0);
 $51 = HEAP32[$11>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$14>>2]|0;
 $54 = ((($52) + (($53*24)|0)|0) + 12|0);
 HEAP32[$54>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $55 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773016,$21,$55,0);
 $56 = HEAP32[$11>>2]|0;
 $57 = HEAP32[$56>>2]|0;
 $58 = HEAP32[$14>>2]|0;
 $59 = ((($57) + (($58*24)|0)|0) + 12|0);
 HEAP32[$59>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $60 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772936,$21,$60,0);
 $61 = HEAP32[$11>>2]|0;
 $62 = HEAP32[$61>>2]|0;
 $63 = HEAP32[$14>>2]|0;
 $64 = ((($62) + (($63*24)|0)|0) + 12|0);
 HEAP32[$64>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $65 = (($this) + 40|0);
 $66 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773040,$66,$65,0);
 $67 = HEAP32[$11>>2]|0;
 $68 = HEAP32[$67>>2]|0;
 $69 = HEAP32[$14>>2]|0;
 $70 = ((($68) + (($69*24)|0)|0) + 12|0);
 HEAP32[$70>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $71 = (($this) + 44|0);
 $72 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773056,$72,$71,0);
 $73 = HEAP32[$11>>2]|0;
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$14>>2]|0;
 $76 = ((($74) + (($75*24)|0)|0) + 12|0);
 HEAP32[$76>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $77 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773080,$66,$77,0);
 $78 = HEAP32[$11>>2]|0;
 $79 = HEAP32[$78>>2]|0;
 $80 = HEAP32[$14>>2]|0;
 $81 = ((($79) + (($80*24)|0)|0) + 12|0);
 HEAP32[$81>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $82 = (($this) + 49|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773104,$66,$82,0);
 $83 = HEAP32[$11>>2]|0;
 $84 = HEAP32[$83>>2]|0;
 $85 = HEAP32[$14>>2]|0;
 $86 = ((($84) + (($85*24)|0)|0) + 12|0);
 HEAP32[$86>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine13StateConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $ArrayTransfer$i$i$i = 0;
 var $ArrayTransfer$i4 = 0, $p$i$i$i$i$i$i6 = 0, $p$i$i$i$i3 = 0, $size$i$i$i$i$i$i$i = 0, $size$i$i$i$i$i2 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $size$i$i$i$i$i$i$i = sp + 60|0;
 $p$i$i$i$i$i$i6 = sp;
 $ArrayTransfer$i$i$i = sp + 4|0;
 $size$i$i$i$i$i2 = sp + 16|0;
 $p$i$i$i$i3 = sp + 32|0;
 $ArrayTransfer$i4 = sp + 48|0;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$size$i$i$i$i$i2>>2] = $0;
 $3 = (($size$i$i$i$i$i2) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($size$i$i$i$i$i2) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772768,$5,$size$i$i$i$i$i2,0);
 HEAP32[$ArrayTransfer$i$i$i>>2] = 0;
 $6 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$6>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$p$i$i$i$i$i$i6,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774192,$ArrayTransfer$i$i$i,0);
 $7 = (($size$i$i$i$i$i$i$i) + 36|0);
 dest=$size$i$i$i$i$i$i$i+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$7>>2] = Math_fround(0.899999976158142089843);
 $8 = (($size$i$i$i$i$i$i$i) + 40|0);
 HEAP8[$8>>0] = 0;
 $9 = (($size$i$i$i$i$i$i$i) + 44|0);
 HEAP32[$9>>2] = 0;
 $10 = (($size$i$i$i$i$i$i$i) + 48|0);
 HEAP8[$10>>0] = 1;
 $11 = (($size$i$i$i$i$i$i$i) + 49|0);
 HEAP8[$11>>0] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774336,$size$i$i$i$i$i$i$i,0);
 __ZN7mecanim12statemachine18TransitionConstant8TransferI13ProxyTransferEEvRT_($size$i$i$i$i$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 16|0);
 $13 = (($this) + 12|0);
 $14 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i>>2] = $12;
 $15 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$15>>2] = $13;
 $16 = (($ArrayTransfer$i$i$i) + 8|0);
 HEAP32[$16>>2] = $14;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773128,$5,$ArrayTransfer$i$i$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i$i$i,0);
 $17 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$17,$p$i$i$i$i$i$i6,0);
 $18 = (($transfer) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($transfer) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($20) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $24 = (($this) + 24|0);
 $25 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i4>>2] = $24;
 $26 = (($ArrayTransfer$i4) + 4|0);
 HEAP32[$26>>2] = $13;
 $27 = (($ArrayTransfer$i4) + 8|0);
 HEAP32[$27>>2] = $25;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773160,$5,$ArrayTransfer$i4,0);
 ;HEAP32[$p$i$i$i$i3+0>>2]=0|0;HEAP32[$p$i$i$i$i3+4>>2]=0|0;HEAP32[$p$i$i$i$i3+8>>2]=0|0;HEAP32[$p$i$i$i$i3+12>>2]=0|0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i2,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774520,$p$i$i$i$i3,0);
 $28 = (($p$i$i$i$i3) + 4|0);
 $29 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i>>2] = $28;
 $30 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$30>>2] = $p$i$i$i$i3;
 $31 = (($ArrayTransfer$i$i$i) + 8|0);
 HEAP32[$31>>2] = $29;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773720,$5,$ArrayTransfer$i$i$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i$i$i,0);
 $32 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$32,$p$i$i$i$i$i$i6,0);
 $33 = HEAP32[$18>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$21>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $37 = (($p$i$i$i$i3) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773736,$32,$37,0);
 $38 = HEAP32[$18>>2]|0;
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$21>>2]|0;
 $41 = ((($39) + (($40*24)|0)|0) + 12|0);
 HEAP32[$41>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $42 = (($this) + 36|0);
 $43 = (($this) + 32|0);
 $44 = HEAP32[$1>>2]|0;
 HEAP32[$size$i$i$i$i$i$i$i>>2] = $42;
 $45 = (($size$i$i$i$i$i$i$i) + 4|0);
 HEAP32[$45>>2] = $43;
 $46 = (($size$i$i$i$i$i$i$i) + 8|0);
 HEAP32[$46>>2] = $44;
 __ZN13ProxyTransfer8TransferI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_PKc17TransferMetaFlags($transfer,$size$i$i$i$i$i$i$i,773176,0);
 $47 = (($this) + 44|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773208,$32,$47,0);
 $48 = HEAP32[$18>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$21>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $52 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772272,$32,$52,0);
 $53 = HEAP32[$18>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$21>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $57 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772800,$32,$57,0);
 $58 = HEAP32[$18>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$21>>2]|0;
 $61 = ((($59) + (($60*24)|0)|0) + 12|0);
 HEAP32[$61>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $62 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773224,$32,$62,0);
 $63 = HEAP32[$18>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = HEAP32[$21>>2]|0;
 $66 = ((($64) + (($65*24)|0)|0) + 12|0);
 HEAP32[$66>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $67 = (($this) + 60|0);
 $68 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773232,$68,$67,0);
 $69 = HEAP32[$18>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$21>>2]|0;
 $72 = ((($70) + (($71*24)|0)|0) + 12|0);
 HEAP32[$72>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $73 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773240,$68,$73,0);
 $74 = HEAP32[$18>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 $76 = HEAP32[$21>>2]|0;
 $77 = ((($75) + (($76*24)|0)|0) + 12|0);
 HEAP32[$77>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $78 = (($this) + 68|0);
 $79 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773256,$79,$78,0);
 $80 = HEAP32[$18>>2]|0;
 $81 = HEAP32[$80>>2]|0;
 $82 = HEAP32[$21>>2]|0;
 $83 = ((($81) + (($82*24)|0)|0) + 12|0);
 HEAP32[$83>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $84 = (($this) + 69|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773272,$79,$84,0);
 $85 = HEAP32[$18>>2]|0;
 $86 = HEAP32[$85>>2]|0;
 $87 = HEAP32[$21>>2]|0;
 $88 = ((($86) + (($87*24)|0)|0) + 12|0);
 HEAP32[$88>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $89 = (($this) + 70|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773296,$79,$89,0);
 $90 = HEAP32[$18>>2]|0;
 $91 = HEAP32[$90>>2]|0;
 $92 = HEAP32[$21>>2]|0;
 $93 = ((($91) + (($92*24)|0)|0) + 12|0);
 HEAP32[$93>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $94 = (($this) + 71|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773304,$79,$94,0);
 $95 = HEAP32[$18>>2]|0;
 $96 = HEAP32[$95>>2]|0;
 $97 = HEAP32[$21>>2]|0;
 $98 = ((($96) + (($97*24)|0)|0) + 12|0);
 HEAP32[$98>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI22OffsetPtrArrayTransferI9OffsetPtrIN7mecanim9animation17BlendTreeConstantEEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i$i$i$i$i = 0, $p$i$i = 0, $p$i$i$i = 0;
 var $p$i$i$i$i$i = 0, $p$i$i$i$i$i$i = 0, $size$i$i$i = 0, $size$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $p$i$i$i$i$i$i = sp + 56|0;
 $size$i$i$i$i = sp;
 $p$i$i$i = sp + 8|0;
 $ArrayTransfer$i$i$i$i$i$i$i$i$i = sp + 16|0;
 $p$i$i$i$i$i = sp + 28|0;
 $size$i$i$i = sp + 40|0;
 $p$i$i = sp + 48|0;
 $0 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$0,$data,$metaFlag);
 HEAP32[$p$i$i>>2] = 0;
 $1 = (($p$i$i) + 4|0);
 HEAP32[$1>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,774008,774008,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774192,$p$i$i,0);
 HEAP32[$p$i$i$i$i$i>>2] = 0;
 $2 = (($p$i$i$i$i$i) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($p$i$i$i$i$i) + 8|0);
 HEAP32[$3>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774376,$p$i$i$i$i$i,0);
 $4 = (($p$i$i$i$i$i) + 4|0);
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i$i$i$i>>2] = $4;
 $7 = (($ArrayTransfer$i$i$i$i$i$i$i$i$i) + 4|0);
 HEAP32[$7>>2] = $p$i$i$i$i$i;
 $8 = (($ArrayTransfer$i$i$i$i$i$i$i$i$i) + 8|0);
 HEAP32[$8>>2] = $6;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,773320,$0,$ArrayTransfer$i$i$i$i$i$i$i$i$i,0);
 HEAP32[$p$i$i$i>>2] = 0;
 $9 = (($p$i$i$i) + 4|0);
 HEAP32[$9>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,774008,774008,$size$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774192,$p$i$i$i,0);
 HEAP32[$p$i$i$i$i$i$i>>2] = 0;
 $10 = (($p$i$i$i$i$i$i) + 4|0);
 HEAP32[$10>>2] = -1;
 $11 = (($p$i$i$i$i$i$i) + 8|0);
 HEAP32[$11>>2] = -1;
 $12 = (($p$i$i$i$i$i$i) + 12|0);
 $13 = (($p$i$i$i$i$i$i) + 48|0);
 dest=$12+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$13>>2] = -1;
 $14 = (($p$i$i$i$i$i$i) + 52|0);
 HEAPF32[$14>>2] = Math_fround(0.0);
 $15 = (($p$i$i$i$i$i$i) + 56|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($p$i$i$i$i$i$i) + 60|0);
 HEAP8[$16>>0] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774400,$p$i$i$i$i$i$i,0);
 __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI13ProxyTransferEEvRT_($p$i$i$i$i$i$i,$this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21BlendTreeNodeConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i = 0, $p$i$i$i$i$i = 0;
 var $p$i$i1 = 0, $size$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $size$i$i$i$i$i$i = sp + 32|0;
 $p$i$i$i$i$i = sp;
 $ArrayTransfer$i$i = sp + 4|0;
 $p$i$i1 = sp + 16|0;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773336,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773352,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773368,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 16|0);
 $18 = (($this) + 12|0);
 $19 = (($transfer) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$ArrayTransfer$i$i>>2] = $17;
 $21 = (($ArrayTransfer$i$i) + 4|0);
 HEAP32[$21>>2] = $18;
 $22 = (($ArrayTransfer$i$i) + 8|0);
 HEAP32[$22>>2] = $20;
 $23 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773384,$23,$ArrayTransfer$i$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$0,$p$i$i$i$i$i,0);
 $24 = HEAP32[$1>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$4>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 24|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773400,774192,$28,0);
 HEAP32[$p$i$i1>>2] = 0;
 $29 = (($p$i$i1) + 4|0);
 HEAP32[$29>>2] = 0;
 $30 = (($p$i$i1) + 8|0);
 HEAP32[$30>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774496,$p$i$i1,0);
 $31 = (($p$i$i1) + 4|0);
 $32 = HEAP32[$19>>2]|0;
 HEAP32[$ArrayTransfer$i$i>>2] = $31;
 $33 = (($ArrayTransfer$i$i) + 4|0);
 HEAP32[$33>>2] = $p$i$i1;
 $34 = (($ArrayTransfer$i$i) + 8|0);
 HEAP32[$34>>2] = $32;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773488,$23,$ArrayTransfer$i$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i$i,0);
 $35 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$35,$p$i$i$i$i$i,0);
 $36 = HEAP32[$1>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$4>>2]|0;
 $39 = ((($37) + (($38*24)|0)|0) + 12|0);
 HEAP32[$39>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $40 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773416,774192,$40,0);
 dest=$size$i$i$i$i$i$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774448,$size$i$i$i$i$i$i,0);
 __ZN7mecanim9animation19Blend2dDataConstant8TransferI13ProxyTransferEEvRT_($size$i$i$i$i$i$i,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $41 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773432,774192,$41,0);
 ;HEAP32[$p$i$i1+0>>2]=0|0;HEAP32[$p$i$i1+4>>2]=0|0;HEAP32[$p$i$i1+8>>2]=0|0;HEAP8[$p$i$i1+12>>0]=0|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774424,$p$i$i1,0);
 $42 = (($p$i$i1) + 4|0);
 $43 = HEAP32[$19>>2]|0;
 HEAP32[$ArrayTransfer$i$i>>2] = $42;
 $44 = (($ArrayTransfer$i$i) + 4|0);
 HEAP32[$44>>2] = $p$i$i1;
 $45 = (($ArrayTransfer$i$i) + 8|0);
 HEAP32[$45>>2] = $43;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773512,$23,$ArrayTransfer$i$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i$i$i$i,0);
 $46 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$46,$p$i$i$i$i$i,0);
 $47 = HEAP32[$1>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$4>>2]|0;
 $50 = ((($48) + (($49*24)|0)|0) + 12|0);
 HEAP32[$50>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $51 = (($p$i$i1) + 12|0);
 $52 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773544,$52,$51,0);
 $53 = HEAP32[$1>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$4>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $57 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773456,$46,$57,0);
 $58 = HEAP32[$1>>2]|0;
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[$4>>2]|0;
 $61 = ((($59) + (($60*24)|0)|0) + 12|0);
 HEAP32[$61>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $62 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773472,$35,$62,0);
 $63 = HEAP32[$1>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = HEAP32[$4>>2]|0;
 $66 = ((($64) + (($65*24)|0)|0) + 12|0);
 HEAP32[$66>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $67 = (($this) + 56|0);
 $68 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773240,$68,$67,0);
 $69 = HEAP32[$1>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$4>>2]|0;
 $72 = ((($70) + (($71*24)|0)|0) + 12|0);
 HEAP32[$72>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $73 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773304,$52,$73,0);
 $74 = HEAP32[$1>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 $76 = HEAP32[$4>>2]|0;
 $77 = ((($75) + (($76*24)|0)|0) + 12|0);
 HEAP32[$77>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation19Blend2dDataConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i7 = 0, $p$i$i$i$i6 = 0, $size$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$i9 = sp + 20|0;
 $p$i$i$i$i6 = sp;
 $ArrayTransfer$i7 = sp + 8|0;
 $0 = (($this) + 4|0);
 $1 = (($transfer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i7>>2] = $0;
 $3 = (($ArrayTransfer$i7) + 4|0);
 HEAP32[$3>>2] = $this;
 $4 = (($ArrayTransfer$i7) + 8|0);
 HEAP32[$4>>2] = $2;
 $5 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773568,$5,$ArrayTransfer$i7,0);
 HEAPF32[$p$i$i$i$i6>>2] = Math_fround(0.0);
 $6 = (($p$i$i$i$i6) + 4|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i9,0);
 $7 = HEAP32[580768>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$7,$p$i$i$i$i6,0);
 $8 = (($transfer) + 16|0);
 $9 = (__ZNK16TypeTreeIterator7GetNodeEv($8)|0);
 $10 = (($9) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 | 2097152;
 $13 = (($transfer) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($transfer) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ((($15) + (($17*24)|0)|0) + 20|0);
 HEAP32[$18>>2] = $12;
 $19 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772592,$19,$p$i$i$i$i6,0);
 $20 = HEAP32[$13>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$16>>2]|0;
 $23 = ((($21) + (($22*24)|0)|0) + 12|0);
 HEAP32[$23>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772600,$19,$6,0);
 $24 = HEAP32[$13>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$16>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 16|0);
 $29 = (($this) + 12|0);
 $30 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i7>>2] = $28;
 $31 = (($ArrayTransfer$i7) + 4|0);
 HEAP32[$31>>2] = $29;
 $32 = (($ArrayTransfer$i7) + 8|0);
 HEAP32[$32>>2] = $30;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773592,$5,$ArrayTransfer$i7,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i9,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$19,$p$i$i$i$i6,0);
 $33 = HEAP32[$13>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$16>>2]|0;
 $36 = ((($34) + (($35*24)|0)|0) + 12|0);
 HEAP32[$36>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $37 = (($this) + 28|0);
 $38 = (($this) + 24|0);
 $39 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i7>>2] = $37;
 $40 = (($ArrayTransfer$i7) + 4|0);
 HEAP32[$40>>2] = $38;
 $41 = (($ArrayTransfer$i7) + 8|0);
 HEAP32[$41>>2] = $39;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773616,$5,$ArrayTransfer$i7,0);
 HEAPF32[$p$i$i$i$i6>>2] = Math_fround(0.0);
 $42 = (($p$i$i$i$i6) + 4|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i9,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$7,$p$i$i$i$i6,0);
 $43 = (__ZNK16TypeTreeIterator7GetNodeEv($8)|0);
 $44 = (($43) + 20|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45 | 2097152;
 $47 = HEAP32[$13>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$16>>2]|0;
 $50 = ((($48) + (($49*24)|0)|0) + 20|0);
 HEAP32[$50>>2] = $46;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772592,$19,$p$i$i$i$i6,0);
 $51 = HEAP32[$13>>2]|0;
 $52 = HEAP32[$51>>2]|0;
 $53 = HEAP32[$16>>2]|0;
 $54 = ((($52) + (($53*24)|0)|0) + 12|0);
 HEAP32[$54>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772600,$19,$42,0);
 $55 = HEAP32[$13>>2]|0;
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$16>>2]|0;
 $58 = ((($56) + (($57*24)|0)|0) + 12|0);
 HEAP32[$58>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $59 = (($this) + 40|0);
 $60 = (($this) + 36|0);
 $61 = HEAP32[$1>>2]|0;
 HEAP32[$ArrayTransfer$i7>>2] = $59;
 $62 = (($ArrayTransfer$i7) + 4|0);
 HEAP32[$62>>2] = $60;
 $63 = (($ArrayTransfer$i7) + 8|0);
 HEAP32[$63>>2] = $61;
 $64 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773640,$64,$ArrayTransfer$i7,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i9,0);
 $65 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,$65,$p$i$i$i$i6,0);
 $66 = HEAP32[$13>>2]|0;
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$16>>2]|0;
 $69 = ((($67) + (($68*24)|0)|0) + 12|0);
 HEAP32[$69>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $70 = (($this) + 52|0);
 $71 = (($this) + 48|0);
 $72 = HEAP32[$1>>2]|0;
 HEAP32[$size$i9>>2] = $70;
 $73 = (($size$i9) + 4|0);
 HEAP32[$73>>2] = $71;
 $74 = (($size$i9) + 8|0);
 HEAP32[$74>>2] = $72;
 __ZN13ProxyTransfer8TransferI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_PKc17TransferMetaFlags($transfer,$size$i9,773672,0);
 STACKTOP = sp;return;
}
function __ZN13ProxyTransfer8TransferI22OffsetPtrArrayTransferIN7mecanim9animation18MotionNeighborListEEEEvRT_PKc17TransferMetaFlags($this,$data,$name,$metaFlag) {
 $this = $this|0;
 $data = $data|0;
 $name = $name|0;
 $metaFlag = $metaFlag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i = 0, $p$i$i = 0, $p$i$i$i$i$i$i = 0, $size$i$i$i = 0, $size$i$i$i$i$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $size$i$i$i$i$i$i$i = sp + 32|0;
 $p$i$i$i$i$i$i = sp;
 $ArrayTransfer$i$i$i = sp + 4|0;
 $size$i$i$i = sp + 16|0;
 $p$i$i = sp + 20|0;
 $0 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,$name,$0,$data,$metaFlag);
 HEAP32[$p$i$i>>2] = 0;
 $1 = (($p$i$i) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($p$i$i) + 8|0);
 HEAP32[$2>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,774008,774008,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,774472,$p$i$i,0);
 $3 = (($p$i$i) + 4|0);
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i>>2] = $3;
 $6 = (($ArrayTransfer$i$i$i) + 4|0);
 HEAP32[$6>>2] = $p$i$i;
 $7 = (($ArrayTransfer$i$i$i) + 8|0);
 HEAP32[$7>>2] = $5;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,773704,$0,$ArrayTransfer$i$i$i,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($this,774008,774008,$size$i$i$i$i$i$i$i,0);
 $8 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($this,772232,$8,$p$i$i$i$i$i$i,0);
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($11) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 __ZN13ProxyTransfer16EndArrayTransferEv($this);
 __ZN13ProxyTransfer11EndTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation13LayerConstant8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $ArrayTransfer$i$i$i$i$i$i = 0, $p$i$i = 0, $p$i$i1 = 0, $size$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $size$i$i$i = sp + 32|0;
 $p$i$i1 = sp;
 $ArrayTransfer$i$i$i$i$i$i = sp + 8|0;
 $p$i$i = sp + 20|0;
 $0 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773752,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773776,$0,$7,0);
 $8 = HEAP32[$1>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ((($9) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = (($this) + 8|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773808,774600,$12,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773992,$0,$12,0);
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 12|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,774000,$0,$17,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $22 = (($this) + 16|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773824,774192,$22,0);
 HEAP32[$p$i$i>>2] = 0;
 $23 = (($p$i$i) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = (($p$i$i) + 8|0);
 HEAP32[$24>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774560,$p$i$i,0);
 $25 = (($p$i$i) + 4|0);
 $26 = (($transfer) + 4|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$ArrayTransfer$i$i$i$i$i$i>>2] = $25;
 $28 = (($ArrayTransfer$i$i$i$i$i$i) + 4|0);
 HEAP32[$28>>2] = $p$i$i;
 $29 = (($ArrayTransfer$i$i$i$i$i$i) + 8|0);
 HEAP32[$29>>2] = $27;
 $30 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773952,$30,$ArrayTransfer$i$i$i$i$i$i,0);
 HEAP32[$p$i$i1>>2] = 0;
 $31 = (($p$i$i1) + 4|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,774008,774008,$size$i$i$i,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,772232,774576,$p$i$i1,0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773960,$0,$p$i$i1,0);
 $32 = HEAP32[$1>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$4>>2]|0;
 $35 = ((($33) + (($34*24)|0)|0) + 12|0);
 HEAP32[$35>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $36 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773976,$36,$31,0);
 $37 = HEAP32[$1>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$4>>2]|0;
 $40 = ((($38) + (($39*24)|0)|0) + 12|0);
 HEAP32[$40>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $41 = (($this) + 24|0);
 $42 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773840,$42,$41,0);
 $43 = HEAP32[$1>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$4>>2]|0;
 $46 = ((($44) + (($45*24)|0)|0) + 12|0);
 HEAP32[$46>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $47 = (($this) + 28|0);
 $48 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773856,$48,$47,0);
 $49 = HEAP32[$1>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$4>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $53 = (($this) + 32|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773888,$36,$53,0);
 $54 = HEAP32[$1>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$4>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $58 = (($this) + 36|0);
 $59 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773904,$59,$58,0);
 $60 = HEAP32[$1>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$4>>2]|0;
 $63 = ((($61) + (($62*24)|0)|0) + 12|0);
 HEAP32[$63>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $64 = (($this) + 37|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,773920,$59,$64,0);
 $65 = HEAP32[$1>>2]|0;
 $66 = HEAP32[$65>>2]|0;
 $67 = HEAP32[$4>>2]|0;
 $68 = ((($66) + (($67*24)|0)|0) + 12|0);
 HEAP32[$68>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZN18AnimatorControllerD2Ev($this) {
 $this = $this|0;
 var $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$byval_copy9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i1$i$i = 0, $c$01$i$i$i = 0, $c$01$i$i$i7 = 0, $lpad$phi$index = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i2$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i6$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i4$i$i = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i5$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy9 = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = sp + 16|0;
 HEAP32[$this>>2] = ((771912 + 8|0));
 $5 = (($this) + 172|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($this) + 176|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($6|0);
  if (!($10)) {
   $__new_last2$i$i$i$i$i = $6;
   $scevgep$i$i$i$i$i = (($9) + -4|0);
   $11 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($11)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $12 = $uglygep3$i$i$i$i$i >>> 2;
   $13 = $12 ^ -1;
   $scevgep4$i$i$i$i$i = (($9) + ($13<<2)|0);
   HEAP32[$8>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($6);
 }
 $14 = (($this) + 168|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)>(-1);
 do {
  if ($16) {
   $17 = (($this) + 156|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($this) + 160|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[$4>>2] = $20;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($18|0),($$byval_copy9|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    HEAP32[$17>>2] = 0;
    label = 8;
    break;
   }
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   $34 = (($this) + 144|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if (!($36)) {
    $37 = (($this) + 148|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)==($35|0);
    if (!($39)) {
     $__new_last2$i$i$i$i$i$i$i$i$i1$i$i = $35;
     $scevgep$i$i$i$i$i$i$i$i$i2$i$i = (($38) + -16|0);
     $40 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i1$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i4$i$i = (($scevgep$i$i$i$i$i$i$i$i$i2$i$i) + ($40)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i5$i$i = $uglygep$i$i$i$i$i$i$i$i$i4$i$i;
     $41 = $uglygep3$i$i$i$i$i$i$i$i$i5$i$i >>> 4;
     $42 = $41 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i6$i$i = (($38) + ($42<<4)|0);
     HEAP32[$37>>2] = $scevgep4$i$i$i$i$i$i$i$i$i6$i$i;
    }
    __ZdlPv($35);
   }
   $68 = (($this) + 124|0);
   $69 = (($this) + 128|0);
   $70 = HEAP32[$69>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($68,$70);
   $71 = (($this) + 88|0);
   HEAP32[$71>>2] = ((768664 + 8|0));
   $72 = (($this) + 96|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($73|0)==(0|0);
   L18: do {
    if (!($74)) {
     $c$01$i$i$i7 = $73;
     while(1) {
      $75 = HEAP32[$c$01$i$i$i7>>2]|0;
      $76 = HEAP32[628296>>2]|0;
      HEAP32[$1>>2] = $76;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($c$01$i$i$i7|0),($$byval_copy9|0));
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       break;
      }
      $79 = ($75|0)==(0|0);
      if ($79) {
       break L18;
      } else {
       $c$01$i$i$i7 = $75;
      }
     }
     $95 = ___cxa_find_matching_catch(0|0)|0;
     $96 = tempRet0;
     $lpad$phi$index = $95;
     ___clang_call_terminate($lpad$phi$index);
     // unreachable;
    }
   } while(0);
   HEAP32[$72>>2] = 0;
   $80 = (($this) + 100|0);
   HEAP32[$80>>2] = 0;
   $81 = (($this) + 104|0);
   HEAP32[$81>>2] = 0;
   $$2 = $33;$$23 = $32;
   label = 31;
  } else {
   label = 8;
  }
 } while(0);
 L26: do {
  if ((label|0) == 8) {
   $23 = (($this) + 144|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = (($this) + 148|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==($24|0);
    if (!($28)) {
     $__new_last2$i$i$i$i$i$i$i$i$i$i$i = $24;
     $scevgep$i$i$i$i$i$i$i$i$i$i$i = (($27) + -16|0);
     $29 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i) + ($29)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i;
     $30 = $uglygep3$i$i$i$i$i$i$i$i$i$i$i >>> 4;
     $31 = $30 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i$i$i = (($27) + ($31<<4)|0);
     HEAP32[$26>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($24);
   }
   $43 = (($this) + 124|0);
   $44 = (($this) + 128|0);
   $45 = HEAP32[$44>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($43,$45);
   $46 = (($this) + 88|0);
   HEAP32[$46>>2] = ((768664 + 8|0));
   $47 = (($this) + 96|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0|0);
   L34: do {
    if (!($49)) {
     $c$01$i$i$i = $48;
     while(1) {
      $50 = HEAP32[$c$01$i$i$i>>2]|0;
      $51 = HEAP32[628296>>2]|0;
      HEAP32[$3>>2] = $51;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($c$01$i$i$i|0),($$byval_copy9|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break;
      }
      $54 = ($50|0)==(0|0);
      if ($54) {
       break L34;
      } else {
       $c$01$i$i$i = $50;
      }
     }
     $66 = ___cxa_find_matching_catch()|0;
     $67 = tempRet0;
     $$2 = $67;$$23 = $66;
     label = 31;
     break L26;
    }
   } while(0);
   HEAP32[$47>>2] = 0;
   $55 = (($this) + 100|0);
   HEAP32[$55>>2] = 0;
   $56 = (($this) + 104|0);
   HEAP32[$56>>2] = 0;
   $57 = (($this) + 80|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)>(-1);
   if (!($59)) {
    __ZN25RuntimeAnimatorControllerD2Ev($this);
    STACKTOP = sp;return;
   }
   $60 = (($this) + 68|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($this) + 72|0);
   $63 = HEAP32[$62>>2]|0;
   HEAP32[$2>>2] = $63;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($61|0),($$byval_copy9|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    $$3 = $83;$$34 = $82;
    label = 34;
    break;
   }
   HEAP32[$60>>2] = 0;
   __ZN25RuntimeAnimatorControllerD2Ev($this);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 31) {
  $84 = (($this) + 80|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)>(-1);
  if ($86) {
   $87 = (($this) + 68|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($this) + 72|0);
   $90 = HEAP32[$89>>2]|0;
   HEAP32[$0>>2] = $90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($88|0),($$byval_copy9|0));
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   if (!($92)) {
    HEAP32[$87>>2] = 0;
    $$3 = $$2;$$34 = $$23;
    label = 34;
   }
  } else {
   $$3 = $$2;$$34 = $$23;
   label = 34;
  }
 }
 if ((label|0) == 34) {
  __THREW__ = 0;
  invoke_vi(3689,($this|0));
  $93 = __THREW__; __THREW__ = 0;
  $94 = $93&1;
  if (!($94)) {
   ___resumeException($$34|0);
   // unreachable;
  }
 }
 $97 = ___cxa_find_matching_catch(0|0)|0;
 $98 = tempRet0;
 $lpad$phi$index = $97;
 ___clang_call_terminate($lpad$phi$index);
 // unreachable;
}
function __Z16AppendPathToHashRKN7mecanim5crc32EPKc($agg$result,$nameHash,$path) {
 $agg$result = $agg$result|0;
 $nameHash = $nameHash|0;
 $path = $path|0;
 var $$masked$i$i = 0, $$masked$i$i4 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $exitcond$i$i = 0, $p$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$nameHash>>2]|0;
 HEAP32[$agg$result>>2] = $0;
 $1 = ($0|0)==(-1);
 if ($1) {
  $$pre$i$i = -1;
 } else {
  $2 = $0 >>> 8;
  $$masked$i$i4 = $0 & 255;
  $3 = $$masked$i$i4 ^ 47;
  $4 = (584048 + ($3<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 ^ $2;
  HEAP32[$agg$result>>2] = $6;
  $$pre$i$i = $6;
 }
 $7 = (_strlen(($path|0))|0);
 $8 = (($path) + ($7)|0);
 $9 = ($7|0)>(0);
 if ($9) {
  $13 = $$pre$i$i;$p$01$i$i = $path;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $10 = HEAP8[$p$01$i$i>>0]|0;
  $11 = $10&255;
  $12 = $13 >>> 8;
  $$masked$i$i = $13 & 255;
  $14 = $11 ^ $$masked$i$i;
  $15 = (584048 + ($14<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16 ^ $12;
  HEAP32[$agg$result>>2] = $17;
  $18 = (($p$01$i$i) + 1|0);
  $exitcond$i$i = ($18|0)==($8|0);
  if ($exitcond$i$i) {
   break;
  } else {
   $13 = $17;$p$01$i$i = $18;
  }
 }
 STACKTOP = sp;return;
}
function __Z15HiearchyMatchesP9TransformPKN7mecanim8skeleton8SkeletonEiRKNS1_5crc32E($transform,$skeleton,$skeletonIndex,$nameHash) {
 $transform = $transform|0;
 $skeleton = $skeleton|0;
 $skeletonIndex = $skeletonIndex|0;
 $nameHash = $nameHash|0;
 var $$02$i$i$i = 0, $$masked$i$i$i$i = 0, $$masked$i$i4$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $childHash = 0, $childStartHint$05 = 0, $childStartHint$1 = 0, $currentMatchCount$0$lcssa = 0;
 var $currentMatchCount$08 = 0, $currentMatchCount$1 = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i$i = 0, $i$03$i$i$i = 0, $i$04$i = 0, $i$06 = 0, $p$01$i$i$i$i = 0, $reflection$01$i$i$i = 0, $reflection$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $childHash = sp;
 $0 = HEAP32[$skeleton>>2]|0;
 $1 = ($0>>>0)>($skeletonIndex>>>0);
 if (!($1)) {
  $currentMatchCount$0$lcssa = 0;
  STACKTOP = sp;return ($currentMatchCount$0$lcssa|0);
 }
 $2 = (($skeleton) + 4|0);
 $3 = $2;
 $4 = (($skeleton) + 12|0);
 $5 = $4;
 $6 = (($transform) + 148|0);
 $7 = (($transform) + 140|0);
 $childStartHint$05 = 0;$currentMatchCount$08 = 0;$i$06 = $skeletonIndex;
 while(1) {
  $8 = HEAP32[$2>>2]|0;
  $9 = (($8) + ($3))|0;
  $10 = $9;
  $11 = (($10) + ($i$06<<3)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==($skeletonIndex|0);
  L6: do {
   if ($13) {
    $$02$i$i$i = -1;$i$03$i$i$i = 0;$reflection$01$i$i$i = 0;
    while(1) {
     $14 = $$02$i$i$i & 1;
     $15 = ($14|0)==(0);
     if ($15) {
      $reflection$1$i$i$i = $reflection$01$i$i$i;
     } else {
      $16 = (31 - ($i$03$i$i$i))|0;
      $17 = 1 << $16;
      $18 = $17 | $reflection$01$i$i$i;
      $reflection$1$i$i$i = $18;
     }
     $19 = (($i$03$i$i$i) + 1)|0;
     $20 = $$02$i$i$i >>> 1;
     $exitcond$i$i$i = ($19|0)==(32);
     if ($exitcond$i$i$i) {
      break;
     } else {
      $$02$i$i$i = $20;$i$03$i$i$i = $19;$reflection$01$i$i$i = $reflection$1$i$i$i;
     }
    }
    HEAP32[$childHash>>2] = $reflection$1$i$i$i;
    $21 = HEAP32[$4>>2]|0;
    $22 = (($21) + ($5))|0;
    $23 = $22;
    $24 = (($23) + ($i$06<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$6>>2]|0;
    $27 = ($26|0)>(0);
    if ($27) {
     $i$04$i = 0;
     while(1) {
      $30 = (($i$04$i) + ($childStartHint$05))|0;
      $31 = (($30|0) % ($26|0))&-1;
      $32 = HEAP32[$7>>2]|0;
      $33 = (($32) + ($31<<2)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = HEAP32[$34>>2]|0;
      $36 = (($35) + 32|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (FUNCTION_TABLE_ii[$37 & 4095]($34)|0);
      $39 = HEAP32[$nameHash>>2]|0;
      $40 = ($39|0)==(-1);
      if ($40) {
       $72 = -1;
      } else {
       $41 = $39 >>> 8;
       $$masked$i$i4$i$i = $39 & 255;
       $42 = $$masked$i$i4$i$i ^ 47;
       $43 = (584048 + ($42<<2)|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = $44 ^ $41;
       $72 = $45;
      }
      $46 = (_strlen(($38|0))|0);
      $47 = (($38) + ($46)|0);
      $48 = ($46|0)>(0);
      if ($48) {
       $52 = $72;$p$01$i$i$i$i = $38;
       while(1) {
        $49 = HEAP8[$p$01$i$i$i$i>>0]|0;
        $50 = $49&255;
        $51 = $52 >>> 8;
        $$masked$i$i$i$i = $52 & 255;
        $53 = $50 ^ $$masked$i$i$i$i;
        $54 = (584048 + ($53<<2)|0);
        $55 = HEAP32[$54>>2]|0;
        $56 = $55 ^ $51;
        $57 = (($p$01$i$i$i$i) + 1|0);
        $exitcond$i$i$i$i = ($57|0)==($47|0);
        if ($exitcond$i$i$i$i) {
         $59 = $56;
         break;
        } else {
         $52 = $56;$p$01$i$i$i$i = $57;
        }
       }
      } else {
       $59 = $72;
      }
      $58 = $59 ^ -1;
      $60 = ($25|0)==($58|0);
      $29 = (($i$04$i) + 1)|0;
      if ($60) {
       break;
      }
      $28 = ($29|0)<($26|0);
      if ($28) {
       $i$04$i = $29;
      } else {
       $childStartHint$1 = $childStartHint$05;$currentMatchCount$1 = $currentMatchCount$08;
       break L6;
      }
     }
     HEAP32[$childHash>>2] = $59;
     $61 = HEAP32[$7>>2]|0;
     $62 = (($61) + ($31<<2)|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = ($63|0)==(0|0);
     if ($64) {
      $childStartHint$1 = $childStartHint$05;$currentMatchCount$1 = $currentMatchCount$08;
     } else {
      $65 = (($currentMatchCount$08) + 1)|0;
      $66 = (__Z15HiearchyMatchesP9TransformPKN7mecanim8skeleton8SkeletonEiRKNS1_5crc32E($63,$skeleton,$i$06,$childHash)|0);
      $67 = (($65) + ($66))|0;
      $68 = (($childStartHint$05) + 1)|0;
      $childStartHint$1 = $68;$currentMatchCount$1 = $67;
     }
    } else {
     $childStartHint$1 = $childStartHint$05;$currentMatchCount$1 = $currentMatchCount$08;
    }
   } else {
    $childStartHint$1 = $childStartHint$05;$currentMatchCount$1 = $currentMatchCount$08;
   }
  } while(0);
  $69 = (($i$06) + 1)|0;
  $70 = HEAP32[$skeleton>>2]|0;
  $71 = ($69>>>0)<($70>>>0);
  if ($71) {
   $childStartHint$05 = $childStartHint$1;$currentMatchCount$08 = $currentMatchCount$1;$i$06 = $69;
  } else {
   $currentMatchCount$0$lcssa = $currentMatchCount$1;
   break;
  }
 }
 STACKTOP = sp;return ($currentMatchCount$0$lcssa|0);
}
function __Z18HiearchyMatchesOptP9TransformPKN7mecanim8skeleton8SkeletonEPKj($transform,$skeleton,$nameArray) {
 $transform = $transform|0;
 $skeleton = $skeleton|0;
 $nameArray = $nameArray|0;
 var $$02$i$i$i$i = 0, $$masked$i$i$i = 0, $$matchCount$1 = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i$i = 0, $i$02 = 0, $i$03$i$i$i$i = 0, $matchCount$0$lcssa = 0, $matchCount$03 = 0;
 var $matchCount$1$lcssa = 0, $matchCount$11 = 0, $p$01$i$i$i = 0, $reflection$01$i$i$i$i = 0, $reflection$1$i$i$i$i = 0, $transformIt$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transform) + 140|0);
 $1 = (($transform) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $matchCount$0$lcssa = 0;
  STACKTOP = sp;return ($matchCount$0$lcssa|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $$pre = HEAP32[$skeleton>>2]|0;
 $45 = $2;$46 = $4;$6 = $$pre;$matchCount$03 = 0;$transformIt$04 = $4;
 while(1) {
  $5 = ($6|0)==(0);
  if ($5) {
   $42 = $46;$43 = $45;$47 = 0;$matchCount$1$lcssa = $matchCount$03;
  } else {
   $i$02 = 0;$matchCount$11 = $matchCount$03;
   while(1) {
    $7 = (($nameArray) + ($i$02<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = HEAP32[$transformIt$04>>2]|0;
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + 32|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (FUNCTION_TABLE_ii[$12 & 4095]($9)|0);
    $$02$i$i$i$i = -1;$i$03$i$i$i$i = 0;$reflection$01$i$i$i$i = 0;
    while(1) {
     $14 = $$02$i$i$i$i & 1;
     $15 = ($14|0)==(0);
     if ($15) {
      $reflection$1$i$i$i$i = $reflection$01$i$i$i$i;
     } else {
      $16 = (31 - ($i$03$i$i$i$i))|0;
      $17 = 1 << $16;
      $18 = $17 | $reflection$01$i$i$i$i;
      $reflection$1$i$i$i$i = $18;
     }
     $19 = (($i$03$i$i$i$i) + 1)|0;
     $20 = $$02$i$i$i$i >>> 1;
     $exitcond$i$i$i$i = ($19|0)==(32);
     if ($exitcond$i$i$i$i) {
      break;
     } else {
      $$02$i$i$i$i = $20;$i$03$i$i$i$i = $19;$reflection$01$i$i$i$i = $reflection$1$i$i$i$i;
     }
    }
    $21 = (_strlen(($13|0))|0);
    $22 = (($13) + ($21)|0);
    $23 = ($21|0)>(0);
    if ($23) {
     $27 = $reflection$1$i$i$i$i;$p$01$i$i$i = $13;
     while(1) {
      $24 = HEAP8[$p$01$i$i$i>>0]|0;
      $25 = $24&255;
      $26 = $27 >>> 8;
      $$masked$i$i$i = $27 & 255;
      $28 = $25 ^ $$masked$i$i$i;
      $29 = (584048 + ($28<<2)|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = $30 ^ $26;
      $32 = (($p$01$i$i$i) + 1|0);
      $exitcond$i$i$i = ($32|0)==($22|0);
      if ($exitcond$i$i$i) {
       $34 = $31;
       break;
      } else {
       $27 = $31;$p$01$i$i$i = $32;
      }
     }
    } else {
     $34 = $reflection$1$i$i$i$i;
    }
    $33 = $34 ^ -1;
    $35 = ($8|0)==($33|0);
    $36 = $35&1;
    $$matchCount$1 = (($36) + ($matchCount$11))|0;
    $37 = (($i$02) + 1)|0;
    $38 = HEAP32[$skeleton>>2]|0;
    $39 = ($37>>>0)<($38>>>0);
    if ($39) {
     $i$02 = $37;$matchCount$11 = $$matchCount$1;
    } else {
     break;
    }
   }
   $$pre7 = HEAP32[$0>>2]|0;
   $$pre8 = HEAP32[$1>>2]|0;
   $42 = $$pre7;$43 = $$pre8;$47 = $38;$matchCount$1$lcssa = $$matchCount$1;
  }
  $40 = (($transformIt$04) + 4|0);
  $41 = (($42) + ($43<<2)|0);
  $44 = ($40|0)==($41|0);
  if ($44) {
   $matchCount$0$lcssa = $matchCount$1$lcssa;
   break;
  } else {
   $45 = $43;$46 = $42;$6 = $47;$matchCount$03 = $matchCount$1$lcssa;$transformIt$04 = $40;
  }
 }
 STACKTOP = sp;return ($matchCount$0$lcssa|0);
}
function __Z18BuildTransformListR9TransformR13dynamic_arrayIPS_Lj4EE($root,$outTransforms) {
 $root = $root|0;
 $outTransforms = $outTransforms|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($outTransforms) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($outTransforms) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 if ($7) {
  $8 = $5 << 1;
  $9 = ($8|0)==(0);
  $10 = $9 ? 1 : $8;
  $11 = ($6>>>0)<($10>>>0);
  do {
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$outTransforms>>2]|0;
     $14 = $10 << 2;
     $15 = (($outTransforms) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,774616,370)|0);
     HEAP32[$outTransforms>>2] = $17;
     break;
    } else {
     $18 = $10 << 2;
     $19 = (($outTransforms) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,774616,352)|0);
     $22 = HEAP32[$outTransforms>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = $23 << 2;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$outTransforms>>2] = $21;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$1>>2]|0;
  $26 = $$pre$i$i;
 } else {
  $26 = $3;
 }
 $25 = (($26) + -1)|0;
 $27 = HEAP32[$outTransforms>>2]|0;
 $28 = (($27) + ($25<<2)|0);
 HEAP32[$28>>2] = $root;
 $29 = (($root) + 148|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)>(0);
 if (!($31)) {
  STACKTOP = sp;return;
 }
 $32 = (($root) + 140|0);
 $i$01 = 0;
 while(1) {
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + ($i$01<<2)|0);
  $35 = HEAP32[$34>>2]|0;
  __Z18BuildTransformListR9TransformR13dynamic_arrayIPS_Lj4EE($35,$outTransforms);
  $36 = (($i$01) + 1)|0;
  $exitcond = ($36|0)==($30|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __Z14FindAvatarRootPKN7mecanim8skeleton8SkeletonEPKjR9Transformb($skeleton,$nameArray,$root,$hasTransformHierarchy) {
 $skeleton = $skeleton|0;
 $nameArray = $nameArray|0;
 $root = $root|0;
 $hasTransformHierarchy = $hasTransformHierarchy|0;
 var $$0 = 0, $$02$i$i$i$us = 0, $$byval_copy9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $allTransforms = 0, $animationRoot$07 = 0, $animationRoot$07$us = 0, $animationRoot$1 = 0, $animationRoot$1$us = 0, $bestMatchCount$08 = 0, $bestMatchCount$08$us = 0, $bestMatchCount$1 = 0, $bestMatchCount$1$us = 0;
 var $exitcond$i$i$i$us = 0, $i$03$i$i$i$us = 0, $i$09 = 0, $i$09$us = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond = 0, $or$cond13 = 0, $reflection$01$i$i$i$us = 0, $reflection$1$i$i$i$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy9 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $allTransforms = sp + 8|0;
 $2 = sp + 24|0;
 $3 = HEAP32[628512>>2]|0;
 HEAP32[$allTransforms>>2] = 0;
 $4 = (($allTransforms) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = (($allTransforms) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($allTransforms) + 12|0);
 HEAP32[$6>>2] = 0;
 $7 = HEAP32[$skeleton>>2]|0;
 $8 = $7 << 1;
 $9 = ($8|0)==(0);
 if ($9) {
  label = 4;
 } else {
  HEAP32[$6>>2] = $8;
  $10 = $7 << 3;
  HEAP32[$1>>2] = $3;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
  $11 = (invoke_iiiiiiii(108,(0|0),($10|0),4,($$byval_copy9|0),0,(774616|0),370)|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   label = 17;
  } else {
   HEAP32[$allTransforms>>2] = $11;
   label = 4;
  }
 }
 L4: do {
  if ((label|0) == 4) {
   __THREW__ = 0;
   invoke_vii(3402,($root|0),($allTransforms|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 17;
   } else {
    $16 = HEAP32[$5>>2]|0;
    $17 = ($16|0)>(0);
    L7: do {
     if ($17) {
      $18 = HEAP32[$allTransforms>>2]|0;
      if ($hasTransformHierarchy) {
       $animationRoot$07$us = 0;$bestMatchCount$08$us = 0;$i$09$us = 0;
      } else {
       $animationRoot$07 = 0;$bestMatchCount$08 = 0;$i$09 = 0;
       while(1) {
        $50 = (($18) + ($i$09<<2)|0);
        $51 = HEAP32[$50>>2]|0;
        __THREW__ = 0;
        $52 = (invoke_iiii(1590,($51|0),($skeleton|0),($nameArray|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        $55 = ($52|0)>($bestMatchCount$08|0);
        if ($55) {
         $56 = HEAP32[$50>>2]|0;
         $animationRoot$1 = $56;$bestMatchCount$1 = $52;
        } else {
         $animationRoot$1 = $animationRoot$07;$bestMatchCount$1 = $bestMatchCount$08;
        }
        $57 = $i$09 ^ -1;
        $58 = (($16) + ($57))|0;
        $59 = ($bestMatchCount$1>>>0)<($58>>>0);
        $60 = (($i$09) + 1)|0;
        $61 = ($60|0)<($16|0);
        $or$cond13 = $59 & $61;
        if ($or$cond13) {
         $animationRoot$07 = $animationRoot$1;$bestMatchCount$08 = $bestMatchCount$1;$i$09 = $60;
        } else {
         $$0 = $animationRoot$1;
         break L7;
        }
       }
       $40 = ___cxa_find_matching_catch()|0;
       $41 = tempRet0;
       $lpad$phi$index = $40;$lpad$phi$index3 = $41;
       break L4;
      }
      while(1) {
       $32 = (($18) + ($i$09$us<<2)|0);
       $26 = HEAP32[$32>>2]|0;
       $$02$i$i$i$us = -1;$i$03$i$i$i$us = 0;$reflection$01$i$i$i$us = 0;
       while(1) {
        $19 = $$02$i$i$i$us & 1;
        $20 = ($19|0)==(0);
        if ($20) {
         $reflection$1$i$i$i$us = $reflection$01$i$i$i$us;
        } else {
         $21 = (31 - ($i$03$i$i$i$us))|0;
         $22 = 1 << $21;
         $23 = $22 | $reflection$01$i$i$i$us;
         $reflection$1$i$i$i$us = $23;
        }
        $24 = (($i$03$i$i$i$us) + 1)|0;
        $25 = $$02$i$i$i$us >>> 1;
        $exitcond$i$i$i$us = ($24|0)==(32);
        if ($exitcond$i$i$i$us) {
         break;
        } else {
         $$02$i$i$i$us = $25;$i$03$i$i$i$us = $24;$reflection$01$i$i$i$us = $reflection$1$i$i$i$us;
        }
       }
       HEAP32[$2>>2] = $reflection$1$i$i$i$us;
       __THREW__ = 0;
       $27 = (invoke_iiiii(271,($26|0),($skeleton|0),0,($2|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
       $30 = ($27|0)>($bestMatchCount$08$us|0);
       if ($30) {
        $31 = HEAP32[$32>>2]|0;
        $animationRoot$1$us = $31;$bestMatchCount$1$us = $27;
       } else {
        $animationRoot$1$us = $animationRoot$07$us;$bestMatchCount$1$us = $bestMatchCount$08$us;
       }
       $33 = $i$09$us ^ -1;
       $34 = (($16) + ($33))|0;
       $35 = ($bestMatchCount$1$us>>>0)<($34>>>0);
       $36 = (($i$09$us) + 1)|0;
       $37 = ($36|0)<($16|0);
       $or$cond = $35 & $37;
       if ($or$cond) {
        $animationRoot$07$us = $animationRoot$1$us;$bestMatchCount$08$us = $bestMatchCount$1$us;$i$09$us = $36;
       } else {
        $$0 = $animationRoot$1$us;
        break L7;
       }
      }
      $38 = ___cxa_find_matching_catch()|0;
      $39 = tempRet0;
      $lpad$phi$index = $38;$lpad$phi$index3 = $39;
      break L4;
     } else {
      $$0 = 0;
     }
    } while(0);
    $62 = HEAP32[$6>>2]|0;
    $63 = ($62|0)>(-1);
    if (!($63)) {
     STACKTOP = sp;return ($$0|0);
    }
    $64 = HEAP32[$allTransforms>>2]|0;
    $65 = HEAP32[$4>>2]|0;
    HEAP32[$0>>2] = $65;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($64,$$byval_copy9);
    HEAP32[$allTransforms>>2] = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $42 = ___cxa_find_matching_catch()|0;
  $43 = tempRet0;
  $lpad$phi$index = $42;$lpad$phi$index3 = $43;
 }
 $44 = HEAP32[$6>>2]|0;
 $45 = ($44|0)>(-1);
 if (!($45)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $46 = HEAP32[$allTransforms>>2]|0;
 $47 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = $47;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($46|0),($$byval_copy9|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $66 = ___cxa_find_matching_catch(0|0)|0;
  $67 = tempRet0;
  ___clang_call_terminate($66);
  // unreachable;
 }
 HEAP32[$allTransforms>>2] = 0;
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z31DoCalculateAnimatorSkinMatricesPv($userData) {
 $userData = $userData|0;
 var $$byval_copy1 = 0, $$idx$i = 0, $$idx$val$i = Math_fround(0), $$idx1$i = 0, $$idx1$val$i = Math_fround(0), $$idx2$i = 0, $$idx2$val$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0;
 var $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0);
 var $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $allocatedMemory = 0;
 var $i$015 = 0, $i1$013 = 0, $q$i3 = 0, $rootPose = 0, $s$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp + 96|0;
 $q$i3 = sp;
 $s$i4 = sp + 16|0;
 $allocatedMemory = sp + 28|0;
 $rootPose = sp + 32|0;
 $0 = HEAP32[$userData>>2]|0;
 HEAP32[$allocatedMemory>>2] = 0;
 $1 = (__ZNK8Animator26GetGlobalSpaceSkeletonPoseEPPN7mecanim8skeleton12SkeletonPoseE($0,$allocatedMemory)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(774624,0,774664,47,1,0,0,0);
  $163 = (($userData) + 12|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = ($164|0)>(0);
  if ($165) {
   $166 = (($userData) + 20|0);
   $i1$013 = 0;
   while(1) {
    $167 = HEAP32[$166>>2]|0;
    $168 = (($167) + ($i1$013<<6)|0);
    (__ZN10Matrix4x4f11SetIdentityEv($168)|0);
    $169 = (($i1$013) + 1)|0;
    $170 = HEAP32[$163>>2]|0;
    $171 = ($169|0)<($170|0);
    if ($171) {
     $i1$013 = $169;
    } else {
     break;
    }
   }
  }
 } else {
  $3 = (($1) + 4|0);
  $4 = (($userData) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $3;
  $7 = HEAP32[$3>>2]|0;
  $8 = (($7) + ($6))|0;
  $9 = $8;
  $10 = (($9) + (($5*48)|0)|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = ((($9) + (($5*48)|0)|0) + 4|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = ((($9) + (($5*48)|0)|0) + 8|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = ((($9) + (($5*48)|0)|0) + 16|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = ((($9) + (($5*48)|0)|0) + 20|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = ((($9) + (($5*48)|0)|0) + 24|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = ((($9) + (($5*48)|0)|0) + 28|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($17 * Math_fround(-1.0));
  $25 = Math_fround($19 * Math_fround(-1.0));
  $26 = Math_fround($21 * Math_fround(-1.0));
  $27 = Math_fround(Math_fround(0.0) - $11);
  $28 = Math_fround(Math_fround(0.0) - $13);
  $29 = Math_fround(Math_fround(0.0) - $15);
  $30 = Math_fround($27 + $27);
  $31 = Math_fround($28 + $28);
  $32 = Math_fround($29 + $29);
  $33 = Math_fround($31 * $24);
  $34 = Math_fround($32 * $25);
  $35 = Math_fround($30 * $26);
  $36 = Math_fround($23 * Math_fround(0.0));
  $37 = Math_fround($30 * $25);
  $38 = Math_fround($31 * $26);
  $39 = Math_fround($24 * $32);
  $40 = Math_fround($33 - $37);
  $41 = Math_fround($34 - $38);
  $42 = Math_fround($35 - $39);
  $43 = Math_fround($23 * $41);
  $44 = Math_fround($23 * $42);
  $45 = Math_fround($23 * $40);
  $46 = Math_fround($27 + $43);
  $47 = Math_fround($28 + $44);
  $48 = Math_fround($29 + $45);
  $49 = Math_fround($24 * $42);
  $50 = Math_fround($25 * $40);
  $51 = Math_fround($26 * $41);
  $52 = Math_fround($25 * $41);
  $53 = Math_fround($26 * $42);
  $54 = Math_fround($24 * $40);
  $55 = Math_fround($49 - $52);
  $56 = Math_fround($50 - $53);
  $57 = Math_fround($51 - $54);
  $58 = Math_fround($46 + $56);
  $59 = Math_fround($47 + $57);
  $60 = Math_fround($48 + $55);
  $61 = Math_fround($25 * Math_fround(0.0));
  $62 = Math_fround($26 * Math_fround(0.0));
  $63 = Math_fround($24 * Math_fround(0.0));
  $64 = Math_fround($61 - $36);
  $65 = Math_fround($23 - $63);
  $66 = Math_fround($62 - $61);
  $67 = Math_fround($63 - $62);
  $68 = Math_fround($64 - $26);
  $69 = Math_fround($65 - $62);
  $70 = Math_fround($66 - $36);
  $71 = Math_fround($67 - $36);
  $72 = Math_fround($68 - $63);
  $73 = Math_fround($69 - $61);
  $74 = Math_fround($70 - $24);
  $75 = Math_fround($71 - $25);
  $76 = Math_fround($74 * Math_fround(-1.0));
  $77 = Math_fround($75 * Math_fround(-1.0));
  $78 = Math_fround($72 * Math_fround(-1.0));
  $79 = Math_fround($76 * $76);
  $80 = Math_fround($77 * $77);
  $81 = Math_fround($78 * $78);
  $82 = Math_fround($73 * $73);
  $83 = Math_fround($79 + $80);
  $84 = Math_fround($82 + $81);
  $85 = Math_fround($83 + $84);
  $86 = (Math_fround(Math_sqrt((Math_fround($85)))));
  $87 = Math_fround(Math_fround(1.0) / $86);
  $88 = Math_fround($87 * $76);
  $89 = Math_fround($87 * $77);
  $90 = Math_fround($87 * $78);
  $91 = Math_fround($87 * $73);
  HEAPF32[$$byval_copy1>>2] = $58;
  $92 = (($$byval_copy1) + 4|0);
  HEAPF32[$92>>2] = $59;
  $93 = (($$byval_copy1) + 8|0);
  HEAPF32[$93>>2] = $60;
  $94 = Math_fround($88 * $88);
  $95 = Math_fround($89 * $89);
  $96 = Math_fround($90 * $90);
  $97 = Math_fround($91 * $91);
  $98 = Math_fround($94 + $95);
  $99 = Math_fround($97 + $96);
  $100 = Math_fround($98 + $99);
  $101 = (Math_fround(Math_sqrt((Math_fround($100)))));
  $102 = Math_fround(Math_fround(1.0) / $101);
  $103 = Math_fround($88 * $102);
  $104 = Math_fround($89 * $102);
  $105 = Math_fround($90 * $102);
  $106 = Math_fround($91 * $102);
  HEAPF32[$q$i3>>2] = $103;
  $107 = (($q$i3) + 4|0);
  HEAPF32[$107>>2] = $104;
  $108 = (($q$i3) + 8|0);
  HEAPF32[$108>>2] = $105;
  $109 = (($q$i3) + 12|0);
  HEAPF32[$109>>2] = $106;
  HEAPF32[$s$i4>>2] = Math_fround(1.0);
  $110 = (($s$i4) + 4|0);
  HEAPF32[$110>>2] = Math_fround(1.0);
  $111 = (($s$i4) + 8|0);
  HEAPF32[$111>>2] = Math_fround(1.0);
  __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($rootPose,$$byval_copy1,$q$i3,$s$i4);
  $112 = (($userData) + 12|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ($113|0)>(0);
  if ($114) {
   $115 = (($userData) + 4|0);
   $116 = (($userData) + 20|0);
   $117 = (($$byval_copy1) + 4|0);
   $118 = (($$byval_copy1) + 8|0);
   $119 = (($q$i3) + 4|0);
   $120 = (($q$i3) + 8|0);
   $121 = (($q$i3) + 12|0);
   $122 = (($s$i4) + 4|0);
   $123 = (($s$i4) + 8|0);
   $i$015 = 0;
   while(1) {
    $124 = HEAP32[$115>>2]|0;
    $125 = (($124) + ($i$015<<1)|0);
    $126 = HEAP16[$125>>1]|0;
    $127 = $126&65535;
    $128 = HEAP32[$3>>2]|0;
    $129 = (($128) + ($6))|0;
    $130 = $129;
    $131 = HEAP32[$116>>2]|0;
    $132 = (($131) + ($i$015<<6)|0);
    $$idx$i = (($130) + (($127*48)|0)|0);
    $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
    $$idx1$i = ((($130) + (($127*48)|0)|0) + 4|0);
    $$idx1$val$i = Math_fround(HEAPF32[$$idx1$i>>2]);
    $$idx2$i = ((($130) + (($127*48)|0)|0) + 8|0);
    $$idx2$val$i = Math_fround(HEAPF32[$$idx2$i>>2]);
    HEAPF32[$$byval_copy1>>2] = $$idx$val$i;
    HEAPF32[$117>>2] = $$idx1$val$i;
    HEAPF32[$118>>2] = $$idx2$val$i;
    $133 = ((($130) + (($127*48)|0)|0) + 16|0);
    $134 = Math_fround(HEAPF32[$133>>2]);
    $135 = Math_fround($134 * $134);
    $136 = ((($130) + (($127*48)|0)|0) + 20|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = Math_fround($137 * $137);
    $139 = ((($130) + (($127*48)|0)|0) + 24|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = Math_fround($140 * $140);
    $142 = ((($130) + (($127*48)|0)|0) + 28|0);
    $143 = Math_fround(HEAPF32[$142>>2]);
    $144 = Math_fround($143 * $143);
    $145 = Math_fround($135 + $138);
    $146 = Math_fround($141 + $144);
    $147 = Math_fround($145 + $146);
    $148 = (Math_fround(Math_sqrt((Math_fround($147)))));
    $149 = Math_fround(Math_fround(1.0) / $148);
    $150 = Math_fround($134 * $149);
    $151 = Math_fround($137 * $149);
    $152 = Math_fround($140 * $149);
    $153 = Math_fround($143 * $149);
    HEAPF32[$q$i3>>2] = $150;
    HEAPF32[$119>>2] = $151;
    HEAPF32[$120>>2] = $152;
    HEAPF32[$121>>2] = $153;
    $154 = ((($130) + (($127*48)|0)|0) + 32|0);
    $155 = Math_fround(HEAPF32[$154>>2]);
    $156 = ((($130) + (($127*48)|0)|0) + 36|0);
    $157 = Math_fround(HEAPF32[$156>>2]);
    $158 = ((($130) + (($127*48)|0)|0) + 40|0);
    $159 = Math_fround(HEAPF32[$158>>2]);
    HEAPF32[$s$i4>>2] = $155;
    HEAPF32[$122>>2] = $157;
    HEAPF32[$123>>2] = $159;
    __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($132,$$byval_copy1,$q$i3,$s$i4);
    $160 = (($i$015) + 1)|0;
    $161 = HEAP32[$112>>2]|0;
    $162 = ($160|0)<($161|0);
    if ($162) {
     $i$015 = $160;
    } else {
     break;
    }
   }
  }
 }
 $172 = HEAP32[$allocatedMemory>>2]|0;
 __ZN8Animator27FreeGlobalSpaceSkeletonPoseEPN7mecanim8skeleton12SkeletonPoseE($172);
 $173 = (($userData) + 16|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ($174|0)==(0|0);
 if ($175) {
  $191 = HEAP32[628432>>2]|0;
  HEAP32[$s$i4>>2] = $191;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$s$i4+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy1);
  STACKTOP = sp;return;
 }
 $176 = (($174) + 120|0);
 $177 = HEAP32[$176>>2]|0;
 $178 = (($userData) + 20|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = (($userData) + 12|0);
 $181 = HEAP32[$180>>2]|0;
 __Z33MultiplyMatrixArrayWithBase4x4REFPK10Matrix4x4fS1_S1_PS_j($rootPose,$179,$177,$179,$181);
 $182 = HEAP32[$173>>2]|0;
 $183 = HEAP32[628248>>2]|0;
 $184 = (($182) + 4|0);
 $185 = HEAP32[$184>>2]|0;
 $186 = (($185) + -1)|0;
 HEAP32[$184>>2] = $186;
 $187 = HEAP32[$184>>2]|0;
 $188 = ($187|0)==(0);
 if (!($188)) {
  $191 = HEAP32[628432>>2]|0;
  HEAP32[$s$i4>>2] = $191;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$s$i4+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy1);
  STACKTOP = sp;return;
 }
 $189 = HEAP32[$182>>2]|0;
 $190 = HEAP32[$189>>2]|0;
 FUNCTION_TABLE_vi[$190 & 4095]($182);
 HEAP32[$q$i3>>2] = $183;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$q$i3+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($182,$$byval_copy1);
 $191 = HEAP32[628432>>2]|0;
 HEAP32[$s$i4>>2] = $191;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$s$i4+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($userData,$$byval_copy1);
 STACKTOP = sp;return;
}
function __ZN16MecanimAnimation19PathHashesToIndicesERN5Unity9ComponentEPKjjPt($this,$animatorComponent,$bonePathHashes,$count,$outIndices) {
 $this = $this|0;
 $animatorComponent = $animatorComponent|0;
 $bonePathHashes = $bonePathHashes|0;
 $count = $count|0;
 $outIndices = $outIndices|0;
 var $$0 = 0, $$not = 0, $$not2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $doMatchSkeleton$0$off0$not = 0, $i$03 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($animatorComponent) + 465|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (__ZN8Animator17GetAvatarConstantEv($animatorComponent)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = $4;
 $7 = HEAP32[$4>>2]|0;
 $8 = (($7) + ($6))|0;
 $9 = $8;
 $10 = (($4) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = ($8|0)==(0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $$not2 = ($count|0)==(0);
 if ($$not2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $i$03 = 0;
 }
 while(1) {
  $12 = (($bonePathHashes) + ($i$03<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (__ZN7mecanim8skeleton16SkeletonFindNodeEPKNS0_8SkeletonEj($9,$13)|0);
  $15 = ($14|0)!=(-1);
  $16 = $14&65535;
  $17 = (($outIndices) + ($i$03<<1)|0);
  HEAP16[$17>>1] = $16;
  $18 = (($i$03) + 1)|0;
  $$not = ($18>>>0)>=($count>>>0);
  $doMatchSkeleton$0$off0$not = $15 ^ 1;
  $brmerge = $$not | $doMatchSkeleton$0$off0$not;
  if ($brmerge) {
   break;
  } else {
   $i$03 = $18;
  }
 }
 if ($15) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = (__ZN8Animator9GetAvatarEv($animatorComponent)|0);
 $20 = ($19|0)!=(0|0);
 if ($20) {
  $21 = HEAP32[$19>>2]|0;
  $22 = (($21) + 32|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (FUNCTION_TABLE_ii[$23 & 4095]($19)|0);
  $25 = $24;
 } else {
  $25 = 774672;
 }
 HEAP32[$vararg_buffer>>2] = $25;
 __Z6FormatPKcz($0,774680,$vararg_buffer);
 $26 = HEAP8[$0>>0]|0;
 $27 = $26 & 1;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  $31 = (($0) + 1|0);
  $34 = $31;
 } else {
  $29 = (($0) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $34 = $30;
 }
 if ($20) {
  $32 = (($19) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $35 = $33;
 } else {
  $35 = 0;
 }
 __THREW__ = 0;
 invoke_viiiiiiii(21,($34|0),0,(774864|0),45,1,($35|0),0,(0|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $43 = ___cxa_find_matching_catch()|0;
  $44 = tempRet0;
  $45 = HEAP8[$0>>0]|0;
  $46 = $45 & 1;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   ___resumeException($43|0);
   // unreachable;
  }
  $48 = (($0) + 8|0);
  $49 = HEAP32[$48>>2]|0;
  __ZdlPv($49);
  ___resumeException($43|0);
  // unreachable;
 } else {
  $38 = HEAP8[$0>>0]|0;
  $39 = $38 & 1;
  $40 = ($39<<24>>24)==(0);
  if ($40) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $41 = (($0) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  __ZdlPv($42);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN16MecanimAnimation25RegisterIAnimationBindingE11ClassIDTypeiP17IAnimationBinding($this,$classID,$inCustomType,$bindingInterface) {
 $this = $this|0;
 $classID = $classID|0;
 $inCustomType = $inCustomType|0;
 $bindingInterface = $bindingInterface|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN11UnityEngine9Animation31GetGenericAnimationBindingCacheEv()|0);
 __ZN11UnityEngine9Animation28GenericAnimationBindingCache25RegisterIAnimationBindingE11ClassIDTypeiP17IAnimationBinding($0,$classID,$inCustomType,$bindingInterface);
 STACKTOP = sp;return;
}
function __ZN16MecanimAnimation34SetGetGlobalSpaceSkeletonPoseFenceEPN5Unity9ComponentER8JobFence($this,$animator,$fence) {
 $this = $this|0;
 $animator = $animator|0;
 $fence = $fence|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($animator) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __Z21CompleteFenceInternalR8JobFence($0);
 }
 $3 = $fence;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN27StateMachineBehaviourPlayerC2EP28IStateMachineBehaviourSender($this,$sender) {
 $this = $this|0;
 $sender = $sender|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $sender;
 $1 = HEAP32[$sender>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($sender)|0);
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_ii[$9 & 4095]($6)|0);
 HEAP32[$this>>2] = $10;
 STACKTOP = sp;return;
}
function __ZNK27StateMachineBehaviourPlayer13FireBehaviourER8StateKeyR18ScriptingArgumentsN7mecanim12statemachine19StateMachineMessageE($this,$key,$arguments,$messageID) {
 $this = $this|0;
 $key = $key|0;
 $arguments = $arguments|0;
 $messageID = $messageID|0;
 var $$ = 0, $$0 = 0, $$0$i14$ph = 0, $$01 = 0, $$neg2$i$i$i$i$i$i = 0, $$sum$i$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i$i = 0, $__len$03$i$i$i$i$i$i = 0, $exception = 0, $i$018 = 0, $invocation = 0, $ret$0$off0$lcssa = 0;
 var $ret$0$off019 = 0, $ret$1$off0 = 0, $temp$0$i25 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $tmpcast$byval_copy = sp + 208|0;
 $0 = sp + 244|0;
 $1 = sp + 216|0;
 $invocation = sp + 8|0;
 $2 = sp;
 $exception = sp + 228|0;
 $3 = sp + 232|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $6;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 4;
 $13 = ($12|0)==(0);
 if ($13) {
  $30 = $6;
 } else {
  $14 = HEAP32[$key>>2]|0;
  $15 = (($key) + 4|0);
  $18 = $6;$__len$03$i$i$i$i$i$i = $12;
  while(1) {
   $16 = (($__len$03$i$i$i$i$i$i|0) / 2)&-1;
   $17 = (($18) + ($16<<4)|0);
   $19 = HEAP32[$17>>2]|0;
   $20 = ($19|0)==($14|0);
   if ($20) {
    $22 = ((($18) + ($16<<4)|0) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = HEAP32[$15>>2]|0;
    $25 = ($23|0)<($24|0);
    if ($25) {
     label = 6;
    } else {
     $207 = $18;$__len$0$be$i$i$i$i$i$i = $16;
    }
   } else {
    $21 = ($19>>>0)<($14>>>0);
    if ($21) {
     label = 6;
    } else {
     $207 = $18;$__len$0$be$i$i$i$i$i$i = $16;
    }
   }
   if ((label|0) == 6) {
    label = 0;
    $$sum$i$i$i$i$i$i = (($16) + 1)|0;
    $26 = (($18) + ($$sum$i$i$i$i$i$i<<4)|0);
    $$neg2$i$i$i$i$i$i = (($__len$03$i$i$i$i$i$i) + -1)|0;
    $27 = (($$neg2$i$i$i$i$i$i) - ($16))|0;
    $207 = $26;$__len$0$be$i$i$i$i$i$i = $27;
   }
   $28 = ($__len$0$be$i$i$i$i$i$i|0)==(0);
   if ($28) {
    $30 = $207;
    break;
   } else {
    $18 = $207;$__len$03$i$i$i$i$i$i = $__len$0$be$i$i$i$i$i$i;
   }
  }
 }
 $29 = ($30|0)==($8|0);
 do {
  if ($29) {
   $48 = 0;$49 = 0;
  } else {
   $31 = HEAP32[$key>>2]|0;
   $32 = HEAP32[$30>>2]|0;
   $33 = ($31|0)==($32|0);
   if ($33) {
    $35 = (($key) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($30) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($36|0)<($38|0);
    if ($39) {
     $48 = 0;$49 = 0;
     break;
    }
   } else {
    $34 = ($31>>>0)<($32>>>0);
    if ($34) {
     $48 = 0;$49 = 0;
     break;
    }
   }
   $40 = (($30) + 8|0);
   $41 = $40;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $48 = $43;$49 = $46;
  }
 } while(0);
 $47 = (($48) + ($49))|0;
 $50 = ($48>>>0)<($47>>>0);
 if (!($50)) {
  $ret$0$off0$lcssa = 0;
  STACKTOP = sp;return ($ret$0$off0$lcssa|0);
 }
 $51 = (($this) + 8|0);
 $52 = (($this) + 4|0);
 $53 = (($1) + 1|0);
 $54 = (($1) + 8|0);
 $55 = (($invocation) + 32|0);
 $56 = (($invocation) + 12|0);
 $57 = (($invocation) + 25|0);
 $58 = (($invocation) + 16|0);
 $59 = (($3) + 8|0);
 $i$018 = $48;$ret$0$off019 = 0;
 L22: while(1) {
  $60 = HEAP32[$51>>2]|0;
  $61 = HEAP32[$60>>2]|0;
  $62 = HEAP32[$61>>2]|0;
  $63 = (FUNCTION_TABLE_ii[$62 & 4095]($60)|0);
  if (!($63)) {
   $ret$0$off0$lcssa = $ret$0$off019;
   label = 57;
   break;
  }
  $64 = HEAP32[$this>>2]|0;
  $65 = (($64) + 16|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + ($i$018<<2)|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = HEAP32[$52>>2]|0;
  $70 = (($69) + 4|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = HEAP32[$69>>2]|0;
  $73 = $71;
  $74 = $72;
  $75 = (($73) - ($74))|0;
  $76 = $75 >> 2;
  $77 = ($68>>>0)<($76>>>0);
  L25: do {
   if ($77) {
    $78 = (($72) + ($68<<2)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($79|0)==(0);
    do {
     if (!($80)) {
      HEAP32[$0>>2] = $79;
      $81 = HEAP32[560624>>2]|0;
      $82 = ($81|0)==(0|0);
      if ($82) {
       label = 26;
      } else {
       $83 = (($81) + 36|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = (($81) + 4|0);
       $86 = HEAP32[$85>>2]|0;
       $87 = ($84|0)==($86|0);
       do {
        if ($87) {
         $88 = (($81) + 28|0);
         $89 = HEAP32[$88>>2]|0;
         $90 = (($81) + 32|0);
         $91 = HEAP32[$90>>2]|0;
         $92 = (($89) + ($91<<3)|0);
         $108 = $92;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast$byval_copy,$81,$0);
         $93 = HEAP32[$tmpcast$byval_copy>>2]|0;
         $94 = ($93|0)==(-1);
         $95 = (($81) + 28|0);
         $96 = HEAP32[$95>>2]|0;
         if ($94) {
          $97 = (($81) + 32|0);
          $98 = HEAP32[$97>>2]|0;
          $99 = (($96) + ($98<<3)|0);
          $108 = $99;
          break;
         } else {
          $100 = (($96) + ($93<<3)|0);
          $108 = $100;
          break;
         }
        }
       } while(0);
       $101 = HEAP32[560624>>2]|0;
       $102 = (($101) + 28|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = (($101) + 32|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = (($103) + ($105<<3)|0);
       $107 = ($108|0)==($106|0);
       if ($107) {
        label = 26;
       } else {
        $109 = (($108) + 4|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = ($110|0)==(0|0);
        if ($111) {
         label = 26;
        } else {
         $temp$0$i25 = $110;
        }
       }
      }
      if ((label|0) == 26) {
       label = 0;
       $112 = HEAP32[$78>>2]|0;
       $113 = (__Z31ReadObjectFromPersistentManageri($112)|0);
       $114 = ($113|0)==(0|0);
       if ($114) {
        break;
       } else {
        $temp$0$i25 = $113;
       }
      }
      $129 = (($temp$0$i25) + 20|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = ($130|0)==(0|0);
      if ($131) {
       $ret$1$off0 = $ret$0$off019;
       break L25;
      }
      $132 = (($temp$0$i25) + 28|0);
      $133 = HEAP8[$132>>0]|0;
      $134 = ($133<<24>>24)==(0);
      if ($134) {
       $ret$1$off0 = $ret$0$off019;
       break L25;
      }
      switch ($messageID|0) {
      case 2:  {
       $$0$i14$ph = 20;
       break;
      }
      case 8:  {
       $$0$i14$ph = 22;
       break;
      }
      case 16:  {
       $$0$i14$ph = 23;
       break;
      }
      case 1:  {
       $$0$i14$ph = 19;
       break;
      }
      case 64:  {
       $$0$i14$ph = 25;
       break;
      }
      case 32:  {
       $$0$i14$ph = 24;
       break;
      }
      case 4:  {
       $$0$i14$ph = 21;
       break;
      }
      default: {
       HEAP32[$tmpcast$byval_copy>>2] = $messageID;
       __Z6FormatPKcz($1,774952,$tmpcast$byval_copy);
       $135 = HEAP32[$51>>2]|0;
       $136 = HEAP32[$135>>2]|0;
       $137 = (($136) + 12|0);
       $138 = HEAP32[$137>>2]|0;
       __THREW__ = 0;
       $139 = (invoke_ii($138|0,($135|0))|0);
       $140 = __THREW__; __THREW__ = 0;
       $141 = $140&1;
       if ($141) {
        label = 46;
        break L22;
       }
       $142 = ($139|0)==(0|0);
       if ($142) {
        $156 = 0;
       } else {
        $143 = HEAP32[$51>>2]|0;
        $144 = HEAP32[$143>>2]|0;
        $145 = (($144) + 12|0);
        $146 = HEAP32[$145>>2]|0;
        __THREW__ = 0;
        $147 = (invoke_ii($146|0,($143|0))|0);
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if ($149) {
         label = 46;
         break L22;
        }
        $150 = (($147) + 4|0);
        $151 = HEAP32[$150>>2]|0;
        $156 = $151;
       }
       $152 = HEAP8[$1>>0]|0;
       $153 = $152 & 1;
       $154 = ($153<<24>>24)==(0);
       $155 = HEAP32[$54>>2]|0;
       $$ = $154 ? $53 : $155;
       __THREW__ = 0;
       invoke_viiiiiiii(21,($$|0),0,(774944|0),68,512,($156|0),0,(0|0));
       $157 = __THREW__; __THREW__ = 0;
       $158 = $157&1;
       if ($158) {
        label = 46;
        break L22;
       }
       $159 = HEAP8[$1>>0]|0;
       $160 = $159 & 1;
       $161 = ($160<<24>>24)==(0);
       if ($161) {
        $ret$1$off0 = $ret$0$off019;
        break L25;
       }
       $162 = HEAP32[$54>>2]|0;
       __ZdlPv($162);
       $ret$1$off0 = $ret$0$off019;
       break L25;
      }
      }
      $169 = (($temp$0$i25) + 52|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = (($170) + ($$0$i14$ph<<3)|0);
      $172 = $171;
      $173 = $172;
      $174 = HEAP32[$173>>2]|0;
      $175 = (($172) + 4)|0;
      $176 = $175;
      $177 = HEAP32[$176>>2]|0;
      $178 = ($174|0)==(0);
      if ($178) {
       $ret$1$off0 = $ret$0$off019;
       break L25;
      }
      $179 = $2;
      $180 = $179;
      HEAP32[$180>>2] = $174;
      $181 = (($179) + 4)|0;
      $182 = $181;
      HEAP32[$182>>2] = $177;
      ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
      __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation,$tmpcast$byval_copy);
      HEAP32[$exception>>2] = 0;
      _memcpy(($55|0),($arguments|0),164)|0;
      $183 = HEAP32[$129>>2]|0;
      HEAP32[$56>>2] = $183;
      HEAP8[$57>>0] = 1;
      $184 = (($temp$0$i25) + 4|0);
      $185 = HEAP32[$184>>2]|0;
      HEAP32[$58>>2] = $185;
      (__ZN19ScriptingInvocation6InvokeEPP18ScriptingException($invocation,$exception)|0);
      $186 = HEAP32[$exception>>2]|0;
      $187 = ($186|0)==(0|0);
      if (!($187)) {
       $188 = HEAP32[$129>>2]|0;
       $189 = (__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject($188)|0);
       ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
       __THREW__ = 0;
       invoke_viii(1731,($186|0),($189|0),($3|0));
       $190 = __THREW__; __THREW__ = 0;
       $191 = $190&1;
       if ($191) {
        label = 53;
        break L22;
       }
       $192 = HEAP8[$3>>0]|0;
       $193 = $192 & 1;
       $194 = ($193<<24>>24)==(0);
       if (!($194)) {
        $195 = HEAP32[$59>>2]|0;
        __ZdlPv($195);
       }
      }
      $202 = HEAP32[$exception>>2]|0;
      $203 = ($202|0)==(0|0);
      $204 = $ret$0$off019 | $203;
      $ret$1$off0 = $204;
      break L25;
     }
    } while(0);
    $115 = HEAP32[$51>>2]|0;
    $116 = HEAP32[$115>>2]|0;
    $117 = (($116) + 12|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (FUNCTION_TABLE_ii[$118 & 4095]($115)|0);
    $120 = ($119|0)==(0|0);
    if ($120) {
     $128 = 0;
    } else {
     $121 = HEAP32[$51>>2]|0;
     $122 = HEAP32[$121>>2]|0;
     $123 = (($122) + 12|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = (FUNCTION_TABLE_ii[$124 & 4095]($121)|0);
     $126 = (($125) + 4|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = $127;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(774904,0,774944,50,512,$128,0,0);
    $ret$1$off0 = $ret$0$off019;
   } else {
    $ret$1$off0 = $ret$0$off019;
   }
  } while(0);
  $205 = (($i$018) + 1)|0;
  $206 = ($205>>>0)<($47>>>0);
  if ($206) {
   $i$018 = $205;$ret$0$off019 = $ret$1$off0;
  } else {
   $ret$0$off0$lcssa = $ret$1$off0;
   label = 57;
   break;
  }
 }
 if ((label|0) == 46) {
  $163 = ___cxa_find_matching_catch()|0;
  $164 = tempRet0;
  $165 = HEAP8[$1>>0]|0;
  $166 = $165 & 1;
  $167 = ($166<<24>>24)==(0);
  if ($167) {
   $$0 = $164;$$01 = $163;
   ___resumeException($$01|0);
   // unreachable;
  }
  $168 = HEAP32[$54>>2]|0;
  __ZdlPv($168);
  $$0 = $164;$$01 = $163;
  ___resumeException($$01|0);
  // unreachable;
 }
 else if ((label|0) == 53) {
  $196 = ___cxa_find_matching_catch()|0;
  $197 = tempRet0;
  $198 = HEAP8[$3>>0]|0;
  $199 = $198 & 1;
  $200 = ($199<<24>>24)==(0);
  if ($200) {
   $$0 = $197;$$01 = $196;
   ___resumeException($$01|0);
   // unreachable;
  }
  $201 = HEAP32[$59>>2]|0;
  __ZdlPv($201);
  $$0 = $197;$$01 = $196;
  ___resumeException($$01|0);
  // unreachable;
 }
 else if ((label|0) == 57) {
  STACKTOP = sp;return ($ret$0$off0$lcssa|0);
 }
 return 0|0;
}
function __ZNK27StateMachineBehaviourPlayer15IsSenderEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($1)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZNK27StateMachineBehaviourPlayer18FireStateBehaviourER17AnimatorStateInfoiN7mecanim12statemachine19StateMachineMessageE($this,$info,$layerIndex,$messageID) {
 $this = $this|0;
 $info = $info|0;
 $layerIndex = $layerIndex|0;
 $messageID = $messageID|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $arguments = 0, $stateKey = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $arguments = sp;
 $stateKey = sp + 168|0;
 __ZN18ScriptingArgumentsC2Ev($arguments);
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = (__ZN9Scripting19ScriptingWrapperForEP6Object($5)|0);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($arguments,$6);
 __ZN18ScriptingArguments9AddStructEPv($arguments,$info);
 __ZN18ScriptingArguments6AddIntEi($arguments,$layerIndex);
 $7 = (($info) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$stateKey>>2] = $8;
 $9 = (($stateKey) + 4|0);
 HEAP32[$9>>2] = $layerIndex;
 $10 = (__ZNK27StateMachineBehaviourPlayer13FireBehaviourER8StateKeyR18ScriptingArgumentsN7mecanim12statemachine19StateMachineMessageE($this,$stateKey,$arguments,$messageID)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZNK27StateMachineBehaviourPlayer25FireStateMachineBehaviourEiN7mecanim12statemachine19StateMachineMessageE($this,$stateMachineFullPath,$messageID) {
 $this = $this|0;
 $stateMachineFullPath = $stateMachineFullPath|0;
 $messageID = $messageID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $arguments = 0, $stateKey = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $arguments = sp;
 $stateKey = sp + 168|0;
 __ZN18ScriptingArgumentsC2Ev($arguments);
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = (__ZN9Scripting19ScriptingWrapperForEP6Object($5)|0);
 __ZN18ScriptingArguments9AddObjectEP15ScriptingObject($arguments,$6);
 __ZN18ScriptingArguments6AddIntEi($arguments,$stateMachineFullPath);
 HEAP32[$stateKey>>2] = $stateMachineFullPath;
 $7 = (($stateKey) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (__ZNK27StateMachineBehaviourPlayer13FireBehaviourER8StateKeyR18ScriptingArgumentsN7mecanim12statemachine19StateMachineMessageE($this,$stateKey,$arguments,$messageID)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN7mecanim9animation18CreateAnimationSetEPKNS0_18ControllerConstantEjRNS_6memory9AllocatorE($controller,$clipCount,$alloc) {
 $controller = $controller|0;
 $clipCount = $clipCount|0;
 $alloc = $alloc|0;
 var $$0$i2 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre18 = 0, $$pre19 = 0, $$pre23$pre = 0, $$pre25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blendTreeIter$06 = 0, $i$015 = 0, $layerIter$011 = 0, $phitmp = 0, $phitmp27 = 0, $stateIter$07 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,40,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $8 = 0;
 } else {
  $4 = (($2) + 32|0);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
  HEAP32[$4>>2] = -1;
  $5 = (($2) + 36|0);
  HEAP32[$5>>2] = -1;
  $8 = $2;
 }
 $6 = HEAP32[$controller>>2]|0;
 $7 = (($8) + 4|0);
 HEAP32[$7>>2] = $6;
 $9 = (($8) + 8|0);
 HEAP32[$9>>2] = $clipCount;
 $10 = ($clipCount|0)==(0);
 if ($10) {
  $$0$i2 = 0;
 } else {
  $11 = HEAP32[$alloc>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = ($clipCount*36)|0;
  $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($alloc,$13,4)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $$0$i2 = 0;
  } else {
   $16 = (($14) + (($clipCount*36)|0)|0);
   $17 = $14;
   while(1) {
    HEAP32[$17>>2] = 0;
    $18 = (($17) + 4|0);
    HEAP32[$18>>2] = -1;
    $19 = (($17) + 8|0);
    ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;HEAP32[$19+16>>2]=0|0;HEAP32[$19+20>>2]=0|0;HEAP32[$19+24>>2]=0|0;
    $20 = (($17) + 36|0);
    $21 = ($20|0)==($16|0);
    if ($21) {
     $$0$i2 = $14;
     break;
    } else {
     $17 = $20;
    }
   }
  }
 }
 $22 = (($8) + 12|0);
 HEAP32[$22>>2] = $$0$i2;
 $23 = (($controller) + 24|0);
 $24 = $23;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($8) + 16|0);
 HEAP32[$29>>2] = $28;
 $30 = ($28|0)==(0);
 if ($30) {
  $31 = (($8) + 20|0);
  HEAP32[$31>>2] = 0;
 } else {
  $32 = HEAP32[$alloc>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = $28 << 2;
  $35 = (FUNCTION_TABLE_iiii[$33 & 2047]($alloc,$34,4)|0);
  $$pre = HEAP32[$29>>2]|0;
  $phitmp = ($$pre|0)==(0);
  $36 = (($8) + 20|0);
  HEAP32[$36>>2] = $35;
  if (!($phitmp)) {
   $i$015 = 0;
   while(1) {
    $37 = (($35) + ($i$015<<2)|0);
    HEAP32[$37>>2] = -1;
    $38 = (($i$015) + 1)|0;
    $39 = HEAP32[$29>>2]|0;
    $40 = ($38>>>0)<($39>>>0);
    if ($40) {
     $i$015 = $38;
    } else {
     break;
    }
   }
  }
 }
 $41 = HEAP32[$7>>2]|0;
 $42 = ($41|0)==(0);
 if ($42) {
  $43 = (($8) + 28|0);
  HEAP32[$43>>2] = 0;
 } else {
  $44 = HEAP32[$alloc>>2]|0;
  $45 = HEAP32[$44>>2]|0;
  $46 = $41 << 2;
  $47 = (FUNCTION_TABLE_iiii[$45 & 2047]($alloc,$46,4)|0);
  $$pre18 = HEAP32[$7>>2]|0;
  $phitmp27 = ($$pre18|0)==(0);
  $48 = (($8) + 28|0);
  HEAP32[$48>>2] = $47;
  if (!($phitmp27)) {
   $49 = (($controller) + 4|0);
   $50 = $49;
   $51 = (($controller) + 16|0);
   $52 = $51;
   $124 = $$pre18;$layerIter$011 = 0;
   while(1) {
    $53 = HEAP32[$49>>2]|0;
    $54 = (($53) + ($50))|0;
    $55 = $54;
    $56 = (($55) + ($layerIter$011<<3)|0);
    $57 = $56;
    $58 = HEAP32[$56>>2]|0;
    $59 = (($57) + ($58))|0;
    $60 = $59;
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)==(-1);
    if ($62) {
     $119 = $124;
    } else {
     $63 = HEAP32[$51>>2]|0;
     $64 = (($63) + ($52))|0;
     $65 = $64;
     $66 = (($65) + ($61<<3)|0);
     $67 = $66;
     $68 = HEAP32[$66>>2]|0;
     $69 = (($67) + ($68))|0;
     $70 = $69;
     $71 = ((($65) + ($61<<3)|0) + 4|0);
     HEAP32[$71>>2] = $70;
     $72 = HEAP32[$70>>2]|0;
     $73 = ($72|0)==(0);
     if ($73) {
      $119 = $124;
     } else {
      $125 = $72;$75 = $63;$stateIter$07 = 0;
      while(1) {
       $74 = (($75) + ($52))|0;
       $76 = $74;
       $77 = (($76) + ($61<<3)|0);
       $78 = $77;
       $79 = HEAP32[$77>>2]|0;
       $80 = (($78) + ($79))|0;
       $81 = $80;
       $82 = (($81) + 4|0);
       $83 = $82;
       $84 = HEAP32[$82>>2]|0;
       $85 = (($83) + ($84))|0;
       $86 = $85;
       $87 = (($86) + ($stateIter$07<<3)|0);
       $88 = $87;
       $89 = HEAP32[$87>>2]|0;
       $90 = (($88) + ($89))|0;
       $91 = $90;
       $92 = (($91) + 32|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = ($93|0)==(0);
       if ($94) {
        $114 = $125;
       } else {
        $95 = (($91) + 36|0);
        $96 = $95;
        $blendTreeIter$06 = 0;
        while(1) {
         $97 = HEAP32[$95>>2]|0;
         $98 = (($97) + ($96))|0;
         $99 = $98;
         $100 = (($99) + ($blendTreeIter$06<<3)|0);
         $101 = $100;
         $102 = HEAP32[$100>>2]|0;
         $103 = (($101) + ($102))|0;
         $104 = $103;
         $105 = (__ZN7mecanim9animation16GetMaxBlendCountERKNS0_17BlendTreeConstantE($104)|0);
         $106 = HEAP32[$8>>2]|0;
         $107 = ($106>>>0)<($105>>>0);
         $108 = $107 ? $105 : $106;
         HEAP32[$8>>2] = $108;
         $109 = (($blendTreeIter$06) + 1)|0;
         $110 = HEAP32[$92>>2]|0;
         $111 = ($109>>>0)<($110>>>0);
         if ($111) {
          $blendTreeIter$06 = $109;
         } else {
          break;
         }
        }
        $$pre19 = HEAP32[$70>>2]|0;
        $114 = $$pre19;
       }
       $112 = (($stateIter$07) + 1)|0;
       $113 = ($112>>>0)<($114>>>0);
       if (!($113)) {
        break;
       }
       $$pre25 = HEAP32[$51>>2]|0;
       $125 = $114;$75 = $$pre25;$stateIter$07 = $112;
      }
      $$pre23$pre = HEAP32[$7>>2]|0;
      $119 = $$pre23$pre;
     }
    }
    $115 = HEAP32[$48>>2]|0;
    $116 = (($115) + ($layerIter$011<<2)|0);
    HEAP32[$116>>2] = 0;
    $117 = (($layerIter$011) + 1)|0;
    $118 = ($117>>>0)<($119>>>0);
    if ($118) {
     $124 = $119;$layerIter$011 = $117;
    } else {
     $$pre$phiZ2D = $8;
     break;
    }
   }
   $120 = HEAP32[$$pre$phiZ2D>>2]|0;
   $121 = $120 << 1;
   $122 = ($121>>>0)<(2);
   $123 = $122 ? 2 : $121;
   HEAP32[$$pre$phiZ2D>>2] = $123;
   STACKTOP = sp;return ($8|0);
  }
 }
 $$pre$phiZ2D = $8;
 $120 = HEAP32[$$pre$phiZ2D>>2]|0;
 $121 = $120 << 1;
 $122 = ($121>>>0)<(2);
 $123 = $122 ? 2 : $121;
 HEAP32[$$pre$phiZ2D>>2] = $123;
 STACKTOP = sp;return ($8|0);
}
function __ZN7mecanim9animation24CreateAnimationSetMemoryEPKNS0_12AnimationSetEbRNS_6memory9AllocatorE($animationSet,$allowConstantCurveOptimization,$alloc) {
 $animationSet = $animationSet|0;
 $allowConstantCurveOptimization = $allowConstantCurveOptimization|0;
 $alloc = $alloc|0;
 var $$0$i = 0, $$lcssa = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $clipIter$02 = 0, $clipIter$02$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,12,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $8 = 0;
 } else {
  HEAP32[$2>>2] = 0;
  $4 = (($2) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($2) + 8|0);
  HEAP32[$5>>2] = 0;
  $8 = $2;
 }
 $6 = (($animationSet) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$6>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0$i = 0;$17 = $7;
 } else {
  $11 = HEAP32[$alloc>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = $9 << 2;
  $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($alloc,$13,4)|0);
  $$pre = HEAP32[$8>>2]|0;
  $$0$i = $14;$17 = $$pre;
 }
 $15 = (($8) + 4|0);
 HEAP32[$15>>2] = $$0$i;
 $16 = ($17|0)==(0);
 if ($16) {
  $$lcssa = 0;
  $64 = (__ZN7mecanim9animation16CreateClipOutputEiRNS_6memory9AllocatorE($$lcssa,$alloc)|0);
  $65 = (($8) + 8|0);
  HEAP32[$65>>2] = $64;
  STACKTOP = sp;return ($8|0);
 }
 $18 = (($animationSet) + 12|0);
 if ($allowConstantCurveOptimization) {
  $26 = 0;$66 = $17;$clipIter$02$us = 0;
  while(1) {
   $19 = HEAP32[$18>>2]|0;
   $20 = (($19) + (($clipIter$02$us*36)|0)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   if ($22) {
    $37 = HEAP32[$15>>2]|0;
    $38 = (($37) + ($clipIter$02$us<<2)|0);
    HEAP32[$38>>2] = 0;
    $41 = $66;$68 = $26;
   } else {
    $23 = ((($19) + (($clipIter$02$us*36)|0)|0) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($26>>>0)<($24>>>0);
    $27 = $25 ? $24 : $26;
    $28 = (($21) + 1040|0);
    $29 = $28;
    $30 = HEAP32[$28>>2]|0;
    $31 = (($30) + ($29))|0;
    $32 = $31;
    $33 = (($21) + 1044|0);
    HEAP32[$33>>2] = $32;
    $34 = (__ZN7mecanim9animation16CreateClipMemoryEPKNS0_4ClipEiRNS_6memory9AllocatorE($32,$24,$alloc)|0);
    $35 = HEAP32[$15>>2]|0;
    $36 = (($35) + ($clipIter$02$us<<2)|0);
    HEAP32[$36>>2] = $34;
    $$pre5 = HEAP32[$8>>2]|0;
    $41 = $$pre5;$68 = $27;
   }
   $39 = (($clipIter$02$us) + 1)|0;
   $40 = ($39>>>0)<($41>>>0);
   if ($40) {
    $26 = $68;$66 = $41;$clipIter$02$us = $39;
   } else {
    $$lcssa = $68;
    break;
   }
  }
  $64 = (__ZN7mecanim9animation16CreateClipOutputEiRNS_6memory9AllocatorE($$lcssa,$alloc)|0);
  $65 = (($8) + 8|0);
  HEAP32[$65>>2] = $64;
  STACKTOP = sp;return ($8|0);
 } else {
  $48 = 0;$67 = $17;$clipIter$02 = 0;
  while(1) {
   $42 = HEAP32[$18>>2]|0;
   $43 = (($42) + (($clipIter$02*36)|0)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($44|0)==(0|0);
   if ($45) {
    $59 = HEAP32[$15>>2]|0;
    $60 = (($59) + ($clipIter$02<<2)|0);
    HEAP32[$60>>2] = 0;
    $63 = $67;$69 = $48;
   } else {
    $46 = (__ZN7mecanim9animation17GetClipCurveCountERKNS0_18ClipMuscleConstantE($44)|0);
    $47 = ($48>>>0)<($46>>>0);
    $49 = $47 ? $46 : $48;
    $50 = (($44) + 1040|0);
    $51 = $50;
    $52 = HEAP32[$50>>2]|0;
    $53 = (($52) + ($51))|0;
    $54 = $53;
    $55 = (($44) + 1044|0);
    HEAP32[$55>>2] = $54;
    $56 = (__ZN7mecanim9animation16CreateClipMemoryEPKNS0_4ClipEiRNS_6memory9AllocatorE($54,$46,$alloc)|0);
    $57 = HEAP32[$15>>2]|0;
    $58 = (($57) + ($clipIter$02<<2)|0);
    HEAP32[$58>>2] = $56;
    $$pre6 = HEAP32[$8>>2]|0;
    $63 = $$pre6;$69 = $49;
   }
   $61 = (($clipIter$02) + 1)|0;
   $62 = ($61>>>0)<($63>>>0);
   if ($62) {
    $48 = $69;$67 = $63;$clipIter$02 = $61;
   } else {
    $$lcssa = $69;
    break;
   }
  }
  $64 = (__ZN7mecanim9animation16CreateClipOutputEiRNS_6memory9AllocatorE($$lcssa,$alloc)|0);
  $65 = (($8) + 8|0);
  HEAP32[$65>>2] = $64;
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __ZN7mecanim9animation25DestroyAnimationSetMemoryEPNS0_18AnimationSetMemoryERNS_6memory9AllocatorE($animationSetMemory,$alloc) {
 $animationSetMemory = $animationSetMemory|0;
 $alloc = $alloc|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $clipIter$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($animationSetMemory|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$animationSetMemory>>2]|0;
 $2 = ($1|0)==(0);
 $$pre = (($animationSetMemory) + 4|0);
 if (!($2)) {
  $clipIter$01 = 0;
  while(1) {
   $3 = HEAP32[$$pre>>2]|0;
   $4 = (($3) + ($clipIter$01<<2)|0);
   $5 = HEAP32[$4>>2]|0;
   __ZN7mecanim9animation17DestroyClipMemoryEPNS0_10ClipMemoryERNS_6memory9AllocatorE($5,$alloc);
   $6 = (($clipIter$01) + 1)|0;
   $7 = HEAP32[$animationSetMemory>>2]|0;
   $8 = ($6>>>0)<($7>>>0);
   if ($8) {
    $clipIter$01 = $6;
   } else {
    break;
   }
  }
 }
 $9 = HEAP32[$alloc>>2]|0;
 $10 = (($9) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$$pre>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095]($alloc,$12);
 $13 = (($animationSetMemory) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN7mecanim9animation17DestroyClipOutputEPNS0_10ClipOutputERNS_6memory9AllocatorE($14,$alloc);
 $15 = HEAP32[$alloc>>2]|0;
 $16 = (($15) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($alloc,$animationSetMemory);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation14AvatarConstant15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z27RegisterAllowNameConversionPKcS0_S0_(774976,774992,775008);
 __Z27RegisterAllowNameConversionPKcS0_S0_(774976,775032,775048);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation20CreateAvatarConstantEPNS_8skeleton8SkeletonEPNS1_12SkeletonPoseES5_PNS_5human5HumanES3_iRKN4math5xformERNS_6memory9AllocatorE($skeleton,$skeletonPose,$defaultPose,$human,$rootMotionSkeleton,$rootMotionIndex,$rootMotionX,$alloc) {
 $skeleton = $skeleton|0;
 $skeletonPose = $skeletonPose|0;
 $defaultPose = $defaultPose|0;
 $human = $human|0;
 $rootMotionSkeleton = $rootMotionSkeleton|0;
 $rootMotionIndex = $rootMotionIndex|0;
 $rootMotionX = $rootMotionX|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0);
 var $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,148,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $15 = 0;
 } else {
  $4 = (($2) + 68|0);
  dest=$2+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAP32[$4>>2] = -1;
  $5 = (($2) + 72|0);
  $6 = (($2) + 100|0);
  ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;HEAP32[$5+24>>2]=0|0;
  HEAPF32[$6>>2] = Math_fround(1.0);
  $7 = (($2) + 104|0);
  HEAPF32[$7>>2] = Math_fround(1.0);
  $8 = (($2) + 108|0);
  HEAPF32[$8>>2] = Math_fround(1.0);
  $9 = (($2) + 112|0);
  HEAPF32[$9>>2] = Math_fround(1.0);
  $10 = (($2) + 116|0);
  HEAPF32[$10>>2] = Math_fround(1.0);
  $11 = (($2) + 120|0);
  ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;HEAP32[$11+24>>2]=0|0;
  $15 = $2;
 }
 $12 = ($skeleton|0)==(0|0);
 if ($12) {
  $17 = 0;
 } else {
  $13 = $skeleton;
  $14 = $15;
  $16 = (($13) - ($14))|0;
  $17 = $16;
 }
 HEAP32[$15>>2] = $17;
 $18 = (($15) + 4|0);
 HEAP32[$18>>2] = $skeleton;
 $19 = (($15) + 8|0);
 $20 = ($skeletonPose|0)==(0|0);
 if ($20) {
  $24 = 0;
 } else {
  $21 = $skeletonPose;
  $22 = $19;
  $23 = (($21) - ($22))|0;
  $24 = $23;
 }
 HEAP32[$19>>2] = $24;
 $25 = (($15) + 12|0);
 HEAP32[$25>>2] = $skeletonPose;
 $26 = (($15) + 16|0);
 $27 = ($defaultPose|0)==(0|0);
 if ($27) {
  $31 = 0;
 } else {
  $28 = $defaultPose;
  $29 = $26;
  $30 = (($28) - ($29))|0;
  $31 = $30;
 }
 HEAP32[$26>>2] = $31;
 $32 = (($15) + 20|0);
 HEAP32[$32>>2] = $defaultPose;
 $33 = (($15) + 36|0);
 $34 = ($human|0)==(0|0);
 if ($34) {
  $38 = 0;
 } else {
  $35 = $human;
  $36 = $33;
  $37 = (($35) - ($36))|0;
  $38 = $37;
 }
 HEAP32[$33>>2] = $38;
 $39 = (($15) + 40|0);
 HEAP32[$39>>2] = $human;
 $40 = (($15) + 120|0);
 $41 = ($rootMotionSkeleton|0)==(0|0);
 if ($41) {
  $45 = 0;
 } else {
  $42 = $rootMotionSkeleton;
  $43 = $40;
  $44 = (($42) - ($43))|0;
  $45 = $44;
 }
 HEAP32[$40>>2] = $45;
 $46 = (($15) + 124|0);
 HEAP32[$46>>2] = $rootMotionSkeleton;
 $47 = (($15) + 68|0);
 HEAP32[$47>>2] = $rootMotionIndex;
 $48 = Math_fround(HEAPF32[$rootMotionX>>2]);
 $49 = (($rootMotionX) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($rootMotionX) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($rootMotionX) + 12|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($15) + 72|0);
 HEAPF32[$55>>2] = $48;
 $56 = (($15) + 76|0);
 HEAPF32[$56>>2] = $50;
 $57 = (($15) + 80|0);
 HEAPF32[$57>>2] = $52;
 $58 = (($15) + 84|0);
 HEAPF32[$58>>2] = $54;
 $59 = (($rootMotionX) + 16|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($rootMotionX) + 20|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($rootMotionX) + 24|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($rootMotionX) + 28|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($15) + 88|0);
 HEAPF32[$67>>2] = $60;
 $68 = (($15) + 92|0);
 HEAPF32[$68>>2] = $62;
 $69 = (($15) + 96|0);
 HEAPF32[$69>>2] = $64;
 $70 = (($15) + 100|0);
 HEAPF32[$70>>2] = $66;
 $71 = (($rootMotionX) + 32|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($rootMotionX) + 36|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($rootMotionX) + 40|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($rootMotionX) + 44|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($15) + 104|0);
 HEAPF32[$79>>2] = $72;
 $80 = (($15) + 108|0);
 HEAPF32[$80>>2] = $74;
 $81 = (($15) + 112|0);
 HEAPF32[$81>>2] = $76;
 $82 = (($15) + 116|0);
 HEAPF32[$82>>2] = $78;
 if ($34) {
  $136 = ($rootMotionIndex|0)==(-1);
  if ($136) {
   STACKTOP = sp;return ($15|0);
  }
  $137 = HEAP32[$rootMotionSkeleton>>2]|0;
  $138 = (($15) + 136|0);
  HEAP32[$138>>2] = $137;
  $139 = (($15) + 140|0);
  $140 = ($137|0)==(0);
  if ($140) {
   $149 = 0;
  } else {
   $141 = HEAP32[$alloc>>2]|0;
   $142 = HEAP32[$141>>2]|0;
   $143 = $137 << 2;
   $144 = (FUNCTION_TABLE_iiii[$142 & 2047]($alloc,$143,4)|0);
   $145 = ($144|0)==(0|0);
   if ($145) {
    $149 = 0;
   } else {
    $146 = $144;
    $147 = $139;
    $148 = (($146) - ($147))|0;
    $149 = $148;
   }
  }
  HEAP32[$139>>2] = $149;
  $150 = (($15) + 144|0);
  $151 = $139;
  $152 = (($149) + ($151))|0;
  $153 = $152;
  HEAP32[$150>>2] = $153;
  $154 = $40;
  $155 = HEAP32[$40>>2]|0;
  $156 = (($155) + ($154))|0;
  $157 = $156;
  HEAP32[$46>>2] = $157;
  __ZN7mecanim8skeleton23SkeletonBuildIndexArrayEPiPKNS0_8SkeletonES4_($153,$157,$skeleton);
  STACKTOP = sp;return ($15|0);
 }
 $83 = (($human) + 48|0);
 $84 = $83;
 $85 = HEAP32[$83>>2]|0;
 $86 = (($85) + ($84))|0;
 $87 = $86;
 $88 = (($human) + 52|0);
 HEAP32[$88>>2] = $87;
 $89 = HEAP32[$87>>2]|0;
 $90 = (($15) + 44|0);
 HEAP32[$90>>2] = $89;
 $91 = (($15) + 48|0);
 $92 = ($89|0)==(0);
 if ($92) {
  $101 = 0;
 } else {
  $93 = HEAP32[$alloc>>2]|0;
  $94 = HEAP32[$93>>2]|0;
  $95 = $89 << 2;
  $96 = (FUNCTION_TABLE_iiii[$94 & 2047]($alloc,$95,4)|0);
  $97 = ($96|0)==(0|0);
  if ($97) {
   $101 = 0;
  } else {
   $98 = $96;
   $99 = $91;
   $100 = (($98) - ($99))|0;
   $101 = $100;
  }
 }
 HEAP32[$91>>2] = $101;
 $102 = (($15) + 52|0);
 $103 = $91;
 $104 = (($101) + ($103))|0;
 $105 = $104;
 HEAP32[$102>>2] = $105;
 $106 = HEAP32[$83>>2]|0;
 $107 = (($106) + ($84))|0;
 $108 = $107;
 HEAP32[$88>>2] = $108;
 __ZN7mecanim8skeleton23SkeletonBuildIndexArrayEPiPKNS0_8SkeletonES4_($105,$108,$skeleton);
 $109 = $15;
 $110 = HEAP32[$15>>2]|0;
 $111 = (($110) + ($109))|0;
 $112 = $111;
 HEAP32[$18>>2] = $112;
 $113 = HEAP32[$112>>2]|0;
 $114 = (($15) + 56|0);
 HEAP32[$114>>2] = $113;
 $115 = (($15) + 60|0);
 $116 = ($113|0)==(0);
 if ($116) {
  $125 = 0;
 } else {
  $117 = HEAP32[$alloc>>2]|0;
  $118 = HEAP32[$117>>2]|0;
  $119 = $113 << 2;
  $120 = (FUNCTION_TABLE_iiii[$118 & 2047]($alloc,$119,4)|0);
  $121 = ($120|0)==(0|0);
  if ($121) {
   $125 = 0;
  } else {
   $122 = $120;
   $123 = $115;
   $124 = (($122) - ($123))|0;
   $125 = $124;
  }
 }
 HEAP32[$115>>2] = $125;
 $126 = (($15) + 64|0);
 $127 = $115;
 $128 = (($125) + ($127))|0;
 $129 = $128;
 HEAP32[$126>>2] = $129;
 $130 = HEAP32[$91>>2]|0;
 $131 = (($130) + ($103))|0;
 $132 = $131;
 HEAP32[$102>>2] = $132;
 $133 = HEAP32[$83>>2]|0;
 $134 = (($133) + ($84))|0;
 $135 = $134;
 HEAP32[$88>>2] = $135;
 __ZN7mecanim8skeleton30SkeletonBuildReverseIndexArrayEPiPKiPKNS0_8SkeletonES6_($129,$132,$135,$skeleton);
 STACKTOP = sp;return ($15|0);
}
function __ZN7mecanim9animation21DestroyAvatarConstantEPNS0_14AvatarConstantERNS_6memory9AllocatorE($constant,$alloc) {
 $constant = $constant|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($constant|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($constant) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = HEAP32[$alloc>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $1;
  $8 = (($2) + ($7))|0;
  $9 = $8;
  $10 = (($constant) + 52|0);
  HEAP32[$10>>2] = $9;
  $11 = $8;
  FUNCTION_TABLE_vii[$6 & 4095]($alloc,$11);
 }
 $12 = (($constant) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = HEAP32[$alloc>>2]|0;
  $16 = (($15) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $12;
  $19 = (($13) + ($18))|0;
  $20 = $19;
  $21 = (($constant) + 64|0);
  HEAP32[$21>>2] = $20;
  $22 = $19;
  FUNCTION_TABLE_vii[$17 & 4095]($alloc,$22);
 }
 $23 = (($constant) + 140|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = HEAP32[$alloc>>2]|0;
  $27 = (($26) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $23;
  $30 = (($24) + ($29))|0;
  $31 = $30;
  $32 = (($constant) + 144|0);
  HEAP32[$32>>2] = $31;
  $33 = $30;
  FUNCTION_TABLE_vii[$28 & 4095]($alloc,$33);
 }
 $34 = HEAP32[$alloc>>2]|0;
 $35 = (($34) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($alloc,$constant);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17CreateAvatarInputEPKNS0_14AvatarConstantERNS_6memory9AllocatorE($constant,$alloc) {
 $constant = $constant|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,28,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $13 = 0;
  STACKTOP = sp;return ($13|0);
 }
 HEAP32[$2>>2] = 0;
 $4 = (($2) + 4|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($2) + 8|0);
 HEAP32[$5>>2] = -1;
 $6 = (($2) + 12|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($2) + 16|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($2) + 20|0);
 $9 = $8;
 $10 = $9;
 HEAP8[$10>>0]=0&255;HEAP8[$10+1>>0]=(0>>8)&255;HEAP8[$10+2>>0]=(0>>16)&255;HEAP8[$10+3>>0]=0>>24;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP8[$12>>0]=0&255;HEAP8[$12+1>>0]=(0>>8)&255;HEAP8[$12+2>>0]=(0>>16)&255;HEAP8[$12+3>>0]=0>>24;
 $13 = $2;
 STACKTOP = sp;return ($13|0);
}
function __ZN7mecanim9animation18DestroyAvatarInputEPNS0_11AvatarInputERNS_6memory9AllocatorE($input,$alloc) {
 $input = $input|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($input|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$alloc>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$input>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($alloc,$4);
 $5 = HEAP32[$alloc>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($alloc,$input);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18CreateAvatarMemoryEPKNS0_14AvatarConstantERNS_6memory9AllocatorE($constant,$alloc) {
 $constant = $constant|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,176,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $25 = 0;
  STACKTOP = sp;return ($25|0);
 }
 $4 = (($2) + 36|0);
 dest=$2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($2) + 40|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($2) + 44|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($2) + 48|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($2) + 52|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($2) + 56|0);
 $10 = (($2) + 84|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;HEAP32[$9+24>>2]=0|0;
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($2) + 88|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($2) + 92|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($2) + 96|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($2) + 100|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($2) + 104|0);
 $16 = (($2) + 132|0);
 ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP32[$15+20>>2]=0|0;HEAP32[$15+24>>2]=0|0;
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($2) + 136|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($2) + 140|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($2) + 144|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($2) + 148|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($2) + 152|0);
 $22 = (($2) + 168|0);
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
 HEAPF32[$22>>2] = Math_fround(0.5);
 $23 = (($2) + 172|0);
 HEAP8[$23>>0] = 1;
 $24 = (($2) + 173|0);
 HEAP8[$24>>0] = 0;
 $25 = $2;
 STACKTOP = sp;return ($25|0);
}
function __ZN7mecanim9animation19DestroyAvatarMemoryEPNS0_12AvatarMemoryERNS_6memory9AllocatorE($memory,$alloc) {
 $memory = $memory|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($memory|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$alloc>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($alloc,$memory);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21CreateAvatarWorkspaceEPKNS0_14AvatarConstantERNS_6memory9AllocatorE($constant,$alloc) {
 $constant = $constant|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,96,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $27 = 0;
 } else {
  $4 = (($2) + 56|0);
  dest=$2+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  HEAPF32[$4>>2] = Math_fround(1.0);
  $5 = (($2) + 72|0);
  HEAPF32[$5>>2] = Math_fround(1.0);
  $6 = (($2) + 68|0);
  HEAPF32[$6>>2] = Math_fround(1.0);
  $7 = (($2) + 64|0);
  HEAPF32[$7>>2] = Math_fround(1.0);
  $8 = (($2) + 60|0);
  HEAPF32[$8>>2] = Math_fround(1.0);
  $9 = (($2) + 76|0);
  ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP8[$9+16>>0]=0|0;
  $27 = $2;
 }
 $10 = (($constant) + 36|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $13 = $10;
  $14 = (($11) + ($13))|0;
  $15 = $14;
  $16 = (($15) + 48|0);
  $17 = $16;
  $18 = HEAP32[$16>>2]|0;
  $19 = (($18) + ($17))|0;
  $20 = $19;
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(0);
  if (!($22)) {
   $23 = HEAP32[$constant>>2]|0;
   $24 = ($23|0)==(0);
   if ($24) {
    STACKTOP = sp;return ($27|0);
   }
   $25 = (($15) + 52|0);
   HEAP32[$25>>2] = $20;
   $26 = (__ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($20,$alloc)|0);
   HEAP32[$27>>2] = $26;
   $28 = HEAP32[$10>>2]|0;
   $29 = (($28) + ($13))|0;
   $30 = $29;
   $31 = (($30) + 48|0);
   $32 = $31;
   $33 = HEAP32[$31>>2]|0;
   $34 = (($32) + ($33))|0;
   $35 = $34;
   $36 = (($30) + 52|0);
   HEAP32[$36>>2] = $35;
   $37 = (__ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($35,$alloc)|0);
   $38 = (($27) + 4|0);
   HEAP32[$38>>2] = $37;
   $39 = HEAP32[$10>>2]|0;
   $40 = (($39) + ($13))|0;
   $41 = $40;
   $42 = (($41) + 48|0);
   $43 = $42;
   $44 = HEAP32[$42>>2]|0;
   $45 = (($43) + ($44))|0;
   $46 = $45;
   $47 = (($41) + 52|0);
   HEAP32[$47>>2] = $46;
   $48 = (__ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($46,$alloc)|0);
   $49 = (($27) + 8|0);
   HEAP32[$49>>2] = $48;
   $50 = HEAP32[$alloc>>2]|0;
   $51 = HEAP32[$50>>2]|0;
   $52 = (FUNCTION_TABLE_iiii[$51 & 2047]($alloc,880,4)|0);
   $53 = ($52|0)==(0|0);
   if ($53) {
    $55 = 0;
   } else {
    __ZN7mecanim5human9HumanPoseC2Ev($52);
    $55 = $52;
   }
   $54 = (($27) + 20|0);
   HEAP32[$54>>2] = $55;
   STACKTOP = sp;return ($27|0);
  }
 }
 $56 = (($constant) + 68|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(-1);
 if ($58) {
  STACKTOP = sp;return ($27|0);
 }
 $59 = (($constant) + 120|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ($60|0)==(0);
 if ($61) {
  STACKTOP = sp;return ($27|0);
 }
 $62 = $59;
 $63 = (($60) + ($62))|0;
 $64 = $63;
 $65 = (($constant) + 124|0);
 HEAP32[$65>>2] = $64;
 $66 = (__ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($64,$alloc)|0);
 $67 = (($27) + 12|0);
 HEAP32[$67>>2] = $66;
 $68 = HEAP32[$59>>2]|0;
 $69 = (($68) + ($62))|0;
 $70 = $69;
 HEAP32[$65>>2] = $70;
 $71 = (__ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($70,$alloc)|0);
 $72 = (($27) + 16|0);
 HEAP32[$72>>2] = $71;
 STACKTOP = sp;return ($27|0);
}
function __ZN7mecanim9animation22DestroyAvatarWorkspaceEPNS0_15AvatarWorkspaceERNS_6memory9AllocatorE($workspace,$alloc) {
 $workspace = $workspace|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($workspace|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($workspace) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN7mecanim8skeleton19DestroySkeletonPoseEPNS0_12SkeletonPoseERNS_6memory9AllocatorE($2,$alloc);
 $3 = (($workspace) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN7mecanim8skeleton19DestroySkeletonPoseEPNS0_12SkeletonPoseERNS_6memory9AllocatorE($4,$alloc);
 $5 = HEAP32[$workspace>>2]|0;
 __ZN7mecanim8skeleton19DestroySkeletonPoseEPNS0_12SkeletonPoseERNS_6memory9AllocatorE($5,$alloc);
 $6 = (($workspace) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 __ZN7mecanim8skeleton19DestroySkeletonPoseEPNS0_12SkeletonPoseERNS_6memory9AllocatorE($7,$alloc);
 $8 = (($workspace) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN7mecanim8skeleton19DestroySkeletonPoseEPNS0_12SkeletonPoseERNS_6memory9AllocatorE($9,$alloc);
 $10 = HEAP32[$alloc>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($workspace) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$12 & 4095]($alloc,$14);
 $15 = HEAP32[$alloc>>2]|0;
 $16 = (($15) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($alloc,$workspace);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18CreateAvatarOutputEPKNS0_14AvatarConstantEbbRNS_6memory9AllocatorE($constant,$hasTransformHierarchy,$hasMotionOutput,$alloc) {
 $constant = $constant|0;
 $hasTransformHierarchy = $hasTransformHierarchy|0;
 $hasMotionOutput = $hasMotionOutput|0;
 $alloc = $alloc|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,20,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $17 = 0;
 } else {
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
  $17 = $2;
 }
 if ($hasTransformHierarchy) {
  $4 = (($constant) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = HEAP32[$constant>>2]|0;
   $8 = ($7|0)==(0);
   if (!($8)) {
    $9 = $constant;
    $10 = (($7) + ($9))|0;
    $11 = $10;
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0);
    if (!($13)) {
     $14 = (($constant) + 4|0);
     HEAP32[$14>>2] = $11;
     $15 = (__ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($11,$alloc)|0);
     $16 = (($17) + 4|0);
     HEAP32[$16>>2] = $15;
    }
   }
  }
 } else {
  $18 = HEAP32[$constant>>2]|0;
  $19 = ($18|0)==(0);
  if (!($19)) {
   $20 = $constant;
   $21 = (($18) + ($20))|0;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0);
   if (!($24)) {
    $25 = (($constant) + 4|0);
    HEAP32[$25>>2] = $22;
    $26 = (__ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($22,$alloc)|0);
    $27 = (($17) + 4|0);
    HEAP32[$27>>2] = $26;
   }
  }
 }
 $28 = (($constant) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if ($30) {
  $31 = (($constant) + 68|0);
  $32 = HEAP32[$31>>2]|0;
  $$not = ($32|0)!=(-1);
  $brmerge = $$not | $hasMotionOutput;
  if (!($brmerge)) {
   STACKTOP = sp;return ($17|0);
  }
 }
 $33 = (__ZN7mecanim6memory9Allocator9ConstructINS_9animation12MotionOutputEEEPT_j($alloc,4)|0);
 $34 = (($17) + 8|0);
 HEAP32[$34>>2] = $33;
 $35 = HEAP32[$28>>2]|0;
 $36 = ($35|0)==(0);
 if ($36) {
  STACKTOP = sp;return ($17|0);
 }
 $37 = HEAP32[$alloc>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = (FUNCTION_TABLE_iiii[$38 & 2047]($alloc,880,4)|0);
 $40 = ($39|0)==(0|0);
 if ($40) {
  $42 = 0;
 } else {
  __ZN7mecanim5human9HumanPoseC2Ev($39);
  $42 = $39;
 }
 $41 = (($17) + 12|0);
 HEAP32[$41>>2] = $42;
 $43 = HEAP32[$alloc>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = (FUNCTION_TABLE_iiii[$44 & 2047]($alloc,880,4)|0);
 $46 = ($45|0)==(0|0);
 if ($46) {
  $48 = 0;
 } else {
  __ZN7mecanim5human9HumanPoseC2Ev($45);
  $48 = $45;
 }
 $47 = (($17) + 16|0);
 HEAP32[$47>>2] = $48;
 STACKTOP = sp;return ($17|0);
}
function __ZN7mecanim6memory9Allocator9ConstructINS_9animation12MotionOutputEEEPT_j($this,$align) {
 $this = $this|0;
 $align = $align|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($this,460,$align)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $54 = 0;
  STACKTOP = sp;return ($54|0);
 }
 HEAPF32[$2>>2] = Math_fround(0.0);
 $4 = (($2) + 36|0);
 $5 = (($2) + 64|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;HEAP32[$4+20>>2]=0|0;HEAP32[$4+24>>2]=0|0;
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($2) + 68|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($2) + 72|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($2) + 76|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($2) + 80|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($2) + 84|0);
 $11 = (($2) + 112|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;HEAP32[$10+16>>2]=0|0;HEAP32[$10+20>>2]=0|0;HEAP32[$10+24>>2]=0|0;
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($2) + 116|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($2) + 120|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($2) + 124|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($2) + 128|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($2) + 132|0);
 $17 = (($2) + 160|0);
 ;HEAP32[$16+0>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;HEAP32[$16+16>>2]=0|0;HEAP32[$16+20>>2]=0|0;HEAP32[$16+24>>2]=0|0;
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($2) + 164|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($2) + 168|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($2) + 172|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($2) + 176|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($2) + 180|0);
 $23 = (($2) + 208|0);
 ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;HEAP32[$22+16>>2]=0|0;HEAP32[$22+20>>2]=0|0;HEAP32[$22+24>>2]=0|0;
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($2) + 212|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($2) + 216|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($2) + 220|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($2) + 224|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($2) + 228|0);
 $29 = (($2) + 256|0);
 ;HEAP32[$28+0>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;HEAP32[$28+12>>2]=0|0;HEAP32[$28+16>>2]=0|0;HEAP32[$28+20>>2]=0|0;HEAP32[$28+24>>2]=0|0;
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = (($2) + 260|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($2) + 264|0);
 HEAPF32[$31>>2] = Math_fround(1.0);
 $32 = (($2) + 268|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $33 = (($2) + 272|0);
 HEAPF32[$33>>2] = Math_fround(1.0);
 $34 = (($2) + 276|0);
 $35 = (($2) + 304|0);
 ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;HEAP32[$34+24>>2]=0|0;
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($2) + 308|0);
 HEAPF32[$36>>2] = Math_fround(1.0);
 $37 = (($2) + 312|0);
 HEAPF32[$37>>2] = Math_fround(1.0);
 $38 = (($2) + 316|0);
 HEAPF32[$38>>2] = Math_fround(1.0);
 $39 = (($2) + 320|0);
 HEAPF32[$39>>2] = Math_fround(1.0);
 $40 = (($2) + 324|0);
 $41 = (($2) + 352|0);
 ;HEAP32[$40+0>>2]=0|0;HEAP32[$40+4>>2]=0|0;HEAP32[$40+8>>2]=0|0;HEAP32[$40+12>>2]=0|0;HEAP32[$40+16>>2]=0|0;HEAP32[$40+20>>2]=0|0;HEAP32[$40+24>>2]=0|0;
 HEAPF32[$41>>2] = Math_fround(1.0);
 $42 = (($2) + 356|0);
 HEAPF32[$42>>2] = Math_fround(1.0);
 $43 = (($2) + 360|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 $44 = (($2) + 364|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 $45 = (($2) + 368|0);
 HEAPF32[$45>>2] = Math_fround(1.0);
 $46 = (($2) + 372|0);
 $47 = (($2) + 400|0);
 ;HEAP32[$46+0>>2]=0|0;HEAP32[$46+4>>2]=0|0;HEAP32[$46+8>>2]=0|0;HEAP32[$46+12>>2]=0|0;HEAP32[$46+16>>2]=0|0;HEAP32[$46+20>>2]=0|0;HEAP32[$46+24>>2]=0|0;
 HEAPF32[$47>>2] = Math_fround(1.0);
 $48 = (($2) + 404|0);
 HEAPF32[$48>>2] = Math_fround(1.0);
 $49 = (($2) + 408|0);
 HEAPF32[$49>>2] = Math_fround(1.0);
 $50 = (($2) + 412|0);
 HEAPF32[$50>>2] = Math_fround(1.0);
 $51 = (($2) + 416|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 $52 = (($2) + 420|0);
 $53 = (($2) + 4|0);
 ;HEAP32[$53+0>>2]=0|0;HEAP32[$53+4>>2]=0|0;HEAP32[$53+8>>2]=0|0;HEAP32[$53+12>>2]=0|0;HEAP32[$53+16>>2]=0|0;HEAP32[$53+20>>2]=0|0;HEAP32[$53+24>>2]=0|0;HEAP32[$53+28>>2]=0|0;
 dest=$52+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $54 = $2;
 STACKTOP = sp;return ($54|0);
}
function __ZN7mecanim9animation19DestroyAvatarOutputEPNS0_12AvatarOutputERNS_6memory9AllocatorE($output,$alloc) {
 $output = $output|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($output|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$output>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($1,$alloc);
 }
 $3 = (($output) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN7mecanim8skeleton19DestroySkeletonPoseEPNS0_12SkeletonPoseERNS_6memory9AllocatorE($4,$alloc);
 $5 = HEAP32[$alloc>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($output) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($alloc,$9);
 $10 = HEAP32[$alloc>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($output) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$12 & 4095]($alloc,$14);
 $15 = HEAP32[$alloc>>2]|0;
 $16 = (($15) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($output) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($alloc,$19);
 $20 = HEAP32[$alloc>>2]|0;
 $21 = (($20) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vii[$22 & 4095]($alloc,$output);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18ControllerConstant15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z27RegisterAllowNameConversionPKcS0_S0_(775072,775096,775120);
 __Z27RegisterAllowNameConversionPKcS0_S0_(775072,775136,775160);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation22CreateControllerMemoryEPKNS0_18ControllerConstantEPKNS0_14AvatarConstantEPKNS0_12AnimationSetEPKNS_18ValueArrayConstantEbRNS_6memory9AllocatorE($controller,$avatar,$animationSet,$dynamicValueConstant,$hasMotionOutput,$alloc) {
 $controller = $controller|0;
 $avatar = $avatar|0;
 $animationSet = $animationSet|0;
 $dynamicValueConstant = $dynamicValueConstant|0;
 $hasMotionOutput = $hasMotionOutput|0;
 $alloc = $alloc|0;
 var $$0$i1125 = 0, $$0$i22 = 0, $$0$i323 = 0, $$0$i724 = 0, $$not = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $layerIter$027 = 0, $stateMachineIter$026 = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,52,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $6 = 0;
 } else {
  dest=$2+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $6 = $2;
 }
 $4 = HEAP32[$controller>>2]|0;
 $5 = (($6) + 12|0);
 HEAP32[$5>>2] = $4;
 $7 = (($controller) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$6>>2] = $8;
 $9 = (($6) + 4|0);
 $10 = ($8|0)==(0);
 if ($10) {
  $$0$i22 = 0;$24 = 0;
 } else {
  $11 = HEAP32[$alloc>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = $8 << 3;
  $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($alloc,$13,4)|0);
  $15 = ($14|0)==(0|0);
  if ($15) {
   $$0$i22 = 0;$24 = 0;
  } else {
   $16 = (($14) + ($8<<3)|0);
   $17 = $14;
   while(1) {
    HEAP32[$17>>2] = 0;
    $18 = (($17) + 4|0);
    HEAP32[$18>>2] = 0;
    $19 = (($17) + 8|0);
    $20 = ($19|0)==($16|0);
    if ($20) {
     break;
    } else {
     $17 = $19;
    }
   }
   $21 = $14;
   $22 = $9;
   $23 = (($21) - ($22))|0;
   $$0$i22 = $14;$24 = $23;
  }
 }
 HEAP32[$9>>2] = $24;
 $25 = (($6) + 8|0);
 HEAP32[$25>>2] = $$0$i22;
 $26 = (($6) + 16|0);
 $27 = HEAP32[$5>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  $$0$i323 = 0;$41 = 0;
 } else {
  $29 = HEAP32[$alloc>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = ($27*36)|0;
  $32 = (FUNCTION_TABLE_iiii[$30 & 2047]($alloc,$31,4)|0);
  $33 = ($32|0)==(0|0);
  if ($33) {
   $$0$i323 = 0;$41 = 0;
  } else {
   $34 = (($32) + (($27*36)|0)|0);
   $35 = $32;
   while(1) {
    dest=$35+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $36 = (($35) + 36|0);
    $37 = ($36|0)==($34|0);
    if ($37) {
     break;
    } else {
     $35 = $36;
    }
   }
   $38 = $32;
   $39 = $26;
   $40 = (($38) - ($39))|0;
   $$0$i323 = $32;$41 = $40;
  }
 }
 HEAP32[$26>>2] = $41;
 $42 = (($6) + 20|0);
 HEAP32[$42>>2] = $$0$i323;
 $43 = (($6) + 24|0);
 $44 = HEAP32[$5>>2]|0;
 $45 = ($44|0)==(0);
 if ($45) {
  $$0$i724 = 0;$58 = 0;
 } else {
  $46 = HEAP32[$alloc>>2]|0;
  $47 = HEAP32[$46>>2]|0;
  $48 = ($44*36)|0;
  $49 = (FUNCTION_TABLE_iiii[$47 & 2047]($alloc,$48,4)|0);
  $50 = ($49|0)==(0|0);
  if ($50) {
   $$0$i724 = 0;$58 = 0;
  } else {
   $51 = (($49) + (($44*36)|0)|0);
   $52 = $49;
   while(1) {
    dest=$52+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $53 = (($52) + 36|0);
    $54 = ($53|0)==($51|0);
    if ($54) {
     break;
    } else {
     $52 = $53;
    }
   }
   $55 = $49;
   $56 = $43;
   $57 = (($55) - ($56))|0;
   $$0$i724 = $49;$58 = $57;
  }
 }
 HEAP32[$43>>2] = $58;
 $59 = (($6) + 28|0);
 HEAP32[$59>>2] = $$0$i724;
 $60 = (($6) + 32|0);
 $61 = HEAP32[$5>>2]|0;
 $62 = ($61|0)==(0);
 if ($62) {
  $$0$i1125 = 0;$71 = 0;
 } else {
  $63 = HEAP32[$alloc>>2]|0;
  $64 = HEAP32[$63>>2]|0;
  $65 = $61 << 2;
  $66 = (FUNCTION_TABLE_iiii[$64 & 2047]($alloc,$65,4)|0);
  $67 = ($66|0)==(0|0);
  if ($67) {
   $$0$i1125 = 0;$71 = 0;
  } else {
   $68 = $66;
   $69 = $60;
   $70 = (($68) - ($69))|0;
   $$0$i1125 = $66;$71 = $70;
  }
 }
 HEAP32[$60>>2] = $71;
 $72 = (($6) + 36|0);
 HEAP32[$72>>2] = $$0$i1125;
 $73 = (($6) + 40|0);
 $74 = (($controller) + 24|0);
 $75 = $74;
 $76 = HEAP32[$74>>2]|0;
 $77 = (($76) + ($75))|0;
 $78 = $77;
 $79 = (($controller) + 28|0);
 HEAP32[$79>>2] = $78;
 $80 = (__ZN7mecanim16CreateValueArrayEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($78,$alloc)|0);
 $81 = ($80|0)==(0|0);
 if ($81) {
  $$pre = $73;
  $$pre$phiZ2D = $$pre;$85 = 0;
 } else {
  $82 = $80;
  $83 = $73;
  $84 = (($82) - ($83))|0;
  $$pre$phiZ2D = $83;$85 = $84;
 }
 HEAP32[$73>>2] = $85;
 $86 = (($6) + 44|0);
 $87 = (($controller) + 32|0);
 $88 = $87;
 $89 = HEAP32[$87>>2]|0;
 $90 = (($89) + ($88))|0;
 $91 = $90;
 $92 = (($controller) + 36|0);
 HEAP32[$92>>2] = $91;
 $93 = (($85) + ($$pre$phiZ2D))|0;
 $94 = $93;
 HEAP32[$86>>2] = $94;
 __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_($91,$94);
 $95 = HEAP32[$controller>>2]|0;
 $96 = ($95|0)==(0);
 if (!($96)) {
  $97 = (($controller) + 4|0);
  $98 = $97;
  $99 = $60;
  $100 = $26;
  $101 = $43;
  $102 = (($avatar) + 36|0);
  $103 = (($avatar) + 68|0);
  $104 = $102;
  $layerIter$027 = 0;
  while(1) {
   $110 = HEAP32[$97>>2]|0;
   $111 = (($110) + ($98))|0;
   $112 = $111;
   $113 = (($112) + ($layerIter$027<<3)|0);
   $114 = $113;
   $115 = HEAP32[$113>>2]|0;
   $116 = (($114) + ($115))|0;
   $117 = $116;
   $118 = (($117) + 32|0);
   $119 = Math_fround(HEAPF32[$118>>2]);
   $120 = HEAP32[$60>>2]|0;
   $121 = (($120) + ($99))|0;
   $122 = $121;
   HEAP32[$72>>2] = $122;
   $123 = (($122) + ($layerIter$027<<2)|0);
   HEAPF32[$123>>2] = $119;
   $124 = HEAP32[$26>>2]|0;
   $125 = (($124) + ($100))|0;
   $126 = $125;
   HEAP32[$42>>2] = $126;
   $127 = (__ZN7mecanim16CreateValueArrayEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($dynamicValueConstant,$alloc)|0);
   $128 = (($126) + (($layerIter$027*36)|0)|0);
   $129 = ($127|0)==(0|0);
   if ($129) {
    $133 = 0;
   } else {
    $130 = $127;
    $131 = $128;
    $132 = (($130) - ($131))|0;
    $133 = $132;
   }
   HEAP32[$128>>2] = $133;
   $134 = ((($126) + (($layerIter$027*36)|0)|0) + 4|0);
   HEAP32[$134>>2] = $127;
   $135 = HEAP32[$26>>2]|0;
   $136 = (($135) + ($100))|0;
   $137 = $136;
   HEAP32[$42>>2] = $137;
   $138 = (__ZN7mecanim20CreateValueArrayMaskEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($dynamicValueConstant,$alloc)|0);
   $139 = ((($137) + (($layerIter$027*36)|0)|0) + 8|0);
   $140 = ($138|0)==(0|0);
   if ($140) {
    $144 = 0;
   } else {
    $141 = $138;
    $142 = $139;
    $143 = (($141) - ($142))|0;
    $144 = $143;
   }
   HEAP32[$139>>2] = $144;
   $145 = ((($137) + (($layerIter$027*36)|0)|0) + 12|0);
   HEAP32[$145>>2] = $138;
   $146 = HEAP32[$43>>2]|0;
   $147 = (($146) + ($101))|0;
   $148 = $147;
   HEAP32[$59>>2] = $148;
   $149 = (__ZN7mecanim16CreateValueArrayEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($dynamicValueConstant,$alloc)|0);
   $150 = (($148) + (($layerIter$027*36)|0)|0);
   $151 = ($149|0)==(0|0);
   if ($151) {
    $155 = 0;
   } else {
    $152 = $149;
    $153 = $150;
    $154 = (($152) - ($153))|0;
    $155 = $154;
   }
   HEAP32[$150>>2] = $155;
   $156 = ((($148) + (($layerIter$027*36)|0)|0) + 4|0);
   HEAP32[$156>>2] = $149;
   $157 = HEAP32[$43>>2]|0;
   $158 = (($157) + ($101))|0;
   $159 = $158;
   HEAP32[$59>>2] = $159;
   $160 = (__ZN7mecanim20CreateValueArrayMaskEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($dynamicValueConstant,$alloc)|0);
   $161 = ((($159) + (($layerIter$027*36)|0)|0) + 8|0);
   $162 = ($160|0)==(0|0);
   if ($162) {
    $166 = 0;
   } else {
    $163 = $160;
    $164 = $161;
    $165 = (($163) - ($164))|0;
    $166 = $165;
   }
   HEAP32[$161>>2] = $166;
   $167 = ((($159) + (($layerIter$027*36)|0)|0) + 12|0);
   HEAP32[$167>>2] = $160;
   $168 = HEAP32[$102>>2]|0;
   $169 = ($168|0)==(0);
   if ($169) {
    label = 49;
   } else {
    $170 = (($168) + ($104))|0;
    $171 = $170;
    $172 = (($171) + 48|0);
    $173 = $172;
    $174 = HEAP32[$172>>2]|0;
    $175 = (($174) + ($173))|0;
    $176 = $175;
    $177 = HEAP32[$176>>2]|0;
    $178 = ($177|0)==(0);
    if ($178) {
     label = 49;
    } else {
     $179 = HEAP32[$26>>2]|0;
     $180 = (($179) + ($100))|0;
     $181 = $180;
     HEAP32[$42>>2] = $181;
     $182 = (__ZN7mecanim6memory9Allocator9ConstructINS_9animation12MotionOutputEEEPT_j($alloc,4)|0);
     $183 = ((($181) + (($layerIter$027*36)|0)|0) + 16|0);
     $184 = ($182|0)==(0|0);
     if ($184) {
      $188 = 0;
     } else {
      $185 = $182;
      $186 = $183;
      $187 = (($185) - ($186))|0;
      $188 = $187;
     }
     HEAP32[$183>>2] = $188;
     $189 = ((($181) + (($layerIter$027*36)|0)|0) + 20|0);
     HEAP32[$189>>2] = $182;
     $190 = HEAP32[$26>>2]|0;
     $191 = (($190) + ($100))|0;
     $192 = $191;
     HEAP32[$42>>2] = $192;
     $193 = HEAP32[$alloc>>2]|0;
     $194 = HEAP32[$193>>2]|0;
     $195 = (FUNCTION_TABLE_iiii[$194 & 2047]($alloc,880,4)|0);
     $196 = ($195|0)==(0|0);
     if ($196) {
      $197 = ((($192) + (($layerIter$027*36)|0)|0) + 24|0);
      $202 = 0;$203 = $197;$205 = 0;
     } else {
      __ZN7mecanim5human9HumanPoseC2Ev($195);
      $198 = ((($192) + (($layerIter$027*36)|0)|0) + 24|0);
      $199 = $195;
      $200 = $198;
      $201 = (($199) - ($200))|0;
      $202 = $201;$203 = $198;$205 = $195;
     }
     HEAP32[$203>>2] = $202;
     $204 = (($203) + 4|0);
     HEAP32[$204>>2] = $205;
     $206 = HEAP32[$43>>2]|0;
     $207 = (($206) + ($101))|0;
     $208 = $207;
     HEAP32[$59>>2] = $208;
     $209 = (__ZN7mecanim6memory9Allocator9ConstructINS_9animation12MotionOutputEEEPT_j($alloc,4)|0);
     $210 = ((($208) + (($layerIter$027*36)|0)|0) + 16|0);
     $211 = ($209|0)==(0|0);
     if ($211) {
      $215 = 0;
     } else {
      $212 = $209;
      $213 = $210;
      $214 = (($212) - ($213))|0;
      $215 = $214;
     }
     HEAP32[$210>>2] = $215;
     $216 = ((($208) + (($layerIter$027*36)|0)|0) + 20|0);
     HEAP32[$216>>2] = $209;
     $217 = HEAP32[$43>>2]|0;
     $218 = (($217) + ($101))|0;
     $219 = $218;
     HEAP32[$59>>2] = $219;
     $220 = HEAP32[$alloc>>2]|0;
     $221 = HEAP32[$220>>2]|0;
     $222 = (FUNCTION_TABLE_iiii[$221 & 2047]($alloc,880,4)|0);
     $223 = ($222|0)==(0|0);
     if ($223) {
      $224 = ((($219) + (($layerIter$027*36)|0)|0) + 24|0);
      $229 = 0;$230 = $224;$232 = 0;
     } else {
      __ZN7mecanim5human9HumanPoseC2Ev($222);
      $225 = ((($219) + (($layerIter$027*36)|0)|0) + 24|0);
      $226 = $222;
      $227 = $225;
      $228 = (($226) - ($227))|0;
      $229 = $228;$230 = $225;$232 = $222;
     }
     HEAP32[$230>>2] = $229;
     $231 = (($230) + 4|0);
     HEAP32[$231>>2] = $232;
    }
   }
   do {
    if ((label|0) == 49) {
     label = 0;
     $233 = HEAP32[$103>>2]|0;
     $$not = ($233|0)!=(-1);
     $brmerge = $$not | $hasMotionOutput;
     $234 = HEAP32[$26>>2]|0;
     $235 = (($234) + ($100))|0;
     $236 = $235;
     HEAP32[$42>>2] = $236;
     if (!($brmerge)) {
      $266 = ((($236) + (($layerIter$027*36)|0)|0) + 16|0);
      HEAP32[$266>>2] = 0;
      $267 = ((($236) + (($layerIter$027*36)|0)|0) + 20|0);
      HEAP32[$267>>2] = 0;
      $268 = HEAP32[$26>>2]|0;
      $269 = (($268) + ($100))|0;
      $270 = $269;
      HEAP32[$42>>2] = $270;
      $271 = ((($270) + (($layerIter$027*36)|0)|0) + 24|0);
      HEAP32[$271>>2] = 0;
      $272 = ((($270) + (($layerIter$027*36)|0)|0) + 28|0);
      HEAP32[$272>>2] = 0;
      $273 = HEAP32[$43>>2]|0;
      $274 = (($273) + ($101))|0;
      $275 = $274;
      $276 = ((($275) + (($layerIter$027*36)|0)|0) + 16|0);
      HEAP32[$276>>2] = 0;
      $277 = ((($275) + (($layerIter$027*36)|0)|0) + 20|0);
      HEAP32[$277>>2] = 0;
      $278 = HEAP32[$43>>2]|0;
      $279 = (($278) + ($101))|0;
      $280 = $279;
      HEAP32[$59>>2] = $280;
      $281 = ((($280) + (($layerIter$027*36)|0)|0) + 24|0);
      HEAP32[$281>>2] = 0;
      $282 = ((($280) + (($layerIter$027*36)|0)|0) + 28|0);
      HEAP32[$282>>2] = 0;
      break;
     }
     $237 = (__ZN7mecanim6memory9Allocator9ConstructINS_9animation12MotionOutputEEEPT_j($alloc,4)|0);
     $238 = ((($236) + (($layerIter$027*36)|0)|0) + 16|0);
     $239 = ($237|0)==(0|0);
     if ($239) {
      $243 = 0;
     } else {
      $240 = $237;
      $241 = $238;
      $242 = (($240) - ($241))|0;
      $243 = $242;
     }
     HEAP32[$238>>2] = $243;
     $244 = ((($236) + (($layerIter$027*36)|0)|0) + 20|0);
     HEAP32[$244>>2] = $237;
     $245 = HEAP32[$26>>2]|0;
     $246 = (($245) + ($100))|0;
     $247 = $246;
     HEAP32[$42>>2] = $247;
     $248 = ((($247) + (($layerIter$027*36)|0)|0) + 24|0);
     HEAP32[$248>>2] = 0;
     $249 = ((($247) + (($layerIter$027*36)|0)|0) + 28|0);
     HEAP32[$249>>2] = 0;
     $250 = HEAP32[$43>>2]|0;
     $251 = (($250) + ($101))|0;
     $252 = $251;
     HEAP32[$59>>2] = $252;
     $253 = (__ZN7mecanim6memory9Allocator9ConstructINS_9animation12MotionOutputEEEPT_j($alloc,4)|0);
     $254 = ((($252) + (($layerIter$027*36)|0)|0) + 16|0);
     $255 = ($253|0)==(0|0);
     if ($255) {
      $259 = 0;
     } else {
      $256 = $253;
      $257 = $254;
      $258 = (($256) - ($257))|0;
      $259 = $258;
     }
     HEAP32[$254>>2] = $259;
     $260 = ((($252) + (($layerIter$027*36)|0)|0) + 20|0);
     HEAP32[$260>>2] = $253;
     $261 = HEAP32[$43>>2]|0;
     $262 = (($261) + ($101))|0;
     $263 = $262;
     HEAP32[$59>>2] = $263;
     $264 = ((($263) + (($layerIter$027*36)|0)|0) + 24|0);
     HEAP32[$264>>2] = 0;
     $265 = ((($263) + (($layerIter$027*36)|0)|0) + 28|0);
     HEAP32[$265>>2] = 0;
    }
   } while(0);
   $283 = (($layerIter$027) + 1)|0;
   $284 = HEAP32[$controller>>2]|0;
   $285 = ($283>>>0)<($284>>>0);
   if ($285) {
    $layerIter$027 = $283;
   } else {
    break;
   }
  }
 }
 $105 = HEAP32[$6>>2]|0;
 $106 = ($105|0)==(0);
 if ($106) {
  STACKTOP = sp;return ($6|0);
 }
 $107 = $9;
 $108 = (($controller) + 16|0);
 $109 = $108;
 $stateMachineIter$026 = 0;
 while(1) {
  $286 = HEAP32[$9>>2]|0;
  $287 = (($286) + ($107))|0;
  $288 = $287;
  HEAP32[$25>>2] = $288;
  $289 = (($288) + ($stateMachineIter$026<<3)|0);
  $290 = HEAP32[$108>>2]|0;
  $291 = (($290) + ($109))|0;
  $292 = $291;
  $293 = (($292) + ($stateMachineIter$026<<3)|0);
  $294 = $293;
  $295 = HEAP32[$293>>2]|0;
  $296 = (($294) + ($295))|0;
  $297 = $296;
  $298 = ((($292) + ($stateMachineIter$026<<3)|0) + 4|0);
  HEAP32[$298>>2] = $297;
  $299 = (__ZN7mecanim12statemachine24CreateStateMachineMemoryEPKNS0_20StateMachineConstantERNS_6memory9AllocatorE($297,$alloc)|0);
  $300 = ($299|0)==(0|0);
  if ($300) {
   $304 = 0;
  } else {
   $301 = $299;
   $302 = $289;
   $303 = (($301) - ($302))|0;
   $304 = $303;
  }
  HEAP32[$289>>2] = $304;
  $305 = ((($288) + ($stateMachineIter$026<<3)|0) + 4|0);
  HEAP32[$305>>2] = $299;
  $306 = (($stateMachineIter$026) + 1)|0;
  $307 = HEAP32[$6>>2]|0;
  $308 = ($306>>>0)<($307>>>0);
  if ($308) {
   $stateMachineIter$026 = $306;
  } else {
   break;
  }
 }
 STACKTOP = sp;return ($6|0);
}
function __ZN7mecanim9animation23DestroyControllerMemoryEPNS0_16ControllerMemoryERNS_6memory9AllocatorE($controllerMemory,$alloc) {
 $controllerMemory = $controllerMemory|0;
 $alloc = $alloc|0;
 var $$pre = 0, $$pre10 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $layerIter$04 = 0, $smIter$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($controllerMemory|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($controllerMemory) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($controllerMemory) + 16|0);
  $5 = $4;
  $6 = (($controllerMemory) + 20|0);
  $7 = (($controllerMemory) + 24|0);
  $8 = $7;
  $9 = (($controllerMemory) + 28|0);
  $layerIter$04 = 0;
  while(1) {
   $15 = HEAP32[$4>>2]|0;
   $16 = (($15) + ($5))|0;
   $17 = $16;
   HEAP32[$6>>2] = $17;
   $18 = (($17) + (($layerIter$04*36)|0)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0);
   if ($20) {
    $27 = $15;
   } else {
    HEAP32[$6>>2] = $17;
    $21 = (($17) + (($layerIter$04*36)|0)|0);
    $22 = $21;
    $23 = (($22) + ($19))|0;
    $24 = $23;
    $25 = ((($17) + (($layerIter$04*36)|0)|0) + 4|0);
    HEAP32[$25>>2] = $24;
    __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($24,$alloc);
    $$pre = HEAP32[$4>>2]|0;
    $27 = $$pre;
   }
   $26 = (($27) + ($5))|0;
   $28 = $26;
   HEAP32[$6>>2] = $28;
   $29 = ((($28) + (($layerIter$04*36)|0)|0) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0);
   if ($31) {
    $38 = $27;
   } else {
    HEAP32[$6>>2] = $28;
    $32 = ((($28) + (($layerIter$04*36)|0)|0) + 8|0);
    $33 = $32;
    $34 = (($33) + ($30))|0;
    $35 = $34;
    $36 = ((($28) + (($layerIter$04*36)|0)|0) + 12|0);
    HEAP32[$36>>2] = $35;
    __ZN7mecanim21DestroyValueArrayMaskEPNS_14ValueArrayMaskERNS_6memory9AllocatorE($35,$alloc);
    $$pre6 = HEAP32[$4>>2]|0;
    $38 = $$pre6;
   }
   $37 = (($38) + ($5))|0;
   $39 = $37;
   HEAP32[$6>>2] = $39;
   $40 = ((($39) + (($layerIter$04*36)|0)|0) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0);
   if ($42) {
    $53 = $38;
   } else {
    $43 = HEAP32[$alloc>>2]|0;
    $44 = (($43) + 4|0);
    $45 = HEAP32[$44>>2]|0;
    HEAP32[$6>>2] = $39;
    $46 = ((($39) + (($layerIter$04*36)|0)|0) + 16|0);
    $47 = $46;
    $48 = (($47) + ($41))|0;
    $49 = $48;
    $50 = ((($39) + (($layerIter$04*36)|0)|0) + 20|0);
    HEAP32[$50>>2] = $49;
    $51 = $48;
    FUNCTION_TABLE_vii[$45 & 4095]($alloc,$51);
    $$pre7 = HEAP32[$4>>2]|0;
    $53 = $$pre7;
   }
   $52 = (($53) + ($5))|0;
   $54 = $52;
   HEAP32[$6>>2] = $54;
   $55 = ((($54) + (($layerIter$04*36)|0)|0) + 24|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==(0);
   if (!($57)) {
    $58 = HEAP32[$alloc>>2]|0;
    $59 = (($58) + 4|0);
    $60 = HEAP32[$59>>2]|0;
    HEAP32[$6>>2] = $54;
    $61 = ((($54) + (($layerIter$04*36)|0)|0) + 24|0);
    $62 = $61;
    $63 = (($62) + ($56))|0;
    $64 = $63;
    $65 = ((($54) + (($layerIter$04*36)|0)|0) + 28|0);
    HEAP32[$65>>2] = $64;
    $66 = $63;
    FUNCTION_TABLE_vii[$60 & 4095]($alloc,$66);
   }
   $67 = HEAP32[$7>>2]|0;
   $68 = (($67) + ($8))|0;
   $69 = $68;
   HEAP32[$9>>2] = $69;
   $70 = (($69) + (($layerIter$04*36)|0)|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = ($71|0)==(0);
   if ($72) {
    $79 = $67;
   } else {
    HEAP32[$9>>2] = $69;
    $73 = (($69) + (($layerIter$04*36)|0)|0);
    $74 = $73;
    $75 = (($74) + ($71))|0;
    $76 = $75;
    $77 = ((($69) + (($layerIter$04*36)|0)|0) + 4|0);
    HEAP32[$77>>2] = $76;
    __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($76,$alloc);
    $$pre8 = HEAP32[$7>>2]|0;
    $79 = $$pre8;
   }
   $78 = (($79) + ($8))|0;
   $80 = $78;
   HEAP32[$9>>2] = $80;
   $81 = ((($80) + (($layerIter$04*36)|0)|0) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ($82|0)==(0);
   if ($83) {
    $90 = $79;
   } else {
    HEAP32[$9>>2] = $80;
    $84 = ((($80) + (($layerIter$04*36)|0)|0) + 8|0);
    $85 = $84;
    $86 = (($85) + ($82))|0;
    $87 = $86;
    $88 = ((($80) + (($layerIter$04*36)|0)|0) + 12|0);
    HEAP32[$88>>2] = $87;
    __ZN7mecanim21DestroyValueArrayMaskEPNS_14ValueArrayMaskERNS_6memory9AllocatorE($87,$alloc);
    $$pre9 = HEAP32[$7>>2]|0;
    $90 = $$pre9;
   }
   $89 = (($90) + ($8))|0;
   $91 = $89;
   HEAP32[$9>>2] = $91;
   $92 = ((($91) + (($layerIter$04*36)|0)|0) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0);
   if ($94) {
    $105 = $90;
   } else {
    $95 = HEAP32[$alloc>>2]|0;
    $96 = (($95) + 4|0);
    $97 = HEAP32[$96>>2]|0;
    HEAP32[$9>>2] = $91;
    $98 = ((($91) + (($layerIter$04*36)|0)|0) + 16|0);
    $99 = $98;
    $100 = (($99) + ($93))|0;
    $101 = $100;
    $102 = ((($91) + (($layerIter$04*36)|0)|0) + 20|0);
    HEAP32[$102>>2] = $101;
    $103 = $100;
    FUNCTION_TABLE_vii[$97 & 4095]($alloc,$103);
    $$pre10 = HEAP32[$7>>2]|0;
    $105 = $$pre10;
   }
   $104 = (($105) + ($8))|0;
   $106 = $104;
   HEAP32[$9>>2] = $106;
   $107 = ((($106) + (($layerIter$04*36)|0)|0) + 24|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = ($108|0)==(0);
   if (!($109)) {
    $110 = HEAP32[$alloc>>2]|0;
    $111 = (($110) + 4|0);
    $112 = HEAP32[$111>>2]|0;
    HEAP32[$9>>2] = $106;
    $113 = ((($106) + (($layerIter$04*36)|0)|0) + 24|0);
    $114 = $113;
    $115 = (($114) + ($108))|0;
    $116 = $115;
    $117 = ((($106) + (($layerIter$04*36)|0)|0) + 28|0);
    HEAP32[$117>>2] = $116;
    $118 = $115;
    FUNCTION_TABLE_vii[$112 & 4095]($alloc,$118);
   }
   $119 = (($layerIter$04) + 1)|0;
   $120 = HEAP32[$1>>2]|0;
   $121 = ($119>>>0)<($120>>>0);
   if ($121) {
    $layerIter$04 = $119;
   } else {
    break;
   }
  }
 }
 $10 = HEAP32[$controllerMemory>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = (($controllerMemory) + 4|0);
  $13 = $12;
  $14 = (($controllerMemory) + 8|0);
  $smIter$02 = 0;
  while(1) {
   $122 = HEAP32[$12>>2]|0;
   $123 = (($122) + ($13))|0;
   $124 = $123;
   HEAP32[$14>>2] = $124;
   $125 = (($124) + ($smIter$02<<3)|0);
   $126 = $125;
   $127 = HEAP32[$125>>2]|0;
   $128 = (($126) + ($127))|0;
   $129 = $128;
   $130 = ((($124) + ($smIter$02<<3)|0) + 4|0);
   HEAP32[$130>>2] = $129;
   __ZN7mecanim12statemachine25DestroyStateMachineMemoryEPNS0_18StateMachineMemoryERNS_6memory9AllocatorE($129,$alloc);
   $131 = (($smIter$02) + 1)|0;
   $132 = HEAP32[$controllerMemory>>2]|0;
   $133 = ($131>>>0)<($132>>>0);
   if ($133) {
    $smIter$02 = $131;
   } else {
    break;
   }
  }
 }
 $134 = (($controllerMemory) + 40|0);
 $135 = $134;
 $136 = HEAP32[$134>>2]|0;
 $137 = (($136) + ($135))|0;
 $138 = $137;
 $139 = (($controllerMemory) + 44|0);
 HEAP32[$139>>2] = $138;
 __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($138,$alloc);
 $140 = (($controllerMemory) + 32|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = ($141|0)==(0);
 if (!($142)) {
  $143 = HEAP32[$alloc>>2]|0;
  $144 = (($143) + 4|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = $140;
  $147 = (($141) + ($146))|0;
  $148 = $147;
  $149 = (($controllerMemory) + 36|0);
  HEAP32[$149>>2] = $148;
  $150 = $147;
  FUNCTION_TABLE_vii[$145 & 4095]($alloc,$150);
 }
 $151 = (($controllerMemory) + 16|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = ($152|0)==(0);
 if (!($153)) {
  $154 = HEAP32[$alloc>>2]|0;
  $155 = (($154) + 4|0);
  $156 = HEAP32[$155>>2]|0;
  $157 = $151;
  $158 = (($152) + ($157))|0;
  $159 = $158;
  $160 = (($controllerMemory) + 20|0);
  HEAP32[$160>>2] = $159;
  $161 = $158;
  FUNCTION_TABLE_vii[$156 & 4095]($alloc,$161);
 }
 $162 = (($controllerMemory) + 24|0);
 $163 = HEAP32[$162>>2]|0;
 $164 = ($163|0)==(0);
 if (!($164)) {
  $165 = HEAP32[$alloc>>2]|0;
  $166 = (($165) + 4|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = $162;
  $169 = (($163) + ($168))|0;
  $170 = $169;
  $171 = (($controllerMemory) + 28|0);
  HEAP32[$171>>2] = $170;
  $172 = $169;
  FUNCTION_TABLE_vii[$167 & 4095]($alloc,$172);
 }
 $173 = (($controllerMemory) + 4|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ($174|0)==(0);
 if (!($175)) {
  $176 = HEAP32[$alloc>>2]|0;
  $177 = (($176) + 4|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = $173;
  $180 = (($174) + ($179))|0;
  $181 = $180;
  $182 = (($controllerMemory) + 8|0);
  HEAP32[$182>>2] = $181;
  $183 = $180;
  FUNCTION_TABLE_vii[$178 & 4095]($alloc,$183);
 }
 $184 = HEAP32[$alloc>>2]|0;
 $185 = (($184) + 4|0);
 $186 = HEAP32[$185>>2]|0;
 FUNCTION_TABLE_vii[$186 & 4095]($alloc,$controllerMemory);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation19CreateBlendingStateEjbbRNS_6memory9AllocatorE($size,$createMotionState,$createHumanPose,$alloc) {
 $size = $size|0;
 $createMotionState = $createMotionState|0;
 $createHumanPose = $createHumanPose|0;
 $alloc = $alloc|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i6 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,20,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
 } else {
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
  $5 = $2;
 }
 $4 = ($size|0)==(0);
 if ($4) {
  HEAP32[$5>>2] = 0;
  $$0$i4 = 0;$$pre$phiZ2D = 0;$14 = 0;
 } else {
  $6 = HEAP32[$alloc>>2]|0;
  $7 = HEAP32[$6>>2]|0;
  $8 = $size << 2;
  $9 = (FUNCTION_TABLE_iiii[$7 & 2047]($alloc,$8,4)|0);
  HEAP32[$5>>2] = $9;
  $10 = HEAP32[$alloc>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_iiii[$11 & 2047]($alloc,$8,4)|0);
  $$pre = HEAP32[$5>>2]|0;
  $$0$i4 = $12;$$pre$phiZ2D = $8;$14 = $$pre;
 }
 $13 = (($5) + 12|0);
 HEAP32[$13>>2] = $$0$i4;
 _memset(($14|0),0,($$pre$phiZ2D|0))|0;
 $15 = HEAP32[$13>>2]|0;
 _memset(($15|0),0,($$pre$phiZ2D|0))|0;
 $brmerge = $createMotionState | $createHumanPose;
 if ($brmerge) {
  if ($4) {
   $$0$i6 = 0;
  } else {
   $16 = HEAP32[$alloc>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   $18 = (FUNCTION_TABLE_iiii[$17 & 2047]($alloc,$$pre$phiZ2D,4)|0);
   $$0$i6 = $18;
  }
  $19 = (($5) + 4|0);
  HEAP32[$19>>2] = $$0$i6;
  _memset(($$0$i6|0),0,($$pre$phiZ2D|0))|0;
 }
 if (!($createHumanPose)) {
  $24 = (($5) + 16|0);
  HEAP32[$24>>2] = $size;
  STACKTOP = sp;return ($5|0);
 }
 if ($4) {
  $$0$i = 0;
 } else {
  $20 = HEAP32[$alloc>>2]|0;
  $21 = HEAP32[$20>>2]|0;
  $22 = (FUNCTION_TABLE_iiii[$21 & 2047]($alloc,$$pre$phiZ2D,4)|0);
  $$0$i = $22;
 }
 $23 = (($5) + 8|0);
 HEAP32[$23>>2] = $$0$i;
 _memset(($$0$i|0),0,($$pre$phiZ2D|0))|0;
 $24 = (($5) + 16|0);
 HEAP32[$24>>2] = $size;
 STACKTOP = sp;return ($5|0);
}
function __ZN7mecanim9animation20DestroyBlendingStateEPNS0_13BlendingStateILb1EEERNS_6memory9AllocatorE($blendingState,$alloc) {
 $blendingState = $blendingState|0;
 $alloc = $alloc|0;
 var $$pre$phi3Z2D = 0, $$pre$phi5Z2D = 0, $$pre$phi7Z2D = 0, $$pre$phiZ2D = 0, $$pre4 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($blendingState|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($blendingState) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$pre4 = (($blendingState) + 4|0);
  $$pre6 = (($blendingState) + 8|0);
  $$pre$phi3Z2D = $blendingState;$$pre$phi5Z2D = $$pre4;$$pre$phi7Z2D = $$pre6;$$pre$phiZ2D = $alloc;
 } else {
  $4 = (($blendingState) + 4|0);
  $5 = (($blendingState) + 8|0);
  $i$01 = 0;
  while(1) {
   $6 = HEAP32[$blendingState>>2]|0;
   $7 = (($6) + ($i$01<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($8,$alloc);
   $9 = HEAP32[$4>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = HEAP32[$alloc>>2]|0;
    $12 = (($11) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($9) + ($i$01<<2)|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vii[$13 & 4095]($alloc,$15);
   }
   $16 = HEAP32[$5>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    $18 = HEAP32[$alloc>>2]|0;
    $19 = (($18) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($16) + ($i$01<<2)|0);
    $22 = HEAP32[$21>>2]|0;
    FUNCTION_TABLE_vii[$20 & 4095]($alloc,$22);
   }
   $23 = (($i$01) + 1)|0;
   $24 = HEAP32[$1>>2]|0;
   $25 = ($23>>>0)<($24>>>0);
   if ($25) {
    $i$01 = $23;
   } else {
    $$pre$phi3Z2D = $blendingState;$$pre$phi5Z2D = $4;$$pre$phi7Z2D = $5;$$pre$phiZ2D = $alloc;
    break;
   }
  }
 }
 $26 = HEAP32[$$pre$phiZ2D>>2]|0;
 $27 = (($26) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$$pre$phi3Z2D>>2]|0;
 FUNCTION_TABLE_vii[$28 & 4095]($alloc,$29);
 $30 = HEAP32[$$pre$phiZ2D>>2]|0;
 $31 = (($30) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$$pre$phi5Z2D>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($alloc,$33);
 $34 = HEAP32[$$pre$phiZ2D>>2]|0;
 $35 = (($34) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$$pre$phi7Z2D>>2]|0;
 FUNCTION_TABLE_vii[$36 & 4095]($alloc,$37);
 $38 = HEAP32[$$pre$phiZ2D>>2]|0;
 $39 = (($38) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($blendingState) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 FUNCTION_TABLE_vii[$40 & 4095]($alloc,$42);
 $43 = HEAP32[$$pre$phiZ2D>>2]|0;
 $44 = (($43) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vii[$45 & 4095]($alloc,$blendingState);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation25CreateControllerWorkspaceEPKNS0_18ControllerConstantEPKNS0_14AvatarConstantEPKNS0_12AnimationSetEPKNS_18ValueArrayConstantEbRNS_6memory9AllocatorE($controller,$avatar,$animationSet,$dynamicValueConstant,$hasMotionOutput,$alloc) {
 $controller = $controller|0;
 $avatar = $avatar|0;
 $animationSet = $animationSet|0;
 $dynamicValueConstant = $dynamicValueConstant|0;
 $hasMotionOutput = $hasMotionOutput|0;
 $alloc = $alloc|0;
 var $$0 = 0, $$0$i = 0, $$0$i11 = 0, $$0$i2 = 0, $$0$i7 = 0, $$01 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phi46Z2D = 0, $$pre$phiZ2D = 0, $$pre40 = 0, $$pre42 = 0, $$pre43 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blendStateIter$019 = 0;
 var $blendStateIter$019$us = 0, $blendStateIter$019$us28 = 0, $boolCount$018 = 0, $boolCount$1 = 0, $hasMotionOutput$ = 0, $i$037 = 0, $i$117 = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $not$ = 0, $stateMachineIter$034 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($avatar) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 $not$ = ($1|0)!=(-1);
 $hasMotionOutput$ = $not$ | $hasMotionOutput;
 $2 = (($avatar) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $118 = 0;
 } else {
  $5 = $2;
  $6 = (($3) + ($5))|0;
  $7 = $6;
  $8 = (($7) + 48|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + ($9))|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)!=(0);
  $118 = $14;
 }
 $15 = HEAP32[$alloc>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 __THREW__ = 0;
 $17 = (invoke_iiii($16|0,($alloc|0),92,4)|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L4: do {
  if ($19) {
   label = 17;
  } else {
   $20 = ($17|0)==(0|0);
   if ($20) {
    $30 = 0;
   } else {
    HEAP32[$17>>2] = 0;
    $21 = (($17) + 4|0);
    HEAP32[$21>>2] = 0;
    $22 = (($17) + 16|0);
    $23 = (($17) + 88|0);
    HEAP8[$23>>0] = 0;
    $24 = (($17) + 89|0);
    HEAP8[$24>>0] = 0;
    $25 = (($17) + 90|0);
    HEAP8[$25>>0] = 0;
    dest=$22+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $30 = $17;
   }
   $26 = (($controller) + 12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0);
   if ($28) {
    $29 = (($30) + 4|0);
    HEAP32[$29>>2] = 0;
    $$0$i7 = 0;$46 = 0;$97 = $29;
   } else {
    $31 = HEAP32[$alloc>>2]|0;
    $32 = HEAP32[$31>>2]|0;
    $33 = $27 << 2;
    __THREW__ = 0;
    $34 = (invoke_iiii($32|0,($alloc|0),($33|0),4)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 17;
     break;
    }
    $$pre = HEAP32[$26>>2]|0;
    $37 = (($30) + 4|0);
    HEAP32[$37>>2] = $34;
    $38 = ($$pre|0)==(0);
    if ($38) {
     $$0$i7 = 0;$46 = 0;$97 = $37;
    } else {
     $39 = HEAP32[$alloc>>2]|0;
     $40 = HEAP32[$39>>2]|0;
     $41 = $$pre << 2;
     __THREW__ = 0;
     $42 = (invoke_iiii($40|0,($alloc|0),($41|0),4)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 17;
      break;
     }
     $$pre40 = HEAP32[$26>>2]|0;
     $$0$i7 = $42;$46 = $$pre40;$97 = $37;
    }
   }
   HEAP32[$30>>2] = $$0$i7;
   $45 = (($30) + 8|0);
   HEAP32[$45>>2] = $46;
   $47 = HEAP32[$26>>2]|0;
   $48 = ($47|0)==(0);
   if ($48) {
    $$0$i11 = 0;$$pre$phiZ2D = 0;
   } else {
    $49 = (($controller) + 16|0);
    $50 = $49;
    $$pre43 = HEAP32[$49>>2]|0;
    $61 = 0;$i$037 = 0;
    while(1) {
     $51 = (($$pre43) + ($50))|0;
     $52 = $51;
     $53 = (($52) + ($i$037<<3)|0);
     $54 = $53;
     $55 = HEAP32[$53>>2]|0;
     $56 = (($54) + ($55))|0;
     $57 = $56;
     $58 = (($57) + 40|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($61>>>0)<($59>>>0);
     $62 = $60 ? $59 : $61;
     $63 = (($i$037) + 1)|0;
     $64 = ($63>>>0)<($47>>>0);
     if ($64) {
      $61 = $62;$i$037 = $63;
     } else {
      break;
     }
    }
    $71 = ($62|0)==(0);
    if ($71) {
     $$0$i11 = 0;$$pre$phiZ2D = 0;
    } else {
     $72 = HEAP32[$alloc>>2]|0;
     $73 = HEAP32[$72>>2]|0;
     $74 = $62 << 2;
     __THREW__ = 0;
     $75 = (invoke_iiii($73|0,($alloc|0),($74|0),4)|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      label = 17;
      break;
     }
     $$0$i11 = $75;$$pre$phiZ2D = $74;
    }
   }
   $78 = (($30) + 12|0);
   HEAP32[$78>>2] = $$0$i11;
   _memset(($$0$i11|0),0,($$pre$phiZ2D|0))|0;
   $79 = HEAP32[$45>>2]|0;
   $80 = ($79|0)==(0);
   L24: do {
    if ($80) {
     $$pre$phi46Z2D = $animationSet;
    } else {
     $81 = (($controller) + 16|0);
     $82 = $81;
     $stateMachineIter$034 = 0;
     while(1) {
      $83 = HEAP32[$81>>2]|0;
      $84 = (($83) + ($82))|0;
      $85 = $84;
      $86 = (($85) + ($stateMachineIter$034<<3)|0);
      $87 = $86;
      $88 = HEAP32[$86>>2]|0;
      $89 = (($87) + ($88))|0;
      $90 = $89;
      $91 = ((($85) + ($stateMachineIter$034<<3)|0) + 4|0);
      HEAP32[$91>>2] = $90;
      $92 = HEAP32[$animationSet>>2]|0;
      __THREW__ = 0;
      $93 = (invoke_iiii(1591,($90|0),($92|0),($alloc|0))|0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       break;
      }
      $96 = HEAP32[$97>>2]|0;
      $98 = (($96) + ($stateMachineIter$034<<2)|0);
      HEAP32[$98>>2] = $93;
      $99 = HEAP32[$81>>2]|0;
      $100 = (($99) + ($82))|0;
      $101 = $100;
      $102 = (($101) + ($stateMachineIter$034<<3)|0);
      $103 = $102;
      $104 = HEAP32[$102>>2]|0;
      $105 = (($103) + ($104))|0;
      $106 = $105;
      $107 = ((($101) + ($stateMachineIter$034<<3)|0) + 4|0);
      HEAP32[$107>>2] = $106;
      $108 = HEAP32[$animationSet>>2]|0;
      __THREW__ = 0;
      $109 = (invoke_iiii(1592,($106|0),($108|0),($alloc|0))|0);
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       break;
      }
      $112 = HEAP32[$30>>2]|0;
      $113 = (($112) + ($stateMachineIter$034<<2)|0);
      HEAP32[$113>>2] = $109;
      $114 = (($stateMachineIter$034) + 1)|0;
      $115 = HEAP32[$45>>2]|0;
      $116 = ($114>>>0)<($115>>>0);
      if ($116) {
       $stateMachineIter$034 = $114;
      } else {
       $$pre$phi46Z2D = $animationSet;
       break L24;
      }
     }
     $67 = ___cxa_find_matching_catch()|0;
     $68 = tempRet0;
     $lpad$phi$index = $67;$lpad$phi$index5 = $68;
     break L4;
    }
   } while(0);
   $117 = HEAP32[$$pre$phi46Z2D>>2]|0;
   __THREW__ = 0;
   $119 = (invoke_iiiii(272,($117|0),($hasMotionOutput$|0),($118|0),($alloc|0))|0);
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    label = 17;
   } else {
    $122 = (($30) + 16|0);
    HEAP32[$122>>2] = $119;
    $123 = (($119) + 16|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = ($124|0)==(0);
    L34: do {
     if (!($125)) {
      if ($118) {
       $blendStateIter$019$us = 0;
      } else {
       if ($hasMotionOutput$) {
        $blendStateIter$019$us28 = 0;
       } else {
        $blendStateIter$019 = 0;
        while(1) {
         __THREW__ = 0;
         $179 = (invoke_iii(2591,($dynamicValueConstant|0),($alloc|0))|0);
         $180 = __THREW__; __THREW__ = 0;
         $181 = $180&1;
         if ($181) {
          break;
         }
         $186 = HEAP32[$122>>2]|0;
         $187 = HEAP32[$186>>2]|0;
         $188 = (($187) + ($blendStateIter$019<<2)|0);
         HEAP32[$188>>2] = $179;
         $189 = (($blendStateIter$019) + 1)|0;
         $190 = HEAP32[$122>>2]|0;
         $191 = (($190) + 16|0);
         $192 = HEAP32[$191>>2]|0;
         $193 = ($189>>>0)<($192>>>0);
         if ($193) {
          $blendStateIter$019 = $189;
         } else {
          break L34;
         }
        }
        $65 = ___cxa_find_matching_catch()|0;
        $66 = tempRet0;
        $lpad$phi$index = $65;$lpad$phi$index5 = $66;
        break L4;
       }
       while(1) {
        __THREW__ = 0;
        $159 = (invoke_iii(2591,($dynamicValueConstant|0),($alloc|0))|0);
        $160 = __THREW__; __THREW__ = 0;
        $161 = $160&1;
        if ($161) {
         break;
        }
        $162 = HEAP32[$122>>2]|0;
        $163 = HEAP32[$162>>2]|0;
        $164 = (($163) + ($blendStateIter$019$us28<<2)|0);
        HEAP32[$164>>2] = $159;
        __THREW__ = 0;
        $165 = (invoke_iii(2592,($alloc|0),4)|0);
        $166 = __THREW__; __THREW__ = 0;
        $167 = $166&1;
        if ($167) {
         break;
        }
        $168 = HEAP32[$122>>2]|0;
        $169 = (($168) + 4|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = (($170) + ($blendStateIter$019$us28<<2)|0);
        HEAP32[$171>>2] = $165;
        $172 = (($blendStateIter$019$us28) + 1)|0;
        $173 = HEAP32[$122>>2]|0;
        $174 = (($173) + 16|0);
        $175 = HEAP32[$174>>2]|0;
        $176 = ($172>>>0)<($175>>>0);
        if ($176) {
         $blendStateIter$019$us28 = $172;
        } else {
         break L34;
        }
       }
       $177 = ___cxa_find_matching_catch()|0;
       $178 = tempRet0;
       $lpad$phi$index = $177;$lpad$phi$index5 = $178;
       break L4;
      }
      while(1) {
       __THREW__ = 0;
       $126 = (invoke_iii(2591,($dynamicValueConstant|0),($alloc|0))|0);
       $127 = __THREW__; __THREW__ = 0;
       $128 = $127&1;
       if ($128) {
        label = 38;
        break;
       }
       $129 = HEAP32[$122>>2]|0;
       $130 = HEAP32[$129>>2]|0;
       $131 = (($130) + ($blendStateIter$019$us<<2)|0);
       HEAP32[$131>>2] = $126;
       __THREW__ = 0;
       $132 = (invoke_iii(2592,($alloc|0),4)|0);
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       if ($134) {
        label = 44;
        break;
       }
       $135 = HEAP32[$122>>2]|0;
       $136 = (($135) + 4|0);
       $137 = HEAP32[$136>>2]|0;
       $138 = (($137) + ($blendStateIter$019$us<<2)|0);
       HEAP32[$138>>2] = $132;
       $139 = HEAP32[$alloc>>2]|0;
       $140 = HEAP32[$139>>2]|0;
       __THREW__ = 0;
       $141 = (invoke_iiii($140|0,($alloc|0),880,4)|0);
       $142 = __THREW__; __THREW__ = 0;
       $143 = $142&1;
       if ($143) {
        label = 45;
        break;
       }
       $144 = ($141|0)==(0|0);
       if ($144) {
        $151 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3705,($141|0));
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 45;
         break;
        } else {
         $151 = $141;
        }
       }
       $147 = HEAP32[$122>>2]|0;
       $148 = (($147) + 8|0);
       $149 = HEAP32[$148>>2]|0;
       $150 = (($149) + ($blendStateIter$019$us<<2)|0);
       HEAP32[$150>>2] = $151;
       $152 = (($blendStateIter$019$us) + 1)|0;
       $153 = HEAP32[$122>>2]|0;
       $154 = (($153) + 16|0);
       $155 = HEAP32[$154>>2]|0;
       $156 = ($152>>>0)<($155>>>0);
       if ($156) {
        $blendStateIter$019$us = $152;
       } else {
        break L34;
       }
      }
      if ((label|0) == 38) {
       $157 = ___cxa_find_matching_catch()|0;
       $158 = tempRet0;
       $lpad$phi$index = $157;$lpad$phi$index5 = $158;
       break L4;
      }
      else if ((label|0) == 44) {
       $182 = ___cxa_find_matching_catch()|0;
       $183 = tempRet0;
       $$0 = $182;$$01 = $183;
       ___resumeException($$0|0);
       // unreachable;
      }
      else if ((label|0) == 45) {
       $184 = ___cxa_find_matching_catch()|0;
       $185 = tempRet0;
       $$0 = $184;$$01 = $185;
       ___resumeException($$0|0);
       // unreachable;
      }
     }
    } while(0);
    __THREW__ = 0;
    $194 = (invoke_iii(2591,($dynamicValueConstant|0),($alloc|0))|0);
    $195 = __THREW__; __THREW__ = 0;
    $196 = $195&1;
    if ($196) {
     label = 17;
    } else {
     $197 = (($30) + 20|0);
     $198 = ($194|0)==(0|0);
     if ($198) {
      $202 = 0;
     } else {
      $199 = $194;
      $200 = $197;
      $201 = (($199) - ($200))|0;
      $202 = $201;
     }
     HEAP32[$197>>2] = $202;
     $203 = (($30) + 24|0);
     HEAP32[$203>>2] = $194;
     if ($118) {
      __THREW__ = 0;
      $204 = (invoke_iii(2592,($alloc|0),4)|0);
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if ($206) {
       label = 17;
       break;
      }
      $207 = (($30) + 36|0);
      $208 = ($204|0)==(0|0);
      if ($208) {
       $212 = 0;
      } else {
       $209 = $204;
       $210 = $207;
       $211 = (($209) - ($210))|0;
       $212 = $211;
      }
      HEAP32[$207>>2] = $212;
      $213 = (($30) + 40|0);
      HEAP32[$213>>2] = $204;
      $214 = HEAP32[$alloc>>2]|0;
      $215 = HEAP32[$214>>2]|0;
      __THREW__ = 0;
      $216 = (invoke_iiii($215|0,($alloc|0),880,4)|0);
      $217 = __THREW__; __THREW__ = 0;
      $218 = $217&1;
      if ($218) {
       label = 17;
       break;
      }
      $219 = ($216|0)==(0|0);
      if ($219) {
       $220 = (($30) + 44|0);
       $227 = 0;$228 = $220;$230 = 0;
      } else {
       __THREW__ = 0;
       invoke_vi(3705,($216|0));
       $221 = __THREW__; __THREW__ = 0;
       $222 = $221&1;
       if ($222) {
        label = 17;
        break;
       }
       $223 = (($30) + 44|0);
       $224 = $216;
       $225 = $223;
       $226 = (($224) - ($225))|0;
       $227 = $226;$228 = $223;$230 = $216;
      }
      HEAP32[$228>>2] = $227;
      $229 = (($228) + 4|0);
      HEAP32[$229>>2] = $230;
     } else {
      if ($hasMotionOutput$) {
       __THREW__ = 0;
       $231 = (invoke_iii(2592,($alloc|0),4)|0);
       $232 = __THREW__; __THREW__ = 0;
       $233 = $232&1;
       if ($233) {
        label = 17;
        break;
       }
       $234 = (($30) + 36|0);
       $235 = ($231|0)==(0|0);
       if ($235) {
        $239 = 0;
       } else {
        $236 = $231;
        $237 = $234;
        $238 = (($236) - ($237))|0;
        $239 = $238;
       }
       HEAP32[$234>>2] = $239;
       $240 = (($30) + 40|0);
       HEAP32[$240>>2] = $231;
      }
     }
     __THREW__ = 0;
     $241 = (invoke_iii(2591,($dynamicValueConstant|0),($alloc|0))|0);
     $242 = __THREW__; __THREW__ = 0;
     $243 = $242&1;
     if ($243) {
      label = 17;
     } else {
      $244 = (($30) + 64|0);
      HEAP32[$244>>2] = $241;
      __THREW__ = 0;
      $245 = (invoke_iii(2591,($dynamicValueConstant|0),($alloc|0))|0);
      $246 = __THREW__; __THREW__ = 0;
      $247 = $246&1;
      if ($247) {
       label = 17;
      } else {
       $248 = (($30) + 68|0);
       HEAP32[$248>>2] = $245;
       $249 = HEAP32[$controller>>2]|0;
       $250 = HEAP32[$$pre$phi46Z2D>>2]|0;
       $251 = Math_imul($250, $249)|0;
       $252 = ($251|0)==(0);
       if ($252) {
        $$0$i2 = 0;
       } else {
        $253 = HEAP32[$alloc>>2]|0;
        $254 = HEAP32[$253>>2]|0;
        $255 = $251 << 5;
        __THREW__ = 0;
        $256 = (invoke_iiii($254|0,($alloc|0),($255|0),4)|0);
        $257 = __THREW__; __THREW__ = 0;
        $258 = $257&1;
        if ($258) {
         label = 17;
         break;
        }
        $259 = ($256|0)==(0|0);
        if ($259) {
         $$0$i2 = 0;
        } else {
         $260 = (($256) + ($251<<5)|0);
         $261 = $256;
         while(1) {
          HEAP32[$261>>2] = -1;
          $262 = (($261) + 4|0);
          HEAP32[$262>>2] = -1;
          $263 = (($261) + 8|0);
          HEAPF32[$263>>2] = Math_fround(0.0);
          $264 = (($261) + 12|0);
          HEAPF32[$264>>2] = Math_fround(0.0);
          $265 = (($261) + 16|0);
          HEAPF32[$265>>2] = Math_fround(0.0);
          $266 = (($261) + 20|0);
          HEAPF32[$266>>2] = Math_fround(1.0);
          $267 = (($261) + 24|0);
          HEAP32[$267>>2] = 0;
          $268 = (($261) + 28|0);
          HEAP8[$268>>0] = 0;
          $269 = (($261) + 32|0);
          $270 = ($269|0)==($260|0);
          if ($270) {
           $$0$i2 = $256;
           break;
          } else {
           $261 = $269;
          }
         }
        }
       }
       $271 = (($30) + 60|0);
       HEAP32[$271>>2] = $$0$i2;
       __THREW__ = 0;
       $272 = (invoke_iii(2582,($dynamicValueConstant|0),($alloc|0))|0);
       $273 = __THREW__; __THREW__ = 0;
       $274 = $273&1;
       if ($274) {
        label = 17;
       } else {
        $275 = (($30) + 72|0);
        HEAP32[$275>>2] = $272;
        __THREW__ = 0;
        $276 = (invoke_iii(2582,($dynamicValueConstant|0),($alloc|0))|0);
        $277 = __THREW__; __THREW__ = 0;
        $278 = $277&1;
        if ($278) {
         label = 17;
        } else {
         $279 = (($30) + 76|0);
         HEAP32[$279>>2] = $276;
         __THREW__ = 0;
         $280 = (invoke_iii(2582,($dynamicValueConstant|0),($alloc|0))|0);
         $281 = __THREW__; __THREW__ = 0;
         $282 = $281&1;
         if ($282) {
          label = 17;
         } else {
          $283 = (($30) + 80|0);
          HEAP32[$283>>2] = $280;
          $284 = (($controller) + 24|0);
          $285 = $284;
          $286 = HEAP32[$284>>2]|0;
          $287 = (($286) + ($285))|0;
          $288 = $287;
          $289 = HEAP32[$288>>2]|0;
          $290 = ($289|0)==(0);
          if ($290) {
           $$0$i = 0;
           $305 = (($30) + 84|0);
           HEAP32[$305>>2] = $$0$i;
           STACKTOP = sp;return ($30|0);
          }
          $$phi$trans$insert = (($288) + 4|0);
          $$pre42 = HEAP32[$$phi$trans$insert>>2]|0;
          $boolCount$018 = 0;$i$117 = 0;
          while(1) {
           $291 = $$phi$trans$insert;
           $292 = (($$pre42) + ($291))|0;
           $293 = $292;
           $294 = ((($293) + ($i$117<<4)|0) + 8|0);
           $295 = HEAP32[$294>>2]|0;
           if ((($295|0) == 9) | (($295|0) == 4)) {
            $296 = (($boolCount$018) + 1)|0;
            $boolCount$1 = $296;
           } else {
            $boolCount$1 = $boolCount$018;
           }
           $297 = (($i$117) + 1)|0;
           $298 = ($297>>>0)<($289>>>0);
           if ($298) {
            $boolCount$018 = $boolCount$1;$i$117 = $297;
           } else {
            break;
           }
          }
          $299 = ($boolCount$1|0)==(0);
          if ($299) {
           $$0$i = 0;
           $305 = (($30) + 84|0);
           HEAP32[$305>>2] = $$0$i;
           STACKTOP = sp;return ($30|0);
          }
          $300 = HEAP32[$alloc>>2]|0;
          $301 = HEAP32[$300>>2]|0;
          __THREW__ = 0;
          $302 = (invoke_iiii($301|0,($alloc|0),($boolCount$1|0),1)|0);
          $303 = __THREW__; __THREW__ = 0;
          $304 = $303&1;
          if ($304) {
           label = 17;
           break;
          } else {
           $$0$i = $302;
          }
          $305 = (($30) + 84|0);
          HEAP32[$305>>2] = $$0$i;
          STACKTOP = sp;return ($30|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 17) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  $lpad$phi$index = $69;$lpad$phi$index5 = $70;
 }
 $$0 = $lpad$phi$index;$$01 = $lpad$phi$index5;
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __ZN7mecanim9animation26DestroyControllerWorkspaceEPNS0_19ControllerWorkspaceERNS_6memory9AllocatorE($controllerWorkspace,$alloc) {
 $controllerWorkspace = $controllerWorkspace|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($controllerWorkspace|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($controllerWorkspace) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($controllerWorkspace) + 4|0);
  $i$01 = 0;
  while(1) {
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + ($i$01<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   __ZN7mecanim12statemachine25DestroyStateMachineOutputEPNS0_18StateMachineOutputERNS_6memory9AllocatorE($7,$alloc);
   $8 = HEAP32[$controllerWorkspace>>2]|0;
   $9 = (($8) + ($i$01<<2)|0);
   $10 = HEAP32[$9>>2]|0;
   __ZN7mecanim12statemachine28DestroyStateMachineWorkspaceEPNS0_21StateMachineWorkspaceERNS_6memory9AllocatorE($10,$alloc);
   $11 = (($i$01) + 1)|0;
   $12 = HEAP32[$1>>2]|0;
   $13 = ($11>>>0)<($12>>>0);
   if ($13) {
    $i$01 = $11;
   } else {
    break;
   }
  }
 }
 $14 = (($controllerWorkspace) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 __ZN7mecanim9animation20DestroyBlendingStateEPNS0_13BlendingStateILb1EEERNS_6memory9AllocatorE($15,$alloc);
 $16 = (($controllerWorkspace) + 20|0);
 $17 = $16;
 $18 = HEAP32[$16>>2]|0;
 $19 = (($18) + ($17))|0;
 $20 = $19;
 $21 = (($controllerWorkspace) + 24|0);
 HEAP32[$21>>2] = $20;
 __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($20,$alloc);
 $22 = (($controllerWorkspace) + 36|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = HEAP32[$alloc>>2]|0;
  $26 = (($25) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $22;
  $29 = (($23) + ($28))|0;
  $30 = $29;
  $31 = (($controllerWorkspace) + 40|0);
  HEAP32[$31>>2] = $30;
  $32 = $29;
  FUNCTION_TABLE_vii[$27 & 4095]($alloc,$32);
 }
 $33 = (($controllerWorkspace) + 44|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = HEAP32[$alloc>>2]|0;
  $37 = (($36) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $33;
  $40 = (($34) + ($39))|0;
  $41 = $40;
  $42 = (($controllerWorkspace) + 48|0);
  HEAP32[$42>>2] = $41;
  $43 = $40;
  FUNCTION_TABLE_vii[$38 & 4095]($alloc,$43);
 }
 $44 = HEAP32[$alloc>>2]|0;
 $45 = (($44) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($controllerWorkspace) + 60|0);
 $48 = HEAP32[$47>>2]|0;
 FUNCTION_TABLE_vii[$46 & 4095]($alloc,$48);
 $49 = HEAP32[$alloc>>2]|0;
 $50 = (($49) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($controllerWorkspace) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vii[$51 & 4095]($alloc,$53);
 $54 = HEAP32[$alloc>>2]|0;
 $55 = (($54) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP32[$controllerWorkspace>>2]|0;
 FUNCTION_TABLE_vii[$56 & 4095]($alloc,$57);
 $58 = HEAP32[$alloc>>2]|0;
 $59 = (($58) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($controllerWorkspace) + 4|0);
 $62 = HEAP32[$61>>2]|0;
 FUNCTION_TABLE_vii[$60 & 4095]($alloc,$62);
 $63 = (($controllerWorkspace) + 64|0);
 $64 = HEAP32[$63>>2]|0;
 __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($64,$alloc);
 $65 = (($controllerWorkspace) + 68|0);
 $66 = HEAP32[$65>>2]|0;
 __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($66,$alloc);
 $67 = (($controllerWorkspace) + 72|0);
 $68 = HEAP32[$67>>2]|0;
 __ZN7mecanim21DestroyValueArrayMaskEPNS_14ValueArrayMaskERNS_6memory9AllocatorE($68,$alloc);
 $69 = (($controllerWorkspace) + 76|0);
 $70 = HEAP32[$69>>2]|0;
 __ZN7mecanim21DestroyValueArrayMaskEPNS_14ValueArrayMaskERNS_6memory9AllocatorE($70,$alloc);
 $71 = (($controllerWorkspace) + 80|0);
 $72 = HEAP32[$71>>2]|0;
 __ZN7mecanim21DestroyValueArrayMaskEPNS_14ValueArrayMaskERNS_6memory9AllocatorE($72,$alloc);
 $73 = HEAP32[$alloc>>2]|0;
 $74 = (($73) + 4|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($controllerWorkspace) + 84|0);
 $77 = HEAP32[$76>>2]|0;
 FUNCTION_TABLE_vii[$75 & 4095]($alloc,$77);
 $78 = HEAP32[$alloc>>2]|0;
 $79 = (($78) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($alloc,$controllerWorkspace);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation11SetIKOnFeetEbRKNS0_14AvatarConstantERKNS0_11AvatarInputERNS0_12AvatarMemoryERNS0_15AvatarWorkspaceERNS0_12AvatarOutputE($left,$avatar,$input,$memory,$workspace,$output) {
 $left = $left|0;
 $avatar = $avatar|0;
 $input = $input|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $output = $output|0;
 var $$in = 0, $$in1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0;
 var $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0);
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0;
 var $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0);
 var $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0);
 var $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0);
 var $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0);
 var $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0);
 var $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0);
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = Math_fround(0), $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0);
 var $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0;
 var $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = Math_fround(0), $432 = 0, $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = Math_fround(0), $437 = Math_fround(0), $438 = 0;
 var $439 = Math_fround(0), $44 = Math_fround(0), $440 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0;
 var $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $avatarX = 0, $ddx = 0, $footGoalX = 0, $goalDX = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $avatarX = sp + 192|0;
 $ddx = sp;
 $footGoalX = sp + 48|0;
 $goalDX = sp + 96|0;
 $0 = sp + 144|0;
 $1 = (($input) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($input) + 20|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = (($memory) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($memory) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($memory) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($memory) + 20|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAPF32[$avatarX>>2] = $7;
 $14 = (($avatarX) + 4|0);
 HEAPF32[$14>>2] = $9;
 $15 = (($avatarX) + 8|0);
 HEAPF32[$15>>2] = $11;
 $16 = (($avatarX) + 12|0);
 HEAPF32[$16>>2] = $13;
 $17 = (($memory) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($memory) + 28|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($memory) + 32|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($memory) + 36|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($avatarX) + 16|0);
 HEAPF32[$25>>2] = $18;
 $26 = (($avatarX) + 20|0);
 HEAPF32[$26>>2] = $20;
 $27 = (($avatarX) + 24|0);
 HEAPF32[$27>>2] = $22;
 $28 = (($avatarX) + 28|0);
 HEAPF32[$28>>2] = $24;
 $29 = (($memory) + 40|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($memory) + 44|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($memory) + 48|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($memory) + 52|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($avatarX) + 32|0);
 HEAPF32[$37>>2] = $30;
 $38 = (($avatarX) + 36|0);
 HEAPF32[$38>>2] = $32;
 $39 = (($avatarX) + 40|0);
 HEAPF32[$39>>2] = $34;
 $40 = (($avatarX) + 44|0);
 HEAPF32[$40>>2] = $36;
 $41 = (($avatar) + 36|0);
 $42 = (($workspace) + 28|0);
 __ZN4mathL13xformInvMulNSERKNS_5xformES2_($ddx,$avatarX,$42);
 $43 = Math_fround(HEAPF32[$ddx>>2]);
 $44 = Math_fround($43 * $43);
 $45 = (($ddx) + 4|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($46 * $46);
 $48 = (($ddx) + 8|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * $49);
 $51 = (($ddx) + 12|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 * $52);
 $54 = Math_fround($44 + $47);
 $55 = Math_fround($50 + $53);
 $56 = Math_fround($54 + $55);
 $57 = (Math_fround(Math_sqrt((Math_fround($56)))));
 $58 = Math_fround($57 / $2);
 $59 = (($ddx) + 28|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = $60 == Math_fround(0.0);
 $62 = $61 ? Math_fround(9.99999997475242707878E-7) : $60;
 $63 = (($ddx) + 16|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 / $62);
 $66 = (($ddx) + 20|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($67 / $62);
 $69 = (($ddx) + 24|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 / $62);
 $72 = (Math_fround(+(Math_atan((+$65)))));
 $73 = (Math_fround(+(Math_atan((+$68)))));
 $74 = (Math_fround(+(Math_atan((+$71)))));
 $75 = (Math_fround(+(Math_atan(0.0))));
 $76 = Math_fround($72 * Math_fround(2.0));
 $77 = Math_fround($73 * Math_fround(2.0));
 $78 = Math_fround($74 * Math_fround(2.0));
 $79 = Math_fround($75 * Math_fround(2.0));
 $80 = Math_fround($76 * $76);
 $81 = Math_fround($77 * $77);
 $82 = Math_fround($78 * $78);
 $83 = Math_fround($79 * $79);
 $84 = Math_fround($80 + $81);
 $85 = Math_fround($82 + $83);
 $86 = Math_fround($84 + $85);
 $87 = (Math_fround(Math_sqrt((Math_fround($86)))));
 $88 = Math_fround($87 / $2);
 $89 = $left&1;
 $90 = $89 ^ 1;
 $91 = (($output) + 16|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ((($92) + (($90*76)|0)|0) + 128|0);
 HEAPF32[$93>>2] = Math_fround(1.0);
 $94 = ((($92) + (($90*76)|0)|0) + 132|0);
 HEAPF32[$94>>2] = Math_fround(1.0);
 if ($5) {
  $387 = $92;
 } else {
  $95 = (($memory) + 172|0);
  $96 = HEAP8[$95>>0]|0;
  $97 = ($96<<24>>24)==(0);
  if ($97) {
   $98 = (($workspace) + 76|0);
   $99 = (($workspace) + 84|0);
   $$in = $left ? $98 : $99;
   $100 = Math_fround(HEAPF32[$$in>>2]);
   $101 = (($workspace) + 80|0);
   $102 = (($workspace) + 88|0);
   $$in1 = $left ? $101 : $102;
   $103 = Math_fround(HEAPF32[$$in1>>2]);
   $104 = Math_fround($58 + $100);
   $105 = Math_fround($88 + $103);
   $106 = (($memory) + 56|0);
   $107 = (($memory) + 104|0);
   $108 = $left ? $106 : $107;
   $109 = ((($92) + (($90*76)|0)|0) + 80|0);
   $110 = Math_fround(HEAPF32[$109>>2]);
   $111 = ((($92) + (($90*76)|0)|0) + 84|0);
   $112 = Math_fround(HEAPF32[$111>>2]);
   $113 = ((($92) + (($90*76)|0)|0) + 88|0);
   $114 = Math_fround(HEAPF32[$113>>2]);
   $115 = ((($92) + (($90*76)|0)|0) + 92|0);
   $116 = Math_fround(HEAPF32[$115>>2]);
   $117 = ((($92) + (($90*76)|0)|0) + 96|0);
   $118 = Math_fround(HEAPF32[$117>>2]);
   $119 = ((($92) + (($90*76)|0)|0) + 100|0);
   $120 = Math_fround(HEAPF32[$119>>2]);
   $121 = ((($92) + (($90*76)|0)|0) + 104|0);
   $122 = Math_fround(HEAPF32[$121>>2]);
   $123 = ((($92) + (($90*76)|0)|0) + 108|0);
   $124 = Math_fround(HEAPF32[$123>>2]);
   $125 = ((($92) + (($90*76)|0)|0) + 112|0);
   $126 = Math_fround(HEAPF32[$125>>2]);
   $127 = ((($92) + (($90*76)|0)|0) + 116|0);
   $128 = Math_fround(HEAPF32[$127>>2]);
   $129 = ((($92) + (($90*76)|0)|0) + 120|0);
   $130 = Math_fround(HEAPF32[$129>>2]);
   $131 = ((($92) + (($90*76)|0)|0) + 124|0);
   $132 = Math_fround(HEAPF32[$131>>2]);
   HEAPF32[$footGoalX>>2] = $110;
   $133 = (($footGoalX) + 4|0);
   HEAPF32[$133>>2] = $112;
   $134 = (($footGoalX) + 8|0);
   HEAPF32[$134>>2] = $114;
   $135 = (($footGoalX) + 12|0);
   HEAPF32[$135>>2] = $116;
   $136 = (($footGoalX) + 16|0);
   HEAPF32[$136>>2] = $118;
   $137 = (($footGoalX) + 20|0);
   HEAPF32[$137>>2] = $120;
   $138 = (($footGoalX) + 24|0);
   HEAPF32[$138>>2] = $122;
   $139 = (($footGoalX) + 28|0);
   HEAPF32[$139>>2] = $124;
   $140 = (($footGoalX) + 32|0);
   HEAPF32[$140>>2] = $126;
   $141 = (($footGoalX) + 36|0);
   HEAPF32[$141>>2] = $128;
   $142 = (($footGoalX) + 40|0);
   HEAPF32[$142>>2] = $130;
   $143 = (($footGoalX) + 44|0);
   HEAPF32[$143>>2] = $132;
   __ZN4mathL13xformInvMulNSERKNS_5xformES2_($goalDX,$108,$footGoalX);
   $144 = Math_fround(HEAPF32[$goalDX>>2]);
   $145 = Math_fround($144 * $144);
   $146 = (($goalDX) + 4|0);
   $147 = Math_fround(HEAPF32[$146>>2]);
   $148 = Math_fround($147 * $147);
   $149 = (($goalDX) + 8|0);
   $150 = Math_fround(HEAPF32[$149>>2]);
   $151 = Math_fround($150 * $150);
   $152 = (($goalDX) + 12|0);
   $153 = Math_fround(HEAPF32[$152>>2]);
   $154 = Math_fround($153 * $153);
   $155 = Math_fround($145 + $148);
   $156 = Math_fround($151 + $154);
   $157 = Math_fround($155 + $156);
   $158 = (Math_fround(Math_sqrt((Math_fround($157)))));
   $159 = $158 > Math_fround(0.0);
   if ($159) {
    $160 = Math_fround($158 / $2);
    $161 = $104 > Math_fround(0.100000001490116119385);
    $162 = $161 ? $104 : Math_fround(0.0);
    $163 = $162 > Math_fround(1.0);
    if ($163) {
     $164 = Math_fround($162 * Math_fround(2.0));
     $166 = $164;
    } else {
     $166 = $162;
    }
    $165 = $166 < $160;
    $167 = $165 ? $166 : $160;
    $168 = Math_fround($167 / $160);
    $169 = Math_fround($168 * $144);
    $170 = Math_fround($168 * $147);
    $171 = Math_fround($168 * $150);
    $172 = Math_fround($168 * $153);
    HEAPF32[$goalDX>>2] = $169;
    HEAPF32[$146>>2] = $170;
    HEAPF32[$149>>2] = $171;
    HEAPF32[$152>>2] = $172;
   }
   $173 = (($goalDX) + 28|0);
   $174 = Math_fround(HEAPF32[$173>>2]);
   $175 = $174 == Math_fround(0.0);
   $176 = $175 ? Math_fround(9.99999997475242707878E-7) : $174;
   $177 = (($goalDX) + 16|0);
   $178 = Math_fround(HEAPF32[$177>>2]);
   $179 = Math_fround($178 / $176);
   $180 = (($goalDX) + 20|0);
   $181 = Math_fround(HEAPF32[$180>>2]);
   $182 = Math_fround($181 / $176);
   $183 = (($goalDX) + 24|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = Math_fround($184 / $176);
   $186 = (Math_fround(+(Math_atan((+$179)))));
   $187 = (Math_fround(+(Math_atan((+$182)))));
   $188 = (Math_fround(+(Math_atan((+$185)))));
   $189 = Math_fround($186 * Math_fround(2.0));
   $190 = Math_fround($187 * Math_fround(2.0));
   $191 = Math_fround($188 * Math_fround(2.0));
   $192 = Math_fround($189 * $189);
   $193 = Math_fround($190 * $190);
   $194 = Math_fround($191 * $191);
   $195 = Math_fround($192 + $193);
   $196 = Math_fround($83 + $194);
   $197 = Math_fround($195 + $196);
   $198 = (Math_fround(Math_sqrt((Math_fround($197)))));
   $199 = $198 > Math_fround(0.0);
   if ($199) {
    $200 = Math_fround($198 / $2);
    $201 = $105 > Math_fround(0.174532920122146606445);
    $202 = $201 ? $105 : Math_fround(0.0);
    $203 = $202 > Math_fround(1.74532926082611083984);
    if ($203) {
     $204 = Math_fround($202 * Math_fround(2.0));
     $206 = $204;
    } else {
     $206 = $202;
    }
    $205 = $206 < $200;
    $207 = $205 ? $206 : $200;
    $208 = Math_fround($207 / $200);
    $209 = Math_fround($189 * $208);
    $210 = Math_fround($190 * $208);
    $211 = Math_fround($191 * $208);
    $212 = (Math_fround(Math_abs((Math_fround($209)))));
    $213 = (Math_fround(Math_abs((Math_fround($210)))));
    $214 = (Math_fround(Math_abs((Math_fround($211)))));
    $215 = Math_fround($212 * Math_fround(0.5));
    $216 = Math_fround($213 * Math_fround(0.5));
    $217 = Math_fround($214 * Math_fround(0.5));
    $218 = Math_fround($215 + Math_fround(1.57079637050628662109));
    $219 = Math_fround($216 + Math_fround(1.57079637050628662109));
    $220 = Math_fround($217 + Math_fround(1.57079637050628662109));
    $221 = Math_fround($218 + Math_fround(-1.57079637050628662109));
    $222 = Math_fround($219 + Math_fround(-1.57079637050628662109));
    $223 = Math_fround($220 + Math_fround(-1.57079637050628662109));
    $224 = (Math_fround(+(_copysignf((+$221),(+$209)))));
    $225 = (Math_fround(+(_copysignf((+$222),(+$210)))));
    $226 = (Math_fround(+(_copysignf((+$223),(+$211)))));
    $227 = (Math_fround(+(_fmaxf((+$224),-1.57079541683197021484))));
    $228 = (Math_fround(+(_fminf((+$227),1.57079732418060302734))));
    $229 = (Math_fround(+(_fmaxf((+$225),-1.57079541683197021484))));
    $230 = (Math_fround(+(_fminf((+$229),1.57079732418060302734))));
    $231 = (Math_fround(+(_fmaxf((+$226),-1.57079541683197021484))));
    $232 = (Math_fround(+(_fminf((+$231),1.57079732418060302734))));
    $233 = Math_fround($228 * Math_fround(0.159154936671257019043));
    $234 = Math_fround($230 * Math_fround(0.159154936671257019043));
    $235 = Math_fround($232 * Math_fround(0.159154936671257019043));
    $236 = (Math_fround(+(_roundf((+$233)))));
    $237 = (Math_fround(+(_roundf((+$234)))));
    $238 = (Math_fround(+(_roundf((+$235)))));
    $239 = Math_fround($233 - $236);
    $240 = Math_fround($234 - $237);
    $241 = Math_fround($235 - $238);
    $242 = (Math_fround(Math_abs((Math_fround($239)))));
    $243 = (Math_fround(Math_abs((Math_fround($240)))));
    $244 = (Math_fround(Math_abs((Math_fround($241)))));
    $245 = Math_fround(Math_fround(0.25) - $242);
    $246 = Math_fround(Math_fround(0.25) - $243);
    $247 = Math_fround(Math_fround(0.25) - $244);
    $248 = Math_fround($245 * $245);
    $249 = Math_fround($246 * $246);
    $250 = Math_fround($247 * $247);
    $251 = Math_fround($248 * $248);
    $252 = Math_fround($249 * $249);
    $253 = Math_fround($250 * $250);
    $254 = Math_fround($248 * Math_fround(-41.283184051513671875));
    $255 = Math_fround($249 * Math_fround(-41.283184051513671875));
    $256 = Math_fround($250 * Math_fround(-41.283184051513671875));
    $257 = Math_fround($254 + Math_fround(6.28318548202514648438));
    $258 = Math_fround($255 + Math_fround(6.28318548202514648438));
    $259 = Math_fround($256 + Math_fround(6.28318548202514648438));
    $260 = Math_fround($251 * Math_fround(76.03546142578125));
    $261 = Math_fround($252 * Math_fround(76.03546142578125));
    $262 = Math_fround($253 * Math_fround(76.03546142578125));
    $263 = Math_fround($257 + $260);
    $264 = Math_fround($258 + $261);
    $265 = Math_fround($259 + $262);
    $266 = Math_fround($245 * $263);
    $267 = Math_fround($246 * $264);
    $268 = Math_fround($247 * $265);
    $269 = Math_fround($233 + Math_fround(-0.25));
    $270 = Math_fround($234 + Math_fround(-0.25));
    $271 = Math_fround($235 + Math_fround(-0.25));
    $272 = (Math_fround(+(_roundf((+$269)))));
    $273 = (Math_fround(+(_roundf((+$270)))));
    $274 = (Math_fround(+(_roundf((+$271)))));
    $275 = Math_fround($269 - $272);
    $276 = Math_fround($270 - $273);
    $277 = Math_fround($271 - $274);
    $278 = (Math_fround(Math_abs((Math_fround($275)))));
    $279 = (Math_fround(Math_abs((Math_fround($276)))));
    $280 = (Math_fround(Math_abs((Math_fround($277)))));
    $281 = Math_fround(Math_fround(0.25) - $278);
    $282 = Math_fround(Math_fround(0.25) - $279);
    $283 = Math_fround(Math_fround(0.25) - $280);
    $284 = Math_fround($281 * $281);
    $285 = Math_fround($282 * $282);
    $286 = Math_fround($283 * $283);
    $287 = Math_fround($284 * $284);
    $288 = Math_fround($285 * $285);
    $289 = Math_fround($286 * $286);
    $290 = Math_fround($284 * Math_fround(-41.283184051513671875));
    $291 = Math_fround($285 * Math_fround(-41.283184051513671875));
    $292 = Math_fround($286 * Math_fround(-41.283184051513671875));
    $293 = Math_fround($290 + Math_fround(6.28318548202514648438));
    $294 = Math_fround($291 + Math_fround(6.28318548202514648438));
    $295 = Math_fround($292 + Math_fround(6.28318548202514648438));
    $296 = Math_fround($287 * Math_fround(76.03546142578125));
    $297 = Math_fround($288 * Math_fround(76.03546142578125));
    $298 = Math_fround($289 * Math_fround(76.03546142578125));
    $299 = Math_fround($293 + $296);
    $300 = Math_fround($294 + $297);
    $301 = Math_fround($295 + $298);
    $302 = Math_fround($281 * $299);
    $303 = Math_fround($282 * $300);
    $304 = Math_fround($283 * $301);
    $305 = Math_fround($302 / $266);
    $306 = Math_fround($303 / $267);
    $307 = Math_fround($304 / $268);
    $308 = Math_fround($305 * $305);
    $309 = Math_fround($306 * $306);
    $310 = Math_fround($307 * $307);
    $311 = Math_fround($308 + $309);
    $312 = Math_fround($310 + Math_fround(1.0));
    $313 = Math_fround($311 + $312);
    $314 = (Math_fround(Math_sqrt((Math_fround($313)))));
    $315 = Math_fround(Math_fround(1.0) / $314);
    $316 = Math_fround($305 * $315);
    $317 = Math_fround($306 * $315);
    $318 = Math_fround($307 * $315);
    HEAPF32[$177>>2] = $316;
    HEAPF32[$180>>2] = $317;
    HEAPF32[$183>>2] = $318;
    HEAPF32[$173>>2] = $315;
   }
   __ZN4mathL8xformMulERKNS_5xformES2_18903($0,$108,$goalDX);
   $319 = Math_fround(HEAPF32[$0>>2]);
   $320 = (($0) + 4|0);
   $321 = Math_fround(HEAPF32[$320>>2]);
   $322 = (($0) + 8|0);
   $323 = Math_fround(HEAPF32[$322>>2]);
   $324 = (($0) + 12|0);
   $325 = Math_fround(HEAPF32[$324>>2]);
   HEAPF32[$108>>2] = $319;
   $326 = (($108) + 4|0);
   HEAPF32[$326>>2] = $321;
   $327 = (($108) + 8|0);
   HEAPF32[$327>>2] = $323;
   $328 = (($108) + 12|0);
   HEAPF32[$328>>2] = $325;
   $329 = (($0) + 16|0);
   $330 = Math_fround(HEAPF32[$329>>2]);
   $331 = (($0) + 20|0);
   $332 = Math_fround(HEAPF32[$331>>2]);
   $333 = (($0) + 24|0);
   $334 = Math_fround(HEAPF32[$333>>2]);
   $335 = (($0) + 28|0);
   $336 = Math_fround(HEAPF32[$335>>2]);
   $337 = (($108) + 16|0);
   HEAPF32[$337>>2] = $330;
   $338 = (($108) + 20|0);
   HEAPF32[$338>>2] = $332;
   $339 = (($108) + 24|0);
   HEAPF32[$339>>2] = $334;
   $340 = (($108) + 28|0);
   HEAPF32[$340>>2] = $336;
   $341 = (($0) + 32|0);
   $342 = Math_fround(HEAPF32[$341>>2]);
   $343 = (($0) + 36|0);
   $344 = Math_fround(HEAPF32[$343>>2]);
   $345 = (($0) + 40|0);
   $346 = Math_fround(HEAPF32[$345>>2]);
   $347 = (($0) + 44|0);
   $348 = Math_fround(HEAPF32[$347>>2]);
   $349 = (($108) + 32|0);
   HEAPF32[$349>>2] = $342;
   $350 = (($108) + 36|0);
   HEAPF32[$350>>2] = $344;
   $351 = (($108) + 40|0);
   HEAPF32[$351>>2] = $346;
   $352 = (($108) + 44|0);
   HEAPF32[$352>>2] = $348;
   $353 = HEAP32[$91>>2]|0;
   $354 = ((($353) + (($90*76)|0)|0) + 80|0);
   HEAPF32[$354>>2] = $319;
   $355 = ((($353) + (($90*76)|0)|0) + 84|0);
   HEAPF32[$355>>2] = $321;
   $356 = ((($353) + (($90*76)|0)|0) + 88|0);
   HEAPF32[$356>>2] = $323;
   $357 = ((($353) + (($90*76)|0)|0) + 92|0);
   HEAPF32[$357>>2] = $325;
   $358 = Math_fround(HEAPF32[$337>>2]);
   $359 = Math_fround(HEAPF32[$338>>2]);
   $360 = Math_fround(HEAPF32[$339>>2]);
   $361 = Math_fround(HEAPF32[$340>>2]);
   $362 = ((($353) + (($90*76)|0)|0) + 96|0);
   HEAPF32[$362>>2] = $358;
   $363 = ((($353) + (($90*76)|0)|0) + 100|0);
   HEAPF32[$363>>2] = $359;
   $364 = ((($353) + (($90*76)|0)|0) + 104|0);
   HEAPF32[$364>>2] = $360;
   $365 = ((($353) + (($90*76)|0)|0) + 108|0);
   HEAPF32[$365>>2] = $361;
   $366 = Math_fround(HEAPF32[$349>>2]);
   $367 = Math_fround(HEAPF32[$350>>2]);
   $368 = Math_fround(HEAPF32[$351>>2]);
   $369 = Math_fround(HEAPF32[$352>>2]);
   $370 = ((($353) + (($90*76)|0)|0) + 112|0);
   HEAPF32[$370>>2] = $366;
   $371 = ((($353) + (($90*76)|0)|0) + 116|0);
   HEAPF32[$371>>2] = $367;
   $372 = ((($353) + (($90*76)|0)|0) + 120|0);
   HEAPF32[$372>>2] = $368;
   $373 = ((($353) + (($90*76)|0)|0) + 124|0);
   HEAPF32[$373>>2] = $369;
   $387 = $353;
  } else {
   $387 = $92;
  }
 }
 $374 = $left ? Math_fround(-1.0) : Math_fround(1.0);
 $375 = $41;
 $376 = HEAP32[$41>>2]|0;
 $377 = (($376) + ($375))|0;
 $378 = $377;
 $379 = (($378) + 392|0);
 $380 = Math_fround(HEAPF32[$379>>2]);
 $381 = Math_fround($374 * $380);
 $382 = (($378) + 420|0);
 $383 = Math_fround(HEAPF32[$382>>2]);
 $384 = Math_fround($381 * $383);
 $385 = Math_fround($384 + $384);
 $386 = ((($387) + (($90*76)|0)|0) + 96|0);
 $388 = Math_fround(HEAPF32[$386>>2]);
 $389 = Math_fround($388 * Math_fround(0.0));
 $390 = ((($387) + (($90*76)|0)|0) + 100|0);
 $391 = Math_fround(HEAPF32[$390>>2]);
 $392 = Math_fround($385 * $391);
 $393 = ((($387) + (($90*76)|0)|0) + 104|0);
 $394 = Math_fround(HEAPF32[$393>>2]);
 $395 = Math_fround($394 * Math_fround(0.0));
 $396 = ((($387) + (($90*76)|0)|0) + 108|0);
 $397 = Math_fround(HEAPF32[$396>>2]);
 $398 = Math_fround($397 * Math_fround(0.0));
 $399 = Math_fround($391 * Math_fround(0.0));
 $400 = Math_fround($388 * $385);
 $401 = Math_fround($389 - $399);
 $402 = Math_fround($392 - $395);
 $403 = Math_fround($395 - $400);
 $404 = Math_fround($398 - $398);
 $405 = Math_fround($397 * $402);
 $406 = Math_fround($401 * $397);
 $407 = Math_fround($397 * $404);
 $408 = Math_fround($405 + Math_fround(0.0));
 $409 = Math_fround($384 + $406);
 $410 = Math_fround($407 + Math_fround(0.0));
 $411 = Math_fround($388 * $403);
 $412 = Math_fround($391 * $401);
 $413 = Math_fround($391 * $402);
 $414 = Math_fround($394 * $403);
 $415 = Math_fround($411 - $413);
 $416 = Math_fround($412 - $414);
 $417 = Math_fround($407 - $407);
 $418 = Math_fround($408 + $416);
 $419 = Math_fround($409 + $415);
 $420 = Math_fround($410 + $417);
 $421 = Math_fround(HEAPF32[$37>>2]);
 $422 = Math_fround($421 * $418);
 $423 = Math_fround(HEAPF32[$38>>2]);
 $424 = Math_fround($423 * Math_fround(0.0));
 $425 = Math_fround(HEAPF32[$39>>2]);
 $426 = Math_fround($425 * $419);
 $427 = Math_fround(HEAPF32[$40>>2]);
 $428 = Math_fround($427 * $420);
 $429 = ((($387) + (($90*76)|0)|0) + 80|0);
 $430 = Math_fround(HEAPF32[$429>>2]);
 $431 = Math_fround($430 + $422);
 $432 = ((($387) + (($90*76)|0)|0) + 84|0);
 $433 = Math_fround(HEAPF32[$432>>2]);
 $434 = Math_fround($424 + $433);
 $435 = ((($387) + (($90*76)|0)|0) + 88|0);
 $436 = Math_fround(HEAPF32[$435>>2]);
 $437 = Math_fround($426 + $436);
 $438 = ((($387) + (($90*76)|0)|0) + 92|0);
 $439 = Math_fround(HEAPF32[$438>>2]);
 $440 = Math_fround($428 + $439);
 HEAPF32[$429>>2] = $431;
 HEAPF32[$432>>2] = $434;
 HEAPF32[$435>>2] = $437;
 HEAPF32[$438>>2] = $440;
 STACKTOP = sp;return;
}
function __ZN4mathL13xformInvMulNSERKNS_5xformES2_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0;
 var $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(-1.0));
 $3 = (($a) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(-1.0));
 $6 = (($a) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(-1.0));
 $9 = (($a) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$b>>2]);
 $12 = Math_fround(HEAPF32[$a>>2]);
 $13 = Math_fround($11 - $12);
 $14 = (($b) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = (($b) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($a) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 - $22);
 $24 = (($b) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($a) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 - $27);
 $29 = Math_fround($13 + $13);
 $30 = Math_fround($18 + $18);
 $31 = Math_fround($23 + $23);
 $32 = Math_fround($2 * $30);
 $33 = Math_fround($5 * $31);
 $34 = Math_fround($8 * $29);
 $35 = Math_fround($10 * Math_fround(0.0));
 $36 = Math_fround($5 * $29);
 $37 = Math_fround($8 * $30);
 $38 = Math_fround($2 * $31);
 $39 = Math_fround($32 - $36);
 $40 = Math_fround($33 - $37);
 $41 = Math_fround($34 - $38);
 $42 = Math_fround($35 - $35);
 $43 = Math_fround($10 * $40);
 $44 = Math_fround($10 * $41);
 $45 = Math_fround($10 * $39);
 $46 = Math_fround($10 * $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 + $45);
 $50 = Math_fround($46 + $28);
 $51 = Math_fround($2 * $41);
 $52 = Math_fround($5 * $39);
 $53 = Math_fround($8 * $40);
 $54 = Math_fround($5 * $40);
 $55 = Math_fround($8 * $41);
 $56 = Math_fround($2 * $39);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($52 - $55);
 $59 = Math_fround($53 - $56);
 $60 = Math_fround($46 - $46);
 $61 = Math_fround($47 + $58);
 $62 = Math_fround($48 + $59);
 $63 = Math_fround($49 + $57);
 $64 = Math_fround($60 + $50);
 $65 = (($b) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($5 * $66);
 $68 = (($b) + 28|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($10 * $69);
 $71 = (($b) + 20|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($8 * $72);
 $74 = (($b) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($2 * $75);
 $77 = Math_fround($10 * $75);
 $78 = Math_fround($2 * $66);
 $79 = Math_fround($5 * $75);
 $80 = Math_fround($8 * $66);
 $81 = Math_fround($67 - $77);
 $82 = Math_fround($70 - $78);
 $83 = Math_fround($73 - $79);
 $84 = Math_fround($76 - $80);
 $85 = Math_fround($8 * $69);
 $86 = Math_fround($8 * $75);
 $87 = Math_fround($10 * $66);
 $88 = Math_fround($10 * $72);
 $89 = Math_fround($81 - $85);
 $90 = Math_fround($82 - $86);
 $91 = Math_fround($83 - $87);
 $92 = Math_fround($84 - $88);
 $93 = Math_fround($2 * $72);
 $94 = Math_fround($5 * $72);
 $95 = Math_fround($2 * $69);
 $96 = Math_fround($5 * $69);
 $97 = Math_fround($89 - $93);
 $98 = Math_fround($90 - $94);
 $99 = Math_fround($91 - $95);
 $100 = Math_fround($92 - $96);
 $101 = Math_fround($99 * Math_fround(-1.0));
 $102 = Math_fround($100 * Math_fround(-1.0));
 $103 = Math_fround($97 * Math_fround(-1.0));
 $104 = Math_fround($101 * $101);
 $105 = Math_fround($102 * $102);
 $106 = Math_fround($103 * $103);
 $107 = Math_fround($98 * $98);
 $108 = Math_fround($104 + $105);
 $109 = Math_fround($107 + $106);
 $110 = Math_fround($108 + $109);
 $111 = (Math_fround(Math_sqrt((Math_fround($110)))));
 $112 = Math_fround(Math_fround(1.0) / $111);
 $113 = Math_fround($112 * $101);
 $114 = Math_fround($112 * $102);
 $115 = Math_fround($112 * $103);
 $116 = Math_fround($112 * $98);
 HEAPF32[$agg$result>>2] = $61;
 $117 = (($agg$result) + 4|0);
 HEAPF32[$117>>2] = $62;
 $118 = (($agg$result) + 8|0);
 HEAPF32[$118>>2] = $63;
 $119 = (($agg$result) + 12|0);
 HEAPF32[$119>>2] = $64;
 $120 = (($agg$result) + 16|0);
 HEAPF32[$120>>2] = $113;
 $121 = (($agg$result) + 20|0);
 HEAPF32[$121>>2] = $114;
 $122 = (($agg$result) + 24|0);
 HEAPF32[$122>>2] = $115;
 $123 = (($agg$result) + 28|0);
 HEAPF32[$123>>2] = $116;
 $124 = (($agg$result) + 32|0);
 HEAPF32[$124>>2] = Math_fround(1.0);
 $125 = (($agg$result) + 36|0);
 HEAPF32[$125>>2] = Math_fround(1.0);
 $126 = (($agg$result) + 40|0);
 HEAPF32[$126>>2] = Math_fround(1.0);
 $127 = (($agg$result) + 44|0);
 HEAPF32[$127>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN4mathL8xformMulERKNS_5xformES2_18903($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($a) + 32|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($b) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($a) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = (($b) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = (($b) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $17);
 $19 = Math_fround($3 + $3);
 $20 = Math_fround($8 + $8);
 $21 = Math_fround($13 + $13);
 $22 = (($a) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($20 * $23);
 $25 = (($a) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($21 * $26);
 $28 = (($a) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($19 * $29);
 $31 = (($a) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(0.0));
 $34 = Math_fround($19 * $26);
 $35 = Math_fround($20 * $29);
 $36 = Math_fround($21 * $23);
 $37 = Math_fround($24 - $34);
 $38 = Math_fround($27 - $35);
 $39 = Math_fround($30 - $36);
 $40 = Math_fround($33 - $33);
 $41 = Math_fround($32 * $38);
 $42 = Math_fround($32 * $39);
 $43 = Math_fround($37 * $32);
 $44 = Math_fround($32 * $40);
 $45 = Math_fround($3 + $41);
 $46 = Math_fround($8 + $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 * $39);
 $50 = Math_fround($26 * $37);
 $51 = Math_fround($29 * $38);
 $52 = Math_fround($26 * $38);
 $53 = Math_fround($29 * $39);
 $54 = Math_fround($23 * $37);
 $55 = Math_fround($49 - $52);
 $56 = Math_fround($50 - $53);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($44 - $44);
 $59 = Math_fround($45 + $56);
 $60 = Math_fround($46 + $57);
 $61 = Math_fround($47 + $55);
 $62 = Math_fround($48 + $58);
 $63 = Math_fround(HEAPF32[$a>>2]);
 $64 = Math_fround($63 + $59);
 $65 = (($a) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 + $60);
 $68 = (($a) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $61);
 $71 = (($a) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 + $62);
 $74 = (($b) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($26 * $75);
 $77 = (($b) + 28|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($32 * $78);
 $80 = (($b) + 20|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($29 * $81);
 $83 = (($b) + 24|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($23 * $84);
 $86 = Math_fround($32 * $84);
 $87 = Math_fround($75 * $23);
 $88 = Math_fround($26 * $84);
 $89 = Math_fround($75 * $29);
 $90 = Math_fround($76 - $86);
 $91 = Math_fround($79 - $87);
 $92 = Math_fround($82 - $88);
 $93 = Math_fround($85 - $89);
 $94 = Math_fround($78 * $29);
 $95 = Math_fround($29 * $84);
 $96 = Math_fround($75 * $32);
 $97 = Math_fround($32 * $81);
 $98 = Math_fround($90 - $94);
 $99 = Math_fround($91 - $95);
 $100 = Math_fround($92 - $96);
 $101 = Math_fround($93 - $97);
 $102 = Math_fround($81 * $23);
 $103 = Math_fround($26 * $81);
 $104 = Math_fround($78 * $23);
 $105 = Math_fround($26 * $78);
 $106 = Math_fround($98 - $102);
 $107 = Math_fround($99 - $103);
 $108 = Math_fround($100 - $104);
 $109 = Math_fround($101 - $105);
 $110 = Math_fround($108 * Math_fround(-1.0));
 $111 = Math_fround($109 * Math_fround(-1.0));
 $112 = Math_fround($106 * Math_fround(-1.0));
 $113 = Math_fround($110 * $110);
 $114 = Math_fround($111 * $111);
 $115 = Math_fround($112 * $112);
 $116 = Math_fround($107 * $107);
 $117 = Math_fround($113 + $114);
 $118 = Math_fround($116 + $115);
 $119 = Math_fround($117 + $118);
 $120 = (Math_fround(Math_sqrt((Math_fround($119)))));
 $121 = Math_fround(Math_fround(1.0) / $120);
 $122 = Math_fround($121 * $110);
 $123 = Math_fround($121 * $111);
 $124 = Math_fround($121 * $112);
 $125 = Math_fround($121 * $107);
 $126 = Math_fround(HEAPF32[$1>>2]);
 $127 = (($b) + 32|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($126 * $128);
 $130 = Math_fround(HEAPF32[$6>>2]);
 $131 = (($b) + 36|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($130 * $132);
 $134 = Math_fround(HEAPF32[$11>>2]);
 $135 = (($b) + 40|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($134 * $136);
 $138 = Math_fround(HEAPF32[$16>>2]);
 $139 = (($b) + 44|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($138 * $140);
 HEAPF32[$agg$result>>2] = $64;
 $142 = (($agg$result) + 4|0);
 HEAPF32[$142>>2] = $67;
 $143 = (($agg$result) + 8|0);
 HEAPF32[$143>>2] = $70;
 $144 = (($agg$result) + 12|0);
 HEAPF32[$144>>2] = $73;
 $145 = (($agg$result) + 16|0);
 HEAPF32[$145>>2] = $122;
 $146 = (($agg$result) + 20|0);
 HEAPF32[$146>>2] = $123;
 $147 = (($agg$result) + 24|0);
 HEAPF32[$147>>2] = $124;
 $148 = (($agg$result) + 28|0);
 HEAPF32[$148>>2] = $125;
 $149 = (($agg$result) + 32|0);
 HEAPF32[$149>>2] = $129;
 $150 = (($agg$result) + 36|0);
 HEAPF32[$150>>2] = $133;
 $151 = (($agg$result) + 40|0);
 HEAPF32[$151>>2] = $137;
 $152 = (($agg$result) + 44|0);
 HEAPF32[$152>>2] = $141;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation16EvaluateAvatarSMEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantERKNS0_12AnimationSetE($constant,$input,$output,$memory,$workspace,$controllerConstant,$animationSet) {
 $constant = $constant|0;
 $input = $input|0;
 $output = $output|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $controllerConstant = $controllerConstant|0;
 $animationSet = $animationSet|0;
 var $$not = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $exitcond = 0, $i$06 = 0, $i$11 = 0, $layerIndex$02 = 0, $or$cond = 0, $stateMachineInput = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $stateMachineInput = sp;
 $0 = ($controllerConstant|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($workspace) + 92|0);
 HEAP8[$1>>0] = 0;
 $2 = HEAP32[$controllerConstant>>2]|0;
 $3 = (($controllerConstant) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($workspace) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $memory;
 $10 = HEAP32[$memory>>2]|0;
 $11 = (($10) + ($9))|0;
 $12 = $11;
 $13 = (($memory) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = (($12) + 40|0);
 $15 = $14;
 $16 = HEAP32[$14>>2]|0;
 $17 = (($15) + ($16))|0;
 $18 = $17;
 $19 = (($12) + 44|0);
 HEAP32[$19>>2] = $18;
 $20 = HEAP32[$18>>2]|0;
 _memset(($8|0),0,($20|0))|0;
 $21 = ($4|0)==(0);
 L4: do {
  if (!($21)) {
   $22 = (($stateMachineInput) + 4|0);
   $23 = (($stateMachineInput) + 16|0);
   $24 = (($stateMachineInput) + 20|0);
   $25 = (($stateMachineInput) + 8|0);
   $26 = ($2|0)==(0);
   $27 = (($controllerConstant) + 16|0);
   $28 = $27;
   $29 = (($input) + 4|0);
   $30 = (($input) + 24|0);
   $31 = (($controllerConstant) + 24|0);
   $32 = $31;
   $33 = (($controllerConstant) + 28|0);
   $34 = (($controllerConstant) + 4|0);
   $35 = $34;
   $36 = (($stateMachineInput) + 12|0);
   $i$06 = 0;
   while(1) {
    HEAP32[$22>>2] = 0;
    HEAP32[$23>>2] = 0;
    HEAP32[$24>>2] = 0;
    $48 = HEAP32[$5>>2]|0;
    $49 = (($48) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    HEAP32[$25>>2] = $50;
    if (!($26)) {
     $51 = HEAP32[$34>>2]|0;
     $52 = (($51) + ($35))|0;
     $53 = $52;
     $84 = $50;$layerIndex$02 = 0;
     while(1) {
      $54 = (($53) + ($layerIndex$02<<3)|0);
      $55 = $54;
      $56 = HEAP32[$54>>2]|0;
      $57 = (($55) + ($56))|0;
      $58 = $57;
      $59 = HEAP32[$58>>2]|0;
      $60 = (($58) + 4|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($59|0)!=(-1);
      $63 = ($i$06|0)==($59|0);
      $or$cond = $62 & $63;
      L12: do {
       if ($or$cond) {
        $64 = ($61|0)==(0);
        do {
         if ($64) {
          $65 = HEAP32[$input>>2]|0;
          $66 = (($65) + (($layerIndex$02*20)|0)|0);
          HEAP32[$36>>2] = $66;
          $81 = $84;$82 = Math_fround(1.0);
         } else {
          $67 = (($58) + 37|0);
          $68 = HEAP8[$67>>0]|0;
          $$not = ($68<<24>>24)!=(0);
          $brmerge = $$not | $64;
          if ($brmerge) {
           $69 = HEAP32[$memory>>2]|0;
           $70 = (($69) + ($9))|0;
           $71 = $70;
           HEAP32[$13>>2] = $71;
           $72 = (($71) + 32|0);
           $73 = $72;
           $74 = HEAP32[$72>>2]|0;
           $75 = (($73) + ($74))|0;
           $76 = $75;
           $77 = (($71) + 36|0);
           HEAP32[$77>>2] = $76;
           $78 = (($76) + ($layerIndex$02<<2)|0);
           $79 = Math_fround(HEAPF32[$78>>2]);
           $$pre = HEAP32[$25>>2]|0;
           $81 = $$pre;$82 = $79;
           break;
          } else {
           $83 = (($84) + ($61<<2)|0);
           HEAPF32[$83>>2] = Math_fround(0.0);
           $163 = $84;
           break L12;
          }
         }
        } while(0);
        $80 = (($81) + ($61<<2)|0);
        HEAPF32[$80>>2] = $82;
        $163 = $81;
       } else {
        $163 = $84;
       }
      } while(0);
      $85 = (($layerIndex$02) + 1)|0;
      $exitcond = ($85|0)==($2|0);
      if ($exitcond) {
       break;
      } else {
       $84 = $163;$layerIndex$02 = $85;
      }
     }
    }
    $86 = HEAP32[$27>>2]|0;
    $87 = (($86) + ($28))|0;
    $88 = $87;
    $89 = (($88) + ($i$06<<3)|0);
    $90 = $89;
    $91 = HEAP32[$89>>2]|0;
    $92 = (($90) + ($91))|0;
    $93 = $92;
    $94 = Math_fround(HEAPF32[$29>>2]);
    HEAPF32[$stateMachineInput>>2] = $94;
    $95 = HEAP32[$memory>>2]|0;
    $96 = (($95) + ($9))|0;
    $97 = $96;
    HEAP32[$13>>2] = $97;
    $98 = (($97) + 48|0);
    $99 = HEAP32[$98>>2]|0;
    HEAP32[$23>>2] = $99;
    $100 = HEAP32[$30>>2]|0;
    HEAP32[$24>>2] = $100;
    HEAP32[$13>>2] = $97;
    $101 = (($97) + 40|0);
    $102 = $101;
    $103 = HEAP32[$101>>2]|0;
    $104 = (($102) + ($103))|0;
    $105 = $104;
    $106 = (($97) + 44|0);
    HEAP32[$106>>2] = $105;
    HEAP32[$22>>2] = $105;
    $107 = HEAP32[$5>>2]|0;
    $108 = HEAP32[$107>>2]|0;
    $109 = (($108) + ($i$06<<2)|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = HEAP32[$31>>2]|0;
    $112 = (($111) + ($32))|0;
    $113 = $112;
    HEAP32[$33>>2] = $113;
    $114 = (($110) + 4|0);
    HEAP32[$114>>2] = $113;
    $115 = HEAP32[$5>>2]|0;
    $116 = (($115) + 84|0);
    $117 = HEAP32[$115>>2]|0;
    $118 = (($117) + ($i$06<<2)|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = (($119) + 8|0);
    HEAP32[$120>>2] = $116;
    $121 = HEAP32[$5>>2]|0;
    $122 = (($121) + 4|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = (($123) + ($i$06<<2)|0);
    $125 = HEAP32[$124>>2]|0;
    HEAP32[$13>>2] = $97;
    $126 = (($97) + 4|0);
    $127 = $126;
    $128 = HEAP32[$126>>2]|0;
    $129 = (($127) + ($128))|0;
    $130 = $129;
    $131 = (($97) + 8|0);
    HEAP32[$131>>2] = $130;
    $132 = (($130) + ($i$06<<3)|0);
    $133 = $132;
    $134 = HEAP32[$132>>2]|0;
    $135 = (($133) + ($134))|0;
    $136 = $135;
    $137 = ((($130) + ($i$06<<3)|0) + 4|0);
    HEAP32[$137>>2] = $136;
    __ZN7mecanim12statemachine20EvaluateStateMachineERKNS0_20StateMachineConstantERKNS0_17StateMachineInputERNS0_18StateMachineOutputERNS0_18StateMachineMemoryERNS0_21StateMachineWorkspaceERKNS_9animation12AnimationSetE($93,$stateMachineInput,$125,$136,$110,$animationSet);
    $138 = (__ZN7mecanim12statemachine10IsDisabledEPKNS0_17StateMachineInputE($stateMachineInput)|0);
    if ($138) {
     break;
    }
    $139 = (($125) + 24|0);
    $140 = HEAP8[$139>>0]|0;
    $141 = HEAP8[$1>>0]|0;
    $142 = $141 | $140;
    HEAP8[$1>>0] = $142;
    $143 = (($125) + 48|0);
    $144 = HEAP8[$143>>0]|0;
    $145 = $142 | $144;
    HEAP8[$1>>0] = $145;
    $146 = (($i$06) + 1)|0;
    $147 = ($146>>>0)<($4>>>0);
    if ($147) {
     $i$06 = $146;
    } else {
     break L4;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $37 = HEAP32[$memory>>2]|0;
 $38 = (($37) + ($9))|0;
 $39 = $38;
 HEAP32[$13>>2] = $39;
 $40 = (($39) + 40|0);
 $41 = $40;
 $42 = HEAP32[$40>>2]|0;
 $43 = (($41) + ($42))|0;
 $44 = $43;
 $45 = (($39) + 44|0);
 HEAP32[$45>>2] = $44;
 $46 = HEAP32[$44>>2]|0;
 $47 = ($46|0)==(0);
 if ($47) {
  STACKTOP = sp;return;
 } else {
  $i$11 = 0;
 }
 while(1) {
  $148 = HEAP32[$5>>2]|0;
  $149 = (($148) + 84|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = (($150) + ($i$11)|0);
  $152 = HEAP8[$151>>0]|0;
  $153 = ($152<<24>>24)==(0);
  if (!($153)) {
   HEAP32[$13>>2] = $39;
   HEAP32[$45>>2] = $44;
   $154 = (($44) + 4|0);
   $155 = $154;
   $156 = HEAP32[$154>>2]|0;
   $157 = (($155) + ($156))|0;
   $158 = $157;
   $159 = (($44) + 8|0);
   HEAP32[$159>>2] = $158;
   $160 = (($158) + ($i$11)|0);
   HEAP8[$160>>0] = 0;
  }
  $161 = (($i$11) + 1)|0;
  HEAP32[$13>>2] = $39;
  HEAP32[$45>>2] = $44;
  $162 = ($161>>>0)<($46>>>0);
  if ($162) {
   $i$11 = $161;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation19AdjustPoseForMotionEPKNS0_25ControllerBindingConstantERKN4math5xformERNS_10ValueArrayERNS_8skeleton12SkeletonPoseESC_($controllerBindingConstant,$motionX,$values,$pose,$poseWs) {
 $controllerBindingConstant = $controllerBindingConstant|0;
 $motionX = $motionX|0;
 $values = $values|0;
 $pose = $pose|0;
 $poseWs = $poseWs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($controllerBindingConstant) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 120|0);
 $3 = $2;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($3) + ($4))|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + -1)|0;
 $9 = (($1) + 124|0);
 HEAP32[$9>>2] = $6;
 $10 = (($1) + 8|0);
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($1) + 12|0);
 HEAP32[$15>>2] = $14;
 $16 = (($controllerBindingConstant) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($1) + 140|0);
 $19 = $18;
 $20 = HEAP32[$18>>2]|0;
 $21 = (($20) + ($19))|0;
 $22 = $21;
 $23 = (($1) + 144|0);
 HEAP32[$23>>2] = $22;
 __ZN7mecanim9animation21SkeletonPoseFromValueERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseERKNS_10ValueArrayEPKNS0_14SkeletonTQSMapEPKiRS5_ii($6,$14,$values,$17,$22,$pose,$8,0);
 $24 = HEAP32[$2>>2]|0;
 $25 = (($24) + ($3))|0;
 $26 = $25;
 HEAP32[$9>>2] = $26;
 __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_($26,$pose,$poseWs);
 $27 = (($pose) + 4|0);
 $28 = $27;
 $29 = HEAP32[$27>>2]|0;
 $30 = (($29) + ($28))|0;
 $31 = $30;
 $32 = (($pose) + 8|0);
 HEAP32[$32>>2] = $31;
 $33 = Math_fround(HEAPF32[$motionX>>2]);
 $34 = (($motionX) + 4|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($motionX) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($motionX) + 12|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 HEAPF32[$31>>2] = $33;
 $40 = (($31) + 4|0);
 HEAPF32[$40>>2] = $35;
 $41 = (($31) + 8|0);
 HEAPF32[$41>>2] = $37;
 $42 = (($31) + 12|0);
 HEAPF32[$42>>2] = $39;
 $43 = (($motionX) + 16|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($motionX) + 20|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($motionX) + 24|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($motionX) + 28|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($31) + 16|0);
 HEAPF32[$51>>2] = $44;
 $52 = (($31) + 20|0);
 HEAPF32[$52>>2] = $46;
 $53 = (($31) + 24|0);
 HEAPF32[$53>>2] = $48;
 $54 = (($31) + 28|0);
 HEAPF32[$54>>2] = $50;
 $55 = (($motionX) + 32|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($motionX) + 36|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($motionX) + 40|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($motionX) + 44|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($31) + 32|0);
 HEAPF32[$63>>2] = $56;
 $64 = (($31) + 36|0);
 HEAPF32[$64>>2] = $58;
 $65 = (($31) + 40|0);
 HEAPF32[$65>>2] = $60;
 $66 = (($31) + 44|0);
 HEAPF32[$66>>2] = $62;
 $67 = (($1) + 68|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)>(0);
 if ($69) {
  $70 = HEAP32[$2>>2]|0;
  $71 = (($70) + ($3))|0;
  $72 = $71;
  HEAP32[$9>>2] = $72;
  $73 = (($7) + -2)|0;
  __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($72,$pose,$poseWs,$73,0);
 }
 $74 = HEAP32[$2>>2]|0;
 $75 = (($74) + ($3))|0;
 $76 = $75;
 HEAP32[$9>>2] = $76;
 __ZN7mecanim8skeleton24SkeletonPoseComputeLocalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($76,$poseWs,$pose,$8,$8);
 $77 = HEAP32[$27>>2]|0;
 $78 = (($77) + ($28))|0;
 $79 = $78;
 HEAP32[$32>>2] = $79;
 $80 = (($79) + 28|0);
 $81 = $78;
 ;HEAP32[$81+0>>2]=0|0;HEAP32[$81+4>>2]=0|0;HEAP32[$81+8>>2]=0|0;HEAP32[$81+12>>2]=0|0;HEAP32[$81+16>>2]=0|0;HEAP32[$81+20>>2]=0|0;HEAP32[$81+24>>2]=0|0;
 HEAPF32[$80>>2] = Math_fround(1.0);
 $82 = (($79) + 32|0);
 HEAPF32[$82>>2] = Math_fround(1.0);
 $83 = (($79) + 36|0);
 HEAPF32[$83>>2] = Math_fround(1.0);
 $84 = (($79) + 40|0);
 HEAPF32[$84>>2] = Math_fround(1.0);
 $85 = (($79) + 44|0);
 HEAPF32[$85>>2] = Math_fround(1.0);
 $86 = HEAP32[$2>>2]|0;
 $87 = (($86) + ($3))|0;
 $88 = $87;
 HEAP32[$9>>2] = $88;
 $89 = HEAP32[$16>>2]|0;
 $90 = HEAP32[$18>>2]|0;
 $91 = (($90) + ($19))|0;
 $92 = $91;
 HEAP32[$23>>2] = $92;
 __ZN7mecanim9animation21ValueFromSkeletonPoseERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseEPKNS0_14SkeletonTQSMapEPKiRNS_10ValueArrayEii($88,$pose,$89,$92,$values,$8,0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21SkeletonPoseFromValueERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseERKNS_10ValueArrayEPKNS0_14SkeletonTQSMapEPKiRS5_ii($skeleton,$defaultPose,$values,$skeletonTQSMap,$indexArray,$pose,$index,$stopIndex) {
 $skeleton = $skeleton|0;
 $defaultPose = $defaultPose|0;
 $values = $values|0;
 $skeletonTQSMap = $skeletonTQSMap|0;
 $indexArray = $indexArray|0;
 $pose = $pose|0;
 $index = $index|0;
 $stopIndex = $stopIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($index|0)==(-1);
 $1 = ($index|0)==($stopIndex|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = (($skeleton) + 4|0);
 $3 = $2;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + ($3))|0;
 $6 = $5;
 $7 = (($6) + ($index<<3)|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN7mecanim9animation21SkeletonPoseFromValueERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseERKNS_10ValueArrayEPKNS0_14SkeletonTQSMapEPKiRS5_ii($skeleton,$defaultPose,$values,$skeletonTQSMap,$indexArray,$pose,$8,$stopIndex);
 $9 = (($indexArray) + ($index<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($skeletonTQSMap) + (($10*12)|0)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(-1);
 $14 = (($pose) + 4|0);
 $15 = $14;
 $16 = HEAP32[$14>>2]|0;
 $17 = (($16) + ($15))|0;
 $18 = $17;
 $19 = (($pose) + 8|0);
 HEAP32[$19>>2] = $18;
 $20 = (($18) + (($index*48)|0)|0);
 if ($13) {
  $37 = (($defaultPose) + 4|0);
  $38 = $37;
  $39 = HEAP32[$37>>2]|0;
  $40 = (($39) + ($38))|0;
  $41 = $40;
  $42 = (($41) + (($10*48)|0)|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = ((($41) + (($10*48)|0)|0) + 4|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = ((($41) + (($10*48)|0)|0) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = ((($41) + (($10*48)|0)|0) + 12|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  HEAPF32[$20>>2] = $43;
  $50 = ((($18) + (($index*48)|0)|0) + 4|0);
  HEAPF32[$50>>2] = $45;
  $51 = ((($18) + (($index*48)|0)|0) + 8|0);
  HEAPF32[$51>>2] = $47;
  $52 = ((($18) + (($index*48)|0)|0) + 12|0);
  HEAPF32[$52>>2] = $49;
 } else {
  $21 = (($values) + 40|0);
  $22 = $21;
  $23 = HEAP32[$21>>2]|0;
  $24 = (($23) + ($22))|0;
  $25 = $24;
  $26 = (($25) + ($12<<4)|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = ((($25) + ($12<<4)|0) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = ((($25) + ($12<<4)|0) + 8|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = ((($25) + ($12<<4)|0) + 12|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  HEAPF32[$20>>2] = $27;
  $34 = ((($18) + (($index*48)|0)|0) + 4|0);
  HEAPF32[$34>>2] = $29;
  $35 = ((($18) + (($index*48)|0)|0) + 8|0);
  HEAPF32[$35>>2] = $31;
  $36 = ((($18) + (($index*48)|0)|0) + 12|0);
  HEAPF32[$36>>2] = $33;
 }
 $53 = ((($skeletonTQSMap) + (($10*12)|0)|0) + 4|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(-1);
 HEAP32[$19>>2] = $18;
 $56 = ((($18) + (($index*48)|0)|0) + 16|0);
 if ($55) {
  $73 = (($defaultPose) + 4|0);
  $74 = $73;
  $75 = HEAP32[$73>>2]|0;
  $76 = (($75) + ($74))|0;
  $77 = $76;
  $78 = ((($77) + (($10*48)|0)|0) + 16|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = ((($77) + (($10*48)|0)|0) + 20|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = ((($77) + (($10*48)|0)|0) + 24|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = ((($77) + (($10*48)|0)|0) + 28|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  HEAPF32[$56>>2] = $79;
  $86 = ((($18) + (($index*48)|0)|0) + 20|0);
  HEAPF32[$86>>2] = $81;
  $87 = ((($18) + (($index*48)|0)|0) + 24|0);
  HEAPF32[$87>>2] = $83;
  $88 = ((($18) + (($index*48)|0)|0) + 28|0);
  HEAPF32[$88>>2] = $85;
 } else {
  $57 = (($values) + 52|0);
  $58 = $57;
  $59 = HEAP32[$57>>2]|0;
  $60 = (($59) + ($58))|0;
  $61 = $60;
  $62 = (($61) + ($54<<4)|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = ((($61) + ($54<<4)|0) + 4|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($61) + ($54<<4)|0) + 8|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($61) + ($54<<4)|0) + 12|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  HEAPF32[$56>>2] = $63;
  $70 = ((($18) + (($index*48)|0)|0) + 20|0);
  HEAPF32[$70>>2] = $65;
  $71 = ((($18) + (($index*48)|0)|0) + 24|0);
  HEAPF32[$71>>2] = $67;
  $72 = ((($18) + (($index*48)|0)|0) + 28|0);
  HEAPF32[$72>>2] = $69;
 }
 $89 = ((($skeletonTQSMap) + (($10*12)|0)|0) + 8|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($90|0)==(-1);
 HEAP32[$19>>2] = $18;
 $92 = ((($18) + (($index*48)|0)|0) + 32|0);
 if ($91) {
  $109 = (($defaultPose) + 4|0);
  $110 = $109;
  $111 = HEAP32[$109>>2]|0;
  $112 = (($111) + ($110))|0;
  $113 = $112;
  $114 = ((($113) + (($10*48)|0)|0) + 32|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = ((($113) + (($10*48)|0)|0) + 36|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = ((($113) + (($10*48)|0)|0) + 40|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = ((($113) + (($10*48)|0)|0) + 44|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  HEAPF32[$92>>2] = $115;
  $122 = ((($18) + (($index*48)|0)|0) + 36|0);
  HEAPF32[$122>>2] = $117;
  $123 = ((($18) + (($index*48)|0)|0) + 40|0);
  HEAPF32[$123>>2] = $119;
  $124 = ((($18) + (($index*48)|0)|0) + 44|0);
  HEAPF32[$124>>2] = $121;
  STACKTOP = sp;return;
 } else {
  $93 = (($values) + 64|0);
  $94 = $93;
  $95 = HEAP32[$93>>2]|0;
  $96 = (($95) + ($94))|0;
  $97 = $96;
  $98 = (($97) + ($90<<4)|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = ((($97) + ($90<<4)|0) + 4|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $102 = ((($97) + ($90<<4)|0) + 8|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = ((($97) + ($90<<4)|0) + 12|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  HEAPF32[$92>>2] = $99;
  $106 = ((($18) + (($index*48)|0)|0) + 36|0);
  HEAPF32[$106>>2] = $101;
  $107 = ((($18) + (($index*48)|0)|0) + 40|0);
  HEAPF32[$107>>2] = $103;
  $108 = ((($18) + (($index*48)|0)|0) + 44|0);
  HEAPF32[$108>>2] = $105;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation21ValueFromSkeletonPoseERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseEPKNS0_14SkeletonTQSMapEPKiRNS_10ValueArrayEii($skeleton,$pose,$skeletonTQSMap,$indexArray,$values,$index,$stopIndex) {
 $skeleton = $skeleton|0;
 $pose = $pose|0;
 $skeletonTQSMap = $skeletonTQSMap|0;
 $indexArray = $indexArray|0;
 $values = $values|0;
 $index = $index|0;
 $stopIndex = $stopIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($index|0)==(-1);
 $1 = ($index|0)==($stopIndex|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = (($skeleton) + 4|0);
 $3 = $2;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + ($3))|0;
 $6 = $5;
 $7 = (($6) + ($index<<3)|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN7mecanim9animation21ValueFromSkeletonPoseERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseEPKNS0_14SkeletonTQSMapEPKiRNS_10ValueArrayEii($skeleton,$pose,$skeletonTQSMap,$indexArray,$values,$8,$stopIndex);
 $9 = (($indexArray) + ($index<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($skeletonTQSMap) + (($10*12)|0)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(-1);
 if (!($13)) {
  $14 = (($pose) + 4|0);
  $15 = $14;
  $16 = HEAP32[$14>>2]|0;
  $17 = (($16) + ($15))|0;
  $18 = $17;
  $19 = (($values) + 40|0);
  $20 = $19;
  $21 = HEAP32[$19>>2]|0;
  $22 = (($21) + ($20))|0;
  $23 = $22;
  $24 = (($values) + 44|0);
  HEAP32[$24>>2] = $23;
  $25 = (($18) + (($index*48)|0)|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = ((($18) + (($index*48)|0)|0) + 4|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = ((($18) + (($index*48)|0)|0) + 8|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = ((($18) + (($index*48)|0)|0) + 12|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($23) + ($12<<4)|0);
  HEAPF32[$33>>2] = $26;
  $34 = ((($23) + ($12<<4)|0) + 4|0);
  HEAPF32[$34>>2] = $28;
  $35 = ((($23) + ($12<<4)|0) + 8|0);
  HEAPF32[$35>>2] = $30;
  $36 = ((($23) + ($12<<4)|0) + 12|0);
  HEAPF32[$36>>2] = $32;
 }
 $37 = ((($skeletonTQSMap) + (($10*12)|0)|0) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(-1);
 if (!($39)) {
  $40 = (($pose) + 4|0);
  $41 = $40;
  $42 = HEAP32[$40>>2]|0;
  $43 = (($42) + ($41))|0;
  $44 = $43;
  $45 = (($values) + 52|0);
  $46 = $45;
  $47 = HEAP32[$45>>2]|0;
  $48 = (($47) + ($46))|0;
  $49 = $48;
  $50 = (($values) + 56|0);
  HEAP32[$50>>2] = $49;
  $51 = ((($44) + (($index*48)|0)|0) + 16|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = ((($44) + (($index*48)|0)|0) + 20|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = ((($44) + (($index*48)|0)|0) + 24|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = ((($44) + (($index*48)|0)|0) + 28|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($49) + ($38<<4)|0);
  HEAPF32[$59>>2] = $52;
  $60 = ((($49) + ($38<<4)|0) + 4|0);
  HEAPF32[$60>>2] = $54;
  $61 = ((($49) + ($38<<4)|0) + 8|0);
  HEAPF32[$61>>2] = $56;
  $62 = ((($49) + ($38<<4)|0) + 12|0);
  HEAPF32[$62>>2] = $58;
 }
 $63 = ((($skeletonTQSMap) + (($10*12)|0)|0) + 8|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(-1);
 if ($65) {
  STACKTOP = sp;return;
 }
 $66 = (($pose) + 4|0);
 $67 = $66;
 $68 = HEAP32[$66>>2]|0;
 $69 = (($68) + ($67))|0;
 $70 = $69;
 $71 = (($values) + 64|0);
 $72 = $71;
 $73 = HEAP32[$71>>2]|0;
 $74 = (($73) + ($72))|0;
 $75 = $74;
 $76 = (($values) + 68|0);
 HEAP32[$76>>2] = $75;
 $77 = ((($70) + (($index*48)|0)|0) + 32|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = ((($70) + (($index*48)|0)|0) + 36|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = ((($70) + (($index*48)|0)|0) + 40|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = ((($70) + (($index*48)|0)|0) + 44|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($75) + ($64<<4)|0);
 HEAPF32[$85>>2] = $78;
 $86 = ((($75) + ($64<<4)|0) + 4|0);
 HEAPF32[$86>>2] = $80;
 $87 = ((($75) + ($64<<4)|0) + 8|0);
 HEAPF32[$87>>2] = $82;
 $88 = ((($75) + ($64<<4)|0) + 12|0);
 HEAPF32[$88>>2] = $84;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17BlendingStateCopyERKNS0_13BlendingStateILb0EEERS2_bbRKNS_6bitsetILj59EEE($srcState,$destState,$hasGenericRootMotion,$isHuman,$mask) {
 $srcState = $srcState|0;
 $destState = $destState|0;
 $hasGenericRootMotion = $hasGenericRootMotion|0;
 $isHuman = $isHuman|0;
 $mask = $mask|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $srcState;
 $1 = HEAP32[$srcState>>2]|0;
 $2 = (($1) + ($0))|0;
 $3 = $2;
 $4 = (($srcState) + 4|0);
 HEAP32[$4>>2] = $3;
 $5 = $destState;
 $6 = HEAP32[$destState>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($destState) + 4|0);
 HEAP32[$9>>2] = $8;
 __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_($3,$8);
 $10 = (($destState) + 8|0);
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($destState) + 12|0);
 HEAP32[$15>>2] = $14;
 $16 = (($srcState) + 8|0);
 $17 = $16;
 $18 = HEAP32[$16>>2]|0;
 $19 = (($18) + ($17))|0;
 $20 = $19;
 $21 = (($srcState) + 12|0);
 HEAP32[$21>>2] = $20;
 __ZN7mecanim13CopyValueMaskEPNS_14ValueArrayMaskEPKS0_($14,$20);
 $brmerge = $hasGenericRootMotion | $isHuman;
 if ($brmerge) {
  $22 = (($destState) + 16|0);
  $23 = $22;
  $24 = HEAP32[$22>>2]|0;
  $25 = (($24) + ($23))|0;
  $26 = $25;
  $27 = (($destState) + 20|0);
  HEAP32[$27>>2] = $26;
  $28 = (($srcState) + 16|0);
  $29 = $28;
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + ($29))|0;
  $32 = $31;
  $33 = (($srcState) + 20|0);
  HEAP32[$33>>2] = $32;
  __ZN7mecanim9animation16MotionOutputCopyEPNS0_12MotionOutputEPKS1_bbRKNS_6bitsetILj59EEE($26,$32,$hasGenericRootMotion,$isHuman,$mask);
 }
 if (!($isHuman)) {
  STACKTOP = sp;return;
 }
 $34 = (($destState) + 24|0);
 $35 = $34;
 $36 = HEAP32[$34>>2]|0;
 $37 = (($36) + ($35))|0;
 $38 = $37;
 $39 = (($destState) + 28|0);
 HEAP32[$39>>2] = $38;
 $40 = (($srcState) + 24|0);
 $41 = $40;
 $42 = HEAP32[$40>>2]|0;
 $43 = (($42) + ($41))|0;
 $44 = $43;
 $45 = (($srcState) + 28|0);
 HEAP32[$45>>2] = $44;
 __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($38,$44,0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation16RestoreBlendNodeERKNS0_13BlendingStateILb0EEEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEiRjPNS0_16ControllerMemoryEPNS0_15AvatarWorkspaceEPNS0_12AvatarOutputEf($backupState,$controllerBindingConstant,$input,$layerIndex,$clipCount,$memory,$workspace,$avatarOutput,$blendFactor) {
 $backupState = $backupState|0;
 $controllerBindingConstant = $controllerBindingConstant|0;
 $input = $input|0;
 $layerIndex = $layerIndex|0;
 $clipCount = $clipCount|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $avatarOutput = $avatarOutput|0;
 $blendFactor = Math_fround($blendFactor);
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $mask = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mask = sp;
 $0 = (($controllerBindingConstant) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($controllerBindingConstant) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  label = 3;
 } else {
  $7 = $4;
  $8 = (($5) + ($7))|0;
  $9 = $8;
  $10 = (($9) + 48|0);
  $11 = $10;
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + ($11))|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0);
  if ($16) {
   label = 3;
  } else {
   $47 = 0;$48 = 1;
  }
 }
 if ((label|0) == 3) {
  $17 = (($1) + 68|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(-1);
  if ($19) {
   $20 = (($input) + 22|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)!=(0);
   $47 = $22;$48 = 0;
  } else {
   $47 = 1;$48 = 0;
  }
 }
 $23 = (($workspace) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($avatarOutput|0)!=(0|0);
 $$pre = HEAP32[$clipCount>>2]|0;
 $28 = ($$pre|0)==(0);
 $or$cond = $27 & $28;
 $29 = $backupState;
 $30 = HEAP32[$backupState>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($backupState) + 4|0);
 HEAP32[$33>>2] = $32;
 if ($or$cond) {
  $34 = HEAP32[$avatarOutput>>2]|0;
  __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_($32,$34);
 } else {
  $35 = HEAP32[$26>>2]|0;
  $36 = (($35) + ($$pre<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_($32,$37);
 }
 $38 = HEAP32[$23>>2]|0;
 $39 = (($38) + 72|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($backupState) + 8|0);
 $42 = $41;
 $43 = HEAP32[$41>>2]|0;
 $44 = (($43) + ($42))|0;
 $45 = $44;
 $46 = (($backupState) + 12|0);
 HEAP32[$46>>2] = $45;
 __ZN7mecanim13CopyValueMaskEPNS_14ValueArrayMaskEPKS0_($40,$45);
 $brmerge = $47 | $48;
 if ($brmerge) {
  $49 = (($3) + 4|0);
  $50 = $49;
  $51 = HEAP32[$49>>2]|0;
  $52 = (($51) + ($50))|0;
  $53 = $52;
  $54 = (($53) + ($layerIndex<<3)|0);
  $55 = $54;
  $56 = HEAP32[$54>>2]|0;
  $57 = (($55) + ($56))|0;
  $58 = $57;
  $59 = (($58) + 8|0);
  $60 = $59;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = (($60) + 4)|0;
  $64 = $63;
  $65 = HEAP32[$64>>2]|0;
  $66 = $mask;
  $67 = $66;
  HEAP32[$67>>2] = $62;
  $68 = (($66) + 4)|0;
  $69 = $68;
  HEAP32[$69>>2] = $65;
  $70 = HEAP32[$clipCount>>2]|0;
  $71 = (($26) + 4|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + ($70<<2)|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($backupState) + 16|0);
  $76 = $75;
  $77 = HEAP32[$75>>2]|0;
  $78 = (($77) + ($76))|0;
  $79 = $78;
  $80 = (($backupState) + 20|0);
  HEAP32[$80>>2] = $79;
  __ZN7mecanim9animation16MotionOutputCopyEPNS0_12MotionOutputEPKS1_bbRKNS_6bitsetILj59EEE($74,$79,$47,$48,$mask);
 }
 $81 = HEAP32[$23>>2]|0;
 $82 = (($81) + 76|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($81) + 72|0);
 $85 = HEAP32[$84>>2]|0;
 __ZN7mecanim11OrValueMaskEPNS_14ValueArrayMaskEPKS0_($83,$85);
 if (!($48)) {
  $97 = HEAP32[$clipCount>>2]|0;
  $98 = (($26) + 12|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = (($99) + ($97<<2)|0);
  HEAPF32[$100>>2] = $blendFactor;
  $101 = (($97) + 1)|0;
  HEAP32[$clipCount>>2] = $101;
  STACKTOP = sp;return;
 }
 $86 = HEAP32[$clipCount>>2]|0;
 $87 = (($26) + 8|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($88) + ($86<<2)|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = (($backupState) + 24|0);
 $92 = $91;
 $93 = HEAP32[$91>>2]|0;
 $94 = (($93) + ($92))|0;
 $95 = $94;
 $96 = (($backupState) + 28|0);
 HEAP32[$96>>2] = $95;
 __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($90,$95,0);
 $97 = HEAP32[$clipCount>>2]|0;
 $98 = (($26) + 12|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = (($99) + ($97<<2)|0);
 HEAPF32[$100>>2] = $blendFactor;
 $101 = (($97) + 1)|0;
 HEAP32[$clipCount>>2] = $101;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17EvaluateBlendNodeEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEibbRjPNS0_16ControllerMemoryEPNS0_15AvatarWorkspaceEPNS0_12AvatarOutputEPNS0_18AnimationSetMemoryEPff($controllerBindingConstant,$input,$layerIndex,$additive,$left,$clipCount,$memory,$workspace,$avatarOutput,$animationSetMemory,$blendFactor,$transitionBlendFactor) {
 $controllerBindingConstant = $controllerBindingConstant|0;
 $input = $input|0;
 $layerIndex = $layerIndex|0;
 $additive = $additive|0;
 $left = $left|0;
 $clipCount = $clipCount|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $avatarOutput = $avatarOutput|0;
 $animationSetMemory = $animationSetMemory|0;
 $blendFactor = $blendFactor|0;
 $transitionBlendFactor = Math_fround($transitionBlendFactor);
 var $$ = 0, $$in = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = Math_fround(0);
 var $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = 0, $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0;
 var $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = 0, $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = 0;
 var $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $476 = Math_fround(0), $477 = Math_fround(0), $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = 0, $482 = Math_fround(0), $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = 0;
 var $491 = Math_fround(0), $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = 0, $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = Math_fround(0), $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = Math_fround(0), $544 = 0;
 var $545 = Math_fround(0), $546 = 0, $547 = Math_fround(0), $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = 0, $56 = 0, $560 = 0, $561 = Math_fround(0), $562 = 0;
 var $563 = Math_fround(0), $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = 0;
 var $581 = 0, $582 = 0, $583 = Math_fround(0), $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $brmerge = 0, $dx = 0, $exitcond = 0, $in = 0, $leftFootDX = 0, $muscleIn = 0, $muscleIn1 = 0, $normalizedTime = 0, $or$cond = 0, $or$cond18 = 0, $outputIter$020 = 0, $rightFootDX = 0, $timeInt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $muscleIn = sp + 328|0;
 $in = sp + 324|0;
 $timeInt = sp + 320|0;
 $normalizedTime = sp + 316|0;
 $muscleIn1 = sp + 288|0;
 $0 = sp + 240|0;
 $dx = sp + 144|0;
 $leftFootDX = sp + 96|0;
 $1 = sp + 48|0;
 $rightFootDX = sp;
 $2 = sp + 192|0;
 $3 = (($controllerBindingConstant) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($controllerBindingConstant) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($controllerBindingConstant) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($4) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  label = 3;
 } else {
  $12 = $9;
  $13 = (($10) + ($12))|0;
  $14 = $13;
  $15 = (($14) + 48|0);
  $16 = $15;
  $17 = HEAP32[$15>>2]|0;
  $18 = (($17) + ($16))|0;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   label = 3;
  } else {
   $78 = 0;$79 = 1;
  }
 }
 if ((label|0) == 3) {
  $22 = (($4) + 68|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==(-1);
  if ($24) {
   $25 = (($input) + 22|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = ($26<<24>>24)!=(0);
   $78 = $27;$79 = 0;
  } else {
   $78 = 1;$79 = 0;
  }
 }
 $28 = (($memory) + 24|0);
 $29 = $28;
 $30 = HEAP32[$28>>2]|0;
 $31 = (($30) + ($29))|0;
 $32 = $31;
 $33 = (($memory) + 28|0);
 HEAP32[$33>>2] = $32;
 $34 = (($32) + (($layerIndex*36)|0)|0);
 $35 = (($6) + 4|0);
 $36 = $35;
 $37 = HEAP32[$35>>2]|0;
 $38 = (($37) + ($36))|0;
 $39 = $38;
 $40 = (($39) + ($layerIndex<<3)|0);
 $41 = $40;
 $42 = HEAP32[$40>>2]|0;
 $43 = (($41) + ($42))|0;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(-1);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = (($44) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($memory) + 4|0);
 $50 = $49;
 $51 = HEAP32[$49>>2]|0;
 $52 = (($51) + ($50))|0;
 $53 = $52;
 $54 = (($memory) + 8|0);
 HEAP32[$54>>2] = $53;
 $55 = (($53) + ($45<<3)|0);
 $56 = $55;
 $57 = HEAP32[$55>>2]|0;
 $58 = (($56) + ($57))|0;
 $59 = $58;
 $60 = ((($53) + ($45<<3)|0) + 4|0);
 HEAP32[$60>>2] = $59;
 $61 = (($workspace) + 24|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + ($45<<2)|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + 4|0);
 $68 = (($66) + 28|0);
 $69 = $left ? $67 : $68;
 $70 = (($animationSetMemory) + 8|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$69>>2]|0;
 $73 = (($72) + (($48*24)|0)|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if ($75) {
  $$pre = (($69) + 21|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $76 = ((($72) + (($48*24)|0)|0) + 4|0);
  $77 = (($8) + 12|0);
  $brmerge = $78 | $79;
  $80 = (($muscleIn) + 4|0);
  $81 = (($muscleIn) + 8|0);
  $82 = (($muscleIn) + 12|0);
  $83 = (($muscleIn) + 16|0);
  $84 = (($muscleIn) + 20|0);
  $85 = (($muscleIn) + 24|0);
  $86 = (($69) + 4|0);
  $87 = (($69) + 8|0);
  $88 = ((($72) + (($48*24)|0)|0) + 16|0);
  $89 = ((($72) + (($48*24)|0)|0) + 20|0);
  $90 = ((($72) + (($48*24)|0)|0) + 12|0);
  $91 = (($animationSetMemory) + 4|0);
  $92 = ($avatarOutput|0)==(0|0);
  $93 = (($69) + 21|0);
  $94 = $34;
  $95 = ((($32) + (($layerIndex*36)|0)|0) + 4|0);
  $96 = (($8) + 36|0);
  $97 = (($muscleIn1) + 4|0);
  $98 = (($muscleIn1) + 8|0);
  $99 = (($muscleIn1) + 12|0);
  $100 = (($muscleIn1) + 16|0);
  $101 = (($muscleIn1) + 20|0);
  $102 = (($muscleIn1) + 24|0);
  $103 = (($input) + 8|0);
  $104 = (($input) + 12|0);
  $105 = (($workspace) + 20|0);
  $106 = (($0) + 4|0);
  $107 = (($0) + 8|0);
  $108 = (($0) + 12|0);
  $109 = (($0) + 16|0);
  $110 = (($0) + 20|0);
  $111 = (($0) + 24|0);
  $112 = (($0) + 28|0);
  $113 = (($0) + 32|0);
  $114 = (($0) + 36|0);
  $115 = (($0) + 40|0);
  $116 = (($0) + 44|0);
  $117 = (($workspace) + 76|0);
  $118 = (($leftFootDX) + 4|0);
  $119 = (($leftFootDX) + 8|0);
  $120 = (($leftFootDX) + 12|0);
  $121 = (($workspace) + 80|0);
  $122 = (($leftFootDX) + 28|0);
  $123 = (($leftFootDX) + 16|0);
  $124 = (($leftFootDX) + 20|0);
  $125 = (($leftFootDX) + 24|0);
  $126 = (($workspace) + 84|0);
  $127 = (($rightFootDX) + 4|0);
  $128 = (($rightFootDX) + 8|0);
  $129 = (($rightFootDX) + 12|0);
  $130 = (($workspace) + 88|0);
  $131 = (($rightFootDX) + 28|0);
  $132 = (($rightFootDX) + 16|0);
  $133 = (($rightFootDX) + 20|0);
  $134 = (($rightFootDX) + 24|0);
  $135 = (($8) + 32|0);
  $136 = (($input) + 23|0);
  $137 = (($4) + 68|0);
  $138 = (($workspace) + 12|0);
  $139 = (($workspace) + 16|0);
  $140 = ((($72) + (($48*24)|0)|0) + 8|0);
  $141 = (($69) + 12|0);
  $142 = (($memory) + 48|0);
  $143 = (($69) + 16|0);
  $144 = (($59) + 56|0);
  $145 = (($59) + 64|0);
  $146 = (($controllerBindingConstant) + 4|0);
  $167 = $62;$outputIter$020 = 0;
  while(1) {
   $147 = HEAP32[$76>>2]|0;
   $148 = (($147) + ($outputIter$020<<2)|0);
   $149 = HEAP32[$148>>2]|0;
   $150 = HEAP32[$77>>2]|0;
   $151 = (($150) + (($149*36)|0)|0);
   $152 = HEAP32[$151>>2]|0;
   $153 = ($152|0)==(0|0);
   if ($153) {
    $597 = $167;
   } else {
    do {
     if ($brmerge) {
      HEAPF32[$muscleIn>>2] = Math_fround(0.0);
      HEAPF32[$80>>2] = Math_fround(0.0);
      HEAP32[$81>>2] = 0;
      HEAPF32[$82>>2] = Math_fround(1.0);
      HEAPF32[$83>>2] = Math_fround(1.0);
      HEAP8[$84>>0] = 0;
      HEAPF32[$85>>2] = Math_fround(0.0);
      $154 = Math_fround(HEAPF32[$86>>2]);
      HEAPF32[$muscleIn>>2] = $154;
      $155 = Math_fround(HEAPF32[$87>>2]);
      HEAPF32[$80>>2] = $155;
      $156 = HEAP32[$88>>2]|0;
      $157 = (($156) + ($outputIter$020)|0);
      $158 = HEAP8[$157>>0]|0;
      HEAP8[$84>>0] = $158;
      $159 = HEAP32[$89>>2]|0;
      $160 = (($159) + ($outputIter$020<<2)|0);
      $161 = Math_fround(HEAPF32[$160>>2]);
      HEAPF32[$85>>2] = $161;
      $162 = HEAP32[$90>>2]|0;
      $163 = (($162) + ($outputIter$020<<2)|0);
      $164 = Math_fround(HEAPF32[$163>>2]);
      HEAPF32[$83>>2] = $164;
      $165 = HEAP32[$clipCount>>2]|0;
      $166 = (($167) + 16|0);
      $168 = HEAP32[$166>>2]|0;
      $169 = (($168) + 4|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = (($170) + ($165<<2)|0);
      $172 = HEAP32[$171>>2]|0;
      if ($79) {
       $173 = HEAP32[$91>>2]|0;
       $174 = (($173) + ($149<<2)|0);
       $175 = HEAP32[$174>>2]|0;
       __ZN7mecanim9animation26EvaluateClipMusclePrevTimeERKNS0_18ClipMuscleConstantERKNS0_15ClipMuscleInputERNS0_12MotionOutputERNS0_10ClipMemoryE($152,$muscleIn,$172,$175);
       break;
      }
      if ($78) {
       $176 = HEAP32[$91>>2]|0;
       $177 = (($176) + ($149<<2)|0);
       $178 = HEAP32[$177>>2]|0;
       __ZN7mecanim9animation28EvaluateClipRootMotionDeltaXERKNS0_18ClipMuscleConstantERKNS0_15ClipMuscleInputERNS0_12MotionOutputERNS0_10ClipMemoryE($152,$muscleIn,$172,$178);
      }
     }
    } while(0);
    if ($92) {
     label = 17;
    } else {
     $179 = HEAP32[$clipCount>>2]|0;
     $180 = ($179|0)==(0);
     if ($180) {
      $$in = $avatarOutput;
     } else {
      label = 17;
     }
    }
    if ((label|0) == 17) {
     label = 0;
     $181 = HEAP32[$clipCount>>2]|0;
     $182 = HEAP32[$61>>2]|0;
     $183 = (($182) + 16|0);
     $184 = HEAP32[$183>>2]|0;
     $185 = HEAP32[$184>>2]|0;
     $186 = (($185) + ($181<<2)|0);
     $$in = $186;
    }
    $187 = HEAP32[$$in>>2]|0;
    HEAPF32[$normalizedTime>>2] = Math_fround(0.0);
    $188 = Math_fround(HEAPF32[$86>>2]);
    $189 = (($152) + 1048|0);
    $190 = Math_fround(HEAPF32[$189>>2]);
    $191 = (($152) + 1052|0);
    $192 = Math_fround(HEAPF32[$191>>2]);
    $193 = (($152) + 1064|0);
    $194 = Math_fround(HEAPF32[$193>>2]);
    $195 = HEAP32[$89>>2]|0;
    $196 = (($195) + ($outputIter$020<<2)|0);
    $197 = Math_fround(HEAPF32[$196>>2]);
    $198 = Math_fround($194 + $197);
    $199 = (($152) + 1633|0);
    $200 = HEAP8[$199>>0]|0;
    $201 = ($200<<24>>24)!=(0);
    $202 = HEAP32[$90>>2]|0;
    $203 = (($202) + ($outputIter$020<<2)|0);
    $204 = Math_fround(HEAPF32[$203>>2]);
    $205 = $204 < Math_fround(0.0);
    $206 = (Math_fround(__ZN7mecanim9animation15ComputeClipTimeEffffbbRfS1_($188,$190,$192,$198,$201,$205,$normalizedTime,$timeInt)));
    HEAPF32[$in>>2] = $206;
    $207 = HEAP32[$61>>2]|0;
    $208 = (($207) + 72|0);
    $209 = HEAP32[$208>>2]|0;
    $210 = (($207) + 76|0);
    $211 = HEAP32[$210>>2]|0;
    $212 = (($152) + 1040|0);
    $213 = $212;
    $214 = HEAP32[$212>>2]|0;
    $215 = (($214) + ($213))|0;
    $216 = $215;
    $217 = (($152) + 1044|0);
    HEAP32[$217>>2] = $216;
    $218 = HEAP32[$91>>2]|0;
    $219 = (($218) + ($149<<2)|0);
    $220 = HEAP32[$219>>2]|0;
    __ZN7mecanim9animation12EvaluateClipEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEPNS0_10ClipOutputE($216,$in,$220,$71);
    $221 = HEAP8[$93>>0]|0;
    $222 = ($221<<24>>24)==(0);
    if ($222) {
     $224 = HEAP32[$34>>2]|0;
     $225 = (($224) + ($94))|0;
     $226 = $225;
     HEAP32[$95>>2] = $226;
     $229 = $226;
    } else {
     $223 = HEAP32[$146>>2]|0;
     $229 = $223;
    }
    $227 = ((($150) + (($149*36)|0)|0) + 12|0);
    $228 = HEAP32[$96>>2]|0;
    __ZN7mecanim9animation14ValuesFromClipERKNS_10ValueArrayERKNS0_18ClipMuscleConstantERKNS0_10ClipOutputERKNS0_12ClipBindingsEiRS1_RNS_14ValueArrayMaskEb($229,0,$71,$227,$228,$187,$209,$222);
    __ZN7mecanim11OrValueMaskEPNS_14ValueArrayMaskEPKS0_($211,$209);
    if ($additive) {
     label = 24;
    } else {
     $230 = HEAP8[$199>>0]|0;
     $231 = ($230<<24>>24)==(0);
     if (!($231)) {
      $232 = (($152) + 1634|0);
      $233 = HEAP8[$232>>0]|0;
      $234 = ($233<<24>>24)==(0);
      if (!($234)) {
       label = 24;
      }
     }
    }
    if ((label|0) == 24) {
     label = 0;
     $235 = HEAP32[$61>>2]|0;
     $236 = (($235) + 64|0);
     $237 = HEAP32[$236>>2]|0;
     $238 = (($235) + 68|0);
     $239 = HEAP32[$238>>2]|0;
     __ZN7mecanim9animation14DeltasFromClipERKNS0_18ClipMuscleConstantERKNS0_12ClipBindingsERKNS_14ValueArrayMaskERNS_10ValueArrayESB_($152,$227,$209,$237,$239);
    }
    if ($brmerge) {
     HEAPF32[$muscleIn1>>2] = Math_fround(0.0);
     HEAPF32[$97>>2] = Math_fround(0.0);
     HEAP32[$98>>2] = 0;
     HEAPF32[$99>>2] = Math_fround(1.0);
     HEAPF32[$100>>2] = Math_fround(1.0);
     HEAP8[$101>>0] = 0;
     HEAPF32[$102>>2] = Math_fround(0.0);
     $240 = Math_fround(HEAPF32[$86>>2]);
     HEAPF32[$muscleIn1>>2] = $240;
     $241 = Math_fround(HEAPF32[$87>>2]);
     HEAPF32[$97>>2] = $241;
     $242 = HEAP32[$clipCount>>2]|0;
     $243 = HEAP32[$61>>2]|0;
     $244 = (($243) + 16|0);
     $245 = HEAP32[$244>>2]|0;
     $246 = (($245) + 4|0);
     $247 = HEAP32[$246>>2]|0;
     $248 = (($247) + ($242<<2)|0);
     $249 = HEAP32[$248>>2]|0;
     do {
      if ($79) {
       $250 = HEAP32[$103>>2]|0;
       $251 = Math_fround(HEAPF32[$104>>2]);
       HEAPF32[$99>>2] = $251;
       $252 = ($250|0)>(0);
       $$ = $252 ? $250 : 0;
       $253 = ($$|0)<(5);
       $254 = $253 ? $$ : 5;
       HEAP32[$98>>2] = $254;
       $255 = HEAP32[$88>>2]|0;
       $256 = (($255) + ($outputIter$020)|0);
       $257 = HEAP8[$256>>0]|0;
       HEAP8[$101>>0] = $257;
       $258 = HEAP32[$89>>2]|0;
       $259 = (($258) + ($outputIter$020<<2)|0);
       $260 = Math_fround(HEAPF32[$259>>2]);
       HEAPF32[$102>>2] = $260;
       $261 = HEAP32[$90>>2]|0;
       $262 = (($261) + ($outputIter$020<<2)|0);
       $263 = Math_fround(HEAPF32[$262>>2]);
       HEAPF32[$100>>2] = $263;
       $264 = (($245) + 8|0);
       $265 = HEAP32[$264>>2]|0;
       $266 = (($265) + ($242<<2)|0);
       $267 = HEAP32[$266>>2]|0;
       $268 = HEAP32[$71>>2]|0;
       $269 = HEAP32[$91>>2]|0;
       $270 = (($269) + ($149<<2)|0);
       $271 = HEAP32[$270>>2]|0;
       __ZN7mecanim9animation18EvaluateClipMuscleERKNS0_18ClipMuscleConstantERKNS0_15ClipMuscleInputEPKfRNS0_12MotionOutputERNS_5human9HumanPoseERNS0_10ClipMemoryE($152,$muscleIn1,$268,$249,$267,$271);
       if ($additive) {
        $272 = (($152) + 1624|0);
        $273 = $272;
        $274 = HEAP32[$272>>2]|0;
        $275 = (($274) + ($273))|0;
        $276 = $275;
        $277 = (($152) + 1628|0);
        HEAP32[$277>>2] = $276;
        $278 = HEAP32[$105>>2]|0;
        __ZN7mecanim9animation12GetHumanPoseERKNS0_18ClipMuscleConstantEPKNS0_10ValueDeltaERNS_5human9HumanPoseE($152,$276,$278);
        $279 = (($152) + 1632|0);
        $280 = HEAP8[$279>>0]|0;
        $281 = ($280<<24>>24)==(0);
        if (!($281)) {
         $282 = HEAP32[$105>>2]|0;
         __ZN7mecanim5human15HumanPoseMirrorERNS0_9HumanPoseERKS1_($282,$282);
        }
        $283 = (($249) + 84|0);
        __ZN4mathL8xformMulERKNS_5xformES2_18903($0,$283,$267);
        $284 = Math_fround(HEAPF32[$0>>2]);
        $285 = Math_fround(HEAPF32[$106>>2]);
        $286 = Math_fround(HEAPF32[$107>>2]);
        $287 = Math_fround(HEAPF32[$108>>2]);
        HEAPF32[$267>>2] = $284;
        $288 = (($267) + 4|0);
        HEAPF32[$288>>2] = $285;
        $289 = (($267) + 8|0);
        HEAPF32[$289>>2] = $286;
        $290 = (($267) + 12|0);
        HEAPF32[$290>>2] = $287;
        $291 = Math_fround(HEAPF32[$109>>2]);
        $292 = Math_fround(HEAPF32[$110>>2]);
        $293 = Math_fround(HEAPF32[$111>>2]);
        $294 = Math_fround(HEAPF32[$112>>2]);
        $295 = (($267) + 16|0);
        HEAPF32[$295>>2] = $291;
        $296 = (($267) + 20|0);
        HEAPF32[$296>>2] = $292;
        $297 = (($267) + 24|0);
        HEAPF32[$297>>2] = $293;
        $298 = (($267) + 28|0);
        HEAPF32[$298>>2] = $294;
        $299 = Math_fround(HEAPF32[$113>>2]);
        $300 = Math_fround(HEAPF32[$114>>2]);
        $301 = Math_fround(HEAPF32[$115>>2]);
        $302 = Math_fround(HEAPF32[$116>>2]);
        $303 = (($267) + 32|0);
        HEAPF32[$303>>2] = $299;
        $304 = (($267) + 36|0);
        HEAPF32[$304>>2] = $300;
        $305 = (($267) + 40|0);
        HEAPF32[$305>>2] = $301;
        $306 = (($267) + 44|0);
        HEAPF32[$306>>2] = $302;
        $307 = HEAP32[$105>>2]|0;
        __ZN7mecanim5human12HumanPoseSubERNS0_9HumanPoseERKS1_S4_($267,$267,$307);
        $308 = (($267) + 80|0);
        $309 = (($267) + 108|0);
        ;HEAP32[$308+0>>2]=0|0;HEAP32[$308+4>>2]=0|0;HEAP32[$308+8>>2]=0|0;HEAP32[$308+12>>2]=0|0;HEAP32[$308+16>>2]=0|0;HEAP32[$308+20>>2]=0|0;HEAP32[$308+24>>2]=0|0;
        HEAPF32[$309>>2] = Math_fround(1.0);
        $310 = (($267) + 112|0);
        HEAPF32[$310>>2] = Math_fround(1.0);
        $311 = (($267) + 116|0);
        HEAPF32[$311>>2] = Math_fround(1.0);
        $312 = (($267) + 120|0);
        HEAPF32[$312>>2] = Math_fround(1.0);
        $313 = (($267) + 124|0);
        HEAPF32[$313>>2] = Math_fround(1.0);
        $314 = (($267) + 156|0);
        $315 = (($267) + 184|0);
        ;HEAP32[$314+0>>2]=0|0;HEAP32[$314+4>>2]=0|0;HEAP32[$314+8>>2]=0|0;HEAP32[$314+12>>2]=0|0;HEAP32[$314+16>>2]=0|0;HEAP32[$314+20>>2]=0|0;HEAP32[$314+24>>2]=0|0;
        HEAPF32[$315>>2] = Math_fround(1.0);
        $316 = (($267) + 188|0);
        HEAPF32[$316>>2] = Math_fround(1.0);
        $317 = (($267) + 192|0);
        HEAPF32[$317>>2] = Math_fround(1.0);
        $318 = (($267) + 196|0);
        HEAPF32[$318>>2] = Math_fround(1.0);
        $319 = (($267) + 200|0);
        HEAPF32[$319>>2] = Math_fround(1.0);
        $320 = (($267) + 232|0);
        $321 = (($267) + 260|0);
        ;HEAP32[$320+0>>2]=0|0;HEAP32[$320+4>>2]=0|0;HEAP32[$320+8>>2]=0|0;HEAP32[$320+12>>2]=0|0;HEAP32[$320+16>>2]=0|0;HEAP32[$320+20>>2]=0|0;HEAP32[$320+24>>2]=0|0;
        HEAPF32[$321>>2] = Math_fround(1.0);
        $322 = (($267) + 264|0);
        HEAPF32[$322>>2] = Math_fround(1.0);
        $323 = (($267) + 268|0);
        HEAPF32[$323>>2] = Math_fround(1.0);
        $324 = (($267) + 272|0);
        HEAPF32[$324>>2] = Math_fround(1.0);
        $325 = (($267) + 276|0);
        HEAPF32[$325>>2] = Math_fround(1.0);
        $326 = (($267) + 308|0);
        $327 = (($267) + 336|0);
        ;HEAP32[$326+0>>2]=0|0;HEAP32[$326+4>>2]=0|0;HEAP32[$326+8>>2]=0|0;HEAP32[$326+12>>2]=0|0;HEAP32[$326+16>>2]=0|0;HEAP32[$326+20>>2]=0|0;HEAP32[$326+24>>2]=0|0;
        HEAPF32[$327>>2] = Math_fround(1.0);
        $328 = (($267) + 340|0);
        HEAPF32[$328>>2] = Math_fround(1.0);
        $329 = (($267) + 344|0);
        HEAPF32[$329>>2] = Math_fround(1.0);
        $330 = (($267) + 348|0);
        HEAPF32[$330>>2] = Math_fround(1.0);
        $331 = (($267) + 352|0);
        HEAPF32[$331>>2] = Math_fround(1.0);
        __ZN7mecanim9animation17MotionOutputClearEPNS0_12MotionOutputE($249);
       }
       $332 = Math_fround(HEAPF32[$249>>2]);
       $333 = $332 != Math_fround(0.0);
       if ($333) {
        __ZN7mecanim9animation29MotionOutputGetDeltaTransformEPKNS0_12MotionOutputE($dx,$249);
        $334 = (($249) + 276|0);
        $335 = (($267) + 80|0);
        __ZN4mathL8xformMulERKNS_5xformES2_18903($1,$dx,$335);
        __ZN4mathL11xformInvMulERKNS_5xformES2_($leftFootDX,$334,$1);
        $336 = (($249) + 324|0);
        $337 = (($267) + 156|0);
        __ZN4mathL8xformMulERKNS_5xformES2_18903($2,$dx,$337);
        __ZN4mathL11xformInvMulERKNS_5xformES2_($rightFootDX,$336,$2);
        $338 = Math_fround(HEAPF32[$117>>2]);
        $339 = Math_fround(HEAPF32[$leftFootDX>>2]);
        $340 = Math_fround($339 * $339);
        $341 = Math_fround(HEAPF32[$118>>2]);
        $342 = Math_fround($341 * $341);
        $343 = Math_fround(HEAPF32[$119>>2]);
        $344 = Math_fround($343 * $343);
        $345 = Math_fround(HEAPF32[$120>>2]);
        $346 = Math_fround($345 * $345);
        $347 = Math_fround($340 + $342);
        $348 = Math_fround($344 + $346);
        $349 = Math_fround($347 + $348);
        $350 = (Math_fround(Math_sqrt((Math_fround($349)))));
        $351 = Math_fround(HEAPF32[$249>>2]);
        $352 = Math_fround($350 / $351);
        $353 = $338 < $352;
        $354 = $353 ? $352 : $338;
        HEAPF32[$117>>2] = $354;
        $355 = Math_fround(HEAPF32[$121>>2]);
        $356 = Math_fround(HEAPF32[$122>>2]);
        $357 = $356 == Math_fround(0.0);
        $358 = $357 ? Math_fround(9.99999997475242707878E-7) : $356;
        $359 = Math_fround(HEAPF32[$123>>2]);
        $360 = Math_fround($359 / $358);
        $361 = Math_fround(HEAPF32[$124>>2]);
        $362 = Math_fround($361 / $358);
        $363 = Math_fround(HEAPF32[$125>>2]);
        $364 = Math_fround($363 / $358);
        $365 = (Math_fround(+(Math_atan((+$360)))));
        $366 = (Math_fround(+(Math_atan((+$362)))));
        $367 = (Math_fround(+(Math_atan((+$364)))));
        $368 = (Math_fround(+(Math_atan(0.0))));
        $369 = Math_fround($365 * Math_fround(2.0));
        $370 = Math_fround($366 * Math_fround(2.0));
        $371 = Math_fround($367 * Math_fround(2.0));
        $372 = Math_fround($368 * Math_fround(2.0));
        $373 = Math_fround($369 * $369);
        $374 = Math_fround($370 * $370);
        $375 = Math_fround($371 * $371);
        $376 = Math_fround($372 * $372);
        $377 = Math_fround($373 + $374);
        $378 = Math_fround($375 + $376);
        $379 = Math_fround($377 + $378);
        $380 = (Math_fround(Math_sqrt((Math_fround($379)))));
        $381 = Math_fround(HEAPF32[$249>>2]);
        $382 = Math_fround($380 / $381);
        $383 = $355 < $382;
        $384 = $383 ? $382 : $355;
        HEAPF32[$121>>2] = $384;
        $385 = Math_fround(HEAPF32[$126>>2]);
        $386 = Math_fround(HEAPF32[$rightFootDX>>2]);
        $387 = Math_fround($386 * $386);
        $388 = Math_fround(HEAPF32[$127>>2]);
        $389 = Math_fround($388 * $388);
        $390 = Math_fround(HEAPF32[$128>>2]);
        $391 = Math_fround($390 * $390);
        $392 = Math_fround(HEAPF32[$129>>2]);
        $393 = Math_fround($392 * $392);
        $394 = Math_fround($387 + $389);
        $395 = Math_fround($391 + $393);
        $396 = Math_fround($394 + $395);
        $397 = (Math_fround(Math_sqrt((Math_fround($396)))));
        $398 = Math_fround(HEAPF32[$249>>2]);
        $399 = Math_fround($397 / $398);
        $400 = $385 < $399;
        $401 = $400 ? $399 : $385;
        HEAPF32[$126>>2] = $401;
        $402 = Math_fround(HEAPF32[$130>>2]);
        $403 = Math_fround(HEAPF32[$131>>2]);
        $404 = $403 == Math_fround(0.0);
        $405 = $404 ? Math_fround(9.99999997475242707878E-7) : $403;
        $406 = Math_fround(HEAPF32[$132>>2]);
        $407 = Math_fround($406 / $405);
        $408 = Math_fround(HEAPF32[$133>>2]);
        $409 = Math_fround($408 / $405);
        $410 = Math_fround(HEAPF32[$134>>2]);
        $411 = Math_fround($410 / $405);
        $412 = (Math_fround(+(Math_atan((+$407)))));
        $413 = (Math_fround(+(Math_atan((+$409)))));
        $414 = (Math_fround(+(Math_atan((+$411)))));
        $415 = Math_fround($412 * Math_fround(2.0));
        $416 = Math_fround($413 * Math_fround(2.0));
        $417 = Math_fround($414 * Math_fround(2.0));
        $418 = Math_fround($415 * $415);
        $419 = Math_fround($416 * $416);
        $420 = Math_fround($417 * $417);
        $421 = Math_fround($418 + $419);
        $422 = Math_fround($376 + $420);
        $423 = Math_fround($421 + $422);
        $424 = (Math_fround(Math_sqrt((Math_fround($423)))));
        $425 = Math_fround(HEAPF32[$249>>2]);
        $426 = Math_fround($424 / $425);
        $427 = $402 < $426;
        $428 = $427 ? $426 : $402;
        HEAPF32[$130>>2] = $428;
       }
      } else {
       $429 = HEAP32[$137>>2]|0;
       $430 = ($429|0)==(-1);
       if (!($430)) {
        if ($additive) {
         __ZN7mecanim9animation17MotionOutputClearEPNS0_12MotionOutputE($249);
         break;
        } else {
         $431 = (($249) + 132|0);
         $432 = (($243) + 64|0);
         $433 = HEAP32[$432>>2]|0;
         $434 = HEAP32[$138>>2]|0;
         $435 = HEAP32[$139>>2]|0;
         __ZN7mecanim9animation19AdjustPoseForMotionEPKNS0_25ControllerBindingConstantERKN4math5xformERNS_10ValueArrayERNS_8skeleton12SkeletonPoseESC_($controllerBindingConstant,$431,$433,$434,$435);
         $436 = (($249) + 180|0);
         $437 = HEAP32[$61>>2]|0;
         $438 = (($437) + 68|0);
         $439 = HEAP32[$438>>2]|0;
         $440 = HEAP32[$138>>2]|0;
         $441 = HEAP32[$139>>2]|0;
         __ZN7mecanim9animation19AdjustPoseForMotionEPKNS0_25ControllerBindingConstantERKN4math5xformERNS_10ValueArrayERNS_8skeleton12SkeletonPoseESC_($controllerBindingConstant,$436,$439,$440,$441);
         $442 = (($249) + 84|0);
         $443 = HEAP32[$138>>2]|0;
         $444 = HEAP32[$139>>2]|0;
         __ZN7mecanim9animation19AdjustPoseForMotionEPKNS0_25ControllerBindingConstantERKN4math5xformERNS_10ValueArrayERNS_8skeleton12SkeletonPoseESC_($controllerBindingConstant,$442,$187,$443,$444);
         break;
        }
       }
      }
     } while(0);
     $445 = HEAP32[$135>>2]|0;
     $446 = ($445|0)==(-1);
     if ($446) {
      label = 40;
     } else {
      $447 = (($209) + 28|0);
      $448 = $447;
      $449 = HEAP32[$447>>2]|0;
      $450 = (($449) + ($448))|0;
      $451 = $450;
      $452 = (($209) + 32|0);
      HEAP32[$452>>2] = $451;
      $453 = (($451) + ($445)|0);
      $454 = HEAP8[$453>>0]|0;
      $455 = ($454<<24>>24)==(0);
      if ($455) {
       label = 40;
      } else {
       $456 = (($249) + 420|0);
       $457 = (($187) + 28|0);
       $458 = $457;
       $459 = HEAP32[$457>>2]|0;
       $460 = (($459) + ($458))|0;
       $461 = $460;
       $462 = (($461) + ($445<<2)|0);
       $463 = Math_fround(HEAPF32[$462>>2]);
       HEAPF32[$456>>2] = $463;
      }
     }
     if ((label|0) == 40) {
      label = 0;
      $464 = (($152) + 1636|0);
      $465 = HEAP8[$464>>0]|0;
      $466 = $465&255;
      $467 = (Math_fround(($466|0)));
      $468 = (($249) + 420|0);
      HEAPF32[$468>>2] = $467;
     }
     $469 = HEAP8[$136>>0]|0;
     $470 = ($469<<24>>24)==(0);
     if ($470) {
      $471 = Math_fround(HEAPF32[$249>>2]);
      $472 = (($249) + 4|0);
      $473 = Math_fround(HEAPF32[$472>>2]);
      $474 = Math_fround($471 * $473);
      $475 = (($249) + 8|0);
      $476 = Math_fround(HEAPF32[$475>>2]);
      $477 = Math_fround($471 * $476);
      $478 = (($249) + 12|0);
      $479 = Math_fround(HEAPF32[$478>>2]);
      $480 = Math_fround($471 * $479);
      $481 = (($249) + 16|0);
      $482 = Math_fround(HEAPF32[$481>>2]);
      $483 = Math_fround($471 * $482);
      HEAPF32[$472>>2] = $474;
      HEAPF32[$475>>2] = $477;
      HEAPF32[$478>>2] = $480;
      HEAPF32[$481>>2] = $483;
      $484 = (($249) + 20|0);
      $485 = Math_fround(HEAPF32[$484>>2]);
      $486 = Math_fround($471 * $485);
      $487 = (($249) + 24|0);
      $488 = Math_fround(HEAPF32[$487>>2]);
      $489 = Math_fround($471 * $488);
      $490 = (($249) + 28|0);
      $491 = Math_fround(HEAPF32[$490>>2]);
      $492 = Math_fround($471 * $491);
      $493 = (($249) + 32|0);
      $494 = Math_fround(HEAPF32[$493>>2]);
      $495 = Math_fround($471 * $494);
      HEAPF32[$484>>2] = $486;
      HEAPF32[$487>>2] = $489;
      HEAPF32[$490>>2] = $492;
      HEAPF32[$493>>2] = $495;
     }
    }
    if ($additive) {
     $496 = HEAP32[$61>>2]|0;
     $497 = (($496) + 64|0);
     $498 = HEAP32[$497>>2]|0;
     __ZN7mecanim13ValueArraySubERKNS_10ValueArrayERS0_PKNS_14ValueArrayMaskE($498,$187,$209);
    }
    $499 = HEAP8[$199>>0]|0;
    $500 = ($499<<24>>24)==(0);
    if (!($500)) {
     $501 = (($152) + 1634|0);
     $502 = HEAP8[$501>>0]|0;
     $503 = ($502<<24>>24)==(0);
     if (!($503)) {
      $504 = HEAP32[$61>>2]|0;
      $505 = (($504) + 64|0);
      $506 = HEAP32[$505>>2]|0;
      $507 = (($504) + 68|0);
      $508 = HEAP32[$507>>2]|0;
      $509 = Math_fround(HEAPF32[$normalizedTime>>2]);
      __ZN7mecanim14ValueArrayLoopERKNS_10ValueArrayES2_RS0_fRKNS_14ValueArrayMaskE($506,$508,$187,$509,$209);
     }
    }
    $510 = HEAP32[$140>>2]|0;
    $511 = (($510) + ($outputIter$020<<2)|0);
    $512 = Math_fround(HEAPF32[$511>>2]);
    $513 = Math_fround($512 * $transitionBlendFactor);
    $514 = HEAP32[$clipCount>>2]|0;
    $515 = (($blendFactor) + ($514<<2)|0);
    HEAPF32[$515>>2] = $513;
    $516 = HEAP32[$61>>2]|0;
    $517 = (($516) + 56|0);
    $518 = HEAP32[$517>>2]|0;
    $519 = (($516) + 60|0);
    $520 = HEAP32[$519>>2]|0;
    $521 = ((($150) + (($149*36)|0)|0) + 4|0);
    $522 = HEAP32[$521>>2]|0;
    $523 = (($520) + ($518<<5)|0);
    HEAP32[$523>>2] = $522;
    $524 = HEAP32[$141>>2]|0;
    $525 = ((($520) + ($518<<5)|0) + 24|0);
    HEAP32[$525>>2] = $524;
    $526 = ((($520) + ($518<<5)|0) + 4|0);
    HEAP32[$526>>2] = $layerIndex;
    $527 = HEAP32[$clipCount>>2]|0;
    $528 = (($blendFactor) + ($527<<2)|0);
    $529 = Math_fround(HEAPF32[$528>>2]);
    $530 = ((($520) + ($518<<5)|0) + 8|0);
    HEAPF32[$530>>2] = $529;
    $531 = HEAP32[$142>>2]|0;
    $532 = ($531|0)==(1);
    $533 = ((($520) + ($518<<5)|0) + 28|0);
    $534 = $532&1;
    HEAP8[$533>>0] = $534;
    $535 = Math_fround(HEAPF32[$87>>2]);
    $536 = Math_fround(HEAPF32[$189>>2]);
    $537 = Math_fround(HEAPF32[$191>>2]);
    $538 = Math_fround(HEAPF32[$193>>2]);
    $539 = HEAP8[$199>>0]|0;
    $540 = ($539<<24>>24)!=(0);
    $541 = HEAP32[$90>>2]|0;
    $542 = (($541) + ($outputIter$020<<2)|0);
    $543 = Math_fround(HEAPF32[$542>>2]);
    $544 = $543 < Math_fround(0.0);
    $545 = (Math_fround(__ZN7mecanim9animation15ComputeClipTimeEffffbbRfS1_($535,$536,$537,$538,$540,$544,$normalizedTime,$timeInt)));
    $546 = ((($520) + ($518<<5)|0) + 12|0);
    HEAPF32[$546>>2] = $545;
    $547 = Math_fround(HEAPF32[$in>>2]);
    $548 = ((($520) + ($518<<5)|0) + 16|0);
    HEAPF32[$548>>2] = $547;
    $549 = HEAP32[$143>>2]|0;
    $550 = $549 & 1;
    $551 = ($550|0)==(0);
    if ($551) {
     label = 51;
    } else {
     $552 = HEAP8[$199>>0]|0;
     $553 = ($552<<24>>24)==(0);
     $554 = $547 == Math_fround(0.0);
     $or$cond18 = $553 & $554;
     if ($or$cond18) {
      $555 = Math_fround(HEAPF32[$87>>2]);
      $556 = Math_fround(HEAPF32[$189>>2]);
      $557 = Math_fround(HEAPF32[$191>>2]);
      $558 = Math_fround(HEAPF32[$193>>2]);
      $559 = HEAP32[$90>>2]|0;
      $560 = (($559) + ($outputIter$020<<2)|0);
      $561 = Math_fround(HEAPF32[$560>>2]);
      $562 = $561 < Math_fround(0.0);
      $563 = (Math_fround(__ZN7mecanim9animation15ComputeClipTimeEffffbbRfS1_($555,$556,$557,$558,1,$562,$normalizedTime,$timeInt)));
      HEAPF32[$546>>2] = $563;
     } else {
      label = 51;
     }
    }
    if ((label|0) == 51) {
     label = 0;
     $564 = $549 & 2;
     $565 = ($564|0)==(0);
     if (!($565)) {
      $566 = HEAP8[$199>>0]|0;
      $567 = ($566<<24>>24)==(0);
      if (!($567)) {
       $568 = Math_fround(HEAPF32[$144>>2]);
       $569 = Math_fround(HEAPF32[$189>>2]);
       $570 = Math_fround(HEAPF32[$191>>2]);
       $571 = Math_fround(HEAPF32[$193>>2]);
       $572 = HEAP32[$90>>2]|0;
       $573 = (($572) + ($outputIter$020<<2)|0);
       $574 = Math_fround(HEAPF32[$573>>2]);
       $575 = $574 < Math_fround(0.0);
       $576 = (Math_fround(__ZN7mecanim9animation15ComputeClipTimeEffffbbRfS1_($568,$569,$570,$571,1,$575,$normalizedTime,$timeInt)));
       $577 = Math_fround(HEAPF32[$145>>2]);
       $578 = Math_fround($576 + $577);
       $579 = Math_fround(HEAPF32[$191>>2]);
       $580 = !($578 <= $579);
       if (!($580)) {
        HEAPF32[$548>>2] = $578;
       }
      }
     }
    }
    $581 = HEAP32[$90>>2]|0;
    $582 = (($581) + ($outputIter$020<<2)|0);
    $583 = Math_fround(HEAPF32[$582>>2]);
    $584 = ((($520) + ($518<<5)|0) + 20|0);
    HEAPF32[$584>>2] = $583;
    $585 = HEAP32[$61>>2]|0;
    $586 = (($585) + 56|0);
    $587 = HEAP32[$586>>2]|0;
    $588 = (($587) + 1)|0;
    HEAP32[$586>>2] = $588;
    $589 = HEAP32[$clipCount>>2]|0;
    $590 = (($589) + 1)|0;
    HEAP32[$clipCount>>2] = $590;
    $597 = $585;
   }
   $591 = (($outputIter$020) + 1)|0;
   $exitcond = ($591|0)==($74|0);
   if ($exitcond) {
    $$pre$phiZ2D = $93;
    break;
   } else {
    $167 = $597;$outputIter$020 = $591;
   }
  }
 }
 $592 = HEAP8[$$pre$phiZ2D>>0]|0;
 $593 = ($592<<24>>24)==(0);
 if (!($593)) {
  STACKTOP = sp;return;
 }
 $594 = HEAP32[$73>>2]|0;
 $595 = ($594|0)==(0);
 $596 = $transitionBlendFactor > Math_fround(0.0);
 $or$cond = $595 & $596;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 __ZN7mecanim9animation16RestoreBlendNodeERKNS0_13BlendingStateILb0EEEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEiRjPNS0_16ControllerMemoryEPNS0_15AvatarWorkspaceEPNS0_12AvatarOutputEf($34,$controllerBindingConstant,$input,$layerIndex,$clipCount,0,$workspace,$avatarOutput,$transitionBlendFactor);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation14ValuesFromClipERKNS_10ValueArrayERKNS0_18ClipMuscleConstantERKNS0_10ClipOutputERKNS0_12ClipBindingsEiRS1_RNS_14ValueArrayMaskEb($valuesFallBack,$cst,$clip,$bindings,$integerRemapStride,$values,$valueArrayMask,$usePreviousAsFallback) {
 $valuesFallBack = $valuesFallBack|0;
 $cst = $cst|0;
 $clip = $clip|0;
 $bindings = $bindings|0;
 $integerRemapStride = $integerRemapStride|0;
 $values = $values|0;
 $valueArrayMask = $valueArrayMask|0;
 $usePreviousAsFallback = $usePreviousAsFallback|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0;
 var $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0;
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $valueIndex$014 = 0, $valueIndex1$010 = 0, $valueIndex4$06 = 0, $valueIndex7$02 = 0, $valueIndex9$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$clip>>2]|0;
 $1 = (($values) + 40|0);
 $2 = $1;
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + ($2))|0;
 $5 = $4;
 $6 = (($values) + 44|0);
 HEAP32[$6>>2] = $5;
 $7 = (($valueArrayMask) + 40|0);
 $8 = $7;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = (($valueArrayMask) + 44|0);
 HEAP32[$12>>2] = $11;
 $13 = (($values) + 36|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = (($valuesFallBack) + 40|0);
  $17 = $16;
  $18 = $usePreviousAsFallback&1;
  $valueIndex$014 = 0;
  while(1) {
   $19 = HEAP32[$bindings>>2]|0;
   $20 = (($19) + ($valueIndex$014<<1)|0);
   $21 = HEAP16[$20>>1]|0;
   $22 = $21 << 16 >> 16;
   $23 = ($21<<16>>16)==(-1);
   if ($23) {
    HEAP32[$6>>2] = $5;
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + ($17))|0;
    $26 = $25;
    $27 = (($26) + ($valueIndex$014<<4)|0);
    $28 = Math_fround(HEAPF32[$27>>2]);
    $29 = ((($26) + ($valueIndex$014<<4)|0) + 4|0);
    $30 = Math_fround(HEAPF32[$29>>2]);
    $31 = ((($26) + ($valueIndex$014<<4)|0) + 8|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = ((($26) + ($valueIndex$014<<4)|0) + 12|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = (($5) + ($valueIndex$014<<4)|0);
    HEAPF32[$35>>2] = $28;
    $36 = ((($5) + ($valueIndex$014<<4)|0) + 4|0);
    HEAPF32[$36>>2] = $30;
    $37 = ((($5) + ($valueIndex$014<<4)|0) + 8|0);
    HEAPF32[$37>>2] = $32;
    $38 = ((($5) + ($valueIndex$014<<4)|0) + 12|0);
    HEAPF32[$38>>2] = $34;
    $39 = (($11) + ($valueIndex$014)|0);
    HEAP8[$39>>0] = $18;
   } else {
    $40 = (($5) + ($valueIndex$014<<4)|0);
    $41 = (($0) + ($22<<2)|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    HEAPF32[$40>>2] = $42;
    $43 = (($22) + 1)|0;
    $44 = (($0) + ($43<<2)|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = (($40) + 4|0);
    HEAPF32[$46>>2] = $45;
    $47 = (($22) + 2)|0;
    $48 = (($0) + ($47<<2)|0);
    $49 = Math_fround(HEAPF32[$48>>2]);
    $50 = (($40) + 8|0);
    HEAPF32[$50>>2] = $49;
    $51 = (($40) + 12|0);
    HEAPF32[$51>>2] = Math_fround(0.0);
    $52 = (($11) + ($valueIndex$014)|0);
    HEAP8[$52>>0] = 1;
   }
   $53 = (($valueIndex$014) + 1)|0;
   $54 = ($53>>>0)<($14>>>0);
   if ($54) {
    $valueIndex$014 = $53;
   } else {
    break;
   }
  }
 }
 $55 = (($values) + 52|0);
 $56 = $55;
 $57 = HEAP32[$55>>2]|0;
 $58 = (($57) + ($56))|0;
 $59 = $58;
 $60 = (($values) + 56|0);
 HEAP32[$60>>2] = $59;
 $61 = (($valueArrayMask) + 52|0);
 $62 = $61;
 $63 = HEAP32[$61>>2]|0;
 $64 = (($63) + ($62))|0;
 $65 = $64;
 $66 = (($valueArrayMask) + 56|0);
 HEAP32[$66>>2] = $65;
 $67 = (($values) + 48|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)==(0);
 if (!($69)) {
  $70 = (($bindings) + 4|0);
  $71 = (($valuesFallBack) + 52|0);
  $72 = $71;
  $73 = $usePreviousAsFallback&1;
  $valueIndex1$010 = 0;
  while(1) {
   $74 = HEAP32[$70>>2]|0;
   $75 = (($74) + ($valueIndex1$010<<1)|0);
   $76 = HEAP16[$75>>1]|0;
   $77 = $76 << 16 >> 16;
   $78 = ($76<<16>>16)==(-1);
   if ($78) {
    HEAP32[$60>>2] = $59;
    $79 = HEAP32[$71>>2]|0;
    $80 = (($79) + ($72))|0;
    $81 = $80;
    $82 = (($81) + ($valueIndex1$010<<4)|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = ((($81) + ($valueIndex1$010<<4)|0) + 4|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = ((($81) + ($valueIndex1$010<<4)|0) + 8|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = ((($81) + ($valueIndex1$010<<4)|0) + 12|0);
    $89 = Math_fround(HEAPF32[$88>>2]);
    $90 = (($59) + ($valueIndex1$010<<4)|0);
    HEAPF32[$90>>2] = $83;
    $91 = ((($59) + ($valueIndex1$010<<4)|0) + 4|0);
    HEAPF32[$91>>2] = $85;
    $92 = ((($59) + ($valueIndex1$010<<4)|0) + 8|0);
    HEAPF32[$92>>2] = $87;
    $93 = ((($59) + ($valueIndex1$010<<4)|0) + 12|0);
    HEAPF32[$93>>2] = $89;
    $94 = (($65) + ($valueIndex1$010)|0);
    HEAP8[$94>>0] = $73;
   } else {
    $95 = (($59) + ($valueIndex1$010<<4)|0);
    $96 = (($0) + ($77<<2)|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    HEAPF32[$95>>2] = $97;
    $98 = (($77) + 1)|0;
    $99 = (($0) + ($98<<2)|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $101 = (($95) + 4|0);
    HEAPF32[$101>>2] = $100;
    $102 = (($77) + 2)|0;
    $103 = (($0) + ($102<<2)|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = (($95) + 8|0);
    HEAPF32[$105>>2] = $104;
    $106 = (($77) + 3)|0;
    $107 = (($0) + ($106<<2)|0);
    $108 = Math_fround(HEAPF32[$107>>2]);
    $109 = (($95) + 12|0);
    HEAPF32[$109>>2] = $108;
    $110 = (($65) + ($valueIndex1$010)|0);
    HEAP8[$110>>0] = 1;
   }
   $111 = (($valueIndex1$010) + 1)|0;
   $112 = ($111>>>0)<($68>>>0);
   if ($112) {
    $valueIndex1$010 = $111;
   } else {
    break;
   }
  }
 }
 $113 = (($values) + 64|0);
 $114 = $113;
 $115 = HEAP32[$113>>2]|0;
 $116 = (($115) + ($114))|0;
 $117 = $116;
 $118 = (($values) + 68|0);
 HEAP32[$118>>2] = $117;
 $119 = (($valueArrayMask) + 64|0);
 $120 = $119;
 $121 = HEAP32[$119>>2]|0;
 $122 = (($121) + ($120))|0;
 $123 = $122;
 $124 = (($valueArrayMask) + 68|0);
 HEAP32[$124>>2] = $123;
 $125 = (($values) + 60|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($126|0)==(0);
 if (!($127)) {
  $128 = (($bindings) + 8|0);
  $129 = (($valuesFallBack) + 64|0);
  $130 = $129;
  $131 = $usePreviousAsFallback&1;
  $valueIndex4$06 = 0;
  while(1) {
   $132 = HEAP32[$128>>2]|0;
   $133 = (($132) + ($valueIndex4$06<<1)|0);
   $134 = HEAP16[$133>>1]|0;
   $135 = $134 << 16 >> 16;
   $136 = ($134<<16>>16)==(-1);
   if ($136) {
    HEAP32[$118>>2] = $117;
    $137 = HEAP32[$129>>2]|0;
    $138 = (($137) + ($130))|0;
    $139 = $138;
    $140 = (($139) + ($valueIndex4$06<<4)|0);
    $141 = Math_fround(HEAPF32[$140>>2]);
    $142 = ((($139) + ($valueIndex4$06<<4)|0) + 4|0);
    $143 = Math_fround(HEAPF32[$142>>2]);
    $144 = ((($139) + ($valueIndex4$06<<4)|0) + 8|0);
    $145 = Math_fround(HEAPF32[$144>>2]);
    $146 = ((($139) + ($valueIndex4$06<<4)|0) + 12|0);
    $147 = Math_fround(HEAPF32[$146>>2]);
    $148 = (($117) + ($valueIndex4$06<<4)|0);
    HEAPF32[$148>>2] = $141;
    $149 = ((($117) + ($valueIndex4$06<<4)|0) + 4|0);
    HEAPF32[$149>>2] = $143;
    $150 = ((($117) + ($valueIndex4$06<<4)|0) + 8|0);
    HEAPF32[$150>>2] = $145;
    $151 = ((($117) + ($valueIndex4$06<<4)|0) + 12|0);
    HEAPF32[$151>>2] = $147;
    $152 = (($123) + ($valueIndex4$06)|0);
    HEAP8[$152>>0] = $131;
   } else {
    $153 = (($117) + ($valueIndex4$06<<4)|0);
    $154 = (($0) + ($135<<2)|0);
    $155 = Math_fround(HEAPF32[$154>>2]);
    HEAPF32[$153>>2] = $155;
    $156 = (($135) + 1)|0;
    $157 = (($0) + ($156<<2)|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = (($153) + 4|0);
    HEAPF32[$159>>2] = $158;
    $160 = (($135) + 2)|0;
    $161 = (($0) + ($160<<2)|0);
    $162 = Math_fround(HEAPF32[$161>>2]);
    $163 = (($153) + 8|0);
    HEAPF32[$163>>2] = $162;
    $164 = (($153) + 12|0);
    HEAPF32[$164>>2] = Math_fround(1.0);
    $165 = (($123) + ($valueIndex4$06)|0);
    HEAP8[$165>>0] = 1;
   }
   $166 = (($valueIndex4$06) + 1)|0;
   $167 = ($166>>>0)<($126>>>0);
   if ($167) {
    $valueIndex4$06 = $166;
   } else {
    break;
   }
  }
 }
 $168 = (($values) + 28|0);
 $169 = $168;
 $170 = HEAP32[$168>>2]|0;
 $171 = (($170) + ($169))|0;
 $172 = $171;
 $173 = (($values) + 32|0);
 HEAP32[$173>>2] = $172;
 $174 = (($valueArrayMask) + 28|0);
 $175 = $174;
 $176 = HEAP32[$174>>2]|0;
 $177 = (($176) + ($175))|0;
 $178 = $177;
 $179 = (($valueArrayMask) + 32|0);
 HEAP32[$179>>2] = $178;
 $180 = (($values) + 24|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ($181|0)==(0);
 if (!($182)) {
  $183 = (($bindings) + 12|0);
  $184 = (($valuesFallBack) + 28|0);
  $185 = $184;
  $186 = $usePreviousAsFallback&1;
  $valueIndex7$02 = 0;
  while(1) {
   $187 = HEAP32[$183>>2]|0;
   $188 = (($187) + ($valueIndex7$02<<1)|0);
   $189 = HEAP16[$188>>1]|0;
   $190 = ($189<<16>>16)==(-1);
   if ($190) {
    $191 = HEAP32[$184>>2]|0;
    $192 = (($191) + ($185))|0;
    $193 = $192;
    $194 = (($193) + ($valueIndex7$02<<2)|0);
    $195 = Math_fround(HEAPF32[$194>>2]);
    HEAP32[$173>>2] = $172;
    $196 = (($172) + ($valueIndex7$02<<2)|0);
    HEAPF32[$196>>2] = $195;
    $197 = (($178) + ($valueIndex7$02)|0);
    HEAP8[$197>>0] = $186;
   } else {
    $198 = $189 << 16 >> 16;
    $199 = (($0) + ($198<<2)|0);
    $200 = Math_fround(HEAPF32[$199>>2]);
    $201 = (($172) + ($valueIndex7$02<<2)|0);
    HEAPF32[$201>>2] = $200;
    $202 = (($178) + ($valueIndex7$02)|0);
    HEAP8[$202>>0] = 1;
   }
   $203 = (($valueIndex7$02) + 1)|0;
   $204 = ($203>>>0)<($181>>>0);
   if ($204) {
    $valueIndex7$02 = $203;
   } else {
    break;
   }
  }
 }
 $205 = (($valueArrayMask) + 16|0);
 $206 = $205;
 $207 = HEAP32[$205>>2]|0;
 $208 = (($207) + ($206))|0;
 $209 = $208;
 $210 = (($valueArrayMask) + 20|0);
 HEAP32[$210>>2] = $209;
 $211 = (($values) + 12|0);
 $212 = HEAP32[$211>>2]|0;
 $213 = ($212|0)==(0);
 if ($213) {
  STACKTOP = sp;return;
 }
 $214 = (($bindings) + 16|0);
 $215 = (($valuesFallBack) + 16|0);
 $216 = $215;
 $217 = (($values) + 16|0);
 $218 = $217;
 $219 = (($values) + 20|0);
 $220 = $usePreviousAsFallback&1;
 $221 = (($bindings) + 20|0);
 $valueIndex9$01 = 0;
 while(1) {
  $222 = HEAP32[$214>>2]|0;
  $223 = (($222) + ($valueIndex9$01<<1)|0);
  $224 = HEAP16[$223>>1]|0;
  $225 = ($224<<16>>16)==(-1);
  if ($225) {
   $226 = HEAP32[$215>>2]|0;
   $227 = (($226) + ($216))|0;
   $228 = $227;
   $229 = (($228) + ($valueIndex9$01<<2)|0);
   $230 = HEAP32[$229>>2]|0;
   $231 = HEAP32[$217>>2]|0;
   $232 = (($231) + ($218))|0;
   $233 = $232;
   HEAP32[$219>>2] = $233;
   $234 = (($233) + ($valueIndex9$01<<2)|0);
   HEAP32[$234>>2] = $230;
   $235 = (($209) + ($valueIndex9$01)|0);
   HEAP8[$235>>0] = $220;
  } else {
   $236 = $224 << 16 >> 16;
   $237 = (($0) + ($236<<2)|0);
   $238 = Math_fround(HEAPF32[$237>>2]);
   $239 = (~~(($238))>>>0);
   $240 = HEAP32[$221>>2]|0;
   $241 = Math_imul($239, $integerRemapStride)|0;
   $242 = (($240) + ($241)|0);
   $243 = HEAP32[$242>>2]|0;
   $244 = HEAP32[$217>>2]|0;
   $245 = (($244) + ($218))|0;
   $246 = $245;
   HEAP32[$219>>2] = $246;
   $247 = (($246) + ($valueIndex9$01<<2)|0);
   HEAP32[$247>>2] = $243;
   $248 = (($209) + ($valueIndex9$01)|0);
   HEAP8[$248>>0] = 1;
  }
  $249 = (($valueIndex9$01) + 1)|0;
  $250 = HEAP32[$211>>2]|0;
  $251 = ($249>>>0)<($250>>>0);
  if ($251) {
   $valueIndex9$01 = $249;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation14DeltasFromClipERKNS0_18ClipMuscleConstantERKNS0_12ClipBindingsERKNS_14ValueArrayMaskERNS_10ValueArrayESB_($cst,$bindings,$mask,$starts,$stops) {
 $cst = $cst|0;
 $bindings = $bindings|0;
 $mask = $mask|0;
 $starts = $starts|0;
 $stops = $stops|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = Math_fround(0), $17 = 0;
 var $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0;
 var $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $valueIndex$08 = 0, $valueIndex1$06 = 0, $valueIndex4$03 = 0, $valueIndex7$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($starts) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($mask) + 40|0);
  $4 = $3;
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + ($4))|0;
  $7 = $6;
  $8 = (($cst) + 1624|0);
  $9 = $8;
  $10 = (($starts) + 40|0);
  $11 = $10;
  $12 = (($starts) + 44|0);
  $13 = (($stops) + 40|0);
  $14 = $13;
  $15 = (($stops) + 44|0);
  $valueIndex$08 = 0;
  while(1) {
   $33 = (($7) + ($valueIndex$08)|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ($34<<24>>24)==(0);
   if (!($35)) {
    $36 = HEAP32[$bindings>>2]|0;
    $37 = (($36) + ($valueIndex$08<<1)|0);
    $38 = HEAP16[$37>>1]|0;
    $39 = $38 << 16 >> 16;
    $40 = HEAP32[$8>>2]|0;
    $41 = (($40) + ($9))|0;
    $42 = $41;
    $43 = (($42) + ($39<<3)|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = (($39) + 1)|0;
    $46 = (($42) + ($45<<3)|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = (($39) + 2)|0;
    $49 = (($42) + ($48<<3)|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = ((($42) + ($39<<3)|0) + 4|0);
    $52 = Math_fround(HEAPF32[$51>>2]);
    $53 = ((($42) + ($45<<3)|0) + 4|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = ((($42) + ($48<<3)|0) + 4|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = HEAP32[$10>>2]|0;
    $58 = (($57) + ($11))|0;
    $59 = $58;
    HEAP32[$12>>2] = $59;
    $60 = (($59) + ($valueIndex$08<<4)|0);
    HEAPF32[$60>>2] = $44;
    $61 = ((($59) + ($valueIndex$08<<4)|0) + 4|0);
    HEAPF32[$61>>2] = $47;
    $62 = ((($59) + ($valueIndex$08<<4)|0) + 8|0);
    HEAPF32[$62>>2] = $50;
    $63 = ((($59) + ($valueIndex$08<<4)|0) + 12|0);
    HEAPF32[$63>>2] = Math_fround(0.0);
    $64 = HEAP32[$13>>2]|0;
    $65 = (($64) + ($14))|0;
    $66 = $65;
    HEAP32[$15>>2] = $66;
    $67 = (($66) + ($valueIndex$08<<4)|0);
    HEAPF32[$67>>2] = $52;
    $68 = ((($66) + ($valueIndex$08<<4)|0) + 4|0);
    HEAPF32[$68>>2] = $54;
    $69 = ((($66) + ($valueIndex$08<<4)|0) + 8|0);
    HEAPF32[$69>>2] = $56;
    $70 = ((($66) + ($valueIndex$08<<4)|0) + 12|0);
    HEAPF32[$70>>2] = Math_fround(0.0);
   }
   $71 = (($valueIndex$08) + 1)|0;
   $72 = ($71>>>0)<($1>>>0);
   if ($72) {
    $valueIndex$08 = $71;
   } else {
    break;
   }
  }
 }
 $16 = (($starts) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = (($mask) + 52|0);
  $20 = $19;
  $21 = HEAP32[$19>>2]|0;
  $22 = (($21) + ($20))|0;
  $23 = $22;
  $24 = (($bindings) + 4|0);
  $25 = (($cst) + 1624|0);
  $26 = $25;
  $27 = (($starts) + 52|0);
  $28 = $27;
  $29 = (($starts) + 56|0);
  $30 = (($stops) + 52|0);
  $31 = $30;
  $32 = (($stops) + 56|0);
  $valueIndex1$06 = 0;
  while(1) {
   $90 = (($23) + ($valueIndex1$06)|0);
   $91 = HEAP8[$90>>0]|0;
   $92 = ($91<<24>>24)==(0);
   if (!($92)) {
    $93 = HEAP32[$24>>2]|0;
    $94 = (($93) + ($valueIndex1$06<<1)|0);
    $95 = HEAP16[$94>>1]|0;
    $96 = $95 << 16 >> 16;
    $97 = HEAP32[$25>>2]|0;
    $98 = (($97) + ($26))|0;
    $99 = $98;
    $100 = (($99) + ($96<<3)|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = (($96) + 1)|0;
    $103 = (($99) + ($102<<3)|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = (($96) + 2)|0;
    $106 = (($99) + ($105<<3)|0);
    $107 = Math_fround(HEAPF32[$106>>2]);
    $108 = (($96) + 3)|0;
    $109 = (($99) + ($108<<3)|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $111 = ((($99) + ($96<<3)|0) + 4|0);
    $112 = Math_fround(HEAPF32[$111>>2]);
    $113 = ((($99) + ($102<<3)|0) + 4|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = ((($99) + ($105<<3)|0) + 4|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = ((($99) + ($108<<3)|0) + 4|0);
    $118 = Math_fround(HEAPF32[$117>>2]);
    $119 = HEAP32[$27>>2]|0;
    $120 = (($119) + ($28))|0;
    $121 = $120;
    HEAP32[$29>>2] = $121;
    $122 = (($121) + ($valueIndex1$06<<4)|0);
    HEAPF32[$122>>2] = $101;
    $123 = ((($121) + ($valueIndex1$06<<4)|0) + 4|0);
    HEAPF32[$123>>2] = $104;
    $124 = ((($121) + ($valueIndex1$06<<4)|0) + 8|0);
    HEAPF32[$124>>2] = $107;
    $125 = ((($121) + ($valueIndex1$06<<4)|0) + 12|0);
    HEAPF32[$125>>2] = $110;
    $126 = HEAP32[$30>>2]|0;
    $127 = (($126) + ($31))|0;
    $128 = $127;
    HEAP32[$32>>2] = $128;
    $129 = (($128) + ($valueIndex1$06<<4)|0);
    HEAPF32[$129>>2] = $112;
    $130 = ((($128) + ($valueIndex1$06<<4)|0) + 4|0);
    HEAPF32[$130>>2] = $114;
    $131 = ((($128) + ($valueIndex1$06<<4)|0) + 8|0);
    HEAPF32[$131>>2] = $116;
    $132 = ((($128) + ($valueIndex1$06<<4)|0) + 12|0);
    HEAPF32[$132>>2] = $118;
   }
   $133 = (($valueIndex1$06) + 1)|0;
   $134 = ($133>>>0)<($17>>>0);
   if ($134) {
    $valueIndex1$06 = $133;
   } else {
    break;
   }
  }
 }
 $73 = (($starts) + 60|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if (!($75)) {
  $76 = (($mask) + 64|0);
  $77 = $76;
  $78 = HEAP32[$76>>2]|0;
  $79 = (($78) + ($77))|0;
  $80 = $79;
  $81 = (($bindings) + 8|0);
  $82 = (($cst) + 1624|0);
  $83 = $82;
  $84 = (($starts) + 64|0);
  $85 = $84;
  $86 = (($starts) + 68|0);
  $87 = (($stops) + 64|0);
  $88 = $87;
  $89 = (($stops) + 68|0);
  $valueIndex4$03 = 0;
  while(1) {
   $152 = (($80) + ($valueIndex4$03)|0);
   $153 = HEAP8[$152>>0]|0;
   $154 = ($153<<24>>24)==(0);
   if (!($154)) {
    $155 = HEAP32[$81>>2]|0;
    $156 = (($155) + ($valueIndex4$03<<1)|0);
    $157 = HEAP16[$156>>1]|0;
    $158 = $157 << 16 >> 16;
    $159 = HEAP32[$82>>2]|0;
    $160 = (($159) + ($83))|0;
    $161 = $160;
    $162 = (($161) + ($158<<3)|0);
    $163 = Math_fround(HEAPF32[$162>>2]);
    $164 = (($158) + 1)|0;
    $165 = (($161) + ($164<<3)|0);
    $166 = Math_fround(HEAPF32[$165>>2]);
    $167 = (($158) + 2)|0;
    $168 = (($161) + ($167<<3)|0);
    $169 = Math_fround(HEAPF32[$168>>2]);
    $170 = ((($161) + ($158<<3)|0) + 4|0);
    $171 = Math_fround(HEAPF32[$170>>2]);
    $172 = ((($161) + ($164<<3)|0) + 4|0);
    $173 = Math_fround(HEAPF32[$172>>2]);
    $174 = ((($161) + ($167<<3)|0) + 4|0);
    $175 = Math_fround(HEAPF32[$174>>2]);
    $176 = HEAP32[$84>>2]|0;
    $177 = (($176) + ($85))|0;
    $178 = $177;
    HEAP32[$86>>2] = $178;
    $179 = (($178) + ($valueIndex4$03<<4)|0);
    HEAPF32[$179>>2] = $163;
    $180 = ((($178) + ($valueIndex4$03<<4)|0) + 4|0);
    HEAPF32[$180>>2] = $166;
    $181 = ((($178) + ($valueIndex4$03<<4)|0) + 8|0);
    HEAPF32[$181>>2] = $169;
    $182 = ((($178) + ($valueIndex4$03<<4)|0) + 12|0);
    HEAPF32[$182>>2] = Math_fround(1.0);
    $183 = HEAP32[$87>>2]|0;
    $184 = (($183) + ($88))|0;
    $185 = $184;
    HEAP32[$89>>2] = $185;
    $186 = (($185) + ($valueIndex4$03<<4)|0);
    HEAPF32[$186>>2] = $171;
    $187 = ((($185) + ($valueIndex4$03<<4)|0) + 4|0);
    HEAPF32[$187>>2] = $173;
    $188 = ((($185) + ($valueIndex4$03<<4)|0) + 8|0);
    HEAPF32[$188>>2] = $175;
    $189 = ((($185) + ($valueIndex4$03<<4)|0) + 12|0);
    HEAPF32[$189>>2] = Math_fround(1.0);
   }
   $190 = (($valueIndex4$03) + 1)|0;
   $191 = ($190>>>0)<($74>>>0);
   if ($191) {
    $valueIndex4$03 = $190;
   } else {
    break;
   }
  }
 }
 $135 = (($starts) + 24|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = ($136|0)==(0);
 if ($137) {
  STACKTOP = sp;return;
 }
 $138 = (($mask) + 28|0);
 $139 = $138;
 $140 = HEAP32[$138>>2]|0;
 $141 = (($140) + ($139))|0;
 $142 = $141;
 $143 = (($bindings) + 12|0);
 $144 = (($cst) + 1624|0);
 $145 = $144;
 $146 = (($starts) + 28|0);
 $147 = $146;
 $148 = (($starts) + 32|0);
 $149 = (($stops) + 28|0);
 $150 = $149;
 $151 = (($stops) + 32|0);
 $valueIndex7$01 = 0;
 while(1) {
  $192 = (($142) + ($valueIndex7$01)|0);
  $193 = HEAP8[$192>>0]|0;
  $194 = ($193<<24>>24)==(0);
  if (!($194)) {
   $195 = HEAP32[$143>>2]|0;
   $196 = (($195) + ($valueIndex7$01<<1)|0);
   $197 = HEAP16[$196>>1]|0;
   $198 = $197 << 16 >> 16;
   $199 = HEAP32[$144>>2]|0;
   $200 = (($199) + ($145))|0;
   $201 = $200;
   $202 = (($201) + ($198<<3)|0);
   $203 = Math_fround(HEAPF32[$202>>2]);
   $204 = HEAP32[$146>>2]|0;
   $205 = (($204) + ($147))|0;
   $206 = $205;
   HEAP32[$148>>2] = $206;
   $207 = (($206) + ($valueIndex7$01<<2)|0);
   HEAPF32[$207>>2] = $203;
   $208 = ((($201) + ($198<<3)|0) + 4|0);
   $209 = Math_fround(HEAPF32[$208>>2]);
   $210 = HEAP32[$149>>2]|0;
   $211 = (($210) + ($150))|0;
   $212 = $211;
   HEAP32[$151>>2] = $212;
   $213 = (($212) + ($valueIndex7$01<<2)|0);
   HEAPF32[$213>>2] = $209;
  }
  $214 = (($valueIndex7$01) + 1)|0;
  $215 = ($214>>>0)<($136>>>0);
  if ($215) {
   $valueIndex7$01 = $214;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4mathL11xformInvMulERKNS_5xformES2_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(-1.0));
 $3 = (($a) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(-1.0));
 $6 = (($a) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(-1.0));
 $9 = (($a) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$b>>2]);
 $12 = Math_fround(HEAPF32[$a>>2]);
 $13 = Math_fround($11 - $12);
 $14 = (($b) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = (($b) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($a) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 - $22);
 $24 = (($b) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($a) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 - $27);
 $29 = Math_fround($13 + $13);
 $30 = Math_fround($18 + $18);
 $31 = Math_fround($23 + $23);
 $32 = Math_fround($2 * $30);
 $33 = Math_fround($5 * $31);
 $34 = Math_fround($8 * $29);
 $35 = Math_fround($10 * Math_fround(0.0));
 $36 = Math_fround($5 * $29);
 $37 = Math_fround($8 * $30);
 $38 = Math_fround($2 * $31);
 $39 = Math_fround($32 - $36);
 $40 = Math_fround($33 - $37);
 $41 = Math_fround($34 - $38);
 $42 = Math_fround($35 - $35);
 $43 = Math_fround($10 * $40);
 $44 = Math_fround($10 * $41);
 $45 = Math_fround($10 * $39);
 $46 = Math_fround($10 * $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 + $45);
 $50 = Math_fround($46 + $28);
 $51 = Math_fround($2 * $41);
 $52 = Math_fround($5 * $39);
 $53 = Math_fround($8 * $40);
 $54 = Math_fround($5 * $40);
 $55 = Math_fround($8 * $41);
 $56 = Math_fround($2 * $39);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($52 - $55);
 $59 = Math_fround($53 - $56);
 $60 = Math_fround($46 - $46);
 $61 = Math_fround($47 + $58);
 $62 = Math_fround($48 + $59);
 $63 = Math_fround($49 + $57);
 $64 = Math_fround($60 + $50);
 $65 = (($a) + 32|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($61 / $66);
 $68 = (($a) + 36|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($62 / $69);
 $71 = (($a) + 40|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($63 / $72);
 $74 = (($a) + 44|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($64 / $75);
 $77 = (($b) + 16|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($5 * $78);
 $80 = (($b) + 28|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($10 * $81);
 $83 = (($b) + 20|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($8 * $84);
 $86 = (($b) + 24|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($2 * $87);
 $89 = Math_fround($10 * $87);
 $90 = Math_fround($2 * $78);
 $91 = Math_fround($5 * $87);
 $92 = Math_fround($8 * $78);
 $93 = Math_fround($79 - $89);
 $94 = Math_fround($82 - $90);
 $95 = Math_fround($85 - $91);
 $96 = Math_fround($88 - $92);
 $97 = Math_fround($8 * $81);
 $98 = Math_fround($8 * $87);
 $99 = Math_fround($10 * $78);
 $100 = Math_fround($10 * $84);
 $101 = Math_fround($93 - $97);
 $102 = Math_fround($94 - $98);
 $103 = Math_fround($95 - $99);
 $104 = Math_fround($96 - $100);
 $105 = Math_fround($2 * $84);
 $106 = Math_fround($5 * $84);
 $107 = Math_fround($2 * $81);
 $108 = Math_fround($5 * $81);
 $109 = Math_fround($101 - $105);
 $110 = Math_fround($102 - $106);
 $111 = Math_fround($103 - $107);
 $112 = Math_fround($104 - $108);
 $113 = Math_fround($111 * Math_fround(-1.0));
 $114 = Math_fround($112 * Math_fround(-1.0));
 $115 = Math_fround($109 * Math_fround(-1.0));
 $116 = Math_fround($113 * $113);
 $117 = Math_fround($114 * $114);
 $118 = Math_fround($115 * $115);
 $119 = Math_fround($110 * $110);
 $120 = Math_fround($116 + $117);
 $121 = Math_fround($119 + $118);
 $122 = Math_fround($120 + $121);
 $123 = (Math_fround(Math_sqrt((Math_fround($122)))));
 $124 = Math_fround(Math_fround(1.0) / $123);
 $125 = Math_fround($124 * $113);
 $126 = Math_fround($124 * $114);
 $127 = Math_fround($124 * $115);
 $128 = Math_fround($124 * $110);
 $129 = (($b) + 32|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = Math_fround($130 / $66);
 $132 = (($b) + 36|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($133 / $69);
 $135 = (($b) + 40|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($136 / $72);
 $138 = (($b) + 44|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($139 / $75);
 HEAPF32[$agg$result>>2] = $67;
 $141 = (($agg$result) + 4|0);
 HEAPF32[$141>>2] = $70;
 $142 = (($agg$result) + 8|0);
 HEAPF32[$142>>2] = $73;
 $143 = (($agg$result) + 12|0);
 HEAPF32[$143>>2] = $76;
 $144 = (($agg$result) + 16|0);
 HEAPF32[$144>>2] = $125;
 $145 = (($agg$result) + 20|0);
 HEAPF32[$145>>2] = $126;
 $146 = (($agg$result) + 24|0);
 HEAPF32[$146>>2] = $127;
 $147 = (($agg$result) + 28|0);
 HEAPF32[$147>>2] = $128;
 $148 = (($agg$result) + 32|0);
 HEAPF32[$148>>2] = $131;
 $149 = (($agg$result) + 36|0);
 HEAPF32[$149>>2] = $134;
 $150 = (($agg$result) + 40|0);
 HEAPF32[$150>>2] = $137;
 $151 = (($agg$result) + 44|0);
 HEAPF32[$151>>2] = $140;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18BlendDynamicStatesERKNS_10ValueArrayERKNS_14ValueArrayMaskEPPS1_PfiRS1_S7_PS4_PNS0_12AvatarOutputEb($valuesDefault,$valueMask,$valuesArray,$blendFactor,$clipCount,$valuesOutput,$valuesInterupted,$valuesMaskInterupted,$avatarOutput,$additive) {
 $valuesDefault = $valuesDefault|0;
 $valueMask = $valueMask|0;
 $valuesArray = $valuesArray|0;
 $blendFactor = $blendFactor|0;
 $clipCount = $clipCount|0;
 $valuesOutput = $valuesOutput|0;
 $valuesInterupted = $valuesInterupted|0;
 $valuesMaskInterupted = $valuesMaskInterupted|0;
 $avatarOutput = $avatarOutput|0;
 $additive = $additive|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $fastCopy$0$off0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($clipCount|0)>(0);
 do {
  if ($0) {
   $1 = ($clipCount|0)==(1);
   if ($1) {
    $2 = Math_fround(HEAPF32[$blendFactor>>2]);
    $3 = Math_fround($2 + Math_fround(-1.0));
    $4 = $3 < Math_fround(0.0);
    if ($4) {
     $5 = Math_fround(-$3);
     $7 = $5;
    } else {
     $7 = $3;
    }
    $6 = !($7 <= Math_fround(9.99999997475242707878E-7));
    if (!($6)) {
     $8 = ($avatarOutput|0)==(0|0);
     if (!($8)) {
      $fastCopy$0$off0 = 1;
      break;
     }
     $9 = HEAP32[$valuesArray>>2]|0;
     __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_PKNS_14ValueArrayMaskE($9,$valuesOutput,$valueMask);
     $fastCopy$0$off0 = 0;
     break;
    }
   }
   $10 = HEAP32[$valuesArray>>2]|0;
   $11 = ($avatarOutput|0)==(0|0);
   if ($11) {
    $13 = $10;
   } else {
    $12 = HEAP32[$avatarOutput>>2]|0;
    $13 = $12;
   }
   HEAP32[$valuesArray>>2] = $13;
   $14 = $additive ? 0 : $valuesDefault;
   __ZN7mecanim15ValueArrayBlendEPKNS_10ValueArrayEPS0_PS3_PKfjPKNS_14ValueArrayMaskE($14,$valuesOutput,$valuesArray,$blendFactor,$clipCount,$valueMask);
   HEAP32[$valuesArray>>2] = $10;
   $fastCopy$0$off0 = 0;
  } else {
   $15 = ($clipCount|0)==(0);
   if ($15) {
    __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_PKNS_14ValueArrayMaskE($valuesDefault,$valuesOutput,$valueMask);
    $fastCopy$0$off0 = 0;
   } else {
    $fastCopy$0$off0 = 0;
   }
  }
 } while(0);
 $16 = ($valuesInterupted|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return ($fastCopy$0$off0|0);
 }
 __ZN7mecanim25ValueArrayCopyInverseMaskEPKNS_10ValueArrayEPS0_PKNS_14ValueArrayMaskE($valuesDefault,$valuesInterupted,$valueMask);
 if ($fastCopy$0$off0) {
  $17 = HEAP32[$avatarOutput>>2]|0;
  __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_PKNS_14ValueArrayMaskE($17,$valuesInterupted,$valueMask);
 } else {
  __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_PKNS_14ValueArrayMaskE($valuesOutput,$valuesInterupted,$valueMask);
 }
 __ZN7mecanim12SetValueMaskEPNS_14ValueArrayMaskEb($valuesMaskInterupted,1);
 STACKTOP = sp;return ($fastCopy$0$off0|0);
}
function __ZN7mecanim9animation16EvaluateOneLayerEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEiPNS0_13BlendingStateILb0EEEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPNS0_12AvatarOutputEPNS0_18AnimationSetMemoryERb($controllerBindingConstant,$input,$layerIndex,$output,$memory,$workspace,$avatarOutput,$animationSetMemory,$fastCopy) {
 $controllerBindingConstant = $controllerBindingConstant|0;
 $input = $input|0;
 $layerIndex = $layerIndex|0;
 $output = $output|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $avatarOutput = $avatarOutput|0;
 $animationSetMemory = $animationSetMemory|0;
 $fastCopy = $fastCopy|0;
 var $$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $brmerge = 0, $clipCount = 0, $extract$t = 0, $mask = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $clipCount = sp + 8|0;
 $mask = sp;
 $0 = (($controllerBindingConstant) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($controllerBindingConstant) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  label = 3;
 } else {
  $7 = $4;
  $8 = (($5) + ($7))|0;
  $9 = $8;
  $10 = (($9) + 48|0);
  $11 = $10;
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + ($11))|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0);
  if ($16) {
   label = 3;
  } else {
   $$off0 = 0;$92 = 1;
  }
 }
 if ((label|0) == 3) {
  $17 = (($1) + 68|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(-1);
  if ($19) {
   $20 = (($input) + 22|0);
   $21 = HEAP8[$20>>0]|0;
   $extract$t = ($21<<24>>24)!=(0);
   $$off0 = $extract$t;$92 = 0;
  } else {
   $$off0 = 1;$92 = 0;
  }
 }
 $22 = (($3) + 4|0);
 $23 = $22;
 $24 = HEAP32[$22>>2]|0;
 $25 = (($24) + ($23))|0;
 $26 = $25;
 $27 = (($26) + ($layerIndex<<3)|0);
 $28 = $27;
 $29 = HEAP32[$27>>2]|0;
 $30 = (($28) + ($29))|0;
 $31 = $30;
 $32 = (($31) + 28|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(1);
 $35 = HEAP32[$31>>2]|0;
 $36 = (($31) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $memory;
 $39 = HEAP32[$memory>>2]|0;
 $40 = (($39) + ($38))|0;
 $41 = $40;
 $42 = (($memory) + 4|0);
 HEAP32[$42>>2] = $41;
 $43 = (($41) + 4|0);
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($44) + ($45))|0;
 $47 = $46;
 $48 = (($41) + 8|0);
 HEAP32[$48>>2] = $47;
 $49 = (($47) + ($35<<3)|0);
 $50 = $49;
 $51 = HEAP32[$49>>2]|0;
 $52 = (($50) + ($51))|0;
 $53 = $52;
 $54 = ((($47) + ($35<<3)|0) + 4|0);
 HEAP32[$54>>2] = $53;
 $55 = (($workspace) + 24|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($56) + 4|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($58) + ($35<<2)|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($56) + 16|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($41) + 16|0);
 $64 = $63;
 $65 = HEAP32[$63>>2]|0;
 $66 = (($64) + ($65))|0;
 $67 = $66;
 $68 = (($41) + 20|0);
 HEAP32[$68>>2] = $67;
 $69 = (($67) + (($layerIndex*36)|0)|0);
 HEAP32[$42>>2] = $41;
 $70 = (($41) + 24|0);
 $71 = $70;
 $72 = HEAP32[$70>>2]|0;
 $73 = (($71) + ($72))|0;
 $74 = $73;
 $75 = (($41) + 28|0);
 HEAP32[$75>>2] = $74;
 $76 = (($74) + (($layerIndex*36)|0)|0);
 HEAP32[$clipCount>>2] = 0;
 $77 = HEAP32[$55>>2]|0;
 $78 = (($77) + 76|0);
 $79 = HEAP32[$78>>2]|0;
 __ZN7mecanim12SetValueMaskEPNS_14ValueArrayMaskEb($79,0);
 $80 = (($60) + 56|0);
 $81 = HEAP8[$80>>0]|0;
 $82 = ($81<<24>>24)==(0);
 if (!($82)) {
  $83 = HEAP32[$22>>2]|0;
  $84 = (($83) + ($23))|0;
  $85 = $84;
  $86 = (($85) + ($layerIndex<<3)|0);
  $87 = $86;
  $88 = HEAP32[$86>>2]|0;
  $89 = (($87) + ($88))|0;
  $90 = $89;
  $91 = (($90) + 8|0);
  __ZN7mecanim9animation17BlendingStateCopyERKNS0_13BlendingStateILb0EEERS2_bbRKNS_6bitsetILj59EEE($76,$69,$$off0,$92,$91);
 }
 $93 = (($53) + 72|0);
 $94 = HEAP8[$93>>0]|0;
 $95 = ($94<<24>>24)==(0);
 if ($95) {
  $101 = (($60) + 49|0);
  $102 = HEAP8[$101>>0]|0;
  $103 = ($102<<24>>24)==(0);
  if ($103) {
   label = 11;
  } else {
   $104 = (($60) + 28|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($105) + (($37*24)|0)|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($107|0)==(0);
   if ($108) {
    $116 = Math_fround(1.0);
   } else {
    label = 11;
   }
  }
  if ((label|0) == 11) {
   $109 = Math_fround(HEAPF32[$60>>2]);
   $110 = Math_fround(Math_fround(1.0) - $109);
   $116 = $110;
  }
  $111 = HEAP32[$memory>>2]|0;
  $112 = (($111) + ($38))|0;
  $113 = $112;
  HEAP32[$42>>2] = $113;
  $114 = (($62) + 12|0);
  $115 = HEAP32[$114>>2]|0;
  __ZN7mecanim9animation17EvaluateBlendNodeEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEibbRjPNS0_16ControllerMemoryEPNS0_15AvatarWorkspaceEPNS0_12AvatarOutputEPNS0_18AnimationSetMemoryEPff($controllerBindingConstant,$input,$layerIndex,$34,1,$clipCount,$113,$workspace,$avatarOutput,$animationSetMemory,$115,$116);
 } else {
  $96 = Math_fround(HEAPF32[$60>>2]);
  $97 = Math_fround(Math_fround(1.0) - $96);
  $98 = HEAP32[$memory>>2]|0;
  $99 = (($98) + ($38))|0;
  $100 = $99;
  HEAP32[$42>>2] = $100;
  __ZN7mecanim9animation16RestoreBlendNodeERKNS0_13BlendingStateILb0EEEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEiRjPNS0_16ControllerMemoryEPNS0_15AvatarWorkspaceEPNS0_12AvatarOutputEf($69,$controllerBindingConstant,$input,$layerIndex,$clipCount,0,$workspace,$avatarOutput,$97);
 }
 $117 = (($60) + 25|0);
 $118 = HEAP8[$117>>0]|0;
 $119 = ($118<<24>>24)==(0);
 if ($119) {
  label = 16;
 } else {
  $120 = (($60) + 4|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = (($121) + (($37*24)|0)|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ($123|0)==(0);
  if ($124) {
   $125 = HEAP8[$93>>0]|0;
   $126 = ($125<<24>>24)==(0);
   if ($126) {
    $133 = Math_fround(1.0);
   } else {
    label = 16;
   }
  } else {
   label = 16;
  }
 }
 if ((label|0) == 16) {
  $127 = Math_fround(HEAPF32[$60>>2]);
  $133 = $127;
 }
 $128 = HEAP32[$memory>>2]|0;
 $129 = (($128) + ($38))|0;
 $130 = $129;
 HEAP32[$42>>2] = $130;
 $131 = (($62) + 12|0);
 $132 = HEAP32[$131>>2]|0;
 __ZN7mecanim9animation17EvaluateBlendNodeEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEibbRjPNS0_16ControllerMemoryEPNS0_15AvatarWorkspaceEPNS0_12AvatarOutputEPNS0_18AnimationSetMemoryEPff($controllerBindingConstant,$input,$layerIndex,$34,0,$clipCount,$130,$workspace,$avatarOutput,$animationSetMemory,$132,$133);
 $134 = (($controllerBindingConstant) + 4|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = HEAP32[$55>>2]|0;
 $137 = (($136) + 76|0);
 $138 = HEAP32[$137>>2]|0;
 $139 = HEAP32[$62>>2]|0;
 $140 = HEAP32[$131>>2]|0;
 $141 = HEAP32[$clipCount>>2]|0;
 $142 = $output;
 $143 = HEAP32[$output>>2]|0;
 $144 = (($143) + ($142))|0;
 $145 = $144;
 $146 = (($output) + 4|0);
 HEAP32[$146>>2] = $145;
 $147 = $76;
 $148 = HEAP32[$76>>2]|0;
 $149 = (($148) + ($147))|0;
 $150 = $149;
 $151 = ((($74) + (($layerIndex*36)|0)|0) + 4|0);
 HEAP32[$151>>2] = $150;
 $152 = ((($74) + (($layerIndex*36)|0)|0) + 8|0);
 $153 = $152;
 $154 = HEAP32[$152>>2]|0;
 $155 = (($154) + ($153))|0;
 $156 = $155;
 $157 = ((($74) + (($layerIndex*36)|0)|0) + 12|0);
 HEAP32[$157>>2] = $156;
 $158 = (__ZN7mecanim9animation18BlendDynamicStatesERKNS_10ValueArrayERKNS_14ValueArrayMaskEPPS1_PfiRS1_S7_PS4_PNS0_12AvatarOutputEb($135,$138,$139,$140,$141,$145,$150,$156,$avatarOutput,$34)|0);
 $159 = $158&1;
 HEAP8[$fastCopy>>0] = $159;
 $brmerge = $$off0 | $92;
 if ($brmerge) {
  $160 = HEAP32[$22>>2]|0;
  $161 = (($160) + ($23))|0;
  $162 = $161;
  $163 = (($162) + ($layerIndex<<3)|0);
  $164 = $163;
  $165 = HEAP32[$163>>2]|0;
  $166 = (($164) + ($165))|0;
  $167 = $166;
  $168 = (($167) + 8|0);
  $169 = $168;
  $170 = $169;
  $171 = HEAP32[$170>>2]|0;
  $172 = (($169) + 4)|0;
  $173 = $172;
  $174 = HEAP32[$173>>2]|0;
  $175 = $mask;
  $176 = $175;
  HEAP32[$176>>2] = $171;
  $177 = (($175) + 4)|0;
  $178 = $177;
  HEAP32[$178>>2] = $174;
  $179 = (($62) + 4|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = HEAP32[$131>>2]|0;
  $182 = (($output) + 16|0);
  $183 = $182;
  $184 = HEAP32[$182>>2]|0;
  $185 = (($184) + ($183))|0;
  $186 = $185;
  $187 = (($output) + 20|0);
  HEAP32[$187>>2] = $186;
  $188 = ((($74) + (($layerIndex*36)|0)|0) + 16|0);
  $189 = $188;
  $190 = HEAP32[$188>>2]|0;
  $191 = (($190) + ($189))|0;
  $192 = $191;
  $193 = ((($74) + (($layerIndex*36)|0)|0) + 20|0);
  HEAP32[$193>>2] = $192;
  $194 = ($141|0)>(0);
  do {
   if ($194) {
    $195 = ($141|0)==(1);
    if ($195) {
     $196 = Math_fround(HEAPF32[$181>>2]);
     $197 = Math_fround($196 + Math_fround(-1.0));
     $198 = $197 < Math_fround(0.0);
     if ($198) {
      $199 = Math_fround(-$197);
      $201 = $199;
     } else {
      $201 = $197;
     }
     $200 = !($201 <= Math_fround(9.99999997475242707878E-7));
     if (!($200)) {
      $202 = HEAP32[$180>>2]|0;
      __ZN7mecanim9animation16MotionOutputCopyEPNS0_12MotionOutputEPKS1_bbRKNS_6bitsetILj59EEE($186,$202,$$off0,$92,$mask);
      break;
     }
    }
    __ZN7mecanim9animation17MotionOutputBlendEPNS0_12MotionOutputEPS2_PfjbbRKNS_6bitsetILj59EEE($186,$180,$181,$141,$$off0,$92,$mask);
   }
  } while(0);
  $203 = ($191|0)==(0);
  if (!($203)) {
   __ZN7mecanim9animation16MotionOutputCopyEPNS0_12MotionOutputEPKS1_bbRKNS_6bitsetILj59EEE($192,$186,$$off0,$92,$mask);
  }
 }
 if (!($92)) {
  STACKTOP = sp;return ($141|0);
 }
 $204 = (($62) + 8|0);
 $205 = HEAP32[$204>>2]|0;
 $206 = HEAP32[$131>>2]|0;
 $207 = (($output) + 24|0);
 $208 = $207;
 $209 = HEAP32[$207>>2]|0;
 $210 = (($209) + ($208))|0;
 $211 = $210;
 $212 = (($output) + 28|0);
 HEAP32[$212>>2] = $211;
 $213 = ((($74) + (($layerIndex*36)|0)|0) + 24|0);
 $214 = $213;
 $215 = HEAP32[$213>>2]|0;
 $216 = (($215) + ($214))|0;
 $217 = $216;
 $218 = ((($74) + (($layerIndex*36)|0)|0) + 28|0);
 HEAP32[$218>>2] = $217;
 $219 = ($141|0)>(0);
 do {
  if ($219) {
   $220 = ($141|0)==(1);
   if ($220) {
    $221 = Math_fround(HEAPF32[$206>>2]);
    $222 = Math_fround($221 + Math_fround(-1.0));
    $223 = $222 < Math_fround(0.0);
    if ($223) {
     $224 = Math_fround(-$222);
     $226 = $224;
    } else {
     $226 = $222;
    }
    $225 = !($226 <= Math_fround(9.99999997475242707878E-7));
    if (!($225)) {
     $227 = HEAP32[$205>>2]|0;
     __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($211,$227,0);
     break;
    }
   }
   __ZN7mecanim5human14HumanPoseBlendERNS0_9HumanPoseEPPS1_Pfj($211,$205,$206,$141);
  }
 } while(0);
 $228 = ($216|0)==(0);
 if ($228) {
  STACKTOP = sp;return ($141|0);
 }
 __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($217,$211,0);
 STACKTOP = sp;return ($141|0);
}
function __ZN7mecanim9animation12MotionOutputaSERKS1_($this,$m) {
 $this = $this|0;
 $m = $m|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0;
 var $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = 0;
 var $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0);
 var $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0);
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0);
 var $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0);
 var $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0);
 var $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$m>>2]);
 HEAPF32[$this>>2] = $0;
 $1 = (($m) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($m) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($m) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($m) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 4|0);
 HEAPF32[$9>>2] = $2;
 $10 = (($this) + 8|0);
 HEAPF32[$10>>2] = $4;
 $11 = (($this) + 12|0);
 HEAPF32[$11>>2] = $6;
 $12 = (($this) + 16|0);
 HEAPF32[$12>>2] = $8;
 $13 = (($m) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($m) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($m) + 28|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($m) + 32|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($this) + 20|0);
 HEAPF32[$21>>2] = $14;
 $22 = (($this) + 24|0);
 HEAPF32[$22>>2] = $16;
 $23 = (($this) + 28|0);
 HEAPF32[$23>>2] = $18;
 $24 = (($this) + 32|0);
 HEAPF32[$24>>2] = $20;
 $25 = (($m) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($m) + 40|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($m) + 44|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($m) + 48|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($this) + 36|0);
 HEAPF32[$33>>2] = $26;
 $34 = (($this) + 40|0);
 HEAPF32[$34>>2] = $28;
 $35 = (($this) + 44|0);
 HEAPF32[$35>>2] = $30;
 $36 = (($this) + 48|0);
 HEAPF32[$36>>2] = $32;
 $37 = (($m) + 52|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($m) + 56|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($m) + 60|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($m) + 64|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($this) + 52|0);
 HEAPF32[$45>>2] = $38;
 $46 = (($this) + 56|0);
 HEAPF32[$46>>2] = $40;
 $47 = (($this) + 60|0);
 HEAPF32[$47>>2] = $42;
 $48 = (($this) + 64|0);
 HEAPF32[$48>>2] = $44;
 $49 = (($m) + 68|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($m) + 72|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($m) + 76|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($m) + 80|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($this) + 68|0);
 HEAPF32[$57>>2] = $50;
 $58 = (($this) + 72|0);
 HEAPF32[$58>>2] = $52;
 $59 = (($this) + 76|0);
 HEAPF32[$59>>2] = $54;
 $60 = (($this) + 80|0);
 HEAPF32[$60>>2] = $56;
 $61 = (($m) + 84|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($m) + 88|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($m) + 92|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($m) + 96|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($this) + 84|0);
 HEAPF32[$69>>2] = $62;
 $70 = (($this) + 88|0);
 HEAPF32[$70>>2] = $64;
 $71 = (($this) + 92|0);
 HEAPF32[$71>>2] = $66;
 $72 = (($this) + 96|0);
 HEAPF32[$72>>2] = $68;
 $73 = (($m) + 100|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($m) + 104|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = (($m) + 108|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($m) + 112|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($this) + 100|0);
 HEAPF32[$81>>2] = $74;
 $82 = (($this) + 104|0);
 HEAPF32[$82>>2] = $76;
 $83 = (($this) + 108|0);
 HEAPF32[$83>>2] = $78;
 $84 = (($this) + 112|0);
 HEAPF32[$84>>2] = $80;
 $85 = (($m) + 116|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($m) + 120|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($m) + 124|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($m) + 128|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = (($this) + 116|0);
 HEAPF32[$93>>2] = $86;
 $94 = (($this) + 120|0);
 HEAPF32[$94>>2] = $88;
 $95 = (($this) + 124|0);
 HEAPF32[$95>>2] = $90;
 $96 = (($this) + 128|0);
 HEAPF32[$96>>2] = $92;
 $97 = (($m) + 132|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($m) + 136|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = (($m) + 140|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($m) + 144|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($this) + 132|0);
 HEAPF32[$105>>2] = $98;
 $106 = (($this) + 136|0);
 HEAPF32[$106>>2] = $100;
 $107 = (($this) + 140|0);
 HEAPF32[$107>>2] = $102;
 $108 = (($this) + 144|0);
 HEAPF32[$108>>2] = $104;
 $109 = (($m) + 148|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($m) + 152|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($m) + 156|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($m) + 160|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (($this) + 148|0);
 HEAPF32[$117>>2] = $110;
 $118 = (($this) + 152|0);
 HEAPF32[$118>>2] = $112;
 $119 = (($this) + 156|0);
 HEAPF32[$119>>2] = $114;
 $120 = (($this) + 160|0);
 HEAPF32[$120>>2] = $116;
 $121 = (($m) + 164|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($m) + 168|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($m) + 172|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($m) + 176|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($this) + 164|0);
 HEAPF32[$129>>2] = $122;
 $130 = (($this) + 168|0);
 HEAPF32[$130>>2] = $124;
 $131 = (($this) + 172|0);
 HEAPF32[$131>>2] = $126;
 $132 = (($this) + 176|0);
 HEAPF32[$132>>2] = $128;
 $133 = (($m) + 180|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($m) + 184|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($m) + 188|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($m) + 192|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = (($this) + 180|0);
 HEAPF32[$141>>2] = $134;
 $142 = (($this) + 184|0);
 HEAPF32[$142>>2] = $136;
 $143 = (($this) + 188|0);
 HEAPF32[$143>>2] = $138;
 $144 = (($this) + 192|0);
 HEAPF32[$144>>2] = $140;
 $145 = (($m) + 196|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($m) + 200|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = (($m) + 204|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = (($m) + 208|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($this) + 196|0);
 HEAPF32[$153>>2] = $146;
 $154 = (($this) + 200|0);
 HEAPF32[$154>>2] = $148;
 $155 = (($this) + 204|0);
 HEAPF32[$155>>2] = $150;
 $156 = (($this) + 208|0);
 HEAPF32[$156>>2] = $152;
 $157 = (($m) + 212|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($m) + 216|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($m) + 220|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = (($m) + 224|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = (($this) + 212|0);
 HEAPF32[$165>>2] = $158;
 $166 = (($this) + 216|0);
 HEAPF32[$166>>2] = $160;
 $167 = (($this) + 220|0);
 HEAPF32[$167>>2] = $162;
 $168 = (($this) + 224|0);
 HEAPF32[$168>>2] = $164;
 $169 = (($m) + 228|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = (($m) + 232|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = (($m) + 236|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($m) + 240|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = (($this) + 228|0);
 HEAPF32[$177>>2] = $170;
 $178 = (($this) + 232|0);
 HEAPF32[$178>>2] = $172;
 $179 = (($this) + 236|0);
 HEAPF32[$179>>2] = $174;
 $180 = (($this) + 240|0);
 HEAPF32[$180>>2] = $176;
 $181 = (($m) + 244|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = (($m) + 248|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = (($m) + 252|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($m) + 256|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($this) + 244|0);
 HEAPF32[$189>>2] = $182;
 $190 = (($this) + 248|0);
 HEAPF32[$190>>2] = $184;
 $191 = (($this) + 252|0);
 HEAPF32[$191>>2] = $186;
 $192 = (($this) + 256|0);
 HEAPF32[$192>>2] = $188;
 $193 = (($m) + 260|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($m) + 264|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($m) + 268|0);
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = (($m) + 272|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = (($this) + 260|0);
 HEAPF32[$201>>2] = $194;
 $202 = (($this) + 264|0);
 HEAPF32[$202>>2] = $196;
 $203 = (($this) + 268|0);
 HEAPF32[$203>>2] = $198;
 $204 = (($this) + 272|0);
 HEAPF32[$204>>2] = $200;
 $205 = (($m) + 276|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = (($m) + 280|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($m) + 284|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($m) + 288|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($this) + 276|0);
 HEAPF32[$213>>2] = $206;
 $214 = (($this) + 280|0);
 HEAPF32[$214>>2] = $208;
 $215 = (($this) + 284|0);
 HEAPF32[$215>>2] = $210;
 $216 = (($this) + 288|0);
 HEAPF32[$216>>2] = $212;
 $217 = (($m) + 292|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 $219 = (($m) + 296|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = (($m) + 300|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = (($m) + 304|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = (($this) + 292|0);
 HEAPF32[$225>>2] = $218;
 $226 = (($this) + 296|0);
 HEAPF32[$226>>2] = $220;
 $227 = (($this) + 300|0);
 HEAPF32[$227>>2] = $222;
 $228 = (($this) + 304|0);
 HEAPF32[$228>>2] = $224;
 $229 = (($m) + 308|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = (($m) + 312|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = (($m) + 316|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = (($m) + 320|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = (($this) + 308|0);
 HEAPF32[$237>>2] = $230;
 $238 = (($this) + 312|0);
 HEAPF32[$238>>2] = $232;
 $239 = (($this) + 316|0);
 HEAPF32[$239>>2] = $234;
 $240 = (($this) + 320|0);
 HEAPF32[$240>>2] = $236;
 $241 = (($m) + 324|0);
 $242 = Math_fround(HEAPF32[$241>>2]);
 $243 = (($m) + 328|0);
 $244 = Math_fround(HEAPF32[$243>>2]);
 $245 = (($m) + 332|0);
 $246 = Math_fround(HEAPF32[$245>>2]);
 $247 = (($m) + 336|0);
 $248 = Math_fround(HEAPF32[$247>>2]);
 $249 = (($this) + 324|0);
 HEAPF32[$249>>2] = $242;
 $250 = (($this) + 328|0);
 HEAPF32[$250>>2] = $244;
 $251 = (($this) + 332|0);
 HEAPF32[$251>>2] = $246;
 $252 = (($this) + 336|0);
 HEAPF32[$252>>2] = $248;
 $253 = (($m) + 340|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = (($m) + 344|0);
 $256 = Math_fround(HEAPF32[$255>>2]);
 $257 = (($m) + 348|0);
 $258 = Math_fround(HEAPF32[$257>>2]);
 $259 = (($m) + 352|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = (($this) + 340|0);
 HEAPF32[$261>>2] = $254;
 $262 = (($this) + 344|0);
 HEAPF32[$262>>2] = $256;
 $263 = (($this) + 348|0);
 HEAPF32[$263>>2] = $258;
 $264 = (($this) + 352|0);
 HEAPF32[$264>>2] = $260;
 $265 = (($m) + 356|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = (($m) + 360|0);
 $268 = Math_fround(HEAPF32[$267>>2]);
 $269 = (($m) + 364|0);
 $270 = Math_fround(HEAPF32[$269>>2]);
 $271 = (($m) + 368|0);
 $272 = Math_fround(HEAPF32[$271>>2]);
 $273 = (($this) + 356|0);
 HEAPF32[$273>>2] = $266;
 $274 = (($this) + 360|0);
 HEAPF32[$274>>2] = $268;
 $275 = (($this) + 364|0);
 HEAPF32[$275>>2] = $270;
 $276 = (($this) + 368|0);
 HEAPF32[$276>>2] = $272;
 $277 = (($m) + 372|0);
 $278 = Math_fround(HEAPF32[$277>>2]);
 $279 = (($m) + 376|0);
 $280 = Math_fround(HEAPF32[$279>>2]);
 $281 = (($m) + 380|0);
 $282 = Math_fround(HEAPF32[$281>>2]);
 $283 = (($m) + 384|0);
 $284 = Math_fround(HEAPF32[$283>>2]);
 $285 = (($this) + 372|0);
 HEAPF32[$285>>2] = $278;
 $286 = (($this) + 376|0);
 HEAPF32[$286>>2] = $280;
 $287 = (($this) + 380|0);
 HEAPF32[$287>>2] = $282;
 $288 = (($this) + 384|0);
 HEAPF32[$288>>2] = $284;
 $289 = (($m) + 388|0);
 $290 = Math_fround(HEAPF32[$289>>2]);
 $291 = (($m) + 392|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = (($m) + 396|0);
 $294 = Math_fround(HEAPF32[$293>>2]);
 $295 = (($m) + 400|0);
 $296 = Math_fround(HEAPF32[$295>>2]);
 $297 = (($this) + 388|0);
 HEAPF32[$297>>2] = $290;
 $298 = (($this) + 392|0);
 HEAPF32[$298>>2] = $292;
 $299 = (($this) + 396|0);
 HEAPF32[$299>>2] = $294;
 $300 = (($this) + 400|0);
 HEAPF32[$300>>2] = $296;
 $301 = (($m) + 404|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = (($m) + 408|0);
 $304 = Math_fround(HEAPF32[$303>>2]);
 $305 = (($m) + 412|0);
 $306 = Math_fround(HEAPF32[$305>>2]);
 $307 = (($m) + 416|0);
 $308 = Math_fround(HEAPF32[$307>>2]);
 $309 = (($this) + 404|0);
 HEAPF32[$309>>2] = $302;
 $310 = (($this) + 408|0);
 HEAPF32[$310>>2] = $304;
 $311 = (($this) + 412|0);
 HEAPF32[$311>>2] = $306;
 $312 = (($this) + 416|0);
 HEAPF32[$312>>2] = $308;
 $313 = (($m) + 420|0);
 $314 = Math_fround(HEAPF32[$313>>2]);
 $315 = (($this) + 420|0);
 HEAPF32[$315>>2] = $314;
 $316 = (($m) + 424|0);
 $317 = Math_fround(HEAPF32[$316>>2]);
 $318 = (($m) + 428|0);
 $319 = Math_fround(HEAPF32[$318>>2]);
 $320 = (($m) + 432|0);
 $321 = Math_fround(HEAPF32[$320>>2]);
 $322 = (($m) + 436|0);
 $323 = Math_fround(HEAPF32[$322>>2]);
 $324 = (($this) + 424|0);
 HEAPF32[$324>>2] = $317;
 $325 = (($this) + 428|0);
 HEAPF32[$325>>2] = $319;
 $326 = (($this) + 432|0);
 HEAPF32[$326>>2] = $321;
 $327 = (($this) + 436|0);
 HEAPF32[$327>>2] = $323;
 $328 = (($m) + 440|0);
 $329 = Math_fround(HEAPF32[$328>>2]);
 $330 = (($m) + 444|0);
 $331 = Math_fround(HEAPF32[$330>>2]);
 $332 = (($m) + 448|0);
 $333 = Math_fround(HEAPF32[$332>>2]);
 $334 = (($m) + 452|0);
 $335 = Math_fround(HEAPF32[$334>>2]);
 $336 = (($this) + 440|0);
 HEAPF32[$336>>2] = $329;
 $337 = (($this) + 444|0);
 HEAPF32[$337>>2] = $331;
 $338 = (($this) + 448|0);
 HEAPF32[$338>>2] = $333;
 $339 = (($this) + 452|0);
 HEAPF32[$339>>2] = $335;
 $340 = (($m) + 456|0);
 $341 = Math_fround(HEAPF32[$340>>2]);
 $342 = (($this) + 456|0);
 HEAPF32[$342>>2] = $341;
 STACKTOP = sp;return ($this|0);
}
function __ZN7mecanim9animation13AddHumanLayerERKNS_5human5HumanERKNS1_9HumanPoseERKNS_6bitsetILj59EEEifbRS5_SC_($human,$poseIn,$poseMask,$index,$weight,$additive,$pose,$poseBase) {
 $human = $human|0;
 $poseIn = $poseIn|0;
 $poseMask = $poseMask|0;
 $index = $index|0;
 $weight = Math_fround($weight);
 $additive = $additive|0;
 $pose = $pose|0;
 $poseBase = $poseBase|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mask = 0, $mask1 = 0, $storemerge10 = 0, $storemerge8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $mask = sp + 8|0;
 $mask1 = sp;
 $0 = ($index|0)==(0);
 if ($0) {
  __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_RKNS_6bitsetILj59EEE($poseBase,$poseIn,$poseMask);
  __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_RKNS_6bitsetILj59EEE($pose,$poseIn,$poseMask);
  STACKTOP = sp;return;
 }
 $1 = $weight > Math_fround(0.0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = $poseMask;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 if ($additive) {
  $8 = $mask;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  $12 = (($mask) + 4|0);
  $13 = $7 & 33554432;
  $14 = ($13|0)==(0);
  if ($14) {
   label = 8;
  } else {
   $15 = (($human) + 424|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    label = 8;
   } else {
    $18 = $7 | 33554432;
    $20 = $18;
   }
  }
  if ((label|0) == 8) {
   $19 = $7 & -33554433;
   $20 = $19;
  }
  HEAP32[$12>>2] = $20;
  $21 = $20 & 67108864;
  $22 = ($21|0)==(0);
  if ($22) {
   label = 12;
  } else {
   $23 = (($human) + 425|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if ($25) {
    label = 12;
   } else {
    $26 = $20 | 67108864;
    $storemerge10 = $26;
   }
  }
  if ((label|0) == 12) {
   $27 = $20 & -67108865;
   $storemerge10 = $27;
  }
  HEAP32[$12>>2] = $storemerge10;
  __ZN7mecanim5human25HumanPoseAddAdditiveLayerERNS0_9HumanPoseERKS1_fRKNS_6bitsetILj59EEE($pose,$poseIn,$weight,$mask);
  $28 = HEAP32[$mask>>2]|0;
  $29 = $28 & 1;
  $30 = ($29|0)==(0);
  if ($30) {
   STACKTOP = sp;return;
  }
  __ZN7mecanim5human25HumanPoseAddAdditiveLayerERNS0_9HumanPoseERKS1_fRKNS_6bitsetILj59EEE($poseBase,$poseIn,$weight,$mask);
  STACKTOP = sp;return;
 } else {
  $31 = $mask1;
  $32 = $31;
  HEAP32[$32>>2] = $4;
  $33 = (($31) + 4)|0;
  $34 = $33;
  HEAP32[$34>>2] = $7;
  $35 = (($mask1) + 4|0);
  $36 = $7 & 33554432;
  $37 = ($36|0)==(0);
  if ($37) {
   label = 18;
  } else {
   $38 = (($human) + 424|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    label = 18;
   } else {
    $41 = $7 | 33554432;
    $43 = $41;
   }
  }
  if ((label|0) == 18) {
   $42 = $7 & -33554433;
   $43 = $42;
  }
  HEAP32[$35>>2] = $43;
  $44 = $43 & 67108864;
  $45 = ($44|0)==(0);
  if ($45) {
   label = 22;
  } else {
   $46 = (($human) + 425|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = ($47<<24>>24)==(0);
   if ($48) {
    label = 22;
   } else {
    $49 = $43 | 67108864;
    $storemerge8 = $49;
   }
  }
  if ((label|0) == 22) {
   $50 = $43 & -67108865;
   $storemerge8 = $50;
  }
  HEAP32[$35>>2] = $storemerge8;
  __ZN7mecanim5human25HumanPoseAddOverrideLayerERNS0_9HumanPoseERKS1_fRKNS_6bitsetILj59EEE($pose,$poseIn,$weight,$mask1);
  $51 = HEAP32[$mask1>>2]|0;
  $52 = $51 & 1;
  $53 = ($52|0)==(0);
  if ($53) {
   STACKTOP = sp;return;
  }
  __ZN7mecanim5human25HumanPoseAddOverrideLayerERNS0_9HumanPoseERKS1_fRKNS_6bitsetILj59EEE($poseBase,$poseIn,$weight,$mask1);
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation20EvaluateAvatarLayersEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPNS0_18AnimationSetMemoryE($controllerBindingConstant,$input,$output,$memory,$workspace,$animationSetMemory) {
 $controllerBindingConstant = $controllerBindingConstant|0;
 $input = $input|0;
 $output = $output|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $animationSetMemory = $animationSetMemory|0;
 var $$not$i = 0, $$pre = 0, $$pre$phi27Z2D = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre$phiZ2D = 0, $$pre31 = 0, $$pre33 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0);
 var $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0);
 var $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0);
 var $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0);
 var $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0);
 var $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0);
 var $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = 0, $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0);
 var $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0);
 var $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = Math_fround(0), $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0);
 var $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = 0, $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0), $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = Math_fround(0);
 var $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = 0, $481 = Math_fround(0), $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0);
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = Math_fround(0), $496 = 0, $497 = Math_fround(0), $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0);
 var $503 = 0, $504 = Math_fround(0), $505 = 0, $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0), $509 = 0, $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = Math_fround(0), $513 = 0, $514 = Math_fround(0), $515 = 0, $516 = Math_fround(0), $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = Math_fround(0);
 var $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge$i = 0, $dx = 0, $fastCopy = 0, $layerIter$023 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $fastCopy = sp + 96|0;
 $dx = sp;
 $0 = sp + 48|0;
 $1 = (($controllerBindingConstant) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($controllerBindingConstant) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($controllerBindingConstant) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($2) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  label = 3;
 } else {
  $10 = $7;
  $11 = (($8) + ($10))|0;
  $12 = $11;
  $13 = (($12) + 48|0);
  $14 = $13;
  $15 = HEAP32[$13>>2]|0;
  $16 = (($15) + ($14))|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  if ($19) {
   label = 3;
  } else {
   $32 = 0;$33 = 1;
  }
 }
 if ((label|0) == 3) {
  $20 = (($2) + 68|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(-1);
  if ($22) {
   $23 = (($input) + 22|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)!=(0);
   $32 = $25;$33 = 0;
  } else {
   $32 = 1;$33 = 0;
  }
 }
 $26 = (($workspace) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 80|0);
 $29 = HEAP32[$28>>2]|0;
 __ZN7mecanim12SetValueMaskEPNS_14ValueArrayMaskEb($29,1);
 $30 = HEAP32[$26>>2]|0;
 $31 = (($30) + 56|0);
 HEAP32[$31>>2] = 0;
 $brmerge = $32 | $33;
 if ($brmerge) {
  $34 = (($output) + 8|0);
  $35 = HEAP32[$34>>2]|0;
  __ZN7mecanim9animation17MotionOutputClearEPNS0_12MotionOutputE($35);
 }
 if ($33) {
  $36 = (($workspace) + 76|0);
  ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;
 }
 $37 = ($4|0)==(0|0);
 if (!($37)) {
  $38 = $memory;
  $39 = HEAP32[$memory>>2]|0;
  $40 = (($39) + ($38))|0;
  $41 = $40;
  $42 = (($memory) + 4|0);
  HEAP32[$42>>2] = $41;
  $43 = (($41) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==(0);
  if (!($45)) {
   $46 = HEAP32[$4>>2]|0;
   $47 = ($46|0)==(0);
   if ($47) {
    $$pre = (($controllerBindingConstant) + 4|0);
    $$pre$phi27Z2D = $output;$$pre$phiZ2D = $$pre;
   } else {
    $48 = (($4) + 4|0);
    $49 = $48;
    $50 = (($6) + 28|0);
    $51 = (($controllerBindingConstant) + 4|0);
    $52 = (($output) + 8|0);
    $53 = (($controllerBindingConstant) + 12|0);
    $54 = (($output) + 16|0);
    $55 = (($output) + 12|0);
    $56 = $7;
    $57 = (($2) + 40|0);
    $layerIter$023 = 0;
    while(1) {
     $58 = HEAP32[$26>>2]|0;
     $59 = (($58) + 20|0);
     $60 = HEAP32[$48>>2]|0;
     $61 = (($60) + ($49))|0;
     $62 = $61;
     $63 = (($62) + ($layerIter$023<<3)|0);
     $64 = $63;
     $65 = HEAP32[$63>>2]|0;
     $66 = (($64) + ($65))|0;
     $67 = $66;
     $68 = HEAP32[$67>>2]|0;
     $69 = ($68|0)==(-1);
     do {
      if (!($69)) {
       $70 = ($layerIter$023|0)==(0);
       if ($70) {
        $138 = Math_fround(1.0);
       } else {
        $71 = (($67) + 4|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = HEAP32[$memory>>2]|0;
        $74 = (($73) + ($38))|0;
        $75 = $74;
        $76 = (($75) + 32|0);
        $77 = $76;
        $78 = HEAP32[$76>>2]|0;
        $79 = (($77) + ($78))|0;
        $80 = $79;
        $81 = (($75) + 36|0);
        HEAP32[$81>>2] = $80;
        $82 = (($80) + ($layerIter$023<<2)|0);
        $83 = Math_fround(HEAPF32[$82>>2]);
        HEAP32[$42>>2] = $75;
        $84 = (($75) + 4|0);
        $85 = $84;
        $86 = HEAP32[$84>>2]|0;
        $87 = (($85) + ($86))|0;
        $88 = $87;
        $89 = (($75) + 8|0);
        HEAP32[$89>>2] = $88;
        $90 = (($88) + ($68<<3)|0);
        $91 = $90;
        $92 = HEAP32[$90>>2]|0;
        $93 = (($91) + ($92))|0;
        $94 = $93;
        $95 = ((($88) + ($68<<3)|0) + 4|0);
        HEAP32[$95>>2] = $94;
        $96 = (($94) + 4|0);
        $97 = $96;
        $98 = HEAP32[$96>>2]|0;
        $99 = (($97) + ($98))|0;
        $100 = $99;
        $101 = (($94) + 8|0);
        HEAP32[$101>>2] = $100;
        $102 = (($100) + ($72<<2)|0);
        $103 = Math_fround(HEAPF32[$102>>2]);
        $104 = Math_fround($83 * $103);
        $138 = $104;
       }
       $105 = (($67) + 28|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ($106|0)==(1);
       HEAP8[$fastCopy>>0] = 0;
       $108 = $70 ? $output : 0;
       $109 = (__ZN7mecanim9animation16EvaluateOneLayerEPKNS0_25ControllerBindingConstantEPKNS0_11AvatarInputEiPNS0_13BlendingStateILb0EEEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPNS0_12AvatarOutputEPNS0_18AnimationSetMemoryERb($controllerBindingConstant,$input,$layerIter$023,$59,$memory,$workspace,$108,$animationSetMemory,$fastCopy)|0);
       $110 = HEAP32[$26>>2]|0;
       $111 = (($110) + 76|0);
       $112 = HEAP32[$111>>2]|0;
       $113 = HEAP32[$50>>2]|0;
       $114 = (($113) + ($layerIter$023<<2)|0);
       $115 = HEAP32[$114>>2]|0;
       __ZN7mecanim12AndValueMaskEPNS_14ValueArrayMaskEPKS0_($112,$115);
       $116 = HEAP8[$fastCopy>>0]|0;
       $117 = ($116<<24>>24)==(0);
       if ($117) {
        $126 = HEAP32[$51>>2]|0;
        $127 = $59;
        $128 = HEAP32[$59>>2]|0;
        $129 = (($128) + ($127))|0;
        $130 = $129;
        $131 = (($58) + 24|0);
        HEAP32[$131>>2] = $130;
        $132 = HEAP32[$26>>2]|0;
        $133 = (($132) + 76|0);
        $134 = HEAP32[$133>>2]|0;
        $135 = HEAP32[$output>>2]|0;
        $136 = (($132) + 80|0);
        $137 = HEAP32[$136>>2]|0;
        __ZN7mecanim13ValueArrayAddEPKNS_10ValueArrayES2_PKNS_14ValueArrayMaskEfbPS0_PS3_($126,$130,$134,$138,$107,$135,$137);
       } else {
        $118 = HEAP32[$26>>2]|0;
        $119 = (($118) + 80|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = (($118) + 76|0);
        $122 = HEAP32[$121>>2]|0;
        __ZN7mecanim13CopyValueMaskEPNS_14ValueArrayMaskEPKS0_($120,$122);
        $123 = HEAP32[$26>>2]|0;
        $124 = (($123) + 80|0);
        $125 = HEAP32[$124>>2]|0;
        __ZN7mecanim15InvertValueMaskEPNS_14ValueArrayMaskE($125);
       }
       do {
        if ($brmerge) {
         $139 = $109 | $layerIter$023;
         $140 = ($139|0)==(0);
         if ($140) {
          $141 = HEAP32[$52>>2]|0;
          __ZN7mecanim9animation17MotionOutputClearEPNS0_12MotionOutputE($141);
          break;
         }
         if ($32) {
          $142 = HEAP32[$53>>2]|0;
          $143 = (($142) + ($layerIter$023)|0);
          $144 = HEAP8[$143>>0]|0;
          $145 = ($144<<24>>24)!=(0);
          $162 = $145;
         } else {
          $162 = 0;
         }
         $146 = (($58) + 36|0);
         $147 = $146;
         $148 = HEAP32[$146>>2]|0;
         $149 = (($148) + ($147))|0;
         $150 = $149;
         $151 = (($58) + 40|0);
         HEAP32[$151>>2] = $150;
         $152 = HEAP32[$52>>2]|0;
         $153 = HEAP32[$48>>2]|0;
         $154 = (($153) + ($49))|0;
         $155 = $154;
         $156 = (($155) + ($layerIter$023<<3)|0);
         $157 = $156;
         $158 = HEAP32[$156>>2]|0;
         $159 = (($157) + ($158))|0;
         $160 = $159;
         $161 = (($160) + 8|0);
         if ($70) {
          (__ZN7mecanim9animation12MotionOutputaSERKS1_($152,$150)|0);
          break;
         }
         $$not$i = !($138 > Math_fround(0.0));
         $brmerge$i = $$not$i | $107;
         if (!($brmerge$i)) {
          __ZN7mecanim9animation22MotionAddOverrideLayerEPNS0_12MotionOutputEPKS1_fbbRKNS_6bitsetILj59EEE($152,$150,$138,$162,$33,$161);
         }
        }
       } while(0);
       if ($33) {
        $163 = $109 | $layerIter$023;
        $164 = ($163|0)==(0);
        if ($164) {
         $165 = HEAP32[$54>>2]|0;
         __ZN7mecanim5human14HumanPoseClearERNS0_9HumanPoseE($165);
         $166 = HEAP32[$55>>2]|0;
         __ZN7mecanim5human14HumanPoseClearERNS0_9HumanPoseE($166);
         break;
        } else {
         $167 = HEAP32[$7>>2]|0;
         $168 = (($167) + ($56))|0;
         $169 = $168;
         HEAP32[$57>>2] = $169;
         $170 = (($58) + 44|0);
         $171 = $170;
         $172 = HEAP32[$170>>2]|0;
         $173 = (($172) + ($171))|0;
         $174 = $173;
         $175 = (($58) + 48|0);
         HEAP32[$175>>2] = $174;
         $176 = HEAP32[$48>>2]|0;
         $177 = (($176) + ($49))|0;
         $178 = $177;
         $179 = (($178) + ($layerIter$023<<3)|0);
         $180 = $179;
         $181 = HEAP32[$179>>2]|0;
         $182 = (($180) + ($181))|0;
         $183 = $182;
         $184 = (($183) + 8|0);
         $185 = HEAP32[$54>>2]|0;
         $186 = HEAP32[$55>>2]|0;
         __ZN7mecanim9animation13AddHumanLayerERKNS_5human5HumanERKNS1_9HumanPoseERKNS_6bitsetILj59EEEifbRS5_SC_($169,$174,$184,$layerIter$023,$138,$107,$185,$186);
         break;
        }
       }
      }
     } while(0);
     $187 = (($layerIter$023) + 1)|0;
     $188 = HEAP32[$4>>2]|0;
     $189 = ($187>>>0)<($188>>>0);
     if ($189) {
      $layerIter$023 = $187;
     } else {
      $$pre$phi27Z2D = $output;$$pre$phiZ2D = $51;
      break;
     }
    }
   }
   $190 = HEAP32[$$pre$phiZ2D>>2]|0;
   $191 = HEAP32[$$pre$phi27Z2D>>2]|0;
   $192 = HEAP32[$26>>2]|0;
   $193 = (($192) + 80|0);
   $194 = HEAP32[$193>>2]|0;
   __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_PKNS_14ValueArrayMaskE($190,$191,$194);
   $195 = HEAP32[$controllerBindingConstant>>2]|0;
   $196 = HEAP32[$$pre$phi27Z2D>>2]|0;
   $197 = (($4) + 24|0);
   $198 = $197;
   $199 = HEAP32[$197>>2]|0;
   $200 = (($199) + ($198))|0;
   $201 = $200;
   $202 = (($4) + 28|0);
   HEAP32[$202>>2] = $201;
   $203 = HEAP32[$memory>>2]|0;
   $204 = (($203) + ($38))|0;
   $205 = $204;
   HEAP32[$42>>2] = $205;
   $206 = (($205) + 40|0);
   $207 = $206;
   $208 = HEAP32[$206>>2]|0;
   $209 = (($207) + ($208))|0;
   $210 = $209;
   $211 = (($205) + 44|0);
   HEAP32[$211>>2] = $210;
   $212 = (($6) + 20|0);
   $213 = HEAP32[$212>>2]|0;
   __ZN7mecanim14ValueArrayCopyEPKNS_18ValueArrayConstantEPKNS_10ValueArrayES2_PS3_PKi($195,$196,$201,$210,$213);
  }
 }
 do {
  if ($brmerge) {
   $214 = (($input) + 4|0);
   $215 = Math_fround(HEAPF32[$214>>2]);
   $216 = (($output) + 8|0);
   $217 = HEAP32[$216>>2]|0;
   HEAPF32[$217>>2] = $215;
   $218 = (($input) + 23|0);
   $219 = HEAP8[$218>>0]|0;
   $220 = ($219<<24>>24)==(0);
   if ($220) {
    $221 = $215 != Math_fround(0.0);
    $222 = (($217) + 4|0);
    if ($221) {
     $223 = Math_fround(HEAPF32[$222>>2]);
     $224 = Math_fround($223 / $215);
     $225 = (($217) + 8|0);
     $226 = Math_fround(HEAPF32[$225>>2]);
     $227 = Math_fround($226 / $215);
     $228 = (($217) + 12|0);
     $229 = Math_fround(HEAPF32[$228>>2]);
     $230 = Math_fround($229 / $215);
     $231 = (($217) + 16|0);
     $232 = Math_fround(HEAPF32[$231>>2]);
     $233 = Math_fround($232 / $215);
     HEAPF32[$222>>2] = $224;
     HEAPF32[$225>>2] = $227;
     HEAPF32[$228>>2] = $230;
     HEAPF32[$231>>2] = $233;
     $234 = (($217) + 20|0);
     $235 = Math_fround(HEAPF32[$234>>2]);
     $236 = Math_fround($235 / $215);
     $237 = (($217) + 24|0);
     $238 = Math_fround(HEAPF32[$237>>2]);
     $239 = Math_fround($238 / $215);
     $240 = (($217) + 28|0);
     $241 = Math_fround(HEAPF32[$240>>2]);
     $242 = Math_fround($241 / $215);
     $243 = (($217) + 32|0);
     $244 = Math_fround(HEAPF32[$243>>2]);
     $245 = Math_fround($244 / $215);
     HEAPF32[$234>>2] = $236;
     HEAPF32[$237>>2] = $239;
     HEAPF32[$240>>2] = $242;
     HEAPF32[$243>>2] = $245;
     break;
    } else {
     ;HEAP32[$222+0>>2]=0|0;HEAP32[$222+4>>2]=0|0;HEAP32[$222+8>>2]=0|0;HEAP32[$222+12>>2]=0|0;HEAP32[$222+16>>2]=0|0;HEAP32[$222+20>>2]=0|0;HEAP32[$222+24>>2]=0|0;HEAP32[$222+28>>2]=0|0;
     break;
    }
   }
  }
 } while(0);
 if (!($33)) {
  STACKTOP = sp;return;
 }
 $246 = (($output) + 8|0);
 $247 = HEAP32[$246>>2]|0;
 __ZN7mecanim9animation29MotionOutputGetDeltaTransformEPKNS0_12MotionOutputE($dx,$247);
 $248 = (($memory) + 172|0);
 $249 = HEAP8[$248>>0]|0;
 $250 = ($249<<24>>24)==(0);
 $251 = (($memory) + 168|0);
 if ($250) {
  $252 = Math_fround(HEAPF32[$251>>2]);
  $253 = HEAP32[$246>>2]|0;
  $254 = (($253) + 324|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = (($253) + 276|0);
  $257 = Math_fround(HEAPF32[$256>>2]);
  $258 = Math_fround($255 - $257);
  $259 = (($253) + 332|0);
  $260 = Math_fround(HEAPF32[$259>>2]);
  $261 = (($253) + 284|0);
  $262 = Math_fround(HEAPF32[$261>>2]);
  $263 = Math_fround($260 - $262);
  $264 = (($253) + 336|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = (($253) + 288|0);
  $267 = Math_fround(HEAPF32[$266>>2]);
  $268 = Math_fround($265 - $267);
  $269 = Math_fround($252 * $258);
  $270 = Math_fround($252 * $263);
  $271 = Math_fround($252 * $268);
  $272 = Math_fround($257 + $269);
  $273 = Math_fround($262 + $270);
  $274 = Math_fround($267 + $271);
  $275 = (($253) + 456|0);
  $276 = Math_fround(HEAPF32[$275>>2]);
  $277 = (($253) + 424|0);
  $278 = Math_fround(HEAPF32[$277>>2]);
  $279 = Math_fround($278 - $272);
  $280 = (($253) + 432|0);
  $281 = Math_fround(HEAPF32[$280>>2]);
  $282 = Math_fround($281 - $273);
  $283 = (($253) + 436|0);
  $284 = Math_fround(HEAPF32[$283>>2]);
  $285 = Math_fround($284 - $274);
  $286 = Math_fround($276 * $279);
  $287 = Math_fround($276 * $282);
  $288 = Math_fround($276 * $285);
  $289 = Math_fround($272 + $286);
  $290 = Math_fround($273 + $287);
  $291 = Math_fround($274 + $288);
  $292 = (($memory) + 152|0);
  $293 = Math_fround(HEAPF32[$292>>2]);
  $294 = Math_fround($293 - $289);
  $295 = (($memory) + 160|0);
  $296 = Math_fround(HEAPF32[$295>>2]);
  $297 = Math_fround($296 - $290);
  $298 = (($memory) + 164|0);
  $299 = Math_fround(HEAPF32[$298>>2]);
  $300 = Math_fround($299 - $291);
  $301 = (($input) + 16|0);
  $302 = Math_fround(HEAPF32[$301>>2]);
  $303 = Math_fround($294 * $302);
  $304 = Math_fround($297 * $302);
  $305 = Math_fround($300 * $302);
  $306 = (($dx) + 32|0);
  $307 = Math_fround(HEAPF32[$306>>2]);
  $308 = Math_fround($303 * $307);
  $309 = (($dx) + 36|0);
  $310 = Math_fround(HEAPF32[$309>>2]);
  $311 = Math_fround($310 * Math_fround(0.0));
  $312 = (($dx) + 40|0);
  $313 = Math_fround(HEAPF32[$312>>2]);
  $314 = Math_fround($304 * $313);
  $315 = (($dx) + 44|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = Math_fround($305 * $316);
  $318 = Math_fround($308 + $308);
  $319 = Math_fround($311 + $311);
  $320 = Math_fround($314 + $314);
  $321 = (($dx) + 16|0);
  $322 = Math_fround(HEAPF32[$321>>2]);
  $323 = Math_fround($319 * $322);
  $324 = (($dx) + 20|0);
  $325 = Math_fround(HEAPF32[$324>>2]);
  $326 = Math_fround($320 * $325);
  $327 = (($dx) + 24|0);
  $328 = Math_fround(HEAPF32[$327>>2]);
  $329 = Math_fround($318 * $328);
  $330 = (($dx) + 28|0);
  $331 = Math_fround(HEAPF32[$330>>2]);
  $332 = Math_fround($331 * Math_fround(0.0));
  $333 = Math_fround($318 * $325);
  $334 = Math_fround($319 * $328);
  $335 = Math_fround($320 * $322);
  $336 = Math_fround($323 - $333);
  $337 = Math_fround($326 - $334);
  $338 = Math_fround($329 - $335);
  $339 = Math_fround($332 - $332);
  $340 = Math_fround($331 * $337);
  $341 = Math_fround($331 * $338);
  $342 = Math_fround($336 * $331);
  $343 = Math_fround($331 * $339);
  $344 = Math_fround($308 + $340);
  $345 = Math_fround($311 + $341);
  $346 = Math_fround($314 + $342);
  $347 = Math_fround($317 + $343);
  $348 = Math_fround($322 * $338);
  $349 = Math_fround($325 * $336);
  $350 = Math_fround($328 * $337);
  $351 = Math_fround($325 * $337);
  $352 = Math_fround($328 * $338);
  $353 = Math_fround($322 * $336);
  $354 = Math_fround($348 - $351);
  $355 = Math_fround($349 - $352);
  $356 = Math_fround($350 - $353);
  $357 = Math_fround($343 - $343);
  $358 = Math_fround($344 + $355);
  $359 = Math_fround($345 + $356);
  $360 = Math_fround($346 + $354);
  $361 = Math_fround($347 + $357);
  $362 = Math_fround(HEAPF32[$dx>>2]);
  $363 = Math_fround($362 + $358);
  $364 = (($dx) + 4|0);
  $365 = Math_fround(HEAPF32[$364>>2]);
  $366 = Math_fround($365 + $359);
  $367 = (($dx) + 8|0);
  $368 = Math_fround(HEAPF32[$367>>2]);
  $369 = Math_fround($368 + $360);
  $370 = (($dx) + 12|0);
  $371 = Math_fround(HEAPF32[$370>>2]);
  $372 = Math_fround($371 + $361);
  HEAPF32[$dx>>2] = $363;
  HEAPF32[$364>>2] = $366;
  HEAPF32[$367>>2] = $369;
  HEAPF32[$370>>2] = $372;
  $373 = HEAP32[$246>>2]|0;
  __ZN7mecanim9animation28MotionOutputSetDeltaPositionEPNS0_12MotionOutputERKN4math7_float4E($373,$dx);
  $$pre$phi32Z2D = $292;$$pre$phi34Z2D = $295;$$pre$phi36Z2D = $298;
 } else {
  $$pre31 = (($memory) + 152|0);
  $$pre33 = (($memory) + 160|0);
  $$pre35 = (($memory) + 164|0);
  $$pre$phi32Z2D = $$pre31;$$pre$phi34Z2D = $$pre33;$$pre$phi36Z2D = $$pre35;
 }
 $374 = (($workspace) + 76|0);
 $375 = Math_fround(HEAPF32[$374>>2]);
 $376 = Math_fround($375 * Math_fround(2.0));
 $377 = Math_fround($376 + Math_fround(0.5));
 $378 = Math_fround($377 * Math_fround(0.5));
 $379 = Math_fround($375 + Math_fround(0.5));
 $380 = (($workspace) + 84|0);
 $381 = Math_fround(HEAPF32[$380>>2]);
 $382 = Math_fround($379 + $381);
 $383 = Math_fround($378 / $382);
 $384 = (Math_fround(+(_fmaxf(0.0,(+$383)))));
 $385 = (Math_fround(+(_fminf(1.0,(+$384)))));
 HEAPF32[$251>>2] = $385;
 $386 = (($output) + 16|0);
 $387 = HEAP32[$386>>2]|0;
 $388 = (($387) + 80|0);
 $389 = Math_fround(HEAPF32[$388>>2]);
 $390 = (($387) + 84|0);
 $391 = Math_fround(HEAPF32[$390>>2]);
 $392 = (($387) + 88|0);
 $393 = Math_fround(HEAPF32[$392>>2]);
 $394 = (($387) + 92|0);
 $395 = Math_fround(HEAPF32[$394>>2]);
 $396 = (($387) + 156|0);
 $397 = Math_fround(HEAPF32[$396>>2]);
 $398 = (($387) + 160|0);
 $399 = Math_fround(HEAPF32[$398>>2]);
 $400 = (($387) + 164|0);
 $401 = Math_fround(HEAPF32[$400>>2]);
 $402 = (($387) + 168|0);
 $403 = Math_fround(HEAPF32[$402>>2]);
 $404 = Math_fround($397 - $389);
 $405 = Math_fround($399 - $391);
 $406 = Math_fround($401 - $393);
 $407 = Math_fround($403 - $395);
 $408 = Math_fround($385 * $404);
 $409 = Math_fround($385 * $405);
 $410 = Math_fround($385 * $406);
 $411 = Math_fround($385 * $407);
 $412 = Math_fround($389 + $408);
 $413 = Math_fround($391 + $409);
 $414 = Math_fround($393 + $410);
 $415 = Math_fround($395 + $411);
 $416 = HEAP32[$246>>2]|0;
 $417 = (($416) + 456|0);
 $418 = Math_fround(HEAPF32[$417>>2]);
 $419 = (($416) + 440|0);
 $420 = Math_fround(HEAPF32[$419>>2]);
 $421 = Math_fround($420 - $412);
 $422 = (($416) + 444|0);
 $423 = Math_fround(HEAPF32[$422>>2]);
 $424 = Math_fround($423 - $413);
 $425 = (($416) + 448|0);
 $426 = Math_fround(HEAPF32[$425>>2]);
 $427 = Math_fround($426 - $414);
 $428 = (($416) + 452|0);
 $429 = Math_fround(HEAPF32[$428>>2]);
 $430 = Math_fround($429 - $415);
 $431 = Math_fround($418 * $421);
 $432 = Math_fround($418 * $424);
 $433 = Math_fround($418 * $427);
 $434 = Math_fround($418 * $430);
 $435 = Math_fround($412 + $431);
 $436 = Math_fround($413 + $432);
 $437 = Math_fround($414 + $433);
 $438 = Math_fround($415 + $434);
 HEAPF32[$$pre$phi32Z2D>>2] = $435;
 $439 = (($memory) + 156|0);
 HEAPF32[$439>>2] = $436;
 HEAPF32[$$pre$phi34Z2D>>2] = $437;
 HEAPF32[$$pre$phi36Z2D>>2] = $438;
 $440 = HEAP32[$7>>2]|0;
 $441 = ($440|0)==(0);
 if ($441) {
  $492 = Math_fround(1.0);
 } else {
  $442 = $7;
  $443 = (($440) + ($442))|0;
  $444 = $443;
  $445 = (($444) + 48|0);
  $446 = $445;
  $447 = HEAP32[$445>>2]|0;
  $448 = (($447) + ($446))|0;
  $449 = $448;
  $450 = HEAP32[$449>>2]|0;
  $451 = ($450|0)==(0);
  if ($451) {
   $492 = Math_fround(1.0);
  } else {
   $452 = (($444) + 392|0);
   $453 = Math_fround(HEAPF32[$452>>2]);
   $492 = $453;
  }
 }
 $454 = (($workspace) + 28|0);
 $455 = (($memory) + 8|0);
 $456 = Math_fround(HEAPF32[$455>>2]);
 $457 = (($memory) + 12|0);
 $458 = Math_fround(HEAPF32[$457>>2]);
 $459 = (($memory) + 16|0);
 $460 = Math_fround(HEAPF32[$459>>2]);
 $461 = (($memory) + 20|0);
 $462 = Math_fround(HEAPF32[$461>>2]);
 HEAPF32[$454>>2] = $456;
 $463 = (($workspace) + 32|0);
 HEAPF32[$463>>2] = $458;
 $464 = (($workspace) + 36|0);
 HEAPF32[$464>>2] = $460;
 $465 = (($workspace) + 40|0);
 HEAPF32[$465>>2] = $462;
 $466 = (($memory) + 24|0);
 $467 = Math_fround(HEAPF32[$466>>2]);
 $468 = (($memory) + 28|0);
 $469 = Math_fround(HEAPF32[$468>>2]);
 $470 = (($memory) + 32|0);
 $471 = Math_fround(HEAPF32[$470>>2]);
 $472 = (($memory) + 36|0);
 $473 = Math_fround(HEAPF32[$472>>2]);
 $474 = (($workspace) + 44|0);
 HEAPF32[$474>>2] = $467;
 $475 = (($workspace) + 48|0);
 HEAPF32[$475>>2] = $469;
 $476 = (($workspace) + 52|0);
 HEAPF32[$476>>2] = $471;
 $477 = (($workspace) + 56|0);
 HEAPF32[$477>>2] = $473;
 $478 = (($memory) + 40|0);
 $479 = Math_fround(HEAPF32[$478>>2]);
 $480 = (($memory) + 44|0);
 $481 = Math_fround(HEAPF32[$480>>2]);
 $482 = (($memory) + 48|0);
 $483 = Math_fround(HEAPF32[$482>>2]);
 $484 = (($memory) + 52|0);
 $485 = Math_fround(HEAPF32[$484>>2]);
 $486 = (($workspace) + 60|0);
 HEAPF32[$486>>2] = $479;
 $487 = (($workspace) + 64|0);
 HEAPF32[$487>>2] = $481;
 $488 = (($workspace) + 68|0);
 HEAPF32[$488>>2] = $483;
 $489 = (($workspace) + 72|0);
 HEAPF32[$489>>2] = $485;
 $490 = Math_fround(HEAPF32[$dx>>2]);
 $491 = Math_fround($492 * $490);
 $493 = (($dx) + 4|0);
 $494 = Math_fround(HEAPF32[$493>>2]);
 $495 = Math_fround($492 * $494);
 $496 = (($dx) + 8|0);
 $497 = Math_fround(HEAPF32[$496>>2]);
 $498 = Math_fround($492 * $497);
 $499 = (($dx) + 12|0);
 $500 = Math_fround(HEAPF32[$499>>2]);
 $501 = Math_fround($492 * $500);
 HEAPF32[$dx>>2] = $491;
 HEAPF32[$493>>2] = $495;
 HEAPF32[$496>>2] = $498;
 HEAPF32[$499>>2] = $501;
 __ZN4mathL8xformMulERKNS_5xformES2_18903($0,$454,$dx);
 $502 = Math_fround(HEAPF32[$0>>2]);
 $503 = (($0) + 4|0);
 $504 = Math_fround(HEAPF32[$503>>2]);
 $505 = (($0) + 8|0);
 $506 = Math_fround(HEAPF32[$505>>2]);
 $507 = (($0) + 12|0);
 $508 = Math_fround(HEAPF32[$507>>2]);
 HEAPF32[$454>>2] = $502;
 HEAPF32[$463>>2] = $504;
 HEAPF32[$464>>2] = $506;
 HEAPF32[$465>>2] = $508;
 $509 = (($0) + 16|0);
 $510 = Math_fround(HEAPF32[$509>>2]);
 $511 = (($0) + 20|0);
 $512 = Math_fround(HEAPF32[$511>>2]);
 $513 = (($0) + 24|0);
 $514 = Math_fround(HEAPF32[$513>>2]);
 $515 = (($0) + 28|0);
 $516 = Math_fround(HEAPF32[$515>>2]);
 HEAPF32[$474>>2] = $510;
 HEAPF32[$475>>2] = $512;
 HEAPF32[$476>>2] = $514;
 HEAPF32[$477>>2] = $516;
 $517 = (($0) + 32|0);
 $518 = Math_fround(HEAPF32[$517>>2]);
 $519 = (($0) + 36|0);
 $520 = Math_fround(HEAPF32[$519>>2]);
 $521 = (($0) + 40|0);
 $522 = Math_fround(HEAPF32[$521>>2]);
 $523 = (($0) + 44|0);
 $524 = Math_fround(HEAPF32[$523>>2]);
 HEAPF32[$486>>2] = $518;
 HEAPF32[$487>>2] = $520;
 HEAPF32[$488>>2] = $522;
 HEAPF32[$489>>2] = $524;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation15EvaluateAvatarXEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceE($constant,$input,$output,$memory,$workspace) {
 $constant = $constant|0;
 $input = $input|0;
 $output = $output|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $dx = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $dx = sp + 48|0;
 $0 = sp;
 $1 = (($constant) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  label = 3;
 } else {
  $4 = $1;
  $5 = (($2) + ($4))|0;
  $6 = $5;
  $7 = (($6) + 48|0);
  $8 = $7;
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + ($8))|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if ($13) {
   label = 3;
  } else {
   $74 = 1;
  }
 }
 if ((label|0) == 3) {
  $14 = (($constant) + 68|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(-1);
  if ($16) {
   $17 = (($input) + 22|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    STACKTOP = sp;return;
   } else {
    $74 = 0;
   }
  } else {
   $74 = 0;
  }
 }
 $20 = (($output) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 __ZN7mecanim9animation29MotionOutputGetDeltaTransformEPKNS0_12MotionOutputE($dx,$21);
 if ($74) {
  $22 = $1;
  $23 = HEAP32[$1>>2]|0;
  $24 = (($23) + ($22))|0;
  $25 = $24;
  $26 = (($25) + 392|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround(HEAPF32[$dx>>2]);
  $29 = Math_fround($27 * $28);
  $30 = (($dx) + 4|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($27 * $31);
  $33 = (($dx) + 8|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($27 * $34);
  $36 = (($dx) + 12|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = Math_fround($27 * $37);
  HEAPF32[$dx>>2] = $29;
  HEAPF32[$30>>2] = $32;
  HEAPF32[$33>>2] = $35;
  HEAPF32[$36>>2] = $38;
 }
 $39 = (($memory) + 8|0);
 __ZN4mathL8xformMulERKNS_5xformES2_18903($0,$39,$dx);
 $40 = Math_fround(HEAPF32[$0>>2]);
 $41 = (($0) + 4|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($0) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($0) + 12|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 HEAPF32[$39>>2] = $40;
 $47 = (($memory) + 12|0);
 HEAPF32[$47>>2] = $42;
 $48 = (($memory) + 16|0);
 HEAPF32[$48>>2] = $44;
 $49 = (($memory) + 20|0);
 HEAPF32[$49>>2] = $46;
 $50 = (($0) + 16|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($0) + 20|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($0) + 24|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($0) + 28|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($memory) + 24|0);
 HEAPF32[$58>>2] = $51;
 $59 = (($memory) + 28|0);
 HEAPF32[$59>>2] = $53;
 $60 = (($memory) + 32|0);
 HEAPF32[$60>>2] = $55;
 $61 = (($memory) + 36|0);
 HEAPF32[$61>>2] = $57;
 $62 = (($0) + 32|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($0) + 36|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($0) + 40|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($0) + 44|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($memory) + 40|0);
 HEAPF32[$70>>2] = $63;
 $71 = (($memory) + 44|0);
 HEAPF32[$71>>2] = $65;
 $72 = (($memory) + 48|0);
 HEAPF32[$72>>2] = $67;
 $73 = (($memory) + 52|0);
 HEAPF32[$73>>2] = $69;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation22EvaluateAvatarRetargetEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantE($constant,$input,$output,$memory,$workspace,$controllerConstant) {
 $constant = $constant|0;
 $input = $input|0;
 $output = $output|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $controllerConstant = $controllerConstant|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $avatarX = 0, $humanPose = 0, $humanPosePtr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 928|0;
 $avatarX = sp + 880|0;
 $humanPose = sp;
 $0 = ($controllerConstant|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($constant) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = $1;
 $5 = (($2) + ($4))|0;
 $6 = $5;
 $7 = (($6) + 48|0);
 $8 = $7;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (($memory) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($memory) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($memory) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($memory) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAPF32[$avatarX>>2] = $15;
 $22 = (($avatarX) + 4|0);
 HEAPF32[$22>>2] = $17;
 $23 = (($avatarX) + 8|0);
 HEAPF32[$23>>2] = $19;
 $24 = (($avatarX) + 12|0);
 HEAPF32[$24>>2] = $21;
 $25 = (($memory) + 24|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($memory) + 28|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($memory) + 32|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($memory) + 36|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($avatarX) + 16|0);
 HEAPF32[$33>>2] = $26;
 $34 = (($avatarX) + 20|0);
 HEAPF32[$34>>2] = $28;
 $35 = (($avatarX) + 24|0);
 HEAPF32[$35>>2] = $30;
 $36 = (($avatarX) + 28|0);
 HEAPF32[$36>>2] = $32;
 $37 = (($memory) + 40|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($memory) + 44|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($memory) + 48|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($memory) + 52|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($avatarX) + 32|0);
 HEAPF32[$45>>2] = $38;
 $46 = (($avatarX) + 36|0);
 HEAPF32[$46>>2] = $40;
 $47 = (($avatarX) + 40|0);
 HEAPF32[$47>>2] = $42;
 $48 = (($avatarX) + 44|0);
 HEAPF32[$48>>2] = $44;
 __ZN7mecanim5human9HumanPoseC2Ev($humanPose);
 $49 = (($input) + 21|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = ($50<<24>>24)==(0);
 if ($51) {
  $56 = HEAP32[$controllerConstant>>2]|0;
  $57 = ($56>>>0)>(1);
  $58 = (($output) + 16|0);
  if ($57) {
   $59 = HEAP32[$58>>2]|0;
   __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($humanPose,$59,0);
   $$pre$phiZ2D = $58;$humanPosePtr$0 = $humanPose;
  } else {
   $$pre$phiZ2D = $58;$humanPosePtr$0 = 0;
  }
 } else {
  $52 = (($output) + 12|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = (($output) + 16|0);
  $55 = HEAP32[$54>>2]|0;
  __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($53,$55,0);
  $$pre$phiZ2D = $54;$humanPosePtr$0 = 0;
 }
 $60 = HEAP32[$1>>2]|0;
 $61 = (($60) + ($4))|0;
 $62 = $61;
 $63 = (($constant) + 40|0);
 HEAP32[$63>>2] = $62;
 $64 = (($output) + 12|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = HEAP32[$$pre$phiZ2D>>2]|0;
 $67 = HEAP32[$workspace>>2]|0;
 $68 = (($workspace) + 4|0);
 $69 = HEAP32[$68>>2]|0;
 __ZN7mecanim5human10RetargetToEPKNS0_5HumanEPKNS0_9HumanPoseES6_RKN4math5xformEPS4_PNS_8skeleton12SkeletonPoseESE_($62,$65,$humanPosePtr$0,$avatarX,$66,$67,$69);
 $70 = HEAP32[$$pre$phiZ2D>>2]|0;
 $71 = (($70) + 128|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 $72 = (($70) + 132|0);
 HEAPF32[$72>>2] = Math_fround(0.0);
 $73 = (($70) + 152|0);
 HEAPF32[$73>>2] = Math_fround(0.0);
 $74 = (($70) + 204|0);
 HEAPF32[$74>>2] = Math_fround(0.0);
 $75 = (($70) + 208|0);
 HEAPF32[$75>>2] = Math_fround(0.0);
 $76 = (($70) + 228|0);
 HEAPF32[$76>>2] = Math_fround(0.0);
 $77 = (($70) + 280|0);
 HEAPF32[$77>>2] = Math_fround(0.0);
 $78 = (($70) + 284|0);
 HEAPF32[$78>>2] = Math_fround(0.0);
 $79 = (($70) + 304|0);
 HEAPF32[$79>>2] = Math_fround(0.0);
 $80 = (($70) + 356|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 $81 = (($70) + 360|0);
 HEAPF32[$81>>2] = Math_fround(0.0);
 $82 = (($70) + 380|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = (($70) + 64|0);
 $84 = (($workspace) + 92|0);
 ;HEAP32[$83+0>>2]=0|0;HEAP32[$83+4>>2]=0|0;HEAP32[$83+8>>2]=0|0;HEAP32[$83+12>>2]=0|0;
 $85 = HEAP8[$84>>0]|0;
 $86 = ($85<<24>>24)==(0);
 if ($86) {
  STACKTOP = sp;return;
 }
 __ZN7mecanim9animation11SetIKOnFeetEbRKNS0_14AvatarConstantERKNS0_11AvatarInputERNS0_12AvatarMemoryERNS0_15AvatarWorkspaceERNS0_12AvatarOutputE(1,$constant,$input,$memory,$workspace,$output);
 __ZN7mecanim9animation11SetIKOnFeetEbRKNS0_14AvatarConstantERKNS0_11AvatarInputERNS0_12AvatarMemoryERNS0_15AvatarWorkspaceERNS0_12AvatarOutputE(0,$constant,$input,$memory,$workspace,$output);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation16EvaluateAvatarIKEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantEb($constant,$input,$output,$memory,$workspace,$controllerConstant,$defaultIKPass) {
 $constant = $constant|0;
 $input = $input|0;
 $output = $output|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $controllerConstant = $controllerConstant|0;
 $defaultIKPass = $defaultIKPass|0;
 var $$pre = 0, $$pre$phi19Z2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre1622 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0;
 var $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0;
 var $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = Math_fround(0);
 var $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0);
 var $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$012 = 0, $needIK$0$in$lcssa = 0, $needIK$0$in$not = 0, $needIK$0$in11 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($controllerConstant|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($constant) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $2;
 $6 = (($3) + ($5))|0;
 $7 = $6;
 $8 = (($7) + 48|0);
 $9 = $8;
 $10 = HEAP32[$8>>2]|0;
 $11 = (($10) + ($9))|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($output) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 64|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = $18 > Math_fround(0.0);
 $20 = (($16) + 68|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = $21 > Math_fround(0.0);
 $23 = (($16) + 72|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $24 > Math_fround(0.0);
 $26 = (($16) + 76|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = $27 > Math_fround(0.0);
 $29 = $22 | $19;
 $30 = $29 | $25;
 $31 = $30 | $28;
 L10: do {
  if ($31) {
   $needIK$0$in$lcssa = 1;
  } else {
   $i$012 = 0;$needIK$0$in11 = 0;
   while(1) {
    $32 = ((($16) + (($i$012*76)|0)|0) + 128|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = $33 > Math_fround(0.0);
    if ($34) {
     $needIK$0$in$lcssa = 1;
     break L10;
    }
    $35 = ((($16) + (($i$012*76)|0)|0) + 132|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    $37 = $36 > Math_fround(0.0);
    if ($37) {
     $needIK$0$in$lcssa = 1;
     break L10;
    }
    $38 = ((($16) + (($i$012*76)|0)|0) + 152|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = $39 > Math_fround(0.0);
    $41 = $needIK$0$in11 | $40;
    $42 = (($i$012) + 1)|0;
    $needIK$0$in$not = $41 ^ 1;
    $43 = ($42>>>0)<(4);
    $or$cond = $43 & $needIK$0$in$not;
    if ($or$cond) {
     $i$012 = $42;$needIK$0$in11 = $41;
    } else {
     $needIK$0$in$lcssa = $41;
     break;
    }
   }
  }
 } while(0);
 $44 = HEAP32[$workspace>>2]|0;
 $45 = (($44) + 4|0);
 $46 = $45;
 $47 = HEAP32[$45>>2]|0;
 $48 = (($46) + ($47))|0;
 $49 = $48;
 $50 = (($44) + 8|0);
 HEAP32[$50>>2] = $49;
 $51 = HEAP32[$15>>2]|0;
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($51) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($51) + 8|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($51) + 12|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 HEAPF32[$49>>2] = $52;
 $59 = (($49) + 4|0);
 HEAPF32[$59>>2] = $54;
 $60 = (($49) + 8|0);
 HEAPF32[$60>>2] = $56;
 $61 = (($49) + 12|0);
 HEAPF32[$61>>2] = $58;
 $62 = (($51) + 16|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($51) + 20|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = (($51) + 24|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = (($51) + 28|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = (($49) + 16|0);
 HEAPF32[$70>>2] = $63;
 $71 = (($49) + 20|0);
 HEAPF32[$71>>2] = $65;
 $72 = (($49) + 24|0);
 HEAPF32[$72>>2] = $67;
 $73 = (($49) + 28|0);
 HEAPF32[$73>>2] = $69;
 $74 = (($51) + 32|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($51) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($51) + 40|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($51) + 44|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = (($49) + 32|0);
 HEAPF32[$82>>2] = $75;
 $83 = (($49) + 36|0);
 HEAPF32[$83>>2] = $77;
 $84 = (($49) + 40|0);
 HEAPF32[$84>>2] = $79;
 $85 = (($49) + 44|0);
 HEAPF32[$85>>2] = $81;
 if ($needIK$0$in$lcssa) {
  $86 = (($7) + 52|0);
  HEAP32[$86>>2] = $12;
  $87 = HEAP32[$workspace>>2]|0;
  $88 = (($workspace) + 4|0);
  $89 = HEAP32[$88>>2]|0;
  __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_($12,$87,$89);
  $90 = HEAP32[$2>>2]|0;
  $91 = (($90) + ($5))|0;
  $92 = $91;
  $93 = (($constant) + 40|0);
  HEAP32[$93>>2] = $92;
  $94 = HEAP32[$15>>2]|0;
  $95 = HEAP32[$workspace>>2]|0;
  $96 = HEAP32[$88>>2]|0;
  $97 = (($workspace) + 8|0);
  $98 = HEAP32[$97>>2]|0;
  __ZN7mecanim5human13FullBodySolveEPKNS0_5HumanEPKNS0_9HumanPoseEPNS_8skeleton12SkeletonPoseES9_S9_($92,$94,$95,$96,$98);
  $$pre = HEAP32[$15>>2]|0;
  $100 = $$pre;
 } else {
  $100 = $51;
 }
 $99 = (($100) + 80|0);
 $101 = Math_fround(HEAPF32[$99>>2]);
 $102 = (($100) + 84|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($100) + 88|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = (($100) + 92|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = (($memory) + 56|0);
 HEAPF32[$108>>2] = $101;
 $109 = (($memory) + 60|0);
 HEAPF32[$109>>2] = $103;
 $110 = (($memory) + 64|0);
 HEAPF32[$110>>2] = $105;
 $111 = (($memory) + 68|0);
 HEAPF32[$111>>2] = $107;
 $112 = (($100) + 96|0);
 $113 = Math_fround(HEAPF32[$112>>2]);
 $114 = (($100) + 100|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = (($100) + 104|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = (($100) + 108|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = (($memory) + 72|0);
 HEAPF32[$120>>2] = $113;
 $121 = (($memory) + 76|0);
 HEAPF32[$121>>2] = $115;
 $122 = (($memory) + 80|0);
 HEAPF32[$122>>2] = $117;
 $123 = (($memory) + 84|0);
 HEAPF32[$123>>2] = $119;
 $124 = (($100) + 112|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = (($100) + 116|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($100) + 120|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = (($100) + 124|0);
 $131 = Math_fround(HEAPF32[$130>>2]);
 $132 = (($memory) + 88|0);
 HEAPF32[$132>>2] = $125;
 $133 = (($memory) + 92|0);
 HEAPF32[$133>>2] = $127;
 $134 = (($memory) + 96|0);
 HEAPF32[$134>>2] = $129;
 $135 = (($memory) + 100|0);
 HEAPF32[$135>>2] = $131;
 $136 = (($100) + 156|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($100) + 160|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = (($100) + 164|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($100) + 168|0);
 $143 = Math_fround(HEAPF32[$142>>2]);
 $144 = (($memory) + 104|0);
 HEAPF32[$144>>2] = $137;
 $145 = (($memory) + 108|0);
 HEAPF32[$145>>2] = $139;
 $146 = (($memory) + 112|0);
 HEAPF32[$146>>2] = $141;
 $147 = (($memory) + 116|0);
 HEAPF32[$147>>2] = $143;
 $148 = (($100) + 172|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($100) + 176|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = (($100) + 180|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = (($100) + 184|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = (($memory) + 120|0);
 HEAPF32[$156>>2] = $149;
 $157 = (($memory) + 124|0);
 HEAPF32[$157>>2] = $151;
 $158 = (($memory) + 128|0);
 HEAPF32[$158>>2] = $153;
 $159 = (($memory) + 132|0);
 HEAPF32[$159>>2] = $155;
 $160 = (($100) + 188|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($100) + 192|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($100) + 196|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = (($100) + 200|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = (($memory) + 136|0);
 HEAPF32[$168>>2] = $161;
 $169 = (($memory) + 140|0);
 HEAPF32[$169>>2] = $163;
 $170 = (($memory) + 144|0);
 HEAPF32[$170>>2] = $165;
 $171 = (($memory) + 148|0);
 HEAPF32[$171>>2] = $167;
 if ($defaultIKPass) {
  $176 = HEAP32[$2>>2]|0;
  $177 = (($176) + ($5))|0;
  $178 = $177;
  $179 = (($178) + 48|0);
  $180 = $179;
  $181 = HEAP32[$179>>2]|0;
  $182 = (($180) + ($181))|0;
  $183 = $182;
  $184 = (($178) + 52|0);
  HEAP32[$184>>2] = $183;
  $185 = HEAP32[$workspace>>2]|0;
  $186 = (($workspace) + 4|0);
  $187 = HEAP32[$186>>2]|0;
  __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_($183,$185,$187);
  $188 = (($constant) + 40|0);
  $189 = (($0) + 4|0);
  $190 = (($0) + 8|0);
  $191 = (($0) + 12|0);
  $192 = HEAP32[$15>>2]|0;
  $193 = HEAP32[$2>>2]|0;
  $194 = (($193) + ($5))|0;
  $195 = $194;
  HEAP32[$188>>2] = $195;
  $196 = HEAP32[$186>>2]|0;
  __ZN7mecanim5human20HumanGetHintPositionEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseENS0_4GoalE($0,$195,$196,0);
  $197 = Math_fround(HEAPF32[$0>>2]);
  $198 = Math_fround(HEAPF32[$189>>2]);
  $199 = Math_fround(HEAPF32[$190>>2]);
  $200 = Math_fround(HEAPF32[$191>>2]);
  $201 = (($192) + 136|0);
  HEAPF32[$201>>2] = $197;
  $202 = (($192) + 140|0);
  HEAPF32[$202>>2] = $198;
  $203 = (($192) + 144|0);
  HEAPF32[$203>>2] = $199;
  $204 = (($192) + 148|0);
  HEAPF32[$204>>2] = $200;
  $$pre$phi19Z2D = $186;$212 = $188;$215 = $0;$217 = $189;$219 = $190;$221 = $191;
 } else {
  $$pre1622 = (($workspace) + 4|0);
  $172 = (($constant) + 40|0);
  $173 = (($0) + 4|0);
  $174 = (($0) + 8|0);
  $175 = (($0) + 12|0);
  $$pre$phi19Z2D = $$pre1622;$212 = $172;$215 = $0;$217 = $173;$219 = $174;$221 = $175;
 }
 $205 = HEAP32[$15>>2]|0;
 $206 = (($205) + 128|0);
 HEAPF32[$206>>2] = Math_fround(0.0);
 $207 = (($205) + 132|0);
 HEAPF32[$207>>2] = Math_fround(0.0);
 $208 = (($205) + 152|0);
 HEAPF32[$208>>2] = Math_fround(0.0);
 if ($defaultIKPass) {
  $209 = HEAP32[$2>>2]|0;
  $210 = (($209) + ($5))|0;
  $211 = $210;
  HEAP32[$212>>2] = $211;
  $213 = HEAP32[$$pre$phi19Z2D>>2]|0;
  __ZN7mecanim5human20HumanGetHintPositionEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseENS0_4GoalE($0,$211,$213,1);
  $214 = Math_fround(HEAPF32[$215>>2]);
  $216 = Math_fround(HEAPF32[$217>>2]);
  $218 = Math_fround(HEAPF32[$219>>2]);
  $220 = Math_fround(HEAPF32[$221>>2]);
  $222 = (($205) + 212|0);
  HEAPF32[$222>>2] = $214;
  $223 = (($205) + 216|0);
  HEAPF32[$223>>2] = $216;
  $224 = (($205) + 220|0);
  HEAPF32[$224>>2] = $218;
  $225 = (($205) + 224|0);
  HEAPF32[$225>>2] = $220;
  $$pre13 = HEAP32[$15>>2]|0;
  $226 = (($$pre13) + 204|0);
  HEAPF32[$226>>2] = Math_fround(0.0);
  $227 = (($$pre13) + 208|0);
  HEAPF32[$227>>2] = Math_fround(0.0);
  $228 = (($$pre13) + 228|0);
  HEAPF32[$228>>2] = Math_fround(0.0);
  $229 = HEAP32[$2>>2]|0;
  $230 = (($229) + ($5))|0;
  $231 = $230;
  HEAP32[$212>>2] = $231;
  $232 = HEAP32[$$pre$phi19Z2D>>2]|0;
  __ZN7mecanim5human20HumanGetHintPositionEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseENS0_4GoalE($0,$231,$232,2);
  $233 = Math_fround(HEAPF32[$215>>2]);
  $234 = Math_fround(HEAPF32[$217>>2]);
  $235 = Math_fround(HEAPF32[$219>>2]);
  $236 = Math_fround(HEAPF32[$221>>2]);
  $237 = (($$pre13) + 288|0);
  HEAPF32[$237>>2] = $233;
  $238 = (($$pre13) + 292|0);
  HEAPF32[$238>>2] = $234;
  $239 = (($$pre13) + 296|0);
  HEAPF32[$239>>2] = $235;
  $240 = (($$pre13) + 300|0);
  HEAPF32[$240>>2] = $236;
  $$pre14 = HEAP32[$15>>2]|0;
  $241 = (($$pre14) + 280|0);
  HEAPF32[$241>>2] = Math_fround(0.0);
  $242 = (($$pre14) + 284|0);
  HEAPF32[$242>>2] = Math_fround(0.0);
  $243 = (($$pre14) + 304|0);
  HEAPF32[$243>>2] = Math_fround(0.0);
  $244 = HEAP32[$2>>2]|0;
  $245 = (($244) + ($5))|0;
  $246 = $245;
  HEAP32[$212>>2] = $246;
  $247 = HEAP32[$$pre$phi19Z2D>>2]|0;
  __ZN7mecanim5human20HumanGetHintPositionEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseENS0_4GoalE($0,$246,$247,3);
  $248 = Math_fround(HEAPF32[$215>>2]);
  $249 = Math_fround(HEAPF32[$217>>2]);
  $250 = Math_fround(HEAPF32[$219>>2]);
  $251 = Math_fround(HEAPF32[$221>>2]);
  $252 = (($$pre14) + 364|0);
  HEAPF32[$252>>2] = $248;
  $253 = (($$pre14) + 368|0);
  HEAPF32[$253>>2] = $249;
  $254 = (($$pre14) + 372|0);
  HEAPF32[$254>>2] = $250;
  $255 = (($$pre14) + 376|0);
  HEAPF32[$255>>2] = $251;
  $$pre15 = HEAP32[$15>>2]|0;
  $263 = $$pre15;
 } else {
  $256 = (($205) + 204|0);
  HEAPF32[$256>>2] = Math_fround(0.0);
  $257 = (($205) + 208|0);
  HEAPF32[$257>>2] = Math_fround(0.0);
  $258 = (($205) + 228|0);
  HEAPF32[$258>>2] = Math_fround(0.0);
  $259 = (($205) + 280|0);
  HEAPF32[$259>>2] = Math_fround(0.0);
  $260 = (($205) + 284|0);
  HEAPF32[$260>>2] = Math_fround(0.0);
  $261 = (($205) + 304|0);
  HEAPF32[$261>>2] = Math_fround(0.0);
  $263 = $205;
 }
 $262 = (($263) + 356|0);
 HEAPF32[$262>>2] = Math_fround(0.0);
 $264 = (($263) + 360|0);
 HEAPF32[$264>>2] = Math_fround(0.0);
 $265 = (($263) + 380|0);
 HEAPF32[$265>>2] = Math_fround(0.0);
 $266 = (($263) + 64|0);
 ;HEAP32[$266+0>>2]=0|0;HEAP32[$266+4>>2]=0|0;HEAP32[$266+8>>2]=0|0;HEAP32[$266+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17EvaluateAvatarEndEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantE($constant,$input,$output,$memory,$workspace,$controllerConstant) {
 $constant = $constant|0;
 $input = $input|0;
 $output = $output|0;
 $memory = $memory|0;
 $workspace = $workspace|0;
 $controllerConstant = $controllerConstant|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($constant) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = $0;
 $4 = (($1) + ($3))|0;
 $5 = $4;
 $6 = (($5) + 48|0);
 $7 = $6;
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + ($7))|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($constant) + 48|0);
 $14 = $13;
 $15 = HEAP32[$13>>2]|0;
 $16 = (($15) + ($14))|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$workspace>>2]|0;
 $20 = (($workspace) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 __ZN7mecanim8skeleton16SkeletonPoseCopyEPKNS0_12SkeletonPoseEPS1_($19,$21);
 $22 = HEAP32[$0>>2]|0;
 $23 = (($22) + ($3))|0;
 $24 = $23;
 $25 = (($constant) + 40|0);
 HEAP32[$25>>2] = $24;
 $26 = HEAP32[$20>>2]|0;
 $27 = (($workspace) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 __ZN7mecanim5human10TwistSolveEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_($24,$26,$28);
 $29 = (($constant) + 8|0);
 $30 = $29;
 $31 = HEAP32[$29>>2]|0;
 $32 = (($31) + ($30))|0;
 $33 = $32;
 $34 = (($constant) + 12|0);
 HEAP32[$34>>2] = $33;
 $35 = (($output) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 __ZN7mecanim8skeleton16SkeletonPoseCopyEPKNS0_12SkeletonPoseEPS1_($33,$36);
 $37 = HEAP32[$35>>2]|0;
 $38 = (($37) + 4|0);
 $39 = $38;
 $40 = HEAP32[$38>>2]|0;
 $41 = (($39) + ($40))|0;
 $42 = $41;
 $43 = (($37) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = (($memory) + 8|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($memory) + 12|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($memory) + 16|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($memory) + 20|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 HEAPF32[$42>>2] = $45;
 $52 = (($42) + 4|0);
 HEAPF32[$52>>2] = $47;
 $53 = (($42) + 8|0);
 HEAPF32[$53>>2] = $49;
 $54 = (($42) + 12|0);
 HEAPF32[$54>>2] = $51;
 $55 = (($memory) + 24|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($memory) + 28|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($memory) + 32|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = (($memory) + 36|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($42) + 16|0);
 HEAPF32[$63>>2] = $56;
 $64 = (($42) + 20|0);
 HEAPF32[$64>>2] = $58;
 $65 = (($42) + 24|0);
 HEAPF32[$65>>2] = $60;
 $66 = (($42) + 28|0);
 HEAPF32[$66>>2] = $62;
 $67 = (($memory) + 40|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($memory) + 44|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($memory) + 48|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($memory) + 52|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($42) + 32|0);
 HEAPF32[$75>>2] = $68;
 $76 = (($42) + 36|0);
 HEAPF32[$76>>2] = $70;
 $77 = (($42) + 40|0);
 HEAPF32[$77>>2] = $72;
 $78 = (($42) + 44|0);
 HEAPF32[$78>>2] = $74;
 $79 = $constant;
 $80 = HEAP32[$constant>>2]|0;
 $81 = (($80) + ($79))|0;
 $82 = $81;
 $83 = (($constant) + 4|0);
 HEAP32[$83>>2] = $82;
 $84 = HEAP32[$35>>2]|0;
 __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($82,$84,$84,$18,0);
 $85 = HEAP32[$0>>2]|0;
 $86 = (($85) + ($3))|0;
 $87 = $86;
 $88 = (($87) + 48|0);
 $89 = $88;
 $90 = HEAP32[$88>>2]|0;
 $91 = (($89) + ($90))|0;
 $92 = $91;
 $93 = (($87) + 52|0);
 HEAP32[$93>>2] = $92;
 $94 = HEAP32[$20>>2]|0;
 __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($92,$94,$94,1,1);
 $95 = HEAP32[$20>>2]|0;
 $96 = (($95) + 4|0);
 $97 = $96;
 $98 = HEAP32[$96>>2]|0;
 $99 = (($97) + ($98))|0;
 $100 = $99;
 $101 = (($95) + 8|0);
 HEAP32[$101>>2] = $100;
 $102 = HEAP32[$35>>2]|0;
 $103 = (($102) + 4|0);
 $104 = $103;
 $105 = HEAP32[$103>>2]|0;
 $106 = (($104) + ($105))|0;
 $107 = $106;
 $108 = (($102) + 8|0);
 HEAP32[$108>>2] = $107;
 $109 = (($107) + (($18*48)|0)|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = ((($107) + (($18*48)|0)|0) + 4|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = ((($107) + (($18*48)|0)|0) + 8|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = ((($107) + (($18*48)|0)|0) + 12|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 HEAPF32[$100>>2] = $110;
 $117 = (($100) + 4|0);
 HEAPF32[$117>>2] = $112;
 $118 = (($100) + 8|0);
 HEAPF32[$118>>2] = $114;
 $119 = (($100) + 12|0);
 HEAPF32[$119>>2] = $116;
 $120 = ((($107) + (($18*48)|0)|0) + 16|0);
 $121 = Math_fround(HEAPF32[$120>>2]);
 $122 = ((($107) + (($18*48)|0)|0) + 20|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = ((($107) + (($18*48)|0)|0) + 24|0);
 $125 = Math_fround(HEAPF32[$124>>2]);
 $126 = ((($107) + (($18*48)|0)|0) + 28|0);
 $127 = Math_fround(HEAPF32[$126>>2]);
 $128 = (($100) + 16|0);
 HEAPF32[$128>>2] = $121;
 $129 = (($100) + 20|0);
 HEAPF32[$129>>2] = $123;
 $130 = (($100) + 24|0);
 HEAPF32[$130>>2] = $125;
 $131 = (($100) + 28|0);
 HEAPF32[$131>>2] = $127;
 $132 = ((($107) + (($18*48)|0)|0) + 32|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = ((($107) + (($18*48)|0)|0) + 36|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = ((($107) + (($18*48)|0)|0) + 40|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = ((($107) + (($18*48)|0)|0) + 44|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = (($100) + 32|0);
 HEAPF32[$140>>2] = $133;
 $141 = (($100) + 36|0);
 HEAPF32[$141>>2] = $135;
 $142 = (($100) + 40|0);
 HEAPF32[$142>>2] = $137;
 $143 = (($100) + 44|0);
 HEAPF32[$143>>2] = $139;
 $144 = HEAP32[$constant>>2]|0;
 $145 = (($144) + ($79))|0;
 $146 = $145;
 HEAP32[$83>>2] = $146;
 $147 = HEAP32[$35>>2]|0;
 __ZN7mecanim8skeleton24SkeletonPoseComputeLocalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($146,$147,$147,$18,0);
 $148 = HEAP32[$0>>2]|0;
 $149 = (($148) + ($3))|0;
 $150 = $149;
 $151 = (($150) + 48|0);
 $152 = $151;
 $153 = HEAP32[$151>>2]|0;
 $154 = (($152) + ($153))|0;
 $155 = $154;
 $156 = (($150) + 52|0);
 HEAP32[$156>>2] = $155;
 $157 = HEAP32[$20>>2]|0;
 __ZN7mecanim8skeleton24SkeletonPoseComputeLocalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($155,$157,$157,1,1);
 $158 = HEAP32[$20>>2]|0;
 $159 = (($158) + 4|0);
 $160 = $159;
 $161 = HEAP32[$159>>2]|0;
 $162 = (($160) + ($161))|0;
 $163 = $162;
 $164 = (($158) + 8|0);
 HEAP32[$164>>2] = $163;
 $165 = HEAP32[$35>>2]|0;
 $166 = (($165) + 4|0);
 $167 = $166;
 $168 = HEAP32[$166>>2]|0;
 $169 = (($167) + ($168))|0;
 $170 = $169;
 $171 = (($165) + 8|0);
 HEAP32[$171>>2] = $170;
 $172 = (($170) + (($18*48)|0)|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = ((($170) + (($18*48)|0)|0) + 4|0);
 $175 = Math_fround(HEAPF32[$174>>2]);
 $176 = ((($170) + (($18*48)|0)|0) + 8|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = ((($170) + (($18*48)|0)|0) + 12|0);
 $179 = Math_fround(HEAPF32[$178>>2]);
 HEAPF32[$163>>2] = $173;
 $180 = (($163) + 4|0);
 HEAPF32[$180>>2] = $175;
 $181 = (($163) + 8|0);
 HEAPF32[$181>>2] = $177;
 $182 = (($163) + 12|0);
 HEAPF32[$182>>2] = $179;
 $183 = ((($170) + (($18*48)|0)|0) + 16|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = ((($170) + (($18*48)|0)|0) + 20|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = ((($170) + (($18*48)|0)|0) + 24|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = ((($170) + (($18*48)|0)|0) + 28|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($163) + 16|0);
 HEAPF32[$191>>2] = $184;
 $192 = (($163) + 20|0);
 HEAPF32[$192>>2] = $186;
 $193 = (($163) + 24|0);
 HEAPF32[$193>>2] = $188;
 $194 = (($163) + 28|0);
 HEAPF32[$194>>2] = $190;
 $195 = ((($170) + (($18*48)|0)|0) + 32|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = ((($170) + (($18*48)|0)|0) + 36|0);
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = ((($170) + (($18*48)|0)|0) + 40|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 $201 = ((($170) + (($18*48)|0)|0) + 44|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($163) + 32|0);
 HEAPF32[$203>>2] = $196;
 $204 = (($163) + 36|0);
 HEAPF32[$204>>2] = $198;
 $205 = (($163) + 40|0);
 HEAPF32[$205>>2] = $200;
 $206 = (($163) + 44|0);
 HEAPF32[$206>>2] = $202;
 $207 = HEAP32[$20>>2]|0;
 $208 = HEAP32[$35>>2]|0;
 $209 = (($constant) + 44|0);
 $210 = HEAP32[$209>>2]|0;
 $211 = HEAP32[$13>>2]|0;
 $212 = (($211) + ($14))|0;
 $213 = $212;
 $214 = (($constant) + 52|0);
 HEAP32[$214>>2] = $213;
 __ZN7mecanim8skeleton16SkeletonPoseCopyEPKNS0_12SkeletonPoseEPS1_jPKi($207,$208,$210,$213);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21SkeletonPoseFromValueERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseERKNS_10ValueArrayEPKNS0_14SkeletonTQSMapERS5_PKib($skeleton,$defaultPose,$values,$skeletonTQSMap,$pose,$humanReverseIndex,$skipRoot) {
 $skeleton = $skeleton|0;
 $defaultPose = $defaultPose|0;
 $values = $values|0;
 $skeletonTQSMap = $skeletonTQSMap|0;
 $pose = $pose|0;
 $humanReverseIndex = $humanReverseIndex|0;
 $skipRoot = $skipRoot|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0);
 var $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0);
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $index$09 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $skipRoot&1;
 $1 = HEAP32[$skeleton>>2]|0;
 $2 = ($0>>>0)<($1>>>0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = ($humanReverseIndex|0)==(0|0);
 $4 = (($pose) + 4|0);
 $5 = $4;
 $6 = (($pose) + 8|0);
 $7 = (($defaultPose) + 4|0);
 $8 = $7;
 $9 = (($values) + 64|0);
 $10 = $9;
 $11 = (($values) + 52|0);
 $12 = $11;
 $13 = (($values) + 40|0);
 $14 = $13;
 $index$09 = $0;
 while(1) {
  if ($3) {
   label = 5;
  } else {
   $15 = (($humanReverseIndex) + ($index$09<<2)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(-1);
   if ($17) {
    label = 5;
   }
  }
  do {
   if ((label|0) == 5) {
    label = 0;
    $18 = (($skeletonTQSMap) + (($index$09*12)|0)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==(-1);
    $21 = HEAP32[$4>>2]|0;
    $22 = (($21) + ($5))|0;
    $23 = $22;
    HEAP32[$6>>2] = $23;
    $24 = (($23) + (($index$09*48)|0)|0);
    if ($20) {
     $39 = HEAP32[$7>>2]|0;
     $40 = (($39) + ($8))|0;
     $41 = $40;
     $42 = (($41) + (($index$09*48)|0)|0);
     $43 = Math_fround(HEAPF32[$42>>2]);
     $44 = ((($41) + (($index$09*48)|0)|0) + 4|0);
     $45 = Math_fround(HEAPF32[$44>>2]);
     $46 = ((($41) + (($index$09*48)|0)|0) + 8|0);
     $47 = Math_fround(HEAPF32[$46>>2]);
     $48 = ((($41) + (($index$09*48)|0)|0) + 12|0);
     $49 = Math_fround(HEAPF32[$48>>2]);
     HEAPF32[$24>>2] = $43;
     $50 = ((($23) + (($index$09*48)|0)|0) + 4|0);
     HEAPF32[$50>>2] = $45;
     $51 = ((($23) + (($index$09*48)|0)|0) + 8|0);
     HEAPF32[$51>>2] = $47;
     $52 = ((($23) + (($index$09*48)|0)|0) + 12|0);
     HEAPF32[$52>>2] = $49;
    } else {
     $25 = HEAP32[$13>>2]|0;
     $26 = (($25) + ($14))|0;
     $27 = $26;
     $28 = (($27) + ($19<<4)|0);
     $29 = Math_fround(HEAPF32[$28>>2]);
     $30 = ((($27) + ($19<<4)|0) + 4|0);
     $31 = Math_fround(HEAPF32[$30>>2]);
     $32 = ((($27) + ($19<<4)|0) + 8|0);
     $33 = Math_fround(HEAPF32[$32>>2]);
     $34 = ((($27) + ($19<<4)|0) + 12|0);
     $35 = Math_fround(HEAPF32[$34>>2]);
     HEAPF32[$24>>2] = $29;
     $36 = ((($23) + (($index$09*48)|0)|0) + 4|0);
     HEAPF32[$36>>2] = $31;
     $37 = ((($23) + (($index$09*48)|0)|0) + 8|0);
     HEAPF32[$37>>2] = $33;
     $38 = ((($23) + (($index$09*48)|0)|0) + 12|0);
     HEAPF32[$38>>2] = $35;
    }
    $53 = ((($skeletonTQSMap) + (($index$09*12)|0)|0) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)==(-1);
    HEAP32[$6>>2] = $23;
    $56 = ((($23) + (($index$09*48)|0)|0) + 16|0);
    if ($55) {
     $71 = HEAP32[$7>>2]|0;
     $72 = (($71) + ($8))|0;
     $73 = $72;
     $74 = ((($73) + (($index$09*48)|0)|0) + 16|0);
     $75 = Math_fround(HEAPF32[$74>>2]);
     $76 = ((($73) + (($index$09*48)|0)|0) + 20|0);
     $77 = Math_fround(HEAPF32[$76>>2]);
     $78 = ((($73) + (($index$09*48)|0)|0) + 24|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $80 = ((($73) + (($index$09*48)|0)|0) + 28|0);
     $81 = Math_fround(HEAPF32[$80>>2]);
     HEAPF32[$56>>2] = $75;
     $82 = ((($23) + (($index$09*48)|0)|0) + 20|0);
     HEAPF32[$82>>2] = $77;
     $83 = ((($23) + (($index$09*48)|0)|0) + 24|0);
     HEAPF32[$83>>2] = $79;
     $84 = ((($23) + (($index$09*48)|0)|0) + 28|0);
     HEAPF32[$84>>2] = $81;
    } else {
     $57 = HEAP32[$11>>2]|0;
     $58 = (($57) + ($12))|0;
     $59 = $58;
     $60 = (($59) + ($54<<4)|0);
     $61 = Math_fround(HEAPF32[$60>>2]);
     $62 = ((($59) + ($54<<4)|0) + 4|0);
     $63 = Math_fround(HEAPF32[$62>>2]);
     $64 = ((($59) + ($54<<4)|0) + 8|0);
     $65 = Math_fround(HEAPF32[$64>>2]);
     $66 = ((($59) + ($54<<4)|0) + 12|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     HEAPF32[$56>>2] = $61;
     $68 = ((($23) + (($index$09*48)|0)|0) + 20|0);
     HEAPF32[$68>>2] = $63;
     $69 = ((($23) + (($index$09*48)|0)|0) + 24|0);
     HEAPF32[$69>>2] = $65;
     $70 = ((($23) + (($index$09*48)|0)|0) + 28|0);
     HEAPF32[$70>>2] = $67;
    }
    $85 = ((($skeletonTQSMap) + (($index$09*12)|0)|0) + 8|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==(-1);
    HEAP32[$6>>2] = $23;
    $88 = ((($23) + (($index$09*48)|0)|0) + 32|0);
    if ($87) {
     $103 = HEAP32[$7>>2]|0;
     $104 = (($103) + ($8))|0;
     $105 = $104;
     $106 = ((($105) + (($index$09*48)|0)|0) + 32|0);
     $107 = Math_fround(HEAPF32[$106>>2]);
     $108 = ((($105) + (($index$09*48)|0)|0) + 36|0);
     $109 = Math_fround(HEAPF32[$108>>2]);
     $110 = ((($105) + (($index$09*48)|0)|0) + 40|0);
     $111 = Math_fround(HEAPF32[$110>>2]);
     $112 = ((($105) + (($index$09*48)|0)|0) + 44|0);
     $113 = Math_fround(HEAPF32[$112>>2]);
     HEAPF32[$88>>2] = $107;
     $114 = ((($23) + (($index$09*48)|0)|0) + 36|0);
     HEAPF32[$114>>2] = $109;
     $115 = ((($23) + (($index$09*48)|0)|0) + 40|0);
     HEAPF32[$115>>2] = $111;
     $116 = ((($23) + (($index$09*48)|0)|0) + 44|0);
     HEAPF32[$116>>2] = $113;
     break;
    } else {
     $89 = HEAP32[$9>>2]|0;
     $90 = (($89) + ($10))|0;
     $91 = $90;
     $92 = (($91) + ($86<<4)|0);
     $93 = Math_fround(HEAPF32[$92>>2]);
     $94 = ((($91) + ($86<<4)|0) + 4|0);
     $95 = Math_fround(HEAPF32[$94>>2]);
     $96 = ((($91) + ($86<<4)|0) + 8|0);
     $97 = Math_fround(HEAPF32[$96>>2]);
     $98 = ((($91) + ($86<<4)|0) + 12|0);
     $99 = Math_fround(HEAPF32[$98>>2]);
     HEAPF32[$88>>2] = $93;
     $100 = ((($23) + (($index$09*48)|0)|0) + 36|0);
     HEAPF32[$100>>2] = $95;
     $101 = ((($23) + (($index$09*48)|0)|0) + 40|0);
     HEAPF32[$101>>2] = $97;
     $102 = ((($23) + (($index$09*48)|0)|0) + 44|0);
     HEAPF32[$102>>2] = $99;
     break;
    }
   }
  } while(0);
  $117 = (($index$09) + 1)|0;
  $118 = ($117>>>0)<($1>>>0);
  if ($118) {
   $index$09 = $117;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21ValueFromSkeletonPoseERKNS_8skeleton8SkeletonERKNS1_12SkeletonPoseEPKNS0_14SkeletonTQSMapERNS_10ValueArrayE($skeleton,$pose,$skeletonTQSMap,$values) {
 $skeleton = $skeleton|0;
 $pose = $pose|0;
 $skeletonTQSMap = $skeletonTQSMap|0;
 $values = $values|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $index$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$skeleton>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($pose) + 4|0);
 $3 = $2;
 $4 = (($values) + 64|0);
 $5 = $4;
 $6 = (($values) + 68|0);
 $7 = (($values) + 52|0);
 $8 = $7;
 $9 = (($values) + 56|0);
 $10 = (($values) + 40|0);
 $11 = $10;
 $12 = (($values) + 44|0);
 $index$01 = 0;
 while(1) {
  $13 = (($skeletonTQSMap) + (($index$01*12)|0)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(-1);
  if (!($15)) {
   $16 = HEAP32[$2>>2]|0;
   $17 = (($16) + ($3))|0;
   $18 = $17;
   $19 = HEAP32[$10>>2]|0;
   $20 = (($19) + ($11))|0;
   $21 = $20;
   HEAP32[$12>>2] = $21;
   $22 = (($18) + (($index$01*48)|0)|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = ((($18) + (($index$01*48)|0)|0) + 4|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = ((($18) + (($index$01*48)|0)|0) + 8|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = ((($18) + (($index$01*48)|0)|0) + 12|0);
   $29 = Math_fround(HEAPF32[$28>>2]);
   $30 = (($21) + ($14<<4)|0);
   HEAPF32[$30>>2] = $23;
   $31 = ((($21) + ($14<<4)|0) + 4|0);
   HEAPF32[$31>>2] = $25;
   $32 = ((($21) + ($14<<4)|0) + 8|0);
   HEAPF32[$32>>2] = $27;
   $33 = ((($21) + ($14<<4)|0) + 12|0);
   HEAPF32[$33>>2] = $29;
  }
  $34 = ((($skeletonTQSMap) + (($index$01*12)|0)|0) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==(-1);
  if (!($36)) {
   $37 = HEAP32[$2>>2]|0;
   $38 = (($37) + ($3))|0;
   $39 = $38;
   $40 = HEAP32[$7>>2]|0;
   $41 = (($40) + ($8))|0;
   $42 = $41;
   HEAP32[$9>>2] = $42;
   $43 = ((($39) + (($index$01*48)|0)|0) + 16|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = ((($39) + (($index$01*48)|0)|0) + 20|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = ((($39) + (($index$01*48)|0)|0) + 24|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = ((($39) + (($index$01*48)|0)|0) + 28|0);
   $50 = Math_fround(HEAPF32[$49>>2]);
   $51 = (($42) + ($35<<4)|0);
   HEAPF32[$51>>2] = $44;
   $52 = ((($42) + ($35<<4)|0) + 4|0);
   HEAPF32[$52>>2] = $46;
   $53 = ((($42) + ($35<<4)|0) + 8|0);
   HEAPF32[$53>>2] = $48;
   $54 = ((($42) + ($35<<4)|0) + 12|0);
   HEAPF32[$54>>2] = $50;
  }
  $55 = ((($skeletonTQSMap) + (($index$01*12)|0)|0) + 8|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(-1);
  if (!($57)) {
   $58 = HEAP32[$2>>2]|0;
   $59 = (($58) + ($3))|0;
   $60 = $59;
   $61 = HEAP32[$4>>2]|0;
   $62 = (($61) + ($5))|0;
   $63 = $62;
   HEAP32[$6>>2] = $63;
   $64 = ((($60) + (($index$01*48)|0)|0) + 32|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = ((($60) + (($index$01*48)|0)|0) + 36|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = ((($60) + (($index$01*48)|0)|0) + 40|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $70 = ((($60) + (($index$01*48)|0)|0) + 44|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = (($63) + ($56<<4)|0);
   HEAPF32[$72>>2] = $65;
   $73 = ((($63) + ($56<<4)|0) + 4|0);
   HEAPF32[$73>>2] = $67;
   $74 = ((($63) + ($56<<4)|0) + 8|0);
   HEAPF32[$74>>2] = $69;
   $75 = ((($63) + ($56<<4)|0) + 12|0);
   HEAPF32[$75>>2] = $71;
  }
  $76 = (($index$01) + 1)|0;
  $77 = ($76>>>0)<($0>>>0);
  if ($77) {
   $index$01 = $76;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation26InitializeMuscleClipTablesEv() {
 var $$02$i$i$i$i$i = 0, $$masked$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $d$08$i = 0, $d2$02$i = 0, $exitcond$i = 0, $exitcond$i$i$i$i = 0;
 var $exitcond$i$i$i$i$i = 0, $exitcond$i1 = 0, $exitcond17$i = 0, $exitcond18$i = 0, $exitcond19$i = 0, $exitcond20$i = 0, $exitcond21$i = 0, $f$011$i = 0, $f1$05$i = 0, $i$01$i = 0, $i$015$i = 0, $i$03$i$i$i$i$i = 0, $i$113$i = 0, $i$210$i = 0, $i$37$i = 0, $i$44$i = 0, $i$51$i = 0, $j$016$i = 0, $j$114$i = 0, $nameQ$i = 0;
 var $nameQw$i = 0, $nameQx$i = 0, $nameQy$i = 0, $nameQz$i = 0, $nameTx$i = 0, $nameTy$i = 0, $nameTz$i = 0, $p$01$i$i$i$i = 0, $reflection$01$i$i$i$i$i = 0, $reflection$1$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1152|0;
 $0 = sp;
 $nameTx$i = sp + 896|0;
 $nameTy$i = sp + 768|0;
 $nameTz$i = sp + 640|0;
 $nameQ$i = sp + 1024|0;
 $nameQx$i = sp + 256|0;
 $nameQy$i = sp + 128|0;
 $nameQz$i = sp + 384|0;
 $nameQw$i = sp + 512|0;
 (_strncpy((775176|0),(793808|0),128)|0);
 HEAP8[((775176 + 127|0))>>0] = 0;
 (_strncpy((((775176 + 128|0))|0),(793824|0),128)|0);
 HEAP8[((775176 + 255|0))>>0] = 0;
 (_strncpy((((775176 + 256|0))|0),(793840|0),128)|0);
 HEAP8[((775176 + 383|0))>>0] = 0;
 (_strncpy((((775176 + 384|0))|0),(793856|0),128)|0);
 HEAP8[((775176 + 511|0))>>0] = 0;
 (_strncpy((((775176 + 512|0))|0),(793872|0),128)|0);
 HEAP8[((775176 + 639|0))>>0] = 0;
 (_strncpy((((775176 + 640|0))|0),(793888|0),128)|0);
 HEAP8[((775176 + 767|0))>>0] = 0;
 (_strncpy((((775176 + 768|0))|0),(793904|0),128)|0);
 HEAP8[((775176 + 895|0))>>0] = 0;
 (_strncpy((((775176 + 896|0))|0),(793920|0),128)|0);
 HEAP8[((775176 + 1023|0))>>0] = 0;
 (_strncpy((((775176 + 1024|0))|0),(793928|0),128)|0);
 HEAP8[((775176 + 1151|0))>>0] = 0;
 (_strncpy((((775176 + 1152|0))|0),(793936|0),128)|0);
 HEAP8[((775176 + 1279|0))>>0] = 0;
 (_strncpy((((775176 + 1280|0))|0),(793944|0),128)|0);
 HEAP8[((775176 + 1407|0))>>0] = 0;
 (_strncpy((((775176 + 1408|0))|0),(793952|0),128)|0);
 HEAP8[((775176 + 1535|0))>>0] = 0;
 (_strncpy((((775176 + 1536|0))|0),(793960|0),128)|0);
 HEAP8[((775176 + 1663|0))>>0] = 0;
 (_strncpy((((775176 + 1664|0))|0),(793968|0),128)|0);
 HEAP8[((775176 + 1791|0))>>0] = 0;
 $1 = (($0) + 127|0);
 $2 = (($nameTx$i) + 127|0);
 $3 = (($nameTy$i) + 127|0);
 $4 = (($nameTz$i) + 127|0);
 $5 = (($nameQ$i) + 127|0);
 $6 = (($nameQx$i) + 127|0);
 $7 = (($nameQy$i) + 127|0);
 $8 = (($nameQz$i) + 127|0);
 $9 = (($nameQw$i) + 127|0);
 $i$015$i = 14;$j$016$i = 0;
 while(1) {
  $10 = (793976 + ($j$016$i<<4)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__ZN7mecanim5human8BoneNameEj($11)|0);
  (_strncpy(($0|0),($12|0),128)|0);
  HEAP8[$1>>0] = 0;
  $13 = (_strlen(($0|0))|0);
  $14 = (128 - ($13))|0;
  (_strncat($0,794040,$14)|0);
  HEAP8[$1>>0] = 0;
  (_strncpy(($nameTx$i|0),($0|0),128)|0);
  HEAP8[$2>>0] = 0;
  $15 = (_strlen(($nameTx$i|0))|0);
  $16 = (128 - ($15))|0;
  (_strncat($nameTx$i,794048,$16)|0);
  HEAP8[$2>>0] = 0;
  (_strncpy(($nameTy$i|0),($0|0),128)|0);
  HEAP8[$3>>0] = 0;
  $17 = (_strlen(($nameTy$i|0))|0);
  $18 = (128 - ($17))|0;
  (_strncat($nameTy$i,794056,$18)|0);
  HEAP8[$3>>0] = 0;
  (_strncpy(($nameTz$i|0),($0|0),128)|0);
  HEAP8[$4>>0] = 0;
  $19 = (_strlen(($nameTz$i|0))|0);
  $20 = (128 - ($19))|0;
  (_strncat($nameTz$i,794064,$20)|0);
  HEAP8[$4>>0] = 0;
  $21 = (__ZN7mecanim5human8BoneNameEj($11)|0);
  (_strncpy(($nameQ$i|0),($21|0),128)|0);
  HEAP8[$5>>0] = 0;
  $22 = (_strlen(($nameQ$i|0))|0);
  $23 = (128 - ($22))|0;
  (_strncat($nameQ$i,794072,$23)|0);
  HEAP8[$5>>0] = 0;
  (_strncpy(($nameQx$i|0),($nameQ$i|0),128)|0);
  HEAP8[$6>>0] = 0;
  $24 = (_strlen(($nameQx$i|0))|0);
  $25 = (128 - ($24))|0;
  (_strncat($nameQx$i,794048,$25)|0);
  HEAP8[$6>>0] = 0;
  (_strncpy(($nameQy$i|0),($nameQ$i|0),128)|0);
  HEAP8[$7>>0] = 0;
  $26 = (_strlen(($nameQy$i|0))|0);
  $27 = (128 - ($26))|0;
  (_strncat($nameQy$i,794056,$27)|0);
  HEAP8[$7>>0] = 0;
  (_strncpy(($nameQz$i|0),($nameQ$i|0),128)|0);
  HEAP8[$8>>0] = 0;
  $28 = (_strlen(($nameQz$i|0))|0);
  $29 = (128 - ($28))|0;
  (_strncat($nameQz$i,794064,$29)|0);
  HEAP8[$8>>0] = 0;
  (_strncpy(($nameQw$i|0),($nameQ$i|0),128)|0);
  HEAP8[$9>>0] = 0;
  $30 = (_strlen(($nameQw$i|0))|0);
  $31 = (128 - ($30))|0;
  (_strncat($nameQw$i,794080,$31)|0);
  HEAP8[$9>>0] = 0;
  $32 = (($i$015$i) + 1)|0;
  $33 = (775176 + ($i$015$i<<7)|0);
  (_strncpy(($33|0),($nameTx$i|0),128)|0);
  $34 = ((775176 + ($i$015$i<<7)|0) + 127|0);
  HEAP8[$34>>0] = 0;
  $35 = (($i$015$i) + 2)|0;
  $36 = (775176 + ($32<<7)|0);
  (_strncpy(($36|0),($nameTy$i|0),128)|0);
  $37 = ((775176 + ($32<<7)|0) + 127|0);
  HEAP8[$37>>0] = 0;
  $38 = (($i$015$i) + 3)|0;
  $39 = (775176 + ($35<<7)|0);
  (_strncpy(($39|0),($nameTz$i|0),128)|0);
  $40 = ((775176 + ($35<<7)|0) + 127|0);
  HEAP8[$40>>0] = 0;
  $41 = (($i$015$i) + 4)|0;
  $42 = (775176 + ($38<<7)|0);
  (_strncpy(($42|0),($nameQx$i|0),128)|0);
  $43 = ((775176 + ($38<<7)|0) + 127|0);
  HEAP8[$43>>0] = 0;
  $44 = (($i$015$i) + 5)|0;
  $45 = (775176 + ($41<<7)|0);
  (_strncpy(($45|0),($nameQy$i|0),128)|0);
  $46 = ((775176 + ($41<<7)|0) + 127|0);
  HEAP8[$46>>0] = 0;
  $47 = (($i$015$i) + 6)|0;
  $48 = (775176 + ($44<<7)|0);
  (_strncpy(($48|0),($nameQz$i|0),128)|0);
  $49 = ((775176 + ($44<<7)|0) + 127|0);
  HEAP8[$49>>0] = 0;
  $50 = (($i$015$i) + 7)|0;
  $51 = (775176 + ($47<<7)|0);
  (_strncpy(($51|0),($nameQw$i|0),128)|0);
  $52 = ((775176 + ($47<<7)|0) + 127|0);
  HEAP8[$52>>0] = 0;
  $53 = (($j$016$i) + 1)|0;
  $exitcond21$i = ($53|0)==(4);
  if ($exitcond21$i) {
   $i$113$i = 42;$j$114$i = 0;
   break;
  } else {
   $i$015$i = $50;$j$016$i = $53;
  }
 }
 while(1) {
  $55 = (($i$113$i) + 1)|0;
  $56 = (__ZN7mecanim5human10MuscleNameEj($j$114$i)|0);
  $57 = (775176 + ($i$113$i<<7)|0);
  (_strncpy(($57|0),($56|0),128)|0);
  $58 = ((775176 + ($i$113$i<<7)|0) + 127|0);
  HEAP8[$58>>0] = 0;
  $59 = (($j$114$i) + 1)|0;
  $exitcond20$i = ($59|0)==(52);
  if ($exitcond20$i) {
   break;
  } else {
   $i$113$i = $55;$j$114$i = $59;
  }
 }
 $54 = (($0) + 127|0);
 $f$011$i = 0;$i$210$i = 94;
 while(1) {
  $d$08$i = 0;$i$37$i = $i$210$i;
  while(1) {
   (_strncpy(($0|0),(794088|0),128)|0);
   HEAP8[$54>>0] = 0;
   $61 = (__ZN7mecanim4hand10FingerNameEj($f$011$i)|0);
   $62 = (_strlen(($0|0))|0);
   $63 = (128 - ($62))|0;
   (_strncat($0,$61,$63)|0);
   HEAP8[$54>>0] = 0;
   $64 = (_strlen(($0|0))|0);
   $65 = (128 - ($64))|0;
   (_strncat($0,794104,$65)|0);
   HEAP8[$54>>0] = 0;
   $66 = (__ZN7mecanim4hand13FingerDoFNameEj($d$08$i)|0);
   $67 = (_strlen(($0|0))|0);
   $68 = (128 - ($67))|0;
   (_strncat($0,$66,$68)|0);
   HEAP8[$54>>0] = 0;
   $69 = (($i$37$i) + 1)|0;
   $70 = (775176 + ($i$37$i<<7)|0);
   (_strncpy(($70|0),($0|0),128)|0);
   $71 = ((775176 + ($i$37$i<<7)|0) + 127|0);
   HEAP8[$71>>0] = 0;
   $72 = (($d$08$i) + 1)|0;
   $exitcond18$i = ($72|0)==(4);
   if ($exitcond18$i) {
    break;
   } else {
    $d$08$i = $72;$i$37$i = $69;
   }
  }
  $73 = (($i$210$i) + 4)|0;
  $74 = (($f$011$i) + 1)|0;
  $exitcond19$i = ($74|0)==(5);
  if ($exitcond19$i) {
   break;
  } else {
   $f$011$i = $74;$i$210$i = $73;
  }
 }
 $60 = (($0) + 127|0);
 $f1$05$i = 0;$i$44$i = 114;
 while(1) {
  $d2$02$i = 0;$i$51$i = $i$44$i;
  while(1) {
   (_strncpy(($0|0),(794112|0),128)|0);
   HEAP8[$60>>0] = 0;
   $75 = (__ZN7mecanim4hand10FingerNameEj($f1$05$i)|0);
   $76 = (_strlen(($0|0))|0);
   $77 = (128 - ($76))|0;
   (_strncat($0,$75,$77)|0);
   HEAP8[$60>>0] = 0;
   $78 = (_strlen(($0|0))|0);
   $79 = (128 - ($78))|0;
   (_strncat($0,794104,$79)|0);
   HEAP8[$60>>0] = 0;
   $80 = (__ZN7mecanim4hand13FingerDoFNameEj($d2$02$i)|0);
   $81 = (_strlen(($0|0))|0);
   $82 = (128 - ($81))|0;
   (_strncat($0,$80,$82)|0);
   HEAP8[$60>>0] = 0;
   $83 = (($i$51$i) + 1)|0;
   $84 = (775176 + ($i$51$i<<7)|0);
   (_strncpy(($84|0),($0|0),128)|0);
   $85 = ((775176 + ($i$51$i<<7)|0) + 127|0);
   HEAP8[$85>>0] = 0;
   $86 = (($d2$02$i) + 1)|0;
   $exitcond$i = ($86|0)==(4);
   if ($exitcond$i) {
    break;
   } else {
    $d2$02$i = $86;$i$51$i = $83;
   }
  }
  $87 = (($i$44$i) + 4)|0;
  $88 = (($f1$05$i) + 1)|0;
  $exitcond17$i = ($88|0)==(5);
  if ($exitcond17$i) {
   break;
  } else {
   $f1$05$i = $88;$i$44$i = $87;
  }
 }
 (_strncpy((((775176 + 17152|0))|0),(794128|0),128)|0);
 HEAP8[((775176 + 17279|0))>>0] = 0;
 (_strncpy((((775176 + 17280|0))|0),(794144|0),128)|0);
 HEAP8[((775176 + 17407|0))>>0] = 0;
 (_strncpy((((775176 + 17408|0))|0),(794160|0),128)|0);
 HEAP8[((775176 + 17535|0))>>0] = 0;
 $i$01$i = 0;
 while(1) {
  $89 = (792712 + ($i$01$i<<3)|0);
  HEAP32[$89>>2] = $i$01$i;
  $$02$i$i$i$i$i = -1;$i$03$i$i$i$i$i = 0;$reflection$01$i$i$i$i$i = 0;
  while(1) {
   $90 = $$02$i$i$i$i$i & 1;
   $91 = ($90|0)==(0);
   if ($91) {
    $reflection$1$i$i$i$i$i = $reflection$01$i$i$i$i$i;
   } else {
    $92 = (31 - ($i$03$i$i$i$i$i))|0;
    $93 = 1 << $92;
    $94 = $93 | $reflection$01$i$i$i$i$i;
    $reflection$1$i$i$i$i$i = $94;
   }
   $95 = (($i$03$i$i$i$i$i) + 1)|0;
   $96 = $$02$i$i$i$i$i >>> 1;
   $exitcond$i$i$i$i$i = ($95|0)==(32);
   if ($exitcond$i$i$i$i$i) {
    break;
   } else {
    $$02$i$i$i$i$i = $96;$i$03$i$i$i$i$i = $95;$reflection$01$i$i$i$i$i = $reflection$1$i$i$i$i$i;
   }
  }
  $97 = (775176 + ($i$01$i<<7)|0);
  $98 = (_strlen(($97|0))|0);
  $99 = ((775176 + ($i$01$i<<7)|0) + ($98)|0);
  $100 = ($98|0)>(0);
  if ($100) {
   $104 = $reflection$1$i$i$i$i$i;$p$01$i$i$i$i = $97;
   while(1) {
    $101 = HEAP8[$p$01$i$i$i$i>>0]|0;
    $102 = $101&255;
    $103 = $104 >>> 8;
    $$masked$i$i$i$i = $104 & 255;
    $105 = $102 ^ $$masked$i$i$i$i;
    $106 = (584048 + ($105<<2)|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = $107 ^ $103;
    $109 = (($p$01$i$i$i$i) + 1|0);
    $exitcond$i$i$i$i = ($109|0)==($99|0);
    if ($exitcond$i$i$i$i) {
     $111 = $108;
     break;
    } else {
     $104 = $108;$p$01$i$i$i$i = $109;
    }
   }
  } else {
   $111 = $reflection$1$i$i$i$i$i;
  }
  $110 = $111 ^ -1;
  $112 = ((792712 + ($i$01$i<<3)|0) + 4|0);
  HEAP32[$112>>2] = $110;
  $113 = (($i$01$i) + 1)|0;
  $exitcond$i1 = ($113|0)==(137);
  if ($exitcond$i1) {
   break;
  } else {
   $i$01$i = $113;
  }
 }
 HEAP32[$0>>2] = 2593;
 __ZNSt3__16__sortIRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEvT0_S8_T_(792712,((792712 + 1096|0)),$0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation15FindMuscleIndexEj($id) {
 $id = $id|0;
 var $$0 = 0, $$01$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$01$i = 792712;
 while(1) {
  $2 = (($$01$i) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==($id|0);
  $1 = (($$01$i) + 8|0);
  if ($4) {
   break;
  }
  $0 = ($1|0)==(((792712 + 1096|0))|0);
  if ($0) {
   $$0 = -1;
   label = 5;
   break;
  } else {
   $$01$i = $1;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$$01$i>>2]|0;
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7mecanim9animation17MotionOutputClearEPNS0_12MotionOutputE($output) {
 $output = $output|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($output) + 84|0);
 $1 = (($output) + 112|0);
 dest=$output+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($output) + 116|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($output) + 120|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($output) + 124|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($output) + 128|0);
 HEAPF32[$5>>2] = Math_fround(1.0);
 $6 = (($output) + 132|0);
 $7 = (($output) + 160|0);
 ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;HEAP32[$6+16>>2]=0|0;HEAP32[$6+20>>2]=0|0;HEAP32[$6+24>>2]=0|0;
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($output) + 164|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($output) + 168|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($output) + 172|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($output) + 176|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($output) + 180|0);
 $13 = (($output) + 208|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;HEAP32[$12+20>>2]=0|0;HEAP32[$12+24>>2]=0|0;
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($output) + 212|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($output) + 216|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($output) + 220|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($output) + 224|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($output) + 228|0);
 $19 = (($output) + 256|0);
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;HEAP32[$18+24>>2]=0|0;
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($output) + 260|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($output) + 264|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($output) + 268|0);
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($output) + 272|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($output) + 276|0);
 $25 = (($output) + 304|0);
 ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;HEAP32[$24+12>>2]=0|0;HEAP32[$24+16>>2]=0|0;HEAP32[$24+20>>2]=0|0;HEAP32[$24+24>>2]=0|0;
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($output) + 308|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($output) + 312|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($output) + 316|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($output) + 320|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = (($output) + 324|0);
 $31 = (($output) + 352|0);
 ;HEAP32[$30+0>>2]=0|0;HEAP32[$30+4>>2]=0|0;HEAP32[$30+8>>2]=0|0;HEAP32[$30+12>>2]=0|0;HEAP32[$30+16>>2]=0|0;HEAP32[$30+20>>2]=0|0;HEAP32[$30+24>>2]=0|0;
 HEAPF32[$31>>2] = Math_fround(1.0);
 $32 = (($output) + 356|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $33 = (($output) + 360|0);
 HEAPF32[$33>>2] = Math_fround(1.0);
 $34 = (($output) + 364|0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 $35 = (($output) + 368|0);
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($output) + 372|0);
 $37 = (($output) + 400|0);
 ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;HEAP32[$36+16>>2]=0|0;HEAP32[$36+20>>2]=0|0;HEAP32[$36+24>>2]=0|0;
 HEAPF32[$37>>2] = Math_fround(1.0);
 $38 = (($output) + 404|0);
 HEAPF32[$38>>2] = Math_fround(1.0);
 $39 = (($output) + 408|0);
 HEAPF32[$39>>2] = Math_fround(1.0);
 $40 = (($output) + 412|0);
 HEAPF32[$40>>2] = Math_fround(1.0);
 $41 = (($output) + 416|0);
 HEAPF32[$41>>2] = Math_fround(1.0);
 $42 = (($output) + 420|0);
 dest=$42+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation16MotionOutputCopyEPNS0_12MotionOutputEPKS1_bbRKNS_6bitsetILj59EEE($output,$motion,$hasRootMotion,$isHuman,$poseMask) {
 $output = $output|0;
 $motion = $motion|0;
 $hasRootMotion = $hasRootMotion|0;
 $isHuman = $isHuman|0;
 $poseMask = $poseMask|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = 0, $18 = Math_fround(0), $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0;
 var $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = Math_fround(0);
 var $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0);
 var $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = Math_fround(0), $313 = 0;
 var $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0;
 var $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  if ($hasRootMotion) {
   label = 4;
  } else {
   if ($isHuman) {
    $0 = HEAP32[$poseMask>>2]|0;
    $1 = $0 & 1;
    $2 = ($1|0)==(0);
    if ($2) {
     break;
    } else {
     label = 4;
     break;
    }
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $3 = (($motion) + 4|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($motion) + 8|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($motion) + 12|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = (($motion) + 16|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($output) + 4|0);
  HEAPF32[$11>>2] = $4;
  $12 = (($output) + 8|0);
  HEAPF32[$12>>2] = $6;
  $13 = (($output) + 12|0);
  HEAPF32[$13>>2] = $8;
  $14 = (($output) + 16|0);
  HEAPF32[$14>>2] = $10;
  $15 = (($motion) + 20|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = (($motion) + 24|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($motion) + 28|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($motion) + 32|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($output) + 20|0);
  HEAPF32[$23>>2] = $16;
  $24 = (($output) + 24|0);
  HEAPF32[$24>>2] = $18;
  $25 = (($output) + 28|0);
  HEAPF32[$25>>2] = $20;
  $26 = (($output) + 32|0);
  HEAPF32[$26>>2] = $22;
  $27 = (($motion) + 420|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($output) + 420|0);
  HEAPF32[$29>>2] = $28;
 }
 if ($hasRootMotion) {
  $30 = (($motion) + 84|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($motion) + 88|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($motion) + 92|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = (($motion) + 96|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($output) + 84|0);
  HEAPF32[$38>>2] = $31;
  $39 = (($output) + 88|0);
  HEAPF32[$39>>2] = $33;
  $40 = (($output) + 92|0);
  HEAPF32[$40>>2] = $35;
  $41 = (($output) + 96|0);
  HEAPF32[$41>>2] = $37;
  $42 = (($motion) + 100|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = (($motion) + 104|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = (($motion) + 108|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = (($motion) + 112|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($output) + 100|0);
  HEAPF32[$50>>2] = $43;
  $51 = (($output) + 104|0);
  HEAPF32[$51>>2] = $45;
  $52 = (($output) + 108|0);
  HEAPF32[$52>>2] = $47;
  $53 = (($output) + 112|0);
  HEAPF32[$53>>2] = $49;
  $54 = (($motion) + 116|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($motion) + 120|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $58 = (($motion) + 124|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = (($motion) + 128|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($output) + 116|0);
  HEAPF32[$62>>2] = $55;
  $63 = (($output) + 120|0);
  HEAPF32[$63>>2] = $57;
  $64 = (($output) + 124|0);
  HEAPF32[$64>>2] = $59;
  $65 = (($output) + 128|0);
  HEAPF32[$65>>2] = $61;
  $66 = (($motion) + 132|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = (($motion) + 136|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = (($motion) + 140|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = (($motion) + 144|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = (($output) + 132|0);
  HEAPF32[$74>>2] = $67;
  $75 = (($output) + 136|0);
  HEAPF32[$75>>2] = $69;
  $76 = (($output) + 140|0);
  HEAPF32[$76>>2] = $71;
  $77 = (($output) + 144|0);
  HEAPF32[$77>>2] = $73;
  $78 = (($motion) + 148|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = (($motion) + 152|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($motion) + 156|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($motion) + 160|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = (($output) + 148|0);
  HEAPF32[$86>>2] = $79;
  $87 = (($output) + 152|0);
  HEAPF32[$87>>2] = $81;
  $88 = (($output) + 156|0);
  HEAPF32[$88>>2] = $83;
  $89 = (($output) + 160|0);
  HEAPF32[$89>>2] = $85;
  $90 = (($motion) + 164|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = (($motion) + 168|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = (($motion) + 172|0);
  $95 = Math_fround(HEAPF32[$94>>2]);
  $96 = (($motion) + 176|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = (($output) + 164|0);
  HEAPF32[$98>>2] = $91;
  $99 = (($output) + 168|0);
  HEAPF32[$99>>2] = $93;
  $100 = (($output) + 172|0);
  HEAPF32[$100>>2] = $95;
  $101 = (($output) + 176|0);
  HEAPF32[$101>>2] = $97;
  $102 = (($motion) + 180|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = (($motion) + 184|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = (($motion) + 188|0);
  $107 = Math_fround(HEAPF32[$106>>2]);
  $108 = (($motion) + 192|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($output) + 180|0);
  HEAPF32[$110>>2] = $103;
  $111 = (($output) + 184|0);
  HEAPF32[$111>>2] = $105;
  $112 = (($output) + 188|0);
  HEAPF32[$112>>2] = $107;
  $113 = (($output) + 192|0);
  HEAPF32[$113>>2] = $109;
  $114 = (($motion) + 196|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($motion) + 200|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = (($motion) + 204|0);
  $119 = Math_fround(HEAPF32[$118>>2]);
  $120 = (($motion) + 208|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = (($output) + 196|0);
  HEAPF32[$122>>2] = $115;
  $123 = (($output) + 200|0);
  HEAPF32[$123>>2] = $117;
  $124 = (($output) + 204|0);
  HEAPF32[$124>>2] = $119;
  $125 = (($output) + 208|0);
  HEAPF32[$125>>2] = $121;
  $126 = (($motion) + 212|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = (($motion) + 216|0);
  $129 = Math_fround(HEAPF32[$128>>2]);
  $130 = (($motion) + 220|0);
  $131 = Math_fround(HEAPF32[$130>>2]);
  $132 = (($motion) + 224|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = (($output) + 212|0);
  HEAPF32[$134>>2] = $127;
  $135 = (($output) + 216|0);
  HEAPF32[$135>>2] = $129;
  $136 = (($output) + 220|0);
  HEAPF32[$136>>2] = $131;
  $137 = (($output) + 224|0);
  HEAPF32[$137>>2] = $133;
 }
 if (!($isHuman)) {
  STACKTOP = sp;return;
 }
 $138 = HEAP32[$poseMask>>2]|0;
 $139 = $138 & 1;
 $140 = ($139|0)==(0);
 if (!($140)) {
  $141 = (($motion) + 228|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($motion) + 232|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = (($motion) + 236|0);
  $146 = Math_fround(HEAPF32[$145>>2]);
  $147 = (($motion) + 240|0);
  $148 = Math_fround(HEAPF32[$147>>2]);
  $149 = (($output) + 228|0);
  HEAPF32[$149>>2] = $142;
  $150 = (($output) + 232|0);
  HEAPF32[$150>>2] = $144;
  $151 = (($output) + 236|0);
  HEAPF32[$151>>2] = $146;
  $152 = (($output) + 240|0);
  HEAPF32[$152>>2] = $148;
  $153 = (($motion) + 244|0);
  $154 = Math_fround(HEAPF32[$153>>2]);
  $155 = (($motion) + 248|0);
  $156 = Math_fround(HEAPF32[$155>>2]);
  $157 = (($motion) + 252|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = (($motion) + 256|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = (($output) + 244|0);
  HEAPF32[$161>>2] = $154;
  $162 = (($output) + 248|0);
  HEAPF32[$162>>2] = $156;
  $163 = (($output) + 252|0);
  HEAPF32[$163>>2] = $158;
  $164 = (($output) + 256|0);
  HEAPF32[$164>>2] = $160;
  $165 = (($motion) + 260|0);
  $166 = Math_fround(HEAPF32[$165>>2]);
  $167 = (($motion) + 264|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($motion) + 268|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = (($motion) + 272|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = (($output) + 260|0);
  HEAPF32[$173>>2] = $166;
  $174 = (($output) + 264|0);
  HEAPF32[$174>>2] = $168;
  $175 = (($output) + 268|0);
  HEAPF32[$175>>2] = $170;
  $176 = (($output) + 272|0);
  HEAPF32[$176>>2] = $172;
  $177 = (($motion) + 372|0);
  $178 = Math_fround(HEAPF32[$177>>2]);
  $179 = (($motion) + 376|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = (($motion) + 380|0);
  $182 = Math_fround(HEAPF32[$181>>2]);
  $183 = (($motion) + 384|0);
  $184 = Math_fround(HEAPF32[$183>>2]);
  $185 = (($output) + 372|0);
  HEAPF32[$185>>2] = $178;
  $186 = (($output) + 376|0);
  HEAPF32[$186>>2] = $180;
  $187 = (($output) + 380|0);
  HEAPF32[$187>>2] = $182;
  $188 = (($output) + 384|0);
  HEAPF32[$188>>2] = $184;
  $189 = (($motion) + 388|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = (($motion) + 392|0);
  $192 = Math_fround(HEAPF32[$191>>2]);
  $193 = (($motion) + 396|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = (($motion) + 400|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = (($output) + 388|0);
  HEAPF32[$197>>2] = $190;
  $198 = (($output) + 392|0);
  HEAPF32[$198>>2] = $192;
  $199 = (($output) + 396|0);
  HEAPF32[$199>>2] = $194;
  $200 = (($output) + 400|0);
  HEAPF32[$200>>2] = $196;
  $201 = (($motion) + 404|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($motion) + 408|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = (($motion) + 412|0);
  $206 = Math_fround(HEAPF32[$205>>2]);
  $207 = (($motion) + 416|0);
  $208 = Math_fround(HEAPF32[$207>>2]);
  $209 = (($output) + 404|0);
  HEAPF32[$209>>2] = $202;
  $210 = (($output) + 408|0);
  HEAPF32[$210>>2] = $204;
  $211 = (($output) + 412|0);
  HEAPF32[$211>>2] = $206;
  $212 = (($output) + 416|0);
  HEAPF32[$212>>2] = $208;
 }
 $213 = (__ZN7mecanim5human19MaskHasLeftFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
 if ($213) {
  $214 = (($motion) + 276|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($motion) + 280|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($motion) + 284|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = (($motion) + 288|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = (($output) + 276|0);
  HEAPF32[$222>>2] = $215;
  $223 = (($output) + 280|0);
  HEAPF32[$223>>2] = $217;
  $224 = (($output) + 284|0);
  HEAPF32[$224>>2] = $219;
  $225 = (($output) + 288|0);
  HEAPF32[$225>>2] = $221;
  $226 = (($motion) + 292|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = (($motion) + 296|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = (($motion) + 300|0);
  $231 = Math_fround(HEAPF32[$230>>2]);
  $232 = (($motion) + 304|0);
  $233 = Math_fround(HEAPF32[$232>>2]);
  $234 = (($output) + 292|0);
  HEAPF32[$234>>2] = $227;
  $235 = (($output) + 296|0);
  HEAPF32[$235>>2] = $229;
  $236 = (($output) + 300|0);
  HEAPF32[$236>>2] = $231;
  $237 = (($output) + 304|0);
  HEAPF32[$237>>2] = $233;
  $238 = (($motion) + 308|0);
  $239 = Math_fround(HEAPF32[$238>>2]);
  $240 = (($motion) + 312|0);
  $241 = Math_fround(HEAPF32[$240>>2]);
  $242 = (($motion) + 316|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = (($motion) + 320|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = (($output) + 308|0);
  HEAPF32[$246>>2] = $239;
  $247 = (($output) + 312|0);
  HEAPF32[$247>>2] = $241;
  $248 = (($output) + 316|0);
  HEAPF32[$248>>2] = $243;
  $249 = (($output) + 320|0);
  HEAPF32[$249>>2] = $245;
 }
 $250 = (__ZN7mecanim5human20MaskHasRightFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
 if ($250) {
  $251 = (($motion) + 324|0);
  $252 = Math_fround(HEAPF32[$251>>2]);
  $253 = (($motion) + 328|0);
  $254 = Math_fround(HEAPF32[$253>>2]);
  $255 = (($motion) + 332|0);
  $256 = Math_fround(HEAPF32[$255>>2]);
  $257 = (($motion) + 336|0);
  $258 = Math_fround(HEAPF32[$257>>2]);
  $259 = (($output) + 324|0);
  HEAPF32[$259>>2] = $252;
  $260 = (($output) + 328|0);
  HEAPF32[$260>>2] = $254;
  $261 = (($output) + 332|0);
  HEAPF32[$261>>2] = $256;
  $262 = (($output) + 336|0);
  HEAPF32[$262>>2] = $258;
  $263 = (($motion) + 340|0);
  $264 = Math_fround(HEAPF32[$263>>2]);
  $265 = (($motion) + 344|0);
  $266 = Math_fround(HEAPF32[$265>>2]);
  $267 = (($motion) + 348|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = (($motion) + 352|0);
  $270 = Math_fround(HEAPF32[$269>>2]);
  $271 = (($output) + 340|0);
  HEAPF32[$271>>2] = $264;
  $272 = (($output) + 344|0);
  HEAPF32[$272>>2] = $266;
  $273 = (($output) + 348|0);
  HEAPF32[$273>>2] = $268;
  $274 = (($output) + 352|0);
  HEAPF32[$274>>2] = $270;
  $275 = (($motion) + 356|0);
  $276 = Math_fround(HEAPF32[$275>>2]);
  $277 = (($motion) + 360|0);
  $278 = Math_fround(HEAPF32[$277>>2]);
  $279 = (($motion) + 364|0);
  $280 = Math_fround(HEAPF32[$279>>2]);
  $281 = (($motion) + 368|0);
  $282 = Math_fround(HEAPF32[$281>>2]);
  $283 = (($output) + 356|0);
  HEAPF32[$283>>2] = $276;
  $284 = (($output) + 360|0);
  HEAPF32[$284>>2] = $278;
  $285 = (($output) + 364|0);
  HEAPF32[$285>>2] = $280;
  $286 = (($output) + 368|0);
  HEAPF32[$286>>2] = $282;
 }
 $287 = (($motion) + 424|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $289 = (($motion) + 428|0);
 $290 = Math_fround(HEAPF32[$289>>2]);
 $291 = (($motion) + 432|0);
 $292 = Math_fround(HEAPF32[$291>>2]);
 $293 = (($motion) + 436|0);
 $294 = Math_fround(HEAPF32[$293>>2]);
 $295 = (($output) + 424|0);
 HEAPF32[$295>>2] = $288;
 $296 = (($output) + 428|0);
 HEAPF32[$296>>2] = $290;
 $297 = (($output) + 432|0);
 HEAPF32[$297>>2] = $292;
 $298 = (($output) + 436|0);
 HEAPF32[$298>>2] = $294;
 $299 = (($motion) + 440|0);
 $300 = Math_fround(HEAPF32[$299>>2]);
 $301 = (($motion) + 444|0);
 $302 = Math_fround(HEAPF32[$301>>2]);
 $303 = (($motion) + 448|0);
 $304 = Math_fround(HEAPF32[$303>>2]);
 $305 = (($motion) + 452|0);
 $306 = Math_fround(HEAPF32[$305>>2]);
 $307 = (($output) + 440|0);
 HEAPF32[$307>>2] = $300;
 $308 = (($output) + 444|0);
 HEAPF32[$308>>2] = $302;
 $309 = (($output) + 448|0);
 HEAPF32[$309>>2] = $304;
 $310 = (($output) + 452|0);
 HEAPF32[$310>>2] = $306;
 $311 = (($motion) + 456|0);
 $312 = Math_fround(HEAPF32[$311>>2]);
 $313 = (($output) + 456|0);
 HEAPF32[$313>>2] = $312;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17MotionOutputBlendEPNS0_12MotionOutputEPS2_PfjbbRKNS_6bitsetILj59EEE($output,$outputArray,$weight,$count,$hasRootMotion,$isHuman,$poseMask) {
 $output = $output|0;
 $outputArray = $outputArray|0;
 $weight = $weight|0;
 $count = $count|0;
 $hasRootMotion = $hasRootMotion|0;
 $isHuman = $isHuman|0;
 $poseMask = $poseMask|0;
 var $$old = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0);
 var $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = 0, $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = 0, $1030 = Math_fround(0), $1031 = Math_fround(0);
 var $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = Math_fround(0);
 var $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = 0, $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = 0, $1067 = 0, $1068 = 0;
 var $1069 = Math_fround(0), $107 = 0, $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = Math_fround(0), $1076 = Math_fround(0), $1077 = Math_fround(0), $1078 = Math_fround(0), $1079 = Math_fround(0), $108 = 0, $1080 = Math_fround(0), $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = Math_fround(0), $1084 = Math_fround(0), $1085 = Math_fround(0), $1086 = Math_fround(0);
 var $1087 = Math_fround(0), $1088 = Math_fround(0), $1089 = Math_fround(0), $109 = Math_fround(0), $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0);
 var $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = 0, $1110 = Math_fround(0), $1111 = 0, $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0);
 var $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0), $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = Math_fround(0), $1133 = 0, $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = 0;
 var $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = 0, $1156 = Math_fround(0), $1157 = Math_fround(0), $116 = Math_fround(0);
 var $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0;
 var $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0);
 var $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0);
 var $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0);
 var $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0;
 var $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0);
 var $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0;
 var $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = 0, $278 = 0, $279 = Math_fround(0);
 var $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0);
 var $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0);
 var $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = 0;
 var $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0;
 var $351 = Math_fround(0), $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = Math_fround(0);
 var $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = Math_fround(0), $373 = 0, $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = 0, $393 = 0, $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0);
 var $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0);
 var $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0);
 var $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = 0, $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = 0, $458 = Math_fround(0), $459 = 0;
 var $46 = 0, $460 = 0, $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = 0, $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $476 = Math_fround(0), $477 = Math_fround(0);
 var $478 = 0, $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = 0, $493 = Math_fround(0), $494 = Math_fround(0), $495 = 0;
 var $496 = Math_fround(0), $497 = Math_fround(0), $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = 0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = Math_fround(0), $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = 0, $522 = Math_fround(0), $523 = 0, $524 = 0, $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = 0, $534 = Math_fround(0), $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0);
 var $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = 0, $554 = Math_fround(0), $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = Math_fround(0), $559 = 0, $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = 0, $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0);
 var $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = 0, $583 = Math_fround(0), $584 = 0, $585 = 0;
 var $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = 0, $595 = Math_fround(0), $596 = Math_fround(0), $597 = 0, $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = 0, $601 = Math_fround(0), $602 = Math_fround(0);
 var $603 = 0, $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = 0, $615 = Math_fround(0), $616 = Math_fround(0), $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = 0;
 var $621 = Math_fround(0), $622 = Math_fround(0), $623 = 0, $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = 0, $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = 0;
 var $64 = 0, $640 = 0, $641 = Math_fround(0), $642 = Math_fround(0), $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = 0, $652 = Math_fround(0), $653 = Math_fround(0), $654 = 0, $655 = Math_fround(0), $656 = Math_fround(0), $657 = 0;
 var $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = 0, $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = 0, $672 = Math_fround(0), $673 = Math_fround(0), $674 = 0, $675 = Math_fround(0);
 var $676 = Math_fround(0), $677 = 0, $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = 0, $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = 0;
 var $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = 0, $702 = Math_fround(0), $703 = Math_fround(0), $704 = 0, $705 = Math_fround(0), $706 = Math_fround(0), $707 = 0, $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0);
 var $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = 0, $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = 0, $722 = Math_fround(0), $723 = Math_fround(0), $724 = 0, $725 = Math_fround(0), $726 = Math_fround(0), $727 = 0, $728 = Math_fround(0), $729 = Math_fround(0);
 var $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = Math_fround(0), $746 = 0, $747 = 0;
 var $748 = Math_fround(0), $749 = 0, $75 = 0, $750 = 0, $751 = Math_fround(0), $752 = 0, $753 = 0, $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = 0, $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = 0, $763 = Math_fround(0), $764 = Math_fround(0), $765 = 0;
 var $766 = Math_fround(0), $767 = Math_fround(0), $768 = 0, $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = 0, $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = 0, $783 = Math_fround(0);
 var $784 = Math_fround(0), $785 = 0, $786 = Math_fround(0), $787 = Math_fround(0), $788 = 0, $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0);
 var $801 = Math_fround(0), $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = Math_fround(0), $807 = 0, $808 = 0, $809 = Math_fround(0), $81 = 0, $810 = 0, $811 = 0, $812 = Math_fround(0), $813 = 0, $814 = 0, $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0);
 var $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = Math_fround(0), $825 = Math_fround(0), $826 = 0, $827 = Math_fround(0), $828 = Math_fround(0), $829 = 0, $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = 0, $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0);
 var $838 = Math_fround(0), $839 = Math_fround(0), $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = 0, $844 = Math_fround(0), $845 = Math_fround(0), $846 = 0, $847 = Math_fround(0), $848 = Math_fround(0), $849 = 0, $85 = 0, $850 = Math_fround(0), $851 = Math_fround(0), $852 = 0, $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0);
 var $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = Math_fround(0), $871 = 0, $872 = 0, $873 = Math_fround(0);
 var $874 = 0, $875 = 0, $876 = Math_fround(0), $877 = 0, $878 = 0, $879 = Math_fround(0), $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = 0, $891 = Math_fround(0);
 var $892 = Math_fround(0), $893 = 0, $894 = Math_fround(0), $895 = Math_fround(0), $896 = 0, $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = 0, $908 = Math_fround(0), $909 = Math_fround(0);
 var $91 = 0, $910 = 0, $911 = Math_fround(0), $912 = Math_fround(0), $913 = 0, $914 = Math_fround(0), $915 = Math_fround(0), $916 = 0, $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0);
 var $928 = Math_fround(0), $929 = Math_fround(0), $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = Math_fround(0), $935 = 0, $936 = 0, $937 = Math_fround(0), $938 = 0, $939 = 0, $94 = 0, $940 = Math_fround(0), $941 = 0, $942 = 0, $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0);
 var $946 = Math_fround(0), $947 = Math_fround(0), $948 = 0, $949 = Math_fround(0), $95 = 0, $950 = Math_fround(0), $951 = 0, $952 = Math_fround(0), $953 = Math_fround(0), $954 = 0, $955 = Math_fround(0), $956 = Math_fround(0), $957 = 0, $958 = Math_fround(0), $959 = Math_fround(0), $96 = 0, $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0);
 var $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = 0, $969 = Math_fround(0), $97 = 0, $970 = Math_fround(0), $971 = 0, $972 = Math_fround(0), $973 = Math_fround(0), $974 = 0, $975 = Math_fround(0), $976 = Math_fround(0), $977 = 0, $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0);
 var $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = 0, $989 = Math_fround(0), $99 = 0, $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = Math_fround(0), $999 = Math_fround(0), $exitcond = 0;
 var $exitcond341 = 0, $iter$0338 = 0, $iter$0338$us = 0, $or$cond = 0, $sumW$0$lcssa = Math_fround(0), $sumW$0339 = Math_fround(0), $sumW$0339$us = Math_fround(0), dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($output) + 4|0);
 $1 = (($output) + 8|0);
 $2 = (($output) + 12|0);
 $3 = (($output) + 16|0);
 $4 = (($output) + 20|0);
 $5 = (($output) + 24|0);
 $6 = (($output) + 28|0);
 $7 = (($output) + 32|0);
 $8 = (($output) + 84|0);
 $9 = (($output) + 88|0);
 $10 = (($output) + 92|0);
 $11 = (($output) + 96|0);
 $12 = (($output) + 100|0);
 $13 = (($output) + 104|0);
 $14 = (($output) + 108|0);
 $15 = (($output) + 112|0);
 $16 = (($output) + 116|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
 ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;HEAP32[$8+24>>2]=0|0;HEAP32[$8+28>>2]=0|0;
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($output) + 120|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($output) + 124|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($output) + 128|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($output) + 132|0);
 $21 = (($output) + 136|0);
 $22 = (($output) + 140|0);
 $23 = (($output) + 144|0);
 $24 = (($output) + 148|0);
 $25 = (($output) + 152|0);
 $26 = (($output) + 156|0);
 $27 = (($output) + 160|0);
 $28 = (($output) + 164|0);
 ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;HEAP32[$20+16>>2]=0|0;HEAP32[$20+20>>2]=0|0;HEAP32[$20+24>>2]=0|0;HEAP32[$20+28>>2]=0|0;
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($output) + 168|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = (($output) + 172|0);
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($output) + 176|0);
 HEAPF32[$31>>2] = Math_fround(1.0);
 $32 = (($output) + 180|0);
 $33 = (($output) + 184|0);
 $34 = (($output) + 188|0);
 $35 = (($output) + 192|0);
 $36 = (($output) + 196|0);
 $37 = (($output) + 200|0);
 $38 = (($output) + 204|0);
 $39 = (($output) + 208|0);
 $40 = (($output) + 212|0);
 ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;HEAP32[$32+20>>2]=0|0;HEAP32[$32+24>>2]=0|0;HEAP32[$32+28>>2]=0|0;
 HEAPF32[$40>>2] = Math_fround(1.0);
 $41 = (($output) + 216|0);
 HEAPF32[$41>>2] = Math_fround(1.0);
 $42 = (($output) + 220|0);
 HEAPF32[$42>>2] = Math_fround(1.0);
 $43 = (($output) + 224|0);
 HEAPF32[$43>>2] = Math_fround(1.0);
 $44 = (($output) + 228|0);
 $45 = (($output) + 232|0);
 $46 = (($output) + 236|0);
 $47 = (($output) + 240|0);
 $48 = (($output) + 244|0);
 $49 = (($output) + 248|0);
 $50 = (($output) + 252|0);
 $51 = (($output) + 256|0);
 $52 = (($output) + 260|0);
 ;HEAP32[$44+0>>2]=0|0;HEAP32[$44+4>>2]=0|0;HEAP32[$44+8>>2]=0|0;HEAP32[$44+12>>2]=0|0;HEAP32[$44+16>>2]=0|0;HEAP32[$44+20>>2]=0|0;HEAP32[$44+24>>2]=0|0;HEAP32[$44+28>>2]=0|0;
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($output) + 264|0);
 HEAPF32[$53>>2] = Math_fround(1.0);
 $54 = (($output) + 268|0);
 HEAPF32[$54>>2] = Math_fround(1.0);
 $55 = (($output) + 272|0);
 HEAPF32[$55>>2] = Math_fround(1.0);
 $56 = (($output) + 276|0);
 $57 = (($output) + 280|0);
 $58 = (($output) + 284|0);
 $59 = (($output) + 288|0);
 $60 = (($output) + 292|0);
 $61 = (($output) + 296|0);
 $62 = (($output) + 300|0);
 $63 = (($output) + 304|0);
 $64 = (($output) + 308|0);
 ;HEAP32[$56+0>>2]=0|0;HEAP32[$56+4>>2]=0|0;HEAP32[$56+8>>2]=0|0;HEAP32[$56+12>>2]=0|0;HEAP32[$56+16>>2]=0|0;HEAP32[$56+20>>2]=0|0;HEAP32[$56+24>>2]=0|0;HEAP32[$56+28>>2]=0|0;
 HEAPF32[$64>>2] = Math_fround(1.0);
 $65 = (($output) + 312|0);
 HEAPF32[$65>>2] = Math_fround(1.0);
 $66 = (($output) + 316|0);
 HEAPF32[$66>>2] = Math_fround(1.0);
 $67 = (($output) + 320|0);
 HEAPF32[$67>>2] = Math_fround(1.0);
 $68 = (($output) + 324|0);
 $69 = (($output) + 328|0);
 $70 = (($output) + 332|0);
 $71 = (($output) + 336|0);
 $72 = (($output) + 340|0);
 $73 = (($output) + 344|0);
 $74 = (($output) + 348|0);
 $75 = (($output) + 352|0);
 $76 = (($output) + 356|0);
 ;HEAP32[$68+0>>2]=0|0;HEAP32[$68+4>>2]=0|0;HEAP32[$68+8>>2]=0|0;HEAP32[$68+12>>2]=0|0;HEAP32[$68+16>>2]=0|0;HEAP32[$68+20>>2]=0|0;HEAP32[$68+24>>2]=0|0;HEAP32[$68+28>>2]=0|0;
 HEAPF32[$76>>2] = Math_fround(1.0);
 $77 = (($output) + 360|0);
 HEAPF32[$77>>2] = Math_fround(1.0);
 $78 = (($output) + 364|0);
 HEAPF32[$78>>2] = Math_fround(1.0);
 $79 = (($output) + 368|0);
 HEAPF32[$79>>2] = Math_fround(1.0);
 $80 = (($output) + 372|0);
 $81 = (($output) + 376|0);
 $82 = (($output) + 380|0);
 $83 = (($output) + 384|0);
 $84 = (($output) + 388|0);
 $85 = (($output) + 392|0);
 $86 = (($output) + 396|0);
 $87 = (($output) + 400|0);
 $88 = (($output) + 404|0);
 ;HEAP32[$80+0>>2]=0|0;HEAP32[$80+4>>2]=0|0;HEAP32[$80+8>>2]=0|0;HEAP32[$80+12>>2]=0|0;HEAP32[$80+16>>2]=0|0;HEAP32[$80+20>>2]=0|0;HEAP32[$80+24>>2]=0|0;HEAP32[$80+28>>2]=0|0;
 HEAPF32[$88>>2] = Math_fround(1.0);
 $89 = (($output) + 408|0);
 HEAPF32[$89>>2] = Math_fround(1.0);
 $90 = (($output) + 412|0);
 HEAPF32[$90>>2] = Math_fround(1.0);
 $91 = (($output) + 416|0);
 HEAPF32[$91>>2] = Math_fround(1.0);
 $92 = (($output) + 424|0);
 $93 = (($output) + 428|0);
 $94 = (($output) + 432|0);
 $95 = (($output) + 436|0);
 $96 = (($output) + 440|0);
 $97 = (($output) + 444|0);
 $98 = (($output) + 448|0);
 $99 = (($output) + 452|0);
 $100 = (($output) + 456|0);
 $101 = (($output) + 420|0);
 $102 = ($count|0)==(0);
 dest=$101+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 L1: do {
  if ($102) {
   $sumW$0$lcssa = Math_fround(0.0);
  } else {
   if ($hasRootMotion) {
    $iter$0338$us = 0;$sumW$0339$us = Math_fround(0.0);
    while(1) {
     $103 = (($weight) + ($iter$0338$us<<2)|0);
     $104 = Math_fround(HEAPF32[$103>>2]);
     $105 = Math_fround($sumW$0339$us + $104);
     $106 = (($outputArray) + ($iter$0338$us<<2)|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = (($107) + 4|0);
     $109 = Math_fround(HEAPF32[$108>>2]);
     $110 = Math_fround($104 * $109);
     $111 = (($107) + 8|0);
     $112 = Math_fround(HEAPF32[$111>>2]);
     $113 = Math_fround($104 * $112);
     $114 = (($107) + 12|0);
     $115 = Math_fround(HEAPF32[$114>>2]);
     $116 = Math_fround($104 * $115);
     $117 = (($107) + 16|0);
     $118 = Math_fround(HEAPF32[$117>>2]);
     $119 = Math_fround($104 * $118);
     $120 = Math_fround(HEAPF32[$0>>2]);
     $121 = Math_fround($110 + $120);
     $122 = Math_fround(HEAPF32[$1>>2]);
     $123 = Math_fround($113 + $122);
     $124 = Math_fround(HEAPF32[$2>>2]);
     $125 = Math_fround($116 + $124);
     $126 = Math_fround(HEAPF32[$3>>2]);
     $127 = Math_fround($119 + $126);
     HEAPF32[$0>>2] = $121;
     HEAPF32[$1>>2] = $123;
     HEAPF32[$2>>2] = $125;
     HEAPF32[$3>>2] = $127;
     $128 = (($107) + 20|0);
     $129 = Math_fround(HEAPF32[$128>>2]);
     $130 = Math_fround($104 * $129);
     $131 = (($107) + 24|0);
     $132 = Math_fround(HEAPF32[$131>>2]);
     $133 = Math_fround($104 * $132);
     $134 = (($107) + 28|0);
     $135 = Math_fround(HEAPF32[$134>>2]);
     $136 = Math_fround($104 * $135);
     $137 = (($107) + 32|0);
     $138 = Math_fround(HEAPF32[$137>>2]);
     $139 = Math_fround($104 * $138);
     $140 = Math_fround(HEAPF32[$4>>2]);
     $141 = Math_fround($130 + $140);
     $142 = Math_fround(HEAPF32[$5>>2]);
     $143 = Math_fround($133 + $142);
     $144 = Math_fround(HEAPF32[$6>>2]);
     $145 = Math_fround($136 + $144);
     $146 = Math_fround(HEAPF32[$7>>2]);
     $147 = Math_fround($139 + $146);
     HEAPF32[$4>>2] = $141;
     HEAPF32[$5>>2] = $143;
     HEAPF32[$6>>2] = $145;
     HEAPF32[$7>>2] = $147;
     $148 = (($107) + 420|0);
     $149 = Math_fround(HEAPF32[$148>>2]);
     $150 = Math_fround($104 * $149);
     $151 = Math_fround(HEAPF32[$101>>2]);
     $152 = Math_fround($151 + $150);
     HEAPF32[$101>>2] = $152;
     $153 = (($outputArray) + ($iter$0338$us<<2)|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (($154) + 84|0);
     $156 = Math_fround(HEAPF32[$155>>2]);
     $157 = Math_fround($104 * $156);
     $158 = (($154) + 88|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = Math_fround($104 * $159);
     $161 = (($154) + 92|0);
     $162 = Math_fround(HEAPF32[$161>>2]);
     $163 = Math_fround($104 * $162);
     $164 = (($154) + 96|0);
     $165 = Math_fround(HEAPF32[$164>>2]);
     $166 = Math_fround($104 * $165);
     $167 = Math_fround(HEAPF32[$8>>2]);
     $168 = Math_fround($157 + $167);
     $169 = Math_fround(HEAPF32[$9>>2]);
     $170 = Math_fround($160 + $169);
     $171 = Math_fround(HEAPF32[$10>>2]);
     $172 = Math_fround($163 + $171);
     $173 = Math_fround(HEAPF32[$11>>2]);
     $174 = Math_fround($166 + $173);
     HEAPF32[$8>>2] = $168;
     HEAPF32[$9>>2] = $170;
     HEAPF32[$10>>2] = $172;
     HEAPF32[$11>>2] = $174;
     $175 = (($154) + 100|0);
     $176 = Math_fround(HEAPF32[$175>>2]);
     $177 = Math_fround($104 * $176);
     $178 = (($154) + 104|0);
     $179 = Math_fround(HEAPF32[$178>>2]);
     $180 = Math_fround($104 * $179);
     $181 = (($154) + 108|0);
     $182 = Math_fround(HEAPF32[$181>>2]);
     $183 = Math_fround($104 * $182);
     $184 = (($154) + 112|0);
     $185 = Math_fround(HEAPF32[$184>>2]);
     $186 = Math_fround($104 * $185);
     $187 = Math_fround(HEAPF32[$12>>2]);
     $188 = Math_fround($187 * $176);
     $189 = Math_fround(HEAPF32[$13>>2]);
     $190 = Math_fround($189 * $179);
     $191 = Math_fround(HEAPF32[$14>>2]);
     $192 = Math_fround($191 * $182);
     $193 = Math_fround(HEAPF32[$15>>2]);
     $194 = Math_fround($193 * $185);
     $195 = Math_fround($188 + $190);
     $196 = Math_fround($192 + $194);
     $197 = Math_fround($195 + $196);
     $198 = (HEAPF32[tempDoublePtr>>2]=$177,HEAP32[tempDoublePtr>>2]|0);
     $199 = (HEAPF32[tempDoublePtr>>2]=$197,HEAP32[tempDoublePtr>>2]|0);
     $200 = $199 & -2147483648;
     $201 = $200 ^ $198;
     $202 = (HEAP32[tempDoublePtr>>2]=$201,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $203 = (HEAPF32[tempDoublePtr>>2]=$180,HEAP32[tempDoublePtr>>2]|0);
     $204 = $200 ^ $203;
     $205 = (HEAP32[tempDoublePtr>>2]=$204,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $206 = (HEAPF32[tempDoublePtr>>2]=$183,HEAP32[tempDoublePtr>>2]|0);
     $207 = $200 ^ $206;
     $208 = (HEAP32[tempDoublePtr>>2]=$207,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $209 = (HEAPF32[tempDoublePtr>>2]=$186,HEAP32[tempDoublePtr>>2]|0);
     $210 = $200 ^ $209;
     $211 = (HEAP32[tempDoublePtr>>2]=$210,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $212 = Math_fround($187 + $202);
     $213 = Math_fround($189 + $205);
     $214 = Math_fround($191 + $208);
     $215 = Math_fround($193 + $211);
     HEAPF32[$12>>2] = $212;
     HEAPF32[$13>>2] = $213;
     HEAPF32[$14>>2] = $214;
     HEAPF32[$15>>2] = $215;
     $216 = (($154) + 132|0);
     $217 = Math_fround(HEAPF32[$216>>2]);
     $218 = Math_fround($104 * $217);
     $219 = (($154) + 136|0);
     $220 = Math_fround(HEAPF32[$219>>2]);
     $221 = Math_fround($104 * $220);
     $222 = (($154) + 140|0);
     $223 = Math_fround(HEAPF32[$222>>2]);
     $224 = Math_fround($104 * $223);
     $225 = (($154) + 144|0);
     $226 = Math_fround(HEAPF32[$225>>2]);
     $227 = Math_fround($104 * $226);
     $228 = Math_fround(HEAPF32[$20>>2]);
     $229 = Math_fround($218 + $228);
     $230 = Math_fround(HEAPF32[$21>>2]);
     $231 = Math_fround($221 + $230);
     $232 = Math_fround(HEAPF32[$22>>2]);
     $233 = Math_fround($224 + $232);
     $234 = Math_fround(HEAPF32[$23>>2]);
     $235 = Math_fround($227 + $234);
     HEAPF32[$20>>2] = $229;
     HEAPF32[$21>>2] = $231;
     HEAPF32[$22>>2] = $233;
     HEAPF32[$23>>2] = $235;
     $236 = (($154) + 148|0);
     $237 = Math_fround(HEAPF32[$236>>2]);
     $238 = Math_fround($104 * $237);
     $239 = (($154) + 152|0);
     $240 = Math_fround(HEAPF32[$239>>2]);
     $241 = Math_fround($104 * $240);
     $242 = (($154) + 156|0);
     $243 = Math_fround(HEAPF32[$242>>2]);
     $244 = Math_fround($104 * $243);
     $245 = (($154) + 160|0);
     $246 = Math_fround(HEAPF32[$245>>2]);
     $247 = Math_fround($104 * $246);
     $248 = Math_fround(HEAPF32[$24>>2]);
     $249 = Math_fround($248 * $237);
     $250 = Math_fround(HEAPF32[$25>>2]);
     $251 = Math_fround($250 * $240);
     $252 = Math_fround(HEAPF32[$26>>2]);
     $253 = Math_fround($252 * $243);
     $254 = Math_fround(HEAPF32[$27>>2]);
     $255 = Math_fround($254 * $246);
     $256 = Math_fround($249 + $251);
     $257 = Math_fround($253 + $255);
     $258 = Math_fround($256 + $257);
     $259 = (HEAPF32[tempDoublePtr>>2]=$238,HEAP32[tempDoublePtr>>2]|0);
     $260 = (HEAPF32[tempDoublePtr>>2]=$258,HEAP32[tempDoublePtr>>2]|0);
     $261 = $260 & -2147483648;
     $262 = $261 ^ $259;
     $263 = (HEAP32[tempDoublePtr>>2]=$262,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $264 = (HEAPF32[tempDoublePtr>>2]=$241,HEAP32[tempDoublePtr>>2]|0);
     $265 = $261 ^ $264;
     $266 = (HEAP32[tempDoublePtr>>2]=$265,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $267 = (HEAPF32[tempDoublePtr>>2]=$244,HEAP32[tempDoublePtr>>2]|0);
     $268 = $261 ^ $267;
     $269 = (HEAP32[tempDoublePtr>>2]=$268,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $270 = (HEAPF32[tempDoublePtr>>2]=$247,HEAP32[tempDoublePtr>>2]|0);
     $271 = $261 ^ $270;
     $272 = (HEAP32[tempDoublePtr>>2]=$271,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $273 = Math_fround($248 + $263);
     $274 = Math_fround($250 + $266);
     $275 = Math_fround($252 + $269);
     $276 = Math_fround($254 + $272);
     HEAPF32[$24>>2] = $273;
     HEAPF32[$25>>2] = $274;
     HEAPF32[$26>>2] = $275;
     HEAPF32[$27>>2] = $276;
     $277 = HEAP32[$153>>2]|0;
     $278 = (($277) + 180|0);
     $279 = Math_fround(HEAPF32[$278>>2]);
     $280 = Math_fround($104 * $279);
     $281 = (($277) + 184|0);
     $282 = Math_fround(HEAPF32[$281>>2]);
     $283 = Math_fround($104 * $282);
     $284 = (($277) + 188|0);
     $285 = Math_fround(HEAPF32[$284>>2]);
     $286 = Math_fround($104 * $285);
     $287 = (($277) + 192|0);
     $288 = Math_fround(HEAPF32[$287>>2]);
     $289 = Math_fround($104 * $288);
     $290 = Math_fround(HEAPF32[$32>>2]);
     $291 = Math_fround($280 + $290);
     $292 = Math_fround(HEAPF32[$33>>2]);
     $293 = Math_fround($283 + $292);
     $294 = Math_fround(HEAPF32[$34>>2]);
     $295 = Math_fround($286 + $294);
     $296 = Math_fround(HEAPF32[$35>>2]);
     $297 = Math_fround($289 + $296);
     HEAPF32[$32>>2] = $291;
     HEAPF32[$33>>2] = $293;
     HEAPF32[$34>>2] = $295;
     HEAPF32[$35>>2] = $297;
     $298 = (($277) + 196|0);
     $299 = Math_fround(HEAPF32[$298>>2]);
     $300 = Math_fround($104 * $299);
     $301 = (($277) + 200|0);
     $302 = Math_fround(HEAPF32[$301>>2]);
     $303 = Math_fround($104 * $302);
     $304 = (($277) + 204|0);
     $305 = Math_fround(HEAPF32[$304>>2]);
     $306 = Math_fround($104 * $305);
     $307 = (($277) + 208|0);
     $308 = Math_fround(HEAPF32[$307>>2]);
     $309 = Math_fround($104 * $308);
     $310 = Math_fround(HEAPF32[$36>>2]);
     $311 = Math_fround($310 * $299);
     $312 = Math_fround(HEAPF32[$37>>2]);
     $313 = Math_fround($312 * $302);
     $314 = Math_fround(HEAPF32[$38>>2]);
     $315 = Math_fround($314 * $305);
     $316 = Math_fround(HEAPF32[$39>>2]);
     $317 = Math_fround($316 * $308);
     $318 = Math_fround($311 + $313);
     $319 = Math_fround($315 + $317);
     $320 = Math_fround($318 + $319);
     $321 = (HEAPF32[tempDoublePtr>>2]=$300,HEAP32[tempDoublePtr>>2]|0);
     $322 = (HEAPF32[tempDoublePtr>>2]=$320,HEAP32[tempDoublePtr>>2]|0);
     $323 = $322 & -2147483648;
     $324 = $323 ^ $321;
     $325 = (HEAP32[tempDoublePtr>>2]=$324,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $326 = (HEAPF32[tempDoublePtr>>2]=$303,HEAP32[tempDoublePtr>>2]|0);
     $327 = $323 ^ $326;
     $328 = (HEAP32[tempDoublePtr>>2]=$327,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $329 = (HEAPF32[tempDoublePtr>>2]=$306,HEAP32[tempDoublePtr>>2]|0);
     $330 = $323 ^ $329;
     $331 = (HEAP32[tempDoublePtr>>2]=$330,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $332 = (HEAPF32[tempDoublePtr>>2]=$309,HEAP32[tempDoublePtr>>2]|0);
     $333 = $323 ^ $332;
     $334 = (HEAP32[tempDoublePtr>>2]=$333,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $335 = Math_fround($310 + $325);
     $336 = Math_fround($312 + $328);
     $337 = Math_fround($314 + $331);
     $338 = Math_fround($316 + $334);
     HEAPF32[$36>>2] = $335;
     HEAPF32[$37>>2] = $336;
     HEAPF32[$38>>2] = $337;
     HEAPF32[$39>>2] = $338;
     if ($isHuman) {
      $339 = HEAP32[$poseMask>>2]|0;
      $340 = $339 & 1;
      $341 = ($340|0)==(0);
      if (!($341)) {
       $342 = (($outputArray) + ($iter$0338$us<<2)|0);
       $343 = HEAP32[$342>>2]|0;
       $344 = (($343) + 228|0);
       $345 = Math_fround(HEAPF32[$344>>2]);
       $346 = Math_fround($104 * $345);
       $347 = (($343) + 232|0);
       $348 = Math_fround(HEAPF32[$347>>2]);
       $349 = Math_fround($104 * $348);
       $350 = (($343) + 236|0);
       $351 = Math_fround(HEAPF32[$350>>2]);
       $352 = Math_fround($104 * $351);
       $353 = (($343) + 240|0);
       $354 = Math_fround(HEAPF32[$353>>2]);
       $355 = Math_fround($104 * $354);
       $356 = Math_fround(HEAPF32[$44>>2]);
       $357 = Math_fround($346 + $356);
       $358 = Math_fround(HEAPF32[$45>>2]);
       $359 = Math_fround($349 + $358);
       $360 = Math_fround(HEAPF32[$46>>2]);
       $361 = Math_fround($352 + $360);
       $362 = Math_fround(HEAPF32[$47>>2]);
       $363 = Math_fround($355 + $362);
       HEAPF32[$44>>2] = $357;
       HEAPF32[$45>>2] = $359;
       HEAPF32[$46>>2] = $361;
       HEAPF32[$47>>2] = $363;
       $364 = (($343) + 244|0);
       $365 = Math_fround(HEAPF32[$364>>2]);
       $366 = Math_fround($104 * $365);
       $367 = (($343) + 248|0);
       $368 = Math_fround(HEAPF32[$367>>2]);
       $369 = Math_fround($104 * $368);
       $370 = (($343) + 252|0);
       $371 = Math_fround(HEAPF32[$370>>2]);
       $372 = Math_fround($104 * $371);
       $373 = (($343) + 256|0);
       $374 = Math_fround(HEAPF32[$373>>2]);
       $375 = Math_fround($104 * $374);
       $376 = Math_fround(HEAPF32[$48>>2]);
       $377 = Math_fround($376 * $365);
       $378 = Math_fround(HEAPF32[$49>>2]);
       $379 = Math_fround($378 * $368);
       $380 = Math_fround(HEAPF32[$50>>2]);
       $381 = Math_fround($380 * $371);
       $382 = Math_fround(HEAPF32[$51>>2]);
       $383 = Math_fround($382 * $374);
       $384 = Math_fround($377 + $379);
       $385 = Math_fround($381 + $383);
       $386 = Math_fround($384 + $385);
       $387 = (HEAPF32[tempDoublePtr>>2]=$366,HEAP32[tempDoublePtr>>2]|0);
       $388 = (HEAPF32[tempDoublePtr>>2]=$386,HEAP32[tempDoublePtr>>2]|0);
       $389 = $388 & -2147483648;
       $390 = $389 ^ $387;
       $391 = (HEAP32[tempDoublePtr>>2]=$390,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $392 = (HEAPF32[tempDoublePtr>>2]=$369,HEAP32[tempDoublePtr>>2]|0);
       $393 = $389 ^ $392;
       $394 = (HEAP32[tempDoublePtr>>2]=$393,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $395 = (HEAPF32[tempDoublePtr>>2]=$372,HEAP32[tempDoublePtr>>2]|0);
       $396 = $389 ^ $395;
       $397 = (HEAP32[tempDoublePtr>>2]=$396,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $398 = (HEAPF32[tempDoublePtr>>2]=$375,HEAP32[tempDoublePtr>>2]|0);
       $399 = $389 ^ $398;
       $400 = (HEAP32[tempDoublePtr>>2]=$399,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $401 = Math_fround($376 + $391);
       $402 = Math_fround($378 + $394);
       $403 = Math_fround($380 + $397);
       $404 = Math_fround($382 + $400);
       HEAPF32[$48>>2] = $401;
       HEAPF32[$49>>2] = $402;
       HEAPF32[$50>>2] = $403;
       HEAPF32[$51>>2] = $404;
       $405 = (($343) + 372|0);
       $406 = Math_fround(HEAPF32[$405>>2]);
       $407 = Math_fround($104 * $406);
       $408 = (($343) + 376|0);
       $409 = Math_fround(HEAPF32[$408>>2]);
       $410 = Math_fround($104 * $409);
       $411 = (($343) + 380|0);
       $412 = Math_fround(HEAPF32[$411>>2]);
       $413 = Math_fround($104 * $412);
       $414 = (($343) + 384|0);
       $415 = Math_fround(HEAPF32[$414>>2]);
       $416 = Math_fround($104 * $415);
       $417 = Math_fround(HEAPF32[$80>>2]);
       $418 = Math_fround($407 + $417);
       $419 = Math_fround(HEAPF32[$81>>2]);
       $420 = Math_fround($410 + $419);
       $421 = Math_fround(HEAPF32[$82>>2]);
       $422 = Math_fround($413 + $421);
       $423 = Math_fround(HEAPF32[$83>>2]);
       $424 = Math_fround($416 + $423);
       HEAPF32[$80>>2] = $418;
       HEAPF32[$81>>2] = $420;
       HEAPF32[$82>>2] = $422;
       HEAPF32[$83>>2] = $424;
       $425 = (($343) + 388|0);
       $426 = Math_fround(HEAPF32[$425>>2]);
       $427 = Math_fround($104 * $426);
       $428 = (($343) + 392|0);
       $429 = Math_fround(HEAPF32[$428>>2]);
       $430 = Math_fround($104 * $429);
       $431 = (($343) + 396|0);
       $432 = Math_fround(HEAPF32[$431>>2]);
       $433 = Math_fround($104 * $432);
       $434 = (($343) + 400|0);
       $435 = Math_fround(HEAPF32[$434>>2]);
       $436 = Math_fround($104 * $435);
       $437 = Math_fround(HEAPF32[$84>>2]);
       $438 = Math_fround($437 * $426);
       $439 = Math_fround(HEAPF32[$85>>2]);
       $440 = Math_fround($439 * $429);
       $441 = Math_fround(HEAPF32[$86>>2]);
       $442 = Math_fround($441 * $432);
       $443 = Math_fround(HEAPF32[$87>>2]);
       $444 = Math_fround($443 * $435);
       $445 = Math_fround($438 + $440);
       $446 = Math_fround($442 + $444);
       $447 = Math_fround($445 + $446);
       $448 = (HEAPF32[tempDoublePtr>>2]=$427,HEAP32[tempDoublePtr>>2]|0);
       $449 = (HEAPF32[tempDoublePtr>>2]=$447,HEAP32[tempDoublePtr>>2]|0);
       $450 = $449 & -2147483648;
       $451 = $450 ^ $448;
       $452 = (HEAP32[tempDoublePtr>>2]=$451,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $453 = (HEAPF32[tempDoublePtr>>2]=$430,HEAP32[tempDoublePtr>>2]|0);
       $454 = $450 ^ $453;
       $455 = (HEAP32[tempDoublePtr>>2]=$454,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $456 = (HEAPF32[tempDoublePtr>>2]=$433,HEAP32[tempDoublePtr>>2]|0);
       $457 = $450 ^ $456;
       $458 = (HEAP32[tempDoublePtr>>2]=$457,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $459 = (HEAPF32[tempDoublePtr>>2]=$436,HEAP32[tempDoublePtr>>2]|0);
       $460 = $450 ^ $459;
       $461 = (HEAP32[tempDoublePtr>>2]=$460,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $462 = Math_fround($437 + $452);
       $463 = Math_fround($439 + $455);
       $464 = Math_fround($441 + $458);
       $465 = Math_fround($443 + $461);
       HEAPF32[$84>>2] = $462;
       HEAPF32[$85>>2] = $463;
       HEAPF32[$86>>2] = $464;
       HEAPF32[$87>>2] = $465;
      }
      $466 = (__ZN7mecanim5human19MaskHasLeftFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
      if ($466) {
       $467 = (($outputArray) + ($iter$0338$us<<2)|0);
       $468 = HEAP32[$467>>2]|0;
       $469 = (($468) + 276|0);
       $470 = Math_fround(HEAPF32[$469>>2]);
       $471 = Math_fround($104 * $470);
       $472 = (($468) + 280|0);
       $473 = Math_fround(HEAPF32[$472>>2]);
       $474 = Math_fround($104 * $473);
       $475 = (($468) + 284|0);
       $476 = Math_fround(HEAPF32[$475>>2]);
       $477 = Math_fround($104 * $476);
       $478 = (($468) + 288|0);
       $479 = Math_fround(HEAPF32[$478>>2]);
       $480 = Math_fround($104 * $479);
       $481 = Math_fround(HEAPF32[$56>>2]);
       $482 = Math_fround($471 + $481);
       $483 = Math_fround(HEAPF32[$57>>2]);
       $484 = Math_fround($474 + $483);
       $485 = Math_fround(HEAPF32[$58>>2]);
       $486 = Math_fround($477 + $485);
       $487 = Math_fround(HEAPF32[$59>>2]);
       $488 = Math_fround($480 + $487);
       HEAPF32[$56>>2] = $482;
       HEAPF32[$57>>2] = $484;
       HEAPF32[$58>>2] = $486;
       HEAPF32[$59>>2] = $488;
       $489 = (($468) + 292|0);
       $490 = Math_fround(HEAPF32[$489>>2]);
       $491 = Math_fround($104 * $490);
       $492 = (($468) + 296|0);
       $493 = Math_fround(HEAPF32[$492>>2]);
       $494 = Math_fround($104 * $493);
       $495 = (($468) + 300|0);
       $496 = Math_fround(HEAPF32[$495>>2]);
       $497 = Math_fround($104 * $496);
       $498 = (($468) + 304|0);
       $499 = Math_fround(HEAPF32[$498>>2]);
       $500 = Math_fround($104 * $499);
       $501 = Math_fround(HEAPF32[$60>>2]);
       $502 = Math_fround($501 * $490);
       $503 = Math_fround(HEAPF32[$61>>2]);
       $504 = Math_fround($503 * $493);
       $505 = Math_fround(HEAPF32[$62>>2]);
       $506 = Math_fround($505 * $496);
       $507 = Math_fround(HEAPF32[$63>>2]);
       $508 = Math_fround($507 * $499);
       $509 = Math_fround($502 + $504);
       $510 = Math_fround($506 + $508);
       $511 = Math_fround($509 + $510);
       $512 = (HEAPF32[tempDoublePtr>>2]=$491,HEAP32[tempDoublePtr>>2]|0);
       $513 = (HEAPF32[tempDoublePtr>>2]=$511,HEAP32[tempDoublePtr>>2]|0);
       $514 = $513 & -2147483648;
       $515 = $514 ^ $512;
       $516 = (HEAP32[tempDoublePtr>>2]=$515,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $517 = (HEAPF32[tempDoublePtr>>2]=$494,HEAP32[tempDoublePtr>>2]|0);
       $518 = $514 ^ $517;
       $519 = (HEAP32[tempDoublePtr>>2]=$518,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $520 = (HEAPF32[tempDoublePtr>>2]=$497,HEAP32[tempDoublePtr>>2]|0);
       $521 = $514 ^ $520;
       $522 = (HEAP32[tempDoublePtr>>2]=$521,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $523 = (HEAPF32[tempDoublePtr>>2]=$500,HEAP32[tempDoublePtr>>2]|0);
       $524 = $514 ^ $523;
       $525 = (HEAP32[tempDoublePtr>>2]=$524,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $526 = Math_fround($501 + $516);
       $527 = Math_fround($503 + $519);
       $528 = Math_fround($505 + $522);
       $529 = Math_fround($507 + $525);
       HEAPF32[$60>>2] = $526;
       HEAPF32[$61>>2] = $527;
       HEAPF32[$62>>2] = $528;
       HEAPF32[$63>>2] = $529;
      }
      $530 = (__ZN7mecanim5human20MaskHasRightFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
      $531 = (($outputArray) + ($iter$0338$us<<2)|0);
      $532 = HEAP32[$531>>2]|0;
      if ($530) {
       $533 = (($532) + 324|0);
       $534 = Math_fround(HEAPF32[$533>>2]);
       $535 = Math_fround($104 * $534);
       $536 = (($532) + 328|0);
       $537 = Math_fround(HEAPF32[$536>>2]);
       $538 = Math_fround($104 * $537);
       $539 = (($532) + 332|0);
       $540 = Math_fround(HEAPF32[$539>>2]);
       $541 = Math_fround($104 * $540);
       $542 = (($532) + 336|0);
       $543 = Math_fround(HEAPF32[$542>>2]);
       $544 = Math_fround($104 * $543);
       $545 = Math_fround(HEAPF32[$68>>2]);
       $546 = Math_fround($535 + $545);
       $547 = Math_fround(HEAPF32[$69>>2]);
       $548 = Math_fround($538 + $547);
       $549 = Math_fround(HEAPF32[$70>>2]);
       $550 = Math_fround($541 + $549);
       $551 = Math_fround(HEAPF32[$71>>2]);
       $552 = Math_fround($544 + $551);
       HEAPF32[$68>>2] = $546;
       HEAPF32[$69>>2] = $548;
       HEAPF32[$70>>2] = $550;
       HEAPF32[$71>>2] = $552;
       $553 = (($532) + 340|0);
       $554 = Math_fround(HEAPF32[$553>>2]);
       $555 = Math_fround($104 * $554);
       $556 = (($532) + 344|0);
       $557 = Math_fround(HEAPF32[$556>>2]);
       $558 = Math_fround($104 * $557);
       $559 = (($532) + 348|0);
       $560 = Math_fround(HEAPF32[$559>>2]);
       $561 = Math_fround($104 * $560);
       $562 = (($532) + 352|0);
       $563 = Math_fround(HEAPF32[$562>>2]);
       $564 = Math_fround($104 * $563);
       $565 = Math_fround(HEAPF32[$72>>2]);
       $566 = Math_fround($565 * $554);
       $567 = Math_fround(HEAPF32[$73>>2]);
       $568 = Math_fround($567 * $557);
       $569 = Math_fround(HEAPF32[$74>>2]);
       $570 = Math_fround($569 * $560);
       $571 = Math_fround(HEAPF32[$75>>2]);
       $572 = Math_fround($571 * $563);
       $573 = Math_fround($566 + $568);
       $574 = Math_fround($570 + $572);
       $575 = Math_fround($573 + $574);
       $576 = (HEAPF32[tempDoublePtr>>2]=$555,HEAP32[tempDoublePtr>>2]|0);
       $577 = (HEAPF32[tempDoublePtr>>2]=$575,HEAP32[tempDoublePtr>>2]|0);
       $578 = $577 & -2147483648;
       $579 = $578 ^ $576;
       $580 = (HEAP32[tempDoublePtr>>2]=$579,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $581 = (HEAPF32[tempDoublePtr>>2]=$558,HEAP32[tempDoublePtr>>2]|0);
       $582 = $578 ^ $581;
       $583 = (HEAP32[tempDoublePtr>>2]=$582,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $584 = (HEAPF32[tempDoublePtr>>2]=$561,HEAP32[tempDoublePtr>>2]|0);
       $585 = $578 ^ $584;
       $586 = (HEAP32[tempDoublePtr>>2]=$585,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $587 = (HEAPF32[tempDoublePtr>>2]=$564,HEAP32[tempDoublePtr>>2]|0);
       $588 = $578 ^ $587;
       $589 = (HEAP32[tempDoublePtr>>2]=$588,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $590 = Math_fround($565 + $580);
       $591 = Math_fround($567 + $583);
       $592 = Math_fround($569 + $586);
       $593 = Math_fround($571 + $589);
       HEAPF32[$72>>2] = $590;
       HEAPF32[$73>>2] = $591;
       HEAPF32[$74>>2] = $592;
       HEAPF32[$75>>2] = $593;
      }
      $594 = (($532) + 424|0);
      $595 = Math_fround(HEAPF32[$594>>2]);
      $596 = Math_fround($104 * $595);
      $597 = (($532) + 428|0);
      $598 = Math_fround(HEAPF32[$597>>2]);
      $599 = Math_fround($104 * $598);
      $600 = (($532) + 432|0);
      $601 = Math_fround(HEAPF32[$600>>2]);
      $602 = Math_fround($104 * $601);
      $603 = (($532) + 436|0);
      $604 = Math_fround(HEAPF32[$603>>2]);
      $605 = Math_fround($104 * $604);
      $606 = Math_fround(HEAPF32[$92>>2]);
      $607 = Math_fround($596 + $606);
      $608 = Math_fround(HEAPF32[$93>>2]);
      $609 = Math_fround($599 + $608);
      $610 = Math_fround(HEAPF32[$94>>2]);
      $611 = Math_fround($602 + $610);
      $612 = Math_fround(HEAPF32[$95>>2]);
      $613 = Math_fround($605 + $612);
      HEAPF32[$92>>2] = $607;
      HEAPF32[$93>>2] = $609;
      HEAPF32[$94>>2] = $611;
      HEAPF32[$95>>2] = $613;
      $614 = (($532) + 440|0);
      $615 = Math_fround(HEAPF32[$614>>2]);
      $616 = Math_fround($104 * $615);
      $617 = (($532) + 444|0);
      $618 = Math_fround(HEAPF32[$617>>2]);
      $619 = Math_fround($104 * $618);
      $620 = (($532) + 448|0);
      $621 = Math_fround(HEAPF32[$620>>2]);
      $622 = Math_fround($104 * $621);
      $623 = (($532) + 452|0);
      $624 = Math_fround(HEAPF32[$623>>2]);
      $625 = Math_fround($104 * $624);
      $626 = Math_fround(HEAPF32[$96>>2]);
      $627 = Math_fround($616 + $626);
      $628 = Math_fround(HEAPF32[$97>>2]);
      $629 = Math_fround($619 + $628);
      $630 = Math_fround(HEAPF32[$98>>2]);
      $631 = Math_fround($622 + $630);
      $632 = Math_fround(HEAPF32[$99>>2]);
      $633 = Math_fround($625 + $632);
      HEAPF32[$96>>2] = $627;
      HEAPF32[$97>>2] = $629;
      HEAPF32[$98>>2] = $631;
      HEAPF32[$99>>2] = $633;
      $634 = (($532) + 456|0);
      $635 = Math_fround(HEAPF32[$634>>2]);
      $636 = Math_fround($104 * $635);
      $637 = Math_fround(HEAPF32[$100>>2]);
      $638 = Math_fround($637 + $636);
      HEAPF32[$100>>2] = $638;
     }
     $639 = (($iter$0338$us) + 1)|0;
     $exitcond341 = ($639|0)==($count|0);
     if ($exitcond341) {
      $sumW$0$lcssa = $105;
      break L1;
     } else {
      $iter$0338$us = $639;$sumW$0339$us = $105;
     }
    }
   } else {
    $iter$0338 = 0;$sumW$0339 = Math_fround(0.0);
   }
   while(1) {
    $640 = (($weight) + ($iter$0338<<2)|0);
    $641 = Math_fround(HEAPF32[$640>>2]);
    $642 = Math_fround($sumW$0339 + $641);
    do {
     if ($isHuman) {
      $643 = HEAP32[$poseMask>>2]|0;
      $644 = $643 & 1;
      $645 = ($644|0)==(0);
      if (!($645)) {
       $646 = (($outputArray) + ($iter$0338<<2)|0);
       $647 = HEAP32[$646>>2]|0;
       $648 = (($647) + 4|0);
       $649 = Math_fround(HEAPF32[$648>>2]);
       $650 = Math_fround($641 * $649);
       $651 = (($647) + 8|0);
       $652 = Math_fround(HEAPF32[$651>>2]);
       $653 = Math_fround($641 * $652);
       $654 = (($647) + 12|0);
       $655 = Math_fround(HEAPF32[$654>>2]);
       $656 = Math_fround($641 * $655);
       $657 = (($647) + 16|0);
       $658 = Math_fround(HEAPF32[$657>>2]);
       $659 = Math_fround($641 * $658);
       $660 = Math_fround(HEAPF32[$0>>2]);
       $661 = Math_fround($650 + $660);
       $662 = Math_fround(HEAPF32[$1>>2]);
       $663 = Math_fround($653 + $662);
       $664 = Math_fround(HEAPF32[$2>>2]);
       $665 = Math_fround($656 + $664);
       $666 = Math_fround(HEAPF32[$3>>2]);
       $667 = Math_fround($659 + $666);
       HEAPF32[$0>>2] = $661;
       HEAPF32[$1>>2] = $663;
       HEAPF32[$2>>2] = $665;
       HEAPF32[$3>>2] = $667;
       $668 = (($647) + 20|0);
       $669 = Math_fround(HEAPF32[$668>>2]);
       $670 = Math_fround($641 * $669);
       $671 = (($647) + 24|0);
       $672 = Math_fround(HEAPF32[$671>>2]);
       $673 = Math_fround($641 * $672);
       $674 = (($647) + 28|0);
       $675 = Math_fround(HEAPF32[$674>>2]);
       $676 = Math_fround($641 * $675);
       $677 = (($647) + 32|0);
       $678 = Math_fround(HEAPF32[$677>>2]);
       $679 = Math_fround($641 * $678);
       $680 = Math_fround(HEAPF32[$4>>2]);
       $681 = Math_fround($670 + $680);
       $682 = Math_fround(HEAPF32[$5>>2]);
       $683 = Math_fround($673 + $682);
       $684 = Math_fround(HEAPF32[$6>>2]);
       $685 = Math_fround($676 + $684);
       $686 = Math_fround(HEAPF32[$7>>2]);
       $687 = Math_fround($679 + $686);
       HEAPF32[$4>>2] = $681;
       HEAPF32[$5>>2] = $683;
       HEAPF32[$6>>2] = $685;
       HEAPF32[$7>>2] = $687;
       $688 = (($647) + 420|0);
       $689 = Math_fround(HEAPF32[$688>>2]);
       $690 = Math_fround($641 * $689);
       $691 = Math_fround(HEAPF32[$101>>2]);
       $692 = Math_fround($691 + $690);
       HEAPF32[$101>>2] = $692;
       if (!($isHuman)) {
        break;
       }
      }
      $693 = HEAP32[$poseMask>>2]|0;
      $694 = $693 & 1;
      $695 = ($694|0)==(0);
      if (!($695)) {
       $696 = (($outputArray) + ($iter$0338<<2)|0);
       $697 = HEAP32[$696>>2]|0;
       $698 = (($697) + 228|0);
       $699 = Math_fround(HEAPF32[$698>>2]);
       $700 = Math_fround($641 * $699);
       $701 = (($697) + 232|0);
       $702 = Math_fround(HEAPF32[$701>>2]);
       $703 = Math_fround($641 * $702);
       $704 = (($697) + 236|0);
       $705 = Math_fround(HEAPF32[$704>>2]);
       $706 = Math_fround($641 * $705);
       $707 = (($697) + 240|0);
       $708 = Math_fround(HEAPF32[$707>>2]);
       $709 = Math_fround($641 * $708);
       $710 = Math_fround(HEAPF32[$44>>2]);
       $711 = Math_fround($700 + $710);
       $712 = Math_fround(HEAPF32[$45>>2]);
       $713 = Math_fround($703 + $712);
       $714 = Math_fround(HEAPF32[$46>>2]);
       $715 = Math_fround($706 + $714);
       $716 = Math_fround(HEAPF32[$47>>2]);
       $717 = Math_fround($709 + $716);
       HEAPF32[$44>>2] = $711;
       HEAPF32[$45>>2] = $713;
       HEAPF32[$46>>2] = $715;
       HEAPF32[$47>>2] = $717;
       $718 = (($697) + 244|0);
       $719 = Math_fround(HEAPF32[$718>>2]);
       $720 = Math_fround($641 * $719);
       $721 = (($697) + 248|0);
       $722 = Math_fround(HEAPF32[$721>>2]);
       $723 = Math_fround($641 * $722);
       $724 = (($697) + 252|0);
       $725 = Math_fround(HEAPF32[$724>>2]);
       $726 = Math_fround($641 * $725);
       $727 = (($697) + 256|0);
       $728 = Math_fround(HEAPF32[$727>>2]);
       $729 = Math_fround($641 * $728);
       $730 = Math_fround(HEAPF32[$48>>2]);
       $731 = Math_fround($730 * $719);
       $732 = Math_fround(HEAPF32[$49>>2]);
       $733 = Math_fround($732 * $722);
       $734 = Math_fround(HEAPF32[$50>>2]);
       $735 = Math_fround($734 * $725);
       $736 = Math_fround(HEAPF32[$51>>2]);
       $737 = Math_fround($736 * $728);
       $738 = Math_fround($731 + $733);
       $739 = Math_fround($735 + $737);
       $740 = Math_fround($738 + $739);
       $741 = (HEAPF32[tempDoublePtr>>2]=$720,HEAP32[tempDoublePtr>>2]|0);
       $742 = (HEAPF32[tempDoublePtr>>2]=$740,HEAP32[tempDoublePtr>>2]|0);
       $743 = $742 & -2147483648;
       $744 = $743 ^ $741;
       $745 = (HEAP32[tempDoublePtr>>2]=$744,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $746 = (HEAPF32[tempDoublePtr>>2]=$723,HEAP32[tempDoublePtr>>2]|0);
       $747 = $743 ^ $746;
       $748 = (HEAP32[tempDoublePtr>>2]=$747,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $749 = (HEAPF32[tempDoublePtr>>2]=$726,HEAP32[tempDoublePtr>>2]|0);
       $750 = $743 ^ $749;
       $751 = (HEAP32[tempDoublePtr>>2]=$750,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $752 = (HEAPF32[tempDoublePtr>>2]=$729,HEAP32[tempDoublePtr>>2]|0);
       $753 = $743 ^ $752;
       $754 = (HEAP32[tempDoublePtr>>2]=$753,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $755 = Math_fround($730 + $745);
       $756 = Math_fround($732 + $748);
       $757 = Math_fround($734 + $751);
       $758 = Math_fround($736 + $754);
       HEAPF32[$48>>2] = $755;
       HEAPF32[$49>>2] = $756;
       HEAPF32[$50>>2] = $757;
       HEAPF32[$51>>2] = $758;
       $759 = (($697) + 372|0);
       $760 = Math_fround(HEAPF32[$759>>2]);
       $761 = Math_fround($641 * $760);
       $762 = (($697) + 376|0);
       $763 = Math_fround(HEAPF32[$762>>2]);
       $764 = Math_fround($641 * $763);
       $765 = (($697) + 380|0);
       $766 = Math_fround(HEAPF32[$765>>2]);
       $767 = Math_fround($641 * $766);
       $768 = (($697) + 384|0);
       $769 = Math_fround(HEAPF32[$768>>2]);
       $770 = Math_fround($641 * $769);
       $771 = Math_fround(HEAPF32[$80>>2]);
       $772 = Math_fround($761 + $771);
       $773 = Math_fround(HEAPF32[$81>>2]);
       $774 = Math_fround($764 + $773);
       $775 = Math_fround(HEAPF32[$82>>2]);
       $776 = Math_fround($767 + $775);
       $777 = Math_fround(HEAPF32[$83>>2]);
       $778 = Math_fround($770 + $777);
       HEAPF32[$80>>2] = $772;
       HEAPF32[$81>>2] = $774;
       HEAPF32[$82>>2] = $776;
       HEAPF32[$83>>2] = $778;
       $779 = (($697) + 388|0);
       $780 = Math_fround(HEAPF32[$779>>2]);
       $781 = Math_fround($641 * $780);
       $782 = (($697) + 392|0);
       $783 = Math_fround(HEAPF32[$782>>2]);
       $784 = Math_fround($641 * $783);
       $785 = (($697) + 396|0);
       $786 = Math_fround(HEAPF32[$785>>2]);
       $787 = Math_fround($641 * $786);
       $788 = (($697) + 400|0);
       $789 = Math_fround(HEAPF32[$788>>2]);
       $790 = Math_fround($641 * $789);
       $791 = Math_fround(HEAPF32[$84>>2]);
       $792 = Math_fround($791 * $780);
       $793 = Math_fround(HEAPF32[$85>>2]);
       $794 = Math_fround($793 * $783);
       $795 = Math_fround(HEAPF32[$86>>2]);
       $796 = Math_fround($795 * $786);
       $797 = Math_fround(HEAPF32[$87>>2]);
       $798 = Math_fround($797 * $789);
       $799 = Math_fround($792 + $794);
       $800 = Math_fround($796 + $798);
       $801 = Math_fround($799 + $800);
       $802 = (HEAPF32[tempDoublePtr>>2]=$781,HEAP32[tempDoublePtr>>2]|0);
       $803 = (HEAPF32[tempDoublePtr>>2]=$801,HEAP32[tempDoublePtr>>2]|0);
       $804 = $803 & -2147483648;
       $805 = $804 ^ $802;
       $806 = (HEAP32[tempDoublePtr>>2]=$805,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $807 = (HEAPF32[tempDoublePtr>>2]=$784,HEAP32[tempDoublePtr>>2]|0);
       $808 = $804 ^ $807;
       $809 = (HEAP32[tempDoublePtr>>2]=$808,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $810 = (HEAPF32[tempDoublePtr>>2]=$787,HEAP32[tempDoublePtr>>2]|0);
       $811 = $804 ^ $810;
       $812 = (HEAP32[tempDoublePtr>>2]=$811,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $813 = (HEAPF32[tempDoublePtr>>2]=$790,HEAP32[tempDoublePtr>>2]|0);
       $814 = $804 ^ $813;
       $815 = (HEAP32[tempDoublePtr>>2]=$814,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $816 = Math_fround($791 + $806);
       $817 = Math_fround($793 + $809);
       $818 = Math_fround($795 + $812);
       $819 = Math_fround($797 + $815);
       HEAPF32[$84>>2] = $816;
       HEAPF32[$85>>2] = $817;
       HEAPF32[$86>>2] = $818;
       HEAPF32[$87>>2] = $819;
      }
      $820 = (__ZN7mecanim5human19MaskHasLeftFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
      if ($820) {
       $821 = (($outputArray) + ($iter$0338<<2)|0);
       $822 = HEAP32[$821>>2]|0;
       $823 = (($822) + 276|0);
       $824 = Math_fround(HEAPF32[$823>>2]);
       $825 = Math_fround($641 * $824);
       $826 = (($822) + 280|0);
       $827 = Math_fround(HEAPF32[$826>>2]);
       $828 = Math_fround($641 * $827);
       $829 = (($822) + 284|0);
       $830 = Math_fround(HEAPF32[$829>>2]);
       $831 = Math_fround($641 * $830);
       $832 = (($822) + 288|0);
       $833 = Math_fround(HEAPF32[$832>>2]);
       $834 = Math_fround($641 * $833);
       $835 = Math_fround(HEAPF32[$56>>2]);
       $836 = Math_fround($825 + $835);
       $837 = Math_fround(HEAPF32[$57>>2]);
       $838 = Math_fround($828 + $837);
       $839 = Math_fround(HEAPF32[$58>>2]);
       $840 = Math_fround($831 + $839);
       $841 = Math_fround(HEAPF32[$59>>2]);
       $842 = Math_fround($834 + $841);
       HEAPF32[$56>>2] = $836;
       HEAPF32[$57>>2] = $838;
       HEAPF32[$58>>2] = $840;
       HEAPF32[$59>>2] = $842;
       $843 = (($822) + 292|0);
       $844 = Math_fround(HEAPF32[$843>>2]);
       $845 = Math_fround($641 * $844);
       $846 = (($822) + 296|0);
       $847 = Math_fround(HEAPF32[$846>>2]);
       $848 = Math_fround($641 * $847);
       $849 = (($822) + 300|0);
       $850 = Math_fround(HEAPF32[$849>>2]);
       $851 = Math_fround($641 * $850);
       $852 = (($822) + 304|0);
       $853 = Math_fround(HEAPF32[$852>>2]);
       $854 = Math_fround($641 * $853);
       $855 = Math_fround(HEAPF32[$60>>2]);
       $856 = Math_fround($855 * $844);
       $857 = Math_fround(HEAPF32[$61>>2]);
       $858 = Math_fround($857 * $847);
       $859 = Math_fround(HEAPF32[$62>>2]);
       $860 = Math_fround($859 * $850);
       $861 = Math_fround(HEAPF32[$63>>2]);
       $862 = Math_fround($861 * $853);
       $863 = Math_fround($856 + $858);
       $864 = Math_fround($860 + $862);
       $865 = Math_fround($863 + $864);
       $866 = (HEAPF32[tempDoublePtr>>2]=$845,HEAP32[tempDoublePtr>>2]|0);
       $867 = (HEAPF32[tempDoublePtr>>2]=$865,HEAP32[tempDoublePtr>>2]|0);
       $868 = $867 & -2147483648;
       $869 = $868 ^ $866;
       $870 = (HEAP32[tempDoublePtr>>2]=$869,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $871 = (HEAPF32[tempDoublePtr>>2]=$848,HEAP32[tempDoublePtr>>2]|0);
       $872 = $868 ^ $871;
       $873 = (HEAP32[tempDoublePtr>>2]=$872,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $874 = (HEAPF32[tempDoublePtr>>2]=$851,HEAP32[tempDoublePtr>>2]|0);
       $875 = $868 ^ $874;
       $876 = (HEAP32[tempDoublePtr>>2]=$875,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $877 = (HEAPF32[tempDoublePtr>>2]=$854,HEAP32[tempDoublePtr>>2]|0);
       $878 = $868 ^ $877;
       $879 = (HEAP32[tempDoublePtr>>2]=$878,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $880 = Math_fround($855 + $870);
       $881 = Math_fround($857 + $873);
       $882 = Math_fround($859 + $876);
       $883 = Math_fround($861 + $879);
       HEAPF32[$60>>2] = $880;
       HEAPF32[$61>>2] = $881;
       HEAPF32[$62>>2] = $882;
       HEAPF32[$63>>2] = $883;
      }
      $884 = (__ZN7mecanim5human20MaskHasRightFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
      $885 = (($outputArray) + ($iter$0338<<2)|0);
      $886 = HEAP32[$885>>2]|0;
      if ($884) {
       $887 = (($886) + 324|0);
       $888 = Math_fround(HEAPF32[$887>>2]);
       $889 = Math_fround($641 * $888);
       $890 = (($886) + 328|0);
       $891 = Math_fround(HEAPF32[$890>>2]);
       $892 = Math_fround($641 * $891);
       $893 = (($886) + 332|0);
       $894 = Math_fround(HEAPF32[$893>>2]);
       $895 = Math_fround($641 * $894);
       $896 = (($886) + 336|0);
       $897 = Math_fround(HEAPF32[$896>>2]);
       $898 = Math_fround($641 * $897);
       $899 = Math_fround(HEAPF32[$68>>2]);
       $900 = Math_fround($889 + $899);
       $901 = Math_fround(HEAPF32[$69>>2]);
       $902 = Math_fround($892 + $901);
       $903 = Math_fround(HEAPF32[$70>>2]);
       $904 = Math_fround($895 + $903);
       $905 = Math_fround(HEAPF32[$71>>2]);
       $906 = Math_fround($898 + $905);
       HEAPF32[$68>>2] = $900;
       HEAPF32[$69>>2] = $902;
       HEAPF32[$70>>2] = $904;
       HEAPF32[$71>>2] = $906;
       $907 = (($886) + 340|0);
       $908 = Math_fround(HEAPF32[$907>>2]);
       $909 = Math_fround($641 * $908);
       $910 = (($886) + 344|0);
       $911 = Math_fround(HEAPF32[$910>>2]);
       $912 = Math_fround($641 * $911);
       $913 = (($886) + 348|0);
       $914 = Math_fround(HEAPF32[$913>>2]);
       $915 = Math_fround($641 * $914);
       $916 = (($886) + 352|0);
       $917 = Math_fround(HEAPF32[$916>>2]);
       $918 = Math_fround($641 * $917);
       $919 = Math_fround(HEAPF32[$72>>2]);
       $920 = Math_fround($919 * $908);
       $921 = Math_fround(HEAPF32[$73>>2]);
       $922 = Math_fround($921 * $911);
       $923 = Math_fround(HEAPF32[$74>>2]);
       $924 = Math_fround($923 * $914);
       $925 = Math_fround(HEAPF32[$75>>2]);
       $926 = Math_fround($925 * $917);
       $927 = Math_fround($920 + $922);
       $928 = Math_fround($924 + $926);
       $929 = Math_fround($927 + $928);
       $930 = (HEAPF32[tempDoublePtr>>2]=$909,HEAP32[tempDoublePtr>>2]|0);
       $931 = (HEAPF32[tempDoublePtr>>2]=$929,HEAP32[tempDoublePtr>>2]|0);
       $932 = $931 & -2147483648;
       $933 = $932 ^ $930;
       $934 = (HEAP32[tempDoublePtr>>2]=$933,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $935 = (HEAPF32[tempDoublePtr>>2]=$912,HEAP32[tempDoublePtr>>2]|0);
       $936 = $932 ^ $935;
       $937 = (HEAP32[tempDoublePtr>>2]=$936,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $938 = (HEAPF32[tempDoublePtr>>2]=$915,HEAP32[tempDoublePtr>>2]|0);
       $939 = $932 ^ $938;
       $940 = (HEAP32[tempDoublePtr>>2]=$939,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $941 = (HEAPF32[tempDoublePtr>>2]=$918,HEAP32[tempDoublePtr>>2]|0);
       $942 = $932 ^ $941;
       $943 = (HEAP32[tempDoublePtr>>2]=$942,Math_fround(HEAPF32[tempDoublePtr>>2]));
       $944 = Math_fround($919 + $934);
       $945 = Math_fround($921 + $937);
       $946 = Math_fround($923 + $940);
       $947 = Math_fround($925 + $943);
       HEAPF32[$72>>2] = $944;
       HEAPF32[$73>>2] = $945;
       HEAPF32[$74>>2] = $946;
       HEAPF32[$75>>2] = $947;
      }
      $948 = (($886) + 424|0);
      $949 = Math_fround(HEAPF32[$948>>2]);
      $950 = Math_fround($641 * $949);
      $951 = (($886) + 428|0);
      $952 = Math_fround(HEAPF32[$951>>2]);
      $953 = Math_fround($641 * $952);
      $954 = (($886) + 432|0);
      $955 = Math_fround(HEAPF32[$954>>2]);
      $956 = Math_fround($641 * $955);
      $957 = (($886) + 436|0);
      $958 = Math_fround(HEAPF32[$957>>2]);
      $959 = Math_fround($641 * $958);
      $960 = Math_fround(HEAPF32[$92>>2]);
      $961 = Math_fround($950 + $960);
      $962 = Math_fround(HEAPF32[$93>>2]);
      $963 = Math_fround($953 + $962);
      $964 = Math_fround(HEAPF32[$94>>2]);
      $965 = Math_fround($956 + $964);
      $966 = Math_fround(HEAPF32[$95>>2]);
      $967 = Math_fround($959 + $966);
      HEAPF32[$92>>2] = $961;
      HEAPF32[$93>>2] = $963;
      HEAPF32[$94>>2] = $965;
      HEAPF32[$95>>2] = $967;
      $968 = (($886) + 440|0);
      $969 = Math_fround(HEAPF32[$968>>2]);
      $970 = Math_fround($641 * $969);
      $971 = (($886) + 444|0);
      $972 = Math_fround(HEAPF32[$971>>2]);
      $973 = Math_fround($641 * $972);
      $974 = (($886) + 448|0);
      $975 = Math_fround(HEAPF32[$974>>2]);
      $976 = Math_fround($641 * $975);
      $977 = (($886) + 452|0);
      $978 = Math_fround(HEAPF32[$977>>2]);
      $979 = Math_fround($641 * $978);
      $980 = Math_fround(HEAPF32[$96>>2]);
      $981 = Math_fround($970 + $980);
      $982 = Math_fround(HEAPF32[$97>>2]);
      $983 = Math_fround($973 + $982);
      $984 = Math_fround(HEAPF32[$98>>2]);
      $985 = Math_fround($976 + $984);
      $986 = Math_fround(HEAPF32[$99>>2]);
      $987 = Math_fround($979 + $986);
      HEAPF32[$96>>2] = $981;
      HEAPF32[$97>>2] = $983;
      HEAPF32[$98>>2] = $985;
      HEAPF32[$99>>2] = $987;
      $988 = (($886) + 456|0);
      $989 = Math_fround(HEAPF32[$988>>2]);
      $990 = Math_fround($641 * $989);
      $991 = Math_fround(HEAPF32[$100>>2]);
      $992 = Math_fround($991 + $990);
      HEAPF32[$100>>2] = $992;
     }
    } while(0);
    $993 = (($iter$0338) + 1)|0;
    $exitcond = ($993|0)==($count|0);
    if ($exitcond) {
     $sumW$0$lcssa = $642;
     break;
    } else {
     $iter$0338 = $993;$sumW$0339 = $642;
    }
   }
  }
 } while(0);
 if ($hasRootMotion) {
  $$old = $sumW$0$lcssa > Math_fround(0.0);
  if ($$old) {
   label = 27;
  }
 } else {
  if ($isHuman) {
   $994 = HEAP32[$poseMask>>2]|0;
   $995 = $994 & 1;
   $996 = ($995|0)!=(0);
   $997 = $sumW$0$lcssa > Math_fround(0.0);
   $or$cond = $996 & $997;
   if ($or$cond) {
    label = 27;
   }
  }
 }
 if ((label|0) == 27) {
  $998 = Math_fround(HEAPF32[$101>>2]);
  $999 = Math_fround($998 / $sumW$0$lcssa);
  HEAPF32[$101>>2] = $999;
 }
 $1000 = Math_fround(Math_fround(1.0) - $sumW$0$lcssa);
 $1001 = (Math_fround(+(_fmaxf(0.0,(+$1000)))));
 $1002 = (Math_fround(+(_fminf(1.0,(+$1001)))));
 if ($hasRootMotion) {
  $1003 = Math_fround(HEAPF32[$12>>2]);
  $1004 = Math_fround($1003 + Math_fround(0.0));
  $1005 = Math_fround(HEAPF32[$13>>2]);
  $1006 = Math_fround($1005 + Math_fround(0.0));
  $1007 = Math_fround(HEAPF32[$14>>2]);
  $1008 = Math_fround($1007 + Math_fround(0.0));
  $1009 = Math_fround(HEAPF32[$15>>2]);
  $1010 = Math_fround($1002 + $1009);
  $1011 = Math_fround($1004 * $1004);
  $1012 = Math_fround($1006 * $1006);
  $1013 = Math_fround($1008 * $1008);
  $1014 = Math_fround($1010 * $1010);
  $1015 = Math_fround($1011 + $1012);
  $1016 = Math_fround($1013 + $1014);
  $1017 = Math_fround($1015 + $1016);
  $1018 = (Math_fround(Math_sqrt((Math_fround($1017)))));
  $1019 = Math_fround(Math_fround(1.0) / $1018);
  $1020 = Math_fround($1004 * $1019);
  $1021 = Math_fround($1006 * $1019);
  $1022 = Math_fround($1008 * $1019);
  $1023 = Math_fround($1010 * $1019);
  HEAPF32[$12>>2] = $1020;
  HEAPF32[$13>>2] = $1021;
  HEAPF32[$14>>2] = $1022;
  HEAPF32[$15>>2] = $1023;
  $1024 = Math_fround(HEAPF32[$24>>2]);
  $1025 = Math_fround($1024 + Math_fround(0.0));
  $1026 = Math_fround(HEAPF32[$25>>2]);
  $1027 = Math_fround($1026 + Math_fround(0.0));
  $1028 = Math_fround(HEAPF32[$26>>2]);
  $1029 = Math_fround($1028 + Math_fround(0.0));
  $1030 = Math_fround(HEAPF32[$27>>2]);
  $1031 = Math_fround($1002 + $1030);
  $1032 = Math_fround($1025 * $1025);
  $1033 = Math_fround($1027 * $1027);
  $1034 = Math_fround($1029 * $1029);
  $1035 = Math_fround($1031 * $1031);
  $1036 = Math_fround($1032 + $1033);
  $1037 = Math_fround($1034 + $1035);
  $1038 = Math_fround($1036 + $1037);
  $1039 = (Math_fround(Math_sqrt((Math_fround($1038)))));
  $1040 = Math_fround(Math_fround(1.0) / $1039);
  $1041 = Math_fround($1025 * $1040);
  $1042 = Math_fround($1027 * $1040);
  $1043 = Math_fround($1029 * $1040);
  $1044 = Math_fround($1031 * $1040);
  HEAPF32[$24>>2] = $1041;
  HEAPF32[$25>>2] = $1042;
  HEAPF32[$26>>2] = $1043;
  HEAPF32[$27>>2] = $1044;
  $1045 = Math_fround(HEAPF32[$36>>2]);
  $1046 = Math_fround($1045 + Math_fround(0.0));
  $1047 = Math_fround(HEAPF32[$37>>2]);
  $1048 = Math_fround($1047 + Math_fround(0.0));
  $1049 = Math_fround(HEAPF32[$38>>2]);
  $1050 = Math_fround($1049 + Math_fround(0.0));
  $1051 = Math_fround(HEAPF32[$39>>2]);
  $1052 = Math_fround($1002 + $1051);
  $1053 = Math_fround($1046 * $1046);
  $1054 = Math_fround($1048 * $1048);
  $1055 = Math_fround($1050 * $1050);
  $1056 = Math_fround($1052 * $1052);
  $1057 = Math_fround($1053 + $1054);
  $1058 = Math_fround($1055 + $1056);
  $1059 = Math_fround($1057 + $1058);
  $1060 = (Math_fround(Math_sqrt((Math_fround($1059)))));
  $1061 = Math_fround(Math_fround(1.0) / $1060);
  $1062 = Math_fround($1046 * $1061);
  $1063 = Math_fround($1048 * $1061);
  $1064 = Math_fround($1050 * $1061);
  $1065 = Math_fround($1052 * $1061);
  HEAPF32[$36>>2] = $1062;
  HEAPF32[$37>>2] = $1063;
  HEAPF32[$38>>2] = $1064;
  HEAPF32[$39>>2] = $1065;
 }
 if (!($isHuman)) {
  STACKTOP = sp;return;
 }
 $1066 = HEAP32[$poseMask>>2]|0;
 $1067 = $1066 & 1;
 $1068 = ($1067|0)==(0);
 if (!($1068)) {
  $1069 = Math_fround(HEAPF32[$48>>2]);
  $1070 = Math_fround($1069 + Math_fround(0.0));
  $1071 = Math_fround(HEAPF32[$49>>2]);
  $1072 = Math_fround($1071 + Math_fround(0.0));
  $1073 = Math_fround(HEAPF32[$50>>2]);
  $1074 = Math_fround($1073 + Math_fround(0.0));
  $1075 = Math_fround(HEAPF32[$51>>2]);
  $1076 = Math_fround($1002 + $1075);
  $1077 = Math_fround($1070 * $1070);
  $1078 = Math_fround($1072 * $1072);
  $1079 = Math_fround($1074 * $1074);
  $1080 = Math_fround($1076 * $1076);
  $1081 = Math_fround($1077 + $1078);
  $1082 = Math_fround($1079 + $1080);
  $1083 = Math_fround($1081 + $1082);
  $1084 = (Math_fround(Math_sqrt((Math_fround($1083)))));
  $1085 = Math_fround(Math_fround(1.0) / $1084);
  $1086 = Math_fround($1070 * $1085);
  $1087 = Math_fround($1072 * $1085);
  $1088 = Math_fround($1074 * $1085);
  $1089 = Math_fround($1076 * $1085);
  HEAPF32[$48>>2] = $1086;
  HEAPF32[$49>>2] = $1087;
  HEAPF32[$50>>2] = $1088;
  HEAPF32[$51>>2] = $1089;
  $1090 = Math_fround(HEAPF32[$84>>2]);
  $1091 = Math_fround($1090 + Math_fround(0.0));
  $1092 = Math_fround(HEAPF32[$85>>2]);
  $1093 = Math_fround($1092 + Math_fround(0.0));
  $1094 = Math_fround(HEAPF32[$86>>2]);
  $1095 = Math_fround($1094 + Math_fround(0.0));
  $1096 = Math_fround(HEAPF32[$87>>2]);
  $1097 = Math_fround($1002 + $1096);
  $1098 = Math_fround($1091 * $1091);
  $1099 = Math_fround($1093 * $1093);
  $1100 = Math_fround($1095 * $1095);
  $1101 = Math_fround($1097 * $1097);
  $1102 = Math_fround($1098 + $1099);
  $1103 = Math_fround($1100 + $1101);
  $1104 = Math_fround($1102 + $1103);
  $1105 = (Math_fround(Math_sqrt((Math_fround($1104)))));
  $1106 = Math_fround(Math_fround(1.0) / $1105);
  $1107 = Math_fround($1091 * $1106);
  $1108 = Math_fround($1093 * $1106);
  $1109 = Math_fround($1095 * $1106);
  $1110 = Math_fround($1097 * $1106);
  HEAPF32[$84>>2] = $1107;
  HEAPF32[$85>>2] = $1108;
  HEAPF32[$86>>2] = $1109;
  HEAPF32[$87>>2] = $1110;
 }
 $1111 = (__ZN7mecanim5human19MaskHasLeftFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
 if ($1111) {
  $1112 = Math_fround(HEAPF32[$60>>2]);
  $1113 = Math_fround($1112 + Math_fround(0.0));
  $1114 = Math_fround(HEAPF32[$61>>2]);
  $1115 = Math_fround($1114 + Math_fround(0.0));
  $1116 = Math_fround(HEAPF32[$62>>2]);
  $1117 = Math_fround($1116 + Math_fround(0.0));
  $1118 = Math_fround(HEAPF32[$63>>2]);
  $1119 = Math_fround($1002 + $1118);
  $1120 = Math_fround($1113 * $1113);
  $1121 = Math_fround($1115 * $1115);
  $1122 = Math_fround($1117 * $1117);
  $1123 = Math_fround($1119 * $1119);
  $1124 = Math_fround($1120 + $1121);
  $1125 = Math_fround($1122 + $1123);
  $1126 = Math_fround($1124 + $1125);
  $1127 = (Math_fround(Math_sqrt((Math_fround($1126)))));
  $1128 = Math_fround(Math_fround(1.0) / $1127);
  $1129 = Math_fround($1113 * $1128);
  $1130 = Math_fround($1115 * $1128);
  $1131 = Math_fround($1117 * $1128);
  $1132 = Math_fround($1119 * $1128);
  HEAPF32[$60>>2] = $1129;
  HEAPF32[$61>>2] = $1130;
  HEAPF32[$62>>2] = $1131;
  HEAPF32[$63>>2] = $1132;
 }
 $1133 = (__ZN7mecanim5human20MaskHasRightFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
 if ($1133) {
  $1134 = Math_fround(HEAPF32[$72>>2]);
  $1135 = Math_fround($1134 + Math_fround(0.0));
  $1136 = Math_fround(HEAPF32[$73>>2]);
  $1137 = Math_fround($1136 + Math_fround(0.0));
  $1138 = Math_fround(HEAPF32[$74>>2]);
  $1139 = Math_fround($1138 + Math_fround(0.0));
  $1140 = Math_fround(HEAPF32[$75>>2]);
  $1141 = Math_fround($1002 + $1140);
  $1142 = Math_fround($1135 * $1135);
  $1143 = Math_fround($1137 * $1137);
  $1144 = Math_fround($1139 * $1139);
  $1145 = Math_fround($1141 * $1141);
  $1146 = Math_fround($1142 + $1143);
  $1147 = Math_fround($1144 + $1145);
  $1148 = Math_fround($1146 + $1147);
  $1149 = (Math_fround(Math_sqrt((Math_fround($1148)))));
  $1150 = Math_fround(Math_fround(1.0) / $1149);
  $1151 = Math_fround($1135 * $1150);
  $1152 = Math_fround($1137 * $1150);
  $1153 = Math_fround($1139 * $1150);
  $1154 = Math_fround($1141 * $1150);
  HEAPF32[$72>>2] = $1151;
  HEAPF32[$73>>2] = $1152;
  HEAPF32[$74>>2] = $1153;
  HEAPF32[$75>>2] = $1154;
 }
 $1155 = $sumW$0$lcssa > Math_fround(0.0);
 if (!($1155)) {
  STACKTOP = sp;return;
 }
 $1156 = Math_fround(HEAPF32[$100>>2]);
 $1157 = Math_fround($1156 / $sumW$0$lcssa);
 HEAPF32[$100>>2] = $1157;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation22MotionAddOverrideLayerEPNS0_12MotionOutputEPKS1_fbbRKNS_6bitsetILj59EEE($output,$motion,$weight,$hasRootMotion,$isHuman,$poseMask) {
 $output = $output|0;
 $motion = $motion|0;
 $weight = Math_fround($weight);
 $hasRootMotion = $hasRootMotion|0;
 $isHuman = $isHuman|0;
 $poseMask = $poseMask|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = Math_fround(0), $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = 0;
 var $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = Math_fround(0), $241 = 0;
 var $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = 0, $278 = Math_fround(0);
 var $279 = Math_fround(0), $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = 0, $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = 0;
 var $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0;
 var $332 = Math_fround(0), $333 = 0, $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = 0, $342 = Math_fround(0), $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = 0;
 var $404 = Math_fround(0), $405 = 0, $406 = Math_fround(0), $407 = Math_fround(0), $408 = 0, $409 = Math_fround(0), $41 = Math_fround(0), $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = 0;
 var $440 = Math_fround(0), $441 = 0, $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = Math_fround(0), $457 = 0, $458 = Math_fround(0);
 var $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = 0, $485 = Math_fround(0), $486 = 0, $487 = 0, $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0);
 var $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0);
 var $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0, $515 = Math_fround(0), $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0), $521 = 0, $522 = Math_fround(0), $523 = Math_fround(0), $524 = 0, $525 = Math_fround(0), $526 = 0, $527 = Math_fround(0), $528 = Math_fround(0), $529 = 0, $53 = Math_fround(0);
 var $530 = Math_fround(0), $531 = 0, $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = 0, $543 = Math_fround(0), $544 = 0, $545 = Math_fround(0), $546 = Math_fround(0), $547 = 0, $548 = Math_fround(0);
 var $549 = 0, $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = 0, $553 = Math_fround(0), $554 = 0, $555 = Math_fround(0), $556 = Math_fround(0), $557 = 0, $558 = Math_fround(0), $559 = 0, $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0);
 var $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = Math_fround(0), $570 = 0, $571 = Math_fround(0), $572 = 0, $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = 0, $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = 0, $581 = Math_fround(0), $582 = 0, $583 = Math_fround(0), $584 = Math_fround(0);
 var $585 = 0, $586 = Math_fround(0), $587 = 0, $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = Math_fround(0), $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = 0;
 var $602 = 0, $603 = Math_fround(0), $604 = 0, $605 = 0, $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0;
 var $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = 0, $633 = Math_fround(0), $634 = 0, $635 = Math_fround(0), $636 = Math_fround(0), $637 = 0, $638 = Math_fround(0);
 var $639 = 0, $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = 0, $643 = Math_fround(0), $644 = 0, $645 = Math_fround(0), $646 = Math_fround(0), $647 = 0, $648 = Math_fround(0), $649 = 0, $65 = Math_fround(0), $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0);
 var $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = Math_fround(0), $660 = 0, $661 = 0, $662 = Math_fround(0), $663 = 0, $664 = Math_fround(0), $665 = Math_fround(0), $666 = 0, $667 = Math_fround(0), $668 = 0, $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = 0, $672 = Math_fround(0), $673 = 0, $674 = Math_fround(0);
 var $675 = Math_fround(0), $676 = 0, $677 = Math_fround(0), $678 = 0, $679 = Math_fround(0), $68 = Math_fround(0), $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = 0, $69 = 0, $690 = Math_fround(0), $691 = 0, $692 = Math_fround(0);
 var $693 = Math_fround(0), $694 = 0, $695 = Math_fround(0), $696 = 0, $697 = Math_fround(0), $698 = Math_fround(0), $699 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $700 = Math_fround(0), $701 = 0, $702 = Math_fround(0), $703 = Math_fround(0), $704 = 0, $705 = Math_fround(0), $706 = 0, $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0);
 var $710 = Math_fround(0), $711 = Math_fround(0), $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = Math_fround(0), $717 = 0, $718 = 0, $719 = Math_fround(0), $72 = 0, $720 = 0, $721 = 0, $722 = Math_fround(0), $723 = 0, $724 = 0, $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0);
 var $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0);
 var $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = 0, $752 = Math_fround(0), $753 = 0, $754 = Math_fround(0), $755 = Math_fround(0), $756 = 0, $757 = Math_fround(0), $758 = 0, $759 = Math_fround(0), $76 = Math_fround(0), $760 = Math_fround(0), $761 = 0, $762 = Math_fround(0), $763 = 0, $764 = Math_fround(0);
 var $765 = Math_fround(0), $766 = 0, $767 = Math_fround(0), $768 = 0, $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = 0, $78 = Math_fround(0), $780 = 0, $781 = Math_fround(0), $782 = 0;
 var $783 = Math_fround(0), $784 = Math_fround(0), $785 = 0, $786 = Math_fround(0), $787 = 0, $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = 0, $791 = Math_fround(0), $792 = 0, $793 = Math_fround(0), $794 = Math_fround(0), $795 = 0, $796 = Math_fround(0), $797 = 0, $798 = Math_fround(0), $799 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0);
 var $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = 0, $809 = Math_fround(0), $81 = Math_fround(0), $810 = 0, $811 = Math_fround(0), $812 = Math_fround(0), $813 = 0, $814 = Math_fround(0), $815 = 0, $816 = Math_fround(0), $817 = Math_fround(0), $818 = 0;
 var $819 = Math_fround(0), $82 = 0, $820 = 0, $821 = Math_fround(0), $822 = Math_fround(0), $823 = 0, $824 = Math_fround(0), $825 = 0, $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = Math_fround(0), $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = Math_fround(0), $836 = 0;
 var $837 = 0, $838 = Math_fround(0), $839 = 0, $84 = 0, $840 = 0, $841 = Math_fround(0), $842 = 0, $843 = 0, $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0);
 var $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = 0, $871 = Math_fround(0), $872 = 0;
 var $873 = Math_fround(0), $874 = Math_fround(0), $875 = 0, $876 = Math_fround(0), $877 = 0, $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = 0, $881 = Math_fround(0), $882 = 0, $883 = Math_fround(0), $884 = Math_fround(0), $885 = 0, $886 = Math_fround(0), $887 = 0, $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0);
 var $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = 0, $899 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $900 = Math_fround(0), $901 = 0, $902 = Math_fround(0), $903 = Math_fround(0), $904 = 0, $905 = Math_fround(0), $906 = Math_fround(0), $907 = 0, $908 = Math_fround(0);
 var $909 = Math_fround(0), $91 = Math_fround(0), $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = Math_fround(0), $916 = Math_fround(0), $917 = 0, $918 = Math_fround(0), $919 = Math_fround(0), $92 = Math_fround(0), $920 = 0, $921 = Math_fround(0), $922 = Math_fround(0), $923 = 0, $924 = Math_fround(0), $925 = Math_fround(0), $926 = 0;
 var $927 = 0, $928 = 0, $929 = 0, $93 = Math_fround(0), $930 = 0, $931 = Math_fround(0), $932 = 0, $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $weight < Math_fround(1.0);
 if (!($0)) {
  __ZN7mecanim9animation16MotionOutputCopyEPNS0_12MotionOutputEPKS1_bbRKNS_6bitsetILj59EEE($output,$motion,$hasRootMotion,$isHuman,$poseMask);
  STACKTOP = sp;return;
 }
 do {
  if ($hasRootMotion) {
   label = 5;
  } else {
   if ($isHuman) {
    $1 = HEAP32[$poseMask>>2]|0;
    $2 = $1 & 1;
    $3 = ($2|0)==(0);
    if ($3) {
     break;
    } else {
     label = 5;
     break;
    }
   } else {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $4 = (($motion) + 4|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = (($output) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround($5 - $7);
  $9 = (($motion) + 8|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($output) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = Math_fround($10 - $12);
  $14 = (($motion) + 12|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($output) + 12|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = Math_fround($15 - $17);
  $19 = (($motion) + 16|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($output) + 16|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($20 - $22);
  $24 = Math_fround($8 * $weight);
  $25 = Math_fround($13 * $weight);
  $26 = Math_fround($18 * $weight);
  $27 = Math_fround($23 * $weight);
  $28 = Math_fround($7 + $24);
  $29 = Math_fround($12 + $25);
  $30 = Math_fround($17 + $26);
  $31 = Math_fround($22 + $27);
  HEAPF32[$6>>2] = $28;
  HEAPF32[$11>>2] = $29;
  HEAPF32[$16>>2] = $30;
  HEAPF32[$21>>2] = $31;
  $32 = (($motion) + 20|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = (($output) + 20|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($33 - $35);
  $37 = (($motion) + 24|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = (($output) + 24|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($38 - $40);
  $42 = (($motion) + 28|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = (($output) + 28|0);
  $45 = Math_fround(HEAPF32[$44>>2]);
  $46 = Math_fround($43 - $45);
  $47 = (($motion) + 32|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($output) + 32|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($48 - $50);
  $52 = Math_fround($36 * $weight);
  $53 = Math_fround($41 * $weight);
  $54 = Math_fround($46 * $weight);
  $55 = Math_fround($51 * $weight);
  $56 = Math_fround($35 + $52);
  $57 = Math_fround($40 + $53);
  $58 = Math_fround($45 + $54);
  $59 = Math_fround($50 + $55);
  HEAPF32[$34>>2] = $56;
  HEAPF32[$39>>2] = $57;
  HEAPF32[$44>>2] = $58;
  HEAPF32[$49>>2] = $59;
  $60 = (($output) + 420|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($motion) + 420|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = Math_fround($63 - $61);
  $65 = Math_fround($64 * $weight);
  $66 = Math_fround($61 + $65);
  HEAPF32[$60>>2] = $66;
 }
 if ($hasRootMotion) {
  $67 = (($motion) + 84|0);
  $68 = Math_fround(HEAPF32[$67>>2]);
  $69 = (($output) + 84|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = Math_fround($68 - $70);
  $72 = (($motion) + 88|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = (($output) + 88|0);
  $75 = Math_fround(HEAPF32[$74>>2]);
  $76 = Math_fround($73 - $75);
  $77 = (($motion) + 92|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = (($output) + 92|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = Math_fround($78 - $80);
  $82 = (($motion) + 96|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = (($output) + 96|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($83 - $85);
  $87 = Math_fround($71 * $weight);
  $88 = Math_fround($76 * $weight);
  $89 = Math_fround($81 * $weight);
  $90 = Math_fround($86 * $weight);
  $91 = Math_fround($70 + $87);
  $92 = Math_fround($75 + $88);
  $93 = Math_fround($80 + $89);
  $94 = Math_fround($85 + $90);
  $95 = (($output) + 100|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = (($motion) + 100|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = Math_fround($96 * $98);
  $100 = (($output) + 104|0);
  $101 = Math_fround(HEAPF32[$100>>2]);
  $102 = (($motion) + 104|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = Math_fround($101 * $103);
  $105 = (($output) + 108|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = (($motion) + 108|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = Math_fround($106 * $108);
  $110 = (($output) + 112|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = (($motion) + 112|0);
  $113 = Math_fround(HEAPF32[$112>>2]);
  $114 = Math_fround($111 * $113);
  $115 = Math_fround($99 + $104);
  $116 = Math_fround($109 + $114);
  $117 = Math_fround($115 + $116);
  $118 = (HEAPF32[tempDoublePtr>>2]=$98,HEAP32[tempDoublePtr>>2]|0);
  $119 = (HEAPF32[tempDoublePtr>>2]=$117,HEAP32[tempDoublePtr>>2]|0);
  $120 = $119 & -2147483648;
  $121 = $120 ^ $118;
  $122 = (HEAP32[tempDoublePtr>>2]=$121,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $123 = (HEAPF32[tempDoublePtr>>2]=$103,HEAP32[tempDoublePtr>>2]|0);
  $124 = $120 ^ $123;
  $125 = (HEAP32[tempDoublePtr>>2]=$124,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $126 = (HEAPF32[tempDoublePtr>>2]=$108,HEAP32[tempDoublePtr>>2]|0);
  $127 = $120 ^ $126;
  $128 = (HEAP32[tempDoublePtr>>2]=$127,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $129 = (HEAPF32[tempDoublePtr>>2]=$113,HEAP32[tempDoublePtr>>2]|0);
  $130 = $120 ^ $129;
  $131 = (HEAP32[tempDoublePtr>>2]=$130,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $132 = Math_fround($122 - $96);
  $133 = Math_fround($125 - $101);
  $134 = Math_fround($128 - $106);
  $135 = Math_fround($131 - $111);
  $136 = Math_fround($132 * $weight);
  $137 = Math_fround($133 * $weight);
  $138 = Math_fround($134 * $weight);
  $139 = Math_fround($135 * $weight);
  $140 = Math_fround($96 + $136);
  $141 = Math_fround($101 + $137);
  $142 = Math_fround($106 + $138);
  $143 = Math_fround($111 + $139);
  $144 = Math_fround($140 * $140);
  $145 = Math_fround($141 * $141);
  $146 = Math_fround($142 * $142);
  $147 = Math_fround($143 * $143);
  $148 = Math_fround($144 + $145);
  $149 = Math_fround($146 + $147);
  $150 = Math_fround($148 + $149);
  $151 = (Math_fround(Math_sqrt((Math_fround($150)))));
  $152 = Math_fround(Math_fround(1.0) / $151);
  $153 = Math_fround($152 * $140);
  $154 = Math_fround($152 * $141);
  $155 = Math_fround($152 * $142);
  $156 = Math_fround($152 * $143);
  $157 = (($motion) + 116|0);
  $158 = Math_fround(HEAPF32[$157>>2]);
  $159 = (($output) + 116|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = Math_fround($158 - $160);
  $162 = (($motion) + 120|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = (($output) + 120|0);
  $165 = Math_fround(HEAPF32[$164>>2]);
  $166 = Math_fround($163 - $165);
  $167 = (($motion) + 124|0);
  $168 = Math_fround(HEAPF32[$167>>2]);
  $169 = (($output) + 124|0);
  $170 = Math_fround(HEAPF32[$169>>2]);
  $171 = Math_fround($168 - $170);
  $172 = (($motion) + 128|0);
  $173 = Math_fround(HEAPF32[$172>>2]);
  $174 = (($output) + 128|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = Math_fround($173 - $175);
  $177 = Math_fround($161 * $weight);
  $178 = Math_fround($166 * $weight);
  $179 = Math_fround($171 * $weight);
  $180 = Math_fround($176 * $weight);
  $181 = Math_fround($160 + $177);
  $182 = Math_fround($165 + $178);
  $183 = Math_fround($170 + $179);
  $184 = Math_fround($175 + $180);
  HEAPF32[$69>>2] = $91;
  HEAPF32[$74>>2] = $92;
  HEAPF32[$79>>2] = $93;
  HEAPF32[$84>>2] = $94;
  HEAPF32[$95>>2] = $153;
  HEAPF32[$100>>2] = $154;
  HEAPF32[$105>>2] = $155;
  HEAPF32[$110>>2] = $156;
  HEAPF32[$159>>2] = $181;
  HEAPF32[$164>>2] = $182;
  HEAPF32[$169>>2] = $183;
  HEAPF32[$174>>2] = $184;
  $185 = (($motion) + 132|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = (($output) + 132|0);
  $188 = Math_fround(HEAPF32[$187>>2]);
  $189 = Math_fround($186 - $188);
  $190 = (($motion) + 136|0);
  $191 = Math_fround(HEAPF32[$190>>2]);
  $192 = (($output) + 136|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = Math_fround($191 - $193);
  $195 = (($motion) + 140|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = (($output) + 140|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = Math_fround($196 - $198);
  $200 = (($motion) + 144|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (($output) + 144|0);
  $203 = Math_fround(HEAPF32[$202>>2]);
  $204 = Math_fround($201 - $203);
  $205 = Math_fround($189 * $weight);
  $206 = Math_fround($194 * $weight);
  $207 = Math_fround($199 * $weight);
  $208 = Math_fround($204 * $weight);
  $209 = Math_fround($188 + $205);
  $210 = Math_fround($193 + $206);
  $211 = Math_fround($198 + $207);
  $212 = Math_fround($203 + $208);
  $213 = (($output) + 148|0);
  $214 = Math_fround(HEAPF32[$213>>2]);
  $215 = (($motion) + 148|0);
  $216 = Math_fround(HEAPF32[$215>>2]);
  $217 = Math_fround($214 * $216);
  $218 = (($output) + 152|0);
  $219 = Math_fround(HEAPF32[$218>>2]);
  $220 = (($motion) + 152|0);
  $221 = Math_fround(HEAPF32[$220>>2]);
  $222 = Math_fround($219 * $221);
  $223 = (($output) + 156|0);
  $224 = Math_fround(HEAPF32[$223>>2]);
  $225 = (($motion) + 156|0);
  $226 = Math_fround(HEAPF32[$225>>2]);
  $227 = Math_fround($224 * $226);
  $228 = (($output) + 160|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = (($motion) + 160|0);
  $231 = Math_fround(HEAPF32[$230>>2]);
  $232 = Math_fround($229 * $231);
  $233 = Math_fround($217 + $222);
  $234 = Math_fround($227 + $232);
  $235 = Math_fround($233 + $234);
  $236 = (HEAPF32[tempDoublePtr>>2]=$216,HEAP32[tempDoublePtr>>2]|0);
  $237 = (HEAPF32[tempDoublePtr>>2]=$235,HEAP32[tempDoublePtr>>2]|0);
  $238 = $237 & -2147483648;
  $239 = $238 ^ $236;
  $240 = (HEAP32[tempDoublePtr>>2]=$239,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $241 = (HEAPF32[tempDoublePtr>>2]=$221,HEAP32[tempDoublePtr>>2]|0);
  $242 = $238 ^ $241;
  $243 = (HEAP32[tempDoublePtr>>2]=$242,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $244 = (HEAPF32[tempDoublePtr>>2]=$226,HEAP32[tempDoublePtr>>2]|0);
  $245 = $238 ^ $244;
  $246 = (HEAP32[tempDoublePtr>>2]=$245,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $247 = (HEAPF32[tempDoublePtr>>2]=$231,HEAP32[tempDoublePtr>>2]|0);
  $248 = $238 ^ $247;
  $249 = (HEAP32[tempDoublePtr>>2]=$248,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $250 = Math_fround($240 - $214);
  $251 = Math_fround($243 - $219);
  $252 = Math_fround($246 - $224);
  $253 = Math_fround($249 - $229);
  $254 = Math_fround($250 * $weight);
  $255 = Math_fround($251 * $weight);
  $256 = Math_fround($252 * $weight);
  $257 = Math_fround($253 * $weight);
  $258 = Math_fround($214 + $254);
  $259 = Math_fround($219 + $255);
  $260 = Math_fround($224 + $256);
  $261 = Math_fround($229 + $257);
  $262 = Math_fround($258 * $258);
  $263 = Math_fround($259 * $259);
  $264 = Math_fround($260 * $260);
  $265 = Math_fround($261 * $261);
  $266 = Math_fround($262 + $263);
  $267 = Math_fround($264 + $265);
  $268 = Math_fround($266 + $267);
  $269 = (Math_fround(Math_sqrt((Math_fround($268)))));
  $270 = Math_fround(Math_fround(1.0) / $269);
  $271 = Math_fround($270 * $258);
  $272 = Math_fround($270 * $259);
  $273 = Math_fround($270 * $260);
  $274 = Math_fround($270 * $261);
  $275 = (($motion) + 164|0);
  $276 = Math_fround(HEAPF32[$275>>2]);
  $277 = (($output) + 164|0);
  $278 = Math_fround(HEAPF32[$277>>2]);
  $279 = Math_fround($276 - $278);
  $280 = (($motion) + 168|0);
  $281 = Math_fround(HEAPF32[$280>>2]);
  $282 = (($output) + 168|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = Math_fround($281 - $283);
  $285 = (($motion) + 172|0);
  $286 = Math_fround(HEAPF32[$285>>2]);
  $287 = (($output) + 172|0);
  $288 = Math_fround(HEAPF32[$287>>2]);
  $289 = Math_fround($286 - $288);
  $290 = (($motion) + 176|0);
  $291 = Math_fround(HEAPF32[$290>>2]);
  $292 = (($output) + 176|0);
  $293 = Math_fround(HEAPF32[$292>>2]);
  $294 = Math_fround($291 - $293);
  $295 = Math_fround($279 * $weight);
  $296 = Math_fround($284 * $weight);
  $297 = Math_fround($289 * $weight);
  $298 = Math_fround($294 * $weight);
  $299 = Math_fround($278 + $295);
  $300 = Math_fround($283 + $296);
  $301 = Math_fround($288 + $297);
  $302 = Math_fround($293 + $298);
  HEAPF32[$187>>2] = $209;
  HEAPF32[$192>>2] = $210;
  HEAPF32[$197>>2] = $211;
  HEAPF32[$202>>2] = $212;
  HEAPF32[$213>>2] = $271;
  HEAPF32[$218>>2] = $272;
  HEAPF32[$223>>2] = $273;
  HEAPF32[$228>>2] = $274;
  HEAPF32[$277>>2] = $299;
  HEAPF32[$282>>2] = $300;
  HEAPF32[$287>>2] = $301;
  HEAPF32[$292>>2] = $302;
  $303 = (($motion) + 180|0);
  $304 = Math_fround(HEAPF32[$303>>2]);
  $305 = (($output) + 180|0);
  $306 = Math_fround(HEAPF32[$305>>2]);
  $307 = Math_fround($304 - $306);
  $308 = (($motion) + 184|0);
  $309 = Math_fround(HEAPF32[$308>>2]);
  $310 = (($output) + 184|0);
  $311 = Math_fround(HEAPF32[$310>>2]);
  $312 = Math_fround($309 - $311);
  $313 = (($motion) + 188|0);
  $314 = Math_fround(HEAPF32[$313>>2]);
  $315 = (($output) + 188|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = Math_fround($314 - $316);
  $318 = (($motion) + 192|0);
  $319 = Math_fround(HEAPF32[$318>>2]);
  $320 = (($output) + 192|0);
  $321 = Math_fround(HEAPF32[$320>>2]);
  $322 = Math_fround($319 - $321);
  $323 = Math_fround($307 * $weight);
  $324 = Math_fround($312 * $weight);
  $325 = Math_fround($317 * $weight);
  $326 = Math_fround($322 * $weight);
  $327 = Math_fround($306 + $323);
  $328 = Math_fround($311 + $324);
  $329 = Math_fround($316 + $325);
  $330 = Math_fround($321 + $326);
  $331 = (($output) + 196|0);
  $332 = Math_fround(HEAPF32[$331>>2]);
  $333 = (($motion) + 196|0);
  $334 = Math_fround(HEAPF32[$333>>2]);
  $335 = Math_fround($332 * $334);
  $336 = (($output) + 200|0);
  $337 = Math_fround(HEAPF32[$336>>2]);
  $338 = (($motion) + 200|0);
  $339 = Math_fround(HEAPF32[$338>>2]);
  $340 = Math_fround($337 * $339);
  $341 = (($output) + 204|0);
  $342 = Math_fround(HEAPF32[$341>>2]);
  $343 = (($motion) + 204|0);
  $344 = Math_fround(HEAPF32[$343>>2]);
  $345 = Math_fround($342 * $344);
  $346 = (($output) + 208|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  $348 = (($motion) + 208|0);
  $349 = Math_fround(HEAPF32[$348>>2]);
  $350 = Math_fround($347 * $349);
  $351 = Math_fround($335 + $340);
  $352 = Math_fround($345 + $350);
  $353 = Math_fround($351 + $352);
  $354 = (HEAPF32[tempDoublePtr>>2]=$334,HEAP32[tempDoublePtr>>2]|0);
  $355 = (HEAPF32[tempDoublePtr>>2]=$353,HEAP32[tempDoublePtr>>2]|0);
  $356 = $355 & -2147483648;
  $357 = $356 ^ $354;
  $358 = (HEAP32[tempDoublePtr>>2]=$357,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $359 = (HEAPF32[tempDoublePtr>>2]=$339,HEAP32[tempDoublePtr>>2]|0);
  $360 = $356 ^ $359;
  $361 = (HEAP32[tempDoublePtr>>2]=$360,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $362 = (HEAPF32[tempDoublePtr>>2]=$344,HEAP32[tempDoublePtr>>2]|0);
  $363 = $356 ^ $362;
  $364 = (HEAP32[tempDoublePtr>>2]=$363,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $365 = (HEAPF32[tempDoublePtr>>2]=$349,HEAP32[tempDoublePtr>>2]|0);
  $366 = $356 ^ $365;
  $367 = (HEAP32[tempDoublePtr>>2]=$366,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $368 = Math_fround($358 - $332);
  $369 = Math_fround($361 - $337);
  $370 = Math_fround($364 - $342);
  $371 = Math_fround($367 - $347);
  $372 = Math_fround($368 * $weight);
  $373 = Math_fround($369 * $weight);
  $374 = Math_fround($370 * $weight);
  $375 = Math_fround($371 * $weight);
  $376 = Math_fround($332 + $372);
  $377 = Math_fround($337 + $373);
  $378 = Math_fround($342 + $374);
  $379 = Math_fround($347 + $375);
  $380 = Math_fround($376 * $376);
  $381 = Math_fround($377 * $377);
  $382 = Math_fround($378 * $378);
  $383 = Math_fround($379 * $379);
  $384 = Math_fround($380 + $381);
  $385 = Math_fround($382 + $383);
  $386 = Math_fround($384 + $385);
  $387 = (Math_fround(Math_sqrt((Math_fround($386)))));
  $388 = Math_fround(Math_fround(1.0) / $387);
  $389 = Math_fround($388 * $376);
  $390 = Math_fround($388 * $377);
  $391 = Math_fround($388 * $378);
  $392 = Math_fround($388 * $379);
  $393 = (($motion) + 212|0);
  $394 = Math_fround(HEAPF32[$393>>2]);
  $395 = (($output) + 212|0);
  $396 = Math_fround(HEAPF32[$395>>2]);
  $397 = Math_fround($394 - $396);
  $398 = (($motion) + 216|0);
  $399 = Math_fround(HEAPF32[$398>>2]);
  $400 = (($output) + 216|0);
  $401 = Math_fround(HEAPF32[$400>>2]);
  $402 = Math_fround($399 - $401);
  $403 = (($motion) + 220|0);
  $404 = Math_fround(HEAPF32[$403>>2]);
  $405 = (($output) + 220|0);
  $406 = Math_fround(HEAPF32[$405>>2]);
  $407 = Math_fround($404 - $406);
  $408 = (($motion) + 224|0);
  $409 = Math_fround(HEAPF32[$408>>2]);
  $410 = (($output) + 224|0);
  $411 = Math_fround(HEAPF32[$410>>2]);
  $412 = Math_fround($409 - $411);
  $413 = Math_fround($397 * $weight);
  $414 = Math_fround($402 * $weight);
  $415 = Math_fround($407 * $weight);
  $416 = Math_fround($412 * $weight);
  $417 = Math_fround($396 + $413);
  $418 = Math_fround($401 + $414);
  $419 = Math_fround($406 + $415);
  $420 = Math_fround($411 + $416);
  HEAPF32[$305>>2] = $327;
  HEAPF32[$310>>2] = $328;
  HEAPF32[$315>>2] = $329;
  HEAPF32[$320>>2] = $330;
  HEAPF32[$331>>2] = $389;
  HEAPF32[$336>>2] = $390;
  HEAPF32[$341>>2] = $391;
  HEAPF32[$346>>2] = $392;
  HEAPF32[$395>>2] = $417;
  HEAPF32[$400>>2] = $418;
  HEAPF32[$405>>2] = $419;
  HEAPF32[$410>>2] = $420;
 }
 if (!($isHuman)) {
  STACKTOP = sp;return;
 }
 $421 = HEAP32[$poseMask>>2]|0;
 $422 = $421 & 1;
 $423 = ($422|0)==(0);
 if (!($423)) {
  $424 = (($motion) + 228|0);
  $425 = Math_fround(HEAPF32[$424>>2]);
  $426 = (($output) + 228|0);
  $427 = Math_fround(HEAPF32[$426>>2]);
  $428 = Math_fround($425 - $427);
  $429 = (($motion) + 232|0);
  $430 = Math_fround(HEAPF32[$429>>2]);
  $431 = (($output) + 232|0);
  $432 = Math_fround(HEAPF32[$431>>2]);
  $433 = Math_fround($430 - $432);
  $434 = (($motion) + 236|0);
  $435 = Math_fround(HEAPF32[$434>>2]);
  $436 = (($output) + 236|0);
  $437 = Math_fround(HEAPF32[$436>>2]);
  $438 = Math_fround($435 - $437);
  $439 = (($motion) + 240|0);
  $440 = Math_fround(HEAPF32[$439>>2]);
  $441 = (($output) + 240|0);
  $442 = Math_fround(HEAPF32[$441>>2]);
  $443 = Math_fround($440 - $442);
  $444 = Math_fround($428 * $weight);
  $445 = Math_fround($433 * $weight);
  $446 = Math_fround($438 * $weight);
  $447 = Math_fround($443 * $weight);
  $448 = Math_fround($427 + $444);
  $449 = Math_fround($432 + $445);
  $450 = Math_fround($437 + $446);
  $451 = Math_fround($442 + $447);
  $452 = (($output) + 244|0);
  $453 = Math_fround(HEAPF32[$452>>2]);
  $454 = (($motion) + 244|0);
  $455 = Math_fround(HEAPF32[$454>>2]);
  $456 = Math_fround($453 * $455);
  $457 = (($output) + 248|0);
  $458 = Math_fround(HEAPF32[$457>>2]);
  $459 = (($motion) + 248|0);
  $460 = Math_fround(HEAPF32[$459>>2]);
  $461 = Math_fround($458 * $460);
  $462 = (($output) + 252|0);
  $463 = Math_fround(HEAPF32[$462>>2]);
  $464 = (($motion) + 252|0);
  $465 = Math_fround(HEAPF32[$464>>2]);
  $466 = Math_fround($463 * $465);
  $467 = (($output) + 256|0);
  $468 = Math_fround(HEAPF32[$467>>2]);
  $469 = (($motion) + 256|0);
  $470 = Math_fround(HEAPF32[$469>>2]);
  $471 = Math_fround($468 * $470);
  $472 = Math_fround($456 + $461);
  $473 = Math_fround($466 + $471);
  $474 = Math_fround($472 + $473);
  $475 = (HEAPF32[tempDoublePtr>>2]=$455,HEAP32[tempDoublePtr>>2]|0);
  $476 = (HEAPF32[tempDoublePtr>>2]=$474,HEAP32[tempDoublePtr>>2]|0);
  $477 = $476 & -2147483648;
  $478 = $477 ^ $475;
  $479 = (HEAP32[tempDoublePtr>>2]=$478,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $480 = (HEAPF32[tempDoublePtr>>2]=$460,HEAP32[tempDoublePtr>>2]|0);
  $481 = $477 ^ $480;
  $482 = (HEAP32[tempDoublePtr>>2]=$481,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $483 = (HEAPF32[tempDoublePtr>>2]=$465,HEAP32[tempDoublePtr>>2]|0);
  $484 = $477 ^ $483;
  $485 = (HEAP32[tempDoublePtr>>2]=$484,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $486 = (HEAPF32[tempDoublePtr>>2]=$470,HEAP32[tempDoublePtr>>2]|0);
  $487 = $477 ^ $486;
  $488 = (HEAP32[tempDoublePtr>>2]=$487,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $489 = Math_fround($479 - $453);
  $490 = Math_fround($482 - $458);
  $491 = Math_fround($485 - $463);
  $492 = Math_fround($488 - $468);
  $493 = Math_fround($489 * $weight);
  $494 = Math_fround($490 * $weight);
  $495 = Math_fround($491 * $weight);
  $496 = Math_fround($492 * $weight);
  $497 = Math_fround($453 + $493);
  $498 = Math_fround($458 + $494);
  $499 = Math_fround($463 + $495);
  $500 = Math_fround($468 + $496);
  $501 = Math_fround($497 * $497);
  $502 = Math_fround($498 * $498);
  $503 = Math_fround($499 * $499);
  $504 = Math_fround($500 * $500);
  $505 = Math_fround($501 + $502);
  $506 = Math_fround($503 + $504);
  $507 = Math_fround($505 + $506);
  $508 = (Math_fround(Math_sqrt((Math_fround($507)))));
  $509 = Math_fround(Math_fround(1.0) / $508);
  $510 = Math_fround($509 * $497);
  $511 = Math_fround($509 * $498);
  $512 = Math_fround($509 * $499);
  $513 = Math_fround($509 * $500);
  $514 = (($motion) + 260|0);
  $515 = Math_fround(HEAPF32[$514>>2]);
  $516 = (($output) + 260|0);
  $517 = Math_fround(HEAPF32[$516>>2]);
  $518 = Math_fround($515 - $517);
  $519 = (($motion) + 264|0);
  $520 = Math_fround(HEAPF32[$519>>2]);
  $521 = (($output) + 264|0);
  $522 = Math_fround(HEAPF32[$521>>2]);
  $523 = Math_fround($520 - $522);
  $524 = (($motion) + 268|0);
  $525 = Math_fround(HEAPF32[$524>>2]);
  $526 = (($output) + 268|0);
  $527 = Math_fround(HEAPF32[$526>>2]);
  $528 = Math_fround($525 - $527);
  $529 = (($motion) + 272|0);
  $530 = Math_fround(HEAPF32[$529>>2]);
  $531 = (($output) + 272|0);
  $532 = Math_fround(HEAPF32[$531>>2]);
  $533 = Math_fround($530 - $532);
  $534 = Math_fround($518 * $weight);
  $535 = Math_fround($523 * $weight);
  $536 = Math_fround($528 * $weight);
  $537 = Math_fround($533 * $weight);
  $538 = Math_fround($517 + $534);
  $539 = Math_fround($522 + $535);
  $540 = Math_fround($527 + $536);
  $541 = Math_fround($532 + $537);
  HEAPF32[$426>>2] = $448;
  HEAPF32[$431>>2] = $449;
  HEAPF32[$436>>2] = $450;
  HEAPF32[$441>>2] = $451;
  HEAPF32[$452>>2] = $510;
  HEAPF32[$457>>2] = $511;
  HEAPF32[$462>>2] = $512;
  HEAPF32[$467>>2] = $513;
  HEAPF32[$516>>2] = $538;
  HEAPF32[$521>>2] = $539;
  HEAPF32[$526>>2] = $540;
  HEAPF32[$531>>2] = $541;
  $542 = (($motion) + 372|0);
  $543 = Math_fround(HEAPF32[$542>>2]);
  $544 = (($output) + 372|0);
  $545 = Math_fround(HEAPF32[$544>>2]);
  $546 = Math_fround($543 - $545);
  $547 = (($motion) + 376|0);
  $548 = Math_fround(HEAPF32[$547>>2]);
  $549 = (($output) + 376|0);
  $550 = Math_fround(HEAPF32[$549>>2]);
  $551 = Math_fround($548 - $550);
  $552 = (($motion) + 380|0);
  $553 = Math_fround(HEAPF32[$552>>2]);
  $554 = (($output) + 380|0);
  $555 = Math_fround(HEAPF32[$554>>2]);
  $556 = Math_fround($553 - $555);
  $557 = (($motion) + 384|0);
  $558 = Math_fround(HEAPF32[$557>>2]);
  $559 = (($output) + 384|0);
  $560 = Math_fround(HEAPF32[$559>>2]);
  $561 = Math_fround($558 - $560);
  $562 = Math_fround($546 * $weight);
  $563 = Math_fround($551 * $weight);
  $564 = Math_fround($556 * $weight);
  $565 = Math_fround($561 * $weight);
  $566 = Math_fround($545 + $562);
  $567 = Math_fround($550 + $563);
  $568 = Math_fround($555 + $564);
  $569 = Math_fround($560 + $565);
  $570 = (($output) + 388|0);
  $571 = Math_fround(HEAPF32[$570>>2]);
  $572 = (($motion) + 388|0);
  $573 = Math_fround(HEAPF32[$572>>2]);
  $574 = Math_fround($571 * $573);
  $575 = (($output) + 392|0);
  $576 = Math_fround(HEAPF32[$575>>2]);
  $577 = (($motion) + 392|0);
  $578 = Math_fround(HEAPF32[$577>>2]);
  $579 = Math_fround($576 * $578);
  $580 = (($output) + 396|0);
  $581 = Math_fround(HEAPF32[$580>>2]);
  $582 = (($motion) + 396|0);
  $583 = Math_fround(HEAPF32[$582>>2]);
  $584 = Math_fround($581 * $583);
  $585 = (($output) + 400|0);
  $586 = Math_fround(HEAPF32[$585>>2]);
  $587 = (($motion) + 400|0);
  $588 = Math_fround(HEAPF32[$587>>2]);
  $589 = Math_fround($586 * $588);
  $590 = Math_fround($574 + $579);
  $591 = Math_fround($584 + $589);
  $592 = Math_fround($590 + $591);
  $593 = (HEAPF32[tempDoublePtr>>2]=$573,HEAP32[tempDoublePtr>>2]|0);
  $594 = (HEAPF32[tempDoublePtr>>2]=$592,HEAP32[tempDoublePtr>>2]|0);
  $595 = $594 & -2147483648;
  $596 = $595 ^ $593;
  $597 = (HEAP32[tempDoublePtr>>2]=$596,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $598 = (HEAPF32[tempDoublePtr>>2]=$578,HEAP32[tempDoublePtr>>2]|0);
  $599 = $595 ^ $598;
  $600 = (HEAP32[tempDoublePtr>>2]=$599,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $601 = (HEAPF32[tempDoublePtr>>2]=$583,HEAP32[tempDoublePtr>>2]|0);
  $602 = $595 ^ $601;
  $603 = (HEAP32[tempDoublePtr>>2]=$602,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $604 = (HEAPF32[tempDoublePtr>>2]=$588,HEAP32[tempDoublePtr>>2]|0);
  $605 = $595 ^ $604;
  $606 = (HEAP32[tempDoublePtr>>2]=$605,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $607 = Math_fround($597 - $571);
  $608 = Math_fround($600 - $576);
  $609 = Math_fround($603 - $581);
  $610 = Math_fround($606 - $586);
  $611 = Math_fround($607 * $weight);
  $612 = Math_fround($608 * $weight);
  $613 = Math_fround($609 * $weight);
  $614 = Math_fround($610 * $weight);
  $615 = Math_fround($571 + $611);
  $616 = Math_fround($576 + $612);
  $617 = Math_fround($581 + $613);
  $618 = Math_fround($586 + $614);
  $619 = Math_fround($615 * $615);
  $620 = Math_fround($616 * $616);
  $621 = Math_fround($617 * $617);
  $622 = Math_fround($618 * $618);
  $623 = Math_fround($619 + $620);
  $624 = Math_fround($621 + $622);
  $625 = Math_fround($623 + $624);
  $626 = (Math_fround(Math_sqrt((Math_fround($625)))));
  $627 = Math_fround(Math_fround(1.0) / $626);
  $628 = Math_fround($627 * $615);
  $629 = Math_fround($627 * $616);
  $630 = Math_fround($627 * $617);
  $631 = Math_fround($627 * $618);
  $632 = (($motion) + 404|0);
  $633 = Math_fround(HEAPF32[$632>>2]);
  $634 = (($output) + 404|0);
  $635 = Math_fround(HEAPF32[$634>>2]);
  $636 = Math_fround($633 - $635);
  $637 = (($motion) + 408|0);
  $638 = Math_fround(HEAPF32[$637>>2]);
  $639 = (($output) + 408|0);
  $640 = Math_fround(HEAPF32[$639>>2]);
  $641 = Math_fround($638 - $640);
  $642 = (($motion) + 412|0);
  $643 = Math_fround(HEAPF32[$642>>2]);
  $644 = (($output) + 412|0);
  $645 = Math_fround(HEAPF32[$644>>2]);
  $646 = Math_fround($643 - $645);
  $647 = (($motion) + 416|0);
  $648 = Math_fround(HEAPF32[$647>>2]);
  $649 = (($output) + 416|0);
  $650 = Math_fround(HEAPF32[$649>>2]);
  $651 = Math_fround($648 - $650);
  $652 = Math_fround($636 * $weight);
  $653 = Math_fround($641 * $weight);
  $654 = Math_fround($646 * $weight);
  $655 = Math_fround($651 * $weight);
  $656 = Math_fround($635 + $652);
  $657 = Math_fround($640 + $653);
  $658 = Math_fround($645 + $654);
  $659 = Math_fround($650 + $655);
  HEAPF32[$544>>2] = $566;
  HEAPF32[$549>>2] = $567;
  HEAPF32[$554>>2] = $568;
  HEAPF32[$559>>2] = $569;
  HEAPF32[$570>>2] = $628;
  HEAPF32[$575>>2] = $629;
  HEAPF32[$580>>2] = $630;
  HEAPF32[$585>>2] = $631;
  HEAPF32[$634>>2] = $656;
  HEAPF32[$639>>2] = $657;
  HEAPF32[$644>>2] = $658;
  HEAPF32[$649>>2] = $659;
 }
 $660 = (__ZN7mecanim5human19MaskHasLeftFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
 if ($660) {
  $661 = (($motion) + 276|0);
  $662 = Math_fround(HEAPF32[$661>>2]);
  $663 = (($output) + 276|0);
  $664 = Math_fround(HEAPF32[$663>>2]);
  $665 = Math_fround($662 - $664);
  $666 = (($motion) + 280|0);
  $667 = Math_fround(HEAPF32[$666>>2]);
  $668 = (($output) + 280|0);
  $669 = Math_fround(HEAPF32[$668>>2]);
  $670 = Math_fround($667 - $669);
  $671 = (($motion) + 284|0);
  $672 = Math_fround(HEAPF32[$671>>2]);
  $673 = (($output) + 284|0);
  $674 = Math_fround(HEAPF32[$673>>2]);
  $675 = Math_fround($672 - $674);
  $676 = (($motion) + 288|0);
  $677 = Math_fround(HEAPF32[$676>>2]);
  $678 = (($output) + 288|0);
  $679 = Math_fround(HEAPF32[$678>>2]);
  $680 = Math_fround($677 - $679);
  $681 = Math_fround($665 * $weight);
  $682 = Math_fround($670 * $weight);
  $683 = Math_fround($675 * $weight);
  $684 = Math_fround($680 * $weight);
  $685 = Math_fround($664 + $681);
  $686 = Math_fround($669 + $682);
  $687 = Math_fround($674 + $683);
  $688 = Math_fround($679 + $684);
  $689 = (($output) + 292|0);
  $690 = Math_fround(HEAPF32[$689>>2]);
  $691 = (($motion) + 292|0);
  $692 = Math_fround(HEAPF32[$691>>2]);
  $693 = Math_fround($690 * $692);
  $694 = (($output) + 296|0);
  $695 = Math_fround(HEAPF32[$694>>2]);
  $696 = (($motion) + 296|0);
  $697 = Math_fround(HEAPF32[$696>>2]);
  $698 = Math_fround($695 * $697);
  $699 = (($output) + 300|0);
  $700 = Math_fround(HEAPF32[$699>>2]);
  $701 = (($motion) + 300|0);
  $702 = Math_fround(HEAPF32[$701>>2]);
  $703 = Math_fround($700 * $702);
  $704 = (($output) + 304|0);
  $705 = Math_fround(HEAPF32[$704>>2]);
  $706 = (($motion) + 304|0);
  $707 = Math_fround(HEAPF32[$706>>2]);
  $708 = Math_fround($705 * $707);
  $709 = Math_fround($693 + $698);
  $710 = Math_fround($703 + $708);
  $711 = Math_fround($709 + $710);
  $712 = (HEAPF32[tempDoublePtr>>2]=$692,HEAP32[tempDoublePtr>>2]|0);
  $713 = (HEAPF32[tempDoublePtr>>2]=$711,HEAP32[tempDoublePtr>>2]|0);
  $714 = $713 & -2147483648;
  $715 = $714 ^ $712;
  $716 = (HEAP32[tempDoublePtr>>2]=$715,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $717 = (HEAPF32[tempDoublePtr>>2]=$697,HEAP32[tempDoublePtr>>2]|0);
  $718 = $714 ^ $717;
  $719 = (HEAP32[tempDoublePtr>>2]=$718,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $720 = (HEAPF32[tempDoublePtr>>2]=$702,HEAP32[tempDoublePtr>>2]|0);
  $721 = $714 ^ $720;
  $722 = (HEAP32[tempDoublePtr>>2]=$721,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $723 = (HEAPF32[tempDoublePtr>>2]=$707,HEAP32[tempDoublePtr>>2]|0);
  $724 = $714 ^ $723;
  $725 = (HEAP32[tempDoublePtr>>2]=$724,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $726 = Math_fround($716 - $690);
  $727 = Math_fround($719 - $695);
  $728 = Math_fround($722 - $700);
  $729 = Math_fround($725 - $705);
  $730 = Math_fround($726 * $weight);
  $731 = Math_fround($727 * $weight);
  $732 = Math_fround($728 * $weight);
  $733 = Math_fround($729 * $weight);
  $734 = Math_fround($690 + $730);
  $735 = Math_fround($695 + $731);
  $736 = Math_fround($700 + $732);
  $737 = Math_fround($705 + $733);
  $738 = Math_fround($734 * $734);
  $739 = Math_fround($735 * $735);
  $740 = Math_fround($736 * $736);
  $741 = Math_fround($737 * $737);
  $742 = Math_fround($738 + $739);
  $743 = Math_fround($740 + $741);
  $744 = Math_fround($742 + $743);
  $745 = (Math_fround(Math_sqrt((Math_fround($744)))));
  $746 = Math_fround(Math_fround(1.0) / $745);
  $747 = Math_fround($746 * $734);
  $748 = Math_fround($746 * $735);
  $749 = Math_fround($746 * $736);
  $750 = Math_fround($746 * $737);
  $751 = (($motion) + 308|0);
  $752 = Math_fround(HEAPF32[$751>>2]);
  $753 = (($output) + 308|0);
  $754 = Math_fround(HEAPF32[$753>>2]);
  $755 = Math_fround($752 - $754);
  $756 = (($motion) + 312|0);
  $757 = Math_fround(HEAPF32[$756>>2]);
  $758 = (($output) + 312|0);
  $759 = Math_fround(HEAPF32[$758>>2]);
  $760 = Math_fround($757 - $759);
  $761 = (($motion) + 316|0);
  $762 = Math_fround(HEAPF32[$761>>2]);
  $763 = (($output) + 316|0);
  $764 = Math_fround(HEAPF32[$763>>2]);
  $765 = Math_fround($762 - $764);
  $766 = (($motion) + 320|0);
  $767 = Math_fround(HEAPF32[$766>>2]);
  $768 = (($output) + 320|0);
  $769 = Math_fround(HEAPF32[$768>>2]);
  $770 = Math_fround($767 - $769);
  $771 = Math_fround($755 * $weight);
  $772 = Math_fround($760 * $weight);
  $773 = Math_fround($765 * $weight);
  $774 = Math_fround($770 * $weight);
  $775 = Math_fround($754 + $771);
  $776 = Math_fround($759 + $772);
  $777 = Math_fround($764 + $773);
  $778 = Math_fround($769 + $774);
  HEAPF32[$663>>2] = $685;
  HEAPF32[$668>>2] = $686;
  HEAPF32[$673>>2] = $687;
  HEAPF32[$678>>2] = $688;
  HEAPF32[$689>>2] = $747;
  HEAPF32[$694>>2] = $748;
  HEAPF32[$699>>2] = $749;
  HEAPF32[$704>>2] = $750;
  HEAPF32[$753>>2] = $775;
  HEAPF32[$758>>2] = $776;
  HEAPF32[$763>>2] = $777;
  HEAPF32[$768>>2] = $778;
 }
 $779 = (__ZN7mecanim5human20MaskHasRightFootGoalERKNS_6bitsetILj59EEE($poseMask)|0);
 if ($779) {
  $780 = (($motion) + 324|0);
  $781 = Math_fround(HEAPF32[$780>>2]);
  $782 = (($output) + 324|0);
  $783 = Math_fround(HEAPF32[$782>>2]);
  $784 = Math_fround($781 - $783);
  $785 = (($motion) + 328|0);
  $786 = Math_fround(HEAPF32[$785>>2]);
  $787 = (($output) + 328|0);
  $788 = Math_fround(HEAPF32[$787>>2]);
  $789 = Math_fround($786 - $788);
  $790 = (($motion) + 332|0);
  $791 = Math_fround(HEAPF32[$790>>2]);
  $792 = (($output) + 332|0);
  $793 = Math_fround(HEAPF32[$792>>2]);
  $794 = Math_fround($791 - $793);
  $795 = (($motion) + 336|0);
  $796 = Math_fround(HEAPF32[$795>>2]);
  $797 = (($output) + 336|0);
  $798 = Math_fround(HEAPF32[$797>>2]);
  $799 = Math_fround($796 - $798);
  $800 = Math_fround($784 * $weight);
  $801 = Math_fround($789 * $weight);
  $802 = Math_fround($794 * $weight);
  $803 = Math_fround($799 * $weight);
  $804 = Math_fround($783 + $800);
  $805 = Math_fround($788 + $801);
  $806 = Math_fround($793 + $802);
  $807 = Math_fround($798 + $803);
  $808 = (($output) + 340|0);
  $809 = Math_fround(HEAPF32[$808>>2]);
  $810 = (($motion) + 340|0);
  $811 = Math_fround(HEAPF32[$810>>2]);
  $812 = Math_fround($809 * $811);
  $813 = (($output) + 344|0);
  $814 = Math_fround(HEAPF32[$813>>2]);
  $815 = (($motion) + 344|0);
  $816 = Math_fround(HEAPF32[$815>>2]);
  $817 = Math_fround($814 * $816);
  $818 = (($output) + 348|0);
  $819 = Math_fround(HEAPF32[$818>>2]);
  $820 = (($motion) + 348|0);
  $821 = Math_fround(HEAPF32[$820>>2]);
  $822 = Math_fround($819 * $821);
  $823 = (($output) + 352|0);
  $824 = Math_fround(HEAPF32[$823>>2]);
  $825 = (($motion) + 352|0);
  $826 = Math_fround(HEAPF32[$825>>2]);
  $827 = Math_fround($824 * $826);
  $828 = Math_fround($812 + $817);
  $829 = Math_fround($822 + $827);
  $830 = Math_fround($828 + $829);
  $831 = (HEAPF32[tempDoublePtr>>2]=$811,HEAP32[tempDoublePtr>>2]|0);
  $832 = (HEAPF32[tempDoublePtr>>2]=$830,HEAP32[tempDoublePtr>>2]|0);
  $833 = $832 & -2147483648;
  $834 = $833 ^ $831;
  $835 = (HEAP32[tempDoublePtr>>2]=$834,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $836 = (HEAPF32[tempDoublePtr>>2]=$816,HEAP32[tempDoublePtr>>2]|0);
  $837 = $833 ^ $836;
  $838 = (HEAP32[tempDoublePtr>>2]=$837,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $839 = (HEAPF32[tempDoublePtr>>2]=$821,HEAP32[tempDoublePtr>>2]|0);
  $840 = $833 ^ $839;
  $841 = (HEAP32[tempDoublePtr>>2]=$840,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $842 = (HEAPF32[tempDoublePtr>>2]=$826,HEAP32[tempDoublePtr>>2]|0);
  $843 = $833 ^ $842;
  $844 = (HEAP32[tempDoublePtr>>2]=$843,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $845 = Math_fround($835 - $809);
  $846 = Math_fround($838 - $814);
  $847 = Math_fround($841 - $819);
  $848 = Math_fround($844 - $824);
  $849 = Math_fround($845 * $weight);
  $850 = Math_fround($846 * $weight);
  $851 = Math_fround($847 * $weight);
  $852 = Math_fround($848 * $weight);
  $853 = Math_fround($809 + $849);
  $854 = Math_fround($814 + $850);
  $855 = Math_fround($819 + $851);
  $856 = Math_fround($824 + $852);
  $857 = Math_fround($853 * $853);
  $858 = Math_fround($854 * $854);
  $859 = Math_fround($855 * $855);
  $860 = Math_fround($856 * $856);
  $861 = Math_fround($857 + $858);
  $862 = Math_fround($859 + $860);
  $863 = Math_fround($861 + $862);
  $864 = (Math_fround(Math_sqrt((Math_fround($863)))));
  $865 = Math_fround(Math_fround(1.0) / $864);
  $866 = Math_fround($865 * $853);
  $867 = Math_fround($865 * $854);
  $868 = Math_fround($865 * $855);
  $869 = Math_fround($865 * $856);
  $870 = (($motion) + 356|0);
  $871 = Math_fround(HEAPF32[$870>>2]);
  $872 = (($output) + 356|0);
  $873 = Math_fround(HEAPF32[$872>>2]);
  $874 = Math_fround($871 - $873);
  $875 = (($motion) + 360|0);
  $876 = Math_fround(HEAPF32[$875>>2]);
  $877 = (($output) + 360|0);
  $878 = Math_fround(HEAPF32[$877>>2]);
  $879 = Math_fround($876 - $878);
  $880 = (($motion) + 364|0);
  $881 = Math_fround(HEAPF32[$880>>2]);
  $882 = (($output) + 364|0);
  $883 = Math_fround(HEAPF32[$882>>2]);
  $884 = Math_fround($881 - $883);
  $885 = (($motion) + 368|0);
  $886 = Math_fround(HEAPF32[$885>>2]);
  $887 = (($output) + 368|0);
  $888 = Math_fround(HEAPF32[$887>>2]);
  $889 = Math_fround($886 - $888);
  $890 = Math_fround($874 * $weight);
  $891 = Math_fround($879 * $weight);
  $892 = Math_fround($884 * $weight);
  $893 = Math_fround($889 * $weight);
  $894 = Math_fround($873 + $890);
  $895 = Math_fround($878 + $891);
  $896 = Math_fround($883 + $892);
  $897 = Math_fround($888 + $893);
  HEAPF32[$782>>2] = $804;
  HEAPF32[$787>>2] = $805;
  HEAPF32[$792>>2] = $806;
  HEAPF32[$797>>2] = $807;
  HEAPF32[$808>>2] = $866;
  HEAPF32[$813>>2] = $867;
  HEAPF32[$818>>2] = $868;
  HEAPF32[$823>>2] = $869;
  HEAPF32[$872>>2] = $894;
  HEAPF32[$877>>2] = $895;
  HEAPF32[$882>>2] = $896;
  HEAPF32[$887>>2] = $897;
 }
 $898 = (($motion) + 424|0);
 $899 = Math_fround(HEAPF32[$898>>2]);
 $900 = Math_fround($899 * $weight);
 $901 = (($motion) + 428|0);
 $902 = Math_fround(HEAPF32[$901>>2]);
 $903 = Math_fround($902 * $weight);
 $904 = (($motion) + 432|0);
 $905 = Math_fround(HEAPF32[$904>>2]);
 $906 = Math_fround($905 * $weight);
 $907 = (($motion) + 436|0);
 $908 = Math_fround(HEAPF32[$907>>2]);
 $909 = Math_fround($908 * $weight);
 $910 = (($output) + 424|0);
 HEAPF32[$910>>2] = $900;
 $911 = (($output) + 428|0);
 HEAPF32[$911>>2] = $903;
 $912 = (($output) + 432|0);
 HEAPF32[$912>>2] = $906;
 $913 = (($output) + 436|0);
 HEAPF32[$913>>2] = $909;
 $914 = (($motion) + 440|0);
 $915 = Math_fround(HEAPF32[$914>>2]);
 $916 = Math_fround($915 * $weight);
 $917 = (($motion) + 444|0);
 $918 = Math_fround(HEAPF32[$917>>2]);
 $919 = Math_fround($918 * $weight);
 $920 = (($motion) + 448|0);
 $921 = Math_fround(HEAPF32[$920>>2]);
 $922 = Math_fround($921 * $weight);
 $923 = (($motion) + 452|0);
 $924 = Math_fround(HEAPF32[$923>>2]);
 $925 = Math_fround($924 * $weight);
 $926 = (($output) + 440|0);
 HEAPF32[$926>>2] = $916;
 $927 = (($output) + 444|0);
 HEAPF32[$927>>2] = $919;
 $928 = (($output) + 448|0);
 HEAPF32[$928>>2] = $922;
 $929 = (($output) + 452|0);
 HEAPF32[$929>>2] = $925;
 $930 = (($output) + 456|0);
 $931 = Math_fround(HEAPF32[$930>>2]);
 $932 = (($motion) + 456|0);
 $933 = Math_fround(HEAPF32[$932>>2]);
 $934 = Math_fround($933 - $931);
 $935 = Math_fround($934 * $weight);
 $936 = Math_fround($931 + $935);
 HEAPF32[$930>>2] = $936;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation28MotionOutputGetDeltaPositionEPKNS0_12MotionOutputE($agg$result,$output) {
 $agg$result = $agg$result|0;
 $output = $output|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$output>>2]);
 $1 = (($output) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($output) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($0 * $5);
 $7 = (($output) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($0 * $8);
 $10 = (($output) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($0 * $11);
 HEAPF32[$agg$result>>2] = $3;
 $13 = (($agg$result) + 4|0);
 HEAPF32[$13>>2] = $6;
 $14 = (($agg$result) + 8|0);
 HEAPF32[$14>>2] = $9;
 $15 = (($agg$result) + 12|0);
 HEAPF32[$15>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation28MotionOutputGetDeltaRotationEPKNS0_12MotionOutputE($agg$result,$output) {
 $agg$result = $agg$result|0;
 $output = $output|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$output>>2]);
 $1 = (($output) + 20|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($output) + 24|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($0 * $5);
 $7 = (($output) + 28|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($0 * $8);
 $10 = (($output) + 32|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($0 * $11);
 $13 = Math_fround($3 * $3);
 $14 = Math_fround($6 * $6);
 $15 = Math_fround($9 * $9);
 $16 = Math_fround($12 * $12);
 $17 = Math_fround($13 + $14);
 $18 = Math_fround($15 + $16);
 $19 = Math_fround($17 + $18);
 $20 = (Math_fround(Math_sqrt((Math_fround($19)))));
 $21 = Math_fround($20 * Math_fround(0.5));
 $22 = (Math_fround(+(Math_sin((+$21)))));
 $23 = (Math_fround(+(Math_cos((+$21)))));
 $24 = Math_fround($3 * $22);
 $25 = Math_fround($24 / $20);
 $26 = Math_fround($6 * $22);
 $27 = Math_fround($26 / $20);
 $28 = Math_fround($9 * $22);
 $29 = Math_fround($28 / $20);
 $30 = $20 == Math_fround(0.0);
 $31 = $30 ? Math_fround(0.0) : $25;
 $32 = $30 ? Math_fround(0.0) : $27;
 $33 = $30 ? Math_fround(0.0) : $29;
 $34 = $30 ? Math_fround(1.0) : $23;
 HEAPF32[$agg$result>>2] = $31;
 $35 = (($agg$result) + 4|0);
 HEAPF32[$35>>2] = $32;
 $36 = (($agg$result) + 8|0);
 HEAPF32[$36>>2] = $33;
 $37 = (($agg$result) + 12|0);
 HEAPF32[$37>>2] = $34;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation29MotionOutputGetDeltaTransformEPKNS0_12MotionOutputE($agg$result,$output) {
 $agg$result = $agg$result|0;
 $output = $output|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$output>>2]);
 $1 = (($output) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($output) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($0 * $5);
 $7 = (($output) + 12|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($0 * $8);
 $10 = (($output) + 16|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($0 * $11);
 $13 = (($output) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($0 * $14);
 $16 = (($output) + 24|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($0 * $17);
 $19 = (($output) + 28|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($0 * $20);
 $22 = (($output) + 32|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($0 * $23);
 $25 = Math_fround($15 * $15);
 $26 = Math_fround($18 * $18);
 $27 = Math_fround($21 * $21);
 $28 = Math_fround($24 * $24);
 $29 = Math_fround($25 + $26);
 $30 = Math_fround($27 + $28);
 $31 = Math_fround($29 + $30);
 $32 = (Math_fround(Math_sqrt((Math_fround($31)))));
 $33 = Math_fround($32 * Math_fround(0.5));
 $34 = (Math_fround(+(Math_sin((+$33)))));
 $35 = (Math_fround(+(Math_cos((+$33)))));
 $36 = Math_fround($15 * $34);
 $37 = Math_fround($36 / $32);
 $38 = Math_fround($18 * $34);
 $39 = Math_fround($38 / $32);
 $40 = Math_fround($21 * $34);
 $41 = Math_fround($40 / $32);
 $42 = $32 == Math_fround(0.0);
 $43 = $42 ? Math_fround(0.0) : $37;
 $44 = $42 ? Math_fround(0.0) : $39;
 $45 = $42 ? Math_fround(0.0) : $41;
 $46 = $42 ? Math_fround(1.0) : $35;
 HEAPF32[$agg$result>>2] = $3;
 $47 = (($agg$result) + 4|0);
 HEAPF32[$47>>2] = $6;
 $48 = (($agg$result) + 8|0);
 HEAPF32[$48>>2] = $9;
 $49 = (($agg$result) + 12|0);
 HEAPF32[$49>>2] = $12;
 $50 = (($agg$result) + 16|0);
 HEAPF32[$50>>2] = $43;
 $51 = (($agg$result) + 20|0);
 HEAPF32[$51>>2] = $44;
 $52 = (($agg$result) + 24|0);
 HEAPF32[$52>>2] = $45;
 $53 = (($agg$result) + 28|0);
 HEAPF32[$53>>2] = $46;
 $54 = (($agg$result) + 32|0);
 HEAPF32[$54>>2] = Math_fround(1.0);
 $55 = (($agg$result) + 36|0);
 HEAPF32[$55>>2] = Math_fround(1.0);
 $56 = (($agg$result) + 40|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($agg$result) + 44|0);
 HEAPF32[$57>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation28MotionOutputSetDeltaPositionEPNS0_12MotionOutputERKN4math7_float4E($output,$deltaPosition) {
 $output = $output|0;
 $deltaPosition = $deltaPosition|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0);
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$output>>2]);
 $1 = Math_fround(HEAPF32[$deltaPosition>>2]);
 $2 = Math_fround($1 / $0);
 $3 = (($deltaPosition) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 / $0);
 $6 = (($deltaPosition) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 / $0);
 $9 = (($deltaPosition) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 / $0);
 $12 = $0 > Math_fround(0.0);
 $13 = $12 ? $2 : Math_fround(0.0);
 $14 = $12 ? $5 : Math_fround(0.0);
 $15 = $12 ? $8 : Math_fround(0.0);
 $16 = $12 ? $11 : Math_fround(0.0);
 $17 = (($output) + 4|0);
 HEAPF32[$17>>2] = $13;
 $18 = (($output) + 8|0);
 HEAPF32[$18>>2] = $14;
 $19 = (($output) + 12|0);
 HEAPF32[$19>>2] = $15;
 $20 = (($output) + 16|0);
 HEAPF32[$20>>2] = $16;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation29MotionOutputSetDeltaTransformEPNS0_12MotionOutputERKN4math5xformE($output,$deltaTransform) {
 $output = $output|0;
 $deltaTransform = $deltaTransform|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$output>>2]);
 $1 = Math_fround(HEAPF32[$deltaTransform>>2]);
 $2 = Math_fround($1 / $0);
 $3 = (($deltaTransform) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 / $0);
 $6 = (($deltaTransform) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 / $0);
 $9 = (($deltaTransform) + 12|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 / $0);
 $12 = $0 > Math_fround(0.0);
 $13 = $12 ? $2 : Math_fround(0.0);
 $14 = $12 ? $5 : Math_fround(0.0);
 $15 = $12 ? $8 : Math_fround(0.0);
 $16 = $12 ? $11 : Math_fround(0.0);
 $17 = (($output) + 4|0);
 HEAPF32[$17>>2] = $13;
 $18 = (($output) + 8|0);
 HEAPF32[$18>>2] = $14;
 $19 = (($output) + 12|0);
 HEAPF32[$19>>2] = $15;
 $20 = (($output) + 16|0);
 HEAPF32[$20>>2] = $16;
 $21 = (($deltaTransform) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $22);
 $24 = (($deltaTransform) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $25);
 $27 = (($deltaTransform) + 24|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * $28);
 $30 = (($deltaTransform) + 28|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * $31);
 $33 = Math_fround($23 + $26);
 $34 = Math_fround($29 + $32);
 $35 = Math_fround($33 + $34);
 $36 = (Math_fround(Math_sqrt((Math_fround($35)))));
 $37 = Math_fround(Math_fround(1.0) / $36);
 $38 = Math_fround($22 * $37);
 $39 = Math_fround($25 * $37);
 $40 = Math_fround($28 * $37);
 $41 = Math_fround($38 * $38);
 $42 = Math_fround($39 * $39);
 $43 = Math_fround($40 * $40);
 $44 = Math_fround($41 + $42);
 $45 = Math_fround($43 + Math_fround(0.0));
 $46 = Math_fround($44 + $45);
 $47 = (Math_fround(Math_sqrt((Math_fround($46)))));
 $48 = (Math_fround(+(Math_asin((+$47)))));
 $49 = Math_fround($48 * Math_fround(2.0));
 $50 = Math_fround($38 * $49);
 $51 = Math_fround($50 / $47);
 $52 = Math_fround($39 * $49);
 $53 = Math_fround($52 / $47);
 $54 = Math_fround($40 * $49);
 $55 = Math_fround($54 / $47);
 $56 = $47 != Math_fround(0.0);
 $57 = $56 ? $51 : Math_fround(0.0);
 $58 = $56 ? $53 : Math_fround(0.0);
 $59 = $56 ? $55 : Math_fround(0.0);
 $60 = Math_fround($57 / $0);
 $61 = Math_fround($58 / $0);
 $62 = Math_fround($59 / $0);
 $63 = Math_fround(Math_fround(0.0) / $0);
 $64 = $12 ? $60 : Math_fround(0.0);
 $65 = $12 ? $61 : Math_fround(0.0);
 $66 = $12 ? $62 : Math_fround(0.0);
 $67 = $12 ? $63 : Math_fround(0.0);
 $68 = (($output) + 20|0);
 HEAPF32[$68>>2] = $64;
 $69 = (($output) + 24|0);
 HEAPF32[$69>>2] = $65;
 $70 = (($output) + 28|0);
 HEAPF32[$70>>2] = $66;
 $71 = (($output) + 32|0);
 HEAPF32[$71>>2] = $67;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation15ComputeClipTimeEffffbbRfS1_($normalizedTimeIn,$startTime,$stopTime,$cycleOffset,$loop,$reverse,$normalizedTimeOut,$timeInt) {
 $normalizedTimeIn = Math_fround($normalizedTimeIn);
 $startTime = Math_fround($startTime);
 $stopTime = Math_fround($stopTime);
 $cycleOffset = Math_fround($cycleOffset);
 $loop = $loop|0;
 $reverse = $reverse|0;
 $normalizedTimeOut = $normalizedTimeOut|0;
 $timeInt = $timeInt|0;
 var $$v = Math_fround(0), $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(+(_fmaxf(0.0,(+$normalizedTimeIn)))));
 $1 = (Math_fround(+(_fminf(1.0,(+$0)))));
 $2 = Math_fround($normalizedTimeIn + $cycleOffset);
 $3 = (Math_fround(+(_modff((+$2),($timeInt|0)))));
 $$v = $loop ? $3 : $1;
 $4 = Math_fround(Math_fround(1.0) - $$v);
 $5 = $reverse&1;
 $6 = $5 ^ 1;
 $7 = (0 - ($6))|0;
 $8 = (HEAPF32[tempDoublePtr>>2]=$4,HEAP32[tempDoublePtr>>2]|0);
 $9 = (HEAPF32[tempDoublePtr>>2]=$$v,HEAP32[tempDoublePtr>>2]|0);
 $10 = $reverse ? $8 : 0;
 $11 = $9 & $7;
 $12 = $10 | $11;
 $13 = (HEAP32[tempDoublePtr>>2]=$12,Math_fround(HEAPF32[tempDoublePtr>>2]));
 HEAPF32[$normalizedTimeOut>>2] = $13;
 $14 = Math_fround($stopTime - $startTime);
 $15 = Math_fround($14 * $13);
 $16 = Math_fround($15 + $startTime);
 STACKTOP = sp;return (Math_fround($16));
}
function __ZN7mecanim9animation14EvaluateMotionERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($agg$result,$constant,$memory,$time) {
 $agg$result = $agg$result|0;
 $constant = $constant|0;
 $memory = $memory|0;
 $time = Math_fround($time);
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0;
 var $99 = 0, $clipIn = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $clipIn = sp;
 $0 = (($agg$result) + 28|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($agg$result) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($agg$result) + 40|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($agg$result) + 32|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 HEAPF32[$clipIn>>2] = $time;
 $5 = (($constant) + 1072|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $35 = Math_fround(0.0);
 } else {
  $8 = (($constant) + 1040|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + ($9))|0;
  $12 = $11;
  $13 = (($constant) + 1044|0);
  HEAP32[$13>>2] = $12;
  $14 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($12,$clipIn,$memory,$6)));
  $35 = $14;
 }
 $15 = (($constant) + 1076|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 if ($17) {
  $37 = Math_fround(0.0);
 } else {
  $18 = (($constant) + 1040|0);
  $19 = $18;
  $20 = HEAP32[$18>>2]|0;
  $21 = (($20) + ($19))|0;
  $22 = $21;
  $23 = (($constant) + 1044|0);
  HEAP32[$23>>2] = $22;
  $24 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($22,$clipIn,$memory,$16)));
  $37 = $24;
 }
 $25 = (($constant) + 1080|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(-1);
 if ($27) {
  $39 = Math_fround(0.0);
 } else {
  $28 = (($constant) + 1040|0);
  $29 = $28;
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + ($29))|0;
  $32 = $31;
  $33 = (($constant) + 1044|0);
  HEAP32[$33>>2] = $32;
  $34 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($32,$clipIn,$memory,$26)));
  $39 = $34;
 }
 HEAPF32[$agg$result>>2] = $35;
 $36 = (($agg$result) + 4|0);
 HEAPF32[$36>>2] = $37;
 $38 = (($agg$result) + 8|0);
 HEAPF32[$38>>2] = $39;
 $40 = (($agg$result) + 12|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($constant) + 1084|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(-1);
 if ($43) {
  $82 = Math_fround(0.0);
 } else {
  $44 = (($constant) + 1040|0);
  $45 = $44;
  $46 = HEAP32[$44>>2]|0;
  $47 = (($46) + ($45))|0;
  $48 = $47;
  $49 = (($constant) + 1044|0);
  HEAP32[$49>>2] = $48;
  $50 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($48,$clipIn,$memory,$42)));
  $82 = $50;
 }
 $51 = (($constant) + 1088|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(-1);
 if ($53) {
  $84 = Math_fround(0.0);
 } else {
  $54 = (($constant) + 1040|0);
  $55 = $54;
  $56 = HEAP32[$54>>2]|0;
  $57 = (($56) + ($55))|0;
  $58 = $57;
  $59 = (($constant) + 1044|0);
  HEAP32[$59>>2] = $58;
  $60 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($58,$clipIn,$memory,$52)));
  $84 = $60;
 }
 $61 = (($constant) + 1092|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(-1);
 if ($63) {
  $86 = Math_fround(0.0);
 } else {
  $64 = (($constant) + 1040|0);
  $65 = $64;
  $66 = HEAP32[$64>>2]|0;
  $67 = (($66) + ($65))|0;
  $68 = $67;
  $69 = (($constant) + 1044|0);
  HEAP32[$69>>2] = $68;
  $70 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($68,$clipIn,$memory,$62)));
  $86 = $70;
 }
 $71 = (($constant) + 1096|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(-1);
 if ($73) {
  $88 = Math_fround(1.0);
  $81 = Math_fround($82 * $82);
  $83 = Math_fround($84 * $84);
  $85 = Math_fround($86 * $86);
  $87 = Math_fround($88 * $88);
  $89 = Math_fround($81 + $83);
  $90 = Math_fround($85 + $87);
  $91 = Math_fround($89 + $90);
  $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
  $93 = Math_fround(Math_fround(1.0) / $92);
  $94 = Math_fround($82 * $93);
  $95 = Math_fround($84 * $93);
  $96 = Math_fround($86 * $93);
  $97 = Math_fround($88 * $93);
  $98 = (($agg$result) + 16|0);
  HEAPF32[$98>>2] = $94;
  $99 = (($agg$result) + 20|0);
  HEAPF32[$99>>2] = $95;
  $100 = (($agg$result) + 24|0);
  HEAPF32[$100>>2] = $96;
  HEAPF32[$0>>2] = $97;
  STACKTOP = sp;return;
 }
 $74 = (($constant) + 1040|0);
 $75 = $74;
 $76 = HEAP32[$74>>2]|0;
 $77 = (($76) + ($75))|0;
 $78 = $77;
 $79 = (($constant) + 1044|0);
 HEAP32[$79>>2] = $78;
 $80 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($78,$clipIn,$memory,$72)));
 $88 = $80;
 $81 = Math_fround($82 * $82);
 $83 = Math_fround($84 * $84);
 $85 = Math_fround($86 * $86);
 $87 = Math_fround($88 * $88);
 $89 = Math_fround($81 + $83);
 $90 = Math_fround($85 + $87);
 $91 = Math_fround($89 + $90);
 $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
 $93 = Math_fround(Math_fround(1.0) / $92);
 $94 = Math_fround($82 * $93);
 $95 = Math_fround($84 * $93);
 $96 = Math_fround($86 * $93);
 $97 = Math_fround($88 * $93);
 $98 = (($agg$result) + 16|0);
 HEAPF32[$98>>2] = $94;
 $99 = (($agg$result) + 20|0);
 HEAPF32[$99>>2] = $95;
 $100 = (($agg$result) + 24|0);
 HEAPF32[$100>>2] = $96;
 HEAPF32[$0>>2] = $97;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12EvaluateRootERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($agg$result,$constant,$memory,$time) {
 $agg$result = $agg$result|0;
 $constant = $constant|0;
 $memory = $memory|0;
 $time = Math_fround($time);
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0;
 var $99 = 0, $clipIn = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $clipIn = sp;
 $0 = (($agg$result) + 28|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($agg$result) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($agg$result) + 40|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($agg$result) + 32|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 HEAPF32[$clipIn>>2] = $time;
 $5 = (($constant) + 1100|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $35 = Math_fround(0.0);
 } else {
  $8 = (($constant) + 1040|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + ($9))|0;
  $12 = $11;
  $13 = (($constant) + 1044|0);
  HEAP32[$13>>2] = $12;
  $14 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($12,$clipIn,$memory,$6)));
  $35 = $14;
 }
 $15 = (($constant) + 1104|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 if ($17) {
  $37 = Math_fround(0.0);
 } else {
  $18 = (($constant) + 1040|0);
  $19 = $18;
  $20 = HEAP32[$18>>2]|0;
  $21 = (($20) + ($19))|0;
  $22 = $21;
  $23 = (($constant) + 1044|0);
  HEAP32[$23>>2] = $22;
  $24 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($22,$clipIn,$memory,$16)));
  $37 = $24;
 }
 $25 = (($constant) + 1108|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(-1);
 if ($27) {
  $39 = Math_fround(0.0);
 } else {
  $28 = (($constant) + 1040|0);
  $29 = $28;
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + ($29))|0;
  $32 = $31;
  $33 = (($constant) + 1044|0);
  HEAP32[$33>>2] = $32;
  $34 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($32,$clipIn,$memory,$26)));
  $39 = $34;
 }
 HEAPF32[$agg$result>>2] = $35;
 $36 = (($agg$result) + 4|0);
 HEAPF32[$36>>2] = $37;
 $38 = (($agg$result) + 8|0);
 HEAPF32[$38>>2] = $39;
 $40 = (($agg$result) + 12|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($constant) + 1112|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(-1);
 if ($43) {
  $82 = Math_fround(0.0);
 } else {
  $44 = (($constant) + 1040|0);
  $45 = $44;
  $46 = HEAP32[$44>>2]|0;
  $47 = (($46) + ($45))|0;
  $48 = $47;
  $49 = (($constant) + 1044|0);
  HEAP32[$49>>2] = $48;
  $50 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($48,$clipIn,$memory,$42)));
  $82 = $50;
 }
 $51 = (($constant) + 1116|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(-1);
 if ($53) {
  $84 = Math_fround(0.0);
 } else {
  $54 = (($constant) + 1040|0);
  $55 = $54;
  $56 = HEAP32[$54>>2]|0;
  $57 = (($56) + ($55))|0;
  $58 = $57;
  $59 = (($constant) + 1044|0);
  HEAP32[$59>>2] = $58;
  $60 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($58,$clipIn,$memory,$52)));
  $84 = $60;
 }
 $61 = (($constant) + 1120|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(-1);
 if ($63) {
  $86 = Math_fround(0.0);
 } else {
  $64 = (($constant) + 1040|0);
  $65 = $64;
  $66 = HEAP32[$64>>2]|0;
  $67 = (($66) + ($65))|0;
  $68 = $67;
  $69 = (($constant) + 1044|0);
  HEAP32[$69>>2] = $68;
  $70 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($68,$clipIn,$memory,$62)));
  $86 = $70;
 }
 $71 = (($constant) + 1124|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(-1);
 if ($73) {
  $88 = Math_fround(1.0);
  $81 = Math_fround($82 * $82);
  $83 = Math_fround($84 * $84);
  $85 = Math_fround($86 * $86);
  $87 = Math_fround($88 * $88);
  $89 = Math_fround($81 + $83);
  $90 = Math_fround($85 + $87);
  $91 = Math_fround($89 + $90);
  $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
  $93 = Math_fround(Math_fround(1.0) / $92);
  $94 = Math_fround($82 * $93);
  $95 = Math_fround($84 * $93);
  $96 = Math_fround($86 * $93);
  $97 = Math_fround($88 * $93);
  $98 = (($agg$result) + 16|0);
  HEAPF32[$98>>2] = $94;
  $99 = (($agg$result) + 20|0);
  HEAPF32[$99>>2] = $95;
  $100 = (($agg$result) + 24|0);
  HEAPF32[$100>>2] = $96;
  HEAPF32[$0>>2] = $97;
  STACKTOP = sp;return;
 }
 $74 = (($constant) + 1040|0);
 $75 = $74;
 $76 = HEAP32[$74>>2]|0;
 $77 = (($76) + ($75))|0;
 $78 = $77;
 $79 = (($constant) + 1044|0);
 HEAP32[$79>>2] = $78;
 $80 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($78,$clipIn,$memory,$72)));
 $88 = $80;
 $81 = Math_fround($82 * $82);
 $83 = Math_fround($84 * $84);
 $85 = Math_fround($86 * $86);
 $87 = Math_fround($88 * $88);
 $89 = Math_fround($81 + $83);
 $90 = Math_fround($85 + $87);
 $91 = Math_fround($89 + $90);
 $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
 $93 = Math_fround(Math_fround(1.0) / $92);
 $94 = Math_fround($82 * $93);
 $95 = Math_fround($84 * $93);
 $96 = Math_fround($86 * $93);
 $97 = Math_fround($88 * $93);
 $98 = (($agg$result) + 16|0);
 HEAPF32[$98>>2] = $94;
 $99 = (($agg$result) + 20|0);
 HEAPF32[$99>>2] = $95;
 $100 = (($agg$result) + 24|0);
 HEAPF32[$100>>2] = $96;
 HEAPF32[$0>>2] = $97;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12EvaluateGoalERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEfi($agg$result,$constant,$memory,$time,$goalIndex) {
 $agg$result = $agg$result|0;
 $constant = $constant|0;
 $memory = $memory|0;
 $time = Math_fround($time);
 $goalIndex = $goalIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $clipIn = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $clipIn = sp;
 $0 = (($agg$result) + 28|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($agg$result) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($agg$result) + 40|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($agg$result) + 32|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = ($goalIndex*7)|0;
 $6 = (($5) + 14)|0;
 HEAPF32[$clipIn>>2] = $time;
 $7 = ((($constant) + ($6<<2)|0) + 1072|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(-1);
 if ($9) {
  $42 = Math_fround(0.0);
 } else {
  $10 = (($constant) + 1040|0);
  $11 = $10;
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + ($11))|0;
  $14 = $13;
  $15 = (($constant) + 1044|0);
  HEAP32[$15>>2] = $14;
  $16 = HEAP32[$7>>2]|0;
  $17 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($14,$clipIn,$memory,$16)));
  $42 = $17;
 }
 $18 = (($5) + 15)|0;
 $19 = ((($constant) + ($18<<2)|0) + 1072|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(-1);
 if ($21) {
  $44 = Math_fround(0.0);
 } else {
  $22 = (($constant) + 1040|0);
  $23 = $22;
  $24 = HEAP32[$22>>2]|0;
  $25 = (($24) + ($23))|0;
  $26 = $25;
  $27 = (($constant) + 1044|0);
  HEAP32[$27>>2] = $26;
  $28 = HEAP32[$19>>2]|0;
  $29 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($26,$clipIn,$memory,$28)));
  $44 = $29;
 }
 $30 = (($5) + 16)|0;
 $31 = ((($constant) + ($30<<2)|0) + 1072|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(-1);
 if ($33) {
  $46 = Math_fround(0.0);
 } else {
  $34 = (($constant) + 1040|0);
  $35 = $34;
  $36 = HEAP32[$34>>2]|0;
  $37 = (($36) + ($35))|0;
  $38 = $37;
  $39 = (($constant) + 1044|0);
  HEAP32[$39>>2] = $38;
  $40 = HEAP32[$31>>2]|0;
  $41 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($38,$clipIn,$memory,$40)));
  $46 = $41;
 }
 HEAPF32[$agg$result>>2] = $42;
 $43 = (($agg$result) + 4|0);
 HEAPF32[$43>>2] = $44;
 $45 = (($agg$result) + 8|0);
 HEAPF32[$45>>2] = $46;
 $47 = (($agg$result) + 12|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($5) + 17)|0;
 $49 = ((($constant) + ($48<<2)|0) + 1072|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(-1);
 if ($51) {
  $97 = Math_fround(0.0);
 } else {
  $52 = (($constant) + 1040|0);
  $53 = $52;
  $54 = HEAP32[$52>>2]|0;
  $55 = (($54) + ($53))|0;
  $56 = $55;
  $57 = (($constant) + 1044|0);
  HEAP32[$57>>2] = $56;
  $58 = HEAP32[$49>>2]|0;
  $59 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($56,$clipIn,$memory,$58)));
  $97 = $59;
 }
 $60 = (($5) + 18)|0;
 $61 = ((($constant) + ($60<<2)|0) + 1072|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(-1);
 if ($63) {
  $99 = Math_fround(0.0);
 } else {
  $64 = (($constant) + 1040|0);
  $65 = $64;
  $66 = HEAP32[$64>>2]|0;
  $67 = (($66) + ($65))|0;
  $68 = $67;
  $69 = (($constant) + 1044|0);
  HEAP32[$69>>2] = $68;
  $70 = HEAP32[$61>>2]|0;
  $71 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($68,$clipIn,$memory,$70)));
  $99 = $71;
 }
 $72 = (($5) + 19)|0;
 $73 = ((($constant) + ($72<<2)|0) + 1072|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(-1);
 if ($75) {
  $101 = Math_fround(0.0);
 } else {
  $76 = (($constant) + 1040|0);
  $77 = $76;
  $78 = HEAP32[$76>>2]|0;
  $79 = (($78) + ($77))|0;
  $80 = $79;
  $81 = (($constant) + 1044|0);
  HEAP32[$81>>2] = $80;
  $82 = HEAP32[$73>>2]|0;
  $83 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($80,$clipIn,$memory,$82)));
  $101 = $83;
 }
 $84 = (($5) + 20)|0;
 $85 = ((($constant) + ($84<<2)|0) + 1072|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(-1);
 if ($87) {
  $103 = Math_fround(1.0);
  $96 = Math_fround($97 * $97);
  $98 = Math_fround($99 * $99);
  $100 = Math_fround($101 * $101);
  $102 = Math_fround($103 * $103);
  $104 = Math_fround($96 + $98);
  $105 = Math_fround($100 + $102);
  $106 = Math_fround($104 + $105);
  $107 = (Math_fround(Math_sqrt((Math_fround($106)))));
  $108 = Math_fround(Math_fround(1.0) / $107);
  $109 = Math_fround($97 * $108);
  $110 = Math_fround($99 * $108);
  $111 = Math_fround($101 * $108);
  $112 = Math_fround($103 * $108);
  $113 = (($agg$result) + 16|0);
  HEAPF32[$113>>2] = $109;
  $114 = (($agg$result) + 20|0);
  HEAPF32[$114>>2] = $110;
  $115 = (($agg$result) + 24|0);
  HEAPF32[$115>>2] = $111;
  HEAPF32[$0>>2] = $112;
  STACKTOP = sp;return;
 }
 $88 = (($constant) + 1040|0);
 $89 = $88;
 $90 = HEAP32[$88>>2]|0;
 $91 = (($90) + ($89))|0;
 $92 = $91;
 $93 = (($constant) + 1044|0);
 HEAP32[$93>>2] = $92;
 $94 = HEAP32[$85>>2]|0;
 $95 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($92,$clipIn,$memory,$94)));
 $103 = $95;
 $96 = Math_fround($97 * $97);
 $98 = Math_fround($99 * $99);
 $100 = Math_fround($101 * $101);
 $102 = Math_fround($103 * $103);
 $104 = Math_fround($96 + $98);
 $105 = Math_fround($100 + $102);
 $106 = Math_fround($104 + $105);
 $107 = (Math_fround(Math_sqrt((Math_fround($106)))));
 $108 = Math_fround(Math_fround(1.0) / $107);
 $109 = Math_fround($97 * $108);
 $110 = Math_fround($99 * $108);
 $111 = Math_fround($101 * $108);
 $112 = Math_fround($103 * $108);
 $113 = (($agg$result) + 16|0);
 HEAPF32[$113>>2] = $109;
 $114 = (($agg$result) + 20|0);
 HEAPF32[$114>>2] = $110;
 $115 = (($agg$result) + 24|0);
 HEAPF32[$115>>2] = $111;
 HEAPF32[$0>>2] = $112;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation15GetMotionStartXERKNS0_18ClipMuscleConstantE($agg$result,$constant) {
 $agg$result = $agg$result|0;
 $constant = $constant|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $value$sroa$0$0 = Math_fround(0), $value$sroa$0$1 = Math_fround(0), $value$sroa$1$0 = Math_fround(0), $value$sroa$1$1 = Math_fround(0), $value$sroa$2$0 = Math_fround(0), $value$sroa$2$1 = Math_fround(0);
 var $value$sroa$3$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 28|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($agg$result) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($agg$result) + 40|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($agg$result) + 32|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($constant) + 1072|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $value$sroa$0$0 = Math_fround(0.0);
 } else {
  $8 = (($constant) + 1624|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + ($9))|0;
  $12 = $11;
  $13 = (($12) + ($6<<3)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $value$sroa$0$0 = $14;
 }
 $15 = (($constant) + 1076|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 if ($17) {
  $value$sroa$1$0 = Math_fround(0.0);
 } else {
  $18 = (($constant) + 1624|0);
  $19 = $18;
  $20 = HEAP32[$18>>2]|0;
  $21 = (($20) + ($19))|0;
  $22 = $21;
  $23 = (($22) + ($16<<3)|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $value$sroa$1$0 = $24;
 }
 $25 = (($constant) + 1080|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(-1);
 if ($27) {
  $value$sroa$2$0 = Math_fround(0.0);
 } else {
  $28 = (($constant) + 1624|0);
  $29 = $28;
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + ($29))|0;
  $32 = $31;
  $33 = (($32) + ($26<<3)|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $value$sroa$2$0 = $34;
 }
 HEAPF32[$agg$result>>2] = $value$sroa$0$0;
 $35 = (($agg$result) + 4|0);
 HEAPF32[$35>>2] = $value$sroa$1$0;
 $36 = (($agg$result) + 8|0);
 HEAPF32[$36>>2] = $value$sroa$2$0;
 $37 = (($agg$result) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($constant) + 1084|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(-1);
 if ($40) {
  $value$sroa$0$1 = Math_fround(0.0);
 } else {
  $41 = (($constant) + 1624|0);
  $42 = $41;
  $43 = HEAP32[$41>>2]|0;
  $44 = (($43) + ($42))|0;
  $45 = $44;
  $46 = (($45) + ($39<<3)|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $value$sroa$0$1 = $47;
 }
 $48 = (($constant) + 1088|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(-1);
 if ($50) {
  $value$sroa$1$1 = Math_fround(0.0);
 } else {
  $51 = (($constant) + 1624|0);
  $52 = $51;
  $53 = HEAP32[$51>>2]|0;
  $54 = (($53) + ($52))|0;
  $55 = $54;
  $56 = (($55) + ($49<<3)|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $value$sroa$1$1 = $57;
 }
 $58 = (($constant) + 1092|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(-1);
 if ($60) {
  $value$sroa$2$1 = Math_fround(0.0);
 } else {
  $61 = (($constant) + 1624|0);
  $62 = $61;
  $63 = HEAP32[$61>>2]|0;
  $64 = (($63) + ($62))|0;
  $65 = $64;
  $66 = (($65) + ($59<<3)|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $value$sroa$2$1 = $67;
 }
 $68 = (($constant) + 1096|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(-1);
 if ($70) {
  $value$sroa$3$0 = Math_fround(1.0);
 } else {
  $71 = (($constant) + 1624|0);
  $72 = $71;
  $73 = HEAP32[$71>>2]|0;
  $74 = (($73) + ($72))|0;
  $75 = $74;
  $76 = (($75) + ($69<<3)|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $value$sroa$3$0 = $77;
 }
 $78 = Math_fround($value$sroa$0$1 * $value$sroa$0$1);
 $79 = Math_fround($value$sroa$1$1 * $value$sroa$1$1);
 $80 = Math_fround($value$sroa$2$1 * $value$sroa$2$1);
 $81 = Math_fround($value$sroa$3$0 * $value$sroa$3$0);
 $82 = Math_fround($78 + $79);
 $83 = Math_fround($80 + $81);
 $84 = Math_fround($82 + $83);
 $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
 $86 = Math_fround(Math_fround(1.0) / $85);
 $87 = Math_fround($value$sroa$0$1 * $86);
 $88 = Math_fround($value$sroa$1$1 * $86);
 $89 = Math_fround($value$sroa$2$1 * $86);
 $90 = Math_fround($value$sroa$3$0 * $86);
 $91 = (($agg$result) + 16|0);
 HEAPF32[$91>>2] = $87;
 $92 = (($agg$result) + 20|0);
 HEAPF32[$92>>2] = $88;
 $93 = (($agg$result) + 24|0);
 HEAPF32[$93>>2] = $89;
 HEAPF32[$0>>2] = $90;
 HEAPF32[$4>>2] = Math_fround(1.0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation14GetMotionStopXERKNS0_18ClipMuscleConstantE($agg$result,$constant) {
 $agg$result = $agg$result|0;
 $constant = $constant|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $value$sroa$0$0 = Math_fround(0), $value$sroa$0$1 = Math_fround(0), $value$sroa$1$0 = Math_fround(0), $value$sroa$1$1 = Math_fround(0), $value$sroa$2$0 = Math_fround(0), $value$sroa$2$1 = Math_fround(0);
 var $value$sroa$3$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 28|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($agg$result) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($agg$result) + 40|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($agg$result) + 32|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($constant) + 1072|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $value$sroa$0$0 = Math_fround(0.0);
 } else {
  $8 = (($constant) + 1624|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + ($9))|0;
  $12 = $11;
  $13 = ((($12) + ($6<<3)|0) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $value$sroa$0$0 = $14;
 }
 $15 = (($constant) + 1076|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 if ($17) {
  $value$sroa$1$0 = Math_fround(0.0);
 } else {
  $18 = (($constant) + 1624|0);
  $19 = $18;
  $20 = HEAP32[$18>>2]|0;
  $21 = (($20) + ($19))|0;
  $22 = $21;
  $23 = ((($22) + ($16<<3)|0) + 4|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $value$sroa$1$0 = $24;
 }
 $25 = (($constant) + 1080|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(-1);
 if ($27) {
  $value$sroa$2$0 = Math_fround(0.0);
 } else {
  $28 = (($constant) + 1624|0);
  $29 = $28;
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + ($29))|0;
  $32 = $31;
  $33 = ((($32) + ($26<<3)|0) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $value$sroa$2$0 = $34;
 }
 HEAPF32[$agg$result>>2] = $value$sroa$0$0;
 $35 = (($agg$result) + 4|0);
 HEAPF32[$35>>2] = $value$sroa$1$0;
 $36 = (($agg$result) + 8|0);
 HEAPF32[$36>>2] = $value$sroa$2$0;
 $37 = (($agg$result) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($constant) + 1084|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(-1);
 if ($40) {
  $value$sroa$0$1 = Math_fround(0.0);
 } else {
  $41 = (($constant) + 1624|0);
  $42 = $41;
  $43 = HEAP32[$41>>2]|0;
  $44 = (($43) + ($42))|0;
  $45 = $44;
  $46 = ((($45) + ($39<<3)|0) + 4|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $value$sroa$0$1 = $47;
 }
 $48 = (($constant) + 1088|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(-1);
 if ($50) {
  $value$sroa$1$1 = Math_fround(0.0);
 } else {
  $51 = (($constant) + 1624|0);
  $52 = $51;
  $53 = HEAP32[$51>>2]|0;
  $54 = (($53) + ($52))|0;
  $55 = $54;
  $56 = ((($55) + ($49<<3)|0) + 4|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $value$sroa$1$1 = $57;
 }
 $58 = (($constant) + 1092|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(-1);
 if ($60) {
  $value$sroa$2$1 = Math_fround(0.0);
 } else {
  $61 = (($constant) + 1624|0);
  $62 = $61;
  $63 = HEAP32[$61>>2]|0;
  $64 = (($63) + ($62))|0;
  $65 = $64;
  $66 = ((($65) + ($59<<3)|0) + 4|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $value$sroa$2$1 = $67;
 }
 $68 = (($constant) + 1096|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(-1);
 if ($70) {
  $value$sroa$3$0 = Math_fround(1.0);
 } else {
  $71 = (($constant) + 1624|0);
  $72 = $71;
  $73 = HEAP32[$71>>2]|0;
  $74 = (($73) + ($72))|0;
  $75 = $74;
  $76 = ((($75) + ($69<<3)|0) + 4|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $value$sroa$3$0 = $77;
 }
 $78 = Math_fround($value$sroa$0$1 * $value$sroa$0$1);
 $79 = Math_fround($value$sroa$1$1 * $value$sroa$1$1);
 $80 = Math_fround($value$sroa$2$1 * $value$sroa$2$1);
 $81 = Math_fround($value$sroa$3$0 * $value$sroa$3$0);
 $82 = Math_fround($78 + $79);
 $83 = Math_fround($80 + $81);
 $84 = Math_fround($82 + $83);
 $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
 $86 = Math_fround(Math_fround(1.0) / $85);
 $87 = Math_fround($value$sroa$0$1 * $86);
 $88 = Math_fround($value$sroa$1$1 * $86);
 $89 = Math_fround($value$sroa$2$1 * $86);
 $90 = Math_fround($value$sroa$3$0 * $86);
 $91 = (($agg$result) + 16|0);
 HEAPF32[$91>>2] = $87;
 $92 = (($agg$result) + 20|0);
 HEAPF32[$92>>2] = $88;
 $93 = (($agg$result) + 24|0);
 HEAPF32[$93>>2] = $89;
 HEAPF32[$0>>2] = $90;
 HEAPF32[$4>>2] = Math_fround(1.0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation13GetRootStartXERKNS0_18ClipMuscleConstantE($agg$result,$constant) {
 $agg$result = $agg$result|0;
 $constant = $constant|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $value$sroa$0$0 = Math_fround(0), $value$sroa$0$1 = Math_fround(0), $value$sroa$1$0 = Math_fround(0), $value$sroa$1$1 = Math_fround(0), $value$sroa$2$0 = Math_fround(0), $value$sroa$2$1 = Math_fround(0);
 var $value$sroa$3$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 28|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($agg$result) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($agg$result) + 40|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($agg$result) + 32|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($constant) + 1100|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $value$sroa$0$0 = Math_fround(0.0);
 } else {
  $8 = (($constant) + 1624|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + ($9))|0;
  $12 = $11;
  $13 = (($12) + ($6<<3)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $value$sroa$0$0 = $14;
 }
 $15 = (($constant) + 1104|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 if ($17) {
  $value$sroa$1$0 = Math_fround(0.0);
 } else {
  $18 = (($constant) + 1624|0);
  $19 = $18;
  $20 = HEAP32[$18>>2]|0;
  $21 = (($20) + ($19))|0;
  $22 = $21;
  $23 = (($22) + ($16<<3)|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $value$sroa$1$0 = $24;
 }
 $25 = (($constant) + 1108|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(-1);
 if ($27) {
  $value$sroa$2$0 = Math_fround(0.0);
 } else {
  $28 = (($constant) + 1624|0);
  $29 = $28;
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + ($29))|0;
  $32 = $31;
  $33 = (($32) + ($26<<3)|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $value$sroa$2$0 = $34;
 }
 HEAPF32[$agg$result>>2] = $value$sroa$0$0;
 $35 = (($agg$result) + 4|0);
 HEAPF32[$35>>2] = $value$sroa$1$0;
 $36 = (($agg$result) + 8|0);
 HEAPF32[$36>>2] = $value$sroa$2$0;
 $37 = (($agg$result) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($constant) + 1112|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(-1);
 if ($40) {
  $value$sroa$0$1 = Math_fround(0.0);
 } else {
  $41 = (($constant) + 1624|0);
  $42 = $41;
  $43 = HEAP32[$41>>2]|0;
  $44 = (($43) + ($42))|0;
  $45 = $44;
  $46 = (($45) + ($39<<3)|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $value$sroa$0$1 = $47;
 }
 $48 = (($constant) + 1116|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(-1);
 if ($50) {
  $value$sroa$1$1 = Math_fround(0.0);
 } else {
  $51 = (($constant) + 1624|0);
  $52 = $51;
  $53 = HEAP32[$51>>2]|0;
  $54 = (($53) + ($52))|0;
  $55 = $54;
  $56 = (($55) + ($49<<3)|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $value$sroa$1$1 = $57;
 }
 $58 = (($constant) + 1120|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(-1);
 if ($60) {
  $value$sroa$2$1 = Math_fround(0.0);
 } else {
  $61 = (($constant) + 1624|0);
  $62 = $61;
  $63 = HEAP32[$61>>2]|0;
  $64 = (($63) + ($62))|0;
  $65 = $64;
  $66 = (($65) + ($59<<3)|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $value$sroa$2$1 = $67;
 }
 $68 = (($constant) + 1124|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(-1);
 if ($70) {
  $value$sroa$3$0 = Math_fround(1.0);
 } else {
  $71 = (($constant) + 1624|0);
  $72 = $71;
  $73 = HEAP32[$71>>2]|0;
  $74 = (($73) + ($72))|0;
  $75 = $74;
  $76 = (($75) + ($69<<3)|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $value$sroa$3$0 = $77;
 }
 $78 = Math_fround($value$sroa$0$1 * $value$sroa$0$1);
 $79 = Math_fround($value$sroa$1$1 * $value$sroa$1$1);
 $80 = Math_fround($value$sroa$2$1 * $value$sroa$2$1);
 $81 = Math_fround($value$sroa$3$0 * $value$sroa$3$0);
 $82 = Math_fround($78 + $79);
 $83 = Math_fround($80 + $81);
 $84 = Math_fround($82 + $83);
 $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
 $86 = Math_fround(Math_fround(1.0) / $85);
 $87 = Math_fround($value$sroa$0$1 * $86);
 $88 = Math_fround($value$sroa$1$1 * $86);
 $89 = Math_fround($value$sroa$2$1 * $86);
 $90 = Math_fround($value$sroa$3$0 * $86);
 $91 = (($agg$result) + 16|0);
 HEAPF32[$91>>2] = $87;
 $92 = (($agg$result) + 20|0);
 HEAPF32[$92>>2] = $88;
 $93 = (($agg$result) + 24|0);
 HEAPF32[$93>>2] = $89;
 HEAPF32[$0>>2] = $90;
 HEAPF32[$4>>2] = Math_fround(1.0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12GetRootStopXERKNS0_18ClipMuscleConstantE($agg$result,$constant) {
 $agg$result = $agg$result|0;
 $constant = $constant|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $value$sroa$0$0 = Math_fround(0), $value$sroa$0$1 = Math_fround(0), $value$sroa$1$0 = Math_fround(0), $value$sroa$1$1 = Math_fround(0), $value$sroa$2$0 = Math_fround(0), $value$sroa$2$1 = Math_fround(0);
 var $value$sroa$3$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 28|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($agg$result) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($agg$result) + 40|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($agg$result) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($agg$result) + 32|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($constant) + 1100|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $value$sroa$0$0 = Math_fround(0.0);
 } else {
  $8 = (($constant) + 1624|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + ($9))|0;
  $12 = $11;
  $13 = ((($12) + ($6<<3)|0) + 4|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $value$sroa$0$0 = $14;
 }
 $15 = (($constant) + 1104|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(-1);
 if ($17) {
  $value$sroa$1$0 = Math_fround(0.0);
 } else {
  $18 = (($constant) + 1624|0);
  $19 = $18;
  $20 = HEAP32[$18>>2]|0;
  $21 = (($20) + ($19))|0;
  $22 = $21;
  $23 = ((($22) + ($16<<3)|0) + 4|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $value$sroa$1$0 = $24;
 }
 $25 = (($constant) + 1108|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(-1);
 if ($27) {
  $value$sroa$2$0 = Math_fround(0.0);
 } else {
  $28 = (($constant) + 1624|0);
  $29 = $28;
  $30 = HEAP32[$28>>2]|0;
  $31 = (($30) + ($29))|0;
  $32 = $31;
  $33 = ((($32) + ($26<<3)|0) + 4|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $value$sroa$2$0 = $34;
 }
 HEAPF32[$agg$result>>2] = $value$sroa$0$0;
 $35 = (($agg$result) + 4|0);
 HEAPF32[$35>>2] = $value$sroa$1$0;
 $36 = (($agg$result) + 8|0);
 HEAPF32[$36>>2] = $value$sroa$2$0;
 $37 = (($agg$result) + 12|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($constant) + 1112|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(-1);
 if ($40) {
  $value$sroa$0$1 = Math_fround(0.0);
 } else {
  $41 = (($constant) + 1624|0);
  $42 = $41;
  $43 = HEAP32[$41>>2]|0;
  $44 = (($43) + ($42))|0;
  $45 = $44;
  $46 = ((($45) + ($39<<3)|0) + 4|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $value$sroa$0$1 = $47;
 }
 $48 = (($constant) + 1116|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(-1);
 if ($50) {
  $value$sroa$1$1 = Math_fround(0.0);
 } else {
  $51 = (($constant) + 1624|0);
  $52 = $51;
  $53 = HEAP32[$51>>2]|0;
  $54 = (($53) + ($52))|0;
  $55 = $54;
  $56 = ((($55) + ($49<<3)|0) + 4|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $value$sroa$1$1 = $57;
 }
 $58 = (($constant) + 1120|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(-1);
 if ($60) {
  $value$sroa$2$1 = Math_fround(0.0);
 } else {
  $61 = (($constant) + 1624|0);
  $62 = $61;
  $63 = HEAP32[$61>>2]|0;
  $64 = (($63) + ($62))|0;
  $65 = $64;
  $66 = ((($65) + ($59<<3)|0) + 4|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $value$sroa$2$1 = $67;
 }
 $68 = (($constant) + 1124|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(-1);
 if ($70) {
  $value$sroa$3$0 = Math_fround(1.0);
 } else {
  $71 = (($constant) + 1624|0);
  $72 = $71;
  $73 = HEAP32[$71>>2]|0;
  $74 = (($73) + ($72))|0;
  $75 = $74;
  $76 = ((($75) + ($69<<3)|0) + 4|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $value$sroa$3$0 = $77;
 }
 $78 = Math_fround($value$sroa$0$1 * $value$sroa$0$1);
 $79 = Math_fround($value$sroa$1$1 * $value$sroa$1$1);
 $80 = Math_fround($value$sroa$2$1 * $value$sroa$2$1);
 $81 = Math_fround($value$sroa$3$0 * $value$sroa$3$0);
 $82 = Math_fround($78 + $79);
 $83 = Math_fround($80 + $81);
 $84 = Math_fround($82 + $83);
 $85 = (Math_fround(Math_sqrt((Math_fround($84)))));
 $86 = Math_fround(Math_fround(1.0) / $85);
 $87 = Math_fround($value$sroa$0$1 * $86);
 $88 = Math_fround($value$sroa$1$1 * $86);
 $89 = Math_fround($value$sroa$2$1 * $86);
 $90 = Math_fround($value$sroa$3$0 * $86);
 $91 = (($agg$result) + 16|0);
 HEAPF32[$91>>2] = $87;
 $92 = (($agg$result) + 20|0);
 HEAPF32[$92>>2] = $88;
 $93 = (($agg$result) + 24|0);
 HEAPF32[$93>>2] = $89;
 HEAPF32[$0>>2] = $90;
 HEAPF32[$4>>2] = Math_fround(1.0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12GetHumanPoseIfEEvRKNS0_18ClipMuscleConstantEPKT_RNS_5human9HumanPoseE($constant,$values,$humanPose) {
 $constant = $constant|0;
 $values = $values|0;
 $humanPose = $humanPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0);
 var $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $currentCurveIndex$034 = 0, $currentCurveIndex$132 = 0, $currentCurveIndex$229 = 0, $currentCurveIndex$326 = 0, $exitcond = 0, $exitcond35 = 0, $exitcond36 = 0, $exitcond37 = 0, $i$033 = 0, $i$131 = 0;
 var $i$228 = 0, $i$325 = 0, $value$sroa$0$0 = Math_fround(0), $value$sroa$0$1 = Math_fround(0), $value$sroa$0$2 = Math_fround(0), $value$sroa$0$3 = Math_fround(0), $value$sroa$1$0 = Math_fround(0), $value$sroa$1$1 = Math_fround(0), $value$sroa$1$2 = Math_fround(0), $value$sroa$1$3 = Math_fround(0), $value$sroa$2$0 = Math_fround(0), $value$sroa$2$1 = Math_fround(0), $value$sroa$2$2 = Math_fround(0), $value$sroa$2$3 = Math_fround(0), $value$sroa$3$0 = Math_fround(0), $value$sroa$3$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($constant) + 1100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $value$sroa$0$0 = Math_fround(0.0);
 } else {
  $3 = (($values) + ($1<<2)|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $value$sroa$0$0 = $4;
 }
 $5 = (($constant) + 1104|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $value$sroa$1$0 = Math_fround(0.0);
 } else {
  $8 = (($values) + ($6<<2)|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $value$sroa$1$0 = $9;
 }
 $10 = (($constant) + 1108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(-1);
 if ($12) {
  $value$sroa$2$0 = Math_fround(0.0);
 } else {
  $13 = (($values) + ($11<<2)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $value$sroa$2$0 = $14;
 }
 HEAPF32[$humanPose>>2] = $value$sroa$0$0;
 $15 = (($humanPose) + 4|0);
 HEAPF32[$15>>2] = $value$sroa$1$0;
 $16 = (($humanPose) + 8|0);
 HEAPF32[$16>>2] = $value$sroa$2$0;
 $17 = (($humanPose) + 12|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($constant) + 1112|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(-1);
 if ($20) {
  $value$sroa$0$1 = Math_fround(0.0);
 } else {
  $21 = (($values) + ($19<<2)|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $value$sroa$0$1 = $22;
 }
 $23 = (($constant) + 1116|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(-1);
 if ($25) {
  $value$sroa$1$1 = Math_fround(0.0);
 } else {
  $26 = (($values) + ($24<<2)|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $value$sroa$1$1 = $27;
 }
 $28 = (($constant) + 1120|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(-1);
 if ($30) {
  $value$sroa$2$1 = Math_fround(0.0);
 } else {
  $31 = (($values) + ($29<<2)|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $value$sroa$2$1 = $32;
 }
 $33 = (($constant) + 1124|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $value$sroa$3$0 = Math_fround(1.0);
 } else {
  $36 = (($values) + ($34<<2)|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $value$sroa$3$0 = $37;
 }
 $38 = Math_fround($value$sroa$0$1 * $value$sroa$0$1);
 $39 = Math_fround($value$sroa$1$1 * $value$sroa$1$1);
 $40 = Math_fround($value$sroa$2$1 * $value$sroa$2$1);
 $41 = Math_fround($value$sroa$3$0 * $value$sroa$3$0);
 $42 = Math_fround($38 + $39);
 $43 = Math_fround($40 + $41);
 $44 = Math_fround($42 + $43);
 $45 = (Math_fround(Math_sqrt((Math_fround($44)))));
 $46 = Math_fround(Math_fround(1.0) / $45);
 $47 = Math_fround($value$sroa$0$1 * $46);
 $48 = Math_fround($value$sroa$1$1 * $46);
 $49 = Math_fround($value$sroa$2$1 * $46);
 $50 = Math_fround($value$sroa$3$0 * $46);
 $51 = (($humanPose) + 16|0);
 HEAPF32[$51>>2] = $47;
 $52 = (($humanPose) + 20|0);
 HEAPF32[$52>>2] = $48;
 $53 = (($humanPose) + 24|0);
 HEAPF32[$53>>2] = $49;
 $54 = (($humanPose) + 28|0);
 HEAPF32[$54>>2] = $50;
 $55 = (($humanPose) + 32|0);
 HEAPF32[$55>>2] = Math_fround(1.0);
 $56 = (($humanPose) + 36|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($humanPose) + 40|0);
 HEAPF32[$57>>2] = Math_fround(1.0);
 $58 = (($humanPose) + 44|0);
 HEAPF32[$58>>2] = Math_fround(1.0);
 $currentCurveIndex$034 = 14;$i$033 = 0;
 while(1) {
  $59 = ((($constant) + ($currentCurveIndex$034<<2)|0) + 1072|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(-1);
  if ($61) {
   $value$sroa$0$2 = Math_fround(0.0);
  } else {
   $62 = (($values) + ($60<<2)|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $value$sroa$0$2 = $63;
  }
  $64 = (($currentCurveIndex$034) + 1)|0;
  $65 = ((($constant) + ($64<<2)|0) + 1072|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==(-1);
  if ($67) {
   $value$sroa$1$2 = Math_fround(0.0);
  } else {
   $68 = (($values) + ($66<<2)|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $value$sroa$1$2 = $69;
  }
  $70 = (($currentCurveIndex$034) + 2)|0;
  $71 = ((($constant) + ($70<<2)|0) + 1072|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(-1);
  if ($73) {
   $value$sroa$2$2 = Math_fround(0.0);
  } else {
   $74 = (($values) + ($72<<2)|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $value$sroa$2$2 = $75;
  }
  $76 = (($currentCurveIndex$034) + 3)|0;
  $77 = ((($humanPose) + (($i$033*76)|0)|0) + 80|0);
  HEAPF32[$77>>2] = $value$sroa$0$2;
  $78 = ((($humanPose) + (($i$033*76)|0)|0) + 84|0);
  HEAPF32[$78>>2] = $value$sroa$1$2;
  $79 = ((($humanPose) + (($i$033*76)|0)|0) + 88|0);
  HEAPF32[$79>>2] = $value$sroa$2$2;
  $80 = ((($humanPose) + (($i$033*76)|0)|0) + 92|0);
  HEAPF32[$80>>2] = Math_fround(0.0);
  $81 = ((($constant) + ($76<<2)|0) + 1072|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(-1);
  if ($83) {
   $value$sroa$0$3 = Math_fround(0.0);
  } else {
   $84 = (($values) + ($82<<2)|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $value$sroa$0$3 = $85;
  }
  $86 = (($currentCurveIndex$034) + 4)|0;
  $87 = ((($constant) + ($86<<2)|0) + 1072|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = ($88|0)==(-1);
  if ($89) {
   $value$sroa$1$3 = Math_fround(0.0);
  } else {
   $90 = (($values) + ($88<<2)|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $value$sroa$1$3 = $91;
  }
  $92 = (($currentCurveIndex$034) + 5)|0;
  $93 = ((($constant) + ($92<<2)|0) + 1072|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)==(-1);
  if ($95) {
   $value$sroa$2$3 = Math_fround(0.0);
  } else {
   $96 = (($values) + ($94<<2)|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $value$sroa$2$3 = $97;
  }
  $98 = (($currentCurveIndex$034) + 6)|0;
  $99 = ((($constant) + ($98<<2)|0) + 1072|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(-1);
  if ($101) {
   $value$sroa$3$1 = Math_fround(1.0);
  } else {
   $102 = (($values) + ($100<<2)|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $value$sroa$3$1 = $103;
  }
  $104 = (($currentCurveIndex$034) + 7)|0;
  $105 = ((($humanPose) + (($i$033*76)|0)|0) + 96|0);
  $106 = ((($humanPose) + (($i$033*76)|0)|0) + 100|0);
  $107 = ((($humanPose) + (($i$033*76)|0)|0) + 104|0);
  $108 = ((($humanPose) + (($i$033*76)|0)|0) + 108|0);
  $109 = Math_fround($value$sroa$0$3 * $value$sroa$0$3);
  $110 = Math_fround($value$sroa$1$3 * $value$sroa$1$3);
  $111 = Math_fround($value$sroa$2$3 * $value$sroa$2$3);
  $112 = Math_fround($value$sroa$3$1 * $value$sroa$3$1);
  $113 = Math_fround($109 + $110);
  $114 = Math_fround($112 + $111);
  $115 = Math_fround($113 + $114);
  $116 = (Math_fround(Math_sqrt((Math_fround($115)))));
  $117 = Math_fround(Math_fround(1.0) / $116);
  $118 = Math_fround($value$sroa$0$3 * $117);
  $119 = Math_fround($value$sroa$1$3 * $117);
  $120 = Math_fround($value$sroa$2$3 * $117);
  $121 = Math_fround($value$sroa$3$1 * $117);
  HEAPF32[$105>>2] = $118;
  HEAPF32[$106>>2] = $119;
  HEAPF32[$107>>2] = $120;
  HEAPF32[$108>>2] = $121;
  $122 = (($i$033) + 1)|0;
  $exitcond37 = ($122|0)==(4);
  if ($exitcond37) {
   $currentCurveIndex$132 = 42;$i$131 = 0;
   break;
  } else {
   $currentCurveIndex$034 = $104;$i$033 = $122;
  }
 }
 while(1) {
  $123 = ((($constant) + ($currentCurveIndex$132<<2)|0) + 1072|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($124|0)==(-1);
  if ($125) {
   $129 = ((($humanPose) + ($i$131<<2)|0) + 672|0);
   HEAPF32[$129>>2] = Math_fround(0.0);
  } else {
   $126 = (($values) + ($124<<2)|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = ((($humanPose) + ($i$131<<2)|0) + 672|0);
   HEAPF32[$128>>2] = $127;
  }
  $130 = (($currentCurveIndex$132) + 1)|0;
  $131 = (($i$131) + 1)|0;
  $exitcond36 = ($131|0)==(52);
  if ($exitcond36) {
   $currentCurveIndex$229 = 94;$i$228 = 0;
   break;
  } else {
   $currentCurveIndex$132 = $130;$i$131 = $131;
  }
 }
 while(1) {
  $132 = ((($constant) + ($currentCurveIndex$229<<2)|0) + 1072|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(-1);
  if ($134) {
   $138 = ((($humanPose) + ($i$228<<2)|0) + 432|0);
   HEAPF32[$138>>2] = Math_fround(0.0);
  } else {
   $135 = (($values) + ($133<<2)|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = ((($humanPose) + ($i$228<<2)|0) + 432|0);
   HEAPF32[$137>>2] = $136;
  }
  $139 = (($currentCurveIndex$229) + 1)|0;
  $140 = (($i$228) + 1)|0;
  $exitcond35 = ($140|0)==(20);
  if ($exitcond35) {
   $currentCurveIndex$326 = 114;$i$325 = 0;
   break;
  } else {
   $currentCurveIndex$229 = $139;$i$228 = $140;
  }
 }
 while(1) {
  $141 = ((($constant) + ($currentCurveIndex$326<<2)|0) + 1072|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = ($142|0)==(-1);
  if ($143) {
   $147 = ((($humanPose) + ($i$325<<2)|0) + 576|0);
   HEAPF32[$147>>2] = Math_fround(0.0);
  } else {
   $144 = (($values) + ($142<<2)|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = ((($humanPose) + ($i$325<<2)|0) + 576|0);
   HEAPF32[$146>>2] = $145;
  }
  $148 = (($currentCurveIndex$326) + 1)|0;
  $149 = (($i$325) + 1)|0;
  $exitcond = ($149|0)==(20);
  if ($exitcond) {
   break;
  } else {
   $currentCurveIndex$326 = $148;$i$325 = $149;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12GetHumanPoseERKNS0_18ClipMuscleConstantEPKNS0_10ValueDeltaERNS_5human9HumanPoseE($constant,$values,$humanPose) {
 $constant = $constant|0;
 $values = $values|0;
 $humanPose = $humanPose|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7mecanim9animation12GetHumanPoseINS0_10ValueDeltaEEEvRKNS0_18ClipMuscleConstantEPKT_RNS_5human9HumanPoseE($constant,$values,$humanPose);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12GetHumanPoseINS0_10ValueDeltaEEEvRKNS0_18ClipMuscleConstantEPKT_RNS_5human9HumanPoseE($constant,$values,$humanPose) {
 $constant = $constant|0;
 $values = $values|0;
 $humanPose = $humanPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0);
 var $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $currentCurveIndex$034 = 0, $currentCurveIndex$132 = 0, $currentCurveIndex$229 = 0, $currentCurveIndex$326 = 0, $exitcond = 0, $exitcond35 = 0, $exitcond36 = 0, $exitcond37 = 0, $i$033 = 0, $i$131 = 0;
 var $i$228 = 0, $i$325 = 0, $value$sroa$0$0 = Math_fround(0), $value$sroa$0$1 = Math_fround(0), $value$sroa$0$2 = Math_fround(0), $value$sroa$0$3 = Math_fround(0), $value$sroa$1$0 = Math_fround(0), $value$sroa$1$1 = Math_fround(0), $value$sroa$1$2 = Math_fround(0), $value$sroa$1$3 = Math_fround(0), $value$sroa$2$0 = Math_fround(0), $value$sroa$2$1 = Math_fround(0), $value$sroa$2$2 = Math_fround(0), $value$sroa$2$3 = Math_fround(0), $value$sroa$3$0 = Math_fround(0), $value$sroa$3$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($constant) + 1100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $value$sroa$0$0 = Math_fround(0.0);
 } else {
  $3 = (($values) + ($1<<3)|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $value$sroa$0$0 = $4;
 }
 $5 = (($constant) + 1104|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $value$sroa$1$0 = Math_fround(0.0);
 } else {
  $8 = (($values) + ($6<<3)|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $value$sroa$1$0 = $9;
 }
 $10 = (($constant) + 1108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(-1);
 if ($12) {
  $value$sroa$2$0 = Math_fround(0.0);
 } else {
  $13 = (($values) + ($11<<3)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $value$sroa$2$0 = $14;
 }
 HEAPF32[$humanPose>>2] = $value$sroa$0$0;
 $15 = (($humanPose) + 4|0);
 HEAPF32[$15>>2] = $value$sroa$1$0;
 $16 = (($humanPose) + 8|0);
 HEAPF32[$16>>2] = $value$sroa$2$0;
 $17 = (($humanPose) + 12|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($constant) + 1112|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(-1);
 if ($20) {
  $value$sroa$0$1 = Math_fround(0.0);
 } else {
  $21 = (($values) + ($19<<3)|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $value$sroa$0$1 = $22;
 }
 $23 = (($constant) + 1116|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(-1);
 if ($25) {
  $value$sroa$1$1 = Math_fround(0.0);
 } else {
  $26 = (($values) + ($24<<3)|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $value$sroa$1$1 = $27;
 }
 $28 = (($constant) + 1120|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(-1);
 if ($30) {
  $value$sroa$2$1 = Math_fround(0.0);
 } else {
  $31 = (($values) + ($29<<3)|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $value$sroa$2$1 = $32;
 }
 $33 = (($constant) + 1124|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $value$sroa$3$0 = Math_fround(1.0);
 } else {
  $36 = (($values) + ($34<<3)|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $value$sroa$3$0 = $37;
 }
 $38 = Math_fround($value$sroa$0$1 * $value$sroa$0$1);
 $39 = Math_fround($value$sroa$1$1 * $value$sroa$1$1);
 $40 = Math_fround($value$sroa$2$1 * $value$sroa$2$1);
 $41 = Math_fround($value$sroa$3$0 * $value$sroa$3$0);
 $42 = Math_fround($38 + $39);
 $43 = Math_fround($40 + $41);
 $44 = Math_fround($42 + $43);
 $45 = (Math_fround(Math_sqrt((Math_fround($44)))));
 $46 = Math_fround(Math_fround(1.0) / $45);
 $47 = Math_fround($value$sroa$0$1 * $46);
 $48 = Math_fround($value$sroa$1$1 * $46);
 $49 = Math_fround($value$sroa$2$1 * $46);
 $50 = Math_fround($value$sroa$3$0 * $46);
 $51 = (($humanPose) + 16|0);
 HEAPF32[$51>>2] = $47;
 $52 = (($humanPose) + 20|0);
 HEAPF32[$52>>2] = $48;
 $53 = (($humanPose) + 24|0);
 HEAPF32[$53>>2] = $49;
 $54 = (($humanPose) + 28|0);
 HEAPF32[$54>>2] = $50;
 $55 = (($humanPose) + 32|0);
 HEAPF32[$55>>2] = Math_fround(1.0);
 $56 = (($humanPose) + 36|0);
 HEAPF32[$56>>2] = Math_fround(1.0);
 $57 = (($humanPose) + 40|0);
 HEAPF32[$57>>2] = Math_fround(1.0);
 $58 = (($humanPose) + 44|0);
 HEAPF32[$58>>2] = Math_fround(1.0);
 $currentCurveIndex$034 = 14;$i$033 = 0;
 while(1) {
  $59 = ((($constant) + ($currentCurveIndex$034<<2)|0) + 1072|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)==(-1);
  if ($61) {
   $value$sroa$0$2 = Math_fround(0.0);
  } else {
   $62 = (($values) + ($60<<3)|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $value$sroa$0$2 = $63;
  }
  $64 = (($currentCurveIndex$034) + 1)|0;
  $65 = ((($constant) + ($64<<2)|0) + 1072|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($66|0)==(-1);
  if ($67) {
   $value$sroa$1$2 = Math_fround(0.0);
  } else {
   $68 = (($values) + ($66<<3)|0);
   $69 = Math_fround(HEAPF32[$68>>2]);
   $value$sroa$1$2 = $69;
  }
  $70 = (($currentCurveIndex$034) + 2)|0;
  $71 = ((($constant) + ($70<<2)|0) + 1072|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(-1);
  if ($73) {
   $value$sroa$2$2 = Math_fround(0.0);
  } else {
   $74 = (($values) + ($72<<3)|0);
   $75 = Math_fround(HEAPF32[$74>>2]);
   $value$sroa$2$2 = $75;
  }
  $76 = (($currentCurveIndex$034) + 3)|0;
  $77 = ((($humanPose) + (($i$033*76)|0)|0) + 80|0);
  HEAPF32[$77>>2] = $value$sroa$0$2;
  $78 = ((($humanPose) + (($i$033*76)|0)|0) + 84|0);
  HEAPF32[$78>>2] = $value$sroa$1$2;
  $79 = ((($humanPose) + (($i$033*76)|0)|0) + 88|0);
  HEAPF32[$79>>2] = $value$sroa$2$2;
  $80 = ((($humanPose) + (($i$033*76)|0)|0) + 92|0);
  HEAPF32[$80>>2] = Math_fround(0.0);
  $81 = ((($constant) + ($76<<2)|0) + 1072|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(-1);
  if ($83) {
   $value$sroa$0$3 = Math_fround(0.0);
  } else {
   $84 = (($values) + ($82<<3)|0);
   $85 = Math_fround(HEAPF32[$84>>2]);
   $value$sroa$0$3 = $85;
  }
  $86 = (($currentCurveIndex$034) + 4)|0;
  $87 = ((($constant) + ($86<<2)|0) + 1072|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = ($88|0)==(-1);
  if ($89) {
   $value$sroa$1$3 = Math_fround(0.0);
  } else {
   $90 = (($values) + ($88<<3)|0);
   $91 = Math_fround(HEAPF32[$90>>2]);
   $value$sroa$1$3 = $91;
  }
  $92 = (($currentCurveIndex$034) + 5)|0;
  $93 = ((($constant) + ($92<<2)|0) + 1072|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = ($94|0)==(-1);
  if ($95) {
   $value$sroa$2$3 = Math_fround(0.0);
  } else {
   $96 = (($values) + ($94<<3)|0);
   $97 = Math_fround(HEAPF32[$96>>2]);
   $value$sroa$2$3 = $97;
  }
  $98 = (($currentCurveIndex$034) + 6)|0;
  $99 = ((($constant) + ($98<<2)|0) + 1072|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(-1);
  if ($101) {
   $value$sroa$3$1 = Math_fround(1.0);
  } else {
   $102 = (($values) + ($100<<3)|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $value$sroa$3$1 = $103;
  }
  $104 = (($currentCurveIndex$034) + 7)|0;
  $105 = ((($humanPose) + (($i$033*76)|0)|0) + 96|0);
  $106 = ((($humanPose) + (($i$033*76)|0)|0) + 100|0);
  $107 = ((($humanPose) + (($i$033*76)|0)|0) + 104|0);
  $108 = ((($humanPose) + (($i$033*76)|0)|0) + 108|0);
  $109 = Math_fround($value$sroa$0$3 * $value$sroa$0$3);
  $110 = Math_fround($value$sroa$1$3 * $value$sroa$1$3);
  $111 = Math_fround($value$sroa$2$3 * $value$sroa$2$3);
  $112 = Math_fround($value$sroa$3$1 * $value$sroa$3$1);
  $113 = Math_fround($109 + $110);
  $114 = Math_fround($112 + $111);
  $115 = Math_fround($113 + $114);
  $116 = (Math_fround(Math_sqrt((Math_fround($115)))));
  $117 = Math_fround(Math_fround(1.0) / $116);
  $118 = Math_fround($value$sroa$0$3 * $117);
  $119 = Math_fround($value$sroa$1$3 * $117);
  $120 = Math_fround($value$sroa$2$3 * $117);
  $121 = Math_fround($value$sroa$3$1 * $117);
  HEAPF32[$105>>2] = $118;
  HEAPF32[$106>>2] = $119;
  HEAPF32[$107>>2] = $120;
  HEAPF32[$108>>2] = $121;
  $122 = (($i$033) + 1)|0;
  $exitcond37 = ($122|0)==(4);
  if ($exitcond37) {
   $currentCurveIndex$132 = 42;$i$131 = 0;
   break;
  } else {
   $currentCurveIndex$034 = $104;$i$033 = $122;
  }
 }
 while(1) {
  $123 = ((($constant) + ($currentCurveIndex$132<<2)|0) + 1072|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($124|0)==(-1);
  if ($125) {
   $129 = ((($humanPose) + ($i$131<<2)|0) + 672|0);
   HEAPF32[$129>>2] = Math_fround(0.0);
  } else {
   $126 = (($values) + ($124<<3)|0);
   $127 = Math_fround(HEAPF32[$126>>2]);
   $128 = ((($humanPose) + ($i$131<<2)|0) + 672|0);
   HEAPF32[$128>>2] = $127;
  }
  $130 = (($currentCurveIndex$132) + 1)|0;
  $131 = (($i$131) + 1)|0;
  $exitcond36 = ($131|0)==(52);
  if ($exitcond36) {
   $currentCurveIndex$229 = 94;$i$228 = 0;
   break;
  } else {
   $currentCurveIndex$132 = $130;$i$131 = $131;
  }
 }
 while(1) {
  $132 = ((($constant) + ($currentCurveIndex$229<<2)|0) + 1072|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(-1);
  if ($134) {
   $138 = ((($humanPose) + ($i$228<<2)|0) + 432|0);
   HEAPF32[$138>>2] = Math_fround(0.0);
  } else {
   $135 = (($values) + ($133<<3)|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = ((($humanPose) + ($i$228<<2)|0) + 432|0);
   HEAPF32[$137>>2] = $136;
  }
  $139 = (($currentCurveIndex$229) + 1)|0;
  $140 = (($i$228) + 1)|0;
  $exitcond35 = ($140|0)==(20);
  if ($exitcond35) {
   $currentCurveIndex$326 = 114;$i$325 = 0;
   break;
  } else {
   $currentCurveIndex$229 = $139;$i$228 = $140;
  }
 }
 while(1) {
  $141 = ((($constant) + ($currentCurveIndex$326<<2)|0) + 1072|0);
  $142 = HEAP32[$141>>2]|0;
  $143 = ($142|0)==(-1);
  if ($143) {
   $147 = ((($humanPose) + ($i$325<<2)|0) + 576|0);
   HEAPF32[$147>>2] = Math_fround(0.0);
  } else {
   $144 = (($values) + ($142<<3)|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = ((($humanPose) + ($i$325<<2)|0) + 576|0);
   HEAPF32[$146>>2] = $145;
  }
  $148 = (($currentCurveIndex$326) + 1)|0;
  $149 = (($i$325) + 1)|0;
  $exitcond = ($149|0)==(20);
  if ($exitcond) {
   break;
  } else {
   $currentCurveIndex$326 = $148;$i$325 = $149;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation28EvaluateClipRootMotionDeltaXERKNS0_18ClipMuscleConstantERKNS0_15ClipMuscleInputERNS0_12MotionOutputERNS0_10ClipMemoryE($constant,$input,$output,$memory) {
 $constant = $constant|0;
 $input = $input|0;
 $output = $output|0;
 $memory = $memory|0;
 var $$ = Math_fround(0), $$234 = Math_fround(0), $$pre = Math_fround(0), $$pre$phi248Z2D = 0, $$pre$phi250Z2D = 0, $$pre$phi252Z2D = 0, $$pre$phi254Z2D = 0, $$pre$phi256Z2D = 0, $$pre$phi258Z2D = 0, $$pre$phi260Z2D = 0, $$pre$phi262Z2D = 0, $$pre$phi264Z2D = 0, $$pre$phi266Z2D = 0, $$pre$phi268Z2D = 0, $$pre$phi270Z2D = 0, $$pre$phi272Z2D = 0, $$pre$phiZ2D = 0, $$pre236 = Math_fround(0), $$pre238 = Math_fround(0), $$pre239 = Math_fround(0);
 var $$pre241 = Math_fround(0), $$pre242 = Math_fround(0), $$pre243 = Math_fround(0), $$pre244 = Math_fround(0), $$pre247 = 0, $$pre249 = 0, $$pre251 = 0, $$pre253 = 0, $$pre255 = 0, $$pre257 = 0, $$pre261 = 0, $$pre263 = 0, $$pre265 = 0, $$pre267 = 0, $$pre269 = 0, $$pre271 = 0, $$v$i = Math_fround(0), $$v$i1 = Math_fround(0), $$val = Math_fround(0), $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = 0, $1004 = 0, $1005 = 0, $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = Math_fround(0), $1014 = 0, $1015 = 0;
 var $1016 = 0, $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = 0, $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = 0, $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0);
 var $1034 = Math_fround(0), $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = Math_fround(0), $104 = 0, $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = 0, $1050 = Math_fround(0), $1051 = 0;
 var $1052 = 0, $1053 = 0, $1054 = 0, $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = 0, $106 = Math_fround(0), $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = Math_fround(0), $1065 = 0, $1066 = Math_fround(0), $1067 = 0, $1068 = Math_fround(0), $1069 = 0, $107 = Math_fround(0);
 var $1070 = Math_fround(0), $1071 = Math_fround(0), $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = Math_fround(0), $1080 = 0, $1081 = Math_fround(0), $1082 = Math_fround(0), $1083 = 0, $1084 = 0, $1085 = Math_fround(0), $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = Math_fround(0);
 var $1089 = Math_fround(0), $109 = Math_fround(0), $1090 = Math_fround(0), $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = Math_fround(0), $1094 = Math_fround(0), $1095 = Math_fround(0), $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = Math_fround(0), $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = Math_fround(0), $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0);
 var $1106 = Math_fround(0), $1107 = Math_fround(0), $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = Math_fround(0), $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = Math_fround(0), $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = Math_fround(0), $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0);
 var $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0), $113 = 0, $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = 0, $1140 = Math_fround(0), $1141 = Math_fround(0);
 var $1142 = Math_fround(0), $1143 = Math_fround(0), $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = 0;
 var $1160 = Math_fround(0), $1161 = Math_fround(0), $1162 = Math_fround(0), $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = Math_fround(0), $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = Math_fround(0), $1169 = Math_fround(0), $117 = Math_fround(0), $1170 = Math_fround(0), $1171 = Math_fround(0), $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0;
 var $1179 = 0, $118 = Math_fround(0), $1180 = 0, $1181 = 0, $1182 = 0, $1183 = Math_fround(0), $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = Math_fround(0), $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = Math_fround(0), $1190 = Math_fround(0), $1191 = Math_fround(0), $1192 = 0, $1193 = Math_fround(0), $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = 0;
 var $1197 = Math_fround(0), $1198 = Math_fround(0), $1199 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $1200 = 0, $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = Math_fround(0), $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = Math_fround(0), $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = Math_fround(0), $1210 = Math_fround(0), $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = Math_fround(0);
 var $1214 = Math_fround(0), $1215 = Math_fround(0), $1216 = Math_fround(0), $1217 = Math_fround(0), $1218 = Math_fround(0), $1219 = Math_fround(0), $122 = 0, $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = Math_fround(0), $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = Math_fround(0), $1229 = Math_fround(0), $123 = 0, $1230 = Math_fround(0), $1231 = Math_fround(0);
 var $1232 = Math_fround(0), $1233 = Math_fround(0), $1234 = Math_fround(0), $1235 = Math_fround(0), $1236 = Math_fround(0), $1237 = Math_fround(0), $1238 = Math_fround(0), $1239 = Math_fround(0), $124 = 0, $1240 = Math_fround(0), $1241 = 0, $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = 0, $1245 = Math_fround(0), $1246 = Math_fround(0), $1247 = 0, $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = 0;
 var $1250 = 0, $1251 = Math_fround(0), $1252 = Math_fround(0), $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = 0, $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0), $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0);
 var $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0), $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = Math_fround(0), $1276 = Math_fround(0), $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = Math_fround(0), $128 = 0, $1280 = Math_fround(0), $1281 = Math_fround(0), $1282 = Math_fround(0), $1283 = Math_fround(0), $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = Math_fround(0);
 var $1287 = Math_fround(0), $1288 = Math_fround(0), $1289 = Math_fround(0), $129 = 0, $1290 = Math_fround(0), $1291 = Math_fround(0), $1292 = Math_fround(0), $1293 = 0, $1294 = Math_fround(0), $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = Math_fround(0), $1298 = Math_fround(0), $1299 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0);
 var $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = Math_fround(0), $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0), $131 = Math_fround(0), $1310 = Math_fround(0), $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = Math_fround(0), $1314 = Math_fround(0), $1315 = Math_fround(0), $1316 = Math_fround(0), $1317 = Math_fround(0), $1318 = Math_fround(0), $1319 = Math_fround(0), $132 = Math_fround(0), $1320 = Math_fround(0), $1321 = Math_fround(0);
 var $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = Math_fround(0), $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = Math_fround(0), $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = 0;
 var $1340 = Math_fround(0), $1341 = Math_fround(0), $1342 = Math_fround(0), $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = 0, $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0);
 var $1359 = Math_fround(0), $136 = 0, $1360 = Math_fround(0), $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = 0, $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = Math_fround(0), $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0);
 var $1377 = Math_fround(0), $1378 = Math_fround(0), $1379 = Math_fround(0), $138 = 0, $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0;
 var $1395 = 0, $1396 = Math_fround(0), $1397 = Math_fround(0), $1398 = Math_fround(0), $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = Math_fround(0), $1401 = 0, $1402 = Math_fround(0), $1403 = Math_fround(0), $1404 = 0, $1405 = Math_fround(0), $1406 = Math_fround(0), $1407 = 0, $1408 = Math_fround(0), $1409 = Math_fround(0), $141 = 0, $1410 = Math_fround(0), $1411 = Math_fround(0);
 var $1412 = Math_fround(0), $1413 = Math_fround(0), $1414 = Math_fround(0), $1415 = Math_fround(0), $1416 = Math_fround(0), $1417 = Math_fround(0), $1418 = Math_fround(0), $1419 = Math_fround(0), $142 = 0, $1420 = Math_fround(0), $1421 = Math_fround(0), $1422 = Math_fround(0), $1423 = Math_fround(0), $1424 = Math_fround(0), $1425 = Math_fround(0), $1426 = Math_fround(0), $1427 = Math_fround(0), $1428 = Math_fround(0), $1429 = Math_fround(0), $143 = 0;
 var $1430 = Math_fround(0), $1431 = Math_fround(0), $1432 = Math_fround(0), $1433 = Math_fround(0), $1434 = Math_fround(0), $1435 = Math_fround(0), $1436 = Math_fround(0), $1437 = Math_fround(0), $1438 = Math_fround(0), $1439 = Math_fround(0), $144 = Math_fround(0), $1440 = Math_fround(0), $1441 = Math_fround(0), $1442 = Math_fround(0), $1443 = Math_fround(0), $1444 = Math_fround(0), $1445 = Math_fround(0), $1446 = 0, $1447 = Math_fround(0), $1448 = Math_fround(0);
 var $1449 = 0, $145 = 0, $1450 = Math_fround(0), $1451 = Math_fround(0), $1452 = 0, $1453 = Math_fround(0), $1454 = Math_fround(0), $1455 = 0, $1456 = Math_fround(0), $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = Math_fround(0), $1460 = Math_fround(0), $1461 = Math_fround(0), $1462 = Math_fround(0), $1463 = Math_fround(0), $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = Math_fround(0);
 var $1467 = Math_fround(0), $1468 = Math_fround(0), $1469 = Math_fround(0), $147 = 0, $1470 = Math_fround(0), $1471 = Math_fround(0), $1472 = Math_fround(0), $1473 = Math_fround(0), $1474 = Math_fround(0), $1475 = Math_fround(0), $1476 = Math_fround(0), $1477 = Math_fround(0), $1478 = Math_fround(0), $1479 = Math_fround(0), $148 = Math_fround(0), $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0);
 var $1485 = Math_fround(0), $1486 = Math_fround(0), $1487 = Math_fround(0), $1488 = Math_fround(0), $1489 = Math_fround(0), $149 = 0, $1490 = Math_fround(0), $1491 = Math_fround(0), $1492 = Math_fround(0), $1493 = Math_fround(0), $1494 = Math_fround(0), $1495 = Math_fround(0), $1496 = Math_fround(0), $1497 = Math_fround(0), $1498 = 0, $1499 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $1500 = Math_fround(0), $1501 = Math_fround(0);
 var $1502 = Math_fround(0), $1503 = Math_fround(0), $1504 = Math_fround(0), $1505 = Math_fround(0), $1506 = Math_fround(0), $1507 = Math_fround(0), $1508 = Math_fround(0), $1509 = Math_fround(0), $151 = 0, $1510 = Math_fround(0), $1511 = Math_fround(0), $1512 = Math_fround(0), $1513 = Math_fround(0), $1514 = Math_fround(0), $1515 = Math_fround(0), $1516 = Math_fround(0), $1517 = Math_fround(0), $1518 = Math_fround(0), $1519 = Math_fround(0), $152 = 0;
 var $1520 = Math_fround(0), $1521 = Math_fround(0), $1522 = Math_fround(0), $1523 = Math_fround(0), $1524 = Math_fround(0), $1525 = Math_fround(0), $1526 = Math_fround(0), $1527 = Math_fround(0), $1528 = Math_fround(0), $1529 = Math_fround(0), $153 = 0, $1530 = Math_fround(0), $1531 = Math_fround(0), $1532 = Math_fround(0), $1533 = Math_fround(0), $1534 = Math_fround(0), $1535 = Math_fround(0), $1536 = Math_fround(0), $1537 = Math_fround(0), $1538 = Math_fround(0);
 var $1539 = Math_fround(0), $154 = 0, $1540 = Math_fround(0), $1541 = Math_fround(0), $1542 = Math_fround(0), $1543 = Math_fround(0), $1544 = Math_fround(0), $1545 = Math_fround(0), $1546 = Math_fround(0), $1547 = Math_fround(0), $1548 = Math_fround(0), $1549 = Math_fround(0), $155 = Math_fround(0), $1550 = Math_fround(0), $1551 = Math_fround(0), $1552 = Math_fround(0), $1553 = Math_fround(0), $1554 = Math_fround(0), $1555 = Math_fround(0), $1556 = Math_fround(0);
 var $1557 = Math_fround(0), $1558 = Math_fround(0), $1559 = Math_fround(0), $156 = 0, $1560 = Math_fround(0), $1561 = Math_fround(0), $1562 = Math_fround(0), $1563 = Math_fround(0), $1564 = Math_fround(0), $1565 = Math_fround(0), $1566 = Math_fround(0), $1567 = Math_fround(0), $1568 = Math_fround(0), $1569 = Math_fround(0), $157 = Math_fround(0), $1570 = Math_fround(0), $1571 = Math_fround(0), $1572 = Math_fround(0), $1573 = Math_fround(0), $1574 = Math_fround(0);
 var $1575 = Math_fround(0), $1576 = Math_fround(0), $1577 = Math_fround(0), $1578 = Math_fround(0), $1579 = Math_fround(0), $158 = 0, $1580 = Math_fround(0), $1581 = Math_fround(0), $1582 = Math_fround(0), $1583 = Math_fround(0), $1584 = Math_fround(0), $1585 = Math_fround(0), $1586 = Math_fround(0), $1587 = Math_fround(0), $1588 = 0, $1589 = Math_fround(0), $159 = Math_fround(0), $1590 = Math_fround(0), $1591 = Math_fround(0), $1592 = Math_fround(0);
 var $1593 = Math_fround(0), $1594 = Math_fround(0), $1595 = Math_fround(0), $1596 = Math_fround(0), $1597 = Math_fround(0), $1598 = Math_fround(0), $1599 = Math_fround(0), $16 = 0, $160 = 0, $1600 = Math_fround(0), $1601 = Math_fround(0), $1602 = Math_fround(0), $1603 = Math_fround(0), $1604 = Math_fround(0), $1605 = Math_fround(0), $1606 = Math_fround(0), $1607 = Math_fround(0), $1608 = Math_fround(0), $1609 = Math_fround(0), $161 = Math_fround(0);
 var $1610 = Math_fround(0), $1611 = Math_fround(0), $1612 = Math_fround(0), $1613 = Math_fround(0), $1614 = Math_fround(0), $1615 = Math_fround(0), $1616 = Math_fround(0), $1617 = Math_fround(0), $1618 = Math_fround(0), $1619 = Math_fround(0), $162 = 0, $1620 = Math_fround(0), $1621 = Math_fround(0), $1622 = Math_fround(0), $1623 = Math_fround(0), $1624 = Math_fround(0), $1625 = Math_fround(0), $1626 = Math_fround(0), $1627 = Math_fround(0), $1628 = Math_fround(0);
 var $1629 = Math_fround(0), $163 = 0, $1630 = Math_fround(0), $1631 = Math_fround(0), $1632 = Math_fround(0), $1633 = Math_fround(0), $1634 = Math_fround(0), $1635 = Math_fround(0), $1636 = Math_fround(0), $1637 = Math_fround(0), $1638 = Math_fround(0), $1639 = Math_fround(0), $164 = 0, $1640 = Math_fround(0), $1641 = Math_fround(0), $1642 = Math_fround(0), $1643 = Math_fround(0), $1644 = Math_fround(0), $1645 = Math_fround(0), $1646 = Math_fround(0);
 var $1647 = Math_fround(0), $1648 = Math_fround(0), $1649 = Math_fround(0), $165 = 0, $1650 = Math_fround(0), $1651 = Math_fround(0), $1652 = Math_fround(0), $1653 = Math_fround(0), $1654 = Math_fround(0), $1655 = Math_fround(0), $1656 = Math_fround(0), $1657 = Math_fround(0), $1658 = Math_fround(0), $1659 = Math_fround(0), $166 = Math_fround(0), $1660 = Math_fround(0), $1661 = Math_fround(0), $1662 = Math_fround(0), $1663 = Math_fround(0), $1664 = Math_fround(0);
 var $1665 = Math_fround(0), $1666 = Math_fround(0), $1667 = Math_fround(0), $1668 = Math_fround(0), $1669 = Math_fround(0), $167 = 0, $1670 = Math_fround(0), $1671 = Math_fround(0), $1672 = Math_fround(0), $1673 = Math_fround(0), $1674 = Math_fround(0), $1675 = Math_fround(0), $1676 = 0, $1677 = Math_fround(0), $1678 = Math_fround(0), $1679 = Math_fround(0), $168 = Math_fround(0), $1680 = Math_fround(0), $1681 = Math_fround(0), $1682 = Math_fround(0);
 var $1683 = Math_fround(0), $1684 = Math_fround(0), $1685 = 0, $1686 = 0, $1687 = 0, $1688 = Math_fround(0), $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = Math_fround(0), $1693 = Math_fround(0), $1694 = Math_fround(0), $1695 = Math_fround(0), $1696 = 0, $1697 = 0, $1698 = 0, $1699 = Math_fround(0), $17 = 0, $170 = Math_fround(0);
 var $1700 = Math_fround(0), $1701 = Math_fround(0), $1702 = Math_fround(0), $1703 = Math_fround(0), $1704 = Math_fround(0), $1705 = Math_fround(0), $1706 = Math_fround(0), $1707 = Math_fround(0), $1708 = Math_fround(0), $1709 = Math_fround(0), $171 = 0, $1710 = Math_fround(0), $1711 = Math_fround(0), $1712 = Math_fround(0), $1713 = Math_fround(0), $1714 = 0, $1715 = Math_fround(0), $1716 = Math_fround(0), $1717 = Math_fround(0), $1718 = Math_fround(0);
 var $1719 = Math_fround(0), $172 = Math_fround(0), $1720 = Math_fround(0), $1721 = Math_fround(0), $1722 = Math_fround(0), $1723 = Math_fround(0), $1724 = Math_fround(0), $1725 = Math_fround(0), $1726 = Math_fround(0), $1727 = Math_fround(0), $1728 = Math_fround(0), $1729 = Math_fround(0), $173 = Math_fround(0), $1730 = Math_fround(0), $1731 = Math_fround(0), $1732 = Math_fround(0), $1733 = 0, $1734 = Math_fround(0), $1735 = Math_fround(0), $1736 = Math_fround(0);
 var $1737 = Math_fround(0), $1738 = Math_fround(0), $1739 = Math_fround(0), $174 = 0, $1740 = Math_fround(0), $1741 = Math_fround(0), $1742 = Math_fround(0), $1743 = Math_fround(0), $1744 = Math_fround(0), $1745 = Math_fround(0), $1746 = Math_fround(0), $1747 = Math_fround(0), $1748 = Math_fround(0), $1749 = Math_fround(0), $175 = Math_fround(0), $1750 = Math_fround(0), $1751 = Math_fround(0), $1752 = Math_fround(0), $1753 = Math_fround(0), $1754 = Math_fround(0);
 var $1755 = Math_fround(0), $1756 = Math_fround(0), $1757 = Math_fround(0), $1758 = Math_fround(0), $1759 = Math_fround(0), $176 = 0, $1760 = Math_fround(0), $1761 = Math_fround(0), $1762 = Math_fround(0), $1763 = Math_fround(0), $1764 = Math_fround(0), $1765 = 0, $1766 = Math_fround(0), $1767 = Math_fround(0), $1768 = Math_fround(0), $1769 = Math_fround(0), $177 = Math_fround(0), $1770 = Math_fround(0), $1771 = Math_fround(0), $1772 = Math_fround(0);
 var $1773 = Math_fround(0), $1774 = Math_fround(0), $1775 = Math_fround(0), $1776 = Math_fround(0), $1777 = Math_fround(0), $1778 = Math_fround(0), $1779 = Math_fround(0), $178 = 0, $1780 = Math_fround(0), $1781 = Math_fround(0), $1782 = Math_fround(0), $1783 = Math_fround(0), $1784 = Math_fround(0), $1785 = Math_fround(0), $1786 = Math_fround(0), $1787 = Math_fround(0), $1788 = Math_fround(0), $1789 = Math_fround(0), $179 = Math_fround(0), $1790 = Math_fround(0);
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0);
 var $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0);
 var $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0;
 var $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = Math_fround(0);
 var $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = Math_fround(0), $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0, $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0);
 var $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0;
 var $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0);
 var $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0);
 var $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0);
 var $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0);
 var $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0);
 var $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0);
 var $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0);
 var $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0);
 var $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0);
 var $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = Math_fround(0), $49 = 0, $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0);
 var $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0);
 var $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0);
 var $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0);
 var $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0);
 var $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0);
 var $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0);
 var $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0);
 var $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0);
 var $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0);
 var $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = 0, $677 = Math_fround(0), $678 = 0, $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = 0.0, $683 = 0.0;
 var $684 = Math_fround(0), $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0);
 var $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0);
 var $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = Math_fround(0), $732 = Math_fround(0), $733 = 0, $734 = 0, $735 = 0, $736 = Math_fround(0), $737 = Math_fround(0);
 var $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0);
 var $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0);
 var $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0);
 var $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $800 = Math_fround(0), $801 = Math_fround(0), $802 = Math_fround(0), $803 = Math_fround(0), $804 = Math_fround(0), $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0);
 var $81 = 0, $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0), $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = Math_fround(0), $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0);
 var $828 = Math_fround(0), $829 = Math_fround(0), $83 = 0, $830 = Math_fround(0), $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = Math_fround(0), $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0);
 var $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0), $85 = 0, $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0);
 var $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = 0, $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0);
 var $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = 0, $890 = Math_fround(0), $891 = Math_fround(0), $892 = Math_fround(0), $893 = Math_fround(0), $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0;
 var $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0), $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0);
 var $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = Math_fround(0), $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = Math_fround(0), $934 = Math_fround(0), $935 = Math_fround(0);
 var $936 = Math_fround(0), $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = Math_fround(0), $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = Math_fround(0), $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0);
 var $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = Math_fround(0), $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0);
 var $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0;
 var $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $brmerge = 0, $currentTimeInt = 0, $prevTimeInt = 0, $refStartX = 0, $refStopX = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 688|0;
 $prevTimeInt = sp + 676|0;
 $currentTimeInt = sp + 672|0;
 $refStartX = sp + 624|0;
 $refStopX = sp + 576|0;
 $0 = sp + 528|0;
 $1 = sp + 480|0;
 $2 = sp + 432|0;
 $3 = sp + 384|0;
 $4 = sp + 336|0;
 $5 = sp + 240|0;
 $6 = sp + 192|0;
 $7 = sp + 144|0;
 $8 = sp + 96|0;
 $9 = sp + 48|0;
 $10 = sp;
 $11 = sp + 288|0;
 $12 = (($constant) + 1072|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(-1);
 if ($14) {
  $15 = (($constant) + 1076|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(-1);
  if ($17) {
   $18 = (($constant) + 1080|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(-1);
   if ($20) {
    $21 = (($constant) + 1084|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(-1);
    if ($23) {
     $24 = (($constant) + 1088|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==(-1);
     if ($26) {
      $27 = (($constant) + 1092|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($28|0)==(-1);
      if ($29) {
       $30 = (($constant) + 1096|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($31|0)!=(-1);
       $74 = $32;
      } else {
       $74 = 1;
      }
     } else {
      $74 = 1;
     }
    } else {
     $74 = 1;
    }
   } else {
    $74 = 1;
   }
  } else {
   $74 = 1;
  }
 } else {
  $74 = 1;
 }
 $33 = (($constant) + 1100|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(-1);
 if ($35) {
  $36 = (($constant) + 1104|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(-1);
  if ($38) {
   $39 = (($constant) + 1108|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(-1);
   if ($41) {
    $42 = (($constant) + 1112|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($43|0)==(-1);
    if ($44) {
     $45 = (($constant) + 1116|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==(-1);
     if ($47) {
      $48 = (($constant) + 1120|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(-1);
      if ($50) {
       $51 = (($constant) + 1124|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52|0)!=(-1);
       $75 = $53;
      } else {
       $75 = 1;
      }
     } else {
      $75 = 1;
     }
    } else {
     $75 = 1;
    }
   } else {
    $75 = 1;
   }
  } else {
   $75 = 1;
  }
 } else {
  $75 = 1;
 }
 $54 = (($output) + 4|0);
 $55 = (($output) + 8|0);
 $56 = (($output) + 12|0);
 $57 = (($output) + 16|0);
 $58 = (($output) + 20|0);
 $59 = (($output) + 24|0);
 $60 = (($output) + 28|0);
 $61 = (($output) + 32|0);
 $62 = (($output) + 84|0);
 $63 = (($output) + 88|0);
 $64 = (($output) + 92|0);
 $65 = (($output) + 96|0);
 $66 = (($output) + 100|0);
 $67 = (($output) + 104|0);
 $68 = (($output) + 108|0);
 $69 = (($output) + 112|0);
 ;HEAP32[$54+0>>2]=0|0;HEAP32[$54+4>>2]=0|0;HEAP32[$54+8>>2]=0|0;HEAP32[$54+12>>2]=0|0;HEAP32[$54+16>>2]=0|0;HEAP32[$54+20>>2]=0|0;HEAP32[$54+24>>2]=0|0;HEAP32[$54+28>>2]=0|0;
 ;HEAP32[$62+0>>2]=0|0;HEAP32[$62+4>>2]=0|0;HEAP32[$62+8>>2]=0|0;HEAP32[$62+12>>2]=0|0;HEAP32[$62+16>>2]=0|0;HEAP32[$62+20>>2]=0|0;HEAP32[$62+24>>2]=0|0;
 HEAPF32[$69>>2] = Math_fround(1.0);
 $70 = (($output) + 116|0);
 HEAPF32[$70>>2] = Math_fround(1.0);
 $71 = (($output) + 120|0);
 HEAPF32[$71>>2] = Math_fround(1.0);
 $72 = (($output) + 124|0);
 HEAPF32[$72>>2] = Math_fround(1.0);
 $73 = (($output) + 128|0);
 HEAPF32[$73>>2] = Math_fround(1.0);
 $brmerge = $74 | $75;
 if (!($brmerge)) {
  STACKTOP = sp;return;
 }
 $76 = (($constant) + 1064|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($input) + 24|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($77 + $79);
 $81 = (($input) + 4|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($constant) + 1048|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = (($constant) + 1052|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($constant) + 1633|0);
 $88 = HEAP8[$87>>0]|0;
 $89 = ($88<<24>>24)!=(0);
 $90 = (($input) + 16|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = $91 < Math_fround(0.0);
 $93 = (Math_fround(+(_fmaxf(0.0,(+$82)))));
 $94 = (Math_fround(+(_fminf(1.0,(+$93)))));
 $95 = Math_fround($82 + $80);
 $96 = (Math_fround(+(_modff((+$95),($prevTimeInt|0)))));
 $$v$i = $89 ? $96 : $94;
 $97 = Math_fround(Math_fround(1.0) - $$v$i);
 $98 = $92&1;
 $99 = $98 ^ 1;
 $100 = (0 - ($99))|0;
 $101 = (HEAPF32[tempDoublePtr>>2]=$97,HEAP32[tempDoublePtr>>2]|0);
 $102 = (HEAPF32[tempDoublePtr>>2]=$$v$i,HEAP32[tempDoublePtr>>2]|0);
 $103 = $92 ? $101 : 0;
 $104 = $102 & $100;
 $105 = $103 | $104;
 $106 = (HEAP32[tempDoublePtr>>2]=$105,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $107 = Math_fround($86 - $84);
 $108 = Math_fround($107 * $106);
 $109 = Math_fround($84 + $108);
 $110 = Math_fround(HEAPF32[$input>>2]);
 $111 = Math_fround(HEAPF32[$83>>2]);
 $112 = Math_fround(HEAPF32[$85>>2]);
 $113 = HEAP8[$87>>0]|0;
 $114 = ($113<<24>>24)!=(0);
 $115 = Math_fround(HEAPF32[$90>>2]);
 $116 = $115 < Math_fround(0.0);
 $117 = (Math_fround(+(_fmaxf(0.0,(+$110)))));
 $118 = (Math_fround(+(_fminf(1.0,(+$117)))));
 $119 = Math_fround($80 + $110);
 $120 = (Math_fround(+(_modff((+$119),($currentTimeInt|0)))));
 $$v$i1 = $114 ? $120 : $118;
 $121 = Math_fround(Math_fround(1.0) - $$v$i1);
 $122 = $116&1;
 $123 = $122 ^ 1;
 $124 = (0 - ($123))|0;
 $125 = (HEAPF32[tempDoublePtr>>2]=$121,HEAP32[tempDoublePtr>>2]|0);
 $126 = (HEAPF32[tempDoublePtr>>2]=$$v$i1,HEAP32[tempDoublePtr>>2]|0);
 $127 = $116 ? $125 : 0;
 $128 = $126 & $124;
 $129 = $127 | $128;
 $130 = (HEAP32[tempDoublePtr>>2]=$129,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $131 = Math_fround($112 - $111);
 $132 = Math_fround($131 * $130);
 $133 = Math_fround($111 + $132);
 $134 = (($refStartX) + 28|0);
 ;HEAP32[$refStartX+0>>2]=0|0;HEAP32[$refStartX+4>>2]=0|0;HEAP32[$refStartX+8>>2]=0|0;HEAP32[$refStartX+12>>2]=0|0;HEAP32[$refStartX+16>>2]=0|0;HEAP32[$refStartX+20>>2]=0|0;HEAP32[$refStartX+24>>2]=0|0;
 HEAPF32[$134>>2] = Math_fround(1.0);
 $135 = (($refStartX) + 44|0);
 HEAPF32[$135>>2] = Math_fround(1.0);
 $136 = (($refStartX) + 40|0);
 HEAPF32[$136>>2] = Math_fround(1.0);
 $137 = (($refStartX) + 36|0);
 HEAPF32[$137>>2] = Math_fround(1.0);
 $138 = (($refStartX) + 32|0);
 HEAPF32[$138>>2] = Math_fround(1.0);
 $139 = (($refStopX) + 28|0);
 ;HEAP32[$refStopX+0>>2]=0|0;HEAP32[$refStopX+4>>2]=0|0;HEAP32[$refStopX+8>>2]=0|0;HEAP32[$refStopX+12>>2]=0|0;HEAP32[$refStopX+16>>2]=0|0;HEAP32[$refStopX+20>>2]=0|0;HEAP32[$refStopX+24>>2]=0|0;
 HEAPF32[$139>>2] = Math_fround(1.0);
 $140 = (($refStopX) + 44|0);
 HEAPF32[$140>>2] = Math_fround(1.0);
 $141 = (($refStopX) + 40|0);
 HEAPF32[$141>>2] = Math_fround(1.0);
 $142 = (($refStopX) + 36|0);
 HEAPF32[$142>>2] = Math_fround(1.0);
 $143 = (($refStopX) + 32|0);
 HEAPF32[$143>>2] = Math_fround(1.0);
 do {
  if ($74) {
   __ZN7mecanim9animation15GetMotionStartXERKNS0_18ClipMuscleConstantE($0,$constant);
   $144 = Math_fround(HEAPF32[$0>>2]);
   $145 = (($0) + 4|0);
   $146 = Math_fround(HEAPF32[$145>>2]);
   $147 = (($0) + 8|0);
   $148 = Math_fround(HEAPF32[$147>>2]);
   $149 = (($0) + 12|0);
   $150 = Math_fround(HEAPF32[$149>>2]);
   HEAPF32[$refStartX>>2] = $144;
   $151 = (($refStartX) + 4|0);
   HEAPF32[$151>>2] = $146;
   $152 = (($refStartX) + 8|0);
   HEAPF32[$152>>2] = $148;
   $153 = (($refStartX) + 12|0);
   HEAPF32[$153>>2] = $150;
   $154 = (($0) + 16|0);
   $155 = Math_fround(HEAPF32[$154>>2]);
   $156 = (($0) + 20|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $158 = (($0) + 24|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = (($0) + 28|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = (($refStartX) + 16|0);
   HEAPF32[$162>>2] = $155;
   $163 = (($refStartX) + 20|0);
   HEAPF32[$163>>2] = $157;
   $164 = (($refStartX) + 24|0);
   HEAPF32[$164>>2] = $159;
   HEAPF32[$134>>2] = $161;
   $165 = (($0) + 32|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   $167 = (($0) + 36|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = (($0) + 40|0);
   $170 = Math_fround(HEAPF32[$169>>2]);
   $171 = (($0) + 44|0);
   $172 = Math_fround(HEAPF32[$171>>2]);
   HEAPF32[$138>>2] = $166;
   HEAPF32[$137>>2] = $168;
   HEAPF32[$136>>2] = $170;
   HEAPF32[$135>>2] = $172;
   __ZN7mecanim9animation14GetMotionStopXERKNS0_18ClipMuscleConstantE($1,$constant);
   $173 = Math_fround(HEAPF32[$1>>2]);
   $174 = (($1) + 4|0);
   $175 = Math_fround(HEAPF32[$174>>2]);
   $176 = (($1) + 8|0);
   $177 = Math_fround(HEAPF32[$176>>2]);
   $178 = (($1) + 12|0);
   $179 = Math_fround(HEAPF32[$178>>2]);
   HEAPF32[$refStopX>>2] = $173;
   $180 = (($refStopX) + 4|0);
   HEAPF32[$180>>2] = $175;
   $181 = (($refStopX) + 8|0);
   HEAPF32[$181>>2] = $177;
   $182 = (($refStopX) + 12|0);
   HEAPF32[$182>>2] = $179;
   $183 = (($1) + 16|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = (($1) + 20|0);
   $186 = Math_fround(HEAPF32[$185>>2]);
   $187 = (($1) + 24|0);
   $188 = Math_fround(HEAPF32[$187>>2]);
   $189 = (($1) + 28|0);
   $190 = Math_fround(HEAPF32[$189>>2]);
   $191 = (($refStopX) + 16|0);
   HEAPF32[$191>>2] = $184;
   $192 = (($refStopX) + 20|0);
   HEAPF32[$192>>2] = $186;
   $193 = (($refStopX) + 24|0);
   HEAPF32[$193>>2] = $188;
   HEAPF32[$139>>2] = $190;
   $194 = (($1) + 32|0);
   $195 = Math_fround(HEAPF32[$194>>2]);
   $196 = (($1) + 36|0);
   $197 = Math_fround(HEAPF32[$196>>2]);
   $198 = (($1) + 40|0);
   $199 = Math_fround(HEAPF32[$198>>2]);
   $200 = (($1) + 44|0);
   $201 = Math_fround(HEAPF32[$200>>2]);
   HEAPF32[$143>>2] = $195;
   HEAPF32[$142>>2] = $197;
   HEAPF32[$141>>2] = $199;
   HEAPF32[$140>>2] = $201;
   __ZN7mecanim9animation14EvaluateMotionERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($2,$constant,$memory,$109);
   $202 = Math_fround(HEAPF32[$2>>2]);
   $203 = (($2) + 4|0);
   $204 = Math_fround(HEAPF32[$203>>2]);
   $205 = (($2) + 8|0);
   $206 = Math_fround(HEAPF32[$205>>2]);
   $207 = (($2) + 12|0);
   $208 = Math_fround(HEAPF32[$207>>2]);
   $209 = (($2) + 16|0);
   $210 = Math_fround(HEAPF32[$209>>2]);
   $211 = (($2) + 20|0);
   $212 = Math_fround(HEAPF32[$211>>2]);
   $213 = (($2) + 24|0);
   $214 = Math_fround(HEAPF32[$213>>2]);
   $215 = (($2) + 28|0);
   $216 = Math_fround(HEAPF32[$215>>2]);
   __ZN7mecanim9animation14EvaluateMotionERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($3,$constant,$memory,$133);
   $217 = Math_fround(HEAPF32[$3>>2]);
   $218 = (($3) + 4|0);
   $219 = Math_fround(HEAPF32[$218>>2]);
   $220 = (($3) + 8|0);
   $221 = Math_fround(HEAPF32[$220>>2]);
   $222 = (($3) + 12|0);
   $223 = Math_fround(HEAPF32[$222>>2]);
   $224 = (($3) + 16|0);
   $225 = Math_fround(HEAPF32[$224>>2]);
   $226 = (($3) + 20|0);
   $227 = Math_fround(HEAPF32[$226>>2]);
   $228 = (($3) + 24|0);
   $229 = Math_fround(HEAPF32[$228>>2]);
   $230 = (($3) + 28|0);
   $231 = Math_fround(HEAPF32[$230>>2]);
   $232 = (($3) + 32|0);
   $233 = Math_fround(HEAPF32[$232>>2]);
   $234 = (($3) + 36|0);
   $235 = Math_fround(HEAPF32[$234>>2]);
   $236 = (($3) + 40|0);
   $237 = Math_fround(HEAPF32[$236>>2]);
   $238 = (($3) + 44|0);
   $239 = Math_fround(HEAPF32[$238>>2]);
   $$pre = Math_fround(HEAPF32[$191>>2]);
   $$pre236 = Math_fround(HEAPF32[$192>>2]);
   $$pre238 = Math_fround(HEAPF32[$193>>2]);
   $$pre239 = Math_fround(HEAPF32[$139>>2]);
   $$pre$phi248Z2D = $151;$$pre$phi250Z2D = $152;$$pre$phi252Z2D = $153;$$pre$phi254Z2D = $162;$$pre$phi256Z2D = $163;$$pre$phi258Z2D = $164;$$pre$phi260Z2D = $refStopX;$$pre$phi262Z2D = $180;$$pre$phi264Z2D = $181;$$pre$phi266Z2D = $182;$$pre$phi268Z2D = $191;$$pre$phi270Z2D = $192;$$pre$phi272Z2D = $193;$$pre$phiZ2D = $refStartX;$1019 = $217;$1020 = $219;$1021 = $221;$1022 = $223;$1023 = $225;$1024 = $227;$1025 = $229;$1026 = $231;$1027 = $233;$1028 = $235;$1029 = $237;$1030 = $239;$1064 = $$pre;$1066 = $$pre236;$1068 = $$pre238;$1070 = $$pre239;$1184 = $210;$1186 = $212;$1188 = $214;$1191 = $202;$1195 = $204;$1199 = $206;$1203 = $208;$1211 = $216;
  } else {
   if (!($75)) {
    $$pre247 = (($refStartX) + 4|0);
    $$pre249 = (($refStartX) + 8|0);
    $$pre251 = (($refStartX) + 12|0);
    $$pre253 = (($refStartX) + 16|0);
    $$pre255 = (($refStartX) + 20|0);
    $$pre257 = (($refStartX) + 24|0);
    $$pre261 = (($refStopX) + 4|0);
    $$pre263 = (($refStopX) + 8|0);
    $$pre265 = (($refStopX) + 12|0);
    $$pre267 = (($refStopX) + 16|0);
    $$pre269 = (($refStopX) + 20|0);
    $$pre271 = (($refStopX) + 24|0);
    $$pre$phi248Z2D = $$pre247;$$pre$phi250Z2D = $$pre249;$$pre$phi252Z2D = $$pre251;$$pre$phi254Z2D = $$pre253;$$pre$phi256Z2D = $$pre255;$$pre$phi258Z2D = $$pre257;$$pre$phi260Z2D = $refStopX;$$pre$phi262Z2D = $$pre261;$$pre$phi264Z2D = $$pre263;$$pre$phi266Z2D = $$pre265;$$pre$phi268Z2D = $$pre267;$$pre$phi270Z2D = $$pre269;$$pre$phi272Z2D = $$pre271;$$pre$phiZ2D = $refStartX;$1019 = Math_fround(0.0);$1020 = Math_fround(0.0);$1021 = Math_fround(0.0);$1022 = Math_fround(0.0);$1023 = Math_fround(0.0);$1024 = Math_fround(0.0);$1025 = Math_fround(0.0);$1026 = Math_fround(1.0);$1027 = Math_fround(1.0);$1028 = Math_fround(1.0);$1029 = Math_fround(1.0);$1030 = Math_fround(1.0);$1064 = Math_fround(0.0);$1066 = Math_fround(0.0);$1068 = Math_fround(0.0);$1070 = Math_fround(1.0);$1184 = Math_fround(0.0);$1186 = Math_fround(0.0);$1188 = Math_fround(0.0);$1191 = Math_fround(0.0);$1195 = Math_fround(0.0);$1199 = Math_fround(0.0);$1203 = Math_fround(0.0);$1211 = Math_fround(1.0);
    break;
   }
   __ZN7mecanim9animation13GetRootStartXERKNS0_18ClipMuscleConstantE($4,$constant);
   $240 = Math_fround(HEAPF32[$4>>2]);
   $241 = (($4) + 4|0);
   $242 = Math_fround(HEAPF32[$241>>2]);
   $243 = (($4) + 8|0);
   $244 = Math_fround(HEAPF32[$243>>2]);
   $245 = (($4) + 12|0);
   $246 = Math_fround(HEAPF32[$245>>2]);
   HEAPF32[$refStartX>>2] = $240;
   $247 = (($refStartX) + 4|0);
   HEAPF32[$247>>2] = $242;
   $248 = (($refStartX) + 8|0);
   HEAPF32[$248>>2] = $244;
   $249 = (($refStartX) + 12|0);
   HEAPF32[$249>>2] = $246;
   $250 = (($4) + 16|0);
   $251 = Math_fround(HEAPF32[$250>>2]);
   $252 = (($4) + 20|0);
   $253 = Math_fround(HEAPF32[$252>>2]);
   $254 = (($4) + 24|0);
   $255 = Math_fround(HEAPF32[$254>>2]);
   $256 = (($4) + 28|0);
   $257 = Math_fround(HEAPF32[$256>>2]);
   $258 = (($refStartX) + 16|0);
   HEAPF32[$258>>2] = $251;
   $259 = (($refStartX) + 20|0);
   HEAPF32[$259>>2] = $253;
   $260 = (($refStartX) + 24|0);
   HEAPF32[$260>>2] = $255;
   HEAPF32[$134>>2] = $257;
   $261 = (($4) + 32|0);
   $262 = Math_fround(HEAPF32[$261>>2]);
   $263 = (($4) + 36|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = (($4) + 40|0);
   $266 = Math_fround(HEAPF32[$265>>2]);
   $267 = (($4) + 44|0);
   $268 = Math_fround(HEAPF32[$267>>2]);
   HEAPF32[$138>>2] = $262;
   HEAPF32[$137>>2] = $264;
   HEAPF32[$136>>2] = $266;
   HEAPF32[$135>>2] = $268;
   __ZN7mecanim9animation12GetRootStopXERKNS0_18ClipMuscleConstantE($5,$constant);
   $269 = Math_fround(HEAPF32[$5>>2]);
   $270 = (($5) + 4|0);
   $271 = Math_fround(HEAPF32[$270>>2]);
   $272 = (($5) + 8|0);
   $273 = Math_fround(HEAPF32[$272>>2]);
   $274 = (($5) + 12|0);
   $275 = Math_fround(HEAPF32[$274>>2]);
   HEAPF32[$refStopX>>2] = $269;
   $276 = (($refStopX) + 4|0);
   HEAPF32[$276>>2] = $271;
   $277 = (($refStopX) + 8|0);
   HEAPF32[$277>>2] = $273;
   $278 = (($refStopX) + 12|0);
   HEAPF32[$278>>2] = $275;
   $279 = (($5) + 16|0);
   $280 = Math_fround(HEAPF32[$279>>2]);
   $281 = (($5) + 20|0);
   $282 = Math_fround(HEAPF32[$281>>2]);
   $283 = (($5) + 24|0);
   $284 = Math_fround(HEAPF32[$283>>2]);
   $285 = (($5) + 28|0);
   $286 = Math_fround(HEAPF32[$285>>2]);
   $287 = (($refStopX) + 16|0);
   HEAPF32[$287>>2] = $280;
   $288 = (($refStopX) + 20|0);
   HEAPF32[$288>>2] = $282;
   $289 = (($refStopX) + 24|0);
   HEAPF32[$289>>2] = $284;
   HEAPF32[$139>>2] = $286;
   $290 = (($5) + 32|0);
   $291 = Math_fround(HEAPF32[$290>>2]);
   $292 = (($5) + 36|0);
   $293 = Math_fround(HEAPF32[$292>>2]);
   $294 = (($5) + 40|0);
   $295 = Math_fround(HEAPF32[$294>>2]);
   $296 = (($5) + 44|0);
   $297 = Math_fround(HEAPF32[$296>>2]);
   HEAPF32[$143>>2] = $291;
   HEAPF32[$142>>2] = $293;
   HEAPF32[$141>>2] = $295;
   HEAPF32[$140>>2] = $297;
   __ZN7mecanim9animation12EvaluateRootERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($6,$constant,$memory,$109);
   $298 = Math_fround(HEAPF32[$6>>2]);
   $299 = (($6) + 4|0);
   $300 = Math_fround(HEAPF32[$299>>2]);
   $301 = (($6) + 8|0);
   $302 = Math_fround(HEAPF32[$301>>2]);
   $303 = (($6) + 12|0);
   $304 = Math_fround(HEAPF32[$303>>2]);
   $305 = (($6) + 16|0);
   $306 = Math_fround(HEAPF32[$305>>2]);
   $307 = (($6) + 20|0);
   $308 = Math_fround(HEAPF32[$307>>2]);
   $309 = (($6) + 24|0);
   $310 = Math_fround(HEAPF32[$309>>2]);
   $311 = (($6) + 28|0);
   $312 = Math_fround(HEAPF32[$311>>2]);
   __ZN7mecanim9animation12EvaluateRootERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($7,$constant,$memory,$133);
   $313 = Math_fround(HEAPF32[$7>>2]);
   $314 = (($7) + 4|0);
   $315 = Math_fround(HEAPF32[$314>>2]);
   $316 = (($7) + 8|0);
   $317 = Math_fround(HEAPF32[$316>>2]);
   $318 = (($7) + 12|0);
   $319 = Math_fround(HEAPF32[$318>>2]);
   $320 = (($7) + 16|0);
   $321 = Math_fround(HEAPF32[$320>>2]);
   $322 = (($7) + 20|0);
   $323 = Math_fround(HEAPF32[$322>>2]);
   $324 = (($7) + 24|0);
   $325 = Math_fround(HEAPF32[$324>>2]);
   $326 = (($7) + 28|0);
   $327 = Math_fround(HEAPF32[$326>>2]);
   $328 = (($7) + 32|0);
   $329 = Math_fround(HEAPF32[$328>>2]);
   $330 = (($7) + 36|0);
   $331 = Math_fround(HEAPF32[$330>>2]);
   $332 = (($7) + 40|0);
   $333 = Math_fround(HEAPF32[$332>>2]);
   $334 = (($7) + 44|0);
   $335 = Math_fround(HEAPF32[$334>>2]);
   $336 = Math_fround(HEAPF32[$134>>2]);
   $337 = Math_fround(HEAPF32[$258>>2]);
   $338 = Math_fround($336 * $337);
   $339 = Math_fround(HEAPF32[$259>>2]);
   $340 = Math_fround($336 * $339);
   $341 = Math_fround(HEAPF32[$260>>2]);
   $342 = Math_fround($336 * $341);
   $343 = Math_fround($336 * $336);
   $344 = Math_fround($343 + Math_fround(-0.5));
   $345 = Math_fround($337 * $339);
   $346 = Math_fround($339 * $339);
   $347 = Math_fround($339 * $341);
   $348 = Math_fround($342 * Math_fround(-1.0));
   $349 = Math_fround($340 * Math_fround(-1.0));
   $350 = Math_fround($345 + $348);
   $351 = Math_fround($344 + $346);
   $352 = Math_fround($338 + $347);
   $353 = Math_fround($340 + $349);
   $354 = Math_fround($350 + $350);
   $355 = Math_fround($351 + $351);
   $356 = Math_fround($352 + $352);
   $357 = Math_fround($353 + $353);
   $358 = Math_fround($355 * Math_fround(0.0));
   $359 = Math_fround($356 * Math_fround(0.0));
   $360 = Math_fround($357 * Math_fround(0.0));
   $361 = Math_fround($354 * Math_fround(0.0));
   $362 = Math_fround($354 - $358);
   $363 = Math_fround($358 - $356);
   $364 = Math_fround($359 - $361);
   $365 = Math_fround($355 + $361);
   $366 = Math_fround($359 + $360);
   $367 = Math_fround($366 + $365);
   $368 = Math_fround($354 * $354);
   $369 = Math_fround($355 * $355);
   $370 = Math_fround($356 * $356);
   $371 = Math_fround($357 * $357);
   $372 = Math_fround($369 + $368);
   $373 = Math_fround($370 + $371);
   $374 = Math_fround($373 + $372);
   $375 = (Math_fround(Math_sqrt((Math_fround($374)))));
   $376 = Math_fround($375 + $367);
   $377 = Math_fround($337 * $364);
   $378 = Math_fround($336 * $376);
   $379 = Math_fround($339 * $362);
   $380 = Math_fround($341 * $363);
   $381 = Math_fround($341 * $376);
   $382 = Math_fround($337 * $363);
   $383 = Math_fround($341 * $364);
   $384 = Math_fround($337 * $362);
   $385 = Math_fround($377 - $381);
   $386 = Math_fround($378 - $382);
   $387 = Math_fround($379 - $383);
   $388 = Math_fround($380 - $384);
   $389 = Math_fround($336 * $362);
   $390 = Math_fround($341 * $362);
   $391 = Math_fround($337 * $376);
   $392 = Math_fround($339 * $376);
   $393 = Math_fround($385 - $389);
   $394 = Math_fround($386 - $390);
   $395 = Math_fround($387 - $391);
   $396 = Math_fround($388 - $392);
   $397 = Math_fround($339 * $363);
   $398 = Math_fround($339 * $364);
   $399 = Math_fround($336 * $363);
   $400 = Math_fround($336 * $364);
   $401 = Math_fround($393 - $397);
   $402 = Math_fround($394 - $398);
   $403 = Math_fround($395 - $399);
   $404 = Math_fround($396 - $400);
   $405 = Math_fround($403 * Math_fround(-1.0));
   $406 = Math_fround($404 * Math_fround(-1.0));
   $407 = Math_fround($401 * Math_fround(-1.0));
   $408 = Math_fround($405 * Math_fround(0.0));
   $409 = Math_fround($407 * Math_fround(0.0));
   $410 = Math_fround($408 * $408);
   $411 = Math_fround($406 * $406);
   $412 = Math_fround($409 * $409);
   $413 = Math_fround($402 * $402);
   $414 = Math_fround($411 + $410);
   $415 = Math_fround($413 + $412);
   $416 = Math_fround($414 + $415);
   $417 = (Math_fround(Math_sqrt((Math_fround($416)))));
   $418 = Math_fround(Math_fround(1.0) / $417);
   $419 = Math_fround($418 * $408);
   $420 = Math_fround($418 * $406);
   $421 = Math_fround($418 * $409);
   $422 = Math_fround($418 * $402);
   HEAPF32[$258>>2] = $419;
   HEAPF32[$259>>2] = $420;
   HEAPF32[$260>>2] = $421;
   HEAPF32[$134>>2] = $422;
   $423 = Math_fround(HEAPF32[$139>>2]);
   $424 = Math_fround(HEAPF32[$287>>2]);
   $425 = Math_fround($423 * $424);
   $426 = Math_fround(HEAPF32[$288>>2]);
   $427 = Math_fround($423 * $426);
   $428 = Math_fround(HEAPF32[$289>>2]);
   $429 = Math_fround($423 * $428);
   $430 = Math_fround($423 * $423);
   $431 = Math_fround($430 + Math_fround(-0.5));
   $432 = Math_fround($424 * $426);
   $433 = Math_fround($426 * $426);
   $434 = Math_fround($426 * $428);
   $435 = Math_fround($429 * Math_fround(-1.0));
   $436 = Math_fround($427 * Math_fround(-1.0));
   $437 = Math_fround($432 + $435);
   $438 = Math_fround($431 + $433);
   $439 = Math_fround($425 + $434);
   $440 = Math_fround($427 + $436);
   $441 = Math_fround($437 + $437);
   $442 = Math_fround($438 + $438);
   $443 = Math_fround($439 + $439);
   $444 = Math_fround($440 + $440);
   $445 = Math_fround($442 * Math_fround(0.0));
   $446 = Math_fround($443 * Math_fround(0.0));
   $447 = Math_fround($444 * Math_fround(0.0));
   $448 = Math_fround($441 * Math_fround(0.0));
   $449 = Math_fround($441 - $445);
   $450 = Math_fround($445 - $443);
   $451 = Math_fround($446 - $448);
   $452 = Math_fround($442 + $448);
   $453 = Math_fround($446 + $447);
   $454 = Math_fround($453 + $452);
   $455 = Math_fround($441 * $441);
   $456 = Math_fround($442 * $442);
   $457 = Math_fround($443 * $443);
   $458 = Math_fround($444 * $444);
   $459 = Math_fround($456 + $455);
   $460 = Math_fround($457 + $458);
   $461 = Math_fround($460 + $459);
   $462 = (Math_fround(Math_sqrt((Math_fround($461)))));
   $463 = Math_fround($462 + $454);
   $464 = Math_fround($424 * $451);
   $465 = Math_fround($423 * $463);
   $466 = Math_fround($426 * $449);
   $467 = Math_fround($428 * $450);
   $468 = Math_fround($428 * $463);
   $469 = Math_fround($424 * $450);
   $470 = Math_fround($428 * $451);
   $471 = Math_fround($424 * $449);
   $472 = Math_fround($464 - $468);
   $473 = Math_fround($465 - $469);
   $474 = Math_fround($466 - $470);
   $475 = Math_fround($467 - $471);
   $476 = Math_fround($423 * $449);
   $477 = Math_fround($428 * $449);
   $478 = Math_fround($424 * $463);
   $479 = Math_fround($426 * $463);
   $480 = Math_fround($472 - $476);
   $481 = Math_fround($473 - $477);
   $482 = Math_fround($474 - $478);
   $483 = Math_fround($475 - $479);
   $484 = Math_fround($426 * $450);
   $485 = Math_fround($426 * $451);
   $486 = Math_fround($423 * $450);
   $487 = Math_fround($423 * $451);
   $488 = Math_fround($480 - $484);
   $489 = Math_fround($481 - $485);
   $490 = Math_fround($482 - $486);
   $491 = Math_fround($483 - $487);
   $492 = Math_fround($490 * Math_fround(-1.0));
   $493 = Math_fround($491 * Math_fround(-1.0));
   $494 = Math_fround($488 * Math_fround(-1.0));
   $495 = Math_fround($492 * Math_fround(0.0));
   $496 = Math_fround($494 * Math_fround(0.0));
   $497 = Math_fround($495 * $495);
   $498 = Math_fround($493 * $493);
   $499 = Math_fround($496 * $496);
   $500 = Math_fround($489 * $489);
   $501 = Math_fround($498 + $497);
   $502 = Math_fround($500 + $499);
   $503 = Math_fround($501 + $502);
   $504 = (Math_fround(Math_sqrt((Math_fround($503)))));
   $505 = Math_fround(Math_fround(1.0) / $504);
   $506 = Math_fround($505 * $495);
   $507 = Math_fround($505 * $493);
   $508 = Math_fround($505 * $496);
   $509 = Math_fround($505 * $489);
   HEAPF32[$287>>2] = $506;
   HEAPF32[$288>>2] = $507;
   HEAPF32[$289>>2] = $508;
   HEAPF32[$139>>2] = $509;
   $510 = Math_fround($306 * $312);
   $511 = Math_fround($308 * $312);
   $512 = Math_fround($310 * $312);
   $513 = Math_fround($312 * $312);
   $514 = Math_fround($513 + Math_fround(-0.5));
   $515 = Math_fround($306 * $308);
   $516 = Math_fround($308 * $308);
   $517 = Math_fround($308 * $310);
   $518 = Math_fround($512 * Math_fround(-1.0));
   $519 = Math_fround($511 * Math_fround(-1.0));
   $520 = Math_fround($515 + $518);
   $521 = Math_fround($516 + $514);
   $522 = Math_fround($517 + $510);
   $523 = Math_fround($511 + $519);
   $524 = Math_fround($520 + $520);
   $525 = Math_fround($521 + $521);
   $526 = Math_fround($522 + $522);
   $527 = Math_fround($523 + $523);
   $528 = Math_fround($525 * Math_fround(0.0));
   $529 = Math_fround($526 * Math_fround(0.0));
   $530 = Math_fround($527 * Math_fround(0.0));
   $531 = Math_fround($524 * Math_fround(0.0));
   $532 = Math_fround($524 - $528);
   $533 = Math_fround($528 - $526);
   $534 = Math_fround($529 - $531);
   $535 = Math_fround($525 + $531);
   $536 = Math_fround($529 + $530);
   $537 = Math_fround($536 + $535);
   $538 = Math_fround($524 * $524);
   $539 = Math_fround($525 * $525);
   $540 = Math_fround($526 * $526);
   $541 = Math_fround($527 * $527);
   $542 = Math_fround($539 + $538);
   $543 = Math_fround($540 + $541);
   $544 = Math_fround($543 + $542);
   $545 = (Math_fround(Math_sqrt((Math_fround($544)))));
   $546 = Math_fround($537 + $545);
   $547 = Math_fround($306 * $534);
   $548 = Math_fround($312 * $546);
   $549 = Math_fround($308 * $532);
   $550 = Math_fround($310 * $533);
   $551 = Math_fround($310 * $546);
   $552 = Math_fround($306 * $533);
   $553 = Math_fround($310 * $534);
   $554 = Math_fround($306 * $532);
   $555 = Math_fround($547 - $551);
   $556 = Math_fround($548 - $552);
   $557 = Math_fround($549 - $553);
   $558 = Math_fround($550 - $554);
   $559 = Math_fround($312 * $532);
   $560 = Math_fround($310 * $532);
   $561 = Math_fround($306 * $546);
   $562 = Math_fround($308 * $546);
   $563 = Math_fround($555 - $559);
   $564 = Math_fround($556 - $560);
   $565 = Math_fround($557 - $561);
   $566 = Math_fround($558 - $562);
   $567 = Math_fround($308 * $533);
   $568 = Math_fround($308 * $534);
   $569 = Math_fround($312 * $533);
   $570 = Math_fround($312 * $534);
   $571 = Math_fround($563 - $567);
   $572 = Math_fround($564 - $568);
   $573 = Math_fround($565 - $569);
   $574 = Math_fround($566 - $570);
   $575 = Math_fround($573 * Math_fround(-1.0));
   $576 = Math_fround($574 * Math_fround(-1.0));
   $577 = Math_fround($571 * Math_fround(-1.0));
   $578 = Math_fround($575 * Math_fround(0.0));
   $579 = Math_fround($577 * Math_fround(0.0));
   $580 = Math_fround($578 * $578);
   $581 = Math_fround($576 * $576);
   $582 = Math_fround($579 * $579);
   $583 = Math_fround($572 * $572);
   $584 = Math_fround($581 + $580);
   $585 = Math_fround($583 + $582);
   $586 = Math_fround($584 + $585);
   $587 = (Math_fround(Math_sqrt((Math_fround($586)))));
   $588 = Math_fround(Math_fround(1.0) / $587);
   $589 = Math_fround($588 * $578);
   $590 = Math_fround($588 * $576);
   $591 = Math_fround($588 * $579);
   $592 = Math_fround($588 * $572);
   $593 = Math_fround($321 * $327);
   $594 = Math_fround($323 * $327);
   $595 = Math_fround($325 * $327);
   $596 = Math_fround($327 * $327);
   $597 = Math_fround($596 + Math_fround(-0.5));
   $598 = Math_fround($321 * $323);
   $599 = Math_fround($323 * $323);
   $600 = Math_fround($323 * $325);
   $601 = Math_fround($595 * Math_fround(-1.0));
   $602 = Math_fround($594 * Math_fround(-1.0));
   $603 = Math_fround($598 + $601);
   $604 = Math_fround($599 + $597);
   $605 = Math_fround($600 + $593);
   $606 = Math_fround($594 + $602);
   $607 = Math_fround($603 + $603);
   $608 = Math_fround($604 + $604);
   $609 = Math_fround($605 + $605);
   $610 = Math_fround($606 + $606);
   $611 = Math_fround($608 * Math_fround(0.0));
   $612 = Math_fround($609 * Math_fround(0.0));
   $613 = Math_fround($610 * Math_fround(0.0));
   $614 = Math_fround($607 * Math_fround(0.0));
   $615 = Math_fround($607 - $611);
   $616 = Math_fround($611 - $609);
   $617 = Math_fround($612 - $614);
   $618 = Math_fround($608 + $614);
   $619 = Math_fround($612 + $613);
   $620 = Math_fround($619 + $618);
   $621 = Math_fround($607 * $607);
   $622 = Math_fround($608 * $608);
   $623 = Math_fround($609 * $609);
   $624 = Math_fround($610 * $610);
   $625 = Math_fround($622 + $621);
   $626 = Math_fround($623 + $624);
   $627 = Math_fround($626 + $625);
   $628 = (Math_fround(Math_sqrt((Math_fround($627)))));
   $629 = Math_fround($620 + $628);
   $630 = Math_fround($321 * $617);
   $631 = Math_fround($327 * $629);
   $632 = Math_fround($323 * $615);
   $633 = Math_fround($325 * $616);
   $634 = Math_fround($325 * $629);
   $635 = Math_fround($321 * $616);
   $636 = Math_fround($325 * $617);
   $637 = Math_fround($321 * $615);
   $638 = Math_fround($630 - $634);
   $639 = Math_fround($631 - $635);
   $640 = Math_fround($632 - $636);
   $641 = Math_fround($633 - $637);
   $642 = Math_fround($327 * $615);
   $643 = Math_fround($325 * $615);
   $644 = Math_fround($321 * $629);
   $645 = Math_fround($323 * $629);
   $646 = Math_fround($638 - $642);
   $647 = Math_fround($639 - $643);
   $648 = Math_fround($640 - $644);
   $649 = Math_fround($641 - $645);
   $650 = Math_fround($323 * $616);
   $651 = Math_fround($323 * $617);
   $652 = Math_fround($327 * $616);
   $653 = Math_fround($327 * $617);
   $654 = Math_fround($646 - $650);
   $655 = Math_fround($647 - $651);
   $656 = Math_fround($648 - $652);
   $657 = Math_fround($649 - $653);
   $658 = Math_fround($656 * Math_fround(-1.0));
   $659 = Math_fround($657 * Math_fround(-1.0));
   $660 = Math_fround($654 * Math_fround(-1.0));
   $661 = Math_fround($658 * Math_fround(0.0));
   $662 = Math_fround($660 * Math_fround(0.0));
   $663 = Math_fround($661 * $661);
   $664 = Math_fround($659 * $659);
   $665 = Math_fround($662 * $662);
   $666 = Math_fround($655 * $655);
   $667 = Math_fround($664 + $663);
   $668 = Math_fround($666 + $665);
   $669 = Math_fround($667 + $668);
   $670 = (Math_fround(Math_sqrt((Math_fround($669)))));
   $671 = Math_fround(Math_fround(1.0) / $670);
   $672 = Math_fround($671 * $661);
   $673 = Math_fround($671 * $659);
   $674 = Math_fround($671 * $662);
   $675 = Math_fround($671 * $655);
   $676 = (($constant) + 1060|0);
   $677 = Math_fround(HEAPF32[$676>>2]);
   $678 = (($constant) + 1056|0);
   $$val = Math_fround(HEAPF32[$678>>2]);
   $679 = Math_fround($$val * Math_fround(0.0174532923847436904907));
   $680 = (Math_fround(Math_abs((Math_fround($679)))));
   $681 = Math_fround($680 * Math_fround(0.5));
   $682 = +$681;
   $683 = $682 + 1.570796326794896558;
   $684 = Math_fround($683);
   $685 = $679 > Math_fround(0.0);
   $686 = $685&1;
   $687 = $679 < Math_fround(0.0);
   $688 = $687&1;
   $689 = (($686) - ($688))|0;
   $690 = (Math_fround(($689|0)));
   $691 = Math_fround($684 + Math_fround(-1.57079637050628662109));
   $692 = Math_fround($690 * $691);
   $693 = (Math_fround(+(_fmaxf((+$692),-1.57079541683197021484))));
   $694 = (Math_fround(+(_fminf((+$693),1.57079541683197021484))));
   $695 = Math_fround($694 * Math_fround(0.159154936671257019043));
   $696 = Math_fround($695 + Math_fround(-0.25));
   $697 = Math_fround($695 + Math_fround(0.0));
   $698 = (Math_fround(+(_roundf((+$696)))));
   $699 = (Math_fround(+(_roundf((+$697)))));
   $700 = Math_fround($696 - $698);
   $701 = Math_fround($697 - $699);
   $702 = (Math_fround(Math_abs((Math_fround($700)))));
   $703 = (Math_fround(Math_abs((Math_fround($701)))));
   $704 = Math_fround(Math_fround(0.25) - $702);
   $705 = Math_fround(Math_fround(0.25) - $703);
   $706 = Math_fround($704 * $704);
   $707 = Math_fround($705 * $705);
   $708 = Math_fround($706 * $706);
   $709 = Math_fround($707 * $707);
   $710 = Math_fround($706 * Math_fround(-41.283184051513671875));
   $711 = Math_fround($707 * Math_fround(-41.283184051513671875));
   $712 = Math_fround($710 + Math_fround(6.28318548202514648438));
   $713 = Math_fround($711 + Math_fround(6.28318548202514648438));
   $714 = Math_fround($708 * Math_fround(76.03546142578125));
   $715 = Math_fround($709 * Math_fround(76.03546142578125));
   $716 = Math_fround($712 + $714);
   $717 = Math_fround($713 + $715);
   $718 = Math_fround($704 * $716);
   $719 = Math_fround($705 * $717);
   $720 = Math_fround($718 / $719);
   $721 = Math_fround($720 * $720);
   $722 = Math_fround($721 + Math_fround(0.0));
   $723 = Math_fround($722 + Math_fround(1.0));
   $724 = (Math_fround(Math_sqrt((Math_fround($723)))));
   $725 = Math_fround(Math_fround(1.0) / $724);
   $726 = Math_fround($725 * Math_fround(0.0));
   $727 = Math_fround($720 * $725);
   $728 = (($constant) + 1639|0);
   $729 = HEAP8[$728>>0]|0;
   $730 = ($729<<24>>24)==(0);
   if ($730) {
    $794 = $677;
   } else {
    $731 = Math_fround(HEAPF32[$247>>2]);
    $732 = Math_fround($677 - $731);
    $794 = $732;
   }
   $733 = (($constant) + 1640|0);
   $734 = HEAP8[$733>>0]|0;
   $735 = ($734<<24>>24)==(0);
   if ($735) {
    $791 = Math_fround(0.0);$797 = Math_fround(0.0);
   } else {
    $736 = Math_fround(HEAPF32[$refStartX>>2]);
    $737 = Math_fround(Math_fround(0.0) - $736);
    $738 = Math_fround(HEAPF32[$248>>2]);
    $739 = Math_fround(Math_fround(0.0) - $738);
    $791 = $737;$797 = $739;
   }
   $740 = (($constant) + 1638|0);
   $741 = HEAP8[$740>>0]|0;
   $742 = ($741<<24>>24)==(0);
   $$pre241 = Math_fround(HEAPF32[$258>>2]);
   if ($742) {
    $$pre242 = Math_fround(HEAPF32[$134>>2]);
    $$pre243 = Math_fround(HEAPF32[$259>>2]);
    $$pre244 = Math_fround(HEAPF32[$260>>2]);
    $817 = $727;$819 = $$pre242;$820 = $725;$822 = $$pre243;$823 = $726;$825 = $$pre244;$826 = $726;
   } else {
    $743 = Math_fround($$pre241 * Math_fround(-1.0));
    $744 = Math_fround(HEAPF32[$259>>2]);
    $745 = Math_fround($744 * Math_fround(-1.0));
    $746 = Math_fround(HEAPF32[$260>>2]);
    $747 = Math_fround($746 * Math_fround(-1.0));
    $748 = Math_fround(HEAPF32[$134>>2]);
    $749 = Math_fround($727 * $743);
    $750 = Math_fround($725 * $748);
    $751 = Math_fround($726 * $745);
    $752 = Math_fround($726 * $747);
    $753 = Math_fround($725 * $747);
    $754 = Math_fround($726 * $743);
    $755 = Math_fround($727 * $747);
    $756 = Math_fround($749 - $753);
    $757 = Math_fround($750 - $754);
    $758 = Math_fround($751 - $755);
    $759 = Math_fround($752 - $754);
    $760 = Math_fround($726 * $748);
    $761 = Math_fround($725 * $743);
    $762 = Math_fround($725 * $745);
    $763 = Math_fround($756 - $760);
    $764 = Math_fround($757 - $752);
    $765 = Math_fround($758 - $761);
    $766 = Math_fround($759 - $762);
    $767 = Math_fround($727 * $745);
    $768 = Math_fround($727 * $748);
    $769 = Math_fround($763 - $751);
    $770 = Math_fround($764 - $767);
    $771 = Math_fround($765 - $760);
    $772 = Math_fround($766 - $768);
    $773 = Math_fround($771 * Math_fround(-1.0));
    $774 = Math_fround($772 * Math_fround(-1.0));
    $775 = Math_fround($769 * Math_fround(-1.0));
    $776 = Math_fround($773 * $773);
    $777 = Math_fround($774 * $774);
    $778 = Math_fround($775 * $775);
    $779 = Math_fround($770 * $770);
    $780 = Math_fround($776 + $777);
    $781 = Math_fround($779 + $778);
    $782 = Math_fround($780 + $781);
    $783 = (Math_fround(Math_sqrt((Math_fround($782)))));
    $784 = Math_fround(Math_fround(1.0) / $783);
    $785 = Math_fround($784 * $773);
    $786 = Math_fround($784 * $774);
    $787 = Math_fround($784 * $775);
    $788 = Math_fround($784 * $770);
    $817 = $786;$819 = $748;$820 = $788;$822 = $744;$823 = $787;$825 = $746;$826 = $785;
   }
   $789 = Math_fround(HEAPF32[$refStartX>>2]);
   $790 = Math_fround($791 + $789);
   $792 = Math_fround(HEAPF32[$247>>2]);
   $793 = Math_fround($794 + $792);
   $795 = Math_fround(HEAPF32[$248>>2]);
   $796 = Math_fround($797 + $795);
   $798 = Math_fround(HEAPF32[$249>>2]);
   $799 = Math_fround($798 + Math_fround(0.0));
   HEAPF32[$refStartX>>2] = $790;
   HEAPF32[$247>>2] = $793;
   HEAPF32[$248>>2] = $796;
   HEAPF32[$249>>2] = $799;
   $800 = Math_fround(HEAPF32[$refStopX>>2]);
   $801 = Math_fround($791 + $800);
   $802 = Math_fround(HEAPF32[$276>>2]);
   $803 = Math_fround($794 + $802);
   $804 = Math_fround(HEAPF32[$277>>2]);
   $805 = Math_fround($797 + $804);
   $806 = Math_fround(HEAPF32[$278>>2]);
   $807 = Math_fround($806 + Math_fround(0.0));
   HEAPF32[$refStopX>>2] = $801;
   HEAPF32[$276>>2] = $803;
   HEAPF32[$277>>2] = $805;
   HEAPF32[$278>>2] = $807;
   $808 = Math_fround($298 + $791);
   $809 = Math_fround($300 + $794);
   $810 = Math_fround($302 + $797);
   $811 = Math_fround($304 + Math_fround(0.0));
   $812 = Math_fround($313 + $791);
   $813 = Math_fround($315 + $794);
   $814 = Math_fround($317 + $797);
   $815 = Math_fround($319 + Math_fround(0.0));
   $816 = Math_fround($817 * $$pre241);
   $818 = Math_fround($820 * $819);
   $821 = Math_fround($823 * $822);
   $824 = Math_fround($826 * $825);
   $827 = Math_fround($820 * $825);
   $828 = Math_fround($826 * $$pre241);
   $829 = Math_fround($817 * $825);
   $830 = Math_fround($823 * $$pre241);
   $831 = Math_fround($816 - $827);
   $832 = Math_fround($818 - $828);
   $833 = Math_fround($821 - $829);
   $834 = Math_fround($824 - $830);
   $835 = Math_fround($823 * $819);
   $836 = Math_fround($823 * $825);
   $837 = Math_fround($820 * $$pre241);
   $838 = Math_fround($820 * $822);
   $839 = Math_fround($831 - $835);
   $840 = Math_fround($832 - $836);
   $841 = Math_fround($833 - $837);
   $842 = Math_fround($834 - $838);
   $843 = Math_fround($826 * $822);
   $844 = Math_fround($817 * $822);
   $845 = Math_fround($826 * $819);
   $846 = Math_fround($817 * $819);
   $847 = Math_fround($839 - $843);
   $848 = Math_fround($840 - $844);
   $849 = Math_fround($841 - $845);
   $850 = Math_fround($842 - $846);
   $851 = Math_fround($849 * Math_fround(-1.0));
   $852 = Math_fround($850 * Math_fround(-1.0));
   $853 = Math_fround($847 * Math_fround(-1.0));
   $854 = Math_fround($851 * $851);
   $855 = Math_fround($852 * $852);
   $856 = Math_fround($853 * $853);
   $857 = Math_fround($848 * $848);
   $858 = Math_fround($854 + $855);
   $859 = Math_fround($857 + $856);
   $860 = Math_fround($858 + $859);
   $861 = (Math_fround(Math_sqrt((Math_fround($860)))));
   $862 = Math_fround(Math_fround(1.0) / $861);
   $863 = Math_fround($862 * $851);
   $864 = Math_fround($862 * $852);
   $865 = Math_fround($862 * $853);
   $866 = Math_fround($862 * $848);
   HEAPF32[$258>>2] = $863;
   HEAPF32[$259>>2] = $864;
   HEAPF32[$260>>2] = $865;
   HEAPF32[$134>>2] = $866;
   $867 = Math_fround(HEAPF32[$287>>2]);
   $868 = Math_fround($817 * $867);
   $869 = Math_fround(HEAPF32[$139>>2]);
   $870 = Math_fround($820 * $869);
   $871 = Math_fround(HEAPF32[$288>>2]);
   $872 = Math_fround($823 * $871);
   $873 = Math_fround(HEAPF32[$289>>2]);
   $874 = Math_fround($826 * $873);
   $875 = Math_fround($820 * $873);
   $876 = Math_fround($826 * $867);
   $877 = Math_fround($817 * $873);
   $878 = Math_fround($823 * $867);
   $879 = Math_fround($868 - $875);
   $880 = Math_fround($870 - $876);
   $881 = Math_fround($872 - $877);
   $882 = Math_fround($874 - $878);
   $883 = Math_fround($823 * $869);
   $884 = Math_fround($823 * $873);
   $885 = Math_fround($820 * $867);
   $886 = Math_fround($820 * $871);
   $887 = Math_fround($879 - $883);
   $888 = Math_fround($880 - $884);
   $889 = Math_fround($881 - $885);
   $890 = Math_fround($882 - $886);
   $891 = Math_fround($826 * $871);
   $892 = Math_fround($817 * $871);
   $893 = Math_fround($826 * $869);
   $894 = Math_fround($817 * $869);
   $895 = Math_fround($887 - $891);
   $896 = Math_fround($888 - $892);
   $897 = Math_fround($889 - $893);
   $898 = Math_fround($890 - $894);
   $899 = Math_fround($897 * Math_fround(-1.0));
   $900 = Math_fround($898 * Math_fround(-1.0));
   $901 = Math_fround($895 * Math_fround(-1.0));
   $902 = Math_fround($899 * $899);
   $903 = Math_fround($900 * $900);
   $904 = Math_fround($901 * $901);
   $905 = Math_fround($896 * $896);
   $906 = Math_fround($902 + $903);
   $907 = Math_fround($905 + $904);
   $908 = Math_fround($906 + $907);
   $909 = (Math_fround(Math_sqrt((Math_fround($908)))));
   $910 = Math_fround(Math_fround(1.0) / $909);
   $911 = Math_fround($910 * $899);
   $912 = Math_fround($910 * $900);
   $913 = Math_fround($910 * $901);
   $914 = Math_fround($910 * $896);
   HEAPF32[$287>>2] = $911;
   HEAPF32[$288>>2] = $912;
   HEAPF32[$289>>2] = $913;
   HEAPF32[$139>>2] = $914;
   $915 = Math_fround($589 * $817);
   $916 = Math_fround($592 * $820);
   $917 = Math_fround($590 * $823);
   $918 = Math_fround($591 * $826);
   $919 = Math_fround($591 * $820);
   $920 = Math_fround($589 * $826);
   $921 = Math_fround($591 * $817);
   $922 = Math_fround($589 * $823);
   $923 = Math_fround($915 - $919);
   $924 = Math_fround($916 - $920);
   $925 = Math_fround($917 - $921);
   $926 = Math_fround($918 - $922);
   $927 = Math_fround($592 * $823);
   $928 = Math_fround($591 * $823);
   $929 = Math_fround($589 * $820);
   $930 = Math_fround($590 * $820);
   $931 = Math_fround($923 - $927);
   $932 = Math_fround($924 - $928);
   $933 = Math_fround($925 - $929);
   $934 = Math_fround($926 - $930);
   $935 = Math_fround($590 * $826);
   $936 = Math_fround($590 * $817);
   $937 = Math_fround($592 * $826);
   $938 = Math_fround($592 * $817);
   $939 = Math_fround($931 - $935);
   $940 = Math_fround($932 - $936);
   $941 = Math_fround($933 - $937);
   $942 = Math_fround($934 - $938);
   $943 = Math_fround($941 * Math_fround(-1.0));
   $944 = Math_fround($942 * Math_fround(-1.0));
   $945 = Math_fround($939 * Math_fround(-1.0));
   $946 = Math_fround($943 * $943);
   $947 = Math_fround($944 * $944);
   $948 = Math_fround($945 * $945);
   $949 = Math_fround($940 * $940);
   $950 = Math_fround($946 + $947);
   $951 = Math_fround($948 + $949);
   $952 = Math_fround($951 + $950);
   $953 = (Math_fround(Math_sqrt((Math_fround($952)))));
   $954 = Math_fround(Math_fround(1.0) / $953);
   $955 = Math_fround($943 * $954);
   $956 = Math_fround($944 * $954);
   $957 = Math_fround($945 * $954);
   $958 = Math_fround($940 * $954);
   $959 = Math_fround($672 * $817);
   $960 = Math_fround($675 * $820);
   $961 = Math_fround($673 * $823);
   $962 = Math_fround($674 * $826);
   $963 = Math_fround($674 * $820);
   $964 = Math_fround($672 * $826);
   $965 = Math_fround($674 * $817);
   $966 = Math_fround($672 * $823);
   $967 = Math_fround($959 - $963);
   $968 = Math_fround($960 - $964);
   $969 = Math_fround($961 - $965);
   $970 = Math_fround($962 - $966);
   $971 = Math_fround($675 * $823);
   $972 = Math_fround($674 * $823);
   $973 = Math_fround($672 * $820);
   $974 = Math_fround($673 * $820);
   $975 = Math_fround($967 - $971);
   $976 = Math_fround($968 - $972);
   $977 = Math_fround($969 - $973);
   $978 = Math_fround($970 - $974);
   $979 = Math_fround($673 * $826);
   $980 = Math_fround($673 * $817);
   $981 = Math_fround($675 * $826);
   $982 = Math_fround($675 * $817);
   $983 = Math_fround($975 - $979);
   $984 = Math_fround($976 - $980);
   $985 = Math_fround($977 - $981);
   $986 = Math_fround($978 - $982);
   $987 = Math_fround($985 * Math_fround(-1.0));
   $988 = Math_fround($986 * Math_fround(-1.0));
   $989 = Math_fround($983 * Math_fround(-1.0));
   $990 = Math_fround($987 * $987);
   $991 = Math_fround($988 * $988);
   $992 = Math_fround($989 * $989);
   $993 = Math_fround($984 * $984);
   $994 = Math_fround($990 + $991);
   $995 = Math_fround($992 + $993);
   $996 = Math_fround($995 + $994);
   $997 = (Math_fround(Math_sqrt((Math_fround($996)))));
   $998 = Math_fround(Math_fround(1.0) / $997);
   $999 = Math_fround($987 * $998);
   $1000 = Math_fround($988 * $998);
   $1001 = Math_fround($989 * $998);
   $1002 = Math_fround($984 * $998);
   $1003 = (($constant) + 1635|0);
   $1004 = HEAP8[$1003>>0]|0;
   $1005 = ($1004<<24>>24)==(0);
   if ($1005) {
    $1777 = $914;$1778 = $913;$1779 = $912;$1780 = $911;$1781 = $958;$1782 = $957;$1783 = $956;$1784 = $955;$1785 = $1002;$1786 = $1001;$1787 = $1000;$1788 = $999;
   } else {
    $1006 = Math_fround(HEAPF32[$258>>2]);
    $1007 = Math_fround(HEAPF32[$259>>2]);
    $1008 = Math_fround(HEAPF32[$260>>2]);
    $1009 = Math_fround(HEAPF32[$134>>2]);
    HEAPF32[$287>>2] = $1006;
    HEAPF32[$288>>2] = $1007;
    HEAPF32[$289>>2] = $1008;
    HEAPF32[$139>>2] = $1009;
    $1777 = $1009;$1778 = $1008;$1779 = $1007;$1780 = $1006;$1781 = $1009;$1782 = $1008;$1783 = $1007;$1784 = $1006;$1785 = $1009;$1786 = $1008;$1787 = $1007;$1788 = $1006;
   }
   $1010 = (($constant) + 1636|0);
   $1011 = HEAP8[$1010>>0]|0;
   $1012 = ($1011<<24>>24)==(0);
   if ($1012) {
    $1789 = $809;$1790 = $813;
   } else {
    $1013 = Math_fround(HEAPF32[$247>>2]);
    HEAPF32[$276>>2] = $1013;
    $1789 = $1013;$1790 = $1013;
   }
   $1014 = (($constant) + 1637|0);
   $1015 = HEAP8[$1014>>0]|0;
   $1016 = ($1015<<24>>24)==(0);
   if ($1016) {
    $$pre$phi248Z2D = $247;$$pre$phi250Z2D = $248;$$pre$phi252Z2D = $249;$$pre$phi254Z2D = $258;$$pre$phi256Z2D = $259;$$pre$phi258Z2D = $260;$$pre$phi260Z2D = $refStopX;$$pre$phi262Z2D = $276;$$pre$phi264Z2D = $277;$$pre$phi266Z2D = $278;$$pre$phi268Z2D = $287;$$pre$phi270Z2D = $288;$$pre$phi272Z2D = $289;$$pre$phiZ2D = $refStartX;$1019 = $812;$1020 = $1790;$1021 = $814;$1022 = $815;$1023 = $1788;$1024 = $1787;$1025 = $1786;$1026 = $1785;$1027 = $329;$1028 = $331;$1029 = $333;$1030 = $335;$1064 = $1780;$1066 = $1779;$1068 = $1778;$1070 = $1777;$1184 = $1784;$1186 = $1783;$1188 = $1782;$1191 = $808;$1195 = $1789;$1199 = $810;$1203 = $811;$1211 = $1781;
   } else {
    $1017 = Math_fround(HEAPF32[$refStartX>>2]);
    HEAPF32[$refStopX>>2] = $1017;
    $1018 = Math_fround(HEAPF32[$248>>2]);
    HEAPF32[$277>>2] = $1018;
    $$pre$phi248Z2D = $247;$$pre$phi250Z2D = $248;$$pre$phi252Z2D = $249;$$pre$phi254Z2D = $258;$$pre$phi256Z2D = $259;$$pre$phi258Z2D = $260;$$pre$phi260Z2D = $refStopX;$$pre$phi262Z2D = $276;$$pre$phi264Z2D = $277;$$pre$phi266Z2D = $278;$$pre$phi268Z2D = $287;$$pre$phi270Z2D = $288;$$pre$phi272Z2D = $289;$$pre$phiZ2D = $refStartX;$1019 = $1017;$1020 = $1790;$1021 = $1018;$1022 = $815;$1023 = $1788;$1024 = $1787;$1025 = $1786;$1026 = $1785;$1027 = $329;$1028 = $331;$1029 = $333;$1030 = $335;$1064 = $1780;$1066 = $1779;$1068 = $1778;$1070 = $1777;$1184 = $1784;$1186 = $1783;$1188 = $1782;$1191 = $1017;$1195 = $1789;$1199 = $1018;$1203 = $811;$1211 = $1781;
   }
  }
 } while(0);
 HEAPF32[$62>>2] = $1019;
 HEAPF32[$63>>2] = $1020;
 HEAPF32[$64>>2] = $1021;
 HEAPF32[$65>>2] = $1022;
 HEAPF32[$66>>2] = $1023;
 HEAPF32[$67>>2] = $1024;
 HEAPF32[$68>>2] = $1025;
 HEAPF32[$69>>2] = $1026;
 HEAPF32[$70>>2] = $1027;
 HEAPF32[$71>>2] = $1028;
 HEAPF32[$72>>2] = $1029;
 HEAPF32[$73>>2] = $1030;
 $1031 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
 $1032 = Math_fround(HEAPF32[$$pre$phi248Z2D>>2]);
 $1033 = Math_fround(HEAPF32[$$pre$phi250Z2D>>2]);
 $1034 = Math_fround(HEAPF32[$$pre$phi252Z2D>>2]);
 $1035 = (($output) + 132|0);
 HEAPF32[$1035>>2] = $1031;
 $1036 = (($output) + 136|0);
 HEAPF32[$1036>>2] = $1032;
 $1037 = (($output) + 140|0);
 HEAPF32[$1037>>2] = $1033;
 $1038 = (($output) + 144|0);
 HEAPF32[$1038>>2] = $1034;
 $1039 = Math_fround(HEAPF32[$$pre$phi254Z2D>>2]);
 $1040 = Math_fround(HEAPF32[$$pre$phi256Z2D>>2]);
 $1041 = Math_fround(HEAPF32[$$pre$phi258Z2D>>2]);
 $1042 = Math_fround(HEAPF32[$134>>2]);
 $1043 = (($output) + 148|0);
 HEAPF32[$1043>>2] = $1039;
 $1044 = (($output) + 152|0);
 HEAPF32[$1044>>2] = $1040;
 $1045 = (($output) + 156|0);
 HEAPF32[$1045>>2] = $1041;
 $1046 = (($output) + 160|0);
 HEAPF32[$1046>>2] = $1042;
 $1047 = Math_fround(HEAPF32[$138>>2]);
 $1048 = Math_fround(HEAPF32[$137>>2]);
 $1049 = Math_fround(HEAPF32[$136>>2]);
 $1050 = Math_fround(HEAPF32[$135>>2]);
 $1051 = (($output) + 164|0);
 HEAPF32[$1051>>2] = $1047;
 $1052 = (($output) + 168|0);
 HEAPF32[$1052>>2] = $1048;
 $1053 = (($output) + 172|0);
 HEAPF32[$1053>>2] = $1049;
 $1054 = (($output) + 176|0);
 HEAPF32[$1054>>2] = $1050;
 $1055 = Math_fround(HEAPF32[$$pre$phi260Z2D>>2]);
 $1056 = Math_fround(HEAPF32[$$pre$phi262Z2D>>2]);
 $1057 = Math_fround(HEAPF32[$$pre$phi264Z2D>>2]);
 $1058 = Math_fround(HEAPF32[$$pre$phi266Z2D>>2]);
 $1059 = (($output) + 180|0);
 HEAPF32[$1059>>2] = $1055;
 $1060 = (($output) + 184|0);
 HEAPF32[$1060>>2] = $1056;
 $1061 = (($output) + 188|0);
 HEAPF32[$1061>>2] = $1057;
 $1062 = (($output) + 192|0);
 HEAPF32[$1062>>2] = $1058;
 $1063 = (($output) + 196|0);
 HEAPF32[$1063>>2] = $1064;
 $1065 = (($output) + 200|0);
 HEAPF32[$1065>>2] = $1066;
 $1067 = (($output) + 204|0);
 HEAPF32[$1067>>2] = $1068;
 $1069 = (($output) + 208|0);
 HEAPF32[$1069>>2] = $1070;
 $1071 = Math_fround(HEAPF32[$143>>2]);
 $1072 = Math_fround(HEAPF32[$142>>2]);
 $1073 = Math_fround(HEAPF32[$141>>2]);
 $1074 = Math_fround(HEAPF32[$140>>2]);
 $1075 = (($output) + 212|0);
 HEAPF32[$1075>>2] = $1071;
 $1076 = (($output) + 216|0);
 HEAPF32[$1076>>2] = $1072;
 $1077 = (($output) + 220|0);
 HEAPF32[$1077>>2] = $1073;
 $1078 = (($output) + 224|0);
 HEAPF32[$1078>>2] = $1074;
 $1079 = HEAP8[$87>>0]|0;
 $1080 = ($1079<<24>>24)==(0);
 do {
  if ($1080) {
   $1586 = Math_fround(HEAPF32[$81>>2]);
   $1587 = Math_fround(HEAPF32[$input>>2]);
   $1588 = $1586 != $1587;
   if ($1588) {
    $1589 = Math_fround($1184 * Math_fround(-1.0));
    $1590 = Math_fround($1186 * Math_fround(-1.0));
    $1591 = Math_fround($1188 * Math_fround(-1.0));
    $1592 = Math_fround($1019 - $1191);
    $1593 = Math_fround($1020 - $1195);
    $1594 = Math_fround($1021 - $1199);
    $1595 = Math_fround($1022 - $1203);
    $1596 = Math_fround($1592 + $1592);
    $1597 = Math_fround($1593 + $1593);
    $1598 = Math_fround($1594 + $1594);
    $1599 = Math_fround($1589 * $1597);
    $1600 = Math_fround($1590 * $1598);
    $1601 = Math_fround($1591 * $1596);
    $1602 = Math_fround($1211 * Math_fround(0.0));
    $1603 = Math_fround($1590 * $1596);
    $1604 = Math_fround($1591 * $1597);
    $1605 = Math_fround($1589 * $1598);
    $1606 = Math_fround($1599 - $1603);
    $1607 = Math_fround($1600 - $1604);
    $1608 = Math_fround($1601 - $1605);
    $1609 = Math_fround($1602 - $1602);
    $1610 = Math_fround($1211 * $1607);
    $1611 = Math_fround($1211 * $1608);
    $1612 = Math_fround($1211 * $1606);
    $1613 = Math_fround($1211 * $1609);
    $1614 = Math_fround($1592 + $1610);
    $1615 = Math_fround($1593 + $1611);
    $1616 = Math_fround($1594 + $1612);
    $1617 = Math_fround($1613 + $1595);
    $1618 = Math_fround($1589 * $1608);
    $1619 = Math_fround($1590 * $1606);
    $1620 = Math_fround($1591 * $1607);
    $1621 = Math_fround($1590 * $1607);
    $1622 = Math_fround($1591 * $1608);
    $1623 = Math_fround($1589 * $1606);
    $1624 = Math_fround($1618 - $1621);
    $1625 = Math_fround($1619 - $1622);
    $1626 = Math_fround($1620 - $1623);
    $1627 = Math_fround($1613 - $1613);
    $1628 = Math_fround($1614 + $1625);
    $1629 = Math_fround($1615 + $1626);
    $1630 = Math_fround($1616 + $1624);
    $1631 = Math_fround($1627 + $1617);
    $1632 = Math_fround($1590 * $1023);
    $1633 = Math_fround($1211 * $1026);
    $1634 = Math_fround($1591 * $1024);
    $1635 = Math_fround($1589 * $1025);
    $1636 = Math_fround($1211 * $1025);
    $1637 = Math_fround($1589 * $1023);
    $1638 = Math_fround($1590 * $1025);
    $1639 = Math_fround($1591 * $1023);
    $1640 = Math_fround($1632 - $1636);
    $1641 = Math_fround($1633 - $1637);
    $1642 = Math_fround($1634 - $1638);
    $1643 = Math_fround($1635 - $1639);
    $1644 = Math_fround($1591 * $1026);
    $1645 = Math_fround($1591 * $1025);
    $1646 = Math_fround($1211 * $1023);
    $1647 = Math_fround($1211 * $1024);
    $1648 = Math_fround($1640 - $1644);
    $1649 = Math_fround($1641 - $1645);
    $1650 = Math_fround($1642 - $1646);
    $1651 = Math_fround($1643 - $1647);
    $1652 = Math_fround($1589 * $1024);
    $1653 = Math_fround($1590 * $1024);
    $1654 = Math_fround($1589 * $1026);
    $1655 = Math_fround($1590 * $1026);
    $1656 = Math_fround($1648 - $1652);
    $1657 = Math_fround($1649 - $1653);
    $1658 = Math_fround($1650 - $1654);
    $1659 = Math_fround($1651 - $1655);
    $1660 = Math_fround($1658 * Math_fround(-1.0));
    $1661 = Math_fround($1659 * Math_fround(-1.0));
    $1662 = Math_fround($1656 * Math_fround(-1.0));
    $1663 = Math_fround($1660 * $1660);
    $1664 = Math_fround($1661 * $1661);
    $1665 = Math_fround($1662 * $1662);
    $1666 = Math_fround($1657 * $1657);
    $1667 = Math_fround($1663 + $1664);
    $1668 = Math_fround($1666 + $1665);
    $1669 = Math_fround($1667 + $1668);
    $1670 = (Math_fround(Math_sqrt((Math_fround($1669)))));
    $1671 = Math_fround(Math_fround(1.0) / $1670);
    $1672 = Math_fround($1660 * $1671);
    $1673 = Math_fround($1661 * $1671);
    $1674 = Math_fround($1662 * $1671);
    $1675 = Math_fround($1657 * $1671);
    $1677 = $1675;$1680 = $1672;$1682 = $1673;$1684 = $1674;$1688 = $1629;$1693 = $1630;$1695 = $1628;$1732 = $1631;
   } else {
    $1677 = Math_fround(1.0);$1680 = Math_fround(0.0);$1682 = Math_fround(0.0);$1684 = Math_fround(0.0);$1688 = Math_fround(0.0);$1693 = Math_fround(0.0);$1695 = Math_fround(0.0);$1732 = Math_fround(0.0);
   }
  } else {
   $1081 = Math_fround($130 - $106);
   $1082 = (Math_fround(Math_abs((Math_fround($1081)))));
   $1083 = $1082 > Math_fround(0.5);
   if (!($1083)) {
    $1498 = $130 != $106;
    if (!($1498)) {
     $1677 = Math_fround(1.0);$1680 = Math_fround(0.0);$1682 = Math_fround(0.0);$1684 = Math_fround(0.0);$1688 = Math_fround(0.0);$1693 = Math_fround(0.0);$1695 = Math_fround(0.0);$1732 = Math_fround(0.0);
     break;
    }
    $1499 = Math_fround($1184 * Math_fround(-1.0));
    $1500 = Math_fround($1186 * Math_fround(-1.0));
    $1501 = Math_fround($1188 * Math_fround(-1.0));
    $1502 = Math_fround($1019 - $1191);
    $1503 = Math_fround($1020 - $1195);
    $1504 = Math_fround($1021 - $1199);
    $1505 = Math_fround($1022 - $1203);
    $1506 = Math_fround($1502 + $1502);
    $1507 = Math_fround($1503 + $1503);
    $1508 = Math_fround($1504 + $1504);
    $1509 = Math_fround($1499 * $1507);
    $1510 = Math_fround($1500 * $1508);
    $1511 = Math_fround($1501 * $1506);
    $1512 = Math_fround($1211 * Math_fround(0.0));
    $1513 = Math_fround($1500 * $1506);
    $1514 = Math_fround($1501 * $1507);
    $1515 = Math_fround($1499 * $1508);
    $1516 = Math_fround($1509 - $1513);
    $1517 = Math_fround($1510 - $1514);
    $1518 = Math_fround($1511 - $1515);
    $1519 = Math_fround($1512 - $1512);
    $1520 = Math_fround($1211 * $1517);
    $1521 = Math_fround($1211 * $1518);
    $1522 = Math_fround($1211 * $1516);
    $1523 = Math_fround($1211 * $1519);
    $1524 = Math_fround($1502 + $1520);
    $1525 = Math_fround($1503 + $1521);
    $1526 = Math_fround($1504 + $1522);
    $1527 = Math_fround($1523 + $1505);
    $1528 = Math_fround($1499 * $1518);
    $1529 = Math_fround($1500 * $1516);
    $1530 = Math_fround($1501 * $1517);
    $1531 = Math_fround($1500 * $1517);
    $1532 = Math_fround($1501 * $1518);
    $1533 = Math_fround($1499 * $1516);
    $1534 = Math_fround($1528 - $1531);
    $1535 = Math_fround($1529 - $1532);
    $1536 = Math_fround($1530 - $1533);
    $1537 = Math_fround($1523 - $1523);
    $1538 = Math_fround($1524 + $1535);
    $1539 = Math_fround($1525 + $1536);
    $1540 = Math_fround($1526 + $1534);
    $1541 = Math_fround($1537 + $1527);
    $1542 = Math_fround($1500 * $1023);
    $1543 = Math_fround($1211 * $1026);
    $1544 = Math_fround($1501 * $1024);
    $1545 = Math_fround($1499 * $1025);
    $1546 = Math_fround($1211 * $1025);
    $1547 = Math_fround($1499 * $1023);
    $1548 = Math_fround($1500 * $1025);
    $1549 = Math_fround($1501 * $1023);
    $1550 = Math_fround($1542 - $1546);
    $1551 = Math_fround($1543 - $1547);
    $1552 = Math_fround($1544 - $1548);
    $1553 = Math_fround($1545 - $1549);
    $1554 = Math_fround($1501 * $1026);
    $1555 = Math_fround($1501 * $1025);
    $1556 = Math_fround($1211 * $1023);
    $1557 = Math_fround($1211 * $1024);
    $1558 = Math_fround($1550 - $1554);
    $1559 = Math_fround($1551 - $1555);
    $1560 = Math_fround($1552 - $1556);
    $1561 = Math_fround($1553 - $1557);
    $1562 = Math_fround($1499 * $1024);
    $1563 = Math_fround($1500 * $1024);
    $1564 = Math_fround($1499 * $1026);
    $1565 = Math_fround($1500 * $1026);
    $1566 = Math_fround($1558 - $1562);
    $1567 = Math_fround($1559 - $1563);
    $1568 = Math_fround($1560 - $1564);
    $1569 = Math_fround($1561 - $1565);
    $1570 = Math_fround($1568 * Math_fround(-1.0));
    $1571 = Math_fround($1569 * Math_fround(-1.0));
    $1572 = Math_fround($1566 * Math_fround(-1.0));
    $1573 = Math_fround($1570 * $1570);
    $1574 = Math_fround($1571 * $1571);
    $1575 = Math_fround($1572 * $1572);
    $1576 = Math_fround($1567 * $1567);
    $1577 = Math_fround($1573 + $1574);
    $1578 = Math_fround($1576 + $1575);
    $1579 = Math_fround($1577 + $1578);
    $1580 = (Math_fround(Math_sqrt((Math_fround($1579)))));
    $1581 = Math_fround(Math_fround(1.0) / $1580);
    $1582 = Math_fround($1570 * $1581);
    $1583 = Math_fround($1571 * $1581);
    $1584 = Math_fround($1572 * $1581);
    $1585 = Math_fround($1567 * $1581);
    $1677 = $1585;$1680 = $1582;$1682 = $1583;$1684 = $1584;$1688 = $1539;$1693 = $1540;$1695 = $1538;$1732 = $1541;
    break;
   }
   $1084 = $130 < $106;
   if ($1084) {
    $1085 = Math_fround($1039 * Math_fround(-1.0));
    $1086 = Math_fround($1040 * Math_fround(-1.0));
    $1087 = Math_fround($1041 * Math_fround(-1.0));
    $1088 = Math_fround($1019 - $1031);
    $1089 = Math_fround($1020 - $1032);
    $1090 = Math_fround($1021 - $1033);
    $1091 = Math_fround($1022 - $1034);
    $1092 = Math_fround($1088 + $1088);
    $1093 = Math_fround($1089 + $1089);
    $1094 = Math_fround($1090 + $1090);
    $1095 = Math_fround($1085 * $1093);
    $1096 = Math_fround($1086 * $1094);
    $1097 = Math_fround($1087 * $1092);
    $1098 = Math_fround($1042 * Math_fround(0.0));
    $1099 = Math_fround($1086 * $1092);
    $1100 = Math_fround($1087 * $1093);
    $1101 = Math_fround($1085 * $1094);
    $1102 = Math_fround($1095 - $1099);
    $1103 = Math_fround($1096 - $1100);
    $1104 = Math_fround($1097 - $1101);
    $1105 = Math_fround($1098 - $1098);
    $1106 = Math_fround($1042 * $1103);
    $1107 = Math_fround($1042 * $1104);
    $1108 = Math_fround($1042 * $1102);
    $1109 = Math_fround($1042 * $1105);
    $1110 = Math_fround($1088 + $1106);
    $1111 = Math_fround($1089 + $1107);
    $1112 = Math_fround($1090 + $1108);
    $1113 = Math_fround($1109 + $1091);
    $1114 = Math_fround($1085 * $1104);
    $1115 = Math_fround($1086 * $1102);
    $1116 = Math_fround($1087 * $1103);
    $1117 = Math_fround($1086 * $1103);
    $1118 = Math_fround($1087 * $1104);
    $1119 = Math_fround($1085 * $1102);
    $1120 = Math_fround($1114 - $1117);
    $1121 = Math_fround($1115 - $1118);
    $1122 = Math_fround($1116 - $1119);
    $1123 = Math_fround($1109 - $1109);
    $1124 = Math_fround($1110 + $1121);
    $1125 = Math_fround($1111 + $1122);
    $1126 = Math_fround($1112 + $1120);
    $1127 = Math_fround($1123 + $1113);
    $1128 = Math_fround($1023 * $1086);
    $1129 = Math_fround($1026 * $1042);
    $1130 = Math_fround($1024 * $1087);
    $1131 = Math_fround($1025 * $1085);
    $1132 = Math_fround($1025 * $1042);
    $1133 = Math_fround($1023 * $1085);
    $1134 = Math_fround($1025 * $1086);
    $1135 = Math_fround($1023 * $1087);
    $1136 = Math_fround($1128 - $1132);
    $1137 = Math_fround($1129 - $1133);
    $1138 = Math_fround($1130 - $1134);
    $1139 = Math_fround($1131 - $1135);
    $1140 = Math_fround($1026 * $1087);
    $1141 = Math_fround($1025 * $1087);
    $1142 = Math_fround($1023 * $1042);
    $1143 = Math_fround($1024 * $1042);
    $1144 = Math_fround($1136 - $1140);
    $1145 = Math_fround($1137 - $1141);
    $1146 = Math_fround($1138 - $1142);
    $1147 = Math_fround($1139 - $1143);
    $1148 = Math_fround($1024 * $1085);
    $1149 = Math_fround($1024 * $1086);
    $1150 = Math_fround($1026 * $1085);
    $1151 = Math_fround($1026 * $1086);
    $1152 = Math_fround($1144 - $1148);
    $1153 = Math_fround($1145 - $1149);
    $1154 = Math_fround($1146 - $1150);
    $1155 = Math_fround($1147 - $1151);
    $1156 = Math_fround($1154 * Math_fround(-1.0));
    $1157 = Math_fround($1155 * Math_fround(-1.0));
    $1158 = Math_fround($1152 * Math_fround(-1.0));
    $1159 = Math_fround($1156 * $1156);
    $1160 = Math_fround($1157 * $1157);
    $1161 = Math_fround($1158 * $1158);
    $1162 = Math_fround($1153 * $1153);
    $1163 = Math_fround($1159 + $1160);
    $1164 = Math_fround($1162 + $1161);
    $1165 = Math_fround($1163 + $1164);
    $1166 = (Math_fround(Math_sqrt((Math_fround($1165)))));
    $1167 = Math_fround(Math_fround(1.0) / $1166);
    $1168 = Math_fround($1156 * $1167);
    $1169 = Math_fround($1157 * $1167);
    $1170 = Math_fround($1158 * $1167);
    $1171 = Math_fround($1153 * $1167);
    HEAPF32[$9>>2] = $1124;
    $1172 = (($9) + 4|0);
    HEAPF32[$1172>>2] = $1125;
    $1173 = (($9) + 8|0);
    HEAPF32[$1173>>2] = $1126;
    $1174 = (($9) + 12|0);
    HEAPF32[$1174>>2] = $1127;
    $1175 = (($9) + 16|0);
    HEAPF32[$1175>>2] = $1168;
    $1176 = (($9) + 20|0);
    HEAPF32[$1176>>2] = $1169;
    $1177 = (($9) + 24|0);
    HEAPF32[$1177>>2] = $1170;
    $1178 = (($9) + 28|0);
    HEAPF32[$1178>>2] = $1171;
    $1179 = (($9) + 32|0);
    HEAPF32[$1179>>2] = Math_fround(1.0);
    $1180 = (($9) + 36|0);
    HEAPF32[$1180>>2] = Math_fround(1.0);
    $1181 = (($9) + 40|0);
    HEAPF32[$1181>>2] = Math_fround(1.0);
    $1182 = (($9) + 44|0);
    HEAPF32[$1182>>2] = Math_fround(1.0);
    __ZN4mathL8xformMulERKNS_5xformES2_18984($8,$refStopX,$9);
    $1183 = Math_fround($1184 * Math_fround(-1.0));
    $1185 = Math_fround($1186 * Math_fround(-1.0));
    $1187 = Math_fround($1188 * Math_fround(-1.0));
    $1189 = Math_fround(HEAPF32[$8>>2]);
    $1190 = Math_fround($1189 - $1191);
    $1192 = (($8) + 4|0);
    $1193 = Math_fround(HEAPF32[$1192>>2]);
    $1194 = Math_fround($1193 - $1195);
    $1196 = (($8) + 8|0);
    $1197 = Math_fround(HEAPF32[$1196>>2]);
    $1198 = Math_fround($1197 - $1199);
    $1200 = (($8) + 12|0);
    $1201 = Math_fround(HEAPF32[$1200>>2]);
    $1202 = Math_fround($1201 - $1203);
    $1204 = Math_fround($1190 + $1190);
    $1205 = Math_fround($1194 + $1194);
    $1206 = Math_fround($1198 + $1198);
    $1207 = Math_fround($1183 * $1205);
    $1208 = Math_fround($1185 * $1206);
    $1209 = Math_fround($1187 * $1204);
    $1210 = Math_fround($1211 * Math_fround(0.0));
    $1212 = Math_fround($1185 * $1204);
    $1213 = Math_fround($1187 * $1205);
    $1214 = Math_fround($1183 * $1206);
    $1215 = Math_fround($1207 - $1212);
    $1216 = Math_fround($1208 - $1213);
    $1217 = Math_fround($1209 - $1214);
    $1218 = Math_fround($1210 - $1210);
    $1219 = Math_fround($1211 * $1216);
    $1220 = Math_fround($1211 * $1217);
    $1221 = Math_fround($1211 * $1215);
    $1222 = Math_fround($1211 * $1218);
    $1223 = Math_fround($1190 + $1219);
    $1224 = Math_fround($1194 + $1220);
    $1225 = Math_fround($1198 + $1221);
    $1226 = Math_fround($1222 + $1202);
    $1227 = Math_fround($1183 * $1217);
    $1228 = Math_fround($1185 * $1215);
    $1229 = Math_fround($1187 * $1216);
    $1230 = Math_fround($1185 * $1216);
    $1231 = Math_fround($1187 * $1217);
    $1232 = Math_fround($1183 * $1215);
    $1233 = Math_fround($1227 - $1230);
    $1234 = Math_fround($1228 - $1231);
    $1235 = Math_fround($1229 - $1232);
    $1236 = Math_fround($1222 - $1222);
    $1237 = Math_fround($1223 + $1234);
    $1238 = Math_fround($1224 + $1235);
    $1239 = Math_fround($1225 + $1233);
    $1240 = Math_fround($1236 + $1226);
    $1241 = (($8) + 16|0);
    $1242 = Math_fround(HEAPF32[$1241>>2]);
    $1243 = Math_fround($1185 * $1242);
    $1244 = (($8) + 28|0);
    $1245 = Math_fround(HEAPF32[$1244>>2]);
    $1246 = Math_fround($1211 * $1245);
    $1247 = (($8) + 20|0);
    $1248 = Math_fround(HEAPF32[$1247>>2]);
    $1249 = Math_fround($1187 * $1248);
    $1250 = (($8) + 24|0);
    $1251 = Math_fround(HEAPF32[$1250>>2]);
    $1252 = Math_fround($1183 * $1251);
    $1253 = Math_fround($1211 * $1251);
    $1254 = Math_fround($1183 * $1242);
    $1255 = Math_fround($1185 * $1251);
    $1256 = Math_fround($1187 * $1242);
    $1257 = Math_fround($1243 - $1253);
    $1258 = Math_fround($1246 - $1254);
    $1259 = Math_fround($1249 - $1255);
    $1260 = Math_fround($1252 - $1256);
    $1261 = Math_fround($1187 * $1245);
    $1262 = Math_fround($1187 * $1251);
    $1263 = Math_fround($1211 * $1242);
    $1264 = Math_fround($1211 * $1248);
    $1265 = Math_fround($1257 - $1261);
    $1266 = Math_fround($1258 - $1262);
    $1267 = Math_fround($1259 - $1263);
    $1268 = Math_fround($1260 - $1264);
    $1269 = Math_fround($1183 * $1248);
    $1270 = Math_fround($1185 * $1248);
    $1271 = Math_fround($1183 * $1245);
    $1272 = Math_fround($1185 * $1245);
    $1273 = Math_fround($1265 - $1269);
    $1274 = Math_fround($1266 - $1270);
    $1275 = Math_fround($1267 - $1271);
    $1276 = Math_fround($1268 - $1272);
    $1277 = Math_fround($1275 * Math_fround(-1.0));
    $1278 = Math_fround($1276 * Math_fround(-1.0));
    $1279 = Math_fround($1273 * Math_fround(-1.0));
    $1280 = Math_fround($1277 * $1277);
    $1281 = Math_fround($1278 * $1278);
    $1282 = Math_fround($1279 * $1279);
    $1283 = Math_fround($1274 * $1274);
    $1284 = Math_fround($1280 + $1281);
    $1285 = Math_fround($1283 + $1282);
    $1286 = Math_fround($1284 + $1285);
    $1287 = (Math_fround(Math_sqrt((Math_fround($1286)))));
    $1288 = Math_fround(Math_fround(1.0) / $1287);
    $1289 = Math_fround($1288 * $1277);
    $1290 = Math_fround($1288 * $1278);
    $1291 = Math_fround($1288 * $1279);
    $1292 = Math_fround($1288 * $1274);
    $1677 = $1292;$1680 = $1289;$1682 = $1290;$1684 = $1291;$1688 = $1238;$1693 = $1239;$1695 = $1237;$1732 = $1240;
    break;
   }
   $1293 = $130 > $106;
   if ($1293) {
    $1294 = Math_fround(HEAPF32[$$pre$phi268Z2D>>2]);
    $1295 = Math_fround($1294 * Math_fround(-1.0));
    $1296 = Math_fround(HEAPF32[$$pre$phi270Z2D>>2]);
    $1297 = Math_fround($1296 * Math_fround(-1.0));
    $1298 = Math_fround(HEAPF32[$$pre$phi272Z2D>>2]);
    $1299 = Math_fround($1298 * Math_fround(-1.0));
    $1300 = Math_fround(HEAPF32[$139>>2]);
    $1301 = Math_fround($1019 - $1055);
    $1302 = Math_fround($1020 - $1056);
    $1303 = Math_fround($1021 - $1057);
    $1304 = Math_fround($1022 - $1058);
    $1305 = Math_fround($1301 + $1301);
    $1306 = Math_fround($1302 + $1302);
    $1307 = Math_fround($1303 + $1303);
    $1308 = Math_fround($1295 * $1306);
    $1309 = Math_fround($1297 * $1307);
    $1310 = Math_fround($1299 * $1305);
    $1311 = Math_fround($1300 * Math_fround(0.0));
    $1312 = Math_fround($1297 * $1305);
    $1313 = Math_fround($1299 * $1306);
    $1314 = Math_fround($1295 * $1307);
    $1315 = Math_fround($1308 - $1312);
    $1316 = Math_fround($1309 - $1313);
    $1317 = Math_fround($1310 - $1314);
    $1318 = Math_fround($1311 - $1311);
    $1319 = Math_fround($1300 * $1316);
    $1320 = Math_fround($1300 * $1317);
    $1321 = Math_fround($1300 * $1315);
    $1322 = Math_fround($1300 * $1318);
    $1323 = Math_fround($1301 + $1319);
    $1324 = Math_fround($1302 + $1320);
    $1325 = Math_fround($1303 + $1321);
    $1326 = Math_fround($1322 + $1304);
    $1327 = Math_fround($1295 * $1317);
    $1328 = Math_fround($1297 * $1315);
    $1329 = Math_fround($1299 * $1316);
    $1330 = Math_fround($1297 * $1316);
    $1331 = Math_fround($1299 * $1317);
    $1332 = Math_fround($1295 * $1315);
    $1333 = Math_fround($1327 - $1330);
    $1334 = Math_fround($1328 - $1331);
    $1335 = Math_fround($1329 - $1332);
    $1336 = Math_fround($1322 - $1322);
    $1337 = Math_fround($1323 + $1334);
    $1338 = Math_fround($1324 + $1335);
    $1339 = Math_fround($1325 + $1333);
    $1340 = Math_fround($1336 + $1326);
    $1341 = Math_fround($1023 * $1297);
    $1342 = Math_fround($1026 * $1300);
    $1343 = Math_fround($1024 * $1299);
    $1344 = Math_fround($1025 * $1295);
    $1345 = Math_fround($1025 * $1300);
    $1346 = Math_fround($1023 * $1295);
    $1347 = Math_fround($1025 * $1297);
    $1348 = Math_fround($1023 * $1299);
    $1349 = Math_fround($1341 - $1345);
    $1350 = Math_fround($1342 - $1346);
    $1351 = Math_fround($1343 - $1347);
    $1352 = Math_fround($1344 - $1348);
    $1353 = Math_fround($1026 * $1299);
    $1354 = Math_fround($1025 * $1299);
    $1355 = Math_fround($1023 * $1300);
    $1356 = Math_fround($1024 * $1300);
    $1357 = Math_fround($1349 - $1353);
    $1358 = Math_fround($1350 - $1354);
    $1359 = Math_fround($1351 - $1355);
    $1360 = Math_fround($1352 - $1356);
    $1361 = Math_fround($1024 * $1295);
    $1362 = Math_fround($1024 * $1297);
    $1363 = Math_fround($1026 * $1295);
    $1364 = Math_fround($1026 * $1297);
    $1365 = Math_fround($1357 - $1361);
    $1366 = Math_fround($1358 - $1362);
    $1367 = Math_fround($1359 - $1363);
    $1368 = Math_fround($1360 - $1364);
    $1369 = Math_fround($1367 * Math_fround(-1.0));
    $1370 = Math_fround($1368 * Math_fround(-1.0));
    $1371 = Math_fround($1365 * Math_fround(-1.0));
    $1372 = Math_fround($1369 * $1369);
    $1373 = Math_fround($1370 * $1370);
    $1374 = Math_fround($1371 * $1371);
    $1375 = Math_fround($1366 * $1366);
    $1376 = Math_fround($1372 + $1373);
    $1377 = Math_fround($1375 + $1374);
    $1378 = Math_fround($1376 + $1377);
    $1379 = (Math_fround(Math_sqrt((Math_fround($1378)))));
    $1380 = Math_fround(Math_fround(1.0) / $1379);
    $1381 = Math_fround($1369 * $1380);
    $1382 = Math_fround($1370 * $1380);
    $1383 = Math_fround($1371 * $1380);
    $1384 = Math_fround($1366 * $1380);
    HEAPF32[$11>>2] = $1337;
    $1385 = (($11) + 4|0);
    HEAPF32[$1385>>2] = $1338;
    $1386 = (($11) + 8|0);
    HEAPF32[$1386>>2] = $1339;
    $1387 = (($11) + 12|0);
    HEAPF32[$1387>>2] = $1340;
    $1388 = (($11) + 16|0);
    HEAPF32[$1388>>2] = $1381;
    $1389 = (($11) + 20|0);
    HEAPF32[$1389>>2] = $1382;
    $1390 = (($11) + 24|0);
    HEAPF32[$1390>>2] = $1383;
    $1391 = (($11) + 28|0);
    HEAPF32[$1391>>2] = $1384;
    $1392 = (($11) + 32|0);
    HEAPF32[$1392>>2] = Math_fround(1.0);
    $1393 = (($11) + 36|0);
    HEAPF32[$1393>>2] = Math_fround(1.0);
    $1394 = (($11) + 40|0);
    HEAPF32[$1394>>2] = Math_fround(1.0);
    $1395 = (($11) + 44|0);
    HEAPF32[$1395>>2] = Math_fround(1.0);
    __ZN4mathL8xformMulERKNS_5xformES2_18984($10,$refStartX,$11);
    $1396 = Math_fround($1184 * Math_fround(-1.0));
    $1397 = Math_fround($1186 * Math_fround(-1.0));
    $1398 = Math_fround($1188 * Math_fround(-1.0));
    $1399 = Math_fround(HEAPF32[$10>>2]);
    $1400 = Math_fround($1399 - $1191);
    $1401 = (($10) + 4|0);
    $1402 = Math_fround(HEAPF32[$1401>>2]);
    $1403 = Math_fround($1402 - $1195);
    $1404 = (($10) + 8|0);
    $1405 = Math_fround(HEAPF32[$1404>>2]);
    $1406 = Math_fround($1405 - $1199);
    $1407 = (($10) + 12|0);
    $1408 = Math_fround(HEAPF32[$1407>>2]);
    $1409 = Math_fround($1408 - $1203);
    $1410 = Math_fround($1400 + $1400);
    $1411 = Math_fround($1403 + $1403);
    $1412 = Math_fround($1406 + $1406);
    $1413 = Math_fround($1396 * $1411);
    $1414 = Math_fround($1397 * $1412);
    $1415 = Math_fround($1398 * $1410);
    $1416 = Math_fround($1211 * Math_fround(0.0));
    $1417 = Math_fround($1397 * $1410);
    $1418 = Math_fround($1398 * $1411);
    $1419 = Math_fround($1396 * $1412);
    $1420 = Math_fround($1413 - $1417);
    $1421 = Math_fround($1414 - $1418);
    $1422 = Math_fround($1415 - $1419);
    $1423 = Math_fround($1416 - $1416);
    $1424 = Math_fround($1211 * $1421);
    $1425 = Math_fround($1211 * $1422);
    $1426 = Math_fround($1211 * $1420);
    $1427 = Math_fround($1211 * $1423);
    $1428 = Math_fround($1400 + $1424);
    $1429 = Math_fround($1403 + $1425);
    $1430 = Math_fround($1406 + $1426);
    $1431 = Math_fround($1427 + $1409);
    $1432 = Math_fround($1396 * $1422);
    $1433 = Math_fround($1397 * $1420);
    $1434 = Math_fround($1398 * $1421);
    $1435 = Math_fround($1397 * $1421);
    $1436 = Math_fround($1398 * $1422);
    $1437 = Math_fround($1396 * $1420);
    $1438 = Math_fround($1432 - $1435);
    $1439 = Math_fround($1433 - $1436);
    $1440 = Math_fround($1434 - $1437);
    $1441 = Math_fround($1427 - $1427);
    $1442 = Math_fround($1428 + $1439);
    $1443 = Math_fround($1429 + $1440);
    $1444 = Math_fround($1430 + $1438);
    $1445 = Math_fround($1441 + $1431);
    $1446 = (($10) + 16|0);
    $1447 = Math_fround(HEAPF32[$1446>>2]);
    $1448 = Math_fround($1397 * $1447);
    $1449 = (($10) + 28|0);
    $1450 = Math_fround(HEAPF32[$1449>>2]);
    $1451 = Math_fround($1211 * $1450);
    $1452 = (($10) + 20|0);
    $1453 = Math_fround(HEAPF32[$1452>>2]);
    $1454 = Math_fround($1398 * $1453);
    $1455 = (($10) + 24|0);
    $1456 = Math_fround(HEAPF32[$1455>>2]);
    $1457 = Math_fround($1396 * $1456);
    $1458 = Math_fround($1211 * $1456);
    $1459 = Math_fround($1396 * $1447);
    $1460 = Math_fround($1397 * $1456);
    $1461 = Math_fround($1398 * $1447);
    $1462 = Math_fround($1448 - $1458);
    $1463 = Math_fround($1451 - $1459);
    $1464 = Math_fround($1454 - $1460);
    $1465 = Math_fround($1457 - $1461);
    $1466 = Math_fround($1398 * $1450);
    $1467 = Math_fround($1398 * $1456);
    $1468 = Math_fround($1211 * $1447);
    $1469 = Math_fround($1211 * $1453);
    $1470 = Math_fround($1462 - $1466);
    $1471 = Math_fround($1463 - $1467);
    $1472 = Math_fround($1464 - $1468);
    $1473 = Math_fround($1465 - $1469);
    $1474 = Math_fround($1396 * $1453);
    $1475 = Math_fround($1397 * $1453);
    $1476 = Math_fround($1396 * $1450);
    $1477 = Math_fround($1397 * $1450);
    $1478 = Math_fround($1470 - $1474);
    $1479 = Math_fround($1471 - $1475);
    $1480 = Math_fround($1472 - $1476);
    $1481 = Math_fround($1473 - $1477);
    $1482 = Math_fround($1480 * Math_fround(-1.0));
    $1483 = Math_fround($1481 * Math_fround(-1.0));
    $1484 = Math_fround($1478 * Math_fround(-1.0));
    $1485 = Math_fround($1482 * $1482);
    $1486 = Math_fround($1483 * $1483);
    $1487 = Math_fround($1484 * $1484);
    $1488 = Math_fround($1479 * $1479);
    $1489 = Math_fround($1485 + $1486);
    $1490 = Math_fround($1488 + $1487);
    $1491 = Math_fround($1489 + $1490);
    $1492 = (Math_fround(Math_sqrt((Math_fround($1491)))));
    $1493 = Math_fround(Math_fround(1.0) / $1492);
    $1494 = Math_fround($1493 * $1482);
    $1495 = Math_fround($1493 * $1483);
    $1496 = Math_fround($1493 * $1484);
    $1497 = Math_fround($1493 * $1479);
    $1677 = $1497;$1680 = $1494;$1682 = $1495;$1684 = $1496;$1688 = $1443;$1693 = $1444;$1695 = $1442;$1732 = $1445;
   } else {
    $1677 = Math_fround(1.0);$1680 = Math_fround(0.0);$1682 = Math_fround(0.0);$1684 = Math_fround(0.0);$1688 = Math_fround(0.0);$1693 = Math_fround(0.0);$1695 = Math_fround(0.0);$1732 = Math_fround(0.0);
   }
  }
 } while(0);
 $1676 = $1677 == Math_fround(0.0);
 $1678 = $1676 ? Math_fround(9.99999997475242707878E-7) : $1677;
 $1679 = Math_fround($1680 / $1678);
 $1681 = Math_fround($1682 / $1678);
 $1683 = Math_fround($1684 / $1678);
 if ($75) {
  $1685 = (($constant) + 1636|0);
  $1686 = HEAP8[$1685>>0]|0;
  $1687 = ($1686<<24>>24)==(0);
  $$ = $1687 ? $1688 : Math_fround(0.0);
  $1689 = (($constant) + 1637|0);
  $1690 = HEAP8[$1689>>0]|0;
  $1691 = ($1690<<24>>24)==(0);
  $1692 = $1691 ? $1693 : Math_fround(0.0);
  $1694 = $1691 ? $1695 : Math_fround(0.0);
  $1696 = (($constant) + 1635|0);
  $1697 = HEAP8[$1696>>0]|0;
  $1698 = ($1697<<24>>24)==(0);
  $$234 = $1698 ? $1681 : Math_fround(0.0);
  $1700 = Math_fround(0.0);$1702 = $$234;$1704 = Math_fround(0.0);$1726 = $1694;$1728 = $$;$1730 = $1692;
 } else {
  $1700 = $1679;$1702 = $1681;$1704 = $1683;$1726 = $1695;$1728 = $1688;$1730 = $1693;
 }
 $1699 = Math_fround($1700 * $1700);
 $1701 = Math_fround($1702 * $1702);
 $1703 = Math_fround($1704 * $1704);
 $1705 = Math_fround($1701 + $1699);
 $1706 = Math_fround($1703 + Math_fround(1.0));
 $1707 = Math_fround($1706 + $1705);
 $1708 = (Math_fround(Math_sqrt((Math_fround($1707)))));
 $1709 = Math_fround(Math_fround(1.0) / $1708);
 $1710 = Math_fround($1700 * $1709);
 $1711 = Math_fround($1702 * $1709);
 $1712 = Math_fround($1704 * $1709);
 $1713 = Math_fround(HEAPF32[$90>>2]);
 $1714 = $1713 != Math_fround(0.0);
 if ($1714) {
  $1715 = Math_fround(HEAPF32[$input>>2]);
  $1716 = Math_fround(HEAPF32[$81>>2]);
  $1717 = Math_fround($1715 - $1716);
  $1718 = Math_fround(HEAPF32[$85>>2]);
  $1719 = Math_fround(HEAPF32[$83>>2]);
  $1720 = Math_fround($1718 - $1719);
  $1721 = Math_fround($1717 * $1720);
  $1722 = (Math_fround(Math_abs((Math_fround($1713)))));
  $1723 = Math_fround($1721 / $1722);
  $1724 = $1723;
 } else {
  $1724 = Math_fround(0.0);
 }
 HEAPF32[$output>>2] = $1724;
 $1725 = Math_fround($1726 / $1724);
 $1727 = Math_fround($1728 / $1724);
 $1729 = Math_fround($1730 / $1724);
 $1731 = Math_fround($1732 / $1724);
 $1733 = $1724 > Math_fround(0.0);
 $1734 = $1733 ? $1725 : Math_fround(0.0);
 $1735 = $1733 ? $1727 : Math_fround(0.0);
 $1736 = $1733 ? $1729 : Math_fround(0.0);
 $1737 = $1733 ? $1731 : Math_fround(0.0);
 HEAPF32[$54>>2] = $1734;
 HEAPF32[$55>>2] = $1735;
 HEAPF32[$56>>2] = $1736;
 HEAPF32[$57>>2] = $1737;
 $1738 = Math_fround($1710 * $1710);
 $1739 = Math_fround($1711 * $1711);
 $1740 = Math_fround($1712 * $1712);
 $1741 = Math_fround($1709 * $1709);
 $1742 = Math_fround($1738 + $1739);
 $1743 = Math_fround($1741 + $1740);
 $1744 = Math_fround($1742 + $1743);
 $1745 = (Math_fround(Math_sqrt((Math_fround($1744)))));
 $1746 = Math_fround(Math_fround(1.0) / $1745);
 $1747 = Math_fround($1710 * $1746);
 $1748 = Math_fround($1711 * $1746);
 $1749 = Math_fround($1712 * $1746);
 $1750 = Math_fround($1747 * $1747);
 $1751 = Math_fround($1748 * $1748);
 $1752 = Math_fround($1749 * $1749);
 $1753 = Math_fround($1750 + $1751);
 $1754 = Math_fround($1752 + Math_fround(0.0));
 $1755 = Math_fround($1753 + $1754);
 $1756 = (Math_fround(Math_sqrt((Math_fround($1755)))));
 $1757 = (Math_fround(+(Math_asin((+$1756)))));
 $1758 = Math_fround($1757 * Math_fround(2.0));
 $1759 = Math_fround($1747 * $1758);
 $1760 = Math_fround($1759 / $1756);
 $1761 = Math_fround($1748 * $1758);
 $1762 = Math_fround($1761 / $1756);
 $1763 = Math_fround($1749 * $1758);
 $1764 = Math_fround($1763 / $1756);
 $1765 = $1756 != Math_fround(0.0);
 $1766 = $1765 ? $1760 : Math_fround(0.0);
 $1767 = $1765 ? $1762 : Math_fround(0.0);
 $1768 = $1765 ? $1764 : Math_fround(0.0);
 $1769 = Math_fround($1766 / $1724);
 $1770 = Math_fround($1767 / $1724);
 $1771 = Math_fround($1768 / $1724);
 $1772 = Math_fround(Math_fround(0.0) / $1724);
 $1773 = $1733 ? $1769 : Math_fround(0.0);
 $1774 = $1733 ? $1770 : Math_fround(0.0);
 $1775 = $1733 ? $1771 : Math_fround(0.0);
 $1776 = $1733 ? $1772 : Math_fround(0.0);
 HEAPF32[$58>>2] = $1773;
 HEAPF32[$59>>2] = $1774;
 HEAPF32[$60>>2] = $1775;
 HEAPF32[$61>>2] = $1776;
 STACKTOP = sp;return;
}
function __ZN4mathL8xformMulERKNS_5xformES2_18984($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($a) + 32|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($b) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($a) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = (($b) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = (($b) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $17);
 $19 = Math_fround($3 + $3);
 $20 = Math_fround($8 + $8);
 $21 = Math_fround($13 + $13);
 $22 = (($a) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($20 * $23);
 $25 = (($a) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($21 * $26);
 $28 = (($a) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($19 * $29);
 $31 = (($a) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(0.0));
 $34 = Math_fround($19 * $26);
 $35 = Math_fround($20 * $29);
 $36 = Math_fround($21 * $23);
 $37 = Math_fround($24 - $34);
 $38 = Math_fround($27 - $35);
 $39 = Math_fround($30 - $36);
 $40 = Math_fround($33 - $33);
 $41 = Math_fround($32 * $38);
 $42 = Math_fround($32 * $39);
 $43 = Math_fround($37 * $32);
 $44 = Math_fround($32 * $40);
 $45 = Math_fround($3 + $41);
 $46 = Math_fround($8 + $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 * $39);
 $50 = Math_fround($26 * $37);
 $51 = Math_fround($29 * $38);
 $52 = Math_fround($26 * $38);
 $53 = Math_fround($29 * $39);
 $54 = Math_fround($23 * $37);
 $55 = Math_fround($49 - $52);
 $56 = Math_fround($50 - $53);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($44 - $44);
 $59 = Math_fround($45 + $56);
 $60 = Math_fround($46 + $57);
 $61 = Math_fround($47 + $55);
 $62 = Math_fround($48 + $58);
 $63 = Math_fround(HEAPF32[$a>>2]);
 $64 = Math_fround($63 + $59);
 $65 = (($a) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 + $60);
 $68 = (($a) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $61);
 $71 = (($a) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 + $62);
 $74 = (($b) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($26 * $75);
 $77 = (($b) + 28|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($32 * $78);
 $80 = (($b) + 20|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($29 * $81);
 $83 = (($b) + 24|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($23 * $84);
 $86 = Math_fround($32 * $84);
 $87 = Math_fround($75 * $23);
 $88 = Math_fround($26 * $84);
 $89 = Math_fround($75 * $29);
 $90 = Math_fround($76 - $86);
 $91 = Math_fround($79 - $87);
 $92 = Math_fround($82 - $88);
 $93 = Math_fround($85 - $89);
 $94 = Math_fround($78 * $29);
 $95 = Math_fround($29 * $84);
 $96 = Math_fround($75 * $32);
 $97 = Math_fround($32 * $81);
 $98 = Math_fround($90 - $94);
 $99 = Math_fround($91 - $95);
 $100 = Math_fround($92 - $96);
 $101 = Math_fround($93 - $97);
 $102 = Math_fround($81 * $23);
 $103 = Math_fround($26 * $81);
 $104 = Math_fround($78 * $23);
 $105 = Math_fround($26 * $78);
 $106 = Math_fround($98 - $102);
 $107 = Math_fround($99 - $103);
 $108 = Math_fround($100 - $104);
 $109 = Math_fround($101 - $105);
 $110 = Math_fround($108 * Math_fround(-1.0));
 $111 = Math_fround($109 * Math_fround(-1.0));
 $112 = Math_fround($106 * Math_fround(-1.0));
 $113 = Math_fround($110 * $110);
 $114 = Math_fround($111 * $111);
 $115 = Math_fround($112 * $112);
 $116 = Math_fround($107 * $107);
 $117 = Math_fround($113 + $114);
 $118 = Math_fround($116 + $115);
 $119 = Math_fround($117 + $118);
 $120 = (Math_fround(Math_sqrt((Math_fround($119)))));
 $121 = Math_fround(Math_fround(1.0) / $120);
 $122 = Math_fround($121 * $110);
 $123 = Math_fround($121 * $111);
 $124 = Math_fround($121 * $112);
 $125 = Math_fround($121 * $107);
 $126 = Math_fround(HEAPF32[$1>>2]);
 $127 = (($b) + 32|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($126 * $128);
 $130 = Math_fround(HEAPF32[$6>>2]);
 $131 = (($b) + 36|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($130 * $132);
 $134 = Math_fround(HEAPF32[$11>>2]);
 $135 = (($b) + 40|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($134 * $136);
 $138 = Math_fround(HEAPF32[$16>>2]);
 $139 = (($b) + 44|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($138 * $140);
 HEAPF32[$agg$result>>2] = $64;
 $142 = (($agg$result) + 4|0);
 HEAPF32[$142>>2] = $67;
 $143 = (($agg$result) + 8|0);
 HEAPF32[$143>>2] = $70;
 $144 = (($agg$result) + 12|0);
 HEAPF32[$144>>2] = $73;
 $145 = (($agg$result) + 16|0);
 HEAPF32[$145>>2] = $122;
 $146 = (($agg$result) + 20|0);
 HEAPF32[$146>>2] = $123;
 $147 = (($agg$result) + 24|0);
 HEAPF32[$147>>2] = $124;
 $148 = (($agg$result) + 28|0);
 HEAPF32[$148>>2] = $125;
 $149 = (($agg$result) + 32|0);
 HEAPF32[$149>>2] = $129;
 $150 = (($agg$result) + 36|0);
 HEAPF32[$150>>2] = $133;
 $151 = (($agg$result) + 40|0);
 HEAPF32[$151>>2] = $137;
 $152 = (($agg$result) + 44|0);
 HEAPF32[$152>>2] = $141;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation26EvaluateClipMusclePrevTimeERKNS0_18ClipMuscleConstantERKNS0_15ClipMuscleInputERNS0_12MotionOutputERNS0_10ClipMemoryE($constant,$input,$output,$memory) {
 $constant = $constant|0;
 $input = $input|0;
 $output = $output|0;
 $memory = $memory|0;
 var $$v$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0);
 var $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0);
 var $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0);
 var $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $clipIn$i = 0, $prevTimeInt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $clipIn$i = sp + 200|0;
 $prevTimeInt = sp;
 $0 = sp + 8|0;
 $1 = sp + 56|0;
 $2 = sp + 104|0;
 $3 = sp + 152|0;
 $4 = (($input) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($constant) + 1048|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($constant) + 1052|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($constant) + 1064|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($input) + 24|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 + $13);
 $15 = (($constant) + 1633|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (($input) + 16|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = $19 < Math_fround(0.0);
 $21 = (Math_fround(+(_fmaxf(0.0,(+$5)))));
 $22 = (Math_fround(+(_fminf(1.0,(+$21)))));
 $23 = Math_fround($5 + $14);
 $24 = (Math_fround(+(_modff((+$23),($prevTimeInt|0)))));
 $$v$i = $17 ? $24 : $22;
 $25 = Math_fround(Math_fround(1.0) - $$v$i);
 $26 = $20&1;
 $27 = $26 ^ 1;
 $28 = (0 - ($27))|0;
 $29 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
 $30 = (HEAPF32[tempDoublePtr>>2]=$$v$i,HEAP32[tempDoublePtr>>2]|0);
 $31 = $20 ? $29 : 0;
 $32 = $30 & $28;
 $33 = $31 | $32;
 $34 = (HEAP32[tempDoublePtr>>2]=$33,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $35 = Math_fround($9 - $7);
 $36 = Math_fround($35 * $34);
 $37 = Math_fround($7 + $36);
 __ZN7mecanim9animation14EvaluateMotionERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($0,$constant,$memory,$37);
 $38 = Math_fround(HEAPF32[$0>>2]);
 $39 = (($0) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($0) + 8|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($0) + 12|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($output) + 36|0);
 HEAPF32[$45>>2] = $38;
 $46 = (($output) + 40|0);
 HEAPF32[$46>>2] = $40;
 $47 = (($output) + 44|0);
 HEAPF32[$47>>2] = $42;
 $48 = (($output) + 48|0);
 HEAPF32[$48>>2] = $44;
 $49 = (($0) + 16|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($0) + 20|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($0) + 24|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($0) + 28|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($output) + 52|0);
 HEAPF32[$57>>2] = $50;
 $58 = (($output) + 56|0);
 HEAPF32[$58>>2] = $52;
 $59 = (($output) + 60|0);
 HEAPF32[$59>>2] = $54;
 $60 = (($output) + 64|0);
 HEAPF32[$60>>2] = $56;
 $61 = (($0) + 32|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($0) + 36|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($0) + 40|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($0) + 44|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($output) + 68|0);
 HEAPF32[$69>>2] = $62;
 $70 = (($output) + 72|0);
 HEAPF32[$70>>2] = $64;
 $71 = (($output) + 76|0);
 HEAPF32[$71>>2] = $66;
 $72 = (($output) + 80|0);
 HEAPF32[$72>>2] = $68;
 __ZN7mecanim9animation12EvaluateRootERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($1,$constant,$memory,$37);
 $73 = Math_fround(HEAPF32[$1>>2]);
 $74 = (($1) + 4|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($1) + 8|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($1) + 12|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = (($output) + 228|0);
 HEAPF32[$80>>2] = $73;
 $81 = (($output) + 232|0);
 HEAPF32[$81>>2] = $75;
 $82 = (($output) + 236|0);
 HEAPF32[$82>>2] = $77;
 $83 = (($output) + 240|0);
 HEAPF32[$83>>2] = $79;
 $84 = (($1) + 16|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($1) + 20|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($1) + 24|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($1) + 28|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = (($output) + 244|0);
 HEAPF32[$92>>2] = $85;
 $93 = (($output) + 248|0);
 HEAPF32[$93>>2] = $87;
 $94 = (($output) + 252|0);
 HEAPF32[$94>>2] = $89;
 $95 = (($output) + 256|0);
 HEAPF32[$95>>2] = $91;
 $96 = (($1) + 32|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = (($1) + 36|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = (($1) + 40|0);
 $101 = Math_fround(HEAPF32[$100>>2]);
 $102 = (($1) + 44|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($output) + 260|0);
 HEAPF32[$104>>2] = $97;
 $105 = (($output) + 264|0);
 HEAPF32[$105>>2] = $99;
 $106 = (($output) + 268|0);
 HEAPF32[$106>>2] = $101;
 $107 = (($output) + 272|0);
 HEAPF32[$107>>2] = $103;
 __ZN7mecanim9animation12EvaluateGoalERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEfi($2,$constant,$memory,$37,0);
 $108 = Math_fround(HEAPF32[$2>>2]);
 $109 = (($2) + 4|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($2) + 8|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($2) + 12|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($output) + 276|0);
 HEAPF32[$115>>2] = $108;
 $116 = (($output) + 280|0);
 HEAPF32[$116>>2] = $110;
 $117 = (($output) + 284|0);
 HEAPF32[$117>>2] = $112;
 $118 = (($output) + 288|0);
 HEAPF32[$118>>2] = $114;
 $119 = (($2) + 16|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($2) + 20|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($2) + 24|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($2) + 28|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($output) + 292|0);
 HEAPF32[$127>>2] = $120;
 $128 = (($output) + 296|0);
 HEAPF32[$128>>2] = $122;
 $129 = (($output) + 300|0);
 HEAPF32[$129>>2] = $124;
 $130 = (($output) + 304|0);
 HEAPF32[$130>>2] = $126;
 $131 = (($2) + 32|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = (($2) + 36|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($2) + 40|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($2) + 44|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($output) + 308|0);
 HEAPF32[$139>>2] = $132;
 $140 = (($output) + 312|0);
 HEAPF32[$140>>2] = $134;
 $141 = (($output) + 316|0);
 HEAPF32[$141>>2] = $136;
 $142 = (($output) + 320|0);
 HEAPF32[$142>>2] = $138;
 __ZN7mecanim9animation12EvaluateGoalERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEfi($3,$constant,$memory,$37,1);
 $143 = Math_fround(HEAPF32[$3>>2]);
 $144 = (($3) + 4|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = (($3) + 8|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = (($3) + 12|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($output) + 324|0);
 HEAPF32[$150>>2] = $143;
 $151 = (($output) + 328|0);
 HEAPF32[$151>>2] = $145;
 $152 = (($output) + 332|0);
 HEAPF32[$152>>2] = $147;
 $153 = (($output) + 336|0);
 HEAPF32[$153>>2] = $149;
 $154 = (($3) + 16|0);
 $155 = Math_fround(HEAPF32[$154>>2]);
 $156 = (($3) + 20|0);
 $157 = Math_fround(HEAPF32[$156>>2]);
 $158 = (($3) + 24|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($3) + 28|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($output) + 340|0);
 HEAPF32[$162>>2] = $155;
 $163 = (($output) + 344|0);
 HEAPF32[$163>>2] = $157;
 $164 = (($output) + 348|0);
 HEAPF32[$164>>2] = $159;
 $165 = (($output) + 352|0);
 HEAPF32[$165>>2] = $161;
 $166 = (($3) + 32|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = (($3) + 36|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = (($3) + 40|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = (($3) + 44|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = (($output) + 356|0);
 HEAPF32[$174>>2] = $167;
 $175 = (($output) + 360|0);
 HEAPF32[$175>>2] = $169;
 $176 = (($output) + 364|0);
 HEAPF32[$176>>2] = $171;
 $177 = (($output) + 368|0);
 HEAPF32[$177>>2] = $173;
 HEAPF32[$clipIn$i>>2] = $37;
 $178 = (($constant) + 1608|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ($179|0)==(-1);
 if ($180) {
  $209 = Math_fround(0.0);
 } else {
  $181 = (($constant) + 1040|0);
  $182 = $181;
  $183 = HEAP32[$181>>2]|0;
  $184 = (($183) + ($182))|0;
  $185 = $184;
  $186 = (($constant) + 1044|0);
  HEAP32[$186>>2] = $185;
  $187 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($185,$clipIn$i,$memory,$179)));
  $209 = $187;
 }
 $188 = (($constant) + 1612|0);
 $189 = HEAP32[$188>>2]|0;
 $190 = ($189|0)==(-1);
 if ($190) {
  $211 = Math_fround(0.0);
 } else {
  $191 = (($constant) + 1040|0);
  $192 = $191;
  $193 = HEAP32[$191>>2]|0;
  $194 = (($193) + ($192))|0;
  $195 = $194;
  $196 = (($constant) + 1044|0);
  HEAP32[$196>>2] = $195;
  $197 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($195,$clipIn$i,$memory,$189)));
  $211 = $197;
 }
 $198 = (($constant) + 1616|0);
 $199 = HEAP32[$198>>2]|0;
 $200 = ($199|0)==(-1);
 if ($200) {
  $213 = Math_fround(0.0);
  $208 = (($output) + 424|0);
  HEAPF32[$208>>2] = $209;
  $210 = (($output) + 428|0);
  HEAPF32[$210>>2] = $211;
  $212 = (($output) + 432|0);
  HEAPF32[$212>>2] = $213;
  $214 = (($output) + 436|0);
  HEAPF32[$214>>2] = Math_fround(0.0);
  STACKTOP = sp;return;
 }
 $201 = (($constant) + 1040|0);
 $202 = $201;
 $203 = HEAP32[$201>>2]|0;
 $204 = (($203) + ($202))|0;
 $205 = $204;
 $206 = (($constant) + 1044|0);
 HEAP32[$206>>2] = $205;
 $207 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($205,$clipIn$i,$memory,$199)));
 $213 = $207;
 $208 = (($output) + 424|0);
 HEAPF32[$208>>2] = $209;
 $210 = (($output) + 428|0);
 HEAPF32[$210>>2] = $211;
 $212 = (($output) + 432|0);
 HEAPF32[$212>>2] = $213;
 $214 = (($output) + 436|0);
 HEAPF32[$214>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation18EvaluateClipMuscleERKNS0_18ClipMuscleConstantERKNS0_15ClipMuscleInputEPKfRNS0_12MotionOutputERNS_5human9HumanPoseERNS0_10ClipMemoryE($constant,$input,$valuesOutput,$motionOutput,$humanPose,$memory) {
 $constant = $constant|0;
 $input = $input|0;
 $valuesOutput = $valuesOutput|0;
 $motionOutput = $motionOutput|0;
 $humanPose = $humanPose|0;
 $memory = $memory|0;
 var $$ = Math_fround(0), $$694 = Math_fround(0), $$off0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert709 = 0, $$phi$trans$insert711 = 0, $$pr692$pre = 0, $$pre = Math_fround(0), $$pre$phi721Z2D = 0, $$pre$phi723Z2D = 0, $$pre$phi725Z2D = 0, $$pre$phi727Z2D = 0, $$pre$phi729Z2D = 0, $$pre$phi731Z2D = 0, $$pre$phiZ2D = 0, $$pre700 = Math_fround(0), $$pre701 = Math_fround(0), $$pre702 = Math_fround(0), $$pre703 = Math_fround(0), $$pre704 = Math_fround(0);
 var $$pre705 = Math_fround(0), $$pre706 = Math_fround(0), $$pre707 = Math_fround(0), $$pre708 = Math_fround(0), $$pre710 = Math_fround(0), $$pre712 = Math_fround(0), $$pre719 = 0, $$pre720 = 0, $$pre722 = 0, $$pre726 = 0, $$pre728 = 0, $$pre730 = 0, $$v$i = Math_fround(0), $$v$i7 = Math_fround(0), $$v$i8 = Math_fround(0), $$val = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0);
 var $1019 = Math_fround(0), $102 = 0, $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = 0, $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0);
 var $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = 0, $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = 0, $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0);
 var $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = 0, $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0;
 var $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = Math_fround(0), $1078 = 0, $1079 = Math_fround(0), $108 = 0, $1080 = 0, $1081 = Math_fround(0), $1082 = 0, $1083 = Math_fround(0), $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = Math_fround(0), $1089 = 0, $109 = 0, $1090 = Math_fround(0);
 var $1091 = 0, $1092 = Math_fround(0), $1093 = 0, $1094 = Math_fround(0), $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = Math_fround(0), $11 = 0, $110 = 0, $1100 = 0, $1101 = Math_fround(0), $1102 = 0, $1103 = Math_fround(0), $1104 = 0, $1105 = Math_fround(0), $1106 = 0, $1107 = 0, $1108 = 0;
 var $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = Math_fround(0), $1115 = 0, $1116 = Math_fround(0), $1117 = 0, $1118 = Math_fround(0), $1119 = 0, $112 = 0, $1120 = Math_fround(0), $1121 = 0, $1122 = Math_fround(0), $1123 = 0, $1124 = Math_fround(0), $1125 = Math_fround(0), $1126 = Math_fround(0);
 var $1127 = Math_fround(0), $1128 = 0, $1129 = Math_fround(0), $113 = 0, $1130 = 0, $1131 = Math_fround(0), $1132 = 0, $1133 = Math_fround(0), $1134 = 0, $1135 = Math_fround(0), $1136 = 0, $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = 0, $114 = 0, $1140 = Math_fround(0), $1141 = 0, $1142 = Math_fround(0), $1143 = 0, $1144 = Math_fround(0);
 var $1145 = 0, $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = 0, $1149 = Math_fround(0), $115 = 0, $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = 0, $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = 0, $1156 = Math_fround(0), $1157 = 0, $1158 = Math_fround(0), $1159 = Math_fround(0), $116 = 0, $1160 = Math_fround(0), $1161 = 0.0, $1162 = 0.0;
 var $1163 = Math_fround(0), $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = Math_fround(0), $117 = 0, $1170 = Math_fround(0), $1171 = Math_fround(0), $1172 = Math_fround(0), $1173 = Math_fround(0), $1174 = Math_fround(0), $1175 = Math_fround(0), $1176 = Math_fround(0), $1177 = Math_fround(0), $1178 = Math_fround(0), $1179 = Math_fround(0), $118 = 0, $1180 = Math_fround(0);
 var $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = Math_fround(0), $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = Math_fround(0), $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = 0, $1190 = Math_fround(0), $1191 = Math_fround(0), $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = Math_fround(0), $1197 = Math_fround(0), $1198 = Math_fround(0), $1199 = Math_fround(0);
 var $12 = 0, $120 = 0, $1200 = Math_fround(0), $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = Math_fround(0), $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = 0, $1214 = 0, $1215 = 0, $1216 = Math_fround(0);
 var $1217 = Math_fround(0), $1218 = 0, $1219 = Math_fround(0), $122 = 0, $1220 = Math_fround(0), $1221 = 0, $1222 = 0, $1223 = 0, $1224 = Math_fround(0), $1225 = 0, $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = 0, $1229 = Math_fround(0), $123 = 0, $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = Math_fround(0), $1233 = Math_fround(0), $1234 = Math_fround(0);
 var $1235 = Math_fround(0), $1236 = Math_fround(0), $1237 = Math_fround(0), $1238 = Math_fround(0), $1239 = Math_fround(0), $124 = Math_fround(0), $1240 = Math_fround(0), $1241 = Math_fround(0), $1242 = Math_fround(0), $1243 = Math_fround(0), $1244 = Math_fround(0), $1245 = Math_fround(0), $1246 = Math_fround(0), $1247 = Math_fround(0), $1248 = Math_fround(0), $1249 = Math_fround(0), $125 = 0, $1250 = Math_fround(0), $1251 = Math_fround(0), $1252 = Math_fround(0);
 var $1253 = Math_fround(0), $1254 = Math_fround(0), $1255 = Math_fround(0), $1256 = Math_fround(0), $1257 = Math_fround(0), $1258 = Math_fround(0), $1259 = Math_fround(0), $126 = Math_fround(0), $1260 = Math_fround(0), $1261 = Math_fround(0), $1262 = Math_fround(0), $1263 = Math_fround(0), $1264 = Math_fround(0), $1265 = Math_fround(0), $1266 = Math_fround(0), $1267 = Math_fround(0), $1268 = Math_fround(0), $1269 = Math_fround(0), $127 = 0, $1270 = Math_fround(0);
 var $1271 = Math_fround(0), $1272 = Math_fround(0), $1273 = Math_fround(0), $1274 = Math_fround(0), $1275 = 0, $1276 = Math_fround(0), $1277 = Math_fround(0), $1278 = Math_fround(0), $1279 = 0, $128 = Math_fround(0), $1280 = Math_fround(0), $1281 = Math_fround(0), $1282 = Math_fround(0), $1283 = 0, $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = Math_fround(0), $1287 = Math_fround(0), $1288 = Math_fround(0), $1289 = Math_fround(0);
 var $129 = 0, $1290 = Math_fround(0), $1291 = Math_fround(0), $1292 = Math_fround(0), $1293 = Math_fround(0), $1294 = Math_fround(0), $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = Math_fround(0), $1298 = Math_fround(0), $1299 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0), $1306 = Math_fround(0);
 var $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0), $131 = 0, $1310 = Math_fround(0), $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = Math_fround(0), $1314 = Math_fround(0), $1315 = Math_fround(0), $1316 = Math_fround(0), $1317 = Math_fround(0), $1318 = 0, $1319 = Math_fround(0), $132 = 0, $1320 = Math_fround(0), $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0), $1324 = 0;
 var $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = 0, $1329 = Math_fround(0), $133 = 0, $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = Math_fround(0), $1333 = Math_fround(0), $1334 = Math_fround(0), $1335 = Math_fround(0), $1336 = Math_fround(0), $1337 = Math_fround(0), $1338 = Math_fround(0), $1339 = Math_fround(0), $134 = 0, $1340 = Math_fround(0), $1341 = Math_fround(0), $1342 = Math_fround(0);
 var $1343 = Math_fround(0), $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = Math_fround(0), $1347 = Math_fround(0), $1348 = Math_fround(0), $1349 = Math_fround(0), $135 = Math_fround(0), $1350 = Math_fround(0), $1351 = Math_fround(0), $1352 = Math_fround(0), $1353 = Math_fround(0), $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = Math_fround(0), $1358 = Math_fround(0), $1359 = Math_fround(0), $136 = 0, $1360 = Math_fround(0);
 var $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = Math_fround(0), $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = Math_fround(0), $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = Math_fround(0), $1379 = Math_fround(0);
 var $138 = 0, $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = Math_fround(0), $1390 = Math_fround(0), $1391 = Math_fround(0), $1392 = Math_fround(0), $1393 = Math_fround(0), $1394 = Math_fround(0), $1395 = Math_fround(0), $1396 = Math_fround(0), $1397 = Math_fround(0);
 var $1398 = Math_fround(0), $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = Math_fround(0), $1401 = Math_fround(0), $1402 = Math_fround(0), $1403 = Math_fround(0), $1404 = Math_fround(0), $1405 = Math_fround(0), $1406 = Math_fround(0), $1407 = Math_fround(0), $1408 = Math_fround(0), $1409 = Math_fround(0), $141 = Math_fround(0), $1410 = Math_fround(0), $1411 = Math_fround(0), $1412 = Math_fround(0), $1413 = Math_fround(0), $1414 = Math_fround(0);
 var $1415 = Math_fround(0), $1416 = Math_fround(0), $1417 = Math_fround(0), $1418 = Math_fround(0), $1419 = Math_fround(0), $142 = 0, $1420 = Math_fround(0), $1421 = Math_fround(0), $1422 = Math_fround(0), $1423 = Math_fround(0), $1424 = Math_fround(0), $1425 = Math_fround(0), $1426 = Math_fround(0), $1427 = Math_fround(0), $1428 = Math_fround(0), $1429 = Math_fround(0), $143 = 0, $1430 = Math_fround(0), $1431 = Math_fround(0), $1432 = Math_fround(0);
 var $1433 = Math_fround(0), $1434 = Math_fround(0), $1435 = Math_fround(0), $1436 = Math_fround(0), $1437 = Math_fround(0), $1438 = Math_fround(0), $1439 = Math_fround(0), $144 = 0, $1440 = Math_fround(0), $1441 = Math_fround(0), $1442 = Math_fround(0), $1443 = Math_fround(0), $1444 = Math_fround(0), $1445 = Math_fround(0), $1446 = Math_fround(0), $1447 = Math_fround(0), $1448 = Math_fround(0), $1449 = Math_fround(0), $145 = 0, $1450 = Math_fround(0);
 var $1451 = Math_fround(0), $1452 = Math_fround(0), $1453 = Math_fround(0), $1454 = Math_fround(0), $1455 = Math_fround(0), $1456 = Math_fround(0), $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = 0, $1460 = Math_fround(0), $1461 = Math_fround(0), $1462 = Math_fround(0), $1463 = Math_fround(0), $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = Math_fround(0), $1467 = Math_fround(0), $1468 = Math_fround(0), $1469 = Math_fround(0);
 var $147 = Math_fround(0), $1470 = Math_fround(0), $1471 = Math_fround(0), $1472 = Math_fround(0), $1473 = Math_fround(0), $1474 = Math_fround(0), $1475 = Math_fround(0), $1476 = Math_fround(0), $1477 = Math_fround(0), $1478 = Math_fround(0), $1479 = Math_fround(0), $148 = 0, $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0), $1486 = Math_fround(0), $1487 = Math_fround(0);
 var $1488 = Math_fround(0), $1489 = Math_fround(0), $149 = Math_fround(0), $1490 = Math_fround(0), $1491 = Math_fround(0), $1492 = Math_fround(0), $1493 = Math_fround(0), $1494 = Math_fround(0), $1495 = Math_fround(0), $1496 = Math_fround(0), $1497 = Math_fround(0), $1498 = Math_fround(0), $1499 = Math_fround(0), $15 = 0, $150 = 0, $1500 = Math_fround(0), $1501 = Math_fround(0), $1502 = Math_fround(0), $1503 = Math_fround(0), $1504 = Math_fround(0);
 var $1505 = Math_fround(0), $1506 = Math_fround(0), $1507 = Math_fround(0), $1508 = Math_fround(0), $1509 = Math_fround(0), $151 = Math_fround(0), $1510 = Math_fround(0), $1511 = Math_fround(0), $1512 = Math_fround(0), $1513 = Math_fround(0), $1514 = Math_fround(0), $1515 = Math_fround(0), $1516 = Math_fround(0), $1517 = Math_fround(0), $1518 = Math_fround(0), $1519 = Math_fround(0), $152 = 0, $1520 = Math_fround(0), $1521 = Math_fround(0), $1522 = Math_fround(0);
 var $1523 = Math_fround(0), $1524 = Math_fround(0), $1525 = Math_fround(0), $1526 = Math_fround(0), $1527 = Math_fround(0), $1528 = Math_fround(0), $1529 = Math_fround(0), $153 = Math_fround(0), $1530 = Math_fround(0), $1531 = Math_fround(0), $1532 = Math_fround(0), $1533 = Math_fround(0), $1534 = Math_fround(0), $1535 = Math_fround(0), $1536 = Math_fround(0), $1537 = Math_fround(0), $1538 = Math_fround(0), $1539 = Math_fround(0), $154 = 0, $1540 = Math_fround(0);
 var $1541 = Math_fround(0), $1542 = Math_fround(0), $1543 = Math_fround(0), $1544 = Math_fround(0), $1545 = Math_fround(0), $1546 = Math_fround(0), $1547 = Math_fround(0), $1548 = Math_fround(0), $1549 = Math_fround(0), $155 = 0, $1550 = Math_fround(0), $1551 = Math_fround(0), $1552 = Math_fround(0), $1553 = Math_fround(0), $1554 = Math_fround(0), $1555 = Math_fround(0), $1556 = Math_fround(0), $1557 = Math_fround(0), $1558 = Math_fround(0), $1559 = Math_fround(0);
 var $156 = 0, $1560 = Math_fround(0), $1561 = Math_fround(0), $1562 = Math_fround(0), $1563 = Math_fround(0), $1564 = 0, $1565 = 0, $1566 = 0, $1567 = Math_fround(0), $1568 = Math_fround(0), $1569 = Math_fround(0), $157 = 0, $1570 = Math_fround(0), $1571 = 0, $1572 = 0, $1573 = 0, $1574 = Math_fround(0), $1575 = 0, $1576 = 0, $1577 = 0;
 var $1578 = Math_fround(0), $1579 = Math_fround(0), $158 = 0, $1580 = Math_fround(0), $1581 = Math_fround(0), $1582 = Math_fround(0), $1583 = Math_fround(0), $1584 = Math_fround(0), $1585 = Math_fround(0), $1586 = Math_fround(0), $1587 = Math_fround(0), $1588 = Math_fround(0), $1589 = Math_fround(0), $159 = Math_fround(0), $1590 = Math_fround(0), $1591 = Math_fround(0), $1592 = Math_fround(0), $1593 = Math_fround(0), $1594 = Math_fround(0), $1595 = Math_fround(0);
 var $1596 = Math_fround(0), $1597 = Math_fround(0), $1598 = Math_fround(0), $1599 = Math_fround(0), $16 = 0, $160 = 0, $1600 = Math_fround(0), $1601 = Math_fround(0), $1602 = Math_fround(0), $1603 = Math_fround(0), $1604 = Math_fround(0), $1605 = Math_fround(0), $1606 = Math_fround(0), $1607 = Math_fround(0), $1608 = Math_fround(0), $1609 = Math_fround(0), $161 = Math_fround(0), $1610 = Math_fround(0), $1611 = Math_fround(0), $1612 = Math_fround(0);
 var $1613 = Math_fround(0), $1614 = Math_fround(0), $1615 = Math_fround(0), $1616 = Math_fround(0), $1617 = Math_fround(0), $1618 = Math_fround(0), $1619 = Math_fround(0), $162 = 0, $1620 = Math_fround(0), $1621 = Math_fround(0), $1622 = Math_fround(0), $1623 = Math_fround(0), $1624 = Math_fround(0), $1625 = Math_fround(0), $1626 = Math_fround(0), $1627 = Math_fround(0), $1628 = Math_fround(0), $1629 = Math_fround(0), $163 = Math_fround(0), $1630 = Math_fround(0);
 var $1631 = Math_fround(0), $1632 = Math_fround(0), $1633 = Math_fround(0), $1634 = Math_fround(0), $1635 = Math_fround(0), $1636 = Math_fround(0), $1637 = Math_fround(0), $1638 = Math_fround(0), $1639 = Math_fround(0), $164 = 0, $1640 = Math_fround(0), $1641 = Math_fround(0), $1642 = Math_fround(0), $1643 = Math_fround(0), $1644 = Math_fround(0), $1645 = Math_fround(0), $1646 = Math_fround(0), $1647 = Math_fround(0), $1648 = Math_fround(0), $1649 = Math_fround(0);
 var $165 = Math_fround(0), $1650 = Math_fround(0), $1651 = Math_fround(0), $1652 = Math_fround(0), $1653 = Math_fround(0), $1654 = Math_fround(0), $1655 = Math_fround(0), $1656 = Math_fround(0), $1657 = Math_fround(0), $1658 = Math_fround(0), $1659 = Math_fround(0), $166 = 0, $1660 = Math_fround(0), $1661 = Math_fround(0), $1662 = Math_fround(0), $1663 = Math_fround(0), $1664 = Math_fround(0), $1665 = Math_fround(0), $1666 = Math_fround(0), $1667 = Math_fround(0);
 var $1668 = Math_fround(0), $1669 = Math_fround(0), $167 = 0, $1670 = Math_fround(0), $1671 = Math_fround(0), $1672 = Math_fround(0), $1673 = Math_fround(0), $1674 = Math_fround(0), $1675 = Math_fround(0), $1676 = Math_fround(0), $1677 = Math_fround(0), $1678 = Math_fround(0), $1679 = Math_fround(0), $168 = 0, $1680 = Math_fround(0), $1681 = Math_fround(0), $1682 = Math_fround(0), $1683 = Math_fround(0), $1684 = Math_fround(0), $1685 = Math_fround(0);
 var $1686 = Math_fround(0), $1687 = Math_fround(0), $1688 = Math_fround(0), $1689 = Math_fround(0), $169 = 0, $1690 = Math_fround(0), $1691 = Math_fround(0), $1692 = Math_fround(0), $1693 = Math_fround(0), $1694 = Math_fround(0), $1695 = Math_fround(0), $1696 = Math_fround(0), $1697 = Math_fround(0), $1698 = Math_fround(0), $1699 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $1700 = Math_fround(0), $1701 = Math_fround(0), $1702 = Math_fround(0);
 var $1703 = Math_fround(0), $1704 = Math_fround(0), $1705 = Math_fround(0), $1706 = Math_fround(0), $1707 = Math_fround(0), $1708 = Math_fround(0), $1709 = Math_fround(0), $171 = 0, $1710 = Math_fround(0), $1711 = Math_fround(0), $1712 = Math_fround(0), $1713 = Math_fround(0), $1714 = Math_fround(0), $1715 = Math_fround(0), $1716 = Math_fround(0), $1717 = Math_fround(0), $1718 = Math_fround(0), $1719 = Math_fround(0), $172 = Math_fround(0), $1720 = Math_fround(0);
 var $1721 = Math_fround(0), $1722 = Math_fround(0), $1723 = Math_fround(0), $1724 = Math_fround(0), $1725 = Math_fround(0), $1726 = Math_fround(0), $1727 = Math_fround(0), $1728 = Math_fround(0), $1729 = Math_fround(0), $173 = 0, $1730 = Math_fround(0), $1731 = Math_fround(0), $1732 = Math_fround(0), $1733 = Math_fround(0), $1734 = Math_fround(0), $1735 = Math_fround(0), $1736 = Math_fround(0), $1737 = Math_fround(0), $1738 = Math_fround(0), $1739 = Math_fround(0);
 var $174 = Math_fround(0), $1740 = Math_fround(0), $1741 = Math_fround(0), $1742 = Math_fround(0), $1743 = Math_fround(0), $1744 = Math_fround(0), $1745 = Math_fround(0), $1746 = Math_fround(0), $1747 = Math_fround(0), $1748 = Math_fround(0), $1749 = Math_fround(0), $175 = 0, $1750 = Math_fround(0), $1751 = Math_fround(0), $1752 = Math_fround(0), $1753 = Math_fround(0), $1754 = Math_fround(0), $1755 = Math_fround(0), $1756 = Math_fround(0), $1757 = Math_fround(0);
 var $1758 = Math_fround(0), $1759 = Math_fround(0), $176 = Math_fround(0), $1760 = Math_fround(0), $1761 = Math_fround(0), $1762 = Math_fround(0), $1763 = Math_fround(0), $1764 = Math_fround(0), $1765 = Math_fround(0), $1766 = Math_fround(0), $1767 = Math_fround(0), $1768 = Math_fround(0), $1769 = Math_fround(0), $177 = 0, $1770 = Math_fround(0), $1771 = Math_fround(0), $1772 = Math_fround(0), $1773 = Math_fround(0), $1774 = Math_fround(0), $1775 = Math_fround(0);
 var $1776 = Math_fround(0), $1777 = Math_fround(0), $1778 = Math_fround(0), $1779 = Math_fround(0), $178 = 0, $1780 = Math_fround(0), $1781 = Math_fround(0), $1782 = Math_fround(0), $1783 = Math_fround(0), $1784 = Math_fround(0), $1785 = Math_fround(0), $1786 = Math_fround(0), $1787 = Math_fround(0), $1788 = Math_fround(0), $1789 = Math_fround(0), $179 = 0, $1790 = Math_fround(0), $1791 = Math_fround(0), $1792 = Math_fround(0), $1793 = Math_fround(0);
 var $1794 = Math_fround(0), $1795 = Math_fround(0), $1796 = Math_fround(0), $1797 = Math_fround(0), $1798 = Math_fround(0), $1799 = Math_fround(0), $18 = 0, $180 = 0, $1800 = Math_fround(0), $1801 = Math_fround(0), $1802 = Math_fround(0), $1803 = Math_fround(0), $1804 = Math_fround(0), $1805 = Math_fround(0), $1806 = Math_fround(0), $1807 = Math_fround(0), $1808 = Math_fround(0), $1809 = Math_fround(0), $181 = 0, $1810 = Math_fround(0);
 var $1811 = Math_fround(0), $1812 = Math_fround(0), $1813 = Math_fround(0), $1814 = Math_fround(0), $1815 = Math_fround(0), $1816 = Math_fround(0), $1817 = Math_fround(0), $1818 = Math_fround(0), $1819 = Math_fround(0), $182 = Math_fround(0), $1820 = Math_fround(0), $1821 = Math_fround(0), $1822 = Math_fround(0), $1823 = Math_fround(0), $1824 = Math_fround(0), $1825 = Math_fround(0), $1826 = Math_fround(0), $1827 = Math_fround(0), $1828 = Math_fround(0), $1829 = Math_fround(0);
 var $183 = 0, $1830 = Math_fround(0), $1831 = Math_fround(0), $1832 = Math_fround(0), $1833 = Math_fround(0), $1834 = Math_fround(0), $1835 = Math_fround(0), $1836 = Math_fround(0), $1837 = Math_fround(0), $1838 = Math_fround(0), $1839 = Math_fround(0), $184 = Math_fround(0), $1840 = Math_fround(0), $1841 = Math_fround(0), $1842 = Math_fround(0), $1843 = Math_fround(0), $1844 = Math_fround(0), $1845 = Math_fround(0), $1846 = Math_fround(0), $1847 = Math_fround(0);
 var $1848 = Math_fround(0), $1849 = Math_fround(0), $185 = 0, $1850 = Math_fround(0), $1851 = Math_fround(0), $1852 = Math_fround(0), $1853 = Math_fround(0), $1854 = Math_fround(0), $1855 = Math_fround(0), $1856 = Math_fround(0), $1857 = Math_fround(0), $1858 = Math_fround(0), $1859 = Math_fround(0), $186 = Math_fround(0), $1860 = Math_fround(0), $1861 = Math_fround(0), $1862 = Math_fround(0), $1863 = Math_fround(0), $1864 = Math_fround(0), $1865 = Math_fround(0);
 var $1866 = Math_fround(0), $1867 = Math_fround(0), $1868 = Math_fround(0), $1869 = Math_fround(0), $187 = 0, $1870 = Math_fround(0), $1871 = Math_fround(0), $1872 = Math_fround(0), $1873 = Math_fround(0), $1874 = Math_fround(0), $1875 = Math_fround(0), $1876 = Math_fround(0), $1877 = Math_fround(0), $1878 = Math_fround(0), $1879 = Math_fround(0), $188 = Math_fround(0), $1880 = Math_fround(0), $1881 = Math_fround(0), $1882 = Math_fround(0), $1883 = Math_fround(0);
 var $1884 = Math_fround(0), $1885 = Math_fround(0), $1886 = Math_fround(0), $1887 = Math_fround(0), $1888 = Math_fround(0), $1889 = 0, $189 = 0, $1890 = Math_fround(0), $1891 = Math_fround(0), $1892 = 0, $1893 = Math_fround(0), $1894 = Math_fround(0), $1895 = 0, $1896 = Math_fround(0), $1897 = Math_fround(0), $1898 = 0, $1899 = Math_fround(0), $19 = 0, $190 = 0, $1900 = Math_fround(0);
 var $1901 = Math_fround(0), $1902 = Math_fround(0), $1903 = Math_fround(0), $1904 = Math_fround(0), $1905 = Math_fround(0), $1906 = Math_fround(0), $1907 = Math_fround(0), $1908 = Math_fround(0), $1909 = Math_fround(0), $191 = 0, $1910 = Math_fround(0), $1911 = Math_fround(0), $1912 = Math_fround(0), $1913 = Math_fround(0), $1914 = Math_fround(0), $1915 = Math_fround(0), $1916 = Math_fround(0), $1917 = Math_fround(0), $1918 = Math_fround(0), $1919 = Math_fround(0);
 var $192 = 0, $1920 = Math_fround(0), $1921 = Math_fround(0), $1922 = Math_fround(0), $1923 = Math_fround(0), $1924 = Math_fround(0), $1925 = Math_fround(0), $1926 = Math_fround(0), $1927 = Math_fround(0), $1928 = Math_fround(0), $1929 = Math_fround(0), $193 = 0, $1930 = Math_fround(0), $1931 = Math_fround(0), $1932 = Math_fround(0), $1933 = 0, $1934 = Math_fround(0), $1935 = Math_fround(0), $1936 = 0, $1937 = Math_fround(0);
 var $1938 = Math_fround(0), $1939 = 0, $194 = Math_fround(0), $1940 = Math_fround(0), $1941 = Math_fround(0), $1942 = 0, $1943 = Math_fround(0), $1944 = Math_fround(0), $1945 = Math_fround(0), $1946 = Math_fround(0), $1947 = Math_fround(0), $1948 = Math_fround(0), $1949 = Math_fround(0), $195 = 0, $1950 = Math_fround(0), $1951 = Math_fround(0), $1952 = Math_fround(0), $1953 = Math_fround(0), $1954 = Math_fround(0), $1955 = Math_fround(0);
 var $1956 = Math_fround(0), $1957 = Math_fround(0), $1958 = Math_fround(0), $1959 = Math_fround(0), $196 = Math_fround(0), $1960 = Math_fround(0), $1961 = Math_fround(0), $1962 = Math_fround(0), $1963 = Math_fround(0), $1964 = Math_fround(0), $1965 = Math_fround(0), $1966 = Math_fround(0), $1967 = Math_fround(0), $1968 = Math_fround(0), $1969 = Math_fround(0), $197 = 0, $1970 = Math_fround(0), $1971 = Math_fround(0), $1972 = Math_fround(0), $1973 = Math_fround(0);
 var $1974 = Math_fround(0), $1975 = Math_fround(0), $1976 = Math_fround(0), $1977 = 0, $1978 = 0, $1979 = 0, $198 = Math_fround(0), $1980 = 0, $1981 = 0, $1982 = 0, $1983 = Math_fround(0), $1984 = Math_fround(0), $1985 = 0, $1986 = Math_fround(0), $1987 = Math_fround(0), $1988 = 0, $1989 = Math_fround(0), $199 = 0, $1990 = Math_fround(0), $1991 = 0;
 var $1992 = Math_fround(0), $1993 = Math_fround(0), $1994 = 0, $1995 = Math_fround(0), $1996 = Math_fround(0), $1997 = 0, $1998 = Math_fround(0), $1999 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $2000 = 0, $2001 = Math_fround(0), $2002 = Math_fround(0), $2003 = 0, $2004 = Math_fround(0), $2005 = Math_fround(0), $2006 = Math_fround(0), $2007 = Math_fround(0), $2008 = Math_fround(0);
 var $2009 = Math_fround(0), $201 = 0, $2010 = Math_fround(0), $2011 = Math_fround(0), $2012 = Math_fround(0), $2013 = Math_fround(0), $2014 = Math_fround(0), $2015 = Math_fround(0), $2016 = Math_fround(0), $2017 = Math_fround(0), $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0;
 var $2027 = 0, $2028 = 0, $2029 = Math_fround(0), $203 = 0, $2030 = 0, $2031 = Math_fround(0), $2032 = 0, $2033 = Math_fround(0), $2034 = 0, $2035 = Math_fround(0), $2036 = 0, $2037 = Math_fround(0), $2038 = 0, $2039 = Math_fround(0), $204 = 0, $2040 = 0, $2041 = Math_fround(0), $2042 = 0, $2043 = Math_fround(0), $2044 = 0;
 var $2045 = Math_fround(0), $2046 = 0, $2047 = Math_fround(0), $2048 = 0, $2049 = Math_fround(0), $205 = Math_fround(0), $2050 = 0, $2051 = Math_fround(0), $2052 = 0, $2053 = Math_fround(0), $2054 = Math_fround(0), $2055 = 0, $2056 = Math_fround(0), $2057 = Math_fround(0), $2058 = 0, $2059 = Math_fround(0), $206 = 0, $2060 = Math_fround(0), $2061 = 0, $2062 = Math_fround(0);
 var $2063 = Math_fround(0), $2064 = 0, $2065 = Math_fround(0), $2066 = Math_fround(0), $2067 = 0, $2068 = Math_fround(0), $2069 = Math_fround(0), $207 = Math_fround(0), $2070 = 0, $2071 = Math_fround(0), $2072 = Math_fround(0), $2073 = 0, $2074 = Math_fround(0), $2075 = Math_fround(0), $2076 = Math_fround(0), $2077 = Math_fround(0), $2078 = Math_fround(0), $2079 = Math_fround(0), $208 = 0, $2080 = Math_fround(0);
 var $2081 = Math_fround(0), $2082 = Math_fround(0), $2083 = Math_fround(0), $2084 = Math_fround(0), $2085 = Math_fround(0), $2086 = Math_fround(0), $2087 = Math_fround(0), $2088 = 0, $2089 = 0, $209 = Math_fround(0), $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = Math_fround(0);
 var $21 = 0, $210 = 0, $2100 = 0, $2101 = Math_fround(0), $2102 = 0, $2103 = Math_fround(0), $2104 = 0, $2105 = Math_fround(0), $2106 = 0, $2107 = Math_fround(0), $2108 = 0, $2109 = Math_fround(0), $211 = Math_fround(0), $2110 = 0, $2111 = Math_fround(0), $2112 = 0, $2113 = Math_fround(0), $2114 = 0, $2115 = Math_fround(0), $2116 = 0;
 var $2117 = Math_fround(0), $2118 = 0, $2119 = Math_fround(0), $212 = 0, $2120 = 0, $2121 = Math_fround(0), $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0, $2130 = Math_fround(0), $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0;
 var $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0, $2140 = Math_fround(0), $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = Math_fround(0), $2151 = 0, $2152 = Math_fround(0);
 var $2153 = Math_fround(0), $2154 = 0, $2155 = Math_fround(0), $2156 = Math_fround(0), $2157 = 0, $2158 = Math_fround(0), $2159 = Math_fround(0), $216 = 0, $2160 = Math_fround(0), $2161 = Math_fround(0), $2162 = Math_fround(0), $2163 = 0, $2164 = Math_fround(0), $2165 = Math_fround(0), $2166 = 0, $2167 = Math_fround(0), $2168 = Math_fround(0), $2169 = 0, $217 = Math_fround(0), $2170 = Math_fround(0);
 var $2171 = Math_fround(0), $2172 = Math_fround(0), $2173 = Math_fround(0), $2174 = Math_fround(0), $2175 = Math_fround(0), $2176 = Math_fround(0), $2177 = Math_fround(0), $2178 = Math_fround(0), $2179 = Math_fround(0), $218 = 0, $2180 = Math_fround(0), $2181 = Math_fround(0), $2182 = Math_fround(0), $2183 = Math_fround(0), $2184 = Math_fround(0), $2185 = Math_fround(0), $2186 = Math_fround(0), $2187 = Math_fround(0), $2188 = Math_fround(0), $2189 = Math_fround(0);
 var $219 = Math_fround(0), $2190 = Math_fround(0), $2191 = Math_fround(0), $2192 = Math_fround(0), $2193 = Math_fround(0), $2194 = Math_fround(0), $2195 = Math_fround(0), $2196 = Math_fround(0), $2197 = Math_fround(0), $2198 = Math_fround(0), $2199 = Math_fround(0), $22 = 0, $220 = 0, $2200 = Math_fround(0), $2201 = Math_fround(0), $2202 = Math_fround(0), $2203 = Math_fround(0), $2204 = Math_fround(0), $2205 = Math_fround(0), $2206 = Math_fround(0);
 var $2207 = Math_fround(0), $2208 = 0, $2209 = 0, $221 = Math_fround(0), $2210 = 0, $2211 = 0, $2212 = 0, $2213 = 0, $2214 = Math_fround(0), $2215 = 0, $2216 = 0, $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0, $2221 = Math_fround(0), $2222 = 0, $2223 = 0, $2224 = 0;
 var $2225 = 0, $2226 = 0, $2227 = 0, $2228 = Math_fround(0), $2229 = Math_fround(0), $223 = Math_fround(0), $2230 = Math_fround(0), $2231 = Math_fround(0), $2232 = Math_fround(0), $2233 = Math_fround(0), $2234 = Math_fround(0), $2235 = Math_fround(0), $2236 = Math_fround(0), $2237 = Math_fround(0), $2238 = Math_fround(0), $2239 = Math_fround(0), $224 = 0, $2240 = Math_fround(0), $2241 = Math_fround(0), $2242 = Math_fround(0);
 var $2243 = Math_fround(0), $2244 = Math_fround(0), $2245 = Math_fround(0), $2246 = Math_fround(0), $2247 = Math_fround(0), $2248 = Math_fround(0), $2249 = Math_fround(0), $225 = 0, $2250 = Math_fround(0), $2251 = Math_fround(0), $2252 = Math_fround(0), $2253 = Math_fround(0), $2254 = Math_fround(0), $2255 = Math_fround(0), $2256 = Math_fround(0), $2257 = Math_fround(0), $2258 = Math_fround(0), $2259 = Math_fround(0), $226 = 0, $2260 = Math_fround(0);
 var $2261 = Math_fround(0), $2262 = Math_fround(0), $2263 = Math_fround(0), $2264 = Math_fround(0), $2265 = Math_fround(0), $2266 = Math_fround(0), $2267 = Math_fround(0), $2268 = Math_fround(0), $2269 = Math_fround(0), $227 = 0, $2270 = Math_fround(0), $2271 = Math_fround(0), $2272 = Math_fround(0), $2273 = Math_fround(0), $2274 = Math_fround(0), $2275 = Math_fround(0), $2276 = Math_fround(0), $2277 = Math_fround(0), $2278 = Math_fround(0), $2279 = Math_fround(0);
 var $228 = Math_fround(0), $2280 = Math_fround(0), $2281 = Math_fround(0), $2282 = Math_fround(0), $2283 = Math_fround(0), $2284 = Math_fround(0), $2285 = Math_fround(0), $2286 = Math_fround(0), $2287 = Math_fround(0), $2288 = 0, $2289 = Math_fround(0), $229 = 0, $2290 = Math_fround(0), $2291 = 0, $2292 = Math_fround(0), $2293 = Math_fround(0), $2294 = 0, $2295 = Math_fround(0), $2296 = Math_fround(0), $2297 = 0;
 var $2298 = Math_fround(0), $2299 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $2300 = Math_fround(0), $2301 = Math_fround(0), $2302 = Math_fround(0), $2303 = Math_fround(0), $2304 = 0, $2305 = Math_fround(0), $2306 = Math_fround(0), $2307 = 0, $2308 = Math_fround(0), $2309 = Math_fround(0), $231 = 0, $2310 = 0, $2311 = Math_fround(0), $2312 = Math_fround(0), $2313 = 0, $2314 = Math_fround(0);
 var $2315 = Math_fround(0), $2316 = Math_fround(0), $2317 = Math_fround(0), $2318 = Math_fround(0), $2319 = Math_fround(0), $232 = Math_fround(0), $2320 = Math_fround(0), $2321 = Math_fround(0), $2322 = Math_fround(0), $2323 = Math_fround(0), $2324 = Math_fround(0), $2325 = Math_fround(0), $2326 = Math_fround(0), $2327 = Math_fround(0), $2328 = Math_fround(0), $2329 = Math_fround(0), $233 = 0, $2330 = Math_fround(0), $2331 = Math_fround(0), $2332 = Math_fround(0);
 var $2333 = Math_fround(0), $2334 = Math_fround(0), $2335 = Math_fround(0), $2336 = Math_fround(0), $2337 = Math_fround(0), $2338 = Math_fround(0), $2339 = Math_fround(0), $234 = Math_fround(0), $2340 = Math_fround(0), $2341 = Math_fround(0), $2342 = Math_fround(0), $2343 = Math_fround(0), $2344 = Math_fround(0), $2345 = Math_fround(0), $2346 = Math_fround(0), $2347 = Math_fround(0), $2348 = Math_fround(0), $2349 = Math_fround(0), $235 = 0, $2350 = Math_fround(0);
 var $2351 = Math_fround(0), $2352 = Math_fround(0), $2353 = Math_fround(0), $2354 = Math_fround(0), $2355 = Math_fround(0), $2356 = Math_fround(0), $2357 = Math_fround(0), $2358 = Math_fround(0), $2359 = Math_fround(0), $236 = 0, $2360 = Math_fround(0), $2361 = Math_fround(0), $2362 = Math_fround(0), $2363 = Math_fround(0), $2364 = Math_fround(0), $2365 = Math_fround(0), $2366 = Math_fround(0), $2367 = Math_fround(0), $2368 = Math_fround(0), $2369 = Math_fround(0);
 var $237 = 0, $2370 = Math_fround(0), $2371 = Math_fround(0), $2372 = Math_fround(0), $2373 = Math_fround(0), $2374 = Math_fround(0), $2375 = Math_fround(0), $2376 = Math_fround(0), $2377 = Math_fround(0), $2378 = Math_fround(0), $2379 = Math_fround(0), $238 = 0, $2380 = Math_fround(0), $2381 = Math_fround(0), $2382 = Math_fround(0), $2383 = Math_fround(0), $2384 = Math_fround(0), $2385 = Math_fround(0), $2386 = Math_fround(0), $2387 = Math_fround(0);
 var $2388 = Math_fround(0), $2389 = Math_fround(0), $239 = Math_fround(0), $2390 = Math_fround(0), $2391 = Math_fround(0), $2392 = Math_fround(0), $2393 = Math_fround(0), $2394 = Math_fround(0), $2395 = Math_fround(0), $2396 = Math_fround(0), $2397 = Math_fround(0), $2398 = Math_fround(0), $2399 = Math_fround(0), $24 = 0, $240 = 0, $2400 = Math_fround(0), $2401 = Math_fround(0), $2402 = Math_fround(0), $2403 = Math_fround(0), $2404 = Math_fround(0);
 var $2405 = Math_fround(0), $2406 = Math_fround(0), $2407 = Math_fround(0), $2408 = Math_fround(0), $2409 = Math_fround(0), $241 = Math_fround(0), $2410 = Math_fround(0), $2411 = Math_fround(0), $2412 = Math_fround(0), $2413 = Math_fround(0), $2414 = Math_fround(0), $2415 = Math_fround(0), $2416 = Math_fround(0), $2417 = Math_fround(0), $2418 = Math_fround(0), $2419 = Math_fround(0), $242 = 0, $2420 = Math_fround(0), $2421 = Math_fround(0), $2422 = Math_fround(0);
 var $2423 = Math_fround(0), $2424 = Math_fround(0), $2425 = Math_fround(0), $2426 = Math_fround(0), $2427 = Math_fround(0), $2428 = Math_fround(0), $2429 = 0, $243 = Math_fround(0), $2430 = Math_fround(0), $2431 = Math_fround(0), $2432 = Math_fround(0), $2433 = 0, $2434 = Math_fround(0), $2435 = Math_fround(0), $2436 = Math_fround(0), $2437 = 0, $2438 = Math_fround(0), $2439 = Math_fround(0), $244 = 0, $2440 = Math_fround(0);
 var $2441 = Math_fround(0), $2442 = Math_fround(0), $2443 = Math_fround(0), $2444 = Math_fround(0), $2445 = Math_fround(0), $2446 = Math_fround(0), $2447 = Math_fround(0), $2448 = Math_fround(0), $2449 = Math_fround(0), $245 = Math_fround(0), $2450 = Math_fround(0), $2451 = Math_fround(0), $2452 = Math_fround(0), $2453 = Math_fround(0), $2454 = Math_fround(0), $2455 = Math_fround(0), $2456 = Math_fround(0), $2457 = Math_fround(0), $2458 = Math_fround(0), $2459 = Math_fround(0);
 var $246 = 0, $2460 = Math_fround(0), $2461 = Math_fround(0), $2462 = Math_fround(0), $2463 = Math_fround(0), $2464 = Math_fround(0), $2465 = Math_fround(0), $2466 = Math_fround(0), $2467 = Math_fround(0), $2468 = Math_fround(0), $2469 = Math_fround(0), $247 = 0, $2470 = Math_fround(0), $2471 = Math_fround(0), $2472 = Math_fround(0), $2473 = Math_fround(0), $2474 = Math_fround(0), $2475 = Math_fround(0), $2476 = Math_fround(0), $2477 = 0;
 var $2478 = Math_fround(0), $2479 = Math_fround(0), $248 = 0, $2480 = 0, $2481 = Math_fround(0), $2482 = Math_fround(0), $2483 = 0, $2484 = Math_fround(0), $2485 = Math_fround(0), $2486 = 0, $2487 = Math_fround(0), $2488 = Math_fround(0), $2489 = Math_fround(0), $249 = 0, $2490 = Math_fround(0), $2491 = Math_fround(0), $2492 = Math_fround(0), $2493 = Math_fround(0), $2494 = Math_fround(0), $2495 = Math_fround(0);
 var $2496 = Math_fround(0), $2497 = Math_fround(0), $2498 = Math_fround(0), $2499 = Math_fround(0), $25 = 0, $250 = 0, $2500 = Math_fround(0), $2501 = Math_fround(0), $2502 = Math_fround(0), $2503 = Math_fround(0), $2504 = Math_fround(0), $2505 = Math_fround(0), $2506 = Math_fround(0), $2507 = Math_fround(0), $2508 = Math_fround(0), $2509 = Math_fround(0), $251 = Math_fround(0), $2510 = Math_fround(0), $2511 = Math_fround(0), $2512 = Math_fround(0);
 var $2513 = Math_fround(0), $2514 = Math_fround(0), $2515 = Math_fround(0), $2516 = Math_fround(0), $2517 = Math_fround(0), $2518 = Math_fround(0), $2519 = Math_fround(0), $252 = 0, $2520 = Math_fround(0), $2521 = Math_fround(0), $2522 = Math_fround(0), $2523 = Math_fround(0), $2524 = Math_fround(0), $2525 = Math_fround(0), $2526 = Math_fround(0), $2527 = Math_fround(0), $2528 = Math_fround(0), $2529 = Math_fround(0), $253 = Math_fround(0), $2530 = Math_fround(0);
 var $2531 = Math_fround(0), $2532 = Math_fround(0), $2533 = Math_fround(0), $2534 = Math_fround(0), $2535 = Math_fround(0), $2536 = Math_fround(0), $2537 = Math_fround(0), $2538 = Math_fround(0), $2539 = Math_fround(0), $254 = 0, $2540 = Math_fround(0), $2541 = Math_fround(0), $2542 = Math_fround(0), $2543 = Math_fround(0), $2544 = Math_fround(0), $2545 = Math_fround(0), $2546 = Math_fround(0), $2547 = Math_fround(0), $2548 = Math_fround(0), $2549 = Math_fround(0);
 var $255 = Math_fround(0), $2550 = Math_fround(0), $2551 = Math_fround(0), $2552 = Math_fround(0), $2553 = Math_fround(0), $2554 = Math_fround(0), $2555 = Math_fround(0), $2556 = Math_fround(0), $2557 = Math_fround(0), $2558 = Math_fround(0), $2559 = Math_fround(0), $256 = 0, $2560 = Math_fround(0), $2561 = Math_fround(0), $2562 = Math_fround(0), $2563 = Math_fround(0), $2564 = Math_fround(0), $2565 = Math_fround(0), $2566 = Math_fround(0), $2567 = Math_fround(0);
 var $2568 = Math_fround(0), $2569 = Math_fround(0), $257 = Math_fround(0), $2570 = Math_fround(0), $2571 = Math_fround(0), $2572 = Math_fround(0), $2573 = Math_fround(0), $2574 = Math_fround(0), $2575 = Math_fround(0), $2576 = Math_fround(0), $2577 = Math_fround(0), $2578 = Math_fround(0), $2579 = Math_fround(0), $258 = 0, $2580 = Math_fround(0), $2581 = Math_fround(0), $2582 = Math_fround(0), $2583 = Math_fround(0), $2584 = Math_fround(0), $2585 = Math_fround(0);
 var $2586 = Math_fround(0), $2587 = Math_fround(0), $2588 = Math_fround(0), $2589 = Math_fround(0), $259 = 0, $2590 = Math_fround(0), $2591 = Math_fround(0), $2592 = Math_fround(0), $2593 = Math_fround(0), $2594 = Math_fround(0), $2595 = Math_fround(0), $2596 = Math_fround(0), $2597 = Math_fround(0), $2598 = Math_fround(0), $2599 = Math_fround(0), $26 = 0, $260 = 0, $2600 = Math_fround(0), $2601 = Math_fround(0), $2602 = Math_fround(0);
 var $2603 = Math_fround(0), $2604 = Math_fround(0), $2605 = Math_fround(0), $2606 = Math_fround(0), $2607 = Math_fround(0), $2608 = Math_fround(0), $2609 = Math_fround(0), $261 = 0, $2610 = Math_fround(0), $2611 = Math_fround(0), $2612 = Math_fround(0), $2613 = Math_fround(0), $2614 = Math_fround(0), $2615 = Math_fround(0), $2616 = 0, $2617 = 0, $2618 = 0, $2619 = 0, $262 = 0, $2620 = 0;
 var $2621 = 0, $2622 = 0, $2623 = 0, $2624 = 0, $2625 = 0, $2626 = 0, $2627 = Math_fround(0), $2628 = Math_fround(0), $2629 = Math_fround(0), $263 = 0, $2630 = Math_fround(0), $2631 = Math_fround(0), $2632 = Math_fround(0), $2633 = Math_fround(0), $2634 = Math_fround(0), $2635 = Math_fround(0), $2636 = Math_fround(0), $2637 = Math_fround(0), $2638 = Math_fround(0), $2639 = Math_fround(0);
 var $264 = 0, $2640 = Math_fround(0), $2641 = Math_fround(0), $2642 = Math_fround(0), $2643 = Math_fround(0), $2644 = Math_fround(0), $2645 = Math_fround(0), $2646 = Math_fround(0), $2647 = 0, $2648 = 0, $2649 = 0, $265 = 0, $2650 = 0, $2651 = 0, $2652 = 0, $2653 = 0, $2654 = 0, $2655 = 0, $2656 = 0, $2657 = 0;
 var $2658 = 0, $2659 = 0, $266 = 0, $2660 = 0, $2661 = 0, $2662 = 0, $2663 = 0, $2664 = 0, $2665 = 0, $2666 = 0, $2667 = 0, $2668 = 0, $2669 = Math_fround(0), $267 = 0, $2670 = Math_fround(0), $2671 = Math_fround(0), $2672 = Math_fround(0), $2673 = Math_fround(0), $2674 = Math_fround(0), $2675 = Math_fround(0);
 var $2676 = Math_fround(0), $2677 = Math_fround(0), $2678 = Math_fround(0), $2679 = Math_fround(0), $268 = 0, $2680 = Math_fround(0), $2681 = Math_fround(0), $2682 = Math_fround(0), $2683 = Math_fround(0), $2684 = Math_fround(0), $2685 = Math_fround(0), $2686 = Math_fround(0), $2687 = Math_fround(0), $2688 = Math_fround(0), $2689 = 0, $269 = 0, $2690 = Math_fround(0), $2691 = 0, $2692 = Math_fround(0), $2693 = 0;
 var $2694 = Math_fround(0), $2695 = 0, $2696 = Math_fround(0), $2697 = 0, $2698 = Math_fround(0), $2699 = 0, $27 = 0, $270 = 0, $2700 = Math_fround(0), $2701 = 0, $2702 = Math_fround(0), $2703 = 0, $2704 = Math_fround(0), $2705 = 0, $2706 = Math_fround(0), $2707 = 0, $2708 = Math_fround(0), $2709 = 0, $271 = 0, $2710 = Math_fround(0);
 var $2711 = Math_fround(0), $2712 = 0, $2713 = Math_fround(0), $2714 = 0, $2715 = Math_fround(0), $2716 = 0, $2717 = Math_fround(0), $2718 = 0, $2719 = Math_fround(0), $272 = Math_fround(0), $2720 = 0, $2721 = Math_fround(0), $2722 = 0, $2723 = Math_fround(0), $2724 = 0, $2725 = Math_fround(0), $2726 = 0, $2727 = Math_fround(0), $2728 = 0, $2729 = Math_fround(0);
 var $273 = 0, $2730 = 0, $2731 = Math_fround(0), $2732 = 0, $2733 = Math_fround(0), $2734 = Math_fround(0), $2735 = 0, $2736 = Math_fround(0), $2737 = 0, $2738 = Math_fround(0), $2739 = 0, $274 = Math_fround(0), $2740 = Math_fround(0), $2741 = 0, $2742 = Math_fround(0), $2743 = 0, $2744 = Math_fround(0), $2745 = 0, $2746 = Math_fround(0), $2747 = 0;
 var $2748 = Math_fround(0), $2749 = 0, $275 = 0, $2750 = Math_fround(0), $2751 = 0, $2752 = Math_fround(0), $2753 = 0, $2754 = Math_fround(0), $2755 = 0, $2756 = Math_fround(0), $2757 = 0, $2758 = 0, $2759 = 0, $276 = Math_fround(0), $2760 = 0, $2761 = 0, $2762 = Math_fround(0), $2763 = Math_fround(0), $2764 = Math_fround(0), $2765 = 0;
 var $2766 = 0, $2767 = 0, $2768 = 0, $2769 = 0, $277 = 0, $2770 = 0, $2771 = 0, $2772 = 0, $2773 = 0, $2774 = 0, $2775 = 0, $2776 = 0, $2777 = 0, $2778 = 0, $2779 = 0, $278 = Math_fround(0), $2780 = 0, $2781 = 0, $2782 = 0, $2783 = 0;
 var $2784 = Math_fround(0), $2785 = Math_fround(0), $2786 = Math_fround(0), $2787 = Math_fround(0), $2788 = Math_fround(0), $2789 = Math_fround(0), $279 = 0, $2790 = Math_fround(0), $2791 = Math_fround(0), $2792 = Math_fround(0), $2793 = Math_fround(0), $2794 = Math_fround(0), $2795 = Math_fround(0), $2796 = Math_fround(0), $2797 = Math_fround(0), $2798 = Math_fround(0), $2799 = Math_fround(0), $28 = 0, $280 = 0, $2800 = Math_fround(0);
 var $2801 = Math_fround(0), $2802 = Math_fround(0), $2803 = Math_fround(0), $2804 = Math_fround(0), $2805 = Math_fround(0), $2806 = Math_fround(0), $2807 = Math_fround(0), $2808 = Math_fround(0), $2809 = Math_fround(0), $281 = 0, $2810 = Math_fround(0), $2811 = Math_fround(0), $2812 = Math_fround(0), $2813 = Math_fround(0), $2814 = Math_fround(0), $2815 = Math_fround(0), $2816 = Math_fround(0), $2817 = Math_fround(0), $2818 = Math_fround(0), $2819 = Math_fround(0);
 var $282 = 0, $2820 = Math_fround(0), $2821 = Math_fround(0), $2822 = Math_fround(0), $2823 = Math_fround(0), $2824 = Math_fround(0), $2825 = Math_fround(0), $2826 = Math_fround(0), $2827 = Math_fround(0), $2828 = Math_fround(0), $2829 = Math_fround(0), $283 = Math_fround(0), $2830 = Math_fround(0), $2831 = Math_fround(0), $2832 = Math_fround(0), $2833 = Math_fround(0), $2834 = Math_fround(0), $2835 = Math_fround(0), $2836 = Math_fround(0), $2837 = Math_fround(0);
 var $2838 = Math_fround(0), $2839 = Math_fround(0), $284 = 0, $2840 = Math_fround(0), $2841 = Math_fround(0), $2842 = Math_fround(0), $2843 = Math_fround(0), $2844 = Math_fround(0), $2845 = Math_fround(0), $2846 = Math_fround(0), $2847 = Math_fround(0), $2848 = Math_fround(0), $2849 = Math_fround(0), $285 = Math_fround(0), $2850 = Math_fround(0), $2851 = Math_fround(0), $2852 = Math_fround(0), $2853 = Math_fround(0), $2854 = Math_fround(0), $2855 = Math_fround(0);
 var $2856 = Math_fround(0), $2857 = Math_fround(0), $2858 = Math_fround(0), $2859 = Math_fround(0), $286 = 0, $2860 = Math_fround(0), $2861 = Math_fround(0), $2862 = Math_fround(0), $2863 = Math_fround(0), $2864 = Math_fround(0), $2865 = Math_fround(0), $2866 = Math_fround(0), $2867 = Math_fround(0), $2868 = Math_fround(0), $2869 = Math_fround(0), $287 = Math_fround(0), $2870 = Math_fround(0), $2871 = Math_fround(0), $2872 = Math_fround(0), $2873 = Math_fround(0);
 var $2874 = Math_fround(0), $2875 = Math_fround(0), $2876 = Math_fround(0), $2877 = Math_fround(0), $2878 = Math_fround(0), $2879 = Math_fround(0), $288 = 0, $2880 = Math_fround(0), $2881 = Math_fround(0), $2882 = Math_fround(0), $2883 = Math_fround(0), $2884 = Math_fround(0), $2885 = Math_fround(0), $2886 = Math_fround(0), $2887 = Math_fround(0), $2888 = Math_fround(0), $2889 = Math_fround(0), $289 = Math_fround(0), $2890 = Math_fround(0), $2891 = Math_fround(0);
 var $2892 = Math_fround(0), $2893 = Math_fround(0), $2894 = Math_fround(0), $2895 = Math_fround(0), $2896 = Math_fround(0), $2897 = Math_fround(0), $2898 = Math_fround(0), $2899 = 0, $29 = 0, $290 = 0, $2900 = Math_fround(0), $2901 = 0, $2902 = 0, $2903 = 0, $2904 = Math_fround(0), $2905 = Math_fround(0), $2906 = Math_fround(0), $2907 = 0, $2908 = Math_fround(0), $2909 = Math_fround(0);
 var $291 = 0, $2910 = 0, $2911 = Math_fround(0), $2912 = Math_fround(0), $2913 = 0, $2914 = Math_fround(0), $2915 = Math_fround(0), $2916 = 0, $2917 = Math_fround(0), $2918 = Math_fround(0), $2919 = 0, $292 = 0, $2920 = Math_fround(0), $2921 = Math_fround(0), $2922 = 0, $2923 = Math_fround(0), $2924 = Math_fround(0), $2925 = 0, $2926 = Math_fround(0), $2927 = Math_fround(0);
 var $2928 = Math_fround(0), $2929 = Math_fround(0), $293 = 0, $2930 = Math_fround(0), $2931 = Math_fround(0), $2932 = Math_fround(0), $2933 = Math_fround(0), $2934 = Math_fround(0), $2935 = Math_fround(0), $2936 = Math_fround(0), $2937 = Math_fround(0), $2938 = Math_fround(0), $2939 = Math_fround(0), $294 = Math_fround(0), $2940 = 0, $2941 = 0, $2942 = 0, $2943 = 0, $2944 = 0, $2945 = 0;
 var $2946 = 0, $2947 = 0, $2948 = 0, $2949 = 0, $295 = 0, $2950 = 0, $2951 = Math_fround(0), $2952 = 0, $2953 = Math_fround(0), $2954 = 0, $2955 = Math_fround(0), $2956 = 0, $2957 = Math_fround(0), $2958 = 0, $2959 = 0, $296 = Math_fround(0), $2960 = 0, $2961 = 0, $2962 = Math_fround(0), $2963 = 0;
 var $2964 = Math_fround(0), $2965 = 0, $2966 = Math_fround(0), $2967 = 0, $2968 = Math_fround(0), $2969 = 0, $297 = 0, $2970 = 0, $2971 = 0, $2972 = 0, $2973 = Math_fround(0), $2974 = 0, $2975 = Math_fround(0), $2976 = 0, $2977 = Math_fround(0), $2978 = 0, $2979 = Math_fround(0), $298 = Math_fround(0), $2980 = Math_fround(0), $2981 = Math_fround(0);
 var $2982 = Math_fround(0), $2983 = Math_fround(0), $2984 = Math_fround(0), $2985 = Math_fround(0), $2986 = Math_fround(0), $2987 = Math_fround(0), $2988 = Math_fround(0), $2989 = Math_fround(0), $299 = 0, $2990 = Math_fround(0), $2991 = Math_fround(0), $2992 = 0, $2993 = 0, $2994 = 0, $2995 = 0, $2996 = 0, $2997 = 0, $2998 = 0, $2999 = 0, $3 = 0;
 var $30 = 0, $300 = Math_fround(0), $3000 = 0, $3001 = 0, $3002 = 0, $3003 = 0, $3004 = Math_fround(0), $3005 = Math_fround(0), $3006 = Math_fround(0), $3007 = Math_fround(0), $3008 = 0, $3009 = 0, $301 = Math_fround(0), $3010 = 0, $3011 = Math_fround(0), $3012 = Math_fround(0), $3013 = Math_fround(0), $3014 = Math_fround(0), $3015 = 0, $3016 = 0;
 var $3017 = 0, $3018 = 0, $3019 = Math_fround(0), $302 = 0, $3020 = Math_fround(0), $3021 = Math_fround(0), $3022 = Math_fround(0), $3023 = 0, $3024 = 0, $3025 = 0, $3026 = 0, $3027 = 0, $3028 = Math_fround(0), $3029 = 0, $303 = Math_fround(0), $3030 = Math_fround(0), $3031 = 0, $3032 = Math_fround(0), $3033 = 0, $3034 = Math_fround(0);
 var $3035 = 0, $3036 = Math_fround(0), $3037 = 0, $3038 = Math_fround(0), $3039 = 0, $304 = 0, $3040 = Math_fround(0), $3041 = 0, $3042 = Math_fround(0), $3043 = 0, $3044 = Math_fround(0), $3045 = 0, $3046 = Math_fround(0), $3047 = 0, $3048 = Math_fround(0), $3049 = 0, $305 = Math_fround(0), $3050 = Math_fround(0), $3051 = Math_fround(0), $3052 = 0;
 var $3053 = Math_fround(0), $3054 = 0, $3055 = Math_fround(0), $3056 = 0, $3057 = Math_fround(0), $3058 = 0, $3059 = Math_fround(0), $306 = 0, $3060 = 0, $3061 = Math_fround(0), $3062 = 0, $3063 = Math_fround(0), $3064 = 0, $3065 = Math_fround(0), $3066 = 0, $3067 = Math_fround(0), $3068 = 0, $3069 = Math_fround(0), $307 = Math_fround(0), $3070 = 0;
 var $3071 = Math_fround(0), $3072 = 0, $3073 = Math_fround(0), $3074 = 0, $3075 = 0, $3076 = Math_fround(0), $3077 = Math_fround(0), $3078 = 0, $3079 = 0, $308 = 0, $3080 = 0, $3081 = Math_fround(0), $3082 = Math_fround(0), $3083 = 0, $3084 = Math_fround(0), $3085 = Math_fround(0), $3086 = 0, $3087 = Math_fround(0), $3088 = Math_fround(0), $3089 = Math_fround(0);
 var $309 = 0, $3090 = Math_fround(0), $3091 = Math_fround(0), $3092 = 0, $3093 = Math_fround(0), $3094 = Math_fround(0), $3095 = 0, $3096 = Math_fround(0), $3097 = Math_fround(0), $3098 = 0, $3099 = Math_fround(0), $31 = 0, $310 = 0, $3100 = Math_fround(0), $3101 = Math_fround(0), $3102 = Math_fround(0), $3103 = Math_fround(0), $3104 = Math_fround(0), $3105 = Math_fround(0), $3106 = Math_fround(0);
 var $3107 = Math_fround(0), $3108 = Math_fround(0), $3109 = Math_fround(0), $311 = 0, $3110 = Math_fround(0), $3111 = Math_fround(0), $3112 = Math_fround(0), $3113 = Math_fround(0), $3114 = Math_fround(0), $3115 = Math_fround(0), $3116 = Math_fround(0), $3117 = Math_fround(0), $3118 = Math_fround(0), $3119 = Math_fround(0), $312 = Math_fround(0), $3120 = Math_fround(0), $3121 = Math_fround(0), $3122 = Math_fround(0), $3123 = Math_fround(0), $3124 = Math_fround(0);
 var $3125 = Math_fround(0), $3126 = Math_fround(0), $3127 = Math_fround(0), $3128 = Math_fround(0), $3129 = Math_fround(0), $313 = 0, $3130 = Math_fround(0), $3131 = Math_fround(0), $3132 = Math_fround(0), $3133 = Math_fround(0), $3134 = Math_fround(0), $3135 = Math_fround(0), $3136 = Math_fround(0), $3137 = Math_fround(0), $3138 = Math_fround(0), $3139 = Math_fround(0), $314 = Math_fround(0), $3140 = Math_fround(0), $3141 = Math_fround(0), $3142 = Math_fround(0);
 var $3143 = Math_fround(0), $3144 = Math_fround(0), $3145 = Math_fround(0), $3146 = Math_fround(0), $3147 = Math_fround(0), $3148 = Math_fround(0), $3149 = Math_fround(0), $315 = 0, $3150 = Math_fround(0), $3151 = Math_fround(0), $3152 = Math_fround(0), $3153 = Math_fround(0), $3154 = Math_fround(0), $3155 = Math_fround(0), $3156 = Math_fround(0), $3157 = Math_fround(0), $3158 = Math_fround(0), $3159 = Math_fround(0), $316 = Math_fround(0), $3160 = Math_fround(0);
 var $3161 = Math_fround(0), $3162 = Math_fround(0), $3163 = Math_fround(0), $3164 = Math_fround(0), $3165 = Math_fround(0), $3166 = Math_fround(0), $3167 = Math_fround(0), $3168 = Math_fround(0), $3169 = Math_fround(0), $317 = 0, $3170 = Math_fround(0), $3171 = Math_fround(0), $3172 = Math_fround(0), $3173 = Math_fround(0), $3174 = Math_fround(0), $3175 = Math_fround(0), $3176 = Math_fround(0), $3177 = Math_fround(0), $3178 = Math_fround(0), $3179 = Math_fround(0);
 var $318 = Math_fround(0), $3180 = Math_fround(0), $3181 = 0, $3182 = 0, $3183 = 0, $3184 = 0, $3185 = 0, $3186 = 0, $3187 = 0, $3188 = 0, $3189 = 0, $319 = 0, $3190 = 0, $3191 = 0, $3192 = Math_fround(0), $3193 = Math_fround(0), $3194 = 0, $3195 = Math_fround(0), $3196 = Math_fround(0), $3197 = 0;
 var $3198 = Math_fround(0), $3199 = Math_fround(0), $32 = 0, $320 = 0, $3200 = 0, $3201 = Math_fround(0), $3202 = Math_fround(0), $3203 = Math_fround(0), $3204 = Math_fround(0), $3205 = Math_fround(0), $3206 = Math_fround(0), $3207 = Math_fround(0), $3208 = Math_fround(0), $3209 = Math_fround(0), $321 = 0, $3210 = Math_fround(0), $3211 = Math_fround(0), $3212 = Math_fround(0), $3213 = Math_fround(0), $3214 = Math_fround(0);
 var $3215 = Math_fround(0), $3216 = Math_fround(0), $3217 = Math_fround(0), $3218 = Math_fround(0), $3219 = Math_fround(0), $322 = 0, $3220 = Math_fround(0), $3221 = Math_fround(0), $3222 = Math_fround(0), $3223 = Math_fround(0), $3224 = Math_fround(0), $3225 = Math_fround(0), $3226 = Math_fround(0), $3227 = Math_fround(0), $3228 = Math_fround(0), $3229 = Math_fround(0), $323 = Math_fround(0), $3230 = Math_fround(0), $3231 = Math_fround(0), $3232 = Math_fround(0);
 var $3233 = Math_fround(0), $3234 = Math_fround(0), $3235 = 0, $3236 = Math_fround(0), $3237 = Math_fround(0), $3238 = 0, $3239 = Math_fround(0), $324 = 0, $3240 = Math_fround(0), $3241 = 0, $3242 = Math_fround(0), $3243 = Math_fround(0), $3244 = 0, $3245 = Math_fround(0), $3246 = Math_fround(0), $3247 = Math_fround(0), $3248 = Math_fround(0), $3249 = Math_fround(0), $325 = Math_fround(0), $3250 = Math_fround(0);
 var $3251 = Math_fround(0), $3252 = Math_fround(0), $3253 = Math_fround(0), $3254 = Math_fround(0), $3255 = Math_fround(0), $3256 = Math_fround(0), $3257 = Math_fround(0), $3258 = Math_fround(0), $3259 = Math_fround(0), $326 = 0, $3260 = Math_fround(0), $3261 = Math_fround(0), $3262 = Math_fround(0), $3263 = Math_fround(0), $3264 = Math_fround(0), $3265 = Math_fround(0), $3266 = Math_fround(0), $3267 = Math_fround(0), $3268 = Math_fround(0), $3269 = Math_fround(0);
 var $327 = Math_fround(0), $3270 = Math_fround(0), $3271 = Math_fround(0), $3272 = Math_fround(0), $3273 = Math_fround(0), $3274 = Math_fround(0), $3275 = Math_fround(0), $3276 = Math_fround(0), $3277 = Math_fround(0), $3278 = Math_fround(0), $3279 = Math_fround(0), $328 = 0, $3280 = Math_fround(0), $3281 = Math_fround(0), $3282 = Math_fround(0), $3283 = Math_fround(0), $3284 = Math_fround(0), $3285 = Math_fround(0), $3286 = Math_fround(0), $3287 = 0;
 var $3288 = Math_fround(0), $3289 = Math_fround(0), $329 = Math_fround(0), $3290 = Math_fround(0), $3291 = Math_fround(0), $3292 = Math_fround(0), $3293 = Math_fround(0), $3294 = Math_fround(0), $3295 = Math_fround(0), $3296 = Math_fround(0), $3297 = Math_fround(0), $3298 = Math_fround(0), $3299 = Math_fround(0), $33 = 0, $330 = 0, $3300 = Math_fround(0), $3301 = Math_fround(0), $3302 = Math_fround(0), $3303 = Math_fround(0), $3304 = Math_fround(0);
 var $3305 = Math_fround(0), $3306 = Math_fround(0), $3307 = Math_fround(0), $3308 = Math_fround(0), $3309 = Math_fround(0), $331 = Math_fround(0), $3310 = Math_fround(0), $3311 = Math_fround(0), $3312 = Math_fround(0), $3313 = Math_fround(0), $3314 = Math_fround(0), $3315 = Math_fround(0), $3316 = Math_fround(0), $3317 = Math_fround(0), $3318 = Math_fround(0), $3319 = Math_fround(0), $332 = 0, $3320 = Math_fround(0), $3321 = Math_fround(0), $3322 = Math_fround(0);
 var $3323 = Math_fround(0), $3324 = Math_fround(0), $3325 = Math_fround(0), $3326 = Math_fround(0), $3327 = Math_fround(0), $3328 = Math_fround(0), $3329 = Math_fround(0), $333 = Math_fround(0), $3330 = Math_fround(0), $3331 = Math_fround(0), $3332 = Math_fround(0), $3333 = Math_fround(0), $3334 = Math_fround(0), $3335 = Math_fround(0), $3336 = Math_fround(0), $3337 = Math_fround(0), $3338 = Math_fround(0), $3339 = Math_fround(0), $334 = 0, $3340 = Math_fround(0);
 var $3341 = Math_fround(0), $3342 = Math_fround(0), $3343 = Math_fround(0), $3344 = Math_fround(0), $3345 = Math_fround(0), $3346 = Math_fround(0), $3347 = Math_fround(0), $3348 = Math_fround(0), $3349 = Math_fround(0), $335 = Math_fround(0), $3350 = Math_fround(0), $3351 = Math_fround(0), $3352 = Math_fround(0), $3353 = Math_fround(0), $3354 = Math_fround(0), $3355 = Math_fround(0), $3356 = Math_fround(0), $3357 = Math_fround(0), $3358 = Math_fround(0), $3359 = Math_fround(0);
 var $336 = 0, $3360 = Math_fround(0), $3361 = Math_fround(0), $3362 = Math_fround(0), $3363 = Math_fround(0), $3364 = Math_fround(0), $3365 = Math_fround(0), $3366 = Math_fround(0), $3367 = Math_fround(0), $3368 = Math_fround(0), $3369 = Math_fround(0), $337 = Math_fround(0), $3370 = Math_fround(0), $3371 = Math_fround(0), $3372 = Math_fround(0), $3373 = Math_fround(0), $3374 = Math_fround(0), $3375 = Math_fround(0), $3376 = Math_fround(0), $3377 = Math_fround(0);
 var $3378 = Math_fround(0), $3379 = Math_fround(0), $338 = 0, $3380 = Math_fround(0), $3381 = Math_fround(0), $3382 = Math_fround(0), $3383 = 0, $3384 = 0, $3385 = 0, $3386 = 0, $3387 = 0, $3388 = 0, $3389 = 0, $339 = Math_fround(0), $3390 = 0, $3391 = 0, $3392 = 0, $3393 = 0, $3394 = Math_fround(0), $3395 = Math_fround(0);
 var $3396 = 0, $3397 = Math_fround(0), $3398 = Math_fround(0), $3399 = 0, $34 = Math_fround(0), $340 = 0, $3400 = Math_fround(0), $3401 = Math_fround(0), $3402 = 0, $3403 = Math_fround(0), $3404 = Math_fround(0), $3405 = Math_fround(0), $3406 = Math_fround(0), $3407 = Math_fround(0), $3408 = Math_fround(0), $3409 = Math_fround(0), $341 = Math_fround(0), $3410 = Math_fround(0), $3411 = Math_fround(0), $3412 = Math_fround(0);
 var $3413 = Math_fround(0), $3414 = Math_fround(0), $3415 = Math_fround(0), $3416 = Math_fround(0), $3417 = Math_fround(0), $3418 = Math_fround(0), $3419 = Math_fround(0), $342 = 0, $3420 = Math_fround(0), $3421 = Math_fround(0), $3422 = Math_fround(0), $3423 = Math_fround(0), $3424 = Math_fround(0), $3425 = Math_fround(0), $3426 = Math_fround(0), $3427 = Math_fround(0), $3428 = Math_fround(0), $3429 = Math_fround(0), $343 = Math_fround(0), $3430 = Math_fround(0);
 var $3431 = Math_fround(0), $3432 = Math_fround(0), $3433 = Math_fround(0), $3434 = Math_fround(0), $3435 = Math_fround(0), $3436 = Math_fround(0), $3437 = 0, $3438 = Math_fround(0), $3439 = Math_fround(0), $344 = 0, $3440 = 0, $3441 = Math_fround(0), $3442 = Math_fround(0), $3443 = 0, $3444 = Math_fround(0), $3445 = Math_fround(0), $3446 = 0, $3447 = Math_fround(0), $3448 = Math_fround(0), $3449 = Math_fround(0);
 var $345 = Math_fround(0), $3450 = Math_fround(0), $3451 = Math_fround(0), $3452 = Math_fround(0), $3453 = Math_fround(0), $3454 = Math_fround(0), $3455 = Math_fround(0), $3456 = Math_fround(0), $3457 = Math_fround(0), $3458 = Math_fround(0), $3459 = Math_fround(0), $346 = Math_fround(0), $3460 = Math_fround(0), $3461 = Math_fround(0), $3462 = Math_fround(0), $3463 = Math_fround(0), $3464 = Math_fround(0), $3465 = Math_fround(0), $3466 = Math_fround(0), $3467 = Math_fround(0);
 var $3468 = Math_fround(0), $3469 = Math_fround(0), $347 = 0, $3470 = Math_fround(0), $3471 = Math_fround(0), $3472 = Math_fround(0), $3473 = Math_fround(0), $3474 = Math_fround(0), $3475 = Math_fround(0), $3476 = Math_fround(0), $3477 = Math_fround(0), $3478 = Math_fround(0), $3479 = Math_fround(0), $348 = Math_fround(0), $3480 = Math_fround(0), $3481 = Math_fround(0), $3482 = Math_fround(0), $3483 = Math_fround(0), $3484 = Math_fround(0), $3485 = Math_fround(0);
 var $3486 = Math_fround(0), $3487 = Math_fround(0), $3488 = Math_fround(0), $3489 = 0, $349 = 0, $3490 = Math_fround(0), $3491 = Math_fround(0), $3492 = Math_fround(0), $3493 = Math_fround(0), $3494 = Math_fround(0), $3495 = Math_fround(0), $3496 = Math_fround(0), $3497 = Math_fround(0), $3498 = Math_fround(0), $3499 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $3500 = Math_fround(0), $3501 = Math_fround(0), $3502 = Math_fround(0);
 var $3503 = Math_fround(0), $3504 = Math_fround(0), $3505 = Math_fround(0), $3506 = Math_fround(0), $3507 = Math_fround(0), $3508 = Math_fround(0), $3509 = Math_fround(0), $351 = 0, $3510 = Math_fround(0), $3511 = Math_fround(0), $3512 = Math_fround(0), $3513 = Math_fround(0), $3514 = Math_fround(0), $3515 = Math_fround(0), $3516 = Math_fround(0), $3517 = Math_fround(0), $3518 = Math_fround(0), $3519 = Math_fround(0), $352 = Math_fround(0), $3520 = Math_fround(0);
 var $3521 = Math_fround(0), $3522 = Math_fround(0), $3523 = Math_fround(0), $3524 = Math_fround(0), $3525 = Math_fround(0), $3526 = Math_fround(0), $3527 = Math_fround(0), $3528 = Math_fround(0), $3529 = Math_fround(0), $353 = 0, $3530 = Math_fround(0), $3531 = Math_fround(0), $3532 = Math_fround(0), $3533 = Math_fround(0), $3534 = Math_fround(0), $3535 = Math_fround(0), $3536 = Math_fround(0), $3537 = Math_fround(0), $3538 = Math_fround(0), $3539 = Math_fround(0);
 var $354 = Math_fround(0), $3540 = Math_fround(0), $3541 = Math_fround(0), $3542 = Math_fround(0), $3543 = Math_fround(0), $3544 = Math_fround(0), $3545 = Math_fround(0), $3546 = Math_fround(0), $3547 = Math_fround(0), $3548 = Math_fround(0), $3549 = Math_fround(0), $355 = 0, $3550 = Math_fround(0), $3551 = Math_fround(0), $3552 = Math_fround(0), $3553 = Math_fround(0), $3554 = Math_fround(0), $3555 = Math_fround(0), $3556 = Math_fround(0), $3557 = Math_fround(0);
 var $3558 = Math_fround(0), $3559 = Math_fround(0), $356 = Math_fround(0), $3560 = Math_fround(0), $3561 = Math_fround(0), $3562 = Math_fround(0), $3563 = Math_fround(0), $3564 = Math_fround(0), $3565 = Math_fround(0), $3566 = Math_fround(0), $3567 = Math_fround(0), $3568 = Math_fround(0), $3569 = Math_fround(0), $357 = 0, $3570 = Math_fround(0), $3571 = Math_fround(0), $3572 = 0, $3573 = Math_fround(0), $3574 = Math_fround(0), $3575 = Math_fround(0);
 var $3576 = Math_fround(0), $3577 = Math_fround(0), $3578 = Math_fround(0), $3579 = Math_fround(0), $358 = Math_fround(0), $3580 = Math_fround(0), $3581 = Math_fround(0), $3582 = Math_fround(0), $3583 = Math_fround(0), $3584 = Math_fround(0), $3585 = Math_fround(0), $3586 = Math_fround(0), $3587 = Math_fround(0), $3588 = Math_fround(0), $3589 = Math_fround(0), $359 = 0, $3590 = Math_fround(0), $3591 = Math_fround(0), $3592 = Math_fround(0), $3593 = Math_fround(0);
 var $3594 = Math_fround(0), $3595 = Math_fround(0), $3596 = Math_fround(0), $3597 = Math_fround(0), $3598 = Math_fround(0), $3599 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $3600 = Math_fround(0), $3601 = Math_fround(0), $3602 = Math_fround(0), $3603 = Math_fround(0), $3604 = Math_fround(0), $3605 = Math_fround(0), $3606 = Math_fround(0), $3607 = Math_fround(0), $3608 = Math_fround(0), $3609 = Math_fround(0), $361 = 0, $3610 = Math_fround(0);
 var $3611 = Math_fround(0), $3612 = Math_fround(0), $3613 = Math_fround(0), $3614 = Math_fround(0), $3615 = Math_fround(0), $3616 = Math_fround(0), $3617 = Math_fround(0), $3618 = Math_fround(0), $3619 = Math_fround(0), $362 = Math_fround(0), $3620 = Math_fround(0), $3621 = Math_fround(0), $3622 = Math_fround(0), $3623 = Math_fround(0), $3624 = Math_fround(0), $3625 = Math_fround(0), $3626 = Math_fround(0), $3627 = Math_fround(0), $3628 = Math_fround(0), $3629 = Math_fround(0);
 var $363 = 0, $3630 = Math_fround(0), $3631 = Math_fround(0), $3632 = Math_fround(0), $3633 = Math_fround(0), $3634 = Math_fround(0), $3635 = Math_fround(0), $3636 = Math_fround(0), $3637 = Math_fround(0), $3638 = Math_fround(0), $3639 = Math_fround(0), $364 = Math_fround(0), $3640 = Math_fround(0), $3641 = Math_fround(0), $3642 = Math_fround(0), $3643 = Math_fround(0), $3644 = Math_fround(0), $3645 = Math_fround(0), $3646 = Math_fround(0), $3647 = Math_fround(0);
 var $3648 = Math_fround(0), $3649 = Math_fround(0), $365 = 0, $3650 = Math_fround(0), $3651 = Math_fround(0), $3652 = Math_fround(0), $3653 = 0, $3654 = Math_fround(0), $3655 = Math_fround(0), $3656 = Math_fround(0), $3657 = Math_fround(0), $3658 = Math_fround(0), $3659 = Math_fround(0), $366 = Math_fround(0), $3660 = Math_fround(0), $3661 = Math_fround(0), $3662 = 0, $3663 = 0, $3664 = 0, $3665 = Math_fround(0);
 var $3666 = 0, $3667 = 0, $3668 = 0, $3669 = Math_fround(0), $367 = 0, $3670 = Math_fround(0), $3671 = Math_fround(0), $3672 = Math_fround(0), $3673 = 0, $3674 = 0, $3675 = 0, $3676 = Math_fround(0), $3677 = Math_fround(0), $3678 = Math_fround(0), $3679 = Math_fround(0), $368 = Math_fround(0), $3680 = Math_fround(0), $3681 = Math_fround(0), $3682 = Math_fround(0), $3683 = Math_fround(0);
 var $3684 = Math_fround(0), $3685 = Math_fround(0), $3686 = Math_fround(0), $3687 = Math_fround(0), $3688 = Math_fround(0), $3689 = Math_fround(0), $369 = 0, $3690 = 0, $3691 = Math_fround(0), $3692 = Math_fround(0), $3693 = Math_fround(0), $3694 = Math_fround(0), $3695 = Math_fround(0), $3696 = Math_fround(0), $3697 = Math_fround(0), $3698 = Math_fround(0), $3699 = Math_fround(0), $37 = Math_fround(0), $370 = Math_fround(0), $3700 = Math_fround(0);
 var $3701 = Math_fround(0), $3702 = Math_fround(0), $3703 = Math_fround(0), $3704 = Math_fround(0), $3705 = Math_fround(0), $3706 = Math_fround(0), $3707 = Math_fround(0), $3708 = Math_fround(0), $3709 = Math_fround(0), $371 = 0, $3710 = Math_fround(0), $3711 = Math_fround(0), $3712 = Math_fround(0), $3713 = Math_fround(0), $3714 = Math_fround(0), $3715 = Math_fround(0), $3716 = Math_fround(0), $3717 = Math_fround(0), $3718 = Math_fround(0), $3719 = Math_fround(0);
 var $372 = Math_fround(0), $3720 = Math_fround(0), $3721 = Math_fround(0), $3722 = Math_fround(0), $3723 = Math_fround(0), $3724 = Math_fround(0), $3725 = Math_fround(0), $3726 = Math_fround(0), $3727 = Math_fround(0), $3728 = Math_fround(0), $3729 = Math_fround(0), $373 = Math_fround(0), $3730 = Math_fround(0), $3731 = Math_fround(0), $3732 = Math_fround(0), $3733 = Math_fround(0), $3734 = Math_fround(0), $3735 = Math_fround(0), $3736 = Math_fround(0), $3737 = Math_fround(0);
 var $3738 = Math_fround(0), $3739 = Math_fround(0), $374 = 0, $3740 = Math_fround(0), $3741 = Math_fround(0), $3742 = Math_fround(0), $3743 = Math_fround(0), $3744 = Math_fround(0), $3745 = Math_fround(0), $3746 = Math_fround(0), $3747 = Math_fround(0), $3748 = Math_fround(0), $3749 = Math_fround(0), $375 = Math_fround(0), $3750 = Math_fround(0), $3751 = Math_fround(0), $3752 = Math_fround(0), $3753 = Math_fround(0), $3754 = Math_fround(0), $3755 = Math_fround(0);
 var $3756 = Math_fround(0), $3757 = Math_fround(0), $3758 = Math_fround(0), $3759 = Math_fround(0), $376 = Math_fround(0), $3760 = Math_fround(0), $3761 = Math_fround(0), $3762 = Math_fround(0), $3763 = Math_fround(0), $3764 = Math_fround(0), $3765 = Math_fround(0), $3766 = Math_fround(0), $3767 = Math_fround(0), $3768 = Math_fround(0), $3769 = Math_fround(0), $377 = 0, $3770 = Math_fround(0), $3771 = Math_fround(0), $3772 = Math_fround(0), $3773 = Math_fround(0);
 var $3774 = Math_fround(0), $3775 = Math_fround(0), $3776 = Math_fround(0), $3777 = Math_fround(0), $3778 = Math_fround(0), $3779 = 0, $378 = Math_fround(0), $3780 = 0, $3781 = 0, $3782 = 0, $3783 = 0, $3784 = 0, $3785 = 0, $3786 = 0, $3787 = 0, $3788 = 0, $3789 = 0, $379 = Math_fround(0), $3790 = Math_fround(0), $3791 = Math_fround(0);
 var $3792 = Math_fround(0), $3793 = Math_fround(0), $3794 = Math_fround(0), $3795 = Math_fround(0), $3796 = Math_fround(0), $3797 = Math_fround(0), $3798 = Math_fround(0), $3799 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $3800 = Math_fround(0), $3801 = Math_fround(0), $3802 = Math_fround(0), $3803 = Math_fround(0), $3804 = Math_fround(0), $3805 = Math_fround(0), $3806 = Math_fround(0), $3807 = Math_fround(0), $3808 = Math_fround(0), $3809 = Math_fround(0);
 var $381 = Math_fround(0), $3810 = Math_fround(0), $3811 = Math_fround(0), $3812 = Math_fround(0), $3813 = Math_fround(0), $3814 = Math_fround(0), $3815 = Math_fround(0), $3816 = Math_fround(0), $3817 = Math_fround(0), $3818 = Math_fround(0), $3819 = Math_fround(0), $382 = Math_fround(0), $3820 = Math_fround(0), $3821 = Math_fround(0), $3822 = Math_fround(0), $3823 = Math_fround(0), $3824 = 0, $3825 = Math_fround(0), $3826 = Math_fround(0), $3827 = 0;
 var $3828 = Math_fround(0), $3829 = Math_fround(0), $383 = Math_fround(0), $3830 = Math_fround(0), $3831 = Math_fround(0), $3832 = Math_fround(0), $3833 = Math_fround(0), $3834 = Math_fround(0), $3835 = Math_fround(0), $3836 = Math_fround(0), $3837 = Math_fround(0), $3838 = Math_fround(0), $3839 = Math_fround(0), $384 = Math_fround(0), $3840 = Math_fround(0), $3841 = Math_fround(0), $3842 = Math_fround(0), $3843 = Math_fround(0), $3844 = Math_fround(0), $3845 = Math_fround(0);
 var $3846 = Math_fround(0), $3847 = Math_fround(0), $3848 = Math_fround(0), $3849 = Math_fround(0), $385 = Math_fround(0), $3850 = Math_fround(0), $3851 = Math_fround(0), $3852 = Math_fround(0), $3853 = Math_fround(0), $3854 = Math_fround(0), $3855 = Math_fround(0), $3856 = Math_fround(0), $3857 = Math_fround(0), $3858 = Math_fround(0), $3859 = Math_fround(0), $386 = Math_fround(0), $3860 = Math_fround(0), $3861 = Math_fround(0), $3862 = Math_fround(0), $3863 = Math_fround(0);
 var $3864 = Math_fround(0), $3865 = Math_fround(0), $3866 = Math_fround(0), $3867 = Math_fround(0), $3868 = Math_fround(0), $3869 = Math_fround(0), $387 = Math_fround(0), $3870 = Math_fround(0), $3871 = Math_fround(0), $3872 = Math_fround(0), $3873 = Math_fround(0), $3874 = Math_fround(0), $3875 = Math_fround(0), $3876 = Math_fround(0), $3877 = Math_fround(0), $3878 = Math_fround(0), $3879 = Math_fround(0), $388 = Math_fround(0), $3880 = Math_fround(0), $3881 = Math_fround(0);
 var $3882 = Math_fround(0), $3883 = Math_fround(0), $3884 = Math_fround(0), $3885 = Math_fround(0), $3886 = Math_fround(0), $3887 = Math_fround(0), $3888 = Math_fround(0), $3889 = Math_fround(0), $389 = Math_fround(0), $3890 = Math_fround(0), $3891 = Math_fround(0), $3892 = Math_fround(0), $3893 = Math_fround(0), $3894 = Math_fround(0), $3895 = Math_fround(0), $3896 = Math_fround(0), $3897 = Math_fround(0), $3898 = Math_fround(0), $3899 = Math_fround(0), $39 = Math_fround(0);
 var $390 = Math_fround(0), $3900 = 0, $3901 = 0, $3902 = Math_fround(0), $3903 = Math_fround(0), $3904 = Math_fround(0), $3905 = Math_fround(0), $3906 = Math_fround(0), $3907 = Math_fround(0), $3908 = 0, $3909 = Math_fround(0), $391 = Math_fround(0), $3910 = 0, $3911 = Math_fround(0), $3912 = 0, $3913 = Math_fround(0), $3914 = 0, $3915 = Math_fround(0), $3916 = Math_fround(0), $3917 = Math_fround(0);
 var $3918 = Math_fround(0), $3919 = Math_fround(0), $392 = Math_fround(0), $3920 = 0, $3921 = Math_fround(0), $3922 = Math_fround(0), $3923 = Math_fround(0), $3924 = Math_fround(0), $3925 = Math_fround(0), $3926 = Math_fround(0), $3927 = Math_fround(0), $3928 = Math_fround(0), $3929 = Math_fround(0), $393 = Math_fround(0), $3930 = Math_fround(0), $3931 = Math_fround(0), $3932 = Math_fround(0), $3933 = Math_fround(0), $3934 = Math_fround(0), $3935 = Math_fround(0);
 var $3936 = Math_fround(0), $3937 = Math_fround(0), $3938 = Math_fround(0), $3939 = Math_fround(0), $394 = Math_fround(0), $3940 = Math_fround(0), $3941 = Math_fround(0), $3942 = Math_fround(0), $3943 = Math_fround(0), $3944 = Math_fround(0), $3945 = Math_fround(0), $3946 = Math_fround(0), $3947 = Math_fround(0), $3948 = Math_fround(0), $3949 = Math_fround(0), $395 = Math_fround(0), $3950 = Math_fround(0), $3951 = Math_fround(0), $3952 = Math_fround(0), $3953 = Math_fround(0);
 var $3954 = Math_fround(0), $3955 = Math_fround(0), $3956 = Math_fround(0), $3957 = Math_fround(0), $3958 = Math_fround(0), $3959 = Math_fround(0), $396 = Math_fround(0), $3960 = Math_fround(0), $3961 = Math_fround(0), $3962 = Math_fround(0), $3963 = 0, $3964 = Math_fround(0), $3965 = 0, $3966 = Math_fround(0), $3967 = 0, $3968 = Math_fround(0), $3969 = 0, $397 = Math_fround(0), $3970 = Math_fround(0), $3971 = 0;
 var $3972 = Math_fround(0), $3973 = 0, $3974 = Math_fround(0), $3975 = 0, $3976 = Math_fround(0), $3977 = 0, $3978 = Math_fround(0), $3979 = 0, $398 = Math_fround(0), $3980 = Math_fround(0), $3981 = 0, $3982 = Math_fround(0), $3983 = 0, $3984 = Math_fround(0), $3985 = 0, $3986 = Math_fround(0), $3987 = 0, $3988 = 0, $3989 = Math_fround(0), $399 = Math_fround(0);
 var $3990 = 0, $3991 = Math_fround(0), $3992 = 0, $3993 = Math_fround(0), $3994 = 0, $3995 = Math_fround(0), $3996 = 0, $3997 = Math_fround(0), $3998 = 0, $3999 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $4000 = 0, $4001 = Math_fround(0), $4002 = 0, $4003 = Math_fround(0), $4004 = 0, $4005 = Math_fround(0), $4006 = 0;
 var $4007 = Math_fround(0), $4008 = 0, $4009 = Math_fround(0), $401 = Math_fround(0), $4010 = 0, $4011 = Math_fround(0), $4012 = 0, $4013 = 0, $4014 = 0, $4015 = 0, $4016 = 0, $4017 = 0, $4018 = 0, $4019 = 0, $402 = Math_fround(0), $4020 = 0, $4021 = Math_fround(0), $4022 = 0, $4023 = Math_fround(0), $4024 = 0;
 var $4025 = Math_fround(0), $4026 = 0, $4027 = Math_fround(0), $4028 = Math_fround(0), $4029 = 0, $403 = Math_fround(0), $4030 = Math_fround(0), $4031 = Math_fround(0), $4032 = Math_fround(0), $4033 = Math_fround(0), $4034 = Math_fround(0), $4035 = Math_fround(0), $4036 = Math_fround(0), $4037 = Math_fround(0), $4038 = Math_fround(0), $4039 = Math_fround(0), $404 = Math_fround(0), $4040 = Math_fround(0), $4041 = Math_fround(0), $4042 = Math_fround(0);
 var $4043 = Math_fround(0), $4044 = Math_fround(0), $4045 = Math_fround(0), $4046 = Math_fround(0), $4047 = Math_fround(0), $4048 = 0, $4049 = Math_fround(0), $405 = Math_fround(0), $4050 = Math_fround(0), $4051 = Math_fround(0), $4052 = Math_fround(0), $4053 = 0, $4054 = 0, $4055 = 0, $4056 = 0, $4057 = Math_fround(0), $4058 = Math_fround(0), $4059 = Math_fround(0), $406 = Math_fround(0), $4060 = Math_fround(0);
 var $4061 = Math_fround(0), $4062 = Math_fround(0), $4063 = Math_fround(0), $4064 = Math_fround(0), $4065 = Math_fround(0), $4066 = Math_fround(0), $4067 = Math_fround(0), $4068 = Math_fround(0), $4069 = Math_fround(0), $407 = Math_fround(0), $4070 = Math_fround(0), $4071 = Math_fround(0), $4072 = Math_fround(0), $4073 = Math_fround(0), $4074 = Math_fround(0), $4075 = Math_fround(0), $4076 = Math_fround(0), $4077 = Math_fround(0), $4078 = Math_fround(0), $4079 = Math_fround(0);
 var $408 = Math_fround(0), $4080 = Math_fround(0), $4081 = Math_fround(0), $4082 = Math_fround(0), $4083 = Math_fround(0), $4084 = Math_fround(0), $4085 = Math_fround(0), $4086 = 0, $4087 = Math_fround(0), $4088 = Math_fround(0), $4089 = Math_fround(0), $409 = Math_fround(0), $4090 = Math_fround(0), $4091 = Math_fround(0), $4092 = Math_fround(0), $4093 = Math_fround(0), $4094 = Math_fround(0), $4095 = Math_fround(0), $4096 = Math_fround(0), $4097 = Math_fround(0);
 var $4098 = 0, $4099 = 0, $41 = 0, $410 = Math_fround(0), $4100 = 0, $4101 = 0, $4102 = 0, $4103 = 0, $4104 = Math_fround(0), $4105 = Math_fround(0), $4106 = Math_fround(0), $4107 = Math_fround(0), $4108 = Math_fround(0), $4109 = Math_fround(0), $411 = Math_fround(0), $4110 = Math_fround(0), $4111 = Math_fround(0), $4112 = Math_fround(0), $4113 = Math_fround(0), $4114 = Math_fround(0);
 var $4115 = Math_fround(0), $4116 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0);
 var $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0, $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0);
 var $465 = 0, $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = 0, $47 = 0, $470 = Math_fround(0), $471 = 0, $472 = Math_fround(0), $473 = 0, $474 = Math_fround(0), $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = Math_fround(0);
 var $483 = 0, $484 = Math_fround(0), $485 = Math_fround(0), $486 = 0, $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0, $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0);
 var $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0);
 var $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0);
 var $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0);
 var $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0);
 var $573 = 0, $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = 0, $578 = Math_fround(0), $579 = 0, $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = 0, $584 = Math_fround(0), $585 = 0, $586 = Math_fround(0), $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0;
 var $591 = 0, $592 = 0, $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0);
 var $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0);
 var $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = Math_fround(0), $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0);
 var $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0);
 var $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = Math_fround(0), $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0);
 var $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0);
 var $7 = 0, $70 = Math_fround(0), $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0);
 var $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = Math_fround(0), $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0);
 var $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0);
 var $753 = Math_fround(0), $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0);
 var $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = Math_fround(0), $786 = 0, $787 = 0, $788 = 0, $789 = Math_fround(0);
 var $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = Math_fround(0), $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0;
 var $807 = 0, $808 = Math_fround(0), $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = Math_fround(0), $819 = 0, $82 = Math_fround(0), $820 = Math_fround(0), $821 = 0, $822 = Math_fround(0), $823 = 0, $824 = Math_fround(0);
 var $825 = 0, $826 = 0, $827 = 0, $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = 0, $831 = Math_fround(0), $832 = 0, $833 = Math_fround(0), $834 = 0, $835 = Math_fround(0), $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = Math_fround(0), $840 = Math_fround(0), $841 = 0, $842 = Math_fround(0);
 var $843 = 0, $844 = Math_fround(0), $845 = 0, $846 = Math_fround(0), $847 = 0, $848 = 0, $849 = 0, $85 = Math_fround(0), $850 = 0, $851 = 0, $852 = Math_fround(0), $853 = 0, $854 = Math_fround(0), $855 = 0, $856 = Math_fround(0), $857 = 0, $858 = Math_fround(0), $859 = 0, $86 = 0, $860 = 0;
 var $861 = 0, $862 = 0, $863 = Math_fround(0), $864 = 0, $865 = Math_fround(0), $866 = 0, $867 = Math_fround(0), $868 = 0, $869 = Math_fround(0), $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = Math_fround(0), $875 = 0, $876 = Math_fround(0), $877 = 0, $878 = Math_fround(0), $879 = Math_fround(0);
 var $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0;
 var $898 = Math_fround(0), $899 = 0, $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = 0, $903 = 0, $904 = Math_fround(0), $905 = 0, $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = 0, $912 = 0, $913 = 0, $914 = 0;
 var $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = 0, $925 = Math_fround(0), $926 = 0, $927 = Math_fround(0), $928 = 0, $929 = Math_fround(0), $93 = 0, $930 = 0, $931 = Math_fround(0), $932 = 0;
 var $933 = Math_fround(0), $934 = 0, $935 = Math_fround(0), $936 = 0, $937 = Math_fround(0), $938 = 0, $939 = Math_fround(0), $94 = 0, $940 = 0, $941 = Math_fround(0), $942 = 0, $943 = Math_fround(0), $944 = 0, $945 = Math_fround(0), $946 = 0, $947 = Math_fround(0), $948 = 0, $949 = Math_fround(0), $95 = 0, $950 = Math_fround(0);
 var $951 = 0, $952 = Math_fround(0), $953 = 0, $954 = Math_fround(0), $955 = 0, $956 = Math_fround(0), $957 = 0, $958 = Math_fround(0), $959 = 0, $96 = 0, $960 = Math_fround(0), $961 = 0, $962 = Math_fround(0), $963 = 0, $964 = Math_fround(0), $965 = 0, $966 = Math_fround(0), $967 = 0, $968 = Math_fround(0), $969 = 0;
 var $97 = 0, $970 = Math_fround(0), $971 = 0, $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0);
 var $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0, $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $clipIn$i = 0, $currentTimeInt = 0, $exitcond = 0, $i$0696 = 0, $i1$0695 = 0, $not$ = 0, $prevLeftFootX = 0;
 var $prevRightFootX = 0, $prevRootX = 0, $prevTimeInt = 0, $refLeftFootPrevX = 0, $refLeftFootStartX = 0, $refLeftFootX = 0, $refRightFootPrevX = 0, $refRightFootStartX = 0, $refRightFootX = 0, $refStartX = 0, $refStopX = 0, $rootX = 0, $stopX = 0, $targetGoalIndex$0 = 0, $targetGoalX = 0, $targetRefX = 0, $targetTime$0 = Math_fround(0), $targetTimeInt = 0, $value$sroa$0$0$i = Math_fround(0), $value$sroa$0$0$i27 = Math_fround(0);
 var $value$sroa$1$0$i = Math_fround(0), $value$sroa$1$0$i28 = Math_fround(0), $value$sroa$2$0$i = Math_fround(0), $value$sroa$2$0$i29 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3200|0;
 $clipIn$i = sp + 3152|0;
 $prevTimeInt = sp + 3148|0;
 $currentTimeInt = sp + 3144|0;
 $stopX = sp + 3096|0;
 $prevRootX = sp + 3048|0;
 $prevLeftFootX = sp + 3000|0;
 $prevRightFootX = sp + 2952|0;
 $rootX = sp + 2904|0;
 $refStartX = sp + 2856|0;
 $refStopX = sp + 2808|0;
 $0 = sp + 2760|0;
 $1 = sp + 2712|0;
 $2 = sp + 2664|0;
 $3 = sp + 2616|0;
 $4 = sp + 2568|0;
 $5 = sp + 2520|0;
 $6 = sp + 2472|0;
 $targetRefX = sp + 2424|0;
 $targetGoalX = sp + 2376|0;
 $targetTimeInt = sp + 2368|0;
 $7 = sp + 2320|0;
 $8 = sp + 2272|0;
 $9 = sp + 2224|0;
 $10 = sp + 2176|0;
 $11 = sp + 2128|0;
 $12 = sp + 2080|0;
 $13 = sp + 2032|0;
 $refLeftFootStartX = sp + 528|0;
 $refRightFootStartX = sp + 480|0;
 $refLeftFootPrevX = sp + 432|0;
 $refRightFootPrevX = sp + 384|0;
 $refLeftFootX = sp + 336|0;
 $refRightFootX = sp + 288|0;
 $14 = sp + 240|0;
 $15 = sp + 144|0;
 $16 = sp + 96|0;
 $17 = sp + 48|0;
 $18 = sp;
 $19 = sp + 192|0;
 $20 = sp + 1408|0;
 $21 = sp + 1456|0;
 $22 = sp + 1504|0;
 $23 = sp + 1552|0;
 $24 = sp + 1600|0;
 $25 = sp + 1648|0;
 $26 = sp + 1696|0;
 $27 = sp + 1744|0;
 $28 = sp + 1792|0;
 $29 = sp + 1840|0;
 $30 = sp + 1888|0;
 $31 = sp + 1936|0;
 $32 = sp + 1984|0;
 $33 = (($constant) + 1064|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($input) + 24|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($34 + $36);
 $38 = (($input) + 4|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($constant) + 1048|0);
 $41 = (($constant) + 1052|0);
 $42 = (($constant) + 1633|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)!=(0);
 $45 = (($input) + 16|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = $46 < Math_fround(0.0);
 $48 = (Math_fround(+(_fmaxf(0.0,(+$39)))));
 $49 = (Math_fround(+(_fminf(1.0,(+$48)))));
 $50 = Math_fround($39 + $37);
 $51 = (Math_fround(+(_modff((+$50),($prevTimeInt|0)))));
 $$v$i = $44 ? $51 : $49;
 $52 = Math_fround(Math_fround(1.0) - $$v$i);
 $53 = $47&1;
 $54 = $53 ^ 1;
 $55 = (0 - ($54))|0;
 $56 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
 $57 = (HEAPF32[tempDoublePtr>>2]=$$v$i,HEAP32[tempDoublePtr>>2]|0);
 $58 = $47 ? $56 : 0;
 $59 = $57 & $55;
 $60 = $58 | $59;
 $61 = (HEAP32[tempDoublePtr>>2]=$60,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $62 = Math_fround(HEAPF32[$input>>2]);
 $63 = Math_fround(HEAPF32[$40>>2]);
 $64 = Math_fround(HEAPF32[$41>>2]);
 $65 = HEAP8[$42>>0]|0;
 $66 = ($65<<24>>24)!=(0);
 $67 = Math_fround(HEAPF32[$45>>2]);
 $68 = $67 < Math_fround(0.0);
 $69 = (Math_fround(+(_fmaxf(0.0,(+$62)))));
 $70 = (Math_fround(+(_fminf(1.0,(+$69)))));
 $71 = Math_fround($37 + $62);
 $72 = (Math_fround(+(_modff((+$71),($currentTimeInt|0)))));
 $$v$i7 = $66 ? $72 : $70;
 $73 = Math_fround(Math_fround(1.0) - $$v$i7);
 $74 = $68&1;
 $75 = $74 ^ 1;
 $76 = (0 - ($75))|0;
 $77 = (HEAPF32[tempDoublePtr>>2]=$73,HEAP32[tempDoublePtr>>2]|0);
 $78 = (HEAPF32[tempDoublePtr>>2]=$$v$i7,HEAP32[tempDoublePtr>>2]|0);
 $79 = $68 ? $77 : 0;
 $80 = $78 & $76;
 $81 = $79 | $80;
 $82 = (HEAP32[tempDoublePtr>>2]=$81,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $83 = Math_fround($64 - $63);
 $84 = Math_fround($83 * $82);
 $85 = Math_fround($63 + $84);
 $86 = (($constant) + 1072|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(-1);
 if ($88) {
  $89 = (($constant) + 1076|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($90|0)==(-1);
  if ($91) {
   $92 = (($constant) + 1080|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(-1);
   if ($94) {
    $95 = (($constant) + 1084|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ($96|0)==(-1);
    if ($97) {
     $98 = (($constant) + 1088|0);
     $99 = HEAP32[$98>>2]|0;
     $100 = ($99|0)==(-1);
     if ($100) {
      $101 = (($constant) + 1092|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = ($102|0)==(-1);
      if ($103) {
       $104 = (($constant) + 1096|0);
       $105 = HEAP32[$104>>2]|0;
       $106 = ($105|0)!=(-1);
       $4102 = $106;
      } else {
       $4102 = 1;
      }
     } else {
      $4102 = 1;
     }
    } else {
     $4102 = 1;
    }
   } else {
    $4102 = 1;
   }
  } else {
   $4102 = 1;
  }
 } else {
  $4102 = 1;
 }
 $107 = (($constant) + 1608|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108|0)==(-1);
 if ($109) {
  $110 = (($constant) + 1612|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($111|0)==(-1);
  if ($112) {
   $113 = (($constant) + 1616|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)!=(-1);
   $4103 = $115;
  } else {
   $4103 = 1;
  }
 } else {
  $4103 = 1;
 }
 $116 = (($constant) + 1632|0);
 $117 = HEAP8[$116>>0]|0;
 $118 = ($117<<24>>24)==(0);
 $119 = (($input) + 20|0);
 $120 = HEAP8[$119>>0]|0;
 $121 = ($120<<24>>24)==(0);
 if ($118) {
  $not$ = $121 ^ 1;
  $$off0 = $not$;
 } else {
  $$off0 = $121;
 }
 $122 = (($constant) + 880|0);
 __ZN4mathL11xformMulInvERKNS_5xformES2_($stopX,$122,$constant);
 $123 = (($motionOutput) + 228|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($motionOutput) + 232|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($motionOutput) + 236|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($motionOutput) + 240|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 HEAPF32[$prevRootX>>2] = $124;
 $131 = (($prevRootX) + 4|0);
 HEAPF32[$131>>2] = $126;
 $132 = (($prevRootX) + 8|0);
 HEAPF32[$132>>2] = $128;
 $133 = (($prevRootX) + 12|0);
 HEAPF32[$133>>2] = $130;
 $134 = (($motionOutput) + 244|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = (($motionOutput) + 248|0);
 $137 = Math_fround(HEAPF32[$136>>2]);
 $138 = (($motionOutput) + 252|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = (($motionOutput) + 256|0);
 $141 = Math_fround(HEAPF32[$140>>2]);
 $142 = (($prevRootX) + 16|0);
 HEAPF32[$142>>2] = $135;
 $143 = (($prevRootX) + 20|0);
 HEAPF32[$143>>2] = $137;
 $144 = (($prevRootX) + 24|0);
 HEAPF32[$144>>2] = $139;
 $145 = (($prevRootX) + 28|0);
 HEAPF32[$145>>2] = $141;
 $146 = (($motionOutput) + 260|0);
 $147 = Math_fround(HEAPF32[$146>>2]);
 $148 = (($motionOutput) + 264|0);
 $149 = Math_fround(HEAPF32[$148>>2]);
 $150 = (($motionOutput) + 268|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = (($motionOutput) + 272|0);
 $153 = Math_fround(HEAPF32[$152>>2]);
 $154 = (($prevRootX) + 32|0);
 HEAPF32[$154>>2] = $147;
 $155 = (($prevRootX) + 36|0);
 HEAPF32[$155>>2] = $149;
 $156 = (($prevRootX) + 40|0);
 HEAPF32[$156>>2] = $151;
 $157 = (($prevRootX) + 44|0);
 HEAPF32[$157>>2] = $153;
 $158 = (($motionOutput) + 276|0);
 $159 = Math_fround(HEAPF32[$158>>2]);
 $160 = (($motionOutput) + 280|0);
 $161 = Math_fround(HEAPF32[$160>>2]);
 $162 = (($motionOutput) + 284|0);
 $163 = Math_fround(HEAPF32[$162>>2]);
 $164 = (($motionOutput) + 288|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 HEAPF32[$prevLeftFootX>>2] = $159;
 $166 = (($prevLeftFootX) + 4|0);
 HEAPF32[$166>>2] = $161;
 $167 = (($prevLeftFootX) + 8|0);
 HEAPF32[$167>>2] = $163;
 $168 = (($prevLeftFootX) + 12|0);
 HEAPF32[$168>>2] = $165;
 $169 = (($motionOutput) + 292|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = (($motionOutput) + 296|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = (($motionOutput) + 300|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($motionOutput) + 304|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = (($prevLeftFootX) + 16|0);
 HEAPF32[$177>>2] = $170;
 $178 = (($prevLeftFootX) + 20|0);
 HEAPF32[$178>>2] = $172;
 $179 = (($prevLeftFootX) + 24|0);
 HEAPF32[$179>>2] = $174;
 $180 = (($prevLeftFootX) + 28|0);
 HEAPF32[$180>>2] = $176;
 $181 = (($motionOutput) + 308|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = (($motionOutput) + 312|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = (($motionOutput) + 316|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($motionOutput) + 320|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 $189 = (($prevLeftFootX) + 32|0);
 HEAPF32[$189>>2] = $182;
 $190 = (($prevLeftFootX) + 36|0);
 HEAPF32[$190>>2] = $184;
 $191 = (($prevLeftFootX) + 40|0);
 HEAPF32[$191>>2] = $186;
 $192 = (($prevLeftFootX) + 44|0);
 HEAPF32[$192>>2] = $188;
 $193 = (($motionOutput) + 324|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($motionOutput) + 328|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($motionOutput) + 332|0);
 $198 = Math_fround(HEAPF32[$197>>2]);
 $199 = (($motionOutput) + 336|0);
 $200 = Math_fround(HEAPF32[$199>>2]);
 HEAPF32[$prevRightFootX>>2] = $194;
 $201 = (($prevRightFootX) + 4|0);
 HEAPF32[$201>>2] = $196;
 $202 = (($prevRightFootX) + 8|0);
 HEAPF32[$202>>2] = $198;
 $203 = (($prevRightFootX) + 12|0);
 HEAPF32[$203>>2] = $200;
 $204 = (($motionOutput) + 340|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = (($motionOutput) + 344|0);
 $207 = Math_fround(HEAPF32[$206>>2]);
 $208 = (($motionOutput) + 348|0);
 $209 = Math_fround(HEAPF32[$208>>2]);
 $210 = (($motionOutput) + 352|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = (($prevRightFootX) + 16|0);
 HEAPF32[$212>>2] = $205;
 $213 = (($prevRightFootX) + 20|0);
 HEAPF32[$213>>2] = $207;
 $214 = (($prevRightFootX) + 24|0);
 HEAPF32[$214>>2] = $209;
 $215 = (($prevRightFootX) + 28|0);
 HEAPF32[$215>>2] = $211;
 $216 = (($motionOutput) + 356|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = (($motionOutput) + 360|0);
 $219 = Math_fround(HEAPF32[$218>>2]);
 $220 = (($motionOutput) + 364|0);
 $221 = Math_fround(HEAPF32[$220>>2]);
 $222 = (($motionOutput) + 368|0);
 $223 = Math_fround(HEAPF32[$222>>2]);
 $224 = (($prevRightFootX) + 32|0);
 HEAPF32[$224>>2] = $217;
 $225 = (($prevRightFootX) + 36|0);
 HEAPF32[$225>>2] = $219;
 $226 = (($prevRightFootX) + 40|0);
 HEAPF32[$226>>2] = $221;
 $227 = (($prevRightFootX) + 44|0);
 HEAPF32[$227>>2] = $223;
 __ZN7mecanim9animation12GetHumanPoseIfEEvRKNS0_18ClipMuscleConstantEPKT_RNS_5human9HumanPoseE($constant,$valuesOutput,$humanPose);
 $228 = Math_fround(HEAPF32[$humanPose>>2]);
 $229 = (($humanPose) + 4|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = (($humanPose) + 8|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = (($humanPose) + 12|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 HEAPF32[$rootX>>2] = $228;
 $235 = (($rootX) + 4|0);
 HEAPF32[$235>>2] = $230;
 $236 = (($rootX) + 8|0);
 HEAPF32[$236>>2] = $232;
 $237 = (($rootX) + 12|0);
 HEAPF32[$237>>2] = $234;
 $238 = (($humanPose) + 16|0);
 $239 = Math_fround(HEAPF32[$238>>2]);
 $240 = (($humanPose) + 20|0);
 $241 = Math_fround(HEAPF32[$240>>2]);
 $242 = (($humanPose) + 24|0);
 $243 = Math_fround(HEAPF32[$242>>2]);
 $244 = (($humanPose) + 28|0);
 $245 = Math_fround(HEAPF32[$244>>2]);
 $246 = (($rootX) + 16|0);
 HEAPF32[$246>>2] = $239;
 $247 = (($rootX) + 20|0);
 HEAPF32[$247>>2] = $241;
 $248 = (($rootX) + 24|0);
 HEAPF32[$248>>2] = $243;
 $249 = (($rootX) + 28|0);
 HEAPF32[$249>>2] = $245;
 $250 = (($humanPose) + 32|0);
 $251 = Math_fround(HEAPF32[$250>>2]);
 $252 = (($humanPose) + 36|0);
 $253 = Math_fround(HEAPF32[$252>>2]);
 $254 = (($humanPose) + 40|0);
 $255 = Math_fround(HEAPF32[$254>>2]);
 $256 = (($humanPose) + 44|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = (($rootX) + 32|0);
 HEAPF32[$258>>2] = $251;
 $259 = (($rootX) + 36|0);
 HEAPF32[$259>>2] = $253;
 $260 = (($rootX) + 40|0);
 HEAPF32[$260>>2] = $255;
 $261 = (($rootX) + 44|0);
 HEAPF32[$261>>2] = $257;
 $262 = (($refStartX) + 28|0);
 ;HEAP32[$refStartX+0>>2]=0|0;HEAP32[$refStartX+4>>2]=0|0;HEAP32[$refStartX+8>>2]=0|0;HEAP32[$refStartX+12>>2]=0|0;HEAP32[$refStartX+16>>2]=0|0;HEAP32[$refStartX+20>>2]=0|0;HEAP32[$refStartX+24>>2]=0|0;
 HEAPF32[$262>>2] = Math_fround(1.0);
 $263 = (($refStartX) + 44|0);
 HEAPF32[$263>>2] = Math_fround(1.0);
 $264 = (($refStartX) + 40|0);
 HEAPF32[$264>>2] = Math_fround(1.0);
 $265 = (($refStartX) + 36|0);
 HEAPF32[$265>>2] = Math_fround(1.0);
 $266 = (($refStartX) + 32|0);
 HEAPF32[$266>>2] = Math_fround(1.0);
 $267 = (($refStopX) + 28|0);
 ;HEAP32[$refStopX+0>>2]=0|0;HEAP32[$refStopX+4>>2]=0|0;HEAP32[$refStopX+8>>2]=0|0;HEAP32[$refStopX+12>>2]=0|0;HEAP32[$refStopX+16>>2]=0|0;HEAP32[$refStopX+20>>2]=0|0;HEAP32[$refStopX+24>>2]=0|0;
 HEAPF32[$267>>2] = Math_fround(1.0);
 $268 = (($refStopX) + 44|0);
 HEAPF32[$268>>2] = Math_fround(1.0);
 $269 = (($refStopX) + 40|0);
 HEAPF32[$269>>2] = Math_fround(1.0);
 $270 = (($refStopX) + 36|0);
 HEAPF32[$270>>2] = Math_fround(1.0);
 $271 = (($refStopX) + 32|0);
 HEAPF32[$271>>2] = Math_fround(1.0);
 if ($4102) {
  __ZN7mecanim9animation15GetMotionStartXERKNS0_18ClipMuscleConstantE($0,$constant);
  $272 = Math_fround(HEAPF32[$0>>2]);
  $273 = (($0) + 4|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = (($0) + 8|0);
  $276 = Math_fround(HEAPF32[$275>>2]);
  $277 = (($0) + 12|0);
  $278 = Math_fround(HEAPF32[$277>>2]);
  HEAPF32[$refStartX>>2] = $272;
  $279 = (($refStartX) + 4|0);
  HEAPF32[$279>>2] = $274;
  $280 = (($refStartX) + 8|0);
  HEAPF32[$280>>2] = $276;
  $281 = (($refStartX) + 12|0);
  HEAPF32[$281>>2] = $278;
  $282 = (($0) + 16|0);
  $283 = Math_fround(HEAPF32[$282>>2]);
  $284 = (($0) + 20|0);
  $285 = Math_fround(HEAPF32[$284>>2]);
  $286 = (($0) + 24|0);
  $287 = Math_fround(HEAPF32[$286>>2]);
  $288 = (($0) + 28|0);
  $289 = Math_fround(HEAPF32[$288>>2]);
  $290 = (($refStartX) + 16|0);
  HEAPF32[$290>>2] = $283;
  $291 = (($refStartX) + 20|0);
  HEAPF32[$291>>2] = $285;
  $292 = (($refStartX) + 24|0);
  HEAPF32[$292>>2] = $287;
  HEAPF32[$262>>2] = $289;
  $293 = (($0) + 32|0);
  $294 = Math_fround(HEAPF32[$293>>2]);
  $295 = (($0) + 36|0);
  $296 = Math_fround(HEAPF32[$295>>2]);
  $297 = (($0) + 40|0);
  $298 = Math_fround(HEAPF32[$297>>2]);
  $299 = (($0) + 44|0);
  $300 = Math_fround(HEAPF32[$299>>2]);
  HEAPF32[$266>>2] = $294;
  HEAPF32[$265>>2] = $296;
  HEAPF32[$264>>2] = $298;
  HEAPF32[$263>>2] = $300;
  __ZN7mecanim9animation14GetMotionStopXERKNS0_18ClipMuscleConstantE($1,$constant);
  $301 = Math_fround(HEAPF32[$1>>2]);
  $302 = (($1) + 4|0);
  $303 = Math_fround(HEAPF32[$302>>2]);
  $304 = (($1) + 8|0);
  $305 = Math_fround(HEAPF32[$304>>2]);
  $306 = (($1) + 12|0);
  $307 = Math_fround(HEAPF32[$306>>2]);
  HEAPF32[$refStopX>>2] = $301;
  $308 = (($refStopX) + 4|0);
  HEAPF32[$308>>2] = $303;
  $309 = (($refStopX) + 8|0);
  HEAPF32[$309>>2] = $305;
  $310 = (($refStopX) + 12|0);
  HEAPF32[$310>>2] = $307;
  $311 = (($1) + 16|0);
  $312 = Math_fround(HEAPF32[$311>>2]);
  $313 = (($1) + 20|0);
  $314 = Math_fround(HEAPF32[$313>>2]);
  $315 = (($1) + 24|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = (($1) + 28|0);
  $318 = Math_fround(HEAPF32[$317>>2]);
  $319 = (($refStopX) + 16|0);
  HEAPF32[$319>>2] = $312;
  $320 = (($refStopX) + 20|0);
  HEAPF32[$320>>2] = $314;
  $321 = (($refStopX) + 24|0);
  HEAPF32[$321>>2] = $316;
  HEAPF32[$267>>2] = $318;
  $322 = (($1) + 32|0);
  $323 = Math_fround(HEAPF32[$322>>2]);
  $324 = (($1) + 36|0);
  $325 = Math_fround(HEAPF32[$324>>2]);
  $326 = (($1) + 40|0);
  $327 = Math_fround(HEAPF32[$326>>2]);
  $328 = (($1) + 44|0);
  $329 = Math_fround(HEAPF32[$328>>2]);
  HEAPF32[$271>>2] = $323;
  HEAPF32[$270>>2] = $325;
  HEAPF32[$269>>2] = $327;
  HEAPF32[$268>>2] = $329;
  $330 = (($motionOutput) + 36|0);
  $331 = Math_fround(HEAPF32[$330>>2]);
  $332 = (($motionOutput) + 40|0);
  $333 = Math_fround(HEAPF32[$332>>2]);
  $334 = (($motionOutput) + 44|0);
  $335 = Math_fround(HEAPF32[$334>>2]);
  $336 = (($motionOutput) + 48|0);
  $337 = Math_fround(HEAPF32[$336>>2]);
  $338 = (($motionOutput) + 52|0);
  $339 = Math_fround(HEAPF32[$338>>2]);
  $340 = (($motionOutput) + 56|0);
  $341 = Math_fround(HEAPF32[$340>>2]);
  $342 = (($motionOutput) + 60|0);
  $343 = Math_fround(HEAPF32[$342>>2]);
  $344 = (($motionOutput) + 64|0);
  $345 = Math_fround(HEAPF32[$344>>2]);
  __ZN7mecanim9animation14EvaluateMotionERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($2,$constant,$memory,$85);
  $346 = Math_fround(HEAPF32[$2>>2]);
  $347 = (($2) + 4|0);
  $348 = Math_fround(HEAPF32[$347>>2]);
  $349 = (($2) + 8|0);
  $350 = Math_fround(HEAPF32[$349>>2]);
  $351 = (($2) + 12|0);
  $352 = Math_fround(HEAPF32[$351>>2]);
  $353 = (($2) + 16|0);
  $354 = Math_fround(HEAPF32[$353>>2]);
  $355 = (($2) + 20|0);
  $356 = Math_fround(HEAPF32[$355>>2]);
  $357 = (($2) + 24|0);
  $358 = Math_fround(HEAPF32[$357>>2]);
  $359 = (($2) + 28|0);
  $360 = Math_fround(HEAPF32[$359>>2]);
  $361 = (($2) + 32|0);
  $362 = Math_fround(HEAPF32[$361>>2]);
  $363 = (($2) + 36|0);
  $364 = Math_fround(HEAPF32[$363>>2]);
  $365 = (($2) + 40|0);
  $366 = Math_fround(HEAPF32[$365>>2]);
  $367 = (($2) + 44|0);
  $368 = Math_fround(HEAPF32[$367>>2]);
  $1124 = Math_fround(0.0);$1125 = Math_fround(0.0);$1137 = $333;$1146 = $348;$1295 = $331;$1299 = $335;$1301 = $337;$1303 = $346;$1307 = $350;$1309 = $352;$1421 = $339;$1423 = $345;$1425 = $341;$1427 = $343;$1469 = $354;$1471 = $360;$1473 = $356;$1475 = $358;$4021 = $362;$4023 = $364;$4025 = $366;$4027 = $368;
 } else {
  $369 = (($constant) + 908|0);
  $370 = Math_fround(HEAPF32[$369>>2]);
  $371 = (($constant) + 896|0);
  $372 = Math_fround(HEAPF32[$371>>2]);
  $373 = Math_fround($370 * $372);
  $374 = (($constant) + 900|0);
  $375 = Math_fround(HEAPF32[$374>>2]);
  $376 = Math_fround($370 * $375);
  $377 = (($constant) + 904|0);
  $378 = Math_fround(HEAPF32[$377>>2]);
  $379 = Math_fround($370 * $378);
  $380 = Math_fround($370 * $370);
  $381 = Math_fround($380 + Math_fround(-0.5));
  $382 = Math_fround($372 * $375);
  $383 = Math_fround($375 * $375);
  $384 = Math_fround($375 * $378);
  $385 = Math_fround($379 * Math_fround(-1.0));
  $386 = Math_fround($376 * Math_fround(-1.0));
  $387 = Math_fround($382 + $385);
  $388 = Math_fround($381 + $383);
  $389 = Math_fround($373 + $384);
  $390 = Math_fround($376 + $386);
  $391 = Math_fround($387 + $387);
  $392 = Math_fround($388 + $388);
  $393 = Math_fround($389 + $389);
  $394 = Math_fround($390 + $390);
  $395 = Math_fround($392 * Math_fround(0.0));
  $396 = Math_fround($393 * Math_fround(0.0));
  $397 = Math_fround($394 * Math_fround(0.0));
  $398 = Math_fround($391 * Math_fround(0.0));
  $399 = Math_fround($391 - $395);
  $400 = Math_fround($395 - $393);
  $401 = Math_fround($396 - $398);
  $402 = Math_fround($392 + $398);
  $403 = Math_fround($396 + $397);
  $404 = Math_fround($403 + $402);
  $405 = Math_fround($391 * $391);
  $406 = Math_fround($392 * $392);
  $407 = Math_fround($393 * $393);
  $408 = Math_fround($394 * $394);
  $409 = Math_fround($406 + $405);
  $410 = Math_fround($407 + $408);
  $411 = Math_fround($410 + $409);
  $412 = (Math_fround(Math_sqrt((Math_fround($411)))));
  $413 = Math_fround($412 + $404);
  $414 = Math_fround($372 * $401);
  $415 = Math_fround($370 * $413);
  $416 = Math_fround($375 * $399);
  $417 = Math_fround($378 * $400);
  $418 = Math_fround($378 * $413);
  $419 = Math_fround($372 * $400);
  $420 = Math_fround($378 * $401);
  $421 = Math_fround($372 * $399);
  $422 = Math_fround($414 - $418);
  $423 = Math_fround($415 - $419);
  $424 = Math_fround($416 - $420);
  $425 = Math_fround($417 - $421);
  $426 = Math_fround($370 * $399);
  $427 = Math_fround($378 * $399);
  $428 = Math_fround($372 * $413);
  $429 = Math_fround($375 * $413);
  $430 = Math_fround($422 - $426);
  $431 = Math_fround($423 - $427);
  $432 = Math_fround($424 - $428);
  $433 = Math_fround($425 - $429);
  $434 = Math_fround($375 * $400);
  $435 = Math_fround($375 * $401);
  $436 = Math_fround($370 * $400);
  $437 = Math_fround($370 * $401);
  $438 = Math_fround($430 - $434);
  $439 = Math_fround($431 - $435);
  $440 = Math_fround($432 - $436);
  $441 = Math_fround($433 - $437);
  $442 = Math_fround($440 * Math_fround(-1.0));
  $443 = Math_fround($441 * Math_fround(-1.0));
  $444 = Math_fround($438 * Math_fround(-1.0));
  $445 = Math_fround($442 * Math_fround(0.0));
  $446 = Math_fround($444 * Math_fround(0.0));
  $447 = Math_fround($445 * $445);
  $448 = Math_fround($443 * $443);
  $449 = Math_fround($446 * $446);
  $450 = Math_fround($439 * $439);
  $451 = Math_fround($448 + $447);
  $452 = Math_fround($450 + $449);
  $453 = Math_fround($451 + $452);
  $454 = (Math_fround(Math_sqrt((Math_fround($453)))));
  $455 = Math_fround(Math_fround(1.0) / $454);
  $456 = Math_fround($455 * $445);
  $457 = Math_fround($455 * $443);
  $458 = Math_fround($455 * $446);
  $459 = Math_fround($455 * $439);
  $460 = Math_fround(HEAPF32[$122>>2]);
  $461 = (($constant) + 884|0);
  $462 = Math_fround(HEAPF32[$461>>2]);
  $463 = (($constant) + 888|0);
  $464 = Math_fround(HEAPF32[$463>>2]);
  $465 = (($constant) + 892|0);
  $466 = Math_fround(HEAPF32[$465>>2]);
  $467 = (($constant) + 912|0);
  $468 = Math_fround(HEAPF32[$467>>2]);
  $469 = (($constant) + 916|0);
  $470 = Math_fround(HEAPF32[$469>>2]);
  $471 = (($constant) + 920|0);
  $472 = Math_fround(HEAPF32[$471>>2]);
  $473 = (($constant) + 924|0);
  $474 = Math_fround(HEAPF32[$473>>2]);
  HEAPF32[$refStartX>>2] = $460;
  $475 = (($refStartX) + 4|0);
  HEAPF32[$475>>2] = $462;
  $476 = (($refStartX) + 8|0);
  HEAPF32[$476>>2] = $464;
  $477 = (($refStartX) + 12|0);
  HEAPF32[$477>>2] = $466;
  $478 = (($refStartX) + 16|0);
  HEAPF32[$478>>2] = $456;
  $479 = (($refStartX) + 20|0);
  HEAPF32[$479>>2] = $457;
  $480 = (($refStartX) + 24|0);
  HEAPF32[$480>>2] = $458;
  HEAPF32[$262>>2] = $459;
  HEAPF32[$266>>2] = $468;
  HEAPF32[$265>>2] = $470;
  HEAPF32[$264>>2] = $472;
  HEAPF32[$263>>2] = $474;
  $481 = (($stopX) + 28|0);
  $482 = Math_fround(HEAPF32[$481>>2]);
  $483 = (($stopX) + 16|0);
  $484 = Math_fround(HEAPF32[$483>>2]);
  $485 = Math_fround($482 * $484);
  $486 = (($stopX) + 20|0);
  $487 = Math_fround(HEAPF32[$486>>2]);
  $488 = Math_fround($482 * $487);
  $489 = (($stopX) + 24|0);
  $490 = Math_fround(HEAPF32[$489>>2]);
  $491 = Math_fround($482 * $490);
  $492 = Math_fround($482 * $482);
  $493 = Math_fround($492 + Math_fround(-0.5));
  $494 = Math_fround($484 * $487);
  $495 = Math_fround($487 * $487);
  $496 = Math_fround($487 * $490);
  $497 = Math_fround($491 * Math_fround(-1.0));
  $498 = Math_fround($488 * Math_fround(-1.0));
  $499 = Math_fround($494 + $497);
  $500 = Math_fround($493 + $495);
  $501 = Math_fround($485 + $496);
  $502 = Math_fround($488 + $498);
  $503 = Math_fround($499 + $499);
  $504 = Math_fround($500 + $500);
  $505 = Math_fround($501 + $501);
  $506 = Math_fround($502 + $502);
  $507 = Math_fround($504 * Math_fround(0.0));
  $508 = Math_fround($505 * Math_fround(0.0));
  $509 = Math_fround($506 * Math_fround(0.0));
  $510 = Math_fround($503 * Math_fround(0.0));
  $511 = Math_fround($503 - $507);
  $512 = Math_fround($507 - $505);
  $513 = Math_fround($508 - $510);
  $514 = Math_fround($504 + $510);
  $515 = Math_fround($508 + $509);
  $516 = Math_fround($515 + $514);
  $517 = Math_fround($503 * $503);
  $518 = Math_fround($504 * $504);
  $519 = Math_fround($505 * $505);
  $520 = Math_fround($506 * $506);
  $521 = Math_fround($518 + $517);
  $522 = Math_fround($519 + $520);
  $523 = Math_fround($522 + $521);
  $524 = (Math_fround(Math_sqrt((Math_fround($523)))));
  $525 = Math_fround($524 + $516);
  $526 = Math_fround($484 * $513);
  $527 = Math_fround($482 * $525);
  $528 = Math_fround($487 * $511);
  $529 = Math_fround($490 * $512);
  $530 = Math_fround($490 * $525);
  $531 = Math_fround($484 * $512);
  $532 = Math_fround($490 * $513);
  $533 = Math_fround($484 * $511);
  $534 = Math_fround($526 - $530);
  $535 = Math_fround($527 - $531);
  $536 = Math_fround($528 - $532);
  $537 = Math_fround($529 - $533);
  $538 = Math_fround($482 * $511);
  $539 = Math_fround($490 * $511);
  $540 = Math_fround($484 * $525);
  $541 = Math_fround($487 * $525);
  $542 = Math_fround($534 - $538);
  $543 = Math_fround($535 - $539);
  $544 = Math_fround($536 - $540);
  $545 = Math_fround($537 - $541);
  $546 = Math_fround($487 * $512);
  $547 = Math_fround($487 * $513);
  $548 = Math_fround($482 * $512);
  $549 = Math_fround($482 * $513);
  $550 = Math_fround($542 - $546);
  $551 = Math_fround($543 - $547);
  $552 = Math_fround($544 - $548);
  $553 = Math_fround($545 - $549);
  $554 = Math_fround($552 * Math_fround(-1.0));
  $555 = Math_fround($553 * Math_fround(-1.0));
  $556 = Math_fround($550 * Math_fround(-1.0));
  $557 = Math_fround($554 * Math_fround(0.0));
  $558 = Math_fround($556 * Math_fround(0.0));
  $559 = Math_fround($557 * $557);
  $560 = Math_fround($555 * $555);
  $561 = Math_fround($558 * $558);
  $562 = Math_fround($551 * $551);
  $563 = Math_fround($560 + $559);
  $564 = Math_fround($562 + $561);
  $565 = Math_fround($563 + $564);
  $566 = (Math_fround(Math_sqrt((Math_fround($565)))));
  $567 = Math_fround(Math_fround(1.0) / $566);
  $568 = Math_fround($567 * $557);
  $569 = Math_fround($567 * $555);
  $570 = Math_fround($567 * $558);
  $571 = Math_fround($567 * $551);
  $572 = Math_fround(HEAPF32[$stopX>>2]);
  $573 = (($stopX) + 4|0);
  $574 = Math_fround(HEAPF32[$573>>2]);
  $575 = (($stopX) + 8|0);
  $576 = Math_fround(HEAPF32[$575>>2]);
  $577 = (($stopX) + 12|0);
  $578 = Math_fround(HEAPF32[$577>>2]);
  $579 = (($stopX) + 32|0);
  $580 = Math_fround(HEAPF32[$579>>2]);
  $581 = (($stopX) + 36|0);
  $582 = Math_fround(HEAPF32[$581>>2]);
  $583 = (($stopX) + 40|0);
  $584 = Math_fround(HEAPF32[$583>>2]);
  $585 = (($stopX) + 44|0);
  $586 = Math_fround(HEAPF32[$585>>2]);
  HEAPF32[$refStopX>>2] = $572;
  $587 = (($refStopX) + 4|0);
  HEAPF32[$587>>2] = $574;
  $588 = (($refStopX) + 8|0);
  HEAPF32[$588>>2] = $576;
  $589 = (($refStopX) + 12|0);
  HEAPF32[$589>>2] = $578;
  $590 = (($refStopX) + 16|0);
  HEAPF32[$590>>2] = $568;
  $591 = (($refStopX) + 20|0);
  HEAPF32[$591>>2] = $569;
  $592 = (($refStopX) + 24|0);
  HEAPF32[$592>>2] = $570;
  HEAPF32[$267>>2] = $571;
  HEAPF32[$271>>2] = $580;
  HEAPF32[$270>>2] = $582;
  HEAPF32[$269>>2] = $584;
  HEAPF32[$268>>2] = $586;
  $593 = Math_fround(HEAPF32[$145>>2]);
  $594 = Math_fround(HEAPF32[$142>>2]);
  $595 = Math_fround($593 * $594);
  $596 = Math_fround(HEAPF32[$143>>2]);
  $597 = Math_fround($593 * $596);
  $598 = Math_fround(HEAPF32[$144>>2]);
  $599 = Math_fround($593 * $598);
  $600 = Math_fround($593 * $593);
  $601 = Math_fround($600 + Math_fround(-0.5));
  $602 = Math_fround($594 * $596);
  $603 = Math_fround($596 * $596);
  $604 = Math_fround($596 * $598);
  $605 = Math_fround($599 * Math_fround(-1.0));
  $606 = Math_fround($597 * Math_fround(-1.0));
  $607 = Math_fround($602 + $605);
  $608 = Math_fround($601 + $603);
  $609 = Math_fround($595 + $604);
  $610 = Math_fround($597 + $606);
  $611 = Math_fround($607 + $607);
  $612 = Math_fround($608 + $608);
  $613 = Math_fround($609 + $609);
  $614 = Math_fround($610 + $610);
  $615 = Math_fround($612 * Math_fround(0.0));
  $616 = Math_fround($613 * Math_fround(0.0));
  $617 = Math_fround($614 * Math_fround(0.0));
  $618 = Math_fround($611 * Math_fround(0.0));
  $619 = Math_fround($611 - $615);
  $620 = Math_fround($615 - $613);
  $621 = Math_fround($616 - $618);
  $622 = Math_fround($612 + $618);
  $623 = Math_fround($616 + $617);
  $624 = Math_fround($623 + $622);
  $625 = Math_fround($611 * $611);
  $626 = Math_fround($612 * $612);
  $627 = Math_fround($613 * $613);
  $628 = Math_fround($614 * $614);
  $629 = Math_fround($626 + $625);
  $630 = Math_fround($627 + $628);
  $631 = Math_fround($630 + $629);
  $632 = (Math_fround(Math_sqrt((Math_fround($631)))));
  $633 = Math_fround($632 + $624);
  $634 = Math_fround($594 * $621);
  $635 = Math_fround($593 * $633);
  $636 = Math_fround($596 * $619);
  $637 = Math_fround($598 * $620);
  $638 = Math_fround($598 * $633);
  $639 = Math_fround($594 * $620);
  $640 = Math_fround($598 * $621);
  $641 = Math_fround($594 * $619);
  $642 = Math_fround($634 - $638);
  $643 = Math_fround($635 - $639);
  $644 = Math_fround($636 - $640);
  $645 = Math_fround($637 - $641);
  $646 = Math_fround($593 * $619);
  $647 = Math_fround($598 * $619);
  $648 = Math_fround($594 * $633);
  $649 = Math_fround($596 * $633);
  $650 = Math_fround($642 - $646);
  $651 = Math_fround($643 - $647);
  $652 = Math_fround($644 - $648);
  $653 = Math_fround($645 - $649);
  $654 = Math_fround($596 * $620);
  $655 = Math_fround($596 * $621);
  $656 = Math_fround($593 * $620);
  $657 = Math_fround($593 * $621);
  $658 = Math_fround($650 - $654);
  $659 = Math_fround($651 - $655);
  $660 = Math_fround($652 - $656);
  $661 = Math_fround($653 - $657);
  $662 = Math_fround($660 * Math_fround(-1.0));
  $663 = Math_fround($661 * Math_fround(-1.0));
  $664 = Math_fround($658 * Math_fround(-1.0));
  $665 = Math_fround($662 * Math_fround(0.0));
  $666 = Math_fround($664 * Math_fround(0.0));
  $667 = Math_fround($665 * $665);
  $668 = Math_fround($663 * $663);
  $669 = Math_fround($666 * $666);
  $670 = Math_fround($659 * $659);
  $671 = Math_fround($668 + $667);
  $672 = Math_fround($670 + $669);
  $673 = Math_fround($671 + $672);
  $674 = (Math_fround(Math_sqrt((Math_fround($673)))));
  $675 = Math_fround(Math_fround(1.0) / $674);
  $676 = Math_fround($675 * $665);
  $677 = Math_fround($675 * $663);
  $678 = Math_fround($675 * $666);
  $679 = Math_fround($675 * $659);
  $680 = Math_fround(HEAPF32[$prevRootX>>2]);
  $681 = Math_fround(HEAPF32[$131>>2]);
  $682 = Math_fround(HEAPF32[$132>>2]);
  $683 = Math_fround(HEAPF32[$133>>2]);
  $684 = Math_fround(HEAPF32[$249>>2]);
  $685 = Math_fround(HEAPF32[$246>>2]);
  $686 = Math_fround($684 * $685);
  $687 = Math_fround(HEAPF32[$247>>2]);
  $688 = Math_fround($684 * $687);
  $689 = Math_fround(HEAPF32[$248>>2]);
  $690 = Math_fround($684 * $689);
  $691 = Math_fround($684 * $684);
  $692 = Math_fround($691 + Math_fround(-0.5));
  $693 = Math_fround($685 * $687);
  $694 = Math_fround($687 * $687);
  $695 = Math_fround($687 * $689);
  $696 = Math_fround($690 * Math_fround(-1.0));
  $697 = Math_fround($688 * Math_fround(-1.0));
  $698 = Math_fround($693 + $696);
  $699 = Math_fround($692 + $694);
  $700 = Math_fround($686 + $695);
  $701 = Math_fround($688 + $697);
  $702 = Math_fround($698 + $698);
  $703 = Math_fround($699 + $699);
  $704 = Math_fround($700 + $700);
  $705 = Math_fround($701 + $701);
  $706 = Math_fround($703 * Math_fround(0.0));
  $707 = Math_fround($704 * Math_fround(0.0));
  $708 = Math_fround($705 * Math_fround(0.0));
  $709 = Math_fround($702 * Math_fround(0.0));
  $710 = Math_fround($702 - $706);
  $711 = Math_fround($706 - $704);
  $712 = Math_fround($707 - $709);
  $713 = Math_fround($703 + $709);
  $714 = Math_fround($707 + $708);
  $715 = Math_fround($714 + $713);
  $716 = Math_fround($702 * $702);
  $717 = Math_fround($703 * $703);
  $718 = Math_fround($704 * $704);
  $719 = Math_fround($705 * $705);
  $720 = Math_fround($717 + $716);
  $721 = Math_fround($718 + $719);
  $722 = Math_fround($721 + $720);
  $723 = (Math_fround(Math_sqrt((Math_fround($722)))));
  $724 = Math_fround($723 + $715);
  $725 = Math_fround($685 * $712);
  $726 = Math_fround($684 * $724);
  $727 = Math_fround($687 * $710);
  $728 = Math_fround($689 * $711);
  $729 = Math_fround($689 * $724);
  $730 = Math_fround($685 * $711);
  $731 = Math_fround($689 * $712);
  $732 = Math_fround($685 * $710);
  $733 = Math_fround($725 - $729);
  $734 = Math_fround($726 - $730);
  $735 = Math_fround($727 - $731);
  $736 = Math_fround($728 - $732);
  $737 = Math_fround($684 * $710);
  $738 = Math_fround($689 * $710);
  $739 = Math_fround($685 * $724);
  $740 = Math_fround($687 * $724);
  $741 = Math_fround($733 - $737);
  $742 = Math_fround($734 - $738);
  $743 = Math_fround($735 - $739);
  $744 = Math_fround($736 - $740);
  $745 = Math_fround($687 * $711);
  $746 = Math_fround($687 * $712);
  $747 = Math_fround($684 * $711);
  $748 = Math_fround($684 * $712);
  $749 = Math_fround($741 - $745);
  $750 = Math_fround($742 - $746);
  $751 = Math_fround($743 - $747);
  $752 = Math_fround($744 - $748);
  $753 = Math_fround($751 * Math_fround(-1.0));
  $754 = Math_fround($752 * Math_fround(-1.0));
  $755 = Math_fround($749 * Math_fround(-1.0));
  $756 = Math_fround($753 * Math_fround(0.0));
  $757 = Math_fround($755 * Math_fround(0.0));
  $758 = Math_fround($756 * $756);
  $759 = Math_fround($754 * $754);
  $760 = Math_fround($757 * $757);
  $761 = Math_fround($750 * $750);
  $762 = Math_fround($759 + $758);
  $763 = Math_fround($761 + $760);
  $764 = Math_fround($762 + $763);
  $765 = (Math_fround(Math_sqrt((Math_fround($764)))));
  $766 = Math_fround(Math_fround(1.0) / $765);
  $767 = Math_fround($766 * $756);
  $768 = Math_fround($766 * $754);
  $769 = Math_fround($766 * $757);
  $770 = Math_fround($766 * $750);
  $771 = Math_fround(HEAPF32[$rootX>>2]);
  $772 = Math_fround(HEAPF32[$235>>2]);
  $773 = Math_fround(HEAPF32[$236>>2]);
  $774 = Math_fround(HEAPF32[$237>>2]);
  $775 = Math_fround(HEAPF32[$258>>2]);
  $776 = Math_fround(HEAPF32[$259>>2]);
  $777 = Math_fround(HEAPF32[$260>>2]);
  $778 = Math_fround(HEAPF32[$261>>2]);
  $779 = (($constant) + 1641|0);
  $780 = HEAP8[$779>>0]|0;
  $781 = ($780<<24>>24)==(0);
  if ($781) {
   $1124 = Math_fround(0.0);$1125 = Math_fround(0.0);$1137 = $681;$1146 = $772;$1295 = $680;$1299 = $682;$1301 = $683;$1303 = $771;$1307 = $773;$1309 = $774;$1421 = $676;$1423 = $679;$1425 = $677;$1427 = $678;$1469 = $767;$1471 = $770;$1473 = $768;$1475 = $769;$4021 = $775;$4023 = $776;$4025 = $777;$4027 = $778;
  } else {
   $782 = (($constant) + 928|0);
   $783 = (($constant) + 80|0);
   __ZN4mathL11xformMulInvERKNS_5xformES2_($4,$782,$783);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($3,$stopX,$4);
   $784 = (($3) + 4|0);
   $785 = Math_fround(HEAPF32[$784>>2]);
   $786 = (($constant) + 976|0);
   $787 = (($constant) + 156|0);
   __ZN4mathL11xformMulInvERKNS_5xformES2_($6,$786,$787);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($5,$stopX,$6);
   $788 = (($5) + 4|0);
   $789 = Math_fround(HEAPF32[$788>>2]);
   $1124 = $785;$1125 = $789;$1137 = $681;$1146 = $772;$1295 = $680;$1299 = $682;$1301 = $683;$1303 = $771;$1307 = $773;$1309 = $774;$1421 = $676;$1423 = $679;$1425 = $677;$1427 = $678;$1469 = $767;$1471 = $770;$1473 = $768;$1475 = $769;$4021 = $775;$4023 = $776;$4025 = $777;$4027 = $778;
  }
 }
 if ($4103) {
  HEAPF32[$clipIn$i>>2] = $85;
  $790 = HEAP32[$107>>2]|0;
  $791 = ($790|0)==(-1);
  if ($791) {
   $820 = Math_fround(0.0);
  } else {
   $792 = (($constant) + 1040|0);
   $793 = $792;
   $794 = HEAP32[$792>>2]|0;
   $795 = (($794) + ($793))|0;
   $796 = $795;
   $797 = (($constant) + 1044|0);
   HEAP32[$797>>2] = $796;
   $798 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($796,$clipIn$i,$memory,$790)));
   $820 = $798;
  }
  $799 = (($constant) + 1612|0);
  $800 = HEAP32[$799>>2]|0;
  $801 = ($800|0)==(-1);
  if ($801) {
   $822 = Math_fround(0.0);
  } else {
   $802 = (($constant) + 1040|0);
   $803 = $802;
   $804 = HEAP32[$802>>2]|0;
   $805 = (($804) + ($803))|0;
   $806 = $805;
   $807 = (($constant) + 1044|0);
   HEAP32[$807>>2] = $806;
   $808 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($806,$clipIn$i,$memory,$800)));
   $822 = $808;
  }
  $809 = (($constant) + 1616|0);
  $810 = HEAP32[$809>>2]|0;
  $811 = ($810|0)==(-1);
  if ($811) {
   $824 = Math_fround(0.0);
  } else {
   $812 = (($constant) + 1040|0);
   $813 = $812;
   $814 = HEAP32[$812>>2]|0;
   $815 = (($814) + ($813))|0;
   $816 = $815;
   $817 = (($constant) + 1044|0);
   HEAP32[$817>>2] = $816;
   $818 = (Math_fround(__ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($816,$clipIn$i,$memory,$810)));
   $824 = $818;
  }
  $819 = (($motionOutput) + 440|0);
  HEAPF32[$819>>2] = $820;
  $821 = (($motionOutput) + 444|0);
  HEAPF32[$821>>2] = $822;
  $823 = (($motionOutput) + 448|0);
  HEAPF32[$823>>2] = $824;
  $825 = (($motionOutput) + 452|0);
  HEAPF32[$825>>2] = Math_fround(0.0);
  $826 = (($motionOutput) + 456|0);
  HEAPF32[$826>>2] = Math_fround(1.0);
 } else {
  $827 = (($motionOutput) + 456|0);
  HEAPF32[$827>>2] = Math_fround(0.0);
 }
 $828 = Math_fround(HEAPF32[$41>>2]);
 $829 = Math_fround(HEAPF32[$stopX>>2]);
 $830 = (($stopX) + 4|0);
 $831 = Math_fround(HEAPF32[$830>>2]);
 $832 = (($stopX) + 8|0);
 $833 = Math_fround(HEAPF32[$832>>2]);
 $834 = (($stopX) + 12|0);
 $835 = Math_fround(HEAPF32[$834>>2]);
 HEAPF32[$clipIn$i>>2] = $829;
 $836 = (($clipIn$i) + 4|0);
 HEAPF32[$836>>2] = $831;
 $837 = (($clipIn$i) + 8|0);
 HEAPF32[$837>>2] = $833;
 $838 = (($clipIn$i) + 12|0);
 HEAPF32[$838>>2] = $835;
 $839 = (($stopX) + 16|0);
 $840 = Math_fround(HEAPF32[$839>>2]);
 $841 = (($stopX) + 20|0);
 $842 = Math_fround(HEAPF32[$841>>2]);
 $843 = (($stopX) + 24|0);
 $844 = Math_fround(HEAPF32[$843>>2]);
 $845 = (($stopX) + 28|0);
 $846 = Math_fround(HEAPF32[$845>>2]);
 $847 = (($clipIn$i) + 16|0);
 HEAPF32[$847>>2] = $840;
 $848 = (($clipIn$i) + 20|0);
 HEAPF32[$848>>2] = $842;
 $849 = (($clipIn$i) + 24|0);
 HEAPF32[$849>>2] = $844;
 $850 = (($clipIn$i) + 28|0);
 HEAPF32[$850>>2] = $846;
 $851 = (($stopX) + 32|0);
 $852 = Math_fround(HEAPF32[$851>>2]);
 $853 = (($stopX) + 36|0);
 $854 = Math_fround(HEAPF32[$853>>2]);
 $855 = (($stopX) + 40|0);
 $856 = Math_fround(HEAPF32[$855>>2]);
 $857 = (($stopX) + 44|0);
 $858 = Math_fround(HEAPF32[$857>>2]);
 $859 = (($clipIn$i) + 32|0);
 HEAPF32[$859>>2] = $852;
 $860 = (($clipIn$i) + 36|0);
 HEAPF32[$860>>2] = $854;
 $861 = (($clipIn$i) + 40|0);
 HEAPF32[$861>>2] = $856;
 $862 = (($clipIn$i) + 44|0);
 HEAPF32[$862>>2] = $858;
 $863 = Math_fround(HEAPF32[$refStopX>>2]);
 $864 = (($refStopX) + 4|0);
 $865 = Math_fround(HEAPF32[$864>>2]);
 $866 = (($refStopX) + 8|0);
 $867 = Math_fround(HEAPF32[$866>>2]);
 $868 = (($refStopX) + 12|0);
 $869 = Math_fround(HEAPF32[$868>>2]);
 HEAPF32[$targetRefX>>2] = $863;
 $870 = (($targetRefX) + 4|0);
 HEAPF32[$870>>2] = $865;
 $871 = (($targetRefX) + 8|0);
 HEAPF32[$871>>2] = $867;
 $872 = (($targetRefX) + 12|0);
 HEAPF32[$872>>2] = $869;
 $873 = (($refStopX) + 16|0);
 $874 = Math_fround(HEAPF32[$873>>2]);
 $875 = (($refStopX) + 20|0);
 $876 = Math_fround(HEAPF32[$875>>2]);
 $877 = (($refStopX) + 24|0);
 $878 = Math_fround(HEAPF32[$877>>2]);
 $879 = Math_fround(HEAPF32[$267>>2]);
 $880 = (($targetRefX) + 16|0);
 HEAPF32[$880>>2] = $874;
 $881 = (($targetRefX) + 20|0);
 HEAPF32[$881>>2] = $876;
 $882 = (($targetRefX) + 24|0);
 HEAPF32[$882>>2] = $878;
 $883 = (($targetRefX) + 28|0);
 HEAPF32[$883>>2] = $879;
 $884 = Math_fround(HEAPF32[$271>>2]);
 $885 = Math_fround(HEAPF32[$270>>2]);
 $886 = Math_fround(HEAPF32[$269>>2]);
 $887 = Math_fround(HEAPF32[$268>>2]);
 $888 = (($targetRefX) + 32|0);
 HEAPF32[$888>>2] = $884;
 $889 = (($targetRefX) + 36|0);
 HEAPF32[$889>>2] = $885;
 $890 = (($targetRefX) + 40|0);
 HEAPF32[$890>>2] = $886;
 $891 = (($targetRefX) + 44|0);
 HEAPF32[$891>>2] = $887;
 $892 = (($targetGoalX) + 28|0);
 ;HEAP32[$targetGoalX+0>>2]=0|0;HEAP32[$targetGoalX+4>>2]=0|0;HEAP32[$targetGoalX+8>>2]=0|0;HEAP32[$targetGoalX+12>>2]=0|0;HEAP32[$targetGoalX+16>>2]=0|0;HEAP32[$targetGoalX+20>>2]=0|0;HEAP32[$targetGoalX+24>>2]=0|0;
 HEAPF32[$892>>2] = Math_fround(1.0);
 $893 = (($targetGoalX) + 32|0);
 HEAPF32[$893>>2] = Math_fround(1.0);
 $894 = (($targetGoalX) + 36|0);
 HEAPF32[$894>>2] = Math_fround(1.0);
 $895 = (($targetGoalX) + 40|0);
 HEAPF32[$895>>2] = Math_fround(1.0);
 $896 = (($targetGoalX) + 44|0);
 HEAPF32[$896>>2] = Math_fround(1.0);
 HEAPF32[$targetTimeInt>>2] = Math_fround(0.0);
 $897 = (($input) + 12|0);
 $898 = Math_fround(HEAPF32[$897>>2]);
 $899 = $898 != Math_fround(1.0);
 do {
  if ($899) {
   $900 = Math_fround(HEAPF32[$40>>2]);
   $901 = Math_fround(HEAPF32[$41>>2]);
   $902 = HEAP8[$42>>0]|0;
   $903 = ($902<<24>>24)!=(0);
   $904 = Math_fround(HEAPF32[$45>>2]);
   $905 = $904 < Math_fround(0.0);
   $906 = (Math_fround(+(_fmaxf(0.0,(+$898)))));
   $907 = (Math_fround(+(_fminf(1.0,(+$906)))));
   $908 = Math_fround($37 + $898);
   $909 = (Math_fround(+(_modff((+$908),($targetTimeInt|0)))));
   $$v$i8 = $903 ? $909 : $907;
   $910 = Math_fround(Math_fround(1.0) - $$v$i8);
   $911 = $905&1;
   $912 = $911 ^ 1;
   $913 = (0 - ($912))|0;
   $914 = (HEAPF32[tempDoublePtr>>2]=$910,HEAP32[tempDoublePtr>>2]|0);
   $915 = (HEAPF32[tempDoublePtr>>2]=$$v$i8,HEAP32[tempDoublePtr>>2]|0);
   $916 = $905 ? $914 : 0;
   $917 = $915 & $913;
   $918 = $916 | $917;
   $919 = (HEAP32[tempDoublePtr>>2]=$918,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $920 = Math_fround($901 - $900);
   $921 = Math_fround($920 * $919);
   $922 = Math_fround($900 + $921);
   __ZN7mecanim9animation12EvaluateRootERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($7,$constant,$memory,$922);
   $923 = Math_fround(HEAPF32[$7>>2]);
   $924 = (($7) + 4|0);
   $925 = Math_fround(HEAPF32[$924>>2]);
   $926 = (($7) + 8|0);
   $927 = Math_fround(HEAPF32[$926>>2]);
   $928 = (($7) + 12|0);
   $929 = Math_fround(HEAPF32[$928>>2]);
   HEAPF32[$clipIn$i>>2] = $923;
   HEAPF32[$836>>2] = $925;
   HEAPF32[$837>>2] = $927;
   HEAPF32[$838>>2] = $929;
   $930 = (($7) + 16|0);
   $931 = Math_fround(HEAPF32[$930>>2]);
   $932 = (($7) + 20|0);
   $933 = Math_fround(HEAPF32[$932>>2]);
   $934 = (($7) + 24|0);
   $935 = Math_fround(HEAPF32[$934>>2]);
   $936 = (($7) + 28|0);
   $937 = Math_fround(HEAPF32[$936>>2]);
   HEAPF32[$847>>2] = $931;
   HEAPF32[$848>>2] = $933;
   HEAPF32[$849>>2] = $935;
   HEAPF32[$850>>2] = $937;
   $938 = (($7) + 32|0);
   $939 = Math_fround(HEAPF32[$938>>2]);
   $940 = (($7) + 36|0);
   $941 = Math_fround(HEAPF32[$940>>2]);
   $942 = (($7) + 40|0);
   $943 = Math_fround(HEAPF32[$942>>2]);
   $944 = (($7) + 44|0);
   $945 = Math_fround(HEAPF32[$944>>2]);
   HEAPF32[$859>>2] = $939;
   HEAPF32[$860>>2] = $941;
   HEAPF32[$861>>2] = $943;
   HEAPF32[$862>>2] = $945;
   __ZN7mecanim9animation12EvaluateGoalERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEfi($9,$constant,$memory,$922,0);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($8,$clipIn$i,$9);
   $946 = (($8) + 4|0);
   $947 = Math_fround(HEAPF32[$946>>2]);
   __ZN7mecanim9animation12EvaluateGoalERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEfi($11,$constant,$memory,$922,1);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($10,$clipIn$i,$11);
   $948 = (($10) + 4|0);
   $949 = Math_fround(HEAPF32[$948>>2]);
   if ($4102) {
    __ZN7mecanim9animation14EvaluateMotionERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEf($12,$constant,$memory,$922);
    $950 = Math_fround(HEAPF32[$12>>2]);
    $951 = (($12) + 4|0);
    $952 = Math_fround(HEAPF32[$951>>2]);
    $953 = (($12) + 8|0);
    $954 = Math_fround(HEAPF32[$953>>2]);
    $955 = (($12) + 12|0);
    $956 = Math_fround(HEAPF32[$955>>2]);
    HEAPF32[$targetRefX>>2] = $950;
    HEAPF32[$870>>2] = $952;
    HEAPF32[$871>>2] = $954;
    HEAPF32[$872>>2] = $956;
    $957 = (($12) + 16|0);
    $958 = Math_fround(HEAPF32[$957>>2]);
    $959 = (($12) + 20|0);
    $960 = Math_fround(HEAPF32[$959>>2]);
    $961 = (($12) + 24|0);
    $962 = Math_fround(HEAPF32[$961>>2]);
    $963 = (($12) + 28|0);
    $964 = Math_fround(HEAPF32[$963>>2]);
    HEAPF32[$880>>2] = $958;
    HEAPF32[$881>>2] = $960;
    HEAPF32[$882>>2] = $962;
    HEAPF32[$883>>2] = $964;
    $965 = (($12) + 32|0);
    $966 = Math_fround(HEAPF32[$965>>2]);
    $967 = (($12) + 36|0);
    $968 = Math_fround(HEAPF32[$967>>2]);
    $969 = (($12) + 40|0);
    $970 = Math_fround(HEAPF32[$969>>2]);
    $971 = (($12) + 44|0);
    $972 = Math_fround(HEAPF32[$971>>2]);
    HEAPF32[$888>>2] = $966;
    HEAPF32[$889>>2] = $968;
    HEAPF32[$890>>2] = $970;
    HEAPF32[$891>>2] = $972;
    $1149 = $947;$1150 = $949;$1153 = $952;$1311 = $950;$1315 = $954;$1317 = $956;$2906 = $919;$targetTime$0 = $922;
    break;
   } else {
    $973 = Math_fround(HEAPF32[$850>>2]);
    $974 = Math_fround(HEAPF32[$847>>2]);
    $975 = Math_fround($973 * $974);
    $976 = Math_fround(HEAPF32[$848>>2]);
    $977 = Math_fround($973 * $976);
    $978 = Math_fround(HEAPF32[$849>>2]);
    $979 = Math_fround($973 * $978);
    $980 = Math_fround($973 * $973);
    $981 = Math_fround($980 + Math_fround(-0.5));
    $982 = Math_fround($974 * $976);
    $983 = Math_fround($976 * $976);
    $984 = Math_fround($976 * $978);
    $985 = Math_fround($979 * Math_fround(-1.0));
    $986 = Math_fround($977 * Math_fround(-1.0));
    $987 = Math_fround($982 + $985);
    $988 = Math_fround($981 + $983);
    $989 = Math_fround($975 + $984);
    $990 = Math_fround($977 + $986);
    $991 = Math_fround($987 + $987);
    $992 = Math_fround($988 + $988);
    $993 = Math_fround($989 + $989);
    $994 = Math_fround($990 + $990);
    $995 = Math_fround($992 * Math_fround(0.0));
    $996 = Math_fround($993 * Math_fround(0.0));
    $997 = Math_fround($994 * Math_fround(0.0));
    $998 = Math_fround($991 * Math_fround(0.0));
    $999 = Math_fround($991 - $995);
    $1000 = Math_fround($995 - $993);
    $1001 = Math_fround($996 - $998);
    $1002 = Math_fround($992 + $998);
    $1003 = Math_fround($996 + $997);
    $1004 = Math_fround($1003 + $1002);
    $1005 = Math_fround($991 * $991);
    $1006 = Math_fround($992 * $992);
    $1007 = Math_fround($993 * $993);
    $1008 = Math_fround($994 * $994);
    $1009 = Math_fround($1006 + $1005);
    $1010 = Math_fround($1007 + $1008);
    $1011 = Math_fround($1010 + $1009);
    $1012 = (Math_fround(Math_sqrt((Math_fround($1011)))));
    $1013 = Math_fround($1012 + $1004);
    $1014 = Math_fround($974 * $1001);
    $1015 = Math_fround($973 * $1013);
    $1016 = Math_fround($976 * $999);
    $1017 = Math_fround($978 * $1000);
    $1018 = Math_fround($978 * $1013);
    $1019 = Math_fround($974 * $1000);
    $1020 = Math_fround($978 * $1001);
    $1021 = Math_fround($974 * $999);
    $1022 = Math_fround($1014 - $1018);
    $1023 = Math_fround($1015 - $1019);
    $1024 = Math_fround($1016 - $1020);
    $1025 = Math_fround($1017 - $1021);
    $1026 = Math_fround($973 * $999);
    $1027 = Math_fround($978 * $999);
    $1028 = Math_fround($974 * $1013);
    $1029 = Math_fround($976 * $1013);
    $1030 = Math_fround($1022 - $1026);
    $1031 = Math_fround($1023 - $1027);
    $1032 = Math_fround($1024 - $1028);
    $1033 = Math_fround($1025 - $1029);
    $1034 = Math_fround($976 * $1000);
    $1035 = Math_fround($976 * $1001);
    $1036 = Math_fround($973 * $1000);
    $1037 = Math_fround($973 * $1001);
    $1038 = Math_fround($1030 - $1034);
    $1039 = Math_fround($1031 - $1035);
    $1040 = Math_fround($1032 - $1036);
    $1041 = Math_fround($1033 - $1037);
    $1042 = Math_fround($1040 * Math_fround(-1.0));
    $1043 = Math_fround($1041 * Math_fround(-1.0));
    $1044 = Math_fround($1038 * Math_fround(-1.0));
    $1045 = Math_fround($1042 * Math_fround(0.0));
    $1046 = Math_fround($1044 * Math_fround(0.0));
    $1047 = Math_fround($1045 * $1045);
    $1048 = Math_fround($1043 * $1043);
    $1049 = Math_fround($1046 * $1046);
    $1050 = Math_fround($1039 * $1039);
    $1051 = Math_fround($1048 + $1047);
    $1052 = Math_fround($1050 + $1049);
    $1053 = Math_fround($1051 + $1052);
    $1054 = (Math_fround(Math_sqrt((Math_fround($1053)))));
    $1055 = Math_fround(Math_fround(1.0) / $1054);
    $1056 = Math_fround($1055 * $1045);
    $1057 = Math_fround($1055 * $1043);
    $1058 = Math_fround($1055 * $1046);
    $1059 = Math_fround($1055 * $1039);
    $1060 = Math_fround(HEAPF32[$clipIn$i>>2]);
    $1061 = Math_fround(HEAPF32[$836>>2]);
    $1062 = Math_fround(HEAPF32[$837>>2]);
    $1063 = Math_fround(HEAPF32[$838>>2]);
    $1064 = Math_fround(HEAPF32[$859>>2]);
    $1065 = Math_fround(HEAPF32[$860>>2]);
    $1066 = Math_fround(HEAPF32[$861>>2]);
    $1067 = Math_fround(HEAPF32[$862>>2]);
    HEAPF32[$targetRefX>>2] = $1060;
    HEAPF32[$870>>2] = $1061;
    HEAPF32[$871>>2] = $1062;
    HEAPF32[$872>>2] = $1063;
    HEAPF32[$880>>2] = $1056;
    HEAPF32[$881>>2] = $1057;
    HEAPF32[$882>>2] = $1058;
    HEAPF32[$883>>2] = $1059;
    HEAPF32[$888>>2] = $1064;
    HEAPF32[$889>>2] = $1065;
    HEAPF32[$890>>2] = $1066;
    HEAPF32[$891>>2] = $1067;
    $1149 = $947;$1150 = $949;$1153 = $1061;$1311 = $1060;$1315 = $1062;$1317 = $1063;$2906 = $919;$targetTime$0 = $922;
    break;
   }
  } else {
   $1149 = $1124;$1150 = $1124;$1153 = $865;$1311 = $863;$1315 = $867;$1317 = $869;$2906 = Math_fround(1.0);$targetTime$0 = $828;
  }
 } while(0);
 $1068 = (($input) + 8|0);
 $1069 = HEAP32[$1068>>2]|0;
 $1070 = (($1069) + -2)|0;
 $1071 = ($1070|0)>(-1);
 if ($1071) {
  if ($$off0) {
   $1072 = $1070 << 1;
   $1073 = $1072 | -3;
   $1074 = $1073 ^ 2;
   $1075 = (($1074) + ($1069))|0;
   $1076 = $1075;
  } else {
   $1076 = $1070;
  }
  __ZN7mecanim9animation12EvaluateGoalERKNS0_18ClipMuscleConstantERNS0_10ClipMemoryEfi($13,$constant,$memory,$targetTime$0,$1076);
  $1077 = Math_fround(HEAPF32[$13>>2]);
  $1078 = (($13) + 4|0);
  $1079 = Math_fround(HEAPF32[$1078>>2]);
  $1080 = (($13) + 8|0);
  $1081 = Math_fround(HEAPF32[$1080>>2]);
  $1082 = (($13) + 12|0);
  $1083 = Math_fround(HEAPF32[$1082>>2]);
  HEAPF32[$targetGoalX>>2] = $1077;
  $1084 = (($targetGoalX) + 4|0);
  HEAPF32[$1084>>2] = $1079;
  $1085 = (($targetGoalX) + 8|0);
  HEAPF32[$1085>>2] = $1081;
  $1086 = (($targetGoalX) + 12|0);
  HEAPF32[$1086>>2] = $1083;
  $1087 = (($13) + 16|0);
  $1088 = Math_fround(HEAPF32[$1087>>2]);
  $1089 = (($13) + 20|0);
  $1090 = Math_fround(HEAPF32[$1089>>2]);
  $1091 = (($13) + 24|0);
  $1092 = Math_fround(HEAPF32[$1091>>2]);
  $1093 = (($13) + 28|0);
  $1094 = Math_fround(HEAPF32[$1093>>2]);
  $1095 = (($targetGoalX) + 16|0);
  HEAPF32[$1095>>2] = $1088;
  $1096 = (($targetGoalX) + 20|0);
  HEAPF32[$1096>>2] = $1090;
  $1097 = (($targetGoalX) + 24|0);
  HEAPF32[$1097>>2] = $1092;
  HEAPF32[$892>>2] = $1094;
  $1098 = (($13) + 32|0);
  $1099 = Math_fround(HEAPF32[$1098>>2]);
  $1100 = (($13) + 36|0);
  $1101 = Math_fround(HEAPF32[$1100>>2]);
  $1102 = (($13) + 40|0);
  $1103 = Math_fround(HEAPF32[$1102>>2]);
  $1104 = (($13) + 44|0);
  $1105 = Math_fround(HEAPF32[$1104>>2]);
  HEAPF32[$893>>2] = $1099;
  HEAPF32[$894>>2] = $1101;
  HEAPF32[$895>>2] = $1103;
  HEAPF32[$896>>2] = $1105;
  $targetGoalIndex$0 = $1076;
 } else {
  $targetGoalIndex$0 = $1070;
 }
 if ($4102) {
  $1581 = $1421;$1583 = $1425;$1585 = $1427;$1588 = $1295;$1591 = $1137;$1594 = $1299;$1597 = $1301;$1605 = $1423;$1684 = $1469;$1686 = $1473;$1688 = $1475;$1691 = $1303;$1694 = $1146;$1697 = $1307;$1700 = $1309;$1708 = $1471;
 } else {
  $1106 = (($constant) + 1641|0);
  $1107 = HEAP8[$1106>>0]|0;
  $1108 = ($1107<<24>>24)==(0);
  if ($1108) {
   $1297 = $1137;$1305 = $1146;$1313 = $1153;
  } else {
   $1109 = (($constant) + 928|0);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($refLeftFootStartX,$122,$1109);
   $1110 = (($constant) + 976|0);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($refRightFootStartX,$122,$1110);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($refLeftFootPrevX,$prevRootX,$prevLeftFootX);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($refRightFootPrevX,$prevRootX,$prevRightFootX);
   $1111 = (($humanPose) + 80|0);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($refLeftFootX,$rootX,$1111);
   $1112 = (($humanPose) + 156|0);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($refRightFootX,$rootX,$1112);
   $1113 = (($refLeftFootStartX) + 4|0);
   $1114 = Math_fround(HEAPF32[$1113>>2]);
   $1115 = (($refRightFootStartX) + 4|0);
   $1116 = Math_fround(HEAPF32[$1115>>2]);
   $1117 = $1114 < $1116;
   $1118 = $1117 ? $1114 : $1116;
   $1119 = (($refStartX) + 4|0);
   $1120 = Math_fround(HEAPF32[$1119>>2]);
   $1121 = $1120 < $1118;
   $1122 = $1121 ? $1120 : $1118;
   HEAPF32[$1119>>2] = $1122;
   $1123 = $1124 < $1125;
   $1126 = $1123 ? $1124 : $1125;
   $1127 = Math_fround(HEAPF32[$864>>2]);
   $1128 = $1127 < $1126;
   $1129 = $1128 ? $1127 : $1126;
   HEAPF32[$864>>2] = $1129;
   $1130 = (($refLeftFootPrevX) + 4|0);
   $1131 = Math_fround(HEAPF32[$1130>>2]);
   $1132 = (($refRightFootPrevX) + 4|0);
   $1133 = Math_fround(HEAPF32[$1132>>2]);
   $1134 = $1131 < $1133;
   $1135 = $1134 ? $1131 : $1133;
   $1136 = $1137 < $1135;
   $1138 = $1136 ? $1137 : $1135;
   $1139 = (($refLeftFootX) + 4|0);
   $1140 = Math_fround(HEAPF32[$1139>>2]);
   $1141 = (($refRightFootX) + 4|0);
   $1142 = Math_fround(HEAPF32[$1141>>2]);
   $1143 = $1140 < $1142;
   $1144 = $1143 ? $1140 : $1142;
   $1145 = $1146 < $1144;
   $1147 = $1145 ? $1146 : $1144;
   $1148 = $1149 > $1150;
   $1151 = $1148 ? $1149 : $1150;
   $1152 = $1153 < $1151;
   $1154 = $1152 ? $1153 : $1151;
   HEAPF32[$870>>2] = $1154;
   $1297 = $1138;$1305 = $1147;$1313 = $1154;
  }
  $1155 = (($constant) + 1060|0);
  $1156 = Math_fround(HEAPF32[$1155>>2]);
  $1157 = (($constant) + 1056|0);
  $$val = Math_fround(HEAPF32[$1157>>2]);
  $1158 = Math_fround($$val * Math_fround(0.0174532923847436904907));
  $1159 = (Math_fround(Math_abs((Math_fround($1158)))));
  $1160 = Math_fround($1159 * Math_fround(0.5));
  $1161 = +$1160;
  $1162 = $1161 + 1.570796326794896558;
  $1163 = Math_fround($1162);
  $1164 = $1158 > Math_fround(0.0);
  $1165 = $1164&1;
  $1166 = $1158 < Math_fround(0.0);
  $1167 = $1166&1;
  $1168 = (($1165) - ($1167))|0;
  $1169 = (Math_fround(($1168|0)));
  $1170 = Math_fround($1163 + Math_fround(-1.57079637050628662109));
  $1171 = Math_fround($1169 * $1170);
  $1172 = (Math_fround(+(_fmaxf((+$1171),-1.57079541683197021484))));
  $1173 = (Math_fround(+(_fminf((+$1172),1.57079541683197021484))));
  $1174 = Math_fround($1173 * Math_fround(0.159154936671257019043));
  $1175 = Math_fround($1174 + Math_fround(-0.25));
  $1176 = Math_fround($1174 + Math_fround(0.0));
  $1177 = (Math_fround(+(_roundf((+$1175)))));
  $1178 = (Math_fround(+(_roundf((+$1176)))));
  $1179 = Math_fround($1175 - $1177);
  $1180 = Math_fround($1176 - $1178);
  $1181 = (Math_fround(Math_abs((Math_fround($1179)))));
  $1182 = (Math_fround(Math_abs((Math_fround($1180)))));
  $1183 = Math_fround(Math_fround(0.25) - $1181);
  $1184 = Math_fround(Math_fround(0.25) - $1182);
  $1185 = Math_fround($1183 * $1183);
  $1186 = Math_fround($1184 * $1184);
  $1187 = Math_fround($1185 * $1185);
  $1188 = Math_fround($1186 * $1186);
  $1189 = Math_fround($1185 * Math_fround(-41.283184051513671875));
  $1190 = Math_fround($1186 * Math_fround(-41.283184051513671875));
  $1191 = Math_fround($1189 + Math_fround(6.28318548202514648438));
  $1192 = Math_fround($1190 + Math_fround(6.28318548202514648438));
  $1193 = Math_fround($1187 * Math_fround(76.03546142578125));
  $1194 = Math_fround($1188 * Math_fround(76.03546142578125));
  $1195 = Math_fround($1191 + $1193);
  $1196 = Math_fround($1192 + $1194);
  $1197 = Math_fround($1183 * $1195);
  $1198 = Math_fround($1184 * $1196);
  $1199 = Math_fround($1197 / $1198);
  $1200 = Math_fround($1199 * $1199);
  $1201 = Math_fround($1200 + Math_fround(0.0));
  $1202 = Math_fround($1201 + Math_fround(1.0));
  $1203 = (Math_fround(Math_sqrt((Math_fround($1202)))));
  $1204 = Math_fround(Math_fround(1.0) / $1203);
  $1205 = Math_fround($1204 * Math_fround(0.0));
  $1206 = Math_fround($1199 * $1204);
  $1207 = (($constant) + 1639|0);
  $1208 = HEAP8[$1207>>0]|0;
  $1209 = ($1208<<24>>24)==(0);
  if ($1209) {
   $1278 = $1156;
  } else {
   $1210 = (($refStartX) + 4|0);
   $1211 = Math_fround(HEAPF32[$1210>>2]);
   $1212 = Math_fround($1156 - $1211);
   $1278 = $1212;
  }
  $1213 = (($constant) + 1640|0);
  $1214 = HEAP8[$1213>>0]|0;
  $1215 = ($1214<<24>>24)==(0);
  if ($1215) {
   $1274 = Math_fround(0.0);$1282 = Math_fround(0.0);
  } else {
   $1216 = Math_fround(HEAPF32[$refStartX>>2]);
   $1217 = Math_fround(Math_fround(0.0) - $1216);
   $1218 = (($refStartX) + 8|0);
   $1219 = Math_fround(HEAPF32[$1218>>2]);
   $1220 = Math_fround(Math_fround(0.0) - $1219);
   $1274 = $1217;$1282 = $1220;
  }
  $1221 = (($constant) + 1638|0);
  $1222 = HEAP8[$1221>>0]|0;
  $1223 = ($1222<<24>>24)==(0);
  $$phi$trans$insert = (($refStartX) + 16|0);
  $$pre707 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  if ($1223) {
   $$pre708 = Math_fround(HEAPF32[$262>>2]);
   $$phi$trans$insert709 = (($refStartX) + 20|0);
   $$pre710 = Math_fround(HEAPF32[$$phi$trans$insert709>>2]);
   $$phi$trans$insert711 = (($refStartX) + 24|0);
   $$pre712 = Math_fround(HEAPF32[$$phi$trans$insert711>>2]);
   $1320 = $1206;$1322 = $$pre708;$1323 = $1204;$1326 = $$pre710;$1327 = $1205;$1330 = $$pre712;$1331 = $1205;
  } else {
   $1224 = Math_fround($$pre707 * Math_fround(-1.0));
   $1225 = (($refStartX) + 20|0);
   $1226 = Math_fround(HEAPF32[$1225>>2]);
   $1227 = Math_fround($1226 * Math_fround(-1.0));
   $1228 = (($refStartX) + 24|0);
   $1229 = Math_fround(HEAPF32[$1228>>2]);
   $1230 = Math_fround($1229 * Math_fround(-1.0));
   $1231 = Math_fround(HEAPF32[$262>>2]);
   $1232 = Math_fround($1206 * $1224);
   $1233 = Math_fround($1204 * $1231);
   $1234 = Math_fround($1205 * $1227);
   $1235 = Math_fround($1205 * $1230);
   $1236 = Math_fround($1204 * $1230);
   $1237 = Math_fround($1205 * $1224);
   $1238 = Math_fround($1206 * $1230);
   $1239 = Math_fround($1232 - $1236);
   $1240 = Math_fround($1233 - $1237);
   $1241 = Math_fround($1234 - $1238);
   $1242 = Math_fround($1235 - $1237);
   $1243 = Math_fround($1205 * $1231);
   $1244 = Math_fround($1204 * $1224);
   $1245 = Math_fround($1204 * $1227);
   $1246 = Math_fround($1239 - $1243);
   $1247 = Math_fround($1240 - $1235);
   $1248 = Math_fround($1241 - $1244);
   $1249 = Math_fround($1242 - $1245);
   $1250 = Math_fround($1206 * $1227);
   $1251 = Math_fround($1206 * $1231);
   $1252 = Math_fround($1246 - $1234);
   $1253 = Math_fround($1247 - $1250);
   $1254 = Math_fround($1248 - $1243);
   $1255 = Math_fround($1249 - $1251);
   $1256 = Math_fround($1254 * Math_fround(-1.0));
   $1257 = Math_fround($1255 * Math_fround(-1.0));
   $1258 = Math_fround($1252 * Math_fround(-1.0));
   $1259 = Math_fround($1256 * $1256);
   $1260 = Math_fround($1257 * $1257);
   $1261 = Math_fround($1258 * $1258);
   $1262 = Math_fround($1253 * $1253);
   $1263 = Math_fround($1259 + $1260);
   $1264 = Math_fround($1262 + $1261);
   $1265 = Math_fround($1263 + $1264);
   $1266 = (Math_fround(Math_sqrt((Math_fround($1265)))));
   $1267 = Math_fround(Math_fround(1.0) / $1266);
   $1268 = Math_fround($1267 * $1256);
   $1269 = Math_fround($1267 * $1257);
   $1270 = Math_fround($1267 * $1258);
   $1271 = Math_fround($1267 * $1253);
   $1320 = $1269;$1322 = $1231;$1323 = $1271;$1326 = $1226;$1327 = $1270;$1330 = $1229;$1331 = $1268;
  }
  $1272 = Math_fround(HEAPF32[$refStartX>>2]);
  $1273 = Math_fround($1274 + $1272);
  $1275 = (($refStartX) + 4|0);
  $1276 = Math_fround(HEAPF32[$1275>>2]);
  $1277 = Math_fround($1278 + $1276);
  $1279 = (($refStartX) + 8|0);
  $1280 = Math_fround(HEAPF32[$1279>>2]);
  $1281 = Math_fround($1282 + $1280);
  $1283 = (($refStartX) + 12|0);
  $1284 = Math_fround(HEAPF32[$1283>>2]);
  $1285 = Math_fround($1284 + Math_fround(0.0));
  HEAPF32[$refStartX>>2] = $1273;
  HEAPF32[$1275>>2] = $1277;
  HEAPF32[$1279>>2] = $1281;
  HEAPF32[$1283>>2] = $1285;
  $1286 = Math_fround(HEAPF32[$refStopX>>2]);
  $1287 = Math_fround($1274 + $1286);
  $1288 = Math_fround(HEAPF32[$864>>2]);
  $1289 = Math_fround($1278 + $1288);
  $1290 = Math_fround(HEAPF32[$866>>2]);
  $1291 = Math_fround($1282 + $1290);
  $1292 = Math_fround(HEAPF32[$868>>2]);
  $1293 = Math_fround($1292 + Math_fround(0.0));
  HEAPF32[$refStopX>>2] = $1287;
  HEAPF32[$864>>2] = $1289;
  HEAPF32[$866>>2] = $1291;
  HEAPF32[$868>>2] = $1293;
  $1294 = Math_fround($1295 + $1274);
  $1296 = Math_fround($1297 + $1278);
  $1298 = Math_fround($1299 + $1282);
  $1300 = Math_fround($1301 + Math_fround(0.0));
  $1302 = Math_fround($1303 + $1274);
  $1304 = Math_fround($1305 + $1278);
  $1306 = Math_fround($1307 + $1282);
  $1308 = Math_fround($1309 + Math_fround(0.0));
  $1310 = Math_fround($1274 + $1311);
  $1312 = Math_fround($1278 + $1313);
  $1314 = Math_fround($1282 + $1315);
  $1316 = Math_fround($1317 + Math_fround(0.0));
  HEAPF32[$targetRefX>>2] = $1310;
  HEAPF32[$870>>2] = $1312;
  HEAPF32[$871>>2] = $1314;
  HEAPF32[$872>>2] = $1316;
  $1318 = (($refStartX) + 16|0);
  $1319 = Math_fround($1320 * $$pre707);
  $1321 = Math_fround($1323 * $1322);
  $1324 = (($refStartX) + 20|0);
  $1325 = Math_fround($1327 * $1326);
  $1328 = (($refStartX) + 24|0);
  $1329 = Math_fround($1331 * $1330);
  $1332 = Math_fround($1323 * $1330);
  $1333 = Math_fround($1331 * $$pre707);
  $1334 = Math_fround($1320 * $1330);
  $1335 = Math_fround($1327 * $$pre707);
  $1336 = Math_fround($1319 - $1332);
  $1337 = Math_fround($1321 - $1333);
  $1338 = Math_fround($1325 - $1334);
  $1339 = Math_fround($1329 - $1335);
  $1340 = Math_fround($1327 * $1322);
  $1341 = Math_fround($1327 * $1330);
  $1342 = Math_fround($1323 * $$pre707);
  $1343 = Math_fround($1323 * $1326);
  $1344 = Math_fround($1336 - $1340);
  $1345 = Math_fround($1337 - $1341);
  $1346 = Math_fround($1338 - $1342);
  $1347 = Math_fround($1339 - $1343);
  $1348 = Math_fround($1331 * $1326);
  $1349 = Math_fround($1320 * $1326);
  $1350 = Math_fround($1331 * $1322);
  $1351 = Math_fround($1320 * $1322);
  $1352 = Math_fround($1344 - $1348);
  $1353 = Math_fround($1345 - $1349);
  $1354 = Math_fround($1346 - $1350);
  $1355 = Math_fround($1347 - $1351);
  $1356 = Math_fround($1354 * Math_fround(-1.0));
  $1357 = Math_fround($1355 * Math_fround(-1.0));
  $1358 = Math_fround($1352 * Math_fround(-1.0));
  $1359 = Math_fround($1356 * $1356);
  $1360 = Math_fround($1357 * $1357);
  $1361 = Math_fround($1358 * $1358);
  $1362 = Math_fround($1353 * $1353);
  $1363 = Math_fround($1359 + $1360);
  $1364 = Math_fround($1362 + $1361);
  $1365 = Math_fround($1363 + $1364);
  $1366 = (Math_fround(Math_sqrt((Math_fround($1365)))));
  $1367 = Math_fround(Math_fround(1.0) / $1366);
  $1368 = Math_fround($1367 * $1356);
  $1369 = Math_fround($1367 * $1357);
  $1370 = Math_fround($1367 * $1358);
  $1371 = Math_fround($1367 * $1353);
  HEAPF32[$1318>>2] = $1368;
  HEAPF32[$1324>>2] = $1369;
  HEAPF32[$1328>>2] = $1370;
  HEAPF32[$262>>2] = $1371;
  $1372 = Math_fround(HEAPF32[$873>>2]);
  $1373 = Math_fround($1320 * $1372);
  $1374 = Math_fround(HEAPF32[$267>>2]);
  $1375 = Math_fround($1323 * $1374);
  $1376 = Math_fround(HEAPF32[$875>>2]);
  $1377 = Math_fround($1327 * $1376);
  $1378 = Math_fround(HEAPF32[$877>>2]);
  $1379 = Math_fround($1331 * $1378);
  $1380 = Math_fround($1323 * $1378);
  $1381 = Math_fround($1331 * $1372);
  $1382 = Math_fround($1320 * $1378);
  $1383 = Math_fround($1327 * $1372);
  $1384 = Math_fround($1373 - $1380);
  $1385 = Math_fround($1375 - $1381);
  $1386 = Math_fround($1377 - $1382);
  $1387 = Math_fround($1379 - $1383);
  $1388 = Math_fround($1327 * $1374);
  $1389 = Math_fround($1327 * $1378);
  $1390 = Math_fround($1323 * $1372);
  $1391 = Math_fround($1323 * $1376);
  $1392 = Math_fround($1384 - $1388);
  $1393 = Math_fround($1385 - $1389);
  $1394 = Math_fround($1386 - $1390);
  $1395 = Math_fround($1387 - $1391);
  $1396 = Math_fround($1331 * $1376);
  $1397 = Math_fround($1320 * $1376);
  $1398 = Math_fround($1331 * $1374);
  $1399 = Math_fround($1320 * $1374);
  $1400 = Math_fround($1392 - $1396);
  $1401 = Math_fround($1393 - $1397);
  $1402 = Math_fround($1394 - $1398);
  $1403 = Math_fround($1395 - $1399);
  $1404 = Math_fround($1402 * Math_fround(-1.0));
  $1405 = Math_fround($1403 * Math_fround(-1.0));
  $1406 = Math_fround($1400 * Math_fround(-1.0));
  $1407 = Math_fround($1404 * $1404);
  $1408 = Math_fround($1405 * $1405);
  $1409 = Math_fround($1406 * $1406);
  $1410 = Math_fround($1401 * $1401);
  $1411 = Math_fround($1407 + $1408);
  $1412 = Math_fround($1410 + $1409);
  $1413 = Math_fround($1411 + $1412);
  $1414 = (Math_fround(Math_sqrt((Math_fround($1413)))));
  $1415 = Math_fround(Math_fround(1.0) / $1414);
  $1416 = Math_fround($1415 * $1404);
  $1417 = Math_fround($1415 * $1405);
  $1418 = Math_fround($1415 * $1406);
  $1419 = Math_fround($1415 * $1401);
  HEAPF32[$873>>2] = $1416;
  HEAPF32[$875>>2] = $1417;
  HEAPF32[$877>>2] = $1418;
  HEAPF32[$267>>2] = $1419;
  $1420 = Math_fround($1421 * $1320);
  $1422 = Math_fround($1423 * $1323);
  $1424 = Math_fround($1425 * $1327);
  $1426 = Math_fround($1427 * $1331);
  $1428 = Math_fround($1427 * $1323);
  $1429 = Math_fround($1421 * $1331);
  $1430 = Math_fround($1427 * $1320);
  $1431 = Math_fround($1421 * $1327);
  $1432 = Math_fround($1420 - $1428);
  $1433 = Math_fround($1422 - $1429);
  $1434 = Math_fround($1424 - $1430);
  $1435 = Math_fround($1426 - $1431);
  $1436 = Math_fround($1423 * $1327);
  $1437 = Math_fround($1427 * $1327);
  $1438 = Math_fround($1421 * $1323);
  $1439 = Math_fround($1425 * $1323);
  $1440 = Math_fround($1432 - $1436);
  $1441 = Math_fround($1433 - $1437);
  $1442 = Math_fround($1434 - $1438);
  $1443 = Math_fround($1435 - $1439);
  $1444 = Math_fround($1425 * $1331);
  $1445 = Math_fround($1425 * $1320);
  $1446 = Math_fround($1423 * $1331);
  $1447 = Math_fround($1423 * $1320);
  $1448 = Math_fround($1440 - $1444);
  $1449 = Math_fround($1441 - $1445);
  $1450 = Math_fround($1442 - $1446);
  $1451 = Math_fround($1443 - $1447);
  $1452 = Math_fround($1450 * Math_fround(-1.0));
  $1453 = Math_fround($1451 * Math_fround(-1.0));
  $1454 = Math_fround($1448 * Math_fround(-1.0));
  $1455 = Math_fround($1452 * $1452);
  $1456 = Math_fround($1453 * $1453);
  $1457 = Math_fround($1454 * $1454);
  $1458 = Math_fround($1449 * $1449);
  $1459 = Math_fround($1455 + $1456);
  $1460 = Math_fround($1457 + $1458);
  $1461 = Math_fround($1460 + $1459);
  $1462 = (Math_fround(Math_sqrt((Math_fround($1461)))));
  $1463 = Math_fround(Math_fround(1.0) / $1462);
  $1464 = Math_fround($1452 * $1463);
  $1465 = Math_fround($1453 * $1463);
  $1466 = Math_fround($1454 * $1463);
  $1467 = Math_fround($1449 * $1463);
  $1468 = Math_fround($1469 * $1320);
  $1470 = Math_fround($1471 * $1323);
  $1472 = Math_fround($1473 * $1327);
  $1474 = Math_fround($1475 * $1331);
  $1476 = Math_fround($1475 * $1323);
  $1477 = Math_fround($1469 * $1331);
  $1478 = Math_fround($1475 * $1320);
  $1479 = Math_fround($1469 * $1327);
  $1480 = Math_fround($1468 - $1476);
  $1481 = Math_fround($1470 - $1477);
  $1482 = Math_fround($1472 - $1478);
  $1483 = Math_fround($1474 - $1479);
  $1484 = Math_fround($1471 * $1327);
  $1485 = Math_fround($1475 * $1327);
  $1486 = Math_fround($1469 * $1323);
  $1487 = Math_fround($1473 * $1323);
  $1488 = Math_fround($1480 - $1484);
  $1489 = Math_fround($1481 - $1485);
  $1490 = Math_fround($1482 - $1486);
  $1491 = Math_fround($1483 - $1487);
  $1492 = Math_fround($1473 * $1331);
  $1493 = Math_fround($1473 * $1320);
  $1494 = Math_fround($1471 * $1331);
  $1495 = Math_fround($1471 * $1320);
  $1496 = Math_fround($1488 - $1492);
  $1497 = Math_fround($1489 - $1493);
  $1498 = Math_fround($1490 - $1494);
  $1499 = Math_fround($1491 - $1495);
  $1500 = Math_fround($1498 * Math_fround(-1.0));
  $1501 = Math_fround($1499 * Math_fround(-1.0));
  $1502 = Math_fround($1496 * Math_fround(-1.0));
  $1503 = Math_fround($1500 * $1500);
  $1504 = Math_fround($1501 * $1501);
  $1505 = Math_fround($1502 * $1502);
  $1506 = Math_fround($1497 * $1497);
  $1507 = Math_fround($1503 + $1504);
  $1508 = Math_fround($1505 + $1506);
  $1509 = Math_fround($1508 + $1507);
  $1510 = (Math_fround(Math_sqrt((Math_fround($1509)))));
  $1511 = Math_fround(Math_fround(1.0) / $1510);
  $1512 = Math_fround($1500 * $1511);
  $1513 = Math_fround($1501 * $1511);
  $1514 = Math_fround($1502 * $1511);
  $1515 = Math_fround($1497 * $1511);
  $1516 = Math_fround(HEAPF32[$880>>2]);
  $1517 = Math_fround($1320 * $1516);
  $1518 = Math_fround(HEAPF32[$883>>2]);
  $1519 = Math_fround($1323 * $1518);
  $1520 = Math_fround(HEAPF32[$881>>2]);
  $1521 = Math_fround($1327 * $1520);
  $1522 = Math_fround(HEAPF32[$882>>2]);
  $1523 = Math_fround($1331 * $1522);
  $1524 = Math_fround($1323 * $1522);
  $1525 = Math_fround($1331 * $1516);
  $1526 = Math_fround($1320 * $1522);
  $1527 = Math_fround($1327 * $1516);
  $1528 = Math_fround($1517 - $1524);
  $1529 = Math_fround($1519 - $1525);
  $1530 = Math_fround($1521 - $1526);
  $1531 = Math_fround($1523 - $1527);
  $1532 = Math_fround($1327 * $1518);
  $1533 = Math_fround($1327 * $1522);
  $1534 = Math_fround($1323 * $1516);
  $1535 = Math_fround($1323 * $1520);
  $1536 = Math_fround($1528 - $1532);
  $1537 = Math_fround($1529 - $1533);
  $1538 = Math_fround($1530 - $1534);
  $1539 = Math_fround($1531 - $1535);
  $1540 = Math_fround($1331 * $1520);
  $1541 = Math_fround($1320 * $1520);
  $1542 = Math_fround($1331 * $1518);
  $1543 = Math_fround($1320 * $1518);
  $1544 = Math_fround($1536 - $1540);
  $1545 = Math_fround($1537 - $1541);
  $1546 = Math_fround($1538 - $1542);
  $1547 = Math_fround($1539 - $1543);
  $1548 = Math_fround($1546 * Math_fround(-1.0));
  $1549 = Math_fround($1547 * Math_fround(-1.0));
  $1550 = Math_fround($1544 * Math_fround(-1.0));
  $1551 = Math_fround($1548 * $1548);
  $1552 = Math_fround($1549 * $1549);
  $1553 = Math_fround($1550 * $1550);
  $1554 = Math_fround($1545 * $1545);
  $1555 = Math_fround($1551 + $1552);
  $1556 = Math_fround($1554 + $1553);
  $1557 = Math_fround($1555 + $1556);
  $1558 = (Math_fround(Math_sqrt((Math_fround($1557)))));
  $1559 = Math_fround(Math_fround(1.0) / $1558);
  $1560 = Math_fround($1559 * $1548);
  $1561 = Math_fround($1559 * $1549);
  $1562 = Math_fround($1559 * $1550);
  $1563 = Math_fround($1559 * $1545);
  HEAPF32[$880>>2] = $1560;
  HEAPF32[$881>>2] = $1561;
  HEAPF32[$882>>2] = $1562;
  HEAPF32[$883>>2] = $1563;
  $1564 = (($constant) + 1635|0);
  $1565 = HEAP8[$1564>>0]|0;
  $1566 = ($1565<<24>>24)==(0);
  if ($1566) {
   $4104 = $1467;$4105 = $1466;$4106 = $1465;$4107 = $1464;$4108 = $1515;$4109 = $1514;$4110 = $1513;$4111 = $1512;
  } else {
   $1567 = Math_fround(HEAPF32[$1318>>2]);
   $1568 = Math_fround(HEAPF32[$1324>>2]);
   $1569 = Math_fround(HEAPF32[$1328>>2]);
   $1570 = Math_fround(HEAPF32[$262>>2]);
   HEAPF32[$873>>2] = $1567;
   HEAPF32[$875>>2] = $1568;
   HEAPF32[$877>>2] = $1569;
   HEAPF32[$267>>2] = $1570;
   HEAPF32[$880>>2] = $1567;
   HEAPF32[$881>>2] = $1568;
   HEAPF32[$882>>2] = $1569;
   HEAPF32[$883>>2] = $1570;
   $4104 = $1570;$4105 = $1569;$4106 = $1568;$4107 = $1567;$4108 = $1570;$4109 = $1569;$4110 = $1568;$4111 = $1567;
  }
  $1571 = (($constant) + 1636|0);
  $1572 = HEAP8[$1571>>0]|0;
  $1573 = ($1572<<24>>24)==(0);
  if ($1573) {
   $4112 = $1296;$4113 = $1304;
  } else {
   $1574 = Math_fround(HEAPF32[$1275>>2]);
   HEAPF32[$864>>2] = $1574;
   HEAPF32[$870>>2] = $1574;
   $4112 = $1574;$4113 = $1574;
  }
  $1575 = (($constant) + 1637|0);
  $1576 = HEAP8[$1575>>0]|0;
  $1577 = ($1576<<24>>24)==(0);
  if ($1577) {
   $1581 = $4107;$1583 = $4106;$1585 = $4105;$1588 = $1294;$1591 = $4112;$1594 = $1298;$1597 = $1300;$1605 = $4104;$1684 = $4111;$1686 = $4110;$1688 = $4109;$1691 = $1302;$1694 = $4113;$1697 = $1306;$1700 = $1308;$1708 = $4108;
  } else {
   $1578 = Math_fround(HEAPF32[$refStartX>>2]);
   HEAPF32[$refStopX>>2] = $1578;
   HEAPF32[$targetRefX>>2] = $1578;
   $1579 = Math_fround(HEAPF32[$1279>>2]);
   HEAPF32[$866>>2] = $1579;
   HEAPF32[$871>>2] = $1579;
   $1581 = $4107;$1583 = $4106;$1585 = $4105;$1588 = $1578;$1591 = $4112;$1594 = $1579;$1597 = $1300;$1605 = $4104;$1684 = $4111;$1686 = $4110;$1688 = $4109;$1691 = $1578;$1694 = $4113;$1697 = $1579;$1700 = $1308;$1708 = $4108;
  }
 }
 $1580 = Math_fround($1581 * Math_fround(-1.0));
 $1582 = Math_fround($1583 * Math_fround(-1.0));
 $1584 = Math_fround($1585 * Math_fround(-1.0));
 $1586 = Math_fround(HEAPF32[$prevRootX>>2]);
 $1587 = Math_fround($1586 - $1588);
 $1589 = Math_fround(HEAPF32[$131>>2]);
 $1590 = Math_fround($1589 - $1591);
 $1592 = Math_fround(HEAPF32[$132>>2]);
 $1593 = Math_fround($1592 - $1594);
 $1595 = Math_fround(HEAPF32[$133>>2]);
 $1596 = Math_fround($1595 - $1597);
 $1598 = Math_fround($1587 + $1587);
 $1599 = Math_fround($1590 + $1590);
 $1600 = Math_fround($1593 + $1593);
 $1601 = Math_fround($1580 * $1599);
 $1602 = Math_fround($1582 * $1600);
 $1603 = Math_fround($1584 * $1598);
 $1604 = Math_fround($1605 * Math_fround(0.0));
 $1606 = Math_fround($1582 * $1598);
 $1607 = Math_fround($1584 * $1599);
 $1608 = Math_fround($1580 * $1600);
 $1609 = Math_fround($1601 - $1606);
 $1610 = Math_fround($1602 - $1607);
 $1611 = Math_fround($1603 - $1608);
 $1612 = Math_fround($1604 - $1604);
 $1613 = Math_fround($1605 * $1610);
 $1614 = Math_fround($1605 * $1611);
 $1615 = Math_fround($1605 * $1609);
 $1616 = Math_fround($1605 * $1612);
 $1617 = Math_fround($1587 + $1613);
 $1618 = Math_fround($1590 + $1614);
 $1619 = Math_fround($1593 + $1615);
 $1620 = Math_fround($1616 + $1596);
 $1621 = Math_fround($1580 * $1611);
 $1622 = Math_fround($1582 * $1609);
 $1623 = Math_fround($1584 * $1610);
 $1624 = Math_fround($1582 * $1610);
 $1625 = Math_fround($1584 * $1611);
 $1626 = Math_fround($1580 * $1609);
 $1627 = Math_fround($1621 - $1624);
 $1628 = Math_fround($1622 - $1625);
 $1629 = Math_fround($1623 - $1626);
 $1630 = Math_fround($1616 - $1616);
 $1631 = Math_fround($1617 + $1628);
 $1632 = Math_fround($1618 + $1629);
 $1633 = Math_fround($1619 + $1627);
 $1634 = Math_fround($1630 + $1620);
 $1635 = Math_fround(HEAPF32[$142>>2]);
 $1636 = Math_fround($1582 * $1635);
 $1637 = Math_fround(HEAPF32[$145>>2]);
 $1638 = Math_fround($1605 * $1637);
 $1639 = Math_fround(HEAPF32[$143>>2]);
 $1640 = Math_fround($1584 * $1639);
 $1641 = Math_fround(HEAPF32[$144>>2]);
 $1642 = Math_fround($1580 * $1641);
 $1643 = Math_fround($1605 * $1641);
 $1644 = Math_fround($1580 * $1635);
 $1645 = Math_fround($1582 * $1641);
 $1646 = Math_fround($1584 * $1635);
 $1647 = Math_fround($1636 - $1643);
 $1648 = Math_fround($1638 - $1644);
 $1649 = Math_fround($1640 - $1645);
 $1650 = Math_fround($1642 - $1646);
 $1651 = Math_fround($1584 * $1637);
 $1652 = Math_fround($1584 * $1641);
 $1653 = Math_fround($1605 * $1635);
 $1654 = Math_fround($1605 * $1639);
 $1655 = Math_fround($1647 - $1651);
 $1656 = Math_fround($1648 - $1652);
 $1657 = Math_fround($1649 - $1653);
 $1658 = Math_fround($1650 - $1654);
 $1659 = Math_fround($1580 * $1639);
 $1660 = Math_fround($1582 * $1639);
 $1661 = Math_fround($1580 * $1637);
 $1662 = Math_fround($1582 * $1637);
 $1663 = Math_fround($1655 - $1659);
 $1664 = Math_fround($1656 - $1660);
 $1665 = Math_fround($1657 - $1661);
 $1666 = Math_fround($1658 - $1662);
 $1667 = Math_fround($1665 * Math_fround(-1.0));
 $1668 = Math_fround($1666 * Math_fround(-1.0));
 $1669 = Math_fround($1663 * Math_fround(-1.0));
 $1670 = Math_fround($1667 * $1667);
 $1671 = Math_fround($1668 * $1668);
 $1672 = Math_fround($1669 * $1669);
 $1673 = Math_fround($1664 * $1664);
 $1674 = Math_fround($1670 + $1671);
 $1675 = Math_fround($1673 + $1672);
 $1676 = Math_fround($1674 + $1675);
 $1677 = (Math_fround(Math_sqrt((Math_fround($1676)))));
 $1678 = Math_fround(Math_fround(1.0) / $1677);
 $1679 = Math_fround($1678 * $1667);
 $1680 = Math_fround($1678 * $1668);
 $1681 = Math_fround($1678 * $1669);
 $1682 = Math_fround($1678 * $1664);
 HEAPF32[$prevRootX>>2] = $1631;
 HEAPF32[$131>>2] = $1632;
 HEAPF32[$132>>2] = $1633;
 HEAPF32[$133>>2] = $1634;
 HEAPF32[$142>>2] = $1679;
 HEAPF32[$143>>2] = $1680;
 HEAPF32[$144>>2] = $1681;
 HEAPF32[$145>>2] = $1682;
 HEAPF32[$154>>2] = Math_fround(1.0);
 HEAPF32[$155>>2] = Math_fround(1.0);
 HEAPF32[$156>>2] = Math_fround(1.0);
 HEAPF32[$157>>2] = Math_fround(1.0);
 $1683 = Math_fround($1684 * Math_fround(-1.0));
 $1685 = Math_fround($1686 * Math_fround(-1.0));
 $1687 = Math_fround($1688 * Math_fround(-1.0));
 $1689 = Math_fround(HEAPF32[$rootX>>2]);
 $1690 = Math_fround($1689 - $1691);
 $1692 = Math_fround(HEAPF32[$235>>2]);
 $1693 = Math_fround($1692 - $1694);
 $1695 = Math_fround(HEAPF32[$236>>2]);
 $1696 = Math_fround($1695 - $1697);
 $1698 = Math_fround(HEAPF32[$237>>2]);
 $1699 = Math_fround($1698 - $1700);
 $1701 = Math_fround($1690 + $1690);
 $1702 = Math_fround($1693 + $1693);
 $1703 = Math_fround($1696 + $1696);
 $1704 = Math_fround($1683 * $1702);
 $1705 = Math_fround($1685 * $1703);
 $1706 = Math_fround($1687 * $1701);
 $1707 = Math_fround($1708 * Math_fround(0.0));
 $1709 = Math_fround($1685 * $1701);
 $1710 = Math_fround($1687 * $1702);
 $1711 = Math_fround($1683 * $1703);
 $1712 = Math_fround($1704 - $1709);
 $1713 = Math_fround($1705 - $1710);
 $1714 = Math_fround($1706 - $1711);
 $1715 = Math_fround($1707 - $1707);
 $1716 = Math_fround($1708 * $1713);
 $1717 = Math_fround($1708 * $1714);
 $1718 = Math_fround($1708 * $1712);
 $1719 = Math_fround($1708 * $1715);
 $1720 = Math_fround($1690 + $1716);
 $1721 = Math_fround($1693 + $1717);
 $1722 = Math_fround($1696 + $1718);
 $1723 = Math_fround($1719 + $1699);
 $1724 = Math_fround($1683 * $1714);
 $1725 = Math_fround($1685 * $1712);
 $1726 = Math_fround($1687 * $1713);
 $1727 = Math_fround($1685 * $1713);
 $1728 = Math_fround($1687 * $1714);
 $1729 = Math_fround($1683 * $1712);
 $1730 = Math_fround($1724 - $1727);
 $1731 = Math_fround($1725 - $1728);
 $1732 = Math_fround($1726 - $1729);
 $1733 = Math_fround($1719 - $1719);
 $1734 = Math_fround($1720 + $1731);
 $1735 = Math_fround($1721 + $1732);
 $1736 = Math_fround($1722 + $1730);
 $1737 = Math_fround($1733 + $1723);
 $1738 = Math_fround(HEAPF32[$246>>2]);
 $1739 = Math_fround($1685 * $1738);
 $1740 = Math_fround(HEAPF32[$249>>2]);
 $1741 = Math_fround($1708 * $1740);
 $1742 = Math_fround(HEAPF32[$247>>2]);
 $1743 = Math_fround($1687 * $1742);
 $1744 = Math_fround(HEAPF32[$248>>2]);
 $1745 = Math_fround($1683 * $1744);
 $1746 = Math_fround($1708 * $1744);
 $1747 = Math_fround($1683 * $1738);
 $1748 = Math_fround($1685 * $1744);
 $1749 = Math_fround($1687 * $1738);
 $1750 = Math_fround($1739 - $1746);
 $1751 = Math_fround($1741 - $1747);
 $1752 = Math_fround($1743 - $1748);
 $1753 = Math_fround($1745 - $1749);
 $1754 = Math_fround($1687 * $1740);
 $1755 = Math_fround($1687 * $1744);
 $1756 = Math_fround($1708 * $1738);
 $1757 = Math_fround($1708 * $1742);
 $1758 = Math_fround($1750 - $1754);
 $1759 = Math_fround($1751 - $1755);
 $1760 = Math_fround($1752 - $1756);
 $1761 = Math_fround($1753 - $1757);
 $1762 = Math_fround($1683 * $1742);
 $1763 = Math_fround($1685 * $1742);
 $1764 = Math_fround($1683 * $1740);
 $1765 = Math_fround($1685 * $1740);
 $1766 = Math_fround($1758 - $1762);
 $1767 = Math_fround($1759 - $1763);
 $1768 = Math_fround($1760 - $1764);
 $1769 = Math_fround($1761 - $1765);
 $1770 = Math_fround($1768 * Math_fround(-1.0));
 $1771 = Math_fround($1769 * Math_fround(-1.0));
 $1772 = Math_fround($1766 * Math_fround(-1.0));
 $1773 = Math_fround($1770 * $1770);
 $1774 = Math_fround($1771 * $1771);
 $1775 = Math_fround($1772 * $1772);
 $1776 = Math_fround($1767 * $1767);
 $1777 = Math_fround($1773 + $1774);
 $1778 = Math_fround($1776 + $1775);
 $1779 = Math_fround($1777 + $1778);
 $1780 = (Math_fround(Math_sqrt((Math_fround($1779)))));
 $1781 = Math_fround(Math_fround(1.0) / $1780);
 $1782 = Math_fround($1781 * $1770);
 $1783 = Math_fround($1781 * $1771);
 $1784 = Math_fround($1781 * $1772);
 $1785 = Math_fround($1781 * $1767);
 HEAPF32[$rootX>>2] = $1734;
 HEAPF32[$235>>2] = $1735;
 HEAPF32[$236>>2] = $1736;
 HEAPF32[$237>>2] = $1737;
 HEAPF32[$246>>2] = $1782;
 HEAPF32[$247>>2] = $1783;
 HEAPF32[$248>>2] = $1784;
 HEAPF32[$249>>2] = $1785;
 HEAPF32[$258>>2] = Math_fround(1.0);
 HEAPF32[$259>>2] = Math_fround(1.0);
 HEAPF32[$260>>2] = Math_fround(1.0);
 HEAPF32[$261>>2] = Math_fround(1.0);
 $1786 = Math_fround(HEAPF32[$880>>2]);
 $1787 = Math_fround($1786 * Math_fround(-1.0));
 $1788 = Math_fround(HEAPF32[$881>>2]);
 $1789 = Math_fround($1788 * Math_fround(-1.0));
 $1790 = Math_fround(HEAPF32[$882>>2]);
 $1791 = Math_fround($1790 * Math_fround(-1.0));
 $1792 = Math_fround(HEAPF32[$883>>2]);
 $1793 = Math_fround(HEAPF32[$clipIn$i>>2]);
 $1794 = Math_fround(HEAPF32[$targetRefX>>2]);
 $1795 = Math_fround($1793 - $1794);
 $1796 = Math_fround(HEAPF32[$836>>2]);
 $1797 = Math_fround(HEAPF32[$870>>2]);
 $1798 = Math_fround($1796 - $1797);
 $1799 = Math_fround(HEAPF32[$837>>2]);
 $1800 = Math_fround(HEAPF32[$871>>2]);
 $1801 = Math_fround($1799 - $1800);
 $1802 = Math_fround(HEAPF32[$838>>2]);
 $1803 = Math_fround(HEAPF32[$872>>2]);
 $1804 = Math_fround($1802 - $1803);
 $1805 = Math_fround($1795 + $1795);
 $1806 = Math_fround($1798 + $1798);
 $1807 = Math_fround($1801 + $1801);
 $1808 = Math_fround($1787 * $1806);
 $1809 = Math_fround($1789 * $1807);
 $1810 = Math_fround($1791 * $1805);
 $1811 = Math_fround($1792 * Math_fround(0.0));
 $1812 = Math_fround($1789 * $1805);
 $1813 = Math_fround($1791 * $1806);
 $1814 = Math_fround($1787 * $1807);
 $1815 = Math_fround($1808 - $1812);
 $1816 = Math_fround($1809 - $1813);
 $1817 = Math_fround($1810 - $1814);
 $1818 = Math_fround($1811 - $1811);
 $1819 = Math_fround($1792 * $1816);
 $1820 = Math_fround($1792 * $1817);
 $1821 = Math_fround($1792 * $1815);
 $1822 = Math_fround($1792 * $1818);
 $1823 = Math_fround($1795 + $1819);
 $1824 = Math_fround($1798 + $1820);
 $1825 = Math_fround($1801 + $1821);
 $1826 = Math_fround($1822 + $1804);
 $1827 = Math_fround($1787 * $1817);
 $1828 = Math_fround($1789 * $1815);
 $1829 = Math_fround($1791 * $1816);
 $1830 = Math_fround($1789 * $1816);
 $1831 = Math_fround($1791 * $1817);
 $1832 = Math_fround($1787 * $1815);
 $1833 = Math_fround($1827 - $1830);
 $1834 = Math_fround($1828 - $1831);
 $1835 = Math_fround($1829 - $1832);
 $1836 = Math_fround($1822 - $1822);
 $1837 = Math_fround($1823 + $1834);
 $1838 = Math_fround($1824 + $1835);
 $1839 = Math_fround($1825 + $1833);
 $1840 = Math_fround($1836 + $1826);
 $1841 = Math_fround(HEAPF32[$847>>2]);
 $1842 = Math_fround($1789 * $1841);
 $1843 = Math_fround(HEAPF32[$850>>2]);
 $1844 = Math_fround($1792 * $1843);
 $1845 = Math_fround(HEAPF32[$848>>2]);
 $1846 = Math_fround($1791 * $1845);
 $1847 = Math_fround(HEAPF32[$849>>2]);
 $1848 = Math_fround($1787 * $1847);
 $1849 = Math_fround($1792 * $1847);
 $1850 = Math_fround($1787 * $1841);
 $1851 = Math_fround($1789 * $1847);
 $1852 = Math_fround($1791 * $1841);
 $1853 = Math_fround($1842 - $1849);
 $1854 = Math_fround($1844 - $1850);
 $1855 = Math_fround($1846 - $1851);
 $1856 = Math_fround($1848 - $1852);
 $1857 = Math_fround($1791 * $1843);
 $1858 = Math_fround($1791 * $1847);
 $1859 = Math_fround($1792 * $1841);
 $1860 = Math_fround($1792 * $1845);
 $1861 = Math_fround($1853 - $1857);
 $1862 = Math_fround($1854 - $1858);
 $1863 = Math_fround($1855 - $1859);
 $1864 = Math_fround($1856 - $1860);
 $1865 = Math_fround($1787 * $1845);
 $1866 = Math_fround($1789 * $1845);
 $1867 = Math_fround($1787 * $1843);
 $1868 = Math_fround($1789 * $1843);
 $1869 = Math_fround($1861 - $1865);
 $1870 = Math_fround($1862 - $1866);
 $1871 = Math_fround($1863 - $1867);
 $1872 = Math_fround($1864 - $1868);
 $1873 = Math_fround($1871 * Math_fround(-1.0));
 $1874 = Math_fround($1872 * Math_fround(-1.0));
 $1875 = Math_fround($1869 * Math_fround(-1.0));
 $1876 = Math_fround($1873 * $1873);
 $1877 = Math_fround($1874 * $1874);
 $1878 = Math_fround($1875 * $1875);
 $1879 = Math_fround($1870 * $1870);
 $1880 = Math_fround($1876 + $1877);
 $1881 = Math_fround($1879 + $1878);
 $1882 = Math_fround($1880 + $1881);
 $1883 = (Math_fround(Math_sqrt((Math_fround($1882)))));
 $1884 = Math_fround(Math_fround(1.0) / $1883);
 $1885 = Math_fround($1884 * $1873);
 $1886 = Math_fround($1884 * $1874);
 $1887 = Math_fround($1884 * $1875);
 $1888 = Math_fround($1884 * $1870);
 HEAPF32[$clipIn$i>>2] = $1837;
 HEAPF32[$836>>2] = $1838;
 HEAPF32[$837>>2] = $1839;
 HEAPF32[$838>>2] = $1840;
 HEAPF32[$847>>2] = $1885;
 HEAPF32[$848>>2] = $1886;
 HEAPF32[$849>>2] = $1887;
 HEAPF32[$850>>2] = $1888;
 HEAPF32[$859>>2] = Math_fround(1.0);
 HEAPF32[$860>>2] = Math_fround(1.0);
 HEAPF32[$861>>2] = Math_fround(1.0);
 HEAPF32[$862>>2] = Math_fround(1.0);
 if ($4103) {
  $1889 = (($motionOutput) + 424|0);
  $1890 = Math_fround(HEAPF32[$1889>>2]);
  $1891 = Math_fround($1890 - $1588);
  $1892 = (($motionOutput) + 428|0);
  $1893 = Math_fround(HEAPF32[$1892>>2]);
  $1894 = Math_fround($1893 - $1591);
  $1895 = (($motionOutput) + 432|0);
  $1896 = Math_fround(HEAPF32[$1895>>2]);
  $1897 = Math_fround($1896 - $1594);
  $1898 = (($motionOutput) + 436|0);
  $1899 = Math_fround(HEAPF32[$1898>>2]);
  $1900 = Math_fround($1899 - $1597);
  $1901 = Math_fround($1891 + $1891);
  $1902 = Math_fround($1894 + $1894);
  $1903 = Math_fround($1897 + $1897);
  $1904 = Math_fround($1580 * $1902);
  $1905 = Math_fround($1582 * $1903);
  $1906 = Math_fround($1584 * $1901);
  $1907 = Math_fround($1582 * $1901);
  $1908 = Math_fround($1584 * $1902);
  $1909 = Math_fround($1580 * $1903);
  $1910 = Math_fround($1904 - $1907);
  $1911 = Math_fround($1905 - $1908);
  $1912 = Math_fround($1906 - $1909);
  $1913 = Math_fround($1605 * $1911);
  $1914 = Math_fround($1605 * $1912);
  $1915 = Math_fround($1605 * $1910);
  $1916 = Math_fround($1891 + $1913);
  $1917 = Math_fround($1894 + $1914);
  $1918 = Math_fround($1897 + $1915);
  $1919 = Math_fround($1616 + $1900);
  $1920 = Math_fround($1580 * $1912);
  $1921 = Math_fround($1582 * $1910);
  $1922 = Math_fround($1584 * $1911);
  $1923 = Math_fround($1582 * $1911);
  $1924 = Math_fround($1584 * $1912);
  $1925 = Math_fround($1580 * $1910);
  $1926 = Math_fround($1920 - $1923);
  $1927 = Math_fround($1921 - $1924);
  $1928 = Math_fround($1922 - $1925);
  $1929 = Math_fround($1916 + $1927);
  $1930 = Math_fround($1917 + $1928);
  $1931 = Math_fround($1918 + $1926);
  $1932 = Math_fround($1630 + $1919);
  HEAPF32[$1889>>2] = $1929;
  HEAPF32[$1892>>2] = $1930;
  HEAPF32[$1895>>2] = $1931;
  HEAPF32[$1898>>2] = $1932;
  $1933 = (($motionOutput) + 440|0);
  $1934 = Math_fround(HEAPF32[$1933>>2]);
  $1935 = Math_fround($1934 - $1691);
  $1936 = (($motionOutput) + 444|0);
  $1937 = Math_fround(HEAPF32[$1936>>2]);
  $1938 = Math_fround($1937 - $1694);
  $1939 = (($motionOutput) + 448|0);
  $1940 = Math_fround(HEAPF32[$1939>>2]);
  $1941 = Math_fround($1940 - $1697);
  $1942 = (($motionOutput) + 452|0);
  $1943 = Math_fround(HEAPF32[$1942>>2]);
  $1944 = Math_fround($1943 - $1700);
  $1945 = Math_fround($1935 + $1935);
  $1946 = Math_fround($1938 + $1938);
  $1947 = Math_fround($1941 + $1941);
  $1948 = Math_fround($1683 * $1946);
  $1949 = Math_fround($1685 * $1947);
  $1950 = Math_fround($1687 * $1945);
  $1951 = Math_fround($1685 * $1945);
  $1952 = Math_fround($1687 * $1946);
  $1953 = Math_fround($1683 * $1947);
  $1954 = Math_fround($1948 - $1951);
  $1955 = Math_fround($1949 - $1952);
  $1956 = Math_fround($1950 - $1953);
  $1957 = Math_fround($1708 * $1955);
  $1958 = Math_fround($1708 * $1956);
  $1959 = Math_fround($1708 * $1954);
  $1960 = Math_fround($1935 + $1957);
  $1961 = Math_fround($1938 + $1958);
  $1962 = Math_fround($1941 + $1959);
  $1963 = Math_fround($1719 + $1944);
  $1964 = Math_fround($1683 * $1956);
  $1965 = Math_fround($1685 * $1954);
  $1966 = Math_fround($1687 * $1955);
  $1967 = Math_fround($1685 * $1955);
  $1968 = Math_fround($1687 * $1956);
  $1969 = Math_fround($1683 * $1954);
  $1970 = Math_fround($1964 - $1967);
  $1971 = Math_fround($1965 - $1968);
  $1972 = Math_fround($1966 - $1969);
  $1973 = Math_fround($1960 + $1971);
  $1974 = Math_fround($1961 + $1972);
  $1975 = Math_fround($1962 + $1970);
  $1976 = Math_fround($1733 + $1963);
  HEAPF32[$1933>>2] = $1973;
  HEAPF32[$1936>>2] = $1974;
  HEAPF32[$1939>>2] = $1975;
  HEAPF32[$1942>>2] = $1976;
 }
 $1977 = HEAP8[$42>>0]|0;
 $1978 = ($1977<<24>>24)==(0);
 if (!($1978)) {
  $1979 = (($constant) + 1634|0);
  $1980 = HEAP8[$1979>>0]|0;
  $1981 = ($1980<<24>>24)==(0);
  if (!($1981)) {
   __ZN7mecanim5human9HumanPoseC2Ev($refLeftFootStartX);
   __ZN7mecanim5human15HumanPoseWeightERNS0_9HumanPoseERKS1_f($refLeftFootStartX,$constant,$82);
   __ZN7mecanim5human12HumanPoseAddERNS0_9HumanPoseERKS1_S4_($humanPose,$humanPose,$refLeftFootStartX);
   $1982 = (($constant) + 80|0);
   $1983 = Math_fround(HEAPF32[$1982>>2]);
   $1984 = Math_fround($61 * $1983);
   $1985 = (($constant) + 84|0);
   $1986 = Math_fround(HEAPF32[$1985>>2]);
   $1987 = Math_fround($61 * $1986);
   $1988 = (($constant) + 88|0);
   $1989 = Math_fround(HEAPF32[$1988>>2]);
   $1990 = Math_fround($61 * $1989);
   $1991 = (($constant) + 92|0);
   $1992 = Math_fround(HEAPF32[$1991>>2]);
   $1993 = Math_fround($61 * $1992);
   $1994 = (($constant) + 96|0);
   $1995 = Math_fround(HEAPF32[$1994>>2]);
   $1996 = Math_fround($61 * $1995);
   $1997 = (($constant) + 100|0);
   $1998 = Math_fround(HEAPF32[$1997>>2]);
   $1999 = Math_fround($61 * $1998);
   $2000 = (($constant) + 104|0);
   $2001 = Math_fround(HEAPF32[$2000>>2]);
   $2002 = Math_fround($61 * $2001);
   $2003 = (($constant) + 108|0);
   $2004 = Math_fround(HEAPF32[$2003>>2]);
   $2005 = Math_fround($1996 * $1996);
   $2006 = Math_fround($1999 * $1999);
   $2007 = Math_fround($2002 * $2002);
   $2008 = Math_fround($2004 * $2004);
   $2009 = Math_fround($2005 + $2006);
   $2010 = Math_fround($2007 + $2008);
   $2011 = Math_fround($2009 + $2010);
   $2012 = (Math_fround(Math_sqrt((Math_fround($2011)))));
   $2013 = Math_fround(Math_fround(1.0) / $2012);
   $2014 = Math_fround($1996 * $2013);
   $2015 = Math_fround($1999 * $2013);
   $2016 = Math_fround($2002 * $2013);
   $2017 = Math_fround($2004 * $2013);
   HEAPF32[$15>>2] = $1984;
   $2018 = (($15) + 4|0);
   HEAPF32[$2018>>2] = $1987;
   $2019 = (($15) + 8|0);
   HEAPF32[$2019>>2] = $1990;
   $2020 = (($15) + 12|0);
   HEAPF32[$2020>>2] = $1993;
   $2021 = (($15) + 16|0);
   HEAPF32[$2021>>2] = $2014;
   $2022 = (($15) + 20|0);
   HEAPF32[$2022>>2] = $2015;
   $2023 = (($15) + 24|0);
   HEAPF32[$2023>>2] = $2016;
   $2024 = (($15) + 28|0);
   HEAPF32[$2024>>2] = $2017;
   $2025 = (($15) + 32|0);
   HEAPF32[$2025>>2] = Math_fround(1.0);
   $2026 = (($15) + 36|0);
   HEAPF32[$2026>>2] = Math_fround(1.0);
   $2027 = (($15) + 40|0);
   HEAPF32[$2027>>2] = Math_fround(1.0);
   $2028 = (($15) + 44|0);
   HEAPF32[$2028>>2] = Math_fround(1.0);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($14,$prevLeftFootX,$15);
   $2029 = Math_fround(HEAPF32[$14>>2]);
   $2030 = (($14) + 4|0);
   $2031 = Math_fround(HEAPF32[$2030>>2]);
   $2032 = (($14) + 8|0);
   $2033 = Math_fround(HEAPF32[$2032>>2]);
   $2034 = (($14) + 12|0);
   $2035 = Math_fround(HEAPF32[$2034>>2]);
   HEAPF32[$prevLeftFootX>>2] = $2029;
   HEAPF32[$166>>2] = $2031;
   HEAPF32[$167>>2] = $2033;
   HEAPF32[$168>>2] = $2035;
   $2036 = (($14) + 16|0);
   $2037 = Math_fround(HEAPF32[$2036>>2]);
   $2038 = (($14) + 20|0);
   $2039 = Math_fround(HEAPF32[$2038>>2]);
   $2040 = (($14) + 24|0);
   $2041 = Math_fround(HEAPF32[$2040>>2]);
   $2042 = (($14) + 28|0);
   $2043 = Math_fround(HEAPF32[$2042>>2]);
   HEAPF32[$177>>2] = $2037;
   HEAPF32[$178>>2] = $2039;
   HEAPF32[$179>>2] = $2041;
   HEAPF32[$180>>2] = $2043;
   $2044 = (($14) + 32|0);
   $2045 = Math_fround(HEAPF32[$2044>>2]);
   $2046 = (($14) + 36|0);
   $2047 = Math_fround(HEAPF32[$2046>>2]);
   $2048 = (($14) + 40|0);
   $2049 = Math_fround(HEAPF32[$2048>>2]);
   $2050 = (($14) + 44|0);
   $2051 = Math_fround(HEAPF32[$2050>>2]);
   HEAPF32[$189>>2] = $2045;
   HEAPF32[$190>>2] = $2047;
   HEAPF32[$191>>2] = $2049;
   HEAPF32[$192>>2] = $2051;
   $2052 = (($constant) + 156|0);
   $2053 = Math_fround(HEAPF32[$2052>>2]);
   $2054 = Math_fround($61 * $2053);
   $2055 = (($constant) + 160|0);
   $2056 = Math_fround(HEAPF32[$2055>>2]);
   $2057 = Math_fround($61 * $2056);
   $2058 = (($constant) + 164|0);
   $2059 = Math_fround(HEAPF32[$2058>>2]);
   $2060 = Math_fround($61 * $2059);
   $2061 = (($constant) + 168|0);
   $2062 = Math_fround(HEAPF32[$2061>>2]);
   $2063 = Math_fround($61 * $2062);
   $2064 = (($constant) + 172|0);
   $2065 = Math_fround(HEAPF32[$2064>>2]);
   $2066 = Math_fround($61 * $2065);
   $2067 = (($constant) + 176|0);
   $2068 = Math_fround(HEAPF32[$2067>>2]);
   $2069 = Math_fround($61 * $2068);
   $2070 = (($constant) + 180|0);
   $2071 = Math_fround(HEAPF32[$2070>>2]);
   $2072 = Math_fround($61 * $2071);
   $2073 = (($constant) + 184|0);
   $2074 = Math_fround(HEAPF32[$2073>>2]);
   $2075 = Math_fround($2066 * $2066);
   $2076 = Math_fround($2069 * $2069);
   $2077 = Math_fround($2072 * $2072);
   $2078 = Math_fround($2074 * $2074);
   $2079 = Math_fround($2075 + $2076);
   $2080 = Math_fround($2077 + $2078);
   $2081 = Math_fround($2079 + $2080);
   $2082 = (Math_fround(Math_sqrt((Math_fround($2081)))));
   $2083 = Math_fround(Math_fround(1.0) / $2082);
   $2084 = Math_fround($2066 * $2083);
   $2085 = Math_fround($2069 * $2083);
   $2086 = Math_fround($2072 * $2083);
   $2087 = Math_fround($2074 * $2083);
   HEAPF32[$17>>2] = $2054;
   $2088 = (($17) + 4|0);
   HEAPF32[$2088>>2] = $2057;
   $2089 = (($17) + 8|0);
   HEAPF32[$2089>>2] = $2060;
   $2090 = (($17) + 12|0);
   HEAPF32[$2090>>2] = $2063;
   $2091 = (($17) + 16|0);
   HEAPF32[$2091>>2] = $2084;
   $2092 = (($17) + 20|0);
   HEAPF32[$2092>>2] = $2085;
   $2093 = (($17) + 24|0);
   HEAPF32[$2093>>2] = $2086;
   $2094 = (($17) + 28|0);
   HEAPF32[$2094>>2] = $2087;
   $2095 = (($17) + 32|0);
   HEAPF32[$2095>>2] = Math_fround(1.0);
   $2096 = (($17) + 36|0);
   HEAPF32[$2096>>2] = Math_fround(1.0);
   $2097 = (($17) + 40|0);
   HEAPF32[$2097>>2] = Math_fround(1.0);
   $2098 = (($17) + 44|0);
   HEAPF32[$2098>>2] = Math_fround(1.0);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($16,$prevRightFootX,$17);
   $2099 = Math_fround(HEAPF32[$16>>2]);
   $2100 = (($16) + 4|0);
   $2101 = Math_fround(HEAPF32[$2100>>2]);
   $2102 = (($16) + 8|0);
   $2103 = Math_fround(HEAPF32[$2102>>2]);
   $2104 = (($16) + 12|0);
   $2105 = Math_fround(HEAPF32[$2104>>2]);
   HEAPF32[$prevRightFootX>>2] = $2099;
   HEAPF32[$201>>2] = $2101;
   HEAPF32[$202>>2] = $2103;
   HEAPF32[$203>>2] = $2105;
   $2106 = (($16) + 16|0);
   $2107 = Math_fround(HEAPF32[$2106>>2]);
   $2108 = (($16) + 20|0);
   $2109 = Math_fround(HEAPF32[$2108>>2]);
   $2110 = (($16) + 24|0);
   $2111 = Math_fround(HEAPF32[$2110>>2]);
   $2112 = (($16) + 28|0);
   $2113 = Math_fround(HEAPF32[$2112>>2]);
   HEAPF32[$212>>2] = $2107;
   HEAPF32[$213>>2] = $2109;
   HEAPF32[$214>>2] = $2111;
   HEAPF32[$215>>2] = $2113;
   $2114 = (($16) + 32|0);
   $2115 = Math_fround(HEAPF32[$2114>>2]);
   $2116 = (($16) + 36|0);
   $2117 = Math_fround(HEAPF32[$2116>>2]);
   $2118 = (($16) + 40|0);
   $2119 = Math_fround(HEAPF32[$2118>>2]);
   $2120 = (($16) + 44|0);
   $2121 = Math_fround(HEAPF32[$2120>>2]);
   HEAPF32[$224>>2] = $2115;
   HEAPF32[$225>>2] = $2117;
   HEAPF32[$226>>2] = $2119;
   HEAPF32[$227>>2] = $2121;
   if ($4103) {
    $2122 = HEAP32[$107>>2]|0;
    $2123 = ($2122|0)==(-1);
    if ($2123) {
     $value$sroa$0$0$i27 = Math_fround(0.0);
    } else {
     $2124 = (($constant) + 1624|0);
     $2125 = $2124;
     $2126 = HEAP32[$2124>>2]|0;
     $2127 = (($2126) + ($2125))|0;
     $2128 = $2127;
     $2129 = (($2128) + ($2122<<3)|0);
     $2130 = Math_fround(HEAPF32[$2129>>2]);
     $value$sroa$0$0$i27 = $2130;
    }
    $2131 = (($constant) + 1612|0);
    $2132 = HEAP32[$2131>>2]|0;
    $2133 = ($2132|0)==(-1);
    if ($2133) {
     $value$sroa$1$0$i28 = Math_fround(0.0);
    } else {
     $2134 = (($constant) + 1624|0);
     $2135 = $2134;
     $2136 = HEAP32[$2134>>2]|0;
     $2137 = (($2136) + ($2135))|0;
     $2138 = $2137;
     $2139 = (($2138) + ($2132<<3)|0);
     $2140 = Math_fround(HEAPF32[$2139>>2]);
     $value$sroa$1$0$i28 = $2140;
    }
    $2141 = (($constant) + 1616|0);
    $2142 = HEAP32[$2141>>2]|0;
    $2143 = ($2142|0)==(-1);
    if ($2143) {
     $value$sroa$2$0$i29 = Math_fround(0.0);
    } else {
     $2144 = (($constant) + 1624|0);
     $2145 = $2144;
     $2146 = HEAP32[$2144>>2]|0;
     $2147 = (($2146) + ($2145))|0;
     $2148 = $2147;
     $2149 = (($2148) + ($2142<<3)|0);
     $2150 = Math_fround(HEAPF32[$2149>>2]);
     $value$sroa$2$0$i29 = $2150;
    }
    $2151 = (($refStartX) + 16|0);
    $2152 = Math_fround(HEAPF32[$2151>>2]);
    $2153 = Math_fround($2152 * Math_fround(-1.0));
    $2154 = (($refStartX) + 20|0);
    $2155 = Math_fround(HEAPF32[$2154>>2]);
    $2156 = Math_fround($2155 * Math_fround(-1.0));
    $2157 = (($refStartX) + 24|0);
    $2158 = Math_fround(HEAPF32[$2157>>2]);
    $2159 = Math_fround($2158 * Math_fround(-1.0));
    $2160 = Math_fround(HEAPF32[$262>>2]);
    $2161 = Math_fround(HEAPF32[$refStartX>>2]);
    $2162 = Math_fround($value$sroa$0$0$i27 - $2161);
    $2163 = (($refStartX) + 4|0);
    $2164 = Math_fround(HEAPF32[$2163>>2]);
    $2165 = Math_fround($value$sroa$1$0$i28 - $2164);
    $2166 = (($refStartX) + 8|0);
    $2167 = Math_fround(HEAPF32[$2166>>2]);
    $2168 = Math_fround($value$sroa$2$0$i29 - $2167);
    $2169 = (($refStartX) + 12|0);
    $2170 = Math_fround(HEAPF32[$2169>>2]);
    $2171 = Math_fround(Math_fround(0.0) - $2170);
    $2172 = Math_fround($2162 + $2162);
    $2173 = Math_fround($2165 + $2165);
    $2174 = Math_fround($2168 + $2168);
    $2175 = Math_fround($2153 * $2173);
    $2176 = Math_fround($2156 * $2174);
    $2177 = Math_fround($2159 * $2172);
    $2178 = Math_fround($2160 * Math_fround(0.0));
    $2179 = Math_fround($2156 * $2172);
    $2180 = Math_fround($2159 * $2173);
    $2181 = Math_fround($2153 * $2174);
    $2182 = Math_fround($2175 - $2179);
    $2183 = Math_fround($2176 - $2180);
    $2184 = Math_fround($2177 - $2181);
    $2185 = Math_fround($2178 - $2178);
    $2186 = Math_fround($2160 * $2183);
    $2187 = Math_fround($2160 * $2184);
    $2188 = Math_fround($2160 * $2182);
    $2189 = Math_fround($2160 * $2185);
    $2190 = Math_fround($2162 + $2186);
    $2191 = Math_fround($2165 + $2187);
    $2192 = Math_fround($2168 + $2188);
    $2193 = Math_fround($2189 + $2171);
    $2194 = Math_fround($2153 * $2184);
    $2195 = Math_fround($2156 * $2182);
    $2196 = Math_fround($2159 * $2183);
    $2197 = Math_fround($2156 * $2183);
    $2198 = Math_fround($2159 * $2184);
    $2199 = Math_fround($2153 * $2182);
    $2200 = Math_fround($2194 - $2197);
    $2201 = Math_fround($2195 - $2198);
    $2202 = Math_fround($2196 - $2199);
    $2203 = Math_fround($2189 - $2189);
    $2204 = Math_fround($2190 + $2201);
    $2205 = Math_fround($2191 + $2202);
    $2206 = Math_fround($2192 + $2200);
    $2207 = Math_fround($2203 + $2193);
    if ($2123) {
     $value$sroa$0$0$i = Math_fround(0.0);
    } else {
     $2208 = (($constant) + 1624|0);
     $2209 = $2208;
     $2210 = HEAP32[$2208>>2]|0;
     $2211 = (($2210) + ($2209))|0;
     $2212 = $2211;
     $2213 = ((($2212) + ($2122<<3)|0) + 4|0);
     $2214 = Math_fround(HEAPF32[$2213>>2]);
     $value$sroa$0$0$i = $2214;
    }
    if ($2133) {
     $value$sroa$1$0$i = Math_fround(0.0);
    } else {
     $2215 = (($constant) + 1624|0);
     $2216 = $2215;
     $2217 = HEAP32[$2215>>2]|0;
     $2218 = (($2217) + ($2216))|0;
     $2219 = $2218;
     $2220 = ((($2219) + ($2132<<3)|0) + 4|0);
     $2221 = Math_fround(HEAPF32[$2220>>2]);
     $value$sroa$1$0$i = $2221;
    }
    if ($2143) {
     $value$sroa$2$0$i = Math_fround(0.0);
    } else {
     $2222 = (($constant) + 1624|0);
     $2223 = $2222;
     $2224 = HEAP32[$2222>>2]|0;
     $2225 = (($2224) + ($2223))|0;
     $2226 = $2225;
     $2227 = ((($2226) + ($2142<<3)|0) + 4|0);
     $2228 = Math_fround(HEAPF32[$2227>>2]);
     $value$sroa$2$0$i = $2228;
    }
    $2229 = Math_fround(HEAPF32[$873>>2]);
    $2230 = Math_fround($2229 * Math_fround(-1.0));
    $2231 = Math_fround(HEAPF32[$875>>2]);
    $2232 = Math_fround($2231 * Math_fround(-1.0));
    $2233 = Math_fround(HEAPF32[$877>>2]);
    $2234 = Math_fround($2233 * Math_fround(-1.0));
    $2235 = Math_fround(HEAPF32[$267>>2]);
    $2236 = Math_fround(HEAPF32[$refStopX>>2]);
    $2237 = Math_fround($value$sroa$0$0$i - $2236);
    $2238 = Math_fround(HEAPF32[$864>>2]);
    $2239 = Math_fround($value$sroa$1$0$i - $2238);
    $2240 = Math_fround(HEAPF32[$866>>2]);
    $2241 = Math_fround($value$sroa$2$0$i - $2240);
    $2242 = Math_fround(HEAPF32[$868>>2]);
    $2243 = Math_fround(Math_fround(0.0) - $2242);
    $2244 = Math_fround($2237 + $2237);
    $2245 = Math_fround($2239 + $2239);
    $2246 = Math_fround($2241 + $2241);
    $2247 = Math_fround($2230 * $2245);
    $2248 = Math_fround($2232 * $2246);
    $2249 = Math_fround($2234 * $2244);
    $2250 = Math_fround($2235 * Math_fround(0.0));
    $2251 = Math_fround($2232 * $2244);
    $2252 = Math_fround($2234 * $2245);
    $2253 = Math_fround($2230 * $2246);
    $2254 = Math_fround($2247 - $2251);
    $2255 = Math_fround($2248 - $2252);
    $2256 = Math_fround($2249 - $2253);
    $2257 = Math_fround($2250 - $2250);
    $2258 = Math_fround($2235 * $2255);
    $2259 = Math_fround($2235 * $2256);
    $2260 = Math_fround($2235 * $2254);
    $2261 = Math_fround($2235 * $2257);
    $2262 = Math_fround($2237 + $2258);
    $2263 = Math_fround($2239 + $2259);
    $2264 = Math_fround($2241 + $2260);
    $2265 = Math_fround($2261 + $2243);
    $2266 = Math_fround($2230 * $2256);
    $2267 = Math_fround($2232 * $2254);
    $2268 = Math_fround($2234 * $2255);
    $2269 = Math_fround($2232 * $2255);
    $2270 = Math_fround($2234 * $2256);
    $2271 = Math_fround($2230 * $2254);
    $2272 = Math_fround($2266 - $2269);
    $2273 = Math_fround($2267 - $2270);
    $2274 = Math_fround($2268 - $2271);
    $2275 = Math_fround($2261 - $2261);
    $2276 = Math_fround($2262 + $2273);
    $2277 = Math_fround($2263 + $2274);
    $2278 = Math_fround($2264 + $2272);
    $2279 = Math_fround($2275 + $2265);
    $2280 = Math_fround($2204 - $2276);
    $2281 = Math_fround($2205 - $2277);
    $2282 = Math_fround($2206 - $2278);
    $2283 = Math_fround($2207 - $2279);
    $2284 = Math_fround($61 * $2280);
    $2285 = Math_fround($61 * $2281);
    $2286 = Math_fround($61 * $2282);
    $2287 = Math_fround($61 * $2283);
    $2288 = (($motionOutput) + 424|0);
    $2289 = Math_fround(HEAPF32[$2288>>2]);
    $2290 = Math_fround($2289 + $2284);
    $2291 = (($motionOutput) + 428|0);
    $2292 = Math_fround(HEAPF32[$2291>>2]);
    $2293 = Math_fround($2292 + $2285);
    $2294 = (($motionOutput) + 432|0);
    $2295 = Math_fround(HEAPF32[$2294>>2]);
    $2296 = Math_fround($2295 + $2286);
    $2297 = (($motionOutput) + 436|0);
    $2298 = Math_fround(HEAPF32[$2297>>2]);
    $2299 = Math_fround($2298 + $2287);
    HEAPF32[$2288>>2] = $2290;
    HEAPF32[$2291>>2] = $2293;
    HEAPF32[$2294>>2] = $2296;
    HEAPF32[$2297>>2] = $2299;
    $2300 = Math_fround($82 * $2280);
    $2301 = Math_fround($82 * $2281);
    $2302 = Math_fround($82 * $2282);
    $2303 = Math_fround($82 * $2283);
    $2304 = (($motionOutput) + 440|0);
    $2305 = Math_fround(HEAPF32[$2304>>2]);
    $2306 = Math_fround($2305 + $2300);
    $2307 = (($motionOutput) + 444|0);
    $2308 = Math_fround(HEAPF32[$2307>>2]);
    $2309 = Math_fround($2308 + $2301);
    $2310 = (($motionOutput) + 448|0);
    $2311 = Math_fround(HEAPF32[$2310>>2]);
    $2312 = Math_fround($2311 + $2302);
    $2313 = (($motionOutput) + 452|0);
    $2314 = Math_fround(HEAPF32[$2313>>2]);
    $2315 = Math_fround($2303 + $2314);
    HEAPF32[$2304>>2] = $2306;
    HEAPF32[$2307>>2] = $2309;
    HEAPF32[$2310>>2] = $2312;
    HEAPF32[$2313>>2] = $2315;
    $$pre$phi721Z2D = $2154;$$pre$phi723Z2D = $2157;$$pre$phi725Z2D = $refStartX;$$pre$phi727Z2D = $2163;$$pre$phi729Z2D = $2166;$$pre$phi731Z2D = $2169;$$pre$phiZ2D = $2151;$2317 = $2229;$2319 = $2231;$2321 = $2233;$2324 = $2236;$2327 = $2238;$2330 = $2240;$2333 = $2242;$2341 = $2235;
   } else {
    $$pre = Math_fround(HEAPF32[$873>>2]);
    $$pre700 = Math_fround(HEAPF32[$875>>2]);
    $$pre701 = Math_fround(HEAPF32[$877>>2]);
    $$pre702 = Math_fround(HEAPF32[$267>>2]);
    $$pre703 = Math_fround(HEAPF32[$refStopX>>2]);
    $$pre704 = Math_fround(HEAPF32[$864>>2]);
    $$pre705 = Math_fround(HEAPF32[$866>>2]);
    $$pre706 = Math_fround(HEAPF32[$868>>2]);
    $$pre719 = (($refStartX) + 16|0);
    $$pre720 = (($refStartX) + 20|0);
    $$pre722 = (($refStartX) + 24|0);
    $$pre726 = (($refStartX) + 4|0);
    $$pre728 = (($refStartX) + 8|0);
    $$pre730 = (($refStartX) + 12|0);
    $$pre$phi721Z2D = $$pre720;$$pre$phi723Z2D = $$pre722;$$pre$phi725Z2D = $refStartX;$$pre$phi727Z2D = $$pre726;$$pre$phi729Z2D = $$pre728;$$pre$phi731Z2D = $$pre730;$$pre$phiZ2D = $$pre719;$2317 = $$pre;$2319 = $$pre700;$2321 = $$pre701;$2324 = $$pre703;$2327 = $$pre704;$2330 = $$pre705;$2333 = $$pre706;$2341 = $$pre702;
   }
   $2316 = Math_fround($2317 * Math_fround(-1.0));
   $2318 = Math_fround($2319 * Math_fround(-1.0));
   $2320 = Math_fround($2321 * Math_fround(-1.0));
   $2322 = Math_fround(HEAPF32[$stopX>>2]);
   $2323 = Math_fround($2322 - $2324);
   $2325 = Math_fround(HEAPF32[$830>>2]);
   $2326 = Math_fround($2325 - $2327);
   $2328 = Math_fround(HEAPF32[$832>>2]);
   $2329 = Math_fround($2328 - $2330);
   $2331 = Math_fround(HEAPF32[$834>>2]);
   $2332 = Math_fround($2331 - $2333);
   $2334 = Math_fround($2323 + $2323);
   $2335 = Math_fround($2326 + $2326);
   $2336 = Math_fround($2329 + $2329);
   $2337 = Math_fround($2316 * $2335);
   $2338 = Math_fround($2318 * $2336);
   $2339 = Math_fround($2320 * $2334);
   $2340 = Math_fround($2341 * Math_fround(0.0));
   $2342 = Math_fround($2318 * $2334);
   $2343 = Math_fround($2320 * $2335);
   $2344 = Math_fround($2316 * $2336);
   $2345 = Math_fround($2337 - $2342);
   $2346 = Math_fround($2338 - $2343);
   $2347 = Math_fround($2339 - $2344);
   $2348 = Math_fround($2340 - $2340);
   $2349 = Math_fround($2341 * $2346);
   $2350 = Math_fround($2341 * $2347);
   $2351 = Math_fround($2341 * $2345);
   $2352 = Math_fround($2341 * $2348);
   $2353 = Math_fround($2323 + $2349);
   $2354 = Math_fround($2326 + $2350);
   $2355 = Math_fround($2329 + $2351);
   $2356 = Math_fround($2352 + $2332);
   $2357 = Math_fround($2316 * $2347);
   $2358 = Math_fround($2318 * $2345);
   $2359 = Math_fround($2320 * $2346);
   $2360 = Math_fround($2318 * $2346);
   $2361 = Math_fround($2320 * $2347);
   $2362 = Math_fround($2316 * $2345);
   $2363 = Math_fround($2357 - $2360);
   $2364 = Math_fround($2358 - $2361);
   $2365 = Math_fround($2359 - $2362);
   $2366 = Math_fround($2352 - $2352);
   $2367 = Math_fround($2353 + $2364);
   $2368 = Math_fround($2354 + $2365);
   $2369 = Math_fround($2355 + $2363);
   $2370 = Math_fround($2366 + $2356);
   $2371 = Math_fround(HEAPF32[$839>>2]);
   $2372 = Math_fround($2318 * $2371);
   $2373 = Math_fround(HEAPF32[$845>>2]);
   $2374 = Math_fround($2341 * $2373);
   $2375 = Math_fround(HEAPF32[$841>>2]);
   $2376 = Math_fround($2320 * $2375);
   $2377 = Math_fround(HEAPF32[$843>>2]);
   $2378 = Math_fround($2316 * $2377);
   $2379 = Math_fround($2341 * $2377);
   $2380 = Math_fround($2316 * $2371);
   $2381 = Math_fround($2318 * $2377);
   $2382 = Math_fround($2320 * $2371);
   $2383 = Math_fround($2372 - $2379);
   $2384 = Math_fround($2374 - $2380);
   $2385 = Math_fround($2376 - $2381);
   $2386 = Math_fround($2378 - $2382);
   $2387 = Math_fround($2320 * $2373);
   $2388 = Math_fround($2320 * $2377);
   $2389 = Math_fround($2341 * $2371);
   $2390 = Math_fround($2341 * $2375);
   $2391 = Math_fround($2383 - $2387);
   $2392 = Math_fround($2384 - $2388);
   $2393 = Math_fround($2385 - $2389);
   $2394 = Math_fround($2386 - $2390);
   $2395 = Math_fround($2316 * $2375);
   $2396 = Math_fround($2318 * $2375);
   $2397 = Math_fround($2316 * $2373);
   $2398 = Math_fround($2318 * $2373);
   $2399 = Math_fround($2391 - $2395);
   $2400 = Math_fround($2392 - $2396);
   $2401 = Math_fround($2393 - $2397);
   $2402 = Math_fround($2394 - $2398);
   $2403 = Math_fround($2401 * Math_fround(-1.0));
   $2404 = Math_fround($2402 * Math_fround(-1.0));
   $2405 = Math_fround($2399 * Math_fround(-1.0));
   $2406 = Math_fround($2403 * $2403);
   $2407 = Math_fround($2404 * $2404);
   $2408 = Math_fround($2405 * $2405);
   $2409 = Math_fround($2400 * $2400);
   $2410 = Math_fround($2406 + $2407);
   $2411 = Math_fround($2409 + $2408);
   $2412 = Math_fround($2410 + $2411);
   $2413 = (Math_fround(Math_sqrt((Math_fround($2412)))));
   $2414 = Math_fround(Math_fround(1.0) / $2413);
   $2415 = Math_fround($2414 * $2403);
   $2416 = Math_fround($2414 * $2404);
   $2417 = Math_fround($2414 * $2405);
   $2418 = Math_fround($2414 * $2400);
   $2419 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
   $2420 = Math_fround($2419 * Math_fround(-1.0));
   $2421 = Math_fround(HEAPF32[$$pre$phi721Z2D>>2]);
   $2422 = Math_fround($2421 * Math_fround(-1.0));
   $2423 = Math_fround(HEAPF32[$$pre$phi723Z2D>>2]);
   $2424 = Math_fround($2423 * Math_fround(-1.0));
   $2425 = Math_fround(HEAPF32[$262>>2]);
   $2426 = Math_fround(HEAPF32[$122>>2]);
   $2427 = Math_fround(HEAPF32[$$pre$phi725Z2D>>2]);
   $2428 = Math_fround($2426 - $2427);
   $2429 = (($constant) + 884|0);
   $2430 = Math_fround(HEAPF32[$2429>>2]);
   $2431 = Math_fround(HEAPF32[$$pre$phi727Z2D>>2]);
   $2432 = Math_fround($2430 - $2431);
   $2433 = (($constant) + 888|0);
   $2434 = Math_fround(HEAPF32[$2433>>2]);
   $2435 = Math_fround(HEAPF32[$$pre$phi729Z2D>>2]);
   $2436 = Math_fround($2434 - $2435);
   $2437 = (($constant) + 892|0);
   $2438 = Math_fround(HEAPF32[$2437>>2]);
   $2439 = Math_fround(HEAPF32[$$pre$phi731Z2D>>2]);
   $2440 = Math_fround($2438 - $2439);
   $2441 = Math_fround($2428 + $2428);
   $2442 = Math_fround($2432 + $2432);
   $2443 = Math_fround($2436 + $2436);
   $2444 = Math_fround($2420 * $2442);
   $2445 = Math_fround($2422 * $2443);
   $2446 = Math_fround($2424 * $2441);
   $2447 = Math_fround($2425 * Math_fround(0.0));
   $2448 = Math_fround($2422 * $2441);
   $2449 = Math_fround($2424 * $2442);
   $2450 = Math_fround($2420 * $2443);
   $2451 = Math_fround($2444 - $2448);
   $2452 = Math_fround($2445 - $2449);
   $2453 = Math_fround($2446 - $2450);
   $2454 = Math_fround($2447 - $2447);
   $2455 = Math_fround($2425 * $2452);
   $2456 = Math_fround($2425 * $2453);
   $2457 = Math_fround($2425 * $2451);
   $2458 = Math_fround($2425 * $2454);
   $2459 = Math_fround($2428 + $2455);
   $2460 = Math_fround($2432 + $2456);
   $2461 = Math_fround($2436 + $2457);
   $2462 = Math_fround($2458 + $2440);
   $2463 = Math_fround($2420 * $2453);
   $2464 = Math_fround($2422 * $2451);
   $2465 = Math_fround($2424 * $2452);
   $2466 = Math_fround($2422 * $2452);
   $2467 = Math_fround($2424 * $2453);
   $2468 = Math_fround($2420 * $2451);
   $2469 = Math_fround($2463 - $2466);
   $2470 = Math_fround($2464 - $2467);
   $2471 = Math_fround($2465 - $2468);
   $2472 = Math_fround($2458 - $2458);
   $2473 = Math_fround($2459 + $2470);
   $2474 = Math_fround($2460 + $2471);
   $2475 = Math_fround($2461 + $2469);
   $2476 = Math_fround($2472 + $2462);
   $2477 = (($constant) + 896|0);
   $2478 = Math_fround(HEAPF32[$2477>>2]);
   $2479 = Math_fround($2422 * $2478);
   $2480 = (($constant) + 908|0);
   $2481 = Math_fround(HEAPF32[$2480>>2]);
   $2482 = Math_fround($2425 * $2481);
   $2483 = (($constant) + 900|0);
   $2484 = Math_fround(HEAPF32[$2483>>2]);
   $2485 = Math_fround($2424 * $2484);
   $2486 = (($constant) + 904|0);
   $2487 = Math_fround(HEAPF32[$2486>>2]);
   $2488 = Math_fround($2420 * $2487);
   $2489 = Math_fround($2425 * $2487);
   $2490 = Math_fround($2420 * $2478);
   $2491 = Math_fround($2422 * $2487);
   $2492 = Math_fround($2424 * $2478);
   $2493 = Math_fround($2479 - $2489);
   $2494 = Math_fround($2482 - $2490);
   $2495 = Math_fround($2485 - $2491);
   $2496 = Math_fround($2488 - $2492);
   $2497 = Math_fround($2424 * $2481);
   $2498 = Math_fround($2424 * $2487);
   $2499 = Math_fround($2425 * $2478);
   $2500 = Math_fround($2425 * $2484);
   $2501 = Math_fround($2493 - $2497);
   $2502 = Math_fround($2494 - $2498);
   $2503 = Math_fround($2495 - $2499);
   $2504 = Math_fround($2496 - $2500);
   $2505 = Math_fround($2420 * $2484);
   $2506 = Math_fround($2422 * $2484);
   $2507 = Math_fround($2420 * $2481);
   $2508 = Math_fround($2422 * $2481);
   $2509 = Math_fround($2501 - $2505);
   $2510 = Math_fround($2502 - $2506);
   $2511 = Math_fround($2503 - $2507);
   $2512 = Math_fround($2504 - $2508);
   $2513 = Math_fround($2511 * Math_fround(-1.0));
   $2514 = Math_fround($2512 * Math_fround(-1.0));
   $2515 = Math_fround($2509 * Math_fround(-1.0));
   $2516 = Math_fround($2513 * $2513);
   $2517 = Math_fround($2514 * $2514);
   $2518 = Math_fround($2515 * $2515);
   $2519 = Math_fround($2510 * $2510);
   $2520 = Math_fround($2516 + $2517);
   $2521 = Math_fround($2519 + $2518);
   $2522 = Math_fround($2520 + $2521);
   $2523 = (Math_fround(Math_sqrt((Math_fround($2522)))));
   $2524 = Math_fround(Math_fround(1.0) / $2523);
   $2525 = Math_fround($2524 * $2513);
   $2526 = Math_fround($2524 * $2514);
   $2527 = Math_fround($2524 * $2515);
   $2528 = Math_fround($2524 * $2510);
   $2529 = Math_fround($2415 * Math_fround(-1.0));
   $2530 = Math_fround($2416 * Math_fround(-1.0));
   $2531 = Math_fround($2417 * Math_fround(-1.0));
   $2532 = Math_fround($2473 - $2367);
   $2533 = Math_fround($2474 - $2368);
   $2534 = Math_fround($2475 - $2369);
   $2535 = Math_fround($2476 - $2370);
   $2536 = Math_fround($2532 + $2532);
   $2537 = Math_fround($2533 + $2533);
   $2538 = Math_fround($2534 + $2534);
   $2539 = Math_fround($2529 * $2537);
   $2540 = Math_fround($2530 * $2538);
   $2541 = Math_fround($2531 * $2536);
   $2542 = Math_fround($2418 * Math_fround(0.0));
   $2543 = Math_fround($2530 * $2536);
   $2544 = Math_fround($2531 * $2537);
   $2545 = Math_fround($2529 * $2538);
   $2546 = Math_fround($2539 - $2543);
   $2547 = Math_fround($2540 - $2544);
   $2548 = Math_fround($2541 - $2545);
   $2549 = Math_fround($2542 - $2542);
   $2550 = Math_fround($2418 * $2547);
   $2551 = Math_fround($2418 * $2548);
   $2552 = Math_fround($2418 * $2546);
   $2553 = Math_fround($2418 * $2549);
   $2554 = Math_fround($2532 + $2550);
   $2555 = Math_fround($2533 + $2551);
   $2556 = Math_fround($2534 + $2552);
   $2557 = Math_fround($2553 + $2535);
   $2558 = Math_fround($2529 * $2548);
   $2559 = Math_fround($2530 * $2546);
   $2560 = Math_fround($2531 * $2547);
   $2561 = Math_fround($2530 * $2547);
   $2562 = Math_fround($2531 * $2548);
   $2563 = Math_fround($2529 * $2546);
   $2564 = Math_fround($2558 - $2561);
   $2565 = Math_fround($2559 - $2562);
   $2566 = Math_fround($2560 - $2563);
   $2567 = Math_fround($2553 - $2553);
   $2568 = Math_fround($2554 + $2565);
   $2569 = Math_fround($2555 + $2566);
   $2570 = Math_fround($2556 + $2564);
   $2571 = Math_fround($2567 + $2557);
   $2572 = Math_fround($2530 * $2525);
   $2573 = Math_fround($2418 * $2528);
   $2574 = Math_fround($2531 * $2526);
   $2575 = Math_fround($2529 * $2527);
   $2576 = Math_fround($2418 * $2527);
   $2577 = Math_fround($2529 * $2525);
   $2578 = Math_fround($2530 * $2527);
   $2579 = Math_fround($2531 * $2525);
   $2580 = Math_fround($2572 - $2576);
   $2581 = Math_fround($2573 - $2577);
   $2582 = Math_fround($2574 - $2578);
   $2583 = Math_fround($2575 - $2579);
   $2584 = Math_fround($2531 * $2528);
   $2585 = Math_fround($2531 * $2527);
   $2586 = Math_fround($2418 * $2525);
   $2587 = Math_fround($2418 * $2526);
   $2588 = Math_fround($2580 - $2584);
   $2589 = Math_fround($2581 - $2585);
   $2590 = Math_fround($2582 - $2586);
   $2591 = Math_fround($2583 - $2587);
   $2592 = Math_fround($2529 * $2526);
   $2593 = Math_fround($2530 * $2526);
   $2594 = Math_fround($2529 * $2528);
   $2595 = Math_fround($2530 * $2528);
   $2596 = Math_fround($2588 - $2592);
   $2597 = Math_fround($2589 - $2593);
   $2598 = Math_fround($2590 - $2594);
   $2599 = Math_fround($2591 - $2595);
   $2600 = Math_fround($2598 * Math_fround(-1.0));
   $2601 = Math_fround($2599 * Math_fround(-1.0));
   $2602 = Math_fround($2596 * Math_fround(-1.0));
   $2603 = Math_fround($2600 * $2600);
   $2604 = Math_fround($2601 * $2601);
   $2605 = Math_fround($2602 * $2602);
   $2606 = Math_fround($2597 * $2597);
   $2607 = Math_fround($2603 + $2604);
   $2608 = Math_fround($2606 + $2605);
   $2609 = Math_fround($2607 + $2608);
   $2610 = (Math_fround(Math_sqrt((Math_fround($2609)))));
   $2611 = Math_fround(Math_fround(1.0) / $2610);
   $2612 = Math_fround($2611 * $2600);
   $2613 = Math_fround($2611 * $2601);
   $2614 = Math_fround($2611 * $2602);
   $2615 = Math_fround($2611 * $2597);
   HEAPF32[$refRightFootStartX>>2] = $2568;
   $2616 = (($refRightFootStartX) + 4|0);
   HEAPF32[$2616>>2] = $2569;
   $2617 = (($refRightFootStartX) + 8|0);
   HEAPF32[$2617>>2] = $2570;
   $2618 = (($refRightFootStartX) + 12|0);
   HEAPF32[$2618>>2] = $2571;
   $2619 = (($refRightFootStartX) + 16|0);
   HEAPF32[$2619>>2] = $2612;
   $2620 = (($refRightFootStartX) + 20|0);
   HEAPF32[$2620>>2] = $2613;
   $2621 = (($refRightFootStartX) + 24|0);
   HEAPF32[$2621>>2] = $2614;
   $2622 = (($refRightFootStartX) + 28|0);
   HEAPF32[$2622>>2] = $2615;
   $2623 = (($refRightFootStartX) + 32|0);
   HEAPF32[$2623>>2] = Math_fround(1.0);
   $2624 = (($refRightFootStartX) + 36|0);
   HEAPF32[$2624>>2] = Math_fround(1.0);
   $2625 = (($refRightFootStartX) + 40|0);
   HEAPF32[$2625>>2] = Math_fround(1.0);
   $2626 = (($refRightFootStartX) + 44|0);
   HEAPF32[$2626>>2] = Math_fround(1.0);
   $2627 = Math_fround($61 * $2568);
   $2628 = Math_fround($61 * $2569);
   $2629 = Math_fround($61 * $2570);
   $2630 = Math_fround($61 * $2571);
   $2631 = Math_fround($61 * $2612);
   $2632 = Math_fround($61 * $2613);
   $2633 = Math_fround($61 * $2614);
   $2634 = Math_fround($2631 * $2631);
   $2635 = Math_fround($2632 * $2632);
   $2636 = Math_fround($2633 * $2633);
   $2637 = Math_fround($2615 * $2615);
   $2638 = Math_fround($2634 + $2635);
   $2639 = Math_fround($2636 + $2637);
   $2640 = Math_fround($2638 + $2639);
   $2641 = (Math_fround(Math_sqrt((Math_fround($2640)))));
   $2642 = Math_fround(Math_fround(1.0) / $2641);
   $2643 = Math_fround($2631 * $2642);
   $2644 = Math_fround($2632 * $2642);
   $2645 = Math_fround($2633 * $2642);
   $2646 = Math_fround($2615 * $2642);
   HEAPF32[$refLeftFootPrevX>>2] = $2627;
   $2647 = (($refLeftFootPrevX) + 4|0);
   HEAPF32[$2647>>2] = $2628;
   $2648 = (($refLeftFootPrevX) + 8|0);
   HEAPF32[$2648>>2] = $2629;
   $2649 = (($refLeftFootPrevX) + 12|0);
   HEAPF32[$2649>>2] = $2630;
   $2650 = (($refLeftFootPrevX) + 16|0);
   HEAPF32[$2650>>2] = $2643;
   $2651 = (($refLeftFootPrevX) + 20|0);
   HEAPF32[$2651>>2] = $2644;
   $2652 = (($refLeftFootPrevX) + 24|0);
   HEAPF32[$2652>>2] = $2645;
   $2653 = (($refLeftFootPrevX) + 28|0);
   HEAPF32[$2653>>2] = $2646;
   $2654 = (($refLeftFootPrevX) + 32|0);
   HEAPF32[$2654>>2] = Math_fround(1.0);
   $2655 = (($refLeftFootPrevX) + 36|0);
   HEAPF32[$2655>>2] = Math_fround(1.0);
   $2656 = (($refLeftFootPrevX) + 40|0);
   HEAPF32[$2656>>2] = Math_fround(1.0);
   $2657 = (($refLeftFootPrevX) + 44|0);
   HEAPF32[$2657>>2] = Math_fround(1.0);
   HEAPF32[$refRightFootPrevX>>2] = $2627;
   $2658 = (($refRightFootPrevX) + 4|0);
   HEAPF32[$2658>>2] = $2628;
   $2659 = (($refRightFootPrevX) + 8|0);
   HEAPF32[$2659>>2] = $2629;
   $2660 = (($refRightFootPrevX) + 12|0);
   HEAPF32[$2660>>2] = $2630;
   $2661 = (($refRightFootPrevX) + 16|0);
   HEAPF32[$2661>>2] = $2643;
   $2662 = (($refRightFootPrevX) + 20|0);
   HEAPF32[$2662>>2] = $2644;
   $2663 = (($refRightFootPrevX) + 24|0);
   HEAPF32[$2663>>2] = $2645;
   $2664 = (($refRightFootPrevX) + 28|0);
   HEAPF32[$2664>>2] = $2646;
   $2665 = (($refRightFootPrevX) + 32|0);
   HEAPF32[$2665>>2] = Math_fround(1.0);
   $2666 = (($refRightFootPrevX) + 36|0);
   HEAPF32[$2666>>2] = Math_fround(1.0);
   $2667 = (($refRightFootPrevX) + 40|0);
   HEAPF32[$2667>>2] = Math_fround(1.0);
   $2668 = (($refRightFootPrevX) + 44|0);
   HEAPF32[$2668>>2] = Math_fround(1.0);
   $2669 = Math_fround($82 * $2568);
   $2670 = Math_fround($82 * $2569);
   $2671 = Math_fround($82 * $2570);
   $2672 = Math_fround($82 * $2571);
   $2673 = Math_fround($82 * $2612);
   $2674 = Math_fround($82 * $2613);
   $2675 = Math_fround($82 * $2614);
   $2676 = Math_fround($2673 * $2673);
   $2677 = Math_fround($2674 * $2674);
   $2678 = Math_fround($2675 * $2675);
   $2679 = Math_fround($2676 + $2677);
   $2680 = Math_fround($2678 + $2637);
   $2681 = Math_fround($2679 + $2680);
   $2682 = (Math_fround(Math_sqrt((Math_fround($2681)))));
   $2683 = Math_fround(Math_fround(1.0) / $2682);
   $2684 = Math_fround($2673 * $2683);
   $2685 = Math_fround($2674 * $2683);
   $2686 = Math_fround($2675 * $2683);
   $2687 = Math_fround($2615 * $2683);
   HEAPF32[$refRightFootStartX>>2] = $2669;
   HEAPF32[$2616>>2] = $2670;
   HEAPF32[$2617>>2] = $2671;
   HEAPF32[$2618>>2] = $2672;
   HEAPF32[$2619>>2] = $2684;
   HEAPF32[$2620>>2] = $2685;
   HEAPF32[$2621>>2] = $2686;
   HEAPF32[$2622>>2] = $2687;
   HEAPF32[$2623>>2] = Math_fround(1.0);
   HEAPF32[$2624>>2] = Math_fround(1.0);
   HEAPF32[$2625>>2] = Math_fround(1.0);
   HEAPF32[$2626>>2] = Math_fround(1.0);
   __ZN4mathL8xformMulERKNS_5xformES2_18984($18,$prevRootX,$refLeftFootPrevX);
   $2688 = Math_fround(HEAPF32[$18>>2]);
   $2689 = (($18) + 4|0);
   $2690 = Math_fround(HEAPF32[$2689>>2]);
   $2691 = (($18) + 8|0);
   $2692 = Math_fround(HEAPF32[$2691>>2]);
   $2693 = (($18) + 12|0);
   $2694 = Math_fround(HEAPF32[$2693>>2]);
   HEAPF32[$prevRootX>>2] = $2688;
   HEAPF32[$131>>2] = $2690;
   HEAPF32[$132>>2] = $2692;
   HEAPF32[$133>>2] = $2694;
   $2695 = (($18) + 16|0);
   $2696 = Math_fround(HEAPF32[$2695>>2]);
   $2697 = (($18) + 20|0);
   $2698 = Math_fround(HEAPF32[$2697>>2]);
   $2699 = (($18) + 24|0);
   $2700 = Math_fround(HEAPF32[$2699>>2]);
   $2701 = (($18) + 28|0);
   $2702 = Math_fround(HEAPF32[$2701>>2]);
   HEAPF32[$142>>2] = $2696;
   HEAPF32[$143>>2] = $2698;
   HEAPF32[$144>>2] = $2700;
   HEAPF32[$145>>2] = $2702;
   $2703 = (($18) + 32|0);
   $2704 = Math_fround(HEAPF32[$2703>>2]);
   $2705 = (($18) + 36|0);
   $2706 = Math_fround(HEAPF32[$2705>>2]);
   $2707 = (($18) + 40|0);
   $2708 = Math_fround(HEAPF32[$2707>>2]);
   $2709 = (($18) + 44|0);
   $2710 = Math_fround(HEAPF32[$2709>>2]);
   HEAPF32[$154>>2] = $2704;
   HEAPF32[$155>>2] = $2706;
   HEAPF32[$156>>2] = $2708;
   HEAPF32[$157>>2] = $2710;
   __ZN4mathL8xformMulERKNS_5xformES2_18984($19,$rootX,$refRightFootStartX);
   $2711 = Math_fround(HEAPF32[$19>>2]);
   $2712 = (($19) + 4|0);
   $2713 = Math_fround(HEAPF32[$2712>>2]);
   $2714 = (($19) + 8|0);
   $2715 = Math_fround(HEAPF32[$2714>>2]);
   $2716 = (($19) + 12|0);
   $2717 = Math_fround(HEAPF32[$2716>>2]);
   HEAPF32[$rootX>>2] = $2711;
   HEAPF32[$235>>2] = $2713;
   HEAPF32[$236>>2] = $2715;
   HEAPF32[$237>>2] = $2717;
   $2718 = (($19) + 16|0);
   $2719 = Math_fround(HEAPF32[$2718>>2]);
   $2720 = (($19) + 20|0);
   $2721 = Math_fround(HEAPF32[$2720>>2]);
   $2722 = (($19) + 24|0);
   $2723 = Math_fround(HEAPF32[$2722>>2]);
   $2724 = (($19) + 28|0);
   $2725 = Math_fround(HEAPF32[$2724>>2]);
   HEAPF32[$246>>2] = $2719;
   HEAPF32[$247>>2] = $2721;
   HEAPF32[$248>>2] = $2723;
   HEAPF32[$249>>2] = $2725;
   $2726 = (($19) + 32|0);
   $2727 = Math_fround(HEAPF32[$2726>>2]);
   $2728 = (($19) + 36|0);
   $2729 = Math_fround(HEAPF32[$2728>>2]);
   $2730 = (($19) + 40|0);
   $2731 = Math_fround(HEAPF32[$2730>>2]);
   $2732 = (($19) + 44|0);
   $2733 = Math_fround(HEAPF32[$2732>>2]);
   HEAPF32[$258>>2] = $2727;
   HEAPF32[$259>>2] = $2729;
   HEAPF32[$260>>2] = $2731;
   HEAPF32[$261>>2] = $2733;
   __ZN4mathL8xformMulERKNS_5xformES2_18984($20,$clipIn$i,$refRightFootPrevX);
   $2734 = Math_fround(HEAPF32[$20>>2]);
   $2735 = (($20) + 4|0);
   $2736 = Math_fround(HEAPF32[$2735>>2]);
   $2737 = (($20) + 8|0);
   $2738 = Math_fround(HEAPF32[$2737>>2]);
   $2739 = (($20) + 12|0);
   $2740 = Math_fround(HEAPF32[$2739>>2]);
   HEAPF32[$clipIn$i>>2] = $2734;
   HEAPF32[$836>>2] = $2736;
   HEAPF32[$837>>2] = $2738;
   HEAPF32[$838>>2] = $2740;
   $2741 = (($20) + 16|0);
   $2742 = Math_fround(HEAPF32[$2741>>2]);
   $2743 = (($20) + 20|0);
   $2744 = Math_fround(HEAPF32[$2743>>2]);
   $2745 = (($20) + 24|0);
   $2746 = Math_fround(HEAPF32[$2745>>2]);
   $2747 = (($20) + 28|0);
   $2748 = Math_fround(HEAPF32[$2747>>2]);
   HEAPF32[$847>>2] = $2742;
   HEAPF32[$848>>2] = $2744;
   HEAPF32[$849>>2] = $2746;
   HEAPF32[$850>>2] = $2748;
   $2749 = (($20) + 32|0);
   $2750 = Math_fround(HEAPF32[$2749>>2]);
   $2751 = (($20) + 36|0);
   $2752 = Math_fround(HEAPF32[$2751>>2]);
   $2753 = (($20) + 40|0);
   $2754 = Math_fround(HEAPF32[$2753>>2]);
   $2755 = (($20) + 44|0);
   $2756 = Math_fround(HEAPF32[$2755>>2]);
   HEAPF32[$859>>2] = $2750;
   HEAPF32[$860>>2] = $2752;
   HEAPF32[$861>>2] = $2754;
   HEAPF32[$862>>2] = $2756;
   $2757 = (($refLeftFootX) + 28|0);
   ;HEAP32[$refLeftFootX+0>>2]=0|0;HEAP32[$refLeftFootX+4>>2]=0|0;HEAP32[$refLeftFootX+8>>2]=0|0;HEAP32[$refLeftFootX+12>>2]=0|0;HEAP32[$refLeftFootX+16>>2]=0|0;HEAP32[$refLeftFootX+20>>2]=0|0;HEAP32[$refLeftFootX+24>>2]=0|0;
   HEAPF32[$2757>>2] = Math_fround(1.0);
   $2758 = (($refLeftFootX) + 44|0);
   HEAPF32[$2758>>2] = Math_fround(1.0);
   $2759 = (($refLeftFootX) + 40|0);
   HEAPF32[$2759>>2] = Math_fround(1.0);
   $2760 = (($refLeftFootX) + 36|0);
   HEAPF32[$2760>>2] = Math_fround(1.0);
   $2761 = (($refLeftFootX) + 32|0);
   HEAPF32[$2761>>2] = Math_fround(1.0);
   $2762 = Math_fround(HEAPF32[$targetTimeInt>>2]);
   $2763 = Math_fround(HEAPF32[$currentTimeInt>>2]);
   $2764 = Math_fround($2762 - $2763);
   $2765 = $2764 > Math_fround(0.0);
   if ($2765) {
    $2766 = (($refLeftFootX) + 4|0);
    $2767 = (($refLeftFootX) + 8|0);
    $2768 = (($refLeftFootX) + 12|0);
    $2769 = (($refLeftFootX) + 16|0);
    $2770 = (($refLeftFootX) + 20|0);
    $2771 = (($refLeftFootX) + 24|0);
    $2772 = (($21) + 4|0);
    $2773 = (($21) + 8|0);
    $2774 = (($21) + 12|0);
    $2775 = (($21) + 16|0);
    $2776 = (($21) + 20|0);
    $2777 = (($21) + 24|0);
    $2778 = (($21) + 28|0);
    $2779 = (($21) + 32|0);
    $2780 = (($21) + 36|0);
    $2781 = (($21) + 40|0);
    $2782 = (($21) + 44|0);
    $i$0696 = 0;
    while(1) {
     $2783 = ($i$0696|0)==(0);
     if ($2783) {
      $2784 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
      $2785 = Math_fround($2784 * Math_fround(-1.0));
      $2786 = Math_fround(HEAPF32[$$pre$phi721Z2D>>2]);
      $2787 = Math_fround($2786 * Math_fround(-1.0));
      $2788 = Math_fround(HEAPF32[$$pre$phi723Z2D>>2]);
      $2789 = Math_fround($2788 * Math_fround(-1.0));
      $2790 = Math_fround(HEAPF32[$262>>2]);
      $2791 = Math_fround(HEAPF32[$refStopX>>2]);
      $2792 = Math_fround(HEAPF32[$$pre$phi725Z2D>>2]);
      $2793 = Math_fround($2791 - $2792);
      $2794 = Math_fround(HEAPF32[$864>>2]);
      $2795 = Math_fround(HEAPF32[$$pre$phi727Z2D>>2]);
      $2796 = Math_fround($2794 - $2795);
      $2797 = Math_fround(HEAPF32[$866>>2]);
      $2798 = Math_fround(HEAPF32[$$pre$phi729Z2D>>2]);
      $2799 = Math_fround($2797 - $2798);
      $2800 = Math_fround(HEAPF32[$868>>2]);
      $2801 = Math_fround(HEAPF32[$$pre$phi731Z2D>>2]);
      $2802 = Math_fround($2800 - $2801);
      $2803 = Math_fround($2793 + $2793);
      $2804 = Math_fround($2796 + $2796);
      $2805 = Math_fround($2799 + $2799);
      $2806 = Math_fround($2785 * $2804);
      $2807 = Math_fround($2787 * $2805);
      $2808 = Math_fround($2789 * $2803);
      $2809 = Math_fround($2790 * Math_fround(0.0));
      $2810 = Math_fround($2787 * $2803);
      $2811 = Math_fround($2789 * $2804);
      $2812 = Math_fround($2785 * $2805);
      $2813 = Math_fround($2806 - $2810);
      $2814 = Math_fround($2807 - $2811);
      $2815 = Math_fround($2808 - $2812);
      $2816 = Math_fround($2809 - $2809);
      $2817 = Math_fround($2790 * $2814);
      $2818 = Math_fround($2790 * $2815);
      $2819 = Math_fround($2790 * $2813);
      $2820 = Math_fround($2790 * $2816);
      $2821 = Math_fround($2793 + $2817);
      $2822 = Math_fround($2796 + $2818);
      $2823 = Math_fround($2799 + $2819);
      $2824 = Math_fround($2820 + $2802);
      $2825 = Math_fround($2785 * $2815);
      $2826 = Math_fround($2787 * $2813);
      $2827 = Math_fround($2789 * $2814);
      $2828 = Math_fround($2787 * $2814);
      $2829 = Math_fround($2789 * $2815);
      $2830 = Math_fround($2785 * $2813);
      $2831 = Math_fround($2825 - $2828);
      $2832 = Math_fround($2826 - $2829);
      $2833 = Math_fround($2827 - $2830);
      $2834 = Math_fround($2820 - $2820);
      $2835 = Math_fround($2821 + $2832);
      $2836 = Math_fround($2822 + $2833);
      $2837 = Math_fround($2823 + $2831);
      $2838 = Math_fround($2834 + $2824);
      $2839 = Math_fround(HEAPF32[$873>>2]);
      $2840 = Math_fround($2787 * $2839);
      $2841 = Math_fround(HEAPF32[$267>>2]);
      $2842 = Math_fround($2790 * $2841);
      $2843 = Math_fround(HEAPF32[$875>>2]);
      $2844 = Math_fround($2789 * $2843);
      $2845 = Math_fround(HEAPF32[$877>>2]);
      $2846 = Math_fround($2785 * $2845);
      $2847 = Math_fround($2790 * $2845);
      $2848 = Math_fround($2785 * $2839);
      $2849 = Math_fround($2787 * $2845);
      $2850 = Math_fround($2789 * $2839);
      $2851 = Math_fround($2840 - $2847);
      $2852 = Math_fround($2842 - $2848);
      $2853 = Math_fround($2844 - $2849);
      $2854 = Math_fround($2846 - $2850);
      $2855 = Math_fround($2789 * $2841);
      $2856 = Math_fround($2789 * $2845);
      $2857 = Math_fround($2790 * $2839);
      $2858 = Math_fround($2790 * $2843);
      $2859 = Math_fround($2851 - $2855);
      $2860 = Math_fround($2852 - $2856);
      $2861 = Math_fround($2853 - $2857);
      $2862 = Math_fround($2854 - $2858);
      $2863 = Math_fround($2785 * $2843);
      $2864 = Math_fround($2787 * $2843);
      $2865 = Math_fround($2785 * $2841);
      $2866 = Math_fround($2787 * $2841);
      $2867 = Math_fround($2859 - $2863);
      $2868 = Math_fround($2860 - $2864);
      $2869 = Math_fround($2861 - $2865);
      $2870 = Math_fround($2862 - $2866);
      $2871 = Math_fround($2869 * Math_fround(-1.0));
      $2872 = Math_fround($2870 * Math_fround(-1.0));
      $2873 = Math_fround($2867 * Math_fround(-1.0));
      $2874 = Math_fround($2871 * $2871);
      $2875 = Math_fround($2872 * $2872);
      $2876 = Math_fround($2873 * $2873);
      $2877 = Math_fround($2868 * $2868);
      $2878 = Math_fround($2874 + $2875);
      $2879 = Math_fround($2877 + $2876);
      $2880 = Math_fround($2878 + $2879);
      $2881 = (Math_fround(Math_sqrt((Math_fround($2880)))));
      $2882 = Math_fround(Math_fround(1.0) / $2881);
      $2883 = Math_fround($2882 * $2871);
      $2884 = Math_fround($2882 * $2872);
      $2885 = Math_fround($2882 * $2873);
      $2886 = Math_fround($2882 * $2868);
      HEAPF32[$refLeftFootX>>2] = $2835;
      HEAPF32[$2766>>2] = $2836;
      HEAPF32[$2767>>2] = $2837;
      HEAPF32[$2768>>2] = $2838;
      HEAPF32[$2769>>2] = $2883;
      HEAPF32[$2770>>2] = $2884;
      HEAPF32[$2771>>2] = $2885;
      HEAPF32[$2757>>2] = $2886;
      HEAPF32[$2761>>2] = Math_fround(1.0);
      HEAPF32[$2760>>2] = Math_fround(1.0);
      HEAPF32[$2759>>2] = Math_fround(1.0);
      HEAPF32[$2758>>2] = Math_fround(1.0);
     }
     __ZN4mathL8xformMulERKNS_5xformES2_18984($21,$targetRefX,$refLeftFootX);
     $2887 = Math_fround(HEAPF32[$21>>2]);
     $2888 = Math_fround(HEAPF32[$2772>>2]);
     $2889 = Math_fround(HEAPF32[$2773>>2]);
     $2890 = Math_fround(HEAPF32[$2774>>2]);
     HEAPF32[$targetRefX>>2] = $2887;
     HEAPF32[$870>>2] = $2888;
     HEAPF32[$871>>2] = $2889;
     HEAPF32[$872>>2] = $2890;
     $2891 = Math_fround(HEAPF32[$2775>>2]);
     $2892 = Math_fround(HEAPF32[$2776>>2]);
     $2893 = Math_fround(HEAPF32[$2777>>2]);
     $2894 = Math_fround(HEAPF32[$2778>>2]);
     HEAPF32[$880>>2] = $2891;
     HEAPF32[$881>>2] = $2892;
     HEAPF32[$882>>2] = $2893;
     HEAPF32[$883>>2] = $2894;
     $2895 = Math_fround(HEAPF32[$2779>>2]);
     $2896 = Math_fround(HEAPF32[$2780>>2]);
     $2897 = Math_fround(HEAPF32[$2781>>2]);
     $2898 = Math_fround(HEAPF32[$2782>>2]);
     HEAPF32[$888>>2] = $2895;
     HEAPF32[$889>>2] = $2896;
     HEAPF32[$890>>2] = $2897;
     HEAPF32[$891>>2] = $2898;
     $2899 = (($i$0696) + 1)|0;
     $2900 = (Math_fround(($2899|0)));
     $2901 = $2900 < $2764;
     if ($2901) {
      $i$0696 = $2899;
     } else {
      break;
     }
    }
   }
   $2902 = ($targetGoalIndex$0|0)>(-1);
   if ($2902) {
    $2903 = ((($constant) + (($targetGoalIndex$0*76)|0)|0) + 80|0);
    $2904 = Math_fround(HEAPF32[$2903>>2]);
    $2905 = Math_fround($2906 * $2904);
    $2907 = ((($constant) + (($targetGoalIndex$0*76)|0)|0) + 84|0);
    $2908 = Math_fround(HEAPF32[$2907>>2]);
    $2909 = Math_fround($2906 * $2908);
    $2910 = ((($constant) + (($targetGoalIndex$0*76)|0)|0) + 88|0);
    $2911 = Math_fround(HEAPF32[$2910>>2]);
    $2912 = Math_fround($2906 * $2911);
    $2913 = ((($constant) + (($targetGoalIndex$0*76)|0)|0) + 92|0);
    $2914 = Math_fround(HEAPF32[$2913>>2]);
    $2915 = Math_fround($2906 * $2914);
    $2916 = ((($constant) + (($targetGoalIndex$0*76)|0)|0) + 96|0);
    $2917 = Math_fround(HEAPF32[$2916>>2]);
    $2918 = Math_fround($2906 * $2917);
    $2919 = ((($constant) + (($targetGoalIndex$0*76)|0)|0) + 100|0);
    $2920 = Math_fround(HEAPF32[$2919>>2]);
    $2921 = Math_fround($2906 * $2920);
    $2922 = ((($constant) + (($targetGoalIndex$0*76)|0)|0) + 104|0);
    $2923 = Math_fround(HEAPF32[$2922>>2]);
    $2924 = Math_fround($2906 * $2923);
    $2925 = ((($constant) + (($targetGoalIndex$0*76)|0)|0) + 108|0);
    $2926 = Math_fround(HEAPF32[$2925>>2]);
    $2927 = Math_fround($2918 * $2918);
    $2928 = Math_fround($2921 * $2921);
    $2929 = Math_fround($2924 * $2924);
    $2930 = Math_fround($2926 * $2926);
    $2931 = Math_fround($2927 + $2928);
    $2932 = Math_fround($2929 + $2930);
    $2933 = Math_fround($2931 + $2932);
    $2934 = (Math_fround(Math_sqrt((Math_fround($2933)))));
    $2935 = Math_fround(Math_fround(1.0) / $2934);
    $2936 = Math_fround($2918 * $2935);
    $2937 = Math_fround($2921 * $2935);
    $2938 = Math_fround($2924 * $2935);
    $2939 = Math_fround($2926 * $2935);
    HEAPF32[$23>>2] = $2905;
    $2940 = (($23) + 4|0);
    HEAPF32[$2940>>2] = $2909;
    $2941 = (($23) + 8|0);
    HEAPF32[$2941>>2] = $2912;
    $2942 = (($23) + 12|0);
    HEAPF32[$2942>>2] = $2915;
    $2943 = (($23) + 16|0);
    HEAPF32[$2943>>2] = $2936;
    $2944 = (($23) + 20|0);
    HEAPF32[$2944>>2] = $2937;
    $2945 = (($23) + 24|0);
    HEAPF32[$2945>>2] = $2938;
    $2946 = (($23) + 28|0);
    HEAPF32[$2946>>2] = $2939;
    $2947 = (($23) + 32|0);
    HEAPF32[$2947>>2] = Math_fround(1.0);
    $2948 = (($23) + 36|0);
    HEAPF32[$2948>>2] = Math_fround(1.0);
    $2949 = (($23) + 40|0);
    HEAPF32[$2949>>2] = Math_fround(1.0);
    $2950 = (($23) + 44|0);
    HEAPF32[$2950>>2] = Math_fround(1.0);
    __ZN4mathL8xformMulERKNS_5xformES2_18984($22,$targetGoalX,$23);
    $2951 = Math_fround(HEAPF32[$22>>2]);
    $2952 = (($22) + 4|0);
    $2953 = Math_fround(HEAPF32[$2952>>2]);
    $2954 = (($22) + 8|0);
    $2955 = Math_fround(HEAPF32[$2954>>2]);
    $2956 = (($22) + 12|0);
    $2957 = Math_fround(HEAPF32[$2956>>2]);
    HEAPF32[$targetGoalX>>2] = $2951;
    $2958 = (($targetGoalX) + 4|0);
    HEAPF32[$2958>>2] = $2953;
    $2959 = (($targetGoalX) + 8|0);
    HEAPF32[$2959>>2] = $2955;
    $2960 = (($targetGoalX) + 12|0);
    HEAPF32[$2960>>2] = $2957;
    $2961 = (($22) + 16|0);
    $2962 = Math_fround(HEAPF32[$2961>>2]);
    $2963 = (($22) + 20|0);
    $2964 = Math_fround(HEAPF32[$2963>>2]);
    $2965 = (($22) + 24|0);
    $2966 = Math_fround(HEAPF32[$2965>>2]);
    $2967 = (($22) + 28|0);
    $2968 = Math_fround(HEAPF32[$2967>>2]);
    $2969 = (($targetGoalX) + 16|0);
    HEAPF32[$2969>>2] = $2962;
    $2970 = (($targetGoalX) + 20|0);
    HEAPF32[$2970>>2] = $2964;
    $2971 = (($targetGoalX) + 24|0);
    HEAPF32[$2971>>2] = $2966;
    HEAPF32[$892>>2] = $2968;
    $2972 = (($22) + 32|0);
    $2973 = Math_fround(HEAPF32[$2972>>2]);
    $2974 = (($22) + 36|0);
    $2975 = Math_fround(HEAPF32[$2974>>2]);
    $2976 = (($22) + 40|0);
    $2977 = Math_fround(HEAPF32[$2976>>2]);
    $2978 = (($22) + 44|0);
    $2979 = Math_fround(HEAPF32[$2978>>2]);
    HEAPF32[$893>>2] = $2973;
    HEAPF32[$894>>2] = $2975;
    HEAPF32[$895>>2] = $2977;
    HEAPF32[$896>>2] = $2979;
   }
  }
 }
 $2980 = Math_fround(HEAPF32[$rootX>>2]);
 $2981 = Math_fround(HEAPF32[$235>>2]);
 $2982 = Math_fround(HEAPF32[$236>>2]);
 $2983 = Math_fround(HEAPF32[$237>>2]);
 HEAPF32[$humanPose>>2] = $2980;
 HEAPF32[$229>>2] = $2981;
 HEAPF32[$231>>2] = $2982;
 HEAPF32[$233>>2] = $2983;
 $2984 = Math_fround(HEAPF32[$246>>2]);
 $2985 = Math_fround(HEAPF32[$247>>2]);
 $2986 = Math_fround(HEAPF32[$248>>2]);
 $2987 = Math_fround(HEAPF32[$249>>2]);
 HEAPF32[$238>>2] = $2984;
 HEAPF32[$240>>2] = $2985;
 HEAPF32[$242>>2] = $2986;
 HEAPF32[$244>>2] = $2987;
 $2988 = Math_fround(HEAPF32[$258>>2]);
 $2989 = Math_fround(HEAPF32[$259>>2]);
 $2990 = Math_fround(HEAPF32[$260>>2]);
 $2991 = Math_fround(HEAPF32[$261>>2]);
 HEAPF32[$250>>2] = $2988;
 HEAPF32[$252>>2] = $2989;
 HEAPF32[$254>>2] = $2990;
 HEAPF32[$256>>2] = $2991;
 $2992 = (($24) + 4|0);
 $2993 = (($24) + 8|0);
 $2994 = (($24) + 12|0);
 $2995 = (($24) + 16|0);
 $2996 = (($24) + 20|0);
 $2997 = (($24) + 24|0);
 $2998 = (($24) + 28|0);
 $2999 = (($24) + 32|0);
 $3000 = (($24) + 36|0);
 $3001 = (($24) + 40|0);
 $3002 = (($24) + 44|0);
 $i1$0695 = 0;
 while(1) {
  $3003 = ((($humanPose) + (($i1$0695*76)|0)|0) + 80|0);
  __ZN4mathL8xformMulERKNS_5xformES2_18984($24,$rootX,$3003);
  $3004 = Math_fround(HEAPF32[$24>>2]);
  $3005 = Math_fround(HEAPF32[$2992>>2]);
  $3006 = Math_fround(HEAPF32[$2993>>2]);
  $3007 = Math_fround(HEAPF32[$2994>>2]);
  HEAPF32[$3003>>2] = $3004;
  $3008 = ((($humanPose) + (($i1$0695*76)|0)|0) + 84|0);
  HEAPF32[$3008>>2] = $3005;
  $3009 = ((($humanPose) + (($i1$0695*76)|0)|0) + 88|0);
  HEAPF32[$3009>>2] = $3006;
  $3010 = ((($humanPose) + (($i1$0695*76)|0)|0) + 92|0);
  HEAPF32[$3010>>2] = $3007;
  $3011 = Math_fround(HEAPF32[$2995>>2]);
  $3012 = Math_fround(HEAPF32[$2996>>2]);
  $3013 = Math_fround(HEAPF32[$2997>>2]);
  $3014 = Math_fround(HEAPF32[$2998>>2]);
  $3015 = ((($humanPose) + (($i1$0695*76)|0)|0) + 96|0);
  HEAPF32[$3015>>2] = $3011;
  $3016 = ((($humanPose) + (($i1$0695*76)|0)|0) + 100|0);
  HEAPF32[$3016>>2] = $3012;
  $3017 = ((($humanPose) + (($i1$0695*76)|0)|0) + 104|0);
  HEAPF32[$3017>>2] = $3013;
  $3018 = ((($humanPose) + (($i1$0695*76)|0)|0) + 108|0);
  HEAPF32[$3018>>2] = $3014;
  $3019 = Math_fround(HEAPF32[$2999>>2]);
  $3020 = Math_fround(HEAPF32[$3000>>2]);
  $3021 = Math_fround(HEAPF32[$3001>>2]);
  $3022 = Math_fround(HEAPF32[$3002>>2]);
  $3023 = ((($humanPose) + (($i1$0695*76)|0)|0) + 112|0);
  HEAPF32[$3023>>2] = $3019;
  $3024 = ((($humanPose) + (($i1$0695*76)|0)|0) + 116|0);
  HEAPF32[$3024>>2] = $3020;
  $3025 = ((($humanPose) + (($i1$0695*76)|0)|0) + 120|0);
  HEAPF32[$3025>>2] = $3021;
  $3026 = ((($humanPose) + (($i1$0695*76)|0)|0) + 124|0);
  HEAPF32[$3026>>2] = $3022;
  $3027 = (($i1$0695) + 1)|0;
  $exitcond = ($3027|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $i1$0695 = $3027;
  }
 }
 __ZN4mathL8xformMulERKNS_5xformES2_18984($25,$prevRootX,$prevLeftFootX);
 $3028 = Math_fround(HEAPF32[$25>>2]);
 $3029 = (($25) + 4|0);
 $3030 = Math_fround(HEAPF32[$3029>>2]);
 $3031 = (($25) + 8|0);
 $3032 = Math_fround(HEAPF32[$3031>>2]);
 $3033 = (($25) + 12|0);
 $3034 = Math_fround(HEAPF32[$3033>>2]);
 HEAPF32[$158>>2] = $3028;
 HEAPF32[$160>>2] = $3030;
 HEAPF32[$162>>2] = $3032;
 HEAPF32[$164>>2] = $3034;
 $3035 = (($25) + 16|0);
 $3036 = Math_fround(HEAPF32[$3035>>2]);
 $3037 = (($25) + 20|0);
 $3038 = Math_fround(HEAPF32[$3037>>2]);
 $3039 = (($25) + 24|0);
 $3040 = Math_fround(HEAPF32[$3039>>2]);
 $3041 = (($25) + 28|0);
 $3042 = Math_fround(HEAPF32[$3041>>2]);
 HEAPF32[$169>>2] = $3036;
 HEAPF32[$171>>2] = $3038;
 HEAPF32[$173>>2] = $3040;
 HEAPF32[$175>>2] = $3042;
 $3043 = (($25) + 32|0);
 $3044 = Math_fround(HEAPF32[$3043>>2]);
 $3045 = (($25) + 36|0);
 $3046 = Math_fround(HEAPF32[$3045>>2]);
 $3047 = (($25) + 40|0);
 $3048 = Math_fround(HEAPF32[$3047>>2]);
 $3049 = (($25) + 44|0);
 $3050 = Math_fround(HEAPF32[$3049>>2]);
 HEAPF32[$181>>2] = $3044;
 HEAPF32[$183>>2] = $3046;
 HEAPF32[$185>>2] = $3048;
 HEAPF32[$187>>2] = $3050;
 __ZN4mathL8xformMulERKNS_5xformES2_18984($26,$prevRootX,$prevRightFootX);
 $3051 = Math_fround(HEAPF32[$26>>2]);
 $3052 = (($26) + 4|0);
 $3053 = Math_fround(HEAPF32[$3052>>2]);
 $3054 = (($26) + 8|0);
 $3055 = Math_fround(HEAPF32[$3054>>2]);
 $3056 = (($26) + 12|0);
 $3057 = Math_fround(HEAPF32[$3056>>2]);
 HEAPF32[$193>>2] = $3051;
 HEAPF32[$195>>2] = $3053;
 HEAPF32[$197>>2] = $3055;
 HEAPF32[$199>>2] = $3057;
 $3058 = (($26) + 16|0);
 $3059 = Math_fround(HEAPF32[$3058>>2]);
 $3060 = (($26) + 20|0);
 $3061 = Math_fround(HEAPF32[$3060>>2]);
 $3062 = (($26) + 24|0);
 $3063 = Math_fround(HEAPF32[$3062>>2]);
 $3064 = (($26) + 28|0);
 $3065 = Math_fround(HEAPF32[$3064>>2]);
 HEAPF32[$204>>2] = $3059;
 HEAPF32[$206>>2] = $3061;
 HEAPF32[$208>>2] = $3063;
 HEAPF32[$210>>2] = $3065;
 $3066 = (($26) + 32|0);
 $3067 = Math_fround(HEAPF32[$3066>>2]);
 $3068 = (($26) + 36|0);
 $3069 = Math_fround(HEAPF32[$3068>>2]);
 $3070 = (($26) + 40|0);
 $3071 = Math_fround(HEAPF32[$3070>>2]);
 $3072 = (($26) + 44|0);
 $3073 = Math_fround(HEAPF32[$3072>>2]);
 HEAPF32[$216>>2] = $3067;
 HEAPF32[$218>>2] = $3069;
 HEAPF32[$220>>2] = $3071;
 HEAPF32[$222>>2] = $3073;
 $3074 = HEAP8[$42>>0]|0;
 $3075 = ($3074<<24>>24)==(0);
 do {
  if ($3075) {
   $3570 = Math_fround(HEAPF32[$38>>2]);
   $3571 = Math_fround(HEAPF32[$input>>2]);
   $3572 = $3570 != $3571;
   if ($3572) {
    $3573 = Math_fround($1691 - $1588);
    $3574 = Math_fround($1694 - $1591);
    $3575 = Math_fround($1697 - $1594);
    $3576 = Math_fround($1700 - $1597);
    $3577 = Math_fround($3573 + $3573);
    $3578 = Math_fround($3574 + $3574);
    $3579 = Math_fround($3575 + $3575);
    $3580 = Math_fround($1580 * $3578);
    $3581 = Math_fround($1582 * $3579);
    $3582 = Math_fround($1584 * $3577);
    $3583 = Math_fround($1582 * $3577);
    $3584 = Math_fround($1584 * $3578);
    $3585 = Math_fround($1580 * $3579);
    $3586 = Math_fround($3580 - $3583);
    $3587 = Math_fround($3581 - $3584);
    $3588 = Math_fround($3582 - $3585);
    $3589 = Math_fround($1605 * $3587);
    $3590 = Math_fround($1605 * $3588);
    $3591 = Math_fround($1605 * $3586);
    $3592 = Math_fround($3573 + $3589);
    $3593 = Math_fround($3574 + $3590);
    $3594 = Math_fround($3575 + $3591);
    $3595 = Math_fround($1616 + $3576);
    $3596 = Math_fround($1580 * $3588);
    $3597 = Math_fround($1582 * $3586);
    $3598 = Math_fround($1584 * $3587);
    $3599 = Math_fround($1582 * $3587);
    $3600 = Math_fround($1584 * $3588);
    $3601 = Math_fround($1580 * $3586);
    $3602 = Math_fround($3596 - $3599);
    $3603 = Math_fround($3597 - $3600);
    $3604 = Math_fround($3598 - $3601);
    $3605 = Math_fround($3592 + $3603);
    $3606 = Math_fround($3593 + $3604);
    $3607 = Math_fround($3594 + $3602);
    $3608 = Math_fround($1630 + $3595);
    $3609 = Math_fround($1582 * $1684);
    $3610 = Math_fround($1605 * $1708);
    $3611 = Math_fround($1584 * $1686);
    $3612 = Math_fround($1580 * $1688);
    $3613 = Math_fround($1605 * $1688);
    $3614 = Math_fround($1580 * $1684);
    $3615 = Math_fround($1582 * $1688);
    $3616 = Math_fround($1584 * $1684);
    $3617 = Math_fround($3609 - $3613);
    $3618 = Math_fround($3610 - $3614);
    $3619 = Math_fround($3611 - $3615);
    $3620 = Math_fround($3612 - $3616);
    $3621 = Math_fround($1584 * $1708);
    $3622 = Math_fround($1584 * $1688);
    $3623 = Math_fround($1605 * $1684);
    $3624 = Math_fround($1605 * $1686);
    $3625 = Math_fround($3617 - $3621);
    $3626 = Math_fround($3618 - $3622);
    $3627 = Math_fround($3619 - $3623);
    $3628 = Math_fround($3620 - $3624);
    $3629 = Math_fround($1580 * $1686);
    $3630 = Math_fround($1582 * $1686);
    $3631 = Math_fround($1580 * $1708);
    $3632 = Math_fround($1582 * $1708);
    $3633 = Math_fround($3625 - $3629);
    $3634 = Math_fround($3626 - $3630);
    $3635 = Math_fround($3627 - $3631);
    $3636 = Math_fround($3628 - $3632);
    $3637 = Math_fround($3635 * Math_fround(-1.0));
    $3638 = Math_fround($3636 * Math_fround(-1.0));
    $3639 = Math_fround($3633 * Math_fround(-1.0));
    $3640 = Math_fround($3637 * $3637);
    $3641 = Math_fround($3638 * $3638);
    $3642 = Math_fround($3639 * $3639);
    $3643 = Math_fround($3634 * $3634);
    $3644 = Math_fround($3640 + $3641);
    $3645 = Math_fround($3643 + $3642);
    $3646 = Math_fround($3644 + $3645);
    $3647 = (Math_fround(Math_sqrt((Math_fround($3646)))));
    $3648 = Math_fround(Math_fround(1.0) / $3647);
    $3649 = Math_fround($3637 * $3648);
    $3650 = Math_fround($3638 * $3648);
    $3651 = Math_fround($3639 * $3648);
    $3652 = Math_fround($3634 * $3648);
    $3654 = $3652;$3657 = $3650;$3659 = $3651;$3661 = $3649;$3665 = $3606;$3670 = $3607;$3672 = $3605;$4047 = $3608;
   } else {
    $3654 = Math_fround(1.0);$3657 = Math_fround(0.0);$3659 = Math_fround(0.0);$3661 = Math_fround(0.0);$3665 = Math_fround(0.0);$3670 = Math_fround(0.0);$3672 = Math_fround(0.0);$4047 = Math_fround(0.0);
   }
  } else {
   $3076 = Math_fround($82 - $61);
   $3077 = (Math_fround(Math_abs((Math_fround($3076)))));
   $3078 = $3077 > Math_fround(0.5);
   if (!($3078)) {
    $3489 = $82 != $61;
    if (!($3489)) {
     $3654 = Math_fround(1.0);$3657 = Math_fround(0.0);$3659 = Math_fround(0.0);$3661 = Math_fround(0.0);$3665 = Math_fround(0.0);$3670 = Math_fround(0.0);$3672 = Math_fround(0.0);$4047 = Math_fround(0.0);
     break;
    }
    $3490 = Math_fround($1691 - $1588);
    $3491 = Math_fround($1694 - $1591);
    $3492 = Math_fround($1697 - $1594);
    $3493 = Math_fround($1700 - $1597);
    $3494 = Math_fround($3490 + $3490);
    $3495 = Math_fround($3491 + $3491);
    $3496 = Math_fround($3492 + $3492);
    $3497 = Math_fround($1580 * $3495);
    $3498 = Math_fround($1582 * $3496);
    $3499 = Math_fround($1584 * $3494);
    $3500 = Math_fround($1582 * $3494);
    $3501 = Math_fround($1584 * $3495);
    $3502 = Math_fround($1580 * $3496);
    $3503 = Math_fround($3497 - $3500);
    $3504 = Math_fround($3498 - $3501);
    $3505 = Math_fround($3499 - $3502);
    $3506 = Math_fround($1605 * $3504);
    $3507 = Math_fround($1605 * $3505);
    $3508 = Math_fround($1605 * $3503);
    $3509 = Math_fround($3490 + $3506);
    $3510 = Math_fround($3491 + $3507);
    $3511 = Math_fround($3492 + $3508);
    $3512 = Math_fround($1616 + $3493);
    $3513 = Math_fround($1580 * $3505);
    $3514 = Math_fround($1582 * $3503);
    $3515 = Math_fround($1584 * $3504);
    $3516 = Math_fround($1582 * $3504);
    $3517 = Math_fround($1584 * $3505);
    $3518 = Math_fround($1580 * $3503);
    $3519 = Math_fround($3513 - $3516);
    $3520 = Math_fround($3514 - $3517);
    $3521 = Math_fround($3515 - $3518);
    $3522 = Math_fround($3509 + $3520);
    $3523 = Math_fround($3510 + $3521);
    $3524 = Math_fround($3511 + $3519);
    $3525 = Math_fround($1630 + $3512);
    $3526 = Math_fround($1582 * $1684);
    $3527 = Math_fround($1605 * $1708);
    $3528 = Math_fround($1584 * $1686);
    $3529 = Math_fround($1580 * $1688);
    $3530 = Math_fround($1605 * $1688);
    $3531 = Math_fround($1580 * $1684);
    $3532 = Math_fround($1582 * $1688);
    $3533 = Math_fround($1584 * $1684);
    $3534 = Math_fround($3526 - $3530);
    $3535 = Math_fround($3527 - $3531);
    $3536 = Math_fround($3528 - $3532);
    $3537 = Math_fround($3529 - $3533);
    $3538 = Math_fround($1584 * $1708);
    $3539 = Math_fround($1584 * $1688);
    $3540 = Math_fround($1605 * $1684);
    $3541 = Math_fround($1605 * $1686);
    $3542 = Math_fround($3534 - $3538);
    $3543 = Math_fround($3535 - $3539);
    $3544 = Math_fround($3536 - $3540);
    $3545 = Math_fround($3537 - $3541);
    $3546 = Math_fround($1580 * $1686);
    $3547 = Math_fround($1582 * $1686);
    $3548 = Math_fround($1580 * $1708);
    $3549 = Math_fround($1582 * $1708);
    $3550 = Math_fround($3542 - $3546);
    $3551 = Math_fround($3543 - $3547);
    $3552 = Math_fround($3544 - $3548);
    $3553 = Math_fround($3545 - $3549);
    $3554 = Math_fround($3552 * Math_fround(-1.0));
    $3555 = Math_fround($3553 * Math_fround(-1.0));
    $3556 = Math_fround($3550 * Math_fround(-1.0));
    $3557 = Math_fround($3554 * $3554);
    $3558 = Math_fround($3555 * $3555);
    $3559 = Math_fround($3556 * $3556);
    $3560 = Math_fround($3551 * $3551);
    $3561 = Math_fround($3557 + $3558);
    $3562 = Math_fround($3560 + $3559);
    $3563 = Math_fround($3561 + $3562);
    $3564 = (Math_fround(Math_sqrt((Math_fround($3563)))));
    $3565 = Math_fround(Math_fround(1.0) / $3564);
    $3566 = Math_fround($3554 * $3565);
    $3567 = Math_fround($3555 * $3565);
    $3568 = Math_fround($3556 * $3565);
    $3569 = Math_fround($3551 * $3565);
    $3654 = $3569;$3657 = $3567;$3659 = $3568;$3661 = $3566;$3665 = $3523;$3670 = $3524;$3672 = $3522;$4047 = $3525;
    break;
   }
   $3079 = $82 < $61;
   if ($3079) {
    $3080 = (($refStartX) + 16|0);
    $3081 = Math_fround(HEAPF32[$3080>>2]);
    $3082 = Math_fround($3081 * Math_fround(-1.0));
    $3083 = (($refStartX) + 20|0);
    $3084 = Math_fround(HEAPF32[$3083>>2]);
    $3085 = Math_fround($3084 * Math_fround(-1.0));
    $3086 = (($refStartX) + 24|0);
    $3087 = Math_fround(HEAPF32[$3086>>2]);
    $3088 = Math_fround($3087 * Math_fround(-1.0));
    $3089 = Math_fround(HEAPF32[$262>>2]);
    $3090 = Math_fround(HEAPF32[$refStartX>>2]);
    $3091 = Math_fround($1691 - $3090);
    $3092 = (($refStartX) + 4|0);
    $3093 = Math_fround(HEAPF32[$3092>>2]);
    $3094 = Math_fround($1694 - $3093);
    $3095 = (($refStartX) + 8|0);
    $3096 = Math_fround(HEAPF32[$3095>>2]);
    $3097 = Math_fround($1697 - $3096);
    $3098 = (($refStartX) + 12|0);
    $3099 = Math_fround(HEAPF32[$3098>>2]);
    $3100 = Math_fround($1700 - $3099);
    $3101 = Math_fround($3091 + $3091);
    $3102 = Math_fround($3094 + $3094);
    $3103 = Math_fround($3097 + $3097);
    $3104 = Math_fround($3082 * $3102);
    $3105 = Math_fround($3085 * $3103);
    $3106 = Math_fround($3088 * $3101);
    $3107 = Math_fround($3089 * Math_fround(0.0));
    $3108 = Math_fround($3085 * $3101);
    $3109 = Math_fround($3088 * $3102);
    $3110 = Math_fround($3082 * $3103);
    $3111 = Math_fround($3104 - $3108);
    $3112 = Math_fround($3105 - $3109);
    $3113 = Math_fround($3106 - $3110);
    $3114 = Math_fround($3107 - $3107);
    $3115 = Math_fround($3089 * $3112);
    $3116 = Math_fround($3089 * $3113);
    $3117 = Math_fround($3089 * $3111);
    $3118 = Math_fround($3089 * $3114);
    $3119 = Math_fround($3091 + $3115);
    $3120 = Math_fround($3094 + $3116);
    $3121 = Math_fround($3097 + $3117);
    $3122 = Math_fround($3118 + $3100);
    $3123 = Math_fround($3082 * $3113);
    $3124 = Math_fround($3085 * $3111);
    $3125 = Math_fround($3088 * $3112);
    $3126 = Math_fround($3085 * $3112);
    $3127 = Math_fround($3088 * $3113);
    $3128 = Math_fround($3082 * $3111);
    $3129 = Math_fround($3123 - $3126);
    $3130 = Math_fround($3124 - $3127);
    $3131 = Math_fround($3125 - $3128);
    $3132 = Math_fround($3118 - $3118);
    $3133 = Math_fround($3119 + $3130);
    $3134 = Math_fround($3120 + $3131);
    $3135 = Math_fround($3121 + $3129);
    $3136 = Math_fround($3132 + $3122);
    $3137 = Math_fround($1684 * $3085);
    $3138 = Math_fround($1708 * $3089);
    $3139 = Math_fround($1686 * $3088);
    $3140 = Math_fround($1688 * $3082);
    $3141 = Math_fround($1688 * $3089);
    $3142 = Math_fround($1684 * $3082);
    $3143 = Math_fround($1688 * $3085);
    $3144 = Math_fround($1684 * $3088);
    $3145 = Math_fround($3137 - $3141);
    $3146 = Math_fround($3138 - $3142);
    $3147 = Math_fround($3139 - $3143);
    $3148 = Math_fround($3140 - $3144);
    $3149 = Math_fround($1708 * $3088);
    $3150 = Math_fround($1688 * $3088);
    $3151 = Math_fround($1684 * $3089);
    $3152 = Math_fround($1686 * $3089);
    $3153 = Math_fround($3145 - $3149);
    $3154 = Math_fround($3146 - $3150);
    $3155 = Math_fround($3147 - $3151);
    $3156 = Math_fround($3148 - $3152);
    $3157 = Math_fround($1686 * $3082);
    $3158 = Math_fround($1686 * $3085);
    $3159 = Math_fround($1708 * $3082);
    $3160 = Math_fround($1708 * $3085);
    $3161 = Math_fround($3153 - $3157);
    $3162 = Math_fround($3154 - $3158);
    $3163 = Math_fround($3155 - $3159);
    $3164 = Math_fround($3156 - $3160);
    $3165 = Math_fround($3163 * Math_fround(-1.0));
    $3166 = Math_fround($3164 * Math_fround(-1.0));
    $3167 = Math_fround($3161 * Math_fround(-1.0));
    $3168 = Math_fround($3165 * $3165);
    $3169 = Math_fround($3166 * $3166);
    $3170 = Math_fround($3167 * $3167);
    $3171 = Math_fround($3162 * $3162);
    $3172 = Math_fround($3168 + $3169);
    $3173 = Math_fround($3171 + $3170);
    $3174 = Math_fround($3172 + $3173);
    $3175 = (Math_fround(Math_sqrt((Math_fround($3174)))));
    $3176 = Math_fround(Math_fround(1.0) / $3175);
    $3177 = Math_fround($3165 * $3176);
    $3178 = Math_fround($3166 * $3176);
    $3179 = Math_fround($3167 * $3176);
    $3180 = Math_fround($3162 * $3176);
    HEAPF32[$28>>2] = $3133;
    $3181 = (($28) + 4|0);
    HEAPF32[$3181>>2] = $3134;
    $3182 = (($28) + 8|0);
    HEAPF32[$3182>>2] = $3135;
    $3183 = (($28) + 12|0);
    HEAPF32[$3183>>2] = $3136;
    $3184 = (($28) + 16|0);
    HEAPF32[$3184>>2] = $3177;
    $3185 = (($28) + 20|0);
    HEAPF32[$3185>>2] = $3178;
    $3186 = (($28) + 24|0);
    HEAPF32[$3186>>2] = $3179;
    $3187 = (($28) + 28|0);
    HEAPF32[$3187>>2] = $3180;
    $3188 = (($28) + 32|0);
    HEAPF32[$3188>>2] = Math_fround(1.0);
    $3189 = (($28) + 36|0);
    HEAPF32[$3189>>2] = Math_fround(1.0);
    $3190 = (($28) + 40|0);
    HEAPF32[$3190>>2] = Math_fround(1.0);
    $3191 = (($28) + 44|0);
    HEAPF32[$3191>>2] = Math_fround(1.0);
    __ZN4mathL8xformMulERKNS_5xformES2_18984($27,$refStopX,$28);
    $3192 = Math_fround(HEAPF32[$27>>2]);
    $3193 = Math_fround($3192 - $1588);
    $3194 = (($27) + 4|0);
    $3195 = Math_fround(HEAPF32[$3194>>2]);
    $3196 = Math_fround($3195 - $1591);
    $3197 = (($27) + 8|0);
    $3198 = Math_fround(HEAPF32[$3197>>2]);
    $3199 = Math_fround($3198 - $1594);
    $3200 = (($27) + 12|0);
    $3201 = Math_fround(HEAPF32[$3200>>2]);
    $3202 = Math_fround($3201 - $1597);
    $3203 = Math_fround($3193 + $3193);
    $3204 = Math_fround($3196 + $3196);
    $3205 = Math_fround($3199 + $3199);
    $3206 = Math_fround($1580 * $3204);
    $3207 = Math_fround($1582 * $3205);
    $3208 = Math_fround($1584 * $3203);
    $3209 = Math_fround($1582 * $3203);
    $3210 = Math_fround($1584 * $3204);
    $3211 = Math_fround($1580 * $3205);
    $3212 = Math_fround($3206 - $3209);
    $3213 = Math_fround($3207 - $3210);
    $3214 = Math_fround($3208 - $3211);
    $3215 = Math_fround($1605 * $3213);
    $3216 = Math_fround($1605 * $3214);
    $3217 = Math_fround($1605 * $3212);
    $3218 = Math_fround($3193 + $3215);
    $3219 = Math_fround($3196 + $3216);
    $3220 = Math_fround($3199 + $3217);
    $3221 = Math_fround($1616 + $3202);
    $3222 = Math_fround($1580 * $3214);
    $3223 = Math_fround($1582 * $3212);
    $3224 = Math_fround($1584 * $3213);
    $3225 = Math_fround($1582 * $3213);
    $3226 = Math_fround($1584 * $3214);
    $3227 = Math_fround($1580 * $3212);
    $3228 = Math_fround($3222 - $3225);
    $3229 = Math_fround($3223 - $3226);
    $3230 = Math_fround($3224 - $3227);
    $3231 = Math_fround($3218 + $3229);
    $3232 = Math_fround($3219 + $3230);
    $3233 = Math_fround($3220 + $3228);
    $3234 = Math_fround($1630 + $3221);
    $3235 = (($27) + 16|0);
    $3236 = Math_fround(HEAPF32[$3235>>2]);
    $3237 = Math_fround($1582 * $3236);
    $3238 = (($27) + 28|0);
    $3239 = Math_fround(HEAPF32[$3238>>2]);
    $3240 = Math_fround($1605 * $3239);
    $3241 = (($27) + 20|0);
    $3242 = Math_fround(HEAPF32[$3241>>2]);
    $3243 = Math_fround($1584 * $3242);
    $3244 = (($27) + 24|0);
    $3245 = Math_fround(HEAPF32[$3244>>2]);
    $3246 = Math_fround($1580 * $3245);
    $3247 = Math_fround($1605 * $3245);
    $3248 = Math_fround($1580 * $3236);
    $3249 = Math_fround($1582 * $3245);
    $3250 = Math_fround($1584 * $3236);
    $3251 = Math_fround($3237 - $3247);
    $3252 = Math_fround($3240 - $3248);
    $3253 = Math_fround($3243 - $3249);
    $3254 = Math_fround($3246 - $3250);
    $3255 = Math_fround($1584 * $3239);
    $3256 = Math_fround($1584 * $3245);
    $3257 = Math_fround($1605 * $3236);
    $3258 = Math_fround($1605 * $3242);
    $3259 = Math_fround($3251 - $3255);
    $3260 = Math_fround($3252 - $3256);
    $3261 = Math_fround($3253 - $3257);
    $3262 = Math_fround($3254 - $3258);
    $3263 = Math_fround($1580 * $3242);
    $3264 = Math_fround($1582 * $3242);
    $3265 = Math_fround($1580 * $3239);
    $3266 = Math_fround($1582 * $3239);
    $3267 = Math_fround($3259 - $3263);
    $3268 = Math_fround($3260 - $3264);
    $3269 = Math_fround($3261 - $3265);
    $3270 = Math_fround($3262 - $3266);
    $3271 = Math_fround($3269 * Math_fround(-1.0));
    $3272 = Math_fround($3270 * Math_fround(-1.0));
    $3273 = Math_fround($3267 * Math_fround(-1.0));
    $3274 = Math_fround($3271 * $3271);
    $3275 = Math_fround($3272 * $3272);
    $3276 = Math_fround($3273 * $3273);
    $3277 = Math_fround($3268 * $3268);
    $3278 = Math_fround($3274 + $3275);
    $3279 = Math_fround($3277 + $3276);
    $3280 = Math_fround($3278 + $3279);
    $3281 = (Math_fround(Math_sqrt((Math_fround($3280)))));
    $3282 = Math_fround(Math_fround(1.0) / $3281);
    $3283 = Math_fround($3282 * $3271);
    $3284 = Math_fround($3282 * $3272);
    $3285 = Math_fround($3282 * $3273);
    $3286 = Math_fround($3282 * $3268);
    $3654 = $3286;$3657 = $3284;$3659 = $3285;$3661 = $3283;$3665 = $3232;$3670 = $3233;$3672 = $3231;$4047 = $3234;
    break;
   }
   $3287 = $82 > $61;
   if ($3287) {
    $3288 = Math_fround(HEAPF32[$873>>2]);
    $3289 = Math_fround($3288 * Math_fround(-1.0));
    $3290 = Math_fround(HEAPF32[$875>>2]);
    $3291 = Math_fround($3290 * Math_fround(-1.0));
    $3292 = Math_fround(HEAPF32[$877>>2]);
    $3293 = Math_fround($3292 * Math_fround(-1.0));
    $3294 = Math_fround(HEAPF32[$267>>2]);
    $3295 = Math_fround(HEAPF32[$refStopX>>2]);
    $3296 = Math_fround($1691 - $3295);
    $3297 = Math_fround(HEAPF32[$864>>2]);
    $3298 = Math_fround($1694 - $3297);
    $3299 = Math_fround(HEAPF32[$866>>2]);
    $3300 = Math_fround($1697 - $3299);
    $3301 = Math_fround(HEAPF32[$868>>2]);
    $3302 = Math_fround($1700 - $3301);
    $3303 = Math_fround($3296 + $3296);
    $3304 = Math_fround($3298 + $3298);
    $3305 = Math_fround($3300 + $3300);
    $3306 = Math_fround($3289 * $3304);
    $3307 = Math_fround($3291 * $3305);
    $3308 = Math_fround($3293 * $3303);
    $3309 = Math_fround($3294 * Math_fround(0.0));
    $3310 = Math_fround($3291 * $3303);
    $3311 = Math_fround($3293 * $3304);
    $3312 = Math_fround($3289 * $3305);
    $3313 = Math_fround($3306 - $3310);
    $3314 = Math_fround($3307 - $3311);
    $3315 = Math_fround($3308 - $3312);
    $3316 = Math_fround($3309 - $3309);
    $3317 = Math_fround($3294 * $3314);
    $3318 = Math_fround($3294 * $3315);
    $3319 = Math_fround($3294 * $3313);
    $3320 = Math_fround($3294 * $3316);
    $3321 = Math_fround($3296 + $3317);
    $3322 = Math_fround($3298 + $3318);
    $3323 = Math_fround($3300 + $3319);
    $3324 = Math_fround($3320 + $3302);
    $3325 = Math_fround($3289 * $3315);
    $3326 = Math_fround($3291 * $3313);
    $3327 = Math_fround($3293 * $3314);
    $3328 = Math_fround($3291 * $3314);
    $3329 = Math_fround($3293 * $3315);
    $3330 = Math_fround($3289 * $3313);
    $3331 = Math_fround($3325 - $3328);
    $3332 = Math_fround($3326 - $3329);
    $3333 = Math_fround($3327 - $3330);
    $3334 = Math_fround($3320 - $3320);
    $3335 = Math_fround($3321 + $3332);
    $3336 = Math_fround($3322 + $3333);
    $3337 = Math_fround($3323 + $3331);
    $3338 = Math_fround($3334 + $3324);
    $3339 = Math_fround($1684 * $3291);
    $3340 = Math_fround($1708 * $3294);
    $3341 = Math_fround($1686 * $3293);
    $3342 = Math_fround($1688 * $3289);
    $3343 = Math_fround($1688 * $3294);
    $3344 = Math_fround($1684 * $3289);
    $3345 = Math_fround($1688 * $3291);
    $3346 = Math_fround($1684 * $3293);
    $3347 = Math_fround($3339 - $3343);
    $3348 = Math_fround($3340 - $3344);
    $3349 = Math_fround($3341 - $3345);
    $3350 = Math_fround($3342 - $3346);
    $3351 = Math_fround($1708 * $3293);
    $3352 = Math_fround($1688 * $3293);
    $3353 = Math_fround($1684 * $3294);
    $3354 = Math_fround($1686 * $3294);
    $3355 = Math_fround($3347 - $3351);
    $3356 = Math_fround($3348 - $3352);
    $3357 = Math_fround($3349 - $3353);
    $3358 = Math_fround($3350 - $3354);
    $3359 = Math_fround($1686 * $3289);
    $3360 = Math_fround($1686 * $3291);
    $3361 = Math_fround($1708 * $3289);
    $3362 = Math_fround($1708 * $3291);
    $3363 = Math_fround($3355 - $3359);
    $3364 = Math_fround($3356 - $3360);
    $3365 = Math_fround($3357 - $3361);
    $3366 = Math_fround($3358 - $3362);
    $3367 = Math_fround($3365 * Math_fround(-1.0));
    $3368 = Math_fround($3366 * Math_fround(-1.0));
    $3369 = Math_fround($3363 * Math_fround(-1.0));
    $3370 = Math_fround($3367 * $3367);
    $3371 = Math_fround($3368 * $3368);
    $3372 = Math_fround($3369 * $3369);
    $3373 = Math_fround($3364 * $3364);
    $3374 = Math_fround($3370 + $3371);
    $3375 = Math_fround($3373 + $3372);
    $3376 = Math_fround($3374 + $3375);
    $3377 = (Math_fround(Math_sqrt((Math_fround($3376)))));
    $3378 = Math_fround(Math_fround(1.0) / $3377);
    $3379 = Math_fround($3367 * $3378);
    $3380 = Math_fround($3368 * $3378);
    $3381 = Math_fround($3369 * $3378);
    $3382 = Math_fround($3364 * $3378);
    HEAPF32[$30>>2] = $3335;
    $3383 = (($30) + 4|0);
    HEAPF32[$3383>>2] = $3336;
    $3384 = (($30) + 8|0);
    HEAPF32[$3384>>2] = $3337;
    $3385 = (($30) + 12|0);
    HEAPF32[$3385>>2] = $3338;
    $3386 = (($30) + 16|0);
    HEAPF32[$3386>>2] = $3379;
    $3387 = (($30) + 20|0);
    HEAPF32[$3387>>2] = $3380;
    $3388 = (($30) + 24|0);
    HEAPF32[$3388>>2] = $3381;
    $3389 = (($30) + 28|0);
    HEAPF32[$3389>>2] = $3382;
    $3390 = (($30) + 32|0);
    HEAPF32[$3390>>2] = Math_fround(1.0);
    $3391 = (($30) + 36|0);
    HEAPF32[$3391>>2] = Math_fround(1.0);
    $3392 = (($30) + 40|0);
    HEAPF32[$3392>>2] = Math_fround(1.0);
    $3393 = (($30) + 44|0);
    HEAPF32[$3393>>2] = Math_fround(1.0);
    __ZN4mathL8xformMulERKNS_5xformES2_18984($29,$refStartX,$30);
    $3394 = Math_fround(HEAPF32[$29>>2]);
    $3395 = Math_fround($3394 - $1588);
    $3396 = (($29) + 4|0);
    $3397 = Math_fround(HEAPF32[$3396>>2]);
    $3398 = Math_fround($3397 - $1591);
    $3399 = (($29) + 8|0);
    $3400 = Math_fround(HEAPF32[$3399>>2]);
    $3401 = Math_fround($3400 - $1594);
    $3402 = (($29) + 12|0);
    $3403 = Math_fround(HEAPF32[$3402>>2]);
    $3404 = Math_fround($3403 - $1597);
    $3405 = Math_fround($3395 + $3395);
    $3406 = Math_fround($3398 + $3398);
    $3407 = Math_fround($3401 + $3401);
    $3408 = Math_fround($1580 * $3406);
    $3409 = Math_fround($1582 * $3407);
    $3410 = Math_fround($1584 * $3405);
    $3411 = Math_fround($1582 * $3405);
    $3412 = Math_fround($1584 * $3406);
    $3413 = Math_fround($1580 * $3407);
    $3414 = Math_fround($3408 - $3411);
    $3415 = Math_fround($3409 - $3412);
    $3416 = Math_fround($3410 - $3413);
    $3417 = Math_fround($1605 * $3415);
    $3418 = Math_fround($1605 * $3416);
    $3419 = Math_fround($1605 * $3414);
    $3420 = Math_fround($3395 + $3417);
    $3421 = Math_fround($3398 + $3418);
    $3422 = Math_fround($3401 + $3419);
    $3423 = Math_fround($1616 + $3404);
    $3424 = Math_fround($1580 * $3416);
    $3425 = Math_fround($1582 * $3414);
    $3426 = Math_fround($1584 * $3415);
    $3427 = Math_fround($1582 * $3415);
    $3428 = Math_fround($1584 * $3416);
    $3429 = Math_fround($1580 * $3414);
    $3430 = Math_fround($3424 - $3427);
    $3431 = Math_fround($3425 - $3428);
    $3432 = Math_fround($3426 - $3429);
    $3433 = Math_fround($3420 + $3431);
    $3434 = Math_fround($3421 + $3432);
    $3435 = Math_fround($3422 + $3430);
    $3436 = Math_fround($1630 + $3423);
    $3437 = (($29) + 16|0);
    $3438 = Math_fround(HEAPF32[$3437>>2]);
    $3439 = Math_fround($1582 * $3438);
    $3440 = (($29) + 28|0);
    $3441 = Math_fround(HEAPF32[$3440>>2]);
    $3442 = Math_fround($1605 * $3441);
    $3443 = (($29) + 20|0);
    $3444 = Math_fround(HEAPF32[$3443>>2]);
    $3445 = Math_fround($1584 * $3444);
    $3446 = (($29) + 24|0);
    $3447 = Math_fround(HEAPF32[$3446>>2]);
    $3448 = Math_fround($1580 * $3447);
    $3449 = Math_fround($1605 * $3447);
    $3450 = Math_fround($1580 * $3438);
    $3451 = Math_fround($1582 * $3447);
    $3452 = Math_fround($1584 * $3438);
    $3453 = Math_fround($3439 - $3449);
    $3454 = Math_fround($3442 - $3450);
    $3455 = Math_fround($3445 - $3451);
    $3456 = Math_fround($3448 - $3452);
    $3457 = Math_fround($1584 * $3441);
    $3458 = Math_fround($1584 * $3447);
    $3459 = Math_fround($1605 * $3438);
    $3460 = Math_fround($1605 * $3444);
    $3461 = Math_fround($3453 - $3457);
    $3462 = Math_fround($3454 - $3458);
    $3463 = Math_fround($3455 - $3459);
    $3464 = Math_fround($3456 - $3460);
    $3465 = Math_fround($1580 * $3444);
    $3466 = Math_fround($1582 * $3444);
    $3467 = Math_fround($1580 * $3441);
    $3468 = Math_fround($1582 * $3441);
    $3469 = Math_fround($3461 - $3465);
    $3470 = Math_fround($3462 - $3466);
    $3471 = Math_fround($3463 - $3467);
    $3472 = Math_fround($3464 - $3468);
    $3473 = Math_fround($3471 * Math_fround(-1.0));
    $3474 = Math_fround($3472 * Math_fround(-1.0));
    $3475 = Math_fround($3469 * Math_fround(-1.0));
    $3476 = Math_fround($3473 * $3473);
    $3477 = Math_fround($3474 * $3474);
    $3478 = Math_fround($3475 * $3475);
    $3479 = Math_fround($3470 * $3470);
    $3480 = Math_fround($3476 + $3477);
    $3481 = Math_fround($3479 + $3478);
    $3482 = Math_fround($3480 + $3481);
    $3483 = (Math_fround(Math_sqrt((Math_fround($3482)))));
    $3484 = Math_fround(Math_fround(1.0) / $3483);
    $3485 = Math_fround($3484 * $3473);
    $3486 = Math_fround($3484 * $3474);
    $3487 = Math_fround($3484 * $3475);
    $3488 = Math_fround($3484 * $3470);
    $3654 = $3488;$3657 = $3486;$3659 = $3487;$3661 = $3485;$3665 = $3434;$3670 = $3435;$3672 = $3433;$4047 = $3436;
   } else {
    $3654 = Math_fround(1.0);$3657 = Math_fround(0.0);$3659 = Math_fround(0.0);$3661 = Math_fround(0.0);$3665 = Math_fround(0.0);$3670 = Math_fround(0.0);$3672 = Math_fround(0.0);$4047 = Math_fround(0.0);
   }
  }
 } while(0);
 $3653 = $3654 == Math_fround(0.0);
 $3655 = $3653 ? Math_fround(9.99999997475242707878E-7) : $3654;
 $3656 = Math_fround($3657 / $3655);
 if ($4102) {
  $3658 = Math_fround($3659 / $3655);
  $3660 = Math_fround($3661 / $3655);
  $3677 = $3660;$3679 = $3656;$3681 = $3658;$3791 = $3672;$4043 = $3665;$4045 = $3670;
 } else {
  $3662 = (($constant) + 1636|0);
  $3663 = HEAP8[$3662>>0]|0;
  $3664 = ($3663<<24>>24)==(0);
  $$ = $3664 ? $3665 : Math_fround(0.0);
  $3666 = (($constant) + 1637|0);
  $3667 = HEAP8[$3666>>0]|0;
  $3668 = ($3667<<24>>24)==(0);
  $3669 = $3668 ? $3670 : Math_fround(0.0);
  $3671 = $3668 ? $3672 : Math_fround(0.0);
  $3673 = (($constant) + 1635|0);
  $3674 = HEAP8[$3673>>0]|0;
  $3675 = ($3674<<24>>24)==(0);
  $$694 = $3675 ? $3656 : Math_fround(0.0);
  $3677 = Math_fround(0.0);$3679 = $$694;$3681 = Math_fround(0.0);$3791 = $3671;$4043 = $$;$4045 = $3669;
 }
 $3676 = Math_fround($3677 * $3677);
 $3678 = Math_fround($3679 * $3679);
 $3680 = Math_fround($3681 * $3681);
 $3682 = Math_fround($3678 + $3676);
 $3683 = Math_fround($3680 + Math_fround(1.0));
 $3684 = Math_fround($3683 + $3682);
 $3685 = (Math_fround(Math_sqrt((Math_fround($3684)))));
 $3686 = Math_fround(Math_fround(1.0) / $3685);
 $3687 = Math_fround($3677 * $3686);
 $3688 = Math_fround($3679 * $3686);
 $3689 = Math_fround($3681 * $3686);
 $3690 = (($motionOutput) + 372|0);
 $3691 = Math_fround(HEAPF32[$targetRefX>>2]);
 $3692 = Math_fround($3691 - $1691);
 $3693 = Math_fround(HEAPF32[$870>>2]);
 $3694 = Math_fround($3693 - $1694);
 $3695 = Math_fround(HEAPF32[$871>>2]);
 $3696 = Math_fround($3695 - $1697);
 $3697 = Math_fround(HEAPF32[$872>>2]);
 $3698 = Math_fround($3697 - $1700);
 $3699 = Math_fround($3692 + $3692);
 $3700 = Math_fround($3694 + $3694);
 $3701 = Math_fround($3696 + $3696);
 $3702 = Math_fround($1683 * $3700);
 $3703 = Math_fround($1685 * $3701);
 $3704 = Math_fround($1687 * $3699);
 $3705 = Math_fround($1685 * $3699);
 $3706 = Math_fround($1687 * $3700);
 $3707 = Math_fround($1683 * $3701);
 $3708 = Math_fround($3702 - $3705);
 $3709 = Math_fround($3703 - $3706);
 $3710 = Math_fround($3704 - $3707);
 $3711 = Math_fround($1708 * $3709);
 $3712 = Math_fround($1708 * $3710);
 $3713 = Math_fround($1708 * $3708);
 $3714 = Math_fround($3692 + $3711);
 $3715 = Math_fround($3694 + $3712);
 $3716 = Math_fround($3696 + $3713);
 $3717 = Math_fround($1719 + $3698);
 $3718 = Math_fround($1683 * $3710);
 $3719 = Math_fround($1685 * $3708);
 $3720 = Math_fround($1687 * $3709);
 $3721 = Math_fround($1685 * $3709);
 $3722 = Math_fround($1687 * $3710);
 $3723 = Math_fround($1683 * $3708);
 $3724 = Math_fround($3718 - $3721);
 $3725 = Math_fround($3719 - $3722);
 $3726 = Math_fround($3720 - $3723);
 $3727 = Math_fround($3714 + $3725);
 $3728 = Math_fround($3715 + $3726);
 $3729 = Math_fround($3716 + $3724);
 $3730 = Math_fround($1733 + $3717);
 $3731 = Math_fround(HEAPF32[$880>>2]);
 $3732 = Math_fround($1685 * $3731);
 $3733 = Math_fround(HEAPF32[$883>>2]);
 $3734 = Math_fround($1708 * $3733);
 $3735 = Math_fround(HEAPF32[$881>>2]);
 $3736 = Math_fround($1687 * $3735);
 $3737 = Math_fround(HEAPF32[$882>>2]);
 $3738 = Math_fround($1683 * $3737);
 $3739 = Math_fround($1708 * $3737);
 $3740 = Math_fround($1683 * $3731);
 $3741 = Math_fround($1685 * $3737);
 $3742 = Math_fround($1687 * $3731);
 $3743 = Math_fround($3732 - $3739);
 $3744 = Math_fround($3734 - $3740);
 $3745 = Math_fround($3736 - $3741);
 $3746 = Math_fround($3738 - $3742);
 $3747 = Math_fround($1687 * $3733);
 $3748 = Math_fround($1687 * $3737);
 $3749 = Math_fround($1708 * $3731);
 $3750 = Math_fround($1708 * $3735);
 $3751 = Math_fround($3743 - $3747);
 $3752 = Math_fround($3744 - $3748);
 $3753 = Math_fround($3745 - $3749);
 $3754 = Math_fround($3746 - $3750);
 $3755 = Math_fround($1683 * $3735);
 $3756 = Math_fround($1685 * $3735);
 $3757 = Math_fround($1683 * $3733);
 $3758 = Math_fround($1685 * $3733);
 $3759 = Math_fround($3751 - $3755);
 $3760 = Math_fround($3752 - $3756);
 $3761 = Math_fround($3753 - $3757);
 $3762 = Math_fround($3754 - $3758);
 $3763 = Math_fround($3761 * Math_fround(-1.0));
 $3764 = Math_fround($3762 * Math_fround(-1.0));
 $3765 = Math_fround($3759 * Math_fround(-1.0));
 $3766 = Math_fround($3763 * $3763);
 $3767 = Math_fround($3764 * $3764);
 $3768 = Math_fround($3765 * $3765);
 $3769 = Math_fround($3760 * $3760);
 $3770 = Math_fround($3766 + $3767);
 $3771 = Math_fround($3769 + $3768);
 $3772 = Math_fround($3770 + $3771);
 $3773 = (Math_fround(Math_sqrt((Math_fround($3772)))));
 $3774 = Math_fround(Math_fround(1.0) / $3773);
 $3775 = Math_fround($3774 * $3763);
 $3776 = Math_fround($3774 * $3764);
 $3777 = Math_fround($3774 * $3765);
 $3778 = Math_fround($3774 * $3760);
 HEAPF32[$3690>>2] = $3727;
 $3779 = (($motionOutput) + 376|0);
 HEAPF32[$3779>>2] = $3728;
 $3780 = (($motionOutput) + 380|0);
 HEAPF32[$3780>>2] = $3729;
 $3781 = (($motionOutput) + 384|0);
 HEAPF32[$3781>>2] = $3730;
 $3782 = (($motionOutput) + 388|0);
 HEAPF32[$3782>>2] = $3775;
 $3783 = (($motionOutput) + 392|0);
 HEAPF32[$3783>>2] = $3776;
 $3784 = (($motionOutput) + 396|0);
 HEAPF32[$3784>>2] = $3777;
 $3785 = (($motionOutput) + 400|0);
 HEAPF32[$3785>>2] = $3778;
 $3786 = (($motionOutput) + 404|0);
 HEAPF32[$3786>>2] = Math_fround(1.0);
 $3787 = (($motionOutput) + 408|0);
 HEAPF32[$3787>>2] = Math_fround(1.0);
 $3788 = (($motionOutput) + 412|0);
 HEAPF32[$3788>>2] = Math_fround(1.0);
 $3789 = (($motionOutput) + 416|0);
 HEAPF32[$3789>>2] = Math_fround(1.0);
 if ($$off0) {
  __ZN7mecanim5human15HumanPoseMirrorERNS0_9HumanPoseERKS1_($humanPose,$humanPose);
  $3790 = Math_fround($3791 * Math_fround(-1.0));
  $3792 = Math_fround($3688 * Math_fround(-1.0));
  $3793 = Math_fround($3689 * Math_fround(-1.0));
  $3794 = Math_fround(HEAPF32[$158>>2]);
  $3795 = Math_fround(HEAPF32[$160>>2]);
  $3796 = Math_fround(HEAPF32[$162>>2]);
  $3797 = Math_fround(HEAPF32[$164>>2]);
  $3798 = Math_fround(HEAPF32[$169>>2]);
  $3799 = Math_fround(HEAPF32[$171>>2]);
  $3800 = Math_fround(HEAPF32[$173>>2]);
  $3801 = Math_fround(HEAPF32[$175>>2]);
  $3802 = Math_fround(HEAPF32[$181>>2]);
  $3803 = Math_fround(HEAPF32[$183>>2]);
  $3804 = Math_fround(HEAPF32[$185>>2]);
  $3805 = Math_fround(HEAPF32[$187>>2]);
  $3806 = Math_fround($3794 * Math_fround(-1.0));
  $3807 = Math_fround($3799 * Math_fround(-1.0));
  $3808 = Math_fround($3800 * Math_fround(-1.0));
  $3809 = Math_fround(HEAPF32[$193>>2]);
  $3810 = Math_fround(HEAPF32[$195>>2]);
  $3811 = Math_fround(HEAPF32[$197>>2]);
  $3812 = Math_fround(HEAPF32[$199>>2]);
  $3813 = Math_fround(HEAPF32[$204>>2]);
  $3814 = Math_fround(HEAPF32[$206>>2]);
  $3815 = Math_fround(HEAPF32[$208>>2]);
  $3816 = Math_fround(HEAPF32[$210>>2]);
  $3817 = Math_fround(HEAPF32[$216>>2]);
  $3818 = Math_fround(HEAPF32[$218>>2]);
  $3819 = Math_fround(HEAPF32[$220>>2]);
  $3820 = Math_fround(HEAPF32[$222>>2]);
  $3821 = Math_fround($3809 * Math_fround(-1.0));
  $3822 = Math_fround($3814 * Math_fround(-1.0));
  $3823 = Math_fround($3815 * Math_fround(-1.0));
  HEAPF32[$158>>2] = $3821;
  HEAPF32[$160>>2] = $3810;
  HEAPF32[$162>>2] = $3811;
  HEAPF32[$164>>2] = $3812;
  HEAPF32[$169>>2] = $3813;
  HEAPF32[$171>>2] = $3822;
  HEAPF32[$173>>2] = $3823;
  HEAPF32[$175>>2] = $3816;
  HEAPF32[$181>>2] = $3817;
  HEAPF32[$183>>2] = $3818;
  HEAPF32[$185>>2] = $3819;
  HEAPF32[$187>>2] = $3820;
  HEAPF32[$193>>2] = $3806;
  HEAPF32[$195>>2] = $3795;
  HEAPF32[$197>>2] = $3796;
  HEAPF32[$199>>2] = $3797;
  HEAPF32[$204>>2] = $3798;
  HEAPF32[$206>>2] = $3807;
  HEAPF32[$208>>2] = $3808;
  HEAPF32[$210>>2] = $3801;
  HEAPF32[$216>>2] = $3802;
  HEAPF32[$218>>2] = $3803;
  HEAPF32[$220>>2] = $3804;
  HEAPF32[$222>>2] = $3805;
  if ($4103) {
   $3824 = (($motionOutput) + 424|0);
   $3825 = Math_fround(HEAPF32[$3824>>2]);
   $3826 = Math_fround($3825 * Math_fround(-1.0));
   HEAPF32[$3824>>2] = $3826;
   $3827 = (($motionOutput) + 440|0);
   $3828 = Math_fround(HEAPF32[$3827>>2]);
   $3829 = Math_fround($3828 * Math_fround(-1.0));
   HEAPF32[$3827>>2] = $3829;
  }
  $3830 = Math_fround($3822 * Math_fround(0.0));
  $3831 = Math_fround($3816 * Math_fround(0.0));
  $3832 = Math_fround($3813 * Math_fround(0.0));
  $3833 = Math_fround($3823 * Math_fround(0.0));
  $3834 = Math_fround($3830 - $3831);
  $3835 = Math_fround($3831 - $3832);
  $3836 = Math_fround($3823 - $3830);
  $3837 = Math_fround($3832 - $3833);
  $3838 = Math_fround($3834 - $3833);
  $3839 = Math_fround($3835 - $3833);
  $3840 = Math_fround($3836 - $3831);
  $3841 = Math_fround($3837 - $3816);
  $3842 = Math_fround($3838 - $3813);
  $3843 = Math_fround($3839 - $3822);
  $3844 = Math_fround($3840 - $3832);
  $3845 = Math_fround($3841 - $3830);
  $3846 = Math_fround($3844 * Math_fround(-1.0));
  $3847 = Math_fround($3845 * Math_fround(-1.0));
  $3848 = Math_fround($3842 * Math_fround(-1.0));
  $3849 = Math_fround($3846 * $3846);
  $3850 = Math_fround($3847 * $3847);
  $3851 = Math_fround($3848 * $3848);
  $3852 = Math_fround($3843 * $3843);
  $3853 = Math_fround($3849 + $3850);
  $3854 = Math_fround($3851 + $3852);
  $3855 = Math_fround($3854 + $3853);
  $3856 = (Math_fround(Math_sqrt((Math_fround($3855)))));
  $3857 = Math_fround(Math_fround(1.0) / $3856);
  $3858 = Math_fround($3857 * $3846);
  $3859 = Math_fround($3857 * $3847);
  $3860 = Math_fround($3857 * $3848);
  $3861 = Math_fround($3857 * $3843);
  HEAPF32[$169>>2] = $3858;
  HEAPF32[$171>>2] = $3859;
  HEAPF32[$173>>2] = $3860;
  HEAPF32[$175>>2] = $3861;
  $3862 = Math_fround($3807 * Math_fround(0.0));
  $3863 = Math_fround($3801 * Math_fround(0.0));
  $3864 = Math_fround($3798 * Math_fround(0.0));
  $3865 = Math_fround($3808 * Math_fround(0.0));
  $3866 = Math_fround($3862 - $3863);
  $3867 = Math_fround($3863 - $3864);
  $3868 = Math_fround($3808 - $3862);
  $3869 = Math_fround($3864 - $3865);
  $3870 = Math_fround($3866 - $3865);
  $3871 = Math_fround($3867 - $3865);
  $3872 = Math_fround($3868 - $3863);
  $3873 = Math_fround($3869 - $3801);
  $3874 = Math_fround($3870 - $3798);
  $3875 = Math_fround($3871 - $3807);
  $3876 = Math_fround($3872 - $3864);
  $3877 = Math_fround($3873 - $3862);
  $3878 = Math_fround($3876 * Math_fround(-1.0));
  $3879 = Math_fround($3877 * Math_fround(-1.0));
  $3880 = Math_fround($3874 * Math_fround(-1.0));
  $3881 = Math_fround($3878 * $3878);
  $3882 = Math_fround($3879 * $3879);
  $3883 = Math_fround($3880 * $3880);
  $3884 = Math_fround($3875 * $3875);
  $3885 = Math_fround($3881 + $3882);
  $3886 = Math_fround($3883 + $3884);
  $3887 = Math_fround($3886 + $3885);
  $3888 = (Math_fround(Math_sqrt((Math_fround($3887)))));
  $3889 = Math_fround(Math_fround(1.0) / $3888);
  $3890 = Math_fround($3889 * $3878);
  $3891 = Math_fround($3889 * $3879);
  $3892 = Math_fround($3889 * $3880);
  $3893 = Math_fround($3889 * $3875);
  HEAPF32[$204>>2] = $3890;
  HEAPF32[$206>>2] = $3891;
  HEAPF32[$208>>2] = $3892;
  HEAPF32[$210>>2] = $3893;
  $3894 = Math_fround(HEAPF32[$3690>>2]);
  $3895 = Math_fround(HEAPF32[$3783>>2]);
  $3896 = Math_fround(HEAPF32[$3784>>2]);
  $3897 = Math_fround($3894 * Math_fround(-1.0));
  $3898 = Math_fround($3895 * Math_fround(-1.0));
  $3899 = Math_fround($3896 * Math_fround(-1.0));
  HEAPF32[$3690>>2] = $3897;
  HEAPF32[$3783>>2] = $3898;
  HEAPF32[$3784>>2] = $3899;
  $3900 = HEAP32[$1068>>2]|0;
  $3901 = ($3900|0)>(0);
  if ($3901) {
   $3902 = Math_fround(HEAPF32[$clipIn$i>>2]);
   $3903 = Math_fround(HEAPF32[$848>>2]);
   $3904 = Math_fround(HEAPF32[$849>>2]);
   $3905 = Math_fround($3902 * Math_fround(-1.0));
   $3906 = Math_fround($3903 * Math_fround(-1.0));
   $3907 = Math_fround($3904 * Math_fround(-1.0));
   HEAPF32[$clipIn$i>>2] = $3905;
   HEAPF32[$848>>2] = $3906;
   HEAPF32[$849>>2] = $3907;
   $3908 = ($3900|0)>(1);
   if ($3908) {
    $3909 = Math_fround(HEAPF32[$targetGoalX>>2]);
    $3910 = (($targetGoalX) + 16|0);
    $3911 = Math_fround(HEAPF32[$3910>>2]);
    $3912 = (($targetGoalX) + 20|0);
    $3913 = Math_fround(HEAPF32[$3912>>2]);
    $3914 = (($targetGoalX) + 24|0);
    $3915 = Math_fround(HEAPF32[$3914>>2]);
    $3916 = Math_fround(HEAPF32[$892>>2]);
    $3917 = Math_fround($3909 * Math_fround(-1.0));
    $3918 = Math_fround($3913 * Math_fround(-1.0));
    $3919 = Math_fround($3915 * Math_fround(-1.0));
    HEAPF32[$targetGoalX>>2] = $3917;
    $3920 = ($3900|0)>(3);
    $3921 = $3920 ? Math_fround(0.0) : Math_fround(1.0);
    $3922 = $3920 ? Math_fround(1.0) : Math_fround(0.0);
    $3923 = Math_fround($3918 * Math_fround(0.0));
    $3924 = Math_fround($3916 * Math_fround(0.0));
    $3925 = Math_fround($3921 * $3919);
    $3926 = Math_fround($3922 * $3911);
    $3927 = Math_fround($3922 * $3916);
    $3928 = Math_fround($3911 * Math_fround(0.0));
    $3929 = Math_fround($3918 * $3922);
    $3930 = Math_fround($3919 * Math_fround(0.0));
    $3931 = Math_fround($3923 - $3927);
    $3932 = Math_fround($3924 - $3928);
    $3933 = Math_fround($3925 - $3929);
    $3934 = Math_fround($3926 - $3930);
    $3935 = Math_fround($3922 * $3919);
    $3936 = Math_fround($3916 * $3921);
    $3937 = Math_fround($3931 - $3930);
    $3938 = Math_fround($3932 - $3935);
    $3939 = Math_fround($3933 - $3924);
    $3940 = Math_fround($3934 - $3936);
    $3941 = Math_fround($3921 * $3911);
    $3942 = Math_fround($3918 * $3921);
    $3943 = Math_fround($3937 - $3941);
    $3944 = Math_fround($3938 - $3942);
    $3945 = Math_fround($3939 - $3928);
    $3946 = Math_fround($3940 - $3923);
    $3947 = Math_fround($3945 * Math_fround(-1.0));
    $3948 = Math_fround($3946 * Math_fround(-1.0));
    $3949 = Math_fround($3943 * Math_fround(-1.0));
    $3950 = Math_fround($3947 * $3947);
    $3951 = Math_fround($3948 * $3948);
    $3952 = Math_fround($3949 * $3949);
    $3953 = Math_fround($3944 * $3944);
    $3954 = Math_fround($3950 + $3951);
    $3955 = Math_fround($3952 + $3953);
    $3956 = Math_fround($3955 + $3954);
    $3957 = (Math_fround(Math_sqrt((Math_fround($3956)))));
    $3958 = Math_fround(Math_fround(1.0) / $3957);
    $3959 = Math_fround($3958 * $3947);
    $3960 = Math_fround($3958 * $3948);
    $3961 = Math_fround($3958 * $3949);
    $3962 = Math_fround($3958 * $3944);
    HEAPF32[$3910>>2] = $3959;
    HEAPF32[$3912>>2] = $3960;
    HEAPF32[$3914>>2] = $3961;
    HEAPF32[$892>>2] = $3962;
    $4114 = $3790;$4115 = $3792;$4116 = $3793;
    label = 98;
   } else {
    $4114 = $3790;$4115 = $3792;$4116 = $3793;
    label = 98;
   }
  } else {
   $4041 = $3790;$4059 = $3792;$4061 = $3793;
  }
 } else {
  $$pr692$pre = HEAP32[$1068>>2]|0;
  $3963 = ($$pr692$pre|0)>(0);
  if ($3963) {
   $4114 = $3791;$4115 = $3688;$4116 = $3689;
   label = 98;
  } else {
   $4041 = $3791;$4059 = $3688;$4061 = $3689;
  }
 }
 if ((label|0) == 98) {
  __ZN4mathL8xformMulERKNS_5xformES2_18984($31,$3690,$clipIn$i);
  $3964 = Math_fround(HEAPF32[$31>>2]);
  $3965 = (($31) + 4|0);
  $3966 = Math_fround(HEAPF32[$3965>>2]);
  $3967 = (($31) + 8|0);
  $3968 = Math_fround(HEAPF32[$3967>>2]);
  $3969 = (($31) + 12|0);
  $3970 = Math_fround(HEAPF32[$3969>>2]);
  HEAPF32[$3690>>2] = $3964;
  HEAPF32[$3779>>2] = $3966;
  HEAPF32[$3780>>2] = $3968;
  HEAPF32[$3781>>2] = $3970;
  $3971 = (($31) + 16|0);
  $3972 = Math_fround(HEAPF32[$3971>>2]);
  $3973 = (($31) + 20|0);
  $3974 = Math_fround(HEAPF32[$3973>>2]);
  $3975 = (($31) + 24|0);
  $3976 = Math_fround(HEAPF32[$3975>>2]);
  $3977 = (($31) + 28|0);
  $3978 = Math_fround(HEAPF32[$3977>>2]);
  HEAPF32[$3782>>2] = $3972;
  HEAPF32[$3783>>2] = $3974;
  HEAPF32[$3784>>2] = $3976;
  HEAPF32[$3785>>2] = $3978;
  $3979 = (($31) + 32|0);
  $3980 = Math_fround(HEAPF32[$3979>>2]);
  $3981 = (($31) + 36|0);
  $3982 = Math_fround(HEAPF32[$3981>>2]);
  $3983 = (($31) + 40|0);
  $3984 = Math_fround(HEAPF32[$3983>>2]);
  $3985 = (($31) + 44|0);
  $3986 = Math_fround(HEAPF32[$3985>>2]);
  HEAPF32[$3786>>2] = $3980;
  HEAPF32[$3787>>2] = $3982;
  HEAPF32[$3788>>2] = $3984;
  HEAPF32[$3789>>2] = $3986;
  $3987 = HEAP32[$1068>>2]|0;
  $3988 = ($3987|0)>(1);
  if ($3988) {
   __ZN4mathL8xformMulERKNS_5xformES2_18984($32,$3690,$targetGoalX);
   $3989 = Math_fround(HEAPF32[$32>>2]);
   $3990 = (($32) + 4|0);
   $3991 = Math_fround(HEAPF32[$3990>>2]);
   $3992 = (($32) + 8|0);
   $3993 = Math_fround(HEAPF32[$3992>>2]);
   $3994 = (($32) + 12|0);
   $3995 = Math_fround(HEAPF32[$3994>>2]);
   HEAPF32[$3690>>2] = $3989;
   HEAPF32[$3779>>2] = $3991;
   HEAPF32[$3780>>2] = $3993;
   HEAPF32[$3781>>2] = $3995;
   $3996 = (($32) + 16|0);
   $3997 = Math_fround(HEAPF32[$3996>>2]);
   $3998 = (($32) + 20|0);
   $3999 = Math_fround(HEAPF32[$3998>>2]);
   $4000 = (($32) + 24|0);
   $4001 = Math_fround(HEAPF32[$4000>>2]);
   $4002 = (($32) + 28|0);
   $4003 = Math_fround(HEAPF32[$4002>>2]);
   HEAPF32[$3782>>2] = $3997;
   HEAPF32[$3783>>2] = $3999;
   HEAPF32[$3784>>2] = $4001;
   HEAPF32[$3785>>2] = $4003;
   $4004 = (($32) + 32|0);
   $4005 = Math_fround(HEAPF32[$4004>>2]);
   $4006 = (($32) + 36|0);
   $4007 = Math_fround(HEAPF32[$4006>>2]);
   $4008 = (($32) + 40|0);
   $4009 = Math_fround(HEAPF32[$4008>>2]);
   $4010 = (($32) + 44|0);
   $4011 = Math_fround(HEAPF32[$4010>>2]);
   HEAPF32[$3786>>2] = $4005;
   HEAPF32[$3787>>2] = $4007;
   HEAPF32[$3788>>2] = $4009;
   HEAPF32[$3789>>2] = $4011;
   $4041 = $4114;$4059 = $4115;$4061 = $4116;
  } else {
   $4041 = $4114;$4059 = $4115;$4061 = $4116;
  }
 }
 $4012 = (($motionOutput) + 84|0);
 HEAPF32[$4012>>2] = $1691;
 $4013 = (($motionOutput) + 88|0);
 HEAPF32[$4013>>2] = $1694;
 $4014 = (($motionOutput) + 92|0);
 HEAPF32[$4014>>2] = $1697;
 $4015 = (($motionOutput) + 96|0);
 HEAPF32[$4015>>2] = $1700;
 $4016 = (($motionOutput) + 100|0);
 HEAPF32[$4016>>2] = $1684;
 $4017 = (($motionOutput) + 104|0);
 HEAPF32[$4017>>2] = $1686;
 $4018 = (($motionOutput) + 108|0);
 HEAPF32[$4018>>2] = $1688;
 $4019 = (($motionOutput) + 112|0);
 HEAPF32[$4019>>2] = $1708;
 $4020 = (($motionOutput) + 116|0);
 HEAPF32[$4020>>2] = $4021;
 $4022 = (($motionOutput) + 120|0);
 HEAPF32[$4022>>2] = $4023;
 $4024 = (($motionOutput) + 124|0);
 HEAPF32[$4024>>2] = $4025;
 $4026 = (($motionOutput) + 128|0);
 HEAPF32[$4026>>2] = $4027;
 $4028 = Math_fround(HEAPF32[$45>>2]);
 $4029 = $4028 != Math_fround(0.0);
 if (!($4029)) {
  $4039 = Math_fround(0.0);
  HEAPF32[$motionOutput>>2] = $4039;
  $4040 = Math_fround($4041 / $4039);
  $4042 = Math_fround($4043 / $4039);
  $4044 = Math_fround($4045 / $4039);
  $4046 = Math_fround($4047 / $4039);
  $4048 = $4039 > Math_fround(0.0);
  $4049 = $4048 ? $4040 : Math_fround(0.0);
  $4050 = $4048 ? $4042 : Math_fround(0.0);
  $4051 = $4048 ? $4044 : Math_fround(0.0);
  $4052 = $4048 ? $4046 : Math_fround(0.0);
  $4053 = (($motionOutput) + 4|0);
  HEAPF32[$4053>>2] = $4049;
  $4054 = (($motionOutput) + 8|0);
  HEAPF32[$4054>>2] = $4050;
  $4055 = (($motionOutput) + 12|0);
  HEAPF32[$4055>>2] = $4051;
  $4056 = (($motionOutput) + 16|0);
  HEAPF32[$4056>>2] = $4052;
  $4057 = Math_fround($3687 * $3687);
  $4058 = Math_fround($4059 * $4059);
  $4060 = Math_fround($4061 * $4061);
  $4062 = Math_fround($3686 * $3686);
  $4063 = Math_fround($4057 + $4058);
  $4064 = Math_fround($4062 + $4060);
  $4065 = Math_fround($4063 + $4064);
  $4066 = (Math_fround(Math_sqrt((Math_fround($4065)))));
  $4067 = Math_fround(Math_fround(1.0) / $4066);
  $4068 = Math_fround($3687 * $4067);
  $4069 = Math_fround($4059 * $4067);
  $4070 = Math_fround($4061 * $4067);
  $4071 = Math_fround($4068 * $4068);
  $4072 = Math_fround($4069 * $4069);
  $4073 = Math_fround($4070 * $4070);
  $4074 = Math_fround($4071 + $4072);
  $4075 = Math_fround($4073 + Math_fround(0.0));
  $4076 = Math_fround($4074 + $4075);
  $4077 = (Math_fround(Math_sqrt((Math_fround($4076)))));
  $4078 = (Math_fround(+(Math_asin((+$4077)))));
  $4079 = Math_fround($4078 * Math_fround(2.0));
  $4080 = Math_fround($4068 * $4079);
  $4081 = Math_fround($4080 / $4077);
  $4082 = Math_fround($4069 * $4079);
  $4083 = Math_fround($4082 / $4077);
  $4084 = Math_fround($4070 * $4079);
  $4085 = Math_fround($4084 / $4077);
  $4086 = $4077 != Math_fround(0.0);
  $4087 = $4086 ? $4081 : Math_fround(0.0);
  $4088 = $4086 ? $4083 : Math_fround(0.0);
  $4089 = $4086 ? $4085 : Math_fround(0.0);
  $4090 = Math_fround($4087 / $4039);
  $4091 = Math_fround($4088 / $4039);
  $4092 = Math_fround($4089 / $4039);
  $4093 = Math_fround(Math_fround(0.0) / $4039);
  $4094 = $4048 ? $4090 : Math_fround(0.0);
  $4095 = $4048 ? $4091 : Math_fround(0.0);
  $4096 = $4048 ? $4092 : Math_fround(0.0);
  $4097 = $4048 ? $4093 : Math_fround(0.0);
  $4098 = (($motionOutput) + 20|0);
  HEAPF32[$4098>>2] = $4094;
  $4099 = (($motionOutput) + 24|0);
  HEAPF32[$4099>>2] = $4095;
  $4100 = (($motionOutput) + 28|0);
  HEAPF32[$4100>>2] = $4096;
  $4101 = (($motionOutput) + 32|0);
  HEAPF32[$4101>>2] = $4097;
  STACKTOP = sp;return;
 }
 $4030 = Math_fround(HEAPF32[$input>>2]);
 $4031 = Math_fround(HEAPF32[$38>>2]);
 $4032 = Math_fround($4030 - $4031);
 $4033 = Math_fround(HEAPF32[$41>>2]);
 $4034 = Math_fround(HEAPF32[$40>>2]);
 $4035 = Math_fround($4033 - $4034);
 $4036 = Math_fround($4032 * $4035);
 $4037 = (Math_fround(Math_abs((Math_fround($4028)))));
 $4038 = Math_fround($4036 / $4037);
 $4039 = $4038;
 HEAPF32[$motionOutput>>2] = $4039;
 $4040 = Math_fround($4041 / $4039);
 $4042 = Math_fround($4043 / $4039);
 $4044 = Math_fround($4045 / $4039);
 $4046 = Math_fround($4047 / $4039);
 $4048 = $4039 > Math_fround(0.0);
 $4049 = $4048 ? $4040 : Math_fround(0.0);
 $4050 = $4048 ? $4042 : Math_fround(0.0);
 $4051 = $4048 ? $4044 : Math_fround(0.0);
 $4052 = $4048 ? $4046 : Math_fround(0.0);
 $4053 = (($motionOutput) + 4|0);
 HEAPF32[$4053>>2] = $4049;
 $4054 = (($motionOutput) + 8|0);
 HEAPF32[$4054>>2] = $4050;
 $4055 = (($motionOutput) + 12|0);
 HEAPF32[$4055>>2] = $4051;
 $4056 = (($motionOutput) + 16|0);
 HEAPF32[$4056>>2] = $4052;
 $4057 = Math_fround($3687 * $3687);
 $4058 = Math_fround($4059 * $4059);
 $4060 = Math_fround($4061 * $4061);
 $4062 = Math_fround($3686 * $3686);
 $4063 = Math_fround($4057 + $4058);
 $4064 = Math_fround($4062 + $4060);
 $4065 = Math_fround($4063 + $4064);
 $4066 = (Math_fround(Math_sqrt((Math_fround($4065)))));
 $4067 = Math_fround(Math_fround(1.0) / $4066);
 $4068 = Math_fround($3687 * $4067);
 $4069 = Math_fround($4059 * $4067);
 $4070 = Math_fround($4061 * $4067);
 $4071 = Math_fround($4068 * $4068);
 $4072 = Math_fround($4069 * $4069);
 $4073 = Math_fround($4070 * $4070);
 $4074 = Math_fround($4071 + $4072);
 $4075 = Math_fround($4073 + Math_fround(0.0));
 $4076 = Math_fround($4074 + $4075);
 $4077 = (Math_fround(Math_sqrt((Math_fround($4076)))));
 $4078 = (Math_fround(+(Math_asin((+$4077)))));
 $4079 = Math_fround($4078 * Math_fround(2.0));
 $4080 = Math_fround($4068 * $4079);
 $4081 = Math_fround($4080 / $4077);
 $4082 = Math_fround($4069 * $4079);
 $4083 = Math_fround($4082 / $4077);
 $4084 = Math_fround($4070 * $4079);
 $4085 = Math_fround($4084 / $4077);
 $4086 = $4077 != Math_fround(0.0);
 $4087 = $4086 ? $4081 : Math_fround(0.0);
 $4088 = $4086 ? $4083 : Math_fround(0.0);
 $4089 = $4086 ? $4085 : Math_fround(0.0);
 $4090 = Math_fround($4087 / $4039);
 $4091 = Math_fround($4088 / $4039);
 $4092 = Math_fround($4089 / $4039);
 $4093 = Math_fround(Math_fround(0.0) / $4039);
 $4094 = $4048 ? $4090 : Math_fround(0.0);
 $4095 = $4048 ? $4091 : Math_fround(0.0);
 $4096 = $4048 ? $4092 : Math_fround(0.0);
 $4097 = $4048 ? $4093 : Math_fround(0.0);
 $4098 = (($motionOutput) + 20|0);
 HEAPF32[$4098>>2] = $4094;
 $4099 = (($motionOutput) + 24|0);
 HEAPF32[$4099>>2] = $4095;
 $4100 = (($motionOutput) + 28|0);
 HEAPF32[$4100>>2] = $4096;
 $4101 = (($motionOutput) + 32|0);
 HEAPF32[$4101>>2] = $4097;
 STACKTOP = sp;return;
}
function __ZN4mathL11xformMulInvERKNS_5xformES2_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = Math_fround(0), $20 = 0, $200 = 0, $201 = 0, $202 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0);
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0);
 var $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(-1.0));
 $3 = (($b) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(-1.0));
 $6 = (($b) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(-1.0));
 $9 = (($b) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($b) + 32|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround(Math_fround(1.0) / $12);
 $14 = (($b) + 36|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround(Math_fround(1.0) / $15);
 $17 = (($b) + 40|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround(Math_fround(1.0) / $18);
 $20 = (($b) + 44|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround(Math_fround(1.0) / $21);
 $23 = Math_fround(HEAPF32[$b>>2]);
 $24 = Math_fround(-$23);
 $25 = (($b) + 4|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround(-$26);
 $28 = (($b) + 8|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround(-$29);
 $31 = (($b) + 12|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($24 - $23);
 $34 = Math_fround($27 - $26);
 $35 = Math_fround($30 - $29);
 $36 = Math_fround($2 * $34);
 $37 = Math_fround($5 * $35);
 $38 = Math_fround($8 * $33);
 $39 = Math_fround($10 * Math_fround(0.0));
 $40 = Math_fround($5 * $33);
 $41 = Math_fround($8 * $34);
 $42 = Math_fround($2 * $35);
 $43 = Math_fround($36 - $40);
 $44 = Math_fround($37 - $41);
 $45 = Math_fround($38 - $42);
 $46 = Math_fround($39 - $39);
 $47 = Math_fround($10 * $44);
 $48 = Math_fround($10 * $45);
 $49 = Math_fround($10 * $43);
 $50 = Math_fround($10 * $46);
 $51 = Math_fround($47 - $23);
 $52 = Math_fround($48 - $26);
 $53 = Math_fround($49 - $29);
 $54 = Math_fround($50 - $32);
 $55 = Math_fround($2 * $45);
 $56 = Math_fround($5 * $43);
 $57 = Math_fround($8 * $44);
 $58 = Math_fround($5 * $44);
 $59 = Math_fround($8 * $45);
 $60 = Math_fround($2 * $43);
 $61 = Math_fround($55 - $58);
 $62 = Math_fround($56 - $59);
 $63 = Math_fround($57 - $60);
 $64 = Math_fround($50 - $50);
 $65 = Math_fround($51 + $62);
 $66 = Math_fround($52 + $63);
 $67 = Math_fround($53 + $61);
 $68 = Math_fround($64 + $54);
 $69 = Math_fround($13 * $65);
 $70 = Math_fround($16 * $66);
 $71 = Math_fround($19 * $67);
 $72 = Math_fround($22 * $68);
 $73 = (($a) + 32|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = Math_fround($74 * $69);
 $76 = (($a) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 * $70);
 $79 = (($a) + 40|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($80 * $71);
 $82 = (($a) + 44|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($72 * $83);
 $85 = Math_fround($75 + $75);
 $86 = Math_fround($78 + $78);
 $87 = Math_fround($81 + $81);
 $88 = (($a) + 16|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = Math_fround($89 * $86);
 $91 = (($a) + 20|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 $93 = Math_fround($92 * $87);
 $94 = (($a) + 24|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = Math_fround($95 * $85);
 $97 = (($a) + 28|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = Math_fround($98 * Math_fround(0.0));
 $100 = Math_fround($92 * $85);
 $101 = Math_fround($95 * $86);
 $102 = Math_fround($89 * $87);
 $103 = Math_fround($90 - $100);
 $104 = Math_fround($93 - $101);
 $105 = Math_fround($96 - $102);
 $106 = Math_fround($99 - $99);
 $107 = Math_fround($98 * $104);
 $108 = Math_fround($98 * $105);
 $109 = Math_fround($98 * $103);
 $110 = Math_fround($98 * $106);
 $111 = Math_fround($75 + $107);
 $112 = Math_fround($78 + $108);
 $113 = Math_fround($81 + $109);
 $114 = Math_fround($84 + $110);
 $115 = Math_fround($89 * $105);
 $116 = Math_fround($92 * $103);
 $117 = Math_fround($95 * $104);
 $118 = Math_fround($92 * $104);
 $119 = Math_fround($95 * $105);
 $120 = Math_fround($89 * $103);
 $121 = Math_fround($115 - $118);
 $122 = Math_fround($116 - $119);
 $123 = Math_fround($117 - $120);
 $124 = Math_fround($110 - $110);
 $125 = Math_fround($111 + $122);
 $126 = Math_fround($112 + $123);
 $127 = Math_fround($113 + $121);
 $128 = Math_fround($114 + $124);
 $129 = Math_fround(HEAPF32[$a>>2]);
 $130 = Math_fround($129 + $125);
 $131 = (($a) + 4|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($132 + $126);
 $134 = (($a) + 8|0);
 $135 = Math_fround(HEAPF32[$134>>2]);
 $136 = Math_fround($135 + $127);
 $137 = (($a) + 12|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = Math_fround($138 + $128);
 $140 = Math_fround($2 * $92);
 $141 = Math_fround($10 * $98);
 $142 = Math_fround($5 * $95);
 $143 = Math_fround($8 * $89);
 $144 = Math_fround($8 * $98);
 $145 = Math_fround($2 * $89);
 $146 = Math_fround($8 * $92);
 $147 = Math_fround($2 * $95);
 $148 = Math_fround($140 - $144);
 $149 = Math_fround($141 - $145);
 $150 = Math_fround($142 - $146);
 $151 = Math_fround($143 - $147);
 $152 = Math_fround($10 * $95);
 $153 = Math_fround($8 * $95);
 $154 = Math_fround($2 * $98);
 $155 = Math_fround($5 * $98);
 $156 = Math_fround($148 - $152);
 $157 = Math_fround($149 - $153);
 $158 = Math_fround($150 - $154);
 $159 = Math_fround($151 - $155);
 $160 = Math_fround($5 * $89);
 $161 = Math_fround($5 * $92);
 $162 = Math_fround($10 * $89);
 $163 = Math_fround($10 * $92);
 $164 = Math_fround($156 - $160);
 $165 = Math_fround($157 - $161);
 $166 = Math_fround($158 - $162);
 $167 = Math_fround($159 - $163);
 $168 = Math_fround($166 * Math_fround(-1.0));
 $169 = Math_fround($167 * Math_fround(-1.0));
 $170 = Math_fround($164 * Math_fround(-1.0));
 $171 = Math_fround($168 * $168);
 $172 = Math_fround($169 * $169);
 $173 = Math_fround($170 * $170);
 $174 = Math_fround($165 * $165);
 $175 = Math_fround($171 + $172);
 $176 = Math_fround($173 + $174);
 $177 = Math_fround($176 + $175);
 $178 = (Math_fround(Math_sqrt((Math_fround($177)))));
 $179 = Math_fround(Math_fround(1.0) / $178);
 $180 = Math_fround($179 * $168);
 $181 = Math_fround($179 * $169);
 $182 = Math_fround($179 * $170);
 $183 = Math_fround($179 * $165);
 $184 = Math_fround(HEAPF32[$73>>2]);
 $185 = Math_fround($13 * $184);
 $186 = Math_fround(HEAPF32[$76>>2]);
 $187 = Math_fround($16 * $186);
 $188 = Math_fround(HEAPF32[$79>>2]);
 $189 = Math_fround($19 * $188);
 $190 = Math_fround(HEAPF32[$82>>2]);
 $191 = Math_fround($22 * $190);
 HEAPF32[$agg$result>>2] = $130;
 $192 = (($agg$result) + 4|0);
 HEAPF32[$192>>2] = $133;
 $193 = (($agg$result) + 8|0);
 HEAPF32[$193>>2] = $136;
 $194 = (($agg$result) + 12|0);
 HEAPF32[$194>>2] = $139;
 $195 = (($agg$result) + 16|0);
 HEAPF32[$195>>2] = $180;
 $196 = (($agg$result) + 20|0);
 HEAPF32[$196>>2] = $181;
 $197 = (($agg$result) + 24|0);
 HEAPF32[$197>>2] = $182;
 $198 = (($agg$result) + 28|0);
 HEAPF32[$198>>2] = $183;
 $199 = (($agg$result) + 32|0);
 HEAPF32[$199>>2] = $185;
 $200 = (($agg$result) + 36|0);
 HEAPF32[$200>>2] = $187;
 $201 = (($agg$result) + 40|0);
 HEAPF32[$201>>2] = $189;
 $202 = (($agg$result) + 44|0);
 HEAPF32[$202>>2] = $191;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17GetClipCurveCountERKNS0_18ClipMuscleConstantE($constant) {
 $constant = $constant|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($constant) + 1040|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($4) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6))|0;
 $10 = (($4) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + ($11))|0;
 STACKTOP = sp;return ($12|0);
}
function __ZN7mecanim9animationL25MuscleIndexIdSortFunctionENS0_13MuscleIndexIdES1_($i,$j) {
 $i = $i|0;
 $j = $j|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($i) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($j) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 STACKTOP = sp;return ($4|0);
}
function __ZNSt3__16__sortIRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$032 = 0, $__i$06$i = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0;
 var $__j$05$i = 0, $__j$05$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__k$0$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $tmpcast7$byval_copy = 0, $tmpcast8$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $tmpcast8$byval_copy = sp + 240|0;
 $tmpcast7$byval_copy = sp + 248|0;
 $0 = sp + 232|0;
 $1 = sp + 224|0;
 $2 = sp + 216|0;
 $3 = sp + 208|0;
 $4 = sp + 200|0;
 $5 = sp + 192|0;
 $6 = sp + 184|0;
 $7 = sp + 176|0;
 $8 = sp + 168|0;
 $9 = sp + 160|0;
 $10 = sp + 152|0;
 $11 = sp + 144|0;
 $12 = sp + 136|0;
 $13 = sp + 128|0;
 $14 = sp + 120|0;
 $15 = sp + 48|0;
 $16 = sp;
 $17 = sp + 8|0;
 $18 = sp + 16|0;
 $19 = sp + 24|0;
 $20 = sp + 32|0;
 $21 = sp + 40|0;
 $22 = sp + 56|0;
 $23 = sp + 64|0;
 $24 = sp + 72|0;
 $25 = sp + 80|0;
 $26 = sp + 88|0;
 $27 = sp + 96|0;
 $28 = sp + 104|0;
 $29 = sp + 112|0;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $30 = $$01$ph;
  $31 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $32 = $$0;
   $33 = (($30) - ($32))|0;
   $34 = $33 >> 3;
   switch ($34|0) {
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 5:  {
    label = 11;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 54;
    break L1;
    break;
   }
   default: {
   }
   }
   $203 = ($33|0)<(248);
   if ($203) {
    label = 13;
    break L1;
   }
   $270 = ($33|0)>(7992);
   $271 = (($34|0) / 2)&-1;
   $272 = (($$0) + ($271<<3)|0);
   if ($270) {
    $273 = (($34|0) / 4)&-1;
    $274 = (($$0) + ($273<<3)|0);
    $$sum = (($273) + ($271))|0;
    $275 = (($$0) + ($$sum<<3)|0);
    $276 = (__ZNSt3__17__sort5IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_S8_S8_T_($$0,$274,$272,$275,$31,$__comp)|0);
    $__n_swaps$0 = $276;
   } else {
    $277 = (__ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($$0,$272,$31,$__comp)|0);
    $__n_swaps$0 = $277;
   }
   $278 = HEAP32[$__comp>>2]|0;
   $279 = $$0;
   $280 = $279;
   $281 = HEAP32[$280>>2]|0;
   $282 = (($279) + 4)|0;
   $283 = $282;
   $284 = HEAP32[$283>>2]|0;
   $285 = $12;
   $286 = $285;
   HEAP32[$286>>2] = $281;
   $287 = (($285) + 4)|0;
   $288 = $287;
   HEAP32[$288>>2] = $284;
   $289 = $272;
   $290 = $289;
   $291 = HEAP32[$290>>2]|0;
   $292 = (($289) + 4)|0;
   $293 = $292;
   $294 = HEAP32[$293>>2]|0;
   $295 = $13;
   $296 = $295;
   HEAP32[$296>>2] = $291;
   $297 = (($295) + 4)|0;
   $298 = $297;
   HEAP32[$298>>2] = $294;
   ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$12+4>>2]|0;
   ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$13+4>>2]|0;
   $299 = (FUNCTION_TABLE_iii[$278 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
   do {
    if ($299) {
     $__j$3 = $31;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $31;
     while(1) {
      $300 = (($__j$0) + -8|0);
      $301 = ($$0|0)==($300|0);
      if ($301) {
       break;
      }
      $438 = HEAP32[$__comp>>2]|0;
      $439 = $300;
      $440 = $439;
      $441 = HEAP32[$440>>2]|0;
      $442 = (($439) + 4)|0;
      $443 = $442;
      $444 = HEAP32[$443>>2]|0;
      $445 = $22;
      $446 = $445;
      HEAP32[$446>>2] = $441;
      $447 = (($445) + 4)|0;
      $448 = $447;
      HEAP32[$448>>2] = $444;
      $449 = $272;
      $450 = $449;
      $451 = HEAP32[$450>>2]|0;
      $452 = (($449) + 4)|0;
      $453 = $452;
      $454 = HEAP32[$453>>2]|0;
      $455 = $23;
      $456 = $455;
      HEAP32[$456>>2] = $451;
      $457 = (($455) + 4)|0;
      $458 = $457;
      HEAP32[$458>>2] = $454;
      ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$22+4>>2]|0;
      ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$23+4>>2]|0;
      $459 = (FUNCTION_TABLE_iii[$438 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
      if ($459) {
       label = 37;
       break;
      } else {
       $__j$0 = $300;
      }
     }
     if ((label|0) == 37) {
      label = 0;
      $460 = $$0;
      $461 = $460;
      $462 = HEAP32[$461>>2]|0;
      $463 = (($460) + 4)|0;
      $464 = $463;
      $465 = HEAP32[$464>>2]|0;
      $466 = $300;
      $467 = $466;
      $468 = HEAP32[$467>>2]|0;
      $469 = (($466) + 4)|0;
      $470 = $469;
      $471 = HEAP32[$470>>2]|0;
      $472 = $$0;
      $473 = $472;
      HEAP32[$473>>2] = $468;
      $474 = (($472) + 4)|0;
      $475 = $474;
      HEAP32[$475>>2] = $471;
      $476 = $300;
      $477 = $476;
      HEAP32[$477>>2] = $462;
      $478 = (($476) + 4)|0;
      $479 = $478;
      HEAP32[$479>>2] = $465;
      $480 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $300;$__n_swaps$3 = $480;
      break;
     }
     $302 = (($$0) + 8|0);
     $303 = HEAP32[$__comp>>2]|0;
     $304 = $$0;
     $305 = $304;
     $306 = HEAP32[$305>>2]|0;
     $307 = (($304) + 4)|0;
     $308 = $307;
     $309 = HEAP32[$308>>2]|0;
     $310 = $14;
     $311 = $310;
     HEAP32[$311>>2] = $306;
     $312 = (($310) + 4)|0;
     $313 = $312;
     HEAP32[$313>>2] = $309;
     $314 = $31;
     $315 = $314;
     $316 = HEAP32[$315>>2]|0;
     $317 = (($314) + 4)|0;
     $318 = $317;
     $319 = HEAP32[$318>>2]|0;
     $320 = $15;
     $321 = $320;
     HEAP32[$321>>2] = $316;
     $322 = (($320) + 4)|0;
     $323 = $322;
     HEAP32[$323>>2] = $319;
     ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$14+4>>2]|0;
     ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$15+4>>2]|0;
     $324 = (FUNCTION_TABLE_iii[$303 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
     if ($324) {
      $__i$1 = $302;
     } else {
      $325 = ($302|0)==($31|0);
      if ($325) {
       label = 54;
       break L1;
      } else {
       $__i$032 = $302;
      }
      while(1) {
       $328 = HEAP32[$__comp>>2]|0;
       $329 = $$0;
       $330 = $329;
       $331 = HEAP32[$330>>2]|0;
       $332 = (($329) + 4)|0;
       $333 = $332;
       $334 = HEAP32[$333>>2]|0;
       $335 = $16;
       $336 = $335;
       HEAP32[$336>>2] = $331;
       $337 = (($335) + 4)|0;
       $338 = $337;
       HEAP32[$338>>2] = $334;
       $339 = $__i$032;
       $340 = $339;
       $341 = HEAP32[$340>>2]|0;
       $342 = (($339) + 4)|0;
       $343 = $342;
       $344 = HEAP32[$343>>2]|0;
       $345 = $17;
       $346 = $345;
       HEAP32[$346>>2] = $341;
       $347 = (($345) + 4)|0;
       $348 = $347;
       HEAP32[$348>>2] = $344;
       ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$16+4>>2]|0;
       ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$17+4>>2]|0;
       $349 = (FUNCTION_TABLE_iii[$328 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
       $327 = (($__i$032) + 8|0);
       if ($349) {
        break;
       }
       $326 = ($327|0)==($31|0);
       if ($326) {
        label = 54;
        break L1;
       } else {
        $__i$032 = $327;
       }
      }
      $350 = $__i$032;
      $351 = $350;
      $352 = HEAP32[$351>>2]|0;
      $353 = (($350) + 4)|0;
      $354 = $353;
      $355 = HEAP32[$354>>2]|0;
      $356 = $31;
      $357 = $356;
      $358 = HEAP32[$357>>2]|0;
      $359 = (($356) + 4)|0;
      $360 = $359;
      $361 = HEAP32[$360>>2]|0;
      $362 = $__i$032;
      $363 = $362;
      HEAP32[$363>>2] = $358;
      $364 = (($362) + 4)|0;
      $365 = $364;
      HEAP32[$365>>2] = $361;
      $366 = $31;
      $367 = $366;
      HEAP32[$367>>2] = $352;
      $368 = (($366) + 4)|0;
      $369 = $368;
      HEAP32[$369>>2] = $355;
      $__i$1 = $327;
     }
     $370 = ($__i$1|0)==($31|0);
     if ($370) {
      label = 54;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $31;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $371 = HEAP32[$__comp>>2]|0;
       $372 = $$0;
       $373 = $372;
       $374 = HEAP32[$373>>2]|0;
       $375 = (($372) + 4)|0;
       $376 = $375;
       $377 = HEAP32[$376>>2]|0;
       $378 = $18;
       $379 = $378;
       HEAP32[$379>>2] = $374;
       $380 = (($378) + 4)|0;
       $381 = $380;
       HEAP32[$381>>2] = $377;
       $382 = $__i$2;
       $383 = $382;
       $384 = HEAP32[$383>>2]|0;
       $385 = (($382) + 4)|0;
       $386 = $385;
       $387 = HEAP32[$386>>2]|0;
       $388 = $19;
       $389 = $388;
       HEAP32[$389>>2] = $384;
       $390 = (($388) + 4)|0;
       $391 = $390;
       HEAP32[$391>>2] = $387;
       ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$18+4>>2]|0;
       ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$19+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$19+4>>2]|0;
       $392 = (FUNCTION_TABLE_iii[$371 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
       $393 = (($__i$2) + 8|0);
       if ($392) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $393;
       }
      }
      while(1) {
       $394 = HEAP32[$__comp>>2]|0;
       $395 = $$0;
       $396 = $395;
       $397 = HEAP32[$396>>2]|0;
       $398 = (($395) + 4)|0;
       $399 = $398;
       $400 = HEAP32[$399>>2]|0;
       $401 = $20;
       $402 = $401;
       HEAP32[$402>>2] = $397;
       $403 = (($401) + 4)|0;
       $404 = $403;
       HEAP32[$404>>2] = $400;
       $405 = (($__j$2) + -8|0);
       $406 = $405;
       $407 = $406;
       $408 = HEAP32[$407>>2]|0;
       $409 = (($406) + 4)|0;
       $410 = $409;
       $411 = HEAP32[$410>>2]|0;
       $412 = $21;
       $413 = $412;
       HEAP32[$413>>2] = $408;
       $414 = (($412) + 4)|0;
       $415 = $414;
       HEAP32[$415>>2] = $411;
       ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$20+4>>2]|0;
       ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$21+4>>2]|0;
       $416 = (FUNCTION_TABLE_iii[$394 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
       if ($416) {
        $__j$2 = $405;
       } else {
        break;
       }
      }
      $417 = ($__i$2>>>0)<($405>>>0);
      if (!($417)) {
       $$0 = $__i$2;
       continue L3;
      }
      $418 = $__i$2;
      $419 = $418;
      $420 = HEAP32[$419>>2]|0;
      $421 = (($418) + 4)|0;
      $422 = $421;
      $423 = HEAP32[$422>>2]|0;
      $424 = $405;
      $425 = $424;
      $426 = HEAP32[$425>>2]|0;
      $427 = (($424) + 4)|0;
      $428 = $427;
      $429 = HEAP32[$428>>2]|0;
      $430 = $__i$2;
      $431 = $430;
      HEAP32[$431>>2] = $426;
      $432 = (($430) + 4)|0;
      $433 = $432;
      HEAP32[$433>>2] = $429;
      $434 = $405;
      $435 = $434;
      HEAP32[$435>>2] = $420;
      $436 = (($434) + 4)|0;
      $437 = $436;
      HEAP32[$437>>2] = $423;
      $__i$2$ph = $393;$__j$1$ph = $405;
     }
    }
   } while(0);
   $481 = (($$0) + 8|0);
   $482 = ($481>>>0)<($__j$3>>>0);
   L34: do {
    if ($482) {
     $__i$3$ph = $481;$__j$4$ph = $__j$3;$__m$0$ph = $272;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $483 = HEAP32[$__comp>>2]|0;
       $484 = $__i$3;
       $485 = $484;
       $486 = HEAP32[$485>>2]|0;
       $487 = (($484) + 4)|0;
       $488 = $487;
       $489 = HEAP32[$488>>2]|0;
       $490 = $24;
       $491 = $490;
       HEAP32[$491>>2] = $486;
       $492 = (($490) + 4)|0;
       $493 = $492;
       HEAP32[$493>>2] = $489;
       $494 = $__m$0$ph;
       $495 = $494;
       $496 = HEAP32[$495>>2]|0;
       $497 = (($494) + 4)|0;
       $498 = $497;
       $499 = HEAP32[$498>>2]|0;
       $500 = $25;
       $501 = $500;
       HEAP32[$501>>2] = $496;
       $502 = (($500) + 4)|0;
       $503 = $502;
       HEAP32[$503>>2] = $499;
       ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$24+4>>2]|0;
       ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$25+4>>2]|0;
       $504 = (FUNCTION_TABLE_iii[$483 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
       $505 = (($__i$3) + 8|0);
       if ($504) {
        $__i$3 = $505;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $506 = HEAP32[$__comp>>2]|0;
       $507 = (($__j$5) + -8|0);
       $508 = $507;
       $509 = $508;
       $510 = HEAP32[$509>>2]|0;
       $511 = (($508) + 4)|0;
       $512 = $511;
       $513 = HEAP32[$512>>2]|0;
       $514 = $26;
       $515 = $514;
       HEAP32[$515>>2] = $510;
       $516 = (($514) + 4)|0;
       $517 = $516;
       HEAP32[$517>>2] = $513;
       $518 = $__m$0$ph;
       $519 = $518;
       $520 = HEAP32[$519>>2]|0;
       $521 = (($518) + 4)|0;
       $522 = $521;
       $523 = HEAP32[$522>>2]|0;
       $524 = $27;
       $525 = $524;
       HEAP32[$525>>2] = $520;
       $526 = (($524) + 4)|0;
       $527 = $526;
       HEAP32[$527>>2] = $523;
       ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$26+4>>2]|0;
       ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$27+4>>2]|0;
       $528 = (FUNCTION_TABLE_iii[$506 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
       if ($528) {
        break;
       } else {
        $__j$5 = $507;
       }
      }
      $529 = ($__i$3>>>0)>($507>>>0);
      if ($529) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $530 = $__i$3;
      $531 = $530;
      $532 = HEAP32[$531>>2]|0;
      $533 = (($530) + 4)|0;
      $534 = $533;
      $535 = HEAP32[$534>>2]|0;
      $536 = $507;
      $537 = $536;
      $538 = HEAP32[$537>>2]|0;
      $539 = (($536) + 4)|0;
      $540 = $539;
      $541 = HEAP32[$540>>2]|0;
      $542 = $__i$3;
      $543 = $542;
      HEAP32[$543>>2] = $538;
      $544 = (($542) + 4)|0;
      $545 = $544;
      HEAP32[$545>>2] = $541;
      $546 = $507;
      $547 = $546;
      HEAP32[$547>>2] = $532;
      $548 = (($546) + 4)|0;
      $549 = $548;
      HEAP32[$549>>2] = $535;
      $550 = (($__n_swaps$4$ph) + 1)|0;
      $551 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $551 ? $507 : $__m$0$ph;
      $__i$3$ph = $505;$__j$4$ph = $507;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $550;
     }
    } else {
     $__i$4 = $481;$__m$2 = $272;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $552 = ($__i$4|0)==($__m$2|0);
   if ($552) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $553 = HEAP32[$__comp>>2]|0;
    $554 = $__m$2;
    $555 = $554;
    $556 = HEAP32[$555>>2]|0;
    $557 = (($554) + 4)|0;
    $558 = $557;
    $559 = HEAP32[$558>>2]|0;
    $560 = $28;
    $561 = $560;
    HEAP32[$561>>2] = $556;
    $562 = (($560) + 4)|0;
    $563 = $562;
    HEAP32[$563>>2] = $559;
    $564 = $__i$4;
    $565 = $564;
    $566 = HEAP32[$565>>2]|0;
    $567 = (($564) + 4)|0;
    $568 = $567;
    $569 = HEAP32[$568>>2]|0;
    $570 = $29;
    $571 = $570;
    HEAP32[$571>>2] = $566;
    $572 = (($570) + 4)|0;
    $573 = $572;
    HEAP32[$573>>2] = $569;
    ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$28+4>>2]|0;
    ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$29+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$29+4>>2]|0;
    $574 = (FUNCTION_TABLE_iii[$553 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
    if ($574) {
     $575 = $__i$4;
     $576 = $575;
     $577 = HEAP32[$576>>2]|0;
     $578 = (($575) + 4)|0;
     $579 = $578;
     $580 = HEAP32[$579>>2]|0;
     $581 = $__m$2;
     $582 = $581;
     $583 = HEAP32[$582>>2]|0;
     $584 = (($581) + 4)|0;
     $585 = $584;
     $586 = HEAP32[$585>>2]|0;
     $587 = $__i$4;
     $588 = $587;
     HEAP32[$588>>2] = $583;
     $589 = (($587) + 4)|0;
     $590 = $589;
     HEAP32[$590>>2] = $586;
     $591 = $__m$2;
     $592 = $591;
     HEAP32[$592>>2] = $577;
     $593 = (($591) + 4)|0;
     $594 = $593;
     HEAP32[$594>>2] = $580;
     $595 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $595;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $596 = ($__n_swaps$6|0)==(0);
   if ($596) {
    $597 = (__ZNSt3__127__insertion_sort_incompleteIRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEbT0_S8_T_($$0,$__i$4,$__comp)|0);
    $598 = (($__i$4) + 8|0);
    $599 = (__ZNSt3__127__insertion_sort_incompleteIRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEbT0_S8_T_($598,$$01$ph,$__comp)|0);
    if ($599) {
     label = 49;
     break;
    }
    if ($597) {
     $$0 = $598;
     continue;
    }
   }
   $600 = $__i$4;
   $601 = (($600) - ($32))|0;
   $602 = (($30) - ($600))|0;
   $603 = ($601|0)<($602|0);
   if (!($603)) {
    label = 53;
    break;
   }
   __ZNSt3__16__sortIRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEvT0_S8_T_($$0,$__i$4,$__comp);
   $604 = (($__i$4) + 8|0);
   $$0 = $604;
  }
  if ((label|0) == 49) {
   label = 0;
   if ($597) {
    label = 54;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 53) {
   label = 0;
   $605 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEvT0_S8_T_($605,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $35 = HEAP32[$__comp>>2]|0;
  $36 = $31;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 4)|0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = $10;
  $43 = $42;
  HEAP32[$43>>2] = $38;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $41;
  $46 = $$0;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) + 4)|0;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = $11;
  $53 = $52;
  HEAP32[$53>>2] = $48;
  $54 = (($52) + 4)|0;
  $55 = $54;
  HEAP32[$55>>2] = $51;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$10+4>>2]|0;
  ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$11+4>>2]|0;
  $56 = (FUNCTION_TABLE_iii[$35 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
  if (!($56)) {
   STACKTOP = sp;return;
  }
  $57 = $$0;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = (($57) + 4)|0;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = $31;
  $64 = $63;
  $65 = HEAP32[$64>>2]|0;
  $66 = (($63) + 4)|0;
  $67 = $66;
  $68 = HEAP32[$67>>2]|0;
  $69 = $$0;
  $70 = $69;
  HEAP32[$70>>2] = $65;
  $71 = (($69) + 4)|0;
  $72 = $71;
  HEAP32[$72>>2] = $68;
  $73 = $31;
  $74 = $73;
  HEAP32[$74>>2] = $59;
  $75 = (($73) + 4)|0;
  $76 = $75;
  HEAP32[$76>>2] = $62;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $77 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($$0,$77,$31,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $78 = (($$0) + 8|0);
  $79 = (($$0) + 16|0);
  (__ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($$0,$78,$79,$__comp)|0);
  $80 = HEAP32[$__comp>>2]|0;
  $81 = $31;
  $82 = $81;
  $83 = HEAP32[$82>>2]|0;
  $84 = (($81) + 4)|0;
  $85 = $84;
  $86 = HEAP32[$85>>2]|0;
  $87 = $4;
  $88 = $87;
  HEAP32[$88>>2] = $83;
  $89 = (($87) + 4)|0;
  $90 = $89;
  HEAP32[$90>>2] = $86;
  $91 = $79;
  $92 = $91;
  $93 = HEAP32[$92>>2]|0;
  $94 = (($91) + 4)|0;
  $95 = $94;
  $96 = HEAP32[$95>>2]|0;
  $97 = $5;
  $98 = $97;
  HEAP32[$98>>2] = $93;
  $99 = (($97) + 4)|0;
  $100 = $99;
  HEAP32[$100>>2] = $96;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
  ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
  $101 = (FUNCTION_TABLE_iii[$80 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
  if (!($101)) {
   STACKTOP = sp;return;
  }
  $102 = $79;
  $103 = $102;
  $104 = HEAP32[$103>>2]|0;
  $105 = (($102) + 4)|0;
  $106 = $105;
  $107 = HEAP32[$106>>2]|0;
  $108 = $31;
  $109 = $108;
  $110 = HEAP32[$109>>2]|0;
  $111 = (($108) + 4)|0;
  $112 = $111;
  $113 = HEAP32[$112>>2]|0;
  $114 = $79;
  $115 = $114;
  HEAP32[$115>>2] = $110;
  $116 = (($114) + 4)|0;
  $117 = $116;
  HEAP32[$117>>2] = $113;
  $118 = $31;
  $119 = $118;
  HEAP32[$119>>2] = $104;
  $120 = (($118) + 4)|0;
  $121 = $120;
  HEAP32[$121>>2] = $107;
  $122 = HEAP32[$__comp>>2]|0;
  $123 = $79;
  $124 = $123;
  $125 = HEAP32[$124>>2]|0;
  $126 = (($123) + 4)|0;
  $127 = $126;
  $128 = HEAP32[$127>>2]|0;
  $129 = $6;
  $130 = $129;
  HEAP32[$130>>2] = $125;
  $131 = (($129) + 4)|0;
  $132 = $131;
  HEAP32[$132>>2] = $128;
  $133 = $78;
  $134 = $133;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($133) + 4)|0;
  $137 = $136;
  $138 = HEAP32[$137>>2]|0;
  $139 = $7;
  $140 = $139;
  HEAP32[$140>>2] = $135;
  $141 = (($139) + 4)|0;
  $142 = $141;
  HEAP32[$142>>2] = $138;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
  ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
  $143 = (FUNCTION_TABLE_iii[$122 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
  if (!($143)) {
   STACKTOP = sp;return;
  }
  $144 = $78;
  $145 = $144;
  $146 = HEAP32[$145>>2]|0;
  $147 = (($144) + 4)|0;
  $148 = $147;
  $149 = HEAP32[$148>>2]|0;
  $150 = $79;
  $151 = $150;
  $152 = HEAP32[$151>>2]|0;
  $153 = (($150) + 4)|0;
  $154 = $153;
  $155 = HEAP32[$154>>2]|0;
  $156 = $78;
  $157 = $156;
  HEAP32[$157>>2] = $152;
  $158 = (($156) + 4)|0;
  $159 = $158;
  HEAP32[$159>>2] = $155;
  $160 = $79;
  $161 = $160;
  HEAP32[$161>>2] = $146;
  $162 = (($160) + 4)|0;
  $163 = $162;
  HEAP32[$163>>2] = $149;
  $164 = HEAP32[$__comp>>2]|0;
  $165 = $8;
  $166 = $165;
  HEAP32[$166>>2] = $152;
  $167 = (($165) + 4)|0;
  $168 = $167;
  HEAP32[$168>>2] = $155;
  $169 = $$0;
  $170 = $169;
  $171 = HEAP32[$170>>2]|0;
  $172 = (($169) + 4)|0;
  $173 = $172;
  $174 = HEAP32[$173>>2]|0;
  $175 = $9;
  $176 = $175;
  HEAP32[$176>>2] = $171;
  $177 = (($175) + 4)|0;
  $178 = $177;
  HEAP32[$178>>2] = $174;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
  ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
  $179 = (FUNCTION_TABLE_iii[$164 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
  if (!($179)) {
   STACKTOP = sp;return;
  }
  $180 = $$0;
  $181 = $180;
  $182 = HEAP32[$181>>2]|0;
  $183 = (($180) + 4)|0;
  $184 = $183;
  $185 = HEAP32[$184>>2]|0;
  $186 = $78;
  $187 = $186;
  $188 = HEAP32[$187>>2]|0;
  $189 = (($186) + 4)|0;
  $190 = $189;
  $191 = HEAP32[$190>>2]|0;
  $192 = $$0;
  $193 = $192;
  HEAP32[$193>>2] = $188;
  $194 = (($192) + 4)|0;
  $195 = $194;
  HEAP32[$195>>2] = $191;
  $196 = $78;
  $197 = $196;
  HEAP32[$197>>2] = $182;
  $198 = (($196) + 4)|0;
  $199 = $198;
  HEAP32[$199>>2] = $185;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  $200 = (($$0) + 8|0);
  $201 = (($$0) + 16|0);
  $202 = (($$0) + 24|0);
  (__ZNSt3__17__sort5IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_S8_S8_T_($$0,$200,$201,$202,$31,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 13) {
  $204 = (($$0) + 16|0);
  $205 = (($$0) + 8|0);
  (__ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($$0,$205,$204,$__comp)|0);
  $206 = (($$0) + 24|0);
  $207 = ($206|0)==($$01$ph|0);
  if ($207) {
   STACKTOP = sp;return;
  } else {
   $__i$06$i = $206;$__j$05$i = $204;
  }
  while(1) {
   $208 = HEAP32[$__comp>>2]|0;
   $209 = $__i$06$i;
   $210 = $209;
   $211 = HEAP32[$210>>2]|0;
   $212 = (($209) + 4)|0;
   $213 = $212;
   $214 = HEAP32[$213>>2]|0;
   $215 = $0;
   $216 = $215;
   HEAP32[$216>>2] = $211;
   $217 = (($215) + 4)|0;
   $218 = $217;
   HEAP32[$218>>2] = $214;
   $219 = $__j$05$i;
   $220 = $219;
   $221 = HEAP32[$220>>2]|0;
   $222 = (($219) + 4)|0;
   $223 = $222;
   $224 = HEAP32[$223>>2]|0;
   $225 = $1;
   $226 = $225;
   HEAP32[$226>>2] = $221;
   $227 = (($225) + 4)|0;
   $228 = $227;
   HEAP32[$228>>2] = $224;
   ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
   $229 = (FUNCTION_TABLE_iii[$208 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
   if ($229) {
    $230 = $__i$06$i;
    $231 = $230;
    $232 = HEAP32[$231>>2]|0;
    $233 = (($230) + 4)|0;
    $234 = $233;
    $235 = HEAP32[$234>>2]|0;
    $__j$1$i = $__i$06$i;$__k$0$i = $__j$05$i;
    while(1) {
     $236 = $__k$0$i;
     $237 = $236;
     $238 = HEAP32[$237>>2]|0;
     $239 = (($236) + 4)|0;
     $240 = $239;
     $241 = HEAP32[$240>>2]|0;
     $242 = $__j$1$i;
     $243 = $242;
     HEAP32[$243>>2] = $238;
     $244 = (($242) + 4)|0;
     $245 = $244;
     HEAP32[$245>>2] = $241;
     $246 = ($__k$0$i|0)==($$0|0);
     if ($246) {
      break;
     }
     $247 = HEAP32[$__comp>>2]|0;
     $248 = $2;
     $249 = $248;
     HEAP32[$249>>2] = $232;
     $250 = (($248) + 4)|0;
     $251 = $250;
     HEAP32[$251>>2] = $235;
     $252 = (($__k$0$i) + -8|0);
     $253 = $252;
     $254 = $253;
     $255 = HEAP32[$254>>2]|0;
     $256 = (($253) + 4)|0;
     $257 = $256;
     $258 = HEAP32[$257>>2]|0;
     $259 = $3;
     $260 = $259;
     HEAP32[$260>>2] = $255;
     $261 = (($259) + 4)|0;
     $262 = $261;
     HEAP32[$262>>2] = $258;
     ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
     ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
     $263 = (FUNCTION_TABLE_iii[$247 & 4095]($tmpcast7$byval_copy,$tmpcast8$byval_copy)|0);
     if ($263) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $252;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $264 = $__k$0$i;
    $265 = $264;
    HEAP32[$265>>2] = $232;
    $266 = (($264) + 4)|0;
    $267 = $266;
    HEAP32[$267>>2] = $235;
   }
   $268 = (($__i$06$i) + 8|0);
   $269 = ($268|0)==($$01$ph|0);
   if ($269) {
    break;
   } else {
    $__j$05$i$phi = $__i$06$i;$__i$06$i = $268;$__j$05$i = $__j$05$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 54) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $tmpcast8$byval_copy = 0, $tmpcast9$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmpcast9$byval_copy = sp + 80|0;
 $tmpcast8$byval_copy = sp + 88|0;
 $0 = sp + 72|0;
 $1 = sp + 64|0;
 $2 = sp + 56|0;
 $3 = sp + 48|0;
 $4 = sp + 40|0;
 $5 = sp + 24|0;
 $6 = sp + 16|0;
 $7 = sp + 8|0;
 $8 = sp;
 $9 = sp + 32|0;
 $10 = HEAP32[$__c>>2]|0;
 $11 = $__y;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $0;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = $__x;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 4)|0;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = $1;
 $28 = $27;
 HEAP32[$28>>2] = $23;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $26;
 ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast9$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast9$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $31 = (FUNCTION_TABLE_iii[$10 & 4095]($tmpcast8$byval_copy,$tmpcast9$byval_copy)|0);
 $32 = HEAP32[$__c>>2]|0;
 if (!($31)) {
  $33 = $__z;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + 4)|0;
  $37 = $36;
  $38 = HEAP32[$37>>2]|0;
  $39 = $2;
  $40 = $39;
  HEAP32[$40>>2] = $35;
  $41 = (($39) + 4)|0;
  $42 = $41;
  HEAP32[$42>>2] = $38;
  $43 = $__y;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = (($43) + 4)|0;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = $3;
  $50 = $49;
  HEAP32[$50>>2] = $45;
  $51 = (($49) + 4)|0;
  $52 = $51;
  HEAP32[$52>>2] = $48;
  ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
  ;HEAP32[$tmpcast9$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast9$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
  $53 = (FUNCTION_TABLE_iii[$32 & 4095]($tmpcast8$byval_copy,$tmpcast9$byval_copy)|0);
  if (!($53)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $54 = $__y;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = (($54) + 4)|0;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = $__z;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = (($60) + 4)|0;
  $64 = $63;
  $65 = HEAP32[$64>>2]|0;
  $66 = $__y;
  $67 = $66;
  HEAP32[$67>>2] = $62;
  $68 = (($66) + 4)|0;
  $69 = $68;
  HEAP32[$69>>2] = $65;
  $70 = $__z;
  $71 = $70;
  HEAP32[$71>>2] = $56;
  $72 = (($70) + 4)|0;
  $73 = $72;
  HEAP32[$73>>2] = $59;
  $74 = HEAP32[$__c>>2]|0;
  $75 = $__y;
  $76 = $75;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($75) + 4)|0;
  $79 = $78;
  $80 = HEAP32[$79>>2]|0;
  $81 = $4;
  $82 = $81;
  HEAP32[$82>>2] = $77;
  $83 = (($81) + 4)|0;
  $84 = $83;
  HEAP32[$84>>2] = $80;
  $85 = $__x;
  $86 = $85;
  $87 = HEAP32[$86>>2]|0;
  $88 = (($85) + 4)|0;
  $89 = $88;
  $90 = HEAP32[$89>>2]|0;
  $91 = $5;
  $92 = $91;
  HEAP32[$92>>2] = $87;
  $93 = (($91) + 4)|0;
  $94 = $93;
  HEAP32[$94>>2] = $90;
  ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
  ;HEAP32[$tmpcast9$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast9$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
  $95 = (FUNCTION_TABLE_iii[$74 & 4095]($tmpcast8$byval_copy,$tmpcast9$byval_copy)|0);
  if (!($95)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $96 = $__x;
  $97 = $96;
  $98 = HEAP32[$97>>2]|0;
  $99 = (($96) + 4)|0;
  $100 = $99;
  $101 = HEAP32[$100>>2]|0;
  $102 = $__y;
  $103 = $102;
  $104 = HEAP32[$103>>2]|0;
  $105 = (($102) + 4)|0;
  $106 = $105;
  $107 = HEAP32[$106>>2]|0;
  $108 = $__x;
  $109 = $108;
  HEAP32[$109>>2] = $104;
  $110 = (($108) + 4)|0;
  $111 = $110;
  HEAP32[$111>>2] = $107;
  $112 = $__y;
  $113 = $112;
  HEAP32[$113>>2] = $98;
  $114 = (($112) + 4)|0;
  $115 = $114;
  HEAP32[$115>>2] = $101;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $116 = $__z;
 $117 = $116;
 $118 = HEAP32[$117>>2]|0;
 $119 = (($116) + 4)|0;
 $120 = $119;
 $121 = HEAP32[$120>>2]|0;
 $122 = $6;
 $123 = $122;
 HEAP32[$123>>2] = $118;
 $124 = (($122) + 4)|0;
 $125 = $124;
 HEAP32[$125>>2] = $121;
 $126 = $__y;
 $127 = $126;
 $128 = HEAP32[$127>>2]|0;
 $129 = (($126) + 4)|0;
 $130 = $129;
 $131 = HEAP32[$130>>2]|0;
 $132 = $7;
 $133 = $132;
 HEAP32[$133>>2] = $128;
 $134 = (($132) + 4)|0;
 $135 = $134;
 HEAP32[$135>>2] = $131;
 ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
 ;HEAP32[$tmpcast9$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$tmpcast9$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
 $136 = (FUNCTION_TABLE_iii[$32 & 4095]($tmpcast8$byval_copy,$tmpcast9$byval_copy)|0);
 $137 = $__x;
 $138 = $137;
 $139 = HEAP32[$138>>2]|0;
 $140 = (($137) + 4)|0;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 if ($136) {
  $143 = $__z;
  $144 = $143;
  $145 = HEAP32[$144>>2]|0;
  $146 = (($143) + 4)|0;
  $147 = $146;
  $148 = HEAP32[$147>>2]|0;
  $149 = $__x;
  $150 = $149;
  HEAP32[$150>>2] = $145;
  $151 = (($149) + 4)|0;
  $152 = $151;
  HEAP32[$152>>2] = $148;
  $153 = $__z;
  $154 = $153;
  HEAP32[$154>>2] = $139;
  $155 = (($153) + 4)|0;
  $156 = $155;
  HEAP32[$156>>2] = $142;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $157 = $__y;
 $158 = $157;
 $159 = HEAP32[$158>>2]|0;
 $160 = (($157) + 4)|0;
 $161 = $160;
 $162 = HEAP32[$161>>2]|0;
 $163 = $__x;
 $164 = $163;
 HEAP32[$164>>2] = $159;
 $165 = (($163) + 4)|0;
 $166 = $165;
 HEAP32[$166>>2] = $162;
 $167 = $__y;
 $168 = $167;
 HEAP32[$168>>2] = $139;
 $169 = (($167) + 4)|0;
 $170 = $169;
 HEAP32[$170>>2] = $142;
 $171 = HEAP32[$__c>>2]|0;
 $172 = $__z;
 $173 = $172;
 $174 = HEAP32[$173>>2]|0;
 $175 = (($172) + 4)|0;
 $176 = $175;
 $177 = HEAP32[$176>>2]|0;
 $178 = $8;
 $179 = $178;
 HEAP32[$179>>2] = $174;
 $180 = (($178) + 4)|0;
 $181 = $180;
 HEAP32[$181>>2] = $177;
 $182 = $9;
 $183 = $182;
 HEAP32[$183>>2] = $139;
 $184 = (($182) + 4)|0;
 $185 = $184;
 HEAP32[$185>>2] = $142;
 ;HEAP32[$tmpcast8$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast8$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
 ;HEAP32[$tmpcast9$byval_copy+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$tmpcast9$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
 $186 = (FUNCTION_TABLE_iii[$171 & 4095]($tmpcast8$byval_copy,$tmpcast9$byval_copy)|0);
 if (!($186)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $187 = $__y;
 $188 = $187;
 $189 = HEAP32[$188>>2]|0;
 $190 = (($187) + 4)|0;
 $191 = $190;
 $192 = HEAP32[$191>>2]|0;
 $193 = $__z;
 $194 = $193;
 $195 = HEAP32[$194>>2]|0;
 $196 = (($193) + 4)|0;
 $197 = $196;
 $198 = HEAP32[$197>>2]|0;
 $199 = $__y;
 $200 = $199;
 HEAP32[$200>>2] = $195;
 $201 = (($199) + 4)|0;
 $202 = $201;
 HEAP32[$202>>2] = $198;
 $203 = $__z;
 $204 = $203;
 HEAP32[$204>>2] = $189;
 $205 = (($203) + 4)|0;
 $206 = $205;
 HEAP32[$206>>2] = $192;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort5IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_S8_S8_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__r$0$i = 0, $tmpcast6$byval_copy = 0, $tmpcast7$byval_copy = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $tmpcast7$byval_copy = sp + 112|0;
 $tmpcast6$byval_copy = sp + 120|0;
 $0 = sp + 104|0;
 $1 = sp + 96|0;
 $2 = sp + 88|0;
 $3 = sp + 80|0;
 $4 = sp + 72|0;
 $5 = sp + 64|0;
 $6 = sp + 56|0;
 $7 = sp + 40|0;
 $8 = sp + 32|0;
 $9 = sp + 24|0;
 $10 = sp + 16|0;
 $11 = sp + 8|0;
 $12 = sp;
 $13 = sp + 48|0;
 $14 = (__ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($__x1,$__x2,$__x3,$__c)|0);
 $15 = HEAP32[$__c>>2]|0;
 $16 = $__x4;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $0;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 $26 = $__x3;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $1;
 $33 = $32;
 HEAP32[$33>>2] = $28;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $31;
 ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $36 = (FUNCTION_TABLE_iii[$15 & 4095]($tmpcast6$byval_copy,$tmpcast7$byval_copy)|0);
 if ($36) {
  $37 = $__x3;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + 4)|0;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = $__x4;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = (($43) + 4)|0;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = $__x3;
  $50 = $49;
  HEAP32[$50>>2] = $45;
  $51 = (($49) + 4)|0;
  $52 = $51;
  HEAP32[$52>>2] = $48;
  $53 = $__x4;
  $54 = $53;
  HEAP32[$54>>2] = $39;
  $55 = (($53) + 4)|0;
  $56 = $55;
  HEAP32[$56>>2] = $42;
  $57 = (($14) + 1)|0;
  $58 = HEAP32[$__c>>2]|0;
  $59 = $__x3;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) + 4)|0;
  $63 = $62;
  $64 = HEAP32[$63>>2]|0;
  $65 = $2;
  $66 = $65;
  HEAP32[$66>>2] = $61;
  $67 = (($65) + 4)|0;
  $68 = $67;
  HEAP32[$68>>2] = $64;
  $69 = $__x2;
  $70 = $69;
  $71 = HEAP32[$70>>2]|0;
  $72 = (($69) + 4)|0;
  $73 = $72;
  $74 = HEAP32[$73>>2]|0;
  $75 = $3;
  $76 = $75;
  HEAP32[$76>>2] = $71;
  $77 = (($75) + 4)|0;
  $78 = $77;
  HEAP32[$78>>2] = $74;
  ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
  ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
  $79 = (FUNCTION_TABLE_iii[$58 & 4095]($tmpcast6$byval_copy,$tmpcast7$byval_copy)|0);
  if ($79) {
   $80 = $__x2;
   $81 = $80;
   $82 = HEAP32[$81>>2]|0;
   $83 = (($80) + 4)|0;
   $84 = $83;
   $85 = HEAP32[$84>>2]|0;
   $86 = $__x3;
   $87 = $86;
   $88 = HEAP32[$87>>2]|0;
   $89 = (($86) + 4)|0;
   $90 = $89;
   $91 = HEAP32[$90>>2]|0;
   $92 = $__x2;
   $93 = $92;
   HEAP32[$93>>2] = $88;
   $94 = (($92) + 4)|0;
   $95 = $94;
   HEAP32[$95>>2] = $91;
   $96 = $__x3;
   $97 = $96;
   HEAP32[$97>>2] = $82;
   $98 = (($96) + 4)|0;
   $99 = $98;
   HEAP32[$99>>2] = $85;
   $100 = (($14) + 2)|0;
   $101 = HEAP32[$__c>>2]|0;
   $102 = $__x2;
   $103 = $102;
   $104 = HEAP32[$103>>2]|0;
   $105 = (($102) + 4)|0;
   $106 = $105;
   $107 = HEAP32[$106>>2]|0;
   $108 = $4;
   $109 = $108;
   HEAP32[$109>>2] = $104;
   $110 = (($108) + 4)|0;
   $111 = $110;
   HEAP32[$111>>2] = $107;
   $112 = $__x1;
   $113 = $112;
   $114 = HEAP32[$113>>2]|0;
   $115 = (($112) + 4)|0;
   $116 = $115;
   $117 = HEAP32[$116>>2]|0;
   $118 = $5;
   $119 = $118;
   HEAP32[$119>>2] = $114;
   $120 = (($118) + 4)|0;
   $121 = $120;
   HEAP32[$121>>2] = $117;
   ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
   ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
   $122 = (FUNCTION_TABLE_iii[$101 & 4095]($tmpcast6$byval_copy,$tmpcast7$byval_copy)|0);
   if ($122) {
    $123 = $__x1;
    $124 = $123;
    $125 = HEAP32[$124>>2]|0;
    $126 = (($123) + 4)|0;
    $127 = $126;
    $128 = HEAP32[$127>>2]|0;
    $129 = $__x2;
    $130 = $129;
    $131 = HEAP32[$130>>2]|0;
    $132 = (($129) + 4)|0;
    $133 = $132;
    $134 = HEAP32[$133>>2]|0;
    $135 = $__x1;
    $136 = $135;
    HEAP32[$136>>2] = $131;
    $137 = (($135) + 4)|0;
    $138 = $137;
    HEAP32[$138>>2] = $134;
    $139 = $__x2;
    $140 = $139;
    HEAP32[$140>>2] = $125;
    $141 = (($139) + 4)|0;
    $142 = $141;
    HEAP32[$142>>2] = $128;
    $143 = (($14) + 3)|0;
    $__r$0$i = $143;
   } else {
    $__r$0$i = $100;
   }
  } else {
   $__r$0$i = $57;
  }
 } else {
  $__r$0$i = $14;
 }
 $144 = HEAP32[$__c>>2]|0;
 $145 = $__x5;
 $146 = $145;
 $147 = HEAP32[$146>>2]|0;
 $148 = (($145) + 4)|0;
 $149 = $148;
 $150 = HEAP32[$149>>2]|0;
 $151 = $6;
 $152 = $151;
 HEAP32[$152>>2] = $147;
 $153 = (($151) + 4)|0;
 $154 = $153;
 HEAP32[$154>>2] = $150;
 $155 = $__x4;
 $156 = $155;
 $157 = HEAP32[$156>>2]|0;
 $158 = (($155) + 4)|0;
 $159 = $158;
 $160 = HEAP32[$159>>2]|0;
 $161 = $7;
 $162 = $161;
 HEAP32[$162>>2] = $157;
 $163 = (($161) + 4)|0;
 $164 = $163;
 HEAP32[$164>>2] = $160;
 ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
 $165 = (FUNCTION_TABLE_iii[$144 & 4095]($tmpcast6$byval_copy,$tmpcast7$byval_copy)|0);
 if (!($165)) {
  $__r$0 = $__r$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $166 = $__x4;
 $167 = $166;
 $168 = HEAP32[$167>>2]|0;
 $169 = (($166) + 4)|0;
 $170 = $169;
 $171 = HEAP32[$170>>2]|0;
 $172 = $__x5;
 $173 = $172;
 $174 = HEAP32[$173>>2]|0;
 $175 = (($172) + 4)|0;
 $176 = $175;
 $177 = HEAP32[$176>>2]|0;
 $178 = $__x4;
 $179 = $178;
 HEAP32[$179>>2] = $174;
 $180 = (($178) + 4)|0;
 $181 = $180;
 HEAP32[$181>>2] = $177;
 $182 = $__x5;
 $183 = $182;
 HEAP32[$183>>2] = $168;
 $184 = (($182) + 4)|0;
 $185 = $184;
 HEAP32[$185>>2] = $171;
 $186 = (($__r$0$i) + 1)|0;
 $187 = HEAP32[$__c>>2]|0;
 $188 = $__x4;
 $189 = $188;
 $190 = HEAP32[$189>>2]|0;
 $191 = (($188) + 4)|0;
 $192 = $191;
 $193 = HEAP32[$192>>2]|0;
 $194 = $8;
 $195 = $194;
 HEAP32[$195>>2] = $190;
 $196 = (($194) + 4)|0;
 $197 = $196;
 HEAP32[$197>>2] = $193;
 $198 = $__x3;
 $199 = $198;
 $200 = HEAP32[$199>>2]|0;
 $201 = (($198) + 4)|0;
 $202 = $201;
 $203 = HEAP32[$202>>2]|0;
 $204 = $9;
 $205 = $204;
 HEAP32[$205>>2] = $200;
 $206 = (($204) + 4)|0;
 $207 = $206;
 HEAP32[$207>>2] = $203;
 ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
 $208 = (FUNCTION_TABLE_iii[$187 & 4095]($tmpcast6$byval_copy,$tmpcast7$byval_copy)|0);
 if (!($208)) {
  $__r$0 = $186;
  STACKTOP = sp;return ($__r$0|0);
 }
 $209 = $__x3;
 $210 = $209;
 $211 = HEAP32[$210>>2]|0;
 $212 = (($209) + 4)|0;
 $213 = $212;
 $214 = HEAP32[$213>>2]|0;
 $215 = $__x4;
 $216 = $215;
 $217 = HEAP32[$216>>2]|0;
 $218 = (($215) + 4)|0;
 $219 = $218;
 $220 = HEAP32[$219>>2]|0;
 $221 = $__x3;
 $222 = $221;
 HEAP32[$222>>2] = $217;
 $223 = (($221) + 4)|0;
 $224 = $223;
 HEAP32[$224>>2] = $220;
 $225 = $__x4;
 $226 = $225;
 HEAP32[$226>>2] = $211;
 $227 = (($225) + 4)|0;
 $228 = $227;
 HEAP32[$228>>2] = $214;
 $229 = (($__r$0$i) + 2)|0;
 $230 = HEAP32[$__c>>2]|0;
 $231 = $__x3;
 $232 = $231;
 $233 = HEAP32[$232>>2]|0;
 $234 = (($231) + 4)|0;
 $235 = $234;
 $236 = HEAP32[$235>>2]|0;
 $237 = $10;
 $238 = $237;
 HEAP32[$238>>2] = $233;
 $239 = (($237) + 4)|0;
 $240 = $239;
 HEAP32[$240>>2] = $236;
 $241 = $__x2;
 $242 = $241;
 $243 = HEAP32[$242>>2]|0;
 $244 = (($241) + 4)|0;
 $245 = $244;
 $246 = HEAP32[$245>>2]|0;
 $247 = $11;
 $248 = $247;
 HEAP32[$248>>2] = $243;
 $249 = (($247) + 4)|0;
 $250 = $249;
 HEAP32[$250>>2] = $246;
 ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$10+4>>2]|0;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$11+4>>2]|0;
 $251 = (FUNCTION_TABLE_iii[$230 & 4095]($tmpcast6$byval_copy,$tmpcast7$byval_copy)|0);
 if (!($251)) {
  $__r$0 = $229;
  STACKTOP = sp;return ($__r$0|0);
 }
 $252 = $__x2;
 $253 = $252;
 $254 = HEAP32[$253>>2]|0;
 $255 = (($252) + 4)|0;
 $256 = $255;
 $257 = HEAP32[$256>>2]|0;
 $258 = $__x3;
 $259 = $258;
 $260 = HEAP32[$259>>2]|0;
 $261 = (($258) + 4)|0;
 $262 = $261;
 $263 = HEAP32[$262>>2]|0;
 $264 = $__x2;
 $265 = $264;
 HEAP32[$265>>2] = $260;
 $266 = (($264) + 4)|0;
 $267 = $266;
 HEAP32[$267>>2] = $263;
 $268 = $__x3;
 $269 = $268;
 HEAP32[$269>>2] = $254;
 $270 = (($268) + 4)|0;
 $271 = $270;
 HEAP32[$271>>2] = $257;
 $272 = (($__r$0$i) + 3)|0;
 $273 = HEAP32[$__c>>2]|0;
 $274 = $__x2;
 $275 = $274;
 $276 = HEAP32[$275>>2]|0;
 $277 = (($274) + 4)|0;
 $278 = $277;
 $279 = HEAP32[$278>>2]|0;
 $280 = $12;
 $281 = $280;
 HEAP32[$281>>2] = $276;
 $282 = (($280) + 4)|0;
 $283 = $282;
 HEAP32[$283>>2] = $279;
 $284 = $__x1;
 $285 = $284;
 $286 = HEAP32[$285>>2]|0;
 $287 = (($284) + 4)|0;
 $288 = $287;
 $289 = HEAP32[$288>>2]|0;
 $290 = $13;
 $291 = $290;
 HEAP32[$291>>2] = $286;
 $292 = (($290) + 4)|0;
 $293 = $292;
 HEAP32[$293>>2] = $289;
 ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$12+4>>2]|0;
 ;HEAP32[$tmpcast7$byval_copy+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$tmpcast7$byval_copy+4>>2]=HEAP32[$13+4>>2]|0;
 $294 = (FUNCTION_TABLE_iii[$273 & 4095]($tmpcast6$byval_copy,$tmpcast7$byval_copy)|0);
 if (!($294)) {
  $__r$0 = $272;
  STACKTOP = sp;return ($__r$0|0);
 }
 $295 = $__x1;
 $296 = $295;
 $297 = HEAP32[$296>>2]|0;
 $298 = (($295) + 4)|0;
 $299 = $298;
 $300 = HEAP32[$299>>2]|0;
 $301 = $__x2;
 $302 = $301;
 $303 = HEAP32[$302>>2]|0;
 $304 = (($301) + 4)|0;
 $305 = $304;
 $306 = HEAP32[$305>>2]|0;
 $307 = $__x1;
 $308 = $307;
 HEAP32[$308>>2] = $303;
 $309 = (($307) + 4)|0;
 $310 = $309;
 HEAP32[$310>>2] = $306;
 $311 = $__x2;
 $312 = $311;
 HEAP32[$312>>2] = $297;
 $313 = (($311) + 4)|0;
 $314 = $313;
 HEAP32[$314>>2] = $300;
 $315 = (($__r$0$i) + 4)|0;
 $__r$0 = $315;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEbT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$09 = 0;
 var $__count$1 = 0, $__i$010 = 0, $__j$08 = 0, $__j$08$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $tmpcast5$byval_copy = 0, $tmpcast6$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $tmpcast6$byval_copy = sp + 96|0;
 $tmpcast5$byval_copy = sp + 104|0;
 $0 = sp + 88|0;
 $1 = sp + 80|0;
 $2 = sp + 72|0;
 $3 = sp + 64|0;
 $4 = sp + 56|0;
 $5 = sp + 48|0;
 $6 = sp + 32|0;
 $7 = sp + 24|0;
 $8 = sp + 16|0;
 $9 = sp + 8|0;
 $10 = sp;
 $11 = sp + 40|0;
 $12 = $__last;
 $13 = $__first;
 $14 = (($12) - ($13))|0;
 $15 = $14 >> 3;
 switch ($15|0) {
 case 4:  {
  $61 = (($__first) + 8|0);
  $62 = (($__first) + 16|0);
  $63 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($__first,$61,$62,$__comp)|0);
  $64 = HEAP32[$__comp>>2]|0;
  $65 = $63;
  $66 = $65;
  $67 = HEAP32[$66>>2]|0;
  $68 = (($65) + 4)|0;
  $69 = $68;
  $70 = HEAP32[$69>>2]|0;
  $71 = $0;
  $72 = $71;
  HEAP32[$72>>2] = $67;
  $73 = (($71) + 4)|0;
  $74 = $73;
  HEAP32[$74>>2] = $70;
  $75 = $62;
  $76 = $75;
  $77 = HEAP32[$76>>2]|0;
  $78 = (($75) + 4)|0;
  $79 = $78;
  $80 = HEAP32[$79>>2]|0;
  $81 = $1;
  $82 = $81;
  HEAP32[$82>>2] = $77;
  $83 = (($81) + 4)|0;
  $84 = $83;
  HEAP32[$84>>2] = $80;
  ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
  $85 = (FUNCTION_TABLE_iii[$64 & 4095]($tmpcast5$byval_copy,$tmpcast6$byval_copy)|0);
  if (!($85)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $86 = $62;
  $87 = $86;
  $88 = HEAP32[$87>>2]|0;
  $89 = (($86) + 4)|0;
  $90 = $89;
  $91 = HEAP32[$90>>2]|0;
  $92 = $63;
  $93 = $92;
  $94 = HEAP32[$93>>2]|0;
  $95 = (($92) + 4)|0;
  $96 = $95;
  $97 = HEAP32[$96>>2]|0;
  $98 = $62;
  $99 = $98;
  HEAP32[$99>>2] = $94;
  $100 = (($98) + 4)|0;
  $101 = $100;
  HEAP32[$101>>2] = $97;
  $102 = $63;
  $103 = $102;
  HEAP32[$103>>2] = $88;
  $104 = (($102) + 4)|0;
  $105 = $104;
  HEAP32[$105>>2] = $91;
  $106 = HEAP32[$__comp>>2]|0;
  $107 = $62;
  $108 = $107;
  $109 = HEAP32[$108>>2]|0;
  $110 = (($107) + 4)|0;
  $111 = $110;
  $112 = HEAP32[$111>>2]|0;
  $113 = $2;
  $114 = $113;
  HEAP32[$114>>2] = $109;
  $115 = (($113) + 4)|0;
  $116 = $115;
  HEAP32[$116>>2] = $112;
  $117 = $61;
  $118 = $117;
  $119 = HEAP32[$118>>2]|0;
  $120 = (($117) + 4)|0;
  $121 = $120;
  $122 = HEAP32[$121>>2]|0;
  $123 = $3;
  $124 = $123;
  HEAP32[$124>>2] = $119;
  $125 = (($123) + 4)|0;
  $126 = $125;
  HEAP32[$126>>2] = $122;
  ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
  ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
  $127 = (FUNCTION_TABLE_iii[$106 & 4095]($tmpcast5$byval_copy,$tmpcast6$byval_copy)|0);
  if (!($127)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $128 = $61;
  $129 = $128;
  $130 = HEAP32[$129>>2]|0;
  $131 = (($128) + 4)|0;
  $132 = $131;
  $133 = HEAP32[$132>>2]|0;
  $134 = $62;
  $135 = $134;
  $136 = HEAP32[$135>>2]|0;
  $137 = (($134) + 4)|0;
  $138 = $137;
  $139 = HEAP32[$138>>2]|0;
  $140 = $61;
  $141 = $140;
  HEAP32[$141>>2] = $136;
  $142 = (($140) + 4)|0;
  $143 = $142;
  HEAP32[$143>>2] = $139;
  $144 = $62;
  $145 = $144;
  HEAP32[$145>>2] = $130;
  $146 = (($144) + 4)|0;
  $147 = $146;
  HEAP32[$147>>2] = $133;
  $148 = HEAP32[$__comp>>2]|0;
  $149 = $4;
  $150 = $149;
  HEAP32[$150>>2] = $136;
  $151 = (($149) + 4)|0;
  $152 = $151;
  HEAP32[$152>>2] = $139;
  $153 = $__first;
  $154 = $153;
  $155 = HEAP32[$154>>2]|0;
  $156 = (($153) + 4)|0;
  $157 = $156;
  $158 = HEAP32[$157>>2]|0;
  $159 = $5;
  $160 = $159;
  HEAP32[$160>>2] = $155;
  $161 = (($159) + 4)|0;
  $162 = $161;
  HEAP32[$162>>2] = $158;
  ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
  ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
  $163 = (FUNCTION_TABLE_iii[$148 & 4095]($tmpcast5$byval_copy,$tmpcast6$byval_copy)|0);
  if (!($163)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $164 = $__first;
  $165 = $164;
  $166 = HEAP32[$165>>2]|0;
  $167 = (($164) + 4)|0;
  $168 = $167;
  $169 = HEAP32[$168>>2]|0;
  $170 = $61;
  $171 = $170;
  $172 = HEAP32[$171>>2]|0;
  $173 = (($170) + 4)|0;
  $174 = $173;
  $175 = HEAP32[$174>>2]|0;
  $176 = $__first;
  $177 = $176;
  HEAP32[$177>>2] = $172;
  $178 = (($176) + 4)|0;
  $179 = $178;
  HEAP32[$179>>2] = $175;
  $180 = $61;
  $181 = $180;
  HEAP32[$181>>2] = $166;
  $182 = (($180) + 4)|0;
  $183 = $182;
  HEAP32[$183>>2] = $169;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $184 = (($__first) + 8|0);
  $185 = (($__first) + 16|0);
  $186 = (($__first) + 24|0);
  $187 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_S8_S8_T_($__first,$184,$185,$186,$187,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $59 = (($__first) + 8|0);
  $60 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($__first,$59,$60,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $16 = HEAP32[$__comp>>2]|0;
  $17 = (($__last) + -8|0);
  $18 = $17;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = (($18) + 4)|0;
  $22 = $21;
  $23 = HEAP32[$22>>2]|0;
  $24 = $6;
  $25 = $24;
  HEAP32[$25>>2] = $20;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $23;
  $28 = $__first;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 4)|0;
  $32 = $31;
  $33 = HEAP32[$32>>2]|0;
  $34 = $7;
  $35 = $34;
  HEAP32[$35>>2] = $30;
  $36 = (($34) + 4)|0;
  $37 = $36;
  HEAP32[$37>>2] = $33;
  ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
  ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
  $38 = (FUNCTION_TABLE_iii[$16 & 4095]($tmpcast5$byval_copy,$tmpcast6$byval_copy)|0);
  if (!($38)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $39 = $__first;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + 4)|0;
  $43 = $42;
  $44 = HEAP32[$43>>2]|0;
  $45 = $17;
  $46 = $45;
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + 4)|0;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = $__first;
  $52 = $51;
  HEAP32[$52>>2] = $47;
  $53 = (($51) + 4)|0;
  $54 = $53;
  HEAP32[$54>>2] = $50;
  $55 = $17;
  $56 = $55;
  HEAP32[$56>>2] = $41;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $44;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $188 = (($__first) + 16|0);
  $189 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRPFbN7mecanim9animation13MuscleIndexIdES3_EPS3_EEjT0_S8_S8_T_($__first,$189,$188,$__comp)|0);
  $190 = (($__first) + 24|0);
  $191 = ($190|0)==($__last|0);
  if ($191) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$09 = 0;$__i$010 = $190;$__j$08 = $188;
  }
  while(1) {
   $192 = HEAP32[$__comp>>2]|0;
   $193 = $__i$010;
   $194 = $193;
   $195 = HEAP32[$194>>2]|0;
   $196 = (($193) + 4)|0;
   $197 = $196;
   $198 = HEAP32[$197>>2]|0;
   $199 = $8;
   $200 = $199;
   HEAP32[$200>>2] = $195;
   $201 = (($199) + 4)|0;
   $202 = $201;
   HEAP32[$202>>2] = $198;
   $203 = $__j$08;
   $204 = $203;
   $205 = HEAP32[$204>>2]|0;
   $206 = (($203) + 4)|0;
   $207 = $206;
   $208 = HEAP32[$207>>2]|0;
   $209 = $9;
   $210 = $209;
   HEAP32[$210>>2] = $205;
   $211 = (($209) + 4)|0;
   $212 = $211;
   HEAP32[$212>>2] = $208;
   ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
   ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
   $213 = (FUNCTION_TABLE_iii[$192 & 4095]($tmpcast5$byval_copy,$tmpcast6$byval_copy)|0);
   if ($213) {
    $214 = $__i$010;
    $215 = $214;
    $216 = HEAP32[$215>>2]|0;
    $217 = (($214) + 4)|0;
    $218 = $217;
    $219 = HEAP32[$218>>2]|0;
    $__j$1 = $__i$010;$__k$0 = $__j$08;
    while(1) {
     $220 = $__k$0;
     $221 = $220;
     $222 = HEAP32[$221>>2]|0;
     $223 = (($220) + 4)|0;
     $224 = $223;
     $225 = HEAP32[$224>>2]|0;
     $226 = $__j$1;
     $227 = $226;
     HEAP32[$227>>2] = $222;
     $228 = (($226) + 4)|0;
     $229 = $228;
     HEAP32[$229>>2] = $225;
     $230 = ($__k$0|0)==($__first|0);
     if ($230) {
      break;
     }
     $231 = HEAP32[$__comp>>2]|0;
     $232 = $10;
     $233 = $232;
     HEAP32[$233>>2] = $216;
     $234 = (($232) + 4)|0;
     $235 = $234;
     HEAP32[$235>>2] = $219;
     $236 = (($__k$0) + -8|0);
     $237 = $236;
     $238 = $237;
     $239 = HEAP32[$238>>2]|0;
     $240 = (($237) + 4)|0;
     $241 = $240;
     $242 = HEAP32[$241>>2]|0;
     $243 = $11;
     $244 = $243;
     HEAP32[$244>>2] = $239;
     $245 = (($243) + 4)|0;
     $246 = $245;
     HEAP32[$246>>2] = $242;
     ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$10+4>>2]|0;
     ;HEAP32[$tmpcast6$byval_copy+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$tmpcast6$byval_copy+4>>2]=HEAP32[$11+4>>2]|0;
     $247 = (FUNCTION_TABLE_iii[$231 & 4095]($tmpcast5$byval_copy,$tmpcast6$byval_copy)|0);
     if ($247) {
      $__j$1$phi = $__k$0;$__k$0 = $236;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $248 = $__k$0;
    $249 = $248;
    HEAP32[$249>>2] = $216;
    $250 = (($248) + 4)|0;
    $251 = $250;
    HEAP32[$251>>2] = $219;
    $252 = (($__count$09) + 1)|0;
    $253 = ($252|0)==(8);
    if ($253) {
     break;
    } else {
     $__count$1 = $252;
    }
   } else {
    $__count$1 = $__count$09;
   }
   $256 = (($__i$010) + 8|0);
   $257 = ($256|0)==($__last|0);
   if ($257) {
    $$0 = 1;
    label = 18;
    break;
   } else {
    $__j$08$phi = $__i$010;$__count$09 = $__count$1;$__i$010 = $256;$__j$08 = $__j$08$phi;
   }
  }
  if ((label|0) == 18) {
   STACKTOP = sp;return ($$0|0);
  }
  $254 = (($__i$010) + 8|0);
  $255 = ($254|0)==($__last|0);
  $$0 = $255;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __GLOBAL__I_a18997() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 775176;
 while(1) {
  HEAP8[$0>>0] = 0;
  $1 = (($0) + 128|0);
  $2 = ($1|0)==(((775176 + 17536|0))|0);
  if ($2) {
   break;
  } else {
   $0 = $1;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation29GetWeightsFreeformDirectionalERKNS0_19Blend2dDataConstantEPfPiP8Vector2fffb($blendConstant,$weightArray,$cropArray,$workspaceBlendVectors,$blendValueX,$blendValueY,$preCompute) {
 $blendConstant = $blendConstant|0;
 $weightArray = $weightArray|0;
 $cropArray = $cropArray|0;
 $workspaceBlendVectors = $workspaceBlendVectors|0;
 $blendValueX = Math_fround($blendValueX);
 $blendValueY = Math_fround($blendValueY);
 $preCompute = $preCompute|0;
 var $$ = Math_fround(0), $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0;
 var $132 = 0, $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0);
 var $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0;
 var $240 = Math_fround(0), $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0, $275 = 0, $276 = Math_fround(0);
 var $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0;
 var $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $angle$0 = Math_fround(0);
 var $brmerge = 0, $exitcond65 = 0, $exitcond66 = 0, $exitcond67 = 0, $exitcond69 = 0, $exitcond70 = 0, $exitcond71 = 0, $exitcond72 = 0, $i$058 = 0, $i1$061 = 0, $i2$032$us = 0, $i3$053 = 0, $i7$044 = 0, $i8$037 = 0, $i9$040 = 0, $ispos = 0, $ispos2$us = 0, $j$028$us = 0, $jIndex$046 = 0, $neg = 0;
 var $neg3$us = 0, $or$cond = 0, $or$cond25$us = 0, $or$cond27 = 0, $or$cond75 = 0, $summedWeight$043 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($blendConstant) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($blendConstant) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$blendConstant>>2]|0;
 $7 = (($blendConstant) + 16|0);
 $8 = $7;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = (($blendConstant) + 20|0);
 HEAP32[$12>>2] = $11;
 $13 = (($blendConstant) + 52|0);
 $14 = $13;
 $15 = HEAP32[$13>>2]|0;
 $16 = (($15) + ($14))|0;
 $17 = $16;
 $18 = (($blendConstant) + 56|0);
 HEAP32[$18>>2] = $17;
 $19 = Math_fround($blendValueX * $blendValueX);
 $20 = Math_fround($blendValueY * $blendValueY);
 $21 = Math_fround($19 + $20);
 $22 = (Math_fround(Math_sqrt((Math_fround($21)))));
 $23 = Math_fround(HEAPF32[616640>>2]);
 $24 = $23 == $blendValueX;
 $25 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
 $26 = $25 == $blendValueY;
 $or$cond = $24 & $26;
 $27 = ($6|0)==(0);
 L1: do {
  if ($or$cond) {
   if (!($27)) {
    $i$058 = 0;
    while(1) {
     $28 = (($workspaceBlendVectors) + ($i$058<<3)|0);
     $29 = (($11) + ($i$058<<2)|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     $31 = Math_fround($22 - $30);
     $32 = (HEAPF32[tempDoublePtr>>2]=$31,HEAP32[tempDoublePtr>>2]|0);
     $33 = $28;
     $34 = $33;
     HEAP32[$34>>2] = 0;
     $35 = (($33) + 4)|0;
     $36 = $35;
     HEAP32[$36>>2] = $32;
     $37 = (($i$058) + 1)|0;
     $exitcond70 = ($37|0)==($6|0);
     if ($exitcond70) {
      break;
     } else {
      $i$058 = $37;
     }
    }
   }
  } else {
   if (!($27)) {
    $41 = $23;$i1$061 = 0;
    while(1) {
     $38 = (($4) + ($i1$061<<3)|0);
     $39 = Math_fround(HEAPF32[$38>>2]);
     $40 = $39 == $41;
     $42 = ((($4) + ($i1$061<<3)|0) + 4|0);
     $43 = Math_fround(HEAPF32[$42>>2]);
     $44 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
     $45 = $43 == $44;
     $or$cond75 = $40 & $45;
     if ($or$cond75) {
      $46 = (($workspaceBlendVectors) + ($i1$061<<3)|0);
      $47 = (($11) + ($i1$061<<2)|0);
      $48 = Math_fround(HEAPF32[$47>>2]);
      $49 = Math_fround($22 - $48);
      $50 = (HEAPF32[tempDoublePtr>>2]=$49,HEAP32[tempDoublePtr>>2]|0);
      $51 = $46;
      $52 = $51;
      HEAP32[$52>>2] = 0;
      $53 = (($51) + 4)|0;
      $54 = $53;
      HEAP32[$54>>2] = $50;
     } else {
      $55 = Math_fround($39 * $blendValueX);
      $56 = Math_fround($43 * $blendValueY);
      $57 = Math_fround($55 + $56);
      $58 = Math_fround($39 * $39);
      $59 = Math_fround($43 * $43);
      $60 = Math_fround($58 + $59);
      $61 = (Math_fround(Math_sqrt((Math_fround($60)))));
      $62 = Math_fround($22 * $61);
      $63 = Math_fround($57 / $62);
      $64 = $63 > Math_fround(-1.0);
      $65 = $64 ? $63 : Math_fround(-1.0);
      $66 = $65 < Math_fround(1.0);
      $67 = $66 ? $65 : Math_fround(1.0);
      $68 = (Math_fround(+(Math_acos((+$67)))));
      $69 = Math_fround($39 * $blendValueY);
      $70 = Math_fround($43 * $blendValueX);
      $71 = Math_fround($69 - $70);
      $72 = $71 < Math_fround(0.0);
      if ($72) {
       $73 = Math_fround(-$68);
       $angle$0 = $73;
      } else {
       $angle$0 = $68;
      }
      $74 = (($workspaceBlendVectors) + ($i1$061<<3)|0);
      $75 = (($11) + ($i1$061<<2)|0);
      $76 = Math_fround(HEAPF32[$75>>2]);
      $77 = Math_fround($22 - $76);
      $78 = (HEAPF32[tempDoublePtr>>2]=$angle$0,HEAP32[tempDoublePtr>>2]|0);
      $79 = (HEAPF32[tempDoublePtr>>2]=$77,HEAP32[tempDoublePtr>>2]|0);
      $80 = $74;
      $81 = $80;
      HEAP32[$81>>2] = $78;
      $82 = (($80) + 4)|0;
      $83 = $82;
      HEAP32[$83>>2] = $79;
     }
     $84 = (($i1$061) + 1)|0;
     $exitcond71 = ($84|0)==($6|0);
     if ($exitcond71) {
      break L1;
     }
     $$pre = Math_fround(HEAPF32[616640>>2]);
     $41 = $$pre;$i1$061 = $84;
    }
   }
  }
 } while(0);
 $85 = ($6|0)==(0);
 if ($preCompute) {
  if ($85) {
   STACKTOP = sp;return;
  }
  $90 = (($blendConstant) + 28|0);
  $91 = $90;
  $92 = (($blendConstant) + 40|0);
  $93 = $92;
  $i2$032$us = 0;
  while(1) {
   $167 = (($workspaceBlendVectors) + ($i2$032$us<<3)|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = (~~(($168)));
   $160 = (($cropArray) + ($i2$032$us<<2)|0);
   HEAP32[$160>>2] = -1;
   $neg3$us = (0 - ($169))|0;
   $ispos2$us = ($169|0)>(-1);
   $170 = $ispos2$us ? $169 : $neg3$us;
   $171 = (Math_fround(($170|0)));
   $172 = Math_fround($171 * Math_fround(0.318309873342514038086));
   $173 = Math_fround(Math_fround(1.0) - $172);
   $111 = (($workspaceBlendVectors) + ($i2$032$us<<3)|0);
   $163 = $173;$j$028$us = 0;
   while(1) {
    $94 = ($i2$032$us|0)==($j$028$us|0);
    if ($94) {
     $276 = $163;
    } else {
     $95 = HEAP32[$blendConstant>>2]|0;
     $96 = Math_imul($95, $j$028$us)|0;
     $97 = (($96) + ($i2$032$us))|0;
     $98 = HEAP32[$90>>2]|0;
     $99 = (($98) + ($91))|0;
     $100 = $99;
     $101 = (($100) + ($97<<3)|0);
     $102 = $101;
     $103 = $102;
     $104 = HEAP32[$103>>2]|0;
     $105 = (($102) + 4)|0;
     $106 = $105;
     $107 = HEAP32[$106>>2]|0;
     $108 = (HEAP32[tempDoublePtr>>2]=$104,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $109 = (HEAP32[tempDoublePtr>>2]=$107,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $110 = $111;
     $112 = $110;
     $113 = HEAP32[$112>>2]|0;
     $114 = (($110) + 4)|0;
     $115 = $114;
     $116 = HEAP32[$115>>2]|0;
     $117 = (HEAP32[tempDoublePtr>>2]=$113,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $118 = (HEAP32[tempDoublePtr>>2]=$116,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $119 = HEAP32[$92>>2]|0;
     $120 = (($119) + ($93))|0;
     $121 = $120;
     $122 = (($121) + ($97<<2)|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     $124 = Math_fround($123 * $118);
     $125 = HEAP32[$0>>2]|0;
     $126 = (($125) + ($1))|0;
     $127 = $126;
     $128 = (($127) + ($i2$032$us<<3)|0);
     $129 = Math_fround(HEAPF32[$128>>2]);
     $130 = Math_fround(HEAPF32[616640>>2]);
     $131 = $129 == $130;
     if ($131) {
      $132 = ((($127) + ($i2$032$us<<3)|0) + 4|0);
      $133 = Math_fround(HEAPF32[$132>>2]);
      $134 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
      $135 = $133 == $134;
      if ($135) {
       $147 = (($workspaceBlendVectors) + ($j$028$us<<3)|0);
       $148 = Math_fround(HEAPF32[$147>>2]);
       $150 = $117;$151 = $148;
      } else {
       label = 20;
      }
     } else {
      label = 20;
     }
     do {
      if ((label|0) == 20) {
       label = 0;
       $136 = (($127) + ($j$028$us<<3)|0);
       $137 = Math_fround(HEAPF32[$136>>2]);
       $138 = $137 == $130;
       if ($138) {
        $139 = ((($127) + ($j$028$us<<3)|0) + 4|0);
        $140 = Math_fround(HEAPF32[$139>>2]);
        $141 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
        $142 = $140 == $141;
        if ($142) {
         $150 = $117;$151 = $117;
         break;
        }
       }
       $143 = $108 == Math_fround(0.0);
       if (!($143)) {
        $144 = $130 == $blendValueX;
        $145 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
        $146 = $145 == $blendValueY;
        $or$cond25$us = $144 & $146;
        if (!($or$cond25$us)) {
         $150 = $117;$151 = $108;
         break;
        }
       }
       $150 = $108;$151 = $108;
      }
     } while(0);
     $149 = Math_fround($151 * $150);
     $152 = Math_fround($109 * $124);
     $153 = Math_fround($152 + $149);
     $154 = Math_fround($151 * $151);
     $155 = Math_fround($109 * $109);
     $156 = Math_fround($155 + $154);
     $157 = Math_fround($153 / $156);
     $158 = Math_fround(Math_fround(1.0) - $157);
     $159 = !($158 <= Math_fround(0.0));
     if (!($159)) {
      label = 27;
      break;
     }
     $162 = $158 < $163;
     if ($162) {
      HEAP32[$160>>2] = $j$028$us;
     }
     $164 = $162 ? $158 : $163;
     $276 = $164;
    }
    $165 = (($j$028$us) + 1)|0;
    $166 = ($165>>>0)<($6>>>0);
    if ($166) {
     $163 = $276;$j$028$us = $165;
    } else {
     break;
    }
   }
   if ((label|0) == 27) {
    label = 0;
    HEAP32[$160>>2] = -1;
   }
   $161 = (($i2$032$us) + 1)|0;
   $exitcond72 = ($161|0)==($6|0);
   if ($exitcond72) {
    break;
   } else {
    $i2$032$us = $161;
   }
  }
  STACKTOP = sp;return;
 }
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = (($blendConstant) + 28|0);
 $87 = $86;
 $88 = (($blendConstant) + 40|0);
 $89 = $88;
 $i3$053 = 0;
 while(1) {
  $174 = (($workspaceBlendVectors) + ($i3$053<<3)|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = (~~(($175)));
  $ispos = ($176|0)>(-1);
  $neg = (0 - ($176))|0;
  $177 = $ispos ? $176 : $neg;
  $178 = (Math_fround(($177|0)));
  $179 = Math_fround($178 * Math_fround(0.318309873342514038086));
  $180 = Math_fround(Math_fround(1.0) - $179);
  $181 = (($17) + (($i3$053*12)|0)|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = ($182|0)==(0);
  L55: do {
   if ($183) {
    $260 = $180;
   } else {
    $184 = ((($17) + (($i3$053*12)|0)|0) + 4|0);
    $185 = $184;
    $186 = HEAP32[$184>>2]|0;
    $187 = (($186) + ($185))|0;
    $188 = $187;
    $189 = HEAP32[$blendConstant>>2]|0;
    $190 = HEAP32[$86>>2]|0;
    $191 = (($190) + ($87))|0;
    $192 = $191;
    $193 = (($workspaceBlendVectors) + ($i3$053<<3)|0);
    $194 = $193;
    $195 = $194;
    $196 = HEAP32[$195>>2]|0;
    $197 = (($194) + 4)|0;
    $198 = $197;
    $199 = HEAP32[$198>>2]|0;
    $200 = (HEAP32[tempDoublePtr>>2]=$196,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $201 = (HEAP32[tempDoublePtr>>2]=$199,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $202 = HEAP32[$88>>2]|0;
    $203 = (($202) + ($89))|0;
    $204 = $203;
    $205 = HEAP32[$0>>2]|0;
    $206 = (($205) + ($1))|0;
    $207 = $206;
    $208 = (($207) + ($i3$053<<3)|0);
    $209 = Math_fround(HEAPF32[$208>>2]);
    $210 = Math_fround(HEAPF32[616640>>2]);
    $211 = $209 == $210;
    $212 = ((($207) + ($i3$053<<3)|0) + 4|0);
    $213 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
    $214 = $210 == $blendValueX;
    $215 = $213 == $blendValueY;
    $or$cond27 = $214 & $215;
    $255 = $180;$jIndex$046 = 0;
    while(1) {
     $216 = (($188) + ($jIndex$046<<2)|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = Math_imul($189, $217)|0;
     $219 = (($218) + ($i3$053))|0;
     $220 = (($192) + ($219<<3)|0);
     $221 = $220;
     $222 = $221;
     $223 = HEAP32[$222>>2]|0;
     $224 = (($221) + 4)|0;
     $225 = $224;
     $226 = HEAP32[$225>>2]|0;
     $227 = (HEAP32[tempDoublePtr>>2]=$223,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $228 = (HEAP32[tempDoublePtr>>2]=$226,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $229 = (($204) + ($219<<2)|0);
     $230 = Math_fround(HEAPF32[$229>>2]);
     $231 = Math_fround($230 * $201);
     if ($211) {
      $232 = Math_fround(HEAPF32[$212>>2]);
      $233 = $232 == $213;
      if ($233) {
       $234 = (($workspaceBlendVectors) + ($217<<3)|0);
       $235 = Math_fround(HEAPF32[$234>>2]);
       $244 = $200;$245 = $235;
      } else {
       label = 40;
      }
     } else {
      label = 40;
     }
     do {
      if ((label|0) == 40) {
       label = 0;
       $236 = (($207) + ($217<<3)|0);
       $237 = Math_fround(HEAPF32[$236>>2]);
       $238 = $237 == $210;
       if ($238) {
        $239 = ((($207) + ($217<<3)|0) + 4|0);
        $240 = Math_fround(HEAPF32[$239>>2]);
        $241 = $240 == $213;
        if ($241) {
         $244 = $200;$245 = $200;
         break;
        }
       }
       $242 = $227 == Math_fround(0.0);
       $brmerge = $242 | $or$cond27;
       $$ = $brmerge ? $227 : $200;
       $244 = $$;$245 = $227;
      }
     } while(0);
     $243 = Math_fround($245 * $244);
     $246 = Math_fround($228 * $231);
     $247 = Math_fround($246 + $243);
     $248 = Math_fround($245 * $245);
     $249 = Math_fround($228 * $228);
     $250 = Math_fround($249 + $248);
     $251 = Math_fround($247 / $250);
     $252 = Math_fround(Math_fround(1.0) - $251);
     $253 = !($252 <= Math_fround(0.0));
     if (!($253)) {
      $260 = Math_fround(0.0);
      break L55;
     }
     $254 = $252 < $255;
     $256 = $254 ? $252 : $255;
     $257 = (($jIndex$046) + 1)|0;
     $258 = ($257>>>0)<($182>>>0);
     if ($258) {
      $255 = $256;$jIndex$046 = $257;
     } else {
      $260 = $256;
      break;
     }
    }
   }
  } while(0);
  $259 = (($weightArray) + ($i3$053<<2)|0);
  HEAPF32[$259>>2] = $260;
  $261 = (($i3$053) + 1)|0;
  $exitcond69 = ($261|0)==($6|0);
  if ($exitcond69) {
   break;
  } else {
   $i3$053 = $261;
  }
 }
 if ($85) {
  STACKTOP = sp;return;
 } else {
  $i7$044 = 0;$summedWeight$043 = Math_fround(0.0);
 }
 while(1) {
  $262 = (($weightArray) + ($i7$044<<2)|0);
  $263 = Math_fround(HEAPF32[$262>>2]);
  $264 = Math_fround($summedWeight$043 + $263);
  $265 = (($i7$044) + 1)|0;
  $exitcond67 = ($265|0)==($6|0);
  if ($exitcond67) {
   break;
  } else {
   $i7$044 = $265;$summedWeight$043 = $264;
  }
 }
 $266 = $264 > Math_fround(0.0);
 if ($266) {
  $267 = Math_fround(Math_fround(1.0) / $264);
  if ($85) {
   STACKTOP = sp;return;
  } else {
   $i8$037 = 0;
  }
  while(1) {
   $268 = (($weightArray) + ($i8$037<<2)|0);
   $269 = Math_fround(HEAPF32[$268>>2]);
   $270 = Math_fround($267 * $269);
   HEAPF32[$268>>2] = $270;
   $271 = (($i8$037) + 1)|0;
   $exitcond65 = ($271|0)==($6|0);
   if ($exitcond65) {
    break;
   } else {
    $i8$037 = $271;
   }
  }
  STACKTOP = sp;return;
 } else {
  $272 = (Math_fround(($6>>>0)));
  $273 = Math_fround(Math_fround(1.0) / $272);
  if ($85) {
   STACKTOP = sp;return;
  } else {
   $i9$040 = 0;
  }
  while(1) {
   $274 = (($weightArray) + ($i9$040<<2)|0);
   HEAPF32[$274>>2] = $273;
   $275 = (($i9$040) + 1)|0;
   $exitcond66 = ($275|0)==($6|0);
   if ($exitcond66) {
    break;
   } else {
    $i9$040 = $275;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim9animation27GetWeightsFreeformCartesianERKNS0_19Blend2dDataConstantEPfPiP8Vector2fffb($blendConstant,$weightArray,$cropArray,$workspaceBlendVectors,$blendValueX,$blendValueY,$preCompute) {
 $blendConstant = $blendConstant|0;
 $weightArray = $weightArray|0;
 $cropArray = $cropArray|0;
 $workspaceBlendVectors = $workspaceBlendVectors|0;
 $blendValueX = Math_fround($blendValueX);
 $blendValueY = Math_fround($blendValueY);
 $preCompute = $preCompute|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond33 = 0, $exitcond34 = 0, $exitcond36 = 0, $exitcond37 = 0, $i$028 = 0, $i1$07 = 0, $i10$012 = 0, $i2$025 = 0, $i9$016 = 0, $j$05 = 0, $jIndex$018 = 0, $summedWeight$015 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($blendConstant) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($blendConstant) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$blendConstant>>2]|0;
 $7 = (($blendConstant) + 52|0);
 $8 = $7;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = (($blendConstant) + 56|0);
 HEAP32[$12>>2] = $11;
 $13 = ($6|0)==(0);
 if (!($13)) {
  $i$028 = 0;
  while(1) {
   $14 = (($workspaceBlendVectors) + ($i$028<<3)|0);
   $15 = (($4) + ($i$028<<3)|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = Math_fround($blendValueX - $16);
   $18 = ((($4) + ($i$028<<3)|0) + 4|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   $20 = Math_fround($blendValueY - $19);
   $21 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
   $22 = (HEAPF32[tempDoublePtr>>2]=$20,HEAP32[tempDoublePtr>>2]|0);
   $23 = $14;
   $24 = $23;
   HEAP32[$24>>2] = $21;
   $25 = (($23) + 4)|0;
   $26 = $25;
   HEAP32[$26>>2] = $22;
   $27 = (($i$028) + 1)|0;
   $exitcond37 = ($27|0)==($6|0);
   if ($exitcond37) {
    break;
   } else {
    $i$028 = $27;
   }
  }
 }
 if ($preCompute) {
  if ($13) {
   STACKTOP = sp;return;
  }
  $32 = (($blendConstant) + 28|0);
  $33 = $32;
  $34 = (($blendConstant) + 40|0);
  $35 = $34;
  $i1$07 = 0;
  while(1) {
   $36 = (($cropArray) + ($i1$07<<2)|0);
   HEAP32[$36>>2] = -1;
   $37 = (($workspaceBlendVectors) + ($i1$07<<3)|0);
   $38 = $37;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = (($38) + 4)|0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (HEAP32[tempDoublePtr>>2]=$40,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $45 = (HEAP32[tempDoublePtr>>2]=$43,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $74 = Math_fround(1.0);$j$05 = 0;
   while(1) {
    $46 = ($i1$07|0)==($j$05|0);
    if ($46) {
     $142 = $74;
    } else {
     $47 = HEAP32[$blendConstant>>2]|0;
     $48 = Math_imul($47, $j$05)|0;
     $49 = (($48) + ($i1$07))|0;
     $50 = HEAP32[$32>>2]|0;
     $51 = (($50) + ($33))|0;
     $52 = $51;
     $53 = (($52) + ($49<<3)|0);
     $54 = $53;
     $55 = $54;
     $56 = HEAP32[$55>>2]|0;
     $57 = (($54) + 4)|0;
     $58 = $57;
     $59 = HEAP32[$58>>2]|0;
     $60 = (HEAP32[tempDoublePtr>>2]=$56,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $61 = (HEAP32[tempDoublePtr>>2]=$59,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $62 = Math_fround($44 * $60);
     $63 = Math_fround($45 * $61);
     $64 = Math_fround($62 + $63);
     $65 = HEAP32[$34>>2]|0;
     $66 = (($65) + ($35))|0;
     $67 = $66;
     $68 = (($67) + ($49<<2)|0);
     $69 = Math_fround(HEAPF32[$68>>2]);
     $70 = Math_fround($69 * $64);
     $71 = Math_fround(Math_fround(1.0) - $70);
     $72 = !($71 <= Math_fround(0.0));
     if (!($72)) {
      label = 11;
      break;
     }
     $73 = $71 < $74;
     if ($73) {
      HEAP32[$36>>2] = $j$05;
     }
     $75 = $73 ? $71 : $74;
     $142 = $75;
    }
    $76 = (($j$05) + 1)|0;
    $77 = ($76>>>0)<($6>>>0);
    if ($77) {
     $74 = $142;$j$05 = $76;
    } else {
     break;
    }
   }
   if ((label|0) == 11) {
    label = 0;
    HEAP32[$36>>2] = -1;
   }
   $78 = (($i1$07) + 1)|0;
   $exitcond = ($78|0)==($6|0);
   if ($exitcond) {
    break;
   } else {
    $i1$07 = $78;
   }
  }
  STACKTOP = sp;return;
 }
 if ($13) {
  STACKTOP = sp;return;
 }
 $28 = (($blendConstant) + 28|0);
 $29 = $28;
 $30 = (($blendConstant) + 40|0);
 $31 = $30;
 $i2$025 = 0;
 while(1) {
  $79 = (($workspaceBlendVectors) + ($i2$025<<3)|0);
  $80 = $79;
  $81 = $80;
  $82 = HEAP32[$81>>2]|0;
  $83 = (($80) + 4)|0;
  $84 = $83;
  $85 = HEAP32[$84>>2]|0;
  $86 = (HEAP32[tempDoublePtr>>2]=$82,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $87 = (HEAP32[tempDoublePtr>>2]=$85,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $88 = (($11) + (($i2$025*12)|0)|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($89|0)==(0);
  L31: do {
   if ($90) {
    $131 = Math_fround(1.0);
   } else {
    $91 = ((($11) + (($i2$025*12)|0)|0) + 4|0);
    $92 = $91;
    $93 = HEAP32[$91>>2]|0;
    $94 = (($93) + ($92))|0;
    $95 = $94;
    $126 = Math_fround(1.0);$jIndex$018 = 0;
    while(1) {
     $96 = (($95) + ($jIndex$018<<2)|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = ($i2$025|0)==($97|0);
     if ($98) {
      $143 = $126;
     } else {
      $99 = HEAP32[$blendConstant>>2]|0;
      $100 = Math_imul($99, $97)|0;
      $101 = (($100) + ($i2$025))|0;
      $102 = HEAP32[$28>>2]|0;
      $103 = (($102) + ($29))|0;
      $104 = $103;
      $105 = (($104) + ($101<<3)|0);
      $106 = $105;
      $107 = $106;
      $108 = HEAP32[$107>>2]|0;
      $109 = (($106) + 4)|0;
      $110 = $109;
      $111 = HEAP32[$110>>2]|0;
      $112 = (HEAP32[tempDoublePtr>>2]=$108,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $113 = (HEAP32[tempDoublePtr>>2]=$111,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $114 = Math_fround($86 * $112);
      $115 = Math_fround($87 * $113);
      $116 = Math_fround($114 + $115);
      $117 = HEAP32[$30>>2]|0;
      $118 = (($117) + ($31))|0;
      $119 = $118;
      $120 = (($119) + ($101<<2)|0);
      $121 = Math_fround(HEAPF32[$120>>2]);
      $122 = Math_fround($121 * $116);
      $123 = Math_fround(Math_fround(1.0) - $122);
      $124 = $123 < Math_fround(0.0);
      if ($124) {
       $131 = Math_fround(0.0);
       break L31;
      }
      $125 = $123 < $126;
      $127 = $125 ? $123 : $126;
      $143 = $127;
     }
     $128 = (($jIndex$018) + 1)|0;
     $129 = ($128>>>0)<($89>>>0);
     if ($129) {
      $126 = $143;$jIndex$018 = $128;
     } else {
      $131 = $143;
      break;
     }
    }
   }
  } while(0);
  $130 = (($weightArray) + ($i2$025<<2)|0);
  HEAPF32[$130>>2] = $131;
  $132 = (($i2$025) + 1)|0;
  $exitcond36 = ($132|0)==($6|0);
  if ($exitcond36) {
   break;
  } else {
   $i2$025 = $132;
  }
 }
 if ($13) {
  STACKTOP = sp;return;
 } else {
  $i9$016 = 0;$summedWeight$015 = Math_fround(0.0);
 }
 while(1) {
  $133 = (($weightArray) + ($i9$016<<2)|0);
  $134 = Math_fround(HEAPF32[$133>>2]);
  $135 = Math_fround($summedWeight$015 + $134);
  $136 = (($i9$016) + 1)|0;
  $exitcond34 = ($136|0)==($6|0);
  if ($exitcond34) {
   break;
  } else {
   $i9$016 = $136;$summedWeight$015 = $135;
  }
 }
 $137 = Math_fround(Math_fround(1.0) / $135);
 if ($13) {
  STACKTOP = sp;return;
 } else {
  $i10$012 = 0;
 }
 while(1) {
  $138 = (($weightArray) + ($i10$012<<2)|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = Math_fround($137 * $139);
  HEAPF32[$138>>2] = $140;
  $141 = (($i10$012) + 1)|0;
  $exitcond33 = ($141|0)==($6|0);
  if ($exitcond33) {
   break;
  } else {
   $i10$012 = $141;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation20CreateBlendTreeInputERNS_6memory9AllocatorE($alloc) {
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,8,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
  STACKTOP = sp;return ($5|0);
 }
 $4 = (($2) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = $2;
 STACKTOP = sp;return ($5|0);
}
function __ZN7mecanim9animation21DestroyBlendTreeInputEPNS0_14BlendTreeInputERNS_6memory9AllocatorE($input,$alloc) {
 $input = $input|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($input|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$alloc>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($alloc,$input);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation21CreateBlendTreeOutputEjRNS_6memory9AllocatorE($maxBlendedClip,$alloc) {
 $maxBlendedClip = $maxBlendedClip|0;
 $alloc = $alloc|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,12,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $7 = 0;
 } else {
  $4 = (($2) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($2) + 8|0);
  HEAPF32[$5>>2] = Math_fround(0.0);
  $7 = $2;
 }
 $6 = (($7) + 4|0);
 HEAP32[$6>>2] = $maxBlendedClip;
 $8 = ($maxBlendedClip|0)==(0);
 if ($8) {
  $$0$i = 0;
  HEAP32[$7>>2] = $$0$i;
  STACKTOP = sp;return ($7|0);
 }
 $9 = HEAP32[$alloc>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = ($maxBlendedClip*20)|0;
 $12 = (FUNCTION_TABLE_iiii[$10 & 2047]($alloc,$11,4)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$0$i = 0;
  HEAP32[$7>>2] = $$0$i;
  STACKTOP = sp;return ($7|0);
 }
 $14 = (($12) + (($maxBlendedClip*20)|0)|0);
 $15 = $12;
 while(1) {
  HEAPF32[$15>>2] = Math_fround(0.0);
  $16 = (($15) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($15) + 8|0);
  HEAPF32[$17>>2] = Math_fround(1.0);
  $18 = (($15) + 12|0);
  HEAP8[$18>>0] = 0;
  $19 = (($15) + 16|0);
  HEAPF32[$19>>2] = Math_fround(0.0);
  $20 = (($15) + 20|0);
  $21 = ($20|0)==($14|0);
  if ($21) {
   $$0$i = $12;
   break;
  } else {
   $15 = $20;
  }
 }
 HEAP32[$7>>2] = $$0$i;
 STACKTOP = sp;return ($7|0);
}
function __ZN7mecanim9animation22DestroyBlendTreeOutputEPNS0_15BlendTreeOutputERNS_6memory9AllocatorE($output,$alloc) {
 $output = $output|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($output|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$alloc>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$output>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($alloc,$4);
 $5 = HEAP32[$alloc>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($alloc,$output);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation24CreateBlendTreeWorkspaceEjRNS_6memory9AllocatorE($maxNodeCount,$alloc) {
 $maxNodeCount = $maxNodeCount|0;
 $alloc = $alloc|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,16,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = 0;
 } else {
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;
  $5 = $2;
 }
 $4 = ($maxNodeCount|0)==(0);
 if ($4) {
  HEAP32[$5>>2] = 0;
  $6 = (($5) + 4|0);
  HEAP32[$6>>2] = 0;
  $7 = (($5) + 8|0);
  HEAP32[$7>>2] = 0;
  $$0$i = 0;
  $30 = (($5) + 12|0);
  HEAP32[$30>>2] = $$0$i;
  STACKTOP = sp;return ($5|0);
 }
 $8 = HEAP32[$alloc>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = $maxNodeCount << 2;
 $11 = (FUNCTION_TABLE_iiii[$9 & 2047]($alloc,$10,4)|0);
 HEAP32[$5>>2] = $11;
 $12 = HEAP32[$alloc>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiii[$13 & 2047]($alloc,$10,4)|0);
 $15 = (($5) + 4|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[$alloc>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_iiii[$17 & 2047]($alloc,$10,4)|0);
 $19 = (($5) + 8|0);
 HEAP32[$19>>2] = $18;
 $20 = HEAP32[$alloc>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = $maxNodeCount << 3;
 $23 = (FUNCTION_TABLE_iiii[$21 & 2047]($alloc,$22,4)|0);
 $24 = ($23|0)==(0|0);
 if ($24) {
  $$0$i = 0;
  $30 = (($5) + 12|0);
  HEAP32[$30>>2] = $$0$i;
  STACKTOP = sp;return ($5|0);
 }
 $25 = (($23) + ($maxNodeCount<<3)|0);
 $26 = $23;
 while(1) {
  HEAPF32[$26>>2] = Math_fround(0.0);
  $27 = (($26) + 4|0);
  HEAPF32[$27>>2] = Math_fround(0.0);
  $28 = (($26) + 8|0);
  $29 = ($28|0)==($25|0);
  if ($29) {
   $$0$i = $23;
   break;
  } else {
   $26 = $28;
  }
 }
 $30 = (($5) + 12|0);
 HEAP32[$30>>2] = $$0$i;
 STACKTOP = sp;return ($5|0);
}
function __ZN7mecanim9animation25DestroyBlendTreeWorkspaceEPNS0_18BlendTreeWorkspaceERNS_6memory9AllocatorE($workspace,$alloc) {
 $workspace = $workspace|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($workspace|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$alloc>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$workspace>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($alloc,$4);
 $5 = HEAP32[$alloc>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($workspace) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($alloc,$9);
 $10 = HEAP32[$alloc>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($workspace) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$12 & 4095]($alloc,$14);
 $15 = HEAP32[$alloc>>2]|0;
 $16 = (($15) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($workspace) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_vii[$17 & 4095]($alloc,$19);
 $20 = HEAP32[$alloc>>2]|0;
 $21 = (($20) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vii[$22 & 4095]($alloc,$workspace);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation27GetWeightsSimpleDirectionalERKNS0_19Blend2dDataConstantEPfPiP8Vector2fffb($blendConstant,$weightArray,$cropArray,$workspaceBlendVectors,$blendValueX,$blendValueY,$preCompute) {
 $blendConstant = $blendConstant|0;
 $weightArray = $weightArray|0;
 $cropArray = $cropArray|0;
 $workspaceBlendVectors = $workspaceBlendVectors|0;
 $blendValueX = Math_fround($blendValueX);
 $blendValueY = Math_fround($blendValueY);
 $preCompute = $preCompute|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $bitcast$i$i = Math_fround(0);
 var $centerWeight$0 = Math_fround(0), $centerWeight$1 = Math_fround(0), $exitcond = 0, $exitcond33 = 0, $i1$08 = 0, $i2$06 = 0, $i3$018 = 0, $i5$011 = 0, $indexA$024 = 0, $indexA$1 = 0, $indexB$023 = 0, $indexB$1 = 0, $indexCenter$022 = 0, $indexCenter$1 = 0, $maxDotForNegCross$021 = Math_fround(0), $maxDotForNegCross$1 = Math_fround(0), $maxDotForPosCross$020 = Math_fround(0), $maxDotForPosCross$1 = Math_fround(0), $or$cond = 0, $or$cond37 = 0;
 var $or$cond5 = 0, $wA$0 = Math_fround(0), $wB$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($blendConstant) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($blendConstant) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$blendConstant>>2]|0;
 $7 = ($weightArray|0)==(0|0);
 $8 = ($3|0)==(0);
 $or$cond = $7 | $8;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $9 = ($6|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = $6 << 2;
 _memset(($weightArray|0),0,($10|0))|0;
 $11 = ($6>>>0)<(2);
 if ($11) {
  HEAPF32[$weightArray>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 }
 $12 = Math_fround(HEAPF32[616640>>2]);
 $13 = $12 == $blendValueX;
 $14 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
 $15 = $14 == $blendValueY;
 $or$cond5 = $13 & $15;
 if ($or$cond5) {
  $i1$08 = 0;
  while(1) {
   $16 = (($4) + ($i1$08<<3)|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = $17 == $12;
   if ($18) {
    $19 = ((($4) + ($i1$08<<3)|0) + 4|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = $20 == $14;
    if ($21) {
     label = 8;
     break;
    }
   }
   $23 = (($i1$08) + 1)|0;
   $24 = ($23>>>0)<($6>>>0);
   if ($24) {
    $i1$08 = $23;
   } else {
    break;
   }
  }
  if ((label|0) == 8) {
   $22 = (($weightArray) + ($i1$08<<2)|0);
   HEAPF32[$22>>2] = Math_fround(1.0);
   STACKTOP = sp;return;
  }
  $25 = (Math_fround(($6>>>0)));
  $26 = Math_fround(Math_fround(1.0) / $25);
  if ($9) {
   STACKTOP = sp;return;
  } else {
   $i2$06 = 0;
  }
  while(1) {
   $27 = (($weightArray) + ($i2$06<<2)|0);
   HEAPF32[$27>>2] = $26;
   $28 = (($i2$06) + 1)|0;
   $exitcond = ($28|0)==($6|0);
   if ($exitcond) {
    break;
   } else {
    $i2$06 = $28;
   }
  }
  STACKTOP = sp;return;
 } else {
  $i3$018 = 0;$indexA$024 = -1;$indexB$023 = -1;$indexCenter$022 = -1;$maxDotForNegCross$021 = Math_fround(-1.0E+5);$maxDotForPosCross$020 = Math_fround(-1.0E+5);
 }
 L26: while(1) {
  $29 = (($4) + ($i3$018<<3)|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = $30 == $12;
  $32 = ((($4) + ($i3$018<<3)|0) + 4|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = $33 == $14;
  $or$cond37 = $31 & $34;
  do {
   if ($or$cond37) {
    $35 = ($indexCenter$022|0)>(-1);
    if ($35) {
     label = 31;
     break L26;
    } else {
     $indexA$1 = $indexA$024;$indexB$1 = $indexB$023;$indexCenter$1 = $i3$018;$maxDotForNegCross$1 = $maxDotForNegCross$021;$maxDotForPosCross$1 = $maxDotForPosCross$020;
    }
   } else {
    $36 = Math_fround($30 * $30);
    $37 = Math_fround($33 * $33);
    $38 = Math_fround($36 + $37);
    $39 = (Math_fround(Math_sqrt((Math_fround($38)))));
    $40 = $29;
    $41 = $40;
    $42 = HEAP32[$41>>2]|0;
    $43 = (($40) + 4)|0;
    $44 = $43;
    $45 = HEAP32[$44>>2]|0;
    $bitcast$i$i = (HEAP32[tempDoublePtr>>2]=$42,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $46 = Math_fround($bitcast$i$i / $39);
    $47 = (HEAP32[tempDoublePtr>>2]=$45,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $48 = Math_fround($47 / $39);
    $49 = Math_fround($46 * $blendValueX);
    $50 = Math_fround($48 * $blendValueY);
    $51 = Math_fround($49 + $50);
    $52 = Math_fround($46 * $blendValueY);
    $53 = Math_fround($48 * $blendValueX);
    $54 = Math_fround($52 - $53);
    $55 = $54 > Math_fround(0.0);
    if ($55) {
     $56 = $51 > $maxDotForPosCross$020;
     if (!($56)) {
      $indexA$1 = $indexA$024;$indexB$1 = $indexB$023;$indexCenter$1 = $indexCenter$022;$maxDotForNegCross$1 = $maxDotForNegCross$021;$maxDotForPosCross$1 = $maxDotForPosCross$020;
      break;
     }
     $indexA$1 = $i3$018;$indexB$1 = $indexB$023;$indexCenter$1 = $indexCenter$022;$maxDotForNegCross$1 = $maxDotForNegCross$021;$maxDotForPosCross$1 = $51;
     break;
    } else {
     $57 = $51 > $maxDotForNegCross$021;
     if (!($57)) {
      $indexA$1 = $indexA$024;$indexB$1 = $indexB$023;$indexCenter$1 = $indexCenter$022;$maxDotForNegCross$1 = $maxDotForNegCross$021;$maxDotForPosCross$1 = $maxDotForPosCross$020;
      break;
     }
     $indexA$1 = $indexA$024;$indexB$1 = $i3$018;$indexCenter$1 = $indexCenter$022;$maxDotForNegCross$1 = $51;$maxDotForPosCross$1 = $maxDotForPosCross$020;
     break;
    }
   }
  } while(0);
  $58 = (($i3$018) + 1)|0;
  $59 = ($58>>>0)<($6>>>0);
  if ($59) {
   $i3$018 = $58;$indexA$024 = $indexA$1;$indexB$023 = $indexB$1;$indexCenter$022 = $indexCenter$1;$maxDotForNegCross$021 = $maxDotForNegCross$1;$maxDotForPosCross$020 = $maxDotForPosCross$1;
  } else {
   break;
  }
 }
 if ((label|0) == 31) {
  STACKTOP = sp;return;
 }
 $60 = $indexA$1 | $indexB$1;
 $61 = ($60|0)<(0);
 if ($61) {
  $centerWeight$1 = Math_fround(1.0);
 } else {
  $62 = (($4) + ($indexA$1<<3)|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = ((($4) + ($indexA$1<<3)|0) + 4|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = (($4) + ($indexB$1<<3)|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($4) + ($indexB$1<<3)|0) + 4|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($63 * $69);
  $71 = Math_fround($65 * $67);
  $72 = Math_fround($70 - $71);
  $73 = Math_fround($69 * $blendValueX);
  $74 = Math_fround($67 * $blendValueY);
  $75 = Math_fround($73 - $74);
  $76 = Math_fround($75 / $72);
  $77 = Math_fround($63 * $blendValueY);
  $78 = Math_fround($65 * $blendValueX);
  $79 = Math_fround($77 - $78);
  $80 = Math_fround($79 / $72);
  $81 = Math_fround(Math_fround(1.0) - $76);
  $82 = Math_fround($81 - $80);
  $83 = $82 < Math_fround(0.0);
  if ($83) {
   $84 = Math_fround($76 + $80);
   $85 = Math_fround($76 / $84);
   $86 = Math_fround($80 / $84);
   $centerWeight$0 = Math_fround(0.0);$wA$0 = $85;$wB$0 = $86;
  } else {
   $87 = $82 > Math_fround(1.0);
   if ($87) {
    $centerWeight$0 = Math_fround(1.0);$wA$0 = Math_fround(0.0);$wB$0 = Math_fround(0.0);
   } else {
    $centerWeight$0 = $82;$wA$0 = $76;$wB$0 = $80;
   }
  }
  $88 = (($weightArray) + ($indexA$1<<2)|0);
  HEAPF32[$88>>2] = $wA$0;
  $89 = (($weightArray) + ($indexB$1<<2)|0);
  HEAPF32[$89>>2] = $wB$0;
  $centerWeight$1 = $centerWeight$0;
 }
 $90 = ($indexCenter$1|0)>(-1);
 if ($90) {
  $91 = (($weightArray) + ($indexCenter$1<<2)|0);
  HEAPF32[$91>>2] = $centerWeight$1;
  STACKTOP = sp;return;
 }
 if ($9) {
  STACKTOP = sp;return;
 }
 $92 = (Math_fround(($6>>>0)));
 $93 = Math_fround(Math_fround(1.0) / $92);
 $94 = Math_fround($centerWeight$1 * $93);
 $i5$011 = 0;
 while(1) {
  $95 = (($weightArray) + ($i5$011<<2)|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = Math_fround($94 + $96);
  HEAPF32[$95>>2] = $97;
  $98 = (($i5$011) + 1)|0;
  $exitcond33 = ($98|0)==($6|0);
  if ($exitcond33) {
   break;
  } else {
   $i5$011 = $98;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation12GetWeights1dERKNS0_19Blend1dDataConstantEPff($blendConstant,$weightArray,$blendValue) {
 $blendConstant = $blendConstant|0;
 $weightArray = $weightArray|0;
 $blendValue = Math_fround($blendValue);
 var $$0$i = Math_fround(0), $$phi$trans$insert = 0, $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0);
 var $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0);
 var $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($blendConstant) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = HEAP32[$blendConstant>>2]|0;
 $7 = (($6) + -1)|0;
 $8 = (($4) + ($7<<2)|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (Math_fround(+(_fmaxf((+$blendValue),(+$5)))));
 $11 = (Math_fround(+(_fminf((+$10),(+$9)))));
 $12 = ($6|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 } else {
  $14 = $5;$j$01 = 0;
 }
 while(1) {
  $13 = !($14 <= $11);
  if ($13) {
   $24 = ($j$01|0)==(0);
   if ($24) {
    $$0$i = Math_fround(1.0);
   } else {
    $25 = (($j$01) + -1)|0;
    $26 = (($4) + ($25<<2)|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = $27 > $11;
    if ($28) {
     $$0$i = Math_fround(0.0);
    } else {
     $29 = Math_fround($14 - $27);
     $30 = $29 != Math_fround(0.0);
     if ($30) {
      $31 = Math_fround($11 - $27);
      $32 = Math_fround($31 / $29);
      $$0$i = $32;
     } else {
      $$0$i = $14;
     }
    }
   }
  } else {
   $15 = (($j$01) + 1)|0;
   $16 = ($15|0)==($6|0);
   if ($16) {
    $$0$i = Math_fround(1.0);
   } else {
    $17 = (($4) + ($15<<2)|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = $18 < $11;
    if ($19) {
     $$0$i = Math_fround(0.0);
    } else {
     $20 = Math_fround($14 - $18);
     $21 = $20 != Math_fround(0.0);
     if ($21) {
      $22 = Math_fround($11 - $18);
      $23 = Math_fround($22 / $20);
      $$0$i = $23;
     } else {
      $$0$i = $14;
     }
    }
   }
  }
  $33 = (($weightArray) + ($j$01<<2)|0);
  HEAPF32[$33>>2] = $$0$i;
  $34 = (($j$01) + 1)|0;
  $35 = ($34>>>0)<($6>>>0);
  if (!($35)) {
   break;
  }
  $$phi$trans$insert = (($4) + ($34<<2)|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $14 = $$pre;$j$01 = $34;
 }
 $36 = (($blendConstant) + 8|0);
 HEAP32[$36>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation10GetWeightsERKNS0_21BlendTreeNodeConstantERNS0_18BlendTreeWorkspaceEPfff($nodeConstant,$workspace,$weightArray,$blendValueX,$blendValueY) {
 $nodeConstant = $nodeConstant|0;
 $workspace = $workspace|0;
 $weightArray = $weightArray|0;
 $blendValueX = Math_fround($blendValueX);
 $blendValueY = Math_fround($blendValueY);
 var $$op$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$nodeConstant>>2]|0;
 switch ($0|0) {
 case 2:  {
  $13 = (($nodeConstant) + 32|0);
  $14 = $13;
  $15 = HEAP32[$13>>2]|0;
  $16 = (($15) + ($14))|0;
  $17 = $16;
  $18 = (($nodeConstant) + 36|0);
  HEAP32[$18>>2] = $17;
  $19 = (($workspace) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($workspace) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  __ZN7mecanim9animation29GetWeightsFreeformDirectionalERKNS0_19Blend2dDataConstantEPfPiP8Vector2fffb($17,$weightArray,$20,$22,$blendValueX,$blendValueY,0);
  STACKTOP = sp;return;
  break;
 }
 case 4:  {
  $33 = (($nodeConstant) + 40|0);
  $34 = $33;
  $35 = HEAP32[$33>>2]|0;
  $36 = (($35) + ($34))|0;
  $37 = $36;
  $38 = (($nodeConstant) + 44|0);
  HEAP32[$38>>2] = $37;
  $39 = HEAP32[$37>>2]|0;
  $40 = ($39|0)==(0);
  if ($40) {
   STACKTOP = sp;return;
  }
  $41 = ($39>>>0)>(1);
  $$op$i = $39 << 2;
  $42 = $41 ? $$op$i : 4;
  _memset(($weightArray|0),0,($42|0))|0;
  STACKTOP = sp;return;
  break;
 }
 case 0:  {
  $1 = (($nodeConstant) + 24|0);
  $2 = $1;
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + ($2))|0;
  $5 = $4;
  $6 = (($nodeConstant) + 28|0);
  HEAP32[$6>>2] = $5;
  __ZN7mecanim9animation12GetWeights1dERKNS0_19Blend1dDataConstantEPff($5,$weightArray,$blendValueX);
  STACKTOP = sp;return;
  break;
 }
 case 3:  {
  $23 = (($nodeConstant) + 32|0);
  $24 = $23;
  $25 = HEAP32[$23>>2]|0;
  $26 = (($25) + ($24))|0;
  $27 = $26;
  $28 = (($nodeConstant) + 36|0);
  HEAP32[$28>>2] = $27;
  $29 = (($workspace) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($workspace) + 12|0);
  $32 = HEAP32[$31>>2]|0;
  __ZN7mecanim9animation27GetWeightsFreeformCartesianERKNS0_19Blend2dDataConstantEPfPiP8Vector2fffb($27,$weightArray,$30,$32,$blendValueX,$blendValueY,0);
  STACKTOP = sp;return;
  break;
 }
 case 1:  {
  $7 = (($nodeConstant) + 32|0);
  $8 = $7;
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + ($8))|0;
  $11 = $10;
  $12 = (($nodeConstant) + 36|0);
  HEAP32[$12>>2] = $11;
  __ZN7mecanim9animation27GetWeightsSimpleDirectionalERKNS0_19Blend2dDataConstantEPfPiP8Vector2fffb($11,$weightArray,0,0,$blendValueX,$blendValueY,0);
  STACKTOP = sp;return;
  break;
 }
 default: {
  STACKTOP = sp;return;
 }
 }
}
function __ZN7mecanim9animation17EvaluateBlendTreeERKNS0_17BlendTreeConstantERKNS0_14BlendTreeInputERNS0_15BlendTreeOutputERNS0_18BlendTreeWorkspaceERKNS0_12AnimationSetEj($constant,$input,$output,$workspace,$animationSet,$indexOffset) {
 $constant = $constant|0;
 $input = $input|0;
 $output = $output|0;
 $workspace = $workspace|0;
 $animationSet = $animationSet|0;
 $indexOffset = $indexOffset|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $childIter$05 = 0, $childIter3$010 = 0, $currentOutputIndex$018 = 0, $currentOutputIndex$1 = 0, $currentOutputIndex$2 = 0;
 var $durationWeight$019 = Math_fround(0), $durationWeight$1 = Math_fround(0), $durationWeight$2 = Math_fround(0), $i$025 = 0, $i1$016 = 0, $j$014 = 0, $leafIndex$020 = 0, $leafIndex$1 = 0, $or$cond = 0, $or$cond1 = 0, $sum$04 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($output) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = HEAP32[$output>>2]|0;
  $i$025 = 0;
  while(1) {
   $4 = ((($3) + (($i$025*20)|0)|0) + 4|0);
   HEAP32[$4>>2] = -1;
   $5 = (($i$025) + 1)|0;
   $6 = HEAP32[$0>>2]|0;
   $7 = ($5>>>0)<($6>>>0);
   if ($7) {
    $i$025 = $5;
   } else {
    break;
   }
  }
 }
 $8 = (($output) + 8|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = HEAP32[$workspace>>2]|0;
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = HEAP32[$constant>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = (($constant) + 4|0);
  $13 = $12;
  $14 = (($input) + 4|0);
  $15 = (($workspace) + 4|0);
  $16 = (($animationSet) + 12|0);
  $currentOutputIndex$018 = 0;$durationWeight$019 = Math_fround(0.0);$i1$016 = 0;$leafIndex$020 = 0;
  while(1) {
   $17 = HEAP32[$12>>2]|0;
   $18 = (($17) + ($13))|0;
   $19 = $18;
   $20 = (($19) + ($i1$016<<3)|0);
   $21 = $20;
   $22 = HEAP32[$20>>2]|0;
   $23 = (($21) + ($22))|0;
   $24 = $23;
   $25 = ((($19) + ($i1$016<<3)|0) + 4|0);
   HEAP32[$25>>2] = $24;
   $26 = (($24) + 48|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(-1);
   if ($28) {
    $70 = (($24) + 12|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71|0)==(0);
    if ($72) {
     $currentOutputIndex$2 = $currentOutputIndex$018;$durationWeight$2 = $durationWeight$019;$leafIndex$1 = $leafIndex$020;
    } else {
     $73 = HEAP32[$24>>2]|0;
     $74 = ($73|0)==(0);
     do {
      if ($74) {
       $75 = HEAP32[$input>>2]|0;
       $76 = (($24) + 4|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = (__ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj($75,$77)|0);
       $79 = ($78|0)==(-1);
       if (!($79)) {
        $80 = HEAP32[$14>>2]|0;
        $81 = HEAP32[$input>>2]|0;
        $82 = (($81) + 4|0);
        $83 = $82;
        $84 = HEAP32[$82>>2]|0;
        $85 = (($83) + ($84))|0;
        $86 = $85;
        $87 = ((($86) + ($78<<4)|0) + 12|0);
        $88 = HEAP32[$87>>2]|0;
        $89 = (($80) + 28|0);
        $90 = $89;
        $91 = HEAP32[$89>>2]|0;
        $92 = (($91) + ($90))|0;
        $93 = $92;
        $94 = (($93) + ($88<<2)|0);
        $95 = Math_fround(HEAPF32[$94>>2]);
        $96 = HEAP32[$15>>2]|0;
        __ZN7mecanim9animation10GetWeightsERKNS0_21BlendTreeNodeConstantERNS0_18BlendTreeWorkspaceEPfff($24,$workspace,$96,$95,Math_fround(0.0));
       }
      } else {
       $97 = ($73>>>0)<(4);
       if ($97) {
        $98 = HEAP32[$input>>2]|0;
        $99 = (($24) + 4|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = (__ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj($98,$100)|0);
        $102 = HEAP32[$input>>2]|0;
        $103 = (($24) + 8|0);
        $104 = HEAP32[$103>>2]|0;
        $105 = (__ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj($102,$104)|0);
        $106 = ($101|0)==(-1);
        $107 = ($105|0)==(-1);
        $or$cond = $106 | $107;
        if ($or$cond) {
         break;
        }
        $108 = HEAP32[$14>>2]|0;
        $109 = HEAP32[$input>>2]|0;
        $110 = (($109) + 4|0);
        $111 = $110;
        $112 = HEAP32[$110>>2]|0;
        $113 = (($111) + ($112))|0;
        $114 = $113;
        $115 = ((($114) + ($101<<4)|0) + 12|0);
        $116 = HEAP32[$115>>2]|0;
        $117 = (($108) + 28|0);
        $118 = $117;
        $119 = HEAP32[$117>>2]|0;
        $120 = (($119) + ($118))|0;
        $121 = $120;
        $122 = (($121) + ($116<<2)|0);
        $123 = Math_fround(HEAPF32[$122>>2]);
        $124 = ((($114) + ($105<<4)|0) + 12|0);
        $125 = HEAP32[$124>>2]|0;
        $126 = (($121) + ($125<<2)|0);
        $127 = Math_fround(HEAPF32[$126>>2]);
        $128 = HEAP32[$15>>2]|0;
        __ZN7mecanim9animation10GetWeightsERKNS0_21BlendTreeNodeConstantERNS0_18BlendTreeWorkspaceEPfff($24,$workspace,$128,$123,$127);
        break;
       }
       $129 = ($73|0)==(4);
       if ($129) {
        $130 = (($24) + 40|0);
        $131 = $130;
        $132 = HEAP32[$130>>2]|0;
        $133 = (($132) + ($131))|0;
        $134 = $133;
        $135 = HEAP32[$134>>2]|0;
        $136 = ($135|0)==(0);
        if (!($136)) {
         $138 = $134;$childIter$05 = 0;$sum$04 = Math_fround(0.0);
         while(1) {
          $137 = (($138) + 4|0);
          $139 = $137;
          $140 = HEAP32[$137>>2]|0;
          $141 = (($140) + ($139))|0;
          $142 = $141;
          $143 = (($142) + ($childIter$05<<2)|0);
          $144 = HEAP32[$143>>2]|0;
          $145 = ($144|0)==(-1);
          if ($145) {
           $167 = Math_fround(0.0);
          } else {
           $146 = HEAP32[$input>>2]|0;
           $147 = (__ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj($146,$144)|0);
           $148 = ($147|0)==(-1);
           if ($148) {
            $167 = Math_fround(0.0);
           } else {
            $149 = HEAP32[$14>>2]|0;
            $150 = HEAP32[$input>>2]|0;
            $151 = (($150) + 4|0);
            $152 = $151;
            $153 = HEAP32[$151>>2]|0;
            $154 = (($152) + ($153))|0;
            $155 = $154;
            $156 = ((($155) + ($147<<4)|0) + 12|0);
            $157 = HEAP32[$156>>2]|0;
            $158 = (($149) + 28|0);
            $159 = $158;
            $160 = HEAP32[$158>>2]|0;
            $161 = (($160) + ($159))|0;
            $162 = $161;
            $163 = (($162) + ($157<<2)|0);
            $164 = Math_fround(HEAPF32[$163>>2]);
            $167 = $164;
           }
          }
          $165 = HEAP32[$15>>2]|0;
          $166 = (($165) + ($childIter$05<<2)|0);
          HEAPF32[$166>>2] = $167;
          $168 = Math_fround($sum$04 + $167);
          $169 = (($childIter$05) + 1)|0;
          $170 = HEAP32[$130>>2]|0;
          $171 = (($170) + ($131))|0;
          $172 = $171;
          $173 = HEAP32[$172>>2]|0;
          $174 = ($169>>>0)<($173>>>0);
          if ($174) {
           $138 = $172;$childIter$05 = $169;$sum$04 = $168;
          } else {
           break;
          }
         }
         $175 = (($172) + 12|0);
         $176 = HEAP8[$175>>0]|0;
         $177 = ($176<<24>>24)!=(0);
         $178 = $168 > Math_fround(1.0);
         $or$cond1 = $177 & $178;
         if ($or$cond1) {
          $179 = (($170) + ($131))|0;
          $180 = $179;
          $181 = HEAP32[$180>>2]|0;
          $182 = ($181|0)==(0);
          if (!($182)) {
           $183 = HEAP32[$15>>2]|0;
           $childIter3$010 = 0;
           while(1) {
            $184 = (($183) + ($childIter3$010<<2)|0);
            $185 = Math_fround(HEAPF32[$184>>2]);
            $186 = Math_fround($185 / $168);
            HEAPF32[$184>>2] = $186;
            $187 = (($childIter3$010) + 1)|0;
            $188 = ($187>>>0)<($181>>>0);
            if ($188) {
             $childIter3$010 = $187;
            } else {
             break;
            }
           }
          }
         }
        }
       }
      }
     } while(0);
     $189 = HEAP32[$70>>2]|0;
     $190 = ($189|0)==(0);
     if ($190) {
      $currentOutputIndex$2 = $currentOutputIndex$018;$durationWeight$2 = $durationWeight$019;$leafIndex$1 = $leafIndex$020;
     } else {
      $191 = HEAP32[$15>>2]|0;
      $192 = HEAP32[$workspace>>2]|0;
      $193 = (($192) + ($i1$016<<2)|0);
      $194 = (($24) + 16|0);
      $195 = $194;
      $196 = HEAP32[$194>>2]|0;
      $197 = (($196) + ($195))|0;
      $198 = $197;
      $j$014 = 0;
      while(1) {
       $199 = (($191) + ($j$014<<2)|0);
       $200 = Math_fround(HEAPF32[$199>>2]);
       $201 = Math_fround(HEAPF32[$193>>2]);
       $202 = Math_fround($200 * $201);
       $203 = (($198) + ($j$014<<2)|0);
       $204 = HEAP32[$203>>2]|0;
       $205 = (($192) + ($204<<2)|0);
       HEAPF32[$205>>2] = $202;
       $206 = (($j$014) + 1)|0;
       $207 = ($206>>>0)<($189>>>0);
       if ($207) {
        $j$014 = $206;
       } else {
        $currentOutputIndex$2 = $currentOutputIndex$018;$durationWeight$2 = $durationWeight$019;$leafIndex$1 = $leafIndex$020;
        break;
       }
      }
     }
    }
   } else {
    $29 = HEAP32[$workspace>>2]|0;
    $30 = (($29) + ($i1$016<<2)|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = $31 > Math_fround(0.0);
    if ($32) {
     $33 = (($leafIndex$020) + ($indexOffset))|0;
     $34 = HEAP32[$16>>2]|0;
     $35 = (($34) + (($33*36)|0)|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==(0|0);
     if ($37) {
      $46 = Math_fround(0.0);
     } else {
      $38 = (($36) + 1052|0);
      $39 = Math_fround(HEAPF32[$38>>2]);
      $40 = (($36) + 1048|0);
      $41 = Math_fround(HEAPF32[$40>>2]);
      $42 = Math_fround($39 - $41);
      $46 = $42;
     }
     $43 = (($24) + 52|0);
     $44 = Math_fround(HEAPF32[$43>>2]);
     $45 = Math_fround($46 * $44);
     $47 = HEAP32[$output>>2]|0;
     $48 = ((($47) + (($currentOutputIndex$018*20)|0)|0) + 4|0);
     HEAP32[$48>>2] = $27;
     $49 = (($47) + (($currentOutputIndex$018*20)|0)|0);
     HEAPF32[$49>>2] = $31;
     $50 = Math_fround(HEAPF32[$43>>2]);
     $51 = $50 != Math_fround(0.0);
     if ($51) {
      $52 = Math_fround(Math_fround(1.0) / $50);
      $54 = $52;
     } else {
      $54 = Math_fround(1.0);
     }
     $53 = ((($47) + (($currentOutputIndex$018*20)|0)|0) + 8|0);
     HEAPF32[$53>>2] = $54;
     $55 = (($24) + 56|0);
     $56 = Math_fround(HEAPF32[$55>>2]);
     $57 = ((($47) + (($currentOutputIndex$018*20)|0)|0) + 16|0);
     HEAPF32[$57>>2] = $56;
     $58 = (($24) + 60|0);
     $59 = HEAP8[$58>>0]|0;
     $60 = ((($47) + (($currentOutputIndex$018*20)|0)|0) + 12|0);
     HEAP8[$60>>0] = $59;
     $61 = (Math_fround(Math_abs((Math_fround($45)))));
     $62 = Math_fround(HEAPF32[$30>>2]);
     $63 = Math_fround($61 * $62);
     $64 = Math_fround(HEAPF32[$8>>2]);
     $65 = Math_fround($64 + $63);
     HEAPF32[$8>>2] = $65;
     $66 = Math_fround(HEAPF32[$30>>2]);
     $67 = Math_fround($durationWeight$019 + $66);
     $68 = (($currentOutputIndex$018) + 1)|0;
     $currentOutputIndex$1 = $68;$durationWeight$1 = $67;
    } else {
     $currentOutputIndex$1 = $currentOutputIndex$018;$durationWeight$1 = $durationWeight$019;
    }
    $69 = (($leafIndex$020) + 1)|0;
    $currentOutputIndex$2 = $currentOutputIndex$1;$durationWeight$2 = $durationWeight$1;$leafIndex$1 = $69;
   }
   $208 = (($i1$016) + 1)|0;
   $209 = HEAP32[$constant>>2]|0;
   $210 = ($208>>>0)<($209>>>0);
   if ($210) {
    $currentOutputIndex$018 = $currentOutputIndex$2;$durationWeight$019 = $durationWeight$2;$i1$016 = $208;$leafIndex$020 = $leafIndex$1;
   } else {
    break;
   }
  }
  $211 = $durationWeight$2 == Math_fround(0.0);
  if (!($211)) {
   $212 = $durationWeight$2 < Math_fround(1.0);
   if (!($212)) {
    STACKTOP = sp;return;
   }
   $213 = Math_fround(HEAPF32[$8>>2]);
   $214 = Math_fround($213 / $durationWeight$2);
   HEAPF32[$8>>2] = $214;
   STACKTOP = sp;return;
  }
 }
 HEAPF32[$8>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation16GetMaxBlendCountERKNS0_17BlendTreeConstantERKNS0_21BlendTreeNodeConstantE($constant,$node) {
 $constant = $constant|0;
 $node = $node|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $i1$06 = 0, $previous$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($node) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(-1);
 $3 = $2&1;
 $4 = HEAP32[$node>>2]|0;
 $5 = ($4|0)==(0);
 $6 = (($node) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($5) {
  if ($8) {
   $55 = $3;
   STACKTOP = sp;return ($55|0);
  }
  $19 = (($constant) + 4|0);
  $20 = (($node) + 16|0);
  $21 = $20;
  $22 = HEAP32[$20>>2]|0;
  $23 = (($22) + ($21))|0;
  $24 = $23;
  $25 = $19;
  $26 = HEAP32[$19>>2]|0;
  $27 = (($26) + ($25))|0;
  $28 = $27;
  $39 = $3;$i$02 = 0;$previous$01 = 0;
  while(1) {
   $29 = (($24) + ($i$02<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($28) + ($30<<3)|0);
   $32 = $31;
   $33 = HEAP32[$31>>2]|0;
   $34 = (($32) + ($33))|0;
   $35 = $34;
   $36 = (__ZN7mecanim9animation16GetMaxBlendCountERKNS0_17BlendTreeConstantERKNS0_21BlendTreeNodeConstantE($constant,$35)|0);
   $37 = (($36) + ($previous$01))|0;
   $38 = ($39>>>0)<($37>>>0);
   $40 = $38 ? $37 : $39;
   $41 = (($i$02) + 1)|0;
   $42 = ($41>>>0)<($7>>>0);
   if ($42) {
    $39 = $40;$i$02 = $41;$previous$01 = $36;
   } else {
    $55 = $40;
    break;
   }
  }
  STACKTOP = sp;return ($55|0);
 } else {
  if ($8) {
   $55 = $3;
   STACKTOP = sp;return ($55|0);
  }
  $9 = (($constant) + 4|0);
  $10 = (($node) + 16|0);
  $11 = $10;
  $12 = HEAP32[$10>>2]|0;
  $13 = (($12) + ($11))|0;
  $14 = $13;
  $15 = $9;
  $16 = HEAP32[$9>>2]|0;
  $17 = (($16) + ($15))|0;
  $18 = $17;
  $52 = $3;$i1$06 = 0;
  while(1) {
   $43 = (($14) + ($i1$06<<2)|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($18) + ($44<<3)|0);
   $46 = $45;
   $47 = HEAP32[$45>>2]|0;
   $48 = (($46) + ($47))|0;
   $49 = $48;
   $50 = (__ZN7mecanim9animation16GetMaxBlendCountERKNS0_17BlendTreeConstantERKNS0_21BlendTreeNodeConstantE($constant,$49)|0);
   $51 = (($50) + ($52))|0;
   $53 = (($i1$06) + 1)|0;
   $54 = ($53>>>0)<($7>>>0);
   if ($54) {
    $52 = $51;$i1$06 = $53;
   } else {
    $55 = $51;
    break;
   }
  }
  STACKTOP = sp;return ($55|0);
 }
 return 0|0;
}
function __ZN7mecanim9animation16GetMaxBlendCountERKNS0_17BlendTreeConstantE($constant) {
 $constant = $constant|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $maxBlendCount$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$constant>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $maxBlendCount$0 = 0;
  STACKTOP = sp;return ($maxBlendCount$0|0);
 }
 $2 = (($constant) + 4|0);
 $3 = $2;
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + ($3))|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5))|0;
 $9 = $8;
 $10 = (__ZN7mecanim9animation16GetMaxBlendCountERKNS0_17BlendTreeConstantERKNS0_21BlendTreeNodeConstantE($constant,$9)|0);
 $maxBlendCount$0 = $10;
 STACKTOP = sp;return ($maxBlendCount$0|0);
}
function __ZN7mecanim9animation16CreateClipMemoryEPKNS0_4ClipEiRNS_6memory9AllocatorE($clip,$totalUsedCurves,$alloc) {
 $clip = $clip|0;
 $totalUsedCurves = $totalUsedCurves|0;
 $alloc = $alloc|0;
 var $$neg2 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,20,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $10 = 0;
 } else {
  $10 = $2;
 }
 $4 = (($clip) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($clip) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $$neg2 = (($totalUsedCurves) - ($5))|0;
 $8 = (($$neg2) - ($7))|0;
 $9 = (($10) + 16|0);
 HEAP32[$9>>2] = $8;
 __ZN7mecanim9animation24CreateStreamedClipMemoryERKNS0_12StreamedClipERNS0_18StreamedClipMemoryERNS_6memory9AllocatorE($clip,$10,$alloc);
 STACKTOP = sp;return ($10|0);
}
function __ZN7mecanim9animation17DestroyClipMemoryEPNS0_10ClipMemoryERNS_6memory9AllocatorE($memory,$alloc) {
 $memory = $memory|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($memory|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 __ZN7mecanim9animation25DestroyStreamedClipMemoryERNS0_18StreamedClipMemoryERNS_6memory9AllocatorE($memory,$alloc);
 $1 = HEAP32[$alloc>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($alloc,$memory);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation16CreateClipOutputEiRNS_6memory9AllocatorE($totalUsedCurves,$alloc) {
 $totalUsedCurves = $totalUsedCurves|0;
 $alloc = $alloc|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,4,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $9 = 0;
 } else {
  $9 = $2;
 }
 $4 = ($totalUsedCurves|0)==(0);
 if ($4) {
  $$0$i = 0;
  HEAP32[$9>>2] = $$0$i;
  STACKTOP = sp;return ($9|0);
 }
 $5 = HEAP32[$alloc>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = $totalUsedCurves << 2;
 $8 = (FUNCTION_TABLE_iiii[$6 & 2047]($alloc,$7,4)|0);
 $$0$i = $8;
 HEAP32[$9>>2] = $$0$i;
 STACKTOP = sp;return ($9|0);
}
function __ZN7mecanim9animation17DestroyClipOutputEPNS0_10ClipOutputERNS_6memory9AllocatorE($output,$alloc) {
 $output = $output|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($output|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$alloc>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$output>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($alloc,$4);
 $5 = HEAP32[$alloc>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($alloc,$output);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation19EvaluateClipAtIndexEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEj($clip,$input,$memory,$index) {
 $clip = $clip|0;
 $input = $input|0;
 $memory = $memory|0;
 $index = $index|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($clip) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($index>>>0);
 if ($2) {
  $3 = Math_fround(HEAPF32[$input>>2]);
  $4 = (Math_fround(__ZN7mecanim9animation17SampleClipAtIndexERKNS0_12StreamedClipERNS0_18StreamedClipMemoryEif($clip,$memory,$index,$3)));
  $$0 = $4;
  STACKTOP = sp;return (Math_fround($$0));
 }
 $5 = (($index) - ($1))|0;
 $6 = (($clip) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = (($clip) + 16|0);
  $10 = Math_fround(HEAPF32[$input>>2]);
  $11 = (Math_fround(__ZN7mecanim9animation17SampleClipAtIndexERKNS0_9DenseClipEif($9,$5,$10)));
  $$0 = $11;
  STACKTOP = sp;return (Math_fround($$0));
 } else {
  $12 = (($5) - ($7))|0;
  $13 = (($clip) + 44|0);
  $14 = (Math_fround(__ZN7mecanim9animation17SampleClipAtIndexERKNS0_12ConstantClipEi($13,$12)));
  $$0 = $14;
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZN7mecanim9animation12EvaluateClipEPKNS0_4ClipEPKNS0_9ClipInputEPNS0_10ClipMemoryEPNS0_10ClipOutputE($clip,$input,$memory,$output) {
 $clip = $clip|0;
 $input = $input|0;
 $memory = $memory|0;
 $output = $output|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $outputData$0 = 0, $outputData$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$output>>2]|0;
 $1 = (($clip) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $outputData$0 = $0;
 } else {
  $4 = Math_fround(HEAPF32[$input>>2]);
  __ZN7mecanim9animation10SampleClipERKNS0_12StreamedClipERNS0_18StreamedClipMemoryEfPf($clip,$memory,$4,$0);
  $5 = HEAP32[$1>>2]|0;
  $6 = (($0) + ($5<<2)|0);
  $outputData$0 = $6;
 }
 $7 = (($clip) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $outputData$1 = $outputData$0;
 } else {
  $10 = (($clip) + 16|0);
  $11 = Math_fround(HEAPF32[$input>>2]);
  __ZN7mecanim9animation10SampleClipERKNS0_9DenseClipEfPf($10,$11,$outputData$0);
  $12 = HEAP32[$7>>2]|0;
  $13 = (($outputData$0) + ($12<<2)|0);
  $outputData$1 = $13;
 }
 $14 = (($memory) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = (($clip) + 44|0);
 __ZN7mecanim9animation10SampleClipERKNS0_12ConstantClipEjPf($17,$15,$outputData$1);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation10SampleClipERKNS0_9DenseClipEfPf($clip,$time,$output) {
 $clip = $clip|0;
 $time = Math_fround($time);
 $output = $output|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0;
 var $9 = 0, $exitcond$i = 0, $i$01$i = 0, $index$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $index$i = sp;
 $0 = (($clip) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($time - $1);
 $3 = (($clip) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 * $4);
 $6 = (Math_fround(+(_modff((+$5),($index$i|0)))));
 $7 = Math_fround(HEAPF32[$index$i>>2]);
 $8 = (~~(($7)));
 $9 = (($8) + 1)|0;
 $10 = ($8|0)>(0);
 $11 = $10 ? $8 : 0;
 $12 = HEAP32[$clip>>2]|0;
 $13 = (($12) + -1)|0;
 $14 = ($11|0)<($13|0);
 $15 = $14 ? $11 : $13;
 $16 = ($9|0)>(0);
 $17 = $16 ? $9 : 0;
 $18 = ($17|0)<($13|0);
 $19 = $18 ? $17 : $13;
 $20 = (($clip) + 20|0);
 $21 = (($clip) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = Math_imul($15, $22)|0;
 $24 = $20;
 $25 = HEAP32[$20>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = $26;
 $28 = Math_imul($19, $22)|0;
 $29 = ($22|0)==(0);
 if ($29) {
  STACKTOP = sp;return;
 } else {
  $i$01$i = 0;
 }
 while(1) {
  $$sum = (($i$01$i) + ($23))|0;
  $30 = (($27) + ($$sum<<2)|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $$sum1 = (($i$01$i) + ($28))|0;
  $32 = (($27) + ($$sum1<<2)|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = Math_fround($33 - $31);
  $35 = Math_fround($6 * $34);
  $36 = Math_fround($31 + $35);
  $37 = (($output) + ($i$01$i<<2)|0);
  HEAPF32[$37>>2] = $36;
  $38 = (($i$01$i) + 1)|0;
  $exitcond$i = ($38|0)==($22|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $38;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17SampleClipAtIndexERKNS0_9DenseClipEif($clip,$curveIndex,$time) {
 $clip = $clip|0;
 $curveIndex = $curveIndex|0;
 $time = Math_fround($time);
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $index$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $index$i = sp;
 $0 = (($clip) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($time - $1);
 $3 = (($clip) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($2 * $4);
 $6 = (Math_fround(+(_modff((+$5),($index$i|0)))));
 $7 = Math_fround(HEAPF32[$index$i>>2]);
 $8 = (~~(($7)));
 $9 = (($8) + 1)|0;
 $10 = ($8|0)>(0);
 $11 = $10 ? $8 : 0;
 $12 = HEAP32[$clip>>2]|0;
 $13 = (($12) + -1)|0;
 $14 = ($11|0)<($13|0);
 $15 = $14 ? $11 : $13;
 $16 = ($9|0)>(0);
 $17 = $16 ? $9 : 0;
 $18 = ($17|0)<($13|0);
 $19 = $18 ? $17 : $13;
 $20 = (($clip) + 20|0);
 $21 = (($clip) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = Math_imul($15, $22)|0;
 $24 = $20;
 $25 = HEAP32[$20>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = $26;
 $28 = Math_imul($19, $22)|0;
 $$sum = (($23) + ($curveIndex))|0;
 $29 = (($27) + ($$sum<<2)|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $$sum1 = (($28) + ($curveIndex))|0;
 $31 = (($27) + ($$sum1<<2)|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 - $30);
 $34 = Math_fround($6 * $33);
 $35 = Math_fround($30 + $34);
 STACKTOP = sp;return (Math_fround($35));
}
function __ZN7mecanim9animation8SeekClipERKNS0_12StreamedClipERNS0_18StreamedClipMemoryEf($curveData,$cache,$time) {
 $curveData = $curveData|0;
 $cache = $cache|0;
 $time = Math_fround($time);
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$sum$i = 0, $$sum4$i = 0, $$sum5$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $coeff0$0$i$i = Math_fround(0), $coeff0$0$in$i$i = 0, $coeff1$0$i$i = Math_fround(0), $coeff1$0$in$i$i = 0, $coeff2$0$i$i = Math_fround(0), $coeff2$0$in$i$i = 0, $coeff3$0$i$i = Math_fround(0), $coeff3$0$in$i$i = 0, $curveIndex$0$i$i = 0, $curveIndex$0$in$i$i = 0, $data$0$in$i = 0, $data$0$in$sum1$i = 0, $data$0$in$sum2$i = 0, $data$0$in$sum3$i = 0;
 var $data$0$in6$i = 0, $i$0$i$i = 0, $readByteOffset$0$lcssa$i = 0, $readByteOffset$07$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cache) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == $time;
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = $1 > $time;
 if ($3) {
  HEAPF32[$0>>2] = Math_fround(-inf);
  $4 = (($cache) + 12|0);
  HEAP32[$4>>2] = 0;
  $13 = 0;
 } else {
  $$phi$trans$insert = (($cache) + 12|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $13 = $$pre;
 }
 $5 = (($curveData) + 4|0);
 $6 = $5;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + ($6))|0;
 $9 = $8;
 $10 = (($curveData) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = $8;
 $12 = (($cache) + 12|0);
 $data$0$in6$i = (($11) + ($13)|0);
 $14 = Math_fround(HEAPF32[$data$0$in6$i>>2]);
 $15 = !($14 <= $time);
 if ($15) {
  $readByteOffset$0$lcssa$i = $13;
 } else {
  $$pre$i = HEAP32[$cache>>2]|0;
  $25 = $14;$readByteOffset$07$i = $13;
  while(1) {
   $data$0$in$sum1$i = (($readByteOffset$07$i) + 8)|0;
   $16 = (($11) + ($data$0$in$sum1$i)|0);
   $data$0$in$sum2$i = (($readByteOffset$07$i) + 4)|0;
   $17 = (($11) + ($data$0$in$sum2$i)|0);
   $18 = HEAP32[$17>>2]|0;
   $data$0$in$sum3$i = (($readByteOffset$07$i) + 12)|0;
   $19 = (($11) + ($data$0$in$sum3$i)|0);
   $$sum$i = (($readByteOffset$07$i) + 16)|0;
   $20 = (($11) + ($$sum$i)|0);
   $$sum4$i = (($readByteOffset$07$i) + 20)|0;
   $21 = (($11) + ($$sum4$i)|0);
   $$sum5$i = (($readByteOffset$07$i) + 24)|0;
   $22 = (($11) + ($$sum5$i)|0);
   $coeff0$0$in$i$i = $19;$coeff1$0$in$i$i = $20;$coeff2$0$in$i$i = $21;$coeff3$0$in$i$i = $22;$curveIndex$0$in$i$i = $16;$i$0$i$i = 1;
   while(1) {
    $curveIndex$0$i$i = HEAP32[$curveIndex$0$in$i$i>>2]|0;
    $coeff0$0$i$i = Math_fround(HEAPF32[$coeff0$0$in$i$i>>2]);
    $coeff3$0$i$i = Math_fround(HEAPF32[$coeff3$0$in$i$i>>2]);
    $coeff2$0$i$i = Math_fround(HEAPF32[$coeff2$0$in$i$i>>2]);
    $coeff1$0$i$i = Math_fround(HEAPF32[$coeff1$0$in$i$i>>2]);
    $23 = ($i$0$i$i|0)<($18|0);
    $24 = (($$pre$i) + (($curveIndex$0$i$i*20)|0)|0);
    HEAPF32[$24>>2] = $25;
    $26 = ((($$pre$i) + (($curveIndex$0$i$i*20)|0)|0) + 4|0);
    HEAPF32[$26>>2] = $coeff0$0$i$i;
    $27 = ((($$pre$i) + (($curveIndex$0$i$i*20)|0)|0) + 8|0);
    HEAPF32[$27>>2] = $coeff1$0$i$i;
    $28 = ((($$pre$i) + (($curveIndex$0$i$i*20)|0)|0) + 12|0);
    HEAPF32[$28>>2] = $coeff2$0$i$i;
    $29 = ((($$pre$i) + (($curveIndex$0$i$i*20)|0)|0) + 16|0);
    HEAPF32[$29>>2] = $coeff3$0$i$i;
    if (!($23)) {
     break;
    }
    $30 = (($16) + (($i$0$i$i*20)|0)|0);
    $31 = ((($16) + (($i$0$i$i*20)|0)|0) + 4|0);
    $32 = ((($16) + (($i$0$i$i*20)|0)|0) + 8|0);
    $33 = ((($16) + (($i$0$i$i*20)|0)|0) + 12|0);
    $34 = ((($16) + (($i$0$i$i*20)|0)|0) + 16|0);
    $35 = (($i$0$i$i) + 1)|0;
    $coeff0$0$in$i$i = $31;$coeff1$0$in$i$i = $32;$coeff2$0$in$i$i = $33;$coeff3$0$in$i$i = $34;$curveIndex$0$in$i$i = $30;$i$0$i$i = $35;
   }
   $36 = ($18*20)|0;
   $37 = (($36) + ($data$0$in$sum1$i))|0;
   $data$0$in$i = (($11) + ($37)|0);
   $38 = Math_fround(HEAPF32[$data$0$in$i>>2]);
   $39 = !($38 <= $time);
   if ($39) {
    $readByteOffset$0$lcssa$i = $37;
    break;
   } else {
    $25 = $38;$readByteOffset$07$i = $37;
   }
  }
 }
 HEAPF32[$0>>2] = $time;
 HEAP32[$12>>2] = $readByteOffset$0$lcssa$i;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation10SampleClipERKNS0_12StreamedClipERNS0_18StreamedClipMemoryEfPf($curveData,$cache,$time,$output) {
 $curveData = $curveData|0;
 $cache = $cache|0;
 $time = Math_fround($time);
 $output = $output|0;
 var $$sum1$i = 0, $$sum2$i = 0, $$sum3$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0;
 var $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0;
 var $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0);
 var $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0;
 var $97 = 0, $98 = 0, $caches$0$lcssa$i = 0, $caches$07$i = 0, $caches$15$i = 0, $exitcond = 0, $i$0$lcssa$i = 0, $i$06$i = 0, $i$06$i$phi = 0, $i$14$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7mecanim9animation8SeekClipERKNS0_12StreamedClipERNS0_18StreamedClipMemoryEf($curveData,$cache,$time);
 $0 = HEAP32[$cache>>2]|0;
 $1 = (($cache) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)<(4);
 if ($3) {
  $caches$0$lcssa$i = $0;$i$0$lcssa$i = 0;
 } else {
  $78 = 4;$caches$07$i = $0;$i$06$i = 0;
  while(1) {
   $5 = (($output) + ($i$06$i<<2)|0);
   $6 = Math_fround(HEAPF32[$caches$07$i>>2]);
   $7 = (($caches$07$i) + 20|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = (($caches$07$i) + 40|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = (($caches$07$i) + 60|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = Math_fround($time - $6);
   $14 = Math_fround($time - $8);
   $15 = Math_fround($time - $10);
   $16 = Math_fround($time - $12);
   $17 = (($caches$07$i) + 4|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = (($caches$07$i) + 24|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = (($caches$07$i) + 44|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = (($caches$07$i) + 64|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = (($caches$07$i) + 8|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = (($caches$07$i) + 28|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = (($caches$07$i) + 48|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = (($caches$07$i) + 68|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = (($caches$07$i) + 12|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = (($caches$07$i) + 32|0);
   $36 = Math_fround(HEAPF32[$35>>2]);
   $37 = (($caches$07$i) + 52|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = (($caches$07$i) + 72|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = (($caches$07$i) + 16|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = (($caches$07$i) + 36|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = (($caches$07$i) + 56|0);
   $46 = Math_fround(HEAPF32[$45>>2]);
   $47 = (($caches$07$i) + 76|0);
   $48 = Math_fround(HEAPF32[$47>>2]);
   $49 = Math_fround($13 * $18);
   $50 = Math_fround($14 * $20);
   $51 = Math_fround($15 * $22);
   $52 = Math_fround($16 * $24);
   $53 = Math_fround($49 + $26);
   $54 = Math_fround($50 + $28);
   $55 = Math_fround($51 + $30);
   $56 = Math_fround($52 + $32);
   $57 = Math_fround($13 * $53);
   $58 = Math_fround($14 * $54);
   $59 = Math_fround($15 * $55);
   $60 = Math_fround($16 * $56);
   $61 = Math_fround($57 + $34);
   $62 = Math_fround($58 + $36);
   $63 = Math_fround($59 + $38);
   $64 = Math_fround($60 + $40);
   $65 = Math_fround($13 * $61);
   $66 = Math_fround($14 * $62);
   $67 = Math_fround($15 * $63);
   $68 = Math_fround($16 * $64);
   $69 = Math_fround($65 + $42);
   $70 = Math_fround($66 + $44);
   $71 = Math_fround($67 + $46);
   $72 = Math_fround($68 + $48);
   HEAPF32[$5>>2] = $69;
   $$sum1$i = $i$06$i | 1;
   $73 = (($output) + ($$sum1$i<<2)|0);
   HEAPF32[$73>>2] = $70;
   $$sum2$i = $i$06$i | 2;
   $74 = (($output) + ($$sum2$i<<2)|0);
   HEAPF32[$74>>2] = $71;
   $$sum3$i = $i$06$i | 3;
   $75 = (($output) + ($$sum3$i<<2)|0);
   HEAPF32[$75>>2] = $72;
   $76 = (($caches$07$i) + 80|0);
   $77 = (($78) + 4)|0;
   $79 = ($77|0)>($2|0);
   if ($79) {
    $caches$0$lcssa$i = $76;$i$0$lcssa$i = $78;
    break;
   } else {
    $i$06$i$phi = $78;$78 = $77;$caches$07$i = $76;$i$06$i = $i$06$i$phi;
   }
  }
 }
 $4 = ($i$0$lcssa$i|0)<($2|0);
 if ($4) {
  $caches$15$i = $caches$0$lcssa$i;$i$14$i = $i$0$lcssa$i;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $80 = Math_fround(HEAPF32[$caches$15$i>>2]);
  $81 = Math_fround($time - $80);
  $82 = (($caches$15$i) + 4|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = Math_fround($81 * $83);
  $85 = (($caches$15$i) + 8|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = Math_fround($84 + $86);
  $88 = Math_fround($81 * $87);
  $89 = (($caches$15$i) + 12|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = Math_fround($90 + $88);
  $92 = Math_fround($81 * $91);
  $93 = (($caches$15$i) + 16|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = Math_fround($94 + $92);
  $96 = (($output) + ($i$14$i<<2)|0);
  HEAPF32[$96>>2] = $95;
  $97 = (($i$14$i) + 1)|0;
  $98 = (($caches$15$i) + 20|0);
  $exitcond = ($97|0)==($2|0);
  if ($exitcond) {
   break;
  } else {
   $caches$15$i = $98;$i$14$i = $97;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17SampleClipAtIndexERKNS0_12StreamedClipERNS0_18StreamedClipMemoryEif($curveData,$cache,$index,$time) {
 $curveData = $curveData|0;
 $cache = $cache|0;
 $index = $index|0;
 $time = Math_fround($time);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7mecanim9animation8SeekClipERKNS0_12StreamedClipERNS0_18StreamedClipMemoryEf($curveData,$cache,$time);
 $0 = HEAP32[$cache>>2]|0;
 $1 = (($0) + (($index*20)|0)|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($time - $2);
 $4 = ((($0) + (($index*20)|0)|0) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($3 * $5);
 $7 = ((($0) + (($index*20)|0)|0) + 8|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 + $8);
 $10 = Math_fround($3 * $9);
 $11 = ((($0) + (($index*20)|0)|0) + 12|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($12 + $10);
 $14 = Math_fround($3 * $13);
 $15 = ((($0) + (($index*20)|0)|0) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + $14);
 STACKTOP = sp;return (Math_fround($17));
}
function __ZN7mecanim9animation24CreateStreamedClipMemoryERKNS0_12StreamedClipERNS0_18StreamedClipMemoryERNS_6memory9AllocatorE($clip,$mem,$alloc) {
 $clip = $clip|0;
 $mem = $mem|0;
 $alloc = $alloc|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($clip) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = HEAP32[$alloc>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = ($1*20)|0;
  $6 = (FUNCTION_TABLE_iiii[$4 & 2047]($alloc,$5,4)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $$0$i = 0;
  } else {
   $$0$i = $6;
  }
 }
 HEAP32[$mem>>2] = $$0$i;
 $8 = HEAP32[$0>>2]|0;
 $9 = (($mem) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = (($mem) + 8|0);
 HEAPF32[$10>>2] = Math_fround(-inf);
 $11 = (($mem) + 12|0);
 HEAP32[$11>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation25DestroyStreamedClipMemoryERNS0_18StreamedClipMemoryERNS_6memory9AllocatorE($memory,$alloc) {
 $memory = $memory|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$memory>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($alloc,$3);
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation10SampleClipERKNS0_12ConstantClipEjPf($curveData,$outputCount,$output) {
 $curveData = $curveData|0;
 $outputCount = $outputCount|0;
 $output = $output|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($curveData) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($curveData) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = $3;
 $7 = $outputCount << 2;
 _memcpy(($output|0),($6|0),($7|0))|0;
 STACKTOP = sp;return;
}
function __ZN7mecanim9animation17SampleClipAtIndexERKNS0_12ConstantClipEi($curveData,$index) {
 $curveData = $curveData|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($curveData) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($4) + ($index<<2)|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 STACKTOP = sp;return (Math_fround($6));
}
function __ZN12_GLOBAL__N_19InitTableEv() {
 var $$02$i$i$i$i = 0, $$02$i$i$i$i104 = 0, $$02$i$i$i$i115 = 0, $$02$i$i$i$i126 = 0, $$02$i$i$i$i137 = 0, $$02$i$i$i$i148 = 0, $$02$i$i$i$i159 = 0, $$02$i$i$i$i170 = 0, $$02$i$i$i$i181 = 0, $$02$i$i$i$i192 = 0, $$02$i$i$i$i203 = 0, $$02$i$i$i$i214 = 0, $$02$i$i$i$i225 = 0, $$02$i$i$i$i236 = 0, $$02$i$i$i$i247 = 0, $$02$i$i$i$i258 = 0, $$02$i$i$i$i269 = 0, $$02$i$i$i$i280 = 0, $$02$i$i$i$i291 = 0, $$02$i$i$i$i302 = 0;
 var $$02$i$i$i$i313 = 0, $$02$i$i$i$i324 = 0, $$02$i$i$i$i335 = 0, $$02$i$i$i$i346 = 0, $$02$i$i$i$i357 = 0, $$02$i$i$i$i368 = 0, $$02$i$i$i$i379 = 0, $$02$i$i$i$i390 = 0, $$02$i$i$i$i401 = 0, $$02$i$i$i$i412 = 0, $$02$i$i$i$i423 = 0, $$02$i$i$i$i434 = 0, $$02$i$i$i$i445 = 0, $$02$i$i$i$i456 = 0, $$02$i$i$i$i467 = 0, $$02$i$i$i$i478 = 0, $$02$i$i$i$i489 = 0, $$02$i$i$i$i500 = 0, $$02$i$i$i$i511 = 0, $$02$i$i$i$i522 = 0;
 var $$02$i$i$i$i533 = 0, $$02$i$i$i$i544 = 0, $$02$i$i$i$i555 = 0, $$02$i$i$i$i566 = 0, $$02$i$i$i$i577 = 0, $$02$i$i$i$i588 = 0, $$02$i$i$i$i599 = 0, $$02$i$i$i$i610 = 0, $$02$i$i$i$i621 = 0, $$02$i$i$i$i632 = 0, $$02$i$i$i$i643 = 0, $$02$i$i$i$i654 = 0, $$02$i$i$i$i665 = 0, $$02$i$i$i$i676 = 0, $$02$i$i$i$i687 = 0, $$02$i$i$i$i698 = 0, $$02$i$i$i$i709 = 0, $$02$i$i$i$i720 = 0, $$02$i$i$i$i731 = 0, $$02$i$i$i$i742 = 0;
 var $$02$i$i$i$i753 = 0, $$02$i$i$i$i764 = 0, $$02$i$i$i$i775 = 0, $$02$i$i$i$i786 = 0, $$02$i$i$i$i797 = 0, $$02$i$i$i$i808 = 0, $$02$i$i$i$i819 = 0, $$02$i$i$i$i830 = 0, $$02$i$i$i$i841 = 0, $$masked$i$i$i = 0, $$masked$i$i$i$1 = 0, $$masked$i$i$i$10 = 0, $$masked$i$i$i$11 = 0, $$masked$i$i$i$2 = 0, $$masked$i$i$i$3 = 0, $$masked$i$i$i$4 = 0, $$masked$i$i$i$5 = 0, $$masked$i$i$i$6 = 0, $$masked$i$i$i$7 = 0, $$masked$i$i$i$8 = 0;
 var $$masked$i$i$i$9 = 0, $$masked$i$i$i110 = 0, $$masked$i$i$i121 = 0, $$masked$i$i$i121$1 = 0, $$masked$i$i$i121$2 = 0, $$masked$i$i$i121$3 = 0, $$masked$i$i$i121$4 = 0, $$masked$i$i$i121$5 = 0, $$masked$i$i$i132 = 0, $$masked$i$i$i143 = 0, $$masked$i$i$i143$1 = 0, $$masked$i$i$i143$2 = 0, $$masked$i$i$i143$3 = 0, $$masked$i$i$i143$4 = 0, $$masked$i$i$i143$5 = 0, $$masked$i$i$i154 = 0, $$masked$i$i$i165 = 0, $$masked$i$i$i165$1 = 0, $$masked$i$i$i165$2 = 0, $$masked$i$i$i165$3 = 0;
 var $$masked$i$i$i165$4 = 0, $$masked$i$i$i165$5 = 0, $$masked$i$i$i176 = 0, $$masked$i$i$i187 = 0, $$masked$i$i$i187$1 = 0, $$masked$i$i$i187$10 = 0, $$masked$i$i$i187$2 = 0, $$masked$i$i$i187$3 = 0, $$masked$i$i$i187$4 = 0, $$masked$i$i$i187$5 = 0, $$masked$i$i$i187$6 = 0, $$masked$i$i$i187$7 = 0, $$masked$i$i$i187$8 = 0, $$masked$i$i$i187$9 = 0, $$masked$i$i$i198 = 0, $$masked$i$i$i209 = 0, $$masked$i$i$i209$1 = 0, $$masked$i$i$i209$10 = 0, $$masked$i$i$i209$2 = 0, $$masked$i$i$i209$3 = 0;
 var $$masked$i$i$i209$4 = 0, $$masked$i$i$i209$5 = 0, $$masked$i$i$i209$6 = 0, $$masked$i$i$i209$7 = 0, $$masked$i$i$i209$8 = 0, $$masked$i$i$i209$9 = 0, $$masked$i$i$i220 = 0, $$masked$i$i$i231 = 0, $$masked$i$i$i231$1 = 0, $$masked$i$i$i231$10 = 0, $$masked$i$i$i231$2 = 0, $$masked$i$i$i231$3 = 0, $$masked$i$i$i231$4 = 0, $$masked$i$i$i231$5 = 0, $$masked$i$i$i231$6 = 0, $$masked$i$i$i231$7 = 0, $$masked$i$i$i231$8 = 0, $$masked$i$i$i231$9 = 0, $$masked$i$i$i242 = 0, $$masked$i$i$i253 = 0;
 var $$masked$i$i$i253$1 = 0, $$masked$i$i$i253$10 = 0, $$masked$i$i$i253$2 = 0, $$masked$i$i$i253$3 = 0, $$masked$i$i$i253$4 = 0, $$masked$i$i$i253$5 = 0, $$masked$i$i$i253$6 = 0, $$masked$i$i$i253$7 = 0, $$masked$i$i$i253$8 = 0, $$masked$i$i$i253$9 = 0, $$masked$i$i$i264 = 0, $$masked$i$i$i275 = 0, $$masked$i$i$i275$1 = 0, $$masked$i$i$i275$2 = 0, $$masked$i$i$i275$3 = 0, $$masked$i$i$i275$4 = 0, $$masked$i$i$i275$5 = 0, $$masked$i$i$i275$6 = 0, $$masked$i$i$i275$7 = 0, $$masked$i$i$i275$8 = 0;
 var $$masked$i$i$i286 = 0, $$masked$i$i$i297 = 0, $$masked$i$i$i297$1 = 0, $$masked$i$i$i297$2 = 0, $$masked$i$i$i297$3 = 0, $$masked$i$i$i297$4 = 0, $$masked$i$i$i297$5 = 0, $$masked$i$i$i297$6 = 0, $$masked$i$i$i297$7 = 0, $$masked$i$i$i297$8 = 0, $$masked$i$i$i308 = 0, $$masked$i$i$i319 = 0, $$masked$i$i$i319$1 = 0, $$masked$i$i$i319$2 = 0, $$masked$i$i$i319$3 = 0, $$masked$i$i$i319$4 = 0, $$masked$i$i$i319$5 = 0, $$masked$i$i$i319$6 = 0, $$masked$i$i$i319$7 = 0, $$masked$i$i$i319$8 = 0;
 var $$masked$i$i$i330 = 0, $$masked$i$i$i341 = 0, $$masked$i$i$i341$1 = 0, $$masked$i$i$i341$10 = 0, $$masked$i$i$i341$11 = 0, $$masked$i$i$i341$12 = 0, $$masked$i$i$i341$13 = 0, $$masked$i$i$i341$2 = 0, $$masked$i$i$i341$3 = 0, $$masked$i$i$i341$4 = 0, $$masked$i$i$i341$5 = 0, $$masked$i$i$i341$6 = 0, $$masked$i$i$i341$7 = 0, $$masked$i$i$i341$8 = 0, $$masked$i$i$i341$9 = 0, $$masked$i$i$i352 = 0, $$masked$i$i$i363 = 0, $$masked$i$i$i363$1 = 0, $$masked$i$i$i363$10 = 0, $$masked$i$i$i363$11 = 0;
 var $$masked$i$i$i363$12 = 0, $$masked$i$i$i363$2 = 0, $$masked$i$i$i363$3 = 0, $$masked$i$i$i363$4 = 0, $$masked$i$i$i363$5 = 0, $$masked$i$i$i363$6 = 0, $$masked$i$i$i363$7 = 0, $$masked$i$i$i363$8 = 0, $$masked$i$i$i363$9 = 0, $$masked$i$i$i374 = 0, $$masked$i$i$i374$1 = 0, $$masked$i$i$i374$2 = 0, $$masked$i$i$i374$3 = 0, $$masked$i$i$i374$4 = 0, $$masked$i$i$i374$5 = 0, $$masked$i$i$i385 = 0, $$masked$i$i$i385$1 = 0, $$masked$i$i$i385$2 = 0, $$masked$i$i$i385$3 = 0, $$masked$i$i$i385$4 = 0;
 var $$masked$i$i$i385$5 = 0, $$masked$i$i$i385$6 = 0, $$masked$i$i$i385$7 = 0, $$masked$i$i$i385$8 = 0, $$masked$i$i$i396 = 0, $$masked$i$i$i396$1 = 0, $$masked$i$i$i396$2 = 0, $$masked$i$i$i407 = 0, $$masked$i$i$i407$1 = 0, $$masked$i$i$i407$10 = 0, $$masked$i$i$i407$11 = 0, $$masked$i$i$i407$12 = 0, $$masked$i$i$i407$13 = 0, $$masked$i$i$i407$2 = 0, $$masked$i$i$i407$3 = 0, $$masked$i$i$i407$4 = 0, $$masked$i$i$i407$5 = 0, $$masked$i$i$i407$6 = 0, $$masked$i$i$i407$7 = 0, $$masked$i$i$i407$8 = 0;
 var $$masked$i$i$i407$9 = 0, $$masked$i$i$i418 = 0, $$masked$i$i$i418$1 = 0, $$masked$i$i$i418$2 = 0, $$masked$i$i$i429 = 0, $$masked$i$i$i429$1 = 0, $$masked$i$i$i429$10 = 0, $$masked$i$i$i429$11 = 0, $$masked$i$i$i429$12 = 0, $$masked$i$i$i429$2 = 0, $$masked$i$i$i429$3 = 0, $$masked$i$i$i429$4 = 0, $$masked$i$i$i429$5 = 0, $$masked$i$i$i429$6 = 0, $$masked$i$i$i429$7 = 0, $$masked$i$i$i429$8 = 0, $$masked$i$i$i429$9 = 0, $$masked$i$i$i440 = 0, $$masked$i$i$i440$1 = 0, $$masked$i$i$i440$2 = 0;
 var $$masked$i$i$i440$3 = 0, $$masked$i$i$i440$4 = 0, $$masked$i$i$i451 = 0, $$masked$i$i$i451$1 = 0, $$masked$i$i$i451$10 = 0, $$masked$i$i$i451$2 = 0, $$masked$i$i$i451$3 = 0, $$masked$i$i$i451$4 = 0, $$masked$i$i$i451$5 = 0, $$masked$i$i$i451$6 = 0, $$masked$i$i$i451$7 = 0, $$masked$i$i$i451$8 = 0, $$masked$i$i$i451$9 = 0, $$masked$i$i$i462 = 0, $$masked$i$i$i462$1 = 0, $$masked$i$i$i462$2 = 0, $$masked$i$i$i462$3 = 0, $$masked$i$i$i462$4 = 0, $$masked$i$i$i462$5 = 0, $$masked$i$i$i473 = 0;
 var $$masked$i$i$i473$1 = 0, $$masked$i$i$i473$10 = 0, $$masked$i$i$i473$2 = 0, $$masked$i$i$i473$3 = 0, $$masked$i$i$i473$4 = 0, $$masked$i$i$i473$5 = 0, $$masked$i$i$i473$6 = 0, $$masked$i$i$i473$7 = 0, $$masked$i$i$i473$8 = 0, $$masked$i$i$i473$9 = 0, $$masked$i$i$i484 = 0, $$masked$i$i$i484$1 = 0, $$masked$i$i$i484$2 = 0, $$masked$i$i$i484$3 = 0, $$masked$i$i$i484$4 = 0, $$masked$i$i$i484$5 = 0, $$masked$i$i$i495 = 0, $$masked$i$i$i495$1 = 0, $$masked$i$i$i495$2 = 0, $$masked$i$i$i495$3 = 0;
 var $$masked$i$i$i495$4 = 0, $$masked$i$i$i495$5 = 0, $$masked$i$i$i495$6 = 0, $$masked$i$i$i495$7 = 0, $$masked$i$i$i495$8 = 0, $$masked$i$i$i495$9 = 0, $$masked$i$i$i506 = 0, $$masked$i$i$i506$1 = 0, $$masked$i$i$i506$2 = 0, $$masked$i$i$i506$3 = 0, $$masked$i$i$i506$4 = 0, $$masked$i$i$i506$5 = 0, $$masked$i$i$i517 = 0, $$masked$i$i$i517$1 = 0, $$masked$i$i$i517$2 = 0, $$masked$i$i$i517$3 = 0, $$masked$i$i$i517$4 = 0, $$masked$i$i$i517$5 = 0, $$masked$i$i$i517$6 = 0, $$masked$i$i$i517$7 = 0;
 var $$masked$i$i$i517$8 = 0, $$masked$i$i$i517$9 = 0, $$masked$i$i$i528 = 0, $$masked$i$i$i528$1 = 0, $$masked$i$i$i528$2 = 0, $$masked$i$i$i528$3 = 0, $$masked$i$i$i528$4 = 0, $$masked$i$i$i528$5 = 0, $$masked$i$i$i539 = 0, $$masked$i$i$i550 = 0, $$masked$i$i$i550$1 = 0, $$masked$i$i$i561 = 0, $$masked$i$i$i572 = 0, $$masked$i$i$i572$1 = 0, $$masked$i$i$i572$2 = 0, $$masked$i$i$i583 = 0, $$masked$i$i$i583$1 = 0, $$masked$i$i$i583$10 = 0, $$masked$i$i$i583$11 = 0, $$masked$i$i$i583$12 = 0;
 var $$masked$i$i$i583$13 = 0, $$masked$i$i$i583$14 = 0, $$masked$i$i$i583$2 = 0, $$masked$i$i$i583$3 = 0, $$masked$i$i$i583$4 = 0, $$masked$i$i$i583$5 = 0, $$masked$i$i$i583$6 = 0, $$masked$i$i$i583$7 = 0, $$masked$i$i$i583$8 = 0, $$masked$i$i$i583$9 = 0, $$masked$i$i$i594 = 0, $$masked$i$i$i594$1 = 0, $$masked$i$i$i594$2 = 0, $$masked$i$i$i594$3 = 0, $$masked$i$i$i594$4 = 0, $$masked$i$i$i594$5 = 0, $$masked$i$i$i605 = 0, $$masked$i$i$i605$1 = 0, $$masked$i$i$i605$10 = 0, $$masked$i$i$i605$11 = 0;
 var $$masked$i$i$i605$12 = 0, $$masked$i$i$i605$13 = 0, $$masked$i$i$i605$14 = 0, $$masked$i$i$i605$2 = 0, $$masked$i$i$i605$3 = 0, $$masked$i$i$i605$4 = 0, $$masked$i$i$i605$5 = 0, $$masked$i$i$i605$6 = 0, $$masked$i$i$i605$7 = 0, $$masked$i$i$i605$8 = 0, $$masked$i$i$i605$9 = 0, $$masked$i$i$i616 = 0, $$masked$i$i$i616$1 = 0, $$masked$i$i$i616$2 = 0, $$masked$i$i$i616$3 = 0, $$masked$i$i$i616$4 = 0, $$masked$i$i$i616$5 = 0, $$masked$i$i$i627 = 0, $$masked$i$i$i627$1 = 0, $$masked$i$i$i627$10 = 0;
 var $$masked$i$i$i627$11 = 0, $$masked$i$i$i627$12 = 0, $$masked$i$i$i627$13 = 0, $$masked$i$i$i627$14 = 0, $$masked$i$i$i627$2 = 0, $$masked$i$i$i627$3 = 0, $$masked$i$i$i627$4 = 0, $$masked$i$i$i627$5 = 0, $$masked$i$i$i627$6 = 0, $$masked$i$i$i627$7 = 0, $$masked$i$i$i627$8 = 0, $$masked$i$i$i627$9 = 0, $$masked$i$i$i638 = 0, $$masked$i$i$i638$1 = 0, $$masked$i$i$i638$2 = 0, $$masked$i$i$i638$3 = 0, $$masked$i$i$i638$4 = 0, $$masked$i$i$i638$5 = 0, $$masked$i$i$i649 = 0, $$masked$i$i$i649$1 = 0;
 var $$masked$i$i$i649$10 = 0, $$masked$i$i$i649$11 = 0, $$masked$i$i$i649$12 = 0, $$masked$i$i$i649$13 = 0, $$masked$i$i$i649$14 = 0, $$masked$i$i$i649$2 = 0, $$masked$i$i$i649$3 = 0, $$masked$i$i$i649$4 = 0, $$masked$i$i$i649$5 = 0, $$masked$i$i$i649$6 = 0, $$masked$i$i$i649$7 = 0, $$masked$i$i$i649$8 = 0, $$masked$i$i$i649$9 = 0, $$masked$i$i$i660 = 0, $$masked$i$i$i660$1 = 0, $$masked$i$i$i660$2 = 0, $$masked$i$i$i660$3 = 0, $$masked$i$i$i660$4 = 0, $$masked$i$i$i660$5 = 0, $$masked$i$i$i671 = 0;
 var $$masked$i$i$i671$1 = 0, $$masked$i$i$i671$10 = 0, $$masked$i$i$i671$11 = 0, $$masked$i$i$i671$12 = 0, $$masked$i$i$i671$13 = 0, $$masked$i$i$i671$2 = 0, $$masked$i$i$i671$3 = 0, $$masked$i$i$i671$4 = 0, $$masked$i$i$i671$5 = 0, $$masked$i$i$i671$6 = 0, $$masked$i$i$i671$7 = 0, $$masked$i$i$i671$8 = 0, $$masked$i$i$i671$9 = 0, $$masked$i$i$i682 = 0, $$masked$i$i$i682$1 = 0, $$masked$i$i$i682$2 = 0, $$masked$i$i$i682$3 = 0, $$masked$i$i$i682$4 = 0, $$masked$i$i$i682$5 = 0, $$masked$i$i$i693 = 0;
 var $$masked$i$i$i693$1 = 0, $$masked$i$i$i693$10 = 0, $$masked$i$i$i693$11 = 0, $$masked$i$i$i693$12 = 0, $$masked$i$i$i693$13 = 0, $$masked$i$i$i693$2 = 0, $$masked$i$i$i693$3 = 0, $$masked$i$i$i693$4 = 0, $$masked$i$i$i693$5 = 0, $$masked$i$i$i693$6 = 0, $$masked$i$i$i693$7 = 0, $$masked$i$i$i693$8 = 0, $$masked$i$i$i693$9 = 0, $$masked$i$i$i704 = 0, $$masked$i$i$i704$1 = 0, $$masked$i$i$i704$2 = 0, $$masked$i$i$i704$3 = 0, $$masked$i$i$i704$4 = 0, $$masked$i$i$i704$5 = 0, $$masked$i$i$i704$6 = 0;
 var $$masked$i$i$i715 = 0, $$masked$i$i$i715$1 = 0, $$masked$i$i$i715$2 = 0, $$masked$i$i$i715$3 = 0, $$masked$i$i$i715$4 = 0, $$masked$i$i$i715$5 = 0, $$masked$i$i$i715$6 = 0, $$masked$i$i$i715$7 = 0, $$masked$i$i$i715$8 = 0, $$masked$i$i$i715$9 = 0, $$masked$i$i$i726 = 0, $$masked$i$i$i726$1 = 0, $$masked$i$i$i726$2 = 0, $$masked$i$i$i726$3 = 0, $$masked$i$i$i726$4 = 0, $$masked$i$i$i726$5 = 0, $$masked$i$i$i737 = 0, $$masked$i$i$i748 = 0, $$masked$i$i$i759 = 0, $$masked$i$i$i759$1 = 0;
 var $$masked$i$i$i759$2 = 0, $$masked$i$i$i759$3 = 0, $$masked$i$i$i759$4 = 0, $$masked$i$i$i770 = 0, $$masked$i$i$i770$1 = 0, $$masked$i$i$i770$10 = 0, $$masked$i$i$i770$11 = 0, $$masked$i$i$i770$12 = 0, $$masked$i$i$i770$2 = 0, $$masked$i$i$i770$3 = 0, $$masked$i$i$i770$4 = 0, $$masked$i$i$i770$5 = 0, $$masked$i$i$i770$6 = 0, $$masked$i$i$i770$7 = 0, $$masked$i$i$i770$8 = 0, $$masked$i$i$i770$9 = 0, $$masked$i$i$i781 = 0, $$masked$i$i$i781$1 = 0, $$masked$i$i$i781$10 = 0, $$masked$i$i$i781$2 = 0;
 var $$masked$i$i$i781$3 = 0, $$masked$i$i$i781$4 = 0, $$masked$i$i$i781$5 = 0, $$masked$i$i$i781$6 = 0, $$masked$i$i$i781$7 = 0, $$masked$i$i$i781$8 = 0, $$masked$i$i$i781$9 = 0, $$masked$i$i$i792 = 0, $$masked$i$i$i803 = 0, $$masked$i$i$i814 = 0, $$masked$i$i$i825 = 0, $$masked$i$i$i825$1 = 0, $$masked$i$i$i825$10 = 0, $$masked$i$i$i825$11 = 0, $$masked$i$i$i825$12 = 0, $$masked$i$i$i825$2 = 0, $$masked$i$i$i825$3 = 0, $$masked$i$i$i825$4 = 0, $$masked$i$i$i825$5 = 0, $$masked$i$i$i825$6 = 0;
 var $$masked$i$i$i825$7 = 0, $$masked$i$i$i825$8 = 0, $$masked$i$i$i825$9 = 0, $$masked$i$i$i836 = 0, $$masked$i$i$i836$1 = 0, $$masked$i$i$i836$2 = 0, $$masked$i$i$i836$3 = 0, $$masked$i$i$i836$4 = 0, $$masked$i$i$i836$5 = 0, $$masked$i$i$i836$6 = 0, $$masked$i$i$i836$7 = 0, $$masked$i$i$i836$8 = 0, $$masked$i$i$i847 = 0, $$masked$i$i$i847$1 = 0, $$masked$i$i$i847$2 = 0, $$masked$i$i$i847$3 = 0, $$masked$i$i$i847$4 = 0, $$masked$i$i$i847$5 = 0, $$masked$i$i$i847$6 = 0, $$masked$i$i$i847$7 = 0;
 var $$masked$i$i$i847$8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0;
 var $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0;
 var $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0;
 var $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0;
 var $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0;
 var $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0;
 var $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0;
 var $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0;
 var $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0;
 var $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0;
 var $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0;
 var $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0;
 var $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0;
 var $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0;
 var $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0;
 var $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0;
 var $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0;
 var $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0;
 var $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0;
 var $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0;
 var $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0;
 var $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0;
 var $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0;
 var $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0;
 var $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0;
 var $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0;
 var $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0;
 var $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0;
 var $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0;
 var $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0;
 var $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0;
 var $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0;
 var $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0;
 var $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0;
 var $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0;
 var $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0;
 var $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0;
 var $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0;
 var $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0;
 var $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0;
 var $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0;
 var $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0;
 var $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0;
 var $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0;
 var $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0;
 var $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0;
 var $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0;
 var $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0;
 var $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0;
 var $188 = 0, $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0;
 var $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0;
 var $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0;
 var $1933 = 0, $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0;
 var $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0;
 var $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0;
 var $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $2 = 0, $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0;
 var $2004 = 0, $2005 = 0, $2006 = 0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0;
 var $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0, $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0;
 var $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0, $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0;
 var $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0, $2067 = 0, $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0;
 var $2077 = 0, $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0;
 var $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0;
 var $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0;
 var $2130 = 0, $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0, $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0;
 var $2149 = 0, $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0, $2162 = 0, $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0;
 var $2167 = 0, $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0, $2174 = 0, $2175 = 0, $2176 = 0, $2177 = 0, $2178 = 0, $2179 = 0, $218 = 0, $2180 = 0, $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0;
 var $2185 = 0, $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0, $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0, $22 = 0, $220 = 0, $2200 = 0, $2201 = 0;
 var $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0, $2210 = 0, $2211 = 0, $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0, $2216 = 0, $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0;
 var $2220 = 0, $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0, $2228 = 0, $2229 = 0, $223 = 0, $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0, $2234 = 0, $2235 = 0, $2236 = 0, $2237 = 0, $2238 = 0;
 var $2239 = 0, $224 = 0, $2240 = 0, $2241 = 0, $2242 = 0, $2243 = 0, $2244 = 0, $2245 = 0, $2246 = 0, $2247 = 0, $2248 = 0, $2249 = 0, $225 = 0, $2250 = 0, $2251 = 0, $2252 = 0, $2253 = 0, $2254 = 0, $2255 = 0, $2256 = 0;
 var $2257 = 0, $2258 = 0, $2259 = 0, $226 = 0, $2260 = 0, $2261 = 0, $2262 = 0, $2263 = 0, $2264 = 0, $2265 = 0, $2266 = 0, $2267 = 0, $2268 = 0, $2269 = 0, $227 = 0, $2270 = 0, $2271 = 0, $2272 = 0, $2273 = 0, $2274 = 0;
 var $2275 = 0, $2276 = 0, $2277 = 0, $2278 = 0, $2279 = 0, $228 = 0, $2280 = 0, $2281 = 0, $2282 = 0, $2283 = 0, $2284 = 0, $2285 = 0, $2286 = 0, $2287 = 0, $2288 = 0, $2289 = 0, $229 = 0, $2290 = 0, $2291 = 0, $2292 = 0;
 var $2293 = 0, $2294 = 0, $2295 = 0, $2296 = 0, $2297 = 0, $2298 = 0, $2299 = 0, $23 = 0, $230 = 0, $2300 = 0, $2301 = 0, $2302 = 0, $2303 = 0, $2304 = 0, $2305 = 0, $2306 = 0, $2307 = 0, $2308 = 0, $2309 = 0, $231 = 0;
 var $2310 = 0, $2311 = 0, $2312 = 0, $2313 = 0, $2314 = 0, $2315 = 0, $2316 = 0, $2317 = 0, $2318 = 0, $2319 = 0, $232 = 0, $2320 = 0, $2321 = 0, $2322 = 0, $2323 = 0, $2324 = 0, $2325 = 0, $2326 = 0, $2327 = 0, $2328 = 0;
 var $2329 = 0, $233 = 0, $2330 = 0, $2331 = 0, $2332 = 0, $2333 = 0, $2334 = 0, $2335 = 0, $2336 = 0, $2337 = 0, $2338 = 0, $2339 = 0, $234 = 0, $2340 = 0, $2341 = 0, $2342 = 0, $2343 = 0, $2344 = 0, $2345 = 0, $2346 = 0;
 var $2347 = 0, $2348 = 0, $2349 = 0, $235 = 0, $2350 = 0, $2351 = 0, $2352 = 0, $2353 = 0, $2354 = 0, $2355 = 0, $2356 = 0, $2357 = 0, $2358 = 0, $2359 = 0, $236 = 0, $2360 = 0, $2361 = 0, $2362 = 0, $2363 = 0, $2364 = 0;
 var $2365 = 0, $2366 = 0, $2367 = 0, $2368 = 0, $2369 = 0, $237 = 0, $2370 = 0, $2371 = 0, $2372 = 0, $2373 = 0, $2374 = 0, $2375 = 0, $2376 = 0, $2377 = 0, $2378 = 0, $2379 = 0, $238 = 0, $2380 = 0, $2381 = 0, $2382 = 0;
 var $2383 = 0, $2384 = 0, $2385 = 0, $2386 = 0, $2387 = 0, $2388 = 0, $2389 = 0, $239 = 0, $2390 = 0, $2391 = 0, $2392 = 0, $2393 = 0, $2394 = 0, $2395 = 0, $2396 = 0, $2397 = 0, $2398 = 0, $2399 = 0, $24 = 0, $240 = 0;
 var $2400 = 0, $2401 = 0, $2402 = 0, $2403 = 0, $2404 = 0, $2405 = 0, $2406 = 0, $2407 = 0, $2408 = 0, $2409 = 0, $241 = 0, $2410 = 0, $2411 = 0, $2412 = 0, $2413 = 0, $2414 = 0, $2415 = 0, $2416 = 0, $2417 = 0, $2418 = 0;
 var $2419 = 0, $242 = 0, $2420 = 0, $2421 = 0, $2422 = 0, $2423 = 0, $2424 = 0, $2425 = 0, $2426 = 0, $2427 = 0, $2428 = 0, $2429 = 0, $243 = 0, $2430 = 0, $2431 = 0, $2432 = 0, $2433 = 0, $2434 = 0, $2435 = 0, $2436 = 0;
 var $2437 = 0, $2438 = 0, $2439 = 0, $244 = 0, $2440 = 0, $2441 = 0, $2442 = 0, $2443 = 0, $2444 = 0, $2445 = 0, $2446 = 0, $2447 = 0, $2448 = 0, $2449 = 0, $245 = 0, $2450 = 0, $2451 = 0, $2452 = 0, $2453 = 0, $2454 = 0;
 var $2455 = 0, $2456 = 0, $2457 = 0, $2458 = 0, $2459 = 0, $246 = 0, $2460 = 0, $2461 = 0, $2462 = 0, $2463 = 0, $2464 = 0, $2465 = 0, $2466 = 0, $2467 = 0, $2468 = 0, $2469 = 0, $247 = 0, $2470 = 0, $2471 = 0, $2472 = 0;
 var $2473 = 0, $2474 = 0, $2475 = 0, $2476 = 0, $2477 = 0, $2478 = 0, $2479 = 0, $248 = 0, $2480 = 0, $2481 = 0, $2482 = 0, $2483 = 0, $2484 = 0, $2485 = 0, $2486 = 0, $2487 = 0, $2488 = 0, $2489 = 0, $249 = 0, $2490 = 0;
 var $2491 = 0, $2492 = 0, $2493 = 0, $2494 = 0, $2495 = 0, $2496 = 0, $2497 = 0, $2498 = 0, $2499 = 0, $25 = 0, $250 = 0, $2500 = 0, $2501 = 0, $2502 = 0, $2503 = 0, $2504 = 0, $2505 = 0, $2506 = 0, $2507 = 0, $2508 = 0;
 var $2509 = 0, $251 = 0, $2510 = 0, $2511 = 0, $2512 = 0, $2513 = 0, $2514 = 0, $2515 = 0, $2516 = 0, $2517 = 0, $2518 = 0, $2519 = 0, $252 = 0, $2520 = 0, $2521 = 0, $2522 = 0, $2523 = 0, $2524 = 0, $2525 = 0, $2526 = 0;
 var $2527 = 0, $2528 = 0, $2529 = 0, $253 = 0, $2530 = 0, $2531 = 0, $2532 = 0, $2533 = 0, $2534 = 0, $2535 = 0, $2536 = 0, $2537 = 0, $2538 = 0, $2539 = 0, $254 = 0, $2540 = 0, $2541 = 0, $2542 = 0, $2543 = 0, $2544 = 0;
 var $2545 = 0, $2546 = 0, $2547 = 0, $2548 = 0, $2549 = 0, $255 = 0, $2550 = 0, $2551 = 0, $2552 = 0, $2553 = 0, $2554 = 0, $2555 = 0, $2556 = 0, $2557 = 0, $2558 = 0, $2559 = 0, $256 = 0, $2560 = 0, $2561 = 0, $2562 = 0;
 var $2563 = 0, $2564 = 0, $2565 = 0, $2566 = 0, $2567 = 0, $2568 = 0, $2569 = 0, $257 = 0, $2570 = 0, $2571 = 0, $2572 = 0, $2573 = 0, $2574 = 0, $2575 = 0, $2576 = 0, $2577 = 0, $2578 = 0, $2579 = 0, $258 = 0, $2580 = 0;
 var $2581 = 0, $2582 = 0, $2583 = 0, $2584 = 0, $2585 = 0, $2586 = 0, $2587 = 0, $2588 = 0, $2589 = 0, $259 = 0, $2590 = 0, $2591 = 0, $2592 = 0, $2593 = 0, $2594 = 0, $2595 = 0, $2596 = 0, $2597 = 0, $2598 = 0, $2599 = 0;
 var $26 = 0, $260 = 0, $2600 = 0, $2601 = 0, $2602 = 0, $2603 = 0, $2604 = 0, $2605 = 0, $2606 = 0, $2607 = 0, $2608 = 0, $2609 = 0, $261 = 0, $2610 = 0, $2611 = 0, $2612 = 0, $2613 = 0, $2614 = 0, $2615 = 0, $2616 = 0;
 var $2617 = 0, $2618 = 0, $2619 = 0, $262 = 0, $2620 = 0, $2621 = 0, $2622 = 0, $2623 = 0, $2624 = 0, $2625 = 0, $2626 = 0, $2627 = 0, $2628 = 0, $2629 = 0, $263 = 0, $2630 = 0, $2631 = 0, $2632 = 0, $2633 = 0, $2634 = 0;
 var $2635 = 0, $2636 = 0, $2637 = 0, $2638 = 0, $2639 = 0, $264 = 0, $2640 = 0, $2641 = 0, $2642 = 0, $2643 = 0, $2644 = 0, $2645 = 0, $2646 = 0, $2647 = 0, $2648 = 0, $2649 = 0, $265 = 0, $2650 = 0, $2651 = 0, $2652 = 0;
 var $2653 = 0, $2654 = 0, $2655 = 0, $2656 = 0, $2657 = 0, $2658 = 0, $2659 = 0, $266 = 0, $2660 = 0, $2661 = 0, $2662 = 0, $2663 = 0, $2664 = 0, $2665 = 0, $2666 = 0, $2667 = 0, $2668 = 0, $2669 = 0, $267 = 0, $2670 = 0;
 var $2671 = 0, $2672 = 0, $2673 = 0, $2674 = 0, $2675 = 0, $2676 = 0, $2677 = 0, $2678 = 0, $2679 = 0, $268 = 0, $2680 = 0, $2681 = 0, $2682 = 0, $2683 = 0, $2684 = 0, $2685 = 0, $2686 = 0, $2687 = 0, $2688 = 0, $2689 = 0;
 var $269 = 0, $2690 = 0, $2691 = 0, $2692 = 0, $2693 = 0, $2694 = 0, $2695 = 0, $2696 = 0, $2697 = 0, $2698 = 0, $2699 = 0, $27 = 0, $270 = 0, $2700 = 0, $2701 = 0, $2702 = 0, $2703 = 0, $2704 = 0, $2705 = 0, $2706 = 0;
 var $2707 = 0, $2708 = 0, $2709 = 0, $271 = 0, $2710 = 0, $2711 = 0, $2712 = 0, $2713 = 0, $2714 = 0, $2715 = 0, $2716 = 0, $2717 = 0, $2718 = 0, $2719 = 0, $272 = 0, $2720 = 0, $2721 = 0, $2722 = 0, $2723 = 0, $2724 = 0;
 var $2725 = 0, $2726 = 0, $2727 = 0, $2728 = 0, $2729 = 0, $273 = 0, $2730 = 0, $2731 = 0, $2732 = 0, $2733 = 0, $2734 = 0, $2735 = 0, $2736 = 0, $2737 = 0, $2738 = 0, $2739 = 0, $274 = 0, $2740 = 0, $2741 = 0, $2742 = 0;
 var $2743 = 0, $2744 = 0, $2745 = 0, $2746 = 0, $2747 = 0, $2748 = 0, $2749 = 0, $275 = 0, $2750 = 0, $2751 = 0, $2752 = 0, $2753 = 0, $2754 = 0, $2755 = 0, $2756 = 0, $2757 = 0, $2758 = 0, $2759 = 0, $276 = 0, $2760 = 0;
 var $2761 = 0, $2762 = 0, $2763 = 0, $2764 = 0, $2765 = 0, $2766 = 0, $2767 = 0, $2768 = 0, $2769 = 0, $277 = 0, $2770 = 0, $2771 = 0, $2772 = 0, $2773 = 0, $2774 = 0, $2775 = 0, $2776 = 0, $2777 = 0, $2778 = 0, $2779 = 0;
 var $278 = 0, $2780 = 0, $2781 = 0, $2782 = 0, $2783 = 0, $2784 = 0, $2785 = 0, $2786 = 0, $2787 = 0, $2788 = 0, $2789 = 0, $279 = 0, $2790 = 0, $2791 = 0, $2792 = 0, $2793 = 0, $2794 = 0, $2795 = 0, $2796 = 0, $2797 = 0;
 var $2798 = 0, $2799 = 0, $28 = 0, $280 = 0, $2800 = 0, $2801 = 0, $2802 = 0, $2803 = 0, $2804 = 0, $2805 = 0, $2806 = 0, $2807 = 0, $2808 = 0, $2809 = 0, $281 = 0, $2810 = 0, $2811 = 0, $2812 = 0, $2813 = 0, $2814 = 0;
 var $2815 = 0, $2816 = 0, $2817 = 0, $2818 = 0, $2819 = 0, $282 = 0, $2820 = 0, $2821 = 0, $2822 = 0, $2823 = 0, $2824 = 0, $2825 = 0, $2826 = 0, $2827 = 0, $2828 = 0, $2829 = 0, $283 = 0, $2830 = 0, $2831 = 0, $2832 = 0;
 var $2833 = 0, $2834 = 0, $2835 = 0, $2836 = 0, $2837 = 0, $2838 = 0, $2839 = 0, $284 = 0, $2840 = 0, $2841 = 0, $2842 = 0, $2843 = 0, $2844 = 0, $2845 = 0, $2846 = 0, $2847 = 0, $2848 = 0, $2849 = 0, $285 = 0, $2850 = 0;
 var $2851 = 0, $2852 = 0, $2853 = 0, $2854 = 0, $2855 = 0, $2856 = 0, $2857 = 0, $2858 = 0, $2859 = 0, $286 = 0, $2860 = 0, $2861 = 0, $2862 = 0, $2863 = 0, $2864 = 0, $2865 = 0, $2866 = 0, $2867 = 0, $2868 = 0, $2869 = 0;
 var $287 = 0, $2870 = 0, $2871 = 0, $2872 = 0, $2873 = 0, $2874 = 0, $2875 = 0, $2876 = 0, $2877 = 0, $2878 = 0, $2879 = 0, $288 = 0, $2880 = 0, $2881 = 0, $2882 = 0, $2883 = 0, $2884 = 0, $2885 = 0, $2886 = 0, $2887 = 0;
 var $2888 = 0, $2889 = 0, $289 = 0, $2890 = 0, $2891 = 0, $2892 = 0, $2893 = 0, $2894 = 0, $2895 = 0, $2896 = 0, $2897 = 0, $2898 = 0, $2899 = 0, $29 = 0, $290 = 0, $2900 = 0, $2901 = 0, $2902 = 0, $2903 = 0, $2904 = 0;
 var $2905 = 0, $2906 = 0, $2907 = 0, $2908 = 0, $2909 = 0, $291 = 0, $2910 = 0, $2911 = 0, $2912 = 0, $2913 = 0, $2914 = 0, $2915 = 0, $2916 = 0, $2917 = 0, $2918 = 0, $2919 = 0, $292 = 0, $2920 = 0, $2921 = 0, $2922 = 0;
 var $2923 = 0, $2924 = 0, $2925 = 0, $2926 = 0, $2927 = 0, $2928 = 0, $2929 = 0, $293 = 0, $2930 = 0, $2931 = 0, $2932 = 0, $2933 = 0, $2934 = 0, $2935 = 0, $2936 = 0, $2937 = 0, $2938 = 0, $2939 = 0, $294 = 0, $2940 = 0;
 var $2941 = 0, $2942 = 0, $2943 = 0, $2944 = 0, $2945 = 0, $2946 = 0, $2947 = 0, $2948 = 0, $2949 = 0, $295 = 0, $2950 = 0, $2951 = 0, $2952 = 0, $2953 = 0, $2954 = 0, $2955 = 0, $2956 = 0, $2957 = 0, $2958 = 0, $2959 = 0;
 var $296 = 0, $2960 = 0, $2961 = 0, $2962 = 0, $2963 = 0, $2964 = 0, $2965 = 0, $2966 = 0, $2967 = 0, $2968 = 0, $2969 = 0, $297 = 0, $2970 = 0, $2971 = 0, $2972 = 0, $2973 = 0, $2974 = 0, $2975 = 0, $2976 = 0, $2977 = 0;
 var $2978 = 0, $2979 = 0, $298 = 0, $2980 = 0, $2981 = 0, $2982 = 0, $2983 = 0, $2984 = 0, $2985 = 0, $2986 = 0, $2987 = 0, $2988 = 0, $2989 = 0, $299 = 0, $2990 = 0, $2991 = 0, $2992 = 0, $2993 = 0, $2994 = 0, $2995 = 0;
 var $2996 = 0, $2997 = 0, $2998 = 0, $2999 = 0, $3 = 0, $30 = 0, $300 = 0, $3000 = 0, $3001 = 0, $3002 = 0, $3003 = 0, $3004 = 0, $3005 = 0, $3006 = 0, $3007 = 0, $3008 = 0, $3009 = 0, $301 = 0, $3010 = 0, $3011 = 0;
 var $3012 = 0, $3013 = 0, $3014 = 0, $3015 = 0, $3016 = 0, $3017 = 0, $3018 = 0, $3019 = 0, $302 = 0, $3020 = 0, $3021 = 0, $3022 = 0, $3023 = 0, $3024 = 0, $3025 = 0, $3026 = 0, $3027 = 0, $3028 = 0, $3029 = 0, $303 = 0;
 var $3030 = 0, $3031 = 0, $3032 = 0, $3033 = 0, $3034 = 0, $3035 = 0, $3036 = 0, $3037 = 0, $3038 = 0, $3039 = 0, $304 = 0, $3040 = 0, $3041 = 0, $3042 = 0, $3043 = 0, $3044 = 0, $3045 = 0, $3046 = 0, $3047 = 0, $3048 = 0;
 var $3049 = 0, $305 = 0, $3050 = 0, $3051 = 0, $3052 = 0, $3053 = 0, $3054 = 0, $3055 = 0, $3056 = 0, $3057 = 0, $3058 = 0, $3059 = 0, $306 = 0, $3060 = 0, $3061 = 0, $3062 = 0, $3063 = 0, $3064 = 0, $3065 = 0, $3066 = 0;
 var $3067 = 0, $3068 = 0, $3069 = 0, $307 = 0, $3070 = 0, $3071 = 0, $3072 = 0, $3073 = 0, $3074 = 0, $3075 = 0, $3076 = 0, $3077 = 0, $3078 = 0, $3079 = 0, $308 = 0, $3080 = 0, $3081 = 0, $3082 = 0, $3083 = 0, $3084 = 0;
 var $3085 = 0, $3086 = 0, $3087 = 0, $3088 = 0, $3089 = 0, $309 = 0, $3090 = 0, $3091 = 0, $3092 = 0, $3093 = 0, $3094 = 0, $3095 = 0, $3096 = 0, $3097 = 0, $3098 = 0, $3099 = 0, $31 = 0, $310 = 0, $3100 = 0, $3101 = 0;
 var $3102 = 0, $3103 = 0, $3104 = 0, $3105 = 0, $3106 = 0, $3107 = 0, $3108 = 0, $3109 = 0, $311 = 0, $3110 = 0, $3111 = 0, $3112 = 0, $3113 = 0, $3114 = 0, $3115 = 0, $3116 = 0, $3117 = 0, $3118 = 0, $3119 = 0, $312 = 0;
 var $3120 = 0, $3121 = 0, $3122 = 0, $3123 = 0, $3124 = 0, $3125 = 0, $3126 = 0, $3127 = 0, $3128 = 0, $3129 = 0, $313 = 0, $3130 = 0, $3131 = 0, $3132 = 0, $3133 = 0, $3134 = 0, $3135 = 0, $3136 = 0, $3137 = 0, $3138 = 0;
 var $3139 = 0, $314 = 0, $3140 = 0, $3141 = 0, $3142 = 0, $3143 = 0, $3144 = 0, $3145 = 0, $3146 = 0, $3147 = 0, $3148 = 0, $3149 = 0, $315 = 0, $3150 = 0, $3151 = 0, $3152 = 0, $3153 = 0, $3154 = 0, $3155 = 0, $3156 = 0;
 var $3157 = 0, $3158 = 0, $3159 = 0, $316 = 0, $3160 = 0, $3161 = 0, $3162 = 0, $3163 = 0, $3164 = 0, $3165 = 0, $3166 = 0, $3167 = 0, $3168 = 0, $3169 = 0, $317 = 0, $3170 = 0, $3171 = 0, $3172 = 0, $3173 = 0, $3174 = 0;
 var $3175 = 0, $3176 = 0, $3177 = 0, $3178 = 0, $3179 = 0, $318 = 0, $3180 = 0, $3181 = 0, $3182 = 0, $3183 = 0, $3184 = 0, $3185 = 0, $3186 = 0, $3187 = 0, $3188 = 0, $3189 = 0, $319 = 0, $3190 = 0, $3191 = 0, $3192 = 0;
 var $3193 = 0, $3194 = 0, $3195 = 0, $3196 = 0, $3197 = 0, $3198 = 0, $3199 = 0, $32 = 0, $320 = 0, $3200 = 0, $3201 = 0, $3202 = 0, $3203 = 0, $3204 = 0, $3205 = 0, $3206 = 0, $3207 = 0, $3208 = 0, $3209 = 0, $321 = 0;
 var $3210 = 0, $3211 = 0, $3212 = 0, $3213 = 0, $3214 = 0, $3215 = 0, $3216 = 0, $3217 = 0, $3218 = 0, $3219 = 0, $322 = 0, $3220 = 0, $3221 = 0, $3222 = 0, $3223 = 0, $3224 = 0, $3225 = 0, $3226 = 0, $3227 = 0, $3228 = 0;
 var $3229 = 0, $323 = 0, $3230 = 0, $3231 = 0, $3232 = 0, $3233 = 0, $3234 = 0, $3235 = 0, $3236 = 0, $3237 = 0, $3238 = 0, $3239 = 0, $324 = 0, $3240 = 0, $3241 = 0, $3242 = 0, $3243 = 0, $3244 = 0, $3245 = 0, $3246 = 0;
 var $3247 = 0, $3248 = 0, $3249 = 0, $325 = 0, $3250 = 0, $3251 = 0, $3252 = 0, $3253 = 0, $3254 = 0, $3255 = 0, $3256 = 0, $3257 = 0, $3258 = 0, $3259 = 0, $326 = 0, $3260 = 0, $3261 = 0, $3262 = 0, $3263 = 0, $3264 = 0;
 var $3265 = 0, $3266 = 0, $3267 = 0, $3268 = 0, $3269 = 0, $327 = 0, $3270 = 0, $3271 = 0, $3272 = 0, $3273 = 0, $3274 = 0, $3275 = 0, $3276 = 0, $3277 = 0, $3278 = 0, $3279 = 0, $328 = 0, $3280 = 0, $3281 = 0, $3282 = 0;
 var $3283 = 0, $3284 = 0, $3285 = 0, $3286 = 0, $3287 = 0, $3288 = 0, $3289 = 0, $329 = 0, $3290 = 0, $3291 = 0, $3292 = 0, $3293 = 0, $3294 = 0, $3295 = 0, $3296 = 0, $3297 = 0, $3298 = 0, $3299 = 0, $33 = 0, $330 = 0;
 var $3300 = 0, $3301 = 0, $3302 = 0, $3303 = 0, $3304 = 0, $3305 = 0, $3306 = 0, $3307 = 0, $3308 = 0, $3309 = 0, $331 = 0, $3310 = 0, $3311 = 0, $3312 = 0, $3313 = 0, $3314 = 0, $3315 = 0, $3316 = 0, $3317 = 0, $3318 = 0;
 var $3319 = 0, $332 = 0, $3320 = 0, $3321 = 0, $3322 = 0, $3323 = 0, $3324 = 0, $3325 = 0, $3326 = 0, $3327 = 0, $3328 = 0, $3329 = 0, $333 = 0, $3330 = 0, $3331 = 0, $3332 = 0, $3333 = 0, $3334 = 0, $3335 = 0, $3336 = 0;
 var $3337 = 0, $3338 = 0, $3339 = 0, $334 = 0, $3340 = 0, $3341 = 0, $3342 = 0, $3343 = 0, $3344 = 0, $3345 = 0, $3346 = 0, $3347 = 0, $3348 = 0, $3349 = 0, $335 = 0, $3350 = 0, $3351 = 0, $3352 = 0, $3353 = 0, $3354 = 0;
 var $3355 = 0, $3356 = 0, $3357 = 0, $3358 = 0, $3359 = 0, $336 = 0, $3360 = 0, $3361 = 0, $3362 = 0, $3363 = 0, $3364 = 0, $3365 = 0, $3366 = 0, $3367 = 0, $3368 = 0, $3369 = 0, $337 = 0, $3370 = 0, $3371 = 0, $3372 = 0;
 var $3373 = 0, $3374 = 0, $3375 = 0, $3376 = 0, $3377 = 0, $3378 = 0, $3379 = 0, $338 = 0, $3380 = 0, $3381 = 0, $3382 = 0, $3383 = 0, $3384 = 0, $3385 = 0, $3386 = 0, $3387 = 0, $3388 = 0, $3389 = 0, $339 = 0, $3390 = 0;
 var $3391 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0;
 var $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0;
 var $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0;
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0;
 var $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0;
 var $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0;
 var $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0;
 var $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0;
 var $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0;
 var $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0;
 var $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0;
 var $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0;
 var $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0;
 var $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0;
 var $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0;
 var $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0;
 var $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0;
 var $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0;
 var $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0;
 var $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0;
 var $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0;
 var $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0;
 var $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0;
 var $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0;
 var $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0;
 var $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0;
 var $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0;
 var $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0;
 var $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0;
 var $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0;
 var $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0;
 var $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0;
 var $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $exitcond$i$i$i$i = 0, $exitcond$i$i$i$i107 = 0, $exitcond$i$i$i$i118 = 0, $exitcond$i$i$i$i129 = 0, $exitcond$i$i$i$i140 = 0, $exitcond$i$i$i$i151 = 0, $exitcond$i$i$i$i162 = 0;
 var $exitcond$i$i$i$i173 = 0, $exitcond$i$i$i$i184 = 0, $exitcond$i$i$i$i195 = 0, $exitcond$i$i$i$i206 = 0, $exitcond$i$i$i$i217 = 0, $exitcond$i$i$i$i228 = 0, $exitcond$i$i$i$i239 = 0, $exitcond$i$i$i$i250 = 0, $exitcond$i$i$i$i261 = 0, $exitcond$i$i$i$i272 = 0, $exitcond$i$i$i$i283 = 0, $exitcond$i$i$i$i294 = 0, $exitcond$i$i$i$i305 = 0, $exitcond$i$i$i$i316 = 0, $exitcond$i$i$i$i327 = 0, $exitcond$i$i$i$i338 = 0, $exitcond$i$i$i$i349 = 0, $exitcond$i$i$i$i360 = 0, $exitcond$i$i$i$i371 = 0, $exitcond$i$i$i$i382 = 0;
 var $exitcond$i$i$i$i393 = 0, $exitcond$i$i$i$i404 = 0, $exitcond$i$i$i$i415 = 0, $exitcond$i$i$i$i426 = 0, $exitcond$i$i$i$i437 = 0, $exitcond$i$i$i$i448 = 0, $exitcond$i$i$i$i459 = 0, $exitcond$i$i$i$i470 = 0, $exitcond$i$i$i$i481 = 0, $exitcond$i$i$i$i492 = 0, $exitcond$i$i$i$i503 = 0, $exitcond$i$i$i$i514 = 0, $exitcond$i$i$i$i525 = 0, $exitcond$i$i$i$i536 = 0, $exitcond$i$i$i$i547 = 0, $exitcond$i$i$i$i558 = 0, $exitcond$i$i$i$i569 = 0, $exitcond$i$i$i$i580 = 0, $exitcond$i$i$i$i591 = 0, $exitcond$i$i$i$i602 = 0;
 var $exitcond$i$i$i$i613 = 0, $exitcond$i$i$i$i624 = 0, $exitcond$i$i$i$i635 = 0, $exitcond$i$i$i$i646 = 0, $exitcond$i$i$i$i657 = 0, $exitcond$i$i$i$i668 = 0, $exitcond$i$i$i$i679 = 0, $exitcond$i$i$i$i690 = 0, $exitcond$i$i$i$i701 = 0, $exitcond$i$i$i$i712 = 0, $exitcond$i$i$i$i723 = 0, $exitcond$i$i$i$i734 = 0, $exitcond$i$i$i$i745 = 0, $exitcond$i$i$i$i756 = 0, $exitcond$i$i$i$i767 = 0, $exitcond$i$i$i$i778 = 0, $exitcond$i$i$i$i789 = 0, $exitcond$i$i$i$i800 = 0, $exitcond$i$i$i$i811 = 0, $exitcond$i$i$i$i822 = 0;
 var $exitcond$i$i$i$i833 = 0, $exitcond$i$i$i$i844 = 0, $exitcond$i$i$i540 = 0, $exitcond$i$i$i562 = 0, $exitcond$i$i$i738 = 0, $exitcond$i$i$i749 = 0, $exitcond$i$i$i793 = 0, $exitcond$i$i$i804 = 0, $exitcond$i$i$i815 = 0, $i$03$i$i$i$i = 0, $i$03$i$i$i$i103 = 0, $i$03$i$i$i$i114 = 0, $i$03$i$i$i$i125 = 0, $i$03$i$i$i$i136 = 0, $i$03$i$i$i$i147 = 0, $i$03$i$i$i$i158 = 0, $i$03$i$i$i$i169 = 0, $i$03$i$i$i$i180 = 0, $i$03$i$i$i$i191 = 0, $i$03$i$i$i$i202 = 0;
 var $i$03$i$i$i$i213 = 0, $i$03$i$i$i$i224 = 0, $i$03$i$i$i$i235 = 0, $i$03$i$i$i$i246 = 0, $i$03$i$i$i$i257 = 0, $i$03$i$i$i$i268 = 0, $i$03$i$i$i$i279 = 0, $i$03$i$i$i$i290 = 0, $i$03$i$i$i$i301 = 0, $i$03$i$i$i$i312 = 0, $i$03$i$i$i$i323 = 0, $i$03$i$i$i$i334 = 0, $i$03$i$i$i$i345 = 0, $i$03$i$i$i$i356 = 0, $i$03$i$i$i$i367 = 0, $i$03$i$i$i$i378 = 0, $i$03$i$i$i$i389 = 0, $i$03$i$i$i$i400 = 0, $i$03$i$i$i$i411 = 0, $i$03$i$i$i$i422 = 0;
 var $i$03$i$i$i$i433 = 0, $i$03$i$i$i$i444 = 0, $i$03$i$i$i$i455 = 0, $i$03$i$i$i$i466 = 0, $i$03$i$i$i$i477 = 0, $i$03$i$i$i$i488 = 0, $i$03$i$i$i$i499 = 0, $i$03$i$i$i$i510 = 0, $i$03$i$i$i$i521 = 0, $i$03$i$i$i$i532 = 0, $i$03$i$i$i$i543 = 0, $i$03$i$i$i$i554 = 0, $i$03$i$i$i$i565 = 0, $i$03$i$i$i$i576 = 0, $i$03$i$i$i$i587 = 0, $i$03$i$i$i$i598 = 0, $i$03$i$i$i$i609 = 0, $i$03$i$i$i$i620 = 0, $i$03$i$i$i$i631 = 0, $i$03$i$i$i$i642 = 0;
 var $i$03$i$i$i$i653 = 0, $i$03$i$i$i$i664 = 0, $i$03$i$i$i$i675 = 0, $i$03$i$i$i$i686 = 0, $i$03$i$i$i$i697 = 0, $i$03$i$i$i$i708 = 0, $i$03$i$i$i$i719 = 0, $i$03$i$i$i$i730 = 0, $i$03$i$i$i$i741 = 0, $i$03$i$i$i$i752 = 0, $i$03$i$i$i$i763 = 0, $i$03$i$i$i$i774 = 0, $i$03$i$i$i$i785 = 0, $i$03$i$i$i$i796 = 0, $i$03$i$i$i$i807 = 0, $i$03$i$i$i$i818 = 0, $i$03$i$i$i$i829 = 0, $i$03$i$i$i$i840 = 0, $p$01$i$i$i538 = 0, $p$01$i$i$i560 = 0;
 var $p$01$i$i$i736 = 0, $p$01$i$i$i747 = 0, $p$01$i$i$i791 = 0, $p$01$i$i$i802 = 0, $p$01$i$i$i813 = 0, $reflection$01$i$i$i$i = 0, $reflection$01$i$i$i$i105 = 0, $reflection$01$i$i$i$i116 = 0, $reflection$01$i$i$i$i127 = 0, $reflection$01$i$i$i$i138 = 0, $reflection$01$i$i$i$i149 = 0, $reflection$01$i$i$i$i160 = 0, $reflection$01$i$i$i$i171 = 0, $reflection$01$i$i$i$i182 = 0, $reflection$01$i$i$i$i193 = 0, $reflection$01$i$i$i$i204 = 0, $reflection$01$i$i$i$i215 = 0, $reflection$01$i$i$i$i226 = 0, $reflection$01$i$i$i$i237 = 0, $reflection$01$i$i$i$i248 = 0;
 var $reflection$01$i$i$i$i259 = 0, $reflection$01$i$i$i$i270 = 0, $reflection$01$i$i$i$i281 = 0, $reflection$01$i$i$i$i292 = 0, $reflection$01$i$i$i$i303 = 0, $reflection$01$i$i$i$i314 = 0, $reflection$01$i$i$i$i325 = 0, $reflection$01$i$i$i$i336 = 0, $reflection$01$i$i$i$i347 = 0, $reflection$01$i$i$i$i358 = 0, $reflection$01$i$i$i$i369 = 0, $reflection$01$i$i$i$i380 = 0, $reflection$01$i$i$i$i391 = 0, $reflection$01$i$i$i$i402 = 0, $reflection$01$i$i$i$i413 = 0, $reflection$01$i$i$i$i424 = 0, $reflection$01$i$i$i$i435 = 0, $reflection$01$i$i$i$i446 = 0, $reflection$01$i$i$i$i457 = 0, $reflection$01$i$i$i$i468 = 0;
 var $reflection$01$i$i$i$i479 = 0, $reflection$01$i$i$i$i490 = 0, $reflection$01$i$i$i$i501 = 0, $reflection$01$i$i$i$i512 = 0, $reflection$01$i$i$i$i523 = 0, $reflection$01$i$i$i$i534 = 0, $reflection$01$i$i$i$i545 = 0, $reflection$01$i$i$i$i556 = 0, $reflection$01$i$i$i$i567 = 0, $reflection$01$i$i$i$i578 = 0, $reflection$01$i$i$i$i589 = 0, $reflection$01$i$i$i$i600 = 0, $reflection$01$i$i$i$i611 = 0, $reflection$01$i$i$i$i622 = 0, $reflection$01$i$i$i$i633 = 0, $reflection$01$i$i$i$i644 = 0, $reflection$01$i$i$i$i655 = 0, $reflection$01$i$i$i$i666 = 0, $reflection$01$i$i$i$i677 = 0, $reflection$01$i$i$i$i688 = 0;
 var $reflection$01$i$i$i$i699 = 0, $reflection$01$i$i$i$i710 = 0, $reflection$01$i$i$i$i721 = 0, $reflection$01$i$i$i$i732 = 0, $reflection$01$i$i$i$i743 = 0, $reflection$01$i$i$i$i754 = 0, $reflection$01$i$i$i$i765 = 0, $reflection$01$i$i$i$i776 = 0, $reflection$01$i$i$i$i787 = 0, $reflection$01$i$i$i$i798 = 0, $reflection$01$i$i$i$i809 = 0, $reflection$01$i$i$i$i820 = 0, $reflection$01$i$i$i$i831 = 0, $reflection$01$i$i$i$i842 = 0, $reflection$1$i$i$i$i = 0, $reflection$1$i$i$i$i106 = 0, $reflection$1$i$i$i$i117 = 0, $reflection$1$i$i$i$i128 = 0, $reflection$1$i$i$i$i139 = 0, $reflection$1$i$i$i$i150 = 0;
 var $reflection$1$i$i$i$i161 = 0, $reflection$1$i$i$i$i172 = 0, $reflection$1$i$i$i$i183 = 0, $reflection$1$i$i$i$i194 = 0, $reflection$1$i$i$i$i205 = 0, $reflection$1$i$i$i$i216 = 0, $reflection$1$i$i$i$i227 = 0, $reflection$1$i$i$i$i238 = 0, $reflection$1$i$i$i$i249 = 0, $reflection$1$i$i$i$i260 = 0, $reflection$1$i$i$i$i271 = 0, $reflection$1$i$i$i$i282 = 0, $reflection$1$i$i$i$i293 = 0, $reflection$1$i$i$i$i304 = 0, $reflection$1$i$i$i$i315 = 0, $reflection$1$i$i$i$i326 = 0, $reflection$1$i$i$i$i337 = 0, $reflection$1$i$i$i$i348 = 0, $reflection$1$i$i$i$i359 = 0, $reflection$1$i$i$i$i370 = 0;
 var $reflection$1$i$i$i$i381 = 0, $reflection$1$i$i$i$i392 = 0, $reflection$1$i$i$i$i403 = 0, $reflection$1$i$i$i$i414 = 0, $reflection$1$i$i$i$i425 = 0, $reflection$1$i$i$i$i436 = 0, $reflection$1$i$i$i$i447 = 0, $reflection$1$i$i$i$i458 = 0, $reflection$1$i$i$i$i469 = 0, $reflection$1$i$i$i$i480 = 0, $reflection$1$i$i$i$i491 = 0, $reflection$1$i$i$i$i502 = 0, $reflection$1$i$i$i$i513 = 0, $reflection$1$i$i$i$i524 = 0, $reflection$1$i$i$i$i535 = 0, $reflection$1$i$i$i$i546 = 0, $reflection$1$i$i$i$i557 = 0, $reflection$1$i$i$i$i568 = 0, $reflection$1$i$i$i$i579 = 0, $reflection$1$i$i$i$i590 = 0;
 var $reflection$1$i$i$i$i601 = 0, $reflection$1$i$i$i$i612 = 0, $reflection$1$i$i$i$i623 = 0, $reflection$1$i$i$i$i634 = 0, $reflection$1$i$i$i$i645 = 0, $reflection$1$i$i$i$i656 = 0, $reflection$1$i$i$i$i667 = 0, $reflection$1$i$i$i$i678 = 0, $reflection$1$i$i$i$i689 = 0, $reflection$1$i$i$i$i700 = 0, $reflection$1$i$i$i$i711 = 0, $reflection$1$i$i$i$i722 = 0, $reflection$1$i$i$i$i733 = 0, $reflection$1$i$i$i$i744 = 0, $reflection$1$i$i$i$i755 = 0, $reflection$1$i$i$i$i766 = 0, $reflection$1$i$i$i$i777 = 0, $reflection$1$i$i$i$i788 = 0, $reflection$1$i$i$i$i799 = 0, $reflection$1$i$i$i$i810 = 0;
 var $reflection$1$i$i$i$i821 = 0, $reflection$1$i$i$i$i832 = 0, $reflection$1$i$i$i$i843 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[795016>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = 794192;
  while(1) {
   HEAP32[$2>>2] = 0;
   $3 = (($2) + 4|0);
   HEAP32[$3>>2] = 0;
   $4 = (($2) + 8|0);
   $5 = ($4|0)==(((794192 + 824|0))|0);
   if ($5) {
    break;
   } else {
    $2 = $4;
   }
  }
  HEAP8[795016>>0] = 1;
  $$02$i$i$i$i104 = -1;$i$03$i$i$i$i103 = 0;$reflection$01$i$i$i$i105 = 0;
 } else {
  $$02$i$i$i$i104 = -1;$i$03$i$i$i$i103 = 0;$reflection$01$i$i$i$i105 = 0;
 }
 while(1) {
  $6 = $$02$i$i$i$i104 & 1;
  $7 = ($6|0)==(0);
  if ($7) {
   $reflection$1$i$i$i$i106 = $reflection$01$i$i$i$i105;
  } else {
   $8 = (31 - ($i$03$i$i$i$i103))|0;
   $9 = 1 << $8;
   $10 = $9 | $reflection$01$i$i$i$i105;
   $reflection$1$i$i$i$i106 = $10;
  }
  $11 = (($i$03$i$i$i$i103) + 1)|0;
  $12 = $$02$i$i$i$i104 >>> 1;
  $exitcond$i$i$i$i107 = ($11|0)==(32);
  if ($exitcond$i$i$i$i107) {
   break;
  } else {
   $$02$i$i$i$i104 = $12;$i$03$i$i$i$i103 = $11;$reflection$01$i$i$i$i105 = $reflection$1$i$i$i$i106;
  }
 }
 $13 = $reflection$1$i$i$i$i106 >>> 8;
 $$masked$i$i$i110 = $reflection$1$i$i$i$i106 & 255;
 $14 = $$masked$i$i$i110 ^ 84;
 $15 = (584048 + ($14<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 ^ $13;
 $18 = $17 ^ -1;
 $19 = 794192;
 $20 = $19;
 HEAP32[$20>>2] = $18;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = (795024);
 $$02$i$i$i$i126 = -1;$i$03$i$i$i$i125 = 0;$reflection$01$i$i$i$i127 = 0;
 while(1) {
  $23 = $$02$i$i$i$i126 & 1;
  $24 = ($23|0)==(0);
  if ($24) {
   $reflection$1$i$i$i$i128 = $reflection$01$i$i$i$i127;
  } else {
   $25 = (31 - ($i$03$i$i$i$i125))|0;
   $26 = 1 << $25;
   $27 = $26 | $reflection$01$i$i$i$i127;
   $reflection$1$i$i$i$i128 = $27;
  }
  $28 = (($i$03$i$i$i$i125) + 1)|0;
  $29 = $$02$i$i$i$i126 >>> 1;
  $exitcond$i$i$i$i129 = ($28|0)==(32);
  if ($exitcond$i$i$i$i129) {
   break;
  } else {
   $$02$i$i$i$i126 = $29;$i$03$i$i$i$i125 = $28;$reflection$01$i$i$i$i127 = $reflection$1$i$i$i$i128;
  }
 }
 $30 = $reflection$1$i$i$i$i128 >>> 8;
 $$masked$i$i$i132 = $reflection$1$i$i$i$i128 & 255;
 $31 = $$masked$i$i$i132 ^ 81;
 $32 = (584048 + ($31<<2)|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $33 ^ $30;
 $35 = $34 ^ -1;
 $36 = ((794192 + 8|0));
 $37 = $36;
 HEAP32[$37>>2] = $35;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = (795032);
 $$02$i$i$i$i148 = -1;$i$03$i$i$i$i147 = 0;$reflection$01$i$i$i$i149 = 0;
 while(1) {
  $40 = $$02$i$i$i$i148 & 1;
  $41 = ($40|0)==(0);
  if ($41) {
   $reflection$1$i$i$i$i150 = $reflection$01$i$i$i$i149;
  } else {
   $42 = (31 - ($i$03$i$i$i$i147))|0;
   $43 = 1 << $42;
   $44 = $43 | $reflection$01$i$i$i$i149;
   $reflection$1$i$i$i$i150 = $44;
  }
  $45 = (($i$03$i$i$i$i147) + 1)|0;
  $46 = $$02$i$i$i$i148 >>> 1;
  $exitcond$i$i$i$i151 = ($45|0)==(32);
  if ($exitcond$i$i$i$i151) {
   break;
  } else {
   $$02$i$i$i$i148 = $46;$i$03$i$i$i$i147 = $45;$reflection$01$i$i$i$i149 = $reflection$1$i$i$i$i150;
  }
 }
 $47 = $reflection$1$i$i$i$i150 >>> 8;
 $$masked$i$i$i154 = $reflection$1$i$i$i$i150 & 255;
 $48 = $$masked$i$i$i154 ^ 83;
 $49 = (584048 + ($48<<2)|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 ^ $47;
 $52 = $51 ^ -1;
 $53 = ((794192 + 16|0));
 $54 = $53;
 HEAP32[$54>>2] = $52;
 $55 = (($53) + 4)|0;
 $56 = $55;
 HEAP32[$56>>2] = (795040);
 $$02$i$i$i$i170 = -1;$i$03$i$i$i$i169 = 0;$reflection$01$i$i$i$i171 = 0;
 while(1) {
  $57 = $$02$i$i$i$i170 & 1;
  $58 = ($57|0)==(0);
  if ($58) {
   $reflection$1$i$i$i$i172 = $reflection$01$i$i$i$i171;
  } else {
   $59 = (31 - ($i$03$i$i$i$i169))|0;
   $60 = 1 << $59;
   $61 = $60 | $reflection$01$i$i$i$i171;
   $reflection$1$i$i$i$i172 = $61;
  }
  $62 = (($i$03$i$i$i$i169) + 1)|0;
  $63 = $$02$i$i$i$i170 >>> 1;
  $exitcond$i$i$i$i173 = ($62|0)==(32);
  if ($exitcond$i$i$i$i173) {
   break;
  } else {
   $$02$i$i$i$i170 = $63;$i$03$i$i$i$i169 = $62;$reflection$01$i$i$i$i171 = $reflection$1$i$i$i$i172;
  }
 }
 $64 = $reflection$1$i$i$i$i172 >>> 8;
 $$masked$i$i$i176 = $reflection$1$i$i$i$i172 & 255;
 $65 = $$masked$i$i$i176 ^ 65;
 $66 = (584048 + ($65<<2)|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = $67 ^ $64;
 $69 = $68 ^ -1;
 $70 = ((794192 + 24|0));
 $71 = $70;
 HEAP32[$71>>2] = $69;
 $72 = (($70) + 4)|0;
 $73 = $72;
 HEAP32[$73>>2] = (795048);
 $$02$i$i$i$i192 = -1;$i$03$i$i$i$i191 = 0;$reflection$01$i$i$i$i193 = 0;
 while(1) {
  $74 = $$02$i$i$i$i192 & 1;
  $75 = ($74|0)==(0);
  if ($75) {
   $reflection$1$i$i$i$i194 = $reflection$01$i$i$i$i193;
  } else {
   $76 = (31 - ($i$03$i$i$i$i191))|0;
   $77 = 1 << $76;
   $78 = $77 | $reflection$01$i$i$i$i193;
   $reflection$1$i$i$i$i194 = $78;
  }
  $79 = (($i$03$i$i$i$i191) + 1)|0;
  $80 = $$02$i$i$i$i192 >>> 1;
  $exitcond$i$i$i$i195 = ($79|0)==(32);
  if ($exitcond$i$i$i$i195) {
   break;
  } else {
   $$02$i$i$i$i192 = $80;$i$03$i$i$i$i191 = $79;$reflection$01$i$i$i$i193 = $reflection$1$i$i$i$i194;
  }
 }
 $81 = $reflection$1$i$i$i$i194 >>> 8;
 $$masked$i$i$i198 = $reflection$1$i$i$i$i194 & 255;
 $82 = $$masked$i$i$i198 ^ 66;
 $83 = (584048 + ($82<<2)|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = $84 ^ $81;
 $86 = $85 ^ -1;
 $87 = ((794192 + 32|0));
 $88 = $87;
 HEAP32[$88>>2] = $86;
 $89 = (($87) + 4)|0;
 $90 = $89;
 HEAP32[$90>>2] = (795056);
 $$02$i$i$i$i214 = -1;$i$03$i$i$i$i213 = 0;$reflection$01$i$i$i$i215 = 0;
 while(1) {
  $91 = $$02$i$i$i$i214 & 1;
  $92 = ($91|0)==(0);
  if ($92) {
   $reflection$1$i$i$i$i216 = $reflection$01$i$i$i$i215;
  } else {
   $93 = (31 - ($i$03$i$i$i$i213))|0;
   $94 = 1 << $93;
   $95 = $94 | $reflection$01$i$i$i$i215;
   $reflection$1$i$i$i$i216 = $95;
  }
  $96 = (($i$03$i$i$i$i213) + 1)|0;
  $97 = $$02$i$i$i$i214 >>> 1;
  $exitcond$i$i$i$i217 = ($96|0)==(32);
  if ($exitcond$i$i$i$i217) {
   break;
  } else {
   $$02$i$i$i$i214 = $97;$i$03$i$i$i$i213 = $96;$reflection$01$i$i$i$i215 = $reflection$1$i$i$i$i216;
  }
 }
 $98 = $reflection$1$i$i$i$i216 >>> 8;
 $$masked$i$i$i220 = $reflection$1$i$i$i$i216 & 255;
 $99 = $$masked$i$i$i220 ^ 67;
 $100 = (584048 + ($99<<2)|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = $101 ^ $98;
 $103 = $102 ^ -1;
 $104 = ((794192 + 40|0));
 $105 = $104;
 HEAP32[$105>>2] = $103;
 $106 = (($104) + 4)|0;
 $107 = $106;
 HEAP32[$107>>2] = (795064);
 $$02$i$i$i$i236 = -1;$i$03$i$i$i$i235 = 0;$reflection$01$i$i$i$i237 = 0;
 while(1) {
  $108 = $$02$i$i$i$i236 & 1;
  $109 = ($108|0)==(0);
  if ($109) {
   $reflection$1$i$i$i$i238 = $reflection$01$i$i$i$i237;
  } else {
   $110 = (31 - ($i$03$i$i$i$i235))|0;
   $111 = 1 << $110;
   $112 = $111 | $reflection$01$i$i$i$i237;
   $reflection$1$i$i$i$i238 = $112;
  }
  $113 = (($i$03$i$i$i$i235) + 1)|0;
  $114 = $$02$i$i$i$i236 >>> 1;
  $exitcond$i$i$i$i239 = ($113|0)==(32);
  if ($exitcond$i$i$i$i239) {
   break;
  } else {
   $$02$i$i$i$i236 = $114;$i$03$i$i$i$i235 = $113;$reflection$01$i$i$i$i237 = $reflection$1$i$i$i$i238;
  }
 }
 $115 = $reflection$1$i$i$i$i238 >>> 8;
 $$masked$i$i$i242 = $reflection$1$i$i$i$i238 & 255;
 $116 = $$masked$i$i$i242 ^ 68;
 $117 = (584048 + ($116<<2)|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = $118 ^ $115;
 $120 = $119 ^ -1;
 $121 = ((794192 + 48|0));
 $122 = $121;
 HEAP32[$122>>2] = $120;
 $123 = (($121) + 4)|0;
 $124 = $123;
 HEAP32[$124>>2] = (795072);
 $$02$i$i$i$i258 = -1;$i$03$i$i$i$i257 = 0;$reflection$01$i$i$i$i259 = 0;
 while(1) {
  $125 = $$02$i$i$i$i258 & 1;
  $126 = ($125|0)==(0);
  if ($126) {
   $reflection$1$i$i$i$i260 = $reflection$01$i$i$i$i259;
  } else {
   $127 = (31 - ($i$03$i$i$i$i257))|0;
   $128 = 1 << $127;
   $129 = $128 | $reflection$01$i$i$i$i259;
   $reflection$1$i$i$i$i260 = $129;
  }
  $130 = (($i$03$i$i$i$i257) + 1)|0;
  $131 = $$02$i$i$i$i258 >>> 1;
  $exitcond$i$i$i$i261 = ($130|0)==(32);
  if ($exitcond$i$i$i$i261) {
   break;
  } else {
   $$02$i$i$i$i258 = $131;$i$03$i$i$i$i257 = $130;$reflection$01$i$i$i$i259 = $reflection$1$i$i$i$i260;
  }
 }
 $132 = $reflection$1$i$i$i$i260 >>> 8;
 $$masked$i$i$i264 = $reflection$1$i$i$i$i260 & 255;
 $133 = $$masked$i$i$i264 ^ 69;
 $134 = (584048 + ($133<<2)|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = $135 ^ $132;
 $137 = $136 ^ -1;
 $138 = ((794192 + 56|0));
 $139 = $138;
 HEAP32[$139>>2] = $137;
 $140 = (($138) + 4)|0;
 $141 = $140;
 HEAP32[$141>>2] = (795080);
 $$02$i$i$i$i280 = -1;$i$03$i$i$i$i279 = 0;$reflection$01$i$i$i$i281 = 0;
 while(1) {
  $142 = $$02$i$i$i$i280 & 1;
  $143 = ($142|0)==(0);
  if ($143) {
   $reflection$1$i$i$i$i282 = $reflection$01$i$i$i$i281;
  } else {
   $144 = (31 - ($i$03$i$i$i$i279))|0;
   $145 = 1 << $144;
   $146 = $145 | $reflection$01$i$i$i$i281;
   $reflection$1$i$i$i$i282 = $146;
  }
  $147 = (($i$03$i$i$i$i279) + 1)|0;
  $148 = $$02$i$i$i$i280 >>> 1;
  $exitcond$i$i$i$i283 = ($147|0)==(32);
  if ($exitcond$i$i$i$i283) {
   break;
  } else {
   $$02$i$i$i$i280 = $148;$i$03$i$i$i$i279 = $147;$reflection$01$i$i$i$i281 = $reflection$1$i$i$i$i282;
  }
 }
 $149 = $reflection$1$i$i$i$i282 >>> 8;
 $$masked$i$i$i286 = $reflection$1$i$i$i$i282 & 255;
 $150 = $$masked$i$i$i286 ^ 88;
 $151 = (584048 + ($150<<2)|0);
 $152 = HEAP32[$151>>2]|0;
 $153 = $152 ^ $149;
 $154 = $153 ^ -1;
 $155 = ((794192 + 64|0));
 $156 = $155;
 HEAP32[$156>>2] = $154;
 $157 = (($155) + 4)|0;
 $158 = $157;
 HEAP32[$158>>2] = (795088);
 $$02$i$i$i$i302 = -1;$i$03$i$i$i$i301 = 0;$reflection$01$i$i$i$i303 = 0;
 while(1) {
  $159 = $$02$i$i$i$i302 & 1;
  $160 = ($159|0)==(0);
  if ($160) {
   $reflection$1$i$i$i$i304 = $reflection$01$i$i$i$i303;
  } else {
   $161 = (31 - ($i$03$i$i$i$i301))|0;
   $162 = 1 << $161;
   $163 = $162 | $reflection$01$i$i$i$i303;
   $reflection$1$i$i$i$i304 = $163;
  }
  $164 = (($i$03$i$i$i$i301) + 1)|0;
  $165 = $$02$i$i$i$i302 >>> 1;
  $exitcond$i$i$i$i305 = ($164|0)==(32);
  if ($exitcond$i$i$i$i305) {
   break;
  } else {
   $$02$i$i$i$i302 = $165;$i$03$i$i$i$i301 = $164;$reflection$01$i$i$i$i303 = $reflection$1$i$i$i$i304;
  }
 }
 $166 = $reflection$1$i$i$i$i304 >>> 8;
 $$masked$i$i$i308 = $reflection$1$i$i$i$i304 & 255;
 $167 = $$masked$i$i$i308 ^ 89;
 $168 = (584048 + ($167<<2)|0);
 $169 = HEAP32[$168>>2]|0;
 $170 = $169 ^ $166;
 $171 = $170 ^ -1;
 $172 = ((794192 + 72|0));
 $173 = $172;
 HEAP32[$173>>2] = $171;
 $174 = (($172) + 4)|0;
 $175 = $174;
 HEAP32[$175>>2] = (795096);
 $$02$i$i$i$i324 = -1;$i$03$i$i$i$i323 = 0;$reflection$01$i$i$i$i325 = 0;
 while(1) {
  $176 = $$02$i$i$i$i324 & 1;
  $177 = ($176|0)==(0);
  if ($177) {
   $reflection$1$i$i$i$i326 = $reflection$01$i$i$i$i325;
  } else {
   $178 = (31 - ($i$03$i$i$i$i323))|0;
   $179 = 1 << $178;
   $180 = $179 | $reflection$01$i$i$i$i325;
   $reflection$1$i$i$i$i326 = $180;
  }
  $181 = (($i$03$i$i$i$i323) + 1)|0;
  $182 = $$02$i$i$i$i324 >>> 1;
  $exitcond$i$i$i$i327 = ($181|0)==(32);
  if ($exitcond$i$i$i$i327) {
   break;
  } else {
   $$02$i$i$i$i324 = $182;$i$03$i$i$i$i323 = $181;$reflection$01$i$i$i$i325 = $reflection$1$i$i$i$i326;
  }
 }
 $183 = $reflection$1$i$i$i$i326 >>> 8;
 $$masked$i$i$i330 = $reflection$1$i$i$i$i326 & 255;
 $184 = $$masked$i$i$i330 ^ 90;
 $185 = (584048 + ($184<<2)|0);
 $186 = HEAP32[$185>>2]|0;
 $187 = $186 ^ $183;
 $188 = $187 ^ -1;
 $189 = ((794192 + 80|0));
 $190 = $189;
 HEAP32[$190>>2] = $188;
 $191 = (($189) + 4)|0;
 $192 = $191;
 HEAP32[$192>>2] = (795104);
 $$02$i$i$i$i346 = -1;$i$03$i$i$i$i345 = 0;$reflection$01$i$i$i$i347 = 0;
 while(1) {
  $193 = $$02$i$i$i$i346 & 1;
  $194 = ($193|0)==(0);
  if ($194) {
   $reflection$1$i$i$i$i348 = $reflection$01$i$i$i$i347;
  } else {
   $195 = (31 - ($i$03$i$i$i$i345))|0;
   $196 = 1 << $195;
   $197 = $196 | $reflection$01$i$i$i$i347;
   $reflection$1$i$i$i$i348 = $197;
  }
  $198 = (($i$03$i$i$i$i345) + 1)|0;
  $199 = $$02$i$i$i$i346 >>> 1;
  $exitcond$i$i$i$i349 = ($198|0)==(32);
  if ($exitcond$i$i$i$i349) {
   break;
  } else {
   $$02$i$i$i$i346 = $199;$i$03$i$i$i$i345 = $198;$reflection$01$i$i$i$i347 = $reflection$1$i$i$i$i348;
  }
 }
 $200 = $reflection$1$i$i$i$i348 >>> 8;
 $$masked$i$i$i352 = $reflection$1$i$i$i$i348 & 255;
 $201 = $$masked$i$i$i352 ^ 87;
 $202 = (584048 + ($201<<2)|0);
 $203 = HEAP32[$202>>2]|0;
 $204 = $203 ^ $200;
 $205 = $204 ^ -1;
 $206 = ((794192 + 88|0));
 $207 = $206;
 HEAP32[$207>>2] = $205;
 $208 = (($206) + 4)|0;
 $209 = $208;
 HEAP32[$209>>2] = (795112);
 $$02$i$i$i$i368 = -1;$i$03$i$i$i$i367 = 0;$reflection$01$i$i$i$i369 = 0;
 while(1) {
  $210 = $$02$i$i$i$i368 & 1;
  $211 = ($210|0)==(0);
  if ($211) {
   $reflection$1$i$i$i$i370 = $reflection$01$i$i$i$i369;
  } else {
   $212 = (31 - ($i$03$i$i$i$i367))|0;
   $213 = 1 << $212;
   $214 = $213 | $reflection$01$i$i$i$i369;
   $reflection$1$i$i$i$i370 = $214;
  }
  $215 = (($i$03$i$i$i$i367) + 1)|0;
  $216 = $$02$i$i$i$i368 >>> 1;
  $exitcond$i$i$i$i371 = ($215|0)==(32);
  if ($exitcond$i$i$i$i371) {
   break;
  } else {
   $$02$i$i$i$i368 = $216;$i$03$i$i$i$i367 = $215;$reflection$01$i$i$i$i369 = $reflection$1$i$i$i$i370;
  }
 }
 $217 = $reflection$1$i$i$i$i370 >>> 8;
 $$masked$i$i$i374 = $reflection$1$i$i$i$i370 & 255;
 $218 = $$masked$i$i$i374 ^ 82;
 $219 = (584048 + ($218<<2)|0);
 $220 = HEAP32[$219>>2]|0;
 $221 = $220 ^ $217;
 $222 = $221 >>> 8;
 $$masked$i$i$i374$1 = $221 & 255;
 $223 = $$masked$i$i$i374$1 ^ 101;
 $224 = (584048 + ($223<<2)|0);
 $225 = HEAP32[$224>>2]|0;
 $226 = $225 ^ $222;
 $227 = $226 >>> 8;
 $$masked$i$i$i374$2 = $226 & 255;
 $228 = $$masked$i$i$i374$2 ^ 115;
 $229 = (584048 + ($228<<2)|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = $230 ^ $227;
 $232 = $231 >>> 8;
 $$masked$i$i$i374$3 = $231 & 255;
 $233 = $$masked$i$i$i374$3 ^ 117;
 $234 = (584048 + ($233<<2)|0);
 $235 = HEAP32[$234>>2]|0;
 $236 = $235 ^ $232;
 $237 = $236 >>> 8;
 $$masked$i$i$i374$4 = $236 & 255;
 $238 = $$masked$i$i$i374$4 ^ 108;
 $239 = (584048 + ($238<<2)|0);
 $240 = HEAP32[$239>>2]|0;
 $241 = $240 ^ $237;
 $242 = $241 >>> 8;
 $$masked$i$i$i374$5 = $241 & 255;
 $243 = $$masked$i$i$i374$5 ^ 116;
 $244 = (584048 + ($243<<2)|0);
 $245 = HEAP32[$244>>2]|0;
 $246 = $245 ^ $242;
 $247 = $246 ^ -1;
 $248 = ((794192 + 96|0));
 $249 = $248;
 HEAP32[$249>>2] = $247;
 $250 = (($248) + 4)|0;
 $251 = $250;
 HEAP32[$251>>2] = (795120);
 $$02$i$i$i$i390 = -1;$i$03$i$i$i$i389 = 0;$reflection$01$i$i$i$i391 = 0;
 while(1) {
  $252 = $$02$i$i$i$i390 & 1;
  $253 = ($252|0)==(0);
  if ($253) {
   $reflection$1$i$i$i$i392 = $reflection$01$i$i$i$i391;
  } else {
   $254 = (31 - ($i$03$i$i$i$i389))|0;
   $255 = 1 << $254;
   $256 = $255 | $reflection$01$i$i$i$i391;
   $reflection$1$i$i$i$i392 = $256;
  }
  $257 = (($i$03$i$i$i$i389) + 1)|0;
  $258 = $$02$i$i$i$i390 >>> 1;
  $exitcond$i$i$i$i393 = ($257|0)==(32);
  if ($exitcond$i$i$i$i393) {
   break;
  } else {
   $$02$i$i$i$i390 = $258;$i$03$i$i$i$i389 = $257;$reflection$01$i$i$i$i391 = $reflection$1$i$i$i$i392;
  }
 }
 $259 = $reflection$1$i$i$i$i392 >>> 8;
 $$masked$i$i$i396 = $reflection$1$i$i$i$i392 & 255;
 $260 = $$masked$i$i$i396 ^ 77;
 $261 = (584048 + ($260<<2)|0);
 $262 = HEAP32[$261>>2]|0;
 $263 = $262 ^ $259;
 $264 = $263 >>> 8;
 $$masked$i$i$i396$1 = $263 & 255;
 $265 = $$masked$i$i$i396$1 ^ 105;
 $266 = (584048 + ($265<<2)|0);
 $267 = HEAP32[$266>>2]|0;
 $268 = $267 ^ $264;
 $269 = $268 >>> 8;
 $$masked$i$i$i396$2 = $268 & 255;
 $270 = $$masked$i$i$i396$2 ^ 110;
 $271 = (584048 + ($270<<2)|0);
 $272 = HEAP32[$271>>2]|0;
 $273 = $272 ^ $269;
 $274 = $273 ^ -1;
 $275 = ((794192 + 104|0));
 $276 = $275;
 HEAP32[$276>>2] = $274;
 $277 = (($275) + 4)|0;
 $278 = $277;
 HEAP32[$278>>2] = (795128);
 $$02$i$i$i$i412 = -1;$i$03$i$i$i$i411 = 0;$reflection$01$i$i$i$i413 = 0;
 while(1) {
  $279 = $$02$i$i$i$i412 & 1;
  $280 = ($279|0)==(0);
  if ($280) {
   $reflection$1$i$i$i$i414 = $reflection$01$i$i$i$i413;
  } else {
   $281 = (31 - ($i$03$i$i$i$i411))|0;
   $282 = 1 << $281;
   $283 = $282 | $reflection$01$i$i$i$i413;
   $reflection$1$i$i$i$i414 = $283;
  }
  $284 = (($i$03$i$i$i$i411) + 1)|0;
  $285 = $$02$i$i$i$i412 >>> 1;
  $exitcond$i$i$i$i415 = ($284|0)==(32);
  if ($exitcond$i$i$i$i415) {
   break;
  } else {
   $$02$i$i$i$i412 = $285;$i$03$i$i$i$i411 = $284;$reflection$01$i$i$i$i413 = $reflection$1$i$i$i$i414;
  }
 }
 $286 = $reflection$1$i$i$i$i414 >>> 8;
 $$masked$i$i$i418 = $reflection$1$i$i$i$i414 & 255;
 $287 = $$masked$i$i$i418 ^ 77;
 $288 = (584048 + ($287<<2)|0);
 $289 = HEAP32[$288>>2]|0;
 $290 = $289 ^ $286;
 $291 = $290 >>> 8;
 $$masked$i$i$i418$1 = $290 & 255;
 $292 = $$masked$i$i$i418$1 ^ 97;
 $293 = (584048 + ($292<<2)|0);
 $294 = HEAP32[$293>>2]|0;
 $295 = $294 ^ $291;
 $296 = $295 >>> 8;
 $$masked$i$i$i418$2 = $295 & 255;
 $297 = $$masked$i$i$i418$2 ^ 120;
 $298 = (584048 + ($297<<2)|0);
 $299 = HEAP32[$298>>2]|0;
 $300 = $299 ^ $296;
 $301 = $300 ^ -1;
 $302 = ((794192 + 112|0));
 $303 = $302;
 HEAP32[$303>>2] = $301;
 $304 = (($302) + 4)|0;
 $305 = $304;
 HEAP32[$305>>2] = (795136);
 $$02$i$i$i$i434 = -1;$i$03$i$i$i$i433 = 0;$reflection$01$i$i$i$i435 = 0;
 while(1) {
  $306 = $$02$i$i$i$i434 & 1;
  $307 = ($306|0)==(0);
  if ($307) {
   $reflection$1$i$i$i$i436 = $reflection$01$i$i$i$i435;
  } else {
   $308 = (31 - ($i$03$i$i$i$i433))|0;
   $309 = 1 << $308;
   $310 = $309 | $reflection$01$i$i$i$i435;
   $reflection$1$i$i$i$i436 = $310;
  }
  $311 = (($i$03$i$i$i$i433) + 1)|0;
  $312 = $$02$i$i$i$i434 >>> 1;
  $exitcond$i$i$i$i437 = ($311|0)==(32);
  if ($exitcond$i$i$i$i437) {
   break;
  } else {
   $$02$i$i$i$i434 = $312;$i$03$i$i$i$i433 = $311;$reflection$01$i$i$i$i435 = $reflection$1$i$i$i$i436;
  }
 }
 $313 = $reflection$1$i$i$i$i436 >>> 8;
 $$masked$i$i$i440 = $reflection$1$i$i$i$i436 & 255;
 $314 = $$masked$i$i$i440 ^ 86;
 $315 = (584048 + ($314<<2)|0);
 $316 = HEAP32[$315>>2]|0;
 $317 = $316 ^ $313;
 $318 = $317 >>> 8;
 $$masked$i$i$i440$1 = $317 & 255;
 $319 = $$masked$i$i$i440$1 ^ 97;
 $320 = (584048 + ($319<<2)|0);
 $321 = HEAP32[$320>>2]|0;
 $322 = $321 ^ $318;
 $323 = $322 >>> 8;
 $$masked$i$i$i440$2 = $322 & 255;
 $324 = $$masked$i$i$i440$2 ^ 108;
 $325 = (584048 + ($324<<2)|0);
 $326 = HEAP32[$325>>2]|0;
 $327 = $326 ^ $323;
 $328 = $327 >>> 8;
 $$masked$i$i$i440$3 = $327 & 255;
 $329 = $$masked$i$i$i440$3 ^ 117;
 $330 = (584048 + ($329<<2)|0);
 $331 = HEAP32[$330>>2]|0;
 $332 = $331 ^ $328;
 $333 = $332 >>> 8;
 $$masked$i$i$i440$4 = $332 & 255;
 $334 = $$masked$i$i$i440$4 ^ 101;
 $335 = (584048 + ($334<<2)|0);
 $336 = HEAP32[$335>>2]|0;
 $337 = $336 ^ $333;
 $338 = $337 ^ -1;
 $339 = ((794192 + 120|0));
 $340 = $339;
 HEAP32[$340>>2] = $338;
 $341 = (($339) + 4)|0;
 $342 = $341;
 HEAP32[$342>>2] = (795144);
 $$02$i$i$i$i456 = -1;$i$03$i$i$i$i455 = 0;$reflection$01$i$i$i$i457 = 0;
 while(1) {
  $343 = $$02$i$i$i$i456 & 1;
  $344 = ($343|0)==(0);
  if ($344) {
   $reflection$1$i$i$i$i458 = $reflection$01$i$i$i$i457;
  } else {
   $345 = (31 - ($i$03$i$i$i$i455))|0;
   $346 = 1 << $345;
   $347 = $346 | $reflection$01$i$i$i$i457;
   $reflection$1$i$i$i$i458 = $347;
  }
  $348 = (($i$03$i$i$i$i455) + 1)|0;
  $349 = $$02$i$i$i$i456 >>> 1;
  $exitcond$i$i$i$i459 = ($348|0)==(32);
  if ($exitcond$i$i$i$i459) {
   break;
  } else {
   $$02$i$i$i$i456 = $349;$i$03$i$i$i$i455 = $348;$reflection$01$i$i$i$i457 = $reflection$1$i$i$i$i458;
  }
 }
 $350 = $reflection$1$i$i$i$i458 >>> 8;
 $$masked$i$i$i462 = $reflection$1$i$i$i$i458 & 255;
 $351 = $$masked$i$i$i462 ^ 77;
 $352 = (584048 + ($351<<2)|0);
 $353 = HEAP32[$352>>2]|0;
 $354 = $353 ^ $350;
 $355 = $354 >>> 8;
 $$masked$i$i$i462$1 = $354 & 255;
 $356 = $$masked$i$i$i462$1 ^ 105;
 $357 = (584048 + ($356<<2)|0);
 $358 = HEAP32[$357>>2]|0;
 $359 = $358 ^ $355;
 $360 = $359 >>> 8;
 $$masked$i$i$i462$2 = $359 & 255;
 $361 = $$masked$i$i$i462$2 ^ 110;
 $362 = (584048 + ($361<<2)|0);
 $363 = HEAP32[$362>>2]|0;
 $364 = $363 ^ $360;
 $365 = $364 >>> 8;
 $$masked$i$i$i462$3 = $364 & 255;
 $366 = $$masked$i$i$i462$3 ^ 77;
 $367 = (584048 + ($366<<2)|0);
 $368 = HEAP32[$367>>2]|0;
 $369 = $368 ^ $365;
 $370 = $369 >>> 8;
 $$masked$i$i$i462$4 = $369 & 255;
 $371 = $$masked$i$i$i462$4 ^ 105;
 $372 = (584048 + ($371<<2)|0);
 $373 = HEAP32[$372>>2]|0;
 $374 = $373 ^ $370;
 $375 = $374 >>> 8;
 $$masked$i$i$i462$5 = $374 & 255;
 $376 = $$masked$i$i$i462$5 ^ 110;
 $377 = (584048 + ($376<<2)|0);
 $378 = HEAP32[$377>>2]|0;
 $379 = $378 ^ $375;
 $380 = $379 ^ -1;
 $381 = ((794192 + 128|0));
 $382 = $381;
 HEAP32[$382>>2] = $380;
 $383 = (($381) + 4)|0;
 $384 = $383;
 HEAP32[$384>>2] = (795152);
 $$02$i$i$i$i478 = -1;$i$03$i$i$i$i477 = 0;$reflection$01$i$i$i$i479 = 0;
 while(1) {
  $385 = $$02$i$i$i$i478 & 1;
  $386 = ($385|0)==(0);
  if ($386) {
   $reflection$1$i$i$i$i480 = $reflection$01$i$i$i$i479;
  } else {
   $387 = (31 - ($i$03$i$i$i$i477))|0;
   $388 = 1 << $387;
   $389 = $388 | $reflection$01$i$i$i$i479;
   $reflection$1$i$i$i$i480 = $389;
  }
  $390 = (($i$03$i$i$i$i477) + 1)|0;
  $391 = $$02$i$i$i$i478 >>> 1;
  $exitcond$i$i$i$i481 = ($390|0)==(32);
  if ($exitcond$i$i$i$i481) {
   break;
  } else {
   $$02$i$i$i$i478 = $391;$i$03$i$i$i$i477 = $390;$reflection$01$i$i$i$i479 = $reflection$1$i$i$i$i480;
  }
 }
 $392 = $reflection$1$i$i$i$i480 >>> 8;
 $$masked$i$i$i484 = $reflection$1$i$i$i$i480 & 255;
 $393 = $$masked$i$i$i484 ^ 77;
 $394 = (584048 + ($393<<2)|0);
 $395 = HEAP32[$394>>2]|0;
 $396 = $395 ^ $392;
 $397 = $396 >>> 8;
 $$masked$i$i$i484$1 = $396 & 255;
 $398 = $$masked$i$i$i484$1 ^ 105;
 $399 = (584048 + ($398<<2)|0);
 $400 = HEAP32[$399>>2]|0;
 $401 = $400 ^ $397;
 $402 = $401 >>> 8;
 $$masked$i$i$i484$2 = $401 & 255;
 $403 = $$masked$i$i$i484$2 ^ 110;
 $404 = (584048 + ($403<<2)|0);
 $405 = HEAP32[$404>>2]|0;
 $406 = $405 ^ $402;
 $407 = $406 >>> 8;
 $$masked$i$i$i484$3 = $406 & 255;
 $408 = $$masked$i$i$i484$3 ^ 77;
 $409 = (584048 + ($408<<2)|0);
 $410 = HEAP32[$409>>2]|0;
 $411 = $410 ^ $407;
 $412 = $411 >>> 8;
 $$masked$i$i$i484$4 = $411 & 255;
 $413 = $$masked$i$i$i484$4 ^ 97;
 $414 = (584048 + ($413<<2)|0);
 $415 = HEAP32[$414>>2]|0;
 $416 = $415 ^ $412;
 $417 = $416 >>> 8;
 $$masked$i$i$i484$5 = $416 & 255;
 $418 = $$masked$i$i$i484$5 ^ 120;
 $419 = (584048 + ($418<<2)|0);
 $420 = HEAP32[$419>>2]|0;
 $421 = $420 ^ $417;
 $422 = $421 ^ -1;
 $423 = ((794192 + 136|0));
 $424 = $423;
 HEAP32[$424>>2] = $422;
 $425 = (($423) + 4)|0;
 $426 = $425;
 HEAP32[$426>>2] = (795160);
 $$02$i$i$i$i500 = -1;$i$03$i$i$i$i499 = 0;$reflection$01$i$i$i$i501 = 0;
 while(1) {
  $427 = $$02$i$i$i$i500 & 1;
  $428 = ($427|0)==(0);
  if ($428) {
   $reflection$1$i$i$i$i502 = $reflection$01$i$i$i$i501;
  } else {
   $429 = (31 - ($i$03$i$i$i$i499))|0;
   $430 = 1 << $429;
   $431 = $430 | $reflection$01$i$i$i$i501;
   $reflection$1$i$i$i$i502 = $431;
  }
  $432 = (($i$03$i$i$i$i499) + 1)|0;
  $433 = $$02$i$i$i$i500 >>> 1;
  $exitcond$i$i$i$i503 = ($432|0)==(32);
  if ($exitcond$i$i$i$i503) {
   break;
  } else {
   $$02$i$i$i$i500 = $433;$i$03$i$i$i$i499 = $432;$reflection$01$i$i$i$i501 = $reflection$1$i$i$i$i502;
  }
 }
 $434 = $reflection$1$i$i$i$i502 >>> 8;
 $$masked$i$i$i506 = $reflection$1$i$i$i$i502 & 255;
 $435 = $$masked$i$i$i506 ^ 77;
 $436 = (584048 + ($435<<2)|0);
 $437 = HEAP32[$436>>2]|0;
 $438 = $437 ^ $434;
 $439 = $438 >>> 8;
 $$masked$i$i$i506$1 = $438 & 255;
 $440 = $$masked$i$i$i506$1 ^ 97;
 $441 = (584048 + ($440<<2)|0);
 $442 = HEAP32[$441>>2]|0;
 $443 = $442 ^ $439;
 $444 = $443 >>> 8;
 $$masked$i$i$i506$2 = $443 & 255;
 $445 = $$masked$i$i$i506$2 ^ 120;
 $446 = (584048 + ($445<<2)|0);
 $447 = HEAP32[$446>>2]|0;
 $448 = $447 ^ $444;
 $449 = $448 >>> 8;
 $$masked$i$i$i506$3 = $448 & 255;
 $450 = $$masked$i$i$i506$3 ^ 77;
 $451 = (584048 + ($450<<2)|0);
 $452 = HEAP32[$451>>2]|0;
 $453 = $452 ^ $449;
 $454 = $453 >>> 8;
 $$masked$i$i$i506$4 = $453 & 255;
 $455 = $$masked$i$i$i506$4 ^ 105;
 $456 = (584048 + ($455<<2)|0);
 $457 = HEAP32[$456>>2]|0;
 $458 = $457 ^ $454;
 $459 = $458 >>> 8;
 $$masked$i$i$i506$5 = $458 & 255;
 $460 = $$masked$i$i$i506$5 ^ 110;
 $461 = (584048 + ($460<<2)|0);
 $462 = HEAP32[$461>>2]|0;
 $463 = $462 ^ $459;
 $464 = $463 ^ -1;
 $465 = ((794192 + 144|0));
 $466 = $465;
 HEAP32[$466>>2] = $464;
 $467 = (($465) + 4)|0;
 $468 = $467;
 HEAP32[$468>>2] = (795168);
 $$02$i$i$i$i522 = -1;$i$03$i$i$i$i521 = 0;$reflection$01$i$i$i$i523 = 0;
 while(1) {
  $469 = $$02$i$i$i$i522 & 1;
  $470 = ($469|0)==(0);
  if ($470) {
   $reflection$1$i$i$i$i524 = $reflection$01$i$i$i$i523;
  } else {
   $471 = (31 - ($i$03$i$i$i$i521))|0;
   $472 = 1 << $471;
   $473 = $472 | $reflection$01$i$i$i$i523;
   $reflection$1$i$i$i$i524 = $473;
  }
  $474 = (($i$03$i$i$i$i521) + 1)|0;
  $475 = $$02$i$i$i$i522 >>> 1;
  $exitcond$i$i$i$i525 = ($474|0)==(32);
  if ($exitcond$i$i$i$i525) {
   break;
  } else {
   $$02$i$i$i$i522 = $475;$i$03$i$i$i$i521 = $474;$reflection$01$i$i$i$i523 = $reflection$1$i$i$i$i524;
  }
 }
 $476 = $reflection$1$i$i$i$i524 >>> 8;
 $$masked$i$i$i528 = $reflection$1$i$i$i$i524 & 255;
 $477 = $$masked$i$i$i528 ^ 77;
 $478 = (584048 + ($477<<2)|0);
 $479 = HEAP32[$478>>2]|0;
 $480 = $479 ^ $476;
 $481 = $480 >>> 8;
 $$masked$i$i$i528$1 = $480 & 255;
 $482 = $$masked$i$i$i528$1 ^ 97;
 $483 = (584048 + ($482<<2)|0);
 $484 = HEAP32[$483>>2]|0;
 $485 = $484 ^ $481;
 $486 = $485 >>> 8;
 $$masked$i$i$i528$2 = $485 & 255;
 $487 = $$masked$i$i$i528$2 ^ 120;
 $488 = (584048 + ($487<<2)|0);
 $489 = HEAP32[$488>>2]|0;
 $490 = $489 ^ $486;
 $491 = $490 >>> 8;
 $$masked$i$i$i528$3 = $490 & 255;
 $492 = $$masked$i$i$i528$3 ^ 77;
 $493 = (584048 + ($492<<2)|0);
 $494 = HEAP32[$493>>2]|0;
 $495 = $494 ^ $491;
 $496 = $495 >>> 8;
 $$masked$i$i$i528$4 = $495 & 255;
 $497 = $$masked$i$i$i528$4 ^ 97;
 $498 = (584048 + ($497<<2)|0);
 $499 = HEAP32[$498>>2]|0;
 $500 = $499 ^ $496;
 $501 = $500 >>> 8;
 $$masked$i$i$i528$5 = $500 & 255;
 $502 = $$masked$i$i$i528$5 ^ 120;
 $503 = (584048 + ($502<<2)|0);
 $504 = HEAP32[$503>>2]|0;
 $505 = $504 ^ $501;
 $506 = $505 ^ -1;
 $507 = ((794192 + 152|0));
 $508 = $507;
 HEAP32[$508>>2] = $506;
 $509 = (($507) + 4)|0;
 $510 = $509;
 HEAP32[$510>>2] = (795176);
 $$02$i$i$i$i544 = -1;$i$03$i$i$i$i543 = 0;$reflection$01$i$i$i$i545 = 0;
 while(1) {
  $511 = $$02$i$i$i$i544 & 1;
  $512 = ($511|0)==(0);
  if ($512) {
   $reflection$1$i$i$i$i546 = $reflection$01$i$i$i$i545;
  } else {
   $513 = (31 - ($i$03$i$i$i$i543))|0;
   $514 = 1 << $513;
   $515 = $514 | $reflection$01$i$i$i$i545;
   $reflection$1$i$i$i$i546 = $515;
  }
  $516 = (($i$03$i$i$i$i543) + 1)|0;
  $517 = $$02$i$i$i$i544 >>> 1;
  $exitcond$i$i$i$i547 = ($516|0)==(32);
  if ($exitcond$i$i$i$i547) {
   break;
  } else {
   $$02$i$i$i$i544 = $517;$i$03$i$i$i$i543 = $516;$reflection$01$i$i$i$i545 = $reflection$1$i$i$i$i546;
  }
 }
 $518 = $reflection$1$i$i$i$i546 >>> 8;
 $$masked$i$i$i550 = $reflection$1$i$i$i$i546 & 255;
 $519 = $$masked$i$i$i550 ^ 73;
 $520 = (584048 + ($519<<2)|0);
 $521 = HEAP32[$520>>2]|0;
 $522 = $521 ^ $518;
 $523 = $522 >>> 8;
 $$masked$i$i$i550$1 = $522 & 255;
 $524 = $$masked$i$i$i550$1 ^ 110;
 $525 = (584048 + ($524<<2)|0);
 $526 = HEAP32[$525>>2]|0;
 $527 = $526 ^ $523;
 $528 = $527 ^ -1;
 $529 = ((794192 + 160|0));
 $530 = $529;
 HEAP32[$530>>2] = $528;
 $531 = (($529) + 4)|0;
 $532 = $531;
 HEAP32[$532>>2] = (795184);
 $$02$i$i$i$i566 = -1;$i$03$i$i$i$i565 = 0;$reflection$01$i$i$i$i567 = 0;
 while(1) {
  $533 = $$02$i$i$i$i566 & 1;
  $534 = ($533|0)==(0);
  if ($534) {
   $reflection$1$i$i$i$i568 = $reflection$01$i$i$i$i567;
  } else {
   $535 = (31 - ($i$03$i$i$i$i565))|0;
   $536 = 1 << $535;
   $537 = $536 | $reflection$01$i$i$i$i567;
   $reflection$1$i$i$i$i568 = $537;
  }
  $538 = (($i$03$i$i$i$i565) + 1)|0;
  $539 = $$02$i$i$i$i566 >>> 1;
  $exitcond$i$i$i$i569 = ($538|0)==(32);
  if ($exitcond$i$i$i$i569) {
   break;
  } else {
   $$02$i$i$i$i566 = $539;$i$03$i$i$i$i565 = $538;$reflection$01$i$i$i$i567 = $reflection$1$i$i$i$i568;
  }
 }
 $540 = $reflection$1$i$i$i$i568 >>> 8;
 $$masked$i$i$i572 = $reflection$1$i$i$i$i568 & 255;
 $541 = $$masked$i$i$i572 ^ 79;
 $542 = (584048 + ($541<<2)|0);
 $543 = HEAP32[$542>>2]|0;
 $544 = $543 ^ $540;
 $545 = $544 >>> 8;
 $$masked$i$i$i572$1 = $544 & 255;
 $546 = $$masked$i$i$i572$1 ^ 117;
 $547 = (584048 + ($546<<2)|0);
 $548 = HEAP32[$547>>2]|0;
 $549 = $548 ^ $545;
 $550 = $549 >>> 8;
 $$masked$i$i$i572$2 = $549 & 255;
 $551 = $$masked$i$i$i572$2 ^ 116;
 $552 = (584048 + ($551<<2)|0);
 $553 = HEAP32[$552>>2]|0;
 $554 = $553 ^ $550;
 $555 = $554 ^ -1;
 $556 = ((794192 + 168|0));
 $557 = $556;
 HEAP32[$557>>2] = $555;
 $558 = (($556) + 4)|0;
 $559 = $558;
 HEAP32[$559>>2] = (795192);
 $$02$i$i$i$i588 = -1;$i$03$i$i$i$i587 = 0;$reflection$01$i$i$i$i589 = 0;
 while(1) {
  $560 = $$02$i$i$i$i588 & 1;
  $561 = ($560|0)==(0);
  if ($561) {
   $reflection$1$i$i$i$i590 = $reflection$01$i$i$i$i589;
  } else {
   $562 = (31 - ($i$03$i$i$i$i587))|0;
   $563 = 1 << $562;
   $564 = $563 | $reflection$01$i$i$i$i589;
   $reflection$1$i$i$i$i590 = $564;
  }
  $565 = (($i$03$i$i$i$i587) + 1)|0;
  $566 = $$02$i$i$i$i588 >>> 1;
  $exitcond$i$i$i$i591 = ($565|0)==(32);
  if ($exitcond$i$i$i$i591) {
   break;
  } else {
   $$02$i$i$i$i588 = $566;$i$03$i$i$i$i587 = $565;$reflection$01$i$i$i$i589 = $reflection$1$i$i$i$i590;
  }
 }
 $567 = $reflection$1$i$i$i$i590 >>> 8;
 $$masked$i$i$i594 = $reflection$1$i$i$i$i590 & 255;
 $568 = $$masked$i$i$i594 ^ 82;
 $569 = (584048 + ($568<<2)|0);
 $570 = HEAP32[$569>>2]|0;
 $571 = $570 ^ $567;
 $572 = $571 >>> 8;
 $$masked$i$i$i594$1 = $571 & 255;
 $573 = $$masked$i$i$i594$1 ^ 97;
 $574 = (584048 + ($573<<2)|0);
 $575 = HEAP32[$574>>2]|0;
 $576 = $575 ^ $572;
 $577 = $576 >>> 8;
 $$masked$i$i$i594$2 = $576 & 255;
 $578 = $$masked$i$i$i594$2 ^ 110;
 $579 = (584048 + ($578<<2)|0);
 $580 = HEAP32[$579>>2]|0;
 $581 = $580 ^ $577;
 $582 = $581 >>> 8;
 $$masked$i$i$i594$3 = $581 & 255;
 $583 = $$masked$i$i$i594$3 ^ 103;
 $584 = (584048 + ($583<<2)|0);
 $585 = HEAP32[$584>>2]|0;
 $586 = $585 ^ $582;
 $587 = $586 >>> 8;
 $$masked$i$i$i594$4 = $586 & 255;
 $588 = $$masked$i$i$i594$4 ^ 101;
 $589 = (584048 + ($588<<2)|0);
 $590 = HEAP32[$589>>2]|0;
 $591 = $590 ^ $587;
 $592 = $591 >>> 8;
 $$masked$i$i$i594$5 = $591 & 255;
 $593 = $$masked$i$i$i594$5 ^ 65;
 $594 = (584048 + ($593<<2)|0);
 $595 = HEAP32[$594>>2]|0;
 $596 = $595 ^ $592;
 $597 = $596 ^ -1;
 $598 = ((794192 + 176|0));
 $599 = $598;
 HEAP32[$599>>2] = $597;
 $600 = (($598) + 4)|0;
 $601 = $600;
 HEAP32[$601>>2] = (795200);
 $$02$i$i$i$i610 = -1;$i$03$i$i$i$i609 = 0;$reflection$01$i$i$i$i611 = 0;
 while(1) {
  $602 = $$02$i$i$i$i610 & 1;
  $603 = ($602|0)==(0);
  if ($603) {
   $reflection$1$i$i$i$i612 = $reflection$01$i$i$i$i611;
  } else {
   $604 = (31 - ($i$03$i$i$i$i609))|0;
   $605 = 1 << $604;
   $606 = $605 | $reflection$01$i$i$i$i611;
   $reflection$1$i$i$i$i612 = $606;
  }
  $607 = (($i$03$i$i$i$i609) + 1)|0;
  $608 = $$02$i$i$i$i610 >>> 1;
  $exitcond$i$i$i$i613 = ($607|0)==(32);
  if ($exitcond$i$i$i$i613) {
   break;
  } else {
   $$02$i$i$i$i610 = $608;$i$03$i$i$i$i609 = $607;$reflection$01$i$i$i$i611 = $reflection$1$i$i$i$i612;
  }
 }
 $609 = $reflection$1$i$i$i$i612 >>> 8;
 $$masked$i$i$i616 = $reflection$1$i$i$i$i612 & 255;
 $610 = $$masked$i$i$i616 ^ 82;
 $611 = (584048 + ($610<<2)|0);
 $612 = HEAP32[$611>>2]|0;
 $613 = $612 ^ $609;
 $614 = $613 >>> 8;
 $$masked$i$i$i616$1 = $613 & 255;
 $615 = $$masked$i$i$i616$1 ^ 97;
 $616 = (584048 + ($615<<2)|0);
 $617 = HEAP32[$616>>2]|0;
 $618 = $617 ^ $614;
 $619 = $618 >>> 8;
 $$masked$i$i$i616$2 = $618 & 255;
 $620 = $$masked$i$i$i616$2 ^ 110;
 $621 = (584048 + ($620<<2)|0);
 $622 = HEAP32[$621>>2]|0;
 $623 = $622 ^ $619;
 $624 = $623 >>> 8;
 $$masked$i$i$i616$3 = $623 & 255;
 $625 = $$masked$i$i$i616$3 ^ 103;
 $626 = (584048 + ($625<<2)|0);
 $627 = HEAP32[$626>>2]|0;
 $628 = $627 ^ $624;
 $629 = $628 >>> 8;
 $$masked$i$i$i616$4 = $628 & 255;
 $630 = $$masked$i$i$i616$4 ^ 101;
 $631 = (584048 + ($630<<2)|0);
 $632 = HEAP32[$631>>2]|0;
 $633 = $632 ^ $629;
 $634 = $633 >>> 8;
 $$masked$i$i$i616$5 = $633 & 255;
 $635 = $$masked$i$i$i616$5 ^ 66;
 $636 = (584048 + ($635<<2)|0);
 $637 = HEAP32[$636>>2]|0;
 $638 = $637 ^ $634;
 $639 = $638 ^ -1;
 $640 = ((794192 + 184|0));
 $641 = $640;
 HEAP32[$641>>2] = $639;
 $642 = (($640) + 4)|0;
 $643 = $642;
 HEAP32[$643>>2] = (795208);
 $$02$i$i$i$i632 = -1;$i$03$i$i$i$i631 = 0;$reflection$01$i$i$i$i633 = 0;
 while(1) {
  $644 = $$02$i$i$i$i632 & 1;
  $645 = ($644|0)==(0);
  if ($645) {
   $reflection$1$i$i$i$i634 = $reflection$01$i$i$i$i633;
  } else {
   $646 = (31 - ($i$03$i$i$i$i631))|0;
   $647 = 1 << $646;
   $648 = $647 | $reflection$01$i$i$i$i633;
   $reflection$1$i$i$i$i634 = $648;
  }
  $649 = (($i$03$i$i$i$i631) + 1)|0;
  $650 = $$02$i$i$i$i632 >>> 1;
  $exitcond$i$i$i$i635 = ($649|0)==(32);
  if ($exitcond$i$i$i$i635) {
   break;
  } else {
   $$02$i$i$i$i632 = $650;$i$03$i$i$i$i631 = $649;$reflection$01$i$i$i$i633 = $reflection$1$i$i$i$i634;
  }
 }
 $651 = $reflection$1$i$i$i$i634 >>> 8;
 $$masked$i$i$i638 = $reflection$1$i$i$i$i634 & 255;
 $652 = $$masked$i$i$i638 ^ 82;
 $653 = (584048 + ($652<<2)|0);
 $654 = HEAP32[$653>>2]|0;
 $655 = $654 ^ $651;
 $656 = $655 >>> 8;
 $$masked$i$i$i638$1 = $655 & 255;
 $657 = $$masked$i$i$i638$1 ^ 97;
 $658 = (584048 + ($657<<2)|0);
 $659 = HEAP32[$658>>2]|0;
 $660 = $659 ^ $656;
 $661 = $660 >>> 8;
 $$masked$i$i$i638$2 = $660 & 255;
 $662 = $$masked$i$i$i638$2 ^ 110;
 $663 = (584048 + ($662<<2)|0);
 $664 = HEAP32[$663>>2]|0;
 $665 = $664 ^ $661;
 $666 = $665 >>> 8;
 $$masked$i$i$i638$3 = $665 & 255;
 $667 = $$masked$i$i$i638$3 ^ 103;
 $668 = (584048 + ($667<<2)|0);
 $669 = HEAP32[$668>>2]|0;
 $670 = $669 ^ $666;
 $671 = $670 >>> 8;
 $$masked$i$i$i638$4 = $670 & 255;
 $672 = $$masked$i$i$i638$4 ^ 101;
 $673 = (584048 + ($672<<2)|0);
 $674 = HEAP32[$673>>2]|0;
 $675 = $674 ^ $671;
 $676 = $675 >>> 8;
 $$masked$i$i$i638$5 = $675 & 255;
 $677 = $$masked$i$i$i638$5 ^ 67;
 $678 = (584048 + ($677<<2)|0);
 $679 = HEAP32[$678>>2]|0;
 $680 = $679 ^ $676;
 $681 = $680 ^ -1;
 $682 = ((794192 + 192|0));
 $683 = $682;
 HEAP32[$683>>2] = $681;
 $684 = (($682) + 4)|0;
 $685 = $684;
 HEAP32[$685>>2] = (795216);
 $$02$i$i$i$i654 = -1;$i$03$i$i$i$i653 = 0;$reflection$01$i$i$i$i655 = 0;
 while(1) {
  $686 = $$02$i$i$i$i654 & 1;
  $687 = ($686|0)==(0);
  if ($687) {
   $reflection$1$i$i$i$i656 = $reflection$01$i$i$i$i655;
  } else {
   $688 = (31 - ($i$03$i$i$i$i653))|0;
   $689 = 1 << $688;
   $690 = $689 | $reflection$01$i$i$i$i655;
   $reflection$1$i$i$i$i656 = $690;
  }
  $691 = (($i$03$i$i$i$i653) + 1)|0;
  $692 = $$02$i$i$i$i654 >>> 1;
  $exitcond$i$i$i$i657 = ($691|0)==(32);
  if ($exitcond$i$i$i$i657) {
   break;
  } else {
   $$02$i$i$i$i654 = $692;$i$03$i$i$i$i653 = $691;$reflection$01$i$i$i$i655 = $reflection$1$i$i$i$i656;
  }
 }
 $693 = $reflection$1$i$i$i$i656 >>> 8;
 $$masked$i$i$i660 = $reflection$1$i$i$i$i656 & 255;
 $694 = $$masked$i$i$i660 ^ 82;
 $695 = (584048 + ($694<<2)|0);
 $696 = HEAP32[$695>>2]|0;
 $697 = $696 ^ $693;
 $698 = $697 >>> 8;
 $$masked$i$i$i660$1 = $697 & 255;
 $699 = $$masked$i$i$i660$1 ^ 97;
 $700 = (584048 + ($699<<2)|0);
 $701 = HEAP32[$700>>2]|0;
 $702 = $701 ^ $698;
 $703 = $702 >>> 8;
 $$masked$i$i$i660$2 = $702 & 255;
 $704 = $$masked$i$i$i660$2 ^ 110;
 $705 = (584048 + ($704<<2)|0);
 $706 = HEAP32[$705>>2]|0;
 $707 = $706 ^ $703;
 $708 = $707 >>> 8;
 $$masked$i$i$i660$3 = $707 & 255;
 $709 = $$masked$i$i$i660$3 ^ 103;
 $710 = (584048 + ($709<<2)|0);
 $711 = HEAP32[$710>>2]|0;
 $712 = $711 ^ $708;
 $713 = $712 >>> 8;
 $$masked$i$i$i660$4 = $712 & 255;
 $714 = $$masked$i$i$i660$4 ^ 101;
 $715 = (584048 + ($714<<2)|0);
 $716 = HEAP32[$715>>2]|0;
 $717 = $716 ^ $713;
 $718 = $717 >>> 8;
 $$masked$i$i$i660$5 = $717 & 255;
 $719 = $$masked$i$i$i660$5 ^ 68;
 $720 = (584048 + ($719<<2)|0);
 $721 = HEAP32[$720>>2]|0;
 $722 = $721 ^ $718;
 $723 = $722 ^ -1;
 $724 = ((794192 + 200|0));
 $725 = $724;
 HEAP32[$725>>2] = $723;
 $726 = (($724) + 4)|0;
 $727 = $726;
 HEAP32[$727>>2] = (795224);
 $$02$i$i$i$i676 = -1;$i$03$i$i$i$i675 = 0;$reflection$01$i$i$i$i677 = 0;
 while(1) {
  $728 = $$02$i$i$i$i676 & 1;
  $729 = ($728|0)==(0);
  if ($729) {
   $reflection$1$i$i$i$i678 = $reflection$01$i$i$i$i677;
  } else {
   $730 = (31 - ($i$03$i$i$i$i675))|0;
   $731 = 1 << $730;
   $732 = $731 | $reflection$01$i$i$i$i677;
   $reflection$1$i$i$i$i678 = $732;
  }
  $733 = (($i$03$i$i$i$i675) + 1)|0;
  $734 = $$02$i$i$i$i676 >>> 1;
  $exitcond$i$i$i$i679 = ($733|0)==(32);
  if ($exitcond$i$i$i$i679) {
   break;
  } else {
   $$02$i$i$i$i676 = $734;$i$03$i$i$i$i675 = $733;$reflection$01$i$i$i$i677 = $reflection$1$i$i$i$i678;
  }
 }
 $735 = $reflection$1$i$i$i$i678 >>> 8;
 $$masked$i$i$i682 = $reflection$1$i$i$i$i678 & 255;
 $736 = $$masked$i$i$i682 ^ 82;
 $737 = (584048 + ($736<<2)|0);
 $738 = HEAP32[$737>>2]|0;
 $739 = $738 ^ $735;
 $740 = $739 >>> 8;
 $$masked$i$i$i682$1 = $739 & 255;
 $741 = $$masked$i$i$i682$1 ^ 97;
 $742 = (584048 + ($741<<2)|0);
 $743 = HEAP32[$742>>2]|0;
 $744 = $743 ^ $740;
 $745 = $744 >>> 8;
 $$masked$i$i$i682$2 = $744 & 255;
 $746 = $$masked$i$i$i682$2 ^ 110;
 $747 = (584048 + ($746<<2)|0);
 $748 = HEAP32[$747>>2]|0;
 $749 = $748 ^ $745;
 $750 = $749 >>> 8;
 $$masked$i$i$i682$3 = $749 & 255;
 $751 = $$masked$i$i$i682$3 ^ 103;
 $752 = (584048 + ($751<<2)|0);
 $753 = HEAP32[$752>>2]|0;
 $754 = $753 ^ $750;
 $755 = $754 >>> 8;
 $$masked$i$i$i682$4 = $754 & 255;
 $756 = $$masked$i$i$i682$4 ^ 101;
 $757 = (584048 + ($756<<2)|0);
 $758 = HEAP32[$757>>2]|0;
 $759 = $758 ^ $755;
 $760 = $759 >>> 8;
 $$masked$i$i$i682$5 = $759 & 255;
 $761 = $$masked$i$i$i682$5 ^ 69;
 $762 = (584048 + ($761<<2)|0);
 $763 = HEAP32[$762>>2]|0;
 $764 = $763 ^ $760;
 $765 = $764 ^ -1;
 $766 = ((794192 + 208|0));
 $767 = $766;
 HEAP32[$767>>2] = $765;
 $768 = (($766) + 4)|0;
 $769 = $768;
 HEAP32[$769>>2] = (795232);
 $$02$i$i$i$i698 = -1;$i$03$i$i$i$i697 = 0;$reflection$01$i$i$i$i699 = 0;
 while(1) {
  $770 = $$02$i$i$i$i698 & 1;
  $771 = ($770|0)==(0);
  if ($771) {
   $reflection$1$i$i$i$i700 = $reflection$01$i$i$i$i699;
  } else {
   $772 = (31 - ($i$03$i$i$i$i697))|0;
   $773 = 1 << $772;
   $774 = $773 | $reflection$01$i$i$i$i699;
   $reflection$1$i$i$i$i700 = $774;
  }
  $775 = (($i$03$i$i$i$i697) + 1)|0;
  $776 = $$02$i$i$i$i698 >>> 1;
  $exitcond$i$i$i$i701 = ($775|0)==(32);
  if ($exitcond$i$i$i$i701) {
   break;
  } else {
   $$02$i$i$i$i698 = $776;$i$03$i$i$i$i697 = $775;$reflection$01$i$i$i$i699 = $reflection$1$i$i$i$i700;
  }
 }
 $777 = $reflection$1$i$i$i$i700 >>> 8;
 $$masked$i$i$i704 = $reflection$1$i$i$i$i700 & 255;
 $778 = $$masked$i$i$i704 ^ 87;
 $779 = (584048 + ($778<<2)|0);
 $780 = HEAP32[$779>>2]|0;
 $781 = $780 ^ $777;
 $782 = $781 >>> 8;
 $$masked$i$i$i704$1 = $781 & 255;
 $783 = $$masked$i$i$i704$1 ^ 101;
 $784 = (584048 + ($783<<2)|0);
 $785 = HEAP32[$784>>2]|0;
 $786 = $785 ^ $782;
 $787 = $786 >>> 8;
 $$masked$i$i$i704$2 = $786 & 255;
 $788 = $$masked$i$i$i704$2 ^ 105;
 $789 = (584048 + ($788<<2)|0);
 $790 = HEAP32[$789>>2]|0;
 $791 = $790 ^ $787;
 $792 = $791 >>> 8;
 $$masked$i$i$i704$3 = $791 & 255;
 $793 = $$masked$i$i$i704$3 ^ 103;
 $794 = (584048 + ($793<<2)|0);
 $795 = HEAP32[$794>>2]|0;
 $796 = $795 ^ $792;
 $797 = $796 >>> 8;
 $$masked$i$i$i704$4 = $796 & 255;
 $798 = $$masked$i$i$i704$4 ^ 104;
 $799 = (584048 + ($798<<2)|0);
 $800 = HEAP32[$799>>2]|0;
 $801 = $800 ^ $797;
 $802 = $801 >>> 8;
 $$masked$i$i$i704$5 = $801 & 255;
 $803 = $$masked$i$i$i704$5 ^ 116;
 $804 = (584048 + ($803<<2)|0);
 $805 = HEAP32[$804>>2]|0;
 $806 = $805 ^ $802;
 $807 = $806 >>> 8;
 $$masked$i$i$i704$6 = $806 & 255;
 $808 = $$masked$i$i$i704$6 ^ 65;
 $809 = (584048 + ($808<<2)|0);
 $810 = HEAP32[$809>>2]|0;
 $811 = $810 ^ $807;
 $812 = $811 ^ -1;
 $813 = ((794192 + 216|0));
 $814 = $813;
 HEAP32[$814>>2] = $812;
 $815 = (($813) + 4)|0;
 $816 = $815;
 HEAP32[$816>>2] = (795240);
 $817 = (__ZN7mecanimL12processCRC32EPKc(795248)|0);
 $818 = ((794192 + 224|0));
 $819 = $818;
 HEAP32[$819>>2] = $817;
 $820 = (($818) + 4)|0;
 $821 = $820;
 HEAP32[$821>>2] = (795248);
 $822 = (__ZN7mecanimL12processCRC32EPKc(795256)|0);
 $823 = ((794192 + 232|0));
 $824 = $823;
 HEAP32[$824>>2] = $822;
 $825 = (($823) + 4)|0;
 $826 = $825;
 HEAP32[$826>>2] = (795256);
 $827 = (__ZN7mecanimL12processCRC32EPKc(795264)|0);
 $828 = ((794192 + 240|0));
 $829 = $828;
 HEAP32[$829>>2] = $827;
 $830 = (($828) + 4)|0;
 $831 = $830;
 HEAP32[$831>>2] = (795264);
 $832 = (__ZN7mecanimL12processCRC32EPKc(795272)|0);
 $833 = ((794192 + 248|0));
 $834 = $833;
 HEAP32[$834>>2] = $832;
 $835 = (($833) + 4)|0;
 $836 = $835;
 HEAP32[$836>>2] = (795272);
 $837 = (__ZN7mecanimL12processCRC32EPKc(795280)|0);
 $838 = ((794192 + 256|0));
 $839 = $838;
 HEAP32[$839>>2] = $837;
 $840 = (($838) + 4)|0;
 $841 = $840;
 HEAP32[$841>>2] = (795280);
 $842 = (__ZN7mecanimL12processCRC32EPKc(795288)|0);
 $843 = ((794192 + 264|0));
 $844 = $843;
 HEAP32[$844>>2] = $842;
 $845 = (($843) + 4)|0;
 $846 = $845;
 HEAP32[$846>>2] = (795288);
 $847 = (__ZN7mecanimL12processCRC32EPKc(795296)|0);
 $848 = ((794192 + 272|0));
 $849 = $848;
 HEAP32[$849>>2] = $847;
 $850 = (($848) + 4)|0;
 $851 = $850;
 HEAP32[$851>>2] = (795296);
 $852 = (__ZN7mecanimL12processCRC32EPKc(795304)|0);
 $853 = ((794192 + 280|0));
 $854 = $853;
 HEAP32[$854>>2] = $852;
 $855 = (($853) + 4)|0;
 $856 = $855;
 HEAP32[$856>>2] = (795304);
 $857 = (__ZN7mecanimL12processCRC32EPKc(795312)|0);
 $858 = ((794192 + 288|0));
 $859 = $858;
 HEAP32[$859>>2] = $857;
 $860 = (($858) + 4)|0;
 $861 = $860;
 HEAP32[$861>>2] = (795312);
 $862 = (__ZN7mecanimL12processCRC32EPKc(795320)|0);
 $863 = ((794192 + 296|0));
 $864 = $863;
 HEAP32[$864>>2] = $862;
 $865 = (($863) + 4)|0;
 $866 = $865;
 HEAP32[$866>>2] = (795320);
 $867 = (__ZN7mecanimL12processCRC32EPKc(795328)|0);
 $868 = ((794192 + 304|0));
 $869 = $868;
 HEAP32[$869>>2] = $867;
 $870 = (($868) + 4)|0;
 $871 = $870;
 HEAP32[$871>>2] = (795328);
 $872 = (__ZN7mecanimL12processCRC32EPKc(795336)|0);
 $873 = ((794192 + 312|0));
 $874 = $873;
 HEAP32[$874>>2] = $872;
 $875 = (($873) + 4)|0;
 $876 = $875;
 HEAP32[$876>>2] = (795336);
 $877 = (__ZN7mecanimL12processCRC32EPKc(795344)|0);
 $878 = ((794192 + 320|0));
 $879 = $878;
 HEAP32[$879>>2] = $877;
 $880 = (($878) + 4)|0;
 $881 = $880;
 HEAP32[$881>>2] = (795344);
 $882 = (__ZN7mecanimL12processCRC32EPKc(795360)|0);
 $883 = ((794192 + 328|0));
 $884 = $883;
 HEAP32[$884>>2] = $882;
 $885 = (($883) + 4)|0;
 $886 = $885;
 HEAP32[$886>>2] = (795360);
 $887 = (__ZN7mecanimL12processCRC32EPKc(795376)|0);
 $888 = ((794192 + 336|0));
 $889 = $888;
 HEAP32[$889>>2] = $887;
 $890 = (($888) + 4)|0;
 $891 = $890;
 HEAP32[$891>>2] = (795376);
 $892 = (__ZN7mecanimL12processCRC32EPKc(795392)|0);
 $893 = ((794192 + 344|0));
 $894 = $893;
 HEAP32[$894>>2] = $892;
 $895 = (($893) + 4)|0;
 $896 = $895;
 HEAP32[$896>>2] = (795392);
 $897 = (__ZN7mecanimL12processCRC32EPKc(795408)|0);
 $898 = ((794192 + 352|0));
 $899 = $898;
 HEAP32[$899>>2] = $897;
 $900 = (($898) + 4)|0;
 $901 = $900;
 HEAP32[$901>>2] = (795408);
 $902 = (__ZN7mecanimL12processCRC32EPKc(795416)|0);
 $903 = ((794192 + 360|0));
 $904 = $903;
 HEAP32[$904>>2] = $902;
 $905 = (($903) + 4)|0;
 $906 = $905;
 HEAP32[$906>>2] = (795416);
 $907 = (__ZN7mecanimL12processCRC32EPKc(795424)|0);
 $908 = ((794192 + 368|0));
 $909 = $908;
 HEAP32[$909>>2] = $907;
 $910 = (($908) + 4)|0;
 $911 = $910;
 HEAP32[$911>>2] = (795424);
 $912 = (__ZN7mecanimL12processCRC32EPKc(795440)|0);
 $913 = ((794192 + 376|0));
 $914 = $913;
 HEAP32[$914>>2] = $912;
 $915 = (($913) + 4)|0;
 $916 = $915;
 HEAP32[$916>>2] = (795440);
 $917 = (__ZN7mecanimL12processCRC32EPKc(795456)|0);
 $918 = ((794192 + 384|0));
 $919 = $918;
 HEAP32[$919>>2] = $917;
 $920 = (($918) + 4)|0;
 $921 = $920;
 HEAP32[$921>>2] = (795456);
 $922 = (__ZN7mecanimL12processCRC32EPKc(795472)|0);
 $923 = ((794192 + 392|0));
 $924 = $923;
 HEAP32[$924>>2] = $922;
 $925 = (($923) + 4)|0;
 $926 = $925;
 HEAP32[$926>>2] = (795472);
 $927 = (__ZN7mecanimL12processCRC32EPKc(795488)|0);
 $928 = ((794192 + 400|0));
 $929 = $928;
 HEAP32[$929>>2] = $927;
 $930 = (($928) + 4)|0;
 $931 = $930;
 HEAP32[$931>>2] = (795488);
 $932 = (__ZN7mecanimL12processCRC32EPKc(795496)|0);
 $933 = ((794192 + 408|0));
 $934 = $933;
 HEAP32[$934>>2] = $932;
 $935 = (($933) + 4)|0;
 $936 = $935;
 HEAP32[$936>>2] = (795496);
 $$02$i$i$i$i841 = -1;$i$03$i$i$i$i840 = 0;$reflection$01$i$i$i$i842 = 0;
 while(1) {
  $937 = $$02$i$i$i$i841 & 1;
  $938 = ($937|0)==(0);
  if ($938) {
   $reflection$1$i$i$i$i843 = $reflection$01$i$i$i$i842;
  } else {
   $939 = (31 - ($i$03$i$i$i$i840))|0;
   $940 = 1 << $939;
   $941 = $940 | $reflection$01$i$i$i$i842;
   $reflection$1$i$i$i$i843 = $941;
  }
  $942 = (($i$03$i$i$i$i840) + 1)|0;
  $943 = $$02$i$i$i$i841 >>> 1;
  $exitcond$i$i$i$i844 = ($942|0)==(32);
  if ($exitcond$i$i$i$i844) {
   break;
  } else {
   $$02$i$i$i$i841 = $943;$i$03$i$i$i$i840 = $942;$reflection$01$i$i$i$i842 = $reflection$1$i$i$i$i843;
  }
 }
 $944 = $reflection$1$i$i$i$i843 >>> 8;
 $$masked$i$i$i847 = $reflection$1$i$i$i$i843 & 255;
 $945 = $$masked$i$i$i847 ^ 67;
 $946 = (584048 + ($945<<2)|0);
 $947 = HEAP32[$946>>2]|0;
 $948 = $947 ^ $944;
 $949 = $948 >>> 8;
 $$masked$i$i$i847$1 = $948 & 255;
 $950 = $$masked$i$i$i847$1 ^ 111;
 $951 = (584048 + ($950<<2)|0);
 $952 = HEAP32[$951>>2]|0;
 $953 = $952 ^ $949;
 $954 = $953 >>> 8;
 $$masked$i$i$i847$2 = $953 & 255;
 $955 = $$masked$i$i$i847$2 ^ 110;
 $956 = (584048 + ($955<<2)|0);
 $957 = HEAP32[$956>>2]|0;
 $958 = $957 ^ $954;
 $959 = $958 >>> 8;
 $$masked$i$i$i847$3 = $958 & 255;
 $960 = $$masked$i$i$i847$3 ^ 100;
 $961 = (584048 + ($960<<2)|0);
 $962 = HEAP32[$961>>2]|0;
 $963 = $962 ^ $959;
 $964 = $963 >>> 8;
 $$masked$i$i$i847$4 = $963 & 255;
 $965 = $$masked$i$i$i847$4 ^ 105;
 $966 = (584048 + ($965<<2)|0);
 $967 = HEAP32[$966>>2]|0;
 $968 = $967 ^ $964;
 $969 = $968 >>> 8;
 $$masked$i$i$i847$5 = $968 & 255;
 $970 = $$masked$i$i$i847$5 ^ 116;
 $971 = (584048 + ($970<<2)|0);
 $972 = HEAP32[$971>>2]|0;
 $973 = $972 ^ $969;
 $974 = $973 >>> 8;
 $$masked$i$i$i847$6 = $973 & 255;
 $975 = $$masked$i$i$i847$6 ^ 105;
 $976 = (584048 + ($975<<2)|0);
 $977 = HEAP32[$976>>2]|0;
 $978 = $977 ^ $974;
 $979 = $978 >>> 8;
 $$masked$i$i$i847$7 = $978 & 255;
 $980 = $$masked$i$i$i847$7 ^ 111;
 $981 = (584048 + ($980<<2)|0);
 $982 = HEAP32[$981>>2]|0;
 $983 = $982 ^ $979;
 $984 = $983 >>> 8;
 $$masked$i$i$i847$8 = $983 & 255;
 $985 = $$masked$i$i$i847$8 ^ 110;
 $986 = (584048 + ($985<<2)|0);
 $987 = HEAP32[$986>>2]|0;
 $988 = $987 ^ $984;
 $989 = $988 ^ -1;
 $990 = ((794192 + 416|0));
 $991 = $990;
 HEAP32[$991>>2] = $989;
 $992 = (($990) + 4)|0;
 $993 = $992;
 HEAP32[$993>>2] = (795504);
 $$02$i$i$i$i830 = -1;$i$03$i$i$i$i829 = 0;$reflection$01$i$i$i$i831 = 0;
 while(1) {
  $994 = $$02$i$i$i$i830 & 1;
  $995 = ($994|0)==(0);
  if ($995) {
   $reflection$1$i$i$i$i832 = $reflection$01$i$i$i$i831;
  } else {
   $996 = (31 - ($i$03$i$i$i$i829))|0;
   $997 = 1 << $996;
   $998 = $997 | $reflection$01$i$i$i$i831;
   $reflection$1$i$i$i$i832 = $998;
  }
  $999 = (($i$03$i$i$i$i829) + 1)|0;
  $1000 = $$02$i$i$i$i830 >>> 1;
  $exitcond$i$i$i$i833 = ($999|0)==(32);
  if ($exitcond$i$i$i$i833) {
   break;
  } else {
   $$02$i$i$i$i830 = $1000;$i$03$i$i$i$i829 = $999;$reflection$01$i$i$i$i831 = $reflection$1$i$i$i$i832;
  }
 }
 $1001 = $reflection$1$i$i$i$i832 >>> 8;
 $$masked$i$i$i836 = $reflection$1$i$i$i$i832 & 255;
 $1002 = $$masked$i$i$i836 ^ 83;
 $1003 = (584048 + ($1002<<2)|0);
 $1004 = HEAP32[$1003>>2]|0;
 $1005 = $1004 ^ $1001;
 $1006 = $1005 >>> 8;
 $$masked$i$i$i836$1 = $1005 & 255;
 $1007 = $$masked$i$i$i836$1 ^ 116;
 $1008 = (584048 + ($1007<<2)|0);
 $1009 = HEAP32[$1008>>2]|0;
 $1010 = $1009 ^ $1006;
 $1011 = $1010 >>> 8;
 $$masked$i$i$i836$2 = $1010 & 255;
 $1012 = $$masked$i$i$i836$2 ^ 97;
 $1013 = (584048 + ($1012<<2)|0);
 $1014 = HEAP32[$1013>>2]|0;
 $1015 = $1014 ^ $1011;
 $1016 = $1015 >>> 8;
 $$masked$i$i$i836$3 = $1015 & 255;
 $1017 = $$masked$i$i$i836$3 ^ 116;
 $1018 = (584048 + ($1017<<2)|0);
 $1019 = HEAP32[$1018>>2]|0;
 $1020 = $1019 ^ $1016;
 $1021 = $1020 >>> 8;
 $$masked$i$i$i836$4 = $1020 & 255;
 $1022 = $$masked$i$i$i836$4 ^ 101;
 $1023 = (584048 + ($1022<<2)|0);
 $1024 = HEAP32[$1023>>2]|0;
 $1025 = $1024 ^ $1021;
 $1026 = $1025 >>> 8;
 $$masked$i$i$i836$5 = $1025 & 255;
 $1027 = $$masked$i$i$i836$5 ^ 84;
 $1028 = (584048 + ($1027<<2)|0);
 $1029 = HEAP32[$1028>>2]|0;
 $1030 = $1029 ^ $1026;
 $1031 = $1030 >>> 8;
 $$masked$i$i$i836$6 = $1030 & 255;
 $1032 = $$masked$i$i$i836$6 ^ 105;
 $1033 = (584048 + ($1032<<2)|0);
 $1034 = HEAP32[$1033>>2]|0;
 $1035 = $1034 ^ $1031;
 $1036 = $1035 >>> 8;
 $$masked$i$i$i836$7 = $1035 & 255;
 $1037 = $$masked$i$i$i836$7 ^ 109;
 $1038 = (584048 + ($1037<<2)|0);
 $1039 = HEAP32[$1038>>2]|0;
 $1040 = $1039 ^ $1036;
 $1041 = $1040 >>> 8;
 $$masked$i$i$i836$8 = $1040 & 255;
 $1042 = $$masked$i$i$i836$8 ^ 101;
 $1043 = (584048 + ($1042<<2)|0);
 $1044 = HEAP32[$1043>>2]|0;
 $1045 = $1044 ^ $1041;
 $1046 = $1045 ^ -1;
 $1047 = ((794192 + 424|0));
 $1048 = $1047;
 HEAP32[$1048>>2] = $1046;
 $1049 = (($1047) + 4)|0;
 $1050 = $1049;
 HEAP32[$1050>>2] = (795520);
 $1051 = (__ZN7mecanimL12processCRC32EPKc(795536)|0);
 $1052 = ((794192 + 432|0));
 $1053 = $1052;
 HEAP32[$1053>>2] = $1051;
 $1054 = (($1052) + 4)|0;
 $1055 = $1054;
 HEAP32[$1055>>2] = (795536);
 $$02$i$i$i$i819 = -1;$i$03$i$i$i$i818 = 0;$reflection$01$i$i$i$i820 = 0;
 while(1) {
  $1056 = $$02$i$i$i$i819 & 1;
  $1057 = ($1056|0)==(0);
  if ($1057) {
   $reflection$1$i$i$i$i821 = $reflection$01$i$i$i$i820;
  } else {
   $1058 = (31 - ($i$03$i$i$i$i818))|0;
   $1059 = 1 << $1058;
   $1060 = $1059 | $reflection$01$i$i$i$i820;
   $reflection$1$i$i$i$i821 = $1060;
  }
  $1061 = (($i$03$i$i$i$i818) + 1)|0;
  $1062 = $$02$i$i$i$i819 >>> 1;
  $exitcond$i$i$i$i822 = ($1061|0)==(32);
  if ($exitcond$i$i$i$i822) {
   break;
  } else {
   $$02$i$i$i$i819 = $1062;$i$03$i$i$i$i818 = $1061;$reflection$01$i$i$i$i820 = $reflection$1$i$i$i$i821;
  }
 }
 $1063 = $reflection$1$i$i$i$i821 >>> 8;
 $$masked$i$i$i825 = $reflection$1$i$i$i$i821 & 255;
 $1064 = $$masked$i$i$i825 ^ 83;
 $1065 = (584048 + ($1064<<2)|0);
 $1066 = HEAP32[$1065>>2]|0;
 $1067 = $1066 ^ $1063;
 $1068 = $1067 >>> 8;
 $$masked$i$i$i825$1 = $1067 & 255;
 $1069 = $$masked$i$i$i825$1 ^ 116;
 $1070 = (584048 + ($1069<<2)|0);
 $1071 = HEAP32[$1070>>2]|0;
 $1072 = $1071 ^ $1068;
 $1073 = $1072 >>> 8;
 $$masked$i$i$i825$2 = $1072 & 255;
 $1074 = $$masked$i$i$i825$2 ^ 97;
 $1075 = (584048 + ($1074<<2)|0);
 $1076 = HEAP32[$1075>>2]|0;
 $1077 = $1076 ^ $1073;
 $1078 = $1077 >>> 8;
 $$masked$i$i$i825$3 = $1077 & 255;
 $1079 = $$masked$i$i$i825$3 ^ 116;
 $1080 = (584048 + ($1079<<2)|0);
 $1081 = HEAP32[$1080>>2]|0;
 $1082 = $1081 ^ $1078;
 $1083 = $1082 >>> 8;
 $$masked$i$i$i825$4 = $1082 & 255;
 $1084 = $$masked$i$i$i825$4 ^ 101;
 $1085 = (584048 + ($1084<<2)|0);
 $1086 = HEAP32[$1085>>2]|0;
 $1087 = $1086 ^ $1083;
 $1088 = $1087 >>> 8;
 $$masked$i$i$i825$5 = $1087 & 255;
 $1089 = $$masked$i$i$i825$5 ^ 69;
 $1090 = (584048 + ($1089<<2)|0);
 $1091 = HEAP32[$1090>>2]|0;
 $1092 = $1091 ^ $1088;
 $1093 = $1092 >>> 8;
 $$masked$i$i$i825$6 = $1092 & 255;
 $1094 = $$masked$i$i$i825$6 ^ 120;
 $1095 = (584048 + ($1094<<2)|0);
 $1096 = HEAP32[$1095>>2]|0;
 $1097 = $1096 ^ $1093;
 $1098 = $1097 >>> 8;
 $$masked$i$i$i825$7 = $1097 & 255;
 $1099 = $$masked$i$i$i825$7 ^ 105;
 $1100 = (584048 + ($1099<<2)|0);
 $1101 = HEAP32[$1100>>2]|0;
 $1102 = $1101 ^ $1098;
 $1103 = $1102 >>> 8;
 $$masked$i$i$i825$8 = $1102 & 255;
 $1104 = $$masked$i$i$i825$8 ^ 116;
 $1105 = (584048 + ($1104<<2)|0);
 $1106 = HEAP32[$1105>>2]|0;
 $1107 = $1106 ^ $1103;
 $1108 = $1107 >>> 8;
 $$masked$i$i$i825$9 = $1107 & 255;
 $1109 = $$masked$i$i$i825$9 ^ 84;
 $1110 = (584048 + ($1109<<2)|0);
 $1111 = HEAP32[$1110>>2]|0;
 $1112 = $1111 ^ $1108;
 $1113 = $1112 >>> 8;
 $$masked$i$i$i825$10 = $1112 & 255;
 $1114 = $$masked$i$i$i825$10 ^ 105;
 $1115 = (584048 + ($1114<<2)|0);
 $1116 = HEAP32[$1115>>2]|0;
 $1117 = $1116 ^ $1113;
 $1118 = $1117 >>> 8;
 $$masked$i$i$i825$11 = $1117 & 255;
 $1119 = $$masked$i$i$i825$11 ^ 109;
 $1120 = (584048 + ($1119<<2)|0);
 $1121 = HEAP32[$1120>>2]|0;
 $1122 = $1121 ^ $1118;
 $1123 = $1122 >>> 8;
 $$masked$i$i$i825$12 = $1122 & 255;
 $1124 = $$masked$i$i$i825$12 ^ 101;
 $1125 = (584048 + ($1124<<2)|0);
 $1126 = HEAP32[$1125>>2]|0;
 $1127 = $1126 ^ $1123;
 $1128 = $1127 ^ -1;
 $1129 = ((794192 + 440|0));
 $1130 = $1129;
 HEAP32[$1130>>2] = $1128;
 $1131 = (($1129) + 4)|0;
 $1132 = $1131;
 HEAP32[$1132>>2] = (795552);
 $1133 = (__ZN7mecanimL12processCRC32EPKc(795568)|0);
 $1134 = ((794192 + 448|0));
 $1135 = $1134;
 HEAP32[$1135>>2] = $1133;
 $1136 = (($1134) + 4)|0;
 $1137 = $1136;
 HEAP32[$1137>>2] = (795568);
 $$02$i$i$i$i808 = -1;$i$03$i$i$i$i807 = 0;$reflection$01$i$i$i$i809 = 0;
 while(1) {
  $1138 = $$02$i$i$i$i808 & 1;
  $1139 = ($1138|0)==(0);
  if ($1139) {
   $reflection$1$i$i$i$i810 = $reflection$01$i$i$i$i809;
  } else {
   $1140 = (31 - ($i$03$i$i$i$i807))|0;
   $1141 = 1 << $1140;
   $1142 = $1141 | $reflection$01$i$i$i$i809;
   $reflection$1$i$i$i$i810 = $1142;
  }
  $1143 = (($i$03$i$i$i$i807) + 1)|0;
  $1144 = $$02$i$i$i$i808 >>> 1;
  $exitcond$i$i$i$i811 = ($1143|0)==(32);
  if ($exitcond$i$i$i$i811) {
   $1148 = $reflection$1$i$i$i$i810;$p$01$i$i$i813 = 795584;
   break;
  } else {
   $$02$i$i$i$i808 = $1144;$i$03$i$i$i$i807 = $1143;$reflection$01$i$i$i$i809 = $reflection$1$i$i$i$i810;
  }
 }
 while(1) {
  $1145 = HEAP8[$p$01$i$i$i813>>0]|0;
  $1146 = $1145&255;
  $1147 = $1148 >>> 8;
  $$masked$i$i$i814 = $1148 & 255;
  $1149 = $1146 ^ $$masked$i$i$i814;
  $1150 = (584048 + ($1149<<2)|0);
  $1151 = HEAP32[$1150>>2]|0;
  $1152 = $1151 ^ $1147;
  $1153 = (($p$01$i$i$i813) + 1|0);
  $exitcond$i$i$i815 = ($1153|0)==(((795584 + 18|0))|0);
  if ($exitcond$i$i$i815) {
   break;
  } else {
   $1148 = $1152;$p$01$i$i$i813 = $1153;
  }
 }
 $1154 = $1152 ^ -1;
 $1155 = ((794192 + 456|0));
 $1156 = $1155;
 HEAP32[$1156>>2] = $1154;
 $1157 = (($1155) + 4)|0;
 $1158 = $1157;
 HEAP32[$1158>>2] = (795584);
 $1159 = (__ZN7mecanimL12processCRC32EPKc(795608)|0);
 $1160 = ((794192 + 464|0));
 $1161 = $1160;
 HEAP32[$1161>>2] = $1159;
 $1162 = (($1160) + 4)|0;
 $1163 = $1162;
 HEAP32[$1163>>2] = (795608);
 $$02$i$i$i$i797 = -1;$i$03$i$i$i$i796 = 0;$reflection$01$i$i$i$i798 = 0;
 while(1) {
  $1164 = $$02$i$i$i$i797 & 1;
  $1165 = ($1164|0)==(0);
  if ($1165) {
   $reflection$1$i$i$i$i799 = $reflection$01$i$i$i$i798;
  } else {
   $1166 = (31 - ($i$03$i$i$i$i796))|0;
   $1167 = 1 << $1166;
   $1168 = $1167 | $reflection$01$i$i$i$i798;
   $reflection$1$i$i$i$i799 = $1168;
  }
  $1169 = (($i$03$i$i$i$i796) + 1)|0;
  $1170 = $$02$i$i$i$i797 >>> 1;
  $exitcond$i$i$i$i800 = ($1169|0)==(32);
  if ($exitcond$i$i$i$i800) {
   $1174 = $reflection$1$i$i$i$i799;$p$01$i$i$i802 = 795632;
   break;
  } else {
   $$02$i$i$i$i797 = $1170;$i$03$i$i$i$i796 = $1169;$reflection$01$i$i$i$i798 = $reflection$1$i$i$i$i799;
  }
 }
 while(1) {
  $1171 = HEAP8[$p$01$i$i$i802>>0]|0;
  $1172 = $1171&255;
  $1173 = $1174 >>> 8;
  $$masked$i$i$i803 = $1174 & 255;
  $1175 = $1172 ^ $$masked$i$i$i803;
  $1176 = (584048 + ($1175<<2)|0);
  $1177 = HEAP32[$1176>>2]|0;
  $1178 = $1177 ^ $1173;
  $1179 = (($p$01$i$i$i802) + 1|0);
  $exitcond$i$i$i804 = ($1179|0)==(((795632 + 16|0))|0);
  if ($exitcond$i$i$i804) {
   break;
  } else {
   $1174 = $1178;$p$01$i$i$i802 = $1179;
  }
 }
 $1180 = $1178 ^ -1;
 $1181 = ((794192 + 472|0));
 $1182 = $1181;
 HEAP32[$1182>>2] = $1180;
 $1183 = (($1181) + 4)|0;
 $1184 = $1183;
 HEAP32[$1184>>2] = (795632);
 $1185 = (__ZN7mecanimL12processCRC32EPKc(795656)|0);
 $1186 = ((794192 + 480|0));
 $1187 = $1186;
 HEAP32[$1187>>2] = $1185;
 $1188 = (($1186) + 4)|0;
 $1189 = $1188;
 HEAP32[$1189>>2] = (795656);
 $$02$i$i$i$i786 = -1;$i$03$i$i$i$i785 = 0;$reflection$01$i$i$i$i787 = 0;
 while(1) {
  $1190 = $$02$i$i$i$i786 & 1;
  $1191 = ($1190|0)==(0);
  if ($1191) {
   $reflection$1$i$i$i$i788 = $reflection$01$i$i$i$i787;
  } else {
   $1192 = (31 - ($i$03$i$i$i$i785))|0;
   $1193 = 1 << $1192;
   $1194 = $1193 | $reflection$01$i$i$i$i787;
   $reflection$1$i$i$i$i788 = $1194;
  }
  $1195 = (($i$03$i$i$i$i785) + 1)|0;
  $1196 = $$02$i$i$i$i786 >>> 1;
  $exitcond$i$i$i$i789 = ($1195|0)==(32);
  if ($exitcond$i$i$i$i789) {
   $1200 = $reflection$1$i$i$i$i788;$p$01$i$i$i791 = 795680;
   break;
  } else {
   $$02$i$i$i$i786 = $1196;$i$03$i$i$i$i785 = $1195;$reflection$01$i$i$i$i787 = $reflection$1$i$i$i$i788;
  }
 }
 while(1) {
  $1197 = HEAP8[$p$01$i$i$i791>>0]|0;
  $1198 = $1197&255;
  $1199 = $1200 >>> 8;
  $$masked$i$i$i792 = $1200 & 255;
  $1201 = $1198 ^ $$masked$i$i$i792;
  $1202 = (584048 + ($1201<<2)|0);
  $1203 = HEAP32[$1202>>2]|0;
  $1204 = $1203 ^ $1199;
  $1205 = (($p$01$i$i$i791) + 1|0);
  $exitcond$i$i$i793 = ($1205|0)==(((795680 + 18|0))|0);
  if ($exitcond$i$i$i793) {
   break;
  } else {
   $1200 = $1204;$p$01$i$i$i791 = $1205;
  }
 }
 $1206 = $1204 ^ -1;
 $1207 = ((794192 + 488|0));
 $1208 = $1207;
 HEAP32[$1208>>2] = $1206;
 $1209 = (($1207) + 4)|0;
 $1210 = $1209;
 HEAP32[$1210>>2] = (795680);
 $1211 = (__ZN7mecanimL12processCRC32EPKc(795704)|0);
 $1212 = ((794192 + 496|0));
 $1213 = $1212;
 HEAP32[$1213>>2] = $1211;
 $1214 = (($1212) + 4)|0;
 $1215 = $1214;
 HEAP32[$1215>>2] = (795704);
 $$02$i$i$i$i775 = -1;$i$03$i$i$i$i774 = 0;$reflection$01$i$i$i$i776 = 0;
 while(1) {
  $1216 = $$02$i$i$i$i775 & 1;
  $1217 = ($1216|0)==(0);
  if ($1217) {
   $reflection$1$i$i$i$i777 = $reflection$01$i$i$i$i776;
  } else {
   $1218 = (31 - ($i$03$i$i$i$i774))|0;
   $1219 = 1 << $1218;
   $1220 = $1219 | $reflection$01$i$i$i$i776;
   $reflection$1$i$i$i$i777 = $1220;
  }
  $1221 = (($i$03$i$i$i$i774) + 1)|0;
  $1222 = $$02$i$i$i$i775 >>> 1;
  $exitcond$i$i$i$i778 = ($1221|0)==(32);
  if ($exitcond$i$i$i$i778) {
   break;
  } else {
   $$02$i$i$i$i775 = $1222;$i$03$i$i$i$i774 = $1221;$reflection$01$i$i$i$i776 = $reflection$1$i$i$i$i777;
  }
 }
 $1223 = $reflection$1$i$i$i$i777 >>> 8;
 $$masked$i$i$i781 = $reflection$1$i$i$i$i777 & 255;
 $1224 = $$masked$i$i$i781 ^ 66;
 $1225 = (584048 + ($1224<<2)|0);
 $1226 = HEAP32[$1225>>2]|0;
 $1227 = $1226 ^ $1223;
 $1228 = $1227 >>> 8;
 $$masked$i$i$i781$1 = $1227 & 255;
 $1229 = $$masked$i$i$i781$1 ^ 108;
 $1230 = (584048 + ($1229<<2)|0);
 $1231 = HEAP32[$1230>>2]|0;
 $1232 = $1231 ^ $1228;
 $1233 = $1232 >>> 8;
 $$masked$i$i$i781$2 = $1232 & 255;
 $1234 = $$masked$i$i$i781$2 ^ 101;
 $1235 = (584048 + ($1234<<2)|0);
 $1236 = HEAP32[$1235>>2]|0;
 $1237 = $1236 ^ $1233;
 $1238 = $1237 >>> 8;
 $$masked$i$i$i781$3 = $1237 & 255;
 $1239 = $$masked$i$i$i781$3 ^ 110;
 $1240 = (584048 + ($1239<<2)|0);
 $1241 = HEAP32[$1240>>2]|0;
 $1242 = $1241 ^ $1238;
 $1243 = $1242 >>> 8;
 $$masked$i$i$i781$4 = $1242 & 255;
 $1244 = $$masked$i$i$i781$4 ^ 100;
 $1245 = (584048 + ($1244<<2)|0);
 $1246 = HEAP32[$1245>>2]|0;
 $1247 = $1246 ^ $1243;
 $1248 = $1247 >>> 8;
 $$masked$i$i$i781$5 = $1247 & 255;
 $1249 = $$masked$i$i$i781$5 ^ 87;
 $1250 = (584048 + ($1249<<2)|0);
 $1251 = HEAP32[$1250>>2]|0;
 $1252 = $1251 ^ $1248;
 $1253 = $1252 >>> 8;
 $$masked$i$i$i781$6 = $1252 & 255;
 $1254 = $$masked$i$i$i781$6 ^ 101;
 $1255 = (584048 + ($1254<<2)|0);
 $1256 = HEAP32[$1255>>2]|0;
 $1257 = $1256 ^ $1253;
 $1258 = $1257 >>> 8;
 $$masked$i$i$i781$7 = $1257 & 255;
 $1259 = $$masked$i$i$i781$7 ^ 105;
 $1260 = (584048 + ($1259<<2)|0);
 $1261 = HEAP32[$1260>>2]|0;
 $1262 = $1261 ^ $1258;
 $1263 = $1262 >>> 8;
 $$masked$i$i$i781$8 = $1262 & 255;
 $1264 = $$masked$i$i$i781$8 ^ 103;
 $1265 = (584048 + ($1264<<2)|0);
 $1266 = HEAP32[$1265>>2]|0;
 $1267 = $1266 ^ $1263;
 $1268 = $1267 >>> 8;
 $$masked$i$i$i781$9 = $1267 & 255;
 $1269 = $$masked$i$i$i781$9 ^ 104;
 $1270 = (584048 + ($1269<<2)|0);
 $1271 = HEAP32[$1270>>2]|0;
 $1272 = $1271 ^ $1268;
 $1273 = $1272 >>> 8;
 $$masked$i$i$i781$10 = $1272 & 255;
 $1274 = $$masked$i$i$i781$10 ^ 116;
 $1275 = (584048 + ($1274<<2)|0);
 $1276 = HEAP32[$1275>>2]|0;
 $1277 = $1276 ^ $1273;
 $1278 = $1277 ^ -1;
 $1279 = ((794192 + 504|0));
 $1280 = $1279;
 HEAP32[$1280>>2] = $1278;
 $1281 = (($1279) + 4)|0;
 $1282 = $1281;
 HEAP32[$1282>>2] = (795720);
 $1283 = (__ZN7mecanimL12processCRC32EPKc(795736)|0);
 $1284 = ((794192 + 512|0));
 $1285 = $1284;
 HEAP32[$1285>>2] = $1283;
 $1286 = (($1284) + 4)|0;
 $1287 = $1286;
 HEAP32[$1287>>2] = (795736);
 $$02$i$i$i$i764 = -1;$i$03$i$i$i$i763 = 0;$reflection$01$i$i$i$i765 = 0;
 while(1) {
  $1288 = $$02$i$i$i$i764 & 1;
  $1289 = ($1288|0)==(0);
  if ($1289) {
   $reflection$1$i$i$i$i766 = $reflection$01$i$i$i$i765;
  } else {
   $1290 = (31 - ($i$03$i$i$i$i763))|0;
   $1291 = 1 << $1290;
   $1292 = $1291 | $reflection$01$i$i$i$i765;
   $reflection$1$i$i$i$i766 = $1292;
  }
  $1293 = (($i$03$i$i$i$i763) + 1)|0;
  $1294 = $$02$i$i$i$i764 >>> 1;
  $exitcond$i$i$i$i767 = ($1293|0)==(32);
  if ($exitcond$i$i$i$i767) {
   break;
  } else {
   $$02$i$i$i$i764 = $1294;$i$03$i$i$i$i763 = $1293;$reflection$01$i$i$i$i765 = $reflection$1$i$i$i$i766;
  }
 }
 $1295 = $reflection$1$i$i$i$i766 >>> 8;
 $$masked$i$i$i770 = $reflection$1$i$i$i$i766 & 255;
 $1296 = $$masked$i$i$i770 ^ 83;
 $1297 = (584048 + ($1296<<2)|0);
 $1298 = HEAP32[$1297>>2]|0;
 $1299 = $1298 ^ $1295;
 $1300 = $1299 >>> 8;
 $$masked$i$i$i770$1 = $1299 & 255;
 $1301 = $$masked$i$i$i770$1 ^ 116;
 $1302 = (584048 + ($1301<<2)|0);
 $1303 = HEAP32[$1302>>2]|0;
 $1304 = $1303 ^ $1300;
 $1305 = $1304 >>> 8;
 $$masked$i$i$i770$2 = $1304 & 255;
 $1306 = $$masked$i$i$i770$2 ^ 97;
 $1307 = (584048 + ($1306<<2)|0);
 $1308 = HEAP32[$1307>>2]|0;
 $1309 = $1308 ^ $1305;
 $1310 = $1309 >>> 8;
 $$masked$i$i$i770$3 = $1309 & 255;
 $1311 = $$masked$i$i$i770$3 ^ 98;
 $1312 = (584048 + ($1311<<2)|0);
 $1313 = HEAP32[$1312>>2]|0;
 $1314 = $1313 ^ $1310;
 $1315 = $1314 >>> 8;
 $$masked$i$i$i770$4 = $1314 & 255;
 $1316 = $$masked$i$i$i770$4 ^ 105;
 $1317 = (584048 + ($1316<<2)|0);
 $1318 = HEAP32[$1317>>2]|0;
 $1319 = $1318 ^ $1315;
 $1320 = $1319 >>> 8;
 $$masked$i$i$i770$5 = $1319 & 255;
 $1321 = $$masked$i$i$i770$5 ^ 108;
 $1322 = (584048 + ($1321<<2)|0);
 $1323 = HEAP32[$1322>>2]|0;
 $1324 = $1323 ^ $1320;
 $1325 = $1324 >>> 8;
 $$masked$i$i$i770$6 = $1324 & 255;
 $1326 = $$masked$i$i$i770$6 ^ 105;
 $1327 = (584048 + ($1326<<2)|0);
 $1328 = HEAP32[$1327>>2]|0;
 $1329 = $1328 ^ $1325;
 $1330 = $1329 >>> 8;
 $$masked$i$i$i770$7 = $1329 & 255;
 $1331 = $$masked$i$i$i770$7 ^ 122;
 $1332 = (584048 + ($1331<<2)|0);
 $1333 = HEAP32[$1332>>2]|0;
 $1334 = $1333 ^ $1330;
 $1335 = $1334 >>> 8;
 $$masked$i$i$i770$8 = $1334 & 255;
 $1336 = $$masked$i$i$i770$8 ^ 101;
 $1337 = (584048 + ($1336<<2)|0);
 $1338 = HEAP32[$1337>>2]|0;
 $1339 = $1338 ^ $1335;
 $1340 = $1339 >>> 8;
 $$masked$i$i$i770$9 = $1339 & 255;
 $1341 = $$masked$i$i$i770$9 ^ 70;
 $1342 = (584048 + ($1341<<2)|0);
 $1343 = HEAP32[$1342>>2]|0;
 $1344 = $1343 ^ $1340;
 $1345 = $1344 >>> 8;
 $$masked$i$i$i770$10 = $1344 & 255;
 $1346 = $$masked$i$i$i770$10 ^ 101;
 $1347 = (584048 + ($1346<<2)|0);
 $1348 = HEAP32[$1347>>2]|0;
 $1349 = $1348 ^ $1345;
 $1350 = $1349 >>> 8;
 $$masked$i$i$i770$11 = $1349 & 255;
 $1351 = $$masked$i$i$i770$11 ^ 101;
 $1352 = (584048 + ($1351<<2)|0);
 $1353 = HEAP32[$1352>>2]|0;
 $1354 = $1353 ^ $1350;
 $1355 = $1354 >>> 8;
 $$masked$i$i$i770$12 = $1354 & 255;
 $1356 = $$masked$i$i$i770$12 ^ 116;
 $1357 = (584048 + ($1356<<2)|0);
 $1358 = HEAP32[$1357>>2]|0;
 $1359 = $1358 ^ $1355;
 $1360 = $1359 ^ -1;
 $1361 = ((794192 + 520|0));
 $1362 = $1361;
 HEAP32[$1362>>2] = $1360;
 $1363 = (($1361) + 4)|0;
 $1364 = $1363;
 HEAP32[$1364>>2] = (795752);
 $$02$i$i$i$i753 = -1;$i$03$i$i$i$i752 = 0;$reflection$01$i$i$i$i754 = 0;
 while(1) {
  $1365 = $$02$i$i$i$i753 & 1;
  $1366 = ($1365|0)==(0);
  if ($1366) {
   $reflection$1$i$i$i$i755 = $reflection$01$i$i$i$i754;
  } else {
   $1367 = (31 - ($i$03$i$i$i$i752))|0;
   $1368 = 1 << $1367;
   $1369 = $1368 | $reflection$01$i$i$i$i754;
   $reflection$1$i$i$i$i755 = $1369;
  }
  $1370 = (($i$03$i$i$i$i752) + 1)|0;
  $1371 = $$02$i$i$i$i753 >>> 1;
  $exitcond$i$i$i$i756 = ($1370|0)==(32);
  if ($exitcond$i$i$i$i756) {
   break;
  } else {
   $$02$i$i$i$i753 = $1371;$i$03$i$i$i$i752 = $1370;$reflection$01$i$i$i$i754 = $reflection$1$i$i$i$i755;
  }
 }
 $1372 = $reflection$1$i$i$i$i755 >>> 8;
 $$masked$i$i$i759 = $reflection$1$i$i$i$i755 & 255;
 $1373 = $$masked$i$i$i759 ^ 82;
 $1374 = (584048 + ($1373<<2)|0);
 $1375 = HEAP32[$1374>>2]|0;
 $1376 = $1375 ^ $1372;
 $1377 = $1376 >>> 8;
 $$masked$i$i$i759$1 = $1376 & 255;
 $1378 = $$masked$i$i$i759$1 ^ 111;
 $1379 = (584048 + ($1378<<2)|0);
 $1380 = HEAP32[$1379>>2]|0;
 $1381 = $1380 ^ $1377;
 $1382 = $1381 >>> 8;
 $$masked$i$i$i759$2 = $1381 & 255;
 $1383 = $$masked$i$i$i759$2 ^ 111;
 $1384 = (584048 + ($1383<<2)|0);
 $1385 = HEAP32[$1384>>2]|0;
 $1386 = $1385 ^ $1382;
 $1387 = $1386 >>> 8;
 $$masked$i$i$i759$3 = $1386 & 255;
 $1388 = $$masked$i$i$i759$3 ^ 116;
 $1389 = (584048 + ($1388<<2)|0);
 $1390 = HEAP32[$1389>>2]|0;
 $1391 = $1390 ^ $1387;
 $1392 = $1391 >>> 8;
 $$masked$i$i$i759$4 = $1391 & 255;
 $1393 = $$masked$i$i$i759$4 ^ 88;
 $1394 = (584048 + ($1393<<2)|0);
 $1395 = HEAP32[$1394>>2]|0;
 $1396 = $1395 ^ $1392;
 $1397 = $1396 ^ -1;
 $1398 = ((794192 + 528|0));
 $1399 = $1398;
 HEAP32[$1399>>2] = $1397;
 $1400 = (($1398) + 4)|0;
 $1401 = $1400;
 HEAP32[$1401>>2] = (795768);
 $1402 = (__ZN7mecanimL12processCRC32EPKc(795776)|0);
 $1403 = ((794192 + 536|0));
 $1404 = $1403;
 HEAP32[$1404>>2] = $1402;
 $1405 = (($1403) + 4)|0;
 $1406 = $1405;
 HEAP32[$1406>>2] = (795776);
 $$02$i$i$i$i742 = -1;$i$03$i$i$i$i741 = 0;$reflection$01$i$i$i$i743 = 0;
 while(1) {
  $1407 = $$02$i$i$i$i742 & 1;
  $1408 = ($1407|0)==(0);
  if ($1408) {
   $reflection$1$i$i$i$i744 = $reflection$01$i$i$i$i743;
  } else {
   $1409 = (31 - ($i$03$i$i$i$i741))|0;
   $1410 = 1 << $1409;
   $1411 = $1410 | $reflection$01$i$i$i$i743;
   $reflection$1$i$i$i$i744 = $1411;
  }
  $1412 = (($i$03$i$i$i$i741) + 1)|0;
  $1413 = $$02$i$i$i$i742 >>> 1;
  $exitcond$i$i$i$i745 = ($1412|0)==(32);
  if ($exitcond$i$i$i$i745) {
   $1417 = $reflection$1$i$i$i$i744;$p$01$i$i$i747 = 795800;
   break;
  } else {
   $$02$i$i$i$i742 = $1413;$i$03$i$i$i$i741 = $1412;$reflection$01$i$i$i$i743 = $reflection$1$i$i$i$i744;
  }
 }
 while(1) {
  $1414 = HEAP8[$p$01$i$i$i747>>0]|0;
  $1415 = $1414&255;
  $1416 = $1417 >>> 8;
  $$masked$i$i$i748 = $1417 & 255;
  $1418 = $1415 ^ $$masked$i$i$i748;
  $1419 = (584048 + ($1418<<2)|0);
  $1420 = HEAP32[$1419>>2]|0;
  $1421 = $1420 ^ $1416;
  $1422 = (($p$01$i$i$i747) + 1|0);
  $exitcond$i$i$i749 = ($1422|0)==(((795800 + 16|0))|0);
  if ($exitcond$i$i$i749) {
   break;
  } else {
   $1417 = $1421;$p$01$i$i$i747 = $1422;
  }
 }
 $1423 = $1421 ^ -1;
 $1424 = ((794192 + 544|0));
 $1425 = $1424;
 HEAP32[$1425>>2] = $1423;
 $1426 = (($1424) + 4)|0;
 $1427 = $1426;
 HEAP32[$1427>>2] = (795800);
 $1428 = (__ZN7mecanimL12processCRC32EPKc(795824)|0);
 $1429 = ((794192 + 552|0));
 $1430 = $1429;
 HEAP32[$1430>>2] = $1428;
 $1431 = (($1429) + 4)|0;
 $1432 = $1431;
 HEAP32[$1432>>2] = (795824);
 $$02$i$i$i$i731 = -1;$i$03$i$i$i$i730 = 0;$reflection$01$i$i$i$i732 = 0;
 while(1) {
  $1433 = $$02$i$i$i$i731 & 1;
  $1434 = ($1433|0)==(0);
  if ($1434) {
   $reflection$1$i$i$i$i733 = $reflection$01$i$i$i$i732;
  } else {
   $1435 = (31 - ($i$03$i$i$i$i730))|0;
   $1436 = 1 << $1435;
   $1437 = $1436 | $reflection$01$i$i$i$i732;
   $reflection$1$i$i$i$i733 = $1437;
  }
  $1438 = (($i$03$i$i$i$i730) + 1)|0;
  $1439 = $$02$i$i$i$i731 >>> 1;
  $exitcond$i$i$i$i734 = ($1438|0)==(32);
  if ($exitcond$i$i$i$i734) {
   $1443 = $reflection$1$i$i$i$i733;$p$01$i$i$i736 = 795848;
   break;
  } else {
   $$02$i$i$i$i731 = $1439;$i$03$i$i$i$i730 = $1438;$reflection$01$i$i$i$i732 = $reflection$1$i$i$i$i733;
  }
 }
 while(1) {
  $1440 = HEAP8[$p$01$i$i$i736>>0]|0;
  $1441 = $1440&255;
  $1442 = $1443 >>> 8;
  $$masked$i$i$i737 = $1443 & 255;
  $1444 = $1441 ^ $$masked$i$i$i737;
  $1445 = (584048 + ($1444<<2)|0);
  $1446 = HEAP32[$1445>>2]|0;
  $1447 = $1446 ^ $1442;
  $1448 = (($p$01$i$i$i736) + 1|0);
  $exitcond$i$i$i738 = ($1448|0)==(((795848 + 17|0))|0);
  if ($exitcond$i$i$i738) {
   break;
  } else {
   $1443 = $1447;$p$01$i$i$i736 = $1448;
  }
 }
 $1449 = $1447 ^ -1;
 $1450 = ((794192 + 560|0));
 $1451 = $1450;
 HEAP32[$1451>>2] = $1449;
 $1452 = (($1450) + 4)|0;
 $1453 = $1452;
 HEAP32[$1453>>2] = (795848);
 $1454 = (__ZN7mecanimL12processCRC32EPKc(795872)|0);
 $1455 = ((794192 + 568|0));
 $1456 = $1455;
 HEAP32[$1456>>2] = $1454;
 $1457 = (($1455) + 4)|0;
 $1458 = $1457;
 HEAP32[$1458>>2] = (795872);
 $$02$i$i$i$i720 = -1;$i$03$i$i$i$i719 = 0;$reflection$01$i$i$i$i721 = 0;
 while(1) {
  $1459 = $$02$i$i$i$i720 & 1;
  $1460 = ($1459|0)==(0);
  if ($1460) {
   $reflection$1$i$i$i$i722 = $reflection$01$i$i$i$i721;
  } else {
   $1461 = (31 - ($i$03$i$i$i$i719))|0;
   $1462 = 1 << $1461;
   $1463 = $1462 | $reflection$01$i$i$i$i721;
   $reflection$1$i$i$i$i722 = $1463;
  }
  $1464 = (($i$03$i$i$i$i719) + 1)|0;
  $1465 = $$02$i$i$i$i720 >>> 1;
  $exitcond$i$i$i$i723 = ($1464|0)==(32);
  if ($exitcond$i$i$i$i723) {
   break;
  } else {
   $$02$i$i$i$i720 = $1465;$i$03$i$i$i$i719 = $1464;$reflection$01$i$i$i$i721 = $reflection$1$i$i$i$i722;
  }
 }
 $1466 = $reflection$1$i$i$i$i722 >>> 8;
 $$masked$i$i$i726 = $reflection$1$i$i$i$i722 & 255;
 $1467 = $$masked$i$i$i726 ^ 76;
 $1468 = (584048 + ($1467<<2)|0);
 $1469 = HEAP32[$1468>>2]|0;
 $1470 = $1469 ^ $1466;
 $1471 = $1470 >>> 8;
 $$masked$i$i$i726$1 = $1470 & 255;
 $1472 = $$masked$i$i$i726$1 ^ 111;
 $1473 = (584048 + ($1472<<2)|0);
 $1474 = HEAP32[$1473>>2]|0;
 $1475 = $1474 ^ $1471;
 $1476 = $1475 >>> 8;
 $$masked$i$i$i726$2 = $1475 & 255;
 $1477 = $$masked$i$i$i726$2 ^ 111;
 $1478 = (584048 + ($1477<<2)|0);
 $1479 = HEAP32[$1478>>2]|0;
 $1480 = $1479 ^ $1476;
 $1481 = $1480 >>> 8;
 $$masked$i$i$i726$3 = $1480 & 255;
 $1482 = $$masked$i$i$i726$3 ^ 107;
 $1483 = (584048 + ($1482<<2)|0);
 $1484 = HEAP32[$1483>>2]|0;
 $1485 = $1484 ^ $1481;
 $1486 = $1485 >>> 8;
 $$masked$i$i$i726$4 = $1485 & 255;
 $1487 = $$masked$i$i$i726$4 ^ 65;
 $1488 = (584048 + ($1487<<2)|0);
 $1489 = HEAP32[$1488>>2]|0;
 $1490 = $1489 ^ $1486;
 $1491 = $1490 >>> 8;
 $$masked$i$i$i726$5 = $1490 & 255;
 $1492 = $$masked$i$i$i726$5 ^ 116;
 $1493 = (584048 + ($1492<<2)|0);
 $1494 = HEAP32[$1493>>2]|0;
 $1495 = $1494 ^ $1491;
 $1496 = $1495 ^ -1;
 $1497 = ((794192 + 576|0));
 $1498 = $1497;
 HEAP32[$1498>>2] = $1496;
 $1499 = (($1497) + 4)|0;
 $1500 = $1499;
 HEAP32[$1500>>2] = (795888);
 $1501 = (__ZN7mecanimL12processCRC32EPKc(795896)|0);
 $1502 = ((794192 + 584|0));
 $1503 = $1502;
 HEAP32[$1503>>2] = $1501;
 $1504 = (($1502) + 4)|0;
 $1505 = $1504;
 HEAP32[$1505>>2] = (795896);
 $$02$i$i$i$i709 = -1;$i$03$i$i$i$i708 = 0;$reflection$01$i$i$i$i710 = 0;
 while(1) {
  $1506 = $$02$i$i$i$i709 & 1;
  $1507 = ($1506|0)==(0);
  if ($1507) {
   $reflection$1$i$i$i$i711 = $reflection$01$i$i$i$i710;
  } else {
   $1508 = (31 - ($i$03$i$i$i$i708))|0;
   $1509 = 1 << $1508;
   $1510 = $1509 | $reflection$01$i$i$i$i710;
   $reflection$1$i$i$i$i711 = $1510;
  }
  $1511 = (($i$03$i$i$i$i708) + 1)|0;
  $1512 = $$02$i$i$i$i709 >>> 1;
  $exitcond$i$i$i$i712 = ($1511|0)==(32);
  if ($exitcond$i$i$i$i712) {
   break;
  } else {
   $$02$i$i$i$i709 = $1512;$i$03$i$i$i$i708 = $1511;$reflection$01$i$i$i$i710 = $reflection$1$i$i$i$i711;
  }
 }
 $1513 = $reflection$1$i$i$i$i711 >>> 8;
 $$masked$i$i$i715 = $reflection$1$i$i$i$i711 & 255;
 $1514 = $$masked$i$i$i715 ^ 82;
 $1515 = (584048 + ($1514<<2)|0);
 $1516 = HEAP32[$1515>>2]|0;
 $1517 = $1516 ^ $1513;
 $1518 = $1517 >>> 8;
 $$masked$i$i$i715$1 = $1517 & 255;
 $1519 = $$masked$i$i$i715$1 ^ 105;
 $1520 = (584048 + ($1519<<2)|0);
 $1521 = HEAP32[$1520>>2]|0;
 $1522 = $1521 ^ $1518;
 $1523 = $1522 >>> 8;
 $$masked$i$i$i715$2 = $1522 & 255;
 $1524 = $$masked$i$i$i715$2 ^ 103;
 $1525 = (584048 + ($1524<<2)|0);
 $1526 = HEAP32[$1525>>2]|0;
 $1527 = $1526 ^ $1523;
 $1528 = $1527 >>> 8;
 $$masked$i$i$i715$3 = $1527 & 255;
 $1529 = $$masked$i$i$i715$3 ^ 104;
 $1530 = (584048 + ($1529<<2)|0);
 $1531 = HEAP32[$1530>>2]|0;
 $1532 = $1531 ^ $1528;
 $1533 = $1532 >>> 8;
 $$masked$i$i$i715$4 = $1532 & 255;
 $1534 = $$masked$i$i$i715$4 ^ 116;
 $1535 = (584048 + ($1534<<2)|0);
 $1536 = HEAP32[$1535>>2]|0;
 $1537 = $1536 ^ $1533;
 $1538 = $1537 >>> 8;
 $$masked$i$i$i715$5 = $1537 & 255;
 $1539 = $$masked$i$i$i715$5 ^ 70;
 $1540 = (584048 + ($1539<<2)|0);
 $1541 = HEAP32[$1540>>2]|0;
 $1542 = $1541 ^ $1538;
 $1543 = $1542 >>> 8;
 $$masked$i$i$i715$6 = $1542 & 255;
 $1544 = $$masked$i$i$i715$6 ^ 111;
 $1545 = (584048 + ($1544<<2)|0);
 $1546 = HEAP32[$1545>>2]|0;
 $1547 = $1546 ^ $1543;
 $1548 = $1547 >>> 8;
 $$masked$i$i$i715$7 = $1547 & 255;
 $1549 = $$masked$i$i$i715$7 ^ 111;
 $1550 = (584048 + ($1549<<2)|0);
 $1551 = HEAP32[$1550>>2]|0;
 $1552 = $1551 ^ $1548;
 $1553 = $1552 >>> 8;
 $$masked$i$i$i715$8 = $1552 & 255;
 $1554 = $$masked$i$i$i715$8 ^ 116;
 $1555 = (584048 + ($1554<<2)|0);
 $1556 = HEAP32[$1555>>2]|0;
 $1557 = $1556 ^ $1553;
 $1558 = $1557 >>> 8;
 $$masked$i$i$i715$9 = $1557 & 255;
 $1559 = $$masked$i$i$i715$9 ^ 88;
 $1560 = (584048 + ($1559<<2)|0);
 $1561 = HEAP32[$1560>>2]|0;
 $1562 = $1561 ^ $1558;
 $1563 = $1562 ^ -1;
 $1564 = ((794192 + 592|0));
 $1565 = $1564;
 HEAP32[$1565>>2] = $1563;
 $1566 = (($1564) + 4)|0;
 $1567 = $1566;
 HEAP32[$1567>>2] = (795912);
 $$02$i$i$i$i687 = -1;$i$03$i$i$i$i686 = 0;$reflection$01$i$i$i$i688 = 0;
 while(1) {
  $1568 = $$02$i$i$i$i687 & 1;
  $1569 = ($1568|0)==(0);
  if ($1569) {
   $reflection$1$i$i$i$i689 = $reflection$01$i$i$i$i688;
  } else {
   $1570 = (31 - ($i$03$i$i$i$i686))|0;
   $1571 = 1 << $1570;
   $1572 = $1571 | $reflection$01$i$i$i$i688;
   $reflection$1$i$i$i$i689 = $1572;
  }
  $1573 = (($i$03$i$i$i$i686) + 1)|0;
  $1574 = $$02$i$i$i$i687 >>> 1;
  $exitcond$i$i$i$i690 = ($1573|0)==(32);
  if ($exitcond$i$i$i$i690) {
   break;
  } else {
   $$02$i$i$i$i687 = $1574;$i$03$i$i$i$i686 = $1573;$reflection$01$i$i$i$i688 = $reflection$1$i$i$i$i689;
  }
 }
 $1575 = $reflection$1$i$i$i$i689 >>> 8;
 $$masked$i$i$i693 = $reflection$1$i$i$i$i689 & 255;
 $1576 = $$masked$i$i$i693 ^ 76;
 $1577 = (584048 + ($1576<<2)|0);
 $1578 = HEAP32[$1577>>2]|0;
 $1579 = $1578 ^ $1575;
 $1580 = $1579 >>> 8;
 $$masked$i$i$i693$1 = $1579 & 255;
 $1581 = $$masked$i$i$i693$1 ^ 101;
 $1582 = (584048 + ($1581<<2)|0);
 $1583 = HEAP32[$1582>>2]|0;
 $1584 = $1583 ^ $1580;
 $1585 = $1584 >>> 8;
 $$masked$i$i$i693$2 = $1584 & 255;
 $1586 = $$masked$i$i$i693$2 ^ 102;
 $1587 = (584048 + ($1586<<2)|0);
 $1588 = HEAP32[$1587>>2]|0;
 $1589 = $1588 ^ $1585;
 $1590 = $1589 >>> 8;
 $$masked$i$i$i693$3 = $1589 & 255;
 $1591 = $$masked$i$i$i693$3 ^ 116;
 $1592 = (584048 + ($1591<<2)|0);
 $1593 = HEAP32[$1592>>2]|0;
 $1594 = $1593 ^ $1590;
 $1595 = $1594 >>> 8;
 $$masked$i$i$i693$4 = $1594 & 255;
 $1596 = $$masked$i$i$i693$4 ^ 70;
 $1597 = (584048 + ($1596<<2)|0);
 $1598 = HEAP32[$1597>>2]|0;
 $1599 = $1598 ^ $1595;
 $1600 = $1599 >>> 8;
 $$masked$i$i$i693$5 = $1599 & 255;
 $1601 = $$masked$i$i$i693$5 ^ 111;
 $1602 = (584048 + ($1601<<2)|0);
 $1603 = HEAP32[$1602>>2]|0;
 $1604 = $1603 ^ $1600;
 $1605 = $1604 >>> 8;
 $$masked$i$i$i693$6 = $1604 & 255;
 $1606 = $$masked$i$i$i693$6 ^ 111;
 $1607 = (584048 + ($1606<<2)|0);
 $1608 = HEAP32[$1607>>2]|0;
 $1609 = $1608 ^ $1605;
 $1610 = $1609 >>> 8;
 $$masked$i$i$i693$7 = $1609 & 255;
 $1611 = $$masked$i$i$i693$7 ^ 116;
 $1612 = (584048 + ($1611<<2)|0);
 $1613 = HEAP32[$1612>>2]|0;
 $1614 = $1613 ^ $1610;
 $1615 = $1614 >>> 8;
 $$masked$i$i$i693$8 = $1614 & 255;
 $1616 = $$masked$i$i$i693$8 ^ 83;
 $1617 = (584048 + ($1616<<2)|0);
 $1618 = HEAP32[$1617>>2]|0;
 $1619 = $1618 ^ $1615;
 $1620 = $1619 >>> 8;
 $$masked$i$i$i693$9 = $1619 & 255;
 $1621 = $$masked$i$i$i693$9 ^ 112;
 $1622 = (584048 + ($1621<<2)|0);
 $1623 = HEAP32[$1622>>2]|0;
 $1624 = $1623 ^ $1620;
 $1625 = $1624 >>> 8;
 $$masked$i$i$i693$10 = $1624 & 255;
 $1626 = $$masked$i$i$i693$10 ^ 101;
 $1627 = (584048 + ($1626<<2)|0);
 $1628 = HEAP32[$1627>>2]|0;
 $1629 = $1628 ^ $1625;
 $1630 = $1629 >>> 8;
 $$masked$i$i$i693$11 = $1629 & 255;
 $1631 = $$masked$i$i$i693$11 ^ 101;
 $1632 = (584048 + ($1631<<2)|0);
 $1633 = HEAP32[$1632>>2]|0;
 $1634 = $1633 ^ $1630;
 $1635 = $1634 >>> 8;
 $$masked$i$i$i693$12 = $1634 & 255;
 $1636 = $$masked$i$i$i693$12 ^ 100;
 $1637 = (584048 + ($1636<<2)|0);
 $1638 = HEAP32[$1637>>2]|0;
 $1639 = $1638 ^ $1635;
 $1640 = $1639 >>> 8;
 $$masked$i$i$i693$13 = $1639 & 255;
 $1641 = $$masked$i$i$i693$13 ^ 84;
 $1642 = (584048 + ($1641<<2)|0);
 $1643 = HEAP32[$1642>>2]|0;
 $1644 = $1643 ^ $1640;
 $1645 = $1644 ^ -1;
 $1646 = ((794192 + 600|0));
 $1647 = $1646;
 HEAP32[$1647>>2] = $1645;
 $1648 = (($1646) + 4)|0;
 $1649 = $1648;
 HEAP32[$1649>>2] = (795928);
 $$02$i$i$i$i665 = -1;$i$03$i$i$i$i664 = 0;$reflection$01$i$i$i$i666 = 0;
 while(1) {
  $1650 = $$02$i$i$i$i665 & 1;
  $1651 = ($1650|0)==(0);
  if ($1651) {
   $reflection$1$i$i$i$i667 = $reflection$01$i$i$i$i666;
  } else {
   $1652 = (31 - ($i$03$i$i$i$i664))|0;
   $1653 = 1 << $1652;
   $1654 = $1653 | $reflection$01$i$i$i$i666;
   $reflection$1$i$i$i$i667 = $1654;
  }
  $1655 = (($i$03$i$i$i$i664) + 1)|0;
  $1656 = $$02$i$i$i$i665 >>> 1;
  $exitcond$i$i$i$i668 = ($1655|0)==(32);
  if ($exitcond$i$i$i$i668) {
   break;
  } else {
   $$02$i$i$i$i665 = $1656;$i$03$i$i$i$i664 = $1655;$reflection$01$i$i$i$i666 = $reflection$1$i$i$i$i667;
  }
 }
 $1657 = $reflection$1$i$i$i$i667 >>> 8;
 $$masked$i$i$i671 = $reflection$1$i$i$i$i667 & 255;
 $1658 = $$masked$i$i$i671 ^ 76;
 $1659 = (584048 + ($1658<<2)|0);
 $1660 = HEAP32[$1659>>2]|0;
 $1661 = $1660 ^ $1657;
 $1662 = $1661 >>> 8;
 $$masked$i$i$i671$1 = $1661 & 255;
 $1663 = $$masked$i$i$i671$1 ^ 101;
 $1664 = (584048 + ($1663<<2)|0);
 $1665 = HEAP32[$1664>>2]|0;
 $1666 = $1665 ^ $1662;
 $1667 = $1666 >>> 8;
 $$masked$i$i$i671$2 = $1666 & 255;
 $1668 = $$masked$i$i$i671$2 ^ 102;
 $1669 = (584048 + ($1668<<2)|0);
 $1670 = HEAP32[$1669>>2]|0;
 $1671 = $1670 ^ $1667;
 $1672 = $1671 >>> 8;
 $$masked$i$i$i671$3 = $1671 & 255;
 $1673 = $$masked$i$i$i671$3 ^ 116;
 $1674 = (584048 + ($1673<<2)|0);
 $1675 = HEAP32[$1674>>2]|0;
 $1676 = $1675 ^ $1672;
 $1677 = $1676 >>> 8;
 $$masked$i$i$i671$4 = $1676 & 255;
 $1678 = $$masked$i$i$i671$4 ^ 70;
 $1679 = (584048 + ($1678<<2)|0);
 $1680 = HEAP32[$1679>>2]|0;
 $1681 = $1680 ^ $1677;
 $1682 = $1681 >>> 8;
 $$masked$i$i$i671$5 = $1681 & 255;
 $1683 = $$masked$i$i$i671$5 ^ 111;
 $1684 = (584048 + ($1683<<2)|0);
 $1685 = HEAP32[$1684>>2]|0;
 $1686 = $1685 ^ $1682;
 $1687 = $1686 >>> 8;
 $$masked$i$i$i671$6 = $1686 & 255;
 $1688 = $$masked$i$i$i671$6 ^ 111;
 $1689 = (584048 + ($1688<<2)|0);
 $1690 = HEAP32[$1689>>2]|0;
 $1691 = $1690 ^ $1687;
 $1692 = $1691 >>> 8;
 $$masked$i$i$i671$7 = $1691 & 255;
 $1693 = $$masked$i$i$i671$7 ^ 116;
 $1694 = (584048 + ($1693<<2)|0);
 $1695 = HEAP32[$1694>>2]|0;
 $1696 = $1695 ^ $1692;
 $1697 = $1696 >>> 8;
 $$masked$i$i$i671$8 = $1696 & 255;
 $1698 = $$masked$i$i$i671$8 ^ 83;
 $1699 = (584048 + ($1698<<2)|0);
 $1700 = HEAP32[$1699>>2]|0;
 $1701 = $1700 ^ $1697;
 $1702 = $1701 >>> 8;
 $$masked$i$i$i671$9 = $1701 & 255;
 $1703 = $$masked$i$i$i671$9 ^ 112;
 $1704 = (584048 + ($1703<<2)|0);
 $1705 = HEAP32[$1704>>2]|0;
 $1706 = $1705 ^ $1702;
 $1707 = $1706 >>> 8;
 $$masked$i$i$i671$10 = $1706 & 255;
 $1708 = $$masked$i$i$i671$10 ^ 101;
 $1709 = (584048 + ($1708<<2)|0);
 $1710 = HEAP32[$1709>>2]|0;
 $1711 = $1710 ^ $1707;
 $1712 = $1711 >>> 8;
 $$masked$i$i$i671$11 = $1711 & 255;
 $1713 = $$masked$i$i$i671$11 ^ 101;
 $1714 = (584048 + ($1713<<2)|0);
 $1715 = HEAP32[$1714>>2]|0;
 $1716 = $1715 ^ $1712;
 $1717 = $1716 >>> 8;
 $$masked$i$i$i671$12 = $1716 & 255;
 $1718 = $$masked$i$i$i671$12 ^ 100;
 $1719 = (584048 + ($1718<<2)|0);
 $1720 = HEAP32[$1719>>2]|0;
 $1721 = $1720 ^ $1717;
 $1722 = $1721 >>> 8;
 $$masked$i$i$i671$13 = $1721 & 255;
 $1723 = $$masked$i$i$i671$13 ^ 81;
 $1724 = (584048 + ($1723<<2)|0);
 $1725 = HEAP32[$1724>>2]|0;
 $1726 = $1725 ^ $1722;
 $1727 = $1726 ^ -1;
 $1728 = ((794192 + 608|0));
 $1729 = $1728;
 HEAP32[$1729>>2] = $1727;
 $1730 = (($1728) + 4)|0;
 $1731 = $1730;
 HEAP32[$1731>>2] = (795944);
 $$02$i$i$i$i643 = -1;$i$03$i$i$i$i642 = 0;$reflection$01$i$i$i$i644 = 0;
 while(1) {
  $1732 = $$02$i$i$i$i643 & 1;
  $1733 = ($1732|0)==(0);
  if ($1733) {
   $reflection$1$i$i$i$i645 = $reflection$01$i$i$i$i644;
  } else {
   $1734 = (31 - ($i$03$i$i$i$i642))|0;
   $1735 = 1 << $1734;
   $1736 = $1735 | $reflection$01$i$i$i$i644;
   $reflection$1$i$i$i$i645 = $1736;
  }
  $1737 = (($i$03$i$i$i$i642) + 1)|0;
  $1738 = $$02$i$i$i$i643 >>> 1;
  $exitcond$i$i$i$i646 = ($1737|0)==(32);
  if ($exitcond$i$i$i$i646) {
   break;
  } else {
   $$02$i$i$i$i643 = $1738;$i$03$i$i$i$i642 = $1737;$reflection$01$i$i$i$i644 = $reflection$1$i$i$i$i645;
  }
 }
 $1739 = $reflection$1$i$i$i$i645 >>> 8;
 $$masked$i$i$i649 = $reflection$1$i$i$i$i645 & 255;
 $1740 = $$masked$i$i$i649 ^ 82;
 $1741 = (584048 + ($1740<<2)|0);
 $1742 = HEAP32[$1741>>2]|0;
 $1743 = $1742 ^ $1739;
 $1744 = $1743 >>> 8;
 $$masked$i$i$i649$1 = $1743 & 255;
 $1745 = $$masked$i$i$i649$1 ^ 105;
 $1746 = (584048 + ($1745<<2)|0);
 $1747 = HEAP32[$1746>>2]|0;
 $1748 = $1747 ^ $1744;
 $1749 = $1748 >>> 8;
 $$masked$i$i$i649$2 = $1748 & 255;
 $1750 = $$masked$i$i$i649$2 ^ 103;
 $1751 = (584048 + ($1750<<2)|0);
 $1752 = HEAP32[$1751>>2]|0;
 $1753 = $1752 ^ $1749;
 $1754 = $1753 >>> 8;
 $$masked$i$i$i649$3 = $1753 & 255;
 $1755 = $$masked$i$i$i649$3 ^ 104;
 $1756 = (584048 + ($1755<<2)|0);
 $1757 = HEAP32[$1756>>2]|0;
 $1758 = $1757 ^ $1754;
 $1759 = $1758 >>> 8;
 $$masked$i$i$i649$4 = $1758 & 255;
 $1760 = $$masked$i$i$i649$4 ^ 116;
 $1761 = (584048 + ($1760<<2)|0);
 $1762 = HEAP32[$1761>>2]|0;
 $1763 = $1762 ^ $1759;
 $1764 = $1763 >>> 8;
 $$masked$i$i$i649$5 = $1763 & 255;
 $1765 = $$masked$i$i$i649$5 ^ 70;
 $1766 = (584048 + ($1765<<2)|0);
 $1767 = HEAP32[$1766>>2]|0;
 $1768 = $1767 ^ $1764;
 $1769 = $1768 >>> 8;
 $$masked$i$i$i649$6 = $1768 & 255;
 $1770 = $$masked$i$i$i649$6 ^ 111;
 $1771 = (584048 + ($1770<<2)|0);
 $1772 = HEAP32[$1771>>2]|0;
 $1773 = $1772 ^ $1769;
 $1774 = $1773 >>> 8;
 $$masked$i$i$i649$7 = $1773 & 255;
 $1775 = $$masked$i$i$i649$7 ^ 111;
 $1776 = (584048 + ($1775<<2)|0);
 $1777 = HEAP32[$1776>>2]|0;
 $1778 = $1777 ^ $1774;
 $1779 = $1778 >>> 8;
 $$masked$i$i$i649$8 = $1778 & 255;
 $1780 = $$masked$i$i$i649$8 ^ 116;
 $1781 = (584048 + ($1780<<2)|0);
 $1782 = HEAP32[$1781>>2]|0;
 $1783 = $1782 ^ $1779;
 $1784 = $1783 >>> 8;
 $$masked$i$i$i649$9 = $1783 & 255;
 $1785 = $$masked$i$i$i649$9 ^ 83;
 $1786 = (584048 + ($1785<<2)|0);
 $1787 = HEAP32[$1786>>2]|0;
 $1788 = $1787 ^ $1784;
 $1789 = $1788 >>> 8;
 $$masked$i$i$i649$10 = $1788 & 255;
 $1790 = $$masked$i$i$i649$10 ^ 112;
 $1791 = (584048 + ($1790<<2)|0);
 $1792 = HEAP32[$1791>>2]|0;
 $1793 = $1792 ^ $1789;
 $1794 = $1793 >>> 8;
 $$masked$i$i$i649$11 = $1793 & 255;
 $1795 = $$masked$i$i$i649$11 ^ 101;
 $1796 = (584048 + ($1795<<2)|0);
 $1797 = HEAP32[$1796>>2]|0;
 $1798 = $1797 ^ $1794;
 $1799 = $1798 >>> 8;
 $$masked$i$i$i649$12 = $1798 & 255;
 $1800 = $$masked$i$i$i649$12 ^ 101;
 $1801 = (584048 + ($1800<<2)|0);
 $1802 = HEAP32[$1801>>2]|0;
 $1803 = $1802 ^ $1799;
 $1804 = $1803 >>> 8;
 $$masked$i$i$i649$13 = $1803 & 255;
 $1805 = $$masked$i$i$i649$13 ^ 100;
 $1806 = (584048 + ($1805<<2)|0);
 $1807 = HEAP32[$1806>>2]|0;
 $1808 = $1807 ^ $1804;
 $1809 = $1808 >>> 8;
 $$masked$i$i$i649$14 = $1808 & 255;
 $1810 = $$masked$i$i$i649$14 ^ 84;
 $1811 = (584048 + ($1810<<2)|0);
 $1812 = HEAP32[$1811>>2]|0;
 $1813 = $1812 ^ $1809;
 $1814 = $1813 ^ -1;
 $1815 = ((794192 + 616|0));
 $1816 = $1815;
 HEAP32[$1816>>2] = $1814;
 $1817 = (($1815) + 4)|0;
 $1818 = $1817;
 HEAP32[$1818>>2] = (795960);
 $$02$i$i$i$i621 = -1;$i$03$i$i$i$i620 = 0;$reflection$01$i$i$i$i622 = 0;
 while(1) {
  $1819 = $$02$i$i$i$i621 & 1;
  $1820 = ($1819|0)==(0);
  if ($1820) {
   $reflection$1$i$i$i$i623 = $reflection$01$i$i$i$i622;
  } else {
   $1821 = (31 - ($i$03$i$i$i$i620))|0;
   $1822 = 1 << $1821;
   $1823 = $1822 | $reflection$01$i$i$i$i622;
   $reflection$1$i$i$i$i623 = $1823;
  }
  $1824 = (($i$03$i$i$i$i620) + 1)|0;
  $1825 = $$02$i$i$i$i621 >>> 1;
  $exitcond$i$i$i$i624 = ($1824|0)==(32);
  if ($exitcond$i$i$i$i624) {
   break;
  } else {
   $$02$i$i$i$i621 = $1825;$i$03$i$i$i$i620 = $1824;$reflection$01$i$i$i$i622 = $reflection$1$i$i$i$i623;
  }
 }
 $1826 = $reflection$1$i$i$i$i623 >>> 8;
 $$masked$i$i$i627 = $reflection$1$i$i$i$i623 & 255;
 $1827 = $$masked$i$i$i627 ^ 82;
 $1828 = (584048 + ($1827<<2)|0);
 $1829 = HEAP32[$1828>>2]|0;
 $1830 = $1829 ^ $1826;
 $1831 = $1830 >>> 8;
 $$masked$i$i$i627$1 = $1830 & 255;
 $1832 = $$masked$i$i$i627$1 ^ 105;
 $1833 = (584048 + ($1832<<2)|0);
 $1834 = HEAP32[$1833>>2]|0;
 $1835 = $1834 ^ $1831;
 $1836 = $1835 >>> 8;
 $$masked$i$i$i627$2 = $1835 & 255;
 $1837 = $$masked$i$i$i627$2 ^ 103;
 $1838 = (584048 + ($1837<<2)|0);
 $1839 = HEAP32[$1838>>2]|0;
 $1840 = $1839 ^ $1836;
 $1841 = $1840 >>> 8;
 $$masked$i$i$i627$3 = $1840 & 255;
 $1842 = $$masked$i$i$i627$3 ^ 104;
 $1843 = (584048 + ($1842<<2)|0);
 $1844 = HEAP32[$1843>>2]|0;
 $1845 = $1844 ^ $1841;
 $1846 = $1845 >>> 8;
 $$masked$i$i$i627$4 = $1845 & 255;
 $1847 = $$masked$i$i$i627$4 ^ 116;
 $1848 = (584048 + ($1847<<2)|0);
 $1849 = HEAP32[$1848>>2]|0;
 $1850 = $1849 ^ $1846;
 $1851 = $1850 >>> 8;
 $$masked$i$i$i627$5 = $1850 & 255;
 $1852 = $$masked$i$i$i627$5 ^ 70;
 $1853 = (584048 + ($1852<<2)|0);
 $1854 = HEAP32[$1853>>2]|0;
 $1855 = $1854 ^ $1851;
 $1856 = $1855 >>> 8;
 $$masked$i$i$i627$6 = $1855 & 255;
 $1857 = $$masked$i$i$i627$6 ^ 111;
 $1858 = (584048 + ($1857<<2)|0);
 $1859 = HEAP32[$1858>>2]|0;
 $1860 = $1859 ^ $1856;
 $1861 = $1860 >>> 8;
 $$masked$i$i$i627$7 = $1860 & 255;
 $1862 = $$masked$i$i$i627$7 ^ 111;
 $1863 = (584048 + ($1862<<2)|0);
 $1864 = HEAP32[$1863>>2]|0;
 $1865 = $1864 ^ $1861;
 $1866 = $1865 >>> 8;
 $$masked$i$i$i627$8 = $1865 & 255;
 $1867 = $$masked$i$i$i627$8 ^ 116;
 $1868 = (584048 + ($1867<<2)|0);
 $1869 = HEAP32[$1868>>2]|0;
 $1870 = $1869 ^ $1866;
 $1871 = $1870 >>> 8;
 $$masked$i$i$i627$9 = $1870 & 255;
 $1872 = $$masked$i$i$i627$9 ^ 83;
 $1873 = (584048 + ($1872<<2)|0);
 $1874 = HEAP32[$1873>>2]|0;
 $1875 = $1874 ^ $1871;
 $1876 = $1875 >>> 8;
 $$masked$i$i$i627$10 = $1875 & 255;
 $1877 = $$masked$i$i$i627$10 ^ 112;
 $1878 = (584048 + ($1877<<2)|0);
 $1879 = HEAP32[$1878>>2]|0;
 $1880 = $1879 ^ $1876;
 $1881 = $1880 >>> 8;
 $$masked$i$i$i627$11 = $1880 & 255;
 $1882 = $$masked$i$i$i627$11 ^ 101;
 $1883 = (584048 + ($1882<<2)|0);
 $1884 = HEAP32[$1883>>2]|0;
 $1885 = $1884 ^ $1881;
 $1886 = $1885 >>> 8;
 $$masked$i$i$i627$12 = $1885 & 255;
 $1887 = $$masked$i$i$i627$12 ^ 101;
 $1888 = (584048 + ($1887<<2)|0);
 $1889 = HEAP32[$1888>>2]|0;
 $1890 = $1889 ^ $1886;
 $1891 = $1890 >>> 8;
 $$masked$i$i$i627$13 = $1890 & 255;
 $1892 = $$masked$i$i$i627$13 ^ 100;
 $1893 = (584048 + ($1892<<2)|0);
 $1894 = HEAP32[$1893>>2]|0;
 $1895 = $1894 ^ $1891;
 $1896 = $1895 >>> 8;
 $$masked$i$i$i627$14 = $1895 & 255;
 $1897 = $$masked$i$i$i627$14 ^ 81;
 $1898 = (584048 + ($1897<<2)|0);
 $1899 = HEAP32[$1898>>2]|0;
 $1900 = $1899 ^ $1896;
 $1901 = $1900 ^ -1;
 $1902 = ((794192 + 624|0));
 $1903 = $1902;
 HEAP32[$1903>>2] = $1901;
 $1904 = (($1902) + 4)|0;
 $1905 = $1904;
 HEAP32[$1905>>2] = (795976);
 $$02$i$i$i$i599 = -1;$i$03$i$i$i$i598 = 0;$reflection$01$i$i$i$i600 = 0;
 while(1) {
  $1906 = $$02$i$i$i$i599 & 1;
  $1907 = ($1906|0)==(0);
  if ($1907) {
   $reflection$1$i$i$i$i601 = $reflection$01$i$i$i$i600;
  } else {
   $1908 = (31 - ($i$03$i$i$i$i598))|0;
   $1909 = 1 << $1908;
   $1910 = $1909 | $reflection$01$i$i$i$i600;
   $reflection$1$i$i$i$i601 = $1910;
  }
  $1911 = (($i$03$i$i$i$i598) + 1)|0;
  $1912 = $$02$i$i$i$i599 >>> 1;
  $exitcond$i$i$i$i602 = ($1911|0)==(32);
  if ($exitcond$i$i$i$i602) {
   break;
  } else {
   $$02$i$i$i$i599 = $1912;$i$03$i$i$i$i598 = $1911;$reflection$01$i$i$i$i600 = $reflection$1$i$i$i$i601;
  }
 }
 $1913 = $reflection$1$i$i$i$i601 >>> 8;
 $$masked$i$i$i605 = $reflection$1$i$i$i$i601 & 255;
 $1914 = $$masked$i$i$i605 ^ 76;
 $1915 = (584048 + ($1914<<2)|0);
 $1916 = HEAP32[$1915>>2]|0;
 $1917 = $1916 ^ $1913;
 $1918 = $1917 >>> 8;
 $$masked$i$i$i605$1 = $1917 & 255;
 $1919 = $$masked$i$i$i605$1 ^ 101;
 $1920 = (584048 + ($1919<<2)|0);
 $1921 = HEAP32[$1920>>2]|0;
 $1922 = $1921 ^ $1918;
 $1923 = $1922 >>> 8;
 $$masked$i$i$i605$2 = $1922 & 255;
 $1924 = $$masked$i$i$i605$2 ^ 102;
 $1925 = (584048 + ($1924<<2)|0);
 $1926 = HEAP32[$1925>>2]|0;
 $1927 = $1926 ^ $1923;
 $1928 = $1927 >>> 8;
 $$masked$i$i$i605$3 = $1927 & 255;
 $1929 = $$masked$i$i$i605$3 ^ 116;
 $1930 = (584048 + ($1929<<2)|0);
 $1931 = HEAP32[$1930>>2]|0;
 $1932 = $1931 ^ $1928;
 $1933 = $1932 >>> 8;
 $$masked$i$i$i605$4 = $1932 & 255;
 $1934 = $$masked$i$i$i605$4 ^ 70;
 $1935 = (584048 + ($1934<<2)|0);
 $1936 = HEAP32[$1935>>2]|0;
 $1937 = $1936 ^ $1933;
 $1938 = $1937 >>> 8;
 $$masked$i$i$i605$5 = $1937 & 255;
 $1939 = $$masked$i$i$i605$5 ^ 111;
 $1940 = (584048 + ($1939<<2)|0);
 $1941 = HEAP32[$1940>>2]|0;
 $1942 = $1941 ^ $1938;
 $1943 = $1942 >>> 8;
 $$masked$i$i$i605$6 = $1942 & 255;
 $1944 = $$masked$i$i$i605$6 ^ 111;
 $1945 = (584048 + ($1944<<2)|0);
 $1946 = HEAP32[$1945>>2]|0;
 $1947 = $1946 ^ $1943;
 $1948 = $1947 >>> 8;
 $$masked$i$i$i605$7 = $1947 & 255;
 $1949 = $$masked$i$i$i605$7 ^ 116;
 $1950 = (584048 + ($1949<<2)|0);
 $1951 = HEAP32[$1950>>2]|0;
 $1952 = $1951 ^ $1948;
 $1953 = $1952 >>> 8;
 $$masked$i$i$i605$8 = $1952 & 255;
 $1954 = $$masked$i$i$i605$8 ^ 83;
 $1955 = (584048 + ($1954<<2)|0);
 $1956 = HEAP32[$1955>>2]|0;
 $1957 = $1956 ^ $1953;
 $1958 = $1957 >>> 8;
 $$masked$i$i$i605$9 = $1957 & 255;
 $1959 = $$masked$i$i$i605$9 ^ 116;
 $1960 = (584048 + ($1959<<2)|0);
 $1961 = HEAP32[$1960>>2]|0;
 $1962 = $1961 ^ $1958;
 $1963 = $1962 >>> 8;
 $$masked$i$i$i605$10 = $1962 & 255;
 $1964 = $$masked$i$i$i605$10 ^ 97;
 $1965 = (584048 + ($1964<<2)|0);
 $1966 = HEAP32[$1965>>2]|0;
 $1967 = $1966 ^ $1963;
 $1968 = $1967 >>> 8;
 $$masked$i$i$i605$11 = $1967 & 255;
 $1969 = $$masked$i$i$i605$11 ^ 98;
 $1970 = (584048 + ($1969<<2)|0);
 $1971 = HEAP32[$1970>>2]|0;
 $1972 = $1971 ^ $1968;
 $1973 = $1972 >>> 8;
 $$masked$i$i$i605$12 = $1972 & 255;
 $1974 = $$masked$i$i$i605$12 ^ 108;
 $1975 = (584048 + ($1974<<2)|0);
 $1976 = HEAP32[$1975>>2]|0;
 $1977 = $1976 ^ $1973;
 $1978 = $1977 >>> 8;
 $$masked$i$i$i605$13 = $1977 & 255;
 $1979 = $$masked$i$i$i605$13 ^ 101;
 $1980 = (584048 + ($1979<<2)|0);
 $1981 = HEAP32[$1980>>2]|0;
 $1982 = $1981 ^ $1978;
 $1983 = $1982 >>> 8;
 $$masked$i$i$i605$14 = $1982 & 255;
 $1984 = $$masked$i$i$i605$14 ^ 84;
 $1985 = (584048 + ($1984<<2)|0);
 $1986 = HEAP32[$1985>>2]|0;
 $1987 = $1986 ^ $1983;
 $1988 = $1987 ^ -1;
 $1989 = ((794192 + 632|0));
 $1990 = $1989;
 HEAP32[$1990>>2] = $1988;
 $1991 = (($1989) + 4)|0;
 $1992 = $1991;
 HEAP32[$1992>>2] = (795992);
 $$02$i$i$i$i577 = -1;$i$03$i$i$i$i576 = 0;$reflection$01$i$i$i$i578 = 0;
 while(1) {
  $1993 = $$02$i$i$i$i577 & 1;
  $1994 = ($1993|0)==(0);
  if ($1994) {
   $reflection$1$i$i$i$i579 = $reflection$01$i$i$i$i578;
  } else {
   $1995 = (31 - ($i$03$i$i$i$i576))|0;
   $1996 = 1 << $1995;
   $1997 = $1996 | $reflection$01$i$i$i$i578;
   $reflection$1$i$i$i$i579 = $1997;
  }
  $1998 = (($i$03$i$i$i$i576) + 1)|0;
  $1999 = $$02$i$i$i$i577 >>> 1;
  $exitcond$i$i$i$i580 = ($1998|0)==(32);
  if ($exitcond$i$i$i$i580) {
   break;
  } else {
   $$02$i$i$i$i577 = $1999;$i$03$i$i$i$i576 = $1998;$reflection$01$i$i$i$i578 = $reflection$1$i$i$i$i579;
  }
 }
 $2000 = $reflection$1$i$i$i$i579 >>> 8;
 $$masked$i$i$i583 = $reflection$1$i$i$i$i579 & 255;
 $2001 = $$masked$i$i$i583 ^ 76;
 $2002 = (584048 + ($2001<<2)|0);
 $2003 = HEAP32[$2002>>2]|0;
 $2004 = $2003 ^ $2000;
 $2005 = $2004 >>> 8;
 $$masked$i$i$i583$1 = $2004 & 255;
 $2006 = $$masked$i$i$i583$1 ^ 101;
 $2007 = (584048 + ($2006<<2)|0);
 $2008 = HEAP32[$2007>>2]|0;
 $2009 = $2008 ^ $2005;
 $2010 = $2009 >>> 8;
 $$masked$i$i$i583$2 = $2009 & 255;
 $2011 = $$masked$i$i$i583$2 ^ 102;
 $2012 = (584048 + ($2011<<2)|0);
 $2013 = HEAP32[$2012>>2]|0;
 $2014 = $2013 ^ $2010;
 $2015 = $2014 >>> 8;
 $$masked$i$i$i583$3 = $2014 & 255;
 $2016 = $$masked$i$i$i583$3 ^ 116;
 $2017 = (584048 + ($2016<<2)|0);
 $2018 = HEAP32[$2017>>2]|0;
 $2019 = $2018 ^ $2015;
 $2020 = $2019 >>> 8;
 $$masked$i$i$i583$4 = $2019 & 255;
 $2021 = $$masked$i$i$i583$4 ^ 70;
 $2022 = (584048 + ($2021<<2)|0);
 $2023 = HEAP32[$2022>>2]|0;
 $2024 = $2023 ^ $2020;
 $2025 = $2024 >>> 8;
 $$masked$i$i$i583$5 = $2024 & 255;
 $2026 = $$masked$i$i$i583$5 ^ 111;
 $2027 = (584048 + ($2026<<2)|0);
 $2028 = HEAP32[$2027>>2]|0;
 $2029 = $2028 ^ $2025;
 $2030 = $2029 >>> 8;
 $$masked$i$i$i583$6 = $2029 & 255;
 $2031 = $$masked$i$i$i583$6 ^ 111;
 $2032 = (584048 + ($2031<<2)|0);
 $2033 = HEAP32[$2032>>2]|0;
 $2034 = $2033 ^ $2030;
 $2035 = $2034 >>> 8;
 $$masked$i$i$i583$7 = $2034 & 255;
 $2036 = $$masked$i$i$i583$7 ^ 116;
 $2037 = (584048 + ($2036<<2)|0);
 $2038 = HEAP32[$2037>>2]|0;
 $2039 = $2038 ^ $2035;
 $2040 = $2039 >>> 8;
 $$masked$i$i$i583$8 = $2039 & 255;
 $2041 = $$masked$i$i$i583$8 ^ 83;
 $2042 = (584048 + ($2041<<2)|0);
 $2043 = HEAP32[$2042>>2]|0;
 $2044 = $2043 ^ $2040;
 $2045 = $2044 >>> 8;
 $$masked$i$i$i583$9 = $2044 & 255;
 $2046 = $$masked$i$i$i583$9 ^ 116;
 $2047 = (584048 + ($2046<<2)|0);
 $2048 = HEAP32[$2047>>2]|0;
 $2049 = $2048 ^ $2045;
 $2050 = $2049 >>> 8;
 $$masked$i$i$i583$10 = $2049 & 255;
 $2051 = $$masked$i$i$i583$10 ^ 97;
 $2052 = (584048 + ($2051<<2)|0);
 $2053 = HEAP32[$2052>>2]|0;
 $2054 = $2053 ^ $2050;
 $2055 = $2054 >>> 8;
 $$masked$i$i$i583$11 = $2054 & 255;
 $2056 = $$masked$i$i$i583$11 ^ 98;
 $2057 = (584048 + ($2056<<2)|0);
 $2058 = HEAP32[$2057>>2]|0;
 $2059 = $2058 ^ $2055;
 $2060 = $2059 >>> 8;
 $$masked$i$i$i583$12 = $2059 & 255;
 $2061 = $$masked$i$i$i583$12 ^ 108;
 $2062 = (584048 + ($2061<<2)|0);
 $2063 = HEAP32[$2062>>2]|0;
 $2064 = $2063 ^ $2060;
 $2065 = $2064 >>> 8;
 $$masked$i$i$i583$13 = $2064 & 255;
 $2066 = $$masked$i$i$i583$13 ^ 101;
 $2067 = (584048 + ($2066<<2)|0);
 $2068 = HEAP32[$2067>>2]|0;
 $2069 = $2068 ^ $2065;
 $2070 = $2069 >>> 8;
 $$masked$i$i$i583$14 = $2069 & 255;
 $2071 = $$masked$i$i$i583$14 ^ 81;
 $2072 = (584048 + ($2071<<2)|0);
 $2073 = HEAP32[$2072>>2]|0;
 $2074 = $2073 ^ $2070;
 $2075 = $2074 ^ -1;
 $2076 = ((794192 + 640|0));
 $2077 = $2076;
 HEAP32[$2077>>2] = $2075;
 $2078 = (($2076) + 4)|0;
 $2079 = $2078;
 HEAP32[$2079>>2] = (796008);
 $$02$i$i$i$i555 = -1;$i$03$i$i$i$i554 = 0;$reflection$01$i$i$i$i556 = 0;
 while(1) {
  $2080 = $$02$i$i$i$i555 & 1;
  $2081 = ($2080|0)==(0);
  if ($2081) {
   $reflection$1$i$i$i$i557 = $reflection$01$i$i$i$i556;
  } else {
   $2082 = (31 - ($i$03$i$i$i$i554))|0;
   $2083 = 1 << $2082;
   $2084 = $2083 | $reflection$01$i$i$i$i556;
   $reflection$1$i$i$i$i557 = $2084;
  }
  $2085 = (($i$03$i$i$i$i554) + 1)|0;
  $2086 = $$02$i$i$i$i555 >>> 1;
  $exitcond$i$i$i$i558 = ($2085|0)==(32);
  if ($exitcond$i$i$i$i558) {
   $2090 = $reflection$1$i$i$i$i557;$p$01$i$i$i560 = 796024;
   break;
  } else {
   $$02$i$i$i$i555 = $2086;$i$03$i$i$i$i554 = $2085;$reflection$01$i$i$i$i556 = $reflection$1$i$i$i$i557;
  }
 }
 while(1) {
  $2087 = HEAP8[$p$01$i$i$i560>>0]|0;
  $2088 = $2087&255;
  $2089 = $2090 >>> 8;
  $$masked$i$i$i561 = $2090 & 255;
  $2091 = $2088 ^ $$masked$i$i$i561;
  $2092 = (584048 + ($2091<<2)|0);
  $2093 = HEAP32[$2092>>2]|0;
  $2094 = $2093 ^ $2089;
  $2095 = (($p$01$i$i$i560) + 1|0);
  $exitcond$i$i$i562 = ($2095|0)==(((796024 + 16|0))|0);
  if ($exitcond$i$i$i562) {
   break;
  } else {
   $2090 = $2094;$p$01$i$i$i560 = $2095;
  }
 }
 $2096 = $2094 ^ -1;
 $2097 = ((794192 + 648|0));
 $2098 = $2097;
 HEAP32[$2098>>2] = $2096;
 $2099 = (($2097) + 4)|0;
 $2100 = $2099;
 HEAP32[$2100>>2] = (796024);
 $$02$i$i$i$i533 = -1;$i$03$i$i$i$i532 = 0;$reflection$01$i$i$i$i534 = 0;
 while(1) {
  $2101 = $$02$i$i$i$i533 & 1;
  $2102 = ($2101|0)==(0);
  if ($2102) {
   $reflection$1$i$i$i$i535 = $reflection$01$i$i$i$i534;
  } else {
   $2103 = (31 - ($i$03$i$i$i$i532))|0;
   $2104 = 1 << $2103;
   $2105 = $2104 | $reflection$01$i$i$i$i534;
   $reflection$1$i$i$i$i535 = $2105;
  }
  $2106 = (($i$03$i$i$i$i532) + 1)|0;
  $2107 = $$02$i$i$i$i533 >>> 1;
  $exitcond$i$i$i$i536 = ($2106|0)==(32);
  if ($exitcond$i$i$i$i536) {
   $2111 = $reflection$1$i$i$i$i535;$p$01$i$i$i538 = 796048;
   break;
  } else {
   $$02$i$i$i$i533 = $2107;$i$03$i$i$i$i532 = $2106;$reflection$01$i$i$i$i534 = $reflection$1$i$i$i$i535;
  }
 }
 while(1) {
  $2108 = HEAP8[$p$01$i$i$i538>>0]|0;
  $2109 = $2108&255;
  $2110 = $2111 >>> 8;
  $$masked$i$i$i539 = $2111 & 255;
  $2112 = $2109 ^ $$masked$i$i$i539;
  $2113 = (584048 + ($2112<<2)|0);
  $2114 = HEAP32[$2113>>2]|0;
  $2115 = $2114 ^ $2110;
  $2116 = (($p$01$i$i$i538) + 1|0);
  $exitcond$i$i$i540 = ($2116|0)==(((796048 + 16|0))|0);
  if ($exitcond$i$i$i540) {
   break;
  } else {
   $2111 = $2115;$p$01$i$i$i538 = $2116;
  }
 }
 $2117 = $2115 ^ -1;
 $2118 = ((794192 + 656|0));
 $2119 = $2118;
 HEAP32[$2119>>2] = $2117;
 $2120 = (($2118) + 4)|0;
 $2121 = $2120;
 HEAP32[$2121>>2] = (796048);
 $$02$i$i$i$i511 = -1;$i$03$i$i$i$i510 = 0;$reflection$01$i$i$i$i512 = 0;
 while(1) {
  $2122 = $$02$i$i$i$i511 & 1;
  $2123 = ($2122|0)==(0);
  if ($2123) {
   $reflection$1$i$i$i$i513 = $reflection$01$i$i$i$i512;
  } else {
   $2124 = (31 - ($i$03$i$i$i$i510))|0;
   $2125 = 1 << $2124;
   $2126 = $2125 | $reflection$01$i$i$i$i512;
   $reflection$1$i$i$i$i513 = $2126;
  }
  $2127 = (($i$03$i$i$i$i510) + 1)|0;
  $2128 = $$02$i$i$i$i511 >>> 1;
  $exitcond$i$i$i$i514 = ($2127|0)==(32);
  if ($exitcond$i$i$i$i514) {
   break;
  } else {
   $$02$i$i$i$i511 = $2128;$i$03$i$i$i$i510 = $2127;$reflection$01$i$i$i$i512 = $reflection$1$i$i$i$i513;
  }
 }
 $2129 = $reflection$1$i$i$i$i513 >>> 8;
 $$masked$i$i$i517 = $reflection$1$i$i$i$i513 & 255;
 $2130 = $$masked$i$i$i517 ^ 82;
 $2131 = (584048 + ($2130<<2)|0);
 $2132 = HEAP32[$2131>>2]|0;
 $2133 = $2132 ^ $2129;
 $2134 = $2133 >>> 8;
 $$masked$i$i$i517$1 = $2133 & 255;
 $2135 = $$masked$i$i$i517$1 ^ 111;
 $2136 = (584048 + ($2135<<2)|0);
 $2137 = HEAP32[$2136>>2]|0;
 $2138 = $2137 ^ $2134;
 $2139 = $2138 >>> 8;
 $$masked$i$i$i517$2 = $2138 & 255;
 $2140 = $$masked$i$i$i517$2 ^ 111;
 $2141 = (584048 + ($2140<<2)|0);
 $2142 = HEAP32[$2141>>2]|0;
 $2143 = $2142 ^ $2139;
 $2144 = $2143 >>> 8;
 $$masked$i$i$i517$3 = $2143 & 255;
 $2145 = $$masked$i$i$i517$3 ^ 116;
 $2146 = (584048 + ($2145<<2)|0);
 $2147 = HEAP32[$2146>>2]|0;
 $2148 = $2147 ^ $2144;
 $2149 = $2148 >>> 8;
 $$masked$i$i$i517$4 = $2148 & 255;
 $2150 = $$masked$i$i$i517$4 ^ 83;
 $2151 = (584048 + ($2150<<2)|0);
 $2152 = HEAP32[$2151>>2]|0;
 $2153 = $2152 ^ $2149;
 $2154 = $2153 >>> 8;
 $$masked$i$i$i517$5 = $2153 & 255;
 $2155 = $$masked$i$i$i517$5 ^ 112;
 $2156 = (584048 + ($2155<<2)|0);
 $2157 = HEAP32[$2156>>2]|0;
 $2158 = $2157 ^ $2154;
 $2159 = $2158 >>> 8;
 $$masked$i$i$i517$6 = $2158 & 255;
 $2160 = $$masked$i$i$i517$6 ^ 101;
 $2161 = (584048 + ($2160<<2)|0);
 $2162 = HEAP32[$2161>>2]|0;
 $2163 = $2162 ^ $2159;
 $2164 = $2163 >>> 8;
 $$masked$i$i$i517$7 = $2163 & 255;
 $2165 = $$masked$i$i$i517$7 ^ 101;
 $2166 = (584048 + ($2165<<2)|0);
 $2167 = HEAP32[$2166>>2]|0;
 $2168 = $2167 ^ $2164;
 $2169 = $2168 >>> 8;
 $$masked$i$i$i517$8 = $2168 & 255;
 $2170 = $$masked$i$i$i517$8 ^ 100;
 $2171 = (584048 + ($2170<<2)|0);
 $2172 = HEAP32[$2171>>2]|0;
 $2173 = $2172 ^ $2169;
 $2174 = $2173 >>> 8;
 $$masked$i$i$i517$9 = $2173 & 255;
 $2175 = $$masked$i$i$i517$9 ^ 84;
 $2176 = (584048 + ($2175<<2)|0);
 $2177 = HEAP32[$2176>>2]|0;
 $2178 = $2177 ^ $2174;
 $2179 = $2178 ^ -1;
 $2180 = ((794192 + 664|0));
 $2181 = $2180;
 HEAP32[$2181>>2] = $2179;
 $2182 = (($2180) + 4)|0;
 $2183 = $2182;
 HEAP32[$2183>>2] = (796072);
 $$02$i$i$i$i489 = -1;$i$03$i$i$i$i488 = 0;$reflection$01$i$i$i$i490 = 0;
 while(1) {
  $2184 = $$02$i$i$i$i489 & 1;
  $2185 = ($2184|0)==(0);
  if ($2185) {
   $reflection$1$i$i$i$i491 = $reflection$01$i$i$i$i490;
  } else {
   $2186 = (31 - ($i$03$i$i$i$i488))|0;
   $2187 = 1 << $2186;
   $2188 = $2187 | $reflection$01$i$i$i$i490;
   $reflection$1$i$i$i$i491 = $2188;
  }
  $2189 = (($i$03$i$i$i$i488) + 1)|0;
  $2190 = $$02$i$i$i$i489 >>> 1;
  $exitcond$i$i$i$i492 = ($2189|0)==(32);
  if ($exitcond$i$i$i$i492) {
   break;
  } else {
   $$02$i$i$i$i489 = $2190;$i$03$i$i$i$i488 = $2189;$reflection$01$i$i$i$i490 = $reflection$1$i$i$i$i491;
  }
 }
 $2191 = $reflection$1$i$i$i$i491 >>> 8;
 $$masked$i$i$i495 = $reflection$1$i$i$i$i491 & 255;
 $2192 = $$masked$i$i$i495 ^ 82;
 $2193 = (584048 + ($2192<<2)|0);
 $2194 = HEAP32[$2193>>2]|0;
 $2195 = $2194 ^ $2191;
 $2196 = $2195 >>> 8;
 $$masked$i$i$i495$1 = $2195 & 255;
 $2197 = $$masked$i$i$i495$1 ^ 111;
 $2198 = (584048 + ($2197<<2)|0);
 $2199 = HEAP32[$2198>>2]|0;
 $2200 = $2199 ^ $2196;
 $2201 = $2200 >>> 8;
 $$masked$i$i$i495$2 = $2200 & 255;
 $2202 = $$masked$i$i$i495$2 ^ 111;
 $2203 = (584048 + ($2202<<2)|0);
 $2204 = HEAP32[$2203>>2]|0;
 $2205 = $2204 ^ $2201;
 $2206 = $2205 >>> 8;
 $$masked$i$i$i495$3 = $2205 & 255;
 $2207 = $$masked$i$i$i495$3 ^ 116;
 $2208 = (584048 + ($2207<<2)|0);
 $2209 = HEAP32[$2208>>2]|0;
 $2210 = $2209 ^ $2206;
 $2211 = $2210 >>> 8;
 $$masked$i$i$i495$4 = $2210 & 255;
 $2212 = $$masked$i$i$i495$4 ^ 83;
 $2213 = (584048 + ($2212<<2)|0);
 $2214 = HEAP32[$2213>>2]|0;
 $2215 = $2214 ^ $2211;
 $2216 = $2215 >>> 8;
 $$masked$i$i$i495$5 = $2215 & 255;
 $2217 = $$masked$i$i$i495$5 ^ 112;
 $2218 = (584048 + ($2217<<2)|0);
 $2219 = HEAP32[$2218>>2]|0;
 $2220 = $2219 ^ $2216;
 $2221 = $2220 >>> 8;
 $$masked$i$i$i495$6 = $2220 & 255;
 $2222 = $$masked$i$i$i495$6 ^ 101;
 $2223 = (584048 + ($2222<<2)|0);
 $2224 = HEAP32[$2223>>2]|0;
 $2225 = $2224 ^ $2221;
 $2226 = $2225 >>> 8;
 $$masked$i$i$i495$7 = $2225 & 255;
 $2227 = $$masked$i$i$i495$7 ^ 101;
 $2228 = (584048 + ($2227<<2)|0);
 $2229 = HEAP32[$2228>>2]|0;
 $2230 = $2229 ^ $2226;
 $2231 = $2230 >>> 8;
 $$masked$i$i$i495$8 = $2230 & 255;
 $2232 = $$masked$i$i$i495$8 ^ 100;
 $2233 = (584048 + ($2232<<2)|0);
 $2234 = HEAP32[$2233>>2]|0;
 $2235 = $2234 ^ $2231;
 $2236 = $2235 >>> 8;
 $$masked$i$i$i495$9 = $2235 & 255;
 $2237 = $$masked$i$i$i495$9 ^ 81;
 $2238 = (584048 + ($2237<<2)|0);
 $2239 = HEAP32[$2238>>2]|0;
 $2240 = $2239 ^ $2236;
 $2241 = $2240 ^ -1;
 $2242 = ((794192 + 672|0));
 $2243 = $2242;
 HEAP32[$2243>>2] = $2241;
 $2244 = (($2242) + 4)|0;
 $2245 = $2244;
 HEAP32[$2245>>2] = (796088);
 $$02$i$i$i$i467 = -1;$i$03$i$i$i$i466 = 0;$reflection$01$i$i$i$i468 = 0;
 while(1) {
  $2246 = $$02$i$i$i$i467 & 1;
  $2247 = ($2246|0)==(0);
  if ($2247) {
   $reflection$1$i$i$i$i469 = $reflection$01$i$i$i$i468;
  } else {
   $2248 = (31 - ($i$03$i$i$i$i466))|0;
   $2249 = 1 << $2248;
   $2250 = $2249 | $reflection$01$i$i$i$i468;
   $reflection$1$i$i$i$i469 = $2250;
  }
  $2251 = (($i$03$i$i$i$i466) + 1)|0;
  $2252 = $$02$i$i$i$i467 >>> 1;
  $exitcond$i$i$i$i470 = ($2251|0)==(32);
  if ($exitcond$i$i$i$i470) {
   break;
  } else {
   $$02$i$i$i$i467 = $2252;$i$03$i$i$i$i466 = $2251;$reflection$01$i$i$i$i468 = $reflection$1$i$i$i$i469;
  }
 }
 $2253 = $reflection$1$i$i$i$i469 >>> 8;
 $$masked$i$i$i473 = $reflection$1$i$i$i$i469 & 255;
 $2254 = $$masked$i$i$i473 ^ 82;
 $2255 = (584048 + ($2254<<2)|0);
 $2256 = HEAP32[$2255>>2]|0;
 $2257 = $2256 ^ $2253;
 $2258 = $2257 >>> 8;
 $$masked$i$i$i473$1 = $2257 & 255;
 $2259 = $$masked$i$i$i473$1 ^ 111;
 $2260 = (584048 + ($2259<<2)|0);
 $2261 = HEAP32[$2260>>2]|0;
 $2262 = $2261 ^ $2258;
 $2263 = $2262 >>> 8;
 $$masked$i$i$i473$2 = $2262 & 255;
 $2264 = $$masked$i$i$i473$2 ^ 111;
 $2265 = (584048 + ($2264<<2)|0);
 $2266 = HEAP32[$2265>>2]|0;
 $2267 = $2266 ^ $2263;
 $2268 = $2267 >>> 8;
 $$masked$i$i$i473$3 = $2267 & 255;
 $2269 = $$masked$i$i$i473$3 ^ 116;
 $2270 = (584048 + ($2269<<2)|0);
 $2271 = HEAP32[$2270>>2]|0;
 $2272 = $2271 ^ $2268;
 $2273 = $2272 >>> 8;
 $$masked$i$i$i473$4 = $2272 & 255;
 $2274 = $$masked$i$i$i473$4 ^ 83;
 $2275 = (584048 + ($2274<<2)|0);
 $2276 = HEAP32[$2275>>2]|0;
 $2277 = $2276 ^ $2273;
 $2278 = $2277 >>> 8;
 $$masked$i$i$i473$5 = $2277 & 255;
 $2279 = $$masked$i$i$i473$5 ^ 116;
 $2280 = (584048 + ($2279<<2)|0);
 $2281 = HEAP32[$2280>>2]|0;
 $2282 = $2281 ^ $2278;
 $2283 = $2282 >>> 8;
 $$masked$i$i$i473$6 = $2282 & 255;
 $2284 = $$masked$i$i$i473$6 ^ 97;
 $2285 = (584048 + ($2284<<2)|0);
 $2286 = HEAP32[$2285>>2]|0;
 $2287 = $2286 ^ $2283;
 $2288 = $2287 >>> 8;
 $$masked$i$i$i473$7 = $2287 & 255;
 $2289 = $$masked$i$i$i473$7 ^ 98;
 $2290 = (584048 + ($2289<<2)|0);
 $2291 = HEAP32[$2290>>2]|0;
 $2292 = $2291 ^ $2288;
 $2293 = $2292 >>> 8;
 $$masked$i$i$i473$8 = $2292 & 255;
 $2294 = $$masked$i$i$i473$8 ^ 108;
 $2295 = (584048 + ($2294<<2)|0);
 $2296 = HEAP32[$2295>>2]|0;
 $2297 = $2296 ^ $2293;
 $2298 = $2297 >>> 8;
 $$masked$i$i$i473$9 = $2297 & 255;
 $2299 = $$masked$i$i$i473$9 ^ 101;
 $2300 = (584048 + ($2299<<2)|0);
 $2301 = HEAP32[$2300>>2]|0;
 $2302 = $2301 ^ $2298;
 $2303 = $2302 >>> 8;
 $$masked$i$i$i473$10 = $2302 & 255;
 $2304 = $$masked$i$i$i473$10 ^ 84;
 $2305 = (584048 + ($2304<<2)|0);
 $2306 = HEAP32[$2305>>2]|0;
 $2307 = $2306 ^ $2303;
 $2308 = $2307 ^ -1;
 $2309 = ((794192 + 680|0));
 $2310 = $2309;
 HEAP32[$2310>>2] = $2308;
 $2311 = (($2309) + 4)|0;
 $2312 = $2311;
 HEAP32[$2312>>2] = (796104);
 $$02$i$i$i$i445 = -1;$i$03$i$i$i$i444 = 0;$reflection$01$i$i$i$i446 = 0;
 while(1) {
  $2313 = $$02$i$i$i$i445 & 1;
  $2314 = ($2313|0)==(0);
  if ($2314) {
   $reflection$1$i$i$i$i447 = $reflection$01$i$i$i$i446;
  } else {
   $2315 = (31 - ($i$03$i$i$i$i444))|0;
   $2316 = 1 << $2315;
   $2317 = $2316 | $reflection$01$i$i$i$i446;
   $reflection$1$i$i$i$i447 = $2317;
  }
  $2318 = (($i$03$i$i$i$i444) + 1)|0;
  $2319 = $$02$i$i$i$i445 >>> 1;
  $exitcond$i$i$i$i448 = ($2318|0)==(32);
  if ($exitcond$i$i$i$i448) {
   break;
  } else {
   $$02$i$i$i$i445 = $2319;$i$03$i$i$i$i444 = $2318;$reflection$01$i$i$i$i446 = $reflection$1$i$i$i$i447;
  }
 }
 $2320 = $reflection$1$i$i$i$i447 >>> 8;
 $$masked$i$i$i451 = $reflection$1$i$i$i$i447 & 255;
 $2321 = $$masked$i$i$i451 ^ 82;
 $2322 = (584048 + ($2321<<2)|0);
 $2323 = HEAP32[$2322>>2]|0;
 $2324 = $2323 ^ $2320;
 $2325 = $2324 >>> 8;
 $$masked$i$i$i451$1 = $2324 & 255;
 $2326 = $$masked$i$i$i451$1 ^ 111;
 $2327 = (584048 + ($2326<<2)|0);
 $2328 = HEAP32[$2327>>2]|0;
 $2329 = $2328 ^ $2325;
 $2330 = $2329 >>> 8;
 $$masked$i$i$i451$2 = $2329 & 255;
 $2331 = $$masked$i$i$i451$2 ^ 111;
 $2332 = (584048 + ($2331<<2)|0);
 $2333 = HEAP32[$2332>>2]|0;
 $2334 = $2333 ^ $2330;
 $2335 = $2334 >>> 8;
 $$masked$i$i$i451$3 = $2334 & 255;
 $2336 = $$masked$i$i$i451$3 ^ 116;
 $2337 = (584048 + ($2336<<2)|0);
 $2338 = HEAP32[$2337>>2]|0;
 $2339 = $2338 ^ $2335;
 $2340 = $2339 >>> 8;
 $$masked$i$i$i451$4 = $2339 & 255;
 $2341 = $$masked$i$i$i451$4 ^ 83;
 $2342 = (584048 + ($2341<<2)|0);
 $2343 = HEAP32[$2342>>2]|0;
 $2344 = $2343 ^ $2340;
 $2345 = $2344 >>> 8;
 $$masked$i$i$i451$5 = $2344 & 255;
 $2346 = $$masked$i$i$i451$5 ^ 116;
 $2347 = (584048 + ($2346<<2)|0);
 $2348 = HEAP32[$2347>>2]|0;
 $2349 = $2348 ^ $2345;
 $2350 = $2349 >>> 8;
 $$masked$i$i$i451$6 = $2349 & 255;
 $2351 = $$masked$i$i$i451$6 ^ 97;
 $2352 = (584048 + ($2351<<2)|0);
 $2353 = HEAP32[$2352>>2]|0;
 $2354 = $2353 ^ $2350;
 $2355 = $2354 >>> 8;
 $$masked$i$i$i451$7 = $2354 & 255;
 $2356 = $$masked$i$i$i451$7 ^ 98;
 $2357 = (584048 + ($2356<<2)|0);
 $2358 = HEAP32[$2357>>2]|0;
 $2359 = $2358 ^ $2355;
 $2360 = $2359 >>> 8;
 $$masked$i$i$i451$8 = $2359 & 255;
 $2361 = $$masked$i$i$i451$8 ^ 108;
 $2362 = (584048 + ($2361<<2)|0);
 $2363 = HEAP32[$2362>>2]|0;
 $2364 = $2363 ^ $2360;
 $2365 = $2364 >>> 8;
 $$masked$i$i$i451$9 = $2364 & 255;
 $2366 = $$masked$i$i$i451$9 ^ 101;
 $2367 = (584048 + ($2366<<2)|0);
 $2368 = HEAP32[$2367>>2]|0;
 $2369 = $2368 ^ $2365;
 $2370 = $2369 >>> 8;
 $$masked$i$i$i451$10 = $2369 & 255;
 $2371 = $$masked$i$i$i451$10 ^ 81;
 $2372 = (584048 + ($2371<<2)|0);
 $2373 = HEAP32[$2372>>2]|0;
 $2374 = $2373 ^ $2370;
 $2375 = $2374 ^ -1;
 $2376 = ((794192 + 688|0));
 $2377 = $2376;
 HEAP32[$2377>>2] = $2375;
 $2378 = (($2376) + 4)|0;
 $2379 = $2378;
 HEAP32[$2379>>2] = (796120);
 $$02$i$i$i$i423 = -1;$i$03$i$i$i$i422 = 0;$reflection$01$i$i$i$i424 = 0;
 while(1) {
  $2380 = $$02$i$i$i$i423 & 1;
  $2381 = ($2380|0)==(0);
  if ($2381) {
   $reflection$1$i$i$i$i425 = $reflection$01$i$i$i$i424;
  } else {
   $2382 = (31 - ($i$03$i$i$i$i422))|0;
   $2383 = 1 << $2382;
   $2384 = $2383 | $reflection$01$i$i$i$i424;
   $reflection$1$i$i$i$i425 = $2384;
  }
  $2385 = (($i$03$i$i$i$i422) + 1)|0;
  $2386 = $$02$i$i$i$i423 >>> 1;
  $exitcond$i$i$i$i426 = ($2385|0)==(32);
  if ($exitcond$i$i$i$i426) {
   break;
  } else {
   $$02$i$i$i$i423 = $2386;$i$03$i$i$i$i422 = $2385;$reflection$01$i$i$i$i424 = $reflection$1$i$i$i$i425;
  }
 }
 $2387 = $reflection$1$i$i$i$i425 >>> 8;
 $$masked$i$i$i429 = $reflection$1$i$i$i$i425 & 255;
 $2388 = $$masked$i$i$i429 ^ 76;
 $2389 = (584048 + ($2388<<2)|0);
 $2390 = HEAP32[$2389>>2]|0;
 $2391 = $2390 ^ $2387;
 $2392 = $2391 >>> 8;
 $$masked$i$i$i429$1 = $2391 & 255;
 $2393 = $$masked$i$i$i429$1 ^ 101;
 $2394 = (584048 + ($2393<<2)|0);
 $2395 = HEAP32[$2394>>2]|0;
 $2396 = $2395 ^ $2392;
 $2397 = $2396 >>> 8;
 $$masked$i$i$i429$2 = $2396 & 255;
 $2398 = $$masked$i$i$i429$2 ^ 102;
 $2399 = (584048 + ($2398<<2)|0);
 $2400 = HEAP32[$2399>>2]|0;
 $2401 = $2400 ^ $2397;
 $2402 = $2401 >>> 8;
 $$masked$i$i$i429$3 = $2401 & 255;
 $2403 = $$masked$i$i$i429$3 ^ 116;
 $2404 = (584048 + ($2403<<2)|0);
 $2405 = HEAP32[$2404>>2]|0;
 $2406 = $2405 ^ $2402;
 $2407 = $2406 >>> 8;
 $$masked$i$i$i429$4 = $2406 & 255;
 $2408 = $$masked$i$i$i429$4 ^ 70;
 $2409 = (584048 + ($2408<<2)|0);
 $2410 = HEAP32[$2409>>2]|0;
 $2411 = $2410 ^ $2407;
 $2412 = $2411 >>> 8;
 $$masked$i$i$i429$5 = $2411 & 255;
 $2413 = $$masked$i$i$i429$5 ^ 111;
 $2414 = (584048 + ($2413<<2)|0);
 $2415 = HEAP32[$2414>>2]|0;
 $2416 = $2415 ^ $2412;
 $2417 = $2416 >>> 8;
 $$masked$i$i$i429$6 = $2416 & 255;
 $2418 = $$masked$i$i$i429$6 ^ 111;
 $2419 = (584048 + ($2418<<2)|0);
 $2420 = HEAP32[$2419>>2]|0;
 $2421 = $2420 ^ $2417;
 $2422 = $2421 >>> 8;
 $$masked$i$i$i429$7 = $2421 & 255;
 $2423 = $$masked$i$i$i429$7 ^ 116;
 $2424 = (584048 + ($2423<<2)|0);
 $2425 = HEAP32[$2424>>2]|0;
 $2426 = $2425 ^ $2422;
 $2427 = $2426 >>> 8;
 $$masked$i$i$i429$8 = $2426 & 255;
 $2428 = $$masked$i$i$i429$8 ^ 80;
 $2429 = (584048 + ($2428<<2)|0);
 $2430 = HEAP32[$2429>>2]|0;
 $2431 = $2430 ^ $2427;
 $2432 = $2431 >>> 8;
 $$masked$i$i$i429$9 = $2431 & 255;
 $2433 = $$masked$i$i$i429$9 ^ 114;
 $2434 = (584048 + ($2433<<2)|0);
 $2435 = HEAP32[$2434>>2]|0;
 $2436 = $2435 ^ $2432;
 $2437 = $2436 >>> 8;
 $$masked$i$i$i429$10 = $2436 & 255;
 $2438 = $$masked$i$i$i429$10 ^ 111;
 $2439 = (584048 + ($2438<<2)|0);
 $2440 = HEAP32[$2439>>2]|0;
 $2441 = $2440 ^ $2437;
 $2442 = $2441 >>> 8;
 $$masked$i$i$i429$11 = $2441 & 255;
 $2443 = $$masked$i$i$i429$11 ^ 106;
 $2444 = (584048 + ($2443<<2)|0);
 $2445 = HEAP32[$2444>>2]|0;
 $2446 = $2445 ^ $2442;
 $2447 = $2446 >>> 8;
 $$masked$i$i$i429$12 = $2446 & 255;
 $2448 = $$masked$i$i$i429$12 ^ 88;
 $2449 = (584048 + ($2448<<2)|0);
 $2450 = HEAP32[$2449>>2]|0;
 $2451 = $2450 ^ $2447;
 $2452 = $2451 ^ -1;
 $2453 = ((794192 + 696|0));
 $2454 = $2453;
 HEAP32[$2454>>2] = $2452;
 $2455 = (($2453) + 4)|0;
 $2456 = $2455;
 HEAP32[$2456>>2] = (796136);
 $$02$i$i$i$i401 = -1;$i$03$i$i$i$i400 = 0;$reflection$01$i$i$i$i402 = 0;
 while(1) {
  $2457 = $$02$i$i$i$i401 & 1;
  $2458 = ($2457|0)==(0);
  if ($2458) {
   $reflection$1$i$i$i$i403 = $reflection$01$i$i$i$i402;
  } else {
   $2459 = (31 - ($i$03$i$i$i$i400))|0;
   $2460 = 1 << $2459;
   $2461 = $2460 | $reflection$01$i$i$i$i402;
   $reflection$1$i$i$i$i403 = $2461;
  }
  $2462 = (($i$03$i$i$i$i400) + 1)|0;
  $2463 = $$02$i$i$i$i401 >>> 1;
  $exitcond$i$i$i$i404 = ($2462|0)==(32);
  if ($exitcond$i$i$i$i404) {
   break;
  } else {
   $$02$i$i$i$i401 = $2463;$i$03$i$i$i$i400 = $2462;$reflection$01$i$i$i$i402 = $reflection$1$i$i$i$i403;
  }
 }
 $2464 = $reflection$1$i$i$i$i403 >>> 8;
 $$masked$i$i$i407 = $reflection$1$i$i$i$i403 & 255;
 $2465 = $$masked$i$i$i407 ^ 82;
 $2466 = (584048 + ($2465<<2)|0);
 $2467 = HEAP32[$2466>>2]|0;
 $2468 = $2467 ^ $2464;
 $2469 = $2468 >>> 8;
 $$masked$i$i$i407$1 = $2468 & 255;
 $2470 = $$masked$i$i$i407$1 ^ 105;
 $2471 = (584048 + ($2470<<2)|0);
 $2472 = HEAP32[$2471>>2]|0;
 $2473 = $2472 ^ $2469;
 $2474 = $2473 >>> 8;
 $$masked$i$i$i407$2 = $2473 & 255;
 $2475 = $$masked$i$i$i407$2 ^ 103;
 $2476 = (584048 + ($2475<<2)|0);
 $2477 = HEAP32[$2476>>2]|0;
 $2478 = $2477 ^ $2474;
 $2479 = $2478 >>> 8;
 $$masked$i$i$i407$3 = $2478 & 255;
 $2480 = $$masked$i$i$i407$3 ^ 104;
 $2481 = (584048 + ($2480<<2)|0);
 $2482 = HEAP32[$2481>>2]|0;
 $2483 = $2482 ^ $2479;
 $2484 = $2483 >>> 8;
 $$masked$i$i$i407$4 = $2483 & 255;
 $2485 = $$masked$i$i$i407$4 ^ 116;
 $2486 = (584048 + ($2485<<2)|0);
 $2487 = HEAP32[$2486>>2]|0;
 $2488 = $2487 ^ $2484;
 $2489 = $2488 >>> 8;
 $$masked$i$i$i407$5 = $2488 & 255;
 $2490 = $$masked$i$i$i407$5 ^ 70;
 $2491 = (584048 + ($2490<<2)|0);
 $2492 = HEAP32[$2491>>2]|0;
 $2493 = $2492 ^ $2489;
 $2494 = $2493 >>> 8;
 $$masked$i$i$i407$6 = $2493 & 255;
 $2495 = $$masked$i$i$i407$6 ^ 111;
 $2496 = (584048 + ($2495<<2)|0);
 $2497 = HEAP32[$2496>>2]|0;
 $2498 = $2497 ^ $2494;
 $2499 = $2498 >>> 8;
 $$masked$i$i$i407$7 = $2498 & 255;
 $2500 = $$masked$i$i$i407$7 ^ 111;
 $2501 = (584048 + ($2500<<2)|0);
 $2502 = HEAP32[$2501>>2]|0;
 $2503 = $2502 ^ $2499;
 $2504 = $2503 >>> 8;
 $$masked$i$i$i407$8 = $2503 & 255;
 $2505 = $$masked$i$i$i407$8 ^ 116;
 $2506 = (584048 + ($2505<<2)|0);
 $2507 = HEAP32[$2506>>2]|0;
 $2508 = $2507 ^ $2504;
 $2509 = $2508 >>> 8;
 $$masked$i$i$i407$9 = $2508 & 255;
 $2510 = $$masked$i$i$i407$9 ^ 80;
 $2511 = (584048 + ($2510<<2)|0);
 $2512 = HEAP32[$2511>>2]|0;
 $2513 = $2512 ^ $2509;
 $2514 = $2513 >>> 8;
 $$masked$i$i$i407$10 = $2513 & 255;
 $2515 = $$masked$i$i$i407$10 ^ 114;
 $2516 = (584048 + ($2515<<2)|0);
 $2517 = HEAP32[$2516>>2]|0;
 $2518 = $2517 ^ $2514;
 $2519 = $2518 >>> 8;
 $$masked$i$i$i407$11 = $2518 & 255;
 $2520 = $$masked$i$i$i407$11 ^ 111;
 $2521 = (584048 + ($2520<<2)|0);
 $2522 = HEAP32[$2521>>2]|0;
 $2523 = $2522 ^ $2519;
 $2524 = $2523 >>> 8;
 $$masked$i$i$i407$12 = $2523 & 255;
 $2525 = $$masked$i$i$i407$12 ^ 106;
 $2526 = (584048 + ($2525<<2)|0);
 $2527 = HEAP32[$2526>>2]|0;
 $2528 = $2527 ^ $2524;
 $2529 = $2528 >>> 8;
 $$masked$i$i$i407$13 = $2528 & 255;
 $2530 = $$masked$i$i$i407$13 ^ 88;
 $2531 = (584048 + ($2530<<2)|0);
 $2532 = HEAP32[$2531>>2]|0;
 $2533 = $2532 ^ $2529;
 $2534 = $2533 ^ -1;
 $2535 = ((794192 + 704|0));
 $2536 = $2535;
 HEAP32[$2536>>2] = $2534;
 $2537 = (($2535) + 4)|0;
 $2538 = $2537;
 HEAP32[$2538>>2] = (796152);
 $$02$i$i$i$i379 = -1;$i$03$i$i$i$i378 = 0;$reflection$01$i$i$i$i380 = 0;
 while(1) {
  $2539 = $$02$i$i$i$i379 & 1;
  $2540 = ($2539|0)==(0);
  if ($2540) {
   $reflection$1$i$i$i$i381 = $reflection$01$i$i$i$i380;
  } else {
   $2541 = (31 - ($i$03$i$i$i$i378))|0;
   $2542 = 1 << $2541;
   $2543 = $2542 | $reflection$01$i$i$i$i380;
   $reflection$1$i$i$i$i381 = $2543;
  }
  $2544 = (($i$03$i$i$i$i378) + 1)|0;
  $2545 = $$02$i$i$i$i379 >>> 1;
  $exitcond$i$i$i$i382 = ($2544|0)==(32);
  if ($exitcond$i$i$i$i382) {
   break;
  } else {
   $$02$i$i$i$i379 = $2545;$i$03$i$i$i$i378 = $2544;$reflection$01$i$i$i$i380 = $reflection$1$i$i$i$i381;
  }
 }
 $2546 = $reflection$1$i$i$i$i381 >>> 8;
 $$masked$i$i$i385 = $reflection$1$i$i$i$i381 & 255;
 $2547 = $$masked$i$i$i385 ^ 80;
 $2548 = (584048 + ($2547<<2)|0);
 $2549 = HEAP32[$2548>>2]|0;
 $2550 = $2549 ^ $2546;
 $2551 = $2550 >>> 8;
 $$masked$i$i$i385$1 = $2550 & 255;
 $2552 = $$masked$i$i$i385$1 ^ 108;
 $2553 = (584048 + ($2552<<2)|0);
 $2554 = HEAP32[$2553>>2]|0;
 $2555 = $2554 ^ $2551;
 $2556 = $2555 >>> 8;
 $$masked$i$i$i385$2 = $2555 & 255;
 $2557 = $$masked$i$i$i385$2 ^ 97;
 $2558 = (584048 + ($2557<<2)|0);
 $2559 = HEAP32[$2558>>2]|0;
 $2560 = $2559 ^ $2556;
 $2561 = $2560 >>> 8;
 $$masked$i$i$i385$3 = $2560 & 255;
 $2562 = $$masked$i$i$i385$3 ^ 110;
 $2563 = (584048 + ($2562<<2)|0);
 $2564 = HEAP32[$2563>>2]|0;
 $2565 = $2564 ^ $2561;
 $2566 = $2565 >>> 8;
 $$masked$i$i$i385$4 = $2565 & 255;
 $2567 = $$masked$i$i$i385$4 ^ 116;
 $2568 = (584048 + ($2567<<2)|0);
 $2569 = HEAP32[$2568>>2]|0;
 $2570 = $2569 ^ $2566;
 $2571 = $2570 >>> 8;
 $$masked$i$i$i385$5 = $2570 & 255;
 $2572 = $$masked$i$i$i385$5 ^ 70;
 $2573 = (584048 + ($2572<<2)|0);
 $2574 = HEAP32[$2573>>2]|0;
 $2575 = $2574 ^ $2571;
 $2576 = $2575 >>> 8;
 $$masked$i$i$i385$6 = $2575 & 255;
 $2577 = $$masked$i$i$i385$6 ^ 101;
 $2578 = (584048 + ($2577<<2)|0);
 $2579 = HEAP32[$2578>>2]|0;
 $2580 = $2579 ^ $2576;
 $2581 = $2580 >>> 8;
 $$masked$i$i$i385$7 = $2580 & 255;
 $2582 = $$masked$i$i$i385$7 ^ 101;
 $2583 = (584048 + ($2582<<2)|0);
 $2584 = HEAP32[$2583>>2]|0;
 $2585 = $2584 ^ $2581;
 $2586 = $2585 >>> 8;
 $$masked$i$i$i385$8 = $2585 & 255;
 $2587 = $$masked$i$i$i385$8 ^ 116;
 $2588 = (584048 + ($2587<<2)|0);
 $2589 = HEAP32[$2588>>2]|0;
 $2590 = $2589 ^ $2586;
 $2591 = $2590 ^ -1;
 $2592 = ((794192 + 712|0));
 $2593 = $2592;
 HEAP32[$2593>>2] = $2591;
 $2594 = (($2592) + 4)|0;
 $2595 = $2594;
 HEAP32[$2595>>2] = (796168);
 $$02$i$i$i$i357 = -1;$i$03$i$i$i$i356 = 0;$reflection$01$i$i$i$i358 = 0;
 while(1) {
  $2596 = $$02$i$i$i$i357 & 1;
  $2597 = ($2596|0)==(0);
  if ($2597) {
   $reflection$1$i$i$i$i359 = $reflection$01$i$i$i$i358;
  } else {
   $2598 = (31 - ($i$03$i$i$i$i356))|0;
   $2599 = 1 << $2598;
   $2600 = $2599 | $reflection$01$i$i$i$i358;
   $reflection$1$i$i$i$i359 = $2600;
  }
  $2601 = (($i$03$i$i$i$i356) + 1)|0;
  $2602 = $$02$i$i$i$i357 >>> 1;
  $exitcond$i$i$i$i360 = ($2601|0)==(32);
  if ($exitcond$i$i$i$i360) {
   break;
  } else {
   $$02$i$i$i$i357 = $2602;$i$03$i$i$i$i356 = $2601;$reflection$01$i$i$i$i358 = $reflection$1$i$i$i$i359;
  }
 }
 $2603 = $reflection$1$i$i$i$i359 >>> 8;
 $$masked$i$i$i363 = $reflection$1$i$i$i$i359 & 255;
 $2604 = $$masked$i$i$i363 ^ 76;
 $2605 = (584048 + ($2604<<2)|0);
 $2606 = HEAP32[$2605>>2]|0;
 $2607 = $2606 ^ $2603;
 $2608 = $2607 >>> 8;
 $$masked$i$i$i363$1 = $2607 & 255;
 $2609 = $$masked$i$i$i363$1 ^ 101;
 $2610 = (584048 + ($2609<<2)|0);
 $2611 = HEAP32[$2610>>2]|0;
 $2612 = $2611 ^ $2608;
 $2613 = $2612 >>> 8;
 $$masked$i$i$i363$2 = $2612 & 255;
 $2614 = $$masked$i$i$i363$2 ^ 102;
 $2615 = (584048 + ($2614<<2)|0);
 $2616 = HEAP32[$2615>>2]|0;
 $2617 = $2616 ^ $2613;
 $2618 = $2617 >>> 8;
 $$masked$i$i$i363$3 = $2617 & 255;
 $2619 = $$masked$i$i$i363$3 ^ 116;
 $2620 = (584048 + ($2619<<2)|0);
 $2621 = HEAP32[$2620>>2]|0;
 $2622 = $2621 ^ $2618;
 $2623 = $2622 >>> 8;
 $$masked$i$i$i363$4 = $2622 & 255;
 $2624 = $$masked$i$i$i363$4 ^ 70;
 $2625 = (584048 + ($2624<<2)|0);
 $2626 = HEAP32[$2625>>2]|0;
 $2627 = $2626 ^ $2623;
 $2628 = $2627 >>> 8;
 $$masked$i$i$i363$5 = $2627 & 255;
 $2629 = $$masked$i$i$i363$5 ^ 111;
 $2630 = (584048 + ($2629<<2)|0);
 $2631 = HEAP32[$2630>>2]|0;
 $2632 = $2631 ^ $2628;
 $2633 = $2632 >>> 8;
 $$masked$i$i$i363$6 = $2632 & 255;
 $2634 = $$masked$i$i$i363$6 ^ 111;
 $2635 = (584048 + ($2634<<2)|0);
 $2636 = HEAP32[$2635>>2]|0;
 $2637 = $2636 ^ $2633;
 $2638 = $2637 >>> 8;
 $$masked$i$i$i363$7 = $2637 & 255;
 $2639 = $$masked$i$i$i363$7 ^ 116;
 $2640 = (584048 + ($2639<<2)|0);
 $2641 = HEAP32[$2640>>2]|0;
 $2642 = $2641 ^ $2638;
 $2643 = $2642 >>> 8;
 $$masked$i$i$i363$8 = $2642 & 255;
 $2644 = $$masked$i$i$i363$8 ^ 83;
 $2645 = (584048 + ($2644<<2)|0);
 $2646 = HEAP32[$2645>>2]|0;
 $2647 = $2646 ^ $2643;
 $2648 = $2647 >>> 8;
 $$masked$i$i$i363$9 = $2647 & 255;
 $2649 = $$masked$i$i$i363$9 ^ 97;
 $2650 = (584048 + ($2649<<2)|0);
 $2651 = HEAP32[$2650>>2]|0;
 $2652 = $2651 ^ $2648;
 $2653 = $2652 >>> 8;
 $$masked$i$i$i363$10 = $2652 & 255;
 $2654 = $$masked$i$i$i363$10 ^ 102;
 $2655 = (584048 + ($2654<<2)|0);
 $2656 = HEAP32[$2655>>2]|0;
 $2657 = $2656 ^ $2653;
 $2658 = $2657 >>> 8;
 $$masked$i$i$i363$11 = $2657 & 255;
 $2659 = $$masked$i$i$i363$11 ^ 101;
 $2660 = (584048 + ($2659<<2)|0);
 $2661 = HEAP32[$2660>>2]|0;
 $2662 = $2661 ^ $2658;
 $2663 = $2662 >>> 8;
 $$masked$i$i$i363$12 = $2662 & 255;
 $2664 = $$masked$i$i$i363$12 ^ 88;
 $2665 = (584048 + ($2664<<2)|0);
 $2666 = HEAP32[$2665>>2]|0;
 $2667 = $2666 ^ $2663;
 $2668 = $2667 ^ -1;
 $2669 = ((794192 + 720|0));
 $2670 = $2669;
 HEAP32[$2670>>2] = $2668;
 $2671 = (($2669) + 4)|0;
 $2672 = $2671;
 HEAP32[$2672>>2] = (796184);
 $$02$i$i$i$i335 = -1;$i$03$i$i$i$i334 = 0;$reflection$01$i$i$i$i336 = 0;
 while(1) {
  $2673 = $$02$i$i$i$i335 & 1;
  $2674 = ($2673|0)==(0);
  if ($2674) {
   $reflection$1$i$i$i$i337 = $reflection$01$i$i$i$i336;
  } else {
   $2675 = (31 - ($i$03$i$i$i$i334))|0;
   $2676 = 1 << $2675;
   $2677 = $2676 | $reflection$01$i$i$i$i336;
   $reflection$1$i$i$i$i337 = $2677;
  }
  $2678 = (($i$03$i$i$i$i334) + 1)|0;
  $2679 = $$02$i$i$i$i335 >>> 1;
  $exitcond$i$i$i$i338 = ($2678|0)==(32);
  if ($exitcond$i$i$i$i338) {
   break;
  } else {
   $$02$i$i$i$i335 = $2679;$i$03$i$i$i$i334 = $2678;$reflection$01$i$i$i$i336 = $reflection$1$i$i$i$i337;
  }
 }
 $2680 = $reflection$1$i$i$i$i337 >>> 8;
 $$masked$i$i$i341 = $reflection$1$i$i$i$i337 & 255;
 $2681 = $$masked$i$i$i341 ^ 82;
 $2682 = (584048 + ($2681<<2)|0);
 $2683 = HEAP32[$2682>>2]|0;
 $2684 = $2683 ^ $2680;
 $2685 = $2684 >>> 8;
 $$masked$i$i$i341$1 = $2684 & 255;
 $2686 = $$masked$i$i$i341$1 ^ 105;
 $2687 = (584048 + ($2686<<2)|0);
 $2688 = HEAP32[$2687>>2]|0;
 $2689 = $2688 ^ $2685;
 $2690 = $2689 >>> 8;
 $$masked$i$i$i341$2 = $2689 & 255;
 $2691 = $$masked$i$i$i341$2 ^ 103;
 $2692 = (584048 + ($2691<<2)|0);
 $2693 = HEAP32[$2692>>2]|0;
 $2694 = $2693 ^ $2690;
 $2695 = $2694 >>> 8;
 $$masked$i$i$i341$3 = $2694 & 255;
 $2696 = $$masked$i$i$i341$3 ^ 104;
 $2697 = (584048 + ($2696<<2)|0);
 $2698 = HEAP32[$2697>>2]|0;
 $2699 = $2698 ^ $2695;
 $2700 = $2699 >>> 8;
 $$masked$i$i$i341$4 = $2699 & 255;
 $2701 = $$masked$i$i$i341$4 ^ 116;
 $2702 = (584048 + ($2701<<2)|0);
 $2703 = HEAP32[$2702>>2]|0;
 $2704 = $2703 ^ $2700;
 $2705 = $2704 >>> 8;
 $$masked$i$i$i341$5 = $2704 & 255;
 $2706 = $$masked$i$i$i341$5 ^ 70;
 $2707 = (584048 + ($2706<<2)|0);
 $2708 = HEAP32[$2707>>2]|0;
 $2709 = $2708 ^ $2705;
 $2710 = $2709 >>> 8;
 $$masked$i$i$i341$6 = $2709 & 255;
 $2711 = $$masked$i$i$i341$6 ^ 111;
 $2712 = (584048 + ($2711<<2)|0);
 $2713 = HEAP32[$2712>>2]|0;
 $2714 = $2713 ^ $2710;
 $2715 = $2714 >>> 8;
 $$masked$i$i$i341$7 = $2714 & 255;
 $2716 = $$masked$i$i$i341$7 ^ 111;
 $2717 = (584048 + ($2716<<2)|0);
 $2718 = HEAP32[$2717>>2]|0;
 $2719 = $2718 ^ $2715;
 $2720 = $2719 >>> 8;
 $$masked$i$i$i341$8 = $2719 & 255;
 $2721 = $$masked$i$i$i341$8 ^ 116;
 $2722 = (584048 + ($2721<<2)|0);
 $2723 = HEAP32[$2722>>2]|0;
 $2724 = $2723 ^ $2720;
 $2725 = $2724 >>> 8;
 $$masked$i$i$i341$9 = $2724 & 255;
 $2726 = $$masked$i$i$i341$9 ^ 83;
 $2727 = (584048 + ($2726<<2)|0);
 $2728 = HEAP32[$2727>>2]|0;
 $2729 = $2728 ^ $2725;
 $2730 = $2729 >>> 8;
 $$masked$i$i$i341$10 = $2729 & 255;
 $2731 = $$masked$i$i$i341$10 ^ 97;
 $2732 = (584048 + ($2731<<2)|0);
 $2733 = HEAP32[$2732>>2]|0;
 $2734 = $2733 ^ $2730;
 $2735 = $2734 >>> 8;
 $$masked$i$i$i341$11 = $2734 & 255;
 $2736 = $$masked$i$i$i341$11 ^ 102;
 $2737 = (584048 + ($2736<<2)|0);
 $2738 = HEAP32[$2737>>2]|0;
 $2739 = $2738 ^ $2735;
 $2740 = $2739 >>> 8;
 $$masked$i$i$i341$12 = $2739 & 255;
 $2741 = $$masked$i$i$i341$12 ^ 101;
 $2742 = (584048 + ($2741<<2)|0);
 $2743 = HEAP32[$2742>>2]|0;
 $2744 = $2743 ^ $2740;
 $2745 = $2744 >>> 8;
 $$masked$i$i$i341$13 = $2744 & 255;
 $2746 = $$masked$i$i$i341$13 ^ 88;
 $2747 = (584048 + ($2746<<2)|0);
 $2748 = HEAP32[$2747>>2]|0;
 $2749 = $2748 ^ $2745;
 $2750 = $2749 ^ -1;
 $2751 = ((794192 + 728|0));
 $2752 = $2751;
 HEAP32[$2752>>2] = $2750;
 $2753 = (($2751) + 4)|0;
 $2754 = $2753;
 HEAP32[$2754>>2] = (796200);
 $$02$i$i$i$i313 = -1;$i$03$i$i$i$i312 = 0;$reflection$01$i$i$i$i314 = 0;
 while(1) {
  $2755 = $$02$i$i$i$i313 & 1;
  $2756 = ($2755|0)==(0);
  if ($2756) {
   $reflection$1$i$i$i$i315 = $reflection$01$i$i$i$i314;
  } else {
   $2757 = (31 - ($i$03$i$i$i$i312))|0;
   $2758 = 1 << $2757;
   $2759 = $2758 | $reflection$01$i$i$i$i314;
   $reflection$1$i$i$i$i315 = $2759;
  }
  $2760 = (($i$03$i$i$i$i312) + 1)|0;
  $2761 = $$02$i$i$i$i313 >>> 1;
  $exitcond$i$i$i$i316 = ($2760|0)==(32);
  if ($exitcond$i$i$i$i316) {
   break;
  } else {
   $$02$i$i$i$i313 = $2761;$i$03$i$i$i$i312 = $2760;$reflection$01$i$i$i$i314 = $reflection$1$i$i$i$i315;
  }
 }
 $2762 = $reflection$1$i$i$i$i315 >>> 8;
 $$masked$i$i$i319 = $reflection$1$i$i$i$i315 & 255;
 $2763 = $$masked$i$i$i319 ^ 80;
 $2764 = (584048 + ($2763<<2)|0);
 $2765 = HEAP32[$2764>>2]|0;
 $2766 = $2765 ^ $2762;
 $2767 = $2766 >>> 8;
 $$masked$i$i$i319$1 = $2766 & 255;
 $2768 = $$masked$i$i$i319$1 ^ 111;
 $2769 = (584048 + ($2768<<2)|0);
 $2770 = HEAP32[$2769>>2]|0;
 $2771 = $2770 ^ $2767;
 $2772 = $2771 >>> 8;
 $$masked$i$i$i319$2 = $2771 & 255;
 $2773 = $$masked$i$i$i319$2 ^ 115;
 $2774 = (584048 + ($2773<<2)|0);
 $2775 = HEAP32[$2774>>2]|0;
 $2776 = $2775 ^ $2772;
 $2777 = $2776 >>> 8;
 $$masked$i$i$i319$3 = $2776 & 255;
 $2778 = $$masked$i$i$i319$3 ^ 105;
 $2779 = (584048 + ($2778<<2)|0);
 $2780 = HEAP32[$2779>>2]|0;
 $2781 = $2780 ^ $2777;
 $2782 = $2781 >>> 8;
 $$masked$i$i$i319$4 = $2781 & 255;
 $2783 = $$masked$i$i$i319$4 ^ 116;
 $2784 = (584048 + ($2783<<2)|0);
 $2785 = HEAP32[$2784>>2]|0;
 $2786 = $2785 ^ $2782;
 $2787 = $2786 >>> 8;
 $$masked$i$i$i319$5 = $2786 & 255;
 $2788 = $$masked$i$i$i319$5 ^ 105;
 $2789 = (584048 + ($2788<<2)|0);
 $2790 = HEAP32[$2789>>2]|0;
 $2791 = $2790 ^ $2787;
 $2792 = $2791 >>> 8;
 $$masked$i$i$i319$6 = $2791 & 255;
 $2793 = $$masked$i$i$i319$6 ^ 111;
 $2794 = (584048 + ($2793<<2)|0);
 $2795 = HEAP32[$2794>>2]|0;
 $2796 = $2795 ^ $2792;
 $2797 = $2796 >>> 8;
 $$masked$i$i$i319$7 = $2796 & 255;
 $2798 = $$masked$i$i$i319$7 ^ 110;
 $2799 = (584048 + ($2798<<2)|0);
 $2800 = HEAP32[$2799>>2]|0;
 $2801 = $2800 ^ $2797;
 $2802 = $2801 >>> 8;
 $$masked$i$i$i319$8 = $2801 & 255;
 $2803 = $$masked$i$i$i319$8 ^ 88;
 $2804 = (584048 + ($2803<<2)|0);
 $2805 = HEAP32[$2804>>2]|0;
 $2806 = $2805 ^ $2802;
 $2807 = $2806 ^ -1;
 $2808 = ((794192 + 736|0));
 $2809 = $2808;
 HEAP32[$2809>>2] = $2807;
 $2810 = (($2808) + 4)|0;
 $2811 = $2810;
 HEAP32[$2811>>2] = (796216);
 $$02$i$i$i$i291 = -1;$i$03$i$i$i$i290 = 0;$reflection$01$i$i$i$i292 = 0;
 while(1) {
  $2812 = $$02$i$i$i$i291 & 1;
  $2813 = ($2812|0)==(0);
  if ($2813) {
   $reflection$1$i$i$i$i293 = $reflection$01$i$i$i$i292;
  } else {
   $2814 = (31 - ($i$03$i$i$i$i290))|0;
   $2815 = 1 << $2814;
   $2816 = $2815 | $reflection$01$i$i$i$i292;
   $reflection$1$i$i$i$i293 = $2816;
  }
  $2817 = (($i$03$i$i$i$i290) + 1)|0;
  $2818 = $$02$i$i$i$i291 >>> 1;
  $exitcond$i$i$i$i294 = ($2817|0)==(32);
  if ($exitcond$i$i$i$i294) {
   break;
  } else {
   $$02$i$i$i$i291 = $2818;$i$03$i$i$i$i290 = $2817;$reflection$01$i$i$i$i292 = $reflection$1$i$i$i$i293;
  }
 }
 $2819 = $reflection$1$i$i$i$i293 >>> 8;
 $$masked$i$i$i297 = $reflection$1$i$i$i$i293 & 255;
 $2820 = $$masked$i$i$i297 ^ 80;
 $2821 = (584048 + ($2820<<2)|0);
 $2822 = HEAP32[$2821>>2]|0;
 $2823 = $2822 ^ $2819;
 $2824 = $2823 >>> 8;
 $$masked$i$i$i297$1 = $2823 & 255;
 $2825 = $$masked$i$i$i297$1 ^ 111;
 $2826 = (584048 + ($2825<<2)|0);
 $2827 = HEAP32[$2826>>2]|0;
 $2828 = $2827 ^ $2824;
 $2829 = $2828 >>> 8;
 $$masked$i$i$i297$2 = $2828 & 255;
 $2830 = $$masked$i$i$i297$2 ^ 115;
 $2831 = (584048 + ($2830<<2)|0);
 $2832 = HEAP32[$2831>>2]|0;
 $2833 = $2832 ^ $2829;
 $2834 = $2833 >>> 8;
 $$masked$i$i$i297$3 = $2833 & 255;
 $2835 = $$masked$i$i$i297$3 ^ 105;
 $2836 = (584048 + ($2835<<2)|0);
 $2837 = HEAP32[$2836>>2]|0;
 $2838 = $2837 ^ $2834;
 $2839 = $2838 >>> 8;
 $$masked$i$i$i297$4 = $2838 & 255;
 $2840 = $$masked$i$i$i297$4 ^ 116;
 $2841 = (584048 + ($2840<<2)|0);
 $2842 = HEAP32[$2841>>2]|0;
 $2843 = $2842 ^ $2839;
 $2844 = $2843 >>> 8;
 $$masked$i$i$i297$5 = $2843 & 255;
 $2845 = $$masked$i$i$i297$5 ^ 105;
 $2846 = (584048 + ($2845<<2)|0);
 $2847 = HEAP32[$2846>>2]|0;
 $2848 = $2847 ^ $2844;
 $2849 = $2848 >>> 8;
 $$masked$i$i$i297$6 = $2848 & 255;
 $2850 = $$masked$i$i$i297$6 ^ 111;
 $2851 = (584048 + ($2850<<2)|0);
 $2852 = HEAP32[$2851>>2]|0;
 $2853 = $2852 ^ $2849;
 $2854 = $2853 >>> 8;
 $$masked$i$i$i297$7 = $2853 & 255;
 $2855 = $$masked$i$i$i297$7 ^ 110;
 $2856 = (584048 + ($2855<<2)|0);
 $2857 = HEAP32[$2856>>2]|0;
 $2858 = $2857 ^ $2854;
 $2859 = $2858 >>> 8;
 $$masked$i$i$i297$8 = $2858 & 255;
 $2860 = $$masked$i$i$i297$8 ^ 89;
 $2861 = (584048 + ($2860<<2)|0);
 $2862 = HEAP32[$2861>>2]|0;
 $2863 = $2862 ^ $2859;
 $2864 = $2863 ^ -1;
 $2865 = ((794192 + 744|0));
 $2866 = $2865;
 HEAP32[$2866>>2] = $2864;
 $2867 = (($2865) + 4)|0;
 $2868 = $2867;
 HEAP32[$2868>>2] = (796232);
 $$02$i$i$i$i269 = -1;$i$03$i$i$i$i268 = 0;$reflection$01$i$i$i$i270 = 0;
 while(1) {
  $2869 = $$02$i$i$i$i269 & 1;
  $2870 = ($2869|0)==(0);
  if ($2870) {
   $reflection$1$i$i$i$i271 = $reflection$01$i$i$i$i270;
  } else {
   $2871 = (31 - ($i$03$i$i$i$i268))|0;
   $2872 = 1 << $2871;
   $2873 = $2872 | $reflection$01$i$i$i$i270;
   $reflection$1$i$i$i$i271 = $2873;
  }
  $2874 = (($i$03$i$i$i$i268) + 1)|0;
  $2875 = $$02$i$i$i$i269 >>> 1;
  $exitcond$i$i$i$i272 = ($2874|0)==(32);
  if ($exitcond$i$i$i$i272) {
   break;
  } else {
   $$02$i$i$i$i269 = $2875;$i$03$i$i$i$i268 = $2874;$reflection$01$i$i$i$i270 = $reflection$1$i$i$i$i271;
  }
 }
 $2876 = $reflection$1$i$i$i$i271 >>> 8;
 $$masked$i$i$i275 = $reflection$1$i$i$i$i271 & 255;
 $2877 = $$masked$i$i$i275 ^ 80;
 $2878 = (584048 + ($2877<<2)|0);
 $2879 = HEAP32[$2878>>2]|0;
 $2880 = $2879 ^ $2876;
 $2881 = $2880 >>> 8;
 $$masked$i$i$i275$1 = $2880 & 255;
 $2882 = $$masked$i$i$i275$1 ^ 111;
 $2883 = (584048 + ($2882<<2)|0);
 $2884 = HEAP32[$2883>>2]|0;
 $2885 = $2884 ^ $2881;
 $2886 = $2885 >>> 8;
 $$masked$i$i$i275$2 = $2885 & 255;
 $2887 = $$masked$i$i$i275$2 ^ 115;
 $2888 = (584048 + ($2887<<2)|0);
 $2889 = HEAP32[$2888>>2]|0;
 $2890 = $2889 ^ $2886;
 $2891 = $2890 >>> 8;
 $$masked$i$i$i275$3 = $2890 & 255;
 $2892 = $$masked$i$i$i275$3 ^ 105;
 $2893 = (584048 + ($2892<<2)|0);
 $2894 = HEAP32[$2893>>2]|0;
 $2895 = $2894 ^ $2891;
 $2896 = $2895 >>> 8;
 $$masked$i$i$i275$4 = $2895 & 255;
 $2897 = $$masked$i$i$i275$4 ^ 116;
 $2898 = (584048 + ($2897<<2)|0);
 $2899 = HEAP32[$2898>>2]|0;
 $2900 = $2899 ^ $2896;
 $2901 = $2900 >>> 8;
 $$masked$i$i$i275$5 = $2900 & 255;
 $2902 = $$masked$i$i$i275$5 ^ 105;
 $2903 = (584048 + ($2902<<2)|0);
 $2904 = HEAP32[$2903>>2]|0;
 $2905 = $2904 ^ $2901;
 $2906 = $2905 >>> 8;
 $$masked$i$i$i275$6 = $2905 & 255;
 $2907 = $$masked$i$i$i275$6 ^ 111;
 $2908 = (584048 + ($2907<<2)|0);
 $2909 = HEAP32[$2908>>2]|0;
 $2910 = $2909 ^ $2906;
 $2911 = $2910 >>> 8;
 $$masked$i$i$i275$7 = $2910 & 255;
 $2912 = $$masked$i$i$i275$7 ^ 110;
 $2913 = (584048 + ($2912<<2)|0);
 $2914 = HEAP32[$2913>>2]|0;
 $2915 = $2914 ^ $2911;
 $2916 = $2915 >>> 8;
 $$masked$i$i$i275$8 = $2915 & 255;
 $2917 = $$masked$i$i$i275$8 ^ 90;
 $2918 = (584048 + ($2917<<2)|0);
 $2919 = HEAP32[$2918>>2]|0;
 $2920 = $2919 ^ $2916;
 $2921 = $2920 ^ -1;
 $2922 = ((794192 + 752|0));
 $2923 = $2922;
 HEAP32[$2923>>2] = $2921;
 $2924 = (($2922) + 4)|0;
 $2925 = $2924;
 HEAP32[$2925>>2] = (796248);
 $$02$i$i$i$i247 = -1;$i$03$i$i$i$i246 = 0;$reflection$01$i$i$i$i248 = 0;
 while(1) {
  $2926 = $$02$i$i$i$i247 & 1;
  $2927 = ($2926|0)==(0);
  if ($2927) {
   $reflection$1$i$i$i$i249 = $reflection$01$i$i$i$i248;
  } else {
   $2928 = (31 - ($i$03$i$i$i$i246))|0;
   $2929 = 1 << $2928;
   $2930 = $2929 | $reflection$01$i$i$i$i248;
   $reflection$1$i$i$i$i249 = $2930;
  }
  $2931 = (($i$03$i$i$i$i246) + 1)|0;
  $2932 = $$02$i$i$i$i247 >>> 1;
  $exitcond$i$i$i$i250 = ($2931|0)==(32);
  if ($exitcond$i$i$i$i250) {
   break;
  } else {
   $$02$i$i$i$i247 = $2932;$i$03$i$i$i$i246 = $2931;$reflection$01$i$i$i$i248 = $reflection$1$i$i$i$i249;
  }
 }
 $2933 = $reflection$1$i$i$i$i249 >>> 8;
 $$masked$i$i$i253 = $reflection$1$i$i$i$i249 & 255;
 $2934 = $$masked$i$i$i253 ^ 81;
 $2935 = (584048 + ($2934<<2)|0);
 $2936 = HEAP32[$2935>>2]|0;
 $2937 = $2936 ^ $2933;
 $2938 = $2937 >>> 8;
 $$masked$i$i$i253$1 = $2937 & 255;
 $2939 = $$masked$i$i$i253$1 ^ 117;
 $2940 = (584048 + ($2939<<2)|0);
 $2941 = HEAP32[$2940>>2]|0;
 $2942 = $2941 ^ $2938;
 $2943 = $2942 >>> 8;
 $$masked$i$i$i253$2 = $2942 & 255;
 $2944 = $$masked$i$i$i253$2 ^ 97;
 $2945 = (584048 + ($2944<<2)|0);
 $2946 = HEAP32[$2945>>2]|0;
 $2947 = $2946 ^ $2943;
 $2948 = $2947 >>> 8;
 $$masked$i$i$i253$3 = $2947 & 255;
 $2949 = $$masked$i$i$i253$3 ^ 116;
 $2950 = (584048 + ($2949<<2)|0);
 $2951 = HEAP32[$2950>>2]|0;
 $2952 = $2951 ^ $2948;
 $2953 = $2952 >>> 8;
 $$masked$i$i$i253$4 = $2952 & 255;
 $2954 = $$masked$i$i$i253$4 ^ 101;
 $2955 = (584048 + ($2954<<2)|0);
 $2956 = HEAP32[$2955>>2]|0;
 $2957 = $2956 ^ $2953;
 $2958 = $2957 >>> 8;
 $$masked$i$i$i253$5 = $2957 & 255;
 $2959 = $$masked$i$i$i253$5 ^ 114;
 $2960 = (584048 + ($2959<<2)|0);
 $2961 = HEAP32[$2960>>2]|0;
 $2962 = $2961 ^ $2958;
 $2963 = $2962 >>> 8;
 $$masked$i$i$i253$6 = $2962 & 255;
 $2964 = $$masked$i$i$i253$6 ^ 110;
 $2965 = (584048 + ($2964<<2)|0);
 $2966 = HEAP32[$2965>>2]|0;
 $2967 = $2966 ^ $2963;
 $2968 = $2967 >>> 8;
 $$masked$i$i$i253$7 = $2967 & 255;
 $2969 = $$masked$i$i$i253$7 ^ 105;
 $2970 = (584048 + ($2969<<2)|0);
 $2971 = HEAP32[$2970>>2]|0;
 $2972 = $2971 ^ $2968;
 $2973 = $2972 >>> 8;
 $$masked$i$i$i253$8 = $2972 & 255;
 $2974 = $$masked$i$i$i253$8 ^ 111;
 $2975 = (584048 + ($2974<<2)|0);
 $2976 = HEAP32[$2975>>2]|0;
 $2977 = $2976 ^ $2973;
 $2978 = $2977 >>> 8;
 $$masked$i$i$i253$9 = $2977 & 255;
 $2979 = $$masked$i$i$i253$9 ^ 110;
 $2980 = (584048 + ($2979<<2)|0);
 $2981 = HEAP32[$2980>>2]|0;
 $2982 = $2981 ^ $2978;
 $2983 = $2982 >>> 8;
 $$masked$i$i$i253$10 = $2982 & 255;
 $2984 = $$masked$i$i$i253$10 ^ 88;
 $2985 = (584048 + ($2984<<2)|0);
 $2986 = HEAP32[$2985>>2]|0;
 $2987 = $2986 ^ $2983;
 $2988 = $2987 ^ -1;
 $2989 = ((794192 + 760|0));
 $2990 = $2989;
 HEAP32[$2990>>2] = $2988;
 $2991 = (($2989) + 4)|0;
 $2992 = $2991;
 HEAP32[$2992>>2] = (796264);
 $$02$i$i$i$i225 = -1;$i$03$i$i$i$i224 = 0;$reflection$01$i$i$i$i226 = 0;
 while(1) {
  $2993 = $$02$i$i$i$i225 & 1;
  $2994 = ($2993|0)==(0);
  if ($2994) {
   $reflection$1$i$i$i$i227 = $reflection$01$i$i$i$i226;
  } else {
   $2995 = (31 - ($i$03$i$i$i$i224))|0;
   $2996 = 1 << $2995;
   $2997 = $2996 | $reflection$01$i$i$i$i226;
   $reflection$1$i$i$i$i227 = $2997;
  }
  $2998 = (($i$03$i$i$i$i224) + 1)|0;
  $2999 = $$02$i$i$i$i225 >>> 1;
  $exitcond$i$i$i$i228 = ($2998|0)==(32);
  if ($exitcond$i$i$i$i228) {
   break;
  } else {
   $$02$i$i$i$i225 = $2999;$i$03$i$i$i$i224 = $2998;$reflection$01$i$i$i$i226 = $reflection$1$i$i$i$i227;
  }
 }
 $3000 = $reflection$1$i$i$i$i227 >>> 8;
 $$masked$i$i$i231 = $reflection$1$i$i$i$i227 & 255;
 $3001 = $$masked$i$i$i231 ^ 81;
 $3002 = (584048 + ($3001<<2)|0);
 $3003 = HEAP32[$3002>>2]|0;
 $3004 = $3003 ^ $3000;
 $3005 = $3004 >>> 8;
 $$masked$i$i$i231$1 = $3004 & 255;
 $3006 = $$masked$i$i$i231$1 ^ 117;
 $3007 = (584048 + ($3006<<2)|0);
 $3008 = HEAP32[$3007>>2]|0;
 $3009 = $3008 ^ $3005;
 $3010 = $3009 >>> 8;
 $$masked$i$i$i231$2 = $3009 & 255;
 $3011 = $$masked$i$i$i231$2 ^ 97;
 $3012 = (584048 + ($3011<<2)|0);
 $3013 = HEAP32[$3012>>2]|0;
 $3014 = $3013 ^ $3010;
 $3015 = $3014 >>> 8;
 $$masked$i$i$i231$3 = $3014 & 255;
 $3016 = $$masked$i$i$i231$3 ^ 116;
 $3017 = (584048 + ($3016<<2)|0);
 $3018 = HEAP32[$3017>>2]|0;
 $3019 = $3018 ^ $3015;
 $3020 = $3019 >>> 8;
 $$masked$i$i$i231$4 = $3019 & 255;
 $3021 = $$masked$i$i$i231$4 ^ 101;
 $3022 = (584048 + ($3021<<2)|0);
 $3023 = HEAP32[$3022>>2]|0;
 $3024 = $3023 ^ $3020;
 $3025 = $3024 >>> 8;
 $$masked$i$i$i231$5 = $3024 & 255;
 $3026 = $$masked$i$i$i231$5 ^ 114;
 $3027 = (584048 + ($3026<<2)|0);
 $3028 = HEAP32[$3027>>2]|0;
 $3029 = $3028 ^ $3025;
 $3030 = $3029 >>> 8;
 $$masked$i$i$i231$6 = $3029 & 255;
 $3031 = $$masked$i$i$i231$6 ^ 110;
 $3032 = (584048 + ($3031<<2)|0);
 $3033 = HEAP32[$3032>>2]|0;
 $3034 = $3033 ^ $3030;
 $3035 = $3034 >>> 8;
 $$masked$i$i$i231$7 = $3034 & 255;
 $3036 = $$masked$i$i$i231$7 ^ 105;
 $3037 = (584048 + ($3036<<2)|0);
 $3038 = HEAP32[$3037>>2]|0;
 $3039 = $3038 ^ $3035;
 $3040 = $3039 >>> 8;
 $$masked$i$i$i231$8 = $3039 & 255;
 $3041 = $$masked$i$i$i231$8 ^ 111;
 $3042 = (584048 + ($3041<<2)|0);
 $3043 = HEAP32[$3042>>2]|0;
 $3044 = $3043 ^ $3040;
 $3045 = $3044 >>> 8;
 $$masked$i$i$i231$9 = $3044 & 255;
 $3046 = $$masked$i$i$i231$9 ^ 110;
 $3047 = (584048 + ($3046<<2)|0);
 $3048 = HEAP32[$3047>>2]|0;
 $3049 = $3048 ^ $3045;
 $3050 = $3049 >>> 8;
 $$masked$i$i$i231$10 = $3049 & 255;
 $3051 = $$masked$i$i$i231$10 ^ 89;
 $3052 = (584048 + ($3051<<2)|0);
 $3053 = HEAP32[$3052>>2]|0;
 $3054 = $3053 ^ $3050;
 $3055 = $3054 ^ -1;
 $3056 = ((794192 + 768|0));
 $3057 = $3056;
 HEAP32[$3057>>2] = $3055;
 $3058 = (($3056) + 4)|0;
 $3059 = $3058;
 HEAP32[$3059>>2] = (796280);
 $$02$i$i$i$i203 = -1;$i$03$i$i$i$i202 = 0;$reflection$01$i$i$i$i204 = 0;
 while(1) {
  $3060 = $$02$i$i$i$i203 & 1;
  $3061 = ($3060|0)==(0);
  if ($3061) {
   $reflection$1$i$i$i$i205 = $reflection$01$i$i$i$i204;
  } else {
   $3062 = (31 - ($i$03$i$i$i$i202))|0;
   $3063 = 1 << $3062;
   $3064 = $3063 | $reflection$01$i$i$i$i204;
   $reflection$1$i$i$i$i205 = $3064;
  }
  $3065 = (($i$03$i$i$i$i202) + 1)|0;
  $3066 = $$02$i$i$i$i203 >>> 1;
  $exitcond$i$i$i$i206 = ($3065|0)==(32);
  if ($exitcond$i$i$i$i206) {
   break;
  } else {
   $$02$i$i$i$i203 = $3066;$i$03$i$i$i$i202 = $3065;$reflection$01$i$i$i$i204 = $reflection$1$i$i$i$i205;
  }
 }
 $3067 = $reflection$1$i$i$i$i205 >>> 8;
 $$masked$i$i$i209 = $reflection$1$i$i$i$i205 & 255;
 $3068 = $$masked$i$i$i209 ^ 81;
 $3069 = (584048 + ($3068<<2)|0);
 $3070 = HEAP32[$3069>>2]|0;
 $3071 = $3070 ^ $3067;
 $3072 = $3071 >>> 8;
 $$masked$i$i$i209$1 = $3071 & 255;
 $3073 = $$masked$i$i$i209$1 ^ 117;
 $3074 = (584048 + ($3073<<2)|0);
 $3075 = HEAP32[$3074>>2]|0;
 $3076 = $3075 ^ $3072;
 $3077 = $3076 >>> 8;
 $$masked$i$i$i209$2 = $3076 & 255;
 $3078 = $$masked$i$i$i209$2 ^ 97;
 $3079 = (584048 + ($3078<<2)|0);
 $3080 = HEAP32[$3079>>2]|0;
 $3081 = $3080 ^ $3077;
 $3082 = $3081 >>> 8;
 $$masked$i$i$i209$3 = $3081 & 255;
 $3083 = $$masked$i$i$i209$3 ^ 116;
 $3084 = (584048 + ($3083<<2)|0);
 $3085 = HEAP32[$3084>>2]|0;
 $3086 = $3085 ^ $3082;
 $3087 = $3086 >>> 8;
 $$masked$i$i$i209$4 = $3086 & 255;
 $3088 = $$masked$i$i$i209$4 ^ 101;
 $3089 = (584048 + ($3088<<2)|0);
 $3090 = HEAP32[$3089>>2]|0;
 $3091 = $3090 ^ $3087;
 $3092 = $3091 >>> 8;
 $$masked$i$i$i209$5 = $3091 & 255;
 $3093 = $$masked$i$i$i209$5 ^ 114;
 $3094 = (584048 + ($3093<<2)|0);
 $3095 = HEAP32[$3094>>2]|0;
 $3096 = $3095 ^ $3092;
 $3097 = $3096 >>> 8;
 $$masked$i$i$i209$6 = $3096 & 255;
 $3098 = $$masked$i$i$i209$6 ^ 110;
 $3099 = (584048 + ($3098<<2)|0);
 $3100 = HEAP32[$3099>>2]|0;
 $3101 = $3100 ^ $3097;
 $3102 = $3101 >>> 8;
 $$masked$i$i$i209$7 = $3101 & 255;
 $3103 = $$masked$i$i$i209$7 ^ 105;
 $3104 = (584048 + ($3103<<2)|0);
 $3105 = HEAP32[$3104>>2]|0;
 $3106 = $3105 ^ $3102;
 $3107 = $3106 >>> 8;
 $$masked$i$i$i209$8 = $3106 & 255;
 $3108 = $$masked$i$i$i209$8 ^ 111;
 $3109 = (584048 + ($3108<<2)|0);
 $3110 = HEAP32[$3109>>2]|0;
 $3111 = $3110 ^ $3107;
 $3112 = $3111 >>> 8;
 $$masked$i$i$i209$9 = $3111 & 255;
 $3113 = $$masked$i$i$i209$9 ^ 110;
 $3114 = (584048 + ($3113<<2)|0);
 $3115 = HEAP32[$3114>>2]|0;
 $3116 = $3115 ^ $3112;
 $3117 = $3116 >>> 8;
 $$masked$i$i$i209$10 = $3116 & 255;
 $3118 = $$masked$i$i$i209$10 ^ 90;
 $3119 = (584048 + ($3118<<2)|0);
 $3120 = HEAP32[$3119>>2]|0;
 $3121 = $3120 ^ $3117;
 $3122 = $3121 ^ -1;
 $3123 = ((794192 + 776|0));
 $3124 = $3123;
 HEAP32[$3124>>2] = $3122;
 $3125 = (($3123) + 4)|0;
 $3126 = $3125;
 HEAP32[$3126>>2] = (796296);
 $$02$i$i$i$i181 = -1;$i$03$i$i$i$i180 = 0;$reflection$01$i$i$i$i182 = 0;
 while(1) {
  $3127 = $$02$i$i$i$i181 & 1;
  $3128 = ($3127|0)==(0);
  if ($3128) {
   $reflection$1$i$i$i$i183 = $reflection$01$i$i$i$i182;
  } else {
   $3129 = (31 - ($i$03$i$i$i$i180))|0;
   $3130 = 1 << $3129;
   $3131 = $3130 | $reflection$01$i$i$i$i182;
   $reflection$1$i$i$i$i183 = $3131;
  }
  $3132 = (($i$03$i$i$i$i180) + 1)|0;
  $3133 = $$02$i$i$i$i181 >>> 1;
  $exitcond$i$i$i$i184 = ($3132|0)==(32);
  if ($exitcond$i$i$i$i184) {
   break;
  } else {
   $$02$i$i$i$i181 = $3133;$i$03$i$i$i$i180 = $3132;$reflection$01$i$i$i$i182 = $reflection$1$i$i$i$i183;
  }
 }
 $3134 = $reflection$1$i$i$i$i183 >>> 8;
 $$masked$i$i$i187 = $reflection$1$i$i$i$i183 & 255;
 $3135 = $$masked$i$i$i187 ^ 81;
 $3136 = (584048 + ($3135<<2)|0);
 $3137 = HEAP32[$3136>>2]|0;
 $3138 = $3137 ^ $3134;
 $3139 = $3138 >>> 8;
 $$masked$i$i$i187$1 = $3138 & 255;
 $3140 = $$masked$i$i$i187$1 ^ 117;
 $3141 = (584048 + ($3140<<2)|0);
 $3142 = HEAP32[$3141>>2]|0;
 $3143 = $3142 ^ $3139;
 $3144 = $3143 >>> 8;
 $$masked$i$i$i187$2 = $3143 & 255;
 $3145 = $$masked$i$i$i187$2 ^ 97;
 $3146 = (584048 + ($3145<<2)|0);
 $3147 = HEAP32[$3146>>2]|0;
 $3148 = $3147 ^ $3144;
 $3149 = $3148 >>> 8;
 $$masked$i$i$i187$3 = $3148 & 255;
 $3150 = $$masked$i$i$i187$3 ^ 116;
 $3151 = (584048 + ($3150<<2)|0);
 $3152 = HEAP32[$3151>>2]|0;
 $3153 = $3152 ^ $3149;
 $3154 = $3153 >>> 8;
 $$masked$i$i$i187$4 = $3153 & 255;
 $3155 = $$masked$i$i$i187$4 ^ 101;
 $3156 = (584048 + ($3155<<2)|0);
 $3157 = HEAP32[$3156>>2]|0;
 $3158 = $3157 ^ $3154;
 $3159 = $3158 >>> 8;
 $$masked$i$i$i187$5 = $3158 & 255;
 $3160 = $$masked$i$i$i187$5 ^ 114;
 $3161 = (584048 + ($3160<<2)|0);
 $3162 = HEAP32[$3161>>2]|0;
 $3163 = $3162 ^ $3159;
 $3164 = $3163 >>> 8;
 $$masked$i$i$i187$6 = $3163 & 255;
 $3165 = $$masked$i$i$i187$6 ^ 110;
 $3166 = (584048 + ($3165<<2)|0);
 $3167 = HEAP32[$3166>>2]|0;
 $3168 = $3167 ^ $3164;
 $3169 = $3168 >>> 8;
 $$masked$i$i$i187$7 = $3168 & 255;
 $3170 = $$masked$i$i$i187$7 ^ 105;
 $3171 = (584048 + ($3170<<2)|0);
 $3172 = HEAP32[$3171>>2]|0;
 $3173 = $3172 ^ $3169;
 $3174 = $3173 >>> 8;
 $$masked$i$i$i187$8 = $3173 & 255;
 $3175 = $$masked$i$i$i187$8 ^ 111;
 $3176 = (584048 + ($3175<<2)|0);
 $3177 = HEAP32[$3176>>2]|0;
 $3178 = $3177 ^ $3174;
 $3179 = $3178 >>> 8;
 $$masked$i$i$i187$9 = $3178 & 255;
 $3180 = $$masked$i$i$i187$9 ^ 110;
 $3181 = (584048 + ($3180<<2)|0);
 $3182 = HEAP32[$3181>>2]|0;
 $3183 = $3182 ^ $3179;
 $3184 = $3183 >>> 8;
 $$masked$i$i$i187$10 = $3183 & 255;
 $3185 = $$masked$i$i$i187$10 ^ 87;
 $3186 = (584048 + ($3185<<2)|0);
 $3187 = HEAP32[$3186>>2]|0;
 $3188 = $3187 ^ $3184;
 $3189 = $3188 ^ -1;
 $3190 = ((794192 + 784|0));
 $3191 = $3190;
 HEAP32[$3191>>2] = $3189;
 $3192 = (($3190) + 4)|0;
 $3193 = $3192;
 HEAP32[$3193>>2] = (796312);
 $$02$i$i$i$i159 = -1;$i$03$i$i$i$i158 = 0;$reflection$01$i$i$i$i160 = 0;
 while(1) {
  $3194 = $$02$i$i$i$i159 & 1;
  $3195 = ($3194|0)==(0);
  if ($3195) {
   $reflection$1$i$i$i$i161 = $reflection$01$i$i$i$i160;
  } else {
   $3196 = (31 - ($i$03$i$i$i$i158))|0;
   $3197 = 1 << $3196;
   $3198 = $3197 | $reflection$01$i$i$i$i160;
   $reflection$1$i$i$i$i161 = $3198;
  }
  $3199 = (($i$03$i$i$i$i158) + 1)|0;
  $3200 = $$02$i$i$i$i159 >>> 1;
  $exitcond$i$i$i$i162 = ($3199|0)==(32);
  if ($exitcond$i$i$i$i162) {
   break;
  } else {
   $$02$i$i$i$i159 = $3200;$i$03$i$i$i$i158 = $3199;$reflection$01$i$i$i$i160 = $reflection$1$i$i$i$i161;
  }
 }
 $3201 = $reflection$1$i$i$i$i161 >>> 8;
 $$masked$i$i$i165 = $reflection$1$i$i$i$i161 & 255;
 $3202 = $$masked$i$i$i165 ^ 83;
 $3203 = (584048 + ($3202<<2)|0);
 $3204 = HEAP32[$3203>>2]|0;
 $3205 = $3204 ^ $3201;
 $3206 = $3205 >>> 8;
 $$masked$i$i$i165$1 = $3205 & 255;
 $3207 = $$masked$i$i$i165$1 ^ 99;
 $3208 = (584048 + ($3207<<2)|0);
 $3209 = HEAP32[$3208>>2]|0;
 $3210 = $3209 ^ $3206;
 $3211 = $3210 >>> 8;
 $$masked$i$i$i165$2 = $3210 & 255;
 $3212 = $$masked$i$i$i165$2 ^ 97;
 $3213 = (584048 + ($3212<<2)|0);
 $3214 = HEAP32[$3213>>2]|0;
 $3215 = $3214 ^ $3211;
 $3216 = $3215 >>> 8;
 $$masked$i$i$i165$3 = $3215 & 255;
 $3217 = $$masked$i$i$i165$3 ^ 108;
 $3218 = (584048 + ($3217<<2)|0);
 $3219 = HEAP32[$3218>>2]|0;
 $3220 = $3219 ^ $3216;
 $3221 = $3220 >>> 8;
 $$masked$i$i$i165$4 = $3220 & 255;
 $3222 = $$masked$i$i$i165$4 ^ 101;
 $3223 = (584048 + ($3222<<2)|0);
 $3224 = HEAP32[$3223>>2]|0;
 $3225 = $3224 ^ $3221;
 $3226 = $3225 >>> 8;
 $$masked$i$i$i165$5 = $3225 & 255;
 $3227 = $$masked$i$i$i165$5 ^ 88;
 $3228 = (584048 + ($3227<<2)|0);
 $3229 = HEAP32[$3228>>2]|0;
 $3230 = $3229 ^ $3226;
 $3231 = $3230 ^ -1;
 $3232 = ((794192 + 792|0));
 $3233 = $3232;
 HEAP32[$3233>>2] = $3231;
 $3234 = (($3232) + 4)|0;
 $3235 = $3234;
 HEAP32[$3235>>2] = (796328);
 $$02$i$i$i$i137 = -1;$i$03$i$i$i$i136 = 0;$reflection$01$i$i$i$i138 = 0;
 while(1) {
  $3236 = $$02$i$i$i$i137 & 1;
  $3237 = ($3236|0)==(0);
  if ($3237) {
   $reflection$1$i$i$i$i139 = $reflection$01$i$i$i$i138;
  } else {
   $3238 = (31 - ($i$03$i$i$i$i136))|0;
   $3239 = 1 << $3238;
   $3240 = $3239 | $reflection$01$i$i$i$i138;
   $reflection$1$i$i$i$i139 = $3240;
  }
  $3241 = (($i$03$i$i$i$i136) + 1)|0;
  $3242 = $$02$i$i$i$i137 >>> 1;
  $exitcond$i$i$i$i140 = ($3241|0)==(32);
  if ($exitcond$i$i$i$i140) {
   break;
  } else {
   $$02$i$i$i$i137 = $3242;$i$03$i$i$i$i136 = $3241;$reflection$01$i$i$i$i138 = $reflection$1$i$i$i$i139;
  }
 }
 $3243 = $reflection$1$i$i$i$i139 >>> 8;
 $$masked$i$i$i143 = $reflection$1$i$i$i$i139 & 255;
 $3244 = $$masked$i$i$i143 ^ 83;
 $3245 = (584048 + ($3244<<2)|0);
 $3246 = HEAP32[$3245>>2]|0;
 $3247 = $3246 ^ $3243;
 $3248 = $3247 >>> 8;
 $$masked$i$i$i143$1 = $3247 & 255;
 $3249 = $$masked$i$i$i143$1 ^ 99;
 $3250 = (584048 + ($3249<<2)|0);
 $3251 = HEAP32[$3250>>2]|0;
 $3252 = $3251 ^ $3248;
 $3253 = $3252 >>> 8;
 $$masked$i$i$i143$2 = $3252 & 255;
 $3254 = $$masked$i$i$i143$2 ^ 97;
 $3255 = (584048 + ($3254<<2)|0);
 $3256 = HEAP32[$3255>>2]|0;
 $3257 = $3256 ^ $3253;
 $3258 = $3257 >>> 8;
 $$masked$i$i$i143$3 = $3257 & 255;
 $3259 = $$masked$i$i$i143$3 ^ 108;
 $3260 = (584048 + ($3259<<2)|0);
 $3261 = HEAP32[$3260>>2]|0;
 $3262 = $3261 ^ $3258;
 $3263 = $3262 >>> 8;
 $$masked$i$i$i143$4 = $3262 & 255;
 $3264 = $$masked$i$i$i143$4 ^ 101;
 $3265 = (584048 + ($3264<<2)|0);
 $3266 = HEAP32[$3265>>2]|0;
 $3267 = $3266 ^ $3263;
 $3268 = $3267 >>> 8;
 $$masked$i$i$i143$5 = $3267 & 255;
 $3269 = $$masked$i$i$i143$5 ^ 89;
 $3270 = (584048 + ($3269<<2)|0);
 $3271 = HEAP32[$3270>>2]|0;
 $3272 = $3271 ^ $3268;
 $3273 = $3272 ^ -1;
 $3274 = ((794192 + 800|0));
 $3275 = $3274;
 HEAP32[$3275>>2] = $3273;
 $3276 = (($3274) + 4)|0;
 $3277 = $3276;
 HEAP32[$3277>>2] = (796336);
 $$02$i$i$i$i115 = -1;$i$03$i$i$i$i114 = 0;$reflection$01$i$i$i$i116 = 0;
 while(1) {
  $3278 = $$02$i$i$i$i115 & 1;
  $3279 = ($3278|0)==(0);
  if ($3279) {
   $reflection$1$i$i$i$i117 = $reflection$01$i$i$i$i116;
  } else {
   $3280 = (31 - ($i$03$i$i$i$i114))|0;
   $3281 = 1 << $3280;
   $3282 = $3281 | $reflection$01$i$i$i$i116;
   $reflection$1$i$i$i$i117 = $3282;
  }
  $3283 = (($i$03$i$i$i$i114) + 1)|0;
  $3284 = $$02$i$i$i$i115 >>> 1;
  $exitcond$i$i$i$i118 = ($3283|0)==(32);
  if ($exitcond$i$i$i$i118) {
   break;
  } else {
   $$02$i$i$i$i115 = $3284;$i$03$i$i$i$i114 = $3283;$reflection$01$i$i$i$i116 = $reflection$1$i$i$i$i117;
  }
 }
 $3285 = $reflection$1$i$i$i$i117 >>> 8;
 $$masked$i$i$i121 = $reflection$1$i$i$i$i117 & 255;
 $3286 = $$masked$i$i$i121 ^ 83;
 $3287 = (584048 + ($3286<<2)|0);
 $3288 = HEAP32[$3287>>2]|0;
 $3289 = $3288 ^ $3285;
 $3290 = $3289 >>> 8;
 $$masked$i$i$i121$1 = $3289 & 255;
 $3291 = $$masked$i$i$i121$1 ^ 99;
 $3292 = (584048 + ($3291<<2)|0);
 $3293 = HEAP32[$3292>>2]|0;
 $3294 = $3293 ^ $3290;
 $3295 = $3294 >>> 8;
 $$masked$i$i$i121$2 = $3294 & 255;
 $3296 = $$masked$i$i$i121$2 ^ 97;
 $3297 = (584048 + ($3296<<2)|0);
 $3298 = HEAP32[$3297>>2]|0;
 $3299 = $3298 ^ $3295;
 $3300 = $3299 >>> 8;
 $$masked$i$i$i121$3 = $3299 & 255;
 $3301 = $$masked$i$i$i121$3 ^ 108;
 $3302 = (584048 + ($3301<<2)|0);
 $3303 = HEAP32[$3302>>2]|0;
 $3304 = $3303 ^ $3300;
 $3305 = $3304 >>> 8;
 $$masked$i$i$i121$4 = $3304 & 255;
 $3306 = $$masked$i$i$i121$4 ^ 101;
 $3307 = (584048 + ($3306<<2)|0);
 $3308 = HEAP32[$3307>>2]|0;
 $3309 = $3308 ^ $3305;
 $3310 = $3309 >>> 8;
 $$masked$i$i$i121$5 = $3309 & 255;
 $3311 = $$masked$i$i$i121$5 ^ 90;
 $3312 = (584048 + ($3311<<2)|0);
 $3313 = HEAP32[$3312>>2]|0;
 $3314 = $3313 ^ $3310;
 $3315 = $3314 ^ -1;
 $3316 = ((794192 + 808|0));
 $3317 = $3316;
 HEAP32[$3317>>2] = $3315;
 $3318 = (($3316) + 4)|0;
 $3319 = $3318;
 HEAP32[$3319>>2] = (796344);
 $$02$i$i$i$i = -1;$i$03$i$i$i$i = 0;$reflection$01$i$i$i$i = 0;
 while(1) {
  $3320 = $$02$i$i$i$i & 1;
  $3321 = ($3320|0)==(0);
  if ($3321) {
   $reflection$1$i$i$i$i = $reflection$01$i$i$i$i;
  } else {
   $3322 = (31 - ($i$03$i$i$i$i))|0;
   $3323 = 1 << $3322;
   $3324 = $3323 | $reflection$01$i$i$i$i;
   $reflection$1$i$i$i$i = $3324;
  }
  $3325 = (($i$03$i$i$i$i) + 1)|0;
  $3326 = $$02$i$i$i$i >>> 1;
  $exitcond$i$i$i$i = ($3325|0)==(32);
  if ($exitcond$i$i$i$i) {
   break;
  } else {
   $$02$i$i$i$i = $3326;$i$03$i$i$i$i = $3325;$reflection$01$i$i$i$i = $reflection$1$i$i$i$i;
  }
 }
 $3327 = $reflection$1$i$i$i$i >>> 8;
 $$masked$i$i$i = $reflection$1$i$i$i$i & 255;
 $3328 = $$masked$i$i$i ^ 68;
 $3329 = (584048 + ($3328<<2)|0);
 $3330 = HEAP32[$3329>>2]|0;
 $3331 = $3330 ^ $3327;
 $3332 = $3331 >>> 8;
 $$masked$i$i$i$1 = $3331 & 255;
 $3333 = $$masked$i$i$i$1 ^ 121;
 $3334 = (584048 + ($3333<<2)|0);
 $3335 = HEAP32[$3334>>2]|0;
 $3336 = $3335 ^ $3332;
 $3337 = $3336 >>> 8;
 $$masked$i$i$i$2 = $3336 & 255;
 $3338 = $$masked$i$i$i$2 ^ 110;
 $3339 = (584048 + ($3338<<2)|0);
 $3340 = HEAP32[$3339>>2]|0;
 $3341 = $3340 ^ $3337;
 $3342 = $3341 >>> 8;
 $$masked$i$i$i$3 = $3341 & 255;
 $3343 = $$masked$i$i$i$3 ^ 97;
 $3344 = (584048 + ($3343<<2)|0);
 $3345 = HEAP32[$3344>>2]|0;
 $3346 = $3345 ^ $3342;
 $3347 = $3346 >>> 8;
 $$masked$i$i$i$4 = $3346 & 255;
 $3348 = $$masked$i$i$i$4 ^ 109;
 $3349 = (584048 + ($3348<<2)|0);
 $3350 = HEAP32[$3349>>2]|0;
 $3351 = $3350 ^ $3347;
 $3352 = $3351 >>> 8;
 $$masked$i$i$i$5 = $3351 & 255;
 $3353 = $$masked$i$i$i$5 ^ 105;
 $3354 = (584048 + ($3353<<2)|0);
 $3355 = HEAP32[$3354>>2]|0;
 $3356 = $3355 ^ $3352;
 $3357 = $3356 >>> 8;
 $$masked$i$i$i$6 = $3356 & 255;
 $3358 = $$masked$i$i$i$6 ^ 99;
 $3359 = (584048 + ($3358<<2)|0);
 $3360 = HEAP32[$3359>>2]|0;
 $3361 = $3360 ^ $3357;
 $3362 = $3361 >>> 8;
 $$masked$i$i$i$7 = $3361 & 255;
 $3363 = $$masked$i$i$i$7 ^ 67;
 $3364 = (584048 + ($3363<<2)|0);
 $3365 = HEAP32[$3364>>2]|0;
 $3366 = $3365 ^ $3362;
 $3367 = $3366 >>> 8;
 $$masked$i$i$i$8 = $3366 & 255;
 $3368 = $$masked$i$i$i$8 ^ 117;
 $3369 = (584048 + ($3368<<2)|0);
 $3370 = HEAP32[$3369>>2]|0;
 $3371 = $3370 ^ $3367;
 $3372 = $3371 >>> 8;
 $$masked$i$i$i$9 = $3371 & 255;
 $3373 = $$masked$i$i$i$9 ^ 114;
 $3374 = (584048 + ($3373<<2)|0);
 $3375 = HEAP32[$3374>>2]|0;
 $3376 = $3375 ^ $3372;
 $3377 = $3376 >>> 8;
 $$masked$i$i$i$10 = $3376 & 255;
 $3378 = $$masked$i$i$i$10 ^ 118;
 $3379 = (584048 + ($3378<<2)|0);
 $3380 = HEAP32[$3379>>2]|0;
 $3381 = $3380 ^ $3377;
 $3382 = $3381 >>> 8;
 $$masked$i$i$i$11 = $3381 & 255;
 $3383 = $$masked$i$i$i$11 ^ 101;
 $3384 = (584048 + ($3383<<2)|0);
 $3385 = HEAP32[$3384>>2]|0;
 $3386 = $3385 ^ $3382;
 $3387 = $3386 ^ -1;
 $3388 = ((794192 + 816|0));
 $3389 = $3388;
 HEAP32[$3389>>2] = $3387;
 $3390 = (($3388) + 4)|0;
 $3391 = $3390;
 HEAP32[$3391>>2] = (796352);
 STACKTOP = sp;return;
}
function __ZN7mecanim6CRCKeyENS_7eStringE($id) {
 $id = $id|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[794184>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  __ZN12_GLOBAL__N_19InitTableEv();
  HEAP32[794176>>2] = 794192;
  HEAP8[794184>>0] = 1;
  $3 = 794192;
 } else {
  $$pre$i = HEAP32[794176>>2]|0;
  $3 = $$pre$i;
 }
 $2 = (($3) + ($id<<3)|0);
 $4 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($4|0);
}
function __ZN7mecanimL12processCRC32EPKc($string) {
 $string = $string|0;
 var $$02$i$i$i = 0, $$masked$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $exitcond$i$i$i = 0, $i$03$i$i$i = 0, $p$01$i$i = 0, $reflection$01$i$i$i = 0, $reflection$1$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$02$i$i$i = -1;$i$03$i$i$i = 0;$reflection$01$i$i$i = 0;
 while(1) {
  $0 = $$02$i$i$i & 1;
  $1 = ($0|0)==(0);
  if ($1) {
   $reflection$1$i$i$i = $reflection$01$i$i$i;
  } else {
   $2 = (31 - ($i$03$i$i$i))|0;
   $3 = 1 << $2;
   $4 = $3 | $reflection$01$i$i$i;
   $reflection$1$i$i$i = $4;
  }
  $5 = (($i$03$i$i$i) + 1)|0;
  $6 = $$02$i$i$i >>> 1;
  $exitcond$i$i$i = ($5|0)==(32);
  if ($exitcond$i$i$i) {
   break;
  } else {
   $$02$i$i$i = $6;$i$03$i$i$i = $5;$reflection$01$i$i$i = $reflection$1$i$i$i;
  }
 }
 $7 = (_strlen(($string|0))|0);
 $8 = (($string) + ($7)|0);
 $9 = ($7|0)>(0);
 if ($9) {
  $13 = $reflection$1$i$i$i;$p$01$i$i = $string;
 } else {
  $20 = $reflection$1$i$i$i;
  $19 = $20 ^ -1;
  STACKTOP = sp;return ($19|0);
 }
 while(1) {
  $10 = HEAP8[$p$01$i$i>>0]|0;
  $11 = $10&255;
  $12 = $13 >>> 8;
  $$masked$i$i = $13 & 255;
  $14 = $11 ^ $$masked$i$i;
  $15 = (584048 + ($14<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16 ^ $12;
  $18 = (($p$01$i$i) + 1|0);
  $exitcond$i$i = ($18|0)==($8|0);
  if ($exitcond$i$i) {
   $20 = $17;
   break;
  } else {
   $13 = $17;$p$01$i$i = $18;
  }
 }
 $19 = $20 ^ -1;
 STACKTOP = sp;return ($19|0);
}
function __ZN7mecanim24CreateValueArrayConstantENS_9ValueTypeEjRNS_6memory9AllocatorE($aType,$aCount,$alloc) {
 $aType = $aType|0;
 $aCount = $aCount|0;
 $alloc = $alloc|0;
 var $$lcssa = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,12,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $6 = 0;
 } else {
  HEAP32[$2>>2] = 0;
  $4 = (($2) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($2) + 8|0);
  HEAP32[$5>>2] = 0;
  $6 = $2;
 }
 HEAP32[$6>>2] = $aCount;
 $7 = (($6) + 4|0);
 $8 = ($aCount|0)==(0);
 if ($8) {
  HEAP32[$7>>2] = 0;
  $9 = (($6) + 8|0);
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return ($6|0);
 }
 $10 = HEAP32[$alloc>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = $aCount << 4;
 $13 = (FUNCTION_TABLE_iiii[$11 & 2047]($alloc,$12,4)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  HEAP32[$7>>2] = 0;
  $15 = (($6) + 8|0);
  HEAP32[$15>>2] = 0;
  $$pre = $7;
  $$pre$phiZ2D = $$pre;$28 = 0;$32 = $7;$45 = $15;
 } else {
  $16 = (($13) + ($aCount<<4)|0);
  $17 = $13;
  while(1) {
   HEAP32[$17>>2] = 0;
   $18 = (($17) + 4|0);
   HEAP32[$18>>2] = 0;
   $19 = (($17) + 8|0);
   HEAP32[$19>>2] = 10;
   $20 = (($17) + 12|0);
   HEAP32[$20>>2] = 0;
   $21 = (($17) + 16|0);
   $22 = ($21|0)==($16|0);
   if ($22) {
    break;
   } else {
    $17 = $21;
   }
  }
  $23 = $13;
  $24 = $7;
  $25 = (($23) - ($24))|0;
  HEAP32[$7>>2] = $25;
  $26 = (($6) + 8|0);
  HEAP32[$26>>2] = $13;
  $$pre$phiZ2D = $24;$28 = $25;$32 = $7;$45 = $26;
 }
 $27 = (($28) + ($$pre$phiZ2D))|0;
 $29 = $27;
 $30 = (($29) + 8|0);
 HEAP32[$30>>2] = $aType;
 $31 = HEAP32[$32>>2]|0;
 $33 = (($31) + ($$pre$phiZ2D))|0;
 $34 = $33;
 $35 = (($34) + 12|0);
 HEAP32[$35>>2] = 0;
 $exitcond$i2 = ($aCount|0)==(1);
 if ($exitcond$i2) {
  $$lcssa = $34;
 } else {
  $39 = 1;
  while(1) {
   $$pre$i = HEAP32[$32>>2]|0;
   $36 = (($$pre$i) + ($$pre$phiZ2D))|0;
   $37 = $36;
   $38 = ((($37) + ($39<<4)|0) + 8|0);
   HEAP32[$38>>2] = $aType;
   $40 = HEAP32[$32>>2]|0;
   $41 = (($40) + ($$pre$phiZ2D))|0;
   $42 = $41;
   $43 = ((($42) + ($39<<4)|0) + 12|0);
   HEAP32[$43>>2] = $39;
   $44 = (($39) + 1)|0;
   $exitcond$i = ($44|0)==($aCount|0);
   if ($exitcond$i) {
    $$lcssa = $42;
    break;
   } else {
    $39 = $44;
   }
  }
 }
 HEAP32[$45>>2] = $$lcssa;
 STACKTOP = sp;return ($6|0);
}
function __ZN7mecanim28CreateValueArrayConstantCopyEPKNS_18ValueArrayConstantEjRNS_6memory9AllocatorE($sourceConstant,$count,$alloc) {
 $sourceConstant = $sourceConstant|0;
 $count = $count|0;
 $alloc = $alloc|0;
 var $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,12,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $6 = 0;
 } else {
  HEAP32[$2>>2] = 0;
  $4 = (($2) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($2) + 8|0);
  HEAP32[$5>>2] = 0;
  $6 = $2;
 }
 HEAP32[$6>>2] = $count;
 $7 = (($sourceConstant) + 4|0);
 $8 = $7;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = (($sourceConstant) + 8|0);
 HEAP32[$12>>2] = $11;
 $13 = ($count|0)==(0);
 if ($13) {
  $14 = (($6) + 4|0);
  $$0$i2 = 0;$25 = 0;$26 = $14;
 } else {
  $15 = HEAP32[$alloc>>2]|0;
  $16 = HEAP32[$15>>2]|0;
  $17 = $count << 4;
  $18 = (FUNCTION_TABLE_iiii[$16 & 2047]($alloc,$17,4)|0);
  $19 = $10;
  _memcpy(($18|0),($19|0),($17|0))|0;
  $20 = (($6) + 4|0);
  $21 = ($18|0)==(0|0);
  if ($21) {
   $$0$i2 = 0;$25 = 0;$26 = $20;
  } else {
   $22 = $18;
   $23 = $20;
   $24 = (($22) - ($23))|0;
   $$0$i2 = $18;$25 = $24;$26 = $20;
  }
 }
 HEAP32[$26>>2] = $25;
 $27 = (($26) + 4|0);
 HEAP32[$27>>2] = $$0$i2;
 STACKTOP = sp;return ($6|0);
}
function __ZN7mecanim25DestroyValueArrayConstantEPNS_18ValueArrayConstantERNS_6memory9AllocatorE($apCst,$alloc) {
 $apCst = $apCst|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($apCst|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($apCst) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = HEAP32[$alloc>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $1;
  $8 = (($2) + ($7))|0;
  $9 = $8;
  $10 = (($apCst) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8;
  FUNCTION_TABLE_vii[$6 & 4095]($alloc,$11);
 }
 $12 = HEAP32[$alloc>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($alloc,$apCst);
 STACKTOP = sp;return;
}
function __ZN7mecanim12SetValueMaskEPNS_14ValueArrayMaskEb($valueArrayMask,$value) {
 $valueArrayMask = $valueArrayMask|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $umax = 0, $umax14 = 0, $umax15 = 0, $umax16 = 0, $umax17 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($valueArrayMask) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($valueArrayMask) + 40|0);
  $4 = $3;
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + ($4))|0;
  $7 = $6;
  $8 = $value&1;
  $9 = ($1>>>0)>(1);
  $umax17 = $9 ? $1 : 1;
  _memset(($7|0),($8|0),($umax17|0))|0;
  $10 = (($valueArrayMask) + 44|0);
  HEAP32[$10>>2] = $7;
 }
 $11 = (($valueArrayMask) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = (($valueArrayMask) + 52|0);
  $15 = $14;
  $16 = HEAP32[$14>>2]|0;
  $17 = (($16) + ($15))|0;
  $18 = $17;
  $19 = $value&1;
  $20 = ($12>>>0)>(1);
  $umax16 = $20 ? $12 : 1;
  _memset(($18|0),($19|0),($umax16|0))|0;
  $21 = (($valueArrayMask) + 56|0);
  HEAP32[$21>>2] = $18;
 }
 $22 = (($valueArrayMask) + 60|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = (($valueArrayMask) + 64|0);
  $26 = $25;
  $27 = HEAP32[$25>>2]|0;
  $28 = (($27) + ($26))|0;
  $29 = $28;
  $30 = $value&1;
  $31 = ($23>>>0)>(1);
  $umax15 = $31 ? $23 : 1;
  _memset(($29|0),($30|0),($umax15|0))|0;
  $32 = (($valueArrayMask) + 68|0);
  HEAP32[$32>>2] = $29;
 }
 $33 = (($valueArrayMask) + 24|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($valueArrayMask) + 28|0);
  $37 = $36;
  $38 = HEAP32[$36>>2]|0;
  $39 = (($38) + ($37))|0;
  $40 = $39;
  $41 = $value&1;
  $42 = ($34>>>0)>(1);
  $umax14 = $42 ? $34 : 1;
  _memset(($40|0),($41|0),($umax14|0))|0;
  $43 = (($valueArrayMask) + 32|0);
  HEAP32[$43>>2] = $40;
 }
 $44 = (($valueArrayMask) + 12|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = (($valueArrayMask) + 16|0);
 $48 = $47;
 $49 = HEAP32[$47>>2]|0;
 $50 = (($49) + ($48))|0;
 $51 = $50;
 $52 = $value&1;
 $53 = ($45>>>0)>(1);
 $umax = $53 ? $45 : 1;
 _memset(($51|0),($52|0),($umax|0))|0;
 $54 = (($valueArrayMask) + 20|0);
 HEAP32[$54>>2] = $51;
 STACKTOP = sp;return;
}
function __ZN7mecanim13CopyValueMaskEPNS_14ValueArrayMaskEPKS0_($valueArrayMask,$srcValueArrayMask) {
 $valueArrayMask = $valueArrayMask|0;
 $srcValueArrayMask = $srcValueArrayMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $i$011 = 0, $i1$09 = 0, $i2$06 = 0, $i3$03 = 0, $i4$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($valueArrayMask) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($srcValueArrayMask) + 40|0);
  $4 = $3;
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + ($4))|0;
  $7 = $6;
  $8 = (($valueArrayMask) + 40|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($10) + ($9))|0;
  $12 = $11;
  $i$011 = 0;
  while(1) {
   $27 = (($7) + ($i$011)|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = (($12) + ($i$011)|0);
   HEAP8[$29>>0] = $28;
   $30 = (($i$011) + 1)|0;
   $31 = ($30>>>0)<($1>>>0);
   if ($31) {
    $i$011 = $30;
   } else {
    break;
   }
  }
  $13 = (($valueArrayMask) + 44|0);
  HEAP32[$13>>2] = $12;
 }
 $14 = (($valueArrayMask) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = (($srcValueArrayMask) + 52|0);
  $18 = $17;
  $19 = HEAP32[$17>>2]|0;
  $20 = (($19) + ($18))|0;
  $21 = $20;
  $22 = (($valueArrayMask) + 52|0);
  $23 = $22;
  $24 = HEAP32[$22>>2]|0;
  $25 = (($24) + ($23))|0;
  $26 = $25;
  $i1$09 = 0;
  while(1) {
   $46 = (($21) + ($i1$09)|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = (($26) + ($i1$09)|0);
   HEAP8[$48>>0] = $47;
   $49 = (($i1$09) + 1)|0;
   $50 = ($49>>>0)<($15>>>0);
   if ($50) {
    $i1$09 = $49;
   } else {
    break;
   }
  }
  $32 = (($valueArrayMask) + 56|0);
  HEAP32[$32>>2] = $26;
 }
 $33 = (($valueArrayMask) + 60|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($srcValueArrayMask) + 64|0);
  $37 = $36;
  $38 = HEAP32[$36>>2]|0;
  $39 = (($38) + ($37))|0;
  $40 = $39;
  $41 = (($valueArrayMask) + 64|0);
  $42 = $41;
  $43 = HEAP32[$41>>2]|0;
  $44 = (($43) + ($42))|0;
  $45 = $44;
  $i2$06 = 0;
  while(1) {
   $65 = (($40) + ($i2$06)|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = (($45) + ($i2$06)|0);
   HEAP8[$67>>0] = $66;
   $68 = (($i2$06) + 1)|0;
   $69 = ($68>>>0)<($34>>>0);
   if ($69) {
    $i2$06 = $68;
   } else {
    break;
   }
  }
  $51 = (($valueArrayMask) + 68|0);
  HEAP32[$51>>2] = $45;
 }
 $52 = (($valueArrayMask) + 24|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0);
 if (!($54)) {
  $55 = (($srcValueArrayMask) + 28|0);
  $56 = $55;
  $57 = HEAP32[$55>>2]|0;
  $58 = (($57) + ($56))|0;
  $59 = $58;
  $60 = (($valueArrayMask) + 28|0);
  $61 = $60;
  $62 = HEAP32[$60>>2]|0;
  $63 = (($62) + ($61))|0;
  $64 = $63;
  $i3$03 = 0;
  while(1) {
   $84 = (($59) + ($i3$03)|0);
   $85 = HEAP8[$84>>0]|0;
   $86 = (($64) + ($i3$03)|0);
   HEAP8[$86>>0] = $85;
   $87 = (($i3$03) + 1)|0;
   $88 = ($87>>>0)<($53>>>0);
   if ($88) {
    $i3$03 = $87;
   } else {
    break;
   }
  }
  $70 = (($valueArrayMask) + 32|0);
  HEAP32[$70>>2] = $64;
 }
 $71 = (($valueArrayMask) + 12|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)==(0);
 if ($73) {
  STACKTOP = sp;return;
 }
 $74 = (($srcValueArrayMask) + 16|0);
 $75 = $74;
 $76 = HEAP32[$74>>2]|0;
 $77 = (($76) + ($75))|0;
 $78 = $77;
 $79 = (($valueArrayMask) + 16|0);
 $80 = $79;
 $81 = HEAP32[$79>>2]|0;
 $82 = (($81) + ($80))|0;
 $83 = $82;
 $i4$01 = 0;
 while(1) {
  $89 = (($78) + ($i4$01)|0);
  $90 = HEAP8[$89>>0]|0;
  $91 = (($83) + ($i4$01)|0);
  HEAP8[$91>>0] = $90;
  $92 = (($i4$01) + 1)|0;
  $93 = ($92>>>0)<($72>>>0);
  if ($93) {
   $i4$01 = $92;
  } else {
   break;
  }
 }
 $94 = (($valueArrayMask) + 20|0);
 HEAP32[$94>>2] = $83;
 STACKTOP = sp;return;
}
function __ZN7mecanim11OrValueMaskEPNS_14ValueArrayMaskEPKS0_($valueArrayMask,$srcValueArrayMask) {
 $valueArrayMask = $valueArrayMask|0;
 $srcValueArrayMask = $srcValueArrayMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$011 = 0, $i1$09 = 0, $i2$06 = 0, $i3$03 = 0, $i4$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($valueArrayMask) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($valueArrayMask) + 40|0);
  $4 = $3;
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + ($4))|0;
  $7 = $6;
  $8 = (($srcValueArrayMask) + 40|0);
  $9 = $8;
  $i$011 = 0;
  while(1) {
   $21 = (($7) + ($i$011)|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $24 = HEAP32[$8>>2]|0;
    $25 = (($24) + ($9))|0;
    $26 = $25;
    $27 = (($26) + ($i$011)|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28;
   } else {
    $29 = 1;
   }
   HEAP8[$21>>0] = $29;
   $30 = (($i$011) + 1)|0;
   $31 = ($30>>>0)<($1>>>0);
   if ($31) {
    $i$011 = $30;
   } else {
    break;
   }
  }
  $10 = (($valueArrayMask) + 44|0);
  HEAP32[$10>>2] = $7;
 }
 $11 = (($valueArrayMask) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = (($valueArrayMask) + 52|0);
  $15 = $14;
  $16 = HEAP32[$14>>2]|0;
  $17 = (($16) + ($15))|0;
  $18 = $17;
  $19 = (($srcValueArrayMask) + 52|0);
  $20 = $19;
  $i1$09 = 0;
  while(1) {
   $43 = (($18) + ($i1$09)|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($44<<24>>24)==(0);
   if ($45) {
    $46 = HEAP32[$19>>2]|0;
    $47 = (($46) + ($20))|0;
    $48 = $47;
    $49 = (($48) + ($i1$09)|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = $50;
   } else {
    $51 = 1;
   }
   HEAP8[$43>>0] = $51;
   $52 = (($i1$09) + 1)|0;
   $53 = ($52>>>0)<($12>>>0);
   if ($53) {
    $i1$09 = $52;
   } else {
    break;
   }
  }
  $32 = (($valueArrayMask) + 56|0);
  HEAP32[$32>>2] = $18;
 }
 $33 = (($valueArrayMask) + 60|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($valueArrayMask) + 64|0);
  $37 = $36;
  $38 = HEAP32[$36>>2]|0;
  $39 = (($38) + ($37))|0;
  $40 = $39;
  $41 = (($srcValueArrayMask) + 64|0);
  $42 = $41;
  $i2$06 = 0;
  while(1) {
   $65 = (($40) + ($i2$06)|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = ($66<<24>>24)==(0);
   if ($67) {
    $68 = HEAP32[$41>>2]|0;
    $69 = (($68) + ($42))|0;
    $70 = $69;
    $71 = (($70) + ($i2$06)|0);
    $72 = HEAP8[$71>>0]|0;
    $73 = $72;
   } else {
    $73 = 1;
   }
   HEAP8[$65>>0] = $73;
   $74 = (($i2$06) + 1)|0;
   $75 = ($74>>>0)<($34>>>0);
   if ($75) {
    $i2$06 = $74;
   } else {
    break;
   }
  }
  $54 = (($valueArrayMask) + 68|0);
  HEAP32[$54>>2] = $40;
 }
 $55 = (($valueArrayMask) + 24|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0);
 if (!($57)) {
  $58 = (($valueArrayMask) + 28|0);
  $59 = $58;
  $60 = HEAP32[$58>>2]|0;
  $61 = (($60) + ($59))|0;
  $62 = $61;
  $63 = (($srcValueArrayMask) + 28|0);
  $64 = $63;
  $i3$03 = 0;
  while(1) {
   $87 = (($62) + ($i3$03)|0);
   $88 = HEAP8[$87>>0]|0;
   $89 = ($88<<24>>24)==(0);
   if ($89) {
    $90 = HEAP32[$63>>2]|0;
    $91 = (($90) + ($64))|0;
    $92 = $91;
    $93 = (($92) + ($i3$03)|0);
    $94 = HEAP8[$93>>0]|0;
    $95 = $94;
   } else {
    $95 = 1;
   }
   HEAP8[$87>>0] = $95;
   $96 = (($i3$03) + 1)|0;
   $97 = ($96>>>0)<($56>>>0);
   if ($97) {
    $i3$03 = $96;
   } else {
    break;
   }
  }
  $76 = (($valueArrayMask) + 32|0);
  HEAP32[$76>>2] = $62;
 }
 $77 = (($valueArrayMask) + 12|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0);
 if ($79) {
  STACKTOP = sp;return;
 }
 $80 = (($valueArrayMask) + 16|0);
 $81 = $80;
 $82 = HEAP32[$80>>2]|0;
 $83 = (($82) + ($81))|0;
 $84 = $83;
 $85 = (($srcValueArrayMask) + 16|0);
 $86 = $85;
 $i4$01 = 0;
 while(1) {
  $98 = (($84) + ($i4$01)|0);
  $99 = HEAP8[$98>>0]|0;
  $100 = ($99<<24>>24)==(0);
  if ($100) {
   $101 = HEAP32[$85>>2]|0;
   $102 = (($101) + ($86))|0;
   $103 = $102;
   $104 = (($103) + ($i4$01)|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = $105;
  } else {
   $106 = 1;
  }
  HEAP8[$98>>0] = $106;
  $107 = (($i4$01) + 1)|0;
  $108 = ($107>>>0)<($78>>>0);
  if ($108) {
   $i4$01 = $107;
  } else {
   break;
  }
 }
 $109 = (($valueArrayMask) + 20|0);
 HEAP32[$109>>2] = $84;
 STACKTOP = sp;return;
}
function __ZN7mecanim12AndValueMaskEPNS_14ValueArrayMaskEPKS0_($valueArrayMask,$srcValueArrayMask) {
 $valueArrayMask = $valueArrayMask|0;
 $srcValueArrayMask = $srcValueArrayMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$011 = 0, $i1$09 = 0, $i2$06 = 0, $i3$03 = 0, $i4$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($valueArrayMask) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($valueArrayMask) + 40|0);
  $4 = $3;
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + ($4))|0;
  $7 = $6;
  $8 = (($srcValueArrayMask) + 40|0);
  $9 = $8;
  $i$011 = 0;
  while(1) {
   $21 = (($7) + ($i$011)|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $29 = 0;
   } else {
    $24 = HEAP32[$8>>2]|0;
    $25 = (($24) + ($9))|0;
    $26 = $25;
    $27 = (($26) + ($i$011)|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28;
   }
   HEAP8[$21>>0] = $29;
   $30 = (($i$011) + 1)|0;
   $31 = ($30>>>0)<($1>>>0);
   if ($31) {
    $i$011 = $30;
   } else {
    break;
   }
  }
  $10 = (($valueArrayMask) + 44|0);
  HEAP32[$10>>2] = $7;
 }
 $11 = (($valueArrayMask) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = (($valueArrayMask) + 52|0);
  $15 = $14;
  $16 = HEAP32[$14>>2]|0;
  $17 = (($16) + ($15))|0;
  $18 = $17;
  $19 = (($srcValueArrayMask) + 52|0);
  $20 = $19;
  $i1$09 = 0;
  while(1) {
   $43 = (($18) + ($i1$09)|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($44<<24>>24)==(0);
   if ($45) {
    $51 = 0;
   } else {
    $46 = HEAP32[$19>>2]|0;
    $47 = (($46) + ($20))|0;
    $48 = $47;
    $49 = (($48) + ($i1$09)|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = $50;
   }
   HEAP8[$43>>0] = $51;
   $52 = (($i1$09) + 1)|0;
   $53 = ($52>>>0)<($12>>>0);
   if ($53) {
    $i1$09 = $52;
   } else {
    break;
   }
  }
  $32 = (($valueArrayMask) + 56|0);
  HEAP32[$32>>2] = $18;
 }
 $33 = (($valueArrayMask) + 60|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = (($valueArrayMask) + 64|0);
  $37 = $36;
  $38 = HEAP32[$36>>2]|0;
  $39 = (($38) + ($37))|0;
  $40 = $39;
  $41 = (($srcValueArrayMask) + 64|0);
  $42 = $41;
  $i2$06 = 0;
  while(1) {
   $65 = (($40) + ($i2$06)|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = ($66<<24>>24)==(0);
   if ($67) {
    $73 = 0;
   } else {
    $68 = HEAP32[$41>>2]|0;
    $69 = (($68) + ($42))|0;
    $70 = $69;
    $71 = (($70) + ($i2$06)|0);
    $72 = HEAP8[$71>>0]|0;
    $73 = $72;
   }
   HEAP8[$65>>0] = $73;
   $74 = (($i2$06) + 1)|0;
   $75 = ($74>>>0)<($34>>>0);
   if ($75) {
    $i2$06 = $74;
   } else {
    break;
   }
  }
  $54 = (($valueArrayMask) + 68|0);
  HEAP32[$54>>2] = $40;
 }
 $55 = (($valueArrayMask) + 24|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0);
 if (!($57)) {
  $58 = (($valueArrayMask) + 28|0);
  $59 = $58;
  $60 = HEAP32[$58>>2]|0;
  $61 = (($60) + ($59))|0;
  $62 = $61;
  $63 = (($srcValueArrayMask) + 28|0);
  $64 = $63;
  $i3$03 = 0;
  while(1) {
   $87 = (($62) + ($i3$03)|0);
   $88 = HEAP8[$87>>0]|0;
   $89 = ($88<<24>>24)==(0);
   if ($89) {
    $95 = 0;
   } else {
    $90 = HEAP32[$63>>2]|0;
    $91 = (($90) + ($64))|0;
    $92 = $91;
    $93 = (($92) + ($i3$03)|0);
    $94 = HEAP8[$93>>0]|0;
    $95 = $94;
   }
   HEAP8[$87>>0] = $95;
   $96 = (($i3$03) + 1)|0;
   $97 = ($96>>>0)<($56>>>0);
   if ($97) {
    $i3$03 = $96;
   } else {
    break;
   }
  }
  $76 = (($valueArrayMask) + 32|0);
  HEAP32[$76>>2] = $62;
 }
 $77 = (($valueArrayMask) + 12|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0);
 if ($79) {
  STACKTOP = sp;return;
 }
 $80 = (($valueArrayMask) + 16|0);
 $81 = $80;
 $82 = HEAP32[$80>>2]|0;
 $83 = (($82) + ($81))|0;
 $84 = $83;
 $85 = (($srcValueArrayMask) + 16|0);
 $86 = $85;
 $i4$01 = 0;
 while(1) {
  $98 = (($84) + ($i4$01)|0);
  $99 = HEAP8[$98>>0]|0;
  $100 = ($99<<24>>24)==(0);
  if ($100) {
   $106 = 0;
  } else {
   $101 = HEAP32[$85>>2]|0;
   $102 = (($101) + ($86))|0;
   $103 = $102;
   $104 = (($103) + ($i4$01)|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = $105;
  }
  HEAP8[$98>>0] = $106;
  $107 = (($i4$01) + 1)|0;
  $108 = ($107>>>0)<($78>>>0);
  if ($108) {
   $i4$01 = $107;
  } else {
   break;
  }
 }
 $109 = (($valueArrayMask) + 20|0);
 HEAP32[$109>>2] = $84;
 STACKTOP = sp;return;
}
function __ZN7mecanim15InvertValueMaskEPNS_14ValueArrayMaskE($valueArrayMask) {
 $valueArrayMask = $valueArrayMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $i$011 = 0, $i1$09 = 0, $i2$06 = 0, $i3$03 = 0, $i4$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($valueArrayMask) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($valueArrayMask) + 40|0);
  $4 = $3;
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + ($4))|0;
  $7 = $6;
  $i$011 = 0;
  while(1) {
   $17 = (($7) + ($i$011)|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = $18 ^ 1;
   HEAP8[$17>>0] = $19;
   $20 = (($i$011) + 1)|0;
   $21 = ($20>>>0)<($1>>>0);
   if ($21) {
    $i$011 = $20;
   } else {
    break;
   }
  }
  $8 = (($valueArrayMask) + 44|0);
  HEAP32[$8>>2] = $7;
 }
 $9 = (($valueArrayMask) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = (($valueArrayMask) + 52|0);
  $13 = $12;
  $14 = HEAP32[$12>>2]|0;
  $15 = (($14) + ($13))|0;
  $16 = $15;
  $i1$09 = 0;
  while(1) {
   $31 = (($16) + ($i1$09)|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32 ^ 1;
   HEAP8[$31>>0] = $33;
   $34 = (($i1$09) + 1)|0;
   $35 = ($34>>>0)<($10>>>0);
   if ($35) {
    $i1$09 = $34;
   } else {
    break;
   }
  }
  $22 = (($valueArrayMask) + 56|0);
  HEAP32[$22>>2] = $16;
 }
 $23 = (($valueArrayMask) + 60|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0);
 if (!($25)) {
  $26 = (($valueArrayMask) + 64|0);
  $27 = $26;
  $28 = HEAP32[$26>>2]|0;
  $29 = (($28) + ($27))|0;
  $30 = $29;
  $i2$06 = 0;
  while(1) {
   $45 = (($30) + ($i2$06)|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = $46 ^ 1;
   HEAP8[$45>>0] = $47;
   $48 = (($i2$06) + 1)|0;
   $49 = ($48>>>0)<($24>>>0);
   if ($49) {
    $i2$06 = $48;
   } else {
    break;
   }
  }
  $36 = (($valueArrayMask) + 68|0);
  HEAP32[$36>>2] = $30;
 }
 $37 = (($valueArrayMask) + 24|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0);
 if (!($39)) {
  $40 = (($valueArrayMask) + 28|0);
  $41 = $40;
  $42 = HEAP32[$40>>2]|0;
  $43 = (($42) + ($41))|0;
  $44 = $43;
  $i3$03 = 0;
  while(1) {
   $59 = (($44) + ($i3$03)|0);
   $60 = HEAP8[$59>>0]|0;
   $61 = $60 ^ 1;
   HEAP8[$59>>0] = $61;
   $62 = (($i3$03) + 1)|0;
   $63 = ($62>>>0)<($38>>>0);
   if ($63) {
    $i3$03 = $62;
   } else {
    break;
   }
  }
  $50 = (($valueArrayMask) + 32|0);
  HEAP32[$50>>2] = $44;
 }
 $51 = (($valueArrayMask) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)==(0);
 if ($53) {
  STACKTOP = sp;return;
 }
 $54 = (($valueArrayMask) + 16|0);
 $55 = $54;
 $56 = HEAP32[$54>>2]|0;
 $57 = (($56) + ($55))|0;
 $58 = $57;
 $i4$01 = 0;
 while(1) {
  $64 = (($58) + ($i4$01)|0);
  $65 = HEAP8[$64>>0]|0;
  $66 = $65 ^ 1;
  HEAP8[$64>>0] = $66;
  $67 = (($i4$01) + 1)|0;
  $68 = ($67>>>0)<($52>>>0);
  if ($68) {
   $i4$01 = $67;
  } else {
   break;
  }
 }
 $69 = (($valueArrayMask) + 20|0);
 HEAP32[$69>>2] = $58;
 STACKTOP = sp;return;
}
function __ZN7mecanim20CreateValueArrayMaskEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($constant,$alloc) {
 $constant = $constant|0;
 $alloc = $alloc|0;
 var $$0$i1018 = 0, $$0$i1519 = 0, $$0$i22 = 0, $$0$i321 = 0, $$0$i720 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$023 = 0, $umax$i = 0, $umax14$i = 0, $umax15$i = 0, $umax16$i = 0, $umax17$i = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,72,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $6 = 0;
 } else {
  dest=$2+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $6 = $2;
 }
 $4 = HEAP32[$constant>>2]|0;
 $5 = ($4|0)==(0);
 L4: do {
  if ($5) {
   $$pre = (($6) + 12|0);
   $$pre$phiZ2D = $$pre;
  } else {
   $7 = (($constant) + 4|0);
   $8 = $7;
   $9 = (($6) + 36|0);
   $10 = (($6) + 48|0);
   $11 = (($6) + 60|0);
   $12 = (($6) + 24|0);
   $13 = (($6) + 12|0);
   $i$023 = 0;
   while(1) {
    $14 = HEAP32[$7>>2]|0;
    $15 = (($14) + ($8))|0;
    $16 = $15;
    $17 = ((($16) + ($i$023<<4)|0) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    switch ($18|0) {
    case 6:  {
     $19 = HEAP32[$9>>2]|0;
     $20 = (($19) + 1)|0;
     HEAP32[$9>>2] = $20;
     break;
    }
    case 7:  {
     $21 = HEAP32[$10>>2]|0;
     $22 = (($21) + 1)|0;
     HEAP32[$10>>2] = $22;
     break;
    }
    case 1:  {
     $25 = HEAP32[$12>>2]|0;
     $26 = (($25) + 1)|0;
     HEAP32[$12>>2] = $26;
     break;
    }
    case 3:  {
     $27 = HEAP32[$13>>2]|0;
     $28 = (($27) + 1)|0;
     HEAP32[$13>>2] = $28;
     break;
    }
    case 8:  {
     $23 = HEAP32[$11>>2]|0;
     $24 = (($23) + 1)|0;
     HEAP32[$11>>2] = $24;
     break;
    }
    default: {
    }
    }
    $29 = (($i$023) + 1)|0;
    $30 = HEAP32[$constant>>2]|0;
    $31 = ($29>>>0)<($30>>>0);
    if ($31) {
     $i$023 = $29;
    } else {
     $$pre$phiZ2D = $13;
     break L4;
    }
   }
  }
 } while(0);
 $32 = HEAP32[$$pre$phiZ2D>>2]|0;
 $33 = ($32|0)==(0);
 if ($33) {
  $34 = (($6) + 16|0);
  $$0$i1018 = 0;$43 = 0;$44 = $34;
 } else {
  $35 = HEAP32[$alloc>>2]|0;
  $36 = HEAP32[$35>>2]|0;
  $37 = (FUNCTION_TABLE_iiii[$36 & 2047]($alloc,$32,1)|0);
  $38 = (($6) + 16|0);
  $39 = ($37|0)==(0|0);
  if ($39) {
   $$0$i1018 = 0;$43 = 0;$44 = $38;
  } else {
   $40 = $37;
   $41 = $38;
   $42 = (($40) - ($41))|0;
   $$0$i1018 = $37;$43 = $42;$44 = $38;
  }
 }
 HEAP32[$44>>2] = $43;
 $45 = (($44) + 4|0);
 HEAP32[$45>>2] = $$0$i1018;
 $46 = (($6) + 24|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0);
 if ($48) {
  $49 = (($6) + 28|0);
  $$0$i1519 = 0;$58 = 0;$59 = $49;
 } else {
  $50 = HEAP32[$alloc>>2]|0;
  $51 = HEAP32[$50>>2]|0;
  $52 = (FUNCTION_TABLE_iiii[$51 & 2047]($alloc,$47,1)|0);
  $53 = (($6) + 28|0);
  $54 = ($52|0)==(0|0);
  if ($54) {
   $$0$i1519 = 0;$58 = 0;$59 = $53;
  } else {
   $55 = $52;
   $56 = $53;
   $57 = (($55) - ($56))|0;
   $$0$i1519 = $52;$58 = $57;$59 = $53;
  }
 }
 HEAP32[$59>>2] = $58;
 $60 = (($59) + 4|0);
 HEAP32[$60>>2] = $$0$i1519;
 $61 = (($6) + 36|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  $64 = (($6) + 40|0);
  $$0$i720 = 0;$73 = 0;$74 = $64;
 } else {
  $65 = HEAP32[$alloc>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = (FUNCTION_TABLE_iiii[$66 & 2047]($alloc,$62,1)|0);
  $68 = (($6) + 40|0);
  $69 = ($67|0)==(0|0);
  if ($69) {
   $$0$i720 = 0;$73 = 0;$74 = $68;
  } else {
   $70 = $67;
   $71 = $68;
   $72 = (($70) - ($71))|0;
   $$0$i720 = $67;$73 = $72;$74 = $68;
  }
 }
 HEAP32[$74>>2] = $73;
 $75 = (($74) + 4|0);
 HEAP32[$75>>2] = $$0$i720;
 $76 = (($6) + 48|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0);
 if ($78) {
  $79 = (($6) + 52|0);
  $$0$i321 = 0;$88 = 0;$89 = $79;
 } else {
  $80 = HEAP32[$alloc>>2]|0;
  $81 = HEAP32[$80>>2]|0;
  $82 = (FUNCTION_TABLE_iiii[$81 & 2047]($alloc,$77,1)|0);
  $83 = (($6) + 52|0);
  $84 = ($82|0)==(0|0);
  if ($84) {
   $$0$i321 = 0;$88 = 0;$89 = $83;
  } else {
   $85 = $82;
   $86 = $83;
   $87 = (($85) - ($86))|0;
   $$0$i321 = $82;$88 = $87;$89 = $83;
  }
 }
 HEAP32[$89>>2] = $88;
 $90 = (($89) + 4|0);
 HEAP32[$90>>2] = $$0$i321;
 $91 = (($6) + 60|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(0);
 if ($93) {
  $94 = (($6) + 64|0);
  $$0$i22 = 0;$103 = 0;$104 = $94;
 } else {
  $95 = HEAP32[$alloc>>2]|0;
  $96 = HEAP32[$95>>2]|0;
  $97 = (FUNCTION_TABLE_iiii[$96 & 2047]($alloc,$92,1)|0);
  $98 = (($6) + 64|0);
  $99 = ($97|0)==(0|0);
  if ($99) {
   $$0$i22 = 0;$103 = 0;$104 = $98;
  } else {
   $100 = $97;
   $101 = $98;
   $102 = (($100) - ($101))|0;
   $$0$i22 = $97;$103 = $102;$104 = $98;
  }
 }
 HEAP32[$104>>2] = $103;
 $105 = (($104) + 4|0);
 HEAP32[$105>>2] = $$0$i22;
 $106 = HEAP32[$61>>2]|0;
 $107 = ($106|0)==(0);
 if (!($107)) {
  $108 = $74;
  $109 = HEAP32[$74>>2]|0;
  $110 = (($109) + ($108))|0;
  $111 = $110;
  $112 = ($106>>>0)>(1);
  $umax17$i = $112 ? $106 : 1;
  _memset(($111|0),0,($umax17$i|0))|0;
  $113 = (($6) + 44|0);
  HEAP32[$113>>2] = $111;
 }
 $114 = HEAP32[$76>>2]|0;
 $115 = ($114|0)==(0);
 if (!($115)) {
  $116 = $89;
  $117 = HEAP32[$89>>2]|0;
  $118 = (($117) + ($116))|0;
  $119 = $118;
  $120 = ($114>>>0)>(1);
  $umax16$i = $120 ? $114 : 1;
  _memset(($119|0),0,($umax16$i|0))|0;
  $121 = (($6) + 56|0);
  HEAP32[$121>>2] = $119;
 }
 $122 = HEAP32[$91>>2]|0;
 $123 = ($122|0)==(0);
 if (!($123)) {
  $124 = $104;
  $125 = HEAP32[$104>>2]|0;
  $126 = (($125) + ($124))|0;
  $127 = $126;
  $128 = ($122>>>0)>(1);
  $umax15$i = $128 ? $122 : 1;
  _memset(($127|0),0,($umax15$i|0))|0;
  $129 = (($6) + 68|0);
  HEAP32[$129>>2] = $127;
 }
 $130 = HEAP32[$46>>2]|0;
 $131 = ($130|0)==(0);
 if (!($131)) {
  $132 = $59;
  $133 = HEAP32[$59>>2]|0;
  $134 = (($133) + ($132))|0;
  $135 = $134;
  $136 = ($130>>>0)>(1);
  $umax14$i = $136 ? $130 : 1;
  _memset(($135|0),0,($umax14$i|0))|0;
  $137 = (($6) + 32|0);
  HEAP32[$137>>2] = $135;
 }
 $138 = HEAP32[$$pre$phiZ2D>>2]|0;
 $139 = ($138|0)==(0);
 if ($139) {
  STACKTOP = sp;return ($6|0);
 }
 $140 = $44;
 $141 = HEAP32[$44>>2]|0;
 $142 = (($141) + ($140))|0;
 $143 = $142;
 $144 = ($138>>>0)>(1);
 $umax$i = $144 ? $138 : 1;
 _memset(($143|0),0,($umax$i|0))|0;
 $145 = (($6) + 20|0);
 HEAP32[$145>>2] = $143;
 STACKTOP = sp;return ($6|0);
}
function __ZN7mecanim21DestroyValueArrayMaskEPNS_14ValueArrayMaskERNS_6memory9AllocatorE($valueArrayMask,$alloc) {
 $valueArrayMask = $valueArrayMask|0;
 $alloc = $alloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($valueArrayMask|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($valueArrayMask) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = HEAP32[$alloc>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $1;
  $8 = (($2) + ($7))|0;
  $9 = $8;
  $10 = (($valueArrayMask) + 20|0);
  HEAP32[$10>>2] = $9;
  FUNCTION_TABLE_vii[$6 & 4095]($alloc,$9);
 }
 $11 = (($valueArrayMask) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = HEAP32[$alloc>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $11;
  $18 = (($12) + ($17))|0;
  $19 = $18;
  $20 = (($valueArrayMask) + 32|0);
  HEAP32[$20>>2] = $19;
  FUNCTION_TABLE_vii[$16 & 4095]($alloc,$19);
 }
 $21 = (($valueArrayMask) + 40|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if (!($23)) {
  $24 = HEAP32[$alloc>>2]|0;
  $25 = (($24) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $21;
  $28 = (($22) + ($27))|0;
  $29 = $28;
  $30 = (($valueArrayMask) + 44|0);
  HEAP32[$30>>2] = $29;
  FUNCTION_TABLE_vii[$26 & 4095]($alloc,$29);
 }
 $31 = (($valueArrayMask) + 52|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $34 = HEAP32[$alloc>>2]|0;
  $35 = (($34) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = $31;
  $38 = (($32) + ($37))|0;
  $39 = $38;
  $40 = (($valueArrayMask) + 56|0);
  HEAP32[$40>>2] = $39;
  FUNCTION_TABLE_vii[$36 & 4095]($alloc,$39);
 }
 $41 = (($valueArrayMask) + 64|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if (!($43)) {
  $44 = HEAP32[$alloc>>2]|0;
  $45 = (($44) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $41;
  $48 = (($42) + ($47))|0;
  $49 = $48;
  $50 = (($valueArrayMask) + 68|0);
  HEAP32[$50>>2] = $49;
  FUNCTION_TABLE_vii[$46 & 4095]($alloc,$49);
 }
 $51 = HEAP32[$alloc>>2]|0;
 $52 = (($51) + 4|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_vii[$53 & 4095]($alloc,$valueArrayMask);
 STACKTOP = sp;return;
}
function __ZN7mecanim16CreateValueArrayEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE($apValueArrayConstant,$alloc) {
 $apValueArrayConstant = $apValueArrayConstant|0;
 $alloc = $alloc|0;
 var $$0$i1226 = 0, $$0$i1428 = 0, $$0$i1627 = 0, $$0$i31 = 0, $$0$i430 = 0, $$0$i929 = 0, $$op = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $i$047 = 0, $i$243 = 0, $i$437 = 0, $i$534 = 0, $i$632 = 0, $umax50 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$alloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($alloc,72,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $9 = 0;
 } else {
  dest=$2+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $9 = $2;
 }
 $4 = HEAP32[$apValueArrayConstant>>2]|0;
 $5 = ($4|0)==(0);
 L4: do {
  if ($5) {
   $$pre$phiZ2D = $9;
  } else {
   $6 = (($apValueArrayConstant) + 4|0);
   $7 = $6;
   $8 = (($9) + 36|0);
   $10 = (($9) + 48|0);
   $11 = (($9) + 60|0);
   $12 = (($9) + 24|0);
   $13 = (($9) + 12|0);
   $i$047 = 0;
   while(1) {
    $14 = HEAP32[$6>>2]|0;
    $15 = (($14) + ($7))|0;
    $16 = $15;
    $17 = ((($16) + ($i$047<<4)|0) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    switch ($18|0) {
    case 7:  {
     $21 = HEAP32[$10>>2]|0;
     $22 = (($21) + 1)|0;
     HEAP32[$10>>2] = $22;
     break;
    }
    case 3:  {
     $27 = HEAP32[$13>>2]|0;
     $28 = (($27) + 1)|0;
     HEAP32[$13>>2] = $28;
     break;
    }
    case 4: case 9:  {
     $29 = HEAP32[$9>>2]|0;
     $30 = (($29) + 1)|0;
     HEAP32[$9>>2] = $30;
     break;
    }
    case 6:  {
     $19 = HEAP32[$8>>2]|0;
     $20 = (($19) + 1)|0;
     HEAP32[$8>>2] = $20;
     break;
    }
    case 1:  {
     $25 = HEAP32[$12>>2]|0;
     $26 = (($25) + 1)|0;
     HEAP32[$12>>2] = $26;
     break;
    }
    case 8:  {
     $23 = HEAP32[$11>>2]|0;
     $24 = (($23) + 1)|0;
     HEAP32[$11>>2] = $24;
     break;
    }
    default: {
    }
    }
    $31 = (($i$047) + 1)|0;
    $32 = HEAP32[$apValueArrayConstant>>2]|0;
    $33 = ($31>>>0)<($32>>>0);
    if ($33) {
     $i$047 = $31;
    } else {
     $$pre$phiZ2D = $9;
     break L4;
    }
   }
  }
 } while(0);
 $34 = (($9) + 4|0);
 $35 = HEAP32[$$pre$phiZ2D>>2]|0;
 $36 = ($35|0)==(0);
 if ($36) {
  $$0$i1226 = 0;$44 = 0;
 } else {
  $37 = HEAP32[$alloc>>2]|0;
  $38 = HEAP32[$37>>2]|0;
  $39 = (FUNCTION_TABLE_iiii[$38 & 2047]($alloc,$35,1)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   $$0$i1226 = 0;$44 = 0;
  } else {
   $41 = $39;
   $42 = $34;
   $43 = (($41) - ($42))|0;
   $$0$i1226 = $39;$44 = $43;
  }
 }
 HEAP32[$34>>2] = $44;
 $45 = (($9) + 8|0);
 HEAP32[$45>>2] = $$0$i1226;
 $46 = (($9) + 16|0);
 $47 = (($9) + 12|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)==(0);
 if ($49) {
  $$0$i1627 = 0;$58 = 0;
 } else {
  $50 = HEAP32[$alloc>>2]|0;
  $51 = HEAP32[$50>>2]|0;
  $52 = $48 << 2;
  $53 = (FUNCTION_TABLE_iiii[$51 & 2047]($alloc,$52,4)|0);
  $54 = ($53|0)==(0|0);
  if ($54) {
   $$0$i1627 = 0;$58 = 0;
  } else {
   $55 = $53;
   $56 = $46;
   $57 = (($55) - ($56))|0;
   $$0$i1627 = $53;$58 = $57;
  }
 }
 HEAP32[$46>>2] = $58;
 $59 = (($9) + 20|0);
 HEAP32[$59>>2] = $$0$i1627;
 $60 = (($9) + 28|0);
 $61 = (($9) + 24|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  $$0$i1428 = 0;$72 = 0;
 } else {
  $64 = HEAP32[$alloc>>2]|0;
  $65 = HEAP32[$64>>2]|0;
  $66 = $62 << 2;
  $67 = (FUNCTION_TABLE_iiii[$65 & 2047]($alloc,$66,4)|0);
  $68 = ($67|0)==(0|0);
  if ($68) {
   $$0$i1428 = 0;$72 = 0;
  } else {
   $69 = $67;
   $70 = $60;
   $71 = (($69) - ($70))|0;
   $$0$i1428 = $67;$72 = $71;
  }
 }
 HEAP32[$60>>2] = $72;
 $73 = (($9) + 32|0);
 HEAP32[$73>>2] = $$0$i1428;
 $74 = (($9) + 40|0);
 $75 = (($9) + 36|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0);
 if ($77) {
  $$0$i929 = 0;$86 = 0;
 } else {
  $78 = HEAP32[$alloc>>2]|0;
  $79 = HEAP32[$78>>2]|0;
  $80 = $76 << 4;
  $81 = (FUNCTION_TABLE_iiii[$79 & 2047]($alloc,$80,4)|0);
  $82 = ($81|0)==(0|0);
  if ($82) {
   $$0$i929 = 0;$86 = 0;
  } else {
   $83 = $81;
   $84 = $74;
   $85 = (($83) - ($84))|0;
   $$0$i929 = $81;$86 = $85;
  }
 }
 HEAP32[$74>>2] = $86;
 $87 = (($9) + 44|0);
 HEAP32[$87>>2] = $$0$i929;
 $88 = (($9) + 52|0);
 $89 = (($9) + 48|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($90|0)==(0);
 if ($91) {
  $$0$i430 = 0;$100 = 0;
 } else {
  $92 = HEAP32[$alloc>>2]|0;
  $93 = HEAP32[$92>>2]|0;
  $94 = $90 << 4;
  $95 = (FUNCTION_TABLE_iiii[$93 & 2047]($alloc,$94,4)|0);
  $96 = ($95|0)==(0|0);
  if ($96) {
   $$0$i430 = 0;$100 = 0;
  } else {
   $97 = $95;
   $98 = $88;
   $99 = (($97) - ($98))|0;
   $$0$i430 = $95;$100 = $99;
  }
 }
 HEAP32[$88>>2] = $100;
 $101 = (($9) + 56|0);
 HEAP32[$101>>2] = $$0$i430;
 $102 = (($9) + 64|0);
 $103 = (($9) + 60|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = ($104|0)==(0);
 if ($105) {
  $$0$i31 = 0;$114 = 0;
 } else {
  $106 = HEAP32[$alloc>>2]|0;
  $107 = HEAP32[$106>>2]|0;
  $108 = $104 << 4;
  $109 = (FUNCTION_TABLE_iiii[$107 & 2047]($alloc,$108,4)|0);
  $110 = ($109|0)==(0|0);
  if ($110) {
   $$0$i31 = 0;$114 = 0;
  } else {
   $111 = $109;
   $112 = $102;
   $113 = (($111) - ($112))|0;
   $$0$i31 = $109;$114 = $113;
  }
 }
 HEAP32[$102>>2] = $114;
 $115 = (($9) + 68|0);
 HEAP32[$115>>2] = $$0$i31;
 $116 = HEAP32[$$pre$phiZ2D>>2]|0;
 $117 = ($116|0)==(0);
 if (!($117)) {
  $118 = $34;
  $119 = HEAP32[$34>>2]|0;
  $120 = (($119) + ($118))|0;
  $121 = $120;
  $122 = ($116>>>0)>(1);
  $umax50 = $122 ? $116 : 1;
  _memset(($121|0),0,($umax50|0))|0;
  HEAP32[$45>>2] = $121;
 }
 $123 = HEAP32[$47>>2]|0;
 $124 = ($123|0)==(0);
 if (!($124)) {
  $125 = $46;
  $i$243 = 0;
  while(1) {
   $136 = HEAP32[$46>>2]|0;
   $137 = (($136) + ($125))|0;
   $126 = $137;
   $138 = (($126) + ($i$243<<2)|0);
   HEAP32[$138>>2] = 0;
   $139 = (($i$243) + 1)|0;
   $140 = HEAP32[$47>>2]|0;
   $141 = ($139>>>0)<($140>>>0);
   if ($141) {
    $i$243 = $139;
   } else {
    break;
   }
  }
  HEAP32[$59>>2] = $126;
 }
 $127 = HEAP32[$61>>2]|0;
 $128 = ($127|0)==(0);
 if (!($128)) {
  $129 = $60;
  $130 = HEAP32[$60>>2]|0;
  $131 = (($130) + ($129))|0;
  $132 = $131;
  $133 = $131;
  $134 = ($127>>>0)>(1);
  $$op = $127 << 2;
  $135 = $134 ? $$op : 4;
  _memset(($133|0),0,($135|0))|0;
  HEAP32[$73>>2] = $132;
 }
 $142 = HEAP32[$75>>2]|0;
 $143 = ($142|0)==(0);
 if (!($143)) {
  $144 = $74;
  $145 = HEAP32[$74>>2]|0;
  $146 = (($145) + ($144))|0;
  $147 = $146;
  $i$437 = 0;
  while(1) {
   $154 = (($147) + ($i$437<<4)|0);
   $155 = (($i$437) + 1)|0;
   $156 = ($155>>>0)<($142>>>0);
   ;HEAP32[$154+0>>2]=0|0;HEAP32[$154+4>>2]=0|0;HEAP32[$154+8>>2]=0|0;HEAP32[$154+12>>2]=0|0;
   if ($156) {
    $i$437 = $155;
   } else {
    break;
   }
  }
  HEAP32[$87>>2] = $147;
 }
 $148 = HEAP32[$89>>2]|0;
 $149 = ($148|0)==(0);
 if (!($149)) {
  $150 = $88;
  $151 = HEAP32[$88>>2]|0;
  $152 = (($151) + ($150))|0;
  $153 = $152;
  $i$534 = 0;
  while(1) {
   $163 = (($153) + ($i$534<<4)|0);
   HEAPF32[$163>>2] = Math_fround(0.0);
   $164 = ((($153) + ($i$534<<4)|0) + 4|0);
   HEAPF32[$164>>2] = Math_fround(0.0);
   $165 = ((($153) + ($i$534<<4)|0) + 8|0);
   HEAPF32[$165>>2] = Math_fround(0.0);
   $166 = ((($153) + ($i$534<<4)|0) + 12|0);
   HEAPF32[$166>>2] = Math_fround(1.0);
   $167 = (($i$534) + 1)|0;
   $168 = ($167>>>0)<($148>>>0);
   if ($168) {
    $i$534 = $167;
   } else {
    break;
   }
  }
  HEAP32[$101>>2] = $153;
 }
 $157 = HEAP32[$103>>2]|0;
 $158 = ($157|0)==(0);
 if ($158) {
  STACKTOP = sp;return ($9|0);
 }
 $159 = $102;
 $160 = HEAP32[$102>>2]|0;
 $161 = (($160) + ($159))|0;
 $162 = $161;
 $i$632 = 0;
 while(1) {
  $169 = (($162) + ($i$632<<4)|0);
  HEAPF32[$169>>2] = Math_fround(1.0);
  $170 = ((($162) + ($i$632<<4)|0) + 4|0);
  HEAPF32[$170>>2] = Math_fround(1.0);
  $171 = ((($162) + ($i$632<<4)|0) + 8|0);
  HEAPF32[$171>>2] = Math_fround(1.0);
  $172 = ((($162) + ($i$632<<4)|0) + 12|0);
  HEAPF32[$172>>2] = Math_fround(1.0);
  $173 = (($i$632) + 1)|0;
  $174 = ($173>>>0)<($157>>>0);
  if ($174) {
   $i$632 = $173;
  } else {
   break;
  }
 }
 HEAP32[$115>>2] = $162;
 STACKTOP = sp;return ($9|0);
}
function __ZN7mecanim17DestroyValueArrayEPNS_10ValueArrayERNS_6memory9AllocatorE($apInput,$alloc) {
 $apInput = $apInput|0;
 $alloc = $alloc|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($apInput|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($apInput) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = HEAP32[$alloc>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $1;
  $8 = (($2) + ($7))|0;
  $9 = $8;
  $10 = (($apInput) + 8|0);
  HEAP32[$10>>2] = $9;
  FUNCTION_TABLE_vii[$6 & 4095]($alloc,$9);
 }
 $11 = (($apInput) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0);
 if (!($13)) {
  $14 = HEAP32[$alloc>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $11;
  $18 = (($12) + ($17))|0;
  $19 = $18;
  $20 = (($apInput) + 20|0);
  HEAP32[$20>>2] = $19;
  $21 = $18;
  FUNCTION_TABLE_vii[$16 & 4095]($alloc,$21);
 }
 $22 = (($apInput) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = HEAP32[$alloc>>2]|0;
  $26 = (($25) + 4|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $22;
  $29 = (($23) + ($28))|0;
  $30 = $29;
  $31 = (($apInput) + 32|0);
  HEAP32[$31>>2] = $30;
  $32 = $29;
  FUNCTION_TABLE_vii[$27 & 4095]($alloc,$32);
 }
 $33 = (($apInput) + 40|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if (!($35)) {
  $36 = $33;
  $37 = (($34) + ($36))|0;
  $38 = $37;
  $39 = (($apInput) + 44|0);
  HEAP32[$39>>2] = $38;
  $40 = $37;
  $41 = HEAP32[$alloc>>2]|0;
  $42 = (($41) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  FUNCTION_TABLE_vii[$43 & 4095]($alloc,$40);
 }
 $44 = (($apInput) + 52|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = $44;
  $48 = (($45) + ($47))|0;
  $49 = $48;
  $50 = (($apInput) + 56|0);
  HEAP32[$50>>2] = $49;
  $51 = $48;
  $52 = HEAP32[$alloc>>2]|0;
  $53 = (($52) + 4|0);
  $54 = HEAP32[$53>>2]|0;
  FUNCTION_TABLE_vii[$54 & 4095]($alloc,$51);
 }
 $55 = (($apInput) + 64|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0);
 if ($57) {
  $$pre$phiZ2D = $alloc;
 } else {
  $58 = $55;
  $59 = (($56) + ($58))|0;
  $60 = $59;
  $61 = (($apInput) + 68|0);
  HEAP32[$61>>2] = $60;
  $62 = $59;
  $63 = HEAP32[$alloc>>2]|0;
  $64 = (($63) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  FUNCTION_TABLE_vii[$65 & 4095]($alloc,$62);
  $$pre$phiZ2D = $alloc;
 }
 $66 = HEAP32[$$pre$phiZ2D>>2]|0;
 $67 = (($66) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 FUNCTION_TABLE_vii[$68 & 4095]($alloc,$apInput);
 STACKTOP = sp;return;
}
function __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_($apSourceValueArray,$apDestinationValueArray) {
 $apSourceValueArray = $apSourceValueArray|0;
 $apDestinationValueArray = $apDestinationValueArray|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i14 = 0, $exitcond$i18 = 0, $exitcond$i22 = 0, $exitcond$i4 = 0, $exitcond$i9 = 0, $i$01$i = 0, $i$01$i13 = 0, $i$01$i17 = 0, $i$01$i21 = 0, $i$01$i3 = 0, $i$01$i8 = 0, $umax$i = 0;
 var $umax$i1 = 0, $umax$i11 = 0, $umax$i15 = 0, $umax$i19 = 0, $umax$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apSourceValueArray) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($apSourceValueArray) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = (($apDestinationValueArray) + 4|0);
 $7 = $6;
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + ($7))|0;
 $10 = $9;
 $11 = (($apDestinationValueArray) + 8|0);
 HEAP32[$11>>2] = $10;
 $12 = HEAP32[$apSourceValueArray>>2]|0;
 $13 = HEAP32[$apDestinationValueArray>>2]|0;
 $14 = ($12>>>0)<($13>>>0);
 $15 = $14 ? $12 : $13;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = $13 ^ -1;
  $18 = $12 ^ -1;
  $19 = ($17>>>0)>($18>>>0);
  $umax$i19 = $19 ? $17 : $18;
  $20 = $umax$i19 ^ -1;
  $i$01$i21 = 0;
  while(1) {
   $21 = (($4) + ($i$01$i21)|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = (($10) + ($i$01$i21)|0);
   HEAP8[$23>>0] = $22;
   $24 = (($i$01$i21) + 1)|0;
   $exitcond$i22 = ($24|0)==($20|0);
   if ($exitcond$i22) {
    break;
   } else {
    $i$01$i21 = $24;
   }
  }
 }
 $25 = (($apSourceValueArray) + 16|0);
 $26 = $25;
 $27 = HEAP32[$25>>2]|0;
 $28 = (($27) + ($26))|0;
 $29 = $28;
 $30 = (($apSourceValueArray) + 20|0);
 HEAP32[$30>>2] = $29;
 $31 = (($apDestinationValueArray) + 16|0);
 $32 = $31;
 $33 = HEAP32[$31>>2]|0;
 $34 = (($33) + ($32))|0;
 $35 = $34;
 $36 = (($apDestinationValueArray) + 20|0);
 HEAP32[$36>>2] = $35;
 $37 = (($apSourceValueArray) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($apDestinationValueArray) + 12|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($38>>>0)<($40>>>0);
 $42 = $41 ? $38 : $40;
 $43 = ($42|0)==(0);
 if (!($43)) {
  $44 = $40 ^ -1;
  $45 = $38 ^ -1;
  $46 = ($44>>>0)>($45>>>0);
  $umax$i15 = $46 ? $44 : $45;
  $47 = $umax$i15 ^ -1;
  $i$01$i17 = 0;
  while(1) {
   $48 = (($29) + ($i$01$i17<<2)|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($35) + ($i$01$i17<<2)|0);
   HEAP32[$50>>2] = $49;
   $51 = (($i$01$i17) + 1)|0;
   $exitcond$i18 = ($51|0)==($47|0);
   if ($exitcond$i18) {
    break;
   } else {
    $i$01$i17 = $51;
   }
  }
 }
 $52 = (($apSourceValueArray) + 28|0);
 $53 = $52;
 $54 = HEAP32[$52>>2]|0;
 $55 = (($54) + ($53))|0;
 $56 = $55;
 $57 = (($apSourceValueArray) + 32|0);
 HEAP32[$57>>2] = $56;
 $58 = (($apDestinationValueArray) + 28|0);
 $59 = $58;
 $60 = HEAP32[$58>>2]|0;
 $61 = (($60) + ($59))|0;
 $62 = $61;
 $63 = (($apDestinationValueArray) + 32|0);
 HEAP32[$63>>2] = $62;
 $64 = (($apSourceValueArray) + 24|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($apDestinationValueArray) + 24|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($65>>>0)<($67>>>0);
 $69 = $68 ? $65 : $67;
 $70 = ($69|0)==(0);
 if (!($70)) {
  $71 = $67 ^ -1;
  $72 = $65 ^ -1;
  $73 = ($71>>>0)>($72>>>0);
  $umax$i11 = $73 ? $71 : $72;
  $74 = $umax$i11 ^ -1;
  $i$01$i13 = 0;
  while(1) {
   $75 = (($56) + ($i$01$i13<<2)|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = (($62) + ($i$01$i13<<2)|0);
   HEAPF32[$77>>2] = $76;
   $78 = (($i$01$i13) + 1)|0;
   $exitcond$i14 = ($78|0)==($74|0);
   if ($exitcond$i14) {
    break;
   } else {
    $i$01$i13 = $78;
   }
  }
 }
 $79 = (($apSourceValueArray) + 40|0);
 $80 = $79;
 $81 = HEAP32[$79>>2]|0;
 $82 = (($81) + ($80))|0;
 $83 = $82;
 $84 = (($apSourceValueArray) + 44|0);
 HEAP32[$84>>2] = $83;
 $85 = (($apDestinationValueArray) + 40|0);
 $86 = $85;
 $87 = HEAP32[$85>>2]|0;
 $88 = (($87) + ($86))|0;
 $89 = $88;
 $90 = (($apDestinationValueArray) + 44|0);
 HEAP32[$90>>2] = $89;
 $91 = (($apSourceValueArray) + 36|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = (($apDestinationValueArray) + 36|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ($92>>>0)<($94>>>0);
 $96 = $95 ? $92 : $94;
 $97 = ($96|0)==(0);
 if (!($97)) {
  $98 = $94 ^ -1;
  $99 = $92 ^ -1;
  $100 = ($98>>>0)>($99>>>0);
  $umax$i6 = $100 ? $98 : $99;
  $101 = $umax$i6 ^ -1;
  $i$01$i8 = 0;
  while(1) {
   $102 = (($83) + ($i$01$i8<<4)|0);
   $103 = Math_fround(HEAPF32[$102>>2]);
   $104 = ((($83) + ($i$01$i8<<4)|0) + 4|0);
   $105 = Math_fround(HEAPF32[$104>>2]);
   $106 = ((($83) + ($i$01$i8<<4)|0) + 8|0);
   $107 = Math_fround(HEAPF32[$106>>2]);
   $108 = ((($83) + ($i$01$i8<<4)|0) + 12|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = (($89) + ($i$01$i8<<4)|0);
   HEAPF32[$110>>2] = $103;
   $111 = ((($89) + ($i$01$i8<<4)|0) + 4|0);
   HEAPF32[$111>>2] = $105;
   $112 = ((($89) + ($i$01$i8<<4)|0) + 8|0);
   HEAPF32[$112>>2] = $107;
   $113 = ((($89) + ($i$01$i8<<4)|0) + 12|0);
   HEAPF32[$113>>2] = $109;
   $114 = (($i$01$i8) + 1)|0;
   $exitcond$i9 = ($114|0)==($101|0);
   if ($exitcond$i9) {
    break;
   } else {
    $i$01$i8 = $114;
   }
  }
 }
 $115 = (($apSourceValueArray) + 52|0);
 $116 = $115;
 $117 = HEAP32[$115>>2]|0;
 $118 = (($117) + ($116))|0;
 $119 = $118;
 $120 = (($apSourceValueArray) + 56|0);
 HEAP32[$120>>2] = $119;
 $121 = (($apDestinationValueArray) + 52|0);
 $122 = $121;
 $123 = HEAP32[$121>>2]|0;
 $124 = (($123) + ($122))|0;
 $125 = $124;
 $126 = (($apDestinationValueArray) + 56|0);
 HEAP32[$126>>2] = $125;
 $127 = (($apSourceValueArray) + 48|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = (($apDestinationValueArray) + 48|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($128>>>0)<($130>>>0);
 $132 = $131 ? $128 : $130;
 $133 = ($132|0)==(0);
 if (!($133)) {
  $134 = $130 ^ -1;
  $135 = $128 ^ -1;
  $136 = ($134>>>0)>($135>>>0);
  $umax$i1 = $136 ? $134 : $135;
  $137 = $umax$i1 ^ -1;
  $i$01$i3 = 0;
  while(1) {
   $138 = (($119) + ($i$01$i3<<4)|0);
   $139 = Math_fround(HEAPF32[$138>>2]);
   $140 = ((($119) + ($i$01$i3<<4)|0) + 4|0);
   $141 = Math_fround(HEAPF32[$140>>2]);
   $142 = ((($119) + ($i$01$i3<<4)|0) + 8|0);
   $143 = Math_fround(HEAPF32[$142>>2]);
   $144 = ((($119) + ($i$01$i3<<4)|0) + 12|0);
   $145 = Math_fround(HEAPF32[$144>>2]);
   $146 = (($125) + ($i$01$i3<<4)|0);
   HEAPF32[$146>>2] = $139;
   $147 = ((($125) + ($i$01$i3<<4)|0) + 4|0);
   HEAPF32[$147>>2] = $141;
   $148 = ((($125) + ($i$01$i3<<4)|0) + 8|0);
   HEAPF32[$148>>2] = $143;
   $149 = ((($125) + ($i$01$i3<<4)|0) + 12|0);
   HEAPF32[$149>>2] = $145;
   $150 = (($i$01$i3) + 1)|0;
   $exitcond$i4 = ($150|0)==($137|0);
   if ($exitcond$i4) {
    break;
   } else {
    $i$01$i3 = $150;
   }
  }
 }
 $151 = (($apSourceValueArray) + 64|0);
 $152 = $151;
 $153 = HEAP32[$151>>2]|0;
 $154 = (($153) + ($152))|0;
 $155 = $154;
 $156 = (($apSourceValueArray) + 68|0);
 HEAP32[$156>>2] = $155;
 $157 = (($apDestinationValueArray) + 64|0);
 $158 = $157;
 $159 = HEAP32[$157>>2]|0;
 $160 = (($159) + ($158))|0;
 $161 = $160;
 $162 = (($apDestinationValueArray) + 68|0);
 HEAP32[$162>>2] = $161;
 $163 = (($apSourceValueArray) + 60|0);
 $164 = HEAP32[$163>>2]|0;
 $165 = (($apDestinationValueArray) + 60|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = ($164>>>0)<($166>>>0);
 $168 = $167 ? $164 : $166;
 $169 = ($168|0)==(0);
 if ($169) {
  STACKTOP = sp;return;
 }
 $170 = $166 ^ -1;
 $171 = $164 ^ -1;
 $172 = ($170>>>0)>($171>>>0);
 $umax$i = $172 ? $170 : $171;
 $173 = $umax$i ^ -1;
 $i$01$i = 0;
 while(1) {
  $174 = (($155) + ($i$01$i<<4)|0);
  $175 = Math_fround(HEAPF32[$174>>2]);
  $176 = ((($155) + ($i$01$i<<4)|0) + 4|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = ((($155) + ($i$01$i<<4)|0) + 8|0);
  $179 = Math_fround(HEAPF32[$178>>2]);
  $180 = ((($155) + ($i$01$i<<4)|0) + 12|0);
  $181 = Math_fround(HEAPF32[$180>>2]);
  $182 = (($161) + ($i$01$i<<4)|0);
  HEAPF32[$182>>2] = $175;
  $183 = ((($161) + ($i$01$i<<4)|0) + 4|0);
  HEAPF32[$183>>2] = $177;
  $184 = ((($161) + ($i$01$i<<4)|0) + 8|0);
  HEAPF32[$184>>2] = $179;
  $185 = ((($161) + ($i$01$i<<4)|0) + 12|0);
  HEAPF32[$185>>2] = $181;
  $186 = (($i$01$i) + 1)|0;
  $exitcond$i = ($186|0)==($173|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $186;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim14ValueArrayCopyEPKNS_18ValueArrayConstantEPKNS_10ValueArrayES2_PS3_PKi($sourceConstant,$source,$destinationConstant,$destination,$destinationInSourceIndexArray) {
 $sourceConstant = $sourceConstant|0;
 $source = $source|0;
 $destinationConstant = $destinationConstant|0;
 $destination = $destination|0;
 $destinationInSourceIndexArray = $destinationInSourceIndexArray|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dstIter$01 = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$destinationConstant>>2]|0;
 $1 = ($0|0)>(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (($sourceConstant) + 4|0);
 $3 = $2;
 $4 = (($destinationConstant) + 4|0);
 $5 = $4;
 $6 = (($source) + 40|0);
 $7 = $6;
 $8 = (($destination) + 40|0);
 $9 = $8;
 $10 = (($destination) + 44|0);
 $11 = (($source) + 52|0);
 $12 = $11;
 $13 = (($destination) + 52|0);
 $14 = $13;
 $15 = (($destination) + 56|0);
 $16 = (($source) + 64|0);
 $17 = $16;
 $18 = (($destination) + 64|0);
 $19 = $18;
 $20 = (($destination) + 68|0);
 $21 = (($source) + 28|0);
 $22 = $21;
 $23 = (($destination) + 28|0);
 $24 = $23;
 $25 = (($destination) + 32|0);
 $26 = (($source) + 16|0);
 $27 = $26;
 $28 = (($destination) + 16|0);
 $29 = $28;
 $30 = (($destination) + 20|0);
 $31 = (($source) + 4|0);
 $32 = $31;
 $33 = (($destination) + 4|0);
 $34 = $33;
 $35 = (($destination) + 8|0);
 $dstIter$01 = 0;
 while(1) {
  $36 = (($destinationInSourceIndexArray) + ($dstIter$01<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(-1);
  L6: do {
   if (!($38)) {
    $39 = HEAP32[$2>>2]|0;
    $40 = (($39) + ($3))|0;
    $41 = $40;
    $42 = ((($41) + ($37<<4)|0) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$4>>2]|0;
    $45 = (($44) + ($5))|0;
    $46 = $45;
    $47 = ((($46) + ($dstIter$01<<4)|0) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($43|0)==($48|0);
    if ($49) {
     switch ($43|0) {
     case 1:  {
      $116 = ((($41) + ($37<<4)|0) + 12|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = HEAP32[$21>>2]|0;
      $119 = (($118) + ($22))|0;
      $120 = $119;
      $121 = (($120) + ($117<<2)|0);
      $122 = Math_fround(HEAPF32[$121>>2]);
      $123 = ((($46) + ($dstIter$01<<4)|0) + 12|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = HEAP32[$23>>2]|0;
      $126 = (($125) + ($24))|0;
      $127 = $126;
      HEAP32[$25>>2] = $127;
      $128 = (($127) + ($124<<2)|0);
      HEAPF32[$128>>2] = $122;
      break L6;
      break;
     }
     case 4: case 9:  {
      $142 = ((($41) + ($37<<4)|0) + 12|0);
      $143 = HEAP32[$142>>2]|0;
      $144 = HEAP32[$31>>2]|0;
      $145 = (($144) + ($32))|0;
      $146 = $145;
      $147 = (($146) + ($143)|0);
      $148 = HEAP8[$147>>0]|0;
      $149 = ((($46) + ($dstIter$01<<4)|0) + 12|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = HEAP32[$33>>2]|0;
      $152 = (($151) + ($34))|0;
      $153 = $152;
      HEAP32[$35>>2] = $153;
      $154 = (($153) + ($150)|0);
      HEAP8[$154>>0] = $148;
      break L6;
      break;
     }
     case 3:  {
      $129 = ((($41) + ($37<<4)|0) + 12|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = HEAP32[$26>>2]|0;
      $132 = (($131) + ($27))|0;
      $133 = $132;
      $134 = (($133) + ($130<<2)|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ((($46) + ($dstIter$01<<4)|0) + 12|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = HEAP32[$28>>2]|0;
      $139 = (($138) + ($29))|0;
      $140 = $139;
      HEAP32[$30>>2] = $140;
      $141 = (($140) + ($137<<2)|0);
      HEAP32[$141>>2] = $135;
      break L6;
      break;
     }
     case 7:  {
      $72 = ((($41) + ($37<<4)|0) + 12|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = HEAP32[$11>>2]|0;
      $75 = (($74) + ($12))|0;
      $76 = $75;
      $77 = (($76) + ($73<<4)|0);
      $78 = Math_fround(HEAPF32[$77>>2]);
      $79 = ((($76) + ($73<<4)|0) + 4|0);
      $80 = Math_fround(HEAPF32[$79>>2]);
      $81 = ((($76) + ($73<<4)|0) + 8|0);
      $82 = Math_fround(HEAPF32[$81>>2]);
      $83 = ((($76) + ($73<<4)|0) + 12|0);
      $84 = Math_fround(HEAPF32[$83>>2]);
      $85 = ((($46) + ($dstIter$01<<4)|0) + 12|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = HEAP32[$13>>2]|0;
      $88 = (($87) + ($14))|0;
      $89 = $88;
      HEAP32[$15>>2] = $89;
      $90 = (($89) + ($86<<4)|0);
      HEAPF32[$90>>2] = $78;
      $91 = ((($89) + ($86<<4)|0) + 4|0);
      HEAPF32[$91>>2] = $80;
      $92 = ((($89) + ($86<<4)|0) + 8|0);
      HEAPF32[$92>>2] = $82;
      $93 = ((($89) + ($86<<4)|0) + 12|0);
      HEAPF32[$93>>2] = $84;
      break L6;
      break;
     }
     case 8:  {
      $94 = ((($41) + ($37<<4)|0) + 12|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = HEAP32[$16>>2]|0;
      $97 = (($96) + ($17))|0;
      $98 = $97;
      $99 = (($98) + ($95<<4)|0);
      $100 = Math_fround(HEAPF32[$99>>2]);
      $101 = ((($98) + ($95<<4)|0) + 4|0);
      $102 = Math_fround(HEAPF32[$101>>2]);
      $103 = ((($98) + ($95<<4)|0) + 8|0);
      $104 = Math_fround(HEAPF32[$103>>2]);
      $105 = ((($98) + ($95<<4)|0) + 12|0);
      $106 = Math_fround(HEAPF32[$105>>2]);
      $107 = ((($46) + ($dstIter$01<<4)|0) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = HEAP32[$18>>2]|0;
      $110 = (($109) + ($19))|0;
      $111 = $110;
      HEAP32[$20>>2] = $111;
      $112 = (($111) + ($108<<4)|0);
      HEAPF32[$112>>2] = $100;
      $113 = ((($111) + ($108<<4)|0) + 4|0);
      HEAPF32[$113>>2] = $102;
      $114 = ((($111) + ($108<<4)|0) + 8|0);
      HEAPF32[$114>>2] = $104;
      $115 = ((($111) + ($108<<4)|0) + 12|0);
      HEAPF32[$115>>2] = $106;
      break L6;
      break;
     }
     case 6:  {
      $50 = ((($41) + ($37<<4)|0) + 12|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = HEAP32[$6>>2]|0;
      $53 = (($52) + ($7))|0;
      $54 = $53;
      $55 = (($54) + ($51<<4)|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      $57 = ((($54) + ($51<<4)|0) + 4|0);
      $58 = Math_fround(HEAPF32[$57>>2]);
      $59 = ((($54) + ($51<<4)|0) + 8|0);
      $60 = Math_fround(HEAPF32[$59>>2]);
      $61 = ((($54) + ($51<<4)|0) + 12|0);
      $62 = Math_fround(HEAPF32[$61>>2]);
      $63 = ((($46) + ($dstIter$01<<4)|0) + 12|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = HEAP32[$8>>2]|0;
      $66 = (($65) + ($9))|0;
      $67 = $66;
      HEAP32[$10>>2] = $67;
      $68 = (($67) + ($64<<4)|0);
      HEAPF32[$68>>2] = $56;
      $69 = ((($67) + ($64<<4)|0) + 4|0);
      HEAPF32[$69>>2] = $58;
      $70 = ((($67) + ($64<<4)|0) + 8|0);
      HEAPF32[$70>>2] = $60;
      $71 = ((($67) + ($64<<4)|0) + 12|0);
      HEAPF32[$71>>2] = $62;
      break L6;
      break;
     }
     default: {
      break L6;
     }
     }
    }
   }
  } while(0);
  $155 = (($dstIter$01) + 1)|0;
  $exitcond = ($155|0)==($0|0);
  if ($exitcond) {
   break;
  } else {
   $dstIter$01 = $155;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim21ValueArrayReverseCopyEPKNS_18ValueArrayConstantEPKNS_10ValueArrayES2_PS3_PKi($sourceConstant,$source,$destinationConstant,$destination,$sourceInDestinationIndexArray) {
 $sourceConstant = $sourceConstant|0;
 $source = $source|0;
 $destinationConstant = $destinationConstant|0;
 $destination = $destination|0;
 $sourceInDestinationIndexArray = $sourceInDestinationIndexArray|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0);
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $srcIter$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$sourceConstant>>2]|0;
 $1 = ($0|0)>(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (($sourceConstant) + 4|0);
 $3 = $2;
 $4 = (($destinationConstant) + 4|0);
 $5 = $4;
 $6 = (($source) + 40|0);
 $7 = $6;
 $8 = (($destination) + 40|0);
 $9 = $8;
 $10 = (($destination) + 44|0);
 $11 = (($source) + 52|0);
 $12 = $11;
 $13 = (($destination) + 52|0);
 $14 = $13;
 $15 = (($destination) + 56|0);
 $16 = (($source) + 64|0);
 $17 = $16;
 $18 = (($destination) + 64|0);
 $19 = $18;
 $20 = (($destination) + 68|0);
 $21 = (($source) + 28|0);
 $22 = $21;
 $23 = (($destination) + 28|0);
 $24 = $23;
 $25 = (($destination) + 32|0);
 $26 = (($source) + 16|0);
 $27 = $26;
 $28 = (($destination) + 16|0);
 $29 = $28;
 $30 = (($destination) + 20|0);
 $31 = (($source) + 4|0);
 $32 = $31;
 $33 = (($destination) + 4|0);
 $34 = $33;
 $35 = (($destination) + 8|0);
 $srcIter$01 = 0;
 while(1) {
  $36 = (($sourceInDestinationIndexArray) + ($srcIter$01<<2)|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(-1);
  L6: do {
   if (!($38)) {
    $39 = HEAP32[$2>>2]|0;
    $40 = (($39) + ($3))|0;
    $41 = $40;
    $42 = ((($41) + ($srcIter$01<<4)|0) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$4>>2]|0;
    $45 = (($44) + ($5))|0;
    $46 = $45;
    $47 = ((($46) + ($37<<4)|0) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($43|0)==($48|0);
    if ($49) {
     switch ($43|0) {
     case 8:  {
      $94 = ((($41) + ($srcIter$01<<4)|0) + 12|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = HEAP32[$16>>2]|0;
      $97 = (($96) + ($17))|0;
      $98 = $97;
      $99 = (($98) + ($95<<4)|0);
      $100 = Math_fround(HEAPF32[$99>>2]);
      $101 = ((($98) + ($95<<4)|0) + 4|0);
      $102 = Math_fround(HEAPF32[$101>>2]);
      $103 = ((($98) + ($95<<4)|0) + 8|0);
      $104 = Math_fround(HEAPF32[$103>>2]);
      $105 = ((($98) + ($95<<4)|0) + 12|0);
      $106 = Math_fround(HEAPF32[$105>>2]);
      $107 = ((($46) + ($37<<4)|0) + 12|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = HEAP32[$18>>2]|0;
      $110 = (($109) + ($19))|0;
      $111 = $110;
      HEAP32[$20>>2] = $111;
      $112 = (($111) + ($108<<4)|0);
      HEAPF32[$112>>2] = $100;
      $113 = ((($111) + ($108<<4)|0) + 4|0);
      HEAPF32[$113>>2] = $102;
      $114 = ((($111) + ($108<<4)|0) + 8|0);
      HEAPF32[$114>>2] = $104;
      $115 = ((($111) + ($108<<4)|0) + 12|0);
      HEAPF32[$115>>2] = $106;
      break L6;
      break;
     }
     case 7:  {
      $72 = ((($41) + ($srcIter$01<<4)|0) + 12|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = HEAP32[$11>>2]|0;
      $75 = (($74) + ($12))|0;
      $76 = $75;
      $77 = (($76) + ($73<<4)|0);
      $78 = Math_fround(HEAPF32[$77>>2]);
      $79 = ((($76) + ($73<<4)|0) + 4|0);
      $80 = Math_fround(HEAPF32[$79>>2]);
      $81 = ((($76) + ($73<<4)|0) + 8|0);
      $82 = Math_fround(HEAPF32[$81>>2]);
      $83 = ((($76) + ($73<<4)|0) + 12|0);
      $84 = Math_fround(HEAPF32[$83>>2]);
      $85 = ((($46) + ($37<<4)|0) + 12|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = HEAP32[$13>>2]|0;
      $88 = (($87) + ($14))|0;
      $89 = $88;
      HEAP32[$15>>2] = $89;
      $90 = (($89) + ($86<<4)|0);
      HEAPF32[$90>>2] = $78;
      $91 = ((($89) + ($86<<4)|0) + 4|0);
      HEAPF32[$91>>2] = $80;
      $92 = ((($89) + ($86<<4)|0) + 8|0);
      HEAPF32[$92>>2] = $82;
      $93 = ((($89) + ($86<<4)|0) + 12|0);
      HEAPF32[$93>>2] = $84;
      break L6;
      break;
     }
     case 3:  {
      $129 = ((($41) + ($srcIter$01<<4)|0) + 12|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = HEAP32[$26>>2]|0;
      $132 = (($131) + ($27))|0;
      $133 = $132;
      $134 = (($133) + ($130<<2)|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ((($46) + ($37<<4)|0) + 12|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = HEAP32[$28>>2]|0;
      $139 = (($138) + ($29))|0;
      $140 = $139;
      HEAP32[$30>>2] = $140;
      $141 = (($140) + ($137<<2)|0);
      HEAP32[$141>>2] = $135;
      break L6;
      break;
     }
     case 4: case 9:  {
      $142 = ((($41) + ($srcIter$01<<4)|0) + 12|0);
      $143 = HEAP32[$142>>2]|0;
      $144 = HEAP32[$31>>2]|0;
      $145 = (($144) + ($32))|0;
      $146 = $145;
      $147 = (($146) + ($143)|0);
      $148 = HEAP8[$147>>0]|0;
      $149 = ((($46) + ($37<<4)|0) + 12|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = HEAP32[$33>>2]|0;
      $152 = (($151) + ($34))|0;
      $153 = $152;
      HEAP32[$35>>2] = $153;
      $154 = (($153) + ($150)|0);
      HEAP8[$154>>0] = $148;
      break L6;
      break;
     }
     case 6:  {
      $50 = ((($41) + ($srcIter$01<<4)|0) + 12|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = HEAP32[$6>>2]|0;
      $53 = (($52) + ($7))|0;
      $54 = $53;
      $55 = (($54) + ($51<<4)|0);
      $56 = Math_fround(HEAPF32[$55>>2]);
      $57 = ((($54) + ($51<<4)|0) + 4|0);
      $58 = Math_fround(HEAPF32[$57>>2]);
      $59 = ((($54) + ($51<<4)|0) + 8|0);
      $60 = Math_fround(HEAPF32[$59>>2]);
      $61 = ((($54) + ($51<<4)|0) + 12|0);
      $62 = Math_fround(HEAPF32[$61>>2]);
      $63 = ((($46) + ($37<<4)|0) + 12|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = HEAP32[$8>>2]|0;
      $66 = (($65) + ($9))|0;
      $67 = $66;
      HEAP32[$10>>2] = $67;
      $68 = (($67) + ($64<<4)|0);
      HEAPF32[$68>>2] = $56;
      $69 = ((($67) + ($64<<4)|0) + 4|0);
      HEAPF32[$69>>2] = $58;
      $70 = ((($67) + ($64<<4)|0) + 8|0);
      HEAPF32[$70>>2] = $60;
      $71 = ((($67) + ($64<<4)|0) + 12|0);
      HEAPF32[$71>>2] = $62;
      break L6;
      break;
     }
     case 1:  {
      $116 = ((($41) + ($srcIter$01<<4)|0) + 12|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = HEAP32[$21>>2]|0;
      $119 = (($118) + ($22))|0;
      $120 = $119;
      $121 = (($120) + ($117<<2)|0);
      $122 = Math_fround(HEAPF32[$121>>2]);
      $123 = ((($46) + ($37<<4)|0) + 12|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = HEAP32[$23>>2]|0;
      $126 = (($125) + ($24))|0;
      $127 = $126;
      HEAP32[$25>>2] = $127;
      $128 = (($127) + ($124<<2)|0);
      HEAPF32[$128>>2] = $122;
      break L6;
      break;
     }
     default: {
      break L6;
     }
     }
    }
   }
  } while(0);
  $155 = (($srcIter$01) + 1)|0;
  $exitcond = ($155|0)==($0|0);
  if ($exitcond) {
   break;
  } else {
   $srcIter$01 = $155;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim14ValueArrayCopyEPKNS_10ValueArrayEPS0_PKNS_14ValueArrayMaskE($aSource,$aValues,$mask) {
 $aSource = $aSource|0;
 $aValues = $aValues|0;
 $mask = $mask|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0);
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0);
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $exitcond$i = 0, $exitcond$i12 = 0, $exitcond$i16 = 0, $exitcond$i3 = 0, $exitcond$i6 = 0, $exitcond$i9 = 0;
 var $i$01$i = 0, $i$01$i1 = 0, $i$01$i10 = 0, $i$01$i14 = 0, $i$01$i4 = 0, $i$01$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($aSource) + 40|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($aSource) + 44|0);
 HEAP32[$5>>2] = $4;
 $6 = (($aValues) + 40|0);
 $7 = $6;
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + ($7))|0;
 $10 = $9;
 $11 = (($aValues) + 44|0);
 HEAP32[$11>>2] = $10;
 $12 = (($mask) + 40|0);
 $13 = $12;
 $14 = HEAP32[$12>>2]|0;
 $15 = (($14) + ($13))|0;
 $16 = $15;
 $17 = (($mask) + 44|0);
 HEAP32[$17>>2] = $16;
 $18 = (($aValues) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $i$01$i14 = 0;
  while(1) {
   $21 = (($16) + ($i$01$i14)|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)==(0);
   if (!($23)) {
    $24 = (($4) + ($i$01$i14<<4)|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = ((($4) + ($i$01$i14<<4)|0) + 4|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = ((($4) + ($i$01$i14<<4)|0) + 8|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = ((($4) + ($i$01$i14<<4)|0) + 12|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = (($10) + ($i$01$i14<<4)|0);
    HEAPF32[$32>>2] = $25;
    $33 = ((($10) + ($i$01$i14<<4)|0) + 4|0);
    HEAPF32[$33>>2] = $27;
    $34 = ((($10) + ($i$01$i14<<4)|0) + 8|0);
    HEAPF32[$34>>2] = $29;
    $35 = ((($10) + ($i$01$i14<<4)|0) + 12|0);
    HEAPF32[$35>>2] = $31;
   }
   $36 = (($i$01$i14) + 1)|0;
   $exitcond$i16 = ($36|0)==($19|0);
   if ($exitcond$i16) {
    break;
   } else {
    $i$01$i14 = $36;
   }
  }
 }
 $37 = (($aSource) + 52|0);
 $38 = $37;
 $39 = HEAP32[$37>>2]|0;
 $40 = (($39) + ($38))|0;
 $41 = $40;
 $42 = (($aSource) + 56|0);
 HEAP32[$42>>2] = $41;
 $43 = (($aValues) + 52|0);
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($aValues) + 56|0);
 HEAP32[$48>>2] = $47;
 $49 = (($mask) + 52|0);
 $50 = $49;
 $51 = HEAP32[$49>>2]|0;
 $52 = (($51) + ($50))|0;
 $53 = $52;
 $54 = (($mask) + 56|0);
 HEAP32[$54>>2] = $53;
 $55 = (($aValues) + 48|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0);
 if (!($57)) {
  $i$01$i10 = 0;
  while(1) {
   $58 = (($53) + ($i$01$i10)|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = ($59<<24>>24)==(0);
   if (!($60)) {
    $61 = (($41) + ($i$01$i10<<4)|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = ((($41) + ($i$01$i10<<4)|0) + 4|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = ((($41) + ($i$01$i10<<4)|0) + 8|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($41) + ($i$01$i10<<4)|0) + 12|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = (($47) + ($i$01$i10<<4)|0);
    HEAPF32[$69>>2] = $62;
    $70 = ((($47) + ($i$01$i10<<4)|0) + 4|0);
    HEAPF32[$70>>2] = $64;
    $71 = ((($47) + ($i$01$i10<<4)|0) + 8|0);
    HEAPF32[$71>>2] = $66;
    $72 = ((($47) + ($i$01$i10<<4)|0) + 12|0);
    HEAPF32[$72>>2] = $68;
   }
   $73 = (($i$01$i10) + 1)|0;
   $exitcond$i12 = ($73|0)==($56|0);
   if ($exitcond$i12) {
    break;
   } else {
    $i$01$i10 = $73;
   }
  }
 }
 $74 = (($aSource) + 64|0);
 $75 = $74;
 $76 = HEAP32[$74>>2]|0;
 $77 = (($76) + ($75))|0;
 $78 = $77;
 $79 = (($aSource) + 68|0);
 HEAP32[$79>>2] = $78;
 $80 = (($aValues) + 64|0);
 $81 = $80;
 $82 = HEAP32[$80>>2]|0;
 $83 = (($82) + ($81))|0;
 $84 = $83;
 $85 = (($aValues) + 68|0);
 HEAP32[$85>>2] = $84;
 $86 = (($mask) + 64|0);
 $87 = $86;
 $88 = HEAP32[$86>>2]|0;
 $89 = (($88) + ($87))|0;
 $90 = $89;
 $91 = (($mask) + 68|0);
 HEAP32[$91>>2] = $90;
 $92 = (($aValues) + 60|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==(0);
 if (!($94)) {
  $i$01$i7 = 0;
  while(1) {
   $95 = (($90) + ($i$01$i7)|0);
   $96 = HEAP8[$95>>0]|0;
   $97 = ($96<<24>>24)==(0);
   if (!($97)) {
    $98 = (($78) + ($i$01$i7<<4)|0);
    $99 = Math_fround(HEAPF32[$98>>2]);
    $100 = ((($78) + ($i$01$i7<<4)|0) + 4|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = ((($78) + ($i$01$i7<<4)|0) + 8|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = ((($78) + ($i$01$i7<<4)|0) + 12|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = (($84) + ($i$01$i7<<4)|0);
    HEAPF32[$106>>2] = $99;
    $107 = ((($84) + ($i$01$i7<<4)|0) + 4|0);
    HEAPF32[$107>>2] = $101;
    $108 = ((($84) + ($i$01$i7<<4)|0) + 8|0);
    HEAPF32[$108>>2] = $103;
    $109 = ((($84) + ($i$01$i7<<4)|0) + 12|0);
    HEAPF32[$109>>2] = $105;
   }
   $110 = (($i$01$i7) + 1)|0;
   $exitcond$i9 = ($110|0)==($93|0);
   if ($exitcond$i9) {
    break;
   } else {
    $i$01$i7 = $110;
   }
  }
 }
 $111 = (($aSource) + 28|0);
 $112 = $111;
 $113 = HEAP32[$111>>2]|0;
 $114 = (($113) + ($112))|0;
 $115 = $114;
 $116 = (($aSource) + 32|0);
 HEAP32[$116>>2] = $115;
 $117 = (($aValues) + 28|0);
 $118 = $117;
 $119 = HEAP32[$117>>2]|0;
 $120 = (($119) + ($118))|0;
 $121 = $120;
 $122 = (($aValues) + 32|0);
 HEAP32[$122>>2] = $121;
 $123 = (($mask) + 28|0);
 $124 = $123;
 $125 = HEAP32[$123>>2]|0;
 $126 = (($125) + ($124))|0;
 $127 = $126;
 $128 = (($mask) + 32|0);
 HEAP32[$128>>2] = $127;
 $129 = (($aValues) + 24|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($130|0)==(0);
 if (!($131)) {
  $i$01$i4 = 0;
  while(1) {
   $132 = (($127) + ($i$01$i4)|0);
   $133 = HEAP8[$132>>0]|0;
   $134 = ($133<<24>>24)==(0);
   if (!($134)) {
    $135 = (($115) + ($i$01$i4<<2)|0);
    $136 = Math_fround(HEAPF32[$135>>2]);
    $137 = (($121) + ($i$01$i4<<2)|0);
    HEAPF32[$137>>2] = $136;
   }
   $138 = (($i$01$i4) + 1)|0;
   $exitcond$i6 = ($138|0)==($130|0);
   if ($exitcond$i6) {
    break;
   } else {
    $i$01$i4 = $138;
   }
  }
 }
 $139 = (($aSource) + 16|0);
 $140 = $139;
 $141 = HEAP32[$139>>2]|0;
 $142 = (($141) + ($140))|0;
 $143 = $142;
 $144 = (($aSource) + 20|0);
 HEAP32[$144>>2] = $143;
 $145 = (($aValues) + 16|0);
 $146 = $145;
 $147 = HEAP32[$145>>2]|0;
 $148 = (($147) + ($146))|0;
 $149 = $148;
 $150 = (($aValues) + 20|0);
 HEAP32[$150>>2] = $149;
 $151 = (($mask) + 16|0);
 $152 = $151;
 $153 = HEAP32[$151>>2]|0;
 $154 = (($153) + ($152))|0;
 $155 = $154;
 $156 = (($mask) + 20|0);
 HEAP32[$156>>2] = $155;
 $157 = (($aValues) + 12|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = ($158|0)==(0);
 if (!($159)) {
  $i$01$i1 = 0;
  while(1) {
   $160 = (($155) + ($i$01$i1)|0);
   $161 = HEAP8[$160>>0]|0;
   $162 = ($161<<24>>24)==(0);
   if (!($162)) {
    $163 = (($143) + ($i$01$i1<<2)|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = (($149) + ($i$01$i1<<2)|0);
    HEAP32[$165>>2] = $164;
   }
   $166 = (($i$01$i1) + 1)|0;
   $exitcond$i3 = ($166|0)==($158|0);
   if ($exitcond$i3) {
    break;
   } else {
    $i$01$i1 = $166;
   }
  }
 }
 $167 = (($aSource) + 4|0);
 $168 = $167;
 $169 = HEAP32[$167>>2]|0;
 $170 = (($169) + ($168))|0;
 $171 = $170;
 $172 = (($aSource) + 8|0);
 HEAP32[$172>>2] = $171;
 $173 = (($aValues) + 4|0);
 $174 = $173;
 $175 = HEAP32[$173>>2]|0;
 $176 = (($175) + ($174))|0;
 $177 = $176;
 $178 = (($aValues) + 8|0);
 HEAP32[$178>>2] = $177;
 $179 = (($mask) + 4|0);
 $180 = $179;
 $181 = HEAP32[$179>>2]|0;
 $182 = (($181) + ($180))|0;
 $183 = $182;
 $184 = (($mask) + 8|0);
 HEAP32[$184>>2] = $183;
 $185 = HEAP32[$aValues>>2]|0;
 $186 = ($185|0)==(0);
 if ($186) {
  STACKTOP = sp;return;
 } else {
  $i$01$i = 0;
 }
 while(1) {
  $187 = (($183) + ($i$01$i)|0);
  $188 = HEAP8[$187>>0]|0;
  $189 = ($188<<24>>24)==(0);
  if (!($189)) {
   $190 = (($171) + ($i$01$i)|0);
   $191 = HEAP8[$190>>0]|0;
   $192 = (($177) + ($i$01$i)|0);
   HEAP8[$192>>0] = $191;
  }
  $193 = (($i$01$i) + 1)|0;
  $exitcond$i = ($193|0)==($185|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $193;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim25ValueArrayCopyInverseMaskEPKNS_10ValueArrayEPS0_PKNS_14ValueArrayMaskE($aSource,$aValues,$mask) {
 $aSource = $aSource|0;
 $aValues = $aValues|0;
 $mask = $mask|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0);
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0);
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $exitcond$i = 0, $exitcond$i12 = 0, $exitcond$i16 = 0, $exitcond$i3 = 0, $exitcond$i6 = 0, $exitcond$i9 = 0;
 var $i$01$i = 0, $i$01$i1 = 0, $i$01$i10 = 0, $i$01$i14 = 0, $i$01$i4 = 0, $i$01$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($aSource) + 40|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($aSource) + 44|0);
 HEAP32[$5>>2] = $4;
 $6 = (($aValues) + 40|0);
 $7 = $6;
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + ($7))|0;
 $10 = $9;
 $11 = (($aValues) + 44|0);
 HEAP32[$11>>2] = $10;
 $12 = (($mask) + 40|0);
 $13 = $12;
 $14 = HEAP32[$12>>2]|0;
 $15 = (($14) + ($13))|0;
 $16 = $15;
 $17 = (($mask) + 44|0);
 HEAP32[$17>>2] = $16;
 $18 = (($aValues) + 36|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $i$01$i14 = 0;
  while(1) {
   $21 = (($16) + ($i$01$i14)|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $24 = (($4) + ($i$01$i14<<4)|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = ((($4) + ($i$01$i14<<4)|0) + 4|0);
    $27 = Math_fround(HEAPF32[$26>>2]);
    $28 = ((($4) + ($i$01$i14<<4)|0) + 8|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = ((($4) + ($i$01$i14<<4)|0) + 12|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = (($10) + ($i$01$i14<<4)|0);
    HEAPF32[$32>>2] = $25;
    $33 = ((($10) + ($i$01$i14<<4)|0) + 4|0);
    HEAPF32[$33>>2] = $27;
    $34 = ((($10) + ($i$01$i14<<4)|0) + 8|0);
    HEAPF32[$34>>2] = $29;
    $35 = ((($10) + ($i$01$i14<<4)|0) + 12|0);
    HEAPF32[$35>>2] = $31;
   }
   $36 = (($i$01$i14) + 1)|0;
   $exitcond$i16 = ($36|0)==($19|0);
   if ($exitcond$i16) {
    break;
   } else {
    $i$01$i14 = $36;
   }
  }
 }
 $37 = (($aSource) + 52|0);
 $38 = $37;
 $39 = HEAP32[$37>>2]|0;
 $40 = (($39) + ($38))|0;
 $41 = $40;
 $42 = (($aSource) + 56|0);
 HEAP32[$42>>2] = $41;
 $43 = (($aValues) + 52|0);
 $44 = $43;
 $45 = HEAP32[$43>>2]|0;
 $46 = (($45) + ($44))|0;
 $47 = $46;
 $48 = (($aValues) + 56|0);
 HEAP32[$48>>2] = $47;
 $49 = (($mask) + 52|0);
 $50 = $49;
 $51 = HEAP32[$49>>2]|0;
 $52 = (($51) + ($50))|0;
 $53 = $52;
 $54 = (($mask) + 56|0);
 HEAP32[$54>>2] = $53;
 $55 = (($aValues) + 48|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ($56|0)==(0);
 if (!($57)) {
  $i$01$i10 = 0;
  while(1) {
   $58 = (($53) + ($i$01$i10)|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = ($59<<24>>24)==(0);
   if ($60) {
    $61 = (($41) + ($i$01$i10<<4)|0);
    $62 = Math_fround(HEAPF32[$61>>2]);
    $63 = ((($41) + ($i$01$i10<<4)|0) + 4|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = ((($41) + ($i$01$i10<<4)|0) + 8|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($41) + ($i$01$i10<<4)|0) + 12|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = (($47) + ($i$01$i10<<4)|0);
    HEAPF32[$69>>2] = $62;
    $70 = ((($47) + ($i$01$i10<<4)|0) + 4|0);
    HEAPF32[$70>>2] = $64;
    $71 = ((($47) + ($i$01$i10<<4)|0) + 8|0);
    HEAPF32[$71>>2] = $66;
    $72 = ((($47) + ($i$01$i10<<4)|0) + 12|0);
    HEAPF32[$72>>2] = $68;
   }
   $73 = (($i$01$i10) + 1)|0;
   $exitcond$i12 = ($73|0)==($56|0);
   if ($exitcond$i12) {
    break;
   } else {
    $i$01$i10 = $73;
   }
  }
 }
 $74 = (($aSource) + 64|0);
 $75 = $74;
 $76 = HEAP32[$74>>2]|0;
 $77 = (($76) + ($75))|0;
 $78 = $77;
 $79 = (($aSource) + 68|0);
 HEAP32[$79>>2] = $78;
 $80 = (($aValues) + 64|0);
 $81 = $80;
 $82 = HEAP32[$80>>2]|0;
 $83 = (($82) + ($81))|0;
 $84 = $83;
 $85 = (($aValues) + 68|0);
 HEAP32[$85>>2] = $84;
 $86 = (($mask) + 64|0);
 $87 = $86;
 $88 = HEAP32[$86>>2]|0;
 $89 = (($88) + ($87))|0;
 $90 = $89;
 $91 = (($mask) + 68|0);
 HEAP32[$91>>2] = $90;
 $92 = (($aValues) + 60|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==(0);
 if (!($94)) {
  $i$01$i7 = 0;
  while(1) {
   $95 = (($90) + ($i$01$i7)|0);
   $96 = HEAP8[$95>>0]|0;
   $97 = ($96<<24>>24)==(0);
   if ($97) {
    $98 = (($78) + ($i$01$i7<<4)|0);
    $99 = Math_fround(HEAPF32[$98>>2]);
    $100 = ((($78) + ($i$01$i7<<4)|0) + 4|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = ((($78) + ($i$01$i7<<4)|0) + 8|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    $104 = ((($78) + ($i$01$i7<<4)|0) + 12|0);
    $105 = Math_fround(HEAPF32[$104>>2]);
    $106 = (($84) + ($i$01$i7<<4)|0);
    HEAPF32[$106>>2] = $99;
    $107 = ((($84) + ($i$01$i7<<4)|0) + 4|0);
    HEAPF32[$107>>2] = $101;
    $108 = ((($84) + ($i$01$i7<<4)|0) + 8|0);
    HEAPF32[$108>>2] = $103;
    $109 = ((($84) + ($i$01$i7<<4)|0) + 12|0);
    HEAPF32[$109>>2] = $105;
   }
   $110 = (($i$01$i7) + 1)|0;
   $exitcond$i9 = ($110|0)==($93|0);
   if ($exitcond$i9) {
    break;
   } else {
    $i$01$i7 = $110;
   }
  }
 }
 $111 = (($aSource) + 28|0);
 $112 = $111;
 $113 = HEAP32[$111>>2]|0;
 $114 = (($113) + ($112))|0;
 $115 = $114;
 $116 = (($aSource) + 32|0);
 HEAP32[$116>>2] = $115;
 $117 = (($aValues) + 28|0);
 $118 = $117;
 $119 = HEAP32[$117>>2]|0;
 $120 = (($119) + ($118))|0;
 $121 = $120;
 $122 = (($aValues) + 32|0);
 HEAP32[$122>>2] = $121;
 $123 = (($mask) + 28|0);
 $124 = $123;
 $125 = HEAP32[$123>>2]|0;
 $126 = (($125) + ($124))|0;
 $127 = $126;
 $128 = (($mask) + 32|0);
 HEAP32[$128>>2] = $127;
 $129 = (($aValues) + 24|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($130|0)==(0);
 if (!($131)) {
  $i$01$i4 = 0;
  while(1) {
   $132 = (($127) + ($i$01$i4)|0);
   $133 = HEAP8[$132>>0]|0;
   $134 = ($133<<24>>24)==(0);
   if ($134) {
    $135 = (($115) + ($i$01$i4<<2)|0);
    $136 = Math_fround(HEAPF32[$135>>2]);
    $137 = (($121) + ($i$01$i4<<2)|0);
    HEAPF32[$137>>2] = $136;
   }
   $138 = (($i$01$i4) + 1)|0;
   $exitcond$i6 = ($138|0)==($130|0);
   if ($exitcond$i6) {
    break;
   } else {
    $i$01$i4 = $138;
   }
  }
 }
 $139 = (($aSource) + 16|0);
 $140 = $139;
 $141 = HEAP32[$139>>2]|0;
 $142 = (($141) + ($140))|0;
 $143 = $142;
 $144 = (($aSource) + 20|0);
 HEAP32[$144>>2] = $143;
 $145 = (($aValues) + 16|0);
 $146 = $145;
 $147 = HEAP32[$145>>2]|0;
 $148 = (($147) + ($146))|0;
 $149 = $148;
 $150 = (($aValues) + 20|0);
 HEAP32[$150>>2] = $149;
 $151 = (($mask) + 16|0);
 $152 = $151;
 $153 = HEAP32[$151>>2]|0;
 $154 = (($153) + ($152))|0;
 $155 = $154;
 $156 = (($mask) + 20|0);
 HEAP32[$156>>2] = $155;
 $157 = (($aValues) + 12|0);
 $158 = HEAP32[$157>>2]|0;
 $159 = ($158|0)==(0);
 if (!($159)) {
  $i$01$i1 = 0;
  while(1) {
   $160 = (($155) + ($i$01$i1)|0);
   $161 = HEAP8[$160>>0]|0;
   $162 = ($161<<24>>24)==(0);
   if ($162) {
    $163 = (($143) + ($i$01$i1<<2)|0);
    $164 = HEAP32[$163>>2]|0;
    $165 = (($149) + ($i$01$i1<<2)|0);
    HEAP32[$165>>2] = $164;
   }
   $166 = (($i$01$i1) + 1)|0;
   $exitcond$i3 = ($166|0)==($158|0);
   if ($exitcond$i3) {
    break;
   } else {
    $i$01$i1 = $166;
   }
  }
 }
 $167 = (($aSource) + 4|0);
 $168 = $167;
 $169 = HEAP32[$167>>2]|0;
 $170 = (($169) + ($168))|0;
 $171 = $170;
 $172 = (($aSource) + 8|0);
 HEAP32[$172>>2] = $171;
 $173 = (($aValues) + 4|0);
 $174 = $173;
 $175 = HEAP32[$173>>2]|0;
 $176 = (($175) + ($174))|0;
 $177 = $176;
 $178 = (($aValues) + 8|0);
 HEAP32[$178>>2] = $177;
 $179 = (($mask) + 4|0);
 $180 = $179;
 $181 = HEAP32[$179>>2]|0;
 $182 = (($181) + ($180))|0;
 $183 = $182;
 $184 = (($mask) + 8|0);
 HEAP32[$184>>2] = $183;
 $185 = HEAP32[$aValues>>2]|0;
 $186 = ($185|0)==(0);
 if ($186) {
  STACKTOP = sp;return;
 } else {
  $i$01$i = 0;
 }
 while(1) {
  $187 = (($183) + ($i$01$i)|0);
  $188 = HEAP8[$187>>0]|0;
  $189 = ($188<<24>>24)==(0);
  if ($189) {
   $190 = (($171) + ($i$01$i)|0);
   $191 = HEAP8[$190>>0]|0;
   $192 = (($177) + ($i$01$i)|0);
   HEAP8[$192>>0] = $191;
  }
  $193 = (($i$01$i) + 1)|0;
  $exitcond$i = ($193|0)==($185|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$01$i = $193;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim15ValueArrayBlendEPKNS_10ValueArrayEPS0_PS3_PKfjPKNS_14ValueArrayMaskE($apValuesDefault,$aValues,$aValuesArray,$apWeightArray,$aCount,$mask) {
 $apValuesDefault = $apValuesDefault|0;
 $aValues = $aValues|0;
 $aValuesArray = $aValuesArray|0;
 $apWeightArray = $apWeightArray|0;
 $aCount = $aCount|0;
 $mask = $mask|0;
 var $$lcssa$us165 = Math_fround(0), $$lcssa115 = Math_fround(0), $$lcssa116 = Math_fround(0), $$lcssa117 = Math_fround(0), $$lcssa118 = Math_fround(0), $$lcssa77 = Math_fround(0), $$lcssa78 = Math_fround(0), $$lcssa79 = Math_fround(0), $$lcssa80 = Math_fround(0), $$lcssa96 = Math_fround(0), $$lcssa97 = Math_fround(0), $$lcssa98 = Math_fround(0), $$lcssa99 = Math_fround(0), $$pre = 0, $$pre154 = 0, $$pre155 = 0, $$pre156 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0);
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0;
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = 0;
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0;
 var $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0);
 var $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0);
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0;
 var $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0);
 var $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0);
 var $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = 0, $367 = Math_fround(0), $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = Math_fround(0), $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0);
 var $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $blendIter$0119 = 0, $blendIter12$082 = 0, $blendIter19$054$us = 0, $blendIter19$054$us68 = 0, $blendIter4$0100 = 0;
 var $exitcond = 0, $exitcond$i = 0, $exitcond142 = 0, $exitcond148 = 0, $exitcond151 = 0, $exitcond153 = 0, $i$03$i = 0, $index$0$lcssa$i = 0, $index$02$i = 0, $index$1$i = 0, $largest$01$i = Math_fround(0), $largest$1$i = Math_fround(0), $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $sumW$0$lcssa = Math_fround(0), $sumW$0120 = Math_fround(0), $sumW10$0$lcssa = Math_fround(0), $sumW10$081 = Math_fround(0), $sumW18$0$lcssa$us164 = Math_fround(0);
 var $sumW18$053$us = Math_fround(0), $sumW2$0$lcssa = Math_fround(0), $sumW2$0101 = Math_fround(0), $valueIndex$0128 = 0, $valueIndex1$0110 = 0, $valueIndex17$059 = 0, $valueIndex17$059$us = 0, $valueIndex17$059$us64 = 0, $valueIndex24$052 = 0, $valueIndex9$091 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($apValuesDefault|0)!=(0|0);
 $1 = (($aValues) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($mask) + 40|0);
  $5 = $4;
  $6 = ($aCount|0)==(0);
  $7 = (($apValuesDefault) + 40|0);
  $8 = $7;
  $9 = (($aValues) + 40|0);
  $10 = $9;
  $11 = (($aValues) + 44|0);
  $$pre156 = HEAP32[$4>>2]|0;
  $valueIndex$0128 = 0;
  while(1) {
   $23 = (($$pre156) + ($5))|0;
   $24 = $23;
   $25 = (($24) + ($valueIndex$0128)|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = ($26<<24>>24)==(0);
   if (!($27)) {
    if ($6) {
     $$lcssa115 = Math_fround(0.0);$$lcssa116 = Math_fround(0.0);$$lcssa117 = Math_fround(0.0);$$lcssa118 = Math_fround(0.0);$sumW$0$lcssa = Math_fround(0.0);
    } else {
     $51 = Math_fround(0.0);$53 = Math_fround(0.0);$55 = Math_fround(0.0);$57 = Math_fround(0.0);$blendIter$0119 = 0;$sumW$0120 = Math_fround(0.0);
     while(1) {
      $28 = (($apWeightArray) + ($blendIter$0119<<2)|0);
      $29 = Math_fround(HEAPF32[$28>>2]);
      $30 = Math_fround($sumW$0120 + $29);
      $31 = (($aValuesArray) + ($blendIter$0119<<2)|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($32) + 40|0);
      $34 = $33;
      $35 = HEAP32[$33>>2]|0;
      $36 = (($34) + ($35))|0;
      $37 = $36;
      $38 = (($37) + ($valueIndex$0128<<4)|0);
      $39 = Math_fround(HEAPF32[$38>>2]);
      $40 = ((($37) + ($valueIndex$0128<<4)|0) + 4|0);
      $41 = Math_fround(HEAPF32[$40>>2]);
      $42 = ((($37) + ($valueIndex$0128<<4)|0) + 8|0);
      $43 = Math_fround(HEAPF32[$42>>2]);
      $44 = ((($37) + ($valueIndex$0128<<4)|0) + 12|0);
      $45 = Math_fround(HEAPF32[$44>>2]);
      $46 = Math_fround($29 * $39);
      $47 = Math_fround($29 * $41);
      $48 = Math_fround($29 * $43);
      $49 = Math_fround($29 * $45);
      $50 = Math_fround($51 + $46);
      $52 = Math_fround($53 + $47);
      $54 = Math_fround($55 + $48);
      $56 = Math_fround($57 + $49);
      $58 = (($blendIter$0119) + 1)|0;
      $exitcond148 = ($58|0)==($aCount|0);
      if ($exitcond148) {
       $$lcssa115 = $56;$$lcssa116 = $54;$$lcssa117 = $52;$$lcssa118 = $50;$sumW$0$lcssa = $30;
       break;
      } else {
       $51 = $50;$53 = $52;$55 = $54;$57 = $56;$blendIter$0119 = $58;$sumW$0120 = $30;
      }
     }
    }
    $59 = $sumW$0$lcssa < Math_fround(1.0);
    $or$cond = $0 & $59;
    if ($or$cond) {
     $60 = Math_fround(Math_fround(1.0) - $sumW$0$lcssa);
     $61 = HEAP32[$7>>2]|0;
     $62 = (($61) + ($8))|0;
     $63 = $62;
     $64 = (($63) + ($valueIndex$0128<<4)|0);
     $65 = Math_fround(HEAPF32[$64>>2]);
     $66 = ((($63) + ($valueIndex$0128<<4)|0) + 4|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = ((($63) + ($valueIndex$0128<<4)|0) + 8|0);
     $69 = Math_fround(HEAPF32[$68>>2]);
     $70 = ((($63) + ($valueIndex$0128<<4)|0) + 12|0);
     $71 = Math_fround(HEAPF32[$70>>2]);
     $72 = Math_fround($60 * $65);
     $73 = Math_fround($60 * $67);
     $74 = Math_fround($60 * $69);
     $75 = Math_fround($60 * $71);
     $76 = Math_fround($$lcssa118 + $72);
     $77 = Math_fround($$lcssa117 + $73);
     $78 = Math_fround($$lcssa116 + $74);
     $79 = Math_fround($$lcssa115 + $75);
     $84 = $76;$86 = $77;$88 = $78;$90 = $79;
    } else {
     $84 = $$lcssa118;$86 = $$lcssa117;$88 = $$lcssa116;$90 = $$lcssa115;
    }
    $80 = HEAP32[$9>>2]|0;
    $81 = (($80) + ($10))|0;
    $82 = $81;
    HEAP32[$11>>2] = $82;
    $83 = (($82) + ($valueIndex$0128<<4)|0);
    HEAPF32[$83>>2] = $84;
    $85 = ((($82) + ($valueIndex$0128<<4)|0) + 4|0);
    HEAPF32[$85>>2] = $86;
    $87 = ((($82) + ($valueIndex$0128<<4)|0) + 8|0);
    HEAPF32[$87>>2] = $88;
    $89 = ((($82) + ($valueIndex$0128<<4)|0) + 12|0);
    HEAPF32[$89>>2] = $90;
   }
   $91 = (($valueIndex$0128) + 1)|0;
   $92 = ($91>>>0)<($2>>>0);
   if ($92) {
    $valueIndex$0128 = $91;
   } else {
    break;
   }
  }
 }
 $12 = (($aValues) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = (($mask) + 52|0);
  $16 = $15;
  $17 = ($aCount|0)==(0);
  $18 = (($apValuesDefault) + 52|0);
  $19 = $18;
  $20 = (($aValues) + 52|0);
  $21 = $20;
  $22 = (($aValues) + 56|0);
  $$pre155 = HEAP32[$15>>2]|0;
  $valueIndex1$0110 = 0;
  while(1) {
   $104 = (($$pre155) + ($16))|0;
   $105 = $104;
   $106 = (($105) + ($valueIndex1$0110)|0);
   $107 = HEAP8[$106>>0]|0;
   $108 = ($107<<24>>24)==(0);
   if (!($108)) {
    if ($17) {
     $$lcssa96 = Math_fround(0.0);$$lcssa97 = Math_fround(0.0);$$lcssa98 = Math_fround(0.0);$$lcssa99 = Math_fround(0.0);$sumW2$0$lcssa = Math_fround(0.0);
    } else {
     $132 = Math_fround(0.0);$134 = Math_fround(0.0);$136 = Math_fround(0.0);$138 = Math_fround(0.0);$blendIter4$0100 = 0;$sumW2$0101 = Math_fround(0.0);
     while(1) {
      $109 = (($apWeightArray) + ($blendIter4$0100<<2)|0);
      $110 = Math_fround(HEAPF32[$109>>2]);
      $111 = Math_fround($sumW2$0101 + $110);
      $112 = (($aValuesArray) + ($blendIter4$0100<<2)|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = (($113) + 52|0);
      $115 = $114;
      $116 = HEAP32[$114>>2]|0;
      $117 = (($115) + ($116))|0;
      $118 = $117;
      $119 = (($118) + ($valueIndex1$0110<<4)|0);
      $120 = Math_fround(HEAPF32[$119>>2]);
      $121 = ((($118) + ($valueIndex1$0110<<4)|0) + 4|0);
      $122 = Math_fround(HEAPF32[$121>>2]);
      $123 = ((($118) + ($valueIndex1$0110<<4)|0) + 8|0);
      $124 = Math_fround(HEAPF32[$123>>2]);
      $125 = ((($118) + ($valueIndex1$0110<<4)|0) + 12|0);
      $126 = Math_fround(HEAPF32[$125>>2]);
      $127 = Math_fround($110 * $120);
      $128 = Math_fround($110 * $122);
      $129 = Math_fround($110 * $124);
      $130 = Math_fround($110 * $126);
      $131 = Math_fround($132 * $120);
      $133 = Math_fround($134 * $122);
      $135 = Math_fround($136 * $124);
      $137 = Math_fround($138 * $126);
      $139 = Math_fround($131 + $133);
      $140 = Math_fround($135 + $137);
      $141 = Math_fround($139 + $140);
      $142 = (HEAPF32[tempDoublePtr>>2]=$127,HEAP32[tempDoublePtr>>2]|0);
      $143 = (HEAPF32[tempDoublePtr>>2]=$141,HEAP32[tempDoublePtr>>2]|0);
      $144 = $143 & -2147483648;
      $145 = $144 ^ $142;
      $146 = (HEAP32[tempDoublePtr>>2]=$145,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $147 = (HEAPF32[tempDoublePtr>>2]=$128,HEAP32[tempDoublePtr>>2]|0);
      $148 = $144 ^ $147;
      $149 = (HEAP32[tempDoublePtr>>2]=$148,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $150 = (HEAPF32[tempDoublePtr>>2]=$129,HEAP32[tempDoublePtr>>2]|0);
      $151 = $144 ^ $150;
      $152 = (HEAP32[tempDoublePtr>>2]=$151,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $153 = (HEAPF32[tempDoublePtr>>2]=$130,HEAP32[tempDoublePtr>>2]|0);
      $154 = $144 ^ $153;
      $155 = (HEAP32[tempDoublePtr>>2]=$154,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $156 = Math_fround($132 + $146);
      $157 = Math_fround($134 + $149);
      $158 = Math_fround($136 + $152);
      $159 = Math_fround($138 + $155);
      $160 = (($blendIter4$0100) + 1)|0;
      $exitcond142 = ($160|0)==($aCount|0);
      if ($exitcond142) {
       $$lcssa96 = $159;$$lcssa97 = $158;$$lcssa98 = $157;$$lcssa99 = $156;$sumW2$0$lcssa = $111;
       break;
      } else {
       $132 = $156;$134 = $157;$136 = $158;$138 = $159;$blendIter4$0100 = $160;$sumW2$0101 = $111;
      }
     }
    }
    $161 = $sumW2$0$lcssa < Math_fround(1.0);
    $or$cond1 = $0 & $161;
    if ($or$cond1) {
     $162 = Math_fround(Math_fround(1.0) - $sumW2$0$lcssa);
     $163 = HEAP32[$18>>2]|0;
     $164 = (($163) + ($19))|0;
     $165 = $164;
     $166 = (($165) + ($valueIndex1$0110<<4)|0);
     $167 = Math_fround(HEAPF32[$166>>2]);
     $168 = ((($165) + ($valueIndex1$0110<<4)|0) + 4|0);
     $169 = Math_fround(HEAPF32[$168>>2]);
     $170 = ((($165) + ($valueIndex1$0110<<4)|0) + 8|0);
     $171 = Math_fround(HEAPF32[$170>>2]);
     $172 = ((($165) + ($valueIndex1$0110<<4)|0) + 12|0);
     $173 = Math_fround(HEAPF32[$172>>2]);
     $174 = Math_fround($162 * $167);
     $175 = Math_fround($162 * $169);
     $176 = Math_fround($162 * $171);
     $177 = Math_fround($162 * $173);
     $178 = Math_fround($$lcssa99 * $167);
     $179 = Math_fround($$lcssa98 * $169);
     $180 = Math_fround($$lcssa97 * $171);
     $181 = Math_fround($$lcssa96 * $173);
     $182 = Math_fround($179 + $178);
     $183 = Math_fround($181 + $180);
     $184 = Math_fround($183 + $182);
     $185 = (HEAPF32[tempDoublePtr>>2]=$174,HEAP32[tempDoublePtr>>2]|0);
     $186 = (HEAPF32[tempDoublePtr>>2]=$184,HEAP32[tempDoublePtr>>2]|0);
     $187 = $186 & -2147483648;
     $188 = $187 ^ $185;
     $189 = (HEAP32[tempDoublePtr>>2]=$188,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $190 = (HEAPF32[tempDoublePtr>>2]=$175,HEAP32[tempDoublePtr>>2]|0);
     $191 = $187 ^ $190;
     $192 = (HEAP32[tempDoublePtr>>2]=$191,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $193 = (HEAPF32[tempDoublePtr>>2]=$176,HEAP32[tempDoublePtr>>2]|0);
     $194 = $187 ^ $193;
     $195 = (HEAP32[tempDoublePtr>>2]=$194,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $196 = (HEAPF32[tempDoublePtr>>2]=$177,HEAP32[tempDoublePtr>>2]|0);
     $197 = $187 ^ $196;
     $198 = (HEAP32[tempDoublePtr>>2]=$197,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $199 = Math_fround($$lcssa99 + $189);
     $200 = Math_fround($$lcssa98 + $192);
     $201 = Math_fround($$lcssa97 + $195);
     $202 = Math_fround($$lcssa96 + $198);
     $204 = $199;$206 = $200;$208 = $201;$210 = $202;
    } else {
     $204 = $$lcssa99;$206 = $$lcssa98;$208 = $$lcssa97;$210 = $$lcssa96;
    }
    $203 = Math_fround($204 * $204);
    $205 = Math_fround($206 * $206);
    $207 = Math_fround($208 * $208);
    $209 = Math_fround($210 * $210);
    $211 = Math_fround($205 + $203);
    $212 = Math_fround($209 + $207);
    $213 = Math_fround($212 + $211);
    $214 = (Math_fround(Math_sqrt((Math_fround($213)))));
    $215 = Math_fround(Math_fround(1.0) / $214);
    $216 = Math_fround($204 * $215);
    $217 = Math_fround($206 * $215);
    $218 = Math_fround($208 * $215);
    $219 = Math_fround($210 * $215);
    $220 = HEAP32[$20>>2]|0;
    $221 = (($220) + ($21))|0;
    $222 = $221;
    HEAP32[$22>>2] = $222;
    $223 = (($222) + ($valueIndex1$0110<<4)|0);
    HEAPF32[$223>>2] = $216;
    $224 = ((($222) + ($valueIndex1$0110<<4)|0) + 4|0);
    HEAPF32[$224>>2] = $217;
    $225 = ((($222) + ($valueIndex1$0110<<4)|0) + 8|0);
    HEAPF32[$225>>2] = $218;
    $226 = ((($222) + ($valueIndex1$0110<<4)|0) + 12|0);
    HEAPF32[$226>>2] = $219;
   }
   $227 = (($valueIndex1$0110) + 1)|0;
   $228 = ($227>>>0)<($13>>>0);
   if ($228) {
    $valueIndex1$0110 = $227;
   } else {
    break;
   }
  }
 }
 $93 = (($aValues) + 60|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = ($94|0)==(0);
 if (!($95)) {
  $96 = (($mask) + 64|0);
  $97 = $96;
  $98 = ($aCount|0)==(0);
  $99 = (($apValuesDefault) + 64|0);
  $100 = $99;
  $101 = (($aValues) + 64|0);
  $102 = $101;
  $103 = (($aValues) + 68|0);
  $$pre154 = HEAP32[$96>>2]|0;
  $valueIndex9$091 = 0;
  while(1) {
   $302 = (($$pre154) + ($97))|0;
   $303 = $302;
   $304 = (($303) + ($valueIndex9$091)|0);
   $305 = HEAP8[$304>>0]|0;
   $306 = ($305<<24>>24)==(0);
   if (!($306)) {
    if ($98) {
     $$lcssa77 = Math_fround(0.0);$$lcssa78 = Math_fround(0.0);$$lcssa79 = Math_fround(0.0);$$lcssa80 = Math_fround(0.0);$sumW10$0$lcssa = Math_fround(0.0);
    } else {
     $330 = Math_fround(0.0);$332 = Math_fround(0.0);$334 = Math_fround(0.0);$336 = Math_fround(0.0);$blendIter12$082 = 0;$sumW10$081 = Math_fround(0.0);
     while(1) {
      $307 = (($apWeightArray) + ($blendIter12$082<<2)|0);
      $308 = Math_fround(HEAPF32[$307>>2]);
      $309 = Math_fround($sumW10$081 + $308);
      $310 = (($aValuesArray) + ($blendIter12$082<<2)|0);
      $311 = HEAP32[$310>>2]|0;
      $312 = (($311) + 64|0);
      $313 = $312;
      $314 = HEAP32[$312>>2]|0;
      $315 = (($313) + ($314))|0;
      $316 = $315;
      $317 = (($316) + ($valueIndex9$091<<4)|0);
      $318 = Math_fround(HEAPF32[$317>>2]);
      $319 = ((($316) + ($valueIndex9$091<<4)|0) + 4|0);
      $320 = Math_fround(HEAPF32[$319>>2]);
      $321 = ((($316) + ($valueIndex9$091<<4)|0) + 8|0);
      $322 = Math_fround(HEAPF32[$321>>2]);
      $323 = ((($316) + ($valueIndex9$091<<4)|0) + 12|0);
      $324 = Math_fround(HEAPF32[$323>>2]);
      $325 = Math_fround($308 * $318);
      $326 = Math_fround($308 * $320);
      $327 = Math_fround($308 * $322);
      $328 = Math_fround($308 * $324);
      $329 = Math_fround($330 + $325);
      $331 = Math_fround($332 + $326);
      $333 = Math_fround($334 + $327);
      $335 = Math_fround($336 + $328);
      $337 = (($blendIter12$082) + 1)|0;
      $exitcond = ($337|0)==($aCount|0);
      if ($exitcond) {
       $$lcssa77 = $335;$$lcssa78 = $333;$$lcssa79 = $331;$$lcssa80 = $329;$sumW10$0$lcssa = $309;
       break;
      } else {
       $330 = $329;$332 = $331;$334 = $333;$336 = $335;$blendIter12$082 = $337;$sumW10$081 = $309;
      }
     }
    }
    $338 = $sumW10$0$lcssa < Math_fround(1.0);
    $or$cond2 = $0 & $338;
    if ($or$cond2) {
     $339 = Math_fround(Math_fround(1.0) - $sumW10$0$lcssa);
     $340 = HEAP32[$99>>2]|0;
     $341 = (($340) + ($100))|0;
     $342 = $341;
     $343 = (($342) + ($valueIndex9$091<<4)|0);
     $344 = Math_fround(HEAPF32[$343>>2]);
     $345 = ((($342) + ($valueIndex9$091<<4)|0) + 4|0);
     $346 = Math_fround(HEAPF32[$345>>2]);
     $347 = ((($342) + ($valueIndex9$091<<4)|0) + 8|0);
     $348 = Math_fround(HEAPF32[$347>>2]);
     $349 = ((($342) + ($valueIndex9$091<<4)|0) + 12|0);
     $350 = Math_fround(HEAPF32[$349>>2]);
     $351 = Math_fround($339 * $344);
     $352 = Math_fround($339 * $346);
     $353 = Math_fround($339 * $348);
     $354 = Math_fround($339 * $350);
     $355 = Math_fround($$lcssa80 + $351);
     $356 = Math_fround($$lcssa79 + $352);
     $357 = Math_fround($$lcssa78 + $353);
     $358 = Math_fround($$lcssa77 + $354);
     $363 = $355;$365 = $356;$367 = $357;$369 = $358;
    } else {
     $363 = $$lcssa80;$365 = $$lcssa79;$367 = $$lcssa78;$369 = $$lcssa77;
    }
    $359 = HEAP32[$101>>2]|0;
    $360 = (($359) + ($102))|0;
    $361 = $360;
    HEAP32[$103>>2] = $361;
    $362 = (($361) + ($valueIndex9$091<<4)|0);
    HEAPF32[$362>>2] = $363;
    $364 = ((($361) + ($valueIndex9$091<<4)|0) + 4|0);
    HEAPF32[$364>>2] = $365;
    $366 = ((($361) + ($valueIndex9$091<<4)|0) + 8|0);
    HEAPF32[$366>>2] = $367;
    $368 = ((($361) + ($valueIndex9$091<<4)|0) + 12|0);
    HEAPF32[$368>>2] = $369;
   }
   $370 = (($valueIndex9$091) + 1)|0;
   $371 = ($370>>>0)<($94>>>0);
   if ($371) {
    $valueIndex9$091 = $370;
   } else {
    break;
   }
  }
 }
 $229 = (($aValues) + 24|0);
 $230 = HEAP32[$229>>2]|0;
 $231 = ($230|0)==(0);
 L46: do {
  if (!($231)) {
   $232 = (($mask) + 28|0);
   $233 = $232;
   $234 = HEAP32[$232>>2]|0;
   $235 = (($234) + ($233))|0;
   $236 = $235;
   $237 = ($aCount|0)!=(0);
   $238 = (($apValuesDefault) + 28|0);
   $239 = $238;
   $240 = (($aValues) + 28|0);
   $241 = $240;
   $242 = (($aValues) + 32|0);
   if ($0) {
    $valueIndex17$059$us = 0;
    while(1) {
     $243 = (($236) + ($valueIndex17$059$us)|0);
     $244 = HEAP8[$243>>0]|0;
     $245 = ($244<<24>>24)==(0);
     if (!($245)) {
      if ($237) {
       $274 = Math_fround(0.0);$blendIter19$054$us = 0;$sumW18$053$us = Math_fround(0.0);
       while(1) {
        $261 = (($apWeightArray) + ($blendIter19$054$us<<2)|0);
        $262 = Math_fround(HEAPF32[$261>>2]);
        $247 = Math_fround($sumW18$053$us + $262);
        $263 = (($aValuesArray) + ($blendIter19$054$us<<2)|0);
        $264 = HEAP32[$263>>2]|0;
        $265 = (($264) + 28|0);
        $266 = $265;
        $267 = HEAP32[$265>>2]|0;
        $268 = (($266) + ($267))|0;
        $269 = $268;
        $270 = (($269) + ($valueIndex17$059$us<<2)|0);
        $271 = Math_fround(HEAPF32[$270>>2]);
        $272 = Math_fround($262 * $271);
        $273 = Math_fround($274 + $272);
        $275 = (($blendIter19$054$us) + 1)|0;
        $exitcond151 = ($275|0)==($aCount|0);
        if ($exitcond151) {
         break;
        } else {
         $274 = $273;$blendIter19$054$us = $275;$sumW18$053$us = $247;
        }
       }
       $246 = $247 < Math_fround(1.0);
       if ($246) {
        $$lcssa$us165 = $273;$sumW18$0$lcssa$us164 = $247;
        label = 26;
       } else {
        $260 = $273;
       }
      } else {
       $$lcssa$us165 = Math_fround(0.0);$sumW18$0$lcssa$us164 = Math_fround(0.0);
       label = 26;
      }
      if ((label|0) == 26) {
       label = 0;
       $248 = Math_fround(Math_fround(1.0) - $sumW18$0$lcssa$us164);
       $249 = HEAP32[$238>>2]|0;
       $250 = (($249) + ($239))|0;
       $251 = $250;
       $252 = (($251) + ($valueIndex17$059$us<<2)|0);
       $253 = Math_fround(HEAPF32[$252>>2]);
       $254 = Math_fround($248 * $253);
       $255 = Math_fround($$lcssa$us165 + $254);
       $260 = $255;
      }
      $256 = HEAP32[$240>>2]|0;
      $257 = (($256) + ($241))|0;
      $258 = $257;
      HEAP32[$242>>2] = $258;
      $259 = (($258) + ($valueIndex17$059$us<<2)|0);
      HEAPF32[$259>>2] = $260;
     }
     $276 = (($valueIndex17$059$us) + 1)|0;
     $277 = ($276>>>0)<($230>>>0);
     if ($277) {
      $valueIndex17$059$us = $276;
     } else {
      break L46;
     }
    }
   }
   if ($237) {
    $valueIndex17$059$us64 = 0;
   } else {
    $valueIndex17$059 = 0;
    while(1) {
     $372 = (($236) + ($valueIndex17$059)|0);
     $373 = HEAP8[$372>>0]|0;
     $374 = ($373<<24>>24)==(0);
     if (!($374)) {
      $375 = HEAP32[$240>>2]|0;
      $376 = (($375) + ($241))|0;
      $377 = $376;
      HEAP32[$242>>2] = $377;
      $378 = (($377) + ($valueIndex17$059<<2)|0);
      HEAPF32[$378>>2] = Math_fround(0.0);
     }
     $379 = (($valueIndex17$059) + 1)|0;
     $380 = ($379>>>0)<($230>>>0);
     if ($380) {
      $valueIndex17$059 = $379;
     } else {
      break L46;
     }
    }
   }
   while(1) {
    $278 = (($236) + ($valueIndex17$059$us64)|0);
    $279 = HEAP8[$278>>0]|0;
    $280 = ($279<<24>>24)==(0);
    if (!($280)) {
     $298 = Math_fround(0.0);$blendIter19$054$us68 = 0;
     while(1) {
      $286 = (($apWeightArray) + ($blendIter19$054$us68<<2)|0);
      $287 = Math_fround(HEAPF32[$286>>2]);
      $288 = (($aValuesArray) + ($blendIter19$054$us68<<2)|0);
      $289 = HEAP32[$288>>2]|0;
      $290 = (($289) + 28|0);
      $291 = $290;
      $292 = HEAP32[$290>>2]|0;
      $293 = (($291) + ($292))|0;
      $294 = $293;
      $295 = (($294) + ($valueIndex17$059$us64<<2)|0);
      $296 = Math_fround(HEAPF32[$295>>2]);
      $297 = Math_fround($287 * $296);
      $285 = Math_fround($298 + $297);
      $299 = (($blendIter19$054$us68) + 1)|0;
      $exitcond153 = ($299|0)==($aCount|0);
      if ($exitcond153) {
       break;
      } else {
       $298 = $285;$blendIter19$054$us68 = $299;
      }
     }
     $281 = HEAP32[$240>>2]|0;
     $282 = (($281) + ($241))|0;
     $283 = $282;
     HEAP32[$242>>2] = $283;
     $284 = (($283) + ($valueIndex17$059$us64<<2)|0);
     HEAPF32[$284>>2] = $285;
    }
    $300 = (($valueIndex17$059$us64) + 1)|0;
    $301 = ($300>>>0)<($230>>>0);
    if ($301) {
     $valueIndex17$059$us64 = $300;
    } else {
     break;
    }
   }
  }
 } while(0);
 $381 = ($aCount>>>0)>(1);
 if ($381) {
  $382 = Math_fround(HEAPF32[$apWeightArray>>2]);
  $i$03$i = 1;$index$02$i = 0;$largest$01$i = $382;
  while(1) {
   $383 = (($apWeightArray) + ($i$03$i<<2)|0);
   $384 = Math_fround(HEAPF32[$383>>2]);
   $385 = $384 > $largest$01$i;
   $largest$1$i = $385 ? $384 : $largest$01$i;
   $index$1$i = $385 ? $i$03$i : $index$02$i;
   $386 = (($i$03$i) + 1)|0;
   $exitcond$i = ($386|0)==($aCount|0);
   if ($exitcond$i) {
    $index$0$lcssa$i = $index$1$i;
    break;
   } else {
    $i$03$i = $386;$index$02$i = $index$1$i;$largest$01$i = $largest$1$i;
   }
  }
 } else {
  $index$0$lcssa$i = 0;
 }
 $387 = (($aValues) + 12|0);
 $388 = HEAP32[$387>>2]|0;
 $389 = ($388|0)==(0);
 if ($389) {
  STACKTOP = sp;return;
 }
 $390 = (($mask) + 16|0);
 $391 = $390;
 $392 = (($aValuesArray) + ($index$0$lcssa$i<<2)|0);
 $393 = (($aValues) + 16|0);
 $394 = $393;
 $395 = (($aValues) + 20|0);
 $417 = $388;$valueIndex24$052 = 0;
 while(1) {
  $396 = HEAP32[$390>>2]|0;
  $397 = (($396) + ($391))|0;
  $398 = $397;
  $399 = (($398) + ($valueIndex24$052)|0);
  $400 = HEAP8[$399>>0]|0;
  $401 = ($400<<24>>24)==(0);
  if ($401) {
   $416 = $417;
  } else {
   $402 = HEAP32[$392>>2]|0;
   $403 = (($402) + 16|0);
   $404 = $403;
   $405 = HEAP32[$403>>2]|0;
   $406 = (($404) + ($405))|0;
   $407 = $406;
   $408 = (($407) + ($valueIndex24$052<<2)|0);
   $409 = HEAP32[$408>>2]|0;
   $410 = HEAP32[$393>>2]|0;
   $411 = (($410) + ($394))|0;
   $412 = $411;
   HEAP32[$395>>2] = $412;
   $413 = (($412) + ($valueIndex24$052<<2)|0);
   HEAP32[$413>>2] = $409;
   $$pre = HEAP32[$387>>2]|0;
   $416 = $$pre;
  }
  $414 = (($valueIndex24$052) + 1)|0;
  $415 = ($414>>>0)<($416>>>0);
  if ($415) {
   $417 = $416;$valueIndex24$052 = $414;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim13ValueArrayAddEPKNS_10ValueArrayES2_PKNS_14ValueArrayMaskEfbPS0_PS3_($apValuesDefault,$apValues,$readMask,$aWeight,$aAdditive,$apValuesOut,$defaultMask) {
 $apValuesDefault = $apValuesDefault|0;
 $apValues = $apValues|0;
 $readMask = $readMask|0;
 $aWeight = Math_fround($aWeight);
 $aAdditive = $aAdditive|0;
 $apValuesOut = $apValuesOut|0;
 $defaultMask = $defaultMask|0;
 var $$in = 0, $$in104 = 0, $$in105 = 0, $$in106 = 0, $$in107 = 0, $$in108 = 0, $$in109 = 0, $$in110 = 0, $$in111 = 0, $$in112 = 0, $$in113 = 0, $$in114 = 0, $$in115 = 0, $$in116 = 0, $$in117 = 0, $$in118 = 0, $$in119 = 0, $$in120 = 0, $$in121 = 0, $$in122 = 0;
 var $$in123 = 0, $$in124 = 0, $$in125 = 0, $$in126 = 0, $$in127 = 0, $$in128 = 0, $$in129 = 0, $$pn = 0, $$pn$in = 0, $$pn130 = 0, $$pn130$in = 0, $$pn131 = 0, $$pn131$in = 0, $$pre = 0, $$pre187 = 0, $$pre188 = 0, $$pre189 = 0, $$pre190 = 0, $$pre191 = 0, $$pre192 = 0;
 var $$sink = 0, $$sink156 = 0, $$sink157 = 0, $$sink158 = 0, $$sink159 = 0, $$sink160 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0;
 var $237 = 0, $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = 0;
 var $273 = Math_fround(0), $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0);
 var $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = Math_fround(0), $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0);
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0;
 var $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $valueIndex$0182 = 0, $valueIndex1$0178 = 0, $valueIndex2$0173 = 0, $valueIndex3$0168 = 0, $valueIndex4$0161 = 0, $valueIndex5$0164 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apValues) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($readMask) + 40|0);
  $4 = $3;
  $5 = (($apValues) + 40|0);
  $6 = $5;
  $7 = (($defaultMask) + 40|0);
  $8 = $7;
  $9 = (($defaultMask) + 44|0);
  $10 = (($apValuesOut) + 40|0);
  $11 = $10;
  $12 = (($apValuesDefault) + 40|0);
  $13 = $12;
  $14 = (($apValuesOut) + 44|0);
  $15 = $aWeight < Math_fround(1.0);
  $$pre192 = HEAP32[$3>>2]|0;
  $valueIndex$0182 = 0;
  while(1) {
   $32 = (($$pre192) + ($4))|0;
   $33 = $32;
   $34 = (($33) + ($valueIndex$0182)|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)==(0);
   if (!($36)) {
    $37 = HEAP32[$5>>2]|0;
    $38 = (($37) + ($6))|0;
    $39 = $38;
    $40 = (($39) + ($valueIndex$0182<<4)|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = ((($39) + ($valueIndex$0182<<4)|0) + 4|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = ((($39) + ($valueIndex$0182<<4)|0) + 8|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = ((($39) + ($valueIndex$0182<<4)|0) + 12|0);
    $47 = Math_fround(HEAPF32[$46>>2]);
    $48 = HEAP32[$7>>2]|0;
    if ($aAdditive) {
     $49 = (($48) + ($8))|0;
     $50 = $49;
     HEAP32[$9>>2] = $50;
     $51 = (($50) + ($valueIndex$0182)|0);
     $52 = HEAP8[$51>>0]|0;
     $53 = ($52<<24>>24)==(0);
     if ($53) {
      $56 = HEAP32[$10>>2]|0;
      $57 = (($56) + ($11))|0;
      $$sink = $57;
     } else {
      $54 = HEAP32[$12>>2]|0;
      $55 = (($54) + ($13))|0;
      $$sink = $55;
     }
     $58 = $$sink;
     $$in129 = (($58) + ($valueIndex$0182<<4)|0);
     $$in128 = ((($58) + ($valueIndex$0182<<4)|0) + 4|0);
     $$in127 = ((($58) + ($valueIndex$0182<<4)|0) + 8|0);
     $$in126 = ((($58) + ($valueIndex$0182<<4)|0) + 12|0);
     $59 = Math_fround(HEAPF32[$$in129>>2]);
     $60 = Math_fround(HEAPF32[$$in128>>2]);
     $61 = Math_fround(HEAPF32[$$in127>>2]);
     $62 = Math_fround(HEAPF32[$$in126>>2]);
     $63 = Math_fround($41 * $aWeight);
     $64 = Math_fround($43 * $aWeight);
     $65 = Math_fround($45 * $aWeight);
     $66 = Math_fround($47 * $aWeight);
     $67 = Math_fround($63 + $59);
     $68 = Math_fround($64 + $60);
     $69 = Math_fround($65 + $61);
     $70 = Math_fround($66 + $62);
     $101 = $67;$103 = $68;$105 = $69;$107 = $70;
    } else {
     if ($15) {
      $71 = (($48) + ($8))|0;
      $72 = $71;
      HEAP32[$9>>2] = $72;
      $73 = (($72) + ($valueIndex$0182)|0);
      $74 = HEAP8[$73>>0]|0;
      $75 = ($74<<24>>24)==(0);
      if ($75) {
       $78 = HEAP32[$10>>2]|0;
       $79 = (($78) + ($11))|0;
       $$sink156 = $79;
      } else {
       $76 = HEAP32[$12>>2]|0;
       $77 = (($76) + ($13))|0;
       $$sink156 = $77;
      }
      $80 = $$sink156;
      $$in125 = (($80) + ($valueIndex$0182<<4)|0);
      $$in124 = ((($80) + ($valueIndex$0182<<4)|0) + 4|0);
      $$in123 = ((($80) + ($valueIndex$0182<<4)|0) + 8|0);
      $$in122 = ((($80) + ($valueIndex$0182<<4)|0) + 12|0);
      $81 = Math_fround(HEAPF32[$$in125>>2]);
      $82 = Math_fround(HEAPF32[$$in124>>2]);
      $83 = Math_fround(HEAPF32[$$in123>>2]);
      $84 = Math_fround(HEAPF32[$$in122>>2]);
      $85 = Math_fround($41 - $81);
      $86 = Math_fround($43 - $82);
      $87 = Math_fround($45 - $83);
      $88 = Math_fround($47 - $84);
      $89 = Math_fround($85 * $aWeight);
      $90 = Math_fround($86 * $aWeight);
      $91 = Math_fround($87 * $aWeight);
      $92 = Math_fround($88 * $aWeight);
      $93 = Math_fround($81 + $89);
      $94 = Math_fround($82 + $90);
      $95 = Math_fround($83 + $91);
      $96 = Math_fround($84 + $92);
      $101 = $93;$103 = $94;$105 = $95;$107 = $96;
     } else {
      $101 = $41;$103 = $43;$105 = $45;$107 = $47;
     }
    }
    $97 = HEAP32[$10>>2]|0;
    $98 = (($97) + ($11))|0;
    $99 = $98;
    HEAP32[$14>>2] = $99;
    $100 = (($99) + ($valueIndex$0182<<4)|0);
    HEAPF32[$100>>2] = $101;
    $102 = ((($99) + ($valueIndex$0182<<4)|0) + 4|0);
    HEAPF32[$102>>2] = $103;
    $104 = ((($99) + ($valueIndex$0182<<4)|0) + 8|0);
    HEAPF32[$104>>2] = $105;
    $106 = ((($99) + ($valueIndex$0182<<4)|0) + 12|0);
    HEAPF32[$106>>2] = $107;
    $108 = (($48) + ($8))|0;
    $109 = $108;
    HEAP32[$9>>2] = $109;
    $110 = (($109) + ($valueIndex$0182)|0);
    HEAP8[$110>>0] = 0;
   }
   $111 = (($valueIndex$0182) + 1)|0;
   $112 = ($111>>>0)<($1>>>0);
   if ($112) {
    $valueIndex$0182 = $111;
   } else {
    break;
   }
  }
 }
 $16 = (($apValues) + 48|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = (($readMask) + 52|0);
  $20 = $19;
  $21 = (($apValues) + 52|0);
  $22 = $21;
  $23 = (($defaultMask) + 52|0);
  $24 = $23;
  $25 = (($defaultMask) + 56|0);
  $26 = (($apValuesOut) + 52|0);
  $27 = $26;
  $28 = (($apValuesDefault) + 52|0);
  $29 = $28;
  $30 = (($apValuesOut) + 56|0);
  $31 = $aWeight < Math_fround(1.0);
  $$pre191 = HEAP32[$19>>2]|0;
  $valueIndex1$0178 = 0;
  while(1) {
   $129 = (($$pre191) + ($20))|0;
   $130 = $129;
   $131 = (($130) + ($valueIndex1$0178)|0);
   $132 = HEAP8[$131>>0]|0;
   $133 = ($132<<24>>24)==(0);
   if (!($133)) {
    $134 = HEAP32[$21>>2]|0;
    $135 = (($134) + ($22))|0;
    $136 = $135;
    $137 = (($136) + ($valueIndex1$0178<<4)|0);
    $138 = Math_fround(HEAPF32[$137>>2]);
    $139 = ((($136) + ($valueIndex1$0178<<4)|0) + 4|0);
    $140 = Math_fround(HEAPF32[$139>>2]);
    $141 = ((($136) + ($valueIndex1$0178<<4)|0) + 8|0);
    $142 = Math_fround(HEAPF32[$141>>2]);
    $143 = ((($136) + ($valueIndex1$0178<<4)|0) + 12|0);
    $144 = Math_fround(HEAPF32[$143>>2]);
    $145 = HEAP32[$23>>2]|0;
    if ($aAdditive) {
     $146 = (($145) + ($24))|0;
     $147 = $146;
     HEAP32[$25>>2] = $147;
     $148 = (($147) + ($valueIndex1$0178)|0);
     $149 = HEAP8[$148>>0]|0;
     $150 = ($149<<24>>24)==(0);
     if ($150) {
      $153 = HEAP32[$26>>2]|0;
      $154 = (($153) + ($27))|0;
      $$sink157 = $154;
     } else {
      $151 = HEAP32[$28>>2]|0;
      $152 = (($151) + ($29))|0;
      $$sink157 = $152;
     }
     $155 = $$sink157;
     $$in121 = (($155) + ($valueIndex1$0178<<4)|0);
     $$in120 = ((($155) + ($valueIndex1$0178<<4)|0) + 4|0);
     $$in119 = ((($155) + ($valueIndex1$0178<<4)|0) + 8|0);
     $$in118 = ((($155) + ($valueIndex1$0178<<4)|0) + 12|0);
     $156 = Math_fround(HEAPF32[$$in121>>2]);
     $157 = Math_fround(HEAPF32[$$in120>>2]);
     $158 = Math_fround(HEAPF32[$$in119>>2]);
     $159 = Math_fround(HEAPF32[$$in118>>2]);
     $160 = Math_fround($138 * $aWeight);
     $161 = Math_fround($140 * $aWeight);
     $162 = Math_fround($142 * $aWeight);
     $163 = Math_fround($160 * $160);
     $164 = Math_fround($161 * $161);
     $165 = Math_fround($162 * $162);
     $166 = Math_fround($144 * $144);
     $167 = Math_fround($163 + $164);
     $168 = Math_fround($165 + $166);
     $169 = Math_fround($167 + $168);
     $170 = (Math_fround(Math_sqrt((Math_fround($169)))));
     $171 = Math_fround(Math_fround(1.0) / $170);
     $172 = Math_fround($160 * $171);
     $173 = Math_fround($161 * $171);
     $174 = Math_fround($162 * $171);
     $175 = Math_fround($144 * $171);
     $176 = Math_fround($157 * $172);
     $177 = Math_fround($159 * $175);
     $178 = Math_fround($158 * $173);
     $179 = Math_fround($156 * $174);
     $180 = Math_fround($159 * $174);
     $181 = Math_fround($156 * $172);
     $182 = Math_fround($157 * $174);
     $183 = Math_fround($158 * $172);
     $184 = Math_fround($176 - $180);
     $185 = Math_fround($177 - $181);
     $186 = Math_fround($178 - $182);
     $187 = Math_fround($179 - $183);
     $188 = Math_fround($158 * $175);
     $189 = Math_fround($158 * $174);
     $190 = Math_fround($159 * $172);
     $191 = Math_fround($159 * $173);
     $192 = Math_fround($184 - $188);
     $193 = Math_fround($185 - $189);
     $194 = Math_fround($186 - $190);
     $195 = Math_fround($187 - $191);
     $196 = Math_fround($156 * $173);
     $197 = Math_fround($157 * $173);
     $198 = Math_fround($156 * $175);
     $199 = Math_fround($157 * $175);
     $200 = Math_fround($192 - $196);
     $201 = Math_fround($193 - $197);
     $202 = Math_fround($194 - $198);
     $203 = Math_fround($195 - $199);
     $204 = Math_fround($202 * Math_fround(-1.0));
     $205 = Math_fround($203 * Math_fround(-1.0));
     $206 = Math_fround($200 * Math_fround(-1.0));
     $271 = $204;$273 = $205;$275 = $206;$277 = $201;
    } else {
     if ($31) {
      $207 = (($145) + ($24))|0;
      $208 = $207;
      HEAP32[$25>>2] = $208;
      $209 = (($208) + ($valueIndex1$0178)|0);
      $210 = HEAP8[$209>>0]|0;
      $211 = ($210<<24>>24)==(0);
      if ($211) {
       $214 = HEAP32[$26>>2]|0;
       $215 = (($214) + ($27))|0;
       $$sink158 = $215;
      } else {
       $212 = HEAP32[$28>>2]|0;
       $213 = (($212) + ($29))|0;
       $$sink158 = $213;
      }
      $216 = $$sink158;
      $$in117 = (($216) + ($valueIndex1$0178<<4)|0);
      $$in116 = ((($216) + ($valueIndex1$0178<<4)|0) + 4|0);
      $$in115 = ((($216) + ($valueIndex1$0178<<4)|0) + 8|0);
      $$in114 = ((($216) + ($valueIndex1$0178<<4)|0) + 12|0);
      $217 = Math_fround(HEAPF32[$$in117>>2]);
      $218 = Math_fround(HEAPF32[$$in116>>2]);
      $219 = Math_fround(HEAPF32[$$in115>>2]);
      $220 = Math_fround(HEAPF32[$$in114>>2]);
      $221 = Math_fround($138 * $217);
      $222 = Math_fround($140 * $218);
      $223 = Math_fround($142 * $219);
      $224 = Math_fround($144 * $220);
      $225 = Math_fround($221 + $222);
      $226 = Math_fround($223 + $224);
      $227 = Math_fround($225 + $226);
      $228 = (HEAPF32[tempDoublePtr>>2]=$138,HEAP32[tempDoublePtr>>2]|0);
      $229 = (HEAPF32[tempDoublePtr>>2]=$227,HEAP32[tempDoublePtr>>2]|0);
      $230 = $229 & -2147483648;
      $231 = $230 ^ $228;
      $232 = (HEAP32[tempDoublePtr>>2]=$231,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $233 = (HEAPF32[tempDoublePtr>>2]=$140,HEAP32[tempDoublePtr>>2]|0);
      $234 = $230 ^ $233;
      $235 = (HEAP32[tempDoublePtr>>2]=$234,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $236 = (HEAPF32[tempDoublePtr>>2]=$142,HEAP32[tempDoublePtr>>2]|0);
      $237 = $230 ^ $236;
      $238 = (HEAP32[tempDoublePtr>>2]=$237,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $239 = (HEAPF32[tempDoublePtr>>2]=$144,HEAP32[tempDoublePtr>>2]|0);
      $240 = $230 ^ $239;
      $241 = (HEAP32[tempDoublePtr>>2]=$240,Math_fround(HEAPF32[tempDoublePtr>>2]));
      $242 = Math_fround($232 - $217);
      $243 = Math_fround($235 - $218);
      $244 = Math_fround($238 - $219);
      $245 = Math_fround($241 - $220);
      $246 = Math_fround($242 * $aWeight);
      $247 = Math_fround($243 * $aWeight);
      $248 = Math_fround($244 * $aWeight);
      $249 = Math_fround($245 * $aWeight);
      $250 = Math_fround($217 + $246);
      $251 = Math_fround($218 + $247);
      $252 = Math_fround($219 + $248);
      $253 = Math_fround($220 + $249);
      $254 = Math_fround($250 * $250);
      $255 = Math_fround($251 * $251);
      $256 = Math_fround($252 * $252);
      $257 = Math_fround($253 * $253);
      $258 = Math_fround($254 + $255);
      $259 = Math_fround($256 + $257);
      $260 = Math_fround($258 + $259);
      $261 = (Math_fround(Math_sqrt((Math_fround($260)))));
      $262 = Math_fround(Math_fround(1.0) / $261);
      $263 = Math_fround($262 * $250);
      $264 = Math_fround($262 * $251);
      $265 = Math_fround($262 * $252);
      $266 = Math_fround($262 * $253);
      $271 = $263;$273 = $264;$275 = $265;$277 = $266;
     } else {
      $271 = $138;$273 = $140;$275 = $142;$277 = $144;
     }
    }
    $267 = HEAP32[$26>>2]|0;
    $268 = (($267) + ($27))|0;
    $269 = $268;
    HEAP32[$30>>2] = $269;
    $270 = (($269) + ($valueIndex1$0178<<4)|0);
    HEAPF32[$270>>2] = $271;
    $272 = ((($269) + ($valueIndex1$0178<<4)|0) + 4|0);
    HEAPF32[$272>>2] = $273;
    $274 = ((($269) + ($valueIndex1$0178<<4)|0) + 8|0);
    HEAPF32[$274>>2] = $275;
    $276 = ((($269) + ($valueIndex1$0178<<4)|0) + 12|0);
    HEAPF32[$276>>2] = $277;
    $278 = (($145) + ($24))|0;
    $279 = $278;
    HEAP32[$25>>2] = $279;
    $280 = (($279) + ($valueIndex1$0178)|0);
    HEAP8[$280>>0] = 0;
   }
   $281 = (($valueIndex1$0178) + 1)|0;
   $282 = ($281>>>0)<($17>>>0);
   if ($282) {
    $valueIndex1$0178 = $281;
   } else {
    break;
   }
  }
 }
 $113 = (($apValues) + 60|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = ($114|0)==(0);
 if (!($115)) {
  $116 = (($readMask) + 64|0);
  $117 = $116;
  $118 = (($apValues) + 64|0);
  $119 = $118;
  $120 = (($defaultMask) + 64|0);
  $121 = $120;
  $122 = (($defaultMask) + 68|0);
  $123 = (($apValuesOut) + 64|0);
  $124 = $123;
  $125 = (($apValuesDefault) + 64|0);
  $126 = $125;
  $127 = (($apValuesOut) + 68|0);
  $128 = $aWeight < Math_fround(1.0);
  $$pre190 = HEAP32[$116>>2]|0;
  $valueIndex2$0173 = 0;
  while(1) {
   $300 = (($$pre190) + ($117))|0;
   $301 = $300;
   $302 = (($301) + ($valueIndex2$0173)|0);
   $303 = HEAP8[$302>>0]|0;
   $304 = ($303<<24>>24)==(0);
   if (!($304)) {
    $305 = HEAP32[$118>>2]|0;
    $306 = (($305) + ($119))|0;
    $307 = $306;
    $308 = (($307) + ($valueIndex2$0173<<4)|0);
    $309 = Math_fround(HEAPF32[$308>>2]);
    $310 = ((($307) + ($valueIndex2$0173<<4)|0) + 4|0);
    $311 = Math_fround(HEAPF32[$310>>2]);
    $312 = ((($307) + ($valueIndex2$0173<<4)|0) + 8|0);
    $313 = Math_fround(HEAPF32[$312>>2]);
    $314 = ((($307) + ($valueIndex2$0173<<4)|0) + 12|0);
    $315 = Math_fround(HEAPF32[$314>>2]);
    $316 = HEAP32[$120>>2]|0;
    if ($aAdditive) {
     $317 = (($316) + ($121))|0;
     $318 = $317;
     HEAP32[$122>>2] = $318;
     $319 = (($318) + ($valueIndex2$0173)|0);
     $320 = HEAP8[$319>>0]|0;
     $321 = ($320<<24>>24)==(0);
     if ($321) {
      $324 = HEAP32[$123>>2]|0;
      $325 = (($324) + ($124))|0;
      $$sink159 = $325;
     } else {
      $322 = HEAP32[$125>>2]|0;
      $323 = (($322) + ($126))|0;
      $$sink159 = $323;
     }
     $326 = $$sink159;
     $$in113 = (($326) + ($valueIndex2$0173<<4)|0);
     $$in112 = ((($326) + ($valueIndex2$0173<<4)|0) + 4|0);
     $$in111 = ((($326) + ($valueIndex2$0173<<4)|0) + 8|0);
     $$in110 = ((($326) + ($valueIndex2$0173<<4)|0) + 12|0);
     $327 = Math_fround(HEAPF32[$$in113>>2]);
     $328 = Math_fround(HEAPF32[$$in112>>2]);
     $329 = Math_fround(HEAPF32[$$in111>>2]);
     $330 = Math_fround(HEAPF32[$$in110>>2]);
     $331 = Math_fround($309 * $aWeight);
     $332 = Math_fround($311 * $aWeight);
     $333 = Math_fround($313 * $aWeight);
     $334 = Math_fround($315 * $aWeight);
     $335 = Math_fround($331 + $327);
     $336 = Math_fround($332 + $328);
     $337 = Math_fround($333 + $329);
     $338 = Math_fround($334 + $330);
     $369 = $335;$371 = $336;$373 = $337;$375 = $338;
    } else {
     if ($128) {
      $339 = (($316) + ($121))|0;
      $340 = $339;
      HEAP32[$122>>2] = $340;
      $341 = (($340) + ($valueIndex2$0173)|0);
      $342 = HEAP8[$341>>0]|0;
      $343 = ($342<<24>>24)==(0);
      if ($343) {
       $346 = HEAP32[$123>>2]|0;
       $347 = (($346) + ($124))|0;
       $$sink160 = $347;
      } else {
       $344 = HEAP32[$125>>2]|0;
       $345 = (($344) + ($126))|0;
       $$sink160 = $345;
      }
      $348 = $$sink160;
      $$in109 = (($348) + ($valueIndex2$0173<<4)|0);
      $$in108 = ((($348) + ($valueIndex2$0173<<4)|0) + 4|0);
      $$in107 = ((($348) + ($valueIndex2$0173<<4)|0) + 8|0);
      $$in106 = ((($348) + ($valueIndex2$0173<<4)|0) + 12|0);
      $349 = Math_fround(HEAPF32[$$in109>>2]);
      $350 = Math_fround(HEAPF32[$$in108>>2]);
      $351 = Math_fround(HEAPF32[$$in107>>2]);
      $352 = Math_fround(HEAPF32[$$in106>>2]);
      $353 = Math_fround($309 - $349);
      $354 = Math_fround($311 - $350);
      $355 = Math_fround($313 - $351);
      $356 = Math_fround($315 - $352);
      $357 = Math_fround($353 * $aWeight);
      $358 = Math_fround($354 * $aWeight);
      $359 = Math_fround($355 * $aWeight);
      $360 = Math_fround($356 * $aWeight);
      $361 = Math_fround($349 + $357);
      $362 = Math_fround($350 + $358);
      $363 = Math_fround($351 + $359);
      $364 = Math_fround($352 + $360);
      $369 = $361;$371 = $362;$373 = $363;$375 = $364;
     } else {
      $369 = $309;$371 = $311;$373 = $313;$375 = $315;
     }
    }
    $365 = HEAP32[$123>>2]|0;
    $366 = (($365) + ($124))|0;
    $367 = $366;
    HEAP32[$127>>2] = $367;
    $368 = (($367) + ($valueIndex2$0173<<4)|0);
    HEAPF32[$368>>2] = $369;
    $370 = ((($367) + ($valueIndex2$0173<<4)|0) + 4|0);
    HEAPF32[$370>>2] = $371;
    $372 = ((($367) + ($valueIndex2$0173<<4)|0) + 8|0);
    HEAPF32[$372>>2] = $373;
    $374 = ((($367) + ($valueIndex2$0173<<4)|0) + 12|0);
    HEAPF32[$374>>2] = $375;
    $376 = (($316) + ($121))|0;
    $377 = $376;
    HEAP32[$122>>2] = $377;
    $378 = (($377) + ($valueIndex2$0173)|0);
    HEAP8[$378>>0] = 0;
   }
   $379 = (($valueIndex2$0173) + 1)|0;
   $380 = ($379>>>0)<($114>>>0);
   if ($380) {
    $valueIndex2$0173 = $379;
   } else {
    break;
   }
  }
 }
 $283 = (($apValues) + 24|0);
 $284 = HEAP32[$283>>2]|0;
 $285 = ($284|0)==(0);
 if (!($285)) {
  $286 = (($readMask) + 28|0);
  $287 = $286;
  $288 = (($apValues) + 28|0);
  $289 = $288;
  $290 = (($defaultMask) + 28|0);
  $291 = $290;
  $292 = (($defaultMask) + 32|0);
  $293 = (($apValuesOut) + 28|0);
  $294 = $293;
  $295 = (($apValuesDefault) + 28|0);
  $296 = $295;
  $297 = (($apValuesOut) + 32|0);
  $298 = $aWeight < Math_fround(1.0);
  $299 = Math_fround(Math_fround(1.0) - $aWeight);
  $$pre189 = HEAP32[$286>>2]|0;
  $valueIndex3$0168 = 0;
  while(1) {
   $381 = (($$pre189) + ($287))|0;
   $382 = $381;
   $383 = (($382) + ($valueIndex3$0168)|0);
   $384 = HEAP8[$383>>0]|0;
   $385 = ($384<<24>>24)==(0);
   if (!($385)) {
    $386 = HEAP32[$288>>2]|0;
    $387 = (($386) + ($289))|0;
    $388 = $387;
    $389 = (($388) + ($valueIndex3$0168<<2)|0);
    $390 = Math_fround(HEAPF32[$389>>2]);
    $391 = HEAP32[$290>>2]|0;
    if ($aAdditive) {
     $392 = (($391) + ($291))|0;
     $393 = $392;
     HEAP32[$292>>2] = $393;
     $394 = (($393) + ($valueIndex3$0168)|0);
     $395 = HEAP8[$394>>0]|0;
     $396 = ($395<<24>>24)==(0);
     if ($396) {
      $399 = HEAP32[$293>>2]|0;
      $400 = (($399) + ($294))|0;
      $$pn131$in = $400;
     } else {
      $397 = HEAP32[$295>>2]|0;
      $398 = (($397) + ($296))|0;
      $$pn131$in = $398;
     }
     $$pn131 = $$pn131$in;
     $$in105 = (($$pn131) + ($valueIndex3$0168<<2)|0);
     $401 = Math_fround(HEAPF32[$$in105>>2]);
     $402 = Math_fround($390 * $aWeight);
     $403 = Math_fround($402 + $401);
     $421 = $403;
    } else {
     if ($298) {
      $404 = (($391) + ($291))|0;
      $405 = $404;
      HEAP32[$292>>2] = $405;
      $406 = (($405) + ($valueIndex3$0168)|0);
      $407 = HEAP8[$406>>0]|0;
      $408 = ($407<<24>>24)==(0);
      if ($408) {
       $411 = HEAP32[$293>>2]|0;
       $412 = (($411) + ($294))|0;
       $$pn130$in = $412;
      } else {
       $409 = HEAP32[$295>>2]|0;
       $410 = (($409) + ($296))|0;
       $$pn130$in = $410;
      }
      $$pn130 = $$pn130$in;
      $$in104 = (($$pn130) + ($valueIndex3$0168<<2)|0);
      $413 = Math_fround(HEAPF32[$$in104>>2]);
      $414 = Math_fround($299 * $413);
      $415 = Math_fround($390 * $aWeight);
      $416 = Math_fround($415 + $414);
      $421 = $416;
     } else {
      $421 = $390;
     }
    }
    $417 = HEAP32[$293>>2]|0;
    $418 = (($417) + ($294))|0;
    $419 = $418;
    HEAP32[$297>>2] = $419;
    $420 = (($419) + ($valueIndex3$0168<<2)|0);
    HEAPF32[$420>>2] = $421;
    $422 = (($391) + ($291))|0;
    $423 = $422;
    HEAP32[$292>>2] = $423;
    $424 = (($423) + ($valueIndex3$0168)|0);
    HEAP8[$424>>0] = 0;
   }
   $425 = (($valueIndex3$0168) + 1)|0;
   $426 = ($425>>>0)<($284>>>0);
   if ($426) {
    $valueIndex3$0168 = $425;
   } else {
    break;
   }
  }
 }
 $427 = $aWeight > Math_fround(0.5);
 $428 = (($apValues) + 12|0);
 $429 = HEAP32[$428>>2]|0;
 $430 = ($429|0)==(0);
 if ($427) {
  if ($430) {
   STACKTOP = sp;return;
  }
  $441 = (($readMask) + 16|0);
  $442 = $441;
  $443 = (($apValues) + 16|0);
  $444 = $443;
  $445 = (($apValuesOut) + 16|0);
  $446 = $445;
  $447 = (($apValuesOut) + 20|0);
  $448 = (($defaultMask) + 16|0);
  $449 = $448;
  $450 = (($defaultMask) + 20|0);
  $502 = $429;$valueIndex4$0161 = 0;
  while(1) {
   $451 = HEAP32[$441>>2]|0;
   $452 = (($451) + ($442))|0;
   $453 = $452;
   $454 = (($453) + ($valueIndex4$0161)|0);
   $455 = HEAP8[$454>>0]|0;
   $456 = ($455<<24>>24)==(0);
   if ($456) {
    $472 = $502;
   } else {
    $457 = HEAP32[$443>>2]|0;
    $458 = (($457) + ($444))|0;
    $459 = $458;
    $460 = (($459) + ($valueIndex4$0161<<2)|0);
    $461 = HEAP32[$460>>2]|0;
    $462 = HEAP32[$445>>2]|0;
    $463 = (($462) + ($446))|0;
    $464 = $463;
    HEAP32[$447>>2] = $464;
    $465 = (($464) + ($valueIndex4$0161<<2)|0);
    HEAP32[$465>>2] = $461;
    $466 = HEAP32[$448>>2]|0;
    $467 = (($466) + ($449))|0;
    $468 = $467;
    HEAP32[$450>>2] = $468;
    $469 = (($468) + ($valueIndex4$0161)|0);
    HEAP8[$469>>0] = 0;
    $$pre = HEAP32[$428>>2]|0;
    $472 = $$pre;
   }
   $470 = (($valueIndex4$0161) + 1)|0;
   $471 = ($470>>>0)<($472>>>0);
   if ($471) {
    $502 = $472;$valueIndex4$0161 = $470;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
 if ($430) {
  STACKTOP = sp;return;
 }
 $431 = (($readMask) + 16|0);
 $432 = $431;
 $433 = (($defaultMask) + 16|0);
 $434 = $433;
 $435 = (($defaultMask) + 20|0);
 $436 = (($apValuesOut) + 16|0);
 $437 = $436;
 $438 = (($apValuesOut) + 20|0);
 $439 = (($apValuesDefault) + 16|0);
 $440 = $439;
 $501 = $429;$valueIndex5$0164 = 0;
 while(1) {
  $473 = HEAP32[$431>>2]|0;
  $474 = (($473) + ($432))|0;
  $475 = $474;
  $476 = (($475) + ($valueIndex5$0164)|0);
  $477 = HEAP8[$476>>0]|0;
  $478 = ($477<<24>>24)==(0);
  if ($478) {
   $500 = $501;
  } else {
   $479 = HEAP32[$433>>2]|0;
   $480 = (($479) + ($434))|0;
   $481 = $480;
   HEAP32[$435>>2] = $481;
   $482 = (($481) + ($valueIndex5$0164)|0);
   $483 = HEAP8[$482>>0]|0;
   $484 = ($483<<24>>24)==(0);
   if ($484) {
    $487 = HEAP32[$436>>2]|0;
    $488 = (($487) + ($437))|0;
    $$pn$in = $488;$491 = $487;
   } else {
    $485 = HEAP32[$439>>2]|0;
    $486 = (($485) + ($440))|0;
    $$pre188 = HEAP32[$436>>2]|0;
    $$pn$in = $486;$491 = $$pre188;
   }
   $$pn = $$pn$in;
   $$in = (($$pn) + ($valueIndex5$0164<<2)|0);
   $489 = HEAP32[$$in>>2]|0;
   $490 = (($491) + ($437))|0;
   $492 = $490;
   HEAP32[$438>>2] = $492;
   $493 = (($492) + ($valueIndex5$0164<<2)|0);
   HEAP32[$493>>2] = $489;
   $494 = HEAP32[$433>>2]|0;
   $495 = (($494) + ($434))|0;
   $496 = $495;
   HEAP32[$435>>2] = $496;
   $497 = (($496) + ($valueIndex5$0164)|0);
   HEAP8[$497>>0] = 0;
   $$pre187 = HEAP32[$428>>2]|0;
   $500 = $$pre187;
  }
  $498 = (($valueIndex5$0164) + 1)|0;
  $499 = ($498>>>0)<($500>>>0);
  if ($499) {
   $501 = $500;$valueIndex5$0164 = $498;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim13ValueArraySubERKNS_10ValueArrayERS0_PKNS_14ValueArrayMaskE($starts,$values,$mask) {
 $starts = $starts|0;
 $values = $values|0;
 $mask = $mask|0;
 var $$pre = 0, $$pre43 = 0, $$pre44 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0);
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0);
 var $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0;
 var $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $valueIndex$040 = 0, $valueIndex1$038 = 0, $valueIndex2$035 = 0, $valueIndex3$033 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($values) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($mask) + 40|0);
  $4 = $3;
  $5 = (($values) + 40|0);
  $6 = $5;
  $7 = (($starts) + 40|0);
  $8 = $7;
  $9 = (($values) + 44|0);
  $$pre44 = HEAP32[$3>>2]|0;
  $valueIndex$040 = 0;
  while(1) {
   $20 = (($$pre44) + ($4))|0;
   $21 = $20;
   $22 = (($21) + ($valueIndex$040)|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)==(0);
   if (!($24)) {
    $25 = HEAP32[$5>>2]|0;
    $26 = (($25) + ($6))|0;
    $27 = $26;
    $28 = (($27) + ($valueIndex$040<<4)|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = ((($27) + ($valueIndex$040<<4)|0) + 4|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = ((($27) + ($valueIndex$040<<4)|0) + 8|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = ((($27) + ($valueIndex$040<<4)|0) + 12|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = HEAP32[$7>>2]|0;
    $37 = (($36) + ($8))|0;
    $38 = $37;
    $39 = (($38) + ($valueIndex$040<<4)|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = ((($38) + ($valueIndex$040<<4)|0) + 4|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = ((($38) + ($valueIndex$040<<4)|0) + 8|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = ((($38) + ($valueIndex$040<<4)|0) + 12|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = Math_fround($29 - $40);
    $48 = Math_fround($31 - $42);
    $49 = Math_fround($33 - $44);
    $50 = Math_fround($35 - $46);
    HEAP32[$9>>2] = $27;
    HEAPF32[$28>>2] = $47;
    HEAPF32[$30>>2] = $48;
    HEAPF32[$32>>2] = $49;
    HEAPF32[$34>>2] = $50;
   }
   $51 = (($valueIndex$040) + 1)|0;
   $52 = ($51>>>0)<($1>>>0);
   if ($52) {
    $valueIndex$040 = $51;
   } else {
    break;
   }
  }
 }
 $10 = (($values) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $13 = (($mask) + 52|0);
  $14 = $13;
  $15 = (($values) + 52|0);
  $16 = $15;
  $17 = (($starts) + 52|0);
  $18 = $17;
  $19 = (($values) + 56|0);
  $$pre43 = HEAP32[$13>>2]|0;
  $valueIndex1$038 = 0;
  while(1) {
   $63 = (($$pre43) + ($14))|0;
   $64 = $63;
   $65 = (($64) + ($valueIndex1$038)|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = ($66<<24>>24)==(0);
   if (!($67)) {
    $68 = HEAP32[$15>>2]|0;
    $69 = (($68) + ($16))|0;
    $70 = $69;
    $71 = (($70) + ($valueIndex1$038<<4)|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = ((($70) + ($valueIndex1$038<<4)|0) + 4|0);
    $74 = Math_fround(HEAPF32[$73>>2]);
    $75 = ((($70) + ($valueIndex1$038<<4)|0) + 8|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = ((($70) + ($valueIndex1$038<<4)|0) + 12|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = HEAP32[$17>>2]|0;
    $80 = (($79) + ($18))|0;
    $81 = $80;
    $82 = (($81) + ($valueIndex1$038<<4)|0);
    $83 = Math_fround(HEAPF32[$82>>2]);
    $84 = ((($81) + ($valueIndex1$038<<4)|0) + 4|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = ((($81) + ($valueIndex1$038<<4)|0) + 8|0);
    $87 = Math_fround(HEAPF32[$86>>2]);
    $88 = ((($81) + ($valueIndex1$038<<4)|0) + 12|0);
    $89 = Math_fround(HEAPF32[$88>>2]);
    $90 = Math_fround($83 * Math_fround(-1.0));
    $91 = Math_fround($85 * Math_fround(-1.0));
    $92 = Math_fround($87 * Math_fround(-1.0));
    $93 = Math_fround($72 * $91);
    $94 = Math_fround($78 * $89);
    $95 = Math_fround($74 * $92);
    $96 = Math_fround($76 * $90);
    $97 = Math_fround($76 * $89);
    $98 = Math_fround($72 * $90);
    $99 = Math_fround($76 * $91);
    $100 = Math_fround($72 * $92);
    $101 = Math_fround($93 - $97);
    $102 = Math_fround($94 - $98);
    $103 = Math_fround($95 - $99);
    $104 = Math_fround($96 - $100);
    $105 = Math_fround($78 * $92);
    $106 = Math_fround($76 * $92);
    $107 = Math_fround($72 * $89);
    $108 = Math_fround($74 * $89);
    $109 = Math_fround($101 - $105);
    $110 = Math_fround($102 - $106);
    $111 = Math_fround($103 - $107);
    $112 = Math_fround($104 - $108);
    $113 = Math_fround($74 * $90);
    $114 = Math_fround($74 * $91);
    $115 = Math_fround($78 * $90);
    $116 = Math_fround($78 * $91);
    $117 = Math_fround($109 - $113);
    $118 = Math_fround($110 - $114);
    $119 = Math_fround($111 - $115);
    $120 = Math_fround($112 - $116);
    $121 = Math_fround($119 * Math_fround(-1.0));
    $122 = Math_fround($120 * Math_fround(-1.0));
    $123 = Math_fround($117 * Math_fround(-1.0));
    $124 = Math_fround($121 * $121);
    $125 = Math_fround($122 * $122);
    $126 = Math_fround($123 * $123);
    $127 = Math_fround($118 * $118);
    $128 = Math_fround($124 + $125);
    $129 = Math_fround($127 + $126);
    $130 = Math_fround($128 + $129);
    $131 = (Math_fround(Math_sqrt((Math_fround($130)))));
    $132 = Math_fround(Math_fround(1.0) / $131);
    $133 = Math_fround($132 * $121);
    $134 = Math_fround($132 * $122);
    $135 = Math_fround($132 * $123);
    $136 = Math_fround($132 * $118);
    HEAP32[$19>>2] = $70;
    HEAPF32[$71>>2] = $133;
    HEAPF32[$73>>2] = $134;
    HEAPF32[$75>>2] = $135;
    HEAPF32[$77>>2] = $136;
   }
   $137 = (($valueIndex1$038) + 1)|0;
   $138 = ($137>>>0)<($11>>>0);
   if ($138) {
    $valueIndex1$038 = $137;
   } else {
    break;
   }
  }
 }
 $53 = (($values) + 60|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0);
 if (!($55)) {
  $56 = (($mask) + 64|0);
  $57 = $56;
  $58 = (($values) + 64|0);
  $59 = $58;
  $60 = (($starts) + 64|0);
  $61 = $60;
  $62 = (($values) + 68|0);
  $$pre = HEAP32[$56>>2]|0;
  $valueIndex2$035 = 0;
  while(1) {
   $152 = (($$pre) + ($57))|0;
   $153 = $152;
   $154 = (($153) + ($valueIndex2$035)|0);
   $155 = HEAP8[$154>>0]|0;
   $156 = ($155<<24>>24)==(0);
   if (!($156)) {
    $157 = HEAP32[$58>>2]|0;
    $158 = (($157) + ($59))|0;
    $159 = $158;
    $160 = (($159) + ($valueIndex2$035<<4)|0);
    $161 = Math_fround(HEAPF32[$160>>2]);
    $162 = ((($159) + ($valueIndex2$035<<4)|0) + 4|0);
    $163 = Math_fround(HEAPF32[$162>>2]);
    $164 = ((($159) + ($valueIndex2$035<<4)|0) + 8|0);
    $165 = Math_fround(HEAPF32[$164>>2]);
    $166 = ((($159) + ($valueIndex2$035<<4)|0) + 12|0);
    $167 = Math_fround(HEAPF32[$166>>2]);
    $168 = HEAP32[$60>>2]|0;
    $169 = (($168) + ($61))|0;
    $170 = $169;
    $171 = (($170) + ($valueIndex2$035<<4)|0);
    $172 = Math_fround(HEAPF32[$171>>2]);
    $173 = ((($170) + ($valueIndex2$035<<4)|0) + 4|0);
    $174 = Math_fround(HEAPF32[$173>>2]);
    $175 = ((($170) + ($valueIndex2$035<<4)|0) + 8|0);
    $176 = Math_fround(HEAPF32[$175>>2]);
    $177 = ((($170) + ($valueIndex2$035<<4)|0) + 12|0);
    $178 = Math_fround(HEAPF32[$177>>2]);
    $179 = Math_fround($161 / $172);
    $180 = Math_fround($163 / $174);
    $181 = Math_fround($165 / $176);
    $182 = Math_fround($167 / $178);
    HEAP32[$62>>2] = $159;
    HEAPF32[$160>>2] = $179;
    HEAPF32[$162>>2] = $180;
    HEAPF32[$164>>2] = $181;
    HEAPF32[$166>>2] = $182;
   }
   $183 = (($valueIndex2$035) + 1)|0;
   $184 = ($183>>>0)<($54>>>0);
   if ($184) {
    $valueIndex2$035 = $183;
   } else {
    break;
   }
  }
 }
 $139 = (($values) + 24|0);
 $140 = HEAP32[$139>>2]|0;
 $141 = ($140|0)==(0);
 if ($141) {
  STACKTOP = sp;return;
 }
 $142 = (($mask) + 28|0);
 $143 = $142;
 $144 = HEAP32[$142>>2]|0;
 $145 = (($144) + ($143))|0;
 $146 = $145;
 $147 = (($values) + 28|0);
 $148 = $147;
 $149 = (($starts) + 28|0);
 $150 = $149;
 $151 = (($values) + 32|0);
 $valueIndex3$033 = 0;
 while(1) {
  $185 = (($146) + ($valueIndex3$033)|0);
  $186 = HEAP8[$185>>0]|0;
  $187 = ($186<<24>>24)==(0);
  if (!($187)) {
   $188 = HEAP32[$147>>2]|0;
   $189 = (($188) + ($148))|0;
   $190 = $189;
   $191 = (($190) + ($valueIndex3$033<<2)|0);
   $192 = Math_fround(HEAPF32[$191>>2]);
   $193 = HEAP32[$149>>2]|0;
   $194 = (($193) + ($150))|0;
   $195 = $194;
   $196 = (($195) + ($valueIndex3$033<<2)|0);
   $197 = Math_fround(HEAPF32[$196>>2]);
   $198 = Math_fround($192 - $197);
   HEAP32[$151>>2] = $190;
   HEAPF32[$191>>2] = $198;
  }
  $199 = (($valueIndex3$033) + 1)|0;
  $200 = ($199>>>0)<($140>>>0);
  if ($200) {
   $valueIndex3$033 = $199;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim14ValueArrayLoopERKNS_10ValueArrayES2_RS0_fRKNS_14ValueArrayMaskE($starts,$stops,$values,$loopWeight,$mask) {
 $starts = $starts|0;
 $stops = $stops|0;
 $values = $values|0;
 $loopWeight = Math_fround($loopWeight);
 $mask = $mask|0;
 var $$pre = 0, $$pre79 = 0, $$pre80 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0;
 var $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0);
 var $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0);
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = Math_fround(0), $275 = 0;
 var $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0);
 var $311 = Math_fround(0), $312 = 0, $313 = 0, $314 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0);
 var $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $valueIndex$076 = 0, $valueIndex1$074 = 0;
 var $valueIndex2$071 = 0, $valueIndex3$069 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($values) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($mask) + 40|0);
  $4 = $3;
  $5 = (($values) + 40|0);
  $6 = $5;
  $7 = (($starts) + 40|0);
  $8 = $7;
  $9 = (($stops) + 40|0);
  $10 = $9;
  $11 = (($values) + 44|0);
  $$pre80 = HEAP32[$3>>2]|0;
  $valueIndex$076 = 0;
  while(1) {
   $24 = (($$pre80) + ($4))|0;
   $25 = $24;
   $26 = (($25) + ($valueIndex$076)|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)==(0);
   if (!($28)) {
    $29 = HEAP32[$5>>2]|0;
    $30 = (($29) + ($6))|0;
    $31 = $30;
    $32 = (($31) + ($valueIndex$076<<4)|0);
    $33 = Math_fround(HEAPF32[$32>>2]);
    $34 = ((($31) + ($valueIndex$076<<4)|0) + 4|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = ((($31) + ($valueIndex$076<<4)|0) + 8|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = ((($31) + ($valueIndex$076<<4)|0) + 12|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = HEAP32[$7>>2]|0;
    $41 = (($40) + ($8))|0;
    $42 = $41;
    $43 = (($42) + ($valueIndex$076<<4)|0);
    $44 = Math_fround(HEAPF32[$43>>2]);
    $45 = ((($42) + ($valueIndex$076<<4)|0) + 4|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = ((($42) + ($valueIndex$076<<4)|0) + 8|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = ((($42) + ($valueIndex$076<<4)|0) + 12|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = HEAP32[$9>>2]|0;
    $52 = (($51) + ($10))|0;
    $53 = $52;
    $54 = (($53) + ($valueIndex$076<<4)|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = ((($53) + ($valueIndex$076<<4)|0) + 4|0);
    $57 = Math_fround(HEAPF32[$56>>2]);
    $58 = ((($53) + ($valueIndex$076<<4)|0) + 8|0);
    $59 = Math_fround(HEAPF32[$58>>2]);
    $60 = ((($53) + ($valueIndex$076<<4)|0) + 12|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = Math_fround($44 - $55);
    $63 = Math_fround($46 - $57);
    $64 = Math_fround($48 - $59);
    $65 = Math_fround($50 - $61);
    $66 = Math_fround($62 * $loopWeight);
    $67 = Math_fround($63 * $loopWeight);
    $68 = Math_fround($64 * $loopWeight);
    $69 = Math_fround($65 * $loopWeight);
    $70 = Math_fround($33 + $66);
    $71 = Math_fround($35 + $67);
    $72 = Math_fround($37 + $68);
    $73 = Math_fround($39 + $69);
    HEAP32[$11>>2] = $31;
    HEAPF32[$32>>2] = $70;
    HEAPF32[$34>>2] = $71;
    HEAPF32[$36>>2] = $72;
    HEAPF32[$38>>2] = $73;
   }
   $74 = (($valueIndex$076) + 1)|0;
   $75 = ($74>>>0)<($1>>>0);
   if ($75) {
    $valueIndex$076 = $74;
   } else {
    break;
   }
  }
 }
 $12 = (($values) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = (($mask) + 52|0);
  $16 = $15;
  $17 = (($values) + 52|0);
  $18 = $17;
  $19 = (($starts) + 52|0);
  $20 = $19;
  $21 = (($stops) + 52|0);
  $22 = $21;
  $23 = (($values) + 56|0);
  $314 = $13;$valueIndex1$074 = 0;
  while(1) {
   $88 = HEAP32[$15>>2]|0;
   $89 = (($88) + ($16))|0;
   $90 = $89;
   $91 = (($90) + ($valueIndex1$074)|0);
   $92 = HEAP8[$91>>0]|0;
   $93 = ($92<<24>>24)==(0);
   if ($93) {
    $223 = $314;
   } else {
    $94 = HEAP32[$17>>2]|0;
    $95 = (($94) + ($18))|0;
    $96 = $95;
    $97 = (($96) + ($valueIndex1$074<<4)|0);
    $98 = Math_fround(HEAPF32[$97>>2]);
    $99 = ((($96) + ($valueIndex1$074<<4)|0) + 4|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $101 = ((($96) + ($valueIndex1$074<<4)|0) + 8|0);
    $102 = Math_fround(HEAPF32[$101>>2]);
    $103 = ((($96) + ($valueIndex1$074<<4)|0) + 12|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = HEAP32[$19>>2]|0;
    $106 = (($105) + ($20))|0;
    $107 = $106;
    $108 = (($107) + ($valueIndex1$074<<4)|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = ((($107) + ($valueIndex1$074<<4)|0) + 4|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = ((($107) + ($valueIndex1$074<<4)|0) + 8|0);
    $113 = Math_fround(HEAPF32[$112>>2]);
    $114 = ((($107) + ($valueIndex1$074<<4)|0) + 12|0);
    $115 = Math_fround(HEAPF32[$114>>2]);
    $116 = HEAP32[$21>>2]|0;
    $117 = (($116) + ($22))|0;
    $118 = $117;
    $119 = (($118) + ($valueIndex1$074<<4)|0);
    $120 = Math_fround(HEAPF32[$119>>2]);
    $121 = ((($118) + ($valueIndex1$074<<4)|0) + 4|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = ((($118) + ($valueIndex1$074<<4)|0) + 8|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = ((($118) + ($valueIndex1$074<<4)|0) + 12|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = Math_fround($120 * Math_fround(-1.0));
    $128 = Math_fround($122 * Math_fround(-1.0));
    $129 = Math_fround($124 * Math_fround(-1.0));
    $130 = Math_fround($109 * $128);
    $131 = Math_fround($115 * $126);
    $132 = Math_fround($111 * $129);
    $133 = Math_fround($113 * $127);
    $134 = Math_fround($113 * $126);
    $135 = Math_fround($109 * $127);
    $136 = Math_fround($113 * $128);
    $137 = Math_fround($109 * $129);
    $138 = Math_fround($130 - $134);
    $139 = Math_fround($131 - $135);
    $140 = Math_fround($132 - $136);
    $141 = Math_fround($133 - $137);
    $142 = Math_fround($115 * $129);
    $143 = Math_fround($113 * $129);
    $144 = Math_fround($109 * $126);
    $145 = Math_fround($111 * $126);
    $146 = Math_fround($138 - $142);
    $147 = Math_fround($139 - $143);
    $148 = Math_fround($140 - $144);
    $149 = Math_fround($141 - $145);
    $150 = Math_fround($111 * $127);
    $151 = Math_fround($111 * $128);
    $152 = Math_fround($115 * $127);
    $153 = Math_fround($115 * $128);
    $154 = Math_fround($146 - $150);
    $155 = Math_fround($147 - $151);
    $156 = Math_fround($148 - $152);
    $157 = Math_fround($149 - $153);
    $158 = Math_fround($156 * Math_fround(-1.0));
    $159 = Math_fround($157 * Math_fround(-1.0));
    $160 = Math_fround($154 * Math_fround(-1.0));
    $161 = Math_fround($158 * $loopWeight);
    $162 = Math_fround($159 * $loopWeight);
    $163 = Math_fround($160 * $loopWeight);
    $164 = Math_fround($161 * $161);
    $165 = Math_fround($162 * $162);
    $166 = Math_fround($163 * $163);
    $167 = Math_fround($155 * $155);
    $168 = Math_fround($164 + $165);
    $169 = Math_fround($167 + $166);
    $170 = Math_fround($168 + $169);
    $171 = (Math_fround(Math_sqrt((Math_fround($170)))));
    $172 = Math_fround(Math_fround(1.0) / $171);
    $173 = Math_fround($172 * $161);
    $174 = Math_fround($172 * $162);
    $175 = Math_fround($172 * $163);
    $176 = Math_fround($172 * $155);
    $177 = Math_fround($100 * $173);
    $178 = Math_fround($104 * $176);
    $179 = Math_fround($102 * $174);
    $180 = Math_fround($98 * $175);
    $181 = Math_fround($104 * $175);
    $182 = Math_fround($98 * $173);
    $183 = Math_fround($100 * $175);
    $184 = Math_fround($102 * $173);
    $185 = Math_fround($177 - $181);
    $186 = Math_fround($178 - $182);
    $187 = Math_fround($179 - $183);
    $188 = Math_fround($180 - $184);
    $189 = Math_fround($102 * $176);
    $190 = Math_fround($102 * $175);
    $191 = Math_fround($104 * $173);
    $192 = Math_fround($104 * $174);
    $193 = Math_fround($185 - $189);
    $194 = Math_fround($186 - $190);
    $195 = Math_fround($187 - $191);
    $196 = Math_fround($188 - $192);
    $197 = Math_fround($98 * $174);
    $198 = Math_fround($100 * $174);
    $199 = Math_fround($98 * $176);
    $200 = Math_fround($100 * $176);
    $201 = Math_fround($193 - $197);
    $202 = Math_fround($194 - $198);
    $203 = Math_fround($195 - $199);
    $204 = Math_fround($196 - $200);
    $205 = Math_fround($203 * Math_fround(-1.0));
    $206 = Math_fround($204 * Math_fround(-1.0));
    $207 = Math_fround($201 * Math_fround(-1.0));
    $208 = Math_fround($205 * $205);
    $209 = Math_fround($206 * $206);
    $210 = Math_fround($207 * $207);
    $211 = Math_fround($202 * $202);
    $212 = Math_fround($208 + $209);
    $213 = Math_fround($211 + $210);
    $214 = Math_fround($212 + $213);
    $215 = (Math_fround(Math_sqrt((Math_fround($214)))));
    $216 = Math_fround(Math_fround(1.0) / $215);
    $217 = Math_fround($216 * $205);
    $218 = Math_fround($216 * $206);
    $219 = Math_fround($216 * $207);
    $220 = Math_fround($216 * $202);
    HEAP32[$23>>2] = $96;
    HEAPF32[$97>>2] = $217;
    HEAPF32[$99>>2] = $218;
    HEAPF32[$101>>2] = $219;
    HEAPF32[$103>>2] = $220;
    $$pre79 = HEAP32[$12>>2]|0;
    $223 = $$pre79;
   }
   $221 = (($valueIndex1$074) + 1)|0;
   $222 = ($221>>>0)<($223>>>0);
   if ($222) {
    $314 = $223;$valueIndex1$074 = $221;
   } else {
    break;
   }
  }
 }
 $76 = (($values) + 60|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0);
 if (!($78)) {
  $79 = (($mask) + 64|0);
  $80 = $79;
  $81 = (($values) + 64|0);
  $82 = $81;
  $83 = (($starts) + 64|0);
  $84 = $83;
  $85 = (($stops) + 64|0);
  $86 = $85;
  $87 = (($values) + 68|0);
  $$pre = HEAP32[$79>>2]|0;
  $valueIndex2$071 = 0;
  while(1) {
   $239 = (($$pre) + ($80))|0;
   $240 = $239;
   $241 = (($240) + ($valueIndex2$071)|0);
   $242 = HEAP8[$241>>0]|0;
   $243 = ($242<<24>>24)==(0);
   if (!($243)) {
    $244 = HEAP32[$81>>2]|0;
    $245 = (($244) + ($82))|0;
    $246 = $245;
    $247 = (($246) + ($valueIndex2$071<<4)|0);
    $248 = Math_fround(HEAPF32[$247>>2]);
    $249 = ((($246) + ($valueIndex2$071<<4)|0) + 4|0);
    $250 = Math_fround(HEAPF32[$249>>2]);
    $251 = ((($246) + ($valueIndex2$071<<4)|0) + 8|0);
    $252 = Math_fround(HEAPF32[$251>>2]);
    $253 = ((($246) + ($valueIndex2$071<<4)|0) + 12|0);
    $254 = Math_fround(HEAPF32[$253>>2]);
    $255 = HEAP32[$83>>2]|0;
    $256 = (($255) + ($84))|0;
    $257 = $256;
    $258 = (($257) + ($valueIndex2$071<<4)|0);
    $259 = Math_fround(HEAPF32[$258>>2]);
    $260 = ((($257) + ($valueIndex2$071<<4)|0) + 4|0);
    $261 = Math_fround(HEAPF32[$260>>2]);
    $262 = ((($257) + ($valueIndex2$071<<4)|0) + 8|0);
    $263 = Math_fround(HEAPF32[$262>>2]);
    $264 = ((($257) + ($valueIndex2$071<<4)|0) + 12|0);
    $265 = Math_fround(HEAPF32[$264>>2]);
    $266 = HEAP32[$85>>2]|0;
    $267 = (($266) + ($86))|0;
    $268 = $267;
    $269 = (($268) + ($valueIndex2$071<<4)|0);
    $270 = Math_fround(HEAPF32[$269>>2]);
    $271 = ((($268) + ($valueIndex2$071<<4)|0) + 4|0);
    $272 = Math_fround(HEAPF32[$271>>2]);
    $273 = ((($268) + ($valueIndex2$071<<4)|0) + 8|0);
    $274 = Math_fround(HEAPF32[$273>>2]);
    $275 = ((($268) + ($valueIndex2$071<<4)|0) + 12|0);
    $276 = Math_fround(HEAPF32[$275>>2]);
    $277 = Math_fround($259 - $270);
    $278 = Math_fround($261 - $272);
    $279 = Math_fround($263 - $274);
    $280 = Math_fround($265 - $276);
    $281 = Math_fround($277 * $loopWeight);
    $282 = Math_fround($278 * $loopWeight);
    $283 = Math_fround($279 * $loopWeight);
    $284 = Math_fround($280 * $loopWeight);
    $285 = Math_fround($248 + $281);
    $286 = Math_fround($250 + $282);
    $287 = Math_fround($252 + $283);
    $288 = Math_fround($254 + $284);
    HEAP32[$87>>2] = $246;
    HEAPF32[$247>>2] = $285;
    HEAPF32[$249>>2] = $286;
    HEAPF32[$251>>2] = $287;
    HEAPF32[$253>>2] = $288;
   }
   $289 = (($valueIndex2$071) + 1)|0;
   $290 = ($289>>>0)<($77>>>0);
   if ($290) {
    $valueIndex2$071 = $289;
   } else {
    break;
   }
  }
 }
 $224 = (($values) + 24|0);
 $225 = HEAP32[$224>>2]|0;
 $226 = ($225|0)==(0);
 if ($226) {
  STACKTOP = sp;return;
 }
 $227 = (($mask) + 28|0);
 $228 = $227;
 $229 = HEAP32[$227>>2]|0;
 $230 = (($229) + ($228))|0;
 $231 = $230;
 $232 = (($values) + 28|0);
 $233 = $232;
 $234 = (($starts) + 28|0);
 $235 = $234;
 $236 = (($stops) + 28|0);
 $237 = $236;
 $238 = (($values) + 32|0);
 $valueIndex3$069 = 0;
 while(1) {
  $291 = (($231) + ($valueIndex3$069)|0);
  $292 = HEAP8[$291>>0]|0;
  $293 = ($292<<24>>24)==(0);
  if (!($293)) {
   $294 = HEAP32[$232>>2]|0;
   $295 = (($294) + ($233))|0;
   $296 = $295;
   $297 = (($296) + ($valueIndex3$069<<2)|0);
   $298 = Math_fround(HEAPF32[$297>>2]);
   $299 = HEAP32[$234>>2]|0;
   $300 = (($299) + ($235))|0;
   $301 = $300;
   $302 = (($301) + ($valueIndex3$069<<2)|0);
   $303 = Math_fround(HEAPF32[$302>>2]);
   $304 = HEAP32[$236>>2]|0;
   $305 = (($304) + ($237))|0;
   $306 = $305;
   $307 = (($306) + ($valueIndex3$069<<2)|0);
   $308 = Math_fround(HEAPF32[$307>>2]);
   $309 = Math_fround($303 - $308);
   $310 = Math_fround($309 * $loopWeight);
   $311 = Math_fround($298 + $310);
   HEAP32[$238>>2] = $296;
   HEAPF32[$297>>2] = $311;
  }
  $312 = (($valueIndex3$069) + 1)|0;
  $313 = ($312>>>0)<($225>>>0);
  if ($313) {
   $valueIndex3$069 = $312;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj($aValueArrayConstant,$id) {
 $aValueArrayConstant = $aValueArrayConstant|0;
 $id = $id|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($aValueArrayConstant|0)==(0|0);
 L1: do {
  if ($0) {
   $$0 = -1;
  } else {
   $1 = (($aValueArrayConstant) + 4|0);
   $2 = HEAP32[$aValueArrayConstant>>2]|0;
   $3 = ($2|0)==(0);
   if ($3) {
    $$0 = -1;
   } else {
    $4 = $1;
    $5 = HEAP32[$1>>2]|0;
    $6 = (($5) + ($4))|0;
    $7 = $6;
    $i$01 = 0;
    while(1) {
     $10 = (($7) + ($i$01<<4)|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==($id|0);
     $9 = (($i$01) + 1)|0;
     if ($12) {
      $$0 = $i$01;
      break L1;
     }
     $8 = ($9>>>0)<($2>>>0);
     if ($8) {
      $i$01 = $9;
     } else {
      $$0 = -1;
      break;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN7mecanim4hand10FingerNameEj($aFinger) {
 $aFinger = $aFinger|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (796368 + ($aFinger<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN7mecanim4hand12PhalangeNameEj($aFinger) {
 $aFinger = $aFinger|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (796432 + ($aFinger<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN7mecanim4hand13FingerDoFNameEj($aFinger) {
 $aFinger = $aFinger|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (796488 + ($aFinger<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN7mecanim4hand8HandPoseC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $scevgep = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = (($this) + 44|0);
 $2 = (($this) + 40|0);
 $3 = (($this) + 36|0);
 $4 = (($this) + 32|0);
 $scevgep = (($this) + 48|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;
 dest=$scevgep+0|0; stop=dest+96|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$0>>2] = Math_fround(1.0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim4hand12HandPoseCopyEPKNS0_8HandPoseEPS1_($apHandPoseSrc,$apHandPoseDst) {
 $apHandPoseSrc = $apHandPoseSrc|0;
 $apHandPoseDst = $apHandPoseDst|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apHandPoseSrc) + 48|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($apHandPoseDst) + 48|0);
 HEAPF32[$2>>2] = $1;
 $3 = (($apHandPoseSrc) + 52|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($apHandPoseDst) + 52|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($apHandPoseSrc) + 56|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($apHandPoseDst) + 56|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($apHandPoseSrc) + 60|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($apHandPoseDst) + 60|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($apHandPoseSrc) + 64|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($apHandPoseDst) + 64|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($apHandPoseSrc) + 68|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($apHandPoseDst) + 68|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($apHandPoseSrc) + 72|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = (($apHandPoseDst) + 72|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($apHandPoseSrc) + 76|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($apHandPoseDst) + 76|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($apHandPoseSrc) + 80|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($apHandPoseDst) + 80|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($apHandPoseSrc) + 84|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($apHandPoseDst) + 84|0);
 HEAPF32[$29>>2] = $28;
 $30 = (($apHandPoseSrc) + 88|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = (($apHandPoseDst) + 88|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($apHandPoseSrc) + 92|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($apHandPoseDst) + 92|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($apHandPoseSrc) + 96|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($apHandPoseDst) + 96|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($apHandPoseSrc) + 100|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($apHandPoseDst) + 100|0);
 HEAPF32[$41>>2] = $40;
 $42 = (($apHandPoseSrc) + 104|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($apHandPoseDst) + 104|0);
 HEAPF32[$44>>2] = $43;
 $45 = (($apHandPoseSrc) + 108|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($apHandPoseDst) + 108|0);
 HEAPF32[$47>>2] = $46;
 $48 = (($apHandPoseSrc) + 112|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($apHandPoseDst) + 112|0);
 HEAPF32[$50>>2] = $49;
 $51 = (($apHandPoseSrc) + 116|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = (($apHandPoseDst) + 116|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($apHandPoseSrc) + 120|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($apHandPoseDst) + 120|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($apHandPoseSrc) + 124|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($apHandPoseDst) + 124|0);
 HEAPF32[$59>>2] = $58;
 STACKTOP = sp;return;
}
function __ZN7mecanim4hand17Hand2SkeletonPoseEPKNS0_4HandEPKNS_8skeleton8SkeletonEPKNS0_8HandPoseEPNS4_12SkeletonPoseE($apHand,$apSkeleton,$apHandPose,$apSkeletonPose) {
 $apHand = $apHand|0;
 $apSkeleton = $apSkeleton|0;
 $apHandPose = $apHandPose|0;
 $apSkeletonPose = $apSkeletonPose|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $f$06 = 0, $xyz = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $xyz = sp;
 $0 = (($xyz) + 4|0);
 $1 = (($xyz) + 8|0);
 $2 = (($xyz) + 12|0);
 $f$06 = 0;
 while(1) {
  $3 = ($f$06*3)|0;
  $4 = $f$06 << 2;
  $5 = (($apHand) + ($3<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>(-1);
  if ($7) {
   $8 = $4 | 1;
   $9 = ((($apHandPose) + ($8<<2)|0) + 48|0);
   $10 = Math_fround(HEAPF32[$9>>2]);
   $11 = ((($apHandPose) + ($4<<2)|0) + 48|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   HEAPF32[$xyz>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = $10;
   HEAPF32[$1>>2] = $12;
   HEAPF32[$2>>2] = Math_fround(0.0);
   __ZN7mecanim8skeleton14SkeletonSetDoFEPKNS0_8SkeletonEPNS0_12SkeletonPoseERKN4math7_float4Ei($apSkeleton,$apSkeletonPose,$xyz,$6);
  }
  $13 = (($3) + 1)|0;
  $14 = (($apHand) + ($13<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)>(-1);
  if ($16) {
   $17 = $4 | 2;
   $18 = ((($apHandPose) + ($17<<2)|0) + 48|0);
   $19 = Math_fround(HEAPF32[$18>>2]);
   HEAPF32[$xyz>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = Math_fround(0.0);
   HEAPF32[$1>>2] = $19;
   HEAPF32[$2>>2] = Math_fround(0.0);
   __ZN7mecanim8skeleton14SkeletonSetDoFEPKNS0_8SkeletonEPNS0_12SkeletonPoseERKN4math7_float4Ei($apSkeleton,$apSkeletonPose,$xyz,$15);
  }
  $20 = (($3) + 2)|0;
  $21 = (($apHand) + ($20<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)>(-1);
  if ($23) {
   $24 = $4 | 3;
   $25 = ((($apHandPose) + ($24<<2)|0) + 48|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   HEAPF32[$xyz>>2] = Math_fround(0.0);
   HEAPF32[$0>>2] = Math_fround(0.0);
   HEAPF32[$1>>2] = $26;
   HEAPF32[$2>>2] = Math_fround(0.0);
   __ZN7mecanim8skeleton14SkeletonSetDoFEPKNS0_8SkeletonEPNS0_12SkeletonPoseERKN4math7_float4Ei($apSkeleton,$apSkeletonPose,$xyz,$22);
  }
  $27 = (($f$06) + 1)|0;
  $exitcond = ($27|0)==(5);
  if ($exitcond) {
   break;
  } else {
   $f$06 = $27;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim5human8BoneNameEj($aBoneIndex) {
 $aBoneIndex = $aBoneIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (796560 + ($aBoneIndex<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN7mecanim5human10MuscleNameEj($aBoneIndex) {
 $aBoneIndex = $aBoneIndex|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (796984 + ($aBoneIndex<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN7mecanim5human19MaskHasLeftFootGoalERKNS_6bitsetILj59EEE($mask) {
 $mask = $mask|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($mask) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2097152;
 $3 = ($2|0)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN7mecanim5human20MaskHasRightFootGoalERKNS_6bitsetILj59EEE($mask) {
 $mask = $mask|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($mask) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4194304;
 $3 = ($2|0)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN7mecanim5human9HumanPoseC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;HEAP32[$this+20>>2]=0|0;HEAP32[$this+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($this) + 44|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 40|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($this) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($this) + 32|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 80|0);
 $6 = (($this) + 108|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;HEAP32[$5+24>>2]=0|0;
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($this) + 124|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($this) + 120|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 116|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 112|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($this) + 128|0);
 $12 = (($this) + 184|0);
 dest=$11+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($this) + 200|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($this) + 196|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($this) + 192|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($this) + 188|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($this) + 204|0);
 $18 = (($this) + 260|0);
 dest=$17+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 276|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($this) + 272|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($this) + 268|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 264|0);
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($this) + 280|0);
 $24 = (($this) + 336|0);
 dest=$23+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($this) + 352|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($this) + 348|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($this) + 344|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($this) + 340|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($this) + 356|0);
 ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;HEAP32[$29+16>>2]=0|0;HEAP32[$29+20>>2]=0|0;HEAP32[$29+24>>2]=0|0;
 $30 = (($this) + 384|0);
 __ZN7mecanim4hand8HandPoseC2Ev($30);
 $31 = (($this) + 528|0);
 __ZN7mecanim4hand8HandPoseC2Ev($31);
 $scevgep = (($this) + 672|0);
 _memset(($scevgep|0),0,208)|0;
 $32 = (($this) + 48|0);
 ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;HEAP32[$32+20>>2]=0|0;HEAP32[$32+24>>2]=0|0;HEAP32[$32+28>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human21HumanComputeRootXformEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseE($agg$result,$apHuman,$apPoseGlobal) {
 $agg$result = $agg$result|0;
 $apHuman = $apHuman|0;
 $apPoseGlobal = $apPoseGlobal|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $exitcond$i = 0, $i$09$i = 0, $mass$08$i = Math_fround(0), $mass$1$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($0) + 4|0);
 $3 = (($0) + 8|0);
 $4 = (($0) + 12|0);
 $19 = Math_fround(0.0);$21 = Math_fround(0.0);$23 = Math_fround(0.0);$25 = Math_fround(0.0);$i$09$i = 0;$mass$08$i = Math_fround(0.0);
 while(1) {
  $5 = ((($apHuman) + ($i$09$i<<2)|0) + 104|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>(-1);
  if ($7) {
   $8 = ((($apHuman) + ($i$09$i<<2)|0) + 200|0);
   $9 = Math_fround(HEAPF32[$8>>2]);
   __ZN7mecanim5human26HumanComputeBoneMassCenterEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseEi($0,$apHuman,$apPoseGlobal,$i$09$i);
   $10 = Math_fround(HEAPF32[$0>>2]);
   $11 = Math_fround($9 * $10);
   $12 = Math_fround(HEAPF32[$2>>2]);
   $13 = Math_fround($9 * $12);
   $14 = Math_fround(HEAPF32[$3>>2]);
   $15 = Math_fround($9 * $14);
   $16 = Math_fround(HEAPF32[$4>>2]);
   $17 = Math_fround($9 * $16);
   $18 = Math_fround($19 + $11);
   $20 = Math_fround($21 + $13);
   $22 = Math_fround($23 + $15);
   $24 = Math_fround($25 + $17);
   $26 = Math_fround($mass$08$i + $9);
   $29 = $18;$31 = $20;$33 = $22;$35 = $24;$mass$1$i = $26;
  } else {
   $29 = $19;$31 = $21;$33 = $23;$35 = $25;$mass$1$i = $mass$08$i;
  }
  $27 = (($i$09$i) + 1)|0;
  $exitcond$i = ($27|0)==(24);
  if ($exitcond$i) {
   break;
  } else {
   $19 = $29;$21 = $31;$23 = $33;$25 = $35;$i$09$i = $27;$mass$08$i = $mass$1$i;
  }
 }
 $28 = Math_fround($29 / $mass$1$i);
 $30 = Math_fround($31 / $mass$1$i);
 $32 = Math_fround($33 / $mass$1$i);
 $34 = Math_fround($35 / $mass$1$i);
 __ZN7mecanim5human23HumanComputeOrientationEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseE($1,$apHuman,$apPoseGlobal);
 HEAPF32[$agg$result>>2] = $28;
 $36 = (($agg$result) + 4|0);
 HEAPF32[$36>>2] = $30;
 $37 = (($agg$result) + 8|0);
 HEAPF32[$37>>2] = $32;
 $38 = (($agg$result) + 12|0);
 HEAPF32[$38>>2] = $34;
 $39 = Math_fround(HEAPF32[$1>>2]);
 $40 = (($1) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($1) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($1) + 12|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($agg$result) + 16|0);
 HEAPF32[$46>>2] = $39;
 $47 = (($agg$result) + 20|0);
 HEAPF32[$47>>2] = $41;
 $48 = (($agg$result) + 24|0);
 HEAPF32[$48>>2] = $43;
 $49 = (($agg$result) + 28|0);
 HEAPF32[$49>>2] = $45;
 $50 = (($agg$result) + 32|0);
 HEAPF32[$50>>2] = Math_fround(1.0);
 $51 = (($agg$result) + 36|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 $52 = (($agg$result) + 40|0);
 HEAPF32[$52>>2] = Math_fround(1.0);
 $53 = (($agg$result) + 44|0);
 HEAPF32[$53>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN4mathL8xformMulERKNS_5xformES2_19323($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($a) + 32|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($b) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($a) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = (($b) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = (($b) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $17);
 $19 = Math_fround($3 + $3);
 $20 = Math_fround($8 + $8);
 $21 = Math_fround($13 + $13);
 $22 = (($a) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($20 * $23);
 $25 = (($a) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($21 * $26);
 $28 = (($a) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($19 * $29);
 $31 = (($a) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(0.0));
 $34 = Math_fround($19 * $26);
 $35 = Math_fround($20 * $29);
 $36 = Math_fround($21 * $23);
 $37 = Math_fround($24 - $34);
 $38 = Math_fround($27 - $35);
 $39 = Math_fround($30 - $36);
 $40 = Math_fround($33 - $33);
 $41 = Math_fround($32 * $38);
 $42 = Math_fround($32 * $39);
 $43 = Math_fround($37 * $32);
 $44 = Math_fround($32 * $40);
 $45 = Math_fround($3 + $41);
 $46 = Math_fround($8 + $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 * $39);
 $50 = Math_fround($26 * $37);
 $51 = Math_fround($29 * $38);
 $52 = Math_fround($26 * $38);
 $53 = Math_fround($29 * $39);
 $54 = Math_fround($23 * $37);
 $55 = Math_fround($49 - $52);
 $56 = Math_fround($50 - $53);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($44 - $44);
 $59 = Math_fround($45 + $56);
 $60 = Math_fround($46 + $57);
 $61 = Math_fround($47 + $55);
 $62 = Math_fround($48 + $58);
 $63 = Math_fround(HEAPF32[$a>>2]);
 $64 = Math_fround($63 + $59);
 $65 = (($a) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 + $60);
 $68 = (($a) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $61);
 $71 = (($a) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 + $62);
 $74 = (($b) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($26 * $75);
 $77 = (($b) + 28|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($32 * $78);
 $80 = (($b) + 20|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($29 * $81);
 $83 = (($b) + 24|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($23 * $84);
 $86 = Math_fround($32 * $84);
 $87 = Math_fround($75 * $23);
 $88 = Math_fround($26 * $84);
 $89 = Math_fround($75 * $29);
 $90 = Math_fround($76 - $86);
 $91 = Math_fround($79 - $87);
 $92 = Math_fround($82 - $88);
 $93 = Math_fround($85 - $89);
 $94 = Math_fround($78 * $29);
 $95 = Math_fround($29 * $84);
 $96 = Math_fround($75 * $32);
 $97 = Math_fround($32 * $81);
 $98 = Math_fround($90 - $94);
 $99 = Math_fround($91 - $95);
 $100 = Math_fround($92 - $96);
 $101 = Math_fround($93 - $97);
 $102 = Math_fround($81 * $23);
 $103 = Math_fround($26 * $81);
 $104 = Math_fround($78 * $23);
 $105 = Math_fround($26 * $78);
 $106 = Math_fround($98 - $102);
 $107 = Math_fround($99 - $103);
 $108 = Math_fround($100 - $104);
 $109 = Math_fround($101 - $105);
 $110 = Math_fround($108 * Math_fround(-1.0));
 $111 = Math_fround($109 * Math_fround(-1.0));
 $112 = Math_fround($106 * Math_fround(-1.0));
 $113 = Math_fround($110 * $110);
 $114 = Math_fround($111 * $111);
 $115 = Math_fround($112 * $112);
 $116 = Math_fround($107 * $107);
 $117 = Math_fround($113 + $114);
 $118 = Math_fround($116 + $115);
 $119 = Math_fround($117 + $118);
 $120 = (Math_fround(Math_sqrt((Math_fround($119)))));
 $121 = Math_fround(Math_fround(1.0) / $120);
 $122 = Math_fround($121 * $110);
 $123 = Math_fround($121 * $111);
 $124 = Math_fround($121 * $112);
 $125 = Math_fround($121 * $107);
 $126 = Math_fround(HEAPF32[$1>>2]);
 $127 = (($b) + 32|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($126 * $128);
 $130 = Math_fround(HEAPF32[$6>>2]);
 $131 = (($b) + 36|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($130 * $132);
 $134 = Math_fround(HEAPF32[$11>>2]);
 $135 = (($b) + 40|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($134 * $136);
 $138 = Math_fround(HEAPF32[$16>>2]);
 $139 = (($b) + 44|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($138 * $140);
 HEAPF32[$agg$result>>2] = $64;
 $142 = (($agg$result) + 4|0);
 HEAPF32[$142>>2] = $67;
 $143 = (($agg$result) + 8|0);
 HEAPF32[$143>>2] = $70;
 $144 = (($agg$result) + 12|0);
 HEAPF32[$144>>2] = $73;
 $145 = (($agg$result) + 16|0);
 HEAPF32[$145>>2] = $122;
 $146 = (($agg$result) + 20|0);
 HEAPF32[$146>>2] = $123;
 $147 = (($agg$result) + 24|0);
 HEAPF32[$147>>2] = $124;
 $148 = (($agg$result) + 28|0);
 HEAPF32[$148>>2] = $125;
 $149 = (($agg$result) + 32|0);
 HEAPF32[$149>>2] = $129;
 $150 = (($agg$result) + 36|0);
 HEAPF32[$150>>2] = $133;
 $151 = (($agg$result) + 40|0);
 HEAPF32[$151>>2] = $137;
 $152 = (($agg$result) + 44|0);
 HEAPF32[$152>>2] = $141;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human30HumanPoseAdjustForMissingBonesEPKNS0_5HumanEPNS0_9HumanPoseE($apHuman,$apHumanPose) {
 $apHuman = $apHuman|0;
 $apHumanPose = $apHumanPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apHuman) + 140|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<(0);
 if ($2) {
  $3 = (($apHumanPose) + 696|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($apHumanPose) + 708|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 + $6);
  HEAPF32[$5>>2] = $7;
  HEAPF32[$3>>2] = Math_fround(0.0);
  $8 = (($apHumanPose) + 700|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($apHumanPose) + 712|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($9 + $11);
  HEAPF32[$10>>2] = $12;
  HEAPF32[$8>>2] = Math_fround(0.0);
  $13 = (($apHumanPose) + 704|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = (($apHumanPose) + 716|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($14 + $16);
  HEAPF32[$15>>2] = $17;
  HEAPF32[$13>>2] = Math_fround(0.0);
 }
 $18 = (($apHuman) + 136|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)<(0);
 if ($20) {
  $21 = (($apHumanPose) + 684|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($apHumanPose) + 672|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($22 + $24);
  HEAPF32[$23>>2] = $25;
  HEAPF32[$21>>2] = Math_fround(0.0);
  $26 = (($apHumanPose) + 688|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($apHumanPose) + 676|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($27 + $29);
  HEAPF32[$28>>2] = $30;
  HEAPF32[$26>>2] = Math_fround(0.0);
  $31 = (($apHumanPose) + 692|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($apHumanPose) + 680|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($32 + $34);
  HEAPF32[$33>>2] = $35;
  HEAPF32[$31>>2] = Math_fround(0.0);
 }
 $36 = (($apHuman) + 148|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)<(0);
 if ($38) {
  $39 = (($apHumanPose) + 808|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($40 * Math_fround(0.150000005960464477539));
  $42 = (($apHumanPose) + 816|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($43 + $41);
  HEAPF32[$42>>2] = $44;
  HEAPF32[$39>>2] = Math_fround(0.0);
  $45 = (($apHumanPose) + 812|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround($46 * Math_fround(0.28125));
  $48 = (($apHumanPose) + 820|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = Math_fround($49 + $47);
  HEAPF32[$48>>2] = $50;
  HEAPF32[$45>>2] = Math_fround(0.0);
 }
 $51 = (($apHuman) + 152|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($52|0)<(0);
 if (!($53)) {
  STACKTOP = sp;return;
 }
 $54 = (($apHumanPose) + 844|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($55 * Math_fround(0.150000005960464477539));
 $57 = (($apHumanPose) + 852|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($58 + $56);
 HEAPF32[$57>>2] = $59;
 HEAPF32[$54>>2] = Math_fround(0.0);
 $60 = (($apHumanPose) + 848|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 * Math_fround(0.28125));
 $63 = (($apHumanPose) + 856|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($64 + $62);
 HEAPF32[$63>>2] = $65;
 HEAPF32[$60>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human18Human2SkeletonPoseEPKNS0_5HumanEPKNS0_9HumanPoseEPNS_8skeleton12SkeletonPoseE($apHuman,$apHumanPose,$apSkeletonPose) {
 $apHuman = $apHuman|0;
 $apHumanPose = $apHumanPose|0;
 $apSkeletonPose = $apSkeletonPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $xyz$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $xyz$i = sp;
 $0 = (($xyz$i) + 4|0);
 $1 = (($xyz$i) + 8|0);
 $2 = (($xyz$i) + 12|0);
 $3 = (($apHuman) + 48|0);
 $4 = $3;
 $5 = (($apHuman) + 52|0);
 $i$01 = 1;
 while(1) {
  $6 = ((($apHuman) + ($i$01<<2)|0) + 104|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(-1);
  if (!($8)) {
   $9 = ((798496 + (($i$01*12)|0)|0) + 8|0);
   $10 = 124830 >>> $i$01;
   $11 = $10 & 1;
   $12 = (0 - ($11))|0;
   $13 = ((798496 + (($i$01*12)|0)|0) + 4|0);
   $14 = 15106022 >>> $i$01;
   $15 = $14 & 1;
   $16 = (0 - ($15))|0;
   $17 = (798496 + (($i$01*12)|0)|0);
   $18 = HEAP32[$9>>2]|0;
   $19 = ((($apHumanPose) + ($18<<2)|0) + 672|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = HEAP32[$13>>2]|0;
   $22 = ((($apHumanPose) + ($21<<2)|0) + 672|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = HEAP32[$17>>2]|0;
   $25 = ((($apHumanPose) + ($24<<2)|0) + 672|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = (HEAPF32[tempDoublePtr>>2]=$20,HEAP32[tempDoublePtr>>2]|0);
   $28 = $27 & $12;
   $29 = (HEAP32[tempDoublePtr>>2]=$28,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $30 = (HEAPF32[tempDoublePtr>>2]=$23,HEAP32[tempDoublePtr>>2]|0);
   $31 = $30 & $16;
   $32 = (HEAP32[tempDoublePtr>>2]=$31,Math_fround(HEAPF32[tempDoublePtr>>2]));
   HEAPF32[$xyz$i>>2] = $29;
   HEAPF32[$0>>2] = $32;
   HEAPF32[$1>>2] = $26;
   HEAPF32[$2>>2] = Math_fround(0.0);
   $33 = HEAP32[$3>>2]|0;
   $34 = (($33) + ($4))|0;
   $35 = $34;
   HEAP32[$5>>2] = $35;
   $36 = HEAP32[$6>>2]|0;
   __ZN7mecanim8skeleton14SkeletonSetDoFEPKNS0_8SkeletonEPNS0_12SkeletonPoseERKN4math7_float4Ei($35,$apSkeletonPose,$xyz$i,$36);
  }
  $37 = (($i$01) + 1)|0;
  $exitcond = ($37|0)==(24);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $37;
  }
 }
 $38 = (($apHuman) + 424|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if (!($40)) {
  $41 = (($apHuman) + 64|0);
  $42 = $41;
  $43 = HEAP32[$41>>2]|0;
  $44 = (($43) + ($42))|0;
  $45 = $44;
  $46 = (($apHuman) + 68|0);
  HEAP32[$46>>2] = $45;
  $47 = HEAP32[$3>>2]|0;
  $48 = (($47) + ($4))|0;
  $49 = $48;
  HEAP32[$5>>2] = $49;
  $50 = (($apHumanPose) + 384|0);
  __ZN7mecanim4hand17Hand2SkeletonPoseEPKNS0_4HandEPKNS_8skeleton8SkeletonEPKNS0_8HandPoseEPNS4_12SkeletonPoseE($45,$49,$50,$apSkeletonPose);
 }
 $51 = (($apHuman) + 425|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = ($52<<24>>24)==(0);
 if ($53) {
  STACKTOP = sp;return;
 }
 $54 = (($apHuman) + 72|0);
 $55 = $54;
 $56 = HEAP32[$54>>2]|0;
 $57 = (($56) + ($55))|0;
 $58 = $57;
 $59 = (($apHuman) + 76|0);
 HEAP32[$59>>2] = $58;
 $60 = HEAP32[$3>>2]|0;
 $61 = (($60) + ($4))|0;
 $62 = $61;
 HEAP32[$5>>2] = $62;
 $63 = (($apHumanPose) + 528|0);
 __ZN7mecanim4hand17Hand2SkeletonPoseEPKNS0_4HandEPKNS_8skeleton8SkeletonEPKNS0_8HandPoseEPNS4_12SkeletonPoseE($58,$62,$63,$apSkeletonPose);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human26HumanComputeBoneMassCenterEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseEi($agg$result,$apHuman,$apSkeletonPose,$aBoneIndex) {
 $agg$result = $agg$result|0;
 $apHuman = $apHuman|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $aBoneIndex = $aBoneIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0);
 var $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = Math_fround(0), $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = Math_fround(0), $248 = 0, $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = Math_fround(0), $258 = 0, $259 = Math_fround(0), $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = Math_fround(0), $280 = Math_fround(0), $281 = 0, $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = Math_fround(0), $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = Math_fround(0), $293 = Math_fround(0), $294 = 0, $295 = Math_fround(0), $296 = 0;
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0);
 var $314 = 0, $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = Math_fround(0), $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0);
 var $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = 0, $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = Math_fround(0), $38 = Math_fround(0), $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0), $385 = 0, $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = 0, $389 = Math_fround(0), $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = 0, $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0), $410 = 0, $411 = 0, $412 = Math_fround(0), $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = 0, $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = 0;
 var $422 = Math_fround(0), $423 = 0, $424 = Math_fround(0), $425 = Math_fround(0), $426 = 0, $427 = Math_fround(0), $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0), $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0);
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = Math_fround(0), $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = Math_fround(0);
 var $459 = 0, $46 = Math_fround(0), $460 = Math_fround(0), $461 = 0, $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = Math_fround(0), $479 = 0, $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = Math_fround(0), $487 = 0, $488 = Math_fround(0), $489 = 0, $49 = Math_fround(0), $490 = Math_fround(0), $491 = Math_fround(0), $492 = 0, $493 = Math_fround(0), $494 = 0;
 var $495 = Math_fround(0), $496 = Math_fround(0), $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = Math_fround(0);
 var $512 = 0, $513 = Math_fround(0), $514 = Math_fround(0), $515 = 0, $516 = Math_fround(0), $517 = 0, $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = Math_fround(0), $524 = Math_fround(0), $525 = 0, $526 = Math_fround(0), $527 = 0, $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0;
 var $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = Math_fround(0), $545 = 0, $546 = Math_fround(0), $547 = Math_fround(0), $548 = 0;
 var $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = Math_fround(0), $552 = Math_fround(0), $553 = 0, $554 = Math_fround(0), $555 = 0, $556 = Math_fround(0), $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0);
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = Math_fround(0), $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = 0, $582 = Math_fround(0), $583 = 0, $584 = Math_fround(0);
 var $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = 0, $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = 0, $592 = Math_fround(0), $593 = 0, $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = Math_fround(0), $609 = 0, $61 = Math_fround(0), $610 = Math_fround(0), $611 = 0, $612 = Math_fround(0), $613 = 0, $614 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0;
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 12|0);
 $1 = (($agg$result) + 8|0);
 $2 = (($agg$result) + 4|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 do {
  switch ($aBoneIndex|0) {
  case 3:  {
   $303 = (($apSkeletonPose) + 4|0);
   $304 = (($apHuman) + 116|0);
   $305 = HEAP32[$304>>2]|0;
   $306 = $303;
   $307 = HEAP32[$303>>2]|0;
   $308 = (($307) + ($306))|0;
   $309 = $308;
   $310 = (($apHuman) + 124|0);
   $311 = HEAP32[$310>>2]|0;
   $312 = (($309) + (($305*48)|0)|0);
   $313 = Math_fround(HEAPF32[$312>>2]);
   $314 = (($309) + (($311*48)|0)|0);
   $315 = Math_fround(HEAPF32[$314>>2]);
   $316 = Math_fround($313 + $315);
   $317 = ((($309) + (($305*48)|0)|0) + 4|0);
   $318 = Math_fround(HEAPF32[$317>>2]);
   $319 = ((($309) + (($311*48)|0)|0) + 4|0);
   $320 = Math_fround(HEAPF32[$319>>2]);
   $321 = Math_fround($318 + $320);
   $322 = ((($309) + (($305*48)|0)|0) + 8|0);
   $323 = Math_fround(HEAPF32[$322>>2]);
   $324 = ((($309) + (($311*48)|0)|0) + 8|0);
   $325 = Math_fround(HEAPF32[$324>>2]);
   $326 = Math_fround($323 + $325);
   $327 = ((($309) + (($305*48)|0)|0) + 12|0);
   $328 = Math_fround(HEAPF32[$327>>2]);
   $329 = ((($309) + (($311*48)|0)|0) + 12|0);
   $330 = Math_fround(HEAPF32[$329>>2]);
   $331 = Math_fround($328 + $330);
   $332 = Math_fround($316 * Math_fround(0.5));
   $333 = Math_fround($321 * Math_fround(0.5));
   $334 = Math_fround($326 * Math_fround(0.5));
   $335 = Math_fround($331 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $332;
   HEAPF32[$2>>2] = $333;
   HEAPF32[$1>>2] = $334;
   HEAPF32[$0>>2] = $335;
   STACKTOP = sp;return;
   break;
  }
  case 12:  {
   $501 = (($apSkeletonPose) + 4|0);
   $502 = (($apHuman) + 152|0);
   $503 = HEAP32[$502>>2]|0;
   $504 = $501;
   $505 = HEAP32[$501>>2]|0;
   $506 = (($505) + ($504))|0;
   $507 = $506;
   $508 = (($apHuman) + 160|0);
   $509 = HEAP32[$508>>2]|0;
   $510 = (($507) + (($503*48)|0)|0);
   $511 = Math_fround(HEAPF32[$510>>2]);
   $512 = (($507) + (($509*48)|0)|0);
   $513 = Math_fround(HEAPF32[$512>>2]);
   $514 = Math_fround($511 + $513);
   $515 = ((($507) + (($503*48)|0)|0) + 4|0);
   $516 = Math_fround(HEAPF32[$515>>2]);
   $517 = ((($507) + (($509*48)|0)|0) + 4|0);
   $518 = Math_fround(HEAPF32[$517>>2]);
   $519 = Math_fround($516 + $518);
   $520 = ((($507) + (($503*48)|0)|0) + 8|0);
   $521 = Math_fround(HEAPF32[$520>>2]);
   $522 = ((($507) + (($509*48)|0)|0) + 8|0);
   $523 = Math_fround(HEAPF32[$522>>2]);
   $524 = Math_fround($521 + $523);
   $525 = ((($507) + (($503*48)|0)|0) + 12|0);
   $526 = Math_fround(HEAPF32[$525>>2]);
   $527 = ((($507) + (($509*48)|0)|0) + 12|0);
   $528 = Math_fround(HEAPF32[$527>>2]);
   $529 = Math_fround($526 + $528);
   $530 = Math_fround($514 * Math_fround(0.5));
   $531 = Math_fround($519 * Math_fround(0.5));
   $532 = Math_fround($524 * Math_fround(0.5));
   $533 = Math_fround($529 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $530;
   HEAPF32[$2>>2] = $531;
   HEAPF32[$1>>2] = $532;
   HEAPF32[$0>>2] = $533;
   STACKTOP = sp;return;
   break;
  }
  case 16:  {
   $567 = (($apSkeletonPose) + 4|0);
   $568 = (($apHuman) + 168|0);
   $569 = HEAP32[$568>>2]|0;
   $570 = $567;
   $571 = HEAP32[$567>>2]|0;
   $572 = (($571) + ($570))|0;
   $573 = $572;
   $574 = (($apHuman) + 176|0);
   $575 = HEAP32[$574>>2]|0;
   $576 = (($573) + (($569*48)|0)|0);
   $577 = Math_fround(HEAPF32[$576>>2]);
   $578 = (($573) + (($575*48)|0)|0);
   $579 = Math_fround(HEAPF32[$578>>2]);
   $580 = Math_fround($577 + $579);
   $581 = ((($573) + (($569*48)|0)|0) + 4|0);
   $582 = Math_fround(HEAPF32[$581>>2]);
   $583 = ((($573) + (($575*48)|0)|0) + 4|0);
   $584 = Math_fround(HEAPF32[$583>>2]);
   $585 = Math_fround($582 + $584);
   $586 = ((($573) + (($569*48)|0)|0) + 8|0);
   $587 = Math_fround(HEAPF32[$586>>2]);
   $588 = ((($573) + (($575*48)|0)|0) + 8|0);
   $589 = Math_fround(HEAPF32[$588>>2]);
   $590 = Math_fround($587 + $589);
   $591 = ((($573) + (($569*48)|0)|0) + 12|0);
   $592 = Math_fround(HEAPF32[$591>>2]);
   $593 = ((($573) + (($575*48)|0)|0) + 12|0);
   $594 = Math_fround(HEAPF32[$593>>2]);
   $595 = Math_fround($592 + $594);
   $596 = Math_fround($580 * Math_fround(0.5));
   $597 = Math_fround($585 * Math_fround(0.5));
   $598 = Math_fround($590 * Math_fround(0.5));
   $599 = Math_fround($595 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $596;
   HEAPF32[$2>>2] = $597;
   HEAPF32[$1>>2] = $598;
   HEAPF32[$0>>2] = $599;
   STACKTOP = sp;return;
   break;
  }
  case 8:  {
   $126 = (($apHuman) + 140|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)>(-1);
   if ($128) {
    $129 = (($apHuman) + 148|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = ($130|0)>(-1);
    if ($131) {
     $132 = (($apHuman) + 152|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($133|0)>(-1);
     if ($134) {
      $135 = (($apSkeletonPose) + 4|0);
      $136 = (($apHuman) + 136|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = $135;
      $139 = HEAP32[$135>>2]|0;
      $140 = (($139) + ($138))|0;
      $141 = $140;
      $142 = (($141) + (($137*48)|0)|0);
      $143 = Math_fround(HEAPF32[$142>>2]);
      $144 = (($141) + (($127*48)|0)|0);
      $145 = Math_fround(HEAPF32[$144>>2]);
      $146 = Math_fround($143 + $145);
      $147 = ((($141) + (($137*48)|0)|0) + 4|0);
      $148 = Math_fround(HEAPF32[$147>>2]);
      $149 = ((($141) + (($127*48)|0)|0) + 4|0);
      $150 = Math_fround(HEAPF32[$149>>2]);
      $151 = Math_fround($148 + $150);
      $152 = ((($141) + (($137*48)|0)|0) + 8|0);
      $153 = Math_fround(HEAPF32[$152>>2]);
      $154 = ((($141) + (($127*48)|0)|0) + 8|0);
      $155 = Math_fround(HEAPF32[$154>>2]);
      $156 = Math_fround($153 + $155);
      $157 = ((($141) + (($137*48)|0)|0) + 12|0);
      $158 = Math_fround(HEAPF32[$157>>2]);
      $159 = ((($141) + (($127*48)|0)|0) + 12|0);
      $160 = Math_fround(HEAPF32[$159>>2]);
      $161 = Math_fround($158 + $160);
      $162 = (($141) + (($130*48)|0)|0);
      $163 = Math_fround(HEAPF32[$162>>2]);
      $164 = Math_fround($146 + $163);
      $165 = ((($141) + (($130*48)|0)|0) + 4|0);
      $166 = Math_fround(HEAPF32[$165>>2]);
      $167 = Math_fround($151 + $166);
      $168 = ((($141) + (($130*48)|0)|0) + 8|0);
      $169 = Math_fround(HEAPF32[$168>>2]);
      $170 = Math_fround($156 + $169);
      $171 = ((($141) + (($130*48)|0)|0) + 12|0);
      $172 = Math_fround(HEAPF32[$171>>2]);
      $173 = Math_fround($161 + $172);
      $174 = (($141) + (($133*48)|0)|0);
      $175 = Math_fround(HEAPF32[$174>>2]);
      $176 = Math_fround($164 + $175);
      $177 = ((($141) + (($133*48)|0)|0) + 4|0);
      $178 = Math_fround(HEAPF32[$177>>2]);
      $179 = Math_fround($167 + $178);
      $180 = ((($141) + (($133*48)|0)|0) + 8|0);
      $181 = Math_fround(HEAPF32[$180>>2]);
      $182 = Math_fround($170 + $181);
      $183 = ((($141) + (($133*48)|0)|0) + 12|0);
      $184 = Math_fround(HEAPF32[$183>>2]);
      $185 = Math_fround($173 + $184);
      $186 = Math_fround($176 * Math_fround(0.25));
      $187 = Math_fround($179 * Math_fround(0.25));
      $188 = Math_fround($182 * Math_fround(0.25));
      $189 = Math_fround($185 * Math_fround(0.25));
      HEAPF32[$agg$result>>2] = $186;
      HEAPF32[$2>>2] = $187;
      HEAPF32[$1>>2] = $188;
      HEAPF32[$0>>2] = $189;
      STACKTOP = sp;return;
     }
    }
   }
   $190 = (($apSkeletonPose) + 4|0);
   $191 = (($apHuman) + 136|0);
   $192 = HEAP32[$191>>2]|0;
   $193 = $190;
   $194 = HEAP32[$190>>2]|0;
   $195 = (($194) + ($193))|0;
   $196 = $195;
   $197 = (($apHuman) + 156|0);
   $198 = HEAP32[$197>>2]|0;
   $199 = (($196) + (($192*48)|0)|0);
   $200 = Math_fround(HEAPF32[$199>>2]);
   $201 = (($196) + (($198*48)|0)|0);
   $202 = Math_fround(HEAPF32[$201>>2]);
   $203 = Math_fround($200 + $202);
   $204 = ((($196) + (($192*48)|0)|0) + 4|0);
   $205 = Math_fround(HEAPF32[$204>>2]);
   $206 = ((($196) + (($198*48)|0)|0) + 4|0);
   $207 = Math_fround(HEAPF32[$206>>2]);
   $208 = Math_fround($205 + $207);
   $209 = ((($196) + (($192*48)|0)|0) + 8|0);
   $210 = Math_fround(HEAPF32[$209>>2]);
   $211 = ((($196) + (($198*48)|0)|0) + 8|0);
   $212 = Math_fround(HEAPF32[$211>>2]);
   $213 = Math_fround($210 + $212);
   $214 = ((($196) + (($192*48)|0)|0) + 12|0);
   $215 = Math_fround(HEAPF32[$214>>2]);
   $216 = ((($196) + (($198*48)|0)|0) + 12|0);
   $217 = Math_fround(HEAPF32[$216>>2]);
   $218 = Math_fround($215 + $217);
   $219 = (($apHuman) + 160|0);
   $220 = HEAP32[$219>>2]|0;
   $221 = (($196) + (($220*48)|0)|0);
   $222 = Math_fround(HEAPF32[$221>>2]);
   $223 = Math_fround($203 + $222);
   $224 = ((($196) + (($220*48)|0)|0) + 4|0);
   $225 = Math_fround(HEAPF32[$224>>2]);
   $226 = Math_fround($208 + $225);
   $227 = ((($196) + (($220*48)|0)|0) + 8|0);
   $228 = Math_fround(HEAPF32[$227>>2]);
   $229 = Math_fround($213 + $228);
   $230 = ((($196) + (($220*48)|0)|0) + 12|0);
   $231 = Math_fround(HEAPF32[$230>>2]);
   $232 = Math_fround($218 + $231);
   $233 = Math_fround($223 * Math_fround(0.333333343267440795898));
   $234 = Math_fround($226 * Math_fround(0.333333343267440795898));
   $235 = Math_fround($229 * Math_fround(0.333333343267440795898));
   $236 = Math_fround($232 * Math_fround(0.333333343267440795898));
   HEAPF32[$agg$result>>2] = $233;
   HEAPF32[$2>>2] = $234;
   HEAPF32[$1>>2] = $235;
   HEAPF32[$0>>2] = $236;
   STACKTOP = sp;return;
   break;
  }
  case 0:  {
   $3 = (($apSkeletonPose) + 4|0);
   $4 = (($apHuman) + 108|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $3;
   $7 = HEAP32[$3>>2]|0;
   $8 = (($7) + ($6))|0;
   $9 = $8;
   $10 = (($apHuman) + 112|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + (($5*48)|0)|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = (($9) + (($11*48)|0)|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = Math_fround($13 + $15);
   $17 = ((($9) + (($5*48)|0)|0) + 4|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = ((($9) + (($11*48)|0)|0) + 4|0);
   $20 = Math_fround(HEAPF32[$19>>2]);
   $21 = Math_fround($18 + $20);
   $22 = ((($9) + (($5*48)|0)|0) + 8|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = ((($9) + (($11*48)|0)|0) + 8|0);
   $25 = Math_fround(HEAPF32[$24>>2]);
   $26 = Math_fround($23 + $25);
   $27 = ((($9) + (($5*48)|0)|0) + 12|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = ((($9) + (($11*48)|0)|0) + 12|0);
   $30 = Math_fround(HEAPF32[$29>>2]);
   $31 = Math_fround($28 + $30);
   $32 = (($apHuman) + 132|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($9) + (($33*48)|0)|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = Math_fround($16 + $35);
   $37 = ((($9) + (($33*48)|0)|0) + 4|0);
   $38 = Math_fround(HEAPF32[$37>>2]);
   $39 = Math_fround($21 + $38);
   $40 = ((($9) + (($33*48)|0)|0) + 8|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = Math_fround($26 + $41);
   $43 = ((($9) + (($33*48)|0)|0) + 12|0);
   $44 = Math_fround(HEAPF32[$43>>2]);
   $45 = Math_fround($31 + $44);
   $46 = Math_fround($36 * Math_fround(0.333333343267440795898));
   $47 = Math_fround($39 * Math_fround(0.333333343267440795898));
   $48 = Math_fround($42 * Math_fround(0.333333343267440795898));
   $49 = Math_fround($45 * Math_fround(0.333333343267440795898));
   HEAPF32[$agg$result>>2] = $46;
   HEAPF32[$2>>2] = $47;
   HEAPF32[$1>>2] = $48;
   HEAPF32[$0>>2] = $49;
   STACKTOP = sp;return;
   break;
  }
  case 11:  {
   $336 = (($apSkeletonPose) + 4|0);
   $337 = (($apHuman) + 148|0);
   $338 = HEAP32[$337>>2]|0;
   $339 = $336;
   $340 = HEAP32[$336>>2]|0;
   $341 = (($340) + ($339))|0;
   $342 = $341;
   $343 = (($apHuman) + 156|0);
   $344 = HEAP32[$343>>2]|0;
   $345 = (($342) + (($338*48)|0)|0);
   $346 = Math_fround(HEAPF32[$345>>2]);
   $347 = (($342) + (($344*48)|0)|0);
   $348 = Math_fround(HEAPF32[$347>>2]);
   $349 = Math_fround($346 + $348);
   $350 = ((($342) + (($338*48)|0)|0) + 4|0);
   $351 = Math_fround(HEAPF32[$350>>2]);
   $352 = ((($342) + (($344*48)|0)|0) + 4|0);
   $353 = Math_fround(HEAPF32[$352>>2]);
   $354 = Math_fround($351 + $353);
   $355 = ((($342) + (($338*48)|0)|0) + 8|0);
   $356 = Math_fround(HEAPF32[$355>>2]);
   $357 = ((($342) + (($344*48)|0)|0) + 8|0);
   $358 = Math_fround(HEAPF32[$357>>2]);
   $359 = Math_fround($356 + $358);
   $360 = ((($342) + (($338*48)|0)|0) + 12|0);
   $361 = Math_fround(HEAPF32[$360>>2]);
   $362 = ((($342) + (($344*48)|0)|0) + 12|0);
   $363 = Math_fround(HEAPF32[$362>>2]);
   $364 = Math_fround($361 + $363);
   $365 = Math_fround($349 * Math_fround(0.5));
   $366 = Math_fround($354 * Math_fround(0.5));
   $367 = Math_fround($359 * Math_fround(0.5));
   $368 = Math_fround($364 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $365;
   HEAPF32[$2>>2] = $366;
   HEAPF32[$1>>2] = $367;
   HEAPF32[$0>>2] = $368;
   STACKTOP = sp;return;
   break;
  }
  case 14:  {
   $534 = (($apSkeletonPose) + 4|0);
   $535 = (($apHuman) + 160|0);
   $536 = HEAP32[$535>>2]|0;
   $537 = $534;
   $538 = HEAP32[$534>>2]|0;
   $539 = (($538) + ($537))|0;
   $540 = $539;
   $541 = (($apHuman) + 168|0);
   $542 = HEAP32[$541>>2]|0;
   $543 = (($540) + (($536*48)|0)|0);
   $544 = Math_fround(HEAPF32[$543>>2]);
   $545 = (($540) + (($542*48)|0)|0);
   $546 = Math_fround(HEAPF32[$545>>2]);
   $547 = Math_fround($544 + $546);
   $548 = ((($540) + (($536*48)|0)|0) + 4|0);
   $549 = Math_fround(HEAPF32[$548>>2]);
   $550 = ((($540) + (($542*48)|0)|0) + 4|0);
   $551 = Math_fround(HEAPF32[$550>>2]);
   $552 = Math_fround($549 + $551);
   $553 = ((($540) + (($536*48)|0)|0) + 8|0);
   $554 = Math_fround(HEAPF32[$553>>2]);
   $555 = ((($540) + (($542*48)|0)|0) + 8|0);
   $556 = Math_fround(HEAPF32[$555>>2]);
   $557 = Math_fround($554 + $556);
   $558 = ((($540) + (($536*48)|0)|0) + 12|0);
   $559 = Math_fround(HEAPF32[$558>>2]);
   $560 = ((($540) + (($542*48)|0)|0) + 12|0);
   $561 = Math_fround(HEAPF32[$560>>2]);
   $562 = Math_fround($559 + $561);
   $563 = Math_fround($547 * Math_fround(0.5));
   $564 = Math_fround($552 * Math_fround(0.5));
   $565 = Math_fround($557 * Math_fround(0.5));
   $566 = Math_fround($562 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $563;
   HEAPF32[$2>>2] = $564;
   HEAPF32[$1>>2] = $565;
   HEAPF32[$0>>2] = $566;
   STACKTOP = sp;return;
   break;
  }
  case 7:  {
   $50 = (($apHuman) + 136|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)>(-1);
   $53 = (($apSkeletonPose) + 4|0);
   $54 = (($apHuman) + 132|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = $53;
   $57 = HEAP32[$53>>2]|0;
   $58 = (($57) + ($56))|0;
   $59 = $58;
   $60 = (($59) + (($55*48)|0)|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   if ($52) {
    $62 = (($59) + (($51*48)|0)|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    $64 = Math_fround($61 + $63);
    $65 = ((($59) + (($55*48)|0)|0) + 4|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($59) + (($51*48)|0)|0) + 4|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = Math_fround($66 + $68);
    $70 = ((($59) + (($55*48)|0)|0) + 8|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = ((($59) + (($51*48)|0)|0) + 8|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = Math_fround($71 + $73);
    $75 = ((($59) + (($55*48)|0)|0) + 12|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = ((($59) + (($51*48)|0)|0) + 12|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = Math_fround($76 + $78);
    $80 = Math_fround($64 * Math_fround(0.5));
    $81 = Math_fround($69 * Math_fround(0.5));
    $82 = Math_fround($74 * Math_fround(0.5));
    $83 = Math_fround($79 * Math_fround(0.5));
    HEAPF32[$agg$result>>2] = $80;
    HEAPF32[$2>>2] = $81;
    HEAPF32[$1>>2] = $82;
    HEAPF32[$0>>2] = $83;
    STACKTOP = sp;return;
   } else {
    $84 = Math_fround($61 * Math_fround(0.100000001490116119385));
    $85 = ((($59) + (($55*48)|0)|0) + 4|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $87 = Math_fround($86 * Math_fround(0.100000001490116119385));
    $88 = ((($59) + (($55*48)|0)|0) + 8|0);
    $89 = Math_fround(HEAPF32[$88>>2]);
    $90 = Math_fround($89 * Math_fround(0.100000001490116119385));
    $91 = ((($59) + (($55*48)|0)|0) + 12|0);
    $92 = Math_fround(HEAPF32[$91>>2]);
    $93 = Math_fround($92 * Math_fround(0.100000001490116119385));
    $94 = (($apHuman) + 156|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($apHuman) + 160|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($59) + (($95*48)|0)|0);
    $99 = Math_fround(HEAPF32[$98>>2]);
    $100 = (($59) + (($97*48)|0)|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = Math_fround($99 + $101);
    $103 = ((($59) + (($95*48)|0)|0) + 4|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = ((($59) + (($97*48)|0)|0) + 4|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $107 = Math_fround($104 + $106);
    $108 = ((($59) + (($95*48)|0)|0) + 8|0);
    $109 = Math_fround(HEAPF32[$108>>2]);
    $110 = ((($59) + (($97*48)|0)|0) + 8|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = Math_fround($109 + $111);
    $113 = ((($59) + (($95*48)|0)|0) + 12|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = ((($59) + (($97*48)|0)|0) + 12|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = Math_fround($114 + $116);
    $118 = Math_fround($102 * Math_fround(0.449999988079071044922));
    $119 = Math_fround($107 * Math_fround(0.449999988079071044922));
    $120 = Math_fround($112 * Math_fround(0.449999988079071044922));
    $121 = Math_fround($117 * Math_fround(0.449999988079071044922));
    $122 = Math_fround($84 + $118);
    $123 = Math_fround($87 + $119);
    $124 = Math_fround($90 + $120);
    $125 = Math_fround($93 + $121);
    HEAPF32[$agg$result>>2] = $122;
    HEAPF32[$2>>2] = $123;
    HEAPF32[$1>>2] = $124;
    HEAPF32[$0>>2] = $125;
    STACKTOP = sp;return;
   }
   break;
  }
  case 9:  {
   $237 = (($apSkeletonPose) + 4|0);
   $238 = (($apHuman) + 140|0);
   $239 = HEAP32[$238>>2]|0;
   $240 = $237;
   $241 = HEAP32[$237>>2]|0;
   $242 = (($241) + ($240))|0;
   $243 = $242;
   $244 = (($apHuman) + 144|0);
   $245 = HEAP32[$244>>2]|0;
   $246 = (($243) + (($239*48)|0)|0);
   $247 = Math_fround(HEAPF32[$246>>2]);
   $248 = (($243) + (($245*48)|0)|0);
   $249 = Math_fround(HEAPF32[$248>>2]);
   $250 = Math_fround($247 + $249);
   $251 = ((($243) + (($239*48)|0)|0) + 4|0);
   $252 = Math_fround(HEAPF32[$251>>2]);
   $253 = ((($243) + (($245*48)|0)|0) + 4|0);
   $254 = Math_fround(HEAPF32[$253>>2]);
   $255 = Math_fround($252 + $254);
   $256 = ((($243) + (($239*48)|0)|0) + 8|0);
   $257 = Math_fround(HEAPF32[$256>>2]);
   $258 = ((($243) + (($245*48)|0)|0) + 8|0);
   $259 = Math_fround(HEAPF32[$258>>2]);
   $260 = Math_fround($257 + $259);
   $261 = ((($243) + (($239*48)|0)|0) + 12|0);
   $262 = Math_fround(HEAPF32[$261>>2]);
   $263 = ((($243) + (($245*48)|0)|0) + 12|0);
   $264 = Math_fround(HEAPF32[$263>>2]);
   $265 = Math_fround($262 + $264);
   $266 = Math_fround($250 * Math_fround(0.5));
   $267 = Math_fround($255 * Math_fround(0.5));
   $268 = Math_fround($260 * Math_fround(0.5));
   $269 = Math_fround($265 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $266;
   HEAPF32[$2>>2] = $267;
   HEAPF32[$1>>2] = $268;
   HEAPF32[$0>>2] = $269;
   STACKTOP = sp;return;
   break;
  }
  case 1:  {
   $270 = (($apSkeletonPose) + 4|0);
   $271 = (($apHuman) + 108|0);
   $272 = HEAP32[$271>>2]|0;
   $273 = $270;
   $274 = HEAP32[$270>>2]|0;
   $275 = (($274) + ($273))|0;
   $276 = $275;
   $277 = (($apHuman) + 116|0);
   $278 = HEAP32[$277>>2]|0;
   $279 = (($276) + (($272*48)|0)|0);
   $280 = Math_fround(HEAPF32[$279>>2]);
   $281 = (($276) + (($278*48)|0)|0);
   $282 = Math_fround(HEAPF32[$281>>2]);
   $283 = Math_fround($280 + $282);
   $284 = ((($276) + (($272*48)|0)|0) + 4|0);
   $285 = Math_fround(HEAPF32[$284>>2]);
   $286 = ((($276) + (($278*48)|0)|0) + 4|0);
   $287 = Math_fround(HEAPF32[$286>>2]);
   $288 = Math_fround($285 + $287);
   $289 = ((($276) + (($272*48)|0)|0) + 8|0);
   $290 = Math_fround(HEAPF32[$289>>2]);
   $291 = ((($276) + (($278*48)|0)|0) + 8|0);
   $292 = Math_fround(HEAPF32[$291>>2]);
   $293 = Math_fround($290 + $292);
   $294 = ((($276) + (($272*48)|0)|0) + 12|0);
   $295 = Math_fround(HEAPF32[$294>>2]);
   $296 = ((($276) + (($278*48)|0)|0) + 12|0);
   $297 = Math_fround(HEAPF32[$296>>2]);
   $298 = Math_fround($295 + $297);
   $299 = Math_fround($283 * Math_fround(0.5));
   $300 = Math_fround($288 * Math_fround(0.5));
   $301 = Math_fround($293 * Math_fround(0.5));
   $302 = Math_fround($298 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $299;
   HEAPF32[$2>>2] = $300;
   HEAPF32[$1>>2] = $301;
   HEAPF32[$0>>2] = $302;
   STACKTOP = sp;return;
   break;
  }
  case 13:  {
   $369 = (($apSkeletonPose) + 4|0);
   $370 = (($apHuman) + 156|0);
   $371 = HEAP32[$370>>2]|0;
   $372 = $369;
   $373 = HEAP32[$369>>2]|0;
   $374 = (($373) + ($372))|0;
   $375 = $374;
   $376 = (($apHuman) + 164|0);
   $377 = HEAP32[$376>>2]|0;
   $378 = (($375) + (($371*48)|0)|0);
   $379 = Math_fround(HEAPF32[$378>>2]);
   $380 = (($375) + (($377*48)|0)|0);
   $381 = Math_fround(HEAPF32[$380>>2]);
   $382 = Math_fround($379 + $381);
   $383 = ((($375) + (($371*48)|0)|0) + 4|0);
   $384 = Math_fround(HEAPF32[$383>>2]);
   $385 = ((($375) + (($377*48)|0)|0) + 4|0);
   $386 = Math_fround(HEAPF32[$385>>2]);
   $387 = Math_fround($384 + $386);
   $388 = ((($375) + (($371*48)|0)|0) + 8|0);
   $389 = Math_fround(HEAPF32[$388>>2]);
   $390 = ((($375) + (($377*48)|0)|0) + 8|0);
   $391 = Math_fround(HEAPF32[$390>>2]);
   $392 = Math_fround($389 + $391);
   $393 = ((($375) + (($371*48)|0)|0) + 12|0);
   $394 = Math_fround(HEAPF32[$393>>2]);
   $395 = ((($375) + (($377*48)|0)|0) + 12|0);
   $396 = Math_fround(HEAPF32[$395>>2]);
   $397 = Math_fround($394 + $396);
   $398 = Math_fround($382 * Math_fround(0.5));
   $399 = Math_fround($387 * Math_fround(0.5));
   $400 = Math_fround($392 * Math_fround(0.5));
   $401 = Math_fround($397 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $398;
   HEAPF32[$2>>2] = $399;
   HEAPF32[$1>>2] = $400;
   HEAPF32[$0>>2] = $401;
   STACKTOP = sp;return;
   break;
  }
  case 15:  {
   $402 = (($apSkeletonPose) + 4|0);
   $403 = (($apHuman) + 156|0);
   $404 = HEAP32[$403>>2]|0;
   $405 = $402;
   $406 = HEAP32[$402>>2]|0;
   $407 = (($406) + ($405))|0;
   $408 = $407;
   $409 = (($apHuman) + 172|0);
   $410 = HEAP32[$409>>2]|0;
   $411 = (($408) + (($404*48)|0)|0);
   $412 = Math_fround(HEAPF32[$411>>2]);
   $413 = (($408) + (($410*48)|0)|0);
   $414 = Math_fround(HEAPF32[$413>>2]);
   $415 = Math_fround($412 + $414);
   $416 = ((($408) + (($404*48)|0)|0) + 4|0);
   $417 = Math_fround(HEAPF32[$416>>2]);
   $418 = ((($408) + (($410*48)|0)|0) + 4|0);
   $419 = Math_fround(HEAPF32[$418>>2]);
   $420 = Math_fround($417 + $419);
   $421 = ((($408) + (($404*48)|0)|0) + 8|0);
   $422 = Math_fround(HEAPF32[$421>>2]);
   $423 = ((($408) + (($410*48)|0)|0) + 8|0);
   $424 = Math_fround(HEAPF32[$423>>2]);
   $425 = Math_fround($422 + $424);
   $426 = ((($408) + (($404*48)|0)|0) + 12|0);
   $427 = Math_fround(HEAPF32[$426>>2]);
   $428 = ((($408) + (($410*48)|0)|0) + 12|0);
   $429 = Math_fround(HEAPF32[$428>>2]);
   $430 = Math_fround($427 + $429);
   $431 = Math_fround($415 * Math_fround(0.5));
   $432 = Math_fround($420 * Math_fround(0.5));
   $433 = Math_fround($425 * Math_fround(0.5));
   $434 = Math_fround($430 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $431;
   HEAPF32[$2>>2] = $432;
   HEAPF32[$1>>2] = $433;
   HEAPF32[$0>>2] = $434;
   STACKTOP = sp;return;
   break;
  }
  case 2:  {
   $435 = (($apSkeletonPose) + 4|0);
   $436 = (($apHuman) + 112|0);
   $437 = HEAP32[$436>>2]|0;
   $438 = $435;
   $439 = HEAP32[$435>>2]|0;
   $440 = (($439) + ($438))|0;
   $441 = $440;
   $442 = (($apHuman) + 120|0);
   $443 = HEAP32[$442>>2]|0;
   $444 = (($441) + (($437*48)|0)|0);
   $445 = Math_fround(HEAPF32[$444>>2]);
   $446 = (($441) + (($443*48)|0)|0);
   $447 = Math_fround(HEAPF32[$446>>2]);
   $448 = Math_fround($445 + $447);
   $449 = ((($441) + (($437*48)|0)|0) + 4|0);
   $450 = Math_fround(HEAPF32[$449>>2]);
   $451 = ((($441) + (($443*48)|0)|0) + 4|0);
   $452 = Math_fround(HEAPF32[$451>>2]);
   $453 = Math_fround($450 + $452);
   $454 = ((($441) + (($437*48)|0)|0) + 8|0);
   $455 = Math_fround(HEAPF32[$454>>2]);
   $456 = ((($441) + (($443*48)|0)|0) + 8|0);
   $457 = Math_fround(HEAPF32[$456>>2]);
   $458 = Math_fround($455 + $457);
   $459 = ((($441) + (($437*48)|0)|0) + 12|0);
   $460 = Math_fround(HEAPF32[$459>>2]);
   $461 = ((($441) + (($443*48)|0)|0) + 12|0);
   $462 = Math_fround(HEAPF32[$461>>2]);
   $463 = Math_fround($460 + $462);
   $464 = Math_fround($448 * Math_fround(0.5));
   $465 = Math_fround($453 * Math_fround(0.5));
   $466 = Math_fround($458 * Math_fround(0.5));
   $467 = Math_fround($463 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $464;
   HEAPF32[$2>>2] = $465;
   HEAPF32[$1>>2] = $466;
   HEAPF32[$0>>2] = $467;
   STACKTOP = sp;return;
   break;
  }
  case 4:  {
   $468 = (($apSkeletonPose) + 4|0);
   $469 = (($apHuman) + 120|0);
   $470 = HEAP32[$469>>2]|0;
   $471 = $468;
   $472 = HEAP32[$468>>2]|0;
   $473 = (($472) + ($471))|0;
   $474 = $473;
   $475 = (($apHuman) + 128|0);
   $476 = HEAP32[$475>>2]|0;
   $477 = (($474) + (($470*48)|0)|0);
   $478 = Math_fround(HEAPF32[$477>>2]);
   $479 = (($474) + (($476*48)|0)|0);
   $480 = Math_fround(HEAPF32[$479>>2]);
   $481 = Math_fround($478 + $480);
   $482 = ((($474) + (($470*48)|0)|0) + 4|0);
   $483 = Math_fround(HEAPF32[$482>>2]);
   $484 = ((($474) + (($476*48)|0)|0) + 4|0);
   $485 = Math_fround(HEAPF32[$484>>2]);
   $486 = Math_fround($483 + $485);
   $487 = ((($474) + (($470*48)|0)|0) + 8|0);
   $488 = Math_fround(HEAPF32[$487>>2]);
   $489 = ((($474) + (($476*48)|0)|0) + 8|0);
   $490 = Math_fround(HEAPF32[$489>>2]);
   $491 = Math_fround($488 + $490);
   $492 = ((($474) + (($470*48)|0)|0) + 12|0);
   $493 = Math_fround(HEAPF32[$492>>2]);
   $494 = ((($474) + (($476*48)|0)|0) + 12|0);
   $495 = Math_fround(HEAPF32[$494>>2]);
   $496 = Math_fround($493 + $495);
   $497 = Math_fround($481 * Math_fround(0.5));
   $498 = Math_fround($486 * Math_fround(0.5));
   $499 = Math_fround($491 * Math_fround(0.5));
   $500 = Math_fround($496 * Math_fround(0.5));
   HEAPF32[$agg$result>>2] = $497;
   HEAPF32[$2>>2] = $498;
   HEAPF32[$1>>2] = $499;
   HEAPF32[$0>>2] = $500;
   STACKTOP = sp;return;
   break;
  }
  default: {
   $600 = (($apSkeletonPose) + 4|0);
   $601 = ((($apHuman) + ($aBoneIndex<<2)|0) + 104|0);
   $602 = HEAP32[$601>>2]|0;
   $603 = $600;
   $604 = HEAP32[$600>>2]|0;
   $605 = (($604) + ($603))|0;
   $606 = $605;
   $607 = (($606) + (($602*48)|0)|0);
   $608 = Math_fround(HEAPF32[$607>>2]);
   $609 = ((($606) + (($602*48)|0)|0) + 4|0);
   $610 = Math_fround(HEAPF32[$609>>2]);
   $611 = ((($606) + (($602*48)|0)|0) + 8|0);
   $612 = Math_fround(HEAPF32[$611>>2]);
   $613 = ((($606) + (($602*48)|0)|0) + 12|0);
   $614 = Math_fround(HEAPF32[$613>>2]);
   HEAPF32[$agg$result>>2] = $608;
   HEAPF32[$2>>2] = $610;
   HEAPF32[$1>>2] = $612;
   HEAPF32[$0>>2] = $614;
   STACKTOP = sp;return;
  }
  }
 } while(0);
}
function __ZN7mecanim5human23HumanComputeOrientationEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseE($agg$result,$apHuman,$apPoseGlobal) {
 $agg$result = $agg$result|0;
 $apHuman = $apHuman|0;
 $apPoseGlobal = $apPoseGlobal|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0);
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0);
 var $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0);
 var $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($apHuman) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($apHuman) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($apHuman) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($apHuman) + 160|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($apPoseGlobal) + 4|0);
 $9 = $8;
 $10 = HEAP32[$8>>2]|0;
 $11 = (($10) + ($9))|0;
 $12 = $11;
 $13 = (($12) + (($1*48)|0)|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($12) + (($3*48)|0)|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 + $16);
 $18 = ((($12) + (($1*48)|0)|0) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($12) + (($3*48)|0)|0) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($19 + $21);
 $23 = ((($12) + (($1*48)|0)|0) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = ((($12) + (($3*48)|0)|0) + 8|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($24 + $26);
 $28 = ((($12) + (($1*48)|0)|0) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = ((($12) + (($3*48)|0)|0) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($29 + $31);
 $33 = Math_fround($17 * Math_fround(0.5));
 $34 = Math_fround($22 * Math_fround(0.5));
 $35 = Math_fround($27 * Math_fround(0.5));
 $36 = Math_fround($32 * Math_fround(0.5));
 $37 = (($12) + (($5*48)|0)|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($12) + (($7*48)|0)|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 + $40);
 $42 = ((($12) + (($5*48)|0)|0) + 4|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = ((($12) + (($7*48)|0)|0) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 + $45);
 $47 = ((($12) + (($5*48)|0)|0) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = ((($12) + (($7*48)|0)|0) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($48 + $50);
 $52 = ((($12) + (($5*48)|0)|0) + 12|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = ((($12) + (($7*48)|0)|0) + 12|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($53 + $55);
 $57 = Math_fround($41 * Math_fround(0.5));
 $58 = Math_fround($46 * Math_fround(0.5));
 $59 = Math_fround($51 * Math_fround(0.5));
 $60 = Math_fround($56 * Math_fround(0.5));
 $61 = Math_fround($57 - $33);
 $62 = Math_fround($58 - $34);
 $63 = Math_fround($59 - $35);
 $64 = Math_fround($60 - $36);
 $65 = Math_fround($61 * $61);
 $66 = Math_fround($62 * $62);
 $67 = Math_fround($63 * $63);
 $68 = Math_fround($64 * $64);
 $69 = Math_fround($65 + $66);
 $70 = Math_fround($67 + $68);
 $71 = Math_fround($69 + $70);
 $72 = (Math_fround(Math_sqrt((Math_fround($71)))));
 $73 = Math_fround(Math_fround(1.0) / $72);
 $74 = Math_fround($61 * $73);
 $75 = Math_fround($62 * $73);
 $76 = Math_fround($63 * $73);
 $77 = Math_fround($16 - $14);
 $78 = Math_fround($21 - $19);
 $79 = Math_fround($26 - $24);
 $80 = Math_fround($31 - $29);
 $81 = Math_fround($40 - $38);
 $82 = Math_fround($45 - $43);
 $83 = Math_fround($50 - $48);
 $84 = Math_fround($55 - $53);
 $85 = Math_fround($77 + $81);
 $86 = Math_fround($78 + $82);
 $87 = Math_fround($79 + $83);
 $88 = Math_fround($80 + $84);
 $89 = Math_fround($85 * $85);
 $90 = Math_fround($86 * $86);
 $91 = Math_fround($87 * $87);
 $92 = Math_fround($88 * $88);
 $93 = Math_fround($89 + $90);
 $94 = Math_fround($91 + $92);
 $95 = Math_fround($93 + $94);
 $96 = (Math_fround(Math_sqrt((Math_fround($95)))));
 $97 = Math_fround(Math_fround(1.0) / $96);
 $98 = Math_fround($85 * $97);
 $99 = Math_fround($86 * $97);
 $100 = Math_fround($87 * $97);
 $101 = Math_fround($75 * $98);
 $102 = Math_fround($76 * $99);
 $103 = Math_fround($74 * $100);
 $104 = Math_fround($74 * $99);
 $105 = Math_fround($75 * $100);
 $106 = Math_fround($76 * $98);
 $107 = Math_fround($101 - $104);
 $108 = Math_fround($102 - $105);
 $109 = Math_fround($103 - $106);
 $110 = Math_fround($74 * $109);
 $111 = Math_fround($75 * $107);
 $112 = Math_fround($76 * $108);
 $113 = Math_fround($75 * $108);
 $114 = Math_fround($76 * $109);
 $115 = Math_fround($74 * $107);
 $116 = Math_fround($110 - $113);
 $117 = Math_fround($111 - $114);
 $118 = Math_fround($112 - $115);
 $119 = !($117 >= Math_fround(0.0));
 do {
  if ($119) {
   $132 = Math_fround($75 - $107);
   $133 = !($132 >= Math_fround(0.0));
   if ($133) {
    $139 = Math_fround($108 + $116);
    $140 = Math_fround($76 + $109);
    $141 = Math_fround(Math_fround(1.0) - $117);
    $142 = Math_fround($141 - $132);
    $143 = Math_fround($118 - $74);
    $145 = $139;$147 = $140;$149 = $142;$151 = $143;
    break;
   } else {
    $134 = Math_fround($74 + $118);
    $135 = Math_fround(Math_fround(1.0) - $117);
    $136 = Math_fround($132 + $135);
    $137 = Math_fround($76 + $109);
    $138 = Math_fround($108 - $116);
    $145 = $134;$147 = $136;$149 = $137;$151 = $138;
    break;
   }
  } else {
   $120 = Math_fround($75 + $107);
   $121 = !($120 >= Math_fround(0.0));
   if ($121) {
    $127 = Math_fround($117 + Math_fround(1.0));
    $128 = Math_fround($127 - $120);
    $129 = Math_fround($74 + $118);
    $130 = Math_fround($108 + $116);
    $131 = Math_fround($76 - $109);
    $145 = $128;$147 = $129;$149 = $130;$151 = $131;
    break;
   } else {
    $122 = Math_fround($76 - $109);
    $123 = Math_fround($108 - $116);
    $124 = Math_fround($118 - $74);
    $125 = Math_fround($117 + Math_fround(1.0));
    $126 = Math_fround($120 + $125);
    $145 = $122;$147 = $123;$149 = $124;$151 = $126;
    break;
   }
  }
 } while(0);
 $144 = Math_fround($145 * $145);
 $146 = Math_fround($147 * $147);
 $148 = Math_fround($149 * $149);
 $150 = Math_fround($151 * $151);
 $152 = Math_fround($146 + $144);
 $153 = Math_fround($150 + $148);
 $154 = Math_fround($153 + $152);
 $155 = (Math_fround(Math_sqrt((Math_fround($154)))));
 $156 = Math_fround(Math_fround(1.0) / $155);
 $157 = Math_fround($145 * $156);
 $158 = Math_fround($147 * $156);
 $159 = Math_fround($149 * $156);
 $160 = Math_fround($151 * $156);
 $161 = (($apHuman) + 16|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = Math_fround($162 * Math_fround(-1.0));
 $164 = (($apHuman) + 20|0);
 $165 = Math_fround(HEAPF32[$164>>2]);
 $166 = Math_fround($165 * Math_fround(-1.0));
 $167 = (($apHuman) + 24|0);
 $168 = Math_fround(HEAPF32[$167>>2]);
 $169 = Math_fround($168 * Math_fround(-1.0));
 $170 = (($apHuman) + 28|0);
 $171 = Math_fround(HEAPF32[$170>>2]);
 $172 = Math_fround($158 * $163);
 $173 = Math_fround($160 * $171);
 $174 = Math_fround($159 * $166);
 $175 = Math_fround($157 * $169);
 $176 = Math_fround($160 * $169);
 $177 = Math_fround($157 * $163);
 $178 = Math_fround($158 * $169);
 $179 = Math_fround($159 * $163);
 $180 = Math_fround($172 - $176);
 $181 = Math_fround($173 - $177);
 $182 = Math_fround($174 - $178);
 $183 = Math_fround($175 - $179);
 $184 = Math_fround($159 * $171);
 $185 = Math_fround($159 * $169);
 $186 = Math_fround($160 * $163);
 $187 = Math_fround($160 * $166);
 $188 = Math_fround($180 - $184);
 $189 = Math_fround($181 - $185);
 $190 = Math_fround($182 - $186);
 $191 = Math_fround($183 - $187);
 $192 = Math_fround($157 * $166);
 $193 = Math_fround($158 * $166);
 $194 = Math_fround($157 * $171);
 $195 = Math_fround($158 * $171);
 $196 = Math_fround($188 - $192);
 $197 = Math_fround($189 - $193);
 $198 = Math_fround($190 - $194);
 $199 = Math_fround($191 - $195);
 $200 = Math_fround($198 * Math_fround(-1.0));
 $201 = Math_fround($199 * Math_fround(-1.0));
 $202 = Math_fround($196 * Math_fround(-1.0));
 $203 = Math_fround($200 * $200);
 $204 = Math_fround($201 * $201);
 $205 = Math_fround($202 * $202);
 $206 = Math_fround($197 * $197);
 $207 = Math_fround($203 + $204);
 $208 = Math_fround($206 + $205);
 $209 = Math_fround($207 + $208);
 $210 = (Math_fround(Math_sqrt((Math_fround($209)))));
 $211 = Math_fround(Math_fround(1.0) / $210);
 $212 = Math_fround($211 * $200);
 $213 = Math_fround($211 * $201);
 $214 = Math_fround($211 * $202);
 $215 = Math_fround($211 * $197);
 HEAPF32[$agg$result>>2] = $212;
 $216 = (($agg$result) + 4|0);
 HEAPF32[$216>>2] = $213;
 $217 = (($agg$result) + 8|0);
 HEAPF32[$217>>2] = $214;
 $218 = (($agg$result) + 12|0);
 HEAPF32[$218>>2] = $215;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human29HumanGetGoalOrientationOffsetENS0_4GoalE($agg$result,$goalIndex) {
 $agg$result = $agg$result|0;
 $goalIndex = $goalIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $goalOrientationOffsetArray = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $goalOrientationOffsetArray = sp;
 HEAPF32[$goalOrientationOffsetArray>>2] = Math_fround(0.5);
 $0 = (($goalOrientationOffsetArray) + 4|0);
 HEAPF32[$0>>2] = Math_fround(-0.5);
 $1 = (($goalOrientationOffsetArray) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.5);
 $2 = (($goalOrientationOffsetArray) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.5);
 $3 = (($goalOrientationOffsetArray) + 16|0);
 HEAPF32[$3>>2] = Math_fround(0.5);
 $4 = (($goalOrientationOffsetArray) + 20|0);
 HEAPF32[$4>>2] = Math_fround(-0.5);
 $5 = (($goalOrientationOffsetArray) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.5);
 $6 = (($goalOrientationOffsetArray) + 28|0);
 HEAPF32[$6>>2] = Math_fround(0.5);
 $7 = (($goalOrientationOffsetArray) + 32|0);
 HEAPF32[$7>>2] = Math_fround(0.707107007503509521484);
 $8 = (($goalOrientationOffsetArray) + 36|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($goalOrientationOffsetArray) + 40|0);
 HEAPF32[$9>>2] = Math_fround(0.707107007503509521484);
 $10 = (($goalOrientationOffsetArray) + 44|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($goalOrientationOffsetArray) + 48|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($goalOrientationOffsetArray) + 52|0);
 HEAPF32[$12>>2] = Math_fround(0.707107007503509521484);
 $13 = (($goalOrientationOffsetArray) + 56|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($goalOrientationOffsetArray) + 60|0);
 HEAPF32[$14>>2] = Math_fround(0.707107007503509521484);
 $15 = (($goalOrientationOffsetArray) + ($goalIndex<<4)|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$15+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human20HumanGetHintPositionEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseENS0_4GoalE($agg$result,$apHuman,$apSkeletonPoseGlobal,$goalIndex) {
 $agg$result = $agg$result|0;
 $apHuman = $apHuman|0;
 $apSkeletonPoseGlobal = $apSkeletonPoseGlobal|0;
 $goalIndex = $goalIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apSkeletonPoseGlobal) + 4|0);
 $1 = ((798784 + ($goalIndex<<4)|0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($apHuman) + ($2<<2)|0) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $0;
 $6 = HEAP32[$0>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($8) + (($4*48)|0)|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$9+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human14HumanPoseClearERNS0_9HumanPoseE($arPose) {
 $arPose = $arPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($arPose) + 28|0);
 ;HEAP32[$arPose+0>>2]=0|0;HEAP32[$arPose+4>>2]=0|0;HEAP32[$arPose+8>>2]=0|0;HEAP32[$arPose+12>>2]=0|0;HEAP32[$arPose+16>>2]=0|0;HEAP32[$arPose+20>>2]=0|0;HEAP32[$arPose+24>>2]=0|0;
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($arPose) + 32|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($arPose) + 36|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 $3 = (($arPose) + 40|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($arPose) + 44|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($arPose) + 80|0);
 $6 = (($arPose) + 108|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;HEAP32[$5+24>>2]=0|0;
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($arPose) + 112|0);
 HEAPF32[$7>>2] = Math_fround(1.0);
 $8 = (($arPose) + 116|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($arPose) + 120|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($arPose) + 124|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($arPose) + 156|0);
 $12 = (($arPose) + 184|0);
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;HEAP32[$11+24>>2]=0|0;
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($arPose) + 188|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($arPose) + 192|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($arPose) + 196|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($arPose) + 200|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($arPose) + 232|0);
 $18 = (($arPose) + 260|0);
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;HEAP32[$17+16>>2]=0|0;HEAP32[$17+20>>2]=0|0;HEAP32[$17+24>>2]=0|0;
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($arPose) + 264|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($arPose) + 268|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($arPose) + 272|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($arPose) + 276|0);
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($arPose) + 308|0);
 $24 = (($arPose) + 336|0);
 ;HEAP32[$23+0>>2]=0|0;HEAP32[$23+4>>2]=0|0;HEAP32[$23+8>>2]=0|0;HEAP32[$23+12>>2]=0|0;HEAP32[$23+16>>2]=0|0;HEAP32[$23+20>>2]=0|0;HEAP32[$23+24>>2]=0|0;
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($arPose) + 340|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($arPose) + 344|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($arPose) + 348|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($arPose) + 352|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $scevgep = (($arPose) + 672|0);
 _memset(($scevgep|0),0,208)|0;
 $29 = (($arPose) + 432|0);
 $30 = (($arPose) + 576|0);
 dest=$29+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$30+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($arPose,$arPoseA,$aDoFOnly) {
 $arPose = $arPose|0;
 $arPoseA = $arPoseA|0;
 $aDoFOnly = $aDoFOnly|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $exitcond4 = 0, $i$02 = 0, $i$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($aDoFOnly) {
  $i$11 = 0;
 } else {
  $0 = Math_fround(HEAPF32[$arPoseA>>2]);
  $1 = (($arPoseA) + 4|0);
  $2 = Math_fround(HEAPF32[$1>>2]);
  $3 = (($arPoseA) + 8|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($arPoseA) + 12|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  HEAPF32[$arPose>>2] = $0;
  $7 = (($arPose) + 4|0);
  HEAPF32[$7>>2] = $2;
  $8 = (($arPose) + 8|0);
  HEAPF32[$8>>2] = $4;
  $9 = (($arPose) + 12|0);
  HEAPF32[$9>>2] = $6;
  $10 = (($arPoseA) + 16|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = (($arPoseA) + 20|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($arPoseA) + 24|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (($arPoseA) + 28|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (($arPose) + 16|0);
  HEAPF32[$18>>2] = $11;
  $19 = (($arPose) + 20|0);
  HEAPF32[$19>>2] = $13;
  $20 = (($arPose) + 24|0);
  HEAPF32[$20>>2] = $15;
  $21 = (($arPose) + 28|0);
  HEAPF32[$21>>2] = $17;
  $22 = (($arPoseA) + 32|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (($arPoseA) + 36|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($arPoseA) + 40|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (($arPoseA) + 44|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = (($arPose) + 32|0);
  HEAPF32[$30>>2] = $23;
  $31 = (($arPose) + 36|0);
  HEAPF32[$31>>2] = $25;
  $32 = (($arPose) + 40|0);
  HEAPF32[$32>>2] = $27;
  $33 = (($arPose) + 44|0);
  HEAPF32[$33>>2] = $29;
  $i$02 = 0;
  while(1) {
   $34 = ((($arPoseA) + (($i$02*76)|0)|0) + 80|0);
   $35 = Math_fround(HEAPF32[$34>>2]);
   $36 = ((($arPoseA) + (($i$02*76)|0)|0) + 84|0);
   $37 = Math_fround(HEAPF32[$36>>2]);
   $38 = ((($arPoseA) + (($i$02*76)|0)|0) + 88|0);
   $39 = Math_fround(HEAPF32[$38>>2]);
   $40 = ((($arPoseA) + (($i$02*76)|0)|0) + 92|0);
   $41 = Math_fround(HEAPF32[$40>>2]);
   $42 = ((($arPose) + (($i$02*76)|0)|0) + 80|0);
   HEAPF32[$42>>2] = $35;
   $43 = ((($arPose) + (($i$02*76)|0)|0) + 84|0);
   HEAPF32[$43>>2] = $37;
   $44 = ((($arPose) + (($i$02*76)|0)|0) + 88|0);
   HEAPF32[$44>>2] = $39;
   $45 = ((($arPose) + (($i$02*76)|0)|0) + 92|0);
   HEAPF32[$45>>2] = $41;
   $46 = ((($arPoseA) + (($i$02*76)|0)|0) + 96|0);
   $47 = Math_fround(HEAPF32[$46>>2]);
   $48 = ((($arPoseA) + (($i$02*76)|0)|0) + 100|0);
   $49 = Math_fround(HEAPF32[$48>>2]);
   $50 = ((($arPoseA) + (($i$02*76)|0)|0) + 104|0);
   $51 = Math_fround(HEAPF32[$50>>2]);
   $52 = ((($arPoseA) + (($i$02*76)|0)|0) + 108|0);
   $53 = Math_fround(HEAPF32[$52>>2]);
   $54 = ((($arPose) + (($i$02*76)|0)|0) + 96|0);
   HEAPF32[$54>>2] = $47;
   $55 = ((($arPose) + (($i$02*76)|0)|0) + 100|0);
   HEAPF32[$55>>2] = $49;
   $56 = ((($arPose) + (($i$02*76)|0)|0) + 104|0);
   HEAPF32[$56>>2] = $51;
   $57 = ((($arPose) + (($i$02*76)|0)|0) + 108|0);
   HEAPF32[$57>>2] = $53;
   $58 = ((($arPoseA) + (($i$02*76)|0)|0) + 112|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = ((($arPoseA) + (($i$02*76)|0)|0) + 116|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = ((($arPoseA) + (($i$02*76)|0)|0) + 120|0);
   $63 = Math_fround(HEAPF32[$62>>2]);
   $64 = ((($arPoseA) + (($i$02*76)|0)|0) + 124|0);
   $65 = Math_fround(HEAPF32[$64>>2]);
   $66 = ((($arPose) + (($i$02*76)|0)|0) + 112|0);
   HEAPF32[$66>>2] = $59;
   $67 = ((($arPose) + (($i$02*76)|0)|0) + 116|0);
   HEAPF32[$67>>2] = $61;
   $68 = ((($arPose) + (($i$02*76)|0)|0) + 120|0);
   HEAPF32[$68>>2] = $63;
   $69 = ((($arPose) + (($i$02*76)|0)|0) + 124|0);
   HEAPF32[$69>>2] = $65;
   $70 = (($i$02) + 1)|0;
   $exitcond4 = ($70|0)==(4);
   if ($exitcond4) {
    $i$11 = 0;
    break;
   } else {
    $i$02 = $70;
   }
  }
 }
 while(1) {
  $71 = ((($arPoseA) + ($i$11<<2)|0) + 672|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = ((($arPose) + ($i$11<<2)|0) + 672|0);
  HEAPF32[$73>>2] = $72;
  $74 = (($i$11) + 1)|0;
  $exitcond = ($74|0)==(52);
  if ($exitcond) {
   break;
  } else {
   $i$11 = $74;
  }
 }
 $75 = (($arPoseA) + 384|0);
 $76 = (($arPose) + 384|0);
 __ZN7mecanim4hand12HandPoseCopyEPKNS0_8HandPoseEPS1_($75,$76);
 $77 = (($arPoseA) + 528|0);
 $78 = (($arPose) + 528|0);
 __ZN7mecanim4hand12HandPoseCopyEPKNS0_8HandPoseEPS1_($77,$78);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_RKNS_6bitsetILj59EEE($arPose,$arPoseA,$arHumanPoseMask) {
 $arPose = $arPose|0;
 $arPoseA = $arPoseA|0;
 $arHumanPoseMask = $arHumanPoseMask|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre42 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0);
 var $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = Math_fround(0);
 var $131 = 0, $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = 0, $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0;
 var $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = Math_fround(0);
 var $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $24 = 0;
 var $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0;
 var $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = Math_fround(0);
 var $98 = 0, $99 = 0, $exitcond = 0, $exitcond41 = 0, $i$029 = 0, $i$518 = 0, $pos$01$i = 0, $scevgep = 0, $scevgep36 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($0) + 4|0);
 HEAP32[$0>>2] = -1;
 HEAP32[$1>>2] = 134217727;
 $7 = 134217727;$pos$01$i = 1;
 while(1) {
  $4 = (($arHumanPoseMask) + ($pos$01$i<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==($7|0);
  if (!($6)) {
   $i$029 = 0;
   break;
  }
  $2 = (($pos$01$i) + -1)|0;
  $3 = ($pos$01$i|0)>(0);
  if (!($3)) {
   label = 5;
   break;
  }
  $$phi$trans$insert = (($0) + ($2<<2)|0);
  $$pre42 = HEAP32[$$phi$trans$insert>>2]|0;
  $7 = $$pre42;$pos$01$i = $2;
 }
 if ((label|0) == 5) {
  __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($arPose,$arPoseA,0);
  STACKTOP = sp;return;
 }
 while(1) {
  $8 = (($i$029) + 1)|0;
  $9 = $8 >>> 5;
  $10 = (($arHumanPoseMask) + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $8 & 31;
  $13 = 1 << $12;
  $14 = $11 & $13;
  $15 = ($14|0)==(0);
  if ($15) {
   $19 = ((($arPose) + ($i$029<<2)|0) + 672|0);
   HEAPF32[$19>>2] = Math_fround(0.0);
  } else {
   $16 = ((($arPoseA) + ($i$029<<2)|0) + 672|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = ((($arPose) + ($i$029<<2)|0) + 672|0);
   HEAPF32[$18>>2] = $17;
  }
  $exitcond41 = ($8|0)==(52);
  if ($exitcond41) {
   break;
  } else {
   $i$029 = $8;
  }
 }
 $20 = (($arHumanPoseMask) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 & 33554432;
 $23 = ($22|0)==(0);
 if ($23) {
  $scevgep36 = (($arPose) + 432|0);
  dest=$scevgep36+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $$pre = HEAP32[$20>>2]|0;
  $85 = $$pre;
 } else {
  $24 = (($arPoseA) + 432|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (($arPose) + 432|0);
  HEAPF32[$26>>2] = $25;
  $27 = (($arPoseA) + 436|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = (($arPose) + 436|0);
  HEAPF32[$29>>2] = $28;
  $30 = (($arPoseA) + 440|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (($arPose) + 440|0);
  HEAPF32[$32>>2] = $31;
  $33 = (($arPoseA) + 444|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($arPose) + 444|0);
  HEAPF32[$35>>2] = $34;
  $36 = (($arPoseA) + 448|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = (($arPose) + 448|0);
  HEAPF32[$38>>2] = $37;
  $39 = (($arPoseA) + 452|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = (($arPose) + 452|0);
  HEAPF32[$41>>2] = $40;
  $42 = (($arPoseA) + 456|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = (($arPose) + 456|0);
  HEAPF32[$44>>2] = $43;
  $45 = (($arPoseA) + 460|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($arPose) + 460|0);
  HEAPF32[$47>>2] = $46;
  $48 = (($arPoseA) + 464|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = (($arPose) + 464|0);
  HEAPF32[$50>>2] = $49;
  $51 = (($arPoseA) + 468|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (($arPose) + 468|0);
  HEAPF32[$53>>2] = $52;
  $54 = (($arPoseA) + 472|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = (($arPose) + 472|0);
  HEAPF32[$56>>2] = $55;
  $57 = (($arPoseA) + 476|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($arPose) + 476|0);
  HEAPF32[$59>>2] = $58;
  $60 = (($arPoseA) + 480|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($arPose) + 480|0);
  HEAPF32[$62>>2] = $61;
  $63 = (($arPoseA) + 484|0);
  $64 = Math_fround(HEAPF32[$63>>2]);
  $65 = (($arPose) + 484|0);
  HEAPF32[$65>>2] = $64;
  $66 = (($arPoseA) + 488|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = (($arPose) + 488|0);
  HEAPF32[$68>>2] = $67;
  $69 = (($arPoseA) + 492|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = (($arPose) + 492|0);
  HEAPF32[$71>>2] = $70;
  $72 = (($arPoseA) + 496|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  $74 = (($arPose) + 496|0);
  HEAPF32[$74>>2] = $73;
  $75 = (($arPoseA) + 500|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($arPose) + 500|0);
  HEAPF32[$77>>2] = $76;
  $78 = (($arPoseA) + 504|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = (($arPose) + 504|0);
  HEAPF32[$80>>2] = $79;
  $81 = (($arPoseA) + 508|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = (($arPose) + 508|0);
  HEAPF32[$83>>2] = $82;
  $85 = $21;
 }
 $84 = $85 & 67108864;
 $86 = ($84|0)==(0);
 if ($86) {
  $scevgep = (($arPose) + 576|0);
  dest=$scevgep+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $i$518 = 0;
 } else {
  $87 = (($arPoseA) + 576|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = (($arPose) + 576|0);
  HEAPF32[$89>>2] = $88;
  $90 = (($arPoseA) + 580|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = (($arPose) + 580|0);
  HEAPF32[$92>>2] = $91;
  $93 = (($arPoseA) + 584|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = (($arPose) + 584|0);
  HEAPF32[$95>>2] = $94;
  $96 = (($arPoseA) + 588|0);
  $97 = Math_fround(HEAPF32[$96>>2]);
  $98 = (($arPose) + 588|0);
  HEAPF32[$98>>2] = $97;
  $99 = (($arPoseA) + 592|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = (($arPose) + 592|0);
  HEAPF32[$101>>2] = $100;
  $102 = (($arPoseA) + 596|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = (($arPose) + 596|0);
  HEAPF32[$104>>2] = $103;
  $105 = (($arPoseA) + 600|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = (($arPose) + 600|0);
  HEAPF32[$107>>2] = $106;
  $108 = (($arPoseA) + 604|0);
  $109 = Math_fround(HEAPF32[$108>>2]);
  $110 = (($arPose) + 604|0);
  HEAPF32[$110>>2] = $109;
  $111 = (($arPoseA) + 608|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($arPose) + 608|0);
  HEAPF32[$113>>2] = $112;
  $114 = (($arPoseA) + 612|0);
  $115 = Math_fround(HEAPF32[$114>>2]);
  $116 = (($arPose) + 612|0);
  HEAPF32[$116>>2] = $115;
  $117 = (($arPoseA) + 616|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = (($arPose) + 616|0);
  HEAPF32[$119>>2] = $118;
  $120 = (($arPoseA) + 620|0);
  $121 = Math_fround(HEAPF32[$120>>2]);
  $122 = (($arPose) + 620|0);
  HEAPF32[$122>>2] = $121;
  $123 = (($arPoseA) + 624|0);
  $124 = Math_fround(HEAPF32[$123>>2]);
  $125 = (($arPose) + 624|0);
  HEAPF32[$125>>2] = $124;
  $126 = (($arPoseA) + 628|0);
  $127 = Math_fround(HEAPF32[$126>>2]);
  $128 = (($arPose) + 628|0);
  HEAPF32[$128>>2] = $127;
  $129 = (($arPoseA) + 632|0);
  $130 = Math_fround(HEAPF32[$129>>2]);
  $131 = (($arPose) + 632|0);
  HEAPF32[$131>>2] = $130;
  $132 = (($arPoseA) + 636|0);
  $133 = Math_fround(HEAPF32[$132>>2]);
  $134 = (($arPose) + 636|0);
  HEAPF32[$134>>2] = $133;
  $135 = (($arPoseA) + 640|0);
  $136 = Math_fround(HEAPF32[$135>>2]);
  $137 = (($arPose) + 640|0);
  HEAPF32[$137>>2] = $136;
  $138 = (($arPoseA) + 644|0);
  $139 = Math_fround(HEAPF32[$138>>2]);
  $140 = (($arPose) + 644|0);
  HEAPF32[$140>>2] = $139;
  $141 = (($arPoseA) + 648|0);
  $142 = Math_fround(HEAPF32[$141>>2]);
  $143 = (($arPose) + 648|0);
  HEAPF32[$143>>2] = $142;
  $144 = (($arPoseA) + 652|0);
  $145 = Math_fround(HEAPF32[$144>>2]);
  $146 = (($arPose) + 652|0);
  HEAPF32[$146>>2] = $145;
  $i$518 = 0;
 }
 while(1) {
  $147 = (($i$518) + 53)|0;
  $148 = $147 >>> 5;
  $149 = (($arHumanPoseMask) + ($148<<2)|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = $147 & 31;
  $152 = 1 << $151;
  $153 = $150 & $152;
  $154 = ($153|0)==(0);
  $155 = ((($arPose) + (($i$518*76)|0)|0) + 80|0);
  if ($154) {
   $191 = ((($arPose) + (($i$518*76)|0)|0) + 108|0);
   ;HEAP32[$155+0>>2]=0|0;HEAP32[$155+4>>2]=0|0;HEAP32[$155+8>>2]=0|0;HEAP32[$155+12>>2]=0|0;HEAP32[$155+16>>2]=0|0;HEAP32[$155+20>>2]=0|0;HEAP32[$155+24>>2]=0|0;
   HEAPF32[$191>>2] = Math_fround(1.0);
   $192 = ((($arPose) + (($i$518*76)|0)|0) + 112|0);
   HEAPF32[$192>>2] = Math_fround(1.0);
   $193 = ((($arPose) + (($i$518*76)|0)|0) + 116|0);
   HEAPF32[$193>>2] = Math_fround(1.0);
   $194 = ((($arPose) + (($i$518*76)|0)|0) + 120|0);
   HEAPF32[$194>>2] = Math_fround(1.0);
   $195 = ((($arPose) + (($i$518*76)|0)|0) + 124|0);
   HEAPF32[$195>>2] = Math_fround(1.0);
  } else {
   $156 = ((($arPoseA) + (($i$518*76)|0)|0) + 80|0);
   $157 = Math_fround(HEAPF32[$156>>2]);
   $158 = ((($arPoseA) + (($i$518*76)|0)|0) + 84|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = ((($arPoseA) + (($i$518*76)|0)|0) + 88|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = ((($arPoseA) + (($i$518*76)|0)|0) + 92|0);
   $163 = Math_fround(HEAPF32[$162>>2]);
   HEAPF32[$155>>2] = $157;
   $164 = ((($arPose) + (($i$518*76)|0)|0) + 84|0);
   HEAPF32[$164>>2] = $159;
   $165 = ((($arPose) + (($i$518*76)|0)|0) + 88|0);
   HEAPF32[$165>>2] = $161;
   $166 = ((($arPose) + (($i$518*76)|0)|0) + 92|0);
   HEAPF32[$166>>2] = $163;
   $167 = ((($arPoseA) + (($i$518*76)|0)|0) + 96|0);
   $168 = Math_fround(HEAPF32[$167>>2]);
   $169 = ((($arPoseA) + (($i$518*76)|0)|0) + 100|0);
   $170 = Math_fround(HEAPF32[$169>>2]);
   $171 = ((($arPoseA) + (($i$518*76)|0)|0) + 104|0);
   $172 = Math_fround(HEAPF32[$171>>2]);
   $173 = ((($arPoseA) + (($i$518*76)|0)|0) + 108|0);
   $174 = Math_fround(HEAPF32[$173>>2]);
   $175 = ((($arPose) + (($i$518*76)|0)|0) + 96|0);
   HEAPF32[$175>>2] = $168;
   $176 = ((($arPose) + (($i$518*76)|0)|0) + 100|0);
   HEAPF32[$176>>2] = $170;
   $177 = ((($arPose) + (($i$518*76)|0)|0) + 104|0);
   HEAPF32[$177>>2] = $172;
   $178 = ((($arPose) + (($i$518*76)|0)|0) + 108|0);
   HEAPF32[$178>>2] = $174;
   $179 = ((($arPoseA) + (($i$518*76)|0)|0) + 112|0);
   $180 = Math_fround(HEAPF32[$179>>2]);
   $181 = ((($arPoseA) + (($i$518*76)|0)|0) + 116|0);
   $182 = Math_fround(HEAPF32[$181>>2]);
   $183 = ((($arPoseA) + (($i$518*76)|0)|0) + 120|0);
   $184 = Math_fround(HEAPF32[$183>>2]);
   $185 = ((($arPoseA) + (($i$518*76)|0)|0) + 124|0);
   $186 = Math_fround(HEAPF32[$185>>2]);
   $187 = ((($arPose) + (($i$518*76)|0)|0) + 112|0);
   HEAPF32[$187>>2] = $180;
   $188 = ((($arPose) + (($i$518*76)|0)|0) + 116|0);
   HEAPF32[$188>>2] = $182;
   $189 = ((($arPose) + (($i$518*76)|0)|0) + 120|0);
   HEAPF32[$189>>2] = $184;
   $190 = ((($arPose) + (($i$518*76)|0)|0) + 124|0);
   HEAPF32[$190>>2] = $186;
  }
  $196 = (($i$518) + 1)|0;
  $exitcond = ($196|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $i$518 = $196;
  }
 }
 $197 = HEAP32[$arHumanPoseMask>>2]|0;
 $198 = $197 & 1;
 $199 = ($198|0)==(0);
 if ($199) {
  $234 = (($arPose) + 28|0);
  ;HEAP32[$arPose+0>>2]=0|0;HEAP32[$arPose+4>>2]=0|0;HEAP32[$arPose+8>>2]=0|0;HEAP32[$arPose+12>>2]=0|0;HEAP32[$arPose+16>>2]=0|0;HEAP32[$arPose+20>>2]=0|0;HEAP32[$arPose+24>>2]=0|0;
  HEAPF32[$234>>2] = Math_fround(1.0);
  $235 = (($arPose) + 32|0);
  HEAPF32[$235>>2] = Math_fround(1.0);
  $236 = (($arPose) + 36|0);
  HEAPF32[$236>>2] = Math_fround(1.0);
  $237 = (($arPose) + 40|0);
  HEAPF32[$237>>2] = Math_fround(1.0);
  $238 = (($arPose) + 44|0);
  HEAPF32[$238>>2] = Math_fround(1.0);
  STACKTOP = sp;return;
 } else {
  $200 = Math_fround(HEAPF32[$arPoseA>>2]);
  $201 = (($arPoseA) + 4|0);
  $202 = Math_fround(HEAPF32[$201>>2]);
  $203 = (($arPoseA) + 8|0);
  $204 = Math_fround(HEAPF32[$203>>2]);
  $205 = (($arPoseA) + 12|0);
  $206 = Math_fround(HEAPF32[$205>>2]);
  HEAPF32[$arPose>>2] = $200;
  $207 = (($arPose) + 4|0);
  HEAPF32[$207>>2] = $202;
  $208 = (($arPose) + 8|0);
  HEAPF32[$208>>2] = $204;
  $209 = (($arPose) + 12|0);
  HEAPF32[$209>>2] = $206;
  $210 = (($arPoseA) + 16|0);
  $211 = Math_fround(HEAPF32[$210>>2]);
  $212 = (($arPoseA) + 20|0);
  $213 = Math_fround(HEAPF32[$212>>2]);
  $214 = (($arPoseA) + 24|0);
  $215 = Math_fround(HEAPF32[$214>>2]);
  $216 = (($arPoseA) + 28|0);
  $217 = Math_fround(HEAPF32[$216>>2]);
  $218 = (($arPose) + 16|0);
  HEAPF32[$218>>2] = $211;
  $219 = (($arPose) + 20|0);
  HEAPF32[$219>>2] = $213;
  $220 = (($arPose) + 24|0);
  HEAPF32[$220>>2] = $215;
  $221 = (($arPose) + 28|0);
  HEAPF32[$221>>2] = $217;
  $222 = (($arPoseA) + 32|0);
  $223 = Math_fround(HEAPF32[$222>>2]);
  $224 = (($arPoseA) + 36|0);
  $225 = Math_fround(HEAPF32[$224>>2]);
  $226 = (($arPoseA) + 40|0);
  $227 = Math_fround(HEAPF32[$226>>2]);
  $228 = (($arPoseA) + 44|0);
  $229 = Math_fround(HEAPF32[$228>>2]);
  $230 = (($arPose) + 32|0);
  HEAPF32[$230>>2] = $223;
  $231 = (($arPose) + 36|0);
  HEAPF32[$231>>2] = $225;
  $232 = (($arPose) + 40|0);
  HEAPF32[$232>>2] = $227;
  $233 = (($arPose) + 44|0);
  HEAPF32[$233>>2] = $229;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim5human12HumanPoseAddERNS0_9HumanPoseERKS1_S4_($arPose,$arPoseA,$arPoseB) {
 $arPose = $arPose|0;
 $arPoseA = $arPoseA|0;
 $arPoseB = $arPoseB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $exitcond = 0, $exitcond5 = 0, $exitcond6 = 0, $i$04 = 0, $i$13 = 0, $i$21 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = (($0) + 4|0);
 $3 = (($0) + 8|0);
 $4 = (($0) + 12|0);
 $5 = (($0) + 16|0);
 $6 = (($0) + 20|0);
 $7 = (($0) + 24|0);
 $8 = (($0) + 28|0);
 $9 = (($0) + 32|0);
 $10 = (($0) + 36|0);
 $11 = (($0) + 40|0);
 $12 = (($0) + 44|0);
 $i$04 = 0;
 while(1) {
  $13 = ((($arPoseA) + (($i$04*76)|0)|0) + 80|0);
  $14 = ((($arPoseB) + (($i$04*76)|0)|0) + 80|0);
  __ZN4mathL8xformMulERKNS_5xformES2_19323($0,$13,$14);
  $15 = Math_fround(HEAPF32[$0>>2]);
  $16 = Math_fround(HEAPF32[$2>>2]);
  $17 = Math_fround(HEAPF32[$3>>2]);
  $18 = Math_fround(HEAPF32[$4>>2]);
  $19 = ((($arPose) + (($i$04*76)|0)|0) + 80|0);
  HEAPF32[$19>>2] = $15;
  $20 = ((($arPose) + (($i$04*76)|0)|0) + 84|0);
  HEAPF32[$20>>2] = $16;
  $21 = ((($arPose) + (($i$04*76)|0)|0) + 88|0);
  HEAPF32[$21>>2] = $17;
  $22 = ((($arPose) + (($i$04*76)|0)|0) + 92|0);
  HEAPF32[$22>>2] = $18;
  $23 = Math_fround(HEAPF32[$5>>2]);
  $24 = Math_fround(HEAPF32[$6>>2]);
  $25 = Math_fround(HEAPF32[$7>>2]);
  $26 = Math_fround(HEAPF32[$8>>2]);
  $27 = ((($arPose) + (($i$04*76)|0)|0) + 96|0);
  HEAPF32[$27>>2] = $23;
  $28 = ((($arPose) + (($i$04*76)|0)|0) + 100|0);
  HEAPF32[$28>>2] = $24;
  $29 = ((($arPose) + (($i$04*76)|0)|0) + 104|0);
  HEAPF32[$29>>2] = $25;
  $30 = ((($arPose) + (($i$04*76)|0)|0) + 108|0);
  HEAPF32[$30>>2] = $26;
  $31 = Math_fround(HEAPF32[$9>>2]);
  $32 = Math_fround(HEAPF32[$10>>2]);
  $33 = Math_fround(HEAPF32[$11>>2]);
  $34 = Math_fround(HEAPF32[$12>>2]);
  $35 = ((($arPose) + (($i$04*76)|0)|0) + 112|0);
  HEAPF32[$35>>2] = $31;
  $36 = ((($arPose) + (($i$04*76)|0)|0) + 116|0);
  HEAPF32[$36>>2] = $32;
  $37 = ((($arPose) + (($i$04*76)|0)|0) + 120|0);
  HEAPF32[$37>>2] = $33;
  $38 = ((($arPose) + (($i$04*76)|0)|0) + 124|0);
  HEAPF32[$38>>2] = $34;
  $39 = (($i$04) + 1)|0;
  $exitcond6 = ($39|0)==(4);
  if ($exitcond6) {
   $i$13 = 0;
   break;
  } else {
   $i$04 = $39;
  }
 }
 while(1) {
  $40 = ((($arPoseA) + ($i$13<<2)|0) + 672|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = ((($arPoseB) + ($i$13<<2)|0) + 672|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($41 + $43);
  $45 = ((($arPose) + ($i$13<<2)|0) + 672|0);
  HEAPF32[$45>>2] = $44;
  $46 = (($i$13) + 1)|0;
  $exitcond5 = ($46|0)==(52);
  if ($exitcond5) {
   $i$21 = 0;
   break;
  } else {
   $i$13 = $46;
  }
 }
 while(1) {
  $47 = ((($arPoseA) + ($i$21<<2)|0) + 432|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = ((($arPoseB) + ($i$21<<2)|0) + 432|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($48 + $50);
  $52 = ((($arPose) + ($i$21<<2)|0) + 432|0);
  HEAPF32[$52>>2] = $51;
  $53 = ((($arPoseA) + ($i$21<<2)|0) + 576|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = ((($arPoseB) + ($i$21<<2)|0) + 576|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($54 + $56);
  $58 = ((($arPose) + ($i$21<<2)|0) + 576|0);
  HEAPF32[$58>>2] = $57;
  $59 = (($i$21) + 1)|0;
  $exitcond = ($59|0)==(20);
  if ($exitcond) {
   break;
  } else {
   $i$21 = $59;
  }
 }
 __ZN4mathL8xformMulERKNS_5xformES2_19323($1,$arPoseA,$arPoseB);
 $60 = Math_fround(HEAPF32[$1>>2]);
 $61 = (($1) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($1) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($1) + 12|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 HEAPF32[$arPose>>2] = $60;
 $67 = (($arPose) + 4|0);
 HEAPF32[$67>>2] = $62;
 $68 = (($arPose) + 8|0);
 HEAPF32[$68>>2] = $64;
 $69 = (($arPose) + 12|0);
 HEAPF32[$69>>2] = $66;
 $70 = (($1) + 16|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($1) + 20|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($1) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($1) + 28|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($arPose) + 16|0);
 HEAPF32[$78>>2] = $71;
 $79 = (($arPose) + 20|0);
 HEAPF32[$79>>2] = $73;
 $80 = (($arPose) + 24|0);
 HEAPF32[$80>>2] = $75;
 $81 = (($arPose) + 28|0);
 HEAPF32[$81>>2] = $77;
 $82 = (($1) + 32|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($1) + 36|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($1) + 40|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($1) + 44|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($arPose) + 32|0);
 HEAPF32[$90>>2] = $83;
 $91 = (($arPose) + 36|0);
 HEAPF32[$91>>2] = $85;
 $92 = (($arPose) + 40|0);
 HEAPF32[$92>>2] = $87;
 $93 = (($arPose) + 44|0);
 HEAPF32[$93>>2] = $89;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human12HumanPoseSubERNS0_9HumanPoseERKS1_S4_($arPose,$arPoseA,$arPoseB) {
 $arPose = $arPose|0;
 $arPoseA = $arPoseA|0;
 $arPoseB = $arPoseB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $exitcond = 0, $exitcond5 = 0, $exitcond6 = 0, $i$04 = 0, $i$13 = 0, $i$21 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 48|0;
 $1 = sp;
 $2 = (($0) + 4|0);
 $3 = (($0) + 8|0);
 $4 = (($0) + 12|0);
 $5 = (($0) + 16|0);
 $6 = (($0) + 20|0);
 $7 = (($0) + 24|0);
 $8 = (($0) + 28|0);
 $9 = (($0) + 32|0);
 $10 = (($0) + 36|0);
 $11 = (($0) + 40|0);
 $12 = (($0) + 44|0);
 $i$04 = 0;
 while(1) {
  $13 = ((($arPoseB) + (($i$04*76)|0)|0) + 80|0);
  $14 = ((($arPoseA) + (($i$04*76)|0)|0) + 80|0);
  __ZN4mathL13xformInvMulNSERKNS_5xformES2_19341($0,$13,$14);
  $15 = Math_fround(HEAPF32[$0>>2]);
  $16 = Math_fround(HEAPF32[$2>>2]);
  $17 = Math_fround(HEAPF32[$3>>2]);
  $18 = Math_fround(HEAPF32[$4>>2]);
  $19 = ((($arPose) + (($i$04*76)|0)|0) + 80|0);
  HEAPF32[$19>>2] = $15;
  $20 = ((($arPose) + (($i$04*76)|0)|0) + 84|0);
  HEAPF32[$20>>2] = $16;
  $21 = ((($arPose) + (($i$04*76)|0)|0) + 88|0);
  HEAPF32[$21>>2] = $17;
  $22 = ((($arPose) + (($i$04*76)|0)|0) + 92|0);
  HEAPF32[$22>>2] = $18;
  $23 = Math_fround(HEAPF32[$5>>2]);
  $24 = Math_fround(HEAPF32[$6>>2]);
  $25 = Math_fround(HEAPF32[$7>>2]);
  $26 = Math_fround(HEAPF32[$8>>2]);
  $27 = ((($arPose) + (($i$04*76)|0)|0) + 96|0);
  HEAPF32[$27>>2] = $23;
  $28 = ((($arPose) + (($i$04*76)|0)|0) + 100|0);
  HEAPF32[$28>>2] = $24;
  $29 = ((($arPose) + (($i$04*76)|0)|0) + 104|0);
  HEAPF32[$29>>2] = $25;
  $30 = ((($arPose) + (($i$04*76)|0)|0) + 108|0);
  HEAPF32[$30>>2] = $26;
  $31 = Math_fround(HEAPF32[$9>>2]);
  $32 = Math_fround(HEAPF32[$10>>2]);
  $33 = Math_fround(HEAPF32[$11>>2]);
  $34 = Math_fround(HEAPF32[$12>>2]);
  $35 = ((($arPose) + (($i$04*76)|0)|0) + 112|0);
  HEAPF32[$35>>2] = $31;
  $36 = ((($arPose) + (($i$04*76)|0)|0) + 116|0);
  HEAPF32[$36>>2] = $32;
  $37 = ((($arPose) + (($i$04*76)|0)|0) + 120|0);
  HEAPF32[$37>>2] = $33;
  $38 = ((($arPose) + (($i$04*76)|0)|0) + 124|0);
  HEAPF32[$38>>2] = $34;
  $39 = (($i$04) + 1)|0;
  $exitcond6 = ($39|0)==(4);
  if ($exitcond6) {
   $i$13 = 0;
   break;
  } else {
   $i$04 = $39;
  }
 }
 while(1) {
  $40 = ((($arPoseA) + ($i$13<<2)|0) + 672|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = ((($arPoseB) + ($i$13<<2)|0) + 672|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($41 - $43);
  $45 = ((($arPose) + ($i$13<<2)|0) + 672|0);
  HEAPF32[$45>>2] = $44;
  $46 = (($i$13) + 1)|0;
  $exitcond5 = ($46|0)==(52);
  if ($exitcond5) {
   $i$21 = 0;
   break;
  } else {
   $i$13 = $46;
  }
 }
 while(1) {
  $47 = ((($arPoseA) + ($i$21<<2)|0) + 432|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = ((($arPoseB) + ($i$21<<2)|0) + 432|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($48 - $50);
  $52 = ((($arPose) + ($i$21<<2)|0) + 432|0);
  HEAPF32[$52>>2] = $51;
  $53 = ((($arPoseA) + ($i$21<<2)|0) + 576|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = ((($arPoseB) + ($i$21<<2)|0) + 576|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = Math_fround($54 - $56);
  $58 = ((($arPose) + ($i$21<<2)|0) + 576|0);
  HEAPF32[$58>>2] = $57;
  $59 = (($i$21) + 1)|0;
  $exitcond = ($59|0)==(20);
  if ($exitcond) {
   break;
  } else {
   $i$21 = $59;
  }
 }
 __ZN4mathL13xformInvMulNSERKNS_5xformES2_19341($1,$arPoseB,$arPoseA);
 $60 = Math_fround(HEAPF32[$1>>2]);
 $61 = (($1) + 4|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($1) + 8|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = (($1) + 12|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 HEAPF32[$arPose>>2] = $60;
 $67 = (($arPose) + 4|0);
 HEAPF32[$67>>2] = $62;
 $68 = (($arPose) + 8|0);
 HEAPF32[$68>>2] = $64;
 $69 = (($arPose) + 12|0);
 HEAPF32[$69>>2] = $66;
 $70 = (($1) + 16|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = (($1) + 20|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = (($1) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($1) + 28|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = (($arPose) + 16|0);
 HEAPF32[$78>>2] = $71;
 $79 = (($arPose) + 20|0);
 HEAPF32[$79>>2] = $73;
 $80 = (($arPose) + 24|0);
 HEAPF32[$80>>2] = $75;
 $81 = (($arPose) + 28|0);
 HEAPF32[$81>>2] = $77;
 $82 = (($1) + 32|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($1) + 36|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = (($1) + 40|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = (($1) + 44|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = (($arPose) + 32|0);
 HEAPF32[$90>>2] = $83;
 $91 = (($arPose) + 36|0);
 HEAPF32[$91>>2] = $85;
 $92 = (($arPose) + 40|0);
 HEAPF32[$92>>2] = $87;
 $93 = (($arPose) + 44|0);
 HEAPF32[$93>>2] = $89;
 STACKTOP = sp;return;
}
function __ZN4mathL13xformInvMulNSERKNS_5xformES2_19341($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0;
 var $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0);
 var $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0);
 var $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0);
 var $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0);
 var $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(-1.0));
 $3 = (($a) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(-1.0));
 $6 = (($a) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(-1.0));
 $9 = (($a) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$b>>2]);
 $12 = Math_fround(HEAPF32[$a>>2]);
 $13 = Math_fround($11 - $12);
 $14 = (($b) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = (($b) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($a) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 - $22);
 $24 = (($b) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($a) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 - $27);
 $29 = Math_fround($13 + $13);
 $30 = Math_fround($18 + $18);
 $31 = Math_fround($23 + $23);
 $32 = Math_fround($2 * $30);
 $33 = Math_fround($5 * $31);
 $34 = Math_fround($8 * $29);
 $35 = Math_fround($10 * Math_fround(0.0));
 $36 = Math_fround($5 * $29);
 $37 = Math_fround($8 * $30);
 $38 = Math_fround($2 * $31);
 $39 = Math_fround($32 - $36);
 $40 = Math_fround($33 - $37);
 $41 = Math_fround($34 - $38);
 $42 = Math_fround($35 - $35);
 $43 = Math_fround($10 * $40);
 $44 = Math_fround($10 * $41);
 $45 = Math_fround($10 * $39);
 $46 = Math_fround($10 * $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 + $45);
 $50 = Math_fround($46 + $28);
 $51 = Math_fround($2 * $41);
 $52 = Math_fround($5 * $39);
 $53 = Math_fround($8 * $40);
 $54 = Math_fround($5 * $40);
 $55 = Math_fround($8 * $41);
 $56 = Math_fround($2 * $39);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($52 - $55);
 $59 = Math_fround($53 - $56);
 $60 = Math_fround($46 - $46);
 $61 = Math_fround($47 + $58);
 $62 = Math_fround($48 + $59);
 $63 = Math_fround($49 + $57);
 $64 = Math_fround($60 + $50);
 $65 = (($b) + 16|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($5 * $66);
 $68 = (($b) + 28|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($10 * $69);
 $71 = (($b) + 20|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($8 * $72);
 $74 = (($b) + 24|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($2 * $75);
 $77 = Math_fround($10 * $75);
 $78 = Math_fround($2 * $66);
 $79 = Math_fround($5 * $75);
 $80 = Math_fround($8 * $66);
 $81 = Math_fround($67 - $77);
 $82 = Math_fround($70 - $78);
 $83 = Math_fround($73 - $79);
 $84 = Math_fround($76 - $80);
 $85 = Math_fround($8 * $69);
 $86 = Math_fround($8 * $75);
 $87 = Math_fround($10 * $66);
 $88 = Math_fround($10 * $72);
 $89 = Math_fround($81 - $85);
 $90 = Math_fround($82 - $86);
 $91 = Math_fround($83 - $87);
 $92 = Math_fround($84 - $88);
 $93 = Math_fround($2 * $72);
 $94 = Math_fround($5 * $72);
 $95 = Math_fround($2 * $69);
 $96 = Math_fround($5 * $69);
 $97 = Math_fround($89 - $93);
 $98 = Math_fround($90 - $94);
 $99 = Math_fround($91 - $95);
 $100 = Math_fround($92 - $96);
 $101 = Math_fround($99 * Math_fround(-1.0));
 $102 = Math_fround($100 * Math_fround(-1.0));
 $103 = Math_fround($97 * Math_fround(-1.0));
 $104 = Math_fround($101 * $101);
 $105 = Math_fround($102 * $102);
 $106 = Math_fround($103 * $103);
 $107 = Math_fround($98 * $98);
 $108 = Math_fround($104 + $105);
 $109 = Math_fround($107 + $106);
 $110 = Math_fround($108 + $109);
 $111 = (Math_fround(Math_sqrt((Math_fround($110)))));
 $112 = Math_fround(Math_fround(1.0) / $111);
 $113 = Math_fround($112 * $101);
 $114 = Math_fround($112 * $102);
 $115 = Math_fround($112 * $103);
 $116 = Math_fround($112 * $98);
 HEAPF32[$agg$result>>2] = $61;
 $117 = (($agg$result) + 4|0);
 HEAPF32[$117>>2] = $62;
 $118 = (($agg$result) + 8|0);
 HEAPF32[$118>>2] = $63;
 $119 = (($agg$result) + 12|0);
 HEAPF32[$119>>2] = $64;
 $120 = (($agg$result) + 16|0);
 HEAPF32[$120>>2] = $113;
 $121 = (($agg$result) + 20|0);
 HEAPF32[$121>>2] = $114;
 $122 = (($agg$result) + 24|0);
 HEAPF32[$122>>2] = $115;
 $123 = (($agg$result) + 28|0);
 HEAPF32[$123>>2] = $116;
 $124 = (($agg$result) + 32|0);
 HEAPF32[$124>>2] = Math_fround(1.0);
 $125 = (($agg$result) + 36|0);
 HEAPF32[$125>>2] = Math_fround(1.0);
 $126 = (($agg$result) + 40|0);
 HEAPF32[$126>>2] = Math_fround(1.0);
 $127 = (($agg$result) + 44|0);
 HEAPF32[$127>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human15HumanPoseWeightERNS0_9HumanPoseERKS1_f($arPose,$arPoseA,$aWeight) {
 $arPose = $arPose|0;
 $arPoseA = $arPoseA|0;
 $aWeight = Math_fround($aWeight);
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0;
 var $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0;
 var $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $exitcond = 0, $exitcond18 = 0, $exitcond19 = 0, $i$017 = 0, $i$116 = 0, $i$214 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$017 = 0;
 while(1) {
  $0 = ((($arPoseA) + (($i$017*76)|0)|0) + 80|0);
  $1 = Math_fround(HEAPF32[$0>>2]);
  $2 = Math_fround($1 * $aWeight);
  $3 = ((($arPoseA) + (($i$017*76)|0)|0) + 84|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = Math_fround($4 * $aWeight);
  $6 = ((($arPoseA) + (($i$017*76)|0)|0) + 88|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  $8 = Math_fround($7 * $aWeight);
  $9 = ((($arPoseA) + (($i$017*76)|0)|0) + 92|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = Math_fround($10 * $aWeight);
  $12 = ((($arPoseA) + (($i$017*76)|0)|0) + 96|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = Math_fround($13 * $aWeight);
  $15 = ((($arPoseA) + (($i$017*76)|0)|0) + 100|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = Math_fround($16 * $aWeight);
  $18 = ((($arPoseA) + (($i$017*76)|0)|0) + 104|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($19 * $aWeight);
  $21 = ((($arPoseA) + (($i$017*76)|0)|0) + 108|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = Math_fround($14 * $14);
  $24 = Math_fround($17 * $17);
  $25 = Math_fround($20 * $20);
  $26 = Math_fround($22 * $22);
  $27 = Math_fround($23 + $24);
  $28 = Math_fround($25 + $26);
  $29 = Math_fround($27 + $28);
  $30 = (Math_fround(Math_sqrt((Math_fround($29)))));
  $31 = Math_fround(Math_fround(1.0) / $30);
  $32 = Math_fround($14 * $31);
  $33 = Math_fround($17 * $31);
  $34 = Math_fround($20 * $31);
  $35 = Math_fround($22 * $31);
  $36 = ((($arPose) + (($i$017*76)|0)|0) + 80|0);
  HEAPF32[$36>>2] = $2;
  $37 = ((($arPose) + (($i$017*76)|0)|0) + 84|0);
  HEAPF32[$37>>2] = $5;
  $38 = ((($arPose) + (($i$017*76)|0)|0) + 88|0);
  HEAPF32[$38>>2] = $8;
  $39 = ((($arPose) + (($i$017*76)|0)|0) + 92|0);
  HEAPF32[$39>>2] = $11;
  $40 = ((($arPose) + (($i$017*76)|0)|0) + 96|0);
  HEAPF32[$40>>2] = $32;
  $41 = ((($arPose) + (($i$017*76)|0)|0) + 100|0);
  HEAPF32[$41>>2] = $33;
  $42 = ((($arPose) + (($i$017*76)|0)|0) + 104|0);
  HEAPF32[$42>>2] = $34;
  $43 = ((($arPose) + (($i$017*76)|0)|0) + 108|0);
  HEAPF32[$43>>2] = $35;
  $44 = ((($arPose) + (($i$017*76)|0)|0) + 112|0);
  HEAPF32[$44>>2] = Math_fround(1.0);
  $45 = ((($arPose) + (($i$017*76)|0)|0) + 116|0);
  HEAPF32[$45>>2] = Math_fround(1.0);
  $46 = ((($arPose) + (($i$017*76)|0)|0) + 120|0);
  HEAPF32[$46>>2] = Math_fround(1.0);
  $47 = ((($arPose) + (($i$017*76)|0)|0) + 124|0);
  HEAPF32[$47>>2] = Math_fround(1.0);
  $48 = (($i$017) + 1)|0;
  $exitcond19 = ($48|0)==(4);
  if ($exitcond19) {
   $i$116 = 0;
   break;
  } else {
   $i$017 = $48;
  }
 }
 while(1) {
  $49 = ((($arPoseA) + ($i$116<<2)|0) + 672|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround($50 * $aWeight);
  $52 = ((($arPose) + ($i$116<<2)|0) + 672|0);
  HEAPF32[$52>>2] = $51;
  $53 = (($i$116) + 1)|0;
  $exitcond18 = ($53|0)==(52);
  if ($exitcond18) {
   $i$214 = 0;
   break;
  } else {
   $i$116 = $53;
  }
 }
 while(1) {
  $54 = ((($arPoseA) + ($i$214<<2)|0) + 432|0);
  $55 = Math_fround(HEAPF32[$54>>2]);
  $56 = Math_fround($55 * $aWeight);
  $57 = ((($arPose) + ($i$214<<2)|0) + 432|0);
  HEAPF32[$57>>2] = $56;
  $58 = ((($arPoseA) + ($i$214<<2)|0) + 576|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = Math_fround($59 * $aWeight);
  $61 = ((($arPose) + ($i$214<<2)|0) + 576|0);
  HEAPF32[$61>>2] = $60;
  $62 = (($i$214) + 1)|0;
  $exitcond = ($62|0)==(20);
  if ($exitcond) {
   break;
  } else {
   $i$214 = $62;
  }
 }
 $63 = Math_fround(HEAPF32[$arPoseA>>2]);
 $64 = Math_fround($63 * $aWeight);
 $65 = (($arPoseA) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 * $aWeight);
 $68 = (($arPoseA) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 * $aWeight);
 $71 = (($arPoseA) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 * $aWeight);
 $74 = (($arPoseA) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($75 * $aWeight);
 $77 = (($arPoseA) + 20|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($78 * $aWeight);
 $80 = (($arPoseA) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 * $aWeight);
 $83 = (($arPoseA) + 28|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($76 * $76);
 $86 = Math_fround($79 * $79);
 $87 = Math_fround($82 * $82);
 $88 = Math_fround($84 * $84);
 $89 = Math_fround($85 + $86);
 $90 = Math_fround($87 + $88);
 $91 = Math_fround($89 + $90);
 $92 = (Math_fround(Math_sqrt((Math_fround($91)))));
 $93 = Math_fround(Math_fround(1.0) / $92);
 $94 = Math_fround($76 * $93);
 $95 = Math_fround($79 * $93);
 $96 = Math_fround($82 * $93);
 $97 = Math_fround($84 * $93);
 HEAPF32[$arPose>>2] = $64;
 $98 = (($arPose) + 4|0);
 HEAPF32[$98>>2] = $67;
 $99 = (($arPose) + 8|0);
 HEAPF32[$99>>2] = $70;
 $100 = (($arPose) + 12|0);
 HEAPF32[$100>>2] = $73;
 $101 = (($arPose) + 16|0);
 HEAPF32[$101>>2] = $94;
 $102 = (($arPose) + 20|0);
 HEAPF32[$102>>2] = $95;
 $103 = (($arPose) + 24|0);
 HEAPF32[$103>>2] = $96;
 $104 = (($arPose) + 28|0);
 HEAPF32[$104>>2] = $97;
 $105 = (($arPose) + 32|0);
 HEAPF32[$105>>2] = Math_fround(1.0);
 $106 = (($arPose) + 36|0);
 HEAPF32[$106>>2] = Math_fround(1.0);
 $107 = (($arPose) + 40|0);
 HEAPF32[$107>>2] = Math_fround(1.0);
 $108 = (($arPose) + 44|0);
 HEAPF32[$108>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human15HumanPoseMirrorERNS0_9HumanPoseERKS1_($arPose,$arPoseA) {
 $arPose = $arPose|0;
 $arPoseA = $arPoseA|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert64 = 0, $$phi$trans$insert66 = 0, $$phi$trans$insert68 = 0, $$phi$trans$insert70 = 0, $$phi$trans$insert72 = 0, $$pre = Math_fround(0), $$pre65 = Math_fround(0), $$pre67 = Math_fround(0), $$pre69 = Math_fround(0), $$pre71 = Math_fround(0), $$pre73 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0);
 var $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0);
 var $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = Math_fround(0);
 var $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = 0;
 var $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0), $170 = Math_fround(0), $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = 0;
 var $178 = Math_fround(0), $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = Math_fround(0), $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0;
 var $196 = Math_fround(0), $197 = 0, $198 = Math_fround(0), $199 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0);
 var $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0);
 var $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0);
 var $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0);
 var $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0);
 var $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0);
 var $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0);
 var $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0);
 var $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0);
 var $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = 0, $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = 0, $38 = Math_fround(0), $39 = 0;
 var $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0;
 var $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0;
 var $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0;
 var $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $exitcond = 0, $exitcond55 = 0, $i$446 = 0, $i$545 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($arPose) + 676|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(-1.0));
 HEAPF32[$0>>2] = $2;
 $3 = (($arPose) + 680|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(-1.0));
 HEAPF32[$3>>2] = $5;
 $6 = (($arPose) + 688|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(-1.0));
 HEAPF32[$6>>2] = $8;
 $9 = (($arPose) + 692|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * Math_fround(-1.0));
 HEAPF32[$9>>2] = $11;
 $12 = (($arPose) + 700|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($13 * Math_fround(-1.0));
 HEAPF32[$12>>2] = $14;
 $15 = (($arPose) + 704|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * Math_fround(-1.0));
 HEAPF32[$15>>2] = $17;
 $18 = (($arPose) + 712|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * Math_fround(-1.0));
 HEAPF32[$18>>2] = $20;
 $21 = (($arPose) + 716|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * Math_fround(-1.0));
 HEAPF32[$21>>2] = $23;
 $24 = (($arPose) + 724|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * Math_fround(-1.0));
 HEAPF32[$24>>2] = $26;
 $27 = (($arPose) + 732|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * Math_fround(-1.0));
 HEAPF32[$27>>2] = $29;
 $30 = (($arPose) + 740|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * Math_fround(-1.0));
 HEAPF32[$30>>2] = $32;
 $33 = (($arPose) + 808|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($arPose) + 844|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 HEAPF32[$33>>2] = $36;
 HEAPF32[$35>>2] = $34;
 $37 = (($arPose) + 812|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($arPose) + 848|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 HEAPF32[$37>>2] = $40;
 HEAPF32[$39>>2] = $38;
 $41 = (($arPose) + 816|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($arPose) + 852|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 HEAPF32[$41>>2] = $44;
 HEAPF32[$43>>2] = $42;
 $45 = (($arPose) + 820|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($arPose) + 856|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 HEAPF32[$45>>2] = $48;
 HEAPF32[$47>>2] = $46;
 $49 = (($arPose) + 824|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($arPose) + 860|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 HEAPF32[$49>>2] = $52;
 HEAPF32[$51>>2] = $50;
 $53 = (($arPose) + 828|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($arPose) + 864|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 HEAPF32[$53>>2] = $56;
 HEAPF32[$55>>2] = $54;
 $57 = (($arPose) + 832|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = (($arPose) + 868|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 HEAPF32[$57>>2] = $60;
 HEAPF32[$59>>2] = $58;
 $61 = (($arPose) + 836|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = (($arPose) + 872|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 HEAPF32[$61>>2] = $64;
 HEAPF32[$63>>2] = $62;
 $65 = (($arPose) + 840|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = (($arPose) + 876|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 HEAPF32[$65>>2] = $68;
 HEAPF32[$67>>2] = $66;
 $69 = (($arPose) + 744|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = (($arPose) + 776|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 HEAPF32[$69>>2] = $72;
 HEAPF32[$71>>2] = $70;
 $73 = (($arPose) + 748|0);
 $74 = Math_fround(HEAPF32[$73>>2]);
 $75 = (($arPose) + 780|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 HEAPF32[$73>>2] = $76;
 HEAPF32[$75>>2] = $74;
 $77 = (($arPose) + 752|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($arPose) + 784|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 HEAPF32[$77>>2] = $80;
 HEAPF32[$79>>2] = $78;
 $81 = (($arPose) + 756|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 $83 = (($arPose) + 788|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 HEAPF32[$81>>2] = $84;
 HEAPF32[$83>>2] = $82;
 $85 = (($arPose) + 760|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = (($arPose) + 792|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 HEAPF32[$85>>2] = $88;
 HEAPF32[$87>>2] = $86;
 $89 = (($arPose) + 764|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = (($arPose) + 796|0);
 $92 = Math_fround(HEAPF32[$91>>2]);
 HEAPF32[$89>>2] = $92;
 HEAPF32[$91>>2] = $90;
 $93 = (($arPose) + 768|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = (($arPose) + 800|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 HEAPF32[$93>>2] = $96;
 HEAPF32[$95>>2] = $94;
 $97 = (($arPose) + 772|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = (($arPose) + 804|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 HEAPF32[$97>>2] = $100;
 HEAPF32[$99>>2] = $98;
 $101 = (($arPose) + 80|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = (($arPose) + 84|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 $105 = (($arPose) + 88|0);
 $106 = Math_fround(HEAPF32[$105>>2]);
 $107 = (($arPose) + 92|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = (($arPose) + 96|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = (($arPose) + 100|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = (($arPose) + 104|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($arPose) + 108|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = (($arPose) + 112|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = (($arPose) + 116|0);
 $120 = Math_fround(HEAPF32[$119>>2]);
 $121 = (($arPose) + 120|0);
 $122 = Math_fround(HEAPF32[$121>>2]);
 $123 = (($arPose) + 124|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = (($arPose) + 156|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($arPose) + 160|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = (($arPose) + 164|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = (($arPose) + 168|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 HEAPF32[$101>>2] = $126;
 HEAPF32[$103>>2] = $128;
 HEAPF32[$105>>2] = $130;
 HEAPF32[$107>>2] = $132;
 $133 = (($arPose) + 172|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = (($arPose) + 176|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = (($arPose) + 180|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 $139 = (($arPose) + 184|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 HEAPF32[$109>>2] = $134;
 HEAPF32[$111>>2] = $136;
 HEAPF32[$113>>2] = $138;
 HEAPF32[$115>>2] = $140;
 $141 = (($arPose) + 188|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = (($arPose) + 192|0);
 $144 = Math_fround(HEAPF32[$143>>2]);
 $145 = (($arPose) + 196|0);
 $146 = Math_fround(HEAPF32[$145>>2]);
 $147 = (($arPose) + 200|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 HEAPF32[$117>>2] = $142;
 HEAPF32[$119>>2] = $144;
 HEAPF32[$121>>2] = $146;
 HEAPF32[$123>>2] = $148;
 HEAPF32[$125>>2] = $102;
 HEAPF32[$127>>2] = $104;
 HEAPF32[$129>>2] = $106;
 HEAPF32[$131>>2] = $108;
 HEAPF32[$133>>2] = $110;
 HEAPF32[$135>>2] = $112;
 HEAPF32[$137>>2] = $114;
 HEAPF32[$139>>2] = $116;
 HEAPF32[$141>>2] = $118;
 HEAPF32[$143>>2] = $120;
 HEAPF32[$145>>2] = $122;
 HEAPF32[$147>>2] = $124;
 $149 = (($arPose) + 232|0);
 $150 = Math_fround(HEAPF32[$149>>2]);
 $151 = (($arPose) + 236|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = (($arPose) + 240|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = (($arPose) + 244|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = (($arPose) + 248|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = (($arPose) + 252|0);
 $160 = Math_fround(HEAPF32[$159>>2]);
 $161 = (($arPose) + 256|0);
 $162 = Math_fround(HEAPF32[$161>>2]);
 $163 = (($arPose) + 260|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = (($arPose) + 264|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = (($arPose) + 268|0);
 $168 = Math_fround(HEAPF32[$167>>2]);
 $169 = (($arPose) + 272|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = (($arPose) + 276|0);
 $172 = Math_fround(HEAPF32[$171>>2]);
 $173 = (($arPose) + 308|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = (($arPose) + 312|0);
 $176 = Math_fround(HEAPF32[$175>>2]);
 $177 = (($arPose) + 316|0);
 $178 = Math_fround(HEAPF32[$177>>2]);
 $179 = (($arPose) + 320|0);
 $180 = Math_fround(HEAPF32[$179>>2]);
 HEAPF32[$149>>2] = $174;
 HEAPF32[$151>>2] = $176;
 HEAPF32[$153>>2] = $178;
 HEAPF32[$155>>2] = $180;
 $181 = (($arPose) + 324|0);
 $182 = Math_fround(HEAPF32[$181>>2]);
 $183 = (($arPose) + 328|0);
 $184 = Math_fround(HEAPF32[$183>>2]);
 $185 = (($arPose) + 332|0);
 $186 = Math_fround(HEAPF32[$185>>2]);
 $187 = (($arPose) + 336|0);
 $188 = Math_fround(HEAPF32[$187>>2]);
 HEAPF32[$157>>2] = $182;
 HEAPF32[$159>>2] = $184;
 HEAPF32[$161>>2] = $186;
 HEAPF32[$163>>2] = $188;
 $189 = (($arPose) + 340|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($arPose) + 344|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($arPose) + 348|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($arPose) + 352|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 HEAPF32[$165>>2] = $190;
 HEAPF32[$167>>2] = $192;
 HEAPF32[$169>>2] = $194;
 HEAPF32[$171>>2] = $196;
 HEAPF32[$173>>2] = $150;
 HEAPF32[$175>>2] = $152;
 HEAPF32[$177>>2] = $154;
 HEAPF32[$179>>2] = $156;
 HEAPF32[$181>>2] = $158;
 HEAPF32[$183>>2] = $160;
 HEAPF32[$185>>2] = $162;
 HEAPF32[$187>>2] = $164;
 HEAPF32[$189>>2] = $166;
 HEAPF32[$191>>2] = $168;
 HEAPF32[$193>>2] = $170;
 HEAPF32[$195>>2] = $172;
 $210 = $138;$211 = $140;$212 = $142;$213 = $144;$214 = $146;$215 = $148;$i$446 = 0;
 while(1) {
  $197 = ((($arPose) + (($i$446*76)|0)|0) + 80|0);
  $198 = Math_fround(HEAPF32[$197>>2]);
  $199 = ((($arPose) + (($i$446*76)|0)|0) + 100|0);
  $200 = Math_fround(HEAPF32[$199>>2]);
  $201 = ((($arPose) + (($i$446*76)|0)|0) + 104|0);
  $202 = ((($arPose) + (($i$446*76)|0)|0) + 108|0);
  $203 = ((($arPose) + (($i$446*76)|0)|0) + 112|0);
  $204 = ((($arPose) + (($i$446*76)|0)|0) + 116|0);
  $205 = ((($arPose) + (($i$446*76)|0)|0) + 120|0);
  $206 = ((($arPose) + (($i$446*76)|0)|0) + 124|0);
  $207 = Math_fround($198 * Math_fround(-1.0));
  $208 = Math_fround($200 * Math_fround(-1.0));
  $209 = Math_fround($210 * Math_fround(-1.0));
  HEAPF32[$197>>2] = $207;
  HEAPF32[$199>>2] = $208;
  HEAPF32[$201>>2] = $209;
  HEAPF32[$202>>2] = $211;
  HEAPF32[$203>>2] = $212;
  HEAPF32[$204>>2] = $213;
  HEAPF32[$205>>2] = $214;
  HEAPF32[$206>>2] = $215;
  $216 = (($i$446) + 1)|0;
  $exitcond55 = ($216|0)==(4);
  if ($exitcond55) {
   break;
  }
  $$phi$trans$insert = ((($arPose) + (($216*76)|0)|0) + 104|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$phi$trans$insert64 = ((($arPose) + (($216*76)|0)|0) + 108|0);
  $$pre65 = Math_fround(HEAPF32[$$phi$trans$insert64>>2]);
  $$phi$trans$insert66 = ((($arPose) + (($216*76)|0)|0) + 112|0);
  $$pre67 = Math_fround(HEAPF32[$$phi$trans$insert66>>2]);
  $$phi$trans$insert68 = ((($arPose) + (($216*76)|0)|0) + 116|0);
  $$pre69 = Math_fround(HEAPF32[$$phi$trans$insert68>>2]);
  $$phi$trans$insert70 = ((($arPose) + (($216*76)|0)|0) + 120|0);
  $$pre71 = Math_fround(HEAPF32[$$phi$trans$insert70>>2]);
  $$phi$trans$insert72 = ((($arPose) + (($216*76)|0)|0) + 124|0);
  $$pre73 = Math_fround(HEAPF32[$$phi$trans$insert72>>2]);
  $210 = $$pre;$211 = $$pre65;$212 = $$pre67;$213 = $$pre69;$214 = $$pre71;$215 = $$pre73;$i$446 = $216;
 }
 $217 = Math_fround(HEAPF32[$111>>2]);
 $218 = Math_fround($217 * Math_fround(0.0));
 $219 = Math_fround(HEAPF32[$115>>2]);
 $220 = Math_fround($219 * Math_fround(0.0));
 $221 = Math_fround(HEAPF32[$113>>2]);
 $222 = Math_fround(HEAPF32[$109>>2]);
 $223 = Math_fround($222 * Math_fround(0.0));
 $224 = Math_fround($221 * Math_fround(0.0));
 $225 = Math_fround($218 - $220);
 $226 = Math_fround($220 - $223);
 $227 = Math_fround($221 - $218);
 $228 = Math_fround($223 - $224);
 $229 = Math_fround($225 - $224);
 $230 = Math_fround($226 - $224);
 $231 = Math_fround($227 - $220);
 $232 = Math_fround($228 - $219);
 $233 = Math_fround($229 - $222);
 $234 = Math_fround($230 - $217);
 $235 = Math_fround($231 - $223);
 $236 = Math_fround($232 - $218);
 $237 = Math_fround($235 * Math_fround(-1.0));
 $238 = Math_fround($236 * Math_fround(-1.0));
 $239 = Math_fround($233 * Math_fround(-1.0));
 $240 = Math_fround($237 * $237);
 $241 = Math_fround($238 * $238);
 $242 = Math_fround($239 * $239);
 $243 = Math_fround($234 * $234);
 $244 = Math_fround($240 + $241);
 $245 = Math_fround($242 + $243);
 $246 = Math_fround($245 + $244);
 $247 = (Math_fround(Math_sqrt((Math_fround($246)))));
 $248 = Math_fround(Math_fround(1.0) / $247);
 $249 = Math_fround($248 * $237);
 $250 = Math_fround($248 * $238);
 $251 = Math_fround($248 * $239);
 $252 = Math_fround($248 * $234);
 HEAPF32[$109>>2] = $249;
 HEAPF32[$111>>2] = $250;
 HEAPF32[$113>>2] = $251;
 HEAPF32[$115>>2] = $252;
 $253 = Math_fround(HEAPF32[$135>>2]);
 $254 = Math_fround($253 * Math_fround(0.0));
 $255 = Math_fround(HEAPF32[$139>>2]);
 $256 = Math_fround($255 * Math_fround(0.0));
 $257 = Math_fround(HEAPF32[$137>>2]);
 $258 = Math_fround(HEAPF32[$133>>2]);
 $259 = Math_fround($258 * Math_fround(0.0));
 $260 = Math_fround($257 * Math_fround(0.0));
 $261 = Math_fround($254 - $256);
 $262 = Math_fround($256 - $259);
 $263 = Math_fround($257 - $254);
 $264 = Math_fround($259 - $260);
 $265 = Math_fround($261 - $260);
 $266 = Math_fround($262 - $260);
 $267 = Math_fround($263 - $256);
 $268 = Math_fround($264 - $255);
 $269 = Math_fround($265 - $258);
 $270 = Math_fround($266 - $253);
 $271 = Math_fround($267 - $259);
 $272 = Math_fround($268 - $254);
 $273 = Math_fround($271 * Math_fround(-1.0));
 $274 = Math_fround($272 * Math_fround(-1.0));
 $275 = Math_fround($269 * Math_fround(-1.0));
 $276 = Math_fround($273 * $273);
 $277 = Math_fround($274 * $274);
 $278 = Math_fround($275 * $275);
 $279 = Math_fround($270 * $270);
 $280 = Math_fround($276 + $277);
 $281 = Math_fround($278 + $279);
 $282 = Math_fround($281 + $280);
 $283 = (Math_fround(Math_sqrt((Math_fround($282)))));
 $284 = Math_fround(Math_fround(1.0) / $283);
 $285 = Math_fround($284 * $273);
 $286 = Math_fround($284 * $274);
 $287 = Math_fround($284 * $275);
 $288 = Math_fround($284 * $270);
 HEAPF32[$133>>2] = $285;
 HEAPF32[$135>>2] = $286;
 HEAPF32[$137>>2] = $287;
 HEAPF32[$139>>2] = $288;
 $289 = Math_fround(HEAPF32[$159>>2]);
 $290 = Math_fround($289 * Math_fround(0.0));
 $291 = Math_fround(HEAPF32[$163>>2]);
 $292 = Math_fround($291 * Math_fround(0.0));
 $293 = Math_fround(HEAPF32[$161>>2]);
 $294 = Math_fround($293 * Math_fround(0.0));
 $295 = Math_fround(HEAPF32[$157>>2]);
 $296 = Math_fround($295 * Math_fround(0.0));
 $297 = Math_fround($290 - $291);
 $298 = Math_fround($292 - $296);
 $299 = Math_fround($294 - $289);
 $300 = Math_fround($295 - $294);
 $301 = Math_fround($297 - $294);
 $302 = Math_fround($298 - $293);
 $303 = Math_fround($299 - $292);
 $304 = Math_fround($300 - $292);
 $305 = Math_fround($301 - $296);
 $306 = Math_fround($302 - $290);
 $307 = Math_fround($303 - $296);
 $308 = Math_fround($304 - $290);
 $309 = Math_fround($307 * Math_fround(-1.0));
 $310 = Math_fround($308 * Math_fround(-1.0));
 $311 = Math_fround($305 * Math_fround(-1.0));
 $312 = Math_fround($309 * $309);
 $313 = Math_fround($310 * $310);
 $314 = Math_fround($311 * $311);
 $315 = Math_fround($306 * $306);
 $316 = Math_fround($312 + $313);
 $317 = Math_fround($314 + $315);
 $318 = Math_fround($316 + $317);
 $319 = (Math_fround(Math_sqrt((Math_fround($318)))));
 $320 = Math_fround(Math_fround(1.0) / $319);
 $321 = Math_fround($320 * $309);
 $322 = Math_fround($320 * $310);
 $323 = Math_fround($320 * $311);
 $324 = Math_fround($320 * $306);
 HEAPF32[$157>>2] = $321;
 HEAPF32[$159>>2] = $322;
 HEAPF32[$161>>2] = $323;
 HEAPF32[$163>>2] = $324;
 $325 = Math_fround(HEAPF32[$183>>2]);
 $326 = Math_fround($325 * Math_fround(0.0));
 $327 = Math_fround(HEAPF32[$187>>2]);
 $328 = Math_fround($327 * Math_fround(0.0));
 $329 = Math_fround(HEAPF32[$185>>2]);
 $330 = Math_fround($329 * Math_fround(0.0));
 $331 = Math_fround(HEAPF32[$181>>2]);
 $332 = Math_fround($331 * Math_fround(0.0));
 $333 = Math_fround($326 - $327);
 $334 = Math_fround($328 - $332);
 $335 = Math_fround($330 - $325);
 $336 = Math_fround($331 - $330);
 $337 = Math_fround($333 - $330);
 $338 = Math_fround($334 - $329);
 $339 = Math_fround($335 - $328);
 $340 = Math_fround($336 - $328);
 $341 = Math_fround($337 - $332);
 $342 = Math_fround($338 - $326);
 $343 = Math_fround($339 - $332);
 $344 = Math_fround($340 - $326);
 $345 = Math_fround($343 * Math_fround(-1.0));
 $346 = Math_fround($344 * Math_fround(-1.0));
 $347 = Math_fround($341 * Math_fround(-1.0));
 $348 = Math_fround($345 * $345);
 $349 = Math_fround($346 * $346);
 $350 = Math_fround($347 * $347);
 $351 = Math_fround($342 * $342);
 $352 = Math_fround($348 + $349);
 $353 = Math_fround($350 + $351);
 $354 = Math_fround($352 + $353);
 $355 = (Math_fround(Math_sqrt((Math_fround($354)))));
 $356 = Math_fround(Math_fround(1.0) / $355);
 $357 = Math_fround($356 * $345);
 $358 = Math_fround($356 * $346);
 $359 = Math_fround($356 * $347);
 $360 = Math_fround($356 * $342);
 HEAPF32[$181>>2] = $357;
 HEAPF32[$183>>2] = $358;
 HEAPF32[$185>>2] = $359;
 HEAPF32[$187>>2] = $360;
 $361 = Math_fround(HEAPF32[$arPose>>2]);
 $362 = (($arPose) + 20|0);
 $363 = Math_fround(HEAPF32[$362>>2]);
 $364 = (($arPose) + 24|0);
 $365 = Math_fround(HEAPF32[$364>>2]);
 $366 = Math_fround($361 * Math_fround(-1.0));
 $367 = Math_fround($363 * Math_fround(-1.0));
 $368 = Math_fround($365 * Math_fround(-1.0));
 HEAPF32[$arPose>>2] = $366;
 HEAPF32[$362>>2] = $367;
 HEAPF32[$364>>2] = $368;
 $i$545 = 0;
 while(1) {
  $369 = ((($arPose) + ($i$545<<2)|0) + 432|0);
  $370 = Math_fround(HEAPF32[$369>>2]);
  $371 = ((($arPose) + ($i$545<<2)|0) + 576|0);
  $372 = Math_fround(HEAPF32[$371>>2]);
  HEAPF32[$369>>2] = $372;
  HEAPF32[$371>>2] = $370;
  $373 = (($i$545) + 1)|0;
  $exitcond = ($373|0)==(20);
  if ($exitcond) {
   break;
  } else {
   $i$545 = $373;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim5human14HumanPoseBlendERNS0_9HumanPoseEPPS1_Pfj($arPose,$apPoseArray,$apWeightArray,$aCount) {
 $arPose = $arPose|0;
 $apPoseArray = $apPoseArray|0;
 $apWeightArray = $apWeightArray|0;
 $aCount = $aCount|0;
 var $$phi$trans$insert114 = 0, $$phi$trans$insert119 = 0, $$phi$trans$insert125 = 0, $$pre = Math_fround(0), $$pre$phi132Z2D = 0, $$pre$phi136Z2D = 0, $$pre$phi140Z2D = 0, $$pre115 = Math_fround(0), $$pre116 = Math_fround(0), $$pre117 = Math_fround(0), $$pre120 = Math_fround(0), $$pre121 = Math_fround(0), $$pre122 = Math_fround(0), $$pre123 = Math_fround(0), $$pre126 = Math_fround(0), $$pre127 = Math_fround(0), $$pre128 = Math_fround(0), $$pre129 = Math_fround(0), $$pre131 = 0, $$pre135 = 0;
 var $$pre139 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0;
 var $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0;
 var $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0);
 var $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0;
 var $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0);
 var $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0);
 var $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0);
 var $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0;
 var $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $exitcond = 0, $exitcond105 = 0, $exitcond106 = 0, $exitcond107 = 0, $i$394 = 0, $i$496 = 0, $i$598 = 0, $phitmp = Math_fround(0);
 var $phitmp141 = Math_fround(0), $phitmp142 = Math_fround(0), $phitmp143 = Math_fround(0), $phitmp144 = Math_fround(0), $phitmp145 = Math_fround(0), $phitmp146 = Math_fround(0), $phitmp147 = Math_fround(0), $phitmp148 = Math_fround(0), $poseIter$0100 = 0, $scevgep = 0, $sumW$0$lcssa = Math_fround(0), $sumW$099 = Math_fround(0), dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $scevgep = (($arPose) + 672|0);
 _memset(($scevgep|0),0,208)|0;
 $0 = (($arPose) + 432|0);
 $1 = (($arPose) + 576|0);
 $2 = (($arPose) + 80|0);
 $3 = (($arPose) + 100|0);
 $4 = (($arPose) + 104|0);
 $5 = (($arPose) + 108|0);
 $6 = (($arPose) + 156|0);
 $7 = (($arPose) + 176|0);
 $8 = (($arPose) + 180|0);
 $9 = (($arPose) + 184|0);
 $10 = (($arPose) + 232|0);
 $11 = (($arPose) + 252|0);
 $12 = (($arPose) + 256|0);
 $13 = (($arPose) + 260|0);
 $14 = (($arPose) + 308|0);
 $15 = (($arPose) + 328|0);
 $16 = (($arPose) + 332|0);
 $17 = (($arPose) + 336|0);
 $18 = (($arPose) + 4|0);
 $19 = (($arPose) + 8|0);
 $20 = (($arPose) + 12|0);
 $21 = (($arPose) + 16|0);
 $22 = (($arPose) + 20|0);
 $23 = (($arPose) + 24|0);
 $24 = (($arPose) + 28|0);
 $25 = (($arPose) + 32|0);
 $26 = (($arPose) + 36|0);
 $27 = (($arPose) + 40|0);
 $28 = (($arPose) + 44|0);
 $29 = ($aCount|0)==(0);
 dest=$arPose+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$2+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$6+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$10+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$14+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$0+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 dest=$1+0|0; stop=dest+80|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 if ($29) {
  $$pre131 = (($arPose) + 172|0);
  $$pre135 = (($arPose) + 248|0);
  $$pre139 = (($arPose) + 324|0);
  $$pre$phi132Z2D = $$pre131;$$pre$phi136Z2D = $$pre135;$$pre$phi140Z2D = $$pre139;$257 = Math_fround(0.0);$259 = Math_fround(0.0);$261 = Math_fround(0.0);$263 = Math_fround(0.0);$275 = Math_fround(0.0);$277 = Math_fround(0.0);$279 = Math_fround(0.0);$281 = Math_fround(0.0);$293 = Math_fround(0.0);$295 = Math_fround(0.0);$297 = Math_fround(0.0);$299 = Math_fround(0.0);$sumW$0$lcssa = Math_fround(0.0);
 } else {
  $poseIter$0100 = 0;$sumW$099 = Math_fround(0.0);
  while(1) {
   $30 = (($apWeightArray) + ($poseIter$0100<<2)|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = (($apPoseArray) + ($poseIter$0100<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $i$394 = 0;
   while(1) {
    $34 = ((($33) + ($i$394<<2)|0) + 672|0);
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = Math_fround($31 * $35);
    $37 = ((($arPose) + ($i$394<<2)|0) + 672|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = Math_fround($38 + $36);
    HEAPF32[$37>>2] = $39;
    $40 = (($i$394) + 1)|0;
    $exitcond = ($40|0)==(52);
    if ($exitcond) {
     $i$496 = 0;
     break;
    } else {
     $i$394 = $40;
    }
   }
   while(1) {
    $41 = ((($33) + ($i$496<<2)|0) + 432|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = Math_fround($31 * $42);
    $44 = ((($arPose) + ($i$496<<2)|0) + 432|0);
    $45 = Math_fround(HEAPF32[$44>>2]);
    $46 = Math_fround($45 + $43);
    HEAPF32[$44>>2] = $46;
    $47 = ((($33) + ($i$496<<2)|0) + 576|0);
    $48 = Math_fround(HEAPF32[$47>>2]);
    $49 = Math_fround($31 * $48);
    $50 = ((($arPose) + ($i$496<<2)|0) + 576|0);
    $51 = Math_fround(HEAPF32[$50>>2]);
    $52 = Math_fround($51 + $49);
    HEAPF32[$50>>2] = $52;
    $53 = (($i$496) + 1)|0;
    $exitcond105 = ($53|0)==(20);
    if ($exitcond105) {
     $i$598 = 0;
     break;
    } else {
     $i$496 = $53;
    }
   }
   while(1) {
    $54 = ((($33) + (($i$598*76)|0)|0) + 80|0);
    $55 = Math_fround(HEAPF32[$54>>2]);
    $56 = Math_fround($31 * $55);
    $57 = ((($33) + (($i$598*76)|0)|0) + 84|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($31 * $58);
    $60 = ((($33) + (($i$598*76)|0)|0) + 88|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = Math_fround($31 * $61);
    $63 = ((($33) + (($i$598*76)|0)|0) + 92|0);
    $64 = Math_fround(HEAPF32[$63>>2]);
    $65 = Math_fround($31 * $64);
    $66 = ((($arPose) + (($i$598*76)|0)|0) + 80|0);
    $67 = Math_fround(HEAPF32[$66>>2]);
    $68 = Math_fround($56 + $67);
    $69 = ((($arPose) + (($i$598*76)|0)|0) + 84|0);
    $70 = Math_fround(HEAPF32[$69>>2]);
    $71 = Math_fround($59 + $70);
    $72 = ((($arPose) + (($i$598*76)|0)|0) + 88|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = Math_fround($62 + $73);
    $75 = ((($arPose) + (($i$598*76)|0)|0) + 92|0);
    $76 = Math_fround(HEAPF32[$75>>2]);
    $77 = Math_fround($65 + $76);
    HEAPF32[$66>>2] = $68;
    HEAPF32[$69>>2] = $71;
    HEAPF32[$72>>2] = $74;
    HEAPF32[$75>>2] = $77;
    $78 = ((($33) + (($i$598*76)|0)|0) + 96|0);
    $79 = Math_fround(HEAPF32[$78>>2]);
    $80 = Math_fround($31 * $79);
    $81 = ((($33) + (($i$598*76)|0)|0) + 100|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround($31 * $82);
    $84 = ((($33) + (($i$598*76)|0)|0) + 104|0);
    $85 = Math_fround(HEAPF32[$84>>2]);
    $86 = Math_fround($31 * $85);
    $87 = ((($33) + (($i$598*76)|0)|0) + 108|0);
    $88 = Math_fround(HEAPF32[$87>>2]);
    $89 = Math_fround($31 * $88);
    $90 = ((($arPose) + (($i$598*76)|0)|0) + 96|0);
    $91 = Math_fround(HEAPF32[$90>>2]);
    $92 = Math_fround($91 * $79);
    $93 = ((($arPose) + (($i$598*76)|0)|0) + 100|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $95 = Math_fround($94 * $82);
    $96 = ((($arPose) + (($i$598*76)|0)|0) + 104|0);
    $97 = Math_fround(HEAPF32[$96>>2]);
    $98 = Math_fround($97 * $85);
    $99 = ((($arPose) + (($i$598*76)|0)|0) + 108|0);
    $100 = Math_fround(HEAPF32[$99>>2]);
    $101 = Math_fround($100 * $88);
    $102 = Math_fround($92 + $95);
    $103 = Math_fround($98 + $101);
    $104 = Math_fround($102 + $103);
    $105 = (HEAPF32[tempDoublePtr>>2]=$80,HEAP32[tempDoublePtr>>2]|0);
    $106 = (HEAPF32[tempDoublePtr>>2]=$104,HEAP32[tempDoublePtr>>2]|0);
    $107 = $106 & -2147483648;
    $108 = $107 ^ $105;
    $109 = (HEAP32[tempDoublePtr>>2]=$108,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $110 = (HEAPF32[tempDoublePtr>>2]=$83,HEAP32[tempDoublePtr>>2]|0);
    $111 = $107 ^ $110;
    $112 = (HEAP32[tempDoublePtr>>2]=$111,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $113 = (HEAPF32[tempDoublePtr>>2]=$86,HEAP32[tempDoublePtr>>2]|0);
    $114 = $107 ^ $113;
    $115 = (HEAP32[tempDoublePtr>>2]=$114,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $116 = (HEAPF32[tempDoublePtr>>2]=$89,HEAP32[tempDoublePtr>>2]|0);
    $117 = $107 ^ $116;
    $118 = (HEAP32[tempDoublePtr>>2]=$117,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $119 = Math_fround($91 + $109);
    $120 = Math_fround($94 + $112);
    $121 = Math_fround($97 + $115);
    $122 = Math_fround($100 + $118);
    HEAPF32[$90>>2] = $119;
    HEAPF32[$93>>2] = $120;
    HEAPF32[$96>>2] = $121;
    HEAPF32[$99>>2] = $122;
    $123 = ((($33) + (($i$598*76)|0)|0) + 112|0);
    $124 = Math_fround(HEAPF32[$123>>2]);
    $125 = Math_fround($31 * $124);
    $126 = ((($33) + (($i$598*76)|0)|0) + 116|0);
    $127 = Math_fround(HEAPF32[$126>>2]);
    $128 = Math_fround($31 * $127);
    $129 = ((($33) + (($i$598*76)|0)|0) + 120|0);
    $130 = Math_fround(HEAPF32[$129>>2]);
    $131 = Math_fround($31 * $130);
    $132 = ((($33) + (($i$598*76)|0)|0) + 124|0);
    $133 = Math_fround(HEAPF32[$132>>2]);
    $134 = Math_fround($31 * $133);
    $135 = ((($arPose) + (($i$598*76)|0)|0) + 112|0);
    $136 = Math_fround(HEAPF32[$135>>2]);
    $137 = Math_fround($125 + $136);
    $138 = ((($arPose) + (($i$598*76)|0)|0) + 116|0);
    $139 = Math_fround(HEAPF32[$138>>2]);
    $140 = Math_fround($128 + $139);
    $141 = ((($arPose) + (($i$598*76)|0)|0) + 120|0);
    $142 = Math_fround(HEAPF32[$141>>2]);
    $143 = Math_fround($131 + $142);
    $144 = ((($arPose) + (($i$598*76)|0)|0) + 124|0);
    $145 = Math_fround(HEAPF32[$144>>2]);
    $146 = Math_fround($134 + $145);
    HEAPF32[$135>>2] = $137;
    HEAPF32[$138>>2] = $140;
    HEAPF32[$141>>2] = $143;
    HEAPF32[$144>>2] = $146;
    $147 = (($i$598) + 1)|0;
    $exitcond106 = ($147|0)==(4);
    if ($exitcond106) {
     break;
    } else {
     $i$598 = $147;
    }
   }
   $148 = Math_fround($sumW$099 + $31);
   $149 = Math_fround(HEAPF32[$33>>2]);
   $150 = Math_fround($31 * $149);
   $151 = (($33) + 4|0);
   $152 = Math_fround(HEAPF32[$151>>2]);
   $153 = Math_fround($31 * $152);
   $154 = (($33) + 8|0);
   $155 = Math_fround(HEAPF32[$154>>2]);
   $156 = Math_fround($31 * $155);
   $157 = (($33) + 12|0);
   $158 = Math_fround(HEAPF32[$157>>2]);
   $159 = Math_fround($31 * $158);
   $160 = Math_fround(HEAPF32[$arPose>>2]);
   $161 = Math_fround($150 + $160);
   $162 = Math_fround(HEAPF32[$18>>2]);
   $163 = Math_fround($153 + $162);
   $164 = Math_fround(HEAPF32[$19>>2]);
   $165 = Math_fround($156 + $164);
   $166 = Math_fround(HEAPF32[$20>>2]);
   $167 = Math_fround($159 + $166);
   HEAPF32[$arPose>>2] = $161;
   HEAPF32[$18>>2] = $163;
   HEAPF32[$19>>2] = $165;
   HEAPF32[$20>>2] = $167;
   $168 = HEAP32[$32>>2]|0;
   $169 = (($168) + 16|0);
   $170 = Math_fround(HEAPF32[$169>>2]);
   $171 = Math_fround($31 * $170);
   $172 = (($168) + 20|0);
   $173 = Math_fround(HEAPF32[$172>>2]);
   $174 = Math_fround($31 * $173);
   $175 = (($168) + 24|0);
   $176 = Math_fround(HEAPF32[$175>>2]);
   $177 = Math_fround($31 * $176);
   $178 = (($168) + 28|0);
   $179 = Math_fround(HEAPF32[$178>>2]);
   $180 = Math_fround($31 * $179);
   $181 = Math_fround(HEAPF32[$21>>2]);
   $182 = Math_fround($181 * $170);
   $183 = Math_fround(HEAPF32[$22>>2]);
   $184 = Math_fround($183 * $173);
   $185 = Math_fround(HEAPF32[$23>>2]);
   $186 = Math_fround($185 * $176);
   $187 = Math_fround(HEAPF32[$24>>2]);
   $188 = Math_fround($187 * $179);
   $189 = Math_fround($182 + $184);
   $190 = Math_fround($186 + $188);
   $191 = Math_fround($189 + $190);
   $192 = (HEAPF32[tempDoublePtr>>2]=$171,HEAP32[tempDoublePtr>>2]|0);
   $193 = (HEAPF32[tempDoublePtr>>2]=$191,HEAP32[tempDoublePtr>>2]|0);
   $194 = $193 & -2147483648;
   $195 = $194 ^ $192;
   $196 = (HEAP32[tempDoublePtr>>2]=$195,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $197 = (HEAPF32[tempDoublePtr>>2]=$174,HEAP32[tempDoublePtr>>2]|0);
   $198 = $194 ^ $197;
   $199 = (HEAP32[tempDoublePtr>>2]=$198,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $200 = (HEAPF32[tempDoublePtr>>2]=$177,HEAP32[tempDoublePtr>>2]|0);
   $201 = $194 ^ $200;
   $202 = (HEAP32[tempDoublePtr>>2]=$201,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $203 = (HEAPF32[tempDoublePtr>>2]=$180,HEAP32[tempDoublePtr>>2]|0);
   $204 = $194 ^ $203;
   $205 = (HEAP32[tempDoublePtr>>2]=$204,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $206 = Math_fround($181 + $196);
   $207 = Math_fround($183 + $199);
   $208 = Math_fround($185 + $202);
   $209 = Math_fround($187 + $205);
   HEAPF32[$21>>2] = $206;
   HEAPF32[$22>>2] = $207;
   HEAPF32[$23>>2] = $208;
   HEAPF32[$24>>2] = $209;
   $210 = (($168) + 32|0);
   $211 = Math_fround(HEAPF32[$210>>2]);
   $212 = Math_fround($31 * $211);
   $213 = (($168) + 36|0);
   $214 = Math_fround(HEAPF32[$213>>2]);
   $215 = Math_fround($31 * $214);
   $216 = (($168) + 40|0);
   $217 = Math_fround(HEAPF32[$216>>2]);
   $218 = Math_fround($31 * $217);
   $219 = (($168) + 44|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = Math_fround($31 * $220);
   $222 = Math_fround(HEAPF32[$25>>2]);
   $223 = Math_fround($212 + $222);
   $224 = Math_fround(HEAPF32[$26>>2]);
   $225 = Math_fround($215 + $224);
   $226 = Math_fround(HEAPF32[$27>>2]);
   $227 = Math_fround($218 + $226);
   $228 = Math_fround(HEAPF32[$28>>2]);
   $229 = Math_fround($221 + $228);
   HEAPF32[$25>>2] = $223;
   HEAPF32[$26>>2] = $225;
   HEAPF32[$27>>2] = $227;
   HEAPF32[$28>>2] = $229;
   $230 = (($poseIter$0100) + 1)|0;
   $exitcond107 = ($230|0)==($aCount|0);
   if ($exitcond107) {
    break;
   } else {
    $poseIter$0100 = $230;$sumW$099 = $148;
   }
  }
  $$phi$trans$insert114 = (($arPose) + 172|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert114>>2]);
  $$pre115 = Math_fround(HEAPF32[$7>>2]);
  $$pre116 = Math_fround(HEAPF32[$8>>2]);
  $$pre117 = Math_fround(HEAPF32[$9>>2]);
  $$phi$trans$insert119 = (($arPose) + 248|0);
  $$pre120 = Math_fround(HEAPF32[$$phi$trans$insert119>>2]);
  $$pre121 = Math_fround(HEAPF32[$11>>2]);
  $$pre122 = Math_fround(HEAPF32[$12>>2]);
  $$pre123 = Math_fround(HEAPF32[$13>>2]);
  $$phi$trans$insert125 = (($arPose) + 324|0);
  $$pre126 = Math_fround(HEAPF32[$$phi$trans$insert125>>2]);
  $$pre127 = Math_fround(HEAPF32[$15>>2]);
  $$pre128 = Math_fround(HEAPF32[$16>>2]);
  $$pre129 = Math_fround(HEAPF32[$17>>2]);
  $phitmp = Math_fround($$pre + Math_fround(0.0));
  $phitmp141 = Math_fround($$pre115 + Math_fround(0.0));
  $phitmp142 = Math_fround($$pre116 + Math_fround(0.0));
  $phitmp143 = Math_fround($$pre120 + Math_fround(0.0));
  $phitmp144 = Math_fround($$pre121 + Math_fround(0.0));
  $phitmp145 = Math_fround($$pre122 + Math_fround(0.0));
  $phitmp146 = Math_fround($$pre126 + Math_fround(0.0));
  $phitmp147 = Math_fround($$pre127 + Math_fround(0.0));
  $phitmp148 = Math_fround($$pre128 + Math_fround(0.0));
  $$pre$phi132Z2D = $$phi$trans$insert114;$$pre$phi136Z2D = $$phi$trans$insert119;$$pre$phi140Z2D = $$phi$trans$insert125;$257 = $$pre117;$259 = $phitmp;$261 = $phitmp141;$263 = $phitmp142;$275 = $$pre123;$277 = $phitmp143;$279 = $phitmp144;$281 = $phitmp145;$293 = $$pre129;$295 = $phitmp146;$297 = $phitmp147;$299 = $phitmp148;$sumW$0$lcssa = $148;
 }
 $231 = Math_fround(Math_fround(1.0) - $sumW$0$lcssa);
 $232 = (Math_fround(+(_fmaxf(0.0,(+$231)))));
 $233 = (Math_fround(+(_fminf(1.0,(+$232)))));
 $234 = (($arPose) + 96|0);
 $235 = Math_fround(HEAPF32[$234>>2]);
 $236 = Math_fround($235 + Math_fround(0.0));
 $237 = Math_fround(HEAPF32[$3>>2]);
 $238 = Math_fround($237 + Math_fround(0.0));
 $239 = Math_fround(HEAPF32[$4>>2]);
 $240 = Math_fround($239 + Math_fround(0.0));
 $241 = Math_fround(HEAPF32[$5>>2]);
 $242 = Math_fround($233 + $241);
 $243 = Math_fround($236 * $236);
 $244 = Math_fround($238 * $238);
 $245 = Math_fround($240 * $240);
 $246 = Math_fround($242 * $242);
 $247 = Math_fround($243 + $244);
 $248 = Math_fround($245 + $246);
 $249 = Math_fround($247 + $248);
 $250 = (Math_fround(Math_sqrt((Math_fround($249)))));
 $251 = Math_fround(Math_fround(1.0) / $250);
 $252 = Math_fround($236 * $251);
 $253 = Math_fround($238 * $251);
 $254 = Math_fround($240 * $251);
 $255 = Math_fround($242 * $251);
 HEAPF32[$234>>2] = $252;
 HEAPF32[$3>>2] = $253;
 HEAPF32[$4>>2] = $254;
 HEAPF32[$5>>2] = $255;
 $256 = Math_fround($233 + $257);
 $258 = Math_fround($259 * $259);
 $260 = Math_fround($261 * $261);
 $262 = Math_fround($263 * $263);
 $264 = Math_fround($256 * $256);
 $265 = Math_fround($258 + $260);
 $266 = Math_fround($262 + $264);
 $267 = Math_fround($265 + $266);
 $268 = (Math_fround(Math_sqrt((Math_fround($267)))));
 $269 = Math_fround(Math_fround(1.0) / $268);
 $270 = Math_fround($259 * $269);
 $271 = Math_fround($261 * $269);
 $272 = Math_fround($263 * $269);
 $273 = Math_fround($256 * $269);
 HEAPF32[$$pre$phi132Z2D>>2] = $270;
 HEAPF32[$7>>2] = $271;
 HEAPF32[$8>>2] = $272;
 HEAPF32[$9>>2] = $273;
 $274 = Math_fround($233 + $275);
 $276 = Math_fround($277 * $277);
 $278 = Math_fround($279 * $279);
 $280 = Math_fround($281 * $281);
 $282 = Math_fround($274 * $274);
 $283 = Math_fround($276 + $278);
 $284 = Math_fround($280 + $282);
 $285 = Math_fround($283 + $284);
 $286 = (Math_fround(Math_sqrt((Math_fround($285)))));
 $287 = Math_fround(Math_fround(1.0) / $286);
 $288 = Math_fround($277 * $287);
 $289 = Math_fround($279 * $287);
 $290 = Math_fround($281 * $287);
 $291 = Math_fround($274 * $287);
 HEAPF32[$$pre$phi136Z2D>>2] = $288;
 HEAPF32[$11>>2] = $289;
 HEAPF32[$12>>2] = $290;
 HEAPF32[$13>>2] = $291;
 $292 = Math_fround($233 + $293);
 $294 = Math_fround($295 * $295);
 $296 = Math_fround($297 * $297);
 $298 = Math_fround($299 * $299);
 $300 = Math_fround($292 * $292);
 $301 = Math_fround($294 + $296);
 $302 = Math_fround($298 + $300);
 $303 = Math_fround($301 + $302);
 $304 = (Math_fround(Math_sqrt((Math_fround($303)))));
 $305 = Math_fround(Math_fround(1.0) / $304);
 $306 = Math_fround($295 * $305);
 $307 = Math_fround($297 * $305);
 $308 = Math_fround($299 * $305);
 $309 = Math_fround($292 * $305);
 HEAPF32[$$pre$phi140Z2D>>2] = $306;
 HEAPF32[$15>>2] = $307;
 HEAPF32[$16>>2] = $308;
 HEAPF32[$17>>2] = $309;
 $310 = Math_fround(HEAPF32[$21>>2]);
 $311 = Math_fround($310 + Math_fround(0.0));
 $312 = Math_fround(HEAPF32[$22>>2]);
 $313 = Math_fround($312 + Math_fround(0.0));
 $314 = Math_fround(HEAPF32[$23>>2]);
 $315 = Math_fround($314 + Math_fround(0.0));
 $316 = Math_fround(HEAPF32[$24>>2]);
 $317 = Math_fround($233 + $316);
 $318 = Math_fround($311 * $311);
 $319 = Math_fround($313 * $313);
 $320 = Math_fround($315 * $315);
 $321 = Math_fround($317 * $317);
 $322 = Math_fround($318 + $319);
 $323 = Math_fround($320 + $321);
 $324 = Math_fround($322 + $323);
 $325 = (Math_fround(Math_sqrt((Math_fround($324)))));
 $326 = Math_fround(Math_fround(1.0) / $325);
 $327 = Math_fround($311 * $326);
 $328 = Math_fround($313 * $326);
 $329 = Math_fround($315 * $326);
 $330 = Math_fround($317 * $326);
 HEAPF32[$21>>2] = $327;
 HEAPF32[$22>>2] = $328;
 HEAPF32[$23>>2] = $329;
 HEAPF32[$24>>2] = $330;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human25HumanPoseAddOverrideLayerERNS0_9HumanPoseERKS1_fRKNS_6bitsetILj59EEE($arPoseBase,$arPose,$aWeight,$arHumanPoseMask) {
 $arPoseBase = $arPoseBase|0;
 $arPose = $arPose|0;
 $aWeight = Math_fround($aWeight);
 $arHumanPoseMask = $arHumanPoseMask|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0;
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0);
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = Math_fround(0), $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = 0;
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = Math_fround(0), $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = Math_fround(0), $283 = 0, $284 = 0, $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0);
 var $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = 0, $322 = Math_fround(0), $323 = Math_fround(0), $324 = 0, $325 = Math_fround(0), $326 = 0, $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0;
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0, $347 = Math_fround(0), $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = 0, $356 = Math_fround(0), $357 = 0, $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0);
 var $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0;
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), $exitcond = 0, $exitcond34 = 0, $exitcond35 = 0, $exitcond36 = 0, $exitcond37 = 0;
 var $exitcond38 = 0, $exitcond39 = 0, $i$033 = 0, $i$132 = 0, $i$132$us = 0, $i$230 = 0, $i$230$us = 0, $i$328 = 0, $i$328$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $aWeight > Math_fround(0.0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = Math_fround(Math_fround(1.0) - $aWeight);
 $2 = $aWeight < Math_fround(1.0);
 $i$033 = 0;
 while(1) {
  $3 = (($i$033) + 1)|0;
  $4 = $3 >>> 5;
  $5 = (($arHumanPoseMask) + ($4<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $3 & 31;
  $8 = 1 << $7;
  $9 = $6 & $8;
  $10 = ($9|0)==(0);
  do {
   if (!($10)) {
    if ($2) {
     $11 = ((($arPoseBase) + ($i$033<<2)|0) + 672|0);
     $12 = Math_fround(HEAPF32[$11>>2]);
     $13 = Math_fround($1 * $12);
     $14 = ((($arPose) + ($i$033<<2)|0) + 672|0);
     $15 = Math_fround(HEAPF32[$14>>2]);
     $16 = Math_fround($15 * $aWeight);
     $17 = Math_fround($13 + $16);
     HEAPF32[$11>>2] = $17;
     break;
    } else {
     $18 = ((($arPose) + ($i$033<<2)|0) + 672|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = ((($arPoseBase) + ($i$033<<2)|0) + 672|0);
     HEAPF32[$20>>2] = $19;
     break;
    }
   }
  } while(0);
  $exitcond36 = ($3|0)==(52);
  if ($exitcond36) {
   break;
  } else {
   $i$033 = $3;
  }
 }
 $21 = (($arHumanPoseMask) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 & 33554432;
 $24 = ($23|0)==(0);
 if (!($24)) {
  if ($2) {
   $i$132$us = 0;
   while(1) {
    $25 = ((($arPoseBase) + ($i$132$us<<2)|0) + 432|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = Math_fround($1 * $26);
    $28 = ((($arPose) + ($i$132$us<<2)|0) + 432|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = Math_fround($29 * $aWeight);
    $31 = Math_fround($27 + $30);
    HEAPF32[$25>>2] = $31;
    $32 = (($i$132$us) + 1)|0;
    $exitcond39 = ($32|0)==(20);
    if ($exitcond39) {
     break;
    } else {
     $i$132$us = $32;
    }
   }
  } else {
   $i$132 = 0;
   while(1) {
    $33 = ((($arPose) + ($i$132<<2)|0) + 432|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = ((($arPoseBase) + ($i$132<<2)|0) + 432|0);
    HEAPF32[$35>>2] = $34;
    $36 = (($i$132) + 1)|0;
    $exitcond35 = ($36|0)==(20);
    if ($exitcond35) {
     break;
    } else {
     $i$132 = $36;
    }
   }
  }
 }
 $37 = $22 & 67108864;
 $38 = ($37|0)==(0);
 if (!($38)) {
  if ($2) {
   $i$230$us = 0;
   while(1) {
    $39 = ((($arPoseBase) + ($i$230$us<<2)|0) + 576|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    $41 = Math_fround($1 * $40);
    $42 = ((($arPose) + ($i$230$us<<2)|0) + 576|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = Math_fround($43 * $aWeight);
    $45 = Math_fround($41 + $44);
    HEAPF32[$39>>2] = $45;
    $46 = (($i$230$us) + 1)|0;
    $exitcond38 = ($46|0)==(20);
    if ($exitcond38) {
     break;
    } else {
     $i$230$us = $46;
    }
   }
  } else {
   $i$230 = 0;
   while(1) {
    $174 = ((($arPose) + ($i$230<<2)|0) + 576|0);
    $175 = Math_fround(HEAPF32[$174>>2]);
    $176 = ((($arPoseBase) + ($i$230<<2)|0) + 576|0);
    HEAPF32[$176>>2] = $175;
    $177 = (($i$230) + 1)|0;
    $exitcond34 = ($177|0)==(20);
    if ($exitcond34) {
     break;
    } else {
     $i$230 = $177;
    }
   }
  }
 }
 if ($2) {
  $i$328$us = 0;
  while(1) {
   $47 = (($i$328$us) + 53)|0;
   $48 = $47 >>> 5;
   $49 = (($arHumanPoseMask) + ($48<<2)|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = $47 & 31;
   $52 = 1 << $51;
   $53 = $50 & $52;
   $54 = ($53|0)==(0);
   if (!($54)) {
    $55 = ((($arPose) + (($i$328$us*76)|0)|0) + 80|0);
    $56 = Math_fround(HEAPF32[$55>>2]);
    $57 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 80|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($56 - $58);
    $60 = ((($arPose) + (($i$328$us*76)|0)|0) + 84|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 84|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    $64 = Math_fround($61 - $63);
    $65 = ((($arPose) + (($i$328$us*76)|0)|0) + 88|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 88|0);
    $68 = Math_fround(HEAPF32[$67>>2]);
    $69 = Math_fround($66 - $68);
    $70 = ((($arPose) + (($i$328$us*76)|0)|0) + 92|0);
    $71 = Math_fround(HEAPF32[$70>>2]);
    $72 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 92|0);
    $73 = Math_fround(HEAPF32[$72>>2]);
    $74 = Math_fround($71 - $73);
    $75 = Math_fround($59 * $aWeight);
    $76 = Math_fround($64 * $aWeight);
    $77 = Math_fround($69 * $aWeight);
    $78 = Math_fround($74 * $aWeight);
    $79 = Math_fround($58 + $75);
    $80 = Math_fround($63 + $76);
    $81 = Math_fround($68 + $77);
    $82 = Math_fround($73 + $78);
    $83 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 96|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = ((($arPose) + (($i$328$us*76)|0)|0) + 96|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $87 = Math_fround($84 * $86);
    $88 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 100|0);
    $89 = Math_fround(HEAPF32[$88>>2]);
    $90 = ((($arPose) + (($i$328$us*76)|0)|0) + 100|0);
    $91 = Math_fround(HEAPF32[$90>>2]);
    $92 = Math_fround($89 * $91);
    $93 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 104|0);
    $94 = Math_fround(HEAPF32[$93>>2]);
    $95 = ((($arPose) + (($i$328$us*76)|0)|0) + 104|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $97 = Math_fround($94 * $96);
    $98 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 108|0);
    $99 = Math_fround(HEAPF32[$98>>2]);
    $100 = ((($arPose) + (($i$328$us*76)|0)|0) + 108|0);
    $101 = Math_fround(HEAPF32[$100>>2]);
    $102 = Math_fround($99 * $101);
    $103 = Math_fround($87 + $92);
    $104 = Math_fround($97 + $102);
    $105 = Math_fround($103 + $104);
    $106 = (HEAPF32[tempDoublePtr>>2]=$86,HEAP32[tempDoublePtr>>2]|0);
    $107 = (HEAPF32[tempDoublePtr>>2]=$105,HEAP32[tempDoublePtr>>2]|0);
    $108 = $107 & -2147483648;
    $109 = $108 ^ $106;
    $110 = (HEAP32[tempDoublePtr>>2]=$109,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $111 = (HEAPF32[tempDoublePtr>>2]=$91,HEAP32[tempDoublePtr>>2]|0);
    $112 = $108 ^ $111;
    $113 = (HEAP32[tempDoublePtr>>2]=$112,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $114 = (HEAPF32[tempDoublePtr>>2]=$96,HEAP32[tempDoublePtr>>2]|0);
    $115 = $108 ^ $114;
    $116 = (HEAP32[tempDoublePtr>>2]=$115,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $117 = (HEAPF32[tempDoublePtr>>2]=$101,HEAP32[tempDoublePtr>>2]|0);
    $118 = $108 ^ $117;
    $119 = (HEAP32[tempDoublePtr>>2]=$118,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $120 = Math_fround($110 - $84);
    $121 = Math_fround($113 - $89);
    $122 = Math_fround($116 - $94);
    $123 = Math_fround($119 - $99);
    $124 = Math_fround($120 * $aWeight);
    $125 = Math_fround($121 * $aWeight);
    $126 = Math_fround($122 * $aWeight);
    $127 = Math_fround($123 * $aWeight);
    $128 = Math_fround($84 + $124);
    $129 = Math_fround($89 + $125);
    $130 = Math_fround($94 + $126);
    $131 = Math_fround($99 + $127);
    $132 = Math_fround($128 * $128);
    $133 = Math_fround($129 * $129);
    $134 = Math_fround($130 * $130);
    $135 = Math_fround($131 * $131);
    $136 = Math_fround($132 + $133);
    $137 = Math_fround($134 + $135);
    $138 = Math_fround($136 + $137);
    $139 = (Math_fround(Math_sqrt((Math_fround($138)))));
    $140 = Math_fround(Math_fround(1.0) / $139);
    $141 = Math_fround($140 * $128);
    $142 = Math_fround($140 * $129);
    $143 = Math_fround($140 * $130);
    $144 = Math_fround($140 * $131);
    $145 = ((($arPose) + (($i$328$us*76)|0)|0) + 112|0);
    $146 = Math_fround(HEAPF32[$145>>2]);
    $147 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 112|0);
    $148 = Math_fround(HEAPF32[$147>>2]);
    $149 = Math_fround($146 - $148);
    $150 = ((($arPose) + (($i$328$us*76)|0)|0) + 116|0);
    $151 = Math_fround(HEAPF32[$150>>2]);
    $152 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 116|0);
    $153 = Math_fround(HEAPF32[$152>>2]);
    $154 = Math_fround($151 - $153);
    $155 = ((($arPose) + (($i$328$us*76)|0)|0) + 120|0);
    $156 = Math_fround(HEAPF32[$155>>2]);
    $157 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 120|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = Math_fround($156 - $158);
    $160 = ((($arPose) + (($i$328$us*76)|0)|0) + 124|0);
    $161 = Math_fround(HEAPF32[$160>>2]);
    $162 = ((($arPoseBase) + (($i$328$us*76)|0)|0) + 124|0);
    $163 = Math_fround(HEAPF32[$162>>2]);
    $164 = Math_fround($161 - $163);
    $165 = Math_fround($149 * $aWeight);
    $166 = Math_fround($154 * $aWeight);
    $167 = Math_fround($159 * $aWeight);
    $168 = Math_fround($164 * $aWeight);
    $169 = Math_fround($148 + $165);
    $170 = Math_fround($153 + $166);
    $171 = Math_fround($158 + $167);
    $172 = Math_fround($163 + $168);
    HEAPF32[$57>>2] = $79;
    HEAPF32[$62>>2] = $80;
    HEAPF32[$67>>2] = $81;
    HEAPF32[$72>>2] = $82;
    HEAPF32[$83>>2] = $141;
    HEAPF32[$88>>2] = $142;
    HEAPF32[$93>>2] = $143;
    HEAPF32[$98>>2] = $144;
    HEAPF32[$147>>2] = $169;
    HEAPF32[$152>>2] = $170;
    HEAPF32[$157>>2] = $171;
    HEAPF32[$162>>2] = $172;
   }
   $173 = (($i$328$us) + 1)|0;
   $exitcond37 = ($173|0)==(4);
   if ($exitcond37) {
    break;
   } else {
    $i$328$us = $173;
   }
  }
 } else {
  $i$328 = 0;
  while(1) {
   $178 = (($i$328) + 53)|0;
   $179 = $178 >>> 5;
   $180 = (($arHumanPoseMask) + ($179<<2)|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = $178 & 31;
   $183 = 1 << $182;
   $184 = $181 & $183;
   $185 = ($184|0)==(0);
   if (!($185)) {
    $186 = ((($arPose) + (($i$328*76)|0)|0) + 80|0);
    $187 = Math_fround(HEAPF32[$186>>2]);
    $188 = ((($arPose) + (($i$328*76)|0)|0) + 84|0);
    $189 = Math_fround(HEAPF32[$188>>2]);
    $190 = ((($arPose) + (($i$328*76)|0)|0) + 88|0);
    $191 = Math_fround(HEAPF32[$190>>2]);
    $192 = ((($arPose) + (($i$328*76)|0)|0) + 92|0);
    $193 = Math_fround(HEAPF32[$192>>2]);
    $194 = ((($arPoseBase) + (($i$328*76)|0)|0) + 80|0);
    HEAPF32[$194>>2] = $187;
    $195 = ((($arPoseBase) + (($i$328*76)|0)|0) + 84|0);
    HEAPF32[$195>>2] = $189;
    $196 = ((($arPoseBase) + (($i$328*76)|0)|0) + 88|0);
    HEAPF32[$196>>2] = $191;
    $197 = ((($arPoseBase) + (($i$328*76)|0)|0) + 92|0);
    HEAPF32[$197>>2] = $193;
    $198 = ((($arPose) + (($i$328*76)|0)|0) + 96|0);
    $199 = Math_fround(HEAPF32[$198>>2]);
    $200 = ((($arPose) + (($i$328*76)|0)|0) + 100|0);
    $201 = Math_fround(HEAPF32[$200>>2]);
    $202 = ((($arPose) + (($i$328*76)|0)|0) + 104|0);
    $203 = Math_fround(HEAPF32[$202>>2]);
    $204 = ((($arPose) + (($i$328*76)|0)|0) + 108|0);
    $205 = Math_fround(HEAPF32[$204>>2]);
    $206 = ((($arPoseBase) + (($i$328*76)|0)|0) + 96|0);
    HEAPF32[$206>>2] = $199;
    $207 = ((($arPoseBase) + (($i$328*76)|0)|0) + 100|0);
    HEAPF32[$207>>2] = $201;
    $208 = ((($arPoseBase) + (($i$328*76)|0)|0) + 104|0);
    HEAPF32[$208>>2] = $203;
    $209 = ((($arPoseBase) + (($i$328*76)|0)|0) + 108|0);
    HEAPF32[$209>>2] = $205;
    $210 = ((($arPose) + (($i$328*76)|0)|0) + 112|0);
    $211 = Math_fround(HEAPF32[$210>>2]);
    $212 = ((($arPose) + (($i$328*76)|0)|0) + 116|0);
    $213 = Math_fround(HEAPF32[$212>>2]);
    $214 = ((($arPose) + (($i$328*76)|0)|0) + 120|0);
    $215 = Math_fround(HEAPF32[$214>>2]);
    $216 = ((($arPose) + (($i$328*76)|0)|0) + 124|0);
    $217 = Math_fround(HEAPF32[$216>>2]);
    $218 = ((($arPoseBase) + (($i$328*76)|0)|0) + 112|0);
    HEAPF32[$218>>2] = $211;
    $219 = ((($arPoseBase) + (($i$328*76)|0)|0) + 116|0);
    HEAPF32[$219>>2] = $213;
    $220 = ((($arPoseBase) + (($i$328*76)|0)|0) + 120|0);
    HEAPF32[$220>>2] = $215;
    $221 = ((($arPoseBase) + (($i$328*76)|0)|0) + 124|0);
    HEAPF32[$221>>2] = $217;
   }
   $222 = (($i$328) + 1)|0;
   $exitcond = ($222|0)==(4);
   if ($exitcond) {
    break;
   } else {
    $i$328 = $222;
   }
  }
 }
 $223 = HEAP32[$arHumanPoseMask>>2]|0;
 $224 = $223 & 1;
 $225 = ($224|0)==(0);
 if ($225) {
  STACKTOP = sp;return;
 }
 $226 = Math_fround(HEAPF32[$arPose>>2]);
 if ($2) {
  $227 = Math_fround(HEAPF32[$arPoseBase>>2]);
  $228 = Math_fround($226 - $227);
  $229 = (($arPose) + 4|0);
  $230 = Math_fround(HEAPF32[$229>>2]);
  $231 = (($arPoseBase) + 4|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = Math_fround($230 - $232);
  $234 = (($arPose) + 8|0);
  $235 = Math_fround(HEAPF32[$234>>2]);
  $236 = (($arPoseBase) + 8|0);
  $237 = Math_fround(HEAPF32[$236>>2]);
  $238 = Math_fround($235 - $237);
  $239 = (($arPose) + 12|0);
  $240 = Math_fround(HEAPF32[$239>>2]);
  $241 = (($arPoseBase) + 12|0);
  $242 = Math_fround(HEAPF32[$241>>2]);
  $243 = Math_fround($240 - $242);
  $244 = Math_fround($228 * $aWeight);
  $245 = Math_fround($233 * $aWeight);
  $246 = Math_fround($238 * $aWeight);
  $247 = Math_fround($243 * $aWeight);
  $248 = Math_fround($227 + $244);
  $249 = Math_fround($232 + $245);
  $250 = Math_fround($237 + $246);
  $251 = Math_fround($242 + $247);
  $252 = (($arPoseBase) + 16|0);
  $253 = Math_fround(HEAPF32[$252>>2]);
  $254 = (($arPose) + 16|0);
  $255 = Math_fround(HEAPF32[$254>>2]);
  $256 = Math_fround($253 * $255);
  $257 = (($arPoseBase) + 20|0);
  $258 = Math_fround(HEAPF32[$257>>2]);
  $259 = (($arPose) + 20|0);
  $260 = Math_fround(HEAPF32[$259>>2]);
  $261 = Math_fround($258 * $260);
  $262 = (($arPoseBase) + 24|0);
  $263 = Math_fround(HEAPF32[$262>>2]);
  $264 = (($arPose) + 24|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = Math_fround($263 * $265);
  $267 = (($arPoseBase) + 28|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = (($arPose) + 28|0);
  $270 = Math_fround(HEAPF32[$269>>2]);
  $271 = Math_fround($268 * $270);
  $272 = Math_fround($256 + $261);
  $273 = Math_fround($266 + $271);
  $274 = Math_fround($272 + $273);
  $275 = (HEAPF32[tempDoublePtr>>2]=$255,HEAP32[tempDoublePtr>>2]|0);
  $276 = (HEAPF32[tempDoublePtr>>2]=$274,HEAP32[tempDoublePtr>>2]|0);
  $277 = $276 & -2147483648;
  $278 = $277 ^ $275;
  $279 = (HEAP32[tempDoublePtr>>2]=$278,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $280 = (HEAPF32[tempDoublePtr>>2]=$260,HEAP32[tempDoublePtr>>2]|0);
  $281 = $277 ^ $280;
  $282 = (HEAP32[tempDoublePtr>>2]=$281,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $283 = (HEAPF32[tempDoublePtr>>2]=$265,HEAP32[tempDoublePtr>>2]|0);
  $284 = $277 ^ $283;
  $285 = (HEAP32[tempDoublePtr>>2]=$284,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $286 = (HEAPF32[tempDoublePtr>>2]=$270,HEAP32[tempDoublePtr>>2]|0);
  $287 = $277 ^ $286;
  $288 = (HEAP32[tempDoublePtr>>2]=$287,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $289 = Math_fround($279 - $253);
  $290 = Math_fround($282 - $258);
  $291 = Math_fround($285 - $263);
  $292 = Math_fround($288 - $268);
  $293 = Math_fround($289 * $aWeight);
  $294 = Math_fround($290 * $aWeight);
  $295 = Math_fround($291 * $aWeight);
  $296 = Math_fround($292 * $aWeight);
  $297 = Math_fround($253 + $293);
  $298 = Math_fround($258 + $294);
  $299 = Math_fround($263 + $295);
  $300 = Math_fround($268 + $296);
  $301 = Math_fround($297 * $297);
  $302 = Math_fround($298 * $298);
  $303 = Math_fround($299 * $299);
  $304 = Math_fround($300 * $300);
  $305 = Math_fround($301 + $302);
  $306 = Math_fround($303 + $304);
  $307 = Math_fround($305 + $306);
  $308 = (Math_fround(Math_sqrt((Math_fround($307)))));
  $309 = Math_fround(Math_fround(1.0) / $308);
  $310 = Math_fround($309 * $297);
  $311 = Math_fround($309 * $298);
  $312 = Math_fround($309 * $299);
  $313 = Math_fround($309 * $300);
  $314 = (($arPose) + 32|0);
  $315 = Math_fround(HEAPF32[$314>>2]);
  $316 = (($arPoseBase) + 32|0);
  $317 = Math_fround(HEAPF32[$316>>2]);
  $318 = Math_fround($315 - $317);
  $319 = (($arPose) + 36|0);
  $320 = Math_fround(HEAPF32[$319>>2]);
  $321 = (($arPoseBase) + 36|0);
  $322 = Math_fround(HEAPF32[$321>>2]);
  $323 = Math_fround($320 - $322);
  $324 = (($arPose) + 40|0);
  $325 = Math_fround(HEAPF32[$324>>2]);
  $326 = (($arPoseBase) + 40|0);
  $327 = Math_fround(HEAPF32[$326>>2]);
  $328 = Math_fround($325 - $327);
  $329 = (($arPose) + 44|0);
  $330 = Math_fround(HEAPF32[$329>>2]);
  $331 = (($arPoseBase) + 44|0);
  $332 = Math_fround(HEAPF32[$331>>2]);
  $333 = Math_fround($330 - $332);
  $334 = Math_fround($318 * $aWeight);
  $335 = Math_fround($323 * $aWeight);
  $336 = Math_fround($328 * $aWeight);
  $337 = Math_fround($333 * $aWeight);
  $338 = Math_fround($317 + $334);
  $339 = Math_fround($322 + $335);
  $340 = Math_fround($327 + $336);
  $341 = Math_fround($332 + $337);
  HEAPF32[$arPoseBase>>2] = $248;
  HEAPF32[$231>>2] = $249;
  HEAPF32[$236>>2] = $250;
  HEAPF32[$241>>2] = $251;
  HEAPF32[$252>>2] = $310;
  HEAPF32[$257>>2] = $311;
  HEAPF32[$262>>2] = $312;
  HEAPF32[$267>>2] = $313;
  HEAPF32[$316>>2] = $338;
  HEAPF32[$321>>2] = $339;
  HEAPF32[$326>>2] = $340;
  HEAPF32[$331>>2] = $341;
  STACKTOP = sp;return;
 } else {
  $342 = (($arPose) + 4|0);
  $343 = Math_fround(HEAPF32[$342>>2]);
  $344 = (($arPose) + 8|0);
  $345 = Math_fround(HEAPF32[$344>>2]);
  $346 = (($arPose) + 12|0);
  $347 = Math_fround(HEAPF32[$346>>2]);
  HEAPF32[$arPoseBase>>2] = $226;
  $348 = (($arPoseBase) + 4|0);
  HEAPF32[$348>>2] = $343;
  $349 = (($arPoseBase) + 8|0);
  HEAPF32[$349>>2] = $345;
  $350 = (($arPoseBase) + 12|0);
  HEAPF32[$350>>2] = $347;
  $351 = (($arPose) + 16|0);
  $352 = Math_fround(HEAPF32[$351>>2]);
  $353 = (($arPose) + 20|0);
  $354 = Math_fround(HEAPF32[$353>>2]);
  $355 = (($arPose) + 24|0);
  $356 = Math_fround(HEAPF32[$355>>2]);
  $357 = (($arPose) + 28|0);
  $358 = Math_fround(HEAPF32[$357>>2]);
  $359 = (($arPoseBase) + 16|0);
  HEAPF32[$359>>2] = $352;
  $360 = (($arPoseBase) + 20|0);
  HEAPF32[$360>>2] = $354;
  $361 = (($arPoseBase) + 24|0);
  HEAPF32[$361>>2] = $356;
  $362 = (($arPoseBase) + 28|0);
  HEAPF32[$362>>2] = $358;
  $363 = (($arPose) + 32|0);
  $364 = Math_fround(HEAPF32[$363>>2]);
  $365 = (($arPose) + 36|0);
  $366 = Math_fround(HEAPF32[$365>>2]);
  $367 = (($arPose) + 40|0);
  $368 = Math_fround(HEAPF32[$367>>2]);
  $369 = (($arPose) + 44|0);
  $370 = Math_fround(HEAPF32[$369>>2]);
  $371 = (($arPoseBase) + 32|0);
  HEAPF32[$371>>2] = $364;
  $372 = (($arPoseBase) + 36|0);
  HEAPF32[$372>>2] = $366;
  $373 = (($arPoseBase) + 40|0);
  HEAPF32[$373>>2] = $368;
  $374 = (($arPoseBase) + 44|0);
  HEAPF32[$374>>2] = $370;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim5human25HumanPoseAddAdditiveLayerERNS0_9HumanPoseERKS1_fRKNS_6bitsetILj59EEE($arPoseBase,$arPose,$aWeight,$arHumanPoseMask) {
 $arPoseBase = $arPoseBase|0;
 $arPose = $arPose|0;
 $aWeight = Math_fround($aWeight);
 $arHumanPoseMask = $arHumanPoseMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = 0, $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = Math_fround(0);
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0;
 var $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $exitcond = 0, $exitcond13 = 0, $exitcond14 = 0, $exitcond15 = 0, $i$012 = 0, $i$111 = 0, $i$29 = 0;
 var $i$37 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $0 = sp + 144|0;
 $1 = sp;
 $2 = sp + 48|0;
 $3 = sp + 96|0;
 $4 = $aWeight > Math_fround(0.0);
 if ($4) {
  $i$012 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $5 = (($i$012) + 1)|0;
  $6 = $5 >>> 5;
  $7 = (($arHumanPoseMask) + ($6<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $5 & 31;
  $10 = 1 << $9;
  $11 = $8 & $10;
  $12 = ($11|0)==(0);
  if (!($12)) {
   $13 = ((($arPose) + ($i$012<<2)|0) + 672|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = Math_fround($14 * $aWeight);
   $16 = ((($arPoseBase) + ($i$012<<2)|0) + 672|0);
   $17 = Math_fround(HEAPF32[$16>>2]);
   $18 = Math_fround($17 + $15);
   HEAPF32[$16>>2] = $18;
  }
  $exitcond15 = ($5|0)==(52);
  if ($exitcond15) {
   break;
  } else {
   $i$012 = $5;
  }
 }
 $19 = (($arHumanPoseMask) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20 & 33554432;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $i$111 = 0;
  while(1) {
   $23 = ((($arPose) + ($i$111<<2)|0) + 432|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = Math_fround($24 * $aWeight);
   $26 = ((($arPoseBase) + ($i$111<<2)|0) + 432|0);
   $27 = Math_fround(HEAPF32[$26>>2]);
   $28 = Math_fround($27 + $25);
   HEAPF32[$26>>2] = $28;
   $29 = (($i$111) + 1)|0;
   $exitcond14 = ($29|0)==(20);
   if ($exitcond14) {
    break;
   } else {
    $i$111 = $29;
   }
  }
 }
 $30 = $20 & 67108864;
 $31 = ($30|0)==(0);
 if (!($31)) {
  $i$29 = 0;
  while(1) {
   $54 = ((($arPose) + ($i$29<<2)|0) + 576|0);
   $55 = Math_fround(HEAPF32[$54>>2]);
   $56 = Math_fround($55 * $aWeight);
   $57 = ((($arPoseBase) + ($i$29<<2)|0) + 576|0);
   $58 = Math_fround(HEAPF32[$57>>2]);
   $59 = Math_fround($58 + $56);
   HEAPF32[$57>>2] = $59;
   $60 = (($i$29) + 1)|0;
   $exitcond13 = ($60|0)==(20);
   if ($exitcond13) {
    break;
   } else {
    $i$29 = $60;
   }
  }
 }
 $32 = (($1) + 4|0);
 $33 = (($1) + 8|0);
 $34 = (($1) + 12|0);
 $35 = (($1) + 16|0);
 $36 = (($1) + 20|0);
 $37 = (($1) + 24|0);
 $38 = (($1) + 28|0);
 $39 = (($1) + 32|0);
 $40 = (($1) + 36|0);
 $41 = (($1) + 40|0);
 $42 = (($1) + 44|0);
 $43 = (($0) + 4|0);
 $44 = (($0) + 8|0);
 $45 = (($0) + 12|0);
 $46 = (($0) + 16|0);
 $47 = (($0) + 20|0);
 $48 = (($0) + 24|0);
 $49 = (($0) + 28|0);
 $50 = (($0) + 32|0);
 $51 = (($0) + 36|0);
 $52 = (($0) + 40|0);
 $53 = (($0) + 44|0);
 $i$37 = 0;
 while(1) {
  $61 = (($i$37) + 53)|0;
  $62 = $61 >>> 5;
  $63 = (($arHumanPoseMask) + ($62<<2)|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = $61 & 31;
  $66 = 1 << $65;
  $67 = $64 & $66;
  $68 = ($67|0)==(0);
  if (!($68)) {
   $69 = ((($arPoseBase) + (($i$37*76)|0)|0) + 80|0);
   $70 = ((($arPose) + (($i$37*76)|0)|0) + 80|0);
   $71 = Math_fround(HEAPF32[$70>>2]);
   $72 = Math_fround($71 * $aWeight);
   $73 = ((($arPose) + (($i$37*76)|0)|0) + 84|0);
   $74 = Math_fround(HEAPF32[$73>>2]);
   $75 = Math_fround($74 * $aWeight);
   $76 = ((($arPose) + (($i$37*76)|0)|0) + 88|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = Math_fround($77 * $aWeight);
   $79 = ((($arPose) + (($i$37*76)|0)|0) + 92|0);
   $80 = Math_fround(HEAPF32[$79>>2]);
   $81 = Math_fround($80 * $aWeight);
   $82 = ((($arPose) + (($i$37*76)|0)|0) + 96|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = Math_fround($83 * $aWeight);
   $85 = ((($arPose) + (($i$37*76)|0)|0) + 100|0);
   $86 = Math_fround(HEAPF32[$85>>2]);
   $87 = Math_fround($86 * $aWeight);
   $88 = ((($arPose) + (($i$37*76)|0)|0) + 104|0);
   $89 = Math_fround(HEAPF32[$88>>2]);
   $90 = Math_fround($89 * $aWeight);
   $91 = ((($arPose) + (($i$37*76)|0)|0) + 108|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = Math_fround($84 * $84);
   $94 = Math_fround($87 * $87);
   $95 = Math_fround($90 * $90);
   $96 = Math_fround($92 * $92);
   $97 = Math_fround($93 + $94);
   $98 = Math_fround($95 + $96);
   $99 = Math_fround($97 + $98);
   $100 = (Math_fround(Math_sqrt((Math_fround($99)))));
   $101 = Math_fround(Math_fround(1.0) / $100);
   $102 = Math_fround($84 * $101);
   $103 = Math_fround($87 * $101);
   $104 = Math_fround($90 * $101);
   $105 = Math_fround($92 * $101);
   HEAPF32[$1>>2] = $72;
   HEAPF32[$32>>2] = $75;
   HEAPF32[$33>>2] = $78;
   HEAPF32[$34>>2] = $81;
   HEAPF32[$35>>2] = $102;
   HEAPF32[$36>>2] = $103;
   HEAPF32[$37>>2] = $104;
   HEAPF32[$38>>2] = $105;
   HEAPF32[$39>>2] = Math_fround(1.0);
   HEAPF32[$40>>2] = Math_fround(1.0);
   HEAPF32[$41>>2] = Math_fround(1.0);
   HEAPF32[$42>>2] = Math_fround(1.0);
   __ZN4mathL8xformMulERKNS_5xformES2_19323($0,$69,$1);
   $106 = Math_fround(HEAPF32[$0>>2]);
   $107 = Math_fround(HEAPF32[$43>>2]);
   $108 = Math_fround(HEAPF32[$44>>2]);
   $109 = Math_fround(HEAPF32[$45>>2]);
   HEAPF32[$69>>2] = $106;
   $110 = ((($arPoseBase) + (($i$37*76)|0)|0) + 84|0);
   HEAPF32[$110>>2] = $107;
   $111 = ((($arPoseBase) + (($i$37*76)|0)|0) + 88|0);
   HEAPF32[$111>>2] = $108;
   $112 = ((($arPoseBase) + (($i$37*76)|0)|0) + 92|0);
   HEAPF32[$112>>2] = $109;
   $113 = Math_fround(HEAPF32[$46>>2]);
   $114 = Math_fround(HEAPF32[$47>>2]);
   $115 = Math_fround(HEAPF32[$48>>2]);
   $116 = Math_fround(HEAPF32[$49>>2]);
   $117 = ((($arPoseBase) + (($i$37*76)|0)|0) + 96|0);
   HEAPF32[$117>>2] = $113;
   $118 = ((($arPoseBase) + (($i$37*76)|0)|0) + 100|0);
   HEAPF32[$118>>2] = $114;
   $119 = ((($arPoseBase) + (($i$37*76)|0)|0) + 104|0);
   HEAPF32[$119>>2] = $115;
   $120 = ((($arPoseBase) + (($i$37*76)|0)|0) + 108|0);
   HEAPF32[$120>>2] = $116;
   $121 = Math_fround(HEAPF32[$50>>2]);
   $122 = Math_fround(HEAPF32[$51>>2]);
   $123 = Math_fround(HEAPF32[$52>>2]);
   $124 = Math_fround(HEAPF32[$53>>2]);
   $125 = ((($arPoseBase) + (($i$37*76)|0)|0) + 112|0);
   HEAPF32[$125>>2] = $121;
   $126 = ((($arPoseBase) + (($i$37*76)|0)|0) + 116|0);
   HEAPF32[$126>>2] = $122;
   $127 = ((($arPoseBase) + (($i$37*76)|0)|0) + 120|0);
   HEAPF32[$127>>2] = $123;
   $128 = ((($arPoseBase) + (($i$37*76)|0)|0) + 124|0);
   HEAPF32[$128>>2] = $124;
  }
  $129 = (($i$37) + 1)|0;
  $exitcond = ($129|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $i$37 = $129;
  }
 }
 $130 = HEAP32[$arHumanPoseMask>>2]|0;
 $131 = $130 & 1;
 $132 = ($131|0)==(0);
 if ($132) {
  STACKTOP = sp;return;
 }
 $133 = Math_fround(HEAPF32[$arPose>>2]);
 $134 = Math_fround($133 * $aWeight);
 $135 = (($arPose) + 4|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($136 * $aWeight);
 $138 = (($arPose) + 8|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($139 * $aWeight);
 $141 = (($arPose) + 12|0);
 $142 = Math_fround(HEAPF32[$141>>2]);
 $143 = Math_fround($142 * $aWeight);
 $144 = (($arPose) + 16|0);
 $145 = Math_fround(HEAPF32[$144>>2]);
 $146 = Math_fround($145 * $aWeight);
 $147 = (($arPose) + 20|0);
 $148 = Math_fround(HEAPF32[$147>>2]);
 $149 = Math_fround($148 * $aWeight);
 $150 = (($arPose) + 24|0);
 $151 = Math_fround(HEAPF32[$150>>2]);
 $152 = Math_fround($151 * $aWeight);
 $153 = (($arPose) + 28|0);
 $154 = Math_fround(HEAPF32[$153>>2]);
 $155 = Math_fround($146 * $146);
 $156 = Math_fround($149 * $149);
 $157 = Math_fround($152 * $152);
 $158 = Math_fround($154 * $154);
 $159 = Math_fround($155 + $156);
 $160 = Math_fround($157 + $158);
 $161 = Math_fround($159 + $160);
 $162 = (Math_fround(Math_sqrt((Math_fround($161)))));
 $163 = Math_fround(Math_fround(1.0) / $162);
 $164 = Math_fround($146 * $163);
 $165 = Math_fround($149 * $163);
 $166 = Math_fround($152 * $163);
 $167 = Math_fround($154 * $163);
 HEAPF32[$3>>2] = $134;
 $168 = (($3) + 4|0);
 HEAPF32[$168>>2] = $137;
 $169 = (($3) + 8|0);
 HEAPF32[$169>>2] = $140;
 $170 = (($3) + 12|0);
 HEAPF32[$170>>2] = $143;
 $171 = (($3) + 16|0);
 HEAPF32[$171>>2] = $164;
 $172 = (($3) + 20|0);
 HEAPF32[$172>>2] = $165;
 $173 = (($3) + 24|0);
 HEAPF32[$173>>2] = $166;
 $174 = (($3) + 28|0);
 HEAPF32[$174>>2] = $167;
 $175 = (($3) + 32|0);
 HEAPF32[$175>>2] = Math_fround(1.0);
 $176 = (($3) + 36|0);
 HEAPF32[$176>>2] = Math_fround(1.0);
 $177 = (($3) + 40|0);
 HEAPF32[$177>>2] = Math_fround(1.0);
 $178 = (($3) + 44|0);
 HEAPF32[$178>>2] = Math_fround(1.0);
 __ZN4mathL8xformMulERKNS_5xformES2_19323($2,$arPoseBase,$3);
 $179 = Math_fround(HEAPF32[$2>>2]);
 $180 = (($2) + 4|0);
 $181 = Math_fround(HEAPF32[$180>>2]);
 $182 = (($2) + 8|0);
 $183 = Math_fround(HEAPF32[$182>>2]);
 $184 = (($2) + 12|0);
 $185 = Math_fround(HEAPF32[$184>>2]);
 HEAPF32[$arPoseBase>>2] = $179;
 $186 = (($arPoseBase) + 4|0);
 HEAPF32[$186>>2] = $181;
 $187 = (($arPoseBase) + 8|0);
 HEAPF32[$187>>2] = $183;
 $188 = (($arPoseBase) + 12|0);
 HEAPF32[$188>>2] = $185;
 $189 = (($2) + 16|0);
 $190 = Math_fround(HEAPF32[$189>>2]);
 $191 = (($2) + 20|0);
 $192 = Math_fround(HEAPF32[$191>>2]);
 $193 = (($2) + 24|0);
 $194 = Math_fround(HEAPF32[$193>>2]);
 $195 = (($2) + 28|0);
 $196 = Math_fround(HEAPF32[$195>>2]);
 $197 = (($arPoseBase) + 16|0);
 HEAPF32[$197>>2] = $190;
 $198 = (($arPoseBase) + 20|0);
 HEAPF32[$198>>2] = $192;
 $199 = (($arPoseBase) + 24|0);
 HEAPF32[$199>>2] = $194;
 $200 = (($arPoseBase) + 28|0);
 HEAPF32[$200>>2] = $196;
 $201 = (($2) + 32|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = (($2) + 36|0);
 $204 = Math_fround(HEAPF32[$203>>2]);
 $205 = (($2) + 40|0);
 $206 = Math_fround(HEAPF32[$205>>2]);
 $207 = (($2) + 44|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($arPoseBase) + 32|0);
 HEAPF32[$209>>2] = $202;
 $210 = (($arPoseBase) + 36|0);
 HEAPF32[$210>>2] = $204;
 $211 = (($arPoseBase) + 40|0);
 HEAPF32[$211>>2] = $206;
 $212 = (($arPoseBase) + 44|0);
 HEAPF32[$212>>2] = $208;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$apSkeletonPoseWs,$aPIndex,$aCIndex,$aTwist) {
 $apHuman = $apHuman|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $apSkeletonPoseWs = $apSkeletonPoseWs|0;
 $aPIndex = $aPIndex|0;
 $aCIndex = $aCIndex|0;
 $aTwist = $aTwist|0;
 var $$in = 0, $$in5 = 0, $$in6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $1000 = Math_fround(0), $1001 = Math_fround(0), $1002 = Math_fround(0), $1003 = Math_fround(0), $1004 = Math_fround(0), $1005 = Math_fround(0), $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = Math_fround(0), $1011 = Math_fround(0);
 var $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0), $1017 = Math_fround(0), $1018 = Math_fround(0), $1019 = Math_fround(0), $102 = Math_fround(0), $1020 = Math_fround(0), $1021 = Math_fround(0), $1022 = Math_fround(0), $1023 = Math_fround(0), $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = Math_fround(0), $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = Math_fround(0), $103 = 0;
 var $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = Math_fround(0), $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0), $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0);
 var $1049 = Math_fround(0), $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0), $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0);
 var $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0;
 var $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = Math_fround(0), $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0);
 var $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0);
 var $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0);
 var $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0);
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0);
 var $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = 0, $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0);
 var $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0);
 var $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0);
 var $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = Math_fround(0), $298 = 0, $299 = 0;
 var $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0);
 var $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0);
 var $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = Math_fround(0), $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = 0, $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = Math_fround(0);
 var $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0);
 var $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = Math_fround(0), $483 = 0, $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = Math_fround(0);
 var $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = Math_fround(0), $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = Math_fround(0), $507 = Math_fround(0), $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = Math_fround(0);
 var $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0;
 var $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = 0, $585 = 0, $586 = 0, $587 = Math_fround(0);
 var $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0);
 var $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = Math_fround(0), $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0);
 var $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = Math_fround(0), $640 = Math_fround(0);
 var $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0);
 var $66 = Math_fround(0), $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0);
 var $678 = Math_fround(0), $679 = 0, $68 = Math_fround(0), $680 = 0, $681 = 0, $682 = 0, $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = 0, $693 = 0, $694 = 0, $695 = 0;
 var $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0;
 var $713 = 0, $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0;
 var $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = Math_fround(0), $74 = 0, $740 = 0, $741 = Math_fround(0), $742 = 0, $743 = Math_fround(0), $744 = 0, $745 = Math_fround(0), $746 = 0, $747 = 0, $748 = 0, $749 = Math_fround(0);
 var $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = Math_fround(0), $755 = 0, $756 = Math_fround(0), $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = Math_fround(0), $762 = 0, $763 = Math_fround(0), $764 = 0, $765 = 0, $766 = 0, $767 = 0;
 var $768 = Math_fround(0), $769 = Math_fround(0), $77 = 0, $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0), $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = 0, $785 = 0;
 var $786 = 0, $787 = 0, $788 = Math_fround(0), $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0;
 var $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0);
 var $821 = Math_fround(0), $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0;
 var $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = Math_fround(0), $844 = 0, $845 = Math_fround(0), $846 = 0, $847 = Math_fround(0), $848 = 0, $849 = Math_fround(0), $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = Math_fround(0), $854 = 0, $855 = 0, $856 = 0, $857 = 0;
 var $858 = Math_fround(0), $859 = 0, $86 = 0, $860 = Math_fround(0), $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = Math_fround(0), $866 = 0, $867 = Math_fround(0), $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0);
 var $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = 0, $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0), $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = Math_fround(0), $893 = Math_fround(0);
 var $894 = Math_fround(0), $895 = Math_fround(0), $896 = Math_fround(0), $897 = Math_fround(0), $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0;
 var $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = 0, $927 = 0, $928 = 0, $929 = 0;
 var $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = Math_fround(0);
 var $948 = 0, $949 = Math_fround(0), $95 = 0, $950 = 0, $951 = Math_fround(0), $952 = 0, $953 = Math_fround(0), $954 = 0, $955 = 0, $956 = 0, $957 = Math_fround(0), $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = Math_fround(0), $963 = 0, $964 = Math_fround(0), $965 = 0;
 var $966 = 0, $967 = 0, $968 = 0, $969 = Math_fround(0), $97 = 0, $970 = 0, $971 = Math_fround(0), $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = Math_fround(0), $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0);
 var $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = Math_fround(0), $988 = Math_fround(0), $989 = Math_fround(0), $99 = 0, $990 = Math_fround(0), $991 = Math_fround(0), $992 = Math_fround(0), $993 = Math_fround(0), $994 = Math_fround(0), $995 = Math_fround(0), $996 = Math_fround(0), $997 = Math_fround(0), $998 = Math_fround(0), $999 = Math_fround(0), $pq = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 96|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = sp + 48|0;
 $5 = sp + 64|0;
 $pq = sp + 80|0;
 $6 = ((($apHuman) + ($aPIndex<<2)|0) + 104|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($apHuman) + ($aCIndex<<2)|0) + 104|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($apHuman) + 48|0);
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($14) + 4|0);
 $16 = $15;
 $17 = HEAP32[$15>>2]|0;
 $18 = (($16) + ($17))|0;
 $19 = $18;
 $20 = (($19) + ($7<<3)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($14) + 24|0);
 $23 = ((($19) + ($7<<3)|0) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22;
 $26 = HEAP32[$22>>2]|0;
 $27 = (($26) + ($25))|0;
 $28 = $27;
 $29 = (($28) + (($24*88)|0)|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = ((($28) + (($24*88)|0)|0) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = ((($28) + (($24*88)|0)|0) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = ((($28) + (($24*88)|0)|0) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = ((($28) + (($24*88)|0)|0) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = ((($28) + (($24*88)|0)|0) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = ((($28) + (($24*88)|0)|0) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = ((($28) + (($24*88)|0)|0) + 28|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = ((($28) + (($24*88)|0)|0) + 32|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = ((($28) + (($24*88)|0)|0) + 36|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = ((($28) + (($24*88)|0)|0) + 40|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = ((($28) + (($24*88)|0)|0) + 44|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = ((($28) + (($24*88)|0)|0) + 48|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = ((($28) + (($24*88)|0)|0) + 52|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = ((($28) + (($24*88)|0)|0) + 56|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = ((($28) + (($24*88)|0)|0) + 60|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = ((($28) + (($24*88)|0)|0) + 64|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = ((($28) + (($24*88)|0)|0) + 68|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = ((($28) + (($24*88)|0)|0) + 72|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = ((($28) + (($24*88)|0)|0) + 76|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = ((($28) + (($24*88)|0)|0) + 80|0);
 $70 = $69;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = (($70) + 4)|0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = (($apSkeletonPoseWs) + 4|0);
 $77 = $76;
 $78 = HEAP32[$76>>2]|0;
 $79 = (($78) + ($77))|0;
 $80 = $79;
 $81 = (($apSkeletonPoseWs) + 8|0);
 HEAP32[$81>>2] = $80;
 $82 = ((($80) + (($21*48)|0)|0) + 16|0);
 HEAPF32[$82>>2] = Math_fround(0.0);
 $83 = ((($80) + (($21*48)|0)|0) + 20|0);
 HEAPF32[$83>>2] = Math_fround(0.0);
 $84 = ((($80) + (($21*48)|0)|0) + 24|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 $85 = ((($80) + (($21*48)|0)|0) + 28|0);
 HEAPF32[$85>>2] = Math_fround(1.0);
 $86 = (($apHuman) + 52|0);
 HEAP32[$86>>2] = $14;
 __ZN7mecanim8skeleton26SkeletonPoseComputeGlobalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($14,$apSkeletonPose,$apSkeletonPoseWs,$9,$7);
 $87 = (($apSkeletonPose) + 4|0);
 $88 = $87;
 $89 = HEAP32[$87>>2]|0;
 $90 = (($89) + ($88))|0;
 $91 = $90;
 $92 = (($apSkeletonPose) + 8|0);
 HEAP32[$92>>2] = $91;
 $93 = ((($91) + (($7*48)|0)|0) + 16|0);
 ;HEAP32[$pq+0>>2]=HEAP32[$93+0>>2]|0;HEAP32[$pq+4>>2]=HEAP32[$93+4>>2]|0;HEAP32[$pq+8>>2]=HEAP32[$93+8>>2]|0;HEAP32[$pq+12>>2]=HEAP32[$93+12>>2]|0;
 $94 = HEAP32[$76>>2]|0;
 $95 = (($94) + ($77))|0;
 $96 = $95;
 HEAP32[$81>>2] = $96;
 $97 = ((($96) + (($9*48)|0)|0) + 16|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = ((($96) + (($9*48)|0)|0) + 20|0);
 $100 = Math_fround(HEAPF32[$99>>2]);
 $101 = ((($96) + (($9*48)|0)|0) + 24|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = ((($96) + (($9*48)|0)|0) + 28|0);
 $104 = Math_fround(HEAPF32[$103>>2]);
 HEAP32[$92>>2] = $91;
 $105 = Math_fround($30 * Math_fround(-1.0));
 $106 = Math_fround($32 * Math_fround(-1.0));
 $107 = Math_fround($34 * Math_fround(-1.0));
 $108 = ((($91) + (($7*48)|0)|0) + 20|0);
 $109 = Math_fround(HEAPF32[$108>>2]);
 $110 = Math_fround($38 * $109);
 $111 = ((($91) + (($7*48)|0)|0) + 28|0);
 $112 = Math_fround(HEAPF32[$111>>2]);
 $113 = Math_fround($44 * $112);
 $114 = ((($91) + (($7*48)|0)|0) + 24|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($40 * $115);
 $117 = ((($91) + (($7*48)|0)|0) + 16|0);
 $118 = Math_fround(HEAPF32[$117>>2]);
 $119 = Math_fround($42 * $118);
 $120 = Math_fround($42 * $112);
 $121 = Math_fround($38 * $118);
 $122 = Math_fround($42 * $109);
 $123 = Math_fround($38 * $115);
 $124 = Math_fround($110 - $120);
 $125 = Math_fround($113 - $121);
 $126 = Math_fround($116 - $122);
 $127 = Math_fround($119 - $123);
 $128 = Math_fround($44 * $115);
 $129 = Math_fround($42 * $115);
 $130 = Math_fround($38 * $112);
 $131 = Math_fround($40 * $112);
 $132 = Math_fround($124 - $128);
 $133 = Math_fround($125 - $129);
 $134 = Math_fround($126 - $130);
 $135 = Math_fround($127 - $131);
 $136 = Math_fround($40 * $118);
 $137 = Math_fround($40 * $109);
 $138 = Math_fround($44 * $118);
 $139 = Math_fround($44 * $109);
 $140 = Math_fround($132 - $136);
 $141 = Math_fround($133 - $137);
 $142 = Math_fround($134 - $138);
 $143 = Math_fround($135 - $139);
 $144 = Math_fround($142 * Math_fround(-1.0));
 $145 = Math_fround($143 * Math_fround(-1.0));
 $146 = Math_fround($140 * Math_fround(-1.0));
 $147 = Math_fround($106 * $144);
 $148 = Math_fround($36 * $141);
 $149 = Math_fround($107 * $145);
 $150 = Math_fround($105 * $146);
 $151 = Math_fround($36 * $146);
 $152 = Math_fround($105 * $144);
 $153 = Math_fround($106 * $146);
 $154 = Math_fround($107 * $144);
 $155 = Math_fround($147 - $151);
 $156 = Math_fround($148 - $152);
 $157 = Math_fround($149 - $153);
 $158 = Math_fround($150 - $154);
 $159 = Math_fround($107 * $141);
 $160 = Math_fround($107 * $146);
 $161 = Math_fround($36 * $144);
 $162 = Math_fround($36 * $145);
 $163 = Math_fround($155 - $159);
 $164 = Math_fround($156 - $160);
 $165 = Math_fround($157 - $161);
 $166 = Math_fround($158 - $162);
 $167 = Math_fround($105 * $145);
 $168 = Math_fround($106 * $145);
 $169 = Math_fround($105 * $141);
 $170 = Math_fround($106 * $141);
 $171 = Math_fround($163 - $167);
 $172 = Math_fround($164 - $168);
 $173 = Math_fround($165 - $169);
 $174 = Math_fround($166 - $170);
 $175 = Math_fround($173 * Math_fround(-1.0));
 $176 = Math_fround($174 * Math_fround(-1.0));
 $177 = Math_fround($171 * Math_fround(-1.0));
 $178 = Math_fround($175 * $175);
 $179 = Math_fround($176 * $176);
 $180 = Math_fround($177 * $177);
 $181 = Math_fround($172 * $172);
 $182 = Math_fround($179 + $178);
 $183 = Math_fround($181 + $180);
 $184 = Math_fround($183 + $182);
 $185 = (Math_fround(Math_sqrt((Math_fround($184)))));
 $186 = Math_fround(Math_fround(1.0) / $185);
 $187 = Math_fround($186 * $175);
 $188 = Math_fround($186 * $176);
 $189 = Math_fround($186 * $177);
 $190 = Math_fround($186 * $172);
 if ((($75|0) == 1)) {
  $275 = $190 == Math_fround(0.0);
  $276 = $275 ? Math_fround(9.99999997475242707878E-7) : $190;
  $277 = Math_fround($187 / $276);
  $278 = Math_fround($188 / $276);
  $279 = Math_fround($189 / $276);
  $280 = Math_fround($277 * $277);
  $281 = Math_fround($280 + Math_fround(1.0));
  $282 = Math_fround($277 * $279);
  $283 = Math_fround($278 - $282);
  $284 = Math_fround($283 / $281);
  $285 = Math_fround($277 * $278);
  $286 = Math_fround($285 + $279);
  $287 = Math_fround($286 / $281);
  $288 = (HEAPF32[tempDoublePtr>>2]=$277,HEAP32[tempDoublePtr>>2]|0);
  $289 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $290 = $289 & -2147483648;
  $291 = $288 ^ $290;
  $292 = (HEAP32[tempDoublePtr>>2]=$291,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $293 = (HEAPF32[tempDoublePtr>>2]=$284,HEAP32[tempDoublePtr>>2]|0);
  $294 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $295 = $294 & -2147483648;
  $296 = $293 ^ $295;
  $297 = (HEAP32[tempDoublePtr>>2]=$296,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $298 = (HEAPF32[tempDoublePtr>>2]=$287,HEAP32[tempDoublePtr>>2]|0);
  $299 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $300 = $299 & -2147483648;
  $301 = $298 ^ $300;
  $302 = (HEAP32[tempDoublePtr>>2]=$301,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $303 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
  $304 = $303 & -2147483648;
  $305 = (HEAP32[tempDoublePtr>>2]=$304,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $306 = (Math_fround(+(Math_atan((+$292)))));
  $307 = (Math_fround(+(Math_atan((+$297)))));
  $308 = (Math_fround(+(Math_atan((+$302)))));
  $309 = (Math_fround(+(Math_atan((+$305)))));
  $310 = Math_fround($306 * Math_fround(2.0));
  $311 = Math_fround($307 * Math_fround(2.0));
  $312 = Math_fround($308 * Math_fround(2.0));
  $313 = Math_fround($309 * Math_fround(2.0));
  $314 = $54 > Math_fround(0.0);
  $315 = $56 > Math_fround(0.0);
  $316 = $58 > Math_fround(0.0);
  $317 = $60 > Math_fround(0.0);
  $318 = Math_fround(-$310);
  $319 = Math_fround(-$311);
  $320 = Math_fround(-$312);
  $321 = Math_fround(-$313);
  $322 = Math_fround($318 / $54);
  $323 = Math_fround($319 / $56);
  $324 = Math_fround($320 / $58);
  $325 = Math_fround($321 / $60);
  $326 = $54 < Math_fround(0.0);
  $327 = $56 < Math_fround(0.0);
  $328 = $58 < Math_fround(0.0);
  $329 = $60 < Math_fround(0.0);
  $330 = (HEAPF32[tempDoublePtr>>2]=$310,HEAP32[tempDoublePtr>>2]|0);
  $331 = $314 ? $330 : 0;
  $332 = (HEAPF32[tempDoublePtr>>2]=$322,HEAP32[tempDoublePtr>>2]|0);
  $333 = $326 ? $332 : $331;
  $334 = (HEAPF32[tempDoublePtr>>2]=$311,HEAP32[tempDoublePtr>>2]|0);
  $335 = $315 ? $334 : 0;
  $336 = (HEAPF32[tempDoublePtr>>2]=$323,HEAP32[tempDoublePtr>>2]|0);
  $337 = $327 ? $336 : $335;
  $338 = (HEAPF32[tempDoublePtr>>2]=$312,HEAP32[tempDoublePtr>>2]|0);
  $339 = $316 ? $338 : 0;
  $340 = (HEAPF32[tempDoublePtr>>2]=$324,HEAP32[tempDoublePtr>>2]|0);
  $341 = $328 ? $340 : $339;
  $342 = (HEAPF32[tempDoublePtr>>2]=$313,HEAP32[tempDoublePtr>>2]|0);
  $343 = $317 ? $342 : 0;
  $344 = (HEAPF32[tempDoublePtr>>2]=$325,HEAP32[tempDoublePtr>>2]|0);
  $345 = $329 ? $344 : $343;
  $346 = $62 < Math_fround(0.0);
  $347 = $64 < Math_fround(0.0);
  $348 = $66 < Math_fround(0.0);
  $349 = $68 < Math_fround(0.0);
  $350 = Math_fround($310 / $62);
  $351 = Math_fround($311 / $64);
  $352 = Math_fround($312 / $66);
  $353 = Math_fround($313 / $68);
  $354 = $62 > Math_fround(0.0);
  $355 = $64 > Math_fround(0.0);
  $356 = $66 > Math_fround(0.0);
  $357 = $68 > Math_fround(0.0);
  $358 = $346 ? $330 : 0;
  $359 = (HEAPF32[tempDoublePtr>>2]=$350,HEAP32[tempDoublePtr>>2]|0);
  $360 = $354 ? $359 : $358;
  $361 = $347 ? $334 : 0;
  $362 = (HEAPF32[tempDoublePtr>>2]=$351,HEAP32[tempDoublePtr>>2]|0);
  $363 = $355 ? $362 : $361;
  $364 = $348 ? $338 : 0;
  $365 = (HEAPF32[tempDoublePtr>>2]=$352,HEAP32[tempDoublePtr>>2]|0);
  $366 = $356 ? $365 : $364;
  $367 = $349 ? $342 : 0;
  $368 = (HEAPF32[tempDoublePtr>>2]=$353,HEAP32[tempDoublePtr>>2]|0);
  $369 = $357 ? $368 : $367;
  $370 = $310 < Math_fround(0.0);
  $371 = $311 < Math_fround(0.0);
  $372 = $312 < Math_fround(0.0);
  $373 = $313 < Math_fround(0.0);
  $374 = $370 ? $333 : $360;
  $375 = $371 ? $337 : $363;
  $376 = $372 ? $341 : $366;
  $377 = $373 ? $345 : $369;
  $378 = (HEAP32[tempDoublePtr>>2]=$377,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $$in = $376;$$in5 = $375;$$in6 = $374;$690 = $378;
 } else if ((($75|0) == 3)) {
  $191 = Math_fround($187 * $187);
  $192 = Math_fround($188 * $187);
  $193 = Math_fround($189 * $187);
  $194 = Math_fround($190 * $187);
  $195 = Math_fround($188 * $188);
  $196 = Math_fround($189 * $188);
  $197 = Math_fround($190 * $188);
  $198 = Math_fround($193 - $197);
  $199 = !($198 >= Math_fround(0.499998986721038818359));
  do {
   if ($199) {
    $204 = Math_fround($190 * $190);
    $205 = Math_fround($190 * $189);
    $206 = Math_fround($204 + Math_fround(-0.5));
    $207 = !($198 <= Math_fround(-0.499998986721038818359));
    if ($207) {
     $211 = Math_fround($189 * $189);
     $212 = Math_fround($196 + $194);
     $213 = Math_fround($211 + $206);
     $214 = Math_fround($198 + $198);
     $215 = Math_fround($205 + $192);
     $216 = Math_fround($206 + $191);
     $217 = (Math_fround(+(Math_atan2((+$212),(+$213)))));
     $218 = (Math_fround(+(Math_asin((+$214)))));
     $219 = Math_fround(-$218);
     $220 = (Math_fround(+(Math_atan2((+$215),(+$216)))));
     $225 = $217;$227 = $219;$229 = $220;
     break;
    } else {
     $208 = Math_fround($192 - $205);
     $209 = Math_fround($195 + $206);
     $210 = (Math_fround(+(Math_atan2((+$208),(+$209)))));
     $225 = $210;$227 = Math_fround(1.57079637050628662109);$229 = Math_fround(0.0);
     break;
    }
   } else {
    $200 = Math_fround($194 - $196);
    $201 = Math_fround(-$193);
    $202 = Math_fround($201 - $197);
    $203 = (Math_fround(+(Math_atan2((+$200),(+$202)))));
    $225 = $203;$227 = Math_fround(-1.57079637050628662109);$229 = Math_fround(0.0);
   }
  } while(0);
  $221 = $54 > Math_fround(0.0);
  $222 = $56 > Math_fround(0.0);
  $223 = $58 > Math_fround(0.0);
  $224 = Math_fround(-$225);
  $226 = Math_fround(-$227);
  $228 = Math_fround(-$229);
  $230 = Math_fround($224 / $54);
  $231 = Math_fround($226 / $56);
  $232 = Math_fround($228 / $58);
  $233 = $54 < Math_fround(0.0);
  $234 = $56 < Math_fround(0.0);
  $235 = $58 < Math_fround(0.0);
  $236 = (HEAPF32[tempDoublePtr>>2]=$225,HEAP32[tempDoublePtr>>2]|0);
  $237 = $221 ? $236 : 0;
  $238 = (HEAPF32[tempDoublePtr>>2]=$230,HEAP32[tempDoublePtr>>2]|0);
  $239 = $233 ? $238 : $237;
  $240 = (HEAPF32[tempDoublePtr>>2]=$227,HEAP32[tempDoublePtr>>2]|0);
  $241 = $222 ? $240 : 0;
  $242 = (HEAPF32[tempDoublePtr>>2]=$231,HEAP32[tempDoublePtr>>2]|0);
  $243 = $234 ? $242 : $241;
  $244 = (HEAPF32[tempDoublePtr>>2]=$229,HEAP32[tempDoublePtr>>2]|0);
  $245 = $223 ? $244 : 0;
  $246 = (HEAPF32[tempDoublePtr>>2]=$232,HEAP32[tempDoublePtr>>2]|0);
  $247 = $235 ? $246 : $245;
  $248 = $62 < Math_fround(0.0);
  $249 = $64 < Math_fround(0.0);
  $250 = $66 < Math_fround(0.0);
  $251 = Math_fround($225 / $62);
  $252 = Math_fround($227 / $64);
  $253 = Math_fround($229 / $66);
  $254 = Math_fround(Math_fround(0.0) / $68);
  $255 = $62 > Math_fround(0.0);
  $256 = $64 > Math_fround(0.0);
  $257 = $66 > Math_fround(0.0);
  $258 = $68 > Math_fround(0.0);
  $259 = $248 ? $236 : 0;
  $260 = (HEAPF32[tempDoublePtr>>2]=$251,HEAP32[tempDoublePtr>>2]|0);
  $261 = $255 ? $260 : $259;
  $262 = $249 ? $240 : 0;
  $263 = (HEAPF32[tempDoublePtr>>2]=$252,HEAP32[tempDoublePtr>>2]|0);
  $264 = $256 ? $263 : $262;
  $265 = $250 ? $244 : 0;
  $266 = (HEAPF32[tempDoublePtr>>2]=$253,HEAP32[tempDoublePtr>>2]|0);
  $267 = $257 ? $266 : $265;
  $268 = $225 < Math_fround(0.0);
  $269 = $227 < Math_fround(0.0);
  $270 = $229 < Math_fround(0.0);
  $271 = $268 ? $239 : $261;
  $272 = $269 ? $243 : $264;
  $273 = $270 ? $247 : $267;
  $274 = $258 ? $254 : Math_fround(0.0);
  $$in = $273;$$in5 = $272;$$in6 = $271;$690 = $274;
 } else if ((($75|0) == 2)) {
  $379 = $190 == Math_fround(0.0);
  $380 = $379 ? Math_fround(9.99999997475242707878E-7) : $190;
  $381 = Math_fround($187 / $380);
  $382 = Math_fround($188 / $380);
  $383 = Math_fround($189 / $380);
  $384 = Math_fround($381 * $381);
  $385 = Math_fround($384 + Math_fround(1.0));
  $386 = Math_fround($381 * $383);
  $387 = Math_fround($382 + $386);
  $388 = Math_fround($387 / $385);
  $389 = Math_fround($381 * $382);
  $390 = Math_fround($383 - $389);
  $391 = Math_fround($390 / $385);
  $392 = (HEAPF32[tempDoublePtr>>2]=$381,HEAP32[tempDoublePtr>>2]|0);
  $393 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $394 = $393 & -2147483648;
  $395 = $392 ^ $394;
  $396 = (HEAP32[tempDoublePtr>>2]=$395,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $397 = (HEAPF32[tempDoublePtr>>2]=$388,HEAP32[tempDoublePtr>>2]|0);
  $398 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $399 = $398 & -2147483648;
  $400 = $397 ^ $399;
  $401 = (HEAP32[tempDoublePtr>>2]=$400,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $402 = (HEAPF32[tempDoublePtr>>2]=$391,HEAP32[tempDoublePtr>>2]|0);
  $403 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $404 = $403 & -2147483648;
  $405 = $402 ^ $404;
  $406 = (HEAP32[tempDoublePtr>>2]=$405,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $407 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
  $408 = $407 & -2147483648;
  $409 = (HEAP32[tempDoublePtr>>2]=$408,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $410 = (Math_fround(+(Math_atan((+$396)))));
  $411 = (Math_fround(+(Math_atan((+$401)))));
  $412 = (Math_fround(+(Math_atan((+$406)))));
  $413 = (Math_fround(+(Math_atan((+$409)))));
  $414 = Math_fround($410 * Math_fround(2.0));
  $415 = Math_fround($411 * Math_fround(2.0));
  $416 = Math_fround($412 * Math_fround(2.0));
  $417 = Math_fround($413 * Math_fround(2.0));
  $418 = $54 > Math_fround(0.0);
  $419 = $56 > Math_fround(0.0);
  $420 = $58 > Math_fround(0.0);
  $421 = $60 > Math_fround(0.0);
  $422 = Math_fround(-$414);
  $423 = Math_fround(-$415);
  $424 = Math_fround(-$416);
  $425 = Math_fround(-$417);
  $426 = Math_fround($422 / $54);
  $427 = Math_fround($423 / $56);
  $428 = Math_fround($424 / $58);
  $429 = Math_fround($425 / $60);
  $430 = $54 < Math_fround(0.0);
  $431 = $56 < Math_fround(0.0);
  $432 = $58 < Math_fround(0.0);
  $433 = $60 < Math_fround(0.0);
  $434 = (HEAPF32[tempDoublePtr>>2]=$414,HEAP32[tempDoublePtr>>2]|0);
  $435 = $418 ? $434 : 0;
  $436 = (HEAPF32[tempDoublePtr>>2]=$426,HEAP32[tempDoublePtr>>2]|0);
  $437 = $430 ? $436 : $435;
  $438 = (HEAPF32[tempDoublePtr>>2]=$415,HEAP32[tempDoublePtr>>2]|0);
  $439 = $419 ? $438 : 0;
  $440 = (HEAPF32[tempDoublePtr>>2]=$427,HEAP32[tempDoublePtr>>2]|0);
  $441 = $431 ? $440 : $439;
  $442 = (HEAPF32[tempDoublePtr>>2]=$416,HEAP32[tempDoublePtr>>2]|0);
  $443 = $420 ? $442 : 0;
  $444 = (HEAPF32[tempDoublePtr>>2]=$428,HEAP32[tempDoublePtr>>2]|0);
  $445 = $432 ? $444 : $443;
  $446 = (HEAPF32[tempDoublePtr>>2]=$417,HEAP32[tempDoublePtr>>2]|0);
  $447 = $421 ? $446 : 0;
  $448 = (HEAPF32[tempDoublePtr>>2]=$429,HEAP32[tempDoublePtr>>2]|0);
  $449 = $433 ? $448 : $447;
  $450 = $62 < Math_fround(0.0);
  $451 = $64 < Math_fround(0.0);
  $452 = $66 < Math_fround(0.0);
  $453 = $68 < Math_fround(0.0);
  $454 = Math_fround($414 / $62);
  $455 = Math_fround($415 / $64);
  $456 = Math_fround($416 / $66);
  $457 = Math_fround($417 / $68);
  $458 = $62 > Math_fround(0.0);
  $459 = $64 > Math_fround(0.0);
  $460 = $66 > Math_fround(0.0);
  $461 = $68 > Math_fround(0.0);
  $462 = $450 ? $434 : 0;
  $463 = (HEAPF32[tempDoublePtr>>2]=$454,HEAP32[tempDoublePtr>>2]|0);
  $464 = $458 ? $463 : $462;
  $465 = $451 ? $438 : 0;
  $466 = (HEAPF32[tempDoublePtr>>2]=$455,HEAP32[tempDoublePtr>>2]|0);
  $467 = $459 ? $466 : $465;
  $468 = $452 ? $442 : 0;
  $469 = (HEAPF32[tempDoublePtr>>2]=$456,HEAP32[tempDoublePtr>>2]|0);
  $470 = $460 ? $469 : $468;
  $471 = $453 ? $446 : 0;
  $472 = (HEAPF32[tempDoublePtr>>2]=$457,HEAP32[tempDoublePtr>>2]|0);
  $473 = $461 ? $472 : $471;
  $474 = $414 < Math_fround(0.0);
  $475 = $415 < Math_fround(0.0);
  $476 = $416 < Math_fround(0.0);
  $477 = $417 < Math_fround(0.0);
  $478 = $474 ? $437 : $464;
  $479 = $475 ? $441 : $467;
  $480 = $476 ? $445 : $470;
  $481 = $477 ? $449 : $473;
  $482 = (HEAP32[tempDoublePtr>>2]=$481,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $$in = $480;$$in5 = $479;$$in6 = $478;$690 = $482;
 } else {
  $483 = $190 == Math_fround(0.0);
  $484 = $483 ? Math_fround(9.99999997475242707878E-7) : $190;
  $485 = Math_fround($187 / $484);
  $486 = Math_fround($188 / $484);
  $487 = Math_fround($189 / $484);
  $488 = (HEAPF32[tempDoublePtr>>2]=$485,HEAP32[tempDoublePtr>>2]|0);
  $489 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $490 = $489 & -2147483648;
  $491 = $488 ^ $490;
  $492 = (HEAP32[tempDoublePtr>>2]=$491,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $493 = (HEAPF32[tempDoublePtr>>2]=$486,HEAP32[tempDoublePtr>>2]|0);
  $494 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $495 = $494 & -2147483648;
  $496 = $493 ^ $495;
  $497 = (HEAP32[tempDoublePtr>>2]=$496,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $498 = (HEAPF32[tempDoublePtr>>2]=$487,HEAP32[tempDoublePtr>>2]|0);
  $499 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $500 = $499 & -2147483648;
  $501 = $498 ^ $500;
  $502 = (HEAP32[tempDoublePtr>>2]=$501,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $503 = (HEAPF32[tempDoublePtr>>2]=$52,HEAP32[tempDoublePtr>>2]|0);
  $504 = $503 & -2147483648;
  $505 = (HEAP32[tempDoublePtr>>2]=$504,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $506 = (Math_fround(+(Math_atan((+$492)))));
  $507 = (Math_fround(+(Math_atan((+$497)))));
  $508 = (Math_fround(+(Math_atan((+$502)))));
  $509 = (Math_fround(+(Math_atan((+$505)))));
  $510 = Math_fround($506 * Math_fround(2.0));
  $511 = Math_fround($507 * Math_fround(2.0));
  $512 = Math_fround($508 * Math_fround(2.0));
  $513 = Math_fround($509 * Math_fround(2.0));
  $514 = $54 > Math_fround(0.0);
  $515 = $56 > Math_fround(0.0);
  $516 = $58 > Math_fround(0.0);
  $517 = $60 > Math_fround(0.0);
  $518 = Math_fround(-$510);
  $519 = Math_fround(-$511);
  $520 = Math_fround(-$512);
  $521 = Math_fround(-$513);
  $522 = Math_fround($518 / $54);
  $523 = Math_fround($519 / $56);
  $524 = Math_fround($520 / $58);
  $525 = Math_fround($521 / $60);
  $526 = $54 < Math_fround(0.0);
  $527 = $56 < Math_fround(0.0);
  $528 = $58 < Math_fround(0.0);
  $529 = $60 < Math_fround(0.0);
  $530 = (HEAPF32[tempDoublePtr>>2]=$510,HEAP32[tempDoublePtr>>2]|0);
  $531 = $514 ? $530 : 0;
  $532 = (HEAPF32[tempDoublePtr>>2]=$522,HEAP32[tempDoublePtr>>2]|0);
  $533 = $526 ? $532 : $531;
  $534 = (HEAPF32[tempDoublePtr>>2]=$511,HEAP32[tempDoublePtr>>2]|0);
  $535 = $515 ? $534 : 0;
  $536 = (HEAPF32[tempDoublePtr>>2]=$523,HEAP32[tempDoublePtr>>2]|0);
  $537 = $527 ? $536 : $535;
  $538 = (HEAPF32[tempDoublePtr>>2]=$512,HEAP32[tempDoublePtr>>2]|0);
  $539 = $516 ? $538 : 0;
  $540 = (HEAPF32[tempDoublePtr>>2]=$524,HEAP32[tempDoublePtr>>2]|0);
  $541 = $528 ? $540 : $539;
  $542 = (HEAPF32[tempDoublePtr>>2]=$513,HEAP32[tempDoublePtr>>2]|0);
  $543 = $517 ? $542 : 0;
  $544 = (HEAPF32[tempDoublePtr>>2]=$525,HEAP32[tempDoublePtr>>2]|0);
  $545 = $529 ? $544 : $543;
  $546 = $62 < Math_fround(0.0);
  $547 = $64 < Math_fround(0.0);
  $548 = $66 < Math_fround(0.0);
  $549 = $68 < Math_fround(0.0);
  $550 = Math_fround($510 / $62);
  $551 = Math_fround($511 / $64);
  $552 = Math_fround($512 / $66);
  $553 = Math_fround($513 / $68);
  $554 = $62 > Math_fround(0.0);
  $555 = $64 > Math_fround(0.0);
  $556 = $66 > Math_fround(0.0);
  $557 = $68 > Math_fround(0.0);
  $558 = $546 ? $530 : 0;
  $559 = (HEAPF32[tempDoublePtr>>2]=$550,HEAP32[tempDoublePtr>>2]|0);
  $560 = $554 ? $559 : $558;
  $561 = $547 ? $534 : 0;
  $562 = (HEAPF32[tempDoublePtr>>2]=$551,HEAP32[tempDoublePtr>>2]|0);
  $563 = $555 ? $562 : $561;
  $564 = $548 ? $538 : 0;
  $565 = (HEAPF32[tempDoublePtr>>2]=$552,HEAP32[tempDoublePtr>>2]|0);
  $566 = $556 ? $565 : $564;
  $567 = $549 ? $542 : 0;
  $568 = (HEAPF32[tempDoublePtr>>2]=$553,HEAP32[tempDoublePtr>>2]|0);
  $569 = $557 ? $568 : $567;
  $570 = $510 < Math_fround(0.0);
  $571 = $511 < Math_fround(0.0);
  $572 = $512 < Math_fround(0.0);
  $573 = $513 < Math_fround(0.0);
  $574 = $570 ? $533 : $560;
  $575 = $571 ? $537 : $563;
  $576 = $572 ? $541 : $566;
  $577 = $573 ? $545 : $569;
  $578 = (HEAP32[tempDoublePtr>>2]=$577,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $$in = $576;$$in5 = $575;$$in6 = $574;$690 = $578;
 }
 $579 = (HEAP32[tempDoublePtr>>2]=$$in6,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $580 = (HEAP32[tempDoublePtr>>2]=$$in5,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $581 = (HEAP32[tempDoublePtr>>2]=$$in,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $582 = Math_fround(HEAPF32[$aTwist>>2]);
 $583 = Math_fround($579 * $582);
 $584 = HEAP32[$87>>2]|0;
 $585 = (($584) + ($88))|0;
 $586 = $585;
 HEAP32[$92>>2] = $586;
 if ((($75|0) == 3)) {
  $587 = Math_fround($583 * Math_fround(0.5));
  $588 = Math_fround($580 * Math_fround(0.5));
  $589 = Math_fround($581 * Math_fround(0.5));
  $590 = Math_fround($587 * Math_fround(0.159154936671257019043));
  $591 = Math_fround($588 * Math_fround(0.159154936671257019043));
  $592 = Math_fround($589 * Math_fround(0.159154936671257019043));
  $593 = (Math_fround(+(_roundf((+$590)))));
  $594 = (Math_fround(+(_roundf((+$591)))));
  $595 = (Math_fround(+(_roundf((+$592)))));
  $596 = Math_fround($590 - $593);
  $597 = Math_fround($591 - $594);
  $598 = Math_fround($592 - $595);
  $599 = (Math_fround(Math_abs((Math_fround($596)))));
  $600 = (Math_fround(Math_abs((Math_fround($597)))));
  $601 = (Math_fround(Math_abs((Math_fround($598)))));
  $602 = Math_fround(Math_fround(0.25) - $599);
  $603 = Math_fround(Math_fround(0.25) - $600);
  $604 = Math_fround(Math_fround(0.25) - $601);
  $605 = Math_fround($602 * $602);
  $606 = Math_fround($603 * $603);
  $607 = Math_fround($604 * $604);
  $608 = Math_fround($605 * $605);
  $609 = Math_fround($606 * $606);
  $610 = Math_fround($607 * $607);
  $611 = Math_fround($605 * Math_fround(-41.283184051513671875));
  $612 = Math_fround($606 * Math_fround(-41.283184051513671875));
  $613 = Math_fround($607 * Math_fround(-41.283184051513671875));
  $614 = Math_fround($611 + Math_fround(6.28318548202514648438));
  $615 = Math_fround($612 + Math_fround(6.28318548202514648438));
  $616 = Math_fround($613 + Math_fround(6.28318548202514648438));
  $617 = Math_fround($608 * Math_fround(76.03546142578125));
  $618 = Math_fround($609 * Math_fround(76.03546142578125));
  $619 = Math_fround($610 * Math_fround(76.03546142578125));
  $620 = Math_fround($614 + $617);
  $621 = Math_fround($615 + $618);
  $622 = Math_fround($616 + $619);
  $623 = Math_fround($602 * $620);
  $624 = Math_fround($603 * $621);
  $625 = Math_fround($604 * $622);
  $626 = Math_fround($590 + Math_fround(-0.25));
  $627 = Math_fround($591 + Math_fround(-0.25));
  $628 = Math_fround($592 + Math_fround(-0.25));
  $629 = (Math_fround(+(_roundf((+$626)))));
  $630 = (Math_fround(+(_roundf((+$627)))));
  $631 = (Math_fround(+(_roundf((+$628)))));
  $632 = Math_fround($626 - $629);
  $633 = Math_fround($627 - $630);
  $634 = Math_fround($628 - $631);
  $635 = (Math_fround(Math_abs((Math_fround($632)))));
  $636 = (Math_fround(Math_abs((Math_fround($633)))));
  $637 = (Math_fround(Math_abs((Math_fround($634)))));
  $638 = Math_fround(Math_fround(0.25) - $635);
  $639 = Math_fround(Math_fround(0.25) - $636);
  $640 = Math_fround(Math_fround(0.25) - $637);
  $641 = Math_fround($638 * $638);
  $642 = Math_fround($639 * $639);
  $643 = Math_fround($640 * $640);
  $644 = Math_fround($641 * $641);
  $645 = Math_fround($642 * $642);
  $646 = Math_fround($643 * $643);
  $647 = Math_fround($641 * Math_fround(-41.283184051513671875));
  $648 = Math_fround($642 * Math_fround(-41.283184051513671875));
  $649 = Math_fround($643 * Math_fround(-41.283184051513671875));
  $650 = Math_fround($647 + Math_fround(6.28318548202514648438));
  $651 = Math_fround($648 + Math_fround(6.28318548202514648438));
  $652 = Math_fround($649 + Math_fround(6.28318548202514648438));
  $653 = Math_fround($644 * Math_fround(76.03546142578125));
  $654 = Math_fround($645 * Math_fround(76.03546142578125));
  $655 = Math_fround($646 * Math_fround(76.03546142578125));
  $656 = Math_fround($650 + $653);
  $657 = Math_fround($651 + $654);
  $658 = Math_fround($652 + $655);
  $659 = Math_fround($638 * $656);
  $660 = Math_fround($639 * $657);
  $661 = Math_fround($640 * $658);
  $662 = Math_fround($625 * $659);
  $663 = Math_fround($659 * $661);
  $664 = Math_fround($623 * $661);
  $665 = Math_fround($623 * $625);
  $666 = Math_fround($624 * $662);
  $667 = Math_fround($624 * $663);
  $668 = Math_fround($624 * $664);
  $669 = Math_fround($624 * $665);
  $670 = Math_fround($660 * Math_fround(-1.0));
  $671 = Math_fround($670 * $664);
  $672 = Math_fround($665 * $660);
  $673 = Math_fround($662 * $670);
  $674 = Math_fround($660 * $663);
  $675 = Math_fround($666 + $671);
  $676 = Math_fround($672 + $667);
  $677 = Math_fround($673 + $668);
  $678 = Math_fround($669 + $674);
  $992 = $676;$994 = $678;$996 = $677;$998 = $675;
 } else if ((($75|0) == 2)) {
  $784 = $54 > Math_fround(0.0);
  $785 = $56 > Math_fround(0.0);
  $786 = $58 > Math_fround(0.0);
  $787 = $60 > Math_fround(0.0);
  $788 = Math_fround($54 * $583);
  $789 = Math_fround(-$788);
  $790 = Math_fround($56 * $580);
  $791 = Math_fround(-$790);
  $792 = Math_fround($58 * $581);
  $793 = Math_fround(-$792);
  $794 = Math_fround($60 * $690);
  $795 = Math_fround(-$794);
  $796 = $54 < Math_fround(0.0);
  $797 = $56 < Math_fround(0.0);
  $798 = $58 < Math_fround(0.0);
  $799 = $60 < Math_fround(0.0);
  $800 = (HEAPF32[tempDoublePtr>>2]=$583,HEAP32[tempDoublePtr>>2]|0);
  $801 = $784 ? $800 : 0;
  $802 = (HEAPF32[tempDoublePtr>>2]=$789,HEAP32[tempDoublePtr>>2]|0);
  $803 = $796 ? $802 : $801;
  $804 = $785 ? $$in5 : 0;
  $805 = (HEAPF32[tempDoublePtr>>2]=$791,HEAP32[tempDoublePtr>>2]|0);
  $806 = $797 ? $805 : $804;
  $807 = $786 ? $$in : 0;
  $808 = (HEAPF32[tempDoublePtr>>2]=$793,HEAP32[tempDoublePtr>>2]|0);
  $809 = $798 ? $808 : $807;
  $810 = (HEAPF32[tempDoublePtr>>2]=$690,HEAP32[tempDoublePtr>>2]|0);
  $811 = $787 ? $810 : 0;
  $812 = (HEAPF32[tempDoublePtr>>2]=$795,HEAP32[tempDoublePtr>>2]|0);
  $813 = $799 ? $812 : $811;
  $814 = $62 < Math_fround(0.0);
  $815 = $64 < Math_fround(0.0);
  $816 = $66 < Math_fround(0.0);
  $817 = $68 < Math_fround(0.0);
  $818 = Math_fround($62 * $583);
  $819 = Math_fround($64 * $580);
  $820 = Math_fround($66 * $581);
  $821 = Math_fround($68 * $690);
  $822 = $62 > Math_fround(0.0);
  $823 = $64 > Math_fround(0.0);
  $824 = $66 > Math_fround(0.0);
  $825 = $68 > Math_fround(0.0);
  $826 = $814 ? $800 : 0;
  $827 = (HEAPF32[tempDoublePtr>>2]=$818,HEAP32[tempDoublePtr>>2]|0);
  $828 = $822 ? $827 : $826;
  $829 = $815 ? $$in5 : 0;
  $830 = (HEAPF32[tempDoublePtr>>2]=$819,HEAP32[tempDoublePtr>>2]|0);
  $831 = $823 ? $830 : $829;
  $832 = $816 ? $$in : 0;
  $833 = (HEAPF32[tempDoublePtr>>2]=$820,HEAP32[tempDoublePtr>>2]|0);
  $834 = $824 ? $833 : $832;
  $835 = $817 ? $810 : 0;
  $836 = (HEAPF32[tempDoublePtr>>2]=$821,HEAP32[tempDoublePtr>>2]|0);
  $837 = $825 ? $836 : $835;
  $838 = $583 < Math_fround(0.0);
  $839 = $580 < Math_fround(0.0);
  $840 = $581 < Math_fround(0.0);
  $841 = $690 < Math_fround(0.0);
  $842 = $838 ? $803 : $828;
  $843 = (HEAP32[tempDoublePtr>>2]=$842,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $844 = $839 ? $806 : $831;
  $845 = (HEAP32[tempDoublePtr>>2]=$844,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $846 = $840 ? $809 : $834;
  $847 = (HEAP32[tempDoublePtr>>2]=$846,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $848 = $841 ? $813 : $837;
  $849 = (HEAP32[tempDoublePtr>>2]=$848,Math_fround(HEAPF32[tempDoublePtr>>2]));
  HEAPF32[$3>>2] = $843;
  $850 = (($3) + 4|0);
  HEAPF32[$850>>2] = $845;
  $851 = (($3) + 8|0);
  HEAPF32[$851>>2] = $847;
  $852 = (($3) + 12|0);
  HEAPF32[$852>>2] = $849;
  __ZN4mathL7halfTanERKNS_7_float4E19358($2,$3);
  $853 = Math_fround(HEAPF32[$2>>2]);
  $854 = (HEAPF32[tempDoublePtr>>2]=$853,HEAP32[tempDoublePtr>>2]|0);
  $855 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $856 = $855 & -2147483648;
  $857 = $854 ^ $856;
  $858 = (HEAP32[tempDoublePtr>>2]=$857,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $859 = (($2) + 4|0);
  $860 = Math_fround(HEAPF32[$859>>2]);
  $861 = (HEAPF32[tempDoublePtr>>2]=$860,HEAP32[tempDoublePtr>>2]|0);
  $862 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $863 = $862 & -2147483648;
  $864 = $861 ^ $863;
  $865 = (HEAP32[tempDoublePtr>>2]=$864,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $866 = (($2) + 8|0);
  $867 = Math_fround(HEAPF32[$866>>2]);
  $868 = (HEAPF32[tempDoublePtr>>2]=$867,HEAP32[tempDoublePtr>>2]|0);
  $869 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $870 = $869 & -2147483648;
  $871 = $868 ^ $870;
  $872 = (HEAP32[tempDoublePtr>>2]=$871,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $873 = Math_fround($858 * $872);
  $874 = Math_fround($865 - $873);
  $875 = Math_fround($858 * $865);
  $876 = Math_fround($875 + $872);
  $877 = Math_fround($858 * $858);
  $878 = Math_fround($874 * $874);
  $879 = Math_fround($876 * $876);
  $880 = Math_fround($877 + $878);
  $881 = Math_fround($879 + Math_fround(1.0));
  $882 = Math_fround($881 + $880);
  $883 = (Math_fround(Math_sqrt((Math_fround($882)))));
  $884 = Math_fround(Math_fround(1.0) / $883);
  $885 = Math_fround($858 * $884);
  $886 = Math_fround($884 * $874);
  $887 = Math_fround($884 * $876);
  $992 = $886;$994 = $884;$996 = $887;$998 = $885;
 } else if ((($75|0) == 1)) {
  $679 = $54 > Math_fround(0.0);
  $680 = $56 > Math_fround(0.0);
  $681 = $58 > Math_fround(0.0);
  $682 = $60 > Math_fround(0.0);
  $683 = Math_fround($54 * $583);
  $684 = Math_fround(-$683);
  $685 = Math_fround($56 * $580);
  $686 = Math_fround(-$685);
  $687 = Math_fround($58 * $581);
  $688 = Math_fround(-$687);
  $689 = Math_fround($60 * $690);
  $691 = Math_fround(-$689);
  $692 = $54 < Math_fround(0.0);
  $693 = $56 < Math_fround(0.0);
  $694 = $58 < Math_fround(0.0);
  $695 = $60 < Math_fround(0.0);
  $696 = (HEAPF32[tempDoublePtr>>2]=$583,HEAP32[tempDoublePtr>>2]|0);
  $697 = $679 ? $696 : 0;
  $698 = (HEAPF32[tempDoublePtr>>2]=$684,HEAP32[tempDoublePtr>>2]|0);
  $699 = $692 ? $698 : $697;
  $700 = $680 ? $$in5 : 0;
  $701 = (HEAPF32[tempDoublePtr>>2]=$686,HEAP32[tempDoublePtr>>2]|0);
  $702 = $693 ? $701 : $700;
  $703 = $681 ? $$in : 0;
  $704 = (HEAPF32[tempDoublePtr>>2]=$688,HEAP32[tempDoublePtr>>2]|0);
  $705 = $694 ? $704 : $703;
  $706 = (HEAPF32[tempDoublePtr>>2]=$690,HEAP32[tempDoublePtr>>2]|0);
  $707 = $682 ? $706 : 0;
  $708 = (HEAPF32[tempDoublePtr>>2]=$691,HEAP32[tempDoublePtr>>2]|0);
  $709 = $695 ? $708 : $707;
  $710 = $62 < Math_fround(0.0);
  $711 = $64 < Math_fround(0.0);
  $712 = $66 < Math_fround(0.0);
  $713 = $68 < Math_fround(0.0);
  $714 = Math_fround($62 * $583);
  $715 = Math_fround($64 * $580);
  $716 = Math_fround($66 * $581);
  $717 = Math_fround($68 * $690);
  $718 = $62 > Math_fround(0.0);
  $719 = $64 > Math_fround(0.0);
  $720 = $66 > Math_fround(0.0);
  $721 = $68 > Math_fround(0.0);
  $722 = $710 ? $696 : 0;
  $723 = (HEAPF32[tempDoublePtr>>2]=$714,HEAP32[tempDoublePtr>>2]|0);
  $724 = $718 ? $723 : $722;
  $725 = $711 ? $$in5 : 0;
  $726 = (HEAPF32[tempDoublePtr>>2]=$715,HEAP32[tempDoublePtr>>2]|0);
  $727 = $719 ? $726 : $725;
  $728 = $712 ? $$in : 0;
  $729 = (HEAPF32[tempDoublePtr>>2]=$716,HEAP32[tempDoublePtr>>2]|0);
  $730 = $720 ? $729 : $728;
  $731 = $713 ? $706 : 0;
  $732 = (HEAPF32[tempDoublePtr>>2]=$717,HEAP32[tempDoublePtr>>2]|0);
  $733 = $721 ? $732 : $731;
  $734 = $583 < Math_fround(0.0);
  $735 = $580 < Math_fround(0.0);
  $736 = $581 < Math_fround(0.0);
  $737 = $690 < Math_fround(0.0);
  $738 = $734 ? $699 : $724;
  $739 = (HEAP32[tempDoublePtr>>2]=$738,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $740 = $735 ? $702 : $727;
  $741 = (HEAP32[tempDoublePtr>>2]=$740,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $742 = $736 ? $705 : $730;
  $743 = (HEAP32[tempDoublePtr>>2]=$742,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $744 = $737 ? $709 : $733;
  $745 = (HEAP32[tempDoublePtr>>2]=$744,Math_fround(HEAPF32[tempDoublePtr>>2]));
  HEAPF32[$1>>2] = $739;
  $746 = (($1) + 4|0);
  HEAPF32[$746>>2] = $741;
  $747 = (($1) + 8|0);
  HEAPF32[$747>>2] = $743;
  $748 = (($1) + 12|0);
  HEAPF32[$748>>2] = $745;
  __ZN4mathL7halfTanERKNS_7_float4E19358($0,$1);
  $749 = Math_fround(HEAPF32[$0>>2]);
  $750 = (HEAPF32[tempDoublePtr>>2]=$749,HEAP32[tempDoublePtr>>2]|0);
  $751 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $752 = $751 & -2147483648;
  $753 = $750 ^ $752;
  $754 = (HEAP32[tempDoublePtr>>2]=$753,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $755 = (($0) + 4|0);
  $756 = Math_fround(HEAPF32[$755>>2]);
  $757 = (HEAPF32[tempDoublePtr>>2]=$756,HEAP32[tempDoublePtr>>2]|0);
  $758 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $759 = $758 & -2147483648;
  $760 = $757 ^ $759;
  $761 = (HEAP32[tempDoublePtr>>2]=$760,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $762 = (($0) + 8|0);
  $763 = Math_fround(HEAPF32[$762>>2]);
  $764 = (HEAPF32[tempDoublePtr>>2]=$763,HEAP32[tempDoublePtr>>2]|0);
  $765 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $766 = $765 & -2147483648;
  $767 = $764 ^ $766;
  $768 = (HEAP32[tempDoublePtr>>2]=$767,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $769 = Math_fround($754 * $768);
  $770 = Math_fround($761 + $769);
  $771 = Math_fround($754 * $761);
  $772 = Math_fround($768 - $771);
  $773 = Math_fround($754 * $754);
  $774 = Math_fround($770 * $770);
  $775 = Math_fround($772 * $772);
  $776 = Math_fround($773 + $774);
  $777 = Math_fround($775 + Math_fround(1.0));
  $778 = Math_fround($777 + $776);
  $779 = (Math_fround(Math_sqrt((Math_fround($778)))));
  $780 = Math_fround(Math_fround(1.0) / $779);
  $781 = Math_fround($754 * $780);
  $782 = Math_fround($780 * $770);
  $783 = Math_fround($780 * $772);
  $992 = $782;$994 = $780;$996 = $783;$998 = $781;
 } else {
  $888 = $54 > Math_fround(0.0);
  $889 = $56 > Math_fround(0.0);
  $890 = $58 > Math_fround(0.0);
  $891 = $60 > Math_fround(0.0);
  $892 = Math_fround($54 * $583);
  $893 = Math_fround(-$892);
  $894 = Math_fround($56 * $580);
  $895 = Math_fround(-$894);
  $896 = Math_fround($58 * $581);
  $897 = Math_fround(-$896);
  $898 = Math_fround($60 * $690);
  $899 = Math_fround(-$898);
  $900 = $54 < Math_fround(0.0);
  $901 = $56 < Math_fround(0.0);
  $902 = $58 < Math_fround(0.0);
  $903 = $60 < Math_fround(0.0);
  $904 = (HEAPF32[tempDoublePtr>>2]=$583,HEAP32[tempDoublePtr>>2]|0);
  $905 = $888 ? $904 : 0;
  $906 = (HEAPF32[tempDoublePtr>>2]=$893,HEAP32[tempDoublePtr>>2]|0);
  $907 = $900 ? $906 : $905;
  $908 = $889 ? $$in5 : 0;
  $909 = (HEAPF32[tempDoublePtr>>2]=$895,HEAP32[tempDoublePtr>>2]|0);
  $910 = $901 ? $909 : $908;
  $911 = $890 ? $$in : 0;
  $912 = (HEAPF32[tempDoublePtr>>2]=$897,HEAP32[tempDoublePtr>>2]|0);
  $913 = $902 ? $912 : $911;
  $914 = (HEAPF32[tempDoublePtr>>2]=$690,HEAP32[tempDoublePtr>>2]|0);
  $915 = $891 ? $914 : 0;
  $916 = (HEAPF32[tempDoublePtr>>2]=$899,HEAP32[tempDoublePtr>>2]|0);
  $917 = $903 ? $916 : $915;
  $918 = $62 < Math_fround(0.0);
  $919 = $64 < Math_fround(0.0);
  $920 = $66 < Math_fround(0.0);
  $921 = $68 < Math_fround(0.0);
  $922 = Math_fround($62 * $583);
  $923 = Math_fround($64 * $580);
  $924 = Math_fround($66 * $581);
  $925 = Math_fround($68 * $690);
  $926 = $62 > Math_fround(0.0);
  $927 = $64 > Math_fround(0.0);
  $928 = $66 > Math_fround(0.0);
  $929 = $68 > Math_fround(0.0);
  $930 = $918 ? $904 : 0;
  $931 = (HEAPF32[tempDoublePtr>>2]=$922,HEAP32[tempDoublePtr>>2]|0);
  $932 = $926 ? $931 : $930;
  $933 = $919 ? $$in5 : 0;
  $934 = (HEAPF32[tempDoublePtr>>2]=$923,HEAP32[tempDoublePtr>>2]|0);
  $935 = $927 ? $934 : $933;
  $936 = $920 ? $$in : 0;
  $937 = (HEAPF32[tempDoublePtr>>2]=$924,HEAP32[tempDoublePtr>>2]|0);
  $938 = $928 ? $937 : $936;
  $939 = $921 ? $914 : 0;
  $940 = (HEAPF32[tempDoublePtr>>2]=$925,HEAP32[tempDoublePtr>>2]|0);
  $941 = $929 ? $940 : $939;
  $942 = $583 < Math_fround(0.0);
  $943 = $580 < Math_fround(0.0);
  $944 = $581 < Math_fround(0.0);
  $945 = $690 < Math_fround(0.0);
  $946 = $942 ? $907 : $932;
  $947 = (HEAP32[tempDoublePtr>>2]=$946,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $948 = $943 ? $910 : $935;
  $949 = (HEAP32[tempDoublePtr>>2]=$948,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $950 = $944 ? $913 : $938;
  $951 = (HEAP32[tempDoublePtr>>2]=$950,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $952 = $945 ? $917 : $941;
  $953 = (HEAP32[tempDoublePtr>>2]=$952,Math_fround(HEAPF32[tempDoublePtr>>2]));
  HEAPF32[$5>>2] = $947;
  $954 = (($5) + 4|0);
  HEAPF32[$954>>2] = $949;
  $955 = (($5) + 8|0);
  HEAPF32[$955>>2] = $951;
  $956 = (($5) + 12|0);
  HEAPF32[$956>>2] = $953;
  __ZN4mathL7halfTanERKNS_7_float4E19358($4,$5);
  $957 = Math_fround(HEAPF32[$4>>2]);
  $958 = (HEAPF32[tempDoublePtr>>2]=$957,HEAP32[tempDoublePtr>>2]|0);
  $959 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $960 = $959 & -2147483648;
  $961 = $958 ^ $960;
  $962 = (HEAP32[tempDoublePtr>>2]=$961,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $963 = (($4) + 4|0);
  $964 = Math_fround(HEAPF32[$963>>2]);
  $965 = (HEAPF32[tempDoublePtr>>2]=$964,HEAP32[tempDoublePtr>>2]|0);
  $966 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $967 = $966 & -2147483648;
  $968 = $965 ^ $967;
  $969 = (HEAP32[tempDoublePtr>>2]=$968,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $970 = (($4) + 8|0);
  $971 = Math_fround(HEAPF32[$970>>2]);
  $972 = (HEAPF32[tempDoublePtr>>2]=$971,HEAP32[tempDoublePtr>>2]|0);
  $973 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $974 = $973 & -2147483648;
  $975 = $972 ^ $974;
  $976 = (HEAP32[tempDoublePtr>>2]=$975,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $977 = Math_fround($962 * $962);
  $978 = Math_fround($969 * $969);
  $979 = Math_fround($976 * $976);
  $980 = Math_fround($977 + $978);
  $981 = Math_fround($979 + Math_fround(1.0));
  $982 = Math_fround($980 + $981);
  $983 = (Math_fround(Math_sqrt((Math_fround($982)))));
  $984 = Math_fround(Math_fround(1.0) / $983);
  $985 = Math_fround($962 * $984);
  $986 = Math_fround($969 * $984);
  $987 = Math_fround($984 * $976);
  $992 = $986;$994 = $984;$996 = $987;$998 = $985;
 }
 $988 = Math_fround($38 * Math_fround(-1.0));
 $989 = Math_fround($40 * Math_fround(-1.0));
 $990 = Math_fround($42 * Math_fround(-1.0));
 $991 = Math_fround($988 * $992);
 $993 = Math_fround($44 * $994);
 $995 = Math_fround($989 * $996);
 $997 = Math_fround($990 * $998);
 $999 = Math_fround($990 * $994);
 $1000 = Math_fround($988 * $998);
 $1001 = Math_fround($990 * $992);
 $1002 = Math_fround($988 * $996);
 $1003 = Math_fround($991 - $999);
 $1004 = Math_fround($993 - $1000);
 $1005 = Math_fround($995 - $1001);
 $1006 = Math_fround($997 - $1002);
 $1007 = Math_fround($44 * $996);
 $1008 = Math_fround($990 * $996);
 $1009 = Math_fround($988 * $994);
 $1010 = Math_fround($989 * $994);
 $1011 = Math_fround($1003 - $1007);
 $1012 = Math_fround($1004 - $1008);
 $1013 = Math_fround($1005 - $1009);
 $1014 = Math_fround($1006 - $1010);
 $1015 = Math_fround($989 * $998);
 $1016 = Math_fround($989 * $992);
 $1017 = Math_fround($44 * $998);
 $1018 = Math_fround($44 * $992);
 $1019 = Math_fround($1011 - $1015);
 $1020 = Math_fround($1012 - $1016);
 $1021 = Math_fround($1013 - $1017);
 $1022 = Math_fround($1014 - $1018);
 $1023 = Math_fround($1021 * Math_fround(-1.0));
 $1024 = Math_fround($1022 * Math_fround(-1.0));
 $1025 = Math_fround($1019 * Math_fround(-1.0));
 $1026 = Math_fround($32 * $1023);
 $1027 = Math_fround($36 * $1020);
 $1028 = Math_fround($34 * $1024);
 $1029 = Math_fround($30 * $1025);
 $1030 = Math_fround($36 * $1025);
 $1031 = Math_fround($30 * $1023);
 $1032 = Math_fround($32 * $1025);
 $1033 = Math_fround($34 * $1023);
 $1034 = Math_fround($1026 - $1030);
 $1035 = Math_fround($1027 - $1031);
 $1036 = Math_fround($1028 - $1032);
 $1037 = Math_fround($1029 - $1033);
 $1038 = Math_fround($34 * $1020);
 $1039 = Math_fround($34 * $1025);
 $1040 = Math_fround($36 * $1023);
 $1041 = Math_fround($36 * $1024);
 $1042 = Math_fround($1034 - $1038);
 $1043 = Math_fround($1035 - $1039);
 $1044 = Math_fround($1036 - $1040);
 $1045 = Math_fround($1037 - $1041);
 $1046 = Math_fround($30 * $1024);
 $1047 = Math_fround($32 * $1024);
 $1048 = Math_fround($30 * $1020);
 $1049 = Math_fround($32 * $1020);
 $1050 = Math_fround($1042 - $1046);
 $1051 = Math_fround($1043 - $1047);
 $1052 = Math_fround($1044 - $1048);
 $1053 = Math_fround($1045 - $1049);
 $1054 = Math_fround($1052 * Math_fround(-1.0));
 $1055 = Math_fround($1053 * Math_fround(-1.0));
 $1056 = Math_fround($1050 * Math_fround(-1.0));
 $1057 = Math_fround($1054 * $1054);
 $1058 = Math_fround($1055 * $1055);
 $1059 = Math_fround($1056 * $1056);
 $1060 = Math_fround($1051 * $1051);
 $1061 = Math_fround($1058 + $1057);
 $1062 = Math_fround($1060 + $1059);
 $1063 = Math_fround($1062 + $1061);
 $1064 = (Math_fround(Math_sqrt((Math_fround($1063)))));
 $1065 = Math_fround(Math_fround(1.0) / $1064);
 $1066 = Math_fround($1065 * $1054);
 $1067 = Math_fround($1065 * $1055);
 $1068 = Math_fround($1065 * $1056);
 $1069 = Math_fround($1065 * $1051);
 $1070 = ((($586) + (($7*48)|0)|0) + 16|0);
 HEAPF32[$1070>>2] = $1066;
 $1071 = ((($586) + (($7*48)|0)|0) + 20|0);
 HEAPF32[$1071>>2] = $1067;
 $1072 = ((($586) + (($7*48)|0)|0) + 24|0);
 HEAPF32[$1072>>2] = $1068;
 $1073 = ((($586) + (($7*48)|0)|0) + 28|0);
 HEAPF32[$1073>>2] = $1069;
 $1074 = HEAP32[$10>>2]|0;
 $1075 = (($1074) + ($11))|0;
 $1076 = $1075;
 HEAP32[$86>>2] = $1076;
 $1077 = HEAP32[$87>>2]|0;
 $1078 = (($1077) + ($88))|0;
 $1079 = $1078;
 HEAP32[$92>>2] = $1079;
 $1080 = ((($1079) + (($7*48)|0)|0) + 16|0);
 __ZN7mecanim8skeleton13SkeletonAlignEPKNS0_8SkeletonERKN4math7_float4ES7_i($1076,$pq,$1080,$7);
 $1081 = HEAP32[$10>>2]|0;
 $1082 = (($1081) + ($11))|0;
 $1083 = $1082;
 HEAP32[$86>>2] = $1083;
 __ZN7mecanim8skeleton26SkeletonPoseComputeGlobalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1083,$apSkeletonPose,$apSkeletonPoseWs,$9,$7);
 $1084 = HEAP32[$76>>2]|0;
 $1085 = (($1084) + ($77))|0;
 $1086 = $1085;
 HEAP32[$81>>2] = $1086;
 $1087 = ((($1086) + (($9*48)|0)|0) + 16|0);
 HEAPF32[$1087>>2] = $98;
 $1088 = ((($1086) + (($9*48)|0)|0) + 20|0);
 HEAPF32[$1088>>2] = $100;
 $1089 = ((($1086) + (($9*48)|0)|0) + 24|0);
 HEAPF32[$1089>>2] = $102;
 $1090 = ((($1086) + (($9*48)|0)|0) + 28|0);
 HEAPF32[$1090>>2] = $104;
 $1091 = HEAP32[$10>>2]|0;
 $1092 = (($1091) + ($11))|0;
 $1093 = $1092;
 HEAP32[$86>>2] = $1093;
 __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1093,$apSkeletonPoseWs,$apSkeletonPose,$9,$9);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human14HumanFixEndDoFEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iifi($apHuman,$apSkeletonPose,$apSkeletonPoseWs,$aPIndex,$aCIndex,$maxError,$maxIter) {
 $apHuman = $apHuman|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $apSkeletonPoseWs = $apSkeletonPoseWs|0;
 $aPIndex = $aPIndex|0;
 $aCIndex = $aCIndex|0;
 $maxError = Math_fround($maxError);
 $maxIter = $maxIter|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0);
 var $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0);
 var $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0);
 var $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0;
 var $200 = 0, $201 = Math_fround(0), $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = 0, $235 = 0, $236 = 0;
 var $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0);
 var $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = Math_fround(0), $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0);
 var $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0);
 var $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = Math_fround(0), $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0);
 var $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0);
 var $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0), $379 = Math_fround(0), $38 = Math_fround(0), $380 = Math_fround(0);
 var $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0);
 var $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = 0, $430 = Math_fround(0), $431 = Math_fround(0), $432 = Math_fround(0), $433 = Math_fround(0), $434 = Math_fround(0);
 var $435 = Math_fround(0), $436 = Math_fround(0), $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = Math_fround(0), $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = Math_fround(0), $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = Math_fround(0), $463 = 0, $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0);
 var $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = Math_fround(0), $486 = Math_fround(0), $487 = Math_fround(0), $488 = Math_fround(0), $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = Math_fround(0), $494 = Math_fround(0), $495 = Math_fround(0), $496 = Math_fround(0), $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = 0;
 var $507 = Math_fround(0), $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = Math_fround(0), $513 = 0, $514 = Math_fround(0), $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0);
 var $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0;
 var $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = Math_fround(0), $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = 0;
 var $561 = 0, $562 = Math_fround(0), $563 = 0, $564 = Math_fround(0), $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = Math_fround(0), $57 = 0, $570 = Math_fround(0), $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = Math_fround(0), $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0);
 var $58 = Math_fround(0), $580 = Math_fround(0), $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0);
 var $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0);
 var $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0);
 var $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0);
 var $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = 0, $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = 0, $668 = 0, $669 = 0;
 var $67 = 0, $670 = 0, $671 = Math_fround(0), $672 = Math_fround(0), $673 = 0, $674 = Math_fround(0), $675 = Math_fround(0), $676 = 0, $677 = Math_fround(0), $678 = Math_fround(0), $679 = 0, $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0);
 var $688 = Math_fround(0), $689 = Math_fround(0), $69 = Math_fround(0), $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0);
 var $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = Math_fround(0), $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0), $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0);
 var $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = Math_fround(0), $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0), $733 = Math_fround(0), $734 = Math_fround(0), $735 = Math_fround(0), $736 = Math_fround(0), $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0);
 var $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = Math_fround(0), $745 = Math_fround(0), $746 = Math_fround(0), $747 = Math_fround(0), $748 = Math_fround(0), $749 = Math_fround(0), $75 = Math_fround(0), $750 = Math_fround(0), $751 = Math_fround(0), $752 = Math_fround(0), $753 = 0, $754 = Math_fround(0), $755 = Math_fround(0), $756 = Math_fround(0), $757 = Math_fround(0), $758 = Math_fround(0), $759 = Math_fround(0);
 var $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0;
 var $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0), $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0);
 var $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = Math_fround(0), $801 = Math_fround(0), $802 = 0, $803 = 0, $804 = 0, $805 = Math_fround(0), $806 = Math_fround(0), $807 = Math_fround(0), $808 = Math_fround(0), $809 = Math_fround(0), $81 = Math_fround(0), $810 = Math_fround(0), $811 = Math_fround(0), $812 = Math_fround(0);
 var $813 = Math_fround(0), $814 = Math_fround(0), $815 = Math_fround(0), $816 = Math_fround(0), $817 = Math_fround(0), $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = Math_fround(0), $821 = Math_fround(0), $822 = Math_fround(0), $823 = Math_fround(0), $824 = Math_fround(0), $825 = Math_fround(0), $826 = Math_fround(0), $827 = Math_fround(0), $828 = Math_fround(0), $829 = Math_fround(0), $83 = Math_fround(0), $830 = Math_fround(0);
 var $831 = Math_fround(0), $832 = Math_fround(0), $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = Math_fround(0), $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = Math_fround(0), $843 = Math_fround(0), $844 = Math_fround(0), $845 = Math_fround(0), $846 = Math_fround(0), $847 = Math_fround(0), $848 = Math_fround(0), $849 = Math_fround(0);
 var $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = 0, $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0), $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0);
 var $868 = Math_fround(0), $869 = Math_fround(0), $87 = Math_fround(0), $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0;
 var $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = Math_fround(0), $890 = 0, $891 = Math_fround(0), $892 = Math_fround(0), $893 = 0, $894 = Math_fround(0), $895 = Math_fround(0), $896 = 0, $897 = Math_fround(0), $898 = Math_fround(0), $899 = 0, $9 = 0, $90 = 0, $900 = Math_fround(0), $901 = Math_fround(0), $902 = Math_fround(0);
 var $903 = Math_fround(0), $904 = Math_fround(0), $905 = Math_fround(0), $906 = Math_fround(0), $907 = Math_fround(0), $908 = Math_fround(0), $909 = Math_fround(0), $91 = Math_fround(0), $910 = Math_fround(0), $911 = Math_fround(0), $912 = Math_fround(0), $913 = Math_fround(0), $914 = Math_fround(0), $915 = Math_fround(0), $916 = Math_fround(0), $917 = Math_fround(0), $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0);
 var $921 = Math_fround(0), $922 = Math_fround(0), $923 = Math_fround(0), $924 = Math_fround(0), $925 = Math_fround(0), $926 = Math_fround(0), $927 = Math_fround(0), $928 = Math_fround(0), $929 = Math_fround(0), $93 = Math_fround(0), $930 = Math_fround(0), $931 = Math_fround(0), $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = Math_fround(0), $937 = Math_fround(0), $938 = 0, $939 = Math_fround(0);
 var $94 = 0, $940 = Math_fround(0), $941 = 0, $942 = Math_fround(0), $943 = Math_fround(0), $944 = 0, $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = Math_fround(0), $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0), $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0);
 var $958 = Math_fround(0), $959 = Math_fround(0), $96 = 0, $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0), $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0);
 var $976 = Math_fround(0), $977 = Math_fround(0), $978 = Math_fround(0), $979 = Math_fround(0), $98 = 0, $980 = Math_fround(0), $981 = Math_fround(0), $982 = Math_fround(0), $983 = Math_fround(0), $984 = Math_fround(0), $985 = Math_fround(0), $986 = Math_fround(0), $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0;
 var $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $brmerge = 0, $iter$0$ph60 = 0, $or$cond1 = 0, $pq = 0, $prevError$0$ph62 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 96|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = sp + 48|0;
 $5 = sp + 64|0;
 $pq = sp + 80|0;
 $6 = ((($apHuman) + ($aPIndex<<2)|0) + 104|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($apHuman) + ($aCIndex<<2)|0) + 104|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($apHuman) + 48|0);
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($14) + 4|0);
 $16 = $15;
 $17 = HEAP32[$15>>2]|0;
 $18 = (($16) + ($17))|0;
 $19 = $18;
 $20 = (($19) + ($7<<3)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($14) + 24|0);
 $23 = ((($19) + ($7<<3)|0) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $22;
 $26 = HEAP32[$22>>2]|0;
 $27 = (($26) + ($25))|0;
 $28 = $27;
 $29 = (($28) + (($24*88)|0)|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = ((($28) + (($24*88)|0)|0) + 4|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = ((($28) + (($24*88)|0)|0) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = ((($28) + (($24*88)|0)|0) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = ((($28) + (($24*88)|0)|0) + 16|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = ((($28) + (($24*88)|0)|0) + 20|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = ((($28) + (($24*88)|0)|0) + 24|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = ((($28) + (($24*88)|0)|0) + 28|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = ((($28) + (($24*88)|0)|0) + 32|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = ((($28) + (($24*88)|0)|0) + 36|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = ((($28) + (($24*88)|0)|0) + 40|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = ((($28) + (($24*88)|0)|0) + 64|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = ((($28) + (($24*88)|0)|0) + 68|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = ((($28) + (($24*88)|0)|0) + 72|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = ((($28) + (($24*88)|0)|0) + 76|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = ((($28) + (($24*88)|0)|0) + 80|0);
 $60 = $59;
 $61 = $60;
 $62 = HEAP32[$61>>2]|0;
 $63 = (($60) + 4)|0;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($19) + ($9<<3)|0) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($28) + (($67*88)|0)|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = ((($28) + (($67*88)|0)|0) + 4|0);
 $71 = Math_fround(HEAPF32[$70>>2]);
 $72 = ((($28) + (($67*88)|0)|0) + 8|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = ((($28) + (($67*88)|0)|0) + 12|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = ((($28) + (($67*88)|0)|0) + 16|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = ((($28) + (($67*88)|0)|0) + 20|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = ((($28) + (($67*88)|0)|0) + 24|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = ((($28) + (($67*88)|0)|0) + 28|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = ((($28) + (($67*88)|0)|0) + 32|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = ((($28) + (($67*88)|0)|0) + 36|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = ((($28) + (($67*88)|0)|0) + 40|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = ((($28) + (($67*88)|0)|0) + 64|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = ((($28) + (($67*88)|0)|0) + 68|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = ((($28) + (($67*88)|0)|0) + 72|0);
 $95 = Math_fround(HEAPF32[$94>>2]);
 $96 = ((($28) + (($67*88)|0)|0) + 76|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = ((($28) + (($67*88)|0)|0) + 80|0);
 $99 = $98;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = (($99) + 4)|0;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = (($apSkeletonPoseWs) + 4|0);
 $106 = $105;
 $107 = HEAP32[$105>>2]|0;
 $108 = (($107) + ($106))|0;
 $109 = $108;
 $110 = (($apSkeletonPoseWs) + 8|0);
 HEAP32[$110>>2] = $109;
 $111 = ((($109) + (($21*48)|0)|0) + 16|0);
 HEAPF32[$111>>2] = Math_fround(0.0);
 $112 = ((($109) + (($21*48)|0)|0) + 20|0);
 HEAPF32[$112>>2] = Math_fround(0.0);
 $113 = ((($109) + (($21*48)|0)|0) + 24|0);
 HEAPF32[$113>>2] = Math_fround(0.0);
 $114 = ((($109) + (($21*48)|0)|0) + 28|0);
 HEAPF32[$114>>2] = Math_fround(1.0);
 $115 = HEAP32[$10>>2]|0;
 $116 = (($115) + ($11))|0;
 $117 = $116;
 $118 = (($apHuman) + 52|0);
 HEAP32[$118>>2] = $117;
 __ZN7mecanim8skeleton26SkeletonPoseComputeGlobalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($117,$apSkeletonPose,$apSkeletonPoseWs,$9,$7);
 $119 = (($apSkeletonPose) + 4|0);
 $120 = $119;
 $121 = HEAP32[$119>>2]|0;
 $122 = (($121) + ($120))|0;
 $123 = $122;
 $124 = (($apSkeletonPose) + 8|0);
 HEAP32[$124>>2] = $123;
 $125 = ((($123) + (($7*48)|0)|0) + 16|0);
 ;HEAP32[$pq+0>>2]=HEAP32[$125+0>>2]|0;HEAP32[$pq+4>>2]=HEAP32[$125+4>>2]|0;HEAP32[$pq+8>>2]=HEAP32[$125+8>>2]|0;HEAP32[$pq+12>>2]=HEAP32[$125+12>>2]|0;
 $126 = HEAP32[$105>>2]|0;
 $127 = (($126) + ($106))|0;
 $128 = $127;
 HEAP32[$110>>2] = $128;
 $129 = ((($128) + (($9*48)|0)|0) + 16|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = ((($128) + (($9*48)|0)|0) + 20|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = ((($128) + (($9*48)|0)|0) + 24|0);
 $134 = Math_fround(HEAPF32[$133>>2]);
 $135 = ((($128) + (($9*48)|0)|0) + 28|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 if ((($65|0) == 1)) {
  $172 = Math_fround($52 * Math_fround(0.0));
  $173 = Math_fround($54 * Math_fround(0.0));
  $174 = Math_fround($56 * Math_fround(0.0));
  $175 = Math_fround($58 * Math_fround(0.0));
  $176 = $52 > Math_fround(0.0);
  $177 = $54 > Math_fround(0.0);
  $178 = $56 > Math_fround(0.0);
  $179 = $58 > Math_fround(0.0);
  $180 = $176 ? $172 : Math_fround(0.0);
  $181 = $177 ? $173 : Math_fround(0.0);
  $182 = $178 ? $174 : Math_fround(0.0);
  $183 = $179 ? $175 : Math_fround(0.0);
  HEAPF32[$1>>2] = $180;
  $184 = (($1) + 4|0);
  HEAPF32[$184>>2] = $181;
  $185 = (($1) + 8|0);
  HEAPF32[$185>>2] = $182;
  $186 = (($1) + 12|0);
  HEAPF32[$186>>2] = $183;
  __ZN4mathL7halfTanERKNS_7_float4E19358($0,$1);
  $187 = Math_fround(HEAPF32[$0>>2]);
  $188 = (HEAPF32[tempDoublePtr>>2]=$187,HEAP32[tempDoublePtr>>2]|0);
  $189 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $190 = $189 & -2147483648;
  $191 = $188 ^ $190;
  $192 = (HEAP32[tempDoublePtr>>2]=$191,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $193 = (($0) + 4|0);
  $194 = Math_fround(HEAPF32[$193>>2]);
  $195 = (HEAPF32[tempDoublePtr>>2]=$194,HEAP32[tempDoublePtr>>2]|0);
  $196 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $197 = $196 & -2147483648;
  $198 = $195 ^ $197;
  $199 = (HEAP32[tempDoublePtr>>2]=$198,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $200 = (($0) + 8|0);
  $201 = Math_fround(HEAPF32[$200>>2]);
  $202 = (HEAPF32[tempDoublePtr>>2]=$201,HEAP32[tempDoublePtr>>2]|0);
  $203 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $204 = $203 & -2147483648;
  $205 = $202 ^ $204;
  $206 = (HEAP32[tempDoublePtr>>2]=$205,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $207 = Math_fround($192 * $206);
  $208 = Math_fround($199 + $207);
  $209 = Math_fround($192 * $199);
  $210 = Math_fround($206 - $209);
  $211 = Math_fround($192 * $192);
  $212 = Math_fround($208 * $208);
  $213 = Math_fround($210 * $210);
  $214 = Math_fround($211 + $212);
  $215 = Math_fround($213 + Math_fround(1.0));
  $216 = Math_fround($215 + $214);
  $217 = (Math_fround(Math_sqrt((Math_fround($216)))));
  $218 = Math_fround(Math_fround(1.0) / $217);
  $219 = Math_fround($192 * $218);
  $220 = Math_fround($218 * $208);
  $221 = Math_fround($218 * $210);
  $322 = $220;$324 = $218;$326 = $221;$328 = $219;
 } else if ((($65|0) == 3)) {
  $137 = (Math_fround(+(_roundf(0.0))));
  $138 = Math_fround(Math_fround(0.0) - $137);
  $139 = (Math_fround(Math_abs((Math_fround($138)))));
  $140 = Math_fround(Math_fround(0.25) - $139);
  $141 = Math_fround($140 * $140);
  $142 = Math_fround($141 * $141);
  $143 = Math_fround($141 * Math_fround(-41.283184051513671875));
  $144 = Math_fround($143 + Math_fround(6.28318548202514648438));
  $145 = Math_fround($142 * Math_fround(76.03546142578125));
  $146 = Math_fround($144 + $145);
  $147 = Math_fround($140 * $146);
  $148 = (Math_fround(+(_roundf(-0.25))));
  $149 = Math_fround(Math_fround(-0.25) - $148);
  $150 = (Math_fround(Math_abs((Math_fround($149)))));
  $151 = Math_fround(Math_fround(0.25) - $150);
  $152 = Math_fround($151 * $151);
  $153 = Math_fround($152 * $152);
  $154 = Math_fround($152 * Math_fround(-41.283184051513671875));
  $155 = Math_fround($154 + Math_fround(6.28318548202514648438));
  $156 = Math_fround($153 * Math_fround(76.03546142578125));
  $157 = Math_fround($155 + $156);
  $158 = Math_fround($151 * $157);
  $159 = Math_fround($147 * $158);
  $160 = Math_fround($158 * $158);
  $161 = Math_fround($147 * $147);
  $162 = Math_fround($147 * $159);
  $163 = Math_fround($147 * $160);
  $164 = Math_fround($147 * $161);
  $165 = Math_fround($158 * Math_fround(-1.0));
  $166 = Math_fround($165 * $159);
  $167 = Math_fround($161 * $158);
  $168 = Math_fround($158 * $160);
  $169 = Math_fround($162 + $166);
  $170 = Math_fround($167 + $163);
  $171 = Math_fround($164 + $168);
  $322 = $170;$324 = $171;$326 = $169;$328 = $169;
 } else if ((($65|0) == 2)) {
  $222 = Math_fround($52 * Math_fround(0.0));
  $223 = Math_fround($54 * Math_fround(0.0));
  $224 = Math_fround($56 * Math_fround(0.0));
  $225 = Math_fround($58 * Math_fround(0.0));
  $226 = $52 > Math_fround(0.0);
  $227 = $54 > Math_fround(0.0);
  $228 = $56 > Math_fround(0.0);
  $229 = $58 > Math_fround(0.0);
  $230 = $226 ? $222 : Math_fround(0.0);
  $231 = $227 ? $223 : Math_fround(0.0);
  $232 = $228 ? $224 : Math_fround(0.0);
  $233 = $229 ? $225 : Math_fround(0.0);
  HEAPF32[$3>>2] = $230;
  $234 = (($3) + 4|0);
  HEAPF32[$234>>2] = $231;
  $235 = (($3) + 8|0);
  HEAPF32[$235>>2] = $232;
  $236 = (($3) + 12|0);
  HEAPF32[$236>>2] = $233;
  __ZN4mathL7halfTanERKNS_7_float4E19358($2,$3);
  $237 = Math_fround(HEAPF32[$2>>2]);
  $238 = (HEAPF32[tempDoublePtr>>2]=$237,HEAP32[tempDoublePtr>>2]|0);
  $239 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $240 = $239 & -2147483648;
  $241 = $238 ^ $240;
  $242 = (HEAP32[tempDoublePtr>>2]=$241,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $243 = (($2) + 4|0);
  $244 = Math_fround(HEAPF32[$243>>2]);
  $245 = (HEAPF32[tempDoublePtr>>2]=$244,HEAP32[tempDoublePtr>>2]|0);
  $246 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $247 = $246 & -2147483648;
  $248 = $245 ^ $247;
  $249 = (HEAP32[tempDoublePtr>>2]=$248,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $250 = (($2) + 8|0);
  $251 = Math_fround(HEAPF32[$250>>2]);
  $252 = (HEAPF32[tempDoublePtr>>2]=$251,HEAP32[tempDoublePtr>>2]|0);
  $253 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $254 = $253 & -2147483648;
  $255 = $252 ^ $254;
  $256 = (HEAP32[tempDoublePtr>>2]=$255,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $257 = Math_fround($242 * $256);
  $258 = Math_fround($249 - $257);
  $259 = Math_fround($242 * $249);
  $260 = Math_fround($259 + $256);
  $261 = Math_fround($242 * $242);
  $262 = Math_fround($258 * $258);
  $263 = Math_fround($260 * $260);
  $264 = Math_fround($261 + $262);
  $265 = Math_fround($263 + Math_fround(1.0));
  $266 = Math_fround($265 + $264);
  $267 = (Math_fround(Math_sqrt((Math_fround($266)))));
  $268 = Math_fround(Math_fround(1.0) / $267);
  $269 = Math_fround($242 * $268);
  $270 = Math_fround($268 * $258);
  $271 = Math_fround($268 * $260);
  $322 = $270;$324 = $268;$326 = $271;$328 = $269;
 } else {
  $272 = Math_fround($52 * Math_fround(0.0));
  $273 = Math_fround($54 * Math_fround(0.0));
  $274 = Math_fround($56 * Math_fround(0.0));
  $275 = Math_fround($58 * Math_fround(0.0));
  $276 = $52 > Math_fround(0.0);
  $277 = $54 > Math_fround(0.0);
  $278 = $56 > Math_fround(0.0);
  $279 = $58 > Math_fround(0.0);
  $280 = $276 ? $272 : Math_fround(0.0);
  $281 = $277 ? $273 : Math_fround(0.0);
  $282 = $278 ? $274 : Math_fround(0.0);
  $283 = $279 ? $275 : Math_fround(0.0);
  HEAPF32[$5>>2] = $280;
  $284 = (($5) + 4|0);
  HEAPF32[$284>>2] = $281;
  $285 = (($5) + 8|0);
  HEAPF32[$285>>2] = $282;
  $286 = (($5) + 12|0);
  HEAPF32[$286>>2] = $283;
  __ZN4mathL7halfTanERKNS_7_float4E19358($4,$5);
  $287 = Math_fround(HEAPF32[$4>>2]);
  $288 = (HEAPF32[tempDoublePtr>>2]=$287,HEAP32[tempDoublePtr>>2]|0);
  $289 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
  $290 = $289 & -2147483648;
  $291 = $288 ^ $290;
  $292 = (HEAP32[tempDoublePtr>>2]=$291,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $293 = (($4) + 4|0);
  $294 = Math_fround(HEAPF32[$293>>2]);
  $295 = (HEAPF32[tempDoublePtr>>2]=$294,HEAP32[tempDoublePtr>>2]|0);
  $296 = (HEAPF32[tempDoublePtr>>2]=$48,HEAP32[tempDoublePtr>>2]|0);
  $297 = $296 & -2147483648;
  $298 = $295 ^ $297;
  $299 = (HEAP32[tempDoublePtr>>2]=$298,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $300 = (($4) + 8|0);
  $301 = Math_fround(HEAPF32[$300>>2]);
  $302 = (HEAPF32[tempDoublePtr>>2]=$301,HEAP32[tempDoublePtr>>2]|0);
  $303 = (HEAPF32[tempDoublePtr>>2]=$50,HEAP32[tempDoublePtr>>2]|0);
  $304 = $303 & -2147483648;
  $305 = $302 ^ $304;
  $306 = (HEAP32[tempDoublePtr>>2]=$305,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $307 = Math_fround($292 * $292);
  $308 = Math_fround($299 * $299);
  $309 = Math_fround($306 * $306);
  $310 = Math_fround($307 + $308);
  $311 = Math_fround($309 + Math_fround(1.0));
  $312 = Math_fround($310 + $311);
  $313 = (Math_fround(Math_sqrt((Math_fround($312)))));
  $314 = Math_fround(Math_fround(1.0) / $313);
  $315 = Math_fround($292 * $314);
  $316 = Math_fround($299 * $314);
  $317 = Math_fround($314 * $306);
  $322 = $316;$324 = $314;$326 = $317;$328 = $315;
 }
 $318 = Math_fround($38 * Math_fround(-1.0));
 $319 = Math_fround($40 * Math_fround(-1.0));
 $320 = Math_fround($42 * Math_fround(-1.0));
 $321 = Math_fround($318 * $322);
 $323 = Math_fround($44 * $324);
 $325 = Math_fround($319 * $326);
 $327 = Math_fround($320 * $328);
 $329 = Math_fround($320 * $324);
 $330 = Math_fround($318 * $328);
 $331 = Math_fround($320 * $322);
 $332 = Math_fround($318 * $326);
 $333 = Math_fround($321 - $329);
 $334 = Math_fround($323 - $330);
 $335 = Math_fround($325 - $331);
 $336 = Math_fround($327 - $332);
 $337 = Math_fround($44 * $326);
 $338 = Math_fround($320 * $326);
 $339 = Math_fround($318 * $324);
 $340 = Math_fround($319 * $324);
 $341 = Math_fround($333 - $337);
 $342 = Math_fround($334 - $338);
 $343 = Math_fround($335 - $339);
 $344 = Math_fround($336 - $340);
 $345 = Math_fround($319 * $328);
 $346 = Math_fround($319 * $322);
 $347 = Math_fround($44 * $328);
 $348 = Math_fround($44 * $322);
 $349 = Math_fround($341 - $345);
 $350 = Math_fround($342 - $346);
 $351 = Math_fround($343 - $347);
 $352 = Math_fround($344 - $348);
 $353 = Math_fround($351 * Math_fround(-1.0));
 $354 = Math_fround($352 * Math_fround(-1.0));
 $355 = Math_fround($349 * Math_fround(-1.0));
 $356 = Math_fround($32 * $353);
 $357 = Math_fround($36 * $350);
 $358 = Math_fround($34 * $354);
 $359 = Math_fround($30 * $355);
 $360 = Math_fround($36 * $355);
 $361 = Math_fround($30 * $353);
 $362 = Math_fround($32 * $355);
 $363 = Math_fround($34 * $353);
 $364 = Math_fround($356 - $360);
 $365 = Math_fround($357 - $361);
 $366 = Math_fround($358 - $362);
 $367 = Math_fround($359 - $363);
 $368 = Math_fround($34 * $350);
 $369 = Math_fround($34 * $355);
 $370 = Math_fround($36 * $353);
 $371 = Math_fround($36 * $354);
 $372 = Math_fround($364 - $368);
 $373 = Math_fround($365 - $369);
 $374 = Math_fround($366 - $370);
 $375 = Math_fround($367 - $371);
 $376 = Math_fround($30 * $354);
 $377 = Math_fround($32 * $354);
 $378 = Math_fround($30 * $350);
 $379 = Math_fround($32 * $350);
 $380 = Math_fround($372 - $376);
 $381 = Math_fround($373 - $377);
 $382 = Math_fround($374 - $378);
 $383 = Math_fround($375 - $379);
 $384 = Math_fround($382 * Math_fround(-1.0));
 $385 = Math_fround($383 * Math_fround(-1.0));
 $386 = Math_fround($380 * Math_fround(-1.0));
 $387 = Math_fround($384 * $384);
 $388 = Math_fround($385 * $385);
 $389 = Math_fround($386 * $386);
 $390 = Math_fround($381 * $381);
 $391 = Math_fround($388 + $387);
 $392 = Math_fround($390 + $389);
 $393 = Math_fround($392 + $391);
 $394 = (Math_fround(Math_sqrt((Math_fround($393)))));
 $395 = Math_fround(Math_fround(1.0) / $394);
 $396 = Math_fround($395 * $384);
 $397 = Math_fround($395 * $385);
 $398 = Math_fround($395 * $386);
 $399 = Math_fround($395 * $381);
 if ((($104|0) == 1)) {
  $435 = Math_fround($91 * Math_fround(0.0));
  $436 = Math_fround($93 * Math_fround(0.0));
  $437 = Math_fround($95 * Math_fround(0.0));
  $438 = Math_fround($97 * Math_fround(0.0));
  $439 = $91 > Math_fround(0.0);
  $440 = $93 > Math_fround(0.0);
  $441 = $95 > Math_fround(0.0);
  $442 = $97 > Math_fround(0.0);
  $443 = $439 ? $435 : Math_fround(0.0);
  $444 = $440 ? $436 : Math_fround(0.0);
  $445 = $441 ? $437 : Math_fround(0.0);
  $446 = $442 ? $438 : Math_fround(0.0);
  HEAPF32[$1>>2] = $443;
  $447 = (($1) + 4|0);
  HEAPF32[$447>>2] = $444;
  $448 = (($1) + 8|0);
  HEAPF32[$448>>2] = $445;
  $449 = (($1) + 12|0);
  HEAPF32[$449>>2] = $446;
  __ZN4mathL7halfTanERKNS_7_float4E19358($0,$1);
  $450 = Math_fround(HEAPF32[$0>>2]);
  $451 = (HEAPF32[tempDoublePtr>>2]=$450,HEAP32[tempDoublePtr>>2]|0);
  $452 = (HEAPF32[tempDoublePtr>>2]=$85,HEAP32[tempDoublePtr>>2]|0);
  $453 = $452 & -2147483648;
  $454 = $451 ^ $453;
  $455 = (HEAP32[tempDoublePtr>>2]=$454,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $456 = (($0) + 4|0);
  $457 = Math_fround(HEAPF32[$456>>2]);
  $458 = (HEAPF32[tempDoublePtr>>2]=$457,HEAP32[tempDoublePtr>>2]|0);
  $459 = (HEAPF32[tempDoublePtr>>2]=$87,HEAP32[tempDoublePtr>>2]|0);
  $460 = $459 & -2147483648;
  $461 = $458 ^ $460;
  $462 = (HEAP32[tempDoublePtr>>2]=$461,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $463 = (($0) + 8|0);
  $464 = Math_fround(HEAPF32[$463>>2]);
  $465 = (HEAPF32[tempDoublePtr>>2]=$464,HEAP32[tempDoublePtr>>2]|0);
  $466 = (HEAPF32[tempDoublePtr>>2]=$89,HEAP32[tempDoublePtr>>2]|0);
  $467 = $466 & -2147483648;
  $468 = $465 ^ $467;
  $469 = (HEAP32[tempDoublePtr>>2]=$468,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $470 = Math_fround($455 * $469);
  $471 = Math_fround($462 + $470);
  $472 = Math_fround($455 * $462);
  $473 = Math_fround($469 - $472);
  $474 = Math_fround($455 * $455);
  $475 = Math_fround($471 * $471);
  $476 = Math_fround($473 * $473);
  $477 = Math_fround($474 + $475);
  $478 = Math_fround($476 + Math_fround(1.0));
  $479 = Math_fround($478 + $477);
  $480 = (Math_fround(Math_sqrt((Math_fround($479)))));
  $481 = Math_fround(Math_fround(1.0) / $480);
  $482 = Math_fround($455 * $481);
  $483 = Math_fround($481 * $471);
  $484 = Math_fround($481 * $473);
  $585 = $483;$587 = $481;$589 = $484;$591 = $482;
 } else if ((($104|0) == 2)) {
  $485 = Math_fround($91 * Math_fround(0.0));
  $486 = Math_fround($93 * Math_fround(0.0));
  $487 = Math_fround($95 * Math_fround(0.0));
  $488 = Math_fround($97 * Math_fround(0.0));
  $489 = $91 > Math_fround(0.0);
  $490 = $93 > Math_fround(0.0);
  $491 = $95 > Math_fround(0.0);
  $492 = $97 > Math_fround(0.0);
  $493 = $489 ? $485 : Math_fround(0.0);
  $494 = $490 ? $486 : Math_fround(0.0);
  $495 = $491 ? $487 : Math_fround(0.0);
  $496 = $492 ? $488 : Math_fround(0.0);
  HEAPF32[$3>>2] = $493;
  $497 = (($3) + 4|0);
  HEAPF32[$497>>2] = $494;
  $498 = (($3) + 8|0);
  HEAPF32[$498>>2] = $495;
  $499 = (($3) + 12|0);
  HEAPF32[$499>>2] = $496;
  __ZN4mathL7halfTanERKNS_7_float4E19358($2,$3);
  $500 = Math_fround(HEAPF32[$2>>2]);
  $501 = (HEAPF32[tempDoublePtr>>2]=$500,HEAP32[tempDoublePtr>>2]|0);
  $502 = (HEAPF32[tempDoublePtr>>2]=$85,HEAP32[tempDoublePtr>>2]|0);
  $503 = $502 & -2147483648;
  $504 = $501 ^ $503;
  $505 = (HEAP32[tempDoublePtr>>2]=$504,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $506 = (($2) + 4|0);
  $507 = Math_fround(HEAPF32[$506>>2]);
  $508 = (HEAPF32[tempDoublePtr>>2]=$507,HEAP32[tempDoublePtr>>2]|0);
  $509 = (HEAPF32[tempDoublePtr>>2]=$87,HEAP32[tempDoublePtr>>2]|0);
  $510 = $509 & -2147483648;
  $511 = $508 ^ $510;
  $512 = (HEAP32[tempDoublePtr>>2]=$511,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $513 = (($2) + 8|0);
  $514 = Math_fround(HEAPF32[$513>>2]);
  $515 = (HEAPF32[tempDoublePtr>>2]=$514,HEAP32[tempDoublePtr>>2]|0);
  $516 = (HEAPF32[tempDoublePtr>>2]=$89,HEAP32[tempDoublePtr>>2]|0);
  $517 = $516 & -2147483648;
  $518 = $515 ^ $517;
  $519 = (HEAP32[tempDoublePtr>>2]=$518,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $520 = Math_fround($505 * $519);
  $521 = Math_fround($512 - $520);
  $522 = Math_fround($505 * $512);
  $523 = Math_fround($522 + $519);
  $524 = Math_fround($505 * $505);
  $525 = Math_fround($521 * $521);
  $526 = Math_fround($523 * $523);
  $527 = Math_fround($524 + $525);
  $528 = Math_fround($526 + Math_fround(1.0));
  $529 = Math_fround($528 + $527);
  $530 = (Math_fround(Math_sqrt((Math_fround($529)))));
  $531 = Math_fround(Math_fround(1.0) / $530);
  $532 = Math_fround($505 * $531);
  $533 = Math_fround($531 * $521);
  $534 = Math_fround($531 * $523);
  $585 = $533;$587 = $531;$589 = $534;$591 = $532;
 } else if ((($104|0) == 3)) {
  $400 = (Math_fround(+(_roundf(0.0))));
  $401 = Math_fround(Math_fround(0.0) - $400);
  $402 = (Math_fround(Math_abs((Math_fround($401)))));
  $403 = Math_fround(Math_fround(0.25) - $402);
  $404 = Math_fround($403 * $403);
  $405 = Math_fround($404 * $404);
  $406 = Math_fround($404 * Math_fround(-41.283184051513671875));
  $407 = Math_fround($406 + Math_fround(6.28318548202514648438));
  $408 = Math_fround($405 * Math_fround(76.03546142578125));
  $409 = Math_fround($407 + $408);
  $410 = Math_fround($403 * $409);
  $411 = (Math_fround(+(_roundf(-0.25))));
  $412 = Math_fround(Math_fround(-0.25) - $411);
  $413 = (Math_fround(Math_abs((Math_fround($412)))));
  $414 = Math_fround(Math_fround(0.25) - $413);
  $415 = Math_fround($414 * $414);
  $416 = Math_fround($415 * $415);
  $417 = Math_fround($415 * Math_fround(-41.283184051513671875));
  $418 = Math_fround($417 + Math_fround(6.28318548202514648438));
  $419 = Math_fround($416 * Math_fround(76.03546142578125));
  $420 = Math_fround($418 + $419);
  $421 = Math_fround($414 * $420);
  $422 = Math_fround($410 * $421);
  $423 = Math_fround($421 * $421);
  $424 = Math_fround($410 * $410);
  $425 = Math_fround($410 * $422);
  $426 = Math_fround($410 * $423);
  $427 = Math_fround($410 * $424);
  $428 = Math_fround($421 * Math_fround(-1.0));
  $429 = Math_fround($428 * $422);
  $430 = Math_fround($424 * $421);
  $431 = Math_fround($421 * $423);
  $432 = Math_fround($425 + $429);
  $433 = Math_fround($430 + $426);
  $434 = Math_fround($427 + $431);
  $585 = $433;$587 = $434;$589 = $432;$591 = $432;
 } else {
  $535 = Math_fround($91 * Math_fround(0.0));
  $536 = Math_fround($93 * Math_fround(0.0));
  $537 = Math_fround($95 * Math_fround(0.0));
  $538 = Math_fround($97 * Math_fround(0.0));
  $539 = $91 > Math_fround(0.0);
  $540 = $93 > Math_fround(0.0);
  $541 = $95 > Math_fround(0.0);
  $542 = $97 > Math_fround(0.0);
  $543 = $539 ? $535 : Math_fround(0.0);
  $544 = $540 ? $536 : Math_fround(0.0);
  $545 = $541 ? $537 : Math_fround(0.0);
  $546 = $542 ? $538 : Math_fround(0.0);
  HEAPF32[$5>>2] = $543;
  $547 = (($5) + 4|0);
  HEAPF32[$547>>2] = $544;
  $548 = (($5) + 8|0);
  HEAPF32[$548>>2] = $545;
  $549 = (($5) + 12|0);
  HEAPF32[$549>>2] = $546;
  __ZN4mathL7halfTanERKNS_7_float4E19358($4,$5);
  $550 = Math_fround(HEAPF32[$4>>2]);
  $551 = (HEAPF32[tempDoublePtr>>2]=$550,HEAP32[tempDoublePtr>>2]|0);
  $552 = (HEAPF32[tempDoublePtr>>2]=$85,HEAP32[tempDoublePtr>>2]|0);
  $553 = $552 & -2147483648;
  $554 = $551 ^ $553;
  $555 = (HEAP32[tempDoublePtr>>2]=$554,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $556 = (($4) + 4|0);
  $557 = Math_fround(HEAPF32[$556>>2]);
  $558 = (HEAPF32[tempDoublePtr>>2]=$557,HEAP32[tempDoublePtr>>2]|0);
  $559 = (HEAPF32[tempDoublePtr>>2]=$87,HEAP32[tempDoublePtr>>2]|0);
  $560 = $559 & -2147483648;
  $561 = $558 ^ $560;
  $562 = (HEAP32[tempDoublePtr>>2]=$561,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $563 = (($4) + 8|0);
  $564 = Math_fround(HEAPF32[$563>>2]);
  $565 = (HEAPF32[tempDoublePtr>>2]=$564,HEAP32[tempDoublePtr>>2]|0);
  $566 = (HEAPF32[tempDoublePtr>>2]=$89,HEAP32[tempDoublePtr>>2]|0);
  $567 = $566 & -2147483648;
  $568 = $565 ^ $567;
  $569 = (HEAP32[tempDoublePtr>>2]=$568,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $570 = Math_fround($555 * $555);
  $571 = Math_fround($562 * $562);
  $572 = Math_fround($569 * $569);
  $573 = Math_fround($570 + $571);
  $574 = Math_fround($572 + Math_fround(1.0));
  $575 = Math_fround($573 + $574);
  $576 = (Math_fround(Math_sqrt((Math_fround($575)))));
  $577 = Math_fround(Math_fround(1.0) / $576);
  $578 = Math_fround($555 * $577);
  $579 = Math_fround($562 * $577);
  $580 = Math_fround($577 * $569);
  $585 = $579;$587 = $577;$589 = $580;$591 = $578;
 }
 $581 = Math_fround($77 * Math_fround(-1.0));
 $582 = Math_fround($79 * Math_fround(-1.0));
 $583 = Math_fround($81 * Math_fround(-1.0));
 $584 = Math_fround($581 * $585);
 $586 = Math_fround($83 * $587);
 $588 = Math_fround($582 * $589);
 $590 = Math_fround($583 * $591);
 $592 = Math_fround($583 * $587);
 $593 = Math_fround($581 * $591);
 $594 = Math_fround($583 * $585);
 $595 = Math_fround($581 * $589);
 $596 = Math_fround($584 - $592);
 $597 = Math_fround($586 - $593);
 $598 = Math_fround($588 - $594);
 $599 = Math_fround($590 - $595);
 $600 = Math_fround($83 * $589);
 $601 = Math_fround($583 * $589);
 $602 = Math_fround($581 * $587);
 $603 = Math_fround($582 * $587);
 $604 = Math_fround($596 - $600);
 $605 = Math_fround($597 - $601);
 $606 = Math_fround($598 - $602);
 $607 = Math_fround($599 - $603);
 $608 = Math_fround($582 * $591);
 $609 = Math_fround($582 * $585);
 $610 = Math_fround($83 * $591);
 $611 = Math_fround($83 * $585);
 $612 = Math_fround($604 - $608);
 $613 = Math_fround($605 - $609);
 $614 = Math_fround($606 - $610);
 $615 = Math_fround($607 - $611);
 $616 = Math_fround($614 * Math_fround(-1.0));
 $617 = Math_fround($615 * Math_fround(-1.0));
 $618 = Math_fround($612 * Math_fround(-1.0));
 $619 = Math_fround($71 * $616);
 $620 = Math_fround($75 * $613);
 $621 = Math_fround($73 * $617);
 $622 = Math_fround($69 * $618);
 $623 = Math_fround($75 * $618);
 $624 = Math_fround($69 * $616);
 $625 = Math_fround($71 * $618);
 $626 = Math_fround($73 * $616);
 $627 = Math_fround($619 - $623);
 $628 = Math_fround($620 - $624);
 $629 = Math_fround($621 - $625);
 $630 = Math_fround($622 - $626);
 $631 = Math_fround($73 * $613);
 $632 = Math_fround($73 * $618);
 $633 = Math_fround($75 * $616);
 $634 = Math_fround($75 * $617);
 $635 = Math_fround($627 - $631);
 $636 = Math_fround($628 - $632);
 $637 = Math_fround($629 - $633);
 $638 = Math_fround($630 - $634);
 $639 = Math_fround($69 * $617);
 $640 = Math_fround($71 * $617);
 $641 = Math_fround($69 * $613);
 $642 = Math_fround($71 * $613);
 $643 = Math_fround($635 - $639);
 $644 = Math_fround($636 - $640);
 $645 = Math_fround($637 - $641);
 $646 = Math_fround($638 - $642);
 $647 = Math_fround($645 * Math_fround(-1.0));
 $648 = Math_fround($646 * Math_fround(-1.0));
 $649 = Math_fround($643 * Math_fround(-1.0));
 $650 = Math_fround($647 * $647);
 $651 = Math_fround($648 * $648);
 $652 = Math_fround($649 * $649);
 $653 = Math_fround($644 * $644);
 $654 = Math_fround($651 + $650);
 $655 = Math_fround($653 + $652);
 $656 = Math_fround($655 + $654);
 $657 = (Math_fround(Math_sqrt((Math_fround($656)))));
 $658 = Math_fround(Math_fround(1.0) / $657);
 $659 = Math_fround($658 * $647);
 $660 = Math_fround($658 * $648);
 $661 = Math_fround($658 * $649);
 $662 = Math_fround($658 * $644);
 $663 = ($maxIter|0)>(0);
 if (!($663)) {
  STACKTOP = sp;return;
 }
 $664 = Math_fround($69 * Math_fround(-1.0));
 $665 = Math_fround($71 * Math_fround(-1.0));
 $666 = Math_fround($73 * Math_fround(-1.0));
 $iter$0$ph60 = 0;$prevError$0$ph62 = Math_fround(360.0);
 while(1) {
  $667 = HEAP32[$119>>2]|0;
  $668 = (($667) + ($120))|0;
  $669 = $668;
  $670 = ((($669) + (($9*48)|0)|0) + 20|0);
  $671 = Math_fround(HEAPF32[$670>>2]);
  $672 = Math_fround($77 * $671);
  $673 = ((($669) + (($9*48)|0)|0) + 28|0);
  $674 = Math_fround(HEAPF32[$673>>2]);
  $675 = Math_fround($83 * $674);
  $676 = ((($669) + (($9*48)|0)|0) + 24|0);
  $677 = Math_fround(HEAPF32[$676>>2]);
  $678 = Math_fround($79 * $677);
  $679 = ((($669) + (($9*48)|0)|0) + 16|0);
  $680 = Math_fround(HEAPF32[$679>>2]);
  $681 = Math_fround($81 * $680);
  $682 = Math_fround($81 * $674);
  $683 = Math_fround($77 * $680);
  $684 = Math_fround($81 * $671);
  $685 = Math_fround($77 * $677);
  $686 = Math_fround($672 - $682);
  $687 = Math_fround($675 - $683);
  $688 = Math_fround($678 - $684);
  $689 = Math_fround($681 - $685);
  $690 = Math_fround($83 * $677);
  $691 = Math_fround($81 * $677);
  $692 = Math_fround($77 * $674);
  $693 = Math_fround($79 * $674);
  $694 = Math_fround($686 - $690);
  $695 = Math_fround($687 - $691);
  $696 = Math_fround($688 - $692);
  $697 = Math_fround($689 - $693);
  $698 = Math_fround($79 * $680);
  $699 = Math_fround($79 * $671);
  $700 = Math_fround($83 * $680);
  $701 = Math_fround($83 * $671);
  $702 = Math_fround($694 - $698);
  $703 = Math_fround($695 - $699);
  $704 = Math_fround($696 - $700);
  $705 = Math_fround($697 - $701);
  $706 = Math_fround($704 * Math_fround(-1.0));
  $707 = Math_fround($705 * Math_fround(-1.0));
  $708 = Math_fround($702 * Math_fround(-1.0));
  $709 = Math_fround($665 * $706);
  $710 = Math_fround($75 * $703);
  $711 = Math_fround($666 * $707);
  $712 = Math_fround($664 * $708);
  $713 = Math_fround($75 * $708);
  $714 = Math_fround($664 * $706);
  $715 = Math_fround($665 * $708);
  $716 = Math_fround($666 * $706);
  $717 = Math_fround($709 - $713);
  $718 = Math_fround($710 - $714);
  $719 = Math_fround($711 - $715);
  $720 = Math_fround($712 - $716);
  $721 = Math_fround($666 * $703);
  $722 = Math_fround($666 * $708);
  $723 = Math_fround($75 * $706);
  $724 = Math_fround($75 * $707);
  $725 = Math_fround($717 - $721);
  $726 = Math_fround($718 - $722);
  $727 = Math_fround($719 - $723);
  $728 = Math_fround($720 - $724);
  $729 = Math_fround($664 * $707);
  $730 = Math_fround($665 * $707);
  $731 = Math_fround($664 * $703);
  $732 = Math_fround($665 * $703);
  $733 = Math_fround($725 - $729);
  $734 = Math_fround($726 - $730);
  $735 = Math_fround($727 - $731);
  $736 = Math_fround($728 - $732);
  $737 = Math_fround($735 * Math_fround(-1.0));
  $738 = Math_fround($736 * Math_fround(-1.0));
  $739 = Math_fround($733 * Math_fround(-1.0));
  $740 = Math_fround($737 * $737);
  $741 = Math_fround($738 * $738);
  $742 = Math_fround($739 * $739);
  $743 = Math_fround($734 * $734);
  $744 = Math_fround($741 + $740);
  $745 = Math_fround($743 + $742);
  $746 = Math_fround($745 + $744);
  $747 = (Math_fround(Math_sqrt((Math_fround($746)))));
  $748 = Math_fround(Math_fround(1.0) / $747);
  $749 = Math_fround($748 * $737);
  $750 = Math_fround($748 * $738);
  $751 = Math_fround($748 * $739);
  $752 = Math_fround($748 * $734);
  $753 = $752 == Math_fround(0.0);
  $754 = $753 ? Math_fround(9.99999997475242707878E-7) : $752;
  $755 = Math_fround($749 / $754);
  $756 = Math_fround($750 / $754);
  $757 = Math_fround($751 / $754);
  $758 = Math_fround($755 * $755);
  $759 = Math_fround($758 + Math_fround(1.0));
  $760 = Math_fround($755 * $757);
  $761 = Math_fround($756 - $760);
  $762 = Math_fround($761 / $759);
  $763 = Math_fround($755 * $756);
  $764 = Math_fround($763 + $757);
  $765 = Math_fround($764 / $759);
  $766 = (Math_fround(+(Math_atan((+$755)))));
  $767 = Math_fround($766 * Math_fround(2.0));
  $768 = Math_fround($767 * Math_fround(57.295780181884765625));
  $769 = (Math_fround(Math_abs((Math_fround($768)))));
  $770 = $769 < $maxError;
  $771 = ($iter$0$ph60|0)>(1);
  $772 = $769 > $prevError$0$ph62;
  $or$cond1 = $771 & $772;
  $brmerge = $770 | $or$cond1;
  HEAP32[$124>>2] = $669;
  if ($brmerge) {
   label = 18;
   break;
  }
  $773 = ($iter$0$ph60|0)==(0);
  if ($773) {
   $774 = HEAP32[$119>>2]|0;
   $775 = (($774) + ($120))|0;
   $776 = $775;
   $777 = ((($776) + (($7*48)|0)|0) + 16|0);
   HEAPF32[$777>>2] = $396;
   $778 = ((($776) + (($7*48)|0)|0) + 20|0);
   HEAPF32[$778>>2] = $397;
   $779 = ((($776) + (($7*48)|0)|0) + 24|0);
   HEAPF32[$779>>2] = $398;
   $780 = ((($776) + (($7*48)|0)|0) + 28|0);
   HEAPF32[$780>>2] = $399;
   HEAP32[$124>>2] = $776;
   $781 = ((($776) + (($9*48)|0)|0) + 16|0);
   HEAPF32[$781>>2] = $659;
   $782 = ((($776) + (($9*48)|0)|0) + 20|0);
   HEAPF32[$782>>2] = $660;
   $783 = ((($776) + (($9*48)|0)|0) + 24|0);
   HEAPF32[$783>>2] = $661;
   $784 = ((($776) + (($9*48)|0)|0) + 28|0);
   HEAPF32[$784>>2] = $662;
   $785 = HEAP32[$10>>2]|0;
   $786 = (($785) + ($11))|0;
   $787 = $786;
   HEAP32[$118>>2] = $787;
   __ZN7mecanim8skeleton26SkeletonPoseComputeGlobalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($787,$apSkeletonPose,$apSkeletonPoseWs,$9,$7);
  } else {
   $788 = Math_fround($765 * Math_fround(0.0));
   $789 = Math_fround($762 + $788);
   $790 = Math_fround($762 * Math_fround(0.0));
   $791 = Math_fround($765 - $790);
   $792 = Math_fround($789 * $789);
   $793 = Math_fround($791 * $791);
   $794 = Math_fround($792 + Math_fround(0.0));
   $795 = Math_fround($793 + Math_fround(1.0));
   $796 = Math_fround($795 + $794);
   $797 = (Math_fround(Math_sqrt((Math_fround($796)))));
   $798 = Math_fround(Math_fround(1.0) / $797);
   $799 = Math_fround($798 * Math_fround(0.0));
   $800 = Math_fround($789 * $798);
   $801 = Math_fround($791 * $798);
   $802 = HEAP32[$119>>2]|0;
   $803 = (($802) + ($120))|0;
   $804 = $803;
   HEAP32[$124>>2] = $804;
   $805 = Math_fround($581 * $800);
   $806 = Math_fround($83 * $798);
   $807 = Math_fround($582 * $801);
   $808 = Math_fround($583 * $799);
   $809 = Math_fround($583 * $798);
   $810 = Math_fround($581 * $799);
   $811 = Math_fround($583 * $800);
   $812 = Math_fround($581 * $801);
   $813 = Math_fround($805 - $809);
   $814 = Math_fround($806 - $810);
   $815 = Math_fround($807 - $811);
   $816 = Math_fround($808 - $812);
   $817 = Math_fround($83 * $801);
   $818 = Math_fround($583 * $801);
   $819 = Math_fround($581 * $798);
   $820 = Math_fround($582 * $798);
   $821 = Math_fround($813 - $817);
   $822 = Math_fround($814 - $818);
   $823 = Math_fround($815 - $819);
   $824 = Math_fround($816 - $820);
   $825 = Math_fround($582 * $799);
   $826 = Math_fround($582 * $800);
   $827 = Math_fround($83 * $799);
   $828 = Math_fround($83 * $800);
   $829 = Math_fround($821 - $825);
   $830 = Math_fround($822 - $826);
   $831 = Math_fround($823 - $827);
   $832 = Math_fround($824 - $828);
   $833 = Math_fround($831 * Math_fround(-1.0));
   $834 = Math_fround($832 * Math_fround(-1.0));
   $835 = Math_fround($829 * Math_fround(-1.0));
   $836 = Math_fround($71 * $833);
   $837 = Math_fround($75 * $830);
   $838 = Math_fround($73 * $834);
   $839 = Math_fround($69 * $835);
   $840 = Math_fround($75 * $835);
   $841 = Math_fround($69 * $833);
   $842 = Math_fround($71 * $835);
   $843 = Math_fround($73 * $833);
   $844 = Math_fround($836 - $840);
   $845 = Math_fround($837 - $841);
   $846 = Math_fround($838 - $842);
   $847 = Math_fround($839 - $843);
   $848 = Math_fround($73 * $830);
   $849 = Math_fround($73 * $835);
   $850 = Math_fround($75 * $833);
   $851 = Math_fround($75 * $834);
   $852 = Math_fround($844 - $848);
   $853 = Math_fround($845 - $849);
   $854 = Math_fround($846 - $850);
   $855 = Math_fround($847 - $851);
   $856 = Math_fround($69 * $834);
   $857 = Math_fround($71 * $834);
   $858 = Math_fround($69 * $830);
   $859 = Math_fround($71 * $830);
   $860 = Math_fround($852 - $856);
   $861 = Math_fround($853 - $857);
   $862 = Math_fround($854 - $858);
   $863 = Math_fround($855 - $859);
   $864 = Math_fround($862 * Math_fround(-1.0));
   $865 = Math_fround($863 * Math_fround(-1.0));
   $866 = Math_fround($860 * Math_fround(-1.0));
   $867 = Math_fround($864 * $864);
   $868 = Math_fround($865 * $865);
   $869 = Math_fround($866 * $866);
   $870 = Math_fround($861 * $861);
   $871 = Math_fround($868 + $867);
   $872 = Math_fround($870 + $869);
   $873 = Math_fround($872 + $871);
   $874 = (Math_fround(Math_sqrt((Math_fround($873)))));
   $875 = Math_fround(Math_fround(1.0) / $874);
   $876 = Math_fround($875 * $864);
   $877 = Math_fround($875 * $865);
   $878 = Math_fround($875 * $866);
   $879 = Math_fround($875 * $861);
   $880 = ((($804) + (($9*48)|0)|0) + 16|0);
   HEAPF32[$880>>2] = $876;
   $881 = ((($804) + (($9*48)|0)|0) + 20|0);
   HEAPF32[$881>>2] = $877;
   $882 = ((($804) + (($9*48)|0)|0) + 24|0);
   HEAPF32[$882>>2] = $878;
   $883 = ((($804) + (($9*48)|0)|0) + 28|0);
   HEAPF32[$883>>2] = $879;
   $884 = HEAP32[$10>>2]|0;
   $885 = (($884) + ($11))|0;
   $886 = $885;
   HEAP32[$118>>2] = $886;
   __ZN7mecanim8skeleton26SkeletonPoseComputeGlobalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($886,$apSkeletonPose,$apSkeletonPoseWs,$9,$9);
  }
  $887 = HEAP32[$105>>2]|0;
  $888 = (($887) + ($106))|0;
  $889 = $888;
  HEAP32[$110>>2] = $889;
  $890 = ((($889) + (($9*48)|0)|0) + 16|0);
  $891 = Math_fround(HEAPF32[$890>>2]);
  $892 = Math_fround($891 * Math_fround(-1.0));
  $893 = ((($889) + (($9*48)|0)|0) + 20|0);
  $894 = Math_fround(HEAPF32[$893>>2]);
  $895 = Math_fround($894 * Math_fround(-1.0));
  $896 = ((($889) + (($9*48)|0)|0) + 24|0);
  $897 = Math_fround(HEAPF32[$896>>2]);
  $898 = Math_fround($897 * Math_fround(-1.0));
  $899 = ((($889) + (($9*48)|0)|0) + 28|0);
  $900 = Math_fround(HEAPF32[$899>>2]);
  $901 = Math_fround($132 * $892);
  $902 = Math_fround($136 * $900);
  $903 = Math_fround($134 * $895);
  $904 = Math_fround($130 * $898);
  $905 = Math_fround($136 * $898);
  $906 = Math_fround($130 * $892);
  $907 = Math_fround($132 * $898);
  $908 = Math_fround($134 * $892);
  $909 = Math_fround($901 - $905);
  $910 = Math_fround($902 - $906);
  $911 = Math_fround($903 - $907);
  $912 = Math_fround($904 - $908);
  $913 = Math_fround($134 * $900);
  $914 = Math_fround($134 * $898);
  $915 = Math_fround($136 * $892);
  $916 = Math_fround($136 * $895);
  $917 = Math_fround($909 - $913);
  $918 = Math_fround($910 - $914);
  $919 = Math_fround($911 - $915);
  $920 = Math_fround($912 - $916);
  $921 = Math_fround($130 * $895);
  $922 = Math_fround($132 * $895);
  $923 = Math_fround($130 * $900);
  $924 = Math_fround($132 * $900);
  $925 = Math_fround($917 - $921);
  $926 = Math_fround($918 - $922);
  $927 = Math_fround($919 - $923);
  $928 = Math_fround($920 - $924);
  $929 = Math_fround($927 * Math_fround(-1.0));
  $930 = Math_fround($928 * Math_fround(-1.0));
  $931 = Math_fround($925 * Math_fround(-1.0));
  $932 = HEAP32[$119>>2]|0;
  $933 = (($932) + ($120))|0;
  $934 = $933;
  $935 = ((($934) + (($7*48)|0)|0) + 16|0);
  $936 = Math_fround(HEAPF32[$935>>2]);
  $937 = Math_fround($936 * $930);
  $938 = ((($934) + (($7*48)|0)|0) + 28|0);
  $939 = Math_fround(HEAPF32[$938>>2]);
  $940 = Math_fround($926 * $939);
  $941 = ((($934) + (($7*48)|0)|0) + 20|0);
  $942 = Math_fround(HEAPF32[$941>>2]);
  $943 = Math_fround($931 * $942);
  $944 = ((($934) + (($7*48)|0)|0) + 24|0);
  $945 = Math_fround(HEAPF32[$944>>2]);
  $946 = Math_fround($929 * $945);
  $947 = Math_fround($926 * $945);
  $948 = Math_fround($936 * $929);
  $949 = Math_fround($930 * $945);
  $950 = Math_fround($936 * $931);
  $951 = Math_fround($937 - $947);
  $952 = Math_fround($940 - $948);
  $953 = Math_fround($943 - $949);
  $954 = Math_fround($946 - $950);
  $955 = Math_fround($939 * $931);
  $956 = Math_fround($931 * $945);
  $957 = Math_fround($936 * $926);
  $958 = Math_fround($926 * $942);
  $959 = Math_fround($951 - $955);
  $960 = Math_fround($952 - $956);
  $961 = Math_fround($953 - $957);
  $962 = Math_fround($954 - $958);
  $963 = Math_fround($929 * $942);
  $964 = Math_fround($930 * $942);
  $965 = Math_fround($939 * $929);
  $966 = Math_fround($939 * $930);
  $967 = Math_fround($959 - $963);
  $968 = Math_fround($960 - $964);
  $969 = Math_fround($961 - $965);
  $970 = Math_fround($962 - $966);
  $971 = Math_fround($969 * Math_fround(-1.0));
  $972 = Math_fround($970 * Math_fround(-1.0));
  $973 = Math_fround($967 * Math_fround(-1.0));
  $974 = Math_fround($971 * $971);
  $975 = Math_fround($972 * $972);
  $976 = Math_fround($973 * $973);
  $977 = Math_fround($968 * $968);
  $978 = Math_fround($974 + $975);
  $979 = Math_fround($977 + $976);
  $980 = Math_fround($978 + $979);
  $981 = (Math_fround(Math_sqrt((Math_fround($980)))));
  $982 = Math_fround(Math_fround(1.0) / $981);
  $983 = Math_fround($982 * $971);
  $984 = Math_fround($982 * $972);
  $985 = Math_fround($982 * $973);
  $986 = Math_fround($982 * $968);
  HEAPF32[$935>>2] = $983;
  HEAPF32[$941>>2] = $984;
  HEAPF32[$944>>2] = $985;
  HEAPF32[$938>>2] = $986;
  $987 = HEAP32[$10>>2]|0;
  $988 = (($987) + ($11))|0;
  $989 = $988;
  HEAP32[$118>>2] = $989;
  HEAP32[$124>>2] = $934;
  $990 = ((($934) + (($7*48)|0)|0) + 16|0);
  __ZN7mecanim8skeleton13SkeletonAlignEPKNS0_8SkeletonERKN4math7_float4ES7_i($989,$pq,$990,$7);
  $991 = HEAP32[$10>>2]|0;
  $992 = (($991) + ($11))|0;
  $993 = $992;
  HEAP32[$118>>2] = $993;
  __ZN7mecanim8skeleton26SkeletonPoseComputeGlobalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($993,$apSkeletonPose,$apSkeletonPoseWs,$9,$7);
  $994 = HEAP32[$105>>2]|0;
  $995 = (($994) + ($106))|0;
  $996 = $995;
  HEAP32[$110>>2] = $996;
  $997 = ((($996) + (($9*48)|0)|0) + 16|0);
  HEAPF32[$997>>2] = $130;
  $998 = ((($996) + (($9*48)|0)|0) + 20|0);
  HEAPF32[$998>>2] = $132;
  $999 = ((($996) + (($9*48)|0)|0) + 24|0);
  HEAPF32[$999>>2] = $134;
  $1000 = ((($996) + (($9*48)|0)|0) + 28|0);
  HEAPF32[$1000>>2] = $136;
  $1001 = HEAP32[$10>>2]|0;
  $1002 = (($1001) + ($11))|0;
  $1003 = $1002;
  HEAP32[$118>>2] = $1003;
  __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1003,$apSkeletonPoseWs,$apSkeletonPose,$9,$9);
  $1004 = (($iter$0$ph60) + 1)|0;
  $1005 = ($1004|0)<($maxIter|0);
  if ($1005) {
   $iter$0$ph60 = $1004;$prevError$0$ph62 = $769;
  } else {
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim5human17ReachGoalRotationEPKNS0_5HumanERKN4math7_float4EiPNS_8skeleton12SkeletonPoseESA_SA_($apHuman,$arEndQ,$aGoalIndex,$apSkeletonPose,$apSkeletonPoseGbl,$apSkeletonPoseWorkspace) {
 $apHuman = $apHuman|0;
 $arEndQ = $arEndQ|0;
 $aGoalIndex = $aGoalIndex|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $apSkeletonPoseGbl = $apSkeletonPoseGbl|0;
 $apSkeletonPoseWorkspace = $apSkeletonPoseWorkspace|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (798784 + ($aGoalIndex<<4)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($apHuman) + ($1<<2)|0) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($apHuman) + 48|0);
 $5 = $4;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($8) + 4|0);
 $10 = $9;
 $11 = HEAP32[$9>>2]|0;
 $12 = (($10) + ($11))|0;
 $13 = $12;
 $14 = (($13) + ($3<<3)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($apSkeletonPose) + 4|0);
 $17 = $16;
 $18 = HEAP32[$16>>2]|0;
 $19 = (($18) + ($17))|0;
 $20 = $19;
 $21 = (($apSkeletonPose) + 8|0);
 HEAP32[$21>>2] = $20;
 $22 = (($apSkeletonPoseGbl) + 4|0);
 $23 = $22;
 $24 = HEAP32[$22>>2]|0;
 $25 = (($24) + ($23))|0;
 $26 = $25;
 $27 = (($apSkeletonPoseGbl) + 8|0);
 HEAP32[$27>>2] = $26;
 $28 = ((($26) + (($15*48)|0)|0) + 16|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * Math_fround(-1.0));
 $31 = ((($26) + (($15*48)|0)|0) + 20|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(-1.0));
 $34 = ((($26) + (($15*48)|0)|0) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * Math_fround(-1.0));
 $37 = ((($26) + (($15*48)|0)|0) + 28|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(HEAPF32[$arEndQ>>2]);
 $40 = Math_fround($33 * $39);
 $41 = (($arEndQ) + 12|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($38 * $42);
 $44 = (($arEndQ) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($36 * $45);
 $47 = (($arEndQ) + 8|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($30 * $48);
 $50 = Math_fround($38 * $48);
 $51 = Math_fround($30 * $39);
 $52 = Math_fround($33 * $48);
 $53 = Math_fround($36 * $39);
 $54 = Math_fround($40 - $50);
 $55 = Math_fround($43 - $51);
 $56 = Math_fround($46 - $52);
 $57 = Math_fround($49 - $53);
 $58 = Math_fround($36 * $42);
 $59 = Math_fround($36 * $48);
 $60 = Math_fround($38 * $39);
 $61 = Math_fround($38 * $45);
 $62 = Math_fround($54 - $58);
 $63 = Math_fround($55 - $59);
 $64 = Math_fround($56 - $60);
 $65 = Math_fround($57 - $61);
 $66 = Math_fround($30 * $45);
 $67 = Math_fround($33 * $45);
 $68 = Math_fround($30 * $42);
 $69 = Math_fround($33 * $42);
 $70 = Math_fround($62 - $66);
 $71 = Math_fround($63 - $67);
 $72 = Math_fround($64 - $68);
 $73 = Math_fround($65 - $69);
 $74 = Math_fround($72 * Math_fround(-1.0));
 $75 = Math_fround($73 * Math_fround(-1.0));
 $76 = Math_fround($70 * Math_fround(-1.0));
 $77 = Math_fround($74 * $74);
 $78 = Math_fround($75 * $75);
 $79 = Math_fround($76 * $76);
 $80 = Math_fround($71 * $71);
 $81 = Math_fround($77 + $78);
 $82 = Math_fround($80 + $79);
 $83 = Math_fround($81 + $82);
 $84 = (Math_fround(Math_sqrt((Math_fround($83)))));
 $85 = Math_fround(Math_fround(1.0) / $84);
 $86 = Math_fround($85 * $74);
 $87 = Math_fround($85 * $75);
 $88 = Math_fround($85 * $76);
 $89 = Math_fround($85 * $71);
 $90 = ((($20) + (($3*48)|0)|0) + 16|0);
 HEAPF32[$90>>2] = $86;
 $91 = ((($20) + (($3*48)|0)|0) + 20|0);
 HEAPF32[$91>>2] = $87;
 $92 = ((($20) + (($3*48)|0)|0) + 24|0);
 HEAPF32[$92>>2] = $88;
 $93 = ((($20) + (($3*48)|0)|0) + 28|0);
 HEAPF32[$93>>2] = $89;
 $94 = ((798784 + ($aGoalIndex<<4)|0) + 8|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ((798784 + ($aGoalIndex<<4)|0) + 12|0);
 $97 = HEAP32[$96>>2]|0;
 __ZN7mecanim5human14HumanFixEndDoFEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iifi($apHuman,$apSkeletonPose,$apSkeletonPoseWorkspace,$95,$97,Math_fround(0.0500000007450580596924),1);
 STACKTOP = sp;return;
}
function __ZN7mecanim5human10RetargetToEPKNS0_5HumanEPKNS0_9HumanPoseES6_RKN4math5xformEPS4_PNS_8skeleton12SkeletonPoseESE_($apHuman,$apHumanPoseBase,$apHumanPose,$arX,$apHumanPoseOut,$apSkeletonPose,$apSkeletonPoseWs) {
 $apHuman = $apHuman|0;
 $apHumanPoseBase = $apHumanPoseBase|0;
 $apHumanPose = $apHumanPose|0;
 $arX = $arX|0;
 $apHumanPoseOut = $apHumanPoseOut|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $apSkeletonPoseWs = $apSkeletonPoseWs|0;
 var $$pre = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0);
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0);
 var $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = 0;
 var $222 = Math_fround(0), $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0);
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0;
 var $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $3 = 0;
 var $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0;
 var $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $exitcond = 0, $exitcond$i = 0, $goalIter$014 = 0, $i$11$i = 0;
 var $rootX = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $0 = sp + 144|0;
 $1 = sp;
 $rootX = sp + 48|0;
 $2 = sp + 96|0;
 $3 = (($apHuman) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($apHuman) + 392|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 __ZN7mecanim5human13HumanPoseCopyERNS0_9HumanPoseERKS1_b($apHumanPoseOut,$apHumanPoseBase,0);
 $7 = Math_fround(HEAPF32[$apHumanPoseOut>>2]);
 $8 = Math_fround($6 * $7);
 $9 = (($apHumanPoseOut) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($6 * $10);
 $12 = (($apHumanPoseOut) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($6 * $13);
 $15 = (($apHumanPoseOut) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($6 * $16);
 HEAPF32[$apHumanPoseOut>>2] = $8;
 HEAPF32[$9>>2] = $11;
 HEAPF32[$12>>2] = $14;
 HEAPF32[$15>>2] = $17;
 __ZN4mathL8xformMulERKNS_5xformES2_19323($0,$arX,$apHumanPoseOut);
 $18 = Math_fround(HEAPF32[$0>>2]);
 $19 = (($0) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($0) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 HEAPF32[$apHumanPoseOut>>2] = $18;
 HEAPF32[$9>>2] = $20;
 HEAPF32[$12>>2] = $22;
 HEAPF32[$15>>2] = $24;
 $25 = (($0) + 16|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($0) + 20|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($0) + 24|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($0) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = (($apHumanPoseOut) + 16|0);
 HEAPF32[$33>>2] = $26;
 $34 = (($apHumanPoseOut) + 20|0);
 HEAPF32[$34>>2] = $28;
 $35 = (($apHumanPoseOut) + 24|0);
 HEAPF32[$35>>2] = $30;
 $36 = (($apHumanPoseOut) + 28|0);
 HEAPF32[$36>>2] = $32;
 $37 = (($0) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($0) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($0) + 40|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($0) + 44|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($apHumanPoseOut) + 32|0);
 HEAPF32[$45>>2] = $38;
 $46 = (($apHumanPoseOut) + 36|0);
 HEAPF32[$46>>2] = $40;
 $47 = (($apHumanPoseOut) + 40|0);
 HEAPF32[$47>>2] = $42;
 $48 = (($apHumanPoseOut) + 44|0);
 HEAPF32[$48>>2] = $44;
 $49 = ($apHumanPose|0)!=(0|0);
 $$sink = $49 ? $apHumanPose : $apHumanPoseBase;
 $50 = (($1) + 4|0);
 $51 = (($1) + 8|0);
 $52 = (($1) + 12|0);
 $53 = (($1) + 16|0);
 $54 = (($1) + 20|0);
 $55 = (($1) + 24|0);
 $56 = (($1) + 28|0);
 $57 = (($1) + 32|0);
 $58 = (($1) + 36|0);
 $59 = (($1) + 40|0);
 $60 = (($1) + 44|0);
 $61 = (($apHuman) + 48|0);
 $62 = $61;
 $goalIter$014 = 0;
 while(1) {
  $63 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 80|0);
  $64 = ((($$sink) + (($goalIter$014*76)|0)|0) + 80|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = ((($$sink) + (($goalIter$014*76)|0)|0) + 84|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($$sink) + (($goalIter$014*76)|0)|0) + 88|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = ((($$sink) + (($goalIter$014*76)|0)|0) + 92|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  HEAPF32[$63>>2] = $65;
  $72 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 84|0);
  HEAPF32[$72>>2] = $67;
  $73 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 88|0);
  HEAPF32[$73>>2] = $69;
  $74 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 92|0);
  HEAPF32[$74>>2] = $71;
  $75 = ((($$sink) + (($goalIter$014*76)|0)|0) + 96|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = ((($$sink) + (($goalIter$014*76)|0)|0) + 100|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = ((($$sink) + (($goalIter$014*76)|0)|0) + 104|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = ((($$sink) + (($goalIter$014*76)|0)|0) + 108|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 96|0);
  HEAPF32[$83>>2] = $76;
  $84 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 100|0);
  HEAPF32[$84>>2] = $78;
  $85 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 104|0);
  HEAPF32[$85>>2] = $80;
  $86 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 108|0);
  HEAPF32[$86>>2] = $82;
  $87 = ((($$sink) + (($goalIter$014*76)|0)|0) + 112|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = ((($$sink) + (($goalIter$014*76)|0)|0) + 116|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = ((($$sink) + (($goalIter$014*76)|0)|0) + 120|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = ((($$sink) + (($goalIter$014*76)|0)|0) + 124|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 112|0);
  HEAPF32[$95>>2] = $88;
  $96 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 116|0);
  HEAPF32[$96>>2] = $90;
  $97 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 120|0);
  HEAPF32[$97>>2] = $92;
  $98 = ((($apHumanPoseOut) + (($goalIter$014*76)|0)|0) + 124|0);
  HEAPF32[$98>>2] = $94;
  $99 = Math_fround($6 * $65);
  $100 = Math_fround($6 * $67);
  $101 = Math_fround($6 * $69);
  $102 = Math_fround($6 * $71);
  HEAPF32[$63>>2] = $99;
  HEAPF32[$72>>2] = $100;
  HEAPF32[$73>>2] = $101;
  HEAPF32[$74>>2] = $102;
  __ZN4mathL8xformMulERKNS_5xformES2_19323($1,$arX,$63);
  $103 = Math_fround(HEAPF32[$1>>2]);
  $104 = Math_fround(HEAPF32[$50>>2]);
  $105 = Math_fround(HEAPF32[$51>>2]);
  $106 = Math_fround(HEAPF32[$52>>2]);
  HEAPF32[$63>>2] = $103;
  HEAPF32[$72>>2] = $104;
  HEAPF32[$73>>2] = $105;
  HEAPF32[$74>>2] = $106;
  $107 = Math_fround(HEAPF32[$53>>2]);
  $108 = Math_fround(HEAPF32[$54>>2]);
  $109 = Math_fround(HEAPF32[$55>>2]);
  $110 = Math_fround(HEAPF32[$56>>2]);
  HEAPF32[$83>>2] = $107;
  HEAPF32[$84>>2] = $108;
  HEAPF32[$85>>2] = $109;
  HEAPF32[$86>>2] = $110;
  $111 = Math_fround(HEAPF32[$57>>2]);
  $112 = Math_fround(HEAPF32[$58>>2]);
  $113 = Math_fround(HEAPF32[$59>>2]);
  $114 = Math_fround(HEAPF32[$60>>2]);
  HEAPF32[$95>>2] = $111;
  HEAPF32[$96>>2] = $112;
  HEAPF32[$97>>2] = $113;
  HEAPF32[$98>>2] = $114;
  $115 = ($goalIter$014|0)<(2);
  if ($115) {
   $116 = ($goalIter$014|0)==(0);
   $117 = HEAP32[$61>>2]|0;
   $118 = (($117) + ($62))|0;
   $119 = $118;
   $120 = (($119) + 24|0);
   $121 = (($119) + 4|0);
   $122 = $116 ? 5 : 6;
   $123 = ((($apHuman) + ($122<<2)|0) + 104|0);
   $124 = HEAP32[$123>>2]|0;
   $125 = $121;
   $126 = HEAP32[$121>>2]|0;
   $127 = (($125) + ($126))|0;
   $128 = $127;
   $129 = ((($128) + ($124<<3)|0) + 4|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = $120;
   $132 = HEAP32[$120>>2]|0;
   $133 = (($132) + ($131))|0;
   $134 = $133;
   $135 = ((($134) + (($130*88)|0)|0) + 80|0);
   $136 = Math_fround(HEAPF32[$135>>2]);
   $137 = Math_fround($136 * $111);
   $138 = Math_fround(-$137);
   $139 = Math_fround($112 * Math_fround(-0.0));
   $140 = Math_fround($113 * Math_fround(-0.0));
   $141 = Math_fround($114 * Math_fround(-0.0));
   $142 = Math_fround($138 - $137);
   $143 = Math_fround($139 + $139);
   $144 = Math_fround($140 + $140);
   $145 = Math_fround($143 * $107);
   $146 = Math_fround($144 * $108);
   $147 = Math_fround($142 * $109);
   $148 = Math_fround($110 * Math_fround(0.0));
   $149 = Math_fround($142 * $108);
   $150 = Math_fround($143 * $109);
   $151 = Math_fround($107 * $144);
   $152 = Math_fround($145 - $149);
   $153 = Math_fround($146 - $150);
   $154 = Math_fround($147 - $151);
   $155 = Math_fround($148 - $148);
   $156 = Math_fround($110 * $153);
   $157 = Math_fround($110 * $154);
   $158 = Math_fround($152 * $110);
   $159 = Math_fround($110 * $155);
   $160 = Math_fround($156 - $137);
   $161 = Math_fround($139 + $157);
   $162 = Math_fround($140 + $158);
   $163 = Math_fround($141 + $159);
   $164 = Math_fround($107 * $154);
   $165 = Math_fround($108 * $152);
   $166 = Math_fround($109 * $153);
   $167 = Math_fround($108 * $153);
   $168 = Math_fround($109 * $154);
   $169 = Math_fround($107 * $152);
   $170 = Math_fround($164 - $167);
   $171 = Math_fround($165 - $168);
   $172 = Math_fround($166 - $169);
   $173 = Math_fround($159 - $159);
   $174 = Math_fround($160 + $171);
   $175 = Math_fround($161 + $172);
   $176 = Math_fround($162 + $170);
   $177 = Math_fround($163 + $173);
   $178 = Math_fround($103 + $174);
   $179 = Math_fround($104 + $175);
   $180 = Math_fround($105 + $176);
   $181 = Math_fround($106 + $177);
   HEAPF32[$63>>2] = $178;
   HEAPF32[$72>>2] = $179;
   HEAPF32[$73>>2] = $180;
   HEAPF32[$74>>2] = $181;
  }
  $182 = (($goalIter$014) + 1)|0;
  $exitcond = ($182|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $goalIter$014 = $182;
  }
 }
 $183 = (($apHuman) + 56|0);
 $184 = $183;
 $185 = HEAP32[$183>>2]|0;
 $186 = (($185) + ($184))|0;
 $187 = $186;
 $188 = (($apHuman) + 60|0);
 HEAP32[$188>>2] = $187;
 __ZN7mecanim8skeleton16SkeletonPoseCopyEPKNS0_12SkeletonPoseEPS1_($187,$apSkeletonPose);
 __ZN7mecanim5human30HumanPoseAdjustForMissingBonesEPKNS0_5HumanEPNS0_9HumanPoseE($apHuman,$apHumanPoseOut);
 __ZN7mecanim5human18Human2SkeletonPoseEPKNS0_5HumanEPKNS0_9HumanPoseEPNS_8skeleton12SkeletonPoseE($apHuman,$apHumanPoseOut,$apSkeletonPose);
 $189 = HEAP32[$61>>2]|0;
 $190 = (($189) + ($62))|0;
 $191 = $190;
 $192 = (($apHuman) + 52|0);
 HEAP32[$192>>2] = $191;
 __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_($191,$apSkeletonPose,$apSkeletonPoseWs);
 __ZN7mecanim5human21HumanComputeRootXformEPKNS0_5HumanEPKNS_8skeleton12SkeletonPoseE($rootX,$apHuman,$apSkeletonPoseWs);
 $193 = (($apSkeletonPose) + 4|0);
 $194 = $193;
 $195 = HEAP32[$193>>2]|0;
 $196 = (($195) + ($194))|0;
 $197 = $196;
 $198 = (($apSkeletonPose) + 8|0);
 HEAP32[$198>>2] = $197;
 $199 = (($apSkeletonPoseWs) + 4|0);
 $200 = $199;
 $201 = HEAP32[$199>>2]|0;
 $202 = (($201) + ($200))|0;
 $203 = $202;
 $204 = (($apSkeletonPoseWs) + 8|0);
 HEAP32[$204>>2] = $203;
 $205 = (($203) + (($4*48)|0)|0);
 __ZN4mathL13xformInvMulNSERKNS_5xformES2_19341($2,$rootX,$205);
 $206 = Math_fround(HEAPF32[$2>>2]);
 $207 = (($2) + 4|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($2) + 8|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($2) + 12|0);
 $212 = Math_fround(HEAPF32[$211>>2]);
 $213 = (($197) + (($4*48)|0)|0);
 HEAPF32[$213>>2] = $206;
 $214 = ((($197) + (($4*48)|0)|0) + 4|0);
 HEAPF32[$214>>2] = $208;
 $215 = ((($197) + (($4*48)|0)|0) + 8|0);
 HEAPF32[$215>>2] = $210;
 $216 = ((($197) + (($4*48)|0)|0) + 12|0);
 HEAPF32[$216>>2] = $212;
 $217 = (($2) + 16|0);
 $218 = Math_fround(HEAPF32[$217>>2]);
 $219 = (($2) + 20|0);
 $220 = Math_fround(HEAPF32[$219>>2]);
 $221 = (($2) + 24|0);
 $222 = Math_fround(HEAPF32[$221>>2]);
 $223 = (($2) + 28|0);
 $224 = Math_fround(HEAPF32[$223>>2]);
 $225 = ((($197) + (($4*48)|0)|0) + 16|0);
 HEAPF32[$225>>2] = $218;
 $226 = ((($197) + (($4*48)|0)|0) + 20|0);
 HEAPF32[$226>>2] = $220;
 $227 = ((($197) + (($4*48)|0)|0) + 24|0);
 HEAPF32[$227>>2] = $222;
 $228 = ((($197) + (($4*48)|0)|0) + 28|0);
 HEAPF32[$228>>2] = $224;
 $229 = (($2) + 32|0);
 $230 = Math_fround(HEAPF32[$229>>2]);
 $231 = (($2) + 36|0);
 $232 = Math_fround(HEAPF32[$231>>2]);
 $233 = (($2) + 40|0);
 $234 = Math_fround(HEAPF32[$233>>2]);
 $235 = (($2) + 44|0);
 $236 = Math_fround(HEAPF32[$235>>2]);
 $237 = ((($197) + (($4*48)|0)|0) + 32|0);
 HEAPF32[$237>>2] = $230;
 $238 = ((($197) + (($4*48)|0)|0) + 36|0);
 HEAPF32[$238>>2] = $232;
 $239 = ((($197) + (($4*48)|0)|0) + 40|0);
 HEAPF32[$239>>2] = $234;
 $240 = ((($197) + (($4*48)|0)|0) + 44|0);
 HEAPF32[$240>>2] = $236;
 $241 = HEAP32[$193>>2]|0;
 $242 = (($241) + ($194))|0;
 $243 = $242;
 HEAP32[$198>>2] = $243;
 $244 = HEAP32[$199>>2]|0;
 $245 = (($244) + ($200))|0;
 $246 = $245;
 HEAP32[$204>>2] = $246;
 $247 = ((($246) + (($4*48)|0)|0) + 32|0);
 $248 = Math_fround(HEAPF32[$247>>2]);
 $249 = ((($246) + (($4*48)|0)|0) + 36|0);
 $250 = Math_fround(HEAPF32[$249>>2]);
 $251 = ((($246) + (($4*48)|0)|0) + 40|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 $253 = ((($246) + (($4*48)|0)|0) + 44|0);
 $254 = Math_fround(HEAPF32[$253>>2]);
 $255 = ((($243) + (($4*48)|0)|0) + 32|0);
 HEAPF32[$255>>2] = $248;
 $256 = ((($243) + (($4*48)|0)|0) + 36|0);
 HEAPF32[$256>>2] = $250;
 $257 = ((($243) + (($4*48)|0)|0) + 40|0);
 HEAPF32[$257>>2] = $252;
 $258 = ((($243) + (($4*48)|0)|0) + 44|0);
 HEAPF32[$258>>2] = $254;
 $259 = ($apHumanPose|0)==(0|0);
 if ($259) {
  $269 = $241;
  $268 = (($269) + ($194))|0;
  $270 = $268;
  HEAP32[$198>>2] = $270;
  $271 = Math_fround(HEAPF32[$apHumanPoseOut>>2]);
  $272 = Math_fround(HEAPF32[$9>>2]);
  $273 = Math_fround(HEAPF32[$12>>2]);
  $274 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$270>>2] = $271;
  $275 = (($270) + 4|0);
  HEAPF32[$275>>2] = $272;
  $276 = (($270) + 8|0);
  HEAPF32[$276>>2] = $273;
  $277 = (($270) + 12|0);
  HEAPF32[$277>>2] = $274;
  $278 = Math_fround(HEAPF32[$33>>2]);
  $279 = Math_fround(HEAPF32[$34>>2]);
  $280 = Math_fround(HEAPF32[$35>>2]);
  $281 = Math_fround(HEAPF32[$36>>2]);
  $282 = (($270) + 16|0);
  HEAPF32[$282>>2] = $278;
  $283 = (($270) + 20|0);
  HEAPF32[$283>>2] = $279;
  $284 = (($270) + 24|0);
  HEAPF32[$284>>2] = $280;
  $285 = (($270) + 28|0);
  HEAPF32[$285>>2] = $281;
  $286 = Math_fround(HEAPF32[$45>>2]);
  $287 = Math_fround(HEAPF32[$46>>2]);
  $288 = Math_fround(HEAPF32[$47>>2]);
  $289 = Math_fround(HEAPF32[$48>>2]);
  $290 = (($270) + 32|0);
  HEAPF32[$290>>2] = $286;
  $291 = (($270) + 36|0);
  HEAPF32[$291>>2] = $287;
  $292 = (($270) + 40|0);
  HEAPF32[$292>>2] = $288;
  $293 = (($270) + 44|0);
  HEAPF32[$293>>2] = $289;
  STACKTOP = sp;return;
 } else {
  $i$11$i = 0;
 }
 while(1) {
  $260 = ((($apHumanPose) + ($i$11$i<<2)|0) + 672|0);
  $261 = Math_fround(HEAPF32[$260>>2]);
  $262 = ((($apHumanPoseOut) + ($i$11$i<<2)|0) + 672|0);
  HEAPF32[$262>>2] = $261;
  $263 = (($i$11$i) + 1)|0;
  $exitcond$i = ($263|0)==(52);
  if ($exitcond$i) {
   break;
  } else {
   $i$11$i = $263;
  }
 }
 $264 = (($apHumanPose) + 384|0);
 $265 = (($apHumanPoseOut) + 384|0);
 __ZN7mecanim4hand12HandPoseCopyEPKNS0_8HandPoseEPS1_($264,$265);
 $266 = (($apHumanPose) + 528|0);
 $267 = (($apHumanPoseOut) + 528|0);
 __ZN7mecanim4hand12HandPoseCopyEPKNS0_8HandPoseEPS1_($266,$267);
 __ZN7mecanim5human30HumanPoseAdjustForMissingBonesEPKNS0_5HumanEPNS0_9HumanPoseE($apHuman,$apHumanPoseOut);
 __ZN7mecanim5human18Human2SkeletonPoseEPKNS0_5HumanEPKNS0_9HumanPoseEPNS_8skeleton12SkeletonPoseE($apHuman,$apHumanPoseOut,$apSkeletonPose);
 $$pre = HEAP32[$193>>2]|0;
 $269 = $$pre;
 $268 = (($269) + ($194))|0;
 $270 = $268;
 HEAP32[$198>>2] = $270;
 $271 = Math_fround(HEAPF32[$apHumanPoseOut>>2]);
 $272 = Math_fround(HEAPF32[$9>>2]);
 $273 = Math_fround(HEAPF32[$12>>2]);
 $274 = Math_fround(HEAPF32[$15>>2]);
 HEAPF32[$270>>2] = $271;
 $275 = (($270) + 4|0);
 HEAPF32[$275>>2] = $272;
 $276 = (($270) + 8|0);
 HEAPF32[$276>>2] = $273;
 $277 = (($270) + 12|0);
 HEAPF32[$277>>2] = $274;
 $278 = Math_fround(HEAPF32[$33>>2]);
 $279 = Math_fround(HEAPF32[$34>>2]);
 $280 = Math_fround(HEAPF32[$35>>2]);
 $281 = Math_fround(HEAPF32[$36>>2]);
 $282 = (($270) + 16|0);
 HEAPF32[$282>>2] = $278;
 $283 = (($270) + 20|0);
 HEAPF32[$283>>2] = $279;
 $284 = (($270) + 24|0);
 HEAPF32[$284>>2] = $280;
 $285 = (($270) + 28|0);
 HEAPF32[$285>>2] = $281;
 $286 = Math_fround(HEAPF32[$45>>2]);
 $287 = Math_fround(HEAPF32[$46>>2]);
 $288 = Math_fround(HEAPF32[$47>>2]);
 $289 = Math_fround(HEAPF32[$48>>2]);
 $290 = (($270) + 32|0);
 HEAPF32[$290>>2] = $286;
 $291 = (($270) + 36|0);
 HEAPF32[$291>>2] = $287;
 $292 = (($270) + 40|0);
 HEAPF32[$292>>2] = $288;
 $293 = (($270) + 44|0);
 HEAPF32[$293>>2] = $289;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human15GetLookAtDeltaQERKN4math7_float4ES4_S4_S4_S4_RKf($agg$result,$pivot,$eyesT,$eyesQ,$eyesDir,$target,$weight) {
 $agg$result = $agg$result|0;
 $pivot = $pivot|0;
 $eyesT = $eyesT|0;
 $eyesQ = $eyesQ|0;
 $eyesDir = $eyesDir|0;
 $target = $target|0;
 $weight = $weight|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0;
 var $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0);
 var $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $weight$val = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$target>>2]);
 $1 = Math_fround(HEAPF32[$eyesT>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($target) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($eyesT) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($target) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($eyesT) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($target) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($eyesT) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 - $16);
 $18 = Math_fround($2 * $2);
 $19 = Math_fround($7 * $7);
 $20 = Math_fround($12 * $12);
 $21 = Math_fround($17 * $17);
 $22 = Math_fround($18 + $19);
 $23 = Math_fround($20 + $21);
 $24 = Math_fround($22 + $23);
 $25 = (Math_fround(Math_sqrt((Math_fround($24)))));
 $26 = Math_fround(HEAPF32[$pivot>>2]);
 $27 = Math_fround($0 - $26);
 $28 = (($pivot) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($4 - $29);
 $31 = (($pivot) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($9 - $32);
 $34 = (($pivot) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($14 - $35);
 $37 = Math_fround(HEAPF32[$eyesDir>>2]);
 $38 = Math_fround($25 * $37);
 $39 = (($eyesDir) + 4|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($25 * $40);
 $42 = (($eyesDir) + 8|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = Math_fround($25 * $43);
 $45 = (($eyesDir) + 12|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = Math_fround($25 * $46);
 $48 = Math_fround($38 + $38);
 $49 = Math_fround($41 + $41);
 $50 = Math_fround($44 + $44);
 $51 = Math_fround(HEAPF32[$eyesQ>>2]);
 $52 = Math_fround($49 * $51);
 $53 = (($eyesQ) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($50 * $54);
 $56 = (($eyesQ) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($48 * $57);
 $59 = (($eyesQ) + 12|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 * Math_fround(0.0));
 $62 = Math_fround($48 * $54);
 $63 = Math_fround($49 * $57);
 $64 = Math_fround($50 * $51);
 $65 = Math_fround($52 - $62);
 $66 = Math_fround($55 - $63);
 $67 = Math_fround($58 - $64);
 $68 = Math_fround($61 - $61);
 $69 = Math_fround($60 * $66);
 $70 = Math_fround($60 * $67);
 $71 = Math_fround($65 * $60);
 $72 = Math_fround($60 * $68);
 $73 = Math_fround($38 + $69);
 $74 = Math_fround($41 + $70);
 $75 = Math_fround($44 + $71);
 $76 = Math_fround($47 + $72);
 $77 = Math_fround($51 * $67);
 $78 = Math_fround($54 * $65);
 $79 = Math_fround($57 * $66);
 $80 = Math_fround($54 * $66);
 $81 = Math_fround($57 * $67);
 $82 = Math_fround($51 * $65);
 $83 = Math_fround($77 - $80);
 $84 = Math_fround($78 - $81);
 $85 = Math_fround($79 - $82);
 $86 = Math_fround($72 - $72);
 $87 = Math_fround($73 + $84);
 $88 = Math_fround($74 + $85);
 $89 = Math_fround($75 + $83);
 $90 = Math_fround($76 + $86);
 $91 = Math_fround($1 - $87);
 $92 = Math_fround($6 - $88);
 $93 = Math_fround($11 - $89);
 $94 = Math_fround($16 - $90);
 $95 = Math_fround($91 - $26);
 $96 = Math_fround($92 - $29);
 $97 = Math_fround($93 - $32);
 $98 = Math_fround($94 - $35);
 $99 = Math_fround($30 * $95);
 $100 = Math_fround($33 * $96);
 $101 = Math_fround($27 * $97);
 $102 = Math_fround($36 * $98);
 $103 = Math_fround($27 * $96);
 $104 = Math_fround($30 * $97);
 $105 = Math_fround($33 * $95);
 $106 = Math_fround($99 - $103);
 $107 = Math_fround($100 - $104);
 $108 = Math_fround($101 - $105);
 $109 = Math_fround($27 * $95);
 $110 = Math_fround($30 * $96);
 $111 = Math_fround($33 * $97);
 $112 = Math_fround($109 + $110);
 $113 = Math_fround($111 + $102);
 $114 = Math_fround($112 + $113);
 $115 = Math_fround($95 * $95);
 $116 = Math_fround($96 * $96);
 $117 = Math_fround($97 * $97);
 $118 = Math_fround($98 * $98);
 $119 = Math_fround($115 + $116);
 $120 = Math_fround($117 + $118);
 $121 = Math_fround($119 + $120);
 $122 = Math_fround($27 * $27);
 $123 = Math_fround($30 * $30);
 $124 = Math_fround($33 * $33);
 $125 = Math_fround($36 * $36);
 $126 = Math_fround($122 + $123);
 $127 = Math_fround($124 + $125);
 $128 = Math_fround($126 + $127);
 $129 = Math_fround($128 * $121);
 $130 = (Math_fround(Math_sqrt((Math_fround($129)))));
 $131 = Math_fround($130 + $114);
 $132 = Math_fround($107 * $107);
 $133 = Math_fround($108 * $108);
 $134 = Math_fround($106 * $106);
 $135 = Math_fround($131 * $131);
 $136 = Math_fround($132 + $133);
 $137 = Math_fround($134 + $135);
 $138 = Math_fround($136 + $137);
 $139 = (Math_fround(Math_sqrt((Math_fround($138)))));
 $140 = Math_fround(Math_fround(1.0) / $139);
 $141 = Math_fround($140 * $107);
 $142 = Math_fround($140 * $108);
 $143 = Math_fround($140 * $106);
 $144 = Math_fround($140 * $131);
 $weight$val = Math_fround(HEAPF32[$weight>>2]);
 $145 = Math_fround($weight$val * $141);
 $146 = Math_fround($weight$val * $142);
 $147 = Math_fround($weight$val * $143);
 $148 = Math_fround($145 * $145);
 $149 = Math_fround($146 * $146);
 $150 = Math_fround($147 * $147);
 $151 = Math_fround($144 * $144);
 $152 = Math_fround($148 + $149);
 $153 = Math_fround($150 + $151);
 $154 = Math_fround($152 + $153);
 $155 = (Math_fround(Math_sqrt((Math_fround($154)))));
 $156 = Math_fround(Math_fround(1.0) / $155);
 $157 = Math_fround($156 * $145);
 $158 = Math_fround($156 * $146);
 $159 = Math_fround($156 * $147);
 $160 = Math_fround($156 * $144);
 HEAPF32[$agg$result>>2] = $157;
 $161 = (($agg$result) + 4|0);
 HEAPF32[$161>>2] = $158;
 $162 = (($agg$result) + 8|0);
 HEAPF32[$162>>2] = $159;
 $163 = (($agg$result) + 12|0);
 HEAPF32[$163>>2] = $160;
 STACKTOP = sp;return;
}
function __ZN7mecanim5human13FullBodySolveEPKNS0_5HumanEPKNS0_9HumanPoseEPNS_8skeleton12SkeletonPoseES9_S9_($apHuman,$apHumanPose,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$apSkeletonPoseWorkspaceB) {
 $apHuman = $apHuman|0;
 $apHumanPose = $apHumanPose|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $apSkeletonPoseWorkspaceA = $apSkeletonPoseWorkspaceA|0;
 $apSkeletonPoseWorkspaceB = $apSkeletonPoseWorkspaceB|0;
 var $$$i$i = Math_fround(0), $$$i1$i = Math_fround(0), $$1$i$i = Math_fround(0), $$1$i2$i = Math_fround(0), $$in = 0, $$pre = Math_fround(0), $$pre$phi144Z2D = 0, $$pre136 = 0, $$pre137 = 0, $$pre138 = 0, $$pre139 = 0, $$pre143 = 0, $$v = Math_fround(0), $$v$i = Math_fround(0), $$v25$i = Math_fround(0), $$v26$i = Math_fround(0), $$v27$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0;
 var $100 = Math_fround(0), $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = Math_fround(0), $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = Math_fround(0), $1017 = 0;
 var $1018 = Math_fround(0), $1019 = 0, $102 = Math_fround(0), $1020 = Math_fround(0), $1021 = 0, $1022 = Math_fround(0), $1023 = 0, $1024 = Math_fround(0), $1025 = Math_fround(0), $1026 = 0, $1027 = Math_fround(0), $1028 = Math_fround(0), $1029 = 0, $103 = Math_fround(0), $1030 = Math_fround(0), $1031 = Math_fround(0), $1032 = 0, $1033 = Math_fround(0), $1034 = Math_fround(0), $1035 = Math_fround(0);
 var $1036 = Math_fround(0), $1037 = Math_fround(0), $1038 = Math_fround(0), $1039 = Math_fround(0), $104 = Math_fround(0), $1040 = Math_fround(0), $1041 = Math_fround(0), $1042 = Math_fround(0), $1043 = Math_fround(0), $1044 = Math_fround(0), $1045 = Math_fround(0), $1046 = Math_fround(0), $1047 = Math_fround(0), $1048 = Math_fround(0), $1049 = Math_fround(0), $105 = Math_fround(0), $1050 = Math_fround(0), $1051 = Math_fround(0), $1052 = Math_fround(0), $1053 = Math_fround(0);
 var $1054 = Math_fround(0), $1055 = Math_fround(0), $1056 = Math_fround(0), $1057 = Math_fround(0), $1058 = Math_fround(0), $1059 = Math_fround(0), $106 = Math_fround(0), $1060 = Math_fround(0), $1061 = Math_fround(0), $1062 = Math_fround(0), $1063 = Math_fround(0), $1064 = Math_fround(0), $1065 = Math_fround(0), $1066 = Math_fround(0), $1067 = Math_fround(0), $1068 = Math_fround(0), $1069 = Math_fround(0), $107 = Math_fround(0), $1070 = Math_fround(0), $1071 = Math_fround(0);
 var $1072 = Math_fround(0), $1073 = Math_fround(0), $1074 = Math_fround(0), $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = Math_fround(0), $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = Math_fround(0), $1085 = 0, $1086 = Math_fround(0), $1087 = Math_fround(0), $1088 = 0, $1089 = Math_fround(0), $109 = Math_fround(0);
 var $1090 = 0, $1091 = Math_fround(0), $1092 = Math_fround(0), $1093 = 0, $1094 = Math_fround(0), $1095 = 0, $1096 = Math_fround(0), $1097 = Math_fround(0), $1098 = 0, $1099 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $1100 = 0, $1101 = Math_fround(0), $1102 = Math_fround(0), $1103 = Math_fround(0), $1104 = Math_fround(0), $1105 = Math_fround(0), $1106 = Math_fround(0), $1107 = 0;
 var $1108 = Math_fround(0), $1109 = Math_fround(0), $111 = Math_fround(0), $1110 = 0, $1111 = Math_fround(0), $1112 = Math_fround(0), $1113 = 0, $1114 = Math_fround(0), $1115 = Math_fround(0), $1116 = 0, $1117 = Math_fround(0), $1118 = Math_fround(0), $1119 = Math_fround(0), $112 = Math_fround(0), $1120 = Math_fround(0), $1121 = Math_fround(0), $1122 = Math_fround(0), $1123 = Math_fround(0), $1124 = Math_fround(0), $1125 = Math_fround(0);
 var $1126 = Math_fround(0), $1127 = Math_fround(0), $1128 = Math_fround(0), $1129 = Math_fround(0), $113 = Math_fround(0), $1130 = Math_fround(0), $1131 = Math_fround(0), $1132 = Math_fround(0), $1133 = Math_fround(0), $1134 = Math_fround(0), $1135 = Math_fround(0), $1136 = Math_fround(0), $1137 = Math_fround(0), $1138 = Math_fround(0), $1139 = Math_fround(0), $114 = Math_fround(0), $1140 = Math_fround(0), $1141 = Math_fround(0), $1142 = Math_fround(0), $1143 = Math_fround(0);
 var $1144 = Math_fround(0), $1145 = Math_fround(0), $1146 = Math_fround(0), $1147 = Math_fround(0), $1148 = Math_fround(0), $1149 = Math_fround(0), $115 = Math_fround(0), $1150 = Math_fround(0), $1151 = Math_fround(0), $1152 = Math_fround(0), $1153 = Math_fround(0), $1154 = Math_fround(0), $1155 = Math_fround(0), $1156 = Math_fround(0), $1157 = Math_fround(0), $1158 = Math_fround(0), $1159 = 0, $116 = Math_fround(0), $1160 = Math_fround(0), $1161 = Math_fround(0);
 var $1162 = 0, $1163 = Math_fround(0), $1164 = Math_fround(0), $1165 = 0, $1166 = Math_fround(0), $1167 = Math_fround(0), $1168 = 0, $1169 = Math_fround(0), $117 = Math_fround(0), $1170 = Math_fround(0), $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = Math_fround(0), $1179 = 0, $118 = Math_fround(0);
 var $1180 = Math_fround(0), $1181 = Math_fround(0), $1182 = Math_fround(0), $1183 = 0, $1184 = Math_fround(0), $1185 = Math_fround(0), $1186 = Math_fround(0), $1187 = 0, $1188 = Math_fround(0), $1189 = Math_fround(0), $119 = Math_fround(0), $1190 = Math_fround(0), $1191 = 0, $1192 = Math_fround(0), $1193 = Math_fround(0), $1194 = Math_fround(0), $1195 = Math_fround(0), $1196 = Math_fround(0), $1197 = Math_fround(0), $1198 = Math_fround(0);
 var $1199 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $1200 = Math_fround(0), $1201 = Math_fround(0), $1202 = Math_fround(0), $1203 = Math_fround(0), $1204 = Math_fround(0), $1205 = Math_fround(0), $1206 = Math_fround(0), $1207 = Math_fround(0), $1208 = Math_fround(0), $1209 = Math_fround(0), $121 = Math_fround(0), $1210 = Math_fround(0), $1211 = Math_fround(0), $1212 = Math_fround(0), $1213 = Math_fround(0), $1214 = Math_fround(0), $1215 = Math_fround(0);
 var $1216 = Math_fround(0), $1217 = Math_fround(0), $1218 = Math_fround(0), $1219 = Math_fround(0), $122 = Math_fround(0), $1220 = Math_fround(0), $1221 = Math_fround(0), $1222 = Math_fround(0), $1223 = Math_fround(0), $1224 = Math_fround(0), $1225 = Math_fround(0), $1226 = Math_fround(0), $1227 = Math_fround(0), $1228 = Math_fround(0), $1229 = Math_fround(0), $123 = Math_fround(0), $1230 = Math_fround(0), $1231 = Math_fround(0), $1232 = Math_fround(0), $1233 = Math_fround(0);
 var $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = Math_fround(0), $1240 = 0, $1241 = Math_fround(0), $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = Math_fround(0), $1250 = 0, $1251 = 0;
 var $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = Math_fround(0), $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = Math_fround(0);
 var $1270 = 0, $1271 = 0, $1272 = 0, $1273 = Math_fround(0), $1274 = 0, $1275 = Math_fround(0), $1276 = 0, $1277 = Math_fround(0), $1278 = 0, $1279 = Math_fround(0), $128 = Math_fround(0), $1280 = 0, $1281 = Math_fround(0), $1282 = Math_fround(0), $1283 = 0, $1284 = Math_fround(0), $1285 = Math_fround(0), $1286 = 0, $1287 = Math_fround(0), $1288 = Math_fround(0);
 var $1289 = 0, $129 = Math_fround(0), $1290 = Math_fround(0), $1291 = Math_fround(0), $1292 = Math_fround(0), $1293 = Math_fround(0), $1294 = Math_fround(0), $1295 = Math_fround(0), $1296 = Math_fround(0), $1297 = Math_fround(0), $1298 = Math_fround(0), $1299 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $1300 = Math_fround(0), $1301 = Math_fround(0), $1302 = Math_fround(0), $1303 = Math_fround(0), $1304 = Math_fround(0), $1305 = Math_fround(0);
 var $1306 = Math_fround(0), $1307 = Math_fround(0), $1308 = Math_fround(0), $1309 = Math_fround(0), $131 = Math_fround(0), $1310 = Math_fround(0), $1311 = Math_fround(0), $1312 = Math_fround(0), $1313 = Math_fround(0), $1314 = Math_fround(0), $1315 = Math_fround(0), $1316 = Math_fround(0), $1317 = Math_fround(0), $1318 = Math_fround(0), $1319 = Math_fround(0), $132 = Math_fround(0), $1320 = Math_fround(0), $1321 = Math_fround(0), $1322 = Math_fround(0), $1323 = Math_fround(0);
 var $1324 = Math_fround(0), $1325 = Math_fround(0), $1326 = Math_fround(0), $1327 = Math_fround(0), $1328 = Math_fround(0), $1329 = Math_fround(0), $133 = Math_fround(0), $1330 = Math_fround(0), $1331 = Math_fround(0), $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = Math_fround(0), $1340 = 0, $1341 = 0;
 var $1342 = Math_fround(0), $1343 = 0, $1344 = Math_fround(0), $1345 = Math_fround(0), $1346 = 0, $1347 = Math_fround(0), $1348 = 0, $1349 = Math_fround(0), $135 = Math_fround(0), $1350 = Math_fround(0), $1351 = 0, $1352 = Math_fround(0), $1353 = 0, $1354 = Math_fround(0), $1355 = Math_fround(0), $1356 = Math_fround(0), $1357 = 0, $1358 = Math_fround(0), $1359 = Math_fround(0), $136 = 0;
 var $1360 = Math_fround(0), $1361 = Math_fround(0), $1362 = Math_fround(0), $1363 = Math_fround(0), $1364 = Math_fround(0), $1365 = Math_fround(0), $1366 = Math_fround(0), $1367 = Math_fround(0), $1368 = Math_fround(0), $1369 = Math_fround(0), $137 = 0, $1370 = Math_fround(0), $1371 = Math_fround(0), $1372 = Math_fround(0), $1373 = Math_fround(0), $1374 = Math_fround(0), $1375 = Math_fround(0), $1376 = Math_fround(0), $1377 = Math_fround(0), $1378 = Math_fround(0);
 var $1379 = Math_fround(0), $138 = 0, $1380 = Math_fround(0), $1381 = Math_fround(0), $1382 = Math_fround(0), $1383 = Math_fround(0), $1384 = Math_fround(0), $1385 = Math_fround(0), $1386 = Math_fround(0), $1387 = Math_fround(0), $1388 = Math_fround(0), $1389 = Math_fround(0), $139 = 0, $1390 = Math_fround(0), $1391 = Math_fround(0), $1392 = Math_fround(0), $1393 = Math_fround(0), $1394 = Math_fround(0), $1395 = Math_fround(0), $1396 = Math_fround(0);
 var $1397 = Math_fround(0), $1398 = Math_fround(0), $1399 = Math_fround(0), $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0;
 var $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0;
 var $1432 = 0, $1433 = Math_fround(0), $1434 = 0, $1435 = Math_fround(0), $1436 = 0, $1437 = Math_fround(0), $1438 = 0, $1439 = Math_fround(0), $144 = 0, $1440 = 0, $1441 = Math_fround(0), $1442 = Math_fround(0), $1443 = 0, $1444 = Math_fround(0), $1445 = Math_fround(0), $1446 = 0, $1447 = Math_fround(0), $1448 = Math_fround(0), $1449 = 0, $145 = 0;
 var $1450 = Math_fround(0), $1451 = Math_fround(0), $1452 = Math_fround(0), $1453 = Math_fround(0), $1454 = Math_fround(0), $1455 = Math_fround(0), $1456 = Math_fround(0), $1457 = Math_fround(0), $1458 = Math_fround(0), $1459 = Math_fround(0), $146 = 0, $1460 = Math_fround(0), $1461 = Math_fround(0), $1462 = Math_fround(0), $1463 = Math_fround(0), $1464 = Math_fround(0), $1465 = Math_fround(0), $1466 = Math_fround(0), $1467 = Math_fround(0), $1468 = Math_fround(0);
 var $1469 = Math_fround(0), $147 = 0, $1470 = Math_fround(0), $1471 = Math_fround(0), $1472 = Math_fround(0), $1473 = Math_fround(0), $1474 = Math_fround(0), $1475 = Math_fround(0), $1476 = Math_fround(0), $1477 = Math_fround(0), $1478 = Math_fround(0), $1479 = Math_fround(0), $148 = 0, $1480 = Math_fround(0), $1481 = Math_fround(0), $1482 = Math_fround(0), $1483 = Math_fround(0), $1484 = Math_fround(0), $1485 = Math_fround(0), $1486 = Math_fround(0);
 var $1487 = Math_fround(0), $1488 = Math_fround(0), $1489 = Math_fround(0), $149 = Math_fround(0), $1490 = Math_fround(0), $1491 = Math_fround(0), $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = Math_fround(0), $1503 = 0;
 var $1504 = Math_fround(0), $1505 = Math_fround(0), $1506 = 0, $1507 = Math_fround(0), $1508 = 0, $1509 = Math_fround(0), $151 = Math_fround(0), $1510 = Math_fround(0), $1511 = 0, $1512 = Math_fround(0), $1513 = 0, $1514 = Math_fround(0), $1515 = Math_fround(0), $1516 = Math_fround(0), $1517 = 0, $1518 = Math_fround(0), $1519 = Math_fround(0), $152 = Math_fround(0), $1520 = Math_fround(0), $1521 = Math_fround(0);
 var $1522 = Math_fround(0), $1523 = Math_fround(0), $1524 = Math_fround(0), $1525 = Math_fround(0), $1526 = Math_fround(0), $1527 = Math_fround(0), $1528 = Math_fround(0), $1529 = Math_fround(0), $153 = 0, $1530 = Math_fround(0), $1531 = Math_fround(0), $1532 = Math_fround(0), $1533 = Math_fround(0), $1534 = Math_fround(0), $1535 = Math_fround(0), $1536 = Math_fround(0), $1537 = Math_fround(0), $1538 = Math_fround(0), $1539 = Math_fround(0), $154 = Math_fround(0);
 var $1540 = Math_fround(0), $1541 = Math_fround(0), $1542 = Math_fround(0), $1543 = Math_fround(0), $1544 = Math_fround(0), $1545 = Math_fround(0), $1546 = Math_fround(0), $1547 = Math_fround(0), $1548 = Math_fround(0), $1549 = Math_fround(0), $155 = 0, $1550 = Math_fround(0), $1551 = Math_fround(0), $1552 = Math_fround(0), $1553 = Math_fround(0), $1554 = Math_fround(0), $1555 = Math_fround(0), $1556 = Math_fround(0), $1557 = Math_fround(0), $1558 = Math_fround(0);
 var $1559 = Math_fround(0), $156 = Math_fround(0), $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = Math_fround(0), $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0;
 var $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = Math_fround(0), $1590 = Math_fround(0), $1591 = 0, $1592 = Math_fround(0), $1593 = Math_fround(0), $1594 = 0;
 var $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = Math_fround(0), $1602 = 0, $1603 = Math_fround(0), $1604 = Math_fround(0), $1605 = 0, $1606 = Math_fround(0), $1607 = 0, $1608 = Math_fround(0), $1609 = Math_fround(0), $161 = Math_fround(0), $1610 = 0, $1611 = Math_fround(0);
 var $1612 = 0, $1613 = Math_fround(0), $1614 = Math_fround(0), $1615 = 0, $1616 = Math_fround(0), $1617 = 0, $1618 = Math_fround(0), $1619 = Math_fround(0), $162 = Math_fround(0), $1620 = Math_fround(0), $1621 = Math_fround(0), $1622 = Math_fround(0), $1623 = Math_fround(0), $1624 = Math_fround(0), $1625 = Math_fround(0), $1626 = Math_fround(0), $1627 = Math_fround(0), $1628 = 0, $1629 = 0, $163 = 0;
 var $1630 = 0, $1631 = 0, $1632 = Math_fround(0), $1633 = Math_fround(0), $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = Math_fround(0), $1640 = 0, $1641 = Math_fround(0), $1642 = 0, $1643 = Math_fround(0), $1644 = Math_fround(0), $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0;
 var $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = Math_fround(0), $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = Math_fround(0), $1660 = Math_fround(0), $1661 = Math_fround(0), $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0;
 var $1667 = 0, $1668 = 0, $1669 = 0, $167 = Math_fround(0), $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = Math_fround(0), $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0;
 var $1685 = 0, $1686 = 0, $1687 = 0, $1688 = Math_fround(0), $1689 = 0, $169 = Math_fround(0), $1690 = Math_fround(0), $1691 = 0, $1692 = Math_fround(0), $1693 = 0, $1694 = Math_fround(0), $1695 = 0, $1696 = Math_fround(0), $1697 = Math_fround(0), $1698 = 0, $1699 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $1700 = Math_fround(0), $1701 = 0;
 var $1702 = Math_fround(0), $1703 = Math_fround(0), $1704 = 0, $1705 = Math_fround(0), $1706 = Math_fround(0), $1707 = Math_fround(0), $1708 = Math_fround(0), $1709 = Math_fround(0), $171 = Math_fround(0), $1710 = Math_fround(0), $1711 = Math_fround(0), $1712 = Math_fround(0), $1713 = Math_fround(0), $1714 = Math_fround(0), $1715 = Math_fround(0), $1716 = Math_fround(0), $1717 = Math_fround(0), $1718 = Math_fround(0), $1719 = Math_fround(0), $172 = 0;
 var $1720 = Math_fround(0), $1721 = Math_fround(0), $1722 = Math_fround(0), $1723 = Math_fround(0), $1724 = Math_fround(0), $1725 = Math_fround(0), $1726 = Math_fround(0), $1727 = Math_fround(0), $1728 = Math_fround(0), $1729 = Math_fround(0), $173 = Math_fround(0), $1730 = Math_fround(0), $1731 = Math_fround(0), $1732 = Math_fround(0), $1733 = Math_fround(0), $1734 = Math_fround(0), $1735 = Math_fround(0), $1736 = Math_fround(0), $1737 = Math_fround(0), $1738 = Math_fround(0);
 var $1739 = Math_fround(0), $174 = Math_fround(0), $1740 = Math_fround(0), $1741 = Math_fround(0), $1742 = Math_fround(0), $1743 = Math_fround(0), $1744 = Math_fround(0), $1745 = Math_fround(0), $1746 = Math_fround(0), $1747 = 0, $1748 = Math_fround(0), $1749 = Math_fround(0), $175 = 0, $1750 = 0, $1751 = Math_fround(0), $1752 = Math_fround(0), $1753 = 0, $1754 = Math_fround(0), $1755 = Math_fround(0), $1756 = 0;
 var $1757 = Math_fround(0), $1758 = Math_fround(0), $1759 = Math_fround(0), $176 = Math_fround(0), $1760 = Math_fround(0), $1761 = Math_fround(0), $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = Math_fround(0), $1767 = 0, $1768 = 0, $1769 = Math_fround(0), $177 = Math_fround(0), $1770 = 0, $1771 = 0, $1772 = Math_fround(0), $1773 = 0, $1774 = 0;
 var $1775 = Math_fround(0), $1776 = Math_fround(0), $1777 = Math_fround(0), $1778 = Math_fround(0), $1779 = Math_fround(0), $178 = 0, $1780 = Math_fround(0), $1781 = Math_fround(0), $1782 = Math_fround(0), $1783 = Math_fround(0), $1784 = Math_fround(0), $1785 = Math_fround(0), $1786 = Math_fround(0), $1787 = Math_fround(0), $1788 = Math_fround(0), $1789 = Math_fround(0), $179 = Math_fround(0), $1790 = Math_fround(0), $1791 = Math_fround(0), $1792 = Math_fround(0);
 var $1793 = Math_fround(0), $1794 = Math_fround(0), $1795 = Math_fround(0), $1796 = Math_fround(0), $1797 = Math_fround(0), $1798 = Math_fround(0), $1799 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $1800 = Math_fround(0), $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0;
 var $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = Math_fround(0), $1818 = 0, $1819 = Math_fround(0), $182 = Math_fround(0), $1820 = 0, $1821 = Math_fround(0), $1822 = 0, $1823 = Math_fround(0), $1824 = Math_fround(0), $1825 = Math_fround(0), $1826 = Math_fround(0), $1827 = Math_fround(0), $1828 = Math_fround(0);
 var $1829 = Math_fround(0), $183 = Math_fround(0), $1830 = Math_fround(0), $1831 = Math_fround(0), $1832 = Math_fround(0), $1833 = Math_fround(0), $1834 = Math_fround(0), $1835 = Math_fround(0), $1836 = Math_fround(0), $1837 = Math_fround(0), $1838 = Math_fround(0), $1839 = Math_fround(0), $184 = Math_fround(0), $1840 = Math_fround(0), $1841 = Math_fround(0), $1842 = Math_fround(0), $1843 = Math_fround(0), $1844 = Math_fround(0), $1845 = Math_fround(0), $1846 = Math_fround(0);
 var $1847 = Math_fround(0), $1848 = Math_fround(0), $1849 = Math_fround(0), $185 = Math_fround(0), $1850 = Math_fround(0), $1851 = Math_fround(0), $1852 = Math_fround(0), $1853 = Math_fround(0), $1854 = Math_fround(0), $1855 = Math_fround(0), $1856 = Math_fround(0), $1857 = Math_fround(0), $1858 = Math_fround(0), $1859 = Math_fround(0), $186 = Math_fround(0), $1860 = Math_fround(0), $1861 = Math_fround(0), $1862 = Math_fround(0), $1863 = Math_fround(0), $1864 = Math_fround(0);
 var $1865 = Math_fround(0), $1866 = Math_fround(0), $1867 = Math_fround(0), $1868 = Math_fround(0), $1869 = Math_fround(0), $187 = Math_fround(0), $1870 = Math_fround(0), $1871 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0);
 var $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0);
 var $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = Math_fround(0);
 var $234 = Math_fround(0), $235 = 0, $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = Math_fround(0), $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0);
 var $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = Math_fround(0);
 var $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0);
 var $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0);
 var $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = Math_fround(0), $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0);
 var $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = Math_fround(0);
 var $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = Math_fround(0);
 var $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0), $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = Math_fround(0), $376 = Math_fround(0), $377 = Math_fround(0), $378 = Math_fround(0);
 var $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = Math_fround(0), $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0);
 var $397 = 0, $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = 0, $430 = Math_fround(0), $431 = 0;
 var $432 = Math_fround(0), $433 = 0, $434 = Math_fround(0), $435 = Math_fround(0), $436 = 0, $437 = Math_fround(0), $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = Math_fround(0), $441 = Math_fround(0), $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = Math_fround(0), $447 = Math_fround(0), $448 = Math_fround(0), $449 = Math_fround(0), $45 = 0;
 var $450 = Math_fround(0), $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = Math_fround(0), $456 = Math_fround(0), $457 = Math_fround(0), $458 = Math_fround(0), $459 = Math_fround(0), $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0);
 var $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0), $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = 0, $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = Math_fround(0), $497 = 0, $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = 0, $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0);
 var $504 = Math_fround(0), $505 = 0, $506 = Math_fround(0), $507 = 0, $508 = Math_fround(0), $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0);
 var $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0);
 var $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0;
 var $559 = 0, $56 = Math_fround(0), $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0;
 var $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = Math_fround(0), $582 = 0, $583 = Math_fround(0), $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = 0, $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = 0, $592 = Math_fround(0), $593 = Math_fround(0), $594 = 0;
 var $595 = Math_fround(0), $596 = Math_fround(0), $597 = 0, $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = 0, $610 = Math_fround(0), $611 = Math_fround(0);
 var $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0), $617 = Math_fround(0), $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = Math_fround(0), $621 = Math_fround(0), $622 = Math_fround(0), $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0;
 var $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0), $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0;
 var $649 = 0, $65 = 0, $650 = 0, $651 = Math_fround(0), $652 = 0, $653 = Math_fround(0), $654 = Math_fround(0), $655 = 0, $656 = Math_fround(0), $657 = 0, $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = 0, $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = 0;
 var $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = Math_fround(0), $675 = Math_fround(0), $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0), $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0);
 var $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = Math_fround(0), $689 = Math_fround(0), $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0), $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0);
 var $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0;
 var $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0;
 var $739 = 0, $74 = 0, $740 = 0, $741 = Math_fround(0), $742 = 0, $743 = Math_fround(0), $744 = 0, $745 = Math_fround(0), $746 = 0, $747 = Math_fround(0), $748 = 0, $749 = Math_fround(0), $75 = 0, $750 = Math_fround(0), $751 = 0, $752 = Math_fround(0), $753 = Math_fround(0), $754 = 0, $755 = Math_fround(0), $756 = Math_fround(0);
 var $757 = 0, $758 = Math_fround(0), $759 = Math_fround(0), $76 = 0, $760 = Math_fround(0), $761 = Math_fround(0), $762 = Math_fround(0), $763 = Math_fround(0), $764 = Math_fround(0), $765 = Math_fround(0), $766 = Math_fround(0), $767 = Math_fround(0), $768 = Math_fround(0), $769 = Math_fround(0), $77 = Math_fround(0), $770 = Math_fround(0), $771 = Math_fround(0), $772 = Math_fround(0), $773 = Math_fround(0), $774 = Math_fround(0);
 var $775 = Math_fround(0), $776 = Math_fround(0), $777 = Math_fround(0), $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = Math_fround(0), $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = Math_fround(0), $788 = Math_fround(0), $789 = Math_fround(0), $79 = Math_fround(0), $790 = Math_fround(0), $791 = Math_fround(0), $792 = Math_fround(0);
 var $793 = Math_fround(0), $794 = Math_fround(0), $795 = Math_fround(0), $796 = Math_fround(0), $797 = Math_fround(0), $798 = Math_fround(0), $799 = Math_fround(0), $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = Math_fround(0);
 var $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = Math_fround(0), $817 = 0, $818 = Math_fround(0), $819 = Math_fround(0), $82 = 0, $820 = 0, $821 = Math_fround(0), $822 = 0, $823 = Math_fround(0), $824 = Math_fround(0), $825 = 0, $826 = Math_fround(0), $827 = 0, $828 = Math_fround(0);
 var $829 = Math_fround(0), $83 = Math_fround(0), $830 = 0, $831 = Math_fround(0), $832 = 0, $833 = Math_fround(0), $834 = Math_fround(0), $835 = Math_fround(0), $836 = Math_fround(0), $837 = Math_fround(0), $838 = Math_fround(0), $839 = 0, $84 = 0, $840 = Math_fround(0), $841 = Math_fround(0), $842 = 0, $843 = Math_fround(0), $844 = Math_fround(0), $845 = 0, $846 = Math_fround(0);
 var $847 = Math_fround(0), $848 = 0, $849 = Math_fround(0), $85 = Math_fround(0), $850 = Math_fround(0), $851 = Math_fround(0), $852 = Math_fround(0), $853 = Math_fround(0), $854 = Math_fround(0), $855 = Math_fround(0), $856 = Math_fround(0), $857 = Math_fround(0), $858 = Math_fround(0), $859 = Math_fround(0), $86 = Math_fround(0), $860 = Math_fround(0), $861 = Math_fround(0), $862 = Math_fround(0), $863 = Math_fround(0), $864 = Math_fround(0);
 var $865 = Math_fround(0), $866 = Math_fround(0), $867 = Math_fround(0), $868 = Math_fround(0), $869 = Math_fround(0), $87 = 0, $870 = Math_fround(0), $871 = Math_fround(0), $872 = Math_fround(0), $873 = Math_fround(0), $874 = Math_fround(0), $875 = Math_fround(0), $876 = Math_fround(0), $877 = Math_fround(0), $878 = Math_fround(0), $879 = Math_fround(0), $88 = Math_fround(0), $880 = Math_fround(0), $881 = Math_fround(0), $882 = Math_fround(0);
 var $883 = Math_fround(0), $884 = Math_fround(0), $885 = Math_fround(0), $886 = Math_fround(0), $887 = Math_fround(0), $888 = Math_fround(0), $889 = Math_fround(0), $89 = Math_fround(0), $890 = Math_fround(0), $891 = 0, $892 = Math_fround(0), $893 = Math_fround(0), $894 = 0, $895 = Math_fround(0), $896 = Math_fround(0), $897 = 0, $898 = Math_fround(0), $899 = Math_fround(0), $9 = 0, $90 = 0;
 var $900 = 0, $901 = Math_fround(0), $902 = Math_fround(0), $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = Math_fround(0), $910 = 0, $911 = 0, $912 = 0, $913 = Math_fround(0), $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = Math_fround(0);
 var $919 = 0, $92 = Math_fround(0), $920 = Math_fround(0), $921 = Math_fround(0), $922 = 0, $923 = Math_fround(0), $924 = 0, $925 = Math_fround(0), $926 = Math_fround(0), $927 = 0, $928 = Math_fround(0), $929 = 0, $93 = 0, $930 = Math_fround(0), $931 = Math_fround(0), $932 = Math_fround(0), $933 = 0, $934 = Math_fround(0), $935 = Math_fround(0), $936 = Math_fround(0);
 var $937 = Math_fround(0), $938 = Math_fround(0), $939 = Math_fround(0), $94 = Math_fround(0), $940 = Math_fround(0), $941 = Math_fround(0), $942 = Math_fround(0), $943 = Math_fround(0), $944 = Math_fround(0), $945 = Math_fround(0), $946 = Math_fround(0), $947 = Math_fround(0), $948 = Math_fround(0), $949 = Math_fround(0), $95 = Math_fround(0), $950 = Math_fround(0), $951 = Math_fround(0), $952 = Math_fround(0), $953 = Math_fround(0), $954 = Math_fround(0);
 var $955 = Math_fround(0), $956 = Math_fround(0), $957 = Math_fround(0), $958 = Math_fround(0), $959 = Math_fround(0), $96 = Math_fround(0), $960 = Math_fround(0), $961 = Math_fround(0), $962 = Math_fround(0), $963 = Math_fround(0), $964 = Math_fround(0), $965 = Math_fround(0), $966 = Math_fround(0), $967 = Math_fround(0), $968 = Math_fround(0), $969 = Math_fround(0), $97 = Math_fround(0), $970 = Math_fround(0), $971 = Math_fround(0), $972 = Math_fround(0);
 var $973 = Math_fround(0), $974 = Math_fround(0), $975 = Math_fround(0), $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = Math_fround(0), $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = Math_fround(0), $988 = 0, $989 = 0, $99 = Math_fround(0), $990 = 0;
 var $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $deltaQ12 = 0, $deltaQ15 = 0, $deltaQ18 = 0, $deltaQ3 = 0, $deltaQ6 = 0, $deltaQ9 = 0, $exitcond = 0, $exitcond134 = 0, $exitcond135 = 0, $eyesPos1 = 0, $eyesPos10 = 0;
 var $eyesPos13 = 0, $eyesPos16 = 0, $eyesPos4 = 0, $eyesPos7 = 0, $eyesRot11 = 0, $eyesRot14 = 0, $eyesRot17 = 0, $eyesRot2 = 0, $eyesRot5 = 0, $eyesRot8 = 0, $goalIter$0131 = 0, $goalIter$1129 = 0, $headGoalT = 0, $iter$0133 = 0, $lbw = 0, $lew = 0, $lsw = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0;
 var $q = 0, $t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $lbw = sp + 468|0;
 $lew = sp + 464|0;
 $headGoalT = sp + 448|0;
 $lsw = sp + 440|0;
 $eyesPos1 = sp + 424|0;
 $eyesRot2 = sp + 408|0;
 $deltaQ3 = sp + 392|0;
 $0 = sp + 376|0;
 $eyesPos4 = sp + 360|0;
 $eyesRot5 = sp + 344|0;
 $deltaQ6 = sp + 328|0;
 $1 = sp + 312|0;
 $eyesPos7 = sp + 296|0;
 $eyesRot8 = sp + 280|0;
 $deltaQ9 = sp + 264|0;
 $2 = sp + 248|0;
 $3 = sp + 240|0;
 $eyesPos10 = sp + 88|0;
 $eyesRot11 = sp;
 $deltaQ12 = sp + 16|0;
 $4 = sp + 32|0;
 $5 = sp + 48|0;
 $eyesPos13 = sp + 56|0;
 $eyesRot14 = sp + 72|0;
 $deltaQ15 = sp + 104|0;
 $6 = sp + 120|0;
 $eyesPos16 = sp + 136|0;
 $eyesRot17 = sp + 152|0;
 $deltaQ18 = sp + 168|0;
 $7 = sp + 184|0;
 $t = sp + 200|0;
 $8 = sp + 216|0;
 $q = sp + 224|0;
 $9 = (($apHuman) + 104|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($apHuman) + 136|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($apHuman) + 132|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($apHuman) + 140|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($apHuman) + 144|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($apHuman) + 188|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($apHuman) + 192|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($apHumanPose) + 64|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = $24 < Math_fround(0.0);
 $$$i1$i = $25 ? Math_fround(0.0) : $24;
 $26 = (($apHumanPose) + 68|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = $27 < Math_fround(0.0);
 $29 = $28 ? Math_fround(0.0) : $27;
 $30 = (($apHumanPose) + 72|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = $31 < Math_fround(0.0);
 $$1$i2$i = $32 ? Math_fround(0.0) : $31;
 $33 = (($apHumanPose) + 76|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = $34 < Math_fround(0.0);
 $36 = $35 ? Math_fround(0.0) : $34;
 $37 = $$$i1$i > Math_fround(1.0);
 $$$i$i = $37 ? Math_fround(1.0) : $$$i1$i;
 $38 = $29 > Math_fround(1.0);
 $39 = $38 ? Math_fround(1.0) : $29;
 $40 = $$1$i2$i > Math_fround(1.0);
 $$1$i$i = $40 ? Math_fround(1.0) : $$1$i2$i;
 $41 = $36 > Math_fround(1.0);
 $42 = $41 ? Math_fround(1.0) : $36;
 HEAPF32[$lbw>>2] = $39;
 HEAPF32[$lew>>2] = $42;
 $43 = (($apHumanPose) + 48|0);
 ;HEAP32[$headGoalT+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$headGoalT+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$headGoalT+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$headGoalT+12>>2]=HEAP32[$43+12>>2]|0;
 $44 = $$$i$i > Math_fround(0.0);
 if ($44) {
  $45 = (($apSkeletonPoseWorkspaceA) + 4|0);
  $46 = $45;
  $47 = HEAP32[$45>>2]|0;
  $48 = (($47) + ($46))|0;
  $49 = $48;
  $50 = (($apSkeletonPoseWorkspaceA) + 8|0);
  HEAP32[$50>>2] = $49;
  $51 = (($49) + (($18*48)|0)|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = ((($49) + (($18*48)|0)|0) + 4|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = ((($49) + (($18*48)|0)|0) + 8|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = ((($49) + (($18*48)|0)|0) + 12|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  HEAP32[$50>>2] = $49;
  $59 = (($apHuman) + 48|0);
  $60 = $59;
  $61 = HEAP32[$59>>2]|0;
  $62 = (($61) + ($60))|0;
  $63 = $62;
  $64 = (($63) + 24|0);
  $65 = (($63) + 4|0);
  $66 = $65;
  $67 = HEAP32[$65>>2]|0;
  $68 = (($66) + ($67))|0;
  $69 = $68;
  $70 = ((($69) + ($18<<3)|0) + 4|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = $64;
  $73 = HEAP32[$64>>2]|0;
  $74 = (($72) + ($73))|0;
  $75 = $74;
  $76 = ((($75) + (($71*88)|0)|0) + 16|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = ((($75) + (($71*88)|0)|0) + 20|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = ((($75) + (($71*88)|0)|0) + 24|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = ((($75) + (($71*88)|0)|0) + 28|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = ((($49) + (($18*48)|0)|0) + 20|0);
  $85 = Math_fround(HEAPF32[$84>>2]);
  $86 = Math_fround($77 * $85);
  $87 = ((($49) + (($18*48)|0)|0) + 28|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($83 * $88);
  $90 = ((($49) + (($18*48)|0)|0) + 24|0);
  $91 = Math_fround(HEAPF32[$90>>2]);
  $92 = Math_fround($79 * $91);
  $93 = ((($49) + (($18*48)|0)|0) + 16|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = Math_fround($81 * $94);
  $96 = Math_fround($81 * $88);
  $97 = Math_fround($77 * $94);
  $98 = Math_fround($81 * $85);
  $99 = Math_fround($77 * $91);
  $100 = Math_fround($86 - $96);
  $101 = Math_fround($89 - $97);
  $102 = Math_fround($92 - $98);
  $103 = Math_fround($95 - $99);
  $104 = Math_fround($83 * $91);
  $105 = Math_fround($81 * $91);
  $106 = Math_fround($77 * $88);
  $107 = Math_fround($79 * $88);
  $108 = Math_fround($100 - $104);
  $109 = Math_fround($101 - $105);
  $110 = Math_fround($102 - $106);
  $111 = Math_fround($103 - $107);
  $112 = Math_fround($79 * $94);
  $113 = Math_fround($79 * $85);
  $114 = Math_fround($83 * $94);
  $115 = Math_fround($83 * $85);
  $116 = Math_fround($108 - $112);
  $117 = Math_fround($109 - $113);
  $118 = Math_fround($110 - $114);
  $119 = Math_fround($111 - $115);
  $120 = Math_fround($118 * Math_fround(-1.0));
  $121 = Math_fround($119 * Math_fround(-1.0));
  $122 = Math_fround($116 * Math_fround(-1.0));
  $123 = Math_fround($120 * $120);
  $124 = Math_fround($121 * $121);
  $125 = Math_fround($122 * $122);
  $126 = Math_fround($117 * $117);
  $127 = Math_fround($123 + $124);
  $128 = Math_fround($125 + $126);
  $129 = Math_fround($128 + $127);
  $130 = (Math_fround(Math_sqrt((Math_fround($129)))));
  $131 = Math_fround(Math_fround(1.0) / $130);
  $132 = Math_fround($131 * $120);
  $133 = Math_fround($131 * $121);
  $134 = Math_fround($131 * $122);
  $135 = Math_fround($131 * $117);
  $136 = ($20|0)==(-1);
  $137 = ($22|0)==(-1);
  $or$cond = $136 | $137;
  if ($or$cond) {
   $226 = $52;$230 = $54;$234 = $56;$238 = $58;
  } else {
   HEAP32[$50>>2] = $49;
   $138 = (($apHuman) + 56|0);
   $139 = $138;
   $140 = HEAP32[$138>>2]|0;
   $141 = (($140) + ($139))|0;
   $142 = $141;
   $143 = (($142) + 4|0);
   $144 = $143;
   $145 = HEAP32[$143>>2]|0;
   $146 = (($144) + ($145))|0;
   $147 = $146;
   $148 = (($147) + (($20*48)|0)|0);
   $149 = Math_fround(HEAPF32[$148>>2]);
   $150 = (($147) + (($22*48)|0)|0);
   $151 = Math_fround(HEAPF32[$150>>2]);
   $152 = Math_fround($149 + $151);
   $153 = ((($147) + (($20*48)|0)|0) + 4|0);
   $154 = Math_fround(HEAPF32[$153>>2]);
   $155 = ((($147) + (($22*48)|0)|0) + 4|0);
   $156 = Math_fround(HEAPF32[$155>>2]);
   $157 = Math_fround($154 + $156);
   $158 = ((($147) + (($20*48)|0)|0) + 8|0);
   $159 = Math_fround(HEAPF32[$158>>2]);
   $160 = ((($147) + (($22*48)|0)|0) + 8|0);
   $161 = Math_fround(HEAPF32[$160>>2]);
   $162 = Math_fround($159 + $161);
   $163 = ((($147) + (($20*48)|0)|0) + 12|0);
   $164 = Math_fround(HEAPF32[$163>>2]);
   $165 = ((($147) + (($22*48)|0)|0) + 12|0);
   $166 = Math_fround(HEAPF32[$165>>2]);
   $167 = Math_fround($164 + $166);
   $168 = Math_fround($152 * Math_fround(0.5));
   $169 = Math_fround($157 * Math_fround(0.5));
   $170 = Math_fround($162 * Math_fround(0.5));
   $171 = Math_fround($167 * Math_fround(0.5));
   $172 = ((($49) + (($18*48)|0)|0) + 32|0);
   $173 = Math_fround(HEAPF32[$172>>2]);
   $174 = Math_fround($168 * $173);
   $175 = ((($49) + (($18*48)|0)|0) + 36|0);
   $176 = Math_fround(HEAPF32[$175>>2]);
   $177 = Math_fround($169 * $176);
   $178 = ((($49) + (($18*48)|0)|0) + 40|0);
   $179 = Math_fround(HEAPF32[$178>>2]);
   $180 = Math_fround($170 * $179);
   $181 = ((($49) + (($18*48)|0)|0) + 44|0);
   $182 = Math_fround(HEAPF32[$181>>2]);
   $183 = Math_fround($171 * $182);
   $184 = Math_fround($174 + $174);
   $185 = Math_fround($177 + $177);
   $186 = Math_fround($180 + $180);
   $187 = Math_fround($185 * $94);
   $188 = Math_fround($186 * $85);
   $189 = Math_fround($184 * $91);
   $190 = Math_fround($88 * Math_fround(0.0));
   $191 = Math_fround($184 * $85);
   $192 = Math_fround($185 * $91);
   $193 = Math_fround($186 * $94);
   $194 = Math_fround($187 - $191);
   $195 = Math_fround($188 - $192);
   $196 = Math_fround($189 - $193);
   $197 = Math_fround($190 - $190);
   $198 = Math_fround($88 * $195);
   $199 = Math_fround($88 * $196);
   $200 = Math_fround($194 * $88);
   $201 = Math_fround($88 * $197);
   $202 = Math_fround($174 + $198);
   $203 = Math_fround($177 + $199);
   $204 = Math_fround($180 + $200);
   $205 = Math_fround($183 + $201);
   $206 = Math_fround($94 * $196);
   $207 = Math_fround($85 * $194);
   $208 = Math_fround($91 * $195);
   $209 = Math_fround($85 * $195);
   $210 = Math_fround($91 * $196);
   $211 = Math_fround($94 * $194);
   $212 = Math_fround($206 - $209);
   $213 = Math_fround($207 - $210);
   $214 = Math_fround($208 - $211);
   $215 = Math_fround($201 - $201);
   $216 = Math_fround($202 + $213);
   $217 = Math_fround($203 + $214);
   $218 = Math_fround($204 + $212);
   $219 = Math_fround($205 + $215);
   $220 = Math_fround($52 + $216);
   $221 = Math_fround($54 + $217);
   $222 = Math_fround($56 + $218);
   $223 = Math_fround($58 + $219);
   $226 = $220;$230 = $221;$234 = $222;$238 = $223;
  }
  $224 = Math_fround(HEAPF32[$headGoalT>>2]);
  $225 = Math_fround($224 - $226);
  $227 = (($headGoalT) + 4|0);
  $228 = Math_fround(HEAPF32[$227>>2]);
  $229 = Math_fround($228 - $230);
  $231 = (($headGoalT) + 8|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = Math_fround($232 - $234);
  $235 = (($headGoalT) + 12|0);
  $236 = Math_fround(HEAPF32[$235>>2]);
  $237 = Math_fround($236 - $238);
  $239 = Math_fround($225 * $225);
  $240 = Math_fround($229 * $229);
  $241 = Math_fround($233 * $233);
  $242 = Math_fround($237 * $237);
  $243 = Math_fround($239 + $240);
  $244 = Math_fround($241 + $242);
  $245 = Math_fround($243 + $244);
  $246 = (Math_fround(Math_sqrt((Math_fround($245)))));
  $247 = Math_fround(-$246);
  $248 = Math_fround($247 - $246);
  $249 = Math_fround($132 * $248);
  $250 = Math_fround($133 * Math_fround(0.0));
  $251 = Math_fround($134 * Math_fround(0.0));
  $252 = Math_fround($135 * Math_fround(0.0));
  $253 = Math_fround($134 * $248);
  $254 = Math_fround($132 * Math_fround(0.0));
  $255 = Math_fround($249 - $250);
  $256 = Math_fround($250 - $253);
  $257 = Math_fround($251 - $254);
  $258 = Math_fround($252 - $252);
  $259 = Math_fround($135 * $256);
  $260 = Math_fround($135 * $257);
  $261 = Math_fround($135 * $255);
  $262 = Math_fround($135 * $258);
  $263 = Math_fround($259 + Math_fround(0.0));
  $264 = Math_fround($260 - $246);
  $265 = Math_fround($261 + Math_fround(0.0));
  $266 = Math_fround($262 + Math_fround(0.0));
  $267 = Math_fround($132 * $257);
  $268 = Math_fround($133 * $255);
  $269 = Math_fround($134 * $256);
  $270 = Math_fround($133 * $256);
  $271 = Math_fround($134 * $257);
  $272 = Math_fround($132 * $255);
  $273 = Math_fround($267 - $270);
  $274 = Math_fround($268 - $271);
  $275 = Math_fround($269 - $272);
  $276 = Math_fround($262 - $262);
  $277 = Math_fround($263 + $274);
  $278 = Math_fround($264 + $275);
  $279 = Math_fround($265 + $273);
  $280 = Math_fround($266 + $276);
  $281 = Math_fround($229 * $277);
  $282 = Math_fround($233 * $278);
  $283 = Math_fround($225 * $279);
  $284 = Math_fround($280 * $237);
  $285 = Math_fround($225 * $278);
  $286 = Math_fround($229 * $279);
  $287 = Math_fround($233 * $277);
  $288 = Math_fround($281 - $285);
  $289 = Math_fround($282 - $286);
  $290 = Math_fround($283 - $287);
  $291 = Math_fround($225 * $277);
  $292 = Math_fround($229 * $278);
  $293 = Math_fround($233 * $279);
  $294 = Math_fround($291 + $292);
  $295 = Math_fround($284 + $293);
  $296 = Math_fround($294 + $295);
  $297 = Math_fround($277 * $277);
  $298 = Math_fround($278 * $278);
  $299 = Math_fround($279 * $279);
  $300 = Math_fround($280 * $280);
  $301 = Math_fround($297 + $298);
  $302 = Math_fround($300 + $299);
  $303 = Math_fround($301 + $302);
  $304 = Math_fround($245 * $303);
  $305 = (Math_fround(Math_sqrt((Math_fround($304)))));
  $306 = Math_fround($305 + $296);
  $307 = Math_fround($289 * $289);
  $308 = Math_fround($290 * $290);
  $309 = Math_fround($288 * $288);
  $310 = Math_fround($306 * $306);
  $311 = Math_fround($307 + $308);
  $312 = Math_fround($309 + $310);
  $313 = Math_fround($311 + $312);
  $314 = (Math_fround(Math_sqrt((Math_fround($313)))));
  $315 = Math_fround(Math_fround(1.0) / $314);
  $316 = Math_fround($315 * $289);
  $317 = Math_fround($315 * $290);
  $318 = Math_fround($315 * $288);
  $319 = Math_fround($315 * $306);
  $320 = Math_fround(Math_fround(1.0) - $$$i$i);
  $321 = Math_fround($320 * Math_fround(180.0));
  $322 = Math_fround($321 * Math_fround(0.0174532923847436904907));
  $323 = Math_fround($322 * Math_fround(0.5));
  $324 = (Math_fround(+(Math_cos((+$323)))));
  $325 = Math_fround($316 * $316);
  $326 = Math_fround($317 * $317);
  $327 = Math_fround($318 * $318);
  $328 = Math_fround($319 * $319);
  $329 = Math_fround($325 + $326);
  $330 = Math_fround($327 + $328);
  $331 = Math_fround($329 + $330);
  $332 = (Math_fround(Math_sqrt((Math_fround($331)))));
  $333 = Math_fround(Math_fround(1.0) / $332);
  $334 = Math_fround($333 * $316);
  $335 = Math_fround($333 * $317);
  $336 = Math_fround($333 * $318);
  $337 = Math_fround($333 * $319);
  $338 = Math_fround(-$337);
  $339 = $337 < Math_fround(0.0);
  $$v27$i = $339 ? $338 : $337;
  $340 = $$v27$i < $324;
  if ($340) {
   $341 = Math_fround(-$336);
   $342 = Math_fround(-$335);
   $343 = Math_fround(-$334);
   $$v26$i = $339 ? $341 : $336;
   $$v25$i = $339 ? $342 : $335;
   $$v$i = $339 ? $343 : $334;
   $344 = Math_fround($324 - $$v27$i);
   $345 = Math_fround($344 / $324);
   $346 = Math_fround(Math_fround(1.0) - $345);
   $347 = Math_fround($$v$i * $346);
   $348 = Math_fround($$v25$i * $346);
   $349 = Math_fround($$v26$i * $346);
   $350 = Math_fround(Math_fround(1.0) - $324);
   $351 = Math_fround($350 * $345);
   $352 = Math_fround($324 + $351);
   $357 = $347;$359 = $348;$361 = $349;$363 = $352;
  } else {
   $357 = $316;$359 = $317;$361 = $318;$363 = $319;
  }
  $353 = Math_fround($277 + $277);
  $354 = Math_fround($278 + $278);
  $355 = Math_fround($279 + $279);
  $356 = Math_fround($354 * $357);
  $358 = Math_fround($355 * $359);
  $360 = Math_fround($353 * $361);
  $362 = Math_fround($363 * Math_fround(0.0));
  $364 = Math_fround($353 * $359);
  $365 = Math_fround($354 * $361);
  $366 = Math_fround($355 * $357);
  $367 = Math_fround($356 - $364);
  $368 = Math_fround($358 - $365);
  $369 = Math_fround($360 - $366);
  $370 = Math_fround($362 - $362);
  $371 = Math_fround($363 * $368);
  $372 = Math_fround($363 * $369);
  $373 = Math_fround($363 * $367);
  $374 = Math_fround($363 * $370);
  $375 = Math_fround($277 + $371);
  $376 = Math_fround($278 + $372);
  $377 = Math_fround($279 + $373);
  $378 = Math_fround($280 + $374);
  $379 = Math_fround($357 * $369);
  $380 = Math_fround($359 * $367);
  $381 = Math_fround($361 * $368);
  $382 = Math_fround($359 * $368);
  $383 = Math_fround($361 * $369);
  $384 = Math_fround($357 * $367);
  $385 = Math_fround($379 - $382);
  $386 = Math_fround($380 - $383);
  $387 = Math_fround($381 - $384);
  $388 = Math_fround($374 - $374);
  $389 = Math_fround($375 + $386);
  $390 = Math_fround($376 + $387);
  $391 = Math_fround($377 + $385);
  $392 = Math_fround($378 + $388);
  $393 = Math_fround($226 + $389);
  $394 = Math_fround($230 + $390);
  $395 = Math_fround($234 + $391);
  $396 = Math_fround($238 + $392);
  HEAPF32[$headGoalT>>2] = $393;
  HEAPF32[$227>>2] = $394;
  HEAPF32[$231>>2] = $395;
  HEAPF32[$235>>2] = $396;
  $$pre = Math_fround(HEAPF32[$lbw>>2]);
  $398 = $$pre;
 } else {
  $398 = $39;
 }
 $397 = $398 > Math_fround(0.0);
 if ($397) {
  $399 = Math_fround($398 * Math_fround(0.5));
  $400 = ($12|0)!=(-1);
  $$v = $400 ? $399 : $398;
  HEAPF32[$lsw>>2] = $$v;
  $401 = (($apSkeletonPoseWorkspaceA) + 4|0);
  $402 = $401;
  $403 = HEAP32[$401>>2]|0;
  $404 = (($403) + ($402))|0;
  $405 = $404;
  $406 = (($apSkeletonPoseWorkspaceA) + 8|0);
  HEAP32[$406>>2] = $405;
  $407 = (($405) + (($18*48)|0)|0);
  ;HEAP32[$eyesPos1+0>>2]=HEAP32[$407+0>>2]|0;HEAP32[$eyesPos1+4>>2]=HEAP32[$407+4>>2]|0;HEAP32[$eyesPos1+8>>2]=HEAP32[$407+8>>2]|0;HEAP32[$eyesPos1+12>>2]=HEAP32[$407+12>>2]|0;
  HEAP32[$406>>2] = $405;
  $408 = (($apHuman) + 48|0);
  $409 = $408;
  $410 = HEAP32[$408>>2]|0;
  $411 = (($410) + ($409))|0;
  $412 = $411;
  $413 = (($412) + 24|0);
  $414 = (($412) + 4|0);
  $415 = $414;
  $416 = HEAP32[$414>>2]|0;
  $417 = (($415) + ($416))|0;
  $418 = $417;
  $419 = ((($418) + ($18<<3)|0) + 4|0);
  $420 = HEAP32[$419>>2]|0;
  $421 = $413;
  $422 = HEAP32[$413>>2]|0;
  $423 = (($421) + ($422))|0;
  $424 = $423;
  $425 = ((($424) + (($420*88)|0)|0) + 16|0);
  $426 = Math_fround(HEAPF32[$425>>2]);
  $427 = ((($424) + (($420*88)|0)|0) + 20|0);
  $428 = Math_fround(HEAPF32[$427>>2]);
  $429 = ((($424) + (($420*88)|0)|0) + 24|0);
  $430 = Math_fround(HEAPF32[$429>>2]);
  $431 = ((($424) + (($420*88)|0)|0) + 28|0);
  $432 = Math_fround(HEAPF32[$431>>2]);
  $433 = ((($405) + (($18*48)|0)|0) + 20|0);
  $434 = Math_fround(HEAPF32[$433>>2]);
  $435 = Math_fround($426 * $434);
  $436 = ((($405) + (($18*48)|0)|0) + 28|0);
  $437 = Math_fround(HEAPF32[$436>>2]);
  $438 = Math_fround($432 * $437);
  $439 = ((($405) + (($18*48)|0)|0) + 24|0);
  $440 = Math_fround(HEAPF32[$439>>2]);
  $441 = Math_fround($428 * $440);
  $442 = ((($405) + (($18*48)|0)|0) + 16|0);
  $443 = Math_fround(HEAPF32[$442>>2]);
  $444 = Math_fround($430 * $443);
  $445 = Math_fround($430 * $437);
  $446 = Math_fround($426 * $443);
  $447 = Math_fround($430 * $434);
  $448 = Math_fround($426 * $440);
  $449 = Math_fround($435 - $445);
  $450 = Math_fround($438 - $446);
  $451 = Math_fround($441 - $447);
  $452 = Math_fround($444 - $448);
  $453 = Math_fround($432 * $440);
  $454 = Math_fround($430 * $440);
  $455 = Math_fround($426 * $437);
  $456 = Math_fround($428 * $437);
  $457 = Math_fround($449 - $453);
  $458 = Math_fround($450 - $454);
  $459 = Math_fround($451 - $455);
  $460 = Math_fround($452 - $456);
  $461 = Math_fround($428 * $443);
  $462 = Math_fround($428 * $434);
  $463 = Math_fround($432 * $443);
  $464 = Math_fround($432 * $434);
  $465 = Math_fround($457 - $461);
  $466 = Math_fround($458 - $462);
  $467 = Math_fround($459 - $463);
  $468 = Math_fround($460 - $464);
  $469 = Math_fround($467 * Math_fround(-1.0));
  $470 = Math_fround($468 * Math_fround(-1.0));
  $471 = Math_fround($465 * Math_fround(-1.0));
  $472 = Math_fround($469 * $469);
  $473 = Math_fround($470 * $470);
  $474 = Math_fround($471 * $471);
  $475 = Math_fround($466 * $466);
  $476 = Math_fround($472 + $473);
  $477 = Math_fround($474 + $475);
  $478 = Math_fround($477 + $476);
  $479 = (Math_fround(Math_sqrt((Math_fround($478)))));
  $480 = Math_fround(Math_fround(1.0) / $479);
  $481 = Math_fround($480 * $469);
  $482 = Math_fround($480 * $470);
  $483 = Math_fround($480 * $471);
  $484 = Math_fround($480 * $466);
  HEAPF32[$eyesRot2>>2] = $481;
  $485 = (($eyesRot2) + 4|0);
  HEAPF32[$485>>2] = $482;
  $486 = (($eyesRot2) + 8|0);
  HEAPF32[$486>>2] = $483;
  $487 = (($eyesRot2) + 12|0);
  HEAPF32[$487>>2] = $484;
  HEAP32[$406>>2] = $405;
  $488 = (($405) + (($14*48)|0)|0);
  HEAPF32[$0>>2] = Math_fround(0.0);
  $489 = (($0) + 4|0);
  HEAPF32[$489>>2] = Math_fround(1.0);
  $490 = (($0) + 8|0);
  HEAPF32[$490>>2] = Math_fround(0.0);
  $491 = (($0) + 12|0);
  HEAPF32[$491>>2] = Math_fround(0.0);
  __ZN7mecanim5human15GetLookAtDeltaQERKN4math7_float4ES4_S4_S4_S4_RKf($deltaQ3,$488,$eyesPos1,$eyesRot2,$0,$headGoalT,$lsw);
  $492 = HEAP32[$401>>2]|0;
  $493 = (($492) + ($402))|0;
  $494 = $493;
  HEAP32[$406>>2] = $494;
  $495 = (($deltaQ3) + 4|0);
  $496 = Math_fround(HEAPF32[$495>>2]);
  $497 = ((($494) + (($14*48)|0)|0) + 16|0);
  $498 = Math_fround(HEAPF32[$497>>2]);
  $499 = Math_fround($496 * $498);
  $500 = (($deltaQ3) + 12|0);
  $501 = Math_fround(HEAPF32[$500>>2]);
  $502 = ((($494) + (($14*48)|0)|0) + 28|0);
  $503 = Math_fround(HEAPF32[$502>>2]);
  $504 = Math_fround($501 * $503);
  $505 = (($deltaQ3) + 8|0);
  $506 = Math_fround(HEAPF32[$505>>2]);
  $507 = ((($494) + (($14*48)|0)|0) + 20|0);
  $508 = Math_fround(HEAPF32[$507>>2]);
  $509 = Math_fround($506 * $508);
  $510 = Math_fround(HEAPF32[$deltaQ3>>2]);
  $511 = ((($494) + (($14*48)|0)|0) + 24|0);
  $512 = Math_fround(HEAPF32[$511>>2]);
  $513 = Math_fround($510 * $512);
  $514 = Math_fround($501 * $512);
  $515 = Math_fround($498 * $510);
  $516 = Math_fround($496 * $512);
  $517 = Math_fround($498 * $506);
  $518 = Math_fround($499 - $514);
  $519 = Math_fround($504 - $515);
  $520 = Math_fround($509 - $516);
  $521 = Math_fround($513 - $517);
  $522 = Math_fround($503 * $506);
  $523 = Math_fround($506 * $512);
  $524 = Math_fround($498 * $501);
  $525 = Math_fround($501 * $508);
  $526 = Math_fround($518 - $522);
  $527 = Math_fround($519 - $523);
  $528 = Math_fround($520 - $524);
  $529 = Math_fround($521 - $525);
  $530 = Math_fround($508 * $510);
  $531 = Math_fround($496 * $508);
  $532 = Math_fround($503 * $510);
  $533 = Math_fround($496 * $503);
  $534 = Math_fround($526 - $530);
  $535 = Math_fround($527 - $531);
  $536 = Math_fround($528 - $532);
  $537 = Math_fround($529 - $533);
  $538 = Math_fround($536 * Math_fround(-1.0));
  $539 = Math_fround($537 * Math_fround(-1.0));
  $540 = Math_fround($534 * Math_fround(-1.0));
  $541 = Math_fround($538 * $538);
  $542 = Math_fround($539 * $539);
  $543 = Math_fround($540 * $540);
  $544 = Math_fround($535 * $535);
  $545 = Math_fround($541 + $542);
  $546 = Math_fround($544 + $543);
  $547 = Math_fround($545 + $546);
  $548 = (Math_fround(Math_sqrt((Math_fround($547)))));
  $549 = Math_fround(Math_fround(1.0) / $548);
  $550 = Math_fround($549 * $538);
  $551 = Math_fround($549 * $539);
  $552 = Math_fround($549 * $540);
  $553 = Math_fround($549 * $535);
  HEAPF32[$497>>2] = $550;
  HEAPF32[$507>>2] = $551;
  HEAPF32[$511>>2] = $552;
  HEAPF32[$502>>2] = $553;
  $554 = HEAP32[$408>>2]|0;
  $555 = (($554) + ($409))|0;
  $556 = $555;
  $557 = (($apHuman) + 52|0);
  HEAP32[$557>>2] = $556;
  __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($556,$apSkeletonPoseWorkspaceA,$apSkeletonPose,$14,$14);
  if ($400) {
   $558 = HEAP32[$408>>2]|0;
   $559 = (($558) + ($409))|0;
   $560 = $559;
   HEAP32[$557>>2] = $560;
   __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($560,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$18,$14);
   $561 = HEAP32[$401>>2]|0;
   $562 = (($561) + ($402))|0;
   $563 = $562;
   HEAP32[$406>>2] = $563;
   $564 = (($563) + (($18*48)|0)|0);
   ;HEAP32[$eyesPos4+0>>2]=HEAP32[$564+0>>2]|0;HEAP32[$eyesPos4+4>>2]=HEAP32[$564+4>>2]|0;HEAP32[$eyesPos4+8>>2]=HEAP32[$564+8>>2]|0;HEAP32[$eyesPos4+12>>2]=HEAP32[$564+12>>2]|0;
   HEAP32[$406>>2] = $563;
   $565 = HEAP32[$408>>2]|0;
   $566 = (($565) + ($409))|0;
   $567 = $566;
   $568 = (($567) + 24|0);
   $569 = (($567) + 4|0);
   $570 = $569;
   $571 = HEAP32[$569>>2]|0;
   $572 = (($570) + ($571))|0;
   $573 = $572;
   $574 = ((($573) + ($18<<3)|0) + 4|0);
   $575 = HEAP32[$574>>2]|0;
   $576 = $568;
   $577 = HEAP32[$568>>2]|0;
   $578 = (($576) + ($577))|0;
   $579 = $578;
   $580 = ((($579) + (($575*88)|0)|0) + 16|0);
   $581 = Math_fround(HEAPF32[$580>>2]);
   $582 = ((($579) + (($575*88)|0)|0) + 20|0);
   $583 = Math_fround(HEAPF32[$582>>2]);
   $584 = ((($579) + (($575*88)|0)|0) + 24|0);
   $585 = Math_fround(HEAPF32[$584>>2]);
   $586 = ((($579) + (($575*88)|0)|0) + 28|0);
   $587 = Math_fround(HEAPF32[$586>>2]);
   $588 = ((($563) + (($18*48)|0)|0) + 20|0);
   $589 = Math_fround(HEAPF32[$588>>2]);
   $590 = Math_fround($581 * $589);
   $591 = ((($563) + (($18*48)|0)|0) + 28|0);
   $592 = Math_fround(HEAPF32[$591>>2]);
   $593 = Math_fround($587 * $592);
   $594 = ((($563) + (($18*48)|0)|0) + 24|0);
   $595 = Math_fround(HEAPF32[$594>>2]);
   $596 = Math_fround($583 * $595);
   $597 = ((($563) + (($18*48)|0)|0) + 16|0);
   $598 = Math_fround(HEAPF32[$597>>2]);
   $599 = Math_fround($585 * $598);
   $600 = Math_fround($585 * $592);
   $601 = Math_fround($581 * $598);
   $602 = Math_fround($585 * $589);
   $603 = Math_fround($581 * $595);
   $604 = Math_fround($590 - $600);
   $605 = Math_fround($593 - $601);
   $606 = Math_fround($596 - $602);
   $607 = Math_fround($599 - $603);
   $608 = Math_fround($587 * $595);
   $609 = Math_fround($585 * $595);
   $610 = Math_fround($581 * $592);
   $611 = Math_fround($583 * $592);
   $612 = Math_fround($604 - $608);
   $613 = Math_fround($605 - $609);
   $614 = Math_fround($606 - $610);
   $615 = Math_fround($607 - $611);
   $616 = Math_fround($583 * $598);
   $617 = Math_fround($583 * $589);
   $618 = Math_fround($587 * $598);
   $619 = Math_fround($587 * $589);
   $620 = Math_fround($612 - $616);
   $621 = Math_fround($613 - $617);
   $622 = Math_fround($614 - $618);
   $623 = Math_fround($615 - $619);
   $624 = Math_fround($622 * Math_fround(-1.0));
   $625 = Math_fround($623 * Math_fround(-1.0));
   $626 = Math_fround($620 * Math_fround(-1.0));
   $627 = Math_fround($624 * $624);
   $628 = Math_fround($625 * $625);
   $629 = Math_fround($626 * $626);
   $630 = Math_fround($621 * $621);
   $631 = Math_fround($627 + $628);
   $632 = Math_fround($629 + $630);
   $633 = Math_fround($632 + $631);
   $634 = (Math_fround(Math_sqrt((Math_fround($633)))));
   $635 = Math_fround(Math_fround(1.0) / $634);
   $636 = Math_fround($635 * $624);
   $637 = Math_fround($635 * $625);
   $638 = Math_fround($635 * $626);
   $639 = Math_fround($635 * $621);
   HEAPF32[$eyesRot5>>2] = $636;
   $640 = (($eyesRot5) + 4|0);
   HEAPF32[$640>>2] = $637;
   $641 = (($eyesRot5) + 8|0);
   HEAPF32[$641>>2] = $638;
   $642 = (($eyesRot5) + 12|0);
   HEAPF32[$642>>2] = $639;
   HEAP32[$406>>2] = $563;
   $643 = (($563) + (($12*48)|0)|0);
   HEAPF32[$1>>2] = Math_fround(0.0);
   $644 = (($1) + 4|0);
   HEAPF32[$644>>2] = Math_fround(1.0);
   $645 = (($1) + 8|0);
   HEAPF32[$645>>2] = Math_fround(0.0);
   $646 = (($1) + 12|0);
   HEAPF32[$646>>2] = Math_fround(0.0);
   __ZN7mecanim5human15GetLookAtDeltaQERKN4math7_float4ES4_S4_S4_S4_RKf($deltaQ6,$643,$eyesPos4,$eyesRot5,$1,$headGoalT,$lbw);
   $647 = HEAP32[$401>>2]|0;
   $648 = (($647) + ($402))|0;
   $649 = $648;
   HEAP32[$406>>2] = $649;
   $650 = (($deltaQ6) + 4|0);
   $651 = Math_fround(HEAPF32[$650>>2]);
   $652 = ((($649) + (($12*48)|0)|0) + 16|0);
   $653 = Math_fround(HEAPF32[$652>>2]);
   $654 = Math_fround($651 * $653);
   $655 = (($deltaQ6) + 12|0);
   $656 = Math_fround(HEAPF32[$655>>2]);
   $657 = ((($649) + (($12*48)|0)|0) + 28|0);
   $658 = Math_fround(HEAPF32[$657>>2]);
   $659 = Math_fround($656 * $658);
   $660 = (($deltaQ6) + 8|0);
   $661 = Math_fround(HEAPF32[$660>>2]);
   $662 = ((($649) + (($12*48)|0)|0) + 20|0);
   $663 = Math_fround(HEAPF32[$662>>2]);
   $664 = Math_fround($661 * $663);
   $665 = Math_fround(HEAPF32[$deltaQ6>>2]);
   $666 = ((($649) + (($12*48)|0)|0) + 24|0);
   $667 = Math_fround(HEAPF32[$666>>2]);
   $668 = Math_fround($665 * $667);
   $669 = Math_fround($656 * $667);
   $670 = Math_fround($653 * $665);
   $671 = Math_fround($651 * $667);
   $672 = Math_fround($653 * $661);
   $673 = Math_fround($654 - $669);
   $674 = Math_fround($659 - $670);
   $675 = Math_fround($664 - $671);
   $676 = Math_fround($668 - $672);
   $677 = Math_fround($658 * $661);
   $678 = Math_fround($661 * $667);
   $679 = Math_fround($653 * $656);
   $680 = Math_fround($656 * $663);
   $681 = Math_fround($673 - $677);
   $682 = Math_fround($674 - $678);
   $683 = Math_fround($675 - $679);
   $684 = Math_fround($676 - $680);
   $685 = Math_fround($663 * $665);
   $686 = Math_fround($651 * $663);
   $687 = Math_fround($658 * $665);
   $688 = Math_fround($651 * $658);
   $689 = Math_fround($681 - $685);
   $690 = Math_fround($682 - $686);
   $691 = Math_fround($683 - $687);
   $692 = Math_fround($684 - $688);
   $693 = Math_fround($691 * Math_fround(-1.0));
   $694 = Math_fround($692 * Math_fround(-1.0));
   $695 = Math_fround($689 * Math_fround(-1.0));
   $696 = Math_fround($693 * $693);
   $697 = Math_fround($694 * $694);
   $698 = Math_fround($695 * $695);
   $699 = Math_fround($690 * $690);
   $700 = Math_fround($696 + $697);
   $701 = Math_fround($699 + $698);
   $702 = Math_fround($700 + $701);
   $703 = (Math_fround(Math_sqrt((Math_fround($702)))));
   $704 = Math_fround(Math_fround(1.0) / $703);
   $705 = Math_fround($704 * $693);
   $706 = Math_fround($704 * $694);
   $707 = Math_fround($704 * $695);
   $708 = Math_fround($704 * $690);
   HEAPF32[$652>>2] = $705;
   HEAPF32[$662>>2] = $706;
   HEAPF32[$666>>2] = $707;
   HEAPF32[$657>>2] = $708;
   $709 = HEAP32[$408>>2]|0;
   $710 = (($709) + ($409))|0;
   $711 = $710;
   HEAP32[$557>>2] = $711;
   __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($711,$apSkeletonPoseWorkspaceA,$apSkeletonPose,$12,$12);
  }
 }
 $712 = $$1$i$i > Math_fround(0.0);
 if ($712) {
  $713 = (($apHuman) + 48|0);
  $714 = $713;
  $715 = HEAP32[$713>>2]|0;
  $716 = (($715) + ($714))|0;
  $717 = $716;
  $718 = (($apHuman) + 52|0);
  HEAP32[$718>>2] = $717;
  __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($717,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$18,$14);
  $719 = ($16|0)==(-1);
  $$pre138 = (($apSkeletonPoseWorkspaceA) + 4|0);
  $$pre139 = $$pre138;
  if ($719) {
   $$pre143 = (($apSkeletonPoseWorkspaceA) + 8|0);
   $$pre$phi144Z2D = $$pre143;
  } else {
   $720 = HEAP32[$$pre138>>2]|0;
   $721 = (($720) + ($$pre139))|0;
   $722 = $721;
   $723 = (($apSkeletonPoseWorkspaceA) + 8|0);
   HEAP32[$723>>2] = $722;
   $724 = (($722) + (($18*48)|0)|0);
   ;HEAP32[$eyesPos7+0>>2]=HEAP32[$724+0>>2]|0;HEAP32[$eyesPos7+4>>2]=HEAP32[$724+4>>2]|0;HEAP32[$eyesPos7+8>>2]=HEAP32[$724+8>>2]|0;HEAP32[$eyesPos7+12>>2]=HEAP32[$724+12>>2]|0;
   HEAP32[$723>>2] = $722;
   $725 = HEAP32[$713>>2]|0;
   $726 = (($725) + ($714))|0;
   $727 = $726;
   $728 = (($727) + 24|0);
   $729 = (($727) + 4|0);
   $730 = $729;
   $731 = HEAP32[$729>>2]|0;
   $732 = (($730) + ($731))|0;
   $733 = $732;
   $734 = ((($733) + ($18<<3)|0) + 4|0);
   $735 = HEAP32[$734>>2]|0;
   $736 = $728;
   $737 = HEAP32[$728>>2]|0;
   $738 = (($736) + ($737))|0;
   $739 = $738;
   $740 = ((($739) + (($735*88)|0)|0) + 16|0);
   $741 = Math_fround(HEAPF32[$740>>2]);
   $742 = ((($739) + (($735*88)|0)|0) + 20|0);
   $743 = Math_fround(HEAPF32[$742>>2]);
   $744 = ((($739) + (($735*88)|0)|0) + 24|0);
   $745 = Math_fround(HEAPF32[$744>>2]);
   $746 = ((($739) + (($735*88)|0)|0) + 28|0);
   $747 = Math_fround(HEAPF32[$746>>2]);
   $748 = ((($722) + (($18*48)|0)|0) + 20|0);
   $749 = Math_fround(HEAPF32[$748>>2]);
   $750 = Math_fround($741 * $749);
   $751 = ((($722) + (($18*48)|0)|0) + 28|0);
   $752 = Math_fround(HEAPF32[$751>>2]);
   $753 = Math_fround($747 * $752);
   $754 = ((($722) + (($18*48)|0)|0) + 24|0);
   $755 = Math_fround(HEAPF32[$754>>2]);
   $756 = Math_fround($743 * $755);
   $757 = ((($722) + (($18*48)|0)|0) + 16|0);
   $758 = Math_fround(HEAPF32[$757>>2]);
   $759 = Math_fround($745 * $758);
   $760 = Math_fround($745 * $752);
   $761 = Math_fround($741 * $758);
   $762 = Math_fround($745 * $749);
   $763 = Math_fround($741 * $755);
   $764 = Math_fround($750 - $760);
   $765 = Math_fround($753 - $761);
   $766 = Math_fround($756 - $762);
   $767 = Math_fround($759 - $763);
   $768 = Math_fround($747 * $755);
   $769 = Math_fround($745 * $755);
   $770 = Math_fround($741 * $752);
   $771 = Math_fround($743 * $752);
   $772 = Math_fround($764 - $768);
   $773 = Math_fround($765 - $769);
   $774 = Math_fround($766 - $770);
   $775 = Math_fround($767 - $771);
   $776 = Math_fround($743 * $758);
   $777 = Math_fround($743 * $749);
   $778 = Math_fround($747 * $758);
   $779 = Math_fround($747 * $749);
   $780 = Math_fround($772 - $776);
   $781 = Math_fround($773 - $777);
   $782 = Math_fround($774 - $778);
   $783 = Math_fround($775 - $779);
   $784 = Math_fround($782 * Math_fround(-1.0));
   $785 = Math_fround($783 * Math_fround(-1.0));
   $786 = Math_fround($780 * Math_fround(-1.0));
   $787 = Math_fround($784 * $784);
   $788 = Math_fround($785 * $785);
   $789 = Math_fround($786 * $786);
   $790 = Math_fround($781 * $781);
   $791 = Math_fround($787 + $788);
   $792 = Math_fround($789 + $790);
   $793 = Math_fround($792 + $791);
   $794 = (Math_fround(Math_sqrt((Math_fround($793)))));
   $795 = Math_fround(Math_fround(1.0) / $794);
   $796 = Math_fround($795 * $784);
   $797 = Math_fround($795 * $785);
   $798 = Math_fround($795 * $786);
   $799 = Math_fround($795 * $781);
   HEAPF32[$eyesRot8>>2] = $796;
   $800 = (($eyesRot8) + 4|0);
   HEAPF32[$800>>2] = $797;
   $801 = (($eyesRot8) + 8|0);
   HEAPF32[$801>>2] = $798;
   $802 = (($eyesRot8) + 12|0);
   HEAPF32[$802>>2] = $799;
   $803 = ($20|0)==(-1);
   $804 = ($22|0)==(-1);
   $or$cond1 = $803 | $804;
   if ($or$cond1) {
    $907 = $720;
   } else {
    HEAP32[$723>>2] = $722;
    $805 = (($apHuman) + 56|0);
    $806 = $805;
    $807 = HEAP32[$805>>2]|0;
    $808 = (($807) + ($806))|0;
    $809 = $808;
    $810 = (($809) + 4|0);
    $811 = $810;
    $812 = HEAP32[$810>>2]|0;
    $813 = (($811) + ($812))|0;
    $814 = $813;
    $815 = (($814) + (($20*48)|0)|0);
    $816 = Math_fround(HEAPF32[$815>>2]);
    $817 = (($814) + (($22*48)|0)|0);
    $818 = Math_fround(HEAPF32[$817>>2]);
    $819 = Math_fround($816 + $818);
    $820 = ((($814) + (($20*48)|0)|0) + 4|0);
    $821 = Math_fround(HEAPF32[$820>>2]);
    $822 = ((($814) + (($22*48)|0)|0) + 4|0);
    $823 = Math_fround(HEAPF32[$822>>2]);
    $824 = Math_fround($821 + $823);
    $825 = ((($814) + (($20*48)|0)|0) + 8|0);
    $826 = Math_fround(HEAPF32[$825>>2]);
    $827 = ((($814) + (($22*48)|0)|0) + 8|0);
    $828 = Math_fround(HEAPF32[$827>>2]);
    $829 = Math_fround($826 + $828);
    $830 = ((($814) + (($20*48)|0)|0) + 12|0);
    $831 = Math_fround(HEAPF32[$830>>2]);
    $832 = ((($814) + (($22*48)|0)|0) + 12|0);
    $833 = Math_fround(HEAPF32[$832>>2]);
    $834 = Math_fround($831 + $833);
    $835 = Math_fround($819 * Math_fround(0.5));
    $836 = Math_fround($824 * Math_fround(0.5));
    $837 = Math_fround($829 * Math_fround(0.5));
    $838 = Math_fround($834 * Math_fround(0.5));
    $839 = ((($722) + (($18*48)|0)|0) + 32|0);
    $840 = Math_fround(HEAPF32[$839>>2]);
    $841 = Math_fround($835 * $840);
    $842 = ((($722) + (($18*48)|0)|0) + 36|0);
    $843 = Math_fround(HEAPF32[$842>>2]);
    $844 = Math_fround($836 * $843);
    $845 = ((($722) + (($18*48)|0)|0) + 40|0);
    $846 = Math_fround(HEAPF32[$845>>2]);
    $847 = Math_fround($837 * $846);
    $848 = ((($722) + (($18*48)|0)|0) + 44|0);
    $849 = Math_fround(HEAPF32[$848>>2]);
    $850 = Math_fround($838 * $849);
    $851 = Math_fround($841 + $841);
    $852 = Math_fround($844 + $844);
    $853 = Math_fround($847 + $847);
    $854 = Math_fround(HEAPF32[$757>>2]);
    $855 = Math_fround($852 * $854);
    $856 = Math_fround(HEAPF32[$748>>2]);
    $857 = Math_fround($853 * $856);
    $858 = Math_fround(HEAPF32[$754>>2]);
    $859 = Math_fround($851 * $858);
    $860 = Math_fround(HEAPF32[$751>>2]);
    $861 = Math_fround($860 * Math_fround(0.0));
    $862 = Math_fround($851 * $856);
    $863 = Math_fround($852 * $858);
    $864 = Math_fround($853 * $854);
    $865 = Math_fround($855 - $862);
    $866 = Math_fround($857 - $863);
    $867 = Math_fround($859 - $864);
    $868 = Math_fround($861 - $861);
    $869 = Math_fround($860 * $866);
    $870 = Math_fround($860 * $867);
    $871 = Math_fround($865 * $860);
    $872 = Math_fround($860 * $868);
    $873 = Math_fround($841 + $869);
    $874 = Math_fround($844 + $870);
    $875 = Math_fround($847 + $871);
    $876 = Math_fround($850 + $872);
    $877 = Math_fround($854 * $867);
    $878 = Math_fround($856 * $865);
    $879 = Math_fround($858 * $866);
    $880 = Math_fround($856 * $866);
    $881 = Math_fround($858 * $867);
    $882 = Math_fround($854 * $865);
    $883 = Math_fround($877 - $880);
    $884 = Math_fround($878 - $881);
    $885 = Math_fround($879 - $882);
    $886 = Math_fround($872 - $872);
    $887 = Math_fround($873 + $884);
    $888 = Math_fround($874 + $885);
    $889 = Math_fround($875 + $883);
    $890 = Math_fround($876 + $886);
    $891 = (($722) + (($18*48)|0)|0);
    $892 = Math_fround(HEAPF32[$891>>2]);
    $893 = Math_fround($892 + $887);
    $894 = ((($722) + (($18*48)|0)|0) + 4|0);
    $895 = Math_fround(HEAPF32[$894>>2]);
    $896 = Math_fround($895 + $888);
    $897 = ((($722) + (($18*48)|0)|0) + 8|0);
    $898 = Math_fround(HEAPF32[$897>>2]);
    $899 = Math_fround($898 + $889);
    $900 = ((($722) + (($18*48)|0)|0) + 12|0);
    $901 = Math_fround(HEAPF32[$900>>2]);
    $902 = Math_fround($901 + $890);
    HEAPF32[$eyesPos7>>2] = $893;
    $903 = (($eyesPos7) + 4|0);
    HEAPF32[$903>>2] = $896;
    $904 = (($eyesPos7) + 8|0);
    HEAPF32[$904>>2] = $899;
    $905 = (($eyesPos7) + 12|0);
    HEAPF32[$905>>2] = $902;
    $$pre136 = HEAP32[$$pre138>>2]|0;
    $907 = $$pre136;
   }
   $906 = (($907) + ($$pre139))|0;
   $908 = $906;
   HEAP32[$723>>2] = $908;
   $909 = (($908) + (($16*48)|0)|0);
   HEAPF32[$2>>2] = Math_fround(0.0);
   $910 = (($2) + 4|0);
   HEAPF32[$910>>2] = Math_fround(1.0);
   $911 = (($2) + 8|0);
   HEAPF32[$911>>2] = Math_fround(0.0);
   $912 = (($2) + 12|0);
   HEAPF32[$912>>2] = Math_fround(0.0);
   $913 = Math_fround($$1$i$i * Math_fround(0.5));
   HEAPF32[$3>>2] = $913;
   __ZN7mecanim5human15GetLookAtDeltaQERKN4math7_float4ES4_S4_S4_S4_RKf($deltaQ9,$909,$eyesPos7,$eyesRot8,$2,$headGoalT,$3);
   $914 = HEAP32[$$pre138>>2]|0;
   $915 = (($914) + ($$pre139))|0;
   $916 = $915;
   HEAP32[$723>>2] = $916;
   $917 = (($deltaQ9) + 4|0);
   $918 = Math_fround(HEAPF32[$917>>2]);
   $919 = ((($916) + (($16*48)|0)|0) + 16|0);
   $920 = Math_fround(HEAPF32[$919>>2]);
   $921 = Math_fround($918 * $920);
   $922 = (($deltaQ9) + 12|0);
   $923 = Math_fround(HEAPF32[$922>>2]);
   $924 = ((($916) + (($16*48)|0)|0) + 28|0);
   $925 = Math_fround(HEAPF32[$924>>2]);
   $926 = Math_fround($923 * $925);
   $927 = (($deltaQ9) + 8|0);
   $928 = Math_fround(HEAPF32[$927>>2]);
   $929 = ((($916) + (($16*48)|0)|0) + 20|0);
   $930 = Math_fround(HEAPF32[$929>>2]);
   $931 = Math_fround($928 * $930);
   $932 = Math_fround(HEAPF32[$deltaQ9>>2]);
   $933 = ((($916) + (($16*48)|0)|0) + 24|0);
   $934 = Math_fround(HEAPF32[$933>>2]);
   $935 = Math_fround($932 * $934);
   $936 = Math_fround($923 * $934);
   $937 = Math_fround($920 * $932);
   $938 = Math_fround($918 * $934);
   $939 = Math_fround($920 * $928);
   $940 = Math_fround($921 - $936);
   $941 = Math_fround($926 - $937);
   $942 = Math_fround($931 - $938);
   $943 = Math_fround($935 - $939);
   $944 = Math_fround($925 * $928);
   $945 = Math_fround($928 * $934);
   $946 = Math_fround($920 * $923);
   $947 = Math_fround($923 * $930);
   $948 = Math_fround($940 - $944);
   $949 = Math_fround($941 - $945);
   $950 = Math_fround($942 - $946);
   $951 = Math_fround($943 - $947);
   $952 = Math_fround($930 * $932);
   $953 = Math_fround($918 * $930);
   $954 = Math_fround($925 * $932);
   $955 = Math_fround($918 * $925);
   $956 = Math_fround($948 - $952);
   $957 = Math_fround($949 - $953);
   $958 = Math_fround($950 - $954);
   $959 = Math_fround($951 - $955);
   $960 = Math_fround($958 * Math_fround(-1.0));
   $961 = Math_fround($959 * Math_fround(-1.0));
   $962 = Math_fround($956 * Math_fround(-1.0));
   $963 = Math_fround($960 * $960);
   $964 = Math_fround($961 * $961);
   $965 = Math_fround($962 * $962);
   $966 = Math_fround($957 * $957);
   $967 = Math_fround($963 + $964);
   $968 = Math_fround($966 + $965);
   $969 = Math_fround($967 + $968);
   $970 = (Math_fround(Math_sqrt((Math_fround($969)))));
   $971 = Math_fround(Math_fround(1.0) / $970);
   $972 = Math_fround($971 * $960);
   $973 = Math_fround($971 * $961);
   $974 = Math_fround($971 * $962);
   $975 = Math_fround($971 * $957);
   HEAPF32[$919>>2] = $972;
   HEAPF32[$929>>2] = $973;
   HEAPF32[$933>>2] = $974;
   HEAPF32[$924>>2] = $975;
   $976 = HEAP32[$713>>2]|0;
   $977 = (($976) + ($714))|0;
   $978 = $977;
   HEAP32[$718>>2] = $978;
   __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($978,$apSkeletonPoseWorkspaceA,$apSkeletonPose,$16,$16);
   $$pre$phi144Z2D = $723;
  }
  $979 = (($eyesRot11) + 4|0);
  $980 = (($eyesRot11) + 8|0);
  $981 = (($eyesRot11) + 12|0);
  $982 = ($20|0)==(-1);
  $983 = ($22|0)==(-1);
  $or$cond2 = $982 | $983;
  $984 = (($4) + 4|0);
  $985 = (($4) + 8|0);
  $986 = (($4) + 12|0);
  $987 = Math_fround($$1$i$i * $$1$i$i);
  $988 = (($deltaQ12) + 4|0);
  $989 = (($deltaQ12) + 12|0);
  $990 = (($deltaQ12) + 8|0);
  $991 = (($apHuman) + 56|0);
  $992 = $991;
  $993 = (($eyesPos10) + 4|0);
  $994 = (($eyesPos10) + 8|0);
  $995 = (($eyesPos10) + 12|0);
  $iter$0133 = 0;
  while(1) {
   $996 = HEAP32[$$pre138>>2]|0;
   $997 = (($996) + ($$pre139))|0;
   $998 = $997;
   HEAP32[$$pre$phi144Z2D>>2] = $998;
   $999 = (($998) + (($18*48)|0)|0);
   ;HEAP32[$eyesPos10+0>>2]=HEAP32[$999+0>>2]|0;HEAP32[$eyesPos10+4>>2]=HEAP32[$999+4>>2]|0;HEAP32[$eyesPos10+8>>2]=HEAP32[$999+8>>2]|0;HEAP32[$eyesPos10+12>>2]=HEAP32[$999+12>>2]|0;
   HEAP32[$$pre$phi144Z2D>>2] = $998;
   $1000 = HEAP32[$713>>2]|0;
   $1001 = (($1000) + ($714))|0;
   $1002 = $1001;
   $1003 = (($1002) + 24|0);
   $1004 = (($1002) + 4|0);
   $1005 = $1004;
   $1006 = HEAP32[$1004>>2]|0;
   $1007 = (($1005) + ($1006))|0;
   $1008 = $1007;
   $1009 = ((($1008) + ($18<<3)|0) + 4|0);
   $1010 = HEAP32[$1009>>2]|0;
   $1011 = $1003;
   $1012 = HEAP32[$1003>>2]|0;
   $1013 = (($1011) + ($1012))|0;
   $1014 = $1013;
   $1015 = ((($1014) + (($1010*88)|0)|0) + 16|0);
   $1016 = Math_fround(HEAPF32[$1015>>2]);
   $1017 = ((($1014) + (($1010*88)|0)|0) + 20|0);
   $1018 = Math_fround(HEAPF32[$1017>>2]);
   $1019 = ((($1014) + (($1010*88)|0)|0) + 24|0);
   $1020 = Math_fround(HEAPF32[$1019>>2]);
   $1021 = ((($1014) + (($1010*88)|0)|0) + 28|0);
   $1022 = Math_fround(HEAPF32[$1021>>2]);
   $1023 = ((($998) + (($18*48)|0)|0) + 20|0);
   $1024 = Math_fround(HEAPF32[$1023>>2]);
   $1025 = Math_fround($1016 * $1024);
   $1026 = ((($998) + (($18*48)|0)|0) + 28|0);
   $1027 = Math_fround(HEAPF32[$1026>>2]);
   $1028 = Math_fround($1022 * $1027);
   $1029 = ((($998) + (($18*48)|0)|0) + 24|0);
   $1030 = Math_fround(HEAPF32[$1029>>2]);
   $1031 = Math_fround($1018 * $1030);
   $1032 = ((($998) + (($18*48)|0)|0) + 16|0);
   $1033 = Math_fround(HEAPF32[$1032>>2]);
   $1034 = Math_fround($1020 * $1033);
   $1035 = Math_fround($1020 * $1027);
   $1036 = Math_fround($1016 * $1033);
   $1037 = Math_fround($1020 * $1024);
   $1038 = Math_fround($1016 * $1030);
   $1039 = Math_fround($1025 - $1035);
   $1040 = Math_fround($1028 - $1036);
   $1041 = Math_fround($1031 - $1037);
   $1042 = Math_fround($1034 - $1038);
   $1043 = Math_fround($1022 * $1030);
   $1044 = Math_fround($1020 * $1030);
   $1045 = Math_fround($1016 * $1027);
   $1046 = Math_fround($1018 * $1027);
   $1047 = Math_fround($1039 - $1043);
   $1048 = Math_fround($1040 - $1044);
   $1049 = Math_fround($1041 - $1045);
   $1050 = Math_fround($1042 - $1046);
   $1051 = Math_fround($1018 * $1033);
   $1052 = Math_fround($1018 * $1024);
   $1053 = Math_fround($1022 * $1033);
   $1054 = Math_fround($1022 * $1024);
   $1055 = Math_fround($1047 - $1051);
   $1056 = Math_fround($1048 - $1052);
   $1057 = Math_fround($1049 - $1053);
   $1058 = Math_fround($1050 - $1054);
   $1059 = Math_fround($1057 * Math_fround(-1.0));
   $1060 = Math_fround($1058 * Math_fround(-1.0));
   $1061 = Math_fround($1055 * Math_fround(-1.0));
   $1062 = Math_fround($1059 * $1059);
   $1063 = Math_fround($1060 * $1060);
   $1064 = Math_fround($1061 * $1061);
   $1065 = Math_fround($1056 * $1056);
   $1066 = Math_fround($1062 + $1063);
   $1067 = Math_fround($1064 + $1065);
   $1068 = Math_fround($1067 + $1066);
   $1069 = (Math_fround(Math_sqrt((Math_fround($1068)))));
   $1070 = Math_fround(Math_fround(1.0) / $1069);
   $1071 = Math_fround($1070 * $1059);
   $1072 = Math_fround($1070 * $1060);
   $1073 = Math_fround($1070 * $1061);
   $1074 = Math_fround($1070 * $1056);
   HEAPF32[$eyesRot11>>2] = $1071;
   HEAPF32[$979>>2] = $1072;
   HEAPF32[$980>>2] = $1073;
   HEAPF32[$981>>2] = $1074;
   if ($or$cond2) {
    $1172 = $996;
   } else {
    HEAP32[$$pre$phi144Z2D>>2] = $998;
    $1075 = HEAP32[$991>>2]|0;
    $1076 = (($1075) + ($992))|0;
    $1077 = $1076;
    $1078 = (($1077) + 4|0);
    $1079 = $1078;
    $1080 = HEAP32[$1078>>2]|0;
    $1081 = (($1079) + ($1080))|0;
    $1082 = $1081;
    $1083 = (($1082) + (($20*48)|0)|0);
    $1084 = Math_fround(HEAPF32[$1083>>2]);
    $1085 = (($1082) + (($22*48)|0)|0);
    $1086 = Math_fround(HEAPF32[$1085>>2]);
    $1087 = Math_fround($1084 + $1086);
    $1088 = ((($1082) + (($20*48)|0)|0) + 4|0);
    $1089 = Math_fround(HEAPF32[$1088>>2]);
    $1090 = ((($1082) + (($22*48)|0)|0) + 4|0);
    $1091 = Math_fround(HEAPF32[$1090>>2]);
    $1092 = Math_fround($1089 + $1091);
    $1093 = ((($1082) + (($20*48)|0)|0) + 8|0);
    $1094 = Math_fround(HEAPF32[$1093>>2]);
    $1095 = ((($1082) + (($22*48)|0)|0) + 8|0);
    $1096 = Math_fround(HEAPF32[$1095>>2]);
    $1097 = Math_fround($1094 + $1096);
    $1098 = ((($1082) + (($20*48)|0)|0) + 12|0);
    $1099 = Math_fround(HEAPF32[$1098>>2]);
    $1100 = ((($1082) + (($22*48)|0)|0) + 12|0);
    $1101 = Math_fround(HEAPF32[$1100>>2]);
    $1102 = Math_fround($1099 + $1101);
    $1103 = Math_fround($1087 * Math_fround(0.5));
    $1104 = Math_fround($1092 * Math_fround(0.5));
    $1105 = Math_fround($1097 * Math_fround(0.5));
    $1106 = Math_fround($1102 * Math_fround(0.5));
    $1107 = ((($998) + (($18*48)|0)|0) + 32|0);
    $1108 = Math_fround(HEAPF32[$1107>>2]);
    $1109 = Math_fround($1103 * $1108);
    $1110 = ((($998) + (($18*48)|0)|0) + 36|0);
    $1111 = Math_fround(HEAPF32[$1110>>2]);
    $1112 = Math_fround($1104 * $1111);
    $1113 = ((($998) + (($18*48)|0)|0) + 40|0);
    $1114 = Math_fround(HEAPF32[$1113>>2]);
    $1115 = Math_fround($1105 * $1114);
    $1116 = ((($998) + (($18*48)|0)|0) + 44|0);
    $1117 = Math_fround(HEAPF32[$1116>>2]);
    $1118 = Math_fround($1106 * $1117);
    $1119 = Math_fround($1109 + $1109);
    $1120 = Math_fround($1112 + $1112);
    $1121 = Math_fround($1115 + $1115);
    $1122 = Math_fround(HEAPF32[$1032>>2]);
    $1123 = Math_fround($1120 * $1122);
    $1124 = Math_fround(HEAPF32[$1023>>2]);
    $1125 = Math_fround($1121 * $1124);
    $1126 = Math_fround(HEAPF32[$1029>>2]);
    $1127 = Math_fround($1119 * $1126);
    $1128 = Math_fround(HEAPF32[$1026>>2]);
    $1129 = Math_fround($1128 * Math_fround(0.0));
    $1130 = Math_fround($1119 * $1124);
    $1131 = Math_fround($1120 * $1126);
    $1132 = Math_fround($1121 * $1122);
    $1133 = Math_fround($1123 - $1130);
    $1134 = Math_fround($1125 - $1131);
    $1135 = Math_fround($1127 - $1132);
    $1136 = Math_fround($1129 - $1129);
    $1137 = Math_fround($1128 * $1134);
    $1138 = Math_fround($1128 * $1135);
    $1139 = Math_fround($1133 * $1128);
    $1140 = Math_fround($1128 * $1136);
    $1141 = Math_fround($1109 + $1137);
    $1142 = Math_fround($1112 + $1138);
    $1143 = Math_fround($1115 + $1139);
    $1144 = Math_fround($1118 + $1140);
    $1145 = Math_fround($1122 * $1135);
    $1146 = Math_fround($1124 * $1133);
    $1147 = Math_fround($1126 * $1134);
    $1148 = Math_fround($1124 * $1134);
    $1149 = Math_fround($1126 * $1135);
    $1150 = Math_fround($1122 * $1133);
    $1151 = Math_fround($1145 - $1148);
    $1152 = Math_fround($1146 - $1149);
    $1153 = Math_fround($1147 - $1150);
    $1154 = Math_fround($1140 - $1140);
    $1155 = Math_fround($1141 + $1152);
    $1156 = Math_fround($1142 + $1153);
    $1157 = Math_fround($1143 + $1151);
    $1158 = Math_fround($1144 + $1154);
    $1159 = (($998) + (($18*48)|0)|0);
    $1160 = Math_fround(HEAPF32[$1159>>2]);
    $1161 = Math_fround($1160 + $1155);
    $1162 = ((($998) + (($18*48)|0)|0) + 4|0);
    $1163 = Math_fround(HEAPF32[$1162>>2]);
    $1164 = Math_fround($1163 + $1156);
    $1165 = ((($998) + (($18*48)|0)|0) + 8|0);
    $1166 = Math_fround(HEAPF32[$1165>>2]);
    $1167 = Math_fround($1166 + $1157);
    $1168 = ((($998) + (($18*48)|0)|0) + 12|0);
    $1169 = Math_fround(HEAPF32[$1168>>2]);
    $1170 = Math_fround($1169 + $1158);
    HEAPF32[$eyesPos10>>2] = $1161;
    HEAPF32[$993>>2] = $1164;
    HEAPF32[$994>>2] = $1167;
    HEAPF32[$995>>2] = $1170;
    $$pre137 = HEAP32[$$pre138>>2]|0;
    $1172 = $$pre137;
   }
   $1171 = (($1172) + ($$pre139))|0;
   $1173 = $1171;
   HEAP32[$$pre$phi144Z2D>>2] = $1173;
   $1174 = (($1173) + (($18*48)|0)|0);
   HEAPF32[$4>>2] = Math_fround(0.0);
   HEAPF32[$984>>2] = Math_fround(1.0);
   HEAPF32[$985>>2] = Math_fround(0.0);
   HEAPF32[$986>>2] = Math_fround(0.0);
   HEAPF32[$5>>2] = $987;
   __ZN7mecanim5human15GetLookAtDeltaQERKN4math7_float4ES4_S4_S4_S4_RKf($deltaQ12,$1174,$eyesPos10,$eyesRot11,$4,$headGoalT,$5);
   $1175 = HEAP32[$$pre138>>2]|0;
   $1176 = (($1175) + ($$pre139))|0;
   $1177 = $1176;
   HEAP32[$$pre$phi144Z2D>>2] = $1177;
   $1178 = Math_fround(HEAPF32[$988>>2]);
   $1179 = ((($1177) + (($18*48)|0)|0) + 16|0);
   $1180 = Math_fround(HEAPF32[$1179>>2]);
   $1181 = Math_fround($1178 * $1180);
   $1182 = Math_fround(HEAPF32[$989>>2]);
   $1183 = ((($1177) + (($18*48)|0)|0) + 28|0);
   $1184 = Math_fround(HEAPF32[$1183>>2]);
   $1185 = Math_fround($1182 * $1184);
   $1186 = Math_fround(HEAPF32[$990>>2]);
   $1187 = ((($1177) + (($18*48)|0)|0) + 20|0);
   $1188 = Math_fround(HEAPF32[$1187>>2]);
   $1189 = Math_fround($1186 * $1188);
   $1190 = Math_fround(HEAPF32[$deltaQ12>>2]);
   $1191 = ((($1177) + (($18*48)|0)|0) + 24|0);
   $1192 = Math_fround(HEAPF32[$1191>>2]);
   $1193 = Math_fround($1190 * $1192);
   $1194 = Math_fround($1182 * $1192);
   $1195 = Math_fround($1180 * $1190);
   $1196 = Math_fround($1178 * $1192);
   $1197 = Math_fround($1180 * $1186);
   $1198 = Math_fround($1181 - $1194);
   $1199 = Math_fround($1185 - $1195);
   $1200 = Math_fround($1189 - $1196);
   $1201 = Math_fround($1193 - $1197);
   $1202 = Math_fround($1184 * $1186);
   $1203 = Math_fround($1186 * $1192);
   $1204 = Math_fround($1180 * $1182);
   $1205 = Math_fround($1182 * $1188);
   $1206 = Math_fround($1198 - $1202);
   $1207 = Math_fround($1199 - $1203);
   $1208 = Math_fround($1200 - $1204);
   $1209 = Math_fround($1201 - $1205);
   $1210 = Math_fround($1188 * $1190);
   $1211 = Math_fround($1178 * $1188);
   $1212 = Math_fround($1184 * $1190);
   $1213 = Math_fround($1178 * $1184);
   $1214 = Math_fround($1206 - $1210);
   $1215 = Math_fround($1207 - $1211);
   $1216 = Math_fround($1208 - $1212);
   $1217 = Math_fround($1209 - $1213);
   $1218 = Math_fround($1216 * Math_fround(-1.0));
   $1219 = Math_fround($1217 * Math_fround(-1.0));
   $1220 = Math_fround($1214 * Math_fround(-1.0));
   $1221 = Math_fround($1218 * $1218);
   $1222 = Math_fround($1219 * $1219);
   $1223 = Math_fround($1220 * $1220);
   $1224 = Math_fround($1215 * $1215);
   $1225 = Math_fround($1221 + $1222);
   $1226 = Math_fround($1224 + $1223);
   $1227 = Math_fround($1225 + $1226);
   $1228 = (Math_fround(Math_sqrt((Math_fround($1227)))));
   $1229 = Math_fround(Math_fround(1.0) / $1228);
   $1230 = Math_fround($1229 * $1218);
   $1231 = Math_fround($1229 * $1219);
   $1232 = Math_fround($1229 * $1220);
   $1233 = Math_fround($1229 * $1215);
   HEAPF32[$1179>>2] = $1230;
   HEAPF32[$1187>>2] = $1231;
   HEAPF32[$1191>>2] = $1232;
   HEAPF32[$1183>>2] = $1233;
   $1234 = HEAP32[$713>>2]|0;
   $1235 = (($1234) + ($714))|0;
   $1236 = $1235;
   HEAP32[$718>>2] = $1236;
   __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1236,$apSkeletonPoseWorkspaceA,$apSkeletonPose,$18,$18);
   $1237 = HEAP32[$713>>2]|0;
   $1238 = (($1237) + ($714))|0;
   $1239 = $1238;
   HEAP32[$718>>2] = $1239;
   __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1239,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$18,$18);
   $1240 = (($iter$0133) + 1)|0;
   $exitcond135 = ($1240|0)==(3);
   if ($exitcond135) {
    break;
   } else {
    $iter$0133 = $1240;
   }
  }
 }
 $1241 = Math_fround(HEAPF32[$lew>>2]);
 $1242 = $1241 > Math_fround(0.0);
 if ($1242) {
  $1243 = ($20|0)==(-1);
  if (!($1243)) {
   $1244 = (($apHuman) + 48|0);
   $1245 = $1244;
   $1246 = HEAP32[$1244>>2]|0;
   $1247 = (($1246) + ($1245))|0;
   $1248 = $1247;
   $1249 = (($apHuman) + 52|0);
   HEAP32[$1249>>2] = $1248;
   __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1248,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$20,$14);
   $1250 = (($apSkeletonPoseWorkspaceA) + 4|0);
   $1251 = $1250;
   $1252 = HEAP32[$1250>>2]|0;
   $1253 = (($1252) + ($1251))|0;
   $1254 = $1253;
   $1255 = (($apSkeletonPoseWorkspaceA) + 8|0);
   HEAP32[$1255>>2] = $1254;
   $1256 = (($1254) + (($20*48)|0)|0);
   ;HEAP32[$eyesPos13+0>>2]=HEAP32[$1256+0>>2]|0;HEAP32[$eyesPos13+4>>2]=HEAP32[$1256+4>>2]|0;HEAP32[$eyesPos13+8>>2]=HEAP32[$1256+8>>2]|0;HEAP32[$eyesPos13+12>>2]=HEAP32[$1256+12>>2]|0;
   HEAP32[$1255>>2] = $1254;
   $1257 = HEAP32[$1244>>2]|0;
   $1258 = (($1257) + ($1245))|0;
   $1259 = $1258;
   $1260 = (($1259) + 24|0);
   $1261 = (($1259) + 4|0);
   $1262 = $1261;
   $1263 = HEAP32[$1261>>2]|0;
   $1264 = (($1262) + ($1263))|0;
   $1265 = $1264;
   $1266 = ((($1265) + ($20<<3)|0) + 4|0);
   $1267 = HEAP32[$1266>>2]|0;
   $1268 = $1260;
   $1269 = HEAP32[$1260>>2]|0;
   $1270 = (($1268) + ($1269))|0;
   $1271 = $1270;
   $1272 = ((($1271) + (($1267*88)|0)|0) + 16|0);
   $1273 = Math_fround(HEAPF32[$1272>>2]);
   $1274 = ((($1271) + (($1267*88)|0)|0) + 20|0);
   $1275 = Math_fround(HEAPF32[$1274>>2]);
   $1276 = ((($1271) + (($1267*88)|0)|0) + 24|0);
   $1277 = Math_fround(HEAPF32[$1276>>2]);
   $1278 = ((($1271) + (($1267*88)|0)|0) + 28|0);
   $1279 = Math_fround(HEAPF32[$1278>>2]);
   $1280 = ((($1254) + (($20*48)|0)|0) + 20|0);
   $1281 = Math_fround(HEAPF32[$1280>>2]);
   $1282 = Math_fround($1273 * $1281);
   $1283 = ((($1254) + (($20*48)|0)|0) + 28|0);
   $1284 = Math_fround(HEAPF32[$1283>>2]);
   $1285 = Math_fround($1279 * $1284);
   $1286 = ((($1254) + (($20*48)|0)|0) + 24|0);
   $1287 = Math_fround(HEAPF32[$1286>>2]);
   $1288 = Math_fround($1275 * $1287);
   $1289 = ((($1254) + (($20*48)|0)|0) + 16|0);
   $1290 = Math_fround(HEAPF32[$1289>>2]);
   $1291 = Math_fround($1277 * $1290);
   $1292 = Math_fround($1277 * $1284);
   $1293 = Math_fround($1273 * $1290);
   $1294 = Math_fround($1277 * $1281);
   $1295 = Math_fround($1273 * $1287);
   $1296 = Math_fround($1282 - $1292);
   $1297 = Math_fround($1285 - $1293);
   $1298 = Math_fround($1288 - $1294);
   $1299 = Math_fround($1291 - $1295);
   $1300 = Math_fround($1279 * $1287);
   $1301 = Math_fround($1277 * $1287);
   $1302 = Math_fround($1273 * $1284);
   $1303 = Math_fround($1275 * $1284);
   $1304 = Math_fround($1296 - $1300);
   $1305 = Math_fround($1297 - $1301);
   $1306 = Math_fround($1298 - $1302);
   $1307 = Math_fround($1299 - $1303);
   $1308 = Math_fround($1275 * $1290);
   $1309 = Math_fround($1275 * $1281);
   $1310 = Math_fround($1279 * $1290);
   $1311 = Math_fround($1279 * $1281);
   $1312 = Math_fround($1304 - $1308);
   $1313 = Math_fround($1305 - $1309);
   $1314 = Math_fround($1306 - $1310);
   $1315 = Math_fround($1307 - $1311);
   $1316 = Math_fround($1314 * Math_fround(-1.0));
   $1317 = Math_fround($1315 * Math_fround(-1.0));
   $1318 = Math_fround($1312 * Math_fround(-1.0));
   $1319 = Math_fround($1316 * $1316);
   $1320 = Math_fround($1317 * $1317);
   $1321 = Math_fround($1318 * $1318);
   $1322 = Math_fround($1313 * $1313);
   $1323 = Math_fround($1319 + $1320);
   $1324 = Math_fround($1321 + $1322);
   $1325 = Math_fround($1324 + $1323);
   $1326 = (Math_fround(Math_sqrt((Math_fround($1325)))));
   $1327 = Math_fround(Math_fround(1.0) / $1326);
   $1328 = Math_fround($1327 * $1316);
   $1329 = Math_fround($1327 * $1317);
   $1330 = Math_fround($1327 * $1318);
   $1331 = Math_fround($1327 * $1313);
   HEAPF32[$eyesRot14>>2] = $1328;
   $1332 = (($eyesRot14) + 4|0);
   HEAPF32[$1332>>2] = $1329;
   $1333 = (($eyesRot14) + 8|0);
   HEAPF32[$1333>>2] = $1330;
   $1334 = (($eyesRot14) + 12|0);
   HEAPF32[$1334>>2] = $1331;
   HEAP32[$1255>>2] = $1254;
   HEAPF32[$6>>2] = Math_fround(-1.0);
   $1335 = (($6) + 4|0);
   HEAPF32[$1335>>2] = Math_fround(0.0);
   $1336 = (($6) + 8|0);
   HEAPF32[$1336>>2] = Math_fround(0.0);
   $1337 = (($6) + 12|0);
   HEAPF32[$1337>>2] = Math_fround(0.0);
   __ZN7mecanim5human15GetLookAtDeltaQERKN4math7_float4ES4_S4_S4_S4_RKf($deltaQ15,$1256,$eyesPos13,$eyesRot14,$6,$headGoalT,$lew);
   $1338 = HEAP32[$1250>>2]|0;
   $1339 = (($1338) + ($1251))|0;
   $1340 = $1339;
   HEAP32[$1255>>2] = $1340;
   $1341 = (($deltaQ15) + 4|0);
   $1342 = Math_fround(HEAPF32[$1341>>2]);
   $1343 = ((($1340) + (($20*48)|0)|0) + 16|0);
   $1344 = Math_fround(HEAPF32[$1343>>2]);
   $1345 = Math_fround($1342 * $1344);
   $1346 = (($deltaQ15) + 12|0);
   $1347 = Math_fround(HEAPF32[$1346>>2]);
   $1348 = ((($1340) + (($20*48)|0)|0) + 28|0);
   $1349 = Math_fround(HEAPF32[$1348>>2]);
   $1350 = Math_fround($1347 * $1349);
   $1351 = (($deltaQ15) + 8|0);
   $1352 = Math_fround(HEAPF32[$1351>>2]);
   $1353 = ((($1340) + (($20*48)|0)|0) + 20|0);
   $1354 = Math_fround(HEAPF32[$1353>>2]);
   $1355 = Math_fround($1352 * $1354);
   $1356 = Math_fround(HEAPF32[$deltaQ15>>2]);
   $1357 = ((($1340) + (($20*48)|0)|0) + 24|0);
   $1358 = Math_fround(HEAPF32[$1357>>2]);
   $1359 = Math_fround($1356 * $1358);
   $1360 = Math_fround($1347 * $1358);
   $1361 = Math_fround($1344 * $1356);
   $1362 = Math_fround($1342 * $1358);
   $1363 = Math_fround($1344 * $1352);
   $1364 = Math_fround($1345 - $1360);
   $1365 = Math_fround($1350 - $1361);
   $1366 = Math_fround($1355 - $1362);
   $1367 = Math_fround($1359 - $1363);
   $1368 = Math_fround($1349 * $1352);
   $1369 = Math_fround($1352 * $1358);
   $1370 = Math_fround($1344 * $1347);
   $1371 = Math_fround($1347 * $1354);
   $1372 = Math_fround($1364 - $1368);
   $1373 = Math_fround($1365 - $1369);
   $1374 = Math_fround($1366 - $1370);
   $1375 = Math_fround($1367 - $1371);
   $1376 = Math_fround($1354 * $1356);
   $1377 = Math_fround($1342 * $1354);
   $1378 = Math_fround($1349 * $1356);
   $1379 = Math_fround($1342 * $1349);
   $1380 = Math_fround($1372 - $1376);
   $1381 = Math_fround($1373 - $1377);
   $1382 = Math_fround($1374 - $1378);
   $1383 = Math_fround($1375 - $1379);
   $1384 = Math_fround($1382 * Math_fround(-1.0));
   $1385 = Math_fround($1383 * Math_fround(-1.0));
   $1386 = Math_fround($1380 * Math_fround(-1.0));
   $1387 = Math_fround($1384 * $1384);
   $1388 = Math_fround($1385 * $1385);
   $1389 = Math_fround($1386 * $1386);
   $1390 = Math_fround($1381 * $1381);
   $1391 = Math_fround($1387 + $1388);
   $1392 = Math_fround($1390 + $1389);
   $1393 = Math_fround($1391 + $1392);
   $1394 = (Math_fround(Math_sqrt((Math_fround($1393)))));
   $1395 = Math_fround(Math_fround(1.0) / $1394);
   $1396 = Math_fround($1395 * $1384);
   $1397 = Math_fround($1395 * $1385);
   $1398 = Math_fround($1395 * $1386);
   $1399 = Math_fround($1395 * $1381);
   HEAPF32[$1343>>2] = $1396;
   HEAPF32[$1353>>2] = $1397;
   HEAPF32[$1357>>2] = $1398;
   HEAPF32[$1348>>2] = $1399;
   $1400 = HEAP32[$1244>>2]|0;
   $1401 = (($1400) + ($1245))|0;
   $1402 = $1401;
   HEAP32[$1249>>2] = $1402;
   __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1402,$apSkeletonPoseWorkspaceA,$apSkeletonPose,$20,$20);
  }
  $1403 = ($22|0)==(-1);
  if (!($1403)) {
   $1404 = (($apHuman) + 48|0);
   $1405 = $1404;
   $1406 = HEAP32[$1404>>2]|0;
   $1407 = (($1406) + ($1405))|0;
   $1408 = $1407;
   $1409 = (($apHuman) + 52|0);
   HEAP32[$1409>>2] = $1408;
   __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1408,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$22,$14);
   $1410 = (($apSkeletonPoseWorkspaceA) + 4|0);
   $1411 = $1410;
   $1412 = HEAP32[$1410>>2]|0;
   $1413 = (($1412) + ($1411))|0;
   $1414 = $1413;
   $1415 = (($apSkeletonPoseWorkspaceA) + 8|0);
   HEAP32[$1415>>2] = $1414;
   $1416 = (($1414) + (($22*48)|0)|0);
   ;HEAP32[$eyesPos16+0>>2]=HEAP32[$1416+0>>2]|0;HEAP32[$eyesPos16+4>>2]=HEAP32[$1416+4>>2]|0;HEAP32[$eyesPos16+8>>2]=HEAP32[$1416+8>>2]|0;HEAP32[$eyesPos16+12>>2]=HEAP32[$1416+12>>2]|0;
   HEAP32[$1415>>2] = $1414;
   $1417 = HEAP32[$1404>>2]|0;
   $1418 = (($1417) + ($1405))|0;
   $1419 = $1418;
   $1420 = (($1419) + 24|0);
   $1421 = (($1419) + 4|0);
   $1422 = $1421;
   $1423 = HEAP32[$1421>>2]|0;
   $1424 = (($1422) + ($1423))|0;
   $1425 = $1424;
   $1426 = ((($1425) + ($22<<3)|0) + 4|0);
   $1427 = HEAP32[$1426>>2]|0;
   $1428 = $1420;
   $1429 = HEAP32[$1420>>2]|0;
   $1430 = (($1428) + ($1429))|0;
   $1431 = $1430;
   $1432 = ((($1431) + (($1427*88)|0)|0) + 16|0);
   $1433 = Math_fround(HEAPF32[$1432>>2]);
   $1434 = ((($1431) + (($1427*88)|0)|0) + 20|0);
   $1435 = Math_fround(HEAPF32[$1434>>2]);
   $1436 = ((($1431) + (($1427*88)|0)|0) + 24|0);
   $1437 = Math_fround(HEAPF32[$1436>>2]);
   $1438 = ((($1431) + (($1427*88)|0)|0) + 28|0);
   $1439 = Math_fround(HEAPF32[$1438>>2]);
   $1440 = ((($1414) + (($22*48)|0)|0) + 20|0);
   $1441 = Math_fround(HEAPF32[$1440>>2]);
   $1442 = Math_fround($1433 * $1441);
   $1443 = ((($1414) + (($22*48)|0)|0) + 28|0);
   $1444 = Math_fround(HEAPF32[$1443>>2]);
   $1445 = Math_fround($1439 * $1444);
   $1446 = ((($1414) + (($22*48)|0)|0) + 24|0);
   $1447 = Math_fround(HEAPF32[$1446>>2]);
   $1448 = Math_fround($1435 * $1447);
   $1449 = ((($1414) + (($22*48)|0)|0) + 16|0);
   $1450 = Math_fround(HEAPF32[$1449>>2]);
   $1451 = Math_fround($1437 * $1450);
   $1452 = Math_fround($1437 * $1444);
   $1453 = Math_fround($1433 * $1450);
   $1454 = Math_fround($1437 * $1441);
   $1455 = Math_fround($1433 * $1447);
   $1456 = Math_fround($1442 - $1452);
   $1457 = Math_fround($1445 - $1453);
   $1458 = Math_fround($1448 - $1454);
   $1459 = Math_fround($1451 - $1455);
   $1460 = Math_fround($1439 * $1447);
   $1461 = Math_fround($1437 * $1447);
   $1462 = Math_fround($1433 * $1444);
   $1463 = Math_fround($1435 * $1444);
   $1464 = Math_fround($1456 - $1460);
   $1465 = Math_fround($1457 - $1461);
   $1466 = Math_fround($1458 - $1462);
   $1467 = Math_fround($1459 - $1463);
   $1468 = Math_fround($1435 * $1450);
   $1469 = Math_fround($1435 * $1441);
   $1470 = Math_fround($1439 * $1450);
   $1471 = Math_fround($1439 * $1441);
   $1472 = Math_fround($1464 - $1468);
   $1473 = Math_fround($1465 - $1469);
   $1474 = Math_fround($1466 - $1470);
   $1475 = Math_fround($1467 - $1471);
   $1476 = Math_fround($1474 * Math_fround(-1.0));
   $1477 = Math_fround($1475 * Math_fround(-1.0));
   $1478 = Math_fround($1472 * Math_fround(-1.0));
   $1479 = Math_fround($1476 * $1476);
   $1480 = Math_fround($1477 * $1477);
   $1481 = Math_fround($1478 * $1478);
   $1482 = Math_fround($1473 * $1473);
   $1483 = Math_fround($1479 + $1480);
   $1484 = Math_fround($1481 + $1482);
   $1485 = Math_fround($1484 + $1483);
   $1486 = (Math_fround(Math_sqrt((Math_fround($1485)))));
   $1487 = Math_fround(Math_fround(1.0) / $1486);
   $1488 = Math_fround($1487 * $1476);
   $1489 = Math_fround($1487 * $1477);
   $1490 = Math_fround($1487 * $1478);
   $1491 = Math_fround($1487 * $1473);
   HEAPF32[$eyesRot17>>2] = $1488;
   $1492 = (($eyesRot17) + 4|0);
   HEAPF32[$1492>>2] = $1489;
   $1493 = (($eyesRot17) + 8|0);
   HEAPF32[$1493>>2] = $1490;
   $1494 = (($eyesRot17) + 12|0);
   HEAPF32[$1494>>2] = $1491;
   HEAP32[$1415>>2] = $1414;
   HEAPF32[$7>>2] = Math_fround(-1.0);
   $1495 = (($7) + 4|0);
   HEAPF32[$1495>>2] = Math_fround(0.0);
   $1496 = (($7) + 8|0);
   HEAPF32[$1496>>2] = Math_fround(0.0);
   $1497 = (($7) + 12|0);
   HEAPF32[$1497>>2] = Math_fround(0.0);
   __ZN7mecanim5human15GetLookAtDeltaQERKN4math7_float4ES4_S4_S4_S4_RKf($deltaQ18,$1416,$eyesPos16,$eyesRot17,$7,$headGoalT,$lew);
   $1498 = HEAP32[$1410>>2]|0;
   $1499 = (($1498) + ($1411))|0;
   $1500 = $1499;
   HEAP32[$1415>>2] = $1500;
   $1501 = (($deltaQ18) + 4|0);
   $1502 = Math_fround(HEAPF32[$1501>>2]);
   $1503 = ((($1500) + (($22*48)|0)|0) + 16|0);
   $1504 = Math_fround(HEAPF32[$1503>>2]);
   $1505 = Math_fround($1502 * $1504);
   $1506 = (($deltaQ18) + 12|0);
   $1507 = Math_fround(HEAPF32[$1506>>2]);
   $1508 = ((($1500) + (($22*48)|0)|0) + 28|0);
   $1509 = Math_fround(HEAPF32[$1508>>2]);
   $1510 = Math_fround($1507 * $1509);
   $1511 = (($deltaQ18) + 8|0);
   $1512 = Math_fround(HEAPF32[$1511>>2]);
   $1513 = ((($1500) + (($22*48)|0)|0) + 20|0);
   $1514 = Math_fround(HEAPF32[$1513>>2]);
   $1515 = Math_fround($1512 * $1514);
   $1516 = Math_fround(HEAPF32[$deltaQ18>>2]);
   $1517 = ((($1500) + (($22*48)|0)|0) + 24|0);
   $1518 = Math_fround(HEAPF32[$1517>>2]);
   $1519 = Math_fround($1516 * $1518);
   $1520 = Math_fround($1507 * $1518);
   $1521 = Math_fround($1504 * $1516);
   $1522 = Math_fround($1502 * $1518);
   $1523 = Math_fround($1504 * $1512);
   $1524 = Math_fround($1505 - $1520);
   $1525 = Math_fround($1510 - $1521);
   $1526 = Math_fround($1515 - $1522);
   $1527 = Math_fround($1519 - $1523);
   $1528 = Math_fround($1509 * $1512);
   $1529 = Math_fround($1512 * $1518);
   $1530 = Math_fround($1504 * $1507);
   $1531 = Math_fround($1507 * $1514);
   $1532 = Math_fround($1524 - $1528);
   $1533 = Math_fround($1525 - $1529);
   $1534 = Math_fround($1526 - $1530);
   $1535 = Math_fround($1527 - $1531);
   $1536 = Math_fround($1514 * $1516);
   $1537 = Math_fround($1502 * $1514);
   $1538 = Math_fround($1509 * $1516);
   $1539 = Math_fround($1502 * $1509);
   $1540 = Math_fround($1532 - $1536);
   $1541 = Math_fround($1533 - $1537);
   $1542 = Math_fround($1534 - $1538);
   $1543 = Math_fround($1535 - $1539);
   $1544 = Math_fround($1542 * Math_fround(-1.0));
   $1545 = Math_fround($1543 * Math_fround(-1.0));
   $1546 = Math_fround($1540 * Math_fround(-1.0));
   $1547 = Math_fround($1544 * $1544);
   $1548 = Math_fround($1545 * $1545);
   $1549 = Math_fround($1546 * $1546);
   $1550 = Math_fround($1541 * $1541);
   $1551 = Math_fround($1547 + $1548);
   $1552 = Math_fround($1550 + $1549);
   $1553 = Math_fround($1551 + $1552);
   $1554 = (Math_fround(Math_sqrt((Math_fround($1553)))));
   $1555 = Math_fround(Math_fround(1.0) / $1554);
   $1556 = Math_fround($1555 * $1544);
   $1557 = Math_fround($1555 * $1545);
   $1558 = Math_fround($1555 * $1546);
   $1559 = Math_fround($1555 * $1541);
   HEAPF32[$1503>>2] = $1556;
   HEAPF32[$1513>>2] = $1557;
   HEAPF32[$1517>>2] = $1558;
   HEAPF32[$1508>>2] = $1559;
   $1560 = HEAP32[$1404>>2]|0;
   $1561 = (($1560) + ($1405))|0;
   $1562 = $1561;
   HEAP32[$1409>>2] = $1562;
   __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1562,$apSkeletonPoseWorkspaceA,$apSkeletonPose,$22,$22);
  }
 }
 $1563 = (($apHuman) + 48|0);
 $1564 = $1563;
 $1565 = (($apHuman) + 52|0);
 $1566 = (($apSkeletonPoseWorkspaceA) + 4|0);
 $1567 = $1566;
 $1568 = (($apSkeletonPoseWorkspaceA) + 8|0);
 $1569 = (($t) + 4|0);
 $1570 = (($t) + 8|0);
 $1571 = (($t) + 12|0);
 $1572 = (($apHuman) + 416|0);
 $1573 = (($apHuman) + 412|0);
 $goalIter$0131 = 0;
 while(1) {
  $1577 = ((798784 + ($goalIter$0131<<4)|0) + 4|0);
  $1578 = HEAP32[$1577>>2]|0;
  $1579 = ((($apHuman) + ($1578<<2)|0) + 104|0);
  $1580 = HEAP32[$1579>>2]|0;
  $1581 = ((798784 + ($goalIter$0131<<4)|0) + 8|0);
  $1582 = HEAP32[$1581>>2]|0;
  $1583 = ((($apHuman) + ($1582<<2)|0) + 104|0);
  $1584 = HEAP32[$1583>>2]|0;
  $1585 = ((798784 + ($goalIter$0131<<4)|0) + 12|0);
  $1586 = HEAP32[$1585>>2]|0;
  $1587 = ((($apHuman) + ($1586<<2)|0) + 104|0);
  $1588 = HEAP32[$1587>>2]|0;
  $1589 = ((($apHumanPose) + (($goalIter$0131*76)|0)|0) + 128|0);
  $1590 = Math_fround(HEAPF32[$1589>>2]);
  $1591 = $1590 > Math_fround(0.0);
  if ($1591) {
   $1592 = (Math_fround(+(_fmaxf(0.0,(+$1590)))));
   $1593 = (Math_fround(+(_fminf(1.0,(+$1592)))));
   $1594 = HEAP32[$1563>>2]|0;
   $1595 = (($1594) + ($1564))|0;
   $1596 = $1595;
   HEAP32[$1565>>2] = $1596;
   __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1596,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$1588,$10);
   $1597 = HEAP32[$1566>>2]|0;
   $1598 = (($1597) + ($1567))|0;
   $1599 = $1598;
   HEAP32[$1568>>2] = $1599;
   $1600 = ((($apHumanPose) + (($goalIter$0131*76)|0)|0) + 80|0);
   $1601 = Math_fround(HEAPF32[$1600>>2]);
   $1602 = (($1599) + (($1588*48)|0)|0);
   $1603 = Math_fround(HEAPF32[$1602>>2]);
   $1604 = Math_fround($1601 - $1603);
   $1605 = ((($apHumanPose) + (($goalIter$0131*76)|0)|0) + 84|0);
   $1606 = Math_fround(HEAPF32[$1605>>2]);
   $1607 = ((($1599) + (($1588*48)|0)|0) + 4|0);
   $1608 = Math_fround(HEAPF32[$1607>>2]);
   $1609 = Math_fround($1606 - $1608);
   $1610 = ((($apHumanPose) + (($goalIter$0131*76)|0)|0) + 88|0);
   $1611 = Math_fround(HEAPF32[$1610>>2]);
   $1612 = ((($1599) + (($1588*48)|0)|0) + 8|0);
   $1613 = Math_fround(HEAPF32[$1612>>2]);
   $1614 = Math_fround($1611 - $1613);
   $1615 = ((($apHumanPose) + (($goalIter$0131*76)|0)|0) + 92|0);
   $1616 = Math_fround(HEAPF32[$1615>>2]);
   $1617 = ((($1599) + (($1588*48)|0)|0) + 12|0);
   $1618 = Math_fround(HEAPF32[$1617>>2]);
   $1619 = Math_fround($1616 - $1618);
   $1620 = Math_fround($1593 * $1604);
   $1621 = Math_fround($1593 * $1609);
   $1622 = Math_fround($1593 * $1614);
   $1623 = Math_fround($1593 * $1619);
   $1624 = Math_fround($1603 + $1620);
   $1625 = Math_fround($1608 + $1621);
   $1626 = Math_fround($1613 + $1622);
   $1627 = Math_fround($1618 + $1623);
   HEAPF32[$t>>2] = $1624;
   HEAPF32[$1569>>2] = $1625;
   HEAPF32[$1570>>2] = $1626;
   HEAPF32[$1571>>2] = $1627;
   $1628 = HEAP32[$1563>>2]|0;
   $1629 = (($1628) + ($1564))|0;
   $1630 = $1629;
   HEAP32[$1565>>2] = $1630;
   $1631 = ($goalIter$0131|0)<(2);
   $$in = $1631 ? $1572 : $1573;
   $1632 = Math_fround(HEAPF32[$$in>>2]);
   $1633 = Math_fround($1593 * $1632);
   HEAPF32[$8>>2] = $1633;
   __ZN7mecanim8skeleton25Skeleton2BoneAdjustLengthEPKNS0_8SkeletonEiiiRKN4math7_float4ERKfPNS0_12SkeletonPoseESB_($1630,$1580,$1584,$1588,$t,$8,$apSkeletonPose,$apSkeletonPoseWorkspaceA);
   $1634 = HEAP32[$1563>>2]|0;
   $1635 = (($1634) + ($1564))|0;
   $1636 = $1635;
   HEAP32[$1565>>2] = $1636;
   __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1636,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$1588,$1580);
   $1637 = HEAP32[$1563>>2]|0;
   $1638 = (($1637) + ($1564))|0;
   $1639 = $1638;
   HEAP32[$1565>>2] = $1639;
   __ZN7mecanim8skeleton15Skeleton2BoneIKEPKNS0_8SkeletonEiiiRKN4math7_float4EfPNS0_12SkeletonPoseES9_($1639,$1580,$1584,$1588,$1600,$1593,$apSkeletonPose,$apSkeletonPoseWorkspaceA);
  }
  $1640 = ((($apHumanPose) + (($goalIter$0131*76)|0)|0) + 152|0);
  $1641 = Math_fround(HEAPF32[$1640>>2]);
  $1642 = $1641 > Math_fround(0.0);
  if ($1642) {
   $1643 = (Math_fround(+(_fmaxf(0.0,(+$1641)))));
   $1644 = (Math_fround(+(_fminf(1.0,(+$1643)))));
   $1645 = HEAP32[$1563>>2]|0;
   $1646 = (($1645) + ($1564))|0;
   $1647 = $1646;
   HEAP32[$1565>>2] = $1647;
   __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1647,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$1588,$1580);
   $1648 = HEAP32[$1563>>2]|0;
   $1649 = (($1648) + ($1564))|0;
   $1650 = $1649;
   HEAP32[$1565>>2] = $1650;
   $1651 = ((($apHumanPose) + (($goalIter$0131*76)|0)|0) + 136|0);
   __ZN7mecanim8skeleton23Skeleton2BoneAdjustHintEPKNS0_8SkeletonEiiiRKN4math7_float4EfPNS0_12SkeletonPoseES9_f($1650,$1580,$1584,$1588,$1651,$1644,$apSkeletonPose,$apSkeletonPoseWorkspaceA,Math_fround(0.0500000007450580596924));
  }
  $1652 = (($goalIter$0131) + 1)|0;
  $exitcond134 = ($1652|0)==(4);
  if ($exitcond134) {
   break;
  } else {
   $goalIter$0131 = $1652;
  }
 }
 $1574 = (($q) + 4|0);
 $1575 = (($q) + 8|0);
 $1576 = (($q) + 12|0);
 $goalIter$1129 = 0;
 while(1) {
  $1653 = ((($apHumanPose) + (($goalIter$1129*76)|0)|0) + 132|0);
  $1654 = Math_fround(HEAPF32[$1653>>2]);
  $1655 = $1654 > Math_fround(0.0);
  if ($1655) {
   $1656 = ((798784 + ($goalIter$1129<<4)|0) + 12|0);
   $1657 = HEAP32[$1656>>2]|0;
   $1658 = ((($apHuman) + ($1657<<2)|0) + 104|0);
   $1659 = HEAP32[$1658>>2]|0;
   $1660 = (Math_fround(+(_fmaxf(0.0,(+$1654)))));
   $1661 = (Math_fround(+(_fminf(1.0,(+$1660)))));
   $1662 = HEAP32[$1563>>2]|0;
   $1663 = (($1662) + ($1564))|0;
   $1664 = $1663;
   HEAP32[$1565>>2] = $1664;
   __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($1664,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$1659,$10);
   $1665 = (798784 + ($goalIter$1129<<4)|0);
   $1666 = HEAP32[$1665>>2]|0;
   $1667 = ((($apHuman) + ($1666<<2)|0) + 104|0);
   $1668 = HEAP32[$1667>>2]|0;
   $1669 = HEAP32[$1566>>2]|0;
   $1670 = (($1669) + ($1567))|0;
   $1671 = $1670;
   HEAP32[$1568>>2] = $1671;
   $1672 = HEAP32[$1563>>2]|0;
   $1673 = (($1672) + ($1564))|0;
   $1674 = $1673;
   $1675 = (($1674) + 24|0);
   $1676 = (($1674) + 4|0);
   $1677 = $1676;
   $1678 = HEAP32[$1676>>2]|0;
   $1679 = (($1677) + ($1678))|0;
   $1680 = $1679;
   $1681 = ((($1680) + ($1668<<3)|0) + 4|0);
   $1682 = HEAP32[$1681>>2]|0;
   $1683 = $1675;
   $1684 = HEAP32[$1675>>2]|0;
   $1685 = (($1683) + ($1684))|0;
   $1686 = $1685;
   $1687 = ((($1686) + (($1682*88)|0)|0) + 16|0);
   $1688 = Math_fround(HEAPF32[$1687>>2]);
   $1689 = ((($1686) + (($1682*88)|0)|0) + 20|0);
   $1690 = Math_fround(HEAPF32[$1689>>2]);
   $1691 = ((($1686) + (($1682*88)|0)|0) + 24|0);
   $1692 = Math_fround(HEAPF32[$1691>>2]);
   $1693 = ((($1686) + (($1682*88)|0)|0) + 28|0);
   $1694 = Math_fround(HEAPF32[$1693>>2]);
   $1695 = ((($1671) + (($1668*48)|0)|0) + 20|0);
   $1696 = Math_fround(HEAPF32[$1695>>2]);
   $1697 = Math_fround($1688 * $1696);
   $1698 = ((($1671) + (($1668*48)|0)|0) + 28|0);
   $1699 = Math_fround(HEAPF32[$1698>>2]);
   $1700 = Math_fround($1694 * $1699);
   $1701 = ((($1671) + (($1668*48)|0)|0) + 24|0);
   $1702 = Math_fround(HEAPF32[$1701>>2]);
   $1703 = Math_fround($1690 * $1702);
   $1704 = ((($1671) + (($1668*48)|0)|0) + 16|0);
   $1705 = Math_fround(HEAPF32[$1704>>2]);
   $1706 = Math_fround($1692 * $1705);
   $1707 = Math_fround($1692 * $1699);
   $1708 = Math_fround($1688 * $1705);
   $1709 = Math_fround($1692 * $1696);
   $1710 = Math_fround($1688 * $1702);
   $1711 = Math_fround($1697 - $1707);
   $1712 = Math_fround($1700 - $1708);
   $1713 = Math_fround($1703 - $1709);
   $1714 = Math_fround($1706 - $1710);
   $1715 = Math_fround($1694 * $1702);
   $1716 = Math_fround($1692 * $1702);
   $1717 = Math_fround($1688 * $1699);
   $1718 = Math_fround($1690 * $1699);
   $1719 = Math_fround($1711 - $1715);
   $1720 = Math_fround($1712 - $1716);
   $1721 = Math_fround($1713 - $1717);
   $1722 = Math_fround($1714 - $1718);
   $1723 = Math_fround($1690 * $1705);
   $1724 = Math_fround($1690 * $1696);
   $1725 = Math_fround($1694 * $1705);
   $1726 = Math_fround($1694 * $1696);
   $1727 = Math_fround($1719 - $1723);
   $1728 = Math_fround($1720 - $1724);
   $1729 = Math_fround($1721 - $1725);
   $1730 = Math_fround($1722 - $1726);
   $1731 = Math_fround($1729 * Math_fround(-1.0));
   $1732 = Math_fround($1730 * Math_fround(-1.0));
   $1733 = Math_fround($1727 * Math_fround(-1.0));
   $1734 = Math_fround($1731 * $1731);
   $1735 = Math_fround($1732 * $1732);
   $1736 = Math_fround($1733 * $1733);
   $1737 = Math_fround($1728 * $1728);
   $1738 = Math_fround($1734 + $1735);
   $1739 = Math_fround($1736 + $1737);
   $1740 = Math_fround($1739 + $1738);
   $1741 = (Math_fround(Math_sqrt((Math_fround($1740)))));
   $1742 = Math_fround(Math_fround(1.0) / $1741);
   $1743 = Math_fround($1742 * $1731);
   $1744 = Math_fround($1742 * $1732);
   $1745 = Math_fround($1742 * $1733);
   $1746 = Math_fround($1742 * $1728);
   $1747 = ((($apHumanPose) + (($goalIter$1129*76)|0)|0) + 96|0);
   $1748 = Math_fround(HEAPF32[$1747>>2]);
   $1749 = Math_fround($1743 * $1748);
   $1750 = ((($apHumanPose) + (($goalIter$1129*76)|0)|0) + 100|0);
   $1751 = Math_fround(HEAPF32[$1750>>2]);
   $1752 = Math_fround($1744 * $1751);
   $1753 = ((($apHumanPose) + (($goalIter$1129*76)|0)|0) + 104|0);
   $1754 = Math_fround(HEAPF32[$1753>>2]);
   $1755 = Math_fround($1745 * $1754);
   $1756 = ((($apHumanPose) + (($goalIter$1129*76)|0)|0) + 108|0);
   $1757 = Math_fround(HEAPF32[$1756>>2]);
   $1758 = Math_fround($1746 * $1757);
   $1759 = Math_fround($1749 + $1752);
   $1760 = Math_fround($1755 + $1758);
   $1761 = Math_fround($1759 + $1760);
   $1762 = (HEAPF32[tempDoublePtr>>2]=$1748,HEAP32[tempDoublePtr>>2]|0);
   $1763 = (HEAPF32[tempDoublePtr>>2]=$1761,HEAP32[tempDoublePtr>>2]|0);
   $1764 = $1763 & -2147483648;
   $1765 = $1764 ^ $1762;
   $1766 = (HEAP32[tempDoublePtr>>2]=$1765,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1767 = (HEAPF32[tempDoublePtr>>2]=$1751,HEAP32[tempDoublePtr>>2]|0);
   $1768 = $1764 ^ $1767;
   $1769 = (HEAP32[tempDoublePtr>>2]=$1768,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1770 = (HEAPF32[tempDoublePtr>>2]=$1754,HEAP32[tempDoublePtr>>2]|0);
   $1771 = $1764 ^ $1770;
   $1772 = (HEAP32[tempDoublePtr>>2]=$1771,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1773 = (HEAPF32[tempDoublePtr>>2]=$1757,HEAP32[tempDoublePtr>>2]|0);
   $1774 = $1764 ^ $1773;
   $1775 = (HEAP32[tempDoublePtr>>2]=$1774,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $1776 = Math_fround($1766 - $1743);
   $1777 = Math_fround($1769 - $1744);
   $1778 = Math_fround($1772 - $1745);
   $1779 = Math_fround($1775 - $1746);
   $1780 = Math_fround($1661 * $1776);
   $1781 = Math_fround($1661 * $1777);
   $1782 = Math_fround($1661 * $1778);
   $1783 = Math_fround($1661 * $1779);
   $1784 = Math_fround($1743 + $1780);
   $1785 = Math_fround($1744 + $1781);
   $1786 = Math_fround($1745 + $1782);
   $1787 = Math_fround($1746 + $1783);
   $1788 = Math_fround($1784 * $1784);
   $1789 = Math_fround($1785 * $1785);
   $1790 = Math_fround($1786 * $1786);
   $1791 = Math_fround($1787 * $1787);
   $1792 = Math_fround($1788 + $1789);
   $1793 = Math_fround($1790 + $1791);
   $1794 = Math_fround($1792 + $1793);
   $1795 = (Math_fround(Math_sqrt((Math_fround($1794)))));
   $1796 = Math_fround(Math_fround(1.0) / $1795);
   $1797 = Math_fround($1796 * $1784);
   $1798 = Math_fround($1796 * $1785);
   $1799 = Math_fround($1796 * $1786);
   $1800 = Math_fround($1796 * $1787);
   HEAPF32[$q>>2] = $1797;
   HEAPF32[$1574>>2] = $1798;
   HEAPF32[$1575>>2] = $1799;
   HEAPF32[$1576>>2] = $1800;
   $1801 = HEAP32[$1563>>2]|0;
   $1802 = (($1801) + ($1564))|0;
   $1803 = $1802;
   $1804 = (($1803) + 24|0);
   $1805 = (($1803) + 4|0);
   $1806 = $1805;
   $1807 = HEAP32[$1805>>2]|0;
   $1808 = (($1806) + ($1807))|0;
   $1809 = $1808;
   $1810 = ((($1809) + ($1668<<3)|0) + 4|0);
   $1811 = HEAP32[$1810>>2]|0;
   $1812 = $1804;
   $1813 = HEAP32[$1804>>2]|0;
   $1814 = (($1812) + ($1813))|0;
   $1815 = $1814;
   $1816 = ((($1815) + (($1811*88)|0)|0) + 16|0);
   $1817 = Math_fround(HEAPF32[$1816>>2]);
   $1818 = ((($1815) + (($1811*88)|0)|0) + 20|0);
   $1819 = Math_fround(HEAPF32[$1818>>2]);
   $1820 = ((($1815) + (($1811*88)|0)|0) + 24|0);
   $1821 = Math_fround(HEAPF32[$1820>>2]);
   $1822 = ((($1815) + (($1811*88)|0)|0) + 28|0);
   $1823 = Math_fround(HEAPF32[$1822>>2]);
   $1824 = Math_fround($1817 * Math_fround(-1.0));
   $1825 = Math_fround($1819 * Math_fround(-1.0));
   $1826 = Math_fround($1821 * Math_fround(-1.0));
   $1827 = Math_fround($1824 * $1798);
   $1828 = Math_fround($1823 * $1800);
   $1829 = Math_fround($1825 * $1799);
   $1830 = Math_fround($1826 * $1797);
   $1831 = Math_fround($1826 * $1800);
   $1832 = Math_fround($1824 * $1797);
   $1833 = Math_fround($1826 * $1798);
   $1834 = Math_fround($1824 * $1799);
   $1835 = Math_fround($1827 - $1831);
   $1836 = Math_fround($1828 - $1832);
   $1837 = Math_fround($1829 - $1833);
   $1838 = Math_fround($1830 - $1834);
   $1839 = Math_fround($1823 * $1799);
   $1840 = Math_fround($1826 * $1799);
   $1841 = Math_fround($1824 * $1800);
   $1842 = Math_fround($1825 * $1800);
   $1843 = Math_fround($1835 - $1839);
   $1844 = Math_fround($1836 - $1840);
   $1845 = Math_fround($1837 - $1841);
   $1846 = Math_fround($1838 - $1842);
   $1847 = Math_fround($1825 * $1797);
   $1848 = Math_fround($1825 * $1798);
   $1849 = Math_fround($1823 * $1797);
   $1850 = Math_fround($1823 * $1798);
   $1851 = Math_fround($1843 - $1847);
   $1852 = Math_fround($1844 - $1848);
   $1853 = Math_fround($1845 - $1849);
   $1854 = Math_fround($1846 - $1850);
   $1855 = Math_fround($1853 * Math_fround(-1.0));
   $1856 = Math_fround($1854 * Math_fround(-1.0));
   $1857 = Math_fround($1851 * Math_fround(-1.0));
   $1858 = Math_fround($1855 * $1855);
   $1859 = Math_fround($1856 * $1856);
   $1860 = Math_fround($1857 * $1857);
   $1861 = Math_fround($1852 * $1852);
   $1862 = Math_fround($1858 + $1859);
   $1863 = Math_fround($1860 + $1861);
   $1864 = Math_fround($1863 + $1862);
   $1865 = (Math_fround(Math_sqrt((Math_fround($1864)))));
   $1866 = Math_fround(Math_fround(1.0) / $1865);
   $1867 = Math_fround($1866 * $1855);
   $1868 = Math_fround($1866 * $1856);
   $1869 = Math_fround($1866 * $1857);
   $1870 = Math_fround($1866 * $1852);
   HEAPF32[$q>>2] = $1867;
   HEAPF32[$1574>>2] = $1868;
   HEAPF32[$1575>>2] = $1869;
   HEAPF32[$1576>>2] = $1870;
   __ZN7mecanim5human17ReachGoalRotationEPKNS0_5HumanERKN4math7_float4EiPNS_8skeleton12SkeletonPoseESA_SA_($apHuman,$q,$goalIter$1129,$apSkeletonPose,$apSkeletonPoseWorkspaceA,$apSkeletonPoseWorkspaceB);
  }
  $1871 = (($goalIter$1129) + 1)|0;
  $exitcond = ($1871|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $goalIter$1129 = $1871;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim5human10TwistSolveEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_($apHuman,$apSkeletonPose,$skeletonPoseWorkspace) {
 $apHuman = $apHuman|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $skeletonPoseWorkspace = $skeletonPoseWorkspace|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $armTwist = 0, $foreArmTwist = 0, $legTwist = 0, $upperLegTwist = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $foreArmTwist = sp + 12|0;
 $armTwist = sp;
 $legTwist = sp + 4|0;
 $upperLegTwist = sp + 8|0;
 $0 = (($apHuman) + 400|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 HEAPF32[$foreArmTwist>>2] = $1;
 $2 = (($apHuman) + 396|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 HEAPF32[$armTwist>>2] = $3;
 $4 = (($apHuman) + 408|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$legTwist>>2] = $5;
 $6 = (($apHuman) + 404|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 HEAPF32[$upperLegTwist>>2] = $7;
 __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$skeletonPoseWorkspace,15,17,$foreArmTwist);
 __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$skeletonPoseWorkspace,13,15,$armTwist);
 __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$skeletonPoseWorkspace,16,18,$foreArmTwist);
 __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$skeletonPoseWorkspace,14,16,$armTwist);
 __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$skeletonPoseWorkspace,3,5,$legTwist);
 __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$skeletonPoseWorkspace,1,3,$upperLegTwist);
 __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$skeletonPoseWorkspace,4,6,$legTwist);
 __ZN7mecanim5human13HumanFixTwistEPKNS0_5HumanEPNS_8skeleton12SkeletonPoseES6_iiRKf($apHuman,$apSkeletonPose,$skeletonPoseWorkspace,2,4,$upperLegTwist);
 STACKTOP = sp;return;
}
function __ZN4mathL7halfTanERKNS_7_float4E19358($agg$result,$a) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0);
 var $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = (Math_fround(Math_abs((Math_fround($0)))));
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (Math_fround(Math_abs((Math_fround($3)))));
 $5 = (($a) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (Math_fround(Math_abs((Math_fround($6)))));
 $8 = (($a) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (Math_fround(Math_abs((Math_fround($9)))));
 $11 = Math_fround($1 * Math_fround(0.5));
 $12 = Math_fround($4 * Math_fround(0.5));
 $13 = Math_fround($7 * Math_fround(0.5));
 $14 = Math_fround($10 * Math_fround(0.5));
 $15 = Math_fround($11 + Math_fround(1.57079637050628662109));
 $16 = Math_fround($12 + Math_fround(1.57079637050628662109));
 $17 = Math_fround($13 + Math_fround(1.57079637050628662109));
 $18 = Math_fround($14 + Math_fround(1.57079637050628662109));
 $19 = Math_fround($15 + Math_fround(-1.57079637050628662109));
 $20 = Math_fround($16 + Math_fround(-1.57079637050628662109));
 $21 = Math_fround($17 + Math_fround(-1.57079637050628662109));
 $22 = Math_fround($18 + Math_fround(-1.57079637050628662109));
 $23 = (Math_fround(+(_copysignf((+$19),(+$0)))));
 $24 = (Math_fround(+(_copysignf((+$20),(+$3)))));
 $25 = (Math_fround(+(_copysignf((+$21),(+$6)))));
 $26 = (Math_fround(+(_copysignf((+$22),(+$9)))));
 $27 = (Math_fround(+(_fmaxf((+$23),-1.57079541683197021484))));
 $28 = (Math_fround(+(_fminf((+$27),1.57079732418060302734))));
 $29 = (Math_fround(+(_fmaxf((+$24),-1.57079541683197021484))));
 $30 = (Math_fround(+(_fminf((+$29),1.57079732418060302734))));
 $31 = (Math_fround(+(_fmaxf((+$25),-1.57079541683197021484))));
 $32 = (Math_fround(+(_fminf((+$31),1.57079732418060302734))));
 $33 = (Math_fround(+(_fmaxf((+$26),-1.57079541683197021484))));
 $34 = (Math_fround(+(_fminf((+$33),1.57079732418060302734))));
 $35 = Math_fround($28 * Math_fround(0.159154936671257019043));
 $36 = Math_fround($30 * Math_fround(0.159154936671257019043));
 $37 = Math_fround($32 * Math_fround(0.159154936671257019043));
 $38 = Math_fround($34 * Math_fround(0.159154936671257019043));
 $39 = (Math_fround(+(_roundf((+$35)))));
 $40 = (Math_fround(+(_roundf((+$36)))));
 $41 = (Math_fround(+(_roundf((+$37)))));
 $42 = (Math_fround(+(_roundf((+$38)))));
 $43 = Math_fround($35 - $39);
 $44 = Math_fround($36 - $40);
 $45 = Math_fround($37 - $41);
 $46 = Math_fround($38 - $42);
 $47 = (Math_fround(Math_abs((Math_fround($43)))));
 $48 = (Math_fround(Math_abs((Math_fround($44)))));
 $49 = (Math_fround(Math_abs((Math_fround($45)))));
 $50 = (Math_fround(Math_abs((Math_fround($46)))));
 $51 = Math_fround(Math_fround(0.25) - $47);
 $52 = Math_fround(Math_fround(0.25) - $48);
 $53 = Math_fround(Math_fround(0.25) - $49);
 $54 = Math_fround(Math_fround(0.25) - $50);
 $55 = Math_fround($51 * $51);
 $56 = Math_fround($52 * $52);
 $57 = Math_fround($53 * $53);
 $58 = Math_fround($54 * $54);
 $59 = Math_fround($55 * $55);
 $60 = Math_fround($56 * $56);
 $61 = Math_fround($57 * $57);
 $62 = Math_fround($58 * $58);
 $63 = Math_fround($55 * Math_fround(-41.283184051513671875));
 $64 = Math_fround($56 * Math_fround(-41.283184051513671875));
 $65 = Math_fround($57 * Math_fround(-41.283184051513671875));
 $66 = Math_fround($58 * Math_fround(-41.283184051513671875));
 $67 = Math_fround($63 + Math_fround(6.28318548202514648438));
 $68 = Math_fround($64 + Math_fround(6.28318548202514648438));
 $69 = Math_fround($65 + Math_fround(6.28318548202514648438));
 $70 = Math_fround($66 + Math_fround(6.28318548202514648438));
 $71 = Math_fround($59 * Math_fround(76.03546142578125));
 $72 = Math_fround($60 * Math_fround(76.03546142578125));
 $73 = Math_fround($61 * Math_fround(76.03546142578125));
 $74 = Math_fround($62 * Math_fround(76.03546142578125));
 $75 = Math_fround($67 + $71);
 $76 = Math_fround($68 + $72);
 $77 = Math_fround($69 + $73);
 $78 = Math_fround($70 + $74);
 $79 = Math_fround($51 * $75);
 $80 = Math_fround($52 * $76);
 $81 = Math_fround($53 * $77);
 $82 = Math_fround($54 * $78);
 $83 = Math_fround($35 + Math_fround(-0.25));
 $84 = Math_fround($36 + Math_fround(-0.25));
 $85 = Math_fround($37 + Math_fround(-0.25));
 $86 = Math_fround($38 + Math_fround(-0.25));
 $87 = (Math_fround(+(_roundf((+$83)))));
 $88 = (Math_fround(+(_roundf((+$84)))));
 $89 = (Math_fround(+(_roundf((+$85)))));
 $90 = (Math_fround(+(_roundf((+$86)))));
 $91 = Math_fround($83 - $87);
 $92 = Math_fround($84 - $88);
 $93 = Math_fround($85 - $89);
 $94 = Math_fround($86 - $90);
 $95 = (Math_fround(Math_abs((Math_fround($91)))));
 $96 = (Math_fround(Math_abs((Math_fround($92)))));
 $97 = (Math_fround(Math_abs((Math_fround($93)))));
 $98 = (Math_fround(Math_abs((Math_fround($94)))));
 $99 = Math_fround(Math_fround(0.25) - $95);
 $100 = Math_fround(Math_fround(0.25) - $96);
 $101 = Math_fround(Math_fround(0.25) - $97);
 $102 = Math_fround(Math_fround(0.25) - $98);
 $103 = Math_fround($99 * $99);
 $104 = Math_fround($100 * $100);
 $105 = Math_fround($101 * $101);
 $106 = Math_fround($102 * $102);
 $107 = Math_fround($103 * $103);
 $108 = Math_fround($104 * $104);
 $109 = Math_fround($105 * $105);
 $110 = Math_fround($106 * $106);
 $111 = Math_fround($103 * Math_fround(-41.283184051513671875));
 $112 = Math_fround($104 * Math_fround(-41.283184051513671875));
 $113 = Math_fround($105 * Math_fround(-41.283184051513671875));
 $114 = Math_fround($106 * Math_fround(-41.283184051513671875));
 $115 = Math_fround($111 + Math_fround(6.28318548202514648438));
 $116 = Math_fround($112 + Math_fround(6.28318548202514648438));
 $117 = Math_fround($113 + Math_fround(6.28318548202514648438));
 $118 = Math_fround($114 + Math_fround(6.28318548202514648438));
 $119 = Math_fround($107 * Math_fround(76.03546142578125));
 $120 = Math_fround($108 * Math_fround(76.03546142578125));
 $121 = Math_fround($109 * Math_fround(76.03546142578125));
 $122 = Math_fround($110 * Math_fround(76.03546142578125));
 $123 = Math_fround($115 + $119);
 $124 = Math_fround($116 + $120);
 $125 = Math_fround($117 + $121);
 $126 = Math_fround($118 + $122);
 $127 = Math_fround($99 * $123);
 $128 = Math_fround($100 * $124);
 $129 = Math_fround($101 * $125);
 $130 = Math_fround($102 * $126);
 $131 = Math_fround($127 / $79);
 $132 = Math_fround($128 / $80);
 $133 = Math_fround($129 / $81);
 $134 = Math_fround($130 / $82);
 HEAPF32[$agg$result>>2] = $131;
 $135 = (($agg$result) + 4|0);
 HEAPF32[$135>>2] = $132;
 $136 = (($agg$result) + 8|0);
 HEAPF32[$136>>2] = $133;
 $137 = (($agg$result) + 12|0);
 HEAPF32[$137>>2] = $134;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton18CreateSkeletonPoseEPKNS0_8SkeletonERNS_6memory9AllocatorE($apSkeleton,$arAlloc) {
 $apSkeleton = $apSkeleton|0;
 $arAlloc = $arAlloc|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$arAlloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($arAlloc,12,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $7 = 0;
 } else {
  HEAP32[$2>>2] = 0;
  $4 = (($2) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($2) + 8|0);
  HEAP32[$5>>2] = 0;
  $7 = $2;
 }
 $6 = HEAP32[$apSkeleton>>2]|0;
 HEAP32[$7>>2] = $6;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$apSkeleton>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0$i1 = 0;$28 = 0;
  HEAP32[$8>>2] = $28;
  $29 = (($7) + 8|0);
  HEAP32[$29>>2] = $$0$i1;
  STACKTOP = sp;return ($7|0);
 }
 $11 = HEAP32[$arAlloc>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = ($9*48)|0;
 $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($arAlloc,$13,4)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  $$0$i1 = 0;$28 = 0;
  HEAP32[$8>>2] = $28;
  $29 = (($7) + 8|0);
  HEAP32[$29>>2] = $$0$i1;
  STACKTOP = sp;return ($7|0);
 }
 $16 = (($14) + (($9*48)|0)|0);
 $18 = $14;
 while(1) {
  $17 = (($18) + 28|0);
  ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;HEAP32[$18+24>>2]=0|0;
  HEAPF32[$17>>2] = Math_fround(1.0);
  $19 = (($18) + 44|0);
  HEAPF32[$19>>2] = Math_fround(1.0);
  $20 = (($18) + 40|0);
  HEAPF32[$20>>2] = Math_fround(1.0);
  $21 = (($18) + 36|0);
  HEAPF32[$21>>2] = Math_fround(1.0);
  $22 = (($18) + 32|0);
  HEAPF32[$22>>2] = Math_fround(1.0);
  $23 = (($18) + 48|0);
  $24 = ($23|0)==($16|0);
  if ($24) {
   break;
  } else {
   $18 = $23;
  }
 }
 $25 = $14;
 $26 = $8;
 $27 = (($25) - ($26))|0;
 $$0$i1 = $14;$28 = $27;
 HEAP32[$8>>2] = $28;
 $29 = (($7) + 8|0);
 HEAP32[$29>>2] = $$0$i1;
 STACKTOP = sp;return ($7|0);
}
function __ZN7mecanim8skeleton19DestroySkeletonPoseEPNS0_12SkeletonPoseERNS_6memory9AllocatorE($apSkeletonPose,$arAlloc) {
 $apSkeletonPose = $apSkeletonPose|0;
 $arAlloc = $arAlloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($apSkeletonPose|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($apSkeletonPose) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = HEAP32[$arAlloc>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $1;
  $8 = (($2) + ($7))|0;
  $9 = $8;
  $10 = (($apSkeletonPose) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8;
  FUNCTION_TABLE_vii[$6 & 4095]($arAlloc,$11);
 }
 $12 = HEAP32[$arAlloc>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($arAlloc,$apSkeletonPose);
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton16SkeletonPoseCopyEPKNS0_12SkeletonPoseEPS1_($apSrcPose,$apDstPose) {
 $apSrcPose = $apSrcPose|0;
 $apDstPose = $apDstPose|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$apDstPose>>2]|0;
 $1 = HEAP32[$apSrcPose>>2]|0;
 $2 = ($0>>>0)<($1>>>0);
 $3 = $2 ? $0 : $1;
 $4 = (($apDstPose) + 4|0);
 $5 = $4;
 $6 = HEAP32[$4>>2]|0;
 $7 = (($6) + ($5))|0;
 $8 = $7;
 $9 = (($apDstPose) + 8|0);
 HEAP32[$9>>2] = $8;
 $10 = $7;
 $11 = (($apSrcPose) + 4|0);
 $12 = $11;
 $13 = HEAP32[$11>>2]|0;
 $14 = (($13) + ($12))|0;
 $15 = $14;
 $16 = ($3*48)|0;
 _memcpy(($10|0),($15|0),($16|0))|0;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton16SkeletonPoseCopyEPKNS0_12SkeletonPoseEPS1_jPKi($apSrcPose,$apDstPose,$aIndexCount,$apIndexArray) {
 $apSrcPose = $apSrcPose|0;
 $apDstPose = $apDstPose|0;
 $aIndexCount = $aIndexCount|0;
 $apIndexArray = $apIndexArray|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($aIndexCount|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($apDstPose) + 4|0);
 $2 = $1;
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + ($2))|0;
 $5 = $4;
 $6 = (($apSrcPose) + 4|0);
 $7 = $6;
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + ($7))|0;
 $10 = $9;
 $i$01 = 0;
 while(1) {
  $11 = (($apIndexArray) + ($i$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + (($i$01*48)|0)|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  $15 = ((($10) + (($i$01*48)|0)|0) + 4|0);
  $16 = Math_fround(HEAPF32[$15>>2]);
  $17 = ((($10) + (($i$01*48)|0)|0) + 8|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = ((($10) + (($i$01*48)|0)|0) + 12|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($5) + (($12*48)|0)|0);
  HEAPF32[$21>>2] = $14;
  $22 = ((($5) + (($12*48)|0)|0) + 4|0);
  HEAPF32[$22>>2] = $16;
  $23 = ((($5) + (($12*48)|0)|0) + 8|0);
  HEAPF32[$23>>2] = $18;
  $24 = ((($5) + (($12*48)|0)|0) + 12|0);
  HEAPF32[$24>>2] = $20;
  $25 = ((($10) + (($i$01*48)|0)|0) + 16|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = ((($10) + (($i$01*48)|0)|0) + 20|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = ((($10) + (($i$01*48)|0)|0) + 24|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = ((($10) + (($i$01*48)|0)|0) + 28|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = ((($5) + (($12*48)|0)|0) + 16|0);
  HEAPF32[$33>>2] = $26;
  $34 = ((($5) + (($12*48)|0)|0) + 20|0);
  HEAPF32[$34>>2] = $28;
  $35 = ((($5) + (($12*48)|0)|0) + 24|0);
  HEAPF32[$35>>2] = $30;
  $36 = ((($5) + (($12*48)|0)|0) + 28|0);
  HEAPF32[$36>>2] = $32;
  $37 = ((($10) + (($i$01*48)|0)|0) + 32|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = ((($10) + (($i$01*48)|0)|0) + 36|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = ((($10) + (($i$01*48)|0)|0) + 40|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = ((($10) + (($i$01*48)|0)|0) + 44|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = ((($5) + (($12*48)|0)|0) + 32|0);
  HEAPF32[$45>>2] = $38;
  $46 = ((($5) + (($12*48)|0)|0) + 36|0);
  HEAPF32[$46>>2] = $40;
  $47 = ((($5) + (($12*48)|0)|0) + 40|0);
  HEAPF32[$47>>2] = $42;
  $48 = ((($5) + (($12*48)|0)|0) + 44|0);
  HEAPF32[$48>>2] = $44;
  $49 = (($i$01) + 1)|0;
  $exitcond = ($49|0)==($aIndexCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $49;
  }
 }
 $50 = (($apDstPose) + 8|0);
 HEAP32[$50>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton16SkeletonFindNodeEPKNS0_8SkeletonEj($apSkeleton,$aID) {
 $apSkeleton = $apSkeleton|0;
 $aID = $aID|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $not$ = 0, $ret$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$apSkeleton>>2]|0;
 $1 = (($apSkeleton) + 12|0);
 $2 = $1;
 $i$02 = 0;
 while(1) {
  $3 = ($i$02|0)<($0|0);
  if (!($3)) {
   $ret$0$lcssa = -1;
   label = 4;
   break;
  }
  $4 = HEAP32[$1>>2]|0;
  $5 = (($4) + ($2))|0;
  $6 = $5;
  $7 = (($6) + ($i$02<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($i$02) + 1)|0;
  $10 = ($i$02|0)==(-1);
  $not$ = ($8|0)!=($aID|0);
  $11 = $10 | $not$;
  if ($11) {
   $i$02 = $9;
  } else {
   $ret$0$lcssa = $i$02;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($ret$0$lcssa|0);
 }
 return 0|0;
}
function __ZN7mecanim8skeleton23SkeletonBuildIndexArrayEPiPKNS0_8SkeletonES4_($indexArray,$apSrcSkeleton,$apDstSkeleton) {
 $indexArray = $indexArray|0;
 $apSrcSkeleton = $apSrcSkeleton|0;
 $apDstSkeleton = $apDstSkeleton|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $i$02$i = 0, $not$$i = 0, $ret$0$lcssa$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$apSrcSkeleton>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($apSrcSkeleton) + 12|0);
 $3 = $2;
 $4 = (($apDstSkeleton) + 12|0);
 $5 = $4;
 $i$01 = 0;
 while(1) {
  $6 = HEAP32[$2>>2]|0;
  $7 = (($6) + ($3))|0;
  $8 = $7;
  $9 = (($8) + ($i$01<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$apDstSkeleton>>2]|0;
  $i$02$i = 0;
  while(1) {
   $12 = ($i$02$i|0)<($11|0);
   if (!($12)) {
    $ret$0$lcssa$i = -1;
    break;
   }
   $13 = HEAP32[$4>>2]|0;
   $14 = (($13) + ($5))|0;
   $15 = $14;
   $16 = (($15) + ($i$02$i<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($i$02$i) + 1)|0;
   $not$$i = ($17|0)==($10|0);
   if ($not$$i) {
    $ret$0$lcssa$i = $i$02$i;
    break;
   } else {
    $i$02$i = $18;
   }
  }
  $19 = (($indexArray) + ($i$01<<2)|0);
  HEAP32[$19>>2] = $ret$0$lcssa$i;
  $20 = (($i$01) + 1)|0;
  $21 = HEAP32[$apSrcSkeleton>>2]|0;
  $22 = ($20>>>0)<($21>>>0);
  if ($22) {
   $i$01 = $20;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton30SkeletonBuildReverseIndexArrayEPiPKiPKNS0_8SkeletonES6_($reverseIndexArray,$indexArray,$apSrcSkeleton,$apDstSkeleton) {
 $reverseIndexArray = $reverseIndexArray|0;
 $indexArray = $indexArray|0;
 $apSrcSkeleton = $apSrcSkeleton|0;
 $apDstSkeleton = $apDstSkeleton|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dstIter$02 = 0, $srcIter$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$apDstSkeleton>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $dstIter$02 = 0;
  while(1) {
   $4 = (($reverseIndexArray) + ($dstIter$02<<2)|0);
   HEAP32[$4>>2] = -1;
   $5 = (($dstIter$02) + 1)|0;
   $6 = HEAP32[$apDstSkeleton>>2]|0;
   $7 = ($5>>>0)<($6>>>0);
   if ($7) {
    $dstIter$02 = $5;
   } else {
    break;
   }
  }
 }
 $2 = HEAP32[$apSrcSkeleton>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $15 = $2;$srcIter$01 = 0;
 }
 while(1) {
  $8 = (($indexArray) + ($srcIter$01<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(-1);
  if ($10) {
   $14 = $15;
  } else {
   $11 = (($reverseIndexArray) + ($9<<2)|0);
   HEAP32[$11>>2] = $srcIter$01;
   $$pre = HEAP32[$apSrcSkeleton>>2]|0;
   $14 = $$pre;
  }
  $12 = (($srcIter$01) + 1)|0;
  $13 = ($12>>>0)<($14>>>0);
  if ($13) {
   $15 = $14;$srcIter$01 = $12;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_($apSkeleton,$apSkeletonPoseLocal,$apSkeletonPoseGlobal) {
 $apSkeleton = $apSkeleton|0;
 $apSkeletonPoseLocal = $apSkeletonPoseLocal|0;
 $apSkeletonPoseGlobal = $apSkeletonPoseGlobal|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp;
 $1 = (($apSkeletonPoseGlobal) + 4|0);
 $2 = $1;
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + ($2))|0;
 $5 = $4;
 $6 = (($apSkeletonPoseGlobal) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = (($apSkeletonPoseLocal) + 4|0);
 $8 = $7;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($11) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($11) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($11) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$5>>2] = $12;
 $19 = (($5) + 4|0);
 HEAPF32[$19>>2] = $14;
 $20 = (($5) + 8|0);
 HEAPF32[$20>>2] = $16;
 $21 = (($5) + 12|0);
 HEAPF32[$21>>2] = $18;
 $22 = (($11) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($11) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($11) + 24|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($11) + 28|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($5) + 16|0);
 HEAPF32[$30>>2] = $23;
 $31 = (($5) + 20|0);
 HEAPF32[$31>>2] = $25;
 $32 = (($5) + 24|0);
 HEAPF32[$32>>2] = $27;
 $33 = (($5) + 28|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($11) + 32|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($11) + 36|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($11) + 40|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($11) + 44|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = (($5) + 32|0);
 HEAPF32[$42>>2] = $35;
 $43 = (($5) + 36|0);
 HEAPF32[$43>>2] = $37;
 $44 = (($5) + 40|0);
 HEAPF32[$44>>2] = $39;
 $45 = (($5) + 44|0);
 HEAPF32[$45>>2] = $41;
 $46 = HEAP32[$apSkeleton>>2]|0;
 $47 = ($46>>>0)>(1);
 if (!($47)) {
  STACKTOP = sp;return;
 }
 $48 = (($apSkeleton) + 4|0);
 $49 = $48;
 $50 = (($0) + 4|0);
 $51 = (($0) + 8|0);
 $52 = (($0) + 12|0);
 $53 = (($0) + 16|0);
 $54 = (($0) + 20|0);
 $55 = (($0) + 24|0);
 $56 = (($0) + 28|0);
 $57 = (($0) + 32|0);
 $58 = (($0) + 36|0);
 $59 = (($0) + 40|0);
 $60 = (($0) + 44|0);
 $62 = $3;$71 = $9;$i$01 = 1;
 while(1) {
  $61 = (($62) + ($2))|0;
  $63 = $61;
  $64 = HEAP32[$48>>2]|0;
  $65 = (($64) + ($49))|0;
  $66 = $65;
  $67 = (($66) + ($i$01<<3)|0);
  $68 = HEAP32[$67>>2]|0;
  HEAP32[$6>>2] = $63;
  $69 = (($63) + (($68*48)|0)|0);
  $70 = (($71) + ($8))|0;
  $72 = $70;
  $73 = (($72) + (($i$01*48)|0)|0);
  __ZN4mathL8xformMulERKNS_5xformES2_19385($0,$69,$73);
  $74 = Math_fround(HEAPF32[$0>>2]);
  $75 = Math_fround(HEAPF32[$50>>2]);
  $76 = Math_fround(HEAPF32[$51>>2]);
  $77 = Math_fround(HEAPF32[$52>>2]);
  $78 = (($63) + (($i$01*48)|0)|0);
  HEAPF32[$78>>2] = $74;
  $79 = ((($63) + (($i$01*48)|0)|0) + 4|0);
  HEAPF32[$79>>2] = $75;
  $80 = ((($63) + (($i$01*48)|0)|0) + 8|0);
  HEAPF32[$80>>2] = $76;
  $81 = ((($63) + (($i$01*48)|0)|0) + 12|0);
  HEAPF32[$81>>2] = $77;
  $82 = Math_fround(HEAPF32[$53>>2]);
  $83 = Math_fround(HEAPF32[$54>>2]);
  $84 = Math_fround(HEAPF32[$55>>2]);
  $85 = Math_fround(HEAPF32[$56>>2]);
  $86 = ((($63) + (($i$01*48)|0)|0) + 16|0);
  HEAPF32[$86>>2] = $82;
  $87 = ((($63) + (($i$01*48)|0)|0) + 20|0);
  HEAPF32[$87>>2] = $83;
  $88 = ((($63) + (($i$01*48)|0)|0) + 24|0);
  HEAPF32[$88>>2] = $84;
  $89 = ((($63) + (($i$01*48)|0)|0) + 28|0);
  HEAPF32[$89>>2] = $85;
  $90 = Math_fround(HEAPF32[$57>>2]);
  $91 = Math_fround(HEAPF32[$58>>2]);
  $92 = Math_fround(HEAPF32[$59>>2]);
  $93 = Math_fround(HEAPF32[$60>>2]);
  $94 = ((($63) + (($i$01*48)|0)|0) + 32|0);
  HEAPF32[$94>>2] = $90;
  $95 = ((($63) + (($i$01*48)|0)|0) + 36|0);
  HEAPF32[$95>>2] = $91;
  $96 = ((($63) + (($i$01*48)|0)|0) + 40|0);
  HEAPF32[$96>>2] = $92;
  $97 = ((($63) + (($i$01*48)|0)|0) + 44|0);
  HEAPF32[$97>>2] = $93;
  $98 = (($i$01) + 1)|0;
  $99 = HEAP32[$apSkeleton>>2]|0;
  $100 = ($98>>>0)<($99>>>0);
  if (!($100)) {
   break;
  }
  $$pre = HEAP32[$1>>2]|0;
  $$pre3 = HEAP32[$7>>2]|0;
  $62 = $$pre;$71 = $$pre3;$i$01 = $98;
 }
 STACKTOP = sp;return;
}
function __ZN4mathL8xformMulERKNS_5xformES2_19385($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $152 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0);
 var $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0);
 var $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0);
 var $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$b>>2]);
 $1 = (($a) + 32|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (($b) + 4|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($a) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 * $7);
 $9 = (($b) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($a) + 40|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = (($b) + 12|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 44|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $17);
 $19 = Math_fround($3 + $3);
 $20 = Math_fround($8 + $8);
 $21 = Math_fround($13 + $13);
 $22 = (($a) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($20 * $23);
 $25 = (($a) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($21 * $26);
 $28 = (($a) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($19 * $29);
 $31 = (($a) + 28|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * Math_fround(0.0));
 $34 = Math_fround($19 * $26);
 $35 = Math_fround($20 * $29);
 $36 = Math_fround($21 * $23);
 $37 = Math_fround($24 - $34);
 $38 = Math_fround($27 - $35);
 $39 = Math_fround($30 - $36);
 $40 = Math_fround($33 - $33);
 $41 = Math_fround($32 * $38);
 $42 = Math_fround($32 * $39);
 $43 = Math_fround($37 * $32);
 $44 = Math_fround($32 * $40);
 $45 = Math_fround($3 + $41);
 $46 = Math_fround($8 + $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 * $39);
 $50 = Math_fround($26 * $37);
 $51 = Math_fround($29 * $38);
 $52 = Math_fround($26 * $38);
 $53 = Math_fround($29 * $39);
 $54 = Math_fround($23 * $37);
 $55 = Math_fround($49 - $52);
 $56 = Math_fround($50 - $53);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($44 - $44);
 $59 = Math_fround($45 + $56);
 $60 = Math_fround($46 + $57);
 $61 = Math_fround($47 + $55);
 $62 = Math_fround($48 + $58);
 $63 = Math_fround(HEAPF32[$a>>2]);
 $64 = Math_fround($63 + $59);
 $65 = (($a) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 + $60);
 $68 = (($a) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 + $61);
 $71 = (($a) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 + $62);
 $74 = (($b) + 16|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($26 * $75);
 $77 = (($b) + 28|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($32 * $78);
 $80 = (($b) + 20|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($29 * $81);
 $83 = (($b) + 24|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($23 * $84);
 $86 = Math_fround($32 * $84);
 $87 = Math_fround($75 * $23);
 $88 = Math_fround($26 * $84);
 $89 = Math_fround($75 * $29);
 $90 = Math_fround($76 - $86);
 $91 = Math_fround($79 - $87);
 $92 = Math_fround($82 - $88);
 $93 = Math_fround($85 - $89);
 $94 = Math_fround($78 * $29);
 $95 = Math_fround($29 * $84);
 $96 = Math_fround($75 * $32);
 $97 = Math_fround($32 * $81);
 $98 = Math_fround($90 - $94);
 $99 = Math_fround($91 - $95);
 $100 = Math_fround($92 - $96);
 $101 = Math_fround($93 - $97);
 $102 = Math_fround($81 * $23);
 $103 = Math_fround($26 * $81);
 $104 = Math_fround($78 * $23);
 $105 = Math_fround($26 * $78);
 $106 = Math_fround($98 - $102);
 $107 = Math_fround($99 - $103);
 $108 = Math_fround($100 - $104);
 $109 = Math_fround($101 - $105);
 $110 = Math_fround($108 * Math_fround(-1.0));
 $111 = Math_fround($109 * Math_fround(-1.0));
 $112 = Math_fround($106 * Math_fround(-1.0));
 $113 = Math_fround($110 * $110);
 $114 = Math_fround($111 * $111);
 $115 = Math_fround($112 * $112);
 $116 = Math_fround($107 * $107);
 $117 = Math_fround($113 + $114);
 $118 = Math_fround($116 + $115);
 $119 = Math_fround($117 + $118);
 $120 = (Math_fround(Math_sqrt((Math_fround($119)))));
 $121 = Math_fround(Math_fround(1.0) / $120);
 $122 = Math_fround($121 * $110);
 $123 = Math_fround($121 * $111);
 $124 = Math_fround($121 * $112);
 $125 = Math_fround($121 * $107);
 $126 = Math_fround(HEAPF32[$1>>2]);
 $127 = (($b) + 32|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($126 * $128);
 $130 = Math_fround(HEAPF32[$6>>2]);
 $131 = (($b) + 36|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($130 * $132);
 $134 = Math_fround(HEAPF32[$11>>2]);
 $135 = (($b) + 40|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($134 * $136);
 $138 = Math_fround(HEAPF32[$16>>2]);
 $139 = (($b) + 44|0);
 $140 = Math_fround(HEAPF32[$139>>2]);
 $141 = Math_fround($138 * $140);
 HEAPF32[$agg$result>>2] = $64;
 $142 = (($agg$result) + 4|0);
 HEAPF32[$142>>2] = $67;
 $143 = (($agg$result) + 8|0);
 HEAPF32[$143>>2] = $70;
 $144 = (($agg$result) + 12|0);
 HEAPF32[$144>>2] = $73;
 $145 = (($agg$result) + 16|0);
 HEAPF32[$145>>2] = $122;
 $146 = (($agg$result) + 20|0);
 HEAPF32[$146>>2] = $123;
 $147 = (($agg$result) + 24|0);
 HEAPF32[$147>>2] = $124;
 $148 = (($agg$result) + 28|0);
 HEAPF32[$148>>2] = $125;
 $149 = (($agg$result) + 32|0);
 HEAPF32[$149>>2] = $129;
 $150 = (($agg$result) + 36|0);
 HEAPF32[$150>>2] = $133;
 $151 = (($agg$result) + 40|0);
 HEAPF32[$151>>2] = $137;
 $152 = (($agg$result) + 44|0);
 HEAPF32[$152>>2] = $141;
 STACKTOP = sp;return;
}
function __ZN4mathL11xformInvMulERKNS_5xformES2_19388($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0, $151 = 0;
 var $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0);
 var $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0);
 var $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0);
 var $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(-1.0));
 $3 = (($a) + 20|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = Math_fround($4 * Math_fround(-1.0));
 $6 = (($a) + 24|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(-1.0));
 $9 = (($a) + 28|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround(HEAPF32[$b>>2]);
 $12 = Math_fround(HEAPF32[$a>>2]);
 $13 = Math_fround($11 - $12);
 $14 = (($b) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($a) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 - $17);
 $19 = (($b) + 8|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($a) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 - $22);
 $24 = (($b) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($a) + 12|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($25 - $27);
 $29 = Math_fround($13 + $13);
 $30 = Math_fround($18 + $18);
 $31 = Math_fround($23 + $23);
 $32 = Math_fround($2 * $30);
 $33 = Math_fround($5 * $31);
 $34 = Math_fround($8 * $29);
 $35 = Math_fround($10 * Math_fround(0.0));
 $36 = Math_fround($5 * $29);
 $37 = Math_fround($8 * $30);
 $38 = Math_fround($2 * $31);
 $39 = Math_fround($32 - $36);
 $40 = Math_fround($33 - $37);
 $41 = Math_fround($34 - $38);
 $42 = Math_fround($35 - $35);
 $43 = Math_fround($10 * $40);
 $44 = Math_fround($10 * $41);
 $45 = Math_fround($10 * $39);
 $46 = Math_fround($10 * $42);
 $47 = Math_fround($13 + $43);
 $48 = Math_fround($18 + $44);
 $49 = Math_fround($23 + $45);
 $50 = Math_fround($46 + $28);
 $51 = Math_fround($2 * $41);
 $52 = Math_fround($5 * $39);
 $53 = Math_fround($8 * $40);
 $54 = Math_fround($5 * $40);
 $55 = Math_fround($8 * $41);
 $56 = Math_fround($2 * $39);
 $57 = Math_fround($51 - $54);
 $58 = Math_fround($52 - $55);
 $59 = Math_fround($53 - $56);
 $60 = Math_fround($46 - $46);
 $61 = Math_fround($47 + $58);
 $62 = Math_fround($48 + $59);
 $63 = Math_fround($49 + $57);
 $64 = Math_fround($60 + $50);
 $65 = (($a) + 32|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($61 / $66);
 $68 = (($a) + 36|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($62 / $69);
 $71 = (($a) + 40|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($63 / $72);
 $74 = (($a) + 44|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($64 / $75);
 $77 = (($b) + 16|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($5 * $78);
 $80 = (($b) + 28|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($10 * $81);
 $83 = (($b) + 20|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($8 * $84);
 $86 = (($b) + 24|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($2 * $87);
 $89 = Math_fround($10 * $87);
 $90 = Math_fround($2 * $78);
 $91 = Math_fround($5 * $87);
 $92 = Math_fround($8 * $78);
 $93 = Math_fround($79 - $89);
 $94 = Math_fround($82 - $90);
 $95 = Math_fround($85 - $91);
 $96 = Math_fround($88 - $92);
 $97 = Math_fround($8 * $81);
 $98 = Math_fround($8 * $87);
 $99 = Math_fround($10 * $78);
 $100 = Math_fround($10 * $84);
 $101 = Math_fround($93 - $97);
 $102 = Math_fround($94 - $98);
 $103 = Math_fround($95 - $99);
 $104 = Math_fround($96 - $100);
 $105 = Math_fround($2 * $84);
 $106 = Math_fround($5 * $84);
 $107 = Math_fround($2 * $81);
 $108 = Math_fround($5 * $81);
 $109 = Math_fround($101 - $105);
 $110 = Math_fround($102 - $106);
 $111 = Math_fround($103 - $107);
 $112 = Math_fround($104 - $108);
 $113 = Math_fround($111 * Math_fround(-1.0));
 $114 = Math_fround($112 * Math_fround(-1.0));
 $115 = Math_fround($109 * Math_fround(-1.0));
 $116 = Math_fround($113 * $113);
 $117 = Math_fround($114 * $114);
 $118 = Math_fround($115 * $115);
 $119 = Math_fround($110 * $110);
 $120 = Math_fround($116 + $117);
 $121 = Math_fround($119 + $118);
 $122 = Math_fround($120 + $121);
 $123 = (Math_fround(Math_sqrt((Math_fround($122)))));
 $124 = Math_fround(Math_fround(1.0) / $123);
 $125 = Math_fround($124 * $113);
 $126 = Math_fround($124 * $114);
 $127 = Math_fround($124 * $115);
 $128 = Math_fround($124 * $110);
 $129 = (($b) + 32|0);
 $130 = Math_fround(HEAPF32[$129>>2]);
 $131 = Math_fround($130 / $66);
 $132 = (($b) + 36|0);
 $133 = Math_fround(HEAPF32[$132>>2]);
 $134 = Math_fround($133 / $69);
 $135 = (($b) + 40|0);
 $136 = Math_fround(HEAPF32[$135>>2]);
 $137 = Math_fround($136 / $72);
 $138 = (($b) + 44|0);
 $139 = Math_fround(HEAPF32[$138>>2]);
 $140 = Math_fround($139 / $75);
 HEAPF32[$agg$result>>2] = $67;
 $141 = (($agg$result) + 4|0);
 HEAPF32[$141>>2] = $70;
 $142 = (($agg$result) + 8|0);
 HEAPF32[$142>>2] = $73;
 $143 = (($agg$result) + 12|0);
 HEAPF32[$143>>2] = $76;
 $144 = (($agg$result) + 16|0);
 HEAPF32[$144>>2] = $125;
 $145 = (($agg$result) + 20|0);
 HEAPF32[$145>>2] = $126;
 $146 = (($agg$result) + 24|0);
 HEAPF32[$146>>2] = $127;
 $147 = (($agg$result) + 28|0);
 HEAPF32[$147>>2] = $128;
 $148 = (($agg$result) + 32|0);
 HEAPF32[$148>>2] = $131;
 $149 = (($agg$result) + 36|0);
 HEAPF32[$149>>2] = $134;
 $150 = (($agg$result) + 40|0);
 HEAPF32[$150>>2] = $137;
 $151 = (($agg$result) + 44|0);
 HEAPF32[$151>>2] = $140;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseLocal,$apSkeletonPoseGlobal,$aIndex,$aStopIndex) {
 $apSkeleton = $apSkeleton|0;
 $apSkeletonPoseLocal = $apSkeletonPoseLocal|0;
 $apSkeletonPoseGlobal = $apSkeletonPoseGlobal|0;
 $aIndex = $aIndex|0;
 $aStopIndex = $aStopIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0;
 var $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0);
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0);
 var $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp;
 $1 = (($apSkeleton) + 4|0);
 $2 = $1;
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + ($2))|0;
 $5 = $4;
 $6 = (($5) + ($aIndex<<3)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(-1);
 if ($8) {
  $58 = (($apSkeletonPoseGlobal) + 4|0);
  $59 = $58;
  $60 = HEAP32[$58>>2]|0;
  $61 = (($60) + ($59))|0;
  $62 = $61;
  $63 = (($apSkeletonPoseGlobal) + 8|0);
  HEAP32[$63>>2] = $62;
  $64 = (($apSkeletonPoseLocal) + 4|0);
  $65 = $64;
  $66 = HEAP32[$64>>2]|0;
  $67 = (($66) + ($65))|0;
  $68 = $67;
  $69 = (($68) + (($aIndex*48)|0)|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = ((($68) + (($aIndex*48)|0)|0) + 4|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = ((($68) + (($aIndex*48)|0)|0) + 8|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = ((($68) + (($aIndex*48)|0)|0) + 12|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = (($62) + (($aIndex*48)|0)|0);
  HEAPF32[$77>>2] = $70;
  $78 = ((($62) + (($aIndex*48)|0)|0) + 4|0);
  HEAPF32[$78>>2] = $72;
  $79 = ((($62) + (($aIndex*48)|0)|0) + 8|0);
  HEAPF32[$79>>2] = $74;
  $80 = ((($62) + (($aIndex*48)|0)|0) + 12|0);
  HEAPF32[$80>>2] = $76;
  $81 = ((($68) + (($aIndex*48)|0)|0) + 16|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = ((($68) + (($aIndex*48)|0)|0) + 20|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = ((($68) + (($aIndex*48)|0)|0) + 24|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = ((($68) + (($aIndex*48)|0)|0) + 28|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = ((($62) + (($aIndex*48)|0)|0) + 16|0);
  HEAPF32[$89>>2] = $82;
  $90 = ((($62) + (($aIndex*48)|0)|0) + 20|0);
  HEAPF32[$90>>2] = $84;
  $91 = ((($62) + (($aIndex*48)|0)|0) + 24|0);
  HEAPF32[$91>>2] = $86;
  $92 = ((($62) + (($aIndex*48)|0)|0) + 28|0);
  HEAPF32[$92>>2] = $88;
  $93 = ((($68) + (($aIndex*48)|0)|0) + 32|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = ((($68) + (($aIndex*48)|0)|0) + 36|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = ((($68) + (($aIndex*48)|0)|0) + 40|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = ((($68) + (($aIndex*48)|0)|0) + 44|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = ((($62) + (($aIndex*48)|0)|0) + 32|0);
  HEAPF32[$101>>2] = $94;
  $102 = ((($62) + (($aIndex*48)|0)|0) + 36|0);
  HEAPF32[$102>>2] = $96;
  $103 = ((($62) + (($aIndex*48)|0)|0) + 40|0);
  HEAPF32[$103>>2] = $98;
  $104 = ((($62) + (($aIndex*48)|0)|0) + 44|0);
  HEAPF32[$104>>2] = $100;
  STACKTOP = sp;return;
 }
 $9 = ($aIndex|0)==($aStopIndex|0);
 if (!($9)) {
  __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseLocal,$apSkeletonPoseGlobal,$7,$aStopIndex);
 }
 $10 = (($apSkeletonPoseGlobal) + 4|0);
 $11 = $10;
 $12 = HEAP32[$10>>2]|0;
 $13 = (($12) + ($11))|0;
 $14 = $13;
 $15 = (($apSkeletonPoseGlobal) + 8|0);
 HEAP32[$15>>2] = $14;
 $16 = (($14) + (($7*48)|0)|0);
 $17 = (($apSkeletonPoseLocal) + 4|0);
 $18 = $17;
 $19 = HEAP32[$17>>2]|0;
 $20 = (($19) + ($18))|0;
 $21 = $20;
 $22 = (($21) + (($aIndex*48)|0)|0);
 __ZN4mathL8xformMulERKNS_5xformES2_19385($0,$16,$22);
 $23 = Math_fround(HEAPF32[$0>>2]);
 $24 = (($0) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($0) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = (($14) + (($aIndex*48)|0)|0);
 HEAPF32[$30>>2] = $23;
 $31 = ((($14) + (($aIndex*48)|0)|0) + 4|0);
 HEAPF32[$31>>2] = $25;
 $32 = ((($14) + (($aIndex*48)|0)|0) + 8|0);
 HEAPF32[$32>>2] = $27;
 $33 = ((($14) + (($aIndex*48)|0)|0) + 12|0);
 HEAPF32[$33>>2] = $29;
 $34 = (($0) + 16|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = (($0) + 20|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = (($0) + 24|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($0) + 28|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = ((($14) + (($aIndex*48)|0)|0) + 16|0);
 HEAPF32[$42>>2] = $35;
 $43 = ((($14) + (($aIndex*48)|0)|0) + 20|0);
 HEAPF32[$43>>2] = $37;
 $44 = ((($14) + (($aIndex*48)|0)|0) + 24|0);
 HEAPF32[$44>>2] = $39;
 $45 = ((($14) + (($aIndex*48)|0)|0) + 28|0);
 HEAPF32[$45>>2] = $41;
 $46 = (($0) + 32|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($0) + 36|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($0) + 40|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($0) + 44|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = ((($14) + (($aIndex*48)|0)|0) + 32|0);
 HEAPF32[$54>>2] = $47;
 $55 = ((($14) + (($aIndex*48)|0)|0) + 36|0);
 HEAPF32[$55>>2] = $49;
 $56 = ((($14) + (($aIndex*48)|0)|0) + 40|0);
 HEAPF32[$56>>2] = $51;
 $57 = ((($14) + (($aIndex*48)|0)|0) + 44|0);
 HEAPF32[$57>>2] = $53;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton26SkeletonPoseComputeGlobalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseLocal,$apSkeletonPoseGlobal,$aIndex,$aStopIndex) {
 $apSkeleton = $apSkeleton|0;
 $apSkeletonPoseLocal = $apSkeletonPoseLocal|0;
 $apSkeletonPoseGlobal = $apSkeletonPoseGlobal|0;
 $aIndex = $aIndex|0;
 $aStopIndex = $aStopIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0);
 var $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0);
 var $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apSkeleton) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($4) + ($aIndex<<3)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  $84 = (($apSkeletonPoseGlobal) + 4|0);
  $85 = $84;
  $86 = HEAP32[$84>>2]|0;
  $87 = (($86) + ($85))|0;
  $88 = $87;
  $89 = (($apSkeletonPoseGlobal) + 8|0);
  HEAP32[$89>>2] = $88;
  $90 = (($apSkeletonPoseLocal) + 4|0);
  $91 = $90;
  $92 = HEAP32[$90>>2]|0;
  $93 = (($92) + ($91))|0;
  $94 = $93;
  $95 = ((($94) + (($aIndex*48)|0)|0) + 16|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = ((($94) + (($aIndex*48)|0)|0) + 20|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = ((($94) + (($aIndex*48)|0)|0) + 24|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = ((($94) + (($aIndex*48)|0)|0) + 28|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = ((($88) + (($aIndex*48)|0)|0) + 16|0);
  HEAPF32[$103>>2] = $96;
  $104 = ((($88) + (($aIndex*48)|0)|0) + 20|0);
  HEAPF32[$104>>2] = $98;
  $105 = ((($88) + (($aIndex*48)|0)|0) + 24|0);
  HEAPF32[$105>>2] = $100;
  $106 = ((($88) + (($aIndex*48)|0)|0) + 28|0);
  HEAPF32[$106>>2] = $102;
  STACKTOP = sp;return;
 }
 $8 = ($aIndex|0)==($aStopIndex|0);
 if (!($8)) {
  __ZN7mecanim8skeleton26SkeletonPoseComputeGlobalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseLocal,$apSkeletonPoseGlobal,$6,$aStopIndex);
 }
 $9 = (($apSkeletonPoseGlobal) + 4|0);
 $10 = $9;
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11) + ($10))|0;
 $13 = $12;
 $14 = (($apSkeletonPoseGlobal) + 8|0);
 HEAP32[$14>>2] = $13;
 $15 = (($apSkeletonPoseLocal) + 4|0);
 $16 = $15;
 $17 = HEAP32[$15>>2]|0;
 $18 = (($17) + ($16))|0;
 $19 = $18;
 $20 = ((($13) + (($6*48)|0)|0) + 20|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = ((($19) + (($aIndex*48)|0)|0) + 16|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($21 * $23);
 $25 = ((($13) + (($6*48)|0)|0) + 28|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = ((($19) + (($aIndex*48)|0)|0) + 28|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($26 * $28);
 $30 = ((($13) + (($6*48)|0)|0) + 24|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = ((($19) + (($aIndex*48)|0)|0) + 20|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($31 * $33);
 $35 = ((($13) + (($6*48)|0)|0) + 16|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = ((($19) + (($aIndex*48)|0)|0) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($36 * $38);
 $40 = Math_fround($26 * $38);
 $41 = Math_fround($23 * $36);
 $42 = Math_fround($21 * $38);
 $43 = Math_fround($23 * $31);
 $44 = Math_fround($24 - $40);
 $45 = Math_fround($29 - $41);
 $46 = Math_fround($34 - $42);
 $47 = Math_fround($39 - $43);
 $48 = Math_fround($28 * $31);
 $49 = Math_fround($31 * $38);
 $50 = Math_fround($23 * $26);
 $51 = Math_fround($26 * $33);
 $52 = Math_fround($44 - $48);
 $53 = Math_fround($45 - $49);
 $54 = Math_fround($46 - $50);
 $55 = Math_fround($47 - $51);
 $56 = Math_fround($33 * $36);
 $57 = Math_fround($21 * $33);
 $58 = Math_fround($28 * $36);
 $59 = Math_fround($21 * $28);
 $60 = Math_fround($52 - $56);
 $61 = Math_fround($53 - $57);
 $62 = Math_fround($54 - $58);
 $63 = Math_fround($55 - $59);
 $64 = Math_fround($62 * Math_fround(-1.0));
 $65 = Math_fround($63 * Math_fround(-1.0));
 $66 = Math_fround($60 * Math_fround(-1.0));
 $67 = Math_fround($64 * $64);
 $68 = Math_fround($65 * $65);
 $69 = Math_fround($66 * $66);
 $70 = Math_fround($61 * $61);
 $71 = Math_fround($67 + $68);
 $72 = Math_fround($70 + $69);
 $73 = Math_fround($71 + $72);
 $74 = (Math_fround(Math_sqrt((Math_fround($73)))));
 $75 = Math_fround(Math_fround(1.0) / $74);
 $76 = Math_fround($75 * $64);
 $77 = Math_fround($75 * $65);
 $78 = Math_fround($75 * $66);
 $79 = Math_fround($75 * $61);
 $80 = ((($13) + (($aIndex*48)|0)|0) + 16|0);
 HEAPF32[$80>>2] = $76;
 $81 = ((($13) + (($aIndex*48)|0)|0) + 20|0);
 HEAPF32[$81>>2] = $77;
 $82 = ((($13) + (($aIndex*48)|0)|0) + 24|0);
 HEAPF32[$82>>2] = $78;
 $83 = ((($13) + (($aIndex*48)|0)|0) + 28|0);
 HEAPF32[$83>>2] = $79;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton24SkeletonPoseComputeLocalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseGlobal,$apSkeletonPoseLocal,$aIndex,$aStopIndex) {
 $apSkeleton = $apSkeleton|0;
 $apSkeletonPoseGlobal = $apSkeletonPoseGlobal|0;
 $apSkeletonPoseLocal = $apSkeletonPoseLocal|0;
 $aIndex = $aIndex|0;
 $aStopIndex = $aStopIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp;
 $1 = (($apSkeleton) + 4|0);
 $2 = $1;
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + ($2))|0;
 $5 = $4;
 $6 = (($5) + ($aIndex<<3)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(-1);
 $9 = (($apSkeletonPoseLocal) + 4|0);
 $10 = $9;
 $11 = HEAP32[$9>>2]|0;
 $12 = (($11) + ($10))|0;
 $13 = $12;
 $14 = (($apSkeletonPoseLocal) + 8|0);
 HEAP32[$14>>2] = $13;
 $15 = (($13) + (($aIndex*48)|0)|0);
 $16 = (($apSkeletonPoseGlobal) + 4|0);
 $17 = $16;
 $18 = HEAP32[$16>>2]|0;
 $19 = (($18) + ($17))|0;
 $20 = $19;
 if ($8) {
  $58 = (($20) + (($aIndex*48)|0)|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($20) + (($aIndex*48)|0)|0) + 4|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = ((($20) + (($aIndex*48)|0)|0) + 8|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = ((($20) + (($aIndex*48)|0)|0) + 12|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  HEAPF32[$15>>2] = $59;
  $66 = ((($13) + (($aIndex*48)|0)|0) + 4|0);
  HEAPF32[$66>>2] = $61;
  $67 = ((($13) + (($aIndex*48)|0)|0) + 8|0);
  HEAPF32[$67>>2] = $63;
  $68 = ((($13) + (($aIndex*48)|0)|0) + 12|0);
  HEAPF32[$68>>2] = $65;
  $69 = ((($20) + (($aIndex*48)|0)|0) + 16|0);
  $70 = Math_fround(HEAPF32[$69>>2]);
  $71 = ((($20) + (($aIndex*48)|0)|0) + 20|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = ((($20) + (($aIndex*48)|0)|0) + 24|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = ((($20) + (($aIndex*48)|0)|0) + 28|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = ((($13) + (($aIndex*48)|0)|0) + 16|0);
  HEAPF32[$77>>2] = $70;
  $78 = ((($13) + (($aIndex*48)|0)|0) + 20|0);
  HEAPF32[$78>>2] = $72;
  $79 = ((($13) + (($aIndex*48)|0)|0) + 24|0);
  HEAPF32[$79>>2] = $74;
  $80 = ((($13) + (($aIndex*48)|0)|0) + 28|0);
  HEAPF32[$80>>2] = $76;
  $81 = ((($20) + (($aIndex*48)|0)|0) + 32|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = ((($20) + (($aIndex*48)|0)|0) + 36|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = ((($20) + (($aIndex*48)|0)|0) + 40|0);
  $86 = Math_fround(HEAPF32[$85>>2]);
  $87 = ((($20) + (($aIndex*48)|0)|0) + 44|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = ((($13) + (($aIndex*48)|0)|0) + 32|0);
  HEAPF32[$89>>2] = $82;
  $90 = ((($13) + (($aIndex*48)|0)|0) + 36|0);
  HEAPF32[$90>>2] = $84;
  $91 = ((($13) + (($aIndex*48)|0)|0) + 40|0);
  HEAPF32[$91>>2] = $86;
  $92 = ((($13) + (($aIndex*48)|0)|0) + 44|0);
  HEAPF32[$92>>2] = $88;
  STACKTOP = sp;return;
 }
 $21 = (($20) + (($7*48)|0)|0);
 $22 = (($20) + (($aIndex*48)|0)|0);
 __ZN4mathL11xformInvMulERKNS_5xformES2_19388($0,$21,$22);
 $23 = Math_fround(HEAPF32[$0>>2]);
 $24 = (($0) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = (($0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($0) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 HEAPF32[$15>>2] = $23;
 $30 = ((($13) + (($aIndex*48)|0)|0) + 4|0);
 HEAPF32[$30>>2] = $25;
 $31 = ((($13) + (($aIndex*48)|0)|0) + 8|0);
 HEAPF32[$31>>2] = $27;
 $32 = ((($13) + (($aIndex*48)|0)|0) + 12|0);
 HEAPF32[$32>>2] = $29;
 $33 = (($0) + 16|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = (($0) + 20|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($0) + 24|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($0) + 28|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = ((($13) + (($aIndex*48)|0)|0) + 16|0);
 HEAPF32[$41>>2] = $34;
 $42 = ((($13) + (($aIndex*48)|0)|0) + 20|0);
 HEAPF32[$42>>2] = $36;
 $43 = ((($13) + (($aIndex*48)|0)|0) + 24|0);
 HEAPF32[$43>>2] = $38;
 $44 = ((($13) + (($aIndex*48)|0)|0) + 28|0);
 HEAPF32[$44>>2] = $40;
 $45 = (($0) + 32|0);
 $46 = Math_fround(HEAPF32[$45>>2]);
 $47 = (($0) + 36|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($0) + 40|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($0) + 44|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = ((($13) + (($aIndex*48)|0)|0) + 32|0);
 HEAPF32[$53>>2] = $46;
 $54 = ((($13) + (($aIndex*48)|0)|0) + 36|0);
 HEAPF32[$54>>2] = $48;
 $55 = ((($13) + (($aIndex*48)|0)|0) + 40|0);
 HEAPF32[$55>>2] = $50;
 $56 = ((($13) + (($aIndex*48)|0)|0) + 44|0);
 HEAPF32[$56>>2] = $52;
 $57 = ($aIndex|0)==($aStopIndex|0);
 if ($57) {
  STACKTOP = sp;return;
 }
 __ZN7mecanim8skeleton24SkeletonPoseComputeLocalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseGlobal,$apSkeletonPoseLocal,$7,$aStopIndex);
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton25SkeletonPoseComputeLocalQEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseGlobal,$apSkeletonPoseLocal,$aIndex,$aStopIndex) {
 $apSkeleton = $apSkeleton|0;
 $apSkeletonPoseGlobal = $apSkeletonPoseGlobal|0;
 $apSkeletonPoseLocal = $apSkeletonPoseLocal|0;
 $aIndex = $aIndex|0;
 $aStopIndex = $aStopIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $aIndex$tr = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($apSkeleton) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($apSkeletonPoseLocal) + 4|0);
 $6 = $5;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + ($6))|0;
 $9 = $8;
 $10 = (($apSkeletonPoseLocal) + 8|0);
 $11 = (($apSkeletonPoseGlobal) + 4|0);
 $12 = $11;
 $13 = HEAP32[$11>>2]|0;
 $14 = (($13) + ($12))|0;
 $15 = $14;
 $aIndex$tr = $aIndex;
 while(1) {
  $16 = (($4) + ($aIndex$tr<<3)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(-1);
  $19 = ((($9) + (($aIndex$tr*48)|0)|0) + 16|0);
  if ($18) {
   label = 4;
   break;
  }
  $20 = ((($15) + (($17*48)|0)|0) + 16|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = Math_fround($21 * Math_fround(-1.0));
  $23 = ((($15) + (($17*48)|0)|0) + 20|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($24 * Math_fround(-1.0));
  $26 = ((($15) + (($17*48)|0)|0) + 24|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($27 * Math_fround(-1.0));
  $29 = ((($15) + (($17*48)|0)|0) + 28|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = ((($15) + (($aIndex$tr*48)|0)|0) + 16|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = Math_fround($25 * $32);
  $34 = ((($15) + (($aIndex$tr*48)|0)|0) + 28|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($30 * $35);
  $37 = ((($15) + (($aIndex$tr*48)|0)|0) + 20|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround($28 * $38);
  $40 = ((($15) + (($aIndex$tr*48)|0)|0) + 24|0);
  $41 = Math_fround(HEAPF32[$40>>2]);
  $42 = Math_fround($22 * $41);
  $43 = Math_fround($30 * $41);
  $44 = Math_fround($22 * $32);
  $45 = Math_fround($25 * $41);
  $46 = Math_fround($28 * $32);
  $47 = Math_fround($33 - $43);
  $48 = Math_fround($36 - $44);
  $49 = Math_fround($39 - $45);
  $50 = Math_fround($42 - $46);
  $51 = Math_fround($28 * $35);
  $52 = Math_fround($28 * $41);
  $53 = Math_fround($30 * $32);
  $54 = Math_fround($30 * $38);
  $55 = Math_fround($47 - $51);
  $56 = Math_fround($48 - $52);
  $57 = Math_fround($49 - $53);
  $58 = Math_fround($50 - $54);
  $59 = Math_fround($22 * $38);
  $60 = Math_fround($25 * $38);
  $61 = Math_fround($22 * $35);
  $62 = Math_fround($25 * $35);
  $63 = Math_fround($55 - $59);
  $64 = Math_fround($56 - $60);
  $65 = Math_fround($57 - $61);
  $66 = Math_fround($58 - $62);
  $67 = Math_fround($65 * Math_fround(-1.0));
  $68 = Math_fround($66 * Math_fround(-1.0));
  $69 = Math_fround($63 * Math_fround(-1.0));
  $70 = Math_fround($67 * $67);
  $71 = Math_fround($68 * $68);
  $72 = Math_fround($69 * $69);
  $73 = Math_fround($64 * $64);
  $74 = Math_fround($70 + $71);
  $75 = Math_fround($73 + $72);
  $76 = Math_fround($74 + $75);
  $77 = (Math_fround(Math_sqrt((Math_fround($76)))));
  $78 = Math_fround(Math_fround(1.0) / $77);
  $79 = Math_fround($78 * $67);
  $80 = Math_fround($78 * $68);
  $81 = Math_fround($78 * $69);
  $82 = Math_fround($78 * $64);
  HEAPF32[$19>>2] = $79;
  $83 = ((($9) + (($aIndex$tr*48)|0)|0) + 20|0);
  HEAPF32[$83>>2] = $80;
  $84 = ((($9) + (($aIndex$tr*48)|0)|0) + 24|0);
  HEAPF32[$84>>2] = $81;
  $85 = ((($9) + (($aIndex$tr*48)|0)|0) + 28|0);
  HEAPF32[$85>>2] = $82;
  $86 = ($aIndex$tr|0)==($aStopIndex|0);
  if ($86) {
   label = 5;
   break;
  } else {
   $aIndex$tr = $17;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$10>>2] = $9;
  $87 = ((($15) + (($aIndex$tr*48)|0)|0) + 16|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = ((($15) + (($aIndex$tr*48)|0)|0) + 20|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = ((($15) + (($aIndex$tr*48)|0)|0) + 24|0);
  $92 = Math_fround(HEAPF32[$91>>2]);
  $93 = ((($15) + (($aIndex$tr*48)|0)|0) + 28|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  HEAPF32[$19>>2] = $88;
  $95 = ((($9) + (($aIndex$tr*48)|0)|0) + 20|0);
  HEAPF32[$95>>2] = $90;
  $96 = ((($9) + (($aIndex$tr*48)|0)|0) + 24|0);
  HEAPF32[$96>>2] = $92;
  $97 = ((($9) + (($aIndex$tr*48)|0)|0) + 28|0);
  HEAPF32[$97>>2] = $94;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 5) {
  HEAP32[$10>>2] = $9;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim8skeleton14SkeletonGetDoFEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEi($agg$result,$apSkeleton,$apSkeletonPose,$aIndex) {
 $agg$result = $agg$result|0;
 $apSkeleton = $apSkeleton|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $aIndex = $aIndex|0;
 var $$in = 0, $$in10 = 0, $$in9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0);
 var $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0);
 var $168 = Math_fround(0), $169 = Math_fround(0), $17 = Math_fround(0), $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0);
 var $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = 0, $238 = Math_fround(0), $239 = 0;
 var $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = Math_fround(0), $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0);
 var $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = Math_fround(0);
 var $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = Math_fround(0), $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0;
 var $311 = 0, $312 = Math_fround(0), $313 = 0, $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = 0, $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = 0, $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = 0;
 var $366 = Math_fround(0), $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = Math_fround(0), $386 = 0, $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0);
 var $401 = 0, $402 = 0, $403 = Math_fround(0), $404 = 0, $405 = 0, $406 = Math_fround(0), $407 = 0, $408 = 0, $409 = Math_fround(0), $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = 0;
 var $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = 0, $448 = 0, $449 = Math_fround(0), $45 = Math_fround(0), $450 = 0, $451 = Math_fround(0), $452 = Math_fround(0), $453 = Math_fround(0), $454 = Math_fround(0), $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $485 = 0, $486 = Math_fround(0), $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = Math_fround(0);
 var $492 = 0, $493 = Math_fround(0), $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = Math_fround(0), $499 = 0, $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = Math_fround(0), $506 = 0, $507 = Math_fround(0), $508 = 0, $509 = 0;
 var $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = 0, $52 = Math_fround(0), $520 = Math_fround(0), $521 = 0, $522 = 0, $523 = Math_fround(0), $524 = 0, $525 = 0, $526 = Math_fround(0), $527 = 0;
 var $528 = 0, $529 = Math_fround(0), $53 = Math_fround(0), $530 = 0, $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = 0, $54 = Math_fround(0), $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = Math_fround(0), $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = Math_fround(0), $560 = Math_fround(0), $561 = 0, $562 = 0, $563 = Math_fround(0);
 var $564 = 0, $565 = 0, $566 = Math_fround(0), $567 = 0, $568 = 0, $569 = Math_fround(0), $57 = Math_fround(0), $570 = 0, $571 = Math_fround(0), $572 = Math_fround(0), $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = Math_fround(0), $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = Math_fround(0), $6 = 0;
 var $60 = Math_fround(0), $600 = 0, $601 = 0, $602 = 0, $603 = Math_fround(0), $604 = 0, $605 = 0, $606 = Math_fround(0), $607 = 0, $608 = 0, $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = 0, $613 = 0, $614 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apSkeleton) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = ((($4) + ($aIndex<<3)|0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($apSkeletonPose) + 4|0);
 $8 = $7;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($9) + ($8))|0;
 $11 = $10;
 $12 = ((($11) + (($aIndex*48)|0)|0) + 28|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = $13 == Math_fround(0.0);
 $15 = $14 ? Math_fround(9.99999997475242707878E-7) : $13;
 $16 = ((($11) + (($aIndex*48)|0)|0) + 16|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($17 / $15);
 $19 = ((($11) + (($aIndex*48)|0)|0) + 20|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 / $15);
 $22 = ((($11) + (($aIndex*48)|0)|0) + 24|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 / $15);
 $25 = (($apSkeleton) + 24|0);
 $26 = $25;
 $27 = HEAP32[$25>>2]|0;
 $28 = (($27) + ($26))|0;
 $29 = $28;
 $30 = (($29) + (($6*88)|0)|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * Math_fround(-1.0));
 $33 = ((($29) + (($6*88)|0)|0) + 4|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * Math_fround(-1.0));
 $36 = ((($29) + (($6*88)|0)|0) + 8|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * Math_fround(-1.0));
 $39 = ((($29) + (($6*88)|0)|0) + 12|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = ((($29) + (($6*88)|0)|0) + 16|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = Math_fround($20 * $42);
 $44 = ((($29) + (($6*88)|0)|0) + 28|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($13 * $45);
 $47 = ((($29) + (($6*88)|0)|0) + 20|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = Math_fround($23 * $48);
 $50 = ((($29) + (($6*88)|0)|0) + 24|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($17 * $51);
 $53 = Math_fround($13 * $51);
 $54 = Math_fround($17 * $42);
 $55 = Math_fround($20 * $51);
 $56 = Math_fround($23 * $42);
 $57 = Math_fround($43 - $53);
 $58 = Math_fround($46 - $54);
 $59 = Math_fround($49 - $55);
 $60 = Math_fround($52 - $56);
 $61 = Math_fround($23 * $45);
 $62 = Math_fround($23 * $51);
 $63 = Math_fround($13 * $42);
 $64 = Math_fround($13 * $48);
 $65 = Math_fround($57 - $61);
 $66 = Math_fround($58 - $62);
 $67 = Math_fround($59 - $63);
 $68 = Math_fround($60 - $64);
 $69 = Math_fround($17 * $48);
 $70 = Math_fround($20 * $48);
 $71 = Math_fround($17 * $45);
 $72 = Math_fround($20 * $45);
 $73 = Math_fround($65 - $69);
 $74 = Math_fround($66 - $70);
 $75 = Math_fround($67 - $71);
 $76 = Math_fround($68 - $72);
 $77 = Math_fround($75 * Math_fround(-1.0));
 $78 = Math_fround($76 * Math_fround(-1.0));
 $79 = Math_fround($73 * Math_fround(-1.0));
 $80 = Math_fround($35 * $77);
 $81 = Math_fround($40 * $74);
 $82 = Math_fround($38 * $78);
 $83 = Math_fround($32 * $79);
 $84 = Math_fround($40 * $79);
 $85 = Math_fround($32 * $77);
 $86 = Math_fround($35 * $79);
 $87 = Math_fround($38 * $77);
 $88 = Math_fround($80 - $84);
 $89 = Math_fround($81 - $85);
 $90 = Math_fround($82 - $86);
 $91 = Math_fround($83 - $87);
 $92 = Math_fround($38 * $74);
 $93 = Math_fround($38 * $79);
 $94 = Math_fround($40 * $77);
 $95 = Math_fround($40 * $78);
 $96 = Math_fround($88 - $92);
 $97 = Math_fround($89 - $93);
 $98 = Math_fround($90 - $94);
 $99 = Math_fround($91 - $95);
 $100 = Math_fround($32 * $78);
 $101 = Math_fround($35 * $78);
 $102 = Math_fround($32 * $74);
 $103 = Math_fround($35 * $74);
 $104 = Math_fround($96 - $100);
 $105 = Math_fround($97 - $101);
 $106 = Math_fround($98 - $102);
 $107 = Math_fround($99 - $103);
 $108 = Math_fround($106 * Math_fround(-1.0));
 $109 = Math_fround($107 * Math_fround(-1.0));
 $110 = Math_fround($104 * Math_fround(-1.0));
 $111 = Math_fround($108 * $108);
 $112 = Math_fround($109 * $109);
 $113 = Math_fround($110 * $110);
 $114 = Math_fround($105 * $105);
 $115 = Math_fround($111 + $112);
 $116 = Math_fround($114 + $113);
 $117 = Math_fround($115 + $116);
 $118 = (Math_fround(Math_sqrt((Math_fround($117)))));
 $119 = Math_fround(Math_fround(1.0) / $118);
 $120 = Math_fround($119 * $108);
 $121 = Math_fround($119 * $109);
 $122 = Math_fround($119 * $110);
 $123 = Math_fround($119 * $105);
 $124 = ((($29) + (($6*88)|0)|0) + 84|0);
 $125 = HEAP32[$124>>2]|0;
 if ((($125|0) == 3)) {
  $126 = Math_fround($120 * $120);
  $127 = Math_fround($120 * $121);
  $128 = Math_fround($120 * $122);
  $129 = Math_fround($123 * $120);
  $130 = Math_fround($121 * $121);
  $131 = Math_fround($122 * $121);
  $132 = Math_fround($123 * $121);
  $133 = Math_fround($128 - $132);
  $134 = !($133 >= Math_fround(0.499998986721038818359));
  do {
   if ($134) {
    $139 = Math_fround($123 * $123);
    $140 = Math_fround($123 * $122);
    $141 = Math_fround($139 + Math_fround(-0.5));
    $142 = !($133 <= Math_fround(-0.499998986721038818359));
    if ($142) {
     $146 = Math_fround($122 * $122);
     $147 = Math_fround($129 + $131);
     $148 = Math_fround($146 + $141);
     $149 = Math_fround($133 + $133);
     $150 = Math_fround($127 + $140);
     $151 = Math_fround($126 + $141);
     $152 = (Math_fround(+(Math_atan2((+$147),(+$148)))));
     $153 = (Math_fround(+(Math_asin((+$149)))));
     $154 = Math_fround(-$153);
     $155 = (Math_fround(+(Math_atan2((+$150),(+$151)))));
     $166 = $152;$168 = $154;$170 = $155;
     break;
    } else {
     $143 = Math_fround($127 - $140);
     $144 = Math_fround($130 + $141);
     $145 = (Math_fround(+(Math_atan2((+$143),(+$144)))));
     $166 = $145;$168 = Math_fround(1.57079637050628662109);$170 = Math_fround(0.0);
     break;
    }
   } else {
    $135 = Math_fround($129 - $131);
    $136 = Math_fround(-$128);
    $137 = Math_fround($136 - $132);
    $138 = (Math_fround(+(Math_atan2((+$135),(+$137)))));
    $166 = $138;$168 = Math_fround(-1.57079637050628662109);$170 = Math_fround(0.0);
   }
  } while(0);
  $156 = ((($29) + (($6*88)|0)|0) + 48|0);
  $157 = Math_fround(HEAPF32[$156>>2]);
  $158 = $157 > Math_fround(0.0);
  $159 = ((($29) + (($6*88)|0)|0) + 52|0);
  $160 = Math_fround(HEAPF32[$159>>2]);
  $161 = $160 > Math_fround(0.0);
  $162 = ((($29) + (($6*88)|0)|0) + 56|0);
  $163 = Math_fround(HEAPF32[$162>>2]);
  $164 = $163 > Math_fround(0.0);
  $165 = Math_fround(-$166);
  $167 = Math_fround(-$168);
  $169 = Math_fround(-$170);
  $171 = Math_fround($165 / $157);
  $172 = Math_fround($167 / $160);
  $173 = Math_fround($169 / $163);
  $174 = $157 < Math_fround(0.0);
  $175 = $160 < Math_fround(0.0);
  $176 = $163 < Math_fround(0.0);
  $177 = (HEAPF32[tempDoublePtr>>2]=$166,HEAP32[tempDoublePtr>>2]|0);
  $178 = $158 ? $177 : 0;
  $179 = (HEAPF32[tempDoublePtr>>2]=$171,HEAP32[tempDoublePtr>>2]|0);
  $180 = $174 ? $179 : $178;
  $181 = (HEAPF32[tempDoublePtr>>2]=$168,HEAP32[tempDoublePtr>>2]|0);
  $182 = $161 ? $181 : 0;
  $183 = (HEAPF32[tempDoublePtr>>2]=$172,HEAP32[tempDoublePtr>>2]|0);
  $184 = $175 ? $183 : $182;
  $185 = (HEAPF32[tempDoublePtr>>2]=$170,HEAP32[tempDoublePtr>>2]|0);
  $186 = $164 ? $185 : 0;
  $187 = (HEAPF32[tempDoublePtr>>2]=$173,HEAP32[tempDoublePtr>>2]|0);
  $188 = $176 ? $187 : $186;
  $189 = ((($29) + (($6*88)|0)|0) + 64|0);
  $190 = Math_fround(HEAPF32[$189>>2]);
  $191 = $190 < Math_fround(0.0);
  $192 = ((($29) + (($6*88)|0)|0) + 68|0);
  $193 = Math_fround(HEAPF32[$192>>2]);
  $194 = $193 < Math_fround(0.0);
  $195 = ((($29) + (($6*88)|0)|0) + 72|0);
  $196 = Math_fround(HEAPF32[$195>>2]);
  $197 = $196 < Math_fround(0.0);
  $198 = ((($29) + (($6*88)|0)|0) + 76|0);
  $199 = Math_fround(HEAPF32[$198>>2]);
  $200 = Math_fround($166 / $190);
  $201 = Math_fround($168 / $193);
  $202 = Math_fround($170 / $196);
  $203 = Math_fround(Math_fround(0.0) / $199);
  $204 = $190 > Math_fround(0.0);
  $205 = $193 > Math_fround(0.0);
  $206 = $196 > Math_fround(0.0);
  $207 = $199 > Math_fround(0.0);
  $208 = $191 ? $177 : 0;
  $209 = (HEAPF32[tempDoublePtr>>2]=$200,HEAP32[tempDoublePtr>>2]|0);
  $210 = $204 ? $209 : $208;
  $211 = $194 ? $181 : 0;
  $212 = (HEAPF32[tempDoublePtr>>2]=$201,HEAP32[tempDoublePtr>>2]|0);
  $213 = $205 ? $212 : $211;
  $214 = $197 ? $185 : 0;
  $215 = (HEAPF32[tempDoublePtr>>2]=$202,HEAP32[tempDoublePtr>>2]|0);
  $216 = $206 ? $215 : $214;
  $217 = $166 < Math_fround(0.0);
  $218 = $168 < Math_fround(0.0);
  $219 = $170 < Math_fround(0.0);
  $220 = $217 ? $180 : $210;
  $221 = $218 ? $184 : $213;
  $222 = $219 ? $188 : $216;
  $223 = $207 ? $203 : Math_fround(0.0);
  $$in = $222;$$in10 = $220;$$in9 = $221;$611 = $223;
  $600 = ($6|0)!=(-1);
  $601 = (HEAPF32[tempDoublePtr>>2]=$18,HEAP32[tempDoublePtr>>2]|0);
  $602 = $600 ? $$in10 : $601;
  $603 = (HEAP32[tempDoublePtr>>2]=$602,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $604 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
  $605 = $600 ? $$in9 : $604;
  $606 = (HEAP32[tempDoublePtr>>2]=$605,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $607 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $608 = $600 ? $$in : $607;
  $609 = (HEAP32[tempDoublePtr>>2]=$608,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $610 = $600 ? $611 : Math_fround(0.0);
  HEAPF32[$agg$result>>2] = $603;
  $612 = (($agg$result) + 4|0);
  HEAPF32[$612>>2] = $606;
  $613 = (($agg$result) + 8|0);
  HEAPF32[$613>>2] = $609;
  $614 = (($agg$result) + 12|0);
  HEAPF32[$614>>2] = $610;
  STACKTOP = sp;return;
 } else if ((($125|0) == 2)) {
  $352 = $123 == Math_fround(0.0);
  $353 = $352 ? Math_fround(9.99999997475242707878E-7) : $123;
  $354 = Math_fround($120 / $353);
  $355 = Math_fround($121 / $353);
  $356 = Math_fround($122 / $353);
  $357 = Math_fround($354 * $354);
  $358 = Math_fround($357 + Math_fround(1.0));
  $359 = Math_fround($354 * $356);
  $360 = Math_fround($355 + $359);
  $361 = Math_fround($360 / $358);
  $362 = Math_fround($354 * $355);
  $363 = Math_fround($356 - $362);
  $364 = Math_fround($363 / $358);
  $365 = ((($29) + (($6*88)|0)|0) + 32|0);
  $366 = Math_fround(HEAPF32[$365>>2]);
  $367 = (HEAPF32[tempDoublePtr>>2]=$354,HEAP32[tempDoublePtr>>2]|0);
  $368 = (HEAPF32[tempDoublePtr>>2]=$366,HEAP32[tempDoublePtr>>2]|0);
  $369 = $368 & -2147483648;
  $370 = $369 ^ $367;
  $371 = (HEAP32[tempDoublePtr>>2]=$370,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $372 = ((($29) + (($6*88)|0)|0) + 36|0);
  $373 = Math_fround(HEAPF32[$372>>2]);
  $374 = (HEAPF32[tempDoublePtr>>2]=$361,HEAP32[tempDoublePtr>>2]|0);
  $375 = (HEAPF32[tempDoublePtr>>2]=$373,HEAP32[tempDoublePtr>>2]|0);
  $376 = $375 & -2147483648;
  $377 = $376 ^ $374;
  $378 = (HEAP32[tempDoublePtr>>2]=$377,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $379 = ((($29) + (($6*88)|0)|0) + 40|0);
  $380 = Math_fround(HEAPF32[$379>>2]);
  $381 = (HEAPF32[tempDoublePtr>>2]=$364,HEAP32[tempDoublePtr>>2]|0);
  $382 = (HEAPF32[tempDoublePtr>>2]=$380,HEAP32[tempDoublePtr>>2]|0);
  $383 = $382 & -2147483648;
  $384 = $383 ^ $381;
  $385 = (HEAP32[tempDoublePtr>>2]=$384,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $386 = ((($29) + (($6*88)|0)|0) + 44|0);
  $387 = Math_fround(HEAPF32[$386>>2]);
  $388 = (HEAPF32[tempDoublePtr>>2]=$387,HEAP32[tempDoublePtr>>2]|0);
  $389 = $388 & -2147483648;
  $390 = (HEAP32[tempDoublePtr>>2]=$389,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $391 = (Math_fround(+(Math_atan((+$371)))));
  $392 = (Math_fround(+(Math_atan((+$378)))));
  $393 = (Math_fround(+(Math_atan((+$385)))));
  $394 = (Math_fround(+(Math_atan((+$390)))));
  $395 = Math_fround($391 * Math_fround(2.0));
  $396 = Math_fround($392 * Math_fround(2.0));
  $397 = Math_fround($393 * Math_fround(2.0));
  $398 = Math_fround($394 * Math_fround(2.0));
  $399 = ((($29) + (($6*88)|0)|0) + 48|0);
  $400 = Math_fround(HEAPF32[$399>>2]);
  $401 = $400 > Math_fround(0.0);
  $402 = ((($29) + (($6*88)|0)|0) + 52|0);
  $403 = Math_fround(HEAPF32[$402>>2]);
  $404 = $403 > Math_fround(0.0);
  $405 = ((($29) + (($6*88)|0)|0) + 56|0);
  $406 = Math_fround(HEAPF32[$405>>2]);
  $407 = $406 > Math_fround(0.0);
  $408 = ((($29) + (($6*88)|0)|0) + 60|0);
  $409 = Math_fround(HEAPF32[$408>>2]);
  $410 = $409 > Math_fround(0.0);
  $411 = Math_fround(-$395);
  $412 = Math_fround(-$396);
  $413 = Math_fround(-$397);
  $414 = Math_fround(-$398);
  $415 = Math_fround($411 / $400);
  $416 = Math_fround($412 / $403);
  $417 = Math_fround($413 / $406);
  $418 = Math_fround($414 / $409);
  $419 = $400 < Math_fround(0.0);
  $420 = $403 < Math_fround(0.0);
  $421 = $406 < Math_fround(0.0);
  $422 = $409 < Math_fround(0.0);
  $423 = (HEAPF32[tempDoublePtr>>2]=$395,HEAP32[tempDoublePtr>>2]|0);
  $424 = $401 ? $423 : 0;
  $425 = (HEAPF32[tempDoublePtr>>2]=$415,HEAP32[tempDoublePtr>>2]|0);
  $426 = $419 ? $425 : $424;
  $427 = (HEAPF32[tempDoublePtr>>2]=$396,HEAP32[tempDoublePtr>>2]|0);
  $428 = $404 ? $427 : 0;
  $429 = (HEAPF32[tempDoublePtr>>2]=$416,HEAP32[tempDoublePtr>>2]|0);
  $430 = $420 ? $429 : $428;
  $431 = (HEAPF32[tempDoublePtr>>2]=$397,HEAP32[tempDoublePtr>>2]|0);
  $432 = $407 ? $431 : 0;
  $433 = (HEAPF32[tempDoublePtr>>2]=$417,HEAP32[tempDoublePtr>>2]|0);
  $434 = $421 ? $433 : $432;
  $435 = (HEAPF32[tempDoublePtr>>2]=$398,HEAP32[tempDoublePtr>>2]|0);
  $436 = $410 ? $435 : 0;
  $437 = (HEAPF32[tempDoublePtr>>2]=$418,HEAP32[tempDoublePtr>>2]|0);
  $438 = $422 ? $437 : $436;
  $439 = ((($29) + (($6*88)|0)|0) + 64|0);
  $440 = Math_fround(HEAPF32[$439>>2]);
  $441 = $440 < Math_fround(0.0);
  $442 = ((($29) + (($6*88)|0)|0) + 68|0);
  $443 = Math_fround(HEAPF32[$442>>2]);
  $444 = $443 < Math_fround(0.0);
  $445 = ((($29) + (($6*88)|0)|0) + 72|0);
  $446 = Math_fround(HEAPF32[$445>>2]);
  $447 = $446 < Math_fround(0.0);
  $448 = ((($29) + (($6*88)|0)|0) + 76|0);
  $449 = Math_fround(HEAPF32[$448>>2]);
  $450 = $449 < Math_fround(0.0);
  $451 = Math_fround($395 / $440);
  $452 = Math_fround($396 / $443);
  $453 = Math_fround($397 / $446);
  $454 = Math_fround($398 / $449);
  $455 = $440 > Math_fround(0.0);
  $456 = $443 > Math_fround(0.0);
  $457 = $446 > Math_fround(0.0);
  $458 = $449 > Math_fround(0.0);
  $459 = $441 ? $423 : 0;
  $460 = (HEAPF32[tempDoublePtr>>2]=$451,HEAP32[tempDoublePtr>>2]|0);
  $461 = $455 ? $460 : $459;
  $462 = $444 ? $427 : 0;
  $463 = (HEAPF32[tempDoublePtr>>2]=$452,HEAP32[tempDoublePtr>>2]|0);
  $464 = $456 ? $463 : $462;
  $465 = $447 ? $431 : 0;
  $466 = (HEAPF32[tempDoublePtr>>2]=$453,HEAP32[tempDoublePtr>>2]|0);
  $467 = $457 ? $466 : $465;
  $468 = $450 ? $435 : 0;
  $469 = (HEAPF32[tempDoublePtr>>2]=$454,HEAP32[tempDoublePtr>>2]|0);
  $470 = $458 ? $469 : $468;
  $471 = $395 < Math_fround(0.0);
  $472 = $396 < Math_fround(0.0);
  $473 = $397 < Math_fround(0.0);
  $474 = $398 < Math_fround(0.0);
  $475 = $471 ? $426 : $461;
  $476 = $472 ? $430 : $464;
  $477 = $473 ? $434 : $467;
  $478 = $474 ? $438 : $470;
  $479 = (HEAP32[tempDoublePtr>>2]=$478,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $$in = $477;$$in10 = $475;$$in9 = $476;$611 = $479;
  $600 = ($6|0)!=(-1);
  $601 = (HEAPF32[tempDoublePtr>>2]=$18,HEAP32[tempDoublePtr>>2]|0);
  $602 = $600 ? $$in10 : $601;
  $603 = (HEAP32[tempDoublePtr>>2]=$602,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $604 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
  $605 = $600 ? $$in9 : $604;
  $606 = (HEAP32[tempDoublePtr>>2]=$605,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $607 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $608 = $600 ? $$in : $607;
  $609 = (HEAP32[tempDoublePtr>>2]=$608,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $610 = $600 ? $611 : Math_fround(0.0);
  HEAPF32[$agg$result>>2] = $603;
  $612 = (($agg$result) + 4|0);
  HEAPF32[$612>>2] = $606;
  $613 = (($agg$result) + 8|0);
  HEAPF32[$613>>2] = $609;
  $614 = (($agg$result) + 12|0);
  HEAPF32[$614>>2] = $610;
  STACKTOP = sp;return;
 } else if ((($125|0) == 1)) {
  $224 = $123 == Math_fround(0.0);
  $225 = $224 ? Math_fround(9.99999997475242707878E-7) : $123;
  $226 = Math_fround($120 / $225);
  $227 = Math_fround($121 / $225);
  $228 = Math_fround($122 / $225);
  $229 = Math_fround($226 * $226);
  $230 = Math_fround($229 + Math_fround(1.0));
  $231 = Math_fround($226 * $228);
  $232 = Math_fround($227 - $231);
  $233 = Math_fround($232 / $230);
  $234 = Math_fround($226 * $227);
  $235 = Math_fround($234 + $228);
  $236 = Math_fround($235 / $230);
  $237 = ((($29) + (($6*88)|0)|0) + 32|0);
  $238 = Math_fround(HEAPF32[$237>>2]);
  $239 = (HEAPF32[tempDoublePtr>>2]=$226,HEAP32[tempDoublePtr>>2]|0);
  $240 = (HEAPF32[tempDoublePtr>>2]=$238,HEAP32[tempDoublePtr>>2]|0);
  $241 = $240 & -2147483648;
  $242 = $241 ^ $239;
  $243 = (HEAP32[tempDoublePtr>>2]=$242,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $244 = ((($29) + (($6*88)|0)|0) + 36|0);
  $245 = Math_fround(HEAPF32[$244>>2]);
  $246 = (HEAPF32[tempDoublePtr>>2]=$233,HEAP32[tempDoublePtr>>2]|0);
  $247 = (HEAPF32[tempDoublePtr>>2]=$245,HEAP32[tempDoublePtr>>2]|0);
  $248 = $247 & -2147483648;
  $249 = $248 ^ $246;
  $250 = (HEAP32[tempDoublePtr>>2]=$249,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $251 = ((($29) + (($6*88)|0)|0) + 40|0);
  $252 = Math_fround(HEAPF32[$251>>2]);
  $253 = (HEAPF32[tempDoublePtr>>2]=$236,HEAP32[tempDoublePtr>>2]|0);
  $254 = (HEAPF32[tempDoublePtr>>2]=$252,HEAP32[tempDoublePtr>>2]|0);
  $255 = $254 & -2147483648;
  $256 = $255 ^ $253;
  $257 = (HEAP32[tempDoublePtr>>2]=$256,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $258 = ((($29) + (($6*88)|0)|0) + 44|0);
  $259 = Math_fround(HEAPF32[$258>>2]);
  $260 = (HEAPF32[tempDoublePtr>>2]=$259,HEAP32[tempDoublePtr>>2]|0);
  $261 = $260 & -2147483648;
  $262 = (HEAP32[tempDoublePtr>>2]=$261,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $263 = (Math_fround(+(Math_atan((+$243)))));
  $264 = (Math_fround(+(Math_atan((+$250)))));
  $265 = (Math_fround(+(Math_atan((+$257)))));
  $266 = (Math_fround(+(Math_atan((+$262)))));
  $267 = Math_fround($263 * Math_fround(2.0));
  $268 = Math_fround($264 * Math_fround(2.0));
  $269 = Math_fround($265 * Math_fround(2.0));
  $270 = Math_fround($266 * Math_fround(2.0));
  $271 = ((($29) + (($6*88)|0)|0) + 48|0);
  $272 = Math_fround(HEAPF32[$271>>2]);
  $273 = $272 > Math_fround(0.0);
  $274 = ((($29) + (($6*88)|0)|0) + 52|0);
  $275 = Math_fround(HEAPF32[$274>>2]);
  $276 = $275 > Math_fround(0.0);
  $277 = ((($29) + (($6*88)|0)|0) + 56|0);
  $278 = Math_fround(HEAPF32[$277>>2]);
  $279 = $278 > Math_fround(0.0);
  $280 = ((($29) + (($6*88)|0)|0) + 60|0);
  $281 = Math_fround(HEAPF32[$280>>2]);
  $282 = $281 > Math_fround(0.0);
  $283 = Math_fround(-$267);
  $284 = Math_fround(-$268);
  $285 = Math_fround(-$269);
  $286 = Math_fround(-$270);
  $287 = Math_fround($283 / $272);
  $288 = Math_fround($284 / $275);
  $289 = Math_fround($285 / $278);
  $290 = Math_fround($286 / $281);
  $291 = $272 < Math_fround(0.0);
  $292 = $275 < Math_fround(0.0);
  $293 = $278 < Math_fround(0.0);
  $294 = $281 < Math_fround(0.0);
  $295 = (HEAPF32[tempDoublePtr>>2]=$267,HEAP32[tempDoublePtr>>2]|0);
  $296 = $273 ? $295 : 0;
  $297 = (HEAPF32[tempDoublePtr>>2]=$287,HEAP32[tempDoublePtr>>2]|0);
  $298 = $291 ? $297 : $296;
  $299 = (HEAPF32[tempDoublePtr>>2]=$268,HEAP32[tempDoublePtr>>2]|0);
  $300 = $276 ? $299 : 0;
  $301 = (HEAPF32[tempDoublePtr>>2]=$288,HEAP32[tempDoublePtr>>2]|0);
  $302 = $292 ? $301 : $300;
  $303 = (HEAPF32[tempDoublePtr>>2]=$269,HEAP32[tempDoublePtr>>2]|0);
  $304 = $279 ? $303 : 0;
  $305 = (HEAPF32[tempDoublePtr>>2]=$289,HEAP32[tempDoublePtr>>2]|0);
  $306 = $293 ? $305 : $304;
  $307 = (HEAPF32[tempDoublePtr>>2]=$270,HEAP32[tempDoublePtr>>2]|0);
  $308 = $282 ? $307 : 0;
  $309 = (HEAPF32[tempDoublePtr>>2]=$290,HEAP32[tempDoublePtr>>2]|0);
  $310 = $294 ? $309 : $308;
  $311 = ((($29) + (($6*88)|0)|0) + 64|0);
  $312 = Math_fround(HEAPF32[$311>>2]);
  $313 = $312 < Math_fround(0.0);
  $314 = ((($29) + (($6*88)|0)|0) + 68|0);
  $315 = Math_fround(HEAPF32[$314>>2]);
  $316 = $315 < Math_fround(0.0);
  $317 = ((($29) + (($6*88)|0)|0) + 72|0);
  $318 = Math_fround(HEAPF32[$317>>2]);
  $319 = $318 < Math_fround(0.0);
  $320 = ((($29) + (($6*88)|0)|0) + 76|0);
  $321 = Math_fround(HEAPF32[$320>>2]);
  $322 = $321 < Math_fround(0.0);
  $323 = Math_fround($267 / $312);
  $324 = Math_fround($268 / $315);
  $325 = Math_fround($269 / $318);
  $326 = Math_fround($270 / $321);
  $327 = $312 > Math_fround(0.0);
  $328 = $315 > Math_fround(0.0);
  $329 = $318 > Math_fround(0.0);
  $330 = $321 > Math_fround(0.0);
  $331 = $313 ? $295 : 0;
  $332 = (HEAPF32[tempDoublePtr>>2]=$323,HEAP32[tempDoublePtr>>2]|0);
  $333 = $327 ? $332 : $331;
  $334 = $316 ? $299 : 0;
  $335 = (HEAPF32[tempDoublePtr>>2]=$324,HEAP32[tempDoublePtr>>2]|0);
  $336 = $328 ? $335 : $334;
  $337 = $319 ? $303 : 0;
  $338 = (HEAPF32[tempDoublePtr>>2]=$325,HEAP32[tempDoublePtr>>2]|0);
  $339 = $329 ? $338 : $337;
  $340 = $322 ? $307 : 0;
  $341 = (HEAPF32[tempDoublePtr>>2]=$326,HEAP32[tempDoublePtr>>2]|0);
  $342 = $330 ? $341 : $340;
  $343 = $267 < Math_fround(0.0);
  $344 = $268 < Math_fround(0.0);
  $345 = $269 < Math_fround(0.0);
  $346 = $270 < Math_fround(0.0);
  $347 = $343 ? $298 : $333;
  $348 = $344 ? $302 : $336;
  $349 = $345 ? $306 : $339;
  $350 = $346 ? $310 : $342;
  $351 = (HEAP32[tempDoublePtr>>2]=$350,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $$in = $349;$$in10 = $347;$$in9 = $348;$611 = $351;
  $600 = ($6|0)!=(-1);
  $601 = (HEAPF32[tempDoublePtr>>2]=$18,HEAP32[tempDoublePtr>>2]|0);
  $602 = $600 ? $$in10 : $601;
  $603 = (HEAP32[tempDoublePtr>>2]=$602,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $604 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
  $605 = $600 ? $$in9 : $604;
  $606 = (HEAP32[tempDoublePtr>>2]=$605,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $607 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $608 = $600 ? $$in : $607;
  $609 = (HEAP32[tempDoublePtr>>2]=$608,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $610 = $600 ? $611 : Math_fround(0.0);
  HEAPF32[$agg$result>>2] = $603;
  $612 = (($agg$result) + 4|0);
  HEAPF32[$612>>2] = $606;
  $613 = (($agg$result) + 8|0);
  HEAPF32[$613>>2] = $609;
  $614 = (($agg$result) + 12|0);
  HEAPF32[$614>>2] = $610;
  STACKTOP = sp;return;
 } else {
  $480 = $123 == Math_fround(0.0);
  $481 = $480 ? Math_fround(9.99999997475242707878E-7) : $123;
  $482 = Math_fround($120 / $481);
  $483 = Math_fround($121 / $481);
  $484 = Math_fround($122 / $481);
  $485 = ((($29) + (($6*88)|0)|0) + 32|0);
  $486 = Math_fround(HEAPF32[$485>>2]);
  $487 = (HEAPF32[tempDoublePtr>>2]=$482,HEAP32[tempDoublePtr>>2]|0);
  $488 = (HEAPF32[tempDoublePtr>>2]=$486,HEAP32[tempDoublePtr>>2]|0);
  $489 = $488 & -2147483648;
  $490 = $489 ^ $487;
  $491 = (HEAP32[tempDoublePtr>>2]=$490,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $492 = ((($29) + (($6*88)|0)|0) + 36|0);
  $493 = Math_fround(HEAPF32[$492>>2]);
  $494 = (HEAPF32[tempDoublePtr>>2]=$483,HEAP32[tempDoublePtr>>2]|0);
  $495 = (HEAPF32[tempDoublePtr>>2]=$493,HEAP32[tempDoublePtr>>2]|0);
  $496 = $495 & -2147483648;
  $497 = $496 ^ $494;
  $498 = (HEAP32[tempDoublePtr>>2]=$497,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $499 = ((($29) + (($6*88)|0)|0) + 40|0);
  $500 = Math_fround(HEAPF32[$499>>2]);
  $501 = (HEAPF32[tempDoublePtr>>2]=$484,HEAP32[tempDoublePtr>>2]|0);
  $502 = (HEAPF32[tempDoublePtr>>2]=$500,HEAP32[tempDoublePtr>>2]|0);
  $503 = $502 & -2147483648;
  $504 = $503 ^ $501;
  $505 = (HEAP32[tempDoublePtr>>2]=$504,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $506 = ((($29) + (($6*88)|0)|0) + 44|0);
  $507 = Math_fround(HEAPF32[$506>>2]);
  $508 = (HEAPF32[tempDoublePtr>>2]=$507,HEAP32[tempDoublePtr>>2]|0);
  $509 = $508 & -2147483648;
  $510 = (HEAP32[tempDoublePtr>>2]=$509,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $511 = (Math_fround(+(Math_atan((+$491)))));
  $512 = (Math_fround(+(Math_atan((+$498)))));
  $513 = (Math_fround(+(Math_atan((+$505)))));
  $514 = (Math_fround(+(Math_atan((+$510)))));
  $515 = Math_fround($511 * Math_fround(2.0));
  $516 = Math_fround($512 * Math_fround(2.0));
  $517 = Math_fround($513 * Math_fround(2.0));
  $518 = Math_fround($514 * Math_fround(2.0));
  $519 = ((($29) + (($6*88)|0)|0) + 48|0);
  $520 = Math_fround(HEAPF32[$519>>2]);
  $521 = $520 > Math_fround(0.0);
  $522 = ((($29) + (($6*88)|0)|0) + 52|0);
  $523 = Math_fround(HEAPF32[$522>>2]);
  $524 = $523 > Math_fround(0.0);
  $525 = ((($29) + (($6*88)|0)|0) + 56|0);
  $526 = Math_fround(HEAPF32[$525>>2]);
  $527 = $526 > Math_fround(0.0);
  $528 = ((($29) + (($6*88)|0)|0) + 60|0);
  $529 = Math_fround(HEAPF32[$528>>2]);
  $530 = $529 > Math_fround(0.0);
  $531 = Math_fround(-$515);
  $532 = Math_fround(-$516);
  $533 = Math_fround(-$517);
  $534 = Math_fround(-$518);
  $535 = Math_fround($531 / $520);
  $536 = Math_fround($532 / $523);
  $537 = Math_fround($533 / $526);
  $538 = Math_fround($534 / $529);
  $539 = $520 < Math_fround(0.0);
  $540 = $523 < Math_fround(0.0);
  $541 = $526 < Math_fround(0.0);
  $542 = $529 < Math_fround(0.0);
  $543 = (HEAPF32[tempDoublePtr>>2]=$515,HEAP32[tempDoublePtr>>2]|0);
  $544 = $521 ? $543 : 0;
  $545 = (HEAPF32[tempDoublePtr>>2]=$535,HEAP32[tempDoublePtr>>2]|0);
  $546 = $539 ? $545 : $544;
  $547 = (HEAPF32[tempDoublePtr>>2]=$516,HEAP32[tempDoublePtr>>2]|0);
  $548 = $524 ? $547 : 0;
  $549 = (HEAPF32[tempDoublePtr>>2]=$536,HEAP32[tempDoublePtr>>2]|0);
  $550 = $540 ? $549 : $548;
  $551 = (HEAPF32[tempDoublePtr>>2]=$517,HEAP32[tempDoublePtr>>2]|0);
  $552 = $527 ? $551 : 0;
  $553 = (HEAPF32[tempDoublePtr>>2]=$537,HEAP32[tempDoublePtr>>2]|0);
  $554 = $541 ? $553 : $552;
  $555 = (HEAPF32[tempDoublePtr>>2]=$518,HEAP32[tempDoublePtr>>2]|0);
  $556 = $530 ? $555 : 0;
  $557 = (HEAPF32[tempDoublePtr>>2]=$538,HEAP32[tempDoublePtr>>2]|0);
  $558 = $542 ? $557 : $556;
  $559 = ((($29) + (($6*88)|0)|0) + 64|0);
  $560 = Math_fround(HEAPF32[$559>>2]);
  $561 = $560 < Math_fround(0.0);
  $562 = ((($29) + (($6*88)|0)|0) + 68|0);
  $563 = Math_fround(HEAPF32[$562>>2]);
  $564 = $563 < Math_fround(0.0);
  $565 = ((($29) + (($6*88)|0)|0) + 72|0);
  $566 = Math_fround(HEAPF32[$565>>2]);
  $567 = $566 < Math_fround(0.0);
  $568 = ((($29) + (($6*88)|0)|0) + 76|0);
  $569 = Math_fround(HEAPF32[$568>>2]);
  $570 = $569 < Math_fround(0.0);
  $571 = Math_fround($515 / $560);
  $572 = Math_fround($516 / $563);
  $573 = Math_fround($517 / $566);
  $574 = Math_fround($518 / $569);
  $575 = $560 > Math_fround(0.0);
  $576 = $563 > Math_fround(0.0);
  $577 = $566 > Math_fround(0.0);
  $578 = $569 > Math_fround(0.0);
  $579 = $561 ? $543 : 0;
  $580 = (HEAPF32[tempDoublePtr>>2]=$571,HEAP32[tempDoublePtr>>2]|0);
  $581 = $575 ? $580 : $579;
  $582 = $564 ? $547 : 0;
  $583 = (HEAPF32[tempDoublePtr>>2]=$572,HEAP32[tempDoublePtr>>2]|0);
  $584 = $576 ? $583 : $582;
  $585 = $567 ? $551 : 0;
  $586 = (HEAPF32[tempDoublePtr>>2]=$573,HEAP32[tempDoublePtr>>2]|0);
  $587 = $577 ? $586 : $585;
  $588 = $570 ? $555 : 0;
  $589 = (HEAPF32[tempDoublePtr>>2]=$574,HEAP32[tempDoublePtr>>2]|0);
  $590 = $578 ? $589 : $588;
  $591 = $515 < Math_fround(0.0);
  $592 = $516 < Math_fround(0.0);
  $593 = $517 < Math_fround(0.0);
  $594 = $518 < Math_fround(0.0);
  $595 = $591 ? $546 : $581;
  $596 = $592 ? $550 : $584;
  $597 = $593 ? $554 : $587;
  $598 = $594 ? $558 : $590;
  $599 = (HEAP32[tempDoublePtr>>2]=$598,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $$in = $597;$$in10 = $595;$$in9 = $596;$611 = $599;
  $600 = ($6|0)!=(-1);
  $601 = (HEAPF32[tempDoublePtr>>2]=$18,HEAP32[tempDoublePtr>>2]|0);
  $602 = $600 ? $$in10 : $601;
  $603 = (HEAP32[tempDoublePtr>>2]=$602,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $604 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
  $605 = $600 ? $$in9 : $604;
  $606 = (HEAP32[tempDoublePtr>>2]=$605,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $607 = (HEAPF32[tempDoublePtr>>2]=$24,HEAP32[tempDoublePtr>>2]|0);
  $608 = $600 ? $$in : $607;
  $609 = (HEAP32[tempDoublePtr>>2]=$608,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $610 = $600 ? $611 : Math_fround(0.0);
  HEAPF32[$agg$result>>2] = $603;
  $612 = (($agg$result) + 4|0);
  HEAPF32[$612>>2] = $606;
  $613 = (($agg$result) + 8|0);
  HEAPF32[$613>>2] = $609;
  $614 = (($agg$result) + 12|0);
  HEAPF32[$614>>2] = $610;
  STACKTOP = sp;return;
 }
}
function __ZN7mecanim8skeleton14SkeletonSetDoFEPKNS0_8SkeletonEPNS0_12SkeletonPoseERKN4math7_float4Ei($apSkeleton,$apSkeletonPose,$aDoF,$aIndex) {
 $apSkeleton = $apSkeleton|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $aDoF = $aDoF|0;
 $aIndex = $aIndex|0;
 var $$v = Math_fround(0), $$v13 = Math_fround(0), $$v14 = Math_fround(0), $$v15 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = Math_fround(0);
 var $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = 0, $183 = Math_fround(0), $184 = 0;
 var $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = Math_fround(0), $231 = 0, $232 = Math_fround(0), $233 = 0, $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = Math_fround(0), $24 = Math_fround(0), $240 = 0, $241 = Math_fround(0), $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0);
 var $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = 0, $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = Math_fround(0), $269 = 0, $27 = Math_fround(0), $270 = 0, $271 = Math_fround(0), $272 = 0, $273 = 0, $274 = Math_fround(0);
 var $275 = 0, $276 = 0, $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = Math_fround(0), $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0), $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = Math_fround(0);
 var $310 = Math_fround(0), $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = Math_fround(0), $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = Math_fround(0), $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0, $341 = 0, $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = 0;
 var $347 = Math_fround(0), $348 = 0, $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = Math_fround(0), $354 = 0, $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0);
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = Math_fround(0), $37 = 0, $370 = 0, $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = 0, $395 = Math_fround(0), $396 = 0, $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = Math_fround(0), $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = 0, $445 = 0, $446 = Math_fround(0), $447 = 0, $448 = Math_fround(0), $449 = Math_fround(0), $45 = Math_fround(0), $450 = Math_fround(0), $451 = Math_fround(0), $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0;
 var $473 = Math_fround(0), $474 = 0, $475 = Math_fround(0), $476 = 0, $477 = Math_fround(0), $478 = 0, $479 = Math_fround(0), $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = Math_fround(0), $484 = 0, $485 = Math_fround(0), $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = Math_fround(0);
 var $491 = 0, $492 = Math_fround(0), $493 = 0, $494 = Math_fround(0), $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = Math_fround(0), $502 = 0, $503 = Math_fround(0), $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = Math_fround(0);
 var $509 = Math_fround(0), $51 = Math_fround(0), $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = 0, $521 = Math_fround(0), $522 = Math_fround(0), $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = 0;
 var $527 = Math_fround(0), $528 = Math_fround(0), $529 = 0, $53 = Math_fround(0), $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0);
 var $545 = Math_fround(0), $546 = Math_fround(0), $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = Math_fround(0), $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = Math_fround(0), $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0);
 var $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = 0, $567 = Math_fround(0), $568 = Math_fround(0), $569 = 0, $57 = Math_fround(0), $570 = Math_fround(0), $571 = Math_fround(0), $572 = 0, $573 = Math_fround(0), $574 = Math_fround(0), $575 = 0, $576 = Math_fround(0), $577 = Math_fround(0), $578 = Math_fround(0), $579 = Math_fround(0), $58 = Math_fround(0), $580 = Math_fround(0);
 var $581 = Math_fround(0), $582 = Math_fround(0), $583 = Math_fround(0), $584 = Math_fround(0), $585 = Math_fround(0), $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = Math_fround(0), $590 = Math_fround(0), $591 = Math_fround(0), $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $600 = Math_fround(0), $601 = Math_fround(0), $602 = Math_fround(0), $603 = Math_fround(0), $604 = Math_fround(0), $605 = Math_fround(0), $606 = Math_fround(0), $607 = Math_fround(0), $608 = Math_fround(0), $609 = Math_fround(0), $61 = Math_fround(0), $610 = Math_fround(0), $611 = Math_fround(0), $612 = Math_fround(0), $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = Math_fround(0);
 var $617 = Math_fround(0), $618 = 0, $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0);
 var $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0);
 var $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 80|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = sp + 48|0;
 $5 = sp + 64|0;
 $6 = (($apSkeleton) + 4|0);
 $7 = $6;
 $8 = HEAP32[$6>>2]|0;
 $9 = (($8) + ($7))|0;
 $10 = $9;
 $11 = ((($10) + ($aIndex<<3)|0) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($apSkeletonPose) + 4|0);
 $14 = $13;
 $15 = HEAP32[$13>>2]|0;
 $16 = (($15) + ($14))|0;
 $17 = $16;
 $18 = (($apSkeletonPose) + 8|0);
 HEAP32[$18>>2] = $17;
 $19 = Math_fround(HEAPF32[$aDoF>>2]);
 $20 = (($aDoF) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($aDoF) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($19 * $19);
 $25 = Math_fround($21 * $21);
 $26 = Math_fround($23 * $23);
 $27 = Math_fround($24 + $25);
 $28 = Math_fround($26 + Math_fround(1.0));
 $29 = Math_fround($27 + $28);
 $30 = (Math_fround(Math_sqrt((Math_fround($29)))));
 $31 = Math_fround(Math_fround(1.0) / $30);
 $32 = Math_fround($19 * $31);
 $33 = Math_fround($21 * $31);
 $34 = Math_fround($23 * $31);
 $35 = (($apSkeleton) + 24|0);
 $36 = $35;
 $37 = HEAP32[$35>>2]|0;
 $38 = (($37) + ($36))|0;
 $39 = $38;
 $40 = ((($39) + (($12*88)|0)|0) + 84|0);
 $41 = HEAP32[$40>>2]|0;
 if ((($41|0) == 3)) {
  $42 = Math_fround($19 * Math_fround(0.5));
  $43 = Math_fround($21 * Math_fround(0.5));
  $44 = Math_fround($23 * Math_fround(0.5));
  $45 = Math_fround($42 * Math_fround(0.159154936671257019043));
  $46 = Math_fround($43 * Math_fround(0.159154936671257019043));
  $47 = Math_fround($44 * Math_fround(0.159154936671257019043));
  $48 = (Math_fround(+(_roundf((+$45)))));
  $49 = (Math_fround(+(_roundf((+$46)))));
  $50 = (Math_fround(+(_roundf((+$47)))));
  $51 = Math_fround($45 - $48);
  $52 = Math_fround($46 - $49);
  $53 = Math_fround($47 - $50);
  $54 = (Math_fround(Math_abs((Math_fround($51)))));
  $55 = (Math_fround(Math_abs((Math_fround($52)))));
  $56 = (Math_fround(Math_abs((Math_fround($53)))));
  $57 = Math_fround(Math_fround(0.25) - $54);
  $58 = Math_fround(Math_fround(0.25) - $55);
  $59 = Math_fround(Math_fround(0.25) - $56);
  $60 = Math_fround($57 * $57);
  $61 = Math_fround($58 * $58);
  $62 = Math_fround($59 * $59);
  $63 = Math_fround($60 * $60);
  $64 = Math_fround($61 * $61);
  $65 = Math_fround($62 * $62);
  $66 = Math_fround($60 * Math_fround(-41.283184051513671875));
  $67 = Math_fround($61 * Math_fround(-41.283184051513671875));
  $68 = Math_fround($62 * Math_fround(-41.283184051513671875));
  $69 = Math_fround($66 + Math_fround(6.28318548202514648438));
  $70 = Math_fround($67 + Math_fround(6.28318548202514648438));
  $71 = Math_fround($68 + Math_fround(6.28318548202514648438));
  $72 = Math_fround($63 * Math_fround(76.03546142578125));
  $73 = Math_fround($64 * Math_fround(76.03546142578125));
  $74 = Math_fround($65 * Math_fround(76.03546142578125));
  $75 = Math_fround($69 + $72);
  $76 = Math_fround($70 + $73);
  $77 = Math_fround($71 + $74);
  $78 = Math_fround($57 * $75);
  $79 = Math_fround($58 * $76);
  $80 = Math_fround($59 * $77);
  $81 = Math_fround($45 + Math_fround(-0.25));
  $82 = Math_fround($46 + Math_fround(-0.25));
  $83 = Math_fround($47 + Math_fround(-0.25));
  $84 = (Math_fround(+(_roundf((+$81)))));
  $85 = (Math_fround(+(_roundf((+$82)))));
  $86 = (Math_fround(+(_roundf((+$83)))));
  $87 = Math_fround($81 - $84);
  $88 = Math_fround($82 - $85);
  $89 = Math_fround($83 - $86);
  $90 = (Math_fround(Math_abs((Math_fround($87)))));
  $91 = (Math_fround(Math_abs((Math_fround($88)))));
  $92 = (Math_fround(Math_abs((Math_fround($89)))));
  $93 = Math_fround(Math_fround(0.25) - $90);
  $94 = Math_fround(Math_fround(0.25) - $91);
  $95 = Math_fround(Math_fround(0.25) - $92);
  $96 = Math_fround($93 * $93);
  $97 = Math_fround($94 * $94);
  $98 = Math_fround($95 * $95);
  $99 = Math_fround($96 * $96);
  $100 = Math_fround($97 * $97);
  $101 = Math_fround($98 * $98);
  $102 = Math_fround($96 * Math_fround(-41.283184051513671875));
  $103 = Math_fround($97 * Math_fround(-41.283184051513671875));
  $104 = Math_fround($98 * Math_fround(-41.283184051513671875));
  $105 = Math_fround($102 + Math_fround(6.28318548202514648438));
  $106 = Math_fround($103 + Math_fround(6.28318548202514648438));
  $107 = Math_fround($104 + Math_fround(6.28318548202514648438));
  $108 = Math_fround($99 * Math_fround(76.03546142578125));
  $109 = Math_fround($100 * Math_fround(76.03546142578125));
  $110 = Math_fround($101 * Math_fround(76.03546142578125));
  $111 = Math_fround($105 + $108);
  $112 = Math_fround($106 + $109);
  $113 = Math_fround($107 + $110);
  $114 = Math_fround($93 * $111);
  $115 = Math_fround($94 * $112);
  $116 = Math_fround($95 * $113);
  $117 = Math_fround($80 * $114);
  $118 = Math_fround($114 * $116);
  $119 = Math_fround($78 * $116);
  $120 = Math_fround($78 * $80);
  $121 = Math_fround($79 * $117);
  $122 = Math_fround($79 * $118);
  $123 = Math_fround($79 * $119);
  $124 = Math_fround($79 * $120);
  $125 = Math_fround($115 * Math_fround(-1.0));
  $126 = Math_fround($125 * $119);
  $127 = Math_fround($120 * $115);
  $128 = Math_fround($117 * $125);
  $129 = Math_fround($115 * $118);
  $130 = Math_fround($121 + $126);
  $131 = Math_fround($127 + $122);
  $132 = Math_fround($128 + $123);
  $133 = Math_fround($124 + $129);
  $532 = $131;$534 = $133;$536 = $132;$538 = $130;
 } else if ((($41|0) == 1)) {
  $134 = ((($39) + (($12*88)|0)|0) + 48|0);
  $135 = Math_fround(HEAPF32[$134>>2]);
  $136 = $135 > Math_fround(0.0);
  $137 = ((($39) + (($12*88)|0)|0) + 52|0);
  $138 = Math_fround(HEAPF32[$137>>2]);
  $139 = $138 > Math_fround(0.0);
  $140 = ((($39) + (($12*88)|0)|0) + 56|0);
  $141 = Math_fround(HEAPF32[$140>>2]);
  $142 = $141 > Math_fround(0.0);
  $143 = ((($39) + (($12*88)|0)|0) + 60|0);
  $144 = Math_fround(HEAPF32[$143>>2]);
  $145 = $144 > Math_fround(0.0);
  $146 = (($aDoF) + 12|0);
  $147 = Math_fround(HEAPF32[$146>>2]);
  $148 = Math_fround($135 * $19);
  $149 = Math_fround(-$148);
  $150 = Math_fround($138 * $21);
  $151 = Math_fround(-$150);
  $152 = Math_fround($141 * $23);
  $153 = Math_fround(-$152);
  $154 = Math_fround($144 * $147);
  $155 = Math_fround(-$154);
  $156 = $135 < Math_fround(0.0);
  $157 = $138 < Math_fround(0.0);
  $158 = $141 < Math_fround(0.0);
  $159 = $144 < Math_fround(0.0);
  $160 = (HEAPF32[tempDoublePtr>>2]=$19,HEAP32[tempDoublePtr>>2]|0);
  $161 = $136 ? $160 : 0;
  $162 = (HEAPF32[tempDoublePtr>>2]=$149,HEAP32[tempDoublePtr>>2]|0);
  $163 = $156 ? $162 : $161;
  $164 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
  $165 = $139 ? $164 : 0;
  $166 = (HEAPF32[tempDoublePtr>>2]=$151,HEAP32[tempDoublePtr>>2]|0);
  $167 = $157 ? $166 : $165;
  $168 = (HEAPF32[tempDoublePtr>>2]=$23,HEAP32[tempDoublePtr>>2]|0);
  $169 = $142 ? $168 : 0;
  $170 = (HEAPF32[tempDoublePtr>>2]=$153,HEAP32[tempDoublePtr>>2]|0);
  $171 = $158 ? $170 : $169;
  $172 = (HEAPF32[tempDoublePtr>>2]=$147,HEAP32[tempDoublePtr>>2]|0);
  $173 = $145 ? $172 : 0;
  $174 = (HEAPF32[tempDoublePtr>>2]=$155,HEAP32[tempDoublePtr>>2]|0);
  $175 = $159 ? $174 : $173;
  $176 = ((($39) + (($12*88)|0)|0) + 64|0);
  $177 = Math_fround(HEAPF32[$176>>2]);
  $178 = $177 < Math_fround(0.0);
  $179 = ((($39) + (($12*88)|0)|0) + 68|0);
  $180 = Math_fround(HEAPF32[$179>>2]);
  $181 = $180 < Math_fround(0.0);
  $182 = ((($39) + (($12*88)|0)|0) + 72|0);
  $183 = Math_fround(HEAPF32[$182>>2]);
  $184 = $183 < Math_fround(0.0);
  $185 = ((($39) + (($12*88)|0)|0) + 76|0);
  $186 = Math_fround(HEAPF32[$185>>2]);
  $187 = $186 < Math_fround(0.0);
  $188 = Math_fround($19 * $177);
  $189 = Math_fround($21 * $180);
  $190 = Math_fround($23 * $183);
  $191 = Math_fround($147 * $186);
  $192 = $177 > Math_fround(0.0);
  $193 = $180 > Math_fround(0.0);
  $194 = $183 > Math_fround(0.0);
  $195 = $186 > Math_fround(0.0);
  $196 = $178 ? $160 : 0;
  $197 = (HEAPF32[tempDoublePtr>>2]=$188,HEAP32[tempDoublePtr>>2]|0);
  $198 = $192 ? $197 : $196;
  $199 = $181 ? $164 : 0;
  $200 = (HEAPF32[tempDoublePtr>>2]=$189,HEAP32[tempDoublePtr>>2]|0);
  $201 = $193 ? $200 : $199;
  $202 = $184 ? $168 : 0;
  $203 = (HEAPF32[tempDoublePtr>>2]=$190,HEAP32[tempDoublePtr>>2]|0);
  $204 = $194 ? $203 : $202;
  $205 = $187 ? $172 : 0;
  $206 = (HEAPF32[tempDoublePtr>>2]=$191,HEAP32[tempDoublePtr>>2]|0);
  $207 = $195 ? $206 : $205;
  $208 = $19 < Math_fround(0.0);
  $209 = $21 < Math_fround(0.0);
  $210 = $23 < Math_fround(0.0);
  $211 = $147 < Math_fround(0.0);
  $212 = $208 ? $163 : $198;
  $213 = (HEAP32[tempDoublePtr>>2]=$212,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $214 = $209 ? $167 : $201;
  $215 = (HEAP32[tempDoublePtr>>2]=$214,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $216 = $210 ? $171 : $204;
  $217 = (HEAP32[tempDoublePtr>>2]=$216,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $218 = $211 ? $175 : $207;
  $219 = (HEAP32[tempDoublePtr>>2]=$218,Math_fround(HEAPF32[tempDoublePtr>>2]));
  HEAPF32[$1>>2] = $213;
  $220 = (($1) + 4|0);
  HEAPF32[$220>>2] = $215;
  $221 = (($1) + 8|0);
  HEAPF32[$221>>2] = $217;
  $222 = (($1) + 12|0);
  HEAPF32[$222>>2] = $219;
  __ZN4mathL7halfTanERKNS_7_float4E19419($0,$1);
  $223 = Math_fround(HEAPF32[$0>>2]);
  $224 = ((($39) + (($12*88)|0)|0) + 32|0);
  $225 = Math_fround(HEAPF32[$224>>2]);
  $226 = (HEAPF32[tempDoublePtr>>2]=$223,HEAP32[tempDoublePtr>>2]|0);
  $227 = (HEAPF32[tempDoublePtr>>2]=$225,HEAP32[tempDoublePtr>>2]|0);
  $228 = $227 & -2147483648;
  $229 = $228 ^ $226;
  $230 = (HEAP32[tempDoublePtr>>2]=$229,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $231 = (($0) + 4|0);
  $232 = Math_fround(HEAPF32[$231>>2]);
  $233 = ((($39) + (($12*88)|0)|0) + 36|0);
  $234 = Math_fround(HEAPF32[$233>>2]);
  $235 = (HEAPF32[tempDoublePtr>>2]=$232,HEAP32[tempDoublePtr>>2]|0);
  $236 = (HEAPF32[tempDoublePtr>>2]=$234,HEAP32[tempDoublePtr>>2]|0);
  $237 = $236 & -2147483648;
  $238 = $237 ^ $235;
  $239 = (HEAP32[tempDoublePtr>>2]=$238,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $240 = (($0) + 8|0);
  $241 = Math_fround(HEAPF32[$240>>2]);
  $242 = ((($39) + (($12*88)|0)|0) + 40|0);
  $243 = Math_fround(HEAPF32[$242>>2]);
  $244 = (HEAPF32[tempDoublePtr>>2]=$241,HEAP32[tempDoublePtr>>2]|0);
  $245 = (HEAPF32[tempDoublePtr>>2]=$243,HEAP32[tempDoublePtr>>2]|0);
  $246 = $245 & -2147483648;
  $247 = $246 ^ $244;
  $248 = (HEAP32[tempDoublePtr>>2]=$247,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $249 = Math_fround($230 * $248);
  $250 = Math_fround($239 + $249);
  $251 = Math_fround($230 * $239);
  $252 = Math_fround($248 - $251);
  $253 = Math_fround($230 * $230);
  $254 = Math_fround($250 * $250);
  $255 = Math_fround($252 * $252);
  $256 = Math_fround($253 + $254);
  $257 = Math_fround($255 + Math_fround(1.0));
  $258 = Math_fround($257 + $256);
  $259 = (Math_fround(Math_sqrt((Math_fround($258)))));
  $260 = Math_fround(Math_fround(1.0) / $259);
  $261 = Math_fround($230 * $260);
  $262 = Math_fround($260 * $250);
  $263 = Math_fround($260 * $252);
  $532 = $262;$534 = $260;$536 = $263;$538 = $261;
 } else if ((($41|0) == 2)) {
  $264 = ((($39) + (($12*88)|0)|0) + 48|0);
  $265 = Math_fround(HEAPF32[$264>>2]);
  $266 = $265 > Math_fround(0.0);
  $267 = ((($39) + (($12*88)|0)|0) + 52|0);
  $268 = Math_fround(HEAPF32[$267>>2]);
  $269 = $268 > Math_fround(0.0);
  $270 = ((($39) + (($12*88)|0)|0) + 56|0);
  $271 = Math_fround(HEAPF32[$270>>2]);
  $272 = $271 > Math_fround(0.0);
  $273 = ((($39) + (($12*88)|0)|0) + 60|0);
  $274 = Math_fround(HEAPF32[$273>>2]);
  $275 = $274 > Math_fround(0.0);
  $276 = (($aDoF) + 12|0);
  $277 = Math_fround(HEAPF32[$276>>2]);
  $278 = Math_fround($265 * $19);
  $279 = Math_fround(-$278);
  $280 = Math_fround($268 * $21);
  $281 = Math_fround(-$280);
  $282 = Math_fround($271 * $23);
  $283 = Math_fround(-$282);
  $284 = Math_fround($274 * $277);
  $285 = Math_fround(-$284);
  $286 = $265 < Math_fround(0.0);
  $287 = $268 < Math_fround(0.0);
  $288 = $271 < Math_fround(0.0);
  $289 = $274 < Math_fround(0.0);
  $290 = (HEAPF32[tempDoublePtr>>2]=$19,HEAP32[tempDoublePtr>>2]|0);
  $291 = $266 ? $290 : 0;
  $292 = (HEAPF32[tempDoublePtr>>2]=$279,HEAP32[tempDoublePtr>>2]|0);
  $293 = $286 ? $292 : $291;
  $294 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
  $295 = $269 ? $294 : 0;
  $296 = (HEAPF32[tempDoublePtr>>2]=$281,HEAP32[tempDoublePtr>>2]|0);
  $297 = $287 ? $296 : $295;
  $298 = (HEAPF32[tempDoublePtr>>2]=$23,HEAP32[tempDoublePtr>>2]|0);
  $299 = $272 ? $298 : 0;
  $300 = (HEAPF32[tempDoublePtr>>2]=$283,HEAP32[tempDoublePtr>>2]|0);
  $301 = $288 ? $300 : $299;
  $302 = (HEAPF32[tempDoublePtr>>2]=$277,HEAP32[tempDoublePtr>>2]|0);
  $303 = $275 ? $302 : 0;
  $304 = (HEAPF32[tempDoublePtr>>2]=$285,HEAP32[tempDoublePtr>>2]|0);
  $305 = $289 ? $304 : $303;
  $306 = ((($39) + (($12*88)|0)|0) + 64|0);
  $307 = Math_fround(HEAPF32[$306>>2]);
  $308 = $307 < Math_fround(0.0);
  $309 = ((($39) + (($12*88)|0)|0) + 68|0);
  $310 = Math_fround(HEAPF32[$309>>2]);
  $311 = $310 < Math_fround(0.0);
  $312 = ((($39) + (($12*88)|0)|0) + 72|0);
  $313 = Math_fround(HEAPF32[$312>>2]);
  $314 = $313 < Math_fround(0.0);
  $315 = ((($39) + (($12*88)|0)|0) + 76|0);
  $316 = Math_fround(HEAPF32[$315>>2]);
  $317 = $316 < Math_fround(0.0);
  $318 = Math_fround($19 * $307);
  $319 = Math_fround($21 * $310);
  $320 = Math_fround($23 * $313);
  $321 = Math_fround($277 * $316);
  $322 = $307 > Math_fround(0.0);
  $323 = $310 > Math_fround(0.0);
  $324 = $313 > Math_fround(0.0);
  $325 = $316 > Math_fround(0.0);
  $326 = $308 ? $290 : 0;
  $327 = (HEAPF32[tempDoublePtr>>2]=$318,HEAP32[tempDoublePtr>>2]|0);
  $328 = $322 ? $327 : $326;
  $329 = $311 ? $294 : 0;
  $330 = (HEAPF32[tempDoublePtr>>2]=$319,HEAP32[tempDoublePtr>>2]|0);
  $331 = $323 ? $330 : $329;
  $332 = $314 ? $298 : 0;
  $333 = (HEAPF32[tempDoublePtr>>2]=$320,HEAP32[tempDoublePtr>>2]|0);
  $334 = $324 ? $333 : $332;
  $335 = $317 ? $302 : 0;
  $336 = (HEAPF32[tempDoublePtr>>2]=$321,HEAP32[tempDoublePtr>>2]|0);
  $337 = $325 ? $336 : $335;
  $338 = $19 < Math_fround(0.0);
  $339 = $21 < Math_fround(0.0);
  $340 = $23 < Math_fround(0.0);
  $341 = $277 < Math_fround(0.0);
  $342 = $338 ? $293 : $328;
  $343 = (HEAP32[tempDoublePtr>>2]=$342,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $344 = $339 ? $297 : $331;
  $345 = (HEAP32[tempDoublePtr>>2]=$344,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $346 = $340 ? $301 : $334;
  $347 = (HEAP32[tempDoublePtr>>2]=$346,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $348 = $341 ? $305 : $337;
  $349 = (HEAP32[tempDoublePtr>>2]=$348,Math_fround(HEAPF32[tempDoublePtr>>2]));
  HEAPF32[$3>>2] = $343;
  $350 = (($3) + 4|0);
  HEAPF32[$350>>2] = $345;
  $351 = (($3) + 8|0);
  HEAPF32[$351>>2] = $347;
  $352 = (($3) + 12|0);
  HEAPF32[$352>>2] = $349;
  __ZN4mathL7halfTanERKNS_7_float4E19419($2,$3);
  $353 = Math_fround(HEAPF32[$2>>2]);
  $354 = ((($39) + (($12*88)|0)|0) + 32|0);
  $355 = Math_fround(HEAPF32[$354>>2]);
  $356 = (HEAPF32[tempDoublePtr>>2]=$353,HEAP32[tempDoublePtr>>2]|0);
  $357 = (HEAPF32[tempDoublePtr>>2]=$355,HEAP32[tempDoublePtr>>2]|0);
  $358 = $357 & -2147483648;
  $359 = $358 ^ $356;
  $360 = (HEAP32[tempDoublePtr>>2]=$359,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $361 = (($2) + 4|0);
  $362 = Math_fround(HEAPF32[$361>>2]);
  $363 = ((($39) + (($12*88)|0)|0) + 36|0);
  $364 = Math_fround(HEAPF32[$363>>2]);
  $365 = (HEAPF32[tempDoublePtr>>2]=$362,HEAP32[tempDoublePtr>>2]|0);
  $366 = (HEAPF32[tempDoublePtr>>2]=$364,HEAP32[tempDoublePtr>>2]|0);
  $367 = $366 & -2147483648;
  $368 = $367 ^ $365;
  $369 = (HEAP32[tempDoublePtr>>2]=$368,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $370 = (($2) + 8|0);
  $371 = Math_fround(HEAPF32[$370>>2]);
  $372 = ((($39) + (($12*88)|0)|0) + 40|0);
  $373 = Math_fround(HEAPF32[$372>>2]);
  $374 = (HEAPF32[tempDoublePtr>>2]=$371,HEAP32[tempDoublePtr>>2]|0);
  $375 = (HEAPF32[tempDoublePtr>>2]=$373,HEAP32[tempDoublePtr>>2]|0);
  $376 = $375 & -2147483648;
  $377 = $376 ^ $374;
  $378 = (HEAP32[tempDoublePtr>>2]=$377,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $379 = Math_fround($360 * $378);
  $380 = Math_fround($369 - $379);
  $381 = Math_fround($360 * $369);
  $382 = Math_fround($381 + $378);
  $383 = Math_fround($360 * $360);
  $384 = Math_fround($380 * $380);
  $385 = Math_fround($382 * $382);
  $386 = Math_fround($383 + $384);
  $387 = Math_fround($385 + Math_fround(1.0));
  $388 = Math_fround($387 + $386);
  $389 = (Math_fround(Math_sqrt((Math_fround($388)))));
  $390 = Math_fround(Math_fround(1.0) / $389);
  $391 = Math_fround($360 * $390);
  $392 = Math_fround($390 * $380);
  $393 = Math_fround($390 * $382);
  $532 = $392;$534 = $390;$536 = $393;$538 = $391;
 } else {
  $394 = ((($39) + (($12*88)|0)|0) + 48|0);
  $395 = Math_fround(HEAPF32[$394>>2]);
  $396 = $395 > Math_fround(0.0);
  $397 = ((($39) + (($12*88)|0)|0) + 52|0);
  $398 = Math_fround(HEAPF32[$397>>2]);
  $399 = $398 > Math_fround(0.0);
  $400 = ((($39) + (($12*88)|0)|0) + 56|0);
  $401 = Math_fround(HEAPF32[$400>>2]);
  $402 = $401 > Math_fround(0.0);
  $403 = ((($39) + (($12*88)|0)|0) + 60|0);
  $404 = Math_fround(HEAPF32[$403>>2]);
  $405 = $404 > Math_fround(0.0);
  $406 = (($aDoF) + 12|0);
  $407 = Math_fround(HEAPF32[$406>>2]);
  $408 = Math_fround($395 * $19);
  $409 = Math_fround(-$408);
  $410 = Math_fround($398 * $21);
  $411 = Math_fround(-$410);
  $412 = Math_fround($401 * $23);
  $413 = Math_fround(-$412);
  $414 = Math_fround($404 * $407);
  $415 = Math_fround(-$414);
  $416 = $395 < Math_fround(0.0);
  $417 = $398 < Math_fround(0.0);
  $418 = $401 < Math_fround(0.0);
  $419 = $404 < Math_fround(0.0);
  $420 = (HEAPF32[tempDoublePtr>>2]=$19,HEAP32[tempDoublePtr>>2]|0);
  $421 = $396 ? $420 : 0;
  $422 = (HEAPF32[tempDoublePtr>>2]=$409,HEAP32[tempDoublePtr>>2]|0);
  $423 = $416 ? $422 : $421;
  $424 = (HEAPF32[tempDoublePtr>>2]=$21,HEAP32[tempDoublePtr>>2]|0);
  $425 = $399 ? $424 : 0;
  $426 = (HEAPF32[tempDoublePtr>>2]=$411,HEAP32[tempDoublePtr>>2]|0);
  $427 = $417 ? $426 : $425;
  $428 = (HEAPF32[tempDoublePtr>>2]=$23,HEAP32[tempDoublePtr>>2]|0);
  $429 = $402 ? $428 : 0;
  $430 = (HEAPF32[tempDoublePtr>>2]=$413,HEAP32[tempDoublePtr>>2]|0);
  $431 = $418 ? $430 : $429;
  $432 = (HEAPF32[tempDoublePtr>>2]=$407,HEAP32[tempDoublePtr>>2]|0);
  $433 = $405 ? $432 : 0;
  $434 = (HEAPF32[tempDoublePtr>>2]=$415,HEAP32[tempDoublePtr>>2]|0);
  $435 = $419 ? $434 : $433;
  $436 = ((($39) + (($12*88)|0)|0) + 64|0);
  $437 = Math_fround(HEAPF32[$436>>2]);
  $438 = $437 < Math_fround(0.0);
  $439 = ((($39) + (($12*88)|0)|0) + 68|0);
  $440 = Math_fround(HEAPF32[$439>>2]);
  $441 = $440 < Math_fround(0.0);
  $442 = ((($39) + (($12*88)|0)|0) + 72|0);
  $443 = Math_fround(HEAPF32[$442>>2]);
  $444 = $443 < Math_fround(0.0);
  $445 = ((($39) + (($12*88)|0)|0) + 76|0);
  $446 = Math_fround(HEAPF32[$445>>2]);
  $447 = $446 < Math_fround(0.0);
  $448 = Math_fround($19 * $437);
  $449 = Math_fround($21 * $440);
  $450 = Math_fround($23 * $443);
  $451 = Math_fround($407 * $446);
  $452 = $437 > Math_fround(0.0);
  $453 = $440 > Math_fround(0.0);
  $454 = $443 > Math_fround(0.0);
  $455 = $446 > Math_fround(0.0);
  $456 = $438 ? $420 : 0;
  $457 = (HEAPF32[tempDoublePtr>>2]=$448,HEAP32[tempDoublePtr>>2]|0);
  $458 = $452 ? $457 : $456;
  $459 = $441 ? $424 : 0;
  $460 = (HEAPF32[tempDoublePtr>>2]=$449,HEAP32[tempDoublePtr>>2]|0);
  $461 = $453 ? $460 : $459;
  $462 = $444 ? $428 : 0;
  $463 = (HEAPF32[tempDoublePtr>>2]=$450,HEAP32[tempDoublePtr>>2]|0);
  $464 = $454 ? $463 : $462;
  $465 = $447 ? $432 : 0;
  $466 = (HEAPF32[tempDoublePtr>>2]=$451,HEAP32[tempDoublePtr>>2]|0);
  $467 = $455 ? $466 : $465;
  $468 = $19 < Math_fround(0.0);
  $469 = $21 < Math_fround(0.0);
  $470 = $23 < Math_fround(0.0);
  $471 = $407 < Math_fround(0.0);
  $472 = $468 ? $423 : $458;
  $473 = (HEAP32[tempDoublePtr>>2]=$472,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $474 = $469 ? $427 : $461;
  $475 = (HEAP32[tempDoublePtr>>2]=$474,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $476 = $470 ? $431 : $464;
  $477 = (HEAP32[tempDoublePtr>>2]=$476,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $478 = $471 ? $435 : $467;
  $479 = (HEAP32[tempDoublePtr>>2]=$478,Math_fround(HEAPF32[tempDoublePtr>>2]));
  HEAPF32[$5>>2] = $473;
  $480 = (($5) + 4|0);
  HEAPF32[$480>>2] = $475;
  $481 = (($5) + 8|0);
  HEAPF32[$481>>2] = $477;
  $482 = (($5) + 12|0);
  HEAPF32[$482>>2] = $479;
  __ZN4mathL7halfTanERKNS_7_float4E19419($4,$5);
  $483 = Math_fround(HEAPF32[$4>>2]);
  $484 = ((($39) + (($12*88)|0)|0) + 32|0);
  $485 = Math_fround(HEAPF32[$484>>2]);
  $486 = (HEAPF32[tempDoublePtr>>2]=$483,HEAP32[tempDoublePtr>>2]|0);
  $487 = (HEAPF32[tempDoublePtr>>2]=$485,HEAP32[tempDoublePtr>>2]|0);
  $488 = $487 & -2147483648;
  $489 = $488 ^ $486;
  $490 = (HEAP32[tempDoublePtr>>2]=$489,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $491 = (($4) + 4|0);
  $492 = Math_fround(HEAPF32[$491>>2]);
  $493 = ((($39) + (($12*88)|0)|0) + 36|0);
  $494 = Math_fround(HEAPF32[$493>>2]);
  $495 = (HEAPF32[tempDoublePtr>>2]=$492,HEAP32[tempDoublePtr>>2]|0);
  $496 = (HEAPF32[tempDoublePtr>>2]=$494,HEAP32[tempDoublePtr>>2]|0);
  $497 = $496 & -2147483648;
  $498 = $497 ^ $495;
  $499 = (HEAP32[tempDoublePtr>>2]=$498,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $500 = (($4) + 8|0);
  $501 = Math_fround(HEAPF32[$500>>2]);
  $502 = ((($39) + (($12*88)|0)|0) + 40|0);
  $503 = Math_fround(HEAPF32[$502>>2]);
  $504 = (HEAPF32[tempDoublePtr>>2]=$501,HEAP32[tempDoublePtr>>2]|0);
  $505 = (HEAPF32[tempDoublePtr>>2]=$503,HEAP32[tempDoublePtr>>2]|0);
  $506 = $505 & -2147483648;
  $507 = $506 ^ $504;
  $508 = (HEAP32[tempDoublePtr>>2]=$507,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $509 = Math_fround($490 * $490);
  $510 = Math_fround($499 * $499);
  $511 = Math_fround($508 * $508);
  $512 = Math_fround($509 + $510);
  $513 = Math_fround($511 + Math_fround(1.0));
  $514 = Math_fround($512 + $513);
  $515 = (Math_fround(Math_sqrt((Math_fround($514)))));
  $516 = Math_fround(Math_fround(1.0) / $515);
  $517 = Math_fround($490 * $516);
  $518 = Math_fround($499 * $516);
  $519 = Math_fround($516 * $508);
  $532 = $518;$534 = $516;$536 = $519;$538 = $517;
 }
 $520 = ((($39) + (($12*88)|0)|0) + 16|0);
 $521 = Math_fround(HEAPF32[$520>>2]);
 $522 = Math_fround($521 * Math_fround(-1.0));
 $523 = ((($39) + (($12*88)|0)|0) + 20|0);
 $524 = Math_fround(HEAPF32[$523>>2]);
 $525 = Math_fround($524 * Math_fround(-1.0));
 $526 = ((($39) + (($12*88)|0)|0) + 24|0);
 $527 = Math_fround(HEAPF32[$526>>2]);
 $528 = Math_fround($527 * Math_fround(-1.0));
 $529 = ((($39) + (($12*88)|0)|0) + 28|0);
 $530 = Math_fround(HEAPF32[$529>>2]);
 $531 = Math_fround($532 * $522);
 $533 = Math_fround($534 * $530);
 $535 = Math_fround($536 * $525);
 $537 = Math_fround($538 * $528);
 $539 = Math_fround($534 * $528);
 $540 = Math_fround($538 * $522);
 $541 = Math_fround($532 * $528);
 $542 = Math_fround($536 * $522);
 $543 = Math_fround($531 - $539);
 $544 = Math_fround($533 - $540);
 $545 = Math_fround($535 - $541);
 $546 = Math_fround($537 - $542);
 $547 = Math_fround($536 * $530);
 $548 = Math_fround($536 * $528);
 $549 = Math_fround($534 * $522);
 $550 = Math_fround($534 * $525);
 $551 = Math_fround($543 - $547);
 $552 = Math_fround($544 - $548);
 $553 = Math_fround($545 - $549);
 $554 = Math_fround($546 - $550);
 $555 = Math_fround($538 * $525);
 $556 = Math_fround($532 * $525);
 $557 = Math_fround($538 * $530);
 $558 = Math_fround($532 * $530);
 $559 = Math_fround($551 - $555);
 $560 = Math_fround($552 - $556);
 $561 = Math_fround($553 - $557);
 $562 = Math_fround($554 - $558);
 $563 = Math_fround($561 * Math_fround(-1.0));
 $564 = Math_fround($562 * Math_fround(-1.0));
 $565 = Math_fround($559 * Math_fround(-1.0));
 $566 = ((($39) + (($12*88)|0)|0) + 4|0);
 $567 = Math_fround(HEAPF32[$566>>2]);
 $568 = Math_fround($567 * $563);
 $569 = ((($39) + (($12*88)|0)|0) + 12|0);
 $570 = Math_fround(HEAPF32[$569>>2]);
 $571 = Math_fround($570 * $560);
 $572 = ((($39) + (($12*88)|0)|0) + 8|0);
 $573 = Math_fround(HEAPF32[$572>>2]);
 $574 = Math_fround($573 * $564);
 $575 = (($39) + (($12*88)|0)|0);
 $576 = Math_fround(HEAPF32[$575>>2]);
 $577 = Math_fround($576 * $565);
 $578 = Math_fround($570 * $565);
 $579 = Math_fround($576 * $563);
 $580 = Math_fround($567 * $565);
 $581 = Math_fround($573 * $563);
 $582 = Math_fround($568 - $578);
 $583 = Math_fround($571 - $579);
 $584 = Math_fround($574 - $580);
 $585 = Math_fround($577 - $581);
 $586 = Math_fround($573 * $560);
 $587 = Math_fround($573 * $565);
 $588 = Math_fround($570 * $563);
 $589 = Math_fround($570 * $564);
 $590 = Math_fround($582 - $586);
 $591 = Math_fround($583 - $587);
 $592 = Math_fround($584 - $588);
 $593 = Math_fround($585 - $589);
 $594 = Math_fround($576 * $564);
 $595 = Math_fround($567 * $564);
 $596 = Math_fround($576 * $560);
 $597 = Math_fround($567 * $560);
 $598 = Math_fround($590 - $594);
 $599 = Math_fround($591 - $595);
 $600 = Math_fround($592 - $596);
 $601 = Math_fround($593 - $597);
 $602 = Math_fround($600 * Math_fround(-1.0));
 $603 = Math_fround($601 * Math_fround(-1.0));
 $604 = Math_fround($598 * Math_fround(-1.0));
 $605 = Math_fround($602 * $602);
 $606 = Math_fround($603 * $603);
 $607 = Math_fround($604 * $604);
 $608 = Math_fround($599 * $599);
 $609 = Math_fround($606 + $605);
 $610 = Math_fround($608 + $607);
 $611 = Math_fround($610 + $609);
 $612 = (Math_fround(Math_sqrt((Math_fround($611)))));
 $613 = Math_fround(Math_fround(1.0) / $612);
 $614 = Math_fround($613 * $602);
 $615 = Math_fround($613 * $603);
 $616 = Math_fround($613 * $604);
 $617 = Math_fround($613 * $599);
 $618 = ($12|0)!=(-1);
 $$v = $618 ? $614 : $32;
 $$v13 = $618 ? $615 : $33;
 $$v14 = $618 ? $616 : $34;
 $$v15 = $618 ? $617 : $31;
 $619 = ((($17) + (($aIndex*48)|0)|0) + 16|0);
 HEAPF32[$619>>2] = $$v;
 $620 = ((($17) + (($aIndex*48)|0)|0) + 20|0);
 HEAPF32[$620>>2] = $$v13;
 $621 = ((($17) + (($aIndex*48)|0)|0) + 24|0);
 HEAPF32[$621>>2] = $$v14;
 $622 = ((($17) + (($aIndex*48)|0)|0) + 28|0);
 HEAPF32[$622>>2] = $$v15;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton13SkeletonAlignEPKNS0_8SkeletonERKN4math7_float4ES7_i($apSkeleton,$arRefQ,$arQ,$aIndex) {
 $apSkeleton = $apSkeleton|0;
 $arRefQ = $arRefQ|0;
 $arQ = $arQ|0;
 $aIndex = $aIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0;
 var $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apSkeleton) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = ((($4) + ($aIndex<<3)|0) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(-1);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($apSkeleton) + 24|0);
 $9 = $8;
 $10 = HEAP32[$8>>2]|0;
 $11 = (($10) + ($9))|0;
 $12 = $11;
 $13 = ((($12) + (($6*88)|0)|0) + 16|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = ((($12) + (($6*88)|0)|0) + 20|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = ((($12) + (($6*88)|0)|0) + 24|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = ((($12) + (($6*88)|0)|0) + 28|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = (($arRefQ) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($14 * $22);
 $24 = (($arRefQ) + 12|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($20 * $25);
 $27 = (($arRefQ) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($16 * $28);
 $30 = Math_fround(HEAPF32[$arRefQ>>2]);
 $31 = Math_fround($18 * $30);
 $32 = Math_fround($18 * $25);
 $33 = Math_fround($14 * $30);
 $34 = Math_fround($18 * $22);
 $35 = Math_fround($14 * $28);
 $36 = Math_fround($23 - $32);
 $37 = Math_fround($26 - $33);
 $38 = Math_fround($29 - $34);
 $39 = Math_fround($31 - $35);
 $40 = Math_fround($20 * $28);
 $41 = Math_fround($18 * $28);
 $42 = Math_fround($14 * $25);
 $43 = Math_fround($16 * $25);
 $44 = Math_fround($36 - $40);
 $45 = Math_fround($37 - $41);
 $46 = Math_fround($38 - $42);
 $47 = Math_fround($39 - $43);
 $48 = Math_fround($16 * $30);
 $49 = Math_fround($16 * $22);
 $50 = Math_fround($20 * $30);
 $51 = Math_fround($20 * $22);
 $52 = Math_fround($44 - $48);
 $53 = Math_fround($45 - $49);
 $54 = Math_fround($46 - $50);
 $55 = Math_fround($47 - $51);
 $56 = Math_fround($54 * Math_fround(-1.0));
 $57 = Math_fround($55 * Math_fround(-1.0));
 $58 = Math_fround($52 * Math_fround(-1.0));
 $59 = Math_fround($56 * $56);
 $60 = Math_fround($57 * $57);
 $61 = Math_fround($58 * $58);
 $62 = Math_fround($53 * $53);
 $63 = Math_fround($59 + $60);
 $64 = Math_fround($61 + $62);
 $65 = Math_fround($64 + $63);
 $66 = (Math_fround(Math_sqrt((Math_fround($65)))));
 $67 = Math_fround(Math_fround(1.0) / $66);
 $68 = Math_fround($67 * $56);
 $69 = Math_fround($67 * $57);
 $70 = Math_fround($67 * $58);
 $71 = Math_fround($67 * $53);
 $72 = Math_fround($71 * $68);
 $73 = Math_fround($71 * $69);
 $74 = Math_fround($70 * $71);
 $75 = Math_fround($71 * $71);
 $76 = Math_fround($75 + Math_fround(-0.5));
 $77 = Math_fround($68 * $68);
 $78 = Math_fround($68 * $69);
 $79 = Math_fround($70 * $68);
 $80 = Math_fround($73 * Math_fround(-1.0));
 $81 = Math_fround($72 * Math_fround(-1.0));
 $82 = Math_fround($77 + $76);
 $83 = Math_fround($74 + $78);
 $84 = Math_fround($79 + $80);
 $85 = Math_fround($72 + $81);
 $86 = Math_fround($82 + $82);
 $87 = Math_fround($83 + $83);
 $88 = Math_fround($84 + $84);
 $89 = Math_fround($85 + $85);
 $90 = (($arQ) + 4|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($14 * $91);
 $93 = (($arQ) + 12|0);
 $94 = Math_fround(HEAPF32[$93>>2]);
 $95 = Math_fround($20 * $94);
 $96 = (($arQ) + 8|0);
 $97 = Math_fround(HEAPF32[$96>>2]);
 $98 = Math_fround($16 * $97);
 $99 = Math_fround(HEAPF32[$arQ>>2]);
 $100 = Math_fround($18 * $99);
 $101 = Math_fround($18 * $94);
 $102 = Math_fround($14 * $99);
 $103 = Math_fround($18 * $91);
 $104 = Math_fround($14 * $97);
 $105 = Math_fround($92 - $101);
 $106 = Math_fround($95 - $102);
 $107 = Math_fround($98 - $103);
 $108 = Math_fround($100 - $104);
 $109 = Math_fround($20 * $97);
 $110 = Math_fround($18 * $97);
 $111 = Math_fround($14 * $94);
 $112 = Math_fround($16 * $94);
 $113 = Math_fround($105 - $109);
 $114 = Math_fround($106 - $110);
 $115 = Math_fround($107 - $111);
 $116 = Math_fround($108 - $112);
 $117 = Math_fround($16 * $99);
 $118 = Math_fround($16 * $91);
 $119 = Math_fround($20 * $99);
 $120 = Math_fround($20 * $91);
 $121 = Math_fround($113 - $117);
 $122 = Math_fround($114 - $118);
 $123 = Math_fround($115 - $119);
 $124 = Math_fround($116 - $120);
 $125 = Math_fround($123 * Math_fround(-1.0));
 $126 = Math_fround($124 * Math_fround(-1.0));
 $127 = Math_fround($121 * Math_fround(-1.0));
 $128 = Math_fround($125 * $125);
 $129 = Math_fround($126 * $126);
 $130 = Math_fround($127 * $127);
 $131 = Math_fround($122 * $122);
 $132 = Math_fround($128 + $129);
 $133 = Math_fround($130 + $131);
 $134 = Math_fround($133 + $132);
 $135 = (Math_fround(Math_sqrt((Math_fround($134)))));
 $136 = Math_fround(Math_fround(1.0) / $135);
 $137 = Math_fround($136 * $125);
 $138 = Math_fround($136 * $126);
 $139 = Math_fround($136 * $127);
 $140 = Math_fround($136 * $122);
 $141 = Math_fround($140 * $137);
 $142 = Math_fround($140 * $138);
 $143 = Math_fround($139 * $140);
 $144 = Math_fround($140 * $140);
 $145 = Math_fround($144 + Math_fround(-0.5));
 $146 = Math_fround($137 * $137);
 $147 = Math_fround($137 * $138);
 $148 = Math_fround($139 * $137);
 $149 = Math_fround($142 * Math_fround(-1.0));
 $150 = Math_fround($141 * Math_fround(-1.0));
 $151 = Math_fround($146 + $145);
 $152 = Math_fround($143 + $147);
 $153 = Math_fround($148 + $149);
 $154 = Math_fround($141 + $150);
 $155 = Math_fround($151 + $151);
 $156 = Math_fround($152 + $152);
 $157 = Math_fround($153 + $153);
 $158 = Math_fround($154 + $154);
 $159 = Math_fround($87 * $155);
 $160 = Math_fround($88 * $156);
 $161 = Math_fround($86 * $157);
 $162 = Math_fround($89 * $158);
 $163 = Math_fround($86 * $156);
 $164 = Math_fround($87 * $157);
 $165 = Math_fround($88 * $155);
 $166 = Math_fround($159 - $163);
 $167 = Math_fround($160 - $164);
 $168 = Math_fround($161 - $165);
 $169 = Math_fround($86 * $155);
 $170 = Math_fround($87 * $156);
 $171 = Math_fround($88 * $157);
 $172 = Math_fround($169 + $170);
 $173 = Math_fround($162 + $171);
 $174 = Math_fround($172 + $173);
 $175 = Math_fround($155 * $155);
 $176 = Math_fround($156 * $156);
 $177 = Math_fround($157 * $157);
 $178 = Math_fround($158 * $158);
 $179 = Math_fround($175 + $176);
 $180 = Math_fround($178 + $177);
 $181 = Math_fround($179 + $180);
 $182 = Math_fround($86 * $86);
 $183 = Math_fround($87 * $87);
 $184 = Math_fround($88 * $88);
 $185 = Math_fround($89 * $89);
 $186 = Math_fround($182 + $183);
 $187 = Math_fround($185 + $184);
 $188 = Math_fround($186 + $187);
 $189 = Math_fround($188 * $181);
 $190 = (Math_fround(Math_sqrt((Math_fround($189)))));
 $191 = Math_fround($190 + $174);
 $192 = Math_fround($99 * $168);
 $193 = Math_fround($94 * $191);
 $194 = Math_fround($91 * $166);
 $195 = Math_fround($97 * $167);
 $196 = Math_fround($97 * $191);
 $197 = Math_fround($99 * $167);
 $198 = Math_fround($97 * $168);
 $199 = Math_fround($99 * $166);
 $200 = Math_fround($192 - $196);
 $201 = Math_fround($193 - $197);
 $202 = Math_fround($194 - $198);
 $203 = Math_fround($195 - $199);
 $204 = Math_fround($94 * $166);
 $205 = Math_fround($97 * $166);
 $206 = Math_fround($99 * $191);
 $207 = Math_fround($91 * $191);
 $208 = Math_fround($200 - $204);
 $209 = Math_fround($201 - $205);
 $210 = Math_fround($202 - $206);
 $211 = Math_fround($203 - $207);
 $212 = Math_fround($91 * $167);
 $213 = Math_fround($91 * $168);
 $214 = Math_fround($94 * $167);
 $215 = Math_fround($94 * $168);
 $216 = Math_fround($208 - $212);
 $217 = Math_fround($209 - $213);
 $218 = Math_fround($210 - $214);
 $219 = Math_fround($211 - $215);
 $220 = Math_fround($218 * Math_fround(-1.0));
 $221 = Math_fround($219 * Math_fround(-1.0));
 $222 = Math_fround($216 * Math_fround(-1.0));
 $223 = Math_fround($220 * $220);
 $224 = Math_fround($221 * $221);
 $225 = Math_fround($222 * $222);
 $226 = Math_fround($217 * $217);
 $227 = Math_fround($223 + $224);
 $228 = Math_fround($226 + $225);
 $229 = Math_fround($227 + $228);
 $230 = (Math_fround(Math_sqrt((Math_fround($229)))));
 $231 = Math_fround(Math_fround(1.0) / $230);
 $232 = Math_fround($231 * $220);
 $233 = Math_fround($231 * $221);
 $234 = Math_fround($231 * $222);
 $235 = Math_fround($231 * $217);
 HEAPF32[$arQ>>2] = $232;
 HEAPF32[$90>>2] = $233;
 HEAPF32[$96>>2] = $234;
 HEAPF32[$93>>2] = $235;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton25Skeleton2BoneAdjustLengthEPKNS0_8SkeletonEiiiRKN4math7_float4ERKfPNS0_12SkeletonPoseESB_($apSkeleton,$aIndexA,$aIndexB,$aIndexC,$aTarget,$aRatio,$apSkeletonPose,$apSkeletonPoseWorkspace) {
 $apSkeleton = $apSkeleton|0;
 $aIndexA = $aIndexA|0;
 $aIndexB = $aIndexB|0;
 $aIndexC = $aIndexC|0;
 $aTarget = $aTarget|0;
 $aRatio = $aRatio|0;
 $apSkeletonPose = $apSkeletonPose|0;
 $apSkeletonPoseWorkspace = $apSkeletonPoseWorkspace|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0;
 var $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0);
 var $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0);
 var $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apSkeletonPoseWorkspace) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($apSkeletonPoseWorkspace) + 8|0);
 $6 = (($4) + (($aIndexB*48)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($4) + (($aIndexA*48)|0)|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($7 - $9);
 $11 = ((($4) + (($aIndexB*48)|0)|0) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = ((($4) + (($aIndexA*48)|0)|0) + 4|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = Math_fround($12 - $14);
 $16 = ((($4) + (($aIndexB*48)|0)|0) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = ((($4) + (($aIndexA*48)|0)|0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 - $19);
 $21 = ((($4) + (($aIndexB*48)|0)|0) + 12|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = ((($4) + (($aIndexA*48)|0)|0) + 12|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 - $24);
 $26 = (($4) + (($aIndexC*48)|0)|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 - $7);
 $29 = ((($4) + (($aIndexC*48)|0)|0) + 4|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 - $12);
 $32 = ((($4) + (($aIndexC*48)|0)|0) + 8|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 - $17);
 $35 = ((($4) + (($aIndexC*48)|0)|0) + 12|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = Math_fround($36 - $22);
 HEAP32[$5>>2] = $4;
 $38 = Math_fround(HEAPF32[$aTarget>>2]);
 $39 = Math_fround($38 - $9);
 $40 = (($aTarget) + 4|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 - $14);
 $43 = (($aTarget) + 8|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = Math_fround($44 - $19);
 $46 = (($aTarget) + 12|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($47 - $24);
 $49 = Math_fround($10 * $10);
 $50 = Math_fround($15 * $15);
 $51 = Math_fround($20 * $20);
 $52 = Math_fround($25 * $25);
 $53 = Math_fround($49 + $50);
 $54 = Math_fround($51 + $52);
 $55 = Math_fround($53 + $54);
 $56 = (Math_fround(Math_sqrt((Math_fround($55)))));
 $57 = Math_fround($28 * $28);
 $58 = Math_fround($31 * $31);
 $59 = Math_fround($34 * $34);
 $60 = Math_fround($37 * $37);
 $61 = Math_fround($57 + $58);
 $62 = Math_fround($59 + $60);
 $63 = Math_fround($61 + $62);
 $64 = (Math_fround(Math_sqrt((Math_fround($63)))));
 $65 = Math_fround($56 + $64);
 $66 = Math_fround($39 * $39);
 $67 = Math_fround($42 * $42);
 $68 = Math_fround($45 * $45);
 $69 = Math_fround($48 * $48);
 $70 = Math_fround($66 + $67);
 $71 = Math_fround($68 + $69);
 $72 = Math_fround($70 + $71);
 $73 = (Math_fround(Math_sqrt((Math_fround($72)))));
 $74 = Math_fround($73 / $65);
 $75 = Math_fround(HEAPF32[$aRatio>>2]);
 $76 = Math_fround(Math_fround(1.0) - $75);
 $77 = $74 > $76;
 if (!($77)) {
  STACKTOP = sp;return;
 }
 $78 = Math_fround($74 - $76);
 $79 = Math_fround($75 * Math_fround(2.0));
 $80 = Math_fround($78 / $79);
 $81 = (Math_fround(+(_fmaxf(0.0,(+$80)))));
 $82 = (Math_fround(+(_fminf(1.0,(+$81)))));
 $83 = Math_fround($75 * $82);
 $84 = Math_fround($82 * $83);
 $85 = Math_fround($84 + Math_fround(1.0));
 $86 = (($apSkeletonPose) + 4|0);
 $87 = $86;
 $88 = HEAP32[$86>>2]|0;
 $89 = (($88) + ($87))|0;
 $90 = $89;
 $91 = (($apSkeletonPose) + 8|0);
 $92 = (($90) + (($aIndexB*48)|0)|0);
 $93 = Math_fround(HEAPF32[$92>>2]);
 $94 = Math_fround($93 * $85);
 $95 = ((($90) + (($aIndexB*48)|0)|0) + 4|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = Math_fround($96 * $85);
 $98 = ((($90) + (($aIndexB*48)|0)|0) + 8|0);
 $99 = Math_fround(HEAPF32[$98>>2]);
 $100 = Math_fround($85 * $99);
 $101 = ((($90) + (($aIndexB*48)|0)|0) + 12|0);
 $102 = Math_fround(HEAPF32[$101>>2]);
 $103 = Math_fround($85 * $102);
 HEAPF32[$92>>2] = $94;
 HEAPF32[$95>>2] = $97;
 HEAPF32[$98>>2] = $100;
 HEAPF32[$101>>2] = $103;
 HEAP32[$91>>2] = $90;
 $104 = (($90) + (($aIndexC*48)|0)|0);
 $105 = Math_fround(HEAPF32[$104>>2]);
 $106 = Math_fround($85 * $105);
 $107 = ((($90) + (($aIndexC*48)|0)|0) + 4|0);
 $108 = Math_fround(HEAPF32[$107>>2]);
 $109 = Math_fround($85 * $108);
 $110 = ((($90) + (($aIndexC*48)|0)|0) + 8|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($85 * $111);
 $113 = ((($90) + (($aIndexC*48)|0)|0) + 12|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround($85 * $114);
 HEAPF32[$104>>2] = $106;
 HEAPF32[$107>>2] = $109;
 HEAPF32[$110>>2] = $112;
 HEAPF32[$113>>2] = $115;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton15Skeleton2BoneIKEPKNS0_8SkeletonEiiiRKN4math7_float4EfPNS0_12SkeletonPoseES9_($apSkeleton,$aIndexA,$aIndexB,$aIndexC,$aTarget,$aWeight,$apSkeletonPose,$apSkeletonPoseWorkspace) {
 $apSkeleton = $apSkeleton|0;
 $aIndexA = $aIndexA|0;
 $aIndexB = $aIndexB|0;
 $aIndexC = $aIndexC|0;
 $aTarget = $aTarget|0;
 $aWeight = Math_fround($aWeight);
 $apSkeletonPose = $apSkeletonPose|0;
 $apSkeletonPoseWorkspace = $apSkeletonPoseWorkspace|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = 0, $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0);
 var $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = Math_fround(0), $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = Math_fround(0), $258 = Math_fround(0), $259 = 0, $26 = Math_fround(0);
 var $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = Math_fround(0);
 var $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = Math_fround(0), $288 = Math_fround(0), $289 = Math_fround(0), $29 = Math_fround(0), $290 = Math_fround(0), $291 = Math_fround(0), $292 = Math_fround(0), $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0);
 var $297 = Math_fround(0), $298 = Math_fround(0), $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = Math_fround(0), $308 = Math_fround(0), $309 = Math_fround(0), $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0), $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = Math_fround(0), $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0);
 var $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0), $347 = Math_fround(0), $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0;
 var $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = Math_fround(0), $365 = Math_fround(0), $366 = Math_fround(0), $367 = Math_fround(0), $368 = Math_fround(0);
 var $369 = Math_fround(0), $37 = 0, $370 = Math_fround(0), $371 = Math_fround(0), $372 = 0, $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0), $383 = Math_fround(0), $384 = Math_fround(0), $385 = Math_fround(0), $386 = Math_fround(0);
 var $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = Math_fround(0), $393 = Math_fround(0), $394 = Math_fround(0), $395 = Math_fround(0), $396 = Math_fround(0), $397 = Math_fround(0), $398 = Math_fround(0), $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = Math_fround(0), $401 = Math_fround(0), $402 = Math_fround(0), $403 = Math_fround(0);
 var $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = Math_fround(0), $408 = Math_fround(0), $409 = Math_fround(0), $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = Math_fround(0), $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0);
 var $422 = Math_fround(0), $423 = Math_fround(0), $424 = 0, $425 = 0, $426 = 0, $427 = Math_fround(0), $428 = Math_fround(0), $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = Math_fround(0), $436 = Math_fround(0), $437 = 0, $438 = Math_fround(0), $439 = Math_fround(0), $44 = 0;
 var $440 = 0, $441 = Math_fround(0), $442 = Math_fround(0), $443 = Math_fround(0), $444 = Math_fround(0), $445 = Math_fround(0), $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = Math_fround(0), $451 = 0, $452 = 0, $453 = Math_fround(0), $454 = 0, $455 = 0, $456 = Math_fround(0), $457 = 0, $458 = 0;
 var $459 = Math_fround(0), $46 = Math_fround(0), $460 = Math_fround(0), $461 = Math_fround(0), $462 = Math_fround(0), $463 = Math_fround(0), $464 = Math_fround(0), $465 = Math_fround(0), $466 = Math_fround(0), $467 = Math_fround(0), $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = Math_fround(0), $471 = Math_fround(0), $472 = Math_fround(0), $473 = Math_fround(0), $474 = Math_fround(0), $475 = Math_fround(0), $476 = Math_fround(0);
 var $477 = Math_fround(0), $478 = Math_fround(0), $479 = Math_fround(0), $48 = Math_fround(0), $480 = Math_fround(0), $481 = Math_fround(0), $482 = Math_fround(0), $483 = Math_fround(0), $484 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0);
 var $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0);
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $dof = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $dof = sp + 16|0;
 $0 = sp;
 $1 = (($apSkeletonPose) + 4|0);
 $2 = $1;
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + ($2))|0;
 $5 = $4;
 $6 = (($apSkeletonPose) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = ((($5) + (($aIndexA*48)|0)|0) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = ((($5) + (($aIndexA*48)|0)|0) + 20|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = ((($5) + (($aIndexA*48)|0)|0) + 24|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = ((($5) + (($aIndexA*48)|0)|0) + 28|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 HEAP32[$6>>2] = $5;
 $15 = ((($5) + (($aIndexB*48)|0)|0) + 16|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = ((($5) + (($aIndexB*48)|0)|0) + 20|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = ((($5) + (($aIndexB*48)|0)|0) + 24|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = ((($5) + (($aIndexB*48)|0)|0) + 28|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 __ZN7mecanim8skeleton14SkeletonGetDoFEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEi($0,$apSkeleton,$apSkeletonPose,$aIndexB);
 $23 = Math_fround(HEAPF32[$0>>2]);
 $24 = (($0) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * Math_fround(0.0));
 $27 = (($0) + 8|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = Math_fround($28 * Math_fround(0.899999976158142089843));
 $30 = (($0) + 12|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 $32 = Math_fround($31 * Math_fround(0.0));
 HEAPF32[$dof>>2] = $23;
 $33 = (($dof) + 4|0);
 HEAPF32[$33>>2] = $26;
 $34 = (($dof) + 8|0);
 HEAPF32[$34>>2] = $29;
 $35 = (($dof) + 12|0);
 HEAPF32[$35>>2] = $32;
 __ZN7mecanim8skeleton14SkeletonSetDoFEPKNS0_8SkeletonEPNS0_12SkeletonPoseERKN4math7_float4Ei($apSkeleton,$apSkeletonPose,$dof,$aIndexB);
 __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPose,$apSkeletonPoseWorkspace,$aIndexC,$aIndexB);
 $36 = (($apSkeletonPoseWorkspace) + 4|0);
 $37 = $36;
 $38 = HEAP32[$36>>2]|0;
 $39 = (($38) + ($37))|0;
 $40 = $39;
 $41 = (($apSkeletonPoseWorkspace) + 8|0);
 $42 = (($40) + (($aIndexB*48)|0)|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = (($40) + (($aIndexA*48)|0)|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($43 - $45);
 $47 = ((($40) + (($aIndexB*48)|0)|0) + 4|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = ((($40) + (($aIndexA*48)|0)|0) + 4|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($48 - $50);
 $52 = ((($40) + (($aIndexB*48)|0)|0) + 8|0);
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = ((($40) + (($aIndexA*48)|0)|0) + 8|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($53 - $55);
 $57 = ((($40) + (($aIndexB*48)|0)|0) + 12|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = ((($40) + (($aIndexA*48)|0)|0) + 12|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($58 - $60);
 $62 = (($40) + (($aIndexC*48)|0)|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($63 - $43);
 $65 = ((($40) + (($aIndexC*48)|0)|0) + 4|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($66 - $48);
 $68 = ((($40) + (($aIndexC*48)|0)|0) + 8|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($69 - $53);
 $71 = ((($40) + (($aIndexC*48)|0)|0) + 12|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = Math_fround($72 - $58);
 $74 = Math_fround($63 - $45);
 $75 = Math_fround($66 - $50);
 $76 = Math_fround($69 - $55);
 $77 = Math_fround($72 - $60);
 HEAP32[$41>>2] = $40;
 $78 = Math_fround(HEAPF32[$aTarget>>2]);
 $79 = Math_fround($78 - $45);
 $80 = (($aTarget) + 4|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 - $50);
 $83 = (($aTarget) + 8|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = Math_fround($84 - $55);
 $86 = (($aTarget) + 12|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($87 - $60);
 $89 = Math_fround($46 * $46);
 $90 = Math_fround($51 * $51);
 $91 = Math_fround($56 * $56);
 $92 = Math_fround($61 * $61);
 $93 = Math_fround($89 + $90);
 $94 = Math_fround($91 + $92);
 $95 = Math_fround($93 + $94);
 $96 = (Math_fround(Math_sqrt((Math_fround($95)))));
 $97 = Math_fround($64 * $64);
 $98 = Math_fround($67 * $67);
 $99 = Math_fround($70 * $70);
 $100 = Math_fround($73 * $73);
 $101 = Math_fround($97 + $98);
 $102 = Math_fround($99 + $100);
 $103 = Math_fround($101 + $102);
 $104 = (Math_fround(Math_sqrt((Math_fround($103)))));
 $105 = Math_fround($74 * $74);
 $106 = Math_fround($75 * $75);
 $107 = Math_fround($76 * $76);
 $108 = Math_fround($77 * $77);
 $109 = Math_fround($105 + $106);
 $110 = Math_fround($107 + $108);
 $111 = Math_fround($109 + $110);
 $112 = (Math_fround(Math_sqrt((Math_fround($111)))));
 $113 = Math_fround($79 * $79);
 $114 = Math_fround($82 * $82);
 $115 = Math_fround($85 * $85);
 $116 = Math_fround($88 * $88);
 $117 = Math_fround($113 + $114);
 $118 = Math_fround($115 + $116);
 $119 = Math_fround($117 + $118);
 $120 = (Math_fround(Math_sqrt((Math_fround($119)))));
 $121 = Math_fround($96 * $96);
 $122 = Math_fround($104 * $104);
 $123 = Math_fround($121 + $122);
 $124 = Math_fround($112 * $112);
 $125 = Math_fround($123 - $124);
 $126 = Math_fround($96 * $104);
 $127 = Math_fround($125 / $126);
 $128 = Math_fround($127 * Math_fround(0.5));
 $129 = (Math_fround(+(_fmaxf((+$128),-1.0))));
 $130 = (Math_fround(+(_fminf((+$129),1.0))));
 $131 = (Math_fround(+(Math_acos((+$130)))));
 $132 = Math_fround($120 * $120);
 $133 = Math_fround($123 - $132);
 $134 = Math_fround($133 / $126);
 $135 = Math_fround($134 * Math_fround(0.5));
 $136 = (Math_fround(+(_fmaxf((+$135),-1.0))));
 $137 = (Math_fround(+(_fminf((+$136),1.0))));
 $138 = (Math_fround(+(Math_acos((+$137)))));
 $139 = Math_fround($46 * $67);
 $140 = Math_fround($51 * $70);
 $141 = Math_fround($56 * $64);
 $142 = Math_fround($61 * $73);
 $143 = Math_fround($51 * $64);
 $144 = Math_fround($56 * $67);
 $145 = Math_fround($46 * $70);
 $146 = Math_fround($139 - $143);
 $147 = Math_fround($140 - $144);
 $148 = Math_fround($141 - $145);
 $149 = Math_fround($142 - $142);
 $150 = Math_fround($147 * $147);
 $151 = Math_fround($148 * $148);
 $152 = Math_fround($146 * $146);
 $153 = Math_fround($149 * $149);
 $154 = Math_fround($150 + $151);
 $155 = Math_fround($152 + $153);
 $156 = Math_fround($154 + $155);
 $157 = (Math_fround(Math_sqrt((Math_fround($156)))));
 $158 = Math_fround(Math_fround(1.0) / $157);
 $159 = Math_fround($147 * $158);
 $160 = Math_fround($148 * $158);
 $161 = Math_fround($146 * $158);
 $162 = Math_fround($149 * $158);
 $163 = Math_fround($131 - $138);
 $164 = Math_fround($163 * Math_fround(0.5));
 $165 = Math_fround($159 + Math_fround(0.0));
 $166 = Math_fround($160 + Math_fround(0.0));
 $167 = Math_fround($161 + Math_fround(0.0));
 $168 = Math_fround($162 + Math_fround(1.0));
 $169 = Math_fround($164 * Math_fround(0.159154936671257019043));
 $170 = Math_fround($169 + Math_fround(-0.25));
 $171 = Math_fround($169 + Math_fround(0.0));
 $172 = (Math_fround(+(_roundf((+$170)))));
 $173 = (Math_fround(+(_roundf((+$171)))));
 $174 = Math_fround($170 - $172);
 $175 = Math_fround($171 - $173);
 $176 = (Math_fround(Math_abs((Math_fround($174)))));
 $177 = (Math_fround(Math_abs((Math_fround($175)))));
 $178 = Math_fround(Math_fround(0.25) - $176);
 $179 = Math_fround(Math_fround(0.25) - $177);
 $180 = Math_fround($178 * $178);
 $181 = Math_fround($179 * $179);
 $182 = Math_fround($180 * $180);
 $183 = Math_fround($181 * $181);
 $184 = Math_fround($180 * Math_fround(-41.283184051513671875));
 $185 = Math_fround($181 * Math_fround(-41.283184051513671875));
 $186 = Math_fround($184 + Math_fround(6.28318548202514648438));
 $187 = Math_fround($185 + Math_fround(6.28318548202514648438));
 $188 = Math_fround($182 * Math_fround(76.03546142578125));
 $189 = Math_fround($183 * Math_fround(76.03546142578125));
 $190 = Math_fround($186 + $188);
 $191 = Math_fround($187 + $189);
 $192 = Math_fround($178 * $190);
 $193 = Math_fround($179 * $191);
 $194 = Math_fround($165 * $192);
 $195 = Math_fround($166 * $192);
 $196 = Math_fround($167 * $192);
 $197 = Math_fround($168 * $193);
 $198 = HEAP32[$36>>2]|0;
 $199 = (($198) + ($37))|0;
 $200 = $199;
 HEAP32[$41>>2] = $200;
 $201 = ((($200) + (($aIndexB*48)|0)|0) + 16|0);
 $202 = Math_fround(HEAPF32[$201>>2]);
 $203 = Math_fround($202 * $195);
 $204 = ((($200) + (($aIndexB*48)|0)|0) + 28|0);
 $205 = Math_fround(HEAPF32[$204>>2]);
 $206 = Math_fround($205 * $197);
 $207 = ((($200) + (($aIndexB*48)|0)|0) + 20|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = Math_fround($208 * $196);
 $210 = ((($200) + (($aIndexB*48)|0)|0) + 24|0);
 $211 = Math_fround(HEAPF32[$210>>2]);
 $212 = Math_fround($194 * $211);
 $213 = Math_fround($211 * $197);
 $214 = Math_fround($202 * $194);
 $215 = Math_fround($211 * $195);
 $216 = Math_fround($202 * $196);
 $217 = Math_fround($203 - $213);
 $218 = Math_fround($206 - $214);
 $219 = Math_fround($209 - $215);
 $220 = Math_fround($212 - $216);
 $221 = Math_fround($205 * $196);
 $222 = Math_fround($196 * $211);
 $223 = Math_fround($202 * $197);
 $224 = Math_fround($208 * $197);
 $225 = Math_fround($217 - $221);
 $226 = Math_fround($218 - $222);
 $227 = Math_fround($219 - $223);
 $228 = Math_fround($220 - $224);
 $229 = Math_fround($208 * $194);
 $230 = Math_fround($208 * $195);
 $231 = Math_fround($205 * $194);
 $232 = Math_fround($205 * $195);
 $233 = Math_fround($225 - $229);
 $234 = Math_fround($226 - $230);
 $235 = Math_fround($227 - $231);
 $236 = Math_fround($228 - $232);
 $237 = Math_fround($235 * Math_fround(-1.0));
 $238 = Math_fround($236 * Math_fround(-1.0));
 $239 = Math_fround($233 * Math_fround(-1.0));
 $240 = Math_fround($237 * $237);
 $241 = Math_fround($238 * $238);
 $242 = Math_fround($239 * $239);
 $243 = Math_fround($234 * $234);
 $244 = Math_fround($240 + $241);
 $245 = Math_fround($243 + $242);
 $246 = Math_fround($244 + $245);
 $247 = (Math_fround(Math_sqrt((Math_fround($246)))));
 $248 = Math_fround(Math_fround(1.0) / $247);
 $249 = Math_fround($248 * $237);
 $250 = Math_fround($248 * $238);
 $251 = Math_fround($248 * $239);
 $252 = Math_fround($248 * $234);
 HEAPF32[$201>>2] = $249;
 HEAPF32[$207>>2] = $250;
 HEAPF32[$210>>2] = $251;
 HEAPF32[$204>>2] = $252;
 __ZN7mecanim8skeleton24SkeletonPoseComputeLocalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseWorkspace,$apSkeletonPose,$aIndexB,$aIndexB);
 $253 = HEAP32[$1>>2]|0;
 $254 = (($253) + ($2))|0;
 $255 = $254;
 HEAP32[$6>>2] = $255;
 $256 = ((($255) + (($aIndexB*48)|0)|0) + 16|0);
 $257 = Math_fround(HEAPF32[$256>>2]);
 $258 = Math_fround($16 * $257);
 $259 = ((($255) + (($aIndexB*48)|0)|0) + 20|0);
 $260 = Math_fround(HEAPF32[$259>>2]);
 $261 = Math_fround($18 * $260);
 $262 = ((($255) + (($aIndexB*48)|0)|0) + 24|0);
 $263 = Math_fround(HEAPF32[$262>>2]);
 $264 = Math_fround($20 * $263);
 $265 = ((($255) + (($aIndexB*48)|0)|0) + 28|0);
 $266 = Math_fround(HEAPF32[$265>>2]);
 $267 = Math_fround($22 * $266);
 $268 = Math_fround($258 + $261);
 $269 = Math_fround($264 + $267);
 $270 = Math_fround($268 + $269);
 $271 = (HEAPF32[tempDoublePtr>>2]=$257,HEAP32[tempDoublePtr>>2]|0);
 $272 = (HEAPF32[tempDoublePtr>>2]=$270,HEAP32[tempDoublePtr>>2]|0);
 $273 = $272 & -2147483648;
 $274 = $273 ^ $271;
 $275 = (HEAP32[tempDoublePtr>>2]=$274,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $276 = (HEAPF32[tempDoublePtr>>2]=$260,HEAP32[tempDoublePtr>>2]|0);
 $277 = $273 ^ $276;
 $278 = (HEAP32[tempDoublePtr>>2]=$277,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $279 = (HEAPF32[tempDoublePtr>>2]=$263,HEAP32[tempDoublePtr>>2]|0);
 $280 = $273 ^ $279;
 $281 = (HEAP32[tempDoublePtr>>2]=$280,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $282 = (HEAPF32[tempDoublePtr>>2]=$266,HEAP32[tempDoublePtr>>2]|0);
 $283 = $273 ^ $282;
 $284 = (HEAP32[tempDoublePtr>>2]=$283,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $285 = Math_fround($275 - $16);
 $286 = Math_fround($278 - $18);
 $287 = Math_fround($281 - $20);
 $288 = Math_fround($284 - $22);
 $289 = Math_fround($285 * $aWeight);
 $290 = Math_fround($286 * $aWeight);
 $291 = Math_fround($287 * $aWeight);
 $292 = Math_fround($288 * $aWeight);
 $293 = Math_fround($16 + $289);
 $294 = Math_fround($18 + $290);
 $295 = Math_fround($20 + $291);
 $296 = Math_fround($22 + $292);
 $297 = Math_fround($293 * $293);
 $298 = Math_fround($294 * $294);
 $299 = Math_fround($295 * $295);
 $300 = Math_fround($296 * $296);
 $301 = Math_fround($297 + $298);
 $302 = Math_fround($299 + $300);
 $303 = Math_fround($301 + $302);
 $304 = (Math_fround(Math_sqrt((Math_fround($303)))));
 $305 = Math_fround(Math_fround(1.0) / $304);
 $306 = Math_fround($305 * $293);
 $307 = Math_fround($305 * $294);
 $308 = Math_fround($305 * $295);
 $309 = Math_fround($305 * $296);
 HEAPF32[$256>>2] = $306;
 HEAPF32[$259>>2] = $307;
 HEAPF32[$262>>2] = $308;
 HEAPF32[$265>>2] = $309;
 __ZN7mecanim8skeleton25SkeletonPoseComputeGlobalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPose,$apSkeletonPoseWorkspace,$aIndexC,$aIndexB);
 $310 = HEAP32[$36>>2]|0;
 $311 = (($310) + ($37))|0;
 $312 = $311;
 $313 = (($312) + (($aIndexC*48)|0)|0);
 $314 = Math_fround(HEAPF32[$313>>2]);
 $315 = (($312) + (($aIndexA*48)|0)|0);
 $316 = Math_fround(HEAPF32[$315>>2]);
 $317 = Math_fround($314 - $316);
 $318 = ((($312) + (($aIndexC*48)|0)|0) + 4|0);
 $319 = Math_fround(HEAPF32[$318>>2]);
 $320 = ((($312) + (($aIndexA*48)|0)|0) + 4|0);
 $321 = Math_fround(HEAPF32[$320>>2]);
 $322 = Math_fround($319 - $321);
 $323 = ((($312) + (($aIndexC*48)|0)|0) + 8|0);
 $324 = Math_fround(HEAPF32[$323>>2]);
 $325 = ((($312) + (($aIndexA*48)|0)|0) + 8|0);
 $326 = Math_fround(HEAPF32[$325>>2]);
 $327 = Math_fround($324 - $326);
 $328 = ((($312) + (($aIndexC*48)|0)|0) + 12|0);
 $329 = Math_fround(HEAPF32[$328>>2]);
 $330 = ((($312) + (($aIndexA*48)|0)|0) + 12|0);
 $331 = Math_fround(HEAPF32[$330>>2]);
 $332 = Math_fround($329 - $331);
 $333 = Math_fround($82 * $317);
 $334 = Math_fround($85 * $322);
 $335 = Math_fround($79 * $327);
 $336 = Math_fround($88 * $332);
 $337 = Math_fround($79 * $322);
 $338 = Math_fround($82 * $327);
 $339 = Math_fround($85 * $317);
 $340 = Math_fround($333 - $337);
 $341 = Math_fround($334 - $338);
 $342 = Math_fround($335 - $339);
 $343 = Math_fround($79 * $317);
 $344 = Math_fround($82 * $322);
 $345 = Math_fround($85 * $327);
 $346 = Math_fround($343 + $344);
 $347 = Math_fround($345 + $336);
 $348 = Math_fround($346 + $347);
 $349 = Math_fround($317 * $317);
 $350 = Math_fround($322 * $322);
 $351 = Math_fround($327 * $327);
 $352 = Math_fround($332 * $332);
 $353 = Math_fround($349 + $350);
 $354 = Math_fround($351 + $352);
 $355 = Math_fround($353 + $354);
 $356 = Math_fround($119 * $355);
 $357 = (Math_fround(Math_sqrt((Math_fround($356)))));
 $358 = Math_fround($357 + $348);
 $359 = Math_fround($341 * $341);
 $360 = Math_fround($342 * $342);
 $361 = Math_fround($340 * $340);
 $362 = Math_fround($358 * $358);
 $363 = Math_fround($359 + $360);
 $364 = Math_fround($361 + $362);
 $365 = Math_fround($363 + $364);
 $366 = (Math_fround(Math_sqrt((Math_fround($365)))));
 $367 = Math_fround(Math_fround(1.0) / $366);
 $368 = Math_fround($341 * $367);
 $369 = Math_fround($342 * $367);
 $370 = Math_fround($340 * $367);
 $371 = Math_fround($367 * $358);
 HEAP32[$41>>2] = $312;
 $372 = ((($312) + (($aIndexA*48)|0)|0) + 16|0);
 $373 = Math_fround(HEAPF32[$372>>2]);
 $374 = Math_fround($369 * $373);
 $375 = ((($312) + (($aIndexA*48)|0)|0) + 28|0);
 $376 = Math_fround(HEAPF32[$375>>2]);
 $377 = Math_fround($371 * $376);
 $378 = ((($312) + (($aIndexA*48)|0)|0) + 20|0);
 $379 = Math_fround(HEAPF32[$378>>2]);
 $380 = Math_fround($370 * $379);
 $381 = ((($312) + (($aIndexA*48)|0)|0) + 24|0);
 $382 = Math_fround(HEAPF32[$381>>2]);
 $383 = Math_fround($368 * $382);
 $384 = Math_fround($371 * $382);
 $385 = Math_fround($368 * $373);
 $386 = Math_fround($369 * $382);
 $387 = Math_fround($370 * $373);
 $388 = Math_fround($374 - $384);
 $389 = Math_fround($377 - $385);
 $390 = Math_fround($380 - $386);
 $391 = Math_fround($383 - $387);
 $392 = Math_fround($370 * $376);
 $393 = Math_fround($370 * $382);
 $394 = Math_fround($371 * $373);
 $395 = Math_fround($371 * $379);
 $396 = Math_fround($388 - $392);
 $397 = Math_fround($389 - $393);
 $398 = Math_fround($390 - $394);
 $399 = Math_fround($391 - $395);
 $400 = Math_fround($368 * $379);
 $401 = Math_fround($369 * $379);
 $402 = Math_fround($368 * $376);
 $403 = Math_fround($369 * $376);
 $404 = Math_fround($396 - $400);
 $405 = Math_fround($397 - $401);
 $406 = Math_fround($398 - $402);
 $407 = Math_fround($399 - $403);
 $408 = Math_fround($406 * Math_fround(-1.0));
 $409 = Math_fround($407 * Math_fround(-1.0));
 $410 = Math_fround($404 * Math_fround(-1.0));
 $411 = Math_fround($408 * $408);
 $412 = Math_fround($409 * $409);
 $413 = Math_fround($410 * $410);
 $414 = Math_fround($405 * $405);
 $415 = Math_fround($411 + $412);
 $416 = Math_fround($414 + $413);
 $417 = Math_fround($415 + $416);
 $418 = (Math_fround(Math_sqrt((Math_fround($417)))));
 $419 = Math_fround(Math_fround(1.0) / $418);
 $420 = Math_fround($419 * $408);
 $421 = Math_fround($419 * $409);
 $422 = Math_fround($419 * $410);
 $423 = Math_fround($419 * $405);
 HEAPF32[$372>>2] = $420;
 HEAPF32[$378>>2] = $421;
 HEAPF32[$381>>2] = $422;
 HEAPF32[$375>>2] = $423;
 __ZN7mecanim8skeleton24SkeletonPoseComputeLocalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseWorkspace,$apSkeletonPose,$aIndexA,$aIndexA);
 $424 = HEAP32[$1>>2]|0;
 $425 = (($424) + ($2))|0;
 $426 = $425;
 HEAP32[$6>>2] = $426;
 $427 = Math_fround(Math_fround(1.0) - $aWeight);
 $428 = (Math_fround(+(_log2f((+$427)))));
 $429 = Math_fround($428 * Math_fround(4.0));
 $430 = (Math_fround(+(_exp2f((+$429)))));
 $431 = ((($426) + (($aIndexA*48)|0)|0) + 16|0);
 $432 = Math_fround(HEAPF32[$431>>2]);
 $433 = Math_fround($8 * $432);
 $434 = ((($426) + (($aIndexA*48)|0)|0) + 20|0);
 $435 = Math_fround(HEAPF32[$434>>2]);
 $436 = Math_fround($10 * $435);
 $437 = ((($426) + (($aIndexA*48)|0)|0) + 24|0);
 $438 = Math_fround(HEAPF32[$437>>2]);
 $439 = Math_fround($12 * $438);
 $440 = ((($426) + (($aIndexA*48)|0)|0) + 28|0);
 $441 = Math_fround(HEAPF32[$440>>2]);
 $442 = Math_fround($14 * $441);
 $443 = Math_fround($433 + $436);
 $444 = Math_fround($439 + $442);
 $445 = Math_fround($443 + $444);
 $446 = (HEAPF32[tempDoublePtr>>2]=$8,HEAP32[tempDoublePtr>>2]|0);
 $447 = (HEAPF32[tempDoublePtr>>2]=$445,HEAP32[tempDoublePtr>>2]|0);
 $448 = $447 & -2147483648;
 $449 = $448 ^ $446;
 $450 = (HEAP32[tempDoublePtr>>2]=$449,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $451 = (HEAPF32[tempDoublePtr>>2]=$10,HEAP32[tempDoublePtr>>2]|0);
 $452 = $448 ^ $451;
 $453 = (HEAP32[tempDoublePtr>>2]=$452,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $454 = (HEAPF32[tempDoublePtr>>2]=$12,HEAP32[tempDoublePtr>>2]|0);
 $455 = $448 ^ $454;
 $456 = (HEAP32[tempDoublePtr>>2]=$455,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $457 = (HEAPF32[tempDoublePtr>>2]=$14,HEAP32[tempDoublePtr>>2]|0);
 $458 = $448 ^ $457;
 $459 = (HEAP32[tempDoublePtr>>2]=$458,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $460 = Math_fround($450 - $432);
 $461 = Math_fround($453 - $435);
 $462 = Math_fround($456 - $438);
 $463 = Math_fround($459 - $441);
 $464 = Math_fround($430 * $460);
 $465 = Math_fround($430 * $461);
 $466 = Math_fround($430 * $462);
 $467 = Math_fround($430 * $463);
 $468 = Math_fround($432 + $464);
 $469 = Math_fround($435 + $465);
 $470 = Math_fround($438 + $466);
 $471 = Math_fround($441 + $467);
 $472 = Math_fround($468 * $468);
 $473 = Math_fround($469 * $469);
 $474 = Math_fround($470 * $470);
 $475 = Math_fround($471 * $471);
 $476 = Math_fround($472 + $473);
 $477 = Math_fround($474 + $475);
 $478 = Math_fround($476 + $477);
 $479 = (Math_fround(Math_sqrt((Math_fround($478)))));
 $480 = Math_fround(Math_fround(1.0) / $479);
 $481 = Math_fround($480 * $468);
 $482 = Math_fround($480 * $469);
 $483 = Math_fround($480 * $470);
 $484 = Math_fround($480 * $471);
 HEAPF32[$431>>2] = $481;
 HEAPF32[$434>>2] = $482;
 HEAPF32[$437>>2] = $483;
 HEAPF32[$440>>2] = $484;
 STACKTOP = sp;return;
}
function __ZN7mecanim8skeleton23Skeleton2BoneAdjustHintEPKNS0_8SkeletonEiiiRKN4math7_float4EfPNS0_12SkeletonPoseES9_f($apSkeleton,$aIndexA,$aIndexB,$aIndexC,$aHint,$weight,$apSkeletonPose,$apSkeletonPoseWorkspace,$minLenRatio) {
 $apSkeleton = $apSkeleton|0;
 $aIndexA = $aIndexA|0;
 $aIndexB = $aIndexB|0;
 $aIndexC = $aIndexC|0;
 $aHint = $aHint|0;
 $weight = Math_fround($weight);
 $apSkeletonPose = $apSkeletonPose|0;
 $apSkeletonPoseWorkspace = $apSkeletonPoseWorkspace|0;
 $minLenRatio = Math_fround($minLenRatio);
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = Math_fround(0), $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = Math_fround(0);
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = Math_fround(0), $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0);
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0);
 var $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = Math_fround(0), $210 = Math_fround(0), $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0);
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apSkeletonPoseWorkspace) + 4|0);
 $1 = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + ($1))|0;
 $4 = $3;
 $5 = (($apSkeletonPoseWorkspace) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = (($4) + (($aIndexA*48)|0)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = ((($4) + (($aIndexA*48)|0)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = ((($4) + (($aIndexA*48)|0)|0) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = ((($4) + (($aIndexA*48)|0)|0) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 HEAP32[$5>>2] = $4;
 $14 = (($4) + (($aIndexB*48)|0)|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = ((($4) + (($aIndexB*48)|0)|0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = ((($4) + (($aIndexB*48)|0)|0) + 8|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = ((($4) + (($aIndexB*48)|0)|0) + 12|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 HEAP32[$5>>2] = $4;
 $22 = (($4) + (($aIndexC*48)|0)|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = ((($4) + (($aIndexC*48)|0)|0) + 4|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = ((($4) + (($aIndexC*48)|0)|0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = ((($4) + (($aIndexC*48)|0)|0) + 12|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($23 - $7);
 $31 = Math_fround($25 - $9);
 $32 = Math_fround($27 - $11);
 $33 = Math_fround($29 - $13);
 $34 = Math_fround($30 * $30);
 $35 = Math_fround($31 * $31);
 $36 = Math_fround($32 * $32);
 $37 = Math_fround($33 * $33);
 $38 = Math_fround($34 + $35);
 $39 = Math_fround($36 + $37);
 $40 = Math_fround($38 + $39);
 $41 = (Math_fround(Math_sqrt((Math_fround($40)))));
 $42 = $41 > Math_fround(0.0);
 if (!($42)) {
  STACKTOP = sp;return;
 }
 $43 = Math_fround($30 / $41);
 $44 = Math_fround($31 / $41);
 $45 = Math_fround($32 / $41);
 $46 = Math_fround($33 / $41);
 $47 = Math_fround($15 - $7);
 $48 = Math_fround($17 - $9);
 $49 = Math_fround($19 - $11);
 $50 = Math_fround($21 - $13);
 $51 = Math_fround(HEAPF32[$aHint>>2]);
 $52 = Math_fround($51 - $7);
 $53 = (($aHint) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 - $9);
 $56 = (($aHint) + 8|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 - $11);
 $59 = (($aHint) + 12|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 - $13);
 $62 = Math_fround($47 * $43);
 $63 = Math_fround($48 * $44);
 $64 = Math_fround($49 * $45);
 $65 = Math_fround($50 * $46);
 $66 = Math_fround($62 + $63);
 $67 = Math_fround($64 + $65);
 $68 = Math_fround($66 + $67);
 $69 = Math_fround($43 * $68);
 $70 = Math_fround($44 * $68);
 $71 = Math_fround($45 * $68);
 $72 = Math_fround($46 * $68);
 $73 = Math_fround($43 * $52);
 $74 = Math_fround($44 * $55);
 $75 = Math_fround($45 * $58);
 $76 = Math_fround($46 * $61);
 $77 = Math_fround($73 + $74);
 $78 = Math_fround($75 + $76);
 $79 = Math_fround($77 + $78);
 $80 = Math_fround($43 * $79);
 $81 = Math_fround($44 * $79);
 $82 = Math_fround($45 * $79);
 $83 = Math_fround($46 * $79);
 $84 = Math_fround($47 - $69);
 $85 = Math_fround($48 - $70);
 $86 = Math_fround($49 - $71);
 $87 = Math_fround($50 - $72);
 $88 = Math_fround($52 - $80);
 $89 = Math_fround($55 - $81);
 $90 = Math_fround($58 - $82);
 $91 = Math_fround($61 - $83);
 $92 = Math_fround($84 * $84);
 $93 = Math_fround($85 * $85);
 $94 = Math_fround($86 * $86);
 $95 = Math_fround($87 * $87);
 $96 = Math_fround($92 + $93);
 $97 = Math_fround($94 + $95);
 $98 = Math_fround($96 + $97);
 $99 = (Math_fround(Math_sqrt((Math_fround($98)))));
 $100 = Math_fround($88 * $88);
 $101 = Math_fround($89 * $89);
 $102 = Math_fround($90 * $90);
 $103 = Math_fround($91 * $91);
 $104 = Math_fround($100 + $101);
 $105 = Math_fround($102 + $103);
 $106 = Math_fround($104 + $105);
 $107 = (Math_fround(Math_sqrt((Math_fround($106)))));
 $108 = $99 > Math_fround(0.0);
 $109 = $107 > Math_fround(0.0);
 $or$cond = $108 & $109;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $110 = Math_fround($23 - $15);
 $111 = Math_fround($25 - $17);
 $112 = Math_fround($27 - $19);
 $113 = Math_fround($29 - $21);
 $114 = Math_fround($47 * $47);
 $115 = Math_fround($48 * $48);
 $116 = Math_fround($49 * $49);
 $117 = Math_fround($50 * $50);
 $118 = Math_fround($114 + $115);
 $119 = Math_fround($116 + $117);
 $120 = Math_fround($118 + $119);
 $121 = (Math_fround(Math_sqrt((Math_fround($120)))));
 $122 = Math_fround($110 * $110);
 $123 = Math_fround($111 * $111);
 $124 = Math_fround($112 * $112);
 $125 = Math_fround($113 * $113);
 $126 = Math_fround($122 + $123);
 $127 = Math_fround($124 + $125);
 $128 = Math_fround($126 + $127);
 $129 = (Math_fround(Math_sqrt((Math_fround($128)))));
 $130 = Math_fround($121 + $129);
 $131 = Math_fround($130 * $minLenRatio);
 $132 = $99 > $131;
 if (!($132)) {
  STACKTOP = sp;return;
 }
 $133 = Math_fround($131 * Math_fround(2.0));
 $134 = Math_fround($133 - $99);
 $135 = Math_fround($133 - $131);
 $136 = Math_fround($134 / $135);
 $137 = Math_fround(Math_fround(1.0) - $136);
 $138 = $99 > $133;
 $139 = $138 ? Math_fround(1.0) : $137;
 $140 = Math_fround($84 * $89);
 $141 = Math_fround($85 * $90);
 $142 = Math_fround($86 * $88);
 $143 = Math_fround($87 * $91);
 $144 = Math_fround($85 * $88);
 $145 = Math_fround($86 * $89);
 $146 = Math_fround($84 * $90);
 $147 = Math_fround($140 - $144);
 $148 = Math_fround($141 - $145);
 $149 = Math_fround($142 - $146);
 $150 = Math_fround($84 * $88);
 $151 = Math_fround($85 * $89);
 $152 = Math_fround($86 * $90);
 $153 = Math_fround($150 + $151);
 $154 = Math_fround($152 + $143);
 $155 = Math_fround($153 + $154);
 $156 = Math_fround($98 * $106);
 $157 = (Math_fround(Math_sqrt((Math_fround($156)))));
 $158 = Math_fround($155 + $157);
 $159 = Math_fround($139 * $weight);
 $160 = Math_fround($148 * $159);
 $161 = Math_fround($149 * $159);
 $162 = Math_fround($147 * $159);
 HEAP32[$5>>2] = $4;
 $163 = ((($4) + (($aIndexA*48)|0)|0) + 16|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = Math_fround($161 * $164);
 $166 = ((($4) + (($aIndexA*48)|0)|0) + 28|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = Math_fround($158 * $167);
 $169 = ((($4) + (($aIndexA*48)|0)|0) + 20|0);
 $170 = Math_fround(HEAPF32[$169>>2]);
 $171 = Math_fround($162 * $170);
 $172 = ((($4) + (($aIndexA*48)|0)|0) + 24|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround($160 * $173);
 $175 = Math_fround($158 * $173);
 $176 = Math_fround($164 * $160);
 $177 = Math_fround($161 * $173);
 $178 = Math_fround($164 * $162);
 $179 = Math_fround($165 - $175);
 $180 = Math_fround($168 - $176);
 $181 = Math_fround($171 - $177);
 $182 = Math_fround($174 - $178);
 $183 = Math_fround($162 * $167);
 $184 = Math_fround($162 * $173);
 $185 = Math_fround($158 * $164);
 $186 = Math_fround($158 * $170);
 $187 = Math_fround($179 - $183);
 $188 = Math_fround($180 - $184);
 $189 = Math_fround($181 - $185);
 $190 = Math_fround($182 - $186);
 $191 = Math_fround($160 * $170);
 $192 = Math_fround($161 * $170);
 $193 = Math_fround($160 * $167);
 $194 = Math_fround($161 * $167);
 $195 = Math_fround($187 - $191);
 $196 = Math_fround($188 - $192);
 $197 = Math_fround($189 - $193);
 $198 = Math_fround($190 - $194);
 $199 = Math_fround($197 * Math_fround(-1.0));
 $200 = Math_fround($198 * Math_fround(-1.0));
 $201 = Math_fround($195 * Math_fround(-1.0));
 $202 = Math_fround($199 * $199);
 $203 = Math_fround($200 * $200);
 $204 = Math_fround($201 * $201);
 $205 = Math_fround($196 * $196);
 $206 = Math_fround($202 + $203);
 $207 = Math_fround($205 + $204);
 $208 = Math_fround($206 + $207);
 $209 = (Math_fround(Math_sqrt((Math_fround($208)))));
 $210 = Math_fround(Math_fround(1.0) / $209);
 $211 = Math_fround($210 * $199);
 $212 = Math_fround($210 * $200);
 $213 = Math_fround($210 * $201);
 $214 = Math_fround($210 * $196);
 HEAPF32[$163>>2] = $211;
 HEAPF32[$169>>2] = $212;
 HEAPF32[$172>>2] = $213;
 HEAPF32[$166>>2] = $214;
 __ZN7mecanim8skeleton24SkeletonPoseComputeLocalEPKNS0_8SkeletonEPKNS0_12SkeletonPoseEPS4_ii($apSkeleton,$apSkeletonPoseWorkspace,$apSkeletonPose,$aIndexA,$aIndexA);
 STACKTOP = sp;return;
}
function __ZN4mathL7halfTanERKNS_7_float4E19419($agg$result,$a) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = Math_fround(0), $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0);
 var $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0);
 var $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0);
 var $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0);
 var $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = (Math_fround(Math_abs((Math_fround($0)))));
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (Math_fround(Math_abs((Math_fround($3)))));
 $5 = (($a) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (Math_fround(Math_abs((Math_fround($6)))));
 $8 = (($a) + 12|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (Math_fround(Math_abs((Math_fround($9)))));
 $11 = Math_fround($1 * Math_fround(0.5));
 $12 = Math_fround($4 * Math_fround(0.5));
 $13 = Math_fround($7 * Math_fround(0.5));
 $14 = Math_fround($10 * Math_fround(0.5));
 $15 = Math_fround($11 + Math_fround(1.57079637050628662109));
 $16 = Math_fround($12 + Math_fround(1.57079637050628662109));
 $17 = Math_fround($13 + Math_fround(1.57079637050628662109));
 $18 = Math_fround($14 + Math_fround(1.57079637050628662109));
 $19 = Math_fround($15 + Math_fround(-1.57079637050628662109));
 $20 = Math_fround($16 + Math_fround(-1.57079637050628662109));
 $21 = Math_fround($17 + Math_fround(-1.57079637050628662109));
 $22 = Math_fround($18 + Math_fround(-1.57079637050628662109));
 $23 = (Math_fround(+(_copysignf((+$19),(+$0)))));
 $24 = (Math_fround(+(_copysignf((+$20),(+$3)))));
 $25 = (Math_fround(+(_copysignf((+$21),(+$6)))));
 $26 = (Math_fround(+(_copysignf((+$22),(+$9)))));
 $27 = (Math_fround(+(_fmaxf((+$23),-1.57079541683197021484))));
 $28 = (Math_fround(+(_fminf((+$27),1.57079732418060302734))));
 $29 = (Math_fround(+(_fmaxf((+$24),-1.57079541683197021484))));
 $30 = (Math_fround(+(_fminf((+$29),1.57079732418060302734))));
 $31 = (Math_fround(+(_fmaxf((+$25),-1.57079541683197021484))));
 $32 = (Math_fround(+(_fminf((+$31),1.57079732418060302734))));
 $33 = (Math_fround(+(_fmaxf((+$26),-1.57079541683197021484))));
 $34 = (Math_fround(+(_fminf((+$33),1.57079732418060302734))));
 $35 = Math_fround($28 * Math_fround(0.159154936671257019043));
 $36 = Math_fround($30 * Math_fround(0.159154936671257019043));
 $37 = Math_fround($32 * Math_fround(0.159154936671257019043));
 $38 = Math_fround($34 * Math_fround(0.159154936671257019043));
 $39 = (Math_fround(+(_roundf((+$35)))));
 $40 = (Math_fround(+(_roundf((+$36)))));
 $41 = (Math_fround(+(_roundf((+$37)))));
 $42 = (Math_fround(+(_roundf((+$38)))));
 $43 = Math_fround($35 - $39);
 $44 = Math_fround($36 - $40);
 $45 = Math_fround($37 - $41);
 $46 = Math_fround($38 - $42);
 $47 = (Math_fround(Math_abs((Math_fround($43)))));
 $48 = (Math_fround(Math_abs((Math_fround($44)))));
 $49 = (Math_fround(Math_abs((Math_fround($45)))));
 $50 = (Math_fround(Math_abs((Math_fround($46)))));
 $51 = Math_fround(Math_fround(0.25) - $47);
 $52 = Math_fround(Math_fround(0.25) - $48);
 $53 = Math_fround(Math_fround(0.25) - $49);
 $54 = Math_fround(Math_fround(0.25) - $50);
 $55 = Math_fround($51 * $51);
 $56 = Math_fround($52 * $52);
 $57 = Math_fround($53 * $53);
 $58 = Math_fround($54 * $54);
 $59 = Math_fround($55 * $55);
 $60 = Math_fround($56 * $56);
 $61 = Math_fround($57 * $57);
 $62 = Math_fround($58 * $58);
 $63 = Math_fround($55 * Math_fround(-41.283184051513671875));
 $64 = Math_fround($56 * Math_fround(-41.283184051513671875));
 $65 = Math_fround($57 * Math_fround(-41.283184051513671875));
 $66 = Math_fround($58 * Math_fround(-41.283184051513671875));
 $67 = Math_fround($63 + Math_fround(6.28318548202514648438));
 $68 = Math_fround($64 + Math_fround(6.28318548202514648438));
 $69 = Math_fround($65 + Math_fround(6.28318548202514648438));
 $70 = Math_fround($66 + Math_fround(6.28318548202514648438));
 $71 = Math_fround($59 * Math_fround(76.03546142578125));
 $72 = Math_fround($60 * Math_fround(76.03546142578125));
 $73 = Math_fround($61 * Math_fround(76.03546142578125));
 $74 = Math_fround($62 * Math_fround(76.03546142578125));
 $75 = Math_fround($67 + $71);
 $76 = Math_fround($68 + $72);
 $77 = Math_fround($69 + $73);
 $78 = Math_fround($70 + $74);
 $79 = Math_fround($51 * $75);
 $80 = Math_fround($52 * $76);
 $81 = Math_fround($53 * $77);
 $82 = Math_fround($54 * $78);
 $83 = Math_fround($35 + Math_fround(-0.25));
 $84 = Math_fround($36 + Math_fround(-0.25));
 $85 = Math_fround($37 + Math_fround(-0.25));
 $86 = Math_fround($38 + Math_fround(-0.25));
 $87 = (Math_fround(+(_roundf((+$83)))));
 $88 = (Math_fround(+(_roundf((+$84)))));
 $89 = (Math_fround(+(_roundf((+$85)))));
 $90 = (Math_fround(+(_roundf((+$86)))));
 $91 = Math_fround($83 - $87);
 $92 = Math_fround($84 - $88);
 $93 = Math_fround($85 - $89);
 $94 = Math_fround($86 - $90);
 $95 = (Math_fround(Math_abs((Math_fround($91)))));
 $96 = (Math_fround(Math_abs((Math_fround($92)))));
 $97 = (Math_fround(Math_abs((Math_fround($93)))));
 $98 = (Math_fround(Math_abs((Math_fround($94)))));
 $99 = Math_fround(Math_fround(0.25) - $95);
 $100 = Math_fround(Math_fround(0.25) - $96);
 $101 = Math_fround(Math_fround(0.25) - $97);
 $102 = Math_fround(Math_fround(0.25) - $98);
 $103 = Math_fround($99 * $99);
 $104 = Math_fround($100 * $100);
 $105 = Math_fround($101 * $101);
 $106 = Math_fround($102 * $102);
 $107 = Math_fround($103 * $103);
 $108 = Math_fround($104 * $104);
 $109 = Math_fround($105 * $105);
 $110 = Math_fround($106 * $106);
 $111 = Math_fround($103 * Math_fround(-41.283184051513671875));
 $112 = Math_fround($104 * Math_fround(-41.283184051513671875));
 $113 = Math_fround($105 * Math_fround(-41.283184051513671875));
 $114 = Math_fround($106 * Math_fround(-41.283184051513671875));
 $115 = Math_fround($111 + Math_fround(6.28318548202514648438));
 $116 = Math_fround($112 + Math_fround(6.28318548202514648438));
 $117 = Math_fround($113 + Math_fround(6.28318548202514648438));
 $118 = Math_fround($114 + Math_fround(6.28318548202514648438));
 $119 = Math_fround($107 * Math_fround(76.03546142578125));
 $120 = Math_fround($108 * Math_fround(76.03546142578125));
 $121 = Math_fround($109 * Math_fround(76.03546142578125));
 $122 = Math_fround($110 * Math_fround(76.03546142578125));
 $123 = Math_fround($115 + $119);
 $124 = Math_fround($116 + $120);
 $125 = Math_fround($117 + $121);
 $126 = Math_fround($118 + $122);
 $127 = Math_fround($99 * $123);
 $128 = Math_fround($100 * $124);
 $129 = Math_fround($101 * $125);
 $130 = Math_fround($102 * $126);
 $131 = Math_fround($127 / $79);
 $132 = Math_fround($128 / $80);
 $133 = Math_fround($129 / $81);
 $134 = Math_fround($130 / $82);
 HEAPF32[$agg$result>>2] = $131;
 $135 = (($agg$result) + 4|0);
 HEAPF32[$135>>2] = $132;
 $136 = (($agg$result) + 8|0);
 HEAPF32[$136>>2] = $133;
 $137 = (($agg$result) + 12|0);
 HEAPF32[$137>>2] = $134;
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine10IsDisabledEPKNS0_17StateMachineInputE($apStateMachineInput) {
 $apStateMachineInput = $apStateMachineInput|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apStateMachineInput) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = 0;
  STACKTOP = sp;return ($5|0);
 }
 $3 = (__ZNK27StateMachineBehaviourPlayer15IsSenderEnabledEv($1)|0);
 $4 = $3 ^ 1;
 $5 = $4;
 STACKTOP = sp;return ($5|0);
}
function __ZN7mecanim12statemachine13GetStateIndexEPKNS0_20StateMachineConstantEj($apStateMachineConstant,$id) {
 $apStateMachineConstant = $apStateMachineConstant|0;
 $id = $id|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apStateMachineConstant) + 4|0);
 $1 = HEAP32[$apStateMachineConstant>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = $0;
 $4 = HEAP32[$0>>2]|0;
 $5 = (($4) + ($3))|0;
 $6 = $5;
 $i$02 = 0;
 while(1) {
  $9 = (($6) + ($i$02<<3)|0);
  $10 = $9;
  $11 = HEAP32[$9>>2]|0;
  $12 = (($10) + ($11))|0;
  $13 = $12;
  $14 = ((($6) + ($i$02<<3)|0) + 4|0);
  HEAP32[$14>>2] = $13;
  $15 = (($13) + 52|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==($id|0);
  if ($17) {
   $$0 = $i$02;
   label = 7;
   break;
  }
  $18 = (($13) + 48|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==($id|0);
  if ($20) {
   $$0 = $i$02;
   label = 7;
   break;
  }
  $21 = (($13) + 44|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==($id|0);
  $8 = (($i$02) + 1)|0;
  if ($23) {
   $$0 = $i$02;
   label = 7;
   break;
  }
  $7 = ($8>>>0)<($1>>>0);
  if ($7) {
   $i$02 = $8;
  } else {
   $$0 = -1;
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN7mecanim12statemachine20CreateStateWorkspaceEjjjRNS_6memory9AllocatorE($motionSetCount,$maxNodeCount,$maxBlendedClip,$arAlloc) {
 $motionSetCount = $motionSetCount|0;
 $maxNodeCount = $maxNodeCount|0;
 $maxBlendedClip = $maxBlendedClip|0;
 $arAlloc = $arAlloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$arAlloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($arAlloc,16,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $7 = 0;
 } else {
  HEAP32[$2>>2] = 0;
  $4 = (($2) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($2) + 8|0);
  HEAP32[$5>>2] = 0;
  $7 = $2;
 }
 $6 = ($motionSetCount|0)==(0);
 if ($6) {
  HEAP32[$7>>2] = 0;
  $8 = (($7) + 4|0);
  HEAP32[$8>>2] = 0;
  $9 = (($7) + 8|0);
  HEAP32[$9>>2] = 0;
  $10 = (($7) + 12|0);
  HEAP32[$10>>2] = $motionSetCount;
  STACKTOP = sp;return ($7|0);
 }
 $11 = HEAP32[$arAlloc>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = $motionSetCount << 2;
 $14 = (FUNCTION_TABLE_iiii[$12 & 2047]($arAlloc,$13,4)|0);
 HEAP32[$7>>2] = $14;
 $15 = HEAP32[$arAlloc>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_iiii[$16 & 2047]($arAlloc,$13,4)|0);
 $18 = (($7) + 4|0);
 HEAP32[$18>>2] = $17;
 $19 = HEAP32[$arAlloc>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_iiii[$20 & 2047]($arAlloc,$13,4)|0);
 $22 = (($7) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($7) + 12|0);
 HEAP32[$23>>2] = $motionSetCount;
 $i$08 = 0;
 while(1) {
  $24 = (__ZN7mecanim9animation20CreateBlendTreeInputERNS_6memory9AllocatorE($arAlloc)|0);
  $25 = HEAP32[$7>>2]|0;
  $26 = (($25) + ($i$08<<2)|0);
  HEAP32[$26>>2] = $24;
  $27 = (__ZN7mecanim9animation21CreateBlendTreeOutputEjRNS_6memory9AllocatorE($maxBlendedClip,$arAlloc)|0);
  $28 = HEAP32[$18>>2]|0;
  $29 = (($28) + ($i$08<<2)|0);
  HEAP32[$29>>2] = $27;
  $30 = (__ZN7mecanim9animation24CreateBlendTreeWorkspaceEjRNS_6memory9AllocatorE($maxNodeCount,$arAlloc)|0);
  $31 = HEAP32[$22>>2]|0;
  $32 = (($31) + ($i$08<<2)|0);
  HEAP32[$32>>2] = $30;
  $33 = (($i$08) + 1)|0;
  $34 = HEAP32[$23>>2]|0;
  $35 = ($33>>>0)<($34>>>0);
  if ($35) {
   $i$08 = $33;
  } else {
   break;
  }
 }
 STACKTOP = sp;return ($7|0);
}
function __ZN7mecanim12statemachine21DestroyStateWorkspaceEPNS0_14StateWorkspaceERNS_6memory9AllocatorE($apStateWorkspace,$arAlloc) {
 $apStateWorkspace = $apStateWorkspace|0;
 $arAlloc = $arAlloc|0;
 var $$pre2 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($apStateWorkspace|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($apStateWorkspace) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 $$pre2 = (($apStateWorkspace) + 4|0);
 $$pre4 = (($apStateWorkspace) + 8|0);
 if (!($3)) {
  $i$01 = 0;
  while(1) {
   $4 = HEAP32[$apStateWorkspace>>2]|0;
   $5 = (($4) + ($i$01<<2)|0);
   $6 = HEAP32[$5>>2]|0;
   __ZN7mecanim9animation21DestroyBlendTreeInputEPNS0_14BlendTreeInputERNS_6memory9AllocatorE($6,$arAlloc);
   $7 = HEAP32[$$pre2>>2]|0;
   $8 = (($7) + ($i$01<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   __ZN7mecanim9animation22DestroyBlendTreeOutputEPNS0_15BlendTreeOutputERNS_6memory9AllocatorE($9,$arAlloc);
   $10 = HEAP32[$$pre4>>2]|0;
   $11 = (($10) + ($i$01<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   __ZN7mecanim9animation25DestroyBlendTreeWorkspaceEPNS0_18BlendTreeWorkspaceERNS_6memory9AllocatorE($12,$arAlloc);
   $13 = (($i$01) + 1)|0;
   $14 = HEAP32[$1>>2]|0;
   $15 = ($13>>>0)<($14>>>0);
   if ($15) {
    $i$01 = $13;
   } else {
    break;
   }
  }
 }
 $16 = HEAP32[$arAlloc>>2]|0;
 $17 = (($16) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$apStateWorkspace>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($arAlloc,$19);
 $20 = HEAP32[$arAlloc>>2]|0;
 $21 = (($20) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$$pre2>>2]|0;
 FUNCTION_TABLE_vii[$22 & 4095]($arAlloc,$23);
 $24 = HEAP32[$arAlloc>>2]|0;
 $25 = (($24) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$$pre4>>2]|0;
 FUNCTION_TABLE_vii[$26 & 4095]($arAlloc,$27);
 $28 = HEAP32[$arAlloc>>2]|0;
 $29 = (($28) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vii[$30 & 4095]($arAlloc,$apStateWorkspace);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine24CreateStateMachineMemoryEPKNS0_20StateMachineConstantERNS_6memory9AllocatorE($apStateMachineConstant,$arAlloc) {
 $apStateMachineConstant = $apStateMachineConstant|0;
 $arAlloc = $arAlloc|0;
 var $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$arAlloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($arAlloc,76,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $11 = 0;
 } else {
  $4 = (($2) + 24|0);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;
  HEAP32[$4>>2] = -1;
  $5 = (($2) + 28|0);
  HEAP32[$5>>2] = -1;
  $6 = (($2) + 32|0);
  HEAP32[$6>>2] = 1;
  $7 = (($2) + 36|0);
  dest=$7+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $11 = $2;
 }
 $8 = (($apStateMachineConstant) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($11) + 12|0);
 HEAP32[$10>>2] = $9;
 $12 = (($apStateMachineConstant) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = (($11) + 4|0);
  $$0$i2 = 0;$25 = 0;$26 = $15;
 } else {
  $16 = HEAP32[$arAlloc>>2]|0;
  $17 = HEAP32[$16>>2]|0;
  $18 = $13 << 2;
  $19 = (FUNCTION_TABLE_iiii[$17 & 2047]($arAlloc,$18,4)|0);
  $20 = (($11) + 4|0);
  $21 = ($19|0)==(0|0);
  if ($21) {
   $$0$i2 = 0;$25 = 0;$26 = $20;
  } else {
   $22 = $19;
   $23 = $20;
   $24 = (($22) - ($23))|0;
   $$0$i2 = $19;$25 = $24;$26 = $20;
  }
 }
 HEAP32[$26>>2] = $25;
 $27 = (($26) + 4|0);
 HEAP32[$27>>2] = $$0$i2;
 $28 = HEAP32[$12>>2]|0;
 HEAP32[$11>>2] = $28;
 STACKTOP = sp;return ($11|0);
}
function __ZN7mecanim12statemachine25DestroyStateMachineMemoryEPNS0_18StateMachineMemoryERNS_6memory9AllocatorE($apStateMachineMemory,$arAlloc) {
 $apStateMachineMemory = $apStateMachineMemory|0;
 $arAlloc = $arAlloc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($apStateMachineMemory|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($apStateMachineMemory) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = HEAP32[$arAlloc>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $1;
  $8 = (($2) + ($7))|0;
  $9 = $8;
  $10 = (($apStateMachineMemory) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = $8;
  FUNCTION_TABLE_vii[$6 & 4095]($arAlloc,$11);
 }
 $12 = HEAP32[$arAlloc>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($arAlloc,$apStateMachineMemory);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine27CreateStateMachineWorkspaceEPKNS0_20StateMachineConstantEjRNS_6memory9AllocatorE($apStateMachineConstant,$maxBlendState,$arAlloc) {
 $apStateMachineConstant = $apStateMachineConstant|0;
 $maxBlendState = $maxBlendState|0;
 $arAlloc = $arAlloc|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $j$01 = 0;
 var $maxNodeCount = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $maxNodeCount = sp;
 $0 = HEAP32[$arAlloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($arAlloc,12,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $51 = 0;
 } else {
  HEAP32[$2>>2] = 0;
  $4 = (($2) + 4|0);
  HEAP32[$4>>2] = 0;
  $5 = (($2) + 8|0);
  HEAP32[$5>>2] = 0;
  $51 = $2;
 }
 HEAP32[$maxNodeCount>>2] = 0;
 $6 = HEAP32[$apStateMachineConstant>>2]|0;
 $7 = ($6|0)==(0);
 $$phi$trans$insert = (($apStateMachineConstant) + 40|0);
 if ($7) {
  $$pre7 = HEAP32[$$phi$trans$insert>>2]|0;
  $48 = $$pre7;$49 = 0;
  $50 = (__ZN7mecanim12statemachine20CreateStateWorkspaceEjjjRNS_6memory9AllocatorE($48,$49,$maxBlendState,$arAlloc)|0);
  HEAP32[$51>>2] = $50;
  STACKTOP = sp;return ($51|0);
 }
 $8 = (($apStateMachineConstant) + 4|0);
 $9 = $8;
 $$pre5 = HEAP32[$$phi$trans$insert>>2]|0;
 $11 = $$pre5;$i$02 = 0;
 while(1) {
  $10 = ($11|0)==(0);
  if ($10) {
   $52 = 0;
  } else {
   $$pre6 = HEAP32[$8>>2]|0;
   $j$01 = 0;
   while(1) {
    $12 = (($$pre6) + ($9))|0;
    $13 = $12;
    $14 = (($13) + ($i$02<<3)|0);
    $15 = $14;
    $16 = HEAP32[$14>>2]|0;
    $17 = (($15) + ($16))|0;
    $18 = $17;
    $19 = ((($13) + ($i$02<<3)|0) + 4|0);
    HEAP32[$19>>2] = $18;
    $20 = (($18) + 16|0);
    $21 = $20;
    $22 = HEAP32[$20>>2]|0;
    $23 = (($21) + ($22))|0;
    $24 = $23;
    $25 = (($24) + ($j$01<<2)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(-1);
    if (!($27)) {
     $28 = (($18) + 36|0);
     $29 = $28;
     $30 = HEAP32[$28>>2]|0;
     $31 = (($30) + ($29))|0;
     $32 = $31;
     $33 = (($32) + ($26<<3)|0);
     $34 = $33;
     $35 = HEAP32[$33>>2]|0;
     $36 = (($34) + ($35))|0;
     $37 = $36;
     $38 = ((($32) + ($26<<3)|0) + 4|0);
     HEAP32[$38>>2] = $37;
     $39 = ($36|0)==(0);
     if (!($39)) {
      $40 = HEAP32[$maxNodeCount>>2]|0;
      $41 = HEAP32[$37>>2]|0;
      $42 = ($40>>>0)<($41>>>0);
      $43 = $42 ? $41 : $40;
      HEAP32[$maxNodeCount>>2] = $43;
     }
    }
    $44 = (($j$01) + 1)|0;
    $45 = ($44>>>0)<($$pre5>>>0);
    if ($45) {
     $j$01 = $44;
    } else {
     $52 = $$pre5;
     break;
    }
   }
  }
  $46 = (($i$02) + 1)|0;
  $47 = ($46>>>0)<($6>>>0);
  if ($47) {
   $11 = $52;$i$02 = $46;
  } else {
   break;
  }
 }
 $$pre = HEAP32[$maxNodeCount>>2]|0;
 $48 = $$pre5;$49 = $$pre;
 $50 = (__ZN7mecanim12statemachine20CreateStateWorkspaceEjjjRNS_6memory9AllocatorE($48,$49,$maxBlendState,$arAlloc)|0);
 HEAP32[$51>>2] = $50;
 STACKTOP = sp;return ($51|0);
}
function __ZN7mecanim12statemachine28DestroyStateMachineWorkspaceEPNS0_21StateMachineWorkspaceERNS_6memory9AllocatorE($apStateMachineWorkspace,$arAlloc) {
 $apStateMachineWorkspace = $apStateMachineWorkspace|0;
 $arAlloc = $arAlloc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($apStateMachineWorkspace|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$apStateMachineWorkspace>>2]|0;
 __ZN7mecanim12statemachine21DestroyStateWorkspaceEPNS0_14StateWorkspaceERNS_6memory9AllocatorE($1,$arAlloc);
 $2 = HEAP32[$arAlloc>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($arAlloc,$apStateMachineWorkspace);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine24CreateStateMachineOutputEPKNS0_20StateMachineConstantEjRNS_6memory9AllocatorE($apStateMachineConstant,$maxBlendedClip,$arAlloc) {
 $apStateMachineConstant = $apStateMachineConstant|0;
 $maxBlendedClip = $maxBlendedClip|0;
 $arAlloc = $arAlloc|0;
 var $$0$i2 = 0, $$0$i4 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $i$041 = 0, $i$041$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$arAlloc>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiii[$1 & 2047]($arAlloc,60,4)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $16 = 0;
 } else {
  $4 = (($2) + 20|0);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
  HEAP32[$4>>2] = 128;
  $5 = (($2) + 24|0);
  HEAP8[$5>>0] = 0;
  $6 = (($2) + 25|0);
  HEAP8[$6>>0] = 1;
  $7 = (($2) + 28|0);
  $8 = (($2) + 44|0);
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;
  HEAP32[$8>>2] = 128;
  $9 = (($2) + 48|0);
  HEAP8[$9>>0] = 0;
  $10 = (($2) + 49|0);
  HEAP8[$10>>0] = 1;
  $11 = (($2) + 52|0);
  HEAP32[$11>>2] = 0;
  $12 = (($2) + 56|0);
  HEAP8[$12>>0] = 0;
  $16 = $2;
 }
 $13 = (($apStateMachineConstant) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($16) + 52|0);
 HEAP32[$15>>2] = $14;
 $17 = HEAP32[$13>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $$0$i2 = 0;
 } else {
  $19 = HEAP32[$arAlloc>>2]|0;
  $20 = HEAP32[$19>>2]|0;
  $21 = ($17*24)|0;
  $22 = (FUNCTION_TABLE_iiii[$20 & 2047]($arAlloc,$21,4)|0);
  $23 = ($22|0)==(0|0);
  if ($23) {
   $$0$i2 = 0;
  } else {
   $24 = (($22) + (($17*24)|0)|0);
   $25 = $22;
   while(1) {
    ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;HEAP32[$25+16>>2]=0|0;HEAP32[$25+20>>2]=0|0;
    $26 = (($25) + 24|0);
    $27 = ($26|0)==($24|0);
    if ($27) {
     $$0$i2 = $22;
     break;
    } else {
     $25 = $26;
    }
   }
  }
 }
 $28 = (($16) + 4|0);
 HEAP32[$28>>2] = $$0$i2;
 $29 = HEAP32[$13>>2]|0;
 $30 = ($29|0)==(0);
 if ($30) {
  $$0$i4 = 0;
 } else {
  $31 = HEAP32[$arAlloc>>2]|0;
  $32 = HEAP32[$31>>2]|0;
  $33 = ($29*24)|0;
  $34 = (FUNCTION_TABLE_iiii[$32 & 2047]($arAlloc,$33,4)|0);
  $35 = ($34|0)==(0|0);
  if ($35) {
   $$0$i4 = 0;
  } else {
   $36 = (($34) + (($29*24)|0)|0);
   $37 = $34;
   while(1) {
    ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP32[$37+16>>2]=0|0;HEAP32[$37+20>>2]=0|0;
    $38 = (($37) + 24|0);
    $39 = ($38|0)==($36|0);
    if ($39) {
     $$0$i4 = $34;
     break;
    } else {
     $37 = $38;
    }
   }
  }
 }
 $40 = (($16) + 28|0);
 HEAP32[$40>>2] = $$0$i4;
 $41 = HEAP32[$13>>2]|0;
 $42 = ($41|0)==(0);
 if ($42) {
  STACKTOP = sp;return ($16|0);
 }
 $43 = ($maxBlendedClip|0)==(0);
 $44 = $maxBlendedClip << 2;
 if ($43) {
  $i$041$us = 0;
  while(1) {
   $45 = HEAP32[$28>>2]|0;
   $46 = ((($45) + (($i$041$us*24)|0)|0) + 8|0);
   HEAP32[$46>>2] = 0;
   $47 = HEAP32[$28>>2]|0;
   $48 = ((($47) + (($i$041$us*24)|0)|0) + 4|0);
   HEAP32[$48>>2] = 0;
   $49 = HEAP32[$28>>2]|0;
   $50 = ((($49) + (($i$041$us*24)|0)|0) + 12|0);
   HEAP32[$50>>2] = 0;
   $51 = HEAP32[$28>>2]|0;
   $52 = ((($51) + (($i$041$us*24)|0)|0) + 16|0);
   HEAP32[$52>>2] = 0;
   $53 = HEAP32[$28>>2]|0;
   $54 = ((($53) + (($i$041$us*24)|0)|0) + 20|0);
   HEAP32[$54>>2] = 0;
   $55 = HEAP32[$40>>2]|0;
   $56 = ((($55) + (($i$041$us*24)|0)|0) + 8|0);
   HEAP32[$56>>2] = 0;
   $57 = HEAP32[$40>>2]|0;
   $58 = ((($57) + (($i$041$us*24)|0)|0) + 4|0);
   HEAP32[$58>>2] = 0;
   $59 = HEAP32[$40>>2]|0;
   $60 = ((($59) + (($i$041$us*24)|0)|0) + 12|0);
   HEAP32[$60>>2] = 0;
   $61 = HEAP32[$40>>2]|0;
   $62 = ((($61) + (($i$041$us*24)|0)|0) + 16|0);
   HEAP32[$62>>2] = 0;
   $63 = HEAP32[$40>>2]|0;
   $64 = ((($63) + (($i$041$us*24)|0)|0) + 20|0);
   HEAP32[$64>>2] = 0;
   $65 = (($i$041$us) + 1)|0;
   $66 = ($65>>>0)<($41>>>0);
   if ($66) {
    $i$041$us = $65;
   } else {
    break;
   }
  }
  STACKTOP = sp;return ($16|0);
 } else {
  $i$041 = 0;
  while(1) {
   $67 = HEAP32[$arAlloc>>2]|0;
   $68 = HEAP32[$67>>2]|0;
   $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($arAlloc,$44,4)|0);
   $70 = HEAP32[$28>>2]|0;
   $71 = ((($70) + (($i$041*24)|0)|0) + 8|0);
   HEAP32[$71>>2] = $69;
   $72 = HEAP32[$arAlloc>>2]|0;
   $73 = HEAP32[$72>>2]|0;
   $74 = (FUNCTION_TABLE_iiii[$73 & 2047]($arAlloc,$44,4)|0);
   $75 = HEAP32[$28>>2]|0;
   $76 = ((($75) + (($i$041*24)|0)|0) + 4|0);
   HEAP32[$76>>2] = $74;
   $77 = HEAP32[$arAlloc>>2]|0;
   $78 = HEAP32[$77>>2]|0;
   $79 = (FUNCTION_TABLE_iiii[$78 & 2047]($arAlloc,$44,4)|0);
   $80 = HEAP32[$28>>2]|0;
   $81 = ((($80) + (($i$041*24)|0)|0) + 12|0);
   HEAP32[$81>>2] = $79;
   $82 = HEAP32[$arAlloc>>2]|0;
   $83 = HEAP32[$82>>2]|0;
   $84 = (FUNCTION_TABLE_iiii[$83 & 2047]($arAlloc,$maxBlendedClip,1)|0);
   $85 = HEAP32[$28>>2]|0;
   $86 = ((($85) + (($i$041*24)|0)|0) + 16|0);
   HEAP32[$86>>2] = $84;
   $87 = HEAP32[$arAlloc>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   $89 = (FUNCTION_TABLE_iiii[$88 & 2047]($arAlloc,$44,4)|0);
   $90 = HEAP32[$28>>2]|0;
   $91 = ((($90) + (($i$041*24)|0)|0) + 20|0);
   HEAP32[$91>>2] = $89;
   $92 = HEAP32[$arAlloc>>2]|0;
   $93 = HEAP32[$92>>2]|0;
   $94 = (FUNCTION_TABLE_iiii[$93 & 2047]($arAlloc,$44,4)|0);
   $95 = HEAP32[$40>>2]|0;
   $96 = ((($95) + (($i$041*24)|0)|0) + 8|0);
   HEAP32[$96>>2] = $94;
   $97 = HEAP32[$arAlloc>>2]|0;
   $98 = HEAP32[$97>>2]|0;
   $99 = (FUNCTION_TABLE_iiii[$98 & 2047]($arAlloc,$44,4)|0);
   $100 = HEAP32[$40>>2]|0;
   $101 = ((($100) + (($i$041*24)|0)|0) + 4|0);
   HEAP32[$101>>2] = $99;
   $102 = HEAP32[$arAlloc>>2]|0;
   $103 = HEAP32[$102>>2]|0;
   $104 = (FUNCTION_TABLE_iiii[$103 & 2047]($arAlloc,$44,4)|0);
   $105 = HEAP32[$40>>2]|0;
   $106 = ((($105) + (($i$041*24)|0)|0) + 12|0);
   HEAP32[$106>>2] = $104;
   $107 = HEAP32[$arAlloc>>2]|0;
   $108 = HEAP32[$107>>2]|0;
   $109 = (FUNCTION_TABLE_iiii[$108 & 2047]($arAlloc,$maxBlendedClip,1)|0);
   $110 = HEAP32[$40>>2]|0;
   $111 = ((($110) + (($i$041*24)|0)|0) + 16|0);
   HEAP32[$111>>2] = $109;
   $112 = HEAP32[$arAlloc>>2]|0;
   $113 = HEAP32[$112>>2]|0;
   $114 = (FUNCTION_TABLE_iiii[$113 & 2047]($arAlloc,$44,4)|0);
   $$pre = HEAP32[$13>>2]|0;
   $115 = HEAP32[$40>>2]|0;
   $116 = ((($115) + (($i$041*24)|0)|0) + 20|0);
   HEAP32[$116>>2] = $114;
   $117 = (($i$041) + 1)|0;
   $118 = ($117>>>0)<($$pre>>>0);
   if ($118) {
    $i$041 = $117;
   } else {
    break;
   }
  }
  STACKTOP = sp;return ($16|0);
 }
 return 0|0;
}
function __ZN7mecanim12statemachine25DestroyStateMachineOutputEPNS0_18StateMachineOutputERNS_6memory9AllocatorE($apStateMachineOutput,$arAlloc) {
 $apStateMachineOutput = $apStateMachineOutput|0;
 $arAlloc = $arAlloc|0;
 var $$lcssa1 = 0, $$pre = 0, $$pre$phi5Z2D = 0, $$pre$phiZ2D = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($apStateMachineOutput|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($apStateMachineOutput) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 $4 = HEAP32[$arAlloc>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 if ($3) {
  $$pre = (($apStateMachineOutput) + 4|0);
  $$pre4 = (($apStateMachineOutput) + 28|0);
  $$lcssa1 = $6;$$pre$phi5Z2D = $$pre4;$$pre$phiZ2D = $$pre;
 } else {
  $7 = (($apStateMachineOutput) + 28|0);
  $8 = (($apStateMachineOutput) + 4|0);
  $12 = $6;$i$02 = 0;
  while(1) {
   $9 = HEAP32[$7>>2]|0;
   $10 = ((($9) + (($i$02*24)|0)|0) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_vii[$12 & 4095]($arAlloc,$11);
   $13 = HEAP32[$arAlloc>>2]|0;
   $14 = (($13) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$7>>2]|0;
   $17 = ((($16) + (($i$02*24)|0)|0) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   FUNCTION_TABLE_vii[$15 & 4095]($arAlloc,$18);
   $19 = HEAP32[$arAlloc>>2]|0;
   $20 = (($19) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$7>>2]|0;
   $23 = ((($22) + (($i$02*24)|0)|0) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_vii[$21 & 4095]($arAlloc,$24);
   $25 = HEAP32[$arAlloc>>2]|0;
   $26 = (($25) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$7>>2]|0;
   $29 = ((($28) + (($i$02*24)|0)|0) + 16|0);
   $30 = HEAP32[$29>>2]|0;
   FUNCTION_TABLE_vii[$27 & 4095]($arAlloc,$30);
   $31 = HEAP32[$arAlloc>>2]|0;
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP32[$7>>2]|0;
   $35 = ((($34) + (($i$02*24)|0)|0) + 20|0);
   $36 = HEAP32[$35>>2]|0;
   FUNCTION_TABLE_vii[$33 & 4095]($arAlloc,$36);
   $37 = HEAP32[$arAlloc>>2]|0;
   $38 = (($37) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$8>>2]|0;
   $41 = ((($40) + (($i$02*24)|0)|0) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   FUNCTION_TABLE_vii[$39 & 4095]($arAlloc,$42);
   $43 = HEAP32[$arAlloc>>2]|0;
   $44 = (($43) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$8>>2]|0;
   $47 = ((($46) + (($i$02*24)|0)|0) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   FUNCTION_TABLE_vii[$45 & 4095]($arAlloc,$48);
   $49 = HEAP32[$arAlloc>>2]|0;
   $50 = (($49) + 4|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = HEAP32[$8>>2]|0;
   $53 = ((($52) + (($i$02*24)|0)|0) + 12|0);
   $54 = HEAP32[$53>>2]|0;
   FUNCTION_TABLE_vii[$51 & 4095]($arAlloc,$54);
   $55 = HEAP32[$arAlloc>>2]|0;
   $56 = (($55) + 4|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = HEAP32[$8>>2]|0;
   $59 = ((($58) + (($i$02*24)|0)|0) + 16|0);
   $60 = HEAP32[$59>>2]|0;
   FUNCTION_TABLE_vii[$57 & 4095]($arAlloc,$60);
   $61 = HEAP32[$arAlloc>>2]|0;
   $62 = (($61) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = HEAP32[$8>>2]|0;
   $65 = ((($64) + (($i$02*24)|0)|0) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   FUNCTION_TABLE_vii[$63 & 4095]($arAlloc,$66);
   $67 = (($i$02) + 1)|0;
   $68 = HEAP32[$1>>2]|0;
   $69 = ($67>>>0)<($68>>>0);
   $70 = HEAP32[$arAlloc>>2]|0;
   $71 = (($70) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   if ($69) {
    $12 = $72;$i$02 = $67;
   } else {
    $$lcssa1 = $72;$$pre$phi5Z2D = $7;$$pre$phiZ2D = $8;
    break;
   }
  }
 }
 $73 = HEAP32[$$pre$phiZ2D>>2]|0;
 FUNCTION_TABLE_vii[$$lcssa1 & 4095]($arAlloc,$73);
 $74 = HEAP32[$arAlloc>>2]|0;
 $75 = (($74) + 4|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = HEAP32[$$pre$phi5Z2D>>2]|0;
 FUNCTION_TABLE_vii[$76 & 4095]($arAlloc,$77);
 $78 = HEAP32[$arAlloc>>2]|0;
 $79 = (($78) + 4|0);
 $80 = HEAP32[$79>>2]|0;
 FUNCTION_TABLE_vii[$80 & 4095]($arAlloc,$apStateMachineOutput);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine21DoBlendTreeEvaluationERKNS0_13StateConstantERNS0_11StateOutputERNS0_14StateWorkspaceERKNS_18ValueArrayConstantERKNS0_17StateMachineInputEifRKNS_9animation12AnimationSetE($arStateConstant,$arStateOutput,$arStateWorkspace,$arValues,$arStateMachineInput,$blendTreeIndex,$weight,$animationSet) {
 $arStateConstant = $arStateConstant|0;
 $arStateOutput = $arStateOutput|0;
 $arStateWorkspace = $arStateWorkspace|0;
 $arValues = $arValues|0;
 $arStateMachineInput = $arStateMachineInput|0;
 $blendTreeIndex = $blendTreeIndex|0;
 $weight = Math_fround($weight);
 $animationSet = $animationSet|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre42 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0);
 var $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $duration$0$lcssa = Math_fround(0), $duration$025 = Math_fround(0), $duration$1 = Math_fround(0), $effectiveDurationWeight$0$ph17 = Math_fround(0), $effectiveDurationWeight$0$ph19 = Math_fround(0), $i$022 = 0, $index$07 = 0, $index1$0 = 0, $index1$012 = 0, $index1$01218 = 0, $index1$01220 = 0, $index1$013 = 0, $leafIndex$09 = 0, $leafIndex$16 = 0;
 var $leafIndex$2 = 0, $phitmp2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($arStateConstant) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $duration$0$lcssa = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($duration$0$lcssa));
 }
 $3 = (($arStateConstant) + 16|0);
 $4 = $3;
 $5 = (($arStateConstant) + 36|0);
 $6 = $5;
 $7 = (($arStateMachineInput) + 4|0);
 $8 = (($arStateWorkspace) + 4|0);
 $9 = (($arStateWorkspace) + 8|0);
 $10 = (($arStateConstant) + 24|0);
 $11 = $10;
 $12 = (($arStateMachineInput) + 8|0);
 $13 = (($arStateOutput) + 4|0);
 $14 = (($arStateConstant) + 60|0);
 $15 = (($arStateConstant) + 71|0);
 $16 = (($arStateConstant) + 64|0);
 $162 = $1;$duration$025 = Math_fround(0.0);$i$022 = 0;
 while(1) {
  $17 = HEAP32[$3>>2]|0;
  $18 = (($17) + ($4))|0;
  $19 = $18;
  $20 = (($19) + ($i$022<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)==(-1);
  if ($22) {
   $161 = $162;$duration$1 = $duration$025;
  } else {
   $23 = HEAP32[$5>>2]|0;
   $24 = (($23) + ($6))|0;
   $25 = $24;
   $26 = (($25) + ($21<<3)|0);
   $27 = $26;
   $28 = HEAP32[$26>>2]|0;
   $29 = (($27) + ($28))|0;
   $30 = $29;
   $31 = ((($25) + ($21<<3)|0) + 4|0);
   HEAP32[$31>>2] = $30;
   $32 = ($29|0)==(0);
   if ($32) {
    $161 = $162;$duration$1 = $duration$025;
   } else {
    $33 = HEAP32[$7>>2]|0;
    $34 = HEAP32[$arStateWorkspace>>2]|0;
    $35 = (($34) + ($i$022<<2)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($36) + 4|0);
    HEAP32[$37>>2] = $33;
    $38 = HEAP32[$arStateWorkspace>>2]|0;
    $39 = (($38) + ($i$022<<2)|0);
    $40 = HEAP32[$39>>2]|0;
    HEAP32[$40>>2] = $arValues;
    $41 = HEAP32[$arStateWorkspace>>2]|0;
    $42 = (($41) + ($i$022<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[$8>>2]|0;
    $45 = (($44) + ($i$022<<2)|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = HEAP32[$9>>2]|0;
    $48 = (($47) + ($i$022<<2)|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = HEAP32[$10>>2]|0;
    $51 = (($50) + ($11))|0;
    $52 = $51;
    $53 = ((($52) + ($i$022<<4)|0) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    __ZN7mecanim9animation17EvaluateBlendTreeERKNS0_17BlendTreeConstantERKNS0_14BlendTreeInputERNS0_15BlendTreeOutputERNS0_18BlendTreeWorkspaceERKNS0_12AnimationSetEj($30,$43,$46,$49,$animationSet,$54);
    $55 = HEAP32[$8>>2]|0;
    $56 = (($55) + ($i$022<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($57) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59|0)==(0);
    L9: do {
     if (!($60)) {
      $$pre42 = HEAP32[$57>>2]|0;
      $index$07 = 0;$leafIndex$09 = 0;
      while(1) {
       $61 = ((($$pre42) + (($index$07*20)|0)|0) + 4|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = ($62|0)==(-1);
       if ($63) {
        break L9;
       }
       $64 = (($$pre42) + (($index$07*20)|0)|0);
       $65 = Math_fround(HEAPF32[$64>>2]);
       $66 = Math_fround($65 * $weight);
       $67 = HEAP32[$13>>2]|0;
       $68 = HEAP32[$67>>2]|0;
       $69 = (($68) + (($i$022*24)|0)|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = ((($68) + (($i$022*24)|0)|0) + 8|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = (($72) + ($70<<2)|0);
       HEAPF32[$73>>2] = $66;
       $74 = ((($$pre42) + (($index$07*20)|0)|0) + 8|0);
       $75 = Math_fround(HEAPF32[$74>>2]);
       $76 = Math_fround(HEAPF32[$14>>2]);
       $77 = Math_fround($75 * $76);
       $78 = ((($68) + (($i$022*24)|0)|0) + 12|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = (($79) + ($70<<2)|0);
       HEAPF32[$80>>2] = $77;
       $81 = ((($$pre42) + (($index$07*20)|0)|0) + 12|0);
       $82 = HEAP8[$81>>0]|0;
       $83 = ($82<<24>>24)==(0);
       $84 = HEAP8[$15>>0]|0;
       if ($83) {
        $88 = $84;
       } else {
        $phitmp2 = $84 ^ 1;
        $88 = $phitmp2;
       }
       $85 = ((($68) + (($i$022*24)|0)|0) + 16|0);
       $86 = HEAP32[$85>>2]|0;
       $87 = (($86) + ($70)|0);
       HEAP8[$87>>0] = $88;
       $89 = ((($$pre42) + (($index$07*20)|0)|0) + 16|0);
       $90 = Math_fround(HEAPF32[$89>>2]);
       $91 = Math_fround(HEAPF32[$16>>2]);
       $92 = Math_fround($90 + $91);
       $93 = ((($68) + (($i$022*24)|0)|0) + 20|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = (($94) + ($70<<2)|0);
       HEAPF32[$95>>2] = $92;
       $96 = HEAP32[$10>>2]|0;
       $97 = (($96) + ($11))|0;
       $98 = $97;
       $99 = (($98) + ($i$022<<4)|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = ($leafIndex$09>>>0)<($100>>>0);
       L18: do {
        if ($101) {
         $$phi$trans$insert = ((($98) + ($i$022<<4)|0) + 4|0);
         $$pre = HEAP32[$$phi$trans$insert>>2]|0;
         $leafIndex$16 = $leafIndex$09;
         while(1) {
          $104 = $$phi$trans$insert;
          $105 = (($$pre) + ($104))|0;
          $106 = $105;
          $107 = (($106) + ($leafIndex$16<<2)|0);
          $108 = HEAP32[$107>>2]|0;
          $109 = ($62|0)==($108|0);
          $103 = (($leafIndex$16) + 1)|0;
          if ($109) {
           break;
          }
          $102 = ($103>>>0)<($100>>>0);
          if ($102) {
           $leafIndex$16 = $103;
          } else {
           $leafIndex$2 = $103;
           break L18;
          }
         }
         $110 = ((($98) + ($i$022<<4)|0) + 12|0);
         $111 = HEAP32[$110>>2]|0;
         $112 = (($111) + ($leafIndex$16))|0;
         $113 = ((($68) + (($i$022*24)|0)|0) + 4|0);
         $114 = HEAP32[$113>>2]|0;
         $115 = (($114) + ($70<<2)|0);
         HEAP32[$115>>2] = $112;
         $116 = HEAP32[$69>>2]|0;
         $117 = (($116) + 1)|0;
         HEAP32[$69>>2] = $117;
         $leafIndex$2 = $103;
        } else {
         $leafIndex$2 = $leafIndex$09;
        }
       } while(0);
       $118 = (($index$07) + 1)|0;
       $119 = (($57) + 4|0);
       $120 = HEAP32[$119>>2]|0;
       $121 = ($118>>>0)<($120>>>0);
       if ($121) {
        $index$07 = $118;$leafIndex$09 = $leafIndex$2;
       } else {
        break;
       }
      }
     }
    } while(0);
    $122 = HEAP32[$0>>2]|0;
    $index1$01218 = (($122) + -1)|0;
    $123 = (($i$022) + 1)|0;
    $124 = ($index1$01218|0)<($123|0);
    L26: do {
     if ($124) {
      $effectiveDurationWeight$0$ph17 = Math_fround(1.0);
     } else {
      $125 = HEAP32[$3>>2]|0;
      $126 = (($125) + ($4))|0;
      $127 = $126;
      $effectiveDurationWeight$0$ph19 = Math_fround(1.0);$index1$01220 = $index1$01218;
      while(1) {
       $index1$013 = $index1$01220;
       while(1) {
        $128 = (($127) + ($index1$013<<2)|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = ($129|0)==(-1);
        if (!($130)) {
         $131 = HEAP32[$5>>2]|0;
         $132 = (($131) + ($6))|0;
         $133 = $132;
         $134 = (($133) + ($129<<3)|0);
         $135 = $134;
         $136 = HEAP32[$134>>2]|0;
         $137 = (($135) + ($136))|0;
         $138 = $137;
         $139 = ((($133) + ($129<<3)|0) + 4|0);
         HEAP32[$139>>2] = $138;
         $140 = ($137|0)==(0);
         if (!($140)) {
          break;
         }
        }
        $index1$0 = (($index1$013) + -1)|0;
        $141 = ($index1$0|0)<($123|0);
        if ($141) {
         $effectiveDurationWeight$0$ph17 = $effectiveDurationWeight$0$ph19;
         break L26;
        } else {
         $index1$013 = $index1$0;
        }
       }
       $142 = HEAP32[$12>>2]|0;
       $143 = (($142) + ($index1$013<<2)|0);
       $144 = Math_fround(HEAPF32[$143>>2]);
       $145 = Math_fround($effectiveDurationWeight$0$ph19 * $144);
       $146 = Math_fround($effectiveDurationWeight$0$ph19 - $145);
       $index1$012 = (($index1$013) + -1)|0;
       $147 = ($index1$012|0)<($123|0);
       if ($147) {
        $effectiveDurationWeight$0$ph17 = $146;
        break;
       } else {
        $effectiveDurationWeight$0$ph19 = $146;$index1$01220 = $index1$012;
       }
      }
     }
    } while(0);
    $148 = HEAP32[$8>>2]|0;
    $149 = (($148) + ($i$022<<2)|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = (($150) + 8|0);
    $152 = Math_fround(HEAPF32[$151>>2]);
    $153 = HEAP32[$12>>2]|0;
    $154 = (($153) + ($i$022<<2)|0);
    $155 = Math_fround(HEAPF32[$154>>2]);
    $156 = Math_fround($152 * $155);
    $157 = Math_fround($effectiveDurationWeight$0$ph17 * $156);
    $158 = Math_fround($duration$025 + $157);
    $161 = $122;$duration$1 = $158;
   }
  }
  $159 = (($i$022) + 1)|0;
  $160 = ($159>>>0)<($161>>>0);
  if ($160) {
   $162 = $161;$duration$025 = $duration$1;$i$022 = $159;
  } else {
   $duration$0$lcssa = $duration$1;
   break;
  }
 }
 STACKTOP = sp;return (Math_fround($duration$0$lcssa));
}
function __ZN7mecanim12statemachine13EvaluateStateERKNS_18ValueArrayConstantERKNS0_13StateConstantERKNS0_17StateMachineInputERNS0_18StateMachineMemoryERNS0_11StateOutputERNS0_14StateWorkspaceEbRKNS_9animation12AnimationSetE($apValues,$apStateConstant,$apStateMachineInput,$apStateMachineMemory,$apStateOutput,$apStateWorkspace,$currentState,$animationSet) {
 $apValues = $apValues|0;
 $apStateConstant = $apStateConstant|0;
 $apStateMachineInput = $apStateMachineInput|0;
 $apStateMachineMemory = $apStateMachineMemory|0;
 $apStateOutput = $apStateOutput|0;
 $apStateWorkspace = $apStateWorkspace|0;
 $currentState = $currentState|0;
 $animationSet = $animationSet|0;
 var $$in = 0, $$phi$trans$insert = 0, $$pre = Math_fround(0), $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apStateConstant) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $$phi$trans$insert = (($apStateOutput) + 4|0);
 $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
 if (!($2)) {
  $3 = HEAP32[$$pre3>>2]|0;
  $i$01 = 0;
  while(1) {
   $4 = (($3) + (($i$01*24)|0)|0);
   HEAP32[$4>>2] = 0;
   $5 = (($i$01) + 1)|0;
   $6 = HEAP32[$0>>2]|0;
   $7 = ($5>>>0)<($6>>>0);
   if ($7) {
    $i$01 = $5;
   } else {
    break;
   }
  }
 }
 $8 = (($apStateConstant) + 68|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = (($apStateOutput) + 4|0);
 $11 = (($$pre3) + 20|0);
 HEAP8[$11>>0] = $9;
 $12 = (($apStateConstant) + 69|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = (($$pre3) + 21|0);
 HEAP8[$14>>0] = $13;
 $15 = Math_fround(HEAPF32[$apStateMachineInput>>2]);
 $16 = (($apStateConstant) + 60|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (Math_fround(Math_abs((Math_fround($17)))));
 $19 = (Math_fround(__ZN7mecanim12statemachine21DoBlendTreeEvaluationERKNS0_13StateConstantERNS0_11StateOutputERNS0_14StateWorkspaceERKNS_18ValueArrayConstantERKNS0_17StateMachineInputEifRKNS_9animation12AnimationSetE($apStateConstant,$apStateOutput,$apStateWorkspace,$apValues,$apStateMachineInput,0,Math_fround(1.0),$animationSet)));
 $20 = Math_fround($19 / $18);
 HEAPF32[$apStateOutput>>2] = $20;
 $21 = $20 != Math_fround(0.0);
 $22 = $21 ? $20 : Math_fround(1.0);
 $23 = Math_fround($15 / $22);
 $24 = (($apStateMachineMemory) + 75|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)==(0);
 if ($26) {
  label = 7;
 } else {
  $27 = (($apStateMachineInput) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0);
  if ($30) {
   $31 = (($28) + 4|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = (($28) + 16|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = Math_fround($34 / $22);
   $36 = Math_fround($32 + $35);
   $37 = HEAP32[$10>>2]|0;
   $38 = (($37) + 4|0);
   HEAPF32[$38>>2] = $36;
   $39 = Math_fround($36 - $23);
   $40 = (($37) + 8|0);
   HEAPF32[$40>>2] = $39;
   HEAP8[$24>>0] = 0;
   HEAPF32[$33>>2] = Math_fround(0.0);
   $$pre = Math_fround(HEAPF32[$38>>2]);
   $49 = $$pre;$58 = $37;
  } else {
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $41 = (($apStateMachineMemory) + 36|0);
  $42 = (($apStateMachineMemory) + 40|0);
  $$in = $currentState ? $41 : $42;
  $43 = Math_fround(HEAPF32[$$in>>2]);
  $44 = Math_fround($23 + $43);
  $45 = HEAP32[$10>>2]|0;
  $46 = (($45) + 4|0);
  HEAPF32[$46>>2] = $44;
  $47 = (($45) + 8|0);
  HEAPF32[$47>>2] = $43;
  $49 = $44;$58 = $45;
 }
 if ($currentState) {
  $48 = (($apStateMachineMemory) + 36|0);
  HEAPF32[$48>>2] = $49;
  $50 = Math_fround(HEAPF32[$apStateOutput>>2]);
  $51 = (($apStateMachineMemory) + 44|0);
  HEAPF32[$51>>2] = $50;
 } else {
  $52 = (($apStateMachineMemory) + 40|0);
  HEAPF32[$52>>2] = $49;
  $53 = Math_fround(HEAPF32[$apStateOutput>>2]);
  $54 = (($apStateMachineMemory) + 48|0);
  HEAPF32[$54>>2] = $53;
 }
 $55 = (($apStateConstant) + 52|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($58) + 12|0);
 HEAP32[$57>>2] = $56;
 $59 = (($58) + 16|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $60 & 128;
 $62 = ($61|0)==(0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = (($apStateMachineInput) + 16|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(1);
 $66 = $65 ? 25 : 28;
 HEAP32[$59>>2] = $66;
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine17EvaluateConditionEPKNS0_17ConditionConstantEPKNS_18ValueArrayConstantEPKNS_10ValueArrayE($apConditionConstant,$apValueArrayConst,$apValueArray) {
 $apConditionConstant = $apConditionConstant|0;
 $apValueArrayConst = $apValueArrayConst|0;
 $apValueArray = $apValueArray|0;
 var $$ = 0, $$0 = 0, $$off = 0, $$off1 = 0, $$off3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, $switch = 0, $switch2 = 0, $switch4 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$apConditionConstant>>2]|0;
 switch ($0|0) {
 case 7: case 6: case 4: case 3: case 2: case 1:  {
  break;
 }
 default: {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 $1 = (($apConditionConstant) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj($apValueArrayConst,$2)|0);
 $4 = ($3|0)>(-1);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($apValueArrayConst) + 4|0);
 $6 = $5;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($7) + ($6))|0;
 $9 = $8;
 $10 = ((($9) + ($3<<4)|0) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 if ((($11|0) == 9) | (($11|0) == 4)) {
  $12 = HEAP32[$apConditionConstant>>2]|0;
  $$off = (($12) + -1)|0;
  $switch = ($$off>>>0)<(2);
  if ($switch) {
   $13 = ((($9) + ($3<<4)|0) + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($apValueArray) + 4|0);
   $16 = $15;
   $17 = HEAP32[$15>>2]|0;
   $18 = (($17) + ($16))|0;
   $19 = $18;
   $20 = (($19) + ($14)|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = ($21<<24>>24)!=(0);
   $not$ = ($12|0)!=(1);
   $$ = $22 ^ $not$;
   $$0 = $$;
   STACKTOP = sp;return ($$0|0);
  } else {
   $39 = $12;
  }
 } else {
  $$pre = HEAP32[$apConditionConstant>>2]|0;
  $23 = ($11|0)==(3);
  if ($23) {
   $$off1 = (($$pre) + -6)|0;
   $switch2 = ($$off1>>>0)<(2);
   if ($switch2) {
    $24 = ((($9) + ($3<<4)|0) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($apValueArray) + 16|0);
    $27 = $26;
    $28 = HEAP32[$26>>2]|0;
    $29 = (($28) + ($27))|0;
    $30 = $29;
    $31 = (($30) + ($25<<2)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($$pre|0)==(6);
    $34 = (Math_fround(($32|0)));
    $35 = (($apConditionConstant) + 8|0);
    $36 = Math_fround(HEAPF32[$35>>2]);
    if ($33) {
     $37 = $34 == $36;
     $$0 = $37;
     STACKTOP = sp;return ($$0|0);
    } else {
     $38 = $34 != $36;
     $$0 = $38;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $39 = $$pre;
   }
  } else {
   $39 = $$pre;
  }
 }
 $$off3 = (($39) + -3)|0;
 $switch4 = ($$off3>>>0)<(2);
 if (!($switch4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ((($11|0) == 3)) {
  $54 = ((($9) + ($3<<4)|0) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($apValueArray) + 16|0);
  $57 = $56;
  $58 = HEAP32[$56>>2]|0;
  $59 = (($58) + ($57))|0;
  $60 = $59;
  $61 = (($60) + ($55<<2)|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($39|0)==(3);
  $64 = (Math_fround(($62|0)));
  $65 = (($apConditionConstant) + 8|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  if ($63) {
   $67 = $64 > $66;
   $$0 = $67;
   STACKTOP = sp;return ($$0|0);
  } else {
   $68 = $64 < $66;
   $$0 = $68;
   STACKTOP = sp;return ($$0|0);
  }
 } else if ((($11|0) == 1)) {
  $40 = ((($9) + ($3<<4)|0) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($apValueArray) + 28|0);
  $43 = $42;
  $44 = HEAP32[$42>>2]|0;
  $45 = (($44) + ($43))|0;
  $46 = $45;
  $47 = (($46) + ($41<<2)|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = ($39|0)==(3);
  $50 = (($apConditionConstant) + 8|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  if ($49) {
   $52 = $48 > $51;
   $$0 = $52;
   STACKTOP = sp;return ($$0|0);
  } else {
   $53 = $48 < $51;
   $$0 = $53;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN7mecanim12statemachine18EvaluateTransitionEPKNS0_18TransitionConstantEPKNS0_15TransitionInputEPNS0_16TransitionOutputEPKNS0_16TransitionMemoryEPNS0_21StateMachineWorkspaceE($apTransitionConstant,$apTransitionInput,$apTransitionOutput,$apTransitionMemory,$apStateMachineWorkspace) {
 $apTransitionConstant = $apTransitionConstant|0;
 $apTransitionInput = $apTransitionInput|0;
 $apTransitionOutput = $apTransitionOutput|0;
 $apTransitionMemory = $apTransitionMemory|0;
 $apStateMachineWorkspace = $apStateMachineWorkspace|0;
 var $$pr6 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $conditionIndex$01$i = 0, $conditionIndex$02 = 0, $currentTimeHigh$0 = Math_fround(0), $exitcond$i = 0, $or$cond = 0, $or$cond1 = 0, $previousTimeLow$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$apTransitionConstant>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = $1&1;
 HEAP8[$apTransitionOutput>>0] = $2;
 $3 = (($apTransitionOutput) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($apTransitionConstant) + 40|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 do {
  if ($6) {
   if ($1) {
    $$pr6 = $2;
   } else {
    STACKTOP = sp;return;
   }
  } else {
   HEAP8[$apTransitionOutput>>0] = 0;
   $7 = (($apTransitionConstant) + 36|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   $9 = !($8 <= Math_fround(1.0));
   $10 = (($apTransitionInput) + 16|0);
   $11 = Math_fround(HEAPF32[$10>>2]);
   if ($9) {
    $27 = $11 < $8;
    if (!($27)) {
     STACKTOP = sp;return;
    }
    $28 = (($apTransitionInput) + 12|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = !($29 >= $8);
    if ($30) {
     STACKTOP = sp;return;
    } else {
     HEAP8[$apTransitionOutput>>0] = 1;
     $31 = Math_fround($29 - $8);
     HEAPF32[$3>>2] = $31;
     $$pr6 = 1;
     break;
    }
   }
   $12 = (Math_fround(+(_truncf((+$11)))));
   $13 = Math_fround($11 - $12);
   $14 = (($apTransitionInput) + 12|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   $16 = (Math_fround(+(_truncf((+$15)))));
   $17 = Math_fround($15 - $16);
   $18 = $13 > $17;
   if ($18) {
    $19 = Math_fround($13 + Math_fround(-1.0));
    $20 = Math_fround($17 + Math_fround(1.0));
    $currentTimeHigh$0 = $20;$previousTimeLow$0 = $19;
   } else {
    $currentTimeHigh$0 = $17;$previousTimeLow$0 = $13;
   }
   $21 = !($previousTimeLow$0 < $8);
   $22 = !($17 >= $8);
   $or$cond = $21 | $22;
   if (!($or$cond)) {
    HEAP8[$apTransitionOutput>>0] = 1;
    $23 = Math_fround($17 - $8);
    HEAPF32[$3>>2] = $23;
    $$pr6 = 1;
    break;
   }
   $24 = !($13 < $8);
   $25 = !($currentTimeHigh$0 >= $8);
   $or$cond1 = $24 | $25;
   if ($or$cond1) {
    STACKTOP = sp;return;
   } else {
    HEAP8[$apTransitionOutput>>0] = 1;
    $26 = Math_fround($currentTimeHigh$0 - $8);
    HEAPF32[$3>>2] = $26;
    $$pr6 = 1;
    break;
   }
  }
 } while(0);
 $32 = (($apTransitionConstant) + 4|0);
 $33 = $32;
 $35 = $0;$87 = $$pr6;$conditionIndex$02 = 0;
 while(1) {
  $34 = ($conditionIndex$02>>>0)<($35>>>0);
  if (!($34)) {
   $51 = $87;
   break;
  }
  $36 = HEAP32[$32>>2]|0;
  $37 = (($36) + ($33))|0;
  $38 = $37;
  $39 = (($38) + ($conditionIndex$02<<3)|0);
  $40 = $39;
  $41 = HEAP32[$39>>2]|0;
  $42 = (($40) + ($41))|0;
  $43 = $42;
  $44 = ((($38) + ($conditionIndex$02<<3)|0) + 4|0);
  HEAP32[$44>>2] = $43;
  $45 = HEAP32[$apTransitionMemory>>2]|0;
  $46 = HEAP32[$apTransitionInput>>2]|0;
  $47 = (__ZN7mecanim12statemachine17EvaluateConditionEPKNS0_17ConditionConstantEPKNS_18ValueArrayConstantEPKNS_10ValueArrayE($43,$45,$46)|0);
  $48 = $47&1;
  HEAP8[$apTransitionOutput>>0] = $48;
  if (!($47)) {
   $51 = $48;
   break;
  }
  $49 = (($conditionIndex$02) + 1)|0;
  $$pre = HEAP32[$apTransitionConstant>>2]|0;
  $35 = $$pre;$87 = $48;$conditionIndex$02 = $49;
 }
 $50 = ($51<<24>>24)==(0);
 if ($50) {
  STACKTOP = sp;return;
 }
 $52 = (($apTransitionConstant) + 4|0);
 $53 = HEAP32[$apTransitionConstant>>2]|0;
 $54 = HEAP32[$apTransitionMemory>>2]|0;
 $55 = ($53|0)==(0);
 if ($55) {
  STACKTOP = sp;return;
 }
 $56 = $52;
 $57 = (($54) + 4|0);
 $58 = $57;
 $59 = (($apStateMachineWorkspace) + 8|0);
 $conditionIndex$01$i = 0;
 while(1) {
  $60 = HEAP32[$52>>2]|0;
  $61 = (($60) + ($56))|0;
  $62 = $61;
  $63 = (($62) + ($conditionIndex$01$i<<3)|0);
  $64 = $63;
  $65 = HEAP32[$63>>2]|0;
  $66 = (($64) + ($65))|0;
  $67 = $66;
  $68 = ((($62) + ($conditionIndex$01$i<<3)|0) + 4|0);
  HEAP32[$68>>2] = $67;
  $69 = HEAP32[$67>>2]|0;
  $70 = ($69|0)==(1);
  if ($70) {
   $71 = (($67) + 4|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (__ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj($54,$72)|0);
   $74 = ($73|0)>(-1);
   if ($74) {
    $75 = HEAP32[$57>>2]|0;
    $76 = (($75) + ($58))|0;
    $77 = $76;
    $78 = ((($77) + ($73<<4)|0) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($79|0)==(9);
    if ($80) {
     $81 = ((($77) + ($73<<4)|0) + 12|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = HEAP32[$59>>2]|0;
     $84 = HEAP32[$83>>2]|0;
     $85 = (($84) + ($82)|0);
     HEAP8[$85>>0] = 1;
    }
   }
  }
  $86 = (($conditionIndex$01$i) + 1)|0;
  $exitcond$i = ($86|0)==($53|0);
  if ($exitcond$i) {
   break;
  } else {
   $conditionIndex$01$i = $86;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine17EvaluateSelectorsEPKNS0_20StateMachineConstantEPKNS_18ValueArrayConstantEPNS_10ValueArrayEjPKNS0_17StateMachineInputEPNS0_18StateMachineMemoryEPNS0_21StateMachineWorkspaceE($apStateMachineConstant,$apValueArrayConstant,$apValueArray,$aDestinationIndex,$apStateMachineInput,$apStateMachineMemory,$apStateMachineWorkspace) {
 $apStateMachineConstant = $apStateMachineConstant|0;
 $apValueArrayConstant = $apValueArrayConstant|0;
 $apValueArray = $apValueArray|0;
 $aDestinationIndex = $aDestinationIndex|0;
 $apStateMachineInput = $apStateMachineInput|0;
 $apStateMachineMemory = $apStateMachineMemory|0;
 $apStateMachineWorkspace = $apStateMachineWorkspace|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $aDestinationIndex$tr = 0, $conditionIndex$01$i = 0, $exitcond$i = 0, $i$01$i = 0, $i$06 = 0, $or$cond = 0, $storemerge = 0, $storemerge$v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($apStateMachineInput) + 20|0);
 $1 = (($apStateMachineConstant) + 28|0);
 $2 = $1;
 $3 = (($apStateMachineMemory) + 32|0);
 $4 = (($apValueArrayConstant) + 4|0);
 $5 = $4;
 $6 = (($apStateMachineWorkspace) + 8|0);
 $aDestinationIndex$tr = $aDestinationIndex;
 L1: while(1) {
  $7 = HEAP32[$0>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $12 = 0;
  } else {
   $9 = (__ZNK27StateMachineBehaviourPlayer15IsSenderEnabledEv($7)|0);
   $10 = $9 ^ 1;
   $12 = $10;
  }
  $11 = ($aDestinationIndex$tr|0)==(-1);
  $or$cond = $12 | $11;
  if ($or$cond) {
   $$0 = 0;
   label = 23;
   break;
  }
  $13 = ($aDestinationIndex$tr>>>0)<(30000);
  if ($13) {
   $$0 = $aDestinationIndex$tr;
   label = 23;
   break;
  }
  $14 = (($aDestinationIndex$tr) + -30000)|0;
  $15 = HEAP32[$1>>2]|0;
  $16 = (($15) + ($2))|0;
  $17 = $16;
  $18 = (($17) + ($14<<3)|0);
  $19 = $18;
  $20 = HEAP32[$18>>2]|0;
  $21 = (($19) + ($20))|0;
  $22 = $21;
  $23 = ((($17) + ($14<<3)|0) + 4|0);
  HEAP32[$23>>2] = $22;
  $24 = (($22) + 16|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(0);
  $27 = HEAP32[$3>>2]|0;
  $storemerge$v = $26 ? 4 : 2;
  $storemerge = $storemerge$v | $27;
  HEAP32[$3>>2] = $storemerge;
  $28 = HEAP32[$0>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = (($22) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($25<<24>>24)!=(0);
   $33 = $32 ? 32 : 64;
   (__ZNK27StateMachineBehaviourPlayer25FireStateMachineBehaviourEiN7mecanim12statemachine19StateMachineMessageE($28,$31,$33)|0);
   $$pr = HEAP32[$0>>2]|0;
   $34 = ($$pr|0)==(0|0);
   if (!($34)) {
    $35 = (__ZNK27StateMachineBehaviourPlayer15IsSenderEnabledEv($$pr)|0);
    if (!($35)) {
     $$0 = 0;
     label = 23;
     break;
    }
   }
  }
  $36 = HEAP32[$22>>2]|0;
  $37 = ($36|0)==(0);
  if ($37) {
   $$0 = 0;
   label = 23;
   break;
  }
  $38 = (($22) + 4|0);
  $39 = $38;
  $i$06 = 0;
  L13: while(1) {
   $40 = HEAP32[$38>>2]|0;
   $41 = (($40) + ($39))|0;
   $42 = $41;
   $43 = (($42) + ($i$06<<3)|0);
   $44 = $43;
   $45 = HEAP32[$43>>2]|0;
   $46 = (($44) + ($45))|0;
   $47 = $46;
   $48 = ((($42) + ($i$06<<3)|0) + 4|0);
   HEAP32[$48>>2] = $47;
   $49 = (($47) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($50|0)==(0);
   if ($51) {
    break;
   }
   $52 = (($47) + 8|0);
   $53 = $52;
   $i$01$i = 0;
   while(1) {
    $57 = HEAP32[$52>>2]|0;
    $58 = (($57) + ($53))|0;
    $59 = $58;
    $60 = (($59) + ($i$01$i<<3)|0);
    $61 = $60;
    $62 = HEAP32[$60>>2]|0;
    $63 = (($61) + ($62))|0;
    $64 = $63;
    $65 = ((($59) + ($i$01$i<<3)|0) + 4|0);
    HEAP32[$65>>2] = $64;
    $66 = (__ZN7mecanim12statemachine17EvaluateConditionEPKNS0_17ConditionConstantEPKNS_18ValueArrayConstantEPKNS_10ValueArrayE($64,$apValueArrayConstant,$apValueArray)|0);
    $56 = (($i$01$i) + 1)|0;
    if (!($66)) {
     break;
    }
    $54 = HEAP32[$49>>2]|0;
    $55 = ($56>>>0)<($54>>>0);
    if ($55) {
     $i$01$i = $56;
    } else {
     label = 15;
     break L13;
    }
   }
   $96 = (($i$06) + 1)|0;
   $97 = HEAP32[$22>>2]|0;
   $98 = ($96>>>0)<($97>>>0);
   if ($98) {
    $i$06 = $96;
   } else {
    $$0 = 0;
    label = 23;
    break L1;
   }
  }
  if ((label|0) == 15) {
   label = 0;
   $67 = ($54|0)==(0);
   if (!($67)) {
    $conditionIndex$01$i = 0;
    while(1) {
     $68 = HEAP32[$52>>2]|0;
     $69 = (($68) + ($53))|0;
     $70 = $69;
     $71 = (($70) + ($conditionIndex$01$i<<3)|0);
     $72 = $71;
     $73 = HEAP32[$71>>2]|0;
     $74 = (($72) + ($73))|0;
     $75 = $74;
     $76 = ((($70) + ($conditionIndex$01$i<<3)|0) + 4|0);
     HEAP32[$76>>2] = $75;
     $77 = HEAP32[$75>>2]|0;
     $78 = ($77|0)==(1);
     if ($78) {
      $79 = (($75) + 4|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (__ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj($apValueArrayConstant,$80)|0);
      $82 = ($81|0)>(-1);
      if ($82) {
       $83 = HEAP32[$4>>2]|0;
       $84 = (($83) + ($5))|0;
       $85 = $84;
       $86 = ((($85) + ($81<<4)|0) + 8|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($87|0)==(9);
       if ($88) {
        $89 = ((($85) + ($81<<4)|0) + 12|0);
        $90 = HEAP32[$89>>2]|0;
        $91 = HEAP32[$6>>2]|0;
        $92 = HEAP32[$91>>2]|0;
        $93 = (($92) + ($90)|0);
        HEAP8[$93>>0] = 1;
       }
      }
     }
     $94 = (($conditionIndex$01$i) + 1)|0;
     $exitcond$i = ($94|0)==($54|0);
     if ($exitcond$i) {
      break;
     } else {
      $conditionIndex$01$i = $94;
     }
    }
   }
  }
  $95 = HEAP32[$47>>2]|0;
  $aDestinationIndex$tr = $95;
 }
 if ((label|0) == 23) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN7mecanim12statemachine19EvaluateTransitionsERK9OffsetPtrIS1_INS0_18TransitionConstantEEEjRNS0_15TransitionInputERNS0_16TransitionOutputERNS0_16TransitionMemoryEPKNS0_20StateMachineConstantEPKNS0_17StateMachineInputEPNS0_18StateMachineOutputEPNS0_18StateMachineMemoryEPNS0_21StateMachineWorkspaceEi($transitionConstantArray,$transitionCount,$transitionInput,$transitionOutput,$transitionMemory,$apStateMachineConstant,$apStateMachineInput,$apStateMachineOutput,$apStateMachineMemory,$apStateMachineWorkspace,$sourceStateIndex) {
 $transitionConstantArray = $transitionConstantArray|0;
 $transitionCount = $transitionCount|0;
 $transitionInput = $transitionInput|0;
 $transitionOutput = $transitionOutput|0;
 $transitionMemory = $transitionMemory|0;
 $apStateMachineConstant = $apStateMachineConstant|0;
 $apStateMachineInput = $apStateMachineInput|0;
 $apStateMachineOutput = $apStateMachineOutput|0;
 $apStateMachineMemory = $apStateMachineMemory|0;
 $apStateMachineWorkspace = $apStateMachineWorkspace|0;
 $sourceStateIndex = $sourceStateIndex|0;
 var $$0 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0);
 var $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($transitionCount|0)==(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = $transitionConstantArray;
 $2 = (($apStateMachineMemory) + 73|0);
 $3 = (($transitionMemory) + 4|0);
 $4 = (($apStateMachineMemory) + 12|0);
 $i$03 = 0;
 while(1) {
  $5 = HEAP32[$transitionConstantArray>>2]|0;
  $6 = (($5) + ($1))|0;
  $7 = $6;
  $8 = (($7) + ($i$03<<3)|0);
  $9 = $8;
  $10 = HEAP32[$8>>2]|0;
  $11 = (($9) + ($10))|0;
  $12 = $11;
  $13 = ((($7) + ($i$03<<3)|0) + 4|0);
  HEAP32[$13>>2] = $12;
  $14 = HEAP8[$2>>0]|0;
  HEAP8[$3>>0] = $14;
  __ZN7mecanim12statemachine18EvaluateTransitionEPKNS0_18TransitionConstantEPKNS0_15TransitionInputEPNS0_16TransitionOutputEPKNS0_16TransitionMemoryEPNS0_21StateMachineWorkspaceE($12,$transitionInput,$transitionOutput,$transitionMemory,$apStateMachineWorkspace);
  $15 = HEAP8[$transitionOutput>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if (!($16)) {
   $17 = (($12) + 49|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if (!($19)) {
    break;
   }
   $20 = HEAP8[$2>>0]|0;
   $21 = ($20<<24>>24)==(0);
   if (!($21)) {
    break;
   }
   $22 = (($12) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$4>>2]|0;
   $25 = ($23|0)==($24|0);
   if (!($25)) {
    break;
   }
   HEAP8[$transitionOutput>>0] = 0;
  }
  $85 = (($i$03) + 1)|0;
  $86 = ($85>>>0)<($transitionCount>>>0);
  if ($86) {
   $i$03 = $85;
  } else {
   $$0 = 0;
   label = 12;
   break;
  }
 }
 if ((label|0) == 12) {
  STACKTOP = sp;return ($$0|0);
 }
 $26 = HEAP8[$2>>0]|0;
 $27 = (($apStateMachineMemory) + 72|0);
 HEAP8[$27>>0] = $26;
 HEAP8[$2>>0] = 1;
 $28 = (($apStateMachineMemory) + 32|0);
 HEAP32[$28>>2] = 1;
 $29 = (($apStateMachineWorkspace) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($apStateMachineInput) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($12) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (__ZN7mecanim12statemachine17EvaluateSelectorsEPKNS0_20StateMachineConstantEPKNS_18ValueArrayConstantEPNS_10ValueArrayEjPKNS0_17StateMachineInputEPNS0_18StateMachineMemoryEPNS0_21StateMachineWorkspaceE($apStateMachineConstant,$30,$32,$34,$apStateMachineInput,$apStateMachineMemory,$apStateMachineWorkspace)|0);
 $36 = (($apStateMachineMemory) + 16|0);
 HEAP32[$36>>2] = $35;
 $37 = (($apStateMachineInput) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = (__ZNK27StateMachineBehaviourPlayer15IsSenderEnabledEv($38)|0);
  if (!($40)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $41 = (($apStateMachineMemory) + 24|0);
 HEAP32[$41>>2] = $i$03;
 $42 = (($apStateMachineMemory) + 28|0);
 HEAP32[$42>>2] = $sourceStateIndex;
 $43 = (($12) + 28|0);
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($apStateMachineMemory) + 64|0);
 HEAPF32[$45>>2] = $44;
 $46 = (($12) + 32|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($apStateMachineMemory) + 68|0);
 HEAPF32[$48>>2] = $47;
 $49 = (($apStateMachineMemory) + 60|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($12) + 40|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = ($51<<24>>24)==(0);
 $53 = (($12) + 36|0);
 $54 = (($transitionInput) + 12|0);
 $$in = $52 ? $54 : $53;
 $55 = Math_fround(HEAPF32[$$in>>2]);
 $56 = (($apStateMachineMemory) + 56|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($apStateMachineMemory) + 75|0);
 HEAP8[$57>>0] = 1;
 $58 = (($apStateMachineInput) + 12|0);
 $59 = HEAP32[$58>>2]|0;
 HEAP32[$59>>2] = 0;
 $60 = Math_fround(HEAPF32[$46>>2]);
 $61 = (($59) + 4|0);
 HEAPF32[$61>>2] = $60;
 $62 = (($transitionOutput) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($apStateMachineMemory) + 44|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = $65 == Math_fround(inf);
 $67 = $66 ? Math_fround(0.0) : $65;
 $68 = Math_fround($63 * $67);
 $69 = (($59) + 16|0);
 HEAPF32[$69>>2] = $68;
 $70 = (($apStateMachineConstant) + 4|0);
 $71 = HEAP32[$36>>2]|0;
 $72 = $70;
 $73 = HEAP32[$70>>2]|0;
 $74 = (($73) + ($72))|0;
 $75 = $74;
 $76 = (($75) + ($71<<3)|0);
 $77 = $76;
 $78 = HEAP32[$76>>2]|0;
 $79 = (($77) + ($78))|0;
 $80 = $79;
 $81 = (($80) + 52|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($apStateMachineOutput) + 40|0);
 HEAP32[$83>>2] = $82;
 $84 = (($apStateMachineOutput) + 44|0);
 HEAP32[$84>>2] = 25;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7mecanim12statemachine20EvaluateStateMachineERKNS0_20StateMachineConstantERKNS0_17StateMachineInputERNS0_18StateMachineOutputERNS0_18StateMachineMemoryERNS0_21StateMachineWorkspaceERKNS_9animation12AnimationSetE($stateMachineConstant,$stateMachineInput,$stateMachineOutput,$stateMachineMemory,$stateMachineWorkspace,$animationSet) {
 $stateMachineConstant = $stateMachineConstant|0;
 $stateMachineInput = $stateMachineInput|0;
 $stateMachineOutput = $stateMachineOutput|0;
 $stateMachineMemory = $stateMachineMemory|0;
 $stateMachineWorkspace = $stateMachineWorkspace|0;
 $animationSet = $animationSet|0;
 var $$ = 0, $$0$i = 0, $$0$i11 = 0, $$0$i1113 = 0, $$0$i6 = 0, $$0$i714 = 0, $$0$in$i = 0, $$not = 0, $$not19 = 0, $$not1954 = 0, $$not1956 = 0, $$not27 = 0, $$op = 0, $$pre = 0, $$pre53 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0;
 var $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = 0, $252 = Math_fround(0), $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0);
 var $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = Math_fround(0), $287 = Math_fround(0), $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = Math_fround(0);
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = Math_fround(0), $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = 0, $310 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0;
 var $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge$not = 0, $brmerge$not29 = 0, $brmerge28 = 0, $brmerge4 = 0, $i$02$i = 0, $i$039 = 0, $i2$034 = 0, $i4$022 = 0, $not$ = 0, $or$cond = 0, $or$cond30 = 0, $or$cond5 = 0, $outputDst = 0;
 var $outputSrc = 0, $startTransition$0$off0 = 0, $transitionCount$0 = 0, $transitionInput = 0, $transitionMemory = 0, $transitionOutput = 0, $transitionSourceIndex$031 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $outputSrc = sp + 48|0;
 $transitionInput = sp;
 $transitionOutput = sp + 24|0;
 $transitionMemory = sp + 32|0;
 $outputDst = sp + 40|0;
 HEAPF32[$stateMachineOutput>>2] = Math_fround(0.0);
 $0 = (($stateMachineOutput) + 56|0);
 HEAP8[$0>>0] = 0;
 $1 = (($stateMachineConstant) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $16 = 0;
 } else {
  $4 = (($stateMachineOutput) + 28|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($stateMachineOutput) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $i$039 = 0;
  while(1) {
   $8 = (($5) + (($i$039*24)|0)|0);
   HEAP32[$8>>2] = 0;
   $9 = (($7) + (($i$039*24)|0)|0);
   HEAP32[$9>>2] = 0;
   $10 = (($i$039) + 1)|0;
   $11 = HEAP32[$1>>2]|0;
   $12 = ($10>>>0)<($11>>>0);
   if ($12) {
    $i$039 = $10;
   } else {
    $16 = $11;
    break;
   }
  }
 }
 $13 = HEAP32[$stateMachineConstant>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = ($16|0)==(0);
  if ($15) {
   STACKTOP = sp;return;
  }
  $17 = (($stateMachineMemory) + 4|0);
  $18 = $17;
  $19 = HEAP32[$17>>2]|0;
  $20 = (($19) + ($18))|0;
  $21 = $20;
  $22 = $20;
  $23 = ($16>>>0)>(1);
  $$op = $16 << 2;
  $24 = $23 ? $$op : 4;
  _memset(($22|0),0,($24|0))|0;
  $25 = (($stateMachineMemory) + 8|0);
  HEAP32[$25>>2] = $21;
  STACKTOP = sp;return;
 }
 $26 = (($stateMachineOutput) + 4|0);
 $27 = (($stateMachineOutput) + 20|0);
 HEAP32[$27>>2] = 128;
 $28 = (($stateMachineOutput) + 28|0);
 $29 = (($stateMachineOutput) + 44|0);
 HEAP32[$29>>2] = 128;
 $30 = Math_fround(HEAPF32[$stateMachineInput>>2]);
 $31 = (($stateMachineMemory) + 12|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($stateMachineConstant) + 4|0);
 $34 = $33;
 $35 = HEAP32[$33>>2]|0;
 $36 = (($35) + ($34))|0;
 $37 = $36;
 $38 = (($37) + ($32<<3)|0);
 $39 = $38;
 $40 = HEAP32[$38>>2]|0;
 $41 = (($39) + ($40))|0;
 $42 = $41;
 $43 = HEAP32[$stateMachineWorkspace>>2]|0;
 HEAPF32[$outputSrc>>2] = Math_fround(0.0);
 $44 = (($outputSrc) + 4|0);
 HEAP32[$44>>2] = $26;
 $45 = (($stateMachineWorkspace) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 __ZN7mecanim12statemachine13EvaluateStateERKNS_18ValueArrayConstantERKNS0_13StateConstantERKNS0_17StateMachineInputERNS0_18StateMachineMemoryERNS0_11StateOutputERNS0_14StateWorkspaceEbRKNS_9animation12AnimationSetE($46,$42,$stateMachineInput,$stateMachineMemory,$outputSrc,$43,1,$animationSet);
 ;HEAP32[$transitionInput+0>>2]=0|0;HEAP32[$transitionInput+4>>2]=0|0;HEAP32[$transitionInput+8>>2]=0|0;HEAP32[$transitionInput+12>>2]=0|0;
 $47 = (($stateMachineInput) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 HEAP32[$transitionInput>>2] = $48;
 $49 = (($stateMachineMemory) + 36|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($transitionInput) + 4|0);
 HEAPF32[$51>>2] = $50;
 $52 = Math_fround(HEAPF32[$outputSrc>>2]);
 $53 = (($transitionInput) + 8|0);
 HEAPF32[$53>>2] = $52;
 $54 = HEAP32[$44>>2]|0;
 $55 = (($54) + 4|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = (($transitionInput) + 12|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($54) + 8|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($transitionInput) + 16|0);
 HEAPF32[$60>>2] = $59;
 HEAP8[$transitionOutput>>0] = 0;
 $61 = (($transitionOutput) + 4|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (($transitionMemory) + 4|0);
 HEAP8[$62>>0] = 0;
 $63 = HEAP32[$45>>2]|0;
 HEAP32[$transitionMemory>>2] = $63;
 $64 = (($stateMachineMemory) + 73|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = HEAP32[$1>>2]|0;
 $67 = ($66|0)==(0);
 if (!($67)) {
  $68 = (($stateMachineMemory) + 4|0);
  $69 = $68;
  $70 = HEAP32[$68>>2]|0;
  $71 = (($70) + ($69))|0;
  $72 = $71;
  $73 = (($stateMachineMemory) + 8|0);
  $i2$034 = 0;
  while(1) {
   $74 = HEAP32[$54>>2]|0;
   $75 = (($74) + (($i2$034*24)|0)|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)!=(0);
   $78 = $77&1;
   $79 = (Math_fround(($78|0)));
   HEAP32[$73>>2] = $72;
   $80 = (($72) + ($i2$034<<2)|0);
   HEAPF32[$80>>2] = $79;
   $81 = (($i2$034) + 1)|0;
   $82 = ($81>>>0)<($66>>>0);
   if ($82) {
    $i2$034 = $81;
   } else {
    break;
   }
  }
 }
 $83 = (($stateMachineMemory) + 75|0);
 $84 = HEAP8[$83>>0]|0;
 $85 = ($84<<24>>24)==(0);
 L18: do {
  if ($85) {
   $308 = $65;$startTransition$0$off0 = 0;
  } else {
   $86 = (($stateMachineInput) + 12|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   $89 = HEAP32[$stateMachineConstant>>2]|0;
   $90 = ($89|0)==(0);
   if ($90) {
    $308 = $65;$startTransition$0$off0 = 0;
   } else {
    $91 = HEAP32[$33>>2]|0;
    $92 = (($91) + ($34))|0;
    $93 = $92;
    $i$02$i = 0;
    while(1) {
     $96 = (($93) + ($i$02$i<<3)|0);
     $97 = $96;
     $98 = HEAP32[$96>>2]|0;
     $99 = (($97) + ($98))|0;
     $100 = $99;
     $101 = ((($93) + ($i$02$i<<3)|0) + 4|0);
     HEAP32[$101>>2] = $100;
     $102 = (($100) + 52|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ($103|0)==($88|0);
     if ($104) {
      break;
     }
     $105 = (($100) + 48|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ($106|0)==($88|0);
     if ($107) {
      break;
     }
     $108 = (($100) + 44|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = ($109|0)==($88|0);
     $95 = (($i$02$i) + 1)|0;
     if ($110) {
      break;
     }
     $94 = ($95>>>0)<($89>>>0);
     if ($94) {
      $i$02$i = $95;
     } else {
      $308 = $65;$startTransition$0$off0 = 0;
      break L18;
     }
    }
    $111 = ($i$02$i|0)==(-1);
    if ($111) {
     $308 = $65;$startTransition$0$off0 = 0;
    } else {
     HEAP8[$83>>0] = 0;
     HEAP8[$64>>0] = 1;
     $112 = (($stateMachineMemory) + 74|0);
     HEAP8[$112>>0] = 1;
     $113 = (($stateMachineMemory) + 16|0);
     HEAP32[$113>>2] = $i$02$i;
     $114 = (($stateMachineMemory) + 24|0);
     HEAP32[$114>>2] = -1;
     $115 = (($stateMachineMemory) + 28|0);
     HEAP32[$115>>2] = -1;
     $116 = HEAP32[$86>>2]|0;
     $117 = (($116) + 8|0);
     $118 = Math_fround(HEAPF32[$117>>2]);
     $119 = (($stateMachineMemory) + 64|0);
     HEAPF32[$119>>2] = $118;
     $120 = (($116) + 4|0);
     $121 = Math_fround(HEAPF32[$120>>2]);
     $122 = (($stateMachineMemory) + 68|0);
     HEAPF32[$122>>2] = $121;
     $123 = (($116) + 12|0);
     $124 = Math_fround(HEAPF32[$123>>2]);
     $125 = (($stateMachineMemory) + 60|0);
     HEAPF32[$125>>2] = $124;
     $126 = Math_fround(HEAPF32[$120>>2]);
     $127 = Math_fround($124 + $126);
     $128 = (($stateMachineMemory) + 40|0);
     HEAPF32[$128>>2] = $127;
     $129 = (($stateMachineMemory) + 72|0);
     HEAP8[$129>>0] = $65;
     $130 = HEAP32[$116>>2]|0;
     $131 = (($stateMachineOutput) + 40|0);
     HEAP32[$131>>2] = $130;
     HEAP32[$29>>2] = 25;
     $308 = 1;$startTransition$0$off0 = 1;
    }
   }
  }
 } while(0);
 $132 = (($stateMachineMemory) + 24|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = ($133|0)==(-1);
 $$pre53 = (($stateMachineMemory) + 28|0);
 do {
  if ($134) {
   $$0$i1113 = 0;$172 = 0;$185 = 2;
  } else {
   $135 = HEAP32[$$pre53>>2]|0;
   $136 = ($135|0)==(-1);
   if ($136) {
    $137 = (($stateMachineConstant) + 16|0);
    $138 = $137;
    $139 = HEAP32[$137>>2]|0;
    $140 = (($139) + ($138))|0;
    $141 = $140;
    $142 = (($141) + ($133<<3)|0);
    $143 = $142;
    $144 = HEAP32[$142>>2]|0;
    $145 = (($143) + ($144))|0;
    $146 = $145;
    $147 = ((($141) + ($133<<3)|0) + 4|0);
    HEAP32[$147>>2] = $146;
    $$0$i11 = $146;
   } else {
    $148 = HEAP32[$33>>2]|0;
    $149 = (($148) + ($34))|0;
    $150 = $149;
    $151 = (($150) + ($135<<3)|0);
    $152 = $151;
    $153 = HEAP32[$151>>2]|0;
    $154 = (($152) + ($153))|0;
    $155 = $154;
    $156 = (($155) + 4|0);
    $157 = $156;
    $158 = HEAP32[$156>>2]|0;
    $159 = (($157) + ($158))|0;
    $160 = $159;
    $161 = (($160) + ($133<<3)|0);
    $162 = $161;
    $163 = HEAP32[$161>>2]|0;
    $164 = (($162) + ($163))|0;
    $165 = $164;
    $166 = ((($160) + ($133<<3)|0) + 4|0);
    HEAP32[$166>>2] = $165;
    $$0$i11 = $165;
   }
   $167 = ($$0$i11|0)==(0|0);
   if ($167) {
    $$0$i1113 = 0;$172 = 0;$185 = 2;
   } else {
    $168 = (($$0$i11) + 44|0);
    $169 = HEAP32[$168>>2]|0;
    if ((($169|0) == 3) | (($169|0) == 4)) {
     $$0$i1113 = $$0$i11;$172 = 1;$185 = 3;
     break;
    } else if ((($169|0) == 2) | (($169|0) == 1)) {
     $$0$i1113 = $$0$i11;$172 = 1;$185 = 2;
     break;
    } else {
     $$0$i1113 = $$0$i11;$172 = 1;$185 = 0;
     break;
    }
   }
  }
 } while(0);
 $170 = HEAP32[$$pre53>>2]|0;
 $171 = ($170|0)==(-1);
 do {
  if ($171) {
   $$not1954 = $172 ^ 1;
   $$not1956 = $$not1954;$194 = 0;$225 = 0;
  } else {
   $173 = HEAP32[$31>>2]|0;
   $174 = ($170|0)==($173|0);
   $175 = $174 ? 1 : 2;
   $$not19 = $172 ^ 1;
   if ($172) {
    $176 = (($$0$i1113) + 44|0);
    $177 = HEAP32[$176>>2]|0;
    if ((($177|0) == 3)) {
     if ($174) {
      $$not1956 = $$not19;$194 = 1;$225 = 1;
      break;
     }
     $180 = $174 ? -1 : 2;
     $$not1956 = $$not19;$194 = $175;$225 = $180;
     break;
    } else if ((($177|0) == 1)) {
     $178 = $174 ? 1 : -1;
     $$not1956 = $$not19;$194 = $175;$225 = $178;
     break;
    } else if ((($177|0) == 2)) {
     $179 = $174 ? -1 : 1;
     $$not1956 = $$not19;$194 = $175;$225 = $179;
     break;
    } else if ((($177|0) == 4)) {
     if (!($174)) {
      $$not1956 = $$not19;$194 = 2;$225 = 1;
      break;
     }
     $181 = $174 ? 2 : -1;
     $$not1956 = $$not19;$194 = 1;$225 = $181;
     break;
    } else {
     $$not1956 = $$not19;$194 = $175;$225 = -1;
     break;
    }
   } else {
    $$not1956 = $$not19;$194 = $175;$225 = 0;
   }
  }
 } while(0);
 $182 = (($stateMachineMemory) + 74|0);
 $183 = HEAP8[$182>>0]|0;
 $$not27 = ($183<<24>>24)!=(0);
 $brmerge28 = $$not27 | $startTransition$0$off0;
 $brmerge$not29 = $brmerge28 ^ 1;
 $184 = ($185|0)!=(0);
 $or$cond30 = $184 & $brmerge$not29;
 do {
  if ($or$cond30) {
   $186 = (($$0$i1113) + 44|0);
   $187 = (($stateMachineConstant) + 16|0);
   $188 = (($stateMachineConstant) + 12|0);
   $189 = ($65<<24>>24)==(0);
   $brmerge4 = $189 | $$not1956;
   $190 = (($stateMachineInput) + 20|0);
   $191 = (($stateMachineMemory) + 16|0);
   $192 = (($$0$i1113) + 48|0);
   $193 = ($194|0)==(2);
   $transitionSourceIndex$031 = 0;
   while(1) {
    L56: do {
     if ($172) {
      $195 = HEAP32[$186>>2]|0;
      $196 = ($transitionSourceIndex$031|0)==(0);
      if ($196) {
       $$0$i714 = $187;$$0$in$i = $188;$309 = 0;
      } else {
       switch ($195|0) {
       case 3:  {
        $197 = ($transitionSourceIndex$031|0)==(1);
        $198 = $197 ? 1 : 2;
        $310 = $198;
        label = 45;
        break L56;
        break;
       }
       case 4:  {
        $199 = ($transitionSourceIndex$031|0)==(1);
        $200 = $199 ? 2 : 1;
        $310 = $200;
        label = 45;
        break L56;
        break;
       }
       case 2: case 1: case 0:  {
        $310 = $195;
        label = 45;
        break L56;
        break;
       }
       default: {
        $$0$i714 = $187;$$0$in$i = $188;$309 = 0;
        break L56;
       }
       }
      }
     } else {
      $not$ = ($transitionSourceIndex$031|0)!=(0);
      $201 = $not$&1;
      $310 = $201;
      label = 45;
     }
    } while(0);
    do {
     if ((label|0) == 45) {
      label = 0;
      if ((($310|0) == 1)) {
       $202 = HEAP32[$31>>2]|0;
       $203 = HEAP32[$33>>2]|0;
       $204 = (($203) + ($34))|0;
       $205 = $204;
       $206 = (($205) + ($202<<3)|0);
       $207 = $206;
       $208 = HEAP32[$206>>2]|0;
       $209 = (($207) + ($208))|0;
       $210 = $209;
       $211 = (($210) + 4|0);
       $$0$i714 = $211;$$0$in$i = $210;$309 = 1;
       break;
      } else if ((($310|0) == 2)) {
       $212 = HEAP32[$191>>2]|0;
       $213 = HEAP32[$33>>2]|0;
       $214 = (($213) + ($34))|0;
       $215 = $214;
       $216 = (($215) + ($212<<3)|0);
       $217 = $216;
       $218 = HEAP32[$216>>2]|0;
       $219 = (($217) + ($218))|0;
       $220 = $219;
       $221 = (($220) + 4|0);
       $$0$i714 = $221;$$0$in$i = $220;$309 = 2;
       break;
      } else {
       $$0$i714 = $187;$$0$in$i = $188;$309 = $310;
       break;
      }
     }
    } while(0);
    $$0$i6 = HEAP32[$$0$in$i>>2]|0;
    if ($brmerge4) {
     $transitionCount$0 = $$0$i6;
    } else {
     $222 = HEAP8[$192>>0]|0;
     $223 = ($222<<24>>24)==(0);
     if ($223) {
      $transitionCount$0 = $$0$i6;
     } else {
      $224 = ($transitionSourceIndex$031>>>0)>($225>>>0);
      if ($224) {
       $transitionCount$0 = 0;
      } else {
       $226 = ($225|0)!=($transitionSourceIndex$031|0);
       $or$cond5 = $226 | $193;
       if ($or$cond5) {
        $transitionCount$0 = $$0$i6;
       } else {
        $227 = HEAP32[$132>>2]|0;
        $transitionCount$0 = $227;
       }
      }
     }
    }
    if ((($309|0) == 1)) {
     $228 = HEAP32[$31>>2]|0;
     $$0$i = $228;
    } else if ((($309|0) == 2)) {
     $229 = HEAP32[$191>>2]|0;
     $$0$i = $229;
    } else {
     $$0$i = -1;
    }
    $230 = (__ZN7mecanim12statemachine19EvaluateTransitionsERK9OffsetPtrIS1_INS0_18TransitionConstantEEEjRNS0_15TransitionInputERNS0_16TransitionOutputERNS0_16TransitionMemoryEPKNS0_20StateMachineConstantEPKNS0_17StateMachineInputEPNS0_18StateMachineOutputEPNS0_18StateMachineMemoryEPNS0_21StateMachineWorkspaceEi($$0$i714,$transitionCount$0,$transitionInput,$transitionOutput,$transitionMemory,$stateMachineConstant,$stateMachineInput,$stateMachineOutput,$stateMachineMemory,$stateMachineWorkspace,$$0$i)|0);
    $231 = HEAP32[$190>>2]|0;
    $232 = ($231|0)==(0|0);
    if (!($232)) {
     $233 = (__ZNK27StateMachineBehaviourPlayer15IsSenderEnabledEv($231)|0);
     if (!($233)) {
      label = 73;
      break;
     }
    }
    $$ = $230 ? $65 : 0;
    HEAP8[$0>>0] = $$;
    $234 = (($transitionSourceIndex$031) + 1)|0;
    $235 = HEAP8[$182>>0]|0;
    $$not = ($235<<24>>24)!=(0);
    $brmerge = $$not | $230;
    $brmerge$not = $brmerge ^ 1;
    $236 = ($234>>>0)<($185>>>0);
    $or$cond = $236 & $brmerge$not;
    if ($or$cond) {
     $transitionSourceIndex$031 = $234;
    } else {
     label = 59;
     break;
    }
   }
   if ((label|0) == 59) {
    $$pre = HEAP8[$64>>0]|0;
    $238 = $$pre;
    break;
   }
   else if ((label|0) == 73) {
    STACKTOP = sp;return;
   }
  } else {
   $238 = $308;
  }
 } while(0);
 $237 = ($238<<24>>24)==(0);
 if ($237) {
  STACKTOP = sp;return;
 }
 $239 = (($stateMachineMemory) + 16|0);
 $240 = HEAP32[$239>>2]|0;
 $241 = HEAP32[$33>>2]|0;
 $242 = (($241) + ($34))|0;
 $243 = $242;
 $244 = (($243) + ($240<<3)|0);
 $245 = $244;
 $246 = HEAP32[$244>>2]|0;
 $247 = (($245) + ($246))|0;
 $248 = $247;
 $249 = HEAP32[$stateMachineWorkspace>>2]|0;
 $250 = Math_fround(HEAPF32[$outputSrc>>2]);
 $251 = (($stateMachineMemory) + 64|0);
 $252 = Math_fround(HEAPF32[$251>>2]);
 $253 = $252 == Math_fround(0.0);
 if ($253) {
  $263 = Math_fround(1.0);
 } else {
  $254 = $250 != Math_fround(0.0);
  $255 = $254 ? $250 : Math_fround(1.0);
  $256 = Math_fround($30 / $255);
  $257 = Math_fround(HEAPF32[$61>>2]);
  $258 = Math_fround($256 - $257);
  $259 = Math_fround($258 / $252);
  $263 = $259;
 }
 $260 = (($stateMachineMemory) + 60|0);
 $261 = Math_fround(HEAPF32[$260>>2]);
 $262 = Math_fround($263 + $261);
 HEAPF32[$260>>2] = $262;
 $264 = (Math_fround(+(_fmaxf(0.0,(+$262)))));
 $265 = (Math_fround(+(_fminf(1.0,(+$264)))));
 HEAPF32[$stateMachineOutput>>2] = $265;
 HEAPF32[$outputDst>>2] = Math_fround(0.0);
 $266 = (($outputDst) + 4|0);
 HEAP32[$266>>2] = $28;
 $267 = HEAP32[$45>>2]|0;
 __ZN7mecanim12statemachine13EvaluateStateERKNS_18ValueArrayConstantERKNS0_13StateConstantERKNS0_17StateMachineInputERNS0_18StateMachineMemoryERNS0_11StateOutputERNS0_14StateWorkspaceEbRKNS_9animation12AnimationSetE($267,$248,$stateMachineInput,$stateMachineMemory,$outputDst,$249,0,$animationSet);
 $268 = HEAP32[$1>>2]|0;
 $269 = ($268|0)==(0);
 if (!($269)) {
  $270 = (($stateMachineMemory) + 4|0);
  $271 = $270;
  $272 = (($stateMachineMemory) + 8|0);
  $i4$022 = 0;
  while(1) {
   $273 = HEAP32[$26>>2]|0;
   $274 = (($273) + (($i4$022*24)|0)|0);
   $275 = HEAP32[$274>>2]|0;
   $276 = ($275|0)==(0);
   $277 = HEAP32[$28>>2]|0;
   $278 = (($277) + (($i4$022*24)|0)|0);
   $279 = HEAP32[$278>>2]|0;
   $280 = ($279|0)==(0);
   if ($276) {
    if (!($280)) {
     $281 = Math_fround(HEAPF32[$stateMachineOutput>>2]);
     $282 = HEAP32[$270>>2]|0;
     $283 = (($282) + ($271))|0;
     $284 = $283;
     HEAP32[$272>>2] = $284;
     $285 = (($284) + ($i4$022<<2)|0);
     HEAPF32[$285>>2] = $281;
    }
   } else {
    if ($280) {
     $286 = Math_fround(HEAPF32[$stateMachineOutput>>2]);
     $287 = Math_fround(Math_fround(1.0) - $286);
     $288 = HEAP32[$270>>2]|0;
     $289 = (($288) + ($271))|0;
     $290 = $289;
     HEAP32[$272>>2] = $290;
     $291 = (($290) + ($i4$022<<2)|0);
     HEAPF32[$291>>2] = $287;
    }
   }
   $292 = (($i4$022) + 1)|0;
   $293 = ($292>>>0)<($268>>>0);
   if ($293) {
    $i4$022 = $292;
   } else {
    break;
   }
  }
 }
 $294 = Math_fround(HEAPF32[$260>>2]);
 $295 = !($294 >= Math_fround(1.0));
 if ($295) {
  STACKTOP = sp;return;
 }
 $296 = HEAP32[$31>>2]|0;
 $297 = (($stateMachineMemory) + 20|0);
 HEAP32[$297>>2] = $296;
 $298 = (($stateMachineMemory) + 44|0);
 $299 = Math_fround(HEAPF32[$298>>2]);
 $300 = (($stateMachineMemory) + 52|0);
 HEAPF32[$300>>2] = $299;
 HEAP32[$27>>2] = 26;
 HEAP8[$64>>0] = 0;
 HEAPF32[$260>>2] = Math_fround(0.0);
 HEAP32[$$pre53>>2] = -1;
 HEAP32[$132>>2] = -1;
 $301 = (($stateMachineMemory) + 68|0);
 HEAPF32[$301>>2] = Math_fround(0.0);
 $302 = HEAP32[$239>>2]|0;
 HEAP32[$31>>2] = $302;
 $303 = (($stateMachineMemory) + 72|0);
 HEAP8[$303>>0] = 0;
 HEAP8[$182>>0] = 0;
 $304 = (($stateMachineMemory) + 40|0);
 $305 = Math_fround(HEAPF32[$304>>2]);
 HEAPF32[$49>>2] = $305;
 $306 = (($stateMachineMemory) + 48|0);
 $307 = Math_fround(HEAPF32[$306>>2]);
 HEAPF32[$298>>2] = $307;
 HEAPF32[$stateMachineOutput>>2] = Math_fround(1.0);
 STACKTOP = sp;return;
}
function __ZN7mecanim12statemachine13StateConstant15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z27RegisterAllowNameConversionPKcS0_S0_(798848,798864,798872);
 STACKTOP = sp;return;
}
function __Z29AnimationCurve_CUSTOM_CleanupP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($self_) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($3) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(-1);
 if ($7) {
  $8 = (($3) + 56|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($3) + 60|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = $11;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($9|0),($$byval_copy|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __ZdlPv($3);
   ___resumeException($14|0);
   // unreachable;
  }
 }
 __ZdlPv($3);
 STACKTOP = sp;return;
}
function __Z30AnimationCurve_CUSTOM_EvaluateP15ScriptingObjectf($self_,$time) {
 $self_ = $self_|0;
 $time = Math_fround($time);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (Math_fround(__ZNK17AnimationCurveTplIfE8EvaluateEf($2,$time)));
   STACKTOP = sp;return (Math_fround($4));
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(799168,$vararg_buffer);
 // unreachable;
 return Math_fround(0);
}
function __Z29AnimationCurve_CUSTOM_SetKeysP15ScriptingObjectP14ScriptingArray($self_,$keys) {
 $self_ = $self_|0;
 $keys = $keys|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($keys,0,16)|0);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(799168,$vararg_buffer1);
  // unreachable;
 }
 $2 = (($self_) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(799168,$vararg_buffer1);
  // unreachable;
 }
 $5 = (__Z21GetScriptingArraySizeP14ScriptingArray($keys)|0);
 $6 = (($0) + ($5<<4)|0);
 __ZN17AnimationCurveTplIfE6AssignEPK11KeyframeTplIfES4_($3,$0,$6);
 $7 = HEAP32[$2>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(799168,$vararg_buffer1);
  // unreachable;
 } else {
  $9 = (($7) + 56|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($7) + 64|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + ($12<<4)|0);
  __ZNSt3__16__sortIRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEvT0_S7_T_($10,$13,$vararg_buffer1);
  __ZN17AnimationCurveTplIfE15InvalidateCacheEv($7);
  STACKTOP = sp;return;
 }
}
function __Z26AnimationCurve_CUSTOM_InitP15ScriptingObjectP14ScriptingArray($self_,$keys) {
 $self_ = $self_|0;
 $keys = $keys|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(80)|0);
 $1 = (($0) + 4|0);
 HEAPF32[$1>>2] = Math_fround(inf);
 HEAP32[$0>>2] = 0;
 $2 = (($0) + 8|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $3 = (($0) + 32|0);
 HEAPF32[$3>>2] = Math_fround(inf);
 $4 = (($0) + 28|0);
 HEAP32[$4>>2] = 0;
 $5 = (($0) + 36|0);
 $6 = (($0) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($0) + 68|0);
 HEAP32[$7>>2] = 0;
 $8 = (($0) + 60|0);
 ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;HEAP32[$5+16>>2]=0|0;HEAP32[$5+20>>2]=0|0;
 HEAP32[$8>>2] = 61;
 $9 = (($0) + 76|0);
 HEAP32[$9>>2] = 2;
 $10 = (($0) + 72|0);
 HEAP32[$10>>2] = 2;
 $11 = (($self_) + 8|0);
 HEAP32[$11>>2] = $0;
 $12 = ($keys|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 __Z29AnimationCurve_CUSTOM_SetKeysP15ScriptingObjectP14ScriptingArray($self_,$keys);
 STACKTOP = sp;return;
}
function __Z26Animation_CUSTOM_CrossFadeP15ScriptingObjectP15ScriptingStringfi($self_,$animation_,$fadeLength,$mode) {
 $self_ = $self_|0;
 $animation_ = $animation_|0;
 $fadeLength = Math_fround($fadeLength);
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $animation = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $animation = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($animation,$animation_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$animation);
 __THREW__ = 0;
 invoke_viifi(5,($2|0),($0|0),(+$fadeLength),($mode|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __Z25Animation_CUSTOM_GetStateP15ScriptingObjectP15ScriptingString($self_,$name_) {
 $self_ = $self_|0;
 $name_ = $name_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $name = sp + 12|0;
 $0 = sp;
 __ZN11ICallStringC2EPv($name,$name_);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  $4 = 0;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 $2 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = $self_;
  __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($4);
  // unreachable;
 }
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$name);
 __THREW__ = 0;
 $5 = (invoke_iii(2594,($2|0),($0|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $8 = HEAP8[$0>>0]|0;
  $9 = $8 & 1;
  $10 = ($9<<24>>24)==(0);
  if (!($10)) {
   $11 = (($0) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   __ZdlPv($12);
  }
  $13 = (__Z19GetScriptingManagerv()|0);
  $14 = (($13) + 108|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (__ZN9Scripting41TrackedReferenceBaseToScriptingObjectImplEP20TrackedReferenceBaseP14ScriptingClass($5,$15)|0);
  STACKTOP = sp;return ($16|0);
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $19 = HEAP8[$0>>0]|0;
 $20 = $19 & 1;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  ___resumeException($17|0);
  // unreachable;
 }
 $22 = (($0) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 __ZdlPv($23);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z38AnimationState_Set_Custom_PropWrapModeP15ScriptingObjecti($self_,$value) {
 $self_ = $self_|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   __ZN14AnimationState11SetWrapModeEi($2,$value);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(799168,$vararg_buffer);
 // unreachable;
}
function __Z35AnimationState_Set_Custom_PropSpeedP15ScriptingObjectf($self_,$value) {
 $self_ = $self_|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   __ZN14AnimationState8SetSpeedEf($2,$value);
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(799168,$vararg_buffer);
 // unreachable;
}
function __Z43Register_UnityEngine_AnimationCurve_Cleanupv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(798888,3706);
 STACKTOP = sp;return;
}
function __Z44Register_UnityEngine_AnimationCurve_Evaluatev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(798928,17);
 STACKTOP = sp;return;
}
function __Z40Register_UnityEngine_AnimationCurve_Initv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(798968,3403);
 STACKTOP = sp;return;
}
function __Z40Register_UnityEngine_Animation_CrossFadev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(799008,6);
 STACKTOP = sp;return;
}
function __Z39Register_UnityEngine_Animation_GetStatev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(799048,2595);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_AnimationState_set_wrapModev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(799080,3404);
 STACKTOP = sp;return;
}
function __Z45Register_UnityEngine_AnimationState_set_speedv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(799128,190);
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0);
 var $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0);
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0);
 var $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0;
 var $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = Math_fround(0);
 var $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $__i$027 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0;
 var $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i23 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -16|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 4;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 71;
    break L1;
    break;
   }
   default: {
   }
   }
   $37 = ($3|0)<(496);
   if ($37) {
    label = 21;
    break L1;
   }
   $38 = ($3|0)>(15984);
   $39 = (($4|0) / 2)&-1;
   $40 = (($$0) + ($39<<4)|0);
   do {
    if ($38) {
     $41 = (($4|0) / 4)&-1;
     $42 = (($$0) + ($41<<4)|0);
     $$sum = (($41) + ($39))|0;
     $43 = (($$0) + ($$sum<<4)|0);
     $44 = (__ZNSt3__17__sort4IRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$42,$40,$43,0)|0);
     $45 = Math_fround(HEAPF32[$1>>2]);
     $46 = Math_fround(HEAPF32[$43>>2]);
     $47 = $45 < $46;
     if (!($47)) {
      $$pre$phiZ2D = $40;$__n_swaps$0 = $44;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$43+12>>2]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$1+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $48 = Math_fround(HEAPF32[$43>>2]);
     $49 = Math_fround(HEAPF32[$40>>2]);
     $50 = $48 < $49;
     if (!($50)) {
      $51 = (($44) + 1)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $51;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$43+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$43+12>>2]|0;
     ;HEAP32[$43+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $52 = Math_fround(HEAPF32[$40>>2]);
     $53 = Math_fround(HEAPF32[$42>>2]);
     $54 = $52 < $53;
     if (!($54)) {
      $55 = (($44) + 2)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $55;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$42+12>>2]|0;
     ;HEAP32[$42+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $56 = Math_fround(HEAPF32[$42>>2]);
     $57 = Math_fround(HEAPF32[$$0>>2]);
     $58 = $56 < $57;
     if ($58) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$42+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$42+12>>2]|0;
      ;HEAP32[$42+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $60 = (($44) + 4)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $60;
      break;
     } else {
      $59 = (($44) + 3)|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = $59;
      break;
     }
    } else {
     $61 = Math_fround(HEAPF32[$40>>2]);
     $62 = Math_fround(HEAPF32[$$0>>2]);
     $63 = $61 < $62;
     $64 = Math_fround(HEAPF32[$1>>2]);
     $65 = $64 < $61;
     if (!($63)) {
      if (!($65)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 0;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $66 = Math_fround(HEAPF32[$40>>2]);
      $67 = Math_fround(HEAPF32[$$0>>2]);
      $68 = $66 < $67;
      if (!($68)) {
       $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
       break;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
      break;
     }
     if ($65) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
      break;
     }
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
     ;HEAP32[$$0+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $69 = Math_fround(HEAPF32[$1>>2]);
     $70 = Math_fround(HEAPF32[$40>>2]);
     $71 = $69 < $70;
     if ($71) {
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$40+12>>2]|0;
      ;HEAP32[$40+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $$pre$phiZ2D = $40;$__n_swaps$0 = 2;
     } else {
      $$pre$phiZ2D = $40;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $72 = Math_fround(HEAPF32[$$0>>2]);
   $73 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
   $74 = $72 < $73;
   do {
    if ($74) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $75 = (($__j$0) + -16|0);
      $76 = ($$0|0)==($75|0);
      if ($76) {
       break;
      }
      $94 = Math_fround(HEAPF32[$75>>2]);
      $95 = $94 < $73;
      if ($95) {
       label = 54;
       break;
      } else {
       $__j$0 = $75;
      }
     }
     if ((label|0) == 54) {
      label = 0;
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$75+12>>2]|0;
      ;HEAP32[$75+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$75+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $96 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $75;$__n_swaps$3 = $96;
      break;
     }
     $77 = (($$0) + 16|0);
     $78 = Math_fround(HEAPF32[$1>>2]);
     $79 = $72 < $78;
     if ($79) {
      $__i$1 = $77;
     } else {
      $80 = ($77|0)==($1|0);
      if ($80) {
       label = 71;
       break L1;
      } else {
       $__i$027 = $77;
      }
      while(1) {
       $83 = Math_fround(HEAPF32[$__i$027>>2]);
       $84 = $72 < $83;
       $82 = (($__i$027) + 16|0);
       if ($84) {
        break;
       }
       $81 = ($82|0)==($1|0);
       if ($81) {
        label = 71;
        break L1;
       } else {
        $__i$027 = $82;
       }
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$027+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$027+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$027+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$027+12>>2]|0;
      ;HEAP32[$__i$027+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$027+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$027+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$027+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $__i$1 = $82;
     }
     $85 = ($__i$1|0)==($1|0);
     if ($85) {
      label = 71;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $86 = Math_fround(HEAPF32[$$0>>2]);
      $__i$2 = $__i$2$ph;
      while(1) {
       $87 = Math_fround(HEAPF32[$__i$2>>2]);
       $88 = $86 < $87;
       $89 = (($__i$2) + 16|0);
       if ($88) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $89;
       }
      }
      while(1) {
       $90 = (($__j$2) + -16|0);
       $91 = Math_fround(HEAPF32[$90>>2]);
       $92 = $86 < $91;
       if ($92) {
        $__j$2 = $90;
       } else {
        break;
       }
      }
      $93 = ($__i$2>>>0)<($90>>>0);
      if (!($93)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$2+12>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$90+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$90+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$90+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$90+12>>2]|0;
      ;HEAP32[$90+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $__i$2$ph = $89;$__j$1$ph = $90;
     }
    }
   } while(0);
   $97 = (($$0) + 16|0);
   $98 = ($97>>>0)<($__j$3>>>0);
   L55: do {
    if ($98) {
     $__i$3$ph = $97;$__j$4$ph = $__j$3;$__m$0$ph = $40;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $99 = Math_fround(HEAPF32[$__m$0$ph>>2]);
      $__i$3 = $__i$3$ph;
      while(1) {
       $100 = Math_fround(HEAPF32[$__i$3>>2]);
       $101 = $100 < $99;
       $102 = (($__i$3) + 16|0);
       if ($101) {
        $__i$3 = $102;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $103 = (($__j$5) + -16|0);
       $104 = Math_fround(HEAPF32[$103>>2]);
       $105 = $104 < $99;
       if ($105) {
        break;
       } else {
        $__j$5 = $103;
       }
      }
      $106 = ($__i$3>>>0)>($103>>>0);
      if ($106) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L55;
      }
      ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$3+12>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$103+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$103+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$103+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$103+12>>2]|0;
      ;HEAP32[$103+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$103+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$103+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$103+12>>2]=HEAP32[$__t$i23+12>>2]|0;
      $107 = (($__n_swaps$4$ph) + 1)|0;
      $108 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $108 ? $103 : $__m$0$ph;
      $__i$3$ph = $102;$__j$4$ph = $103;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $107;
     }
    } else {
     $__i$4 = $97;$__m$2 = $40;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $109 = ($__i$4|0)==($__m$2|0);
   if ($109) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $110 = Math_fround(HEAPF32[$__m$2>>2]);
    $111 = Math_fround(HEAPF32[$__i$4>>2]);
    $112 = $110 < $111;
    if ($112) {
     ;HEAP32[$__t$i23+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$__i$4+12>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i23+12>>2]|0;
     $113 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $113;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $114 = ($__n_swaps$6|0)==(0);
   if ($114) {
    $115 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEbT0_S7_T_($$0,$__i$4,0)|0);
    $116 = (($__i$4) + 16|0);
    $117 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEbT0_S7_T_($116,$$01$ph,0)|0);
    if ($117) {
     label = 66;
     break;
    }
    if ($115) {
     $$0 = $116;
     continue;
    }
   }
   $118 = $__i$4;
   $119 = (($118) - ($2))|0;
   $120 = (($0) - ($118))|0;
   $121 = ($119|0)<($120|0);
   if (!($121)) {
    label = 70;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEvT0_S7_T_($$0,$__i$4,$__comp);
   $122 = (($__i$4) + 16|0);
   $$0 = $122;
  }
  if ((label|0) == 66) {
   label = 0;
   if ($115) {
    label = 71;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 70) {
   label = 0;
   $123 = (($__i$4) + 16|0);
   __ZNSt3__16__sortIRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEvT0_S7_T_($123,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = Math_fround(HEAPF32[$1>>2]);
  $6 = Math_fround(HEAPF32[$$0>>2]);
  $7 = $5 < $6;
  if (!($7)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $8 = (($$0) + 16|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = Math_fround(HEAPF32[$$0>>2]);
  $11 = $9 < $10;
  $12 = Math_fround(HEAPF32[$1>>2]);
  $13 = $12 < $9;
  if (!($11)) {
   if (!($13)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   $14 = Math_fround(HEAPF32[$8>>2]);
   $15 = Math_fround(HEAPF32[$$0>>2]);
   $16 = $14 < $15;
   if (!($16)) {
    STACKTOP = sp;return;
   }
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   STACKTOP = sp;return;
  }
  if ($13) {
   ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
   ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $17 = Math_fround(HEAPF32[$1>>2]);
  $18 = Math_fround(HEAPF32[$8>>2]);
  $19 = $17 < $18;
  if (!($19)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $20 = (($$0) + 16|0);
  $21 = (($$0) + 32|0);
  (__ZNSt3__17__sort4IRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$20,$21,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $22 = (($$0) + 16|0);
  $23 = (($$0) + 32|0);
  $24 = (($$0) + 48|0);
  (__ZNSt3__17__sort4IRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$22,$23,$24,0)|0);
  $25 = Math_fround(HEAPF32[$1>>2]);
  $26 = Math_fround(HEAPF32[$24>>2]);
  $27 = $25 < $26;
  if (!($27)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$1+12>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $28 = Math_fround(HEAPF32[$24>>2]);
  $29 = Math_fround(HEAPF32[$23>>2]);
  $30 = $28 < $29;
  if (!($30)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$23+12>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $31 = Math_fround(HEAPF32[$23>>2]);
  $32 = Math_fround(HEAPF32[$22>>2]);
  $33 = $31 < $32;
  if (!($33)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;
  ;HEAP32[$23+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$23+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$23+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$23+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  $34 = Math_fround(HEAPF32[$22>>2]);
  $35 = Math_fround(HEAPF32[$$0>>2]);
  $36 = $34 < $35;
  if (!($36)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i23+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i23+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i23+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i23+12>>2]=HEAP32[$$0+12>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$22+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$22+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$22+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$22+12>>2]|0;
  ;HEAP32[$22+0>>2]=HEAP32[$__t$i23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__t$i23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__t$i23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__t$i23+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  __ZNSt3__118__insertion_sort_3IRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEvT0_S7_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 71) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0);
 var $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $__r$0 = 0, $__t$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i2 = sp;
 $0 = Math_fround(HEAPF32[$__x2>>2]);
 $1 = Math_fround(HEAPF32[$__x1>>2]);
 $2 = $0 < $1;
 $3 = Math_fround(HEAPF32[$__x3>>2]);
 $4 = $3 < $0;
 do {
  if ($2) {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
    ;HEAP32[$__x1+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $$0$i = 1;
    break;
   }
   ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
   ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
   ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
   $8 = Math_fround(HEAPF32[$__x3>>2]);
   $9 = Math_fround(HEAPF32[$__x2>>2]);
   $10 = $8 < $9;
   if ($10) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $$0$i = 2;
   } else {
    $$0$i = 1;
   }
  } else {
   if ($4) {
    ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
    ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
    ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
    $5 = Math_fround(HEAPF32[$__x2>>2]);
    $6 = Math_fround(HEAPF32[$__x1>>2]);
    $7 = $5 < $6;
    if ($7) {
     ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
     ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
     ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
     $$0$i = 2;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 $11 = Math_fround(HEAPF32[$__x4>>2]);
 $12 = Math_fround(HEAPF32[$__x3>>2]);
 $13 = $11 < $12;
 if (!($13)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x3+12>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $14 = (($$0$i) + 1)|0;
 $15 = Math_fround(HEAPF32[$__x3>>2]);
 $16 = Math_fround(HEAPF32[$__x2>>2]);
 $17 = $15 < $16;
 if (!($17)) {
  $__r$0 = $14;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $18 = (($$0$i) + 2)|0;
 $19 = Math_fround(HEAPF32[$__x2>>2]);
 $20 = Math_fround(HEAPF32[$__x1>>2]);
 $21 = $19 < $20;
 if (!($21)) {
  $__r$0 = $18;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;
 $22 = (($$0$i) + 3)|0;
 $__r$0 = $22;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0);
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i = 0, $__t$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4$i = sp + 16|0;
 $__t$sroa$1 = sp;
 $0 = (($__first) + 32|0);
 $1 = (($__first) + 16|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround(HEAPF32[$__first>>2]);
 $4 = $2 < $3;
 $5 = Math_fround(HEAPF32[$0>>2]);
 $6 = $5 < $2;
 do {
  if ($4) {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    break;
   }
   ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;
   ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
   $9 = Math_fround(HEAPF32[$1>>2]);
   $10 = $5 < $9;
   if ($10) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
   }
  } else {
   if ($6) {
    ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$1+12>>2]|0;
    ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
    ;HEAP32[$0+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    $7 = Math_fround(HEAPF32[$1>>2]);
    $8 = $7 < $3;
    if ($8) {
     ;HEAP32[$__t$i4$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i+12>>2]=HEAP32[$__first+12>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$__t$i4$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i4$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i4$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i4$i+12>>2]|0;
    }
   }
  }
 } while(0);
 $11 = (($__first) + 48|0);
 $12 = ($11|0)==($__last|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $__i$02 = $11;$__j$01 = $0;
 while(1) {
  $13 = Math_fround(HEAPF32[$__i$02>>2]);
  $14 = Math_fround(HEAPF32[$__j$01>>2]);
  $15 = $13 < $14;
  if ($15) {
   $16 = (($__i$02) + 4|0);
   ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$16+8>>2]|0;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;
    $17 = ($__k$0|0)==($__first|0);
    if ($17) {
     $__k$0$lcssa = $__first;
     break;
    }
    $18 = (($__k$0) + -16|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    $20 = $13 < $19;
    if ($20) {
     $__j$1$phi = $__k$0;$__k$0 = $18;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAPF32[$__k$0$lcssa>>2] = $13;
   $21 = (($__k$0$lcssa) + 4|0);
   ;HEAP32[$21+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;
  }
  $22 = (($__i$02) + 16|0);
  $23 = ($22|0)==($__last|0);
  if ($23) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $22;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$014 = 0, $__count$1 = 0, $__i$015 = 0, $__j$013 = 0, $__j$013$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, $__t$i4$i5 = 0, $__t$sroa$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4$i5 = sp + 16|0;
 $__t$sroa$1 = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 4;
 switch ($3|0) {
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $8 = (($__first) + 16|0);
  $9 = (($__last) + -16|0);
  $10 = Math_fround(HEAPF32[$8>>2]);
  $11 = Math_fround(HEAPF32[$__first>>2]);
  $12 = $10 < $11;
  $13 = Math_fround(HEAPF32[$9>>2]);
  $14 = $13 < $10;
  if (!($12)) {
   if (!($14)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $15 = Math_fround(HEAPF32[$8>>2]);
   $16 = Math_fround(HEAPF32[$__first>>2]);
   $17 = $15 < $16;
   if (!($17)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;
   ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($14) {
   ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
   ;HEAP32[$__first+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$9+12>>2]|0;
   ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $18 = Math_fround(HEAPF32[$9>>2]);
  $19 = Math_fround(HEAPF32[$8>>2]);
  $20 = $18 < $19;
  if (!($20)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$8+12>>2]|0;
  ;HEAP32[$8+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$9+12>>2]|0;
  ;HEAP32[$9+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -16|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  $6 = Math_fround(HEAPF32[$__first>>2]);
  $7 = $5 < $6;
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $24 = (($__first) + 16|0);
  $25 = (($__first) + 32|0);
  $26 = (($__first) + 48|0);
  $27 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$24,$25,$26,0)|0);
  $28 = Math_fround(HEAPF32[$27>>2]);
  $29 = Math_fround(HEAPF32[$26>>2]);
  $30 = $28 < $29;
  if (!($30)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$26+12>>2]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$27+12>>2]|0;
  ;HEAP32[$27+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$27+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $31 = Math_fround(HEAPF32[$26>>2]);
  $32 = Math_fround(HEAPF32[$25>>2]);
  $33 = $31 < $32;
  if (!($33)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$25+12>>2]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$26+12>>2]|0;
  ;HEAP32[$26+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $34 = Math_fround(HEAPF32[$25>>2]);
  $35 = Math_fround(HEAPF32[$24>>2]);
  $36 = $34 < $35;
  if (!($36)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$25+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$25+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$25+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$25+12>>2]|0;
  ;HEAP32[$25+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $37 = Math_fround(HEAPF32[$24>>2]);
  $38 = Math_fround(HEAPF32[$__first>>2]);
  $39 = $37 < $38;
  if (!($39)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$24+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$24+12>>2]|0;
  ;HEAP32[$24+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $21 = (($__first) + 16|0);
  $22 = (($__first) + 32|0);
  $23 = (($__last) + -16|0);
  (__ZNSt3__17__sort4IRNS_6__lessI11KeyframeTplIfES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$21,$22,$23,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $40 = (($__first) + 32|0);
  $41 = (($__first) + 16|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(HEAPF32[$__first>>2]);
  $44 = $42 < $43;
  $45 = Math_fround(HEAPF32[$40>>2]);
  $46 = $45 < $42;
  do {
   if ($44) {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
     ;HEAP32[$__first+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     break;
    }
    ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
    ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;
    ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
    $49 = Math_fround(HEAPF32[$41>>2]);
    $50 = $45 < $49;
    if ($50) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
    }
   } else {
    if ($46) {
     ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$41+12>>2]|0;
     ;HEAP32[$41+0>>2]=HEAP32[$40+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$40+12>>2]|0;
     ;HEAP32[$40+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$40+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     $47 = Math_fround(HEAPF32[$41>>2]);
     $48 = $47 < $43;
     if ($48) {
      ;HEAP32[$__t$i4$i5+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i4$i5+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i4$i5+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i4$i5+12>>2]=HEAP32[$__first+12>>2]|0;
      ;HEAP32[$__first+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$41+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$41+12>>2]|0;
      ;HEAP32[$41+0>>2]=HEAP32[$__t$i4$i5+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$__t$i4$i5+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$__t$i4$i5+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$__t$i4$i5+12>>2]|0;
     }
    }
   }
  } while(0);
  $51 = (($__first) + 48|0);
  $52 = ($51|0)==($__last|0);
  if ($52) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$014 = 0;$__i$015 = $51;$__j$013 = $40;
  while(1) {
   $53 = Math_fround(HEAPF32[$__i$015>>2]);
   $54 = Math_fround(HEAPF32[$__j$013>>2]);
   $55 = $53 < $54;
   if ($55) {
    $56 = (($__i$015) + 4|0);
    ;HEAP32[$__t$sroa$1+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$__t$sroa$1+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$__t$sroa$1+8>>2]=HEAP32[$56+8>>2]|0;
    $__j$1 = $__i$015;$__k$0 = $__j$013;
    while(1) {
     ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;
     $57 = ($__k$0|0)==($__first|0);
     if ($57) {
      $__k$0$lcssa = $__first;
      break;
     }
     $58 = (($__k$0) + -16|0);
     $59 = Math_fround(HEAPF32[$58>>2]);
     $60 = $53 < $59;
     if ($60) {
      $__j$1$phi = $__k$0;$__k$0 = $58;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAPF32[$__k$0$lcssa>>2] = $53;
    $61 = (($__k$0$lcssa) + 4|0);
    ;HEAP32[$61+0>>2]=HEAP32[$__t$sroa$1+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$__t$sroa$1+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$__t$sroa$1+8>>2]|0;
    $62 = (($__count$014) + 1)|0;
    $63 = ($62|0)==(8);
    if ($63) {
     break;
    } else {
     $__count$1 = $62;
    }
   } else {
    $__count$1 = $__count$014;
   }
   $66 = (($__i$015) + 16|0);
   $67 = ($66|0)==($__last|0);
   if ($67) {
    $$0 = 1;
    label = 35;
    break;
   } else {
    $__j$013$phi = $__i$015;$__count$014 = $__count$1;$__i$015 = $66;$__j$013 = $__j$013$phi;
   }
  }
  if ((label|0) == 35) {
   STACKTOP = sp;return ($$0|0);
  }
  $64 = (($__i$015) + 16|0);
  $65 = ($64|0)==($__last|0);
  $$0 = $65;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __Z20Animator_CUSTOM_PlayP15ScriptingObjectiif($self_,$stateNameHash,$layer,$normalizedTime) {
 $self_ = $self_|0;
 $stateNameHash = $stateNameHash|0;
 $layer = $layer|0;
 $normalizedTime = Math_fround($normalizedTime);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   __ZN8Animator9GotoStateEiifff($1,$layer,$stateNameHash,$normalizedTime,Math_fround(0.0),Math_fround(0.0));
   STACKTOP = sp;return;
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
}
function __Z28Animator_CUSTOM_StringToHashP15ScriptingString($name_) {
 $name_ = $name_|0;
 var $0 = 0, $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $name = sp;
 __ZN11ICallStringC2EPv($name,$name_);
 $0 = (__ZL22ScriptingStringToCRC32R11ICallString($name)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL22ScriptingStringToCRC32R11ICallString($stringValue) {
 $stringValue = $stringValue|0;
 var $$0 = 0, $$02$i$i$i$i = 0, $$masked$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i$i = 0, $exitcond$i$i$i$i = 0, $i$03$i$i$i$i = 0, $p$01$i$i$i = 0, $reflection$01$i$i$i$i = 0;
 var $reflection$1$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZNK11ICallString6IsNullEv($stringValue)|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZNK11ICallString6AsUTF8Ev($0,$stringValue);
 $2 = HEAP8[$0>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = (($0) + 1|0);
  $15 = $7;
 } else {
  $5 = (($0) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $15 = $6;
 }
 $$02$i$i$i$i = -1;$i$03$i$i$i$i = 0;$reflection$01$i$i$i$i = 0;
 while(1) {
  $8 = $$02$i$i$i$i & 1;
  $9 = ($8|0)==(0);
  if ($9) {
   $reflection$1$i$i$i$i = $reflection$01$i$i$i$i;
  } else {
   $10 = (31 - ($i$03$i$i$i$i))|0;
   $11 = 1 << $10;
   $12 = $11 | $reflection$01$i$i$i$i;
   $reflection$1$i$i$i$i = $12;
  }
  $13 = (($i$03$i$i$i$i) + 1)|0;
  $14 = $$02$i$i$i$i >>> 1;
  $exitcond$i$i$i$i = ($13|0)==(32);
  if ($exitcond$i$i$i$i) {
   break;
  } else {
   $$02$i$i$i$i = $14;$i$03$i$i$i$i = $13;$reflection$01$i$i$i$i = $reflection$1$i$i$i$i;
  }
 }
 $16 = (_strlen(($15|0))|0);
 $17 = (($15) + ($16)|0);
 $18 = ($16|0)>(0);
 if ($18) {
  $22 = $reflection$1$i$i$i$i;$p$01$i$i$i = $15;
  while(1) {
   $19 = HEAP8[$p$01$i$i$i>>0]|0;
   $20 = $19&255;
   $21 = $22 >>> 8;
   $$masked$i$i$i = $22 & 255;
   $23 = $20 ^ $$masked$i$i$i;
   $24 = (584048 + ($23<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 ^ $21;
   $27 = (($p$01$i$i$i) + 1|0);
   $exitcond$i$i$i = ($27|0)==($17|0);
   if ($exitcond$i$i$i) {
    $29 = $26;
    break;
   } else {
    $22 = $26;$p$01$i$i$i = $27;
   }
  }
 } else {
  $29 = $reflection$1$i$i$i$i;
 }
 $28 = $29 ^ -1;
 if ($4) {
  $$0 = $28;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (($0) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 __ZdlPv($31);
 $$0 = $28;
 STACKTOP = sp;return ($$0|0);
}
function __Z34Register_UnityEngine_Animator_Playv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(799176,9);
 STACKTOP = sp;return;
}
function __Z42Register_UnityEngine_Animator_StringToHashv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(799208,3404);
 STACKTOP = sp;return;
}
function __ZNK14DetailDatabase12IsPatchEmptyEii($this,$x,$y) {
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = Math_imul($1, $y)|0;
 $3 = (($2) + ($x))|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5) + (($3*52)|0)|0) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($3*52)|0)|0) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN14DetailDatabase17RefreshPrototypesEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy14 = 0, $$pre = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = Math_fround(0), $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = Math_fround(0), $209 = Math_fround(0), $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0, $allocPtr2$0 = 0;
 var $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$01$i$i = 0, $i$02$i = 0, $i$02$i8 = 0, $v$01$i = 0, $v$01$i11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy14 = sp + 32|0;
 $0 = sp + 28|0;
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 12|0;
 $8 = (($this) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 136)&-1;
 $16 = $15 << 2;
 $17 = (($16) + 15)|0;
 $18 = ($17>>>0)<(2000);
 $19 = ($9|0)!=($11|0);
 if ($18) {
  if ($19) {
   $20 = STACKTOP; STACKTOP = STACKTOP + ((((1*$17)|0)+15)&-16)|0;;
   $219 = 0;$allocPtr$0 = $20;
   label = 8;
  } else {
   $219 = 0;$allocPtr$0 = 0;
   label = 8;
  }
 } else {
  if ($19) {
   $21 = HEAP32[628512>>2]|0;
   HEAP32[$5>>2] = $21;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
   $22 = (invoke_iiiiiii(102,($17|0),16,($$byval_copy14|0),0,(799248|0),575)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $228 = 0;
    label = 6;
   } else {
    $219 = $22;$allocPtr$0 = $22;
    label = 8;
   }
  } else {
   $219 = 0;$allocPtr$0 = 0;
   label = 8;
  }
 }
 L6: do {
  if ((label|0) == 8) {
   $27 = $allocPtr$0;
   $28 = (($27) + 15)|0;
   $29 = $28 & -16;
   $30 = $29;
   __THREW__ = 0;
   invoke_vii(3405,($this|0),($30|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $228 = $219;
    label = 6;
   } else {
    $33 = (($this) + 56|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     $88 = HEAP32[628384>>2]|0;
     HEAP32[$1>>2] = $88;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
     $89 = (invoke_iiiiiii(103,136,($$byval_copy14|0),1,16,(799248|0),1111)|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      $228 = $219;
      label = 6;
      break;
     }
     HEAP32[$2>>2] = $88;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_viii(1733,($89|0),($$byval_copy14|0),0);
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      $107 = ___cxa_find_matching_catch()|0;
      $108 = tempRet0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_viiiiii(97,($89|0),($$byval_copy14|0),1,16,(799248|0),1111);
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if (!($110)) {
       $229 = $219;$eh$lpad$body$index2Z2D = $108;$eh$lpad$body$indexZ2D = $107;
       label = 7;
       break;
      }
      $111 = ___cxa_find_matching_catch(0|0)|0;
      $112 = tempRet0;
      ___clang_call_terminate($111);
      // unreachable;
     }
     __THREW__ = 0;
     $94 = (invoke_ii(3405,($89|0))|0);
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      $228 = $219;
      label = 6;
      break;
     }
     $97 = HEAP32[$94>>2]|0;
     $98 = (($97) + 24|0);
     $99 = HEAP32[$98>>2]|0;
     __THREW__ = 0;
     invoke_vi($99|0,($94|0));
     $100 = __THREW__; __THREW__ = 0;
     $101 = $100&1;
     if ($101) {
      $228 = $219;
      label = 6;
      break;
     }
     $102 = HEAP32[$94>>2]|0;
     $103 = (($102) + 12|0);
     $104 = HEAP32[$103>>2]|0;
     __THREW__ = 0;
     invoke_vii($104|0,($94|0),4);
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      $228 = $219;
      label = 6;
      break;
     }
     HEAP32[$33>>2] = $94;
     $113 = HEAP32[$94>>2]|0;
     $114 = (($113) + 148|0);
     $115 = HEAP32[$114>>2]|0;
     __THREW__ = 0;
     (invoke_iiiiiiii($115|0,($94|0),2,2,5,1,1,0)|0);
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      $228 = $219;
      label = 6;
      break;
     }
     $118 = HEAP32[$33>>2]|0;
     $119 = HEAP32[$118>>2]|0;
     $120 = (($119) + 44|0);
     $121 = HEAP32[$120>>2]|0;
     __THREW__ = 0;
     invoke_vii($121|0,($118|0),61);
     $122 = __THREW__; __THREW__ = 0;
     $123 = $122&1;
     if ($123) {
      $228 = $219;
      label = 6;
      break;
     }
     $124 = HEAP32[$33>>2]|0;
     __THREW__ = 0;
     invoke_vii(3406,($124|0),1);
     $125 = __THREW__; __THREW__ = 0;
     $126 = $125&1;
     if ($126) {
      $228 = $219;
      label = 6;
      break;
     } else {
      label = 31;
     }
    } else {
     $36 = (($34) + 4|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==(0);
     if ($38) {
      __THREW__ = 0;
      (invoke_ii(3405,($34|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       $228 = $219;
       label = 6;
       break;
      }
      $41 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      invoke_vii(3406,($41|0),1);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       $228 = $219;
       label = 6;
       break;
      }
      $44 = (($this) + 116|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = HEAP32[$8>>2]|0;
      $47 = HEAP32[$10>>2]|0;
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $49 = $46;
       $50 = $47;
       $51 = (($49) - ($50))|0;
       $52 = (($51|0) / 136)&-1;
       $i$02$i8 = 0;
       while(1) {
        $53 = (($45) + ($i$02$i8<<4)|0);
        $54 = Math_fround(HEAPF32[$53>>2]);
        $55 = ((($45) + ($i$02$i8<<4)|0) + 4|0);
        $56 = Math_fround(HEAPF32[$55>>2]);
        $57 = ((($45) + ($i$02$i8<<4)|0) + 8|0);
        $58 = Math_fround(HEAPF32[$57>>2]);
        $59 = ((($45) + ($i$02$i8<<4)|0) + 12|0);
        $60 = Math_fround(HEAPF32[$59>>2]);
        $61 = ((($47) + (($i$02$i8*136)|0)|0) + 104|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = ((($47) + (($i$02$i8*136)|0)|0) + 100|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = ($62|0)==($64|0);
        if (!($65)) {
         $66 = $62;
         $67 = $64;
         $68 = (($66) - ($67))|0;
         $69 = $68 >> 3;
         $v$01$i11 = 0;
         while(1) {
          $70 = (($64) + ($v$01$i11<<3)|0);
          $71 = Math_fround(HEAPF32[$70>>2]);
          $72 = Math_fround($58 * $71);
          $73 = Math_fround($54 + $72);
          HEAPF32[$70>>2] = $73;
          $74 = ((($64) + ($v$01$i11<<3)|0) + 4|0);
          $75 = Math_fround(HEAPF32[$74>>2]);
          $76 = Math_fround($60 * $75);
          $77 = Math_fround($56 + $76);
          HEAPF32[$74>>2] = $77;
          $78 = (($v$01$i11) + 1)|0;
          $79 = ($78>>>0)<($69>>>0);
          if ($79) {
           $v$01$i11 = $78;
          } else {
           break;
          }
         }
        }
        $80 = (($i$02$i8) + 1)|0;
        $81 = ($80>>>0)<($52>>>0);
        if ($81) {
         $i$02$i8 = $80;
        } else {
         break;
        }
       }
      }
      $82 = HEAP32[628288>>2]|0;
      HEAP32[$6>>2] = $82;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$6+0>>2]|0;
      invoke_vii(2591,($45|0),($$byval_copy14|0));
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if ($84) {
       $228 = $219;
       label = 6;
       break;
      }
      HEAP32[$44>>2] = 0;
      $85 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      invoke_vii(3407,($85|0),0);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       $228 = $219;
       label = 6;
       break;
      }
     } else {
      label = 31;
     }
    }
    do {
     if ((label|0) == 31) {
      $127 = HEAP32[$8>>2]|0;
      $128 = HEAP32[$10>>2]|0;
      $129 = $127;
      $130 = $128;
      $131 = (($129) - ($130))|0;
      $132 = (($131|0) / 136)&-1;
      $133 = $132 << 4;
      $134 = $133 | 15;
      $135 = ($134>>>0)<(2000);
      $136 = ($127|0)!=($128|0);
      do {
       if ($135) {
        if ($136) {
         $137 = STACKTOP; STACKTOP = STACKTOP + ((((1*$134)|0)+15)&-16)|0;;
         $147 = 0;$156 = $127;$158 = $128;$allocPtr2$0 = $137;
         label = 41;
        } else {
         $147 = 0;$156 = $127;$158 = $127;$allocPtr2$0 = 0;
         label = 41;
        }
       } else {
        if ($136) {
         $138 = HEAP32[628512>>2]|0;
         HEAP32[$7>>2] = $138;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$7+0>>2]|0;
         $139 = (invoke_iiiiiii(102,($134|0),16,($$byval_copy14|0),0,(799248|0),606)|0);
         $140 = __THREW__; __THREW__ = 0;
         $141 = $140&1;
         if ($141) {
          $142 = ___cxa_find_matching_catch()|0;
          $143 = tempRet0;
          $230 = $0;$231 = $143;$232 = $142;
          break;
         } else {
          $$pre = HEAP32[$8>>2]|0;
          $$pre24 = HEAP32[$10>>2]|0;
          $147 = $139;$156 = $$pre;$158 = $$pre24;$allocPtr2$0 = $139;
          label = 41;
          break;
         }
        } else {
         $147 = 0;$156 = $127;$158 = $127;$allocPtr2$0 = 0;
         label = 41;
        }
       }
      } while(0);
      if ((label|0) == 41) {
       $151 = $allocPtr2$0;
       $152 = (($151) + 15)|0;
       $153 = $152 & -16;
       $154 = $153;
       $155 = $156;
       $157 = $158;
       $159 = (($155) - ($157))|0;
       $160 = (($159|0) / 136)&-1;
       $161 = HEAP32[$33>>2]|0;
       $162 = ($159|0)>(0);
       L48: do {
        if ($162) {
         $i$01$i$i = 0;
         while(1) {
          $163 = (($30) + ($i$01$i$i<<2)|0);
          $164 = HEAP32[$163>>2]|0;
          $165 = ($164|0)==(0|0);
          if (!($165)) {
           $166 = (($164) + 56|0);
           $167 = HEAP32[$166>>2]|0;
           $168 = ($167|0)==(0);
           if (!($168)) {
            break;
           }
          }
          $171 = (($i$01$i$i) + 1)|0;
          $172 = ($171|0)<($160|0);
          if ($172) {
           $i$01$i$i = $171;
          } else {
           label = 46;
           break L48;
          }
         }
         __THREW__ = 0;
         invoke_vii(3408,($161|0),1);
         $169 = __THREW__; __THREW__ = 0;
         $170 = $169&1;
         if (!($170)) {
          label = 47;
         }
        } else {
         label = 46;
        }
       } while(0);
       if ((label|0) == 46) {
        __THREW__ = 0;
        invoke_vii(3408,($161|0),0);
        $173 = __THREW__; __THREW__ = 0;
        $174 = $173&1;
        if (!($174)) {
         label = 47;
        }
       }
       if ((label|0) == 47) {
        $175 = HEAP32[$33>>2]|0;
        __THREW__ = 0;
        (invoke_iiiiiiiii(43,($175|0),2048,($160|0),($30|0),($154|0),0,1,0)|0);
        $176 = __THREW__; __THREW__ = 0;
        $177 = $176&1;
        if (!($177)) {
         $178 = HEAP32[$8>>2]|0;
         $179 = HEAP32[$10>>2]|0;
         $180 = ($178|0)==($179|0);
         if (!($180)) {
          $181 = $178;
          $182 = $179;
          $183 = (($181) - ($182))|0;
          $184 = (($183|0) / 136)&-1;
          $i$02$i = 0;
          while(1) {
           $185 = (($154) + ($i$02$i<<4)|0);
           $186 = Math_fround(HEAPF32[$185>>2]);
           $187 = ((($154) + ($i$02$i<<4)|0) + 4|0);
           $188 = Math_fround(HEAPF32[$187>>2]);
           $189 = ((($154) + ($i$02$i<<4)|0) + 8|0);
           $190 = Math_fround(HEAPF32[$189>>2]);
           $191 = ((($154) + ($i$02$i<<4)|0) + 12|0);
           $192 = Math_fround(HEAPF32[$191>>2]);
           $193 = ((($179) + (($i$02$i*136)|0)|0) + 104|0);
           $194 = HEAP32[$193>>2]|0;
           $195 = ((($179) + (($i$02$i*136)|0)|0) + 100|0);
           $196 = HEAP32[$195>>2]|0;
           $197 = ($194|0)==($196|0);
           if (!($197)) {
            $198 = $194;
            $199 = $196;
            $200 = (($198) - ($199))|0;
            $201 = $200 >> 3;
            $v$01$i = 0;
            while(1) {
             $202 = (($196) + ($v$01$i<<3)|0);
             $203 = Math_fround(HEAPF32[$202>>2]);
             $204 = Math_fround($190 * $203);
             $205 = Math_fround($186 + $204);
             HEAPF32[$202>>2] = $205;
             $206 = ((($196) + ($v$01$i<<3)|0) + 4|0);
             $207 = Math_fround(HEAPF32[$206>>2]);
             $208 = Math_fround($192 * $207);
             $209 = Math_fround($188 + $208);
             HEAPF32[$206>>2] = $209;
             $210 = (($v$01$i) + 1)|0;
             $211 = ($210>>>0)<($201>>>0);
             if ($211) {
              $v$01$i = $210;
             } else {
              break;
             }
            }
           }
           $212 = (($i$02$i) + 1)|0;
           $213 = ($212>>>0)<($184>>>0);
           if ($213) {
            $i$02$i = $212;
           } else {
            break;
           }
          }
         }
         $214 = ($147|0)==(0|0);
         if ($214) {
          break;
         }
         $215 = HEAP32[628512>>2]|0;
         HEAP32[$3>>2] = $215;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
         invoke_vii(2591,($147|0),($$byval_copy14|0));
         $216 = __THREW__; __THREW__ = 0;
         $217 = $216&1;
         if ($217) {
          $228 = $219;
          label = 6;
          break L6;
         } else {
          break;
         }
        }
       }
       $144 = ___cxa_find_matching_catch()|0;
       $145 = tempRet0;
       $146 = ($147|0)==(0|0);
       if ($146) {
        $230 = $0;$231 = $145;$232 = $144;
       } else {
        $148 = HEAP32[628512>>2]|0;
        HEAP32[$0>>2] = $148;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($147|0),($$byval_copy14|0));
        $149 = __THREW__; __THREW__ = 0;
        $150 = $149&1;
        if ($150) {
         $226 = ___cxa_find_matching_catch(0|0)|0;
         $227 = tempRet0;
         ___clang_call_terminate($226);
         // unreachable;
        } else {
         $230 = $0;$231 = $145;$232 = $144;
        }
       }
      }
      $$0 = $232;$$01 = $231;$222 = $219;
      break L6;
     }
    } while(0);
    HEAP8[$this>>0] = 0;
    $218 = ($219|0)==(0|0);
    if ($218) {
     STACKTOP = sp;return;
    }
    $220 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $220;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($219,$$byval_copy14);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $229 = $228;$eh$lpad$body$index2Z2D = $26;$eh$lpad$body$indexZ2D = $25;
  label = 7;
 }
 if ((label|0) == 7) {
  $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index2Z2D;$222 = $229;
 }
 $221 = ($222|0)==(0|0);
 if ($221) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $223 = HEAP32[628512>>2]|0;
 HEAP32[$4>>2] = $223;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$4+0>>2]|0;
 invoke_vii(2591,($222|0),($$byval_copy14|0));
 $224 = __THREW__; __THREW__ = 0;
 $225 = $224&1;
 if ($225) {
  $226 = ___cxa_find_matching_catch(0|0)|0;
  $227 = tempRet0;
  ___clang_call_terminate($226);
  // unreachable;
 } else {
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __Z17dynamic_pptr_castIP9Texture2D6ObjectET_RK4PPtrIT0_E($ptr) {
 $ptr = $ptr|0;
 var $$0$i1 = 0, $$0$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$ptr>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if (!($2)) {
   HEAP32[$0>>2] = $1;
   $3 = HEAP32[560624>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    label = 10;
   } else {
    $5 = (($3) + 36|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($3) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($6|0)==($8|0);
    do {
     if ($9) {
      $10 = (($3) + 28|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (($3) + 32|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($11) + ($13<<3)|0);
      $30 = $14;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
      $15 = HEAP32[$pos$i$i$i$i>>2]|0;
      $16 = ($15|0)==(-1);
      $17 = (($3) + 28|0);
      $18 = HEAP32[$17>>2]|0;
      if ($16) {
       $19 = (($3) + 32|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($18) + ($20<<3)|0);
       $30 = $21;
       break;
      } else {
       $22 = (($18) + ($15<<3)|0);
       $30 = $22;
       break;
      }
     }
    } while(0);
    $23 = HEAP32[560624>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + ($27<<3)|0);
    $29 = ($30|0)==($28|0);
    if ($29) {
     label = 10;
    } else {
     $31 = (($30) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      label = 10;
     } else {
      $$0$i3 = $32;
     }
    }
   }
   if ((label|0) == 10) {
    $34 = HEAP32[$ptr>>2]|0;
    $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
    $36 = ($35|0)==(0|0);
    if ($36) {
     break;
    } else {
     $$0$i3 = $35;
    }
   }
   $37 = (($$0$i3) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38 >>> 21;
   $40 = HEAP32[560640>>2]|0;
   $41 = Math_imul($40, $39)|0;
   $42 = (($41) + 28)|0;
   $43 = $42 >> 5;
   $44 = $43 << 5;
   $45 = (($42) - ($44))|0;
   $46 = HEAP32[560632>>2]|0;
   $47 = (($46) + ($43<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = 1 << $45;
   $50 = $49 & $48;
   $51 = ($50|0)==(0);
   if (!($51)) {
    $$0$i1 = $$0$i3;
    STACKTOP = sp;return ($$0$i1|0);
   }
  }
 } while(0);
 $$0$i1 = 0;
 STACKTOP = sp;return ($$0$i1|0);
}
function __ZN14DetailDatabase22RefreshPrototypesStep1EPP9Texture2D($this,$sourceTextures) {
 $this = $this|0;
 $sourceTextures = $sourceTextures|0;
 var $$0$i285 = 0, $$0$i303 = 0, $$byval_copy = 0, $$byval_copy4 = 0, $$in = 0, $$in417 = 0, $$not = 0, $$not415 = 0, $$pre = 0, $$pre406 = 0, $$pre407 = 0, $$pre409 = 0, $$pre410 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0;
 var $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0;
 var $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0;
 var $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0;
 var $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0;
 var $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0;
 var $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0;
 var $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0;
 var $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0;
 var $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0;
 var $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0;
 var $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0;
 var $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0;
 var $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0;
 var $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0;
 var $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0;
 var $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0;
 var $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0;
 var $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0;
 var $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0;
 var $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0;
 var $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0;
 var $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0;
 var $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0;
 var $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0;
 var $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0;
 var $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0;
 var $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0;
 var $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0;
 var $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0;
 var $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0;
 var $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0;
 var $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0;
 var $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0;
 var $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0;
 var $998 = 0, $999 = 0, $__new_last1$i$i$i = 0, $__new_last1$i$i$i$i = 0, $__new_last1$i$i$i$i137 = 0, $__new_last1$i$i$i$i18 = 0, $__new_last1$i$i$i$i181 = 0, $__new_last1$i$i$i$i214 = 0, $__new_last1$i$i$i$i245 = 0, $__new_last1$i$i$i$i335 = 0, $__new_last1$i$i$i$i368 = 0, $__new_last1$i$i$i$i55 = 0, $__new_last1$i$i$i$i99 = 0, $__new_last1$i$i$i286 = 0, $__new_last2$i$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i304 = 0, $__new_last2$i$i$i$i121 = 0, $__new_last2$i$i$i$i165 = 0, $__new_last2$i$i$i$i198 = 0;
 var $__new_last2$i$i$i$i2 = 0, $__new_last2$i$i$i$i229 = 0, $__new_last2$i$i$i$i319 = 0, $__new_last2$i$i$i$i352 = 0, $__new_last2$i$i$i$i39 = 0, $__new_last2$i$i$i$i83 = 0, $__new_last2$i$i$i1$i = 0, $__new_last2$i$i$i1$i106 = 0, $__new_last2$i$i$i1$i144 = 0, $__new_last2$i$i$i1$i188 = 0, $__new_last2$i$i$i1$i221 = 0, $__new_last2$i$i$i1$i25 = 0, $__new_last2$i$i$i1$i252 = 0, $__new_last2$i$i$i1$i342 = 0, $__new_last2$i$i$i1$i375 = 0, $__new_last2$i$i$i1$i62 = 0, $__new_last2$i$i$i11$i = 0, $__new_last2$i$i$i11$i10 = 0, $__new_last2$i$i$i11$i129 = 0, $__new_last2$i$i$i11$i173 = 0;
 var $__new_last2$i$i$i11$i206 = 0, $__new_last2$i$i$i11$i237 = 0, $__new_last2$i$i$i11$i327 = 0, $__new_last2$i$i$i11$i360 = 0, $__new_last2$i$i$i11$i47 = 0, $__new_last2$i$i$i11$i91 = 0, $__new_last2$i$i$i296 = 0, $brmerge = 0, $brmerge416 = 0, $colors = 0, $i$0402 = 0, $or$cond = 0, $or$cond397 = 0, $or$cond398 = 0, $phitmp$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i305 = 0, $scevgep$i$i$i$i122 = 0;
 var $scevgep$i$i$i$i166 = 0, $scevgep$i$i$i$i199 = 0, $scevgep$i$i$i$i230 = 0, $scevgep$i$i$i$i3 = 0, $scevgep$i$i$i$i320 = 0, $scevgep$i$i$i$i353 = 0, $scevgep$i$i$i$i40 = 0, $scevgep$i$i$i$i84 = 0, $scevgep$i$i$i12$i = 0, $scevgep$i$i$i12$i11 = 0, $scevgep$i$i$i12$i130 = 0, $scevgep$i$i$i12$i174 = 0, $scevgep$i$i$i12$i207 = 0, $scevgep$i$i$i12$i238 = 0, $scevgep$i$i$i12$i328 = 0, $scevgep$i$i$i12$i361 = 0, $scevgep$i$i$i12$i48 = 0, $scevgep$i$i$i12$i92 = 0, $scevgep$i$i$i2$i = 0, $scevgep$i$i$i2$i107 = 0;
 var $scevgep$i$i$i2$i145 = 0, $scevgep$i$i$i2$i189 = 0, $scevgep$i$i$i2$i222 = 0, $scevgep$i$i$i2$i253 = 0, $scevgep$i$i$i2$i26 = 0, $scevgep$i$i$i2$i343 = 0, $scevgep$i$i$i2$i376 = 0, $scevgep$i$i$i2$i63 = 0, $scevgep$i$i$i275 = 0, $scevgep$i$i$i287 = 0, $scevgep$i$i$i292 = 0, $scevgep$i$i$i297 = 0, $scevgep$i$i$i8$i = 0, $scevgep$i$i$i8$i100 = 0, $scevgep$i$i$i8$i138 = 0, $scevgep$i$i$i8$i182 = 0, $scevgep$i$i$i8$i19 = 0, $scevgep$i$i$i8$i215 = 0, $scevgep$i$i$i8$i246 = 0, $scevgep$i$i$i8$i336 = 0;
 var $scevgep$i$i$i8$i369 = 0, $scevgep$i$i$i8$i56 = 0, $scevgep2$i$i$i = 0, $scevgep2$i$i$i$i = 0, $scevgep2$i$i$i$i101 = 0, $scevgep2$i$i$i$i139 = 0, $scevgep2$i$i$i$i183 = 0, $scevgep2$i$i$i$i20 = 0, $scevgep2$i$i$i$i216 = 0, $scevgep2$i$i$i$i247 = 0, $scevgep2$i$i$i$i337 = 0, $scevgep2$i$i$i$i370 = 0, $scevgep2$i$i$i$i57 = 0, $scevgep2$i$i$i276 = 0, $scevgep2$i$i$i288 = 0, $scevgep23$i$i$i = 0, $scevgep23$i$i$i$i = 0, $scevgep23$i$i$i$i102 = 0, $scevgep23$i$i$i$i140 = 0, $scevgep23$i$i$i$i184 = 0;
 var $scevgep23$i$i$i$i21 = 0, $scevgep23$i$i$i$i217 = 0, $scevgep23$i$i$i$i248 = 0, $scevgep23$i$i$i$i338 = 0, $scevgep23$i$i$i$i371 = 0, $scevgep23$i$i$i$i58 = 0, $scevgep23$i$i$i277 = 0, $scevgep23$i$i$i289 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i309 = 0, $scevgep4$i$i$i$i126 = 0, $scevgep4$i$i$i$i170 = 0, $scevgep4$i$i$i$i203 = 0, $scevgep4$i$i$i$i234 = 0, $scevgep4$i$i$i$i324 = 0, $scevgep4$i$i$i$i357 = 0, $scevgep4$i$i$i$i44 = 0, $scevgep4$i$i$i$i7 = 0;
 var $scevgep4$i$i$i$i88 = 0, $scevgep4$i$i$i16$i = 0, $scevgep4$i$i$i16$i134 = 0, $scevgep4$i$i$i16$i15 = 0, $scevgep4$i$i$i16$i178 = 0, $scevgep4$i$i$i16$i211 = 0, $scevgep4$i$i$i16$i242 = 0, $scevgep4$i$i$i16$i332 = 0, $scevgep4$i$i$i16$i365 = 0, $scevgep4$i$i$i16$i52 = 0, $scevgep4$i$i$i16$i96 = 0, $scevgep4$i$i$i278 = 0, $scevgep4$i$i$i290 = 0, $scevgep4$i$i$i293 = 0, $scevgep4$i$i$i301 = 0, $scevgep4$i$i$i6$i = 0, $scevgep4$i$i$i6$i111 = 0, $scevgep4$i$i$i6$i149 = 0, $scevgep4$i$i$i6$i193 = 0, $scevgep4$i$i$i6$i226 = 0;
 var $scevgep4$i$i$i6$i257 = 0, $scevgep4$i$i$i6$i30 = 0, $scevgep4$i$i$i6$i347 = 0, $scevgep4$i$i$i6$i380 = 0, $scevgep4$i$i$i6$i67 = 0, $scevgep4$i$i$i9$i = 0, $scevgep4$i$i$i9$i103 = 0, $scevgep4$i$i$i9$i141 = 0, $scevgep4$i$i$i9$i185 = 0, $scevgep4$i$i$i9$i218 = 0, $scevgep4$i$i$i9$i22 = 0, $scevgep4$i$i$i9$i249 = 0, $scevgep4$i$i$i9$i339 = 0, $scevgep4$i$i$i9$i372 = 0, $scevgep4$i$i$i9$i59 = 0, $storemerge = 0, $storemerge418 = 0, $temp$0$i = 0, $temp$0$i119 = 0, $temp$0$i157414 = 0;
 var $temp$0$i163 = 0, $temp$0$i265 = 0, $temp$0$i284 = 0, $temp$0$i317 = 0, $temp$0$i38 = 0, $temp$0$i387 = 0, $temp$0$i81 = 0, $tempBuffer = 0, $triangles = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i307 = 0, $uglygep$i$i$i$i124 = 0, $uglygep$i$i$i$i168 = 0, $uglygep$i$i$i$i201 = 0, $uglygep$i$i$i$i232 = 0, $uglygep$i$i$i$i322 = 0, $uglygep$i$i$i$i355 = 0, $uglygep$i$i$i$i42 = 0;
 var $uglygep$i$i$i$i5 = 0, $uglygep$i$i$i$i86 = 0, $uglygep$i$i$i14$i = 0, $uglygep$i$i$i14$i13 = 0, $uglygep$i$i$i14$i132 = 0, $uglygep$i$i$i14$i176 = 0, $uglygep$i$i$i14$i209 = 0, $uglygep$i$i$i14$i240 = 0, $uglygep$i$i$i14$i330 = 0, $uglygep$i$i$i14$i363 = 0, $uglygep$i$i$i14$i50 = 0, $uglygep$i$i$i14$i94 = 0, $uglygep$i$i$i299 = 0, $uglygep$i$i$i4$i = 0, $uglygep$i$i$i4$i109 = 0, $uglygep$i$i$i4$i147 = 0, $uglygep$i$i$i4$i191 = 0, $uglygep$i$i$i4$i224 = 0, $uglygep$i$i$i4$i255 = 0, $uglygep$i$i$i4$i28 = 0;
 var $uglygep$i$i$i4$i345 = 0, $uglygep$i$i$i4$i378 = 0, $uglygep$i$i$i4$i65 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i308 = 0, $uglygep3$i$i$i$i125 = 0, $uglygep3$i$i$i$i169 = 0, $uglygep3$i$i$i$i202 = 0, $uglygep3$i$i$i$i233 = 0, $uglygep3$i$i$i$i323 = 0, $uglygep3$i$i$i$i356 = 0, $uglygep3$i$i$i$i43 = 0, $uglygep3$i$i$i$i6 = 0, $uglygep3$i$i$i$i87 = 0, $uglygep3$i$i$i15$i = 0, $uglygep3$i$i$i15$i133 = 0, $uglygep3$i$i$i15$i14 = 0, $uglygep3$i$i$i15$i177 = 0;
 var $uglygep3$i$i$i15$i210 = 0, $uglygep3$i$i$i15$i241 = 0, $uglygep3$i$i$i15$i331 = 0, $uglygep3$i$i$i15$i364 = 0, $uglygep3$i$i$i15$i51 = 0, $uglygep3$i$i$i15$i95 = 0, $uglygep3$i$i$i300 = 0, $uglygep3$i$i$i5$i = 0, $uglygep3$i$i$i5$i110 = 0, $uglygep3$i$i$i5$i148 = 0, $uglygep3$i$i$i5$i192 = 0, $uglygep3$i$i$i5$i225 = 0, $uglygep3$i$i$i5$i256 = 0, $uglygep3$i$i$i5$i29 = 0, $uglygep3$i$i$i5$i346 = 0, $uglygep3$i$i$i5$i379 = 0, $uglygep3$i$i$i5$i66 = 0, $uvs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $$byval_copy4 = sp + 368|0;
 $$byval_copy = sp + 320|0;
 $0 = sp + 312|0;
 $1 = sp + 308|0;
 $2 = sp + 304|0;
 $3 = sp + 300|0;
 $4 = sp + 296|0;
 $5 = sp + 292|0;
 $6 = sp + 288|0;
 $7 = sp + 284|0;
 $8 = sp + 280|0;
 $9 = sp + 276|0;
 $10 = sp + 272|0;
 $11 = sp + 268|0;
 $12 = sp + 264|0;
 $13 = sp + 260|0;
 $14 = sp + 248|0;
 $15 = sp + 236|0;
 $16 = sp + 232|0;
 $17 = sp + 220|0;
 $18 = sp + 80|0;
 $19 = sp + 76|0;
 $20 = sp + 64|0;
 $21 = sp + 56|0;
 $22 = sp + 48|0;
 $23 = sp + 32|0;
 $24 = sp + 16|0;
 $25 = sp + 8|0;
 $26 = sp;
 $27 = sp + 20|0;
 $28 = sp + 96|0;
 $29 = sp + 104|0;
 $30 = sp + 112|0;
 $tempBuffer = sp + 124|0;
 $31 = sp + 136|0;
 $32 = sp + 140|0;
 $33 = sp + 144|0;
 $34 = sp + 156|0;
 $colors = sp + 160|0;
 $uvs = sp + 176|0;
 $triangles = sp + 376|0;
 $35 = sp + 208|0;
 $36 = (($this) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($37|0)==($39|0);
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($$byval_copy) + 4|0);
 $42 = (($$byval_copy) + 8|0);
 $43 = (($$byval_copy) + 12|0);
 $44 = (($$byval_copy) + 16|0);
 $45 = (($$byval_copy) + 20|0);
 $46 = (($$byval_copy) + 24|0);
 $47 = (($$byval_copy) + 28|0);
 $48 = (($$byval_copy) + 32|0);
 $49 = (($$byval_copy) + 36|0);
 $50 = (($$byval_copy) + 40|0);
 $51 = (($$byval_copy) + 44|0);
 $52 = (($colors) + 4|0);
 $53 = (($colors) + 8|0);
 $54 = (($colors) + 12|0);
 $55 = (($uvs) + 4|0);
 $56 = (($uvs) + 8|0);
 $57 = (($uvs) + 12|0);
 $58 = (($uvs) + 16|0);
 $59 = (($uvs) + 20|0);
 $60 = (($uvs) + 24|0);
 $61 = (($uvs) + 28|0);
 $62 = (($$byval_copy) + 48|0);
 $63 = (($colors) + 16|0);
 $64 = (($uvs) + 32|0);
 $65 = (($triangles) + 12|0);
 $66 = (($35) + 8|0);
 $67 = (($14) + 8|0);
 $68 = (($17) + 8|0);
 $69 = (($18) + 8|0);
 $70 = (($20) + 8|0);
 $71 = (($21) + 4|0);
 $72 = (($22) + 4|0);
 $73 = (($23) + 8|0);
 $74 = (($27) + 4|0);
 $75 = (($27) + 8|0);
 $76 = (($30) + 8|0);
 $77 = (($28) + 4|0);
 $78 = (($29) + 4|0);
 $79 = (($tempBuffer) + 4|0);
 $80 = (($tempBuffer) + 8|0);
 $81 = (($33) + 8|0);
 $82 = (($25) + 4|0);
 $83 = (($26) + 4|0);
 $84 = (($15) + 8|0);
 $87 = $39;$i$0402 = 0;
 L4: while(1) {
  $85 = (($sourceTextures) + ($i$0402<<2)|0);
  HEAP32[$85>>2] = 0;
  $86 = (($87) + (($i$0402*136)|0)|0);
  $88 = HEAP32[$86>>2]|0;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $90 = ((($87) + (($i$0402*136)|0)|0) + 72|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($91|0)==(0);
    if ($92) {
     label = 252;
    } else {
     label = 274;
    }
   } else {
    HEAP32[$13>>2] = $88;
    $93 = HEAP32[560624>>2]|0;
    $94 = ($93|0)==(0|0);
    if ($94) {
     label = 13;
    } else {
     $95 = (($93) + 36|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($93) + 4|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = ($96|0)==($98|0);
     do {
      if ($99) {
       $100 = (($93) + 28|0);
       $101 = HEAP32[$100>>2]|0;
       $102 = (($93) + 32|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = (($101) + ($103<<3)|0);
       $120 = $104;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$93,$13);
       $105 = HEAP32[$$byval_copy4>>2]|0;
       $106 = ($105|0)==(-1);
       $107 = (($93) + 28|0);
       $108 = HEAP32[$107>>2]|0;
       if ($106) {
        $109 = (($93) + 32|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = (($108) + ($110<<3)|0);
        $120 = $111;
        break;
       } else {
        $112 = (($108) + ($105<<3)|0);
        $120 = $112;
        break;
       }
      }
     } while(0);
     $113 = HEAP32[560624>>2]|0;
     $114 = (($113) + 28|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = (($113) + 32|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = (($115) + ($117<<3)|0);
     $119 = ($120|0)==($118|0);
     if ($119) {
      label = 13;
     } else {
      $121 = (($120) + 4|0);
      $122 = HEAP32[$121>>2]|0;
      $123 = ($122|0)==(0|0);
      if ($123) {
       label = 13;
      } else {
       $temp$0$i = $122;
      }
     }
    }
    if ((label|0) == 13) {
     label = 0;
     $124 = HEAP32[$86>>2]|0;
     $125 = (__Z31ReadObjectFromPersistentManageri($124)|0);
     $temp$0$i = $125;
    }
    $126 = ((($87) + (($i$0402*136)|0)|0) + 72|0);
    $127 = HEAP32[$126>>2]|0;
    $128 = ($127|0)==(0);
    $129 = ($temp$0$i|0)==(0|0);
    $or$cond = $128 | $129;
    if ($or$cond) {
     if ($128) {
      label = 252;
      break;
     } else {
      label = 274;
      break;
     }
    }
    $130 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($temp$0$i,25)|0);
    $131 = ($130|0)==(0|0);
    if ($131) {
     $132 = HEAP32[$temp$0$i>>2]|0;
     $133 = (($132) + 32|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (FUNCTION_TABLE_ii[$134 & 4095]($temp$0$i)|0);
     __Z6AppendPKcS0_($14,799280,$135);
     $136 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = ((($87) + (($i$0402*136)|0)|0) + 80|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = ($139|0)==($137|0);
     if (!($140)) {
      $__new_last2$i$i$i$i2 = $137;
      $scevgep$i$i$i$i3 = (($139) + -12|0);
      $141 = (0 - ($__new_last2$i$i$i$i2))|0;
      $uglygep$i$i$i$i5 = (($scevgep$i$i$i$i3) + ($141)|0);
      $uglygep3$i$i$i$i6 = $uglygep$i$i$i$i5;
      $142 = (($uglygep3$i$i$i$i6>>>0) / 12)&-1;
      $143 = $142 ^ -1;
      $scevgep4$i$i$i$i7 = (($139) + (($143*12)|0)|0);
      HEAP32[$138>>2] = $scevgep4$i$i$i$i7;
     }
     $144 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = ($147|0)==($145|0);
     if (!($148)) {
      $__new_last2$i$i$i11$i10 = $145;
      $scevgep$i$i$i12$i11 = (($147) + -8|0);
      $149 = (0 - ($__new_last2$i$i$i11$i10))|0;
      $uglygep$i$i$i14$i13 = (($scevgep$i$i$i12$i11) + ($149)|0);
      $uglygep3$i$i$i15$i14 = $uglygep$i$i$i14$i13;
      $150 = $uglygep3$i$i$i15$i14 >>> 3;
      $151 = $150 ^ -1;
      $scevgep4$i$i$i16$i15 = (($147) + ($151<<3)|0);
      HEAP32[$146>>2] = $scevgep4$i$i$i16$i15;
     }
     $152 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = ($155|0)==($153|0);
     if (!($156)) {
      $__new_last1$i$i$i$i18 = $153;
      $scevgep$i$i$i8$i19 = (($155) + -4|0);
      $157 = (0 - ($__new_last1$i$i$i$i18))|0;
      $scevgep2$i$i$i$i20 = (($scevgep$i$i$i8$i19) + ($157)|0);
      $scevgep23$i$i$i$i21 = $scevgep2$i$i$i$i20;
      $158 = $scevgep23$i$i$i$i21 >>> 2;
      $159 = $158 ^ -1;
      $scevgep4$i$i$i9$i22 = (($155) + ($159<<2)|0);
      HEAP32[$154>>2] = $scevgep4$i$i$i9$i22;
     }
     $160 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
     $163 = HEAP32[$162>>2]|0;
     $164 = ($163|0)==($161|0);
     if (!($164)) {
      $__new_last2$i$i$i1$i25 = $161;
      $scevgep$i$i$i2$i26 = (($163) + -2|0);
      $165 = (0 - ($__new_last2$i$i$i1$i25))|0;
      $uglygep$i$i$i4$i28 = (($scevgep$i$i$i2$i26) + ($165)|0);
      $uglygep3$i$i$i5$i29 = $uglygep$i$i$i4$i28;
      $166 = $uglygep3$i$i$i5$i29 >>> 1;
      $167 = $166 ^ -1;
      $scevgep4$i$i$i6$i30 = (($163) + ($167<<1)|0);
      HEAP32[$162>>2] = $scevgep4$i$i$i6$i30;
     }
     $168 = HEAP8[$14>>0]|0;
     $169 = $168 & 1;
     $170 = ($169<<24>>24)==(0);
     if ($170) {
      break;
     }
     $171 = HEAP32[$67>>2]|0;
     __ZdlPv($171);
     break;
    }
    $172 = HEAP32[$130>>2]|0;
    $173 = (($172) + 128|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = (FUNCTION_TABLE_ii[$174 & 4095]($130)|0);
    $176 = ($175|0)==(1);
    if (!($176)) {
     $177 = HEAP32[$86>>2]|0;
     HEAP32[$12>>2] = $177;
     $178 = HEAP32[560624>>2]|0;
     $179 = ($178|0)==(0|0);
     if ($179) {
      label = 35;
     } else {
      $180 = (($178) + 36|0);
      $181 = HEAP32[$180>>2]|0;
      $182 = (($178) + 4|0);
      $183 = HEAP32[$182>>2]|0;
      $184 = ($181|0)==($183|0);
      do {
       if ($184) {
        $185 = (($178) + 28|0);
        $186 = HEAP32[$185>>2]|0;
        $187 = (($178) + 32|0);
        $188 = HEAP32[$187>>2]|0;
        $189 = (($186) + ($188<<3)|0);
        $205 = $189;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$178,$12);
        $190 = HEAP32[$$byval_copy4>>2]|0;
        $191 = ($190|0)==(-1);
        $192 = (($178) + 28|0);
        $193 = HEAP32[$192>>2]|0;
        if ($191) {
         $194 = (($178) + 32|0);
         $195 = HEAP32[$194>>2]|0;
         $196 = (($193) + ($195<<3)|0);
         $205 = $196;
         break;
        } else {
         $197 = (($193) + ($190<<3)|0);
         $205 = $197;
         break;
        }
       }
      } while(0);
      $198 = HEAP32[560624>>2]|0;
      $199 = (($198) + 28|0);
      $200 = HEAP32[$199>>2]|0;
      $201 = (($198) + 32|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = (($200) + ($202<<3)|0);
      $204 = ($205|0)==($203|0);
      if ($204) {
       label = 35;
      } else {
       $206 = (($205) + 4|0);
       $207 = HEAP32[$206>>2]|0;
       $208 = ($207|0)==(0|0);
       if ($208) {
        label = 35;
       } else {
        $temp$0$i38 = $207;
       }
      }
     }
     if ((label|0) == 35) {
      label = 0;
      $209 = HEAP32[$86>>2]|0;
      $210 = (__Z31ReadObjectFromPersistentManageri($209)|0);
      $temp$0$i38 = $210;
     }
     $211 = HEAP32[$temp$0$i38>>2]|0;
     $212 = (($211) + 32|0);
     $213 = HEAP32[$212>>2]|0;
     $214 = (FUNCTION_TABLE_ii[$213 & 4095]($temp$0$i38)|0);
     __Z6AppendPKcS0_($15,$214,799304);
     $215 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = ((($87) + (($i$0402*136)|0)|0) + 80|0);
     $218 = HEAP32[$217>>2]|0;
     $219 = ($218|0)==($216|0);
     if (!($219)) {
      $__new_last2$i$i$i$i39 = $216;
      $scevgep$i$i$i$i40 = (($218) + -12|0);
      $220 = (0 - ($__new_last2$i$i$i$i39))|0;
      $uglygep$i$i$i$i42 = (($scevgep$i$i$i$i40) + ($220)|0);
      $uglygep3$i$i$i$i43 = $uglygep$i$i$i$i42;
      $221 = (($uglygep3$i$i$i$i43>>>0) / 12)&-1;
      $222 = $221 ^ -1;
      $scevgep4$i$i$i$i44 = (($218) + (($222*12)|0)|0);
      HEAP32[$217>>2] = $scevgep4$i$i$i$i44;
     }
     $223 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
     $224 = HEAP32[$223>>2]|0;
     $225 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
     $226 = HEAP32[$225>>2]|0;
     $227 = ($226|0)==($224|0);
     if (!($227)) {
      $__new_last2$i$i$i11$i47 = $224;
      $scevgep$i$i$i12$i48 = (($226) + -8|0);
      $228 = (0 - ($__new_last2$i$i$i11$i47))|0;
      $uglygep$i$i$i14$i50 = (($scevgep$i$i$i12$i48) + ($228)|0);
      $uglygep3$i$i$i15$i51 = $uglygep$i$i$i14$i50;
      $229 = $uglygep3$i$i$i15$i51 >>> 3;
      $230 = $229 ^ -1;
      $scevgep4$i$i$i16$i52 = (($226) + ($230<<3)|0);
      HEAP32[$225>>2] = $scevgep4$i$i$i16$i52;
     }
     $231 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
     $232 = HEAP32[$231>>2]|0;
     $233 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
     $234 = HEAP32[$233>>2]|0;
     $235 = ($234|0)==($232|0);
     if (!($235)) {
      $__new_last1$i$i$i$i55 = $232;
      $scevgep$i$i$i8$i56 = (($234) + -4|0);
      $236 = (0 - ($__new_last1$i$i$i$i55))|0;
      $scevgep2$i$i$i$i57 = (($scevgep$i$i$i8$i56) + ($236)|0);
      $scevgep23$i$i$i$i58 = $scevgep2$i$i$i$i57;
      $237 = $scevgep23$i$i$i$i58 >>> 2;
      $238 = $237 ^ -1;
      $scevgep4$i$i$i9$i59 = (($234) + ($238<<2)|0);
      HEAP32[$233>>2] = $scevgep4$i$i$i9$i59;
     }
     $239 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
     $240 = HEAP32[$239>>2]|0;
     $241 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = ($242|0)==($240|0);
     if (!($243)) {
      $__new_last2$i$i$i1$i62 = $240;
      $scevgep$i$i$i2$i63 = (($242) + -2|0);
      $244 = (0 - ($__new_last2$i$i$i1$i62))|0;
      $uglygep$i$i$i4$i65 = (($scevgep$i$i$i2$i63) + ($244)|0);
      $uglygep3$i$i$i5$i66 = $uglygep$i$i$i4$i65;
      $245 = $uglygep3$i$i$i5$i66 >>> 1;
      $246 = $245 ^ -1;
      $scevgep4$i$i$i6$i67 = (($242) + ($246<<1)|0);
      HEAP32[$241>>2] = $scevgep4$i$i$i6$i67;
     }
     $247 = HEAP8[$15>>0]|0;
     $248 = $247 & 1;
     $249 = ($248<<24>>24)==(0);
     if ($249) {
      break;
     }
     $250 = HEAP32[$84>>2]|0;
     __ZdlPv($250);
     break;
    }
    $251 = HEAP32[$130>>2]|0;
    $252 = (($251) + 132|0);
    $253 = HEAP32[$252>>2]|0;
    FUNCTION_TABLE_viii[$253 & 4095]($16,$130,0);
    $254 = HEAP32[$16>>2]|0;
    $255 = ($254|0)==(0);
    do {
     if (!($255)) {
      HEAP32[$11>>2] = $254;
      $256 = HEAP32[560624>>2]|0;
      $257 = ($256|0)==(0|0);
      if ($257) {
       label = 56;
      } else {
       $258 = (($256) + 36|0);
       $259 = HEAP32[$258>>2]|0;
       $260 = (($256) + 4|0);
       $261 = HEAP32[$260>>2]|0;
       $262 = ($259|0)==($261|0);
       do {
        if ($262) {
         $263 = (($256) + 28|0);
         $264 = HEAP32[$263>>2]|0;
         $265 = (($256) + 32|0);
         $266 = HEAP32[$265>>2]|0;
         $267 = (($264) + ($266<<3)|0);
         $283 = $267;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$256,$11);
         $268 = HEAP32[$$byval_copy4>>2]|0;
         $269 = ($268|0)==(-1);
         $270 = (($256) + 28|0);
         $271 = HEAP32[$270>>2]|0;
         if ($269) {
          $272 = (($256) + 32|0);
          $273 = HEAP32[$272>>2]|0;
          $274 = (($271) + ($273<<3)|0);
          $283 = $274;
          break;
         } else {
          $275 = (($271) + ($268<<3)|0);
          $283 = $275;
          break;
         }
        }
       } while(0);
       $276 = HEAP32[560624>>2]|0;
       $277 = (($276) + 28|0);
       $278 = HEAP32[$277>>2]|0;
       $279 = (($276) + 32|0);
       $280 = HEAP32[$279>>2]|0;
       $281 = (($278) + ($280<<3)|0);
       $282 = ($283|0)==($281|0);
       if ($282) {
        label = 56;
       } else {
        $284 = (($283) + 4|0);
        $285 = HEAP32[$284>>2]|0;
        $286 = ($285|0)==(0|0);
        if ($286) {
         label = 56;
        } else {
         $$in = $285;
        }
       }
      }
      if ((label|0) == 56) {
       label = 0;
       $287 = HEAP32[$16>>2]|0;
       $288 = (__Z31ReadObjectFromPersistentManageri($287)|0);
       $289 = ($288|0)==(0|0);
       if ($289) {
        break;
       } else {
        $$in = $288;
       }
      }
      $364 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($temp$0$i,33)|0);
      $365 = ($364|0)==(0|0);
      if ($365) {
       $366 = HEAP32[$86>>2]|0;
       HEAP32[$9>>2] = $366;
       $367 = HEAP32[560624>>2]|0;
       $368 = ($367|0)==(0|0);
       if ($368) {
        label = 85;
       } else {
        $369 = (($367) + 36|0);
        $370 = HEAP32[$369>>2]|0;
        $371 = (($367) + 4|0);
        $372 = HEAP32[$371>>2]|0;
        $373 = ($370|0)==($372|0);
        do {
         if ($373) {
          $374 = (($367) + 28|0);
          $375 = HEAP32[$374>>2]|0;
          $376 = (($367) + 32|0);
          $377 = HEAP32[$376>>2]|0;
          $378 = (($375) + ($377<<3)|0);
          $394 = $378;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$367,$9);
          $379 = HEAP32[$$byval_copy4>>2]|0;
          $380 = ($379|0)==(-1);
          $381 = (($367) + 28|0);
          $382 = HEAP32[$381>>2]|0;
          if ($380) {
           $383 = (($367) + 32|0);
           $384 = HEAP32[$383>>2]|0;
           $385 = (($382) + ($384<<3)|0);
           $394 = $385;
           break;
          } else {
           $386 = (($382) + ($379<<3)|0);
           $394 = $386;
           break;
          }
         }
        } while(0);
        $387 = HEAP32[560624>>2]|0;
        $388 = (($387) + 28|0);
        $389 = HEAP32[$388>>2]|0;
        $390 = (($387) + 32|0);
        $391 = HEAP32[$390>>2]|0;
        $392 = (($389) + ($391<<3)|0);
        $393 = ($394|0)==($392|0);
        if ($393) {
         label = 85;
        } else {
         $395 = (($394) + 4|0);
         $396 = HEAP32[$395>>2]|0;
         $397 = ($396|0)==(0|0);
         if ($397) {
          label = 85;
         } else {
          $temp$0$i119 = $396;
         }
        }
       }
       if ((label|0) == 85) {
        label = 0;
        $398 = HEAP32[$86>>2]|0;
        $399 = (__Z31ReadObjectFromPersistentManageri($398)|0);
        $temp$0$i119 = $399;
       }
       $400 = HEAP32[$temp$0$i119>>2]|0;
       $401 = (($400) + 32|0);
       $402 = HEAP32[$401>>2]|0;
       $403 = (FUNCTION_TABLE_ii[$402 & 4095]($temp$0$i119)|0);
       __Z6AppendPKcS0_($18,799368,$403);
       $404 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
       $405 = HEAP32[$404>>2]|0;
       $406 = ((($87) + (($i$0402*136)|0)|0) + 80|0);
       $407 = HEAP32[$406>>2]|0;
       $408 = ($407|0)==($405|0);
       if (!($408)) {
        $__new_last2$i$i$i$i121 = $405;
        $scevgep$i$i$i$i122 = (($407) + -12|0);
        $409 = (0 - ($__new_last2$i$i$i$i121))|0;
        $uglygep$i$i$i$i124 = (($scevgep$i$i$i$i122) + ($409)|0);
        $uglygep3$i$i$i$i125 = $uglygep$i$i$i$i124;
        $410 = (($uglygep3$i$i$i$i125>>>0) / 12)&-1;
        $411 = $410 ^ -1;
        $scevgep4$i$i$i$i126 = (($407) + (($411*12)|0)|0);
        HEAP32[$406>>2] = $scevgep4$i$i$i$i126;
       }
       $412 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
       $413 = HEAP32[$412>>2]|0;
       $414 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
       $415 = HEAP32[$414>>2]|0;
       $416 = ($415|0)==($413|0);
       if (!($416)) {
        $__new_last2$i$i$i11$i129 = $413;
        $scevgep$i$i$i12$i130 = (($415) + -8|0);
        $417 = (0 - ($__new_last2$i$i$i11$i129))|0;
        $uglygep$i$i$i14$i132 = (($scevgep$i$i$i12$i130) + ($417)|0);
        $uglygep3$i$i$i15$i133 = $uglygep$i$i$i14$i132;
        $418 = $uglygep3$i$i$i15$i133 >>> 3;
        $419 = $418 ^ -1;
        $scevgep4$i$i$i16$i134 = (($415) + ($419<<3)|0);
        HEAP32[$414>>2] = $scevgep4$i$i$i16$i134;
       }
       $420 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
       $421 = HEAP32[$420>>2]|0;
       $422 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
       $423 = HEAP32[$422>>2]|0;
       $424 = ($423|0)==($421|0);
       if (!($424)) {
        $__new_last1$i$i$i$i137 = $421;
        $scevgep$i$i$i8$i138 = (($423) + -4|0);
        $425 = (0 - ($__new_last1$i$i$i$i137))|0;
        $scevgep2$i$i$i$i139 = (($scevgep$i$i$i8$i138) + ($425)|0);
        $scevgep23$i$i$i$i140 = $scevgep2$i$i$i$i139;
        $426 = $scevgep23$i$i$i$i140 >>> 2;
        $427 = $426 ^ -1;
        $scevgep4$i$i$i9$i141 = (($423) + ($427<<2)|0);
        HEAP32[$422>>2] = $scevgep4$i$i$i9$i141;
       }
       $428 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
       $429 = HEAP32[$428>>2]|0;
       $430 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
       $431 = HEAP32[$430>>2]|0;
       $432 = ($431|0)==($429|0);
       if (!($432)) {
        $__new_last2$i$i$i1$i144 = $429;
        $scevgep$i$i$i2$i145 = (($431) + -2|0);
        $433 = (0 - ($__new_last2$i$i$i1$i144))|0;
        $uglygep$i$i$i4$i147 = (($scevgep$i$i$i2$i145) + ($433)|0);
        $uglygep3$i$i$i5$i148 = $uglygep$i$i$i4$i147;
        $434 = $uglygep3$i$i$i5$i148 >>> 1;
        $435 = $434 ^ -1;
        $scevgep4$i$i$i6$i149 = (($431) + ($435<<1)|0);
        HEAP32[$430>>2] = $scevgep4$i$i$i6$i149;
       }
       $436 = HEAP8[$18>>0]|0;
       $437 = $436 & 1;
       $438 = ($437<<24>>24)==(0);
       if ($438) {
        break L6;
       }
       $439 = HEAP32[$69>>2]|0;
       __ZdlPv($439);
       break L6;
      }
      __ZN10MeshFilter13GetSharedMeshEv($19,$364);
      $440 = HEAP32[$19>>2]|0;
      $441 = ($440|0)==(0);
      do {
       if (!($441)) {
        HEAP32[$8>>2] = $440;
        $442 = HEAP32[560624>>2]|0;
        $443 = ($442|0)==(0|0);
        if ($443) {
         label = 106;
        } else {
         $444 = (($442) + 36|0);
         $445 = HEAP32[$444>>2]|0;
         $446 = (($442) + 4|0);
         $447 = HEAP32[$446>>2]|0;
         $448 = ($445|0)==($447|0);
         do {
          if ($448) {
           $449 = (($442) + 28|0);
           $450 = HEAP32[$449>>2]|0;
           $451 = (($442) + 32|0);
           $452 = HEAP32[$451>>2]|0;
           $453 = (($450) + ($452<<3)|0);
           $469 = $453;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$442,$8);
           $454 = HEAP32[$$byval_copy4>>2]|0;
           $455 = ($454|0)==(-1);
           $456 = (($442) + 28|0);
           $457 = HEAP32[$456>>2]|0;
           if ($455) {
            $458 = (($442) + 32|0);
            $459 = HEAP32[$458>>2]|0;
            $460 = (($457) + ($459<<3)|0);
            $469 = $460;
            break;
           } else {
            $461 = (($457) + ($454<<3)|0);
            $469 = $461;
            break;
           }
          }
         } while(0);
         $462 = HEAP32[560624>>2]|0;
         $463 = (($462) + 28|0);
         $464 = HEAP32[$463>>2]|0;
         $465 = (($462) + 32|0);
         $466 = HEAP32[$465>>2]|0;
         $467 = (($464) + ($466<<3)|0);
         $468 = ($469|0)==($467|0);
         if ($468) {
          label = 106;
         } else {
          $470 = (($469) + 4|0);
          $471 = HEAP32[$470>>2]|0;
          $472 = ($471|0)==(0|0);
          if ($472) {
           label = 106;
          } else {
           $$in417 = $471;$temp$0$i157414 = $471;
          }
         }
        }
        if ((label|0) == 106) {
         label = 0;
         $473 = HEAP32[$19>>2]|0;
         $474 = (__Z31ReadObjectFromPersistentManageri($473)|0);
         $475 = ($474|0)==(0|0);
         if ($475) {
          break;
         } else {
          $$in417 = $474;$temp$0$i157414 = $474;
         }
        }
        $550 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
        $551 = (($temp$0$i157414) + 28|0);
        $552 = HEAP32[$551>>2]|0;
        $553 = (($552) + 10|0);
        $554 = HEAP8[$553>>0]|0;
        $555 = ($554<<24>>24)==(0);
        do {
         if ($555) {
          $556 = (($552) + 11|0);
          $557 = HEAP8[$556>>0]|0;
          $558 = ($557&255)<(3);
          if ($558) {
           label = 128;
          } else {
           $559 = (($552) + 92|0);
           $560 = HEAP32[$559>>2]|0;
           $561 = ($560|0)==(0|0);
           if ($561) {
            HEAP32[$21>>2] = 0;
            HEAP32[$71>>2] = 1;
            label = 133;
            break;
           } else {
            $562 = (($552) + 8|0);
            $563 = HEAP8[$562>>0]|0;
            $564 = $563&255;
            $565 = ((($552) + (($564*12)|0)|0) + 50|0);
            $566 = HEAP8[$565>>0]|0;
            $567 = $566&255;
            $568 = ((($552) + (($564*12)|0)|0) + 44|0);
            $569 = HEAP32[$568>>2]|0;
            $570 = (($552) + 9|0);
            $571 = HEAP8[$570>>0]|0;
            $572 = $571&255;
            $573 = (($572) + ($569))|0;
            $574 = (($560) + ($573)|0);
            $storemerge = $567;$storemerge418 = $574;
            label = 132;
            break;
           }
          }
         } else {
          label = 128;
         }
        } while(0);
        if ((label|0) == 128) {
         label = 0;
         $storemerge = 0;$storemerge418 = 0;
         label = 132;
        }
        if ((label|0) == 132) {
         label = 0;
         HEAP32[$21>>2] = $storemerge418;
         HEAP32[$71>>2] = $storemerge;
         if ($555) {
          label = 133;
         } else {
          label = 134;
         }
        }
        do {
         if ((label|0) == 133) {
          label = 0;
          $575 = (($552) + 11|0);
          $576 = HEAP8[$575>>0]|0;
          $577 = ($576&255)<(3);
          if ($577) {
           label = 134;
          } else {
           $578 = (($552) + 92|0);
           $579 = HEAP32[$578>>2]|0;
           $580 = ($579|0)==(0|0);
           if ($580) {
            HEAP32[$22>>2] = 0;
            HEAP32[$72>>2] = 1;
            break;
           } else {
            $581 = (($552) + 100|0);
            $582 = HEAP32[$581>>2]|0;
            $583 = (($552) + 8|0);
            $584 = HEAP8[$583>>0]|0;
            $585 = $584&255;
            $586 = ((($552) + (($585*12)|0)|0) + 50|0);
            $587 = HEAP8[$586>>0]|0;
            $588 = $587&255;
            $589 = ((($552) + (($585*12)|0)|0) + 44|0);
            $590 = HEAP32[$589>>2]|0;
            $591 = (($552) + 9|0);
            $592 = HEAP8[$591>>0]|0;
            $593 = $592&255;
            $594 = Math_imul($588, $582)|0;
            $595 = (($594) + ($590))|0;
            $596 = (($595) + ($593))|0;
            $597 = (($579) + ($596)|0);
            HEAP32[$22>>2] = $597;
            HEAP32[$72>>2] = $588;
            break;
           }
          }
         }
        } while(0);
        if ((label|0) == 134) {
         label = 0;
         HEAP32[$22>>2] = 0;
         HEAP32[$72>>2] = 0;
        }
        __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE6assignI14StrideIteratorIS1_EEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($550,$21,$22);
        $598 = HEAP32[$550>>2]|0;
        $599 = ((($87) + (($i$0402*136)|0)|0) + 80|0);
        $600 = HEAP32[$599>>2]|0;
        $601 = ($598|0)==($600|0);
        if ($601) {
         $602 = HEAP32[$temp$0$i>>2]|0;
         $603 = (($602) + 32|0);
         $604 = HEAP32[$603>>2]|0;
         $605 = (FUNCTION_TABLE_ii[$604 & 4095]($temp$0$i)|0);
         __Z6AppendPKcS0_($23,799408,$605);
         $606 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
         $607 = HEAP32[$606>>2]|0;
         $608 = HEAP32[$599>>2]|0;
         $609 = ($608|0)==($607|0);
         if (!($609)) {
          $__new_last2$i$i$i$i198 = $607;
          $scevgep$i$i$i$i199 = (($608) + -12|0);
          $610 = (0 - ($__new_last2$i$i$i$i198))|0;
          $uglygep$i$i$i$i201 = (($scevgep$i$i$i$i199) + ($610)|0);
          $uglygep3$i$i$i$i202 = $uglygep$i$i$i$i201;
          $611 = (($uglygep3$i$i$i$i202>>>0) / 12)&-1;
          $612 = $611 ^ -1;
          $scevgep4$i$i$i$i203 = (($608) + (($612*12)|0)|0);
          HEAP32[$599>>2] = $scevgep4$i$i$i$i203;
         }
         $613 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
         $614 = HEAP32[$613>>2]|0;
         $615 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
         $616 = HEAP32[$615>>2]|0;
         $617 = ($616|0)==($614|0);
         if (!($617)) {
          $__new_last2$i$i$i11$i206 = $614;
          $scevgep$i$i$i12$i207 = (($616) + -8|0);
          $618 = (0 - ($__new_last2$i$i$i11$i206))|0;
          $uglygep$i$i$i14$i209 = (($scevgep$i$i$i12$i207) + ($618)|0);
          $uglygep3$i$i$i15$i210 = $uglygep$i$i$i14$i209;
          $619 = $uglygep3$i$i$i15$i210 >>> 3;
          $620 = $619 ^ -1;
          $scevgep4$i$i$i16$i211 = (($616) + ($620<<3)|0);
          HEAP32[$615>>2] = $scevgep4$i$i$i16$i211;
         }
         $621 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
         $622 = HEAP32[$621>>2]|0;
         $623 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
         $624 = HEAP32[$623>>2]|0;
         $625 = ($624|0)==($622|0);
         if (!($625)) {
          $__new_last1$i$i$i$i214 = $622;
          $scevgep$i$i$i8$i215 = (($624) + -4|0);
          $626 = (0 - ($__new_last1$i$i$i$i214))|0;
          $scevgep2$i$i$i$i216 = (($scevgep$i$i$i8$i215) + ($626)|0);
          $scevgep23$i$i$i$i217 = $scevgep2$i$i$i$i216;
          $627 = $scevgep23$i$i$i$i217 >>> 2;
          $628 = $627 ^ -1;
          $scevgep4$i$i$i9$i218 = (($624) + ($628<<2)|0);
          HEAP32[$623>>2] = $scevgep4$i$i$i9$i218;
         }
         $629 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
         $630 = HEAP32[$629>>2]|0;
         $631 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
         $632 = HEAP32[$631>>2]|0;
         $633 = ($632|0)==($630|0);
         if (!($633)) {
          $__new_last2$i$i$i1$i221 = $630;
          $scevgep$i$i$i2$i222 = (($632) + -2|0);
          $634 = (0 - ($__new_last2$i$i$i1$i221))|0;
          $uglygep$i$i$i4$i224 = (($scevgep$i$i$i2$i222) + ($634)|0);
          $uglygep3$i$i$i5$i225 = $uglygep$i$i$i4$i224;
          $635 = $uglygep3$i$i$i5$i225 >>> 1;
          $636 = $635 ^ -1;
          $scevgep4$i$i$i6$i226 = (($632) + ($636<<1)|0);
          HEAP32[$631>>2] = $scevgep4$i$i$i6$i226;
         }
         $637 = HEAP8[$23>>0]|0;
         $638 = $637 & 1;
         $639 = ($638<<24>>24)==(0);
         if ($639) {
          break L6;
         }
         $640 = HEAP32[$73>>2]|0;
         __ZdlPv($640);
         break L6;
        }
        $641 = HEAP32[$551>>2]|0;
        $642 = (($641) + 19|0);
        $643 = HEAP8[$642>>0]|0;
        $644 = ($643<<24>>24)==(0);
        $645 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
        do {
         if ($644) {
          $664 = HEAP32[$645>>2]|0;
          $665 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
          $666 = HEAP32[$665>>2]|0;
          $667 = ($666|0)==($664|0);
          $$pre409 = $664;
          if ($667) {
           $672 = $641;$675 = $664;
          } else {
           $scevgep$i$i$i275 = (($666) + -4|0);
           $668 = (0 - ($$pre409))|0;
           $scevgep2$i$i$i276 = (($scevgep$i$i$i275) + ($668)|0);
           $scevgep23$i$i$i277 = $scevgep2$i$i$i276;
           $669 = $scevgep23$i$i$i277 >>> 2;
           $670 = $669 ^ -1;
           $scevgep4$i$i$i278 = (($666) + ($670<<2)|0);
           HEAP32[$665>>2] = $scevgep4$i$i$i278;
           $$pre = HEAP32[$551>>2]|0;
           $672 = $$pre;$675 = $scevgep4$i$i$i278;
          }
          $671 = (($672) + 100|0);
          $673 = HEAP32[$671>>2]|0;
          HEAP32[$24>>2] = -1;
          $674 = $675;
          $676 = (($674) - ($$pre409))|0;
          $677 = $676 >> 2;
          $678 = ($677>>>0)<($673>>>0);
          if ($678) {
           $679 = (($673) - ($677))|0;
           __ZNSt3__16vectorI11ColorRGBA32NS_9allocatorIS1_EEE8__appendEjRKS1_($645,$679,$24);
           break;
          }
          $680 = ($677>>>0)>($673>>>0);
          if (!($680)) {
           break;
          }
          $681 = (($664) + ($673<<2)|0);
          $682 = ($675|0)==($681|0);
          if ($682) {
           break;
          }
          $__new_last1$i$i$i286 = $681;
          $scevgep$i$i$i287 = (($675) + -4|0);
          $683 = (0 - ($__new_last1$i$i$i286))|0;
          $scevgep2$i$i$i288 = (($scevgep$i$i$i287) + ($683)|0);
          $scevgep23$i$i$i289 = $scevgep2$i$i$i288;
          $684 = $scevgep23$i$i$i289 >>> 2;
          $685 = $684 ^ -1;
          $scevgep4$i$i$i290 = (($675) + ($685<<2)|0);
          HEAP32[$665>>2] = $scevgep4$i$i$i290;
         } else {
          $646 = (($641) + 100|0);
          $647 = HEAP32[$646>>2]|0;
          $648 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
          $649 = HEAP32[$648>>2]|0;
          $650 = HEAP32[$645>>2]|0;
          $651 = $649;
          $652 = $650;
          $653 = (($651) - ($652))|0;
          $654 = $653 >> 2;
          $655 = ($654>>>0)<($647>>>0);
          do {
           if ($655) {
            $656 = (($647) - ($654))|0;
            __ZNSt3__16vectorI11ColorRGBA32NS_9allocatorIS1_EEE8__appendEj($645,$656);
            $$pre407 = HEAP32[$645>>2]|0;
            $663 = $$pre407;
           } else {
            $657 = ($654>>>0)>($647>>>0);
            if (!($657)) {
             $663 = $650;
             break;
            }
            $658 = (($650) + ($647<<2)|0);
            $659 = ($649|0)==($658|0);
            if ($659) {
             $663 = $650;
             break;
            }
            $__new_last1$i$i$i = $658;
            $scevgep$i$i$i = (($649) + -4|0);
            $660 = (0 - ($__new_last1$i$i$i))|0;
            $scevgep2$i$i$i = (($scevgep$i$i$i) + ($660)|0);
            $scevgep23$i$i$i = $scevgep2$i$i$i;
            $661 = $scevgep23$i$i$i >>> 2;
            $662 = $661 ^ -1;
            $scevgep4$i$i$i = (($649) + ($662<<2)|0);
            HEAP32[$648>>2] = $scevgep4$i$i$i;
            $663 = $650;
           }
          } while(0);
          __ZNK4Mesh17ExtractColorArrayEP11ColorRGBA32($$in417,$663);
         }
        } while(0);
        $686 = HEAP32[$551>>2]|0;
        $687 = (($686) + 15|0);
        $688 = HEAP8[$687>>0]|0;
        $689 = ($688<<24>>24)==(0);
        $690 = ((($87) + (($i$0402*136)|0)|0) + 88|0);
        do {
         if ($689) {
          $731 = HEAP32[$690>>2]|0;
          $732 = ((($87) + (($i$0402*136)|0)|0) + 92|0);
          $733 = HEAP32[$732>>2]|0;
          $734 = ($733|0)==($731|0);
          $$pre410 = $731;
          if ($734) {
           $739 = $686;$742 = $731;
          } else {
           $scevgep$i$i$i292 = (($733) + -12|0);
           $735 = (0 - ($$pre410))|0;
           $uglygep$i$i$i = (($scevgep$i$i$i292) + ($735)|0);
           $uglygep3$i$i$i = $uglygep$i$i$i;
           $736 = (($uglygep3$i$i$i>>>0) / 12)&-1;
           $737 = $736 ^ -1;
           $scevgep4$i$i$i293 = (($733) + (($737*12)|0)|0);
           HEAP32[$732>>2] = $scevgep4$i$i$i293;
           $$pre406 = HEAP32[$551>>2]|0;
           $739 = $$pre406;$742 = $scevgep4$i$i$i293;
          }
          $738 = (($739) + 100|0);
          $740 = HEAP32[$738>>2]|0;
          HEAPF32[$27>>2] = Math_fround(0.0);
          HEAPF32[$74>>2] = Math_fround(1.0);
          HEAPF32[$75>>2] = Math_fround(0.0);
          $741 = $742;
          $743 = (($741) - ($$pre410))|0;
          $744 = (($743|0) / 12)&-1;
          $745 = ($744>>>0)<($740>>>0);
          if ($745) {
           $746 = (($740) - ($744))|0;
           __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE8__appendEjRKS1_($690,$746,$27);
           break;
          }
          $747 = ($744>>>0)>($740>>>0);
          if (!($747)) {
           break;
          }
          $748 = (($731) + (($740*12)|0)|0);
          $749 = ($742|0)==($748|0);
          if ($749) {
           break;
          }
          $__new_last2$i$i$i296 = $748;
          $scevgep$i$i$i297 = (($742) + -12|0);
          $750 = (0 - ($__new_last2$i$i$i296))|0;
          $uglygep$i$i$i299 = (($scevgep$i$i$i297) + ($750)|0);
          $uglygep3$i$i$i300 = $uglygep$i$i$i299;
          $751 = (($uglygep3$i$i$i300>>>0) / 12)&-1;
          $752 = $751 ^ -1;
          $scevgep4$i$i$i301 = (($742) + (($752*12)|0)|0);
          HEAP32[$732>>2] = $scevgep4$i$i$i301;
         } else {
          $691 = (($686) + 14|0);
          $692 = HEAP8[$691>>0]|0;
          $693 = ($692<<24>>24)!=(0);
          $694 = ($688&255)<(3);
          $or$cond397 = $693 | $694;
          do {
           if ($or$cond397) {
            HEAP32[$25>>2] = 0;
            HEAP32[$82>>2] = 0;
           } else {
            $695 = (($686) + 92|0);
            $696 = HEAP32[$695>>2]|0;
            $697 = ($696|0)==(0|0);
            if ($697) {
             HEAP32[$25>>2] = 0;
             HEAP32[$82>>2] = 1;
             break;
            } else {
             $698 = (($686) + 12|0);
             $699 = HEAP8[$698>>0]|0;
             $700 = $699&255;
             $701 = ((($686) + (($700*12)|0)|0) + 50|0);
             $702 = HEAP8[$701>>0]|0;
             $703 = $702&255;
             $704 = ((($686) + (($700*12)|0)|0) + 44|0);
             $705 = HEAP32[$704>>2]|0;
             $706 = (($686) + 13|0);
             $707 = HEAP8[$706>>0]|0;
             $708 = $707&255;
             $709 = (($708) + ($705))|0;
             $710 = (($696) + ($709)|0);
             HEAP32[$25>>2] = $710;
             HEAP32[$82>>2] = $703;
             break;
            }
           }
          } while(0);
          $$not = ($692<<24>>24)!=(0);
          $brmerge = $$not | $694;
          do {
           if ($brmerge) {
            HEAP32[$26>>2] = 0;
            HEAP32[$83>>2] = 0;
           } else {
            $711 = (($686) + 92|0);
            $712 = HEAP32[$711>>2]|0;
            $713 = ($712|0)==(0|0);
            if ($713) {
             HEAP32[$26>>2] = 0;
             HEAP32[$83>>2] = 1;
             break;
            } else {
             $714 = (($686) + 100|0);
             $715 = HEAP32[$714>>2]|0;
             $716 = (($686) + 12|0);
             $717 = HEAP8[$716>>0]|0;
             $718 = $717&255;
             $719 = ((($686) + (($718*12)|0)|0) + 50|0);
             $720 = HEAP8[$719>>0]|0;
             $721 = $720&255;
             $722 = ((($686) + (($718*12)|0)|0) + 44|0);
             $723 = HEAP32[$722>>2]|0;
             $724 = (($686) + 13|0);
             $725 = HEAP8[$724>>0]|0;
             $726 = $725&255;
             $727 = Math_imul($721, $715)|0;
             $728 = (($727) + ($723))|0;
             $729 = (($728) + ($726))|0;
             $730 = (($712) + ($729)|0);
             HEAP32[$26>>2] = $730;
             HEAP32[$83>>2] = $721;
             break;
            }
           }
          } while(0);
          __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE6assignI14StrideIteratorIS1_EEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($690,$25,$26);
         }
        } while(0);
        $753 = HEAP32[$551>>2]|0;
        $754 = (($753) + 23|0);
        $755 = HEAP8[$754>>0]|0;
        $756 = ($755<<24>>24)==(0);
        if ($756) {
         $800 = HEAP32[$86>>2]|0;
         HEAP32[$1>>2] = $800;
         $801 = HEAP32[560624>>2]|0;
         $802 = ($801|0)==(0|0);
         do {
          if ($802) {
           label = 202;
          } else {
           $803 = (($801) + 36|0);
           $804 = HEAP32[$803>>2]|0;
           $805 = (($801) + 4|0);
           $806 = HEAP32[$805>>2]|0;
           $807 = ($804|0)==($806|0);
           do {
            if ($807) {
             $808 = (($801) + 28|0);
             $809 = HEAP32[$808>>2]|0;
             $810 = (($801) + 32|0);
             $811 = HEAP32[$810>>2]|0;
             $812 = (($809) + ($811<<3)|0);
             $828 = $812;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$801,$1);
             $813 = HEAP32[$$byval_copy4>>2]|0;
             $814 = ($813|0)==(-1);
             $815 = (($801) + 28|0);
             $816 = HEAP32[$815>>2]|0;
             if ($814) {
              $817 = (($801) + 32|0);
              $818 = HEAP32[$817>>2]|0;
              $819 = (($816) + ($818<<3)|0);
              $828 = $819;
              break;
             } else {
              $820 = (($816) + ($813<<3)|0);
              $828 = $820;
              break;
             }
            }
           } while(0);
           $821 = HEAP32[560624>>2]|0;
           $822 = (($821) + 28|0);
           $823 = HEAP32[$822>>2]|0;
           $824 = (($821) + 32|0);
           $825 = HEAP32[$824>>2]|0;
           $826 = (($823) + ($825<<3)|0);
           $827 = ($828|0)==($826|0);
           if ($827) {
            label = 202;
            break;
           }
           $829 = (($828) + 4|0);
           $830 = HEAP32[$829>>2]|0;
           $831 = ($830|0)==(0|0);
           if ($831) {
            label = 202;
           } else {
            $temp$0$i317 = $830;
           }
          }
         } while(0);
         if ((label|0) == 202) {
          label = 0;
          $832 = HEAP32[$86>>2]|0;
          $833 = (__Z31ReadObjectFromPersistentManageri($832)|0);
          $temp$0$i317 = $833;
         }
         $834 = HEAP32[$temp$0$i317>>2]|0;
         $835 = (($834) + 32|0);
         $836 = HEAP32[$835>>2]|0;
         $837 = (FUNCTION_TABLE_ii[$836 & 4095]($temp$0$i317)|0);
         __Z6AppendPKcS0_($30,799432,$837);
         $838 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
         $839 = HEAP32[$838>>2]|0;
         $840 = HEAP32[$599>>2]|0;
         $841 = ($840|0)==($839|0);
         if (!($841)) {
          $__new_last2$i$i$i$i319 = $839;
          $scevgep$i$i$i$i320 = (($840) + -12|0);
          $842 = (0 - ($__new_last2$i$i$i$i319))|0;
          $uglygep$i$i$i$i322 = (($scevgep$i$i$i$i320) + ($842)|0);
          $uglygep3$i$i$i$i323 = $uglygep$i$i$i$i322;
          $843 = (($uglygep3$i$i$i$i323>>>0) / 12)&-1;
          $844 = $843 ^ -1;
          $scevgep4$i$i$i$i324 = (($840) + (($844*12)|0)|0);
          HEAP32[$599>>2] = $scevgep4$i$i$i$i324;
         }
         $845 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
         $846 = HEAP32[$845>>2]|0;
         $847 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
         $848 = HEAP32[$847>>2]|0;
         $849 = ($848|0)==($846|0);
         if (!($849)) {
          $__new_last2$i$i$i11$i327 = $846;
          $scevgep$i$i$i12$i328 = (($848) + -8|0);
          $850 = (0 - ($__new_last2$i$i$i11$i327))|0;
          $uglygep$i$i$i14$i330 = (($scevgep$i$i$i12$i328) + ($850)|0);
          $uglygep3$i$i$i15$i331 = $uglygep$i$i$i14$i330;
          $851 = $uglygep3$i$i$i15$i331 >>> 3;
          $852 = $851 ^ -1;
          $scevgep4$i$i$i16$i332 = (($848) + ($852<<3)|0);
          HEAP32[$847>>2] = $scevgep4$i$i$i16$i332;
         }
         $853 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
         $854 = HEAP32[$853>>2]|0;
         $855 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
         $856 = HEAP32[$855>>2]|0;
         $857 = ($856|0)==($854|0);
         if (!($857)) {
          $__new_last1$i$i$i$i335 = $854;
          $scevgep$i$i$i8$i336 = (($856) + -4|0);
          $858 = (0 - ($__new_last1$i$i$i$i335))|0;
          $scevgep2$i$i$i$i337 = (($scevgep$i$i$i8$i336) + ($858)|0);
          $scevgep23$i$i$i$i338 = $scevgep2$i$i$i$i337;
          $859 = $scevgep23$i$i$i$i338 >>> 2;
          $860 = $859 ^ -1;
          $scevgep4$i$i$i9$i339 = (($856) + ($860<<2)|0);
          HEAP32[$855>>2] = $scevgep4$i$i$i9$i339;
         }
         $861 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
         $862 = HEAP32[$861>>2]|0;
         $863 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
         $864 = HEAP32[$863>>2]|0;
         $865 = ($864|0)==($862|0);
         if (!($865)) {
          $__new_last2$i$i$i1$i342 = $862;
          $scevgep$i$i$i2$i343 = (($864) + -2|0);
          $866 = (0 - ($__new_last2$i$i$i1$i342))|0;
          $uglygep$i$i$i4$i345 = (($scevgep$i$i$i2$i343) + ($866)|0);
          $uglygep3$i$i$i5$i346 = $uglygep$i$i$i4$i345;
          $867 = $uglygep3$i$i$i5$i346 >>> 1;
          $868 = $867 ^ -1;
          $scevgep4$i$i$i6$i347 = (($864) + ($868<<1)|0);
          HEAP32[$863>>2] = $scevgep4$i$i$i6$i347;
         }
         $869 = HEAP8[$30>>0]|0;
         $870 = $869 & 1;
         $871 = ($870<<24>>24)==(0);
         if ($871) {
          break L6;
         }
         $872 = HEAP32[$76>>2]|0;
         __ZdlPv($872);
         break L6;
        }
        $757 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
        $758 = (($753) + 22|0);
        $759 = HEAP8[$758>>0]|0;
        $760 = ($759<<24>>24)!=(0);
        $761 = ($755&255)<(2);
        $or$cond398 = $760 | $761;
        do {
         if ($or$cond398) {
          HEAP32[$28>>2] = 0;
          HEAP32[$77>>2] = 0;
         } else {
          $762 = (($753) + 92|0);
          $763 = HEAP32[$762>>2]|0;
          $764 = ($763|0)==(0|0);
          if ($764) {
           HEAP32[$28>>2] = 0;
           HEAP32[$77>>2] = 1;
           break;
          } else {
           $765 = (($753) + 20|0);
           $766 = HEAP8[$765>>0]|0;
           $767 = $766&255;
           $768 = ((($753) + (($767*12)|0)|0) + 50|0);
           $769 = HEAP8[$768>>0]|0;
           $770 = $769&255;
           $771 = ((($753) + (($767*12)|0)|0) + 44|0);
           $772 = HEAP32[$771>>2]|0;
           $773 = (($753) + 21|0);
           $774 = HEAP8[$773>>0]|0;
           $775 = $774&255;
           $776 = (($775) + ($772))|0;
           $777 = (($763) + ($776)|0);
           HEAP32[$28>>2] = $777;
           HEAP32[$77>>2] = $770;
           break;
          }
         }
        } while(0);
        $$not415 = ($759<<24>>24)!=(0);
        $brmerge416 = $$not415 | $761;
        do {
         if ($brmerge416) {
          HEAP32[$29>>2] = 0;
          HEAP32[$78>>2] = 0;
         } else {
          $778 = (($753) + 92|0);
          $779 = HEAP32[$778>>2]|0;
          $780 = ($779|0)==(0|0);
          if ($780) {
           HEAP32[$29>>2] = 0;
           HEAP32[$78>>2] = 1;
           break;
          } else {
           $781 = (($753) + 100|0);
           $782 = HEAP32[$781>>2]|0;
           $783 = (($753) + 20|0);
           $784 = HEAP8[$783>>0]|0;
           $785 = $784&255;
           $786 = ((($753) + (($785*12)|0)|0) + 50|0);
           $787 = HEAP8[$786>>0]|0;
           $788 = $787&255;
           $789 = ((($753) + (($785*12)|0)|0) + 44|0);
           $790 = HEAP32[$789>>2]|0;
           $791 = (($753) + 21|0);
           $792 = HEAP8[$791>>0]|0;
           $793 = $792&255;
           $794 = Math_imul($788, $782)|0;
           $795 = (($794) + ($790))|0;
           $796 = (($795) + ($793))|0;
           $797 = (($779) + ($796)|0);
           HEAP32[$29>>2] = $797;
           HEAP32[$78>>2] = $788;
           break;
          }
         }
        } while(0);
        __ZNSt3__16vectorI8Vector2fNS_9allocatorIS1_EEE6assignI14StrideIteratorIS1_EEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($757,$28,$29);
        HEAP32[$tempBuffer>>2] = 0;
        HEAP32[$79>>2] = 0;
        HEAP32[$80>>2] = 0;
        __THREW__ = 0;
        invoke_vii(3409,($$in417|0),($tempBuffer|0));
        $798 = __THREW__; __THREW__ = 0;
        $799 = $798&1;
        if ($799) {
         label = 236;
         break L4;
        }
        $873 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
        $874 = HEAP32[$tempBuffer>>2]|0;
        HEAP32[$31>>2] = $874;
        $875 = HEAP32[$79>>2]|0;
        HEAP32[$32>>2] = $875;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$31+0>>2]|0;
        ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$32+0>>2]|0;
        invoke_viii(2024,($873|0),($$byval_copy|0),($$byval_copy4|0));
        $876 = __THREW__; __THREW__ = 0;
        $877 = $876&1;
        if ($877) {
         label = 236;
         break L4;
        }
        $878 = HEAP32[$873>>2]|0;
        $879 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
        $880 = HEAP32[$879>>2]|0;
        $881 = ($878|0)==($880|0);
        do {
         if ($881) {
          $882 = HEAP32[$86>>2]|0;
          HEAP32[$0>>2] = $882;
          $883 = HEAP32[560624>>2]|0;
          $884 = ($883|0)==(0|0);
          do {
           if ($884) {
            label = 223;
           } else {
            $885 = (($883) + 36|0);
            $886 = HEAP32[$885>>2]|0;
            $887 = (($883) + 4|0);
            $888 = HEAP32[$887>>2]|0;
            $889 = ($886|0)==($888|0);
            do {
             if ($889) {
              $890 = (($883) + 28|0);
              $891 = HEAP32[$890>>2]|0;
              $892 = (($883) + 32|0);
              $893 = HEAP32[$892>>2]|0;
              $894 = (($891) + ($893<<3)|0);
              $910 = $894;
             } else {
              __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$883,$0);
              $895 = HEAP32[$$byval_copy4>>2]|0;
              $896 = ($895|0)==(-1);
              $897 = (($883) + 28|0);
              $898 = HEAP32[$897>>2]|0;
              if ($896) {
               $899 = (($883) + 32|0);
               $900 = HEAP32[$899>>2]|0;
               $901 = (($898) + ($900<<3)|0);
               $910 = $901;
               break;
              } else {
               $902 = (($898) + ($895<<3)|0);
               $910 = $902;
               break;
              }
             }
            } while(0);
            $903 = HEAP32[560624>>2]|0;
            $904 = (($903) + 28|0);
            $905 = HEAP32[$904>>2]|0;
            $906 = (($903) + 32|0);
            $907 = HEAP32[$906>>2]|0;
            $908 = (($905) + ($907<<3)|0);
            $909 = ($910|0)==($908|0);
            if ($909) {
             label = 223;
             break;
            }
            $911 = (($910) + 4|0);
            $912 = HEAP32[$911>>2]|0;
            $913 = ($912|0)==(0|0);
            if ($913) {
             label = 223;
            } else {
             $temp$0$i387 = $912;
            }
           }
          } while(0);
          if ((label|0) == 223) {
           label = 0;
           $914 = HEAP32[$86>>2]|0;
           __THREW__ = 0;
           $915 = (invoke_ii(3215,($914|0))|0);
           $916 = __THREW__; __THREW__ = 0;
           $917 = $916&1;
           if ($917) {
            label = 236;
            break L4;
           } else {
            $temp$0$i387 = $915;
           }
          }
          $918 = HEAP32[$temp$0$i387>>2]|0;
          $919 = (($918) + 32|0);
          $920 = HEAP32[$919>>2]|0;
          __THREW__ = 0;
          $921 = (invoke_ii($920|0,($temp$0$i387|0))|0);
          $922 = __THREW__; __THREW__ = 0;
          $923 = $922&1;
          if ($923) {
           label = 236;
           break L4;
          }
          __THREW__ = 0;
          invoke_viii(1727,($33|0),(799456|0),($921|0));
          $924 = __THREW__; __THREW__ = 0;
          $925 = $924&1;
          if ($925) {
           label = 236;
           break L4;
          }
          $926 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
          $927 = HEAP32[$926>>2]|0;
          $928 = HEAP32[$599>>2]|0;
          $929 = ($928|0)==($927|0);
          if (!($929)) {
           $__new_last2$i$i$i$i352 = $927;
           $scevgep$i$i$i$i353 = (($928) + -12|0);
           $930 = (0 - ($__new_last2$i$i$i$i352))|0;
           $uglygep$i$i$i$i355 = (($scevgep$i$i$i$i353) + ($930)|0);
           $uglygep3$i$i$i$i356 = $uglygep$i$i$i$i355;
           $931 = (($uglygep3$i$i$i$i356>>>0) / 12)&-1;
           $932 = $931 ^ -1;
           $scevgep4$i$i$i$i357 = (($928) + (($932*12)|0)|0);
           HEAP32[$599>>2] = $scevgep4$i$i$i$i357;
          }
          $933 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
          $934 = HEAP32[$933>>2]|0;
          $935 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
          $936 = HEAP32[$935>>2]|0;
          $937 = ($936|0)==($934|0);
          if (!($937)) {
           $__new_last2$i$i$i11$i360 = $934;
           $scevgep$i$i$i12$i361 = (($936) + -8|0);
           $938 = (0 - ($__new_last2$i$i$i11$i360))|0;
           $uglygep$i$i$i14$i363 = (($scevgep$i$i$i12$i361) + ($938)|0);
           $uglygep3$i$i$i15$i364 = $uglygep$i$i$i14$i363;
           $939 = $uglygep3$i$i$i15$i364 >>> 3;
           $940 = $939 ^ -1;
           $scevgep4$i$i$i16$i365 = (($936) + ($940<<3)|0);
           HEAP32[$935>>2] = $scevgep4$i$i$i16$i365;
          }
          $941 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
          $942 = HEAP32[$941>>2]|0;
          $943 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
          $944 = HEAP32[$943>>2]|0;
          $945 = ($944|0)==($942|0);
          if (!($945)) {
           $__new_last1$i$i$i$i368 = $942;
           $scevgep$i$i$i8$i369 = (($944) + -4|0);
           $946 = (0 - ($__new_last1$i$i$i$i368))|0;
           $scevgep2$i$i$i$i370 = (($scevgep$i$i$i8$i369) + ($946)|0);
           $scevgep23$i$i$i$i371 = $scevgep2$i$i$i$i370;
           $947 = $scevgep23$i$i$i$i371 >>> 2;
           $948 = $947 ^ -1;
           $scevgep4$i$i$i9$i372 = (($944) + ($948<<2)|0);
           HEAP32[$943>>2] = $scevgep4$i$i$i9$i372;
          }
          $949 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
          $950 = HEAP32[$949>>2]|0;
          $951 = HEAP32[$879>>2]|0;
          $952 = ($951|0)==($950|0);
          if (!($952)) {
           $__new_last2$i$i$i1$i375 = $950;
           $scevgep$i$i$i2$i376 = (($951) + -2|0);
           $953 = (0 - ($__new_last2$i$i$i1$i375))|0;
           $uglygep$i$i$i4$i378 = (($scevgep$i$i$i2$i376) + ($953)|0);
           $uglygep3$i$i$i5$i379 = $uglygep$i$i$i4$i378;
           $954 = $uglygep3$i$i$i5$i379 >>> 1;
           $955 = $954 ^ -1;
           $scevgep4$i$i$i6$i380 = (($951) + ($955<<1)|0);
           HEAP32[$879>>2] = $scevgep4$i$i$i6$i380;
          }
          $956 = HEAP8[$33>>0]|0;
          $957 = $956 & 1;
          $958 = ($957<<24>>24)==(0);
          if ($958) {
           break;
          }
          $959 = HEAP32[$81>>2]|0;
          __ZdlPv($959);
         } else {
          $973 = HEAP32[799256>>2]|0;
          HEAP32[$34>>2] = $973;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$34+0>>2]|0;
          $974 = (invoke_iii(2596,($$in|0),($$byval_copy4|0))|0);
          $975 = __THREW__; __THREW__ = 0;
          $976 = $975&1;
          if ($976) {
           label = 236;
           break L4;
          }
          $977 = ($974|0)==(0|0);
          if ($977) {
           label = 244;
          } else {
           $978 = (($974) + 8|0);
           $979 = HEAP32[$978>>2]|0;
           $980 = $979 >>> 21;
           $981 = HEAP32[560640>>2]|0;
           $982 = Math_imul($981, $980)|0;
           $983 = (($982) + 28)|0;
           $984 = $983 >> 5;
           $985 = $984 << 5;
           $986 = (($983) - ($985))|0;
           $987 = HEAP32[560632>>2]|0;
           $988 = (($987) + ($984<<2)|0);
           $989 = HEAP32[$988>>2]|0;
           $990 = 1 << $986;
           $991 = $990 & $989;
           $992 = ($991|0)==(0);
           if ($992) {
            label = 244;
           } else {
            $$0$i303 = $974;
           }
          }
          if ((label|0) == 244) {
           label = 0;
           $$0$i303 = 0;
          }
          HEAP32[$85>>2] = $$0$i303;
         }
        } while(0);
        $993 = HEAP32[$tempBuffer>>2]|0;
        $994 = ($993|0)==(0|0);
        if ($994) {
         break L6;
        }
        $995 = HEAP32[$79>>2]|0;
        $996 = ($995|0)==($993|0);
        if (!($996)) {
         $__new_last2$i$i$i$i$i = $993;
         $scevgep$i$i$i$i$i = (($995) + -4|0);
         $997 = (0 - ($__new_last2$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($997)|0);
         $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
         $998 = $uglygep3$i$i$i$i$i >>> 2;
         $999 = $998 ^ -1;
         $scevgep4$i$i$i$i$i = (($995) + ($999<<2)|0);
         HEAP32[$79>>2] = $scevgep4$i$i$i$i$i;
        }
        HEAP32[$2>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($993|0),($$byval_copy4|0));
        $1000 = __THREW__; __THREW__ = 0;
        $1001 = $1000&1;
        if ($1001) {
         label = 250;
         break L4;
        } else {
         break L6;
        }
       }
      } while(0);
      $476 = HEAP32[$86>>2]|0;
      HEAP32[$7>>2] = $476;
      $477 = HEAP32[560624>>2]|0;
      $478 = ($477|0)==(0|0);
      if ($478) {
       label = 115;
      } else {
       $479 = (($477) + 36|0);
       $480 = HEAP32[$479>>2]|0;
       $481 = (($477) + 4|0);
       $482 = HEAP32[$481>>2]|0;
       $483 = ($480|0)==($482|0);
       do {
        if ($483) {
         $484 = (($477) + 28|0);
         $485 = HEAP32[$484>>2]|0;
         $486 = (($477) + 32|0);
         $487 = HEAP32[$486>>2]|0;
         $488 = (($485) + ($487<<3)|0);
         $504 = $488;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$477,$7);
         $489 = HEAP32[$$byval_copy4>>2]|0;
         $490 = ($489|0)==(-1);
         $491 = (($477) + 28|0);
         $492 = HEAP32[$491>>2]|0;
         if ($490) {
          $493 = (($477) + 32|0);
          $494 = HEAP32[$493>>2]|0;
          $495 = (($492) + ($494<<3)|0);
          $504 = $495;
          break;
         } else {
          $496 = (($492) + ($489<<3)|0);
          $504 = $496;
          break;
         }
        }
       } while(0);
       $497 = HEAP32[560624>>2]|0;
       $498 = (($497) + 28|0);
       $499 = HEAP32[$498>>2]|0;
       $500 = (($497) + 32|0);
       $501 = HEAP32[$500>>2]|0;
       $502 = (($499) + ($501<<3)|0);
       $503 = ($504|0)==($502|0);
       if ($503) {
        label = 115;
       } else {
        $505 = (($504) + 4|0);
        $506 = HEAP32[$505>>2]|0;
        $507 = ($506|0)==(0|0);
        if ($507) {
         label = 115;
        } else {
         $temp$0$i163 = $506;
        }
       }
      }
      if ((label|0) == 115) {
       label = 0;
       $508 = HEAP32[$86>>2]|0;
       $509 = (__Z31ReadObjectFromPersistentManageri($508)|0);
       $temp$0$i163 = $509;
      }
      $510 = HEAP32[$temp$0$i163>>2]|0;
      $511 = (($510) + 32|0);
      $512 = HEAP32[$511>>2]|0;
      $513 = (FUNCTION_TABLE_ii[$512 & 4095]($temp$0$i163)|0);
      __Z6AppendPKcS0_($20,799392,$513);
      $514 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
      $515 = HEAP32[$514>>2]|0;
      $516 = ((($87) + (($i$0402*136)|0)|0) + 80|0);
      $517 = HEAP32[$516>>2]|0;
      $518 = ($517|0)==($515|0);
      if (!($518)) {
       $__new_last2$i$i$i$i165 = $515;
       $scevgep$i$i$i$i166 = (($517) + -12|0);
       $519 = (0 - ($__new_last2$i$i$i$i165))|0;
       $uglygep$i$i$i$i168 = (($scevgep$i$i$i$i166) + ($519)|0);
       $uglygep3$i$i$i$i169 = $uglygep$i$i$i$i168;
       $520 = (($uglygep3$i$i$i$i169>>>0) / 12)&-1;
       $521 = $520 ^ -1;
       $scevgep4$i$i$i$i170 = (($517) + (($521*12)|0)|0);
       HEAP32[$516>>2] = $scevgep4$i$i$i$i170;
      }
      $522 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
      $523 = HEAP32[$522>>2]|0;
      $524 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
      $525 = HEAP32[$524>>2]|0;
      $526 = ($525|0)==($523|0);
      if (!($526)) {
       $__new_last2$i$i$i11$i173 = $523;
       $scevgep$i$i$i12$i174 = (($525) + -8|0);
       $527 = (0 - ($__new_last2$i$i$i11$i173))|0;
       $uglygep$i$i$i14$i176 = (($scevgep$i$i$i12$i174) + ($527)|0);
       $uglygep3$i$i$i15$i177 = $uglygep$i$i$i14$i176;
       $528 = $uglygep3$i$i$i15$i177 >>> 3;
       $529 = $528 ^ -1;
       $scevgep4$i$i$i16$i178 = (($525) + ($529<<3)|0);
       HEAP32[$524>>2] = $scevgep4$i$i$i16$i178;
      }
      $530 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
      $531 = HEAP32[$530>>2]|0;
      $532 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
      $533 = HEAP32[$532>>2]|0;
      $534 = ($533|0)==($531|0);
      if (!($534)) {
       $__new_last1$i$i$i$i181 = $531;
       $scevgep$i$i$i8$i182 = (($533) + -4|0);
       $535 = (0 - ($__new_last1$i$i$i$i181))|0;
       $scevgep2$i$i$i$i183 = (($scevgep$i$i$i8$i182) + ($535)|0);
       $scevgep23$i$i$i$i184 = $scevgep2$i$i$i$i183;
       $536 = $scevgep23$i$i$i$i184 >>> 2;
       $537 = $536 ^ -1;
       $scevgep4$i$i$i9$i185 = (($533) + ($537<<2)|0);
       HEAP32[$532>>2] = $scevgep4$i$i$i9$i185;
      }
      $538 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
      $539 = HEAP32[$538>>2]|0;
      $540 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
      $541 = HEAP32[$540>>2]|0;
      $542 = ($541|0)==($539|0);
      if (!($542)) {
       $__new_last2$i$i$i1$i188 = $539;
       $scevgep$i$i$i2$i189 = (($541) + -2|0);
       $543 = (0 - ($__new_last2$i$i$i1$i188))|0;
       $uglygep$i$i$i4$i191 = (($scevgep$i$i$i2$i189) + ($543)|0);
       $uglygep3$i$i$i5$i192 = $uglygep$i$i$i4$i191;
       $544 = $uglygep3$i$i$i5$i192 >>> 1;
       $545 = $544 ^ -1;
       $scevgep4$i$i$i6$i193 = (($541) + ($545<<1)|0);
       HEAP32[$540>>2] = $scevgep4$i$i$i6$i193;
      }
      $546 = HEAP8[$20>>0]|0;
      $547 = $546 & 1;
      $548 = ($547<<24>>24)==(0);
      if ($548) {
       break L6;
      }
      $549 = HEAP32[$70>>2]|0;
      __ZdlPv($549);
      break L6;
     }
    } while(0);
    $290 = HEAP32[$86>>2]|0;
    HEAP32[$10>>2] = $290;
    $291 = HEAP32[560624>>2]|0;
    $292 = ($291|0)==(0|0);
    if ($292) {
     label = 65;
    } else {
     $293 = (($291) + 36|0);
     $294 = HEAP32[$293>>2]|0;
     $295 = (($291) + 4|0);
     $296 = HEAP32[$295>>2]|0;
     $297 = ($294|0)==($296|0);
     do {
      if ($297) {
       $298 = (($291) + 28|0);
       $299 = HEAP32[$298>>2]|0;
       $300 = (($291) + 32|0);
       $301 = HEAP32[$300>>2]|0;
       $302 = (($299) + ($301<<3)|0);
       $318 = $302;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$291,$10);
       $303 = HEAP32[$$byval_copy4>>2]|0;
       $304 = ($303|0)==(-1);
       $305 = (($291) + 28|0);
       $306 = HEAP32[$305>>2]|0;
       if ($304) {
        $307 = (($291) + 32|0);
        $308 = HEAP32[$307>>2]|0;
        $309 = (($306) + ($308<<3)|0);
        $318 = $309;
        break;
       } else {
        $310 = (($306) + ($303<<3)|0);
        $318 = $310;
        break;
       }
      }
     } while(0);
     $311 = HEAP32[560624>>2]|0;
     $312 = (($311) + 28|0);
     $313 = HEAP32[$312>>2]|0;
     $314 = (($311) + 32|0);
     $315 = HEAP32[$314>>2]|0;
     $316 = (($313) + ($315<<3)|0);
     $317 = ($318|0)==($316|0);
     if ($317) {
      label = 65;
     } else {
      $319 = (($318) + 4|0);
      $320 = HEAP32[$319>>2]|0;
      $321 = ($320|0)==(0|0);
      if ($321) {
       label = 65;
      } else {
       $temp$0$i81 = $320;
      }
     }
    }
    if ((label|0) == 65) {
     label = 0;
     $322 = HEAP32[$86>>2]|0;
     $323 = (__Z31ReadObjectFromPersistentManageri($322)|0);
     $temp$0$i81 = $323;
    }
    $324 = HEAP32[$temp$0$i81>>2]|0;
    $325 = (($324) + 32|0);
    $326 = HEAP32[$325>>2]|0;
    $327 = (FUNCTION_TABLE_ii[$326 & 4095]($temp$0$i81)|0);
    __Z6AppendPKcS0_($17,799344,$327);
    $328 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
    $329 = HEAP32[$328>>2]|0;
    $330 = ((($87) + (($i$0402*136)|0)|0) + 80|0);
    $331 = HEAP32[$330>>2]|0;
    $332 = ($331|0)==($329|0);
    if (!($332)) {
     $__new_last2$i$i$i$i83 = $329;
     $scevgep$i$i$i$i84 = (($331) + -12|0);
     $333 = (0 - ($__new_last2$i$i$i$i83))|0;
     $uglygep$i$i$i$i86 = (($scevgep$i$i$i$i84) + ($333)|0);
     $uglygep3$i$i$i$i87 = $uglygep$i$i$i$i86;
     $334 = (($uglygep3$i$i$i$i87>>>0) / 12)&-1;
     $335 = $334 ^ -1;
     $scevgep4$i$i$i$i88 = (($331) + (($335*12)|0)|0);
     HEAP32[$330>>2] = $scevgep4$i$i$i$i88;
    }
    $336 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
    $337 = HEAP32[$336>>2]|0;
    $338 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
    $339 = HEAP32[$338>>2]|0;
    $340 = ($339|0)==($337|0);
    if (!($340)) {
     $__new_last2$i$i$i11$i91 = $337;
     $scevgep$i$i$i12$i92 = (($339) + -8|0);
     $341 = (0 - ($__new_last2$i$i$i11$i91))|0;
     $uglygep$i$i$i14$i94 = (($scevgep$i$i$i12$i92) + ($341)|0);
     $uglygep3$i$i$i15$i95 = $uglygep$i$i$i14$i94;
     $342 = $uglygep3$i$i$i15$i95 >>> 3;
     $343 = $342 ^ -1;
     $scevgep4$i$i$i16$i96 = (($339) + ($343<<3)|0);
     HEAP32[$338>>2] = $scevgep4$i$i$i16$i96;
    }
    $344 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
    $345 = HEAP32[$344>>2]|0;
    $346 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
    $347 = HEAP32[$346>>2]|0;
    $348 = ($347|0)==($345|0);
    if (!($348)) {
     $__new_last1$i$i$i$i99 = $345;
     $scevgep$i$i$i8$i100 = (($347) + -4|0);
     $349 = (0 - ($__new_last1$i$i$i$i99))|0;
     $scevgep2$i$i$i$i101 = (($scevgep$i$i$i8$i100) + ($349)|0);
     $scevgep23$i$i$i$i102 = $scevgep2$i$i$i$i101;
     $350 = $scevgep23$i$i$i$i102 >>> 2;
     $351 = $350 ^ -1;
     $scevgep4$i$i$i9$i103 = (($347) + ($351<<2)|0);
     HEAP32[$346>>2] = $scevgep4$i$i$i9$i103;
    }
    $352 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
    $353 = HEAP32[$352>>2]|0;
    $354 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
    $355 = HEAP32[$354>>2]|0;
    $356 = ($355|0)==($353|0);
    if (!($356)) {
     $__new_last2$i$i$i1$i106 = $353;
     $scevgep$i$i$i2$i107 = (($355) + -2|0);
     $357 = (0 - ($__new_last2$i$i$i1$i106))|0;
     $uglygep$i$i$i4$i109 = (($scevgep$i$i$i2$i107) + ($357)|0);
     $uglygep3$i$i$i5$i110 = $uglygep$i$i$i4$i109;
     $358 = $uglygep3$i$i$i5$i110 >>> 1;
     $359 = $358 ^ -1;
     $scevgep4$i$i$i6$i111 = (($355) + ($359<<1)|0);
     HEAP32[$354>>2] = $scevgep4$i$i$i6$i111;
    }
    $360 = HEAP8[$17>>0]|0;
    $361 = $360 & 1;
    $362 = ($361<<24>>24)==(0);
    if (!($362)) {
     $363 = HEAP32[$68>>2]|0;
     __ZdlPv($363);
    }
   }
  } while(0);
  do {
   if ((label|0) == 252) {
    label = 0;
    $1004 = ((($87) + (($i$0402*136)|0)|0) + 4|0);
    $1005 = HEAP32[$1004>>2]|0;
    $1006 = ($1005|0)==(0);
    if ($1006) {
     label = 274;
    } else {
     HEAP32[$3>>2] = $1005;
     $1007 = HEAP32[560624>>2]|0;
     $1008 = ($1007|0)==(0|0);
     if ($1008) {
      label = 261;
     } else {
      $1009 = (($1007) + 36|0);
      $1010 = HEAP32[$1009>>2]|0;
      $1011 = (($1007) + 4|0);
      $1012 = HEAP32[$1011>>2]|0;
      $1013 = ($1010|0)==($1012|0);
      do {
       if ($1013) {
        $1014 = (($1007) + 28|0);
        $1015 = HEAP32[$1014>>2]|0;
        $1016 = (($1007) + 32|0);
        $1017 = HEAP32[$1016>>2]|0;
        $1018 = (($1015) + ($1017<<3)|0);
        $1034 = $1018;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$1007,$3);
        $1019 = HEAP32[$$byval_copy4>>2]|0;
        $1020 = ($1019|0)==(-1);
        $1021 = (($1007) + 28|0);
        $1022 = HEAP32[$1021>>2]|0;
        if ($1020) {
         $1023 = (($1007) + 32|0);
         $1024 = HEAP32[$1023>>2]|0;
         $1025 = (($1022) + ($1024<<3)|0);
         $1034 = $1025;
         break;
        } else {
         $1026 = (($1022) + ($1019<<3)|0);
         $1034 = $1026;
         break;
        }
       }
      } while(0);
      $1027 = HEAP32[560624>>2]|0;
      $1028 = (($1027) + 28|0);
      $1029 = HEAP32[$1028>>2]|0;
      $1030 = (($1027) + 32|0);
      $1031 = HEAP32[$1030>>2]|0;
      $1032 = (($1029) + ($1031<<3)|0);
      $1033 = ($1034|0)==($1032|0);
      if ($1033) {
       label = 261;
      } else {
       $1035 = (($1034) + 4|0);
       $1036 = HEAP32[$1035>>2]|0;
       $1037 = ($1036|0)==(0|0);
       if ($1037) {
        label = 261;
       }
      }
     }
     if ((label|0) == 261) {
      label = 0;
      $1038 = HEAP32[$1004>>2]|0;
      $1039 = (__Z31ReadObjectFromPersistentManageri($1038)|0);
      $phitmp$i = ($1039|0)==(0|0);
      if ($phitmp$i) {
       label = 274;
       break;
      }
     }
     HEAPF32[$$byval_copy>>2] = Math_fround(-0.5);
     HEAPF32[$41>>2] = Math_fround(0.0);
     HEAPF32[$42>>2] = Math_fround(0.0);
     HEAPF32[$43>>2] = Math_fround(-0.5);
     HEAPF32[$44>>2] = Math_fround(1.0);
     HEAPF32[$45>>2] = Math_fround(0.0);
     HEAPF32[$46>>2] = Math_fround(0.5);
     HEAPF32[$47>>2] = Math_fround(1.0);
     HEAPF32[$48>>2] = Math_fround(0.0);
     HEAPF32[$49>>2] = Math_fround(0.5);
     HEAPF32[$50>>2] = Math_fround(0.0);
     HEAPF32[$51>>2] = Math_fround(0.0);
     HEAP32[$colors>>2] = 10526880;
     HEAP32[$52>>2] = -1;
     HEAP32[$53>>2] = -1;
     HEAP32[$54>>2] = 10526880;
     HEAPF32[$uvs>>2] = Math_fround(0.0);
     HEAPF32[$55>>2] = Math_fround(0.0);
     HEAPF32[$56>>2] = Math_fround(0.0);
     HEAPF32[$57>>2] = Math_fround(1.0);
     HEAPF32[$58>>2] = Math_fround(1.0);
     HEAPF32[$59>>2] = Math_fround(1.0);
     HEAPF32[$60>>2] = Math_fround(1.0);
     HEAPF32[$61>>2] = Math_fround(0.0);
     ;HEAP16[$triangles+0>>1]=HEAP16[799480+0>>1]|0;HEAP16[$triangles+2>>1]=HEAP16[799480+2>>1]|0;HEAP16[$triangles+4>>1]=HEAP16[799480+4>>1]|0;HEAP16[$triangles+6>>1]=HEAP16[799480+6>>1]|0;HEAP16[$triangles+8>>1]=HEAP16[799480+8>>1]|0;HEAP16[$triangles+10>>1]=HEAP16[799480+10>>1]|0;
     $1040 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
     __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($1040,$$byval_copy,$62);
     $1041 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
     __ZNSt3__16vectorI11ColorRGBA32NS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($1041,$colors,$63);
     $1042 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
     __ZNSt3__16vectorI8Vector2fNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($1042,$uvs,$64);
     $1043 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
     __ZNSt3__16vectorItNS_9allocatorItEEE6assignIPtEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleItNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($1043,$triangles,$65);
     $1044 = HEAP32[$1004>>2]|0;
     $1045 = ($1044|0)==(0);
     if ($1045) {
      $$0$i285 = 0;
     } else {
      HEAP32[$4>>2] = $1044;
      $1046 = HEAP32[560624>>2]|0;
      $1047 = ($1046|0)==(0|0);
      if ($1047) {
       label = 271;
      } else {
       $1048 = (($1046) + 36|0);
       $1049 = HEAP32[$1048>>2]|0;
       $1050 = (($1046) + 4|0);
       $1051 = HEAP32[$1050>>2]|0;
       $1052 = ($1049|0)==($1051|0);
       do {
        if ($1052) {
         $1053 = (($1046) + 28|0);
         $1054 = HEAP32[$1053>>2]|0;
         $1055 = (($1046) + 32|0);
         $1056 = HEAP32[$1055>>2]|0;
         $1057 = (($1054) + ($1056<<3)|0);
         $1073 = $1057;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$1046,$4);
         $1058 = HEAP32[$$byval_copy4>>2]|0;
         $1059 = ($1058|0)==(-1);
         $1060 = (($1046) + 28|0);
         $1061 = HEAP32[$1060>>2]|0;
         if ($1059) {
          $1062 = (($1046) + 32|0);
          $1063 = HEAP32[$1062>>2]|0;
          $1064 = (($1061) + ($1063<<3)|0);
          $1073 = $1064;
          break;
         } else {
          $1065 = (($1061) + ($1058<<3)|0);
          $1073 = $1065;
          break;
         }
        }
       } while(0);
       $1066 = HEAP32[560624>>2]|0;
       $1067 = (($1066) + 28|0);
       $1068 = HEAP32[$1067>>2]|0;
       $1069 = (($1066) + 32|0);
       $1070 = HEAP32[$1069>>2]|0;
       $1071 = (($1068) + ($1070<<3)|0);
       $1072 = ($1073|0)==($1071|0);
       if ($1072) {
        label = 271;
       } else {
        $1074 = (($1073) + 4|0);
        $1075 = HEAP32[$1074>>2]|0;
        $1076 = ($1075|0)==(0|0);
        if ($1076) {
         label = 271;
        } else {
         $temp$0$i284 = $1075;
        }
       }
      }
      if ((label|0) == 271) {
       label = 0;
       $1077 = HEAP32[$1004>>2]|0;
       $1078 = (__Z31ReadObjectFromPersistentManageri($1077)|0);
       $temp$0$i284 = $1078;
      }
      $$0$i285 = $temp$0$i284;
     }
     HEAP32[$85>>2] = $$0$i285;
    }
   }
  } while(0);
  L383: do {
   if ((label|0) == 274) {
    label = 0;
    $1079 = HEAP32[$86>>2]|0;
    $1080 = ($1079|0)==(0);
    do {
     if (!($1080)) {
      HEAP32[$5>>2] = $1079;
      $1081 = HEAP32[560624>>2]|0;
      $1082 = ($1081|0)==(0|0);
      if ($1082) {
       label = 283;
      } else {
       $1083 = (($1081) + 36|0);
       $1084 = HEAP32[$1083>>2]|0;
       $1085 = (($1081) + 4|0);
       $1086 = HEAP32[$1085>>2]|0;
       $1087 = ($1084|0)==($1086|0);
       do {
        if ($1087) {
         $1088 = (($1081) + 28|0);
         $1089 = HEAP32[$1088>>2]|0;
         $1090 = (($1081) + 32|0);
         $1091 = HEAP32[$1090>>2]|0;
         $1092 = (($1089) + ($1091<<3)|0);
         $1108 = $1092;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$1081,$5);
         $1093 = HEAP32[$$byval_copy4>>2]|0;
         $1094 = ($1093|0)==(-1);
         $1095 = (($1081) + 28|0);
         $1096 = HEAP32[$1095>>2]|0;
         if ($1094) {
          $1097 = (($1081) + 32|0);
          $1098 = HEAP32[$1097>>2]|0;
          $1099 = (($1096) + ($1098<<3)|0);
          $1108 = $1099;
          break;
         } else {
          $1100 = (($1096) + ($1093<<3)|0);
          $1108 = $1100;
          break;
         }
        }
       } while(0);
       $1101 = HEAP32[560624>>2]|0;
       $1102 = (($1101) + 28|0);
       $1103 = HEAP32[$1102>>2]|0;
       $1104 = (($1101) + 32|0);
       $1105 = HEAP32[$1104>>2]|0;
       $1106 = (($1103) + ($1105<<3)|0);
       $1107 = ($1108|0)==($1106|0);
       if ($1107) {
        label = 283;
       } else {
        $1109 = (($1108) + 4|0);
        $1110 = HEAP32[$1109>>2]|0;
        $1111 = ($1110|0)==(0|0);
        if ($1111) {
         label = 283;
        }
       }
      }
      if ((label|0) == 283) {
       label = 0;
       $1112 = HEAP32[$86>>2]|0;
       $1113 = (__Z31ReadObjectFromPersistentManageri($1112)|0);
       $1114 = ($1113|0)==(0|0);
       if ($1114) {
        break;
       }
      }
      $1115 = HEAP32[$86>>2]|0;
      HEAP32[$6>>2] = $1115;
      $1116 = HEAP32[560624>>2]|0;
      $1117 = ($1116|0)==(0|0);
      if ($1117) {
       label = 292;
      } else {
       $1118 = (($1116) + 36|0);
       $1119 = HEAP32[$1118>>2]|0;
       $1120 = (($1116) + 4|0);
       $1121 = HEAP32[$1120>>2]|0;
       $1122 = ($1119|0)==($1121|0);
       do {
        if ($1122) {
         $1123 = (($1116) + 28|0);
         $1124 = HEAP32[$1123>>2]|0;
         $1125 = (($1116) + 32|0);
         $1126 = HEAP32[$1125>>2]|0;
         $1127 = (($1124) + ($1126<<3)|0);
         $1143 = $1127;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy4,$1116,$6);
         $1128 = HEAP32[$$byval_copy4>>2]|0;
         $1129 = ($1128|0)==(-1);
         $1130 = (($1116) + 28|0);
         $1131 = HEAP32[$1130>>2]|0;
         if ($1129) {
          $1132 = (($1116) + 32|0);
          $1133 = HEAP32[$1132>>2]|0;
          $1134 = (($1131) + ($1133<<3)|0);
          $1143 = $1134;
          break;
         } else {
          $1135 = (($1131) + ($1128<<3)|0);
          $1143 = $1135;
          break;
         }
        }
       } while(0);
       $1136 = HEAP32[560624>>2]|0;
       $1137 = (($1136) + 28|0);
       $1138 = HEAP32[$1137>>2]|0;
       $1139 = (($1136) + 32|0);
       $1140 = HEAP32[$1139>>2]|0;
       $1141 = (($1138) + ($1140<<3)|0);
       $1142 = ($1143|0)==($1141|0);
       if ($1142) {
        label = 292;
       } else {
        $1144 = (($1143) + 4|0);
        $1145 = HEAP32[$1144>>2]|0;
        $1146 = ($1145|0)==(0|0);
        if ($1146) {
         label = 292;
        } else {
         $temp$0$i265 = $1145;
        }
       }
      }
      if ((label|0) == 292) {
       label = 0;
       $1147 = HEAP32[$86>>2]|0;
       $1148 = (__Z31ReadObjectFromPersistentManageri($1147)|0);
       $temp$0$i265 = $1148;
      }
      $1149 = HEAP32[$temp$0$i265>>2]|0;
      $1150 = (($1149) + 32|0);
      $1151 = HEAP32[$1150>>2]|0;
      $1152 = (FUNCTION_TABLE_ii[$1151 & 4095]($temp$0$i265)|0);
      __Z6AppendPKcS0_($35,799496,$1152);
      $1153 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
      $1154 = HEAP32[$1153>>2]|0;
      $1155 = ((($87) + (($i$0402*136)|0)|0) + 80|0);
      $1156 = HEAP32[$1155>>2]|0;
      $1157 = ($1156|0)==($1154|0);
      if (!($1157)) {
       $__new_last2$i$i$i$i229 = $1154;
       $scevgep$i$i$i$i230 = (($1156) + -12|0);
       $1158 = (0 - ($__new_last2$i$i$i$i229))|0;
       $uglygep$i$i$i$i232 = (($scevgep$i$i$i$i230) + ($1158)|0);
       $uglygep3$i$i$i$i233 = $uglygep$i$i$i$i232;
       $1159 = (($uglygep3$i$i$i$i233>>>0) / 12)&-1;
       $1160 = $1159 ^ -1;
       $scevgep4$i$i$i$i234 = (($1156) + (($1160*12)|0)|0);
       HEAP32[$1155>>2] = $scevgep4$i$i$i$i234;
      }
      $1161 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
      $1162 = HEAP32[$1161>>2]|0;
      $1163 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
      $1164 = HEAP32[$1163>>2]|0;
      $1165 = ($1164|0)==($1162|0);
      if (!($1165)) {
       $__new_last2$i$i$i11$i237 = $1162;
       $scevgep$i$i$i12$i238 = (($1164) + -8|0);
       $1166 = (0 - ($__new_last2$i$i$i11$i237))|0;
       $uglygep$i$i$i14$i240 = (($scevgep$i$i$i12$i238) + ($1166)|0);
       $uglygep3$i$i$i15$i241 = $uglygep$i$i$i14$i240;
       $1167 = $uglygep3$i$i$i15$i241 >>> 3;
       $1168 = $1167 ^ -1;
       $scevgep4$i$i$i16$i242 = (($1164) + ($1168<<3)|0);
       HEAP32[$1163>>2] = $scevgep4$i$i$i16$i242;
      }
      $1169 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
      $1170 = HEAP32[$1169>>2]|0;
      $1171 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
      $1172 = HEAP32[$1171>>2]|0;
      $1173 = ($1172|0)==($1170|0);
      if (!($1173)) {
       $__new_last1$i$i$i$i245 = $1170;
       $scevgep$i$i$i8$i246 = (($1172) + -4|0);
       $1174 = (0 - ($__new_last1$i$i$i$i245))|0;
       $scevgep2$i$i$i$i247 = (($scevgep$i$i$i8$i246) + ($1174)|0);
       $scevgep23$i$i$i$i248 = $scevgep2$i$i$i$i247;
       $1175 = $scevgep23$i$i$i$i248 >>> 2;
       $1176 = $1175 ^ -1;
       $scevgep4$i$i$i9$i249 = (($1172) + ($1176<<2)|0);
       HEAP32[$1171>>2] = $scevgep4$i$i$i9$i249;
      }
      $1177 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
      $1178 = HEAP32[$1177>>2]|0;
      $1179 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
      $1180 = HEAP32[$1179>>2]|0;
      $1181 = ($1180|0)==($1178|0);
      if (!($1181)) {
       $__new_last2$i$i$i1$i252 = $1178;
       $scevgep$i$i$i2$i253 = (($1180) + -2|0);
       $1182 = (0 - ($__new_last2$i$i$i1$i252))|0;
       $uglygep$i$i$i4$i255 = (($scevgep$i$i$i2$i253) + ($1182)|0);
       $uglygep3$i$i$i5$i256 = $uglygep$i$i$i4$i255;
       $1183 = $uglygep3$i$i$i5$i256 >>> 1;
       $1184 = $1183 ^ -1;
       $scevgep4$i$i$i6$i257 = (($1180) + ($1184<<1)|0);
       HEAP32[$1179>>2] = $scevgep4$i$i$i6$i257;
      }
      $1185 = HEAP8[$35>>0]|0;
      $1186 = $1185 & 1;
      $1187 = ($1186<<24>>24)==(0);
      if ($1187) {
       break L383;
      }
      $1188 = HEAP32[$66>>2]|0;
      __ZdlPv($1188);
      break L383;
     }
    } while(0);
    $1189 = ((($87) + (($i$0402*136)|0)|0) + 76|0);
    $1190 = HEAP32[$1189>>2]|0;
    $1191 = ((($87) + (($i$0402*136)|0)|0) + 80|0);
    $1192 = HEAP32[$1191>>2]|0;
    $1193 = ($1192|0)==($1190|0);
    if (!($1193)) {
     $__new_last2$i$i$i$i = $1190;
     $scevgep$i$i$i$i = (($1192) + -12|0);
     $1194 = (0 - ($__new_last2$i$i$i$i))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($1194)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $1195 = (($uglygep3$i$i$i$i>>>0) / 12)&-1;
     $1196 = $1195 ^ -1;
     $scevgep4$i$i$i$i = (($1192) + (($1196*12)|0)|0);
     HEAP32[$1191>>2] = $scevgep4$i$i$i$i;
    }
    $1197 = ((($87) + (($i$0402*136)|0)|0) + 100|0);
    $1198 = HEAP32[$1197>>2]|0;
    $1199 = ((($87) + (($i$0402*136)|0)|0) + 104|0);
    $1200 = HEAP32[$1199>>2]|0;
    $1201 = ($1200|0)==($1198|0);
    if (!($1201)) {
     $__new_last2$i$i$i11$i = $1198;
     $scevgep$i$i$i12$i = (($1200) + -8|0);
     $1202 = (0 - ($__new_last2$i$i$i11$i))|0;
     $uglygep$i$i$i14$i = (($scevgep$i$i$i12$i) + ($1202)|0);
     $uglygep3$i$i$i15$i = $uglygep$i$i$i14$i;
     $1203 = $uglygep3$i$i$i15$i >>> 3;
     $1204 = $1203 ^ -1;
     $scevgep4$i$i$i16$i = (($1200) + ($1204<<3)|0);
     HEAP32[$1199>>2] = $scevgep4$i$i$i16$i;
    }
    $1205 = ((($87) + (($i$0402*136)|0)|0) + 112|0);
    $1206 = HEAP32[$1205>>2]|0;
    $1207 = ((($87) + (($i$0402*136)|0)|0) + 116|0);
    $1208 = HEAP32[$1207>>2]|0;
    $1209 = ($1208|0)==($1206|0);
    if (!($1209)) {
     $__new_last1$i$i$i$i = $1206;
     $scevgep$i$i$i8$i = (($1208) + -4|0);
     $1210 = (0 - ($__new_last1$i$i$i$i))|0;
     $scevgep2$i$i$i$i = (($scevgep$i$i$i8$i) + ($1210)|0);
     $scevgep23$i$i$i$i = $scevgep2$i$i$i$i;
     $1211 = $scevgep23$i$i$i$i >>> 2;
     $1212 = $1211 ^ -1;
     $scevgep4$i$i$i9$i = (($1208) + ($1212<<2)|0);
     HEAP32[$1207>>2] = $scevgep4$i$i$i9$i;
    }
    $1213 = ((($87) + (($i$0402*136)|0)|0) + 124|0);
    $1214 = HEAP32[$1213>>2]|0;
    $1215 = ((($87) + (($i$0402*136)|0)|0) + 128|0);
    $1216 = HEAP32[$1215>>2]|0;
    $1217 = ($1216|0)==($1214|0);
    if (!($1217)) {
     $__new_last2$i$i$i1$i = $1214;
     $scevgep$i$i$i2$i = (($1216) + -2|0);
     $1218 = (0 - ($__new_last2$i$i$i1$i))|0;
     $uglygep$i$i$i4$i = (($scevgep$i$i$i2$i) + ($1218)|0);
     $uglygep3$i$i$i5$i = $uglygep$i$i$i4$i;
     $1219 = $uglygep3$i$i$i5$i >>> 1;
     $1220 = $1219 ^ -1;
     $scevgep4$i$i$i6$i = (($1216) + ($1220<<1)|0);
     HEAP32[$1215>>2] = $scevgep4$i$i$i6$i;
    }
   }
  } while(0);
  $1221 = (($i$0402) + 1)|0;
  $1222 = HEAP32[$36>>2]|0;
  $1223 = HEAP32[$38>>2]|0;
  $1224 = $1222;
  $1225 = $1223;
  $1226 = (($1224) - ($1225))|0;
  $1227 = (($1226|0) / 136)&-1;
  $1228 = ($1221>>>0)<($1227>>>0);
  if ($1228) {
   $87 = $1223;$i$0402 = $1221;
  } else {
   label = 312;
   break;
  }
 }
 if ((label|0) == 236) {
  $960 = ___cxa_find_matching_catch()|0;
  $961 = tempRet0;
  $962 = HEAP32[$tempBuffer>>2]|0;
  $963 = ($962|0)==(0|0);
  if ($963) {
   ___resumeException($960|0);
   // unreachable;
  }
  $964 = HEAP32[$79>>2]|0;
  $965 = ($964|0)==($962|0);
  if (!($965)) {
   $__new_last2$i$i$i$i$i304 = $962;
   $scevgep$i$i$i$i$i305 = (($964) + -4|0);
   $966 = (0 - ($__new_last2$i$i$i$i$i304))|0;
   $uglygep$i$i$i$i$i307 = (($scevgep$i$i$i$i$i305) + ($966)|0);
   $uglygep3$i$i$i$i$i308 = $uglygep$i$i$i$i$i307;
   $967 = $uglygep3$i$i$i$i$i308 >>> 2;
   $968 = $967 ^ -1;
   $scevgep4$i$i$i$i$i309 = (($964) + ($968<<2)|0);
   HEAP32[$79>>2] = $scevgep4$i$i$i$i$i309;
  }
  HEAP32[$$byval_copy>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
  invoke_vii(2591,($962|0),($$byval_copy4|0));
  $969 = __THREW__; __THREW__ = 0;
  $970 = $969&1;
  if ($970) {
   $971 = ___cxa_find_matching_catch()|0;
   $972 = tempRet0;
   ___cxa_call_unexpected(($971|0));
   // unreachable;
  } else {
   ___resumeException($960|0);
   // unreachable;
  }
 }
 else if ((label|0) == 250) {
  $1002 = ___cxa_find_matching_catch()|0;
  $1003 = tempRet0;
  ___cxa_call_unexpected(($1002|0));
  // unreachable;
 }
 else if ((label|0) == 312) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE6assignI14StrideIteratorIS1_EEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i20 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$pr = 0, $$pre$i = 0, $$pre$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $8 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = (($__first) + 4|0);
 $2 = HEAP32[$__last>>2]|0;
 $3 = (($__last) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $0;
 $7 = (($5) - ($6))|0;
 $8 = (($7>>>0) / ($4>>>0))&-1;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = (($14|0) / 12)&-1;
 $16 = ($8>>>0)>($15>>>0);
 if ($16) {
  $47 = ($11|0)==(0|0);
  if ($47) {
   $56 = $10;
  } else {
   $48 = (($this) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==($11|0);
   if (!($50)) {
    $scevgep$i$i$i$i = (($49) + -12|0);
    $51 = (0 - ($13))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($51)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $52 = (($uglygep3$i$i$i$i>>>0) / 12)&-1;
    $53 = $52 ^ -1;
    $scevgep4$i$i$i$i = (($49) + (($53*12)|0)|0);
    HEAP32[$48>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($11);
   HEAP32[$9>>2] = 0;
   HEAP32[$48>>2] = 0;
   HEAP32[$this>>2] = 0;
   $56 = 0;
  }
  $54 = ($8>>>0)>(357913941);
  if ($54) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $55 = $56;
  $57 = (($55|0) / 12)&-1;
  $58 = ($57>>>0)<(178956970);
  if ($58) {
   $59 = $57 << 1;
   $60 = ($59>>>0)<($8>>>0);
   $61 = $60 ? $8 : $59;
   $62 = ($61>>>0)>(357913941);
   if ($62) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i20 = $61;
   }
  } else {
   $$0$i20 = 357913941;
  }
  $63 = ($$0$i20*12)|0;
  $64 = (__Znwj($63)|0);
  $65 = (($this) + 4|0);
  HEAP32[$65>>2] = $64;
  HEAP32[$this>>2] = $64;
  $66 = (($64) + (($$0$i20*12)|0)|0);
  HEAP32[$9>>2] = $66;
  $67 = HEAP32[$__first>>2]|0;
  $68 = HEAP32[$1>>2]|0;
  $69 = HEAP32[$__last>>2]|0;
  $70 = ($67|0)==($69|0);
  if ($70) {
   STACKTOP = sp;return;
  } else {
   $72 = $64;$73 = $67;
  }
  while(1) {
   $71 = ($72|0)==(0|0);
   if ($71) {
    $75 = 0;
   } else {
    ;HEAP32[$72+0>>2]=HEAP32[$73+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$73+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$73+8>>2]|0;
    $$pre$i = HEAP32[$65>>2]|0;
    $75 = $$pre$i;
   }
   $74 = (($75) + 12|0);
   HEAP32[$65>>2] = $74;
   $76 = (($73) + ($68)|0);
   $77 = ($76|0)==($69|0);
   if ($77) {
    break;
   } else {
    $72 = $74;$73 = $76;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18;
 $20 = (($19) - ($13))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = ($8>>>0)>($21>>>0);
 $23 = HEAP32[$1>>2]|0;
 if ($22) {
  $24 = Math_imul($23, $21)|0;
  $25 = (($0) + ($24)|0);
  $27 = $25;$40 = $23;$__growing$0$off0 = 1;
 } else {
  $27 = $2;$40 = $4;$__growing$0$off0 = 0;
 }
 $26 = ($0|0)==($27|0);
 if ($26) {
  $$0$lcssa$i$i = $11;
 } else {
  $$01$i$i = $11;$28 = $0;
  while(1) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$28+8>>2]|0;
   $29 = (($28) + ($23)|0);
   $30 = (($$01$i$i) + 12|0);
   $31 = ($29|0)==($27|0);
   if ($31) {
    $$0$lcssa$i$i = $30;
    break;
   } else {
    $$01$i$i = $30;$28 = $29;
   }
  }
 }
 if (!($__growing$0$off0)) {
  $42 = HEAP32[$17>>2]|0;
  $43 = ($42|0)==($$0$lcssa$i$i|0);
  if ($43) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($42) + -12|0);
  $44 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($44)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $45 = (($uglygep3$i$i>>>0) / 12)&-1;
  $46 = $45 ^ -1;
  $scevgep4$i$i = (($42) + (($46*12)|0)|0);
  HEAP32[$17>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $32 = HEAP32[$__last>>2]|0;
 $33 = ($27|0)==($32|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $$pr = HEAP32[$17>>2]|0;
 $35 = $$pr;$36 = $27;
 while(1) {
  $34 = ($35|0)==(0|0);
  if ($34) {
   $38 = 0;
  } else {
   ;HEAP32[$35+0>>2]=HEAP32[$36+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$36+8>>2]|0;
   $$pre$i2 = HEAP32[$17>>2]|0;
   $38 = $$pre$i2;
  }
  $37 = (($38) + 12|0);
  HEAP32[$17>>2] = $37;
  $39 = (($36) + ($40)|0);
  $41 = ($39|0)==($32|0);
  if ($41) {
   break;
  } else {
   $35 = $37;$36 = $39;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8Vector2fNS_9allocatorIS1_EEE6assignI14StrideIteratorIS1_EEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i20 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$pr = 0, $$pre$i = 0, $$pre$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0;
 var $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = (($__first) + 4|0);
 $2 = HEAP32[$__last>>2]|0;
 $3 = (($__last) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $0;
 $7 = (($5) - ($6))|0;
 $8 = (($7>>>0) / ($4>>>0))&-1;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = $10;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = $14 >> 3;
 $16 = ($8>>>0)>($15>>>0);
 if ($16) {
  $67 = ($11|0)==(0|0);
  if ($67) {
   $76 = $10;
  } else {
   $68 = (($this) + 4|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($69|0)==($11|0);
   if (!($70)) {
    $scevgep$i$i$i$i = (($69) + -8|0);
    $71 = (0 - ($13))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($71)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $72 = $uglygep3$i$i$i$i >>> 3;
    $73 = $72 ^ -1;
    $scevgep4$i$i$i$i = (($69) + ($73<<3)|0);
    HEAP32[$68>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($11);
   HEAP32[$9>>2] = 0;
   HEAP32[$68>>2] = 0;
   HEAP32[$this>>2] = 0;
   $76 = 0;
  }
  $74 = ($8>>>0)>(536870911);
  if ($74) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $75 = $76;
  $77 = $75 >> 3;
  $78 = ($77>>>0)<(268435455);
  if ($78) {
   $79 = $75 >> 2;
   $80 = ($79>>>0)<($8>>>0);
   $81 = $80 ? $8 : $79;
   $82 = ($81>>>0)>(536870911);
   if ($82) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i20 = $81;
   }
  } else {
   $$0$i20 = 536870911;
  }
  $83 = $$0$i20 << 3;
  $84 = (__Znwj($83)|0);
  $85 = (($this) + 4|0);
  HEAP32[$85>>2] = $84;
  HEAP32[$this>>2] = $84;
  $86 = (($84) + ($$0$i20<<3)|0);
  HEAP32[$9>>2] = $86;
  $87 = HEAP32[$__first>>2]|0;
  $88 = HEAP32[$1>>2]|0;
  $89 = HEAP32[$__last>>2]|0;
  $90 = ($87|0)==($89|0);
  if ($90) {
   STACKTOP = sp;return;
  } else {
   $92 = $84;$94 = $87;
  }
  while(1) {
   $91 = ($92|0)==(0|0);
   if ($91) {
    $105 = 0;
   } else {
    $93 = $94;
    $95 = $93;
    $96 = HEAP32[$95>>2]|0;
    $97 = (($93) + 4)|0;
    $98 = $97;
    $99 = HEAP32[$98>>2]|0;
    $100 = $92;
    $101 = $100;
    HEAP32[$101>>2] = $96;
    $102 = (($100) + 4)|0;
    $103 = $102;
    HEAP32[$103>>2] = $99;
    $$pre$i = HEAP32[$85>>2]|0;
    $105 = $$pre$i;
   }
   $104 = (($105) + 8|0);
   HEAP32[$85>>2] = $104;
   $106 = (($94) + ($88)|0);
   $107 = ($106|0)==($89|0);
   if ($107) {
    break;
   } else {
    $92 = $104;$94 = $106;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = (($this) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18;
 $20 = (($19) - ($13))|0;
 $21 = $20 >> 3;
 $22 = ($8>>>0)>($21>>>0);
 $23 = HEAP32[$1>>2]|0;
 if ($22) {
  $24 = Math_imul($23, $21)|0;
  $25 = (($0) + ($24)|0);
  $27 = $25;$60 = $23;$__growing$0$off0 = 1;
 } else {
  $27 = $2;$60 = $4;$__growing$0$off0 = 0;
 }
 $26 = ($0|0)==($27|0);
 if ($26) {
  $$0$lcssa$i$i = $11;
 } else {
  $$01$i$i = $11;$29 = $0;
  while(1) {
   $28 = $29;
   $30 = $28;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($28) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = $$01$i$i;
   $36 = $35;
   HEAP32[$36>>2] = $31;
   $37 = (($35) + 4)|0;
   $38 = $37;
   HEAP32[$38>>2] = $34;
   $39 = (($29) + ($23)|0);
   $40 = (($$01$i$i) + 8|0);
   $41 = ($39|0)==($27|0);
   if ($41) {
    $$0$lcssa$i$i = $40;
    break;
   } else {
    $$01$i$i = $40;$29 = $39;
   }
  }
 }
 if (!($__growing$0$off0)) {
  $62 = HEAP32[$17>>2]|0;
  $63 = ($62|0)==($$0$lcssa$i$i|0);
  if ($63) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($62) + -8|0);
  $64 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($64)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $65 = $uglygep3$i$i >>> 3;
  $66 = $65 ^ -1;
  $scevgep4$i$i = (($62) + ($66<<3)|0);
  HEAP32[$17>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $42 = HEAP32[$__last>>2]|0;
 $43 = ($27|0)==($42|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 $$pr = HEAP32[$17>>2]|0;
 $45 = $$pr;$47 = $27;
 while(1) {
  $44 = ($45|0)==(0|0);
  if ($44) {
   $58 = 0;
  } else {
   $46 = $47;
   $48 = $46;
   $49 = HEAP32[$48>>2]|0;
   $50 = (($46) + 4)|0;
   $51 = $50;
   $52 = HEAP32[$51>>2]|0;
   $53 = $45;
   $54 = $53;
   HEAP32[$54>>2] = $49;
   $55 = (($53) + 4)|0;
   $56 = $55;
   HEAP32[$56>>2] = $52;
   $$pre$i2 = HEAP32[$17>>2]|0;
   $58 = $$pre$i2;
  }
  $57 = (($58) + 8|0);
  HEAP32[$17>>2] = $57;
  $59 = (($47) + ($60)|0);
  $61 = ($59|0)==($42|0);
  if ($61) {
   break;
  } else {
   $45 = $57;$47 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorItNS_9allocatorItEEE6assignINS_11__wrap_iterIPjEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleItNS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i41 = 0, $$0$lcssa$i$i = 0, $$012$i$i = 0, $$03$i$i = 0, $$promoted15$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $8 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i24 = 0, $scevgep$i10 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep7$i$i = 0, $scevgep8$i = 0, $scevgep8$i17 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i26 = 0, $uglygep$i12 = 0;
 var $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep6$i = 0, $uglygep6$i$i = 0, $uglygep6$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = HEAP32[$__last>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 1;
 $13 = ($5>>>0)>($12>>>0);
 if ($13) {
  $47 = ($8|0)==(0|0);
  if ($47) {
   $56 = $7;
  } else {
   $48 = (($this) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==($8|0);
   if (!($50)) {
    $scevgep$i$i$i$i = (($49) + -2|0);
    $51 = (0 - ($10))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($51)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $52 = $uglygep3$i$i$i$i >>> 1;
    $53 = $52 ^ -1;
    $scevgep4$i$i$i$i = (($49) + ($53<<1)|0);
    HEAP32[$48>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($8);
   HEAP32[$6>>2] = 0;
   HEAP32[$48>>2] = 0;
   HEAP32[$this>>2] = 0;
   $56 = 0;
  }
  $54 = ($4|0)<(0);
  if ($54) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $55 = $56;
  $57 = $55 >> 1;
  $58 = ($57>>>0)<(1073741823);
  if ($58) {
   $59 = ($55>>>0)<($5>>>0);
   $60 = $59 ? $5 : $55;
   $61 = ($60|0)<(0);
   if ($61) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i41 = $60;
   }
  } else {
   $$0$i41 = 2147483647;
  }
  $62 = $$0$i41 << 1;
  $63 = (__Znwj($62)|0);
  $64 = (($this) + 4|0);
  HEAP32[$64>>2] = $63;
  HEAP32[$this>>2] = $63;
  $65 = (($63) + ($$0$i41<<1)|0);
  HEAP32[$6>>2] = $65;
  $66 = ($0|0)==($1|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($1) + -4|0);
  $67 = (0 - ($3))|0;
  $uglygep$i = (($scevgep$i) + ($67)|0);
  $uglygep6$i = $uglygep$i;
  $68 = $uglygep6$i >>> 2;
  $70 = $63;$72 = $0;
  while(1) {
   $69 = ($70|0)==(0|0);
   if (!($69)) {
    $71 = HEAP32[$72>>2]|0;
    $73 = $71&65535;
    HEAP16[$70>>1] = $73;
   }
   $74 = (($70) + 2|0);
   $75 = (($72) + 4|0);
   $76 = ($75|0)==($1|0);
   if ($76) {
    break;
   } else {
    $70 = $74;$72 = $75;
   }
  }
  $77 = (($68) + 1)|0;
  $scevgep8$i = (($63) + ($77<<1)|0);
  HEAP32[$64>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 }
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = (($16) - ($10))|0;
 $18 = $17 >> 1;
 $19 = ($5>>>0)>($18>>>0);
 if ($19) {
  $20 = (($0) + ($18<<2)|0);
  $22 = $20;$__growing$0$off0 = 1;
 } else {
  $22 = $1;$__growing$0$off0 = 0;
 }
 $21 = ($0|0)==($22|0);
 if ($21) {
  $$0$lcssa$i$i = $8;
 } else {
  $scevgep$i$i24 = (($22) + -4|0);
  $23 = (0 - ($3))|0;
  $uglygep$i$i26 = (($scevgep$i$i24) + ($23)|0);
  $uglygep6$i$i = $uglygep$i$i26;
  $$012$i$i = $0;$$03$i$i = $8;
  while(1) {
   $24 = HEAP32[$$012$i$i>>2]|0;
   $25 = $24&65535;
   HEAP16[$$03$i$i>>1] = $25;
   $26 = (($$012$i$i) + 4|0);
   $27 = (($$03$i$i) + 2|0);
   $28 = ($26|0)==($22|0);
   if ($28) {
    break;
   } else {
    $$012$i$i = $26;$$03$i$i = $27;
   }
  }
  $29 = $uglygep6$i$i >>> 2;
  $30 = (($29) + 1)|0;
  $scevgep7$i$i = (($8) + ($30<<1)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if (!($__growing$0$off0)) {
  $43 = ($15|0)==($$0$lcssa$i$i|0);
  if ($43) {
   STACKTOP = sp;return;
  }
  $__new_last2$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($15) + -2|0);
  $44 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($44)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $45 = $uglygep3$i$i >>> 1;
  $46 = $45 ^ -1;
  $scevgep4$i$i = (($15) + ($46<<1)|0);
  HEAP32[$14>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $31 = ($22|0)==($1|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $$promoted15$i9 = $22;
 $scevgep$i10 = (($1) + -4|0);
 $32 = (0 - ($$promoted15$i9))|0;
 $uglygep$i12 = (($scevgep$i10) + ($32)|0);
 $uglygep6$i13 = $uglygep$i12;
 $33 = $uglygep6$i13 >>> 2;
 $35 = $15;$37 = $22;
 while(1) {
  $34 = ($35|0)==(0|0);
  if (!($34)) {
   $36 = HEAP32[$37>>2]|0;
   $38 = $36&65535;
   HEAP16[$35>>1] = $38;
  }
  $39 = (($35) + 2|0);
  $40 = (($37) + 4|0);
  $41 = ($40|0)==($1|0);
  if ($41) {
   break;
  } else {
   $35 = $39;$37 = $40;
  }
 }
 $42 = (($33) + 1)|0;
 $scevgep8$i17 = (($15) + ($42<<1)|0);
 HEAP32[$14>>2] = $scevgep8$i17;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 12)&-1;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = (($15|0) / 12)&-1;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $26 = $__last;
   $27 = (($26) - ($1))|0;
   $28 = (($27|0) / 12)&-1;
   _memmove(($6|0),($__first|0),($27|0))|0;
   $29 = (($6) + (($28*12)|0)|0);
   $30 = HEAP32[$12>>2]|0;
   $31 = ($30|0)==($29|0);
   if ($31) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $29;
   $scevgep$i$i = (($30) + -12|0);
   $32 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($32)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $33 = (($uglygep3$i$i>>>0) / 12)&-1;
   $34 = $33 ^ -1;
   $scevgep4$i$i = (($30) + (($34*12)|0)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + (($16*12)|0)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$12>>2]|0;
  $$01$i3 = $18;$21 = $$pre$i1;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $23 = 0;
   } else {
    ;HEAP32[$21+0>>2]=HEAP32[$$01$i3+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$$01$i3+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$$01$i3+8>>2]|0;
    $$pre2$i4 = HEAP32[$12>>2]|0;
    $23 = $$pre2$i4;
   }
   $22 = (($23) + 12|0);
   HEAP32[$12>>2] = $22;
   $24 = (($$01$i3) + 12|0);
   $25 = ($24|0)==($__last|0);
   if ($25) {
    break;
   } else {
    $$01$i3 = $24;$21 = $22;
   }
  }
  STACKTOP = sp;return;
 }
 $35 = ($6|0)==(0|0);
 if ($35) {
  $44 = $5;
 } else {
  $36 = (($this) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==($6|0);
  if (!($38)) {
   $scevgep$i$i$i$i = (($37) + -12|0);
   $39 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($39)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $40 = (($uglygep3$i$i$i$i>>>0) / 12)&-1;
   $41 = $40 ^ -1;
   $scevgep4$i$i$i$i = (($37) + (($41*12)|0)|0);
   HEAP32[$36>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$36>>2] = 0;
  HEAP32[$this>>2] = 0;
  $44 = 0;
 }
 $42 = ($3>>>0)>(357913941);
 if ($42) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $43 = $44;
 $45 = (($43|0) / 12)&-1;
 $46 = ($45>>>0)<(178956970);
 if ($46) {
  $47 = $45 << 1;
  $48 = ($47>>>0)<($3>>>0);
  $49 = $48 ? $3 : $47;
  $50 = ($49>>>0)>(357913941);
  if ($50) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $49;
  }
 } else {
  $$0$i7 = 357913941;
 }
 $51 = ($$0$i7*12)|0;
 $52 = (__Znwj($51)|0);
 $53 = (($this) + 4|0);
 HEAP32[$53>>2] = $52;
 HEAP32[$this>>2] = $52;
 $54 = (($52) + (($$0$i7*12)|0)|0);
 HEAP32[$4>>2] = $54;
 $55 = ($__first|0)==($__last|0);
 if ($55) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$57 = $52;
 }
 while(1) {
  $56 = ($57|0)==(0|0);
  if ($56) {
   $59 = 0;
  } else {
   ;HEAP32[$57+0>>2]=HEAP32[$$01$i+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$$01$i+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$$01$i+8>>2]|0;
   $$pre2$i = HEAP32[$53>>2]|0;
   $59 = $$pre2$i;
  }
  $58 = (($59) + 12|0);
  HEAP32[$53>>2] = $58;
  $60 = (($$01$i) + 12|0);
  $61 = ($60|0)==($__last|0);
  if ($61) {
   break;
  } else {
   $$01$i = $60;$57 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI11ColorRGBA32NS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i9 = 0, $$0$lcssa$i$i = 0, $$01$i = 0, $$01$i3 = 0, $$012$i$i = 0, $$03$i$i = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last1$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0;
 var $scevgep$i$i7 = 0, $scevgep2$i$i = 0, $scevgep2$i$i$i$i = 0, $scevgep23$i$i = 0, $scevgep23$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep5$i$i = 0, $scevgep56$i$i = 0, $scevgep7$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($3>>>0)>($10>>>0);
 if ($11) {
  $40 = ($6|0)==(0|0);
  if ($40) {
   $49 = $5;
  } else {
   $41 = (($this) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==($6|0);
   if (!($43)) {
    $scevgep$i$i$i$i = (($42) + -4|0);
    $44 = (0 - ($8))|0;
    $scevgep2$i$i$i$i = (($scevgep$i$i$i$i) + ($44)|0);
    $scevgep23$i$i$i$i = $scevgep2$i$i$i$i;
    $45 = $scevgep23$i$i$i$i >>> 2;
    $46 = $45 ^ -1;
    $scevgep4$i$i$i$i = (($42) + ($46<<2)|0);
    HEAP32[$41>>2] = $scevgep4$i$i$i$i;
   }
   __ZdlPv($6);
   HEAP32[$4>>2] = 0;
   HEAP32[$41>>2] = 0;
   HEAP32[$this>>2] = 0;
   $49 = 0;
  }
  $47 = ($3>>>0)>(1073741823);
  if ($47) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $48 = $49;
  $50 = $48 >> 2;
  $51 = ($50>>>0)<(536870911);
  if ($51) {
   $52 = $48 >> 1;
   $53 = ($52>>>0)<($3>>>0);
   $54 = $53 ? $3 : $52;
   $55 = ($54>>>0)>(1073741823);
   if ($55) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i9 = $54;
   }
  } else {
   $$0$i9 = 1073741823;
  }
  $56 = $$0$i9 << 2;
  $57 = (__Znwj($56)|0);
  $58 = (($this) + 4|0);
  HEAP32[$58>>2] = $57;
  HEAP32[$this>>2] = $57;
  $59 = (($57) + ($$0$i9<<2)|0);
  HEAP32[$4>>2] = $59;
  $60 = ($__first|0)==($__last|0);
  if ($60) {
   STACKTOP = sp;return;
  } else {
   $$01$i = $__first;$62 = $57;
  }
  while(1) {
   $61 = ($62|0)==(0|0);
   if ($61) {
    $65 = 0;
   } else {
    $63 = HEAP32[$$01$i>>2]|0;
    HEAP32[$62>>2] = $63;
    $$pre2$i = HEAP32[$58>>2]|0;
    $65 = $$pre2$i;
   }
   $64 = (($65) + 4|0);
   HEAP32[$58>>2] = $64;
   $66 = (($$01$i) + 4|0);
   $67 = ($66|0)==($__last|0);
   if ($67) {
    break;
   } else {
    $$01$i = $66;$62 = $64;
   }
  }
  STACKTOP = sp;return;
 }
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($8))|0;
 $16 = $15 >> 2;
 $17 = ($3>>>0)>($16>>>0);
 if ($17) {
  $18 = (($__first) + ($16<<2)|0);
  $20 = $18;$__growing$0$off0 = 1;
 } else {
  $20 = $__last;$__growing$0$off0 = 0;
 }
 $19 = ($20|0)==($__first|0);
 if ($19) {
  $$0$lcssa$i$i = $6;
 } else {
  $scevgep$i$i7 = (($20) + -4|0);
  $21 = (0 - ($1))|0;
  $scevgep5$i$i = (($scevgep$i$i7) + ($21)|0);
  $scevgep56$i$i = $scevgep5$i$i;
  $$012$i$i = $__first;$$03$i$i = $6;
  while(1) {
   $22 = HEAP32[$$012$i$i>>2]|0;
   HEAP32[$$03$i$i>>2] = $22;
   $23 = (($$012$i$i) + 4|0);
   $24 = (($$03$i$i) + 4|0);
   $25 = ($23|0)==($20|0);
   if ($25) {
    break;
   } else {
    $$012$i$i = $23;$$03$i$i = $24;
   }
  }
  $26 = $scevgep56$i$i >>> 2;
  $27 = (($26) + 1)|0;
  $scevgep7$i$i = (($6) + ($27<<2)|0);
  $$0$lcssa$i$i = $scevgep7$i$i;
 }
 if (!($__growing$0$off0)) {
  $36 = ($13|0)==($$0$lcssa$i$i|0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $__new_last1$i$i = $$0$lcssa$i$i;
  $scevgep$i$i = (($13) + -4|0);
  $37 = (0 - ($__new_last1$i$i))|0;
  $scevgep2$i$i = (($scevgep$i$i) + ($37)|0);
  $scevgep23$i$i = $scevgep2$i$i;
  $38 = $scevgep23$i$i >>> 2;
  $39 = $38 ^ -1;
  $scevgep4$i$i = (($13) + ($39<<2)|0);
  HEAP32[$12>>2] = $scevgep4$i$i;
  STACKTOP = sp;return;
 }
 $28 = ($20|0)==($__last|0);
 if ($28) {
  STACKTOP = sp;return;
 } else {
  $$01$i3 = $20;$30 = $13;
 }
 while(1) {
  $29 = ($30|0)==(0|0);
  if ($29) {
   $33 = 0;
  } else {
   $31 = HEAP32[$$01$i3>>2]|0;
   HEAP32[$30>>2] = $31;
   $$pre2$i4 = HEAP32[$12>>2]|0;
   $33 = $$pre2$i4;
  }
  $32 = (($33) + 4|0);
  HEAP32[$12>>2] = $32;
  $34 = (($$01$i3) + 4|0);
  $35 = ($34|0)==($__last|0);
  if ($35) {
   break;
  } else {
   $$01$i3 = $34;$30 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8Vector2fNS_9allocatorIS1_EEE6assignIPS1_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i7 = 0, $$01$i = 0, $$01$i3 = 0, $$pre$i1 = 0, $$pre2$i = 0, $$pre2$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 3;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = $15 >> 3;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $36 = $__last;
   $37 = (($36) - ($1))|0;
   $38 = $37 >> 3;
   _memmove(($6|0),($__first|0),($37|0))|0;
   $39 = (($6) + ($38<<3)|0);
   $40 = HEAP32[$12>>2]|0;
   $41 = ($40|0)==($39|0);
   if ($41) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $39;
   $scevgep$i$i = (($40) + -8|0);
   $42 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($42)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $43 = $uglygep3$i$i >>> 3;
   $44 = $43 ^ -1;
   $scevgep4$i$i = (($40) + ($44<<3)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + ($16<<3)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i1 = HEAP32[$12>>2]|0;
  $$01$i3 = $18;$21 = $$pre$i1;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $33 = 0;
   } else {
    $22 = $$01$i3;
    $23 = $22;
    $24 = HEAP32[$23>>2]|0;
    $25 = (($22) + 4)|0;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = $21;
    $29 = $28;
    HEAP32[$29>>2] = $24;
    $30 = (($28) + 4)|0;
    $31 = $30;
    HEAP32[$31>>2] = $27;
    $$pre2$i4 = HEAP32[$12>>2]|0;
    $33 = $$pre2$i4;
   }
   $32 = (($33) + 8|0);
   HEAP32[$12>>2] = $32;
   $34 = (($$01$i3) + 8|0);
   $35 = ($34|0)==($__last|0);
   if ($35) {
    break;
   } else {
    $$01$i3 = $34;$21 = $32;
   }
  }
  STACKTOP = sp;return;
 }
 $45 = ($6|0)==(0|0);
 if ($45) {
  $54 = $5;
 } else {
  $46 = (($this) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==($6|0);
  if (!($48)) {
   $scevgep$i$i$i$i = (($47) + -8|0);
   $49 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($49)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $50 = $uglygep3$i$i$i$i >>> 3;
   $51 = $50 ^ -1;
   $scevgep4$i$i$i$i = (($47) + ($51<<3)|0);
   HEAP32[$46>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$46>>2] = 0;
  HEAP32[$this>>2] = 0;
  $54 = 0;
 }
 $52 = ($3>>>0)>(536870911);
 if ($52) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $53 = $54;
 $55 = $53 >> 3;
 $56 = ($55>>>0)<(268435455);
 if ($56) {
  $57 = $53 >> 2;
  $58 = ($57>>>0)<($3>>>0);
  $59 = $58 ? $3 : $57;
  $60 = ($59>>>0)>(536870911);
  if ($60) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i7 = $59;
  }
 } else {
  $$0$i7 = 536870911;
 }
 $61 = $$0$i7 << 3;
 $62 = (__Znwj($61)|0);
 $63 = (($this) + 4|0);
 HEAP32[$63>>2] = $62;
 HEAP32[$this>>2] = $62;
 $64 = (($62) + ($$0$i7<<3)|0);
 HEAP32[$4>>2] = $64;
 $65 = ($__first|0)==($__last|0);
 if ($65) {
  STACKTOP = sp;return;
 } else {
  $$01$i = $__first;$67 = $62;
 }
 while(1) {
  $66 = ($67|0)==(0|0);
  if ($66) {
   $79 = 0;
  } else {
   $68 = $$01$i;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $67;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   $$pre2$i = HEAP32[$63>>2]|0;
   $79 = $$pre2$i;
  }
  $78 = (($79) + 8|0);
  HEAP32[$63>>2] = $78;
  $80 = (($$01$i) + 8|0);
  $81 = ($80|0)==($__last|0);
  if ($81) {
   break;
  } else {
   $$01$i = $80;$67 = $78;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorItNS_9allocatorItEEE6assignIPtEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleItNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i13 = 0, $$01$i = 0, $$01$i8 = 0, $$promoted$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i3 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep5$i = 0;
 var $scevgep5$i10 = 0, $uglygep$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i5 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep4$i = 0, $uglygep4$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 1;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 1;
 $11 = ($3>>>0)>($10>>>0);
 if (!($11)) {
  $12 = (($this) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13;
  $15 = (($14) - ($8))|0;
  $16 = $15 >> 1;
  $17 = ($3>>>0)>($16>>>0);
  if (!($17)) {
   $30 = $__last;
   $31 = (($30) - ($1))|0;
   $32 = $31 >> 1;
   _memmove(($6|0),($__first|0),($31|0))|0;
   $33 = (($6) + ($32<<1)|0);
   $34 = HEAP32[$12>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -2|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = $uglygep3$i$i >>> 1;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + ($38<<1)|0);
   HEAP32[$12>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $18 = (($__first) + ($16<<1)|0);
  _memmove(($6|0),($__first|0),($15|0))|0;
  $19 = ($18|0)==($__last|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $20 = $18;
  $$promoted$i2 = HEAP32[$12>>2]|0;
  $scevgep$i3 = (($__last) + -2|0);
  $21 = (0 - ($20))|0;
  $uglygep$i5 = (($scevgep$i3) + ($21)|0);
  $uglygep4$i6 = $uglygep$i5;
  $22 = $uglygep4$i6 >>> 1;
  $$01$i8 = $18;$24 = $$promoted$i2;
  while(1) {
   $23 = ($24|0)==(0|0);
   if (!($23)) {
    $25 = HEAP16[$$01$i8>>1]|0;
    HEAP16[$24>>1] = $25;
   }
   $26 = (($24) + 2|0);
   $27 = (($$01$i8) + 2|0);
   $28 = ($27|0)==($__last|0);
   if ($28) {
    break;
   } else {
    $$01$i8 = $27;$24 = $26;
   }
  }
  $29 = (($22) + 1)|0;
  $scevgep5$i10 = (($$promoted$i2) + ($29<<1)|0);
  HEAP32[$12>>2] = $scevgep5$i10;
  STACKTOP = sp;return;
 }
 $39 = ($6|0)==(0|0);
 if ($39) {
  $48 = $5;
 } else {
  $40 = (($this) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==($6|0);
  if (!($42)) {
   $scevgep$i$i$i$i = (($41) + -2|0);
   $43 = (0 - ($8))|0;
   $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
   $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
   $44 = $uglygep3$i$i$i$i >>> 1;
   $45 = $44 ^ -1;
   $scevgep4$i$i$i$i = (($41) + ($45<<1)|0);
   HEAP32[$40>>2] = $scevgep4$i$i$i$i;
  }
  __ZdlPv($6);
  HEAP32[$4>>2] = 0;
  HEAP32[$40>>2] = 0;
  HEAP32[$this>>2] = 0;
  $48 = 0;
 }
 $46 = ($2|0)<(0);
 if ($46) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $47 = $48;
 $49 = $47 >> 1;
 $50 = ($49>>>0)<(1073741823);
 if ($50) {
  $51 = ($47>>>0)<($3>>>0);
  $52 = $51 ? $3 : $47;
  $53 = ($52|0)<(0);
  if ($53) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i13 = $52;
  }
 } else {
  $$0$i13 = 2147483647;
 }
 $54 = $$0$i13 << 1;
 $55 = (__Znwj($54)|0);
 $56 = (($this) + 4|0);
 HEAP32[$56>>2] = $55;
 HEAP32[$this>>2] = $55;
 $57 = (($55) + ($$0$i13<<1)|0);
 HEAP32[$4>>2] = $57;
 $58 = ($__first|0)==($__last|0);
 if ($58) {
  STACKTOP = sp;return;
 }
 $scevgep$i = (($__last) + -2|0);
 $59 = (0 - ($1))|0;
 $uglygep$i = (($scevgep$i) + ($59)|0);
 $uglygep4$i = $uglygep$i;
 $60 = $uglygep4$i >>> 1;
 $$01$i = $__first;$62 = $55;
 while(1) {
  $61 = ($62|0)==(0|0);
  if (!($61)) {
   $63 = HEAP16[$$01$i>>1]|0;
   HEAP16[$62>>1] = $63;
  }
  $64 = (($62) + 2|0);
  $65 = (($$01$i) + 2|0);
  $66 = ($65|0)==($__last|0);
  if ($66) {
   break;
  } else {
   $$01$i = $65;$62 = $64;
  }
 }
 $67 = (($60) + 1)|0;
 $scevgep5$i = (($55) + ($67<<1)|0);
 HEAP32[$56>>2] = $scevgep5$i;
 STACKTOP = sp;return;
}
function __ZN14DetailDatabase9BuildMeshEii8Vector3f16DetailRenderModef($this,$patchX,$patchY,$size,$renderMode,$density) {
 $this = $this|0;
 $patchX = $patchX|0;
 $patchY = $patchY|0;
 $size = $size|0;
 $renderMode = $renderMode|0;
 $density = Math_fround($density);
 var $$0 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $totalTriangleCount = 0, $totalVertexCount = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $totalTriangleCount = sp;
 $totalVertexCount = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_imul($3, $patchY)|0;
 $5 = (($4) + ($patchX))|0;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + (($5*52)|0)|0);
 __ZN14DetailDatabase29ComputeVertexAndTriangleCountER11DetailPatch16DetailRenderModefPiS3_($this,$8,$renderMode,$density,$totalVertexCount,$totalTriangleCount);
 $9 = HEAP32[$totalTriangleCount>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$totalVertexCount>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $13;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $14 = (__Znwj10MemLabelIdbiPKci(280,$$byval_copy2,1,16,799248,794)|0);
 $15 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $15;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1698,($14|0),($$byval_copy2|0),0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  $18 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($14)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 24|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_vi[$21 & 4095]($18);
  $22 = HEAP32[$18>>2]|0;
  $23 = (($22) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vii[$24 & 4095]($18,4);
  $25 = HEAP32[$18>>2]|0;
  $26 = (($25) + 44|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vii[$27 & 4095]($18,61);
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$size+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$size+4>>2]|0;HEAP32[$$byval_copy2+8>>2]=HEAP32[$size+8>>2]|0;
  __ZN14DetailDatabase12GenerateMeshER4Meshii8Vector3f16DetailRenderModefii($this,$18,$patchX,$patchY,$$byval_copy2,$renderMode,$density,$11,$9);
  $$0 = $18;
  STACKTOP = sp;return ($$0|0);
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($14|0),($$byval_copy2|0),1,16,(799248|0),794);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $32 = ___cxa_find_matching_catch(0|0)|0;
  $33 = tempRet0;
  ___clang_call_terminate($32);
  // unreachable;
 } else {
  ___resumeException($28|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN14DetailDatabase29ComputeVertexAndTriangleCountER11DetailPatch16DetailRenderModefPiS3_($this,$patch,$renderMode,$density,$vertexCount,$triangleCount) {
 $this = $this|0;
 $patch = $patch|0;
 $renderMode = $renderMode|0;
 $density = Math_fround($density);
 $vertexCount = $vertexCount|0;
 $triangleCount = $triangleCount|0;
 var $$lcssa4 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond13 = 0, $i$08 = 0;
 var $tmp = 0, $tmp1 = 0, $x$02 = 0, $y$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$triangleCount>>2] = 0;
 HEAP32[$vertexCount>>2] = 0;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($patch) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($patch) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 16|0);
 $8 = ($1|0)>(0);
 $9 = (($patch) + 40|0);
 $$pre = HEAP32[$7>>2]|0;
 $45 = 0;$i$08 = 0;
 while(1) {
  $10 = (($5) + ($i$08)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = ((($$pre) + (($12*136)|0)|0) + 68|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==($renderMode|0);
  if ($15) {
   $16 = ((($$pre) + (($12*136)|0)|0) + 76|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($$pre) + (($12*136)|0)|0) + 80|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($17|0)==($19|0);
   if ($20) {
    $72 = $45;
   } else {
    if ($8) {
     $21 = Math_imul($i$08, $1)|0;
     $73 = 0;$y$05 = 0;
     while(1) {
      $tmp = (($y$05) + ($21))|0;
      $tmp1 = Math_imul($tmp, $1)|0;
      $22 = HEAP32[$9>>2]|0;
      $23 = $y$05 & 7;
      $41 = $73;$x$02 = 0;
      while(1) {
       $24 = (($tmp1) + ($x$02))|0;
       $25 = (($22) + ($24)|0);
       $26 = HEAP8[$25>>0]|0;
       $27 = ($26<<24>>24)==(0);
       if ($27) {
        $74 = $41;
       } else {
        $28 = $26&255;
        $29 = (Math_fround(($28|0)));
        $30 = Math_fround($29 * $density);
        $31 = $x$02 << 3;
        $32 = $31 & 56;
        $33 = $32 | $23;
        $34 = (799520 + ($33<<2)|0);
        $35 = Math_fround(HEAPF32[$34>>2]);
        $36 = Math_fround($35 + Math_fround(-0.5));
        $37 = Math_fround($36 * Math_fround(0.015625));
        $38 = Math_fround($30 + $37);
        $39 = (~~(($38)));
        $40 = (($39) + ($41))|0;
        $74 = $40;
       }
       $42 = (($x$02) + 1)|0;
       $exitcond = ($42|0)==($1|0);
       if ($exitcond) {
        break;
       } else {
        $41 = $74;$x$02 = $42;
       }
      }
      $43 = (($y$05) + 1)|0;
      $exitcond13 = ($43|0)==($1|0);
      if ($exitcond13) {
       $$lcssa4 = $74;
       break;
      } else {
       $73 = $74;$y$05 = $43;
      }
     }
    } else {
     $$lcssa4 = 0;
    }
    $44 = (50000 - ($45))|0;
    $46 = $19;
    $47 = $17;
    $48 = (($46) - ($47))|0;
    $49 = (($48|0) / 12)&-1;
    $50 = (($44>>>0) / ($49>>>0))&-1;
    $51 = ($$lcssa4|0)<($50|0);
    $52 = $51 ? $$lcssa4 : $50;
    $53 = ((($$pre) + (($12*136)|0)|0) + 128|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ((($$pre) + (($12*136)|0)|0) + 124|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = $54;
    $58 = $56;
    $59 = (($57) - ($58))|0;
    $60 = $59 >> 1;
    $61 = Math_imul($60, $52)|0;
    $62 = HEAP32[$triangleCount>>2]|0;
    $63 = (($61) + ($62))|0;
    HEAP32[$triangleCount>>2] = $63;
    $64 = Math_imul($49, $52)|0;
    $65 = HEAP32[$vertexCount>>2]|0;
    $66 = (($65) + ($64))|0;
    HEAP32[$vertexCount>>2] = $66;
    $72 = $66;
   }
  } else {
   $72 = $45;
  }
  $67 = (($i$08) + 1)|0;
  $68 = $3;
  $69 = $5;
  $70 = (($68) - ($69))|0;
  $71 = ($67>>>0)<($70>>>0);
  if ($71) {
   $45 = $72;$i$08 = $67;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14DetailDatabase12GenerateMeshER4Meshii8Vector3f16DetailRenderModefii($this,$mesh,$patchX,$patchY,$size,$renderMode,$density,$totalVertexCount,$totalTriangleCount) {
 $this = $this|0;
 $mesh = $mesh|0;
 $patchX = $patchX|0;
 $patchY = $patchY|0;
 $size = $size|0;
 $renderMode = $renderMode|0;
 $density = Math_fround($density);
 $totalVertexCount = $totalVertexCount|0;
 $totalTriangleCount = $totalTriangleCount|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$01$i = 0, $$01$i40 = 0, $$01$i43 = 0, $$01$i48 = 0, $$01$i50 = 0, $$01$i53 = 0, $$1 = 0, $$12 = 0, $$146 = 0, $$147 = 0, $$148 = 0, $$2 = 0, $$23 = 0, $$3 = 0, $$34 = 0, $$4 = 0, $$45 = 0;
 var $$5 = 0, $$56 = 0, $$byval_copy25 = 0, $$lcssa207 = Math_fround(0), $$lcssa209 = Math_fround(0), $$op$i$i$i$i = Math_fround(0), $$op$i1$i$i$i = Math_fround(0), $$op$i2$i$i$i = Math_fround(0), $$op$i3$i$i$i = Math_fround(0), $$pre = 0, $$pre231 = 0, $$pre232 = 0, $$pre233$pre = 0, $$pre234$pre = 0, $$pre243 = 0, $$pre244 = 0, $$pre245 = 0, $$pre246 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = Math_fround(0), $1007 = Math_fround(0), $1008 = Math_fround(0), $1009 = Math_fround(0), $101 = 0, $1010 = Math_fround(0), $1011 = Math_fround(0), $1012 = Math_fround(0), $1013 = Math_fround(0), $1014 = Math_fround(0), $1015 = Math_fround(0), $1016 = Math_fround(0);
 var $1017 = Math_fround(0), $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = Math_fround(0), $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0;
 var $240 = 0, $241 = Math_fround(0), $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0);
 var $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = Math_fround(0), $343 = Math_fround(0), $344 = Math_fround(0), $345 = Math_fround(0), $346 = 0, $347 = 0, $348 = Math_fround(0);
 var $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = Math_fround(0), $36 = 0, $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = Math_fround(0), $365 = 0, $366 = Math_fround(0);
 var $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = 0, $370 = Math_fround(0), $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = 0, $378 = Math_fround(0), $379 = Math_fround(0), $38 = 0, $380 = 0, $381 = 0, $382 = Math_fround(0), $383 = 0, $384 = Math_fround(0);
 var $385 = Math_fround(0), $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = Math_fround(0), $411 = Math_fround(0), $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = Math_fround(0), $417 = 0, $418 = Math_fround(0), $419 = Math_fround(0), $42 = 0;
 var $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = Math_fround(0), $446 = 0, $447 = Math_fround(0), $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0), $527 = Math_fround(0), $528 = Math_fround(0);
 var $529 = Math_fround(0), $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = 0, $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = 0, $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = 0, $544 = Math_fround(0), $545 = Math_fround(0), $546 = Math_fround(0);
 var $547 = Math_fround(0), $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = Math_fround(0), $551 = Math_fround(0), $552 = Math_fround(0), $553 = Math_fround(0), $554 = Math_fround(0), $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0);
 var $565 = Math_fround(0), $566 = Math_fround(0), $567 = Math_fround(0), $568 = Math_fround(0), $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0;
 var $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = Math_fround(0), $624 = Math_fround(0), $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = Math_fround(0), $63 = 0, $630 = Math_fround(0), $631 = Math_fround(0), $632 = Math_fround(0), $633 = Math_fround(0), $634 = Math_fround(0), $635 = Math_fround(0), $636 = Math_fround(0);
 var $637 = Math_fround(0), $638 = Math_fround(0), $639 = Math_fround(0), $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = Math_fround(0), $643 = Math_fround(0), $644 = Math_fround(0), $645 = Math_fround(0), $646 = Math_fround(0), $647 = Math_fround(0), $648 = Math_fround(0), $649 = Math_fround(0), $65 = 0, $650 = Math_fround(0), $651 = 0, $652 = 0, $653 = Math_fround(0), $654 = Math_fround(0);
 var $655 = 0, $656 = Math_fround(0), $657 = Math_fround(0), $658 = Math_fround(0), $659 = 0, $66 = 0, $660 = Math_fround(0), $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = Math_fround(0), $668 = Math_fround(0), $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0);
 var $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0;
 var $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0;
 var $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0;
 var $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0;
 var $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0;
 var $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0;
 var $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0;
 var $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0;
 var $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0;
 var $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0;
 var $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0;
 var $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0;
 var $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0;
 var $907 = 0, $908 = 0, $909 = Math_fround(0), $91 = 0, $910 = Math_fround(0), $911 = 0, $912 = Math_fround(0), $913 = Math_fround(0), $914 = 0, $915 = Math_fround(0), $916 = Math_fround(0), $917 = 0, $918 = Math_fround(0), $919 = Math_fround(0), $92 = 0, $920 = Math_fround(0), $921 = Math_fround(0), $922 = 0, $923 = Math_fround(0), $924 = Math_fround(0);
 var $925 = 0, $926 = Math_fround(0), $927 = Math_fround(0), $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0;
 var $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0;
 var $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0;
 var $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0;
 var $998 = 0, $999 = 0, $aabb$i = 0, $allocPtr$0 = 0, $allocPtr10$0 = 0, $allocPtr12$0 = 0, $allocPtr4$0 = 0, $allocPtr6$0 = 0, $allocPtr8$0 = 0, $billboardSize = 0, $exitcond$i = 0, $exitcond$i103 = 0, $exitcond$i108 = 0, $exitcond$i61 = 0, $exitcond$i68 = 0, $exitcond$i71 = 0, $exitcond$i76 = 0, $exitcond$i81 = 0, $exitcond$i90 = 0, $exitcond$i94 = 0;
 var $exitcond$i98 = 0, $i$01$i = 0, $i$01$i102 = 0, $i$01$i107 = 0, $i$01$i60 = 0, $i$01$i70 = 0, $i$01$i75 = 0, $i$01$i80 = 0, $i$01$i93 = 0, $i$01$i97 = 0, $i$02$i = 0, $i$02$i89 = 0, $i$0213 = 0, $k$0173 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp = 0, $pos = 0, $rot = 0, $scale = 0;
 var $t$0156 = 0, $t13$0154 = 0, $terrainNormal$i = 0, $terrainNormal$i78 = 0, $tmp = 0, $tmp152 = 0, $totalVertexCount$ = 0, $transform = 0, $triangleCount$0$lcssa = 0, $triangleCount$0215 = 0, $triangleCount$1201 = 0, $triangleCount$2185 = 0, $triangleCount$3172 = 0, $triangleCount$4 = 0, $triangleCount$5 = 0, $triangleCount$6 = 0, $vertexCount$0$lcssa = 0, $vertexCount$0214 = 0, $vertexCount$1200 = 0, $vertexCount$2184 = 0;
 var $vertexCount$3165 = 0, $vertexCount$4 = 0, $vertexCount$5 = 0, $vertexCount$6 = 0, $x$0186 = 0, $y$0202 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $$byval_copy25 = sp + 272|0;
 $terrainNormal$i78 = sp + 260|0;
 $terrainNormal$i = sp + 248|0;
 $aabb$i = sp + 224|0;
 $0 = sp + 216|0;
 $1 = sp + 212|0;
 $2 = sp + 208|0;
 $3 = sp + 204|0;
 $4 = sp + 200|0;
 $5 = sp + 196|0;
 $6 = sp + 192|0;
 $7 = sp + 188|0;
 $8 = sp + 184|0;
 $9 = sp + 180|0;
 $10 = sp + 176|0;
 $11 = sp + 20|0;
 $12 = sp;
 $13 = sp + 4|0;
 $14 = sp + 8|0;
 $15 = sp + 12|0;
 $16 = sp + 16|0;
 $17 = sp + 24|0;
 $18 = sp + 28|0;
 $19 = sp + 32|0;
 $pos = sp + 36|0;
 $billboardSize = sp + 48|0;
 $rot = sp + 80|0;
 $scale = sp + 96|0;
 $transform = sp + 112|0;
 $20 = (($this) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = Math_imul($21, $patchY)|0;
 $23 = (($22) + ($patchX))|0;
 $24 = (($this) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($totalVertexCount*12)|0;
 $27 = (($26) + 15)|0;
 $28 = ($27>>>0)<(2000);
 $29 = ($totalVertexCount|0)!=(0);
 if ($28) {
  if ($29) {
   $30 = STACKTOP; STACKTOP = STACKTOP + ((((1*$27)|0)+15)&-16)|0;;
   $960 = 0;$allocPtr$0 = $30;
   label = 7;
  } else {
   $960 = 0;$allocPtr$0 = 0;
   label = 7;
  }
 } else {
  if ($29) {
   $31 = HEAP32[628512>>2]|0;
   HEAP32[$13>>2] = $31;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$13+0>>2]|0;
   $32 = (invoke_iiiiiii(102,($27|0),16,($$byval_copy25|0),0,(799248|0),826)|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    $994 = 0;
    label = 6;
   } else {
    $960 = $32;$allocPtr$0 = $32;
    label = 7;
   }
  } else {
   $960 = 0;$allocPtr$0 = 0;
   label = 7;
  }
 }
 L6: do {
  if ((label|0) == 7) {
   $37 = $allocPtr$0;
   $38 = (($37) + 15)|0;
   $39 = $38 & -16;
   $40 = $39;
   $41 = $totalVertexCount << 3;
   $42 = (($41) + 15)|0;
   $43 = ($42>>>0)<(2000);
   if ($43) {
    if ($29) {
     $50 = STACKTOP; STACKTOP = STACKTOP + ((((1*$42)|0)+15)&-16)|0;;
     $51 = $50;
     $52 = (($51) + 15)|0;
     $53 = $52 & -16;
     $54 = $53;
     $55 = STACKTOP; STACKTOP = STACKTOP + ((((1*$42)|0)+15)&-16)|0;;
     $431 = $54;$950 = 0;$955 = 0;$allocPtr4$0 = $55;
     label = 15;
    } else {
     $431 = 0;$950 = 0;$955 = 0;$allocPtr4$0 = 0;
     label = 15;
    }
   } else {
    if ($29) {
     $44 = HEAP32[628512>>2]|0;
     HEAP32[$14>>2] = $44;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$14+0>>2]|0;
     $45 = (invoke_iiiiiii(102,($42|0),16,($$byval_copy25|0),0,(799248|0),829)|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      $995 = 0;
      label = 11;
     } else {
      $56 = $45;
      $57 = (($56) + 15)|0;
      $58 = $57 & -16;
      $59 = $58;
      $60 = HEAP32[628512>>2]|0;
      HEAP32[$15>>2] = $60;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$15+0>>2]|0;
      $61 = (invoke_iiiiiii(102,($42|0),16,($$byval_copy25|0),0,(799248|0),834)|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       $996 = $45;$997 = 0;
       label = 14;
      } else {
       $431 = $59;$950 = $61;$955 = $45;$allocPtr4$0 = $61;
       label = 15;
      }
     }
    } else {
     $431 = 0;$950 = 0;$955 = 0;$allocPtr4$0 = 0;
     label = 15;
    }
   }
   L14: do {
    if ((label|0) == 15) {
     $66 = $allocPtr4$0;
     $67 = (($66) + 15)|0;
     $68 = $67 & -16;
     $69 = $68;
     $70 = ($renderMode|0)==(0);
     $totalVertexCount$ = $70 ? $totalVertexCount : 0;
     $71 = $totalVertexCount$ << 4;
     $72 = $71 | 15;
     $73 = ($72>>>0)<(2000);
     $74 = ($totalVertexCount$|0)!=(0);
     if ($73) {
      if ($74) {
       $75 = STACKTOP; STACKTOP = STACKTOP + ((((1*$72)|0)+15)&-16)|0;;
       $945 = 0;$allocPtr6$0 = $75;
       label = 21;
      } else {
       $945 = 0;$allocPtr6$0 = 0;
       label = 21;
      }
     } else {
      if ($74) {
       $76 = HEAP32[628512>>2]|0;
       HEAP32[$16>>2] = $76;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$16+0>>2]|0;
       $77 = (invoke_iiiiiii(102,($72|0),16,($$byval_copy25|0),0,(799248|0),841)|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        $999 = 0;
        label = 20;
       } else {
        $945 = $77;$allocPtr6$0 = $77;
        label = 21;
       }
      } else {
       $945 = 0;$allocPtr6$0 = 0;
       label = 21;
      }
     }
     L21: do {
      if ((label|0) == 21) {
       $82 = $allocPtr6$0;
       $83 = (($82) + 15)|0;
       $84 = $83 & -16;
       $85 = $84;
       $86 = $totalVertexCount << 2;
       $87 = (($86) + 15)|0;
       $88 = ($87>>>0)<(2000);
       if ($88) {
        if ($29) {
         $89 = STACKTOP; STACKTOP = STACKTOP + ((((1*$87)|0)+15)&-16)|0;;
         $940 = 0;$allocPtr8$0 = $89;
         label = 27;
        } else {
         $940 = 0;$allocPtr8$0 = 0;
         label = 27;
        }
       } else {
        if ($29) {
         $90 = HEAP32[628512>>2]|0;
         HEAP32[$17>>2] = $90;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$17+0>>2]|0;
         $91 = (invoke_iiiiiii(102,($87|0),16,($$byval_copy25|0),0,(799248|0),844)|0);
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          $1000 = 0;
          label = 26;
         } else {
          $940 = $91;$allocPtr8$0 = $91;
          label = 27;
         }
        } else {
         $940 = 0;$allocPtr8$0 = 0;
         label = 27;
        }
       }
       L28: do {
        if ((label|0) == 27) {
         $96 = $allocPtr8$0;
         $97 = (($96) + 15)|0;
         $98 = $97 & -16;
         $99 = $98;
         if ($28) {
          if ($29) {
           $100 = STACKTOP; STACKTOP = STACKTOP + ((((1*$27)|0)+15)&-16)|0;;
           $935 = 0;$allocPtr10$0 = $100;
           label = 33;
          } else {
           $935 = 0;$allocPtr10$0 = 0;
           label = 33;
          }
         } else {
          if ($29) {
           $101 = HEAP32[628512>>2]|0;
           HEAP32[$18>>2] = $101;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$18+0>>2]|0;
           $102 = (invoke_iiiiiii(102,($27|0),16,($$byval_copy25|0),0,(799248|0),848)|0);
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            $1001 = 0;
            label = 32;
           } else {
            $935 = $102;$allocPtr10$0 = $102;
            label = 33;
           }
          } else {
           $935 = 0;$allocPtr10$0 = 0;
           label = 33;
          }
         }
         L35: do {
          if ((label|0) == 33) {
           $107 = $allocPtr10$0;
           $108 = (($107) + 15)|0;
           $109 = $108 & -16;
           $110 = $109;
           $111 = $totalTriangleCount << 1;
           $112 = (($111) + 15)|0;
           $113 = ($112>>>0)<(2000);
           $114 = ($totalTriangleCount|0)!=(0);
           if ($113) {
            if ($114) {
             $115 = STACKTOP; STACKTOP = STACKTOP + ((((1*$112)|0)+15)&-16)|0;;
             $127 = 0;$allocPtr12$0 = $115;
             label = 44;
            } else {
             $127 = 0;$allocPtr12$0 = 0;
             label = 44;
            }
           } else {
            if ($114) {
             $116 = HEAP32[628512>>2]|0;
             HEAP32[$19>>2] = $116;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$19+0>>2]|0;
             $117 = (invoke_iiiiiii(102,($112|0),16,($$byval_copy25|0),0,(799248|0),851)|0);
             $118 = __THREW__; __THREW__ = 0;
             $119 = $118&1;
             if ($119) {
              $120 = ___cxa_find_matching_catch()|0;
              $121 = tempRet0;
              $1002 = $0;$1003 = $121;$1004 = $120;
             } else {
              $127 = $117;$allocPtr12$0 = $117;
              label = 44;
             }
            } else {
             $127 = 0;$allocPtr12$0 = 0;
             label = 44;
            }
           }
           if ((label|0) == 44) {
            $131 = $allocPtr12$0;
            $132 = (($131) + 15)|0;
            $133 = $132 & -16;
            $134 = $133;
            $135 = $133;
            $136 = (($this) + 40|0);
            $137 = HEAP32[$136>>2]|0;
            $138 = HEAP32[$20>>2]|0;
            $139 = Math_imul($138, $137)|0;
            $140 = (Math_fround(($139|0)));
            $141 = Math_fround(Math_fround(1.0) / $140);
            $142 = (($this) + 28|0);
            $143 = HEAP32[$142>>2]|0;
            $144 = (($143) + 232|0);
            $145 = ((($25) + (($23*52)|0)|0) + 32|0);
            $146 = HEAP32[$145>>2]|0;
            $147 = ((($25) + (($23*52)|0)|0) + 28|0);
            $148 = HEAP32[$147>>2]|0;
            $149 = ($146|0)==($148|0);
            L45: do {
             if ($149) {
              $$lcssa207 = Math_fround(0.0);$$lcssa209 = Math_fround(0.0);$triangleCount$0$lcssa = 0;$vertexCount$0$lcssa = 0;
              label = 94;
             } else {
              $150 = (($this) + 16|0);
              $151 = ($137|0)>(0);
              $152 = ((($25) + (($23*52)|0)|0) + 40|0);
              $153 = (Math_fround(($patchX|0)));
              $154 = (Math_fround(($patchY|0)));
              $155 = (($this) + 88|0);
              $156 = (($this) + 92|0);
              $157 = (($this) + 96|0);
              $158 = (($this) + 100|0);
              $159 = (($pos) + 4|0);
              $160 = (($pos) + 8|0);
              $161 = (($size) + 8|0);
              $162 = (($billboardSize) + 4|0);
              $163 = (($billboardSize) + 8|0);
              $164 = (($billboardSize) + 12|0);
              $165 = (($billboardSize) + 16|0);
              $166 = (($billboardSize) + 20|0);
              $167 = (($billboardSize) + 24|0);
              $168 = (($billboardSize) + 28|0);
              $169 = (($rot) + 12|0);
              $170 = (($rot) + 4|0);
              $171 = (($rot) + 8|0);
              $172 = (($scale) + 4|0);
              $173 = (($scale) + 8|0);
              $174 = (($transform) + 16|0);
              $175 = (($transform) + 32|0);
              $176 = (($transform) + 48|0);
              $177 = (($transform) + 4|0);
              $178 = (($transform) + 20|0);
              $179 = (($transform) + 36|0);
              $180 = (($transform) + 52|0);
              $181 = (($transform) + 8|0);
              $182 = (($transform) + 24|0);
              $183 = (($transform) + 40|0);
              $184 = (($transform) + 56|0);
              $185 = ($renderMode|0)==(2);
              $186 = ($109|0)==(0);
              $1005 = $146;$1006 = Math_fround(0.0);$1007 = Math_fround(0.0);$188 = $148;$i$0213 = 0;$triangleCount$0215 = 0;$vertexCount$0214 = 0;
              L47: while(1) {
               $187 = (($188) + ($i$0213)|0);
               $189 = HEAP8[$187>>0]|0;
               $190 = $189&255;
               $191 = HEAP32[$150>>2]|0;
               $192 = ((($191) + (($190*136)|0)|0) + 68|0);
               $193 = HEAP32[$192>>2]|0;
               $194 = ($193|0)==($renderMode|0);
               if ($194) {
                $195 = ((($191) + (($190*136)|0)|0) + 80|0);
                $196 = HEAP32[$195>>2]|0;
                $197 = ((($191) + (($190*136)|0)|0) + 76|0);
                $198 = HEAP32[$197>>2]|0;
                $199 = ($196|0)==($198|0);
                $$146 = $199 ? 0 : $198;
                $200 = ((($191) + (($190*136)|0)|0) + 92|0);
                $201 = HEAP32[$200>>2]|0;
                $202 = ((($191) + (($190*136)|0)|0) + 88|0);
                $203 = HEAP32[$202>>2]|0;
                $204 = ($201|0)==($203|0);
                $205 = $204 ? 0 : $203;
                $206 = ((($191) + (($190*136)|0)|0) + 104|0);
                $207 = HEAP32[$206>>2]|0;
                $208 = ((($191) + (($190*136)|0)|0) + 100|0);
                $209 = HEAP32[$208>>2]|0;
                $210 = ($207|0)==($209|0);
                $$147 = $210 ? 0 : $209;
                $211 = ((($191) + (($190*136)|0)|0) + 116|0);
                $212 = HEAP32[$211>>2]|0;
                $213 = ((($191) + (($190*136)|0)|0) + 112|0);
                $214 = HEAP32[$213>>2]|0;
                $215 = ($212|0)==($214|0);
                $216 = $215 ? 0 : $214;
                $217 = ((($191) + (($190*136)|0)|0) + 128|0);
                $218 = HEAP32[$217>>2]|0;
                $219 = ((($191) + (($190*136)|0)|0) + 124|0);
                $220 = HEAP32[$219>>2]|0;
                $221 = ($218|0)==($220|0);
                $$148 = $221 ? 0 : $220;
                $222 = ((($191) + (($190*136)|0)|0) + 24|0);
                $223 = Math_fround(HEAPF32[$222>>2]);
                $224 = ((($191) + (($190*136)|0)|0) + 48|0);
                $225 = Math_fround(HEAPF32[$224>>2]);
                $226 = ((($191) + (($190*136)|0)|0) + 52|0);
                $227 = Math_fround(HEAPF32[$226>>2]);
                $228 = ((($191) + (($190*136)|0)|0) + 56|0);
                $229 = Math_fround(HEAPF32[$228>>2]);
                $230 = ((($191) + (($190*136)|0)|0) + 60|0);
                $231 = Math_fround(HEAPF32[$230>>2]);
                $232 = ((($191) + (($190*136)|0)|0) + 32|0);
                $233 = Math_fround(HEAPF32[$232>>2]);
                $234 = ((($191) + (($190*136)|0)|0) + 36|0);
                $235 = Math_fround(HEAPF32[$234>>2]);
                $236 = ((($191) + (($190*136)|0)|0) + 40|0);
                $237 = Math_fround(HEAPF32[$236>>2]);
                $238 = ((($191) + (($190*136)|0)|0) + 44|0);
                $239 = Math_fround(HEAPF32[$238>>2]);
                $240 = ((($191) + (($190*136)|0)|0) + 8|0);
                $241 = Math_fround(HEAPF32[$240>>2]);
                $242 = Math_fround($241 * Math_fround(0.5));
                $243 = ((($191) + (($190*136)|0)|0) + 12|0);
                $244 = Math_fround(HEAPF32[$243>>2]);
                $245 = Math_fround($244 - $241);
                $246 = Math_fround($245 * Math_fround(0.5));
                $247 = ((($191) + (($190*136)|0)|0) + 16|0);
                $248 = Math_fround(HEAPF32[$247>>2]);
                $249 = ((($191) + (($190*136)|0)|0) + 20|0);
                $250 = Math_fround(HEAPF32[$249>>2]);
                $251 = Math_fround($250 - $248);
                $252 = $218;
                $253 = $220;
                $254 = (($252) - ($253))|0;
                $255 = $254 >> 1;
                $256 = $196;
                $257 = $198;
                $258 = (($256) - ($257))|0;
                $259 = (($258|0) / 12)&-1;
                if ($199) {
                 $1008 = $1007;$1009 = $1006;$693 = $1005;$695 = $188;$triangleCount$6 = $triangleCount$0215;$vertexCount$6 = $vertexCount$0214;
                } else {
                 if ($151) {
                  $260 = Math_imul($i$0213, $137)|0;
                  $261 = ($258|0)>(0);
                  $262 = ($254|0)>(0);
                  $1010 = $1006;$1011 = $1007;$triangleCount$1201 = $triangleCount$0215;$vertexCount$1200 = $vertexCount$0214;$y$0202 = 0;
                  while(1) {
                   $tmp = (($y$0202) + ($260))|0;
                   $tmp152 = Math_imul($tmp, $137)|0;
                   $263 = (Math_fround(($y$0202|0)));
                   $264 = $y$0202 & 7;
                   $1012 = $1010;$1013 = $1011;$triangleCount$2185 = $triangleCount$1201;$vertexCount$2184 = $vertexCount$1200;$x$0186 = 0;
                   while(1) {
                    $265 = (($tmp152) + ($x$0186))|0;
                    $266 = HEAP32[$152>>2]|0;
                    $267 = (($266) + ($265)|0);
                    $268 = HEAP8[$267>>0]|0;
                    $269 = $268&255;
                    $270 = ($268<<24>>24)==(0);
                    L57: do {
                     if ($270) {
                      $1014 = $1013;$1015 = $1012;$triangleCount$5 = $triangleCount$2185;$vertexCount$5 = $vertexCount$2184;
                     } else {
                      $271 = HEAP32[$20>>2]|0;
                      $272 = (Math_fround(($271|0)));
                      $273 = Math_fround($153 / $272);
                      $274 = (Math_fround(($x$0186|0)));
                      $275 = Math_imul($271, $137)|0;
                      $276 = (Math_fround(($275|0)));
                      $277 = Math_fround($274 / $276);
                      $278 = Math_fround($273 + $277);
                      $279 = Math_fround($154 / $272);
                      $280 = Math_fround($263 / $276);
                      $281 = Math_fround($279 + $280);
                      $282 = Math_imul($271, $patchX)|0;
                      $283 = (($282) + ($patchY))|0;
                      $284 = ($283*1013)|0;
                      $285 = (($284) + ($265))|0;
                      HEAP32[$155>>2] = $285;
                      $286 = Math_imul($285, 1812433253)|0;
                      $287 = (($286) + 1)|0;
                      HEAP32[$156>>2] = $287;
                      $288 = Math_imul($287, 1812433253)|0;
                      $289 = (($288) + 1)|0;
                      HEAP32[$157>>2] = $289;
                      $290 = Math_imul($289, 1812433253)|0;
                      $291 = (($290) + 1)|0;
                      HEAP32[$158>>2] = $291;
                      $292 = (50000 - ($vertexCount$2184))|0;
                      $293 = (($292|0) / ($259|0))&-1;
                      $294 = ($269|0)<($293|0);
                      $295 = $294 ? $269 : $293;
                      $296 = (Math_fround(($295|0)));
                      $297 = Math_fround($296 * $density);
                      $298 = $x$0186 << 3;
                      $299 = $298 & 56;
                      $300 = $299 | $264;
                      $301 = (799520 + ($300<<2)|0);
                      $302 = Math_fround(HEAPF32[$301>>2]);
                      $303 = Math_fround($302 + Math_fround(-0.5));
                      $304 = Math_fround($303 * Math_fround(0.015625));
                      $305 = Math_fround($304 + $297);
                      $306 = (~~(($305)));
                      $307 = ($306|0)>(0);
                      if ($307) {
                       $309 = $285;$312 = $291;$323 = $287;$325 = $289;$415 = $1013;$418 = $1012;$k$0173 = 1;$triangleCount$3172 = $triangleCount$2185;$vertexCount$3165 = $vertexCount$2184;
                      } else {
                       $1014 = $1013;$1015 = $1012;$triangleCount$5 = $triangleCount$2185;$vertexCount$5 = $vertexCount$2184;
                       break;
                      }
                      while(1) {
                       $308 = $309 << 11;
                       $310 = $308 ^ $309;
                       $311 = $312 >>> 19;
                       $313 = $310 >>> 8;
                       $314 = $313 ^ $310;
                       $315 = $314 ^ $312;
                       $316 = $315 ^ $311;
                       $317 = $316 & 8388607;
                       $318 = (Math_fround(($317>>>0)));
                       $319 = Math_fround($318 * Math_fround(1.19209303761635965202E-7));
                       $320 = Math_fround($141 * $319);
                       $321 = Math_fround($278 + $320);
                       $322 = $323 << 11;
                       $324 = $322 ^ $323;
                       HEAP32[$155>>2] = $325;
                       HEAP32[$156>>2] = $312;
                       HEAP32[$157>>2] = $316;
                       $326 = $315 >>> 19;
                       $327 = $324 >>> 8;
                       $328 = $327 ^ $324;
                       $329 = $328 ^ $316;
                       $330 = $329 ^ $326;
                       HEAP32[$158>>2] = $330;
                       $331 = $330 & 8388607;
                       $332 = (Math_fround(($331>>>0)));
                       $333 = Math_fround($332 * Math_fround(1.19209303761635965202E-7));
                       $334 = Math_fround($141 * $333);
                       $335 = Math_fround($281 + $334);
                       HEAPF32[$pos>>2] = Math_fround(0.0);
                       HEAPF32[$159>>2] = Math_fround(0.0);
                       HEAPF32[$160>>2] = Math_fround(0.0);
                       __THREW__ = 0;
                       $336 = (Math_fround(+(invoke_fiff(8,($144|0),(+$321),(+$335)))));
                       $337 = __THREW__; __THREW__ = 0;
                       $338 = $337&1;
                       if ($338) {
                        break L47;
                       }
                       HEAPF32[$159>>2] = $336;
                       $339 = Math_fround(HEAPF32[$size>>2]);
                       $340 = Math_fround($321 * $339);
                       HEAPF32[$pos>>2] = $340;
                       $341 = Math_fround(HEAPF32[$161>>2]);
                       $342 = Math_fround($335 * $341);
                       HEAPF32[$160>>2] = $342;
                       $343 = Math_fround($223 * $340);
                       $344 = Math_fround($223 * $342);
                       __THREW__ = 0;
                       $345 = (Math_fround(+(invoke_fff(2,(+$343),(+$344)))));
                       $346 = __THREW__; __THREW__ = 0;
                       $347 = $346&1;
                       if ($347) {
                        break L47;
                       }
                       $348 = Math_fround($345 + Math_fround(0.689999997615814208984));
                       $349 = Math_fround($348 / Math_fround(1.48300004005432128906));
                       $350 = Math_fround(Math_fround(1.0) - $349);
                       $351 = Math_fround($225 * $350);
                       $352 = Math_fround($227 * $350);
                       $353 = Math_fround($229 * $350);
                       $354 = Math_fround($231 * $350);
                       $355 = Math_fround($233 * $349);
                       $356 = Math_fround($235 * $349);
                       $357 = Math_fround($237 * $349);
                       $358 = Math_fround($239 * $349);
                       $359 = Math_fround($355 + $351);
                       $360 = Math_fround($356 + $352);
                       $361 = Math_fround($357 + $353);
                       $362 = Math_fround($358 + $354);
                       $363 = $359 < Math_fround(0.0);
                       $364 = $363 ? Math_fround(0.0) : $359;
                       $365 = $364 > Math_fround(1.0);
                       $$op$i$i$i$i = Math_fround($364 * Math_fround(255.0));
                       $366 = $365 ? Math_fround(255.0) : $$op$i$i$i$i;
                       $367 = Math_fround($366 + Math_fround(0.5));
                       $368 = (~~(($367))>>>0);
                       $369 = $360 < Math_fround(0.0);
                       $370 = $369 ? Math_fround(0.0) : $360;
                       $371 = $370 > Math_fround(1.0);
                       $$op$i3$i$i$i = Math_fround($370 * Math_fround(255.0));
                       $372 = $371 ? Math_fround(255.0) : $$op$i3$i$i$i;
                       $373 = Math_fround($372 + Math_fround(0.5));
                       $374 = (~~(($373))>>>0);
                       $375 = $361 < Math_fround(0.0);
                       $376 = $375 ? Math_fround(0.0) : $361;
                       $377 = $376 > Math_fround(1.0);
                       $$op$i2$i$i$i = Math_fround($376 * Math_fround(255.0));
                       $378 = $377 ? Math_fround(255.0) : $$op$i2$i$i$i;
                       $379 = Math_fround($378 + Math_fround(0.5));
                       $380 = (~~(($379))>>>0);
                       $381 = $362 < Math_fround(0.0);
                       $382 = $381 ? Math_fround(0.0) : $362;
                       $383 = $382 > Math_fround(1.0);
                       $$op$i1$i$i$i = Math_fround($382 * Math_fround(255.0));
                       $384 = $383 ? Math_fround(255.0) : $$op$i1$i$i$i;
                       $385 = Math_fround($384 + Math_fround(0.5));
                       $386 = (~~(($385))>>>0);
                       $387 = HEAP8[((640792 + 258|0))>>0]|0;
                       $388 = ($387<<24>>24)==(0);
                       if ($388) {
                        $389 = $386 << 24;
                        $390 = $380 << 16;
                        $391 = $390 & 16711680;
                        $392 = $391 | $389;
                        $393 = $374 << 8;
                        $394 = $393 & 65280;
                        $395 = $392 | $394;
                        $396 = $368 & 255;
                        $397 = $395 | $396;
                        $398 = $395 >>> 8;
                        $399 = $392 >>> 16;
                        $400 = $386 & 255;
                        $453 = $397;$456 = $398;$459 = $399;$462 = $400;
                       } else {
                        $453 = $380;$456 = $374;$459 = $368;$462 = $386;
                       }
                       if ($261) {
                        $401 = (HEAPF32[tempDoublePtr>>2]=$321,HEAP32[tempDoublePtr>>2]|0);
                        $402 = (HEAPF32[tempDoublePtr>>2]=$335,HEAP32[tempDoublePtr>>2]|0);
                        $i$01$i107 = 0;
                        while(1) {
                         $403 = (($i$01$i107) + ($vertexCount$3165))|0;
                         $404 = (($69) + ($403<<3)|0);
                         $405 = $404;
                         $406 = $405;
                         HEAP32[$406>>2] = $401;
                         $407 = (($405) + 4)|0;
                         $408 = $407;
                         HEAP32[$408>>2] = $402;
                         $409 = (($i$01$i107) + 1)|0;
                         $exitcond$i108 = ($409|0)==($259|0);
                         if ($exitcond$i108) {
                          break;
                         } else {
                          $i$01$i107 = $409;
                         }
                        }
                       }
                       do {
                        if ($70) {
                         $410 = Math_fround($246 * $349);
                         $411 = Math_fround($242 + $410);
                         $412 = Math_fround($251 * $349);
                         $413 = Math_fround($248 + $412);
                         $414 = $415 < $411;
                         $416 = $414 ? $411 : $415;
                         $417 = $418 < $413;
                         $419 = $417 ? $413 : $418;
                         $420 = Math_fround(-$411);
                         HEAPF32[$billboardSize>>2] = $420;
                         HEAPF32[$162>>2] = Math_fround(0.0);
                         HEAPF32[$163>>2] = $420;
                         HEAPF32[$164>>2] = $413;
                         HEAPF32[$165>>2] = $411;
                         HEAPF32[$166>>2] = $413;
                         HEAPF32[$167>>2] = $411;
                         HEAPF32[$168>>2] = Math_fround(0.0);
                         $421 = Math_fround(HEAPF32[$pos>>2]);
                         $422 = Math_fround(HEAPF32[$159>>2]);
                         $423 = Math_fround(HEAPF32[$160>>2]);
                         if ($261) {
                          $i$01$i102 = 0;
                          while(1) {
                           $424 = (($i$01$i102) + ($vertexCount$3165))|0;
                           $425 = (($40) + (($424*12)|0)|0);
                           HEAPF32[$425>>2] = $421;
                           $426 = ((($40) + (($424*12)|0)|0) + 4|0);
                           HEAPF32[$426>>2] = $422;
                           $427 = ((($40) + (($424*12)|0)|0) + 8|0);
                           HEAPF32[$427>>2] = $423;
                           $428 = (($i$01$i102) + 1)|0;
                           $exitcond$i103 = ($428|0)==($259|0);
                           if ($exitcond$i103) {
                            $i$01$i97 = 0;
                            break;
                           } else {
                            $i$01$i102 = $428;
                           }
                          }
                          while(1) {
                           $429 = (($i$01$i97) + ($vertexCount$3165))|0;
                           $430 = (($431) + ($429<<3)|0);
                           $432 = (($$147) + ($i$01$i97<<3)|0);
                           $433 = $432;
                           $434 = $433;
                           $435 = HEAP32[$434>>2]|0;
                           $436 = (($433) + 4)|0;
                           $437 = $436;
                           $438 = HEAP32[$437>>2]|0;
                           $439 = $430;
                           $440 = $439;
                           HEAP32[$440>>2] = $435;
                           $441 = (($439) + 4)|0;
                           $442 = $441;
                           HEAP32[$442>>2] = $438;
                           $443 = (($i$01$i97) + 1)|0;
                           $exitcond$i98 = ($443|0)==($259|0);
                           if ($exitcond$i98) {
                            $i$01$i93 = 0;
                            break;
                           } else {
                            $i$01$i97 = $443;
                           }
                          }
                          while(1) {
                           $444 = (($billboardSize) + ($i$01$i93<<3)|0);
                           $445 = Math_fround(HEAPF32[$444>>2]);
                           $446 = ((($billboardSize) + ($i$01$i93<<3)|0) + 4|0);
                           $447 = Math_fround(HEAPF32[$446>>2]);
                           $448 = (($i$01$i93) + ($vertexCount$3165))|0;
                           $449 = (($85) + ($448<<4)|0);
                           HEAPF32[$449>>2] = $445;
                           $450 = ((($85) + ($448<<4)|0) + 4|0);
                           HEAPF32[$450>>2] = $447;
                           $451 = (($i$01$i93) + 1)|0;
                           $exitcond$i94 = ($451|0)==($259|0);
                           if ($exitcond$i94) {
                            break;
                           } else {
                            $i$01$i93 = $451;
                           }
                          }
                          $452 = $453 & 255;
                          $454 = (($452) + 1)|0;
                          $455 = $456 & 255;
                          $457 = (($455) + 1)|0;
                          $458 = $459 & 255;
                          $460 = (($458) + 1)|0;
                          $461 = $462 & 255;
                          $463 = (($461) + 1)|0;
                          $i$02$i89 = 0;
                          while(1) {
                           $464 = (($i$02$i89) + ($vertexCount$3165))|0;
                           $465 = (($99) + ($464<<2)|0);
                           $466 = (($216) + ($i$02$i89<<2)|0);
                           $467 = HEAP32[$466>>2]|0;
                           $468 = $467 & 255;
                           $469 = Math_imul($468, $454)|0;
                           $470 = $469 >>> 8;
                           $471 = $470 & 255;
                           $472 = $467 >>> 8;
                           $473 = $472 & 255;
                           $474 = Math_imul($473, $457)|0;
                           $475 = $474 & 65280;
                           $476 = $467 & 16711680;
                           $477 = Math_imul($476, $460)|0;
                           $478 = $477 >>> 8;
                           $479 = $478 & 16711680;
                           $480 = $472 & 16711680;
                           $481 = Math_imul($480, $463)|0;
                           $482 = $481 & -16777216;
                           $483 = $475 | $482;
                           $484 = $483 | $471;
                           $485 = $484 | $479;
                           HEAP32[$465>>2] = $485;
                           $486 = (($i$02$i89) + 1)|0;
                           $exitcond$i90 = ($486|0)==($259|0);
                           if ($exitcond$i90) {
                            break;
                           } else {
                            $i$02$i89 = $486;
                           }
                          }
                         }
                         __THREW__ = 0;
                         invoke_viiff(1,($terrainNormal$i78|0),($144|0),(+$321),(+$335));
                         $487 = __THREW__; __THREW__ = 0;
                         $488 = $487&1;
                         if ($488) {
                          break L47;
                         }
                         if ($261) {
                          $i$01$i80 = 0;
                          while(1) {
                           $489 = (($i$01$i80) + ($vertexCount$3165))|0;
                           $490 = (($110) + (($489*12)|0)|0);
                           ;HEAP32[$490+0>>2]=HEAP32[$terrainNormal$i78+0>>2]|0;HEAP32[$490+4>>2]=HEAP32[$terrainNormal$i78+4>>2]|0;HEAP32[$490+8>>2]=HEAP32[$terrainNormal$i78+8>>2]|0;
                           $491 = (($i$01$i80) + 1)|0;
                           $exitcond$i81 = ($491|0)==($259|0);
                           if ($exitcond$i81) {
                            break;
                           } else {
                            $i$01$i80 = $491;
                           }
                          }
                         }
                         if ($262) {
                          $t$0156 = 0;
                         } else {
                          $1016 = $416;$1017 = $419;
                          break;
                         }
                         while(1) {
                          $492 = (($$148) + ($t$0156<<1)|0);
                          $493 = HEAP16[$492>>1]|0;
                          $494 = $493&65535;
                          $495 = (($494) + ($vertexCount$3165))|0;
                          $496 = $495&65535;
                          $497 = (($t$0156) + ($triangleCount$3172))|0;
                          $498 = (($135) + ($497<<1)|0);
                          HEAP16[$498>>1] = $496;
                          $499 = (($t$0156) + 1)|0;
                          $500 = ($499|0)<($255|0);
                          if ($500) {
                           $t$0156 = $499;
                          } else {
                           $1016 = $416;$1017 = $419;
                           break;
                          }
                         }
                        } else {
                         $501 = HEAP32[$155>>2]|0;
                         $502 = $501 << 11;
                         $503 = $502 ^ $501;
                         $504 = HEAP32[$156>>2]|0;
                         HEAP32[$155>>2] = $504;
                         $505 = HEAP32[$157>>2]|0;
                         HEAP32[$156>>2] = $505;
                         $506 = HEAP32[$158>>2]|0;
                         HEAP32[$157>>2] = $506;
                         $507 = $506 >>> 19;
                         $508 = $503 >>> 8;
                         $509 = $508 ^ $503;
                         $510 = $509 ^ $506;
                         $511 = $510 ^ $507;
                         HEAP32[$158>>2] = $511;
                         $512 = $511 & 8388607;
                         $513 = (Math_fround(($512>>>0)));
                         $514 = Math_fround($513 * Math_fround(1.19209303761635965202E-7));
                         $515 = Math_fround($514 * Math_fround(6.28318500518798828125));
                         $516 = Math_fround($515 * Math_fround(0.5));
                         $517 = (Math_fround(+(Math_sin((+$516)))));
                         $518 = (Math_fround(+(Math_cos((+$516)))));
                         HEAPF32[$169>>2] = $518;
                         $519 = Math_fround($517 * Math_fround(0.0));
                         HEAPF32[$rot>>2] = $519;
                         HEAPF32[$170>>2] = $517;
                         HEAPF32[$171>>2] = $519;
                         $520 = Math_fround(HEAPF32[$240>>2]);
                         $521 = Math_fround(HEAPF32[$243>>2]);
                         $522 = Math_fround($349 * $521);
                         $523 = Math_fround($350 * $520);
                         $524 = Math_fround($523 + $522);
                         $525 = Math_fround(HEAPF32[$247>>2]);
                         $526 = Math_fround(HEAPF32[$249>>2]);
                         $527 = Math_fround($349 * $526);
                         $528 = Math_fround($350 * $525);
                         $529 = Math_fround($528 + $527);
                         HEAPF32[$scale>>2] = $524;
                         HEAPF32[$172>>2] = $529;
                         HEAPF32[$173>>2] = $524;
                         __THREW__ = 0;
                         invoke_viiii(419,($transform|0),($pos|0),($rot|0),($scale|0));
                         $530 = __THREW__; __THREW__ = 0;
                         $531 = $530&1;
                         if ($531) {
                          break L47;
                         }
                         if ($261) {
                          $i$01$i75 = 0;
                          while(1) {
                           $532 = (($i$01$i75) + ($vertexCount$3165))|0;
                           $533 = Math_fround(HEAPF32[$transform>>2]);
                           $534 = (($$146) + (($i$01$i75*12)|0)|0);
                           $535 = Math_fround(HEAPF32[$534>>2]);
                           $536 = Math_fround($533 * $535);
                           $537 = Math_fround(HEAPF32[$174>>2]);
                           $538 = ((($$146) + (($i$01$i75*12)|0)|0) + 4|0);
                           $539 = Math_fround(HEAPF32[$538>>2]);
                           $540 = Math_fround($537 * $539);
                           $541 = Math_fround($536 + $540);
                           $542 = Math_fround(HEAPF32[$175>>2]);
                           $543 = ((($$146) + (($i$01$i75*12)|0)|0) + 8|0);
                           $544 = Math_fround(HEAPF32[$543>>2]);
                           $545 = Math_fround($542 * $544);
                           $546 = Math_fround($541 + $545);
                           $547 = Math_fround(HEAPF32[$176>>2]);
                           $548 = Math_fround($547 + $546);
                           $549 = Math_fround(HEAPF32[$177>>2]);
                           $550 = Math_fround($535 * $549);
                           $551 = Math_fround(HEAPF32[$178>>2]);
                           $552 = Math_fround($539 * $551);
                           $553 = Math_fround($550 + $552);
                           $554 = Math_fround(HEAPF32[$179>>2]);
                           $555 = Math_fround($544 * $554);
                           $556 = Math_fround($553 + $555);
                           $557 = Math_fround(HEAPF32[$180>>2]);
                           $558 = Math_fround($557 + $556);
                           $559 = Math_fround(HEAPF32[$181>>2]);
                           $560 = Math_fround($535 * $559);
                           $561 = Math_fround(HEAPF32[$182>>2]);
                           $562 = Math_fround($539 * $561);
                           $563 = Math_fround($560 + $562);
                           $564 = Math_fround(HEAPF32[$183>>2]);
                           $565 = Math_fround($544 * $564);
                           $566 = Math_fround($563 + $565);
                           $567 = Math_fround(HEAPF32[$184>>2]);
                           $568 = Math_fround($567 + $566);
                           $569 = (($40) + (($532*12)|0)|0);
                           HEAPF32[$569>>2] = $548;
                           $570 = ((($40) + (($532*12)|0)|0) + 4|0);
                           HEAPF32[$570>>2] = $558;
                           $571 = ((($40) + (($532*12)|0)|0) + 8|0);
                           HEAPF32[$571>>2] = $568;
                           $572 = (($i$01$i75) + 1)|0;
                           $exitcond$i76 = ($572|0)==($259|0);
                           if ($exitcond$i76) {
                            $i$01$i70 = 0;
                            break;
                           } else {
                            $i$01$i75 = $572;
                           }
                          }
                          while(1) {
                           $573 = (($i$01$i70) + ($vertexCount$3165))|0;
                           $574 = (($431) + ($573<<3)|0);
                           $575 = (($$147) + ($i$01$i70<<3)|0);
                           $576 = $575;
                           $577 = $576;
                           $578 = HEAP32[$577>>2]|0;
                           $579 = (($576) + 4)|0;
                           $580 = $579;
                           $581 = HEAP32[$580>>2]|0;
                           $582 = $574;
                           $583 = $582;
                           HEAP32[$583>>2] = $578;
                           $584 = (($582) + 4)|0;
                           $585 = $584;
                           HEAP32[$585>>2] = $581;
                           $586 = (($i$01$i70) + 1)|0;
                           $exitcond$i71 = ($586|0)==($259|0);
                           if ($exitcond$i71) {
                            break;
                           } else {
                            $i$01$i70 = $586;
                           }
                          }
                          $587 = $453 & 255;
                          $588 = (($587) + 1)|0;
                          $589 = $456 & 255;
                          $590 = (($589) + 1)|0;
                          $591 = $459 & 255;
                          $592 = (($591) + 1)|0;
                          $593 = $462 & 255;
                          $594 = (($593) + 1)|0;
                          $i$02$i = 0;
                          while(1) {
                           $595 = (($i$02$i) + ($vertexCount$3165))|0;
                           $596 = (($99) + ($595<<2)|0);
                           $597 = (($216) + ($i$02$i<<2)|0);
                           $598 = HEAP32[$597>>2]|0;
                           $599 = $598 & 255;
                           $600 = Math_imul($599, $588)|0;
                           $601 = $600 >>> 8;
                           $602 = $601 & 255;
                           $603 = $598 >>> 8;
                           $604 = $603 & 255;
                           $605 = Math_imul($604, $590)|0;
                           $606 = $605 & 65280;
                           $607 = $598 & 16711680;
                           $608 = Math_imul($607, $592)|0;
                           $609 = $608 >>> 8;
                           $610 = $609 & 16711680;
                           $611 = $603 & 16711680;
                           $612 = Math_imul($611, $594)|0;
                           $613 = $612 & -16777216;
                           $614 = $606 | $613;
                           $615 = $614 | $602;
                           $616 = $615 | $610;
                           HEAP32[$596>>2] = $616;
                           $617 = (($i$02$i) + 1)|0;
                           $exitcond$i68 = ($617|0)==($259|0);
                           if ($exitcond$i68) {
                            break;
                           } else {
                            $i$02$i = $617;
                           }
                          }
                         }
                         do {
                          if ($185) {
                           __THREW__ = 0;
                           invoke_viiff(1,($terrainNormal$i|0),($144|0),(+$321),(+$335));
                           $618 = __THREW__; __THREW__ = 0;
                           $619 = $618&1;
                           if ($619) {
                            break L47;
                           }
                           if ($261) {
                            $i$01$i60 = 0;
                           } else {
                            break;
                           }
                           while(1) {
                            $620 = (($i$01$i60) + ($vertexCount$3165))|0;
                            $621 = (($110) + (($620*12)|0)|0);
                            ;HEAP32[$621+0>>2]=HEAP32[$terrainNormal$i+0>>2]|0;HEAP32[$621+4>>2]=HEAP32[$terrainNormal$i+4>>2]|0;HEAP32[$621+8>>2]=HEAP32[$terrainNormal$i+8>>2]|0;
                            $622 = (($i$01$i60) + 1)|0;
                            $exitcond$i61 = ($622|0)==($259|0);
                            if ($exitcond$i61) {
                             break;
                            } else {
                             $i$01$i60 = $622;
                            }
                           }
                          } else {
                           if ($186) {
                            break;
                           }
                           $623 = Math_fround(HEAPF32[$rot>>2]);
                           $624 = Math_fround(HEAPF32[$170>>2]);
                           $625 = Math_fround(HEAPF32[$171>>2]);
                           $626 = Math_fround(HEAPF32[$169>>2]);
                           if (!($261)) {
                            break;
                           }
                           $627 = Math_fround($623 * Math_fround(2.0));
                           $628 = Math_fround($624 * Math_fround(2.0));
                           $629 = Math_fround($625 * Math_fround(2.0));
                           $630 = Math_fround($623 * $627);
                           $631 = Math_fround($624 * $628);
                           $632 = Math_fround($625 * $629);
                           $633 = Math_fround($623 * $628);
                           $634 = Math_fround($623 * $629);
                           $635 = Math_fround($624 * $629);
                           $636 = Math_fround($627 * $626);
                           $637 = Math_fround($628 * $626);
                           $638 = Math_fround($626 * $629);
                           $639 = Math_fround($631 + $632);
                           $640 = Math_fround(Math_fround(1.0) - $639);
                           $641 = Math_fround($633 - $638);
                           $642 = Math_fround($634 + $637);
                           $643 = Math_fround($633 + $638);
                           $644 = Math_fround($630 + $632);
                           $645 = Math_fround(Math_fround(1.0) - $644);
                           $646 = Math_fround($635 - $636);
                           $647 = Math_fround($634 - $637);
                           $648 = Math_fround($635 + $636);
                           $649 = Math_fround($630 + $631);
                           $650 = Math_fround(Math_fround(1.0) - $649);
                           $i$01$i = 0;
                           while(1) {
                            $651 = (($i$01$i) + ($vertexCount$3165))|0;
                            $652 = (($205) + (($i$01$i*12)|0)|0);
                            $653 = Math_fround(HEAPF32[$652>>2]);
                            $654 = Math_fround($640 * $653);
                            $655 = ((($205) + (($i$01$i*12)|0)|0) + 4|0);
                            $656 = Math_fround(HEAPF32[$655>>2]);
                            $657 = Math_fround($641 * $656);
                            $658 = Math_fround($654 + $657);
                            $659 = ((($205) + (($i$01$i*12)|0)|0) + 8|0);
                            $660 = Math_fround(HEAPF32[$659>>2]);
                            $661 = Math_fround($642 * $660);
                            $662 = Math_fround($661 + $658);
                            $663 = Math_fround($643 * $653);
                            $664 = Math_fround($645 * $656);
                            $665 = Math_fround($663 + $664);
                            $666 = Math_fround($646 * $660);
                            $667 = Math_fround($666 + $665);
                            $668 = Math_fround($647 * $653);
                            $669 = Math_fround($648 * $656);
                            $670 = Math_fround($668 + $669);
                            $671 = Math_fround($650 * $660);
                            $672 = Math_fround($670 + $671);
                            $673 = (($110) + (($651*12)|0)|0);
                            HEAPF32[$673>>2] = $662;
                            $674 = ((($110) + (($651*12)|0)|0) + 4|0);
                            HEAPF32[$674>>2] = $667;
                            $675 = ((($110) + (($651*12)|0)|0) + 8|0);
                            HEAPF32[$675>>2] = $672;
                            $676 = (($i$01$i) + 1)|0;
                            $exitcond$i = ($676|0)==($259|0);
                            if ($exitcond$i) {
                             break;
                            } else {
                             $i$01$i = $676;
                            }
                           }
                          }
                         } while(0);
                         if ($262) {
                          $t13$0154 = 0;
                         } else {
                          $1016 = $415;$1017 = $418;
                          break;
                         }
                         while(1) {
                          $677 = (($$148) + ($t13$0154<<1)|0);
                          $678 = HEAP16[$677>>1]|0;
                          $679 = $678&65535;
                          $680 = (($679) + ($vertexCount$3165))|0;
                          $681 = $680&65535;
                          $682 = (($t13$0154) + ($triangleCount$3172))|0;
                          $683 = (($135) + ($682<<1)|0);
                          HEAP16[$683>>1] = $681;
                          $684 = (($t13$0154) + 1)|0;
                          $685 = ($684|0)<($255|0);
                          if ($685) {
                           $t13$0154 = $684;
                          } else {
                           $1016 = $415;$1017 = $418;
                           break;
                          }
                         }
                        }
                       } while(0);
                       $triangleCount$4 = (($triangleCount$3172) + ($255))|0;
                       $vertexCount$4 = (($vertexCount$3165) + ($259))|0;
                       $686 = ($k$0173|0)<($306|0);
                       if (!($686)) {
                        $1014 = $1016;$1015 = $1017;$triangleCount$5 = $triangleCount$4;$vertexCount$5 = $vertexCount$4;
                        break L57;
                       }
                       $$pre243 = HEAP32[$155>>2]|0;
                       $$pre244 = HEAP32[$156>>2]|0;
                       $$pre245 = HEAP32[$157>>2]|0;
                       $$pre246 = HEAP32[$158>>2]|0;
                       $phitmp = (($k$0173) + 1)|0;
                       $309 = $$pre243;$312 = $$pre246;$323 = $$pre244;$325 = $$pre245;$415 = $1016;$418 = $1017;$k$0173 = $phitmp;$triangleCount$3172 = $triangleCount$4;$vertexCount$3165 = $vertexCount$4;
                      }
                     }
                    } while(0);
                    $687 = (($x$0186) + 1)|0;
                    $688 = ($687|0)<($137|0);
                    if ($688) {
                     $1012 = $1015;$1013 = $1014;$triangleCount$2185 = $triangleCount$5;$vertexCount$2184 = $vertexCount$5;$x$0186 = $687;
                    } else {
                     break;
                    }
                   }
                   $689 = (($y$0202) + 1)|0;
                   $690 = ($689|0)<($137|0);
                   if ($690) {
                    $1010 = $1015;$1011 = $1014;$triangleCount$1201 = $triangleCount$5;$vertexCount$1200 = $vertexCount$5;$y$0202 = $689;
                   } else {
                    break;
                   }
                  }
                  $$pre233$pre = HEAP32[$145>>2]|0;
                  $$pre234$pre = HEAP32[$147>>2]|0;
                  $1008 = $1014;$1009 = $1015;$693 = $$pre233$pre;$695 = $$pre234$pre;$triangleCount$6 = $triangleCount$5;$vertexCount$6 = $vertexCount$5;
                 } else {
                  $1008 = $1007;$1009 = $1006;$693 = $1005;$695 = $188;$triangleCount$6 = $triangleCount$0215;$vertexCount$6 = $vertexCount$0214;
                 }
                }
               } else {
                $1008 = $1007;$1009 = $1006;$693 = $1005;$695 = $188;$triangleCount$6 = $triangleCount$0215;$vertexCount$6 = $vertexCount$0214;
               }
               $691 = (($i$0213) + 1)|0;
               $692 = $693;
               $694 = $695;
               $696 = (($692) - ($694))|0;
               $697 = ($691>>>0)<($696>>>0);
               if ($697) {
                $1005 = $693;$1006 = $1009;$1007 = $1008;$188 = $695;$i$0213 = $691;$triangleCount$0215 = $triangleCount$6;$vertexCount$0214 = $vertexCount$6;
               } else {
                $$lcssa207 = $1008;$$lcssa209 = $1009;$triangleCount$0$lcssa = $triangleCount$6;$vertexCount$0$lcssa = $vertexCount$6;
                label = 94;
                break L45;
               }
              }
              $122 = ___cxa_find_matching_catch()|0;
              $123 = tempRet0;
              $lpad$phi$index = $122;$lpad$phi$index2 = $123;
             }
            } while(0);
            if ((label|0) == 94) {
             __THREW__ = 0;
             invoke_vii(3410,($mesh|0),1);
             $698 = __THREW__; __THREW__ = 0;
             $699 = $698&1;
             do {
              if (!($699)) {
               $$ = $70 ? 159 : 31;
               __THREW__ = 0;
               invoke_viii(2025,($mesh|0),($vertexCount$0$lcssa|0),($$|0));
               $700 = __THREW__; __THREW__ = 0;
               $701 = $700&1;
               if (!($701)) {
                $702 = (($mesh) + 28|0);
                $703 = HEAP32[$702>>2]|0;
                $704 = (($703) + 10|0);
                $705 = HEAP8[$704>>0]|0;
                $706 = ($705<<24>>24)==(0);
                do {
                 if ($706) {
                  $707 = (($703) + 11|0);
                  $708 = HEAP8[$707>>0]|0;
                  $709 = ($708&255)<(3);
                  if ($709) {
                   $1018 = 0;$731 = 0;
                  } else {
                   $710 = (($703) + 92|0);
                   $711 = HEAP32[$710>>2]|0;
                   $712 = ($711|0)==(0|0);
                   if ($712) {
                    $1018 = 0;$731 = 1;
                    break;
                   }
                   $713 = (($703) + 8|0);
                   $714 = HEAP8[$713>>0]|0;
                   $715 = $714&255;
                   $716 = ((($703) + (($715*12)|0)|0) + 50|0);
                   $717 = HEAP8[$716>>0]|0;
                   $718 = $717&255;
                   $719 = ((($703) + (($715*12)|0)|0) + 44|0);
                   $720 = HEAP32[$719>>2]|0;
                   $721 = (($703) + 9|0);
                   $722 = HEAP8[$721>>0]|0;
                   $723 = $722&255;
                   $724 = (($723) + ($720))|0;
                   $725 = (($711) + ($724)|0);
                   $1018 = $725;$731 = $718;
                  }
                 } else {
                  $1018 = 0;$731 = 0;
                 }
                } while(0);
                $726 = (($40) + (($vertexCount$0$lcssa*12)|0)|0);
                $727 = ($vertexCount$0$lcssa|0)==(0);
                if ($727) {
                 $734 = $703;
                } else {
                 $$01$i53 = $40;$728 = $1018;
                 while(1) {
                  ;HEAP32[$728+0>>2]=HEAP32[$$01$i53+0>>2]|0;HEAP32[$728+4>>2]=HEAP32[$$01$i53+4>>2]|0;HEAP32[$728+8>>2]=HEAP32[$$01$i53+8>>2]|0;
                  $729 = (($$01$i53) + 12|0);
                  $730 = (($728) + ($731)|0);
                  $732 = ($729|0)==($726|0);
                  if ($732) {
                   break;
                  } else {
                   $$01$i53 = $729;$728 = $730;
                  }
                 }
                 $$pre = HEAP32[$702>>2]|0;
                 $734 = $$pre;
                }
                $733 = (($734) + 18|0);
                $735 = HEAP8[$733>>0]|0;
                $736 = ($735<<24>>24)==(2);
                do {
                 if ($736) {
                  $737 = (($734) + 19|0);
                  $738 = HEAP8[$737>>0]|0;
                  $739 = ($738&255)<(4);
                  if ($739) {
                   $1019 = 0;$761 = 0;
                   break;
                  }
                  $740 = (($734) + 92|0);
                  $741 = HEAP32[$740>>2]|0;
                  $742 = ($741|0)==(0|0);
                  if ($742) {
                   $1019 = 0;$761 = 1;
                   break;
                  }
                  $743 = (($734) + 16|0);
                  $744 = HEAP8[$743>>0]|0;
                  $745 = $744&255;
                  $746 = ((($734) + (($745*12)|0)|0) + 50|0);
                  $747 = HEAP8[$746>>0]|0;
                  $748 = $747&255;
                  $749 = ((($734) + (($745*12)|0)|0) + 44|0);
                  $750 = HEAP32[$749>>2]|0;
                  $751 = (($734) + 17|0);
                  $752 = HEAP8[$751>>0]|0;
                  $753 = $752&255;
                  $754 = (($753) + ($750))|0;
                  $755 = (($741) + ($754)|0);
                  $1019 = $755;$761 = $748;
                 } else {
                  $1019 = 0;$761 = 0;
                 }
                } while(0);
                $756 = (($99) + ($vertexCount$0$lcssa<<2)|0);
                if (!($727)) {
                 $$01$i50 = $99;$758 = $1019;
                 while(1) {
                  $757 = HEAP32[$$01$i50>>2]|0;
                  HEAP32[$758>>2] = $757;
                  $759 = (($$01$i50) + 4|0);
                  $760 = (($758) + ($761)|0);
                  $762 = ($759|0)==($756|0);
                  if ($762) {
                   break;
                  } else {
                   $$01$i50 = $759;$758 = $760;
                  }
                 }
                }
                $763 = (($734) + 14|0);
                $764 = HEAP8[$763>>0]|0;
                $765 = ($764<<24>>24)==(0);
                do {
                 if ($765) {
                  $766 = (($734) + 15|0);
                  $767 = HEAP8[$766>>0]|0;
                  $768 = ($767&255)<(3);
                  if ($768) {
                   $1020 = 0;$789 = 0;
                   break;
                  }
                  $769 = (($734) + 92|0);
                  $770 = HEAP32[$769>>2]|0;
                  $771 = ($770|0)==(0|0);
                  if ($771) {
                   $1020 = 0;$789 = 1;
                   break;
                  }
                  $772 = (($734) + 12|0);
                  $773 = HEAP8[$772>>0]|0;
                  $774 = $773&255;
                  $775 = ((($734) + (($774*12)|0)|0) + 50|0);
                  $776 = HEAP8[$775>>0]|0;
                  $777 = $776&255;
                  $778 = ((($734) + (($774*12)|0)|0) + 44|0);
                  $779 = HEAP32[$778>>2]|0;
                  $780 = (($734) + 13|0);
                  $781 = HEAP8[$780>>0]|0;
                  $782 = $781&255;
                  $783 = (($782) + ($779))|0;
                  $784 = (($770) + ($783)|0);
                  $1020 = $784;$789 = $777;
                 } else {
                  $1020 = 0;$789 = 0;
                 }
                } while(0);
                $785 = (($110) + (($vertexCount$0$lcssa*12)|0)|0);
                if ($727) {
                 $792 = $734;
                } else {
                 $$01$i48 = $110;$786 = $1020;
                 while(1) {
                  ;HEAP32[$786+0>>2]=HEAP32[$$01$i48+0>>2]|0;HEAP32[$786+4>>2]=HEAP32[$$01$i48+4>>2]|0;HEAP32[$786+8>>2]=HEAP32[$$01$i48+8>>2]|0;
                  $787 = (($$01$i48) + 12|0);
                  $788 = (($786) + ($789)|0);
                  $790 = ($787|0)==($785|0);
                  if ($790) {
                   break;
                  } else {
                   $$01$i48 = $787;$786 = $788;
                  }
                 }
                 $$pre231 = HEAP32[$702>>2]|0;
                 $792 = $$pre231;
                }
                $791 = (($792) + 22|0);
                $793 = HEAP8[$791>>0]|0;
                $794 = ($793<<24>>24)==(0);
                do {
                 if ($794) {
                  $795 = (($792) + 23|0);
                  $796 = HEAP8[$795>>0]|0;
                  $797 = ($796&255)<(2);
                  if ($797) {
                   $1021 = 0;$828 = 0;
                   break;
                  }
                  $798 = (($792) + 92|0);
                  $799 = HEAP32[$798>>2]|0;
                  $800 = ($799|0)==(0|0);
                  if ($800) {
                   $1021 = 0;$828 = 1;
                   break;
                  }
                  $801 = (($792) + 20|0);
                  $802 = HEAP8[$801>>0]|0;
                  $803 = $802&255;
                  $804 = ((($792) + (($803*12)|0)|0) + 50|0);
                  $805 = HEAP8[$804>>0]|0;
                  $806 = $805&255;
                  $807 = ((($792) + (($803*12)|0)|0) + 44|0);
                  $808 = HEAP32[$807>>2]|0;
                  $809 = (($792) + 21|0);
                  $810 = HEAP8[$809>>0]|0;
                  $811 = $810&255;
                  $812 = (($811) + ($808))|0;
                  $813 = (($799) + ($812)|0);
                  $1021 = $813;$828 = $806;
                 } else {
                  $1021 = 0;$828 = 0;
                 }
                } while(0);
                $814 = (($431) + ($vertexCount$0$lcssa<<3)|0);
                if ($727) {
                 $831 = $792;
                } else {
                 $$01$i43 = $431;$822 = $1021;
                 while(1) {
                  $815 = $$01$i43;
                  $816 = $815;
                  $817 = HEAP32[$816>>2]|0;
                  $818 = (($815) + 4)|0;
                  $819 = $818;
                  $820 = HEAP32[$819>>2]|0;
                  $821 = $822;
                  $823 = $821;
                  HEAP32[$823>>2] = $817;
                  $824 = (($821) + 4)|0;
                  $825 = $824;
                  HEAP32[$825>>2] = $820;
                  $826 = (($$01$i43) + 8|0);
                  $827 = (($822) + ($828)|0);
                  $829 = ($826|0)==($814|0);
                  if ($829) {
                   break;
                  } else {
                   $$01$i43 = $826;$822 = $827;
                  }
                 }
                 $$pre232 = HEAP32[$702>>2]|0;
                 $831 = $$pre232;
                }
                $830 = (($831) + 26|0);
                $832 = HEAP8[$830>>0]|0;
                $833 = ($832<<24>>24)==(0);
                do {
                 if ($833) {
                  $834 = (($831) + 27|0);
                  $835 = HEAP8[$834>>0]|0;
                  $836 = ($835&255)<(2);
                  if ($836) {
                   $1022 = 0;$867 = 0;
                   break;
                  }
                  $837 = (($831) + 92|0);
                  $838 = HEAP32[$837>>2]|0;
                  $839 = ($838|0)==(0|0);
                  if ($839) {
                   $1022 = 0;$867 = 1;
                   break;
                  }
                  $840 = (($831) + 24|0);
                  $841 = HEAP8[$840>>0]|0;
                  $842 = $841&255;
                  $843 = ((($831) + (($842*12)|0)|0) + 50|0);
                  $844 = HEAP8[$843>>0]|0;
                  $845 = $844&255;
                  $846 = ((($831) + (($842*12)|0)|0) + 44|0);
                  $847 = HEAP32[$846>>2]|0;
                  $848 = (($831) + 25|0);
                  $849 = HEAP8[$848>>0]|0;
                  $850 = $849&255;
                  $851 = (($850) + ($847))|0;
                  $852 = (($838) + ($851)|0);
                  $1022 = $852;$867 = $845;
                 } else {
                  $1022 = 0;$867 = 0;
                 }
                } while(0);
                $853 = (($69) + ($vertexCount$0$lcssa<<3)|0);
                if (!($727)) {
                 $$01$i40 = $69;$861 = $1022;
                 while(1) {
                  $854 = $$01$i40;
                  $855 = $854;
                  $856 = HEAP32[$855>>2]|0;
                  $857 = (($854) + 4)|0;
                  $858 = $857;
                  $859 = HEAP32[$858>>2]|0;
                  $860 = $861;
                  $862 = $860;
                  HEAP32[$862>>2] = $856;
                  $863 = (($860) + 4)|0;
                  $864 = $863;
                  HEAP32[$864>>2] = $859;
                  $865 = (($$01$i40) + 8|0);
                  $866 = (($861) + ($867)|0);
                  $868 = ($865|0)==($853|0);
                  if ($868) {
                   break;
                  } else {
                   $$01$i40 = $865;$861 = $866;
                  }
                 }
                }
                do {
                 if ($70) {
                  $869 = HEAP32[$702>>2]|0;
                  $870 = (($869) + 38|0);
                  $871 = HEAP8[$870>>0]|0;
                  $872 = ($871<<24>>24)==(0);
                  do {
                   if ($872) {
                    $873 = (($869) + 39|0);
                    $874 = HEAP8[$873>>0]|0;
                    $875 = ($874&255)<(4);
                    if ($875) {
                     $1023 = 0;$896 = 0;
                     break;
                    }
                    $876 = (($869) + 92|0);
                    $877 = HEAP32[$876>>2]|0;
                    $878 = ($877|0)==(0|0);
                    if ($878) {
                     $1023 = 0;$896 = 1;
                     break;
                    }
                    $879 = (($869) + 36|0);
                    $880 = HEAP8[$879>>0]|0;
                    $881 = $880&255;
                    $882 = ((($869) + (($881*12)|0)|0) + 50|0);
                    $883 = HEAP8[$882>>0]|0;
                    $884 = $883&255;
                    $885 = ((($869) + (($881*12)|0)|0) + 44|0);
                    $886 = HEAP32[$885>>2]|0;
                    $887 = (($869) + 37|0);
                    $888 = HEAP8[$887>>0]|0;
                    $889 = $888&255;
                    $890 = (($889) + ($886))|0;
                    $891 = (($877) + ($890)|0);
                    $1023 = $891;$896 = $884;
                   } else {
                    $1023 = 0;$896 = 0;
                   }
                  } while(0);
                  $892 = (($85) + ($vertexCount$0$lcssa<<4)|0);
                  if ($727) {
                   break;
                  } else {
                   $$01$i = $85;$893 = $1023;
                  }
                  while(1) {
                   ;HEAP32[$893+0>>2]=HEAP32[$$01$i+0>>2]|0;HEAP32[$893+4>>2]=HEAP32[$$01$i+4>>2]|0;HEAP32[$893+8>>2]=HEAP32[$$01$i+8>>2]|0;HEAP32[$893+12>>2]=HEAP32[$$01$i+12>>2]|0;
                   $894 = (($$01$i) + 16|0);
                   $895 = (($893) + ($896)|0);
                   $897 = ($894|0)==($892|0);
                   if ($897) {
                    break;
                   } else {
                    $$01$i = $894;$893 = $895;
                   }
                  }
                 }
                } while(0);
                __THREW__ = 0;
                (invoke_iiiiiii(122,($mesh|0),($134|0),($triangleCount$0$lcssa|0),0,0,1)|0);
                $898 = __THREW__; __THREW__ = 0;
                $899 = $898&1;
                if ($899) {
                 break;
                }
                $900 = HEAP32[$702>>2]|0;
                $901 = (($900) + 96|0);
                $902 = HEAP32[$901>>2]|0;
                __THREW__ = 0;
                invoke_viii(2026,($mesh|0),($902|0),1);
                $903 = __THREW__; __THREW__ = 0;
                $904 = $903&1;
                if ($904) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3707,($mesh|0));
                $905 = __THREW__; __THREW__ = 0;
                $906 = $905&1;
                if ($906) {
                 break;
                }
                if ($70) {
                 $907 = (($mesh) + 168|0);
                 ;HEAP32[$aabb$i+0>>2]=HEAP32[$907+0>>2]|0;HEAP32[$aabb$i+4>>2]=HEAP32[$907+4>>2]|0;HEAP32[$aabb$i+8>>2]=HEAP32[$907+8>>2]|0;HEAP32[$aabb$i+12>>2]=HEAP32[$907+12>>2]|0;HEAP32[$aabb$i+16>>2]=HEAP32[$907+16>>2]|0;HEAP32[$aabb$i+20>>2]=HEAP32[$907+20>>2]|0;
                 $908 = $$lcssa207 < $$lcssa209;
                 $909 = $908 ? $$lcssa209 : $$lcssa207;
                 $910 = Math_fround($$lcssa209 * Math_fround(0.5));
                 $911 = (($aabb$i) + 12|0);
                 $912 = Math_fround(HEAPF32[$911>>2]);
                 $913 = Math_fround($909 + $912);
                 HEAPF32[$911>>2] = $913;
                 $914 = (($aabb$i) + 16|0);
                 $915 = Math_fround(HEAPF32[$914>>2]);
                 $916 = Math_fround($910 + $915);
                 HEAPF32[$914>>2] = $916;
                 $917 = (($aabb$i) + 20|0);
                 $918 = Math_fround(HEAPF32[$917>>2]);
                 $919 = Math_fround($909 + $918);
                 HEAPF32[$917>>2] = $919;
                 $920 = Math_fround(HEAPF32[$aabb$i>>2]);
                 $921 = Math_fround($920 + Math_fround(0.0));
                 HEAPF32[$aabb$i>>2] = $921;
                 $922 = (($aabb$i) + 4|0);
                 $923 = Math_fround(HEAPF32[$922>>2]);
                 $924 = Math_fround($910 + $923);
                 HEAPF32[$922>>2] = $924;
                 $925 = (($aabb$i) + 8|0);
                 $926 = Math_fround(HEAPF32[$925>>2]);
                 $927 = Math_fround($926 + Math_fround(0.0));
                 HEAPF32[$925>>2] = $927;
                 __THREW__ = 0;
                 invoke_vii(3411,($mesh|0),($aabb$i|0));
                 $928 = __THREW__; __THREW__ = 0;
                 $929 = $928&1;
                 if ($929) {
                  break;
                 }
                }
                $930 = ($127|0)==(0|0);
                if (!($930)) {
                 $931 = HEAP32[628512>>2]|0;
                 HEAP32[$1>>2] = $931;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$1+0>>2]|0;
                 invoke_vii(2591,($127|0),($$byval_copy25|0));
                 $932 = __THREW__; __THREW__ = 0;
                 $933 = $932&1;
                 if ($933) {
                  $1001 = $935;
                  label = 32;
                  break L35;
                 }
                }
                $934 = ($935|0)==(0|0);
                if (!($934)) {
                 $936 = HEAP32[628512>>2]|0;
                 HEAP32[$2>>2] = $936;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$2+0>>2]|0;
                 invoke_vii(2591,($935|0),($$byval_copy25|0));
                 $937 = __THREW__; __THREW__ = 0;
                 $938 = $937&1;
                 if ($938) {
                  $1000 = $940;
                  label = 26;
                  break L28;
                 }
                }
                $939 = ($940|0)==(0|0);
                if (!($939)) {
                 $941 = HEAP32[628512>>2]|0;
                 HEAP32[$3>>2] = $941;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$3+0>>2]|0;
                 invoke_vii(2591,($940|0),($$byval_copy25|0));
                 $942 = __THREW__; __THREW__ = 0;
                 $943 = $942&1;
                 if ($943) {
                  $999 = $945;
                  label = 20;
                  break L21;
                 }
                }
                $944 = ($945|0)==(0|0);
                if (!($944)) {
                 $946 = HEAP32[628512>>2]|0;
                 HEAP32[$4>>2] = $946;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$4+0>>2]|0;
                 invoke_vii(2591,($945|0),($$byval_copy25|0));
                 $947 = __THREW__; __THREW__ = 0;
                 $948 = $947&1;
                 if ($948) {
                  $996 = $955;$997 = $950;
                  label = 14;
                  break L14;
                 }
                }
                $949 = ($950|0)==(0|0);
                if (!($949)) {
                 $951 = HEAP32[628512>>2]|0;
                 HEAP32[$5>>2] = $951;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$5+0>>2]|0;
                 invoke_vii(2591,($950|0),($$byval_copy25|0));
                 $952 = __THREW__; __THREW__ = 0;
                 $953 = $952&1;
                 if ($953) {
                  $995 = $955;
                  label = 11;
                  break L14;
                 }
                }
                $954 = ($955|0)==(0|0);
                if (!($954)) {
                 $956 = HEAP32[628512>>2]|0;
                 HEAP32[$6>>2] = $956;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$6+0>>2]|0;
                 invoke_vii(2591,($955|0),($$byval_copy25|0));
                 $957 = __THREW__; __THREW__ = 0;
                 $958 = $957&1;
                 if ($958) {
                  $994 = $960;
                  label = 6;
                  break L6;
                 }
                }
                $959 = ($960|0)==(0|0);
                if ($959) {
                 STACKTOP = sp;return;
                }
                $961 = HEAP32[628512>>2]|0;
                HEAP32[$0>>2] = $961;
                ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$0+0>>2]|0;
                __Z19free_alloc_internalPv10MemLabelId($960,$$byval_copy25);
                STACKTOP = sp;return;
               }
              }
             } while(0);
             $124 = ___cxa_find_matching_catch()|0;
             $125 = tempRet0;
             $lpad$phi$index = $124;$lpad$phi$index2 = $125;
            }
            $126 = ($127|0)==(0|0);
            if ($126) {
             $1002 = $0;$1003 = $lpad$phi$index2;$1004 = $lpad$phi$index;
            } else {
             $128 = HEAP32[628512>>2]|0;
             HEAP32[$0>>2] = $128;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$0+0>>2]|0;
             invoke_vii(2591,($127|0),($$byval_copy25|0));
             $129 = __THREW__; __THREW__ = 0;
             $130 = $129&1;
             if ($130) {
              $992 = ___cxa_find_matching_catch(0|0)|0;
              $993 = tempRet0;
              ___clang_call_terminate($992);
              // unreachable;
             } else {
              $1002 = $0;$1003 = $lpad$phi$index2;$1004 = $lpad$phi$index;
             }
            }
           }
           $$0 = $1004;$$01 = $1003;$963 = $935;
          }
         } while(0);
         if ((label|0) == 32) {
          $105 = ___cxa_find_matching_catch()|0;
          $106 = tempRet0;
          $$0 = $105;$$01 = $106;$963 = $1001;
         }
         $962 = ($963|0)==(0|0);
         if ($962) {
          $$1 = $$0;$$12 = $$01;$968 = $940;
         } else {
          $964 = HEAP32[628512>>2]|0;
          HEAP32[$7>>2] = $964;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$7+0>>2]|0;
          invoke_vii(2591,($963|0),($$byval_copy25|0));
          $965 = __THREW__; __THREW__ = 0;
          $966 = $965&1;
          if ($966) {
           $992 = ___cxa_find_matching_catch(0|0)|0;
           $993 = tempRet0;
           ___clang_call_terminate($992);
           // unreachable;
          } else {
           $$1 = $$0;$$12 = $$01;$968 = $940;
          }
         }
        }
       } while(0);
       if ((label|0) == 26) {
        $94 = ___cxa_find_matching_catch()|0;
        $95 = tempRet0;
        $$1 = $94;$$12 = $95;$968 = $1000;
       }
       $967 = ($968|0)==(0|0);
       if ($967) {
        $$2 = $$1;$$23 = $$12;$973 = $945;
       } else {
        $969 = HEAP32[628512>>2]|0;
        HEAP32[$8>>2] = $969;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$8+0>>2]|0;
        invoke_vii(2591,($968|0),($$byval_copy25|0));
        $970 = __THREW__; __THREW__ = 0;
        $971 = $970&1;
        if ($971) {
         $992 = ___cxa_find_matching_catch(0|0)|0;
         $993 = tempRet0;
         ___clang_call_terminate($992);
         // unreachable;
        } else {
         $$2 = $$1;$$23 = $$12;$973 = $945;
        }
       }
      }
     } while(0);
     if ((label|0) == 20) {
      $80 = ___cxa_find_matching_catch()|0;
      $81 = tempRet0;
      $$2 = $80;$$23 = $81;$973 = $999;
     }
     $972 = ($973|0)==(0|0);
     if ($972) {
      $$3 = $$2;$$34 = $$23;$978 = $950;$998 = $955;
      label = 162;
     } else {
      $974 = HEAP32[628512>>2]|0;
      HEAP32[$9>>2] = $974;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$9+0>>2]|0;
      invoke_vii(2591,($973|0),($$byval_copy25|0));
      $975 = __THREW__; __THREW__ = 0;
      $976 = $975&1;
      if ($976) {
       $992 = ___cxa_find_matching_catch(0|0)|0;
       $993 = tempRet0;
       ___clang_call_terminate($992);
       // unreachable;
      } else {
       $$3 = $$2;$$34 = $$23;$978 = $950;$998 = $955;
       label = 162;
      }
     }
    }
   } while(0);
   if ((label|0) == 11) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    $$4 = $48;$$45 = $49;$983 = $995;
   }
   else if ((label|0) == 14) {
    $64 = ___cxa_find_matching_catch()|0;
    $65 = tempRet0;
    $$3 = $64;$$34 = $65;$978 = $997;$998 = $996;
    label = 162;
   }
   if ((label|0) == 162) {
    $977 = ($978|0)==(0|0);
    if ($977) {
     $$4 = $$3;$$45 = $$34;$983 = $998;
    } else {
     $979 = HEAP32[628512>>2]|0;
     HEAP32[$10>>2] = $979;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$10+0>>2]|0;
     invoke_vii(2591,($978|0),($$byval_copy25|0));
     $980 = __THREW__; __THREW__ = 0;
     $981 = $980&1;
     if ($981) {
      $992 = ___cxa_find_matching_catch(0|0)|0;
      $993 = tempRet0;
      ___clang_call_terminate($992);
      // unreachable;
     } else {
      $$4 = $$3;$$45 = $$34;$983 = $998;
     }
    }
   }
   $982 = ($983|0)==(0|0);
   if ($982) {
    $$5 = $$4;$$56 = $$45;$988 = $960;
   } else {
    $984 = HEAP32[628512>>2]|0;
    HEAP32[$11>>2] = $984;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$11+0>>2]|0;
    invoke_vii(2591,($983|0),($$byval_copy25|0));
    $985 = __THREW__; __THREW__ = 0;
    $986 = $985&1;
    if ($986) {
     $992 = ___cxa_find_matching_catch(0|0)|0;
     $993 = tempRet0;
     ___clang_call_terminate($992);
     // unreachable;
    } else {
     $$5 = $$4;$$56 = $$45;$988 = $960;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  $$5 = $35;$$56 = $36;$988 = $994;
 }
 $987 = ($988|0)==(0|0);
 if ($987) {
  ___resumeException($$5|0);
  // unreachable;
 }
 $989 = HEAP32[628512>>2]|0;
 HEAP32[$12>>2] = $989;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy25+0>>2]=HEAP32[$12+0>>2]|0;
 invoke_vii(2591,($988|0),($$byval_copy25|0));
 $990 = __THREW__; __THREW__ = 0;
 $991 = $990&1;
 if ($991) {
  $992 = ___cxa_find_matching_catch(0|0)|0;
  $993 = tempRet0;
  ___clang_call_terminate($992);
  // unreachable;
 } else {
  ___resumeException($$5|0);
  // unreachable;
 }
}
function __ZN14DetailDatabase29UpdateDetailPrototypesIfDirtyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __ZN14DetailDatabase17RefreshPrototypesEv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8Vector3fNS_9allocatorIS1_EEE8__appendEjRKS1_($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    ;HEAP32[$10+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$__x+8>>2]|0;
    $$pre1$i = HEAP32[$2>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 12|0);
   HEAP32[$2>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($5) - ($16))|0;
 $18 = (($17|0) / 12)&-1;
 $19 = (($18) + ($__n))|0;
 $20 = ($19>>>0)>(357913941);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($4) - ($16))|0;
 $22 = (($21|0) / 12)&-1;
 $23 = ($22>>>0)<(178956970);
 if ($23) {
  $24 = $22 << 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i57 = 0;$31 = 0;
  } else {
   $$0$i56 = $26;
   label = 10;
  }
 } else {
  $$0$i56 = 357913941;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = ($$0$i56*12)|0;
  $29 = (__Znwj($28)|0);
  $$0$i57 = $$0$i56;$31 = $29;
 }
 $30 = (($31) + (($18*12)|0)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if ($32) {
   $35 = 0;
  } else {
   ;HEAP32[$33+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$__x+8>>2]|0;
   $35 = $33;
  }
  $34 = (($35) + 12|0);
  $36 = (($$0$i2) + -1)|0;
  $37 = ($36|0)==(0);
  if ($37) {
   break;
  } else {
   $$0$i2 = $36;$33 = $34;
  }
 }
 $38 = (($31) + (($$0$i57*12)|0)|0);
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$2>>2]|0;
 $41 = $40;
 $42 = $39;
 $43 = (($41) - ($42))|0;
 $44 = (($43|0) / -12)&-1;
 $$sum = (($44) + ($18))|0;
 $45 = (($31) + (($$sum*12)|0)|0);
 _memcpy(($45|0),($39|0),($43|0))|0;
 HEAP32[$this>>2] = $45;
 HEAP32[$2>>2] = $34;
 HEAP32[$0>>2] = $38;
 $46 = ($39|0)==(0|0);
 if ($46) {
  STACKTOP = sp;return;
 }
 __ZdlPv($39);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI11ColorRGBA32NS_9allocatorIS1_EEE8__appendEjRKS1_($this,$__n,$__x) {
 $this = $this|0;
 $__n = $__n|0;
 $__x = $__x|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $13 = 0;
   } else {
    $11 = HEAP32[$__x>>2]|0;
    HEAP32[$10>>2] = $11;
    $$pre1$i = HEAP32[$2>>2]|0;
    $13 = $$pre1$i;
   }
   $12 = (($13) + 4|0);
   HEAP32[$2>>2] = $12;
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$10 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($5) - ($17))|0;
 $19 = $18 >> 2;
 $20 = (($19) + ($__n))|0;
 $21 = ($20>>>0)>(1073741823);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($4) - ($17))|0;
 $23 = $22 >> 2;
 $24 = ($23>>>0)<(536870911);
 if ($24) {
  $25 = $22 >> 1;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i57 = 0;$32 = 0;
  } else {
   $$0$i56 = $27;
   label = 10;
  }
 } else {
  $$0$i56 = 1073741823;
  label = 10;
 }
 if ((label|0) == 10) {
  $29 = $$0$i56 << 2;
  $30 = (__Znwj($29)|0);
  $$0$i57 = $$0$i56;$32 = $30;
 }
 $31 = (($32) + ($19<<2)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if ($33) {
   $37 = 0;
  } else {
   $35 = HEAP32[$__x>>2]|0;
   HEAP32[$34>>2] = $35;
   $37 = $34;
  }
  $36 = (($37) + 4|0);
  $38 = (($$0$i2) + -1)|0;
  $39 = ($38|0)==(0);
  if ($39) {
   break;
  } else {
   $$0$i2 = $38;$34 = $36;
  }
 }
 $40 = (($32) + ($$0$i57<<2)|0);
 $41 = HEAP32[$this>>2]|0;
 $42 = HEAP32[$2>>2]|0;
 $43 = $42;
 $44 = $41;
 $45 = (($43) - ($44))|0;
 $46 = $45 >> 2;
 $$sum = (($19) - ($46))|0;
 $47 = (($32) + ($$sum<<2)|0);
 _memcpy(($47|0),($41|0),($45|0))|0;
 HEAP32[$this>>2] = $47;
 HEAP32[$2>>2] = $36;
 HEAP32[$0>>2] = $40;
 $48 = ($41|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 __ZdlPv($41);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI11ColorRGBA32NS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i4 = 0, $$0$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0, $scevgep$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $scevgep$i = (($3) + ($__n<<2)|0);
  HEAP32[$2>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$this>>2]|0;
 $10 = $9;
 $11 = (($5) - ($10))|0;
 $12 = $11 >> 2;
 $13 = (($12) + ($__n))|0;
 $14 = ($13>>>0)>(1073741823);
 if ($14) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $15 = (($4) - ($10))|0;
 $16 = $15 >> 2;
 $17 = ($16>>>0)<(536870911);
 if ($17) {
  $18 = $15 >> 1;
  $19 = ($18>>>0)<($13>>>0);
  $20 = $19 ? $13 : $18;
  $21 = ($20|0)==(0);
  if ($21) {
   $$0$i5 = 0;$25 = 0;
  } else {
   $$0$i4 = $20;
   label = 7;
  }
 } else {
  $$0$i4 = 1073741823;
  label = 7;
 }
 if ((label|0) == 7) {
  $22 = $$0$i4 << 2;
  $23 = (__Znwj($22)|0);
  $$0$i5 = $$0$i4;$25 = $23;
 }
 $24 = (($25) + ($$0$i5<<2)|0);
 $scevgep$i2 = (($25) + ($13<<2)|0);
 _memcpy(($25|0),($9|0),($11|0))|0;
 HEAP32[$this>>2] = $25;
 HEAP32[$2>>2] = $scevgep$i2;
 HEAP32[$0>>2] = $24;
 $26 = ($9|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 __ZdlPv($9);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a19751() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799264);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[799256>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN14DetailRendererC2E4PPtrI11TerrainDataE8Vector3fi($this,$terrain,$position,$lightmapIndex) {
 $this = $this|0;
 $terrain = $terrain|0;
 $position = $position|0;
 $lightmapIndex = $lightmapIndex|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $__p$0$i$i$i = 0, $i$018 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $shader$0 = 0, $shaderNotFound$0$off017 = 0, $shaderNotFound$1$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 28|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = sp + 24|0;
 $3 = (($this) + 12|0);
 $4 = (($this) + 36|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 40|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 36|0);
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 48|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 52|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 48|0);
 $11 = (($this) + 44|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 60|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 64|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 60|0);
 $15 = (($this) + 56|0);
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 68|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($this) + 72|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($this) + 76|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = HEAP32[$terrain>>2]|0;
 HEAP32[$3>>2] = $19;
 ;HEAP32[$16+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$position+8>>2]|0;
 $20 = (($this) + 28|0);
 HEAP32[$20>>2] = $lightmapIndex;
 __THREW__ = 0;
 $21 = (invoke_i(80)|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 do {
  if ($23) {
   label = 18;
  } else {
   $24 = (($0) + 1|0);
   $25 = (($1) + 1|0);
   $26 = (($1) + 8|0);
   $27 = (($0) + 8|0);
   $28 = (($0) + 4|0);
   $i$018 = 0;$shaderNotFound$0$off017 = 0;
   while(1) {
    $29 = (800112 + ($i$018<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (_strlen(($30|0))|0);
    $32 = ($31>>>0)>(4294967279);
    if ($32) {
     label = 4;
     break;
    }
    $35 = ($31>>>0)<(11);
    if ($35) {
     $36 = $31 << 1;
     $37 = $36&255;
     HEAP8[$0>>0] = $37;
     $__p$0$i$i$i = $24;
    } else {
     $38 = (($31) + 16)|0;
     $39 = $38 & -16;
     __THREW__ = 0;
     $40 = (invoke_ii(2988,($39|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 17;
      break;
     }
     HEAP32[$27>>2] = $40;
     $43 = $39 | 1;
     HEAP32[$0>>2] = $43;
     HEAP32[$28>>2] = $31;
     $__p$0$i$i$i = $40;
    }
    _memcpy(($__p$0$i$i$i|0),($30|0),($31|0))|0;
    $44 = (($__p$0$i$i$i) + ($31)|0);
    HEAP8[$44>>0] = 0;
    __THREW__ = 0;
    $45 = (invoke_iii(2366,($21|0),($0|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 20;
     break;
    }
    $48 = HEAP8[$0>>0]|0;
    $49 = $48 & 1;
    $50 = ($49<<24>>24)==(0);
    if (!($50)) {
     $51 = HEAP32[$27>>2]|0;
     __ZdlPv($51);
    }
    $52 = ($45|0)==(0|0);
    if ($52) {
     HEAP8[$1>>0] = 14;
     ;HEAP8[$25+0>>0]=HEAP8[800128+0>>0]|0;HEAP8[$25+1>>0]=HEAP8[800128+1>>0]|0;HEAP8[$25+2>>0]=HEAP8[800128+2>>0]|0;HEAP8[$25+3>>0]=HEAP8[800128+3>>0]|0;HEAP8[$25+4>>0]=HEAP8[800128+4>>0]|0;HEAP8[$25+5>>0]=HEAP8[800128+5>>0]|0;HEAP8[$25+6>>0]=HEAP8[800128+6>>0]|0;
     HEAP8[$26>>0] = 0;
     __THREW__ = 0;
     $53 = (invoke_iii(2366,($21|0),($1|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      label = 22;
      break;
     }
     $56 = HEAP8[$1>>0]|0;
     $57 = $56 & 1;
     $58 = ($57<<24>>24)==(0);
     if ($58) {
      $shader$0 = $53;$shaderNotFound$1$off0 = 1;
     } else {
      $59 = HEAP32[$26>>2]|0;
      __ZdlPv($59);
      $shader$0 = $53;$shaderNotFound$1$off0 = 1;
     }
    } else {
     $shader$0 = $45;$shaderNotFound$1$off0 = $shaderNotFound$0$off017;
    }
    __THREW__ = 0;
    $76 = (invoke_iiii(1539,($shader$0|0),61,0)|0);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     label = 17;
     break;
    }
    $79 = (($this) + ($i$018<<2)|0);
    HEAP32[$79>>2] = $76;
    $80 = HEAP32[799776>>2]|0;
    HEAP32[$2>>2] = $80;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viif(47,($76|0),($$byval_copy|0),0.375);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     label = 17;
     break;
    }
    $83 = (($i$018) + 1)|0;
    $84 = ($83|0)<(3);
    if ($84) {
     $i$018 = $83;$shaderNotFound$0$off017 = $shaderNotFound$1$off0;
    } else {
     label = 27;
     break;
    }
   }
   if ((label|0) == 4) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     label = 18;
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 17) {
    $60 = ___cxa_find_matching_catch()|0;
    $61 = tempRet0;
    $lpad$phi$index = $60;$lpad$phi$index2 = $61;
    label = 19;
    break;
   }
   else if ((label|0) == 20) {
    $64 = ___cxa_find_matching_catch()|0;
    $65 = tempRet0;
    $66 = HEAP8[$0>>0]|0;
    $67 = $66 & 1;
    $68 = ($67<<24>>24)==(0);
    if ($68) {
     $$0 = $64;$$01 = $65;
     break;
    }
    $69 = HEAP32[$27>>2]|0;
    __ZdlPv($69);
    $$0 = $64;$$01 = $65;
    break;
   }
   else if ((label|0) == 22) {
    $70 = ___cxa_find_matching_catch()|0;
    $71 = tempRet0;
    $72 = HEAP8[$1>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    if ($74) {
     $$0 = $70;$$01 = $71;
     break;
    }
    $75 = HEAP32[$26>>2]|0;
    __ZdlPv($75);
    $$0 = $70;$$01 = $71;
    break;
   }
   else if ((label|0) == 27) {
    if (!($shaderNotFound$1$off0)) {
     $87 = (($this) + 80|0);
     HEAP32[$87>>2] = 0;
     $88 = (($this) + 84|0);
     HEAPF32[$88>>2] = Math_fround(0.0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,(800136|0),0,(800256|0),60,1,0,0,(0|0));
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     label = 18;
     break;
    }
    $87 = (($this) + 80|0);
    HEAP32[$87>>2] = 0;
    $88 = (($this) + 84|0);
    HEAPF32[$88>>2] = Math_fround(0.0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $62 = ___cxa_find_matching_catch()|0;
  $63 = tempRet0;
  $lpad$phi$index = $62;$lpad$phi$index2 = $63;
  label = 19;
 }
 if ((label|0) == 19) {
  $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
 }
 $89 = (($this) + 56|0);
 $90 = (($this) + 60|0);
 $91 = HEAP32[$90>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($89,$91);
 $92 = (($this) + 44|0);
 $93 = (($this) + 48|0);
 $94 = HEAP32[$93>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($92,$94);
 $95 = (($this) + 32|0);
 $96 = (($this) + 36|0);
 $97 = HEAP32[$96>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($95,$97);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN14DetailRenderer15GrabCachedPatchEii16DetailRenderModef($this,$x,$y,$mode,$density) {
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $mode = $mode|0;
 $density = Math_fround($density);
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $index = 0, $temp$0$i = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $index = sp + 8|0;
 $2 = ((($this) + (($mode*12)|0)|0) + 32|0);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$1>>2] = $4;
 $5 = HEAP32[560624>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 9;
 } else {
  $7 = (($5) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==($10|0);
  do {
   if ($11) {
    $12 = (($5) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($5) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($13) + ($15<<3)|0);
    $32 = $16;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$5,$1);
    $17 = HEAP32[$$byval_copy>>2]|0;
    $18 = ($17|0)==(-1);
    $19 = (($5) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    if ($18) {
     $21 = (($5) + 32|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + ($22<<3)|0);
     $32 = $23;
     break;
    } else {
     $24 = (($20) + ($17<<3)|0);
     $32 = $24;
     break;
    }
   }
  } while(0);
  $25 = HEAP32[560624>>2]|0;
  $26 = (($25) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 32|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + ($29<<3)|0);
  $31 = ($32|0)==($30|0);
  if ($31) {
   label = 9;
  } else {
   $33 = (($32) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if ($35) {
    label = 9;
   } else {
    $temp$0$i = $34;
   }
  }
 }
 if ((label|0) == 9) {
  $36 = HEAP32[$3>>2]|0;
  $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
  $temp$0$i = $37;
 }
 $38 = (($temp$0$i) + 112|0);
 $39 = (($38) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = Math_imul($40, $y)|0;
 $42 = (($41) + ($x))|0;
 HEAP32[$index>>2] = $42;
 $43 = (__ZNSt3__13mapIj17DetailPatchRenderNS_4lessIjEE11memory_poolINS_4pairIKjS1_EEEEixERS6_($2,$index)|0);
 $44 = (($43) + 6|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = ($45<<24>>24)==(0);
 if (!($46)) {
  $89 = (($this) + 80|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($43) + 8|0);
  HEAP32[$91>>2] = $90;
  STACKTOP = sp;return ($43|0);
 }
 $47 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $47;
 $48 = HEAP32[560624>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  label = 19;
 } else {
  $50 = (($48) + 36|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($48) + 4|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($51|0)==($53|0);
  do {
   if ($54) {
    $55 = (($48) + 28|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($48) + 32|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($56) + ($58<<3)|0);
    $75 = $59;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$48,$0);
    $60 = HEAP32[$$byval_copy>>2]|0;
    $61 = ($60|0)==(-1);
    $62 = (($48) + 28|0);
    $63 = HEAP32[$62>>2]|0;
    if ($61) {
     $64 = (($48) + 32|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = (($63) + ($65<<3)|0);
     $75 = $66;
     break;
    } else {
     $67 = (($63) + ($60<<3)|0);
     $75 = $67;
     break;
    }
   }
  } while(0);
  $68 = HEAP32[560624>>2]|0;
  $69 = (($68) + 28|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($68) + 32|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($70) + ($72<<3)|0);
  $74 = ($75|0)==($73|0);
  if ($74) {
   label = 19;
  } else {
   $76 = (($75) + 4|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if ($78) {
    label = 19;
   } else {
    $temp$0$i5 = $77;
   }
  }
 }
 if ((label|0) == 19) {
  $79 = HEAP32[$3>>2]|0;
  $80 = (__Z31ReadObjectFromPersistentManageri($79)|0);
  $temp$0$i5 = $80;
 }
 $81 = (($temp$0$i5) + 112|0);
 $82 = (($this) + 16|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$82+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$82+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$82+8>>2]|0;
 $83 = (__ZN14DetailDatabase9BuildMeshEii8Vector3f16DetailRenderModef($81,$x,$y,$$byval_copy,$mode,$density)|0);
 HEAP32[$43>>2] = $83;
 $84 = ($83|0)==(0|0);
 $85 = (($43) + 5|0);
 $86 = $84&1;
 HEAP8[$85>>0] = $86;
 $87 = (($43) + 12|0);
 HEAP32[$87>>2] = $x;
 $88 = (($43) + 16|0);
 HEAP32[$88>>2] = $y;
 HEAP8[$44>>0] = 1;
 $89 = (($this) + 80|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = (($43) + 8|0);
 HEAP32[$91>>2] = $90;
 STACKTOP = sp;return ($43|0);
}
function __ZNSt3__13mapIj17DetailPatchRenderNS_4lessIjEE11memory_poolINS_4pairIKjS1_EEEEixERS6_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp + 12|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $14 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $14;
   $$0$i = $14;$20 = $14;
  } else {
   $4 = HEAP32[$__k>>2]|0;
   $__nd$0$in$i = $2;
   while(1) {
    $5 = (($__nd$0$in$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4>>>0)<($6>>>0);
    if ($7) {
     $8 = HEAP32[$__nd$0$in$i>>2]|0;
     $9 = ($8|0)==(0|0);
     if ($9) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $8;
      continue;
     }
    }
    $10 = ($6>>>0)<($4>>>0);
    if (!($10)) {
     label = 9;
     break;
    }
    $11 = (($__nd$0$in$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $12;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $11;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $15 = HEAP32[$$0$i>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $__r$0 = $15;
  $29 = (($__r$0) + 20|0);
  STACKTOP = sp;return ($29|0);
 }
 __ZNSt3__13mapIj17DetailPatchRenderNS_4lessIjEE11memory_poolINS_4pairIKjS1_EEEE25__construct_node_with_keyERS6_($0,$this,$__k);
 $17 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$17>>2] = 0;
 $18 = (($17) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $17;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $17;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $__r$0 = $17;
 $29 = (($__r$0) + 20|0);
 STACKTOP = sp;return ($29|0);
}
function __ZN14DetailRenderer6RenderEP6Camerafif($this,$camera,$viewDistance,$layer,$detailDensity) {
 $this = $this|0;
 $camera = $camera|0;
 $viewDistance = Math_fround($viewDistance);
 $layer = $layer|0;
 $detailDensity = Math_fround($detailDensity);
 var $$ = 0, $$$ = 0, $$$2 = 0, $$$i = Math_fround(0), $$0$i = Math_fround(0), $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i14 = 0, $$0$i$i$i$i18 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i16 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $$byval_copy32 = 0, $$idx = 0, $$idx53 = 0, $$pre$i = 0, $$pre$i36 = 0, $$sink$i$i = Math_fround(0);
 var $$sink$i$i25 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0), $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0);
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0);
 var $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0);
 var $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0);
 var $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0;
 var $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = Math_fround(0), $496 = 0, $497 = Math_fround(0), $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = Math_fround(0), $516 = 0, $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = 0, $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = Math_fround(0), $536 = 0, $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = Math_fround(0), $542 = Math_fround(0), $543 = Math_fround(0), $544 = Math_fround(0), $545 = Math_fround(0), $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = Math_fround(0), $558 = Math_fround(0), $559 = Math_fround(0), $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = Math_fround(0), $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0);
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = Math_fround(0), $58 = 0, $580 = Math_fround(0), $581 = Math_fround(0), $582 = 0, $583 = Math_fround(0);
 var $584 = Math_fround(0), $585 = Math_fround(0), $586 = 0, $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0), $59 = 0, $590 = Math_fround(0), $591 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bounds = 0, $ceilf$i = Math_fround(0), $ceilf$i27 = Math_fround(0), $color = 0, $eh$lpad$body$indexZ2D = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0;
 var $matrix = 0, $maxy$0 = 0, $miny$0 = 0, $planes = 0, $position = 0, $prop = 0, $props = 0, $r$066 = 0, $r4$056 = 0, $storemerge = 0, $temp$0$i = 0, $temp$0$i8 = 0, $up = 0, $x$073 = 0, $y$081 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $$byval_copy32 = sp + 400|0;
 $0 = sp + 396|0;
 $1 = sp + 392|0;
 $2 = sp + 388|0;
 $3 = sp + 384|0;
 $4 = sp + 380|0;
 $5 = sp + 376|0;
 $6 = sp + 372|0;
 $7 = sp + 368|0;
 $8 = sp + 364|0;
 $9 = sp + 352|0;
 $10 = sp + 348|0;
 $11 = sp + 344|0;
 $position = sp + 332|0;
 $12 = sp + 320|0;
 $planes = sp + 96|0;
 $bounds = sp;
 $up = sp + 24|0;
 $13 = sp + 36|0;
 $14 = sp + 48|0;
 $props = sp + 60|0;
 $15 = sp + 192|0;
 $16 = sp + 204|0;
 $matrix = sp + 216|0;
 $prop = sp + 280|0;
 $color = sp + 296|0;
 $17 = sp + 312|0;
 $18 = sp + 316|0;
 $19 = $detailDensity < Math_fround(0.0);
 if ($19) {
  $$0$i = Math_fround(0.0);
 } else {
  $20 = $detailDensity > Math_fround(1.0);
  $$$i = $20 ? Math_fround(1.0) : $detailDensity;
  $$0$i = $$$i;
 }
 $21 = (($this) + 12|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$8>>2] = $22;
 $23 = HEAP32[560624>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  label = 11;
 } else {
  $25 = (($23) + 36|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($23) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($26|0)==($28|0);
  do {
   if ($29) {
    $30 = (($23) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($23) + 32|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($31) + ($33<<3)|0);
    $50 = $34;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy32,$23,$8);
    $35 = HEAP32[$$byval_copy32>>2]|0;
    $36 = ($35|0)==(-1);
    $37 = (($23) + 28|0);
    $38 = HEAP32[$37>>2]|0;
    if ($36) {
     $39 = (($23) + 32|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($38) + ($40<<3)|0);
     $50 = $41;
     break;
    } else {
     $42 = (($38) + ($35<<3)|0);
     $50 = $42;
     break;
    }
   }
  } while(0);
  $43 = HEAP32[560624>>2]|0;
  $44 = (($43) + 28|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($43) + 32|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + ($47<<3)|0);
  $49 = ($50|0)==($48|0);
  if ($49) {
   label = 11;
  } else {
   $51 = (($50) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0|0);
   if ($53) {
    label = 11;
   } else {
    $temp$0$i = $52;
   }
  }
 }
 if ((label|0) == 11) {
  $54 = HEAP32[$21>>2]|0;
  $55 = (__Z31ReadObjectFromPersistentManageri($54)|0);
  $temp$0$i = $55;
 }
 $56 = (($temp$0$i) + 112|0);
 $57 = (__Z14IsWorldPlayingv()|0);
 if ($57) {
  $58 = (__Z14GetTimeManagerv()|0);
  $59 = (($58) + 104|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($56) + 76|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = Math_fround($60 * $62);
  $64 = Math_fround($63 * Math_fround(0.0500000007450580596924));
  $68 = $64;
 } else {
  $68 = Math_fround(0.0);
 }
 $65 = (($this) + 84|0);
 $66 = Math_fround(HEAPF32[$65>>2]);
 $67 = Math_fround($68 + $66);
 HEAPF32[$65>>2] = $67;
 $69 = (($this) + 80|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($70) + 1)|0;
 HEAP32[$69>>2] = $71;
 $72 = (($this) + 16|0);
 $73 = HEAP32[$21>>2]|0;
 HEAP32[$7>>2] = $73;
 $74 = HEAP32[560624>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  label = 22;
 } else {
  $76 = (($74) + 36|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = (($74) + 4|0);
  $79 = HEAP32[$78>>2]|0;
  $80 = ($77|0)==($79|0);
  do {
   if ($80) {
    $81 = (($74) + 28|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($74) + 32|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($82) + ($84<<3)|0);
    $101 = $85;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy32,$74,$7);
    $86 = HEAP32[$$byval_copy32>>2]|0;
    $87 = ($86|0)==(-1);
    $88 = (($74) + 28|0);
    $89 = HEAP32[$88>>2]|0;
    if ($87) {
     $90 = (($74) + 32|0);
     $91 = HEAP32[$90>>2]|0;
     $92 = (($89) + ($91<<3)|0);
     $101 = $92;
     break;
    } else {
     $93 = (($89) + ($86<<3)|0);
     $101 = $93;
     break;
    }
   }
  } while(0);
  $94 = HEAP32[560624>>2]|0;
  $95 = (($94) + 28|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (($94) + 32|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = (($96) + ($98<<3)|0);
  $100 = ($101|0)==($99|0);
  if ($100) {
   label = 22;
  } else {
   $102 = (($101) + 4|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = ($103|0)==(0|0);
   if ($104) {
    label = 22;
   } else {
    $temp$0$i8 = $103;
   }
  }
 }
 if ((label|0) == 22) {
  $105 = HEAP32[$21>>2]|0;
  $106 = (__Z31ReadObjectFromPersistentManageri($105)|0);
  $temp$0$i8 = $106;
 }
 $107 = (($temp$0$i8) + 232|0);
 __ZNK9Heightmap7GetSizeEv($9,$107);
 ;HEAP32[$72+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$9+8>>2]|0;
 $108 = (($56) + 36|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ($109|0)==(0);
 if ($110) {
  STACKTOP = sp;return;
 }
 __ZN14DetailDatabase29UpdateDetailPrototypesIfDirtyEv($56);
 $111 = (($56) + 56|0);
 $112 = HEAP32[$this>>2]|0;
 $113 = HEAP32[799792>>2]|0;
 HEAP32[$10>>2] = $113;
 ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$10+0>>2]|0;
 $114 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($112,$$byval_copy32)|0);
 if ($114) {
  $115 = HEAP32[$this>>2]|0;
  $116 = HEAP32[799792>>2]|0;
  HEAP32[$11>>2] = $116;
  $117 = HEAP32[$111>>2]|0;
  ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$11+0>>2]|0;
  __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($115,$$byval_copy32,$117);
 }
 $118 = (($this) + 4|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = HEAP32[799792>>2]|0;
 HEAP32[$10>>2] = $120;
 ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$10+0>>2]|0;
 $121 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($119,$$byval_copy32)|0);
 if ($121) {
  $567 = HEAP32[$118>>2]|0;
  $568 = HEAP32[799792>>2]|0;
  HEAP32[$11>>2] = $568;
  $569 = HEAP32[$111>>2]|0;
  ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$11+0>>2]|0;
  __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($567,$$byval_copy32,$569);
 }
 $570 = (($this) + 8|0);
 $571 = HEAP32[$570>>2]|0;
 $572 = HEAP32[799792>>2]|0;
 HEAP32[$10>>2] = $572;
 ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$10+0>>2]|0;
 $573 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($571,$$byval_copy32)|0);
 if ($573) {
  $574 = HEAP32[$570>>2]|0;
  $575 = HEAP32[799792>>2]|0;
  HEAP32[$11>>2] = $575;
  $576 = HEAP32[$111>>2]|0;
  ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$11+0>>2]|0;
  __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($574,$$byval_copy32,$576);
 }
 $577 = (($camera) + 24|0);
 $578 = HEAP32[$577>>2]|0;
 $212 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($578)|0);
 __ZNK9Transform11GetPositionEv($12,$212);
 $194 = (($this) + 68|0);
 $579 = Math_fround(HEAPF32[$12>>2]);
 $580 = Math_fround(HEAPF32[$194>>2]);
 $581 = Math_fround($579 - $580);
 $582 = (($12) + 4|0);
 $583 = Math_fround(HEAPF32[$582>>2]);
 $198 = (($this) + 72|0);
 $584 = Math_fround(HEAPF32[$198>>2]);
 $585 = Math_fround($583 - $584);
 $586 = (($12) + 8|0);
 $587 = Math_fround(HEAPF32[$586>>2]);
 $202 = (($this) + 76|0);
 $588 = Math_fround(HEAPF32[$202>>2]);
 $126 = Math_fround($587 - $588);
 HEAPF32[$position>>2] = $581;
 $295 = (($position) + 4|0);
 HEAPF32[$295>>2] = $585;
 $297 = (($position) + 8|0);
 HEAPF32[$297>>2] = $126;
 $127 = (Math_fround(($109|0)));
 $589 = Math_fround($127 * $581);
 $137 = Math_fround(HEAPF32[$72>>2]);
 $590 = Math_fround($589 / $137);
 $123 = Math_fround($590 + Math_fround(0.5));
 $591 = !($123 >= Math_fround(0.0));
 if ($591) {
  $122 = Math_fround($123 + Math_fround(-0.999999940395355224609));
  $$sink$i$i = $122;
 } else {
  $$sink$i$i = $123;
 }
 $124 = (~~(($$sink$i$i)));
 $125 = Math_fround($127 * $126);
 $128 = (($this) + 24|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($125 / $129);
 $131 = Math_fround($130 + Math_fround(0.5));
 $132 = !($131 >= Math_fround(0.0));
 if ($132) {
  $133 = Math_fround($131 + Math_fround(-0.999999940395355224609));
  $$sink$i$i25 = $133;
 } else {
  $$sink$i$i25 = $131;
 }
 $134 = (~~(($$sink$i$i25)));
 $135 = Math_fround($127 * $viewDistance);
 $136 = Math_fround($135 / $137);
 $ceilf$i = (Math_fround(Math_ceil((Math_fround($136)))));
 $138 = Math_fround($ceilf$i + Math_fround(1.0));
 $139 = (~~(($138)));
 $140 = Math_fround($135 / $129);
 $ceilf$i27 = (Math_fround(Math_ceil((Math_fround($140)))));
 $141 = Math_fround($ceilf$i27 + Math_fround(1.0));
 $142 = (~~(($141)));
 $143 = (($124) - ($139))|0;
 $144 = ($143|0)<(0);
 $$ = $144 ? 0 : $143;
 $145 = (($109) + -1)|0;
 $146 = ($$|0)>($145|0);
 $147 = (($134) - ($142))|0;
 $148 = ($147|0)<(0);
 $$1 = $148 ? 0 : $147;
 $149 = ($$1|0)>($145|0);
 $150 = (($139) + ($124))|0;
 $151 = ($150|0)<(0);
 $$2 = $151 ? 0 : $150;
 $152 = ($$2|0)>($145|0);
 $153 = (($142) + ($134))|0;
 $154 = ($153|0)<(0);
 $$3 = $154 ? 0 : $153;
 $155 = ($$3|0)>($145|0);
 $maxy$0 = $155 ? $145 : $$3;
 HEAPF32[$planes>>2] = Math_fround(0.0);
 $156 = (($planes) + 4|0);
 HEAPF32[$156>>2] = Math_fround(0.0);
 $157 = (($planes) + 8|0);
 HEAPF32[$157>>2] = Math_fround(0.0);
 $158 = (($planes) + 16|0);
 HEAPF32[$158>>2] = Math_fround(0.0);
 $159 = (($planes) + 20|0);
 HEAPF32[$159>>2] = Math_fround(0.0);
 $160 = (($planes) + 24|0);
 HEAPF32[$160>>2] = Math_fround(0.0);
 $161 = (($planes) + 32|0);
 HEAPF32[$161>>2] = Math_fround(0.0);
 $162 = (($planes) + 36|0);
 HEAPF32[$162>>2] = Math_fround(0.0);
 $163 = (($planes) + 40|0);
 HEAPF32[$163>>2] = Math_fround(0.0);
 $164 = (($planes) + 48|0);
 HEAPF32[$164>>2] = Math_fround(0.0);
 $165 = (($planes) + 52|0);
 HEAPF32[$165>>2] = Math_fround(0.0);
 $166 = (($planes) + 56|0);
 HEAPF32[$166>>2] = Math_fround(0.0);
 $167 = (($planes) + 64|0);
 HEAPF32[$167>>2] = Math_fround(0.0);
 $168 = (($planes) + 68|0);
 HEAPF32[$168>>2] = Math_fround(0.0);
 $169 = (($planes) + 72|0);
 HEAPF32[$169>>2] = Math_fround(0.0);
 $170 = (($planes) + 80|0);
 HEAPF32[$170>>2] = Math_fround(0.0);
 $171 = (($planes) + 84|0);
 HEAPF32[$171>>2] = Math_fround(0.0);
 $172 = (($planes) + 88|0);
 HEAPF32[$172>>2] = Math_fround(0.0);
 $$$ = $146 ? $145 : $$;
 $miny$0 = $149 ? $145 : $$1;
 $$$2 = $152 ? $145 : $$2;
 $173 = Math_fround($viewDistance * $viewDistance);
 $174 = (__ZNK6Camera20GetWorldToClipMatrixEv($camera)|0);
 __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($174,$planes);
 $175 = HEAP32[$this>>2]|0;
 $176 = (__ZN5Unity8Material9GetShaderEv($175)|0);
 $177 = (__ZNK6Shader11IsSupportedEv($176)|0);
 $178 = ($miny$0|0)>($maxy$0|0);
 if (!($178)) {
  $179 = ($$$|0)>($$$2|0);
  $180 = (($bounds) + 4|0);
  $181 = (($bounds) + 8|0);
  $y$081 = $miny$0;
  while(1) {
   if (!($179)) {
    $x$073 = $$$;
    while(1) {
     $182 = (__ZNK14DetailDatabase12IsPatchEmptyEii($56,$x$073,$y$081)|0);
     do {
      if (!($182)) {
       if (!($177)) {
        $487 = (__ZN14DetailRenderer15GrabCachedPatchEii16DetailRenderModef($this,$x$073,$y$081,1,$$0$i)|0);
        $488 = (($487) + 5|0);
        $489 = HEAP8[$488>>0]|0;
        $490 = ($489<<24>>24)==(0);
        do {
         if ($490) {
          $492 = HEAP32[$487>>2]|0;
          $493 = (($492) + 168|0);
          ;HEAP32[$bounds+0>>2]=HEAP32[$493+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$493+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$493+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$493+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$493+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$493+20>>2]|0;
          $494 = (($487) + 4|0);
          HEAP8[$494>>0] = 1;
          $495 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($position,$bounds)));
          $496 = $495 > $173;
          if ($496) {
           HEAP8[$494>>0] = 0;
           break;
          }
          $497 = Math_fround(HEAPF32[$194>>2]);
          $498 = Math_fround(HEAPF32[$bounds>>2]);
          $499 = Math_fround($497 + $498);
          HEAPF32[$bounds>>2] = $499;
          $500 = Math_fround(HEAPF32[$198>>2]);
          $501 = Math_fround(HEAPF32[$180>>2]);
          $502 = Math_fround($500 + $501);
          HEAPF32[$180>>2] = $502;
          $503 = Math_fround(HEAPF32[$202>>2]);
          $504 = Math_fround(HEAPF32[$181>>2]);
          $505 = Math_fround($503 + $504);
          HEAPF32[$181>>2] = $505;
          $506 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($bounds,$planes)|0);
          if ($506) {
           break;
          }
          HEAP8[$494>>0] = 0;
         } else {
          $491 = (($487) + 4|0);
          HEAP8[$491>>0] = 0;
         }
        } while(0);
        $507 = (__ZN14DetailRenderer15GrabCachedPatchEii16DetailRenderModef($this,$x$073,$y$081,2,$$0$i)|0);
        $508 = (($507) + 5|0);
        $509 = HEAP8[$508>>0]|0;
        $510 = ($509<<24>>24)==(0);
        if (!($510)) {
         $511 = (($507) + 4|0);
         HEAP8[$511>>0] = 0;
         break;
        }
        $512 = HEAP32[$507>>2]|0;
        $513 = (($512) + 168|0);
        ;HEAP32[$bounds+0>>2]=HEAP32[$513+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$513+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$513+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$513+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$513+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$513+20>>2]|0;
        $514 = (($507) + 4|0);
        HEAP8[$514>>0] = 1;
        $515 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($position,$bounds)));
        $516 = $515 > $173;
        if ($516) {
         HEAP8[$514>>0] = 0;
         break;
        }
        $517 = Math_fround(HEAPF32[$194>>2]);
        $518 = Math_fround(HEAPF32[$bounds>>2]);
        $519 = Math_fround($517 + $518);
        HEAPF32[$bounds>>2] = $519;
        $520 = Math_fround(HEAPF32[$198>>2]);
        $521 = Math_fround(HEAPF32[$180>>2]);
        $522 = Math_fround($520 + $521);
        HEAPF32[$180>>2] = $522;
        $523 = Math_fround(HEAPF32[$202>>2]);
        $524 = Math_fround(HEAPF32[$181>>2]);
        $525 = Math_fround($523 + $524);
        HEAPF32[$181>>2] = $525;
        $526 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($bounds,$planes)|0);
        if ($526) {
         break;
        }
        HEAP8[$514>>0] = 0;
        break;
       }
       $183 = (__ZN14DetailRenderer15GrabCachedPatchEii16DetailRenderModef($this,$x$073,$y$081,0,$$0$i)|0);
       $184 = (($183) + 5|0);
       $185 = HEAP8[$184>>0]|0;
       $186 = ($185<<24>>24)==(0);
       do {
        if ($186) {
         $188 = HEAP32[$183>>2]|0;
         $189 = (($188) + 168|0);
         ;HEAP32[$bounds+0>>2]=HEAP32[$189+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$189+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$189+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$189+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$189+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$189+20>>2]|0;
         $190 = (($183) + 4|0);
         HEAP8[$190>>0] = 1;
         $191 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($position,$bounds)));
         $192 = $191 > $173;
         if ($192) {
          HEAP8[$190>>0] = 0;
          break;
         }
         $193 = Math_fround(HEAPF32[$194>>2]);
         $195 = Math_fround(HEAPF32[$bounds>>2]);
         $196 = Math_fround($193 + $195);
         HEAPF32[$bounds>>2] = $196;
         $197 = Math_fround(HEAPF32[$198>>2]);
         $199 = Math_fround(HEAPF32[$180>>2]);
         $200 = Math_fround($197 + $199);
         HEAPF32[$180>>2] = $200;
         $201 = Math_fround(HEAPF32[$202>>2]);
         $203 = Math_fround(HEAPF32[$181>>2]);
         $204 = Math_fround($201 + $203);
         HEAPF32[$181>>2] = $204;
         $205 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($bounds,$planes)|0);
         if ($205) {
          break;
         }
         HEAP8[$190>>0] = 0;
        } else {
         $187 = (($183) + 4|0);
         HEAP8[$187>>0] = 0;
        }
       } while(0);
       $527 = (__ZN14DetailRenderer15GrabCachedPatchEii16DetailRenderModef($this,$x$073,$y$081,1,$$0$i)|0);
       $528 = (($527) + 5|0);
       $529 = HEAP8[$528>>0]|0;
       $530 = ($529<<24>>24)==(0);
       do {
        if ($530) {
         $532 = HEAP32[$527>>2]|0;
         $533 = (($532) + 168|0);
         ;HEAP32[$bounds+0>>2]=HEAP32[$533+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$533+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$533+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$533+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$533+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$533+20>>2]|0;
         $534 = (($527) + 4|0);
         HEAP8[$534>>0] = 1;
         $535 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($position,$bounds)));
         $536 = $535 > $173;
         if ($536) {
          HEAP8[$534>>0] = 0;
          break;
         }
         $537 = Math_fround(HEAPF32[$194>>2]);
         $538 = Math_fround(HEAPF32[$bounds>>2]);
         $539 = Math_fround($537 + $538);
         HEAPF32[$bounds>>2] = $539;
         $540 = Math_fround(HEAPF32[$198>>2]);
         $541 = Math_fround(HEAPF32[$180>>2]);
         $542 = Math_fround($540 + $541);
         HEAPF32[$180>>2] = $542;
         $543 = Math_fround(HEAPF32[$202>>2]);
         $544 = Math_fround(HEAPF32[$181>>2]);
         $545 = Math_fround($543 + $544);
         HEAPF32[$181>>2] = $545;
         $546 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($bounds,$planes)|0);
         if ($546) {
          break;
         }
         HEAP8[$534>>0] = 0;
        } else {
         $531 = (($527) + 4|0);
         HEAP8[$531>>0] = 0;
        }
       } while(0);
       $547 = (__ZN14DetailRenderer15GrabCachedPatchEii16DetailRenderModef($this,$x$073,$y$081,2,$$0$i)|0);
       $548 = (($547) + 5|0);
       $549 = HEAP8[$548>>0]|0;
       $550 = ($549<<24>>24)==(0);
       if (!($550)) {
        $551 = (($547) + 4|0);
        HEAP8[$551>>0] = 0;
        break;
       }
       $552 = HEAP32[$547>>2]|0;
       $553 = (($552) + 168|0);
       ;HEAP32[$bounds+0>>2]=HEAP32[$553+0>>2]|0;HEAP32[$bounds+4>>2]=HEAP32[$553+4>>2]|0;HEAP32[$bounds+8>>2]=HEAP32[$553+8>>2]|0;HEAP32[$bounds+12>>2]=HEAP32[$553+12>>2]|0;HEAP32[$bounds+16>>2]=HEAP32[$553+16>>2]|0;HEAP32[$bounds+20>>2]=HEAP32[$553+20>>2]|0;
       $554 = (($547) + 4|0);
       HEAP8[$554>>0] = 1;
       $555 = (Math_fround(__Z20CalculateSqrDistanceRK8Vector3fRK4AABB($position,$bounds)));
       $556 = $555 > $173;
       if ($556) {
        HEAP8[$554>>0] = 0;
        break;
       }
       $557 = Math_fround(HEAPF32[$194>>2]);
       $558 = Math_fround(HEAPF32[$bounds>>2]);
       $559 = Math_fround($557 + $558);
       HEAPF32[$bounds>>2] = $559;
       $560 = Math_fround(HEAPF32[$198>>2]);
       $561 = Math_fround(HEAPF32[$180>>2]);
       $562 = Math_fround($560 + $561);
       HEAPF32[$180>>2] = $562;
       $563 = Math_fround(HEAPF32[$202>>2]);
       $564 = Math_fround(HEAPF32[$181>>2]);
       $565 = Math_fround($563 + $564);
       HEAPF32[$181>>2] = $565;
       $566 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($bounds,$planes)|0);
       if ($566) {
        break;
       }
       HEAP8[$554>>0] = 0;
      }
     } while(0);
     $206 = (($x$073) + 1)|0;
     $207 = ($x$073|0)<($$$2|0);
     if ($207) {
      $x$073 = $206;
     } else {
      break;
     }
    }
   }
   $208 = (($y$081) + 1)|0;
   $209 = ($y$081|0)<($maxy$0|0);
   if ($209) {
    $y$081 = $208;
   } else {
    break;
   }
  }
 }
 HEAPF32[$13>>2] = Math_fround(0.0);
 $210 = (($13) + 4|0);
 HEAPF32[$210>>2] = Math_fround(1.0);
 $211 = (($13) + 8|0);
 HEAPF32[$211>>2] = Math_fround(0.0);
 __ZNK9Transform25InverseTransformDirectionERK8Vector3f($up,$212,$13);
 $213 = (($up) + 8|0);
 HEAPF32[$213>>2] = Math_fround(0.0);
 __ZNK9Transform18TransformDirectionERK8Vector3f($14,$212,$up);
 ;HEAP32[$up+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$up+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$up+8>>2]=HEAP32[$14+8>>2]|0;
 $214 = Math_fround(HEAPF32[$up>>2]);
 $215 = Math_fround($214 * $214);
 $216 = (($up) + 4|0);
 $217 = Math_fround(HEAPF32[$216>>2]);
 $218 = Math_fround($217 * $217);
 $219 = Math_fround($215 + $218);
 $220 = Math_fround(HEAPF32[$213>>2]);
 $221 = Math_fround($220 * $220);
 $222 = Math_fround($219 + $221);
 $223 = (Math_fround(Math_sqrt((Math_fround($222)))));
 $224 = Math_fround(HEAPF32[616648>>2]);
 $225 = $223 > $224;
 if ($225) {
  $226 = Math_fround($214 / $223);
  $227 = Math_fround($217 / $223);
  $228 = Math_fround($220 / $223);
  $232 = $226;$233 = $227;$234 = $228;
 } else {
  $229 = Math_fround(HEAPF32[616680>>2]);
  $230 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
  $231 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
  $232 = $229;$233 = $230;$234 = $231;
 }
 HEAPF32[$up>>2] = $232;
 HEAPF32[$216>>2] = $233;
 HEAPF32[$213>>2] = $234;
 $235 = HEAP32[628512>>2]|0;
 HEAP32[$props>>2] = 0;
 $236 = (($props) + 4|0);
 HEAP32[$236>>2] = $235;
 $237 = (($props) + 8|0);
 HEAP32[$237>>2] = 0;
 $238 = (($props) + 12|0);
 HEAP32[$238>>2] = 0;
 $239 = (($props) + 16|0);
 HEAP32[$239>>2] = 0;
 $240 = (($props) + 20|0);
 HEAP32[$240>>2] = $235;
 $241 = (($props) + 24|0);
 HEAP32[$241>>2] = 0;
 $242 = (($props) + 28|0);
 HEAP32[$242>>2] = 0;
 $243 = (($props) + 32|0);
 $244 = HEAP32[641904>>2]|0;
 HEAP32[$243>>2] = $244;
 HEAPF32[$16>>2] = Math_fround(0.0);
 $245 = (($16) + 4|0);
 HEAPF32[$245>>2] = Math_fround(0.0);
 $246 = (($16) + 8|0);
 HEAPF32[$246>>2] = Math_fround(-1.0);
 __THREW__ = 0;
 invoke_viii(1690,($15|0),($212|0),($16|0));
 $247 = __THREW__; __THREW__ = 0;
 $248 = $247&1;
 do {
  if ($248) {
   label = 88;
  } else {
   $249 = (($15) + 4|0);
   $250 = Math_fround(HEAPF32[$249>>2]);
   $251 = Math_fround(HEAPF32[$213>>2]);
   $252 = Math_fround($250 * $251);
   $253 = (($15) + 8|0);
   $254 = Math_fround(HEAPF32[$253>>2]);
   $255 = Math_fround(HEAPF32[$216>>2]);
   $256 = Math_fround($254 * $255);
   $257 = Math_fround($252 - $256);
   $258 = Math_fround(HEAPF32[$up>>2]);
   $259 = Math_fround($254 * $258);
   $260 = Math_fround(HEAPF32[$15>>2]);
   $261 = Math_fround($251 * $260);
   $262 = Math_fround($259 - $261);
   $263 = Math_fround($255 * $260);
   $264 = Math_fround($250 * $258);
   $265 = Math_fround($263 - $264);
   $266 = Math_fround($257 * $257);
   $267 = Math_fround($262 * $262);
   $268 = Math_fround($266 + $267);
   $269 = Math_fround($265 * $265);
   $270 = Math_fround($269 + $268);
   $271 = (Math_fround(Math_sqrt((Math_fround($270)))));
   $272 = $271 > $224;
   if ($272) {
    $273 = Math_fround($257 / $271);
    $274 = Math_fround($262 / $271);
    $275 = Math_fround($265 / $271);
    $311 = $273;$312 = $274;$313 = $275;
   } else {
    $276 = Math_fround(HEAPF32[616680>>2]);
    $277 = Math_fround(HEAPF32[((616680 + 4|0))>>2]);
    $278 = Math_fround(HEAPF32[((616680 + 8|0))>>2]);
    $311 = $276;$312 = $277;$313 = $278;
   }
   __THREW__ = 0;
   (invoke_iii(2370,($matrix|0),($194|0))|0);
   $279 = __THREW__; __THREW__ = 0;
   $280 = $279&1;
   if ($280) {
    label = 88;
   } else {
    $281 = (($prop) + 4|0);
    $282 = (($prop) + 8|0);
    $283 = Math_fround(Math_fround(1.0) / $173);
    $284 = (($prop) + 12|0);
    $285 = (($56) + 84|0);
    $286 = (($56) + 60|0);
    $287 = (($this) + 28|0);
    $288 = (($56) + 80|0);
    $r$066 = 0;
    L115: while(1) {
     $289 = (($this) + ($r$066<<2)|0);
     $290 = HEAP32[$289>>2]|0;
     HEAP32[$237>>2] = 0;
     HEAP32[$241>>2] = 0;
     HEAP32[$243>>2] = $244;
     __THREW__ = 0;
     invoke_viif(48,($props|0),(799816|0),(+$173));
     $291 = __THREW__; __THREW__ = 0;
     $292 = $291&1;
     if ($292) {
      label = 87;
      break;
     }
     $293 = Math_fround(HEAPF32[$position>>2]);
     HEAPF32[$prop>>2] = $293;
     $294 = Math_fround(HEAPF32[$295>>2]);
     HEAPF32[$281>>2] = $294;
     $296 = Math_fround(HEAPF32[$297>>2]);
     HEAPF32[$282>>2] = $296;
     HEAPF32[$284>>2] = $283;
     __THREW__ = 0;
     invoke_viii(2027,($props|0),(799840|0),($prop|0));
     $298 = __THREW__; __THREW__ = 0;
     $299 = $298&1;
     if ($299) {
      label = 87;
      break;
     }
     $300 = Math_fround(HEAPF32[$65>>2]);
     HEAPF32[$prop>>2] = $300;
     $301 = Math_fround(HEAPF32[$285>>2]);
     $302 = Math_fround($301 * Math_fround(0.400000005960464477539));
     HEAPF32[$281>>2] = $302;
     $303 = ($r$066|0)==(1);
     if ($303) {
      $306 = Math_fround(0.0);
     } else {
      $304 = Math_fround(HEAPF32[$288>>2]);
      $305 = Math_fround($304 * Math_fround(6.0));
      $306 = $305;
     }
     HEAPF32[$282>>2] = $306;
     HEAPF32[$284>>2] = $173;
     __THREW__ = 0;
     invoke_viii(2027,($props|0),(799864|0),($prop|0));
     $307 = __THREW__; __THREW__ = 0;
     $308 = $307&1;
     if ($308) {
      label = 87;
      break;
     }
     ;HEAP32[$color+0>>2]=HEAP32[$286+0>>2]|0;HEAP32[$color+4>>2]=HEAP32[$286+4>>2]|0;HEAP32[$color+8>>2]=HEAP32[$286+8>>2]|0;HEAP32[$color+12>>2]=HEAP32[$286+12>>2]|0;
     __THREW__ = 0;
     invoke_viii(2028,($props|0),(799896|0),($color|0));
     $309 = __THREW__; __THREW__ = 0;
     $310 = $309&1;
     if ($310) {
      label = 87;
      break;
     }
     HEAPF32[$prop>>2] = $311;
     HEAPF32[$281>>2] = $312;
     HEAPF32[$282>>2] = $313;
     HEAPF32[$284>>2] = Math_fround(0.0);
     __THREW__ = 0;
     invoke_viii(2027,($props|0),(799920|0),($prop|0));
     $314 = __THREW__; __THREW__ = 0;
     $315 = $314&1;
     if ($315) {
      label = 87;
      break;
     }
     $316 = Math_fround(HEAPF32[$up>>2]);
     HEAPF32[$prop>>2] = $316;
     $317 = Math_fround(HEAPF32[$216>>2]);
     HEAPF32[$281>>2] = $317;
     $318 = Math_fround(HEAPF32[$213>>2]);
     HEAPF32[$282>>2] = $318;
     HEAPF32[$284>>2] = Math_fround(0.0);
     __THREW__ = 0;
     invoke_viii(2027,($props|0),(799944|0),($prop|0));
     $319 = __THREW__; __THREW__ = 0;
     $320 = $319&1;
     if ($320) {
      label = 87;
      break;
     }
     $321 = ((($this) + (($r$066*12)|0)|0) + 32|0);
     $322 = HEAP32[$321>>2]|0;
     $323 = ((($this) + (($r$066*12)|0)|0) + 36|0);
     $324 = ($322|0)==($323|0);
     if (!($324)) {
      $325 = ($290|0)==(0|0);
      $326 = (($290) + 4|0);
      $328 = $322;
      while(1) {
       $327 = (($328) + 24|0);
       $329 = HEAP8[$327>>0]|0;
       $330 = ($329<<24>>24)==(0);
       if (!($330)) {
        $331 = (($328) + 20|0);
        $332 = HEAP32[$331>>2]|0;
        if ($325) {
         $storemerge = 0;
        } else {
         $333 = HEAP32[$326>>2]|0;
         $storemerge = $333;
        }
        HEAP32[$17>>2] = $storemerge;
        __THREW__ = 0;
        $334 = (invoke_iiiiiiiii(44,($matrix|0),($332|0),($17|0),($layer|0),0,1,0,($camera|0))|0);
        $335 = __THREW__; __THREW__ = 0;
        $336 = $335&1;
        if ($336) {
         label = 86;
         break L115;
        }
        $337 = (($334) + 204|0);
        $338 = ($337|0)==($props|0);
        if (!($338)) {
         $339 = HEAP32[$props>>2]|0;
         $340 = HEAP32[$237>>2]|0;
         $$idx = $340 << 4;
         $341 = $$idx >> 4;
         $342 = (($334) + 212|0);
         HEAP32[$342>>2] = $341;
         $343 = (($334) + 216|0);
         $344 = HEAP32[$343>>2]|0;
         $345 = $344 & 2147483647;
         $346 = ($345>>>0)<($341>>>0);
         do {
          if ($346) {
           $347 = ($344|0)>(-1);
           if ($347) {
            HEAP32[$343>>2] = $341;
            $348 = HEAP32[$337>>2]|0;
            $349 = (($334) + 208|0);
            $350 = HEAP32[$349>>2]|0;
            HEAP32[$2>>2] = $350;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$2+0>>2]|0;
            $351 = (invoke_iiiiiiii(108,($348|0),($$idx|0),4,($$byval_copy32|0),0,(800256|0),370)|0);
            $352 = __THREW__; __THREW__ = 0;
            $353 = $352&1;
            if ($353) {
             label = 86;
             break L115;
            }
            HEAP32[$337>>2] = $351;
            $364 = $351;
            break;
           } else {
            $354 = (($334) + 208|0);
            $355 = HEAP32[$354>>2]|0;
            HEAP32[$3>>2] = $355;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$3+0>>2]|0;
            $356 = (invoke_iiiiiii(102,($$idx|0),4,($$byval_copy32|0),0,(800256|0),352)|0);
            $357 = __THREW__; __THREW__ = 0;
            $358 = $357&1;
            if ($358) {
             label = 86;
             break L115;
            }
            $359 = HEAP32[$337>>2]|0;
            $360 = HEAP32[$342>>2]|0;
            $361 = $360 << 4;
            _memcpy(($356|0),($359|0),($361|0))|0;
            HEAP32[$343>>2] = $341;
            HEAP32[$337>>2] = $356;
            $364 = $356;
            break;
           }
          } else {
           $$pre$i = HEAP32[$337>>2]|0;
           $364 = $$pre$i;
          }
         } while(0);
         $362 = HEAP32[$342>>2]|0;
         $363 = $362 << 4;
         _memcpy(($364|0),($339|0),($363|0))|0;
         $365 = (($334) + 220|0);
         $366 = HEAP32[$239>>2]|0;
         $367 = HEAP32[$241>>2]|0;
         $$idx53 = $367 << 2;
         $368 = $$idx53 >> 2;
         $369 = (($334) + 228|0);
         HEAP32[$369>>2] = $368;
         $370 = (($334) + 232|0);
         $371 = HEAP32[$370>>2]|0;
         $372 = $371 & 2147483647;
         $373 = ($372>>>0)<($368>>>0);
         do {
          if ($373) {
           $374 = ($371|0)>(-1);
           if ($374) {
            HEAP32[$370>>2] = $368;
            $375 = HEAP32[$365>>2]|0;
            $376 = (($334) + 224|0);
            $377 = HEAP32[$376>>2]|0;
            HEAP32[$0>>2] = $377;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$0+0>>2]|0;
            $378 = (invoke_iiiiiiii(108,($375|0),($$idx53|0),4,($$byval_copy32|0),0,(800256|0),370)|0);
            $379 = __THREW__; __THREW__ = 0;
            $380 = $379&1;
            if ($380) {
             label = 86;
             break L115;
            }
            HEAP32[$365>>2] = $378;
            $391 = $378;
            break;
           } else {
            $381 = (($334) + 224|0);
            $382 = HEAP32[$381>>2]|0;
            HEAP32[$1>>2] = $382;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$1+0>>2]|0;
            $383 = (invoke_iiiiiii(102,($$idx53|0),4,($$byval_copy32|0),0,(800256|0),352)|0);
            $384 = __THREW__; __THREW__ = 0;
            $385 = $384&1;
            if ($385) {
             label = 86;
             break L115;
            }
            $386 = HEAP32[$365>>2]|0;
            $387 = HEAP32[$369>>2]|0;
            $388 = $387 << 2;
            _memcpy(($383|0),($386|0),($388|0))|0;
            HEAP32[$370>>2] = $368;
            HEAP32[$365>>2] = $383;
            $391 = $383;
            break;
           }
          } else {
           $$pre$i36 = HEAP32[$365>>2]|0;
           $391 = $$pre$i36;
          }
         } while(0);
         $389 = HEAP32[$369>>2]|0;
         $390 = $389 << 2;
         _memcpy(($391|0),($366|0),($390|0))|0;
        }
        $392 = HEAP32[$243>>2]|0;
        $393 = (($334) + 236|0);
        HEAP32[$393>>2] = $392;
        __THREW__ = 0;
        invoke_vi(3708,($337|0));
        $394 = __THREW__; __THREW__ = 0;
        $395 = $394&1;
        if ($395) {
         label = 86;
         break L115;
        }
        $396 = (($334) + 168|0);
        HEAP32[$396>>2] = $337;
        $397 = HEAP32[$287>>2]|0;
        __THREW__ = 0;
        invoke_viii(2029,($334|0),($397|0),0);
        $398 = __THREW__; __THREW__ = 0;
        $399 = $398&1;
        if ($399) {
         label = 86;
         break L115;
        }
       }
       $430 = (($328) + 4|0);
       $431 = HEAP32[$430>>2]|0;
       $432 = ($431|0)==(0|0);
       if ($432) {
        $$01$i$i$i$i16 = $328;
        while(1) {
         $435 = (($$01$i$i$i$i16) + 8|0);
         $436 = HEAP32[$435>>2]|0;
         $437 = HEAP32[$436>>2]|0;
         $438 = ($437|0)==($$01$i$i$i$i16|0);
         if ($438) {
          $$0$i$i$i$i18 = $436;
          break;
         } else {
          $$01$i$i$i$i16 = $436;
         }
        }
       } else {
        $$0$i$i$i$i$i14 = $431;
        while(1) {
         $433 = HEAP32[$$0$i$i$i$i$i14>>2]|0;
         $434 = ($433|0)==(0|0);
         if ($434) {
          $$0$i$i$i$i18 = $$0$i$i$i$i$i14;
          break;
         } else {
          $$0$i$i$i$i$i14 = $433;
         }
        }
       }
       $439 = ($$0$i$i$i$i18|0)==($323|0);
       if ($439) {
        break;
       } else {
        $328 = $$0$i$i$i$i18;
       }
      }
     }
     $440 = (($r$066) + 1)|0;
     $441 = ($440|0)<(3);
     if ($441) {
      $r$066 = $440;
     } else {
      label = 52;
      break;
     }
    }
    if ((label|0) == 52) {
     $r4$056 = 0;
     L169: while(1) {
      $442 = ((($this) + (($r4$056*12)|0)|0) + 32|0);
      $443 = HEAP32[$442>>2]|0;
      $444 = ((($this) + (($r4$056*12)|0)|0) + 36|0);
      $445 = ($443|0)==($444|0);
      if (!($445)) {
       $447 = $443;
       while(1) {
        $446 = (($447) + 4|0);
        $448 = HEAP32[$446>>2]|0;
        $449 = ($448|0)==(0|0);
        if ($449) {
         $$01$i$i$i$i = $447;
         while(1) {
          $452 = (($$01$i$i$i$i) + 8|0);
          $453 = HEAP32[$452>>2]|0;
          $454 = HEAP32[$453>>2]|0;
          $455 = ($454|0)==($$01$i$i$i$i|0);
          if ($455) {
           $$0$i$i$i$i = $453;
           break;
          } else {
           $$01$i$i$i$i = $453;
          }
         }
        } else {
         $$0$i$i$i$i$i = $448;
         while(1) {
          $450 = HEAP32[$$0$i$i$i$i$i>>2]|0;
          $451 = ($450|0)==(0|0);
          if ($451) {
           $$0$i$i$i$i = $$0$i$i$i$i$i;
           break;
          } else {
           $$0$i$i$i$i$i = $450;
          }
         }
        }
        $456 = (($447) + 28|0);
        $457 = HEAP32[$456>>2]|0;
        $458 = HEAP32[$69>>2]|0;
        $459 = ($457|0)<($458|0);
        if ($459) {
         HEAP32[$6>>2] = $447;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$6+0>>2]|0;
         invoke_viii(2030,($18|0),($442|0),($$byval_copy32|0));
         $461 = __THREW__; __THREW__ = 0;
         $462 = $461&1;
         if ($462) {
          label = 85;
          break L169;
         }
        }
        $460 = ($$0$i$i$i$i|0)==($444|0);
        if ($460) {
         break;
        } else {
         $447 = $$0$i$i$i$i;
        }
       }
      }
      $463 = (($r4$056) + 1)|0;
      $464 = ($463|0)<(3);
      if ($464) {
       $r4$056 = $463;
      } else {
       break;
      }
     }
     if ((label|0) == 85) {
      $400 = ___cxa_find_matching_catch()|0;
      $401 = tempRet0;
      $lpad$phi$index = $400;$lpad$phi$index4 = $401;
      break;
     }
     $465 = HEAP32[$242>>2]|0;
     $466 = ($465|0)>(-1);
     do {
      if ($466) {
       $467 = HEAP32[$239>>2]|0;
       $468 = HEAP32[$240>>2]|0;
       HEAP32[$1>>2] = $468;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($467|0),($$byval_copy32|0));
       $469 = __THREW__; __THREW__ = 0;
       $470 = $469&1;
       if (!($470)) {
        HEAP32[$239>>2] = 0;
        break;
       }
       $475 = ___cxa_find_matching_catch()|0;
       $476 = tempRet0;
       $477 = HEAP32[$238>>2]|0;
       $478 = ($477|0)>(-1);
       if (!($478)) {
        ___resumeException($475|0);
        // unreachable;
       }
       $479 = HEAP32[$props>>2]|0;
       $480 = HEAP32[$236>>2]|0;
       HEAP32[$0>>2] = $480;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($479|0),($$byval_copy32|0));
       $481 = __THREW__; __THREW__ = 0;
       $482 = $481&1;
       if ($482) {
        $483 = ___cxa_find_matching_catch(0|0)|0;
        $484 = tempRet0;
        ___clang_call_terminate($483);
        // unreachable;
       }
       HEAP32[$props>>2] = 0;
       ___resumeException($475|0);
       // unreachable;
      }
     } while(0);
     $471 = HEAP32[$238>>2]|0;
     $472 = ($471|0)>(-1);
     if (!($472)) {
      STACKTOP = sp;return;
     }
     $473 = HEAP32[$props>>2]|0;
     $474 = HEAP32[$236>>2]|0;
     HEAP32[$0>>2] = $474;
     ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($473,$$byval_copy32);
     HEAP32[$props>>2] = 0;
     STACKTOP = sp;return;
    }
    else if ((label|0) == 86) {
     $402 = ___cxa_find_matching_catch()|0;
     $403 = tempRet0;
     $lpad$phi$index = $402;$lpad$phi$index4 = $403;
     break;
    }
    else if ((label|0) == 87) {
     $404 = ___cxa_find_matching_catch()|0;
     $405 = tempRet0;
     $lpad$phi$index = $404;$lpad$phi$index4 = $405;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 88) {
  $406 = ___cxa_find_matching_catch()|0;
  $407 = tempRet0;
  $lpad$phi$index = $406;$lpad$phi$index4 = $407;
 }
 $408 = HEAP32[$242>>2]|0;
 $409 = ($408|0)>(-1);
 do {
  if ($409) {
   $410 = HEAP32[$239>>2]|0;
   $411 = HEAP32[$240>>2]|0;
   HEAP32[$5>>2] = $411;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($410|0),($$byval_copy32|0));
   $412 = __THREW__; __THREW__ = 0;
   $413 = $412&1;
   if (!($413)) {
    HEAP32[$239>>2] = 0;
    break;
   }
   $420 = ___cxa_find_matching_catch(0|0)|0;
   $421 = tempRet0;
   $422 = HEAP32[$238>>2]|0;
   $423 = ($422|0)>(-1);
   if (!($423)) {
    $eh$lpad$body$indexZ2D = $420;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $424 = HEAP32[$props>>2]|0;
   $425 = HEAP32[$236>>2]|0;
   HEAP32[$4>>2] = $425;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($424|0),($$byval_copy32|0));
   $426 = __THREW__; __THREW__ = 0;
   $427 = $426&1;
   if ($427) {
    $428 = ___cxa_find_matching_catch(0|0)|0;
    $429 = tempRet0;
    ___clang_call_terminate($428);
    // unreachable;
   }
   HEAP32[$props>>2] = 0;
   $eh$lpad$body$indexZ2D = $420;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 $414 = HEAP32[$238>>2]|0;
 $415 = ($414|0)>(-1);
 if (!($415)) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $416 = HEAP32[$props>>2]|0;
 $417 = HEAP32[$236>>2]|0;
 HEAP32[$4>>2] = $417;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$4+0>>2]|0;
 invoke_vii(2591,($416|0),($$byval_copy32|0));
 $418 = __THREW__; __THREW__ = 0;
 $419 = $418&1;
 if ($419) {
  $485 = ___cxa_find_matching_catch(0|0)|0;
  $486 = tempRet0;
  $eh$lpad$body$indexZ2D = $485;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$props>>2] = 0;
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14DetailRenderer7CleanupEv($this) {
 $this = $this|0;
 var $$0$i$i$i = 0, $$0$i$i$i$1 = 0, $$0$i$i$i$2 = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$1 = 0, $$0$i$i$i$i$2 = 0, $$01$i$i$i = 0, $$01$i$i$i$1 = 0, $$01$i$i$i$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __Z19DestroySingleObjectP6Object($0);
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 36|0);
 $4 = ($2|0)==($3|0);
 if (!($4)) {
  $6 = $2;
  while(1) {
   $5 = (($6) + 26|0);
   HEAP8[$5>>0] = 0;
   $7 = (($6) + 20|0);
   $8 = HEAP32[$7>>2]|0;
   __Z19DestroySingleObjectP6Object($8);
   HEAP32[$7>>2] = 0;
   $9 = (($6) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    $$01$i$i$i = $6;
    while(1) {
     $14 = (($$01$i$i$i) + 8|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==($$01$i$i$i|0);
     if ($17) {
      $$0$i$i$i = $15;
      break;
     } else {
      $$01$i$i$i = $15;
     }
    }
   } else {
    $$0$i$i$i$i = $10;
    while(1) {
     $12 = HEAP32[$$0$i$i$i$i>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      $$0$i$i$i = $$0$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i = $12;
     }
    }
   }
   $18 = ($$0$i$i$i|0)==($3|0);
   if ($18) {
    break;
   } else {
    $6 = $$0$i$i$i;
   }
  }
 }
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 __Z19DestroySingleObjectP6Object($20);
 $21 = (($this) + 44|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 48|0);
 $24 = ($22|0)==($23|0);
 if (!($24)) {
  $26 = $22;
  while(1) {
   $25 = (($26) + 26|0);
   HEAP8[$25>>0] = 0;
   $27 = (($26) + 20|0);
   $28 = HEAP32[$27>>2]|0;
   __Z19DestroySingleObjectP6Object($28);
   HEAP32[$27>>2] = 0;
   $29 = (($26) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   if ($31) {
    $$01$i$i$i$1 = $26;
    while(1) {
     $34 = (($$01$i$i$i$1) + 8|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==($$01$i$i$i$1|0);
     if ($37) {
      $$0$i$i$i$1 = $35;
      break;
     } else {
      $$01$i$i$i$1 = $35;
     }
    }
   } else {
    $$0$i$i$i$i$1 = $30;
    while(1) {
     $32 = HEAP32[$$0$i$i$i$i$1>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      $$0$i$i$i$1 = $$0$i$i$i$i$1;
      break;
     } else {
      $$0$i$i$i$i$1 = $32;
     }
    }
   }
   $38 = ($$0$i$i$i$1|0)==($23|0);
   if ($38) {
    break;
   } else {
    $26 = $$0$i$i$i$1;
   }
  }
 }
 $39 = (($this) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 __Z19DestroySingleObjectP6Object($40);
 $41 = (($this) + 56|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($this) + 60|0);
 $44 = ($42|0)==($43|0);
 if ($44) {
  STACKTOP = sp;return;
 } else {
  $46 = $42;
 }
 while(1) {
  $45 = (($46) + 26|0);
  HEAP8[$45>>0] = 0;
  $47 = (($46) + 20|0);
  $48 = HEAP32[$47>>2]|0;
  __Z19DestroySingleObjectP6Object($48);
  HEAP32[$47>>2] = 0;
  $49 = (($46) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==(0|0);
  if ($51) {
   $$01$i$i$i$2 = $46;
   while(1) {
    $54 = (($$01$i$i$i$2) + 8|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$55>>2]|0;
    $57 = ($56|0)==($$01$i$i$i$2|0);
    if ($57) {
     $$0$i$i$i$2 = $55;
     break;
    } else {
     $$01$i$i$i$2 = $55;
    }
   }
  } else {
   $$0$i$i$i$i$2 = $50;
   while(1) {
    $52 = HEAP32[$$0$i$i$i$i$2>>2]|0;
    $53 = ($52|0)==(0|0);
    if ($53) {
     $$0$i$i$i$2 = $$0$i$i$i$i$2;
     break;
    } else {
     $$0$i$i$i$i$2 = $52;
    }
   }
  }
  $58 = ($$0$i$i$i$2|0)==($43|0);
  if ($58) {
   break;
  } else {
   $46 = $$0$i$i$i$2;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14DetailRenderer16ReloadAllDetailsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = (($this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($0,$2);
 $3 = (($this) + 40|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 36|0);
 HEAP32[$0>>2] = $4;
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 44|0);
 $6 = (($this) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($5,$7);
 $8 = (($this) + 52|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 48|0);
 HEAP32[$5>>2] = $9;
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 56|0);
 $11 = (($this) + 60|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($10,$12);
 $13 = (($this) + 64|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 60|0);
 HEAP32[$10>>2] = $14;
 HEAP32[$14>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = ($__nd|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
 $4 = (($__nd) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$5);
 $6 = (($__nd) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_vi(3709,($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 }
 $10 = HEAP8[800272>>0]|0;
 $11 = ($10<<24>>24)==(0);
 do {
  if ($11) {
   $12 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $12;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   $13 = (invoke_iiiiiii(103,40,($$byval_copy7|0),0,16,(800256|0),141)|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[628480>>2]|0;
    HEAP32[$1>>2] = $16;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viiiiii(98,($13|0),1,(800280|0),40,32768,($$byval_copy7|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     HEAP32[800264>>2] = $13;
     __THREW__ = 0;
     invoke_vi(3395,($13|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = 800272;
     $28 = $27;
     HEAP32[$28>>2] = 1;
     $29 = (($27) + 4)|0;
     $30 = $29;
     HEAP32[$30>>2] = 0;
     label = 10;
     break;
    }
    $19 = ___cxa_find_matching_catch()|0;
    $20 = tempRet0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viiiiii(97,($13|0),($$byval_copy7|0),0,16,(800256|0),141);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     $23 = ___cxa_find_matching_catch(0|0)|0;
     $24 = tempRet0;
     ___clang_call_terminate($23);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $19;
     ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
     // unreachable;
    }
   }
  } else {
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  $31 = HEAP32[800264>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($31|0),($__nd|0));
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if (!($33)) {
   STACKTOP = sp;return;
  }
 }
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $34;
 ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
 // unreachable;
}
function __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE5eraseENS_21__tree_const_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEE($agg$result,$this,$__p) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__p = $__p|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$01$i$i = 0, $$byval_copy7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$__p>>2]|0;
 HEAP32[$agg$result>>2] = $2;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$01$i$i = $2;
  while(1) {
   $8 = (($$01$i$i) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($$01$i$i|0);
   if ($11) {
    $$0$i$i = $9;
    break;
   } else {
    $$01$i$i = $9;
   }
  }
 } else {
  $$0$i$i$i = $4;
  while(1) {
   $6 = HEAP32[$$0$i$i$i>>2]|0;
   $7 = ($6|0)==(0|0);
   if ($7) {
    $$0$i$i = $$0$i$i$i;
    break;
   } else {
    $$0$i$i$i = $6;
   }
  }
 }
 HEAP32[$agg$result>>2] = $$0$i$i;
 $12 = HEAP32[$this>>2]|0;
 $13 = ($12|0)==($2|0);
 if ($13) {
  HEAP32[$this>>2] = $$0$i$i;
 }
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$14>>2] = $16;
 $17 = (($2) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 __Z19DestroySingleObjectP6Object($18);
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($20,$2);
 $21 = HEAP8[800272>>0]|0;
 $22 = ($21<<24>>24)==(0);
 do {
  if ($22) {
   $23 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $23;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
   $24 = (invoke_iiiiiii(103,40,($$byval_copy7|0),0,16,(800256|0),141)|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP32[628480>>2]|0;
    HEAP32[$1>>2] = $27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_viiiiii(98,($24|0),1,(800280|0),40,32768,($$byval_copy7|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     HEAP32[800264>>2] = $24;
     __THREW__ = 0;
     invoke_vi(3395,($24|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     $38 = 800272;
     $39 = $38;
     HEAP32[$39>>2] = 1;
     $40 = (($38) + 4)|0;
     $41 = $40;
     HEAP32[$41>>2] = 0;
     label = 14;
     break;
    }
    $30 = ___cxa_find_matching_catch()|0;
    $31 = tempRet0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viiiiii(97,($24|0),($$byval_copy7|0),0,16,(800256|0),141);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     $34 = ___cxa_find_matching_catch(0|0)|0;
     $35 = tempRet0;
     ___clang_call_terminate($34);
     // unreachable;
    } else {
     $eh$lpad$body$i$indexZ2D = $30;
     ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
     // unreachable;
    }
   }
  } else {
   label = 14;
  }
 } while(0);
 if ((label|0) == 14) {
  $42 = HEAP32[800264>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($42|0),($2|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if (!($44)) {
   STACKTOP = sp;return;
  }
 }
 $45 = ___cxa_find_matching_catch()|0;
 $46 = tempRet0;
 $eh$lpad$body$i$indexZ2D = $45;
 ___cxa_call_unexpected(($eh$lpad$body$i$indexZ2D|0));
 // unreachable;
}
function __ZNSt3__13mapIj17DetailPatchRenderNS_4lessIjEE11memory_poolINS_4pairIKjS1_EEEE25__construct_node_with_keyERS6_($agg$result,$this,$__k) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__k = $__k|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 $3 = HEAP8[800272>>0]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   $5 = HEAP32[628480>>2]|0;
   HEAP32[$0>>2] = $5;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $6 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,800256,141)|0);
   $7 = HEAP32[628480>>2]|0;
   HEAP32[$1>>2] = $7;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(98,($6|0),1,(800280|0),40,32768,($$byval_copy2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    HEAP32[800264>>2] = $6;
    __ZN10MemoryPool24RegisterStaticMemoryPoolEPS_($6);
    $16 = 800272;
    $17 = $16;
    HEAP32[$17>>2] = 1;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP32[$19>>2] = 0;
    break;
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viiiiii(97,($6|0),($$byval_copy2|0),0,16,(800256|0),141);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch(0|0)|0;
    $15 = tempRet0;
    ___clang_call_terminate($14);
    // unreachable;
   } else {
    ___resumeException($10|0);
    // unreachable;
   }
  }
 } while(0);
 $20 = HEAP32[800264>>2]|0;
 $21 = (__ZN10MemoryPool8AllocateEj($20,40)|0);
 $22 = $2;
 $23 = (($21) + 16|0);
 $24 = HEAP32[$__k>>2]|0;
 HEAP32[$23>>2] = $24;
 $25 = (($21) + 20|0);
 $26 = (($21) + 26|0);
 HEAP8[$26>>0] = 0;
 HEAP32[$25>>2] = 0;
 HEAP32[$agg$result>>2] = $21;
 $27 = (($agg$result) + 4|0);
 $28 = $27;
 $29 = $28;
 HEAP32[$29>>2] = $22;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = 257;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a19771() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799784);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[799776>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799800);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[799792>>2] = $2;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799824);
 $3 = HEAP32[$0>>2]|0;
 HEAP32[799816>>2] = $3;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799848);
 $4 = HEAP32[$0>>2]|0;
 HEAP32[799840>>2] = $4;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799872);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[799864>>2] = $5;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799904);
 $6 = HEAP32[$0>>2]|0;
 HEAP32[799896>>2] = $6;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799928);
 $7 = HEAP32[$0>>2]|0;
 HEAP32[799920>>2] = $7;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,799952);
 $8 = HEAP32[$0>>2]|0;
 HEAP32[799944>>2] = $8;
 STACKTOP = sp;return;
}
function __ZN21ImposterRenderTextureC2ERK12TreeDatabase($this,$treeDB) {
 $this = $this|0;
 $treeDB = $treeDB|0;
 var $$$i = 0, $$0 = 0, $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $i$08 = 0, $i1$07 = 0;
 var $runOffset$06 = Math_fround(0), $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $totalPixelWidth$0$lcssa = Math_fround(0), $totalPixelWidth$09 = Math_fround(0), $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $0 = sp + 24|0;
 $1 = sp + 8|0;
 HEAP32[$this>>2] = $treeDB;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 28|0);
 HEAPF32[$5>>2] = Math_fround(inf);
 $6 = (($this) + 32|0);
 HEAPF32[$6>>2] = Math_fround(inf);
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = 256;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = 2048;
 $9 = (($this) + 44|0);
 dest=$9+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vi(3396,1);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 do {
  if ($11) {
   label = 6;
  } else {
   __THREW__ = 0;
   $12 = (invoke_i(124)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
   } else {
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3396,0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 6;
      break;
     }
     $17 = (($this) + 24|0);
     HEAP8[$17>>0] = 0;
     $18 = (($this) + 20|0);
     HEAP32[$18>>2] = 0;
     $19 = (($this) + 16|0);
     HEAP32[$19>>2] = 0;
     STACKTOP = sp;return;
    }
    $22 = (($this) + 24|0);
    HEAP8[$22>>0] = 1;
    $23 = HEAP32[$this>>2]|0;
    $24 = (($23) + 32|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 28|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = $25;
    $29 = $27;
    $30 = (($28) - ($29))|0;
    $31 = $30 >> 7;
    $32 = HEAP32[$3>>2]|0;
    $33 = HEAP32[$2>>2]|0;
    $34 = $32;
    $35 = $33;
    $36 = (($34) - ($35))|0;
    $37 = $36 >> 4;
    $38 = ($37>>>0)<($31>>>0);
    if ($38) {
     $39 = (($31) - ($37))|0;
     __THREW__ = 0;
     invoke_vii(2698,($2|0),($39|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      label = 6;
      break;
     }
    } else {
     $42 = ($37>>>0)>($31>>>0);
     if ($42) {
      $43 = (($33) + ($31<<4)|0);
      $44 = ($32|0)==($43|0);
      if (!($44)) {
       $__new_last2$i$i$i = $43;
       $scevgep$i$i$i = (($32) + -16|0);
       $45 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($45)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $46 = $uglygep3$i$i$i >>> 4;
       $47 = $46 ^ -1;
       $scevgep4$i$i$i = (($32) + ($47<<4)|0);
       HEAP32[$3>>2] = $scevgep4$i$i$i;
      }
     }
    }
    $48 = HEAP32[$24>>2]|0;
    $49 = HEAP32[$26>>2]|0;
    $50 = ($48|0)==($49|0);
    $$pre = HEAP32[$7>>2]|0;
    if ($50) {
     $89 = $48;$totalPixelWidth$0$lcssa = Math_fround(0.0);
    } else {
     $51 = (Math_fround(($$pre|0)));
     $52 = $48;
     $53 = $49;
     $54 = (($52) - ($53))|0;
     $55 = $54 >> 7;
     $i$08 = 0;$totalPixelWidth$09 = Math_fround(0.0);
     while(1) {
      $56 = ((($49) + ($i$08<<7)|0) + 96|0);
      $57 = Math_fround(HEAPF32[$56>>2]);
      $58 = $57 < Math_fround(1.0);
      $59 = $58 ? $57 : Math_fround(1.0);
      $60 = Math_fround($51 * $59);
      $61 = Math_fround($60 + Math_fround(1.0));
      $62 = Math_fround($totalPixelWidth$09 + $61);
      $63 = (($i$08) + 1)|0;
      $64 = ($63>>>0)<($55>>>0);
      if ($64) {
       $i$08 = $63;$totalPixelWidth$09 = $62;
      } else {
       $89 = $49;$totalPixelWidth$0$lcssa = $62;
       break;
      }
     }
    }
    $65 = Math_fround($totalPixelWidth$0$lcssa + Math_fround(0.5));
    $66 = (~~(($65))>>>0);
    $67 = (($66) + -1)|0;
    $68 = $67 >>> 16;
    $69 = $68 | $67;
    $70 = $69 >>> 8;
    $71 = $70 | $69;
    $72 = $71 >>> 4;
    $73 = $72 | $71;
    $74 = $73 >>> 2;
    $75 = $74 | $73;
    $76 = $75 >>> 1;
    $77 = $76 | $75;
    $78 = (($77) + 1)|0;
    $79 = $78 >>> 1;
    $80 = (($66) - ($79))|0;
    $81 = (($78) - ($66))|0;
    $82 = ($80>>>0)<($81>>>0);
    $$$i = $82 ? $79 : $78;
    $83 = HEAP32[$8>>2]|0;
    $84 = ($$$i|0)<($83|0);
    $85 = $84 ? $$$i : $83;
    $86 = (Math_fround(($85|0)));
    $87 = Math_fround(Math_fround(1.0) / $86);
    $88 = ($48|0)==($89|0);
    if (!($88)) {
     $90 = HEAP32[$2>>2]|0;
     $91 = $48;
     $92 = $89;
     $93 = (($91) - ($92))|0;
     $94 = $93 >> 7;
     $i1$07 = 0;$runOffset$06 = Math_fround(0.0);
     while(1) {
      $95 = ((($89) + ($i1$07<<7)|0) + 96|0);
      $96 = Math_fround(HEAPF32[$95>>2]);
      $97 = $96 < Math_fround(1.0);
      $98 = $97 ? $96 : Math_fround(1.0);
      $99 = (Math_fround(($$pre|0)));
      $100 = Math_fround($99 * $98);
      $101 = Math_fround($100 / $totalPixelWidth$0$lcssa);
      $102 = Math_fround($87 + $runOffset$06);
      $103 = Math_fround($101 - $87);
      $104 = Math_fround($103 - $87);
      $105 = (($90) + ($i1$07<<4)|0);
      HEAPF32[$105>>2] = $102;
      $106 = ((($90) + ($i1$07<<4)|0) + 8|0);
      HEAPF32[$106>>2] = $104;
      $107 = ((($90) + ($i1$07<<4)|0) + 4|0);
      HEAPF32[$107>>2] = Math_fround(0.0);
      $108 = ((($90) + ($i1$07<<4)|0) + 12|0);
      HEAPF32[$108>>2] = Math_fround(1.0);
      $109 = Math_fround($runOffset$06 + $101);
      $110 = (($i1$07) + 1)|0;
      $111 = ($110>>>0)<($94>>>0);
      if ($111) {
       $i1$07 = $110;$runOffset$06 = $109;
      } else {
       break;
      }
     }
    }
    __THREW__ = 0;
    $112 = (invoke_iii(2597,($85|0),($$pre|0))|0);
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    if ($114) {
     label = 6;
    } else {
     $115 = (($this) + 20|0);
     HEAP32[$115>>2] = $112;
     __THREW__ = 0;
     $116 = (invoke_ii(2988,16)|0);
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      label = 6;
     } else {
      $119 = (($0) + 8|0);
      HEAP32[$119>>2] = $116;
      HEAP32[$0>>2] = 17;
      $120 = (($0) + 4|0);
      HEAP32[$120>>2] = 15;
      dest=$116+0|0; src=800296+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
      $121 = (($116) + 15|0);
      HEAP8[$121>>0] = 0;
      __THREW__ = 0;
      HEAP32[$vararg_buffer>>2] = 0;
      $122 = (invoke_iiiiii(197,($0|0),1,61,(800312|0),($vararg_buffer|0))|0);
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       $159 = ___cxa_find_matching_catch()|0;
       $160 = tempRet0;
       $161 = HEAP8[$0>>0]|0;
       $162 = $161 & 1;
       $163 = ($162<<24>>24)==(0);
       if ($163) {
        $$0 = $159;$$01 = $160;
        break;
       }
       $164 = HEAP32[$119>>2]|0;
       __ZdlPv($164);
       $$0 = $159;$$01 = $160;
       break;
      }
      $125 = HEAP8[$0>>0]|0;
      $126 = $125 & 1;
      $127 = ($126<<24>>24)==(0);
      if (!($127)) {
       $128 = HEAP32[$119>>2]|0;
       __ZdlPv($128);
      }
      __THREW__ = 0;
      $129 = (invoke_iii(2363,($122|0),20)|0);
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       label = 6;
      } else {
       $132 = (($this) + 16|0);
       HEAP32[$132>>2] = $129;
       $133 = HEAP32[$115>>2]|0;
       __THREW__ = 0;
       invoke_vii(3412,($129|0),($133|0));
       $134 = __THREW__; __THREW__ = 0;
       $135 = $134&1;
       if ($135) {
        label = 6;
       } else {
        $136 = HEAP32[$132>>2]|0;
        __THREW__ = 0;
        invoke_vii(2635,($136|0),2);
        $137 = __THREW__; __THREW__ = 0;
        $138 = $137&1;
        if ($138) {
         label = 6;
        } else {
         $139 = HEAP32[$132>>2]|0;
         HEAPF32[$1>>2] = Math_fround(0.20000000298023223877);
         $140 = (($1) + 4|0);
         HEAPF32[$140>>2] = Math_fround(0.20000000298023223877);
         $141 = (($1) + 8|0);
         HEAPF32[$141>>2] = Math_fround(0.20000000298023223877);
         $142 = (($1) + 12|0);
         HEAPF32[$142>>2] = Math_fround(0.0);
         __THREW__ = 0;
         invoke_vii(2636,($139|0),($1|0));
         $143 = __THREW__; __THREW__ = 0;
         $144 = $143&1;
         if ($144) {
          label = 6;
         } else {
          $145 = HEAP32[$132>>2]|0;
          __THREW__ = 0;
          invoke_vii(2633,($145|0),1);
          $146 = __THREW__; __THREW__ = 0;
          $147 = $146&1;
          if ($147) {
           label = 6;
          } else {
           $148 = HEAP32[$132>>2]|0;
           __THREW__ = 0;
           invoke_vii(2637,($148|0),0);
           $149 = __THREW__; __THREW__ = 0;
           $150 = $149&1;
           if ($150) {
            label = 6;
           } else {
            $151 = HEAP32[$132>>2]|0;
            $152 = HEAP32[$151>>2]|0;
            $153 = (($152) + 120|0);
            $154 = HEAP32[$153>>2]|0;
            __THREW__ = 0;
            invoke_vii($154|0,($151|0),0);
            $155 = __THREW__; __THREW__ = 0;
            $156 = $155&1;
            if ($156) {
             label = 6;
            } else {
             __THREW__ = 0;
             invoke_vi(3396,0);
             $157 = __THREW__; __THREW__ = 0;
             $158 = $157&1;
             if ($158) {
              label = 6;
             } else {
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $$0 = $20;$$01 = $21;
 }
 $165 = HEAP32[$2>>2]|0;
 $166 = ($165|0)==(0|0);
 if ($166) {
  ___resumeException($$0|0);
  // unreachable;
 }
 $167 = HEAP32[$3>>2]|0;
 $168 = ($167|0)==($165|0);
 if (!($168)) {
  $__new_last2$i$i$i$i$i = $165;
  $scevgep$i$i$i$i$i = (($167) + -16|0);
  $169 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($169)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $170 = $uglygep3$i$i$i$i$i >>> 4;
  $171 = $170 ^ -1;
  $scevgep4$i$i$i$i$i = (($167) + ($171<<4)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($165);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZL16CreateImposterRTii($width,$height) {
 $width = $width|0;
 $height = $height|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(172,$$byval_copy2,1,16,800320,30)|0);
 $4 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1743,($3|0),($$byval_copy2|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($3)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vi[$10 & 4095]($7);
  $11 = HEAP32[$7>>2]|0;
  $12 = (($11) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($7,61);
  __ZN13RenderTexture8SetWidthEi($7,$width);
  __ZN13RenderTexture9SetHeightEi($7,$height);
  __ZN13RenderTexture14SetColorFormatE19RenderTextureFormat($7,0);
  __ZN13RenderTexture14SetDepthFormatE17DepthBufferFormat($7,1);
  $14 = (__Z19GetActiveColorSpacev()|0);
  $15 = ($14|0)==(1);
  __ZN13RenderTexture16SetSRGBReadWriteEb($7,$15);
  $16 = HEAP32[$7>>2]|0;
  $17 = (($16) + 36|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_vii[$18 & 4095]($7,800376);
  __ZN13RenderTexture9SetMipMapEb($7,1);
  __ZN7Texture13SetMipMapBiasEf($7,Math_fround(-1.0));
  $19 = HEAP32[$7>>2]|0;
  $20 = (($19) + 12|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_vii[$21 & 4095]($7,4);
  STACKTOP = sp;return ($7|0);
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(800320|0),30);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch(0|0)|0;
  $27 = tempRet0;
  ___clang_call_terminate($26);
  // unreachable;
 } else {
  ___resumeException($22|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN21ImposterRenderTextureD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0;
 var $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 7;
 } else {
  $3 = (($1) + 24|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vii(2597,($4|0),0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   label = 7;
  }
 }
 do {
  if ((label|0) == 7) {
   $18 = (($this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   if (!($20)) {
    __THREW__ = 0;
    invoke_vi(3709,($19|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
   }
   $23 = (($this) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   if ($25) {
    STACKTOP = sp;return;
   }
   $26 = (($this) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==($24|0);
   if (!($28)) {
    $__new_last2$i$i$i$i$i = $24;
    $scevgep$i$i$i$i$i = (($27) + -16|0);
    $29 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($29)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $30 = $uglygep3$i$i$i$i$i >>> 4;
    $31 = $30 ^ -1;
    $scevgep4$i$i$i$i$i = (($27) + ($31<<4)|0);
    HEAP32[$26>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($24);
   STACKTOP = sp;return;
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  ___resumeException($7|0);
  // unreachable;
 }
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($10|0);
 if (!($14)) {
  $__new_last2$i$i$i$i$i1 = $10;
  $scevgep$i$i$i$i$i2 = (($13) + -16|0);
  $15 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($15)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $16 = $uglygep3$i$i$i$i$i5 >>> 4;
  $17 = $16 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($13) + ($17<<4)|0);
  HEAP32[$12>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($10);
 ___resumeException($7|0);
 // unreachable;
}
function __ZN21ImposterRenderTexture15UpdateImpostersERK6Camera($this,$mainCamera) {
 $this = $this|0;
 $mainCamera = $mainCamera|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $delta$0$i = Math_fround(0), $delta$0$i3 = Math_fround(0), $floorf$i$i$i = Math_fround(0), $floorf$i$i$i2 = Math_fround(0), $i$05 = 0, $pos$i$i$i$i$i$i = 0, $rtRecreated$0$off0 = 0, $temp$0$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $pos$i$i$i$i$i$i = sp + 144|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 16|0;
 $3 = sp + 32|0;
 $4 = sp + 48|0;
 $5 = sp + 112|0;
 $6 = sp + 128|0;
 $7 = (__Z12GetGfxDevicev()|0);
 $8 = (($7) + 5784|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $11 = (__Z12GetGfxDevicev()|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 504|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 4095]($11);
 }
 $15 = (__Z19GetActiveColorSpacev()|0);
 $16 = ($15|0)==(1);
 $17 = (($this) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 130|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = $21 ^ $16;
 if ($22) {
  $23 = (($18) + 100|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($18) + 104|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (__ZL16CreateImposterRTii($24,$26)|0);
  $28 = (($this) + 16|0);
  $29 = HEAP32[$28>>2]|0;
  __ZN6Camera16SetTargetTextureEP13RenderTexture($29,$27);
  $30 = HEAP32[$17>>2]|0;
  __Z19DestroySingleObjectP6Object($30);
  HEAP32[$17>>2] = $27;
  $rtRecreated$0$off0 = 1;
 } else {
  $rtRecreated$0$off0 = 0;
 }
 $31 = (($mainCamera) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($32)|0);
 __ZNK9Transform11GetRotationEv($2,$33);
 __Z17QuaternionToEulerRK11Quaternionf($1,$2);
 $34 = HEAP32[$17>>2]|0;
 $35 = (($34) + 140|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $38 = (($34) + 148|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  if ($40) {
   $$pre = (($this) + 28|0);
   $$pre$phiZ2D = $$pre;
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  $41 = (($this) + 28|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = $42 != Math_fround(inf);
  if ($43) {
   $44 = Math_fround(HEAPF32[$1>>2]);
   $45 = Math_fround($44 - $42);
   $46 = Math_fround($45 / Math_fround(6.28318548202514648438));
   $floorf$i$i$i = (Math_fround(Math_floor((Math_fround($46)))));
   $47 = Math_fround($floorf$i$i$i * Math_fround(6.28318548202514648438));
   $48 = Math_fround($45 - $47);
   $49 = $48 > Math_fround(3.14159274101257324219);
   if ($49) {
    $50 = Math_fround($48 + Math_fround(-6.28318548202514648438));
    $delta$0$i = $50;
   } else {
    $delta$0$i = $48;
   }
   $51 = (Math_fround(Math_abs((Math_fround($delta$0$i)))));
   $52 = $51 < Math_fround(0.00174532923847436904907);
   if ($52) {
    $53 = (($this) + 32|0);
    $54 = Math_fround(HEAPF32[$53>>2]);
    $55 = $54 != Math_fround(inf);
    if ($55) {
     $56 = (($1) + 4|0);
     $57 = Math_fround(HEAPF32[$56>>2]);
     $58 = Math_fround($57 - $54);
     $59 = Math_fround($58 / Math_fround(6.28318548202514648438));
     $floorf$i$i$i2 = (Math_fround(Math_floor((Math_fround($59)))));
     $60 = Math_fround($floorf$i$i$i2 * Math_fround(6.28318548202514648438));
     $61 = Math_fround($58 - $60);
     $62 = $61 > Math_fround(3.14159274101257324219);
     if ($62) {
      $63 = Math_fround($61 + Math_fround(-6.28318548202514648438));
      $delta$0$i3 = $63;
     } else {
      $delta$0$i3 = $61;
     }
     $64 = (Math_fround(Math_abs((Math_fround($delta$0$i3)))));
     $65 = $64 < Math_fround(0.00174532923847436904907);
     if ($65) {
      STACKTOP = sp;return ($rtRecreated$0$off0|0);
     } else {
      $$pre$phiZ2D = $41;
     }
    } else {
     $$pre$phiZ2D = $41;
    }
   } else {
    $$pre$phiZ2D = $41;
   }
  } else {
   $$pre$phiZ2D = $41;
  }
 }
 $66 = Math_fround(HEAPF32[$1>>2]);
 HEAPF32[$$pre$phiZ2D>>2] = $66;
 $67 = (($1) + 4|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($this) + 32|0);
 HEAPF32[$69>>2] = $68;
 $70 = (($this) + 16|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + 24|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($73)|0);
 $75 = Math_fround(HEAPF32[$1>>2]);
 $76 = Math_fround(HEAPF32[$67>>2]);
 $77 = Math_fround($75 * Math_fround(57.2957763671875));
 $78 = Math_fround($76 * Math_fround(57.2957763671875));
 HEAPF32[$3>>2] = $77;
 $79 = (($3) + 4|0);
 HEAPF32[$79>>2] = $78;
 $80 = (($3) + 8|0);
 HEAPF32[$80>>2] = Math_fround(0.0);
 __ZN9Transform19SetLocalEulerAnglesERK8Vector3f($74,$3);
 $81 = (($this) + 44|0);
 $82 = HEAP32[$70>>2]|0;
 __ZNK6Camera22GetCameraToWorldMatrixEv($4,$82);
 dest=$81+0|0; src=$4+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $83 = (__Z16GetRenderManagerv()|0);
 $84 = HEAP32[$83>>2]|0;
 HEAP32[$0>>2] = $84;
 $85 = HEAP32[560624>>2]|0;
 $86 = ($85|0)==(0|0);
 if ($86) {
  label = 24;
 } else {
  $87 = (($85) + 36|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($85) + 4|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($88|0)==($90|0);
  do {
   if ($91) {
    $92 = (($85) + 28|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (($85) + 32|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($93) + ($95<<3)|0);
    $112 = $96;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i$i,$85,$0);
    $97 = HEAP32[$pos$i$i$i$i$i$i>>2]|0;
    $98 = ($97|0)==(-1);
    $99 = (($85) + 28|0);
    $100 = HEAP32[$99>>2]|0;
    if ($98) {
     $101 = (($85) + 32|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = (($100) + ($102<<3)|0);
     $112 = $103;
     break;
    } else {
     $104 = (($100) + ($97<<3)|0);
     $112 = $104;
     break;
    }
   }
  } while(0);
  $105 = HEAP32[560624>>2]|0;
  $106 = (($105) + 28|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($105) + 32|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($107) + ($109<<3)|0);
  $111 = ($112|0)==($110|0);
  if ($111) {
   label = 24;
  } else {
   $113 = (($112) + 4|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = ($114|0)==(0|0);
   if ($115) {
    label = 24;
   } else {
    $temp$0$i$i$i = $114;
   }
  }
 }
 if ((label|0) == 24) {
  $116 = HEAP32[$83>>2]|0;
  $117 = (__Z31ReadObjectFromPersistentManageri($116)|0);
  $temp$0$i$i$i = $117;
 }
 $118 = HEAP32[$70>>2]|0;
 HEAPF32[$5>>2] = Math_fround(0.0);
 $119 = (($5) + 8|0);
 HEAPF32[$119>>2] = Math_fround(1.0);
 $120 = (($5) + 4|0);
 HEAPF32[$120>>2] = Math_fround(0.0);
 $121 = (($5) + 12|0);
 HEAPF32[$121>>2] = Math_fround(1.0);
 __ZN6Camera25SetNormalizedViewportRectERK5RectTIfE($118,$5);
 $122 = HEAP32[$70>>2]|0;
 __ZN6Camera13SetClearFlagsEi($122,2);
 $123 = HEAP32[$70>>2]|0;
 HEAP8[$6>>0] = 0;
 $124 = (($6) + 1|0);
 HEAP8[$124>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(348,($123|0),10,(0|0),($6|0));
 $125 = __THREW__; __THREW__ = 0;
 $126 = $125&1;
 if ($126) {
  $151 = ___cxa_find_matching_catch()|0;
  $152 = tempRet0;
  $153 = HEAP8[$6>>0]|0;
  $154 = $153 & 1;
  $155 = ($154<<24>>24)==(0);
  if ($155) {
   ___resumeException($151|0);
   // unreachable;
  }
  $156 = (($6) + 8|0);
  $157 = HEAP32[$156>>2]|0;
  __ZdlPv($157);
  ___resumeException($151|0);
  // unreachable;
 }
 $127 = HEAP8[$6>>0]|0;
 $128 = $127 & 1;
 $129 = ($128<<24>>24)==(0);
 if (!($129)) {
  $130 = (($6) + 8|0);
  $131 = HEAP32[$130>>2]|0;
  __ZdlPv($131);
 }
 $132 = HEAP32[$this>>2]|0;
 $133 = (($132) + 32|0);
 $134 = HEAP32[$133>>2]|0;
 $135 = (($132) + 28|0);
 $136 = HEAP32[$135>>2]|0;
 $137 = ($134|0)==($136|0);
 if (!($137)) {
  $138 = (($this) + 4|0);
  $142 = $136;$i$05 = 0;
  while(1) {
   $139 = HEAP32[$138>>2]|0;
   $140 = (($139) + ($i$05<<4)|0);
   $141 = (($142) + ($i$05<<7)|0);
   __ZN21ImposterRenderTexture14UpdateImposterERK5RectTIfERKN12TreeDatabase9PrototypeE($this,$140,$141);
   $143 = (($i$05) + 1)|0;
   $144 = HEAP32[$133>>2]|0;
   $145 = HEAP32[$135>>2]|0;
   $146 = $144;
   $147 = $145;
   $148 = (($146) - ($147))|0;
   $149 = $148 >> 7;
   $150 = ($143>>>0)<($149>>>0);
   if ($150) {
    $142 = $145;$i$05 = $143;
   } else {
    break;
   }
  }
 }
 $158 = HEAP32[652824>>2]|0;
 __ZN6Camera15StandaloneSetupERN9ShaderLab17ShaderPassContextE($temp$0$i$i$i,$158);
 STACKTOP = sp;return ($rtRecreated$0$off0|0);
}
function __ZN21ImposterRenderTexture14UpdateImposterERK5RectTIfERKN12TreeDatabase9PrototypeE($this,$rect,$prototype) {
 $this = $this|0;
 $rect = $rect|0;
 $prototype = $prototype|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0);
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0);
 var $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $m$08 = 0, $p$07 = 0, $phitmp$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy2 = sp + 112|0;
 $0 = sp + 108|0;
 $1 = sp + 104|0;
 $2 = sp + 92|0;
 $3 = sp + 80|0;
 $4 = sp + 68|0;
 $5 = sp + 56|0;
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp + 8|0;
 $9 = sp + 4|0;
 $10 = sp;
 $11 = sp + 40|0;
 $12 = (($prototype) + 76|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($prototype) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $16;
 $18 = HEAP32[560624>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  label = 11;
 } else {
  $20 = (($18) + 36|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($18) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($21|0)==($23|0);
  do {
   if ($24) {
    $25 = (($18) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($18) + 32|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + ($28<<3)|0);
    $45 = $29;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$18,$1);
    $30 = HEAP32[$$byval_copy2>>2]|0;
    $31 = ($30|0)==(-1);
    $32 = (($18) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    if ($31) {
     $34 = (($18) + 32|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($33) + ($35<<3)|0);
     $45 = $36;
     break;
    } else {
     $37 = (($33) + ($30<<3)|0);
     $45 = $37;
     break;
    }
   }
  } while(0);
  $38 = HEAP32[560624>>2]|0;
  $39 = (($38) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 32|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + ($42<<3)|0);
  $44 = ($45|0)==($43|0);
  if ($44) {
   label = 11;
  } else {
   $46 = (($45) + 4|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    label = 11;
   }
  }
 }
 if ((label|0) == 11) {
  $49 = HEAP32[$15>>2]|0;
  $50 = (__Z31ReadObjectFromPersistentManageri($49)|0);
  $phitmp$i = ($50|0)==(0|0);
  if ($phitmp$i) {
   STACKTOP = sp;return;
  }
 }
 $51 = (($this) + 16|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($52) + 24|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($54)|0);
 $56 = (($prototype) + 88|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = (($prototype) + 84|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($59 * Math_fround(0.5));
 $61 = Math_fround($57 - $60);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $62 = (($2) + 4|0);
 HEAPF32[$62>>2] = $61;
 $63 = (($2) + 8|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 __ZN9Transform11SetPositionERK8Vector3f($55,$2);
 __ZNK9Transform11GetPositionEv($4,$55);
 $64 = Math_fround(HEAPF32[616744>>2]);
 $65 = Math_fround(HEAPF32[((616744 + 4|0))>>2]);
 $66 = Math_fround(HEAPF32[((616744 + 8|0))>>2]);
 $67 = Math_fround(HEAPF32[$58>>2]);
 $68 = (($prototype) + 92|0);
 $69 = Math_fround(HEAPF32[$68>>2]);
 $70 = Math_fround($67 + $69);
 $71 = Math_fround($64 * $70);
 $72 = Math_fround($65 * $70);
 $73 = Math_fround($66 * $70);
 $74 = Math_fround($71 * Math_fround(-2.0));
 $75 = Math_fround($72 * Math_fround(-2.0));
 $76 = Math_fround($73 * Math_fround(-2.0));
 HEAPF32[$6>>2] = $74;
 $77 = (($6) + 4|0);
 HEAPF32[$77>>2] = $75;
 $78 = (($6) + 8|0);
 HEAPF32[$78>>2] = $76;
 __ZNK9Transform18TransformDirectionERK8Vector3f($5,$55,$6);
 $79 = Math_fround(HEAPF32[$4>>2]);
 $80 = Math_fround(HEAPF32[$5>>2]);
 $81 = Math_fround($79 + $80);
 $82 = (($4) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = (($5) + 4|0);
 $85 = Math_fround(HEAPF32[$84>>2]);
 $86 = Math_fround($83 + $85);
 $87 = (($4) + 8|0);
 $88 = Math_fround(HEAPF32[$87>>2]);
 $89 = (($5) + 8|0);
 $90 = Math_fround(HEAPF32[$89>>2]);
 $91 = Math_fround($88 + $90);
 HEAPF32[$3>>2] = $81;
 $92 = (($3) + 4|0);
 HEAPF32[$92>>2] = $86;
 $93 = (($3) + 8|0);
 HEAPF32[$93>>2] = $91;
 __ZN9Transform11SetPositionERK8Vector3f($55,$3);
 $94 = HEAP32[$51>>2]|0;
 __ZN6Camera13SetClearFlagsEi($94,4);
 $95 = HEAP32[$51>>2]|0;
 __ZN6Camera25SetNormalizedViewportRectERK5RectTIfE($95,$rect);
 $96 = HEAP32[$51>>2]|0;
 $97 = (($prototype) + 96|0);
 $98 = Math_fround(HEAPF32[$97>>2]);
 $99 = $98 < Math_fround(1.0);
 $100 = $99 ? $98 : Math_fround(1.0);
 __ZN6Camera9SetAspectEf($96,$100);
 $101 = HEAP32[$51>>2]|0;
 $102 = Math_fround(HEAPF32[$58>>2]);
 $103 = Math_fround(HEAPF32[$68>>2]);
 $104 = $102 < $103;
 $105 = $104 ? $103 : $102;
 $106 = Math_fround($105 * Math_fround(0.5));
 __ZN6Camera19SetOrthographicSizeEf($101,$106);
 $107 = HEAP32[$51>>2]|0;
 HEAP8[$7>>0] = 0;
 $108 = (($7) + 1|0);
 HEAP8[$108>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(348,($107|0),10,(0|0),($7|0));
 $109 = __THREW__; __THREW__ = 0;
 $110 = $109&1;
 if ($110) {
  $175 = ___cxa_find_matching_catch()|0;
  $176 = tempRet0;
  $177 = HEAP8[$7>>0]|0;
  $178 = $177 & 1;
  $179 = ($178<<24>>24)==(0);
  if ($179) {
   ___resumeException($175|0);
   // unreachable;
  }
  $180 = (($7) + 8|0);
  $181 = HEAP32[$180>>2]|0;
  __ZdlPv($181);
  ___resumeException($175|0);
  // unreachable;
 }
 $111 = HEAP8[$7>>0]|0;
 $112 = $111 & 1;
 $113 = ($112<<24>>24)==(0);
 if (!($113)) {
  $114 = (($7) + 8|0);
  $115 = HEAP32[$114>>2]|0;
  __ZdlPv($115);
 }
 HEAP32[$$byval_copy2>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy2,800328);
 $116 = HEAP32[$$byval_copy2>>2]|0;
 HEAP32[$$byval_copy2>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy2,800336);
 $117 = HEAP32[$$byval_copy2>>2]|0;
 HEAP32[$$byval_copy2>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($$byval_copy2,800352);
 $118 = HEAP32[$$byval_copy2>>2]|0;
 $119 = HEAP32[652824>>2]|0;
 $120 = HEAP32[$12>>2]|0;
 $121 = ($120|0)==(0);
 if ($121) {
  STACKTOP = sp;return;
 }
 $122 = (($prototype) + 52|0);
 $123 = (($prototype) + 20|0);
 $124 = (($prototype) + 68|0);
 $125 = (($11) + 4|0);
 $126 = (($11) + 8|0);
 $127 = (($11) + 12|0);
 $m$08 = 0;
 while(1) {
  $128 = HEAP32[$122>>2]|0;
  $129 = (($128) + ($m$08<<4)|0);
  $130 = HEAP32[$123>>2]|0;
  $131 = (($130) + ($m$08<<2)|0);
  $132 = Math_fround(HEAPF32[$131>>2]);
  $133 = HEAP32[$124>>2]|0;
  $134 = (($133) + ($m$08<<2)|0);
  $135 = HEAP32[$134>>2]|0;
  HEAP32[$8>>2] = $116;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$8+0>>2]|0;
  __ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf($135,$$byval_copy2,$129);
  HEAP32[$9>>2] = $117;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$9+0>>2]|0;
  __ZN5Unity8Material8SetFloatEN9ShaderLab16FastPropertyNameEf($135,$$byval_copy2,$132);
  HEAP32[$10>>2] = $118;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$10+0>>2]|0;
  __ZN5Unity8Material9SetMatrixEN9ShaderLab16FastPropertyNameERK10Matrix4x4f($135,$$byval_copy2,616552);
  $136 = (__ZN5Unity8Material12GetPassCountEv($135)|0);
  $137 = ($136|0)>(0);
  if ($137) {
   $p$07 = 0;
   while(1) {
    $138 = (__Z21CheckShouldRenderPassiRN5Unity8MaterialE($p$07,$135)|0);
    if ($138) {
     $139 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($135,$p$07,$119,0,1)|0);
     $140 = ($139|0)==(0|0);
     if (!($140)) {
      $141 = HEAP32[$15>>2]|0;
      HEAP32[$0>>2] = $141;
      $142 = HEAP32[560624>>2]|0;
      $143 = ($142|0)==(0|0);
      if ($143) {
       label = 28;
      } else {
       $144 = (($142) + 36|0);
       $145 = HEAP32[$144>>2]|0;
       $146 = (($142) + 4|0);
       $147 = HEAP32[$146>>2]|0;
       $148 = ($145|0)==($147|0);
       do {
        if ($148) {
         $149 = (($142) + 28|0);
         $150 = HEAP32[$149>>2]|0;
         $151 = (($142) + 32|0);
         $152 = HEAP32[$151>>2]|0;
         $153 = (($150) + ($152<<3)|0);
         $169 = $153;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$142,$0);
         $154 = HEAP32[$$byval_copy2>>2]|0;
         $155 = ($154|0)==(-1);
         $156 = (($142) + 28|0);
         $157 = HEAP32[$156>>2]|0;
         if ($155) {
          $158 = (($142) + 32|0);
          $159 = HEAP32[$158>>2]|0;
          $160 = (($157) + ($159<<3)|0);
          $169 = $160;
          break;
         } else {
          $161 = (($157) + ($154<<3)|0);
          $169 = $161;
          break;
         }
        }
       } while(0);
       $162 = HEAP32[560624>>2]|0;
       $163 = (($162) + 28|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = (($162) + 32|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = (($164) + ($166<<3)|0);
       $168 = ($169|0)==($167|0);
       if ($168) {
        label = 28;
       } else {
        $170 = (($169) + 4|0);
        $171 = HEAP32[$170>>2]|0;
        $172 = ($171|0)==(0|0);
        if ($172) {
         label = 28;
        } else {
         $temp$0$i = $171;
        }
       }
      }
      if ((label|0) == 28) {
       label = 0;
       $173 = HEAP32[$15>>2]|0;
       $174 = (__Z31ReadObjectFromPersistentManageri($173)|0);
       $temp$0$i = $174;
      }
      HEAPF32[$11>>2] = Math_fround(0.0);
      HEAPF32[$125>>2] = Math_fround(0.0);
      HEAPF32[$126>>2] = Math_fround(0.0);
      HEAPF32[$127>>2] = Math_fround(1.0);
      __ZN8DrawUtil8DrawMeshERK14ChannelAssignsR4MeshRK8Vector3fRK11Quaternionfi($139,$temp$0$i,616680,$11,$m$08);
     }
    }
    $182 = (($p$07) + 1)|0;
    $183 = (__ZN5Unity8Material12GetPassCountEv($135)|0);
    $184 = ($182|0)<($183|0);
    if ($184) {
     $p$07 = $182;
    } else {
     break;
    }
   }
  }
  $185 = (($m$08) + 1)|0;
  $186 = HEAP32[$12>>2]|0;
  $187 = ($185>>>0)<($186>>>0);
  if ($187) {
   $m$08 = $185;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK21ImposterRenderTexture18GetBillboardParamsERfS0_($this,$angleFactor,$offsetFactor) {
 $this = $this|0;
 $angleFactor = $angleFactor|0;
 $offsetFactor = $offsetFactor|0;
 var $$$i$i = Math_fround(0), $$0$i$i = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0);
 var $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround($1 * Math_fround(0.5));
 $3 = Math_fround($2 / Math_fround(3.14159274101257324219));
 $4 = Math_fround($3 * Math_fround(360.0));
 $5 = !($4 <= Math_fround(90.0));
 if ($5) {
  $6 = Math_fround($4 + Math_fround(-360.0));
  $8 = $6;
 } else {
  $8 = $4;
 }
 $7 = Math_fround($8 / Math_fround(360.0));
 $9 = Math_fround($7 * Math_fround(2.0));
 $10 = Math_fround($9 * Math_fround(3.14159274101257324219));
 $11 = (Math_fround(+(Math_cos((+$10)))));
 $12 = Math_fround(Math_fround(1.0) - $11);
 HEAPF32[$angleFactor>>2] = $12;
 $13 = (Math_fround(Math_abs((Math_fround($8)))));
 $14 = $13 < Math_fround(40.0);
 if ($14) {
  $29 = Math_fround(0.0);
  $28 = $29 > Math_fround(0.100000001490116119385);
  $30 = $28 ? $29 : Math_fround(0.100000001490116119385);
  HEAPF32[$offsetFactor>>2] = $30;
  STACKTOP = sp;return;
 }
 $15 = Math_fround($13 + Math_fround(-40.0));
 $16 = Math_fround($15 / Math_fround(50.0));
 $17 = $16 < Math_fround(0.0);
 if ($17) {
  $$0$i$i = Math_fround(0.0);
 } else {
  $18 = $16 > Math_fround(1.0);
  $$$i$i = $18 ? Math_fround(1.0) : $16;
  $$0$i$i = $$$i$i;
 }
 $19 = Math_fround($$0$i$i * Math_fround(-2.0));
 $20 = Math_fround($$0$i$i * $19);
 $21 = Math_fround($$0$i$i * $20);
 $22 = Math_fround($$0$i$i * Math_fround(3.0));
 $23 = Math_fround($$0$i$i * $22);
 $24 = Math_fround($23 + $21);
 $25 = Math_fround(Math_fround(1.0) - $24);
 $26 = Math_fround($25 * Math_fround(0.0));
 $27 = Math_fround($24 + $26);
 $29 = $27;
 $28 = $29 > Math_fround(0.100000001490116119385);
 $30 = $28 ? $29 : Math_fround(0.100000001490116119385);
 HEAPF32[$offsetFactor>>2] = $30;
 STACKTOP = sp;return;
}
function __ZNK9Heightmap13GetPatchIndexEiii($this,$x,$y,$level) {
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $level = $level|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $index$0$lcssa = 0, $index$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($level|0)>(0);
 $1 = (($this) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 if ($0) {
  $i$01 = 0;$index$02 = 0;
  while(1) {
   $3 = (($2) - ($i$01))|0;
   $4 = 1 << $3;
   $5 = $4 << $3;
   $6 = (($5) + ($index$02))|0;
   $7 = (($i$01) + 1)|0;
   $exitcond = ($7|0)==($level|0);
   if ($exitcond) {
    $index$0$lcssa = $6;
    break;
   } else {
    $i$01 = $7;$index$02 = $6;
   }
  }
 } else {
  $index$0$lcssa = 0;
 }
 $8 = (($2) - ($level))|0;
 $9 = $y << $8;
 $10 = (($index$0$lcssa) + ($x))|0;
 $11 = (($10) + ($9))|0;
 STACKTOP = sp;return ($11|0);
}
function __ZNK9Heightmap39CalculateNormalSobelRespectingNeighborsEiiPK15TerrainRenderer($agg$result,$this,$x,$y,$renderer) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $renderer = $renderer|0;
 var $$0$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 4|0);
 $1 = (($agg$result) + 8|0);
 $2 = (($x) + -1)|0;
 $3 = (($y) + -1)|0;
 $4 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$2,$3,$renderer)));
 $5 = Math_fround($4 * Math_fround(-1.0));
 $6 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$2,$y,$renderer)));
 $7 = Math_fround($6 * Math_fround(-2.0));
 $8 = Math_fround($5 + $7);
 $9 = (($y) + 1)|0;
 $10 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$2,$9,$renderer)));
 $11 = Math_fround($10 * Math_fround(-1.0));
 $12 = Math_fround($8 + $11);
 $13 = (($x) + 1)|0;
 $14 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$13,$3,$renderer)));
 $15 = Math_fround($14 + $12);
 $16 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$13,$y,$renderer)));
 $17 = Math_fround($16 * Math_fround(2.0));
 $18 = Math_fround($15 + $17);
 $19 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$13,$9,$renderer)));
 $20 = Math_fround($19 + $18);
 $21 = (($this) + 80|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($20 / $22);
 $24 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$2,$3,$renderer)));
 $25 = Math_fround($24 * Math_fround(-1.0));
 $26 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$x,$3,$renderer)));
 $27 = Math_fround($26 * Math_fround(-2.0));
 $28 = Math_fround($25 + $27);
 $29 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$13,$3,$renderer)));
 $30 = Math_fround($29 * Math_fround(-1.0));
 $31 = Math_fround($28 + $30);
 $32 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$2,$9,$renderer)));
 $33 = Math_fround($32 + $31);
 $34 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$x,$9,$renderer)));
 $35 = Math_fround($34 * Math_fround(2.0));
 $36 = Math_fround($33 + $35);
 $37 = (Math_fround(__ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$13,$9,$renderer)));
 $38 = Math_fround($37 + $36);
 $39 = (($this) + 88|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = Math_fround($38 / $40);
 $42 = Math_fround(-$23);
 HEAPF32[$agg$result>>2] = $42;
 HEAPF32[$0>>2] = Math_fround(8.0);
 $43 = Math_fround(-$41);
 HEAPF32[$1>>2] = $43;
 $44 = Math_fround($23 * $23);
 $45 = Math_fround($44 + Math_fround(64.0));
 $46 = Math_fround($41 * $41);
 $47 = Math_fround($46 + $45);
 $48 = $47 == Math_fround(0.0);
 if ($48) {
  $$0$i$i = $47;
  $51 = Math_fround($$0$i$i * $42);
  $52 = Math_fround($$0$i$i * Math_fround(8.0));
  $53 = Math_fround($$0$i$i * $43);
  HEAPF32[$agg$result>>2] = $51;
  HEAPF32[$0>>2] = $52;
  HEAPF32[$1>>2] = $53;
  STACKTOP = sp;return;
 }
 $49 = (Math_fround(Math_sqrt((Math_fround($47)))));
 $50 = Math_fround(Math_fround(1.0) / $49);
 $$0$i$i = $50;
 $51 = Math_fround($$0$i$i * $42);
 $52 = Math_fround($$0$i$i * Math_fround(8.0));
 $53 = Math_fround($$0$i$i * $43);
 HEAPF32[$agg$result>>2] = $51;
 HEAPF32[$0>>2] = $52;
 HEAPF32[$1>>2] = $53;
 STACKTOP = sp;return;
}
function __ZNK9Heightmap28GetHeightRespectingNeighborsEiiPK15TerrainRenderer($this,$x,$y,$renderer) {
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $renderer = $renderer|0;
 var $$$i$i$i = 0, $$$i1$i$i = 0, $$0 = 0, $$0$i$i$i = 0, $$0$i2$i$i = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $$2 = 0, $$neg59 = 0, $$neg61 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = Math_fround(0), $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = Math_fround(0), $351 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $lookup$0 = 0, $lookup$1 = 0, $lookup$2 = 0, $lookup$3 = 0, $or$cond = 0, $or$cond5 = 0, $or$cond6 = 0, $or$cond7 = 0, $pos$i$i$i$i46 = 0, $temp$0$i = 0, $temp$0$i17 = 0, $temp$0$i30 = 0, $temp$0$i50 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i46 = sp + 32|0;
 $0 = sp + 28|0;
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 12|0;
 $8 = ($x|0)>(-1);
 $9 = ($renderer|0)==(0|0);
 $or$cond = $8 | $9;
 do {
  if ($or$cond) {
   $$0 = $renderer;$$03 = $x;$lookup$0 = $this;
  } else {
   $10 = (($renderer) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$0 = $renderer;$$03 = $x;$lookup$0 = $this;
   } else {
    $13 = (($11) + 104|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0);
    if ($15) {
     $$0 = $renderer;$$03 = $x;$lookup$0 = $this;
    } else {
     HEAP32[$6>>2] = $14;
     $16 = HEAP32[560624>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 12;
     } else {
      $18 = (($16) + 36|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = (($16) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($19|0)==($21|0);
      do {
       if ($22) {
        $23 = (($16) + 28|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = (($16) + 32|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = (($24) + ($26<<3)|0);
        $43 = $27;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i46,$16,$6);
        $28 = HEAP32[$pos$i$i$i$i46>>2]|0;
        $29 = ($28|0)==(-1);
        $30 = (($16) + 28|0);
        $31 = HEAP32[$30>>2]|0;
        if ($29) {
         $32 = (($16) + 32|0);
         $33 = HEAP32[$32>>2]|0;
         $34 = (($31) + ($33<<3)|0);
         $43 = $34;
         break;
        } else {
         $35 = (($31) + ($28<<3)|0);
         $43 = $35;
         break;
        }
       }
      } while(0);
      $36 = HEAP32[560624>>2]|0;
      $37 = (($36) + 28|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 32|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($38) + ($40<<3)|0);
      $42 = ($43|0)==($41|0);
      if ($42) {
       label = 12;
      } else {
       $44 = (($43) + 4|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = ($45|0)==(0|0);
       if ($46) {
        label = 12;
       }
      }
     }
     if ((label|0) == 12) {
      $47 = (__Z31ReadObjectFromPersistentManageri($14)|0);
      $48 = ($47|0)==(0|0);
      if ($48) {
       $$0 = $renderer;$$03 = $x;$lookup$0 = $this;
       break;
      }
     }
     $49 = HEAP32[$10>>2]|0;
     $50 = (($49) + 104|0);
     $51 = HEAP32[$50>>2]|0;
     HEAP32[$5>>2] = $51;
     $52 = HEAP32[560624>>2]|0;
     $53 = ($52|0)==(0|0);
     if ($53) {
      label = 21;
     } else {
      $54 = (($52) + 36|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = (($52) + 4|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($55|0)==($57|0);
      do {
       if ($58) {
        $59 = (($52) + 28|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = (($52) + 32|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = (($60) + ($62<<3)|0);
        $79 = $63;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i46,$52,$5);
        $64 = HEAP32[$pos$i$i$i$i46>>2]|0;
        $65 = ($64|0)==(-1);
        $66 = (($52) + 28|0);
        $67 = HEAP32[$66>>2]|0;
        if ($65) {
         $68 = (($52) + 32|0);
         $69 = HEAP32[$68>>2]|0;
         $70 = (($67) + ($69<<3)|0);
         $79 = $70;
         break;
        } else {
         $71 = (($67) + ($64<<3)|0);
         $79 = $71;
         break;
        }
       }
      } while(0);
      $72 = HEAP32[560624>>2]|0;
      $73 = (($72) + 28|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = (($72) + 32|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = (($74) + ($76<<3)|0);
      $78 = ($79|0)==($77|0);
      if ($78) {
       label = 21;
      } else {
       $80 = (($79) + 4|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0|0);
       if ($82) {
        label = 21;
       } else {
        $temp$0$i17 = $81;
       }
      }
     }
     if ((label|0) == 21) {
      $83 = (__Z31ReadObjectFromPersistentManageri($51)|0);
      $temp$0$i17 = $83;
     }
     $84 = (($temp$0$i17) + 232|0);
     $85 = (($84) + 64|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($x) + -1)|0;
     $88 = (($87) + ($86))|0;
     $$0 = $49;$$03 = $88;$lookup$0 = $84;
    }
   }
  }
 } while(0);
 $89 = (($lookup$0) + 64|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = ($$03|0)<($90|0);
 $92 = ($$0|0)==(0|0);
 $or$cond5 = $91 | $92;
 do {
  if ($or$cond5) {
   $$1 = $$0;$$14 = $$03;$lookup$1 = $lookup$0;
  } else {
   $93 = (($$0) + 4|0);
   $94 = HEAP32[$93>>2]|0;
   $95 = ($94|0)==(0|0);
   if ($95) {
    $$1 = $$0;$$14 = $$03;$lookup$1 = $lookup$0;
   } else {
    $96 = (($94) + 104|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($97|0)==(0);
    if ($98) {
     $$1 = $$0;$$14 = $$03;$lookup$1 = $lookup$0;
    } else {
     HEAP32[$4>>2] = $97;
     $99 = HEAP32[560624>>2]|0;
     $100 = ($99|0)==(0|0);
     if ($100) {
      label = 34;
     } else {
      $101 = (($99) + 36|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = (($99) + 4|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = ($102|0)==($104|0);
      do {
       if ($105) {
        $106 = (($99) + 28|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = (($99) + 32|0);
        $109 = HEAP32[$108>>2]|0;
        $110 = (($107) + ($109<<3)|0);
        $126 = $110;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i46,$99,$4);
        $111 = HEAP32[$pos$i$i$i$i46>>2]|0;
        $112 = ($111|0)==(-1);
        $113 = (($99) + 28|0);
        $114 = HEAP32[$113>>2]|0;
        if ($112) {
         $115 = (($99) + 32|0);
         $116 = HEAP32[$115>>2]|0;
         $117 = (($114) + ($116<<3)|0);
         $126 = $117;
         break;
        } else {
         $118 = (($114) + ($111<<3)|0);
         $126 = $118;
         break;
        }
       }
      } while(0);
      $119 = HEAP32[560624>>2]|0;
      $120 = (($119) + 28|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = (($119) + 32|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = (($121) + ($123<<3)|0);
      $125 = ($126|0)==($124|0);
      if ($125) {
       label = 34;
      } else {
       $127 = (($126) + 4|0);
       $128 = HEAP32[$127>>2]|0;
       $129 = ($128|0)==(0|0);
       if ($129) {
        label = 34;
       }
      }
     }
     if ((label|0) == 34) {
      $130 = (__Z31ReadObjectFromPersistentManageri($97)|0);
      $131 = ($130|0)==(0|0);
      if ($131) {
       $$1 = $$0;$$14 = $$03;$lookup$1 = $lookup$0;
       break;
      }
     }
     $132 = HEAP32[$89>>2]|0;
     $$neg59 = (($$03) + 1)|0;
     $133 = (($$neg59) - ($132))|0;
     $134 = HEAP32[$93>>2]|0;
     $135 = (($134) + 104|0);
     $136 = HEAP32[$135>>2]|0;
     HEAP32[$3>>2] = $136;
     $137 = HEAP32[560624>>2]|0;
     $138 = ($137|0)==(0|0);
     if ($138) {
      label = 43;
     } else {
      $139 = (($137) + 36|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = (($137) + 4|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = ($140|0)==($142|0);
      do {
       if ($143) {
        $144 = (($137) + 28|0);
        $145 = HEAP32[$144>>2]|0;
        $146 = (($137) + 32|0);
        $147 = HEAP32[$146>>2]|0;
        $148 = (($145) + ($147<<3)|0);
        $164 = $148;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i46,$137,$3);
        $149 = HEAP32[$pos$i$i$i$i46>>2]|0;
        $150 = ($149|0)==(-1);
        $151 = (($137) + 28|0);
        $152 = HEAP32[$151>>2]|0;
        if ($150) {
         $153 = (($137) + 32|0);
         $154 = HEAP32[$153>>2]|0;
         $155 = (($152) + ($154<<3)|0);
         $164 = $155;
         break;
        } else {
         $156 = (($152) + ($149<<3)|0);
         $164 = $156;
         break;
        }
       }
      } while(0);
      $157 = HEAP32[560624>>2]|0;
      $158 = (($157) + 28|0);
      $159 = HEAP32[$158>>2]|0;
      $160 = (($157) + 32|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = (($159) + ($161<<3)|0);
      $163 = ($164|0)==($162|0);
      if ($163) {
       label = 43;
      } else {
       $165 = (($164) + 4|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = ($166|0)==(0|0);
       if ($167) {
        label = 43;
       } else {
        $temp$0$i30 = $166;
       }
      }
     }
     if ((label|0) == 43) {
      $168 = (__Z31ReadObjectFromPersistentManageri($136)|0);
      $temp$0$i30 = $168;
     }
     $169 = (($temp$0$i30) + 232|0);
     $$1 = $134;$$14 = $133;$lookup$1 = $169;
    }
   }
  }
 } while(0);
 $170 = ($y|0)>(-1);
 $171 = ($$1|0)==(0|0);
 $or$cond6 = $170 | $171;
 do {
  if ($or$cond6) {
   $$01 = $y;$$2 = $$1;$lookup$2 = $lookup$1;
  } else {
   $172 = (($$1) + 8|0);
   $173 = HEAP32[$172>>2]|0;
   $174 = ($173|0)==(0|0);
   if ($174) {
    $$01 = $y;$$2 = $$1;$lookup$2 = $lookup$1;
   } else {
    $175 = (($173) + 104|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = ($176|0)==(0);
    if ($177) {
     $$01 = $y;$$2 = $$1;$lookup$2 = $lookup$1;
    } else {
     HEAP32[$1>>2] = $176;
     $178 = HEAP32[560624>>2]|0;
     $179 = ($178|0)==(0|0);
     if ($179) {
      label = 56;
     } else {
      $180 = (($178) + 36|0);
      $181 = HEAP32[$180>>2]|0;
      $182 = (($178) + 4|0);
      $183 = HEAP32[$182>>2]|0;
      $184 = ($181|0)==($183|0);
      do {
       if ($184) {
        $185 = (($178) + 28|0);
        $186 = HEAP32[$185>>2]|0;
        $187 = (($178) + 32|0);
        $188 = HEAP32[$187>>2]|0;
        $189 = (($186) + ($188<<3)|0);
        $205 = $189;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i46,$178,$1);
        $190 = HEAP32[$pos$i$i$i$i46>>2]|0;
        $191 = ($190|0)==(-1);
        $192 = (($178) + 28|0);
        $193 = HEAP32[$192>>2]|0;
        if ($191) {
         $194 = (($178) + 32|0);
         $195 = HEAP32[$194>>2]|0;
         $196 = (($193) + ($195<<3)|0);
         $205 = $196;
         break;
        } else {
         $197 = (($193) + ($190<<3)|0);
         $205 = $197;
         break;
        }
       }
      } while(0);
      $198 = HEAP32[560624>>2]|0;
      $199 = (($198) + 28|0);
      $200 = HEAP32[$199>>2]|0;
      $201 = (($198) + 32|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = (($200) + ($202<<3)|0);
      $204 = ($205|0)==($203|0);
      if ($204) {
       label = 56;
      } else {
       $206 = (($205) + 4|0);
       $207 = HEAP32[$206>>2]|0;
       $208 = ($207|0)==(0|0);
       if ($208) {
        label = 56;
       }
      }
     }
     if ((label|0) == 56) {
      $209 = (__Z31ReadObjectFromPersistentManageri($176)|0);
      $210 = ($209|0)==(0|0);
      if ($210) {
       $$01 = $y;$$2 = $$1;$lookup$2 = $lookup$1;
       break;
      }
     }
     $211 = HEAP32[$172>>2]|0;
     $212 = (($211) + 104|0);
     $213 = HEAP32[$212>>2]|0;
     HEAP32[$0>>2] = $213;
     $214 = HEAP32[560624>>2]|0;
     $215 = ($214|0)==(0|0);
     if ($215) {
      label = 65;
     } else {
      $216 = (($214) + 36|0);
      $217 = HEAP32[$216>>2]|0;
      $218 = (($214) + 4|0);
      $219 = HEAP32[$218>>2]|0;
      $220 = ($217|0)==($219|0);
      do {
       if ($220) {
        $221 = (($214) + 28|0);
        $222 = HEAP32[$221>>2]|0;
        $223 = (($214) + 32|0);
        $224 = HEAP32[$223>>2]|0;
        $225 = (($222) + ($224<<3)|0);
        $241 = $225;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i46,$214,$0);
        $226 = HEAP32[$pos$i$i$i$i46>>2]|0;
        $227 = ($226|0)==(-1);
        $228 = (($214) + 28|0);
        $229 = HEAP32[$228>>2]|0;
        if ($227) {
         $230 = (($214) + 32|0);
         $231 = HEAP32[$230>>2]|0;
         $232 = (($229) + ($231<<3)|0);
         $241 = $232;
         break;
        } else {
         $233 = (($229) + ($226<<3)|0);
         $241 = $233;
         break;
        }
       }
      } while(0);
      $234 = HEAP32[560624>>2]|0;
      $235 = (($234) + 28|0);
      $236 = HEAP32[$235>>2]|0;
      $237 = (($234) + 32|0);
      $238 = HEAP32[$237>>2]|0;
      $239 = (($236) + ($238<<3)|0);
      $240 = ($241|0)==($239|0);
      if ($240) {
       label = 65;
      } else {
       $242 = (($241) + 4|0);
       $243 = HEAP32[$242>>2]|0;
       $244 = ($243|0)==(0|0);
       if ($244) {
        label = 65;
       } else {
        $temp$0$i50 = $243;
       }
      }
     }
     if ((label|0) == 65) {
      $245 = (__Z31ReadObjectFromPersistentManageri($213)|0);
      $temp$0$i50 = $245;
     }
     $246 = (($temp$0$i50) + 232|0);
     $247 = (($246) + 68|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = (($y) + -1)|0;
     $250 = (($249) + ($248))|0;
     $$01 = $250;$$2 = $211;$lookup$2 = $246;
    }
   }
  }
 } while(0);
 $251 = (($lookup$2) + 68|0);
 $252 = HEAP32[$251>>2]|0;
 $253 = ($$01|0)<($252|0);
 $254 = ($$2|0)==(0|0);
 $or$cond7 = $253 | $254;
 do {
  if ($or$cond7) {
   $$12 = $$01;$lookup$3 = $lookup$2;
  } else {
   $255 = HEAP32[$$2>>2]|0;
   $256 = ($255|0)==(0|0);
   if ($256) {
    $$12 = $$01;$lookup$3 = $lookup$2;
   } else {
    $257 = (($255) + 104|0);
    $258 = HEAP32[$257>>2]|0;
    $259 = ($258|0)==(0);
    if ($259) {
     $$12 = $$01;$lookup$3 = $lookup$2;
    } else {
     HEAP32[$2>>2] = $258;
     $260 = HEAP32[560624>>2]|0;
     $261 = ($260|0)==(0|0);
     if ($261) {
      label = 78;
     } else {
      $262 = (($260) + 36|0);
      $263 = HEAP32[$262>>2]|0;
      $264 = (($260) + 4|0);
      $265 = HEAP32[$264>>2]|0;
      $266 = ($263|0)==($265|0);
      do {
       if ($266) {
        $267 = (($260) + 28|0);
        $268 = HEAP32[$267>>2]|0;
        $269 = (($260) + 32|0);
        $270 = HEAP32[$269>>2]|0;
        $271 = (($268) + ($270<<3)|0);
        $287 = $271;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i46,$260,$2);
        $272 = HEAP32[$pos$i$i$i$i46>>2]|0;
        $273 = ($272|0)==(-1);
        $274 = (($260) + 28|0);
        $275 = HEAP32[$274>>2]|0;
        if ($273) {
         $276 = (($260) + 32|0);
         $277 = HEAP32[$276>>2]|0;
         $278 = (($275) + ($277<<3)|0);
         $287 = $278;
         break;
        } else {
         $279 = (($275) + ($272<<3)|0);
         $287 = $279;
         break;
        }
       }
      } while(0);
      $280 = HEAP32[560624>>2]|0;
      $281 = (($280) + 28|0);
      $282 = HEAP32[$281>>2]|0;
      $283 = (($280) + 32|0);
      $284 = HEAP32[$283>>2]|0;
      $285 = (($282) + ($284<<3)|0);
      $286 = ($287|0)==($285|0);
      if ($286) {
       label = 78;
      } else {
       $288 = (($287) + 4|0);
       $289 = HEAP32[$288>>2]|0;
       $290 = ($289|0)==(0|0);
       if ($290) {
        label = 78;
       }
      }
     }
     if ((label|0) == 78) {
      $291 = (__Z31ReadObjectFromPersistentManageri($258)|0);
      $292 = ($291|0)==(0|0);
      if ($292) {
       $$12 = $$01;$lookup$3 = $lookup$2;
       break;
      }
     }
     $293 = HEAP32[$251>>2]|0;
     $$neg61 = (($$01) + 1)|0;
     $294 = (($$neg61) - ($293))|0;
     $295 = HEAP32[$$2>>2]|0;
     $296 = (($295) + 104|0);
     $297 = HEAP32[$296>>2]|0;
     HEAP32[$7>>2] = $297;
     $298 = HEAP32[560624>>2]|0;
     $299 = ($298|0)==(0|0);
     if ($299) {
      label = 87;
     } else {
      $300 = (($298) + 36|0);
      $301 = HEAP32[$300>>2]|0;
      $302 = (($298) + 4|0);
      $303 = HEAP32[$302>>2]|0;
      $304 = ($301|0)==($303|0);
      do {
       if ($304) {
        $305 = (($298) + 28|0);
        $306 = HEAP32[$305>>2]|0;
        $307 = (($298) + 32|0);
        $308 = HEAP32[$307>>2]|0;
        $309 = (($306) + ($308<<3)|0);
        $325 = $309;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i46,$298,$7);
        $310 = HEAP32[$pos$i$i$i$i46>>2]|0;
        $311 = ($310|0)==(-1);
        $312 = (($298) + 28|0);
        $313 = HEAP32[$312>>2]|0;
        if ($311) {
         $314 = (($298) + 32|0);
         $315 = HEAP32[$314>>2]|0;
         $316 = (($313) + ($315<<3)|0);
         $325 = $316;
         break;
        } else {
         $317 = (($313) + ($310<<3)|0);
         $325 = $317;
         break;
        }
       }
      } while(0);
      $318 = HEAP32[560624>>2]|0;
      $319 = (($318) + 28|0);
      $320 = HEAP32[$319>>2]|0;
      $321 = (($318) + 32|0);
      $322 = HEAP32[$321>>2]|0;
      $323 = (($320) + ($322<<3)|0);
      $324 = ($325|0)==($323|0);
      if ($324) {
       label = 87;
      } else {
       $326 = (($325) + 4|0);
       $327 = HEAP32[$326>>2]|0;
       $328 = ($327|0)==(0|0);
       if ($328) {
        label = 87;
       } else {
        $temp$0$i = $327;
       }
      }
     }
     if ((label|0) == 87) {
      $329 = (__Z31ReadObjectFromPersistentManageri($297)|0);
      $temp$0$i = $329;
     }
     $330 = (($temp$0$i) + 232|0);
     $$12 = $294;$lookup$3 = $330;
    }
   }
  }
 } while(0);
 $331 = (($lookup$3) + 64|0);
 $332 = HEAP32[$331>>2]|0;
 $333 = (($lookup$3) + 68|0);
 $334 = HEAP32[$333>>2]|0;
 $335 = (($lookup$3) + 84|0);
 $336 = Math_fround(HEAPF32[$335>>2]);
 $337 = Math_fround($336 / Math_fround(32766.0));
 $338 = (($332) + -1)|0;
 $339 = ($$14|0)<(0);
 if ($339) {
  $$0$i$i$i = 0;
 } else {
  $340 = ($338|0)<($$14|0);
  $$$i$i$i = $340 ? $338 : $$14;
  $$0$i$i$i = $$$i$i$i;
 }
 $341 = (($334) + -1)|0;
 $342 = ($$12|0)<(0);
 if ($342) {
  $$0$i2$i$i = 0;
  $344 = Math_imul($$0$i$i$i, $334)|0;
  $345 = (($$0$i2$i$i) + ($344))|0;
  $346 = (($lookup$3) + 8|0);
  $347 = HEAP32[$346>>2]|0;
  $348 = (($347) + ($345<<1)|0);
  $349 = HEAP16[$348>>1]|0;
  $350 = (Math_fround(($349<<16>>16)));
  $351 = Math_fround($337 * $350);
  STACKTOP = sp;return (Math_fround($351));
 }
 $343 = ($341|0)<($$12|0);
 $$$i1$i$i = $343 ? $341 : $$12;
 $$0$i2$i$i = $$$i1$i$i;
 $344 = Math_imul($$0$i$i$i, $334)|0;
 $345 = (($$0$i2$i$i) + ($344))|0;
 $346 = (($lookup$3) + 8|0);
 $347 = HEAP32[$346>>2]|0;
 $348 = (($347) + ($345<<1)|0);
 $349 = HEAP16[$348>>1]|0;
 $350 = (Math_fround(($349<<16>>16)));
 $351 = Math_fround($337 * $350);
 STACKTOP = sp;return (Math_fround($351));
}
function __ZN9Heightmap20CalculateNormalSobelEiiiiRK13dynamic_arrayIsLj2EERK8Vector3f($agg$result,$x,$y,$width,$height,$heights,$scale) {
 $agg$result = $agg$result|0;
 $x = $x|0;
 $y = $y|0;
 $width = $width|0;
 $height = $height|0;
 $heights = $heights|0;
 $scale = $scale|0;
 var $$$i$i = 0, $$$i$i14 = 0, $$$i$i2 = 0, $$$i$i20 = 0, $$$i$i26 = 0, $$$i$i32 = 0, $$$i$i38 = 0, $$$i$i44 = 0, $$$i$i50 = 0, $$$i$i56 = 0, $$$i$i62 = 0, $$$i$i8 = 0, $$$i1$i = 0, $$$i1$i11 = 0, $$$i1$i17 = 0, $$$i1$i23 = 0, $$$i1$i29 = 0, $$$i1$i35 = 0, $$$i1$i41 = 0, $$$i1$i47 = 0;
 var $$$i1$i5 = 0, $$$i1$i53 = 0, $$$i1$i59 = 0, $$$i1$i65 = 0, $$0$i$i = 0, $$0$i$i1 = Math_fround(0), $$0$i$i15 = 0, $$0$i$i21 = 0, $$0$i$i27 = 0, $$0$i$i3 = 0, $$0$i$i33 = 0, $$0$i$i39 = 0, $$0$i$i45 = 0, $$0$i$i51 = 0, $$0$i$i57 = 0, $$0$i$i63 = 0, $$0$i$i9 = 0, $$0$i2$i = 0, $$0$i2$i12 = 0, $$0$i2$i18 = 0;
 var $$0$i2$i24 = 0, $$0$i2$i30 = 0, $$0$i2$i36 = 0, $$0$i2$i42 = 0, $$0$i2$i48 = 0, $$0$i2$i54 = 0, $$0$i2$i6 = 0, $$0$i2$i60 = 0, $$0$i2$i66 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0);
 var $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0;
 var $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($x) + -1)|0;
 $1 = (($y) + -1)|0;
 $2 = (($scale) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($width) + -1)|0;
 $5 = ($x|0)<(1);
 if ($5) {
  $$0$i$i = 0;
 } else {
  $6 = ($4|0)<($0|0);
  $$$i$i = $6 ? $4 : $0;
  $$0$i$i = $$$i$i;
 }
 $7 = (($height) + -1)|0;
 $8 = ($y|0)<(1);
 if ($8) {
  $$0$i2$i = 0;
 } else {
  $9 = ($7|0)<($1|0);
  $$$i1$i = $9 ? $7 : $1;
  $$0$i2$i = $$$i1$i;
 }
 $10 = Math_imul($$0$i$i, $height)|0;
 $11 = (($$0$i2$i) + ($10))|0;
 $12 = HEAP32[$heights>>2]|0;
 $13 = (($12) + ($11<<1)|0);
 $14 = HEAP16[$13>>1]|0;
 $15 = (Math_fround(($14<<16>>16)));
 $16 = Math_fround($3 * $15);
 $17 = Math_fround($16 * Math_fround(-1.0));
 if ($5) {
  $$0$i$i3 = 0;
 } else {
  $18 = ($4|0)<($0|0);
  $$$i$i2 = $18 ? $4 : $0;
  $$0$i$i3 = $$$i$i2;
 }
 $19 = ($y|0)<(0);
 if ($19) {
  $$0$i2$i6 = 0;
 } else {
  $20 = ($7|0)<($y|0);
  $$$i1$i5 = $20 ? $7 : $y;
  $$0$i2$i6 = $$$i1$i5;
 }
 $21 = Math_imul($$0$i$i3, $height)|0;
 $22 = (($$0$i2$i6) + ($21))|0;
 $23 = (($12) + ($22<<1)|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = (Math_fround(($24<<16>>16)));
 $26 = Math_fround($3 * $25);
 $27 = Math_fround($26 * Math_fround(-2.0));
 $28 = Math_fround($17 + $27);
 $29 = (($y) + 1)|0;
 if ($5) {
  $$0$i$i63 = 0;
 } else {
  $30 = ($4|0)<($0|0);
  $$$i$i62 = $30 ? $4 : $0;
  $$0$i$i63 = $$$i$i62;
 }
 $31 = ($29|0)<(0);
 if ($31) {
  $$0$i2$i66 = 0;
 } else {
  $32 = ($7|0)<($29|0);
  $$$i1$i65 = $32 ? $7 : $29;
  $$0$i2$i66 = $$$i1$i65;
 }
 $33 = Math_imul($$0$i$i63, $height)|0;
 $34 = (($$0$i2$i66) + ($33))|0;
 $35 = (($12) + ($34<<1)|0);
 $36 = HEAP16[$35>>1]|0;
 $37 = (Math_fround(($36<<16>>16)));
 $38 = Math_fround($3 * $37);
 $39 = Math_fround($38 * Math_fround(-1.0));
 $40 = Math_fround($28 + $39);
 $41 = (($x) + 1)|0;
 $42 = ($41|0)<(0);
 if ($42) {
  $$0$i$i57 = 0;
 } else {
  $43 = ($4|0)<($41|0);
  $$$i$i56 = $43 ? $4 : $41;
  $$0$i$i57 = $$$i$i56;
 }
 if ($8) {
  $$0$i2$i60 = 0;
 } else {
  $44 = ($7|0)<($1|0);
  $$$i1$i59 = $44 ? $7 : $1;
  $$0$i2$i60 = $$$i1$i59;
 }
 $45 = Math_imul($$0$i$i57, $height)|0;
 $46 = (($$0$i2$i60) + ($45))|0;
 $47 = (($12) + ($46<<1)|0);
 $48 = HEAP16[$47>>1]|0;
 $49 = (Math_fround(($48<<16>>16)));
 $50 = Math_fround($3 * $49);
 $51 = Math_fround($40 + $50);
 if ($42) {
  $$0$i$i51 = 0;
 } else {
  $52 = ($4|0)<($41|0);
  $$$i$i50 = $52 ? $4 : $41;
  $$0$i$i51 = $$$i$i50;
 }
 if ($19) {
  $$0$i2$i54 = 0;
 } else {
  $53 = ($7|0)<($y|0);
  $$$i1$i53 = $53 ? $7 : $y;
  $$0$i2$i54 = $$$i1$i53;
 }
 $54 = Math_imul($$0$i$i51, $height)|0;
 $55 = (($$0$i2$i54) + ($54))|0;
 $56 = (($12) + ($55<<1)|0);
 $57 = HEAP16[$56>>1]|0;
 $58 = (Math_fround(($57<<16>>16)));
 $59 = Math_fround($3 * $58);
 $60 = Math_fround($59 * Math_fround(2.0));
 $61 = Math_fround($51 + $60);
 if ($42) {
  $$0$i$i45 = 0;
 } else {
  $62 = ($4|0)<($41|0);
  $$$i$i44 = $62 ? $4 : $41;
  $$0$i$i45 = $$$i$i44;
 }
 if ($31) {
  $$0$i2$i48 = 0;
 } else {
  $63 = ($7|0)<($29|0);
  $$$i1$i47 = $63 ? $7 : $29;
  $$0$i2$i48 = $$$i1$i47;
 }
 $64 = Math_imul($$0$i$i45, $height)|0;
 $65 = (($$0$i2$i48) + ($64))|0;
 $66 = (($12) + ($65<<1)|0);
 $67 = HEAP16[$66>>1]|0;
 $68 = (Math_fround(($67<<16>>16)));
 $69 = Math_fround($3 * $68);
 $70 = Math_fround($61 + $69);
 $71 = Math_fround(HEAPF32[$scale>>2]);
 $72 = Math_fround($70 / $71);
 if ($5) {
  $$0$i$i39 = 0;
 } else {
  $73 = ($4|0)<($0|0);
  $$$i$i38 = $73 ? $4 : $0;
  $$0$i$i39 = $$$i$i38;
 }
 if ($8) {
  $$0$i2$i42 = 0;
 } else {
  $74 = ($7|0)<($1|0);
  $$$i1$i41 = $74 ? $7 : $1;
  $$0$i2$i42 = $$$i1$i41;
 }
 $75 = Math_imul($$0$i$i39, $height)|0;
 $76 = (($$0$i2$i42) + ($75))|0;
 $77 = (($12) + ($76<<1)|0);
 $78 = HEAP16[$77>>1]|0;
 $79 = (Math_fround(($78<<16>>16)));
 $80 = Math_fround($3 * $79);
 $81 = Math_fround($80 * Math_fround(-1.0));
 $82 = ($x|0)<(0);
 if ($82) {
  $$0$i$i33 = 0;
 } else {
  $83 = ($4|0)<($x|0);
  $$$i$i32 = $83 ? $4 : $x;
  $$0$i$i33 = $$$i$i32;
 }
 if ($8) {
  $$0$i2$i36 = 0;
 } else {
  $84 = ($7|0)<($1|0);
  $$$i1$i35 = $84 ? $7 : $1;
  $$0$i2$i36 = $$$i1$i35;
 }
 $85 = Math_imul($$0$i$i33, $height)|0;
 $86 = (($$0$i2$i36) + ($85))|0;
 $87 = (($12) + ($86<<1)|0);
 $88 = HEAP16[$87>>1]|0;
 $89 = (Math_fround(($88<<16>>16)));
 $90 = Math_fround($3 * $89);
 $91 = Math_fround($90 * Math_fround(-2.0));
 $92 = Math_fround($81 + $91);
 if ($42) {
  $$0$i$i27 = 0;
 } else {
  $93 = ($4|0)<($41|0);
  $$$i$i26 = $93 ? $4 : $41;
  $$0$i$i27 = $$$i$i26;
 }
 if ($8) {
  $$0$i2$i30 = 0;
 } else {
  $94 = ($7|0)<($1|0);
  $$$i1$i29 = $94 ? $7 : $1;
  $$0$i2$i30 = $$$i1$i29;
 }
 $95 = Math_imul($$0$i$i27, $height)|0;
 $96 = (($$0$i2$i30) + ($95))|0;
 $97 = (($12) + ($96<<1)|0);
 $98 = HEAP16[$97>>1]|0;
 $99 = (Math_fround(($98<<16>>16)));
 $100 = Math_fround($3 * $99);
 $101 = Math_fround($100 * Math_fround(-1.0));
 $102 = Math_fround($92 + $101);
 if ($5) {
  $$0$i$i21 = 0;
 } else {
  $103 = ($4|0)<($0|0);
  $$$i$i20 = $103 ? $4 : $0;
  $$0$i$i21 = $$$i$i20;
 }
 if ($31) {
  $$0$i2$i24 = 0;
 } else {
  $104 = ($7|0)<($29|0);
  $$$i1$i23 = $104 ? $7 : $29;
  $$0$i2$i24 = $$$i1$i23;
 }
 $105 = Math_imul($$0$i$i21, $height)|0;
 $106 = (($$0$i2$i24) + ($105))|0;
 $107 = (($12) + ($106<<1)|0);
 $108 = HEAP16[$107>>1]|0;
 $109 = (Math_fround(($108<<16>>16)));
 $110 = Math_fround($3 * $109);
 $111 = Math_fround($102 + $110);
 if ($82) {
  $$0$i$i15 = 0;
 } else {
  $112 = ($4|0)<($x|0);
  $$$i$i14 = $112 ? $4 : $x;
  $$0$i$i15 = $$$i$i14;
 }
 if ($31) {
  $$0$i2$i18 = 0;
 } else {
  $113 = ($7|0)<($29|0);
  $$$i1$i17 = $113 ? $7 : $29;
  $$0$i2$i18 = $$$i1$i17;
 }
 $114 = Math_imul($$0$i$i15, $height)|0;
 $115 = (($$0$i2$i18) + ($114))|0;
 $116 = (($12) + ($115<<1)|0);
 $117 = HEAP16[$116>>1]|0;
 $118 = (Math_fround(($117<<16>>16)));
 $119 = Math_fround($3 * $118);
 $120 = Math_fround($119 * Math_fround(2.0));
 $121 = Math_fround($111 + $120);
 if ($42) {
  $$0$i$i9 = 0;
 } else {
  $122 = ($4|0)<($41|0);
  $$$i$i8 = $122 ? $4 : $41;
  $$0$i$i9 = $$$i$i8;
 }
 if ($31) {
  $$0$i2$i12 = 0;
 } else {
  $123 = ($7|0)<($29|0);
  $$$i1$i11 = $123 ? $7 : $29;
  $$0$i2$i12 = $$$i1$i11;
 }
 $124 = Math_imul($$0$i$i9, $height)|0;
 $125 = (($$0$i2$i12) + ($124))|0;
 $126 = (($12) + ($125<<1)|0);
 $127 = HEAP16[$126>>1]|0;
 $128 = (Math_fround(($127<<16>>16)));
 $129 = Math_fround($3 * $128);
 $130 = Math_fround($121 + $129);
 $131 = (($scale) + 8|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = Math_fround($130 / $132);
 $134 = Math_fround($72 * $72);
 $135 = Math_fround($134 + Math_fround(64.0));
 $136 = Math_fround($133 * $133);
 $137 = Math_fround($135 + $136);
 $138 = $137 == Math_fround(0.0);
 if ($138) {
  $$0$i$i1 = $137;
  $141 = Math_fround($72 * $$0$i$i1);
  $142 = Math_fround(-$141);
  $143 = Math_fround($$0$i$i1 * Math_fround(8.0));
  $144 = Math_fround($133 * $$0$i$i1);
  $145 = Math_fround(-$144);
  HEAPF32[$agg$result>>2] = $142;
  $146 = (($agg$result) + 4|0);
  HEAPF32[$146>>2] = $143;
  $147 = (($agg$result) + 8|0);
  HEAPF32[$147>>2] = $145;
  STACKTOP = sp;return;
 }
 $139 = (Math_fround(Math_sqrt((Math_fround($137)))));
 $140 = Math_fround(Math_fround(1.0) / $139);
 $$0$i$i1 = $140;
 $141 = Math_fround($72 * $$0$i$i1);
 $142 = Math_fround(-$141);
 $143 = Math_fround($$0$i$i1 * Math_fround(8.0));
 $144 = Math_fround($133 * $$0$i$i1);
 $145 = Math_fround(-$144);
 HEAPF32[$agg$result>>2] = $142;
 $146 = (($agg$result) + 4|0);
 HEAPF32[$146>>2] = $143;
 $147 = (($agg$result) + 8|0);
 HEAPF32[$147>>2] = $145;
 STACKTOP = sp;return;
}
function __ZNK9Heightmap7GetSizeEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 64|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 $5 = (Math_fround(($4|0)));
 $6 = Math_fround($1 * $5);
 $7 = (($this) + 84|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($this) + 88|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($this) + 68|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + -1)|0;
 $14 = (Math_fround(($13|0)));
 $15 = Math_fround($10 * $14);
 HEAPF32[$agg$result>>2] = $6;
 $16 = (($agg$result) + 4|0);
 HEAPF32[$16>>2] = $8;
 $17 = (($agg$result) + 8|0);
 HEAPF32[$17>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN9Heightmap13CreatePhysicsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $desc = 0, $exitcond = 0, $exitcond1 = 0, $or$cond = 0, $x$03$us$i = 0, $y$02$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $desc = sp;
 $0 = (__Z11GetIPhysicsv()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$6 & 4095]($3);
  HEAP32[$2>>2] = 0;
 }
 $7 = (($desc) + 12|0);
 $8 = (($desc) + 16|0);
 $9 = (($desc) + 28|0);
 $10 = (($desc) + 4|0);
 $11 = (($desc) + 8|0);
 HEAP32[$11>>2] = 1;
 $12 = (($desc) + 20|0);
 $13 = (($desc) + 24|0);
 HEAP16[$9>>1] = 0;
 $14 = (($this) + 64|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 << 2;
 $17 = (($this) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = Math_imul($16, $18)|0;
 $20 = (_malloc($19)|0);
 HEAP32[$desc>>2] = $15;
 HEAP32[$10>>2] = $18;
 HEAP32[$7>>2] = 4;
 HEAP32[$8>>2] = $20;
 $21 = (($this) + 76|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround(-$22);
 HEAPF32[$12>>2] = $23;
 HEAPF32[$13>>2] = Math_fround(4.0);
 $24 = ($15|0)>(0);
 $25 = ($18|0)>(0);
 $or$cond = $24 & $25;
 if ($or$cond) {
  $26 = (($this) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  $x$03$us$i = 0;
  while(1) {
   $30 = Math_imul($x$03$us$i, $18)|0;
   $y$02$us$i = 0;
   while(1) {
    $29 = (($y$02$us$i) + ($30))|0;
    $31 = (($27) + ($29<<1)|0);
    $32 = HEAP16[$31>>1]|0;
    $33 = (($20) + ($29<<2)|0);
    $34 = $32&65535;
    $35 = $34 | 8388608;
    HEAP16[$33>>1]=$35&65535;HEAP16[$33+2>>1]=$35>>>16;
    $36 = (($y$02$us$i) + 1)|0;
    $exitcond = ($36|0)==($18|0);
    if ($exitcond) {
     break;
    } else {
     $y$02$us$i = $36;
    }
   }
   $28 = (($x$03$us$i) + 1)|0;
   $exitcond1 = ($28|0)==($15|0);
   if ($exitcond1) {
    break;
   } else {
    $x$03$us$i = $28;
   }
  }
 }
 $37 = HEAP32[$0>>2]|0;
 $38 = (($37) + 48|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (FUNCTION_TABLE_iii[$39 & 4095]($0,$desc)|0);
 HEAP32[$2>>2] = $40;
 $41 = HEAP32[$8>>2]|0;
 _free($41);
 STACKTOP = sp;return;
}
function __ZNK9Heightmap21GetMaximumHeightErrorEiii($this,$x,$y,$level) {
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $level = $level|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $index$0$lcssa$i = 0, $index$02$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($level|0)>(0);
 $1 = (($this) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 if ($0) {
  $i$01$i = 0;$index$02$i = 0;
  while(1) {
   $3 = (($2) - ($i$01$i))|0;
   $4 = 1 << $3;
   $5 = $4 << $3;
   $6 = (($5) + ($index$02$i))|0;
   $7 = (($i$01$i) + 1)|0;
   $exitcond$i = ($7|0)==($level|0);
   if ($exitcond$i) {
    $index$0$lcssa$i = $6;
    break;
   } else {
    $i$01$i = $7;$index$02$i = $6;
   }
  }
 } else {
  $index$0$lcssa$i = 0;
 }
 $8 = (($2) - ($level))|0;
 $9 = $y << $8;
 $10 = (($9) + ($x))|0;
 $11 = (($10) + ($index$0$lcssa$i))|0;
 $12 = (($this) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($11<<2)|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 STACKTOP = sp;return (Math_fround($15));
}
function __ZNK9Heightmap21GetInterpolatedHeightEff($this,$x,$y) {
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $$$i$i$i = 0, $$$i$i$i1 = 0, $$$i$i$i13 = 0, $$$i$i$i19 = 0, $$$i$i$i7 = 0, $$$i1$i$i = 0, $$$i1$i$i10 = 0, $$$i1$i$i16 = 0, $$$i1$i$i22 = 0, $$$i1$i$i4 = 0, $$0 = Math_fround(0), $$0$i$i$i = 0, $$0$i$i$i14 = 0, $$0$i$i$i2 = 0, $$0$i$i$i20 = 0, $$0$i$i$i8 = 0, $$0$i2$i$i = 0, $$0$i2$i$i11 = 0, $$0$i2$i$i17 = 0, $$0$i2$i$i23 = 0;
 var $$0$i2$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0);
 var $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = (Math_fround(($2|0)));
 $4 = Math_fround($3 * $x);
 $5 = (($this) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 $8 = (Math_fround(($7|0)));
 $9 = Math_fround($8 * $y);
 $10 = (~~(($4)));
 $11 = (~~(($9)));
 $12 = (Math_fround(($10|0)));
 $13 = Math_fround($4 - $12);
 $14 = (Math_fround(($11|0)));
 $15 = Math_fround($9 - $14);
 $16 = $13 > $15;
 $17 = (($this) + 84|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($18 / Math_fround(32766.0));
 $20 = ($10|0)<(0);
 if ($20) {
  $$0$i$i$i = 0;
 } else {
  $21 = ($2|0)<($10|0);
  $$$i$i$i = $21 ? $2 : $10;
  $$0$i$i$i = $$$i$i$i;
 }
 $22 = ($11|0)<(0);
 if ($22) {
  $$0$i2$i$i = 0;
 } else {
  $23 = ($7|0)<($11|0);
  $$$i1$i$i = $23 ? $7 : $11;
  $$0$i2$i$i = $$$i1$i$i;
 }
 $24 = Math_imul($$0$i$i$i, $6)|0;
 $25 = (($$0$i2$i$i) + ($24))|0;
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + ($25<<1)|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = (Math_fround(($29<<16>>16)));
 $31 = Math_fround($19 * $30);
 if ($16) {
  $32 = (($10) + 1)|0;
  $33 = ($32|0)<(0);
  if ($33) {
   $$0$i$i$i20 = 0;
  } else {
   $34 = ($2|0)<($32|0);
   $$$i$i$i19 = $34 ? $2 : $32;
   $$0$i$i$i20 = $$$i$i$i19;
  }
  if ($22) {
   $$0$i2$i$i23 = 0;
  } else {
   $35 = ($7|0)<($11|0);
   $$$i1$i$i22 = $35 ? $7 : $11;
   $$0$i2$i$i23 = $$$i1$i$i22;
  }
  $36 = Math_imul($$0$i$i$i20, $6)|0;
  $37 = (($$0$i2$i$i23) + ($36))|0;
  $38 = (($27) + ($37<<1)|0);
  $39 = HEAP16[$38>>1]|0;
  $40 = (Math_fround(($39<<16>>16)));
  $41 = Math_fround($19 * $40);
  $42 = (($11) + 1)|0;
  if ($33) {
   $$0$i$i$i14 = 0;
  } else {
   $43 = ($2|0)<($32|0);
   $$$i$i$i13 = $43 ? $2 : $32;
   $$0$i$i$i14 = $$$i$i$i13;
  }
  $44 = ($42|0)<(0);
  if ($44) {
   $$0$i2$i$i17 = 0;
  } else {
   $45 = ($7|0)<($42|0);
   $$$i1$i$i16 = $45 ? $7 : $42;
   $$0$i2$i$i17 = $$$i1$i$i16;
  }
  $46 = Math_imul($$0$i$i$i14, $6)|0;
  $47 = (($$0$i2$i$i17) + ($46))|0;
  $48 = (($27) + ($47<<1)|0);
  $49 = HEAP16[$48>>1]|0;
  $50 = (Math_fround(($49<<16>>16)));
  $51 = Math_fround($19 * $50);
  $52 = Math_fround($41 - $31);
  $53 = Math_fround($13 * $52);
  $54 = Math_fround($31 + $53);
  $55 = Math_fround($51 - $41);
  $56 = Math_fround($15 * $55);
  $57 = Math_fround($54 + $56);
  $$0 = $57;
  STACKTOP = sp;return (Math_fround($$0));
 } else {
  $58 = (($11) + 1)|0;
  if ($20) {
   $$0$i$i$i8 = 0;
  } else {
   $59 = ($2|0)<($10|0);
   $$$i$i$i7 = $59 ? $2 : $10;
   $$0$i$i$i8 = $$$i$i$i7;
  }
  $60 = ($58|0)<(0);
  if ($60) {
   $$0$i2$i$i11 = 0;
  } else {
   $61 = ($7|0)<($58|0);
   $$$i1$i$i10 = $61 ? $7 : $58;
   $$0$i2$i$i11 = $$$i1$i$i10;
  }
  $62 = Math_imul($$0$i$i$i8, $6)|0;
  $63 = (($$0$i2$i$i11) + ($62))|0;
  $64 = (($27) + ($63<<1)|0);
  $65 = HEAP16[$64>>1]|0;
  $66 = (Math_fround(($65<<16>>16)));
  $67 = Math_fround($19 * $66);
  $68 = (($10) + 1)|0;
  $69 = ($68|0)<(0);
  if ($69) {
   $$0$i$i$i2 = 0;
  } else {
   $70 = ($2|0)<($68|0);
   $$$i$i$i1 = $70 ? $2 : $68;
   $$0$i$i$i2 = $$$i$i$i1;
  }
  if ($60) {
   $$0$i2$i$i5 = 0;
  } else {
   $71 = ($7|0)<($58|0);
   $$$i1$i$i4 = $71 ? $7 : $58;
   $$0$i2$i$i5 = $$$i1$i$i4;
  }
  $72 = Math_imul($$0$i$i$i2, $6)|0;
  $73 = (($$0$i2$i$i5) + ($72))|0;
  $74 = (($27) + ($73<<1)|0);
  $75 = HEAP16[$74>>1]|0;
  $76 = (Math_fround(($75<<16>>16)));
  $77 = Math_fround($19 * $76);
  $78 = Math_fround($77 - $67);
  $79 = Math_fround($13 * $78);
  $80 = Math_fround($31 + $79);
  $81 = Math_fround($67 - $31);
  $82 = Math_fround($15 * $81);
  $83 = Math_fround($82 + $80);
  $$0 = $83;
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __ZNK9Heightmap21GetInterpolatedNormalEff($agg$result,$this,$x,$y) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $$0$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $12 = 0;
 var $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0;
 var $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0);
 var $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0);
 var $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0;
 var $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $n00 = 0, $n01 = 0, $n10 = 0, $n11 = 0, $scale$i3 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $scale$i3 = sp + 48|0;
 $n00 = sp;
 $n10 = sp + 12|0;
 $n01 = sp + 24|0;
 $n11 = sp + 36|0;
 $0 = (($this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = (Math_fround(($2|0)));
 $4 = Math_fround($3 * $x);
 $5 = (($this) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + -1)|0;
 $8 = (Math_fround(($7|0)));
 $9 = Math_fround($8 * $y);
 $10 = (~~(($4)));
 $11 = (~~(($9)));
 $12 = (($this) + 80|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($this) + 84|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = Math_fround($15 / Math_fround(32766.0));
 $17 = (($this) + 88|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$scale$i3>>2] = $13;
 $19 = (($scale$i3) + 4|0);
 HEAPF32[$19>>2] = $16;
 $20 = (($scale$i3) + 8|0);
 HEAPF32[$20>>2] = $18;
 $21 = (($this) + 8|0);
 __ZN9Heightmap20CalculateNormalSobelEiiiiRK13dynamic_arrayIsLj2EERK8Vector3f($n00,$10,$11,$1,$6,$21,$scale$i3);
 $22 = (($10) + 1)|0;
 $23 = Math_fround(HEAPF32[$12>>2]);
 $24 = Math_fround(HEAPF32[$14>>2]);
 $25 = Math_fround($24 / Math_fround(32766.0));
 $26 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$scale$i3>>2] = $23;
 $27 = (($scale$i3) + 4|0);
 HEAPF32[$27>>2] = $25;
 $28 = (($scale$i3) + 8|0);
 HEAPF32[$28>>2] = $26;
 $29 = HEAP32[$0>>2]|0;
 $30 = HEAP32[$5>>2]|0;
 __ZN9Heightmap20CalculateNormalSobelEiiiiRK13dynamic_arrayIsLj2EERK8Vector3f($n10,$22,$11,$29,$30,$21,$scale$i3);
 $31 = (($11) + 1)|0;
 $32 = Math_fround(HEAPF32[$12>>2]);
 $33 = Math_fround(HEAPF32[$14>>2]);
 $34 = Math_fround($33 / Math_fround(32766.0));
 $35 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$scale$i3>>2] = $32;
 $36 = (($scale$i3) + 4|0);
 HEAPF32[$36>>2] = $34;
 $37 = (($scale$i3) + 8|0);
 HEAPF32[$37>>2] = $35;
 $38 = HEAP32[$0>>2]|0;
 $39 = HEAP32[$5>>2]|0;
 __ZN9Heightmap20CalculateNormalSobelEiiiiRK13dynamic_arrayIsLj2EERK8Vector3f($n01,$10,$31,$38,$39,$21,$scale$i3);
 $40 = Math_fround(HEAPF32[$12>>2]);
 $41 = Math_fround(HEAPF32[$14>>2]);
 $42 = Math_fround($41 / Math_fround(32766.0));
 $43 = Math_fround(HEAPF32[$17>>2]);
 HEAPF32[$scale$i3>>2] = $40;
 $44 = (($scale$i3) + 4|0);
 HEAPF32[$44>>2] = $42;
 $45 = (($scale$i3) + 8|0);
 HEAPF32[$45>>2] = $43;
 $46 = HEAP32[$0>>2]|0;
 $47 = HEAP32[$5>>2]|0;
 __ZN9Heightmap20CalculateNormalSobelEiiiiRK13dynamic_arrayIsLj2EERK8Vector3f($n11,$22,$31,$46,$47,$21,$scale$i3);
 $48 = (Math_fround(($10|0)));
 $49 = Math_fround($4 - $48);
 $50 = (Math_fround(($11|0)));
 $51 = Math_fround($9 - $50);
 $52 = Math_fround(HEAPF32[$n10>>2]);
 $53 = Math_fround($49 * $52);
 $54 = (($n10) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = Math_fround($49 * $55);
 $57 = (($n10) + 8|0);
 $58 = Math_fround(HEAPF32[$57>>2]);
 $59 = Math_fround($49 * $58);
 $60 = Math_fround(Math_fround(1.0) - $49);
 $61 = Math_fround(HEAPF32[$n00>>2]);
 $62 = Math_fround($60 * $61);
 $63 = (($n00) + 4|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($60 * $64);
 $66 = (($n00) + 8|0);
 $67 = Math_fround(HEAPF32[$66>>2]);
 $68 = Math_fround($60 * $67);
 $69 = Math_fround($53 + $62);
 $70 = Math_fround($56 + $65);
 $71 = Math_fround($59 + $68);
 $72 = Math_fround(HEAPF32[$n11>>2]);
 $73 = Math_fround($49 * $72);
 $74 = (($n11) + 4|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($49 * $75);
 $77 = (($n11) + 8|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = Math_fround($49 * $78);
 $80 = Math_fround(HEAPF32[$n01>>2]);
 $81 = Math_fround($60 * $80);
 $82 = (($n01) + 4|0);
 $83 = Math_fround(HEAPF32[$82>>2]);
 $84 = Math_fround($60 * $83);
 $85 = (($n01) + 8|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($60 * $86);
 $88 = Math_fround($73 + $81);
 $89 = Math_fround($76 + $84);
 $90 = Math_fround($79 + $87);
 $91 = Math_fround($51 * $88);
 $92 = Math_fround($51 * $89);
 $93 = Math_fround($51 * $90);
 $94 = Math_fround(Math_fround(1.0) - $51);
 $95 = Math_fround($94 * $69);
 $96 = Math_fround($94 * $70);
 $97 = Math_fround($94 * $71);
 $98 = Math_fround($95 + $91);
 $99 = Math_fround($96 + $92);
 $100 = Math_fround($97 + $93);
 HEAPF32[$agg$result>>2] = $98;
 $101 = (($agg$result) + 4|0);
 HEAPF32[$101>>2] = $99;
 $102 = (($agg$result) + 8|0);
 HEAPF32[$102>>2] = $100;
 $103 = Math_fround($98 * $98);
 $104 = Math_fround($99 * $99);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($100 * $100);
 $107 = Math_fround($105 + $106);
 $108 = $107 == Math_fround(0.0);
 if ($108) {
  $$0$i$i = $107;
  $111 = Math_fround($98 * $$0$i$i);
  $112 = Math_fround($99 * $$0$i$i);
  $113 = Math_fround($100 * $$0$i$i);
  HEAPF32[$agg$result>>2] = $111;
  HEAPF32[$101>>2] = $112;
  HEAPF32[$102>>2] = $113;
  STACKTOP = sp;return;
 }
 $109 = (Math_fround(Math_sqrt((Math_fround($107)))));
 $110 = Math_fround(Math_fround(1.0) / $109);
 $$0$i$i = $110;
 $111 = Math_fround($98 * $$0$i$i);
 $112 = Math_fround($99 * $$0$i$i);
 $113 = Math_fround($100 * $$0$i$i);
 HEAPF32[$agg$result>>2] = $111;
 HEAPF32[$101>>2] = $112;
 HEAPF32[$102>>2] = $113;
 STACKTOP = sp;return;
}
function __ZN9Heightmap17FillPatchVerticesERK14StrideIteratorI8Vector3fES4_RKS0_I8Vector2fEiiiP15TerrainRenderer($this,$vertices,$normals,$uvs,$xPatch,$yPatch,$mipLevel,$renderer) {
 $this = $this|0;
 $vertices = $vertices|0;
 $normals = $normals|0;
 $uvs = $uvs|0;
 $xPatch = $xPatch|0;
 $yPatch = $yPatch|0;
 $mipLevel = $mipLevel|0;
 $renderer = $renderer|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $8 = Math_fround(0), $9 = 0, $exitcond = 0, $exitcond5 = 0, $normal = 0, $x$04 = 0, $y$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $normal = sp;
 $0 = (($this) + 80|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($this) + 84|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($this) + 88|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = 1 << $mipLevel;
 $7 = (Math_fround(($6|0)));
 $8 = Math_fround($3 / Math_fround(32766.0));
 $9 = (($this) + 64|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + -1)|0;
 $12 = (Math_fround(($11|0)));
 $13 = Math_fround(Math_fround(1.0) / $12);
 $14 = Math_fround($7 * $13);
 $15 = (($this) + 68|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 $18 = (Math_fround(($17|0)));
 $19 = Math_fround(Math_fround(1.0) / $18);
 $20 = Math_fround($7 * $19);
 $21 = $xPatch << $mipLevel;
 $22 = $21 << 4;
 $23 = (Math_fround(($22|0)));
 $24 = Math_fround($23 / $12);
 $25 = $yPatch << $mipLevel;
 $26 = $25 << 4;
 $27 = (Math_fround(($26|0)));
 $28 = Math_fround($27 / $18);
 $29 = $xPatch << 4;
 $30 = $yPatch << 4;
 $31 = HEAP32[$vertices>>2]|0;
 $32 = (($vertices) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$normals>>2]|0;
 $35 = (($normals) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$uvs>>2]|0;
 $38 = (($uvs) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($this) + 8|0);
 $x$04 = 0;
 while(1) {
  $41 = (($x$04) + ($29))|0;
  $42 = ($x$04*17)|0;
  $43 = (Math_fround(($41|0)));
  $44 = Math_fround($1 * $43);
  $45 = Math_fround($7 * $44);
  $46 = (Math_fround(($x$04|0)));
  $47 = Math_fround($14 * $46);
  $48 = Math_fround($24 + $47);
  $49 = $41 << $mipLevel;
  $y$03 = 0;
  while(1) {
   $50 = (($y$03) + ($30))|0;
   $51 = HEAP32[$15>>2]|0;
   $52 = Math_imul($51, $41)|0;
   $53 = (($52) + ($50))|0;
   $54 = $53 << $mipLevel;
   $55 = HEAP32[$40>>2]|0;
   $56 = (($55) + ($54<<1)|0);
   $57 = HEAP16[$56>>1]|0;
   $58 = (Math_fround(($57<<16>>16)));
   $59 = Math_fround($8 * $58);
   $60 = (($y$03) + ($42))|0;
   $61 = Math_imul($60, $33)|0;
   $62 = (($31) + ($61)|0);
   HEAPF32[$62>>2] = $45;
   $$sum = (($61) + 4)|0;
   $63 = (($31) + ($$sum)|0);
   HEAPF32[$63>>2] = $59;
   $64 = (Math_fround(($50|0)));
   $65 = Math_fround($5 * $64);
   $66 = Math_fround($7 * $65);
   $$sum1 = (($61) + 8)|0;
   $67 = (($31) + ($$sum1)|0);
   HEAPF32[$67>>2] = $66;
   $68 = Math_imul($60, $39)|0;
   $69 = (($37) + ($68)|0);
   HEAPF32[$69>>2] = $48;
   $70 = (Math_fround(($y$03|0)));
   $71 = Math_fround($20 * $70);
   $72 = Math_fround($28 + $71);
   $$sum2 = (($68) + 4)|0;
   $73 = (($37) + ($$sum2)|0);
   HEAPF32[$73>>2] = $72;
   $74 = $50 << $mipLevel;
   __ZNK9Heightmap39CalculateNormalSobelRespectingNeighborsEiiPK15TerrainRenderer($normal,$this,$49,$74,$renderer);
   $75 = Math_imul($60, $36)|0;
   $76 = (($34) + ($75)|0);
   ;HEAP32[$76+0>>2]=HEAP32[$normal+0>>2]|0;HEAP32[$76+4>>2]=HEAP32[$normal+4>>2]|0;HEAP32[$76+8>>2]=HEAP32[$normal+8>>2]|0;
   $77 = (($y$03) + 1)|0;
   $exitcond = ($77|0)==(17);
   if ($exitcond) {
    break;
   } else {
    $y$03 = $77;
   }
  }
  $78 = (($x$04) + 1)|0;
  $exitcond5 = ($78|0)==(17);
  if ($exitcond5) {
   break;
  } else {
   $x$04 = $78;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK9Heightmap9GetBoundsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $i$01$i$i = 0, $index$0$lcssa$i$i = 0, $index$02$i$i = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if ($2) {
  $i$01$i$i = 0;$index$02$i$i = 0;
  while(1) {
   $3 = (($1) - ($i$01$i$i))|0;
   $4 = 1 << $3;
   $5 = $4 << $3;
   $6 = (($5) + ($index$02$i$i))|0;
   $7 = (($i$01$i$i) + 1)|0;
   $exitcond$i$i = ($7|0)==($1|0);
   if ($exitcond$i$i) {
    break;
   } else {
    $i$01$i$i = $7;$index$02$i$i = $6;
   }
  }
  $phitmp = $6 << 1;
  $index$0$lcssa$i$i = $phitmp;
 } else {
  $index$0$lcssa$i$i = 0;
 }
 $8 = (($this) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($index$0$lcssa$i$i<<2)|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = $index$0$lcssa$i$i | 1;
 $13 = (($9) + ($12<<2)|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 80|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 * Math_fround(0.0));
 $18 = (($this) + 88|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * Math_fround(0.0));
 $21 = (($this) + 84|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($11 * $22);
 $24 = 16 << $1;
 $25 = (Math_fround(($24|0)));
 $26 = Math_fround($25 * $16);
 $27 = Math_fround($25 * $19);
 $28 = Math_fround($14 * $22);
 $29 = (($agg$result) + 4|0);
 $30 = (($agg$result) + 8|0);
 $31 = (($agg$result) + 12|0);
 $32 = (($agg$result) + 16|0);
 $33 = (($agg$result) + 20|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 $34 = Math_fround($26 + $17);
 $35 = Math_fround($28 + $23);
 $36 = Math_fround($27 + $20);
 $37 = Math_fround($34 * Math_fround(0.5));
 $38 = Math_fround($35 * Math_fround(0.5));
 $39 = Math_fround($36 * Math_fround(0.5));
 HEAPF32[$agg$result>>2] = $37;
 HEAPF32[$29>>2] = $38;
 HEAPF32[$30>>2] = $39;
 $40 = Math_fround($26 - $17);
 $41 = Math_fround($28 - $23);
 $42 = Math_fround($27 - $20);
 $43 = Math_fround($40 * Math_fround(0.5));
 $44 = Math_fround($41 * Math_fround(0.5));
 $45 = Math_fround($42 * Math_fround(0.5));
 HEAPF32[$31>>2] = $43;
 HEAPF32[$32>>2] = $44;
 HEAPF32[$33>>2] = $45;
 STACKTOP = sp;return;
}
function __ZNK9Heightmap9GetBoundsEiii($agg$result,$this,$xPatch,$yPatch,$mipLevel) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $xPatch = $xPatch|0;
 $yPatch = $yPatch|0;
 $mipLevel = $mipLevel|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $index$0$lcssa$i = 0, $index$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mipLevel|0)>(0);
 $1 = (($this) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 if ($0) {
  $i$01$i = 0;$index$02$i = 0;
  while(1) {
   $3 = (($2) - ($i$01$i))|0;
   $4 = 1 << $3;
   $5 = $4 << $3;
   $6 = (($5) + ($index$02$i))|0;
   $7 = (($i$01$i) + 1)|0;
   $exitcond$i = ($7|0)==($mipLevel|0);
   if ($exitcond$i) {
    $index$0$lcssa$i = $6;
    break;
   } else {
    $i$01$i = $7;$index$02$i = $6;
   }
  }
 } else {
  $index$0$lcssa$i = 0;
 }
 $8 = (($2) - ($mipLevel))|0;
 $9 = $yPatch << $8;
 $10 = (($9) + ($xPatch))|0;
 $11 = (($10) + ($index$0$lcssa$i))|0;
 $12 = $11 << 1;
 $13 = (($this) + 40|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($12<<2)|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = $12 | 1;
 $18 = (($14) + ($17<<2)|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = $xPatch << $mipLevel;
 $21 = $20 << 4;
 $22 = (Math_fround(($21|0)));
 $23 = (($this) + 80|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 * $24);
 $26 = $yPatch << $mipLevel;
 $27 = $26 << 4;
 $28 = (Math_fround(($27|0)));
 $29 = (($this) + 88|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($28 * $30);
 $32 = (($this) + 84|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($16 * $33);
 $35 = (($xPatch) + 1)|0;
 $36 = $35 << $mipLevel;
 $37 = $36 << 4;
 $38 = (Math_fround(($37|0)));
 $39 = Math_fround($38 * $24);
 $40 = (($yPatch) + 1)|0;
 $41 = $40 << $mipLevel;
 $42 = $41 << 4;
 $43 = (Math_fround(($42|0)));
 $44 = Math_fround($43 * $30);
 $45 = Math_fround($19 * $33);
 $46 = (($agg$result) + 4|0);
 $47 = (($agg$result) + 8|0);
 $48 = (($agg$result) + 12|0);
 $49 = (($agg$result) + 16|0);
 $50 = (($agg$result) + 20|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 $51 = Math_fround($39 + $25);
 $52 = Math_fround($45 + $34);
 $53 = Math_fround($44 + $31);
 $54 = Math_fround($51 * Math_fround(0.5));
 $55 = Math_fround($52 * Math_fround(0.5));
 $56 = Math_fround($53 * Math_fround(0.5));
 HEAPF32[$agg$result>>2] = $54;
 HEAPF32[$46>>2] = $55;
 HEAPF32[$47>>2] = $56;
 $57 = Math_fround($39 - $25);
 $58 = Math_fround($45 - $34);
 $59 = Math_fround($44 - $31);
 $60 = Math_fround($57 * Math_fround(0.5));
 $61 = Math_fround($58 * Math_fround(0.5));
 $62 = Math_fround($59 * Math_fround(0.5));
 HEAPF32[$48>>2] = $60;
 HEAPF32[$49>>2] = $61;
 HEAPF32[$50>>2] = $62;
 STACKTOP = sp;return;
}
function __ZN9Heightmap16GetPxHeightFieldEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = $1;
  STACKTOP = sp;return ($3|0);
 }
 __ZN9Heightmap13CreatePhysicsEv($this);
 $$pre = HEAP32[$0>>2]|0;
 $3 = $$pre;
 STACKTOP = sp;return ($3|0);
}
function __ZN20QuadTreeNodeRenderer16StaticInitializeEv() {
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628480>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy2,0,16,800408,16)|0);
 $4 = HEAP32[628440>>2]|0;
 HEAP32[$1>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(98,($3|0),1,(800416|0),252,6200,($$byval_copy2|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  HEAP32[800400>>2] = $3;
  STACKTOP = sp;return;
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),0,16,(800408|0),16);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN20QuadTreeNodeRenderer13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[800400>>2]|0;
 $2 = HEAP32[628480>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN10MemoryPoolD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[800400>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20QuadTreeNodeRendererC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererC2Ev($this);
 HEAP32[$this>>2] = ((800440 + 8|0));
 $0 = (($this) + 244|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 248|0);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20QuadTreeNodeRenderer5SetupEP15TerrainRendererP12QuadTreeNode($this,$terrainRenderer,$quadTreeNode) {
 $this = $this|0;
 $terrainRenderer = $terrainRenderer|0;
 $quadTreeNode = $quadTreeNode|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 244|0);
 HEAP32[$0>>2] = $terrainRenderer;
 $1 = (($this) + 248|0);
 HEAP32[$1>>2] = $quadTreeNode;
 STACKTOP = sp;return;
}
function __ZN20QuadTreeNodeRenderer17SetLightmapParamsEtRK8Vector4f12LightmapType($this,$lightmapIndex,$lightmapST,$lightmapType) {
 $this = $this|0;
 $lightmapIndex = $lightmapIndex|0;
 $lightmapST = $lightmapST|0;
 $lightmapType = $lightmapType|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = (($0) + ($lightmapType<<1)|0);
 HEAP16[$1>>1] = $lightmapIndex;
 $2 = ((($this) + ($lightmapType<<4)|0) + 4|0);
 ;HEAP32[$2+0>>2]=HEAP32[$lightmapST+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$lightmapST+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$lightmapST+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$lightmapST+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN20QuadTreeNodeRenderer6RenderEiRK14ChannelAssigns($this,$0,$channels) {
 $this = $this|0;
 $0 = $0|0;
 $channels = $channels|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $whiteColors = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $whiteColors = sp;
 $1 = (($channels) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 4;
 $4 = ($3|0)==(0);
 if ($4) {
  __ZN20QuadTreeNodeRenderer25RenderWithSecondaryStreamERK14ChannelAssignsPK18VertexStreamSource($this,$channels,0);
  STACKTOP = sp;return;
 } else {
  $5 = (__Z12GetGfxDevicev()|0);
  __ZN9GfxDevice23GetAllWhiteVertexStreamEj($whiteColors,$5,289);
  __ZN20QuadTreeNodeRenderer25RenderWithSecondaryStreamERK14ChannelAssignsPK18VertexStreamSource($this,$channels,$whiteColors);
  STACKTOP = sp;return;
 }
}
function __ZN20QuadTreeNodeRenderer25RenderWithSecondaryStreamERK14ChannelAssignsPK18VertexStreamSource($this,$channels,$secondaryStream) {
 $this = $this|0;
 $channels = $channels|0;
 $secondaryStream = $secondaryStream|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $streams = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $streams = sp;
 $1 = (($this) + 244|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 248|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 168|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $16 = $5;
 } else {
  $10 = (__Z12GetGfxDevicev()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 216|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($10,$14);
  $$pre = HEAP32[$4>>2]|0;
  $16 = $$pre;
 }
 $15 = (($16) + 12|0);
 $17 = (($16) + 4|0);
 $18 = (($16) + 120|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19 & 2;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $22 = HEAP32[$17>>2]|0;
  $23 = ($22|0)==(0|0);
  if ($23) {
   label = 8;
  } else {
   $24 = HEAP32[$22>>2]|0;
   $25 = (($24) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (FUNCTION_TABLE_ii[$26 & 4095]($22)|0);
   if ($27) {
    label = 8;
   }
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  $28 = HEAP32[$17>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   $30 = HEAP32[$1>>2]|0;
   __ZN15TerrainRenderer24ReclaimPatchVertexBufferEP12VertexBuffer($30,$28);
  }
  $31 = HEAP32[$1>>2]|0;
  $32 = HEAP32[$4>>2]|0;
  $33 = (($32) + 84|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 88|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($32) + 92|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($16) + 32|0);
  __ZN15TerrainRenderer20GetPatchVertexStreamEiiiPj($0,$31,$34,$36,$38,$39);
  $40 = $0;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = $17;
  $47 = $46;
  HEAP32[$47>>2] = $42;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $45;
  $50 = (($16) + 28|0);
  HEAP32[$50>>2] = 0;
  $51 = HEAP32[$4>>2]|0;
  $52 = (($51) + 120|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53 & -3;
  HEAP8[$52>>0] = $54;
 }
 $55 = HEAP32[$4>>2]|0;
 $56 = (($55) + 120|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = $57 & 4;
 $59 = ($58<<24>>24)==(0);
 if ($59) {
  $60 = HEAP32[$55>>2]|0;
  $61 = ($60|0)==(0|0);
  if ($61) {
   label = 13;
  }
 } else {
  label = 13;
 }
 if ((label|0) == 13) {
  $62 = HEAP32[$1>>2]|0;
  $63 = (($55) + 68|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($16) + 20|0);
  $66 = (__ZN15TerrainRenderer19GetPatchIndexBufferEiPj($62,$64,$65)|0);
  $67 = HEAP32[$4>>2]|0;
  HEAP32[$67>>2] = $66;
  $68 = (($16) + 16|0);
  HEAP32[$68>>2] = 0;
  HEAP32[$15>>2] = 0;
  $69 = HEAP32[$4>>2]|0;
  $70 = (($69) + 120|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71 & -5;
  HEAP8[$70>>0] = $72;
 }
 $73 = $17;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = (($73) + 4)|0;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = $streams;
 $80 = $79;
 HEAP32[$80>>2] = $75;
 $81 = (($79) + 4)|0;
 $82 = $81;
 HEAP32[$82>>2] = $78;
 $83 = (($streams) + 8|0);
 HEAP32[$83>>2] = 0;
 $84 = (($streams) + 12|0);
 HEAP32[$84>>2] = 0;
 $85 = ($secondaryStream|0)!=(0|0);
 if ($85) {
  $86 = (($streams) + 8|0);
  $87 = $secondaryStream;
  $88 = $87;
  $89 = HEAP32[$88>>2]|0;
  $90 = (($87) + 4)|0;
  $91 = $90;
  $92 = HEAP32[$91>>2]|0;
  $93 = $86;
  $94 = $93;
  HEAP32[$94>>2] = $89;
  $95 = (($93) + 4)|0;
  $96 = $95;
  HEAP32[$96>>2] = $92;
 }
 $97 = (__Z12GetGfxDevicev()|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (($98) + 300|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = HEAP32[$4>>2]|0;
 $102 = HEAP32[$101>>2]|0;
 $103 = $85 ? 2 : 1;
 $104 = HEAP32[$1>>2]|0;
 $105 = (__ZN15TerrainRenderer24GetPatchMeshVertexFormatEv($104)|0);
 $106 = (($channels) + 4|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (__ZN16MeshVertexFormat20GetVertexDeclarationEjPKS_($105,$107,0)|0);
 FUNCTION_TABLE_viiiiiiii[$100 & 63]($97,$102,$streams,$103,$15,1,$108,$channels);
 STACKTOP = sp;return;
}
function __ZN20QuadTreeNodeRendererD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN20QuadTreeNodeRendererD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(950,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[800400>>2]|0;
  __ZN10MemoryPool10DeallocateEPv($2,$this);
  STACKTOP = sp;return;
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $5 = HEAP32[800400>>2]|0;
 __THREW__ = 0;
 invoke_vii(2609,($5|0),($this|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  ___resumeException($3|0);
  // unreachable;
 }
}
function __ZN20QuadTreeNodeRenderer14OnAssetDeletedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13SplatDatabase18RecalculateBasemapEb($this,$isLoadingThread) {
 $this = $this|0;
 $isLoadingThread = $isLoadingThread|0;
 var $$ = 0, $$$i = 0, $$0 = 0, $$0$i15 = 0, $$01 = 0, $$arith = 0, $$arith2 = 0, $$byval_copy9 = 0, $$overflow = 0, $$overflow3 = 0, $$pre = 0, $$pre$i = 0, $$pre$i5 = 0, $$pre56 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = Math_fround(0), $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = Math_fround(0), $229 = Math_fround(0);
 var $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = Math_fround(0), $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = 0, $239 = 0, $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = 0, $243 = 0, $244 = Math_fround(0), $245 = Math_fround(0), $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alphaFixX$027$us = 0, $alphaFixY$037 = 0, $alphamap = 0, $c$023$us = 0, $exitcond = 0, $exitcond52 = 0, $i$042 = 0, $i3$020 = 0, $m$01$i$i = 0, $not$ = 0, $phitmp = 0, $pixIndex$036 = 0, $pixIndex$129$us = 0, $s$021 = 0, $s1$024$us = 0;
 var $s2$032 = 0, $sRGBEncountered$0$off0$ = 0, $sRGBEncountered$0$off044 = 0, $sRGBEncountered$2$off0 = 0, $scevgep = 0, $split31 = 0, $terrainSize = 0, $x$028$us = 0, $y$035 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy9 = sp;
 $0 = sp + 60|0;
 $1 = sp + 56|0;
 $2 = sp + 52|0;
 $3 = sp + 48|0;
 $4 = sp + 64|0;
 $terrainSize = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp + 20|0;
 $alphamap = sp + 32|0;
 L1: do {
  if ($isLoadingThread) {
   $7 = (($this) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$this>>2]|0;
   $10 = $8;
   $11 = $9;
   $12 = (($10) - ($11))|0;
   $13 = (($12|0) / 24)&-1;
   $14 = ($12|0)>(0);
   L3: do {
    if ($14) {
     $15 = HEAP32[$9>>2]|0;
     HEAP32[$2>>2] = $15;
     $16 = (__Z17dynamic_pptr_castIP9Texture2D6ObjectET_RK4PPtrIT0_E($2)|0);
     $17 = ($16|0)==(0|0);
     if ($17) {
      STACKTOP = sp;return;
     } else {
      $19 = 1;
     }
     while(1) {
      $18 = ($19|0)<($13|0);
      if (!($18)) {
       break L3;
      }
      $$pre$i = HEAP32[$this>>2]|0;
      $20 = (($$pre$i) + (($19*24)|0)|0);
      $21 = HEAP32[$20>>2]|0;
      HEAP32[$2>>2] = $21;
      $22 = (__Z17dynamic_pptr_castIP9Texture2D6ObjectET_RK4PPtrIT0_E($2)|0);
      $23 = ($22|0)==(0|0);
      $24 = (($19) + 1)|0;
      if ($23) {
       break;
      } else {
       $19 = $24;
      }
     }
     STACKTOP = sp;return;
    }
   } while(0);
   $25 = (($this) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($this) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($26|0)==($28|0);
   if (!($29)) {
    $39 = $28;$m$01$i$i = 0;
    while(1) {
     $38 = (($39) + ($m$01$i$i<<2)|0);
     $40 = HEAP32[$38>>2]|0;
     HEAP32[$1>>2] = $40;
     $41 = (__Z17dynamic_pptr_castIP9Texture2D6ObjectET_RK4PPtrIT0_E($1)|0);
     $42 = ($41|0)==(0|0);
     $37 = (($m$01$i$i) + 1)|0;
     if ($42) {
      break;
     }
     $30 = HEAP32[$25>>2]|0;
     $31 = HEAP32[$27>>2]|0;
     $32 = $30;
     $33 = $31;
     $34 = (($32) - ($33))|0;
     $35 = $34 >> 2;
     $36 = ($37>>>0)<($35>>>0);
     if ($36) {
      $39 = $31;$m$01$i$i = $37;
     } else {
      break L1;
     }
    }
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $43 = (($this) + 36|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 24|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 do {
  if ($47) {
   $48 = HEAP32[628384>>2]|0;
   HEAP32[$3>>2] = $48;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
   $49 = (__Znwj10MemLabelIdbiPKci(136,$$byval_copy9,1,16,800536,100)|0);
   $50 = HEAP32[628384>>2]|0;
   HEAP32[$4>>2] = $50;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(1733,($49|0),($$byval_copy9|0),1);
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if ($52) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_viiiiii(97,($49|0),($$byval_copy9|0),1,16,(800536|0),100);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     $409 = ___cxa_find_matching_catch(0|0)|0;
     $410 = tempRet0;
     ___clang_call_terminate($409);
     // unreachable;
    } else {
     $$0 = $68;$$01 = $69;
     ___resumeException($$0|0);
     // unreachable;
    }
   }
   $53 = (__ZN6Object22CalculateCachedClassIDEPS_($49)|0);
   HEAP32[$45>>2] = $53;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 24|0);
   $56 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vi[$56 & 4095]($53);
   $57 = HEAP32[$45>>2]|0;
   $58 = HEAP32[$57>>2]|0;
   $59 = (($58) + 148|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (FUNCTION_TABLE_iiiiiiii[$60 & 127]($57,$44,$44,4,1,1,0)|0);
   if (!($61)) {
    $62 = (($this) + 28|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = ($63|0)==(0|0);
    if ($64) {
     $67 = 0;
    } else {
     $65 = (($63) + 4|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = $66;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(800544,0,800536,112,1,$67,0,0);
    STACKTOP = sp;return;
   }
  } else {
   $72 = HEAP32[$46>>2]|0;
   $73 = (($72) + 104|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (FUNCTION_TABLE_ii[$74 & 4095]($46)|0);
   $76 = ($75|0)==($44|0);
   if ($76) {
    $77 = HEAP32[$45>>2]|0;
    $78 = HEAP32[$77>>2]|0;
    $79 = (($78) + 108|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (FUNCTION_TABLE_ii[$80 & 4095]($77)|0);
    $82 = ($81|0)==($44|0);
    if ($82) {
     $83 = HEAP32[$45>>2]|0;
     $84 = (($83) + 48|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = ($85|0)==(0|0);
     if (!($86)) {
      $87 = (($85) + 32|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = ($88|0)==(4);
      if ($89) {
       $90 = HEAP32[$83>>2]|0;
       $91 = (($90) + 124|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = (FUNCTION_TABLE_ii[$92 & 4095]($83)|0);
       if ($93) {
        break;
       }
      }
     }
    }
   }
   $94 = HEAP32[$45>>2]|0;
   $95 = (__ZN9Texture2D16ResizeWithFormatEii13TextureFormati($94,$44,$44,4,1)|0);
   if (!($95)) {
    $96 = (($this) + 28|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($97|0)==(0|0);
    if ($98) {
     $101 = 0;
    } else {
     $99 = (($97) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = $100;
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(800544,0,800536,124,1,$101,0,0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $102 = (($this) + 28|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + 232|0);
 __ZNK9Heightmap7GetSizeEv($terrainSize,$104);
 $105 = (($this) + 4|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = HEAP32[$this>>2]|0;
 $108 = $106;
 $109 = $107;
 $110 = (($108) - ($109))|0;
 $111 = (($110|0) / 24)&-1;
 $$arith2 = ($111*40)|0;
 $$overflow3 = ($111>>>0)>(107374182);
 $112 = $$overflow3 ? -1 : $$arith2;
 $113 = (__Znaj($112)|0);
 $114 = ($110|0)>(0);
 do {
  if ($114) {
   $116 = (($6) + 1|0);
   $117 = (($6) + 8|0);
   $118 = (($terrainSize) + 8|0);
   $119 = (Math_fround(($44|0)));
   $121 = $107;$i$042 = 0;$sRGBEncountered$0$off044 = 0;
   while(1) {
    $120 = (($121) + (($i$042*24)|0)|0);
    $122 = HEAP32[$120>>2]|0;
    HEAP32[$5>>2] = $122;
    $123 = (__Z17dynamic_pptr_castIP9Texture2D6ObjectET_RK4PPtrIT0_E($5)|0);
    $124 = ($123|0)==(0|0);
    if ($124) {
     HEAP32[$$byval_copy9>>2] = $i$042;
     __Z6FormatPKcz($6,800576,$$byval_copy9);
     $125 = HEAP32[$102>>2]|0;
     $126 = ($125|0)==(0|0);
     if ($126) {
      $133 = 0;
     } else {
      $127 = (($125) + 4|0);
      $128 = HEAP32[$127>>2]|0;
      $133 = $128;
     }
     $129 = HEAP8[$6>>0]|0;
     $130 = $129 & 1;
     $131 = ($130<<24>>24)==(0);
     $132 = HEAP32[$117>>2]|0;
     $$ = $131 ? $116 : $132;
     __THREW__ = 0;
     invoke_viiiiiiii(21,($$|0),0,(800536|0),172,1,($133|0),0,(0|0));
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      break;
     }
     $136 = HEAP8[$6>>0]|0;
     $137 = $136 & 1;
     $138 = ($137<<24>>24)==(0);
     if (!($138)) {
      $139 = HEAP32[$117>>2]|0;
      __ZdlPv($139);
     }
     $140 = (__Znaj(4)|0);
     $141 = ((($113) + (($i$042*40)|0)|0) + 36|0);
     HEAP32[$141>>2] = $140;
     HEAP32[$140>>2] = -1;
     $142 = ((($113) + (($i$042*40)|0)|0) + 32|0);
     HEAP32[$142>>2] = 1;
     $143 = (($113) + (($i$042*40)|0)|0);
     ;HEAP32[$143+0>>2]=0|0;HEAP32[$143+4>>2]=0|0;HEAP32[$143+8>>2]=0|0;HEAP32[$143+12>>2]=0|0;HEAP32[$143+16>>2]=0|0;HEAP32[$143+20>>2]=0|0;
     $sRGBEncountered$2$off0 = $sRGBEncountered$0$off044;
    } else {
     $150 = (($123) + 56|0);
     $151 = HEAP32[$150>>2]|0;
     $not$ = ($151|0)!=(0);
     $sRGBEncountered$0$off0$ = $sRGBEncountered$0$off044 | $not$;
     $152 = HEAP32[$123>>2]|0;
     $153 = (($152) + 104|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (FUNCTION_TABLE_ii[$154 & 4095]($123)|0);
     $156 = HEAP32[$123>>2]|0;
     $157 = (($156) + 108|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (FUNCTION_TABLE_ii[$158 & 4095]($123)|0);
     $160 = Math_fround(HEAPF32[$terrainSize>>2]);
     $161 = HEAP32[$this>>2]|0;
     $162 = ((($161) + (($i$042*24)|0)|0) + 8|0);
     $163 = Math_fround(HEAPF32[$162>>2]);
     $164 = Math_fround($160 / $163);
     $165 = Math_fround(HEAPF32[$118>>2]);
     $166 = ((($161) + (($i$042*24)|0)|0) + 12|0);
     $167 = Math_fround(HEAPF32[$166>>2]);
     $168 = Math_fround($165 / $167);
     $169 = Math_fround($119 / $164);
     $170 = (~~(($169)));
     $171 = ($170|0)<(1);
     $172 = $171 ? 1 : $170;
     $173 = Math_fround($119 / $168);
     $174 = (~~(($173)));
     $175 = ($174|0)<(1);
     $176 = $175 ? 1 : $174;
     $177 = Math_imul($159, $155)|0;
     $178 = Math_imul($176, $172)|0;
     $179 = (($177|0) / ($178|0))&-1;
     $180 = (Math_fround(($179|0)));
     $181 = ((($161) + (($i$042*24)|0)|0) + 16|0);
     $182 = Math_fround(HEAPF32[$181>>2]);
     $183 = Math_fround($182 / $160);
     $184 = Math_fround($164 * $183);
     $185 = ((($161) + (($i$042*24)|0)|0) + 20|0);
     $186 = Math_fround(HEAPF32[$185>>2]);
     $187 = Math_fround($186 / $165);
     $188 = Math_fround($168 * $187);
     $189 = (Math_fround(+(_log2f((+$180)))));
     $190 = Math_fround($189 * Math_fround(0.5));
     $191 = (~~(($190)));
     $192 = (__ZNK9Texture2D16CountDataMipmapsEv($123)|0);
     $193 = (($192) + -1)|0;
     $194 = ($191|0)<(0);
     if ($194) {
      $$0$i15 = 0;
     } else {
      $195 = ($191|0)>($193|0);
      $$$i = $195 ? $193 : $191;
      $$0$i15 = $$$i;
     }
     $196 = (($123) + 48|0);
     $197 = HEAP32[$196>>2]|0;
     $198 = ($197|0)==(0|0);
     if ($198) {
      $201 = 5;
     } else {
      $199 = (($197) + 32|0);
      $200 = HEAP32[$199>>2]|0;
      $201 = $200;
     }
     $202 = (__Z33GetMinimumTextureMipSizeForFormat13TextureFormat($201)|0);
     $203 = $155 >> $$0$i15;
     $204 = ($203|0)<($202|0);
     $205 = $204 ? $202 : $203;
     $206 = $159 >> $$0$i15;
     $207 = ($206|0)<($202|0);
     $208 = $207 ? $202 : $206;
     $209 = Math_imul($205, $208)|0;
     $$arith = $209<<2;
     $$overflow = ($209>>>0)>(1073741823);
     $210 = $$overflow ? -1 : $$arith;
     $211 = (__Znaj($210)|0);
     $212 = ((($113) + (($i$042*40)|0)|0) + 36|0);
     HEAP32[$212>>2] = $211;
     $213 = (__ZNK9Texture2D11GetPixels32EiP11ColorRGBA32i($123,$$0$i15,$211,$209)|0);
     if (!($213)) {
      $214 = HEAP32[$212>>2]|0;
      $215 = $209 << 2;
      _memset(($214|0),0,($215|0))|0;
      $216 = HEAP32[$102>>2]|0;
      $217 = ($216|0)==(0|0);
      if ($217) {
       $220 = 0;
      } else {
       $218 = (($216) + 4|0);
       $219 = HEAP32[$218>>2]|0;
       $220 = $219;
      }
      __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(800608,0,800536,213,1,$220,0,0);
     }
     $221 = ((($113) + (($i$042*40)|0)|0) + 32|0);
     HEAP32[$221>>2] = $205;
     $222 = $205 << 16;
     $223 = (($222) + -1)|0;
     $224 = (($113) + (($i$042*40)|0)|0);
     HEAP32[$224>>2] = $223;
     $225 = $208 << 16;
     $226 = (($225) + -1)|0;
     $227 = ((($113) + (($i$042*40)|0)|0) + 4|0);
     HEAP32[$227>>2] = $226;
     $228 = (Math_fround(($205|0)));
     $229 = Math_fround($164 * $228);
     $230 = Math_fround($229 / $119);
     $231 = Math_fround($230 * Math_fround(65536.0));
     $232 = (~~(($231)));
     $233 = ((($113) + (($i$042*40)|0)|0) + 8|0);
     HEAP32[$233>>2] = $232;
     $234 = (Math_fround(($208|0)));
     $235 = Math_fround($168 * $234);
     $236 = Math_fround($235 / $119);
     $237 = Math_fround($236 * Math_fround(65536.0));
     $238 = (~~(($237)));
     $239 = ((($113) + (($i$042*40)|0)|0) + 12|0);
     HEAP32[$239>>2] = $238;
     $240 = Math_fround($184 * $228);
     $241 = Math_fround($240 * Math_fround(65536.0));
     $242 = (~~(($241)));
     $243 = ((($113) + (($i$042*40)|0)|0) + 24|0);
     HEAP32[$243>>2] = $242;
     $244 = Math_fround($188 * $234);
     $245 = Math_fround($244 * Math_fround(65536.0));
     $246 = (~~(($245)));
     $247 = ((($113) + (($i$042*40)|0)|0) + 16|0);
     HEAP32[$247>>2] = 0;
     $248 = (($238|0) / 2)&-1;
     $249 = (($248) + ($246))|0;
     $250 = $249 & $226;
     $251 = ((($113) + (($i$042*40)|0)|0) + 20|0);
     HEAP32[$251>>2] = $250;
     $sRGBEncountered$2$off0 = $sRGBEncountered$0$off0$;
    }
    $252 = (($i$042) + 1)|0;
    $253 = ($252|0)<($111|0);
    if (!($253)) {
     label = 49;
     break;
    }
    $$pre56 = HEAP32[$this>>2]|0;
    $121 = $$pre56;$i$042 = $252;$sRGBEncountered$0$off044 = $sRGBEncountered$2$off0;
   }
   if ((label|0) == 49) {
    $254 = HEAP32[$45>>2]|0;
    if (!($sRGBEncountered$2$off0)) {
     $255 = $254;
     label = 51;
     break;
    }
    __ZN7Texture33SetStoredColorSpaceNoDirtyNoApplyE17TextureColorSpace($254,1);
    break;
   }
   $144 = ___cxa_find_matching_catch()|0;
   $145 = tempRet0;
   $146 = HEAP8[$6>>0]|0;
   $147 = $146 & 1;
   $148 = ($147<<24>>24)==(0);
   if ($148) {
    $$0 = $144;$$01 = $145;
    ___resumeException($$0|0);
    // unreachable;
   }
   $149 = HEAP32[$117>>2]|0;
   __ZdlPv($149);
   $$0 = $144;$$01 = $145;
   ___resumeException($$0|0);
   // unreachable;
  } else {
   $115 = HEAP32[$45>>2]|0;
   $255 = $115;
   label = 51;
  }
 } while(0);
 if ((label|0) == 51) {
  __ZN7Texture33SetStoredColorSpaceNoDirtyNoApplyE17TextureColorSpace($255,0);
 }
 HEAP32[$alphamap>>2] = 0;
 $256 = (($alphamap) + 8|0);
 HEAP32[$256>>2] = 0;
 $257 = (($alphamap) + 12|0);
 HEAP32[$257>>2] = 0;
 $258 = (($alphamap) + 4|0);
 HEAP32[$258>>2] = 61;
 __THREW__ = 0;
 invoke_viii(2031,($this|0),($alphamap|0),0);
 $259 = __THREW__; __THREW__ = 0;
 $260 = $259&1;
 do {
  if (!($260)) {
   $261 = HEAP32[$45>>2]|0;
   __THREW__ = 0;
   invoke_vi(3470,($261|0));
   $262 = __THREW__; __THREW__ = 0;
   $263 = $262&1;
   if (!($263)) {
    $264 = (($261) + 48|0);
    $265 = HEAP32[$264>>2]|0;
    $266 = ($265|0)==(0|0);
    if ($266) {
     $307 = 0;
    } else {
     $267 = (($265) + 8|0);
     $268 = HEAP32[$267>>2]|0;
     $307 = $268;
    }
    $269 = (($this) + 32|0);
    $270 = HEAP32[$269>>2]|0;
    $271 = $270 << 16;
    $272 = (($271|0) / ($44|0))&-1;
    $273 = ($44|0)>(0);
    L90: do {
     if ($273) {
      $274 = HEAP32[$alphamap>>2]|0;
      $275 = $44 << 2;
      $278 = $270;$alphaFixY$037 = 0;$pixIndex$036 = 0;$y$035 = 1;
      while(1) {
       $276 = $alphaFixY$037 >> 16;
       $277 = Math_imul($278, $276)|0;
       if ($114) {
        $s$021 = 0;
        while(1) {
         $279 = ((($113) + (($s$021*40)|0)|0) + 8|0);
         $280 = HEAP32[$279>>2]|0;
         $281 = (($280|0) / 2)&-1;
         $282 = ((($113) + (($s$021*40)|0)|0) + 24|0);
         $283 = HEAP32[$282>>2]|0;
         $284 = (($283) + ($281))|0;
         $285 = (($113) + (($s$021*40)|0)|0);
         $286 = HEAP32[$285>>2]|0;
         $287 = $284 & $286;
         $288 = ((($113) + (($s$021*40)|0)|0) + 16|0);
         HEAP32[$288>>2] = $287;
         $289 = ((($113) + (($s$021*40)|0)|0) + 20|0);
         $290 = HEAP32[$289>>2]|0;
         $291 = $290 >> 16;
         $292 = ((($113) + (($s$021*40)|0)|0) + 32|0);
         $293 = HEAP32[$292>>2]|0;
         $294 = Math_imul($291, $293)|0;
         $295 = ((($113) + (($s$021*40)|0)|0) + 28|0);
         HEAP32[$295>>2] = $294;
         $296 = (($s$021) + 1)|0;
         $297 = ($296|0)<($111|0);
         if ($297) {
          $s$021 = $296;
         } else {
          break;
         }
        }
        if ($114) {
         $alphaFixX$027$us = 0;$pixIndex$129$us = $pixIndex$036;$x$028$us = 0;
         while(1) {
          $345 = $alphaFixX$027$us >> 16;
          $346 = (($345) + ($277))|0;
          $324 = Math_imul($346, $111)|0;
          $c$023$us = 0;$s1$024$us = 0;
          while(1) {
           $313 = ((($113) + (($s1$024$us*40)|0)|0) + 28|0);
           $314 = HEAP32[$313>>2]|0;
           $315 = ((($113) + (($s1$024$us*40)|0)|0) + 16|0);
           $316 = HEAP32[$315>>2]|0;
           $317 = $316 >> 16;
           $318 = (($317) + ($314))|0;
           $319 = ((($113) + (($s1$024$us*40)|0)|0) + 36|0);
           $320 = HEAP32[$319>>2]|0;
           $321 = (($320) + ($318<<2)|0);
           $322 = HEAP32[$321>>2]|0;
           $323 = (($s1$024$us) + ($324))|0;
           $325 = (($274) + ($323)|0);
           $326 = HEAP8[$325>>0]|0;
           $327 = $326&255;
           $328 = $322 & 16711935;
           $329 = Math_imul($327, $328)|0;
           $330 = $329 >>> 8;
           $331 = $330 & 16711935;
           $332 = $322 >>> 8;
           $333 = $332 & 16711935;
           $334 = Math_imul($327, $333)|0;
           $335 = $334 & 65280;
           $336 = $331 | $335;
           $309 = (($336) + ($c$023$us))|0;
           $337 = ((($113) + (($s1$024$us*40)|0)|0) + 8|0);
           $338 = HEAP32[$337>>2]|0;
           $339 = (($338) + ($316))|0;
           $340 = (($113) + (($s1$024$us*40)|0)|0);
           $341 = HEAP32[$340>>2]|0;
           $342 = $339 & $341;
           HEAP32[$315>>2] = $342;
           $343 = (($s1$024$us) + 1)|0;
           $344 = ($343|0)<($111|0);
           if ($344) {
            $c$023$us = $309;$s1$024$us = $343;
           } else {
            break;
           }
          }
          $308 = (($307) + ($pixIndex$129$us<<2)|0);
          HEAP32[$308>>2] = $309;
          $310 = (($x$028$us) + 1)|0;
          $311 = (($alphaFixX$027$us) + ($272))|0;
          $312 = (($pixIndex$129$us) + 1)|0;
          $exitcond = ($310|0)==($44|0);
          if ($exitcond) {
           break;
          } else {
           $alphaFixX$027$us = $311;$pixIndex$129$us = $312;$x$028$us = $310;
          }
         }
        } else {
         label = 64;
        }
       } else {
        label = 64;
       }
       if ((label|0) == 64) {
        label = 0;
        $306 = $pixIndex$036 << 2;
        $scevgep = (($307) + ($306)|0);
        _memset(($scevgep|0),0,($275|0))|0;
       }
       $split31 = (($44) + ($pixIndex$036))|0;
       if ($114) {
        $s2$032 = 0;
        while(1) {
         $347 = ((($113) + (($s2$032*40)|0)|0) + 20|0);
         $348 = HEAP32[$347>>2]|0;
         $349 = ((($113) + (($s2$032*40)|0)|0) + 12|0);
         $350 = HEAP32[$349>>2]|0;
         $351 = (($350) + ($348))|0;
         $352 = ((($113) + (($s2$032*40)|0)|0) + 4|0);
         $353 = HEAP32[$352>>2]|0;
         $354 = $351 & $353;
         HEAP32[$347>>2] = $354;
         $355 = (($s2$032) + 1)|0;
         $356 = ($355|0)<($111|0);
         if ($356) {
          $s2$032 = $355;
         } else {
          break;
         }
        }
       }
       $exitcond52 = ($y$035|0)==($44|0);
       if ($exitcond52) {
        break L90;
       }
       $357 = (($alphaFixY$037) + ($272))|0;
       $$pre = HEAP32[$269>>2]|0;
       $phitmp = (($y$035) + 1)|0;
       $278 = $$pre;$alphaFixY$037 = $357;$pixIndex$036 = $split31;$y$035 = $phitmp;
      }
     }
    } while(0);
    $358 = ($106|0)==($107|0);
    if ($358) {
     $359 = Math_imul($44, $44)|0;
     $360 = HEAP32[$45>>2]|0;
     $361 = (($360) + 48|0);
     $362 = HEAP32[$361>>2]|0;
     $363 = ($362|0)==(0|0);
     if ($363) {
      $366 = 5;
     } else {
      $364 = (($362) + 32|0);
      $365 = HEAP32[$364>>2]|0;
      $366 = $365;
     }
     __THREW__ = 0;
     $367 = (invoke_ii(3406,($366|0))|0);
     $368 = __THREW__; __THREW__ = 0;
     $369 = $368&1;
     if ($369) {
      break;
     }
     $370 = Math_imul($359, $367)|0;
     _memset(($307|0),-1,($370|0))|0;
    }
    $371 = HEAP32[$45>>2]|0;
    $372 = HEAP32[$371>>2]|0;
    $373 = (($372) + 160|0);
    $374 = HEAP32[$373>>2]|0;
    __THREW__ = 0;
    invoke_vi($374|0,($371|0));
    $375 = __THREW__; __THREW__ = 0;
    $376 = $375&1;
    if (!($376)) {
     if (!($isLoadingThread)) {
      $377 = HEAP32[$45>>2]|0;
      $378 = (($377) + 4|0);
      $379 = HEAP32[$378>>2]|0;
      $380 = ($379|0)==(0);
      if ($380) {
       __THREW__ = 0;
       (invoke_ii(3405,($377|0))|0);
       $381 = __THREW__; __THREW__ = 0;
       $382 = $381&1;
       if ($382) {
        break;
       }
       $383 = HEAP32[$45>>2]|0;
       $384 = HEAP32[$383>>2]|0;
       $385 = (($384) + 44|0);
       $386 = HEAP32[$385>>2]|0;
       __THREW__ = 0;
       invoke_vii($386|0,($383|0),61);
       $387 = __THREW__; __THREW__ = 0;
       $388 = $387&1;
       if ($388) {
        break;
       }
       $389 = HEAP32[$45>>2]|0;
       __THREW__ = 0;
       invoke_vii(3406,($389|0),1);
       $390 = __THREW__; __THREW__ = 0;
       $391 = $390&1;
       if ($391) {
        break;
       }
       $$pre$i5 = HEAP32[$45>>2]|0;
       $393 = $$pre$i5;
      } else {
       $393 = $377;
      }
      $392 = HEAP32[$393>>2]|0;
      $394 = (($392) + 12|0);
      $395 = HEAP32[$394>>2]|0;
      __THREW__ = 0;
      invoke_vii($395|0,($393|0),0);
      $396 = __THREW__; __THREW__ = 0;
      $397 = $396&1;
      if ($397) {
       break;
      }
     }
     if ($114) {
      $i3$020 = 0;
      while(1) {
       $398 = ((($113) + (($i3$020*40)|0)|0) + 36|0);
       $399 = HEAP32[$398>>2]|0;
       $400 = ($399|0)==(0|0);
       if (!($400)) {
        __ZdaPv($399);
       }
       $401 = (($i3$020) + 1)|0;
       $402 = ($401|0)<($111|0);
       if ($402) {
        $i3$020 = $401;
       } else {
        break;
       }
      }
     }
     $403 = ($113|0)==(0|0);
     if (!($403)) {
      __ZdaPv($113);
     }
     $404 = (($this) + 40|0);
     HEAP8[$404>>0] = 0;
     $405 = HEAP32[$257>>2]|0;
     $406 = ($405|0)>(-1);
     if (!($406)) {
      STACKTOP = sp;return;
     }
     $407 = HEAP32[$alphamap>>2]|0;
     $408 = HEAP32[$258>>2]|0;
     HEAP32[$0>>2] = $408;
     ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($407,$$byval_copy9);
     HEAP32[$alphamap>>2] = 0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $298 = ___cxa_find_matching_catch()|0;
 $299 = tempRet0;
 $300 = HEAP32[$257>>2]|0;
 $301 = ($300|0)>(-1);
 if (!($301)) {
  $$0 = $298;$$01 = $299;
  ___resumeException($$0|0);
  // unreachable;
 }
 $302 = HEAP32[$alphamap>>2]|0;
 $303 = HEAP32[$258>>2]|0;
 HEAP32[$0>>2] = $303;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($302|0),($$byval_copy9|0));
 $304 = __THREW__; __THREW__ = 0;
 $305 = $304&1;
 if ($305) {
  $409 = ___cxa_find_matching_catch(0|0)|0;
  $410 = tempRet0;
  ___clang_call_terminate($409);
  // unreachable;
 }
 HEAP32[$alphamap>>2] = 0;
 $$0 = $298;$$01 = $299;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN13SplatDatabase12GetAlphamapsER13dynamic_arrayIhLj1EEb($this,$buffer,$allowResourceLoad) {
 $this = $this|0;
 $buffer = $buffer|0;
 $allowResourceLoad = $allowResourceLoad|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$51 = 0, $$52 = 0, $$53 = 0, $$byval_copy18 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$021$us = 0, $allocPtr$0 = 0, $bufferIndex$022$us = 0, $exitcond = 0, $i$024$us = 0, $indvars$iv = 0, $indvars$iv$next = 0, $indvars$iv$op = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $m$043 = 0, $m1$027 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy18 = sp;
 $0 = sp + 52|0;
 $1 = sp + 48|0;
 $2 = sp + 36|0;
 $3 = sp + 56|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp + 20|0;
 $7 = sp + 24|0;
 $8 = (($this) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 L1: do {
  if ($12) {
   $$pre = (($this) + 32|0);
   $$pre$phiZ2D = $$pre;
  } else {
   $13 = (($this) + 28|0);
   $14 = (($2) + 1|0);
   $15 = (($2) + 8|0);
   $16 = (($this) + 32|0);
   $17 = (($3) + 1|0);
   $18 = (($3) + 8|0);
   $19 = (($4) + 1|0);
   $20 = (($4) + 8|0);
   $22 = $11;$m$043 = 0;
   L4: while(1) {
    $21 = (($22) + ($m$043<<2)|0);
    $23 = HEAP32[$21>>2]|0;
    HEAP32[$1>>2] = $23;
    $24 = (__Z17dynamic_pptr_castIP9Texture2D6ObjectET_RK4PPtrIT0_E($1)|0);
    $25 = ($24|0)==(0|0);
    do {
     if ($25) {
      HEAP32[$$byval_copy18>>2] = $m$043;
      __Z6FormatPKcz($2,800648,$$byval_copy18);
      $26 = HEAP32[$13>>2]|0;
      $27 = ($26|0)==(0|0);
      if ($27) {
       $34 = 0;
      } else {
       $28 = (($26) + 4|0);
       $29 = HEAP32[$28>>2]|0;
       $34 = $29;
      }
      $30 = HEAP8[$2>>0]|0;
      $31 = $30 & 1;
      $32 = ($31<<24>>24)==(0);
      $33 = HEAP32[$15>>2]|0;
      $$ = $32 ? $14 : $33;
      __THREW__ = 0;
      invoke_viiiiiiii(21,($$|0),0,(800536|0),396,1,($34|0),0,(0|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 10;
       break L4;
      }
      $37 = HEAP8[$2>>0]|0;
      $38 = $37 & 1;
      $39 = ($38<<24>>24)==(0);
      if (!($39)) {
       $40 = HEAP32[$15>>2]|0;
       __ZdlPv($40);
      }
     } else {
      $47 = HEAP32[$24>>2]|0;
      $48 = (($47) + 104|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = (FUNCTION_TABLE_ii[$49 & 4095]($24)|0);
      $51 = HEAP32[$16>>2]|0;
      $52 = ($50|0)==($51|0);
      if (!($52)) {
       $53 = ($m$043|0)==(0);
       if (!($53)) {
        HEAP32[$$byval_copy18>>2] = $m$043;
        __Z6FormatPKcz($4,800808,$$byval_copy18);
        $79 = HEAP32[$13>>2]|0;
        $80 = ($79|0)==(0|0);
        if ($80) {
         $87 = 0;
        } else {
         $81 = (($79) + 4|0);
         $82 = HEAP32[$81>>2]|0;
         $87 = $82;
        }
        $83 = HEAP8[$4>>0]|0;
        $84 = $83 & 1;
        $85 = ($84<<24>>24)==(0);
        $86 = HEAP32[$20>>2]|0;
        $$52 = $85 ? $19 : $86;
        __THREW__ = 0;
        invoke_viiiiiiii(21,($$52|0),0,(800536|0),409,1,($87|0),0,(0|0));
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 27;
         break L4;
        }
        $90 = HEAP8[$4>>0]|0;
        $91 = $90 & 1;
        $92 = ($91<<24>>24)==(0);
        if ($92) {
         break;
        }
        $93 = HEAP32[$20>>2]|0;
        __ZdlPv($93);
        break;
       }
       HEAP32[$$byval_copy18>>2] = 0;
       __Z6FormatPKcz($3,800688,$$byval_copy18);
       $54 = HEAP32[$13>>2]|0;
       $55 = ($54|0)==(0|0);
       if ($55) {
        $62 = 0;
       } else {
        $56 = (($54) + 4|0);
        $57 = HEAP32[$56>>2]|0;
        $62 = $57;
       }
       $58 = HEAP8[$3>>0]|0;
       $59 = $58 & 1;
       $60 = ($59<<24>>24)==(0);
       $61 = HEAP32[$18>>2]|0;
       $$51 = $60 ? $17 : $61;
       __THREW__ = 0;
       invoke_viiiiiiii(21,($$51|0),0,(800536|0),404,512,($62|0),0,(0|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 20;
        break L4;
       }
       $65 = HEAP8[$3>>0]|0;
       $66 = $65 & 1;
       $67 = ($66<<24>>24)==(0);
       if (!($67)) {
        $68 = HEAP32[$18>>2]|0;
        __ZdlPv($68);
       }
       $69 = HEAP32[$24>>2]|0;
       $70 = (($69) + 104|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = (FUNCTION_TABLE_ii[$71 & 4095]($24)|0);
       HEAP32[$16>>2] = $72;
      }
     }
    } while(0);
    $100 = (($m$043) + 1)|0;
    $101 = HEAP32[$8>>2]|0;
    $102 = HEAP32[$10>>2]|0;
    $103 = $101;
    $104 = $102;
    $105 = (($103) - ($104))|0;
    $106 = $105 >> 2;
    $107 = ($100>>>0)<($106>>>0);
    if ($107) {
     $22 = $102;$m$043 = $100;
    } else {
     $$pre$phiZ2D = $16;
     break L1;
    }
   }
   if ((label|0) == 10) {
    $41 = ___cxa_find_matching_catch()|0;
    $42 = tempRet0;
    $43 = HEAP8[$2>>0]|0;
    $44 = $43 & 1;
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     $$1 = $41;$$12 = $42;
     ___resumeException($$1|0);
     // unreachable;
    }
    $46 = HEAP32[$15>>2]|0;
    __ZdlPv($46);
    $$1 = $41;$$12 = $42;
    ___resumeException($$1|0);
    // unreachable;
   }
   else if ((label|0) == 20) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    $75 = HEAP8[$3>>0]|0;
    $76 = $75 & 1;
    $77 = ($76<<24>>24)==(0);
    if ($77) {
     $$1 = $73;$$12 = $74;
     ___resumeException($$1|0);
     // unreachable;
    }
    $78 = HEAP32[$18>>2]|0;
    __ZdlPv($78);
    $$1 = $73;$$12 = $74;
    ___resumeException($$1|0);
    // unreachable;
   }
   else if ((label|0) == 27) {
    $94 = ___cxa_find_matching_catch()|0;
    $95 = tempRet0;
    $96 = HEAP8[$4>>0]|0;
    $97 = $96 & 1;
    $98 = ($97<<24>>24)==(0);
    if ($98) {
     $$1 = $94;$$12 = $95;
     ___resumeException($$1|0);
     // unreachable;
    }
    $99 = HEAP32[$20>>2]|0;
    __ZdlPv($99);
    $$1 = $94;$$12 = $95;
    ___resumeException($$1|0);
    // unreachable;
   }
  }
 } while(0);
 $108 = HEAP32[$$pre$phiZ2D>>2]|0;
 $109 = Math_imul($108, $108)|0;
 $110 = (($this) + 4|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = HEAP32[$this>>2]|0;
 $113 = $111;
 $114 = $112;
 $115 = (($113) - ($114))|0;
 $116 = (($115|0) / 24)&-1;
 $117 = Math_imul($116, $109)|0;
 $118 = (($buffer) + 8|0);
 HEAP32[$118>>2] = $117;
 $119 = (($buffer) + 12|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = $120 & 2147483647;
 $122 = ($121>>>0)<($117>>>0);
 do {
  if ($122) {
   $123 = ($120|0)>(-1);
   if ($123) {
    HEAP32[$119>>2] = $117;
    $124 = HEAP32[$buffer>>2]|0;
    $125 = (($buffer) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    HEAP32[$0>>2] = $126;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
    $127 = (__Z16realloc_internalPvji10MemLabelIdiPKci($124,$117,1,$$byval_copy18,0,800536,370)|0);
    HEAP32[$buffer>>2] = $127;
    break;
   } else {
    $128 = (($buffer) + 4|0);
    $129 = HEAP32[$128>>2]|0;
    HEAP32[$0>>2] = $129;
    ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
    $130 = (__Z15malloc_internaljj10MemLabelIdiPKci($117,1,$$byval_copy18,0,800536,352)|0);
    $131 = HEAP32[$buffer>>2]|0;
    $132 = HEAP32[$118>>2]|0;
    _memcpy(($130|0),($131|0),($132|0))|0;
    HEAP32[$119>>2] = $117;
    HEAP32[$buffer>>2] = $130;
    break;
   }
  }
 } while(0);
 $133 = $109 << 2;
 $134 = (($133) + 15)|0;
 $135 = ($134>>>0)<(2000);
 $136 = ($109|0)!=(0);
 if ($135) {
  if ($136) {
   $137 = STACKTOP; STACKTOP = STACKTOP + ((((1*$134)|0)+15)&-16)|0;;
   $229 = 0;$allocPtr$0 = $137;
   label = 42;
  } else {
   $229 = 0;$allocPtr$0 = 0;
   label = 42;
  }
 } else {
  if ($136) {
   $138 = HEAP32[628512>>2]|0;
   HEAP32[$5>>2] = $138;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$5+0>>2]|0;
   $139 = (invoke_iiiiiii(102,($134|0),16,($$byval_copy18|0),0,(800536|0),421)|0);
   $140 = __THREW__; __THREW__ = 0;
   $141 = $140&1;
   if ($141) {
    $144 = ___cxa_find_matching_catch()|0;
    $145 = tempRet0;
    $238 = 0;$lpad$phi$index = $144;$lpad$phi$index2 = $145;
    label = 41;
   } else {
    $229 = $139;$allocPtr$0 = $139;
    label = 42;
   }
  } else {
   $229 = 0;$allocPtr$0 = 0;
   label = 42;
  }
 }
 L60: do {
  if ((label|0) == 42) {
   $146 = $allocPtr$0;
   $147 = (($146) + 15)|0;
   $148 = $147 & -16;
   $149 = $148;
   $150 = $148;
   $151 = HEAP32[$8>>2]|0;
   $152 = HEAP32[$10>>2]|0;
   $153 = ($151|0)==($152|0);
   L62: do {
    if (!($153)) {
     $154 = (($this) + 28|0);
     $155 = (($7) + 1|0);
     $156 = (($7) + 8|0);
     $157 = ($109|0)!=(0);
     $158 = $116 ^ -1;
     $164 = $152;$indvars$iv = $158;$m1$027 = 0;
     while(1) {
      $159 = ($indvars$iv|0)>(-5);
      $indvars$iv$op = $indvars$iv ^ -1;
      $160 = $159 ? $indvars$iv$op : 4;
      $161 = $m1$027 << 2;
      $162 = (($116) - ($161))|0;
      $163 = (($164) + ($m1$027<<2)|0);
      $165 = HEAP32[$163>>2]|0;
      HEAP32[$6>>2] = $165;
      __THREW__ = 0;
      $166 = (invoke_ii(3407,($6|0))|0);
      $167 = __THREW__; __THREW__ = 0;
      $168 = $167&1;
      if ($168) {
       label = 39;
       break;
      }
      $169 = ($166|0)==(0|0);
      if ($169) {
       label = 51;
      } else {
       $170 = HEAP32[$166>>2]|0;
       $171 = (($170) + 104|0);
       $172 = HEAP32[$171>>2]|0;
       __THREW__ = 0;
       $173 = (invoke_ii($172|0,($166|0))|0);
       $174 = __THREW__; __THREW__ = 0;
       $175 = $174&1;
       if ($175) {
        label = 39;
        break;
       }
       $176 = ($173|0)==($108|0);
       if ($176) {
        $177 = HEAP32[$166>>2]|0;
        $178 = (($177) + 108|0);
        $179 = HEAP32[$178>>2]|0;
        __THREW__ = 0;
        $180 = (invoke_ii($179|0,($166|0))|0);
        $181 = __THREW__; __THREW__ = 0;
        $182 = $181&1;
        if ($182) {
         label = 39;
         break;
        }
        $183 = ($180|0)==($108|0);
        if ($183) {
         __THREW__ = 0;
         (invoke_iiiii(273,($166|0),0,($150|0),($109|0))|0);
         $184 = __THREW__; __THREW__ = 0;
         $185 = $184&1;
         if ($185) {
          label = 39;
          break;
         }
        } else {
         label = 51;
        }
       } else {
        label = 51;
       }
      }
      if ((label|0) == 51) {
       label = 0;
       __THREW__ = 0;
       HEAP32[$$byval_copy18>>2] = $m1$027;
       invoke_viii(1617,($7|0),(800896|0),($$byval_copy18|0));
       $186 = __THREW__; __THREW__ = 0;
       $187 = $186&1;
       if ($187) {
        label = 39;
        break;
       }
       $188 = HEAP32[$154>>2]|0;
       $189 = ($188|0)==(0|0);
       if ($189) {
        $196 = 0;
       } else {
        $190 = (($188) + 4|0);
        $191 = HEAP32[$190>>2]|0;
        $196 = $191;
       }
       $192 = HEAP8[$7>>0]|0;
       $193 = $192 & 1;
       $194 = ($193<<24>>24)==(0);
       $195 = HEAP32[$156>>2]|0;
       $$53 = $194 ? $155 : $195;
       __THREW__ = 0;
       invoke_viiiiiiii(21,($$53|0),0,(800536|0),434,1,($196|0),0,(0|0));
       $197 = __THREW__; __THREW__ = 0;
       $198 = $197&1;
       if ($198) {
        break;
       }
       $199 = HEAP8[$7>>0]|0;
       $200 = $199 & 1;
       $201 = ($200<<24>>24)==(0);
       if (!($201)) {
        $202 = HEAP32[$156>>2]|0;
        __ZdlPv($202);
       }
       _memset(($149|0),0,($133|0))|0;
      }
      $203 = ($162|0)>(0);
      $or$cond = $157 & $203;
      if ($or$cond) {
       $bufferIndex$022$us = $161;$i$024$us = 0;
       while(1) {
        $208 = (($150) + ($i$024$us<<2)|0);
        $a$021$us = 0;
        while(1) {
         $207 = (($208) + ($a$021$us)|0);
         $209 = HEAP8[$207>>0]|0;
         $210 = (($a$021$us) + ($bufferIndex$022$us))|0;
         $211 = HEAP32[$buffer>>2]|0;
         $212 = (($211) + ($210)|0);
         HEAP8[$212>>0] = $209;
         $213 = (($a$021$us) + 1)|0;
         $exitcond = ($213|0)==($160|0);
         if ($exitcond) {
          break;
         } else {
          $a$021$us = $213;
         }
        }
        $204 = (($bufferIndex$022$us) + ($116))|0;
        $205 = (($i$024$us) + 1)|0;
        $206 = ($205|0)<($109|0);
        if ($206) {
         $bufferIndex$022$us = $204;$i$024$us = $205;
        } else {
         break;
        }
       }
      }
      $220 = (($m1$027) + 1)|0;
      $221 = HEAP32[$8>>2]|0;
      $222 = HEAP32[$10>>2]|0;
      $223 = $221;
      $224 = $222;
      $225 = (($223) - ($224))|0;
      $226 = $225 >> 2;
      $227 = ($220>>>0)<($226>>>0);
      $indvars$iv$next = (($indvars$iv) + 4)|0;
      if ($227) {
       $164 = $222;$indvars$iv = $indvars$iv$next;$m1$027 = $220;
      } else {
       break L62;
      }
     }
     if ((label|0) == 39) {
      $142 = ___cxa_find_matching_catch()|0;
      $143 = tempRet0;
      $238 = $229;$lpad$phi$index = $142;$lpad$phi$index2 = $143;
      label = 41;
      break L60;
     }
     $214 = ___cxa_find_matching_catch()|0;
     $215 = tempRet0;
     $216 = HEAP8[$7>>0]|0;
     $217 = $216 & 1;
     $218 = ($217<<24>>24)==(0);
     if ($218) {
      $$0 = $214;$$01 = $215;$232 = $229;
      break L60;
     }
     $219 = HEAP32[$156>>2]|0;
     __ZdlPv($219);
     $$0 = $214;$$01 = $215;$232 = $229;
     break L60;
    }
   } while(0);
   $228 = ($229|0)==(0|0);
   if ($228) {
    STACKTOP = sp;return;
   }
   $230 = HEAP32[628512>>2]|0;
   HEAP32[$0>>2] = $230;
   ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($229,$$byval_copy18);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 41) {
  $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;$232 = $238;
 }
 $231 = ($232|0)==(0|0);
 if ($231) {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$1|0);
  // unreachable;
 }
 $233 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $233;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($232|0),($$byval_copy18|0));
 $234 = __THREW__; __THREW__ = 0;
 $235 = $234&1;
 if ($235) {
  $236 = ___cxa_find_matching_catch(0|0)|0;
  $237 = tempRet0;
  ___clang_call_terminate($236);
  // unreachable;
 } else {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZN13SplatDatabase25RecalculateBasemapIfDirtyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN13SplatDatabase18RecalculateBasemapEb($this,0);
 STACKTOP = sp;return;
}
function __ZNK13SplatDatabase15GetAlphaTextureEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($index<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $4;
 $6 = HEAP32[560624>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  label = 10;
 } else {
  $8 = (($6) + 36|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($9|0)==($11|0);
  do {
   if ($12) {
    $13 = (($6) + 28|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($6) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14) + ($16<<3)|0);
    $33 = $17;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$6,$0);
    $18 = HEAP32[$pos$i$i$i$i>>2]|0;
    $19 = ($18|0)==(-1);
    $20 = (($6) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    if ($19) {
     $22 = (($6) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($21) + ($23<<3)|0);
     $33 = $24;
     break;
    } else {
     $25 = (($21) + ($18<<3)|0);
     $33 = $25;
     break;
    }
   }
  } while(0);
  $26 = HEAP32[560624>>2]|0;
  $27 = (($26) + 28|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 32|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + ($30<<3)|0);
  $32 = ($33|0)==($31|0);
  if ($32) {
   label = 10;
  } else {
   $34 = (($33) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    label = 10;
   } else {
    $temp$0$i = $35;
   }
  }
 }
 if ((label|0) == 10) {
  $37 = HEAP32[$3>>2]|0;
  $38 = (__Z31ReadObjectFromPersistentManageri($37)|0);
  $temp$0$i = $38;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNK13SplatDatabase10GetBasemapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN14SplatMaterialsC2ERK4PPtrI11TerrainDataERKS0_IN5Unity8MaterialEE($this,$terrainData,$templateMaterial) {
 $this = $this|0;
 $terrainData = $terrainData|0;
 $templateMaterial = $templateMaterial|0;
 var $0 = 0, $1 = 0, $2 = 0, $scevgep4 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$terrainData>>2]|0;
 HEAP32[$this>>2] = $0;
 $1 = HEAP32[$templateMaterial>>2]|0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $1;
 $scevgep4 = (($this) + 8|0);
 dest=$scevgep4+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN14SplatMaterials16LoadSplatShadersEv($this);
 __ZN14SplatMaterials15UpdateMaterialsERK4PPtrIN5Unity8MaterialEE($this,$templateMaterial);
 STACKTOP = sp;return;
}
function __ZN14SplatMaterials16LoadSplatShadersEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0;
 var $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0$i = 0;
  $37 = (($this) + 8|0);
  __ZN14SplatMaterials22LoadSplatShadersStaticEPN5Unity8MaterialEPP6Shader($$0$i,$37);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $2;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 10;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 10;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 10;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 10) {
  $35 = HEAP32[$1>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $$0$i = $temp$0$i;
 $37 = (($this) + 8|0);
 __ZN14SplatMaterials22LoadSplatShadersStaticEPN5Unity8MaterialEPP6Shader($$0$i,$37);
 STACKTOP = sp;return;
}
function __ZN14SplatMaterials15UpdateMaterialsERK4PPtrIN5Unity8MaterialEE($this,$templateMaterial) {
 $this = $this|0;
 $templateMaterial = $templateMaterial|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$templateMaterial>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  __ZN14SplatMaterials20UpdateSplatMaterialsEv($this);
  __ZN14SplatMaterials22UpdateBaseMapMaterialsEv($this);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $2;
 __ZN14SplatMaterials16LoadSplatShadersEv($this);
 $4 = (($this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 __Z19DestroySingleObjectP6Object($5);
 HEAP32[$4>>2] = 0;
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 __Z19DestroySingleObjectP6Object($7);
 HEAP32[$6>>2] = 0;
 $8 = (($this) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 __Z19DestroySingleObjectP6Object($9);
 HEAP32[$8>>2] = 0;
 $10 = (($this) + 32|0);
 $11 = HEAP32[$10>>2]|0;
 __Z19DestroySingleObjectP6Object($11);
 HEAP32[$10>>2] = 0;
 $12 = (($this) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 __Z19DestroySingleObjectP6Object($13);
 HEAP32[$12>>2] = 0;
 $14 = (($this) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 __Z19DestroySingleObjectP6Object($15);
 HEAP32[$14>>2] = 0;
 $16 = (($this) + 44|0);
 $17 = HEAP32[$16>>2]|0;
 __Z19DestroySingleObjectP6Object($17);
 HEAP32[$16>>2] = 0;
 $18 = (($this) + 48|0);
 $19 = HEAP32[$18>>2]|0;
 __Z19DestroySingleObjectP6Object($19);
 HEAP32[$18>>2] = 0;
 $20 = (($this) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 __Z19DestroySingleObjectP6Object($21);
 HEAP32[$20>>2] = 0;
 __ZN14SplatMaterials20UpdateSplatMaterialsEv($this);
 __ZN14SplatMaterials22UpdateBaseMapMaterialsEv($this);
 STACKTOP = sp;return;
}
function __ZN14SplatMaterialsD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP32[$this+16>>2]=0|0;
 $1 = HEAP32[$0>>2]|0;
 __Z19DestroySingleObjectP6Object($1);
 HEAP32[$0>>2] = 0;
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 __Z19DestroySingleObjectP6Object($3);
 HEAP32[$2>>2] = 0;
 $4 = (($this) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 __Z19DestroySingleObjectP6Object($5);
 HEAP32[$4>>2] = 0;
 $6 = (($this) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 __Z19DestroySingleObjectP6Object($7);
 HEAP32[$6>>2] = 0;
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 __Z19DestroySingleObjectP6Object($9);
 HEAP32[$8>>2] = 0;
 $10 = (($this) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 __Z19DestroySingleObjectP6Object($11);
 HEAP32[$10>>2] = 0;
 $12 = (($this) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 __Z19DestroySingleObjectP6Object($13);
 HEAP32[$12>>2] = 0;
 $14 = (($this) + 48|0);
 $15 = HEAP32[$14>>2]|0;
 __Z19DestroySingleObjectP6Object($15);
 HEAP32[$14>>2] = 0;
 $16 = (($this) + 52|0);
 $17 = HEAP32[$16>>2]|0;
 __Z19DestroySingleObjectP6Object($17);
 HEAP32[$16>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14SplatMaterials14SetTerrainDataERK4PPtrI11TerrainDataE($this,$terrainData) {
 $this = $this|0;
 $terrainData = $terrainData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$terrainData>>2]|0;
 $2 = ($0|0)==($1|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$this>>2] = $1;
 $3 = (($this) + 4|0);
 __ZN14SplatMaterials15UpdateMaterialsERK4PPtrIN5Unity8MaterialEE($this,$3);
 STACKTOP = sp;return;
}
function __ZN14SplatMaterials20UpdateSplatMaterialsEv($this) {
 $this = $this|0;
 var $$$$i$i$i$i$i = 0, $$$i$i$i$i$i = 0, $$0$i = 0, $$0$i$i = 0, $$0$i6 = 0, $$0$i6$i = 0, $$byval_copy31 = 0, $$pre = 0, $$pre$phi11Z2D = 0, $$pre10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0;
 var $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond$i = 0, $heightmapSize$i = 0, $i1$011$i = 0, $i1$08 = 0, $splatOffset$i = 0, $splatScale$i = 0, $temp$0$i = 0, $temp$0$i$i = 0, $temp$0$i5 = 0, $temp$0$i5$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy31 = sp + 148|0;
 $0 = sp + 144|0;
 $1 = sp + 132|0;
 $2 = sp + 120|0;
 $3 = sp + 116|0;
 $4 = sp + 112|0;
 $5 = sp + 108|0;
 $6 = sp + 104|0;
 $7 = sp + 100|0;
 $8 = sp + 96|0;
 $9 = sp + 92|0;
 $10 = sp + 88|0;
 $11 = sp + 84|0;
 $12 = sp + 80|0;
 $13 = sp + 76|0;
 $heightmapSize$i = sp + 64|0;
 $14 = sp + 20|0;
 $15 = sp;
 $16 = sp + 4|0;
 $17 = sp + 8|0;
 $18 = sp + 12|0;
 $19 = sp + 16|0;
 $splatScale$i = sp + 24|0;
 $splatOffset$i = sp + 32|0;
 $20 = sp + 40|0;
 $21 = sp + 44|0;
 $22 = sp + 48|0;
 $23 = sp + 52|0;
 $24 = sp + 56|0;
 $25 = sp + 60|0;
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0);
 if ($27) {
  $$0$i = 0;
 } else {
  HEAP32[$25>>2] = $26;
  $28 = HEAP32[560624>>2]|0;
  $29 = ($28|0)==(0|0);
  if ($29) {
   label = 10;
  } else {
   $30 = (($28) + 36|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($28) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($31|0)==($33|0);
   do {
    if ($34) {
     $35 = (($28) + 28|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($28) + 32|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($36) + ($38<<3)|0);
     $55 = $39;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy31,$28,$25);
     $40 = HEAP32[$$byval_copy31>>2]|0;
     $41 = ($40|0)==(-1);
     $42 = (($28) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     if ($41) {
      $44 = (($28) + 32|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = (($43) + ($45<<3)|0);
      $55 = $46;
      break;
     } else {
      $47 = (($43) + ($40<<3)|0);
      $55 = $47;
      break;
     }
    }
   } while(0);
   $48 = HEAP32[560624>>2]|0;
   $49 = (($48) + 28|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 32|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (($50) + ($52<<3)|0);
   $54 = ($55|0)==($53|0);
   if ($54) {
    label = 10;
   } else {
    $56 = (($55) + 4|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ($57|0)==(0|0);
    if ($58) {
     label = 10;
    } else {
     $temp$0$i = $57;
    }
   }
  }
  if ((label|0) == 10) {
   $59 = HEAP32[$this>>2]|0;
   $60 = (__Z31ReadObjectFromPersistentManageri($59)|0);
   $temp$0$i = $60;
  }
  $$0$i = $temp$0$i;
 }
 $61 = (($this) + 4|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  $$0$i6 = 0;
 } else {
  HEAP32[$24>>2] = $62;
  $64 = HEAP32[560624>>2]|0;
  $65 = ($64|0)==(0|0);
  if ($65) {
   label = 21;
  } else {
   $66 = (($64) + 36|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($64) + 4|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($67|0)==($69|0);
   do {
    if ($70) {
     $71 = (($64) + 28|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = (($64) + 32|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($72) + ($74<<3)|0);
     $91 = $75;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy31,$64,$24);
     $76 = HEAP32[$$byval_copy31>>2]|0;
     $77 = ($76|0)==(-1);
     $78 = (($64) + 28|0);
     $79 = HEAP32[$78>>2]|0;
     if ($77) {
      $80 = (($64) + 32|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = (($79) + ($81<<3)|0);
      $91 = $82;
      break;
     } else {
      $83 = (($79) + ($76<<3)|0);
      $91 = $83;
      break;
     }
    }
   } while(0);
   $84 = HEAP32[560624>>2]|0;
   $85 = (($84) + 28|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (($84) + 32|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = (($86) + ($88<<3)|0);
   $90 = ($91|0)==($89|0);
   if ($90) {
    label = 21;
   } else {
    $92 = (($91) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ($93|0)==(0|0);
    if ($94) {
     label = 21;
    } else {
     $temp$0$i5 = $93;
    }
   }
  }
  if ((label|0) == 21) {
   $95 = HEAP32[$61>>2]|0;
   $96 = (__Z31ReadObjectFromPersistentManageri($95)|0);
   $temp$0$i5 = $96;
  }
  $$0$i6 = $temp$0$i5;
 }
 $97 = ($$0$i|0)==(0|0);
 $$pre = (($$0$i) + 44|0);
 if ($97) {
  $$pre10 = (($$0$i) + 40|0);
  $$pre$phi11Z2D = $$pre10;$124 = 1;
 } else {
  $98 = HEAP32[$$pre>>2]|0;
  $99 = (($$0$i) + 40|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = $98;
  $102 = $100;
  $103 = (($101) - ($102))|0;
  $104 = $103 >> 2;
  $105 = ($104|0)<(1);
  $106 = $105 ? 1 : $104;
  $$pre$phi11Z2D = $99;$124 = $106;
 }
 $107 = ($$0$i6|0)==(0|0);
 $108 = (($$0$i) + 28|0);
 $109 = (($1) + 1|0);
 $110 = (($1) + 11|0);
 $111 = (($2) + 1|0);
 $112 = (($$byval_copy31) + 1|0);
 $113 = (($$0$i) + 232|0);
 $114 = (($$0$i) + 32|0);
 $115 = (($heightmapSize$i) + 8|0);
 $116 = (($splatScale$i) + 4|0);
 $117 = (($splatOffset$i) + 4|0);
 $118 = (($1) + 8|0);
 $119 = (($2) + 8|0);
 $120 = (($$byval_copy31) + 8|0);
 $121 = (($$byval_copy31) + 4|0);
 $122 = (($$0$i6) + 108|0);
 $i1$08 = 0;
 L37: while(1) {
  $123 = ($i1$08|0)<($124|0);
  $125 = ((($this) + ($i1$08<<2)|0) + 20|0);
  $126 = HEAP32[$125>>2]|0;
  do {
   if ($123) {
    $127 = ($126|0)==(0|0);
    if ($127) {
     $128 = ($i1$08|0)==(0);
     $129 = $128 ? 1 : 2;
     $130 = ((($this) + ($129<<2)|0) + 8|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($131,61,0)|0);
     $133 = (__ZNK5Unity8Material20GetActualRenderQueueEv($132)|0);
     $134 = (($133) + ($i1$08))|0;
     __ZN5Unity8Material20SetCustomRenderQueueEi($132,$134);
     HEAP32[$125>>2] = $132;
     $135 = $132;
    } else {
     $135 = $126;
    }
    if (!($107)) {
     __ZN5Unity8Material26CopyPropertiesFromMaterialERS0_($135,$$0$i6);
     __ZN5Unity8Material17SetShaderKeywordsERK8UnityStr($135,$122);
    }
    $136 = HEAP32[801088>>2]|0;
    if ($97) {
     HEAP32[$4>>2] = $136;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$4+0>>2]|0;
     $137 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($137) {
      $138 = HEAP32[801088>>2]|0;
      HEAP32[$5>>2] = $138;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$5+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $139 = HEAP32[800936>>2]|0;
     HEAP32[$6>>2] = $139;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$6+0>>2]|0;
     $140 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($140) {
      $141 = HEAP32[800936>>2]|0;
      HEAP32[$7>>2] = $141;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$7+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $142 = HEAP32[800960>>2]|0;
     HEAP32[$8>>2] = $142;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$8+0>>2]|0;
     $143 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($143) {
      $144 = HEAP32[800960>>2]|0;
      HEAP32[$9>>2] = $144;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$9+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $145 = HEAP32[801008>>2]|0;
     HEAP32[$10>>2] = $145;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$10+0>>2]|0;
     $146 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($146) {
      $147 = HEAP32[801008>>2]|0;
      HEAP32[$11>>2] = $147;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$11+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $148 = HEAP32[((800960 + 4|0))>>2]|0;
     HEAP32[$8>>2] = $148;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$8+0>>2]|0;
     $149 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($149) {
      $313 = HEAP32[((800960 + 4|0))>>2]|0;
      HEAP32[$9>>2] = $313;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$9+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $314 = HEAP32[((801008 + 4|0))>>2]|0;
     HEAP32[$10>>2] = $314;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$10+0>>2]|0;
     $315 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($315) {
      $316 = HEAP32[((801008 + 4|0))>>2]|0;
      HEAP32[$11>>2] = $316;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$11+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $317 = HEAP32[((800960 + 8|0))>>2]|0;
     HEAP32[$8>>2] = $317;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$8+0>>2]|0;
     $318 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($318) {
      $319 = HEAP32[((800960 + 8|0))>>2]|0;
      HEAP32[$9>>2] = $319;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$9+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $320 = HEAP32[((801008 + 8|0))>>2]|0;
     HEAP32[$10>>2] = $320;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$10+0>>2]|0;
     $321 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($321) {
      $322 = HEAP32[((801008 + 8|0))>>2]|0;
      HEAP32[$11>>2] = $322;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$11+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $323 = HEAP32[((800960 + 12|0))>>2]|0;
     HEAP32[$8>>2] = $323;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$8+0>>2]|0;
     $324 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($324) {
      $325 = HEAP32[((800960 + 12|0))>>2]|0;
      HEAP32[$9>>2] = $325;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$9+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     }
     $326 = HEAP32[((801008 + 12|0))>>2]|0;
     HEAP32[$10>>2] = $326;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$10+0>>2]|0;
     $327 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if (!($327)) {
      break;
     }
     $328 = HEAP32[((801008 + 12|0))>>2]|0;
     HEAP32[$11>>2] = $328;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$11+0>>2]|0;
     __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
     break;
    }
    HEAP32[$12>>2] = $136;
    ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$12+0>>2]|0;
    $150 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
    if ($150) {
     $151 = HEAP32[801088>>2]|0;
     HEAP32[$13>>2] = $151;
     $152 = (__ZNK13SplatDatabase10GetBasemapEv($108)|0);
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$13+0>>2]|0;
     __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,$152);
    }
    HEAP8[$1>>0] = 20;
    dest=$109+0|0; src=801384+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    HEAP8[$110>>0] = 0;
    HEAP8[$2>>0] = 0;
    HEAP8[$111>>0] = 0;
    __THREW__ = 0;
    invoke_viiiii(112,($$byval_copy31|0),($135|0),($1|0),0,($2|0));
    $153 = __THREW__; __THREW__ = 0;
    $154 = $153&1;
    if ($154) {
     break L37;
    }
    $155 = HEAP8[$$byval_copy31>>0]|0;
    $156 = $155 & 1;
    $157 = ($156<<24>>24)==(0);
    if ($157) {
     $160 = $155&255;
     $161 = $160 >>> 1;
     $163 = $161;$165 = $112;
    } else {
     $158 = HEAP32[$121>>2]|0;
     $159 = HEAP32[$120>>2]|0;
     $163 = $158;$165 = $159;
    }
    $162 = ($163>>>0)>(1);
    $164 = $162 ? 1 : $163;
    $166 = (_memcmp($165,801400,$164)|0);
    $167 = ($166|0)==(0);
    if ($167) {
     $168 = ($163|0)==(0);
     $$$i$i$i$i$i = $162&1;
     $$$$i$i$i$i$i = $168 ? -1 : $$$i$i$i$i$i;
     $170 = $$$$i$i$i$i$i;
    } else {
     $170 = $166;
    }
    $169 = ($170|0)==(0);
    if (!($157)) {
     $171 = HEAP32[$120>>2]|0;
     __ZdlPv($171);
    }
    $172 = HEAP8[$2>>0]|0;
    $173 = $172 & 1;
    $174 = ($173<<24>>24)==(0);
    if (!($174)) {
     $175 = HEAP32[$119>>2]|0;
     __ZdlPv($175);
    }
    $176 = HEAP8[$1>>0]|0;
    $177 = $176 & 1;
    $178 = ($177<<24>>24)==(0);
    if (!($178)) {
     $179 = HEAP32[$118>>2]|0;
     __ZdlPv($179);
    }
    if ($169) {
     __ZNK9Heightmap7GetSizeEv($heightmapSize$i,$113);
     $190 = HEAP32[$$pre>>2]|0;
     $191 = HEAP32[$$pre$phi11Z2D>>2]|0;
     $192 = HEAP32[$114>>2]|0;
     $193 = HEAP32[$108>>2]|0;
     $194 = $192;
     $195 = $193;
     $196 = (($194) - ($195))|0;
     $197 = (($196|0) / 24)&-1;
     $198 = HEAP32[800936>>2]|0;
     HEAP32[$14>>2] = $198;
     ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$14+0>>2]|0;
     $199 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
     if ($199) {
      $200 = $191;
      $201 = $190;
      $202 = (($201) - ($200))|0;
      $203 = $202 >> 2;
      $204 = HEAP32[800936>>2]|0;
      HEAP32[$15>>2] = $204;
      $205 = ($203|0)>($i1$08|0);
      if ($205) {
       $206 = (__ZNK13SplatDatabase15GetAlphaTextureEi($108,$i1$08)|0);
       $207 = $206;
      } else {
       $207 = 0;
      }
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$15+0>>2]|0;
      __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,$207);
     }
     $208 = $i1$08 << 2;
     $i1$011$i = 0;
     while(1) {
      $209 = (($i1$011$i) + ($208))|0;
      $210 = (800960 + ($i1$011$i<<2)|0);
      $211 = HEAP32[$210>>2]|0;
      HEAP32[$16>>2] = $211;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$16+0>>2]|0;
      $212 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
      $213 = (801008 + ($i1$011$i<<2)|0);
      $214 = HEAP32[$213>>2]|0;
      HEAP32[$17>>2] = $214;
      ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$17+0>>2]|0;
      $215 = (__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE($135,$$byval_copy31)|0);
      $216 = ($209|0)<($197|0);
      do {
       if ($216) {
        $219 = HEAP32[$108>>2]|0;
        if ($212) {
         $220 = Math_fround(HEAPF32[$heightmapSize$i>>2]);
         $221 = ((($219) + (($209*24)|0)|0) + 8|0);
         $222 = Math_fround(HEAPF32[$221>>2]);
         $223 = Math_fround($220 / $222);
         $224 = Math_fround(HEAPF32[$115>>2]);
         $225 = ((($219) + (($209*24)|0)|0) + 12|0);
         $226 = Math_fround(HEAPF32[$225>>2]);
         $227 = Math_fround($224 / $226);
         HEAPF32[$splatScale$i>>2] = $223;
         HEAPF32[$116>>2] = $227;
         $228 = ((($219) + (($209*24)|0)|0) + 16|0);
         $229 = Math_fround(HEAPF32[$228>>2]);
         $230 = Math_fround($229 / $220);
         $231 = Math_fround($223 * $230);
         $232 = ((($219) + (($209*24)|0)|0) + 20|0);
         $233 = Math_fround(HEAPF32[$232>>2]);
         $234 = Math_fround($233 / $224);
         $235 = Math_fround($227 * $234);
         HEAPF32[$splatOffset$i>>2] = $231;
         HEAPF32[$117>>2] = $235;
         $236 = HEAP32[$210>>2]|0;
         HEAP32[$20>>2] = $236;
         $237 = (($219) + (($209*24)|0)|0);
         $238 = HEAP32[$237>>2]|0;
         $239 = ($238|0)==(0);
         if ($239) {
          $$0$i6$i = 0;
         } else {
          HEAP32[$0>>2] = $238;
          $240 = HEAP32[560624>>2]|0;
          $241 = ($240|0)==(0|0);
          do {
           if ($241) {
            label = 83;
           } else {
            $242 = (($240) + 36|0);
            $243 = HEAP32[$242>>2]|0;
            $244 = (($240) + 4|0);
            $245 = HEAP32[$244>>2]|0;
            $246 = ($243|0)==($245|0);
            do {
             if ($246) {
              $247 = (($240) + 28|0);
              $248 = HEAP32[$247>>2]|0;
              $249 = (($240) + 32|0);
              $250 = HEAP32[$249>>2]|0;
              $251 = (($248) + ($250<<3)|0);
              $267 = $251;
             } else {
              __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy31,$240,$0);
              $252 = HEAP32[$$byval_copy31>>2]|0;
              $253 = ($252|0)==(-1);
              $254 = (($240) + 28|0);
              $255 = HEAP32[$254>>2]|0;
              if ($253) {
               $256 = (($240) + 32|0);
               $257 = HEAP32[$256>>2]|0;
               $258 = (($255) + ($257<<3)|0);
               $267 = $258;
               break;
              } else {
               $259 = (($255) + ($252<<3)|0);
               $267 = $259;
               break;
              }
             }
            } while(0);
            $260 = HEAP32[560624>>2]|0;
            $261 = (($260) + 28|0);
            $262 = HEAP32[$261>>2]|0;
            $263 = (($260) + 32|0);
            $264 = HEAP32[$263>>2]|0;
            $265 = (($262) + ($264<<3)|0);
            $266 = ($267|0)==($265|0);
            if ($266) {
             label = 83;
             break;
            }
            $268 = (($267) + 4|0);
            $269 = HEAP32[$268>>2]|0;
            $270 = ($269|0)==(0|0);
            if ($270) {
             label = 83;
            } else {
             $temp$0$i5$i = $269;
            }
           }
          } while(0);
          if ((label|0) == 83) {
           label = 0;
           $271 = HEAP32[$237>>2]|0;
           $272 = (__Z31ReadObjectFromPersistentManageri($271)|0);
           $temp$0$i5$i = $272;
          }
          $$0$i6$i = $temp$0$i5$i;
         }
         ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$20+0>>2]|0;
         __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,$$0$i6$i);
         $273 = HEAP32[$210>>2]|0;
         HEAP32[$21>>2] = $273;
         ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$21+0>>2]|0;
         __ZN5Unity8Material15SetTextureScaleEN9ShaderLab16FastPropertyNameERK8Vector2f($135,$$byval_copy31,$splatScale$i);
         $274 = HEAP32[$210>>2]|0;
         HEAP32[$22>>2] = $274;
         ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$22+0>>2]|0;
         __ZN5Unity8Material16SetTextureOffsetEN9ShaderLab16FastPropertyNameERK8Vector2f($135,$$byval_copy31,$splatOffset$i);
        }
        if (!($215)) {
         break;
        }
        $275 = HEAP32[$213>>2]|0;
        HEAP32[$23>>2] = $275;
        $276 = ((($219) + (($209*24)|0)|0) + 4|0);
        $277 = HEAP32[$276>>2]|0;
        $278 = ($277|0)==(0);
        if ($278) {
         $$0$i$i = 0;
        } else {
         HEAP32[$3>>2] = $277;
         $279 = HEAP32[560624>>2]|0;
         $280 = ($279|0)==(0|0);
         do {
          if ($280) {
           label = 96;
          } else {
           $281 = (($279) + 36|0);
           $282 = HEAP32[$281>>2]|0;
           $283 = (($279) + 4|0);
           $284 = HEAP32[$283>>2]|0;
           $285 = ($282|0)==($284|0);
           do {
            if ($285) {
             $286 = (($279) + 28|0);
             $287 = HEAP32[$286>>2]|0;
             $288 = (($279) + 32|0);
             $289 = HEAP32[$288>>2]|0;
             $290 = (($287) + ($289<<3)|0);
             $306 = $290;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy31,$279,$3);
             $291 = HEAP32[$$byval_copy31>>2]|0;
             $292 = ($291|0)==(-1);
             $293 = (($279) + 28|0);
             $294 = HEAP32[$293>>2]|0;
             if ($292) {
              $295 = (($279) + 32|0);
              $296 = HEAP32[$295>>2]|0;
              $297 = (($294) + ($296<<3)|0);
              $306 = $297;
              break;
             } else {
              $298 = (($294) + ($291<<3)|0);
              $306 = $298;
              break;
             }
            }
           } while(0);
           $299 = HEAP32[560624>>2]|0;
           $300 = (($299) + 28|0);
           $301 = HEAP32[$300>>2]|0;
           $302 = (($299) + 32|0);
           $303 = HEAP32[$302>>2]|0;
           $304 = (($301) + ($303<<3)|0);
           $305 = ($306|0)==($304|0);
           if ($305) {
            label = 96;
            break;
           }
           $307 = (($306) + 4|0);
           $308 = HEAP32[$307>>2]|0;
           $309 = ($308|0)==(0|0);
           if ($309) {
            label = 96;
           } else {
            $temp$0$i$i = $308;
           }
          }
         } while(0);
         if ((label|0) == 96) {
          label = 0;
          $310 = HEAP32[$276>>2]|0;
          $311 = (__Z31ReadObjectFromPersistentManageri($310)|0);
          $temp$0$i$i = $311;
         }
         $$0$i$i = $temp$0$i$i;
        }
        ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$23+0>>2]|0;
        __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,$$0$i$i);
       } else {
        if ($212) {
         $217 = HEAP32[$210>>2]|0;
         HEAP32[$18>>2] = $217;
         ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$18+0>>2]|0;
         __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
        }
        if (!($215)) {
         break;
        }
        $218 = HEAP32[$213>>2]|0;
        HEAP32[$19>>2] = $218;
        ;HEAP32[$$byval_copy31+0>>2]=HEAP32[$19+0>>2]|0;
        __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($135,$$byval_copy31,0);
       }
      } while(0);
      $312 = (($i1$011$i) + 1)|0;
      $exitcond$i = ($312|0)==(4);
      if ($exitcond$i) {
       break;
      } else {
       $i1$011$i = $312;
      }
     }
    }
   } else {
    __Z19DestroySingleObjectP6Object($126);
    HEAP32[$125>>2] = 0;
   }
  } while(0);
  $329 = (($i1$08) + 1)|0;
  $330 = ($329|0)<(8);
  if ($330) {
   $i1$08 = $329;
  } else {
   label = 112;
   break;
  }
 }
 if ((label|0) == 112) {
  STACKTOP = sp;return;
 }
 $180 = ___cxa_find_matching_catch()|0;
 $181 = tempRet0;
 $182 = HEAP8[$2>>0]|0;
 $183 = $182 & 1;
 $184 = ($183<<24>>24)==(0);
 if (!($184)) {
  $185 = HEAP32[$119>>2]|0;
  __ZdlPv($185);
 }
 $186 = HEAP8[$1>>0]|0;
 $187 = $186 & 1;
 $188 = ($187<<24>>24)==(0);
 if ($188) {
  ___resumeException($180|0);
  // unreachable;
 }
 $189 = HEAP32[$118>>2]|0;
 __ZdlPv($189);
 ___resumeException($180|0);
 // unreachable;
}
function __ZN14SplatMaterials22UpdateBaseMapMaterialsEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $or$cond = 0, $temp$0$i = 0, $temp$0$i59 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  HEAP32[$1>>2] = $3;
  $5 = HEAP32[560624>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   label = 10;
  } else {
   $7 = (($5) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   do {
    if ($11) {
     $12 = (($5) + 28|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($5) + 32|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($13) + ($15<<3)|0);
     $32 = $16;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$5,$1);
     $17 = HEAP32[$$byval_copy>>2]|0;
     $18 = ($17|0)==(-1);
     $19 = (($5) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     if ($18) {
      $21 = (($5) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $32 = $23;
      break;
     } else {
      $24 = (($20) + ($17<<3)|0);
      $32 = $24;
      break;
     }
    }
   } while(0);
   $25 = HEAP32[560624>>2]|0;
   $26 = (($25) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 32|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + ($29<<3)|0);
   $31 = ($32|0)==($30|0);
   if ($31) {
    label = 10;
   } else {
    $33 = (($32) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 10;
    } else {
     $temp$0$i = $34;
    }
   }
  }
  if ((label|0) == 10) {
   $36 = HEAP32[$this>>2]|0;
   $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
   $temp$0$i = $37;
  }
  $38 = (($this) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  $41 = ($temp$0$i|0)==(0|0);
  $or$cond = $40 | $41;
  if (!($or$cond)) {
   $44 = (($temp$0$i) + 28|0);
   $45 = (__ZNK13SplatDatabase10GetBasemapEv($44)|0);
   $46 = (($this) + 52|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    $49 = HEAP32[$38>>2]|0;
    $50 = (__ZN5Unity8Material14CreateMaterialER6Shaderib($49,61,0)|0);
    HEAP32[$46>>2] = $50;
   }
   $51 = (($this) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==(0);
   do {
    if (!($53)) {
     HEAP32[$0>>2] = $52;
     $54 = HEAP32[560624>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      label = 24;
     } else {
      $56 = (($54) + 36|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = (($54) + 4|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($57|0)==($59|0);
      do {
       if ($60) {
        $61 = (($54) + 28|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = (($54) + 32|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = (($62) + ($64<<3)|0);
        $81 = $65;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$54,$0);
        $66 = HEAP32[$$byval_copy>>2]|0;
        $67 = ($66|0)==(-1);
        $68 = (($54) + 28|0);
        $69 = HEAP32[$68>>2]|0;
        if ($67) {
         $70 = (($54) + 32|0);
         $71 = HEAP32[$70>>2]|0;
         $72 = (($69) + ($71<<3)|0);
         $81 = $72;
         break;
        } else {
         $73 = (($69) + ($66<<3)|0);
         $81 = $73;
         break;
        }
       }
      } while(0);
      $74 = HEAP32[560624>>2]|0;
      $75 = (($74) + 28|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = (($74) + 32|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($76) + ($78<<3)|0);
      $80 = ($81|0)==($79|0);
      if ($80) {
       label = 24;
      } else {
       $82 = (($81) + 4|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = ($83|0)==(0|0);
       if ($84) {
        label = 24;
       } else {
        $temp$0$i59 = $83;
       }
      }
     }
     if ((label|0) == 24) {
      $85 = HEAP32[$51>>2]|0;
      $86 = (__Z31ReadObjectFromPersistentManageri($85)|0);
      $87 = ($86|0)==(0|0);
      if ($87) {
       break;
      } else {
       $temp$0$i59 = $86;
      }
     }
     $88 = HEAP32[$46>>2]|0;
     __ZN5Unity8Material26CopyPropertiesFromMaterialERS0_($88,$temp$0$i59);
     $89 = HEAP32[$46>>2]|0;
     $90 = (($89) + 72|0);
     (__ZNSt3__13mapIN9ShaderLab16FastPropertyNameEN18UnityPropertySheet11UnityTexEnvENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_($90,801088)|0);
     $91 = HEAP32[$46>>2]|0;
     $92 = (($temp$0$i59) + 108|0);
     __ZN5Unity8Material17SetShaderKeywordsERK8UnityStr($91,$92);
    }
   } while(0);
   $93 = HEAP32[$46>>2]|0;
   $94 = HEAP32[801088>>2]|0;
   HEAP32[$2>>2] = $94;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   __ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture($93,$$byval_copy,$45);
   STACKTOP = sp;return;
  }
 }
 $42 = (($this) + 52|0);
 $43 = HEAP32[$42>>2]|0;
 __Z19DestroySingleObjectP6Object($43);
 HEAP32[$42>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK14SplatMaterials12GetMaterialsER13dynamic_arrayIPN5Unity8MaterialELj4EE($this,$materials) {
 $this = $this|0;
 $materials = $materials|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($materials) + 8|0);
 $2 = (($materials) + 12|0);
 $3 = (($materials) + 4|0);
 $i$01 = 0;
 while(1) {
  $4 = ((($this) + ($i$01<<2)|0) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   label = 10;
   break;
  }
  $7 = HEAP32[$1>>2]|0;
  $8 = (($7) + 1)|0;
  HEAP32[$1>>2] = $8;
  $9 = HEAP32[$2>>2]|0;
  $10 = $9 & 2147483647;
  $11 = ($8>>>0)>($10>>>0);
  if ($11) {
   $12 = $9 << 1;
   $13 = ($12|0)==(0);
   $14 = $13 ? 1 : $12;
   $15 = ($10>>>0)<($14>>>0);
   do {
    if ($15) {
     $16 = ($9|0)>(-1);
     if ($16) {
      HEAP32[$2>>2] = $14;
      $17 = HEAP32[$materials>>2]|0;
      $18 = $14 << 2;
      $19 = HEAP32[$3>>2]|0;
      HEAP32[$0>>2] = $19;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $20 = (__Z16realloc_internalPvji10MemLabelIdiPKci($17,$18,4,$$byval_copy1,0,801376,370)|0);
      HEAP32[$materials>>2] = $20;
      break;
     } else {
      $21 = $14 << 2;
      $22 = HEAP32[$3>>2]|0;
      HEAP32[$0>>2] = $22;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($21,4,$$byval_copy1,0,801376,352)|0);
      $24 = HEAP32[$materials>>2]|0;
      $25 = HEAP32[$1>>2]|0;
      $26 = $25 << 2;
      _memcpy(($23|0),($24|0),($26|0))|0;
      HEAP32[$2>>2] = $14;
      HEAP32[$materials>>2] = $23;
      break;
     }
    }
   } while(0);
   $$pre$i$i = HEAP32[$1>>2]|0;
   $28 = $$pre$i$i;
  } else {
   $28 = $8;
  }
  $27 = (($28) + -1)|0;
  $29 = HEAP32[$materials>>2]|0;
  $30 = (($29) + ($27<<2)|0);
  HEAP32[$30>>2] = $5;
  $31 = (($i$01) + 1)|0;
  $32 = ($31|0)<(8);
  if ($32) {
   $i$01 = $31;
  } else {
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return;
 }
}
function __ZNK14SplatMaterials20GetSplatBaseMaterialEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN14SplatMaterials22LoadSplatShadersStaticEPN5Unity8MaterialEPP6Shader($templateMat,$outShaders) {
 $templateMat = $templateMat|0;
 $outShaders = $outShaders|0;
 var $$02 = 0, $$03 = 0, $$ph31$ph = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$036 = 0, $shaderNotFound$0$off035 = 0, $shaderNotFound$1$off0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 60|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 $6 = ($templateMat|0)==(0|0);
 do {
  if ($6) {
   $7 = (($outShaders) + 4|0);
   HEAP32[$7>>2] = 0;
   $$ph31$ph = $7;
   label = 8;
  } else {
   $8 = (__ZN5Unity8Material9GetShaderEv($templateMat)|0);
   $9 = (($outShaders) + 4|0);
   HEAP32[$9>>2] = $8;
   $10 = ($8|0)==(0|0);
   if ($10) {
    $$ph31$ph = $9;
    label = 8;
   } else {
    $11 = (__Znwj(16)|0);
    $12 = (($0) + 8|0);
    HEAP32[$12>>2] = $11;
    HEAP32[$0>>2] = 17;
    $13 = (($0) + 4|0);
    HEAP32[$13>>2] = 13;
    dest=$11+0|0; src=801112+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $14 = (($11) + 13|0);
    HEAP8[$14>>0] = 0;
    __THREW__ = 0;
    $15 = (invoke_iii(2598,($8|0),($0|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     $47 = ___cxa_find_matching_catch()|0;
     $48 = tempRet0;
     $49 = HEAP8[$0>>0]|0;
     $50 = $49 & 1;
     $51 = ($50<<24>>24)==(0);
     if ($51) {
      $$02 = $48;$$03 = $47;
      ___resumeException($$03|0);
      // unreachable;
     }
     $52 = HEAP32[$12>>2]|0;
     __ZdlPv($52);
     $$02 = $48;$$03 = $47;
     ___resumeException($$03|0);
     // unreachable;
    }
    $18 = (($outShaders) + 8|0);
    HEAP32[$18>>2] = $15;
    $19 = HEAP8[$0>>0]|0;
    $20 = $19 & 1;
    $21 = ($20<<24>>24)==(0);
    if (!($21)) {
     $22 = HEAP32[$12>>2]|0;
     __ZdlPv($22);
    }
    $23 = (__Znwj(16)|0);
    $24 = (($1) + 8|0);
    HEAP32[$24>>2] = $23;
    HEAP32[$1>>2] = 17;
    $25 = (($1) + 4|0);
    HEAP32[$25>>2] = 13;
    dest=$23+0|0; src=801128+0|0; stop=dest+13|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $26 = (($23) + 13|0);
    HEAP8[$26>>0] = 0;
    __THREW__ = 0;
    $27 = (invoke_iii(2598,($8|0),($1|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     HEAP32[$outShaders>>2] = $27;
     $31 = HEAP8[$1>>0]|0;
     $32 = $31 & 1;
     $33 = ($32<<24>>24)==(0);
     if ($33) {
      $66 = $9;$86 = $18;
      break;
     }
     $34 = HEAP32[$24>>2]|0;
     __ZdlPv($34);
     $66 = $9;$86 = $18;
     break;
    }
    $53 = ___cxa_find_matching_catch()|0;
    $54 = tempRet0;
    $55 = HEAP8[$1>>0]|0;
    $56 = $55 & 1;
    $57 = ($56<<24>>24)==(0);
    if ($57) {
     $$02 = $54;$$03 = $53;
     ___resumeException($$03|0);
     // unreachable;
    }
    $58 = HEAP32[$24>>2]|0;
    __ZdlPv($58);
    $$02 = $54;$$03 = $53;
    ___resumeException($$03|0);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $30 = (($outShaders) + 8|0);
  HEAP32[$30>>2] = 0;
  HEAP32[$outShaders>>2] = 0;
  $66 = $$ph31$ph;$86 = $30;
 }
 $35 = (__Z15GetScriptMapperv()|0);
 $36 = HEAP32[$outShaders>>2]|0;
 $37 = ($36|0)==(0|0);
 do {
  if ($37) {
   HEAP8[$2>>0] = 14;
   $38 = (($2) + 1|0);
   ;HEAP8[$38+0>>0]=HEAP8[801144+0>>0]|0;HEAP8[$38+1>>0]=HEAP8[801144+1>>0]|0;HEAP8[$38+2>>0]=HEAP8[801144+2>>0]|0;HEAP8[$38+3>>0]=HEAP8[801144+3>>0]|0;HEAP8[$38+4>>0]=HEAP8[801144+4>>0]|0;HEAP8[$38+5>>0]=HEAP8[801144+5>>0]|0;HEAP8[$38+6>>0]=HEAP8[801144+6>>0]|0;
   $39 = (($2) + 8|0);
   HEAP8[$39>>0] = 0;
   __THREW__ = 0;
   $40 = (invoke_iii(2366,($35|0),($2|0))|0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if (!($42)) {
    HEAP32[$outShaders>>2] = $40;
    $43 = HEAP8[$2>>0]|0;
    $44 = $43 & 1;
    $45 = ($44<<24>>24)==(0);
    if ($45) {
     break;
    }
    $46 = HEAP32[$39>>2]|0;
    __ZdlPv($46);
    break;
   }
   $59 = ___cxa_find_matching_catch()|0;
   $60 = tempRet0;
   $61 = HEAP8[$2>>0]|0;
   $62 = $61 & 1;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    $$02 = $60;$$03 = $59;
    ___resumeException($$03|0);
    // unreachable;
   }
   $64 = HEAP32[$39>>2]|0;
   __ZdlPv($64);
   $$02 = $60;$$03 = $59;
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $65 = HEAP32[$66>>2]|0;
 $67 = ($65|0)==(0|0);
 do {
  if ($67) {
   $68 = (__Znwj(64)|0);
   $69 = (($3) + 8|0);
   HEAP32[$69>>2] = $68;
   HEAP32[$3>>2] = 65;
   $70 = (($3) + 4|0);
   HEAP32[$70>>2] = 48;
   dest=$68+0|0; src=801152+0|0; stop=dest+48|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $71 = (($68) + 48|0);
   HEAP8[$71>>0] = 0;
   __THREW__ = 0;
   $72 = (invoke_iii(2366,($35|0),($3|0))|0);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if (!($74)) {
    HEAP32[$66>>2] = $72;
    $75 = HEAP8[$3>>0]|0;
    $76 = $75 & 1;
    $77 = ($76<<24>>24)==(0);
    if ($77) {
     break;
    }
    $78 = HEAP32[$69>>2]|0;
    __ZdlPv($78);
    break;
   }
   $79 = ___cxa_find_matching_catch()|0;
   $80 = tempRet0;
   $81 = HEAP8[$3>>0]|0;
   $82 = $81 & 1;
   $83 = ($82<<24>>24)==(0);
   if ($83) {
    $$02 = $80;$$03 = $79;
    ___resumeException($$03|0);
    // unreachable;
   }
   $84 = HEAP32[$69>>2]|0;
   __ZdlPv($84);
   $$02 = $80;$$03 = $79;
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $85 = HEAP32[$86>>2]|0;
 $87 = ($85|0)==(0|0);
 do {
  if ($87) {
   $88 = (__Znwj(48)|0);
   $89 = (($4) + 8|0);
   HEAP32[$89>>2] = $88;
   HEAP32[$4>>2] = 49;
   $90 = (($4) + 4|0);
   HEAP32[$90>>2] = 46;
   dest=$88+0|0; src=801208+0|0; stop=dest+46|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $91 = (($88) + 46|0);
   HEAP8[$91>>0] = 0;
   __THREW__ = 0;
   $92 = (invoke_iii(2366,($35|0),($4|0))|0);
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if (!($94)) {
    HEAP32[$86>>2] = $92;
    $95 = HEAP8[$4>>0]|0;
    $96 = $95 & 1;
    $97 = ($96<<24>>24)==(0);
    if ($97) {
     break;
    }
    $98 = HEAP32[$89>>2]|0;
    __ZdlPv($98);
    break;
   }
   $101 = ___cxa_find_matching_catch()|0;
   $102 = tempRet0;
   $103 = HEAP8[$4>>0]|0;
   $104 = $103 & 1;
   $105 = ($104<<24>>24)==(0);
   if ($105) {
    $$02 = $102;$$03 = $101;
    ___resumeException($$03|0);
    // unreachable;
   }
   $106 = HEAP32[$89>>2]|0;
   __ZdlPv($106);
   $$02 = $102;$$03 = $101;
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $99 = (($5) + 1|0);
 $100 = (($5) + 8|0);
 $i$036 = 0;$shaderNotFound$0$off035 = 0;
 while(1) {
  $107 = (($outShaders) + ($i$036<<2)|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = ($108|0)==(0|0);
  if ($109) {
   HEAP8[$5>>0] = 14;
   ;HEAP8[$99+0>>0]=HEAP8[801144+0>>0]|0;HEAP8[$99+1>>0]=HEAP8[801144+1>>0]|0;HEAP8[$99+2>>0]=HEAP8[801144+2>>0]|0;HEAP8[$99+3>>0]=HEAP8[801144+3>>0]|0;HEAP8[$99+4>>0]=HEAP8[801144+4>>0]|0;HEAP8[$99+5>>0]=HEAP8[801144+5>>0]|0;HEAP8[$99+6>>0]=HEAP8[801144+6>>0]|0;
   HEAP8[$100>>0] = 0;
   __THREW__ = 0;
   $110 = (invoke_iii(2366,($35|0),($5|0))|0);
   $111 = __THREW__; __THREW__ = 0;
   $112 = $111&1;
   if ($112) {
    label = 38;
    break;
   }
   HEAP32[$107>>2] = $110;
   $113 = HEAP8[$5>>0]|0;
   $114 = $113 & 1;
   $115 = ($114<<24>>24)==(0);
   if ($115) {
    $shaderNotFound$1$off0 = 1;
   } else {
    $116 = HEAP32[$100>>2]|0;
    __ZdlPv($116);
    $shaderNotFound$1$off0 = 1;
   }
  } else {
   $shaderNotFound$1$off0 = $shaderNotFound$0$off035;
  }
  $123 = (($i$036) + 1)|0;
  $124 = ($123|0)<(3);
  if ($124) {
   $i$036 = $123;$shaderNotFound$0$off035 = $shaderNotFound$1$off0;
  } else {
   label = 41;
   break;
  }
 }
 if ((label|0) == 38) {
  $117 = ___cxa_find_matching_catch()|0;
  $118 = tempRet0;
  $119 = HEAP8[$5>>0]|0;
  $120 = $119 & 1;
  $121 = ($120<<24>>24)==(0);
  if ($121) {
   $$02 = $118;$$03 = $117;
   ___resumeException($$03|0);
   // unreachable;
  }
  $122 = HEAP32[$100>>2]|0;
  __ZdlPv($122);
  $$02 = $118;$$03 = $117;
  ___resumeException($$03|0);
  // unreachable;
 }
 else if ((label|0) == 41) {
  if (!($shaderNotFound$1$off0)) {
   STACKTOP = sp;return;
  }
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(801256,0,801376,229,1,0,0,0);
  STACKTOP = sp;return;
 }
}
function __GLOBAL__I_a19829() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,800944);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[800936>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,800976);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[800960>>2] = $2;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,800984);
 $3 = HEAP32[$0>>2]|0;
 HEAP32[((800960 + 4|0))>>2] = $3;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,800992);
 $4 = HEAP32[$0>>2]|0;
 HEAP32[((800960 + 8|0))>>2] = $4;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,801000);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[((800960 + 12|0))>>2] = $5;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,801024);
 $6 = HEAP32[$0>>2]|0;
 HEAP32[801008>>2] = $6;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,801040);
 $7 = HEAP32[$0>>2]|0;
 HEAP32[((801008 + 4|0))>>2] = $7;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,801056);
 $8 = HEAP32[$0>>2]|0;
 HEAP32[((801008 + 8|0))>>2] = $8;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,801072);
 $9 = HEAP32[$0>>2]|0;
 HEAP32[((801008 + 12|0))>>2] = $9;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,801096);
 $10 = HEAP32[$0>>2]|0;
 HEAP32[801088>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN7Terrain5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAPF32[$0>>2] = Math_fround(5.0);
 $1 = (($this) + 52|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 56|0);
 HEAPF32[$2>>2] = Math_fround(1000.0);
 $3 = (($this) + 60|0);
 HEAPF32[$3>>2] = Math_fround(5000.0);
 $4 = (($this) + 64|0);
 HEAPF32[$4>>2] = Math_fround(50.0);
 $5 = (($this) + 68|0);
 HEAPF32[$5>>2] = Math_fround(5.0);
 $6 = (($this) + 72|0);
 HEAP32[$6>>2] = 50;
 $7 = (($this) + 76|0);
 HEAPF32[$7>>2] = Math_fround(80.0);
 $8 = (($this) + 80|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 84|0);
 HEAP8[$9>>0] = 1;
 $10 = (($this) + 85|0);
 HEAP8[$10>>0] = 1;
 $11 = (($this) + 86|0);
 HEAP8[$11>>0] = 1;
 $12 = (($this) + 172|0);
 $13 = (($this) + 188|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
 HEAP32[$13>>2] = 7;
 $14 = (($this) + 128|0);
 $15 = (($14) + 2|0);
 HEAP16[$15>>1] = 255;
 HEAP16[$14>>1] = 255;
 $16 = (($this) + 96|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($this) + 100|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($this) + 104|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 108|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($this) + 112|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($this) + 116|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 120|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 124|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($this) + 132|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($this) + 136|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($this) + 140|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 144|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 148|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($this) + 152|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = (($this) + 156|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($this) + 160|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($this) + 164|0);
 HEAP8[$32>>0] = 1;
 $33 = (($this) + 168|0);
 $34 = HEAP32[$33>>2]|0;
 __Z19DestroySingleObjectP6Object($34);
 HEAP32[$33>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7Terrain10SmartResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 HEAPF32[$0>>2] = Math_fround(5.0);
 $1 = (($this) + 52|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 56|0);
 HEAPF32[$2>>2] = Math_fround(1000.0);
 $3 = (($this) + 60|0);
 HEAPF32[$3>>2] = Math_fround(5000.0);
 $4 = (($this) + 64|0);
 HEAPF32[$4>>2] = Math_fround(50.0);
 $5 = (($this) + 68|0);
 HEAPF32[$5>>2] = Math_fround(5.0);
 $6 = (($this) + 72|0);
 HEAP32[$6>>2] = 50;
 $7 = (($this) + 76|0);
 HEAPF32[$7>>2] = Math_fround(80.0);
 $8 = (($this) + 80|0);
 HEAPF32[$8>>2] = Math_fround(1.0);
 $9 = (($this) + 84|0);
 HEAP8[$9>>0] = 1;
 $10 = (($this) + 85|0);
 HEAP8[$10>>0] = 1;
 $11 = (($this) + 86|0);
 HEAP8[$11>>0] = 1;
 $12 = (($this) + 172|0);
 $13 = (($this) + 188|0);
 ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
 HEAP32[$13>>2] = 7;
 $14 = (($this) + 128|0);
 $15 = (($14) + 2|0);
 HEAP16[$15>>1] = 255;
 HEAP16[$14>>1] = 255;
 $16 = (($this) + 96|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($this) + 100|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($this) + 104|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($this) + 108|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($this) + 112|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($this) + 116|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 120|0);
 HEAPF32[$22>>2] = Math_fround(0.0);
 $23 = (($this) + 124|0);
 HEAPF32[$23>>2] = Math_fround(0.0);
 $24 = (($this) + 132|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($this) + 136|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($this) + 140|0);
 HEAPF32[$26>>2] = Math_fround(0.0);
 $27 = (($this) + 144|0);
 HEAPF32[$27>>2] = Math_fround(0.0);
 $28 = (($this) + 148|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($this) + 152|0);
 HEAPF32[$29>>2] = Math_fround(1.0);
 $30 = (($this) + 156|0);
 HEAPF32[$30>>2] = Math_fround(0.0);
 $31 = (($this) + 160|0);
 HEAPF32[$31>>2] = Math_fround(0.0);
 $32 = (($this) + 164|0);
 HEAP8[$32>>0] = 1;
 $33 = (($this) + 168|0);
 $34 = HEAP32[$33>>2]|0;
 __Z19DestroySingleObjectP6Object($34);
 HEAP32[$33>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7Terrain15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN7Terrain12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN7Terrain12AddToManagerEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $phitmp$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (__Z18GetITerrainManagerv()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($3,$this);
 $7 = (($this) + 30|0);
 HEAP8[$7>>0] = 1;
 $8 = HEAP32[628440>>2]|0;
 HEAP32[$2>>2] = $8;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
 $9 = (__Znwj10MemLabelIdbiPKci(56,$$byval_copy1,0,16,801552,112)|0);
 $10 = (($this) + 44|0);
 $11 = (($this) + 88|0);
 __THREW__ = 0;
 invoke_viii(2032,($9|0),($10|0),($11|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $86 = ___cxa_find_matching_catch()|0;
  $87 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_viiiiii(97,($9|0),($$byval_copy1|0),0,16,(801552|0),112);
  $88 = __THREW__; __THREW__ = 0;
  $89 = $88&1;
  if ($89) {
   $90 = ___cxa_find_matching_catch(0|0)|0;
   $91 = tempRet0;
   ___clang_call_terminate($90);
   // unreachable;
  } else {
   ___resumeException($86|0);
   // unreachable;
  }
 }
 $14 = (($this) + 92|0);
 HEAP32[$14>>2] = $9;
 $15 = HEAP32[$10>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = $15;
 $17 = HEAP32[560624>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  label = 11;
 } else {
  $19 = (($17) + 36|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($17) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($20|0)==($22|0);
  do {
   if ($23) {
    $24 = (($17) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($17) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + ($27<<3)|0);
    $44 = $28;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$17,$1);
    $29 = HEAP32[$$byval_copy1>>2]|0;
    $30 = ($29|0)==(-1);
    $31 = (($17) + 28|0);
    $32 = HEAP32[$31>>2]|0;
    if ($30) {
     $33 = (($17) + 32|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + ($34<<3)|0);
     $44 = $35;
     break;
    } else {
     $36 = (($32) + ($29<<3)|0);
     $44 = $36;
     break;
    }
   }
  } while(0);
  $37 = HEAP32[560624>>2]|0;
  $38 = (($37) + 28|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + 32|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<3)|0);
  $43 = ($44|0)==($42|0);
  if ($43) {
   label = 11;
  } else {
   $45 = (($44) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    label = 11;
   } else {
    $52 = $37;
   }
  }
 }
 do {
  if ((label|0) == 11) {
   $48 = HEAP32[$10>>2]|0;
   $49 = (__Z31ReadObjectFromPersistentManageri($48)|0);
   $phitmp$i = ($49|0)==(0|0);
   if ($phitmp$i) {
    STACKTOP = sp;return;
   } else {
    $$pre = HEAP32[560624>>2]|0;
    $52 = $$pre;
    break;
   }
  }
 } while(0);
 $50 = HEAP32[$10>>2]|0;
 HEAP32[$0>>2] = $50;
 $51 = ($52|0)==(0|0);
 if ($51) {
  label = 21;
 } else {
  $53 = (($52) + 36|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 4|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($54|0)==($56|0);
  do {
   if ($57) {
    $58 = (($52) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = (($52) + 32|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($59) + ($61<<3)|0);
    $78 = $62;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$52,$0);
    $63 = HEAP32[$$byval_copy1>>2]|0;
    $64 = ($63|0)==(-1);
    $65 = (($52) + 28|0);
    $66 = HEAP32[$65>>2]|0;
    if ($64) {
     $67 = (($52) + 32|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($66) + ($68<<3)|0);
     $78 = $69;
     break;
    } else {
     $70 = (($66) + ($63<<3)|0);
     $78 = $70;
     break;
    }
   }
  } while(0);
  $71 = HEAP32[560624>>2]|0;
  $72 = (($71) + 28|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($71) + 32|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($73) + ($75<<3)|0);
  $77 = ($78|0)==($76|0);
  if ($77) {
   label = 21;
  } else {
   $79 = (($78) + 4|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0|0);
   if ($81) {
    label = 21;
   } else {
    $temp$0$i = $80;
   }
  }
 }
 if ((label|0) == 21) {
  $82 = HEAP32[$10>>2]|0;
  $83 = (__Z31ReadObjectFromPersistentManageri($82)|0);
  $temp$0$i = $83;
 }
 $84 = (($this) + 24|0);
 $85 = HEAP32[$84>>2]|0;
 __ZN11TerrainData7AddUserEPN5Unity10GameObjectE($temp$0$i,$85);
 STACKTOP = sp;return;
}
function __ZN7Terrain17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $phitmp$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (__Z18GetITerrainManagerv()|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095]($3,$this);
 $7 = (($this) + 30|0);
 HEAP8[$7>>0] = 0;
 $8 = (($this) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 do {
  if (!($10)) {
   HEAP32[$2>>2] = $9;
   $11 = HEAP32[560624>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    label = 10;
   } else {
    $13 = (($11) + 36|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($11) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($14|0)==($16|0);
    do {
     if ($17) {
      $18 = (($11) + 28|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = (($11) + 32|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($19) + ($21<<3)|0);
      $38 = $22;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$11,$2);
      $23 = HEAP32[$$byval_copy>>2]|0;
      $24 = ($23|0)==(-1);
      $25 = (($11) + 28|0);
      $26 = HEAP32[$25>>2]|0;
      if ($24) {
       $27 = (($11) + 32|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = (($26) + ($28<<3)|0);
       $38 = $29;
       break;
      } else {
       $30 = (($26) + ($23<<3)|0);
       $38 = $30;
       break;
      }
     }
    } while(0);
    $31 = HEAP32[560624>>2]|0;
    $32 = (($31) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($31) + 32|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($33) + ($35<<3)|0);
    $37 = ($38|0)==($36|0);
    if ($37) {
     label = 10;
    } else {
     $39 = (($38) + 4|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      label = 10;
     } else {
      $46 = $31;
     }
    }
   }
   if ((label|0) == 10) {
    $42 = HEAP32[$8>>2]|0;
    $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
    $phitmp$i = ($43|0)==(0|0);
    if ($phitmp$i) {
     break;
    }
    $$pre = HEAP32[560624>>2]|0;
    $46 = $$pre;
   }
   $44 = HEAP32[$8>>2]|0;
   HEAP32[$1>>2] = $44;
   $45 = ($46|0)==(0|0);
   if ($45) {
    label = 20;
   } else {
    $47 = (($46) + 36|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($48|0)==($50|0);
    do {
     if ($51) {
      $52 = (($46) + 28|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = (($46) + 32|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = (($53) + ($55<<3)|0);
      $72 = $56;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$46,$1);
      $57 = HEAP32[$$byval_copy>>2]|0;
      $58 = ($57|0)==(-1);
      $59 = (($46) + 28|0);
      $60 = HEAP32[$59>>2]|0;
      if ($58) {
       $61 = (($46) + 32|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($60) + ($62<<3)|0);
       $72 = $63;
       break;
      } else {
       $64 = (($60) + ($57<<3)|0);
       $72 = $64;
       break;
      }
     }
    } while(0);
    $65 = HEAP32[560624>>2]|0;
    $66 = (($65) + 28|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (($65) + 32|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($67) + ($69<<3)|0);
    $71 = ($72|0)==($70|0);
    if ($71) {
     label = 20;
    } else {
     $73 = (($72) + 4|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = ($74|0)==(0|0);
     if ($75) {
      label = 20;
     } else {
      $temp$0$i = $74;
     }
    }
   }
   if ((label|0) == 20) {
    $76 = HEAP32[$8>>2]|0;
    $77 = (__Z31ReadObjectFromPersistentManageri($76)|0);
    $temp$0$i = $77;
   }
   $78 = (($this) + 24|0);
   $79 = HEAP32[$78>>2]|0;
   __ZN11TerrainData10RemoveUserEPN5Unity10GameObjectE($temp$0$i,$79);
  }
 } while(0);
 $80 = (($this) + 92|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = HEAP32[628440>>2]|0;
 $83 = ($81|0)==(0|0);
 if ($83) {
  HEAP32[$0>>2] = $82;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($81,$$byval_copy);
  HEAP32[$80>>2] = 0;
  __ZN7Terrain5FlushEv($this);
  STACKTOP = sp;return;
 }
 __ZN14SplatMaterialsD2Ev($81);
 HEAP32[$0>>2] = $82;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($81,$$byval_copy);
 HEAP32[$80>>2] = 0;
 __ZN7Terrain5FlushEv($this);
 STACKTOP = sp;return;
}
function __ZN7Terrain5FlushEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 196|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 204|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $$lcssa = $2;
 } else {
  $i$012 = $2;
  while(1) {
   $6 = (($i$012) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[628440>>2]|0;
   $9 = ($7|0)==(0|0);
   if (!($9)) {
    __ZN12TreeRendererD2Ev($7);
   }
   HEAP32[$0>>2] = $8;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy3);
   HEAP32[$6>>2] = 0;
   $10 = (($i$012) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[628440>>2]|0;
   $13 = ($11|0)==(0|0);
   if (!($13)) {
    __ZN15TerrainRendererD2Ev($11);
   }
   HEAP32[$0>>2] = $12;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($11,$$byval_copy3);
   HEAP32[$10>>2] = 0;
   $14 = (($i$012) + 12|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[628440>>2]|0;
   $17 = ($15|0)==(0|0);
   if (!($17)) {
    __ZN14DetailRendererD2Ev($15);
   }
   HEAP32[$0>>2] = $16;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($15,$$byval_copy3);
   HEAP32[$14>>2] = 0;
   $18 = (($i$012) + 20|0);
   $19 = HEAP32[$1>>2]|0;
   $20 = HEAP32[$3>>2]|0;
   $21 = (($19) + (($20*20)|0)|0);
   $22 = ($18|0)==($21|0);
   if ($22) {
    $$lcssa = $19;
    break;
   } else {
    $i$012 = $18;
   }
  }
 }
 $23 = (($this) + 208|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  HEAP32[$3>>2] = 0;
  HEAP32[$23>>2] = 0;
  STACKTOP = sp;return;
 }
 $26 = (($this) + 200|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$0>>2] = $27;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($$lcssa,$$byval_copy3);
 HEAP32[$1>>2] = 0;
 HEAP32[$3>>2] = 0;
 HEAP32[$23>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7Terrain17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 __Z19DestroySingleObjectP6Object($1);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK7Terrain11GetPositionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($1)|0);
 __ZNK9Transform11GetPositionEv($agg$result,$2);
 STACKTOP = sp;return;
}
function __ZNK7Terrain12GetWorldAABBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 9;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 9;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 9;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 9) {
  $35 = HEAP32[$2>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $37 = (($temp$0$i) + 232|0);
 __ZNK9Heightmap9GetBoundsEv($agg$result,$37);
 $38 = (($this) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($39)|0);
 __ZNK9Transform11GetPositionEv($1,$40);
 $41 = Math_fround(HEAPF32[$1>>2]);
 $42 = Math_fround(HEAPF32[$agg$result>>2]);
 $43 = Math_fround($41 + $42);
 HEAPF32[$agg$result>>2] = $43;
 $44 = (($1) + 4|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($agg$result) + 4|0);
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = Math_fround($45 + $47);
 HEAPF32[$46>>2] = $48;
 $49 = (($1) + 8|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($agg$result) + 8|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($50 + $52);
 HEAPF32[$51>>2] = $53;
 STACKTOP = sp;return;
}
function __ZN7Terrain14SetTerrainDataERK4PPtrI11TerrainDataE($this,$terrainData) {
 $this = $this|0;
 $terrainData = $terrainData|0;
 var $$pre = 0, $$pre19 = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp$i = 0, $phitmp$i12 = 0, $pos$i$i$i$i$i7 = 0, $temp$0$i = 0;
 var $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i$i7 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$terrainData>>2]|0;
 $7 = ($5|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 30|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $152 = $6;
 } else {
  $11 = (($this) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($5|0)==(0);
  do {
   if (!($13)) {
    HEAP32[$2>>2] = $5;
    $14 = HEAP32[560624>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     label = 12;
    } else {
     $16 = (($14) + 36|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($14) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($17|0)==($19|0);
     do {
      if ($20) {
       $21 = (($14) + 28|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($14) + 32|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($22) + ($24<<3)|0);
       $41 = $25;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i7,$14,$2);
       $26 = HEAP32[$pos$i$i$i$i$i7>>2]|0;
       $27 = ($26|0)==(-1);
       $28 = (($14) + 28|0);
       $29 = HEAP32[$28>>2]|0;
       if ($27) {
        $30 = (($14) + 32|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = (($29) + ($31<<3)|0);
        $41 = $32;
        break;
       } else {
        $33 = (($29) + ($26<<3)|0);
        $41 = $33;
        break;
       }
      }
     } while(0);
     $34 = HEAP32[560624>>2]|0;
     $35 = (($34) + 28|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($34) + 32|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($36) + ($38<<3)|0);
     $40 = ($41|0)==($39|0);
     if ($40) {
      label = 12;
     } else {
      $42 = (($41) + 4|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = ($43|0)==(0|0);
      if ($44) {
       label = 12;
      } else {
       $49 = $34;
      }
     }
    }
    if ((label|0) == 12) {
     $45 = HEAP32[$4>>2]|0;
     $46 = (__Z31ReadObjectFromPersistentManageri($45)|0);
     $phitmp$i = ($46|0)==(0|0);
     if ($phitmp$i) {
      break;
     }
     $$pre20 = HEAP32[560624>>2]|0;
     $49 = $$pre20;
    }
    $47 = HEAP32[$4>>2]|0;
    HEAP32[$1>>2] = $47;
    $48 = ($49|0)==(0|0);
    if ($48) {
     label = 22;
    } else {
     $50 = (($49) + 36|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = (($49) + 4|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($51|0)==($53|0);
     do {
      if ($54) {
       $55 = (($49) + 28|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = (($49) + 32|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($56) + ($58<<3)|0);
       $75 = $59;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i7,$49,$1);
       $60 = HEAP32[$pos$i$i$i$i$i7>>2]|0;
       $61 = ($60|0)==(-1);
       $62 = (($49) + 28|0);
       $63 = HEAP32[$62>>2]|0;
       if ($61) {
        $64 = (($49) + 32|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = (($63) + ($65<<3)|0);
        $75 = $66;
        break;
       } else {
        $67 = (($63) + ($60<<3)|0);
        $75 = $67;
        break;
       }
      }
     } while(0);
     $68 = HEAP32[560624>>2]|0;
     $69 = (($68) + 28|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($68) + 32|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = (($70) + ($72<<3)|0);
     $74 = ($75|0)==($73|0);
     if ($74) {
      label = 22;
     } else {
      $76 = (($75) + 4|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = ($77|0)==(0|0);
      if ($78) {
       label = 22;
      } else {
       $temp$0$i5 = $77;
      }
     }
    }
    if ((label|0) == 22) {
     $79 = HEAP32[$4>>2]|0;
     $80 = (__Z31ReadObjectFromPersistentManageri($79)|0);
     $temp$0$i5 = $80;
    }
    __ZN11TerrainData10RemoveUserEPN5Unity10GameObjectE($temp$0$i5,$12);
   }
  } while(0);
  $81 = HEAP32[$terrainData>>2]|0;
  $82 = ($81|0)==(0);
  do {
   if (!($82)) {
    HEAP32[$0>>2] = $81;
    $83 = HEAP32[560624>>2]|0;
    $84 = ($83|0)==(0|0);
    if ($84) {
     label = 33;
    } else {
     $85 = (($83) + 36|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($83) + 4|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = ($86|0)==($88|0);
     do {
      if ($89) {
       $90 = (($83) + 28|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = (($83) + 32|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = (($91) + ($93<<3)|0);
       $110 = $94;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i7,$83,$0);
       $95 = HEAP32[$pos$i$i$i$i$i7>>2]|0;
       $96 = ($95|0)==(-1);
       $97 = (($83) + 28|0);
       $98 = HEAP32[$97>>2]|0;
       if ($96) {
        $99 = (($83) + 32|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = (($98) + ($100<<3)|0);
        $110 = $101;
        break;
       } else {
        $102 = (($98) + ($95<<3)|0);
        $110 = $102;
        break;
       }
      }
     } while(0);
     $103 = HEAP32[560624>>2]|0;
     $104 = (($103) + 28|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = (($103) + 32|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = (($105) + ($107<<3)|0);
     $109 = ($110|0)==($108|0);
     if ($109) {
      label = 33;
     } else {
      $111 = (($110) + 4|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = ($112|0)==(0|0);
      if ($113) {
       label = 33;
      } else {
       $118 = $103;
      }
     }
    }
    if ((label|0) == 33) {
     $114 = HEAP32[$terrainData>>2]|0;
     $115 = (__Z31ReadObjectFromPersistentManageri($114)|0);
     $phitmp$i12 = ($115|0)==(0|0);
     if ($phitmp$i12) {
      break;
     }
     $$pre19 = HEAP32[560624>>2]|0;
     $118 = $$pre19;
    }
    $116 = HEAP32[$terrainData>>2]|0;
    HEAP32[$3>>2] = $116;
    $117 = ($118|0)==(0|0);
    if ($117) {
     label = 43;
    } else {
     $119 = (($118) + 36|0);
     $120 = HEAP32[$119>>2]|0;
     $121 = (($118) + 4|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ($120|0)==($122|0);
     do {
      if ($123) {
       $124 = (($118) + 28|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = (($118) + 32|0);
       $127 = HEAP32[$126>>2]|0;
       $128 = (($125) + ($127<<3)|0);
       $144 = $128;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i7,$118,$3);
       $129 = HEAP32[$pos$i$i$i$i$i7>>2]|0;
       $130 = ($129|0)==(-1);
       $131 = (($118) + 28|0);
       $132 = HEAP32[$131>>2]|0;
       if ($130) {
        $133 = (($118) + 32|0);
        $134 = HEAP32[$133>>2]|0;
        $135 = (($132) + ($134<<3)|0);
        $144 = $135;
        break;
       } else {
        $136 = (($132) + ($129<<3)|0);
        $144 = $136;
        break;
       }
      }
     } while(0);
     $137 = HEAP32[560624>>2]|0;
     $138 = (($137) + 28|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = (($137) + 32|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = (($139) + ($141<<3)|0);
     $143 = ($144|0)==($142|0);
     if ($143) {
      label = 43;
     } else {
      $145 = (($144) + 4|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($146|0)==(0|0);
      if ($147) {
       label = 43;
      } else {
       $temp$0$i = $146;
      }
     }
    }
    if ((label|0) == 43) {
     $148 = HEAP32[$terrainData>>2]|0;
     $149 = (__Z31ReadObjectFromPersistentManageri($148)|0);
     $temp$0$i = $149;
    }
    __ZN11TerrainData7AddUserEPN5Unity10GameObjectE($temp$0$i,$12);
   }
  } while(0);
  $150 = (($this) + 92|0);
  $151 = HEAP32[$150>>2]|0;
  __ZN14SplatMaterials14SetTerrainDataERK4PPtrI11TerrainDataE($151,$terrainData);
  $$pre = HEAP32[$terrainData>>2]|0;
  $152 = $$pre;
 }
 HEAP32[$4>>2] = $152;
 __ZN7Terrain5FlushEv($this);
 STACKTOP = sp;return;
}
function __ZN7Terrain23GarbageCollectRenderersEv($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$ph12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 4|0;
 $0 = sp;
 $1 = (__Z14GetTimeManagerv()|0);
 $2 = (($1) + 128|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 196|0);
 $5 = (($this) + 204|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP32[$4>>2]|0;
 $43 = $6;$44 = $8;$i$0$ph12 = $8;
 L4: while(1) {
  $9 = (($i$0$ph12) + 16|0);
  $10 = (($i$0$ph12) + 8|0);
  $11 = (($i$0$ph12) + 4|0);
  $12 = (($i$0$ph12) + 12|0);
  $13 = (($i$0$ph12) + 20|0);
  $14 = $13;
  $40 = $44;$41 = $43;
  while(1) {
   $15 = HEAP32[$9>>2]|0;
   $16 = (($3) - ($15))|0;
   $17 = ($16>>>0)>(100);
   if (!($17)) {
    $18 = HEAP32[$i$0$ph12>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     break;
    }
   }
   $20 = HEAP32[$10>>2]|0;
   $21 = HEAP32[628440>>2]|0;
   $22 = ($20|0)==(0|0);
   if (!($22)) {
    __ZN12TreeRendererD2Ev($20);
   }
   HEAP32[$0>>2] = $21;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($20,$$byval_copy2);
   HEAP32[$10>>2] = 0;
   $23 = HEAP32[$11>>2]|0;
   $24 = HEAP32[628440>>2]|0;
   $25 = ($23|0)==(0|0);
   if (!($25)) {
    __ZN15TerrainRendererD2Ev($23);
   }
   HEAP32[$0>>2] = $24;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($23,$$byval_copy2);
   HEAP32[$11>>2] = 0;
   $26 = HEAP32[$12>>2]|0;
   $27 = HEAP32[628440>>2]|0;
   $28 = ($26|0)==(0|0);
   if (!($28)) {
    __ZN14DetailRendererD2Ev($26);
   }
   HEAP32[$0>>2] = $27;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($26,$$byval_copy2);
   HEAP32[$12>>2] = 0;
   $29 = HEAP32[$4>>2]|0;
   $30 = HEAP32[$5>>2]|0;
   $31 = (($29) + (($30*20)|0)|0);
   $32 = $31;
   $33 = (($32) - ($14))|0;
   _memmove(($i$0$ph12|0),($13|0),($33|0))|0;
   $34 = HEAP32[$5>>2]|0;
   $35 = (($34) + -1)|0;
   HEAP32[$5>>2] = $35;
   $36 = HEAP32[$4>>2]|0;
   $37 = (($36) + (($35*20)|0)|0);
   $38 = ($i$0$ph12|0)==($37|0);
   if ($38) {
    label = 14;
    break L4;
   } else {
    $40 = $36;$41 = $35;
   }
  }
  $39 = (($40) + (($41*20)|0)|0);
  $42 = ($13|0)==($39|0);
  if ($42) {
   label = 14;
   break;
  } else {
   $43 = $41;$44 = $40;$i$0$ph12 = $13;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZN7Terrain10FlushDirtyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $i$013 = 0;
 var $i1$010 = 0, $i2$07 = 0, $i3$05 = 0, $not$ = 0, $phitmp$i = 0, $pos$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   label = 11;
  } else {
   HEAP32[$0>>2] = $2;
   $4 = HEAP32[560624>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = (($4) + 36|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($4) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($7|0)==($9|0);
    do {
     if ($10) {
      $11 = (($4) + 28|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = (($4) + 32|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($12) + ($14<<3)|0);
      $31 = $15;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$4,$0);
      $16 = HEAP32[$pos$i$i$i$i$i>>2]|0;
      $17 = ($16|0)==(-1);
      $18 = (($4) + 28|0);
      $19 = HEAP32[$18>>2]|0;
      if ($17) {
       $20 = (($4) + 32|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($19) + ($21<<3)|0);
       $31 = $22;
       break;
      } else {
       $23 = (($19) + ($16<<3)|0);
       $31 = $23;
       break;
      }
     }
    } while(0);
    $24 = HEAP32[560624>>2]|0;
    $25 = (($24) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + 32|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + ($28<<3)|0);
    $30 = ($31|0)==($29|0);
    if (!($30)) {
     $32 = (($31) + 4|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)==(0|0);
     if (!($34)) {
      break;
     }
    }
   }
   $35 = HEAP32[$1>>2]|0;
   $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
   $phitmp$i = ($36|0)==(0|0);
   if ($phitmp$i) {
    label = 11;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  __ZN7Terrain5FlushEv($this);
 }
 $37 = (($this) + 192|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 1;
 $not$ = ($39|0)==(0);
 $40 = $38 & 3;
 $41 = ($40|0)==(0);
 $42 = $38 & 4;
 $43 = ($42|0)==(0);
 if (!($43)) {
  $44 = (($this) + 196|0);
  $45 = (($this) + 204|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0);
  if (!($47)) {
   $48 = HEAP32[$44>>2]|0;
   $i$013 = $48;
   while(1) {
    $49 = (($i$013) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    __ZN15TerrainRenderer22ReloadPrecomputedErrorEv($50);
    $51 = (($i$013) + 20|0);
    $52 = HEAP32[$44>>2]|0;
    $53 = HEAP32[$45>>2]|0;
    $54 = (($52) + (($53*20)|0)|0);
    $55 = ($51|0)==($54|0);
    if ($55) {
     break;
    } else {
     $i$013 = $51;
    }
   }
  }
 }
 if (!($41)) {
  $56 = (($this) + 196|0);
  $57 = (($this) + 204|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0);
  if (!($59)) {
   $60 = HEAP32[$56>>2]|0;
   $i1$010 = $60;
   while(1) {
    $61 = (($i1$010) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    __ZN12TreeRenderer11ReloadTreesEv($62);
    $63 = (($i1$010) + 20|0);
    $64 = HEAP32[$56>>2]|0;
    $65 = HEAP32[$57>>2]|0;
    $66 = (($64) + (($65*20)|0)|0);
    $67 = ($63|0)==($66|0);
    if ($67) {
     break;
    } else {
     $i1$010 = $63;
    }
   }
  }
 }
 if (!($not$)) {
  $68 = (($this) + 196|0);
  $69 = (($this) + 204|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($70|0)==(0);
  if (!($71)) {
   $72 = HEAP32[$68>>2]|0;
   $i2$07 = $72;
   while(1) {
    $73 = (($i2$07) + 12|0);
    $74 = HEAP32[$73>>2]|0;
    __ZN14DetailRenderer16ReloadAllDetailsEv($74);
    $75 = (($i2$07) + 20|0);
    $76 = HEAP32[$68>>2]|0;
    $77 = HEAP32[$69>>2]|0;
    $78 = (($76) + (($77*20)|0)|0);
    $79 = ($75|0)==($78|0);
    if ($79) {
     break;
    } else {
     $i2$07 = $75;
    }
   }
  }
 }
 $80 = HEAP32[$37>>2]|0;
 $81 = $80 & 1;
 $82 = ($81|0)==(0);
 if (!($82)) {
  $83 = (($this) + 196|0);
  $84 = (($this) + 204|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)==(0);
  if (!($86)) {
   $87 = HEAP32[$83>>2]|0;
   $i3$05 = $87;
   while(1) {
    $88 = (($i3$05) + 4|0);
    $89 = HEAP32[$88>>2]|0;
    __ZN15TerrainRenderer9ReloadAllEv($89);
    $90 = (($i3$05) + 20|0);
    $91 = HEAP32[$83>>2]|0;
    $92 = HEAP32[$84>>2]|0;
    $93 = (($91) + (($92*20)|0)|0);
    $94 = ($90|0)==($93|0);
    if ($94) {
     break;
    } else {
     $i3$05 = $90;
    }
   }
  }
 }
 $95 = (($this) + 92|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96|0)==(0|0);
 if ($97) {
  HEAP32[$37>>2] = 0;
  STACKTOP = sp;return;
 }
 $98 = (($this) + 88|0);
 __ZN14SplatMaterials15UpdateMaterialsERK4PPtrIN5Unity8MaterialEE($96,$98);
 HEAP32[$37>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN7Terrain11GetRendererEv($this) {
 $this = $this|0;
 var $$$i$i = 0, $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy7 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = Math_fround(0), $228 = 0, $229 = Math_fround(0), $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$012 = 0, $phitmp$i = 0, $position = 0, $temp$0$i = 0, $temp$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy7 = sp + 44|0;
 $0 = sp + 40|0;
 $1 = sp + 36|0;
 $2 = sp + 32|0;
 $position = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 12|0;
 $8 = (__Z16GetRenderManagerv()|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$2>>2] = $9;
 $10 = HEAP32[560624>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  label = 9;
 } else {
  $12 = (($10) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($10) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($13|0)==($15|0);
  do {
   if ($16) {
    $17 = (($10) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($10) + 32|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($18) + ($20<<3)|0);
    $37 = $21;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy7,$10,$2);
    $22 = HEAP32[$$byval_copy7>>2]|0;
    $23 = ($22|0)==(-1);
    $24 = (($10) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    if ($23) {
     $26 = (($10) + 32|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($25) + ($27<<3)|0);
     $37 = $28;
     break;
    } else {
     $29 = (($25) + ($22<<3)|0);
     $37 = $29;
     break;
    }
   }
  } while(0);
  $30 = HEAP32[560624>>2]|0;
  $31 = (($30) + 28|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 32|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + ($34<<3)|0);
  $36 = ($37|0)==($35|0);
  if ($36) {
   label = 9;
  } else {
   $38 = (($37) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)==(0|0);
   if ($40) {
    label = 9;
   } else {
    $temp$0$i$i$i = $39;
   }
  }
 }
 if ((label|0) == 9) {
  $41 = HEAP32[$8>>2]|0;
  $42 = (__Z31ReadObjectFromPersistentManageri($41)|0);
  $temp$0$i$i$i = $42;
 }
 $43 = (($temp$0$i$i$i) + 412|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($this) + 24|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46) + 40|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = 1 << $48;
 $50 = $49 & $44;
 $51 = ($50|0)==(0);
 if ($51) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $52 = (__Z14GetTimeManagerv()|0);
 $53 = (($52) + 128|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (($this) + 196|0);
 $56 = (($this) + 204|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0);
 L17: do {
  if (!($58)) {
   $59 = HEAP32[$55>>2]|0;
   $i$012 = $59;
   while(1) {
    $63 = HEAP32[$i$012>>2]|0;
    $64 = ($63|0)==($temp$0$i$i$i|0);
    $62 = (($i$012) + 20|0);
    if ($64) {
     break;
    }
    $60 = (($59) + (($57*20)|0)|0);
    $61 = ($62|0)==($60|0);
    if ($61) {
     break L17;
    } else {
     $i$012 = $62;
    }
   }
   $65 = (($i$012) + 16|0);
   HEAP32[$65>>2] = $54;
   $$0 = $i$012;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $66 = (($this) + 44|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0);
 if ($68) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $67;
 $69 = HEAP32[560624>>2]|0;
 $70 = ($69|0)==(0|0);
 if ($70) {
  label = 25;
 } else {
  $71 = (($69) + 36|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($69) + 4|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($72|0)==($74|0);
  do {
   if ($75) {
    $76 = (($69) + 28|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (($69) + 32|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($77) + ($79<<3)|0);
    $96 = $80;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy7,$69,$0);
    $81 = HEAP32[$$byval_copy7>>2]|0;
    $82 = ($81|0)==(-1);
    $83 = (($69) + 28|0);
    $84 = HEAP32[$83>>2]|0;
    if ($82) {
     $85 = (($69) + 32|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($84) + ($86<<3)|0);
     $96 = $87;
     break;
    } else {
     $88 = (($84) + ($81<<3)|0);
     $96 = $88;
     break;
    }
   }
  } while(0);
  $89 = HEAP32[560624>>2]|0;
  $90 = (($89) + 28|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($89) + 32|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (($91) + ($93<<3)|0);
  $95 = ($96|0)==($94|0);
  if ($95) {
   label = 25;
  } else {
   $97 = (($96) + 4|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==(0|0);
   if ($99) {
    label = 25;
   }
  }
 }
 if ((label|0) == 25) {
  $100 = HEAP32[$66>>2]|0;
  $101 = (__Z31ReadObjectFromPersistentManageri($100)|0);
  $phitmp$i = ($101|0)==(0|0);
  if ($phitmp$i) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $102 = HEAP32[$45>>2]|0;
 $103 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($102)|0);
 __ZNK9Transform11GetPositionEv($position,$103);
 $104 = HEAP32[$56>>2]|0;
 $105 = (($104) + 1)|0;
 HEAP32[$56>>2] = $105;
 $106 = (($this) + 208|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = $107 & 2147483647;
 $109 = ($108>>>0)<($105>>>0);
 do {
  if ($109) {
   $110 = ($107|0)>(-1);
   if ($110) {
    HEAP32[$106>>2] = $105;
    $111 = HEAP32[$55>>2]|0;
    $112 = ($105*20)|0;
    $113 = (($this) + 200|0);
    $114 = HEAP32[$113>>2]|0;
    HEAP32[$1>>2] = $114;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    $115 = (__Z16realloc_internalPvji10MemLabelIdiPKci($111,$112,4,$$byval_copy7,0,801552,370)|0);
    HEAP32[$55>>2] = $115;
    $126 = $115;
    break;
   } else {
    $116 = ($105*20)|0;
    $117 = (($this) + 200|0);
    $118 = HEAP32[$117>>2]|0;
    HEAP32[$1>>2] = $118;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    $119 = (__Z15malloc_internaljj10MemLabelIdiPKci($116,4,$$byval_copy7,0,801552,352)|0);
    $120 = HEAP32[$55>>2]|0;
    $121 = HEAP32[$56>>2]|0;
    $122 = ($121*20)|0;
    _memcpy(($119|0),($120|0),($122|0))|0;
    HEAP32[$106>>2] = $105;
    HEAP32[$55>>2] = $119;
    $126 = $119;
    break;
   }
  } else {
   $$pre = HEAP32[$55>>2]|0;
   $126 = $$pre;
  }
 } while(0);
 $123 = HEAP32[$56>>2]|0;
 $124 = (($123) + -1)|0;
 $125 = (($126) + (($124*20)|0)|0);
 HEAP32[$125>>2] = $temp$0$i$i$i;
 $127 = HEAP32[628440>>2]|0;
 HEAP32[$3>>2] = $127;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
 $128 = (__Znwj10MemLabelIdbiPKci(328,$$byval_copy7,0,16,801552,294)|0);
 $129 = HEAP32[$45>>2]|0;
 $130 = (($129) + 4|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = HEAP32[$66>>2]|0;
 HEAP32[$4>>2] = $132;
 __THREW__ = 0;
 invoke_viiii(420,($128|0),($131|0),($4|0),($position|0));
 $133 = __THREW__; __THREW__ = 0;
 $134 = $133&1;
 if ($134) {
  $135 = ___cxa_find_matching_catch()|0;
  $136 = tempRet0;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_viiiiii(97,($128|0),($$byval_copy7|0),0,16,(801552|0),294);
  $137 = __THREW__; __THREW__ = 0;
  $138 = $137&1;
  if ($138) {
   $197 = ___cxa_find_matching_catch(0|0)|0;
   $198 = tempRet0;
   ___clang_call_terminate($197);
   // unreachable;
  } else {
   $$01 = $136;$$02 = $135;
   ___resumeException($$02|0);
   // unreachable;
  }
 }
 $199 = ((($126) + (($124*20)|0)|0) + 4|0);
 HEAP32[$199>>2] = $128;
 $182 = (($this) + 128|0);
 $200 = HEAP32[$182>>2]|0;
 $201 = (($128) + 140|0);
 HEAP32[$201>>2] = $200;
 $202 = (($this) + 132|0);
 $203 = (($this) + 136|0);
 $204 = (($this) + 140|0);
 $205 = (($this) + 144|0);
 $206 = HEAP32[$199>>2]|0;
 $207 = (($this) + 96|0);
 $208 = Math_fround(HEAPF32[$207>>2]);
 $209 = (($this) + 100|0);
 $210 = Math_fround(HEAPF32[$209>>2]);
 $211 = (($this) + 104|0);
 $212 = $211;
 $213 = $212;
 $214 = HEAP32[$213>>2]|0;
 $215 = (($212) + 4)|0;
 $216 = $215;
 $217 = HEAP32[$216>>2]|0;
 $218 = (($206) + 108|0);
 HEAPF32[$218>>2] = $208;
 $219 = (($206) + 112|0);
 HEAPF32[$219>>2] = $210;
 $220 = (($206) + 116|0);
 $221 = $220;
 $222 = $221;
 HEAP32[$222>>2] = $214;
 $223 = (($221) + 4)|0;
 $224 = $223;
 HEAP32[$224>>2] = $217;
 $225 = HEAP32[$199>>2]|0;
 $226 = (($this) + 112|0);
 $227 = Math_fround(HEAPF32[$226>>2]);
 $228 = (($this) + 116|0);
 $229 = Math_fround(HEAPF32[$228>>2]);
 $230 = (($this) + 120|0);
 $231 = $230;
 $232 = $231;
 $233 = HEAP32[$232>>2]|0;
 $234 = (($231) + 4)|0;
 $235 = $234;
 $236 = HEAP32[$235>>2]|0;
 $237 = (HEAP32[tempDoublePtr>>2]=$233,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $238 = (HEAP32[tempDoublePtr>>2]=$236,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $239 = Math_fround(HEAPF32[$202>>2]);
 $240 = Math_fround($227 * $239);
 $241 = Math_fround(HEAPF32[$203>>2]);
 $242 = Math_fround($229 * $241);
 $243 = Math_fround(HEAPF32[$204>>2]);
 $244 = Math_fround($227 * $243);
 $245 = Math_fround($237 + $244);
 $246 = Math_fround(HEAPF32[$205>>2]);
 $247 = Math_fround($229 * $246);
 $248 = Math_fround($238 + $247);
 $249 = (($225) + 124|0);
 HEAPF32[$249>>2] = $240;
 $250 = (($225) + 128|0);
 HEAPF32[$250>>2] = $242;
 $251 = (($225) + 132|0);
 $252 = (HEAPF32[tempDoublePtr>>2]=$245,HEAP32[tempDoublePtr>>2]|0);
 $253 = (HEAPF32[tempDoublePtr>>2]=$248,HEAP32[tempDoublePtr>>2]|0);
 $254 = $251;
 $255 = $254;
 HEAP32[$255>>2] = $252;
 $256 = (($254) + 4)|0;
 $257 = $256;
 HEAP32[$257>>2] = $253;
 $258 = HEAP32[628440>>2]|0;
 HEAP32[$5>>2] = $258;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
 $174 = (__Znwj10MemLabelIdbiPKci(300,$$byval_copy7,0,16,801552,301)|0);
 $259 = HEAP32[$66>>2]|0;
 HEAP32[$1>>2] = $259;
 $140 = HEAP32[560624>>2]|0;
 $260 = ($140|0)==(0|0);
 if ($260) {
  label = 40;
 } else {
  $139 = (($140) + 36|0);
  $141 = HEAP32[$139>>2]|0;
  $142 = (($140) + 4|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ($141|0)==($143|0);
  do {
   if ($144) {
    $145 = (($140) + 28|0);
    $146 = HEAP32[$145>>2]|0;
    $147 = (($140) + 32|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = (($146) + ($148<<3)|0);
    $165 = $149;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy7,$140,$1);
    $150 = HEAP32[$$byval_copy7>>2]|0;
    $151 = ($150|0)==(-1);
    $152 = (($140) + 28|0);
    $153 = HEAP32[$152>>2]|0;
    if ($151) {
     $154 = (($140) + 32|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = (($153) + ($155<<3)|0);
     $165 = $156;
     break;
    } else {
     $157 = (($153) + ($150<<3)|0);
     $165 = $157;
     break;
    }
   }
  } while(0);
  $158 = HEAP32[560624>>2]|0;
  $159 = (($158) + 28|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = (($158) + 32|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = (($160) + ($162<<3)|0);
  $164 = ($165|0)==($163|0);
  if ($164) {
   label = 40;
  } else {
   $166 = (($165) + 4|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ($167|0)==(0|0);
   if ($168) {
    label = 40;
   } else {
    $temp$0$i = $167;
    label = 41;
   }
  }
 }
 if ((label|0) == 40) {
  $169 = HEAP32[$66>>2]|0;
  __THREW__ = 0;
  $170 = (invoke_ii(3215,($169|0))|0);
  $171 = __THREW__; __THREW__ = 0;
  $172 = $171&1;
  if (!($172)) {
   $temp$0$i = $170;
   label = 41;
  }
 }
 if ((label|0) == 41) {
  $173 = (($temp$0$i) + 72|0);
  __THREW__ = 0;
  invoke_viii(2033,($174|0),($173|0),($position|0));
  $175 = __THREW__; __THREW__ = 0;
  $176 = $175&1;
  if (!($176)) {
   $177 = ((($126) + (($124*20)|0)|0) + 8|0);
   HEAP32[$177>>2] = $174;
   $178 = HEAP32[628440>>2]|0;
   HEAP32[$6>>2] = $178;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
   $179 = (__Znwj10MemLabelIdbiPKci(88,$$byval_copy7,0,16,801552,302)|0);
   $180 = HEAP32[$66>>2]|0;
   HEAP32[$7>>2] = $180;
   $181 = HEAP16[$182>>1]|0;
   $183 = ($181<<16>>16)==(255);
   $184 = $181&65535;
   $$$i$i = $183 ? -1 : $184;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$$byval_copy7+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$$byval_copy7+8>>2]=HEAP32[$position+8>>2]|0;
   invoke_viiii(421,($179|0),($7|0),($$byval_copy7|0),($$$i$i|0));
   $185 = __THREW__; __THREW__ = 0;
   $186 = $185&1;
   if (!($186)) {
    $187 = ((($126) + (($124*20)|0)|0) + 12|0);
    HEAP32[$187>>2] = $179;
    $188 = ((($126) + (($124*20)|0)|0) + 16|0);
    HEAP32[$188>>2] = $54;
    $$0 = $125;
    STACKTOP = sp;return ($$0|0);
   }
   $193 = ___cxa_find_matching_catch()|0;
   $194 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
   invoke_viiiiii(97,($179|0),($$byval_copy7|0),0,16,(801552|0),302);
   $195 = __THREW__; __THREW__ = 0;
   $196 = $195&1;
   if ($196) {
    $197 = ___cxa_find_matching_catch(0|0)|0;
    $198 = tempRet0;
    ___clang_call_terminate($197);
    // unreachable;
   } else {
    $$01 = $194;$$02 = $193;
    ___resumeException($$02|0);
    // unreachable;
   }
  }
 }
 $189 = ___cxa_find_matching_catch()|0;
 $190 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
 invoke_viiiiii(97,($174|0),($$byval_copy7|0),0,16,(801552|0),301);
 $191 = __THREW__; __THREW__ = 0;
 $192 = $191&1;
 if ($192) {
  $197 = ___cxa_find_matching_catch(0|0)|0;
  $198 = tempRet0;
  ___clang_call_terminate($197);
  // unreachable;
 } else {
  $$01 = $190;$$02 = $189;
  ___resumeException($$02|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN7Terrain28GetTerrainRendererDontCreateEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i$i = 0, $r$02 = 0;
 var $temp$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (__Z16GetRenderManagerv()|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[560624>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 9;
 } else {
  $5 = (($3) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $10 = (($3) + 28|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($3) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + ($13<<3)|0);
    $30 = $14;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$3,$0);
    $15 = HEAP32[$pos$i$i$i$i$i>>2]|0;
    $16 = ($15|0)==(-1);
    $17 = (($3) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    if ($16) {
     $19 = (($3) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $30 = $21;
     break;
    } else {
     $22 = (($18) + ($15<<3)|0);
     $30 = $22;
     break;
    }
   }
  } while(0);
  $23 = HEAP32[560624>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + ($27<<3)|0);
  $29 = ($30|0)==($28|0);
  if ($29) {
   label = 9;
  } else {
   $31 = (($30) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
   } else {
    $temp$0$i$i$i = $32;
   }
  }
 }
 if ((label|0) == 9) {
  $34 = HEAP32[$1>>2]|0;
  $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
  $temp$0$i$i$i = $35;
 }
 $36 = (($temp$0$i$i$i) + 412|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + 40|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = 1 << $41;
 $43 = $42 & $37;
 $44 = ($43|0)==(0);
 if ($44) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $45 = (($this) + 204|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0);
 if ($47) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $48 = (($this) + 196|0);
 $49 = HEAP32[$48>>2]|0;
 $r$02 = $49;
 while(1) {
  $53 = HEAP32[$r$02>>2]|0;
  $54 = ($53|0)==($temp$0$i$i$i|0);
  $52 = (($r$02) + 20|0);
  if ($54) {
   break;
  }
  $50 = (($49) + (($46*20)|0)|0);
  $51 = ($52|0)==($50|0);
  if ($51) {
   $$0 = 0;
   label = 16;
   break;
  } else {
   $r$02 = $52;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 $55 = (($r$02) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 $$0 = $56;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK7Terrain23TryGetSplatBaseMaterialEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
  STACKTOP = sp;return ($4|0);
 }
 $3 = (__ZNK14SplatMaterials20GetSplatBaseMaterialEv($1)|0);
 $4 = $3;
 STACKTOP = sp;return ($4|0);
}
function __ZN7Terrain16SetLightmapIndexEi12LightmapType($this,$value,$lightmapType) {
 $this = $this|0;
 $value = $value|0;
 $lightmapType = $lightmapType|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $r$01 = 0, $r$01$us = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = sp + 4|0;
 $1 = (($this) + 128|0);
 $2 = (($1) + ($lightmapType<<1)|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($value|0)==(-1);
 do {
  if ($4) {
   HEAP16[$2>>1] = 255;
  } else {
   $5 = ($value>>>0)>(255);
   if (!($5)) {
    $27 = $value&65535;
    HEAP16[$2>>1] = $27;
    break;
   }
   HEAP16[$2>>1] = 255;
   HEAP32[$vararg_buffer>>2] = 255;
   __Z6FormatPKcz($0,802128,$vararg_buffer);
   $6 = HEAP8[$0>>0]|0;
   $7 = $6 & 1;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    $11 = (($0) + 1|0);
    $12 = $11;
   } else {
    $9 = (($0) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $12 = $10;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($12|0),0,(801552|0),60,1,0,0,(0|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP8[$0>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     break;
    }
    $18 = (($0) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    __ZdlPv($19);
    break;
   }
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   $22 = HEAP8[$0>>0]|0;
   $23 = $22 & 1;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    ___resumeException($20|0);
    // unreachable;
   }
   $25 = (($0) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   __ZdlPv($26);
   ___resumeException($20|0);
   // unreachable;
  }
 } while(0);
 $28 = HEAP16[$2>>1]|0;
 $29 = ($28<<16>>16)==($3<<16>>16);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = (($this) + 196|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($this) + 204|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0);
 if ($34) {
  STACKTOP = sp;return;
 }
 $35 = ($lightmapType|0)==(0);
 if ($35) {
  $r$01$us = $31;
  while(1) {
   $36 = (($r$01$us) + 4|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = HEAP32[$1>>2]|0;
   $39 = (($37) + 140|0);
   HEAP32[$39>>2] = $38;
   $40 = (($r$01$us) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 28|0);
   HEAP32[$42>>2] = $value;
   $43 = (($r$01$us) + 20|0);
   $44 = HEAP32[$30>>2]|0;
   $45 = HEAP32[$32>>2]|0;
   $46 = (($44) + (($45*20)|0)|0);
   $47 = ($43|0)==($46|0);
   if ($47) {
    break;
   } else {
    $r$01$us = $43;
   }
  }
  STACKTOP = sp;return;
 } else {
  $r$01 = $31;
  while(1) {
   $48 = (($r$01) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = HEAP32[$1>>2]|0;
   $51 = (($49) + 140|0);
   HEAP32[$51>>2] = $50;
   $52 = (($r$01) + 20|0);
   $53 = HEAP32[$30>>2]|0;
   $54 = HEAP32[$32>>2]|0;
   $55 = (($53) + (($54*20)|0)|0);
   $56 = ($52|0)==($55|0);
   if ($56) {
    break;
   } else {
    $r$01 = $52;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN7Terrain18ShiftLightmapIndexEi($this,$value) {
 $this = $this|0;
 $value = $value|0;
 var $$$i$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(255);
 $3 = $1&65535;
 $$$i$i = $2 ? -1 : $3;
 $4 = (($$$i$i) + ($value))|0;
 __ZN7Terrain16SetLightmapIndexEi12LightmapType($this,$4,0);
 STACKTOP = sp;return;
}
function __ZN7Terrain23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801560,801568,$this,0);
 __ZN7Terrain8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Terrain23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,801560,801568,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN7Terrain8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Terrain23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Terrain8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Terrain23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Terrain8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Terrain23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7Terrain8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN7Terrain23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $8 = (($this) + 88|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$6>>2]|0;
 (FUNCTION_TABLE_iiii[$12 & 2047]($10,$9,$13)|0);
 STACKTOP = sp;return;
}
function __Z21RegisterClass_Terrainv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(218,243,244,0,245);
 STACKTOP = sp;return;
}
function __ZN7Terrain13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 HEAP8[$0>>0] = 14;
 $3 = (($0) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[801568+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[801568+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[801568+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[801568+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[801568+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[801568+5>>0]|0;HEAP8[$3+6>>0]=HEAP8[801568+6>>0]|0;
 $4 = (($0) + 8|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,218,8,($0|0),212,(2599|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $13 = HEAP8[$0>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   ___resumeException($11|0);
   // unreachable;
  }
  $16 = HEAP32[$4>>2]|0;
  __ZdlPv($16);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = HEAP32[$4>>2]|0;
  __ZdlPv($10);
  STACKTOP = sp;return;
 }
}
function __ZN7Terrain7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(212,$$byval_copy8,1,16,801552,35)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy8|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $64 = ___cxa_find_matching_catch()|0;
  $65 = tempRet0;
  $eh$lpad$body$index2Z2D = $65;$eh$lpad$body$indexZ2D = $64;
 } else {
  $6 = (($3) + 28|0);
  HEAP8[$6>>0] = 1;
  $7 = (($3) + 29|0);
  HEAP8[$7>>0] = 0;
  HEAP32[$3>>2] = ((801408 + 8|0));
  $8 = (($3) + 30|0);
  HEAP8[$8>>0] = 0;
  $9 = (($3) + 32|0);
  $10 = (($3) + 88|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 92|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 168|0);
  $13 = (($3) + 196|0);
  HEAP32[$13>>2] = 0;
  $14 = (($3) + 204|0);
  HEAP32[$14>>2] = 0;
  $15 = (($3) + 208|0);
  HEAP32[$15>>2] = 0;
  $16 = (($3) + 200|0);
  ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;
  HEAP32[$12>>2] = 0;
  HEAP32[$16>>2] = 61;
  $17 = (($3) + 48|0);
  HEAPF32[$17>>2] = Math_fround(5.0);
  $18 = (($3) + 52|0);
  HEAP32[$18>>2] = 0;
  $19 = (($3) + 56|0);
  HEAPF32[$19>>2] = Math_fround(1000.0);
  $20 = (($3) + 60|0);
  HEAPF32[$20>>2] = Math_fround(5000.0);
  $21 = (($3) + 64|0);
  HEAPF32[$21>>2] = Math_fround(50.0);
  $22 = (($3) + 68|0);
  HEAPF32[$22>>2] = Math_fround(5.0);
  $23 = (($3) + 72|0);
  HEAP32[$23>>2] = 50;
  $24 = (($3) + 76|0);
  HEAPF32[$24>>2] = Math_fround(80.0);
  $25 = (($3) + 80|0);
  HEAPF32[$25>>2] = Math_fround(1.0);
  $26 = (($3) + 84|0);
  HEAP8[$26>>0] = 1;
  $27 = (($3) + 85|0);
  HEAP8[$27>>0] = 1;
  $28 = (($3) + 86|0);
  HEAP8[$28>>0] = 1;
  $29 = (($3) + 172|0);
  $30 = (($3) + 188|0);
  ;HEAP32[$29+0>>2]=0|0;HEAP32[$29+4>>2]=0|0;HEAP32[$29+8>>2]=0|0;HEAP32[$29+12>>2]=0|0;
  HEAP32[$30>>2] = 7;
  $31 = (($3) + 128|0);
  $32 = (($3) + 130|0);
  HEAP16[$32>>1] = 255;
  HEAP16[$31>>1] = 255;
  $33 = (($3) + 96|0);
  HEAPF32[$33>>2] = Math_fround(1.0);
  $34 = (($3) + 100|0);
  HEAPF32[$34>>2] = Math_fround(1.0);
  $35 = (($3) + 104|0);
  HEAPF32[$35>>2] = Math_fround(0.0);
  $36 = (($3) + 108|0);
  HEAPF32[$36>>2] = Math_fround(0.0);
  $37 = (($3) + 112|0);
  HEAPF32[$37>>2] = Math_fround(1.0);
  $38 = (($3) + 116|0);
  HEAPF32[$38>>2] = Math_fround(1.0);
  $39 = (($3) + 120|0);
  HEAPF32[$39>>2] = Math_fround(0.0);
  $40 = (($3) + 124|0);
  HEAPF32[$40>>2] = Math_fround(0.0);
  $41 = (($3) + 132|0);
  HEAPF32[$41>>2] = Math_fround(1.0);
  $42 = (($3) + 136|0);
  HEAPF32[$42>>2] = Math_fround(1.0);
  $43 = (($3) + 140|0);
  HEAPF32[$43>>2] = Math_fround(0.0);
  $44 = (($3) + 144|0);
  HEAPF32[$44>>2] = Math_fround(0.0);
  $45 = (($3) + 148|0);
  HEAPF32[$45>>2] = Math_fround(1.0);
  $46 = (($3) + 152|0);
  HEAPF32[$46>>2] = Math_fround(1.0);
  $47 = (($3) + 156|0);
  HEAPF32[$47>>2] = Math_fround(0.0);
  $48 = (($3) + 160|0);
  HEAPF32[$48>>2] = Math_fround(0.0);
  $49 = (($3) + 164|0);
  HEAP8[$49>>0] = 1;
  __THREW__ = 0;
  invoke_vi(3709,(0|0));
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if (!($51)) {
   HEAP32[$12>>2] = 0;
   STACKTOP = sp;return ($3|0);
  }
  $52 = ___cxa_find_matching_catch()|0;
  $53 = tempRet0;
  $54 = HEAP32[$15>>2]|0;
  $55 = ($54|0)>(-1);
  do {
   if ($55) {
    $56 = HEAP32[$13>>2]|0;
    $57 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $57;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($56|0),($$byval_copy8|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     $62 = ___cxa_find_matching_catch(0|0)|0;
     $63 = tempRet0;
     ___clang_call_terminate($62);
     // unreachable;
    } else {
     HEAP32[$13>>2] = 0;
     break;
    }
   }
  } while(0);
  __THREW__ = 0;
  invoke_vi(3410,($3|0));
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if ($61) {
   $62 = ___cxa_find_matching_catch(0|0)|0;
   $63 = tempRet0;
   ___clang_call_terminate($62);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $53;$eh$lpad$body$indexZ2D = $52;
  }
 }
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy8|0),1,16,(801552|0),35);
 $66 = __THREW__; __THREW__ = 0;
 $67 = $66&1;
 if ($67) {
  $68 = ___cxa_find_matching_catch(0|0)|0;
  $69 = tempRet0;
  ___clang_call_terminate($68);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK7Terrain25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 218;
}
function __ZN7Terrain8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $localIdentifier$i$i$i1 = 0, $value = 0, $value1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i1 = sp;
 $value = sp + 20|0;
 $value1 = sp + 16|0;
 __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 HEAP32[$value>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801576,802104,$value,0);
 $0 = (($localIdentifier$i$i$i1) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 $5 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,802056,$5,$value,1);
 $6 = (($transfer) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($transfer) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($8) + (($10*24)|0)|0) + 12|0);
 HEAP32[$11>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $12 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,802072,$12,$0,1);
 $13 = HEAP32[$6>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$9>>2]|0;
 $16 = ((($14) + (($15*24)|0)|0) + 12|0);
 HEAP32[$16>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $17 = (($this) + 60|0);
 $18 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801592,$18,$17,0);
 $19 = HEAP32[$6>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$9>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801608,$18,$23,0);
 $24 = HEAP32[$6>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$9>>2]|0;
 $27 = ((($25) + (($26*24)|0)|0) + 12|0);
 HEAP32[$27>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $28 = (($this) + 68|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801632,$18,$28,0);
 $29 = HEAP32[$6>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$9>>2]|0;
 $32 = ((($30) + (($31*24)|0)|0) + 12|0);
 HEAP32[$32>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $33 = (($this) + 72|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801656,$5,$33,0);
 $34 = HEAP32[$6>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$9>>2]|0;
 $37 = ((($35) + (($36*24)|0)|0) + 12|0);
 HEAP32[$37>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $38 = (($this) + 76|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801688,$18,$38,0);
 $39 = HEAP32[$6>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$9>>2]|0;
 $42 = ((($40) + (($41*24)|0)|0) + 12|0);
 HEAP32[$42>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $43 = (($this) + 80|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801712,$18,$43,0);
 $44 = HEAP32[$6>>2]|0;
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$9>>2]|0;
 $47 = ((($45) + (($46*24)|0)|0) + 12|0);
 HEAP32[$47>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $48 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801736,$18,$48,0);
 $49 = HEAP32[$6>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = HEAP32[$9>>2]|0;
 $52 = ((($50) + (($51*24)|0)|0) + 12|0);
 HEAP32[$52>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $53 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801760,$18,$53,0);
 $54 = HEAP32[$6>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$9>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $58 = (($this) + 52|0);
 $59 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801784,$59,$58,0);
 $60 = HEAP32[$6>>2]|0;
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$9>>2]|0;
 $63 = ((($61) + (($62*24)|0)|0) + 12|0);
 HEAP32[$63>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $64 = (($this) + 84|0);
 $65 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801808,$65,$64,0);
 $66 = HEAP32[$6>>2]|0;
 $67 = HEAP32[$66>>2]|0;
 $68 = HEAP32[$9>>2]|0;
 $69 = ((($67) + (($68*24)|0)|0) + 12|0);
 HEAP32[$69>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $70 = (($this) + 85|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801824,$65,$70,0);
 $71 = HEAP32[$6>>2]|0;
 $72 = HEAP32[$71>>2]|0;
 $73 = HEAP32[$9>>2]|0;
 $74 = ((($72) + (($73*24)|0)|0) + 12|0);
 HEAP32[$74>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $75 = (($this) + 86|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801840,$65,$75,0);
 $76 = HEAP32[$6>>2]|0;
 $77 = HEAP32[$76>>2]|0;
 $78 = HEAP32[$9>>2]|0;
 $79 = ((($77) + (($78*24)|0)|0) + 12|0);
 HEAP32[$79>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 HEAP32[$value1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801864,802088,$value1,0);
 $80 = (($localIdentifier$i$i$i1) + 8|0);
 $81 = $80;
 $82 = $81;
 HEAP32[$82>>2] = 0;
 $83 = (($81) + 4)|0;
 $84 = $83;
 HEAP32[$84>>2] = 0;
 HEAP32[$localIdentifier$i$i$i1>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,802056,$59,$value1,1);
 $85 = HEAP32[$6>>2]|0;
 $86 = HEAP32[$85>>2]|0;
 $87 = HEAP32[$9>>2]|0;
 $88 = ((($86) + (($87*24)|0)|0) + 12|0);
 HEAP32[$88>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $89 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,802072,$89,$80,1);
 $90 = HEAP32[$6>>2]|0;
 $91 = HEAP32[$90>>2]|0;
 $92 = HEAP32[$9>>2]|0;
 $93 = ((($91) + (($92*24)|0)|0) + 12|0);
 HEAP32[$93>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $94 = (($this) + 128|0);
 $95 = HEAP32[580720>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801888,$95,$94,8388609);
 $96 = HEAP32[$6>>2]|0;
 $97 = HEAP32[$96>>2]|0;
 $98 = HEAP32[$9>>2]|0;
 $99 = ((($97) + (($98*24)|0)|0) + 12|0);
 HEAP32[$99>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $100 = (($94) + 2|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801904,$95,$100,8388609);
 $101 = HEAP32[$6>>2]|0;
 $102 = HEAP32[$101>>2]|0;
 $103 = HEAP32[$9>>2]|0;
 $104 = ((($102) + (($103*24)|0)|0) + 12|0);
 HEAP32[$104>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $105 = (($this) + 96|0);
 $106 = HEAP32[580784>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801928,$106,$105,8388609);
 __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($105,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $107 = (($this) + 112|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801952,$106,$107,8388609);
 __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($107,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $108 = (($this) + 164|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,801984,$65,$108,0);
 $109 = HEAP32[$6>>2]|0;
 $110 = HEAP32[$109>>2]|0;
 $111 = HEAP32[$9>>2]|0;
 $112 = ((($110) + (($111*24)|0)|0) + 12|0);
 HEAP32[$112>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $113 = (($this) + 132|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,802016,$106,$113,8388609);
 __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($113,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $114 = (($this) + 148|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,802032,$106,$114,8388609);
 __ZN8Vector4f8TransferI13ProxyTransferEEvRT_($114,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN7Terrain8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$$i = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i13 = 0, $$sum$i$i$i$i$i3 = 0, $$sum$i$i$i$i$i8 = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i14 = 0, $$sum1$i$i$i$i$i4 = 0, $$sum1$i$i$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $intIndex = 0, $value = 0, $value1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 16|0;
 $value = sp + 4|0;
 $value1 = sp + 8|0;
 $intIndex = sp + 12|0;
 __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 HEAP32[$value>>2] = 0;
 $1 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,801576,802104,$vararg_buffer,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = ($1|0)>(0);
  if ($3) {
   __ZN4PPtrI11TerrainDataE8TransferI14SafeBinaryReadEEvRT_($value,$transfer);
  } else {
   $4 = HEAP32[$vararg_buffer>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    (FUNCTION_TABLE_iii[$4 & 4095]($value,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $6 = (($transfer) + 136|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  __ZN7Terrain14SetTerrainDataERK4PPtrI11TerrainDataE($this,$value);
 }
 $9 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$9,801592,0);
 $10 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$10,801608,0);
 $11 = (($this) + 68|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$11,801632,0);
 $12 = (($this) + 72|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$12,801656,0);
 $13 = (($this) + 76|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$13,801688,0);
 $14 = (($this) + 80|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$14,801712,0);
 $15 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$15,801736,0);
 $16 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$16,801760,0);
 $17 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$17,801784,0);
 $18 = (($this) + 84|0);
 $19 = HEAP32[580544>>2]|0;
 $20 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,801808,$19,$vararg_buffer,0)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  $22 = ($20|0)>(0);
  do {
   if ($22) {
    $23 = (($transfer) + 12|0);
    $24 = (($transfer) + 80|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($transfer) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($transfer) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($transfer) + 32|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = Math_imul($33, $31)|0;
    $$sum$i$i$i$i$i3 = (($27) - ($34))|0;
    $35 = (($29) + ($$sum$i$i$i$i$i3)|0);
    HEAP32[$23>>2] = $35;
    $36 = ($$sum$i$i$i$i$i3|0)<(0);
    if (!($36)) {
     $$sum1$i$i$i$i$i4 = (($$sum$i$i$i$i$i3) + 1)|0;
     $37 = (($29) + ($$sum1$i$i$i$i$i4)|0);
     $38 = (($transfer) + 20|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($37>>>0)>($39>>>0);
     if (!($40)) {
      $41 = HEAP8[$35>>0]|0;
      HEAP8[$18>>0] = $41;
      $42 = HEAP32[$23>>2]|0;
      $43 = (($42) + 1|0);
      HEAP32[$23>>2] = $43;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($23,$18,1);
   } else {
    $44 = HEAP32[$vararg_buffer>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     (FUNCTION_TABLE_iii[$44 & 4095]($18,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $46 = (($this) + 85|0);
 $47 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,801824,$19,$vararg_buffer,0)|0);
 $48 = ($47|0)==(0);
 if (!($48)) {
  $49 = ($47|0)>(0);
  do {
   if ($49) {
    $50 = (($transfer) + 12|0);
    $51 = (($transfer) + 80|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($52) + 12|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = (($transfer) + 16|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (($transfer) + 28|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($transfer) + 32|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = Math_imul($60, $58)|0;
    $$sum$i$i$i$i$i8 = (($54) - ($61))|0;
    $62 = (($56) + ($$sum$i$i$i$i$i8)|0);
    HEAP32[$50>>2] = $62;
    $63 = ($$sum$i$i$i$i$i8|0)<(0);
    if (!($63)) {
     $$sum1$i$i$i$i$i9 = (($$sum$i$i$i$i$i8) + 1)|0;
     $64 = (($56) + ($$sum1$i$i$i$i$i9)|0);
     $65 = (($transfer) + 20|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ($64>>>0)>($66>>>0);
     if (!($67)) {
      $68 = HEAP8[$62>>0]|0;
      HEAP8[$46>>0] = $68;
      $69 = HEAP32[$50>>2]|0;
      $70 = (($69) + 1|0);
      HEAP32[$50>>2] = $70;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($50,$46,1);
   } else {
    $71 = HEAP32[$vararg_buffer>>2]|0;
    $72 = ($71|0)==(0|0);
    if (!($72)) {
     (FUNCTION_TABLE_iii[$71 & 4095]($46,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $73 = (($this) + 86|0);
 $74 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,801840,$19,$vararg_buffer,0)|0);
 $75 = ($74|0)==(0);
 if (!($75)) {
  $76 = ($74|0)>(0);
  do {
   if ($76) {
    $77 = (($transfer) + 12|0);
    $78 = (($transfer) + 80|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($79) + 12|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($transfer) + 16|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($transfer) + 28|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($transfer) + 32|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = Math_imul($87, $85)|0;
    $$sum$i$i$i$i$i13 = (($81) - ($88))|0;
    $89 = (($83) + ($$sum$i$i$i$i$i13)|0);
    HEAP32[$77>>2] = $89;
    $90 = ($$sum$i$i$i$i$i13|0)<(0);
    if (!($90)) {
     $$sum1$i$i$i$i$i14 = (($$sum$i$i$i$i$i13) + 1)|0;
     $91 = (($83) + ($$sum1$i$i$i$i$i14)|0);
     $92 = (($transfer) + 20|0);
     $93 = HEAP32[$92>>2]|0;
     $94 = ($91>>>0)>($93>>>0);
     if (!($94)) {
      $95 = HEAP8[$89>>0]|0;
      HEAP8[$73>>0] = $95;
      $96 = HEAP32[$77>>2]|0;
      $97 = (($96) + 1|0);
      HEAP32[$77>>2] = $97;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($77,$73,1);
   } else {
    $98 = HEAP32[$vararg_buffer>>2]|0;
    $99 = ($98|0)==(0|0);
    if (!($99)) {
     (FUNCTION_TABLE_iii[$98 & 4095]($73,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 HEAP32[$value1>>2] = 0;
 $100 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,801864,802088,$vararg_buffer,1)|0);
 $101 = ($100|0)==(0);
 if (!($101)) {
  $102 = ($100|0)>(0);
  if ($102) {
   __ZN4PPtrIN5Unity8MaterialEE8TransferI14SafeBinaryReadEEvRT_($value1,$transfer);
  } else {
   $103 = HEAP32[$vararg_buffer>>2]|0;
   $104 = ($103|0)==(0|0);
   if (!($104)) {
    (FUNCTION_TABLE_iii[$103 & 4095]($value1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $105 = HEAP8[$6>>0]|0;
 $106 = ($105<<24>>24)==(0);
 if (!($106)) {
  $107 = (($this) + 88|0);
  $108 = HEAP32[$107>>2]|0;
  $109 = HEAP32[$value1>>2]|0;
  $110 = ($108|0)==($109|0);
  if (!($110)) {
   HEAP32[$107>>2] = $109;
   $111 = (($this) + 92|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ($112|0)==(0|0);
   if (!($113)) {
    __ZN14SplatMaterials15UpdateMaterialsERK4PPtrIN5Unity8MaterialEE($112,$value1);
   }
  }
 }
 $114 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 $115 = (($this) + 128|0);
 do {
  if ($114) {
   $116 = HEAP16[$115>>1]|0;
   $117 = ($116<<16>>16)==(255);
   $118 = $116&65535;
   $$$i = $117 ? -1 : $118;
   HEAP32[$intIndex>>2] = $$$i;
   __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$intIndex,801888,0);
   $119 = HEAP32[$intIndex>>2]|0;
   $120 = ($119|0)==(-1);
   if ($120) {
    HEAP16[$115>>1] = 255;
    break;
   }
   $121 = ($119>>>0)>(255);
   if (!($121)) {
    $143 = $119&65535;
    HEAP16[$115>>1] = $143;
    break;
   }
   HEAP16[$115>>1] = 255;
   HEAP32[$vararg_buffer>>2] = 255;
   __Z6FormatPKcz($0,802128,$vararg_buffer);
   $122 = HEAP8[$0>>0]|0;
   $123 = $122 & 1;
   $124 = ($123<<24>>24)==(0);
   if ($124) {
    $127 = (($0) + 1|0);
    $128 = $127;
   } else {
    $125 = (($0) + 8|0);
    $126 = HEAP32[$125>>2]|0;
    $128 = $126;
   }
   __THREW__ = 0;
   invoke_viiiiiiii(21,($128|0),0,(801552|0),60,1,0,0,(0|0));
   $129 = __THREW__; __THREW__ = 0;
   $130 = $129&1;
   if (!($130)) {
    $131 = HEAP8[$0>>0]|0;
    $132 = $131 & 1;
    $133 = ($132<<24>>24)==(0);
    if ($133) {
     break;
    }
    $134 = (($0) + 8|0);
    $135 = HEAP32[$134>>2]|0;
    __ZdlPv($135);
    break;
   }
   $136 = ___cxa_find_matching_catch()|0;
   $137 = tempRet0;
   $138 = HEAP8[$0>>0]|0;
   $139 = $138 & 1;
   $140 = ($139<<24>>24)==(0);
   if ($140) {
    ___resumeException($136|0);
    // unreachable;
   }
   $141 = (($0) + 8|0);
   $142 = HEAP32[$141>>2]|0;
   __ZdlPv($142);
   ___resumeException($136|0);
   // unreachable;
  } else {
   __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$115,801888,0);
  }
 } while(0);
 $144 = (($115) + 2|0);
 __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($transfer,$144,801904,0);
 $145 = (($this) + 96|0);
 __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($transfer,$145,801928,0);
 $146 = (($this) + 112|0);
 __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($transfer,$146,801952,0);
 $147 = (($this) + 164|0);
 $148 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,801984,$19,$vararg_buffer,0)|0);
 $149 = ($148|0)==(0);
 if ($149) {
  $174 = (($this) + 132|0);
  __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($transfer,$174,802016,0);
  $175 = (($this) + 148|0);
  __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($transfer,$175,802032,0);
  STACKTOP = sp;return;
 }
 $150 = ($148|0)>(0);
 do {
  if ($150) {
   $151 = (($transfer) + 12|0);
   $152 = (($transfer) + 80|0);
   $153 = HEAP32[$152>>2]|0;
   $154 = (($153) + 12|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = (($transfer) + 16|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = (($transfer) + 28|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = (($transfer) + 32|0);
   $161 = HEAP32[$160>>2]|0;
   $162 = Math_imul($161, $159)|0;
   $$sum$i$i$i$i$i = (($155) - ($162))|0;
   $163 = (($157) + ($$sum$i$i$i$i$i)|0);
   HEAP32[$151>>2] = $163;
   $164 = ($$sum$i$i$i$i$i|0)<(0);
   if (!($164)) {
    $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
    $165 = (($157) + ($$sum1$i$i$i$i$i)|0);
    $166 = (($transfer) + 20|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = ($165>>>0)>($167>>>0);
    if (!($168)) {
     $169 = HEAP8[$163>>0]|0;
     HEAP8[$147>>0] = $169;
     $170 = HEAP32[$151>>2]|0;
     $171 = (($170) + 1|0);
     HEAP32[$151>>2] = $171;
     break;
    }
   }
   __ZN12CachedReader15UpdateReadCacheEPvj($151,$147,1);
  } else {
   $172 = HEAP32[$vararg_buffer>>2]|0;
   $173 = ($172|0)==(0|0);
   if (!($173)) {
    (FUNCTION_TABLE_iii[$172 & 4095]($147,$transfer)|0);
   }
  }
 } while(0);
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $174 = (($this) + 132|0);
 __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($transfer,$174,802016,0);
 $175 = (($this) + 148|0);
 __ZN14SafeBinaryRead8TransferI8Vector4fEEvRT_PKc17TransferMetaFlags($transfer,$175,802032,0);
 STACKTOP = sp;return;
}
function __ZN7Terrain8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0;
 var $$pre31 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0);
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $value = 0, $value1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp + 4|0;
 $value1 = sp;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 HEAP32[$value>>2] = 0;
 __ZN4PPtrI11TerrainDataE8TransferI18StreamedBinaryReadILb0EEEEvRT_($value,$transfer);
 __ZN7Terrain14SetTerrainDataERK4PPtrI11TerrainDataE($this,$value);
 $0 = (($this) + 60|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre12 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre12;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 }
 $8 = (($this) + 64|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)>($12>>>0);
 if ($11) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$8,4);
  $$pre13 = HEAP32[$1>>2]|0;
  $$pre14 = HEAP32[$4>>2]|0;
  $16 = $$pre13;$18 = $$pre14;
 } else {
  $13 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$8>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 }
 $14 = (($this) + 68|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)>($18>>>0);
 if ($17) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$14,4);
  $$pre15 = HEAP32[$1>>2]|0;
  $$pre16 = HEAP32[$4>>2]|0;
  $22 = $$pre15;$24 = $$pre16;
 } else {
  $19 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$14>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 }
 $20 = (($this) + 72|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre17 = HEAP32[$1>>2]|0;
  $$pre18 = HEAP32[$4>>2]|0;
  $28 = $$pre17;$30 = $$pre18;
 } else {
  $25 = HEAP32[$22>>2]|0;
  HEAP32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 }
 $26 = (($this) + 76|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)>($30>>>0);
 if ($29) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$26,4);
  $$pre19 = HEAP32[$1>>2]|0;
  $$pre20 = HEAP32[$4>>2]|0;
  $34 = $$pre19;$36 = $$pre20;
 } else {
  $31 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$26>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 }
 $32 = (($this) + 80|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)>($36>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$32,4);
  $$pre21 = HEAP32[$1>>2]|0;
  $$pre22 = HEAP32[$4>>2]|0;
  $40 = $$pre21;$42 = $$pre22;
 } else {
  $37 = Math_fround(HEAPF32[$34>>2]);
  HEAPF32[$32>>2] = $37;
  HEAP32[$1>>2] = $33;
  $40 = $33;$42 = $36;
 }
 $38 = (($this) + 48|0);
 $39 = (($40) + 4|0);
 $41 = ($39>>>0)>($42>>>0);
 if ($41) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$38,4);
  $$pre23 = HEAP32[$1>>2]|0;
  $$pre24 = HEAP32[$4>>2]|0;
  $46 = $$pre23;$48 = $$pre24;
 } else {
  $43 = Math_fround(HEAPF32[$40>>2]);
  HEAPF32[$38>>2] = $43;
  HEAP32[$1>>2] = $39;
  $46 = $39;$48 = $42;
 }
 $44 = (($this) + 56|0);
 $45 = (($46) + 4|0);
 $47 = ($45>>>0)>($48>>>0);
 if ($47) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$44,4);
  $$pre25 = HEAP32[$1>>2]|0;
  $$pre26 = HEAP32[$4>>2]|0;
  $52 = $$pre25;$54 = $$pre26;
 } else {
  $49 = Math_fround(HEAPF32[$46>>2]);
  HEAPF32[$44>>2] = $49;
  HEAP32[$1>>2] = $45;
  $52 = $45;$54 = $48;
 }
 $50 = (($this) + 52|0);
 $51 = (($52) + 4|0);
 $53 = ($51>>>0)>($54>>>0);
 if ($53) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$50,4);
  $$pre27 = HEAP32[$1>>2]|0;
  $$pre28 = HEAP32[$4>>2]|0;
  $58 = $$pre27;$60 = $$pre28;
 } else {
  $55 = HEAP32[$52>>2]|0;
  HEAP32[$50>>2] = $55;
  HEAP32[$1>>2] = $51;
  $58 = $51;$60 = $54;
 }
 $56 = (($this) + 84|0);
 $57 = (($58) + 1|0);
 $59 = ($57>>>0)>($60>>>0);
 if ($59) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$56,1);
 } else {
  $61 = HEAP8[$58>>0]|0;
  HEAP8[$56>>0] = $61;
  $62 = HEAP32[$1>>2]|0;
  $63 = (($62) + 1|0);
  HEAP32[$1>>2] = $63;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $64 = (($this) + 85|0);
 $65 = HEAP32[$1>>2]|0;
 $66 = (($65) + 1|0);
 $67 = HEAP32[$4>>2]|0;
 $68 = ($66>>>0)>($67>>>0);
 if ($68) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$64,1);
  $$pre29 = HEAP32[$1>>2]|0;
  $74 = $$pre29;
 } else {
  $69 = HEAP8[$65>>0]|0;
  HEAP8[$64>>0] = $69;
  $70 = HEAP32[$1>>2]|0;
  $71 = (($70) + 1|0);
  HEAP32[$1>>2] = $71;
  $74 = $71;
 }
 $72 = (($this) + 86|0);
 $73 = (($74) + 1|0);
 $75 = HEAP32[$4>>2]|0;
 $76 = ($73>>>0)>($75>>>0);
 if ($76) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$72,1);
 } else {
  $77 = HEAP8[$74>>0]|0;
  HEAP8[$72>>0] = $77;
  $78 = HEAP32[$1>>2]|0;
  $79 = (($78) + 1|0);
  HEAP32[$1>>2] = $79;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 HEAP32[$value1>>2] = 0;
 __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($value1,$transfer);
 $80 = (($this) + 88|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = HEAP32[$value1>>2]|0;
 $83 = ($81|0)==($82|0);
 if (!($83)) {
  HEAP32[$80>>2] = $82;
  $84 = (($this) + 92|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)==(0|0);
  if (!($86)) {
   __ZN14SplatMaterials15UpdateMaterialsERK4PPtrIN5Unity8MaterialEE($85,$value1);
  }
 }
 $87 = (($this) + 128|0);
 $88 = HEAP32[$1>>2]|0;
 $89 = (($88) + 2|0);
 $90 = HEAP32[$4>>2]|0;
 $91 = ($89>>>0)>($90>>>0);
 if ($91) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$87,2);
  $$pre30 = HEAP32[$1>>2]|0;
  $$pre31 = HEAP32[$4>>2]|0;
  $95 = $$pre30;$97 = $$pre31;
 } else {
  $92 = HEAP16[$88>>1]|0;
  HEAP16[$87>>1] = $92;
  HEAP32[$1>>2] = $89;
  $95 = $89;$97 = $90;
 }
 $93 = (($87) + 2|0);
 $94 = (($95) + 2|0);
 $96 = ($94>>>0)>($97>>>0);
 if ($96) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$93,2);
 } else {
  $98 = HEAP16[$95>>1]|0;
  HEAP16[$93>>1] = $98;
  HEAP32[$1>>2] = $94;
 }
 $99 = (($this) + 96|0);
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($99,$transfer);
 $100 = (($this) + 112|0);
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($100,$transfer);
 $101 = (($this) + 164|0);
 $102 = HEAP32[$1>>2]|0;
 $103 = (($102) + 1|0);
 $104 = HEAP32[$4>>2]|0;
 $105 = ($103>>>0)>($104>>>0);
 if ($105) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$101,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  $109 = (($this) + 132|0);
  __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($109,$transfer);
  $110 = (($this) + 148|0);
  __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($110,$transfer);
  STACKTOP = sp;return;
 } else {
  $106 = HEAP8[$102>>0]|0;
  HEAP8[$101>>0] = $106;
  $107 = HEAP32[$1>>2]|0;
  $108 = (($107) + 1|0);
  HEAP32[$1>>2] = $108;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  $109 = (($this) + 132|0);
  __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($109,$transfer);
  $110 = (($this) + 148|0);
  __ZN8Vector4f8TransferI18StreamedBinaryReadILb0EEEEvRT_($110,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN7Terrain8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i24 = 0, $$pre$i$i$i29 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i32 = 0, $$pre$i$i$i37 = 0, $$pre$i$i$i38 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i15Z2D = 0, $$pre$phi$i$i$i20Z2D = 0, $$pre$phi$i$i$i25Z2D = 0, $$pre$phi$i$i$i30Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre40 = 0;
 var $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $$pre54 = 0, $$pre55 = 0, $$pre56 = 0, $$pre57 = 0, $$pre58 = 0, $$pre59 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $value = 0, $value1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp + 4|0;
 $value1 = sp;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 HEAP32[$value>>2] = 0;
 __ZN4PPtrI11TerrainDataE8TransferI18StreamedBinaryReadILb1EEEEvRT_($value,$transfer);
 __ZN7Terrain14SetTerrainDataERK4PPtrI11TerrainDataE($this,$value);
 $0 = (($this) + 60|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i = HEAP32[$0>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre40 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $0;$13 = $$pre;$15 = $$pre40;$9 = $$pre$i$i$i;
 } else {
  $7 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = (HEAPF32[tempDoublePtr>>2]=$7,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $0;$13 = $3;$15 = $5;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $10;
 $11 = (($this) + 64|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i3 = HEAP32[$11>>2]|0;
  $$pre41 = HEAP32[$1>>2]|0;
  $$pre42 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i4Z2D = $11;$18 = $$pre$i$i$i3;$22 = $$pre41;$24 = $$pre42;
 } else {
  $16 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$1>>2] = $12;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $11;$18 = $17;$22 = $12;$24 = $15;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $19;
 $20 = (($this) + 68|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,4);
  $$pre$i$i$i8 = HEAP32[$20>>2]|0;
  $$pre43 = HEAP32[$1>>2]|0;
  $$pre44 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i9Z2D = $20;$27 = $$pre$i$i$i8;$31 = $$pre43;$33 = $$pre44;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$1>>2] = $21;
  $26 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $20;$27 = $26;$31 = $21;$33 = $24;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $28;
 $29 = (($this) + 72|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$29,4);
  $$pre$i$i$i11 = HEAP32[$29>>2]|0;
  $$pre45 = HEAP32[$1>>2]|0;
  $$pre46 = HEAP32[$4>>2]|0;
  $35 = $$pre$i$i$i11;$39 = $$pre45;$41 = $$pre46;
 } else {
  $34 = HEAP32[$31>>2]|0;
  HEAP32[$29>>2] = $34;
  HEAP32[$1>>2] = $30;
  $35 = $34;$39 = $30;$41 = $33;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$29>>2] = $36;
 $37 = (($this) + 76|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$37,4);
  $$pre$i$i$i14 = HEAP32[$37>>2]|0;
  $$pre47 = HEAP32[$1>>2]|0;
  $$pre48 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i15Z2D = $37;$44 = $$pre$i$i$i14;$48 = $$pre47;$50 = $$pre48;
 } else {
  $42 = Math_fround(HEAPF32[$39>>2]);
  HEAPF32[$37>>2] = $42;
  HEAP32[$1>>2] = $38;
  $43 = (HEAPF32[tempDoublePtr>>2]=$42,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i15Z2D = $37;$44 = $43;$48 = $38;$50 = $41;
 }
 $45 = (_llvm_bswap_i32(($44|0))|0);
 HEAP32[$$pre$phi$i$i$i15Z2D>>2] = $45;
 $46 = (($this) + 80|0);
 $47 = (($48) + 4|0);
 $49 = ($47>>>0)>($50>>>0);
 if ($49) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$46,4);
  $$pre$i$i$i19 = HEAP32[$46>>2]|0;
  $$pre49 = HEAP32[$1>>2]|0;
  $$pre50 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i20Z2D = $46;$53 = $$pre$i$i$i19;$57 = $$pre49;$59 = $$pre50;
 } else {
  $51 = Math_fround(HEAPF32[$48>>2]);
  HEAPF32[$46>>2] = $51;
  HEAP32[$1>>2] = $47;
  $52 = (HEAPF32[tempDoublePtr>>2]=$51,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i20Z2D = $46;$53 = $52;$57 = $47;$59 = $50;
 }
 $54 = (_llvm_bswap_i32(($53|0))|0);
 HEAP32[$$pre$phi$i$i$i20Z2D>>2] = $54;
 $55 = (($this) + 48|0);
 $56 = (($57) + 4|0);
 $58 = ($56>>>0)>($59>>>0);
 if ($58) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$55,4);
  $$pre$i$i$i24 = HEAP32[$55>>2]|0;
  $$pre51 = HEAP32[$1>>2]|0;
  $$pre52 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i25Z2D = $55;$62 = $$pre$i$i$i24;$66 = $$pre51;$68 = $$pre52;
 } else {
  $60 = Math_fround(HEAPF32[$57>>2]);
  HEAPF32[$55>>2] = $60;
  HEAP32[$1>>2] = $56;
  $61 = (HEAPF32[tempDoublePtr>>2]=$60,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i25Z2D = $55;$62 = $61;$66 = $56;$68 = $59;
 }
 $63 = (_llvm_bswap_i32(($62|0))|0);
 HEAP32[$$pre$phi$i$i$i25Z2D>>2] = $63;
 $64 = (($this) + 56|0);
 $65 = (($66) + 4|0);
 $67 = ($65>>>0)>($68>>>0);
 if ($67) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$64,4);
  $$pre$i$i$i29 = HEAP32[$64>>2]|0;
  $$pre53 = HEAP32[$1>>2]|0;
  $$pre54 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$i30Z2D = $64;$71 = $$pre$i$i$i29;$75 = $$pre53;$77 = $$pre54;
 } else {
  $69 = Math_fround(HEAPF32[$66>>2]);
  HEAPF32[$64>>2] = $69;
  HEAP32[$1>>2] = $65;
  $70 = (HEAPF32[tempDoublePtr>>2]=$69,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i30Z2D = $64;$71 = $70;$75 = $65;$77 = $68;
 }
 $72 = (_llvm_bswap_i32(($71|0))|0);
 HEAP32[$$pre$phi$i$i$i30Z2D>>2] = $72;
 $73 = (($this) + 52|0);
 $74 = (($75) + 4|0);
 $76 = ($74>>>0)>($77>>>0);
 if ($76) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$73,4);
  $$pre$i$i$i32 = HEAP32[$73>>2]|0;
  $$pre55 = HEAP32[$1>>2]|0;
  $$pre56 = HEAP32[$4>>2]|0;
  $79 = $$pre$i$i$i32;$83 = $$pre55;$85 = $$pre56;
 } else {
  $78 = HEAP32[$75>>2]|0;
  HEAP32[$73>>2] = $78;
  HEAP32[$1>>2] = $74;
  $79 = $78;$83 = $74;$85 = $77;
 }
 $80 = (_llvm_bswap_i32(($79|0))|0);
 HEAP32[$73>>2] = $80;
 $81 = (($this) + 84|0);
 $82 = (($83) + 1|0);
 $84 = ($82>>>0)>($85>>>0);
 if ($84) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$81,1);
 } else {
  $86 = HEAP8[$83>>0]|0;
  HEAP8[$81>>0] = $86;
  $87 = HEAP32[$1>>2]|0;
  $88 = (($87) + 1|0);
  HEAP32[$1>>2] = $88;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $89 = (($this) + 85|0);
 $90 = HEAP32[$1>>2]|0;
 $91 = (($90) + 1|0);
 $92 = HEAP32[$4>>2]|0;
 $93 = ($91>>>0)>($92>>>0);
 if ($93) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$89,1);
  $$pre57 = HEAP32[$1>>2]|0;
  $99 = $$pre57;
 } else {
  $94 = HEAP8[$90>>0]|0;
  HEAP8[$89>>0] = $94;
  $95 = HEAP32[$1>>2]|0;
  $96 = (($95) + 1|0);
  HEAP32[$1>>2] = $96;
  $99 = $96;
 }
 $97 = (($this) + 86|0);
 $98 = (($99) + 1|0);
 $100 = HEAP32[$4>>2]|0;
 $101 = ($98>>>0)>($100>>>0);
 if ($101) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$97,1);
 } else {
  $102 = HEAP8[$99>>0]|0;
  HEAP8[$97>>0] = $102;
  $103 = HEAP32[$1>>2]|0;
  $104 = (($103) + 1|0);
  HEAP32[$1>>2] = $104;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 HEAP32[$value1>>2] = 0;
 __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($value1,$transfer);
 $105 = (($this) + 88|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = HEAP32[$value1>>2]|0;
 $108 = ($106|0)==($107|0);
 if (!($108)) {
  HEAP32[$105>>2] = $107;
  $109 = (($this) + 92|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = ($110|0)==(0|0);
  if (!($111)) {
   __ZN14SplatMaterials15UpdateMaterialsERK4PPtrIN5Unity8MaterialEE($110,$value1);
  }
 }
 $112 = (($this) + 128|0);
 $113 = HEAP32[$1>>2]|0;
 $114 = (($113) + 2|0);
 $115 = HEAP32[$4>>2]|0;
 $116 = ($114>>>0)>($115>>>0);
 if ($116) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$112,2);
  $$pre$i$i$i38 = HEAP16[$112>>1]|0;
  $$pre58 = HEAP32[$1>>2]|0;
  $$pre59 = HEAP32[$4>>2]|0;
  $119 = $$pre$i$i$i38;$126 = $$pre58;$128 = $$pre59;
 } else {
  $117 = HEAP16[$113>>1]|0;
  HEAP16[$112>>1] = $117;
  HEAP32[$1>>2] = $114;
  $119 = $117;$126 = $114;$128 = $115;
 }
 $118 = $119&65535;
 $120 = $118 << 8;
 $121 = $118 >>> 8;
 $122 = $120 | $121;
 $123 = $122&65535;
 HEAP16[$112>>1] = $123;
 $124 = (($112) + 2|0);
 $125 = (($126) + 2|0);
 $127 = ($125>>>0)>($128>>>0);
 if ($127) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$124,2);
  $$pre$i$i$i37 = HEAP16[$124>>1]|0;
  $131 = $$pre$i$i$i37;
 } else {
  $129 = HEAP16[$126>>1]|0;
  HEAP16[$124>>1] = $129;
  HEAP32[$1>>2] = $125;
  $131 = $129;
 }
 $130 = $131&65535;
 $132 = $130 << 8;
 $133 = $130 >>> 8;
 $134 = $132 | $133;
 $135 = $134&65535;
 HEAP16[$124>>1] = $135;
 $136 = (($this) + 96|0);
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($136,$transfer);
 $137 = (($this) + 112|0);
 __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($137,$transfer);
 $138 = (($this) + 164|0);
 $139 = HEAP32[$1>>2]|0;
 $140 = (($139) + 1|0);
 $141 = HEAP32[$4>>2]|0;
 $142 = ($140>>>0)>($141>>>0);
 if ($142) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$138,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  $146 = (($this) + 132|0);
  __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($146,$transfer);
  $147 = (($this) + 148|0);
  __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($147,$transfer);
  STACKTOP = sp;return;
 } else {
  $143 = HEAP8[$139>>0]|0;
  HEAP8[$138>>0] = $143;
  $144 = HEAP32[$1>>2]|0;
  $145 = (($144) + 1|0);
  HEAP32[$1>>2] = $145;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  $146 = (($this) + 132|0);
  __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($146,$transfer);
  $147 = (($this) + 148|0);
  __ZN8Vector4f8TransferI18StreamedBinaryReadILb1EEEEvRT_($147,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN7Terrain8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0;
 var $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $value = 0, $value1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $value = sp + 4|0;
 $value1 = sp;
 __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$value>>2] = $1;
 __ZN4PPtrI11TerrainDataE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($value,$transfer);
 $2 = (($this) + 60|0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)<($7>>>0);
 if ($8) {
  $9 = Math_fround(HEAPF32[$2>>2]);
  HEAPF32[$4>>2] = $9;
  HEAP32[$3>>2] = $5;
  $12 = $5;$14 = $7;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$2,4);
  $$pre = HEAP32[$3>>2]|0;
  $$pre13 = HEAP32[$6>>2]|0;
  $12 = $$pre;$14 = $$pre13;
 }
 $10 = (($this) + 64|0);
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)<($14>>>0);
 if ($13) {
  $15 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$12>>2] = $15;
  HEAP32[$3>>2] = $11;
  $18 = $11;$20 = $14;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$10,4);
  $$pre14 = HEAP32[$3>>2]|0;
  $$pre15 = HEAP32[$6>>2]|0;
  $18 = $$pre14;$20 = $$pre15;
 }
 $16 = (($this) + 68|0);
 $17 = (($18) + 4|0);
 $19 = ($17>>>0)<($20>>>0);
 if ($19) {
  $21 = Math_fround(HEAPF32[$16>>2]);
  HEAPF32[$18>>2] = $21;
  HEAP32[$3>>2] = $17;
  $24 = $17;$26 = $20;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$16,4);
  $$pre16 = HEAP32[$3>>2]|0;
  $$pre17 = HEAP32[$6>>2]|0;
  $24 = $$pre16;$26 = $$pre17;
 }
 $22 = (($this) + 72|0);
 $23 = (($24) + 4|0);
 $25 = ($23>>>0)<($26>>>0);
 if ($25) {
  $27 = HEAP32[$22>>2]|0;
  HEAP32[$24>>2] = $27;
  HEAP32[$3>>2] = $23;
  $30 = $23;$32 = $26;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$22,4);
  $$pre18 = HEAP32[$3>>2]|0;
  $$pre19 = HEAP32[$6>>2]|0;
  $30 = $$pre18;$32 = $$pre19;
 }
 $28 = (($this) + 76|0);
 $29 = (($30) + 4|0);
 $31 = ($29>>>0)<($32>>>0);
 if ($31) {
  $33 = Math_fround(HEAPF32[$28>>2]);
  HEAPF32[$30>>2] = $33;
  HEAP32[$3>>2] = $29;
  $36 = $29;$38 = $32;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$28,4);
  $$pre20 = HEAP32[$3>>2]|0;
  $$pre21 = HEAP32[$6>>2]|0;
  $36 = $$pre20;$38 = $$pre21;
 }
 $34 = (($this) + 80|0);
 $35 = (($36) + 4|0);
 $37 = ($35>>>0)<($38>>>0);
 if ($37) {
  $39 = Math_fround(HEAPF32[$34>>2]);
  HEAPF32[$36>>2] = $39;
  HEAP32[$3>>2] = $35;
  $42 = $35;$44 = $38;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$34,4);
  $$pre22 = HEAP32[$3>>2]|0;
  $$pre23 = HEAP32[$6>>2]|0;
  $42 = $$pre22;$44 = $$pre23;
 }
 $40 = (($this) + 48|0);
 $41 = (($42) + 4|0);
 $43 = ($41>>>0)<($44>>>0);
 if ($43) {
  $45 = Math_fround(HEAPF32[$40>>2]);
  HEAPF32[$42>>2] = $45;
  HEAP32[$3>>2] = $41;
  $48 = $41;$50 = $44;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$40,4);
  $$pre24 = HEAP32[$3>>2]|0;
  $$pre25 = HEAP32[$6>>2]|0;
  $48 = $$pre24;$50 = $$pre25;
 }
 $46 = (($this) + 56|0);
 $47 = (($48) + 4|0);
 $49 = ($47>>>0)<($50>>>0);
 if ($49) {
  $51 = Math_fround(HEAPF32[$46>>2]);
  HEAPF32[$48>>2] = $51;
  HEAP32[$3>>2] = $47;
  $54 = $47;$56 = $50;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$46,4);
  $$pre26 = HEAP32[$3>>2]|0;
  $$pre27 = HEAP32[$6>>2]|0;
  $54 = $$pre26;$56 = $$pre27;
 }
 $52 = (($this) + 52|0);
 $53 = (($54) + 4|0);
 $55 = ($53>>>0)<($56>>>0);
 if ($55) {
  $57 = HEAP32[$52>>2]|0;
  HEAP32[$54>>2] = $57;
  HEAP32[$3>>2] = $53;
  $60 = $53;$62 = $56;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$52,4);
  $$pre28 = HEAP32[$3>>2]|0;
  $$pre29 = HEAP32[$6>>2]|0;
  $60 = $$pre28;$62 = $$pre29;
 }
 $58 = (($this) + 84|0);
 $59 = (($60) + 1|0);
 $61 = ($59>>>0)<($62>>>0);
 if ($61) {
  $63 = HEAP8[$58>>0]|0;
  HEAP8[$60>>0] = $63;
  $64 = HEAP32[$3>>2]|0;
  $65 = (($64) + 1|0);
  HEAP32[$3>>2] = $65;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$58,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $66 = (($this) + 85|0);
 $67 = HEAP32[$3>>2]|0;
 $68 = (($67) + 1|0);
 $69 = HEAP32[$6>>2]|0;
 $70 = ($68>>>0)<($69>>>0);
 if ($70) {
  $71 = HEAP8[$66>>0]|0;
  HEAP8[$67>>0] = $71;
  $72 = HEAP32[$3>>2]|0;
  $73 = (($72) + 1|0);
  HEAP32[$3>>2] = $73;
  $76 = $73;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$66,1);
  $$pre30 = HEAP32[$3>>2]|0;
  $76 = $$pre30;
 }
 $74 = (($this) + 86|0);
 $75 = (($76) + 1|0);
 $77 = HEAP32[$6>>2]|0;
 $78 = ($75>>>0)<($77>>>0);
 if ($78) {
  $79 = HEAP8[$74>>0]|0;
  HEAP8[$76>>0] = $79;
  $80 = HEAP32[$3>>2]|0;
  $81 = (($80) + 1|0);
  HEAP32[$3>>2] = $81;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$74,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $82 = (($this) + 88|0);
 $83 = HEAP32[$82>>2]|0;
 HEAP32[$value1>>2] = $83;
 __ZN4PPtrIN5Unity8MaterialEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($value1,$transfer);
 $84 = (($this) + 128|0);
 $85 = HEAP32[$3>>2]|0;
 $86 = (($85) + 2|0);
 $87 = HEAP32[$6>>2]|0;
 $88 = ($86>>>0)<($87>>>0);
 if ($88) {
  $89 = HEAP16[$84>>1]|0;
  HEAP16[$85>>1] = $89;
  HEAP32[$3>>2] = $86;
  $92 = $86;$94 = $87;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$84,2);
  $$pre31 = HEAP32[$3>>2]|0;
  $$pre32 = HEAP32[$6>>2]|0;
  $92 = $$pre31;$94 = $$pre32;
 }
 $90 = (($84) + 2|0);
 $91 = (($92) + 2|0);
 $93 = ($91>>>0)<($94>>>0);
 if ($93) {
  $95 = HEAP16[$90>>1]|0;
  HEAP16[$92>>1] = $95;
  HEAP32[$3>>2] = $91;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$90,2);
 }
 $96 = (($this) + 96|0);
 __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($96,$transfer);
 $97 = (($this) + 112|0);
 __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($97,$transfer);
 $98 = (($this) + 164|0);
 $99 = HEAP32[$3>>2]|0;
 $100 = (($99) + 1|0);
 $101 = HEAP32[$6>>2]|0;
 $102 = ($100>>>0)<($101>>>0);
 if ($102) {
  $103 = HEAP8[$98>>0]|0;
  HEAP8[$99>>0] = $103;
  $104 = HEAP32[$3>>2]|0;
  $105 = (($104) + 1|0);
  HEAP32[$3>>2] = $105;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  $106 = (($this) + 132|0);
  __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($106,$transfer);
  $107 = (($this) + 148|0);
  __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($107,$transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($3,$98,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  $106 = (($this) + 132|0);
  __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($106,$transfer);
  $107 = (($this) + 148|0);
  __ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_($107,$transfer);
  STACKTOP = sp;return;
 }
}
function __ZN7TerrainD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((801408 + 8|0));
 $1 = (($this) + 208|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 if (!($3)) {
  __ZN9BehaviourD2Ev($this);
  STACKTOP = sp;return;
 }
 $4 = (($this) + 196|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 200|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($5|0),($$byval_copy|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  HEAP32[$4>>2] = 0;
  __ZN9BehaviourD2Ev($this);
  STACKTOP = sp;return;
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN7TerrainD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((801408 + 8|0));
 $1 = (($this) + 208|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(-1);
 do {
  if ($3) {
   $4 = (($this) + 196|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($this) + 200|0);
   $7 = HEAP32[$6>>2]|0;
   HEAP32[$0>>2] = $7;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($5|0),($$byval_copy|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    HEAP32[$4>>2] = 0;
    break;
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3410,($this|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $14 = ___cxa_find_matching_catch(0|0)|0;
    $15 = tempRet0;
    ___clang_call_terminate($14);
    // unreachable;
   } else {
    $eh$lpad$body$index2Z2D = $11;$eh$lpad$body$indexZ2D = $10;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3410,($this|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $eh$lpad$body$index2Z2D = $19;$eh$lpad$body$indexZ2D = $18;
 __ZdlPv($this);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN4PPtrI11TerrainDataE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN4PPtrI11TerrainDataE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI11TerrainDataE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI11TerrainDataE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,802056,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,802072,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,802056,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,802072,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN14DetailRendererD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3710,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $13 = (($this) + 56|0);
  $14 = (($this) + 60|0);
  $15 = HEAP32[$14>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($13,$15);
  $16 = (($this) + 44|0);
  $17 = (($this) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($16,$18);
  $19 = (($this) + 32|0);
  $20 = (($this) + 36|0);
  $21 = HEAP32[$20>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($19,$21);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $2 = (($this) + 56|0);
  $3 = (($this) + 60|0);
  $4 = HEAP32[$3>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($2,$4);
  $5 = (($this) + 44|0);
  $6 = (($this) + 48|0);
  $7 = HEAP32[$6>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($5,$7);
  $8 = (($this) + 32|0);
  $9 = (($this) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE7destroyEPNS_11__tree_nodeIS3_PvEE($8,$10);
  STACKTOP = sp;return;
 }
}
function __ZNK11TerrainData7HasUserEPN5Unity10GameObjectE($this,$user) {
 $this = $this|0;
 $user = $user|0;
 var $$ = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($user|0)==(0|0);
 if ($0) {
  $17 = 0;
 } else {
  $1 = (($user) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  $17 = $2;
 }
 $3 = (($this) + 328|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 332|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 $8 = $4;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10|0)==(0);
 if ($11) {
  $22 = $4;
 } else {
  $14 = $4;$__len$03$i$i$i$i$i = $10;
  while(1) {
   $12 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $13 = (($14) + ($12<<2)|0);
   $15 = HEAP32[$13>>2]|0;
   $16 = ($15|0)<($17|0);
   if ($16) {
    $$sum$i$i$i$i$i = (($12) + 1)|0;
    $18 = (($14) + ($$sum$i$i$i$i$i<<2)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $19 = (($$neg2$i$i$i$i$i) - ($12))|0;
    $27 = $18;$__len$0$be$i$i$i$i$i = $19;
   } else {
    $27 = $14;$__len$0$be$i$i$i$i$i = $12;
   }
   $20 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($20) {
    $22 = $27;
    break;
   } else {
    $14 = $27;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $21 = ($22|0)==($6|0);
 if ($21) {
  $26 = $6;
  $25 = ($26|0)!=($6|0);
  STACKTOP = sp;return ($25|0);
 }
 $23 = HEAP32[$22>>2]|0;
 $24 = ($17|0)<($23|0);
 $$ = $24 ? $6 : $22;
 $26 = $$;
 $25 = ($26|0)!=($6|0);
 STACKTOP = sp;return ($25|0);
}
function __ZN11TerrainData7AddUserEPN5Unity10GameObjectE($this,$user) {
 $this = $this|0;
 $user = $user|0;
 var $$byval_copy = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 328|0);
 $4 = ($user|0)==(0|0);
 if ($4) {
  HEAP32[$2>>2] = 0;
  $20 = 0;
 } else {
  $5 = (($user) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$2>>2] = $6;
  $20 = $6;
 }
 $7 = HEAP32[$3>>2]|0;
 $8 = (($this) + 332|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = $7;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($13|0)==(0);
 if ($14) {
  $25 = $7;
 } else {
  $17 = $7;$__len$03$i$i$i$i$i = $13;
  while(1) {
   $15 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $16 = (($17) + ($15<<2)|0);
   $18 = HEAP32[$16>>2]|0;
   $19 = ($18|0)<($20|0);
   if ($19) {
    $$sum$i$i$i$i$i = (($15) + 1)|0;
    $21 = (($17) + ($$sum$i$i$i$i$i<<2)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $22 = (($$neg2$i$i$i$i$i) - ($15))|0;
    $28 = $21;$__len$0$be$i$i$i$i$i = $22;
   } else {
    $28 = $17;$__len$0$be$i$i$i$i$i = $15;
   }
   $23 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($23) {
    $25 = $28;
    break;
   } else {
    $17 = $28;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $24 = ($25|0)==($9|0);
 if (!($24)) {
  $26 = HEAP32[$25>>2]|0;
  $27 = ($20|0)<($26|0);
  if (!($27)) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$1>>2] = $25;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__16vectorI4PPtrIN5Unity10GameObjectEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE6insertENS_11__wrap_iterIPKS4_EERSA_($0,$3,$$byval_copy,$2);
 STACKTOP = sp;return;
}
function __ZN11TerrainData10RemoveUserEPN5Unity10GameObjectE($this,$user) {
 $this = $this|0;
 $user = $user|0;
 var $$0$lcssa$i$i$i$i$i = 0, $$012$i$i$i$i$i = 0, $$03$i$i$i$i$i = 0, $$neg2$i$i$i$i$i = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum5$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__first5$i$i$i$i$i = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i1$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep7$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep6$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($user|0)==(0|0);
 if ($0) {
  $17 = 0;
 } else {
  $1 = (($user) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  $17 = $2;
 }
 $3 = (($this) + 328|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 332|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 $8 = $4;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10|0)==(0);
 if ($11) {
  $22 = $4;
 } else {
  $14 = $4;$__len$03$i$i$i$i$i = $10;
  while(1) {
   $12 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
   $13 = (($14) + ($12<<2)|0);
   $15 = HEAP32[$13>>2]|0;
   $16 = ($15|0)<($17|0);
   if ($16) {
    $$sum$i$i$i$i$i = (($12) + 1)|0;
    $18 = (($14) + ($$sum$i$i$i$i$i<<2)|0);
    $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
    $19 = (($$neg2$i$i$i$i$i) - ($12))|0;
    $41 = $18;$__len$0$be$i$i$i$i$i = $19;
   } else {
    $41 = $14;$__len$0$be$i$i$i$i$i = $12;
   }
   $20 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($20) {
    $22 = $41;
    break;
   } else {
    $14 = $41;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $21 = ($22|0)==($6|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $23 = HEAP32[$22>>2]|0;
 $24 = ($17|0)<($23|0);
 if ($24) {
  STACKTOP = sp;return;
 }
 $25 = $22;
 $26 = (($25) - ($8))|0;
 $27 = $26 >> 2;
 $28 = (($4) + ($27<<2)|0);
 $$sum$i$i$i = (($27) + 1)|0;
 $29 = (($4) + ($$sum$i$i$i<<2)|0);
 $30 = ($29|0)==($6|0);
 if ($30) {
  $$0$lcssa$i$i$i$i$i = $28;
 } else {
  $scevgep$i$i1$i$i$i = (($6) + -4|0);
  $$012$i$i$i$i$i = $29;$$03$i$i$i$i$i = $28;
  while(1) {
   $31 = HEAP32[$$012$i$i$i$i$i>>2]|0;
   HEAP32[$$03$i$i$i$i$i>>2] = $31;
   $32 = (($$012$i$i$i$i$i) + 4|0);
   $33 = (($$03$i$i$i$i$i) + 4|0);
   $34 = ($32|0)==($6|0);
   if ($34) {
    break;
   } else {
    $$012$i$i$i$i$i = $32;$$03$i$i$i$i$i = $33;
   }
  }
  $__first5$i$i$i$i$i = $29;
  $35 = (0 - ($__first5$i$i$i$i$i))|0;
  $uglygep$i$i3$i$i$i = (($scevgep$i$i1$i$i$i) + ($35)|0);
  $uglygep6$i$i$i$i$i = $uglygep$i$i3$i$i$i;
  $36 = $uglygep6$i$i$i$i$i >>> 2;
  $$sum5$i$i$i = (($36) + ($$sum$i$i$i))|0;
  $scevgep7$i$i$i$i$i = (($4) + ($$sum5$i$i$i<<2)|0);
  $$0$lcssa$i$i$i$i$i = $scevgep7$i$i$i$i$i;
 }
 $37 = ($6|0)==($$0$lcssa$i$i$i$i$i|0);
 if ($37) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i$i$i = $$0$lcssa$i$i$i$i$i;
 $scevgep$i$i$i$i$i = (($6) + -4|0);
 $38 = (0 - ($__new_last2$i$i$i$i$i))|0;
 $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($38)|0);
 $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
 $39 = $uglygep3$i$i$i$i$i >>> 2;
 $40 = $39 ^ -1;
 $scevgep4$i$i$i$i$i = (($6) + ($40<<2)|0);
 HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI4PPtrIN5Unity10GameObjectEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE6insertENS_11__wrap_iterIPKS4_EERSA_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i18 = 0, $$0$i19 = 0, $$01$i$i = 0, $$01$i7$i = 0, $$012$i$i$i16 = 0, $$03$i$i$i15 = 0, $$byval_copy4 = 0, $$sum = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__begin13$i1$i = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, $scevgep$i$i = 0, $scevgep$i2$i = 0, $scevgep5$i$i = 0, $scevgep5$i8$i = 0, $uglygep$i$i = 0, $uglygep$i4$i = 0, $uglygep4$i$i = 0, $uglygep4$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = HEAP32[$__position>>2]|0;
 $4 = $3;
 $5 = $2;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($2) + ($7<<2)|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = ($8|0)==($10|0);
  if ($14) {
   $15 = ($8|0)==(0|0);
   if (!($15)) {
    $16 = HEAP32[$__x>>2]|0;
    HEAP32[$8>>2] = $16;
   }
   $$sum25 = (($7) + 1)|0;
   $17 = (($2) + ($$sum25<<2)|0);
   HEAP32[$9>>2] = $17;
   $__p$0 = $8;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($7) + 1)|0;
  $18 = (($2) + ($$sum<<2)|0);
  $19 = $10;
  $20 = $18;
  $21 = (($19) - ($20))|0;
  $22 = $21 >> 2;
  $$sum23 = (($22) + ($7))|0;
  $23 = (($2) + ($$sum23<<2)|0);
  $24 = ($23>>>0)<($10>>>0);
  if ($24) {
   $26 = $10;$__i$01$i = $23;
   while(1) {
    $25 = ($26|0)==(0|0);
    if (!($25)) {
     $27 = HEAP32[$__i$01$i>>2]|0;
     HEAP32[$26>>2] = $27;
    }
    $28 = (($__i$01$i) + 4|0);
    $29 = (($26) + 4|0);
    $30 = ($28>>>0)<($10>>>0);
    if ($30) {
     $26 = $29;$__i$01$i = $28;
    } else {
     break;
    }
   }
   HEAP32[$9>>2] = $29;
   $38 = $29;
  } else {
   $38 = $10;
  }
  $31 = ($22|0)==(0);
  if (!($31)) {
   $$012$i$i$i16 = $23;$$03$i$i$i15 = $10;
   while(1) {
    $32 = (($$03$i$i$i15) + -4|0);
    $33 = (($$012$i$i$i16) + -4|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $34;
    $35 = ($33|0)==($8|0);
    if ($35) {
     break;
    } else {
     $$012$i$i$i16 = $33;$$03$i$i$i15 = $32;
    }
   }
  }
  $36 = ($8>>>0)>($__x>>>0);
  if ($36) {
   $__xr$0 = $__x;
  } else {
   $37 = ($38>>>0)>($__x>>>0);
   $39 = (($__x) + 4|0);
   $$ = $37 ? $39 : $__x;
   $__xr$0 = $$;
  }
  $40 = HEAP32[$__xr$0>>2]|0;
  HEAP32[$8>>2] = $40;
  $__p$0 = $8;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $41 = $10;
 $42 = (($41) - ($5))|0;
 $43 = $42 >> 2;
 $44 = (($43) + 1)|0;
 $45 = ($44|0)<(0);
 if ($45) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $46 = $12;
 $47 = (($46) - ($5))|0;
 $48 = $47 >> 2;
 $49 = ($48>>>0)<(1073741823);
 if ($49) {
  $52 = $47 >> 1;
  $53 = ($52>>>0)<($44>>>0);
  $54 = $53 ? $44 : $52;
  $55 = $8;
  $56 = $6 >> 2;
  $57 = ($54|0)==(0);
  if ($57) {
   $$0$i19 = 0;$102 = $55;$61 = 0;$62 = $56;
  } else {
   $$0$i18 = $54;$124 = $56;$125 = $55;
   label = 21;
  }
 } else {
  $50 = $8;
  $51 = $6 >> 2;
  $$0$i18 = 2147483647;$124 = $51;$125 = $50;
  label = 21;
 }
 if ((label|0) == 21) {
  $58 = $$0$i18 << 2;
  HEAP32[$0>>2] = 55;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $59 = (__Z15malloc_internaljj10MemLabelIdiPKci($58,16,$$byval_copy4,0,802168,79)|0);
  $$0$i19 = $$0$i18;$102 = $125;$61 = $59;$62 = $124;
 }
 $60 = (($61) + ($62<<2)|0);
 $63 = (($61) + ($$0$i19<<2)|0);
 $64 = ($62|0)==($$0$i19|0);
 do {
  if ($64) {
   $65 = ($62|0)>(0);
   if ($65) {
    $66 = (($62) + 1)|0;
    $67 = (($66|0) / -2)&-1;
    $$sum22 = (($67) + ($62))|0;
    $68 = (($61) + ($$sum22<<2)|0);
    $111 = $63;$85 = $68;
    break;
   }
   $69 = $62 << 1;
   $70 = ($62|0)==(0);
   $71 = $70 ? 1 : $69;
   $72 = $71 << 2;
   HEAP32[$0>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   $73 = (invoke_iiiiiii(102,($72|0),16,($$byval_copy4|0),0,(802168|0),79)|0);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if (!($75)) {
    $76 = $71 >>> 2;
    $77 = (($73) + ($76<<2)|0);
    $78 = (($73) + ($71<<2)|0);
    $79 = ($61|0)==(0|0);
    if ($79) {
     $111 = $78;$85 = $77;
     break;
    }
    HEAP32[$0>>2] = 55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($61|0),($$byval_copy4|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if (!($81)) {
     $111 = $78;$85 = $77;
     break;
    }
    $82 = ___cxa_find_matching_catch()|0;
    $83 = tempRet0;
    ___cxa_call_unexpected(($82|0));
    // unreachable;
   }
   $117 = ___cxa_find_matching_catch()|0;
   $118 = tempRet0;
   $119 = ($61|0)==(0|0);
   if ($119) {
    ___resumeException($117|0);
    // unreachable;
   }
   HEAP32[$1>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($61|0),($$byval_copy4|0));
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    ___cxa_call_unexpected(($122|0));
    // unreachable;
   } else {
    ___resumeException($117|0);
    // unreachable;
   }
  } else {
   $111 = $63;$85 = $60;
  }
 } while(0);
 $84 = ($85|0)==(0|0);
 if (!($84)) {
  $86 = HEAP32[$__x>>2]|0;
  HEAP32[$85>>2] = $86;
 }
 $87 = (($85) + 4|0);
 $88 = HEAP32[$this>>2]|0;
 $89 = ($88|0)==($8|0);
 if ($89) {
  $109 = $85;
 } else {
  $__begin13$i1$i = $88;
  $$sum20 = (($7) + -1)|0;
  $scevgep$i2$i = (($2) + ($$sum20<<2)|0);
  $90 = (0 - ($__begin13$i1$i))|0;
  $uglygep$i4$i = (($scevgep$i2$i) + ($90)|0);
  $uglygep4$i5$i = $uglygep$i4$i;
  $$01$i7$i = $8;$94 = $85;
  while(1) {
   $91 = (($$01$i7$i) + -4|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = (($94) + -4|0);
   HEAP32[$93>>2] = $92;
   $95 = (($94) + -4|0);
   $96 = ($91|0)==($88|0);
   if ($96) {
    break;
   } else {
    $$01$i7$i = $91;$94 = $95;
   }
  }
  $97 = $uglygep4$i5$i >>> 2;
  $98 = $97 ^ -1;
  $scevgep5$i8$i = (($85) + ($98<<2)|0);
  $109 = $scevgep5$i8$i;
 }
 $99 = HEAP32[$9>>2]|0;
 $100 = ($99|0)==($8|0);
 if ($100) {
  $110 = $87;
 } else {
  $scevgep$i$i = (($99) + -4|0);
  $101 = (0 - ($102))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($101)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $8;$104 = $87;
  while(1) {
   $103 = HEAP32[$$01$i$i>>2]|0;
   HEAP32[$104>>2] = $103;
   $105 = (($$01$i$i) + 4|0);
   $106 = (($104) + 4|0);
   $107 = ($105|0)==($99|0);
   if ($107) {
    break;
   } else {
    $$01$i$i = $105;$104 = $106;
   }
  }
  $108 = $uglygep4$i$i >>> 2;
  $$sum21 = (($108) + 2)|0;
  $scevgep5$i$i = (($85) + ($$sum21<<2)|0);
  $110 = $scevgep5$i$i;
 }
 HEAP32[$this>>2] = $109;
 HEAP32[$9>>2] = $110;
 HEAP32[$11>>2] = $111;
 $112 = ($88|0)==(0|0);
 if ($112) {
  $__p$0 = $85;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($88|0),($$byval_copy4|0));
 $113 = __THREW__; __THREW__ = 0;
 $114 = $113&1;
 if ($114) {
  $115 = ___cxa_find_matching_catch()|0;
  $116 = tempRet0;
  ___cxa_call_unexpected(($115|0));
  // unreachable;
 } else {
  $__p$0 = $85;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
}
function __ZL21InitializeCachedStripv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $i$01 = 0;
 while(1) {
  HEAP32[$0>>2] = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $1 = (__Znwj10MemLabelIdbiPKci(8,$$byval_copy,0,16,802176,31)|0);
  HEAP32[$1>>2] = 0;
  $2 = (($1) + 4|0);
  HEAP32[$2>>2] = 0;
  $3 = (802184 + ($i$01<<2)|0);
  HEAP32[$3>>2] = $1;
  $4 = (($i$01) + 1)|0;
  $exitcond = ($4|0)==(16);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZL18DestroyCachedStripv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $i$03 = 0;
 while(1) {
  $2 = (802184 + ($i$03<<2)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($3) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(0|0);
   if (!($7)) {
    $8 = HEAP32[628248>>2]|0;
    HEAP32[$0>>2] = $8;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy1);
   }
  }
  HEAP32[$1>>2] = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy1);
  HEAP32[$2>>2] = 0;
  $9 = (($i$03) + 1)|0;
  $exitcond = ($9|0)==(16);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZN21TerrainIndexGenerator14GetIndexBufferEiRji($edgeMask,$count,$stride) {
 $edgeMask = $edgeMask|0;
 $count = $count|0;
 $stride = $stride|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$0 = 0, $index$1 = 0;
 var $index$2 = 0, $index$3 = 0, $index$4 = 0, $index$5 = 0, $index$6 = 0, $index$8$ph = 0, $index$87$us = 0, $index$94$us = 0, $maxX$0 = 0, $maxY$0 = 0, $minX$0 = 0, $minY$0 = 0, $smax = 0, $split11 = 0, $x$05$us = 0, $y$08$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628248>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Z15malloc_internaljj10MemLabelIdiPKci(6936,16,$$byval_copy,0,802176,47)|0);
 $3 = $edgeMask & 1;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (__ZL18AddSliverTrianglesPjjii($2,0,0,$edgeMask)|0);
  $index$0 = $5;$minX$0 = 1;
 } else {
  $index$0 = 0;$minX$0 = 0;
 }
 $6 = $edgeMask & 2;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (__ZL18AddSliverTrianglesPjjii($2,$index$0,1,$edgeMask)|0);
  $index$1 = $8;$maxX$0 = 15;
 } else {
  $index$1 = $index$0;$maxX$0 = 16;
 }
 $9 = $edgeMask & 4;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = (__ZL18AddSliverTrianglesPjjii($2,$index$1,2,$edgeMask)|0);
  $index$2 = $11;$maxY$0 = 15;
 } else {
  $index$2 = $index$1;$maxY$0 = 16;
 }
 $12 = $edgeMask & 8;
 $13 = ($12|0)==(0);
 if ($13) {
  $14 = (__ZL18AddSliverTrianglesPjjii($2,$index$2,3,$edgeMask)|0);
  $index$3 = $14;$minY$0 = 1;
 } else {
  $index$3 = $index$2;$minY$0 = 0;
 }
 $15 = $edgeMask & 5;
 $16 = ($15|0)==(5);
 if ($16) {
  $index$4 = $index$3;
 } else {
  $17 = (__ZL15AddSliverCornerPjjii($2,$index$3,0,$edgeMask)|0);
  $index$4 = $17;
 }
 $18 = $edgeMask & 6;
 $19 = ($18|0)==(6);
 if ($19) {
  $index$5 = $index$4;
 } else {
  $20 = (__ZL15AddSliverCornerPjjii($2,$index$4,1,$edgeMask)|0);
  $index$5 = $20;
 }
 $21 = $edgeMask & 9;
 $22 = ($21|0)==(9);
 if ($22) {
  $index$6 = $index$5;
 } else {
  $23 = (__ZL15AddSliverCornerPjjii($2,$index$5,2,$edgeMask)|0);
  $index$6 = $23;
 }
 $24 = $edgeMask & 10;
 $25 = ($24|0)==(10);
 if ($25) {
  $index$8$ph = $index$6;
 } else {
  $26 = (__ZL15AddSliverCornerPjjii($2,$index$6,3,$edgeMask)|0);
  $index$8$ph = $26;
 }
 $27 = ($minX$0>>>0)<($maxX$0>>>0);
 if (!($27)) {
  $split11 = $index$8$ph;
  HEAP32[$count>>2] = $split11;
  STACKTOP = sp;return ($2|0);
 }
 $28 = (($minX$0) + 1)|0;
 $29 = ($maxX$0>>>0)>($28>>>0);
 $smax = $29 ? $maxX$0 : $28;
 $30 = ($smax*6)|0;
 $31 = (0 - ($minX$0))|0;
 $32 = $31 & 6;
 $33 = (($30) - ($32))|0;
 $index$87$us = $index$8$ph;$y$08$us = $minY$0;
 while(1) {
  $36 = (($y$08$us) + 1)|0;
  $index$94$us = $index$87$us;$x$05$us = $minX$0;
  while(1) {
   $37 = ($x$05$us*17)|0;
   $38 = (($37) + ($y$08$us))|0;
   $39 = (($index$94$us) + 1)|0;
   $40 = (($2) + ($index$94$us<<2)|0);
   HEAP32[$40>>2] = $38;
   $41 = (($37) + ($36))|0;
   $42 = (($index$94$us) + 2)|0;
   $43 = (($2) + ($39<<2)|0);
   HEAP32[$43>>2] = $41;
   $44 = (($x$05$us) + 1)|0;
   $45 = ($44*17)|0;
   $46 = (($45) + ($36))|0;
   $47 = (($index$94$us) + 3)|0;
   $48 = (($2) + ($42<<2)|0);
   HEAP32[$48>>2] = $46;
   $49 = (($index$94$us) + 4)|0;
   $50 = (($2) + ($47<<2)|0);
   HEAP32[$50>>2] = $38;
   $51 = (($index$94$us) + 5)|0;
   $52 = (($2) + ($49<<2)|0);
   HEAP32[$52>>2] = $46;
   $53 = (($45) + ($y$08$us))|0;
   $54 = (($index$94$us) + 6)|0;
   $55 = (($2) + ($51<<2)|0);
   HEAP32[$55>>2] = $53;
   $56 = ($44|0)<($maxX$0|0);
   if ($56) {
    $index$94$us = $54;$x$05$us = $44;
   } else {
    break;
   }
  }
  $34 = (($33) + ($index$87$us))|0;
  $35 = ($36|0)<($maxY$0|0);
  if ($35) {
   $index$87$us = $34;$y$08$us = $36;
  } else {
   $split11 = $34;
   break;
  }
 }
 HEAP32[$count>>2] = $split11;
 STACKTOP = sp;return ($2|0);
}
function __ZL18AddSliverTrianglesPjjii($triangles,$index,$direction,$edgeMask) {
 $triangles = $triangles|0;
 $index = $index|0;
 $direction = $direction|0;
 $edgeMask = $edgeMask|0;
 var $$011 = 0, $$1 = 0, $$22 = 0, $$22$us = 0, $$22$us3 = 0, $$3 = 0, $$3$us = 0, $$3$us5 = 0, $$4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $exitcond = 0, $i$01 = 0;
 var $i$01$us = 0, $i$01$us4 = 0, $y$010 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 1 << $direction;
 $1 = $0 & $edgeMask;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$011 = $index;$y$010 = 2;
  while(1) {
   if ((($direction|0) == 2)) {
    $84 = ($y$010*17)|0;
    $85 = (($84) + 15)|0;
    $86 = (($$011) + 1)|0;
    $87 = (($triangles) + ($$011<<2)|0);
    HEAP32[$87>>2] = $85;
    $88 = (($84) + 16)|0;
    $89 = (($$011) + 2)|0;
    $90 = (($triangles) + ($86<<2)|0);
    HEAP32[$90>>2] = $88;
    $91 = (($84) + 33)|0;
    $92 = (($$011) + 3)|0;
    $93 = (($triangles) + ($89<<2)|0);
    HEAP32[$93>>2] = $91;
    $94 = (($$011) + 4)|0;
    $95 = (($triangles) + ($92<<2)|0);
    HEAP32[$95>>2] = $85;
    $96 = (($$011) + 5)|0;
    $97 = (($triangles) + ($94<<2)|0);
    HEAP32[$97>>2] = $91;
    $98 = (($84) + 32)|0;
    $99 = (($$011) + 6)|0;
    $100 = (($triangles) + ($96<<2)|0);
    HEAP32[$100>>2] = $98;
    $$1 = $99;
   } else if ((($direction|0) == 1)) {
    $68 = (($y$010) + 255)|0;
    $69 = (($$011) + 1)|0;
    $70 = (($triangles) + ($$011<<2)|0);
    HEAP32[$70>>2] = $68;
    $71 = (($y$010) + 256)|0;
    $72 = (($$011) + 2)|0;
    $73 = (($triangles) + ($69<<2)|0);
    HEAP32[$73>>2] = $71;
    $74 = (($y$010) + 273)|0;
    $75 = (($$011) + 3)|0;
    $76 = (($triangles) + ($72<<2)|0);
    HEAP32[$76>>2] = $74;
    $77 = (($$011) + 4)|0;
    $78 = (($triangles) + ($75<<2)|0);
    HEAP32[$78>>2] = $68;
    $79 = (($$011) + 5)|0;
    $80 = (($triangles) + ($77<<2)|0);
    HEAP32[$80>>2] = $74;
    $81 = (($y$010) + 272)|0;
    $82 = (($$011) + 6)|0;
    $83 = (($triangles) + ($79<<2)|0);
    HEAP32[$83>>2] = $81;
    $$1 = $82;
   } else if ((($direction|0) == 0)) {
    $53 = (($$011) + 1)|0;
    $54 = (($triangles) + ($$011<<2)|0);
    HEAP32[$54>>2] = $y$010;
    $55 = (($y$010) + 1)|0;
    $56 = (($$011) + 2)|0;
    $57 = (($triangles) + ($53<<2)|0);
    HEAP32[$57>>2] = $55;
    $58 = (($y$010) + 18)|0;
    $59 = (($$011) + 3)|0;
    $60 = (($triangles) + ($56<<2)|0);
    HEAP32[$60>>2] = $58;
    $61 = (($$011) + 4)|0;
    $62 = (($triangles) + ($59<<2)|0);
    HEAP32[$62>>2] = $y$010;
    $63 = (($$011) + 5)|0;
    $64 = (($triangles) + ($61<<2)|0);
    HEAP32[$64>>2] = $58;
    $65 = (($y$010) + 17)|0;
    $66 = (($$011) + 6)|0;
    $67 = (($triangles) + ($63<<2)|0);
    HEAP32[$67>>2] = $65;
    $$1 = $66;
   } else if ((($direction|0) == 3)) {
    $101 = ($y$010*17)|0;
    $102 = (($$011) + 1)|0;
    $103 = (($triangles) + ($$011<<2)|0);
    HEAP32[$103>>2] = $101;
    $104 = (($101) + 1)|0;
    $105 = (($$011) + 2)|0;
    $106 = (($triangles) + ($102<<2)|0);
    HEAP32[$106>>2] = $104;
    $107 = (($101) + 17)|0;
    $108 = (($101) + 18)|0;
    $109 = (($$011) + 3)|0;
    $110 = (($triangles) + ($105<<2)|0);
    HEAP32[$110>>2] = $108;
    $111 = (($$011) + 4)|0;
    $112 = (($triangles) + ($109<<2)|0);
    HEAP32[$112>>2] = $101;
    $113 = (($$011) + 5)|0;
    $114 = (($triangles) + ($111<<2)|0);
    HEAP32[$114>>2] = $108;
    $115 = (($$011) + 6)|0;
    $116 = (($triangles) + ($113<<2)|0);
    HEAP32[$116>>2] = $107;
    $$1 = $115;
   } else {
    $$1 = $$011;
   }
   $117 = (($y$010) + 1)|0;
   $exitcond = ($117|0)==(14);
   if ($exitcond) {
    $$4 = $$1;
    break;
   } else {
    $$011 = $$1;$y$010 = $117;
   }
  }
  STACKTOP = sp;return ($$4|0);
 }
 if ((($direction|0) == 1)) {
  $$22$us3 = $index;$i$01$us4 = 2;
  while(1) {
   $28 = (($i$01$us4) + 255)|0;
   $29 = (($$22$us3) + 1)|0;
   $30 = (($triangles) + ($$22$us3<<2)|0);
   HEAP32[$30>>2] = $28;
   $31 = $i$01$us4 | 1;
   $32 = (($31) + 255)|0;
   $33 = (($$22$us3) + 2)|0;
   $34 = (($triangles) + ($29<<2)|0);
   HEAP32[$34>>2] = $32;
   $35 = (($i$01$us4) + 272)|0;
   $36 = (($$22$us3) + 3)|0;
   $37 = (($triangles) + ($33<<2)|0);
   HEAP32[$37>>2] = $35;
   $38 = (($$22$us3) + 4)|0;
   $39 = (($triangles) + ($36<<2)|0);
   HEAP32[$39>>2] = $35;
   $40 = (($$22$us3) + 5)|0;
   $41 = (($triangles) + ($38<<2)|0);
   HEAP32[$41>>2] = $32;
   $42 = (($i$01$us4) + 274)|0;
   $43 = (($$22$us3) + 6)|0;
   $44 = (($triangles) + ($40<<2)|0);
   HEAP32[$44>>2] = $42;
   $45 = (($$22$us3) + 7)|0;
   $46 = (($triangles) + ($43<<2)|0);
   HEAP32[$46>>2] = $42;
   $47 = (($$22$us3) + 8)|0;
   $48 = (($triangles) + ($45<<2)|0);
   HEAP32[$48>>2] = $32;
   $49 = (($i$01$us4) + 257)|0;
   $50 = (($triangles) + ($47<<2)|0);
   HEAP32[$50>>2] = $49;
   $$3$us5 = (($$22$us3) + 9)|0;
   $51 = (($i$01$us4) + 2)|0;
   $52 = ($51|0)<(14);
   if ($52) {
    $$22$us3 = $$3$us5;$i$01$us4 = $51;
   } else {
    $$4 = $$3$us5;
    break;
   }
  }
  STACKTOP = sp;return ($$4|0);
 } else if ((($direction|0) == 0)) {
  $$22$us = $index;$i$01$us = 2;
  while(1) {
   $3 = (($i$01$us) + 17)|0;
   $4 = (($$22$us) + 1)|0;
   $5 = (($triangles) + ($$22$us<<2)|0);
   HEAP32[$5>>2] = $3;
   $6 = (($$22$us) + 2)|0;
   $7 = (($triangles) + ($4<<2)|0);
   HEAP32[$7>>2] = $i$01$us;
   $8 = $i$01$us | 1;
   $9 = (($8) + 17)|0;
   $10 = (($$22$us) + 3)|0;
   $11 = (($triangles) + ($6<<2)|0);
   HEAP32[$11>>2] = $9;
   $12 = (($$22$us) + 4)|0;
   $13 = (($triangles) + ($10<<2)|0);
   HEAP32[$13>>2] = $i$01$us;
   $14 = (($i$01$us) + 2)|0;
   $15 = (($$22$us) + 5)|0;
   $16 = (($triangles) + ($12<<2)|0);
   HEAP32[$16>>2] = $14;
   $17 = (($$22$us) + 6)|0;
   $18 = (($triangles) + ($15<<2)|0);
   HEAP32[$18>>2] = $9;
   $19 = (($$22$us) + 7)|0;
   $20 = (($triangles) + ($17<<2)|0);
   HEAP32[$20>>2] = $14;
   $21 = (($i$01$us) + 19)|0;
   $22 = (($$22$us) + 8)|0;
   $23 = (($triangles) + ($19<<2)|0);
   HEAP32[$23>>2] = $21;
   $24 = (($triangles) + ($22<<2)|0);
   HEAP32[$24>>2] = $9;
   $$3$us = (($$22$us) + 9)|0;
   $25 = (($i$01$us) + 2)|0;
   $26 = ($25|0)<(14);
   if ($26) {
    $$22$us = $$3$us;$i$01$us = $25;
   } else {
    break;
   }
  }
  $27 = (($index) + 54)|0;
  $$4 = $27;
  STACKTOP = sp;return ($$4|0);
 } else {
  $$22 = $index;$i$01 = 2;
  while(1) {
   $cond = ($direction|0)==(3);
   $118 = ($i$01*17)|0;
   if ($cond) {
    $119 = (($$22) + 1)|0;
    $120 = (($triangles) + ($$22<<2)|0);
    HEAP32[$120>>2] = $118;
    $121 = $118 | 1;
    $122 = (($$22) + 2)|0;
    $123 = (($triangles) + ($119<<2)|0);
    HEAP32[$123>>2] = $121;
    $124 = $i$01 | 1;
    $125 = ($124*17)|0;
    $126 = (($125) + 1)|0;
    $127 = (($$22) + 3)|0;
    $128 = (($triangles) + ($122<<2)|0);
    HEAP32[$128>>2] = $126;
    $129 = (($$22) + 4)|0;
    $130 = (($triangles) + ($127<<2)|0);
    HEAP32[$130>>2] = $126;
    $131 = (($118) + 34)|0;
    $132 = (($$22) + 5)|0;
    $133 = (($triangles) + ($129<<2)|0);
    HEAP32[$133>>2] = $131;
    $134 = (($$22) + 6)|0;
    $135 = (($triangles) + ($132<<2)|0);
    HEAP32[$135>>2] = $118;
    $136 = (($$22) + 7)|0;
    $137 = (($triangles) + ($134<<2)|0);
    HEAP32[$137>>2] = $131;
    $138 = (($$22) + 8)|0;
    $139 = (($triangles) + ($136<<2)|0);
    HEAP32[$139>>2] = $126;
    $140 = (($118) + 35)|0;
    $141 = (($triangles) + ($138<<2)|0);
    HEAP32[$141>>2] = $140;
   } else {
    $142 = (($118) + 16)|0;
    $143 = (($$22) + 1)|0;
    $144 = (($triangles) + ($$22<<2)|0);
    HEAP32[$144>>2] = $142;
    $145 = $i$01 | 1;
    $146 = ($145*17)|0;
    $147 = (($146) + 15)|0;
    $148 = (($$22) + 2)|0;
    $149 = (($triangles) + ($143<<2)|0);
    HEAP32[$149>>2] = $147;
    $150 = (($118) + 15)|0;
    $151 = (($$22) + 3)|0;
    $152 = (($triangles) + ($148<<2)|0);
    HEAP32[$152>>2] = $150;
    $153 = (($$22) + 4)|0;
    $154 = (($triangles) + ($151<<2)|0);
    HEAP32[$154>>2] = $147;
    $155 = (($$22) + 5)|0;
    $156 = (($triangles) + ($153<<2)|0);
    HEAP32[$156>>2] = $142;
    $157 = (($118) + 50)|0;
    $158 = (($$22) + 6)|0;
    $159 = (($triangles) + ($155<<2)|0);
    HEAP32[$159>>2] = $157;
    $160 = (($$22) + 7)|0;
    $161 = (($triangles) + ($158<<2)|0);
    HEAP32[$161>>2] = $157;
    $162 = (($118) + 49)|0;
    $163 = (($$22) + 8)|0;
    $164 = (($triangles) + ($160<<2)|0);
    HEAP32[$164>>2] = $162;
    $165 = (($triangles) + ($163<<2)|0);
    HEAP32[$165>>2] = $147;
   }
   $$3 = (($$22) + 9)|0;
   $166 = (($i$01) + 2)|0;
   $167 = ($166|0)<(14);
   if ($167) {
    $$22 = $$3;$i$01 = $166;
   } else {
    $$4 = $$3;
    break;
   }
  }
  STACKTOP = sp;return ($$4|0);
 }
 return 0|0;
}
function __ZL15AddSliverCornerPjjii($triangles,$index,$direction,$edgeMask) {
 $triangles = $triangles|0;
 $index = $index|0;
 $direction = $direction|0;
 $edgeMask = $edgeMask|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $flip$0$off0 = 0, $hMask$0 = 0, $mask$1 = 0, $not$ = 0, $ox$0 = 0, $oy$0 = 0, $vMask$0 = 0, $xBase$0 = 0, $yBase$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($direction|0) == 2)) {
  $flip$0$off0 = 0;$hMask$0 = 1;$ox$0 = 1;$oy$0 = 1;$vMask$0 = 8;$xBase$0 = 1;$yBase$0 = 1;
 } else if ((($direction|0) == 0)) {
  $flip$0$off0 = 1;$hMask$0 = 1;$ox$0 = 1;$oy$0 = -1;$vMask$0 = 4;$xBase$0 = 1;$yBase$0 = 15;
 } else if ((($direction|0) == 3)) {
  $flip$0$off0 = 1;$hMask$0 = 2;$ox$0 = -1;$oy$0 = 1;$vMask$0 = 8;$xBase$0 = 15;$yBase$0 = 1;
 } else {
  $flip$0$off0 = 0;$hMask$0 = 2;$ox$0 = -1;$oy$0 = -1;$vMask$0 = 4;$xBase$0 = 15;$yBase$0 = 15;
 }
 $0 = $hMask$0 & $edgeMask;
 $not$ = ($0|0)!=(0);
 $$ = $not$&1;
 $1 = $vMask$0 & $edgeMask;
 $2 = ($1|0)==(0);
 $3 = $$ | 2;
 $mask$1 = $2 ? $$ : $3;
 $4 = ($mask$1|0)==(1);
 if ($4) {
  $5 = ($xBase$0*17)|0;
  $6 = (($5) + ($yBase$0))|0;
  $7 = (($index) + 1)|0;
  $8 = (($triangles) + ($index<<2)|0);
  HEAP32[$8>>2] = $6;
  $9 = (($xBase$0) - ($ox$0))|0;
  $10 = ($9*17)|0;
  $11 = (($yBase$0) - ($oy$0))|0;
  $12 = (($10) + ($11))|0;
  $13 = (($index) + 2)|0;
  $14 = (($triangles) + ($7<<2)|0);
  HEAP32[$14>>2] = $12;
  $15 = (($10) + ($yBase$0))|0;
  $16 = (($index) + 3)|0;
  $17 = (($triangles) + ($13<<2)|0);
  HEAP32[$17>>2] = $15;
  $18 = (($ox$0) + ($xBase$0))|0;
  $19 = ($18*17)|0;
  $20 = (($19) + ($11))|0;
  $21 = (($index) + 4)|0;
  $22 = (($triangles) + ($16<<2)|0);
  HEAP32[$22>>2] = $20;
  $23 = (($index) + 5)|0;
  $24 = (($triangles) + ($21<<2)|0);
  HEAP32[$24>>2] = $6;
  $25 = (($19) + ($yBase$0))|0;
  $26 = (($index) + 6)|0;
  $27 = (($triangles) + ($23<<2)|0);
  HEAP32[$27>>2] = $25;
  $28 = (($index) + 7)|0;
  $29 = (($triangles) + ($26<<2)|0);
  HEAP32[$29>>2] = $6;
  $30 = (($index) + 8)|0;
  $31 = (($triangles) + ($28<<2)|0);
  HEAP32[$31>>2] = $20;
  $32 = (($index) + 9)|0;
  $33 = (($triangles) + ($30<<2)|0);
  HEAP32[$33>>2] = $12;
  if (!($flip$0$off0)) {
   $$0 = $32;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$8>>2] = $12;
  HEAP32[$14>>2] = $6;
  HEAP32[$22>>2] = $6;
  HEAP32[$24>>2] = $20;
  HEAP32[$29>>2] = $20;
  HEAP32[$31>>2] = $6;
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = ($mask$1|0)==(2);
 $35 = ($xBase$0*17)|0;
 if ($34) {
  $36 = (($oy$0) + ($yBase$0))|0;
  $37 = (($36) + ($35))|0;
  $38 = (($index) + 1)|0;
  $39 = (($triangles) + ($index<<2)|0);
  HEAP32[$39>>2] = $37;
  $40 = (($35) + ($yBase$0))|0;
  $41 = (($index) + 2)|0;
  $42 = (($triangles) + ($38<<2)|0);
  HEAP32[$42>>2] = $40;
  $43 = (($xBase$0) - ($ox$0))|0;
  $44 = ($43*17)|0;
  $45 = (($44) + ($36))|0;
  $46 = (($index) + 3)|0;
  $47 = (($triangles) + ($41<<2)|0);
  HEAP32[$47>>2] = $45;
  $48 = (($index) + 4)|0;
  $49 = (($triangles) + ($46<<2)|0);
  HEAP32[$49>>2] = $40;
  $50 = (($yBase$0) - ($oy$0))|0;
  $51 = (($44) + ($50))|0;
  $52 = (($index) + 5)|0;
  $53 = (($triangles) + ($48<<2)|0);
  HEAP32[$53>>2] = $51;
  $54 = (($index) + 6)|0;
  $55 = (($triangles) + ($52<<2)|0);
  HEAP32[$55>>2] = $45;
  $56 = (($index) + 7)|0;
  $57 = (($triangles) + ($54<<2)|0);
  HEAP32[$57>>2] = $51;
  $58 = (($index) + 8)|0;
  $59 = (($triangles) + ($56<<2)|0);
  HEAP32[$59>>2] = $40;
  $60 = (($50) + ($35))|0;
  $61 = (($index) + 9)|0;
  $62 = (($triangles) + ($58<<2)|0);
  HEAP32[$62>>2] = $60;
  if (!($flip$0$off0)) {
   $$0 = $61;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$39>>2] = $40;
  HEAP32[$42>>2] = $37;
  HEAP32[$49>>2] = $51;
  HEAP32[$53>>2] = $40;
  HEAP32[$57>>2] = $40;
  HEAP32[$59>>2] = $51;
  $$0 = $61;
  STACKTOP = sp;return ($$0|0);
 } else {
  $63 = (($35) + ($yBase$0))|0;
  $64 = (($index) + 1)|0;
  $65 = (($triangles) + ($index<<2)|0);
  HEAP32[$65>>2] = $63;
  $66 = (($xBase$0) - ($ox$0))|0;
  $67 = ($66*17)|0;
  $68 = (($oy$0) + ($yBase$0))|0;
  $69 = (($67) + ($68))|0;
  $70 = (($index) + 2)|0;
  $71 = (($triangles) + ($64<<2)|0);
  HEAP32[$71>>2] = $69;
  $72 = (($68) + ($35))|0;
  $73 = (($index) + 3)|0;
  $74 = (($triangles) + ($70<<2)|0);
  HEAP32[$74>>2] = $72;
  $75 = (($ox$0) + ($xBase$0))|0;
  $76 = ($75*17)|0;
  $77 = (($yBase$0) - ($oy$0))|0;
  $78 = (($76) + ($77))|0;
  $79 = (($index) + 4)|0;
  $80 = (($triangles) + ($73<<2)|0);
  HEAP32[$80>>2] = $78;
  $81 = (($index) + 5)|0;
  $82 = (($triangles) + ($79<<2)|0);
  HEAP32[$82>>2] = $63;
  $83 = (($76) + ($yBase$0))|0;
  $84 = (($index) + 6)|0;
  $85 = (($triangles) + ($81<<2)|0);
  HEAP32[$85>>2] = $83;
  $86 = (($index) + 7)|0;
  $87 = (($triangles) + ($84<<2)|0);
  HEAP32[$87>>2] = $63;
  $88 = (($67) + ($77))|0;
  $89 = (($index) + 8)|0;
  $90 = (($triangles) + ($86<<2)|0);
  HEAP32[$90>>2] = $88;
  $91 = (($index) + 9)|0;
  $92 = (($triangles) + ($89<<2)|0);
  HEAP32[$92>>2] = $69;
  $93 = (($index) + 10)|0;
  $94 = (($triangles) + ($91<<2)|0);
  HEAP32[$94>>2] = $63;
  $95 = (($index) + 11)|0;
  $96 = (($triangles) + ($93<<2)|0);
  HEAP32[$96>>2] = $78;
  $97 = (($index) + 12)|0;
  $98 = (($triangles) + ($95<<2)|0);
  HEAP32[$98>>2] = $88;
  if (!($flip$0$off0)) {
   $$0 = $97;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$65>>2] = $69;
  HEAP32[$71>>2] = $63;
  HEAP32[$80>>2] = $63;
  HEAP32[$82>>2] = $78;
  HEAP32[$87>>2] = $88;
  HEAP32[$90>>2] = $63;
  HEAP32[$94>>2] = $78;
  HEAP32[$96>>2] = $63;
  $$0 = $97;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN21TerrainIndexGenerator22GetOptimizedIndexStripEiRj($edgeMask,$count) {
 $edgeMask = $edgeMask|0;
 $count = $count|0;
 var $$byval_copy3 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $i$010 = 0, $newStrip = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0;
 var $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $0 = sp;
 $newStrip = sp + 4|0;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 $3 = $edgeMask & 15;
 $4 = (802184 + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $64 = HEAP32[$4>>2]|0;
  $65 = HEAP32[$64>>2]|0;
  HEAP32[$count>>2] = $65;
  $66 = (($64) + 4|0);
  $67 = HEAP32[$66>>2]|0;
  STACKTOP = sp;return ($67|0);
 }
 $9 = (__ZN21TerrainIndexGenerator14GetIndexBufferEiRji($3,$count,0)|0);
 HEAP32[$newStrip>>2] = 0;
 $10 = (($newStrip) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($newStrip) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = HEAP32[$count>>2]|0;
 __THREW__ = 0;
 (invoke_iiii(1593,($9|0),($12|0),($newStrip|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if (!($14)) {
  $15 = HEAP32[628248>>2]|0;
  HEAP32[$1>>2] = $15;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($9|0),($$byval_copy3|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $18 = HEAP32[$10>>2]|0;
   $19 = HEAP32[$newStrip>>2]|0;
   $20 = $18;
   $21 = $19;
   $22 = (($20) - ($21))|0;
   $23 = $22 >> 2;
   HEAP32[$count>>2] = $23;
   $24 = $22 >> 1;
   $25 = HEAP32[628248>>2]|0;
   HEAP32[$2>>2] = $25;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
   $26 = (invoke_iiiiiii(102,($24|0),16,($$byval_copy3|0),0,(802176|0),119)|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[$count>>2]|0;
    $30 = ($29|0)==(0);
    if ($30) {
     $$lcssa = 0;
    } else {
     $31 = HEAP32[$newStrip>>2]|0;
     $i$010 = 0;
     while(1) {
      $32 = (($31) + ($i$010<<2)|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = $33&65535;
      $35 = (($26) + ($i$010<<1)|0);
      HEAP16[$35>>1] = $34;
      $36 = (($i$010) + 1)|0;
      $37 = ($36>>>0)<($29>>>0);
      if ($37) {
       $i$010 = $36;
      } else {
       $$lcssa = $29;
       break;
      }
     }
    }
    $51 = HEAP32[$4>>2]|0;
    HEAP32[$51>>2] = $$lcssa;
    $52 = (($51) + 4|0);
    HEAP32[$52>>2] = $26;
    $53 = HEAP32[$newStrip>>2]|0;
    $54 = ($53|0)==(0|0);
    if ($54) {
     $64 = HEAP32[$4>>2]|0;
     $65 = HEAP32[$64>>2]|0;
     HEAP32[$count>>2] = $65;
     $66 = (($64) + 4|0);
     $67 = HEAP32[$66>>2]|0;
     STACKTOP = sp;return ($67|0);
    }
    $55 = HEAP32[$10>>2]|0;
    $56 = ($55|0)==($53|0);
    if (!($56)) {
     $__new_last2$i$i$i$i$i = $53;
     $scevgep$i$i$i$i$i = (($55) + -4|0);
     $57 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($57)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $58 = $uglygep3$i$i$i$i$i >>> 2;
     $59 = $58 ^ -1;
     $scevgep4$i$i$i$i$i = (($55) + ($59<<2)|0);
     HEAP32[$10>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($53|0),($$byval_copy3|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     $62 = ___cxa_find_matching_catch()|0;
     $63 = tempRet0;
     ___cxa_call_unexpected(($62|0));
     // unreachable;
    } else {
     $64 = HEAP32[$4>>2]|0;
     $65 = HEAP32[$64>>2]|0;
     HEAP32[$count>>2] = $65;
     $66 = (($64) + 4|0);
     $67 = HEAP32[$66>>2]|0;
     STACKTOP = sp;return ($67|0);
    }
   }
  }
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 $40 = HEAP32[$newStrip>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  ___resumeException($38|0);
  // unreachable;
 }
 $42 = HEAP32[$10>>2]|0;
 $43 = ($42|0)==($40|0);
 if (!($43)) {
  $__new_last2$i$i$i$i$i1 = $40;
  $scevgep$i$i$i$i$i2 = (($42) + -4|0);
  $44 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($44)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $45 = $uglygep3$i$i$i$i$i5 >>> 2;
  $46 = $45 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($42) + ($46<<2)|0);
  HEAP32[$10>>2] = $scevgep4$i$i$i$i$i6;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($40|0),($$byval_copy3|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 } else {
  ___resumeException($38|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN15TerrainRendererC2Ei4PPtrI11TerrainDataERK8Vector3f($this,$instanceID,$terrainData,$position) {
 $this = $this|0;
 $instanceID = $instanceID|0;
 $terrainData = $terrainData|0;
 $position = $position|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $temp$0$i = 0, $temp$0$i11 = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 16|0);
 $4 = (($this) + 28|0);
 $5 = (($this) + 32|0);
 $6 = (($this) + 44|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($this) + 48|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($this) + 52|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($this) + 60|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($this) + 64|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($this) + 68|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($this) + 104|0);
 HEAP32[$12>>2] = 0;
 dest=$this+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $13 = HEAP32[628440>>2]|0;
 $14 = (($this) + 144|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 148|0);
 HEAP32[$15>>2] = $13;
 $16 = (($this) + 152|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 156|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 288|0);
 dest=$18+0|0; stop=dest+36|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $19 = HEAP32[$terrainData>>2]|0;
 HEAP32[$0>>2] = $19;
 $20 = HEAP32[560624>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  label = 9;
 } else {
  $22 = (($20) + 36|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($20) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($23|0)==($25|0);
  do {
   if ($26) {
    $27 = (($20) + 28|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($20) + 32|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + ($30<<3)|0);
    $47 = $31;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$20,$0);
    $32 = HEAP32[$$byval_copy>>2]|0;
    $33 = ($32|0)==(-1);
    $34 = (($20) + 28|0);
    $35 = HEAP32[$34>>2]|0;
    if ($33) {
     $36 = (($20) + 32|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($35) + ($37<<3)|0);
     $47 = $38;
     break;
    } else {
     $39 = (($35) + ($32<<3)|0);
     $47 = $39;
     break;
    }
   }
  } while(0);
  $40 = HEAP32[560624>>2]|0;
  $41 = (($40) + 28|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 32|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($42) + ($44<<3)|0);
  $46 = ($47|0)==($45|0);
  if ($46) {
   label = 9;
  } else {
   $48 = (($47) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==(0|0);
   if ($50) {
    label = 9;
   } else {
    $temp$0$i11 = $49;
    label = 10;
   }
  }
 }
 if ((label|0) == 9) {
  $51 = HEAP32[$terrainData>>2]|0;
  __THREW__ = 0;
  $52 = (invoke_ii(3215,($51|0))|0);
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if (!($54)) {
   $temp$0$i11 = $52;
   label = 10;
  }
 }
 do {
  if ((label|0) == 10) {
   $55 = (($temp$0$i11) + 232|0);
   $56 = (($55) + 80|0);
   ;HEAP32[$3+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$56+8>>2]|0;
   $57 = HEAP32[$terrainData>>2]|0;
   HEAP32[$1>>2] = $57;
   $58 = HEAP32[560624>>2]|0;
   $59 = ($58|0)==(0|0);
   if ($59) {
    label = 18;
   } else {
    $60 = (($58) + 36|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($58) + 4|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = ($61|0)==($63|0);
    do {
     if ($64) {
      $65 = (($58) + 28|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = (($58) + 32|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (($66) + ($68<<3)|0);
      $85 = $69;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy,$58,$1);
      $70 = HEAP32[$$byval_copy>>2]|0;
      $71 = ($70|0)==(-1);
      $72 = (($58) + 28|0);
      $73 = HEAP32[$72>>2]|0;
      if ($71) {
       $74 = (($58) + 32|0);
       $75 = HEAP32[$74>>2]|0;
       $76 = (($73) + ($75<<3)|0);
       $85 = $76;
       break;
      } else {
       $77 = (($73) + ($70<<3)|0);
       $85 = $77;
       break;
      }
     }
    } while(0);
    $78 = HEAP32[560624>>2]|0;
    $79 = (($78) + 28|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($78) + 32|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($80) + ($82<<3)|0);
    $84 = ($85|0)==($83|0);
    if ($84) {
     label = 18;
    } else {
     $86 = (($85) + 4|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = ($87|0)==(0|0);
     if ($88) {
      label = 18;
     } else {
      $temp$0$i = $87;
     }
    }
   }
   if ((label|0) == 18) {
    $89 = HEAP32[$terrainData>>2]|0;
    __THREW__ = 0;
    $90 = (invoke_ii(3215,($89|0))|0);
    $91 = __THREW__; __THREW__ = 0;
    $92 = $91&1;
    if ($92) {
     break;
    } else {
     $temp$0$i = $90;
    }
   }
   $93 = (($temp$0$i) + 232|0);
   $94 = (($93) + 72|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($this) + 40|0);
   HEAP32[$96>>2] = $95;
   $97 = HEAP32[$terrainData>>2]|0;
   HEAP32[$12>>2] = $97;
   ;HEAP32[$6+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$position+8>>2]|0;
   $98 = (($this) + 140|0);
   $99 = (($98) + 2|0);
   HEAP16[$99>>1] = 255;
   HEAP16[$98>>1] = 255;
   $100 = (($this) + 108|0);
   HEAPF32[$100>>2] = Math_fround(1.0);
   $101 = (($this) + 112|0);
   HEAPF32[$101>>2] = Math_fround(1.0);
   $102 = (($this) + 116|0);
   HEAPF32[$102>>2] = Math_fround(0.0);
   $103 = (($this) + 120|0);
   HEAPF32[$103>>2] = Math_fround(0.0);
   $104 = (($this) + 124|0);
   HEAPF32[$104>>2] = Math_fround(1.0);
   $105 = (($this) + 128|0);
   HEAPF32[$105>>2] = Math_fround(1.0);
   $106 = (($this) + 132|0);
   HEAPF32[$106>>2] = Math_fround(0.0);
   $107 = (($this) + 136|0);
   HEAPF32[$107>>2] = Math_fround(0.0);
   $108 = (($this) + 160|0);
   dest=$108+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $109 = HEAP8[((588176 + 1|0))>>0]|0;
   $110 = HEAP8[588176>>0]|0;
   __THREW__ = 0;
   $111 = (invoke_ii(3408,($110|0))|0);
   $112 = __THREW__; __THREW__ = 0;
   $113 = $112&1;
   if (!($113)) {
    $122 = $109&255;
    $123 = Math_imul($111, $122)|0;
    $124 = $123&255;
    $125 = HEAP8[((588176 + 3|0))>>0]|0;
    $126 = HEAP8[((588176 + 2|0))>>0]|0;
    __THREW__ = 0;
    $127 = (invoke_ii(3408,($126|0))|0);
    $128 = __THREW__; __THREW__ = 0;
    $129 = $128&1;
    if (!($129)) {
     $130 = $125&255;
     $131 = Math_imul($127, $130)|0;
     $132 = (($131) + ($123))|0;
     $133 = HEAP8[((588176 + 7|0))>>0]|0;
     $134 = HEAP8[((588176 + 6|0))>>0]|0;
     __THREW__ = 0;
     $135 = (invoke_ii(3408,($134|0))|0);
     $136 = __THREW__; __THREW__ = 0;
     $137 = $136&1;
     if (!($137)) {
      $138 = $133&255;
      $139 = $132&255;
      $140 = Math_imul($135, $138)|0;
      $141 = (($140) + ($132))|0;
      $142 = HEAP8[588176>>0]|0;
      $143 = (($this) + 290|0);
      HEAP8[$143>>0] = $142;
      $144 = HEAP8[((588176 + 1|0))>>0]|0;
      $145 = (($this) + 291|0);
      HEAP8[$145>>0] = $144;
      $146 = HEAP8[((588176 + 2|0))>>0]|0;
      $147 = (($this) + 294|0);
      HEAP8[$147>>0] = $146;
      $148 = HEAP8[((588176 + 3|0))>>0]|0;
      $149 = (($this) + 295|0);
      HEAP8[$149>>0] = $148;
      $150 = (($this) + 293|0);
      HEAP8[$150>>0] = $124;
      $151 = HEAP8[((588176 + 6|0))>>0]|0;
      $152 = (($this) + 302|0);
      HEAP8[$152>>0] = $151;
      $153 = HEAP8[((588176 + 7|0))>>0]|0;
      $154 = (($this) + 303|0);
      HEAP8[$154>>0] = $153;
      $155 = (($this) + 301|0);
      HEAP8[$155>>0] = $139;
      $156 = (($this) + 304|0);
      $157 = (($this) + 300|0);
      $158 = HEAP32[$157>>2]|0;
      HEAP32[$156>>2] = $158;
      $159 = $141 & 255;
      $160 = (($this) + 324|0);
      HEAP32[$160>>2] = $159;
      __THREW__ = 0;
      invoke_vi(3711,($this|0));
      $161 = __THREW__; __THREW__ = 0;
      $162 = $161&1;
      if (!($162)) {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $114 = ___cxa_find_matching_catch()|0;
 $115 = tempRet0;
 $116 = HEAP32[$17>>2]|0;
 $117 = ($116|0)>(-1);
 do {
  if ($117) {
   $118 = HEAP32[$14>>2]|0;
   $119 = HEAP32[$15>>2]|0;
   HEAP32[$2>>2] = $119;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($118|0),($$byval_copy|0));
   $120 = __THREW__; __THREW__ = 0;
   $121 = $120&1;
   if ($121) {
    $170 = ___cxa_find_matching_catch(0|0)|0;
    $171 = tempRet0;
    ___clang_call_terminate($170);
    // unreachable;
   } else {
    HEAP32[$14>>2] = 0;
    break;
   }
  }
 } while(0);
 $163 = HEAP32[$4>>2]|0;
 $164 = ($163|0)==(0|0);
 if ($164) {
  ___resumeException($114|0);
  // unreachable;
 }
 $165 = HEAP32[$5>>2]|0;
 $166 = ($165|0)==($163|0);
 if (!($166)) {
  $__new_last2$i$i$i$i$i = $163;
  $scevgep$i$i$i$i$i = (($165) + -124|0);
  $167 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($167)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $168 = (($uglygep3$i$i$i$i$i>>>0) / 124)&-1;
  $169 = $168 ^ -1;
  $scevgep4$i$i$i$i$i = (($165) + (($169*124)|0)|0);
  HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($163);
 ___resumeException($114|0);
 // unreachable;
}
function __ZN15TerrainRenderer12RebuildNodesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0;
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $__new_last2$i$i$i = 0, $exitcond$i$us = 0, $i$01$i$us = 0, $index$02$i$us = 0, $level$07 = 0, $pos$i$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $temp$0$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, $x$01 = 0, $x$01$us = 0, $y$03 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 104|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = HEAP32[560624>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  label = 9;
 } else {
  $6 = (($4) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($7|0)==($9|0);
  do {
   if ($10) {
    $11 = (($4) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($4) + 32|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + ($14<<3)|0);
    $31 = $15;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$4,$0);
    $16 = HEAP32[$pos$i$i$i$i>>2]|0;
    $17 = ($16|0)==(-1);
    $18 = (($4) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($4) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $31 = $22;
     break;
    } else {
     $23 = (($19) + ($16<<3)|0);
     $31 = $23;
     break;
    }
   }
  } while(0);
  $24 = HEAP32[560624>>2]|0;
  $25 = (($24) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 32|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($28<<3)|0);
  $30 = ($31|0)==($29|0);
  if ($30) {
   label = 9;
  } else {
   $32 = (($31) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if ($34) {
    label = 9;
   } else {
    $temp$0$i = $33;
   }
  }
 }
 if ((label|0) == 9) {
  $35 = HEAP32[$2>>2]|0;
  $36 = (__Z31ReadObjectFromPersistentManageri($35)|0);
  $temp$0$i = $36;
 }
 $37 = (($temp$0$i) + 232|0);
 $38 = (($37) + 72|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (__ZNK9Heightmap13GetPatchIndexEiii($37,0,0,$39)|0);
 $41 = (($40) + 1)|0;
 $42 = (($this) + 28|0);
 $43 = (($this) + 32|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$42>>2]|0;
 $46 = $44;
 $47 = $45;
 $48 = (($46) - ($47))|0;
 $49 = (($48|0) / 124)&-1;
 $50 = ($49>>>0)<($41>>>0);
 if ($50) {
  $51 = (($41) - ($49))|0;
  __ZNSt3__16vectorI12QuadTreeNodeNS_9allocatorIS1_EEE8__appendEj($42,$51);
 } else {
  $52 = ($49>>>0)>($41>>>0);
  if ($52) {
   $53 = (($45) + (($41*124)|0)|0);
   $54 = ($44|0)==($53|0);
   if (!($54)) {
    $__new_last2$i$i$i = $53;
    $scevgep$i$i$i = (($44) + -124|0);
    $55 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($55)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $56 = (($uglygep3$i$i$i>>>0) / 124)&-1;
    $57 = $56 ^ -1;
    $scevgep4$i$i$i = (($44) + (($57*124)|0)|0);
    HEAP32[$43>>2] = $scevgep4$i$i$i;
   }
  }
 }
 $58 = (($this) + 40|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)<(0);
 if ($60) {
  STACKTOP = sp;return;
 }
 $61 = (($this) + 44|0);
 $62 = (($this) + 48|0);
 $63 = (($this) + 52|0);
 $65 = $59;$level$07 = 0;
 while(1) {
  $64 = (($65) - ($level$07))|0;
  $66 = 1 << $64;
  $67 = ($66|0)>(0);
  if ($67) {
   $68 = ($level$07|0)>(0);
   $70 = $65;$y$03 = 0;
   while(1) {
    $69 = (($70) - ($level$07))|0;
    $71 = 1 << $69;
    $72 = ($71|0)>(0);
    L29: do {
     if ($72) {
      if ($68) {
       $74 = $70;$80 = $69;$x$01$us = 0;
      } else {
       $110 = $69;$x$01 = 0;
       while(1) {
        $109 = $y$03 << $110;
        $111 = (($109) + ($x$01))|0;
        $112 = HEAP32[$42>>2]|0;
        $113 = ((($112) + (($111*124)|0)|0) + 84|0);
        HEAP32[$113>>2] = $x$01;
        $114 = ((($112) + (($111*124)|0)|0) + 88|0);
        HEAP32[$114>>2] = $y$03;
        $115 = ((($112) + (($111*124)|0)|0) + 92|0);
        HEAP32[$115>>2] = $level$07;
        $116 = (Math_fround(__ZNK9Heightmap21GetMaximumHeightErrorEiii($37,$x$01,$y$03,$level$07)));
        $117 = HEAP32[$42>>2]|0;
        $118 = ((($117) + (($111*124)|0)|0) + 72|0);
        HEAPF32[$118>>2] = $116;
        $119 = ((($117) + (($111*124)|0)|0) + 96|0);
        __ZNK9Heightmap9GetBoundsEiii($1,$37,$x$01,$y$03,$level$07);
        ;HEAP32[$119+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$119+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$119+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$119+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$119+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$119+20>>2]=HEAP32[$1+20>>2]|0;
        $120 = HEAP32[$42>>2]|0;
        $121 = Math_fround(HEAPF32[$61>>2]);
        $122 = ((($120) + (($111*124)|0)|0) + 96|0);
        $123 = Math_fround(HEAPF32[$122>>2]);
        $124 = Math_fround($121 + $123);
        HEAPF32[$122>>2] = $124;
        $125 = Math_fround(HEAPF32[$62>>2]);
        $126 = ((($120) + (($111*124)|0)|0) + 100|0);
        $127 = Math_fround(HEAPF32[$126>>2]);
        $128 = Math_fround($125 + $127);
        HEAPF32[$126>>2] = $128;
        $129 = Math_fround(HEAPF32[$63>>2]);
        $130 = ((($120) + (($111*124)|0)|0) + 104|0);
        $131 = Math_fround(HEAPF32[$130>>2]);
        $132 = Math_fround($129 + $131);
        HEAPF32[$130>>2] = $132;
        $133 = (($x$01) + 1)|0;
        $134 = HEAP32[$58>>2]|0;
        $135 = (($134) - ($level$07))|0;
        $136 = 1 << $135;
        $137 = ($133|0)<($136|0);
        if ($137) {
         $110 = $135;$x$01 = $133;
        } else {
         $140 = $134;
         break L29;
        }
       }
      }
      while(1) {
       $i$01$i$us = 0;$index$02$i$us = 0;
       while(1) {
        $73 = (($74) - ($i$01$i$us))|0;
        $75 = 1 << $73;
        $76 = $75 << $73;
        $77 = (($76) + ($index$02$i$us))|0;
        $78 = (($i$01$i$us) + 1)|0;
        $exitcond$i$us = ($78|0)==($level$07|0);
        if ($exitcond$i$us) {
         break;
        } else {
         $i$01$i$us = $78;$index$02$i$us = $77;
        }
       }
       $79 = $y$03 << $80;
       $81 = (($79) + ($x$01$us))|0;
       $82 = (($81) + ($77))|0;
       $83 = HEAP32[$42>>2]|0;
       $84 = ((($83) + (($82*124)|0)|0) + 84|0);
       HEAP32[$84>>2] = $x$01$us;
       $85 = ((($83) + (($82*124)|0)|0) + 88|0);
       HEAP32[$85>>2] = $y$03;
       $86 = ((($83) + (($82*124)|0)|0) + 92|0);
       HEAP32[$86>>2] = $level$07;
       $87 = (Math_fround(__ZNK9Heightmap21GetMaximumHeightErrorEiii($37,$x$01$us,$y$03,$level$07)));
       $88 = HEAP32[$42>>2]|0;
       $89 = ((($88) + (($82*124)|0)|0) + 72|0);
       HEAPF32[$89>>2] = $87;
       $90 = ((($88) + (($82*124)|0)|0) + 96|0);
       __ZNK9Heightmap9GetBoundsEiii($1,$37,$x$01$us,$y$03,$level$07);
       ;HEAP32[$90+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$90+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$90+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$90+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$90+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$90+20>>2]=HEAP32[$1+20>>2]|0;
       $91 = HEAP32[$42>>2]|0;
       $92 = Math_fround(HEAPF32[$61>>2]);
       $93 = ((($91) + (($82*124)|0)|0) + 96|0);
       $94 = Math_fround(HEAPF32[$93>>2]);
       $95 = Math_fround($92 + $94);
       HEAPF32[$93>>2] = $95;
       $96 = Math_fround(HEAPF32[$62>>2]);
       $97 = ((($91) + (($82*124)|0)|0) + 100|0);
       $98 = Math_fround(HEAPF32[$97>>2]);
       $99 = Math_fround($96 + $98);
       HEAPF32[$97>>2] = $99;
       $100 = Math_fround(HEAPF32[$63>>2]);
       $101 = ((($91) + (($82*124)|0)|0) + 104|0);
       $102 = Math_fround(HEAPF32[$101>>2]);
       $103 = Math_fround($100 + $102);
       HEAPF32[$101>>2] = $103;
       $104 = (($x$01$us) + 1)|0;
       $105 = HEAP32[$58>>2]|0;
       $106 = (($105) - ($level$07))|0;
       $107 = 1 << $106;
       $108 = ($104|0)<($107|0);
       if ($108) {
        $74 = $105;$80 = $106;$x$01$us = $104;
       } else {
        $140 = $105;
        break;
       }
      }
     } else {
      $140 = $70;
     }
    } while(0);
    $138 = (($y$03) + 1)|0;
    $139 = (($140) - ($level$07))|0;
    $141 = 1 << $139;
    $142 = ($138|0)<($141|0);
    if ($142) {
     $70 = $140;$y$03 = $138;
    } else {
     $145 = $140;
     break;
    }
   }
  } else {
   $145 = $65;
  }
  $143 = (($level$07) + 1)|0;
  $144 = ($level$07|0)<($145|0);
  if ($144) {
   $65 = $145;$level$07 = $143;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15TerrainRendererD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $i$020 = 0, $i1$014 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 L1: do {
  if ($5) {
   label = 2;
  } else {
   $11 = $2;
   while(1) {
    $10 = (($11) + 4|0);
    $12 = HEAP32[$10>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(3413,($this|0),($12|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     HEAP32[$11>>2] = 0;
     HEAP32[$10>>2] = 0;
     $16 = (($11) + 8|0);
     HEAP32[$16>>2] = 0;
    }
    $17 = (($11) + 120|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18 & -7;
    HEAP8[$17>>0] = $19;
    $20 = (($11) + 124|0);
    $21 = ($20|0)==($4|0);
    if ($21) {
     label = 2;
     break L1;
    } else {
     $11 = $20;
    }
   }
   $26 = ___cxa_find_matching_catch()|0;
   $27 = tempRet0;
   $lpad$phi$index = $26;$lpad$phi$index3 = $27;
   label = 11;
  }
 } while(0);
 L9: do {
  if ((label|0) == 2) {
   $6 = (($this) + 144|0);
   $7 = (($this) + 152|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   L11: do {
    if ($9) {
     $i1$014 = 0;
    } else {
     $i$020 = 0;
     while(1) {
      __THREW__ = 0;
      $37 = (invoke_i(59)|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      $40 = HEAP32[$37>>2]|0;
      $41 = (($40) + 292|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = HEAP32[$6>>2]|0;
      $44 = (($43) + ($i$020<<2)|0);
      $45 = HEAP32[$44>>2]|0;
      __THREW__ = 0;
      invoke_vii($42|0,($37|0),($45|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = (($i$020) + 1)|0;
      $49 = HEAP32[$7>>2]|0;
      $50 = ($48>>>0)<($49>>>0);
      if ($50) {
       $i$020 = $48;
      } else {
       $i1$014 = 0;
       break L11;
      }
     }
     $24 = ___cxa_find_matching_catch()|0;
     $25 = tempRet0;
     $lpad$phi$index = $24;$lpad$phi$index3 = $25;
     label = 11;
     break L9;
    }
   } while(0);
   while(1) {
    $51 = ((($this) + ($i1$014<<3)|0) + 164|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($52|0)==(0|0);
    if (!($53)) {
     __THREW__ = 0;
     $54 = (invoke_i(59)|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      label = 8;
      break;
     }
     $57 = HEAP32[$54>>2]|0;
     $58 = (($57) + 272|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = HEAP32[$51>>2]|0;
     __THREW__ = 0;
     invoke_vii($59|0,($54|0),($60|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 8;
      break;
     }
    }
    $63 = (($i1$014) + 1)|0;
    $64 = ($63|0)<(16);
    if ($64) {
     $i1$014 = $63;
    } else {
     break;
    }
   }
   if ((label|0) == 8) {
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    $lpad$phi$index = $22;$lpad$phi$index3 = $23;
    label = 11;
    break;
   }
   $65 = (($this) + 156|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)>(-1);
   do {
    if ($67) {
     $68 = HEAP32[$6>>2]|0;
     $69 = (($this) + 148|0);
     $70 = HEAP32[$69>>2]|0;
     HEAP32[$0>>2] = $70;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($68|0),($$byval_copy8|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      $80 = ___cxa_find_matching_catch()|0;
      $81 = tempRet0;
      $$0 = $81;$$01 = $80;
      break L9;
     } else {
      HEAP32[$6>>2] = 0;
      break;
     }
    }
   } while(0);
   $73 = HEAP32[$1>>2]|0;
   $74 = ($73|0)==(0|0);
   if ($74) {
    STACKTOP = sp;return;
   }
   $75 = HEAP32[$3>>2]|0;
   $76 = ($75|0)==($73|0);
   if (!($76)) {
    $__new_last2$i$i$i$i$i2 = $73;
    $scevgep$i$i$i$i$i3 = (($75) + -124|0);
    $77 = (0 - ($__new_last2$i$i$i$i$i2))|0;
    $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($77)|0);
    $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
    $78 = (($uglygep3$i$i$i$i$i6>>>0) / 124)&-1;
    $79 = $78 ^ -1;
    $scevgep4$i$i$i$i$i7 = (($75) + (($79*124)|0)|0);
    HEAP32[$3>>2] = $scevgep4$i$i$i$i$i7;
   }
   __ZdlPv($73);
   STACKTOP = sp;return;
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $28 = (($this) + 156|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>(-1);
   if ($30) {
    $31 = (($this) + 144|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($this) + 148|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$0>>2] = $34;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($32|0),($$byval_copy8|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     $89 = ___cxa_find_matching_catch(0|0)|0;
     $90 = tempRet0;
     ___clang_call_terminate($89);
     // unreachable;
    } else {
     HEAP32[$31>>2] = 0;
     $$0 = $lpad$phi$index3;$$01 = $lpad$phi$index;
     break;
    }
   } else {
    $$0 = $lpad$phi$index3;$$01 = $lpad$phi$index;
   }
  }
 } while(0);
 $82 = HEAP32[$1>>2]|0;
 $83 = ($82|0)==(0|0);
 if ($83) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $84 = HEAP32[$3>>2]|0;
 $85 = ($84|0)==($82|0);
 if (!($85)) {
  $__new_last2$i$i$i$i$i = $82;
  $scevgep$i$i$i$i$i = (($84) + -124|0);
  $86 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($86)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $87 = (($uglygep3$i$i$i$i$i>>>0) / 124)&-1;
  $88 = $87 ^ -1;
  $scevgep4$i$i$i$i$i = (($84) + (($88*124)|0)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($82);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN15TerrainRenderer12SetNeighborsEPS_S0_S0_S0_($this,$left,$top,$right,$bottom) {
 $this = $this|0;
 $left = $left|0;
 $top = $top|0;
 $right = $right|0;
 $bottom = $bottom|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $top;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $right;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $bottom;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $left;
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer19GetPatchIndexBufferEiPj($this,$edgeMask,$indexCount) {
 $this = $this|0;
 $edgeMask = $edgeMask|0;
 $indexCount = $indexCount|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $indexCount1 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $trilist = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $indexCount1 = sp + 4|0;
 $trilist = sp + 8|0;
 $1 = ((($this) + ($edgeMask<<3)|0) + 160|0);
 $2 = ((($this) + ($edgeMask<<3)|0) + 164|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $5 = (__ZN21TerrainIndexGenerator22GetOptimizedIndexStripEiRj($edgeMask,$indexCount1)|0);
   HEAP32[$trilist>>2] = 0;
   $6 = (($trilist) + 4|0);
   HEAP32[$6>>2] = 0;
   $7 = (($trilist) + 8|0);
   HEAP32[$7>>2] = 0;
   $8 = HEAP32[$indexCount1>>2]|0;
   __THREW__ = 0;
   invoke_viii(2034,($5|0),($8|0),($trilist|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_i(59)|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[$11>>2]|0;
     $15 = (($14) + 256|0);
     $16 = HEAP32[$15>>2]|0;
     __THREW__ = 0;
     $17 = (invoke_ii($16|0,($11|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      $20 = (invoke_i(59)|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       $23 = HEAP32[$20>>2]|0;
       $24 = (($23) + 260|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = HEAP32[$6>>2]|0;
       $27 = HEAP32[$trilist>>2]|0;
       $28 = $26;
       $29 = $27;
       $30 = (($28) - ($29))|0;
       __THREW__ = 0;
       invoke_viiiiiii($25|0,($20|0),($17|0),0,0,($30|0),($27|0),0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        $33 = HEAP32[$6>>2]|0;
        $34 = HEAP32[$trilist>>2]|0;
        $35 = $33;
        $36 = $34;
        $37 = (($35) - ($36))|0;
        $38 = $37 >> 1;
        HEAP32[$1>>2] = $38;
        HEAP32[$2>>2] = $17;
        $39 = ($34|0)==(0|0);
        if ($39) {
         break;
        }
        $40 = ($33|0)==($34|0);
        if (!($40)) {
         $scevgep$i$i$i$i$i2 = (($33) + -2|0);
         $41 = (0 - ($36))|0;
         $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($41)|0);
         $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
         $42 = $uglygep3$i$i$i$i$i5 >>> 1;
         $43 = $42 ^ -1;
         $scevgep4$i$i$i$i$i6 = (($33) + ($43<<1)|0);
         HEAP32[$6>>2] = $scevgep4$i$i$i$i$i6;
        }
        HEAP32[$0>>2] = 90;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($34|0),($$byval_copy1|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         break;
        }
        $46 = ___cxa_find_matching_catch()|0;
        $47 = tempRet0;
        ___cxa_call_unexpected(($46|0));
        // unreachable;
       }
      }
     }
    }
   }
   $48 = ___cxa_find_matching_catch()|0;
   $49 = tempRet0;
   $50 = HEAP32[$trilist>>2]|0;
   $51 = ($50|0)==(0|0);
   if ($51) {
    ___resumeException($48|0);
    // unreachable;
   }
   $52 = HEAP32[$6>>2]|0;
   $53 = ($52|0)==($50|0);
   if (!($53)) {
    $__new_last2$i$i$i$i$i = $50;
    $scevgep$i$i$i$i$i = (($52) + -2|0);
    $54 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($54)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $55 = $uglygep3$i$i$i$i$i >>> 1;
    $56 = $55 ^ -1;
    $scevgep4$i$i$i$i$i = (($52) + ($56<<1)|0);
    HEAP32[$6>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($50|0),($$byval_copy1|0));
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $59 = ___cxa_find_matching_catch()|0;
    $60 = tempRet0;
    ___cxa_call_unexpected(($59|0));
    // unreachable;
   } else {
    ___resumeException($48|0);
    // unreachable;
   }
  }
 } while(0);
 $61 = ($indexCount|0)==(0|0);
 if ($61) {
  $63 = HEAP32[$2>>2]|0;
  STACKTOP = sp;return ($63|0);
 }
 $62 = HEAP32[$1>>2]|0;
 HEAP32[$indexCount>>2] = $62;
 $63 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($63|0);
}
function __ZN15TerrainRenderer20GetPatchVertexStreamEiiiPj($agg$result,$this,$x,$y,$level,$vertexCount) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $level = $level|0;
 $vertexCount = $vertexCount|0;
 var $$byval_copy9 = 0, $$idx = 0, $$index = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0, $temp$0$i = 0, $vb$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy9 = sp + 40|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 16|0;
 $4 = sp + 24|0;
 $5 = sp + 32|0;
 $6 = (($this) + 152|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $16 = (__Z12GetGfxDevicev()|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 276|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
  $vb$0 = $20;
 } else {
  $9 = (($this) + 144|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($10) + 4|0);
  $$idx = $7 << 2;
  $13 = (($$idx) + -4)|0;
  _memmove(($10|0),($12|0),($13|0))|0;
  $14 = HEAP32[$6>>2]|0;
  $15 = (($14) + -1)|0;
  HEAP32[$6>>2] = $15;
  $vb$0 = $11;
 }
 $21 = (($this) + 324|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22*289)|0;
 $24 = (($23) + 31)|0;
 $25 = ($24>>>0)<(2000);
 if ($25) {
  $26 = ($23|0)==(0);
  if ($26) {
   $37 = 0;$allocPtr$0 = 0;
  } else {
   $27 = STACKTOP; STACKTOP = STACKTOP + ((((1*$24)|0)+15)&-16)|0;;
   $37 = 0;$allocPtr$0 = $27;
  }
 } else {
  $28 = HEAP32[628512>>2]|0;
  HEAP32[$2>>2] = $28;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
  $29 = (invoke_iiiiiii(102,($24|0),16,($$byval_copy9|0),0,(802248|0),143)|0);
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   $$index = $32;$$index3 = $33;$112 = $0;
   ___resumeException($$index|0);
   // unreachable;
  } else {
   $37 = $29;$allocPtr$0 = $29;
  }
 }
 $41 = $allocPtr$0;
 $42 = (($41) + 31)|0;
 $43 = $42 & -32;
 $44 = $43;
 $45 = (($this) + 104|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$1>>2] = $46;
 $47 = HEAP32[560624>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  label = 19;
 } else {
  $49 = (($47) + 36|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($47) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($50|0)==($52|0);
  do {
   if ($53) {
    $54 = (($47) + 28|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($47) + 32|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($55) + ($57<<3)|0);
    $74 = $58;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy9,$47,$1);
    $59 = HEAP32[$$byval_copy9>>2]|0;
    $60 = ($59|0)==(-1);
    $61 = (($47) + 28|0);
    $62 = HEAP32[$61>>2]|0;
    if ($60) {
     $63 = (($47) + 32|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = (($62) + ($64<<3)|0);
     $74 = $65;
     break;
    } else {
     $66 = (($62) + ($59<<3)|0);
     $74 = $66;
     break;
    }
   }
  } while(0);
  $67 = HEAP32[560624>>2]|0;
  $68 = (($67) + 28|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($67) + 32|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($69) + ($71<<3)|0);
  $73 = ($74|0)==($72|0);
  if ($73) {
   label = 19;
  } else {
   $75 = (($74) + 4|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)==(0|0);
   if ($77) {
    label = 19;
   } else {
    $temp$0$i = $76;
    label = 20;
   }
  }
 }
 if ((label|0) == 19) {
  $78 = HEAP32[$45>>2]|0;
  __THREW__ = 0;
  $79 = (invoke_ii(3215,($78|0))|0);
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if (!($81)) {
   $temp$0$i = $79;
   label = 20;
  }
 }
 if ((label|0) == 20) {
  $82 = (($temp$0$i) + 232|0);
  $83 = (($this) + 293|0);
  $84 = HEAP8[$83>>0]|0;
  $85 = (($this) + 301|0);
  $86 = HEAP8[$85>>0]|0;
  $87 = $86&255;
  $88 = HEAP32[$21>>2]|0;
  HEAP32[$3>>2] = $44;
  $89 = (($3) + 4|0);
  HEAP32[$89>>2] = $88;
  $90 = $84&255;
  $91 = (($44) + ($90)|0);
  HEAP32[$4>>2] = $91;
  $92 = (($4) + 4|0);
  HEAP32[$92>>2] = $88;
  $93 = (($44) + ($87)|0);
  HEAP32[$5>>2] = $93;
  $94 = (($5) + 4|0);
  HEAP32[$94>>2] = $88;
  __THREW__ = 0;
  invoke_viiiiiiii(33,($82|0),($3|0),($4|0),($5|0),($x|0),($y|0),($level|0),($this|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if (!($96)) {
   __THREW__ = 0;
   $97 = (invoke_i(59)|0);
   $98 = __THREW__; __THREW__ = 0;
   $99 = $98&1;
   if (!($99)) {
    $100 = HEAP32[$97>>2]|0;
    $101 = (($100) + 280|0);
    $102 = HEAP32[$101>>2]|0;
    __THREW__ = 0;
    invoke_viiiiiii($102|0,($97|0),($vb$0|0),1,0,($23|0),($44|0),0);
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if (!($104)) {
     $105 = ($vertexCount|0)==(0|0);
     if (!($105)) {
      HEAP32[$vertexCount>>2] = 289;
     }
     HEAP32[$agg$result>>2] = $vb$0;
     $106 = (($agg$result) + 4|0);
     $107 = HEAP32[$21>>2]|0;
     HEAP32[$106>>2] = $107;
     $108 = ($37|0)==(0|0);
     if ($108) {
      STACKTOP = sp;return;
     }
     $109 = HEAP32[628512>>2]|0;
     HEAP32[$0>>2] = $109;
     ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($37,$$byval_copy9);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 $36 = ($37|0)==(0|0);
 if ($36) {
  $$index = $34;$$index3 = $35;$112 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $38 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $38;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($37|0),($$byval_copy9|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $110 = ___cxa_find_matching_catch(0|0)|0;
  $111 = tempRet0;
  ___clang_call_terminate($110);
  // unreachable;
 } else {
  $$index = $34;$$index3 = $35;$112 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __ZN15TerrainRenderer24ReclaimPatchVertexBufferEP12VertexBuffer($this,$vb) {
 $this = $this|0;
 $vb = $vb|0;
 var $$byval_copy1 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 144|0);
 $2 = (($this) + 152|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 156|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if (!($8)) {
  $27 = $4;
  $26 = (($27) + -1)|0;
  $28 = HEAP32[$1>>2]|0;
  $29 = (($28) + ($26<<2)|0);
  HEAP32[$29>>2] = $vb;
  STACKTOP = sp;return;
 }
 $9 = $6 << 1;
 $10 = ($9|0)==(0);
 $11 = $10 ? 1 : $9;
 $12 = ($7>>>0)<($11>>>0);
 do {
  if ($12) {
   $13 = ($6|0)>(-1);
   if ($13) {
    HEAP32[$5>>2] = $11;
    $14 = HEAP32[$1>>2]|0;
    $15 = $11 << 2;
    $16 = (($this) + 148|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy1,0,802248,370)|0);
    HEAP32[$1>>2] = $18;
    break;
   } else {
    $19 = $11 << 2;
    $20 = (($this) + 148|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,802248,352)|0);
    $23 = HEAP32[$1>>2]|0;
    $24 = HEAP32[$2>>2]|0;
    $25 = $24 << 2;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$5>>2] = $11;
    HEAP32[$1>>2] = $22;
    break;
   }
  }
 } while(0);
 $$pre$i$i = HEAP32[$2>>2]|0;
 $27 = $$pre$i$i;
 $26 = (($27) + -1)|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAP32[$29>>2] = $vb;
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer24GetPatchMeshVertexFormatEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 320|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $7 = $2;
  STACKTOP = sp;return ($7|0);
 }
 $4 = (__Z26GetMeshVertexFormatManagerv()|0);
 $5 = (($this) + 288|0);
 __ZN18VertexChannelsInfoC2ERA8_K11ChannelInfo($0,$5);
 $6 = (__ZN23MeshVertexFormatManager19GetMeshVertexFormatERK18VertexChannelsInfo($4,$0)|0);
 HEAP32[$1>>2] = $6;
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZN15TerrainRenderer7GetNodeEiii($this,$x,$y,$level) {
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $level = $level|0;
 var $$0 = 0, $$lcssa12 = 0, $$lcssa9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0;
 var $i$01$i = 0, $index$0$lcssa$i = 0, $index$02$i = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond1 = 0, $or$cond1$not = 0, $or$cond1$not$us = 0, $or$cond2 = 0, $or$cond2$us = 0, $phitmp = 0, $this$tr$lcssa3 = 0, $this$tr$ph30 = 0, $this$tr20 = 0, $this$tr20$us = 0, $x$tr$ph31 = 0, $x$tr$ph3180 = 0, $y$tr$lcssa6 = 0, $y$tr$ph32 = 0;
 var $y$tr21 = 0, $y$tr21$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($level|0)<(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $this$tr$ph30 = $this;$x$tr$ph31 = $x;$y$tr$ph32 = $y;
 }
 L3: while(1) {
  $notlhs = ($x$tr$ph31|0)<(0);
  $1 = ($x$tr$ph31|0)==(-1);
  if ($1) {
   $this$tr20$us = $this$tr$ph30;$y$tr21$us = $y$tr$ph32;
  } else {
   $this$tr20 = $this$tr$ph30;$y$tr21 = $y$tr$ph32;
   while(1) {
    $25 = (($this$tr20) + 40|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)<($level|0);
    if ($27) {
     $$0 = 0;
     label = 26;
     break L3;
    }
    $28 = (($26) - ($level))|0;
    $29 = 1 << $28;
    $notrhs = ($29|0)<=($x$tr$ph31|0);
    $or$cond$not = $notrhs | $notlhs;
    $30 = ($y$tr21|0)<(0);
    $or$cond1 = $or$cond$not | $30;
    $or$cond1$not = $or$cond1 ^ 1;
    $31 = ($29|0)>($y$tr21|0);
    $or$cond2 = $31 & $or$cond1$not;
    if ($or$cond2) {
     $$lcssa12 = $28;$$lcssa9 = $26;$this$tr$lcssa3 = $this$tr20;$x$tr$ph3180 = $x$tr$ph31;$y$tr$lcssa6 = $y$tr21;
     label = 23;
     break L3;
    }
    $32 = ($29|0)==($x$tr$ph31|0);
    if ($32) {
     $33 = (($this$tr20) + 4|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if (!($35)) {
      $this$tr$ph30 = $34;$x$tr$ph31 = 0;$y$tr$ph32 = $y$tr21;
      continue L3;
     }
    }
    $36 = ($29|0)==($y$tr21|0);
    if ($36) {
     $37 = HEAP32[$this$tr20>>2]|0;
     $38 = ($37|0)==(0|0);
     if (!($38)) {
      $this$tr20 = $37;$y$tr21 = 0;
      continue;
     }
    }
    $39 = ($y$tr21|0)==(-1);
    if (!($39)) {
     $$0 = 0;
     label = 26;
     break L3;
    }
    $40 = (($this$tr20) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($41|0)==(0|0);
    if ($42) {
     $$0 = 0;
     label = 26;
     break L3;
    }
    $43 = (($29) + -1)|0;
    $this$tr20 = $41;$y$tr21 = $43;
   }
  }
  while(1) {
   $2 = (($this$tr20$us) + 40|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)<($level|0);
   if ($4) {
    $$0 = 0;
    label = 26;
    break L3;
   }
   $5 = (($3) - ($level))|0;
   $6 = 1 << $5;
   $7 = $6 | $x$tr$ph31;
   $8 = $7 | $y$tr21$us;
   $or$cond1$not$us = ($8|0)>(-1);
   $9 = ($6|0)>($y$tr21$us|0);
   $or$cond2$us = $9 & $or$cond1$not$us;
   if ($or$cond2$us) {
    $$lcssa12 = $5;$$lcssa9 = $3;$this$tr$lcssa3 = $this$tr20$us;$x$tr$ph3180 = -1;$y$tr$lcssa6 = $y$tr21$us;
    label = 23;
    break L3;
   }
   $10 = (($this$tr20$us) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if (!($12)) {
    break;
   }
   $13 = ($6|0)==(-1);
   if ($13) {
    $14 = (($this$tr20$us) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if (!($16)) {
     $this$tr$ph30 = $15;$x$tr$ph31 = 0;$y$tr$ph32 = $y$tr21$us;
     continue L3;
    }
   }
   $17 = ($6|0)==($y$tr21$us|0);
   if ($17) {
    $18 = HEAP32[$this$tr20$us>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     $this$tr20$us = $18;$y$tr21$us = 0;
     continue;
    }
   }
   $20 = ($y$tr21$us|0)==(-1);
   if (!($20)) {
    $$0 = 0;
    label = 26;
    break L3;
   }
   $21 = (($this$tr20$us) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    $$0 = 0;
    label = 26;
    break L3;
   }
   $24 = (($6) + -1)|0;
   $this$tr20$us = $22;$y$tr21$us = $24;
  }
  $phitmp = (($6) + -1)|0;
  $this$tr$ph30 = $11;$x$tr$ph31 = $phitmp;$y$tr$ph32 = $y$tr21$us;
 }
 if ((label|0) == 23) {
  $44 = ($level|0)>(0);
  if ($44) {
   $i$01$i = 0;$index$02$i = 0;
   while(1) {
    $45 = (($$lcssa9) - ($i$01$i))|0;
    $46 = 1 << $45;
    $47 = $46 << $45;
    $48 = (($47) + ($index$02$i))|0;
    $49 = (($i$01$i) + 1)|0;
    $exitcond$i = ($49|0)==($level|0);
    if ($exitcond$i) {
     $index$0$lcssa$i = $48;
     break;
    } else {
     $i$01$i = $49;$index$02$i = $48;
    }
   }
  } else {
   $index$0$lcssa$i = 0;
  }
  $50 = $y$tr$lcssa6 << $$lcssa12;
  $51 = (($50) + ($x$tr$ph3180))|0;
  $52 = (($51) + ($index$0$lcssa$i))|0;
  $53 = (($this$tr$lcssa3) + 28|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($54) + (($52*124)|0)|0);
  $$0 = $55;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 26) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN15TerrainRenderer18GetNodeAndRendererEiiiRPS_($this,$x,$y,$level,$renderer) {
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $level = $level|0;
 $renderer = $renderer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $index$0$lcssa$i = 0, $index$02$i = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond1 = 0, $or$cond1$not = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($level|0)<(0);
 if (!($0)) {
  $1 = (($this) + 40|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)<($level|0);
  if (!($3)) {
   $4 = (($2) - ($level))|0;
   $5 = 1 << $4;
   $notlhs = ($x|0)<(0);
   $notrhs = ($5|0)<=($x|0);
   $or$cond$not = $notrhs | $notlhs;
   $6 = ($y|0)<(0);
   $or$cond1 = $or$cond$not | $6;
   $or$cond1$not = $or$cond1 ^ 1;
   $7 = ($5|0)>($y|0);
   $or$cond2 = $7 & $or$cond1$not;
   if ($or$cond2) {
    HEAP32[$renderer>>2] = $this;
    $33 = ($level|0)>(0);
    if ($33) {
     $i$01$i = 0;$index$02$i = 0;
     while(1) {
      $34 = (($2) - ($i$01$i))|0;
      $35 = 1 << $34;
      $36 = $35 << $34;
      $37 = (($36) + ($index$02$i))|0;
      $38 = (($i$01$i) + 1)|0;
      $exitcond$i = ($38|0)==($level|0);
      if ($exitcond$i) {
       $index$0$lcssa$i = $37;
       break;
      } else {
       $i$01$i = $38;$index$02$i = $37;
      }
     }
    } else {
     $index$0$lcssa$i = 0;
    }
    $39 = $y << $4;
    $40 = (($39) + ($x))|0;
    $41 = (($40) + ($index$0$lcssa$i))|0;
    $42 = (($this) + 28|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + (($41*124)|0)|0);
    $$0 = $44;
    STACKTOP = sp;return ($$0|0);
   }
   $8 = ($x|0)==(-1);
   if ($8) {
    $9 = (($this) + 12|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     HEAP32[$renderer>>2] = $10;
     $12 = HEAP32[$9>>2]|0;
     $13 = (($5) + -1)|0;
     $14 = (__ZN15TerrainRenderer7GetNodeEiii($12,$13,$y,$level)|0);
     $$0 = $14;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $15 = ($5|0)==($x|0);
   if ($15) {
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if (!($18)) {
     HEAP32[$renderer>>2] = $17;
     $19 = HEAP32[$16>>2]|0;
     $20 = (__ZN15TerrainRenderer7GetNodeEiii($19,0,$y,$level)|0);
     $$0 = $20;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $21 = ($5|0)==($y|0);
   if ($21) {
    $22 = HEAP32[$this>>2]|0;
    $23 = ($22|0)==(0|0);
    if (!($23)) {
     HEAP32[$renderer>>2] = $22;
     $24 = HEAP32[$this>>2]|0;
     $25 = (__ZN15TerrainRenderer7GetNodeEiii($24,$x,0,$level)|0);
     $$0 = $25;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $26 = ($y|0)==(-1);
   if ($26) {
    $27 = (($this) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if (!($29)) {
     HEAP32[$renderer>>2] = $28;
     $30 = HEAP32[$27>>2]|0;
     $31 = (($5) + -1)|0;
     $32 = (__ZN15TerrainRenderer7GetNodeEiii($30,$x,$31,$level)|0);
     $$0 = $32;
     STACKTOP = sp;return ($$0|0);
    }
   }
   HEAP32[$renderer>>2] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$renderer>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN15TerrainRenderer17CalculateEdgeMaskER12QuadTreeNode($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $$ = 0, $$mask$1 = 0, $$mask$1$1 = 0, $$mask$1$2 = 0, $$off = 0, $$off$1 = 0, $$off$2 = 0, $$off$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mask$1 = 0, $mask$1$1 = 0, $mask$1$2 = 0, $switch = 0, $switch$1 = 0, $switch$2 = 0, $switch$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN15TerrainRenderer12FindNeighborER12QuadTreeNodei($this,$node,0)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $mask$1 = 1;
 } else {
  $2 = (($0) + 76|0);
  $3 = HEAP32[$2>>2]|0;
  $$off = (($3) + -1)|0;
  $switch = ($$off>>>0)<(2);
  $$ = $switch&1;
  $mask$1 = $$;
 }
 $4 = (__ZN15TerrainRenderer12FindNeighborER12QuadTreeNodei($this,$node,1)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $9 = $mask$1 | 2;
  $mask$1$1 = $9;
 } else {
  $6 = (($4) + 76|0);
  $7 = HEAP32[$6>>2]|0;
  $$off$1 = (($7) + -1)|0;
  $switch$1 = ($$off$1>>>0)<(2);
  $8 = $mask$1 | 2;
  $$mask$1 = $switch$1 ? $8 : $mask$1;
  $mask$1$1 = $$mask$1;
 }
 $10 = (__ZN15TerrainRenderer12FindNeighborER12QuadTreeNodei($this,$node,2)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  $15 = $mask$1$1 | 4;
  $mask$1$2 = $15;
 } else {
  $12 = (($10) + 76|0);
  $13 = HEAP32[$12>>2]|0;
  $$off$2 = (($13) + -1)|0;
  $switch$2 = ($$off$2>>>0)<(2);
  $14 = $mask$1$1 | 4;
  $$mask$1$1 = $switch$2 ? $14 : $mask$1$1;
  $mask$1$2 = $$mask$1$1;
 }
 $16 = (__ZN15TerrainRenderer12FindNeighborER12QuadTreeNodei($this,$node,3)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  $21 = $mask$1$2 | 8;
  STACKTOP = sp;return ($21|0);
 } else {
  $18 = (($16) + 76|0);
  $19 = HEAP32[$18>>2]|0;
  $$off$3 = (($19) + -1)|0;
  $switch$3 = ($$off$3>>>0)<(2);
  $20 = $mask$1$2 | 8;
  $$mask$1$2 = $switch$3 ? $20 : $mask$1$2;
  STACKTOP = sp;return ($$mask$1$2|0);
 }
 return 0|0;
}
function __ZN15TerrainRenderer12FindNeighborER12QuadTreeNodei($this,$node,$direction) {
 $this = $this|0;
 $node = $node|0;
 $direction = $direction|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($direction|0) == 2)) {
  $0 = (($node) + 84|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($node) + 88|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 1)|0;
  $5 = (($node) + 92|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZN15TerrainRenderer7GetNodeEiii($this,$1,$4,$6)|0);
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 } else if ((($direction|0) == 3)) {
  $8 = (($node) + 84|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($node) + 88|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + -1)|0;
  $13 = (($node) + 92|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__ZN15TerrainRenderer7GetNodeEiii($this,$9,$12,$14)|0);
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 } else {
  $16 = ($direction|0)==(0);
  $17 = (($node) + 84|0);
  $18 = HEAP32[$17>>2]|0;
  if ($16) {
   $19 = (($18) + -1)|0;
   $20 = (($node) + 88|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($node) + 92|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (__ZN15TerrainRenderer7GetNodeEiii($this,$19,$21,$23)|0);
   $$0 = $24;
   STACKTOP = sp;return ($$0|0);
  } else {
   $25 = (($18) + 1)|0;
   $26 = (($node) + 88|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($node) + 92|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (__ZN15TerrainRenderer7GetNodeEiii($this,$25,$27,$29)|0);
   $$0 = $30;
   STACKTOP = sp;return ($$0|0);
  }
 }
 return 0|0;
}
function __ZN15TerrainRenderer23FindNeighborAndRendererER12QuadTreeNodeiRPS_($this,$node,$direction,$renderer) {
 $this = $this|0;
 $node = $node|0;
 $direction = $direction|0;
 $renderer = $renderer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($direction|0) == 2)) {
  $0 = (($node) + 84|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (($node) + 88|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 1)|0;
  $5 = (($node) + 92|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (__ZN15TerrainRenderer18GetNodeAndRendererEiiiRPS_($this,$1,$4,$6,$renderer)|0);
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 } else if ((($direction|0) == 3)) {
  $8 = (($node) + 84|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($node) + 88|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + -1)|0;
  $13 = (($node) + 92|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (__ZN15TerrainRenderer18GetNodeAndRendererEiiiRPS_($this,$9,$12,$14,$renderer)|0);
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 } else {
  $16 = ($direction|0)==(0);
  $17 = (($node) + 84|0);
  $18 = HEAP32[$17>>2]|0;
  if ($16) {
   $19 = (($18) + -1)|0;
   $20 = (($node) + 88|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($node) + 92|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (__ZN15TerrainRenderer18GetNodeAndRendererEiiiRPS_($this,$19,$21,$23,$renderer)|0);
   $$0 = $24;
   STACKTOP = sp;return ($$0|0);
  } else {
   $25 = (($18) + 1)|0;
   $26 = (($node) + 88|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($node) + 92|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (__ZN15TerrainRenderer18GetNodeAndRendererEiiiRPS_($this,$25,$27,$29,$renderer)|0);
   $$0 = $30;
   STACKTOP = sp;return ($$0|0);
  }
 }
 return 0|0;
}
function __ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,$direction) {
 $this = $this|0;
 $node = $node|0;
 $direction = $direction|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($direction|0) == 1)) {
  $10 = (($node) + 84|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 << 1;
  $13 = $12 | 1;
  $14 = (($node) + 88|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 << 1;
  $17 = (($node) + 92|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + -1)|0;
  $20 = (__ZN15TerrainRenderer7GetNodeEiii($this,$13,$16,$19)|0);
  $$0 = $20;
  STACKTOP = sp;return ($$0|0);
 } else if ((($direction|0) == 0)) {
  $0 = (($node) + 84|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = $1 << 1;
  $3 = (($node) + 88|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4 << 1;
  $6 = (($node) + 92|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + -1)|0;
  $9 = (__ZN15TerrainRenderer7GetNodeEiii($this,$2,$5,$8)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 } else {
  $21 = ($direction|0)==(2);
  $22 = (($node) + 84|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 << 1;
  if ($21) {
   $25 = (($node) + 88|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = $26 << 1;
   $28 = $27 | 1;
   $29 = (($node) + 92|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + -1)|0;
   $32 = (__ZN15TerrainRenderer7GetNodeEiii($this,$24,$28,$31)|0);
   $$0 = $32;
   STACKTOP = sp;return ($$0|0);
  } else {
   $33 = $24 | 1;
   $34 = (($node) + 88|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 << 1;
   $37 = $36 | 1;
   $38 = (($node) + 92|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + -1)|0;
   $41 = (__ZN15TerrainRenderer7GetNodeEiii($this,$33,$37,$40)|0);
   $$0 = $41;
   STACKTOP = sp;return ($$0|0);
  }
 }
 return 0|0;
}
function __ZN15TerrainRenderer11RenderStep1EP6Cameraiff($this,$camera,$maxLodLevel,$tau,$splatDistance) {
 $this = $this|0;
 $camera = $camera|0;
 $maxLodLevel = $maxLodLevel|0;
 $tau = Math_fround($tau);
 $splatDistance = Math_fround($splatDistance);
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = ($maxLodLevel|0)<(0);
 if ($2) {
  $$0$i = 0;
 } else {
  $3 = (($this) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)<($maxLodLevel|0);
  $$$i = $5 ? $4 : $maxLodLevel;
  $$0$i = $$$i;
 }
 $6 = (($camera) + 456|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($camera) + 452|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = Math_fround($9 * Math_fround(0.5));
 $11 = Math_fround($10 / Math_fround(360.0));
 $12 = Math_fround($11 * Math_fround(2.0));
 $13 = Math_fround($12 * Math_fround(3.14159274101257324219));
 $14 = (Math_fround(+(Math_tan((+$13)))));
 $15 = Math_fround($7 * $14);
 __ZNK6Camera13GetCameraRectEb($0,$camera,1);
 $16 = (($0) + 12|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (Math_fround(Math_abs((Math_fround($15)))));
 $19 = Math_fround($7 / $18);
 $20 = Math_fround($tau * Math_fround(2.0));
 $21 = Math_fround($20 / $17);
 $22 = Math_fround($19 / $21);
 $23 = (($this) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + -124|0);
 $26 = (($this) + 60|0);
 $27 = (($camera) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($28)|0);
 __ZNK9Transform11GetPositionEv($1,$29);
 ;HEAP32[$26+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$1+8>>2]|0;
 $30 = (($this) + 72|0);
 HEAP32[$30>>2] = $$0$i;
 $31 = (($this) + 76|0);
 HEAPF32[$31>>2] = $22;
 $32 = Math_fround($splatDistance * $splatDistance);
 $33 = (($this) + 80|0);
 HEAPF32[$33>>2] = $32;
 __ZN15TerrainRenderer21RecursiveCalculateLodER12QuadTreeNode($this,$25);
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer21RecursiveCalculateLodER12QuadTreeNode($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $fSqrDistance$1$1$i = Math_fround(0), $fSqrDistance$1$2$i = Math_fround(0), $fSqrDistance$1$i = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($node) + 96|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 - $3);
 $5 = (($this) + 64|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($node) + 100|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 - $8);
 $10 = (($this) + 68|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($node) + 104|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround($11 - $13);
 $15 = (($node) + 108|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround(-$16);
 $18 = $4 < $17;
 if ($18) {
  $19 = Math_fround($4 + $16);
  $20 = Math_fround($19 * $19);
  $21 = Math_fround($20 + Math_fround(0.0));
  $fSqrDistance$1$i = $21;
 } else {
  $22 = $4 > $16;
  if ($22) {
   $23 = Math_fround($4 - $16);
   $24 = Math_fround($23 * $23);
   $25 = Math_fround($24 + Math_fround(0.0));
   $fSqrDistance$1$i = $25;
  } else {
   $fSqrDistance$1$i = Math_fround(0.0);
  }
 }
 $26 = (($15) + 4|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround(-$27);
 $29 = $9 < $28;
 if ($29) {
  $34 = Math_fround($9 + $27);
  $35 = Math_fround($34 * $34);
  $36 = Math_fround($fSqrDistance$1$i + $35);
  $fSqrDistance$1$1$i = $36;
 } else {
  $30 = $9 > $27;
  if ($30) {
   $31 = Math_fround($9 - $27);
   $32 = Math_fround($31 * $31);
   $33 = Math_fround($fSqrDistance$1$i + $32);
   $fSqrDistance$1$1$i = $33;
  } else {
   $fSqrDistance$1$1$i = $fSqrDistance$1$i;
  }
 }
 $37 = (($15) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround(-$38);
 $40 = $14 < $39;
 if ($40) {
  $45 = Math_fround($14 + $38);
  $46 = Math_fround($45 * $45);
  $47 = Math_fround($fSqrDistance$1$1$i + $46);
  $fSqrDistance$1$2$i = $47;
 } else {
  $41 = $14 > $38;
  if ($41) {
   $42 = Math_fround($14 - $38);
   $43 = Math_fround($42 * $42);
   $44 = Math_fround($fSqrDistance$1$1$i + $43);
   $fSqrDistance$1$2$i = $44;
  } else {
   $fSqrDistance$1$2$i = $fSqrDistance$1$1$i;
  }
 }
 $48 = (($this) + 76|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = (($node) + 72|0);
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = Math_fround($49 * $51);
 $53 = Math_fround($52 * $52);
 $54 = $fSqrDistance$1$2$i > $53;
 if (!($54)) {
  $55 = (($node) + 92|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($this) + 72|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($56|0)==($58|0);
  if (!($59)) {
   $69 = (($node) + 76|0);
   HEAP32[$69>>2] = 1;
   $70 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,0)|0);
   __ZN15TerrainRenderer21RecursiveCalculateLodER12QuadTreeNode($this,$70);
   $71 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,1)|0);
   __ZN15TerrainRenderer21RecursiveCalculateLodER12QuadTreeNode($this,$71);
   $72 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,2)|0);
   __ZN15TerrainRenderer21RecursiveCalculateLodER12QuadTreeNode($this,$72);
   $73 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,3)|0);
   __ZN15TerrainRenderer21RecursiveCalculateLodER12QuadTreeNode($this,$73);
   STACKTOP = sp;return;
  }
 }
 $60 = (($node) + 76|0);
 HEAP32[$60>>2] = 2;
 $61 = (($this) + 80|0);
 $62 = Math_fround(HEAPF32[$61>>2]);
 $63 = $fSqrDistance$1$2$i < $62;
 $64 = (($node) + 120|0);
 $65 = $63&1;
 $66 = HEAP8[$64>>0]|0;
 $67 = $66 & -2;
 $68 = $67 | $65;
 HEAP8[$64>>0] = $68;
 __ZN15TerrainRenderer26MarkChildVisibilityRecurseER12QuadTreeNodei($this,$node,0);
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer11RenderStep2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -124|0);
 __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$2);
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $renderer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $renderer = sp;
 $0 = (($node) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 0)) {
  STACKTOP = sp;return;
 } else if ((($1|0) == 2)) {
  $2 = (__ZN15TerrainRenderer23FindNeighborAndRendererER12QuadTreeNodeiRPS_($this,$node,0,$renderer)|0);
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $8 = (($2) + 76|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0);
   if ($10) {
    $11 = HEAP32[$renderer>>2]|0;
    $12 = (($2) + 92|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + 32|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($15) + -32|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($13|0)==($17|0);
    if (!($18)) {
     $19 = (($2) + 84|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($20|0) / 2)&-1;
     $22 = (($2) + 88|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($23|0) / 2)&-1;
     $25 = (($13) + 1)|0;
     $26 = (__ZN15TerrainRenderer7GetNodeEiii($11,$21,$24,$25)|0);
     $27 = (($26) + 76|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==(0);
     if ($29) {
      __ZN15TerrainRenderer16ForceSplitParentER12QuadTreeNode($11,$26);
     }
    }
   }
  }
  $30 = (__ZN15TerrainRenderer23FindNeighborAndRendererER12QuadTreeNodeiRPS_($this,$node,1,$renderer)|0);
  $31 = ($30|0)==(0|0);
  if (!($31)) {
   $32 = (($30) + 76|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0);
   if ($34) {
    $35 = HEAP32[$renderer>>2]|0;
    $36 = (($30) + 92|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($35) + 32|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + -32|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($37|0)==($41|0);
    if (!($42)) {
     $43 = (($30) + 84|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44|0) / 2)&-1;
     $46 = (($30) + 88|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (($47|0) / 2)&-1;
     $49 = (($37) + 1)|0;
     $50 = (__ZN15TerrainRenderer7GetNodeEiii($35,$45,$48,$49)|0);
     $51 = (($50) + 76|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==(0);
     if ($53) {
      __ZN15TerrainRenderer16ForceSplitParentER12QuadTreeNode($35,$50);
     }
    }
   }
  }
  $54 = (__ZN15TerrainRenderer23FindNeighborAndRendererER12QuadTreeNodeiRPS_($this,$node,2,$renderer)|0);
  $55 = ($54|0)==(0|0);
  if (!($55)) {
   $56 = (($54) + 76|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==(0);
   if ($58) {
    $59 = HEAP32[$renderer>>2]|0;
    $60 = (($54) + 92|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($59) + 32|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($63) + -32|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($61|0)==($65|0);
    if (!($66)) {
     $67 = (($54) + 84|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($68|0) / 2)&-1;
     $70 = (($54) + 88|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = (($71|0) / 2)&-1;
     $73 = (($61) + 1)|0;
     $74 = (__ZN15TerrainRenderer7GetNodeEiii($59,$69,$72,$73)|0);
     $75 = (($74) + 76|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = ($76|0)==(0);
     if ($77) {
      __ZN15TerrainRenderer16ForceSplitParentER12QuadTreeNode($59,$74);
     }
    }
   }
  }
  $78 = (__ZN15TerrainRenderer23FindNeighborAndRendererER12QuadTreeNodeiRPS_($this,$node,3,$renderer)|0);
  $79 = ($78|0)==(0|0);
  if ($79) {
   STACKTOP = sp;return;
  }
  $80 = (($78) + 76|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = ($81|0)==(0);
  if (!($82)) {
   STACKTOP = sp;return;
  }
  $83 = HEAP32[$renderer>>2]|0;
  $84 = (($78) + 92|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($83) + 32|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (($87) + -32|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = ($85|0)==($89|0);
  if ($90) {
   STACKTOP = sp;return;
  }
  $91 = (($78) + 84|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (($92|0) / 2)&-1;
  $94 = (($78) + 88|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($95|0) / 2)&-1;
  $97 = (($85) + 1)|0;
  $98 = (__ZN15TerrainRenderer7GetNodeEiii($83,$93,$96,$97)|0);
  $99 = (($98) + 76|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = ($100|0)==(0);
  if (!($101)) {
   STACKTOP = sp;return;
  }
  __ZN15TerrainRenderer16ForceSplitParentER12QuadTreeNode($83,$98);
  STACKTOP = sp;return;
 } else {
  $4 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,0)|0);
  __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$4);
  $5 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,1)|0);
  __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$5);
  $6 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,2)|0);
  __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$6);
  $7 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,3)|0);
  __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$7);
  STACKTOP = sp;return;
 }
}
function __ZN15TerrainRenderer11RenderStep3EP6CameraibPPN5Unity8MaterialEiS4_($this,$camera,$layer,$castShadows,$splatMats,$splatMatCount,$baseMat) {
 $this = $this|0;
 $camera = $camera|0;
 $layer = $layer|0;
 $castShadows = $castShadows|0;
 $splatMats = $splatMats|0;
 $splatMatCount = $splatMatCount|0;
 $baseMat = $baseMat|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -124|0);
 $4 = (($this) + 84|0);
 HEAP32[$4>>2] = $layer;
 $5 = (($this) + 88|0);
 HEAP32[$5>>2] = $camera;
 $6 = (($this) + 56|0);
 $7 = $castShadows&1;
 HEAP8[$6>>0] = $7;
 $8 = (($this) + 100|0);
 HEAP32[$8>>2] = $splatMats;
 $9 = (($this) + 96|0);
 HEAP32[$9>>2] = $splatMatCount;
 $10 = (($this) + 92|0);
 HEAP32[$10>>2] = $baseMat;
 $11 = (($this) + 104|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$0>>2] = $12;
 $13 = HEAP32[560624>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($13) + 36|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($13) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($16|0)==($18|0);
  do {
   if ($19) {
    $20 = (($13) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($13) + 32|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + ($23<<3)|0);
    $40 = $24;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$13,$0);
    $25 = HEAP32[$pos$i$i$i$i>>2]|0;
    $26 = ($25|0)==(-1);
    $27 = (($13) + 28|0);
    $28 = HEAP32[$27>>2]|0;
    if ($26) {
     $29 = (($13) + 32|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($28) + ($30<<3)|0);
     $40 = $31;
     break;
    } else {
     $32 = (($28) + ($25<<3)|0);
     $40 = $32;
     break;
    }
   }
  } while(0);
  $33 = HEAP32[560624>>2]|0;
  $34 = (($33) + 28|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + 32|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + ($37<<3)|0);
  $39 = ($40|0)==($38|0);
  if (!($39)) {
   $41 = (($40) + 4|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==(0|0);
   if (!($43)) {
    $temp$0$i = $42;
    $46 = (($temp$0$i) + 232|0);
    __ZN15TerrainRenderer21RecursiveRenderMeshesER12QuadTreeNodeR9Heightmap($this,$3,$46);
    STACKTOP = sp;return;
   }
  }
 }
 $44 = HEAP32[$11>>2]|0;
 $45 = (__Z31ReadObjectFromPersistentManageri($44)|0);
 $temp$0$i = $45;
 $46 = (($temp$0$i) + 232|0);
 __ZN15TerrainRenderer21RecursiveRenderMeshesER12QuadTreeNodeR9Heightmap($this,$3,$46);
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer21RecursiveRenderMeshesER12QuadTreeNodeR9Heightmap($this,$node,$heightmap) {
 $this = $this|0;
 $node = $node|0;
 $heightmap = $heightmap|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($node) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2);
 if ($2) {
  $3 = (($node) + 80|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(2);
  if ($5) {
   $6 = (($node) + 72|0);
   $7 = Math_fround(HEAPF32[$6>>2]);
   $8 = $7 == Math_fround(inf);
   $10 = $8;
  } else {
   $10 = 1;
  }
  $9 = (__ZN15TerrainRenderer17CalculateEdgeMaskER12QuadTreeNode($this,$node)|0);
  __ZN15TerrainRenderer13BuildRendererER12QuadTreeNodebi($this,$node,$10,$9);
  __ZN15TerrainRenderer10RenderNodeER12QuadTreeNode($this,$node);
  $11 = HEAP32[$3>>2]|0;
  $12 = ($11|0)==(1);
  if (!($12)) {
   $43 = HEAP32[$0>>2]|0;
   $44 = (($node) + 80|0);
   HEAP32[$44>>2] = $43;
   STACKTOP = sp;return;
  }
  $13 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,0)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$13);
  $14 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,1)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$14);
  $15 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,2)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$15);
  $16 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,3)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$16);
  $43 = HEAP32[$0>>2]|0;
  $44 = (($node) + 80|0);
  HEAP32[$44>>2] = $43;
  STACKTOP = sp;return;
 }
 $17 = ($1|0)==(1);
 $18 = (($node) + 80|0);
 $19 = HEAP32[$18>>2]|0;
 if ($17) {
  $20 = ($19|0)==(2);
  if ($20) {
   $21 = (($node) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if (!($23)) {
    __ZN15TerrainRenderer24ReclaimPatchVertexBufferEP12VertexBuffer($this,$22);
    HEAP32[$node>>2] = 0;
    HEAP32[$21>>2] = 0;
    $24 = (($node) + 8|0);
    HEAP32[$24>>2] = 0;
   }
   $25 = (($node) + 120|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = $26 & -7;
   HEAP8[$25>>0] = $27;
  }
  $28 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,0)|0);
  __ZN15TerrainRenderer21RecursiveRenderMeshesER12QuadTreeNodeR9Heightmap($this,$28,$heightmap);
  $29 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,1)|0);
  __ZN15TerrainRenderer21RecursiveRenderMeshesER12QuadTreeNodeR9Heightmap($this,$29,$heightmap);
  $30 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,2)|0);
  __ZN15TerrainRenderer21RecursiveRenderMeshesER12QuadTreeNodeR9Heightmap($this,$30,$heightmap);
  $31 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,3)|0);
  __ZN15TerrainRenderer21RecursiveRenderMeshesER12QuadTreeNodeR9Heightmap($this,$31,$heightmap);
  $43 = HEAP32[$0>>2]|0;
  $44 = (($node) + 80|0);
  HEAP32[$44>>2] = $43;
  STACKTOP = sp;return;
 }
 if ((($19|0) == 2)) {
  $36 = (($node) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   __ZN15TerrainRenderer24ReclaimPatchVertexBufferEP12VertexBuffer($this,$37);
   HEAP32[$node>>2] = 0;
   HEAP32[$36>>2] = 0;
   $39 = (($node) + 8|0);
   HEAP32[$39>>2] = 0;
  }
  $40 = (($node) + 120|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41 & -7;
  HEAP8[$40>>0] = $42;
  $43 = HEAP32[$0>>2]|0;
  $44 = (($node) + 80|0);
  HEAP32[$44>>2] = $43;
  STACKTOP = sp;return;
 } else if ((($19|0) == 1)) {
  $32 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,0)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$32);
  $33 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,1)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$33);
  $34 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,2)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$34);
  $35 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,3)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$35);
  $43 = HEAP32[$0>>2]|0;
  $44 = (($node) + 80|0);
  HEAP32[$44>>2] = $43;
  STACKTOP = sp;return;
 } else {
  $43 = HEAP32[$0>>2]|0;
  $44 = (($node) + 80|0);
  HEAP32[$44>>2] = $43;
  STACKTOP = sp;return;
 }
}
function __ZN15TerrainRenderer9ReloadAllEv($this) {
 $this = $this|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $pos$i$i$i$i1 = 0, $temp$0$i = 0, $temp$0$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $8 = $3;$98 = $5;
  while(1) {
   $7 = (($8) + 76|0);
   $9 = HEAP32[$7>>2]|0;
   $10 = ($9|0)==(2);
   if ($10) {
    $11 = (($8) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     __ZN15TerrainRenderer24ReclaimPatchVertexBufferEP12VertexBuffer($this,$12);
     HEAP32[$8>>2] = 0;
     HEAP32[$11>>2] = 0;
     $14 = (($8) + 8|0);
     HEAP32[$14>>2] = 0;
    }
    $15 = (($8) + 120|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = $16 & -7;
    HEAP8[$15>>0] = $17;
    $$pre$i = HEAP32[$4>>2]|0;
    $21 = $$pre$i;
   } else {
    $21 = $98;
   }
   HEAP32[$7>>2] = 0;
   $18 = (($8) + 80|0);
   HEAP32[$18>>2] = 0;
   $19 = (($8) + 124|0);
   $20 = ($19|0)==($21|0);
   if ($20) {
    break;
   } else {
    $8 = $19;$98 = $21;
   }
  }
 }
 $22 = (($this) + 16|0);
 $23 = (($this) + 104|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$1>>2] = $24;
 $25 = HEAP32[560624>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  label = 15;
 } else {
  $27 = (($25) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($25) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28|0)==($30|0);
  do {
   if ($31) {
    $32 = (($25) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($25) + 32|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($33) + ($35<<3)|0);
    $52 = $36;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$25,$1);
    $37 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $38 = ($37|0)==(-1);
    $39 = (($25) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    if ($38) {
     $41 = (($25) + 32|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($40) + ($42<<3)|0);
     $52 = $43;
     break;
    } else {
     $44 = (($40) + ($37<<3)|0);
     $52 = $44;
     break;
    }
   }
  } while(0);
  $45 = HEAP32[560624>>2]|0;
  $46 = (($45) + 28|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + 32|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($47) + ($49<<3)|0);
  $51 = ($52|0)==($50|0);
  if ($51) {
   label = 15;
  } else {
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    label = 15;
   } else {
    $temp$0$i = $54;
   }
  }
 }
 if ((label|0) == 15) {
  $56 = HEAP32[$23>>2]|0;
  $57 = (__Z31ReadObjectFromPersistentManageri($56)|0);
  $temp$0$i = $57;
 }
 $58 = (($temp$0$i) + 232|0);
 $59 = (($58) + 80|0);
 ;HEAP32[$22+0>>2]=HEAP32[$59+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$59+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$59+8>>2]|0;
 $60 = HEAP32[$23>>2]|0;
 HEAP32[$0>>2] = $60;
 $61 = HEAP32[560624>>2]|0;
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  $63 = (($61) + 36|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($61) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ($64|0)==($66|0);
  do {
   if ($67) {
    $68 = (($61) + 28|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($61) + 32|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($69) + ($71<<3)|0);
    $88 = $72;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i1,$61,$0);
    $73 = HEAP32[$pos$i$i$i$i1>>2]|0;
    $74 = ($73|0)==(-1);
    $75 = (($61) + 28|0);
    $76 = HEAP32[$75>>2]|0;
    if ($74) {
     $77 = (($61) + 32|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = (($76) + ($78<<3)|0);
     $88 = $79;
     break;
    } else {
     $80 = (($76) + ($73<<3)|0);
     $88 = $80;
     break;
    }
   }
  } while(0);
  $81 = HEAP32[560624>>2]|0;
  $82 = (($81) + 28|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($81) + 32|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = (($83) + ($85<<3)|0);
  $87 = ($88|0)==($86|0);
  if (!($87)) {
   $89 = (($88) + 4|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = ($90|0)==(0|0);
   if (!($91)) {
    $temp$0$i5 = $90;
    $94 = (($temp$0$i5) + 232|0);
    $95 = (($94) + 72|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($this) + 40|0);
    HEAP32[$97>>2] = $96;
    __ZN15TerrainRenderer12RebuildNodesEv($this);
    STACKTOP = sp;return;
   }
  }
 }
 $92 = HEAP32[$23>>2]|0;
 $93 = (__Z31ReadObjectFromPersistentManageri($92)|0);
 $temp$0$i5 = $93;
 $94 = (($temp$0$i5) + 232|0);
 $95 = (($94) + 72|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (($this) + 40|0);
 HEAP32[$97>>2] = $96;
 __ZN15TerrainRenderer12RebuildNodesEv($this);
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer19UnloadFromGfxDeviceEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$04 = 0, $i1$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  $11 = $2;
  while(1) {
   $10 = (($11) + 4|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    __ZN15TerrainRenderer24ReclaimPatchVertexBufferEP12VertexBuffer($this,$12);
    HEAP32[$11>>2] = 0;
    HEAP32[$10>>2] = 0;
    $14 = (($11) + 8|0);
    HEAP32[$14>>2] = 0;
   }
   $15 = (($11) + 120|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = $16 | 6;
   HEAP8[$15>>0] = $17;
   $18 = (($11) + 124|0);
   $19 = HEAP32[$3>>2]|0;
   $20 = ($18|0)==($19|0);
   if ($20) {
    break;
   } else {
    $11 = $18;
   }
  }
 }
 $6 = (($this) + 144|0);
 $7 = (($this) + 152|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $i$04 = 0;
  while(1) {
   $21 = (__Z12GetGfxDevicev()|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 292|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$6>>2]|0;
   $26 = (($25) + ($i$04<<2)|0);
   $27 = HEAP32[$26>>2]|0;
   FUNCTION_TABLE_vii[$24 & 4095]($21,$27);
   $28 = (($i$04) + 1)|0;
   $29 = HEAP32[$7>>2]|0;
   $30 = ($28>>>0)<($29>>>0);
   if ($30) {
    $i$04 = $28;
   } else {
    break;
   }
  }
 }
 $31 = (($this) + 156|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)>(-1);
 if ($33) {
  $34 = HEAP32[$6>>2]|0;
  $35 = (($this) + 148|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$0>>2] = $36;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($34,$$byval_copy);
  HEAP32[$6>>2] = 0;
 }
 HEAP32[$7>>2] = 0;
 HEAP32[$31>>2] = 0;
 $i1$02 = 0;
 while(1) {
  $37 = ((($this) + ($i1$02<<3)|0) + 164|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   $40 = (__Z12GetGfxDevicev()|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 272|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = HEAP32[$37>>2]|0;
   FUNCTION_TABLE_vii[$43 & 4095]($40,$44);
  }
  HEAP32[$37>>2] = 0;
  $45 = (($i1$02) + 1)|0;
  $exitcond = ($45|0)==(16);
  if ($exitcond) {
   break;
  } else {
   $i1$02 = $45;
  }
 }
 $46 = (($this) + 320|0);
 HEAP32[$46>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer17ReloadToGfxDeviceEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer26MarkChildVisibilityRecurseER12QuadTreeNodei($this,$node,$newVisibility) {
 $this = $this|0;
 $node = $node|0;
 $newVisibility = $newVisibility|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($node) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,0)|0);
 $4 = (($3) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==($newVisibility|0);
 if (!($6)) {
  HEAP32[$4>>2] = $newVisibility;
  __ZN15TerrainRenderer26MarkChildVisibilityRecurseER12QuadTreeNodei($this,$3,$newVisibility);
 }
 $7 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,1)|0);
 $8 = (($7) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($newVisibility|0);
 if (!($10)) {
  HEAP32[$8>>2] = $newVisibility;
  __ZN15TerrainRenderer26MarkChildVisibilityRecurseER12QuadTreeNodei($this,$7,$newVisibility);
 }
 $11 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,2)|0);
 $12 = (($11) + 76|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($newVisibility|0);
 if (!($14)) {
  HEAP32[$12>>2] = $newVisibility;
  __ZN15TerrainRenderer26MarkChildVisibilityRecurseER12QuadTreeNodei($this,$11,$newVisibility);
 }
 $15 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,3)|0);
 $16 = (($15) + 76|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==($newVisibility|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 HEAP32[$16>>2] = $newVisibility;
 __ZN15TerrainRenderer26MarkChildVisibilityRecurseER12QuadTreeNodei($this,$15,$newVisibility);
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer22ReloadPrecomputedErrorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[560624>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 9;
 } else {
  $5 = (($3) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $10 = (($3) + 28|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($3) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + ($13<<3)|0);
    $30 = $14;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
    $15 = HEAP32[$pos$i$i$i$i>>2]|0;
    $16 = ($15|0)==(-1);
    $17 = (($3) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    if ($16) {
     $19 = (($3) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $30 = $21;
     break;
    } else {
     $22 = (($18) + ($15<<3)|0);
     $30 = $22;
     break;
    }
   }
  } while(0);
  $23 = HEAP32[560624>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + ($27<<3)|0);
  $29 = ($30|0)==($28|0);
  if ($29) {
   label = 9;
  } else {
   $31 = (($30) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 9;
   } else {
    $temp$0$i = $32;
   }
  }
 }
 if ((label|0) == 9) {
  $34 = HEAP32[$1>>2]|0;
  $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
  $temp$0$i = $35;
 }
 $36 = (($temp$0$i) + 232|0);
 $37 = (($this) + 28|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($this) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($38|0)==($40|0);
 if ($41) {
  STACKTOP = sp;return;
 } else {
  $43 = $38;
 }
 while(1) {
  $42 = (($43) + 84|0);
  $44 = HEAP32[$42>>2]|0;
  $45 = (($43) + 88|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($43) + 92|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (Math_fround(__ZNK9Heightmap21GetMaximumHeightErrorEiii($36,$44,$46,$48)));
  $50 = (($43) + 72|0);
  HEAPF32[$50>>2] = $49;
  $51 = (($43) + 120|0);
  $52 = HEAP8[$51>>0]|0;
  $53 = $52 | 2;
  HEAP8[$51>>0] = $53;
  $54 = (($43) + 124|0);
  $55 = HEAP32[$39>>2]|0;
  $56 = ($54|0)==($55|0);
  if ($56) {
   break;
  } else {
   $43 = $54;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer16ForceSplitParentER12QuadTreeNode($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0);
 var $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $exitcond = 0;
 var $fSqrDistance$1$1$i = Math_fround(0), $fSqrDistance$1$2$i = Math_fround(0), $fSqrDistance$1$i = Math_fround(0), $i$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($node) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1|0) / 2)&-1;
 $3 = (($node) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4|0) / 2)&-1;
 $6 = (($node) + 92|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 $9 = (__ZN15TerrainRenderer7GetNodeEiii($this,$2,$5,$8)|0);
 $10 = (($9) + 76|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  __ZN15TerrainRenderer16ForceSplitParentER12QuadTreeNode($this,$9);
  $$pr = HEAP32[$10>>2]|0;
  $14 = $$pr;
 } else {
  $14 = $11;
 }
 $13 = ($14|0)==(2);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 60|0);
 $16 = (($this) + 64|0);
 $17 = (($this) + 68|0);
 $18 = (($this) + 80|0);
 $i$03 = 0;
 while(1) {
  $23 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$9,$i$03)|0);
  $24 = (($23) + 76|0);
  HEAP32[$24>>2] = 2;
  $25 = Math_fround(HEAPF32[$15>>2]);
  $26 = (($23) + 96|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = Math_fround($25 - $27);
  $29 = Math_fround(HEAPF32[$16>>2]);
  $30 = (($23) + 100|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = Math_fround($29 - $31);
  $33 = Math_fround(HEAPF32[$17>>2]);
  $34 = (($23) + 104|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = Math_fround($33 - $35);
  $37 = (($23) + 108|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = Math_fround(-$38);
  $40 = $28 < $39;
  if ($40) {
   $41 = Math_fround($28 + $38);
   $42 = Math_fround($41 * $41);
   $43 = Math_fround($42 + Math_fround(0.0));
   $fSqrDistance$1$i = $43;
  } else {
   $44 = $28 > $38;
   if ($44) {
    $45 = Math_fround($28 - $38);
    $46 = Math_fround($45 * $45);
    $47 = Math_fround($46 + Math_fround(0.0));
    $fSqrDistance$1$i = $47;
   } else {
    $fSqrDistance$1$i = Math_fround(0.0);
   }
  }
  $48 = (($37) + 4|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = Math_fround(-$49);
  $51 = $32 < $50;
  if ($51) {
   $56 = Math_fround($32 + $49);
   $57 = Math_fround($56 * $56);
   $58 = Math_fround($fSqrDistance$1$i + $57);
   $fSqrDistance$1$1$i = $58;
  } else {
   $52 = $32 > $49;
   if ($52) {
    $53 = Math_fround($32 - $49);
    $54 = Math_fround($53 * $53);
    $55 = Math_fround($fSqrDistance$1$i + $54);
    $fSqrDistance$1$1$i = $55;
   } else {
    $fSqrDistance$1$1$i = $fSqrDistance$1$i;
   }
  }
  $59 = (($37) + 8|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = Math_fround(-$60);
  $62 = $36 < $61;
  if ($62) {
   $67 = Math_fround($36 + $60);
   $68 = Math_fround($67 * $67);
   $69 = Math_fround($fSqrDistance$1$1$i + $68);
   $fSqrDistance$1$2$i = $69;
  } else {
   $63 = $36 > $60;
   if ($63) {
    $64 = Math_fround($36 - $60);
    $65 = Math_fround($64 * $64);
    $66 = Math_fround($fSqrDistance$1$1$i + $65);
    $fSqrDistance$1$2$i = $66;
   } else {
    $fSqrDistance$1$2$i = $fSqrDistance$1$1$i;
   }
  }
  $70 = Math_fround(HEAPF32[$18>>2]);
  $71 = $fSqrDistance$1$2$i < $70;
  $72 = (($23) + 120|0);
  $73 = $71&1;
  $74 = HEAP8[$72>>0]|0;
  $75 = $74 & -2;
  $76 = $75 | $73;
  HEAP8[$72>>0] = $76;
  __ZN15TerrainRenderer26MarkChildVisibilityRecurseER12QuadTreeNodei($this,$23,0);
  $77 = (($i$03) + 1)|0;
  $exitcond = ($77|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $i$03 = $77;
  }
 }
 $19 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$9,0)|0);
 __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$19);
 $20 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$9,1)|0);
 __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$20);
 $21 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$9,2)|0);
 __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$21);
 $22 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$9,3)|0);
 __ZN15TerrainRenderer21EnforceLodTransitionsER12QuadTreeNode($this,$22);
 HEAP32[$10>>2] = 1;
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($node) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 1)) {
  $2 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,0)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$2);
  $3 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,1)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$3);
  $4 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,2)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$4);
  $5 = (__ZN15TerrainRenderer9FindChildER12QuadTreeNodei($this,$node,3)|0);
  __ZN15TerrainRenderer21RecursiveRemoveMeshesER12QuadTreeNode($this,$5);
 } else if ((($1|0) == 2)) {
  $6 = (($node) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   __ZN15TerrainRenderer24ReclaimPatchVertexBufferEP12VertexBuffer($this,$7);
   HEAP32[$node>>2] = 0;
   HEAP32[$6>>2] = 0;
   $9 = (($node) + 8|0);
   HEAP32[$9>>2] = 0;
  }
  $10 = (($node) + 120|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 & -7;
  HEAP8[$10>>0] = $12;
 } else if ((($1|0) == 0)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer10RenderNodeER12QuadTreeNode($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $exitcond = 0, $m$01 = 0, $matrix = 0, $position = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $position = sp + 64|0;
 $matrix = sp;
 ;HEAP32[$position+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$position+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$position+8>>2]=HEAP32[616680+8>>2]|0;
 $0 = (($this) + 44|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$position>>2]);
 $3 = Math_fround($1 + $2);
 HEAPF32[$position>>2] = $3;
 $4 = (($this) + 48|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($position) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($5 + $7);
 HEAPF32[$6>>2] = $8;
 $9 = (($this) + 52|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($position) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 + $12);
 HEAPF32[$11>>2] = $13;
 (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($matrix,$position)|0);
 $14 = (($node) + 120|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15 & 1;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $26 = (($this) + 92|0);
  $27 = HEAP32[$26>>2]|0;
  __ZN15TerrainRenderer26CreateQuadTreeNodeRendererER12QuadTreeNodeRK10Matrix4x4fPN5Unity8MaterialE($this,$node,$matrix,$27);
  STACKTOP = sp;return;
 }
 $18 = (($this) + 96|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (($this) + 100|0);
 $m$01 = 0;
 while(1) {
  $22 = HEAP32[$21>>2]|0;
  $23 = (($22) + ($m$01<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  __ZN15TerrainRenderer26CreateQuadTreeNodeRendererER12QuadTreeNodeRK10Matrix4x4fPN5Unity8MaterialE($this,$node,$matrix,$24);
  $25 = (($m$01) + 1)|0;
  $exitcond = ($25|0)==($19|0);
  if ($exitcond) {
   break;
  } else {
   $m$01 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer26CreateQuadTreeNodeRendererER12QuadTreeNodeRK10Matrix4x4fPN5Unity8MaterialE($this,$node,$matrix,$material) {
 $this = $this|0;
 $node = $node|0;
 $matrix = $matrix|0;
 $material = $material|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[800400>>2]|0;
 $2 = (__ZN10MemoryPool8AllocateEj($1,252)|0);
 __THREW__ = 0;
 invoke_vi(3712,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $24 = HEAP32[800400>>2]|0;
  __THREW__ = 0;
  invoke_vii(2609,($24|0),($2|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch(0|0)|0;
   $28 = tempRet0;
   ___clang_call_terminate($27);
   // unreachable;
  } else {
   ___resumeException($22|0);
   // unreachable;
  }
 }
 $5 = (($node) + 44|0);
 $6 = ($material|0)==(0|0);
 if ($6) {
  HEAP32[$0>>2] = 0;
 } else {
  $7 = (($material) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$0>>2] = $8;
 }
 $9 = (($this) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 56|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 __ZN20IntermediateRenderer10InitializeERK10Matrix4x4fRK4AABB4PPtrIN5Unity8MaterialEEibb($2,$matrix,$5,$0,$10,$13,1);
 __ZN20QuadTreeNodeRenderer5SetupEP15TerrainRendererP12QuadTreeNode($2,$this,$node);
 $14 = (($this) + 140|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = (($this) + 108|0);
 __ZN20QuadTreeNodeRenderer17SetLightmapParamsEtRK8Vector4f12LightmapType($2,$15,$16,0);
 $17 = (($14) + 2|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = (($this) + 124|0);
 __ZN20QuadTreeNodeRenderer17SetLightmapParamsEtRK8Vector4f12LightmapType($2,$18,$19,1);
 $20 = (($this) + 88|0);
 $21 = HEAP32[$20>>2]|0;
 __Z23AddIntermediateRendererP20IntermediateRendererP6Camera($2,$21);
 STACKTOP = sp;return;
}
function __ZN15TerrainRenderer13BuildRendererER12QuadTreeNodebi($this,$node,$updateMesh,$edgeMask) {
 $this = $this|0;
 $node = $node|0;
 $updateMesh = $updateMesh|0;
 $edgeMask = $edgeMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 8|0;
 if ($updateMesh) {
  $2 = (($node) + 44|0);
  $3 = (($this) + 104|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP32[$0>>2] = $4;
  $5 = HEAP32[560624>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   label = 10;
  } else {
   $7 = (($5) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   do {
    if ($11) {
     $12 = (($5) + 28|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($5) + 32|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($13) + ($15<<3)|0);
     $32 = $16;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$5,$0);
     $17 = HEAP32[$pos$i$i$i$i>>2]|0;
     $18 = ($17|0)==(-1);
     $19 = (($5) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     if ($18) {
      $21 = (($5) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $32 = $23;
      break;
     } else {
      $24 = (($20) + ($17<<3)|0);
      $32 = $24;
      break;
     }
    }
   } while(0);
   $25 = HEAP32[560624>>2]|0;
   $26 = (($25) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 32|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + ($29<<3)|0);
   $31 = ($32|0)==($30|0);
   if ($31) {
    label = 10;
   } else {
    $33 = (($32) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if ($35) {
     label = 10;
    } else {
     $temp$0$i = $34;
    }
   }
  }
  if ((label|0) == 10) {
   $36 = HEAP32[$3>>2]|0;
   $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
   $temp$0$i = $37;
  }
  $38 = (($temp$0$i) + 232|0);
  $39 = (($node) + 84|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($node) + 88|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($node) + 92|0);
  $44 = HEAP32[$43>>2]|0;
  __ZNK9Heightmap9GetBoundsEiii($1,$38,$40,$42,$44);
  ;HEAP32[$2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$1+20>>2]|0;
  $45 = (($node) + 120|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46 | 2;
  HEAP8[$45>>0] = $47;
 }
 $48 = (($node) + 68|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==($edgeMask|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 HEAP32[$48>>2] = $edgeMask;
 $51 = (($node) + 120|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = $52 | 4;
 HEAP8[$51>>0] = $53;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI12QuadTreeNodeNS_9allocatorIS1_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i4 = 0, $$0$i712 = 0, $$0$i713 = 0, $$01$i$i = 0, $$pre$i2 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $scevgep = 0, $scevgep11 = 0, $uglygep = 0, $uglygep10 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 124)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $10 = (($0) + 12|0);
  $$0$i = $__n;$12 = $4;
  while(1) {
   $11 = ($12|0)==(0|0);
   if ($11) {
    $26 = 0;
   } else {
    $13 = (($12) + 12|0);
    $14 = (($12) + 44|0);
    dest=$13+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    ;HEAP32[$0+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[616680+8>>2]|0;
    ;HEAP32[$10+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[616680+8>>2]|0;
    ;HEAP32[$14+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$14+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$14+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$14+20>>2]=HEAP32[$0+20>>2]|0;
    $15 = (($12) + 96|0);
    ;HEAP32[$15+0>>2]=0|0;HEAP32[$15+4>>2]=0|0;HEAP32[$15+8>>2]=0|0;HEAP32[$15+12>>2]=0|0;HEAP32[$15+16>>2]=0|0;HEAP32[$15+20>>2]=0|0;
    $16 = (($12) + 68|0);
    HEAP32[$16>>2] = -1;
    $17 = (($12) + 72|0);
    HEAPF32[$17>>2] = Math_fround(1.0);
    $18 = (($12) + 76|0);
    HEAP32[$18>>2] = 0;
    $19 = (($12) + 80|0);
    HEAP32[$19>>2] = 0;
    $20 = (($12) + 120|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21 & -7;
    HEAP8[$20>>0] = $22;
    HEAP32[$12>>2] = 0;
    $23 = (($12) + 4|0);
    HEAP32[$23>>2] = 0;
    $24 = (($12) + 8|0);
    HEAP32[$24>>2] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $26 = $$pre1$i;
   }
   $25 = (($26) + 124|0);
   HEAP32[$3>>2] = $25;
   $27 = (($$0$i) + -1)|0;
   $28 = ($27|0)==(0);
   if ($28) {
    break;
   } else {
    $$0$i = $27;$12 = $25;
   }
  }
  STACKTOP = sp;return;
 }
 $29 = HEAP32[$this>>2]|0;
 $30 = $29;
 $31 = (($6) - ($30))|0;
 $32 = (($31|0) / 124)&-1;
 $33 = (($32) + ($__n))|0;
 $34 = ($33>>>0)>(34636833);
 if ($34) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $35 = (($5) - ($30))|0;
 $36 = (($35|0) / 124)&-1;
 $37 = ($36>>>0)<(17318416);
 if ($37) {
  $38 = $36 << 1;
  $39 = ($38>>>0)<($33>>>0);
  $40 = $39 ? $33 : $38;
  $41 = ($40|0)==(0);
  if ($41) {
   $$0$i713 = 0;$45 = 0;
  } else {
   $$0$i712 = $40;
   label = 10;
  }
 } else {
  $$0$i712 = 34636833;
  label = 10;
 }
 if ((label|0) == 10) {
  $42 = ($$0$i712*124)|0;
  $43 = (__Znwj($42)|0);
  $$0$i713 = $$0$i712;$45 = $43;
 }
 $44 = (($45) + (($32*124)|0)|0);
 $46 = (($0) + 12|0);
 $$0$i4 = $__n;$48 = $44;
 while(1) {
  $47 = ($48|0)==(0|0);
  if ($47) {
   $62 = 0;
  } else {
   $49 = (($48) + 12|0);
   $50 = (($48) + 44|0);
   dest=$49+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   ;HEAP32[$0+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[616680+8>>2]|0;
   ;HEAP32[$46+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$46+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[616680+8>>2]|0;
   ;HEAP32[$50+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$50+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$50+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$50+20>>2]=HEAP32[$0+20>>2]|0;
   $51 = (($48) + 96|0);
   ;HEAP32[$51+0>>2]=0|0;HEAP32[$51+4>>2]=0|0;HEAP32[$51+8>>2]=0|0;HEAP32[$51+12>>2]=0|0;HEAP32[$51+16>>2]=0|0;HEAP32[$51+20>>2]=0|0;
   $52 = (($48) + 68|0);
   HEAP32[$52>>2] = -1;
   $53 = (($48) + 72|0);
   HEAPF32[$53>>2] = Math_fround(1.0);
   $54 = (($48) + 76|0);
   HEAP32[$54>>2] = 0;
   $55 = (($48) + 80|0);
   HEAP32[$55>>2] = 0;
   $56 = (($48) + 120|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = $57 & -7;
   HEAP8[$56>>0] = $58;
   HEAP32[$48>>2] = 0;
   $59 = (($48) + 4|0);
   HEAP32[$59>>2] = 0;
   $60 = (($48) + 8|0);
   HEAP32[$60>>2] = 0;
   $62 = $48;
  }
  $61 = (($62) + 124|0);
  $63 = (($$0$i4) + -1)|0;
  $64 = ($63|0)==(0);
  if ($64) {
   break;
  } else {
   $$0$i4 = $63;$48 = $61;
  }
 }
 $65 = (($45) + (($$0$i713*124)|0)|0);
 $66 = HEAP32[$this>>2]|0;
 $67 = HEAP32[$3>>2]|0;
 $68 = ($67|0)==($66|0);
 if ($68) {
  $78 = $44;$80 = $66;
 } else {
  $69 = $66;
  $70 = (($32) + -1)|0;
  $scevgep = (($67) + -124|0);
  $71 = (0 - ($69))|0;
  $uglygep = (($scevgep) + ($71)|0);
  $uglygep10 = $uglygep;
  $72 = (($uglygep10>>>0) / 124)&-1;
  $73 = (($70) - ($72))|0;
  $$01$i$i = $67;$75 = $44;
  while(1) {
   $74 = (($75) + -124|0);
   $76 = (($$01$i$i) + -124|0);
   dest=$74+0|0; src=$76+0|0; stop=dest+124|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $77 = ($76|0)==($66|0);
   if ($77) {
    break;
   } else {
    $$01$i$i = $76;$75 = $74;
   }
  }
  $scevgep11 = (($45) + (($73*124)|0)|0);
  $$pre$i2 = HEAP32[$this>>2]|0;
  $78 = $scevgep11;$80 = $$pre$i2;
 }
 HEAP32[$this>>2] = $78;
 HEAP32[$3>>2] = $61;
 HEAP32[$1>>2] = $65;
 $79 = ($80|0)==(0|0);
 if ($79) {
  STACKTOP = sp;return;
 }
 __ZdlPv($80);
 STACKTOP = sp;return;
}
function __ZN14TerrainManagerC2Ev($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $__f$0$i$i$i$i = 0, $__f$0$i$i$i$i5 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((802256 + 8|0));
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $2;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = $5;
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 24|0);
 HEAP32[$7>>2] = 0;
 $8 = HEAP32[628440>>2]|0;
 $9 = (($this) + 28|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 32|0);
 HEAP32[$10>>2] = $8;
 $11 = (($this) + 36|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 40|0);
 HEAP32[$12>>2] = 0;
 __THREW__ = 0;
 $13 = (invoke_i(78)|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if (!($15)) {
  $i$01$i = 0;
  while(1) {
   $18 = ((($13) + ($i$01$i<<2)|0) + 896|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0|0);
   $17 = (($i$01$i) + 1)|0;
   if ($20) {
    break;
   }
   $16 = ($17|0)<(16);
   if ($16) {
    $i$01$i = $17;
   } else {
    label = 5;
    break;
   }
  }
  if ((label|0) == 5) {
   STACKTOP = sp;return;
  }
  HEAP32[$18>>2] = 3414;
  STACKTOP = sp;return;
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $23 = HEAP32[$12>>2]|0;
 $24 = ($23|0)>(-1);
 do {
  if ($24) {
   $25 = HEAP32[$9>>2]|0;
   $26 = HEAP32[$10>>2]|0;
   HEAP32[$0>>2] = $26;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($25|0),($$byval_copy2|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $63 = ___cxa_find_matching_catch(0|0)|0;
    $64 = tempRet0;
    ___clang_call_terminate($63);
    // unreachable;
   } else {
    HEAP32[$9>>2] = 0;
    break;
   }
  }
 } while(0);
 $29 = HEAP32[$7>>2]|0;
 $30 = ($29|0)==(0);
 L16: do {
  if (!($30)) {
   $31 = HEAP32[$6>>2]|0;
   $32 = HEAP32[$5>>2]|0;
   $33 = (($32) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$31>>2]|0;
   $36 = (($35) + 4|0);
   HEAP32[$36>>2] = $34;
   $37 = HEAP32[$31>>2]|0;
   $38 = HEAP32[$33>>2]|0;
   HEAP32[$38>>2] = $37;
   HEAP32[$7>>2] = 0;
   $__f$0$i$i$i$i5 = $31;
   while(1) {
    $39 = ($__f$0$i$i$i$i5|0)==($5|0);
    if ($39) {
     break L16;
    }
    $40 = (($__f$0$i$i$i$i5) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$0>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($__f$0$i$i$i$i5|0),($$byval_copy2|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     break;
    } else {
     $__f$0$i$i$i$i5 = $41;
    }
   }
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   ___cxa_call_unexpected(($44|0));
   // unreachable;
  }
 } while(0);
 $46 = HEAP32[$4>>2]|0;
 $47 = ($46|0)==(0);
 if ($47) {
  ___resumeException($21|0);
  // unreachable;
 }
 $48 = HEAP32[$3>>2]|0;
 $49 = HEAP32[$2>>2]|0;
 $50 = (($49) + 4|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = HEAP32[$48>>2]|0;
 $53 = (($52) + 4|0);
 HEAP32[$53>>2] = $51;
 $54 = HEAP32[$48>>2]|0;
 $55 = HEAP32[$50>>2]|0;
 HEAP32[$55>>2] = $54;
 HEAP32[$4>>2] = 0;
 $__f$0$i$i$i$i = $48;
 while(1) {
  $56 = ($__f$0$i$i$i$i|0)==($2|0);
  if ($56) {
   label = 19;
   break;
  }
  $57 = (($__f$0$i$i$i$i) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  HEAP32[$1>>2] = 44;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($__f$0$i$i$i$i|0),($$byval_copy2|0));
  $59 = __THREW__; __THREW__ = 0;
  $60 = $59&1;
  if ($60) {
   label = 18;
   break;
  } else {
   $__f$0$i$i$i$i = $58;
  }
 }
 if ((label|0) == 18) {
  $61 = ___cxa_find_matching_catch()|0;
  $62 = tempRet0;
  ___cxa_call_unexpected(($61|0));
  // unreachable;
 }
 else if ((label|0) == 19) {
  ___resumeException($21|0);
  // unreachable;
 }
}
function __ZN14TerrainManager23AfterCullingOutputReadyEPK9IndexListPK16RendererCullData($visible,$renderers) {
 $visible = $visible|0;
 $renderers = $renderers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetITerrainManagerv()|0);
 $1 = (($visible) + 48|0);
 $2 = (($renderers) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($0) + 28|0);
 __ZN12TreeRenderer15WillRenderTreesERK9IndexListPK9SceneNodeR13dynamic_arrayIbLj1EE($1,$3,$4);
 STACKTOP = sp;return;
}
function __ZN14TerrainManagerD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1325,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN14TerrainManagerD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__f$0$i$i$i$i = 0, $__f$0$i$i$i$i12 = 0, $__f$0$i$i$i$i4 = 0, $__f$0$i$i$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = ((802256 + 8|0));
 __THREW__ = 0;
 $3 = (invoke_i(78)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if ($5) {
   $56 = ___cxa_find_matching_catch()|0;
   $57 = tempRet0;
   $58 = (($this) + 40|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)>(-1);
   if ($60) {
    $61 = (($this) + 28|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($this) + 32|0);
    $64 = HEAP32[$63>>2]|0;
    HEAP32[$0>>2] = $64;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($62|0),($$byval_copy5|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     $109 = ___cxa_find_matching_catch(0|0)|0;
     $110 = tempRet0;
     ___clang_call_terminate($109);
     // unreachable;
    } else {
     HEAP32[$61>>2] = 0;
     $$0 = $57;$$01 = $56;
     break;
    }
   } else {
    $$0 = $57;$$01 = $56;
   }
  } else {
   $6 = (($3) + 896|0);
   __ZN17CallbackArrayBaseIPFvPK9IndexListPK16RendererCullDataEE10UnregisterES7_($6,3414);
   $7 = (($this) + 40|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)>(-1);
   do {
    if ($9) {
     $10 = (($this) + 28|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($this) + 32|0);
     $13 = HEAP32[$12>>2]|0;
     HEAP32[$2>>2] = $13;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($11|0),($$byval_copy5|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      $67 = ___cxa_find_matching_catch()|0;
      $68 = tempRet0;
      $$0 = $68;$$01 = $67;
      break L1;
     } else {
      HEAP32[$10>>2] = 0;
      break;
     }
    }
   } while(0);
   $16 = (($this) + 16|0);
   $17 = (($this) + 24|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0);
   L14: do {
    if (!($19)) {
     $20 = (($this) + 20|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$16>>2]|0;
     $23 = (($22) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$21>>2]|0;
     $26 = (($25) + 4|0);
     HEAP32[$26>>2] = $24;
     $27 = HEAP32[$21>>2]|0;
     $28 = HEAP32[$23>>2]|0;
     HEAP32[$28>>2] = $27;
     HEAP32[$17>>2] = 0;
     $__f$0$i$i$i$i = $21;
     while(1) {
      $29 = ($__f$0$i$i$i$i|0)==($16|0);
      if ($29) {
       break L14;
      }
      $30 = (($__f$0$i$i$i$i) + 4|0);
      $31 = HEAP32[$30>>2]|0;
      HEAP32[$1>>2] = 44;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($__f$0$i$i$i$i|0),($$byval_copy5|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      } else {
       $__f$0$i$i$i$i = $31;
      }
     }
     $34 = ___cxa_find_matching_catch()|0;
     $35 = tempRet0;
     ___cxa_call_unexpected(($34|0));
     // unreachable;
    }
   } while(0);
   $36 = (($this) + 4|0);
   $37 = (($this) + 12|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0);
   if ($39) {
    STACKTOP = sp;return;
   }
   $40 = (($this) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = HEAP32[$36>>2]|0;
   $43 = (($42) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = HEAP32[$41>>2]|0;
   $46 = (($45) + 4|0);
   HEAP32[$46>>2] = $44;
   $47 = HEAP32[$41>>2]|0;
   $48 = HEAP32[$43>>2]|0;
   HEAP32[$48>>2] = $47;
   HEAP32[$37>>2] = 0;
   $__f$0$i$i$i$i4 = $41;
   while(1) {
    $49 = ($__f$0$i$i$i$i4|0)==($36|0);
    if ($49) {
     label = 15;
     break;
    }
    $50 = (($__f$0$i$i$i$i4) + 4|0);
    $51 = HEAP32[$50>>2]|0;
    HEAP32[$0>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($__f$0$i$i$i$i4|0),($$byval_copy5|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 14;
     break;
    } else {
     $__f$0$i$i$i$i4 = $51;
    }
   }
   if ((label|0) == 14) {
    $54 = ___cxa_find_matching_catch()|0;
    $55 = tempRet0;
    ___cxa_call_unexpected(($54|0));
    // unreachable;
   }
   else if ((label|0) == 15) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $69 = (($this) + 16|0);
 $70 = (($this) + 24|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = ($71|0)==(0);
 L31: do {
  if (!($72)) {
   $73 = (($this) + 20|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = HEAP32[$69>>2]|0;
   $76 = (($75) + 4|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = HEAP32[$74>>2]|0;
   $79 = (($78) + 4|0);
   HEAP32[$79>>2] = $77;
   $80 = HEAP32[$74>>2]|0;
   $81 = HEAP32[$76>>2]|0;
   HEAP32[$81>>2] = $80;
   HEAP32[$70>>2] = 0;
   $__f$0$i$i$i$i9 = $74;
   while(1) {
    $82 = ($__f$0$i$i$i$i9|0)==($69|0);
    if ($82) {
     break L31;
    }
    $83 = (($__f$0$i$i$i$i9) + 4|0);
    $84 = HEAP32[$83>>2]|0;
    HEAP32[$1>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($__f$0$i$i$i$i9|0),($$byval_copy5|0));
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     break;
    } else {
     $__f$0$i$i$i$i9 = $84;
    }
   }
   $87 = ___cxa_find_matching_catch()|0;
   $88 = tempRet0;
   ___cxa_call_unexpected(($87|0));
   // unreachable;
  }
 } while(0);
 $89 = (($this) + 4|0);
 $90 = (($this) + 12|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = ($91|0)==(0);
 if ($92) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $93 = (($this) + 8|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = HEAP32[$89>>2]|0;
 $96 = (($95) + 4|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = HEAP32[$94>>2]|0;
 $99 = (($98) + 4|0);
 HEAP32[$99>>2] = $97;
 $100 = HEAP32[$94>>2]|0;
 $101 = HEAP32[$96>>2]|0;
 HEAP32[$101>>2] = $100;
 HEAP32[$90>>2] = 0;
 $__f$0$i$i$i$i12 = $94;
 while(1) {
  $102 = ($__f$0$i$i$i$i12|0)==($89|0);
  if ($102) {
   label = 30;
   break;
  }
  $103 = (($__f$0$i$i$i$i12) + 4|0);
  $104 = HEAP32[$103>>2]|0;
  HEAP32[$0>>2] = 44;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($__f$0$i$i$i$i12|0),($$byval_copy5|0));
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if ($106) {
   label = 29;
   break;
  } else {
   $__f$0$i$i$i$i12 = $104;
  }
 }
 if ((label|0) == 29) {
  $107 = ___cxa_find_matching_catch()|0;
  $108 = tempRet0;
  ___cxa_call_unexpected(($107|0));
  // unreachable;
 }
 else if ((label|0) == 30) {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNK14TerrainManager21GetInterpolatedHeightEPK6ObjectRK8Vector3fS5_Rf($this,$inTerrainData,$terrainPosition,$position,$outputHeight) {
 $this = $this|0;
 $inTerrainData = $inTerrainData|0;
 $terrainPosition = $terrainPosition|0;
 $position = $position|0;
 $outputHeight = $outputHeight|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0);
 var $26 = Math_fround(0), $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $or$cond1 = 0, $terrainSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $terrainSize = sp;
 $0 = ($inTerrainData|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($inTerrainData) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 >>> 21;
 $4 = HEAP32[560640>>2]|0;
 $5 = Math_imul($4, $3)|0;
 $6 = (($5) + 156)|0;
 $7 = $6 >> 5;
 $8 = $7 << 5;
 $9 = (($6) - ($8))|0;
 $10 = HEAP32[560632>>2]|0;
 $11 = (($10) + ($7<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = 1 << $9;
 $14 = $13 & $12;
 $15 = ($14|0)==(0);
 if ($15) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = (($inTerrainData) + 232|0);
 __ZNK9Heightmap7GetSizeEv($terrainSize,$16);
 $17 = Math_fround(HEAPF32[$position>>2]);
 $18 = Math_fround(HEAPF32[$terrainPosition>>2]);
 $19 = Math_fround($17 - $18);
 $20 = (($terrainPosition) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = (($position) + 8|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = (($terrainPosition) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($23 - $25);
 $27 = Math_fround(HEAPF32[$terrainSize>>2]);
 $28 = Math_fround(Math_fround(1.0) / $27);
 $29 = (($terrainSize) + 8|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround(Math_fround(1.0) / $30);
 $32 = Math_fround($19 * $28);
 $33 = Math_fround($26 * $31);
 $34 = $32 > Math_fround(1.0);
 $35 = $32 < Math_fround(0.0);
 $or$cond = $34 | $35;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = $33 > Math_fround(1.0);
 $37 = $33 < Math_fround(0.0);
 $or$cond1 = $36 | $37;
 if ($or$cond1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $38 = (Math_fround(__ZNK9Heightmap21GetInterpolatedHeightEff($16,$32,$33)));
 $39 = Math_fround($21 + $38);
 HEAPF32[$outputHeight>>2] = $39;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14TerrainManager15CullAllTerrainsEi($this,$cullingMask) {
 $this = $this|0;
 $cullingMask = $cullingMask|0;
 var $$0 = 0, $$01 = 0, $$byval_copy5 = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre106 = 0, $$pre107 = 0, $$pre108 = 0, $$pre109 = 0, $$pre110 = 0, $$pre111 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0;
 var $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0;
 var $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = Math_fround(0), $517 = 0.0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = Math_fround(0), $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = Math_fround(0), $534 = 0.0, $535 = 0, $536 = 0, $537 = 0;
 var $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0;
 var $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0;
 var $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0;
 var $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = Math_fround(0), $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0;
 var $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0;
 var $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = Math_fround(0), $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = Math_fround(0), $66 = 0, $660 = 0, $661 = Math_fround(0), $662 = 0, $663 = Math_fround(0);
 var $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = Math_fround(0), $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0;
 var $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = Math_fround(0), $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__f$0$i$i = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2 = 0, $bottom$0 = 0, $left$0 = 0, $lights = 0, $offsetAndSize$i = 0, $phitmp$i = 0, $phitmp$i$i = 0, $phitmp$i38 = 0, $phitmp$i52 = 0, $phitmp$i66 = 0, $right$0 = 0;
 var $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $splatMats = 0, $temp$0$i = 0, $temp$0$i$i = 0, $temp$0$i32 = 0, $temp$0$i45 = 0, $temp$0$i59 = 0, $temp$0$i73 = 0, $top$0 = 0, $treeProbeSetHash$i = 0, $treeProbeSetIndexOffset$0$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy5 = sp + 128|0;
 $0 = sp + 124|0;
 $1 = sp + 120|0;
 $2 = sp + 116|0;
 $3 = sp + 112|0;
 $4 = sp + 108|0;
 $5 = sp + 104|0;
 $6 = sp + 100|0;
 $7 = sp + 96|0;
 $8 = sp + 92|0;
 $9 = sp + 88|0;
 $10 = sp + 32|0;
 $11 = sp + 16|0;
 $treeProbeSetHash$i = sp;
 $offsetAndSize$i = sp + 24|0;
 $12 = sp + 36|0;
 $13 = sp + 40|0;
 $14 = sp + 44|0;
 $15 = sp + 48|0;
 $lights = sp + 60|0;
 $splatMats = sp + 72|0;
 $16 = (($this) + 4|0);
 $17 = (($this) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 L1: do {
  if (!($19)) {
   $20 = (($this) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = HEAP32[$16>>2]|0;
   $23 = (($22) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$21>>2]|0;
   $26 = (($25) + 4|0);
   HEAP32[$26>>2] = $24;
   $27 = HEAP32[$21>>2]|0;
   $28 = HEAP32[$23>>2]|0;
   HEAP32[$28>>2] = $27;
   HEAP32[$17>>2] = 0;
   $__f$0$i$i = $21;
   while(1) {
    $29 = ($__f$0$i$i|0)==($16|0);
    if ($29) {
     break L1;
    }
    $30 = (($__f$0$i$i) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    HEAP32[$14>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$14+0>>2]|0;
    invoke_vii(2591,($__f$0$i$i|0),($$byval_copy5|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    } else {
     $__f$0$i$i = $31;
    }
   }
   $34 = ___cxa_find_matching_catch()|0;
   $35 = tempRet0;
   ___cxa_call_unexpected(($34|0));
   // unreachable;
  }
 } while(0);
 $36 = (($this) + 16|0);
 $37 = (($this) + 20|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==($36|0);
 if ($39) {
  $$pre$phiZ2D = $16;
 } else {
  $40 = (($15) + 4|0);
  $41 = (($15) + 8|0);
  $43 = $38;
  while(1) {
   $42 = (($43) + 8|0);
   $44 = HEAP32[$42>>2]|0;
   $45 = (($44) + 24|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = (($46) + 40|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = 1 << $48;
   $50 = $49 & $cullingMask;
   $51 = ($50|0)==(0);
   if (!($51)) {
    HEAP32[$0>>2] = 44;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $52 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy5,0,802376,79)|0);
    $53 = (($52) + 8|0);
    $54 = HEAP32[$42>>2]|0;
    HEAP32[$53>>2] = $54;
    $55 = HEAP32[$16>>2]|0;
    $56 = (($55) + 4|0);
    HEAP32[$56>>2] = $52;
    $57 = HEAP32[$16>>2]|0;
    HEAP32[$52>>2] = $57;
    HEAP32[$16>>2] = $52;
    $58 = (($52) + 4|0);
    HEAP32[$58>>2] = $16;
    $59 = HEAP32[$17>>2]|0;
    $60 = (($59) + 1)|0;
    HEAP32[$17>>2] = $60;
    __ZNK7Terrain11GetPositionEv($15,$44);
    $61 = (($44) + 32|0);
    $62 = Math_fround(HEAPF32[$15>>2]);
    $63 = Math_fround(HEAPF32[$61>>2]);
    $64 = $62 != $63;
    if ($64) {
     label = 13;
    } else {
     $65 = Math_fround(HEAPF32[$40>>2]);
     $66 = (($44) + 36|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = $65 != $67;
     if ($68) {
      label = 13;
     } else {
      $69 = Math_fround(HEAPF32[$41>>2]);
      $70 = (($44) + 40|0);
      $71 = Math_fround(HEAPF32[$70>>2]);
      $72 = $69 != $71;
      if ($72) {
       label = 13;
      }
     }
    }
    if ((label|0) == 13) {
     label = 0;
     ;HEAP32[$61+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$15+8>>2]|0;
     __ZN7Terrain5FlushEv($44);
    }
    __ZN7Terrain23GarbageCollectRenderersEv($44);
    __ZN7Terrain10FlushDirtyEv($44);
    $73 = (__ZN7Terrain11GetRendererEv($44)|0);
    $74 = ($73|0)==(0|0);
    if (!($74)) {
     $75 = (($44) + 44|0);
     $76 = HEAP32[$75>>2]|0;
     HEAP32[$9>>2] = $76;
     $77 = HEAP32[560624>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      label = 23;
     } else {
      $79 = (($77) + 36|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($77) + 4|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ($80|0)==($82|0);
      do {
       if ($83) {
        $84 = (($77) + 28|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = (($77) + 32|0);
        $87 = HEAP32[$86>>2]|0;
        $88 = (($85) + ($87<<3)|0);
        $104 = $88;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$77,$9);
        $89 = HEAP32[$$byval_copy5>>2]|0;
        $90 = ($89|0)==(-1);
        $91 = (($77) + 28|0);
        $92 = HEAP32[$91>>2]|0;
        if ($90) {
         $93 = (($77) + 32|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = (($92) + ($94<<3)|0);
         $104 = $95;
         break;
        } else {
         $96 = (($92) + ($89<<3)|0);
         $104 = $96;
         break;
        }
       }
      } while(0);
      $97 = HEAP32[560624>>2]|0;
      $98 = (($97) + 28|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = (($97) + 32|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = (($99) + ($101<<3)|0);
      $103 = ($104|0)==($102|0);
      if ($103) {
       label = 23;
      } else {
       $105 = (($104) + 4|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = ($106|0)==(0|0);
       if ($107) {
        label = 23;
       } else {
        $temp$0$i = $106;
       }
      }
     }
     if ((label|0) == 23) {
      label = 0;
      $108 = HEAP32[$75>>2]|0;
      $109 = (__Z31ReadObjectFromPersistentManageri($108)|0);
      $temp$0$i = $109;
     }
     $110 = (($temp$0$i) + 28|0);
     __ZN13SplatDatabase25RecalculateBasemapIfDirtyEv($110);
     $111 = (($44) + 188|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = $112 & 1;
     $114 = ($113|0)==(0);
     if (!($114)) {
      $115 = (($44) + 85|0);
      $116 = HEAP8[$115>>0]|0;
      $117 = ($116<<24>>24)==(0);
      if (!($117)) {
       $118 = ($112|0)==(1);
       if ($118) {
        $128 = Math_fround(3.40282346638528859812E+38);
       } else {
        $119 = (($44) + 56|0);
        $120 = Math_fround(HEAPF32[$119>>2]);
        $128 = $120;
       }
       $121 = (($73) + 4|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = HEAP32[$73>>2]|0;
       $124 = (($44) + 52|0);
       $125 = HEAP32[$124>>2]|0;
       $126 = (($44) + 48|0);
       $127 = Math_fround(HEAPF32[$126>>2]);
       __ZN15TerrainRenderer11RenderStep1EP6Cameraiff($122,$123,$125,$127,$128);
      }
     }
    }
   }
   $129 = (($43) + 4|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ($130|0)==($36|0);
   if ($131) {
    $$pre$phiZ2D = $16;
    break;
   } else {
    $43 = $130;
   }
  }
 }
 $132 = (($this) + 8|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = ($133|0)==($$pre$phiZ2D|0);
 if ($134) {
  $136 = $133;
 } else {
  $138 = $133;
  while(1) {
   $137 = (($138) + 8|0);
   $139 = HEAP32[$137>>2]|0;
   $140 = (__ZN7Terrain28GetTerrainRendererDontCreateEv($139)|0);
   $141 = ($140|0)==(0|0);
   if (!($141)) {
    $142 = (($139) + 188|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = $143 & 1;
    $145 = ($144|0)==(0);
    if (!($145)) {
     $146 = (($139) + 85|0);
     $147 = HEAP8[$146>>0]|0;
     $148 = ($147<<24>>24)==(0);
     if (!($148)) {
      $149 = (($139) + 172|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = ($150|0)==(0);
      do {
       if ($151) {
        $left$0 = 0;
       } else {
        HEAP32[$8>>2] = $150;
        $152 = HEAP32[560624>>2]|0;
        $153 = ($152|0)==(0|0);
        if ($153) {
         label = 46;
        } else {
         $154 = (($152) + 36|0);
         $155 = HEAP32[$154>>2]|0;
         $156 = (($152) + 4|0);
         $157 = HEAP32[$156>>2]|0;
         $158 = ($155|0)==($157|0);
         do {
          if ($158) {
           $159 = (($152) + 28|0);
           $160 = HEAP32[$159>>2]|0;
           $161 = (($152) + 32|0);
           $162 = HEAP32[$161>>2]|0;
           $163 = (($160) + ($162<<3)|0);
           $179 = $163;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$152,$8);
           $164 = HEAP32[$$byval_copy5>>2]|0;
           $165 = ($164|0)==(-1);
           $166 = (($152) + 28|0);
           $167 = HEAP32[$166>>2]|0;
           if ($165) {
            $168 = (($152) + 32|0);
            $169 = HEAP32[$168>>2]|0;
            $170 = (($167) + ($169<<3)|0);
            $179 = $170;
            break;
           } else {
            $171 = (($167) + ($164<<3)|0);
            $179 = $171;
            break;
           }
          }
         } while(0);
         $172 = HEAP32[560624>>2]|0;
         $173 = (($172) + 28|0);
         $174 = HEAP32[$173>>2]|0;
         $175 = (($172) + 32|0);
         $176 = HEAP32[$175>>2]|0;
         $177 = (($174) + ($176<<3)|0);
         $178 = ($179|0)==($177|0);
         if ($178) {
          label = 46;
         } else {
          $180 = (($179) + 4|0);
          $181 = HEAP32[$180>>2]|0;
          $182 = ($181|0)==(0|0);
          if ($182) {
           label = 46;
          } else {
           $187 = $172;
          }
         }
        }
        if ((label|0) == 46) {
         label = 0;
         $183 = HEAP32[$149>>2]|0;
         $184 = (__Z31ReadObjectFromPersistentManageri($183)|0);
         $phitmp$i = ($184|0)==(0|0);
         if ($phitmp$i) {
          $left$0 = 0;
          break;
         }
         $$pre111 = HEAP32[560624>>2]|0;
         $187 = $$pre111;
        }
        $185 = HEAP32[$149>>2]|0;
        HEAP32[$7>>2] = $185;
        $186 = ($187|0)==(0|0);
        if ($186) {
         label = 56;
        } else {
         $188 = (($187) + 36|0);
         $189 = HEAP32[$188>>2]|0;
         $190 = (($187) + 4|0);
         $191 = HEAP32[$190>>2]|0;
         $192 = ($189|0)==($191|0);
         do {
          if ($192) {
           $193 = (($187) + 28|0);
           $194 = HEAP32[$193>>2]|0;
           $195 = (($187) + 32|0);
           $196 = HEAP32[$195>>2]|0;
           $197 = (($194) + ($196<<3)|0);
           $213 = $197;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$187,$7);
           $198 = HEAP32[$$byval_copy5>>2]|0;
           $199 = ($198|0)==(-1);
           $200 = (($187) + 28|0);
           $201 = HEAP32[$200>>2]|0;
           if ($199) {
            $202 = (($187) + 32|0);
            $203 = HEAP32[$202>>2]|0;
            $204 = (($201) + ($203<<3)|0);
            $213 = $204;
            break;
           } else {
            $205 = (($201) + ($198<<3)|0);
            $213 = $205;
            break;
           }
          }
         } while(0);
         $206 = HEAP32[560624>>2]|0;
         $207 = (($206) + 28|0);
         $208 = HEAP32[$207>>2]|0;
         $209 = (($206) + 32|0);
         $210 = HEAP32[$209>>2]|0;
         $211 = (($208) + ($210<<3)|0);
         $212 = ($213|0)==($211|0);
         if ($212) {
          label = 56;
         } else {
          $214 = (($213) + 4|0);
          $215 = HEAP32[$214>>2]|0;
          $216 = ($215|0)==(0|0);
          if ($216) {
           label = 56;
          } else {
           $temp$0$i32 = $215;
          }
         }
        }
        if ((label|0) == 56) {
         label = 0;
         $217 = HEAP32[$149>>2]|0;
         $218 = (__Z31ReadObjectFromPersistentManageri($217)|0);
         $temp$0$i32 = $218;
        }
        $219 = (__ZN7Terrain28GetTerrainRendererDontCreateEv($temp$0$i32)|0);
        $left$0 = $219;
       }
      } while(0);
      $220 = (($139) + 176|0);
      $221 = HEAP32[$220>>2]|0;
      $222 = ($221|0)==(0);
      do {
       if ($222) {
        $right$0 = 0;
       } else {
        HEAP32[$6>>2] = $221;
        $223 = HEAP32[560624>>2]|0;
        $224 = ($223|0)==(0|0);
        if ($224) {
         label = 67;
        } else {
         $225 = (($223) + 36|0);
         $226 = HEAP32[$225>>2]|0;
         $227 = (($223) + 4|0);
         $228 = HEAP32[$227>>2]|0;
         $229 = ($226|0)==($228|0);
         do {
          if ($229) {
           $230 = (($223) + 28|0);
           $231 = HEAP32[$230>>2]|0;
           $232 = (($223) + 32|0);
           $233 = HEAP32[$232>>2]|0;
           $234 = (($231) + ($233<<3)|0);
           $250 = $234;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$223,$6);
           $235 = HEAP32[$$byval_copy5>>2]|0;
           $236 = ($235|0)==(-1);
           $237 = (($223) + 28|0);
           $238 = HEAP32[$237>>2]|0;
           if ($236) {
            $239 = (($223) + 32|0);
            $240 = HEAP32[$239>>2]|0;
            $241 = (($238) + ($240<<3)|0);
            $250 = $241;
            break;
           } else {
            $242 = (($238) + ($235<<3)|0);
            $250 = $242;
            break;
           }
          }
         } while(0);
         $243 = HEAP32[560624>>2]|0;
         $244 = (($243) + 28|0);
         $245 = HEAP32[$244>>2]|0;
         $246 = (($243) + 32|0);
         $247 = HEAP32[$246>>2]|0;
         $248 = (($245) + ($247<<3)|0);
         $249 = ($250|0)==($248|0);
         if ($249) {
          label = 67;
         } else {
          $251 = (($250) + 4|0);
          $252 = HEAP32[$251>>2]|0;
          $253 = ($252|0)==(0|0);
          if ($253) {
           label = 67;
          } else {
           $258 = $243;
          }
         }
        }
        if ((label|0) == 67) {
         label = 0;
         $254 = HEAP32[$220>>2]|0;
         $255 = (__Z31ReadObjectFromPersistentManageri($254)|0);
         $phitmp$i38 = ($255|0)==(0|0);
         if ($phitmp$i38) {
          $right$0 = 0;
          break;
         }
         $$pre110 = HEAP32[560624>>2]|0;
         $258 = $$pre110;
        }
        $256 = HEAP32[$220>>2]|0;
        HEAP32[$5>>2] = $256;
        $257 = ($258|0)==(0|0);
        if ($257) {
         label = 77;
        } else {
         $259 = (($258) + 36|0);
         $260 = HEAP32[$259>>2]|0;
         $261 = (($258) + 4|0);
         $262 = HEAP32[$261>>2]|0;
         $263 = ($260|0)==($262|0);
         do {
          if ($263) {
           $264 = (($258) + 28|0);
           $265 = HEAP32[$264>>2]|0;
           $266 = (($258) + 32|0);
           $267 = HEAP32[$266>>2]|0;
           $268 = (($265) + ($267<<3)|0);
           $284 = $268;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$258,$5);
           $269 = HEAP32[$$byval_copy5>>2]|0;
           $270 = ($269|0)==(-1);
           $271 = (($258) + 28|0);
           $272 = HEAP32[$271>>2]|0;
           if ($270) {
            $273 = (($258) + 32|0);
            $274 = HEAP32[$273>>2]|0;
            $275 = (($272) + ($274<<3)|0);
            $284 = $275;
            break;
           } else {
            $276 = (($272) + ($269<<3)|0);
            $284 = $276;
            break;
           }
          }
         } while(0);
         $277 = HEAP32[560624>>2]|0;
         $278 = (($277) + 28|0);
         $279 = HEAP32[$278>>2]|0;
         $280 = (($277) + 32|0);
         $281 = HEAP32[$280>>2]|0;
         $282 = (($279) + ($281<<3)|0);
         $283 = ($284|0)==($282|0);
         if ($283) {
          label = 77;
         } else {
          $285 = (($284) + 4|0);
          $286 = HEAP32[$285>>2]|0;
          $287 = ($286|0)==(0|0);
          if ($287) {
           label = 77;
          } else {
           $temp$0$i45 = $286;
          }
         }
        }
        if ((label|0) == 77) {
         label = 0;
         $288 = HEAP32[$220>>2]|0;
         $289 = (__Z31ReadObjectFromPersistentManageri($288)|0);
         $temp$0$i45 = $289;
        }
        $290 = (__ZN7Terrain28GetTerrainRendererDontCreateEv($temp$0$i45)|0);
        $right$0 = $290;
       }
      } while(0);
      $291 = (($139) + 184|0);
      $292 = HEAP32[$291>>2]|0;
      $293 = ($292|0)==(0);
      do {
       if ($293) {
        $top$0 = 0;
       } else {
        HEAP32[$4>>2] = $292;
        $294 = HEAP32[560624>>2]|0;
        $295 = ($294|0)==(0|0);
        if ($295) {
         label = 88;
        } else {
         $296 = (($294) + 36|0);
         $297 = HEAP32[$296>>2]|0;
         $298 = (($294) + 4|0);
         $299 = HEAP32[$298>>2]|0;
         $300 = ($297|0)==($299|0);
         do {
          if ($300) {
           $301 = (($294) + 28|0);
           $302 = HEAP32[$301>>2]|0;
           $303 = (($294) + 32|0);
           $304 = HEAP32[$303>>2]|0;
           $305 = (($302) + ($304<<3)|0);
           $321 = $305;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$294,$4);
           $306 = HEAP32[$$byval_copy5>>2]|0;
           $307 = ($306|0)==(-1);
           $308 = (($294) + 28|0);
           $309 = HEAP32[$308>>2]|0;
           if ($307) {
            $310 = (($294) + 32|0);
            $311 = HEAP32[$310>>2]|0;
            $312 = (($309) + ($311<<3)|0);
            $321 = $312;
            break;
           } else {
            $313 = (($309) + ($306<<3)|0);
            $321 = $313;
            break;
           }
          }
         } while(0);
         $314 = HEAP32[560624>>2]|0;
         $315 = (($314) + 28|0);
         $316 = HEAP32[$315>>2]|0;
         $317 = (($314) + 32|0);
         $318 = HEAP32[$317>>2]|0;
         $319 = (($316) + ($318<<3)|0);
         $320 = ($321|0)==($319|0);
         if ($320) {
          label = 88;
         } else {
          $322 = (($321) + 4|0);
          $323 = HEAP32[$322>>2]|0;
          $324 = ($323|0)==(0|0);
          if ($324) {
           label = 88;
          } else {
           $329 = $314;
          }
         }
        }
        if ((label|0) == 88) {
         label = 0;
         $325 = HEAP32[$291>>2]|0;
         $326 = (__Z31ReadObjectFromPersistentManageri($325)|0);
         $phitmp$i52 = ($326|0)==(0|0);
         if ($phitmp$i52) {
          $top$0 = 0;
          break;
         }
         $$pre109 = HEAP32[560624>>2]|0;
         $329 = $$pre109;
        }
        $327 = HEAP32[$291>>2]|0;
        HEAP32[$3>>2] = $327;
        $328 = ($329|0)==(0|0);
        if ($328) {
         label = 98;
        } else {
         $330 = (($329) + 36|0);
         $331 = HEAP32[$330>>2]|0;
         $332 = (($329) + 4|0);
         $333 = HEAP32[$332>>2]|0;
         $334 = ($331|0)==($333|0);
         do {
          if ($334) {
           $335 = (($329) + 28|0);
           $336 = HEAP32[$335>>2]|0;
           $337 = (($329) + 32|0);
           $338 = HEAP32[$337>>2]|0;
           $339 = (($336) + ($338<<3)|0);
           $355 = $339;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$329,$3);
           $340 = HEAP32[$$byval_copy5>>2]|0;
           $341 = ($340|0)==(-1);
           $342 = (($329) + 28|0);
           $343 = HEAP32[$342>>2]|0;
           if ($341) {
            $344 = (($329) + 32|0);
            $345 = HEAP32[$344>>2]|0;
            $346 = (($343) + ($345<<3)|0);
            $355 = $346;
            break;
           } else {
            $347 = (($343) + ($340<<3)|0);
            $355 = $347;
            break;
           }
          }
         } while(0);
         $348 = HEAP32[560624>>2]|0;
         $349 = (($348) + 28|0);
         $350 = HEAP32[$349>>2]|0;
         $351 = (($348) + 32|0);
         $352 = HEAP32[$351>>2]|0;
         $353 = (($350) + ($352<<3)|0);
         $354 = ($355|0)==($353|0);
         if ($354) {
          label = 98;
         } else {
          $356 = (($355) + 4|0);
          $357 = HEAP32[$356>>2]|0;
          $358 = ($357|0)==(0|0);
          if ($358) {
           label = 98;
          } else {
           $temp$0$i59 = $357;
          }
         }
        }
        if ((label|0) == 98) {
         label = 0;
         $359 = HEAP32[$291>>2]|0;
         $360 = (__Z31ReadObjectFromPersistentManageri($359)|0);
         $temp$0$i59 = $360;
        }
        $361 = (__ZN7Terrain28GetTerrainRendererDontCreateEv($temp$0$i59)|0);
        $top$0 = $361;
       }
      } while(0);
      $362 = (($139) + 180|0);
      $363 = HEAP32[$362>>2]|0;
      $364 = ($363|0)==(0);
      do {
       if ($364) {
        $bottom$0 = 0;
       } else {
        HEAP32[$2>>2] = $363;
        $365 = HEAP32[560624>>2]|0;
        $366 = ($365|0)==(0|0);
        if ($366) {
         label = 109;
        } else {
         $367 = (($365) + 36|0);
         $368 = HEAP32[$367>>2]|0;
         $369 = (($365) + 4|0);
         $370 = HEAP32[$369>>2]|0;
         $371 = ($368|0)==($370|0);
         do {
          if ($371) {
           $372 = (($365) + 28|0);
           $373 = HEAP32[$372>>2]|0;
           $374 = (($365) + 32|0);
           $375 = HEAP32[$374>>2]|0;
           $376 = (($373) + ($375<<3)|0);
           $392 = $376;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$365,$2);
           $377 = HEAP32[$$byval_copy5>>2]|0;
           $378 = ($377|0)==(-1);
           $379 = (($365) + 28|0);
           $380 = HEAP32[$379>>2]|0;
           if ($378) {
            $381 = (($365) + 32|0);
            $382 = HEAP32[$381>>2]|0;
            $383 = (($380) + ($382<<3)|0);
            $392 = $383;
            break;
           } else {
            $384 = (($380) + ($377<<3)|0);
            $392 = $384;
            break;
           }
          }
         } while(0);
         $385 = HEAP32[560624>>2]|0;
         $386 = (($385) + 28|0);
         $387 = HEAP32[$386>>2]|0;
         $388 = (($385) + 32|0);
         $389 = HEAP32[$388>>2]|0;
         $390 = (($387) + ($389<<3)|0);
         $391 = ($392|0)==($390|0);
         if ($391) {
          label = 109;
         } else {
          $393 = (($392) + 4|0);
          $394 = HEAP32[$393>>2]|0;
          $395 = ($394|0)==(0|0);
          if ($395) {
           label = 109;
          } else {
           $400 = $385;
          }
         }
        }
        if ((label|0) == 109) {
         label = 0;
         $396 = HEAP32[$362>>2]|0;
         $397 = (__Z31ReadObjectFromPersistentManageri($396)|0);
         $phitmp$i66 = ($397|0)==(0|0);
         if ($phitmp$i66) {
          $bottom$0 = 0;
          break;
         }
         $$pre108 = HEAP32[560624>>2]|0;
         $400 = $$pre108;
        }
        $398 = HEAP32[$362>>2]|0;
        HEAP32[$1>>2] = $398;
        $399 = ($400|0)==(0|0);
        if ($399) {
         label = 119;
        } else {
         $401 = (($400) + 36|0);
         $402 = HEAP32[$401>>2]|0;
         $403 = (($400) + 4|0);
         $404 = HEAP32[$403>>2]|0;
         $405 = ($402|0)==($404|0);
         do {
          if ($405) {
           $406 = (($400) + 28|0);
           $407 = HEAP32[$406>>2]|0;
           $408 = (($400) + 32|0);
           $409 = HEAP32[$408>>2]|0;
           $410 = (($407) + ($409<<3)|0);
           $426 = $410;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$400,$1);
           $411 = HEAP32[$$byval_copy5>>2]|0;
           $412 = ($411|0)==(-1);
           $413 = (($400) + 28|0);
           $414 = HEAP32[$413>>2]|0;
           if ($412) {
            $415 = (($400) + 32|0);
            $416 = HEAP32[$415>>2]|0;
            $417 = (($414) + ($416<<3)|0);
            $426 = $417;
            break;
           } else {
            $418 = (($414) + ($411<<3)|0);
            $426 = $418;
            break;
           }
          }
         } while(0);
         $419 = HEAP32[560624>>2]|0;
         $420 = (($419) + 28|0);
         $421 = HEAP32[$420>>2]|0;
         $422 = (($419) + 32|0);
         $423 = HEAP32[$422>>2]|0;
         $424 = (($421) + ($423<<3)|0);
         $425 = ($426|0)==($424|0);
         if ($425) {
          label = 119;
         } else {
          $427 = (($426) + 4|0);
          $428 = HEAP32[$427>>2]|0;
          $429 = ($428|0)==(0|0);
          if ($429) {
           label = 119;
          } else {
           $temp$0$i73 = $428;
          }
         }
        }
        if ((label|0) == 119) {
         label = 0;
         $430 = HEAP32[$362>>2]|0;
         $431 = (__Z31ReadObjectFromPersistentManageri($430)|0);
         $temp$0$i73 = $431;
        }
        $432 = (__ZN7Terrain28GetTerrainRendererDontCreateEv($temp$0$i73)|0);
        $bottom$0 = $432;
       }
      } while(0);
      __ZN15TerrainRenderer12SetNeighborsEPS_S0_S0_S0_($140,$left$0,$top$0,$right$0,$bottom$0);
     }
    }
   }
   $433 = (($138) + 4|0);
   $434 = HEAP32[$433>>2]|0;
   $435 = ($434|0)==($$pre$phiZ2D|0);
   if ($435) {
    break;
   } else {
    $138 = $434;
   }
  }
  $$pre = HEAP32[$132>>2]|0;
  $136 = $$pre;
 }
 $135 = ($136|0)==($$pre$phiZ2D|0);
 if ($135) {
  STACKTOP = sp;return;
 } else {
  $443 = $136;
 }
 while(1) {
  $442 = (($443) + 8|0);
  $444 = HEAP32[$442>>2]|0;
  $445 = (__ZN7Terrain28GetTerrainRendererDontCreateEv($444)|0);
  $446 = ($445|0)==(0|0);
  if (!($446)) {
   $447 = (($444) + 188|0);
   $448 = HEAP32[$447>>2]|0;
   $449 = $448 & 1;
   $450 = ($449|0)==(0);
   if (!($450)) {
    $451 = (($444) + 85|0);
    $452 = HEAP8[$451>>0]|0;
    $453 = ($452<<24>>24)==(0);
    if (!($453)) {
     __ZN15TerrainRenderer11RenderStep2Ev($445);
    }
   }
  }
  $454 = (($443) + 4|0);
  $455 = HEAP32[$454>>2]|0;
  $456 = ($455|0)==($$pre$phiZ2D|0);
  if ($456) {
   break;
  } else {
   $443 = $455;
  }
 }
 $$pre106 = HEAP32[$132>>2]|0;
 $436 = ($$pre106|0)==($$pre$phiZ2D|0);
 if ($436) {
  STACKTOP = sp;return;
 }
 $437 = (($lights) + 4|0);
 $438 = (($offsetAndSize$i) + 4|0);
 $439 = (($splatMats) + 4|0);
 $440 = (($splatMats) + 8|0);
 $441 = (($splatMats) + 12|0);
 $458 = $$pre106;
 L186: while(1) {
  $457 = (($458) + 8|0);
  $459 = HEAP32[$457>>2]|0;
  $460 = (__ZN7Terrain11GetRendererEv($459)|0);
  $461 = ($460|0)==(0|0);
  if (!($461)) {
   $462 = (($459) + 24|0);
   $463 = HEAP32[$462>>2]|0;
   $464 = (($463) + 40|0);
   $465 = HEAP32[$464>>2]|0;
   $466 = (__Z15GetLightManagerv()|0);
   __ZN12LightManager9GetLightsE9LightTypei($lights,$466,1,$465);
   $467 = (($459) + 188|0);
   $468 = HEAP32[$467>>2]|0;
   $469 = $468 & 1;
   $470 = ($469|0)==(0);
   if (!($470)) {
    $471 = (($459) + 85|0);
    $472 = HEAP8[$471>>0]|0;
    $473 = ($472<<24>>24)==(0);
    if (!($473)) {
     $474 = HEAP32[628512>>2]|0;
     HEAP32[$splatMats>>2] = 0;
     HEAP32[$439>>2] = $474;
     HEAP32[$440>>2] = 0;
     HEAP32[$441>>2] = 0;
     $475 = (($459) + 92|0);
     $476 = HEAP32[$475>>2]|0;
     __THREW__ = 0;
     invoke_vii(3415,($476|0),($splatMats|0));
     $477 = __THREW__; __THREW__ = 0;
     $478 = $477&1;
     if ($478) {
      label = 140;
      break;
     }
     $479 = HEAP32[$475>>2]|0;
     __THREW__ = 0;
     $480 = (invoke_ii(3409,($479|0))|0);
     $481 = __THREW__; __THREW__ = 0;
     $482 = $481&1;
     if ($482) {
      label = 140;
      break;
     }
     $483 = (($460) + 4|0);
     $484 = HEAP32[$483>>2]|0;
     $485 = HEAP32[$460>>2]|0;
     $486 = (($459) + 84|0);
     $487 = HEAP8[$486>>0]|0;
     $488 = ($487<<24>>24)!=(0);
     $489 = HEAP32[$splatMats>>2]|0;
     $490 = HEAP32[$440>>2]|0;
     __THREW__ = 0;
     invoke_viiiiiii(71,($484|0),($485|0),($465|0),($488|0),($489|0),($490|0),($480|0));
     $491 = __THREW__; __THREW__ = 0;
     $492 = $491&1;
     if ($492) {
      label = 140;
      break;
     }
     $493 = HEAP32[$441>>2]|0;
     $494 = ($493|0)>(-1);
     if ($494) {
      $495 = HEAP32[$splatMats>>2]|0;
      $496 = HEAP32[$439>>2]|0;
      HEAP32[$0>>2] = $496;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($495|0),($$byval_copy5|0));
      $497 = __THREW__; __THREW__ = 0;
      $498 = $497&1;
      if ($498) {
       label = 139;
       break;
      }
      HEAP32[$splatMats>>2] = 0;
     }
    }
   }
   $509 = HEAP32[$467>>2]|0;
   $510 = $509 & 4;
   $511 = ($510|0)==(0);
   if ($511) {
    $527 = $509;
   } else {
    $512 = (($459) + 86|0);
    $513 = HEAP8[$512>>0]|0;
    $514 = ($513<<24>>24)==(0);
    if ($514) {
     $527 = $509;
    } else {
     $515 = (($459) + 76|0);
     $516 = Math_fround(HEAPF32[$515>>2]);
     $517 = +$516;
     $518 = $517 > 0.00100000000000000002082;
     if ($518) {
      $519 = (($460) + 12|0);
      $520 = HEAP32[$519>>2]|0;
      $521 = HEAP32[$460>>2]|0;
      $522 = (($459) + 80|0);
      $523 = Math_fround(HEAPF32[$522>>2]);
      __THREW__ = 0;
      invoke_viifif(1,($520|0),($521|0),(+$516),($465|0),(+$523));
      $524 = __THREW__; __THREW__ = 0;
      $525 = $524&1;
      if ($525) {
       label = 139;
       break;
      }
      $$pre107 = HEAP32[$467>>2]|0;
      $527 = $$pre107;
     } else {
      $527 = $509;
     }
    }
   }
   $526 = $527 & 2;
   $528 = ($526|0)==(0);
   if (!($528)) {
    $529 = (($459) + 86|0);
    $530 = HEAP8[$529>>0]|0;
    $531 = ($530<<24>>24)==(0);
    if (!($531)) {
     $532 = (($459) + 60|0);
     $533 = Math_fround(HEAPF32[$532>>2]);
     $534 = +$533;
     $535 = $534 > 0.00100000000000000002082;
     if ($535) {
      $536 = (($460) + 8|0);
      $537 = HEAP32[$536>>2]|0;
      $538 = (($459) + 164|0);
      $539 = HEAP8[$538>>0]|0;
      $540 = ($539<<24>>24)==(0);
      do {
       if ($540) {
        $treeProbeSetIndexOffset$0$i = -1;
       } else {
        $541 = (($459) + 44|0);
        $542 = HEAP32[$541>>2]|0;
        $543 = ($542|0)==(0);
        if ($543) {
         $treeProbeSetIndexOffset$0$i = -1;
        } else {
         HEAP32[$10>>2] = $542;
         $544 = HEAP32[560624>>2]|0;
         $545 = ($544|0)==(0|0);
         do {
          if ($545) {
           label = 161;
          } else {
           $546 = (($544) + 36|0);
           $547 = HEAP32[$546>>2]|0;
           $548 = (($544) + 4|0);
           $549 = HEAP32[$548>>2]|0;
           $550 = ($547|0)==($549|0);
           do {
            if ($550) {
             $551 = (($544) + 28|0);
             $552 = HEAP32[$551>>2]|0;
             $553 = (($544) + 32|0);
             $554 = HEAP32[$553>>2]|0;
             $555 = (($552) + ($554<<3)|0);
             $571 = $555;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$544,$10);
             $556 = HEAP32[$$byval_copy5>>2]|0;
             $557 = ($556|0)==(-1);
             $558 = (($544) + 28|0);
             $559 = HEAP32[$558>>2]|0;
             if ($557) {
              $560 = (($544) + 32|0);
              $561 = HEAP32[$560>>2]|0;
              $562 = (($559) + ($561<<3)|0);
              $571 = $562;
              break;
             } else {
              $563 = (($559) + ($556<<3)|0);
              $571 = $563;
              break;
             }
            }
           } while(0);
           $564 = HEAP32[560624>>2]|0;
           $565 = (($564) + 28|0);
           $566 = HEAP32[$565>>2]|0;
           $567 = (($564) + 32|0);
           $568 = HEAP32[$567>>2]|0;
           $569 = (($566) + ($568<<3)|0);
           $570 = ($571|0)==($569|0);
           if ($570) {
            label = 161;
            break;
           }
           $572 = (($571) + 4|0);
           $573 = HEAP32[$572>>2]|0;
           $574 = ($573|0)==(0|0);
           if ($574) {
            label = 161;
           }
          }
         } while(0);
         if ((label|0) == 161) {
          label = 0;
          __THREW__ = 0;
          $575 = (invoke_ii(3215,($542|0))|0);
          $576 = __THREW__; __THREW__ = 0;
          $577 = $576&1;
          if ($577) {
           label = 139;
           break L186;
          }
          $phitmp$i$i = ($575|0)==(0|0);
          if ($phitmp$i$i) {
           $treeProbeSetIndexOffset$0$i = -1;
           break;
          }
         }
         __THREW__ = 0;
         $578 = (invoke_i(64)|0);
         $579 = __THREW__; __THREW__ = 0;
         $580 = $579&1;
         if ($580) {
          label = 139;
          break L186;
         }
         __THREW__ = 0;
         $581 = (invoke_ii(3410,($578|0))|0);
         $582 = __THREW__; __THREW__ = 0;
         $583 = $582&1;
         if ($583) {
          label = 139;
          break L186;
         }
         $584 = ($581|0)==(0|0);
         if ($584) {
          $treeProbeSetIndexOffset$0$i = -1;
          break;
         }
         __THREW__ = 0;
         $585 = (invoke_i(64)|0);
         $586 = __THREW__; __THREW__ = 0;
         $587 = $586&1;
         if ($587) {
          label = 139;
          break L186;
         }
         __THREW__ = 0;
         $588 = (invoke_ii(3411,($585|0))|0);
         $589 = __THREW__; __THREW__ = 0;
         $590 = $589&1;
         if ($590) {
          label = 139;
          break L186;
         }
         $591 = (($459) + 4|0);
         $592 = HEAP32[$591>>2]|0;
         __THREW__ = 0;
         invoke_viii(2035,($treeProbeSetHash$i|0),($588|0),($592|0));
         $593 = __THREW__; __THREW__ = 0;
         $594 = $593&1;
         if ($594) {
          label = 139;
          break L186;
         }
         __THREW__ = 0;
         $595 = (invoke_i(64)|0);
         $596 = __THREW__; __THREW__ = 0;
         $597 = $596&1;
         if ($597) {
          label = 139;
          break L186;
         }
         __THREW__ = 0;
         $598 = (invoke_ii(3410,($595|0))|0);
         $599 = __THREW__; __THREW__ = 0;
         $600 = $599&1;
         if ($600) {
          label = 139;
          break L186;
         }
         __THREW__ = 0;
         invoke_viii(2036,($offsetAndSize$i|0),($598|0),($treeProbeSetHash$i|0));
         $601 = __THREW__; __THREW__ = 0;
         $602 = $601&1;
         if ($602) {
          label = 139;
          break L186;
         }
         $603 = HEAP32[$offsetAndSize$i>>2]|0;
         $604 = ($603|0)==(-1);
         if ($604) {
          $treeProbeSetIndexOffset$0$i = -1;
          break;
         }
         $605 = HEAP32[$438>>2]|0;
         $606 = HEAP32[$541>>2]|0;
         HEAP32[$11>>2] = $606;
         $607 = HEAP32[560624>>2]|0;
         $608 = ($607|0)==(0|0);
         do {
          if ($608) {
           label = 181;
          } else {
           $609 = (($607) + 36|0);
           $610 = HEAP32[$609>>2]|0;
           $611 = (($607) + 4|0);
           $612 = HEAP32[$611>>2]|0;
           $613 = ($610|0)==($612|0);
           do {
            if ($613) {
             $614 = (($607) + 28|0);
             $615 = HEAP32[$614>>2]|0;
             $616 = (($607) + 32|0);
             $617 = HEAP32[$616>>2]|0;
             $618 = (($615) + ($617<<3)|0);
             $634 = $618;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$607,$11);
             $619 = HEAP32[$$byval_copy5>>2]|0;
             $620 = ($619|0)==(-1);
             $621 = (($607) + 28|0);
             $622 = HEAP32[$621>>2]|0;
             if ($620) {
              $623 = (($607) + 32|0);
              $624 = HEAP32[$623>>2]|0;
              $625 = (($622) + ($624<<3)|0);
              $634 = $625;
              break;
             } else {
              $626 = (($622) + ($619<<3)|0);
              $634 = $626;
              break;
             }
            }
           } while(0);
           $627 = HEAP32[560624>>2]|0;
           $628 = (($627) + 28|0);
           $629 = HEAP32[$628>>2]|0;
           $630 = (($627) + 32|0);
           $631 = HEAP32[$630>>2]|0;
           $632 = (($629) + ($631<<3)|0);
           $633 = ($634|0)==($632|0);
           if ($633) {
            label = 181;
            break;
           }
           $635 = (($634) + 4|0);
           $636 = HEAP32[$635>>2]|0;
           $637 = ($636|0)==(0|0);
           if ($637) {
            label = 181;
           } else {
            $temp$0$i$i = $636;
           }
          }
         } while(0);
         if ((label|0) == 181) {
          label = 0;
          __THREW__ = 0;
          $638 = (invoke_ii(3215,($606|0))|0);
          $639 = __THREW__; __THREW__ = 0;
          $640 = $639&1;
          if ($640) {
           label = 139;
           break L186;
          } else {
           $temp$0$i$i = $638;
          }
         }
         $641 = (($temp$0$i$i) + 88|0);
         $642 = (($641) + 4|0);
         $643 = HEAP32[$642>>2]|0;
         $644 = HEAP32[$641>>2]|0;
         $645 = $643;
         $646 = $644;
         $647 = (($645) - ($646))|0;
         $648 = (($647|0) / 40)&-1;
         $649 = ($605|0)==($648|0);
         if ($649) {
          $$pre$i = HEAP32[$offsetAndSize$i>>2]|0;
          $treeProbeSetIndexOffset$0$i = $$pre$i;
          break;
         }
         $650 = ($459|0)==(0|0);
         if ($650) {
          $652 = 0;
         } else {
          $651 = HEAP32[$591>>2]|0;
          $652 = $651;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,(802384|0),0,(802376|0),70,1,($652|0),0,(0|0));
         $653 = __THREW__; __THREW__ = 0;
         $654 = $653&1;
         if ($654) {
          label = 139;
          break L186;
         }
         HEAP8[$538>>0] = 0;
         $treeProbeSetIndexOffset$0$i = -1;
        }
       }
      } while(0);
      __THREW__ = 0;
      invoke_vii(3416,($537|0),($treeProbeSetIndexOffset$0$i|0));
      $655 = __THREW__; __THREW__ = 0;
      $656 = $655&1;
      if ($656) {
       label = 139;
       break;
      }
      $657 = HEAP32[$536>>2]|0;
      $658 = HEAP32[$460>>2]|0;
      $659 = Math_fround(HEAPF32[$532>>2]);
      $660 = (($459) + 64|0);
      $661 = Math_fround(HEAPF32[$660>>2]);
      $662 = (($459) + 68|0);
      $663 = Math_fround(HEAPF32[$662>>2]);
      $664 = (($459) + 72|0);
      $665 = HEAP32[$664>>2]|0;
      __THREW__ = 0;
      invoke_viiifffii(1,($657|0),($658|0),($lights|0),(+$659),(+$661),(+$663),($665|0),($465|0));
      $666 = __THREW__; __THREW__ = 0;
      $667 = $666&1;
      if ($667) {
       label = 139;
       break;
      }
     }
    }
   }
   $668 = HEAP32[$lights>>2]|0;
   $669 = ($668|0)==(0|0);
   if (!($669)) {
    $670 = HEAP32[$437>>2]|0;
    $671 = ($670|0)==($668|0);
    if (!($671)) {
     $__new_last2$i$i$i$i$i2 = $668;
     $scevgep$i$i$i$i$i3 = (($670) + -4|0);
     $672 = (0 - ($__new_last2$i$i$i$i$i2))|0;
     $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($672)|0);
     $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
     $673 = $uglygep3$i$i$i$i$i6 >>> 2;
     $674 = $673 ^ -1;
     $scevgep4$i$i$i$i$i7 = (($670) + ($674<<2)|0);
     HEAP32[$437>>2] = $scevgep4$i$i$i$i$i7;
    }
    HEAP32[$12>>2] = 44;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$12+0>>2]|0;
    invoke_vii(2591,($668|0),($$byval_copy5|0));
    $675 = __THREW__; __THREW__ = 0;
    $676 = $675&1;
    if ($676) {
     label = 194;
     break;
    }
   }
  }
  $690 = (($458) + 4|0);
  $691 = HEAP32[$690>>2]|0;
  $692 = ($691|0)==($$pre$phiZ2D|0);
  if ($692) {
   label = 201;
   break;
  } else {
   $458 = $691;
  }
 }
 do {
  if ((label|0) == 139) {
   $499 = ___cxa_find_matching_catch()|0;
   $500 = tempRet0;
   $$0 = $500;$$01 = $499;
  }
  else if ((label|0) == 140) {
   $501 = ___cxa_find_matching_catch()|0;
   $502 = tempRet0;
   $503 = HEAP32[$441>>2]|0;
   $504 = ($503|0)>(-1);
   if ($504) {
    $505 = HEAP32[$splatMats>>2]|0;
    $506 = HEAP32[$439>>2]|0;
    HEAP32[$0>>2] = $506;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($505|0),($$byval_copy5|0));
    $507 = __THREW__; __THREW__ = 0;
    $508 = $507&1;
    if ($508) {
     $693 = ___cxa_find_matching_catch(0|0)|0;
     $694 = tempRet0;
     ___clang_call_terminate($693);
     // unreachable;
    } else {
     HEAP32[$splatMats>>2] = 0;
     $$0 = $502;$$01 = $501;
     break;
    }
   } else {
    $$0 = $502;$$01 = $501;
   }
  }
  else if ((label|0) == 194) {
   $677 = ___cxa_find_matching_catch()|0;
   $678 = tempRet0;
   ___cxa_call_unexpected(($677|0));
   // unreachable;
  }
  else if ((label|0) == 201) {
   STACKTOP = sp;return;
  }
 } while(0);
 $679 = HEAP32[$lights>>2]|0;
 $680 = ($679|0)==(0|0);
 if ($680) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $681 = HEAP32[$437>>2]|0;
 $682 = ($681|0)==($679|0);
 if (!($682)) {
  $__new_last2$i$i$i$i$i = $679;
  $scevgep$i$i$i$i$i = (($681) + -4|0);
  $683 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($683)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $684 = $uglygep3$i$i$i$i$i >>> 2;
  $685 = $684 ^ -1;
  $scevgep4$i$i$i$i$i = (($681) + ($685<<2)|0);
  HEAP32[$437>>2] = $scevgep4$i$i$i$i$i;
 }
 HEAP32[$13>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$13+0>>2]|0;
 invoke_vii(2591,($679|0),($$byval_copy5|0));
 $686 = __THREW__; __THREW__ = 0;
 $687 = $686&1;
 if ($687) {
  $688 = ___cxa_find_matching_catch()|0;
  $689 = tempRet0;
  ___cxa_call_unexpected(($688|0));
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN14TerrainManager29SetLightmapIndexOnAllTerrainsEi($this,$lightmapIndex) {
 $this = $this|0;
 $lightmapIndex = $lightmapIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $2;
 }
 while(1) {
  $4 = (($5) + 8|0);
  $6 = HEAP32[$4>>2]|0;
  __ZN7Terrain16SetLightmapIndexEi12LightmapType($6,$lightmapIndex,0);
  $7 = (($5) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($0|0);
  if ($9) {
   break;
  } else {
   $5 = $8;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14TerrainManager23CreateTerrainGameObjectEP11TerrainData($this,$assignTerrain) {
 $this = $this|0;
 $assignTerrain = $assignTerrain|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 12|0;
 $1 = sp + 8|0;
 HEAP8[$0>>0] = 14;
 $2 = (($0) + 1|0);
 ;HEAP8[$2+0>>0]=HEAP8[802352+0>>0]|0;HEAP8[$2+1>>0]=HEAP8[802352+1>>0]|0;HEAP8[$2+2>>0]=HEAP8[802352+2>>0]|0;HEAP8[$2+3>>0]=HEAP8[802352+3>>0]|0;HEAP8[$2+4>>0]=HEAP8[802352+4>>0]|0;HEAP8[$2+5>>0]=HEAP8[802352+5>>0]|0;HEAP8[$2+6>>0]=HEAP8[802352+6>>0]|0;
 $3 = (($0) + 8|0);
 HEAP8[$3>>0] = 0;
 __THREW__ = 0;
 HEAP32[$vararg_buffer>>2] = 802352;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $4 = (invoke_iiii(1568,($0|0),(802360|0),($vararg_buffer|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $22 = HEAP8[$0>>0]|0;
  $23 = $22 & 1;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   ___resumeException($20|0);
   // unreachable;
  }
  $25 = HEAP32[$3>>2]|0;
  __ZdlPv($25);
  ___resumeException($20|0);
  // unreachable;
 }
 $7 = HEAP8[$0>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = HEAP32[$3>>2]|0;
  __ZdlPv($10);
 }
 $11 = (__ZNK5Unity10GameObject28QueryComponentImplementationEi($4,218)|0);
 $12 = ($assignTerrain|0)==(0|0);
 if ($12) {
  HEAP32[$1>>2] = 0;
 } else {
  $13 = (($assignTerrain) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$1>>2] = $14;
 }
 __ZN7Terrain14SetTerrainDataERK4PPtrI11TerrainDataE($11,$1);
 $15 = (__Z18GetITerrainPhysicsv()|0);
 $16 = ($15|0)==(0|0);
 if ($16) {
  STACKTOP = sp;return ($4|0);
 }
 $17 = (__Z18GetITerrainPhysicsv()|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_viii[$19 & 4095]($17,$4,$assignTerrain);
 STACKTOP = sp;return ($4|0);
}
function __ZN14TerrainManager20ReconnectTerrainDataEv($this) {
 $this = $this|0;
 var $$byval_copy6 = 0, $$lcssa = 0, $$lcssa15 = 0, $$lcssa17 = 0, $$pre = 0, $$pre$i = 0, $$pre27 = 0, $$pre29 = 0, $$pre31 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i2 = 0, $i1$019 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7 = 0, $temp$0$i = 0, $tempList = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy6 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $tempList = sp + 12|0;
 HEAP32[$tempList>>2] = 0;
 $3 = (($tempList) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($tempList) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 16|0);
 $6 = (($this) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($5|0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $12 = $7;$14 = 0;$15 = 0;
 }
 while(1) {
  $11 = (($12) + 8|0);
  $13 = ($14|0)==($15|0);
  if ($13) {
   __THREW__ = 0;
   invoke_vii(3417,($tempList|0),($11|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    label = 12;
    break;
   }
  } else {
   $16 = ($14|0)==(0|0);
   if ($16) {
    $19 = 0;
   } else {
    $17 = HEAP32[$11>>2]|0;
    HEAP32[$14>>2] = $17;
    $$pre$i = HEAP32[$3>>2]|0;
    $19 = $$pre$i;
   }
   $18 = (($19) + 4|0);
   HEAP32[$3>>2] = $18;
  }
  $22 = (($12) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)==($5|0);
  $$pre = HEAP32[$3>>2]|0;
  if ($24) {
   label = 2;
   break;
  }
  $$pre31 = HEAP32[$4>>2]|0;
  $12 = $23;$14 = $$pre;$15 = $$pre31;
 }
 L13: do {
  if ((label|0) == 2) {
   $$pre27 = HEAP32[$tempList>>2]|0;
   $9 = $$pre27;
   $10 = ($$pre|0)==($$pre27|0);
   L16: do {
    if ($10) {
     $$lcssa = $$pre27;$$lcssa15 = $$pre27;$$lcssa17 = $9;
    } else {
     $41 = $$pre27;$i1$019 = 0;
     L18: while(1) {
      $40 = (($41) + ($i1$019<<2)|0);
      $42 = HEAP32[$40>>2]|0;
      $43 = (($42) + 44|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==(0);
      do {
       if (!($45)) {
        HEAP32[$0>>2] = $44;
        $46 = HEAP32[560624>>2]|0;
        $47 = ($46|0)==(0|0);
        if ($47) {
         label = 27;
        } else {
         $48 = (($46) + 36|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = (($46) + 4|0);
         $51 = HEAP32[$50>>2]|0;
         $52 = ($49|0)==($51|0);
         do {
          if ($52) {
           $53 = (($46) + 28|0);
           $54 = HEAP32[$53>>2]|0;
           $55 = (($46) + 32|0);
           $56 = HEAP32[$55>>2]|0;
           $57 = (($54) + ($56<<3)|0);
           $73 = $57;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy6,$46,$0);
           $58 = HEAP32[$$byval_copy6>>2]|0;
           $59 = ($58|0)==(-1);
           $60 = (($46) + 28|0);
           $61 = HEAP32[$60>>2]|0;
           if ($59) {
            $62 = (($46) + 32|0);
            $63 = HEAP32[$62>>2]|0;
            $64 = (($61) + ($63<<3)|0);
            $73 = $64;
            break;
           } else {
            $65 = (($61) + ($58<<3)|0);
            $73 = $65;
            break;
           }
          }
         } while(0);
         $66 = HEAP32[560624>>2]|0;
         $67 = (($66) + 28|0);
         $68 = HEAP32[$67>>2]|0;
         $69 = (($66) + 32|0);
         $70 = HEAP32[$69>>2]|0;
         $71 = (($68) + ($70<<3)|0);
         $72 = ($73|0)==($71|0);
         if ($72) {
          label = 27;
         } else {
          $74 = (($73) + 4|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = ($75|0)==(0|0);
          if ($76) {
           label = 27;
          } else {
           $83 = $66;
          }
         }
        }
        if ((label|0) == 27) {
         label = 0;
         $77 = HEAP32[$43>>2]|0;
         __THREW__ = 0;
         $78 = (invoke_ii(3215,($77|0))|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break L18;
         }
         $phitmp$i = ($78|0)==(0|0);
         if ($phitmp$i) {
          break;
         }
         $$pre29 = HEAP32[560624>>2]|0;
         $83 = $$pre29;
        }
        $81 = HEAP32[$43>>2]|0;
        HEAP32[$2>>2] = $81;
        $82 = ($83|0)==(0|0);
        if ($82) {
         label = 38;
        } else {
         $84 = (($83) + 36|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = (($83) + 4|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = ($85|0)==($87|0);
         do {
          if ($88) {
           $89 = (($83) + 28|0);
           $90 = HEAP32[$89>>2]|0;
           $91 = (($83) + 32|0);
           $92 = HEAP32[$91>>2]|0;
           $93 = (($90) + ($92<<3)|0);
           $109 = $93;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy6,$83,$2);
           $94 = HEAP32[$$byval_copy6>>2]|0;
           $95 = ($94|0)==(-1);
           $96 = (($83) + 28|0);
           $97 = HEAP32[$96>>2]|0;
           if ($95) {
            $98 = (($83) + 32|0);
            $99 = HEAP32[$98>>2]|0;
            $100 = (($97) + ($99<<3)|0);
            $109 = $100;
            break;
           } else {
            $101 = (($97) + ($94<<3)|0);
            $109 = $101;
            break;
           }
          }
         } while(0);
         $102 = HEAP32[560624>>2]|0;
         $103 = (($102) + 28|0);
         $104 = HEAP32[$103>>2]|0;
         $105 = (($102) + 32|0);
         $106 = HEAP32[$105>>2]|0;
         $107 = (($104) + ($106<<3)|0);
         $108 = ($109|0)==($107|0);
         if ($108) {
          label = 38;
         } else {
          $110 = (($109) + 4|0);
          $111 = HEAP32[$110>>2]|0;
          $112 = ($111|0)==(0|0);
          if ($112) {
           label = 38;
          } else {
           $temp$0$i = $111;
          }
         }
        }
        if ((label|0) == 38) {
         label = 0;
         $113 = HEAP32[$43>>2]|0;
         __THREW__ = 0;
         $114 = (invoke_ii(3215,($113|0))|0);
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break L18;
         } else {
          $temp$0$i = $114;
         }
        }
        $117 = (($42) + 24|0);
        $118 = HEAP32[$117>>2]|0;
        __THREW__ = 0;
        $119 = (invoke_iii(2600,($temp$0$i|0),($118|0))|0);
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if ($121) {
         break L18;
        }
        if (!($119)) {
         $122 = HEAP32[$42>>2]|0;
         $123 = (($122) + 128|0);
         $124 = HEAP32[$123>>2]|0;
         __THREW__ = 0;
         invoke_vi($124|0,($42|0));
         $125 = __THREW__; __THREW__ = 0;
         $126 = $125&1;
         if ($126) {
          break L18;
         }
         $127 = HEAP32[$42>>2]|0;
         $128 = (($127) + 124|0);
         $129 = HEAP32[$128>>2]|0;
         __THREW__ = 0;
         invoke_vi($129|0,($42|0));
         $130 = __THREW__; __THREW__ = 0;
         $131 = $130&1;
         if ($131) {
          break L18;
         }
        }
       }
      } while(0);
      $132 = (($i1$019) + 1)|0;
      $133 = HEAP32[$3>>2]|0;
      $134 = HEAP32[$tempList>>2]|0;
      $135 = $133;
      $136 = $134;
      $137 = (($135) - ($136))|0;
      $138 = $137 >> 2;
      $139 = ($132>>>0)<($138>>>0);
      if ($139) {
       $41 = $134;$i1$019 = $132;
      } else {
       $$lcssa = $133;$$lcssa15 = $134;$$lcssa17 = $136;
       break L16;
      }
     }
     $25 = ___cxa_find_matching_catch()|0;
     $26 = tempRet0;
     $lpad$phi$index = $25;$lpad$phi$index2 = $26;
     break L13;
    }
   } while(0);
   $140 = ($$lcssa15|0)==(0|0);
   if ($140) {
    STACKTOP = sp;return;
   }
   $141 = ($$lcssa|0)==($$lcssa15|0);
   if (!($141)) {
    $scevgep$i$i$i$i$i = (($$lcssa) + -4|0);
    $142 = (0 - ($$lcssa17))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($142)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $143 = $uglygep3$i$i$i$i$i >>> 2;
    $144 = $143 ^ -1;
    $scevgep4$i$i$i$i$i = (($$lcssa) + ($144<<2)|0);
    HEAP32[$3>>2] = $scevgep4$i$i$i$i$i;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($$lcssa15|0),($$byval_copy6|0));
   $145 = __THREW__; __THREW__ = 0;
   $146 = $145&1;
   if ($146) {
    $147 = ___cxa_find_matching_catch()|0;
    $148 = tempRet0;
    ___cxa_call_unexpected(($147|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
  else if ((label|0) == 12) {
   $27 = ___cxa_find_matching_catch()|0;
   $28 = tempRet0;
   $lpad$phi$index = $27;$lpad$phi$index2 = $28;
  }
 } while(0);
 $29 = HEAP32[$tempList>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $31 = HEAP32[$3>>2]|0;
 $32 = ($31|0)==($29|0);
 if (!($32)) {
  $__new_last2$i$i$i$i$i2 = $29;
  $scevgep$i$i$i$i$i3 = (($31) + -4|0);
  $33 = (0 - ($__new_last2$i$i$i$i$i2))|0;
  $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($33)|0);
  $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
  $34 = $uglygep3$i$i$i$i$i6 >>> 2;
  $35 = $34 ^ -1;
  $scevgep4$i$i$i$i$i7 = (($31) + ($35<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i7;
 }
 HEAP32[$1>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($29|0),($$byval_copy6|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN14TerrainManager10AddTerrainEP7Terrain($this,$terrain) {
 $this = $this|0;
 $terrain = $terrain|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 L1: do {
  if ($4) {
   $13 = $3;
   label = 4;
  } else {
   $6 = $3;
   while(1) {
    $5 = (($6) + 8|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==($terrain|0);
    if ($8) {
     $13 = $6;
     label = 4;
     break L1;
    }
    $9 = (($6) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($1|0);
    if ($11) {
     break;
    } else {
     $6 = $10;
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $12 = ($13|0)==($1|0);
  if (!($12)) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$0>>2] = 44;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $14 = (__Z15malloc_internaljj10MemLabelIdiPKci(12,16,$$byval_copy,0,802376,79)|0);
 $15 = (($14) + 8|0);
 HEAP32[$15>>2] = $terrain;
 $16 = HEAP32[$1>>2]|0;
 $17 = (($16) + 4|0);
 HEAP32[$17>>2] = $14;
 $18 = HEAP32[$1>>2]|0;
 HEAP32[$14>>2] = $18;
 HEAP32[$1>>2] = $14;
 $19 = (($14) + 4|0);
 HEAP32[$19>>2] = $1;
 $20 = (($this) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 1)|0;
 HEAP32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN14TerrainManager13RemoveTerrainEP7Terrain($this,$terrain) {
 $this = $this|0;
 $terrain = $terrain|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 L1: do {
  if ($4) {
   $13 = $3;
  } else {
   $6 = $3;
   while(1) {
    $5 = (($6) + 8|0);
    $7 = HEAP32[$5>>2]|0;
    $8 = ($7|0)==($terrain|0);
    if ($8) {
     $13 = $6;
     break L1;
    }
    $9 = (($6) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==($1|0);
    if ($11) {
     break;
    } else {
     $6 = $10;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $12 = ($13|0)==($1|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $14 = (($13) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$13>>2]|0;
 $17 = (($16) + 4|0);
 HEAP32[$17>>2] = $15;
 $18 = HEAP32[$13>>2]|0;
 $19 = HEAP32[$14>>2]|0;
 HEAP32[$19>>2] = $18;
 $20 = (($this) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + -1)|0;
 HEAP32[$20>>2] = $22;
 HEAP32[$0>>2] = 44;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($13|0),($$byval_copy|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  ___cxa_call_unexpected(($25|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN14TerrainManager27UnloadTerrainsFromGfxDeviceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $2;
 }
 while(1) {
  $4 = (($5) + 8|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = (($6) + 204|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = (($6) + 196|0);
   $i1$01 = 0;
   while(1) {
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($11) + (($i1$01*20)|0)|0) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    __ZN15TerrainRenderer19UnloadFromGfxDeviceEv($13);
    $14 = (($i1$01) + 1)|0;
    $15 = HEAP32[$7>>2]|0;
    $16 = ($14>>>0)<($15>>>0);
    if ($16) {
     $i1$01 = $14;
    } else {
     break;
    }
   }
  }
  $17 = (($5) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==($0|0);
  if ($19) {
   break;
  } else {
   $5 = $18;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14TerrainManager25ReloadTerrainsToGfxDeviceEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $2;
 }
 while(1) {
  $4 = (($5) + 8|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = (($6) + 204|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = (($6) + 196|0);
   $i1$01 = 0;
   while(1) {
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($11) + (($i1$01*20)|0)|0) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    __ZN15TerrainRenderer17ReloadToGfxDeviceEv($13);
    $14 = (($i1$01) + 1)|0;
    $15 = HEAP32[$7>>2]|0;
    $16 = ($14>>>0)<($15>>>0);
    if ($16) {
     $i1$01 = $14;
    } else {
     break;
    }
   }
  }
  $17 = (($5) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==($0|0);
  if ($19) {
   break;
  } else {
   $5 = $18;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14TerrainManager26Heightmap_GetPxHeightFieldER9Heightmap($this,$heightmap) {
 $this = $this|0;
 $heightmap = $heightmap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9Heightmap16GetPxHeightFieldEv($heightmap)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14TerrainManager17Heightmap_GetSizeER9Heightmap($agg$result,$this,$heightmap) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $heightmap = $heightmap|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK9Heightmap7GetSizeEv($agg$result,$heightmap);
 STACKTOP = sp;return;
}
function __ZN14TerrainManager20CollectTreeRenderersER13dynamic_arrayI9SceneNodeLj4EERS0_I4AABBLj4EE($this,$sceneNodes,$boundingBoxes) {
 $this = $this|0;
 $sceneNodes = $sceneNodes|0;
 $boundingBoxes = $boundingBoxes|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 16|0);
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if (!($4)) {
  $6 = $3;
  while(1) {
   $5 = (($6) + 8|0);
   $7 = HEAP32[$5>>2]|0;
   $8 = (($7) + 188|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 & 2;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $12 = (($7) + 86|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if (!($14)) {
     $15 = (($7) + 60|0);
     $16 = Math_fround(HEAPF32[$15>>2]);
     $17 = +$16;
     $18 = $17 > 0.00100000000000000002082;
     if ($18) {
      $19 = (__ZN7Terrain11GetRendererEv($7)|0);
      $20 = ($19|0)==(0|0);
      if (!($20)) {
       $21 = (($19) + 8|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($22|0)==(0|0);
       if (!($23)) {
        __ZN12TreeRenderer20CollectTreeRenderersER13dynamic_arrayI9SceneNodeLj4EERS0_I4AABBLj4EE($22,$sceneNodes,$boundingBoxes);
       }
      }
     }
    }
   }
   $24 = (($6) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==($1|0);
   if ($26) {
    break;
   } else {
    $6 = $25;
   }
  }
 }
 $27 = (($this) + 28|0);
 $28 = (($this) + 36|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($sceneNodes) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $30 & 2147483647;
 $34 = ($33>>>0)<($32>>>0);
 do {
  if ($34) {
   $35 = ($30|0)>(-1);
   if ($35) {
    HEAP32[$29>>2] = $32;
    $36 = HEAP32[$27>>2]|0;
    $37 = (($this) + 32|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$0>>2] = $38;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $39 = (__Z16realloc_internalPvji10MemLabelIdiPKci($36,$32,1,$$byval_copy1,0,802376,370)|0);
    HEAP32[$27>>2] = $39;
    break;
   } else {
    $40 = (($this) + 32|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$0>>2] = $41;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $42 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,1,$$byval_copy1,0,802376,352)|0);
    $43 = HEAP32[$27>>2]|0;
    $44 = HEAP32[$28>>2]|0;
    _memcpy(($42|0),($43|0),($44|0))|0;
    HEAP32[$29>>2] = $32;
    HEAP32[$27>>2] = $42;
    break;
   }
  }
 } while(0);
 $45 = HEAP32[$28>>2]|0;
 $46 = ($45>>>0)<($32>>>0);
 if (!($46)) {
  HEAP32[$28>>2] = $32;
  STACKTOP = sp;return;
 }
 $47 = HEAP32[$27>>2]|0;
 $48 = (($47) + ($32)|0);
 $49 = ($45|0)==($32|0);
 if ($49) {
  HEAP32[$28>>2] = $32;
  STACKTOP = sp;return;
 }
 $50 = (($47) + ($45)|0);
 $$01$i$i = $50;
 while(1) {
  $51 = ($$01$i$i|0)==(0|0);
  if (!($51)) {
   HEAP8[$$01$i$i>>0] = 0;
  }
  $52 = (($$01$i$i) + 1|0);
  $53 = ($52|0)==($48|0);
  if ($53) {
   break;
  } else {
   $$01$i$i = $52;
  }
 }
 HEAP32[$28>>2] = $32;
 STACKTOP = sp;return;
}
function __ZNK14TerrainManager23CollectLODGroupManagersEPPK15LODGroupManageri($this,$lodGroupManagers,$arraySize) {
 $this = $this|0;
 $lodGroupManagers = $lodGroupManagers|0;
 $arraySize = $arraySize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($0|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $2;
 }
 while(1) {
  $4 = (($5) + 8|0);
  $6 = HEAP32[$4>>2]|0;
  $7 = (($6) + 188|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & 2;
  $10 = ($9|0)==(0);
  if (!($10)) {
   $11 = (($6) + 86|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if (!($13)) {
    $14 = (($6) + 60|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = +$15;
    $17 = $16 > 0.00100000000000000002082;
    if ($17) {
     $18 = (__ZN7Terrain11GetRendererEv($6)|0);
     $19 = ($18|0)==(0|0);
     if (!($19)) {
      $20 = (($18) + 8|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21|0)==(0|0);
      if (!($22)) {
       $23 = (($21) + 204|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($24|0)<($arraySize|0);
       if ($25) {
        $26 = (($lodGroupManagers) + ($24<<2)|0);
        HEAP32[$26>>2] = $23;
       }
      }
     }
    }
   }
  }
  $27 = (($5) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==($0|0);
  if ($29) {
   break;
  } else {
   $5 = $28;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14TerrainManager23TryGetSplatBaseMaterialEP7Terrain($this,$terrain) {
 $this = $this|0;
 $terrain = $terrain|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7Terrain23TryGetSplatBaseMaterialEv($terrain)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK14TerrainManager31GetSplatBaseMaterialTextureNameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (801088|0);
}
function __ZN14TerrainManager12GetWorldAABBEP7Terrain($agg$result,$this,$terrain) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $terrain = $terrain|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK7Terrain12GetWorldAABBEv($agg$result,$terrain);
 STACKTOP = sp;return;
}
function __ZN14TerrainManager21GetEnlightenProxyMeshEP7Terrain($this,$terrain) {
 $this = $this|0;
 $terrain = $terrain|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZNK14TerrainManager16GetActiveTerrainEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $7 = 0;
  STACKTOP = sp;return ($7|0);
 }
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function __ZNK14TerrainManager17GetActiveTerrainsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__16vectorIP7Terrain13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 2;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 2;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,802376,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<2)|0);
 $24 = (($23) + ($$0$i3<<2)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  $26 = HEAP32[$__x>>2]|0;
  HEAP32[$22>>2] = $26;
 }
 $27 = (($23) + ($8<<2)|0);
 $28 = HEAP32[$this>>2]|0;
 $29 = HEAP32[$1>>2]|0;
 $30 = $29;
 $31 = $28;
 $32 = (($30) - ($31))|0;
 $33 = $32 >> 2;
 $$sum1 = (($7) - ($33))|0;
 $34 = (($23) + ($$sum1<<2)|0);
 _memcpy(($34|0),($28|0),($32|0))|0;
 $35 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $34;
 HEAP32[$1>>2] = $27;
 HEAP32[$10>>2] = $24;
 $36 = ($35|0)==(0|0);
 if ($36) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($35|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z22RegisterModule_Terrainv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $i$01$i$i1 = 0;
 var $i$01$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i = 0;
 while(1) {
  $3 = ((($0) + ($i$01$i$i<<2)|0) + 64|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  $2 = (($i$01$i$i) + 1)|0;
  if ($5) {
   label = 4;
   break;
  }
  $1 = ($2|0)<(16);
  if ($1) {
   $i$01$i$i = $2;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$3>>2] = 246;
 }
 $6 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i2 = 0;
 while(1) {
  $9 = (($6) + ($i$01$i$i2<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  $8 = (($i$01$i$i2) + 1)|0;
  if ($11) {
   label = 8;
   break;
  }
  $7 = ($8|0)<(16);
  if ($7) {
   $i$01$i$i2 = $8;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  HEAP32[$9>>2] = 247;
 }
 $12 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i1 = 0;
 while(1) {
  $15 = ((($12) + ($i$01$i$i1<<2)|0) + 128|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  $14 = (($i$01$i$i1) + 1)|0;
  if ($17) {
   break;
  }
  $13 = ($14|0)<(16);
  if ($13) {
   $i$01$i$i1 = $14;
  } else {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
 HEAP32[$15>>2] = 248;
 STACKTOP = sp;return;
}
function __ZL28RegisterModuleICalls_Terrainv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL24InitializeModule_Terrainv() {
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (__ZN15GlobalCallbacks3GetEv()|0);
 $i$01$i = 0;
 while(1) {
  $4 = ((($1) + ($i$01$i<<2)|0) + 256|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  $3 = (($i$01$i) + 1)|0;
  if ($6) {
   label = 4;
   break;
  }
  $2 = ($3|0)<(16);
  if ($2) {
   $i$01$i = $3;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$4>>2] = 2037;
 }
 $7 = HEAP32[628440>>2]|0;
 HEAP32[$0>>2] = $7;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $8 = (__Znwj10MemLabelIdbiPKci(44,$$byval_copy1,1,16,802464,52)|0);
 __THREW__ = 0;
 invoke_vi(3713,($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  __Z18SetITerrainManagerP15ITerrainManager($8);
  STACKTOP = sp;return;
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($8|0),($$byval_copy1|0),1,16,(802464|0),52);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($11|0);
  // unreachable;
 }
}
function __ZL21CleanupModule_Terrainv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__Z18GetITerrainManagerv()|0);
 $2 = HEAP32[628440>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$1>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 __Z18SetITerrainManagerP15ITerrainManager(0);
 STACKTOP = sp;return;
}
function __ZL27PostLoadLevelAdditiveStaticRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER18AwakeFromLoadQueueN18LoadLevelOperation11LoadingModeE19992($pathName,$awakeQueue,$mode) {
 $pathName = $pathName|0;
 $awakeQueue = $awakeQueue|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 if (!((($mode|0) == 1) | (($mode|0) == 5))) {
  STACKTOP = sp;return;
 }
 $1 = (__ZN18AwakeFromLoadQueue19GetManagerFromQueueI16LightmapSettingsEEPT_v($awakeQueue)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($1) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (__Z19GetLightmapSettingsv()|0);
 $7 = (($6) + 76|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($awakeQueue) + 72|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (($awakeQueue) + 64|0);
 $i$03 = 0;
 while(1) {
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14) + (($i$03*12)|0)|0) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$0>>2] = $16;
  $17 = HEAP32[560624>>2]|0;
  $18 = ($17|0)==(0|0);
  if (!($18)) {
   $19 = (($17) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($17) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($20|0)==($22|0);
   do {
    if ($23) {
     $24 = (($17) + 28|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($17) + 32|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (($25) + ($27<<3)|0);
     $44 = $28;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$17,$0);
     $29 = HEAP32[$pos$i$i$i>>2]|0;
     $30 = ($29|0)==(-1);
     $31 = (($17) + 28|0);
     $32 = HEAP32[$31>>2]|0;
     if ($30) {
      $33 = (($17) + 32|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($32) + ($34<<3)|0);
      $44 = $35;
      break;
     } else {
      $36 = (($32) + ($29<<3)|0);
      $44 = $36;
      break;
     }
    }
   } while(0);
   $37 = HEAP32[560624>>2]|0;
   $38 = (($37) + 28|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($37) + 32|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($39) + ($41<<3)|0);
   $43 = ($44|0)==($42|0);
   if (!($43)) {
    $45 = (($44) + 4|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)==(0|0);
    if (!($47)) {
     $48 = (($46) + 8|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = $49 >>> 21;
     $51 = HEAP32[560640>>2]|0;
     $52 = Math_imul($51, $50)|0;
     $53 = (($52) + 218)|0;
     $54 = $53 >> 5;
     $55 = $54 << 5;
     $56 = (($53) - ($55))|0;
     $57 = HEAP32[560632>>2]|0;
     $58 = (($57) + ($54<<2)|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = 1 << $56;
     $61 = $60 & $59;
     $62 = ($61|0)==(0);
     if (!($62)) {
      __ZN7Terrain18ShiftLightmapIndexEi($46,$8);
     }
    }
   }
  }
  $63 = (($i$03) + 1)|0;
  $64 = HEAP32[$10>>2]|0;
  $65 = ($63>>>0)<($64>>>0);
  if ($65) {
   $i$03 = $63;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __GLOBAL__I_a20005() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,802472);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,802480);
 STACKTOP = sp;return;
}
function __ZNK12TreeDatabase9Prototype21GetTreeInstanceMatrixER10Matrix4x4fRK8Vector3fRK12TreeInstance($this,$mat,$position,$treeInstance) {
 $this = $this|0;
 $mat = $mat|0;
 $position = $position|0;
 $treeInstance = $treeInstance|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scale = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $scale = sp + 16|0;
 $0 = sp;
 $1 = (($treeInstance) + 12|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($treeInstance) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 HEAPF32[$scale>>2] = $2;
 $5 = (($scale) + 4|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($scale) + 8|0);
 HEAPF32[$6>>2] = $2;
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(2);
 if ($9) {
  $10 = (($treeInstance) + 20|0);
  $11 = Math_fround(HEAPF32[$10>>2]);
  $12 = Math_fround($11 * Math_fround(0.5));
  $13 = (Math_fround(+(Math_sin((+$12)))));
  $14 = (Math_fround(+(Math_cos((+$12)))));
  $15 = (($0) + 12|0);
  HEAPF32[$15>>2] = $14;
  $16 = Math_fround(HEAPF32[616728>>2]);
  $17 = Math_fround($13 * $16);
  HEAPF32[$0>>2] = $17;
  $18 = Math_fround(HEAPF32[((616728 + 4|0))>>2]);
  $19 = Math_fround($13 * $18);
  $20 = (($0) + 4|0);
  HEAPF32[$20>>2] = $19;
  $21 = Math_fround(HEAPF32[((616728 + 8|0))>>2]);
  $22 = Math_fround($13 * $21);
  $23 = (($0) + 8|0);
  HEAPF32[$23>>2] = $22;
  __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($mat,$position,$0,$scale);
  STACKTOP = sp;return;
 } else {
  HEAPF32[$0>>2] = Math_fround(0.0);
  $24 = (($0) + 4|0);
  HEAPF32[$24>>2] = Math_fround(0.0);
  $25 = (($0) + 8|0);
  HEAPF32[$25>>2] = Math_fround(0.0);
  $26 = (($0) + 12|0);
  HEAPF32[$26>>2] = Math_fround(1.0);
  __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($mat,$position,$0,$scale);
  STACKTOP = sp;return;
 }
}
function __ZN24TreeIntermediateRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns($this,$renderData,$channels) {
 $this = $this|0;
 $renderData = $renderData|0;
 $channels = $channels|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z20RenderMultipleMeshesRK22RenderMultipleMeshDataRK14ChannelAssigns($renderData,$channels);
 STACKTOP = sp;return;
}
function __ZN26LegacyTreeInstanceRendererC2ER12TreeRendereriP4MeshRK13dynamic_arrayIPN5Unity8MaterialELj4EERK10Matrix4x4fRK4AABB($this,$treeRenderer,$treeIndex,$mesh,$materials,$matrix,$aabb) {
 $this = $this|0;
 $treeRenderer = $treeRenderer|0;
 $treeIndex = $treeIndex|0;
 $mesh = $mesh|0;
 $materials = $materials|0;
 $matrix = $matrix|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN20IntermediateRendererC2Ev($this);
 $1 = (($this) + 244|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 248|0);
 HEAP32[$2>>2] = $treeRenderer;
 $3 = (($this) + 252|0);
 HEAP32[$3>>2] = $treeIndex;
 HEAP32[$this>>2] = ((802528 + 8|0));
 $4 = (($this) + 260|0);
 HEAP32[$4>>2] = $materials;
 HEAP32[$0>>2] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(72,($this|0),($matrix|0),($aabb|0),($0|0),0,1,1);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = (($this) + 256|0);
  HEAP32[$7>>2] = $mesh;
  $8 = (($this) + 204|0);
  $9 = (($this) + 168|0);
  HEAP32[$9>>2] = $8;
  STACKTOP = sp;return;
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __THREW__ = 0;
 invoke_vi(950,($this|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 } else {
  ___resumeException($10|0);
  // unreachable;
 }
}
function __ZN26LegacyTreeInstanceRenderer6RenderEiRK14ChannelAssigns($this,$materialIndex,$channels) {
 $this = $this|0;
 $materialIndex = $materialIndex|0;
 $channels = $channels|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__Z12GetGfxDevicev()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 216|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$0>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($3,$7);
 }
 $8 = (($this) + 256|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_($channels,$9,$materialIndex,0,0);
 STACKTOP = sp;return;
}
function __ZN26LegacyTreeInstanceRenderer6UpdateEb($this,$shadows) {
 $this = $this|0;
 $shadows = $shadows|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 42|0);
 $1 = $shadows&1;
 HEAP8[$0>>0] = $1;
 $2 = (($this) + 41|0);
 HEAP8[$2>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN23LODTreeInstanceRendererC2ER12TreeRendereriR12MeshRendererRK10Matrix4x4fi($this,$treeRenderer,$treeIndex,$meshRenderer,$matrix,$treeInstanceDataIndex) {
 $this = $this|0;
 $treeRenderer = $treeRenderer|0;
 $treeIndex = $treeIndex|0;
 $meshRenderer = $meshRenderer|0;
 $matrix = $matrix|0;
 $treeInstanceDataIndex = $treeInstanceDataIndex|0;
 var $$0$i7 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $phitmp = 0, $pos$i$i$i$i2 = 0, $temp$0$i16 = 0, $temp$0$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i2 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 __ZN20IntermediateRendererC2Ev($this);
 $4 = (($this) + 244|0);
 HEAP32[$4>>2] = 1;
 $5 = (($this) + 248|0);
 HEAP32[$5>>2] = $treeRenderer;
 $6 = (($this) + 252|0);
 HEAP32[$6>>2] = $treeIndex;
 HEAP32[$this>>2] = ((802624 + 8|0));
 $7 = (($this) + 260|0);
 $8 = (($meshRenderer) + 220|0);
 HEAP32[$7>>2] = $8;
 $9 = (($this) + 264|0);
 HEAP32[$9>>2] = $treeInstanceDataIndex;
 $10 = (($this) + 268|0);
 HEAP8[$10>>0] = 0;
 $11 = (($meshRenderer) + 204|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 176|0);
 HEAP32[$13>>2] = $12;
 $14 = (($meshRenderer) + 72|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 44|0);
 HEAP32[$16>>2] = $15;
 __THREW__ = 0;
 invoke_vii(3418,($2|0),($meshRenderer|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = HEAP32[$2>>2]|0;
   $20 = ($19|0)==(0);
   if ($20) {
    $$0$i7 = 0;
   } else {
    HEAP32[$0>>2] = $19;
    $21 = HEAP32[560624>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     label = 11;
    } else {
     $23 = (($21) + 36|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($21) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($24|0)==($26|0);
     do {
      if ($27) {
       $28 = (($21) + 28|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($21) + 32|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = (($29) + ($31<<3)|0);
       $48 = $32;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i2,$21,$0);
       $33 = HEAP32[$pos$i$i$i$i2>>2]|0;
       $34 = ($33|0)==(-1);
       $35 = (($21) + 28|0);
       $36 = HEAP32[$35>>2]|0;
       if ($34) {
        $37 = (($21) + 32|0);
        $38 = HEAP32[$37>>2]|0;
        $39 = (($36) + ($38<<3)|0);
        $48 = $39;
        break;
       } else {
        $40 = (($36) + ($33<<3)|0);
        $48 = $40;
        break;
       }
      }
     } while(0);
     $41 = HEAP32[560624>>2]|0;
     $42 = (($41) + 28|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($41) + 32|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($43) + ($45<<3)|0);
     $47 = ($48|0)==($46|0);
     if ($47) {
      label = 11;
     } else {
      $49 = (($48) + 4|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($50|0)==(0|0);
      if ($51) {
       label = 11;
      } else {
       $temp$0$i6 = $50;
      }
     }
    }
    if ((label|0) == 11) {
     $52 = HEAP32[$2>>2]|0;
     __THREW__ = 0;
     $53 = (invoke_ii(3215,($52|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     } else {
      $temp$0$i6 = $53;
     }
    }
    $$0$i7 = $temp$0$i6;
   }
   $56 = (($this) + 256|0);
   HEAP32[$56>>2] = $$0$i7;
   $57 = (($$0$i7) + 168|0);
   HEAP32[$3>>2] = 0;
   $58 = (($meshRenderer) + 69|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = ($59<<24>>24)!=(0);
   $61 = (($meshRenderer) + 70|0);
   $62 = HEAP8[$61>>0]|0;
   $63 = ($62<<24>>24)!=(0);
   __THREW__ = 0;
   invoke_viiiiiii(72,($this|0),($matrix|0),($57|0),($3|0),0,($60|0),($63|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if (!($65)) {
    $66 = HEAP32[$7>>2]|0;
    $67 = (($66) + 8|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ($68|0)==(0);
    if ($69) {
     $129 = 1;
     $128 = (($this) + 269|0);
     HEAP8[$128>>0] = $129;
     STACKTOP = sp;return;
    }
    $70 = HEAP32[$66>>2]|0;
    $71 = HEAP32[$70>>2]|0;
    $72 = ($71|0)==(0);
    if ($72) {
     $129 = 1;
     $128 = (($this) + 269|0);
     HEAP8[$128>>0] = $129;
     STACKTOP = sp;return;
    }
    HEAP32[$1>>2] = $71;
    $73 = HEAP32[560624>>2]|0;
    $74 = ($73|0)==(0|0);
    if ($74) {
     label = 24;
    } else {
     $75 = (($73) + 36|0);
     $76 = HEAP32[$75>>2]|0;
     $77 = (($73) + 4|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ($76|0)==($78|0);
     do {
      if ($79) {
       $80 = (($73) + 28|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = (($73) + 32|0);
       $83 = HEAP32[$82>>2]|0;
       $84 = (($81) + ($83<<3)|0);
       $100 = $84;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i2,$73,$1);
       $85 = HEAP32[$pos$i$i$i$i2>>2]|0;
       $86 = ($85|0)==(-1);
       $87 = (($73) + 28|0);
       $88 = HEAP32[$87>>2]|0;
       if ($86) {
        $89 = (($73) + 32|0);
        $90 = HEAP32[$89>>2]|0;
        $91 = (($88) + ($90<<3)|0);
        $100 = $91;
        break;
       } else {
        $92 = (($88) + ($85<<3)|0);
        $100 = $92;
        break;
       }
      }
     } while(0);
     $93 = HEAP32[560624>>2]|0;
     $94 = (($93) + 28|0);
     $95 = HEAP32[$94>>2]|0;
     $96 = (($93) + 32|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = (($95) + ($97<<3)|0);
     $99 = ($100|0)==($98|0);
     if ($99) {
      label = 24;
     } else {
      $101 = (($100) + 4|0);
      $102 = HEAP32[$101>>2]|0;
      $103 = ($102|0)==(0|0);
      if ($103) {
       label = 24;
      } else {
       $temp$0$i16 = $102;
      }
     }
    }
    if ((label|0) == 24) {
     $104 = HEAP32[$70>>2]|0;
     __THREW__ = 0;
     $105 = (invoke_ii(3215,($104|0))|0);
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if ($107) {
      break;
     }
     $108 = ($105|0)==(0|0);
     if ($108) {
      $129 = 1;
      $128 = (($this) + 269|0);
      HEAP8[$128>>0] = $129;
      STACKTOP = sp;return;
     } else {
      $temp$0$i16 = $105;
     }
    }
    $109 = (($temp$0$i16) + 88|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = ($110|0)==(0|0);
    if ($111) {
     $129 = 1;
     $128 = (($this) + 269|0);
     HEAP8[$128>>0] = $129;
     STACKTOP = sp;return;
    }
    $112 = HEAP32[802496>>2]|0;
    $$0$ph7$i$i$i$i = $109;$$01$ph6$i$in$i$i$i = $110;
    L44: while(1) {
     $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
     while(1) {
      $113 = (($$013$i$in$i$i$i) + 16|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = ($114|0)<($112|0);
      if (!($115)) {
       break;
      }
      $118 = (($$013$i$in$i$i$i) + 4|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = ($119|0)==(0|0);
      if ($120) {
       $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
       break L44;
      } else {
       $$013$i$in$i$i$i = $119;
      }
     }
     $116 = HEAP32[$$013$i$in$i$i$i>>2]|0;
     $117 = ($116|0)==(0|0);
     if ($117) {
      $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
      break;
     } else {
      $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $116;
     }
    }
    $121 = ($$0$ph5$i$i$i$i|0)==($109|0);
    if ($121) {
     $129 = 1;
     $128 = (($this) + 269|0);
     HEAP8[$128>>0] = $129;
     STACKTOP = sp;return;
    }
    $122 = (($$0$ph5$i$i$i$i) + 16|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = ($112|0)<($123|0);
    if ($124) {
     $129 = 1;
     $128 = (($this) + 269|0);
     HEAP8[$128>>0] = $129;
     STACKTOP = sp;return;
    }
    $125 = (($$0$ph5$i$i$i$i) + 20|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = $126 == Math_fround(0.0);
    $phitmp = $127&1;
    $129 = $phitmp;
    $128 = (($this) + 269|0);
    HEAP8[$128>>0] = $129;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $130 = ___cxa_find_matching_catch()|0;
 $131 = tempRet0;
 __THREW__ = 0;
 invoke_vi(950,($this|0));
 $132 = __THREW__; __THREW__ = 0;
 $133 = $132&1;
 if ($133) {
  $134 = ___cxa_find_matching_catch(0|0)|0;
  $135 = tempRet0;
  ___clang_call_terminate($134);
  // unreachable;
 } else {
  ___resumeException($130|0);
  // unreachable;
 }
}
function __ZN23LODTreeInstanceRenderer6RenderEiRK14ChannelAssigns($this,$materialIndex,$channels) {
 $this = $this|0;
 $materialIndex = $materialIndex|0;
 $channels = $channels|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 168|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__Z12GetGfxDevicev()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 216|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$0>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($3,$7);
 }
 $8 = (($this) + 256|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_($channels,$9,$materialIndex,0,0);
 STACKTOP = sp;return;
}
function __ZN23LODTreeInstanceRenderer10UpdateWindEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $result = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $result = sp;
 $0 = (($this) + 248|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 269|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 264|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6;
 } else {
  $7 = -1;
 }
 __ZN12TreeRenderer21ComputeWindPropertiesEib($result,$1,$7,0);
 $8 = HEAP32[$result>>2]|0;
 $9 = (($this) + 168|0);
 HEAP32[$9>>2] = $8;
 $10 = (($result) + 4|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = (($this) + 268|0);
 HEAP8[$12>>0] = $11;
 STACKTOP = sp;return;
}
function __ZN29BillboardTreeInstanceRendererC2ER12TreeRendereriiib($this,$treeRenderer,$treeIndex,$treeInstanceDataIndex,$billboardAssetInstanceId,$prototypeUsesLightProbe) {
 $this = $this|0;
 $treeRenderer = $treeRenderer|0;
 $treeIndex = $treeIndex|0;
 $treeInstanceDataIndex = $treeInstanceDataIndex|0;
 $billboardAssetInstanceId = $billboardAssetInstanceId|0;
 $prototypeUsesLightProbe = $prototypeUsesLightProbe|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererC2Ev($this);
 $0 = (($this) + 244|0);
 HEAP32[$0>>2] = 2;
 $1 = (($this) + 248|0);
 HEAP32[$1>>2] = $treeRenderer;
 $2 = (($this) + 252|0);
 HEAP32[$2>>2] = $treeIndex;
 HEAP32[$this>>2] = ((802720 + 8|0));
 $3 = (($this) + 260|0);
 HEAP32[$3>>2] = $billboardAssetInstanceId;
 $4 = (($this) + 264|0);
 HEAP32[$4>>2] = $treeInstanceDataIndex;
 $5 = (($this) + 268|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = $prototypeUsesLightProbe&1;
 $7 = (($this) + 176|0);
 HEAP32[$7>>2] = $6;
 __THREW__ = 0;
 $8 = (invoke_i(125)|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = (($8) + 60|0);
  $12 = (($this) + 168|0);
  HEAP32[$12>>2] = $11;
  $13 = (($this) + 272|0);
  HEAP8[$13>>0] = 1;
  STACKTOP = sp;return;
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __THREW__ = 0;
 invoke_vi(950,($this|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($14|0);
  // unreachable;
 }
}
function __ZN29BillboardTreeInstanceRenderer6RenderEiRK14ChannelAssigns($this,$materialIndex,$channels) {
 $this = $this|0;
 $materialIndex = $materialIndex|0;
 $channels = $channels|0;
 var $$byval_copy12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0;
 var $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $eh$lpad$body$indexZ2D = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy12 = sp + 64|0;
 $0 = sp;
 $1 = sp + 4|0;
 $temp = sp + 8|0;
 $2 = sp + 48|0;
 $3 = (__Z24GetBillboardBatchManagerv()|0);
 $4 = (($3) + 60|0);
 $5 = (__Z12GetGfxDevicev()|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 216|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095]($5,$4);
 $9 = (($this) + 168|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($4|0);
 if (!($11)) {
  $12 = (__Z12GetGfxDevicev()|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + 216|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$15 & 4095]($12,$16);
 }
 $17 = (($this) + 248|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 252|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[628512>>2]|0;
 HEAP32[$temp>>2] = 0;
 $25 = (($temp) + 4|0);
 HEAP32[$25>>2] = $24;
 $26 = (($temp) + 8|0);
 HEAP32[$26>>2] = 0;
 $27 = (($temp) + 12|0);
 HEAP32[$27>>2] = 0;
 $28 = (($temp) + 16|0);
 HEAP32[$28>>2] = 0;
 $29 = (($temp) + 20|0);
 HEAP32[$29>>2] = $24;
 $30 = (($temp) + 24|0);
 HEAP32[$30>>2] = 0;
 $31 = (($temp) + 28|0);
 HEAP32[$31>>2] = 0;
 $32 = (($temp) + 32|0);
 $33 = HEAP32[641904>>2]|0;
 HEAP32[$32>>2] = $33;
 $34 = ((($23) + (($21*40)|0)|0) + 12|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = ((($23) + (($21*40)|0)|0) + 16|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = ((($23) + (($21*40)|0)|0) + 20|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = (($this) + 268|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 HEAPF32[$2>>2] = $35;
 $42 = (($2) + 4|0);
 HEAPF32[$42>>2] = $37;
 $43 = (($2) + 8|0);
 HEAPF32[$43>>2] = $39;
 $44 = (($2) + 12|0);
 HEAPF32[$44>>2] = $41;
 __THREW__ = 0;
 invoke_viii(2027,($temp|0),(589712|0),($2|0));
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if (!($46)) {
  __THREW__ = 0;
  $47 = (invoke_i(59)|0);
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  if (!($49)) {
   $50 = HEAP32[$47>>2]|0;
   $51 = (($50) + 216|0);
   $52 = HEAP32[$51>>2]|0;
   __THREW__ = 0;
   invoke_vii($52|0,($47|0),($temp|0));
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if (!($54)) {
    $55 = HEAP32[$31>>2]|0;
    $56 = ($55|0)>(-1);
    do {
     if ($56) {
      $57 = HEAP32[$28>>2]|0;
      $58 = HEAP32[$29>>2]|0;
      HEAP32[$1>>2] = $58;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($57|0),($$byval_copy12|0));
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if (!($60)) {
       HEAP32[$28>>2] = 0;
       break;
      }
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      $67 = HEAP32[$27>>2]|0;
      $68 = ($67|0)>(-1);
      if (!($68)) {
       ___resumeException($65|0);
       // unreachable;
      }
      $69 = HEAP32[$temp>>2]|0;
      $70 = HEAP32[$25>>2]|0;
      HEAP32[$0>>2] = $70;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($69|0),($$byval_copy12|0));
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       $73 = ___cxa_find_matching_catch(0|0)|0;
       $74 = tempRet0;
       ___clang_call_terminate($73);
       // unreachable;
      }
      HEAP32[$temp>>2] = 0;
      ___resumeException($65|0);
      // unreachable;
     }
    } while(0);
    $61 = HEAP32[$27>>2]|0;
    $62 = ($61|0)>(-1);
    if (!($62)) {
     $75 = (($this) + 256|0);
     $76 = HEAP32[$75>>2]|0;
     __ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_($channels,$76,$materialIndex,0,0);
     STACKTOP = sp;return;
    }
    $63 = HEAP32[$temp>>2]|0;
    $64 = HEAP32[$25>>2]|0;
    HEAP32[$0>>2] = $64;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($63,$$byval_copy12);
    HEAP32[$temp>>2] = 0;
    $75 = (($this) + 256|0);
    $76 = HEAP32[$75>>2]|0;
    __ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_($channels,$76,$materialIndex,0,0);
    STACKTOP = sp;return;
   }
  }
 }
 $77 = ___cxa_find_matching_catch()|0;
 $78 = tempRet0;
 $79 = HEAP32[$31>>2]|0;
 $80 = ($79|0)>(-1);
 do {
  if ($80) {
   $81 = HEAP32[$28>>2]|0;
   $82 = HEAP32[$29>>2]|0;
   HEAP32[$1>>2] = $82;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($81|0),($$byval_copy12|0));
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if (!($84)) {
    HEAP32[$28>>2] = 0;
    break;
   }
   $91 = ___cxa_find_matching_catch(0|0)|0;
   $92 = tempRet0;
   $93 = HEAP32[$27>>2]|0;
   $94 = ($93|0)>(-1);
   if (!($94)) {
    $eh$lpad$body$indexZ2D = $91;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   $95 = HEAP32[$temp>>2]|0;
   $96 = HEAP32[$25>>2]|0;
   HEAP32[$0>>2] = $96;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($95|0),($$byval_copy12|0));
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   if ($98) {
    $99 = ___cxa_find_matching_catch(0|0)|0;
    $100 = tempRet0;
    ___clang_call_terminate($99);
    // unreachable;
   }
   HEAP32[$temp>>2] = 0;
   $eh$lpad$body$indexZ2D = $91;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 $85 = HEAP32[$27>>2]|0;
 $86 = ($85|0)>(-1);
 if (!($86)) {
  ___resumeException($77|0);
  // unreachable;
 }
 $87 = HEAP32[$temp>>2]|0;
 $88 = HEAP32[$25>>2]|0;
 HEAP32[$0>>2] = $88;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($87|0),($$byval_copy12|0));
 $89 = __THREW__; __THREW__ = 0;
 $90 = $89&1;
 if ($90) {
  $101 = ___cxa_find_matching_catch(0|0)|0;
  $102 = tempRet0;
  $eh$lpad$body$indexZ2D = $101;
  ___clang_call_terminate($eh$lpad$body$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$temp>>2] = 0;
  ___resumeException($77|0);
  // unreachable;
 }
}
function __ZN29BillboardTreeInstanceRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns($this,$renderData,$channels) {
 $this = $this|0;
 $renderData = $renderData|0;
 $channels = $channels|0;
 var $$phi$trans$insert$pre = 0, $$pre = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $batchBegin$02 = 0, $batchBegin$1 = 0, $batchIndices$03 = 0, $batchIndices$1 = 0, $batchVertices$04 = 0, $batchVertices$1 = 0, $it$01 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z12GetGfxDevicev()|0);
 $1 = (__Z24GetBillboardBatchManagerv()|0);
 $2 = (($1) + 60|0);
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 216|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$5 & 4095]($0,$2);
 $6 = HEAP32[$renderData>>2]|0;
 $7 = (($6) + 64|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 168|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($2|0);
 if ($11) {
  $18 = $6;
 } else {
  $12 = HEAP32[$0>>2]|0;
  $13 = (($12) + 216|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vii[$14 & 4095]($0,$10);
  $$pre = HEAP32[$renderData>>2]|0;
  $18 = $$pre;
 }
 $15 = (($renderData) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($18) + (($16*76)|0)|0);
 $19 = ($16|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = ($16*76)|0;
 $21 = (($20) + -76)|0;
 $22 = (($21>>>0) / 76)&-1;
 $23 = (($22) + 1)|0;
 $batchBegin$02 = $18;$batchIndices$03 = 0;$batchVertices$04 = 0;$it$01 = $18;
 while(1) {
  $24 = (($it$01) + 64|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 68|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (FUNCTION_TABLE_ii[$28 & 4095]($25)|0);
  $30 = (($29) + 44|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 20|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + ($batchVertices$04))|0;
  $35 = ($34>>>0)>(65535);
  $$phi$trans$insert$pre = (($31) + 8|0);
  if ($35) {
   label = 7;
  } else {
   $36 = HEAP32[$$phi$trans$insert$pre>>2]|0;
   $37 = (($36) + ($batchIndices$03))|0;
   $38 = ($37>>>0)>(32000);
   if ($38) {
    label = 7;
   } else {
    $40 = $33;$42 = $36;$batchBegin$1 = $batchBegin$02;$batchIndices$1 = $batchIndices$03;$batchVertices$1 = $batchVertices$04;
   }
  }
  if ((label|0) == 7) {
   label = 0;
   __ZL11SubmitBatchRK14ChannelAssignsPK17BatchInstanceDataS4_20040($channels,$batchBegin$02,$it$01);
   $$pre6 = HEAP32[$32>>2]|0;
   $$pre7 = HEAP32[$$phi$trans$insert$pre>>2]|0;
   $40 = $$pre6;$42 = $$pre7;$batchBegin$1 = $it$01;$batchIndices$1 = 0;$batchVertices$1 = 0;
  }
  $39 = (($40) + ($batchVertices$1))|0;
  $41 = (($42) + ($batchIndices$1))|0;
  $43 = (($it$01) + 76|0);
  $44 = ($43|0)==($17|0);
  if ($44) {
   break;
  } else {
   $batchBegin$02 = $batchBegin$1;$batchIndices$03 = $41;$batchVertices$04 = $39;$it$01 = $43;
  }
 }
 $scevgep = (($18) + (($23*76)|0)|0);
 $45 = ($scevgep>>>0)>($batchBegin$1>>>0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 __ZL11SubmitBatchRK14ChannelAssignsPK17BatchInstanceDataS4_20040($channels,$batchBegin$1,$scevgep);
 STACKTOP = sp;return;
}
function __ZL11SubmitBatchRK14ChannelAssignsPK17BatchInstanceDataS4_20040($channels,$begin,$end) {
 $channels = $channels|0;
 $begin = $begin|0;
 $end = $end|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $i$01 = 0, $pos$i$i$i$i = 0;
 var $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($begin) + 64|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viii[$8 & 4095]($1,$5,0);
 $9 = HEAP32[$1>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0$i = 0;
 } else {
  HEAP32[$0>>2] = $9;
  $11 = HEAP32[560624>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   label = 10;
  } else {
   $13 = (($11) + 36|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($11) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14|0)==($16|0);
   do {
    if ($17) {
     $18 = (($11) + 28|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($11) + 32|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + ($21<<3)|0);
     $38 = $22;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$11,$0);
     $23 = HEAP32[$pos$i$i$i$i>>2]|0;
     $24 = ($23|0)==(-1);
     $25 = (($11) + 28|0);
     $26 = HEAP32[$25>>2]|0;
     if ($24) {
      $27 = (($11) + 32|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = (($26) + ($28<<3)|0);
      $38 = $29;
      break;
     } else {
      $30 = (($26) + ($23<<3)|0);
      $38 = $30;
      break;
     }
    }
   } while(0);
   $31 = HEAP32[560624>>2]|0;
   $32 = (($31) + 28|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 32|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) + ($35<<3)|0);
   $37 = ($38|0)==($36|0);
   if ($37) {
    label = 10;
   } else {
    $39 = (($38) + 4|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==(0|0);
    if ($41) {
     label = 10;
    } else {
     $temp$0$i = $40;
    }
   }
  }
  if ((label|0) == 10) {
   $42 = HEAP32[$1>>2]|0;
   $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
   $temp$0$i = $43;
  }
  $$0$i = $temp$0$i;
 }
 $44 = (__Z24GetBillboardBatchManagerv()|0);
 (__ZN21BillboardBatchManager10BeginBatchEPN5Unity8MaterialERK14ChannelAssigns($44,$$0$i,$channels)|0);
 $45 = ($begin>>>0)<($end>>>0);
 if (!($45)) {
  $76 = (__Z24GetBillboardBatchManagerv()|0);
  __ZN21BillboardBatchManager17EndBatchAndSubmitEv($76);
  STACKTOP = sp;return;
 }
 $46 = (($3) + 4|0);
 $47 = (($3) + 8|0);
 $i$01 = $begin;
 while(1) {
  $48 = (($i$01) + 64|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 248|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = HEAP32[$51>>2]|0;
  $53 = (($49) + 252|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 16|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (__Z24GetBillboardBatchManagerv()|0);
  $58 = (($49) + 260|0);
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$2>>2] = $59;
  $60 = (($i$01) + 48|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = (($i$01) + 52|0);
  $63 = Math_fround(HEAPF32[$62>>2]);
  $64 = (($i$01) + 56|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  HEAPF32[$3>>2] = $61;
  HEAPF32[$46>>2] = $63;
  HEAPF32[$47>>2] = $65;
  $66 = ((($56) + (($54*40)|0)|0) + 12|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($56) + (($54*40)|0)|0) + 16|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = ((($56) + (($54*40)|0)|0) + 20|0);
  $71 = Math_fround(HEAPF32[$70>>2]);
  $72 = (($49) + 268|0);
  $73 = Math_fround(HEAPF32[$72>>2]);
  __ZN21BillboardBatchManager16AddBatchInstanceERK4PPtrI14BillboardAssetERK8Vector3fffff($57,$2,$3,$67,$69,$71,$73);
  $74 = (($i$01) + 76|0);
  $75 = ($74>>>0)<($end>>>0);
  if ($75) {
   $i$01 = $74;
  } else {
   break;
  }
 }
 $76 = (__Z24GetBillboardBatchManagerv()|0);
 __ZN21BillboardBatchManager17EndBatchAndSubmitEv($76);
 STACKTOP = sp;return;
}
function __ZN29BillboardTreeInstanceRenderer21UpdateMaterialAndMeshEPN5Unity8MaterialEP4Mesh($this,$material,$mesh) {
 $this = $this|0;
 $material = $material|0;
 $mesh = $mesh|0;
 var $$0$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 200|0);
 $1 = ($material|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 0;
  $2 = (($this) + 256|0);
  HEAP32[$2>>2] = $mesh;
  $$0$i = 1;
 } else {
  $3 = (($material) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP32[$0>>2] = $4;
  $5 = (($this) + 256|0);
  HEAP32[$5>>2] = $mesh;
  $6 = (($material) + 88|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($material) + 88|0);
  $9 = ($7|0)==(0|0);
  if ($9) {
   $$0$i = 1;
  } else {
   $10 = HEAP32[802496>>2]|0;
   $$0$ph7$i$i$i$i = $8;$$01$ph6$i$in$i$i$i = $7;
   L4: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $11 = (($$013$i$in$i$i$i) + 16|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)<($10|0);
     if (!($13)) {
      break;
     }
     $16 = (($$013$i$in$i$i$i) + 4|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L4;
     } else {
      $$013$i$in$i$i$i = $17;
     }
    }
    $14 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $15 = ($14|0)==(0|0);
    if ($15) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $14;
    }
   }
   $19 = ($$0$ph5$i$i$i$i|0)==($8|0);
   if ($19) {
    $$0$i = 1;
   } else {
    $20 = (($$0$ph5$i$i$i$i) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($10|0)<($21|0);
    if ($22) {
     $$0$i = 1;
    } else {
     $23 = (($$0$ph5$i$i$i$i) + 20|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $25 = $24 == Math_fround(0.0);
     $phitmp = $25&1;
     $$0$i = $phitmp;
    }
   }
  }
 }
 $26 = (($this) + 272|0);
 HEAP8[$26>>0] = $$0$i;
 STACKTOP = sp;return;
}
function __ZN29BillboardTreeInstanceRenderer10UpdateWindEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $result = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $result = sp;
 $0 = (($this) + 248|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 272|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = (($this) + 264|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6;
 } else {
  $7 = -1;
 }
 __ZN12TreeRenderer21ComputeWindPropertiesEib($result,$1,$7,1);
 $8 = HEAP32[$result>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (__Z24GetBillboardBatchManagerv()|0);
  $11 = (($10) + 60|0);
  $13 = $11;
 } else {
  $13 = $8;
 }
 $12 = (($this) + 168|0);
 HEAP32[$12>>2] = $13;
 $14 = (($result) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($this) + 268|0);
 HEAPF32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function __ZNK24TreeIntermediateRenderer14AllowsBatchingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 256|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK24TreeIntermediateRenderer8GetLayerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 248|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK24TreeIntermediateRenderer12GetLayerMaskEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 248|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = 1 << $3;
 STACKTOP = sp;return ($4|0);
}
function __ZN24TreeIntermediateRenderer7GetMeshEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 256|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN24TreeIntermediateRenderer14OnAssetDeletedEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN23LODTreeInstanceRendererD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN23LODTreeInstanceRendererD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK23LODTreeInstanceRenderer14AllowsBatchingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $6 = 0;
  STACKTOP = sp;return ($6|0);
 }
 $3 = (($this) + 256|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(0|0);
 $6 = $5;
 STACKTOP = sp;return ($6|0);
}
function __ZNK23LODTreeInstanceRenderer16GetMaterialCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK23LODTreeInstanceRenderer11GetMaterialEi($agg$result,$this,$i) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($i<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$agg$result>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNK23LODTreeInstanceRenderer14GetSubsetIndexEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($i|0);
}
function __ZN26LegacyTreeInstanceRendererD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN26LegacyTreeInstanceRendererD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK26LegacyTreeInstanceRenderer16GetMaterialCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK26LegacyTreeInstanceRenderer11GetMaterialEi($agg$result,$this,$i) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($i<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[$agg$result>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $6 = (($4) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$agg$result>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNK26LegacyTreeInstanceRenderer14GetSubsetIndexEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($i|0);
}
function __ZN29BillboardTreeInstanceRendererD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN29BillboardTreeInstanceRendererD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20IntermediateRendererD2Ev($this);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a20041() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,802504);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[802496>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN12TreeRendererC2ER12TreeDatabaseRK8Vector3f($this,$database,$position) {
 $this = $this|0;
 $database = $database|0;
 $position = $position|0;
 var $$0 = 0, $$01 = 0, $$6 = 0, $$69 = 0, $$byval_copy24 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0;
 var $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__f$0$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $eh$lpad$body$indexZ2D = 0, $i$01$i = 0, $or$cond$i = 0, $or$cond$i$i = 0, $s$0 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy24 = sp + 112|0;
 $0 = sp + 108|0;
 $1 = sp + 104|0;
 $2 = sp + 100|0;
 $3 = sp + 96|0;
 $4 = sp + 92|0;
 $5 = sp + 88|0;
 $6 = sp + 84|0;
 $7 = sp + 80|0;
 $8 = sp + 76|0;
 $9 = sp + 72|0;
 $10 = sp + 68|0;
 $11 = sp + 16|0;
 $12 = sp;
 $13 = sp + 4|0;
 $14 = sp + 8|0;
 $15 = sp + 12|0;
 $16 = sp + 20|0;
 $17 = sp + 32|0;
 $18 = sp + 44|0;
 $19 = sp + 56|0;
 $20 = sp + 60|0;
 $21 = sp + 64|0;
 HEAP32[$this>>2] = 0;
 $22 = (($this) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = HEAP32[628440>>2]|0;
 $24 = (($this) + 8|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 12|0);
 HEAP32[$25>>2] = $23;
 $26 = (($this) + 16|0);
 HEAP32[$26>>2] = 0;
 $27 = (($this) + 20|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 24|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 28|0);
 HEAP32[$29>>2] = $23;
 $30 = (($this) + 32|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 36|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 40|0);
 $33 = HEAP32[641904>>2]|0;
 HEAP32[$32>>2] = $33;
 $34 = (($this) + 44|0);
 $35 = (($this) + 56|0);
 $36 = (($this) + 68|0);
 $37 = (($this) + 84|0);
 ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;HEAP32[$34+16>>2]=0|0;HEAP32[$34+20>>2]=0|0;HEAP32[$34+24>>2]=0|0;
 HEAP32[$37>>2] = -1;
 $38 = (($this) + 88|0);
 HEAP32[$38>>2] = 0;
 $39 = HEAP32[628440>>2]|0;
 $40 = (($this) + 92|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 96|0);
 HEAP32[$41>>2] = $39;
 $42 = (($this) + 100|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 104|0);
 HEAP32[$43>>2] = 0;
 $44 = HEAP32[628440>>2]|0;
 $45 = (($this) + 108|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 112|0);
 HEAP32[$46>>2] = $44;
 $47 = (($this) + 116|0);
 HEAP32[$47>>2] = 0;
 $48 = (($this) + 120|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 124|0);
 HEAP32[$49>>2] = 0;
 $50 = (($this) + 128|0);
 $51 = HEAP32[628440>>2]|0;
 HEAP32[$50>>2] = $50;
 $52 = (($this) + 132|0);
 HEAP32[$52>>2] = $50;
 $53 = (($this) + 136|0);
 HEAP32[$53>>2] = 0;
 $54 = (($this) + 140|0);
 HEAP32[$54>>2] = 8192;
 $55 = (($this) + 144|0);
 HEAP32[$55>>2] = $51;
 $56 = (($this) + 148|0);
 HEAP8[$56>>0] = 0;
 $57 = HEAP32[628440>>2]|0;
 $58 = (($this) + 152|0);
 HEAP32[$58>>2] = 0;
 $59 = (($this) + 156|0);
 HEAP32[$59>>2] = $57;
 $60 = (($this) + 160|0);
 HEAP32[$60>>2] = 0;
 $61 = (($this) + 164|0);
 HEAP32[$61>>2] = 0;
 $62 = HEAP32[628440>>2]|0;
 $63 = (($this) + 168|0);
 HEAP32[$63>>2] = 0;
 $64 = (($this) + 172|0);
 HEAP32[$64>>2] = $62;
 $65 = (($this) + 176|0);
 HEAP32[$65>>2] = 0;
 $66 = (($this) + 180|0);
 HEAP32[$66>>2] = 0;
 $67 = HEAP32[628440>>2]|0;
 $68 = (($this) + 184|0);
 HEAP32[$68>>2] = 0;
 $69 = (($this) + 188|0);
 HEAP32[$69>>2] = $67;
 $70 = (($this) + 192|0);
 HEAP32[$70>>2] = 0;
 $71 = (($this) + 196|0);
 HEAP32[$71>>2] = 0;
 $72 = (($this) + 200|0);
 HEAP32[$72>>2] = -1;
 $73 = (($this) + 204|0);
 $74 = HEAP32[628440>>2]|0;
 HEAP32[$15>>2] = $74;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$15+0>>2]|0;
 invoke_vii(3419,($73|0),($$byval_copy24|0));
 $75 = __THREW__; __THREW__ = 0;
 $76 = $75&1;
 do {
  if ($76) {
   $108 = ___cxa_find_matching_catch()|0;
   $109 = tempRet0;
   $$6 = $109;$$69 = $108;
   label = 81;
  } else {
   $77 = (($this) + 232|0);
   $78 = (($this) + 236|0);
   $79 = (($this) + 244|0);
   $80 = (($this) + 248|0);
   ;HEAP32[$77+0>>2]=0|0;HEAP32[$77+4>>2]=0|0;HEAP32[$77+8>>2]=0|0;HEAP32[$77+12>>2]=0|0;HEAP32[$77+16>>2]=0|0;HEAP32[$77+20>>2]=0|0;
   $81 = HEAP32[628440>>2]|0;
   $82 = (($this) + 256|0);
   HEAP32[$82>>2] = 0;
   $83 = (($this) + 260|0);
   HEAP32[$83>>2] = $81;
   $84 = (($this) + 264|0);
   HEAP32[$84>>2] = 0;
   $85 = (($this) + 268|0);
   HEAP32[$85>>2] = 0;
   $86 = HEAP32[628440>>2]|0;
   $87 = (($this) + 272|0);
   HEAP32[$87>>2] = 0;
   $88 = (($this) + 276|0);
   HEAP32[$88>>2] = $86;
   $89 = (($this) + 280|0);
   HEAP32[$89>>2] = 0;
   $90 = (($this) + 284|0);
   HEAP32[$90>>2] = 0;
   $91 = (($this) + 288|0);
   HEAP32[$91>>2] = $91;
   $92 = (($this) + 292|0);
   HEAP32[$92>>2] = $91;
   $93 = (($this) + 296|0);
   HEAP32[$93>>2] = 0;
   $94 = (($database) + 32|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (($database) + 28|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($95|0)==($97|0);
   if ($98) {
    STACKTOP = sp;return;
   }
   $99 = $95;
   $100 = $97;
   $101 = (($99) - ($100))|0;
   $102 = $101 >> 7;
   $i$01$i = 0;
   while(1) {
    $105 = ((($97) + ($i$01$i<<7)|0) + 4|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ($106|0)==(0);
    $104 = (($i$01$i) + 1)|0;
    if (!($107)) {
     break;
    }
    $103 = ($104>>>0)<($102>>>0);
    if ($103) {
     $i$01$i = $104;
    } else {
     label = 44;
     break;
    }
   }
   if ((label|0) == 44) {
    STACKTOP = sp;return;
   }
   HEAP32[$this>>2] = $database;
   $112 = HEAP32[$database>>2]|0;
   $113 = (($112) + 232|0);
   __THREW__ = 0;
   invoke_vii(3420,($16|0),($113|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   L12: do {
    if ($115) {
     label = 7;
    } else {
     ;HEAP32[$34+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$16+8>>2]|0;
     ;HEAP32[$35+0>>2]=HEAP32[$position+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$position+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$position+8>>2]|0;
     __THREW__ = 0;
     $116 = (invoke_ii(2988,108)|0);
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      label = 7;
     } else {
      __THREW__ = 0;
      invoke_vii(3421,($116|0),($database|0));
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       $159 = ___cxa_find_matching_catch()|0;
       $160 = tempRet0;
       __ZdlPv($116);
       $$0 = $160;$$01 = $159;
       break;
      }
      $121 = HEAP32[$49>>2]|0;
      $122 = ($121|0)==($116|0);
      $123 = ($121|0)==(0|0);
      $or$cond$i = $122 | $123;
      do {
       if (!($or$cond$i)) {
        __THREW__ = 0;
        invoke_vi(3714,($121|0));
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         $126 = ___cxa_find_matching_catch()|0;
         $127 = tempRet0;
         __ZdlPv($121);
         ___cxa_call_unexpected(($126|0));
         // unreachable;
        } else {
         __ZdlPv($121);
         break;
        }
       }
      } while(0);
      HEAP32[$49>>2] = $116;
      __THREW__ = 0;
      $128 = (invoke_i(80)|0);
      $129 = __THREW__; __THREW__ = 0;
      $130 = $129&1;
      if ($130) {
       label = 7;
      } else {
       __THREW__ = 0;
       $131 = (invoke_ii(2988,48)|0);
       $132 = __THREW__; __THREW__ = 0;
       $133 = $132&1;
       if ($133) {
        label = 7;
       } else {
        $134 = (($17) + 8|0);
        HEAP32[$134>>2] = $131;
        HEAP32[$17>>2] = 49;
        $135 = (($17) + 4|0);
        HEAP32[$135>>2] = 34;
        dest=$131+0|0; src=803104+0|0; stop=dest+34|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $136 = (($131) + 34|0);
        HEAP8[$136>>0] = 0;
        __THREW__ = 0;
        $137 = (invoke_iii(2366,($128|0),($17|0))|0);
        $138 = __THREW__; __THREW__ = 0;
        $139 = $138&1;
        if ($139) {
         $161 = ___cxa_find_matching_catch()|0;
         $162 = tempRet0;
         $163 = HEAP8[$17>>0]|0;
         $164 = $163 & 1;
         $165 = ($164<<24>>24)==(0);
         if ($165) {
          $$0 = $162;$$01 = $161;
          break;
         }
         $166 = HEAP32[$134>>2]|0;
         __ZdlPv($166);
         $$0 = $162;$$01 = $161;
         break;
        }
        $140 = HEAP8[$17>>0]|0;
        $141 = $140 & 1;
        $142 = ($141<<24>>24)==(0);
        if (!($142)) {
         $143 = HEAP32[$134>>2]|0;
         __ZdlPv($143);
        }
        $144 = ($137|0)==(0|0);
        do {
         if ($144) {
          __THREW__ = 0;
          invoke_viiiiiiii(21,(803144|0),0,(803264|0),345,1,0,0,(0|0));
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          if ($146) {
           label = 7;
           break L12;
          }
          __THREW__ = 0;
          $147 = (invoke_i(80)|0);
          $148 = __THREW__; __THREW__ = 0;
          $149 = $148&1;
          if ($149) {
           label = 7;
           break L12;
          }
          HEAP8[$18>>0] = 14;
          $150 = (($18) + 1|0);
          ;HEAP8[$150+0>>0]=HEAP8[803272+0>>0]|0;HEAP8[$150+1>>0]=HEAP8[803272+1>>0]|0;HEAP8[$150+2>>0]=HEAP8[803272+2>>0]|0;HEAP8[$150+3>>0]=HEAP8[803272+3>>0]|0;HEAP8[$150+4>>0]=HEAP8[803272+4>>0]|0;HEAP8[$150+5>>0]=HEAP8[803272+5>>0]|0;HEAP8[$150+6>>0]=HEAP8[803272+6>>0]|0;
          $151 = (($18) + 8|0);
          HEAP8[$151>>0] = 0;
          __THREW__ = 0;
          $152 = (invoke_iii(2366,($147|0),($18|0))|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           $167 = ___cxa_find_matching_catch()|0;
           $168 = tempRet0;
           $169 = HEAP8[$18>>0]|0;
           $170 = $169 & 1;
           $171 = ($170<<24>>24)==(0);
           if ($171) {
            $$0 = $168;$$01 = $167;
            break L12;
           }
           $172 = HEAP32[$151>>2]|0;
           __ZdlPv($172);
           $$0 = $168;$$01 = $167;
           break L12;
          } else {
           $155 = HEAP8[$18>>0]|0;
           $156 = $155 & 1;
           $157 = ($156<<24>>24)==(0);
           if ($157) {
            $s$0 = $152;
            break;
           }
           $158 = HEAP32[$151>>2]|0;
           __ZdlPv($158);
           $s$0 = $152;
           break;
          }
         } else {
          $s$0 = $137;
         }
        } while(0);
        __THREW__ = 0;
        $173 = (invoke_iiii(1539,($s$0|0),61,0)|0);
        $174 = __THREW__; __THREW__ = 0;
        $175 = $174&1;
        if ($175) {
         label = 7;
        } else {
         HEAP32[$22>>2] = $173;
         HEAP32[$5>>2] = -1;
         __THREW__ = 0;
         invoke_vii(2618,($5|0),(803280|0));
         $176 = __THREW__; __THREW__ = 0;
         $177 = $176&1;
         if ($177) {
          label = 7;
         } else {
          $178 = HEAP32[$5>>2]|0;
          HEAP32[$19>>2] = $178;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$19+0>>2]|0;
          $179 = (invoke_iii(2601,($173|0),($$byval_copy24|0))|0);
          $180 = __THREW__; __THREW__ = 0;
          $181 = $180&1;
          if ($181) {
           label = 7;
          } else {
           if ($179) {
            $182 = HEAP32[$22>>2]|0;
            HEAP32[$4>>2] = -1;
            __THREW__ = 0;
            invoke_vii(2618,($4|0),(803280|0));
            $183 = __THREW__; __THREW__ = 0;
            $184 = $183&1;
            if ($184) {
             label = 7;
             break;
            }
            $185 = HEAP32[$4>>2]|0;
            HEAP32[$20>>2] = $185;
            $186 = HEAP32[$49>>2]|0;
            $187 = (($186) + 20|0);
            $188 = HEAP32[$187>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$20+0>>2]|0;
            invoke_viii(1682,($182|0),($$byval_copy24|0),($188|0));
            $189 = __THREW__; __THREW__ = 0;
            $190 = $189&1;
            if ($190) {
             label = 7;
             break;
            }
           }
           $191 = HEAP32[$96>>2]|0;
           $192 = HEAP32[$94>>2]|0;
           $193 = ($191|0)==($192|0);
           if ($193) {
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           invoke_viiiii(113,($21|0),($database|0),($35|0),($34|0),500);
           $194 = __THREW__; __THREW__ = 0;
           $195 = $194&1;
           if ($195) {
            label = 7;
           } else {
            $196 = HEAP32[$21>>2]|0;
            HEAP32[$21>>2] = 0;
            $197 = HEAP32[$36>>2]|0;
            $198 = ($197|0)==($196|0);
            $199 = ($197|0)==(0|0);
            $or$cond$i$i = $198 | $199;
            do {
             if (!($or$cond$i$i)) {
              __THREW__ = 0;
              invoke_vi(3715,($197|0));
              $200 = __THREW__; __THREW__ = 0;
              $201 = $200&1;
              if ($201) {
               $202 = ___cxa_find_matching_catch()|0;
               $203 = tempRet0;
               __ZdlPv($197);
               ___cxa_call_unexpected(($202|0));
               // unreachable;
              } else {
               __ZdlPv($197);
               break;
              }
             }
            } while(0);
            HEAP32[$36>>2] = $196;
            __THREW__ = 0;
            invoke_vi(3716,($this|0));
            $204 = __THREW__; __THREW__ = 0;
            $205 = $204&1;
            if ($205) {
             $206 = ___cxa_find_matching_catch()|0;
             $207 = tempRet0;
             $$0 = $207;$$01 = $206;
             break;
            } else {
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 7) {
    $110 = ___cxa_find_matching_catch()|0;
    $111 = tempRet0;
    $$0 = $111;$$01 = $110;
   }
   $208 = HEAP32[$93>>2]|0;
   $209 = ($208|0)==(0);
   L66: do {
    if (!($209)) {
     $210 = HEAP32[$92>>2]|0;
     $211 = HEAP32[$91>>2]|0;
     $212 = (($211) + 4|0);
     $213 = HEAP32[$212>>2]|0;
     $214 = HEAP32[$210>>2]|0;
     $215 = (($214) + 4|0);
     HEAP32[$215>>2] = $213;
     $216 = HEAP32[$210>>2]|0;
     $217 = HEAP32[$212>>2]|0;
     HEAP32[$217>>2] = $216;
     HEAP32[$93>>2] = 0;
     $__f$0$i$i$i$i = $210;
     while(1) {
      $218 = ($__f$0$i$i$i$i|0)==($91|0);
      if ($218) {
       break L66;
      }
      $219 = (($__f$0$i$i$i$i) + 4|0);
      $220 = HEAP32[$219>>2]|0;
      $221 = (($__f$0$i$i$i$i) + 32|0);
      $222 = HEAP32[$221>>2]|0;
      $223 = ($222|0)>(-1);
      if ($223) {
       $224 = (($__f$0$i$i$i$i) + 20|0);
       $225 = HEAP32[$224>>2]|0;
       $226 = (($__f$0$i$i$i$i) + 24|0);
       $227 = HEAP32[$226>>2]|0;
       HEAP32[$0>>2] = $227;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($225|0),($$byval_copy24|0));
       $228 = __THREW__; __THREW__ = 0;
       $229 = $228&1;
       if ($229) {
        label = 54;
        break;
       }
       HEAP32[$224>>2] = 0;
      }
      HEAP32[$3>>2] = 55;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($__f$0$i$i$i$i|0),($$byval_copy24|0));
      $230 = __THREW__; __THREW__ = 0;
      $231 = $230&1;
      if ($231) {
       label = 53;
       break;
      } else {
       $__f$0$i$i$i$i = $220;
      }
     }
     if ((label|0) == 53) {
      $232 = ___cxa_find_matching_catch()|0;
      $233 = tempRet0;
      ___cxa_call_unexpected(($232|0));
      // unreachable;
     }
     else if ((label|0) == 54) {
      $234 = ___cxa_find_matching_catch()|0;
      $235 = tempRet0;
      ___cxa_call_unexpected(($234|0));
      // unreachable;
     }
    }
   } while(0);
   $236 = HEAP32[$90>>2]|0;
   $237 = ($236|0)>(-1);
   if ($237) {
    $238 = HEAP32[$87>>2]|0;
    $239 = HEAP32[$88>>2]|0;
    HEAP32[$2>>2] = $239;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($238|0),($$byval_copy24|0));
    $240 = __THREW__; __THREW__ = 0;
    $241 = $240&1;
    if ($241) {
     break;
    }
    HEAP32[$87>>2] = 0;
   }
   $242 = HEAP32[$85>>2]|0;
   $243 = ($242|0)>(-1);
   if ($243) {
    $244 = HEAP32[$82>>2]|0;
    $245 = HEAP32[$83>>2]|0;
    HEAP32[$1>>2] = $245;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($244|0),($$byval_copy24|0));
    $246 = __THREW__; __THREW__ = 0;
    $247 = $246&1;
    if ($247) {
     break;
    }
    HEAP32[$82>>2] = 0;
   }
   $248 = HEAP32[$79>>2]|0;
   $249 = ($248|0)==(0|0);
   if (!($249)) {
    while(1) {
     $250 = HEAP32[$80>>2]|0;
     $251 = ($250|0)==($248|0);
     if ($251) {
      break;
     }
     $252 = (($250) + -148|0);
     HEAP32[$80>>2] = $252;
     __THREW__ = 0;
     invoke_vi(3717,($252|0));
     $253 = __THREW__; __THREW__ = 0;
     $254 = $253&1;
     if ($254) {
      label = 64;
      break;
     }
    }
    if ((label|0) == 64) {
     $255 = ___cxa_find_matching_catch()|0;
     $256 = tempRet0;
     ___cxa_call_unexpected(($255|0));
     // unreachable;
    }
    $257 = HEAP32[$79>>2]|0;
    HEAP32[$0>>2] = 55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($257|0),($$byval_copy24|0));
    $258 = __THREW__; __THREW__ = 0;
    $259 = $258&1;
    if ($259) {
     $260 = ___cxa_find_matching_catch()|0;
     $261 = tempRet0;
     ___cxa_call_unexpected(($260|0));
     // unreachable;
    }
   }
   $262 = HEAP32[$77>>2]|0;
   $263 = ($262|0)==(0|0);
   if (!($263)) {
    $264 = HEAP32[$78>>2]|0;
    $265 = ($264|0)==($262|0);
    do {
     if ($265) {
      $283 = $262;
     } else {
      $267 = $264;
      while(1) {
       $266 = (($267) + -28|0);
       HEAP32[$78>>2] = $266;
       $268 = (($267) + -24|0);
       $269 = HEAP32[$268>>2]|0;
       $270 = ($269|0)==(0|0);
       if ($270) {
        $272 = $266;
       } else {
        $273 = (($267) + -20|0);
        $274 = HEAP32[$273>>2]|0;
        $275 = ($274|0)==($269|0);
        if (!($275)) {
         $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $269;
         $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($274) + -72|0);
         $276 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
         $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($276)|0);
         $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
         $277 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i>>>0) / 72)&-1;
         $278 = $277 ^ -1;
         $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($274) + (($278*72)|0)|0);
         HEAP32[$273>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
        }
        HEAP32[$6>>2] = 55;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$6+0>>2]|0;
        invoke_vii(2591,($269|0),($$byval_copy24|0));
        $279 = __THREW__; __THREW__ = 0;
        $280 = $279&1;
        if ($280) {
         label = 76;
         break;
        }
        $$pre$i$i$i$i$i = HEAP32[$78>>2]|0;
        $272 = $$pre$i$i$i$i$i;
       }
       $271 = ($272|0)==($262|0);
       if ($271) {
        label = 77;
        break;
       } else {
        $267 = $272;
       }
      }
      if ((label|0) == 76) {
       $281 = ___cxa_find_matching_catch()|0;
       $282 = tempRet0;
       ___cxa_call_unexpected(($281|0));
       // unreachable;
      }
      else if ((label|0) == 77) {
       $$pre$i$i$i = HEAP32[$77>>2]|0;
       $283 = $$pre$i$i$i;
       break;
      }
     }
    } while(0);
    HEAP32[$7>>2] = 55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$7+0>>2]|0;
    invoke_vii(2591,($283|0),($$byval_copy24|0));
    $284 = __THREW__; __THREW__ = 0;
    $285 = $284&1;
    if ($285) {
     $286 = ___cxa_find_matching_catch()|0;
     $287 = tempRet0;
     ___cxa_call_unexpected(($286|0));
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_vi(3718,($73|0));
   $288 = __THREW__; __THREW__ = 0;
   $289 = $288&1;
   if (!($289)) {
    $$6 = $$0;$$69 = $$01;
    label = 81;
   }
  }
 } while(0);
 do {
  if ((label|0) == 81) {
   $290 = HEAP32[$71>>2]|0;
   $291 = ($290|0)>(-1);
   if ($291) {
    $292 = HEAP32[$68>>2]|0;
    $293 = HEAP32[$69>>2]|0;
    HEAP32[$8>>2] = $293;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$8+0>>2]|0;
    invoke_vii(2591,($292|0),($$byval_copy24|0));
    $294 = __THREW__; __THREW__ = 0;
    $295 = $294&1;
    if ($295) {
     break;
    }
    HEAP32[$68>>2] = 0;
   }
   $296 = HEAP32[$66>>2]|0;
   $297 = ($296|0)>(-1);
   if ($297) {
    $298 = HEAP32[$63>>2]|0;
    $299 = HEAP32[$64>>2]|0;
    HEAP32[$9>>2] = $299;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$9+0>>2]|0;
    invoke_vii(2591,($298|0),($$byval_copy24|0));
    $300 = __THREW__; __THREW__ = 0;
    $301 = $300&1;
    if ($301) {
     break;
    }
    HEAP32[$63>>2] = 0;
   }
   $302 = HEAP32[$61>>2]|0;
   $303 = ($302|0)>(-1);
   if ($303) {
    $304 = HEAP32[$58>>2]|0;
    $305 = HEAP32[$59>>2]|0;
    HEAP32[$10>>2] = $305;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$10+0>>2]|0;
    invoke_vii(2591,($304|0),($$byval_copy24|0));
    $306 = __THREW__; __THREW__ = 0;
    $307 = $306&1;
    if ($307) {
     break;
    }
    HEAP32[$58>>2] = 0;
   }
   __THREW__ = 0;
   invoke_vi(3719,($50|0));
   $308 = __THREW__; __THREW__ = 0;
   $309 = $308&1;
   if (!($309)) {
    $310 = HEAP32[$49>>2]|0;
    $311 = ($310|0)==(0|0);
    do {
     if (!($311)) {
      __THREW__ = 0;
      invoke_vi(3714,($310|0));
      $312 = __THREW__; __THREW__ = 0;
      $313 = $312&1;
      if ($313) {
       $314 = ___cxa_find_matching_catch()|0;
       $315 = tempRet0;
       __ZdlPv($310);
       ___cxa_call_unexpected(($314|0));
       // unreachable;
      } else {
       __ZdlPv($310);
       break;
      }
     }
    } while(0);
    $316 = HEAP32[$48>>2]|0;
    $317 = ($316|0)>(-1);
    if ($317) {
     $318 = HEAP32[$45>>2]|0;
     $319 = HEAP32[$46>>2]|0;
     HEAP32[$11>>2] = $319;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$11+0>>2]|0;
     invoke_vii(2591,($318|0),($$byval_copy24|0));
     $320 = __THREW__; __THREW__ = 0;
     $321 = $320&1;
     if ($321) {
      break;
     }
     HEAP32[$45>>2] = 0;
    }
    $322 = HEAP32[$43>>2]|0;
    $323 = ($322|0)>(-1);
    if ($323) {
     $324 = HEAP32[$40>>2]|0;
     $325 = HEAP32[$41>>2]|0;
     HEAP32[$12>>2] = $325;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$12+0>>2]|0;
     invoke_vii(2591,($324|0),($$byval_copy24|0));
     $326 = __THREW__; __THREW__ = 0;
     $327 = $326&1;
     if ($327) {
      break;
     }
     HEAP32[$40>>2] = 0;
    }
    $328 = HEAP32[$36>>2]|0;
    $329 = ($328|0)==(0|0);
    do {
     if (!($329)) {
      __THREW__ = 0;
      invoke_vi(3715,($328|0));
      $330 = __THREW__; __THREW__ = 0;
      $331 = $330&1;
      if ($331) {
       $332 = ___cxa_find_matching_catch()|0;
       $333 = tempRet0;
       __ZdlPv($328);
       ___cxa_call_unexpected(($332|0));
       // unreachable;
      } else {
       __ZdlPv($328);
       break;
      }
     }
    } while(0);
    $334 = HEAP32[$31>>2]|0;
    $335 = ($334|0)>(-1);
    do {
     if ($335) {
      $336 = HEAP32[$28>>2]|0;
      $337 = HEAP32[$29>>2]|0;
      HEAP32[$14>>2] = $337;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$14+0>>2]|0;
      invoke_vii(2591,($336|0),($$byval_copy24|0));
      $338 = __THREW__; __THREW__ = 0;
      $339 = $338&1;
      if (!($339)) {
       HEAP32[$28>>2] = 0;
       break;
      }
      $346 = ___cxa_find_matching_catch(0|0)|0;
      $347 = tempRet0;
      $348 = HEAP32[$27>>2]|0;
      $349 = ($348|0)>(-1);
      if (!($349)) {
       $eh$lpad$body$indexZ2D = $346;
       ___clang_call_terminate($eh$lpad$body$indexZ2D);
       // unreachable;
      }
      $350 = HEAP32[$24>>2]|0;
      $351 = HEAP32[$25>>2]|0;
      HEAP32[$1>>2] = $351;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($350|0),($$byval_copy24|0));
      $352 = __THREW__; __THREW__ = 0;
      $353 = $352&1;
      if ($353) {
       $354 = ___cxa_find_matching_catch(0|0)|0;
       $355 = tempRet0;
       ___clang_call_terminate($354);
       // unreachable;
      }
      HEAP32[$24>>2] = 0;
      $eh$lpad$body$indexZ2D = $346;
      ___clang_call_terminate($eh$lpad$body$indexZ2D);
      // unreachable;
     }
    } while(0);
    $340 = HEAP32[$27>>2]|0;
    $341 = ($340|0)>(-1);
    if (!($341)) {
     ___resumeException($$69|0);
     // unreachable;
    }
    $342 = HEAP32[$24>>2]|0;
    $343 = HEAP32[$25>>2]|0;
    HEAP32[$13>>2] = $343;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$13+0>>2]|0;
    invoke_vii(2591,($342|0),($$byval_copy24|0));
    $344 = __THREW__; __THREW__ = 0;
    $345 = $344&1;
    if (!($345)) {
     HEAP32[$24>>2] = 0;
     ___resumeException($$69|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $356 = ___cxa_find_matching_catch(0|0)|0;
 $357 = tempRet0;
 $eh$lpad$body$indexZ2D = $356;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN21TreeBinaryTreeBuilder5BuildER12TreeDatabaseRK8Vector3fS4_i($agg$result,$database,$position,$scale,$minimumInstances) {
 $agg$result = $agg$result|0;
 $database = $database|0;
 $position = $position|0;
 $scale = $scale|0;
 $minimumInstances = $minimumInstances|0;
 var $$0 = 0, $$01 = 0, $$byval_copy9 = 0, $$idx = 0, $$pre = 0, $$pre$i$i = 0, $$pre16 = 0, $$pre16$pre = 0, $$pre17 = 0, $$pre17$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $legacyTreeInstances = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $storemerge15 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy9 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $legacyTreeInstances = sp + 16|0;
 HEAP32[$legacyTreeInstances>>2] = 0;
 $4 = (($legacyTreeInstances) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($legacyTreeInstances) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($legacyTreeInstances) + 4|0);
 HEAP32[$6>>2] = 61;
 $7 = (($database) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($database) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 L1: do {
  if ($11) {
   label = 18;
  } else {
   $12 = (($database) + 28|0);
   $105 = $8;$14 = $10;$32 = 0;$storemerge15 = 0;
   L3: while(1) {
    $13 = ((($14) + (($storemerge15*40)|0)|0) + 32|0);
    $15 = HEAP32[$13>>2]|0;
    $16 = HEAP32[$12>>2]|0;
    $17 = ((($16) + ($15<<7)|0) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(1);
    if ($19) {
     $20 = HEAP32[$4>>2]|0;
     $21 = (($20) + 1)|0;
     HEAP32[$4>>2] = $21;
     $22 = HEAP32[$5>>2]|0;
     $23 = $22 & 2147483647;
     $24 = ($21>>>0)>($23>>>0);
     if ($24) {
      $25 = $22 << 1;
      $26 = ($25|0)==(0);
      $27 = $26 ? 1 : $25;
      $28 = ($23>>>0)<($27>>>0);
      do {
       if ($28) {
        $29 = ($22|0)>(-1);
        if ($29) {
         HEAP32[$5>>2] = $27;
         $30 = $27 << 2;
         $31 = HEAP32[$6>>2]|0;
         HEAP32[$1>>2] = $31;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
         $33 = (invoke_iiiiiiii(108,($32|0),($30|0),4,($$byval_copy9|0),0,(803264|0),370)|0);
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          label = 13;
          break L3;
         }
         HEAP32[$legacyTreeInstances>>2] = $33;
         $106 = $33;
         break;
        } else {
         $36 = $27 << 2;
         $37 = HEAP32[$6>>2]|0;
         HEAP32[$2>>2] = $37;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
         $38 = (invoke_iiiiiii(102,($36|0),4,($$byval_copy9|0),0,(803264|0),352)|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          label = 13;
          break L3;
         }
         $41 = HEAP32[$legacyTreeInstances>>2]|0;
         $42 = HEAP32[$4>>2]|0;
         $43 = $42 << 2;
         _memcpy(($38|0),($41|0),($43|0))|0;
         HEAP32[$5>>2] = $27;
         HEAP32[$legacyTreeInstances>>2] = $38;
         $106 = $38;
         break;
        }
       } else {
        $106 = $32;
       }
      } while(0);
      $$pre$i$i = HEAP32[$4>>2]|0;
      $$pre16$pre = HEAP32[$7>>2]|0;
      $$pre17$pre = HEAP32[$9>>2]|0;
      $$pre16 = $$pre16$pre;$$pre17 = $$pre17$pre;$45 = $$pre$i$i;$47 = $106;
     } else {
      $$pre16 = $105;$$pre17 = $14;$45 = $21;$47 = $32;
     }
     $44 = (($45) + -1)|0;
     $46 = (($47) + ($44<<2)|0);
     HEAP32[$46>>2] = $storemerge15;
     $54 = $$pre16;$56 = $$pre17;$83 = $47;
    } else {
     $54 = $105;$56 = $14;$83 = $32;
    }
    $52 = (($storemerge15) + 1)|0;
    $53 = $54;
    $55 = $56;
    $57 = (($53) - ($55))|0;
    $58 = (($57|0) / 40)&-1;
    $59 = ($52>>>0)<($58>>>0);
    if ($59) {
     $105 = $54;$14 = $56;$32 = $83;$storemerge15 = $52;
    } else {
     label = 17;
     break;
    }
   }
   L19: do {
    if ((label|0) == 13) {
     $48 = ___cxa_find_matching_catch()|0;
     $49 = tempRet0;
     $lpad$phi$index = $48;$lpad$phi$index2 = $49;
     label = 15;
    }
    else if ((label|0) == 17) {
     $$pre = HEAP32[$4>>2]|0;
     $60 = ($$pre|0)==(0);
     if ($60) {
      label = 18;
      break L1;
     }
     __THREW__ = 0;
     $61 = (invoke_ii(2988,100)|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      $50 = ___cxa_find_matching_catch()|0;
      $51 = tempRet0;
      $lpad$phi$index = $50;$lpad$phi$index2 = $51;
      label = 15;
      break;
     }
     HEAP32[$61>>2] = $database;
     $64 = HEAP32[628440>>2]|0;
     $65 = (($61) + 4|0);
     HEAP32[$65>>2] = 0;
     $66 = (($61) + 8|0);
     HEAP32[$66>>2] = $64;
     $67 = (($61) + 12|0);
     dest=$67+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     $68 = (($61) + 76|0);
     HEAP32[$68>>2] = 0;
     $69 = (($61) + 80|0);
     HEAP32[$69>>2] = $64;
     $70 = (($61) + 84|0);
     ;HEAP32[$70+0>>2]=0|0;HEAP32[$70+4>>2]=0|0;HEAP32[$70+8>>2]=0|0;HEAP32[$70+12>>2]=0|0;
     $71 = ($legacyTreeInstances|0)==($65|0);
     L26: do {
      if ($71) {
       label = 26;
      } else {
       $$idx = $$pre << 2;
       $72 = $$idx >> 2;
       HEAP32[$67>>2] = $72;
       $73 = ($72|0)==(0);
       do {
        if ($73) {
         $82 = 0;
        } else {
         $74 = (($61) + 16|0);
         HEAP32[$74>>2] = $72;
         HEAP32[$0>>2] = $64;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
         $75 = (invoke_iiiiiiii(108,(0|0),($$idx|0),4,($$byval_copy9|0),0,(803264|0),370)|0);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          $78 = ___cxa_find_matching_catch()|0;
          $79 = tempRet0;
          $107 = $79;$108 = $78;
          break L26;
         } else {
          HEAP32[$65>>2] = $75;
          $82 = $75;
          break;
         }
        }
       } while(0);
       $80 = HEAP32[$67>>2]|0;
       $81 = $80 << 2;
       _memcpy(($82|0),($83|0),($81|0))|0;
       label = 26;
      }
     } while(0);
     do {
      if ((label|0) == 26) {
       __THREW__ = 0;
       invoke_viiii(422,($61|0),($position|0),($scale|0),($minimumInstances|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        $86 = ___cxa_find_matching_catch()|0;
        $87 = tempRet0;
        $88 = ($61|0)==(0|0);
        if ($88) {
         $$0 = $86;$$01 = $87;
         break L19;
        } else {
         $107 = $87;$108 = $86;
         break;
        }
       } else {
        HEAP32[$agg$result>>2] = $61;
        break L1;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3715,($61|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      $91 = ___cxa_find_matching_catch()|0;
      $92 = tempRet0;
      __ZdlPv($61);
      ___cxa_call_unexpected(($91|0));
      // unreachable;
     } else {
      __ZdlPv($61);
      $$0 = $108;$$01 = $107;
      break;
     }
    }
   } while(0);
   if ((label|0) == 15) {
    $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
   }
   $97 = HEAP32[$5>>2]|0;
   $98 = ($97|0)>(-1);
   if (!($98)) {
    ___resumeException($$0|0);
    // unreachable;
   }
   $99 = HEAP32[$legacyTreeInstances>>2]|0;
   $100 = HEAP32[$6>>2]|0;
   HEAP32[$3>>2] = $100;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($99|0),($$byval_copy9|0));
   $101 = __THREW__; __THREW__ = 0;
   $102 = $101&1;
   if ($102) {
    $103 = ___cxa_find_matching_catch(0|0)|0;
    $104 = tempRet0;
    ___clang_call_terminate($103);
    // unreachable;
   }
   HEAP32[$legacyTreeInstances>>2] = 0;
   ___resumeException($$0|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 18) {
  HEAP32[$agg$result>>2] = 0;
 }
 $93 = HEAP32[$5>>2]|0;
 $94 = ($93|0)>(-1);
 if (!($94)) {
  STACKTOP = sp;return;
 }
 $95 = HEAP32[$legacyTreeInstances>>2]|0;
 $96 = HEAP32[$6>>2]|0;
 HEAP32[$0>>2] = $96;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($95,$$byval_copy9);
 HEAP32[$legacyTreeInstances>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer17PopulateRenderersEv($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $billboard = 0, $i$01$i = 0, $i$019 = 0, $i1$016 = 0, $phitmp$i = 0, $phitmp$i6 = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 48|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $billboard = sp + 16|0;
 $4 = sp + 20|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7|0)==($9|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = $7;
 $12 = $9;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 7;
 $i$01$i = 0;
 while(1) {
  $17 = ((($9) + ($i$01$i<<7)|0) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  $16 = (($i$01$i) + 1)|0;
  if (!($19)) {
   break;
  }
  $15 = ($16>>>0)<($14>>>0);
  if ($15) {
   $i$01$i = $16;
  } else {
   label = 59;
   break;
  }
 }
 if ((label|0) == 59) {
  STACKTOP = sp;return;
 }
 __ZN12TreeRenderer24InitializePrototypeInfosEv($this);
 $20 = HEAP32[$6>>2]|0;
 $21 = HEAP32[$8>>2]|0;
 $22 = ($20|0)==($21|0);
 L10: do {
  if (!($22)) {
   $23 = (($this) + 288|0);
   $24 = (($4) + 12|0);
   $25 = (($4) + 16|0);
   $26 = (($4) + 20|0);
   $27 = (($4) + 24|0);
   $29 = $21;$i$019 = 0;
   L12: while(1) {
    $28 = ((($29) + ($i$019<<7)|0) + 12|0);
    $30 = HEAP32[$28>>2]|0;
    $31 = ($30|0)==(0);
    do {
     if (!($31)) {
      HEAP32[$3>>2] = $30;
      $32 = HEAP32[560624>>2]|0;
      $33 = ($32|0)==(0|0);
      if ($33) {
       label = 16;
      } else {
       $34 = (($32) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = (($32) + 4|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($35|0)==($37|0);
       do {
        if ($38) {
         $39 = (($32) + 28|0);
         $40 = HEAP32[$39>>2]|0;
         $41 = (($32) + 32|0);
         $42 = HEAP32[$41>>2]|0;
         $43 = (($40) + ($42<<3)|0);
         $59 = $43;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$32,$3);
         $44 = HEAP32[$$byval_copy3>>2]|0;
         $45 = ($44|0)==(-1);
         $46 = (($32) + 28|0);
         $47 = HEAP32[$46>>2]|0;
         if ($45) {
          $48 = (($32) + 32|0);
          $49 = HEAP32[$48>>2]|0;
          $50 = (($47) + ($49<<3)|0);
          $59 = $50;
          break;
         } else {
          $51 = (($47) + ($44<<3)|0);
          $59 = $51;
          break;
         }
        }
       } while(0);
       $52 = HEAP32[560624>>2]|0;
       $53 = (($52) + 28|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = (($52) + 32|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = (($54) + ($56<<3)|0);
       $58 = ($59|0)==($57|0);
       if ($58) {
        label = 16;
       } else {
        $60 = (($59) + 4|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = ($61|0)==(0|0);
        if ($62) {
         label = 16;
        } else {
         $69 = $52;
        }
       }
      }
      if ((label|0) == 16) {
       label = 0;
       $63 = HEAP32[$28>>2]|0;
       $64 = (__Z31ReadObjectFromPersistentManageri($63)|0);
       $phitmp$i = ($64|0)==(0|0);
       if ($phitmp$i) {
        break;
       }
       $$pre = HEAP32[560624>>2]|0;
       $69 = $$pre;
      }
      $65 = HEAP32[$8>>2]|0;
      $66 = ((($65) + ($i$019<<7)|0) + 12|0);
      $67 = HEAP32[$66>>2]|0;
      HEAP32[$2>>2] = $67;
      $68 = ($69|0)==(0|0);
      if ($68) {
       label = 26;
      } else {
       $70 = (($69) + 36|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = (($69) + 4|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = ($71|0)==($73|0);
       do {
        if ($74) {
         $75 = (($69) + 28|0);
         $76 = HEAP32[$75>>2]|0;
         $77 = (($69) + 32|0);
         $78 = HEAP32[$77>>2]|0;
         $79 = (($76) + ($78<<3)|0);
         $95 = $79;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$69,$2);
         $80 = HEAP32[$$byval_copy3>>2]|0;
         $81 = ($80|0)==(-1);
         $82 = (($69) + 28|0);
         $83 = HEAP32[$82>>2]|0;
         if ($81) {
          $84 = (($69) + 32|0);
          $85 = HEAP32[$84>>2]|0;
          $86 = (($83) + ($85<<3)|0);
          $95 = $86;
          break;
         } else {
          $87 = (($83) + ($80<<3)|0);
          $95 = $87;
          break;
         }
        }
       } while(0);
       $88 = HEAP32[560624>>2]|0;
       $89 = (($88) + 28|0);
       $90 = HEAP32[$89>>2]|0;
       $91 = (($88) + 32|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = (($90) + ($92<<3)|0);
       $94 = ($95|0)==($93|0);
       if ($94) {
        label = 26;
       } else {
        $96 = (($95) + 4|0);
        $97 = HEAP32[$96>>2]|0;
        $98 = ($97|0)==(0|0);
        if ($98) {
         label = 26;
        } else {
         $temp$0$i = $97;
        }
       }
      }
      if ((label|0) == 26) {
       label = 0;
       $99 = HEAP32[$66>>2]|0;
       $100 = (__Z31ReadObjectFromPersistentManageri($99)|0);
       $temp$0$i = $100;
      }
      $101 = (($temp$0$i) + 284|0);
      $102 = HEAP32[$101>>2]|0;
      HEAP32[$billboard>>2] = $102;
      $103 = ($102|0)==(0);
      if (!($103)) {
       HEAP32[$1>>2] = $102;
       $104 = HEAP32[560624>>2]|0;
       $105 = ($104|0)==(0|0);
       if ($105) {
        label = 36;
       } else {
        $106 = (($104) + 36|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = (($104) + 4|0);
        $109 = HEAP32[$108>>2]|0;
        $110 = ($107|0)==($109|0);
        do {
         if ($110) {
          $111 = (($104) + 28|0);
          $112 = HEAP32[$111>>2]|0;
          $113 = (($104) + 32|0);
          $114 = HEAP32[$113>>2]|0;
          $115 = (($112) + ($114<<3)|0);
          $131 = $115;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy3,$104,$1);
          $116 = HEAP32[$$byval_copy3>>2]|0;
          $117 = ($116|0)==(-1);
          $118 = (($104) + 28|0);
          $119 = HEAP32[$118>>2]|0;
          if ($117) {
           $120 = (($104) + 32|0);
           $121 = HEAP32[$120>>2]|0;
           $122 = (($119) + ($121<<3)|0);
           $131 = $122;
           break;
          } else {
           $123 = (($119) + ($116<<3)|0);
           $131 = $123;
           break;
          }
         }
        } while(0);
        $124 = HEAP32[560624>>2]|0;
        $125 = (($124) + 28|0);
        $126 = HEAP32[$125>>2]|0;
        $127 = (($124) + 32|0);
        $128 = HEAP32[$127>>2]|0;
        $129 = (($126) + ($128<<3)|0);
        $130 = ($131|0)==($129|0);
        if ($130) {
         label = 36;
        } else {
         $132 = (($131) + 4|0);
         $133 = HEAP32[$132>>2]|0;
         $134 = ($133|0)==(0|0);
         if ($134) {
          label = 36;
         }
        }
       }
       if ((label|0) == 36) {
        label = 0;
        $135 = HEAP32[$billboard>>2]|0;
        $136 = (__Z31ReadObjectFromPersistentManageri($135)|0);
        $phitmp$i6 = ($136|0)==(0|0);
        if ($phitmp$i6) {
         break;
        }
       }
       $137 = (__Z24GetBillboardBatchManagerv()|0);
       __ZN21BillboardBatchManager8RegisterERK4PPtrI14BillboardAssetE($137,$billboard);
       HEAP32[$4>>2] = 0;
       $138 = HEAP32[628440>>2]|0;
       HEAP32[$24>>2] = 0;
       HEAP32[$25>>2] = $138;
       HEAP32[$26>>2] = 0;
       HEAP32[$27>>2] = 0;
       __THREW__ = 0;
       invoke_vii(3422,($23|0),($4|0));
       $139 = __THREW__; __THREW__ = 0;
       $140 = $139&1;
       if ($140) {
        break L12;
       }
       $141 = HEAP32[$27>>2]|0;
       $142 = ($141|0)>(-1);
       if ($142) {
        $143 = HEAP32[$24>>2]|0;
        $144 = HEAP32[$25>>2]|0;
        HEAP32[$0>>2] = $144;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
        __Z19free_alloc_internalPv10MemLabelId($143,$$byval_copy3);
        HEAP32[$24>>2] = 0;
       }
       $145 = HEAP32[$23>>2]|0;
       $146 = HEAP32[$billboard>>2]|0;
       $147 = (($145) + 8|0);
       HEAP32[$147>>2] = $146;
       $148 = (__Z24GetBillboardBatchManagerv()|0);
       $149 = (__ZN21BillboardBatchManager23GetMaterialIntermediateERK4PPtrI14BillboardAssetE($148,$billboard)|0);
       $150 = ($149|0)==(0|0);
       if ($150) {
        $154 = 0;
       } else {
        $151 = (($149) + 4|0);
        $152 = HEAP32[$151>>2]|0;
        $154 = $152;
       }
       $153 = (($145) + 12|0);
       HEAP32[$153>>2] = $154;
       $155 = (__Z24GetBillboardBatchManagerv()|0);
       $156 = (__ZN21BillboardBatchManager7GetMeshERK4PPtrI14BillboardAssetE($155,$billboard)|0);
       $157 = ($156|0)==(0|0);
       if ($157) {
        $161 = 0;
       } else {
        $158 = (($156) + 4|0);
        $159 = HEAP32[$158>>2]|0;
        $161 = $159;
       }
       $160 = (($145) + 16|0);
       HEAP32[$160>>2] = $161;
      }
     }
    } while(0);
    $162 = (($i$019) + 1)|0;
    $163 = HEAP32[$6>>2]|0;
    $164 = HEAP32[$8>>2]|0;
    $165 = $163;
    $166 = $164;
    $167 = (($165) - ($166))|0;
    $168 = $167 >> 7;
    $169 = ($162>>>0)<($168>>>0);
    if ($169) {
     $29 = $164;$i$019 = $162;
    } else {
     break L10;
    }
   }
   $170 = ___cxa_find_matching_catch()|0;
   $171 = tempRet0;
   $172 = HEAP32[$27>>2]|0;
   $173 = ($172|0)>(-1);
   if (!($173)) {
    ___resumeException($170|0);
    // unreachable;
   }
   $174 = HEAP32[$24>>2]|0;
   $175 = HEAP32[$25>>2]|0;
   HEAP32[$0>>2] = $175;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($174|0),($$byval_copy3|0));
   $176 = __THREW__; __THREW__ = 0;
   $177 = $176&1;
   if ($177) {
    $236 = ___cxa_find_matching_catch(0|0)|0;
    $237 = tempRet0;
    ___clang_call_terminate($236);
    // unreachable;
   }
   HEAP32[$24>>2] = 0;
   ___resumeException($170|0);
   // unreachable;
  }
 } while(0);
 $178 = HEAP32[$this>>2]|0;
 $179 = (($this) + 204|0);
 $180 = (($178) + 20|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = (($178) + 16|0);
 $183 = HEAP32[$182>>2]|0;
 $184 = $181;
 $185 = $183;
 $186 = (($184) - ($185))|0;
 $187 = (($186|0) / 40)&-1;
 $188 = (($187) + 1)|0;
 __ZN15LODGroupManager20ReserveInternalArrayEi($179,$188);
 $189 = (($this) + 184|0);
 $190 = HEAP32[$180>>2]|0;
 $191 = HEAP32[$182>>2]|0;
 $192 = $190;
 $193 = $191;
 $194 = (($192) - ($193))|0;
 $195 = (($194|0) / 40)&-1;
 $196 = (($this) + 192|0);
 HEAP32[$196>>2] = $195;
 $197 = (($this) + 196|0);
 $198 = HEAP32[$197>>2]|0;
 $199 = $198 & 2147483647;
 $200 = ($199>>>0)<($195>>>0);
 do {
  if ($200) {
   $201 = ($198|0)>(-1);
   if ($201) {
    HEAP32[$197>>2] = $195;
    $202 = HEAP32[$189>>2]|0;
    $203 = $195 << 2;
    $204 = (($this) + 188|0);
    $205 = HEAP32[$204>>2]|0;
    HEAP32[$0>>2] = $205;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $206 = (__Z16realloc_internalPvji10MemLabelIdiPKci($202,$203,4,$$byval_copy3,0,803264,370)|0);
    HEAP32[$189>>2] = $206;
    break;
   } else {
    $207 = $195 << 2;
    $208 = (($this) + 188|0);
    $209 = HEAP32[$208>>2]|0;
    HEAP32[$0>>2] = $209;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $210 = (__Z15malloc_internaljj10MemLabelIdiPKci($207,4,$$byval_copy3,0,803264,352)|0);
    $211 = HEAP32[$189>>2]|0;
    $212 = HEAP32[$196>>2]|0;
    $213 = $212 << 2;
    _memcpy(($210|0),($211|0),($213|0))|0;
    HEAP32[$197>>2] = $195;
    HEAP32[$189>>2] = $210;
    break;
   }
  }
 } while(0);
 $214 = HEAP32[$180>>2]|0;
 $215 = HEAP32[$182>>2]|0;
 $216 = ($214|0)==($215|0);
 if ($216) {
  STACKTOP = sp;return;
 } else {
  $219 = $215;$i1$016 = 0;
 }
 while(1) {
  $217 = HEAP32[$this>>2]|0;
  $218 = ((($219) + (($i1$016*40)|0)|0) + 32|0);
  $220 = HEAP32[$218>>2]|0;
  $221 = (($217) + 28|0);
  $222 = HEAP32[$221>>2]|0;
  $223 = (($222) + ($220<<7)|0);
  $224 = (__ZNK12TreeDatabase9Prototype11GetLODGroupEv($223)|0);
  $225 = ($224|0)==(0|0);
  if ($225) {
   $226 = (__ZNK12TreeDatabase9Prototype13GetLegacyMeshEv($223)|0);
   $227 = ($226|0)==(0|0);
   if (!($227)) {
    __ZN12TreeRenderer29CreateMeshTreeRendererForTreeEi($this,$i1$016);
   }
  } else {
   __ZN12TreeRenderer25CreateLODRenderersForTreeEi($this,$i1$016);
  }
  $228 = (($i1$016) + 1)|0;
  $229 = HEAP32[$180>>2]|0;
  $230 = HEAP32[$182>>2]|0;
  $231 = $229;
  $232 = $230;
  $233 = (($231) - ($232))|0;
  $234 = (($233|0) / 40)&-1;
  $235 = ($228>>>0)<($234>>>0);
  if ($235) {
   $219 = $230;$i1$016 = $228;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12TreeRendererD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$10 = 0, $$1011 = 0, $$11 = 0, $$1112 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$5 = 0, $$56 = 0, $$6 = 0, $$67 = 0, $$7 = 0, $$78 = 0, $$8 = 0, $$89 = 0, $$9 = 0, $$910 = 0, $$byval_copy42 = 0, $$pre$i = 0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i47 = 0, $$pre$i$i$i49 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__f$0$i$i$i$i = 0, $__f$0$i$i$i$i25 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i39 = 0, $eh$lpad$body$indexZ2D = 0, $i$02$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i40 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i44 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i42 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i43 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy42 = sp + 100|0;
 $0 = sp + 96|0;
 $1 = sp + 92|0;
 $2 = sp + 88|0;
 $3 = sp + 84|0;
 $4 = sp + 80|0;
 $5 = sp + 76|0;
 $6 = sp + 72|0;
 $7 = sp + 68|0;
 $8 = sp + 64|0;
 $9 = sp + 60|0;
 $10 = sp + 56|0;
 $11 = sp + 52|0;
 $12 = sp + 48|0;
 $13 = sp + 16|0;
 $14 = sp;
 $15 = sp + 4|0;
 $16 = sp + 8|0;
 $17 = sp + 12|0;
 $18 = sp + 20|0;
 $19 = sp + 24|0;
 $20 = sp + 28|0;
 $21 = sp + 32|0;
 $22 = sp + 36|0;
 $23 = sp + 40|0;
 $24 = sp + 44|0;
 __THREW__ = 0;
 invoke_vi(3720,($this|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 L1: do {
  if ($26) {
   label = 85;
  } else {
   $27 = (($this) + 108|0);
   $28 = (($this) + 116|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0);
   L3: do {
    if (!($30)) {
     $456 = $29;$i$02$i = 0;
     while(1) {
      $31 = HEAP32[$27>>2]|0;
      $32 = (($31) + ($i$02$i<<2)|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($33) + 56|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($35|0)==(0);
      if ($36) {
       $43 = $456;
      } else {
       $37 = (($33) + 44|0);
       $38 = HEAP32[$37>>2]|0;
       __THREW__ = 0;
       invoke_vi(3709,($38|0));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break;
       }
       HEAP32[$37>>2] = 0;
       HEAP32[$34>>2] = 0;
       $$pre$i = HEAP32[$28>>2]|0;
       $43 = $$pre$i;
      }
      $41 = (($i$02$i) + 1)|0;
      $42 = ($41>>>0)<($43>>>0);
      if ($42) {
       $456 = $43;$i$02$i = $41;
      } else {
       break L3;
      }
     }
     $244 = ___cxa_find_matching_catch()|0;
     $245 = tempRet0;
     $lpad$phi$index = $244;$lpad$phi$index2 = $245;
     label = 86;
     break L1;
    }
   } while(0);
   $44 = (($this) + 120|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)>(-1);
   if ($46) {
    $47 = HEAP32[$27>>2]|0;
    $48 = (($this) + 112|0);
    $49 = HEAP32[$48>>2]|0;
    HEAP32[$24>>2] = $49;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$24+0>>2]|0;
    invoke_vii(2591,($47|0),($$byval_copy42|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 85;
     break;
    }
    HEAP32[$27>>2] = 0;
   }
   HEAP32[$28>>2] = 0;
   HEAP32[$44>>2] = 0;
   $52 = (($this) + 88|0);
   $53 = HEAP32[$52>>2]|0;
   __THREW__ = 0;
   invoke_vi(3709,($53|0));
   $54 = __THREW__; __THREW__ = 0;
   $55 = $54&1;
   if ($55) {
    label = 85;
   } else {
    HEAP32[$52>>2] = 0;
    $56 = (($this) + 4|0);
    $57 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    invoke_vi(3709,($57|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 85;
    } else {
     HEAP32[$56>>2] = 0;
     $60 = (($this) + 288|0);
     $61 = (($this) + 296|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($62|0)==(0);
     L19: do {
      if (!($63)) {
       $64 = (($this) + 292|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = HEAP32[$60>>2]|0;
       $67 = (($66) + 4|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = HEAP32[$65>>2]|0;
       $70 = (($69) + 4|0);
       HEAP32[$70>>2] = $68;
       $71 = HEAP32[$65>>2]|0;
       $72 = HEAP32[$67>>2]|0;
       HEAP32[$72>>2] = $71;
       HEAP32[$61>>2] = 0;
       $__f$0$i$i$i$i = $65;
       while(1) {
        $73 = ($__f$0$i$i$i$i|0)==($60|0);
        if ($73) {
         break L19;
        }
        $74 = (($__f$0$i$i$i$i) + 4|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($__f$0$i$i$i$i) + 32|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = ($77|0)>(-1);
        if ($78) {
         $79 = (($__f$0$i$i$i$i) + 20|0);
         $80 = HEAP32[$79>>2]|0;
         $81 = (($__f$0$i$i$i$i) + 24|0);
         $82 = HEAP32[$81>>2]|0;
         HEAP32[$0>>2] = $82;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_vii(2591,($80|0),($$byval_copy42|0));
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          label = 21;
          break;
         }
         HEAP32[$79>>2] = 0;
        }
        HEAP32[$23>>2] = 55;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$23+0>>2]|0;
        invoke_vii(2591,($__f$0$i$i$i$i|0),($$byval_copy42|0));
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 20;
         break;
        } else {
         $__f$0$i$i$i$i = $75;
        }
       }
       if ((label|0) == 20) {
        $87 = ___cxa_find_matching_catch()|0;
        $88 = tempRet0;
        ___cxa_call_unexpected(($87|0));
        // unreachable;
       }
       else if ((label|0) == 21) {
        $89 = ___cxa_find_matching_catch()|0;
        $90 = tempRet0;
        ___cxa_call_unexpected(($89|0));
        // unreachable;
       }
      }
     } while(0);
     $91 = (($this) + 284|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($92|0)>(-1);
     do {
      if ($93) {
       $94 = (($this) + 272|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = (($this) + 276|0);
       $97 = HEAP32[$96>>2]|0;
       HEAP32[$22>>2] = $97;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$22+0>>2]|0;
       invoke_vii(2591,($95|0),($$byval_copy42|0));
       $98 = __THREW__; __THREW__ = 0;
       $99 = $98&1;
       if ($99) {
        $279 = ___cxa_find_matching_catch()|0;
        $280 = tempRet0;
        $$1 = $280;$$12 = $279;
        label = 100;
        break L1;
       } else {
        HEAP32[$94>>2] = 0;
        break;
       }
      }
     } while(0);
     $100 = (($this) + 268|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101|0)>(-1);
     do {
      if ($102) {
       $103 = (($this) + 256|0);
       $104 = HEAP32[$103>>2]|0;
       $105 = (($this) + 260|0);
       $106 = HEAP32[$105>>2]|0;
       HEAP32[$21>>2] = $106;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$21+0>>2]|0;
       invoke_vii(2591,($104|0),($$byval_copy42|0));
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        $290 = ___cxa_find_matching_catch()|0;
        $291 = tempRet0;
        $$2 = $291;$$23 = $290;
        label = 103;
        break L1;
       } else {
        HEAP32[$103>>2] = 0;
        break;
       }
      }
     } while(0);
     $109 = (($this) + 244|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0|0);
     if (!($111)) {
      $112 = (($this) + 248|0);
      while(1) {
       $113 = HEAP32[$112>>2]|0;
       $114 = ($113|0)==($110|0);
       if ($114) {
        break;
       }
       $115 = (($113) + -148|0);
       HEAP32[$112>>2] = $115;
       __THREW__ = 0;
       invoke_vi(3717,($115|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 32;
        break;
       }
      }
      if ((label|0) == 32) {
       $118 = ___cxa_find_matching_catch()|0;
       $119 = tempRet0;
       ___cxa_call_unexpected(($118|0));
       // unreachable;
      }
      $120 = HEAP32[$109>>2]|0;
      HEAP32[$20>>2] = 55;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$20+0>>2]|0;
      invoke_vii(2591,($120|0),($$byval_copy42|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       $123 = ___cxa_find_matching_catch()|0;
       $124 = tempRet0;
       ___cxa_call_unexpected(($123|0));
       // unreachable;
      }
     }
     $125 = (($this) + 232|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = ($126|0)==(0|0);
     if (!($127)) {
      $128 = (($this) + 236|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = ($129|0)==($126|0);
      do {
       if ($130) {
        $148 = $126;
       } else {
        $132 = $129;
        while(1) {
         $131 = (($132) + -28|0);
         HEAP32[$128>>2] = $131;
         $133 = (($132) + -24|0);
         $134 = HEAP32[$133>>2]|0;
         $135 = ($134|0)==(0|0);
         if ($135) {
          $137 = $131;
         } else {
          $138 = (($132) + -20|0);
          $139 = HEAP32[$138>>2]|0;
          $140 = ($139|0)==($134|0);
          if (!($140)) {
           $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $134;
           $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($139) + -72|0);
           $141 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
           $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($141)|0);
           $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
           $142 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i>>>0) / 72)&-1;
           $143 = $142 ^ -1;
           $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($139) + (($143*72)|0)|0);
           HEAP32[$138>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
          }
          HEAP32[$18>>2] = 55;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$18+0>>2]|0;
          invoke_vii(2591,($134|0),($$byval_copy42|0));
          $144 = __THREW__; __THREW__ = 0;
          $145 = $144&1;
          if ($145) {
           label = 44;
           break;
          }
          $$pre$i$i$i$i$i = HEAP32[$128>>2]|0;
          $137 = $$pre$i$i$i$i$i;
         }
         $136 = ($137|0)==($126|0);
         if ($136) {
          label = 45;
          break;
         } else {
          $132 = $137;
         }
        }
        if ((label|0) == 44) {
         $146 = ___cxa_find_matching_catch()|0;
         $147 = tempRet0;
         ___cxa_call_unexpected(($146|0));
         // unreachable;
        }
        else if ((label|0) == 45) {
         $$pre$i$i$i = HEAP32[$125>>2]|0;
         $148 = $$pre$i$i$i;
         break;
        }
       }
      } while(0);
      HEAP32[$19>>2] = 55;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$19+0>>2]|0;
      invoke_vii(2591,($148|0),($$byval_copy42|0));
      $149 = __THREW__; __THREW__ = 0;
      $150 = $149&1;
      if ($150) {
       $151 = ___cxa_find_matching_catch()|0;
       $152 = tempRet0;
       ___cxa_call_unexpected(($151|0));
       // unreachable;
      }
     }
     $153 = (($this) + 204|0);
     __THREW__ = 0;
     invoke_vi(3718,($153|0));
     $154 = __THREW__; __THREW__ = 0;
     $155 = $154&1;
     if ($155) {
      $345 = ___cxa_find_matching_catch()|0;
      $346 = tempRet0;
      $$5 = $346;$$56 = $345;
      label = 126;
      break;
     }
     $156 = (($this) + 196|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)>(-1);
     do {
      if ($158) {
       $159 = (($this) + 184|0);
       $160 = HEAP32[$159>>2]|0;
       $161 = (($this) + 188|0);
       $162 = HEAP32[$161>>2]|0;
       HEAP32[$17>>2] = $162;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$17+0>>2]|0;
       invoke_vii(2591,($160|0),($$byval_copy42|0));
       $163 = __THREW__; __THREW__ = 0;
       $164 = $163&1;
       if ($164) {
        $350 = ___cxa_find_matching_catch()|0;
        $351 = tempRet0;
        $$6 = $351;$$67 = $350;
        label = 130;
        break L1;
       } else {
        HEAP32[$159>>2] = 0;
        break;
       }
      }
     } while(0);
     $165 = (($this) + 180|0);
     $166 = HEAP32[$165>>2]|0;
     $167 = ($166|0)>(-1);
     do {
      if ($167) {
       $168 = (($this) + 168|0);
       $169 = HEAP32[$168>>2]|0;
       $170 = (($this) + 172|0);
       $171 = HEAP32[$170>>2]|0;
       HEAP32[$16>>2] = $171;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$16+0>>2]|0;
       invoke_vii(2591,($169|0),($$byval_copy42|0));
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       if ($173) {
        $361 = ___cxa_find_matching_catch()|0;
        $362 = tempRet0;
        $$7 = $362;$$78 = $361;
        label = 134;
        break L1;
       } else {
        HEAP32[$168>>2] = 0;
        break;
       }
      }
     } while(0);
     $174 = (($this) + 164|0);
     $175 = HEAP32[$174>>2]|0;
     $176 = ($175|0)>(-1);
     do {
      if ($176) {
       $177 = (($this) + 152|0);
       $178 = HEAP32[$177>>2]|0;
       $179 = (($this) + 156|0);
       $180 = HEAP32[$179>>2]|0;
       HEAP32[$15>>2] = $180;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$15+0>>2]|0;
       invoke_vii(2591,($178|0),($$byval_copy42|0));
       $181 = __THREW__; __THREW__ = 0;
       $182 = $181&1;
       if ($182) {
        $372 = ___cxa_find_matching_catch()|0;
        $373 = tempRet0;
        $$8 = $373;$$89 = $372;
        label = 138;
        break L1;
       } else {
        HEAP32[$177>>2] = 0;
        break;
       }
      }
     } while(0);
     $183 = (($this) + 128|0);
     __THREW__ = 0;
     invoke_vi(3719,($183|0));
     $184 = __THREW__; __THREW__ = 0;
     $185 = $184&1;
     if ($185) {
      $383 = ___cxa_find_matching_catch()|0;
      $384 = tempRet0;
      $$9 = $384;$$910 = $383;
      label = 139;
      break;
     }
     $186 = (($this) + 124|0);
     $187 = HEAP32[$186>>2]|0;
     $188 = ($187|0)==(0|0);
     do {
      if (!($188)) {
       __THREW__ = 0;
       invoke_vi(3714,($187|0));
       $189 = __THREW__; __THREW__ = 0;
       $190 = $189&1;
       if ($190) {
        $191 = ___cxa_find_matching_catch()|0;
        $192 = tempRet0;
        __ZdlPv($187);
        ___cxa_call_unexpected(($191|0));
        // unreachable;
       } else {
        __ZdlPv($187);
        break;
       }
      }
     } while(0);
     $193 = HEAP32[$44>>2]|0;
     $194 = ($193|0)>(-1);
     do {
      if ($194) {
       $195 = HEAP32[$27>>2]|0;
       $196 = (($this) + 112|0);
       $197 = HEAP32[$196>>2]|0;
       HEAP32[$14>>2] = $197;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$14+0>>2]|0;
       invoke_vii(2591,($195|0),($$byval_copy42|0));
       $198 = __THREW__; __THREW__ = 0;
       $199 = $198&1;
       if ($199) {
        $404 = ___cxa_find_matching_catch()|0;
        $405 = tempRet0;
        $$10 = $405;$$1011 = $404;
        label = 148;
        break L1;
       } else {
        HEAP32[$27>>2] = 0;
        break;
       }
      }
     } while(0);
     $200 = (($this) + 104|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = ($201|0)>(-1);
     do {
      if ($202) {
       $203 = (($this) + 92|0);
       $204 = HEAP32[$203>>2]|0;
       $205 = (($this) + 96|0);
       $206 = HEAP32[$205>>2]|0;
       HEAP32[$13>>2] = $206;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$13+0>>2]|0;
       invoke_vii(2591,($204|0),($$byval_copy42|0));
       $207 = __THREW__; __THREW__ = 0;
       $208 = $207&1;
       if ($208) {
        $406 = ___cxa_find_matching_catch()|0;
        $407 = tempRet0;
        $$11 = $407;$$1112 = $406;
        label = 151;
        break L1;
       } else {
        HEAP32[$203>>2] = 0;
        break;
       }
      }
     } while(0);
     $209 = (($this) + 68|0);
     $210 = HEAP32[$209>>2]|0;
     $211 = ($210|0)==(0|0);
     do {
      if (!($211)) {
       __THREW__ = 0;
       invoke_vi(3715,($210|0));
       $212 = __THREW__; __THREW__ = 0;
       $213 = $212&1;
       if ($213) {
        $214 = ___cxa_find_matching_catch()|0;
        $215 = tempRet0;
        __ZdlPv($210);
        ___cxa_call_unexpected(($214|0));
        // unreachable;
       } else {
        __ZdlPv($210);
        break;
       }
      }
     } while(0);
     $216 = (($this) + 8|0);
     $217 = (($this) + 36|0);
     $218 = HEAP32[$217>>2]|0;
     $219 = ($218|0)>(-1);
     do {
      if ($219) {
       $220 = (($this) + 24|0);
       $221 = HEAP32[$220>>2]|0;
       $222 = (($this) + 28|0);
       $223 = HEAP32[$222>>2]|0;
       HEAP32[$1>>2] = $223;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($221|0),($$byval_copy42|0));
       $224 = __THREW__; __THREW__ = 0;
       $225 = $224&1;
       if (!($225)) {
        HEAP32[$220>>2] = 0;
        break;
       }
       $232 = ___cxa_find_matching_catch()|0;
       $233 = tempRet0;
       $234 = (($this) + 20|0);
       $235 = HEAP32[$234>>2]|0;
       $236 = ($235|0)>(-1);
       if (!($236)) {
        ___resumeException($232|0);
        // unreachable;
       }
       $237 = HEAP32[$216>>2]|0;
       $238 = (($this) + 12|0);
       $239 = HEAP32[$238>>2]|0;
       HEAP32[$0>>2] = $239;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($237|0),($$byval_copy42|0));
       $240 = __THREW__; __THREW__ = 0;
       $241 = $240&1;
       if ($241) {
        $242 = ___cxa_find_matching_catch(0|0)|0;
        $243 = tempRet0;
        ___clang_call_terminate($242);
        // unreachable;
       }
       HEAP32[$216>>2] = 0;
       ___resumeException($232|0);
       // unreachable;
      }
     } while(0);
     $226 = (($this) + 20|0);
     $227 = HEAP32[$226>>2]|0;
     $228 = ($227|0)>(-1);
     if (!($228)) {
      STACKTOP = sp;return;
     }
     $229 = HEAP32[$216>>2]|0;
     $230 = (($this) + 12|0);
     $231 = HEAP32[$230>>2]|0;
     HEAP32[$0>>2] = $231;
     ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($229,$$byval_copy42);
     HEAP32[$216>>2] = 0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 85) {
  $246 = ___cxa_find_matching_catch()|0;
  $247 = tempRet0;
  $lpad$phi$index = $246;$lpad$phi$index2 = $247;
  label = 86;
 }
 if ((label|0) == 86) {
  $248 = (($this) + 288|0);
  $249 = (($this) + 296|0);
  $250 = HEAP32[$249>>2]|0;
  $251 = ($250|0)==(0);
  L142: do {
   if (!($251)) {
    $252 = (($this) + 292|0);
    $253 = HEAP32[$252>>2]|0;
    $254 = HEAP32[$248>>2]|0;
    $255 = (($254) + 4|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = HEAP32[$253>>2]|0;
    $258 = (($257) + 4|0);
    HEAP32[$258>>2] = $256;
    $259 = HEAP32[$253>>2]|0;
    $260 = HEAP32[$255>>2]|0;
    HEAP32[$260>>2] = $259;
    HEAP32[$249>>2] = 0;
    $__f$0$i$i$i$i25 = $253;
    while(1) {
     $261 = ($__f$0$i$i$i$i25|0)==($248|0);
     if ($261) {
      break L142;
     }
     $262 = (($__f$0$i$i$i$i25) + 4|0);
     $263 = HEAP32[$262>>2]|0;
     $264 = (($__f$0$i$i$i$i25) + 32|0);
     $265 = HEAP32[$264>>2]|0;
     $266 = ($265|0)>(-1);
     if ($266) {
      $267 = (($__f$0$i$i$i$i25) + 20|0);
      $268 = HEAP32[$267>>2]|0;
      $269 = (($__f$0$i$i$i$i25) + 24|0);
      $270 = HEAP32[$269>>2]|0;
      HEAP32[$0>>2] = $270;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($268|0),($$byval_copy42|0));
      $271 = __THREW__; __THREW__ = 0;
      $272 = $271&1;
      if ($272) {
       label = 94;
       break;
      }
      HEAP32[$267>>2] = 0;
     }
     HEAP32[$12>>2] = 55;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$12+0>>2]|0;
     invoke_vii(2591,($__f$0$i$i$i$i25|0),($$byval_copy42|0));
     $273 = __THREW__; __THREW__ = 0;
     $274 = $273&1;
     if ($274) {
      label = 93;
      break;
     } else {
      $__f$0$i$i$i$i25 = $263;
     }
    }
    if ((label|0) == 93) {
     $275 = ___cxa_find_matching_catch()|0;
     $276 = tempRet0;
     ___cxa_call_unexpected(($275|0));
     // unreachable;
    }
    else if ((label|0) == 94) {
     $277 = ___cxa_find_matching_catch()|0;
     $278 = tempRet0;
     ___cxa_call_unexpected(($277|0));
     // unreachable;
    }
   }
  } while(0);
  $281 = (($this) + 284|0);
  $282 = HEAP32[$281>>2]|0;
  $283 = ($282|0)>(-1);
  if ($283) {
   $284 = (($this) + 272|0);
   $285 = HEAP32[$284>>2]|0;
   $286 = (($this) + 276|0);
   $287 = HEAP32[$286>>2]|0;
   HEAP32[$11>>2] = $287;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$11+0>>2]|0;
   invoke_vii(2591,($285|0),($$byval_copy42|0));
   $288 = __THREW__; __THREW__ = 0;
   $289 = $288&1;
   if (!($289)) {
    HEAP32[$284>>2] = 0;
    $$1 = $lpad$phi$index2;$$12 = $lpad$phi$index;
    label = 100;
   }
  } else {
   $$1 = $lpad$phi$index2;$$12 = $lpad$phi$index;
   label = 100;
  }
 }
 if ((label|0) == 100) {
  $292 = (($this) + 268|0);
  $293 = HEAP32[$292>>2]|0;
  $294 = ($293|0)>(-1);
  if ($294) {
   $295 = (($this) + 256|0);
   $296 = HEAP32[$295>>2]|0;
   $297 = (($this) + 260|0);
   $298 = HEAP32[$297>>2]|0;
   HEAP32[$10>>2] = $298;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$10+0>>2]|0;
   invoke_vii(2591,($296|0),($$byval_copy42|0));
   $299 = __THREW__; __THREW__ = 0;
   $300 = $299&1;
   if (!($300)) {
    HEAP32[$295>>2] = 0;
    $$2 = $$1;$$23 = $$12;
    label = 103;
   }
  } else {
   $$2 = $$1;$$23 = $$12;
   label = 103;
  }
 }
 if ((label|0) == 103) {
  $301 = (($this) + 244|0);
  $302 = HEAP32[$301>>2]|0;
  $303 = ($302|0)==(0|0);
  if (!($303)) {
   $304 = (($this) + 248|0);
   while(1) {
    $305 = HEAP32[$304>>2]|0;
    $306 = ($305|0)==($302|0);
    if ($306) {
     break;
    }
    $307 = (($305) + -148|0);
    HEAP32[$304>>2] = $307;
    __THREW__ = 0;
    invoke_vi(3717,($307|0));
    $308 = __THREW__; __THREW__ = 0;
    $309 = $308&1;
    if ($309) {
     label = 107;
     break;
    }
   }
   if ((label|0) == 107) {
    $310 = ___cxa_find_matching_catch()|0;
    $311 = tempRet0;
    ___cxa_call_unexpected(($310|0));
    // unreachable;
   }
   $312 = HEAP32[$301>>2]|0;
   HEAP32[$9>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($312|0),($$byval_copy42|0));
   $313 = __THREW__; __THREW__ = 0;
   $314 = $313&1;
   if ($314) {
    $315 = ___cxa_find_matching_catch()|0;
    $316 = tempRet0;
    ___cxa_call_unexpected(($315|0));
    // unreachable;
   }
  }
  $317 = (($this) + 232|0);
  $318 = HEAP32[$317>>2]|0;
  $319 = ($318|0)==(0|0);
  if (!($319)) {
   $320 = (($this) + 236|0);
   $321 = HEAP32[$320>>2]|0;
   $322 = ($321|0)==($318|0);
   do {
    if ($322) {
     $340 = $318;
    } else {
     $324 = $321;
     while(1) {
      $323 = (($324) + -28|0);
      HEAP32[$320>>2] = $323;
      $325 = (($324) + -24|0);
      $326 = HEAP32[$325>>2]|0;
      $327 = ($326|0)==(0|0);
      if ($327) {
       $329 = $323;
      } else {
       $330 = (($324) + -20|0);
       $331 = HEAP32[$330>>2]|0;
       $332 = ($331|0)==($326|0);
       if (!($332)) {
        $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i39 = $326;
        $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i40 = (($331) + -72|0);
        $333 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i39))|0;
        $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i42 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i40) + ($333)|0);
        $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i43 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i42;
        $334 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i43>>>0) / 72)&-1;
        $335 = $334 ^ -1;
        $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i44 = (($331) + (($335*72)|0)|0);
        HEAP32[$330>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i44;
       }
       HEAP32[$7>>2] = 55;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$7+0>>2]|0;
       invoke_vii(2591,($326|0),($$byval_copy42|0));
       $336 = __THREW__; __THREW__ = 0;
       $337 = $336&1;
       if ($337) {
        label = 119;
        break;
       }
       $$pre$i$i$i$i$i47 = HEAP32[$320>>2]|0;
       $329 = $$pre$i$i$i$i$i47;
      }
      $328 = ($329|0)==($318|0);
      if ($328) {
       label = 120;
       break;
      } else {
       $324 = $329;
      }
     }
     if ((label|0) == 119) {
      $338 = ___cxa_find_matching_catch()|0;
      $339 = tempRet0;
      ___cxa_call_unexpected(($338|0));
      // unreachable;
     }
     else if ((label|0) == 120) {
      $$pre$i$i$i49 = HEAP32[$317>>2]|0;
      $340 = $$pre$i$i$i49;
      break;
     }
    }
   } while(0);
   HEAP32[$8>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$8+0>>2]|0;
   invoke_vii(2591,($340|0),($$byval_copy42|0));
   $341 = __THREW__; __THREW__ = 0;
   $342 = $341&1;
   if ($342) {
    $343 = ___cxa_find_matching_catch()|0;
    $344 = tempRet0;
    ___cxa_call_unexpected(($343|0));
    // unreachable;
   }
  }
  $347 = (($this) + 204|0);
  __THREW__ = 0;
  invoke_vi(3718,($347|0));
  $348 = __THREW__; __THREW__ = 0;
  $349 = $348&1;
  if (!($349)) {
   $$5 = $$2;$$56 = $$23;
   label = 126;
  }
 }
 if ((label|0) == 126) {
  $352 = (($this) + 196|0);
  $353 = HEAP32[$352>>2]|0;
  $354 = ($353|0)>(-1);
  if ($354) {
   $355 = (($this) + 184|0);
   $356 = HEAP32[$355>>2]|0;
   $357 = (($this) + 188|0);
   $358 = HEAP32[$357>>2]|0;
   HEAP32[$6>>2] = $358;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$6+0>>2]|0;
   invoke_vii(2591,($356|0),($$byval_copy42|0));
   $359 = __THREW__; __THREW__ = 0;
   $360 = $359&1;
   if (!($360)) {
    HEAP32[$355>>2] = 0;
    $$6 = $$5;$$67 = $$56;
    label = 130;
   }
  } else {
   $$6 = $$5;$$67 = $$56;
   label = 130;
  }
 }
 if ((label|0) == 130) {
  $363 = (($this) + 180|0);
  $364 = HEAP32[$363>>2]|0;
  $365 = ($364|0)>(-1);
  if ($365) {
   $366 = (($this) + 168|0);
   $367 = HEAP32[$366>>2]|0;
   $368 = (($this) + 172|0);
   $369 = HEAP32[$368>>2]|0;
   HEAP32[$5>>2] = $369;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($367|0),($$byval_copy42|0));
   $370 = __THREW__; __THREW__ = 0;
   $371 = $370&1;
   if (!($371)) {
    HEAP32[$366>>2] = 0;
    $$7 = $$6;$$78 = $$67;
    label = 134;
   }
  } else {
   $$7 = $$6;$$78 = $$67;
   label = 134;
  }
 }
 if ((label|0) == 134) {
  $374 = (($this) + 164|0);
  $375 = HEAP32[$374>>2]|0;
  $376 = ($375|0)>(-1);
  if ($376) {
   $377 = (($this) + 152|0);
   $378 = HEAP32[$377>>2]|0;
   $379 = (($this) + 156|0);
   $380 = HEAP32[$379>>2]|0;
   HEAP32[$4>>2] = $380;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_vii(2591,($378|0),($$byval_copy42|0));
   $381 = __THREW__; __THREW__ = 0;
   $382 = $381&1;
   if (!($382)) {
    HEAP32[$377>>2] = 0;
    $$8 = $$7;$$89 = $$78;
    label = 138;
   }
  } else {
   $$8 = $$7;$$89 = $$78;
   label = 138;
  }
 }
 if ((label|0) == 138) {
  $385 = (($this) + 128|0);
  __THREW__ = 0;
  invoke_vi(3719,($385|0));
  $386 = __THREW__; __THREW__ = 0;
  $387 = $386&1;
  if (!($387)) {
   $$9 = $$8;$$910 = $$89;
   label = 139;
  }
 }
 if ((label|0) == 139) {
  $388 = (($this) + 124|0);
  $389 = HEAP32[$388>>2]|0;
  $390 = ($389|0)==(0|0);
  do {
   if (!($390)) {
    __THREW__ = 0;
    invoke_vi(3714,($389|0));
    $391 = __THREW__; __THREW__ = 0;
    $392 = $391&1;
    if ($392) {
     $393 = ___cxa_find_matching_catch()|0;
     $394 = tempRet0;
     __ZdlPv($389);
     ___cxa_call_unexpected(($393|0));
     // unreachable;
    } else {
     __ZdlPv($389);
     break;
    }
   }
  } while(0);
  $395 = (($this) + 120|0);
  $396 = HEAP32[$395>>2]|0;
  $397 = ($396|0)>(-1);
  if ($397) {
   $398 = (($this) + 108|0);
   $399 = HEAP32[$398>>2]|0;
   $400 = (($this) + 112|0);
   $401 = HEAP32[$400>>2]|0;
   HEAP32[$3>>2] = $401;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($399|0),($$byval_copy42|0));
   $402 = __THREW__; __THREW__ = 0;
   $403 = $402&1;
   if (!($403)) {
    HEAP32[$398>>2] = 0;
    $$10 = $$9;$$1011 = $$910;
    label = 148;
   }
  } else {
   $$10 = $$9;$$1011 = $$910;
   label = 148;
  }
 }
 if ((label|0) == 148) {
  $408 = (($this) + 104|0);
  $409 = HEAP32[$408>>2]|0;
  $410 = ($409|0)>(-1);
  if ($410) {
   $411 = (($this) + 92|0);
   $412 = HEAP32[$411>>2]|0;
   $413 = (($this) + 96|0);
   $414 = HEAP32[$413>>2]|0;
   HEAP32[$2>>2] = $414;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($412|0),($$byval_copy42|0));
   $415 = __THREW__; __THREW__ = 0;
   $416 = $415&1;
   if (!($416)) {
    HEAP32[$411>>2] = 0;
    $$11 = $$10;$$1112 = $$1011;
    label = 151;
   }
  } else {
   $$11 = $$10;$$1112 = $$1011;
   label = 151;
  }
 }
 if ((label|0) == 151) {
  $417 = (($this) + 68|0);
  $418 = HEAP32[$417>>2]|0;
  $419 = ($418|0)==(0|0);
  do {
   if (!($419)) {
    __THREW__ = 0;
    invoke_vi(3715,($418|0));
    $420 = __THREW__; __THREW__ = 0;
    $421 = $420&1;
    if ($421) {
     $422 = ___cxa_find_matching_catch()|0;
     $423 = tempRet0;
     __ZdlPv($418);
     ___cxa_call_unexpected(($422|0));
     // unreachable;
    } else {
     __ZdlPv($418);
     break;
    }
   }
  } while(0);
  $424 = (($this) + 8|0);
  $425 = (($this) + 36|0);
  $426 = HEAP32[$425>>2]|0;
  $427 = ($426|0)>(-1);
  do {
   if ($427) {
    $428 = (($this) + 24|0);
    $429 = HEAP32[$428>>2]|0;
    $430 = (($this) + 28|0);
    $431 = HEAP32[$430>>2]|0;
    HEAP32[$1>>2] = $431;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($429|0),($$byval_copy42|0));
    $432 = __THREW__; __THREW__ = 0;
    $433 = $432&1;
    if (!($433)) {
     HEAP32[$428>>2] = 0;
     break;
    }
    $442 = ___cxa_find_matching_catch(0|0)|0;
    $443 = tempRet0;
    $444 = (($this) + 20|0);
    $445 = HEAP32[$444>>2]|0;
    $446 = ($445|0)>(-1);
    if (!($446)) {
     $eh$lpad$body$indexZ2D = $442;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
    $447 = HEAP32[$424>>2]|0;
    $448 = (($this) + 12|0);
    $449 = HEAP32[$448>>2]|0;
    HEAP32[$0>>2] = $449;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($447|0),($$byval_copy42|0));
    $450 = __THREW__; __THREW__ = 0;
    $451 = $450&1;
    if ($451) {
     $452 = ___cxa_find_matching_catch(0|0)|0;
     $453 = tempRet0;
     ___clang_call_terminate($452);
     // unreachable;
    }
    HEAP32[$424>>2] = 0;
    $eh$lpad$body$indexZ2D = $442;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  } while(0);
  $434 = (($this) + 20|0);
  $435 = HEAP32[$434>>2]|0;
  $436 = ($435|0)>(-1);
  if (!($436)) {
   ___resumeException($$1112|0);
   // unreachable;
  }
  $437 = HEAP32[$424>>2]|0;
  $438 = (($this) + 12|0);
  $439 = HEAP32[$438>>2]|0;
  HEAP32[$0>>2] = $439;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy42+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($437|0),($$byval_copy42|0));
  $440 = __THREW__; __THREW__ = 0;
  $441 = $440&1;
  if (!($441)) {
   HEAP32[$424>>2] = 0;
   ___resumeException($$1112|0);
   // unreachable;
  }
 }
 $454 = ___cxa_find_matching_catch(0|0)|0;
 $455 = tempRet0;
 $eh$lpad$body$indexZ2D = $454;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
}
function __ZN12TreeRenderer14ClearRenderersEv($this) {
 $this = $this|0;
 var $$byval_copy8 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__f$0$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $i$012 = 0, $i1$05 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 128|0);
 HEAP32[802520>>2] = $2;
 $3 = (($this) + 152|0);
 $4 = (($this) + 160|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $147 = $5;$i$012 = 0;
  while(1) {
   $7 = HEAP32[$3>>2]|0;
   $8 = (($7) + (($i$012*24)|0)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $16 = $147;
   } else {
    $11 = HEAP32[$9>>2]|0;
    $12 = (($11) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vi[$13 & 4095]($9);
    $$pre18 = HEAP32[$4>>2]|0;
    $16 = $$pre18;
   }
   $14 = (($i$012) + 1)|0;
   $15 = ($14>>>0)<($16>>>0);
   if ($15) {
    $147 = $16;$i$012 = $14;
   } else {
    break;
   }
  }
 }
 $17 = (($this) + 164|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)>(-1);
 if ($19) {
  $20 = HEAP32[$3>>2]|0;
  $21 = (($this) + 156|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$0>>2] = $22;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($20,$$byval_copy8);
  HEAP32[$3>>2] = 0;
 }
 HEAP32[$4>>2] = 0;
 HEAP32[$17>>2] = 0;
 $23 = (($this) + 180|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if ($25) {
  $26 = (($this) + 168|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($this) + 172|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[$0>>2] = $29;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy8);
  HEAP32[$26>>2] = 0;
 }
 $30 = (($this) + 176|0);
 HEAP32[$30>>2] = 0;
 HEAP32[$23>>2] = 0;
 $31 = (($this) + 196|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)>(-1);
 if ($33) {
  $34 = (($this) + 184|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($this) + 188|0);
  $37 = HEAP32[$36>>2]|0;
  HEAP32[$0>>2] = $37;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($35,$$byval_copy8);
  HEAP32[$34>>2] = 0;
 }
 $38 = (($this) + 192|0);
 HEAP32[$38>>2] = 0;
 HEAP32[$31>>2] = 0;
 $39 = (($this) + 204|0);
 __ZN15LODGroupManager18ClearInternalArrayEv($39);
 HEAP32[802520>>2] = $2;
 $40 = (($this) + 256|0);
 $41 = (($this) + 264|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0);
 if (!($43)) {
  $148 = $42;$i1$05 = 0;
  while(1) {
   $44 = HEAP32[$40>>2]|0;
   $45 = (($44) + (($i1$05*24)|0)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    $53 = $148;
   } else {
    $48 = HEAP32[$46>>2]|0;
    $49 = (($48) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    FUNCTION_TABLE_vi[$50 & 4095]($46);
    $$pre = HEAP32[$41>>2]|0;
    $53 = $$pre;
   }
   $51 = (($i1$05) + 1)|0;
   $52 = ($51>>>0)<($53>>>0);
   if ($52) {
    $148 = $53;$i1$05 = $51;
   } else {
    break;
   }
  }
 }
 $54 = (($this) + 268|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)>(-1);
 if ($56) {
  $57 = HEAP32[$40>>2]|0;
  $58 = (($this) + 260|0);
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$0>>2] = $59;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($57,$$byval_copy8);
  HEAP32[$40>>2] = 0;
 }
 HEAP32[$41>>2] = 0;
 HEAP32[$54>>2] = 0;
 $60 = (($this) + 284|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ($61|0)>(-1);
 if ($62) {
  $63 = (($this) + 272|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($this) + 276|0);
  $66 = HEAP32[$65>>2]|0;
  HEAP32[$0>>2] = $66;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($64,$$byval_copy8);
  HEAP32[$63>>2] = 0;
 }
 $67 = (($this) + 280|0);
 HEAP32[$67>>2] = 0;
 HEAP32[$60>>2] = 0;
 $68 = (($this) + 288|0);
 $69 = (($this) + 292|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ($70|0)==($68|0);
 if (!($71)) {
  $74 = $70;
  while(1) {
   $72 = (__Z24GetBillboardBatchManagerv()|0);
   $73 = (($74) + 8|0);
   __ZN21BillboardBatchManager10UnregisterERK4PPtrI14BillboardAssetE($72,$73);
   $75 = (($74) + 32|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($76|0)>(-1);
   if ($77) {
    $78 = (($74) + 20|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($74) + 24|0);
    $81 = HEAP32[$80>>2]|0;
    HEAP32[$0>>2] = $81;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($79,$$byval_copy8);
    HEAP32[$78>>2] = 0;
   }
   $82 = (($74) + 28|0);
   HEAP32[$82>>2] = 0;
   HEAP32[$75>>2] = 0;
   $83 = (($74) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ($84|0)==($68|0);
   if ($85) {
    break;
   } else {
    $74 = $84;
   }
  }
 }
 $86 = (($this) + 296|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = ($87|0)==(0);
 L40: do {
  if (!($88)) {
   $89 = HEAP32[$69>>2]|0;
   $90 = HEAP32[$68>>2]|0;
   $91 = (($90) + 4|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = HEAP32[$89>>2]|0;
   $94 = (($93) + 4|0);
   HEAP32[$94>>2] = $92;
   $95 = HEAP32[$89>>2]|0;
   $96 = HEAP32[$91>>2]|0;
   HEAP32[$96>>2] = $95;
   HEAP32[$86>>2] = 0;
   $__f$0$i$i = $89;
   while(1) {
    $97 = ($__f$0$i$i|0)==($68|0);
    if ($97) {
     break L40;
    }
    $98 = (($__f$0$i$i) + 4|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($__f$0$i$i) + 32|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ($101|0)>(-1);
    if ($102) {
     $103 = (($__f$0$i$i) + 20|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = (($__f$0$i$i) + 24|0);
     $106 = HEAP32[$105>>2]|0;
     HEAP32[$0>>2] = $106;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($104|0),($$byval_copy8|0));
     $107 = __THREW__; __THREW__ = 0;
     $108 = $107&1;
     if ($108) {
      label = 34;
      break;
     }
     HEAP32[$103>>2] = 0;
    }
    HEAP32[$1>>2] = 55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($__f$0$i$i|0),($$byval_copy8|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 33;
     break;
    } else {
     $__f$0$i$i = $99;
    }
   }
   if ((label|0) == 33) {
    $111 = ___cxa_find_matching_catch()|0;
    $112 = tempRet0;
    ___cxa_call_unexpected(($111|0));
    // unreachable;
   }
   else if ((label|0) == 34) {
    $113 = ___cxa_find_matching_catch()|0;
    $114 = tempRet0;
    ___cxa_call_unexpected(($113|0));
    // unreachable;
   }
  }
 } while(0);
 $115 = (($this) + 244|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (($this) + 248|0);
 while(1) {
  $118 = HEAP32[$117>>2]|0;
  $119 = ($118|0)==($116|0);
  if ($119) {
   break;
  }
  $120 = (($118) + -148|0);
  HEAP32[$117>>2] = $120;
  __THREW__ = 0;
  invoke_vi(3717,($120|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   label = 38;
   break;
  }
 }
 if ((label|0) == 38) {
  $123 = ___cxa_find_matching_catch()|0;
  $124 = tempRet0;
  ___cxa_call_unexpected(($123|0));
  // unreachable;
 }
 $125 = (($this) + 232|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (($this) + 236|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = ($128|0)==($126|0);
 if ($129) {
  __ZN19LinearAllocatorBase5purgeEb($2,0);
  STACKTOP = sp;return;
 }
 $131 = $128;
 while(1) {
  $130 = (($131) + -28|0);
  HEAP32[$127>>2] = $130;
  $132 = (($131) + -24|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(0|0);
  if ($134) {
   $136 = $130;
  } else {
   $137 = (($131) + -20|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ($138|0)==($133|0);
   if (!($139)) {
    $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $133;
    $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($138) + -72|0);
    $140 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($140)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
    $141 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i>>>0) / 72)&-1;
    $142 = $141 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($138) + (($142*72)|0)|0);
    HEAP32[$137>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
   }
   HEAP32[$0>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($133|0),($$byval_copy8|0));
   $143 = __THREW__; __THREW__ = 0;
   $144 = $143&1;
   if ($144) {
    label = 47;
    break;
   }
   $$pre$i$i$i = HEAP32[$127>>2]|0;
   $136 = $$pre$i$i$i;
  }
  $135 = ($136|0)==($126|0);
  if ($135) {
   label = 48;
   break;
  } else {
   $131 = $136;
  }
 }
 if ((label|0) == 47) {
  $145 = ___cxa_find_matching_catch()|0;
  $146 = tempRet0;
  ___cxa_call_unexpected(($145|0));
  // unreachable;
 }
 else if ((label|0) == 48) {
  __ZN19LinearAllocatorBase5purgeEb($2,0);
  STACKTOP = sp;return;
 }
}
function __ZNK12TreeDatabase9Prototype11GetLODGroupEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(2);
 if (!($3)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $5;
 $7 = HEAP32[560624>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  label = 11;
 } else {
  $9 = (($7) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($7) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  do {
   if ($13) {
    $14 = (($7) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($7) + 32|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + ($17<<3)|0);
    $34 = $18;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$7,$0);
    $19 = HEAP32[$pos$i$i$i$i>>2]|0;
    $20 = ($19|0)==(-1);
    $21 = (($7) + 28|0);
    $22 = HEAP32[$21>>2]|0;
    if ($20) {
     $23 = (($7) + 32|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($22) + ($24<<3)|0);
     $34 = $25;
     break;
    } else {
     $26 = (($22) + ($19<<3)|0);
     $34 = $26;
     break;
    }
   }
  } while(0);
  $27 = HEAP32[560624>>2]|0;
  $28 = (($27) + 28|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 32|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + ($31<<3)|0);
  $33 = ($34|0)==($32|0);
  if ($33) {
   label = 11;
  } else {
   $35 = (($34) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    label = 11;
   } else {
    $temp$0$i = $36;
   }
  }
 }
 if ((label|0) == 11) {
  $38 = (__Z31ReadObjectFromPersistentManageri($5)|0);
  $temp$0$i = $38;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN12TreeRenderer25CreateLODRenderersForTreeEi($this,$treeIndex) {
 $this = $this|0;
 $treeIndex = $treeIndex|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i29 = 0, $$0$i$i652 = 0, $$0$i3459 = 0, $$0$i61 = 0, $$01 = 0, $$byval_copy16 = 0, $$in = 0, $$neg2$i$i$i$i$i = 0, $$off0 = 0, $$pre = 0, $$pre$i = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = Math_fround(0), $458 = 0, $459 = Math_fround(0), $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = Math_fround(0), $466 = Math_fround(0), $467 = 0, $468 = Math_fround(0), $469 = Math_fround(0), $47 = 0, $470 = 0, $471 = Math_fround(0), $472 = Math_fround(0), $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = Math_fround(0), $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = Math_fround(0), $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = Math_fround(0), $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = Math_fround(0), $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = Math_fround(0), $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = Math_fround(0), $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0);
 var $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $eh$lpad$body$i$i$i$i$indexZ2D = 0, $eh$lpad$body$index10Z2D = 0, $eh$lpad$body$indexZ2D = 0, $i$063 = 0, $localAABB = 0, $lodIndex$064 = 0, $lodInstanceDataIndex$0 = 0, $or$cond = 0, $phitmp = 0, $phitmp$i = 0, $phitmp$i17 = 0, $phitmp$i26 = 0, $temp$0$i = 0, $temp$0$i$i16 = 0;
 var $temp$0$i11 = 0, $temp$0$i40 = 0, $temp$0$i47 = 0, $translationOnly = 0, $treeMat = 0, $treePosition = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $$byval_copy16 = sp + 368|0;
 $0 = sp + 360|0;
 $1 = sp + 356|0;
 $2 = sp + 208|0;
 $3 = sp + 204|0;
 $4 = sp + 200|0;
 $5 = sp + 196|0;
 $6 = sp + 192|0;
 $7 = sp + 188|0;
 $8 = sp + 180|0;
 $treePosition = sp + 168|0;
 $treeMat = sp + 104|0;
 $9 = sp + 96|0;
 $localAABB = sp + 72|0;
 $translationOnly = sp + 8|0;
 $10 = sp;
 $11 = sp + 184|0;
 $12 = HEAP32[$this>>2]|0;
 $13 = (($12) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + (($treeIndex*40)|0)|0);
 $16 = ((($14) + (($treeIndex*40)|0)|0) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($12) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($17<<7)|0);
 $21 = (($this) + 232|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ((($19) + ($17<<7)|0) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$8>>2] = $24;
 $25 = HEAP32[560624>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  label = 9;
 } else {
  $27 = (($25) + 36|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($25) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28|0)==($30|0);
  do {
   if ($31) {
    $32 = (($25) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($25) + 32|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($33) + ($35<<3)|0);
    $52 = $36;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$25,$8);
    $37 = HEAP32[$$byval_copy16>>2]|0;
    $38 = ($37|0)==(-1);
    $39 = (($25) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    if ($38) {
     $41 = (($25) + 32|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($40) + ($42<<3)|0);
     $52 = $43;
     break;
    } else {
     $44 = (($40) + ($37<<3)|0);
     $52 = $44;
     break;
    }
   }
  } while(0);
  $45 = HEAP32[560624>>2]|0;
  $46 = (($45) + 28|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + 32|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($47) + ($49<<3)|0);
  $51 = ($52|0)==($50|0);
  if ($51) {
   label = 9;
  } else {
   $53 = (($52) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    label = 9;
   } else {
    $temp$0$i = $54;
   }
  }
 }
 if ((label|0) == 9) {
  $56 = HEAP32[$23>>2]|0;
  $57 = (__Z31ReadObjectFromPersistentManageri($56)|0);
  $temp$0$i = $57;
 }
 $58 = Math_fround(HEAPF32[$15>>2]);
 $59 = (($this) + 44|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($58 * $60);
 $62 = ((($14) + (($treeIndex*40)|0)|0) + 4|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = (($this) + 48|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($63 * $65);
 $67 = ((($14) + (($treeIndex*40)|0)|0) + 8|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 $69 = (($this) + 52|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($68 * $70);
 $72 = (($this) + 56|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($61 + $73);
 $75 = (($this) + 60|0);
 $76 = Math_fround(HEAPF32[$75>>2]);
 $77 = Math_fround($66 + $76);
 $78 = (($this) + 64|0);
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = Math_fround($71 + $79);
 HEAPF32[$treePosition>>2] = $74;
 $81 = (($treePosition) + 4|0);
 HEAPF32[$81>>2] = $77;
 $82 = (($treePosition) + 8|0);
 HEAPF32[$82>>2] = $80;
 __ZNK12TreeDatabase9Prototype21GetTreeInstanceMatrixER10Matrix4x4fRK8Vector3fRK12TreeInstance($20,$treeMat,$treePosition,$15);
 $83 = ((($19) + ($17<<7)|0) + 12|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($84|0)==(0);
 do {
  if ($85) {
   $$0$i$i652 = 0;$$off0 = 0;
  } else {
   HEAP32[$6>>2] = $84;
   $86 = HEAP32[560624>>2]|0;
   $87 = ($86|0)==(0|0);
   if ($87) {
    label = 19;
   } else {
    $88 = (($86) + 36|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($86) + 4|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($89|0)==($91|0);
    do {
     if ($92) {
      $93 = (($86) + 28|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (($86) + 32|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($94) + ($96<<3)|0);
      $113 = $97;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$86,$6);
      $98 = HEAP32[$$byval_copy16>>2]|0;
      $99 = ($98|0)==(-1);
      $100 = (($86) + 28|0);
      $101 = HEAP32[$100>>2]|0;
      if ($99) {
       $102 = (($86) + 32|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = (($101) + ($103<<3)|0);
       $113 = $104;
       break;
      } else {
       $105 = (($101) + ($98<<3)|0);
       $113 = $105;
       break;
      }
     }
    } while(0);
    $106 = HEAP32[560624>>2]|0;
    $107 = (($106) + 28|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = (($106) + 32|0);
    $110 = HEAP32[$109>>2]|0;
    $111 = (($108) + ($110<<3)|0);
    $112 = ($113|0)==($111|0);
    if ($112) {
     label = 19;
    } else {
     $114 = (($113) + 4|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = ($115|0)==(0|0);
     if ($116) {
      label = 19;
     } else {
      $121 = $106;
     }
    }
   }
   if ((label|0) == 19) {
    $117 = HEAP32[$83>>2]|0;
    $118 = (__Z31ReadObjectFromPersistentManageri($117)|0);
    $phitmp$i = ($118|0)==(0|0);
    if ($phitmp$i) {
     $$0$i$i652 = 0;$$off0 = 0;
     break;
    }
    $$pre = HEAP32[560624>>2]|0;
    $121 = $$pre;
   }
   $119 = HEAP32[$83>>2]|0;
   HEAP32[$5>>2] = $119;
   $120 = ($121|0)==(0|0);
   if ($120) {
    label = 29;
   } else {
    $122 = (($121) + 36|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = (($121) + 4|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ($123|0)==($125|0);
    do {
     if ($126) {
      $127 = (($121) + 28|0);
      $128 = HEAP32[$127>>2]|0;
      $129 = (($121) + 32|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = (($128) + ($130<<3)|0);
      $147 = $131;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$121,$5);
      $132 = HEAP32[$$byval_copy16>>2]|0;
      $133 = ($132|0)==(-1);
      $134 = (($121) + 28|0);
      $135 = HEAP32[$134>>2]|0;
      if ($133) {
       $136 = (($121) + 32|0);
       $137 = HEAP32[$136>>2]|0;
       $138 = (($135) + ($137<<3)|0);
       $147 = $138;
       break;
      } else {
       $139 = (($135) + ($132<<3)|0);
       $147 = $139;
       break;
      }
     }
    } while(0);
    $140 = HEAP32[560624>>2]|0;
    $141 = (($140) + 28|0);
    $142 = HEAP32[$141>>2]|0;
    $143 = (($140) + 32|0);
    $144 = HEAP32[$143>>2]|0;
    $145 = (($142) + ($144<<3)|0);
    $146 = ($147|0)==($145|0);
    if ($146) {
     label = 29;
    } else {
     $148 = (($147) + 4|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = ($149|0)==(0|0);
     if ($150) {
      label = 29;
     } else {
      $temp$0$i11 = $149;
     }
    }
   }
   if ((label|0) == 29) {
    $151 = HEAP32[$83>>2]|0;
    $152 = (__Z31ReadObjectFromPersistentManageri($151)|0);
    $temp$0$i11 = $152;
   }
   $153 = (($temp$0$i11) + 284|0);
   $154 = HEAP32[$153>>2]|0;
   $155 = ($154|0)==(0);
   if ($155) {
    $$0$i$i652 = -1;$$off0 = 0;
   } else {
    HEAP32[$4>>2] = $154;
    $156 = HEAP32[560624>>2]|0;
    $157 = ($156|0)==(0|0);
    if ($157) {
     label = 39;
    } else {
     $158 = (($156) + 36|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = (($156) + 4|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = ($159|0)==($161|0);
     do {
      if ($162) {
       $163 = (($156) + 28|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = (($156) + 32|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = (($164) + ($166<<3)|0);
       $183 = $167;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$156,$4);
       $168 = HEAP32[$$byval_copy16>>2]|0;
       $169 = ($168|0)==(-1);
       $170 = (($156) + 28|0);
       $171 = HEAP32[$170>>2]|0;
       if ($169) {
        $172 = (($156) + 32|0);
        $173 = HEAP32[$172>>2]|0;
        $174 = (($171) + ($173<<3)|0);
        $183 = $174;
        break;
       } else {
        $175 = (($171) + ($168<<3)|0);
        $183 = $175;
        break;
       }
      }
     } while(0);
     $176 = HEAP32[560624>>2]|0;
     $177 = (($176) + 28|0);
     $178 = HEAP32[$177>>2]|0;
     $179 = (($176) + 32|0);
     $180 = HEAP32[$179>>2]|0;
     $181 = (($178) + ($180<<3)|0);
     $182 = ($183|0)==($181|0);
     if ($182) {
      label = 39;
     } else {
      $184 = (($183) + 4|0);
      $185 = HEAP32[$184>>2]|0;
      $186 = ($185|0)==(0|0);
      if ($186) {
       label = 39;
      } else {
       $temp$0$i$i16 = $185;
      }
     }
    }
    if ((label|0) == 39) {
     $187 = HEAP32[$153>>2]|0;
     $188 = (__Z31ReadObjectFromPersistentManageri($187)|0);
     $temp$0$i$i16 = $188;
    }
    $phitmp$i17 = ($temp$0$i$i16|0)!=(0|0);
    $$0$i$i652 = -1;$$off0 = $phitmp$i17;
   }
  }
 } while(0);
 $189 = (($temp$0$i) + 48|0);
 $190 = HEAP32[$189>>2]|0;
 $191 = (($temp$0$i) + 44|0);
 $192 = HEAP32[$191>>2]|0;
 $193 = $190;
 $194 = $192;
 $195 = (($193) - ($194))|0;
 $196 = (($195|0) / 28)&-1;
 $197 = (($196) + ($$0$i$i652))|0;
 $198 = ((($22) + (($17*28)|0)|0) + 16|0);
 $199 = HEAP32[$198>>2]|0;
 $200 = ($199|0)==(0);
 L58: do {
  if ($200) {
   $lodInstanceDataIndex$0 = -1;
  } else {
   $201 = (($this) + 244|0);
   $202 = (($this) + 248|0);
   $203 = HEAP32[$202>>2]|0;
   $204 = HEAP32[$201>>2]|0;
   $205 = $203;
   $206 = $204;
   $207 = (($205) - ($206))|0;
   $208 = (($207|0) / 148)&-1;
   $209 = (($2) + 4|0);
   ;HEAP32[$209+0>>2]=0|0;HEAP32[$209+4>>2]=0|0;HEAP32[$209+8>>2]=0|0;HEAP32[$209+12>>2]=0|0;HEAP32[$209+16>>2]=0|0;HEAP32[$209+20>>2]=0|0;
   $210 = (($2) + 32|0);
   __ZN25LightweightSTWindInstanceC2Ev($210);
   $211 = HEAP32[628440>>2]|0;
   $212 = (($2) + 76|0);
   HEAP32[$212>>2] = 0;
   $213 = (($2) + 80|0);
   HEAP32[$213>>2] = $211;
   $214 = (($2) + 84|0);
   HEAP32[$214>>2] = 0;
   $215 = (($2) + 88|0);
   HEAP32[$215>>2] = 0;
   $216 = (($2) + 92|0);
   HEAP32[$216>>2] = 0;
   $217 = (($2) + 96|0);
   HEAP32[$217>>2] = $211;
   $218 = (($2) + 100|0);
   HEAP32[$218>>2] = 0;
   $219 = (($2) + 104|0);
   HEAP32[$219>>2] = 0;
   $220 = (($2) + 108|0);
   $221 = HEAP32[641904>>2]|0;
   HEAP32[$220>>2] = $221;
   $222 = (($2) + 112|0);
   HEAP32[$222>>2] = 0;
   $223 = (($2) + 116|0);
   HEAP32[$223>>2] = $211;
   $224 = (($2) + 120|0);
   HEAP32[$224>>2] = 0;
   $225 = (($2) + 124|0);
   HEAP32[$225>>2] = 0;
   $226 = (($2) + 128|0);
   HEAP32[$226>>2] = 0;
   $227 = (($2) + 132|0);
   HEAP32[$227>>2] = $211;
   $228 = (($2) + 136|0);
   HEAP32[$228>>2] = 0;
   $229 = (($2) + 140|0);
   HEAP32[$229>>2] = 0;
   $230 = (($2) + 144|0);
   HEAP32[$230>>2] = $221;
   HEAP16[$2>>1] = 0;
   $231 = HEAP32[$16>>2]|0;
   $232 = $231&65535;
   $233 = (($2) + 2|0);
   HEAP16[$233>>1] = $232;
   $234 = ((($19) + ($17<<7)|0) + 100|0);
   __THREW__ = 0;
   invoke_viii(2038,($234|0),($treeMat|0),($209|0));
   $235 = __THREW__; __THREW__ = 0;
   $236 = $235&1;
   L60: do {
    if ($236) {
     label = 64;
    } else {
     $237 = ((($22) + (($17*28)|0)|0) + 20|0);
     $238 = HEAP32[$237>>2]|0;
     $239 = (($2) + 28|0);
     HEAP32[$239>>2] = $238;
     $240 = HEAP32[$202>>2]|0;
     $241 = (($this) + 252|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = ($240|0)==($242|0);
     if ($243) {
      __THREW__ = 0;
      invoke_vii(3424,($201|0),($2|0));
      $288 = __THREW__; __THREW__ = 0;
      $289 = $288&1;
      if ($289) {
       label = 64;
       break;
      }
     } else {
      $244 = ($240|0)==(0|0);
      do {
       if ($244) {
        $287 = 0;
       } else {
        dest=$240+0|0; src=$2+0|0; stop=dest+76|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
        $245 = (($240) + 76|0);
        $246 = (($2) + 76|0);
        __THREW__ = 0;
        invoke_vii(3423,($245|0),($246|0));
        $247 = __THREW__; __THREW__ = 0;
        $248 = $247&1;
        if ($248) {
         label = 64;
         break L60;
        }
        $249 = (($240) + 112|0);
        $250 = (($2) + 112|0);
        __THREW__ = 0;
        invoke_vii(3423,($249|0),($250|0));
        $251 = __THREW__; __THREW__ = 0;
        $252 = $251&1;
        if (!($252)) {
         $$pre$i = HEAP32[$202>>2]|0;
         $287 = $$pre$i;
         break;
        }
        $253 = ___cxa_find_matching_catch()|0;
        $254 = tempRet0;
        $255 = (($240) + 104|0);
        $256 = HEAP32[$255>>2]|0;
        $257 = ($256|0)>(-1);
        do {
         if ($257) {
          $258 = (($240) + 92|0);
          $259 = HEAP32[$258>>2]|0;
          $260 = (($240) + 96|0);
          $261 = HEAP32[$260>>2]|0;
          HEAP32[$1>>2] = $261;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
          invoke_vii(2591,($259|0),($$byval_copy16|0));
          $262 = __THREW__; __THREW__ = 0;
          $263 = $262&1;
          if (!($263)) {
           HEAP32[$258>>2] = 0;
           break;
          }
          $272 = ___cxa_find_matching_catch(0|0)|0;
          $273 = tempRet0;
          $274 = (($240) + 88|0);
          $275 = HEAP32[$274>>2]|0;
          $276 = ($275|0)>(-1);
          if (!($276)) {
           $eh$lpad$body$i$i$i$i$indexZ2D = $272;
           ___clang_call_terminate($eh$lpad$body$i$i$i$i$indexZ2D);
           // unreachable;
          }
          $277 = HEAP32[$245>>2]|0;
          $278 = (($240) + 80|0);
          $279 = HEAP32[$278>>2]|0;
          HEAP32[$0>>2] = $279;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
          invoke_vii(2591,($277|0),($$byval_copy16|0));
          $280 = __THREW__; __THREW__ = 0;
          $281 = $280&1;
          if ($281) {
           $282 = ___cxa_find_matching_catch(0|0)|0;
           $283 = tempRet0;
           ___clang_call_terminate($282);
           // unreachable;
          }
          HEAP32[$245>>2] = 0;
          $eh$lpad$body$i$i$i$i$indexZ2D = $272;
          ___clang_call_terminate($eh$lpad$body$i$i$i$i$indexZ2D);
          // unreachable;
         }
        } while(0);
        $264 = (($240) + 88|0);
        $265 = HEAP32[$264>>2]|0;
        $266 = ($265|0)>(-1);
        if (!($266)) {
         $eh$lpad$body$index10Z2D = $254;$eh$lpad$body$indexZ2D = $253;
         break L60;
        }
        $267 = HEAP32[$245>>2]|0;
        $268 = (($240) + 80|0);
        $269 = HEAP32[$268>>2]|0;
        HEAP32[$0>>2] = $269;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($267|0),($$byval_copy16|0));
        $270 = __THREW__; __THREW__ = 0;
        $271 = $270&1;
        if (!($271)) {
         HEAP32[$245>>2] = 0;
         $eh$lpad$body$index10Z2D = $254;$eh$lpad$body$indexZ2D = $253;
         break L60;
        }
        $284 = ___cxa_find_matching_catch(0|0)|0;
        $285 = tempRet0;
        $eh$lpad$body$i$i$i$i$indexZ2D = $284;
        ___clang_call_terminate($eh$lpad$body$i$i$i$i$indexZ2D);
        // unreachable;
       }
      } while(0);
      $286 = (($287) + 148|0);
      HEAP32[$202>>2] = $286;
     }
     $290 = ($197|0)>(0);
     if ($290) {
      $291 = HEAP32[$202>>2]|0;
      $292 = (($291) + -72|0);
      __THREW__ = 0;
      invoke_vii(3425,($292|0),0);
      $293 = __THREW__; __THREW__ = 0;
      $294 = $293&1;
      if ($294) {
       label = 64;
       break;
      }
     }
     if ($$off0) {
      $299 = HEAP32[$202>>2]|0;
      $300 = (($299) + -36|0);
      __THREW__ = 0;
      invoke_vii(3425,($300|0),1);
      $301 = __THREW__; __THREW__ = 0;
      $302 = $301&1;
      if ($302) {
       label = 64;
       break;
      }
     }
     __ZN12TreeRenderer19LODTreeInstanceDataD2Ev($2);
     $lodInstanceDataIndex$0 = $208;
     break L58;
    }
   } while(0);
   if ((label|0) == 64) {
    $295 = ___cxa_find_matching_catch()|0;
    $296 = tempRet0;
    $eh$lpad$body$index10Z2D = $296;$eh$lpad$body$indexZ2D = $295;
   }
   __THREW__ = 0;
   invoke_vi(3717,($2|0));
   $297 = __THREW__; __THREW__ = 0;
   $298 = $297&1;
   if ($298) {
    $666 = ___cxa_find_matching_catch(0|0)|0;
    $667 = tempRet0;
    ___clang_call_terminate($666);
    // unreachable;
   } else {
    $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index10Z2D;
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $303 = (($this) + 204|0);
 $304 = (__ZN15LODGroupManager11AddLODGroupER8LODGroupRK8Vector3f($303,$temp$0$i,$treePosition)|0);
 $305 = ($197|0)>(0);
 L104: do {
  if ($305) {
   $306 = ((($22) + (($17*28)|0)|0) + 4|0);
   $307 = ((($22) + (($17*28)|0)|0) + 8|0);
   $308 = (($this) + 128|0);
   $309 = (($this) + 200|0);
   $310 = (($this) + 256|0);
   $311 = $304&65535;
   $312 = (($this) + 272|0);
   $lodIndex$064 = 0;
   L106: while(1) {
    $313 = (__ZNK8LODGroup6GetLODEi($temp$0$i,$lodIndex$064)|0);
    $314 = (($313) + 20|0);
    $315 = HEAP32[$314>>2]|0;
    $316 = ($315|0)==(0);
    if (!($316)) {
     $317 = (($313) + 12|0);
     $i$063 = 0;
     while(1) {
      $318 = HEAP32[$317>>2]|0;
      $319 = (($318) + ($i$063<<2)|0);
      $320 = HEAP32[$319>>2]|0;
      $321 = (__Z23dynamic_instanceID_castIP12MeshRendererET_i($320)|0);
      $322 = ($321|0)==(0|0);
      do {
       if (!($322)) {
        __ZNK12MeshRenderer13GetSharedMeshEv($9,$321);
        $323 = HEAP32[$9>>2]|0;
        $324 = ($323|0)==(0);
        if (!($324)) {
         HEAP32[$3>>2] = $323;
         $325 = HEAP32[560624>>2]|0;
         $326 = ($325|0)==(0|0);
         if ($326) {
          label = 83;
         } else {
          $327 = (($325) + 36|0);
          $328 = HEAP32[$327>>2]|0;
          $329 = (($325) + 4|0);
          $330 = HEAP32[$329>>2]|0;
          $331 = ($328|0)==($330|0);
          do {
           if ($331) {
            $332 = (($325) + 28|0);
            $333 = HEAP32[$332>>2]|0;
            $334 = (($325) + 32|0);
            $335 = HEAP32[$334>>2]|0;
            $336 = (($333) + ($335<<3)|0);
            $352 = $336;
           } else {
            __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$325,$3);
            $337 = HEAP32[$$byval_copy16>>2]|0;
            $338 = ($337|0)==(-1);
            $339 = (($325) + 28|0);
            $340 = HEAP32[$339>>2]|0;
            if ($338) {
             $341 = (($325) + 32|0);
             $342 = HEAP32[$341>>2]|0;
             $343 = (($340) + ($342<<3)|0);
             $352 = $343;
             break;
            } else {
             $344 = (($340) + ($337<<3)|0);
             $352 = $344;
             break;
            }
           }
          } while(0);
          $345 = HEAP32[560624>>2]|0;
          $346 = (($345) + 28|0);
          $347 = HEAP32[$346>>2]|0;
          $348 = (($345) + 32|0);
          $349 = HEAP32[$348>>2]|0;
          $350 = (($347) + ($349<<3)|0);
          $351 = ($352|0)==($350|0);
          if ($351) {
           label = 83;
          } else {
           $353 = (($352) + 4|0);
           $354 = HEAP32[$353>>2]|0;
           $355 = ($354|0)==(0|0);
           if ($355) {
            label = 83;
           }
          }
         }
         if ((label|0) == 83) {
          label = 0;
          $356 = HEAP32[$9>>2]|0;
          $357 = (__Z31ReadObjectFromPersistentManageri($356)|0);
          $phitmp$i26 = ($357|0)==(0|0);
          if ($phitmp$i26) {
           break;
          }
         }
         $358 = HEAP32[$306>>2]|0;
         $359 = HEAP32[$307>>2]|0;
         $360 = ($359|0)==($358|0);
         if ($360) {
          $374 = $358;
         } else {
          $361 = $358;
          $362 = $359;
          $363 = (($362) - ($361))|0;
          $364 = (($363|0) / 72)&-1;
          $367 = $358;$__len$03$i$i$i$i$i = $364;
          while(1) {
           $365 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
           $366 = (($367) + (($365*72)|0)|0);
           $368 = HEAP32[$366>>2]|0;
           $369 = ($368|0)<($320|0);
           if ($369) {
            $$sum$i$i$i$i$i = (($365) + 1)|0;
            $370 = (($367) + (($$sum$i$i$i$i$i*72)|0)|0);
            $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
            $371 = (($$neg2$i$i$i$i$i) - ($365))|0;
            $668 = $370;$__len$0$be$i$i$i$i$i = $371;
           } else {
            $668 = $367;$__len$0$be$i$i$i$i$i = $365;
           }
           $372 = ($__len$0$be$i$i$i$i$i|0)==(0);
           if ($372) {
            $374 = $668;
            break;
           } else {
            $367 = $668;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
           }
          }
         }
         $373 = ($374|0)==($359|0);
         if ($373) {
          $378 = $359;
         } else {
          $375 = HEAP32[$374>>2]|0;
          $376 = ($320|0)<($375|0);
          $$ = $376 ? $359 : $374;
          $378 = $$;
         }
         $377 = (($378) + 4|0);
         __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($treeMat,$377,$$byval_copy16);
         HEAP32[802520>>2] = $308;
         $379 = (__ZN22ForwardLinearAllocator8allocateEjj($308,272,4)|0);
         __THREW__ = 0;
         invoke_viiiiii(133,($379|0),($this|0),($treeIndex|0),($321|0),($$byval_copy16|0),($lodInstanceDataIndex$0|0));
         $380 = __THREW__; __THREW__ = 0;
         $381 = $380&1;
         if ($381) {
          break L106;
         }
         $382 = HEAP32[$309>>2]|0;
         $383 = ($382|0)==(-1);
         if (!($383)) {
          $384 = (($379) + 176|0);
          $385 = HEAP32[$384>>2]|0;
          $386 = ($385|0)==(0);
          if (!($386)) {
           HEAP32[$384>>2] = 2;
           $387 = (($379) + 252|0);
           $388 = HEAP32[$387>>2]|0;
           $389 = (($388) + ($382))|0;
           $390 = (($379) + 180|0);
           HEAP32[$390>>2] = $389;
          }
         }
         $393 = (__ZN13dynamic_arrayI9SceneNodeLj4EE19push_back_constructEv($310)|0);
         HEAP32[$393>>2] = $379;
         $394 = HEAP32[$379>>2]|0;
         $395 = (($394) + 32|0);
         $396 = HEAP32[$395>>2]|0;
         $397 = (FUNCTION_TABLE_ii[$396 & 4095]($379)|0);
         $398 = (($393) + 4|0);
         HEAP32[$398>>2] = $397;
         $399 = HEAP32[$303>>2]|0;
         $400 = $399&65535;
         $401 = (($393) + 12|0);
         HEAP16[$401>>1] = $400;
         $402 = (($393) + 14|0);
         HEAP16[$402>>1] = $311;
         $403 = (($378) + 68|0);
         $404 = HEAP32[$403>>2]|0;
         $405 = (($393) + 16|0);
         HEAP32[$405>>2] = $404;
         $406 = (__ZN13dynamic_arrayI4AABBLj4EE9push_backEv($312)|0);
         __ZN12BaseRenderer12GetWorldAABBER4AABB($379,$406);
        }
       }
      } while(0);
      $407 = (($i$063) + 1)|0;
      $408 = HEAP32[$314>>2]|0;
      $409 = ($407>>>0)<($408>>>0);
      if ($409) {
       $i$063 = $407;
      } else {
       break;
      }
     }
    }
    $410 = (($lodIndex$064) + 1)|0;
    $411 = ($410|0)<($197|0);
    if ($411) {
     $lodIndex$064 = $410;
    } else {
     break L104;
    }
   }
   $391 = ___cxa_find_matching_catch()|0;
   $392 = tempRet0;
   $$0 = $391;$$01 = $392;
   ___resumeException($$0|0);
   // unreachable;
  }
 } while(0);
 if (!($$off0)) {
  STACKTOP = sp;return;
 }
 $412 = HEAP32[$83>>2]|0;
 HEAP32[$0>>2] = $412;
 $413 = HEAP32[560624>>2]|0;
 $414 = ($413|0)==(0|0);
 if ($414) {
  label = 108;
 } else {
  $415 = (($413) + 36|0);
  $416 = HEAP32[$415>>2]|0;
  $417 = (($413) + 4|0);
  $418 = HEAP32[$417>>2]|0;
  $419 = ($416|0)==($418|0);
  do {
   if ($419) {
    $420 = (($413) + 28|0);
    $421 = HEAP32[$420>>2]|0;
    $422 = (($413) + 32|0);
    $423 = HEAP32[$422>>2]|0;
    $424 = (($421) + ($423<<3)|0);
    $440 = $424;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$413,$0);
    $425 = HEAP32[$$byval_copy16>>2]|0;
    $426 = ($425|0)==(-1);
    $427 = (($413) + 28|0);
    $428 = HEAP32[$427>>2]|0;
    if ($426) {
     $429 = (($413) + 32|0);
     $430 = HEAP32[$429>>2]|0;
     $431 = (($428) + ($430<<3)|0);
     $440 = $431;
     break;
    } else {
     $432 = (($428) + ($425<<3)|0);
     $440 = $432;
     break;
    }
   }
  } while(0);
  $433 = HEAP32[560624>>2]|0;
  $434 = (($433) + 28|0);
  $435 = HEAP32[$434>>2]|0;
  $436 = (($433) + 32|0);
  $437 = HEAP32[$436>>2]|0;
  $438 = (($435) + ($437<<3)|0);
  $439 = ($440|0)==($438|0);
  if ($439) {
   label = 108;
  } else {
   $441 = (($440) + 4|0);
   $442 = HEAP32[$441>>2]|0;
   $443 = ($442|0)==(0|0);
   if ($443) {
    label = 108;
   } else {
    $temp$0$i47 = $442;
   }
  }
 }
 if ((label|0) == 108) {
  $444 = HEAP32[$83>>2]|0;
  $445 = (__Z31ReadObjectFromPersistentManageri($444)|0);
  $temp$0$i47 = $445;
 }
 $446 = (($temp$0$i47) + 284|0);
 $447 = HEAP32[$446>>2]|0;
 $448 = (($this) + 288|0);
 $449 = (($this) + 292|0);
 $$in = $449;
 while(1) {
  $450 = HEAP32[$$in>>2]|0;
  $451 = (($450) + 8|0);
  $452 = HEAP32[$451>>2]|0;
  $453 = ($452|0)==($447|0);
  $454 = ($450|0)==($448|0);
  $or$cond = $453 | $454;
  $455 = (($450) + 4|0);
  if ($or$cond) {
   break;
  } else {
   $$in = $455;
  }
 }
 ;HEAP32[$localAABB+0>>2]=0|0;HEAP32[$localAABB+4>>2]=0|0;HEAP32[$localAABB+8>>2]=0|0;HEAP32[$localAABB+12>>2]=0|0;HEAP32[$localAABB+16>>2]=0|0;HEAP32[$localAABB+20>>2]=0|0;
 $456 = ((($14) + (($treeIndex*40)|0)|0) + 12|0);
 $457 = Math_fround(HEAPF32[$456>>2]);
 $458 = ((($14) + (($treeIndex*40)|0)|0) + 16|0);
 $459 = Math_fround(HEAPF32[$458>>2]);
 $460 = HEAP32[$this>>2]|0;
 $461 = HEAP32[$16>>2]|0;
 $462 = (($460) + 28|0);
 $463 = HEAP32[$462>>2]|0;
 $464 = ((($463) + ($461<<7)|0) + 112|0);
 $465 = Math_fround(HEAPF32[$464>>2]);
 $466 = Math_fround($457 * $465);
 $467 = ((($463) + ($461<<7)|0) + 116|0);
 $468 = Math_fround(HEAPF32[$467>>2]);
 $469 = Math_fround($459 * $468);
 $470 = ((($463) + ($461<<7)|0) + 120|0);
 $471 = Math_fround(HEAPF32[$470>>2]);
 $472 = Math_fround($457 * $471);
 ;HEAP32[$localAABB+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$localAABB+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$localAABB+8>>2]=HEAP32[616680+8>>2]|0;
 $473 = (($localAABB) + 12|0);
 HEAPF32[$473>>2] = $466;
 $474 = (($localAABB) + 16|0);
 HEAPF32[$474>>2] = $469;
 $475 = (($localAABB) + 20|0);
 HEAPF32[$475>>2] = $472;
 $476 = (($this) + 128|0);
 HEAP32[802520>>2] = $476;
 $477 = (__ZN22ForwardLinearAllocator8allocateEjj($476,276,4)|0);
 $478 = HEAP32[$83>>2]|0;
 HEAP32[$1>>2] = $478;
 $479 = HEAP32[560624>>2]|0;
 $480 = ($479|0)==(0|0);
 if ($480) {
  label = 119;
 } else {
  $481 = (($479) + 36|0);
  $482 = HEAP32[$481>>2]|0;
  $483 = (($479) + 4|0);
  $484 = HEAP32[$483>>2]|0;
  $485 = ($482|0)==($484|0);
  do {
   if ($485) {
    $486 = (($479) + 28|0);
    $487 = HEAP32[$486>>2]|0;
    $488 = (($479) + 32|0);
    $489 = HEAP32[$488>>2]|0;
    $490 = (($487) + ($489<<3)|0);
    $506 = $490;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$479,$1);
    $491 = HEAP32[$$byval_copy16>>2]|0;
    $492 = ($491|0)==(-1);
    $493 = (($479) + 28|0);
    $494 = HEAP32[$493>>2]|0;
    if ($492) {
     $495 = (($479) + 32|0);
     $496 = HEAP32[$495>>2]|0;
     $497 = (($494) + ($496<<3)|0);
     $506 = $497;
     break;
    } else {
     $498 = (($494) + ($491<<3)|0);
     $506 = $498;
     break;
    }
   }
  } while(0);
  $499 = HEAP32[560624>>2]|0;
  $500 = (($499) + 28|0);
  $501 = HEAP32[$500>>2]|0;
  $502 = (($499) + 32|0);
  $503 = HEAP32[$502>>2]|0;
  $504 = (($501) + ($503<<3)|0);
  $505 = ($506|0)==($504|0);
  if ($505) {
   label = 119;
  } else {
   $507 = (($506) + 4|0);
   $508 = HEAP32[$507>>2]|0;
   $509 = ($508|0)==(0|0);
   if ($509) {
    label = 119;
   } else {
    $temp$0$i40 = $508;
    label = 120;
   }
  }
 }
 if ((label|0) == 119) {
  $510 = HEAP32[$83>>2]|0;
  __THREW__ = 0;
  $511 = (invoke_ii(3215,($510|0))|0);
  $512 = __THREW__; __THREW__ = 0;
  $513 = $512&1;
  if (!($513)) {
   $temp$0$i40 = $511;
   label = 120;
  }
 }
 if ((label|0) == 120) {
  $514 = (($temp$0$i40) + 28|0);
  $515 = (($514) + 176|0);
  $516 = HEAP32[$515>>2]|0;
  $517 = ($516|0)==(1);
  __THREW__ = 0;
  invoke_viiiiii(134,($477|0),($this|0),($treeIndex|0),($lodInstanceDataIndex$0|0),($447|0),($517|0));
  $518 = __THREW__; __THREW__ = 0;
  $519 = $518&1;
  if (!($519)) {
   (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($translationOnly,$treePosition)|0);
   HEAP32[$10>>2] = 0;
   __ZN20IntermediateRenderer10InitializeERK10Matrix4x4fRK4AABB4PPtrIN5Unity8MaterialEEibb($477,$translationOnly,$localAABB,$10,0,0,0);
   $520 = (($450) + 12|0);
   $521 = HEAP32[$520>>2]|0;
   $522 = ($521|0)==(0);
   do {
    if ($522) {
     label = 132;
    } else {
     HEAP32[$2>>2] = $521;
     $523 = HEAP32[560624>>2]|0;
     $524 = ($523|0)==(0|0);
     if ($524) {
      label = 130;
     } else {
      $525 = (($523) + 36|0);
      $526 = HEAP32[$525>>2]|0;
      $527 = (($523) + 4|0);
      $528 = HEAP32[$527>>2]|0;
      $529 = ($526|0)==($528|0);
      do {
       if ($529) {
        $530 = (($523) + 28|0);
        $531 = HEAP32[$530>>2]|0;
        $532 = (($523) + 32|0);
        $533 = HEAP32[$532>>2]|0;
        $534 = (($531) + ($533<<3)|0);
        $550 = $534;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$523,$2);
        $535 = HEAP32[$$byval_copy16>>2]|0;
        $536 = ($535|0)==(-1);
        $537 = (($523) + 28|0);
        $538 = HEAP32[$537>>2]|0;
        if ($536) {
         $539 = (($523) + 32|0);
         $540 = HEAP32[$539>>2]|0;
         $541 = (($538) + ($540<<3)|0);
         $550 = $541;
         break;
        } else {
         $542 = (($538) + ($535<<3)|0);
         $550 = $542;
         break;
        }
       }
      } while(0);
      $543 = HEAP32[560624>>2]|0;
      $544 = (($543) + 28|0);
      $545 = HEAP32[$544>>2]|0;
      $546 = (($543) + 32|0);
      $547 = HEAP32[$546>>2]|0;
      $548 = (($545) + ($547<<3)|0);
      $549 = ($550|0)==($548|0);
      if ($549) {
       label = 130;
      } else {
       $551 = (($550) + 4|0);
       $552 = HEAP32[$551>>2]|0;
       $553 = ($552|0)==(0|0);
       if ($553) {
        label = 130;
       } else {
        $$0$i3459 = $552;
       }
      }
     }
     if ((label|0) == 130) {
      $554 = (__Z31ReadObjectFromPersistentManageri($521)|0);
      $555 = ($554|0)==(0|0);
      if ($555) {
       label = 132;
       break;
      } else {
       $$0$i3459 = $554;
      }
     }
     $556 = (($$0$i3459) + 8|0);
     $557 = HEAP32[$556>>2]|0;
     $558 = $557 >>> 21;
     $559 = HEAP32[560640>>2]|0;
     $560 = Math_imul($559, $558)|0;
     $561 = (($560) + 21)|0;
     $562 = $561 >> 5;
     $563 = $562 << 5;
     $564 = (($561) - ($563))|0;
     $565 = HEAP32[560632>>2]|0;
     $566 = (($565) + ($562<<2)|0);
     $567 = HEAP32[$566>>2]|0;
     $568 = 1 << $564;
     $569 = $568 & $567;
     $570 = ($569|0)==(0);
     if ($570) {
      label = 132;
     } else {
      $$0$i$i29 = $$0$i3459;
     }
    }
   } while(0);
   if ((label|0) == 132) {
    $$0$i$i29 = 0;
   }
   $571 = (($450) + 16|0);
   $572 = HEAP32[$571>>2]|0;
   $573 = ($572|0)==(0);
   do {
    if ($573) {
     label = 144;
    } else {
     HEAP32[$7>>2] = $572;
     $574 = HEAP32[560624>>2]|0;
     $575 = ($574|0)==(0|0);
     if ($575) {
      label = 142;
     } else {
      $576 = (($574) + 36|0);
      $577 = HEAP32[$576>>2]|0;
      $578 = (($574) + 4|0);
      $579 = HEAP32[$578>>2]|0;
      $580 = ($577|0)==($579|0);
      do {
       if ($580) {
        $581 = (($574) + 28|0);
        $582 = HEAP32[$581>>2]|0;
        $583 = (($574) + 32|0);
        $584 = HEAP32[$583>>2]|0;
        $585 = (($582) + ($584<<3)|0);
        $601 = $585;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy16,$574,$7);
        $586 = HEAP32[$$byval_copy16>>2]|0;
        $587 = ($586|0)==(-1);
        $588 = (($574) + 28|0);
        $589 = HEAP32[$588>>2]|0;
        if ($587) {
         $590 = (($574) + 32|0);
         $591 = HEAP32[$590>>2]|0;
         $592 = (($589) + ($591<<3)|0);
         $601 = $592;
         break;
        } else {
         $593 = (($589) + ($586<<3)|0);
         $601 = $593;
         break;
        }
       }
      } while(0);
      $594 = HEAP32[560624>>2]|0;
      $595 = (($594) + 28|0);
      $596 = HEAP32[$595>>2]|0;
      $597 = (($594) + 32|0);
      $598 = HEAP32[$597>>2]|0;
      $599 = (($596) + ($598<<3)|0);
      $600 = ($601|0)==($599|0);
      if ($600) {
       label = 142;
      } else {
       $602 = (($601) + 4|0);
       $603 = HEAP32[$602>>2]|0;
       $604 = ($603|0)==(0|0);
       if ($604) {
        label = 142;
       } else {
        $$0$i61 = $603;
       }
      }
     }
     if ((label|0) == 142) {
      $605 = (__Z31ReadObjectFromPersistentManageri($572)|0);
      $606 = ($605|0)==(0|0);
      if ($606) {
       label = 144;
       break;
      } else {
       $$0$i61 = $605;
      }
     }
     $607 = (($$0$i61) + 8|0);
     $608 = HEAP32[$607>>2]|0;
     $609 = $608 >>> 21;
     $610 = HEAP32[560640>>2]|0;
     $611 = Math_imul($610, $609)|0;
     $612 = (($611) + 43)|0;
     $613 = $612 >> 5;
     $614 = $613 << 5;
     $615 = (($612) - ($614))|0;
     $616 = HEAP32[560632>>2]|0;
     $617 = (($616) + ($613<<2)|0);
     $618 = HEAP32[$617>>2]|0;
     $619 = 1 << $615;
     $620 = $619 & $618;
     $621 = ($620|0)==(0);
     if ($621) {
      label = 144;
     } else {
      $$0$i$i = $$0$i61;
     }
    }
   } while(0);
   if ((label|0) == 144) {
    $$0$i$i = 0;
   }
   __ZN29BillboardTreeInstanceRenderer21UpdateMaterialAndMeshEPN5Unity8MaterialEP4Mesh($477,$$0$i$i29,$$0$i$i);
   $622 = (($this) + 200|0);
   $623 = HEAP32[$622>>2]|0;
   $624 = ($623|0)==(-1);
   if (!($624)) {
    $625 = (($477) + 176|0);
    $626 = HEAP32[$625>>2]|0;
    $627 = ($626|0)==(0);
    if (!($627)) {
     HEAP32[$625>>2] = 2;
     $628 = (($477) + 252|0);
     $629 = HEAP32[$628>>2]|0;
     $630 = (($629) + ($623))|0;
     $631 = (($477) + 180|0);
     HEAP32[$631>>2] = $630;
    }
   }
   $634 = (($450) + 20|0);
   $635 = (($this) + 256|0);
   $636 = (($this) + 264|0);
   $637 = HEAP32[$636>>2]|0;
   HEAP32[$11>>2] = $637;
   __ZN13dynamic_arrayIjLj4EE9push_backERKj($634,$11);
   $638 = (__ZN13dynamic_arrayI9SceneNodeLj4EE19push_back_constructEv($635)|0);
   HEAP32[$638>>2] = $477;
   $639 = HEAP32[$520>>2]|0;
   $640 = ($639|0)==(0);
   if ($640) {
    $644 = 1;
   } else {
    $641 = HEAP32[$571>>2]|0;
    $642 = ($641|0)==(0);
    $phitmp = $642&1;
    $644 = $phitmp;
   }
   $643 = (($638) + 22|0);
   HEAP8[$643>>0] = $644;
   $645 = HEAP32[$477>>2]|0;
   $646 = (($645) + 32|0);
   $647 = HEAP32[$646>>2]|0;
   $648 = (FUNCTION_TABLE_ii[$647 & 4095]($477)|0);
   $649 = (($638) + 4|0);
   HEAP32[$649>>2] = $648;
   $650 = HEAP32[$303>>2]|0;
   $651 = $650&65535;
   $652 = (($638) + 12|0);
   HEAP16[$652>>1] = $651;
   $653 = $304&65535;
   $654 = (($638) + 14|0);
   HEAP16[$654>>1] = $653;
   $655 = HEAP32[$189>>2]|0;
   $656 = HEAP32[$191>>2]|0;
   $657 = $655;
   $658 = $656;
   $659 = (($657) - ($658))|0;
   $660 = (($659|0) / 28)&-1;
   $661 = (($660) + -1)|0;
   $662 = 1 << $661;
   $663 = (($638) + 16|0);
   HEAP32[$663>>2] = $662;
   $664 = (($this) + 272|0);
   $665 = (__ZN13dynamic_arrayI4AABBLj4EE9push_backEv($664)|0);
   __ZN12BaseRenderer12GetWorldAABBER4AABB($477,$665);
   STACKTOP = sp;return;
  }
 }
 $632 = ___cxa_find_matching_catch()|0;
 $633 = tempRet0;
 $$0 = $632;$$01 = $633;
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNK12TreeDatabase9Prototype13GetLegacyMeshEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(1);
 if (!($3)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $5;
 $7 = HEAP32[560624>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  label = 11;
 } else {
  $9 = (($7) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($7) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  do {
   if ($13) {
    $14 = (($7) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($7) + 32|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + ($17<<3)|0);
    $34 = $18;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$7,$0);
    $19 = HEAP32[$pos$i$i$i$i>>2]|0;
    $20 = ($19|0)==(-1);
    $21 = (($7) + 28|0);
    $22 = HEAP32[$21>>2]|0;
    if ($20) {
     $23 = (($7) + 32|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($22) + ($24<<3)|0);
     $34 = $25;
     break;
    } else {
     $26 = (($22) + ($19<<3)|0);
     $34 = $26;
     break;
    }
   }
  } while(0);
  $27 = HEAP32[560624>>2]|0;
  $28 = (($27) + 28|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 32|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + ($31<<3)|0);
  $33 = ($34|0)==($32|0);
  if ($33) {
   label = 11;
  } else {
   $35 = (($34) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    label = 11;
   } else {
    $temp$0$i = $36;
   }
  }
 }
 if ((label|0) == 11) {
  $38 = (__Z31ReadObjectFromPersistentManageri($5)|0);
  $temp$0$i = $38;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN12TreeRenderer29CreateMeshTreeRendererForTreeEi($this,$treeIndex) {
 $this = $this|0;
 $treeIndex = $treeIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $aabb = 0, $modelview = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $modelview = sp + 56|0;
 $0 = sp;
 $1 = sp + 16|0;
 $aabb = sp + 32|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($treeIndex*40)|0)|0) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($2) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($6<<7)|0);
 $10 = (($this) + 152|0);
 $11 = (($this) + 160|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 184|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($treeIndex<<2)|0);
 HEAP32[$15>>2] = $12;
 $16 = (($4) + (($treeIndex*40)|0)|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($this) + 44|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($17 * $19);
 $21 = ((($4) + (($treeIndex*40)|0)|0) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = (($this) + 48|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($22 * $24);
 $26 = ((($4) + (($treeIndex*40)|0)|0) + 8|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = (($this) + 52|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($27 * $29);
 $31 = (($this) + 56|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($20 + $32);
 $34 = (($this) + 60|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($25 + $35);
 $37 = (($this) + 64|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($30 + $38);
 HEAPF32[$0>>2] = $33;
 $40 = (($0) + 4|0);
 HEAPF32[$40>>2] = $36;
 $41 = (($0) + 8|0);
 HEAPF32[$41>>2] = $39;
 HEAPF32[$1>>2] = Math_fround(0.0);
 $42 = (($1) + 4|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($1) + 8|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($1) + 12|0);
 HEAPF32[$44>>2] = Math_fround(1.0);
 __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($modelview,$0,$1,616696);
 $45 = (__ZNK12TreeDatabase9Prototype13GetLegacyMeshEv($9)|0);
 $46 = (($45) + 168|0);
 ;HEAP32[$aabb+0>>2]=HEAP32[$46+0>>2]|0;HEAP32[$aabb+4>>2]=HEAP32[$46+4>>2]|0;HEAP32[$aabb+8>>2]=HEAP32[$46+8>>2]|0;HEAP32[$aabb+12>>2]=HEAP32[$46+12>>2]|0;HEAP32[$aabb+16>>2]=HEAP32[$46+16>>2]|0;HEAP32[$aabb+20>>2]=HEAP32[$46+20>>2]|0;
 $47 = (($aabb) + 16|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = ((($4) + (($treeIndex*40)|0)|0) + 16|0);
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = Math_fround($48 * $50);
 $52 = Math_fround($51 - $48);
 $53 = (($aabb) + 4|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 + $52);
 HEAPF32[$53>>2] = $55;
 $56 = (($aabb) + 12|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = ((($4) + (($treeIndex*40)|0)|0) + 12|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = Math_fround($57 * $59);
 $61 = Math_fround(HEAPF32[$49>>2]);
 $62 = Math_fround($48 * $61);
 $63 = (($aabb) + 20|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = Math_fround($59 * $64);
 HEAPF32[$56>>2] = $60;
 HEAPF32[$47>>2] = $62;
 HEAPF32[$63>>2] = $65;
 $66 = (($this) + 128|0);
 HEAP32[802520>>2] = $66;
 $67 = (__ZN22ForwardLinearAllocator8allocateEjj($66,264,4)|0);
 $68 = ((($8) + ($6<<7)|0) + 36|0);
 __ZN26LegacyTreeInstanceRendererC2ER12TreeRendereriP4MeshRK13dynamic_arrayIPN5Unity8MaterialELj4EERK10Matrix4x4fRK4AABB($67,$this,$treeIndex,$45,$68,$modelview,$aabb);
 $69 = (__ZN13dynamic_arrayI9SceneNodeLj4EE19push_back_constructEv($10)|0);
 HEAP32[$69>>2] = $67;
 $70 = HEAP32[$67>>2]|0;
 $71 = (($70) + 32|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (FUNCTION_TABLE_ii[$72 & 4095]($67)|0);
 $74 = (($69) + 4|0);
 HEAP32[$74>>2] = $73;
 $75 = (($this) + 168|0);
 $76 = (__ZN13dynamic_arrayI4AABBLj4EE9push_backEv($75)|0);
 __ZN12BaseRenderer12GetWorldAABBER4AABB($67,$76);
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer11ReloadTreesEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12TreeRenderer11ReloadTreesEi($this,500);
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer11ReloadTreesEi($this,$treesPerBatch) {
 $this = $this|0;
 $treesPerBatch = $treesPerBatch|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 56|0);
  $5 = (($this) + 44|0);
  __ZN21TreeBinaryTreeBuilder5BuildER12TreeDatabaseRK8Vector3fS4_i($1,$2,$4,$5,$treesPerBatch);
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$1>>2] = 0;
  $7 = (($this) + 68|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($6|0);
  $10 = ($8|0)==(0|0);
  $or$cond$i$i = $9 | $10;
  do {
   if (!($or$cond$i$i)) {
    __THREW__ = 0;
    invoke_vi(3715,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     $13 = ___cxa_find_matching_catch()|0;
     $14 = tempRet0;
     __ZdlPv($8);
     ___cxa_call_unexpected(($13|0));
     // unreachable;
    } else {
     __ZdlPv($8);
     break;
    }
   }
  } while(0);
  HEAP32[$7>>2] = $6;
  $15 = (($this) + 120|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)>(-1);
  if ($17) {
   $18 = (($this) + 108|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 112|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$0>>2] = $21;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($19,$$byval_copy1);
   HEAP32[$18>>2] = 0;
  }
  $22 = (($this) + 116|0);
  HEAP32[$22>>2] = 0;
  HEAP32[$15>>2] = 0;
 }
 $23 = (($this) + 104|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  $30 = (($this) + 100|0);
  HEAP32[$30>>2] = 0;
  HEAP32[$23>>2] = 0;
  $31 = (($this) + 148|0);
  HEAP8[$31>>0] = 1;
  STACKTOP = sp;return;
 }
 $26 = (($this) + 92|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($this) + 96|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$0>>2] = $29;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy1);
 HEAP32[$26>>2] = 0;
 $30 = (($this) + 100|0);
 HEAP32[$30>>2] = 0;
 HEAP32[$23>>2] = 0;
 $31 = (($this) + 148|0);
 HEAP8[$31>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer6RenderER6CameraRKNSt3__16vectorIP5Light13stl_allocatorIS5_L18MemLabelIdentifier44ELi16EEEEfffii($this,$camera,$lights,$treeDistance,$billboardStartDistance,$crossFadeLength,$maximumMeshTrees,$layer) {
 $this = $this|0;
 $camera = $camera|0;
 $lights = $lights|0;
 $treeDistance = Math_fround($treeDistance);
 $billboardStartDistance = Math_fround($billboardStartDistance);
 $crossFadeLength = Math_fround($crossFadeLength);
 $maximumMeshTrees = $maximumMeshTrees|0;
 $layer = $layer|0;
 var $$$i = Math_fround(0), $$$i$i = Math_fround(0), $$0 = 0, $$0$i = Math_fround(0), $$0$i$i = Math_fround(0), $$0$i$i$i = Math_fround(0), $$0$i1$i$i = Math_fround(0), $$0$i3$i$i = Math_fround(0), $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy40 = 0, $$idx = 0, $$idx$i$i = 0, $$idx$val = Math_fround(0), $$idx4 = 0, $$idx4$val = Math_fround(0), $$idx5 = 0;
 var $$idx5$val = Math_fround(0), $$idx6 = 0, $$idx6$val = Math_fround(0), $$idx7 = 0, $$idx7$val = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0), $$phi$trans$insert = 0, $$pr = 0, $$pr132 = 0, $$pre = 0, $$pre127 = 0, $$pre128 = 0, $$pre129 = 0, $$pre130 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0;
 var $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = Math_fround(0), $237 = Math_fround(0), $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = Math_fround(0), $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = Math_fround(0), $246 = Math_fround(0);
 var $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0);
 var $265 = Math_fround(0), $266 = Math_fround(0), $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = Math_fround(0), $272 = Math_fround(0), $273 = Math_fround(0), $274 = Math_fround(0), $275 = Math_fround(0), $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = Math_fround(0), $281 = Math_fround(0), $282 = Math_fround(0);
 var $283 = Math_fround(0), $284 = Math_fround(0), $285 = Math_fround(0), $286 = Math_fround(0), $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = Math_fround(0), $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0;
 var $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = Math_fround(0), $309 = 0, $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = 0, $318 = Math_fround(0);
 var $319 = 0, $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0), $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = 0, $326 = Math_fround(0), $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = Math_fround(0), $335 = Math_fround(0), $336 = Math_fround(0);
 var $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0.0, $461 = 0, $462 = 0.0;
 var $463 = 0.0, $464 = Math_fround(0), $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = Math_fround(0), $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = Math_fround(0), $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = Math_fround(0), $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = Math_fround(0), $545 = Math_fround(0), $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = Math_fround(0), $584 = 0, $585 = 0, $586 = Math_fround(0), $587 = Math_fround(0), $588 = Math_fround(0), $589 = Math_fround(0);
 var $59 = 0, $590 = 0, $591 = 0, $592 = Math_fround(0), $593 = Math_fround(0), $594 = Math_fround(0), $595 = Math_fround(0), $596 = Math_fround(0), $597 = Math_fround(0), $598 = Math_fround(0), $599 = Math_fround(0), $6 = 0, $60 = 0, $600 = Math_fround(0), $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = Math_fround(0), $614 = Math_fround(0), $615 = Math_fround(0), $616 = 0, $617 = 0, $618 = Math_fround(0), $619 = Math_fround(0), $62 = 0, $620 = 0, $621 = Math_fround(0), $622 = Math_fround(0), $623 = 0, $624 = Math_fround(0);
 var $625 = Math_fround(0), $626 = Math_fround(0), $627 = Math_fround(0), $628 = Math_fround(0), $629 = 0, $63 = 0, $630 = Math_fround(0), $631 = 0, $632 = Math_fround(0), $633 = 0, $634 = Math_fround(0), $635 = Math_fround(0), $636 = 0, $637 = Math_fround(0), $638 = Math_fround(0), $639 = 0, $64 = 0, $640 = Math_fround(0), $641 = Math_fround(0), $642 = 0;
 var $643 = Math_fround(0), $644 = Math_fround(0), $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = Math_fround(0), $651 = Math_fround(0), $652 = Math_fround(0), $653 = Math_fround(0), $654 = Math_fround(0), $655 = Math_fround(0), $656 = Math_fround(0), $657 = 0, $658 = Math_fround(0), $659 = Math_fround(0), $66 = 0, $660 = Math_fround(0);
 var $661 = Math_fround(0), $662 = Math_fround(0), $663 = Math_fround(0), $664 = Math_fround(0), $665 = Math_fround(0), $666 = Math_fround(0), $667 = 0, $668 = 0, $669 = Math_fround(0), $67 = 0, $670 = Math_fround(0), $671 = Math_fround(0), $672 = Math_fround(0), $673 = Math_fround(0), $674 = 0, $675 = 0, $676 = Math_fround(0), $677 = Math_fround(0), $678 = Math_fround(0), $679 = Math_fround(0);
 var $68 = 0, $680 = Math_fround(0), $681 = Math_fround(0), $682 = Math_fround(0), $683 = Math_fround(0), $684 = Math_fround(0), $685 = Math_fround(0), $686 = Math_fround(0), $687 = Math_fround(0), $688 = 0, $689 = 0, $69 = 0, $690 = Math_fround(0), $691 = Math_fround(0), $692 = Math_fround(0), $693 = Math_fround(0), $694 = Math_fround(0), $695 = Math_fround(0), $696 = Math_fround(0), $697 = Math_fround(0);
 var $698 = Math_fround(0), $699 = Math_fround(0), $7 = 0, $70 = 0, $700 = Math_fround(0), $701 = Math_fround(0), $702 = Math_fround(0), $703 = Math_fround(0), $704 = Math_fround(0), $705 = Math_fround(0), $706 = Math_fround(0), $707 = Math_fround(0), $708 = Math_fround(0), $709 = Math_fround(0), $71 = 0, $710 = Math_fround(0), $711 = Math_fround(0), $712 = Math_fround(0), $713 = Math_fround(0), $714 = Math_fround(0);
 var $715 = Math_fround(0), $716 = Math_fround(0), $717 = Math_fround(0), $718 = Math_fround(0), $719 = Math_fround(0), $72 = 0, $720 = Math_fround(0), $721 = Math_fround(0), $722 = Math_fround(0), $723 = Math_fround(0), $724 = Math_fround(0), $725 = Math_fround(0), $726 = Math_fround(0), $727 = Math_fround(0), $728 = Math_fround(0), $729 = Math_fround(0), $73 = 0, $730 = Math_fround(0), $731 = Math_fround(0), $732 = Math_fround(0);
 var $733 = Math_fround(0), $734 = 0, $735 = 0, $736 = 0, $737 = Math_fround(0), $738 = Math_fround(0), $739 = Math_fround(0), $74 = 0, $740 = Math_fround(0), $741 = Math_fround(0), $742 = Math_fround(0), $743 = Math_fround(0), $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = Math_fround(0), $779 = Math_fround(0), $78 = 0, $780 = 0, $781 = Math_fround(0), $782 = Math_fround(0), $783 = Math_fround(0), $784 = Math_fround(0), $785 = Math_fround(0), $786 = Math_fround(0), $787 = 0;
 var $788 = 0, $789 = Math_fround(0), $79 = 0, $790 = Math_fround(0), $791 = 0, $792 = 0, $793 = Math_fround(0), $794 = Math_fround(0), $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0;
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = Math_fround(0), $843 = Math_fround(0), $844 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $billboardOffsetFactor = 0, $billboardsList = 0, $bounds = 0, $cameraDir = 0, $color = 0, $eh$lpad$body$index7Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body34$indexZ2D = 0, $exitcond = 0, $force$i = 0, $frustum = 0, $i$0120 = 0, $i1$0117 = 0, $i3$0110 = 0, $i4$0105 = 0, $i5$098 = 0, $i6$093 = 0, $i7$092 = 0, $magnitude$0$i = Math_fround(0), $matrix$i = 0;
 var $matrix$i70 = 0, $or$cond$i = 0, $propertySquashAmount = 0, $propertySquashPlaneNormal = 0, $propertyTerrainEngineBendTree = 0, $propertyTreeInstanceColor = 0, $propertyTreeInstanceScale = 0, $propertyWind = 0, $q$i = 0, $rotate = 0, $sext = 0, $skewFade$0 = Math_fround(0), $storemerge = 0, $tempBillboardAngleFactor = 0, $wind = 0, $writePos$0$lcssa = 0, $writePos$094 = 0, $writePos$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 720|0;
 $$byval_copy40 = sp + 712|0;
 $matrix$i70 = sp + 648|0;
 $0 = sp + 640|0;
 $1 = sp + 636|0;
 $2 = sp + 632|0;
 $3 = sp + 628|0;
 $4 = sp + 624|0;
 $matrix$i = sp + 560|0;
 $5 = sp + 556|0;
 $6 = sp + 552|0;
 $7 = sp + 548|0;
 $8 = sp + 544|0;
 $9 = sp + 540|0;
 $10 = sp + 536|0;
 $11 = sp + 532|0;
 $12 = sp + 528|0;
 $13 = sp + 524|0;
 $14 = sp + 520|0;
 $15 = sp + 516|0;
 $16 = sp + 512|0;
 $17 = sp;
 $force$i = sp + 496|0;
 $q$i = sp + 480|0;
 $18 = sp + 464|0;
 $19 = sp + 448|0;
 $20 = sp + 444|0;
 $21 = sp + 440|0;
 $22 = sp + 436|0;
 $23 = sp + 432|0;
 $24 = sp + 228|0;
 $25 = sp + 232|0;
 $26 = sp + 224|0;
 $27 = sp + 220|0;
 $28 = sp + 216|0;
 $frustum = sp + 120|0;
 $29 = sp + 116|0;
 $30 = sp + 104|0;
 $cameraDir = sp + 72|0;
 $billboardsList = sp + 56|0;
 $31 = sp + 24|0;
 $32 = sp + 8|0;
 $color = sp + 40|0;
 $33 = sp + 88|0;
 $34 = sp + 236|0;
 $35 = sp + 240|0;
 $propertyTerrainEngineBendTree = sp + 244|0;
 $propertyTreeInstanceColor = sp + 248|0;
 $propertyTreeInstanceScale = sp + 252|0;
 $propertySquashPlaneNormal = sp + 256|0;
 $propertySquashAmount = sp + 260|0;
 $propertyWind = sp + 264|0;
 $billboardOffsetFactor = sp + 268|0;
 $tempBillboardAngleFactor = sp + 272|0;
 $bounds = sp + 280|0;
 $rotate = sp + 304|0;
 $wind = sp + 368|0;
 $36 = sp + 384|0;
 $37 = sp + 400|0;
 $38 = sp + 416|0;
 $39 = HEAP32[652824>>2]|0;
 $40 = HEAP32[$this>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = (($this) + 148|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = ($43<<24>>24)==(0);
 if ($44) {
  __ZN12TreeRenderer23UpdateWindAssetPointersEv($this);
  $$pr = HEAP8[$42>>0]|0;
  $45 = ($$pr<<24>>24)==(0);
  if (!($45)) {
   label = 4;
  }
 } else {
  label = 4;
 }
 if ((label|0) == 4) {
  __ZN12TreeRenderer14ClearRenderersEv($this);
  __ZN12TreeRenderer17PopulateRenderersEv($this);
  HEAP8[$42>>0] = 0;
 }
 __ZN12TreeRenderer14RenderLODTreesER6Camerai($this,0,$layer);
 $46 = (($this) + 84|0);
 HEAP32[$46>>2] = $layer;
 HEAPF32[$frustum>>2] = Math_fround(0.0);
 $47 = (($frustum) + 4|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($frustum) + 8|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($frustum) + 16|0);
 HEAPF32[$49>>2] = Math_fround(0.0);
 $50 = (($frustum) + 20|0);
 HEAPF32[$50>>2] = Math_fround(0.0);
 $51 = (($frustum) + 24|0);
 HEAPF32[$51>>2] = Math_fround(0.0);
 $52 = (($frustum) + 32|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($frustum) + 36|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 $54 = (($frustum) + 40|0);
 HEAPF32[$54>>2] = Math_fround(0.0);
 $55 = (($frustum) + 48|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 $56 = (($frustum) + 52|0);
 HEAPF32[$56>>2] = Math_fround(0.0);
 $57 = (($frustum) + 56|0);
 HEAPF32[$57>>2] = Math_fround(0.0);
 $58 = (($frustum) + 64|0);
 HEAPF32[$58>>2] = Math_fround(0.0);
 $59 = (($frustum) + 68|0);
 HEAPF32[$59>>2] = Math_fround(0.0);
 $60 = (($frustum) + 72|0);
 HEAPF32[$60>>2] = Math_fround(0.0);
 $61 = (($frustum) + 80|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (($frustum) + 84|0);
 HEAPF32[$62>>2] = Math_fround(0.0);
 $63 = (($frustum) + 88|0);
 HEAPF32[$63>>2] = Math_fround(0.0);
 $64 = (__ZNK6Camera20GetWorldToClipMatrixEv($camera)|0);
 __Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane($64,$frustum);
 $65 = (($this) + 68|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)==(0|0);
 if ($67) {
  $68 = (($this) + 104|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ($69|0)>(-1);
  if ($70) {
   $71 = (($this) + 92|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($this) + 96|0);
   $74 = HEAP32[$73>>2]|0;
   HEAP32[$matrix$i70>>2] = $74;
   ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$matrix$i70+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($72,$$byval_copy40);
   HEAP32[$71>>2] = 0;
  }
  $75 = (($this) + 100|0);
  HEAP32[$75>>2] = 0;
  HEAP32[$68>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(1);
 __THREW__ = 0;
 $76 = (invoke_i(124)|0);
 $77 = __THREW__; __THREW__ = 0;
 $78 = $77&1;
 L16: do {
  if ($78) {
   label = 20;
  } else {
   $79 = (($this) + 124|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = (($80) + 24|0);
   $82 = HEAP8[$81>>0]|0;
   $83 = ($82<<24>>24)!=(0);
   $84 = $76 ^ $83;
   if ($84) {
    __THREW__ = 0;
    $85 = (invoke_ii(2988,108)|0);
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     label = 20;
     break;
    }
    $88 = HEAP32[$this>>2]|0;
    __THREW__ = 0;
    invoke_vii(3421,($85|0),($88|0));
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     $110 = ___cxa_find_matching_catch()|0;
     $111 = tempRet0;
     __ZdlPv($85);
     $$2 = $110;$$23 = $111;
     label = 184;
     break;
    }
    $91 = HEAP32[$79>>2]|0;
    $92 = ($91|0)==($85|0);
    $93 = ($91|0)==(0|0);
    $or$cond$i = $92 | $93;
    do {
     if (!($or$cond$i)) {
      __THREW__ = 0;
      invoke_vi(3714,($91|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       $96 = ___cxa_find_matching_catch()|0;
       $97 = tempRet0;
       __ZdlPv($91);
       ___cxa_call_unexpected(($96|0));
       // unreachable;
      } else {
       __ZdlPv($91);
       break;
      }
     }
    } while(0);
    HEAP32[$79>>2] = $85;
    $98 = (($this) + 4|0);
    $99 = HEAP32[$98>>2]|0;
    HEAP32[$$byval_copy40>>2] = -1;
    __THREW__ = 0;
    invoke_vii(2618,($$byval_copy40|0),(803280|0));
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 20;
     break;
    }
    $102 = HEAP32[$$byval_copy40>>2]|0;
    HEAP32[$29>>2] = $102;
    $103 = HEAP32[$79>>2]|0;
    $104 = (($103) + 20|0);
    $105 = HEAP32[$104>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$29+0>>2]|0;
    invoke_viii(1682,($99|0),($$byval_copy40|0),($105|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     label = 20;
     break;
    }
    $$pre127 = HEAP32[$79>>2]|0;
    $$phi$trans$insert = (($$pre127) + 24|0);
    $$pre128 = HEAP8[$$phi$trans$insert>>0]|0;
    $113 = $$pre128;
   } else {
    $113 = $82;
   }
   $112 = ($113<<24>>24)==(0);
   if ($112) {
    $114 = Math_fround($billboardStartDistance - $billboardStartDistance);
    $120 = Math_fround(0.0);$121 = $114;$842 = $billboardStartDistance;$843 = $billboardStartDistance;
    label = 25;
   } else {
    $115 = $treeDistance < $billboardStartDistance;
    $116 = $115 ? $treeDistance : $billboardStartDistance;
    $117 = Math_fround($treeDistance - $116);
    $118 = $crossFadeLength < Math_fround(0.0);
    if ($118) {
     $$0$i = Math_fround(0.0);$124 = $treeDistance;$127 = $116;
    } else {
     $120 = $crossFadeLength;$121 = $117;$842 = $116;$843 = $treeDistance;
     label = 25;
    }
   }
   if ((label|0) == 25) {
    $119 = $120 > $121;
    $$$i = $119 ? $121 : $120;
    $$0$i = $$$i;$124 = $843;$127 = $842;
   }
   $122 = (($this) + 76|0);
   HEAPF32[$122>>2] = $$0$i;
   $123 = Math_fround($124 * $124);
   $125 = (($this) + 72|0);
   HEAPF32[$125>>2] = $123;
   $126 = Math_fround($127 + $$0$i);
   $128 = Math_fround($126 * $126);
   $129 = (($this) + 80|0);
   HEAPF32[$129>>2] = $128;
   $130 = (($camera) + 24|0);
   $131 = HEAP32[$130>>2]|0;
   __THREW__ = 0;
   $132 = (invoke_ii(3220,($131|0))|0);
   $133 = __THREW__; __THREW__ = 0;
   $134 = $133&1;
   if ($134) {
    label = 20;
   } else {
    __THREW__ = 0;
    invoke_vii(2620,($30|0),($132|0));
    $135 = __THREW__; __THREW__ = 0;
    $136 = $135&1;
    if ($136) {
     label = 20;
    } else {
     __THREW__ = 0;
     invoke_viii(1690,($cameraDir|0),($132|0),(616744|0));
     $137 = __THREW__; __THREW__ = 0;
     $138 = $137&1;
     if ($138) {
      label = 20;
     } else {
      $139 = (($this) + 112|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = (($this) + 108|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = (($this) + 116|0);
      $144 = HEAP32[$143>>2]|0;
      $$idx$i$i = $144 << 2;
      $145 = $$idx$i$i >> 2;
      $146 = ($145|0)==(0);
      if ($146) {
       $177 = 0;$826 = 0;
      } else {
       HEAP32[$21>>2] = $140;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$21+0>>2]|0;
       $147 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i|0),4,($$byval_copy40|0),0,(803264|0),370)|0);
       $148 = __THREW__; __THREW__ = 0;
       $149 = $148&1;
       if ($149) {
        label = 20;
        break;
       }
       _memcpy(($147|0),($142|0),($$idx$i$i|0))|0;
       $sext = $144 << 2;
       $150 = $sext >> 2;
       $i$0120 = 0;
       while(1) {
        $151 = (($147) + ($i$0120<<2)|0);
        $152 = HEAP32[$151>>2]|0;
        $153 = (($152) + 56|0);
        $154 = HEAP32[$153>>2]|0;
        $155 = ($154|0)==(1);
        if ($155) {
         HEAP32[$153>>2] = -1;
        }
        $158 = (($i$0120) + 1)|0;
        $exitcond = ($158|0)==($150|0);
        if ($exitcond) {
         $177 = $147;$826 = $145;
         break;
        } else {
         $i$0120 = $158;
        }
       }
      }
      $159 = (($this) + 120|0);
      $160 = HEAP32[$159>>2]|0;
      $161 = ($160|0)>(-1);
      if ($161) {
       $162 = HEAP32[$141>>2]|0;
       $163 = HEAP32[$139>>2]|0;
       HEAP32[$20>>2] = $163;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$20+0>>2]|0;
       invoke_vii(2591,($162|0),($$byval_copy40|0));
       $164 = __THREW__; __THREW__ = 0;
       $165 = $164&1;
       if ($165) {
        label = 35;
       } else {
        HEAP32[$141>>2] = 0;
        label = 40;
       }
      } else {
       label = 40;
      }
      L55: do {
       if ((label|0) == 40) {
        HEAP32[$143>>2] = 0;
        HEAP32[$159>>2] = 0;
        $166 = (($this) + 92|0);
        $167 = (($this) + 100|0);
        HEAP32[$167>>2] = 0;
        $168 = (($this) + 104|0);
        $169 = HEAP32[628512>>2]|0;
        HEAP32[$billboardsList>>2] = 0;
        $170 = (($billboardsList) + 4|0);
        HEAP32[$170>>2] = $169;
        $171 = (($billboardsList) + 8|0);
        HEAP32[$171>>2] = 0;
        $172 = (($billboardsList) + 12|0);
        HEAP32[$172>>2] = 0;
        $173 = HEAP32[$65>>2]|0;
        __THREW__ = 0;
        invoke_viiiii(114,($this|0),($173|0),($frustum|0),($billboardsList|0),($30|0));
        $174 = __THREW__; __THREW__ = 0;
        $175 = $174&1;
        L57: do {
         if ($175) {
          label = 49;
         } else {
          L59: do {
           if (!($146)) {
            $i1$0117 = 0;
            while(1) {
             $176 = (($177) + ($i1$0117<<2)|0);
             $178 = HEAP32[$176>>2]|0;
             $179 = (($178) + 56|0);
             $180 = HEAP32[$179>>2]|0;
             $181 = ($180|0)==(-1);
             if ($181) {
              $182 = (($178) + 44|0);
              $183 = HEAP32[$182>>2]|0;
              __THREW__ = 0;
              invoke_vi(3709,($183|0));
              $184 = __THREW__; __THREW__ = 0;
              $185 = $184&1;
              if ($185) {
               break;
              }
              HEAP32[$182>>2] = 0;
              HEAP32[$179>>2] = 0;
             }
             $196 = (($i1$0117) + 1)|0;
             $197 = ($196>>>0)<($145>>>0);
             if ($197) {
              $i1$0117 = $196;
             } else {
              break L59;
             }
            }
            $192 = ___cxa_find_matching_catch()|0;
            $193 = tempRet0;
            $eh$lpad$body$index7Z2D = $193;$eh$lpad$body$indexZ2D = $192;
            label = 50;
            break L57;
           }
          } while(0);
          $198 = HEAP32[$billboardsList>>2]|0;
          $199 = HEAP32[$171>>2]|0;
          $200 = (($198) + ($199<<2)|0);
          $201 = HEAP32[$this>>2]|0;
          $202 = (($201) + 16|0);
          HEAP32[$17>>2] = $202;
          __ZNSt3__16__sortIR23TreeInstanceIndexSorterPjEEvT0_S4_T_($198,$200,$17);
          $203 = (($lights) + 4|0);
          $204 = HEAP32[$203>>2]|0;
          $205 = HEAP32[$lights>>2]|0;
          $206 = $204;
          $207 = $205;
          $208 = (($206) - ($207))|0;
          $209 = $208 >> 2;
          $210 = ($209|0)>(4);
          $211 = $210 ? 4 : $209;
          $212 = ($211|0)>(0);
          do {
           if ($212) {
            $213 = (($31) + 4|0);
            $214 = (($31) + 8|0);
            $215 = (($31) + 12|0);
            $216 = (($39) + 20|0);
            $217 = (($32) + 4|0);
            $218 = (($32) + 8|0);
            $219 = (($32) + 12|0);
            $220 = (($color) + 4|0);
            $221 = (($color) + 8|0);
            $222 = (($color) + 12|0);
            $226 = $205;$i3$0110 = 0;
            while(1) {
             $225 = (($226) + ($i3$0110<<2)|0);
             $227 = HEAP32[$225>>2]|0;
             $228 = (($227) + 24|0);
             $229 = HEAP32[$228>>2]|0;
             __THREW__ = 0;
             $230 = (invoke_ii(3220,($229|0))|0);
             $231 = __THREW__; __THREW__ = 0;
             $232 = $231&1;
             if ($232) {
              label = 47;
              break;
             }
             __THREW__ = 0;
             invoke_vii(2645,($31|0),($230|0));
             $233 = __THREW__; __THREW__ = 0;
             $234 = $233&1;
             if ($234) {
              label = 47;
              break;
             }
             $235 = Math_fround(HEAPF32[$31>>2]);
             $236 = Math_fround(-$235);
             $237 = Math_fround(HEAPF32[$213>>2]);
             $238 = Math_fround(-$237);
             $239 = Math_fround(HEAPF32[$214>>2]);
             $240 = Math_fround(HEAPF32[$215>>2]);
             $241 = Math_fround(-$240);
             $242 = Math_fround($235 * Math_fround(-2.0));
             $243 = Math_fround($237 * Math_fround(-2.0));
             $244 = Math_fround($239 * Math_fround(-2.0));
             $245 = Math_fround($242 * $236);
             $246 = Math_fround($243 * $238);
             $247 = Math_fround($239 * $244);
             $248 = Math_fround($243 * $236);
             $249 = Math_fround($244 * $236);
             $250 = Math_fround($244 * $238);
             $251 = Math_fround($242 * $241);
             $252 = Math_fround($243 * $241);
             $253 = Math_fround($244 * $241);
             $254 = Math_fround($246 - $247);
             $255 = Math_fround(Math_fround(1.0) - $254);
             $256 = Math_fround(HEAPF32[616744>>2]);
             $257 = Math_fround($256 * $255);
             $258 = Math_fround($248 - $253);
             $259 = Math_fround(HEAPF32[((616744 + 4|0))>>2]);
             $260 = Math_fround($259 * $258);
             $261 = Math_fround($260 + $257);
             $262 = Math_fround($249 + $252);
             $263 = Math_fround(HEAPF32[((616744 + 8|0))>>2]);
             $264 = Math_fround($262 * $263);
             $265 = Math_fround($264 + $261);
             $266 = Math_fround($248 + $253);
             $267 = Math_fround($256 * $266);
             $268 = Math_fround($245 - $247);
             $269 = Math_fround(Math_fround(1.0) - $268);
             $270 = Math_fround($259 * $269);
             $271 = Math_fround($267 + $270);
             $272 = Math_fround($250 - $251);
             $273 = Math_fround($272 * $263);
             $274 = Math_fround($273 + $271);
             $275 = Math_fround($249 - $252);
             $276 = Math_fround($256 * $275);
             $277 = Math_fround($250 + $251);
             $278 = Math_fround($259 * $277);
             $279 = Math_fround($276 + $278);
             $280 = Math_fround($245 + $246);
             $281 = Math_fround(Math_fround(1.0) - $280);
             $282 = Math_fround($281 * $263);
             $283 = Math_fround($282 + $279);
             $284 = Math_fround(-$265);
             $285 = Math_fround(-$274);
             $286 = Math_fround(-$283);
             HEAPF32[$32>>2] = $284;
             HEAPF32[$217>>2] = $285;
             HEAPF32[$218>>2] = $286;
             HEAPF32[$219>>2] = Math_fround(0.0);
             $287 = (802816 + ($i3$0110<<2)|0);
             __THREW__ = 0;
             invoke_viii(1689,($216|0),($287|0),($32|0));
             $288 = __THREW__; __THREW__ = 0;
             $289 = $288&1;
             if ($289) {
              label = 47;
              break;
             }
             $290 = (($227) + 184|0);
             $291 = Math_fround(HEAPF32[$290>>2]);
             $292 = (($227) + 140|0);
             $293 = Math_fround(HEAPF32[$292>>2]);
             $294 = Math_fround($291 * $293);
             $295 = (($227) + 144|0);
             $296 = Math_fround(HEAPF32[$295>>2]);
             $297 = Math_fround($291 * $296);
             $298 = (($227) + 148|0);
             $299 = Math_fround(HEAPF32[$298>>2]);
             $300 = Math_fround($291 * $299);
             $301 = (($227) + 152|0);
             $302 = Math_fround(HEAPF32[$301>>2]);
             $303 = Math_fround($291 * $302);
             HEAPF32[$color>>2] = $294;
             HEAPF32[$220>>2] = $297;
             HEAPF32[$221>>2] = $300;
             HEAPF32[$222>>2] = $303;
             __THREW__ = 0;
             $304 = (invoke_i(66)|0);
             $305 = __THREW__; __THREW__ = 0;
             $306 = $305&1;
             if ($306) {
              label = 47;
              break;
             }
             $307 = ($304|0)==(1);
             $308 = Math_fround(HEAPF32[$color>>2]);
             if ($307) {
              $309 = !($308 <= Math_fround(0.0404499992728233337402));
              do {
               if ($309) {
                $311 = $308 < Math_fround(1.0);
                if ($311) {
                 $312 = Math_fround($308 + Math_fround(0.054999999701976776123));
                 $313 = Math_fround($312 / Math_fround(1.05499994754791259766));
                 $314 = (Math_fround(+(Math_pow((+$313),2.40000009536743164063))));
                 $$0$i$i$i = $314;
                 break;
                } else {
                 $315 = (Math_fround(+(Math_pow((+$308),2.40000009536743164063))));
                 $$0$i$i$i = $315;
                 break;
                }
               } else {
                $310 = Math_fround($308 / Math_fround(12.9200000762939453125));
                $$0$i$i$i = $310;
               }
              } while(0);
              $316 = Math_fround(HEAPF32[$220>>2]);
              $317 = !($316 <= Math_fround(0.0404499992728233337402));
              do {
               if ($317) {
                $319 = $316 < Math_fround(1.0);
                if ($319) {
                 $320 = Math_fround($316 + Math_fround(0.054999999701976776123));
                 $321 = Math_fround($320 / Math_fround(1.05499994754791259766));
                 $322 = (Math_fround(+(Math_pow((+$321),2.40000009536743164063))));
                 $$0$i3$i$i = $322;
                 break;
                } else {
                 $323 = (Math_fround(+(Math_pow((+$316),2.40000009536743164063))));
                 $$0$i3$i$i = $323;
                 break;
                }
               } else {
                $318 = Math_fround($316 / Math_fround(12.9200000762939453125));
                $$0$i3$i$i = $318;
               }
              } while(0);
              $324 = Math_fround(HEAPF32[$221>>2]);
              $325 = !($324 <= Math_fround(0.0404499992728233337402));
              do {
               if ($325) {
                $327 = $324 < Math_fround(1.0);
                if ($327) {
                 $328 = Math_fround($324 + Math_fround(0.054999999701976776123));
                 $329 = Math_fround($328 / Math_fround(1.05499994754791259766));
                 $330 = (Math_fround(+(Math_pow((+$329),2.40000009536743164063))));
                 $$0$i1$i$i = $330;
                 break;
                } else {
                 $331 = (Math_fround(+(Math_pow((+$324),2.40000009536743164063))));
                 $$0$i1$i$i = $331;
                 break;
                }
               } else {
                $326 = Math_fround($324 / Math_fround(12.9200000762939453125));
                $$0$i1$i$i = $326;
               }
              } while(0);
              $332 = Math_fround(HEAPF32[$222>>2]);
              $336 = $$0$i$i$i;$337 = $$0$i3$i$i;$338 = $$0$i1$i$i;$339 = $332;
             } else {
              $333 = Math_fround(HEAPF32[$220>>2]);
              $334 = Math_fround(HEAPF32[$221>>2]);
              $335 = Math_fround(HEAPF32[$222>>2]);
              $336 = $308;$337 = $333;$338 = $334;$339 = $335;
             }
             HEAPF32[$color>>2] = $336;
             HEAPF32[$220>>2] = $337;
             HEAPF32[$221>>2] = $338;
             HEAPF32[$222>>2] = $339;
             $340 = (802960 + ($i3$0110<<2)|0);
             __THREW__ = 0;
             invoke_viii(1689,($216|0),($340|0),($color|0));
             $341 = __THREW__; __THREW__ = 0;
             $342 = $341&1;
             if ($342) {
              label = 47;
              break;
             }
             $343 = (($i3$0110) + 1)|0;
             $344 = ($343|0)<($211|0);
             if (!($344)) {
              label = 54;
              break;
             }
             $$pre129 = HEAP32[$lights>>2]|0;
             $226 = $$pre129;$i3$0110 = $343;
            }
            if ((label|0) == 47) {
             $190 = ___cxa_find_matching_catch()|0;
             $191 = tempRet0;
             $eh$lpad$body$index7Z2D = $191;$eh$lpad$body$indexZ2D = $190;
             label = 50;
             break L57;
            }
            else if ((label|0) == 54) {
             $223 = ($211|0)<(4);
             if ($223) {
              label = 55;
              break;
             } else {
              break;
             }
            }
           } else {
            label = 55;
           }
          } while(0);
          L106: do {
           if ((label|0) == 55) {
            $224 = (($39) + 20|0);
            $i4$0105 = $211;
            while(1) {
             $345 = (802960 + ($i4$0105<<2)|0);
             ;HEAP32[$33+0>>2]=0|0;HEAP32[$33+4>>2]=0|0;HEAP32[$33+8>>2]=0|0;HEAP32[$33+12>>2]=0|0;
             __THREW__ = 0;
             invoke_viii(1689,($224|0),($345|0),($33|0));
             $346 = __THREW__; __THREW__ = 0;
             $347 = $346&1;
             if ($347) {
              break;
             }
             $348 = (($i4$0105) + 1)|0;
             $349 = ($348|0)<(4);
             if ($349) {
              $i4$0105 = $348;
             } else {
              break L106;
             }
            }
            $188 = ___cxa_find_matching_catch()|0;
            $189 = tempRet0;
            $eh$lpad$body$index7Z2D = $189;$eh$lpad$body$indexZ2D = $188;
            label = 50;
            break L57;
           }
          } while(0);
          $350 = HEAP32[$79>>2]|0;
          $351 = (($350) + 24|0);
          $352 = HEAP8[$351>>0]|0;
          $353 = ($352<<24>>24)==(0);
          do {
           if (!($353)) {
            __THREW__ = 0;
            $354 = (invoke_iii(2602,($350|0),($camera|0))|0);
            $355 = __THREW__; __THREW__ = 0;
            $356 = $355&1;
            if ($356) {
             label = 49;
             break L57;
            }
            if (!($354)) {
             break;
            }
            $357 = (($this) + 4|0);
            $358 = HEAP32[$357>>2]|0;
            HEAP32[$4>>2] = -1;
            __THREW__ = 0;
            invoke_vii(2618,($4|0),(803280|0));
            $359 = __THREW__; __THREW__ = 0;
            $360 = $359&1;
            if ($360) {
             label = 49;
             break L57;
            }
            $361 = HEAP32[$4>>2]|0;
            HEAP32[$34>>2] = $361;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$34+0>>2]|0;
            $362 = (invoke_iii(2601,($358|0),($$byval_copy40|0))|0);
            $363 = __THREW__; __THREW__ = 0;
            $364 = $363&1;
            if ($364) {
             label = 49;
             break L57;
            }
            if (!($362)) {
             break;
            }
            $365 = HEAP32[$357>>2]|0;
            HEAP32[$3>>2] = -1;
            __THREW__ = 0;
            invoke_vii(2618,($3|0),(803280|0));
            $366 = __THREW__; __THREW__ = 0;
            $367 = $366&1;
            if ($367) {
             label = 49;
             break L57;
            }
            $368 = HEAP32[$3>>2]|0;
            HEAP32[$35>>2] = $368;
            $369 = HEAP32[$79>>2]|0;
            $370 = (($369) + 20|0);
            $371 = HEAP32[$370>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$35+0>>2]|0;
            invoke_viii(1682,($365|0),($$byval_copy40|0),($371|0));
            $372 = __THREW__; __THREW__ = 0;
            $373 = $372&1;
            if ($373) {
             label = 49;
             break L57;
            }
           }
          } while(0);
          __THREW__ = 0;
          invoke_vii(3426,($this|0),($camera|0));
          $374 = __THREW__; __THREW__ = 0;
          $375 = $374&1;
          if ($375) {
           label = 49;
          } else {
           $376 = HEAP32[$143>>2]|0;
           $377 = ($376|0)==(0);
           L123: do {
            if (!($377)) {
             $378 = (($this) + 4|0);
             $379 = (($this) + 8|0);
             $i5$098 = 0;
             while(1) {
              $380 = HEAP32[$141>>2]|0;
              $381 = (($380) + ($i5$098<<2)|0);
              $382 = HEAP32[$381>>2]|0;
              $383 = (($382) + 44|0);
              $384 = HEAP32[$383>>2]|0;
              $385 = HEAP32[$378>>2]|0;
              __THREW__ = 0;
              (invoke_ii(3230,($matrix$i70|0))|0);
              $386 = __THREW__; __THREW__ = 0;
              $387 = $386&1;
              if ($387) {
               break;
              }
              $388 = ($385|0)==(0|0);
              if ($388) {
               $storemerge = 0;
              } else {
               $389 = (($385) + 4|0);
               $390 = HEAP32[$389>>2]|0;
               $storemerge = $390;
              }
              HEAP32[$0>>2] = $storemerge;
              __THREW__ = 0;
              $391 = (invoke_iiiiiiiii(44,($matrix$i70|0),($384|0),($0|0),($layer|0),1,1,0,($camera|0))|0);
              $392 = __THREW__; __THREW__ = 0;
              $393 = $392&1;
              if ($393) {
               break;
              }
              $394 = (($391) + 168|0);
              HEAP32[$394>>2] = $379;
              $395 = (($i5$098) + 1)|0;
              $396 = HEAP32[$143>>2]|0;
              $397 = ($395>>>0)<($396>>>0);
              if ($397) {
               $i5$098 = $395;
              } else {
               break L123;
              }
             }
             $186 = ___cxa_find_matching_catch()|0;
             $187 = tempRet0;
             $eh$lpad$body$index7Z2D = $187;$eh$lpad$body$indexZ2D = $186;
             label = 50;
             break L57;
            }
           } while(0);
           $398 = HEAP32[$79>>2]|0;
           $399 = (($398) + 24|0);
           $400 = HEAP8[$399>>0]|0;
           $401 = ($400<<24>>24)==(0);
           do {
            if (!($401)) {
             $402 = HEAP32[$171>>2]|0;
             $403 = ($402|0)==(0);
             if ($403) {
              break;
             }
             $404 = (($this) + 88|0);
             $405 = HEAP32[$404>>2]|0;
             $406 = ($405|0)==(0|0);
             if ($406) {
              $407 = HEAP32[628384>>2]|0;
              HEAP32[$1>>2] = $407;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$1+0>>2]|0;
              $408 = (invoke_iiiiiii(103,280,($$byval_copy40|0),1,16,(803264|0),1111)|0);
              $409 = __THREW__; __THREW__ = 0;
              $410 = $409&1;
              if ($410) {
               label = 49;
               break L57;
              }
              HEAP32[$2>>2] = $407;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$2+0>>2]|0;
              invoke_viii(1698,($408|0),($$byval_copy40|0),0);
              $411 = __THREW__; __THREW__ = 0;
              $412 = $411&1;
              if ($412) {
               $426 = ___cxa_find_matching_catch()|0;
               $427 = tempRet0;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$1+0>>2]|0;
               invoke_viiiiii(97,($408|0),($$byval_copy40|0),1,16,(803264|0),1111);
               $428 = __THREW__; __THREW__ = 0;
               $429 = $428&1;
               if (!($429)) {
                $eh$lpad$body$index7Z2D = $427;$eh$lpad$body$indexZ2D = $426;
                label = 50;
                break L57;
               }
               $430 = ___cxa_find_matching_catch(0|0)|0;
               $431 = tempRet0;
               ___clang_call_terminate($430);
               // unreachable;
              }
              __THREW__ = 0;
              $413 = (invoke_ii(3405,($408|0))|0);
              $414 = __THREW__; __THREW__ = 0;
              $415 = $414&1;
              if ($415) {
               label = 49;
               break L57;
              }
              $416 = HEAP32[$413>>2]|0;
              $417 = (($416) + 24|0);
              $418 = HEAP32[$417>>2]|0;
              __THREW__ = 0;
              invoke_vi($418|0,($413|0));
              $419 = __THREW__; __THREW__ = 0;
              $420 = $419&1;
              if ($420) {
               label = 49;
               break L57;
              }
              $421 = HEAP32[$413>>2]|0;
              $422 = (($421) + 12|0);
              $423 = HEAP32[$422>>2]|0;
              __THREW__ = 0;
              invoke_vii($423|0,($413|0),4);
              $424 = __THREW__; __THREW__ = 0;
              $425 = $424&1;
              if ($425) {
               label = 49;
               break L57;
              }
              HEAP32[$404>>2] = $413;
              $432 = HEAP32[$413>>2]|0;
              $433 = (($432) + 44|0);
              $434 = HEAP32[$433>>2]|0;
              __THREW__ = 0;
              invoke_vii($434|0,($413|0),61);
              $435 = __THREW__; __THREW__ = 0;
              $436 = $435&1;
              if ($436) {
               label = 49;
               break L57;
              }
              $437 = HEAP32[$404>>2]|0;
              __THREW__ = 0;
              invoke_vi(3721,($437|0));
              $438 = __THREW__; __THREW__ = 0;
              $439 = $438&1;
              if ($439) {
               label = 49;
               break L57;
              }
              $$pre130 = HEAP32[$404>>2]|0;
              $440 = $$pre130;
             } else {
              $440 = $405;
             }
             __THREW__ = 0;
             invoke_viiii(423,($this|0),($440|0),($billboardsList|0),1);
             $441 = __THREW__; __THREW__ = 0;
             $442 = $441&1;
             if ($442) {
              label = 49;
              break L57;
             }
             $443 = HEAP32[$404>>2]|0;
             $444 = (($this) + 4|0);
             $445 = HEAP32[$444>>2]|0;
             $446 = (($this) + 8|0);
             __THREW__ = 0;
             (invoke_ii(3230,($matrix$i|0))|0);
             $447 = __THREW__; __THREW__ = 0;
             $448 = $447&1;
             if ($448) {
              label = 49;
              break L57;
             }
             $449 = ($445|0)==(0|0);
             if ($449) {
              HEAP32[$5>>2] = 0;
             } else {
              $450 = (($445) + 4|0);
              $451 = HEAP32[$450>>2]|0;
              HEAP32[$5>>2] = $451;
             }
             __THREW__ = 0;
             $452 = (invoke_iiiiiiiii(44,($matrix$i|0),($443|0),($5|0),($layer|0),1,1,0,($camera|0))|0);
             $453 = __THREW__; __THREW__ = 0;
             $454 = $453&1;
             if ($454) {
              label = 49;
              break L57;
             }
             $455 = (($452) + 168|0);
             HEAP32[$455>>2] = $446;
            }
           } while(0);
           __THREW__ = 0;
           $456 = (invoke_i(87)|0);
           $457 = __THREW__; __THREW__ = 0;
           $458 = $457&1;
           if ($458) {
            label = 49;
            break;
           }
           $459 = (($456) + 88|0);
           $460 = +HEAPF64[$459>>3];
           $461 = (($456) + 160|0);
           $462 = +HEAPF64[$461>>3];
           $463 = $460 + $462;
           $464 = Math_fround($463);
           HEAP32[$6>>2] = -1;
           __THREW__ = 0;
           invoke_vii(2618,($6|0),(803296|0));
           $465 = __THREW__; __THREW__ = 0;
           $466 = $465&1;
           if ($466) {
            label = 49;
            break;
           }
           $467 = HEAP32[$6>>2]|0;
           HEAP32[$propertyTerrainEngineBendTree>>2] = $467;
           HEAP32[$7>>2] = -1;
           __THREW__ = 0;
           invoke_vii(2618,($7|0),(803320|0));
           $468 = __THREW__; __THREW__ = 0;
           $469 = $468&1;
           if ($469) {
            label = 49;
            break;
           }
           $470 = HEAP32[$7>>2]|0;
           HEAP32[$propertyTreeInstanceColor>>2] = $470;
           HEAP32[$8>>2] = -1;
           __THREW__ = 0;
           invoke_vii(2618,($8|0),(803344|0));
           $471 = __THREW__; __THREW__ = 0;
           $472 = $471&1;
           if ($472) {
            label = 49;
            break;
           }
           $473 = HEAP32[$8>>2]|0;
           HEAP32[$propertyTreeInstanceScale>>2] = $473;
           HEAP32[$9>>2] = -1;
           __THREW__ = 0;
           invoke_vii(2618,($9|0),(803368|0));
           $474 = __THREW__; __THREW__ = 0;
           $475 = $474&1;
           if ($475) {
            label = 49;
            break;
           }
           $476 = HEAP32[$9>>2]|0;
           HEAP32[$propertySquashPlaneNormal>>2] = $476;
           HEAP32[$10>>2] = -1;
           __THREW__ = 0;
           invoke_vii(2618,($10|0),(803392|0));
           $477 = __THREW__; __THREW__ = 0;
           $478 = $477&1;
           if ($478) {
            label = 49;
            break;
           }
           $479 = HEAP32[$10>>2]|0;
           HEAP32[$propertySquashAmount>>2] = $479;
           HEAP32[$11>>2] = -1;
           __THREW__ = 0;
           invoke_vii(2618,($11|0),(803408|0));
           $480 = __THREW__; __THREW__ = 0;
           $481 = $480&1;
           if ($481) {
            label = 49;
            break;
           }
           $482 = HEAP32[$11>>2]|0;
           HEAP32[$propertyWind>>2] = $482;
           HEAPF32[$billboardOffsetFactor>>2] = Math_fround(1.0);
           $483 = HEAP32[$79>>2]|0;
           $484 = (($483) + 24|0);
           $485 = HEAP8[$484>>0]|0;
           $486 = ($485<<24>>24)==(0);
           if (!($486)) {
            __THREW__ = 0;
            invoke_viii(2039,($483|0),($tempBillboardAngleFactor|0),($billboardOffsetFactor|0));
            $487 = __THREW__; __THREW__ = 0;
            $488 = $487&1;
            if ($488) {
             label = 49;
             break;
            }
           }
           $489 = HEAP32[$167>>2]|0;
           $490 = ($489|0)==(0);
           if ($490) {
            $writePos$0$lcssa = 0;
           } else {
            $491 = HEAP32[$166>>2]|0;
            $492 = HEAP32[$this>>2]|0;
            $493 = (($492) + 16|0);
            $494 = HEAP32[$493>>2]|0;
            $495 = Math_fround(HEAPF32[$129>>2]);
            $496 = (($this) + 184|0);
            $844 = $489;$i6$093 = 0;$writePos$094 = 0;
            while(1) {
             $497 = (($491) + ($i6$093<<2)|0);
             $498 = HEAP32[$497>>2]|0;
             $499 = ((($494) + (($498*40)|0)|0) + 36|0);
             $500 = Math_fround(HEAPF32[$499>>2]);
             $501 = $500 < $495;
             do {
              if ($501) {
               $502 = HEAP32[$496>>2]|0;
               $503 = (($502) + ($498<<2)|0);
               $504 = HEAP32[$503>>2]|0;
               $505 = ($504|0)==(-1);
               if ($505) {
                $510 = $844;$writePos$1 = $writePos$094;
                break;
               }
               $506 = (($writePos$094) + 1)|0;
               $507 = (($491) + ($writePos$094<<2)|0);
               HEAP32[$507>>2] = $498;
               $$pre = HEAP32[$167>>2]|0;
               $510 = $$pre;$writePos$1 = $506;
              } else {
               $510 = $844;$writePos$1 = $writePos$094;
              }
             } while(0);
             $508 = (($i6$093) + 1)|0;
             $509 = ($508>>>0)<($510>>>0);
             if ($509) {
              $844 = $510;$i6$093 = $508;$writePos$094 = $writePos$1;
             } else {
              $writePos$0$lcssa = $writePos$1;
              break;
             }
            }
           }
           HEAP32[$167>>2] = $writePos$0$lcssa;
           $511 = HEAP32[$168>>2]|0;
           $512 = $511 & 2147483647;
           $513 = ($512>>>0)<($writePos$0$lcssa>>>0);
           if ($513) {
            $514 = ($511|0)>(-1);
            if ($514) {
             HEAP32[$168>>2] = $writePos$0$lcssa;
             $515 = HEAP32[$166>>2]|0;
             $516 = $writePos$0$lcssa << 2;
             $517 = (($this) + 96|0);
             $518 = HEAP32[$517>>2]|0;
             HEAP32[$12>>2] = $518;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$12+0>>2]|0;
             $519 = (invoke_iiiiiiii(108,($515|0),($516|0),4,($$byval_copy40|0),0,(803264|0),370)|0);
             $520 = __THREW__; __THREW__ = 0;
             $521 = $520&1;
             if ($521) {
              label = 49;
              break;
             }
             HEAP32[$166>>2] = $519;
            } else {
             $522 = $writePos$0$lcssa << 2;
             $523 = (($this) + 96|0);
             $524 = HEAP32[$523>>2]|0;
             HEAP32[$13>>2] = $524;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$13+0>>2]|0;
             $525 = (invoke_iiiiiii(102,($522|0),4,($$byval_copy40|0),0,(803264|0),352)|0);
             $526 = __THREW__; __THREW__ = 0;
             $527 = $526&1;
             if ($527) {
              label = 49;
              break;
             }
             $528 = HEAP32[$166>>2]|0;
             $529 = HEAP32[$167>>2]|0;
             $530 = $529 << 2;
             _memcpy(($525|0),($528|0),($530|0))|0;
             HEAP32[$168>>2] = $writePos$0$lcssa;
             HEAP32[$166>>2] = $525;
            }
            $$pr132 = HEAP32[$167>>2]|0;
            $533 = $$pr132;
           } else {
            $533 = $writePos$0$lcssa;
           }
           $531 = HEAP32[628512>>2]|0;
           $532 = ($533|0)==(0);
           L186: do {
            if (!($532)) {
             $534 = (($this) + 184|0);
             $535 = (($this) + 152|0);
             $536 = $$0$i < Math_fround(0.0);
             $537 = Math_fround(-$$0$i);
             $$idx = (($this) + 56|0);
             $$idx4 = (($this) + 60|0);
             $$idx5 = (($this) + 64|0);
             $$idx6 = (($this) + 44|0);
             $$idx7 = (($this) + 48|0);
             $$idx8 = (($this) + 52|0);
             $538 = (($bounds) + 4|0);
             $539 = (($bounds) + 8|0);
             $540 = (($bounds) + 12|0);
             $541 = (($bounds) + 16|0);
             $542 = (($bounds) + 20|0);
             $543 = (($force$i) + 8|0);
             $544 = Math_fround($464 * Math_fround(4.69999980926513671875));
             $545 = Math_fround($464 * Math_fround(4.30000019073486328125));
             $546 = (($force$i) + 12|0);
             $547 = (($18) + 4|0);
             $548 = (($18) + 8|0);
             $549 = (($q$i) + 12|0);
             $550 = (($q$i) + 8|0);
             $551 = (($q$i) + 4|0);
             $552 = (($19) + 4|0);
             $553 = (($19) + 8|0);
             $554 = (($19) + 12|0);
             $555 = (($cameraDir) + 4|0);
             $556 = (($cameraDir) + 8|0);
             $557 = HEAP32[641904>>2]|0;
             $558 = (($36) + 4|0);
             $559 = (($36) + 8|0);
             $560 = (($36) + 12|0);
             $561 = (($37) + 4|0);
             $562 = (($37) + 8|0);
             $563 = (($37) + 12|0);
             $564 = (($38) + 4|0);
             $565 = (($38) + 8|0);
             $566 = (($38) + 12|0);
             $i7$092 = 0;
             while(1) {
              $567 = HEAP32[$this>>2]|0;
              $568 = HEAP32[$166>>2]|0;
              $569 = (($568) + ($i7$092<<2)|0);
              $570 = HEAP32[$569>>2]|0;
              $571 = (($567) + 16|0);
              $572 = HEAP32[$571>>2]|0;
              $573 = HEAP32[$534>>2]|0;
              $574 = (($573) + ($570<<2)|0);
              $575 = HEAP32[$574>>2]|0;
              $576 = HEAP32[$535>>2]|0;
              $577 = (($576) + (($575*24)|0)|0);
              $578 = HEAP32[$577>>2]|0;
              $579 = ((($572) + (($570*40)|0)|0) + 32|0);
              $580 = HEAP32[$579>>2]|0;
              $581 = (($567) + 28|0);
              $582 = HEAP32[$581>>2]|0;
              $583 = $536 ? $537 : $$0$i;
              $584 = !($583 <= Math_fround(9.99999997475242707878E-7));
              if ($584) {
               $585 = ((($572) + (($570*40)|0)|0) + 36|0);
               $586 = Math_fround(HEAPF32[$585>>2]);
               $587 = (Math_fround(Math_sqrt((Math_fround($586)))));
               $588 = Math_fround($126 - $587);
               $589 = Math_fround($588 / $$0$i);
               $590 = $589 < Math_fround(0.0);
               if ($590) {
                $$0$i$i = Math_fround(0.0);
               } else {
                $591 = $589 > Math_fround(1.0);
                $$$i$i = $591 ? Math_fround(1.0) : $589;
                $$0$i$i = $$$i$i;
               }
               $592 = Math_fround($$0$i$i * Math_fround(-2.0));
               $593 = Math_fround($$0$i$i * $592);
               $594 = Math_fround($$0$i$i * $593);
               $595 = Math_fround($$0$i$i * Math_fround(3.0));
               $596 = Math_fround($$0$i$i * $595);
               $597 = Math_fround($596 + $594);
               $598 = Math_fround(Math_fround(1.0) - $597);
               $599 = Math_fround($598 * Math_fround(0.0));
               $600 = Math_fround($597 + $599);
               $skewFade$0 = $600;
              } else {
               $skewFade$0 = Math_fround(1.0);
              }
              $613 = Math_fround(Math_fround(1.0) - $skewFade$0);
              $614 = Math_fround($613 * Math_fround(0.0399999991059303283691));
              $615 = Math_fround($skewFade$0 + $614);
              $616 = $skewFade$0 >= Math_fround(1.0);
              ;HEAP32[$bounds+0>>2]=0|0;HEAP32[$bounds+4>>2]=0|0;HEAP32[$bounds+8>>2]=0|0;HEAP32[$bounds+12>>2]=0|0;HEAP32[$bounds+16>>2]=0|0;HEAP32[$bounds+20>>2]=0|0;
              $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
              $$idx4$val = Math_fround(HEAPF32[$$idx4>>2]);
              $$idx5$val = Math_fround(HEAPF32[$$idx5>>2]);
              $$idx6$val = Math_fround(HEAPF32[$$idx6>>2]);
              $$idx7$val = Math_fround(HEAPF32[$$idx7>>2]);
              $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
              $617 = (($572) + (($570*40)|0)|0);
              $618 = Math_fround(HEAPF32[$617>>2]);
              $619 = Math_fround($$idx6$val * $618);
              $620 = ((($572) + (($570*40)|0)|0) + 4|0);
              $621 = Math_fround(HEAPF32[$620>>2]);
              $622 = Math_fround($$idx7$val * $621);
              $623 = ((($572) + (($570*40)|0)|0) + 8|0);
              $624 = Math_fround(HEAPF32[$623>>2]);
              $625 = Math_fround($$idx8$val * $624);
              $626 = Math_fround($$idx$val + $619);
              $627 = Math_fround($$idx4$val + $622);
              $628 = Math_fround($$idx5$val + $625);
              $629 = ((($572) + (($570*40)|0)|0) + 12|0);
              $630 = Math_fround(HEAPF32[$629>>2]);
              $631 = ((($572) + (($570*40)|0)|0) + 16|0);
              $632 = Math_fround(HEAPF32[$631>>2]);
              $633 = ((($582) + ($580<<7)|0) + 112|0);
              $634 = Math_fround(HEAPF32[$633>>2]);
              $635 = Math_fround($630 * $634);
              $636 = ((($582) + ($580<<7)|0) + 116|0);
              $637 = Math_fround(HEAPF32[$636>>2]);
              $638 = Math_fround($632 * $637);
              $639 = ((($582) + ($580<<7)|0) + 120|0);
              $640 = Math_fround(HEAPF32[$639>>2]);
              $641 = Math_fround($630 * $640);
              HEAPF32[$bounds>>2] = $626;
              HEAPF32[$538>>2] = $627;
              HEAPF32[$539>>2] = $628;
              HEAPF32[$540>>2] = $635;
              HEAPF32[$541>>2] = $638;
              HEAPF32[$542>>2] = $641;
              $642 = ((($582) + ($580<<7)|0) + 124|0);
              $643 = Math_fround(HEAPF32[$642>>2]);
              $644 = Math_fround($skewFade$0 * $643);
              __THREW__ = 0;
              $645 = (invoke_i(126)|0);
              $646 = __THREW__; __THREW__ = 0;
              $647 = $646&1;
              if ($647) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(2040,($force$i|0),($645|0),($bounds|0));
              $648 = __THREW__; __THREW__ = 0;
              $649 = $648&1;
              if ($649) {
               break;
              }
              $650 = Math_fround(HEAPF32[$543>>2]);
              $651 = Math_fround(HEAPF32[$force$i>>2]);
              $652 = Math_fround($650 * $650);
              $653 = Math_fround($652 + Math_fround(0.0));
              $654 = Math_fround($651 * $651);
              $655 = Math_fround($653 + $654);
              $656 = (Math_fround(Math_sqrt((Math_fround($655)))));
              $657 = $656 > Math_fround(9.99999974737875163555E-6);
              if ($657) {
               $658 = Math_fround(-$651);
               $659 = Math_fround($650 / $656);
               $660 = Math_fround(Math_fround(0.0) / $656);
               $661 = Math_fround($658 / $656);
               $697 = $659;$699 = $660;$701 = $661;$magnitude$0$i = $656;
              } else {
               $697 = $650;$699 = Math_fround(0.0);$701 = Math_fround(1.0);$magnitude$0$i = Math_fround(0.0);
              }
              $662 = Math_fround(HEAPF32[$bounds>>2]);
              $663 = Math_fround($662 * Math_fround(0.219999998807907104492));
              $664 = Math_fround($663 - $544);
              $665 = Math_fround($662 * Math_fround(9.00500011444091796875));
              __THREW__ = 0;
              $666 = (Math_fround(+(invoke_fff(2,(+$664),(+$665)))));
              $667 = __THREW__; __THREW__ = 0;
              $668 = $667&1;
              if ($668) {
               break;
              }
              $669 = Math_fround(HEAPF32[$539>>2]);
              $670 = Math_fround($669 * Math_fround(0.219999998807907104492));
              $671 = Math_fround($670 - $545);
              $672 = Math_fround($669 * Math_fround(9.00500011444091796875));
              __THREW__ = 0;
              $673 = (Math_fround(+(invoke_fff(2,(+$671),(+$672)))));
              $674 = __THREW__; __THREW__ = 0;
              $675 = $674&1;
              if ($675) {
               break;
              }
              $676 = Math_fround($666 + Math_fround(0.689999997615814208984));
              $677 = Math_fround($676 / Math_fround(1.48300004005432128906));
              $678 = Math_fround($677 * Math_fround(0.699999988079071044921));
              $679 = Math_fround($673 + Math_fround(0.689999997615814208984));
              $680 = Math_fround($679 / Math_fround(1.48300004005432128906));
              $681 = Math_fround($680 * Math_fround(0.5));
              $682 = Math_fround($644 * Math_fround(0.0174532923847436904907));
              $683 = Math_fround(HEAPF32[$546>>2]);
              $684 = Math_fround($682 * $683);
              $685 = Math_fround($678 * $684);
              $686 = Math_fround($684 * Math_fround(0.0));
              $687 = Math_fround($681 * $684);
              HEAPF32[$18>>2] = $685;
              HEAPF32[$547>>2] = $686;
              HEAPF32[$548>>2] = $687;
              __THREW__ = 0;
              invoke_vii(3427,($q$i|0),($18|0));
              $688 = __THREW__; __THREW__ = 0;
              $689 = $688&1;
              if ($689) {
               break;
              }
              $690 = Math_fround($644 * Math_fround(7.0));
              $691 = Math_fround($690 * Math_fround(0.0174532923847436904907));
              $692 = Math_fround($691 * $magnitude$0$i);
              $693 = Math_fround($692 * Math_fround(0.5));
              $694 = (Math_fround(+(Math_sin((+$693)))));
              $695 = (Math_fround(+(Math_cos((+$693)))));
              $696 = Math_fround($697 * $694);
              $698 = Math_fround($699 * $694);
              $700 = Math_fround($701 * $694);
              $702 = Math_fround(HEAPF32[$q$i>>2]);
              $703 = Math_fround($695 * $702);
              $704 = Math_fround(HEAPF32[$549>>2]);
              $705 = Math_fround($696 * $704);
              $706 = Math_fround($703 + $705);
              $707 = Math_fround(HEAPF32[$550>>2]);
              $708 = Math_fround($698 * $707);
              $709 = Math_fround($706 + $708);
              $710 = Math_fround(HEAPF32[$551>>2]);
              $711 = Math_fround($700 * $710);
              $712 = Math_fround($709 - $711);
              $713 = Math_fround($695 * $710);
              $714 = Math_fround($698 * $704);
              $715 = Math_fround($714 + $713);
              $716 = Math_fround($700 * $702);
              $717 = Math_fround($716 + $715);
              $718 = Math_fround($696 * $707);
              $719 = Math_fround($717 - $718);
              $720 = Math_fround($695 * $707);
              $721 = Math_fround($700 * $704);
              $722 = Math_fround($721 + $720);
              $723 = Math_fround($696 * $710);
              $724 = Math_fround($722 + $723);
              $725 = Math_fround($698 * $702);
              $726 = Math_fround($724 - $725);
              $727 = Math_fround($695 * $704);
              $728 = Math_fround($696 * $702);
              $729 = Math_fround($727 - $728);
              $730 = Math_fround($698 * $710);
              $731 = Math_fround($729 - $730);
              $732 = Math_fround($700 * $707);
              $733 = Math_fround($731 - $732);
              HEAPF32[$19>>2] = $712;
              HEAPF32[$552>>2] = $719;
              HEAPF32[$553>>2] = $726;
              HEAPF32[$554>>2] = $733;
              __THREW__ = 0;
              invoke_viiii(419,($rotate|0),(616680|0),($19|0),(616696|0));
              $734 = __THREW__; __THREW__ = 0;
              $735 = $734&1;
              if ($735) {
               break;
              }
              ;HEAP32[$wind+0>>2]=HEAP32[$force$i+0>>2]|0;HEAP32[$wind+4>>2]=HEAP32[$force$i+4>>2]|0;HEAP32[$wind+8>>2]=HEAP32[$force$i+8>>2]|0;HEAP32[$wind+12>>2]=HEAP32[$force$i+12>>2]|0;
              $736 = ((($582) + ($580<<7)|0) + 92|0);
              $737 = Math_fround(HEAPF32[$736>>2]);
              $738 = Math_fround(HEAPF32[$629>>2]);
              $739 = Math_fround($737 * $738);
              $740 = Math_fround($739 * Math_fround(0.5));
              $741 = Math_fround(HEAPF32[$cameraDir>>2]);
              $742 = Math_fround(HEAPF32[$555>>2]);
              $743 = Math_fround(HEAPF32[$556>>2]);
              $744 = (($578) + 204|0);
              $745 = (($744) + 8|0);
              HEAP32[$745>>2] = 0;
              $746 = (($744) + 24|0);
              HEAP32[$746>>2] = 0;
              $747 = (($744) + 32|0);
              HEAP32[$747>>2] = $557;
              __THREW__ = 0;
              invoke_viii(2041,($744|0),($propertyTerrainEngineBendTree|0),($rotate|0));
              $748 = __THREW__; __THREW__ = 0;
              $749 = $748&1;
              if ($749) {
               break;
              }
              $750 = ((($572) + (($570*40)|0)|0) + 24|0);
              $751 = ((($572) + (($570*40)|0)|0) + 28|0);
              $752 = HEAP32[$750>>2]|0;
              $753 = $752 & 255;
              $754 = HEAP32[$751>>2]|0;
              $755 = $754 & 255;
              $756 = (($755) + 1)|0;
              $757 = Math_imul($756, $753)|0;
              $758 = $757 >>> 8;
              $759 = $752 >>> 8;
              $760 = $759 & 255;
              $761 = $754 >>> 8;
              $762 = $761 & 255;
              $763 = (($762) + 1)|0;
              $764 = Math_imul($763, $760)|0;
              $765 = $752 & 16711680;
              $766 = $754 >>> 16;
              $767 = $766 & 255;
              $768 = (($767) + 1)|0;
              $769 = Math_imul($768, $765)|0;
              $770 = $769 >>> 24;
              $771 = $759 & 16711680;
              $772 = $754 >>> 24;
              $773 = (($772) + 1)|0;
              $774 = Math_imul($773, $771)|0;
              $775 = $764 >>> 8;
              $776 = $774 >>> 24;
              $777 = $758 & 255;
              $778 = (Math_fround(($777|0)));
              $779 = Math_fround($778 / Math_fround(255.0));
              $780 = $775 & 255;
              $781 = (Math_fround(($780|0)));
              $782 = Math_fround($781 / Math_fround(255.0));
              $783 = (Math_fround(($770|0)));
              $784 = Math_fround($783 / Math_fround(255.0));
              $785 = (Math_fround(($776|0)));
              $786 = Math_fround($785 / Math_fround(255.0));
              HEAPF32[$36>>2] = $779;
              HEAPF32[$558>>2] = $782;
              HEAPF32[$559>>2] = $784;
              HEAPF32[$560>>2] = $786;
              __THREW__ = 0;
              invoke_viii(2028,($744|0),($propertyTreeInstanceColor|0),($36|0));
              $787 = __THREW__; __THREW__ = 0;
              $788 = $787&1;
              if ($788) {
               break;
              }
              $789 = Math_fround(HEAPF32[$629>>2]);
              $790 = Math_fround(HEAPF32[$631>>2]);
              HEAPF32[$37>>2] = $789;
              HEAPF32[$561>>2] = $790;
              HEAPF32[$562>>2] = $789;
              HEAPF32[$563>>2] = Math_fround(1.0);
              __THREW__ = 0;
              invoke_viii(2027,($744|0),($propertyTreeInstanceScale|0),($37|0));
              $791 = __THREW__; __THREW__ = 0;
              $792 = $791&1;
              if ($792) {
               break;
              }
              $793 = Math_fround(HEAPF32[$billboardOffsetFactor>>2]);
              $794 = Math_fround($740 * $793);
              HEAPF32[$38>>2] = $741;
              HEAPF32[$564>>2] = $742;
              HEAPF32[$565>>2] = $743;
              HEAPF32[$566>>2] = $794;
              __THREW__ = 0;
              invoke_viii(2027,($744|0),($propertySquashPlaneNormal|0),($38|0));
              $795 = __THREW__; __THREW__ = 0;
              $796 = $795&1;
              if ($796) {
               break;
              }
              __THREW__ = 0;
              invoke_viif(48,($744|0),($propertySquashAmount|0),(+$615));
              $797 = __THREW__; __THREW__ = 0;
              $798 = $797&1;
              if ($798) {
               break;
              }
              __THREW__ = 0;
              invoke_viii(2027,($744|0),($propertyWind|0),($wind|0));
              $799 = __THREW__; __THREW__ = 0;
              $800 = $799&1;
              if ($800) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3708,($744|0));
              $801 = __THREW__; __THREW__ = 0;
              $802 = $801&1;
              if ($802) {
               break;
              }
              __THREW__ = 0;
              invoke_vii(3428,($578|0),($616|0));
              $803 = __THREW__; __THREW__ = 0;
              $804 = $803&1;
              if ($804) {
               break;
              }
              $805 = ((($576) + (($575*24)|0)|0) + 4|0);
              HEAP32[$805>>2] = $layer;
              $806 = (($i7$092) + 1)|0;
              $807 = HEAP32[$167>>2]|0;
              $808 = ($806>>>0)<($807>>>0);
              if ($808) {
               $i7$092 = $806;
              } else {
               break L186;
              }
             }
             $601 = ___cxa_find_matching_catch()|0;
             $602 = tempRet0;
             HEAP32[$16>>2] = $531;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$16+0>>2]|0;
             invoke_vii(2591,(0|0),($$byval_copy40|0));
             $603 = __THREW__; __THREW__ = 0;
             $604 = $603&1;
             if (!($604)) {
              HEAP32[$15>>2] = $531;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$15+0>>2]|0;
              invoke_vii(2591,(0|0),($$byval_copy40|0));
              $605 = __THREW__; __THREW__ = 0;
              $606 = $605&1;
              if ($606) {
               break L16;
              } else {
               $$0 = $601;$$01 = $602;
               break L57;
              }
             }
             $607 = ___cxa_find_matching_catch(0|0)|0;
             $608 = tempRet0;
             HEAP32[$14>>2] = $531;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$14+0>>2]|0;
             invoke_vii(2591,(0|0),($$byval_copy40|0));
             $609 = __THREW__; __THREW__ = 0;
             $610 = $609&1;
             if ($610) {
              $611 = ___cxa_find_matching_catch(0|0)|0;
              $612 = tempRet0;
              ___clang_call_terminate($611);
              // unreachable;
             } else {
              $eh$lpad$body34$indexZ2D = $607;
              ___clang_call_terminate($eh$lpad$body34$indexZ2D);
              // unreachable;
             }
            }
           } while(0);
           HEAP32[$24>>2] = $531;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$24+0>>2]|0;
           invoke_vii(2591,(0|0),($$byval_copy40|0));
           $809 = __THREW__; __THREW__ = 0;
           $810 = $809&1;
           if ($810) {
            $813 = ___cxa_find_matching_catch()|0;
            $814 = tempRet0;
            HEAP32[$22>>2] = $531;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$22+0>>2]|0;
            invoke_vii(2591,(0|0),($$byval_copy40|0));
            $815 = __THREW__; __THREW__ = 0;
            $816 = $815&1;
            if (!($816)) {
             $eh$lpad$body$index7Z2D = $814;$eh$lpad$body$indexZ2D = $813;
             label = 50;
             break;
            }
            $817 = ___cxa_find_matching_catch(0|0)|0;
            $818 = tempRet0;
            ___clang_call_terminate($817);
            // unreachable;
           }
           HEAP32[$23>>2] = $531;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$23+0>>2]|0;
           invoke_vii(2591,(0|0),($$byval_copy40|0));
           $811 = __THREW__; __THREW__ = 0;
           $812 = $811&1;
           if ($812) {
            label = 49;
            break;
           }
           $819 = HEAP32[$172>>2]|0;
           $820 = ($819|0)>(-1);
           if ($820) {
            $821 = HEAP32[$billboardsList>>2]|0;
            $822 = HEAP32[$170>>2]|0;
            HEAP32[$25>>2] = $822;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$25+0>>2]|0;
            invoke_vii(2591,($821|0),($$byval_copy40|0));
            $823 = __THREW__; __THREW__ = 0;
            $824 = $823&1;
            if ($824) {
             label = 35;
             break L55;
            }
            HEAP32[$billboardsList>>2] = 0;
           }
           $825 = ($826|0)>(-1);
           if ($825) {
            HEAP32[$26>>2] = $140;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$26+0>>2]|0;
            invoke_vii(2591,($177|0),($$byval_copy40|0));
            $827 = __THREW__; __THREW__ = 0;
            $828 = $827&1;
            if ($828) {
             label = 20;
             break L16;
            }
           }
           __ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb(0);
           STACKTOP = sp;return;
          }
         }
        } while(0);
        if ((label|0) == 49) {
         $194 = ___cxa_find_matching_catch()|0;
         $195 = tempRet0;
         $eh$lpad$body$index7Z2D = $195;$eh$lpad$body$indexZ2D = $194;
         label = 50;
        }
        if ((label|0) == 50) {
         $$0 = $eh$lpad$body$indexZ2D;$$01 = $eh$lpad$body$index7Z2D;
        }
        $829 = HEAP32[$172>>2]|0;
        $830 = ($829|0)>(-1);
        if ($830) {
         $831 = HEAP32[$billboardsList>>2]|0;
         $832 = HEAP32[$170>>2]|0;
         HEAP32[$27>>2] = $832;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$27+0>>2]|0;
         invoke_vii(2591,($831|0),($$byval_copy40|0));
         $833 = __THREW__; __THREW__ = 0;
         $834 = $833&1;
         if ($834) {
          break L16;
         }
         HEAP32[$billboardsList>>2] = 0;
         $$1 = $$0;$$12 = $$01;
        } else {
         $$1 = $$0;$$12 = $$01;
        }
       }
      } while(0);
      if ((label|0) == 35) {
       $156 = ___cxa_find_matching_catch()|0;
       $157 = tempRet0;
       $$1 = $156;$$12 = $157;
      }
      $835 = ($826|0)>(-1);
      if ($835) {
       HEAP32[$28>>2] = $140;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy40+0>>2]=HEAP32[$28+0>>2]|0;
       invoke_vii(2591,($177|0),($$byval_copy40|0));
       $836 = __THREW__; __THREW__ = 0;
       $837 = $836&1;
       if (!($837)) {
        $$2 = $$1;$$23 = $$12;
        label = 184;
       }
      } else {
       $$2 = $$1;$$23 = $$12;
       label = 184;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $108 = ___cxa_find_matching_catch()|0;
  $109 = tempRet0;
  $$2 = $108;$$23 = $109;
  label = 184;
 }
 if ((label|0) == 184) {
  __THREW__ = 0;
  invoke_vi(3396,0);
  $838 = __THREW__; __THREW__ = 0;
  $839 = $838&1;
  if (!($839)) {
   ___resumeException($$2|0);
   // unreachable;
  }
 }
 $840 = ___cxa_find_matching_catch(0|0)|0;
 $841 = tempRet0;
 $eh$lpad$body34$indexZ2D = $840;
 ___clang_call_terminate($eh$lpad$body34$indexZ2D);
 // unreachable;
}
function __ZN12TreeRenderer23UpdateWindAssetPointersEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$pre = 0, $$pre7 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var $doUpdate$0$off04 = 0, $doUpdate$1$off0 = 0, $i$03 = 0, $i1$02 = 0, $pos$i$i$i$i = 0, $temp$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 236|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 232|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $7 = $4;$doUpdate$0$off04 = 0;$i$03 = 0;
 while(1) {
  $6 = ((($7) + (($i$03*28)|0)|0) + 16|0);
  $8 = HEAP32[$6>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $$0$i = 0;$44 = $7;
  } else {
   HEAP32[$0>>2] = $8;
   $10 = HEAP32[560624>>2]|0;
   $11 = ($10|0)==(0|0);
   if ($11) {
    label = 12;
   } else {
    $12 = (($10) + 36|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($10) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13|0)==($15|0);
    do {
     if ($16) {
      $17 = (($10) + 28|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($10) + 32|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($18) + ($20<<3)|0);
      $37 = $21;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$10,$0);
      $22 = HEAP32[$pos$i$i$i$i>>2]|0;
      $23 = ($22|0)==(-1);
      $24 = (($10) + 28|0);
      $25 = HEAP32[$24>>2]|0;
      if ($23) {
       $26 = (($10) + 32|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = (($25) + ($27<<3)|0);
       $37 = $28;
       break;
      } else {
       $29 = (($25) + ($22<<3)|0);
       $37 = $29;
       break;
      }
     }
    } while(0);
    $30 = HEAP32[560624>>2]|0;
    $31 = (($30) + 28|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 32|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($32) + ($34<<3)|0);
    $36 = ($37|0)==($35|0);
    if ($36) {
     label = 12;
    } else {
     $38 = (($37) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      label = 12;
     } else {
      $temp$0$i = $39;
     }
    }
   }
   if ((label|0) == 12) {
    label = 0;
    $41 = HEAP32[$6>>2]|0;
    $42 = (__Z31ReadObjectFromPersistentManageri($41)|0);
    $temp$0$i = $42;
   }
   $$pre = HEAP32[$3>>2]|0;
   $$0$i = $temp$0$i;$44 = $$pre;
  }
  $43 = ((($44) + (($i$03*28)|0)|0) + 20|0);
  $45 = HEAP32[$43>>2]|0;
  $46 = ($45|0)==($$0$i|0);
  if ($46) {
   $51 = $44;$doUpdate$1$off0 = $doUpdate$0$off04;
  } else {
   HEAP32[$43>>2] = $$0$i;
   $$pre7 = HEAP32[$3>>2]|0;
   $51 = $$pre7;$doUpdate$1$off0 = 1;
  }
  $47 = (($i$03) + 1)|0;
  $48 = HEAP32[$1>>2]|0;
  $49 = $48;
  $50 = $51;
  $52 = (($49) - ($50))|0;
  $53 = (($52|0) / 28)&-1;
  $54 = ($47>>>0)<($53>>>0);
  if ($54) {
   $7 = $51;$doUpdate$0$off04 = $doUpdate$1$off0;$i$03 = $47;
  } else {
   break;
  }
 }
 if (!($doUpdate$1$off0)) {
  STACKTOP = sp;return;
 }
 $55 = (($this) + 248|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($this) + 244|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($56|0)==($58|0);
 if ($59) {
  STACKTOP = sp;return;
 } else {
  $61 = $58;$65 = $51;$i1$02 = 0;
 }
 while(1) {
  $60 = ((($61) + (($i1$02*148)|0)|0) + 2|0);
  $62 = HEAP16[$60>>1]|0;
  $63 = $62&65535;
  $64 = ((($65) + (($63*28)|0)|0) + 20|0);
  $66 = HEAP32[$64>>2]|0;
  $67 = ((($61) + (($i1$02*148)|0)|0) + 28|0);
  HEAP32[$67>>2] = $66;
  $68 = (($i1$02) + 1)|0;
  $69 = HEAP32[$55>>2]|0;
  $70 = HEAP32[$57>>2]|0;
  $71 = $69;
  $72 = $70;
  $73 = (($71) - ($72))|0;
  $74 = (($73|0) / 148)&-1;
  $75 = ($68>>>0)<($74>>>0);
  if (!($75)) {
   break;
  }
  $$pre9 = HEAP32[$3>>2]|0;
  $61 = $70;$65 = $$pre9;$i1$02 = $68;
 }
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer14RenderLODTreesER6Camerai($this,$camera,$layer) {
 $this = $this|0;
 $camera = $camera|0;
 $layer = $layer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $i1$03 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetLODGroupManagerv()|0);
 $1 = (($0) + 20|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($this) + 224|0);
 HEAPF32[$3>>2] = $2;
 $4 = (__Z18GetLODGroupManagerv()|0);
 $5 = (($4) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 228|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 84|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($layer|0);
 if (!($10)) {
  $11 = (($this) + 264|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if (!($13)) {
   $14 = (($this) + 256|0);
   $15 = HEAP32[$14>>2]|0;
   $i$06 = 0;
   while(1) {
    $16 = ((($15) + (($i$06*24)|0)|0) + 4|0);
    HEAP32[$16>>2] = $layer;
    $17 = (($i$06) + 1)|0;
    $18 = HEAP32[$11>>2]|0;
    $19 = ($17>>>0)<($18>>>0);
    if ($19) {
     $i$06 = $17;
    } else {
     break;
    }
   }
  }
 }
 $20 = (($this) + 288|0);
 $21 = (($this) + 292|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==($20|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($this) + 256|0);
 $27 = $22;
 while(1) {
  $25 = (__Z24GetBillboardBatchManagerv()|0);
  $26 = (($27) + 8|0);
  $28 = (__ZN21BillboardBatchManager23GetMaterialIntermediateERK4PPtrI14BillboardAssetE($25,$26)|0);
  $29 = (__Z24GetBillboardBatchManagerv()|0);
  $30 = (__ZN21BillboardBatchManager7GetMeshERK4PPtrI14BillboardAssetE($29,$26)|0);
  $31 = ($28|0)==(0|0);
  if ($31) {
   $40 = 0;
  } else {
   $32 = (($28) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $40 = $33;
  }
  $34 = ($30|0)==(0|0);
  if ($34) {
   $44 = 0;
  } else {
   $35 = (($30) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $44 = $36;
  }
  $37 = (($27) + 12|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($40|0)==($38|0);
  $41 = (($27) + 16|0);
  if ($39) {
   $42 = HEAP32[$41>>2]|0;
   $43 = ($44|0)==($42|0);
   if (!($43)) {
    label = 13;
   }
  } else {
   label = 13;
  }
  if ((label|0) == 13) {
   label = 0;
   HEAP32[$37>>2] = $40;
   HEAP32[$41>>2] = $44;
   $45 = ($40|0)==(0);
   if ($45) {
    $56 = 1;
   } else {
    $46 = ($44|0)==(0);
    $phitmp = $46&1;
    $56 = $phitmp;
   }
   $47 = (($27) + 28|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ($48|0)==(0);
   if (!($49)) {
    $50 = (($27) + 20|0);
    $i1$03 = 0;
    while(1) {
     $51 = HEAP32[$50>>2]|0;
     $52 = (($51) + ($i1$03<<2)|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = HEAP32[$24>>2]|0;
     $55 = ((($54) + (($53*24)|0)|0) + 22|0);
     HEAP8[$55>>0] = $56;
     $57 = (($54) + (($53*24)|0)|0);
     $58 = HEAP32[$57>>2]|0;
     __ZN29BillboardTreeInstanceRenderer21UpdateMaterialAndMeshEPN5Unity8MaterialEP4Mesh($58,$28,$30);
     $59 = (($i1$03) + 1)|0;
     $60 = HEAP32[$47>>2]|0;
     $61 = ($59>>>0)<($60>>>0);
     if ($61) {
      $i1$03 = $59;
     } else {
      break;
     }
    }
   }
  }
  $62 = (($27) + 4|0);
  $63 = HEAP32[$62>>2]|0;
  $64 = ($63|0)==($20|0);
  if ($64) {
   break;
  } else {
   $27 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer13RenderRecurseEP14TreeBinaryTreePK5PlaneR13dynamic_arrayIjLj4EERK8Vector3f($this,$binTree,$planes,$closeupBillboards,$cameraPos) {
 $this = $this|0;
 $binTree = $binTree|0;
 $planes = $planes|0;
 $closeupBillboards = $closeupBillboards|0;
 $cameraPos = $cameraPos|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $$01$i = 0, $$byval_copy5 = 0, $$pre = Math_fround(0), $$pre10 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = Math_fround(0);
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0);
 var $129 = Math_fround(0), $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0);
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = Math_fround(0), $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0);
 var $219 = 0, $22 = Math_fround(0), $220 = Math_fround(0), $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = Math_fround(0), $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = Math_fround(0), $233 = Math_fround(0), $234 = Math_fround(0), $235 = Math_fround(0), $236 = 0;
 var $237 = Math_fround(0), $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = 0, $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0);
 var $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = Math_fround(0), $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0), $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = Math_fround(0), $270 = 0, $28 = Math_fround(0), $29 = Math_fround(0);
 var $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0;
 var $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0);
 var $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cameraPos$idx$val = Math_fround(0), $cameraPos$idx2 = 0, $cameraPos$idx2$val = Math_fround(0);
 var $exitcond$i = 0, $exitcond39$i = 0, $exitcond40$i = 0, $fSqrDistance$1$1$i = Math_fround(0), $fSqrDistance$1$i = Math_fround(0), $i$035$i = 0, $i$09 = 0, $i1$032$i = 0, $i2$031$i = 0, $index = 0, $sortIndex$0$i = 0, $sortIndex$1$i = 0, $treeBounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp + 40|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $index = sp + 12|0;
 $treeBounds = sp + 16|0;
 $3 = ($binTree|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($binTree) + 20|0);
 $cameraPos$idx$val = Math_fround(HEAPF32[$cameraPos>>2]);
 $cameraPos$idx2 = (($cameraPos) + 8|0);
 $cameraPos$idx2$val = Math_fround(HEAPF32[$cameraPos$idx2>>2]);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($cameraPos$idx$val - $5);
 $7 = (($binTree) + 28|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($cameraPos$idx2$val - $8);
 $10 = (($binTree) + 32|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($binTree) + 40|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(-$11);
 $15 = $6 < $14;
 if ($15) {
  $16 = Math_fround($6 + $11);
  $17 = Math_fround($16 * $16);
  $18 = Math_fround($17 + Math_fround(0.0));
  $fSqrDistance$1$i = $18;
 } else {
  $19 = $6 > $11;
  if ($19) {
   $20 = Math_fround($6 - $11);
   $21 = Math_fround($20 * $20);
   $22 = Math_fround($21 + Math_fround(0.0));
   $fSqrDistance$1$i = $22;
  } else {
   $fSqrDistance$1$i = Math_fround(0.0);
  }
 }
 $23 = Math_fround(-$13);
 $24 = $9 < $23;
 if ($24) {
  $29 = Math_fround($9 + $13);
  $30 = Math_fround($29 * $29);
  $31 = Math_fround($30 + $fSqrDistance$1$i);
  $fSqrDistance$1$1$i = $31;
 } else {
  $25 = $9 > $13;
  if ($25) {
   $26 = Math_fround($9 - $13);
   $27 = Math_fround($26 * $26);
   $28 = Math_fround($27 + $fSqrDistance$1$i);
   $fSqrDistance$1$1$i = $28;
  } else {
   $fSqrDistance$1$1$i = $fSqrDistance$1$i;
  }
 }
 $32 = (($this) + 72|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = $fSqrDistance$1$1$i > $33;
 if ($34) {
  STACKTOP = sp;return;
 }
 $35 = (($binTree) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0);
 if ($37) {
  $38 = (($binTree) + 60|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround($39 * $cameraPos$idx$val);
  $41 = (($binTree) + 64|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($cameraPos) + 4|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = Math_fround($42 * $44);
  $46 = Math_fround($40 + $45);
  $47 = (($binTree) + 68|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = Math_fround($48 * $cameraPos$idx2$val);
  $50 = Math_fround($46 + $49);
  $51 = (($binTree) + 72|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = Math_fround($52 + $50);
  $54 = $53 > Math_fround(0.0);
  if ($54) {
   $55 = (($binTree) + 96|0);
   $56 = HEAP32[$55>>2]|0;
   __ZN12TreeRenderer13RenderRecurseEP14TreeBinaryTreePK5PlaneR13dynamic_arrayIjLj4EERK8Vector3f($this,$56,$planes,$closeupBillboards,$cameraPos);
   $57 = (($binTree) + 92|0);
   $58 = HEAP32[$57>>2]|0;
   __ZN12TreeRenderer13RenderRecurseEP14TreeBinaryTreePK5PlaneR13dynamic_arrayIjLj4EERK8Vector3f($this,$58,$planes,$closeupBillboards,$cameraPos);
   STACKTOP = sp;return;
  } else {
   $59 = (($binTree) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   __ZN12TreeRenderer13RenderRecurseEP14TreeBinaryTreePK5PlaneR13dynamic_arrayIjLj4EERK8Vector3f($this,$60,$planes,$closeupBillboards,$cameraPos);
   $61 = (($binTree) + 96|0);
   $62 = HEAP32[$61>>2]|0;
   __ZN12TreeRenderer13RenderRecurseEP14TreeBinaryTreePK5PlaneR13dynamic_arrayIjLj4EERK8Vector3f($this,$62,$planes,$closeupBillboards,$cameraPos);
   STACKTOP = sp;return;
  }
 }
 $63 = (($this) + 80|0);
 $64 = Math_fround(HEAPF32[$63>>2]);
 $65 = $fSqrDistance$1$1$i > $64;
 if (!($65)) {
  $66 = (($binTree) + 4|0);
  $67 = (($this) + 44|0);
  $68 = (($this) + 48|0);
  $69 = (($this) + 52|0);
  $70 = (($this) + 56|0);
  $71 = (($this) + 60|0);
  $72 = (($this) + 64|0);
  $73 = (($treeBounds) + 4|0);
  $74 = (($treeBounds) + 8|0);
  $75 = (($treeBounds) + 12|0);
  $76 = (($treeBounds) + 16|0);
  $77 = (($treeBounds) + 20|0);
  $78 = (($this) + 92|0);
  $229 = $cameraPos$idx$val;$231 = $cameraPos$idx2$val;$i$09 = 0;
  while(1) {
   $206 = HEAP32[$66>>2]|0;
   $207 = (($206) + ($i$09<<2)|0);
   $208 = HEAP32[$207>>2]|0;
   HEAP32[$index>>2] = $208;
   $209 = HEAP32[$this>>2]|0;
   $210 = (($209) + 16|0);
   $211 = HEAP32[$210>>2]|0;
   $212 = (($211) + (($208*40)|0)|0);
   $213 = Math_fround(HEAPF32[$212>>2]);
   $214 = Math_fround(HEAPF32[$67>>2]);
   $215 = Math_fround($213 * $214);
   $216 = ((($211) + (($208*40)|0)|0) + 4|0);
   $217 = Math_fround(HEAPF32[$216>>2]);
   $218 = Math_fround(HEAPF32[$68>>2]);
   $219 = ((($211) + (($208*40)|0)|0) + 8|0);
   $220 = Math_fround(HEAPF32[$219>>2]);
   $221 = Math_fround(HEAPF32[$69>>2]);
   $222 = Math_fround($220 * $221);
   $223 = Math_fround(HEAPF32[$70>>2]);
   $224 = Math_fround($215 + $223);
   $225 = Math_fround(HEAPF32[$71>>2]);
   $226 = Math_fround(HEAPF32[$72>>2]);
   $227 = Math_fround($222 + $226);
   $228 = Math_fround($224 - $229);
   $230 = Math_fround($227 - $231);
   $232 = Math_fround($228 * $228);
   $233 = Math_fround($232 + Math_fround(0.0));
   $234 = Math_fround($230 * $230);
   $235 = Math_fround($233 + $234);
   $236 = ((($211) + (($208*40)|0)|0) + 36|0);
   HEAPF32[$236>>2] = $235;
   $237 = Math_fround(HEAPF32[$32>>2]);
   $238 = !($235 >= $237);
   do {
    if ($238) {
     $239 = Math_fround($217 * $218);
     $240 = Math_fround($239 + $225);
     $241 = ((($211) + (($208*40)|0)|0) + 12|0);
     $242 = Math_fround(HEAPF32[$241>>2]);
     $243 = ((($211) + (($208*40)|0)|0) + 16|0);
     $244 = Math_fround(HEAPF32[$243>>2]);
     $245 = ((($211) + (($208*40)|0)|0) + 32|0);
     $246 = HEAP32[$245>>2]|0;
     $247 = (($209) + 28|0);
     $248 = HEAP32[$247>>2]|0;
     $249 = ((($248) + ($246<<7)|0) + 100|0);
     ;HEAP32[$treeBounds+0>>2]=HEAP32[$249+0>>2]|0;HEAP32[$treeBounds+4>>2]=HEAP32[$249+4>>2]|0;HEAP32[$treeBounds+8>>2]=HEAP32[$249+8>>2]|0;HEAP32[$treeBounds+12>>2]=HEAP32[$249+12>>2]|0;HEAP32[$treeBounds+16>>2]=HEAP32[$249+16>>2]|0;HEAP32[$treeBounds+20>>2]=HEAP32[$249+20>>2]|0;
     $250 = Math_fround(HEAPF32[$treeBounds>>2]);
     $251 = Math_fround($242 * $250);
     $252 = Math_fround(HEAPF32[$73>>2]);
     $253 = Math_fround($244 * $252);
     $254 = Math_fround(HEAPF32[$74>>2]);
     $255 = Math_fround($242 * $254);
     $256 = Math_fround($224 + $251);
     $257 = Math_fround($240 + $253);
     $258 = Math_fround($227 + $255);
     $259 = Math_fround(HEAPF32[$75>>2]);
     $260 = Math_fround($242 * $259);
     $261 = Math_fround(HEAPF32[$76>>2]);
     $262 = Math_fround($244 * $261);
     $263 = Math_fround(HEAPF32[$77>>2]);
     $264 = Math_fround($242 * $263);
     HEAPF32[$treeBounds>>2] = $256;
     HEAPF32[$73>>2] = $257;
     HEAPF32[$74>>2] = $258;
     HEAPF32[$75>>2] = $260;
     HEAPF32[$76>>2] = $262;
     HEAPF32[$77>>2] = $264;
     $265 = Math_fround(HEAPF32[$63>>2]);
     $266 = !($235 >= $265);
     if (!($266)) {
      $267 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($treeBounds,$planes)|0);
      if ($267) {
       __ZN13dynamic_arrayIjLj4EE9push_backERKj($closeupBillboards,$index);
       break;
      }
     }
     __ZN13dynamic_arrayIjLj4EE9push_backERKj($78,$index);
    }
   } while(0);
   $268 = (($i$09) + 1)|0;
   $269 = HEAP32[$35>>2]|0;
   $270 = ($268>>>0)<($269>>>0);
   if (!($270)) {
    break;
   }
   $$pre = Math_fround(HEAPF32[$cameraPos>>2]);
   $$pre10 = Math_fround(HEAPF32[$cameraPos$idx2>>2]);
   $229 = $$pre;$231 = $$pre10;$i$09 = $268;
  }
  STACKTOP = sp;return;
 }
 $79 = (__Z24IntersectAABBFrustumFullRK4AABBPK5Plane($4,$planes)|0);
 if (!($79)) {
  STACKTOP = sp;return;
 }
 $80 = Math_fround(HEAPF32[$4>>2]);
 $81 = Math_fround(HEAPF32[$10>>2]);
 $82 = Math_fround(HEAPF32[$7>>2]);
 $83 = Math_fround(HEAPF32[$12>>2]);
 $84 = Math_fround($82 - $83);
 $85 = Math_fround($80 + $81);
 $86 = Math_fround($82 + $83);
 $87 = Math_fround(HEAPF32[$cameraPos>>2]);
 $88 = $87 > $85;
 if ($88) {
  $sortIndex$0$i = 2;
 } else {
  $89 = Math_fround($80 - $81);
  $90 = $87 > $89;
  if ($90) {
   $sortIndex$0$i = 1;
  } else {
   $sortIndex$0$i = 0;
  }
 }
 $91 = Math_fround(HEAPF32[$cameraPos$idx2>>2]);
 $92 = $91 > $86;
 do {
  if ($92) {
   $sortIndex$1$i = $sortIndex$0$i;
  } else {
   $93 = $91 > $84;
   if ($93) {
    $94 = (($sortIndex$0$i) + 3)|0;
    $sortIndex$1$i = $94;
    break;
   } else {
    $95 = (($sortIndex$0$i) + 6)|0;
    $sortIndex$1$i = $95;
    break;
   }
  }
 } while(0);
 $96 = (($binTree) + 52|0);
 HEAP32[$96>>2] = $sortIndex$1$i;
 __ZN12TreeRenderer11RenderBatchER14TreeBinaryTreef($this,$binTree,Math_fround(0.0));
 $97 = HEAP32[$96>>2]|0;
 $98 = (($binTree) + 48|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($97|0)==($99|0);
 if ($100) {
  STACKTOP = sp;return;
 }
 HEAP32[$98>>2] = $97;
 $101 = HEAP32[$binTree>>2]|0;
 $102 = HEAP32[$35>>2]|0;
 $103 = HEAP32[628512>>2]|0;
 $104 = $102 << 3;
 HEAP32[$0>>2] = $103;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 $105 = (__Z15malloc_internaljj10MemLabelIdiPKci($104,4,$$byval_copy5,0,803264,352)|0);
 $106 = ($102|0)==(0);
 if (!($106)) {
  $i$035$i = 0;
  while(1) {
   $107 = (($105) + ($i$035$i<<3)|0);
   HEAP32[$107>>2] = $i$035$i;
   $108 = (($i$035$i) + 1)|0;
   $exitcond40$i = ($108|0)==($102|0);
   if ($exitcond40$i) {
    break;
   } else {
    $i$035$i = $108;
   }
  }
 }
 $111 = ($97|0)==(4);
 if (!($111)) {
  if (!($106)) {
   $112 = (($binTree) + 4|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = (($101) + 16|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = (803416 + (($97*12)|0)|0);
   $117 = ((803416 + (($97*12)|0)|0) + 4|0);
   $118 = ((803416 + (($97*12)|0)|0) + 8|0);
   $i1$032$i = 0;
   while(1) {
    $119 = (($113) + ($i1$032$i<<2)|0);
    $120 = HEAP32[$119>>2]|0;
    $121 = (($115) + (($120*40)|0)|0);
    $122 = Math_fround(HEAPF32[$121>>2]);
    $123 = Math_fround(HEAPF32[$116>>2]);
    $124 = Math_fround($122 * $123);
    $125 = ((($115) + (($120*40)|0)|0) + 4|0);
    $126 = Math_fround(HEAPF32[$125>>2]);
    $127 = Math_fround(HEAPF32[$117>>2]);
    $128 = Math_fround($126 * $127);
    $129 = Math_fround($124 + $128);
    $130 = ((($115) + (($120*40)|0)|0) + 8|0);
    $131 = Math_fround(HEAPF32[$130>>2]);
    $132 = Math_fround(HEAPF32[$118>>2]);
    $133 = Math_fround($131 * $132);
    $134 = Math_fround($129 + $133);
    $135 = ((($105) + ($i1$032$i<<3)|0) + 4|0);
    HEAPF32[$135>>2] = $134;
    $136 = (($i1$032$i) + 1)|0;
    $exitcond39$i = ($136|0)==($102|0);
    if ($exitcond39$i) {
     break;
    } else {
     $i1$032$i = $136;
    }
   }
  }
  $137 = (($105) + ($102<<3)|0);
  __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEvT0_S7_T_($105,$137);
 }
 $138 = ($102*6)|0;
 $139 = ($138|0)==(0);
 do {
  if ($139) {
   $159 = 0;$187 = 0;
   label = 44;
  } else {
   $140 = ($138|0)<(0);
   if ($140) {
    __THREW__ = 0;
    invoke_vi(3308,0);
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if (!($142)) {
     // unreachable;
    }
   } else {
    $143 = ($102*12)|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $144 = (invoke_iiiiiii(102,($143|0),16,($$byval_copy5|0),0,(803264|0),79)|0);
    $145 = __THREW__; __THREW__ = 0;
    $146 = $145&1;
    if (!($146)) {
     $$0$i$i$i$i = $138;$148 = $144;
     while(1) {
      $147 = ($148|0)==(0|0);
      if (!($147)) {
       HEAP16[$148>>1] = 0;
      }
      $149 = (($148) + 2|0);
      $150 = (($$0$i$i$i$i) + -1)|0;
      $151 = ($150|0)==(0);
      if ($151) {
       break;
      } else {
       $$0$i$i$i$i = $150;$148 = $149;
      }
     }
     $152 = (($144) + ($138<<1)|0);
     $159 = $144;$187 = $152;
     label = 44;
     break;
    }
   }
   $109 = ___cxa_find_matching_catch()|0;
   $110 = tempRet0;
   $$0$i = $109;$$01$i = $110;
  }
 } while(0);
 do {
  if ((label|0) == 44) {
   if (!($106)) {
    $i2$031$i = 0;
    while(1) {
     $153 = ($i2$031$i*6)|0;
     $154 = (($105) + ($i2$031$i<<3)|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = $155 << 2;
     $157 = $156&65535;
     $158 = (($159) + ($153<<1)|0);
     HEAP16[$158>>1] = $157;
     $160 = $156 | 1;
     $161 = $160&65535;
     $162 = $153 | 1;
     $163 = (($159) + ($162<<1)|0);
     HEAP16[$163>>1] = $161;
     $164 = $156 | 2;
     $165 = $164&65535;
     $166 = (($153) + 2)|0;
     $167 = (($159) + ($166<<1)|0);
     HEAP16[$167>>1] = $165;
     $168 = (($153) + 3)|0;
     $169 = (($159) + ($168<<1)|0);
     HEAP16[$169>>1] = $165;
     $170 = (($153) + 4)|0;
     $171 = (($159) + ($170<<1)|0);
     HEAP16[$171>>1] = $161;
     $172 = $156 | 3;
     $173 = $172&65535;
     $174 = (($153) + 5)|0;
     $175 = (($159) + ($174<<1)|0);
     HEAP16[$175>>1] = $173;
     $176 = (($i2$031$i) + 1)|0;
     $exitcond$i = ($176|0)==($102|0);
     if ($exitcond$i) {
      break;
     } else {
      $i2$031$i = $176;
     }
    }
   }
   $184 = (($binTree) + 44|0);
   $185 = HEAP32[$184>>2]|0;
   $186 = ($159|0)==($187|0);
   $188 = $186 ? 0 : $159;
   $189 = $187;
   $190 = $159;
   $191 = (($189) - ($190))|0;
   $192 = $191 >> 1;
   __THREW__ = 0;
   (invoke_iiiiiii(122,($185|0),($188|0),($192|0),0,0,17)|0);
   $193 = __THREW__; __THREW__ = 0;
   $194 = $193&1;
   if ($194) {
    $177 = ___cxa_find_matching_catch()|0;
    $178 = tempRet0;
    $179 = ($159|0)==(0|0);
    if ($179) {
     $$0$i = $177;$$01$i = $178;
     break;
    }
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($159|0),($$byval_copy5|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if (!($181)) {
     $$0$i = $177;$$01$i = $178;
     break;
    }
    $182 = ___cxa_find_matching_catch()|0;
    $183 = tempRet0;
    ___cxa_call_unexpected(($182|0));
    // unreachable;
   }
   $195 = ($159|0)==(0|0);
   if (!($195)) {
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($159|0),($$byval_copy5|0));
    $196 = __THREW__; __THREW__ = 0;
    $197 = $196&1;
    if ($197) {
     $198 = ___cxa_find_matching_catch()|0;
     $199 = tempRet0;
     ___cxa_call_unexpected(($198|0));
     // unreachable;
    }
   }
   $200 = ($102|0)>(-1);
   if (!($200)) {
    STACKTOP = sp;return;
   }
   HEAP32[$1>>2] = $103;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($105,$$byval_copy5);
   STACKTOP = sp;return;
  }
 } while(0);
 $201 = ($102|0)>(-1);
 if (!($201)) {
  ___resumeException($$0$i|0);
  // unreachable;
 }
 HEAP32[$2>>2] = $103;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($105|0),($$byval_copy5|0));
 $202 = __THREW__; __THREW__ = 0;
 $203 = $202&1;
 if ($203) {
  $204 = ___cxa_find_matching_catch(0|0)|0;
  $205 = tempRet0;
  ___clang_call_terminate($204);
  // unreachable;
 } else {
  ___resumeException($$0$i|0);
  // unreachable;
 }
}
function __ZN12TreeRenderer17UpdateShaderPropsERK6Camera($this,$cam) {
 $this = $this|0;
 $cam = $cam|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $billboardAngleFactor = 0, $billboardOffsetFactor = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 136|0;
 $1 = sp + 124|0;
 $billboardAngleFactor = sp + 120|0;
 $billboardOffsetFactor = sp + 116|0;
 $2 = sp + 112|0;
 $3 = sp + 96|0;
 $4 = sp + 88|0;
 $5 = sp + 72|0;
 $6 = sp + 48|0;
 $7 = sp + 32|0;
 $8 = sp + 24|0;
 $9 = sp + 8|0;
 $10 = sp;
 $11 = sp + 56|0;
 $12 = (($cam) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($13)|0);
 __ZNK9Transform11GetPositionEv($1,$14);
 $15 = (($this) + 124|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 24|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (($16) + 84|0);
 $21 = (($16) + 80|0);
 $22 = (($16) + 76|0);
 $23 = (($16) + 68|0);
 $24 = (($16) + 64|0);
 $25 = (($16) + 60|0);
 $26 = (($16) + 52|0);
 $27 = (($16) + 48|0);
 $28 = (($16) + 44|0);
 $29 = Math_fround(HEAPF32[$20>>2]);
 $30 = Math_fround(HEAPF32[$21>>2]);
 $31 = Math_fround(HEAPF32[$22>>2]);
 $32 = Math_fround(HEAPF32[$23>>2]);
 $33 = Math_fround(HEAPF32[$24>>2]);
 $34 = Math_fround(HEAPF32[$25>>2]);
 $35 = Math_fround(HEAPF32[$26>>2]);
 $36 = Math_fround(HEAPF32[$27>>2]);
 $37 = Math_fround(HEAPF32[$28>>2]);
 __ZNK21ImposterRenderTexture18GetBillboardParamsERfS0_($16,$billboardAngleFactor,$billboardOffsetFactor);
 $38 = (($this) + 8|0);
 $39 = (($this) + 16|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 32|0);
 HEAP32[$40>>2] = 0;
 $41 = HEAP32[641904>>2]|0;
 $42 = (($this) + 40|0);
 HEAP32[$42>>2] = $41;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,803544);
 $43 = HEAP32[$0>>2]|0;
 HEAP32[$2>>2] = $43;
 HEAPF32[$3>>2] = $37;
 $44 = (($3) + 4|0);
 HEAPF32[$44>>2] = $36;
 $45 = (($3) + 8|0);
 HEAPF32[$45>>2] = $35;
 $46 = (($3) + 12|0);
 HEAPF32[$46>>2] = Math_fround(0.0);
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($38,$2,$3);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,803576);
 $47 = HEAP32[$0>>2]|0;
 HEAP32[$4>>2] = $47;
 $48 = Math_fround(HEAPF32[$billboardOffsetFactor>>2]);
 HEAPF32[$5>>2] = $34;
 $49 = (($5) + 4|0);
 HEAPF32[$49>>2] = $33;
 $50 = (($5) + 8|0);
 HEAPF32[$50>>2] = $32;
 $51 = (($5) + 12|0);
 HEAPF32[$51>>2] = $48;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($38,$4,$5);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,803600);
 $52 = HEAP32[$0>>2]|0;
 HEAP32[$6>>2] = $52;
 HEAPF32[$7>>2] = $31;
 $53 = (($7) + 4|0);
 HEAPF32[$53>>2] = $30;
 $54 = (($7) + 8|0);
 HEAPF32[$54>>2] = $29;
 $55 = (($7) + 12|0);
 HEAPF32[$55>>2] = Math_fround(0.0);
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($38,$6,$7);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,803632);
 $56 = HEAP32[$0>>2]|0;
 HEAP32[$8>>2] = $56;
 $57 = Math_fround(HEAPF32[$1>>2]);
 $58 = (($1) + 4|0);
 $59 = Math_fround(HEAPF32[$58>>2]);
 $60 = (($1) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround(HEAPF32[$billboardAngleFactor>>2]);
 HEAPF32[$9>>2] = $57;
 $63 = (($9) + 4|0);
 HEAPF32[$63>>2] = $59;
 $64 = (($9) + 8|0);
 HEAPF32[$64>>2] = $61;
 $65 = (($9) + 12|0);
 HEAPF32[$65>>2] = $62;
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($38,$8,$9);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,803656);
 $66 = HEAP32[$0>>2]|0;
 HEAP32[$10>>2] = $66;
 $67 = (($this) + 72|0);
 $68 = Math_fround(HEAPF32[$67>>2]);
 HEAPF32[$11>>2] = $68;
 $69 = (($11) + 4|0);
 HEAPF32[$69>>2] = Math_fround(0.0);
 $70 = (($11) + 8|0);
 HEAPF32[$70>>2] = Math_fround(0.0);
 $71 = (($11) + 12|0);
 HEAPF32[$71>>2] = Math_fround(0.0);
 __ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f($38,$10,$11);
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer21GenerateBillboardMeshER4MeshRK13dynamic_arrayIjLj4EEb($this,$mesh,$instances,$buildTriangles) {
 $this = $this|0;
 $mesh = $mesh|0;
 $instances = $instances|0;
 $buildTriangles = $buildTriangles|0;
 var $$0$i$i$i = 0, $$byval_copy2 = 0, $$op$i$i$i$i = Math_fround(0), $$op$i$i$i$i$us = Math_fround(0), $$op$i1$i$i$i = Math_fround(0), $$op$i1$i$i$i$us = Math_fround(0), $$op$i2$i$i$i = Math_fround(0), $$op$i2$i$i$i$us = Math_fround(0), $$op$i3$i$i$i = Math_fround(0), $$op$i3$i$i$i$us = Math_fround(0), $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0;
 var $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = Math_fround(0);
 var $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0;
 var $160 = 0, $161 = 0, $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = Math_fround(0), $182 = 0, $183 = Math_fround(0), $184 = Math_fround(0), $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = Math_fround(0), $196 = Math_fround(0);
 var $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0), $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = Math_fround(0), $239 = Math_fround(0), $24 = 0, $240 = Math_fround(0), $241 = 0, $242 = Math_fround(0), $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = Math_fround(0), $247 = Math_fround(0), $248 = Math_fround(0), $249 = Math_fround(0), $25 = 0;
 var $250 = Math_fround(0), $251 = Math_fround(0), $252 = Math_fround(0), $253 = Math_fround(0), $254 = Math_fround(0), $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = Math_fround(0), $265 = 0, $266 = 0, $267 = 0, $268 = Math_fround(0);
 var $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = Math_fround(0), $275 = 0, $276 = 0, $277 = 0, $278 = Math_fround(0), $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0;
 var $287 = 0, $288 = Math_fround(0), $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = Math_fround(0), $296 = Math_fround(0), $297 = Math_fround(0), $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0);
 var $304 = Math_fround(0), $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = Math_fround(0), $309 = Math_fround(0), $31 = 0, $310 = Math_fround(0), $311 = 0, $312 = Math_fround(0), $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = Math_fround(0), $321 = Math_fround(0);
 var $322 = Math_fround(0), $323 = Math_fround(0), $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = 0, $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = 0, $358 = Math_fround(0);
 var $359 = 0, $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = Math_fround(0), $363 = Math_fround(0), $364 = 0, $365 = 0, $366 = Math_fround(0), $367 = Math_fround(0), $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0;
 var $377 = Math_fround(0), $378 = 0, $379 = Math_fround(0), $38 = 0, $380 = Math_fround(0), $381 = 0, $382 = 0, $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = 0, $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = 0;
 var $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0;
 var $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0), $419 = Math_fround(0), $42 = Math_fround(0), $420 = Math_fround(0), $421 = Math_fround(0), $422 = Math_fround(0), $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = Math_fround(0);
 var $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0;
 var $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0;
 var $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0;
 var $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0;
 var $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0;
 var $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $bounds = 0, $exitcond = 0, $exitcond39 = 0, $i$035 = 0;
 var $i$035$us = 0, $i1$034 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp + 56|0;
 $0 = sp;
 $bounds = sp + 8|0;
 $1 = sp + 32|0;
 $2 = sp + 44|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($instances) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 << 2;
 __ZN4Mesh14ResizeVerticesEjj($mesh,$6,29);
 $7 = (($mesh) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 92|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($mesh) + 276|0);
 $12 = HEAP8[$11>>0]|0;
 ;HEAP32[$bounds+0>>2]=0|0;HEAP32[$bounds+4>>2]=0|0;HEAP32[$bounds+8>>2]=0|0;HEAP32[$bounds+12>>2]=0|0;HEAP32[$bounds+16>>2]=0|0;HEAP32[$bounds+20>>2]=0|0;
 $13 = ($5|0)==(0);
 if (!($13)) {
  $14 = ($12<<24>>24)==(0);
  $15 = (($3) + 16|0);
  $16 = (($this) + 44|0);
  $17 = (($this) + 48|0);
  $18 = (($this) + 52|0);
  $19 = (($this) + 56|0);
  $20 = (($this) + 60|0);
  $21 = (($this) + 64|0);
  $22 = (($this) + 124|0);
  $23 = (($bounds) + 4|0);
  $24 = (($bounds) + 8|0);
  $25 = (($bounds) + 12|0);
  $26 = (($bounds) + 16|0);
  $27 = (($bounds) + 20|0);
  $28 = (($1) + 4|0);
  $29 = (($1) + 8|0);
  $30 = (($2) + 4|0);
  $31 = (($2) + 8|0);
  if ($14) {
   $i$035$us = 0;
   while(1) {
    $32 = HEAP32[$instances>>2]|0;
    $33 = (($32) + ($i$035$us<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = HEAP32[$15>>2]|0;
    $36 = HEAP32[$this>>2]|0;
    $37 = ((($35) + (($34*40)|0)|0) + 32|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 28|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($35) + (($34*40)|0)|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    $43 = Math_fround(HEAPF32[$16>>2]);
    $44 = Math_fround($42 * $43);
    $45 = ((($35) + (($34*40)|0)|0) + 4|0);
    $46 = Math_fround(HEAPF32[$45>>2]);
    $47 = Math_fround(HEAPF32[$17>>2]);
    $48 = Math_fround($46 * $47);
    $49 = ((($35) + (($34*40)|0)|0) + 8|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    $51 = Math_fround(HEAPF32[$18>>2]);
    $52 = Math_fround($50 * $51);
    $53 = Math_fround(HEAPF32[$19>>2]);
    $54 = Math_fround($44 + $53);
    $55 = Math_fround(HEAPF32[$20>>2]);
    $56 = Math_fround($48 + $55);
    $57 = Math_fround(HEAPF32[$21>>2]);
    $58 = Math_fround($52 + $57);
    $59 = ((($35) + (($34*40)|0)|0) + 24|0);
    $60 = HEAP8[$59>>0]|0;
    $61 = $60&255;
    $62 = (Math_fround(($61|0)));
    $63 = Math_fround($62 / Math_fround(255.0));
    $64 = ((($35) + (($34*40)|0)|0) + 25|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = $65&255;
    $67 = (Math_fround(($66|0)));
    $68 = Math_fround($67 / Math_fround(255.0));
    $69 = ((($35) + (($34*40)|0)|0) + 26|0);
    $70 = HEAP8[$69>>0]|0;
    $71 = $70&255;
    $72 = (Math_fround(($71|0)));
    $73 = Math_fround($72 / Math_fround(255.0));
    $74 = ((($35) + (($34*40)|0)|0) + 27|0);
    $75 = HEAP8[$74>>0]|0;
    $76 = $75&255;
    $77 = (Math_fround(($76|0)));
    $78 = Math_fround($77 / Math_fround(255.0));
    $79 = ((($35) + (($34*40)|0)|0) + 28|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = $80&255;
    $82 = (Math_fround(($81|0)));
    $83 = Math_fround($82 / Math_fround(255.0));
    $84 = ((($35) + (($34*40)|0)|0) + 29|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = (Math_fround(($86|0)));
    $88 = Math_fround($87 / Math_fround(255.0));
    $89 = ((($35) + (($34*40)|0)|0) + 30|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = $90&255;
    $92 = (Math_fround(($91|0)));
    $93 = Math_fround($92 / Math_fround(255.0));
    $94 = ((($35) + (($34*40)|0)|0) + 31|0);
    $95 = HEAP8[$94>>0]|0;
    $96 = $95&255;
    $97 = (Math_fround(($96|0)));
    $98 = Math_fround($97 / Math_fround(255.0));
    $99 = Math_fround($63 * $83);
    $100 = Math_fround($68 * $88);
    $101 = Math_fround($73 * $93);
    $102 = Math_fround($78 * $98);
    $103 = ((($40) + ($38<<7)|0) + 92|0);
    $104 = Math_fround(HEAPF32[$103>>2]);
    $105 = ((($35) + (($34*40)|0)|0) + 12|0);
    $106 = Math_fround(HEAPF32[$105>>2]);
    $107 = Math_fround($104 * $106);
    $108 = Math_fround($107 * Math_fround(0.5));
    $109 = ((($40) + ($38<<7)|0) + 84|0);
    $110 = Math_fround(HEAPF32[$109>>2]);
    $111 = ((($35) + (($34*40)|0)|0) + 16|0);
    $112 = Math_fround(HEAPF32[$111>>2]);
    $113 = Math_fround($110 * $112);
    $114 = Math_fround($113 * Math_fround(0.5));
    $115 = ((($40) + ($38<<7)|0) + 88|0);
    $116 = Math_fround(HEAPF32[$115>>2]);
    $117 = Math_fround($110 * Math_fround(0.5));
    $118 = Math_fround($116 - $117);
    $119 = Math_fround($112 * $118);
    $120 = $110 < $104;
    $121 = $120 ? $104 : $110;
    $122 = Math_fround($121 - $110);
    $123 = Math_fround($122 * Math_fround(0.5));
    $124 = Math_fround($116 + $123);
    $125 = Math_fround($112 * $124);
    $126 = Math_fround($110 - $116);
    $127 = Math_fround($126 + $123);
    $128 = Math_fround($112 * $127);
    $129 = Math_fround($106 * $121);
    $130 = Math_fround($129 * Math_fround(0.5));
    $131 = $i$035$us << 2;
    $132 = (($10) + ($131<<5)|0);
    HEAPF32[$132>>2] = $54;
    $133 = ((($10) + ($131<<5)|0) + 4|0);
    HEAPF32[$133>>2] = $56;
    $134 = ((($10) + ($131<<5)|0) + 8|0);
    HEAPF32[$134>>2] = $58;
    $135 = $131 | 1;
    $136 = (($10) + ($135<<5)|0);
    HEAPF32[$136>>2] = $54;
    $137 = ((($10) + ($135<<5)|0) + 4|0);
    HEAPF32[$137>>2] = $56;
    $138 = ((($10) + ($135<<5)|0) + 8|0);
    HEAPF32[$138>>2] = $58;
    $139 = $131 | 2;
    $140 = (($10) + ($139<<5)|0);
    HEAPF32[$140>>2] = $54;
    $141 = ((($10) + ($139<<5)|0) + 4|0);
    HEAPF32[$141>>2] = $56;
    $142 = ((($10) + ($139<<5)|0) + 8|0);
    HEAPF32[$142>>2] = $58;
    $143 = $131 | 3;
    $144 = (($10) + ($143<<5)|0);
    HEAPF32[$144>>2] = $54;
    $145 = ((($10) + ($143<<5)|0) + 4|0);
    HEAPF32[$145>>2] = $56;
    $146 = ((($10) + ($143<<5)|0) + 8|0);
    HEAPF32[$146>>2] = $58;
    $147 = HEAP32[$22>>2]|0;
    $148 = HEAP32[$37>>2]|0;
    $149 = (($147) + 4|0);
    $150 = HEAP32[$149>>2]|0;
    $151 = (($150) + ($148<<4)|0);
    $152 = Math_fround(HEAPF32[$151>>2]);
    $153 = Math_fround(-$130);
    $154 = ((($10) + ($131<<5)|0) + 16|0);
    HEAPF32[$154>>2] = $152;
    $155 = ((($10) + ($131<<5)|0) + 20|0);
    HEAPF32[$155>>2] = $153;
    $156 = Math_fround(HEAPF32[$151>>2]);
    $157 = ((($150) + ($148<<4)|0) + 8|0);
    $158 = Math_fround(HEAPF32[$157>>2]);
    $159 = Math_fround($156 + $158);
    $160 = ((($10) + ($135<<5)|0) + 16|0);
    HEAPF32[$160>>2] = $159;
    $161 = ((($10) + ($135<<5)|0) + 20|0);
    HEAPF32[$161>>2] = $153;
    $162 = Math_fround(HEAPF32[$151>>2]);
    $163 = ((($10) + ($139<<5)|0) + 16|0);
    HEAPF32[$163>>2] = $162;
    $164 = ((($10) + ($139<<5)|0) + 20|0);
    HEAPF32[$164>>2] = $130;
    $165 = Math_fround(HEAPF32[$151>>2]);
    $166 = Math_fround(HEAPF32[$157>>2]);
    $167 = Math_fround($165 + $166);
    $168 = ((($10) + ($143<<5)|0) + 16|0);
    HEAPF32[$168>>2] = $167;
    $169 = ((($10) + ($143<<5)|0) + 20|0);
    HEAPF32[$169>>2] = $130;
    $170 = Math_fround(-$108);
    $171 = Math_fround(-$128);
    $172 = ((($10) + ($131<<5)|0) + 24|0);
    HEAPF32[$172>>2] = $170;
    $173 = ((($10) + ($131<<5)|0) + 28|0);
    HEAPF32[$173>>2] = $171;
    $174 = ((($10) + ($135<<5)|0) + 24|0);
    HEAPF32[$174>>2] = $108;
    $175 = ((($10) + ($135<<5)|0) + 28|0);
    HEAPF32[$175>>2] = $171;
    $176 = ((($10) + ($139<<5)|0) + 24|0);
    HEAPF32[$176>>2] = $170;
    $177 = ((($10) + ($139<<5)|0) + 28|0);
    HEAPF32[$177>>2] = $125;
    $178 = ((($10) + ($143<<5)|0) + 24|0);
    HEAPF32[$178>>2] = $108;
    $179 = ((($10) + ($143<<5)|0) + 28|0);
    HEAPF32[$179>>2] = $125;
    $180 = $99 < Math_fround(0.0);
    $181 = $180 ? Math_fround(0.0) : $99;
    $182 = $181 > Math_fround(1.0);
    $$op$i$i$i$i$us = Math_fround($181 * Math_fround(255.0));
    $183 = $182 ? Math_fround(255.0) : $$op$i$i$i$i$us;
    $184 = Math_fround($183 + Math_fround(0.5));
    $185 = (~~(($184))>>>0);
    $186 = $100 < Math_fround(0.0);
    $187 = $186 ? Math_fround(0.0) : $100;
    $188 = $187 > Math_fround(1.0);
    $$op$i3$i$i$i$us = Math_fround($187 * Math_fround(255.0));
    $189 = $188 ? Math_fround(255.0) : $$op$i3$i$i$i$us;
    $190 = Math_fround($189 + Math_fround(0.5));
    $191 = (~~(($190))>>>0);
    $192 = $101 < Math_fround(0.0);
    $193 = $192 ? Math_fround(0.0) : $101;
    $194 = $193 > Math_fround(1.0);
    $$op$i2$i$i$i$us = Math_fround($193 * Math_fround(255.0));
    $195 = $194 ? Math_fround(255.0) : $$op$i2$i$i$i$us;
    $196 = Math_fround($195 + Math_fround(0.5));
    $197 = (~~(($196))>>>0);
    $198 = $102 < Math_fround(0.0);
    $199 = $198 ? Math_fround(0.0) : $102;
    $200 = $199 > Math_fround(1.0);
    $$op$i1$i$i$i$us = Math_fround($199 * Math_fround(255.0));
    $201 = $200 ? Math_fround(255.0) : $$op$i1$i$i$i$us;
    $202 = Math_fround($201 + Math_fround(0.5));
    $203 = (~~(($202))>>>0);
    $204 = ((($10) + ($131<<5)|0) + 12|0);
    $205 = ((($10) + ($135<<5)|0) + 12|0);
    $206 = ((($10) + ($139<<5)|0) + 12|0);
    $207 = ((($10) + ($143<<5)|0) + 12|0);
    $208 = $203 << 24;
    $209 = $197 << 16;
    $210 = $209 & 16711680;
    $211 = $210 | $208;
    $212 = $191 << 8;
    $213 = $212 & 65280;
    $214 = $211 | $213;
    $215 = $185 & 255;
    $216 = $214 | $215;
    HEAP32[$207>>2] = $216;
    HEAP32[$206>>2] = $216;
    HEAP32[$205>>2] = $216;
    HEAP32[$204>>2] = $216;
    $217 = Math_fround($54 + Math_fround(0.0));
    $218 = Math_fround($56 + $119);
    $219 = Math_fround($58 + Math_fround(0.0));
    $220 = ($i$035$us|0)==(0);
    if ($220) {
     HEAPF32[$bounds>>2] = $217;
     HEAPF32[$23>>2] = $218;
     HEAPF32[$24>>2] = $219;
     HEAPF32[$25>>2] = $108;
     HEAPF32[$26>>2] = $114;
     HEAPF32[$27>>2] = $108;
    } else {
     $221 = Math_fround($217 + $108);
     $222 = Math_fround($114 + $218);
     $223 = Math_fround($219 + $108);
     HEAPF32[$1>>2] = $221;
     HEAPF32[$28>>2] = $222;
     HEAPF32[$29>>2] = $223;
     __ZN4AABB11EncapsulateERK8Vector3f($bounds,$1);
     $224 = Math_fround($217 - $108);
     $225 = Math_fround($218 - $114);
     $226 = Math_fround($219 - $108);
     HEAPF32[$2>>2] = $224;
     HEAPF32[$30>>2] = $225;
     HEAPF32[$31>>2] = $226;
     __ZN4AABB11EncapsulateERK8Vector3f($bounds,$2);
    }
    $227 = (($i$035$us) + 1)|0;
    $exitcond39 = ($227|0)==($5|0);
    if ($exitcond39) {
     break;
    } else {
     $i$035$us = $227;
    }
   }
  } else {
   $i$035 = 0;
   while(1) {
    $228 = HEAP32[$instances>>2]|0;
    $229 = (($228) + ($i$035<<2)|0);
    $230 = HEAP32[$229>>2]|0;
    $231 = HEAP32[$15>>2]|0;
    $232 = HEAP32[$this>>2]|0;
    $233 = ((($231) + (($230*40)|0)|0) + 32|0);
    $234 = HEAP32[$233>>2]|0;
    $235 = (($232) + 28|0);
    $236 = HEAP32[$235>>2]|0;
    $237 = (($231) + (($230*40)|0)|0);
    $238 = Math_fround(HEAPF32[$237>>2]);
    $239 = Math_fround(HEAPF32[$16>>2]);
    $240 = Math_fround($238 * $239);
    $241 = ((($231) + (($230*40)|0)|0) + 4|0);
    $242 = Math_fround(HEAPF32[$241>>2]);
    $243 = Math_fround(HEAPF32[$17>>2]);
    $244 = Math_fround($242 * $243);
    $245 = ((($231) + (($230*40)|0)|0) + 8|0);
    $246 = Math_fround(HEAPF32[$245>>2]);
    $247 = Math_fround(HEAPF32[$18>>2]);
    $248 = Math_fround($246 * $247);
    $249 = Math_fround(HEAPF32[$19>>2]);
    $250 = Math_fround($240 + $249);
    $251 = Math_fround(HEAPF32[$20>>2]);
    $252 = Math_fround($244 + $251);
    $253 = Math_fround(HEAPF32[$21>>2]);
    $254 = Math_fround($248 + $253);
    $255 = ((($231) + (($230*40)|0)|0) + 24|0);
    $256 = HEAP8[$255>>0]|0;
    $257 = $256&255;
    $258 = (Math_fround(($257|0)));
    $259 = Math_fround($258 / Math_fround(255.0));
    $260 = ((($231) + (($230*40)|0)|0) + 25|0);
    $261 = HEAP8[$260>>0]|0;
    $262 = $261&255;
    $263 = (Math_fround(($262|0)));
    $264 = Math_fround($263 / Math_fround(255.0));
    $265 = ((($231) + (($230*40)|0)|0) + 26|0);
    $266 = HEAP8[$265>>0]|0;
    $267 = $266&255;
    $268 = (Math_fround(($267|0)));
    $269 = Math_fround($268 / Math_fround(255.0));
    $270 = ((($231) + (($230*40)|0)|0) + 27|0);
    $271 = HEAP8[$270>>0]|0;
    $272 = $271&255;
    $273 = (Math_fround(($272|0)));
    $274 = Math_fround($273 / Math_fround(255.0));
    $275 = ((($231) + (($230*40)|0)|0) + 28|0);
    $276 = HEAP8[$275>>0]|0;
    $277 = $276&255;
    $278 = (Math_fround(($277|0)));
    $279 = Math_fround($278 / Math_fround(255.0));
    $280 = ((($231) + (($230*40)|0)|0) + 29|0);
    $281 = HEAP8[$280>>0]|0;
    $282 = $281&255;
    $283 = (Math_fround(($282|0)));
    $284 = Math_fround($283 / Math_fround(255.0));
    $285 = ((($231) + (($230*40)|0)|0) + 30|0);
    $286 = HEAP8[$285>>0]|0;
    $287 = $286&255;
    $288 = (Math_fround(($287|0)));
    $289 = Math_fround($288 / Math_fround(255.0));
    $290 = ((($231) + (($230*40)|0)|0) + 31|0);
    $291 = HEAP8[$290>>0]|0;
    $292 = $291&255;
    $293 = (Math_fround(($292|0)));
    $294 = Math_fround($293 / Math_fround(255.0));
    $295 = Math_fround($259 * $279);
    $296 = Math_fround($264 * $284);
    $297 = Math_fround($269 * $289);
    $298 = Math_fround($274 * $294);
    $299 = ((($236) + ($234<<7)|0) + 92|0);
    $300 = Math_fround(HEAPF32[$299>>2]);
    $301 = ((($231) + (($230*40)|0)|0) + 12|0);
    $302 = Math_fround(HEAPF32[$301>>2]);
    $303 = Math_fround($300 * $302);
    $304 = Math_fround($303 * Math_fround(0.5));
    $305 = ((($236) + ($234<<7)|0) + 84|0);
    $306 = Math_fround(HEAPF32[$305>>2]);
    $307 = ((($231) + (($230*40)|0)|0) + 16|0);
    $308 = Math_fround(HEAPF32[$307>>2]);
    $309 = Math_fround($306 * $308);
    $310 = Math_fround($309 * Math_fround(0.5));
    $311 = ((($236) + ($234<<7)|0) + 88|0);
    $312 = Math_fround(HEAPF32[$311>>2]);
    $313 = Math_fround($306 * Math_fround(0.5));
    $314 = Math_fround($312 - $313);
    $315 = Math_fround($308 * $314);
    $316 = $306 < $300;
    $317 = $316 ? $300 : $306;
    $318 = Math_fround($317 - $306);
    $319 = Math_fround($318 * Math_fround(0.5));
    $320 = Math_fround($312 + $319);
    $321 = Math_fround($308 * $320);
    $322 = Math_fround($306 - $312);
    $323 = Math_fround($322 + $319);
    $324 = Math_fround($308 * $323);
    $325 = Math_fround($302 * $317);
    $326 = Math_fround($325 * Math_fround(0.5));
    $327 = $i$035 << 2;
    $328 = (($10) + ($327<<5)|0);
    HEAPF32[$328>>2] = $250;
    $329 = ((($10) + ($327<<5)|0) + 4|0);
    HEAPF32[$329>>2] = $252;
    $330 = ((($10) + ($327<<5)|0) + 8|0);
    HEAPF32[$330>>2] = $254;
    $331 = $327 | 1;
    $332 = (($10) + ($331<<5)|0);
    HEAPF32[$332>>2] = $250;
    $333 = ((($10) + ($331<<5)|0) + 4|0);
    HEAPF32[$333>>2] = $252;
    $334 = ((($10) + ($331<<5)|0) + 8|0);
    HEAPF32[$334>>2] = $254;
    $335 = $327 | 2;
    $336 = (($10) + ($335<<5)|0);
    HEAPF32[$336>>2] = $250;
    $337 = ((($10) + ($335<<5)|0) + 4|0);
    HEAPF32[$337>>2] = $252;
    $338 = ((($10) + ($335<<5)|0) + 8|0);
    HEAPF32[$338>>2] = $254;
    $339 = $327 | 3;
    $340 = (($10) + ($339<<5)|0);
    HEAPF32[$340>>2] = $250;
    $341 = ((($10) + ($339<<5)|0) + 4|0);
    HEAPF32[$341>>2] = $252;
    $342 = ((($10) + ($339<<5)|0) + 8|0);
    HEAPF32[$342>>2] = $254;
    $343 = HEAP32[$22>>2]|0;
    $344 = HEAP32[$233>>2]|0;
    $345 = (($343) + 4|0);
    $346 = HEAP32[$345>>2]|0;
    $347 = (($346) + ($344<<4)|0);
    $348 = Math_fround(HEAPF32[$347>>2]);
    $349 = Math_fround(-$326);
    $350 = ((($10) + ($327<<5)|0) + 16|0);
    HEAPF32[$350>>2] = $348;
    $351 = ((($10) + ($327<<5)|0) + 20|0);
    HEAPF32[$351>>2] = $349;
    $352 = Math_fround(HEAPF32[$347>>2]);
    $353 = ((($346) + ($344<<4)|0) + 8|0);
    $354 = Math_fround(HEAPF32[$353>>2]);
    $355 = Math_fround($352 + $354);
    $356 = ((($10) + ($331<<5)|0) + 16|0);
    HEAPF32[$356>>2] = $355;
    $357 = ((($10) + ($331<<5)|0) + 20|0);
    HEAPF32[$357>>2] = $349;
    $358 = Math_fround(HEAPF32[$347>>2]);
    $359 = ((($10) + ($335<<5)|0) + 16|0);
    HEAPF32[$359>>2] = $358;
    $360 = ((($10) + ($335<<5)|0) + 20|0);
    HEAPF32[$360>>2] = $326;
    $361 = Math_fround(HEAPF32[$347>>2]);
    $362 = Math_fround(HEAPF32[$353>>2]);
    $363 = Math_fround($361 + $362);
    $364 = ((($10) + ($339<<5)|0) + 16|0);
    HEAPF32[$364>>2] = $363;
    $365 = ((($10) + ($339<<5)|0) + 20|0);
    HEAPF32[$365>>2] = $326;
    $366 = Math_fround(-$304);
    $367 = Math_fround(-$324);
    $368 = ((($10) + ($327<<5)|0) + 24|0);
    HEAPF32[$368>>2] = $366;
    $369 = ((($10) + ($327<<5)|0) + 28|0);
    HEAPF32[$369>>2] = $367;
    $370 = ((($10) + ($331<<5)|0) + 24|0);
    HEAPF32[$370>>2] = $304;
    $371 = ((($10) + ($331<<5)|0) + 28|0);
    HEAPF32[$371>>2] = $367;
    $372 = ((($10) + ($335<<5)|0) + 24|0);
    HEAPF32[$372>>2] = $366;
    $373 = ((($10) + ($335<<5)|0) + 28|0);
    HEAPF32[$373>>2] = $321;
    $374 = ((($10) + ($339<<5)|0) + 24|0);
    HEAPF32[$374>>2] = $304;
    $375 = ((($10) + ($339<<5)|0) + 28|0);
    HEAPF32[$375>>2] = $321;
    $376 = $295 < Math_fround(0.0);
    $377 = $376 ? Math_fround(0.0) : $295;
    $378 = $377 > Math_fround(1.0);
    $$op$i$i$i$i = Math_fround($377 * Math_fround(255.0));
    $379 = $378 ? Math_fround(255.0) : $$op$i$i$i$i;
    $380 = Math_fround($379 + Math_fround(0.5));
    $381 = (~~(($380))>>>0);
    $382 = $296 < Math_fround(0.0);
    $383 = $382 ? Math_fround(0.0) : $296;
    $384 = $383 > Math_fround(1.0);
    $$op$i3$i$i$i = Math_fround($383 * Math_fround(255.0));
    $385 = $384 ? Math_fround(255.0) : $$op$i3$i$i$i;
    $386 = Math_fround($385 + Math_fround(0.5));
    $387 = (~~(($386))>>>0);
    $388 = $297 < Math_fround(0.0);
    $389 = $388 ? Math_fround(0.0) : $297;
    $390 = $389 > Math_fround(1.0);
    $$op$i2$i$i$i = Math_fround($389 * Math_fround(255.0));
    $391 = $390 ? Math_fround(255.0) : $$op$i2$i$i$i;
    $392 = Math_fround($391 + Math_fround(0.5));
    $393 = (~~(($392))>>>0);
    $394 = $298 < Math_fround(0.0);
    $395 = $394 ? Math_fround(0.0) : $298;
    $396 = $395 > Math_fround(1.0);
    $$op$i1$i$i$i = Math_fround($395 * Math_fround(255.0));
    $397 = $396 ? Math_fround(255.0) : $$op$i1$i$i$i;
    $398 = Math_fround($397 + Math_fround(0.5));
    $399 = (~~(($398))>>>0);
    $400 = $381 << 16;
    $401 = $387 << 8;
    $402 = ((($10) + ($327<<5)|0) + 12|0);
    $403 = ((($10) + ($331<<5)|0) + 12|0);
    $404 = ((($10) + ($335<<5)|0) + 12|0);
    $405 = ((($10) + ($339<<5)|0) + 12|0);
    $406 = $399 << 24;
    $407 = $400 & 16711680;
    $408 = $407 | $406;
    $409 = $401 & 65280;
    $410 = $408 | $409;
    $411 = $393 & 255;
    $412 = $410 | $411;
    HEAP32[$405>>2] = $412;
    HEAP32[$404>>2] = $412;
    HEAP32[$403>>2] = $412;
    HEAP32[$402>>2] = $412;
    $413 = Math_fround($250 + Math_fround(0.0));
    $414 = Math_fround($252 + $315);
    $415 = Math_fround($254 + Math_fround(0.0));
    $416 = ($i$035|0)==(0);
    if ($416) {
     HEAPF32[$bounds>>2] = $413;
     HEAPF32[$23>>2] = $414;
     HEAPF32[$24>>2] = $415;
     HEAPF32[$25>>2] = $304;
     HEAPF32[$26>>2] = $310;
     HEAPF32[$27>>2] = $304;
    } else {
     $417 = Math_fround($413 + $304);
     $418 = Math_fround($310 + $414);
     $419 = Math_fround($415 + $304);
     HEAPF32[$1>>2] = $417;
     HEAPF32[$28>>2] = $418;
     HEAPF32[$29>>2] = $419;
     __ZN4AABB11EncapsulateERK8Vector3f($bounds,$1);
     $420 = Math_fround($413 - $304);
     $421 = Math_fround($414 - $310);
     $422 = Math_fround($415 - $304);
     HEAPF32[$2>>2] = $420;
     HEAPF32[$30>>2] = $421;
     HEAPF32[$31>>2] = $422;
     __ZN4AABB11EncapsulateERK8Vector3f($bounds,$2);
    }
    $423 = (($i$035) + 1)|0;
    $exitcond = ($423|0)==($5|0);
    if ($exitcond) {
     break;
    } else {
     $i$035 = $423;
    }
   }
  }
 }
 __ZN4Mesh9SetBoundsERK4AABB($mesh,$bounds);
 $424 = HEAP32[$7>>2]|0;
 $425 = (($424) + 96|0);
 $426 = HEAP32[$425>>2]|0;
 __ZN4Mesh16SetChannelsDirtyEjb($mesh,$426,0);
 if (!($buildTriangles)) {
  STACKTOP = sp;return;
 }
 $427 = HEAP32[$4>>2]|0;
 $428 = ($427*6)|0;
 $429 = ($428|0)==(0);
 if ($429) {
  $440 = $427;$445 = 0;$472 = 0;
 } else {
  $430 = ($428|0)<(0);
  if ($430) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $431 = ($427*12)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $432 = (__Z15malloc_internaljj10MemLabelIdiPKci($431,16,$$byval_copy2,0,803264,79)|0);
  $$0$i$i$i = $428;$434 = $432;
  while(1) {
   $433 = ($434|0)==(0|0);
   if (!($433)) {
    HEAP16[$434>>1] = 0;
   }
   $435 = (($434) + 2|0);
   $436 = (($$0$i$i$i) + -1)|0;
   $437 = ($436|0)==(0);
   if ($437) {
    break;
   } else {
    $$0$i$i$i = $436;$434 = $435;
   }
  }
  $438 = (($432) + ($428<<1)|0);
  $$pre = HEAP32[$4>>2]|0;
  $440 = $$pre;$445 = $432;$472 = $438;
 }
 $439 = ($440|0)==(0);
 if (!($439)) {
  $i1$034 = 0;
  while(1) {
   $441 = ($i1$034*6)|0;
   $442 = $i1$034 << 2;
   $443 = $442&65535;
   $444 = (($445) + ($441<<1)|0);
   HEAP16[$444>>1] = $443;
   $446 = $442 | 1;
   $447 = $446&65535;
   $448 = $441 | 1;
   $449 = (($445) + ($448<<1)|0);
   HEAP16[$449>>1] = $447;
   $450 = $442 | 2;
   $451 = $450&65535;
   $452 = (($441) + 2)|0;
   $453 = (($445) + ($452<<1)|0);
   HEAP16[$453>>1] = $451;
   $454 = (($441) + 3)|0;
   $455 = (($445) + ($454<<1)|0);
   HEAP16[$455>>1] = $451;
   $456 = (($441) + 4)|0;
   $457 = (($445) + ($456<<1)|0);
   HEAP16[$457>>1] = $447;
   $458 = $442 | 3;
   $459 = $458&65535;
   $460 = (($441) + 5)|0;
   $461 = (($445) + ($460<<1)|0);
   HEAP16[$461>>1] = $459;
   $462 = (($i1$034) + 1)|0;
   $463 = ($462>>>0)<($440>>>0);
   if ($463) {
    $i1$034 = $462;
   } else {
    break;
   }
  }
 }
 $471 = ($445|0)==($472|0);
 $473 = $471 ? 0 : $445;
 $474 = $472;
 $475 = $445;
 $476 = (($474) - ($475))|0;
 $477 = $476 >> 1;
 __THREW__ = 0;
 (invoke_iiiiiii(122,($mesh|0),($473|0),($477|0),0,0,17)|0);
 $478 = __THREW__; __THREW__ = 0;
 $479 = $478&1;
 if ($479) {
  $464 = ___cxa_find_matching_catch()|0;
  $465 = tempRet0;
  $466 = ($445|0)==(0|0);
  if ($466) {
   ___resumeException($464|0);
   // unreachable;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($445|0),($$byval_copy2|0));
  $467 = __THREW__; __THREW__ = 0;
  $468 = $467&1;
  if ($468) {
   $469 = ___cxa_find_matching_catch()|0;
   $470 = tempRet0;
   ___cxa_call_unexpected(($469|0));
   // unreachable;
  } else {
   ___resumeException($464|0);
   // unreachable;
  }
 } else {
  $480 = ($445|0)==(0|0);
  if ($480) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($445|0),($$byval_copy2|0));
  $481 = __THREW__; __THREW__ = 0;
  $482 = $481&1;
  if ($482) {
   $483 = ___cxa_find_matching_catch()|0;
   $484 = tempRet0;
   ___cxa_call_unexpected(($483|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZN12TreeRenderer16UpdateProbeIndexEi($this,$treeProbeSetIndexOffset) {
 $this = $this|0;
 $treeProbeSetIndexOffset = $treeProbeSetIndexOffset|0;
 var $$pre = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $i$012 = 0, $i1$09 = 0, $i2$05 = 0, $i3$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($treeProbeSetIndexOffset|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $treeProbeSetIndexOffset;
 $3 = ($treeProbeSetIndexOffset|0)==(-1);
 $4 = (($this) + 160|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($3) {
  if (!($6)) {
   $9 = (($this) + 152|0);
   $10 = HEAP32[$9>>2]|0;
   $66 = $5;$i2$05 = 0;
   while(1) {
    $47 = (($10) + (($i2$05*24)|0)|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + 176|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==(0);
    if ($51) {
     $55 = $66;
    } else {
     HEAP32[$49>>2] = 1;
     $52 = (($48) + 180|0);
     HEAP32[$52>>2] = -1;
     $$pre14 = HEAP32[$4>>2]|0;
     $55 = $$pre14;
    }
    $53 = (($i2$05) + 1)|0;
    $54 = ($53>>>0)<($55>>>0);
    if ($54) {
     $66 = $55;$i2$05 = $53;
    } else {
     break;
    }
   }
  }
  $42 = (($this) + 264|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ($43|0)==(0);
  if ($44) {
   STACKTOP = sp;return;
  }
  $45 = (($this) + 256|0);
  $46 = HEAP32[$45>>2]|0;
  $68 = $43;$i3$03 = 0;
  while(1) {
   $56 = (($46) + (($i3$03*24)|0)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + 176|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0);
   if ($60) {
    $64 = $68;
   } else {
    HEAP32[$58>>2] = 1;
    $61 = (($57) + 180|0);
    HEAP32[$61>>2] = -1;
    $$pre = HEAP32[$42>>2]|0;
    $64 = $$pre;
   }
   $62 = (($i3$03) + 1)|0;
   $63 = ($62>>>0)<($64>>>0);
   if ($63) {
    $68 = $64;$i3$03 = $62;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else {
  if (!($6)) {
   $7 = (($this) + 152|0);
   $8 = HEAP32[$7>>2]|0;
   $65 = $5;$i$012 = 0;
   while(1) {
    $16 = (($8) + (($i$012*24)|0)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 176|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==(0);
    if ($20) {
     $28 = $65;
    } else {
     $21 = HEAP32[$0>>2]|0;
     HEAP32[$18>>2] = 2;
     $22 = (($17) + 252|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($23) + ($21))|0;
     $25 = (($17) + 180|0);
     HEAP32[$25>>2] = $24;
     $$pre16 = HEAP32[$4>>2]|0;
     $28 = $$pre16;
    }
    $26 = (($i$012) + 1)|0;
    $27 = ($26>>>0)<($28>>>0);
    if ($27) {
     $65 = $28;$i$012 = $26;
    } else {
     break;
    }
   }
  }
  $11 = (($this) + 264|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (($this) + 256|0);
  $15 = HEAP32[$14>>2]|0;
  $67 = $12;$i1$09 = 0;
  while(1) {
   $29 = (($15) + (($i1$09*24)|0)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($30) + 176|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0);
   if ($33) {
    $41 = $67;
   } else {
    $34 = HEAP32[$0>>2]|0;
    HEAP32[$31>>2] = 2;
    $35 = (($30) + 252|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (($36) + ($34))|0;
    $38 = (($30) + 180|0);
    HEAP32[$38>>2] = $37;
    $$pre15 = HEAP32[$11>>2]|0;
    $41 = $$pre15;
   }
   $39 = (($i1$09) + 1)|0;
   $40 = ($39>>>0)<($41>>>0);
   if ($40) {
    $67 = $41;$i1$09 = $39;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZN12TreeRenderer20CollectTreeRenderersER13dynamic_arrayI9SceneNodeLj4EERS0_I4AABBLj4EE($this,$sceneNodes,$boundingBoxes) {
 $this = $this|0;
 $sceneNodes = $sceneNodes|0;
 $boundingBoxes = $boundingBoxes|0;
 var $$byval_copy3 = 0, $$pre$phi6Z2D = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $i$02 = 0, $i1$01 = 0, $oldSize$0$lcssa = 0, $oldSize$03 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 264|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($2))|0;
 $6 = (($sceneNodes) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + ($7))|0;
 HEAP32[$6>>2] = $8;
 $9 = (($sceneNodes) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11>>>0)<($8>>>0);
 do {
  if ($12) {
   $13 = ($10|0)>(-1);
   if ($13) {
    HEAP32[$9>>2] = $8;
    $14 = HEAP32[$sceneNodes>>2]|0;
    $15 = ($8*24)|0;
    $16 = (($sceneNodes) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy3,0,803264,370)|0);
    HEAP32[$sceneNodes>>2] = $18;
    break;
   } else {
    $19 = ($8*24)|0;
    $20 = (($sceneNodes) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy3,0,803264,352)|0);
    $23 = HEAP32[$sceneNodes>>2]|0;
    $24 = HEAP32[$6>>2]|0;
    $25 = ($24*24)|0;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$9>>2] = $8;
    HEAP32[$sceneNodes>>2] = $22;
    break;
   }
  }
 } while(0);
 $26 = (($boundingBoxes) + 8|0);
 HEAP32[$26>>2] = $8;
 $27 = (($boundingBoxes) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 & 2147483647;
 $30 = ($29>>>0)<($8>>>0);
 do {
  if ($30) {
   $31 = ($28|0)>(-1);
   if ($31) {
    HEAP32[$27>>2] = $8;
    $32 = HEAP32[$boundingBoxes>>2]|0;
    $33 = ($8*24)|0;
    $34 = (($boundingBoxes) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    HEAP32[$0>>2] = $35;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $36 = (__Z16realloc_internalPvji10MemLabelIdiPKci($32,$33,4,$$byval_copy3,0,803264,370)|0);
    HEAP32[$boundingBoxes>>2] = $36;
    break;
   } else {
    $37 = ($8*24)|0;
    $38 = (($boundingBoxes) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$0>>2] = $39;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $40 = (__Z15malloc_internaljj10MemLabelIdiPKci($37,4,$$byval_copy3,0,803264,352)|0);
    $41 = HEAP32[$boundingBoxes>>2]|0;
    $42 = HEAP32[$26>>2]|0;
    $43 = ($42*24)|0;
    _memcpy(($40|0),($41|0),($43|0))|0;
    HEAP32[$27>>2] = $8;
    HEAP32[$boundingBoxes>>2] = $40;
    break;
   }
  }
 } while(0);
 $44 = HEAP32[$1>>2]|0;
 $45 = ($44|0)==(0);
 if ($45) {
  $$pre$phi6Z2D = $boundingBoxes;$$pre$phiZ2D = $sceneNodes;$oldSize$0$lcssa = $7;
 } else {
  $46 = (($this) + 92|0);
  $47 = (($this) + 184|0);
  $48 = (($this) + 152|0);
  $49 = (($this) + 168|0);
  $i$02 = 0;$oldSize$03 = $7;
  while(1) {
   $50 = HEAP32[$46>>2]|0;
   $51 = (($50) + ($i$02<<2)|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = HEAP32[$47>>2]|0;
   $54 = (($53) + ($52<<2)|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = HEAP32[$sceneNodes>>2]|0;
   $57 = (($56) + (($oldSize$03*24)|0)|0);
   $58 = HEAP32[$48>>2]|0;
   $59 = (($58) + (($55*24)|0)|0);
   ;HEAP32[$57+0>>2]=HEAP32[$59+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$59+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$59+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$59+12>>2]|0;HEAP32[$57+16>>2]=HEAP32[$59+16>>2]|0;HEAP16[$57+20>>1]=HEAP16[$59+20>>1]|0;HEAP8[$57+22>>0]=HEAP8[$59+22>>0]|0;
   $60 = HEAP32[$boundingBoxes>>2]|0;
   $61 = (($60) + (($oldSize$03*24)|0)|0);
   $62 = HEAP32[$49>>2]|0;
   $63 = (($62) + (($55*24)|0)|0);
   ;HEAP32[$61+0>>2]=HEAP32[$63+0>>2]|0;HEAP32[$61+4>>2]=HEAP32[$63+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$63+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$63+12>>2]|0;HEAP32[$61+16>>2]=HEAP32[$63+16>>2]|0;HEAP32[$61+20>>2]=HEAP32[$63+20>>2]|0;
   $64 = (($oldSize$03) + 1)|0;
   $65 = (($i$02) + 1)|0;
   $66 = HEAP32[$1>>2]|0;
   $67 = ($65>>>0)<($66>>>0);
   if ($67) {
    $i$02 = $65;$oldSize$03 = $64;
   } else {
    $$pre$phi6Z2D = $boundingBoxes;$$pre$phiZ2D = $sceneNodes;$oldSize$0$lcssa = $64;
    break;
   }
  }
 }
 $68 = HEAP32[$$pre$phiZ2D>>2]|0;
 $69 = (($68) + (($oldSize$0$lcssa*24)|0)|0);
 $70 = HEAP32[$$pre$phi6Z2D>>2]|0;
 $71 = (($70) + (($oldSize$0$lcssa*24)|0)|0);
 $72 = (($this) + 256|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = HEAP32[$3>>2]|0;
 $75 = ($74*24)|0;
 _memcpy(($69|0),($73|0),($75|0))|0;
 $76 = (($this) + 272|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (($this) + 280|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($79*24)|0;
 _memcpy(($71|0),($77|0),($80|0))|0;
 $81 = (($this) + 248|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($this) + 244|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($82|0)==($84|0);
 if ($85) {
  STACKTOP = sp;return;
 }
 $86 = $82;
 $87 = $84;
 $88 = (($86) - ($87))|0;
 $89 = (($88|0) / 148)&-1;
 $i1$01 = 0;
 while(1) {
  $90 = (($84) + (($i1$01*148)|0)|0);
  HEAP16[$90>>1] = 0;
  $91 = (($i1$01) + 1)|0;
  $92 = ($91>>>0)<($89>>>0);
  if ($92) {
   $i1$01 = $91;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer24InitializePrototypeInfosEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$byval_copy2 = 0, $$c$i$i$i4$i$i = 0, $$c$i$i$i4$i$i1415 = 0, $$neg2$i$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i11 = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i3 = 0, $i$025 = 0, $j$018 = 0, $l$02$i = 0, $r$01$i = 0, $r$017 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = 0, $temp$0$i = 0, $temp$0$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i6 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $$byval_copy2 = sp + 208|0;
 $0 = sp + 200|0;
 $1 = sp + 196|0;
 $2 = sp;
 $3 = sp + 192|0;
 $4 = sp + 188|0;
 $5 = sp + 184|0;
 $6 = sp + 168|0;
 $7 = sp + 96|0;
 $8 = sp + 68|0;
 $9 = sp + 80|0;
 $10 = sp + 172|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = (($this) + 232|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 236|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($13|0);
 do {
  if ($16) {
   $44 = $13;
  } else {
   $18 = $15;
   while(1) {
    $17 = (($18) + -28|0);
    HEAP32[$14>>2] = $17;
    $19 = (($18) + -24|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     $23 = $17;
    } else {
     $24 = (($18) + -20|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($25|0)==($20|0);
     if (!($26)) {
      $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $20;
      $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($25) + -72|0);
      $27 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($27)|0);
      $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
      $28 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i>>>0) / 72)&-1;
      $29 = $28 ^ -1;
      $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($25) + (($29*72)|0)|0);
      HEAP32[$24>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
     }
     HEAP32[$5>>2] = 55;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($20|0),($$byval_copy2|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 9;
      break;
     }
     $$pre$i$i$i = HEAP32[$14>>2]|0;
     $23 = $$pre$i$i$i;
    }
    $22 = ($23|0)==($13|0);
    if ($22) {
     label = 10;
     break;
    } else {
     $18 = $23;
    }
   }
   if ((label|0) == 9) {
    $32 = ___cxa_find_matching_catch()|0;
    $33 = tempRet0;
    ___cxa_call_unexpected(($32|0));
    // unreachable;
   }
   else if ((label|0) == 10) {
    $$pre = HEAP32[$12>>2]|0;
    $44 = $$pre;
    break;
   }
  }
 } while(0);
 $34 = (($11) + 32|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($11) + 28|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $35;
 $39 = $37;
 $40 = (($38) - ($39))|0;
 $41 = $40 >> 7;
 $42 = $13;
 $43 = $44;
 $45 = (($42) - ($43))|0;
 $46 = (($45|0) / 28)&-1;
 $47 = ($46>>>0)<($41>>>0);
 L16: do {
  if ($47) {
   $48 = (($41) - ($46))|0;
   __ZNSt3__16vectorIN12TreeRenderer13PrototypeInfoE13stl_allocatorIS2_L18MemLabelIdentifier55ELi16EEE8__appendEj($12,$48);
  } else {
   $49 = ($46>>>0)>($41>>>0);
   if ($49) {
    $50 = (($44) + (($41*28)|0)|0);
    $51 = ($13|0)==($50|0);
    if (!($51)) {
     $53 = $13;
     while(1) {
      $52 = (($53) + -28|0);
      HEAP32[$14>>2] = $52;
      $54 = (($53) + -24|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ($55|0)==(0|0);
      if ($56) {
       $58 = $52;
      } else {
       $63 = (($53) + -20|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = ($64|0)==($55|0);
       if (!($65)) {
        $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i3 = $55;
        $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = (($64) + -72|0);
        $66 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i3))|0;
        $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i6 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4) + ($66)|0);
        $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i6;
        $67 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7>>>0) / 72)&-1;
        $68 = $67 ^ -1;
        $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = (($64) + (($68*72)|0)|0);
        HEAP32[$63>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8;
       }
       HEAP32[$4>>2] = 55;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$4+0>>2]|0;
       invoke_vii(2591,($55|0),($$byval_copy2|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break;
       }
       $$pre$i$i$i11 = HEAP32[$14>>2]|0;
       $58 = $$pre$i$i$i11;
      }
      $57 = ($58|0)==($50|0);
      if ($57) {
       break L16;
      } else {
       $53 = $58;
      }
     }
     $71 = ___cxa_find_matching_catch()|0;
     $72 = tempRet0;
     ___cxa_call_unexpected(($71|0));
     // unreachable;
    }
   }
  }
 } while(0);
 $59 = HEAP32[$34>>2]|0;
 $60 = HEAP32[$36>>2]|0;
 $61 = ($59|0)==($60|0);
 if ($61) {
  STACKTOP = sp;return;
 }
 $62 = (($7) + 4|0);
 $74 = $60;$i$025 = 0;
 while(1) {
  $73 = (($74) + ($i$025<<7)|0);
  $75 = (__ZNK12TreeDatabase9Prototype11GetLODGroupEv($73)|0);
  $76 = ($75|0)==(0|0);
  if (!($76)) {
   $77 = HEAP32[$12>>2]|0;
   $78 = (($75) + 48|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($75) + 44|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = $79;
   $83 = $81;
   $84 = (($82) - ($83))|0;
   $85 = ($84|0)>(0);
   if ($85) {
    $86 = ((($77) + (($i$025*28)|0)|0) + 4|0);
    $87 = ((($77) + (($i$025*28)|0)|0) + 8|0);
    $88 = ((($77) + (($i$025*28)|0)|0) + 4|0);
    $j$018 = 0;
    while(1) {
     $89 = (__ZNK8LODGroup6GetLODEi($75,$j$018)|0);
     $90 = 1 << $j$018;
     $91 = (($89) + 20|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($92|0)==(0);
     if (!($93)) {
      $94 = (($89) + 12|0);
      $r$017 = 0;
      while(1) {
       $95 = HEAP32[$94>>2]|0;
       $96 = (($95) + ($r$017<<2)|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = (__Z23dynamic_instanceID_castIP12MeshRendererET_i($97)|0);
       $99 = ($98|0)==(0|0);
       if (!($99)) {
        dest=$2+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
        HEAP32[$7>>2] = $97;
        dest=$62+0|0; src=$2+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $100 = HEAP32[$86>>2]|0;
        $101 = HEAP32[$87>>2]|0;
        $102 = ($101|0)==($100|0);
        if ($102) {
         $116 = $100;
        } else {
         $103 = $100;
         $104 = $101;
         $105 = (($104) - ($103))|0;
         $106 = (($105|0) / 72)&-1;
         $109 = $100;$__len$03$i$i$i$i$i = $106;
         while(1) {
          $107 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
          $108 = (($109) + (($107*72)|0)|0);
          $110 = HEAP32[$108>>2]|0;
          $111 = ($110|0)<($97|0);
          if ($111) {
           $$sum$i$i$i$i$i = (($107) + 1)|0;
           $112 = (($109) + (($$sum$i$i$i$i$i*72)|0)|0);
           $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
           $113 = (($$neg2$i$i$i$i$i) - ($107))|0;
           $258 = $112;$__len$0$be$i$i$i$i$i = $113;
          } else {
           $258 = $109;$__len$0$be$i$i$i$i$i = $107;
          }
          $114 = ($__len$0$be$i$i$i$i$i|0)==(0);
          if ($114) {
           $116 = $258;
           break;
          } else {
           $109 = $258;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
          }
         }
        }
        $115 = ($116|0)==($101|0);
        if ($115) {
         label = 38;
        } else {
         $117 = HEAP32[$116>>2]|0;
         $118 = ($97|0)<($117|0);
         if ($118) {
          label = 38;
         } else {
          $$c$i$i$i4$i$i1415 = $116;
         }
        }
        do {
         if ((label|0) == 38) {
          label = 0;
          HEAP32[$1>>2] = $116;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
          __ZNSt3__16vectorINS_4pairIiN12TreeRenderer15RendererLODInfoEEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE6insertENS_11__wrap_iterIPKS4_EERSA_($0,$88,$$byval_copy2,$7);
          $119 = HEAP32[$0>>2]|0;
          $$c$i$i$i4$i$i = $119;
          $120 = (($$c$i$i$i4$i$i) + 68|0);
          HEAP32[$120>>2] = 0;
          $121 = (($98) + 24|0);
          $122 = HEAP32[$121>>2]|0;
          $123 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($122)|0);
          $124 = ($123|0)==(0|0);
          $125 = (($$c$i$i$i4$i$i) + 4|0);
          if ($124) {
           dest=$125+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           $$c$i$i$i4$i$i1415 = $$c$i$i$i4$i$i;
           break;
          } else {
           $126 = (($123) + 44|0);
           ;HEAP32[$8+0>>2]=HEAP32[$126+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$126+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$126+8>>2]|0;
           $127 = (($123) + 28|0);
           ;HEAP32[$9+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$127+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$127+12>>2]|0;
           $128 = (($123) + 56|0);
           ;HEAP32[$10+0>>2]=HEAP32[$128+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$128+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$128+8>>2]|0;
           __ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_($125,$8,$9,$10);
           $$c$i$i$i4$i$i1415 = $$c$i$i$i4$i$i;
           break;
          }
         }
        } while(0);
        $129 = (($$c$i$i$i4$i$i1415) + 68|0);
        $130 = HEAP32[$129>>2]|0;
        $131 = $130 | $90;
        HEAP32[$129>>2] = $131;
       }
       $132 = (($r$017) + 1)|0;
       $133 = HEAP32[$91>>2]|0;
       $134 = ($132>>>0)<($133>>>0);
       if ($134) {
        $r$017 = $132;
       } else {
        break;
       }
      }
     }
     $135 = (($j$018) + 1)|0;
     $136 = HEAP32[$78>>2]|0;
     $137 = HEAP32[$80>>2]|0;
     $138 = $136;
     $139 = $137;
     $140 = (($138) - ($139))|0;
     $141 = (($140|0) / 28)&-1;
     $142 = ($135|0)<($141|0);
     if ($142) {
      $j$018 = $135;
     } else {
      break;
     }
    }
   }
   $143 = ((($77) + (($i$025*28)|0)|0) + 16|0);
   $144 = HEAP32[$36>>2]|0;
   $145 = (($144) + ($i$025<<7)|0);
   $146 = (__ZNK12TreeDatabase9Prototype11GetLODGroupEv($145)|0);
   $147 = ($146|0)==(0|0);
   L68: do {
    if ($147) {
     label = 61;
    } else {
     $148 = (($146) + 48|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = (($146) + 44|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = $149;
     $153 = $151;
     $154 = (($152) - ($153))|0;
     $155 = ($154|0)>(0);
     if ($155) {
      $l$02$i = 0;
      L70: while(1) {
       $164 = (__ZNK8LODGroup6GetLODEi($146,$l$02$i)|0);
       $165 = (($164) + 20|0);
       $166 = HEAP32[$165>>2]|0;
       $167 = ($166|0)==(0);
       L72: do {
        if (!($167)) {
         $168 = (($164) + 12|0);
         $r$01$i = 0;
         while(1) {
          $172 = HEAP32[$168>>2]|0;
          $173 = (($172) + ($r$01$i<<2)|0);
          $174 = HEAP32[$173>>2]|0;
          HEAP32[$3>>2] = $174;
          $175 = HEAP32[560624>>2]|0;
          $176 = ($175|0)==(0|0);
          if ($176) {
           label = 58;
          } else {
           $177 = (($175) + 36|0);
           $178 = HEAP32[$177>>2]|0;
           $179 = (($175) + 4|0);
           $180 = HEAP32[$179>>2]|0;
           $181 = ($178|0)==($180|0);
           do {
            if ($181) {
             $182 = (($175) + 28|0);
             $183 = HEAP32[$182>>2]|0;
             $184 = (($175) + 32|0);
             $185 = HEAP32[$184>>2]|0;
             $186 = (($183) + ($185<<3)|0);
             $202 = $186;
            } else {
             __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$175,$3);
             $187 = HEAP32[$$byval_copy2>>2]|0;
             $188 = ($187|0)==(-1);
             $189 = (($175) + 28|0);
             $190 = HEAP32[$189>>2]|0;
             if ($188) {
              $191 = (($175) + 32|0);
              $192 = HEAP32[$191>>2]|0;
              $193 = (($190) + ($192<<3)|0);
              $202 = $193;
              break;
             } else {
              $194 = (($190) + ($187<<3)|0);
              $202 = $194;
              break;
             }
            }
           } while(0);
           $195 = HEAP32[560624>>2]|0;
           $196 = (($195) + 28|0);
           $197 = HEAP32[$196>>2]|0;
           $198 = (($195) + 32|0);
           $199 = HEAP32[$198>>2]|0;
           $200 = (($197) + ($199<<3)|0);
           $201 = ($202|0)==($200|0);
           if ($201) {
            label = 58;
           } else {
            $203 = (($202) + 4|0);
            $204 = HEAP32[$203>>2]|0;
            $205 = ($204|0)==(0|0);
            if ($205) {
             label = 58;
            } else {
             $temp$0$i$i = $204;
            }
           }
          }
          if ((label|0) == 58) {
           label = 0;
           $206 = HEAP32[$173>>2]|0;
           $207 = (__Z31ReadObjectFromPersistentManageri($206)|0);
           $temp$0$i$i = $207;
          }
          $208 = (($temp$0$i$i) + 24|0);
          $209 = HEAP32[$208>>2]|0;
          $210 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($209,193)|0);
          $211 = ($210|0)==(0|0);
          $171 = (($r$01$i) + 1)|0;
          if (!($211)) {
           break;
          }
          $169 = HEAP32[$165>>2]|0;
          $170 = ($171>>>0)<($169>>>0);
          if ($170) {
           $r$01$i = $171;
          } else {
           break L72;
          }
         }
         $212 = (($210) + 28|0);
         $213 = HEAP32[$212>>2]|0;
         $214 = ($213|0)==(0);
         if (!($214)) {
          break L70;
         }
        }
       } while(0);
       $156 = (($l$02$i) + 1)|0;
       $157 = HEAP32[$148>>2]|0;
       $158 = HEAP32[$150>>2]|0;
       $159 = $157;
       $160 = $158;
       $161 = (($159) - ($160))|0;
       $162 = (($161|0) / 28)&-1;
       $163 = ($156|0)<($162|0);
       if ($163) {
        $l$02$i = $156;
       } else {
        label = 61;
        break L68;
       }
      }
      HEAP32[$143>>2] = $213;
      HEAP32[$6>>2] = $213;
      $215 = HEAP32[560624>>2]|0;
      $216 = ($215|0)==(0|0);
      if ($216) {
       label = 70;
      } else {
       $217 = (($215) + 36|0);
       $218 = HEAP32[$217>>2]|0;
       $219 = (($215) + 4|0);
       $220 = HEAP32[$219>>2]|0;
       $221 = ($218|0)==($220|0);
       do {
        if ($221) {
         $222 = (($215) + 28|0);
         $223 = HEAP32[$222>>2]|0;
         $224 = (($215) + 32|0);
         $225 = HEAP32[$224>>2]|0;
         $226 = (($223) + ($225<<3)|0);
         $242 = $226;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy2,$215,$6);
         $227 = HEAP32[$$byval_copy2>>2]|0;
         $228 = ($227|0)==(-1);
         $229 = (($215) + 28|0);
         $230 = HEAP32[$229>>2]|0;
         if ($228) {
          $231 = (($215) + 32|0);
          $232 = HEAP32[$231>>2]|0;
          $233 = (($230) + ($232<<3)|0);
          $242 = $233;
          break;
         } else {
          $234 = (($230) + ($227<<3)|0);
          $242 = $234;
          break;
         }
        }
       } while(0);
       $235 = HEAP32[560624>>2]|0;
       $236 = (($235) + 28|0);
       $237 = HEAP32[$236>>2]|0;
       $238 = (($235) + 32|0);
       $239 = HEAP32[$238>>2]|0;
       $240 = (($237) + ($239<<3)|0);
       $241 = ($242|0)==($240|0);
       if ($241) {
        label = 70;
       } else {
        $243 = (($242) + 4|0);
        $244 = HEAP32[$243>>2]|0;
        $245 = ($244|0)==(0|0);
        if ($245) {
         label = 70;
        } else {
         $temp$0$i = $244;
        }
       }
      }
      if ((label|0) == 70) {
       label = 0;
       $246 = HEAP32[$143>>2]|0;
       $247 = (__Z31ReadObjectFromPersistentManageri($246)|0);
       $temp$0$i = $247;
      }
      $$0$i = $temp$0$i;
     } else {
      label = 61;
     }
    }
   } while(0);
   if ((label|0) == 61) {
    label = 0;
    HEAP32[$143>>2] = 0;
    $$0$i = 0;
   }
   $248 = ((($77) + (($i$025*28)|0)|0) + 20|0);
   HEAP32[$248>>2] = $$0$i;
   $249 = ((($77) + (($i$025*28)|0)|0) + 24|0);
   HEAP8[$249>>0] = 1;
  }
  $250 = (($i$025) + 1)|0;
  $251 = HEAP32[$34>>2]|0;
  $252 = HEAP32[$36>>2]|0;
  $253 = $251;
  $254 = $252;
  $255 = (($253) - ($254))|0;
  $256 = $255 >> 7;
  $257 = ($250>>>0)<($256>>>0);
  if ($257) {
   $74 = $252;$i$025 = $250;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__14listIN12TreeRenderer18BillboardRenderersE13stl_allocatorIS2_L18MemLabelIdentifier55ELi16EEE9push_backERKS2_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$byval_copy2 = 0, $$idx$i$i$i$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$0>>2] = 55;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Z15malloc_internaljj10MemLabelIdiPKci(36,16,$$byval_copy2,0,803264,79)|0);
 $3 = (($2) + 8|0);
 $4 = HEAP32[$__x>>2]|0;
 HEAP32[$3>>2] = $4;
 $5 = (($2) + 12|0);
 $6 = (($__x) + 4|0);
 $7 = $6;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $5;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = (($__x) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($2) + 24|0);
 HEAP32[$19>>2] = $18;
 $20 = (($2) + 28|0);
 HEAP32[$20>>2] = 0;
 $21 = (($2) + 32|0);
 HEAP32[$21>>2] = 0;
 $22 = (($2) + 20|0);
 HEAP32[$22>>2] = 0;
 $23 = (($__x) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($__x) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $$idx$i$i$i$i$i = $26 << 2;
 $27 = $$idx$i$i$i$i$i >> 2;
 HEAP32[$20>>2] = $27;
 $28 = ($27|0)==(0);
 if ($28) {
  $32 = 0;$33 = 0;
  _memcpy(($32|0),($24|0),($33|0))|0;
  $34 = HEAP32[$this>>2]|0;
  $35 = (($34) + 4|0);
  HEAP32[$35>>2] = $2;
  $36 = HEAP32[$this>>2]|0;
  HEAP32[$2>>2] = $36;
  HEAP32[$this>>2] = $2;
  $37 = (($2) + 4|0);
  HEAP32[$37>>2] = $this;
  $38 = (($this) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 1)|0;
  HEAP32[$38>>2] = $40;
  STACKTOP = sp;return;
 }
 HEAP32[$21>>2] = $27;
 HEAP32[$0>>2] = $18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $29 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i$i|0),4,($$byval_copy2|0),0,(803264|0),370)|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if (!($31)) {
  HEAP32[$22>>2] = $29;
  $$pre$i$i$i$i = HEAP32[$20>>2]|0;
  $phitmp$i$i$i$i = $$pre$i$i$i$i << 2;
  $32 = $29;$33 = $phitmp$i$i$i$i;
  _memcpy(($32|0),($24|0),($33|0))|0;
  $34 = HEAP32[$this>>2]|0;
  $35 = (($34) + 4|0);
  HEAP32[$35>>2] = $2;
  $36 = HEAP32[$this>>2]|0;
  HEAP32[$2>>2] = $36;
  HEAP32[$this>>2] = $2;
  $37 = (($2) + 4|0);
  HEAP32[$37>>2] = $this;
  $38 = (($this) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 1)|0;
  HEAP32[$38>>2] = $40;
  STACKTOP = sp;return;
 }
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 $43 = ($2|0)==(0|0);
 if ($43) {
  ___resumeException($41|0);
  // unreachable;
 }
 HEAP32[$1>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($2|0),($$byval_copy2|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  ___resumeException($41|0);
  // unreachable;
 }
}
function __ZN13dynamic_arrayI9SceneNodeLj4EE19push_back_constructEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 do {
  if ($7) {
   $8 = $5 << 1;
   $9 = ($8|0)==(0);
   $10 = $9 ? 1 : $8;
   $11 = ($6>>>0)<($10>>>0);
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*24)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,803264,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*24)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,803264,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*24)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($25) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($26*24)|0)|0);
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return ($28|0);
 }
 HEAP32[$28>>2] = 0;
 $30 = ((($27) + (($26*24)|0)|0) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($27) + (($26*24)|0)|0) + 8|0);
 HEAP32[$31>>2] = -1;
 $32 = ((($27) + (($26*24)|0)|0) + 12|0);
 ;HEAP16[$32+0>>1]=0|0;HEAP16[$32+2>>1]=0|0;HEAP16[$32+4>>1]=0|0;HEAP16[$32+6>>1]=0|0;HEAP16[$32+8>>1]=0|0;HEAP8[$32+10>>0]=0|0;
 STACKTOP = sp;return ($28|0);
}
function __ZN13dynamic_arrayI4AABBLj4EE9push_backEv($this) {
 $this = $this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 2147483647;
 $7 = ($3>>>0)>($6>>>0);
 do {
  if ($7) {
   $8 = $5 << 1;
   $9 = ($8|0)==(0);
   $10 = $9 ? 1 : $8;
   $11 = ($6>>>0)<($10>>>0);
   if ($11) {
    $12 = ($5|0)>(-1);
    if ($12) {
     HEAP32[$4>>2] = $10;
     $13 = HEAP32[$this>>2]|0;
     $14 = ($10*24)|0;
     $15 = (($this) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     HEAP32[$0>>2] = $16;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $17 = (__Z16realloc_internalPvji10MemLabelIdiPKci($13,$14,4,$$byval_copy1,0,803264,370)|0);
     HEAP32[$this>>2] = $17;
     break;
    } else {
     $18 = ($10*24)|0;
     $19 = (($this) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     HEAP32[$0>>2] = $20;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,4,$$byval_copy1,0,803264,352)|0);
     $22 = HEAP32[$this>>2]|0;
     $23 = HEAP32[$1>>2]|0;
     $24 = ($23*24)|0;
     _memcpy(($21|0),($22|0),($24|0))|0;
     HEAP32[$4>>2] = $10;
     HEAP32[$this>>2] = $21;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$1>>2]|0;
 $26 = (($25) + -1)|0;
 $27 = HEAP32[$this>>2]|0;
 $28 = (($27) + (($26*24)|0)|0);
 STACKTOP = sp;return ($28|0);
}
function __ZN12TreeRenderer11RenderBatchER14TreeBinaryTreef($this,$binTree,$sqrDistance) {
 $this = $this|0;
 $binTree = $binTree|0;
 $sqrDistance = Math_fround($sqrDistance);
 var $$byval_copy4 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($binTree) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = (($binTree) + 44|0);
   $6 = HEAP32[$5>>2]|0;
   __Z19DestroySingleObjectP6Object($6);
   HEAP32[$5>>2] = 0;
   $7 = HEAP32[628384>>2]|0;
   HEAP32[$0>>2] = $7;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   $8 = (__Znwj10MemLabelIdbiPKci(280,$$byval_copy4,1,16,803264,1111)|0);
   HEAP32[$1>>2] = $7;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viii(1698,($8|0),($$byval_copy4|0),0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $17 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($8)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 24|0);
    $20 = HEAP32[$19>>2]|0;
    FUNCTION_TABLE_vi[$20 & 4095]($17);
    $21 = HEAP32[$17>>2]|0;
    $22 = (($21) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    FUNCTION_TABLE_vii[$23 & 4095]($17,4);
    HEAP32[$5>>2] = $17;
    $24 = HEAP32[$17>>2]|0;
    $25 = (($24) + 44|0);
    $26 = HEAP32[$25>>2]|0;
    FUNCTION_TABLE_vii[$26 & 4095]($17,61);
    $27 = HEAP32[$5>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    $29 = (($28) + 36|0);
    $30 = HEAP32[$29>>2]|0;
    FUNCTION_TABLE_vii[$30 & 4095]($27,803528);
    $31 = HEAP32[$5>>2]|0;
    $32 = (($binTree) + 4|0);
    __ZN12TreeRenderer21GenerateBillboardMeshER4MeshRK13dynamic_arrayIjLj4EEb($this,$31,$32,0);
    $33 = (($binTree) + 48|0);
    HEAP32[$33>>2] = -1;
    break;
   }
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viiiiii(97,($8|0),($$byval_copy4|0),1,16,(803264|0),1111);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    $15 = ___cxa_find_matching_catch(0|0)|0;
    $16 = tempRet0;
    ___clang_call_terminate($15);
    // unreachable;
   } else {
    ___resumeException($11|0);
    // unreachable;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 1;
 $34 = (($this) + 108|0);
 $35 = (($this) + 116|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$35>>2] = $37;
 $38 = (($this) + 120|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39 & 2147483647;
 $41 = ($37>>>0)>($40>>>0);
 if (!($41)) {
  $60 = $37;
  $59 = (($60) + -1)|0;
  $61 = HEAP32[$34>>2]|0;
  $62 = (($61) + ($59<<2)|0);
  HEAP32[$62>>2] = $binTree;
  STACKTOP = sp;return;
 }
 $42 = $39 << 1;
 $43 = ($42|0)==(0);
 $44 = $43 ? 1 : $42;
 $45 = ($40>>>0)<($44>>>0);
 do {
  if ($45) {
   $46 = ($39|0)>(-1);
   if ($46) {
    HEAP32[$38>>2] = $44;
    $47 = HEAP32[$34>>2]|0;
    $48 = $44 << 2;
    $49 = (($this) + 112|0);
    $50 = HEAP32[$49>>2]|0;
    HEAP32[$0>>2] = $50;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $51 = (__Z16realloc_internalPvji10MemLabelIdiPKci($47,$48,4,$$byval_copy4,0,803264,370)|0);
    HEAP32[$34>>2] = $51;
    break;
   } else {
    $52 = $44 << 2;
    $53 = (($this) + 112|0);
    $54 = HEAP32[$53>>2]|0;
    HEAP32[$0>>2] = $54;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $55 = (__Z15malloc_internaljj10MemLabelIdiPKci($52,4,$$byval_copy4,0,803264,352)|0);
    $56 = HEAP32[$34>>2]|0;
    $57 = HEAP32[$35>>2]|0;
    $58 = $57 << 2;
    _memcpy(($55|0),($56|0),($58|0))|0;
    HEAP32[$38>>2] = $44;
    HEAP32[$34>>2] = $55;
    break;
   }
  }
 } while(0);
 $$pre$i$i = HEAP32[$35>>2]|0;
 $60 = $$pre$i$i;
 $59 = (($60) + -1)|0;
 $61 = HEAP32[$34>>2]|0;
 $62 = (($61) + ($59<<2)|0);
 HEAP32[$62>>2] = $binTree;
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIjLj4EE9push_backERKj($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$t>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if (!($8)) {
  $27 = $4;
  $26 = (($27) + -1)|0;
  $28 = HEAP32[$this>>2]|0;
  $29 = (($28) + ($26<<2)|0);
  HEAP32[$29>>2] = $1;
  STACKTOP = sp;return;
 }
 $9 = $6 << 1;
 $10 = ($9|0)==(0);
 $11 = $10 ? 1 : $9;
 $12 = ($7>>>0)<($11>>>0);
 do {
  if ($12) {
   $13 = ($6|0)>(-1);
   if ($13) {
    HEAP32[$5>>2] = $11;
    $14 = HEAP32[$this>>2]|0;
    $15 = $11 << 2;
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy1,0,803264,370)|0);
    HEAP32[$this>>2] = $18;
    break;
   } else {
    $19 = $11 << 2;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,803264,352)|0);
    $23 = HEAP32[$this>>2]|0;
    $24 = HEAP32[$2>>2]|0;
    $25 = $24 << 2;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$5>>2] = $11;
    HEAP32[$this>>2] = $22;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$2>>2]|0;
 $27 = $$pre$i;
 $26 = (($27) + -1)|0;
 $28 = HEAP32[$this>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAP32[$29>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer15WillRenderTreesERK9IndexListPK9SceneNodeR13dynamic_arrayIbLj1EE($visibleList,$treeNodes,$visibilityBits) {
 $visibleList = $visibleList|0;
 $treeNodes = $treeNodes|0;
 $visibilityBits = $visibilityBits|0;
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($visibleList) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $$pre = HEAP32[$visibilityBits>>2]|0;
 $19 = $1;$7 = $$pre;$i$01 = 0;
 while(1) {
  $3 = HEAP32[$visibleList>>2]|0;
  $4 = (($3) + ($i$01<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($7) + ($5)|0);
  $8 = HEAP8[$6>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   $10 = (($treeNodes) + (($5*24)|0)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 244|0);
   $13 = HEAP32[$12>>2]|0;
   if ((($13|0) == 1)) {
    __ZN23LODTreeInstanceRenderer10UpdateWindEv($11);
   } else if ((($13|0) == 2)) {
    __ZN29BillboardTreeInstanceRenderer10UpdateWindEv($11);
   }
   $14 = HEAP32[$visibilityBits>>2]|0;
   $15 = (($14) + ($5)|0);
   HEAP8[$15>>0] = 1;
   $$pre2 = HEAP32[$0>>2]|0;
   $18 = $$pre2;$20 = $14;
  } else {
   $18 = $19;$20 = $7;
  }
  $16 = (($i$01) + 1)|0;
  $17 = ($16|0)<($18|0);
  if ($17) {
   $19 = $18;$7 = $20;$i$01 = $16;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12TreeRenderer21ComputeWindPropertiesEib($agg$result,$this,$treeInstanceDataIndex,$globalWindOnly) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $treeInstanceDataIndex = $treeInstanceDataIndex|0;
 $globalWindOnly = $globalWindOnly|0;
 var $$pre = 0, $$tr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $0 = ($treeInstanceDataIndex|0)>(-1);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 244|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + (($treeInstanceDataIndex*148)|0)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = HEAP16[$3>>1]|0;
 $9 = $8 & 1;
 $10 = ($9<<16>>16)==(0);
 if ($10) {
  $11 = (__ZN20SpeedTreeWindManager11GetInstanceEv()|0);
  $12 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 32|0);
  $13 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 4|0);
  $14 = HEAP32[$5>>2]|0;
  $15 = (__ZN20SpeedTreeWindManager8TickWindER25LightweightSTWindInstanceRK4AABBRK18SpeedTreeWindAsset($11,$12,$13,$14)|0);
  $16 = ($15|0)==(0|0);
  $$pre = HEAP16[$3>>1]|0;
  if ($16) {
   $21 = $$pre;
  } else {
   $17 = $$pre&65535;
   $18 = $17 | 2;
   $19 = $18&65535;
   HEAP16[$3>>1] = $19;
   $21 = $19;
  }
  $20 = $21&65535;
  $22 = $20 | 1;
  $23 = $22&65535;
  HEAP16[$3>>1] = $23;
  $24 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 84|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0);
  if (!($26)) {
   $27 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 76|0);
   __ZN20SpeedTreeWindManager18FillWindPropertiesER21MaterialPropertyBlockbbPKNS_8WindDataERK25LightweightSTWindInstance($27,1,0,$15,$12);
  }
  $28 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 120|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0);
  if (!($30)) {
   $31 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 112|0);
   __ZN20SpeedTreeWindManager18FillWindPropertiesER21MaterialPropertyBlockbbPKNS_8WindDataERK25LightweightSTWindInstance($31,1,1,$15,$12);
  }
 }
 $32 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 112|0);
 $33 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 76|0);
 $34 = $globalWindOnly ? $32 : $33;
 HEAP32[$agg$result>>2] = $34;
 $35 = HEAP16[$3>>1]|0;
 $36 = (($agg$result) + 4|0);
 $37 = ($35&65535) >>> 1;
 $$tr = $37&255;
 $38 = $$tr & 1;
 HEAP8[$36>>0] = $38;
 $39 = ((($2) + (($treeInstanceDataIndex*148)|0)|0) + 36|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($agg$result) + 8|0);
 HEAPF32[$41>>2] = $40;
 STACKTOP = sp;return;
}
function __Z23dynamic_instanceID_castIP12MeshRendererET_i($instanceID) {
 $instanceID = $instanceID|0;
 var $$0$i = 0, $$0$i13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = ($instanceID|0)==(0);
 do {
  if (!($1)) {
   HEAP32[$0>>2] = $instanceID;
   $2 = HEAP32[560624>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    label = 10;
   } else {
    $4 = (($2) + 36|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (($2) + 4|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($5|0)==($7|0);
    do {
     if ($8) {
      $9 = (($2) + 28|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = (($2) + 32|0);
      $12 = HEAP32[$11>>2]|0;
      $13 = (($10) + ($12<<3)|0);
      $29 = $13;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$2,$0);
      $14 = HEAP32[$pos$i$i$i$i>>2]|0;
      $15 = ($14|0)==(-1);
      $16 = (($2) + 28|0);
      $17 = HEAP32[$16>>2]|0;
      if ($15) {
       $18 = (($2) + 32|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($17) + ($19<<3)|0);
       $29 = $20;
       break;
      } else {
       $21 = (($17) + ($14<<3)|0);
       $29 = $21;
       break;
      }
     }
    } while(0);
    $22 = HEAP32[560624>>2]|0;
    $23 = (($22) + 28|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($22) + 32|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + ($26<<3)|0);
    $28 = ($29|0)==($27|0);
    if ($28) {
     label = 10;
    } else {
     $30 = (($29) + 4|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==(0|0);
     if ($32) {
      label = 10;
     } else {
      $$0$i13 = $31;
     }
    }
   }
   if ((label|0) == 10) {
    $33 = (__Z31ReadObjectFromPersistentManageri($instanceID)|0);
    $34 = ($33|0)==(0|0);
    if ($34) {
     break;
    } else {
     $$0$i13 = $33;
    }
   }
   $35 = (($$0$i13) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = $36 >>> 21;
   $38 = HEAP32[560640>>2]|0;
   $39 = Math_imul($38, $37)|0;
   $40 = (($39) + 23)|0;
   $41 = $40 >> 5;
   $42 = $41 << 5;
   $43 = (($40) - ($42))|0;
   $44 = HEAP32[560632>>2]|0;
   $45 = (($44) + ($41<<2)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = 1 << $43;
   $48 = $47 & $46;
   $49 = ($48|0)==(0);
   if (!($49)) {
    $$0$i = $$0$i13;
    STACKTOP = sp;return ($$0$i|0);
   }
  }
 } while(0);
 $$0$i = 0;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZNSt3__16vectorIN12TreeRenderer19LODTreeInstanceDataE13stl_allocatorIS2_L18MemLabelIdentifier55ELi16EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i6 = 0, $$0$i7 = 0, $$byval_copy19 = 0, $$pre = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__v = 0, $eh$lpad$body$i$i$i$indexZ2D = 0, $eh$lpad$body$index10Z2D = 0;
 var $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy19 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 148)&-1;
 $10 = (($9) + 1)|0;
 $11 = ($10|0)<(0);
 if ($11) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($7))|0;
 $16 = (($15|0) / 148)&-1;
 $17 = ($16>>>0)<(1073741823);
 if ($17) {
  $20 = $16 << 1;
  $21 = ($20>>>0)<($10>>>0);
  $22 = $21 ? $10 : $20;
  $23 = (($__v) + 12|0);
  HEAP32[$23>>2] = 0;
  $24 = (($__v) + 16|0);
  HEAP32[$24>>2] = $2;
  $25 = ($22|0)==(0);
  if ($25) {
   $$0$i7 = 0;$28 = 0;$33 = $23;
  } else {
   $$0$i6 = $22;$110 = $23;
   label = 6;
  }
 } else {
  $18 = (($__v) + 12|0);
  HEAP32[$18>>2] = 0;
  $19 = (($__v) + 16|0);
  HEAP32[$19>>2] = $2;
  $$0$i6 = 2147483647;$110 = $18;
  label = 6;
 }
 if ((label|0) == 6) {
  $26 = ($$0$i6*148)|0;
  HEAP32[$0>>2] = 55;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
  $27 = (__Z15malloc_internaljj10MemLabelIdiPKci($26,16,$$byval_copy19,0,803264,79)|0);
  $$0$i7 = $$0$i6;$28 = $27;$33 = $110;
 }
 HEAP32[$__v>>2] = $28;
 $29 = (($28) + (($9*148)|0)|0);
 $30 = (($__v) + 8|0);
 HEAP32[$30>>2] = $29;
 $31 = (($__v) + 4|0);
 HEAP32[$31>>2] = $29;
 $32 = (($28) + (($$0$i7*148)|0)|0);
 HEAP32[$33>>2] = $32;
 $34 = ($29|0)==(0|0);
 do {
  if ($34) {
   $77 = 0;
   label = 23;
  } else {
   dest=$29+0|0; src=$__x+0|0; stop=dest+76|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
   $35 = ((($28) + (($9*148)|0)|0) + 76|0);
   $36 = (($__x) + 76|0);
   __THREW__ = 0;
   invoke_vii(3423,($35|0),($36|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 32;
   } else {
    $39 = ((($28) + (($9*148)|0)|0) + 112|0);
    $40 = (($__x) + 112|0);
    __THREW__ = 0;
    invoke_vii(3423,($39|0),($40|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     $$pre5 = HEAP32[$30>>2]|0;
     $77 = $$pre5;
     label = 23;
     break;
    }
    $43 = ___cxa_find_matching_catch()|0;
    $44 = tempRet0;
    $45 = ((($28) + (($9*148)|0)|0) + 104|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)>(-1);
    do {
     if ($47) {
      $48 = ((($28) + (($9*148)|0)|0) + 92|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ((($28) + (($9*148)|0)|0) + 96|0);
      $51 = HEAP32[$50>>2]|0;
      HEAP32[$1>>2] = $51;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($49|0),($$byval_copy19|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if (!($53)) {
       HEAP32[$48>>2] = 0;
       break;
      }
      $62 = ___cxa_find_matching_catch(0|0)|0;
      $63 = tempRet0;
      $64 = ((($28) + (($9*148)|0)|0) + 88|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = ($65|0)>(-1);
      if (!($66)) {
       $eh$lpad$body$i$i$i$indexZ2D = $62;
       ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
       // unreachable;
      }
      $67 = HEAP32[$35>>2]|0;
      $68 = ((($28) + (($9*148)|0)|0) + 80|0);
      $69 = HEAP32[$68>>2]|0;
      HEAP32[$0>>2] = $69;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($67|0),($$byval_copy19|0));
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       $72 = ___cxa_find_matching_catch(0|0)|0;
       $73 = tempRet0;
       ___clang_call_terminate($72);
       // unreachable;
      }
      HEAP32[$35>>2] = 0;
      $eh$lpad$body$i$i$i$indexZ2D = $62;
      ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
      // unreachable;
     }
    } while(0);
    $54 = ((($28) + (($9*148)|0)|0) + 88|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)>(-1);
    if ($56) {
     $57 = HEAP32[$35>>2]|0;
     $58 = ((($28) + (($9*148)|0)|0) + 80|0);
     $59 = HEAP32[$58>>2]|0;
     HEAP32[$0>>2] = $59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($57|0),($$byval_copy19|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if (!($61)) {
      HEAP32[$35>>2] = 0;
      $eh$lpad$body$index10Z2D = $44;$eh$lpad$body$indexZ2D = $43;
      break;
     }
     $74 = ___cxa_find_matching_catch(0|0)|0;
     $75 = tempRet0;
     $eh$lpad$body$i$i$i$indexZ2D = $74;
     ___clang_call_terminate($eh$lpad$body$i$i$i$indexZ2D);
     // unreachable;
    } else {
     $eh$lpad$body$index10Z2D = $44;$eh$lpad$body$indexZ2D = $43;
    }
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $76 = (($77) + 148|0);
  HEAP32[$30>>2] = $76;
  __THREW__ = 0;
  invoke_vii(3429,($this|0),($__v|0));
  $78 = __THREW__; __THREW__ = 0;
  $79 = $78&1;
  if ($79) {
   label = 32;
  } else {
   $80 = HEAP32[$31>>2]|0;
   $$pre = HEAP32[$30>>2]|0;
   $82 = $$pre;
   while(1) {
    $81 = ($82|0)==($80|0);
    if ($81) {
     break;
    }
    $83 = (($82) + -148|0);
    HEAP32[$30>>2] = $83;
    __THREW__ = 0;
    invoke_vi(3717,($83|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     label = 27;
     break;
    } else {
     $82 = $83;
    }
   }
   if ((label|0) == 27) {
    $86 = ___cxa_find_matching_catch()|0;
    $87 = tempRet0;
    ___cxa_call_unexpected(($86|0));
    // unreachable;
   }
   $88 = HEAP32[$__v>>2]|0;
   $89 = ($88|0)==(0|0);
   if ($89) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($88|0),($$byval_copy19|0));
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    $92 = ___cxa_find_matching_catch()|0;
    $93 = tempRet0;
    ___cxa_call_unexpected(($92|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 if ((label|0) == 32) {
  $94 = ___cxa_find_matching_catch()|0;
  $95 = tempRet0;
  $eh$lpad$body$index10Z2D = $95;$eh$lpad$body$indexZ2D = $94;
 }
 $96 = HEAP32[$31>>2]|0;
 $$pre4 = HEAP32[$30>>2]|0;
 $98 = $$pre4;
 while(1) {
  $97 = ($98|0)==($96|0);
  if ($97) {
   break;
  }
  $99 = (($98) + -148|0);
  HEAP32[$30>>2] = $99;
  __THREW__ = 0;
  invoke_vi(3717,($99|0));
  $100 = __THREW__; __THREW__ = 0;
  $101 = $100&1;
  if ($101) {
   label = 36;
   break;
  } else {
   $98 = $99;
  }
 }
 if ((label|0) == 36) {
  $102 = ___cxa_find_matching_catch()|0;
  $103 = tempRet0;
  ___cxa_call_unexpected(($102|0));
  // unreachable;
 }
 $104 = HEAP32[$__v>>2]|0;
 $105 = ($104|0)==(0|0);
 if ($105) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$0>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($104|0),($$byval_copy19|0));
 $106 = __THREW__; __THREW__ = 0;
 $107 = $106&1;
 if ($107) {
  $108 = ___cxa_find_matching_catch()|0;
  $109 = tempRet0;
  ___cxa_call_unexpected(($108|0));
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN12TreeRenderer19LODTreeInstanceDataE13stl_allocatorIS2_L18MemLabelIdentifier55ELi16EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS5_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$02$i = 0, $$byval_copy9 = 0, $$pre = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$i$i$i$i$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy9 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($__v) + 4|0);
 $6 = ($4|0)==($2|0);
 $$pre7 = HEAP32[$5>>2]|0;
 if ($6) {
  $52 = $$pre7;$53 = $2;
  HEAP32[$this>>2] = $52;
  HEAP32[$5>>2] = $53;
  $54 = (($__v) + 8|0);
  $55 = HEAP32[$3>>2]|0;
  $56 = HEAP32[$54>>2]|0;
  HEAP32[$3>>2] = $56;
  HEAP32[$54>>2] = $55;
  $57 = (($this) + 8|0);
  $58 = (($__v) + 12|0);
  $59 = HEAP32[$57>>2]|0;
  $60 = HEAP32[$58>>2]|0;
  HEAP32[$57>>2] = $60;
  HEAP32[$58>>2] = $59;
  $61 = HEAP32[$5>>2]|0;
  HEAP32[$__v>>2] = $61;
  STACKTOP = sp;return;
 } else {
  $$02$i = $4;$8 = $$pre7;
 }
 while(1) {
  $7 = (($8) + -148|0);
  $9 = (($$02$i) + -148|0);
  dest=$7+0|0; src=$9+0|0; stop=dest+76|0; do { HEAP16[dest>>1]=HEAP16[src>>1]|0; dest=dest+2|0; src=src+2|0; } while ((dest|0) < (stop|0));
  $10 = (($8) + -72|0);
  $11 = (($$02$i) + -72|0);
  __ZN21MaterialPropertyBlockC2ERKS_($10,$11);
  $12 = (($8) + -36|0);
  $13 = (($$02$i) + -36|0);
  __THREW__ = 0;
  invoke_vii(3423,($12|0),($13|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   break;
  }
  $49 = HEAP32[$5>>2]|0;
  $50 = (($49) + -148|0);
  HEAP32[$5>>2] = $50;
  $51 = ($9|0)==($2|0);
  if ($51) {
   label = 17;
   break;
  } else {
   $$02$i = $9;$8 = $50;
  }
 }
 if ((label|0) == 17) {
  $$pre = HEAP32[$this>>2]|0;
  $52 = $50;$53 = $$pre;
  HEAP32[$this>>2] = $52;
  HEAP32[$5>>2] = $53;
  $54 = (($__v) + 8|0);
  $55 = HEAP32[$3>>2]|0;
  $56 = HEAP32[$54>>2]|0;
  HEAP32[$3>>2] = $56;
  HEAP32[$54>>2] = $55;
  $57 = (($this) + 8|0);
  $58 = (($__v) + 12|0);
  $59 = HEAP32[$57>>2]|0;
  $60 = HEAP32[$58>>2]|0;
  HEAP32[$57>>2] = $60;
  HEAP32[$58>>2] = $59;
  $61 = HEAP32[$5>>2]|0;
  HEAP32[$__v>>2] = $61;
  STACKTOP = sp;return;
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 $18 = (($8) + -44|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(-1);
 do {
  if ($20) {
   $21 = (($8) + -56|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($8) + -52|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$1>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($22|0),($$byval_copy9|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    HEAP32[$21>>2] = 0;
    break;
   }
   $35 = ___cxa_find_matching_catch(0|0)|0;
   $36 = tempRet0;
   $37 = (($8) + -60|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)>(-1);
   if (!($39)) {
    $eh$lpad$body$i$i$i$i$indexZ2D = $35;
    ___clang_call_terminate($eh$lpad$body$i$i$i$i$indexZ2D);
    // unreachable;
   }
   $40 = HEAP32[$10>>2]|0;
   $41 = (($8) + -68|0);
   $42 = HEAP32[$41>>2]|0;
   HEAP32[$0>>2] = $42;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($40|0),($$byval_copy9|0));
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if ($44) {
    $45 = ___cxa_find_matching_catch(0|0)|0;
    $46 = tempRet0;
    ___clang_call_terminate($45);
    // unreachable;
   }
   HEAP32[$10>>2] = 0;
   $eh$lpad$body$i$i$i$i$indexZ2D = $35;
   ___clang_call_terminate($eh$lpad$body$i$i$i$i$indexZ2D);
   // unreachable;
  }
 } while(0);
 $27 = (($8) + -60|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)>(-1);
 if (!($29)) {
  ___resumeException($16|0);
  // unreachable;
 }
 $30 = HEAP32[$10>>2]|0;
 $31 = (($8) + -68|0);
 $32 = HEAP32[$31>>2]|0;
 HEAP32[$0>>2] = $32;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($30|0),($$byval_copy9|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $47 = ___cxa_find_matching_catch(0|0)|0;
  $48 = tempRet0;
  $eh$lpad$body$i$i$i$i$indexZ2D = $47;
  ___clang_call_terminate($eh$lpad$body$i$i$i$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$10>>2] = 0;
  ___resumeException($16|0);
  // unreachable;
 }
}
function __ZN21MaterialPropertyBlockC2ERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $$byval_copy2 = 0, $$idx$i$i = 0, $$idx$i$i1 = 0, $$pre$i = 0, $$pre$i2 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, $phitmp$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 $3 = (($0) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 12|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$this>>2] = 0;
 $8 = HEAP32[$0>>2]|0;
 $9 = (($0) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $$idx$i$i = $10 << 4;
 $11 = $$idx$i$i >> 4;
 HEAP32[$6>>2] = $11;
 $12 = ($11|0)==(0);
 if ($12) {
  $14 = 0;$15 = 0;
 } else {
  HEAP32[$7>>2] = $11;
  HEAP32[$1>>2] = $4;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $13 = (__Z16realloc_internalPvji10MemLabelIdiPKci(0,$$idx$i$i,4,$$byval_copy2,0,803264,370)|0);
  HEAP32[$this>>2] = $13;
  $$pre$i = HEAP32[$6>>2]|0;
  $phitmp$i = $$pre$i << 4;
  $14 = $13;$15 = $phitmp$i;
 }
 _memcpy(($14|0),($8|0),($15|0))|0;
 $16 = (($0) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 20|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 24|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 28|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 16|0);
 HEAP32[$21>>2] = 0;
 $22 = (($0) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($0) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $$idx$i$i1 = $25 << 2;
 $26 = $$idx$i$i1 >> 2;
 HEAP32[$19>>2] = $26;
 $27 = ($26|0)==(0);
 if ($27) {
  $31 = 0;$32 = 0;
  _memcpy(($31|0),($23|0),($32|0))|0;
  $33 = (($this) + 32|0);
  $34 = (($0) + 32|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$33>>2] = $35;
  STACKTOP = sp;return;
 }
 HEAP32[$20>>2] = $26;
 HEAP32[$2>>2] = $17;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 $28 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i1|0),4,($$byval_copy2|0),0,(803264|0),370)|0);
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if (!($30)) {
  HEAP32[$21>>2] = $28;
  $$pre$i2 = HEAP32[$19>>2]|0;
  $phitmp$i3 = $$pre$i2 << 2;
  $31 = $28;$32 = $phitmp$i3;
  _memcpy(($31|0),($23|0),($32|0))|0;
  $33 = (($this) + 32|0);
  $34 = (($0) + 32|0);
  $35 = HEAP32[$34>>2]|0;
  HEAP32[$33>>2] = $35;
  STACKTOP = sp;return;
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = HEAP32[$7>>2]|0;
 $39 = ($38|0)>(-1);
 if (!($39)) {
  ___resumeException($36|0);
  // unreachable;
 }
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $41;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($40|0),($$byval_copy2|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch(0|0)|0;
  $45 = tempRet0;
  ___clang_call_terminate($44);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($36|0);
 // unreachable;
}
function __ZNSt3__16vectorINS_4pairIiN12TreeRenderer15RendererLODInfoEEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE6insertENS_11__wrap_iterIPKS4_EERSA_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i14 = 0, $$0$i15 = 0, $$012$i$i$i12 = 0, $$03$i$i$i11 = 0, $$byval_copy4 = 0, $$pre = 0, $$pre$i10 = 0, $$sum = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = HEAP32[$__position>>2]|0;
 $4 = $3;
 $5 = $2;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 72)&-1;
 $8 = (($2) + (($7*72)|0)|0);
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = ($8|0)==($10|0);
  if ($14) {
   $15 = ($8|0)==(0|0);
   if ($15) {
    $17 = 0;
   } else {
    dest=$8+0|0; src=$__x+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre = HEAP32[$9>>2]|0;
    $17 = $$pre;
   }
   $16 = (($17) + 72|0);
   HEAP32[$9>>2] = $16;
   $__p$0 = $8;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($7) + 1)|0;
  $18 = (($2) + (($$sum*72)|0)|0);
  $19 = $10;
  $20 = $18;
  $21 = (($19) - ($20))|0;
  $22 = (($21|0) / 72)&-1;
  $$sum18 = (($22) + ($7))|0;
  $23 = (($2) + (($$sum18*72)|0)|0);
  $24 = ($23>>>0)<($10>>>0);
  if ($24) {
   $26 = $10;$__i$01$i = $23;
   while(1) {
    $25 = ($26|0)==(0|0);
    if ($25) {
     $29 = 0;
    } else {
     dest=$26+0|0; src=$__i$01$i+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $$pre$i10 = HEAP32[$9>>2]|0;
     $29 = $$pre$i10;
    }
    $27 = (($__i$01$i) + 72|0);
    $28 = (($29) + 72|0);
    HEAP32[$9>>2] = $28;
    $30 = ($27>>>0)<($10>>>0);
    if ($30) {
     $26 = $28;$__i$01$i = $27;
    } else {
     break;
    }
   }
  }
  $31 = ($10|0)==($18|0);
  if (!($31)) {
   $$012$i$i$i12 = $23;$$03$i$i$i11 = $10;
   while(1) {
    $32 = (($$03$i$i$i11) + -72|0);
    $33 = (($$012$i$i$i12) + -72|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$32>>2] = $34;
    $35 = (($$03$i$i$i11) + -68|0);
    $36 = (($$012$i$i$i12) + -68|0);
    dest=$35+0|0; src=$36+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $37 = ($33|0)==($8|0);
    if ($37) {
     break;
    } else {
     $$012$i$i$i12 = $33;$$03$i$i$i11 = $32;
    }
   }
  }
  $38 = ($8>>>0)>($__x>>>0);
  if ($38) {
   $__xr$0 = $__x;
  } else {
   $39 = HEAP32[$9>>2]|0;
   $40 = ($39>>>0)>($__x>>>0);
   $41 = (($__x) + 72|0);
   $$ = $40 ? $41 : $__x;
   $__xr$0 = $$;
  }
  $42 = HEAP32[$__xr$0>>2]|0;
  HEAP32[$8>>2] = $42;
  $43 = ((($2) + (($7*72)|0)|0) + 4|0);
  $44 = (($__xr$0) + 4|0);
  dest=$43+0|0; src=$44+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $__p$0 = $8;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $45 = $10;
 $46 = (($45) - ($5))|0;
 $47 = (($46|0) / 72)&-1;
 $48 = (($47) + 1)|0;
 $49 = ($48|0)<(0);
 if ($49) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $50 = $12;
 $51 = (($50) - ($5))|0;
 $52 = (($51|0) / 72)&-1;
 $53 = ($52>>>0)<(1073741823);
 if ($53) {
  $56 = $52 << 1;
  $57 = ($56>>>0)<($48>>>0);
  $58 = $57 ? $48 : $56;
  $59 = $8;
  $60 = (($6|0) / 72)&-1;
  $61 = ($58|0)==(0);
  if ($61) {
   $$0$i15 = 0;$65 = 0;$66 = $60;$96 = $59;
  } else {
   $$0$i14 = $58;$118 = $60;$119 = $59;
   label = 20;
  }
 } else {
  $54 = $8;
  $55 = (($6|0) / 72)&-1;
  $$0$i14 = 2147483647;$118 = $55;$119 = $54;
  label = 20;
 }
 if ((label|0) == 20) {
  $62 = ($$0$i14*72)|0;
  HEAP32[$0>>2] = 55;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $63 = (__Z15malloc_internaljj10MemLabelIdiPKci($62,16,$$byval_copy4,0,803264,79)|0);
  $$0$i15 = $$0$i14;$65 = $63;$66 = $118;$96 = $119;
 }
 $64 = (($65) + (($66*72)|0)|0);
 $67 = (($65) + (($$0$i15*72)|0)|0);
 $68 = ($66|0)==($$0$i15|0);
 do {
  if ($68) {
   $69 = ($66|0)>(0);
   $70 = (($6|0) / 72)&-1;
   if ($69) {
    $71 = (($70) + 1)|0;
    $72 = (($71|0) / -2)&-1;
    $$sum17 = (($72) + ($66))|0;
    $73 = (($65) + (($$sum17*72)|0)|0);
    $105 = $67;$90 = $73;
    break;
   }
   $74 = $70 << 1;
   $75 = ($74|0)==(0);
   $76 = $75 ? 1 : $74;
   $77 = ($76*72)|0;
   HEAP32[$0>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   $78 = (invoke_iiiiiii(102,($77|0),16,($$byval_copy4|0),0,(803264|0),79)|0);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if (!($80)) {
    $81 = $76 >>> 2;
    $82 = (($78) + (($81*72)|0)|0);
    $83 = (($78) + (($76*72)|0)|0);
    $84 = ($65|0)==(0|0);
    if ($84) {
     $105 = $83;$90 = $82;
     break;
    }
    HEAP32[$0>>2] = 55;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($65|0),($$byval_copy4|0));
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if (!($86)) {
     $105 = $83;$90 = $82;
     break;
    }
    $87 = ___cxa_find_matching_catch()|0;
    $88 = tempRet0;
    ___cxa_call_unexpected(($87|0));
    // unreachable;
   }
   $111 = ___cxa_find_matching_catch()|0;
   $112 = tempRet0;
   $113 = ($65|0)==(0|0);
   if ($113) {
    ___resumeException($111|0);
    // unreachable;
   }
   HEAP32[$1>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($65|0),($$byval_copy4|0));
   $114 = __THREW__; __THREW__ = 0;
   $115 = $114&1;
   if ($115) {
    $116 = ___cxa_find_matching_catch()|0;
    $117 = tempRet0;
    ___cxa_call_unexpected(($116|0));
    // unreachable;
   } else {
    ___resumeException($111|0);
    // unreachable;
   }
  } else {
   $105 = $67;$90 = $64;
  }
 } while(0);
 $89 = ($90|0)==(0|0);
 if ($89) {
  $92 = 0;
 } else {
  dest=$90+0|0; src=$__x+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $92 = $90;
 }
 $91 = (($92) + 72|0);
 $93 = HEAP32[$this>>2]|0;
 $94 = $93;
 $95 = (($96) - ($94))|0;
 $97 = (($95|0) / -72)&-1;
 $98 = (($90) + (($97*72)|0)|0);
 _memcpy(($98|0),($93|0),($95|0))|0;
 $99 = HEAP32[$9>>2]|0;
 $100 = $99;
 $101 = (($100) - ($96))|0;
 $102 = (($101|0) / 72)&-1;
 _memcpy(($91|0),($8|0),($101|0))|0;
 $$sum16 = (($102) + 1)|0;
 $103 = (($92) + (($$sum16*72)|0)|0);
 $104 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $98;
 HEAP32[$9>>2] = $103;
 HEAP32[$11>>2] = $105;
 $106 = ($104|0)==(0|0);
 if ($106) {
  $__p$0 = $90;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 HEAP32[$1>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($104|0),($$byval_copy4|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch()|0;
  $110 = tempRet0;
  ___cxa_call_unexpected(($109|0));
  // unreachable;
 } else {
  $__p$0 = $90;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN12TreeRenderer13PrototypeInfoE13stl_allocatorIS2_L18MemLabelIdentifier55ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i128 = 0, $$0$i129 = 0, $$0$i17 = 0, $$01$i$i = 0, $$byval_copy4 = 0, $$pre = 0, $$pre$i21 = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = 0, $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0;
 var $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i5 = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i9 = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 28)&-1;
 $10 = ($9>>>0)<($__n>>>0);
 if (!($10)) {
  $$0$i = $__n;$12 = $5;
  while(1) {
   $11 = ($12|0)==(0|0);
   if ($11) {
    $15 = 0;
   } else {
    $13 = (($12) + 4|0);
    ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;HEAP32[$13+16>>2]=0|0;HEAP8[$13+20>>0]=0|0;
    $$pre1$i = HEAP32[$4>>2]|0;
    $15 = $$pre1$i;
   }
   $14 = (($15) + 28|0);
   HEAP32[$4>>2] = $14;
   $16 = (($$0$i) + -1)|0;
   $17 = ($16|0)==(0);
   if ($17) {
    break;
   } else {
    $$0$i = $16;$12 = $14;
   }
  }
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$this>>2]|0;
 $19 = $18;
 $20 = (($7) - ($19))|0;
 $21 = (($20|0) / 28)&-1;
 $22 = (($21) + ($__n))|0;
 $23 = ($22|0)<(0);
 if ($23) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $24 = (($6) - ($19))|0;
 $25 = (($24|0) / 28)&-1;
 $26 = ($25>>>0)<(1073741823);
 if ($26) {
  $27 = $25 << 1;
  $28 = ($27>>>0)<($22>>>0);
  $29 = $28 ? $22 : $27;
  $30 = ($29|0)==(0);
  if ($30) {
   $$0$i129 = 0;$34 = 0;
  } else {
   $$0$i128 = $29;
   label = 9;
  }
 } else {
  $$0$i128 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $31 = ($$0$i128*28)|0;
  HEAP32[$0>>2] = 55;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $32 = (__Z15malloc_internaljj10MemLabelIdiPKci($31,16,$$byval_copy4,0,803264,79)|0);
  $$0$i129 = $$0$i128;$34 = $32;
 }
 $33 = (($34) + (($21*28)|0)|0);
 $$0$i17 = $__n;$36 = $33;
 while(1) {
  $35 = ($36|0)==(0|0);
  if ($35) {
   $39 = 0;
  } else {
   $37 = (($36) + 4|0);
   ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP32[$37+16>>2]=0|0;HEAP8[$37+20>>0]=0|0;
   $39 = $36;
  }
  $38 = (($39) + 28|0);
  $40 = (($$0$i17) + -1)|0;
  $41 = ($40|0)==(0);
  if ($41) {
   break;
  } else {
   $$0$i17 = $40;$36 = $38;
  }
 }
 $42 = (($34) + (($$0$i129*28)|0)|0);
 $43 = HEAP32[$this>>2]|0;
 $44 = HEAP32[$4>>2]|0;
 $45 = ($44|0)==($43|0);
 L23: do {
  if ($45) {
   HEAP32[$this>>2] = $33;
   HEAP32[$4>>2] = $38;
   HEAP32[$2>>2] = $42;
   $79 = $43;
  } else {
   $$01$i$i = $44;$48 = $33;
   while(1) {
    $46 = (($$01$i$i) + -28|0);
    $47 = (($48) + -28|0);
    $49 = HEAP8[$46>>0]|0;
    HEAP8[$47>>0] = $49;
    $50 = (($48) + -24|0);
    $51 = (($$01$i$i) + -24|0);
    __THREW__ = 0;
    invoke_vii(3430,($50|0),($51|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    $54 = (($$01$i$i) + -12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($48) + -12|0);
    HEAP32[$56>>2] = $55;
    $57 = (($48) + -8|0);
    $58 = (($$01$i$i) + -8|0);
    ;HEAP32[$57+0>>2]=HEAP32[$58+0>>2]|0;HEAP8[$57+4>>0]=HEAP8[$58+4>>0]|0;
    $59 = (($48) + -28|0);
    $60 = ($46|0)==($43|0);
    if ($60) {
     label = 18;
     break;
    } else {
     $$01$i$i = $46;$48 = $59;
    }
   }
   if ((label|0) == 18) {
    $$pre$i21 = HEAP32[$this>>2]|0;
    $$pre = HEAP32[$4>>2]|0;
    HEAP32[$this>>2] = $59;
    HEAP32[$4>>2] = $38;
    HEAP32[$2>>2] = $42;
    $61 = ($$pre|0)==($$pre$i21|0);
    if ($61) {
     $79 = $$pre$i21;
     break;
    }
    $63 = $$pre;
    while(1) {
     $62 = (($63) + -28|0);
     $64 = (($63) + -24|0);
     $65 = HEAP32[$64>>2]|0;
     $66 = ($65|0)==(0|0);
     if (!($66)) {
      $68 = (($63) + -20|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($69|0)==($65|0);
      if (!($70)) {
       $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4 = $65;
       $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i5 = (($69) + -72|0);
       $71 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i4))|0;
       $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7 = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i5) + ($71)|0);
       $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8 = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i7;
       $72 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i8>>>0) / 72)&-1;
       $73 = $72 ^ -1;
       $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i9 = (($69) + (($73*72)|0)|0);
       HEAP32[$68>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i9;
      }
      HEAP32[$1>>2] = 55;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($65|0),($$byval_copy4|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       break;
      }
     }
     $67 = ($62|0)==($$pre$i21|0);
     if ($67) {
      $79 = $$pre$i21;
      break L23;
     } else {
      $63 = $62;
     }
    }
    $76 = ___cxa_find_matching_catch()|0;
    $77 = tempRet0;
    ___cxa_call_unexpected(($76|0));
    // unreachable;
   }
   $84 = ___cxa_find_matching_catch()|0;
   $85 = tempRet0;
   $86 = ($38|0)==($48|0);
   L40: do {
    if (!($86)) {
     $88 = $38;
     while(1) {
      $87 = (($88) + -28|0);
      $89 = (($88) + -24|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = ($90|0)==(0|0);
      if (!($91)) {
       $93 = (($88) + -20|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = ($94|0)==($90|0);
       if (!($95)) {
        $__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $90;
        $scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($94) + -72|0);
        $96 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i))|0;
        $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i) + ($96)|0);
        $uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
        $97 = (($uglygep3$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i>>>0) / 72)&-1;
        $98 = $97 ^ -1;
        $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i = (($94) + (($98*72)|0)|0);
        HEAP32[$93>>2] = $scevgep4$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i$i;
       }
       HEAP32[$1>>2] = 55;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($90|0),($$byval_copy4|0));
       $99 = __THREW__; __THREW__ = 0;
       $100 = $99&1;
       if ($100) {
        break;
       }
      }
      $92 = ($87|0)==($48|0);
      if ($92) {
       break L40;
      } else {
       $88 = $87;
      }
     }
     $101 = ___cxa_find_matching_catch()|0;
     $102 = tempRet0;
     ___cxa_call_unexpected(($101|0));
     // unreachable;
    }
   } while(0);
   $103 = ($34|0)==(0|0);
   if ($103) {
    ___resumeException($84|0);
    // unreachable;
   }
   HEAP32[$0>>2] = 55;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($34|0),($$byval_copy4|0));
   $104 = __THREW__; __THREW__ = 0;
   $105 = $104&1;
   if ($105) {
    $106 = ___cxa_find_matching_catch()|0;
    $107 = tempRet0;
    ___cxa_call_unexpected(($106|0));
    // unreachable;
   } else {
    ___resumeException($84|0);
    // unreachable;
   }
  }
 } while(0);
 $78 = ($79|0)==(0|0);
 if ($78) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($79|0),($$byval_copy4|0));
 $80 = __THREW__; __THREW__ = 0;
 $81 = $80&1;
 if ($81) {
  $82 = ___cxa_find_matching_catch()|0;
  $83 = tempRet0;
  ___cxa_call_unexpected(($82|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorINS_4pairIiN12TreeRenderer15RendererLODInfoEEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEEC2ERKS8_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$01$i = 0, $$byval_copy1 = 0, $$pre2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($__x) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$__x>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 72)&-1;
 $11 = ($5|0)==($6|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($9|0)<(0);
 if ($12) {
  __THREW__ = 0;
  invoke_vi(3308,0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   // unreachable;
  }
 } else {
  HEAP32[$0>>2] = 55;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $15 = (invoke_iiiiiii(102,($9|0),16,($$byval_copy1|0),0,(803264|0),79)|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   HEAP32[$2>>2] = $15;
   HEAP32[$this>>2] = $15;
   $18 = (($15) + (($10*72)|0)|0);
   HEAP32[$3>>2] = $18;
   $19 = HEAP32[$__x>>2]|0;
   $20 = HEAP32[$4>>2]|0;
   $21 = ($19|0)==($20|0);
   if ($21) {
    STACKTOP = sp;return;
   } else {
    $$01$i = $19;$23 = $15;
   }
   while(1) {
    $22 = ($23|0)==(0|0);
    if ($22) {
     $25 = 0;
    } else {
     dest=$23+0|0; src=$$01$i+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $$pre2$i = HEAP32[$2>>2]|0;
     $25 = $$pre2$i;
    }
    $24 = (($25) + 72|0);
    HEAP32[$2>>2] = $24;
    $26 = (($$01$i) + 72|0);
    $27 = ($26|0)==($20|0);
    if ($27) {
     break;
    } else {
     $$01$i = $26;$23 = $24;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 $30 = HEAP32[$this>>2]|0;
 $31 = ($30|0)==(0|0);
 if ($31) {
  ___resumeException($28|0);
  // unreachable;
 }
 $32 = HEAP32[$2>>2]|0;
 $33 = ($32|0)==($30|0);
 if (!($33)) {
  $__new_last2$i$i$i = $30;
  $scevgep$i$i$i = (($32) + -72|0);
  $34 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($34)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $35 = (($uglygep3$i$i$i>>>0) / 72)&-1;
  $36 = $35 ^ -1;
  $scevgep4$i$i$i = (($32) + (($36*72)|0)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i;
 }
 HEAP32[$1>>2] = 55;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($30|0),($$byval_copy1|0));
 $37 = __THREW__; __THREW__ = 0;
 $38 = $37&1;
 if ($38) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  ___cxa_call_unexpected(($39|0));
  // unreachable;
 } else {
  ___resumeException($28|0);
  // unreachable;
 }
}
function __ZNSt3__16__sortIR23TreeInstanceIndexSorterPjEEvT0_S4_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$pre$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = Math_fround(0), $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = 0, $163 = Math_fround(0), $164 = 0;
 var $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0);
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0);
 var $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = Math_fround(0), $216 = 0, $217 = 0, $218 = Math_fround(0);
 var $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = Math_fround(0), $234 = 0, $235 = Math_fround(0), $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0);
 var $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$011 = 0, $__i$02$i = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0;
 var $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__k$0$i = 0, $__k$0$lcssa$i = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0;
 var $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 2;
   switch ($4|0) {
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 83;
    break L1;
    break;
   }
   default: {
   }
   }
   $68 = ($3|0)<(124);
   if ($68) {
    label = 21;
    break L1;
   }
   $104 = ($3|0)>(3996);
   $105 = (($4|0) / 2)&-1;
   $106 = (($$0) + ($105<<2)|0);
   do {
    if ($104) {
     $107 = (($4|0) / 4)&-1;
     $108 = (($$0) + ($107<<2)|0);
     $$sum = (($107) + ($105))|0;
     $109 = (($$0) + ($$sum<<2)|0);
     $110 = (__ZNSt3__17__sort4IR23TreeInstanceIndexSorterPjEEjT0_S4_S4_S4_T_($$0,$108,$106,$109,$__comp)|0);
     $111 = HEAP32[$1>>2]|0;
     $112 = HEAP32[$109>>2]|0;
     $113 = HEAP32[$__comp>>2]|0;
     $114 = HEAP32[$113>>2]|0;
     $115 = ((($114) + (($111*40)|0)|0) + 36|0);
     $116 = Math_fround(HEAPF32[$115>>2]);
     $117 = ((($114) + (($112*40)|0)|0) + 36|0);
     $118 = Math_fround(HEAPF32[$117>>2]);
     $119 = $116 > $118;
     if ($119) {
      HEAP32[$109>>2] = $111;
      HEAP32[$1>>2] = $112;
      $120 = HEAP32[$109>>2]|0;
      $121 = HEAP32[$106>>2]|0;
      $122 = ((($114) + (($120*40)|0)|0) + 36|0);
      $123 = Math_fround(HEAPF32[$122>>2]);
      $124 = ((($114) + (($121*40)|0)|0) + 36|0);
      $125 = Math_fround(HEAPF32[$124>>2]);
      $126 = $123 > $125;
      if (!($126)) {
       $127 = (($110) + 1)|0;
       $172 = $114;$__n_swaps$0 = $127;
       break;
      }
      HEAP32[$106>>2] = $120;
      HEAP32[$109>>2] = $121;
      $128 = HEAP32[$106>>2]|0;
      $129 = HEAP32[$108>>2]|0;
      $130 = ((($114) + (($128*40)|0)|0) + 36|0);
      $131 = Math_fround(HEAPF32[$130>>2]);
      $132 = ((($114) + (($129*40)|0)|0) + 36|0);
      $133 = Math_fround(HEAPF32[$132>>2]);
      $134 = $131 > $133;
      if (!($134)) {
       $135 = (($110) + 2)|0;
       $172 = $114;$__n_swaps$0 = $135;
       break;
      }
      HEAP32[$108>>2] = $128;
      HEAP32[$106>>2] = $129;
      $136 = (($110) + 3)|0;
      $137 = HEAP32[$108>>2]|0;
      $138 = HEAP32[$$0>>2]|0;
      $139 = ((($114) + (($137*40)|0)|0) + 36|0);
      $140 = Math_fround(HEAPF32[$139>>2]);
      $141 = ((($114) + (($138*40)|0)|0) + 36|0);
      $142 = Math_fround(HEAPF32[$141>>2]);
      $143 = $140 > $142;
      if ($143) {
       HEAP32[$$0>>2] = $137;
       HEAP32[$108>>2] = $138;
       $144 = (($110) + 4)|0;
       $172 = $114;$__n_swaps$0 = $144;
      } else {
       $172 = $114;$__n_swaps$0 = $136;
      }
     } else {
      $172 = $114;$__n_swaps$0 = $110;
     }
    } else {
     $145 = HEAP32[$106>>2]|0;
     $146 = HEAP32[$$0>>2]|0;
     $147 = HEAP32[$__comp>>2]|0;
     $148 = HEAP32[$147>>2]|0;
     $149 = ((($148) + (($145*40)|0)|0) + 36|0);
     $150 = Math_fround(HEAPF32[$149>>2]);
     $151 = ((($148) + (($146*40)|0)|0) + 36|0);
     $152 = Math_fround(HEAPF32[$151>>2]);
     $153 = $150 > $152;
     $154 = HEAP32[$1>>2]|0;
     $155 = ((($148) + (($154*40)|0)|0) + 36|0);
     $156 = Math_fround(HEAPF32[$155>>2]);
     $157 = $156 > $150;
     if (!($153)) {
      if (!($157)) {
       $172 = $148;$__n_swaps$0 = 0;
       break;
      }
      HEAP32[$106>>2] = $154;
      HEAP32[$1>>2] = $145;
      $158 = HEAP32[$106>>2]|0;
      $159 = HEAP32[$$0>>2]|0;
      $160 = ((($148) + (($158*40)|0)|0) + 36|0);
      $161 = Math_fround(HEAPF32[$160>>2]);
      $162 = ((($148) + (($159*40)|0)|0) + 36|0);
      $163 = Math_fround(HEAPF32[$162>>2]);
      $164 = $161 > $163;
      if (!($164)) {
       $172 = $148;$__n_swaps$0 = 1;
       break;
      }
      HEAP32[$$0>>2] = $158;
      HEAP32[$106>>2] = $159;
      $172 = $148;$__n_swaps$0 = 2;
      break;
     }
     if ($157) {
      HEAP32[$$0>>2] = $154;
      HEAP32[$1>>2] = $146;
      $172 = $148;$__n_swaps$0 = 1;
      break;
     }
     HEAP32[$$0>>2] = $145;
     HEAP32[$106>>2] = $146;
     $165 = HEAP32[$1>>2]|0;
     $166 = ((($148) + (($165*40)|0)|0) + 36|0);
     $167 = Math_fround(HEAPF32[$166>>2]);
     $168 = $167 > $152;
     if ($168) {
      HEAP32[$106>>2] = $165;
      HEAP32[$1>>2] = $146;
      $172 = $148;$__n_swaps$0 = 2;
     } else {
      $172 = $148;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $169 = HEAP32[$$0>>2]|0;
   $170 = HEAP32[$106>>2]|0;
   $171 = ((($172) + (($169*40)|0)|0) + 36|0);
   $173 = Math_fround(HEAPF32[$171>>2]);
   $174 = ((($172) + (($170*40)|0)|0) + 36|0);
   $175 = Math_fround(HEAPF32[$174>>2]);
   $176 = $173 > $175;
   do {
    if ($176) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $177 = (($__j$0) + -4|0);
      $178 = ($$0|0)==($177|0);
      if ($178) {
       break;
      }
      $206 = HEAP32[$177>>2]|0;
      $207 = ((($172) + (($206*40)|0)|0) + 36|0);
      $208 = Math_fround(HEAPF32[$207>>2]);
      $209 = $208 > $175;
      if ($209) {
       label = 66;
       break;
      } else {
       $__j$0 = $177;
      }
     }
     if ((label|0) == 66) {
      label = 0;
      HEAP32[$$0>>2] = $206;
      HEAP32[$177>>2] = $169;
      $210 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $177;$__n_swaps$3 = $210;
      break;
     }
     $179 = (($$0) + 4|0);
     $180 = HEAP32[$1>>2]|0;
     $181 = ((($172) + (($180*40)|0)|0) + 36|0);
     $182 = Math_fround(HEAPF32[$181>>2]);
     $183 = $173 > $182;
     if ($183) {
      $__i$1 = $179;
     } else {
      $184 = ($179|0)==($1|0);
      if ($184) {
       label = 83;
       break L1;
      } else {
       $__i$011 = $179;
      }
      while(1) {
       $187 = HEAP32[$__i$011>>2]|0;
       $188 = ((($172) + (($187*40)|0)|0) + 36|0);
       $189 = Math_fround(HEAPF32[$188>>2]);
       $190 = $173 > $189;
       $186 = (($__i$011) + 4|0);
       if ($190) {
        break;
       }
       $185 = ($186|0)==($1|0);
       if ($185) {
        label = 83;
        break L1;
       } else {
        $__i$011 = $186;
       }
      }
      HEAP32[$__i$011>>2] = $180;
      HEAP32[$1>>2] = $187;
      $__i$1 = $186;
     }
     $191 = ($__i$1|0)==($1|0);
     if ($191) {
      label = 83;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $192 = HEAP32[$$0>>2]|0;
      $193 = ((($172) + (($192*40)|0)|0) + 36|0);
      $194 = Math_fround(HEAPF32[$193>>2]);
      $__i$2 = $__i$2$ph;
      while(1) {
       $195 = HEAP32[$__i$2>>2]|0;
       $196 = ((($172) + (($195*40)|0)|0) + 36|0);
       $197 = Math_fround(HEAPF32[$196>>2]);
       $198 = $194 > $197;
       $199 = (($__i$2) + 4|0);
       if ($198) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $199;
       }
      }
      while(1) {
       $200 = (($__j$2) + -4|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ((($172) + (($201*40)|0)|0) + 36|0);
       $203 = Math_fround(HEAPF32[$202>>2]);
       $204 = $194 > $203;
       if ($204) {
        $__j$2 = $200;
       } else {
        break;
       }
      }
      $205 = ($__i$2>>>0)<($200>>>0);
      if (!($205)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__i$2>>2] = $201;
      HEAP32[$200>>2] = $195;
      $__i$2$ph = $199;$__j$1$ph = $200;
     }
    }
   } while(0);
   $211 = (($$0) + 4|0);
   $212 = ($211>>>0)<($__j$3>>>0);
   L51: do {
    if ($212) {
     $__i$3$ph = $211;$__j$4$ph = $__j$3;$__m$0$ph = $106;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $213 = HEAP32[$__m$0$ph>>2]|0;
      $214 = ((($172) + (($213*40)|0)|0) + 36|0);
      $215 = Math_fround(HEAPF32[$214>>2]);
      $__i$3 = $__i$3$ph;
      while(1) {
       $216 = HEAP32[$__i$3>>2]|0;
       $217 = ((($172) + (($216*40)|0)|0) + 36|0);
       $218 = Math_fround(HEAPF32[$217>>2]);
       $219 = $218 > $215;
       $220 = (($__i$3) + 4|0);
       if ($219) {
        $__i$3 = $220;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $221 = (($__j$5) + -4|0);
       $222 = HEAP32[$221>>2]|0;
       $223 = ((($172) + (($222*40)|0)|0) + 36|0);
       $224 = Math_fround(HEAPF32[$223>>2]);
       $225 = $224 > $215;
       if ($225) {
        break;
       } else {
        $__j$5 = $221;
       }
      }
      $226 = ($__i$3>>>0)>($221>>>0);
      if ($226) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L51;
      }
      HEAP32[$__i$3>>2] = $222;
      HEAP32[$221>>2] = $216;
      $227 = (($__n_swaps$4$ph) + 1)|0;
      $228 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $228 ? $221 : $__m$0$ph;
      $__i$3$ph = $220;$__j$4$ph = $221;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $227;
     }
    } else {
     $__i$4 = $211;$__m$2 = $106;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $229 = ($__i$4|0)==($__m$2|0);
   if ($229) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $230 = HEAP32[$__m$2>>2]|0;
    $231 = HEAP32[$__i$4>>2]|0;
    $232 = ((($172) + (($230*40)|0)|0) + 36|0);
    $233 = Math_fround(HEAPF32[$232>>2]);
    $234 = ((($172) + (($231*40)|0)|0) + 36|0);
    $235 = Math_fround(HEAPF32[$234>>2]);
    $236 = $233 > $235;
    if ($236) {
     HEAP32[$__i$4>>2] = $230;
     HEAP32[$__m$2>>2] = $231;
     $237 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $237;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $238 = ($__n_swaps$6|0)==(0);
   if ($238) {
    $239 = (__ZNSt3__127__insertion_sort_incompleteIR23TreeInstanceIndexSorterPjEEbT0_S4_T_($$0,$__i$4,$__comp)|0);
    $240 = (($__i$4) + 4|0);
    $241 = (__ZNSt3__127__insertion_sort_incompleteIR23TreeInstanceIndexSorterPjEEbT0_S4_T_($240,$$01$ph,$__comp)|0);
    if ($241) {
     label = 78;
     break;
    }
    if ($239) {
     $$0 = $240;
     continue;
    }
   }
   $242 = $__i$4;
   $243 = (($242) - ($2))|0;
   $244 = (($0) - ($242))|0;
   $245 = ($243|0)<($244|0);
   if (!($245)) {
    label = 82;
    break;
   }
   __ZNSt3__16__sortIR23TreeInstanceIndexSorterPjEEvT0_S4_T_($$0,$__i$4,$__comp);
   $246 = (($__i$4) + 4|0);
   $$0 = $246;
  }
  if ((label|0) == 78) {
   label = 0;
   if ($239) {
    label = 83;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 82) {
   label = 0;
   $247 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIR23TreeInstanceIndexSorterPjEEvT0_S4_T_($247,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = HEAP32[$__comp>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8) + (($5*40)|0)|0) + 36|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = ((($8) + (($6*40)|0)|0) + 36|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = $10 > $12;
  if (!($13)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $5;
  HEAP32[$1>>2] = $6;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $14 = (($$0) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$$0>>2]|0;
  $17 = HEAP32[$__comp>>2]|0;
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($18) + (($15*40)|0)|0) + 36|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = ((($18) + (($16*40)|0)|0) + 36|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = $20 > $22;
  $24 = HEAP32[$1>>2]|0;
  $25 = ((($18) + (($24*40)|0)|0) + 36|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = $26 > $20;
  if (!($23)) {
   if (!($27)) {
    STACKTOP = sp;return;
   }
   HEAP32[$14>>2] = $24;
   HEAP32[$1>>2] = $15;
   $28 = HEAP32[$14>>2]|0;
   $29 = HEAP32[$$0>>2]|0;
   $30 = ((($18) + (($28*40)|0)|0) + 36|0);
   $31 = Math_fround(HEAPF32[$30>>2]);
   $32 = ((($18) + (($29*40)|0)|0) + 36|0);
   $33 = Math_fround(HEAPF32[$32>>2]);
   $34 = $31 > $33;
   if (!($34)) {
    STACKTOP = sp;return;
   }
   HEAP32[$$0>>2] = $28;
   HEAP32[$14>>2] = $29;
   STACKTOP = sp;return;
  }
  if ($27) {
   HEAP32[$$0>>2] = $24;
   HEAP32[$1>>2] = $16;
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $15;
  HEAP32[$14>>2] = $16;
  $35 = HEAP32[$1>>2]|0;
  $36 = ((($18) + (($35*40)|0)|0) + 36|0);
  $37 = Math_fround(HEAPF32[$36>>2]);
  $38 = $37 > $22;
  if (!($38)) {
   STACKTOP = sp;return;
  }
  HEAP32[$14>>2] = $35;
  HEAP32[$1>>2] = $16;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $39 = (($$0) + 4|0);
  $40 = (($$0) + 8|0);
  (__ZNSt3__17__sort4IR23TreeInstanceIndexSorterPjEEjT0_S4_S4_S4_T_($$0,$39,$40,$1,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $41 = (($$0) + 4|0);
  $42 = (($$0) + 8|0);
  $43 = (($$0) + 12|0);
  (__ZNSt3__17__sort4IR23TreeInstanceIndexSorterPjEEjT0_S4_S4_S4_T_($$0,$41,$42,$43,$__comp)|0);
  $44 = HEAP32[$1>>2]|0;
  $45 = HEAP32[$43>>2]|0;
  $46 = HEAP32[$__comp>>2]|0;
  $47 = HEAP32[$46>>2]|0;
  $48 = ((($47) + (($44*40)|0)|0) + 36|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = ((($47) + (($45*40)|0)|0) + 36|0);
  $51 = Math_fround(HEAPF32[$50>>2]);
  $52 = $49 > $51;
  if (!($52)) {
   STACKTOP = sp;return;
  }
  HEAP32[$43>>2] = $44;
  HEAP32[$1>>2] = $45;
  $53 = HEAP32[$43>>2]|0;
  $54 = HEAP32[$42>>2]|0;
  $55 = ((($47) + (($53*40)|0)|0) + 36|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = ((($47) + (($54*40)|0)|0) + 36|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = $56 > $58;
  if (!($59)) {
   STACKTOP = sp;return;
  }
  HEAP32[$42>>2] = $53;
  HEAP32[$43>>2] = $54;
  $60 = HEAP32[$41>>2]|0;
  $61 = ((($47) + (($60*40)|0)|0) + 36|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = $56 > $62;
  if (!($63)) {
   STACKTOP = sp;return;
  }
  HEAP32[$41>>2] = $53;
  HEAP32[$42>>2] = $60;
  $64 = HEAP32[$$0>>2]|0;
  $65 = ((($47) + (($64*40)|0)|0) + 36|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = $56 > $66;
  if (!($67)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $53;
  HEAP32[$41>>2] = $64;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $69 = (($$0) + 8|0);
  $70 = (($$0) + 4|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = HEAP32[$$0>>2]|0;
  $73 = HEAP32[$__comp>>2]|0;
  $74 = HEAP32[$73>>2]|0;
  $75 = ((($74) + (($71*40)|0)|0) + 36|0);
  $76 = Math_fround(HEAPF32[$75>>2]);
  $77 = ((($74) + (($72*40)|0)|0) + 36|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = $76 > $78;
  $80 = HEAP32[$69>>2]|0;
  $81 = ((($74) + (($80*40)|0)|0) + 36|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = $82 > $76;
  do {
   if ($79) {
    if ($83) {
     HEAP32[$$0>>2] = $80;
     HEAP32[$69>>2] = $72;
     $248 = $72;
     break;
    }
    HEAP32[$$0>>2] = $71;
    HEAP32[$70>>2] = $72;
    $85 = $82 > $78;
    if ($85) {
     HEAP32[$70>>2] = $80;
     HEAP32[$69>>2] = $72;
     $248 = $72;
    } else {
     $248 = $80;
    }
   } else {
    if ($83) {
     HEAP32[$70>>2] = $80;
     HEAP32[$69>>2] = $71;
     $84 = $82 > $78;
     if ($84) {
      HEAP32[$$0>>2] = $80;
      HEAP32[$70>>2] = $72;
      $248 = $71;
     } else {
      $248 = $71;
     }
    } else {
     $248 = $80;
    }
   }
  } while(0);
  $86 = (($$0) + 12|0);
  $87 = ($86|0)==($$01$ph|0);
  if ($87) {
   STACKTOP = sp;return;
  } else {
   $92 = $248;$__i$02$i = $86;$__j$01$i = $69;
  }
  while(1) {
   $88 = HEAP32[$__i$02$i>>2]|0;
   $89 = ((($74) + (($88*40)|0)|0) + 36|0);
   $90 = Math_fround(HEAPF32[$89>>2]);
   $91 = ((($74) + (($92*40)|0)|0) + 36|0);
   $93 = Math_fround(HEAPF32[$91>>2]);
   $94 = $90 > $93;
   if ($94) {
    $95 = $92;$__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     HEAP32[$__j$1$i>>2] = $95;
     $96 = ($__k$0$i|0)==($$0|0);
     if ($96) {
      $__k$0$lcssa$i = $$0;
      break;
     }
     $97 = (($__k$0$i) + -4|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = ((($74) + (($98*40)|0)|0) + 36|0);
     $100 = Math_fround(HEAPF32[$99>>2]);
     $101 = $90 > $100;
     if ($101) {
      $__j$1$i$phi = $__k$0$i;$95 = $98;$__k$0$i = $97;$__j$1$i = $__j$1$i$phi;
     } else {
      $__k$0$lcssa$i = $__k$0$i;
      break;
     }
    }
    HEAP32[$__k$0$lcssa$i>>2] = $88;
   }
   $102 = (($__i$02$i) + 4|0);
   $103 = ($102|0)==($$01$ph|0);
   if ($103) {
    break;
   }
   $$pre$i = HEAP32[$__i$02$i>>2]|0;
   $__j$01$i$phi = $__i$02$i;$92 = $$pre$i;$__i$02$i = $102;$__j$01$i = $__j$01$i$phi;
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 83) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IR23TreeInstanceIndexSorterPjEEjT0_S4_S4_S4_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__x2>>2]|0;
 $1 = HEAP32[$__x1>>2]|0;
 $2 = HEAP32[$__c>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + (($0*40)|0)|0) + 36|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = ((($3) + (($1*40)|0)|0) + 36|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = $5 > $7;
 $9 = HEAP32[$__x3>>2]|0;
 $10 = ((($3) + (($9*40)|0)|0) + 36|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = $11 > $5;
 do {
  if ($8) {
   if ($12) {
    HEAP32[$__x1>>2] = $9;
    HEAP32[$__x3>>2] = $1;
    $$0$i = 1;$28 = $1;
    break;
   }
   HEAP32[$__x1>>2] = $0;
   HEAP32[$__x2>>2] = $1;
   $20 = HEAP32[$__x3>>2]|0;
   $21 = ((($3) + (($20*40)|0)|0) + 36|0);
   $22 = Math_fround(HEAPF32[$21>>2]);
   $23 = $22 > $7;
   if ($23) {
    HEAP32[$__x2>>2] = $20;
    HEAP32[$__x3>>2] = $1;
    $$0$i = 2;$28 = $1;
   } else {
    $$0$i = 1;$28 = $20;
   }
  } else {
   if ($12) {
    HEAP32[$__x2>>2] = $9;
    HEAP32[$__x3>>2] = $0;
    $13 = HEAP32[$__x2>>2]|0;
    $14 = HEAP32[$__x1>>2]|0;
    $15 = ((($3) + (($13*40)|0)|0) + 36|0);
    $16 = Math_fround(HEAPF32[$15>>2]);
    $17 = ((($3) + (($14*40)|0)|0) + 36|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = $16 > $18;
    if ($19) {
     HEAP32[$__x1>>2] = $13;
     HEAP32[$__x2>>2] = $14;
     $$pre = HEAP32[$__x3>>2]|0;
     $$0$i = 2;$28 = $$pre;
    } else {
     $$0$i = 1;$28 = $0;
    }
   } else {
    $$0$i = 0;$28 = $9;
   }
  }
 } while(0);
 $24 = HEAP32[$__x4>>2]|0;
 $25 = ((($3) + (($24*40)|0)|0) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = ((($3) + (($28*40)|0)|0) + 36|0);
 $29 = Math_fround(HEAPF32[$27>>2]);
 $30 = $26 > $29;
 if (!($30)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $24;
 HEAP32[$__x4>>2] = $28;
 $31 = (($$0$i) + 1)|0;
 $32 = HEAP32[$__x3>>2]|0;
 $33 = HEAP32[$__x2>>2]|0;
 $34 = ((($3) + (($32*40)|0)|0) + 36|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = ((($3) + (($33*40)|0)|0) + 36|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = $35 > $37;
 if (!($38)) {
  $__r$0 = $31;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $32;
 HEAP32[$__x3>>2] = $33;
 $39 = (($$0$i) + 2)|0;
 $40 = HEAP32[$__x2>>2]|0;
 $41 = HEAP32[$__x1>>2]|0;
 $42 = ((($3) + (($40*40)|0)|0) + 36|0);
 $43 = Math_fround(HEAPF32[$42>>2]);
 $44 = ((($3) + (($41*40)|0)|0) + 36|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = $43 > $45;
 if (!($46)) {
  $__r$0 = $39;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $40;
 HEAP32[$__x2>>2] = $41;
 $47 = (($$0$i) + 3)|0;
 $__r$0 = $47;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIR23TreeInstanceIndexSorterPjEEbT0_S4_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0);
 var $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0);
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$05 = 0, $__count$1 = 0, $__i$06 = 0, $__j$04 = 0, $__j$04$phi = 0, $__j$1 = 0, $__j$1$phi = 0;
 var $__k$0 = 0, $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 2:  {
  $4 = (($__last) + -4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = HEAP32[$__comp>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($8) + (($5*40)|0)|0) + 36|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = ((($8) + (($6*40)|0)|0) + 36|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = $10 > $12;
  if (!($13)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $43 = (($__first) + 4|0);
  $44 = (($__first) + 8|0);
  $45 = (($__first) + 12|0);
  $46 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IR23TreeInstanceIndexSorterPjEEjT0_S4_S4_S4_T_($__first,$43,$44,$45,$__comp)|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = HEAP32[$45>>2]|0;
  $49 = HEAP32[$__comp>>2]|0;
  $50 = HEAP32[$49>>2]|0;
  $51 = ((($50) + (($47*40)|0)|0) + 36|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = ((($50) + (($48*40)|0)|0) + 36|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = $52 > $54;
  if (!($55)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$45>>2] = $47;
  HEAP32[$46>>2] = $48;
  $56 = HEAP32[$45>>2]|0;
  $57 = HEAP32[$44>>2]|0;
  $58 = ((($50) + (($56*40)|0)|0) + 36|0);
  $59 = Math_fround(HEAPF32[$58>>2]);
  $60 = ((($50) + (($57*40)|0)|0) + 36|0);
  $61 = Math_fround(HEAPF32[$60>>2]);
  $62 = $59 > $61;
  if (!($62)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$44>>2] = $56;
  HEAP32[$45>>2] = $57;
  $63 = HEAP32[$43>>2]|0;
  $64 = ((($50) + (($63*40)|0)|0) + 36|0);
  $65 = Math_fround(HEAPF32[$64>>2]);
  $66 = $59 > $65;
  if (!($66)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$43>>2] = $56;
  HEAP32[$44>>2] = $63;
  $67 = HEAP32[$__first>>2]|0;
  $68 = ((($50) + (($67*40)|0)|0) + 36|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = $59 > $69;
  if (!($70)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $56;
  HEAP32[$43>>2] = $67;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $14 = (($__first) + 4|0);
  $15 = (($__last) + -4|0);
  $16 = HEAP32[$14>>2]|0;
  $17 = HEAP32[$__first>>2]|0;
  $18 = HEAP32[$__comp>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($19) + (($16*40)|0)|0) + 36|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = ((($19) + (($17*40)|0)|0) + 36|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = $21 > $23;
  $25 = HEAP32[$15>>2]|0;
  $26 = ((($19) + (($25*40)|0)|0) + 36|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = $27 > $21;
  if (!($24)) {
   if (!($28)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$14>>2] = $25;
   HEAP32[$15>>2] = $16;
   $29 = HEAP32[$14>>2]|0;
   $30 = HEAP32[$__first>>2]|0;
   $31 = ((($19) + (($29*40)|0)|0) + 36|0);
   $32 = Math_fround(HEAPF32[$31>>2]);
   $33 = ((($19) + (($30*40)|0)|0) + 36|0);
   $34 = Math_fround(HEAPF32[$33>>2]);
   $35 = $32 > $34;
   if (!($35)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__first>>2] = $29;
   HEAP32[$14>>2] = $30;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($28) {
   HEAP32[$__first>>2] = $25;
   HEAP32[$15>>2] = $17;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $16;
  HEAP32[$14>>2] = $17;
  $36 = HEAP32[$15>>2]|0;
  $37 = ((($19) + (($36*40)|0)|0) + 36|0);
  $38 = Math_fround(HEAPF32[$37>>2]);
  $39 = $38 > $23;
  if (!($39)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$14>>2] = $36;
  HEAP32[$15>>2] = $17;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $40 = (($__first) + 4|0);
  $41 = (($__first) + 8|0);
  $42 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IR23TreeInstanceIndexSorterPjEEjT0_S4_S4_S4_T_($__first,$40,$41,$42,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $71 = (($__first) + 8|0);
  $72 = (($__first) + 4|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = HEAP32[$__first>>2]|0;
  $75 = HEAP32[$__comp>>2]|0;
  $76 = HEAP32[$75>>2]|0;
  $77 = ((($76) + (($73*40)|0)|0) + 36|0);
  $78 = Math_fround(HEAPF32[$77>>2]);
  $79 = ((($76) + (($74*40)|0)|0) + 36|0);
  $80 = Math_fround(HEAPF32[$79>>2]);
  $81 = $78 > $80;
  $82 = HEAP32[$71>>2]|0;
  $83 = ((($76) + (($82*40)|0)|0) + 36|0);
  $84 = Math_fround(HEAPF32[$83>>2]);
  $85 = $84 > $78;
  do {
   if ($81) {
    if ($85) {
     HEAP32[$__first>>2] = $82;
     HEAP32[$71>>2] = $74;
     $110 = $74;
     break;
    }
    HEAP32[$__first>>2] = $73;
    HEAP32[$72>>2] = $74;
    $87 = $84 > $80;
    if ($87) {
     HEAP32[$72>>2] = $82;
     HEAP32[$71>>2] = $74;
     $110 = $74;
    } else {
     $110 = $82;
    }
   } else {
    if ($85) {
     HEAP32[$72>>2] = $82;
     HEAP32[$71>>2] = $73;
     $86 = $84 > $80;
     if ($86) {
      HEAP32[$__first>>2] = $82;
      HEAP32[$72>>2] = $74;
      $110 = $73;
     } else {
      $110 = $73;
     }
    } else {
     $110 = $82;
    }
   }
  } while(0);
  $88 = (($__first) + 12|0);
  $89 = ($88|0)==($__last|0);
  if ($89) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $94 = $110;$__count$05 = 0;$__i$06 = $88;$__j$04 = $71;
  }
  while(1) {
   $90 = HEAP32[$__i$06>>2]|0;
   $91 = ((($76) + (($90*40)|0)|0) + 36|0);
   $92 = Math_fround(HEAPF32[$91>>2]);
   $93 = ((($76) + (($94*40)|0)|0) + 36|0);
   $95 = Math_fround(HEAPF32[$93>>2]);
   $96 = $92 > $95;
   if ($96) {
    $97 = $94;$__j$1 = $__i$06;$__k$0 = $__j$04;
    while(1) {
     HEAP32[$__j$1>>2] = $97;
     $98 = ($__k$0|0)==($__first|0);
     if ($98) {
      $__k$0$lcssa = $__first;
      break;
     }
     $99 = (($__k$0) + -4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = ((($76) + (($100*40)|0)|0) + 36|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = $92 > $102;
     if ($103) {
      $__j$1$phi = $__k$0;$97 = $100;$__k$0 = $99;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $90;
    $104 = (($__count$05) + 1)|0;
    $105 = ($104|0)==(8);
    if ($105) {
     break;
    } else {
     $__count$1 = $104;
    }
   } else {
    $__count$1 = $__count$05;
   }
   $108 = (($__i$06) + 4|0);
   $109 = ($108|0)==($__last|0);
   if ($109) {
    $$0 = 1;
    label = 34;
    break;
   }
   $$pre = HEAP32[$__i$06>>2]|0;
   $__j$04$phi = $__i$06;$94 = $$pre;$__count$05 = $__count$1;$__i$06 = $108;$__j$04 = $__j$04$phi;
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  $106 = (($__i$06) + 4|0);
  $107 = ($106|0)==($__last|0);
  $$0 = $107;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN14TreeBinaryTreeD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3709,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L1: do {
  if ($6) {
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   $39 = (($this) + 96|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   do {
    if (!($41)) {
     __THREW__ = 0;
     invoke_vi(3715,($40|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      $44 = ___cxa_find_matching_catch()|0;
      $45 = tempRet0;
      __ZdlPv($40);
      ___cxa_call_unexpected(($44|0));
      // unreachable;
     } else {
      __ZdlPv($40);
      break;
     }
    }
   } while(0);
   $46 = (($this) + 92|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   do {
    if (!($48)) {
     __THREW__ = 0;
     invoke_vi(3715,($47|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      $51 = ___cxa_find_matching_catch()|0;
      $52 = tempRet0;
      __ZdlPv($47);
      ___cxa_call_unexpected(($51|0));
      // unreachable;
     } else {
      __ZdlPv($47);
      break;
     }
    }
   } while(0);
   $53 = (($this) + 88|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)>(-1);
   if ($55) {
    $56 = (($this) + 76|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = (($this) + 80|0);
    $59 = HEAP32[$58>>2]|0;
    HEAP32[$0>>2] = $59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy3|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     $73 = ___cxa_find_matching_catch(0|0)|0;
     $74 = tempRet0;
     ___clang_call_terminate($73);
     // unreachable;
    } else {
     HEAP32[$56>>2] = 0;
     $$0 = $38;$$01 = $37;
     break;
    }
   } else {
    $$0 = $38;$$01 = $37;
   }
  } else {
   $7 = (($this) + 96|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   do {
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3715,($8|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      $12 = ___cxa_find_matching_catch()|0;
      $13 = tempRet0;
      __ZdlPv($8);
      ___cxa_call_unexpected(($12|0));
      // unreachable;
     } else {
      __ZdlPv($8);
      break;
     }
    }
   } while(0);
   $14 = (($this) + 92|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   do {
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(3715,($15|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      $19 = ___cxa_find_matching_catch()|0;
      $20 = tempRet0;
      __ZdlPv($15);
      ___cxa_call_unexpected(($19|0));
      // unreachable;
     } else {
      __ZdlPv($15);
      break;
     }
    }
   } while(0);
   $21 = (($this) + 88|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)>(-1);
   do {
    if ($23) {
     $24 = (($this) + 76|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($this) + 80|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$1>>2] = $27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($25|0),($$byval_copy3|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      $62 = ___cxa_find_matching_catch()|0;
      $63 = tempRet0;
      $$0 = $63;$$01 = $62;
      break L1;
     } else {
      HEAP32[$24>>2] = 0;
      break;
     }
    }
   } while(0);
   $30 = (($this) + 16|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)>(-1);
   if (!($32)) {
    STACKTOP = sp;return;
   }
   $33 = (($this) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($this) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP32[$0>>2] = $36;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($34,$$byval_copy3);
   HEAP32[$33>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $64 = (($this) + 16|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ($65|0)>(-1);
 if (!($66)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $67 = (($this) + 4|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($this) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 HEAP32[$2>>2] = $70;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($68|0),($$byval_copy3|0));
 $71 = __THREW__; __THREW__ = 0;
 $72 = $71&1;
 if ($72) {
  $73 = ___cxa_find_matching_catch(0|0)|0;
  $74 = tempRet0;
  ___clang_call_terminate($73);
  // unreachable;
 }
 HEAP32[$67>>2] = 0;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN12TreeRenderer19LODTreeInstanceDataD2Ev($this) {
 $this = $this|0;
 var $$byval_copy22 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body12$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy22 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 112|0);
 $5 = (($this) + 140|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(-1);
 do {
  if ($7) {
   $8 = (($this) + 128|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 132|0);
   $11 = HEAP32[$10>>2]|0;
   HEAP32[$3>>2] = $11;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy22|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    HEAP32[$8>>2] = 0;
    label = 4;
    break;
   }
   $22 = ___cxa_find_matching_catch()|0;
   $23 = tempRet0;
   $24 = (($this) + 124|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(-1);
   if ($26) {
    $27 = HEAP32[$4>>2]|0;
    $28 = (($this) + 116|0);
    $29 = HEAP32[$28>>2]|0;
    HEAP32[$0>>2] = $29;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy22|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     $32 = ___cxa_find_matching_catch(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    } else {
     HEAP32[$4>>2] = 0;
     $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
     break;
    }
   } else {
    $eh$lpad$body$index3Z2D = $23;$eh$lpad$body$indexZ2D = $22;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $14 = (($this) + 124|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>(-1);
   do {
    if ($16) {
     $17 = HEAP32[$4>>2]|0;
     $18 = (($this) + 116|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$2>>2] = $19;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($17|0),($$byval_copy22|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      $62 = ___cxa_find_matching_catch()|0;
      $63 = tempRet0;
      $eh$lpad$body$index3Z2D = $63;$eh$lpad$body$indexZ2D = $62;
      break L10;
     } else {
      HEAP32[$4>>2] = 0;
      break;
     }
    }
   } while(0);
   $34 = (($this) + 76|0);
   $35 = (($this) + 104|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)>(-1);
   do {
    if ($37) {
     $38 = (($this) + 92|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($this) + 96|0);
     $41 = HEAP32[$40>>2]|0;
     HEAP32[$1>>2] = $41;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($39|0),($$byval_copy22|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      HEAP32[$38>>2] = 0;
      break;
     }
     $50 = ___cxa_find_matching_catch()|0;
     $51 = tempRet0;
     $52 = (($this) + 88|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)>(-1);
     if (!($54)) {
      ___resumeException($50|0);
      // unreachable;
     }
     $55 = HEAP32[$34>>2]|0;
     $56 = (($this) + 80|0);
     $57 = HEAP32[$56>>2]|0;
     HEAP32[$0>>2] = $57;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($55|0),($$byval_copy22|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      $60 = ___cxa_find_matching_catch(0|0)|0;
      $61 = tempRet0;
      ___clang_call_terminate($60);
      // unreachable;
     }
     HEAP32[$34>>2] = 0;
     ___resumeException($50|0);
     // unreachable;
    }
   } while(0);
   $44 = (($this) + 88|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)>(-1);
   if (!($46)) {
    STACKTOP = sp;return;
   }
   $47 = HEAP32[$34>>2]|0;
   $48 = (($this) + 80|0);
   $49 = HEAP32[$48>>2]|0;
   HEAP32[$0>>2] = $49;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($47,$$byval_copy22);
   HEAP32[$34>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $64 = (($this) + 76|0);
 $65 = (($this) + 104|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = ($66|0)>(-1);
 do {
  if ($67) {
   $68 = (($this) + 92|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = (($this) + 96|0);
   $71 = HEAP32[$70>>2]|0;
   HEAP32[$1>>2] = $71;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($69|0),($$byval_copy22|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if (!($73)) {
    HEAP32[$68>>2] = 0;
    break;
   }
   $82 = ___cxa_find_matching_catch(0|0)|0;
   $83 = tempRet0;
   $84 = (($this) + 88|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = ($85|0)>(-1);
   if (!($86)) {
    $eh$lpad$body12$indexZ2D = $82;
    ___clang_call_terminate($eh$lpad$body12$indexZ2D);
    // unreachable;
   }
   $87 = HEAP32[$64>>2]|0;
   $88 = (($this) + 80|0);
   $89 = HEAP32[$88>>2]|0;
   HEAP32[$0>>2] = $89;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($87|0),($$byval_copy22|0));
   $90 = __THREW__; __THREW__ = 0;
   $91 = $90&1;
   if ($91) {
    $92 = ___cxa_find_matching_catch(0|0)|0;
    $93 = tempRet0;
    ___clang_call_terminate($92);
    // unreachable;
   }
   HEAP32[$64>>2] = 0;
   $eh$lpad$body12$indexZ2D = $82;
   ___clang_call_terminate($eh$lpad$body12$indexZ2D);
   // unreachable;
  }
 } while(0);
 $74 = (($this) + 88|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = ($75|0)>(-1);
 if (!($76)) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $77 = HEAP32[$64>>2]|0;
 $78 = (($this) + 80|0);
 $79 = HEAP32[$78>>2]|0;
 HEAP32[$0>>2] = $79;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($77|0),($$byval_copy22|0));
 $80 = __THREW__; __THREW__ = 0;
 $81 = $80&1;
 if ($81) {
  $94 = ___cxa_find_matching_catch(0|0)|0;
  $95 = tempRet0;
  $eh$lpad$body12$indexZ2D = $94;
  ___clang_call_terminate($eh$lpad$body12$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$64>>2] = 0;
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEvT0_S7_T_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$idx = 0, $$0$idx$val = Math_fround(0), $$0$idx1 = 0, $$0$idx1$val = Math_fround(0), $$0$idx6$val = Math_fround(0), $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$idx$i = 0, $$idx$val = Math_fround(0), $$idx$val$i = Math_fround(0), $$idx11 = 0, $$idx11$val = Math_fround(0), $$idx2$pre = 0, $$idx2$pre$phiZZ2D = 0, $$idx2$val = Math_fround(0), $$idx4$val = Math_fround(0), $$idx8 = 0, $$idx8$val = Math_fround(0);
 var $$idx9 = 0, $$idx9$val = Math_fround(0), $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0);
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = Math_fround(0), $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = Math_fround(0), $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$0$idx = 0, $__i$0$idx$i = 0, $__i$0$idx$val = Math_fround(0), $__i$0$idx$val$i = Math_fround(0), $__i$02$i = 0, $__i$044 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$idx = 0, $__i$2$idx$val = Math_fround(0), $__i$2$ph = 0, $__i$3 = 0;
 var $__i$3$idx = 0, $__i$3$idx$val = Math_fround(0), $__i$3$ph = 0, $__i$4 = 0, $__i$4$idx = 0, $__i$4$idx$val = Math_fround(0), $__j$0 = 0, $__j$0$idx$i = 0, $__j$0$idx$val$i = Math_fround(0), $__j$01$i = 0, $__j$01$i$phi = 0, $__j$1$i = 0, $__j$1$i$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__k$0$i = 0, $__m$0$idx = 0;
 var $__m$0$idx$val = Math_fround(0), $__m$0$ph = 0, $__m$2 = 0, $__m$2$idx = 0, $__m$2$idx$val = Math_fround(0), $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__x$idx$i = 0, $__x$idx$i$i = 0, $__x$idx$i30 = 0, $__x$idx$val$i = Math_fround(0), $__x$idx$val$i$i = Math_fround(0), $__x$idx$val$i31 = Math_fround(0), $__x$idx2$val$i = Math_fround(0), $__x$idx2$val$i35 = Math_fround(0), $__x1$idx$i = 0, $__x1$idx$i24 = 0;
 var $__x1$idx$val$i = Math_fround(0), $__x1$idx$val$i25 = Math_fround(0), $__x2$idx$i = 0, $__x2$idx$i21 = 0, $__x2$idx$val$i = Math_fround(0), $__x2$idx$val$i22 = Math_fround(0), $__x2$idx3$val$i23 = Math_fround(0), $__x3$idx$i = 0, $__x3$idx$i18 = 0, $__x3$idx$val$i = Math_fround(0), $__x3$idx$val$i19 = Math_fround(0), $__x3$idx2$val$i20 = Math_fround(0), $__x4$idx$i = 0, $__x4$idx$i15 = 0, $__x4$idx$val$i = Math_fround(0), $__x4$idx$val$i16 = Math_fround(0), $__x4$idx1$val$i = Math_fround(0), $__x4$idx1$val$i17 = Math_fround(0), $__x5$idx$i13 = 0, $__x5$idx$val$i = Math_fround(0);
 var $__x5$idx$val$i14 = Math_fround(0), $__y$idx$i = 0, $__y$idx$i$i = 0, $__y$idx$i28 = 0, $__y$idx$val$i = Math_fround(0), $__y$idx$val$i$i = Math_fround(0), $__y$idx$val$i29 = Math_fround(0), $__y$idx1$val$i = Math_fround(0), $__y$idx1$val$i34 = Math_fround(0), $__z$idx$i$i = 0, $__z$idx$val$i = Math_fround(0), $__z$idx$val$i$i = Math_fround(0), $__z$idx$val$i33 = Math_fround(0), $__z$idx4$val$i = Math_fround(0), $__z$idx4$val$i36 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $__x5$idx$i13 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 4:  {
    label = 14;
    break L1;
    break;
   }
   case 5:  {
    label = 15;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 85;
    break L1;
    break;
   }
   default: {
   }
   }
   $198 = ($3|0)<(248);
   if ($198) {
    label = 21;
    break L1;
   }
   $318 = ($3|0)>(7992);
   $319 = (($4|0) / 2)&-1;
   $320 = (($$0) + ($319<<3)|0);
   do {
    if ($318) {
     $321 = (($4|0) / 4)&-1;
     $322 = (($$0) + ($321<<3)|0);
     $$sum = (($321) + ($319))|0;
     $323 = (($$0) + ($$sum<<3)|0);
     $324 = (__ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$322,$320,$323)|0);
     $__x5$idx$val$i14 = Math_fround(HEAPF32[$__x5$idx$i13>>2]);
     $__x4$idx$i15 = ((($$0) + ($$sum<<3)|0) + 4|0);
     $__x4$idx$val$i16 = Math_fround(HEAPF32[$__x4$idx$i15>>2]);
     $325 = $__x5$idx$val$i14 < $__x4$idx$val$i16;
     if (!($325)) {
      $$idx2$pre = ((($$0) + ($319<<3)|0) + 4|0);
      $$idx2$pre$phiZZ2D = $$idx2$pre;$__n_swaps$0 = $324;
      break;
     }
     $326 = $323;
     $327 = $326;
     $328 = HEAP32[$327>>2]|0;
     $329 = (($326) + 4)|0;
     $330 = $329;
     $331 = HEAP32[$330>>2]|0;
     $332 = $1;
     $333 = $332;
     $334 = HEAP32[$333>>2]|0;
     $335 = (($332) + 4)|0;
     $336 = $335;
     $337 = HEAP32[$336>>2]|0;
     $338 = $323;
     $339 = $338;
     HEAP32[$339>>2] = $334;
     $340 = (($338) + 4)|0;
     $341 = $340;
     HEAP32[$341>>2] = $337;
     $342 = $1;
     $343 = $342;
     HEAP32[$343>>2] = $328;
     $344 = (($342) + 4)|0;
     $345 = $344;
     HEAP32[$345>>2] = $331;
     $__x4$idx1$val$i17 = Math_fround(HEAPF32[$__x4$idx$i15>>2]);
     $__x3$idx$i18 = ((($$0) + ($319<<3)|0) + 4|0);
     $__x3$idx$val$i19 = Math_fround(HEAPF32[$__x3$idx$i18>>2]);
     $346 = $__x4$idx1$val$i17 < $__x3$idx$val$i19;
     if (!($346)) {
      $347 = (($324) + 1)|0;
      $$idx2$pre$phiZZ2D = $__x3$idx$i18;$__n_swaps$0 = $347;
      break;
     }
     $348 = $320;
     $349 = $348;
     $350 = HEAP32[$349>>2]|0;
     $351 = (($348) + 4)|0;
     $352 = $351;
     $353 = HEAP32[$352>>2]|0;
     $354 = $323;
     $355 = $354;
     $356 = HEAP32[$355>>2]|0;
     $357 = (($354) + 4)|0;
     $358 = $357;
     $359 = HEAP32[$358>>2]|0;
     $360 = $320;
     $361 = $360;
     HEAP32[$361>>2] = $356;
     $362 = (($360) + 4)|0;
     $363 = $362;
     HEAP32[$363>>2] = $359;
     $364 = $323;
     $365 = $364;
     HEAP32[$365>>2] = $350;
     $366 = (($364) + 4)|0;
     $367 = $366;
     HEAP32[$367>>2] = $353;
     $__x3$idx2$val$i20 = Math_fround(HEAPF32[$__x3$idx$i18>>2]);
     $__x2$idx$i21 = ((($$0) + ($321<<3)|0) + 4|0);
     $__x2$idx$val$i22 = Math_fround(HEAPF32[$__x2$idx$i21>>2]);
     $368 = $__x3$idx2$val$i20 < $__x2$idx$val$i22;
     if (!($368)) {
      $369 = (($324) + 2)|0;
      $$idx2$pre$phiZZ2D = $__x3$idx$i18;$__n_swaps$0 = $369;
      break;
     }
     $370 = $322;
     $371 = $370;
     $372 = HEAP32[$371>>2]|0;
     $373 = (($370) + 4)|0;
     $374 = $373;
     $375 = HEAP32[$374>>2]|0;
     $376 = $320;
     $377 = $376;
     $378 = HEAP32[$377>>2]|0;
     $379 = (($376) + 4)|0;
     $380 = $379;
     $381 = HEAP32[$380>>2]|0;
     $382 = $322;
     $383 = $382;
     HEAP32[$383>>2] = $378;
     $384 = (($382) + 4)|0;
     $385 = $384;
     HEAP32[$385>>2] = $381;
     $386 = $320;
     $387 = $386;
     HEAP32[$387>>2] = $372;
     $388 = (($386) + 4)|0;
     $389 = $388;
     HEAP32[$389>>2] = $375;
     $__x2$idx3$val$i23 = Math_fround(HEAPF32[$__x2$idx$i21>>2]);
     $__x1$idx$i24 = (($$0) + 4|0);
     $__x1$idx$val$i25 = Math_fround(HEAPF32[$__x1$idx$i24>>2]);
     $390 = $__x2$idx3$val$i23 < $__x1$idx$val$i25;
     if ($390) {
      $392 = $$0;
      $393 = $392;
      $394 = HEAP32[$393>>2]|0;
      $395 = (($392) + 4)|0;
      $396 = $395;
      $397 = HEAP32[$396>>2]|0;
      $398 = $322;
      $399 = $398;
      $400 = HEAP32[$399>>2]|0;
      $401 = (($398) + 4)|0;
      $402 = $401;
      $403 = HEAP32[$402>>2]|0;
      $404 = $$0;
      $405 = $404;
      HEAP32[$405>>2] = $400;
      $406 = (($404) + 4)|0;
      $407 = $406;
      HEAP32[$407>>2] = $403;
      $408 = $322;
      $409 = $408;
      HEAP32[$409>>2] = $394;
      $410 = (($408) + 4)|0;
      $411 = $410;
      HEAP32[$411>>2] = $397;
      $412 = (($324) + 4)|0;
      $$idx2$pre$phiZZ2D = $__x3$idx$i18;$__n_swaps$0 = $412;
      break;
     } else {
      $391 = (($324) + 3)|0;
      $$idx2$pre$phiZZ2D = $__x3$idx$i18;$__n_swaps$0 = $391;
      break;
     }
    } else {
     $__y$idx$i28 = ((($$0) + ($319<<3)|0) + 4|0);
     $__y$idx$val$i29 = Math_fround(HEAPF32[$__y$idx$i28>>2]);
     $__x$idx$i30 = (($$0) + 4|0);
     $__x$idx$val$i31 = Math_fround(HEAPF32[$__x$idx$i30>>2]);
     $413 = $__y$idx$val$i29 < $__x$idx$val$i31;
     $__z$idx$val$i33 = Math_fround(HEAPF32[$__x5$idx$i13>>2]);
     $414 = $__z$idx$val$i33 < $__y$idx$val$i29;
     if (!($413)) {
      if (!($414)) {
       $$idx2$pre$phiZZ2D = $__y$idx$i28;$__n_swaps$0 = 0;
       break;
      }
      $415 = $320;
      $416 = $415;
      $417 = HEAP32[$416>>2]|0;
      $418 = (($415) + 4)|0;
      $419 = $418;
      $420 = HEAP32[$419>>2]|0;
      $421 = $1;
      $422 = $421;
      $423 = HEAP32[$422>>2]|0;
      $424 = (($421) + 4)|0;
      $425 = $424;
      $426 = HEAP32[$425>>2]|0;
      $427 = $320;
      $428 = $427;
      HEAP32[$428>>2] = $423;
      $429 = (($427) + 4)|0;
      $430 = $429;
      HEAP32[$430>>2] = $426;
      $431 = $1;
      $432 = $431;
      HEAP32[$432>>2] = $417;
      $433 = (($431) + 4)|0;
      $434 = $433;
      HEAP32[$434>>2] = $420;
      $__y$idx1$val$i34 = Math_fround(HEAPF32[$__y$idx$i28>>2]);
      $__x$idx2$val$i35 = Math_fround(HEAPF32[$__x$idx$i30>>2]);
      $435 = $__y$idx1$val$i34 < $__x$idx2$val$i35;
      if (!($435)) {
       $$idx2$pre$phiZZ2D = $__y$idx$i28;$__n_swaps$0 = 1;
       break;
      }
      $436 = $$0;
      $437 = $436;
      $438 = HEAP32[$437>>2]|0;
      $439 = (($436) + 4)|0;
      $440 = $439;
      $441 = HEAP32[$440>>2]|0;
      $442 = $320;
      $443 = $442;
      $444 = HEAP32[$443>>2]|0;
      $445 = (($442) + 4)|0;
      $446 = $445;
      $447 = HEAP32[$446>>2]|0;
      $448 = $$0;
      $449 = $448;
      HEAP32[$449>>2] = $444;
      $450 = (($448) + 4)|0;
      $451 = $450;
      HEAP32[$451>>2] = $447;
      $452 = $320;
      $453 = $452;
      HEAP32[$453>>2] = $438;
      $454 = (($452) + 4)|0;
      $455 = $454;
      HEAP32[$455>>2] = $441;
      $$idx2$pre$phiZZ2D = $__y$idx$i28;$__n_swaps$0 = 2;
      break;
     }
     $456 = $$0;
     $457 = $456;
     $458 = HEAP32[$457>>2]|0;
     $459 = (($456) + 4)|0;
     $460 = $459;
     $461 = HEAP32[$460>>2]|0;
     if ($414) {
      $462 = $1;
      $463 = $462;
      $464 = HEAP32[$463>>2]|0;
      $465 = (($462) + 4)|0;
      $466 = $465;
      $467 = HEAP32[$466>>2]|0;
      $468 = $$0;
      $469 = $468;
      HEAP32[$469>>2] = $464;
      $470 = (($468) + 4)|0;
      $471 = $470;
      HEAP32[$471>>2] = $467;
      $472 = $1;
      $473 = $472;
      HEAP32[$473>>2] = $458;
      $474 = (($472) + 4)|0;
      $475 = $474;
      HEAP32[$475>>2] = $461;
      $$idx2$pre$phiZZ2D = $__y$idx$i28;$__n_swaps$0 = 1;
      break;
     }
     $476 = $320;
     $477 = $476;
     $478 = HEAP32[$477>>2]|0;
     $479 = (($476) + 4)|0;
     $480 = $479;
     $481 = HEAP32[$480>>2]|0;
     $482 = $$0;
     $483 = $482;
     HEAP32[$483>>2] = $478;
     $484 = (($482) + 4)|0;
     $485 = $484;
     HEAP32[$485>>2] = $481;
     $486 = $320;
     $487 = $486;
     HEAP32[$487>>2] = $458;
     $488 = (($486) + 4)|0;
     $489 = $488;
     HEAP32[$489>>2] = $461;
     $__z$idx4$val$i36 = Math_fround(HEAPF32[$__x5$idx$i13>>2]);
     $490 = (HEAP32[tempDoublePtr>>2]=$461,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $491 = $__z$idx4$val$i36 < $490;
     if ($491) {
      $492 = $1;
      $493 = $492;
      $494 = HEAP32[$493>>2]|0;
      $495 = (($492) + 4)|0;
      $496 = $495;
      $497 = HEAP32[$496>>2]|0;
      $498 = $320;
      $499 = $498;
      HEAP32[$499>>2] = $494;
      $500 = (($498) + 4)|0;
      $501 = $500;
      HEAP32[$501>>2] = $497;
      $502 = $1;
      $503 = $502;
      HEAP32[$503>>2] = $458;
      $504 = (($502) + 4)|0;
      $505 = $504;
      HEAP32[$505>>2] = $461;
      $$idx2$pre$phiZZ2D = $__y$idx$i28;$__n_swaps$0 = 2;
     } else {
      $$idx2$pre$phiZZ2D = $__y$idx$i28;$__n_swaps$0 = 1;
     }
    }
   } while(0);
   $$0$idx1 = (($$0) + 4|0);
   $$0$idx1$val = Math_fround(HEAPF32[$$0$idx1>>2]);
   $$idx2$val = Math_fround(HEAPF32[$$idx2$pre$phiZZ2D>>2]);
   $506 = $$0$idx1$val < $$idx2$val;
   do {
    if ($506) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $507 = (($__j$0) + -8|0);
      $508 = ($$0|0)==($507|0);
      if ($508) {
       break;
      }
      $$idx9 = (($__j$0) + -4|0);
      $$idx9$val = Math_fround(HEAPF32[$$idx9>>2]);
      $561 = $$idx9$val < $$idx2$val;
      if ($561) {
       label = 68;
       break;
      } else {
       $__j$0 = $507;
      }
     }
     if ((label|0) == 68) {
      label = 0;
      $562 = $$0;
      $563 = $562;
      $564 = HEAP32[$563>>2]|0;
      $565 = (($562) + 4)|0;
      $566 = $565;
      $567 = HEAP32[$566>>2]|0;
      $568 = $507;
      $569 = $568;
      $570 = HEAP32[$569>>2]|0;
      $571 = (($568) + 4)|0;
      $572 = $571;
      $573 = HEAP32[$572>>2]|0;
      $574 = $$0;
      $575 = $574;
      HEAP32[$575>>2] = $570;
      $576 = (($574) + 4)|0;
      $577 = $576;
      HEAP32[$577>>2] = $573;
      $578 = $507;
      $579 = $578;
      HEAP32[$579>>2] = $564;
      $580 = (($578) + 4)|0;
      $581 = $580;
      HEAP32[$581>>2] = $567;
      $582 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $507;$__n_swaps$3 = $582;
      break;
     }
     $509 = (($$0) + 8|0);
     $$idx4$val = Math_fround(HEAPF32[$__x5$idx$i13>>2]);
     $510 = $$0$idx1$val < $$idx4$val;
     if ($510) {
      $__i$1 = $509;
     } else {
      $511 = ($509|0)==($1|0);
      if ($511) {
       label = 85;
       break L1;
      } else {
       $__i$044 = $509;
      }
      while(1) {
       $__i$0$idx = (($__i$044) + 4|0);
       $__i$0$idx$val = Math_fround(HEAPF32[$__i$0$idx>>2]);
       $514 = $$0$idx1$val < $__i$0$idx$val;
       $513 = (($__i$044) + 8|0);
       if ($514) {
        break;
       }
       $512 = ($513|0)==($1|0);
       if ($512) {
        label = 85;
        break L1;
       } else {
        $__i$044 = $513;
       }
      }
      $515 = $__i$044;
      $516 = $515;
      $517 = HEAP32[$516>>2]|0;
      $518 = (($515) + 4)|0;
      $519 = $518;
      $520 = HEAP32[$519>>2]|0;
      $521 = $1;
      $522 = $521;
      $523 = HEAP32[$522>>2]|0;
      $524 = (($521) + 4)|0;
      $525 = $524;
      $526 = HEAP32[$525>>2]|0;
      $527 = $__i$044;
      $528 = $527;
      HEAP32[$528>>2] = $523;
      $529 = (($527) + 4)|0;
      $530 = $529;
      HEAP32[$530>>2] = $526;
      $531 = $1;
      $532 = $531;
      HEAP32[$532>>2] = $517;
      $533 = (($531) + 4)|0;
      $534 = $533;
      HEAP32[$534>>2] = $520;
      $__i$1 = $513;
     }
     $535 = ($__i$1|0)==($1|0);
     if ($535) {
      label = 85;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $$0$idx6$val = Math_fround(HEAPF32[$$0$idx1>>2]);
      $__i$2 = $__i$2$ph;
      while(1) {
       $__i$2$idx = (($__i$2) + 4|0);
       $__i$2$idx$val = Math_fround(HEAPF32[$__i$2$idx>>2]);
       $536 = $$0$idx6$val < $__i$2$idx$val;
       $537 = (($__i$2) + 8|0);
       if ($536) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $537;
       }
      }
      while(1) {
       $538 = (($__j$2) + -8|0);
       $$idx8 = (($__j$2) + -4|0);
       $$idx8$val = Math_fround(HEAPF32[$$idx8>>2]);
       $539 = $$0$idx6$val < $$idx8$val;
       if ($539) {
        $__j$2 = $538;
       } else {
        break;
       }
      }
      $540 = ($__i$2>>>0)<($538>>>0);
      if (!($540)) {
       $$0 = $__i$2;
       continue L3;
      }
      $541 = $__i$2;
      $542 = $541;
      $543 = HEAP32[$542>>2]|0;
      $544 = (($541) + 4)|0;
      $545 = $544;
      $546 = HEAP32[$545>>2]|0;
      $547 = $538;
      $548 = $547;
      $549 = HEAP32[$548>>2]|0;
      $550 = (($547) + 4)|0;
      $551 = $550;
      $552 = HEAP32[$551>>2]|0;
      $553 = $__i$2;
      $554 = $553;
      HEAP32[$554>>2] = $549;
      $555 = (($553) + 4)|0;
      $556 = $555;
      HEAP32[$556>>2] = $552;
      $557 = $538;
      $558 = $557;
      HEAP32[$558>>2] = $543;
      $559 = (($557) + 4)|0;
      $560 = $559;
      HEAP32[$560>>2] = $546;
      $__i$2$ph = $537;$__j$1$ph = $538;
     }
    }
   } while(0);
   $583 = (($$0) + 8|0);
   $584 = ($583>>>0)<($__j$3>>>0);
   L55: do {
    if ($584) {
     $__i$3$ph = $583;$__j$4$ph = $__j$3;$__m$0$ph = $320;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__m$0$idx = (($__m$0$ph) + 4|0);
      $__m$0$idx$val = Math_fround(HEAPF32[$__m$0$idx>>2]);
      $__i$3 = $__i$3$ph;
      while(1) {
       $__i$3$idx = (($__i$3) + 4|0);
       $__i$3$idx$val = Math_fround(HEAPF32[$__i$3$idx>>2]);
       $585 = $__i$3$idx$val < $__m$0$idx$val;
       $586 = (($__i$3) + 8|0);
       if ($585) {
        $__i$3 = $586;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $587 = (($__j$5) + -8|0);
       $$idx11 = (($__j$5) + -4|0);
       $$idx11$val = Math_fround(HEAPF32[$$idx11>>2]);
       $588 = $$idx11$val < $__m$0$idx$val;
       if ($588) {
        break;
       } else {
        $__j$5 = $587;
       }
      }
      $589 = ($__i$3>>>0)>($587>>>0);
      if ($589) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L55;
      }
      $590 = $__i$3;
      $591 = $590;
      $592 = HEAP32[$591>>2]|0;
      $593 = (($590) + 4)|0;
      $594 = $593;
      $595 = HEAP32[$594>>2]|0;
      $596 = $587;
      $597 = $596;
      $598 = HEAP32[$597>>2]|0;
      $599 = (($596) + 4)|0;
      $600 = $599;
      $601 = HEAP32[$600>>2]|0;
      $602 = $__i$3;
      $603 = $602;
      HEAP32[$603>>2] = $598;
      $604 = (($602) + 4)|0;
      $605 = $604;
      HEAP32[$605>>2] = $601;
      $606 = $587;
      $607 = $606;
      HEAP32[$607>>2] = $592;
      $608 = (($606) + 4)|0;
      $609 = $608;
      HEAP32[$609>>2] = $595;
      $610 = (($__n_swaps$4$ph) + 1)|0;
      $611 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $611 ? $587 : $__m$0$ph;
      $__i$3$ph = $586;$__j$4$ph = $587;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $610;
     }
    } else {
     $__i$4 = $583;$__m$2 = $320;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $612 = ($__i$4|0)==($__m$2|0);
   if ($612) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $__m$2$idx = (($__m$2) + 4|0);
    $__m$2$idx$val = Math_fround(HEAPF32[$__m$2$idx>>2]);
    $__i$4$idx = (($__i$4) + 4|0);
    $__i$4$idx$val = Math_fround(HEAPF32[$__i$4$idx>>2]);
    $613 = $__m$2$idx$val < $__i$4$idx$val;
    if ($613) {
     $614 = $__i$4;
     $615 = $614;
     $616 = HEAP32[$615>>2]|0;
     $617 = (($614) + 4)|0;
     $618 = $617;
     $619 = HEAP32[$618>>2]|0;
     $620 = $__m$2;
     $621 = $620;
     $622 = HEAP32[$621>>2]|0;
     $623 = (($620) + 4)|0;
     $624 = $623;
     $625 = HEAP32[$624>>2]|0;
     $626 = $__i$4;
     $627 = $626;
     HEAP32[$627>>2] = $622;
     $628 = (($626) + 4)|0;
     $629 = $628;
     HEAP32[$629>>2] = $625;
     $630 = $__m$2;
     $631 = $630;
     HEAP32[$631>>2] = $616;
     $632 = (($630) + 4)|0;
     $633 = $632;
     HEAP32[$633>>2] = $619;
     $634 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $634;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $635 = ($__n_swaps$6|0)==(0);
   if ($635) {
    $636 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEbT0_S7_T_($$0,$__i$4)|0);
    $637 = (($__i$4) + 8|0);
    $638 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEbT0_S7_T_($637,$$01$ph)|0);
    if ($638) {
     label = 80;
     break;
    }
    if ($636) {
     $$0 = $637;
     continue;
    }
   }
   $639 = $__i$4;
   $640 = (($639) - ($2))|0;
   $641 = (($0) - ($639))|0;
   $642 = ($640|0)<($641|0);
   if (!($642)) {
    label = 84;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEvT0_S7_T_($$0,$__i$4);
   $643 = (($__i$4) + 8|0);
   $$0 = $643;
  }
  if ((label|0) == 80) {
   label = 0;
   if ($636) {
    label = 85;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 84) {
   label = 0;
   $644 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEvT0_S7_T_($644,$$01$ph);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $$idx$val = Math_fround(HEAPF32[$__x5$idx$i13>>2]);
  $$0$idx = (($$0) + 4|0);
  $$0$idx$val = Math_fround(HEAPF32[$$0$idx>>2]);
  $5 = $$idx$val < $$0$idx$val;
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = $$0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $1;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $$0;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $1;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $26 = (($$0) + 8|0);
  $__y$idx$i = (($$0) + 12|0);
  $__y$idx$val$i = Math_fround(HEAPF32[$__y$idx$i>>2]);
  $__x$idx$i = (($$0) + 4|0);
  $__x$idx$val$i = Math_fround(HEAPF32[$__x$idx$i>>2]);
  $27 = $__y$idx$val$i < $__x$idx$val$i;
  $__z$idx$val$i = Math_fround(HEAPF32[$__x5$idx$i13>>2]);
  $28 = $__z$idx$val$i < $__y$idx$val$i;
  if (!($27)) {
   if (!($28)) {
    STACKTOP = sp;return;
   }
   $29 = $26;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = $1;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $38 = (($35) + 4)|0;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = $26;
   $42 = $41;
   HEAP32[$42>>2] = $37;
   $43 = (($41) + 4)|0;
   $44 = $43;
   HEAP32[$44>>2] = $40;
   $45 = $1;
   $46 = $45;
   HEAP32[$46>>2] = $31;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $34;
   $__y$idx1$val$i = Math_fround(HEAPF32[$__y$idx$i>>2]);
   $__x$idx2$val$i = Math_fround(HEAPF32[$__x$idx$i>>2]);
   $49 = $__y$idx1$val$i < $__x$idx2$val$i;
   if (!($49)) {
    STACKTOP = sp;return;
   }
   $50 = $$0;
   $51 = $50;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($50) + 4)|0;
   $54 = $53;
   $55 = HEAP32[$54>>2]|0;
   $56 = $26;
   $57 = $56;
   $58 = HEAP32[$57>>2]|0;
   $59 = (($56) + 4)|0;
   $60 = $59;
   $61 = HEAP32[$60>>2]|0;
   $62 = $$0;
   $63 = $62;
   HEAP32[$63>>2] = $58;
   $64 = (($62) + 4)|0;
   $65 = $64;
   HEAP32[$65>>2] = $61;
   $66 = $26;
   $67 = $66;
   HEAP32[$67>>2] = $52;
   $68 = (($66) + 4)|0;
   $69 = $68;
   HEAP32[$69>>2] = $55;
   STACKTOP = sp;return;
  }
  $70 = $$0;
  $71 = $70;
  $72 = HEAP32[$71>>2]|0;
  $73 = (($70) + 4)|0;
  $74 = $73;
  $75 = HEAP32[$74>>2]|0;
  if ($28) {
   $76 = $1;
   $77 = $76;
   $78 = HEAP32[$77>>2]|0;
   $79 = (($76) + 4)|0;
   $80 = $79;
   $81 = HEAP32[$80>>2]|0;
   $82 = $$0;
   $83 = $82;
   HEAP32[$83>>2] = $78;
   $84 = (($82) + 4)|0;
   $85 = $84;
   HEAP32[$85>>2] = $81;
   $86 = $1;
   $87 = $86;
   HEAP32[$87>>2] = $72;
   $88 = (($86) + 4)|0;
   $89 = $88;
   HEAP32[$89>>2] = $75;
   STACKTOP = sp;return;
  }
  $90 = $26;
  $91 = $90;
  $92 = HEAP32[$91>>2]|0;
  $93 = (($90) + 4)|0;
  $94 = $93;
  $95 = HEAP32[$94>>2]|0;
  $96 = $$0;
  $97 = $96;
  HEAP32[$97>>2] = $92;
  $98 = (($96) + 4)|0;
  $99 = $98;
  HEAP32[$99>>2] = $95;
  $100 = $26;
  $101 = $100;
  HEAP32[$101>>2] = $72;
  $102 = (($100) + 4)|0;
  $103 = $102;
  HEAP32[$103>>2] = $75;
  $__z$idx4$val$i = Math_fround(HEAPF32[$__x5$idx$i13>>2]);
  $104 = (HEAP32[tempDoublePtr>>2]=$75,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $105 = $__z$idx4$val$i < $104;
  if (!($105)) {
   STACKTOP = sp;return;
  }
  $106 = $1;
  $107 = $106;
  $108 = HEAP32[$107>>2]|0;
  $109 = (($106) + 4)|0;
  $110 = $109;
  $111 = HEAP32[$110>>2]|0;
  $112 = $26;
  $113 = $112;
  HEAP32[$113>>2] = $108;
  $114 = (($112) + 4)|0;
  $115 = $114;
  HEAP32[$115>>2] = $111;
  $116 = $1;
  $117 = $116;
  HEAP32[$117>>2] = $72;
  $118 = (($116) + 4)|0;
  $119 = $118;
  HEAP32[$119>>2] = $75;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $120 = (($$0) + 8|0);
  $121 = (($$0) + 16|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$120,$121,$1)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 15) {
  $122 = (($$0) + 8|0);
  $123 = (($$0) + 16|0);
  $124 = (($$0) + 24|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$122,$123,$124)|0);
  $__x5$idx$val$i = Math_fround(HEAPF32[$__x5$idx$i13>>2]);
  $__x4$idx$i = (($$0) + 28|0);
  $__x4$idx$val$i = Math_fround(HEAPF32[$__x4$idx$i>>2]);
  $125 = $__x5$idx$val$i < $__x4$idx$val$i;
  if (!($125)) {
   STACKTOP = sp;return;
  }
  $126 = $124;
  $127 = $126;
  $128 = HEAP32[$127>>2]|0;
  $129 = (($126) + 4)|0;
  $130 = $129;
  $131 = HEAP32[$130>>2]|0;
  $132 = $1;
  $133 = $132;
  $134 = HEAP32[$133>>2]|0;
  $135 = (($132) + 4)|0;
  $136 = $135;
  $137 = HEAP32[$136>>2]|0;
  $138 = $124;
  $139 = $138;
  HEAP32[$139>>2] = $134;
  $140 = (($138) + 4)|0;
  $141 = $140;
  HEAP32[$141>>2] = $137;
  $142 = $1;
  $143 = $142;
  HEAP32[$143>>2] = $128;
  $144 = (($142) + 4)|0;
  $145 = $144;
  HEAP32[$145>>2] = $131;
  $__x4$idx1$val$i = Math_fround(HEAPF32[$__x4$idx$i>>2]);
  $__x3$idx$i = (($$0) + 20|0);
  $__x3$idx$val$i = Math_fround(HEAPF32[$__x3$idx$i>>2]);
  $146 = $__x4$idx1$val$i < $__x3$idx$val$i;
  if (!($146)) {
   STACKTOP = sp;return;
  }
  $147 = $123;
  $148 = $147;
  $149 = HEAP32[$148>>2]|0;
  $150 = (($147) + 4)|0;
  $151 = $150;
  $152 = HEAP32[$151>>2]|0;
  $153 = $124;
  $154 = $153;
  $155 = HEAP32[$154>>2]|0;
  $156 = (($153) + 4)|0;
  $157 = $156;
  $158 = HEAP32[$157>>2]|0;
  $159 = $123;
  $160 = $159;
  HEAP32[$160>>2] = $155;
  $161 = (($159) + 4)|0;
  $162 = $161;
  HEAP32[$162>>2] = $158;
  $163 = $124;
  $164 = $163;
  HEAP32[$164>>2] = $149;
  $165 = (($163) + 4)|0;
  $166 = $165;
  HEAP32[$166>>2] = $152;
  $167 = (HEAP32[tempDoublePtr>>2]=$158,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $__x2$idx$i = (($$0) + 12|0);
  $__x2$idx$val$i = Math_fround(HEAPF32[$__x2$idx$i>>2]);
  $168 = $167 < $__x2$idx$val$i;
  if (!($168)) {
   STACKTOP = sp;return;
  }
  $169 = $122;
  $170 = $169;
  $171 = HEAP32[$170>>2]|0;
  $172 = (($169) + 4)|0;
  $173 = $172;
  $174 = HEAP32[$173>>2]|0;
  $175 = $122;
  $176 = $175;
  HEAP32[$176>>2] = $155;
  $177 = (($175) + 4)|0;
  $178 = $177;
  HEAP32[$178>>2] = $158;
  $179 = $123;
  $180 = $179;
  HEAP32[$180>>2] = $171;
  $181 = (($179) + 4)|0;
  $182 = $181;
  HEAP32[$182>>2] = $174;
  $__x1$idx$i = (($$0) + 4|0);
  $__x1$idx$val$i = Math_fround(HEAPF32[$__x1$idx$i>>2]);
  $183 = $167 < $__x1$idx$val$i;
  if (!($183)) {
   STACKTOP = sp;return;
  }
  $184 = $$0;
  $185 = $184;
  $186 = HEAP32[$185>>2]|0;
  $187 = (($184) + 4)|0;
  $188 = $187;
  $189 = HEAP32[$188>>2]|0;
  $190 = $$0;
  $191 = $190;
  HEAP32[$191>>2] = $155;
  $192 = (($190) + 4)|0;
  $193 = $192;
  HEAP32[$193>>2] = $158;
  $194 = $122;
  $195 = $194;
  HEAP32[$195>>2] = $186;
  $196 = (($194) + 4)|0;
  $197 = $196;
  HEAP32[$197>>2] = $189;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 21) {
  $199 = (($$0) + 16|0);
  $200 = (($$0) + 8|0);
  $__y$idx$i$i = (($$0) + 12|0);
  $__y$idx$val$i$i = Math_fround(HEAPF32[$__y$idx$i$i>>2]);
  $__x$idx$i$i = (($$0) + 4|0);
  $__x$idx$val$i$i = Math_fround(HEAPF32[$__x$idx$i$i>>2]);
  $201 = $__y$idx$val$i$i < $__x$idx$val$i$i;
  $__z$idx$i$i = (($$0) + 20|0);
  $__z$idx$val$i$i = Math_fround(HEAPF32[$__z$idx$i$i>>2]);
  $202 = $__z$idx$val$i$i < $__y$idx$val$i$i;
  do {
   if ($201) {
    $239 = $$0;
    $240 = $239;
    $241 = HEAP32[$240>>2]|0;
    $242 = (($239) + 4)|0;
    $243 = $242;
    $244 = HEAP32[$243>>2]|0;
    if ($202) {
     $245 = $199;
     $246 = $245;
     $247 = HEAP32[$246>>2]|0;
     $248 = (($245) + 4)|0;
     $249 = $248;
     $250 = HEAP32[$249>>2]|0;
     $251 = $$0;
     $252 = $251;
     HEAP32[$252>>2] = $247;
     $253 = (($251) + 4)|0;
     $254 = $253;
     HEAP32[$254>>2] = $250;
     $255 = $199;
     $256 = $255;
     HEAP32[$256>>2] = $241;
     $257 = (($255) + 4)|0;
     $258 = $257;
     HEAP32[$258>>2] = $244;
     break;
    }
    $259 = $200;
    $260 = $259;
    $261 = HEAP32[$260>>2]|0;
    $262 = (($259) + 4)|0;
    $263 = $262;
    $264 = HEAP32[$263>>2]|0;
    $265 = $$0;
    $266 = $265;
    HEAP32[$266>>2] = $261;
    $267 = (($265) + 4)|0;
    $268 = $267;
    HEAP32[$268>>2] = $264;
    $269 = $200;
    $270 = $269;
    HEAP32[$270>>2] = $241;
    $271 = (($269) + 4)|0;
    $272 = $271;
    HEAP32[$272>>2] = $244;
    $273 = (HEAP32[tempDoublePtr>>2]=$244,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $274 = $__z$idx$val$i$i < $273;
    if ($274) {
     $275 = $199;
     $276 = $275;
     $277 = HEAP32[$276>>2]|0;
     $278 = (($275) + 4)|0;
     $279 = $278;
     $280 = HEAP32[$279>>2]|0;
     $281 = $200;
     $282 = $281;
     HEAP32[$282>>2] = $277;
     $283 = (($281) + 4)|0;
     $284 = $283;
     HEAP32[$284>>2] = $280;
     $285 = $199;
     $286 = $285;
     HEAP32[$286>>2] = $241;
     $287 = (($285) + 4)|0;
     $288 = $287;
     HEAP32[$288>>2] = $244;
    }
   } else {
    if ($202) {
     $203 = $200;
     $204 = $203;
     $205 = HEAP32[$204>>2]|0;
     $206 = (($203) + 4)|0;
     $207 = $206;
     $208 = HEAP32[$207>>2]|0;
     $209 = $199;
     $210 = $209;
     $211 = HEAP32[$210>>2]|0;
     $212 = (($209) + 4)|0;
     $213 = $212;
     $214 = HEAP32[$213>>2]|0;
     $215 = $200;
     $216 = $215;
     HEAP32[$216>>2] = $211;
     $217 = (($215) + 4)|0;
     $218 = $217;
     HEAP32[$218>>2] = $214;
     $219 = $199;
     $220 = $219;
     HEAP32[$220>>2] = $205;
     $221 = (($219) + 4)|0;
     $222 = $221;
     HEAP32[$222>>2] = $208;
     $223 = (HEAP32[tempDoublePtr>>2]=$214,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $224 = $223 < $__x$idx$val$i$i;
     if ($224) {
      $225 = $$0;
      $226 = $225;
      $227 = HEAP32[$226>>2]|0;
      $228 = (($225) + 4)|0;
      $229 = $228;
      $230 = HEAP32[$229>>2]|0;
      $231 = $$0;
      $232 = $231;
      HEAP32[$232>>2] = $211;
      $233 = (($231) + 4)|0;
      $234 = $233;
      HEAP32[$234>>2] = $214;
      $235 = $200;
      $236 = $235;
      HEAP32[$236>>2] = $227;
      $237 = (($235) + 4)|0;
      $238 = $237;
      HEAP32[$238>>2] = $230;
     }
    }
   }
  } while(0);
  $289 = (($$0) + 24|0);
  $290 = ($289|0)==($$01$ph|0);
  if ($290) {
   STACKTOP = sp;return;
  } else {
   $__i$02$i = $289;$__j$01$i = $199;
  }
  while(1) {
   $__i$0$idx$i = (($__i$02$i) + 4|0);
   $__i$0$idx$val$i = Math_fround(HEAPF32[$__i$0$idx$i>>2]);
   $__j$0$idx$i = (($__j$01$i) + 4|0);
   $__j$0$idx$val$i = Math_fround(HEAPF32[$__j$0$idx$i>>2]);
   $291 = $__i$0$idx$val$i < $__j$0$idx$val$i;
   if ($291) {
    $292 = $__i$02$i;
    $293 = $292;
    $294 = HEAP32[$293>>2]|0;
    $295 = (($292) + 4)|0;
    $296 = $295;
    $297 = HEAP32[$296>>2]|0;
    $298 = (HEAP32[tempDoublePtr>>2]=$297,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $__j$1$i = $__i$02$i;$__k$0$i = $__j$01$i;
    while(1) {
     $299 = $__k$0$i;
     $300 = $299;
     $301 = HEAP32[$300>>2]|0;
     $302 = (($299) + 4)|0;
     $303 = $302;
     $304 = HEAP32[$303>>2]|0;
     $305 = $__j$1$i;
     $306 = $305;
     HEAP32[$306>>2] = $301;
     $307 = (($305) + 4)|0;
     $308 = $307;
     HEAP32[$308>>2] = $304;
     $309 = ($__k$0$i|0)==($$0|0);
     if ($309) {
      break;
     }
     $310 = (($__k$0$i) + -8|0);
     $$idx$i = (($__k$0$i) + -4|0);
     $$idx$val$i = Math_fround(HEAPF32[$$idx$i>>2]);
     $311 = $298 < $$idx$val$i;
     if ($311) {
      $__j$1$i$phi = $__k$0$i;$__k$0$i = $310;$__j$1$i = $__j$1$i$phi;
     } else {
      break;
     }
    }
    $312 = $__k$0$i;
    $313 = $312;
    HEAP32[$313>>2] = $294;
    $314 = (($312) + 4)|0;
    $315 = $314;
    HEAP32[$315>>2] = $297;
   }
   $316 = (($__i$02$i) + 8|0);
   $317 = ($316|0)==($$01$ph|0);
   if ($317) {
    break;
   } else {
    $__j$01$i$phi = $__i$02$i;$__i$02$i = $316;$__j$01$i = $__j$01$i$phi;
   }
  }
  STACKTOP = sp;return;
 }
 else if ((label|0) == 85) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0);
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__r$0 = 0, $__x$idx$i = 0, $__x$idx$val$i = Math_fround(0), $__x$idx2$val$i = Math_fround(0), $__x1$idx$val = Math_fround(0), $__x2$idx$val = Math_fround(0), $__x2$idx2$val = Math_fround(0), $__x3$idx$val = Math_fround(0), $__x3$idx$val$pre = Math_fround(0), $__x3$idx1$val = Math_fround(0), $__x4$idx = 0, $__x4$idx$val = Math_fround(0), $__y$idx$i = 0, $__y$idx$val$i = Math_fround(0), $__y$idx1$val$i = Math_fround(0), $__z$idx$i = 0, $__z$idx$val$i = Math_fround(0), $__z$idx4$val$i = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $__y$idx$i = (($__x2) + 4|0);
 $__y$idx$val$i = Math_fround(HEAPF32[$__y$idx$i>>2]);
 $__x$idx$i = (($__x1) + 4|0);
 $__x$idx$val$i = Math_fround(HEAPF32[$__x$idx$i>>2]);
 $0 = $__y$idx$val$i < $__x$idx$val$i;
 $__z$idx$i = (($__x3) + 4|0);
 $__z$idx$val$i = Math_fround(HEAPF32[$__z$idx$i>>2]);
 $1 = $__z$idx$val$i < $__y$idx$val$i;
 do {
  if ($0) {
   $44 = $__x1;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 4)|0;
   $48 = $47;
   $49 = HEAP32[$48>>2]|0;
   if ($1) {
    $50 = $__x3;
    $51 = $50;
    $52 = HEAP32[$51>>2]|0;
    $53 = (($50) + 4)|0;
    $54 = $53;
    $55 = HEAP32[$54>>2]|0;
    $56 = $__x1;
    $57 = $56;
    HEAP32[$57>>2] = $52;
    $58 = (($56) + 4)|0;
    $59 = $58;
    HEAP32[$59>>2] = $55;
    $60 = $__x3;
    $61 = $60;
    HEAP32[$61>>2] = $46;
    $62 = (($60) + 4)|0;
    $63 = $62;
    HEAP32[$63>>2] = $49;
    $64 = (HEAP32[tempDoublePtr>>2]=$49,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $$0$i = 1;$__x3$idx$val = $64;
    break;
   }
   $65 = $__x2;
   $66 = $65;
   $67 = HEAP32[$66>>2]|0;
   $68 = (($65) + 4)|0;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = $__x1;
   $72 = $71;
   HEAP32[$72>>2] = $67;
   $73 = (($71) + 4)|0;
   $74 = $73;
   HEAP32[$74>>2] = $70;
   $75 = $__x2;
   $76 = $75;
   HEAP32[$76>>2] = $46;
   $77 = (($75) + 4)|0;
   $78 = $77;
   HEAP32[$78>>2] = $49;
   $__z$idx4$val$i = Math_fround(HEAPF32[$__z$idx$i>>2]);
   $79 = (HEAP32[tempDoublePtr>>2]=$49,Math_fround(HEAPF32[tempDoublePtr>>2]));
   $80 = $__z$idx4$val$i < $79;
   if ($80) {
    $81 = $__x3;
    $82 = $81;
    $83 = HEAP32[$82>>2]|0;
    $84 = (($81) + 4)|0;
    $85 = $84;
    $86 = HEAP32[$85>>2]|0;
    $87 = $__x2;
    $88 = $87;
    HEAP32[$88>>2] = $83;
    $89 = (($87) + 4)|0;
    $90 = $89;
    HEAP32[$90>>2] = $86;
    $91 = $__x3;
    $92 = $91;
    HEAP32[$92>>2] = $46;
    $93 = (($91) + 4)|0;
    $94 = $93;
    HEAP32[$94>>2] = $49;
    $$0$i = 2;$__x3$idx$val = $79;
   } else {
    $$0$i = 1;$__x3$idx$val = $__z$idx4$val$i;
   }
  } else {
   if ($1) {
    $2 = $__x2;
    $3 = $2;
    $4 = HEAP32[$3>>2]|0;
    $5 = (($2) + 4)|0;
    $6 = $5;
    $7 = HEAP32[$6>>2]|0;
    $8 = $__x3;
    $9 = $8;
    $10 = HEAP32[$9>>2]|0;
    $11 = (($8) + 4)|0;
    $12 = $11;
    $13 = HEAP32[$12>>2]|0;
    $14 = $__x2;
    $15 = $14;
    HEAP32[$15>>2] = $10;
    $16 = (($14) + 4)|0;
    $17 = $16;
    HEAP32[$17>>2] = $13;
    $18 = $__x3;
    $19 = $18;
    HEAP32[$19>>2] = $4;
    $20 = (($18) + 4)|0;
    $21 = $20;
    HEAP32[$21>>2] = $7;
    $__y$idx1$val$i = Math_fround(HEAPF32[$__y$idx$i>>2]);
    $__x$idx2$val$i = Math_fround(HEAPF32[$__x$idx$i>>2]);
    $22 = $__y$idx1$val$i < $__x$idx2$val$i;
    $23 = (HEAP32[tempDoublePtr>>2]=$7,Math_fround(HEAPF32[tempDoublePtr>>2]));
    if ($22) {
     $24 = $__x1;
     $25 = $24;
     $26 = HEAP32[$25>>2]|0;
     $27 = (($24) + 4)|0;
     $28 = $27;
     $29 = HEAP32[$28>>2]|0;
     $30 = $__x2;
     $31 = $30;
     $32 = HEAP32[$31>>2]|0;
     $33 = (($30) + 4)|0;
     $34 = $33;
     $35 = HEAP32[$34>>2]|0;
     $36 = $__x1;
     $37 = $36;
     HEAP32[$37>>2] = $32;
     $38 = (($36) + 4)|0;
     $39 = $38;
     HEAP32[$39>>2] = $35;
     $40 = $__x2;
     $41 = $40;
     HEAP32[$41>>2] = $26;
     $42 = (($40) + 4)|0;
     $43 = $42;
     HEAP32[$43>>2] = $29;
     $__x3$idx$val$pre = Math_fround(HEAPF32[$__z$idx$i>>2]);
     $$0$i = 2;$__x3$idx$val = $__x3$idx$val$pre;
    } else {
     $$0$i = 1;$__x3$idx$val = $23;
    }
   } else {
    $$0$i = 0;$__x3$idx$val = $__z$idx$val$i;
   }
  }
 } while(0);
 $__x4$idx = (($__x4) + 4|0);
 $__x4$idx$val = Math_fround(HEAPF32[$__x4$idx>>2]);
 $95 = $__x4$idx$val < $__x3$idx$val;
 if (!($95)) {
  $__r$0 = $$0$i;
  STACKTOP = sp;return ($__r$0|0);
 }
 $96 = $__x3;
 $97 = $96;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($96) + 4)|0;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = $__x4;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = (($102) + 4)|0;
 $106 = $105;
 $107 = HEAP32[$106>>2]|0;
 $108 = $__x3;
 $109 = $108;
 HEAP32[$109>>2] = $104;
 $110 = (($108) + 4)|0;
 $111 = $110;
 HEAP32[$111>>2] = $107;
 $112 = $__x4;
 $113 = $112;
 HEAP32[$113>>2] = $98;
 $114 = (($112) + 4)|0;
 $115 = $114;
 HEAP32[$115>>2] = $101;
 $116 = (($$0$i) + 1)|0;
 $__x3$idx1$val = Math_fround(HEAPF32[$__z$idx$i>>2]);
 $__x2$idx$val = Math_fround(HEAPF32[$__y$idx$i>>2]);
 $117 = $__x3$idx1$val < $__x2$idx$val;
 if (!($117)) {
  $__r$0 = $116;
  STACKTOP = sp;return ($__r$0|0);
 }
 $118 = $__x2;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = (($118) + 4)|0;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = $__x3;
 $125 = $124;
 $126 = HEAP32[$125>>2]|0;
 $127 = (($124) + 4)|0;
 $128 = $127;
 $129 = HEAP32[$128>>2]|0;
 $130 = $__x2;
 $131 = $130;
 HEAP32[$131>>2] = $126;
 $132 = (($130) + 4)|0;
 $133 = $132;
 HEAP32[$133>>2] = $129;
 $134 = $__x3;
 $135 = $134;
 HEAP32[$135>>2] = $120;
 $136 = (($134) + 4)|0;
 $137 = $136;
 HEAP32[$137>>2] = $123;
 $138 = (($$0$i) + 2)|0;
 $__x2$idx2$val = Math_fround(HEAPF32[$__y$idx$i>>2]);
 $__x1$idx$val = Math_fround(HEAPF32[$__x$idx$i>>2]);
 $139 = $__x2$idx2$val < $__x1$idx$val;
 if (!($139)) {
  $__r$0 = $138;
  STACKTOP = sp;return ($__r$0|0);
 }
 $140 = $__x1;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $__x2;
 $147 = $146;
 $148 = HEAP32[$147>>2]|0;
 $149 = (($146) + 4)|0;
 $150 = $149;
 $151 = HEAP32[$150>>2]|0;
 $152 = $__x1;
 $153 = $152;
 HEAP32[$153>>2] = $148;
 $154 = (($152) + 4)|0;
 $155 = $154;
 HEAP32[$155>>2] = $151;
 $156 = $__x2;
 $157 = $156;
 HEAP32[$157>>2] = $142;
 $158 = (($156) + 4)|0;
 $159 = $158;
 HEAP32[$159>>2] = $145;
 $160 = (($$0$i) + 3)|0;
 $__r$0 = $160;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEbT0_S7_T_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0 = 0, $$idx = 0, $$idx$val = Math_fround(0), $$idx1 = 0, $$idx1$val = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = Math_fround(0), $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__count$015 = 0, $__count$1 = 0, $__first$idx = 0, $__first$idx$val = Math_fround(0), $__i$0$idx = 0, $__i$0$idx$val = Math_fround(0), $__i$016 = 0, $__j$0$idx = 0, $__j$0$idx$val = Math_fround(0), $__j$014 = 0, $__j$014$phi = 0;
 var $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__x$idx$i = 0, $__x$idx$i4 = 0, $__x$idx$val$i = Math_fround(0), $__x$idx$val$i5 = Math_fround(0), $__x$idx2$val$i9 = Math_fround(0), $__x1$idx$i = 0, $__x1$idx$val$i = Math_fround(0), $__x2$idx$i = 0, $__x2$idx$val$i = Math_fround(0), $__x3$idx$i = 0, $__x3$idx$val$i = Math_fround(0), $__x4$idx$i = 0, $__x4$idx$val$i = Math_fround(0), $__x4$idx1$val$i = Math_fround(0), $__x5$idx$i = 0, $__x5$idx$val$i = Math_fround(0), $__y$idx$i = 0;
 var $__y$idx$i2 = 0, $__y$idx$val$i = Math_fround(0), $__y$idx$val$i3 = Math_fround(0), $__y$idx1$val$i8 = Math_fround(0), $__z$idx$i = 0, $__z$idx$i6 = 0, $__z$idx$val$i = Math_fround(0), $__z$idx$val$i7 = Math_fround(0), $__z$idx4$val$i10 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 2:  {
  $$idx = (($__last) + -4|0);
  $$idx$val = Math_fround(HEAPF32[$$idx>>2]);
  $__first$idx = (($__first) + 4|0);
  $__first$idx$val = Math_fround(HEAPF32[$__first$idx>>2]);
  $4 = $$idx$val < $__first$idx$val;
  if (!($4)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $5 = (($__last) + -8|0);
  $6 = $__first;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $5;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $__first;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $5;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $121 = (($__first) + 8|0);
  $122 = (($__first) + 16|0);
  $123 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$121,$122,$123)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $124 = (($__first) + 8|0);
  $125 = (($__first) + 16|0);
  $126 = (($__first) + 24|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN12_GLOBAL__N_19BatchItemES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$124,$125,$126)|0);
  $__x5$idx$i = (($__last) + -4|0);
  $__x5$idx$val$i = Math_fround(HEAPF32[$__x5$idx$i>>2]);
  $__x4$idx$i = (($__first) + 28|0);
  $__x4$idx$val$i = Math_fround(HEAPF32[$__x4$idx$i>>2]);
  $127 = $__x5$idx$val$i < $__x4$idx$val$i;
  if (!($127)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $128 = (($__last) + -8|0);
  $129 = $126;
  $130 = $129;
  $131 = HEAP32[$130>>2]|0;
  $132 = (($129) + 4)|0;
  $133 = $132;
  $134 = HEAP32[$133>>2]|0;
  $135 = $128;
  $136 = $135;
  $137 = HEAP32[$136>>2]|0;
  $138 = (($135) + 4)|0;
  $139 = $138;
  $140 = HEAP32[$139>>2]|0;
  $141 = $126;
  $142 = $141;
  HEAP32[$142>>2] = $137;
  $143 = (($141) + 4)|0;
  $144 = $143;
  HEAP32[$144>>2] = $140;
  $145 = $128;
  $146 = $145;
  HEAP32[$146>>2] = $131;
  $147 = (($145) + 4)|0;
  $148 = $147;
  HEAP32[$148>>2] = $134;
  $__x4$idx1$val$i = Math_fround(HEAPF32[$__x4$idx$i>>2]);
  $__x3$idx$i = (($__first) + 20|0);
  $__x3$idx$val$i = Math_fround(HEAPF32[$__x3$idx$i>>2]);
  $149 = $__x4$idx1$val$i < $__x3$idx$val$i;
  if (!($149)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $150 = $125;
  $151 = $150;
  $152 = HEAP32[$151>>2]|0;
  $153 = (($150) + 4)|0;
  $154 = $153;
  $155 = HEAP32[$154>>2]|0;
  $156 = $126;
  $157 = $156;
  $158 = HEAP32[$157>>2]|0;
  $159 = (($156) + 4)|0;
  $160 = $159;
  $161 = HEAP32[$160>>2]|0;
  $162 = $125;
  $163 = $162;
  HEAP32[$163>>2] = $158;
  $164 = (($162) + 4)|0;
  $165 = $164;
  HEAP32[$165>>2] = $161;
  $166 = $126;
  $167 = $166;
  HEAP32[$167>>2] = $152;
  $168 = (($166) + 4)|0;
  $169 = $168;
  HEAP32[$169>>2] = $155;
  $170 = (HEAP32[tempDoublePtr>>2]=$161,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $__x2$idx$i = (($__first) + 12|0);
  $__x2$idx$val$i = Math_fround(HEAPF32[$__x2$idx$i>>2]);
  $171 = $170 < $__x2$idx$val$i;
  if (!($171)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $172 = $124;
  $173 = $172;
  $174 = HEAP32[$173>>2]|0;
  $175 = (($172) + 4)|0;
  $176 = $175;
  $177 = HEAP32[$176>>2]|0;
  $178 = $124;
  $179 = $178;
  HEAP32[$179>>2] = $158;
  $180 = (($178) + 4)|0;
  $181 = $180;
  HEAP32[$181>>2] = $161;
  $182 = $125;
  $183 = $182;
  HEAP32[$183>>2] = $174;
  $184 = (($182) + 4)|0;
  $185 = $184;
  HEAP32[$185>>2] = $177;
  $__x1$idx$i = (($__first) + 4|0);
  $__x1$idx$val$i = Math_fround(HEAPF32[$__x1$idx$i>>2]);
  $186 = $170 < $__x1$idx$val$i;
  if (!($186)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $187 = $__first;
  $188 = $187;
  $189 = HEAP32[$188>>2]|0;
  $190 = (($187) + 4)|0;
  $191 = $190;
  $192 = HEAP32[$191>>2]|0;
  $193 = $__first;
  $194 = $193;
  HEAP32[$194>>2] = $158;
  $195 = (($193) + 4)|0;
  $196 = $195;
  HEAP32[$196>>2] = $161;
  $197 = $124;
  $198 = $197;
  HEAP32[$198>>2] = $189;
  $199 = (($197) + 4)|0;
  $200 = $199;
  HEAP32[$200>>2] = $192;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $26 = (($__first) + 8|0);
  $27 = (($__last) + -8|0);
  $__y$idx$i2 = (($__first) + 12|0);
  $__y$idx$val$i3 = Math_fround(HEAPF32[$__y$idx$i2>>2]);
  $__x$idx$i4 = (($__first) + 4|0);
  $__x$idx$val$i5 = Math_fround(HEAPF32[$__x$idx$i4>>2]);
  $28 = $__y$idx$val$i3 < $__x$idx$val$i5;
  $__z$idx$i6 = (($__last) + -4|0);
  $__z$idx$val$i7 = Math_fround(HEAPF32[$__z$idx$i6>>2]);
  $29 = $__z$idx$val$i7 < $__y$idx$val$i3;
  if (!($28)) {
   if (!($29)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $30 = $26;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $27;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = (($36) + 4)|0;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = $26;
   $43 = $42;
   HEAP32[$43>>2] = $38;
   $44 = (($42) + 4)|0;
   $45 = $44;
   HEAP32[$45>>2] = $41;
   $46 = $27;
   $47 = $46;
   HEAP32[$47>>2] = $32;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $35;
   $__y$idx1$val$i8 = Math_fround(HEAPF32[$__y$idx$i2>>2]);
   $__x$idx2$val$i9 = Math_fround(HEAPF32[$__x$idx$i4>>2]);
   $50 = $__y$idx1$val$i8 < $__x$idx2$val$i9;
   if (!($50)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $51 = $__first;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($51) + 4)|0;
   $55 = $54;
   $56 = HEAP32[$55>>2]|0;
   $57 = $26;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + 4)|0;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = $__first;
   $64 = $63;
   HEAP32[$64>>2] = $59;
   $65 = (($63) + 4)|0;
   $66 = $65;
   HEAP32[$66>>2] = $62;
   $67 = $26;
   $68 = $67;
   HEAP32[$68>>2] = $53;
   $69 = (($67) + 4)|0;
   $70 = $69;
   HEAP32[$70>>2] = $56;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $71 = $__first;
  $72 = $71;
  $73 = HEAP32[$72>>2]|0;
  $74 = (($71) + 4)|0;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  if ($29) {
   $77 = $27;
   $78 = $77;
   $79 = HEAP32[$78>>2]|0;
   $80 = (($77) + 4)|0;
   $81 = $80;
   $82 = HEAP32[$81>>2]|0;
   $83 = $__first;
   $84 = $83;
   HEAP32[$84>>2] = $79;
   $85 = (($83) + 4)|0;
   $86 = $85;
   HEAP32[$86>>2] = $82;
   $87 = $27;
   $88 = $87;
   HEAP32[$88>>2] = $73;
   $89 = (($87) + 4)|0;
   $90 = $89;
   HEAP32[$90>>2] = $76;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $91 = $26;
  $92 = $91;
  $93 = HEAP32[$92>>2]|0;
  $94 = (($91) + 4)|0;
  $95 = $94;
  $96 = HEAP32[$95>>2]|0;
  $97 = $__first;
  $98 = $97;
  HEAP32[$98>>2] = $93;
  $99 = (($97) + 4)|0;
  $100 = $99;
  HEAP32[$100>>2] = $96;
  $101 = $26;
  $102 = $101;
  HEAP32[$102>>2] = $73;
  $103 = (($101) + 4)|0;
  $104 = $103;
  HEAP32[$104>>2] = $76;
  $__z$idx4$val$i10 = Math_fround(HEAPF32[$__z$idx$i6>>2]);
  $105 = (HEAP32[tempDoublePtr>>2]=$76,Math_fround(HEAPF32[tempDoublePtr>>2]));
  $106 = $__z$idx4$val$i10 < $105;
  if (!($106)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $107 = $27;
  $108 = $107;
  $109 = HEAP32[$108>>2]|0;
  $110 = (($107) + 4)|0;
  $111 = $110;
  $112 = HEAP32[$111>>2]|0;
  $113 = $26;
  $114 = $113;
  HEAP32[$114>>2] = $109;
  $115 = (($113) + 4)|0;
  $116 = $115;
  HEAP32[$116>>2] = $112;
  $117 = $27;
  $118 = $117;
  HEAP32[$118>>2] = $73;
  $119 = (($117) + 4)|0;
  $120 = $119;
  HEAP32[$120>>2] = $76;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $201 = (($__first) + 16|0);
  $202 = (($__first) + 8|0);
  $__y$idx$i = (($__first) + 12|0);
  $__y$idx$val$i = Math_fround(HEAPF32[$__y$idx$i>>2]);
  $__x$idx$i = (($__first) + 4|0);
  $__x$idx$val$i = Math_fround(HEAPF32[$__x$idx$i>>2]);
  $203 = $__y$idx$val$i < $__x$idx$val$i;
  $__z$idx$i = (($__first) + 20|0);
  $__z$idx$val$i = Math_fround(HEAPF32[$__z$idx$i>>2]);
  $204 = $__z$idx$val$i < $__y$idx$val$i;
  do {
   if ($203) {
    $241 = $__first;
    $242 = $241;
    $243 = HEAP32[$242>>2]|0;
    $244 = (($241) + 4)|0;
    $245 = $244;
    $246 = HEAP32[$245>>2]|0;
    if ($204) {
     $247 = $201;
     $248 = $247;
     $249 = HEAP32[$248>>2]|0;
     $250 = (($247) + 4)|0;
     $251 = $250;
     $252 = HEAP32[$251>>2]|0;
     $253 = $__first;
     $254 = $253;
     HEAP32[$254>>2] = $249;
     $255 = (($253) + 4)|0;
     $256 = $255;
     HEAP32[$256>>2] = $252;
     $257 = $201;
     $258 = $257;
     HEAP32[$258>>2] = $243;
     $259 = (($257) + 4)|0;
     $260 = $259;
     HEAP32[$260>>2] = $246;
     break;
    }
    $261 = $202;
    $262 = $261;
    $263 = HEAP32[$262>>2]|0;
    $264 = (($261) + 4)|0;
    $265 = $264;
    $266 = HEAP32[$265>>2]|0;
    $267 = $__first;
    $268 = $267;
    HEAP32[$268>>2] = $263;
    $269 = (($267) + 4)|0;
    $270 = $269;
    HEAP32[$270>>2] = $266;
    $271 = $202;
    $272 = $271;
    HEAP32[$272>>2] = $243;
    $273 = (($271) + 4)|0;
    $274 = $273;
    HEAP32[$274>>2] = $246;
    $275 = (HEAP32[tempDoublePtr>>2]=$246,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $276 = $__z$idx$val$i < $275;
    if ($276) {
     $277 = $201;
     $278 = $277;
     $279 = HEAP32[$278>>2]|0;
     $280 = (($277) + 4)|0;
     $281 = $280;
     $282 = HEAP32[$281>>2]|0;
     $283 = $202;
     $284 = $283;
     HEAP32[$284>>2] = $279;
     $285 = (($283) + 4)|0;
     $286 = $285;
     HEAP32[$286>>2] = $282;
     $287 = $201;
     $288 = $287;
     HEAP32[$288>>2] = $243;
     $289 = (($287) + 4)|0;
     $290 = $289;
     HEAP32[$290>>2] = $246;
    }
   } else {
    if ($204) {
     $205 = $202;
     $206 = $205;
     $207 = HEAP32[$206>>2]|0;
     $208 = (($205) + 4)|0;
     $209 = $208;
     $210 = HEAP32[$209>>2]|0;
     $211 = $201;
     $212 = $211;
     $213 = HEAP32[$212>>2]|0;
     $214 = (($211) + 4)|0;
     $215 = $214;
     $216 = HEAP32[$215>>2]|0;
     $217 = $202;
     $218 = $217;
     HEAP32[$218>>2] = $213;
     $219 = (($217) + 4)|0;
     $220 = $219;
     HEAP32[$220>>2] = $216;
     $221 = $201;
     $222 = $221;
     HEAP32[$222>>2] = $207;
     $223 = (($221) + 4)|0;
     $224 = $223;
     HEAP32[$224>>2] = $210;
     $225 = (HEAP32[tempDoublePtr>>2]=$216,Math_fround(HEAPF32[tempDoublePtr>>2]));
     $226 = $225 < $__x$idx$val$i;
     if ($226) {
      $227 = $__first;
      $228 = $227;
      $229 = HEAP32[$228>>2]|0;
      $230 = (($227) + 4)|0;
      $231 = $230;
      $232 = HEAP32[$231>>2]|0;
      $233 = $__first;
      $234 = $233;
      HEAP32[$234>>2] = $213;
      $235 = (($233) + 4)|0;
      $236 = $235;
      HEAP32[$236>>2] = $216;
      $237 = $202;
      $238 = $237;
      HEAP32[$238>>2] = $229;
      $239 = (($237) + 4)|0;
      $240 = $239;
      HEAP32[$240>>2] = $232;
     }
    }
   }
  } while(0);
  $291 = (($__first) + 24|0);
  $292 = ($291|0)==($__last|0);
  if ($292) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$015 = 0;$__i$016 = $291;$__j$014 = $201;
  }
  while(1) {
   $__i$0$idx = (($__i$016) + 4|0);
   $__i$0$idx$val = Math_fround(HEAPF32[$__i$0$idx>>2]);
   $__j$0$idx = (($__j$014) + 4|0);
   $__j$0$idx$val = Math_fround(HEAPF32[$__j$0$idx>>2]);
   $293 = $__i$0$idx$val < $__j$0$idx$val;
   if ($293) {
    $294 = $__i$016;
    $295 = $294;
    $296 = HEAP32[$295>>2]|0;
    $297 = (($294) + 4)|0;
    $298 = $297;
    $299 = HEAP32[$298>>2]|0;
    $300 = (HEAP32[tempDoublePtr>>2]=$299,Math_fround(HEAPF32[tempDoublePtr>>2]));
    $__j$1 = $__i$016;$__k$0 = $__j$014;
    while(1) {
     $301 = $__k$0;
     $302 = $301;
     $303 = HEAP32[$302>>2]|0;
     $304 = (($301) + 4)|0;
     $305 = $304;
     $306 = HEAP32[$305>>2]|0;
     $307 = $__j$1;
     $308 = $307;
     HEAP32[$308>>2] = $303;
     $309 = (($307) + 4)|0;
     $310 = $309;
     HEAP32[$310>>2] = $306;
     $311 = ($__k$0|0)==($__first|0);
     if ($311) {
      break;
     }
     $312 = (($__k$0) + -8|0);
     $$idx1 = (($__k$0) + -4|0);
     $$idx1$val = Math_fround(HEAPF32[$$idx1>>2]);
     $313 = $300 < $$idx1$val;
     if ($313) {
      $__j$1$phi = $__k$0;$__k$0 = $312;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $314 = $__k$0;
    $315 = $314;
    HEAP32[$315>>2] = $296;
    $316 = (($314) + 4)|0;
    $317 = $316;
    HEAP32[$317>>2] = $299;
    $318 = (($__count$015) + 1)|0;
    $319 = ($318|0)==(8);
    if ($319) {
     break;
    } else {
     $__count$1 = $318;
    }
   } else {
    $__count$1 = $__count$015;
   }
   $322 = (($__i$016) + 8|0);
   $323 = ($322|0)==($__last|0);
   if ($323) {
    $$0 = 1;
    label = 34;
    break;
   } else {
    $__j$014$phi = $__i$016;$__count$015 = $__count$1;$__i$016 = $322;$__j$014 = $__j$014$phi;
   }
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  $320 = (($__i$016) + 8|0);
  $321 = ($320|0)==($__last|0);
  $$0 = $321;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN22ForwardLinearAllocator8allocateEjj($this,$size,$alignment) {
 $this = $this|0;
 $size = $size|0;
 $alignment = $alignment|0;
 var $$byval_copy3 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $block$0 = 0, $size$$i = 0, $size$$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
  HEAP32[$0>>2] = 65;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $5 = (__Z15malloc_internaljj10MemLabelIdiPKci(24,16,$$byval_copy3,0,803264,79)|0);
  $6 = (($5) + 8|0);
  ;HEAP32[$6+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$1+12>>2]|0;
  $7 = HEAP32[$this>>2]|0;
  $8 = (($7) + 4|0);
  HEAP32[$8>>2] = $5;
  $9 = HEAP32[$this>>2]|0;
  HEAP32[$5>>2] = $9;
  HEAP32[$this>>2] = $5;
  $10 = (($5) + 4|0);
  HEAP32[$10>>2] = $this;
  $11 = HEAP32[$2>>2]|0;
  $12 = (($11) + 1)|0;
  HEAP32[$2>>2] = $12;
  $13 = (($this) + 12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14>>>0)<($size>>>0);
  $size$$i1 = $15 ? $size : $14;
  $16 = HEAP32[$this>>2]|0;
  $17 = (($this) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) + 20|0);
  HEAP32[$19>>2] = $18;
  HEAP32[$0>>2] = $18;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($size$$i1,16,$$byval_copy3,0,803264,34)|0);
  $21 = (($16) + 8|0);
  HEAP32[$21>>2] = $20;
  $22 = (($16) + 12|0);
  HEAP32[$22>>2] = $20;
  $23 = (($16) + 16|0);
  HEAP32[$23>>2] = $size$$i1;
  $$pre$phiZ2D = $this;
 } else {
  $$pre$phiZ2D = $this;
 }
 $24 = HEAP32[$$pre$phiZ2D>>2]|0;
 $25 = (($24) + 8|0);
 $26 = (($24) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27;
 $29 = (($28) + -1)|0;
 $30 = (($alignment) + -1)|0;
 $31 = $29 | $30;
 $32 = (1 - ($28))|0;
 $33 = (($31) + ($32))|0;
 $34 = (($33) + ($size))|0;
 $35 = (($24) + 16|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$25>>2]|0;
 $38 = $37;
 $39 = (($36) - ($28))|0;
 $40 = (($39) + ($38))|0;
 $41 = ($34>>>0)>($40>>>0);
 if (!($41)) {
  $block$0 = $25;
  $63 = (($block$0) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($64) + ($34)|0);
  HEAP32[$63>>2] = $65;
  $66 = $64;
  $67 = (($66) + ($33))|0;
  $68 = $67;
  STACKTOP = sp;return ($68|0);
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAP32[$0>>2] = 65;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $42 = (__Z15malloc_internaljj10MemLabelIdiPKci(24,16,$$byval_copy3,0,803264,79)|0);
 $43 = (($42) + 8|0);
 ;HEAP32[$43+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$1+12>>2]|0;
 $44 = HEAP32[$$pre$phiZ2D>>2]|0;
 $45 = (($44) + 4|0);
 HEAP32[$45>>2] = $42;
 $46 = HEAP32[$$pre$phiZ2D>>2]|0;
 HEAP32[$42>>2] = $46;
 HEAP32[$$pre$phiZ2D>>2] = $42;
 $47 = (($42) + 4|0);
 HEAP32[$47>>2] = $this;
 $48 = HEAP32[$2>>2]|0;
 $49 = (($48) + 1)|0;
 HEAP32[$2>>2] = $49;
 $50 = (($this) + 12|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51>>>0)<($size>>>0);
 $size$$i = $52 ? $size : $51;
 $53 = HEAP32[$$pre$phiZ2D>>2]|0;
 $54 = (($this) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($53) + 20|0);
 HEAP32[$56>>2] = $55;
 HEAP32[$0>>2] = $55;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 $57 = (__Z15malloc_internaljj10MemLabelIdiPKci($size$$i,16,$$byval_copy3,0,803264,34)|0);
 $58 = (($53) + 8|0);
 HEAP32[$58>>2] = $57;
 $59 = (($53) + 12|0);
 HEAP32[$59>>2] = $57;
 $60 = (($53) + 16|0);
 HEAP32[$60>>2] = $size$$i;
 $61 = HEAP32[$$pre$phiZ2D>>2]|0;
 $62 = (($61) + 8|0);
 $block$0 = $62;
 $63 = (($block$0) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + ($34)|0);
 HEAP32[$63>>2] = $65;
 $66 = $64;
 $67 = (($66) + ($33))|0;
 $68 = $67;
 STACKTOP = sp;return ($68|0);
}
function __ZN19LinearAllocatorBase5purgeEb($this,$releaseAllBlocks) {
 $this = $this|0;
 $releaseAllBlocks = $releaseAllBlocks|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 if ($releaseAllBlocks) {
  $9 = $5;
 } else {
  $6 = (($5) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $9 = $7;
 }
 $8 = ($9|0)==($this|0);
 L7: do {
  if (!($8)) {
   $11 = $9;
   while(1) {
    $10 = (($11) + 8|0);
    $12 = HEAP32[$10>>2]|0;
    $13 = (($11) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$0>>2] = $14;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($12,$$byval_copy1);
    $15 = (($11) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($this|0);
    if ($17) {
     break;
    } else {
     $11 = $16;
    }
   }
   if (!($8)) {
    $18 = HEAP32[$this>>2]|0;
    $19 = (($18) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$9>>2]|0;
    $22 = (($21) + 4|0);
    HEAP32[$22>>2] = $20;
    $23 = HEAP32[$9>>2]|0;
    $24 = HEAP32[$19>>2]|0;
    HEAP32[$24>>2] = $23;
    $26 = $9;
    while(1) {
     $25 = ($26|0)==($this|0);
     if ($25) {
      break L7;
     }
     $27 = (($26) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = HEAP32[$1>>2]|0;
     $30 = (($29) + -1)|0;
     HEAP32[$1>>2] = $30;
     HEAP32[$0>>2] = 65;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($26|0),($$byval_copy1|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     } else {
      $26 = $28;
     }
    }
    $33 = ___cxa_find_matching_catch()|0;
    $34 = tempRet0;
    ___cxa_call_unexpected(($33|0));
    // unreachable;
   }
  }
 } while(0);
 if ($releaseAllBlocks) {
  STACKTOP = sp;return;
 }
 $35 = HEAP32[$this>>2]|0;
 $36 = (($35) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + 12|0);
 HEAP32[$38>>2] = $37;
 STACKTOP = sp;return;
}
function __ZN21TreeBinaryTreeBuilder15CalculateBoundsERKNSt3__16vectorI12TreeInstanceNS0_9allocatorIS2_EEEERK13dynamic_arrayIjLj4EERKNS1_IN12TreeDatabase9PrototypeENS3_ISD_EEEERK8Vector3fSK_($agg$result,$allInstances,$instances,$prototypes,$position,$scale) {
 $agg$result = $agg$result|0;
 $allInstances = $allInstances|0;
 $instances = $instances|0;
 $prototypes = $prototypes|0;
 $position = $position|0;
 $scale = $scale|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0;
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = 0, $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = Math_fround(0), $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $i$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = HEAP32[$instances>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$allInstances>>2]|0;
 $5 = (($4) + (($3*40)|0)|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(HEAPF32[$scale>>2]);
 $8 = Math_fround($6 * $7);
 $9 = ((($4) + (($3*40)|0)|0) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($scale) + 4|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = ((($4) + (($3*40)|0)|0) + 8|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($scale) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 * $17);
 $19 = Math_fround(HEAPF32[$position>>2]);
 $20 = Math_fround($8 + $19);
 $21 = (($position) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($13 + $22);
 $24 = (($position) + 8|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($18 + $25);
 $27 = (($agg$result) + 12|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 HEAPF32[$agg$result>>2] = $20;
 $28 = (($agg$result) + 4|0);
 HEAPF32[$28>>2] = $23;
 $29 = (($agg$result) + 8|0);
 HEAPF32[$29>>2] = $26;
 ;HEAP32[$27+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[616680+8>>2]|0;
 $30 = (($instances) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $33 = (($0) + 4|0);
 $34 = (($0) + 8|0);
 $35 = (($1) + 4|0);
 $36 = (($1) + 8|0);
 $i$04 = 0;
 while(1) {
  $37 = HEAP32[$instances>>2]|0;
  $38 = (($37) + ($i$04<<2)|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = HEAP32[$allInstances>>2]|0;
  $41 = (($40) + (($39*40)|0)|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = Math_fround(HEAPF32[$scale>>2]);
  $44 = Math_fround($42 * $43);
  $45 = ((($40) + (($39*40)|0)|0) + 4|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = Math_fround(HEAPF32[$11>>2]);
  $48 = Math_fround($46 * $47);
  $49 = ((($40) + (($39*40)|0)|0) + 8|0);
  $50 = Math_fround(HEAPF32[$49>>2]);
  $51 = Math_fround(HEAPF32[$16>>2]);
  $52 = Math_fround($50 * $51);
  $53 = Math_fround(HEAPF32[$position>>2]);
  $54 = Math_fround($44 + $53);
  $55 = Math_fround(HEAPF32[$21>>2]);
  $56 = Math_fround($48 + $55);
  $57 = Math_fround(HEAPF32[$24>>2]);
  $58 = Math_fround($52 + $57);
  $59 = ((($40) + (($39*40)|0)|0) + 12|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = ((($40) + (($39*40)|0)|0) + 16|0);
  $62 = Math_fround(HEAPF32[$61>>2]);
  $63 = ((($40) + (($39*40)|0)|0) + 32|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = HEAP32[$prototypes>>2]|0;
  $66 = ((($65) + ($64<<7)|0) + 100|0);
  $67 = Math_fround(HEAPF32[$66>>2]);
  $68 = ((($65) + ($64<<7)|0) + 112|0);
  $69 = Math_fround(HEAPF32[$68>>2]);
  $70 = Math_fround($67 - $69);
  $71 = ((($65) + ($64<<7)|0) + 104|0);
  $72 = Math_fround(HEAPF32[$71>>2]);
  $73 = ((($65) + ($64<<7)|0) + 116|0);
  $74 = Math_fround(HEAPF32[$73>>2]);
  $75 = Math_fround($72 - $74);
  $76 = ((($65) + ($64<<7)|0) + 108|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = ((($65) + ($64<<7)|0) + 120|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($77 - $79);
  $81 = Math_fround($60 * $70);
  $82 = Math_fround($62 * $75);
  $83 = Math_fround($60 * $80);
  $84 = Math_fround($54 + $81);
  $85 = Math_fround($56 + $82);
  $86 = Math_fround($58 + $83);
  HEAPF32[$0>>2] = $84;
  HEAPF32[$33>>2] = $85;
  HEAPF32[$34>>2] = $86;
  __ZN4AABB11EncapsulateERK8Vector3f($agg$result,$0);
  $87 = Math_fround(HEAPF32[$66>>2]);
  $88 = Math_fround(HEAPF32[$68>>2]);
  $89 = Math_fround($87 + $88);
  $90 = Math_fround(HEAPF32[$71>>2]);
  $91 = Math_fround(HEAPF32[$73>>2]);
  $92 = Math_fround($90 + $91);
  $93 = Math_fround(HEAPF32[$76>>2]);
  $94 = Math_fround(HEAPF32[$78>>2]);
  $95 = Math_fround($93 + $94);
  $96 = Math_fround($60 * $89);
  $97 = Math_fround($62 * $92);
  $98 = Math_fround($60 * $95);
  $99 = Math_fround($54 + $96);
  $100 = Math_fround($56 + $97);
  $101 = Math_fround($58 + $98);
  HEAPF32[$1>>2] = $99;
  HEAPF32[$35>>2] = $100;
  HEAPF32[$36>>2] = $101;
  __ZN4AABB11EncapsulateERK8Vector3f($agg$result,$1);
  $102 = (($i$04) + 1)|0;
  $103 = HEAP32[$30>>2]|0;
  $104 = ($102>>>0)<($103>>>0);
  if ($104) {
   $i$04 = $102;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13dynamic_arrayIiLj4EEaSERKS0_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$byval_copy1 = 0, $$idx = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = ($other|0)==($this|0);
 if ($1) {
  STACKTOP = sp;return ($this|0);
 }
 $2 = HEAP32[$other>>2]|0;
 $3 = (($other) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $$idx = $4 << 2;
 $5 = $$idx >> 2;
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2147483647;
 $10 = ($9>>>0)<($5>>>0);
 do {
  if ($10) {
   $11 = ($8|0)>(-1);
   if ($11) {
    HEAP32[$7>>2] = $5;
    $12 = HEAP32[$this>>2]|0;
    $13 = (($this) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$0>>2] = $14;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $15 = (__Z16realloc_internalPvji10MemLabelIdiPKci($12,$$idx,4,$$byval_copy1,0,803264,370)|0);
    HEAP32[$this>>2] = $15;
    $24 = $15;
    break;
   } else {
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx,4,$$byval_copy1,0,803264,352)|0);
    $19 = HEAP32[$this>>2]|0;
    $20 = HEAP32[$6>>2]|0;
    $21 = $20 << 2;
    _memcpy(($18|0),($19|0),($21|0))|0;
    HEAP32[$7>>2] = $5;
    HEAP32[$this>>2] = $18;
    $24 = $18;
    break;
   }
  } else {
   $$pre$i = HEAP32[$this>>2]|0;
   $24 = $$pre$i;
  }
 } while(0);
 $22 = HEAP32[$6>>2]|0;
 $23 = $22 << 2;
 _memcpy(($24|0),($2|0),($23|0))|0;
 STACKTOP = sp;return ($this|0);
}
function __ZN21TreeBinaryTreeBuilder27CalculateSupportedInstancesERKNSt3__16vectorI12TreeInstanceNS0_9allocatorIS2_EEEERK13dynamic_arrayIjLj4EERKNS1_IN12TreeDatabase9PrototypeENS3_ISD_EEEE($agg$result,$allInstances,$instances,$prototypes) {
 $agg$result = $agg$result|0;
 $allInstances = $allInstances|0;
 $instances = $instances|0;
 $prototypes = $prototypes|0;
 var $$0 = 0, $$01 = 0, $$01$i$i$i = 0, $$1 = 0, $$12 = 0, $$byval_copy14 = 0, $$idx = 0, $$lcssa = 0, $$lcssa30 = 0, $$lcssa32 = 0, $$ph = 0, $$ph27 = 0, $$ph28 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$038 = 0, $i1$034 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy14 = sp + 32|0;
 $0 = sp + 28|0;
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 12|0;
 $8 = (($prototypes) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$prototypes>>2]|0;
 $11 = $9;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 7;
 $15 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $15;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
 $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($14,1,$$byval_copy14,0,803264,352)|0);
 $17 = (($16) + ($14)|0);
 $18 = ($14|0)==(0);
 if (!($18)) {
  $$01$i$i$i = $16;
  while(1) {
   $19 = ($$01$i$i$i|0)==(0|0);
   if (!($19)) {
    HEAP8[$$01$i$i$i>>0] = 0;
   }
   $20 = (($$01$i$i$i) + 1|0);
   $21 = ($20|0)==($17|0);
   if ($21) {
    break;
   } else {
    $$01$i$i$i = $20;
   }
  }
 }
 $22 = (($instances) + 8|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $25 = HEAP32[$instances>>2]|0;
  $26 = HEAP32[$allInstances>>2]|0;
  $i$038 = 0;
  while(1) {
   $27 = (($25) + ($i$038<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ((($26) + (($28*40)|0)|0) + 32|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($16) + ($30)|0);
   HEAP8[$31>>0] = 1;
   $32 = (($i$038) + 1)|0;
   $33 = ($32>>>0)<($23>>>0);
   if ($33) {
    $i$038 = $32;
   } else {
    break;
   }
  }
 }
 $36 = HEAP32[628512>>2]|0;
 $37 = HEAP32[$8>>2]|0;
 $38 = HEAP32[$prototypes>>2]|0;
 $39 = $37;
 $40 = $38;
 $41 = (($39) - ($40))|0;
 $42 = $41 >> 7;
 $43 = ($42|0)==(0);
 do {
  if ($43) {
   $$ph = 0;$$ph27 = 0;
   label = 12;
  } else {
   $44 = $41 >> 5;
   HEAP32[$2>>2] = $36;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
   $45 = (invoke_iiiiiiii(108,(0|0),($44|0),4,($$byval_copy14|0),0,(803264|0),370)|0);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    $112 = $42;$113 = 0;$lpad$phi$index = $75;$lpad$phi$index2 = $76;
    label = 25;
    break;
   } else {
    $$ph = $42;$$ph27 = $45;
    label = 12;
    break;
   }
  }
 } while(0);
 L18: do {
  if ((label|0) == 12) {
   L20: do {
    if ($18) {
     $$lcssa = $$ph;$$lcssa30 = 0;$$lcssa32 = $$ph27;
    } else {
     $52 = 0;$54 = $$ph;$62 = $$ph27;$i1$034 = 0;
     L22: while(1) {
      $48 = (($16) + ($i1$034)|0);
      $49 = HEAP8[$48>>0]|0;
      $50 = ($49<<24>>24)==(0);
      if ($50) {
       $108 = $54;$109 = $52;$110 = $62;
      } else {
       $51 = (($52) + 1)|0;
       $53 = $54 & 2147483647;
       $55 = ($51>>>0)>($53>>>0);
       do {
        if ($55) {
         $56 = $54 << 1;
         $57 = ($56|0)==(0);
         $58 = $57 ? 1 : $56;
         $59 = ($53>>>0)<($58>>>0);
         if ($59) {
          $60 = ($54|0)>(-1);
          if ($60) {
           $61 = $58 << 2;
           HEAP32[$0>>2] = $36;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
           $63 = (invoke_iiiiiiii(108,($62|0),($61|0),4,($$byval_copy14|0),0,(803264|0),370)|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            $$ph28 = $58;
            break L22;
           }
           $111 = $58;$72 = $63;
           break;
          } else {
           $66 = $58 << 2;
           HEAP32[$1>>2] = $36;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
           $67 = (invoke_iiiiiii(102,($66|0),4,($$byval_copy14|0),0,(803264|0),352)|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            $$ph28 = $54;
            break L22;
           }
           $70 = $51 << 2;
           _memcpy(($67|0),($62|0),($70|0))|0;
           $111 = $58;$72 = $67;
           break;
          }
         } else {
          $111 = $54;$72 = $62;
         }
        } else {
         $111 = $54;$72 = $62;
        }
       } while(0);
       $71 = (($72) + ($52<<2)|0);
       HEAP32[$71>>2] = $i1$034;
       $108 = $111;$109 = $51;$110 = $72;
      }
      $77 = (($i1$034) + 1)|0;
      $78 = ($77>>>0)<($14>>>0);
      if ($78) {
       $52 = $109;$54 = $108;$62 = $110;$i1$034 = $77;
      } else {
       $$lcssa = $108;$$lcssa30 = $109;$$lcssa32 = $110;
       break L20;
      }
     }
     $73 = ___cxa_find_matching_catch()|0;
     $74 = tempRet0;
     $112 = $$ph28;$113 = $62;$lpad$phi$index = $73;$lpad$phi$index2 = $74;
     label = 25;
     break L18;
    }
   } while(0);
   $79 = HEAP32[628440>>2]|0;
   HEAP32[$agg$result>>2] = 0;
   $80 = (($agg$result) + 4|0);
   HEAP32[$80>>2] = $79;
   $81 = (($agg$result) + 8|0);
   $82 = (($agg$result) + 12|0);
   HEAP32[$82>>2] = 0;
   $$idx = $$lcssa30 << 2;
   $83 = $$idx >> 2;
   HEAP32[$81>>2] = $83;
   $84 = ($83|0)==(0);
   do {
    if ($84) {
     $93 = 0;
    } else {
     HEAP32[$82>>2] = $83;
     HEAP32[$3>>2] = $79;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
     $85 = (invoke_iiiiiiii(108,(0|0),($$idx|0),4,($$byval_copy14|0),0,(803264|0),370)|0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if (!($87)) {
      HEAP32[$agg$result>>2] = $85;
      $93 = $85;
      break;
     }
     $88 = ___cxa_find_matching_catch()|0;
     $89 = tempRet0;
     $90 = ($$idx|0)>(-4);
     if (!($90)) {
      $$0 = $89;$$01 = $88;$100 = $$lcssa32;$99 = $$lcssa;
      label = 38;
      break L18;
     }
     HEAP32[$4>>2] = $79;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$4+0>>2]|0;
     invoke_vii(2591,(0|0),($$byval_copy14|0));
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      $106 = ___cxa_find_matching_catch(0|0)|0;
      $107 = tempRet0;
      ___clang_call_terminate($106);
      // unreachable;
     } else {
      HEAP32[$agg$result>>2] = 0;
      $$0 = $89;$$01 = $88;$100 = $$lcssa32;$99 = $$lcssa;
      label = 38;
      break L18;
     }
    }
   } while(0);
   _memcpy(($93|0),($$lcssa32|0),($$idx|0))|0;
   $94 = ($$lcssa|0)>(-1);
   if ($94) {
    HEAP32[$5>>2] = $36;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($$lcssa32|0),($$byval_copy14|0));
    $95 = __THREW__; __THREW__ = 0;
    $96 = $95&1;
    if ($96) {
     $34 = ___cxa_find_matching_catch()|0;
     $35 = tempRet0;
     $$1 = $35;$$12 = $34;
     break;
    }
   }
   $97 = ($13|0)>(-128);
   if (!($97)) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = $15;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($16,$$byval_copy14);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 25) {
  $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;$100 = $113;$99 = $112;
  label = 38;
 }
 if ((label|0) == 38) {
  $98 = ($99|0)>(-1);
  if ($98) {
   HEAP32[$6>>2] = $36;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$6+0>>2]|0;
   invoke_vii(2591,($100|0),($$byval_copy14|0));
   $101 = __THREW__; __THREW__ = 0;
   $102 = $101&1;
   if ($102) {
    $106 = ___cxa_find_matching_catch(0|0)|0;
    $107 = tempRet0;
    ___clang_call_terminate($106);
    // unreachable;
   } else {
    $$1 = $$0;$$12 = $$01;
   }
  } else {
   $$1 = $$0;$$12 = $$01;
  }
 }
 $103 = ($13|0)>(-128);
 if (!($103)) {
  ___resumeException($$12|0);
  // unreachable;
 }
 HEAP32[$7>>2] = $15;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$7+0>>2]|0;
 invoke_vii(2591,($16|0),($$byval_copy14|0));
 $104 = __THREW__; __THREW__ = 0;
 $105 = $104&1;
 if ($105) {
  $106 = ___cxa_find_matching_catch(0|0)|0;
  $107 = tempRet0;
  ___clang_call_terminate($106);
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZN22ForwardLinearAllocatorD2Ev($this) {
 $this = $this|0;
 var $$byval_copy3 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__f$0$i$i$i$i$i = 0, $__f$0$i$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($this|0);
 L4: do {
  if (!($7)) {
   $9 = $6;
   while(1) {
    $8 = (($9) + 8|0);
    $10 = HEAP32[$8>>2]|0;
    $11 = (($9) + 20|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$0>>2] = $12;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($10|0),($$byval_copy3|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    $15 = (($9) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($this|0);
    if ($17) {
     label = 6;
     break;
    } else {
     $9 = $16;
    }
   }
   if ((label|0) == 6) {
    $18 = HEAP32[$this>>2]|0;
    $19 = (($18) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$6>>2]|0;
    $22 = (($21) + 4|0);
    HEAP32[$22>>2] = $20;
    $23 = HEAP32[$6>>2]|0;
    $24 = HEAP32[$19>>2]|0;
    HEAP32[$24>>2] = $23;
    $26 = $6;
    while(1) {
     $25 = ($26|0)==($this|0);
     if ($25) {
      break L4;
     }
     $27 = (($26) + 4|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = HEAP32[$2>>2]|0;
     $30 = (($29) + -1)|0;
     HEAP32[$2>>2] = $30;
     HEAP32[$0>>2] = 65;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($26|0),($$byval_copy3|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     } else {
      $26 = $28;
     }
    }
    $33 = ___cxa_find_matching_catch()|0;
    $34 = tempRet0;
    ___cxa_call_unexpected(($33|0));
    // unreachable;
   }
   $51 = ___cxa_find_matching_catch()|0;
   $52 = tempRet0;
   $53 = HEAP32[$2>>2]|0;
   $54 = ($53|0)==(0);
   if ($54) {
    ___resumeException($51|0);
    // unreachable;
   }
   $55 = HEAP32[$5>>2]|0;
   $56 = HEAP32[$this>>2]|0;
   $57 = (($56) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = HEAP32[$55>>2]|0;
   $60 = (($59) + 4|0);
   HEAP32[$60>>2] = $58;
   $61 = HEAP32[$55>>2]|0;
   $62 = HEAP32[$57>>2]|0;
   HEAP32[$62>>2] = $61;
   HEAP32[$2>>2] = 0;
   $__f$0$i$i$i$i$i1 = $55;
   while(1) {
    $63 = ($__f$0$i$i$i$i$i1|0)==($this|0);
    if ($63) {
     label = 21;
     break;
    }
    $64 = (($__f$0$i$i$i$i$i1) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    HEAP32[$1>>2] = 65;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($__f$0$i$i$i$i$i1|0),($$byval_copy3|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     label = 20;
     break;
    } else {
     $__f$0$i$i$i$i$i1 = $65;
    }
   }
   if ((label|0) == 20) {
    $68 = ___cxa_find_matching_catch()|0;
    $69 = tempRet0;
    ___cxa_call_unexpected(($68|0));
    // unreachable;
   }
   else if ((label|0) == 21) {
    ___resumeException($51|0);
    // unreachable;
   }
  }
 } while(0);
 $$pr = HEAP32[$2>>2]|0;
 $35 = ($$pr|0)==(0);
 if ($35) {
  STACKTOP = sp;return;
 }
 $36 = HEAP32[$5>>2]|0;
 $37 = HEAP32[$this>>2]|0;
 $38 = (($37) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = HEAP32[$36>>2]|0;
 $41 = (($40) + 4|0);
 HEAP32[$41>>2] = $39;
 $42 = HEAP32[$36>>2]|0;
 $43 = HEAP32[$38>>2]|0;
 HEAP32[$43>>2] = $42;
 HEAP32[$2>>2] = 0;
 $__f$0$i$i$i$i$i = $36;
 while(1) {
  $44 = ($__f$0$i$i$i$i$i|0)==($this|0);
  if ($44) {
   label = 15;
   break;
  }
  $45 = (($__f$0$i$i$i$i$i) + 4|0);
  $46 = HEAP32[$45>>2]|0;
  HEAP32[$1>>2] = 65;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($__f$0$i$i$i$i$i|0),($$byval_copy3|0));
  $47 = __THREW__; __THREW__ = 0;
  $48 = $47&1;
  if ($48) {
   label = 14;
   break;
  } else {
   $__f$0$i$i$i$i$i = $46;
  }
 }
 if ((label|0) == 14) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  ___cxa_call_unexpected(($49|0));
  // unreachable;
 }
 else if ((label|0) == 15) {
  STACKTOP = sp;return;
 }
}
function __ZN21TreeBinaryTreeBuilder5SplitER14TreeBinaryTreeRK8Vector3fS4_i($bintree,$position,$scale,$minimumInstances) {
 $bintree = $bintree|0;
 $position = $position|0;
 $scale = $scale|0;
 $minimumInstances = $minimumInstances|0;
 var $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy16 = 0, $$ph = 0, $$ph34 = 0, $$ph35 = 0, $$ph36 = 0, $$ph37 = 0, $$ph38 = 0, $$ph39 = 0, $$ph40 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre69 = Math_fround(0), $$pre70 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0;
 var $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0);
 var $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0;
 var $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0);
 var $98 = Math_fround(0), $99 = Math_fround(0), $_ZN8Vector3f5xAxisE$_ZN8Vector3f5zAxisE = 0, $i$052 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i13 = 0, $posBounds = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy16 = sp + 108|0;
 $0 = sp + 104|0;
 $1 = sp + 100|0;
 $2 = sp + 96|0;
 $3 = sp + 92|0;
 $4 = sp + 88|0;
 $5 = sp + 84|0;
 $6 = sp + 80|0;
 $7 = sp + 48|0;
 $8 = sp + 44|0;
 $9 = sp + 40|0;
 $10 = sp + 16|0;
 $11 = sp;
 $posBounds = sp + 56|0;
 $12 = HEAP32[$bintree>>2]|0;
 $13 = (($12) + 16|0);
 $14 = (($12) + 28|0);
 $15 = (($bintree) + 20|0);
 $16 = (($bintree) + 4|0);
 __ZN21TreeBinaryTreeBuilder15CalculateBoundsERKNSt3__16vectorI12TreeInstanceNS0_9allocatorIS2_EEEERK13dynamic_arrayIjLj4EERKNS1_IN12TreeDatabase9PrototypeENS3_ISD_EEEERK8Vector3fSK_($10,$13,$16,$14,$position,$scale);
 ;HEAP32[$15+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$15+16>>2]=HEAP32[$10+16>>2]|0;HEAP32[$15+20>>2]=HEAP32[$10+20>>2]|0;
 $17 = (($bintree) + 76|0);
 __ZN21TreeBinaryTreeBuilder27CalculateSupportedInstancesERKNSt3__16vectorI12TreeInstanceNS0_9allocatorIS2_EEEERK13dynamic_arrayIjLj4EERKNS1_IN12TreeDatabase9PrototypeENS3_ISD_EEEE($11,$13,$16,$14);
 __THREW__ = 0;
 (invoke_iii(2603,($17|0),($11|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  $31 = (($11) + 12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)>(-1);
  if (!($33)) {
   $$2 = $30;$$23 = $29;
   ___resumeException($$23|0);
   // unreachable;
  }
  $34 = HEAP32[$11>>2]|0;
  $35 = (($11) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  HEAP32[$8>>2] = $36;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$8+0>>2]|0;
  invoke_vii(2591,($34|0),($$byval_copy16|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   $270 = ___cxa_find_matching_catch(0|0)|0;
   $271 = tempRet0;
   ___clang_call_terminate($270);
   // unreachable;
  }
  HEAP32[$11>>2] = 0;
  $$2 = $30;$$23 = $29;
  ___resumeException($$23|0);
  // unreachable;
 }
 $20 = (($11) + 12|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)>(-1);
 if ($22) {
  $23 = HEAP32[$11>>2]|0;
  $24 = (($11) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$0>>2] = $25;
  ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($23,$$byval_copy16);
  HEAP32[$11>>2] = 0;
 }
 $26 = (($bintree) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)>($minimumInstances|0);
 if (!($28)) {
  STACKTOP = sp;return;
 }
 __ZN21TreeBinaryTreeBuilder18CalculatePosBoundsERKNSt3__16vectorI12TreeInstanceNS0_9allocatorIS2_EEEERK13dynamic_arrayIjLj4EERK8Vector3fSE_($posBounds,$13,$16,$position,$scale);
 $39 = (($posBounds) + 12|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = $40 < Math_fround(0.0);
 if ($41) {
  $42 = Math_fround(-$40);
  $44 = $42;
 } else {
  $44 = $40;
 }
 $43 = !($44 <= Math_fround(9.99999997475242707878E-7));
 $$phi$trans$insert = (($posBounds) + 20|0);
 $$pre69 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
 if (!($43)) {
  $45 = $$pre69 < Math_fround(0.0);
  if ($45) {
   $46 = Math_fround(-$$pre69);
   $48 = $46;
  } else {
   $48 = $$pre69;
  }
  $47 = !($48 <= Math_fround(9.99999997475242707878E-7));
  if (!($47)) {
   STACKTOP = sp;return;
  }
 }
 $49 = (($bintree) + 60|0);
 $50 = $40 > $$pre69;
 $_ZN8Vector3f5xAxisE$_ZN8Vector3f5zAxisE = $50 ? 616712 : 616744;
 ;HEAP32[$49+0>>2]=HEAP32[$_ZN8Vector3f5xAxisE$_ZN8Vector3f5zAxisE+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$_ZN8Vector3f5xAxisE$_ZN8Vector3f5zAxisE+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$_ZN8Vector3f5xAxisE$_ZN8Vector3f5zAxisE+8>>2]|0;
 $51 = Math_fround(HEAPF32[$_ZN8Vector3f5xAxisE$_ZN8Vector3f5zAxisE>>2]);
 $52 = Math_fround(HEAPF32[$posBounds>>2]);
 $53 = Math_fround($51 * $52);
 $54 = (($_ZN8Vector3f5xAxisE$_ZN8Vector3f5zAxisE) + 4|0);
 $55 = Math_fround(HEAPF32[$54>>2]);
 $56 = (($posBounds) + 4|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($55 * $57);
 $59 = Math_fround($53 + $58);
 $60 = (($_ZN8Vector3f5xAxisE$_ZN8Vector3f5zAxisE) + 8|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (($posBounds) + 8|0);
 $63 = Math_fround(HEAPF32[$62>>2]);
 $64 = Math_fround($61 * $63);
 $65 = Math_fround($59 + $64);
 $66 = Math_fround(-$65);
 $67 = (($bintree) + 72|0);
 HEAPF32[$67>>2] = $66;
 $68 = HEAP32[628440>>2]|0;
 $69 = HEAP32[$26>>2]|0;
 $70 = ($69|0)==(0);
 L27: do {
  if ($70) {
   $246 = $68;$247 = 0;$272 = 0;$273 = $68;$274 = 0;
   label = 56;
  } else {
   $71 = (($scale) + 4|0);
   $72 = (($scale) + 8|0);
   $73 = (($position) + 4|0);
   $74 = (($position) + 8|0);
   $75 = (($bintree) + 64|0);
   $76 = (($bintree) + 68|0);
   $108 = $66;$111 = 0;$113 = 0;$121 = 0;$135 = 0;$137 = 0;$145 = 0;$i$052 = 0;
   L29: while(1) {
    $77 = HEAP32[$16>>2]|0;
    $78 = (($77) + ($i$052<<2)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = HEAP32[$13>>2]|0;
    $81 = (($80) + (($79*40)|0)|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround(HEAPF32[$scale>>2]);
    $84 = Math_fround($82 * $83);
    $85 = ((($80) + (($79*40)|0)|0) + 4|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $87 = Math_fround(HEAPF32[$71>>2]);
    $88 = Math_fround($86 * $87);
    $89 = ((($80) + (($79*40)|0)|0) + 8|0);
    $90 = Math_fround(HEAPF32[$89>>2]);
    $91 = Math_fround(HEAPF32[$72>>2]);
    $92 = Math_fround($90 * $91);
    $93 = Math_fround(HEAPF32[$position>>2]);
    $94 = Math_fround($84 + $93);
    $95 = Math_fround(HEAPF32[$73>>2]);
    $96 = Math_fround($88 + $95);
    $97 = Math_fround(HEAPF32[$74>>2]);
    $98 = Math_fround($92 + $97);
    $99 = Math_fround(HEAPF32[$49>>2]);
    $100 = Math_fround($94 * $99);
    $101 = Math_fround(HEAPF32[$75>>2]);
    $102 = Math_fround($96 * $101);
    $103 = Math_fround($100 + $102);
    $104 = Math_fround(HEAPF32[$76>>2]);
    $105 = Math_fround($98 * $104);
    $106 = Math_fround($103 + $105);
    $107 = Math_fround($108 + $106);
    $109 = $107 > Math_fround(0.0);
    if ($109) {
     $110 = (($111) + 1)|0;
     $112 = $113 & 2147483647;
     $114 = ($110>>>0)>($112>>>0);
     do {
      if ($114) {
       $115 = $113 << 1;
       $116 = ($115|0)==(0);
       $117 = $116 ? 1 : $115;
       $118 = ($112>>>0)<($117>>>0);
       if ($118) {
        $119 = ($113|0)>(-1);
        if ($119) {
         $120 = $117 << 2;
         HEAP32[$0>>2] = $68;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
         $122 = (invoke_iiiiiiii(108,($121|0),($120|0),4,($$byval_copy16|0),0,(803264|0),370)|0);
         $123 = __THREW__; __THREW__ = 0;
         $124 = $123&1;
         if ($124) {
          $$ph = $117;$$ph34 = $137;
          label = 60;
          break L29;
         }
         $131 = $122;$275 = $117;
         break;
        } else {
         $125 = $117 << 2;
         HEAP32[$1>>2] = $68;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
         $126 = (invoke_iiiiiii(102,($125|0),4,($$byval_copy16|0),0,(803264|0),352)|0);
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          $$ph = $113;$$ph34 = $137;
          label = 60;
          break L29;
         }
         $129 = $110 << 2;
         _memcpy(($126|0),($121|0),($129|0))|0;
         $131 = $126;$275 = $117;
         break;
        }
       } else {
        $131 = $121;$275 = $113;
       }
      } else {
       $131 = $121;$275 = $113;
      }
     } while(0);
     $130 = (($131) + ($111<<2)|0);
     HEAP32[$130>>2] = $79;
     $160 = $110;$162 = $135;$221 = $131;$225 = $275;$231 = $145;$235 = $137;
    } else {
     $134 = (($135) + 1)|0;
     $136 = $137 & 2147483647;
     $138 = ($134>>>0)>($136>>>0);
     do {
      if ($138) {
       $139 = $137 << 1;
       $140 = ($139|0)==(0);
       $141 = $140 ? 1 : $139;
       $142 = ($136>>>0)<($141>>>0);
       if ($142) {
        $143 = ($137|0)>(-1);
        if ($143) {
         $144 = $141 << 2;
         HEAP32[$2>>2] = $68;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$2+0>>2]|0;
         $146 = (invoke_iiiiiiii(108,($145|0),($144|0),4,($$byval_copy16|0),0,(803264|0),370)|0);
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          $$ph = $113;$$ph34 = $141;
          label = 60;
          break L29;
         }
         $155 = $146;$276 = $141;
         break;
        } else {
         $149 = $141 << 2;
         HEAP32[$3>>2] = $68;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$3+0>>2]|0;
         $150 = (invoke_iiiiiii(102,($149|0),4,($$byval_copy16|0),0,(803264|0),352)|0);
         $151 = __THREW__; __THREW__ = 0;
         $152 = $151&1;
         if ($152) {
          $$ph = $113;$$ph34 = $137;
          label = 60;
          break L29;
         }
         $153 = $134 << 2;
         _memcpy(($150|0),($145|0),($153|0))|0;
         $155 = $150;$276 = $141;
         break;
        }
       } else {
        $155 = $145;$276 = $137;
       }
      } else {
       $155 = $145;$276 = $137;
      }
     } while(0);
     $154 = (($155) + ($135<<2)|0);
     HEAP32[$154>>2] = $79;
     $160 = $111;$162 = $134;$221 = $121;$225 = $113;$231 = $155;$235 = $276;
    }
    $156 = (($i$052) + 1)|0;
    $157 = HEAP32[$26>>2]|0;
    $158 = ($156>>>0)<($157>>>0);
    if (!($158)) {
     label = 36;
     break;
    }
    $$pre70 = Math_fround(HEAPF32[$67>>2]);
    $108 = $$pre70;$111 = $160;$113 = $225;$121 = $221;$135 = $162;$137 = $235;$145 = $231;$i$052 = $156;
   }
   L54: do {
    if ((label|0) == 36) {
     $159 = ($160|0)==(0);
     $161 = ($162|0)==(0);
     $or$cond = $159 | $161;
     L56: do {
      if ($or$cond) {
       $245 = $235;$277 = $225;$278 = $68;$279 = $221;$280 = $68;$281 = $231;
      } else {
       $163 = (($bintree) + 16|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = ($164|0)>(-1);
       if ($165) {
        $166 = HEAP32[$16>>2]|0;
        $167 = (($bintree) + 8|0);
        $168 = HEAP32[$167>>2]|0;
        HEAP32[$4>>2] = $168;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$4+0>>2]|0;
        invoke_vii(2591,($166|0),($$byval_copy16|0));
        $169 = __THREW__; __THREW__ = 0;
        $170 = $169&1;
        if ($170) {
         $$ph35 = $225;$$ph36 = $68;$$ph37 = $221;$$ph38 = $235;$$ph39 = $68;$$ph40 = $231;
        } else {
         HEAP32[$16>>2] = 0;
         label = 40;
        }
       } else {
        label = 40;
       }
       do {
        if ((label|0) == 40) {
         HEAP32[$26>>2] = 0;
         HEAP32[$163>>2] = 0;
         $171 = (($bintree) + 88|0);
         $172 = HEAP32[$171>>2]|0;
         $173 = ($172|0)>(-1);
         if ($173) {
          $174 = HEAP32[$17>>2]|0;
          $175 = (($bintree) + 80|0);
          $176 = HEAP32[$175>>2]|0;
          HEAP32[$5>>2] = $176;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$5+0>>2]|0;
          invoke_vii(2591,($174|0),($$byval_copy16|0));
          $177 = __THREW__; __THREW__ = 0;
          $178 = $177&1;
          if ($178) {
           $$ph35 = $225;$$ph36 = $68;$$ph37 = $221;$$ph38 = $235;$$ph39 = $68;$$ph40 = $231;
           break;
          }
          HEAP32[$17>>2] = 0;
         }
         $179 = (($bintree) + 84|0);
         HEAP32[$179>>2] = 0;
         HEAP32[$171>>2] = 0;
         __THREW__ = 0;
         $180 = (invoke_ii(2988,100)|0);
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if ($182) {
          $$ph35 = $225;$$ph36 = $68;$$ph37 = $221;$$ph38 = $235;$$ph39 = $68;$$ph40 = $231;
         } else {
          $183 = HEAP32[$bintree>>2]|0;
          HEAP32[$180>>2] = $183;
          $184 = HEAP32[628440>>2]|0;
          $185 = (($180) + 4|0);
          HEAP32[$185>>2] = 0;
          $186 = (($180) + 8|0);
          HEAP32[$186>>2] = $184;
          $187 = (($180) + 12|0);
          dest=$187+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
          $188 = (($180) + 76|0);
          HEAP32[$188>>2] = 0;
          $189 = (($180) + 80|0);
          HEAP32[$189>>2] = $184;
          $190 = (($180) + 84|0);
          ;HEAP32[$190+0>>2]=0|0;HEAP32[$190+4>>2]=0|0;HEAP32[$190+8>>2]=0|0;HEAP32[$190+12>>2]=0|0;
          $191 = (($bintree) + 92|0);
          $192 = HEAP32[$191>>2]|0;
          $193 = ($192|0)==($180|0);
          $194 = ($192|0)==(0|0);
          $or$cond$i13 = $193 | $194;
          do {
           if (!($or$cond$i13)) {
            __THREW__ = 0;
            invoke_vi(3715,($192|0));
            $195 = __THREW__; __THREW__ = 0;
            $196 = $195&1;
            if ($196) {
             $197 = ___cxa_find_matching_catch()|0;
             $198 = tempRet0;
             __ZdlPv($192);
             ___cxa_call_unexpected(($197|0));
             // unreachable;
            } else {
             __ZdlPv($192);
             break;
            }
           }
          } while(0);
          HEAP32[$191>>2] = $180;
          __THREW__ = 0;
          $199 = (invoke_ii(2988,100)|0);
          $200 = __THREW__; __THREW__ = 0;
          $201 = $200&1;
          if ($201) {
           $$ph35 = $225;$$ph36 = $68;$$ph37 = $221;$$ph38 = $235;$$ph39 = $68;$$ph40 = $231;
          } else {
           $202 = HEAP32[$bintree>>2]|0;
           HEAP32[$199>>2] = $202;
           $203 = HEAP32[628440>>2]|0;
           $204 = (($199) + 4|0);
           HEAP32[$204>>2] = 0;
           $205 = (($199) + 8|0);
           HEAP32[$205>>2] = $203;
           $206 = (($199) + 12|0);
           dest=$206+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
           $207 = (($199) + 76|0);
           HEAP32[$207>>2] = 0;
           $208 = (($199) + 80|0);
           HEAP32[$208>>2] = $203;
           $209 = (($199) + 84|0);
           ;HEAP32[$209+0>>2]=0|0;HEAP32[$209+4>>2]=0|0;HEAP32[$209+8>>2]=0|0;HEAP32[$209+12>>2]=0|0;
           $210 = (($bintree) + 96|0);
           $211 = HEAP32[$210>>2]|0;
           $212 = ($211|0)==($199|0);
           $213 = ($211|0)==(0|0);
           $or$cond$i = $212 | $213;
           do {
            if ($or$cond$i) {
             $219 = $180;
            } else {
             __THREW__ = 0;
             invoke_vi(3715,($211|0));
             $214 = __THREW__; __THREW__ = 0;
             $215 = $214&1;
             if ($215) {
              $216 = ___cxa_find_matching_catch()|0;
              $217 = tempRet0;
              __ZdlPv($211);
              ___cxa_call_unexpected(($216|0));
              // unreachable;
             } else {
              __ZdlPv($211);
              $$pre = HEAP32[$191>>2]|0;
              $219 = $$pre;
              break;
             }
            }
           } while(0);
           HEAP32[$210>>2] = $199;
           $218 = (($219) + 4|0);
           $220 = HEAP32[$218>>2]|0;
           HEAP32[$218>>2] = $221;
           $222 = (($219) + 12|0);
           HEAP32[$222>>2] = $160;
           $223 = (($219) + 16|0);
           $224 = HEAP32[$223>>2]|0;
           HEAP32[$223>>2] = $225;
           $226 = (($219) + 8|0);
           $227 = HEAP32[$226>>2]|0;
           HEAP32[$226>>2] = $68;
           $228 = HEAP32[$210>>2]|0;
           $229 = (($228) + 4|0);
           $230 = HEAP32[$229>>2]|0;
           HEAP32[$229>>2] = $231;
           $232 = (($228) + 12|0);
           HEAP32[$232>>2] = $162;
           $233 = (($228) + 16|0);
           $234 = HEAP32[$233>>2]|0;
           HEAP32[$233>>2] = $235;
           $236 = (($228) + 8|0);
           $237 = HEAP32[$236>>2]|0;
           HEAP32[$236>>2] = $68;
           $238 = HEAP32[$191>>2]|0;
           __THREW__ = 0;
           invoke_viiii(422,($238|0),($position|0),($scale|0),($minimumInstances|0));
           $239 = __THREW__; __THREW__ = 0;
           $240 = $239&1;
           if ($240) {
            $$ph35 = $224;$$ph36 = $227;$$ph37 = $220;$$ph38 = $234;$$ph39 = $237;$$ph40 = $230;
           } else {
            $241 = HEAP32[$210>>2]|0;
            __THREW__ = 0;
            invoke_viiii(422,($241|0),($position|0),($scale|0),($minimumInstances|0));
            $242 = __THREW__; __THREW__ = 0;
            $243 = $242&1;
            if ($243) {
             $$ph35 = $224;$$ph36 = $227;$$ph37 = $220;$$ph38 = $234;$$ph39 = $237;$$ph40 = $230;
            } else {
             $245 = $234;$277 = $224;$278 = $227;$279 = $220;$280 = $237;$281 = $230;
             break L56;
            }
           }
          }
         }
        }
       } while(0);
       $256 = ___cxa_find_matching_catch()|0;
       $257 = tempRet0;
       $259 = $$ph38;$260 = $$ph39;$261 = $$ph40;$282 = $$ph35;$283 = $$ph36;$284 = $$ph37;$lpad$phi$index = $256;$lpad$phi$index2 = $257;
       break L54;
      }
     } while(0);
     $244 = ($245|0)>(-1);
     if ($244) {
      $246 = $280;$247 = $281;$272 = $279;$273 = $278;$274 = $277;
      label = 56;
      break L27;
     } else {
      $251 = $277;$252 = $278;$253 = $279;
      label = 57;
      break L27;
     }
    }
    else if ((label|0) == 60) {
     $254 = ___cxa_find_matching_catch()|0;
     $255 = tempRet0;
     $259 = $$ph34;$260 = $68;$261 = $145;$282 = $$ph;$283 = $68;$284 = $121;$lpad$phi$index = $254;$lpad$phi$index2 = $255;
    }
   } while(0);
   $258 = ($259|0)>(-1);
   if ($258) {
    HEAP32[$9>>2] = $260;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$9+0>>2]|0;
    invoke_vii(2591,($261|0),($$byval_copy16|0));
    $262 = __THREW__; __THREW__ = 0;
    $263 = $262&1;
    if ($263) {
     $270 = ___cxa_find_matching_catch(0|0)|0;
     $271 = tempRet0;
     ___clang_call_terminate($270);
     // unreachable;
    } else {
     $$1 = $lpad$phi$index2;$$12 = $lpad$phi$index;$265 = $282;$266 = $283;$267 = $284;
    }
   } else {
    $$1 = $lpad$phi$index2;$$12 = $lpad$phi$index;$265 = $282;$266 = $283;$267 = $284;
   }
  }
 } while(0);
 if ((label|0) == 56) {
  HEAP32[$7>>2] = $246;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$7+0>>2]|0;
  invoke_vii(2591,($247|0),($$byval_copy16|0));
  $248 = __THREW__; __THREW__ = 0;
  $249 = $248&1;
  if ($249) {
   $132 = ___cxa_find_matching_catch()|0;
   $133 = tempRet0;
   $$1 = $133;$$12 = $132;$265 = $274;$266 = $273;$267 = $272;
  } else {
   $251 = $274;$252 = $273;$253 = $272;
   label = 57;
  }
 }
 if ((label|0) == 57) {
  $250 = ($251|0)>(-1);
  if (!($250)) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = $252;
  ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($253,$$byval_copy16);
  STACKTOP = sp;return;
 }
 $264 = ($265|0)>(-1);
 if (!($264)) {
  $$2 = $$1;$$23 = $$12;
  ___resumeException($$23|0);
  // unreachable;
 }
 HEAP32[$6>>2] = $266;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_vii(2591,($267|0),($$byval_copy16|0));
 $268 = __THREW__; __THREW__ = 0;
 $269 = $268&1;
 if ($269) {
  $270 = ___cxa_find_matching_catch(0|0)|0;
  $271 = tempRet0;
  ___clang_call_terminate($270);
  // unreachable;
 } else {
  $$2 = $$1;$$23 = $$12;
  ___resumeException($$23|0);
  // unreachable;
 }
}
function __ZN21TreeBinaryTreeBuilder18CalculatePosBoundsERKNSt3__16vectorI12TreeInstanceNS0_9allocatorIS2_EEEERK13dynamic_arrayIjLj4EERK8Vector3fSE_($agg$result,$allInstances,$instances,$position,$scale) {
 $agg$result = $agg$result|0;
 $allInstances = $allInstances|0;
 $instances = $instances|0;
 $position = $position|0;
 $scale = $scale|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $i$07 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$instances>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$allInstances>>2]|0;
 $4 = (($3) + (($2*40)|0)|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround(HEAPF32[$scale>>2]);
 $7 = Math_fround($5 * $6);
 $8 = ((($3) + (($2*40)|0)|0) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($scale) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 * $11);
 $13 = ((($3) + (($2*40)|0)|0) + 8|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($scale) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = Math_fround(HEAPF32[$position>>2]);
 $19 = Math_fround($7 + $18);
 $20 = (($position) + 4|0);
 $21 = Math_fround(HEAPF32[$20>>2]);
 $22 = Math_fround($12 + $21);
 $23 = (($position) + 8|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = Math_fround($17 + $24);
 $26 = (($agg$result) + 12|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 HEAPF32[$agg$result>>2] = $19;
 $27 = (($agg$result) + 4|0);
 HEAPF32[$27>>2] = $22;
 $28 = (($agg$result) + 8|0);
 HEAPF32[$28>>2] = $25;
 ;HEAP32[$26+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[616680+8>>2]|0;
 $29 = (($instances) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = (($0) + 4|0);
 $33 = (($0) + 8|0);
 $i$07 = 0;
 while(1) {
  $34 = HEAP32[$instances>>2]|0;
  $35 = (($34) + ($i$07<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP32[$allInstances>>2]|0;
  $38 = (($37) + (($36*40)|0)|0);
  $39 = Math_fround(HEAPF32[$38>>2]);
  $40 = Math_fround(HEAPF32[$scale>>2]);
  $41 = Math_fround($39 * $40);
  $42 = ((($37) + (($36*40)|0)|0) + 4|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround(HEAPF32[$10>>2]);
  $45 = Math_fround($43 * $44);
  $46 = ((($37) + (($36*40)|0)|0) + 8|0);
  $47 = Math_fround(HEAPF32[$46>>2]);
  $48 = Math_fround(HEAPF32[$15>>2]);
  $49 = Math_fround($47 * $48);
  $50 = Math_fround(HEAPF32[$position>>2]);
  $51 = Math_fround($41 + $50);
  $52 = Math_fround(HEAPF32[$20>>2]);
  $53 = Math_fround($45 + $52);
  $54 = Math_fround(HEAPF32[$23>>2]);
  $55 = Math_fround($49 + $54);
  HEAPF32[$0>>2] = $51;
  HEAPF32[$32>>2] = $53;
  HEAPF32[$33>>2] = $55;
  __ZN4AABB11EncapsulateERK8Vector3f($agg$result,$0);
  $56 = (($i$07) + 1)|0;
  $57 = HEAP32[$29>>2]|0;
  $58 = ($56>>>0)<($57>>>0);
  if ($58) {
   $i$07 = $56;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __GLOBAL__I_a20087() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,802832);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[802816>>2] = $1;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,802864);
 $2 = HEAP32[$0>>2]|0;
 HEAP32[((802816 + 4|0))>>2] = $2;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,802896);
 $3 = HEAP32[$0>>2]|0;
 HEAP32[((802816 + 8|0))>>2] = $3;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,802928);
 $4 = HEAP32[$0>>2]|0;
 HEAP32[((802816 + 12|0))>>2] = $4;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,802976);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[802960>>2] = $5;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,803008);
 $6 = HEAP32[$0>>2]|0;
 HEAP32[((802960 + 4|0))>>2] = $6;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,803040);
 $7 = HEAP32[$0>>2]|0;
 HEAP32[((802960 + 8|0))>>2] = $7;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,803072);
 $8 = HEAP32[$0>>2]|0;
 HEAP32[((802960 + 12|0))>>2] = $8;
 HEAPF32[803416>>2] = Math_fround(-1.0);
 HEAPF32[((803416 + 4|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 8|0))>>2] = Math_fround(1.0);
 HEAPF32[((803416 + 12|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 16|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 20|0))>>2] = Math_fround(1.0);
 HEAPF32[((803416 + 24|0))>>2] = Math_fround(1.0);
 HEAPF32[((803416 + 28|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 32|0))>>2] = Math_fround(1.0);
 HEAPF32[((803416 + 36|0))>>2] = Math_fround(-1.0);
 ;HEAP32[((803416 + 40|0))+0>>2]=0|0;HEAP32[((803416 + 40|0))+4>>2]=0|0;HEAP32[((803416 + 40|0))+8>>2]=0|0;HEAP32[((803416 + 40|0))+12>>2]=0|0;HEAP32[((803416 + 40|0))+16>>2]=0|0;
 HEAPF32[((803416 + 60|0))>>2] = Math_fround(1.0);
 HEAPF32[((803416 + 64|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 68|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 72|0))>>2] = Math_fround(-1.0);
 HEAPF32[((803416 + 76|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 80|0))>>2] = Math_fround(-1.0);
 HEAPF32[((803416 + 84|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 88|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 92|0))>>2] = Math_fround(-1.0);
 HEAPF32[((803416 + 96|0))>>2] = Math_fround(1.0);
 HEAPF32[((803416 + 100|0))>>2] = Math_fround(0.0);
 HEAPF32[((803416 + 104|0))>>2] = Math_fround(-1.0);
 STACKTOP = sp;return;
}
function __Z29InitializeTextRenderingModulev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01$i = 0, $i$01$i1 = 0, $i$01$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628344>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(4,$$byval_copy,1,16,803680,46)|0);
 HEAP32[$2>>2] = ((803688 + 8|0));
 __ZN13TextRendering17SetITextRenderingEPNS_14ITextRenderingE($2);
 HEAP32[579464>>2] = 152;
 $3 = (__ZN15GlobalCallbacks3GetEv()|0);
 $i$01$i3 = 0;
 while(1) {
  $6 = ((($3) + ($i$01$i3<<2)|0) + 320|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  $5 = (($i$01$i3) + 1)|0;
  if ($8) {
   label = 4;
   break;
  }
  $4 = ($5|0)<(16);
  if ($4) {
   $i$01$i3 = $5;
  } else {
   $i$01$i1 = 0;
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$6>>2] = 249;
  $i$01$i1 = 0;
 }
 while(1) {
  $11 = (597480 + ($i$01$i1<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  $10 = (($i$01$i1) + 1)|0;
  if ($13) {
   label = 7;
   break;
  }
  $9 = ($10|0)<(16);
  if ($9) {
   $i$01$i1 = $10;
  } else {
   $i$01$i = 0;
   break;
  }
 }
 if ((label|0) == 7) {
  HEAP32[$11>>2] = 250;
  $i$01$i = 0;
 }
 while(1) {
  $16 = (597416 + ($i$01$i<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  $15 = (($i$01$i) + 1)|0;
  if ($18) {
   break;
  }
  $14 = ($15|0)<(16);
  if ($14) {
   $i$01$i = $15;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return;
 }
 HEAP32[$16>>2] = 251;
 STACKTOP = sp;return;
}
function __ZZ29InitializeTextRenderingModulevEN27TextRenderingGarbageCollect7ForwardEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate17TextMeshGenerator14GarbageCollectEv();
 STACKTOP = sp;return;
}
function __ZZ29InitializeTextRenderingModulevEN16cleanupAfterLoad7ForwardE_0v() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate17TextMeshGenerator5FlushEv();
 STACKTOP = sp;return;
}
function __Z26CleanupTextRenderingModulev() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__ZN13TextRendering17GetITextRenderingEv()|0);
 $2 = HEAP32[628344>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 __ZN13TextRendering17SetITextRenderingEPNS_14ITextRenderingE(0);
 __ZN20TextRenderingPrivate17TextMeshGenerator5FlushEv();
 STACKTOP = sp;return;
}
function __ZNK19TextRenderingModule8TMGenGetERK11UTF16StringPN13TextRendering4FontE10TextAnchor13TextAlignmentfffbb11ColorRGBA32ii($this,$text,$font,$anchor,$alignment,$wordWrapWidth,$tabSize,$lineSpacing,$richText,$pixelcorrect,$color,$fontSize,$fontStyle) {
 $this = $this|0;
 $text = $text|0;
 $font = $font|0;
 $anchor = $anchor|0;
 $alignment = $alignment|0;
 $wordWrapWidth = Math_fround($wordWrapWidth);
 $tabSize = Math_fround($tabSize);
 $lineSpacing = Math_fround($lineSpacing);
 $richText = $richText|0;
 $pixelcorrect = $pixelcorrect|0;
 $color = $color|0;
 $fontSize = $fontSize|0;
 $fontStyle = $fontStyle|0;
 var $0 = 0, $1 = 0, $2 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$color>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZN20TextRenderingPrivate17TextMeshGenerator3GetERK11UTF16StringPNS_4FontE10TextAnchor13TextAlignmentfffbb11ColorRGBA32ii($text,$font,$anchor,$alignment,$wordWrapWidth,$tabSize,$lineSpacing,$richText,$pixelcorrect,$tmpcast$byval_copy,$fontSize,$fontStyle)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK19TextRenderingModule22TMGenGetCursorPositionEPN13TextRendering17TextMeshGeneratorERK5RectTIfEi($agg$result,$this,$gen,$screenRect,$cursor) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $gen = $gen|0;
 $screenRect = $screenRect|0;
 $cursor = $cursor|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate17TextMeshGenerator17GetCursorPositionERK5RectTIfEi($agg$result,$gen,$screenRect,$cursor);
 STACKTOP = sp;return;
}
function __ZNK19TextRenderingModule29TMGenGetCursorIndexAtPositionEPN13TextRendering17TextMeshGeneratorERK5RectTIfERK8Vector2f($this,$gen,$screenRect,$pos) {
 $this = $this|0;
 $gen = $gen|0;
 $screenRect = $screenRect|0;
 $pos = $pos|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN20TextRenderingPrivate17TextMeshGenerator24GetCursorIndexAtPositionERK5RectTIfERK8Vector2f($gen,$screenRect,$pos)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK19TextRenderingModule10TMGenFlushEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate17TextMeshGenerator5FlushEv();
 STACKTOP = sp;return;
}
function __ZNK19TextRenderingModule38FontGetNumCharactersThatFitWithinWidthEPN13TextRendering4FontERK11UTF16Stringfij($this,$font,$text,$width,$size,$style) {
 $this = $this|0;
 $font = $font|0;
 $text = $text|0;
 $width = Math_fround($width);
 $size = $size|0;
 $style = $style|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN20TextRenderingPrivate4Font34GetNumCharactersThatFitWithinWidthERK11UTF16Stringfij($font,$text,$width,$size,$style)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z28RegisterModule_TextRenderingv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $i$01$i$i1 = 0;
 var $i$01$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i = 0;
 while(1) {
  $3 = ((($0) + ($i$01$i$i<<2)|0) + 64|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  $2 = (($i$01$i$i) + 1)|0;
  if ($5) {
   label = 4;
   break;
  }
  $1 = ($2|0)<(16);
  if ($1) {
   $i$01$i$i = $2;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$3>>2] = 252;
 }
 $6 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i2 = 0;
 while(1) {
  $9 = (($6) + ($i$01$i$i2<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  $8 = (($i$01$i$i2) + 1)|0;
  if ($11) {
   label = 8;
   break;
  }
  $7 = ($8|0)<(16);
  if ($7) {
   $i$01$i$i2 = $8;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  HEAP32[$9>>2] = 253;
 }
 $12 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i1 = 0;
 while(1) {
  $15 = ((($12) + ($i$01$i$i1<<2)|0) + 128|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  $14 = (($i$01$i$i1) + 1)|0;
  if ($17) {
   break;
  }
  $13 = ($14|0)<(16);
  if ($13) {
   $i$01$i$i1 = $14;
  } else {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
 HEAP32[$15>>2] = 254;
 STACKTOP = sp;return;
}
function __ZL34RegisterModuleICalls_TextRenderingv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL30InitializeModule_TextRenderingv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z29InitializeTextRenderingModulev();
 STACKTOP = sp;return;
}
function __ZL27CleanupModule_TextRenderingv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z26CleanupTextRenderingModulev();
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate15DynamicFontDataC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 4|0);
 HEAP32[$this>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate15DynamicFontDataD2Ev($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = ($0|0)==($1|0);
 L1: do {
  if (!($2)) {
   $4 = $0;
   while(1) {
    $3 = (($4) + 32|0);
    $5 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    (invoke_ii(3412,($5|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    $8 = (($4) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     $$01$i$i$i$i = $4;
     while(1) {
      $13 = (($$01$i$i$i$i) + 8|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = HEAP32[$14>>2]|0;
      $16 = ($15|0)==($$01$i$i$i$i|0);
      if ($16) {
       $$0$i$i$i$i = $14;
       break;
      } else {
       $$01$i$i$i$i = $14;
      }
     }
    } else {
     $$0$i$i$i$i$i = $9;
     while(1) {
      $11 = HEAP32[$$0$i$i$i$i$i>>2]|0;
      $12 = ($11|0)==(0|0);
      if ($12) {
       $$0$i$i$i$i = $$0$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i = $11;
      }
     }
    }
    $17 = ($$0$i$i$i$i|0)==($1|0);
    if ($17) {
     break L1;
    } else {
     $4 = $$0$i$i$i$i;
    }
   }
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   $22 = (($this) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefEP11FT_FaceRec_EENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$23);
   ___resumeException($20|0);
   // unreachable;
  }
 } while(0);
 $18 = (($this) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefEP11FT_FaceRec_EENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$19);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate15GetFontMetadataERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERS6_S9_RjSA_iPi($path,$family_name,$style_name,$style_flags,$face_flags,$face_index,$num_faces) {
 $path = $path|0;
 $family_name = $family_name|0;
 $style_name = $style_name|0;
 $style_flags = $style_flags|0;
 $face_flags = $face_flags|0;
 $face_index = $face_index|0;
 $num_faces = $num_faces|0;
 var $$ = 0, $$0 = 0, $$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $face = 0, $res = 0, $shortName = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $shortName = sp;
 $res = sp + 28|0;
 $face = sp + 12|0;
 __Z24GetLastPathNameComponentRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($0,$path);
 __THREW__ = 0;
 invoke_vii(2753,($shortName|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $10 = HEAP8[$0>>0]|0;
  $11 = $10 & 1;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   ___resumeException($8|0);
   // unreachable;
  }
  $13 = (($0) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  __ZdlPv($14);
  ___resumeException($8|0);
  // unreachable;
 }
 $3 = HEAP8[$0>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($0) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  __ZdlPv($7);
 }
 HEAP8[$res>>0] = 0;
 __THREW__ = 0;
 $15 = (invoke_iiiiiiiii(45,($shortName|0),($family_name|0),($style_name|0),($style_flags|0),($face_flags|0),($face_index|0),($num_faces|0),($res|0))|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if (!($17)) {
   if (!($15)) {
    $25 = HEAP32[803736>>2]|0;
    $26 = HEAP8[$path>>0]|0;
    $27 = $26 & 1;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     $31 = (($path) + 1|0);
     $32 = $31;
    } else {
     $29 = (($path) + 8|0);
     $30 = HEAP32[$29>>2]|0;
     $32 = $30;
    }
    __THREW__ = 0;
    $33 = (invoke_iiiii(274,($25|0),($32|0),($face_index|0),($face|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = ($33|0)==(0);
    if ($36) {
     $37 = HEAP32[$face>>2]|0;
     $38 = HEAP32[$37>>2]|0;
     HEAP32[$num_faces>>2] = $38;
     $39 = (($37) + 20|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $55 = $37;
     } else {
      __THREW__ = 0;
      (invoke_iii(2392,($family_name|0),($40|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      }
      $44 = HEAP32[$face>>2]|0;
      $45 = (($44) + 24|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(0|0);
      $$ = $47 ? 803720 : $46;
      __THREW__ = 0;
      (invoke_iii(2392,($style_name|0),($$|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      $50 = HEAP32[$face>>2]|0;
      $51 = (($50) + 12|0);
      $52 = HEAP32[$51>>2]|0;
      HEAP32[$style_flags>>2] = $52;
      $53 = (($50) + 8|0);
      $54 = HEAP32[$53>>2]|0;
      HEAP32[$face_flags>>2] = $54;
      HEAP8[$res>>0] = 1;
      $55 = $50;
     }
     __THREW__ = 0;
     (invoke_ii(3412,($55|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
    }
   }
   $$0$in = HEAP8[$res>>0]|0;
   $$0 = ($$0$in<<24>>24)!=(0);
   $58 = HEAP8[$shortName>>0]|0;
   $59 = $58 & 1;
   $60 = ($59<<24>>24)==(0);
   if ($60) {
    STACKTOP = sp;return ($$0|0);
   }
   $61 = (($shortName) + 8|0);
   $62 = HEAP32[$61>>2]|0;
   __ZdlPv($62);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $20 = HEAP8[$shortName>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  ___resumeException($18|0);
  // unreachable;
 }
 $23 = (($shortName) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 __ZdlPv($24);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __ZN20TextRenderingPrivate13ReadFontFilesEv() {
 var $$ = 0, $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01 = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$1 = 0, $$12 = 0, $$136 = 0, $$137 = 0, $$3 = 0, $$34 = 0, $$byval_copy = 0, $$lcssa75 = 0, $$lcssa85 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i7 = 0;
 var $$pre$i$i$i8 = 0, $$pre131 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__lhs_sz$05$i$i$i = 0, $__lp$03$i$i$i = 0;
 var $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i23 = 0, $__p$0$i$i$i19 = 0, $__rp$04$i$i$i = 0, $face_flags = 0, $family_name = 0, $folderIndex$0123 = 0, $font = 0, $fontIndex$073 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi49$index = 0, $lpad$phi49$index7 = 0, $lpad$phi54$index = 0, $lpad$phi54$index12 = 0, $lpad$phi59$index = 0, $lpad$phi59$index17 = 0, $numFaces = 0, $or$cond = 0;
 var $paths = 0, $phitmp = 0, $phitmp$i$i = 0, $phitmp135 = 0, $r = 0, $style_flags = 0, $style_name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp + 112|0;
 $0 = sp + 108|0;
 $paths = sp + 96|0;
 $family_name = sp + 84|0;
 $style_name = sp + 72|0;
 $style_flags = sp + 68|0;
 $face_flags = sp + 64|0;
 $numFaces = sp + 48|0;
 $r = sp + 32|0;
 $1 = sp + 16|0;
 $font = sp;
 $2 = sp + 52|0;
 $3 = HEAP32[628344>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $4 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,803720,57)|0);
 $5 = (($4) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 8|0);
 HEAP32[$6>>2] = 0;
 HEAP32[$4>>2] = $5;
 HEAP32[803728>>2] = $4;
 HEAP32[$paths>>2] = 0;
 $7 = (($paths) + 4|0);
 HEAP32[$7>>2] = 0;
 $8 = (($paths) + 8|0);
 HEAP32[$8>>2] = 0;
 __THREW__ = 0;
 invoke_vi(3722,($paths|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if ($10) {
   $42 = ___cxa_find_matching_catch()|0;
   $43 = tempRet0;
   $$3 = $42;$$34 = $43;
  } else {
   $11 = HEAP32[$7>>2]|0;
   $12 = HEAP32[$paths>>2]|0;
   $13 = ($11|0)==($12|0);
   L4: do {
    if ($13) {
     $$lcssa75 = $11;$$lcssa85 = $11;
    } else {
     $14 = (($family_name) + 8|0);
     $15 = (($style_name) + 8|0);
     $16 = (($family_name) + 1|0);
     $17 = (($1) + 1|0);
     $18 = (($r) + 12|0);
     $19 = (($font) + 12|0);
     $20 = (($r) + 8|0);
     $21 = (($font) + 8|0);
     $22 = (($font) + 1|0);
     $23 = (($font) + 4|0);
     $24 = (($style_name) + 1|0);
     $25 = (($2) + 8|0);
     $26 = (($2) + 4|0);
     $27 = (($2) + 1|0);
     $28 = (($1) + 8|0);
     $29 = (($1) + 4|0);
     $30 = (($r) + 1|0);
     $31 = (($r) + 4|0);
     $33 = $12;$folderIndex$0123 = 0;
     L6: while(1) {
      $32 = (($33) + (($folderIndex$0123*12)|0)|0);
      ;HEAP32[$family_name+0>>2]=0|0;HEAP32[$family_name+4>>2]=0|0;HEAP32[$family_name+8>>2]=0|0;
      ;HEAP32[$style_name+0>>2]=0|0;HEAP32[$style_name+4>>2]=0|0;HEAP32[$style_name+8>>2]=0|0;
      HEAP32[$numFaces>>2] = 1;
      $34 = ((($33) + (($folderIndex$0123*12)|0)|0) + 8|0);
      $35 = ((($33) + (($folderIndex$0123*12)|0)|0) + 4|0);
      $fontIndex$073 = 0;
      while(1) {
       __THREW__ = 0;
       $36 = (invoke_iiiiiiii(115,($32|0),($family_name|0),($style_name|0),($style_flags|0),($face_flags|0),($fontIndex$073|0),($numFaces|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 9;
        break L6;
       }
       if ($36) {
        $39 = HEAP32[$face_flags>>2]|0;
        $40 = $39 & 1;
        $41 = ($40|0)==(0);
        if (!($41)) {
         $48 = HEAP8[$family_name>>0]|0;
         $49 = $48 & 1;
         $50 = ($49<<24>>24)==(0);
         $51 = HEAP32[$14>>2]|0;
         $$ = $50 ? $16 : $51;
         $52 = (_strlen(($$|0))|0);
         $53 = ($52>>>0)>(4294967279);
         if ($53) {
          label = 13;
          break L6;
         }
         $56 = ($52>>>0)<(11);
         if ($56) {
          $57 = $52 << 1;
          $58 = $57&255;
          HEAP8[$1>>0] = $58;
          $74 = $58;$__p$0$i$i$i = $17;
         } else {
          $59 = (($52) + 16)|0;
          $60 = $59 & -16;
          __THREW__ = 0;
          $61 = (invoke_ii(2988,($60|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 9;
           break L6;
          }
          HEAP32[$28>>2] = $61;
          $64 = $60 | 1;
          HEAP32[$1>>2] = $64;
          HEAP32[$29>>2] = $52;
          $65 = $64&255;
          $74 = $65;$__p$0$i$i$i = $61;
         }
         _memcpy(($__p$0$i$i$i|0),($$|0),($52|0))|0;
         $66 = (($__p$0$i$i$i) + ($52)|0);
         HEAP8[$66>>0] = 0;
         $67 = HEAP32[$style_flags>>2]|0;
         $68 = $67 << 1;
         $69 = $68 & 2;
         $70 = $67 >>> 1;
         $71 = $70 & 1;
         $72 = $71 | $69;
         $73 = $74 & 1;
         $75 = ($73<<24>>24)==(0);
         if ($75) {
          ;HEAP32[$r+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$r+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$r+8>>2]=HEAP32[$1+8>>2]|0;
         } else {
          $76 = HEAP32[$28>>2]|0;
          $77 = HEAP32[$29>>2]|0;
          $78 = ($77>>>0)>(4294967279);
          if ($78) {
           label = 22;
           break L6;
          }
          $81 = ($77>>>0)<(11);
          if ($81) {
           $82 = $77 << 1;
           $83 = $82&255;
           HEAP8[$r>>0] = $83;
           $__p$0$i$i$i$i$i = $30;
          } else {
           $84 = (($77) + 16)|0;
           $85 = $84 & -16;
           __THREW__ = 0;
           $86 = (invoke_ii(2988,($85|0))|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            label = 84;
            break L6;
           }
           HEAP32[$20>>2] = $86;
           $89 = $85 | 1;
           HEAP32[$r>>2] = $89;
           HEAP32[$31>>2] = $77;
           $__p$0$i$i$i$i$i = $86;
          }
          _memcpy(($__p$0$i$i$i$i$i|0),($76|0),($77|0))|0;
          $90 = (($__p$0$i$i$i$i$i) + ($77)|0);
          HEAP8[$90>>0] = 0;
         }
         HEAP32[$18>>2] = $72;
         $91 = $74 & 1;
         $92 = ($91<<24>>24)==(0);
         if (!($92)) {
          $93 = HEAP32[$28>>2]|0;
          __ZdlPv($93);
         }
         $94 = HEAP8[$32>>0]|0;
         $95 = $94 & 1;
         $96 = ($95<<24>>24)==(0);
         if ($96) {
          ;HEAP32[$2+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$32+8>>2]|0;
          $$pre131 = HEAP8[$2>>0]|0;
          $114 = $$pre131;
         } else {
          $97 = HEAP32[$34>>2]|0;
          $98 = HEAP32[$35>>2]|0;
          $99 = ($98>>>0)>(4294967279);
          if ($99) {
           label = 34;
           break L6;
          }
          $102 = ($98>>>0)<(11);
          if ($102) {
           $103 = $98 << 1;
           $104 = $103&255;
           HEAP8[$2>>0] = $104;
           $295 = $104;$__p$0$i$i$i19 = $27;
          } else {
           $105 = (($98) + 16)|0;
           $106 = $105 & -16;
           __THREW__ = 0;
           $107 = (invoke_ii(2988,($106|0))|0);
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            label = 88;
            break L6;
           }
           HEAP32[$25>>2] = $107;
           $110 = $106 | 1;
           HEAP32[$2>>2] = $110;
           HEAP32[$26>>2] = $98;
           $111 = $110&255;
           $295 = $111;$__p$0$i$i$i19 = $107;
          }
          _memcpy(($__p$0$i$i$i19|0),($97|0),($98|0))|0;
          $112 = (($__p$0$i$i$i19) + ($98)|0);
          HEAP8[$112>>0] = 0;
          $114 = $295;
         }
         $113 = $114 & 1;
         $115 = ($113<<24>>24)==(0);
         if ($115) {
          ;HEAP32[$font+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$font+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$font+8>>2]=HEAP32[$2+8>>2]|0;
         } else {
          $116 = HEAP32[$25>>2]|0;
          $117 = HEAP32[$26>>2]|0;
          $118 = ($117>>>0)>(4294967279);
          if ($118) {
           label = 44;
           break L6;
          }
          $121 = ($117>>>0)<(11);
          if ($121) {
           $122 = $117 << 1;
           $123 = $122&255;
           HEAP8[$font>>0] = $123;
           $__p$0$i$i$i$i$i23 = $22;
          } else {
           $124 = (($117) + 16)|0;
           $125 = $124 & -16;
           __THREW__ = 0;
           $126 = (invoke_ii(2988,($125|0))|0);
           $127 = __THREW__; __THREW__ = 0;
           $128 = $127&1;
           if ($128) {
            label = 91;
            break L6;
           }
           HEAP32[$21>>2] = $126;
           $129 = $125 | 1;
           HEAP32[$font>>2] = $129;
           HEAP32[$23>>2] = $117;
           $__p$0$i$i$i$i$i23 = $126;
          }
          _memcpy(($__p$0$i$i$i$i$i23|0),($116|0),($117|0))|0;
          $130 = (($__p$0$i$i$i$i$i23) + ($117)|0);
          HEAP8[$130>>0] = 0;
         }
         HEAP32[$19>>2] = $fontIndex$073;
         $131 = $114 & 1;
         $132 = ($131<<24>>24)==(0);
         if (!($132)) {
          $133 = HEAP32[$25>>2]|0;
          __ZdlPv($133);
         }
         $134 = HEAP32[803728>>2]|0;
         $135 = (($134) + 4|0);
         $136 = HEAP32[$135>>2]|0;
         $137 = (($134) + 4|0);
         $138 = ($136|0)==(0|0);
         L56: do {
          if ($138) {
           label = 97;
          } else {
           $$0$ph7$i$i$i = $137;$$01$ph6$i$in$i$i = $136;
           L57: while(1) {
            $$013$i$in$i$i = $$01$ph6$i$in$i$i;
            while(1) {
             $139 = (($$013$i$in$i$i) + 16|0);
             $140 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($139,$r)|0);
             if (!($140)) {
              break;
             }
             $143 = (($$013$i$in$i$i) + 4|0);
             $144 = HEAP32[$143>>2]|0;
             $145 = ($144|0)==(0|0);
             if ($145) {
              $$0$ph5$i$i$i = $$0$ph7$i$i$i;
              break L57;
             } else {
              $$013$i$in$i$i = $144;
             }
            }
            $141 = HEAP32[$$013$i$in$i$i>>2]|0;
            $142 = ($141|0)==(0|0);
            if ($142) {
             $$0$ph5$i$i$i = $$013$i$in$i$i;
             break;
            } else {
             $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $141;
            }
           }
           $146 = ($$0$ph5$i$i$i|0)==($137|0);
           if ($146) {
            label = 97;
           } else {
            $147 = (($$0$ph5$i$i$i) + 16|0);
            $148 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($r,$147)|0);
            $149 = ($$0$ph5$i$i$i|0)==($137|0);
            $or$cond = $148 | $149;
            if ($or$cond) {
             label = 97;
             break;
            }
            $150 = (($$0$ph5$i$i$i) + 32|0);
            $151 = (($$0$ph5$i$i$i) + 44|0);
            $152 = HEAP32[$151>>2]|0;
            $153 = HEAP32[$19>>2]|0;
            $154 = ($152|0)==($153|0);
            L66: do {
             if ($154) {
              $155 = HEAP8[$150>>0]|0;
              $156 = $155 & 1;
              $157 = ($156<<24>>24)==(0);
              if ($157) {
               $160 = $155&255;
               $161 = $160 >>> 1;
               $169 = $161;
              } else {
               $158 = (($$0$ph5$i$i$i) + 36|0);
               $159 = HEAP32[$158>>2]|0;
               $169 = $159;
              }
              $162 = HEAP8[$font>>0]|0;
              $163 = $162 & 1;
              $164 = ($163<<24>>24)==(0);
              if ($164) {
               $166 = $162&255;
               $167 = $166 >>> 1;
               $170 = $167;
              } else {
               $165 = HEAP32[$23>>2]|0;
               $170 = $165;
              }
              $168 = ($169|0)==($170|0);
              if (!($168)) {
               break;
              }
              if ($157) {
               $173 = (($150) + 1|0);
               $183 = $173;
              } else {
               $171 = (($$0$ph5$i$i$i) + 40|0);
               $172 = HEAP32[$171>>2]|0;
               $183 = $172;
              }
              $174 = HEAP32[$21>>2]|0;
              $$136 = $164 ? $22 : $174;
              if (!($157)) {
               $184 = (_memcmp($183,$$136,$169)|0);
               $phitmp$i$i = ($184|0)==(0);
               if ($phitmp$i$i) {
                break L56;
               } else {
                break;
               }
              }
              $175 = ($169|0)==(0);
              if ($175) {
               break L56;
              } else {
               $__lhs_sz$05$i$i$i = $169;$__lp$03$i$i$i = $183;$__rp$04$i$i$i = $$136;
              }
              while(1) {
               $176 = HEAP8[$__lp$03$i$i$i>>0]|0;
               $177 = HEAP8[$__rp$04$i$i$i>>0]|0;
               $178 = ($176<<24>>24)==($177<<24>>24);
               if (!($178)) {
                break L66;
               }
               $179 = (($__lhs_sz$05$i$i$i) + -1)|0;
               $180 = (($__lp$03$i$i$i) + 1|0);
               $181 = (($__rp$04$i$i$i) + 1|0);
               $182 = ($179|0)==(0);
               if ($182) {
                break L56;
               } else {
                $__lhs_sz$05$i$i$i = $179;$__lp$03$i$i$i = $180;$__rp$04$i$i$i = $181;
               }
              }
             }
            } while(0);
            $185 = HEAP8[$style_name>>0]|0;
            $186 = $185 & 1;
            $187 = ($186<<24>>24)==(0);
            $188 = HEAP32[$15>>2]|0;
            $$137 = $187 ? $24 : $188;
            if ((($72|0) == 2)) {
             $189 = (_strcmp($$137,803960)|0);
             $190 = ($189|0)==(0);
             if (!($190)) {
              break;
             }
            } else if ((($72|0) == 3)) {
             $193 = (_strcmp($$137,803976)|0);
             $194 = ($193|0)==(0);
             if (!($194)) {
              break;
             }
            } else if ((($72|0) == 0)) {
             $195 = (_strcmp($$137,803952)|0);
             $196 = ($195|0)==(0);
             if (!($196)) {
              break;
             }
            } else if ((($72|0) == 1)) {
             $191 = (_strcmp($$137,803968)|0);
             $192 = ($191|0)==(0);
             if (!($192)) {
              break;
             }
            } else {
             break;
            }
            __THREW__ = 0;
            $197 = (invoke_iii(2604,($134|0),($r|0))|0);
            $198 = __THREW__; __THREW__ = 0;
            $199 = $198&1;
            if ($199) {
             label = 95;
             break L6;
            }
            __THREW__ = 0;
            (invoke_iii(2233,($197|0),($font|0))|0);
            $200 = __THREW__; __THREW__ = 0;
            $201 = $200&1;
            if ($201) {
             label = 95;
             break L6;
            }
            $202 = HEAP32[$19>>2]|0;
            $203 = (($197) + 12|0);
            HEAP32[$203>>2] = $202;
           }
          }
         } while(0);
         if ((label|0) == 97) {
          label = 0;
          __THREW__ = 0;
          $226 = (invoke_iii(2604,($134|0),($r|0))|0);
          $227 = __THREW__; __THREW__ = 0;
          $228 = $227&1;
          if ($228) {
           label = 95;
           break L6;
          }
          __THREW__ = 0;
          (invoke_iii(2233,($226|0),($font|0))|0);
          $229 = __THREW__; __THREW__ = 0;
          $230 = $229&1;
          if ($230) {
           label = 95;
           break L6;
          }
          $231 = HEAP32[$19>>2]|0;
          $232 = (($226) + 12|0);
          HEAP32[$232>>2] = $231;
         }
         $233 = HEAP8[$font>>0]|0;
         $234 = $233 & 1;
         $235 = ($234<<24>>24)==(0);
         if (!($235)) {
          $236 = HEAP32[$21>>2]|0;
          __ZdlPv($236);
         }
         $237 = HEAP8[$r>>0]|0;
         $238 = $237 & 1;
         $239 = ($238<<24>>24)==(0);
         if (!($239)) {
          $240 = HEAP32[$20>>2]|0;
          __ZdlPv($240);
         }
        }
       }
       $245 = (($fontIndex$073) + 1)|0;
       $246 = HEAP32[$numFaces>>2]|0;
       $247 = ($245|0)<($246|0);
       if ($247) {
        $fontIndex$073 = $245;
       } else {
        break;
       }
      }
      $$pre = HEAP8[$style_name>>0]|0;
      $phitmp = $$pre & 1;
      $phitmp135 = ($phitmp<<24>>24)==(0);
      if (!($phitmp135)) {
       $248 = HEAP32[$15>>2]|0;
       __ZdlPv($248);
      }
      $249 = HEAP8[$family_name>>0]|0;
      $250 = $249 & 1;
      $251 = ($250<<24>>24)==(0);
      if (!($251)) {
       $252 = HEAP32[$14>>2]|0;
       __ZdlPv($252);
      }
      $253 = (($folderIndex$0123) + 1)|0;
      $254 = HEAP32[$7>>2]|0;
      $255 = HEAP32[$paths>>2]|0;
      $256 = $254;
      $257 = $255;
      $258 = (($256) - ($257))|0;
      $259 = (($258|0) / 12)&-1;
      $260 = ($253>>>0)<($259>>>0);
      if ($260) {
       $33 = $255;$folderIndex$0123 = $253;
      } else {
       $$lcssa75 = $254;$$lcssa85 = $255;
       break L4;
      }
     }
     do {
      if ((label|0) == 9) {
       $44 = ___cxa_find_matching_catch()|0;
       $45 = tempRet0;
       $lpad$phi$index = $44;$lpad$phi$index2 = $45;
       label = 11;
      }
      else if ((label|0) == 13) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        $46 = ___cxa_find_matching_catch()|0;
        $47 = tempRet0;
        $lpad$phi$index = $46;$lpad$phi$index2 = $47;
        label = 11;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 22) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        $206 = ___cxa_find_matching_catch()|0;
        $207 = tempRet0;
        $lpad$phi49$index = $206;$lpad$phi49$index7 = $207;
        label = 86;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 34) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        $212 = ___cxa_find_matching_catch()|0;
        $213 = tempRet0;
        $lpad$phi54$index = $212;$lpad$phi54$index12 = $213;
        label = 90;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 44) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        $216 = ___cxa_find_matching_catch()|0;
        $217 = tempRet0;
        $lpad$phi59$index = $216;$lpad$phi59$index17 = $217;
        label = 93;
        break;
       } else {
        // unreachable;
       }
      }
      else if ((label|0) == 84) {
       $204 = ___cxa_find_matching_catch()|0;
       $205 = tempRet0;
       $lpad$phi49$index = $204;$lpad$phi49$index7 = $205;
       label = 86;
      }
      else if ((label|0) == 88) {
       $210 = ___cxa_find_matching_catch()|0;
       $211 = tempRet0;
       $lpad$phi54$index = $210;$lpad$phi54$index12 = $211;
       label = 90;
      }
      else if ((label|0) == 91) {
       $214 = ___cxa_find_matching_catch()|0;
       $215 = tempRet0;
       $lpad$phi59$index = $214;$lpad$phi59$index17 = $215;
       label = 93;
      }
      else if ((label|0) == 95) {
       $220 = ___cxa_find_matching_catch()|0;
       $221 = tempRet0;
       $222 = HEAP8[$font>>0]|0;
       $223 = $222 & 1;
       $224 = ($223<<24>>24)==(0);
       if ($224) {
        $$0 = $220;$$01 = $221;
        label = 104;
       } else {
        $225 = HEAP32[$21>>2]|0;
        __ZdlPv($225);
        $$0 = $220;$$01 = $221;
        label = 104;
       }
      }
     } while(0);
     if ((label|0) == 11) {
      $$1 = $lpad$phi$index;$$12 = $lpad$phi$index2;
     }
     else if ((label|0) == 86) {
      $208 = $74 & 1;
      $209 = ($208<<24>>24)==(0);
      if ($209) {
       $$1 = $lpad$phi49$index;$$12 = $lpad$phi49$index7;
      } else {
       __ZdlPv($76);
       $$1 = $lpad$phi49$index;$$12 = $lpad$phi49$index7;
      }
     }
     else if ((label|0) == 90) {
      $$0 = $lpad$phi54$index;$$01 = $lpad$phi54$index12;
      label = 104;
     }
     else if ((label|0) == 93) {
      $218 = $114 & 1;
      $219 = ($218<<24>>24)==(0);
      if ($219) {
       $$0 = $lpad$phi59$index;$$01 = $lpad$phi59$index17;
       label = 104;
      } else {
       __ZdlPv($116);
       $$0 = $lpad$phi59$index;$$01 = $lpad$phi59$index17;
       label = 104;
      }
     }
     if ((label|0) == 104) {
      $241 = HEAP8[$r>>0]|0;
      $242 = $241 & 1;
      $243 = ($242<<24>>24)==(0);
      if ($243) {
       $$1 = $$0;$$12 = $$01;
      } else {
       $244 = HEAP32[$20>>2]|0;
       __ZdlPv($244);
       $$1 = $$0;$$12 = $$01;
      }
     }
     $261 = HEAP8[$style_name>>0]|0;
     $262 = $261 & 1;
     $263 = ($262<<24>>24)==(0);
     if (!($263)) {
      $264 = HEAP32[$15>>2]|0;
      __ZdlPv($264);
     }
     $265 = HEAP8[$family_name>>0]|0;
     $266 = $265 & 1;
     $267 = ($266<<24>>24)==(0);
     if ($267) {
      $$3 = $$1;$$34 = $$12;
      break L1;
     }
     $268 = HEAP32[$14>>2]|0;
     __ZdlPv($268);
     $$3 = $$1;$$34 = $$12;
     break L1;
    }
   } while(0);
   $269 = ($$lcssa85|0)==(0|0);
   if ($269) {
    STACKTOP = sp;return;
   }
   $270 = ($$lcssa75|0)==($$lcssa85|0);
   if ($270) {
    $280 = $$lcssa85;
   } else {
    $272 = $$lcssa75;
    while(1) {
     $271 = (($272) + -12|0);
     HEAP32[$7>>2] = $271;
     $273 = HEAP8[$271>>0]|0;
     $274 = $273 & 1;
     $275 = ($274<<24>>24)==(0);
     if ($275) {
      $277 = $271;
     } else {
      $278 = (($272) + -4|0);
      $279 = HEAP32[$278>>2]|0;
      __ZdlPv($279);
      $$pre$i$i$i$i$i7 = HEAP32[$7>>2]|0;
      $277 = $$pre$i$i$i$i$i7;
     }
     $276 = ($277|0)==($$lcssa85|0);
     if ($276) {
      break;
     } else {
      $272 = $277;
     }
    }
    $$pre$i$i$i8 = HEAP32[$paths>>2]|0;
    $280 = $$pre$i$i$i8;
   }
   __ZdlPv($280);
   STACKTOP = sp;return;
  }
 } while(0);
 $281 = HEAP32[$paths>>2]|0;
 $282 = ($281|0)==(0|0);
 if ($282) {
  ___resumeException($$3|0);
  // unreachable;
 }
 $283 = HEAP32[$7>>2]|0;
 $284 = ($283|0)==($281|0);
 if ($284) {
  $294 = $281;
 } else {
  $286 = $283;
  while(1) {
   $285 = (($286) + -12|0);
   HEAP32[$7>>2] = $285;
   $287 = HEAP8[$285>>0]|0;
   $288 = $287 & 1;
   $289 = ($288<<24>>24)==(0);
   if ($289) {
    $291 = $285;
   } else {
    $292 = (($286) + -4|0);
    $293 = HEAP32[$292>>2]|0;
    __ZdlPv($293);
    $$pre$i$i$i$i$i = HEAP32[$7>>2]|0;
    $291 = $$pre$i$i$i$i$i;
   }
   $290 = ($291|0)==($281|0);
   if ($290) {
    break;
   } else {
    $286 = $291;
   }
  }
  $$pre$i$i$i = HEAP32[$paths>>2]|0;
  $294 = $$pre$i$i$i;
 }
 __ZdlPv($294);
 ___resumeException($$3|0);
 // unreachable;
}
function __ZNSt3__13mapIN20TextRenderingPrivate7FontRefENS1_6OSFontENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__nd$0$in$i = 0, $__p$0$i$i$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $11 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $11;
   $$0$i = $11;$48 = $11;
  } else {
   $__nd$0$in$i = $1;
   while(1) {
    $3 = (($__nd$0$in$i) + 16|0);
    $4 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($__k,$3)|0);
    if ($4) {
     $5 = HEAP32[$__nd$0$in$i>>2]|0;
     $6 = ($5|0)==(0|0);
     if ($6) {
      label = 4;
      break;
     } else {
      $__nd$0$in$i = $5;
      continue;
     }
    }
    $7 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($3,$__k)|0);
    if (!($7)) {
     label = 8;
     break;
    }
    $8 = (($__nd$0$in$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     label = 7;
     break;
    } else {
     $__nd$0$in$i = $9;
    }
   }
   if ((label|0) == 4) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$48 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 7) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $8;$48 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$48 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $12 = HEAP32[$$0$i>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $__r$0 = $12;
  $57 = (($__r$0) + 32|0);
  STACKTOP = sp;return ($57|0);
 }
 $14 = (__Znwj(48)|0);
 $15 = (($14) + 16|0);
 $16 = HEAP8[$__k>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 L17: do {
  if ($18) {
   ;HEAP32[$15+0>>2]=HEAP32[$__k+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$__k+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$__k+8>>2]|0;
  } else {
   $19 = (($__k) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($__k) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22>>>0)>(4294967279);
   do {
    if ($23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      // unreachable;
     }
    } else {
     $26 = ($22>>>0)<(11);
     if ($26) {
      $27 = $22 << 1;
      $28 = $27&255;
      HEAP8[$15>>0] = $28;
      $29 = (($14) + 17|0);
      $__p$0$i$i$i$i$i$i$i = $29;
     } else {
      $30 = (($22) + 16)|0;
      $31 = $30 & -16;
      __THREW__ = 0;
      $32 = (invoke_ii(2988,($31|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = (($14) + 24|0);
      HEAP32[$35>>2] = $32;
      $36 = $31 | 1;
      HEAP32[$15>>2] = $36;
      $37 = (($14) + 20|0);
      HEAP32[$37>>2] = $22;
      $__p$0$i$i$i$i$i$i$i = $32;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($20|0),($22|0))|0;
     $38 = (($__p$0$i$i$i$i$i$i$i) + ($22)|0);
     HEAP8[$38>>0] = 0;
     break L17;
    }
   } while(0);
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   $41 = ($14|0)==(0|0);
   if ($41) {
    ___resumeException($39|0);
    // unreachable;
   }
   __ZdlPv($14);
   ___resumeException($39|0);
   // unreachable;
  }
 } while(0);
 $42 = (($14) + 28|0);
 $43 = (($__k) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 HEAP32[$42>>2] = $44;
 $45 = (($14) + 32|0);
 ;HEAP32[$45+0>>2]=0|0;HEAP32[$45+4>>2]=0|0;HEAP32[$45+8>>2]=0|0;HEAP32[$45+12>>2]=0|0;
 HEAP32[$14>>2] = 0;
 $46 = (($14) + 4|0);
 HEAP32[$46>>2] = 0;
 $47 = (($14) + 8|0);
 HEAP32[$47>>2] = $48;
 HEAP32[$$0$i>>2] = $14;
 $49 = HEAP32[$this>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  $53 = $14;
 } else {
  HEAP32[$this>>2] = $50;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $53 = $$pre$i;
 }
 $52 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($52,$53);
 $54 = (($this) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 1)|0;
 HEAP32[$54>>2] = $56;
 $__r$0 = $14;
 $57 = (($__r$0) + 32|0);
 STACKTOP = sp;return ($57|0);
}
function __ZN20TextRenderingPrivate15DynamicFontData17GetFaceForFontRefERNS_7FontRefERNSt3__16vectorI4PPtrINS_4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEE($this,$r,$fallbacks) {
 $this = $this|0;
 $r = $r|0;
 $fallbacks = $fallbacks|0;
 var $$0 = 0, $$0$ph5$i$i$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph5$i$i$i$pn = 0, $$0$ph5$i$i$i9 = 0, $$0$ph7$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$0$ph7$i$i$i3 = 0, $$01$ph6$i$in$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$01$ph6$i$in$i$i4 = 0, $$013$i$in$i$i = 0, $$013$i$in$i$i$i = 0, $$013$i$in$i$i6 = 0, $$1 = 0, $$1$in = 0, $$pre = 0, $$pre$i = 0, $$pre$pre = 0, $$pre46 = 0;
 var $$pre48 = 0, $$pre49 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i$i = 0, $font = 0, $phitmp$i = 0, $pos$i$i$i$i13 = 0, $temp$0$i = 0, $temp$0$i17 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pos$i$i$i$i13 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $font = sp + 16|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 4|0);
 $6 = ($4|0)==(0|0);
 if (!($6)) {
  $$0$ph7$i$i$i = $5;$$01$ph6$i$in$i$i = $4;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $7 = (($$013$i$in$i$i) + 16|0);
    $8 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($7,$r)|0);
    if (!($8)) {
     break;
    }
    $11 = (($$013$i$in$i$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $12;
    }
   }
   $9 = HEAP32[$$013$i$in$i$i>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $9;
   }
  }
  $14 = ($$0$ph5$i$i$i|0)==($5|0);
  if (!($14)) {
   $15 = (($$0$ph5$i$i$i) + 16|0);
   $16 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($r,$15)|0);
   if (!($16)) {
    $$0$ph5$i$i$i$pn = $$0$ph5$i$i$i;
    $$1$in = (($$0$ph5$i$i$i$pn) + 32|0);
    $$1 = HEAP32[$$1$in>>2]|0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $17 = HEAP32[$fallbacks>>2]|0;
 $18 = (($fallbacks) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 L12: do {
  if (!($20)) {
   $22 = $17;
   L14: while(1) {
    $21 = HEAP32[$22>>2]|0;
    $23 = ($21|0)==(0);
    do {
     if (!($23)) {
      HEAP32[$2>>2] = $21;
      $24 = HEAP32[560624>>2]|0;
      $25 = ($24|0)==(0|0);
      if ($25) {
       label = 19;
      } else {
       $26 = (($24) + 36|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = (($24) + 4|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($27|0)==($29|0);
       do {
        if ($30) {
         $31 = (($24) + 28|0);
         $32 = HEAP32[$31>>2]|0;
         $33 = (($24) + 32|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = (($32) + ($34<<3)|0);
         $51 = $35;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i13,$24,$2);
         $36 = HEAP32[$pos$i$i$i$i13>>2]|0;
         $37 = ($36|0)==(-1);
         $38 = (($24) + 28|0);
         $39 = HEAP32[$38>>2]|0;
         if ($37) {
          $40 = (($24) + 32|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = (($39) + ($41<<3)|0);
          $51 = $42;
          break;
         } else {
          $43 = (($39) + ($36<<3)|0);
          $51 = $43;
          break;
         }
        }
       } while(0);
       $44 = HEAP32[560624>>2]|0;
       $45 = (($44) + 28|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = (($44) + 32|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = (($46) + ($48<<3)|0);
       $50 = ($51|0)==($49|0);
       if ($50) {
        label = 19;
       } else {
        $52 = (($51) + 4|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($53|0)==(0|0);
        if ($54) {
         label = 19;
        } else {
         $59 = $44;
        }
       }
      }
      if ((label|0) == 19) {
       label = 0;
       $55 = HEAP32[$22>>2]|0;
       $56 = (__Z31ReadObjectFromPersistentManageri($55)|0);
       $phitmp$i = ($56|0)==(0|0);
       if ($phitmp$i) {
        break;
       }
       $$pre49 = HEAP32[560624>>2]|0;
       $59 = $$pre49;
      }
      $57 = HEAP32[$22>>2]|0;
      HEAP32[$1>>2] = $57;
      $58 = ($59|0)==(0|0);
      if ($58) {
       label = 29;
      } else {
       $60 = (($59) + 36|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($59) + 4|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = ($61|0)==($63|0);
       do {
        if ($64) {
         $65 = (($59) + 28|0);
         $66 = HEAP32[$65>>2]|0;
         $67 = (($59) + 32|0);
         $68 = HEAP32[$67>>2]|0;
         $69 = (($66) + ($68<<3)|0);
         $85 = $69;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i13,$59,$1);
         $70 = HEAP32[$pos$i$i$i$i13>>2]|0;
         $71 = ($70|0)==(-1);
         $72 = (($59) + 28|0);
         $73 = HEAP32[$72>>2]|0;
         if ($71) {
          $74 = (($59) + 32|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = (($73) + ($75<<3)|0);
          $85 = $76;
          break;
         } else {
          $77 = (($73) + ($70<<3)|0);
          $85 = $77;
          break;
         }
        }
       } while(0);
       $78 = HEAP32[560624>>2]|0;
       $79 = (($78) + 28|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = (($78) + 32|0);
       $82 = HEAP32[$81>>2]|0;
       $83 = (($80) + ($82<<3)|0);
       $84 = ($85|0)==($83|0);
       if ($84) {
        label = 29;
       } else {
        $86 = (($85) + 4|0);
        $87 = HEAP32[$86>>2]|0;
        $88 = ($87|0)==(0|0);
        if ($88) {
         label = 29;
        } else {
         $temp$0$i = $87;
        }
       }
      }
      if ((label|0) == 29) {
       label = 0;
       $89 = HEAP32[$22>>2]|0;
       $90 = (__Z31ReadObjectFromPersistentManageri($89)|0);
       $temp$0$i = $90;
      }
      $91 = (($temp$0$i) + 216|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($92) + 4|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (($92) + 4|0);
      $96 = ($94|0)==(0|0);
      if ($96) {
       label = 37;
      } else {
       $$0$ph7$i$i$i3 = $95;$$01$ph6$i$in$i$i4 = $94;
       L46: while(1) {
        $$013$i$in$i$i6 = $$01$ph6$i$in$i$i4;
        while(1) {
         $97 = (($$013$i$in$i$i6) + 16|0);
         $98 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($97,$r)|0);
         if (!($98)) {
          break;
         }
         $101 = (($$013$i$in$i$i6) + 4|0);
         $102 = HEAP32[$101>>2]|0;
         $103 = ($102|0)==(0|0);
         if ($103) {
          $$0$ph5$i$i$i9 = $$0$ph7$i$i$i3;
          break L46;
         } else {
          $$013$i$in$i$i6 = $102;
         }
        }
        $99 = HEAP32[$$013$i$in$i$i6>>2]|0;
        $100 = ($99|0)==(0|0);
        if ($100) {
         $$0$ph5$i$i$i9 = $$013$i$in$i$i6;
         break;
        } else {
         $$0$ph7$i$i$i3 = $$013$i$in$i$i6;$$01$ph6$i$in$i$i4 = $99;
        }
       }
       $104 = ($$0$ph5$i$i$i9|0)==($95|0);
       if ($104) {
        label = 37;
       } else {
        $105 = (($$0$ph5$i$i$i9) + 16|0);
        $106 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($r,$105)|0);
        if ($106) {
         label = 37;
        } else {
         $145 = $$0$ph5$i$i$i9;
        }
       }
      }
      if ((label|0) == 37) {
       label = 0;
       $145 = $95;
      }
      $107 = HEAP32[$22>>2]|0;
      HEAP32[$0>>2] = $107;
      $108 = HEAP32[560624>>2]|0;
      $109 = ($108|0)==(0|0);
      if ($109) {
       label = 46;
      } else {
       $110 = (($108) + 36|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = (($108) + 4|0);
       $113 = HEAP32[$112>>2]|0;
       $114 = ($111|0)==($113|0);
       do {
        if ($114) {
         $115 = (($108) + 28|0);
         $116 = HEAP32[$115>>2]|0;
         $117 = (($108) + 32|0);
         $118 = HEAP32[$117>>2]|0;
         $119 = (($116) + ($118<<3)|0);
         $135 = $119;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i13,$108,$0);
         $120 = HEAP32[$pos$i$i$i$i13>>2]|0;
         $121 = ($120|0)==(-1);
         $122 = (($108) + 28|0);
         $123 = HEAP32[$122>>2]|0;
         if ($121) {
          $124 = (($108) + 32|0);
          $125 = HEAP32[$124>>2]|0;
          $126 = (($123) + ($125<<3)|0);
          $135 = $126;
          break;
         } else {
          $127 = (($123) + ($120<<3)|0);
          $135 = $127;
          break;
         }
        }
       } while(0);
       $128 = HEAP32[560624>>2]|0;
       $129 = (($128) + 28|0);
       $130 = HEAP32[$129>>2]|0;
       $131 = (($128) + 32|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = (($130) + ($132<<3)|0);
       $134 = ($135|0)==($133|0);
       if ($134) {
        label = 46;
       } else {
        $136 = (($135) + 4|0);
        $137 = HEAP32[$136>>2]|0;
        $138 = ($137|0)==(0|0);
        if ($138) {
         label = 46;
        } else {
         $temp$0$i17 = $137;
        }
       }
      }
      if ((label|0) == 46) {
       label = 0;
       $139 = HEAP32[$22>>2]|0;
       $140 = (__Z31ReadObjectFromPersistentManageri($139)|0);
       $temp$0$i17 = $140;
      }
      $141 = (($temp$0$i17) + 216|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = (($142) + 4|0);
      $144 = ($145|0)==($143|0);
      if (!($144)) {
       $$0$ph5$i$i$i$pn = $145;
       break L14;
      }
     }
    } while(0);
    $146 = (($22) + 4|0);
    $147 = HEAP32[$18>>2]|0;
    $148 = ($146|0)==($147|0);
    if ($148) {
     break L12;
    } else {
     $22 = $146;
    }
   }
   $$1$in = (($$0$ph5$i$i$i$pn) + 32|0);
   $$1 = HEAP32[$$1$in>>2]|0;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 $149 = HEAP32[803728>>2]|0;
 $150 = ($149|0)==(0|0);
 if ($150) {
  __ZN20TextRenderingPrivate13ReadFontFilesEv();
  $$pre$i = HEAP32[803728>>2]|0;
  $152 = $$pre$i;
 } else {
  $152 = $149;
 }
 $151 = (($152) + 4|0);
 $153 = HEAP32[$151>>2]|0;
 $154 = (($152) + 4|0);
 $155 = ($153|0)==(0|0);
 if ($155) {
  label = 66;
 } else {
  $$0$ph7$i$i$i$i = $154;$$01$ph6$i$in$i$i$i = $153;
  L77: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $156 = (($$013$i$in$i$i$i) + 16|0);
    $157 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($156,$r)|0);
    if (!($157)) {
     break;
    }
    $160 = (($$013$i$in$i$i$i) + 4|0);
    $161 = HEAP32[$160>>2]|0;
    $162 = ($161|0)==(0|0);
    if ($162) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L77;
    } else {
     $$013$i$in$i$i$i = $161;
    }
   }
   $158 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $159 = ($158|0)==(0|0);
   if ($159) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $158;
   }
  }
  $163 = ($$0$ph5$i$i$i$i|0)==($154|0);
  if ($163) {
   label = 66;
  } else {
   $164 = (($$0$ph5$i$i$i$i) + 16|0);
   $165 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($r,$164)|0);
   if ($165) {
    label = 66;
   } else {
    $166 = (($$0$ph5$i$i$i$i) + 32|0);
    $167 = HEAP8[$166>>0]|0;
    $168 = $167 & 1;
    $169 = ($168<<24>>24)==(0);
    if ($169) {
     ;HEAP32[$font+0>>2]=HEAP32[$166+0>>2]|0;HEAP32[$font+4>>2]=HEAP32[$166+4>>2]|0;HEAP32[$font+8>>2]=HEAP32[$166+8>>2]|0;
     $$pre$pre = HEAP8[$font>>0]|0;
     $$pre = $$pre$pre;
    } else {
     $170 = (($$0$ph5$i$i$i$i) + 40|0);
     $171 = HEAP32[$170>>2]|0;
     $172 = (($$0$ph5$i$i$i$i) + 36|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = ($173>>>0)>(4294967279);
     if ($174) {
      __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
      // unreachable;
     }
     $175 = ($173>>>0)<(11);
     if ($175) {
      $176 = $173 << 1;
      $177 = $176&255;
      HEAP8[$font>>0] = $177;
      $178 = (($font) + 1|0);
      $$pre48 = $177;$__p$0$i$i$i$i$i$i = $178;
     } else {
      $179 = (($173) + 16)|0;
      $180 = $179 & -16;
      $181 = (__Znwj($180)|0);
      $182 = (($font) + 8|0);
      HEAP32[$182>>2] = $181;
      $183 = $180 | 1;
      HEAP32[$font>>2] = $183;
      $184 = (($font) + 4|0);
      HEAP32[$184>>2] = $173;
      $185 = $183&255;
      $$pre48 = $185;$__p$0$i$i$i$i$i$i = $181;
     }
     _memcpy(($__p$0$i$i$i$i$i$i|0),($171|0),($173|0))|0;
     $186 = (($__p$0$i$i$i$i$i$i) + ($173)|0);
     HEAP8[$186>>0] = 0;
     $$pre = $$pre48;
    }
    $187 = (($font) + 12|0);
    $188 = (($$0$ph5$i$i$i$i) + 44|0);
    $189 = HEAP32[$188>>2]|0;
    HEAP32[$187>>2] = $189;
    $190 = $$pre & 1;
    $191 = ($190<<24>>24)==(0);
    if ($191) {
     $195 = $$pre;$227 = $font;$228 = $189;
     label = 69;
    } else {
     $192 = (($font) + 4|0);
     $193 = HEAP32[$192>>2]|0;
     $198 = $193;$207 = $189;$214 = $font;$229 = 0;$230 = $$pre;
    }
   }
  }
 }
 if ((label|0) == 66) {
  ;HEAP32[$font+0>>2]=0|0;HEAP32[$font+4>>2]=0|0;HEAP32[$font+8>>2]=0|0;HEAP32[$font+12>>2]=0|0;
  $195 = 0;$227 = $font;$228 = 0;
  label = 69;
 }
 if ((label|0) == 69) {
  $194 = $195&255;
  $196 = $194 >>> 1;
  $198 = $196;$207 = $228;$214 = $227;$229 = 1;$230 = $195;
 }
 $197 = ($198|0)==(0);
 do {
  if ($197) {
   $$0 = 0;$223 = $230;
  } else {
   $199 = HEAP32[803736>>2]|0;
   if ($229) {
    $202 = (($font) + 1|0);
    $206 = $202;
   } else {
    $200 = (($font) + 8|0);
    $201 = HEAP32[$200>>2]|0;
    $206 = $201;
   }
   __THREW__ = 0;
   $203 = (invoke_iii(2605,($this|0),($r|0))|0);
   $204 = __THREW__; __THREW__ = 0;
   $205 = $204&1;
   if (!($205)) {
    __THREW__ = 0;
    (invoke_iiiii(274,($199|0),($206|0),($207|0),($203|0))|0);
    $208 = __THREW__; __THREW__ = 0;
    $209 = $208&1;
    if (!($209)) {
     __THREW__ = 0;
     $210 = (invoke_iii(2605,($this|0),($r|0))|0);
     $211 = __THREW__; __THREW__ = 0;
     $212 = $211&1;
     if (!($212)) {
      $213 = HEAP32[$210>>2]|0;
      $$pre46 = HEAP8[$214>>0]|0;
      $$0 = $213;$223 = $$pre46;
      break;
     }
    }
   }
   $215 = ___cxa_find_matching_catch()|0;
   $216 = tempRet0;
   $217 = HEAP8[$214>>0]|0;
   $218 = $217 & 1;
   $219 = ($218<<24>>24)==(0);
   if ($219) {
    ___resumeException($215|0);
    // unreachable;
   }
   $220 = (($font) + 8|0);
   $221 = HEAP32[$220>>2]|0;
   __ZdlPv($221);
   ___resumeException($215|0);
   // unreachable;
  }
 } while(0);
 $222 = $223 & 1;
 $224 = ($222<<24>>24)==(0);
 if ($224) {
  STACKTOP = sp;return ($$0|0);
 }
 $225 = (($font) + 8|0);
 $226 = HEAP32[$225>>2]|0;
 __ZdlPv($226);
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__13mapIN20TextRenderingPrivate7FontRefEP11FT_FaceRec_NS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__nd$0$in$i = 0, $__p$0$i$i$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $11 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $11;
   $$0$i = $11;$48 = $11;
  } else {
   $__nd$0$in$i = $1;
   while(1) {
    $3 = (($__nd$0$in$i) + 16|0);
    $4 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($__k,$3)|0);
    if ($4) {
     $5 = HEAP32[$__nd$0$in$i>>2]|0;
     $6 = ($5|0)==(0|0);
     if ($6) {
      label = 4;
      break;
     } else {
      $__nd$0$in$i = $5;
      continue;
     }
    }
    $7 = (__ZNK20TextRenderingPrivate7FontRefltERKS0_($3,$__k)|0);
    if (!($7)) {
     label = 8;
     break;
    }
    $8 = (($__nd$0$in$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     label = 7;
     break;
    } else {
     $__nd$0$in$i = $9;
    }
   }
   if ((label|0) == 4) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$48 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 7) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $8;$48 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$48 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $12 = HEAP32[$$0$i>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $__r$0 = $12;
  $57 = (($__r$0) + 32|0);
  STACKTOP = sp;return ($57|0);
 }
 $14 = (__Znwj(36)|0);
 $15 = (($14) + 16|0);
 $16 = HEAP8[$__k>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 L17: do {
  if ($18) {
   ;HEAP32[$15+0>>2]=HEAP32[$__k+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$__k+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$__k+8>>2]|0;
  } else {
   $19 = (($__k) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($__k) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22>>>0)>(4294967279);
   do {
    if ($23) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      // unreachable;
     }
    } else {
     $26 = ($22>>>0)<(11);
     if ($26) {
      $27 = $22 << 1;
      $28 = $27&255;
      HEAP8[$15>>0] = $28;
      $29 = (($14) + 17|0);
      $__p$0$i$i$i$i$i$i$i = $29;
     } else {
      $30 = (($22) + 16)|0;
      $31 = $30 & -16;
      __THREW__ = 0;
      $32 = (invoke_ii(2988,($31|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = (($14) + 24|0);
      HEAP32[$35>>2] = $32;
      $36 = $31 | 1;
      HEAP32[$15>>2] = $36;
      $37 = (($14) + 20|0);
      HEAP32[$37>>2] = $22;
      $__p$0$i$i$i$i$i$i$i = $32;
     }
     _memcpy(($__p$0$i$i$i$i$i$i$i|0),($20|0),($22|0))|0;
     $38 = (($__p$0$i$i$i$i$i$i$i) + ($22)|0);
     HEAP8[$38>>0] = 0;
     break L17;
    }
   } while(0);
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   $41 = ($14|0)==(0|0);
   if ($41) {
    ___resumeException($39|0);
    // unreachable;
   }
   __ZdlPv($14);
   ___resumeException($39|0);
   // unreachable;
  }
 } while(0);
 $42 = (($14) + 28|0);
 $43 = (($__k) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 HEAP32[$42>>2] = $44;
 $45 = (($14) + 32|0);
 HEAP32[$45>>2] = 0;
 HEAP32[$14>>2] = 0;
 $46 = (($14) + 4|0);
 HEAP32[$46>>2] = 0;
 $47 = (($14) + 8|0);
 HEAP32[$47>>2] = $48;
 HEAP32[$$0$i>>2] = $14;
 $49 = HEAP32[$this>>2]|0;
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if ($51) {
  $53 = $14;
 } else {
  HEAP32[$this>>2] = $50;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $53 = $$pre$i;
 }
 $52 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($52,$53);
 $54 = (($this) + 8|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 1)|0;
 HEAP32[$54>>2] = $56;
 $__r$0 = $14;
 $57 = (($__r$0) + 32|0);
 STACKTOP = sp;return ($57|0);
}
function __ZN20TextRenderingPrivate15DynamicFontData36GetFaceForCharacterIfAvailableInFontERNS_7FontRefERNSt3__16vectorI4PPtrINS_4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEEj($this,$r,$fallbacks,$unicodeChar) {
 $this = $this|0;
 $r = $r|0;
 $fallbacks = $fallbacks|0;
 $unicodeChar = $unicodeChar|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, $r2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $r2 = sp;
 $0 = (__ZN20TextRenderingPrivate15DynamicFontData17GetFaceForFontRefERNS_7FontRefERNSt3__16vectorI4PPtrINS_4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEE($this,$r,$fallbacks)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (_FT_Get_Char_Index($0,$unicodeChar)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $$1 = $0;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $4 = (($r) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $7 = HEAP8[$r>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  ;HEAP32[$r2+0>>2]=HEAP32[$r+0>>2]|0;HEAP32[$r2+4>>2]=HEAP32[$r+4>>2]|0;HEAP32[$r2+8>>2]=HEAP32[$r+8>>2]|0;
 } else {
  $10 = (($r) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($r) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13>>>0)>(4294967279);
  if ($14) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $15 = ($13>>>0)<(11);
  if ($15) {
   $16 = $13 << 1;
   $17 = $16&255;
   HEAP8[$r2>>0] = $17;
   $18 = (($r2) + 1|0);
   $__p$0$i$i$i$i$i = $18;
  } else {
   $19 = (($13) + 16)|0;
   $20 = $19 & -16;
   $21 = (__Znwj($20)|0);
   $22 = (($r2) + 8|0);
   HEAP32[$22>>2] = $21;
   $23 = $20 | 1;
   HEAP32[$r2>>2] = $23;
   $24 = (($r2) + 4|0);
   HEAP32[$24>>2] = $13;
   $__p$0$i$i$i$i$i = $21;
  }
  _memcpy(($__p$0$i$i$i$i$i|0),($11|0),($13|0))|0;
  $25 = (($__p$0$i$i$i$i$i) + ($13)|0);
  HEAP8[$25>>0] = 0;
 }
 $26 = (($r2) + 12|0);
 HEAP32[$26>>2] = 0;
 __THREW__ = 0;
 $27 = (invoke_iiii(1594,($this|0),($r2|0),($fallbacks|0))|0);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 do {
  if (!($29)) {
   $30 = ($27|0)==(0|0);
   if (!($30)) {
    __THREW__ = 0;
    $31 = (invoke_iii(2606,($27|0),($unicodeChar|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = ($31|0)==(0);
    if (!($34)) {
     $42 = HEAP8[$r2>>0]|0;
     $43 = $42 & 1;
     $44 = ($43<<24>>24)==(0);
     if ($44) {
      $$1 = $27;
      STACKTOP = sp;return ($$1|0);
     }
     $45 = (($r2) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     __ZdlPv($46);
     $$1 = $27;
     STACKTOP = sp;return ($$1|0);
    }
   }
   $47 = HEAP8[$r2>>0]|0;
   $48 = $47 & 1;
   $49 = ($48<<24>>24)==(0);
   if ($49) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $50 = (($r2) + 8|0);
   $51 = HEAP32[$50>>2]|0;
   __ZdlPv($51);
   $$1 = 0;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 $37 = HEAP8[$r2>>0]|0;
 $38 = $37 & 1;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  ___resumeException($35|0);
  // unreachable;
 }
 $40 = (($r2) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 __ZdlPv($41);
 ___resumeException($35|0);
 // unreachable;
 return 0|0;
}
function __ZN20TextRenderingPrivate15DynamicFontData19GetFaceForCharacterERNSt3__16vectorI8UnityStr13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEERNS2_I4PPtrINS_4FontEES4_ISB_LS5_27ELi16EEEEjj($this,$fonts,$fallbacks,$style,$unicodeChar) {
 $this = $this|0;
 $fonts = $fonts|0;
 $fallbacks = $fallbacks|0;
 $style = $style|0;
 $unicodeChar = $unicodeChar|0;
 var $$ = 0, $$0$ = 0, $$0$lcssa = 0, $$01$be$i$i$i$i = 0, $$01$be$i$i$i$i42 = 0, $$014$i$i$i$i = 0, $$014$i$i$i$i41 = 0, $$0174 = 0, $$02 = 0, $$04 = 0, $$09 = 0, $$1 = 0, $$110 = 0, $$15 = 0, $$182 = 0, $$183 = 0, $$184 = 0, $$185 = 0, $$2$ = 0, $$211 = 0;
 var $$2113 = 0, $$26 = 0, $$312 = 0, $$37 = 0, $$4 = 0, $$413 = 0, $$48 = 0, $$5 = 0, $$514 = 0, $$6 = 0, $$615 = 0, $$pre = 0, $$pre181 = 0, $$sum$i$i = 0, $$sum$i$i39 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__m1$0$i$i$i$i = 0, $__m1$0$i$i$i$i44 = 0, $__m2$0$i$i$i$i = 0;
 var $__m2$0$i$i$i$i45 = 0, $__p$0$i$i = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i76 = 0, $__p$0$i$i$i$i$i94 = 0, $__p$0$i$i$i$i91 = 0, $__p$0$i$i27 = 0, $__p$0$i$i55 = 0, $__p$0$i$i64 = 0, $cond = 0, $lpad$phi$index = 0, $lpad$phi$index22 = 0, $lpad$phi120$index = 0, $lpad$phi120$index2 = 0, $lpad$phi125$index = 0, $lpad$phi125$index7 = 0, $lpad$phi130$index = 0, $lpad$phi130$index12 = 0, $lpad$phi135$index = 0;
 var $lpad$phi135$index17 = 0, $name = 0, $r = 0, $r2 = 0, $st$0 = 0, $st$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $name = sp + 136|0;
 $r = sp + 120|0;
 $0 = sp + 104|0;
 $1 = sp + 92|0;
 $2 = sp + 80|0;
 $3 = sp + 68|0;
 $4 = sp + 44|0;
 $5 = sp + 32|0;
 $6 = sp + 16|0;
 $r2 = sp;
 $7 = sp + 56|0;
 $8 = HEAP32[$fonts>>2]|0;
 $9 = (($fonts) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 L1: do {
  if ($11) {
   $$0$lcssa = 0;
  } else {
   $12 = (($name) + 1|0);
   $13 = (($r) + 12|0);
   $14 = (($6) + 12|0);
   $15 = (($6) + 8|0);
   $16 = (($name) + 8|0);
   $17 = (($name) + 4|0);
   $18 = (($6) + 1|0);
   $19 = (($6) + 4|0);
   $20 = (($4) + 1|0);
   $21 = (($5) + 1|0);
   $22 = (($4) + 8|0);
   $23 = (($5) + 8|0);
   $24 = (($3) + 8|0);
   $25 = (($5) + 4|0);
   $26 = (($4) + 4|0);
   $27 = (($1) + 1|0);
   $28 = (($2) + 1|0);
   $29 = $style | 1;
   $30 = (($1) + 8|0);
   $31 = (($2) + 8|0);
   $32 = (($0) + 8|0);
   $33 = (($2) + 4|0);
   $34 = (($1) + 4|0);
   $35 = (($r) + 8|0);
   $36 = (($r) + 1|0);
   $37 = (($r) + 4|0);
   $$0174 = 0;$42 = $8;
   L3: while(1) {
    $41 = HEAP8[$42>>0]|0;
    $43 = $41 & 1;
    $44 = ($43<<24>>24)==(0);
    if ($44) {
     $45 = (($42) + 1|0);
     $46 = $41&255;
     $47 = $46 >>> 1;
     $54 = $47;$62 = $45;
    } else {
     $48 = (($42) + 8|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = (($42) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51>>>0)>(4294967279);
     if ($52) {
      label = 7;
      break;
     } else {
      $54 = $51;$62 = $49;
     }
    }
    $53 = ($54>>>0)<(11);
    if ($53) {
     $55 = $54 << 1;
     $56 = $55&255;
     HEAP8[$name>>0] = $56;
     $65 = $56;$__p$0$i$i$i$i = $12;
    } else {
     $57 = (($54) + 16)|0;
     $58 = $57 & -16;
     $59 = (__Znwj($58)|0);
     HEAP32[$16>>2] = $59;
     $60 = $58 | 1;
     HEAP32[$name>>2] = $60;
     HEAP32[$17>>2] = $54;
     $61 = $60&255;
     $65 = $61;$__p$0$i$i$i$i = $59;
    }
    _memcpy(($__p$0$i$i$i$i|0),($62|0),($54|0))|0;
    $63 = (($__p$0$i$i$i$i) + ($54)|0);
    HEAP8[$63>>0] = 0;
    $64 = $65 & 1;
    $66 = ($64<<24>>24)==(0);
    if ($66) {
     ;HEAP32[$r+0>>2]=HEAP32[$name+0>>2]|0;HEAP32[$r+4>>2]=HEAP32[$name+4>>2]|0;HEAP32[$r+8>>2]=HEAP32[$name+8>>2]|0;
    } else {
     $67 = HEAP32[$16>>2]|0;
     $68 = HEAP32[$17>>2]|0;
     $69 = ($68>>>0)>(4294967279);
     if ($69) {
      label = 14;
      break;
     }
     $72 = ($68>>>0)<(11);
     if ($72) {
      $73 = $68 << 1;
      $74 = $73&255;
      HEAP8[$r>>0] = $74;
      $__p$0$i$i$i$i$i = $36;
     } else {
      $75 = (($68) + 16)|0;
      $76 = $75 & -16;
      __THREW__ = 0;
      $77 = (invoke_ii(2988,($76|0))|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       label = 23;
       break;
      }
      HEAP32[$35>>2] = $77;
      $80 = $76 | 1;
      HEAP32[$r>>2] = $80;
      HEAP32[$37>>2] = $68;
      $__p$0$i$i$i$i$i = $77;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($67|0),($68|0))|0;
     $81 = (($__p$0$i$i$i$i$i) + ($68)|0);
     HEAP8[$81>>0] = 0;
    }
    HEAP32[$13>>2] = $style;
    __THREW__ = 0;
    $82 = (invoke_iiiii(275,($this|0),($r|0),($fallbacks|0),($unicodeChar|0))|0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     label = 26;
     break;
    }
    $85 = ($82|0)==(0|0);
    if ($85) {
     $94 = HEAP8[$name>>0]|0;
     $95 = $94 & 1;
     $96 = ($95<<24>>24)==(0);
     if ($96) {
      $98 = $94&255;
      $99 = $98 >>> 1;
      $101 = $99;
     } else {
      $97 = HEAP32[$17>>2]|0;
      $101 = $97;
     }
     $100 = ($101>>>0)<(5);
     L30: do {
      if ($100) {
       $203 = $94;$st$0 = $style;
      } else {
       $102 = HEAP32[$16>>2]|0;
       $$182 = $96 ? $12 : $102;
       $103 = (($$182) + ($101)|0);
       $104 = $$182;
       $105 = ($101|0)<(5);
       if ($105) {
        $203 = $94;$st$0 = $style;
       } else {
        $$sum$i$i = (($101) + -4)|0;
        $106 = (($$182) + ($$sum$i$i)|0);
        $107 = ($$sum$i$i|0)==(0);
        if ($107) {
         $203 = $94;$st$0 = $style;
        } else {
         $$014$i$i$i$i = $$182;
         L33: while(1) {
          $108 = HEAP8[$$014$i$i$i$i>>0]|0;
          $109 = ($108<<24>>24)==(32);
          if ($109) {
           $__m1$0$i$i$i$i = $$014$i$i$i$i;$__m2$0$i$i$i$i = 803744;
           while(1) {
            $111 = (($__m2$0$i$i$i$i) + 1|0);
            $112 = ($111|0)==(((803744 + 5|0))|0);
            if ($112) {
             break L33;
            }
            $113 = (($__m1$0$i$i$i$i) + 1|0);
            $114 = HEAP8[$113>>0]|0;
            $115 = HEAP8[$111>>0]|0;
            $116 = ($114<<24>>24)==($115<<24>>24);
            if ($116) {
             $__m1$0$i$i$i$i = $113;$__m2$0$i$i$i$i = $111;
            } else {
             break;
            }
           }
          }
          $$01$be$i$i$i$i = (($$014$i$i$i$i) + 1|0);
          $110 = ($$01$be$i$i$i$i|0)==($106|0);
          if ($110) {
           $203 = $94;$st$0 = $style;
           break L30;
          } else {
           $$014$i$i$i$i = $$01$be$i$i$i$i;
          }
         }
         $117 = ($$014$i$i$i$i|0)==($103|0);
         if ($117) {
          $203 = $94;$st$0 = $style;
         } else {
          $118 = $$014$i$i$i$i;
          $119 = (($118) - ($104))|0;
          $120 = ($119|0)==(-1);
          if ($120) {
           $203 = $94;$st$0 = $style;
          } else {
           if ($96) {
            $123 = $94&255;
            $124 = $123 >>> 1;
            $126 = $124;$140 = $12;
           } else {
            $121 = HEAP32[$17>>2]|0;
            $122 = HEAP32[$16>>2]|0;
            $126 = $121;$140 = $122;
           }
           $125 = ($126>>>0)<($119>>>0);
           $127 = $125 ? $126 : $119;
           $128 = ($127>>>0)>(4294967279);
           if ($128) {
            label = 45;
            break L3;
           }
           $131 = ($127>>>0)<(11);
           if ($131) {
            $132 = $127 << 1;
            $133 = $132&255;
            HEAP8[$1>>0] = $133;
            $__p$0$i$i = $27;
           } else {
            $134 = (($127) + 16)|0;
            $135 = $134 & -16;
            __THREW__ = 0;
            $136 = (invoke_ii(2988,($135|0))|0);
            $137 = __THREW__; __THREW__ = 0;
            $138 = $137&1;
            if ($138) {
             label = 26;
             break L3;
            }
            HEAP32[$30>>2] = $136;
            $139 = $135 | 1;
            HEAP32[$1>>2] = $139;
            HEAP32[$34>>2] = $127;
            $__p$0$i$i = $136;
           }
           _memcpy(($__p$0$i$i|0),($140|0),($127|0))|0;
           $141 = (($__p$0$i$i) + ($127)|0);
           HEAP8[$141>>0] = 0;
           $142 = (($119) + 5)|0;
           if ($96) {
            $144 = $94&255;
            $145 = $144 >>> 1;
            $147 = $145;
           } else {
            $143 = HEAP32[$17>>2]|0;
            $147 = $143;
           }
           $146 = ($147>>>0)<($142>>>0);
           if ($146) {
            label = 55;
            break L3;
           }
           $150 = HEAP32[$16>>2]|0;
           $$183 = $96 ? $12 : $150;
           $151 = (($$183) + ($142)|0);
           $152 = (($147) - ($142))|0;
           $153 = ($152>>>0)>(4294967279);
           if ($153) {
            label = 58;
            break L3;
           }
           $156 = ($152>>>0)<(11);
           if ($156) {
            $157 = $152 << 1;
            $158 = $157&255;
            HEAP8[$2>>0] = $158;
            $__p$0$i$i27 = $28;
           } else {
            $159 = (($152) + 16)|0;
            $160 = $159 & -16;
            __THREW__ = 0;
            $161 = (invoke_ii(2988,($160|0))|0);
            $162 = __THREW__; __THREW__ = 0;
            $163 = $162&1;
            if ($163) {
             label = 73;
             break L3;
            }
            HEAP32[$31>>2] = $161;
            $164 = $160 | 1;
            HEAP32[$2>>2] = $164;
            HEAP32[$33>>2] = $152;
            $__p$0$i$i27 = $161;
           }
           _memcpy(($__p$0$i$i27|0),($151|0),($152|0))|0;
           $165 = (($__p$0$i$i27) + ($152)|0);
           HEAP8[$165>>0] = 0;
           __THREW__ = 0;
           invoke_viii(1774,($0|0),($1|0),($2|0));
           $166 = __THREW__; __THREW__ = 0;
           $167 = $166&1;
           if ($167) {
            label = 76;
            break L3;
           }
           __THREW__ = 0;
           (invoke_iii(2233,($name|0),($0|0))|0);
           $168 = __THREW__; __THREW__ = 0;
           $169 = $168&1;
           if ($169) {
            label = 77;
            break L3;
           }
           $170 = HEAP8[$0>>0]|0;
           $171 = $170 & 1;
           $172 = ($171<<24>>24)==(0);
           if (!($172)) {
            $173 = HEAP32[$32>>2]|0;
            __ZdlPv($173);
           }
           $174 = HEAP8[$2>>0]|0;
           $175 = $174 & 1;
           $176 = ($175<<24>>24)==(0);
           if (!($176)) {
            $177 = HEAP32[$31>>2]|0;
            __ZdlPv($177);
           }
           $178 = HEAP8[$1>>0]|0;
           $179 = $178 & 1;
           $180 = ($179<<24>>24)==(0);
           if (!($180)) {
            $181 = HEAP32[$30>>2]|0;
            __ZdlPv($181);
           }
           $$pre = HEAP8[$name>>0]|0;
           $203 = $$pre;$st$0 = $29;
          }
         }
        }
       }
      }
     } while(0);
     $202 = $203 & 1;
     $204 = ($202<<24>>24)==(0);
     if ($204) {
      $206 = $203&255;
      $207 = $206 >>> 1;
      $209 = $207;
     } else {
      $205 = HEAP32[$17>>2]|0;
      $209 = $205;
     }
     $208 = ($209>>>0)<(7);
     L80: do {
      if ($208) {
       $312 = $203;$st$1 = $st$0;
      } else {
       $210 = HEAP32[$16>>2]|0;
       $$184 = $204 ? $12 : $210;
       $211 = (($$184) + ($209)|0);
       $212 = $$184;
       $213 = ($209|0)<(7);
       if ($213) {
        $312 = $203;$st$1 = $st$0;
       } else {
        $$sum$i$i39 = (($209) + -6)|0;
        $214 = (($$184) + ($$sum$i$i39)|0);
        $215 = ($$sum$i$i39|0)==(0);
        if ($215) {
         $312 = $203;$st$1 = $st$0;
        } else {
         $$014$i$i$i$i41 = $$184;
         L83: while(1) {
          $216 = HEAP8[$$014$i$i$i$i41>>0]|0;
          $217 = ($216<<24>>24)==(32);
          if ($217) {
           $__m1$0$i$i$i$i44 = $$014$i$i$i$i41;$__m2$0$i$i$i$i45 = 803752;
           while(1) {
            $219 = (($__m2$0$i$i$i$i45) + 1|0);
            $220 = ($219|0)==(((803752 + 7|0))|0);
            if ($220) {
             break L83;
            }
            $221 = (($__m1$0$i$i$i$i44) + 1|0);
            $222 = HEAP8[$221>>0]|0;
            $223 = HEAP8[$219>>0]|0;
            $224 = ($222<<24>>24)==($223<<24>>24);
            if ($224) {
             $__m1$0$i$i$i$i44 = $221;$__m2$0$i$i$i$i45 = $219;
            } else {
             break;
            }
           }
          }
          $$01$be$i$i$i$i42 = (($$014$i$i$i$i41) + 1|0);
          $218 = ($$01$be$i$i$i$i42|0)==($214|0);
          if ($218) {
           $312 = $203;$st$1 = $st$0;
           break L80;
          } else {
           $$014$i$i$i$i41 = $$01$be$i$i$i$i42;
          }
         }
         $225 = ($$014$i$i$i$i41|0)==($211|0);
         if ($225) {
          $312 = $203;$st$1 = $st$0;
         } else {
          $226 = $$014$i$i$i$i41;
          $227 = (($226) - ($212))|0;
          $228 = ($227|0)==(-1);
          if ($228) {
           $312 = $203;$st$1 = $st$0;
          } else {
           if ($204) {
            $231 = $203&255;
            $232 = $231 >>> 1;
            $234 = $232;$248 = $12;
           } else {
            $229 = HEAP32[$17>>2]|0;
            $230 = HEAP32[$16>>2]|0;
            $234 = $229;$248 = $230;
           }
           $233 = ($234>>>0)<($227>>>0);
           $235 = $233 ? $234 : $227;
           $236 = ($235>>>0)>(4294967279);
           if ($236) {
            label = 99;
            break L3;
           }
           $239 = ($235>>>0)<(11);
           if ($239) {
            $240 = $235 << 1;
            $241 = $240&255;
            HEAP8[$4>>0] = $241;
            $__p$0$i$i55 = $20;
           } else {
            $242 = (($235) + 16)|0;
            $243 = $242 & -16;
            __THREW__ = 0;
            $244 = (invoke_ii(2988,($243|0))|0);
            $245 = __THREW__; __THREW__ = 0;
            $246 = $245&1;
            if ($246) {
             label = 26;
             break L3;
            }
            HEAP32[$22>>2] = $244;
            $247 = $243 | 1;
            HEAP32[$4>>2] = $247;
            HEAP32[$26>>2] = $235;
            $__p$0$i$i55 = $244;
           }
           _memcpy(($__p$0$i$i55|0),($248|0),($235|0))|0;
           $249 = (($__p$0$i$i55) + ($235)|0);
           HEAP8[$249>>0] = 0;
           $250 = (($227) + 7)|0;
           if ($204) {
            $252 = $203&255;
            $253 = $252 >>> 1;
            $255 = $253;
           } else {
            $251 = HEAP32[$17>>2]|0;
            $255 = $251;
           }
           $254 = ($255>>>0)<($250>>>0);
           if ($254) {
            label = 109;
            break L3;
           }
           $258 = HEAP32[$16>>2]|0;
           $$185 = $204 ? $12 : $258;
           $259 = (($$185) + ($250)|0);
           $260 = (($255) - ($250))|0;
           $261 = ($260>>>0)>(4294967279);
           if ($261) {
            label = 112;
            break L3;
           }
           $264 = ($260>>>0)<(11);
           if ($264) {
            $265 = $260 << 1;
            $266 = $265&255;
            HEAP8[$5>>0] = $266;
            $__p$0$i$i64 = $21;
           } else {
            $267 = (($260) + 16)|0;
            $268 = $267 & -16;
            __THREW__ = 0;
            $269 = (invoke_ii(2988,($268|0))|0);
            $270 = __THREW__; __THREW__ = 0;
            $271 = $270&1;
            if ($271) {
             label = 127;
             break L3;
            }
            HEAP32[$23>>2] = $269;
            $272 = $268 | 1;
            HEAP32[$5>>2] = $272;
            HEAP32[$25>>2] = $260;
            $__p$0$i$i64 = $269;
           }
           _memcpy(($__p$0$i$i64|0),($259|0),($260|0))|0;
           $273 = (($__p$0$i$i64) + ($260)|0);
           HEAP8[$273>>0] = 0;
           __THREW__ = 0;
           invoke_viii(1774,($3|0),($4|0),($5|0));
           $274 = __THREW__; __THREW__ = 0;
           $275 = $274&1;
           if ($275) {
            label = 130;
            break L3;
           }
           __THREW__ = 0;
           (invoke_iii(2233,($name|0),($3|0))|0);
           $276 = __THREW__; __THREW__ = 0;
           $277 = $276&1;
           if ($277) {
            label = 131;
            break L3;
           }
           $278 = HEAP8[$3>>0]|0;
           $279 = $278 & 1;
           $280 = ($279<<24>>24)==(0);
           if (!($280)) {
            $281 = HEAP32[$24>>2]|0;
            __ZdlPv($281);
           }
           $282 = HEAP8[$5>>0]|0;
           $283 = $282 & 1;
           $284 = ($283<<24>>24)==(0);
           if (!($284)) {
            $285 = HEAP32[$23>>2]|0;
            __ZdlPv($285);
           }
           $286 = HEAP8[$4>>0]|0;
           $287 = $286 & 1;
           $288 = ($287<<24>>24)==(0);
           if (!($288)) {
            $289 = HEAP32[$22>>2]|0;
            __ZdlPv($289);
           }
           $290 = $st$0 | 2;
           $$pre181 = HEAP8[$name>>0]|0;
           $312 = $$pre181;$st$1 = $290;
          }
         }
        }
       }
      }
     } while(0);
     $311 = $312 & 1;
     $313 = ($311<<24>>24)==(0);
     if ($313) {
      ;HEAP32[$6+0>>2]=HEAP32[$name+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$name+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$name+8>>2]|0;
     } else {
      $314 = HEAP32[$16>>2]|0;
      $315 = HEAP32[$17>>2]|0;
      $316 = ($315>>>0)>(4294967279);
      if ($316) {
       label = 140;
       break;
      }
      $319 = ($315>>>0)<(11);
      if ($319) {
       $320 = $315 << 1;
       $321 = $320&255;
       HEAP8[$6>>0] = $321;
       $__p$0$i$i$i$i$i76 = $18;
      } else {
       $322 = (($315) + 16)|0;
       $323 = $322 & -16;
       __THREW__ = 0;
       $324 = (invoke_ii(2988,($323|0))|0);
       $325 = __THREW__; __THREW__ = 0;
       $326 = $325&1;
       if ($326) {
        label = 26;
        break;
       }
       HEAP32[$15>>2] = $324;
       $327 = $323 | 1;
       HEAP32[$6>>2] = $327;
       HEAP32[$19>>2] = $315;
       $__p$0$i$i$i$i$i76 = $324;
      }
      _memcpy(($__p$0$i$i$i$i$i76|0),($314|0),($315|0))|0;
      $328 = (($__p$0$i$i$i$i$i76) + ($315)|0);
      HEAP8[$328>>0] = 0;
     }
     HEAP32[$14>>2] = $st$1;
     __THREW__ = 0;
     (invoke_iii(2233,($r|0),($6|0))|0);
     $329 = __THREW__; __THREW__ = 0;
     $330 = $329&1;
     if ($330) {
      label = 152;
      break;
     }
     $331 = HEAP32[$14>>2]|0;
     HEAP32[$13>>2] = $331;
     $332 = HEAP8[$6>>0]|0;
     $333 = $332 & 1;
     $334 = ($333<<24>>24)==(0);
     if (!($334)) {
      $335 = HEAP32[$15>>2]|0;
      __ZdlPv($335);
     }
     __THREW__ = 0;
     $336 = (invoke_iiiii(275,($this|0),($r|0),($fallbacks|0),($unicodeChar|0))|0);
     $337 = __THREW__; __THREW__ = 0;
     $338 = $337&1;
     if ($338) {
      label = 26;
      break;
     }
     $339 = ($336|0)==(0|0);
     $340 = $339&1;
     $$ = $340 ^ 1;
     $$0$ = $339 ? $$0174 : $336;
     $$02 = $$;$$1 = $$0$;
    } else {
     $$02 = 1;$$1 = $82;
    }
    $347 = HEAP8[$r>>0]|0;
    $348 = $347 & 1;
    $349 = ($348<<24>>24)==(0);
    if (!($349)) {
     $350 = HEAP32[$35>>2]|0;
     __ZdlPv($350);
    }
    $351 = HEAP8[$name>>0]|0;
    $352 = $351 & 1;
    $353 = ($352<<24>>24)==(0);
    if (!($353)) {
     $354 = HEAP32[$16>>2]|0;
     __ZdlPv($354);
    }
    $cond = ($$02|0)==(1);
    $40 = (($42) + 12|0);
    if ($cond) {
     $$4 = $$1;
     label = 195;
     break;
    }
    $38 = HEAP32[$9>>2]|0;
    $39 = ($40|0)==($38|0);
    if ($39) {
     $$0$lcssa = $$1;
     break L1;
    } else {
     $$0174 = $$1;$42 = $40;
    }
   }
   switch (label|0) {
    case 7: {
     __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
     // unreachable;
     break;
    }
    case 14: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      $88 = ___cxa_find_matching_catch()|0;
      $89 = tempRet0;
      $lpad$phi120$index = $88;$lpad$phi120$index2 = $89;
      label = 25;
      break;
     } else {
      // unreachable;
     }
     break;
    }
    case 23: {
     $86 = ___cxa_find_matching_catch()|0;
     $87 = tempRet0;
     $lpad$phi120$index = $86;$lpad$phi120$index2 = $87;
     label = 25;
     break;
    }
    case 26: {
     $90 = ___cxa_find_matching_catch()|0;
     $91 = tempRet0;
     $lpad$phi125$index = $90;$lpad$phi125$index7 = $91;
     label = 28;
     break;
    }
    case 45: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $129 = __THREW__; __THREW__ = 0;
     $130 = $129&1;
     if ($130) {
      label = 27;
     } else {
      // unreachable;
     }
     break;
    }
    case 55: {
     __THREW__ = 0;
     invoke_vi(3304,0);
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     if ($149) {
      label = 74;
     } else {
      // unreachable;
     }
     break;
    }
    case 58: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $154 = __THREW__; __THREW__ = 0;
     $155 = $154&1;
     if ($155) {
      label = 74;
     } else {
      // unreachable;
     }
     break;
    }
    case 73: {
     $182 = ___cxa_find_matching_catch()|0;
     $183 = tempRet0;
     $lpad$phi130$index = $182;$lpad$phi130$index12 = $183;
     label = 75;
     break;
    }
    case 76: {
     $186 = ___cxa_find_matching_catch()|0;
     $187 = tempRet0;
     $$04 = $187;$$09 = $186;
     label = 79;
     break;
    }
    case 77: {
     $188 = ___cxa_find_matching_catch()|0;
     $189 = tempRet0;
     $190 = HEAP8[$0>>0]|0;
     $191 = $190 & 1;
     $192 = ($191<<24>>24)==(0);
     if ($192) {
      $$04 = $189;$$09 = $188;
      label = 79;
     } else {
      $193 = HEAP32[$32>>2]|0;
      __ZdlPv($193);
      $$04 = $189;$$09 = $188;
      label = 79;
     }
     break;
    }
    case 99: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $237 = __THREW__; __THREW__ = 0;
     $238 = $237&1;
     if ($238) {
      label = 27;
     } else {
      // unreachable;
     }
     break;
    }
    case 109: {
     __THREW__ = 0;
     invoke_vi(3304,0);
     $256 = __THREW__; __THREW__ = 0;
     $257 = $256&1;
     if ($257) {
      label = 128;
     } else {
      // unreachable;
     }
     break;
    }
    case 112: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $262 = __THREW__; __THREW__ = 0;
     $263 = $262&1;
     if ($263) {
      label = 128;
     } else {
      // unreachable;
     }
     break;
    }
    case 127: {
     $291 = ___cxa_find_matching_catch()|0;
     $292 = tempRet0;
     $lpad$phi135$index = $291;$lpad$phi135$index17 = $292;
     label = 129;
     break;
    }
    case 130: {
     $295 = ___cxa_find_matching_catch()|0;
     $296 = tempRet0;
     $$211 = $295;$$26 = $296;
     label = 133;
     break;
    }
    case 131: {
     $297 = ___cxa_find_matching_catch()|0;
     $298 = tempRet0;
     $299 = HEAP8[$3>>0]|0;
     $300 = $299 & 1;
     $301 = ($300<<24>>24)==(0);
     if ($301) {
      $$211 = $297;$$26 = $298;
      label = 133;
     } else {
      $302 = HEAP32[$24>>2]|0;
      __ZdlPv($302);
      $$211 = $297;$$26 = $298;
      label = 133;
     }
     break;
    }
    case 140: {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $317 = __THREW__; __THREW__ = 0;
     $318 = $317&1;
     if ($318) {
      label = 27;
     } else {
      // unreachable;
     }
     break;
    }
    case 152: {
     $341 = ___cxa_find_matching_catch()|0;
     $342 = tempRet0;
     $343 = HEAP8[$6>>0]|0;
     $344 = $343 & 1;
     $345 = ($344<<24>>24)==(0);
     if ($345) {
      $$413 = $341;$$48 = $342;
      label = 159;
     } else {
      $346 = HEAP32[$15>>2]|0;
      __ZdlPv($346);
      $$413 = $341;$$48 = $342;
      label = 159;
     }
     break;
    }
    case 195: {
     STACKTOP = sp;return ($$4|0);
     break;
    }
   }
   if ((label|0) == 25) {
    $$5 = $lpad$phi120$index2;$$514 = $lpad$phi120$index;
   }
   else if ((label|0) == 27) {
    $92 = ___cxa_find_matching_catch()|0;
    $93 = tempRet0;
    $lpad$phi125$index = $92;$lpad$phi125$index7 = $93;
    label = 28;
   }
   else if ((label|0) == 74) {
    $184 = ___cxa_find_matching_catch()|0;
    $185 = tempRet0;
    $lpad$phi130$index = $184;$lpad$phi130$index12 = $185;
    label = 75;
   }
   else if ((label|0) == 79) {
    $194 = HEAP8[$2>>0]|0;
    $195 = $194 & 1;
    $196 = ($195<<24>>24)==(0);
    if ($196) {
     $$110 = $$09;$$15 = $$04;
     label = 81;
    } else {
     $197 = HEAP32[$31>>2]|0;
     __ZdlPv($197);
     $$110 = $$09;$$15 = $$04;
     label = 81;
    }
   }
   else if ((label|0) == 128) {
    $293 = ___cxa_find_matching_catch()|0;
    $294 = tempRet0;
    $lpad$phi135$index = $293;$lpad$phi135$index17 = $294;
    label = 129;
   }
   else if ((label|0) == 133) {
    $303 = HEAP8[$5>>0]|0;
    $304 = $303 & 1;
    $305 = ($304<<24>>24)==(0);
    if ($305) {
     $$312 = $$211;$$37 = $$26;
     label = 135;
    } else {
     $306 = HEAP32[$23>>2]|0;
     __ZdlPv($306);
     $$312 = $$211;$$37 = $$26;
     label = 135;
    }
   }
   if ((label|0) == 28) {
    $$413 = $lpad$phi125$index;$$48 = $lpad$phi125$index7;
    label = 159;
   }
   else if ((label|0) == 75) {
    $$110 = $lpad$phi130$index;$$15 = $lpad$phi130$index12;
    label = 81;
   }
   else if ((label|0) == 129) {
    $$312 = $lpad$phi135$index;$$37 = $lpad$phi135$index17;
    label = 135;
   }
   if ((label|0) == 81) {
    $198 = HEAP8[$1>>0]|0;
    $199 = $198 & 1;
    $200 = ($199<<24>>24)==(0);
    if ($200) {
     $$413 = $$110;$$48 = $$15;
     label = 159;
    } else {
     $201 = HEAP32[$30>>2]|0;
     __ZdlPv($201);
     $$413 = $$110;$$48 = $$15;
     label = 159;
    }
   }
   else if ((label|0) == 135) {
    $307 = HEAP8[$4>>0]|0;
    $308 = $307 & 1;
    $309 = ($308<<24>>24)==(0);
    if ($309) {
     $$413 = $$312;$$48 = $$37;
     label = 159;
    } else {
     $310 = HEAP32[$22>>2]|0;
     __ZdlPv($310);
     $$413 = $$312;$$48 = $$37;
     label = 159;
    }
   }
   if ((label|0) == 159) {
    $355 = HEAP8[$r>>0]|0;
    $356 = $355 & 1;
    $357 = ($356<<24>>24)==(0);
    if ($357) {
     $$5 = $$48;$$514 = $$413;
    } else {
     $358 = HEAP32[$35>>2]|0;
     __ZdlPv($358);
     $$5 = $$48;$$514 = $$413;
    }
   }
   $359 = HEAP8[$name>>0]|0;
   $360 = $359 & 1;
   $361 = ($360<<24>>24)==(0);
   if ($361) {
    $$6 = $$5;$$615 = $$514;
    ___resumeException($$615|0);
    // unreachable;
   }
   $362 = HEAP32[$16>>2]|0;
   __ZdlPv($362);
   $$6 = $$5;$$615 = $$514;
   ___resumeException($$615|0);
   // unreachable;
  }
 } while(0);
 $363 = (__ZN20TextRenderingPrivate12GetFallbacksEv()|0);
 $364 = HEAP32[$363>>2]|0;
 $365 = (($363) + 4|0);
 $366 = HEAP32[$365>>2]|0;
 $367 = ($364|0)==($366|0);
 if ($367) {
  $$4 = 0;
  STACKTOP = sp;return ($$4|0);
 }
 $368 = (($7) + 1|0);
 $369 = (($r2) + 12|0);
 $370 = (($r2) + 8|0);
 $371 = (($7) + 8|0);
 $372 = (($7) + 4|0);
 $373 = (($r2) + 1|0);
 $374 = (($r2) + 4|0);
 $$2113 = $$0$lcssa;$379 = $364;
 while(1) {
  $378 = HEAP8[$379>>0]|0;
  $380 = $378 & 1;
  $381 = ($380<<24>>24)==(0);
  if ($381) {
   $382 = (($379) + 1|0);
   $383 = $378&255;
   $384 = $383 >>> 1;
   $391 = $384;$399 = $382;
  } else {
   $385 = (($379) + 8|0);
   $386 = HEAP32[$385>>2]|0;
   $387 = (($379) + 4|0);
   $388 = HEAP32[$387>>2]|0;
   $389 = ($388>>>0)>(4294967279);
   if ($389) {
    label = 169;
    break;
   } else {
    $391 = $388;$399 = $386;
   }
  }
  $390 = ($391>>>0)<(11);
  if ($390) {
   $392 = $391 << 1;
   $393 = $392&255;
   HEAP8[$7>>0] = $393;
   $402 = $393;$__p$0$i$i$i$i91 = $368;
  } else {
   $394 = (($391) + 16)|0;
   $395 = $394 & -16;
   $396 = (__Znwj($395)|0);
   HEAP32[$371>>2] = $396;
   $397 = $395 | 1;
   HEAP32[$7>>2] = $397;
   HEAP32[$372>>2] = $391;
   $398 = $397&255;
   $402 = $398;$__p$0$i$i$i$i91 = $396;
  }
  _memcpy(($__p$0$i$i$i$i91|0),($399|0),($391|0))|0;
  $400 = (($__p$0$i$i$i$i91) + ($391)|0);
  HEAP8[$400>>0] = 0;
  $401 = $402 & 1;
  $403 = ($401<<24>>24)==(0);
  if ($403) {
   ;HEAP32[$r2+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$r2+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$r2+8>>2]=HEAP32[$7+8>>2]|0;
  } else {
   $404 = HEAP32[$371>>2]|0;
   $405 = HEAP32[$372>>2]|0;
   $406 = ($405>>>0)>(4294967279);
   if ($406) {
    label = 176;
    break;
   }
   $409 = ($405>>>0)<(11);
   if ($409) {
    $410 = $405 << 1;
    $411 = $410&255;
    HEAP8[$r2>>0] = $411;
    $__p$0$i$i$i$i$i94 = $373;
   } else {
    $412 = (($405) + 16)|0;
    $413 = $412 & -16;
    __THREW__ = 0;
    $414 = (invoke_ii(2988,($413|0))|0);
    $415 = __THREW__; __THREW__ = 0;
    $416 = $415&1;
    if ($416) {
     label = 189;
     break;
    }
    HEAP32[$370>>2] = $414;
    $417 = $413 | 1;
    HEAP32[$r2>>2] = $417;
    HEAP32[$374>>2] = $405;
    $__p$0$i$i$i$i$i94 = $414;
   }
   _memcpy(($__p$0$i$i$i$i$i94|0),($404|0),($405|0))|0;
   $418 = (($__p$0$i$i$i$i$i94) + ($405)|0);
   HEAP8[$418>>0] = 0;
  }
  HEAP32[$369>>2] = $style;
  $419 = $402 & 1;
  $420 = ($419<<24>>24)==(0);
  if (!($420)) {
   $421 = HEAP32[$371>>2]|0;
   __ZdlPv($421);
  }
  __THREW__ = 0;
  $422 = (invoke_iiiii(275,($this|0),($r2|0),($fallbacks|0),($unicodeChar|0))|0);
  $423 = __THREW__; __THREW__ = 0;
  $424 = $423&1;
  if ($424) {
   label = 193;
   break;
  }
  $425 = ($422|0)==(0|0);
  $$2$ = $425 ? $$2113 : $422;
  $426 = HEAP8[$r2>>0]|0;
  $427 = $426 & 1;
  $428 = ($427<<24>>24)==(0);
  if (!($428)) {
   $429 = HEAP32[$370>>2]|0;
   __ZdlPv($429);
  }
  $377 = (($379) + 12|0);
  if (!($425)) {
   $$4 = $$2$;
   label = 195;
   break;
  }
  $375 = HEAP32[$365>>2]|0;
  $376 = ($377|0)==($375|0);
  if ($376) {
   $$4 = 0;
   label = 195;
   break;
  } else {
   $$2113 = $$2$;$379 = $377;
  }
 }
 do {
  if ((label|0) == 169) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  else if ((label|0) == 176) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $407 = __THREW__; __THREW__ = 0;
   $408 = $407&1;
   if ($408) {
    $432 = ___cxa_find_matching_catch()|0;
    $433 = tempRet0;
    $lpad$phi$index = $432;$lpad$phi$index22 = $433;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 189) {
   $430 = ___cxa_find_matching_catch()|0;
   $431 = tempRet0;
   $lpad$phi$index = $430;$lpad$phi$index22 = $431;
  }
  else if ((label|0) == 193) {
   $436 = ___cxa_find_matching_catch()|0;
   $437 = tempRet0;
   $438 = HEAP8[$r2>>0]|0;
   $439 = $438 & 1;
   $440 = ($439<<24>>24)==(0);
   if ($440) {
    $$6 = $437;$$615 = $436;
    ___resumeException($$615|0);
    // unreachable;
   }
   $441 = HEAP32[$370>>2]|0;
   __ZdlPv($441);
   $$6 = $437;$$615 = $436;
   ___resumeException($$615|0);
   // unreachable;
  }
  else if ((label|0) == 195) {
   STACKTOP = sp;return ($$4|0);
  }
 } while(0);
 $434 = $402 & 1;
 $435 = ($434<<24>>24)==(0);
 if ($435) {
  $$6 = $lpad$phi$index22;$$615 = $lpad$phi$index;
  ___resumeException($$615|0);
  // unreachable;
 }
 __ZdlPv($404);
 $$6 = $lpad$phi$index22;$$615 = $lpad$phi$index;
 ___resumeException($$615|0);
 // unreachable;
 return 0|0;
}
function __ZN20TextRenderingPrivate4Font19HasCharacterDynamicEj($this,$unicodeChar) {
 $this = $this|0;
 $unicodeChar = $unicodeChar|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($unicodeChar>>>0)>(31);
 STACKTOP = sp;return ($0|0);
}
function __ZN20TextRenderingPrivate4Font18GetCharacterBitmapERjS1_S1_R5RectTIfERfjij($this,$charWidth,$charHeight,$bufferWidth,$vert,$advance,$unicodeChar,$size,$style) {
 $this = $this|0;
 $charWidth = $charWidth|0;
 $charHeight = $charHeight|0;
 $bufferWidth = $bufferWidth|0;
 $vert = $vert|0;
 $advance = $advance|0;
 $unicodeChar = $unicodeChar|0;
 $size = $size|0;
 $style = $style|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0);
 var $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = Math_fround(0), $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $face$1 = 0;
 var $i$04 = 0, $m = 0, $srcBitmap$0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $m = sp;
 $1 = ($size|0)==(0);
 if ($1) {
  $2 = (($this) + 32|0);
  $3 = HEAP32[$2>>2]|0;
  $$01 = $3;
 } else {
  $$01 = $size;
 }
 $4 = (($this) + 216|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 132|0);
 $7 = (($this) + 144|0);
 $8 = (__ZN20TextRenderingPrivate15DynamicFontData19GetFaceForCharacterERNSt3__16vectorI8UnityStr13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEERNS2_I4PPtrINS_4FontEES4_ISB_LS5_27ELi16EEEEjj($5,$6,$7,$style,$unicodeChar)|0);
 $9 = ($8|0)==(0|0);
 do {
  if ($9) {
   HEAP8[$0>>0] = 18;
   $10 = (($0) + 1|0);
   dest=$10+0|0; src=803792+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $11 = (($0) + 10|0);
   HEAP8[$11>>0] = 0;
   __THREW__ = 0;
   $12 = (invoke_i(58)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_iiii(1532,($12|0),128,($0|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP8[$0>>0]|0;
     $19 = $18 & 1;
     $20 = ($19<<24>>24)==(0);
     if (!($20)) {
      $21 = (($0) + 8|0);
      $22 = HEAP32[$21>>2]|0;
      __ZdlPv($22);
     }
     $23 = ($15|0)==(0|0);
     if ($23) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($15) + 216|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($15) + 132|0);
     $34 = (($15) + 144|0);
     $35 = (__ZN20TextRenderingPrivate15DynamicFontData19GetFaceForCharacterERNSt3__16vectorI8UnityStr13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEERNS2_I4PPtrINS_4FontEES4_ISB_LS5_27ELi16EEEEjj($32,$33,$34,$style,$unicodeChar)|0);
     $36 = ($35|0)==(0|0);
     if ($36) {
      $$0 = 0;
     } else {
      $face$1 = $35;
      break;
     }
     STACKTOP = sp;return ($$0|0);
    }
   }
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $26 = HEAP8[$0>>0]|0;
   $27 = $26 & 1;
   $28 = ($27<<24>>24)==(0);
   if ($28) {
    ___resumeException($24|0);
    // unreachable;
   }
   $29 = (($0) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   __ZdlPv($30);
   ___resumeException($24|0);
   // unreachable;
  } else {
   $face$1 = $8;
  }
 } while(0);
 $37 = (($face$1) + 12|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 1;
 $40 = $38 & 2;
 $41 = ($40|0)==(0);
 if ($41) {
  $42 = $style & 1;
  $43 = ($42|0)==(0);
  if ($43) {
   label = 15;
  } else {
   HEAP32[$m>>2] = 81920;
  }
 } else {
  label = 15;
 }
 if ((label|0) == 15) {
  HEAP32[$m>>2] = 65536;
 }
 $44 = ($39|0)==(0);
 if ($44) {
  $45 = $style & 2;
  $46 = ($45|0)==(0);
  if ($46) {
   label = 19;
  } else {
   $47 = (($m) + 4|0);
   HEAP32[$47>>2] = 16384;
  }
 } else {
  label = 19;
 }
 if ((label|0) == 19) {
  $48 = (($m) + 4|0);
  HEAP32[$48>>2] = 0;
 }
 $49 = (($m) + 12|0);
 HEAP32[$49>>2] = 65536;
 $50 = (($m) + 8|0);
 HEAP32[$50>>2] = 0;
 _FT_Set_Transform($face$1,$m,0);
 $51 = (Math_fround(($$01|0)));
 $52 = Math_fround($51 * Math_fround(64.0));
 $53 = (~~(($52)));
 (_FT_Set_Char_Size($face$1,0,$53,72,72)|0);
 $54 = (_FT_Get_Char_Index($face$1,$unicodeChar)|0);
 $55 = ($54|0)==(0);
 if ($55) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $56 = (($this) + 212|0);
 $57 = HEAP32[$56>>2]|0;
 if ((($57|0) == 3) | (($57|0) == 0)) {
  $$0$i = 2;
 } else if ((($57|0) == 1)) {
  $$0$i = 0;
 } else if ((($57|0) == 2)) {
  $$0$i = 131072;
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(803760,0,803720,340,1,0,0,0);
  $$0$i = 2;
 }
 $58 = (_FT_Load_Glyph($face$1,$54,$$0$i)|0);
 $59 = ($58|0)==(0);
 if (!($59)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $60 = (($face$1) + 84|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($61) + 72|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = ($63|0)==(1651078259);
 do {
  if ($64) {
   $69 = $61;
  } else {
   $65 = $$0$i >>> 16;
   $66 = (_FT_Render_Glyph($61,$65)|0);
   $67 = ($66|0)==(0);
   if ($67) {
    $$pre = HEAP32[$60>>2]|0;
    $69 = $$pre;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $68 = (($69) + 76|0);
 $70 = (($69) + 94|0);
 $71 = HEAP8[$70>>0]|0;
 $72 = ($71<<24>>24)==(2);
 if ($72) {
  $srcBitmap$0 = $68;
 } else {
  $73 = HEAP8[803808>>0]|0;
  $74 = ($73<<24>>24)==(0);
  if ($74) {
   _FT_Bitmap_New(803816);
   HEAP8[803808>>0] = 1;
  }
  $75 = HEAP32[803736>>2]|0;
  (_FT_Bitmap_Convert($75,$68,803816,4)|0);
  $76 = HEAP16[((803816 + 16|0))>>1]|0;
  $77 = ($76<<16>>16)==(256);
  if ($77) {
   $srcBitmap$0 = 803816;
  } else {
   $78 = $76 << 16 >> 16;
   $79 = (($78) + -1)|0;
   $80 = (Math_fround(($79|0)));
   $81 = Math_fround(Math_fround(1.0) / $80);
   $82 = Math_fround($81 * Math_fround(255.0));
   $83 = HEAP32[((803816 + 8|0))>>2]|0;
   $84 = HEAP32[803816>>2]|0;
   $85 = Math_imul($84, $83)|0;
   $86 = ($85|0)>(0);
   if ($86) {
    $i$04 = 0;
    while(1) {
     $87 = HEAP32[((803816 + 12|0))>>2]|0;
     $88 = (($87) + ($i$04)|0);
     $89 = HEAP8[$88>>0]|0;
     $90 = (Math_fround(($89&255)));
     $91 = Math_fround($82 * $90);
     $92 = (~~(($91))&255);
     HEAP8[$88>>0] = $92;
     $93 = (($i$04) + 1)|0;
     $94 = HEAP32[((803816 + 8|0))>>2]|0;
     $95 = HEAP32[803816>>2]|0;
     $96 = Math_imul($95, $94)|0;
     $97 = ($93|0)<($96|0);
     if ($97) {
      $i$04 = $93;
     } else {
      $srcBitmap$0 = 803816;
      break;
     }
    }
   } else {
    $srcBitmap$0 = 803816;
   }
  }
 }
 $98 = (($srcBitmap$0) + 4|0);
 $99 = HEAP32[$98>>2]|0;
 HEAP32[$charWidth>>2] = $99;
 $100 = HEAP32[$srcBitmap$0>>2]|0;
 HEAP32[$charHeight>>2] = $100;
 $101 = (($srcBitmap$0) + 8|0);
 $102 = HEAP32[$101>>2]|0;
 HEAP32[$bufferWidth>>2] = $102;
 $103 = HEAP32[$60>>2]|0;
 $104 = (($103) + 100|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (Math_fround(($105|0)));
 $107 = (($103) + 104|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = (Math_fround(($108|0)));
 $110 = (($this) + 208|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($109 - $111);
 $113 = HEAP32[$charWidth>>2]|0;
 $114 = (Math_fround(($113>>>0)));
 $115 = HEAP32[$charHeight>>2]|0;
 $116 = (Math_fround(($115>>>0)));
 $117 = Math_fround(-$116);
 HEAPF32[$vert>>2] = $106;
 $118 = (($vert) + 4|0);
 HEAPF32[$118>>2] = $112;
 $119 = (($vert) + 8|0);
 HEAPF32[$119>>2] = $114;
 $120 = (($vert) + 12|0);
 HEAPF32[$120>>2] = $117;
 $121 = HEAP32[$60>>2]|0;
 $122 = (($121) + 40|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (+($123|0));
 $125 = $124 * 0.015625;
 $126 = $125 + 0.5;
 $127 = (+Math_floor((+$126)));
 $128 = Math_fround($127);
 HEAPF32[$advance>>2] = $128;
 $129 = HEAP32[$98>>2]|0;
 $130 = HEAP32[$srcBitmap$0>>2]|0;
 $131 = Math_imul($130, $129)|0;
 $132 = ($131|0)==(0);
 if ($132) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $133 = (($srcBitmap$0) + 12|0);
 $134 = HEAP32[$133>>2]|0;
 $$0 = $134;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20TextRenderingPrivate15DynamicFontData21GetFontMetricsForFaceENSt3__16vectorI8UnityStr13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEEiRNS2_I4PPtrINS_4FontEES4_ISA_LS5_27ELi16EEEEPfSE_($this,$names,$size,$fallbacks,$ascent,$lineSpacing) {
 $this = $this|0;
 $names = $names|0;
 $size = $size|0;
 $fallbacks = $fallbacks|0;
 $ascent = $ascent|0;
 $lineSpacing = $lineSpacing|0;
 var $$02 = 0, $$03 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = Math_fround(0);
 var $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi13$index = 0, $lpad$phi13$index7 = 0, $r = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $r = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$names>>2]|0;
 $2 = (($names) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $$2 = 0;
  STACKTOP = sp;return ($$2|0);
 }
 $5 = (($0) + 1|0);
 $6 = (($r) + 12|0);
 $7 = (($r) + 8|0);
 $8 = (($0) + 8|0);
 $9 = (($0) + 4|0);
 $10 = (($r) + 1|0);
 $11 = (($r) + 4|0);
 $13 = $1;
 while(1) {
  $12 = HEAP8[$13>>0]|0;
  $14 = $12 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $16 = (($13) + 1|0);
   $17 = $12&255;
   $18 = $17 >>> 1;
   $25 = $18;$33 = $16;
  } else {
   $19 = (($13) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($13) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22>>>0)>(4294967279);
   if ($23) {
    label = 6;
    break;
   } else {
    $25 = $22;$33 = $20;
   }
  }
  $24 = ($25>>>0)<(11);
  if ($24) {
   $26 = $25 << 1;
   $27 = $26&255;
   HEAP8[$0>>0] = $27;
   $36 = $27;$__p$0$i$i$i$i = $5;
  } else {
   $28 = (($25) + 16)|0;
   $29 = $28 & -16;
   $30 = (__Znwj($29)|0);
   HEAP32[$8>>2] = $30;
   $31 = $29 | 1;
   HEAP32[$0>>2] = $31;
   HEAP32[$9>>2] = $25;
   $32 = $31&255;
   $36 = $32;$__p$0$i$i$i$i = $30;
  }
  _memcpy(($__p$0$i$i$i$i|0),($33|0),($25|0))|0;
  $34 = (($__p$0$i$i$i$i) + ($25)|0);
  HEAP8[$34>>0] = 0;
  $35 = $36 & 1;
  $37 = ($35<<24>>24)==(0);
  if ($37) {
   ;HEAP32[$r+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$r+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$r+8>>2]=HEAP32[$0+8>>2]|0;
  } else {
   $38 = HEAP32[$8>>2]|0;
   $39 = HEAP32[$9>>2]|0;
   $40 = ($39>>>0)>(4294967279);
   if ($40) {
    label = 13;
    break;
   }
   $43 = ($39>>>0)<(11);
   if ($43) {
    $44 = $39 << 1;
    $45 = $44&255;
    HEAP8[$r>>0] = $45;
    $__p$0$i$i$i$i$i = $10;
   } else {
    $46 = (($39) + 16)|0;
    $47 = $46 & -16;
    __THREW__ = 0;
    $48 = (invoke_ii(2988,($47|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 27;
     break;
    }
    HEAP32[$7>>2] = $48;
    $51 = $47 | 1;
    HEAP32[$r>>2] = $51;
    HEAP32[$11>>2] = $39;
    $__p$0$i$i$i$i$i = $48;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($38|0),($39|0))|0;
   $52 = (($__p$0$i$i$i$i$i) + ($39)|0);
   HEAP8[$52>>0] = 0;
  }
  HEAP32[$6>>2] = 0;
  $53 = $36 & 1;
  $54 = ($53<<24>>24)==(0);
  if (!($54)) {
   $55 = HEAP32[$8>>2]|0;
   __ZdlPv($55);
  }
  __THREW__ = 0;
  $56 = (invoke_iiii(1594,($this|0),($r|0),($fallbacks|0))|0);
  $57 = __THREW__; __THREW__ = 0;
  $58 = $57&1;
  if ($58) {
   label = 31;
   break;
  }
  $59 = ($56|0)==(0|0);
  if (!($59)) {
   label = 24;
   break;
  }
  $98 = HEAP8[$r>>0]|0;
  $99 = $98 & 1;
  $100 = ($99<<24>>24)==(0);
  if (!($100)) {
   $101 = HEAP32[$7>>2]|0;
   __ZdlPv($101);
  }
  $102 = (($13) + 12|0);
  $103 = HEAP32[$2>>2]|0;
  $104 = ($102|0)==($103|0);
  if ($104) {
   $$2 = 0;
   label = 38;
   break;
  } else {
   $13 = $102;
  }
 }
 do {
  if ((label|0) == 6) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  else if ((label|0) == 13) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $86 = ___cxa_find_matching_catch()|0;
    $87 = tempRet0;
    $lpad$phi$index = $86;$lpad$phi$index2 = $87;
    label = 29;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 24) {
   __THREW__ = 0;
   (invoke_iiii(1595,($56|0),($size|0),0)|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    $92 = ___cxa_find_matching_catch()|0;
    $93 = tempRet0;
    $lpad$phi13$index = $92;$lpad$phi13$index7 = $93;
    label = 33;
    break;
   }
   $62 = (($56) + 70|0);
   $63 = HEAP16[$62>>1]|0;
   $64 = (Math_fround(($63<<16>>16)));
   $65 = (($56) + 88|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($66) + 14|0);
   $68 = HEAP16[$67>>1]|0;
   $69 = (Math_fround(($68&65535)));
   $70 = Math_fround($64 * $69);
   $71 = (($56) + 68|0);
   $72 = HEAP16[$71>>1]|0;
   $73 = (Math_fround(($72&65535)));
   $74 = Math_fround($70 / $73);
   HEAPF32[$ascent>>2] = $74;
   $75 = (($56) + 74|0);
   $76 = HEAP16[$75>>1]|0;
   $77 = (Math_fround(($76<<16>>16)));
   $78 = Math_fround($77 * $69);
   $79 = Math_fround($78 / $73);
   HEAPF32[$lineSpacing>>2] = $79;
   $80 = HEAP8[$r>>0]|0;
   $81 = $80 & 1;
   $82 = ($81<<24>>24)==(0);
   if ($82) {
    $$2 = 1;
    STACKTOP = sp;return ($$2|0);
   }
   $83 = HEAP32[$7>>2]|0;
   __ZdlPv($83);
   $$2 = 1;
   STACKTOP = sp;return ($$2|0);
  }
  else if ((label|0) == 27) {
   $84 = ___cxa_find_matching_catch()|0;
   $85 = tempRet0;
   $lpad$phi$index = $84;$lpad$phi$index2 = $85;
   label = 29;
  }
  else if ((label|0) == 31) {
   $90 = ___cxa_find_matching_catch()|0;
   $91 = tempRet0;
   $lpad$phi13$index = $90;$lpad$phi13$index7 = $91;
   label = 33;
  }
  else if ((label|0) == 38) {
   STACKTOP = sp;return ($$2|0);
  }
 } while(0);
 if ((label|0) == 29) {
  $88 = $36 & 1;
  $89 = ($88<<24>>24)==(0);
  if ($89) {
   $$02 = $lpad$phi$index2;$$03 = $lpad$phi$index;
   ___resumeException($$03|0);
   // unreachable;
  }
  __ZdlPv($38);
  $$02 = $lpad$phi$index2;$$03 = $lpad$phi$index;
  ___resumeException($$03|0);
  // unreachable;
 }
 else if ((label|0) == 33) {
  $94 = HEAP8[$r>>0]|0;
  $95 = $94 & 1;
  $96 = ($95<<24>>24)==(0);
  if ($96) {
   $$02 = $lpad$phi13$index7;$$03 = $lpad$phi13$index;
   ___resumeException($$03|0);
   // unreachable;
  }
  $97 = HEAP32[$7>>2]|0;
  __ZdlPv($97);
  $$02 = $lpad$phi13$index7;$$03 = $lpad$phi13$index;
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN20TextRenderingPrivate4Font16SetupDynamicFontEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy11 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $face = 0, $r = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy11 = sp + 108|0;
 $0 = sp + 104|0;
 $1 = sp + 100|0;
 $2 = sp + 96|0;
 $3 = sp + 92|0;
 $4 = sp + 88|0;
 $5 = sp + 84|0;
 $6 = sp + 80|0;
 $7 = sp + 76|0;
 $face = sp + 60|0;
 $8 = sp + 56|0;
 $9 = sp + 44|0;
 $10 = sp + 40|0;
 $r = sp + 24|0;
 $11 = sp + 12|0;
 $12 = sp;
 $13 = sp + 64|0;
 $14 = (($this) + 120|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 124|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($15|0)==($17|0);
 L1: do {
  if (!($18)) {
   $19 = (($this) + 216|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    HEAP32[$face>>2] = 0;
    $24 = HEAP32[803736>>2]|0;
    $25 = $17;
    $26 = $15;
    $27 = (($25) - ($26))|0;
    $28 = (_FT_New_Memory_Face($24,$15,$27,0,$face)|0);
    $29 = ($28|0)==(0);
    if (!($29)) {
     __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(803840,0,803720,465,1,0,0,0);
     break;
    }
    $30 = HEAP32[$face>>2]|0;
    $31 = (($30) + 20|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==(0|0);
    if ($33) {
     HEAP32[$31>>2] = 803872;
    }
    $34 = (($this) + 132|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = HEAP8[$35>>0]|0;
    $37 = $36 & 1;
    $38 = ($37<<24>>24)==(0);
    if ($38) {
     $41 = (($35) + 1|0);
     $45 = $41;
    } else {
     $39 = (($35) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $45 = $40;
    }
    $42 = HEAP32[$face>>2]|0;
    $43 = (($42) + 20|0);
    $44 = HEAP32[$43>>2]|0;
    $46 = (_strcmp($45,$44)|0);
    $47 = ($46|0)==(0);
    do {
     if (!($47)) {
      HEAP32[$8>>2] = $35;
      $48 = (_strlen(($44|0))|0);
      $49 = ($48>>>0)>(2147483631);
      if ($49) {
       __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
       // unreachable;
      }
      $50 = ($48>>>0)<(11);
      if ($50) {
       $51 = $48 << 1;
       $52 = $51&255;
       HEAP8[$9>>0] = $52;
       $53 = (($9) + 1|0);
       $__p$0$i$i$i$i = $53;
      } else {
       $54 = (($48) + 16)|0;
       $55 = $54 & -16;
       HEAP32[$0>>2] = 59;
       ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
       $56 = (__Z15malloc_internaljj10MemLabelIdiPKci($55,16,$$byval_copy11,0,803720,79)|0);
       $57 = (($9) + 8|0);
       HEAP32[$57>>2] = $56;
       $58 = $55 | 1;
       HEAP32[$9>>2] = $58;
       $59 = (($9) + 4|0);
       HEAP32[$59>>2] = $48;
       $__p$0$i$i$i$i = $56;
      }
      _memcpy(($__p$0$i$i$i$i|0),($44|0),($48|0))|0;
      $60 = (($__p$0$i$i$i$i) + ($48)|0);
      HEAP8[$60>>0] = 0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$8+0>>2]|0;
      invoke_viiii(424,($10|0),($34|0),($$byval_copy11|0),($9|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if (!($62)) {
       $63 = HEAP8[$9>>0]|0;
       $64 = $63 & 1;
       $65 = ($64<<24>>24)==(0);
       if ($65) {
        break;
       }
       $66 = (($9) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       HEAP32[$4>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$4+0>>2]|0;
       invoke_vii(2591,($67|0),($$byval_copy11|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if (!($69)) {
        break;
       }
       $70 = ___cxa_find_matching_catch()|0;
       $71 = tempRet0;
       ___cxa_call_unexpected(($70|0));
       // unreachable;
      }
      $72 = ___cxa_find_matching_catch()|0;
      $73 = tempRet0;
      $74 = HEAP8[$9>>0]|0;
      $75 = $74 & 1;
      $76 = ($75<<24>>24)==(0);
      if ($76) {
       $$0 = $73;$$01 = $72;
       ___resumeException($$01|0);
       // unreachable;
      }
      $77 = (($9) + 8|0);
      $78 = HEAP32[$77>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($78|0),($$byval_copy11|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       $81 = ___cxa_find_matching_catch()|0;
       $82 = tempRet0;
       ___cxa_call_unexpected(($81|0));
       // unreachable;
      } else {
       $$0 = $73;$$01 = $72;
       ___resumeException($$01|0);
       // unreachable;
      }
     }
    } while(0);
    $83 = HEAP32[$face>>2]|0;
    $84 = (($83) + 20|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (_strlen(($85|0))|0);
    $87 = ($86>>>0)>(4294967279);
    if ($87) {
     __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
     // unreachable;
    }
    $88 = ($86>>>0)<(11);
    if ($88) {
     $89 = $86 << 1;
     $90 = $89&255;
     HEAP8[$11>>0] = $90;
     $91 = (($11) + 1|0);
     $$pre$phiZ2D = $11;$108 = $90;$__p$0$i$i$i = $91;
    } else {
     $92 = (($86) + 16)|0;
     $93 = $92 & -16;
     $94 = (__Znwj($93)|0);
     $95 = (($11) + 8|0);
     HEAP32[$95>>2] = $94;
     $96 = $93 | 1;
     HEAP32[$11>>2] = $96;
     $97 = (($11) + 4|0);
     HEAP32[$97>>2] = $86;
     $98 = $96&255;
     $$pre$phiZ2D = $11;$108 = $98;$__p$0$i$i$i = $94;
    }
    _memcpy(($__p$0$i$i$i|0),($85|0),($86|0))|0;
    $99 = (($__p$0$i$i$i) + ($86)|0);
    HEAP8[$99>>0] = 0;
    $100 = (($83) + 12|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = $101 << 1;
    $103 = $102 & 2;
    $104 = $101 >>> 1;
    $105 = $104 & 1;
    $106 = $105 | $103;
    $107 = $108 & 1;
    $109 = ($107<<24>>24)==(0);
    L42: do {
     if ($109) {
      ;HEAP32[$r+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$r+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$r+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
     } else {
      $110 = (($11) + 8|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = (($11) + 4|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = ($113>>>0)>(4294967279);
      do {
       if ($114) {
        __THREW__ = 0;
        invoke_vi(3309,0);
        $115 = __THREW__; __THREW__ = 0;
        $116 = $115&1;
        if (!($116)) {
         // unreachable;
        }
       } else {
        $117 = ($113>>>0)<(11);
        if ($117) {
         $118 = $113 << 1;
         $119 = $118&255;
         HEAP8[$r>>0] = $119;
         $120 = (($r) + 1|0);
         $__p$0$i$i$i$i$i = $120;
        } else {
         $121 = (($113) + 16)|0;
         $122 = $121 & -16;
         __THREW__ = 0;
         $123 = (invoke_ii(2988,($122|0))|0);
         $124 = __THREW__; __THREW__ = 0;
         $125 = $124&1;
         if ($125) {
          break;
         }
         $126 = (($r) + 8|0);
         HEAP32[$126>>2] = $123;
         $127 = $122 | 1;
         HEAP32[$r>>2] = $127;
         $128 = (($r) + 4|0);
         HEAP32[$128>>2] = $113;
         $__p$0$i$i$i$i$i = $123;
        }
        _memcpy(($__p$0$i$i$i$i$i|0),($111|0),($113|0))|0;
        $129 = (($__p$0$i$i$i$i$i) + ($113)|0);
        HEAP8[$129>>0] = 0;
        break L42;
       }
      } while(0);
      $157 = ___cxa_find_matching_catch()|0;
      $158 = tempRet0;
      $159 = $108 & 1;
      $160 = ($159<<24>>24)==(0);
      if ($160) {
       $$0 = $158;$$01 = $157;
       ___resumeException($$01|0);
       // unreachable;
      }
      __ZdlPv($111);
      $$0 = $158;$$01 = $157;
      ___resumeException($$01|0);
      // unreachable;
     }
    } while(0);
    $130 = (($r) + 12|0);
    HEAP32[$130>>2] = $106;
    $131 = $108 & 1;
    $132 = ($131<<24>>24)==(0);
    if ($132) {
     $139 = $83;
    } else {
     $133 = (($11) + 8|0);
     $134 = HEAP32[$133>>2]|0;
     __ZdlPv($134);
     $$pre = HEAP32[$face>>2]|0;
     $139 = $$pre;
    }
    $135 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    $136 = (invoke_iii(2605,($135|0),($r|0))|0);
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    do {
     if (!($138)) {
      HEAP32[$136>>2] = $139;
      $140 = HEAP32[$130>>2]|0;
      $141 = ($140|0)==(0);
      if (!($141)) {
       HEAP32[$130>>2] = 0;
       $142 = HEAP32[803736>>2]|0;
       $143 = HEAP32[$14>>2]|0;
       $144 = HEAP32[$16>>2]|0;
       $145 = $144;
       $146 = $143;
       $147 = (($145) - ($146))|0;
       __THREW__ = 0;
       $148 = (invoke_iiiiii(218,($142|0),($143|0),($147|0),0,($face|0))|0);
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if ($150) {
        break;
       }
       $151 = ($148|0)==(0);
       if ($151) {
        $152 = HEAP32[$face>>2]|0;
        $153 = HEAP32[$19>>2]|0;
        __THREW__ = 0;
        $154 = (invoke_iii(2605,($153|0),($r|0))|0);
        $155 = __THREW__; __THREW__ = 0;
        $156 = $155&1;
        if ($156) {
         break;
        }
        HEAP32[$154>>2] = $152;
       }
      }
      $168 = HEAP8[$r>>0]|0;
      $169 = $168 & 1;
      $170 = ($169<<24>>24)==(0);
      if ($170) {
       break L1;
      }
      $171 = (($r) + 8|0);
      $172 = HEAP32[$171>>2]|0;
      __ZdlPv($172);
      break L1;
     }
    } while(0);
    $161 = ___cxa_find_matching_catch()|0;
    $162 = tempRet0;
    $163 = HEAP8[$r>>0]|0;
    $164 = $163 & 1;
    $165 = ($164<<24>>24)==(0);
    if ($165) {
     $$0 = $162;$$01 = $161;
     ___resumeException($$01|0);
     // unreachable;
    }
    $166 = (($r) + 8|0);
    $167 = HEAP32[$166>>2]|0;
    __ZdlPv($167);
    $$0 = $162;$$01 = $161;
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $173 = (($this) + 208|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 $175 = $174 == Math_fround(0.0);
 if (!($175)) {
  STACKTOP = sp;return;
 }
 $176 = (($this) + 216|0);
 $177 = HEAP32[$176>>2]|0;
 $178 = (($this) + 132|0);
 __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEEC2ERKS5_($12,$178);
 $179 = (($this) + 32|0);
 $180 = HEAP32[$179>>2]|0;
 $181 = (($this) + 144|0);
 $182 = (($this) + 28|0);
 __THREW__ = 0;
 $183 = (invoke_iiiiiii(123,($177|0),($12|0),($180|0),($181|0),($173|0),($182|0))|0);
 $184 = __THREW__; __THREW__ = 0;
 $185 = $184&1;
 if ($185) {
  $233 = ___cxa_find_matching_catch()|0;
  $234 = tempRet0;
  $235 = HEAP32[$12>>2]|0;
  $236 = ($235|0)==(0|0);
  if ($236) {
   $$0 = $234;$$01 = $233;
   ___resumeException($$01|0);
   // unreachable;
  }
  $237 = (($12) + 4|0);
  $238 = HEAP32[$237>>2]|0;
  $239 = ($238|0)==($235|0);
  L86: do {
   if (!($239)) {
    $241 = $238;
    while(1) {
     $240 = (($241) + -12|0);
     HEAP32[$237>>2] = $240;
     $242 = HEAP8[$240>>0]|0;
     $243 = $242 & 1;
     $244 = ($243<<24>>24)==(0);
     if (!($244)) {
      $246 = (($241) + -4|0);
      $247 = HEAP32[$246>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($247|0),($$byval_copy11|0));
      $248 = __THREW__; __THREW__ = 0;
      $249 = $248&1;
      if ($249) {
       break;
      }
     }
     $245 = ($240|0)==($235|0);
     if ($245) {
      break L86;
     } else {
      $241 = $240;
     }
    }
    $250 = ___cxa_find_matching_catch()|0;
    $251 = tempRet0;
    ___cxa_call_unexpected(($250|0));
    // unreachable;
   }
  } while(0);
  HEAP32[$5>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,($235|0),($$byval_copy11|0));
  $252 = __THREW__; __THREW__ = 0;
  $253 = $252&1;
  if ($253) {
   $254 = ___cxa_find_matching_catch()|0;
   $255 = tempRet0;
   ___cxa_call_unexpected(($254|0));
   // unreachable;
  } else {
   $$0 = $234;$$01 = $233;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $186 = HEAP32[$12>>2]|0;
 $187 = ($186|0)==(0|0);
 if (!($187)) {
  $188 = (($12) + 4|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = ($189|0)==($186|0);
  L101: do {
   if (!($190)) {
    $192 = $189;
    while(1) {
     $191 = (($192) + -12|0);
     HEAP32[$188>>2] = $191;
     $193 = HEAP8[$191>>0]|0;
     $194 = $193 & 1;
     $195 = ($194<<24>>24)==(0);
     if (!($195)) {
      $197 = (($192) + -4|0);
      $198 = HEAP32[$197>>2]|0;
      HEAP32[$2>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($198|0),($$byval_copy11|0));
      $199 = __THREW__; __THREW__ = 0;
      $200 = $199&1;
      if ($200) {
       break;
      }
     }
     $196 = ($191|0)==($186|0);
     if ($196) {
      break L101;
     } else {
      $192 = $191;
     }
    }
    $201 = ___cxa_find_matching_catch()|0;
    $202 = tempRet0;
    ___cxa_call_unexpected(($201|0));
    // unreachable;
   }
  } while(0);
  HEAP32[$3>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($186|0),($$byval_copy11|0));
  $203 = __THREW__; __THREW__ = 0;
  $204 = $203&1;
  if ($204) {
   $205 = ___cxa_find_matching_catch()|0;
   $206 = tempRet0;
   ___cxa_call_unexpected(($205|0));
   // unreachable;
  }
 }
 if ($183) {
  STACKTOP = sp;return;
 }
 $207 = HEAP32[$176>>2]|0;
 $208 = (__ZN20TextRenderingPrivate12GetFallbacksEv()|0);
 __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEEC2ERKS5_($13,$208);
 $209 = HEAP32[$179>>2]|0;
 __THREW__ = 0;
 (invoke_iiiiiii(123,($207|0),($13|0),($209|0),($181|0),($173|0),($182|0))|0);
 $210 = __THREW__; __THREW__ = 0;
 $211 = $210&1;
 if ($211) {
  $256 = ___cxa_find_matching_catch()|0;
  $257 = tempRet0;
  $258 = HEAP32[$13>>2]|0;
  $259 = ($258|0)==(0|0);
  if ($259) {
   $$0 = $257;$$01 = $256;
   ___resumeException($$01|0);
   // unreachable;
  }
  $260 = (($13) + 4|0);
  $261 = HEAP32[$260>>2]|0;
  $262 = ($261|0)==($258|0);
  L120: do {
   if (!($262)) {
    $264 = $261;
    while(1) {
     $263 = (($264) + -12|0);
     HEAP32[$260>>2] = $263;
     $265 = HEAP8[$263>>0]|0;
     $266 = $265 & 1;
     $267 = ($266<<24>>24)==(0);
     if (!($267)) {
      $269 = (($264) + -4|0);
      $270 = HEAP32[$269>>2]|0;
      HEAP32[$6>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$6+0>>2]|0;
      invoke_vii(2591,($270|0),($$byval_copy11|0));
      $271 = __THREW__; __THREW__ = 0;
      $272 = $271&1;
      if ($272) {
       break;
      }
     }
     $268 = ($263|0)==($258|0);
     if ($268) {
      break L120;
     } else {
      $264 = $263;
     }
    }
    $273 = ___cxa_find_matching_catch()|0;
    $274 = tempRet0;
    ___cxa_call_unexpected(($273|0));
    // unreachable;
   }
  } while(0);
  HEAP32[$7>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$7+0>>2]|0;
  invoke_vii(2591,($258|0),($$byval_copy11|0));
  $275 = __THREW__; __THREW__ = 0;
  $276 = $275&1;
  if ($276) {
   $277 = ___cxa_find_matching_catch()|0;
   $278 = tempRet0;
   ___cxa_call_unexpected(($277|0));
   // unreachable;
  } else {
   $$0 = $257;$$01 = $256;
   ___resumeException($$01|0);
   // unreachable;
  }
 } else {
  $212 = HEAP32[$13>>2]|0;
  $213 = ($212|0)==(0|0);
  if ($213) {
   STACKTOP = sp;return;
  }
  $214 = (($13) + 4|0);
  $215 = HEAP32[$214>>2]|0;
  $216 = ($215|0)==($212|0);
  L136: do {
   if (!($216)) {
    $218 = $215;
    while(1) {
     $217 = (($218) + -12|0);
     HEAP32[$214>>2] = $217;
     $219 = HEAP8[$217>>0]|0;
     $220 = $219 & 1;
     $221 = ($220<<24>>24)==(0);
     if (!($221)) {
      $223 = (($218) + -4|0);
      $224 = HEAP32[$223>>2]|0;
      HEAP32[$0>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($224|0),($$byval_copy11|0));
      $225 = __THREW__; __THREW__ = 0;
      $226 = $225&1;
      if ($226) {
       break;
      }
     }
     $222 = ($217|0)==($212|0);
     if ($222) {
      break L136;
     } else {
      $218 = $217;
     }
    }
    $227 = ___cxa_find_matching_catch()|0;
    $228 = tempRet0;
    ___cxa_call_unexpected(($227|0));
    // unreachable;
   }
  } while(0);
  HEAP32[$1>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($212|0),($$byval_copy11|0));
  $229 = __THREW__; __THREW__ = 0;
  $230 = $229&1;
  if ($230) {
   $231 = ___cxa_find_matching_catch()|0;
   $232 = tempRet0;
   ___cxa_call_unexpected(($231|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE6insertENS_11__wrap_iterIPKS1_EERS7_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i16 = 0, $$0$i17 = 0, $$byval_copy12 = 0, $$byval_copy21 = 0, $$pre = 0, $$pre11$pre = 0, $$pre12$pre = 0, $$pre7$i = 0, $$sum = 0, $$sum15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0 = 0, $__p$0$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i = 0, $__t$i = 0, $__v = 0, $__xr$0 = 0, $eh$lpad$body18$index4Z2D = 0, $eh$lpad$body18$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy21 = sp + 76|0;
 $$byval_copy12 = sp + 72|0;
 $0 = sp + 68|0;
 $1 = sp + 64|0;
 $2 = sp + 60|0;
 $3 = sp + 56|0;
 $__t$i = sp + 36|0;
 $4 = sp + 12|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $__v = sp + 16|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = HEAP32[$__position>>2]|0;
 $10 = $9;
 $11 = $8;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = (($8) + (($13*12)|0)|0);
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($16>>>0)<($18>>>0);
 if ($19) {
  $20 = ($14|0)==($16|0);
  if (!($20)) {
   $$sum = (($13) + 1)|0;
   $48 = (($8) + (($$sum*12)|0)|0);
   __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE12__move_rangeEPS1_S6_S6_($this,$14,$16,$48);
   $49 = ($14>>>0)>($__x>>>0);
   if ($49) {
    $__xr$0 = $__x;
   } else {
    $50 = HEAP32[$15>>2]|0;
    $51 = ($50>>>0)>($__x>>>0);
    $52 = (($__x) + 12|0);
    $$ = $51 ? $52 : $__x;
    $__xr$0 = $$;
   }
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($14,$__xr$0)|0);
   $__p$0 = $14;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $21 = ($14|0)==(0|0);
  if ($21) {
   $47 = 0;
  } else {
   $22 = HEAP8[$__x>>0]|0;
   $23 = $22 & 1;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    $29 = (($__x) + 1|0);
    $30 = $22&255;
    $31 = $30 >>> 1;
    $33 = $31;$44 = $29;
   } else {
    $25 = (($__x) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($__x) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $33 = $28;$44 = $26;
   }
   $32 = ($33>>>0)>(2147483631);
   if ($32) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $34 = ($33>>>0)<(11);
   if ($34) {
    $35 = $33 << 1;
    $36 = $35&255;
    HEAP8[$14>>0] = $36;
    $37 = (($14) + 1|0);
    $__p$0$i$i$i$i$i = $37;
   } else {
    $38 = (($33) + 16)|0;
    $39 = $38 & -16;
    HEAP32[$$byval_copy12>>2] = 59;
    ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$$byval_copy12+0>>2]|0;
    $40 = (__Z15malloc_internaljj10MemLabelIdiPKci($39,16,$$byval_copy21,0,803720,79)|0);
    $41 = ((($8) + (($13*12)|0)|0) + 8|0);
    HEAP32[$41>>2] = $40;
    $42 = $39 | 1;
    HEAP32[$14>>2] = $42;
    $43 = ((($8) + (($13*12)|0)|0) + 4|0);
    HEAP32[$43>>2] = $33;
    $__p$0$i$i$i$i$i = $40;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($44|0),($33|0))|0;
   $45 = (($__p$0$i$i$i$i$i) + ($33)|0);
   HEAP8[$45>>0] = 0;
   $$pre = HEAP32[$15>>2]|0;
   $47 = $$pre;
  }
  $46 = (($47) + 12|0);
  HEAP32[$15>>2] = $46;
  $__p$0 = $14;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $53 = (($this) + 8|0);
 $54 = $16;
 $55 = (($54) - ($11))|0;
 $56 = (($55|0) / 12)&-1;
 $57 = (($56) + 1)|0;
 $58 = ($57|0)<(0);
 if ($58) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $59 = $18;
 $60 = (($59) - ($11))|0;
 $61 = (($60|0) / 12)&-1;
 $62 = ($61>>>0)<(1073741823);
 if ($62) {
  $66 = $61 << 1;
  $67 = ($66>>>0)<($57>>>0);
  $68 = $67 ? $57 : $66;
  $69 = (($12|0) / 12)&-1;
  $70 = (($__v) + 12|0);
  HEAP32[$70>>2] = 0;
  $71 = (($__v) + 16|0);
  HEAP32[$71>>2] = $53;
  $72 = ($68|0)==(0);
  if ($72) {
   $$0$i17 = 0;$75 = 0;$77 = $69;$81 = $70;
  } else {
   $$0$i16 = $68;$213 = $70;$214 = $69;
   label = 22;
  }
 } else {
  $63 = (($12|0) / 12)&-1;
  $64 = (($__v) + 12|0);
  HEAP32[$64>>2] = 0;
  $65 = (($__v) + 16|0);
  HEAP32[$65>>2] = $53;
  $$0$i16 = 2147483647;$213 = $64;$214 = $63;
  label = 22;
 }
 if ((label|0) == 22) {
  $73 = ($$0$i16*12)|0;
  HEAP32[$$byval_copy12>>2] = 27;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$$byval_copy12+0>>2]|0;
  $74 = (__Z15malloc_internaljj10MemLabelIdiPKci($73,16,$$byval_copy21,0,803720,79)|0);
  $$0$i17 = $$0$i16;$75 = $74;$77 = $214;$81 = $213;
 }
 HEAP32[$__v>>2] = $75;
 $76 = (($75) + (($77*12)|0)|0);
 $78 = (($__v) + 8|0);
 HEAP32[$78>>2] = $76;
 $79 = (($__v) + 4|0);
 HEAP32[$79>>2] = $76;
 $80 = (($75) + (($$0$i17*12)|0)|0);
 HEAP32[$81>>2] = $80;
 $82 = ($77|0)==($$0$i17|0);
 do {
  if ($82) {
   $83 = ($12|0)>(0);
   $84 = (($12|0) / 12)&-1;
   if ($83) {
    $85 = (($84) + 1)|0;
    $86 = (($85|0) / -2)&-1;
    $$sum15 = (($77) + ($86))|0;
    $87 = (($75) + (($$sum15*12)|0)|0);
    HEAP32[$78>>2] = $87;
    HEAP32[$79>>2] = $87;
    $137 = $87;
    label = 40;
    break;
   }
   $88 = $84 << 1;
   $89 = ($88|0)==(0);
   $90 = $89 ? 1 : $88;
   $91 = (($__t$i) + 12|0);
   $92 = (($__t$i) + 16|0);
   HEAP32[$92>>2] = $53;
   $93 = ($90*12)|0;
   HEAP32[$0>>2] = 27;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
   $94 = (invoke_iiiiiii(102,($93|0),16,($$byval_copy21|0),0,(803720|0),79)|0);
   $95 = __THREW__; __THREW__ = 0;
   $96 = $95&1;
   if ($96) {
    label = 62;
   } else {
    $97 = $90 >>> 2;
    HEAP32[$__t$i>>2] = $94;
    $98 = (($94) + (($97*12)|0)|0);
    $99 = (($__t$i) + 8|0);
    HEAP32[$99>>2] = $98;
    $100 = (($__t$i) + 4|0);
    HEAP32[$100>>2] = $98;
    $101 = (($94) + (($90*12)|0)|0);
    HEAP32[$91>>2] = $101;
    HEAP32[$4>>2] = $76;
    HEAP32[$5>>2] = $76;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
    ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_viii(2042,($__t$i|0),($$byval_copy12|0),($$byval_copy21|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if (!($103)) {
     $104 = HEAP32[$__t$i>>2]|0;
     HEAP32[$__v>>2] = $104;
     HEAP32[$__t$i>>2] = $75;
     $105 = HEAP32[$100>>2]|0;
     HEAP32[$79>>2] = $105;
     HEAP32[$100>>2] = $76;
     $106 = HEAP32[$99>>2]|0;
     HEAP32[$78>>2] = $106;
     HEAP32[$99>>2] = $76;
     $107 = HEAP32[$91>>2]|0;
     HEAP32[$81>>2] = $107;
     HEAP32[$91>>2] = $76;
     $108 = ($75|0)==(0|0);
     if ($108) {
      $137 = $106;
      label = 40;
      break;
     }
     HEAP32[$$byval_copy12>>2] = 27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$$byval_copy12+0>>2]|0;
     invoke_vii(2591,($75|0),($$byval_copy21|0));
     $109 = __THREW__; __THREW__ = 0;
     $110 = $109&1;
     if (!($110)) {
      $137 = $106;
      label = 40;
      break;
     }
     $111 = ___cxa_find_matching_catch()|0;
     $112 = tempRet0;
     ___cxa_call_unexpected(($111|0));
     // unreachable;
    }
    $113 = ___cxa_find_matching_catch()|0;
    $114 = tempRet0;
    $115 = HEAP32[$100>>2]|0;
    $116 = HEAP32[$99>>2]|0;
    $117 = ($116|0)==($115|0);
    L46: do {
     if (!($117)) {
      $119 = $116;
      while(1) {
       $118 = (($119) + -12|0);
       HEAP32[$99>>2] = $118;
       $120 = HEAP8[$118>>0]|0;
       $121 = $120 & 1;
       $122 = ($121<<24>>24)==(0);
       if (!($122)) {
        $124 = (($119) + -4|0);
        $125 = HEAP32[$124>>2]|0;
        HEAP32[$2>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($125|0),($$byval_copy21|0));
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if ($127) {
         break;
        }
       }
       $123 = ($118|0)==($115|0);
       if ($123) {
        break L46;
       } else {
        $119 = $118;
       }
      }
      $128 = ___cxa_find_matching_catch()|0;
      $129 = tempRet0;
      ___cxa_call_unexpected(($128|0));
      // unreachable;
     }
    } while(0);
    $130 = HEAP32[$__t$i>>2]|0;
    $131 = ($130|0)==(0|0);
    if ($131) {
     $eh$lpad$body18$index4Z2D = $114;$eh$lpad$body18$indexZ2D = $113;
    } else {
     HEAP32[$1>>2] = 27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($130|0),($$byval_copy21|0));
     $132 = __THREW__; __THREW__ = 0;
     $133 = $132&1;
     if ($133) {
      $134 = ___cxa_find_matching_catch()|0;
      $135 = tempRet0;
      ___cxa_call_unexpected(($134|0));
      // unreachable;
     } else {
      $eh$lpad$body18$index4Z2D = $114;$eh$lpad$body18$indexZ2D = $113;
     }
    }
   }
  } else {
   $137 = $76;
   label = 40;
  }
 } while(0);
 do {
  if ((label|0) == 40) {
   $136 = ($137|0)==(0|0);
   if ($136) {
    $167 = 0;
   } else {
    $138 = HEAP8[$__x>>0]|0;
    $139 = $138 & 1;
    $140 = ($139<<24>>24)==(0);
    if ($140) {
     $145 = (($__x) + 1|0);
     $146 = $138&255;
     $147 = $146 >>> 1;
     $149 = $147;$164 = $145;
    } else {
     $141 = (($__x) + 8|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = (($__x) + 4|0);
     $144 = HEAP32[$143>>2]|0;
     $149 = $144;$164 = $142;
    }
    $148 = ($149>>>0)>(2147483631);
    if ($148) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $150 = __THREW__; __THREW__ = 0;
     $151 = $150&1;
     if ($151) {
      label = 62;
      break;
     }
     // unreachable;
    }
    $152 = ($149>>>0)<(11);
    if ($152) {
     $153 = $149 << 1;
     $154 = $153&255;
     HEAP8[$137>>0] = $154;
     $155 = (($137) + 1|0);
     $__p$0$i$i$i$i$i$i = $155;
    } else {
     $156 = (($149) + 16)|0;
     $157 = $156 & -16;
     HEAP32[$3>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
     $158 = (invoke_iiiiiii(102,($157|0),16,($$byval_copy21|0),0,(803720|0),79)|0);
     $159 = __THREW__; __THREW__ = 0;
     $160 = $159&1;
     if ($160) {
      label = 62;
      break;
     }
     $161 = (($137) + 8|0);
     HEAP32[$161>>2] = $158;
     $162 = $157 | 1;
     HEAP32[$137>>2] = $162;
     $163 = (($137) + 4|0);
     HEAP32[$163>>2] = $149;
     $__p$0$i$i$i$i$i$i = $158;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($164|0),($149|0))|0;
    $165 = (($__p$0$i$i$i$i$i$i) + ($149)|0);
    HEAP8[$165>>0] = 0;
    $$pre7$i = HEAP32[$78>>2]|0;
    $167 = $$pre7$i;
   }
   $166 = (($167) + 12|0);
   HEAP32[$78>>2] = $166;
   __THREW__ = 0;
   $168 = (invoke_iiii(1596,($this|0),($__v|0),($14|0))|0);
   $169 = __THREW__; __THREW__ = 0;
   $170 = $169&1;
   if ($170) {
    label = 62;
   } else {
    $171 = HEAP32[$79>>2]|0;
    $172 = HEAP32[$78>>2]|0;
    $173 = ($172|0)==($171|0);
    L76: do {
     if (!($173)) {
      $175 = $172;
      while(1) {
       $174 = (($175) + -12|0);
       HEAP32[$78>>2] = $174;
       $176 = HEAP8[$174>>0]|0;
       $177 = $176 & 1;
       $178 = ($177<<24>>24)==(0);
       if (!($178)) {
        $180 = (($175) + -4|0);
        $181 = HEAP32[$180>>2]|0;
        HEAP32[$1>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_vii(2591,($181|0),($$byval_copy21|0));
        $182 = __THREW__; __THREW__ = 0;
        $183 = $182&1;
        if ($183) {
         break;
        }
       }
       $179 = ($174|0)==($171|0);
       if ($179) {
        break L76;
       } else {
        $175 = $174;
       }
      }
      $184 = ___cxa_find_matching_catch()|0;
      $185 = tempRet0;
      ___cxa_call_unexpected(($184|0));
      // unreachable;
     }
    } while(0);
    $186 = HEAP32[$__v>>2]|0;
    $187 = ($186|0)==(0|0);
    if ($187) {
     $__p$0 = $168;
     HEAP32[$agg$result>>2] = $__p$0;
     STACKTOP = sp;return;
    }
    HEAP32[$0>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($186|0),($$byval_copy21|0));
    $188 = __THREW__; __THREW__ = 0;
    $189 = $188&1;
    if ($189) {
     $190 = ___cxa_find_matching_catch()|0;
     $191 = tempRet0;
     ___cxa_call_unexpected(($190|0));
     // unreachable;
    } else {
     $__p$0 = $168;
     HEAP32[$agg$result>>2] = $__p$0;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 L91: do {
  if ((label|0) == 62) {
   $192 = ___cxa_find_matching_catch()|0;
   $193 = tempRet0;
   $$pre11$pre = HEAP32[$79>>2]|0;
   $$pre12$pre = HEAP32[$78>>2]|0;
   $194 = ($$pre12$pre|0)==($$pre11$pre|0);
   if ($194) {
    $eh$lpad$body18$index4Z2D = $193;$eh$lpad$body18$indexZ2D = $192;
   } else {
    $196 = $$pre12$pre;
    while(1) {
     $195 = (($196) + -12|0);
     HEAP32[$78>>2] = $195;
     $197 = HEAP8[$195>>0]|0;
     $198 = $197 & 1;
     $199 = ($198<<24>>24)==(0);
     if (!($199)) {
      $201 = (($196) + -4|0);
      $202 = HEAP32[$201>>2]|0;
      HEAP32[$7>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$7+0>>2]|0;
      invoke_vii(2591,($202|0),($$byval_copy21|0));
      $203 = __THREW__; __THREW__ = 0;
      $204 = $203&1;
      if ($204) {
       break;
      }
     }
     $200 = ($195|0)==($$pre11$pre|0);
     if ($200) {
      $eh$lpad$body18$index4Z2D = $193;$eh$lpad$body18$indexZ2D = $192;
      break L91;
     } else {
      $196 = $195;
     }
    }
    $205 = ___cxa_find_matching_catch()|0;
    $206 = tempRet0;
    ___cxa_call_unexpected(($205|0));
    // unreachable;
   }
  }
 } while(0);
 $207 = HEAP32[$__v>>2]|0;
 $208 = ($207|0)==(0|0);
 if ($208) {
  ___resumeException($eh$lpad$body18$indexZ2D|0);
  // unreachable;
 }
 HEAP32[$6>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$6+0>>2]|0;
 invoke_vii(2591,($207|0),($$byval_copy21|0));
 $209 = __THREW__; __THREW__ = 0;
 $210 = $209&1;
 if ($210) {
  $211 = ___cxa_find_matching_catch()|0;
  $212 = tempRet0;
  ___cxa_call_unexpected(($211|0));
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body18$indexZ2D|0);
  // unreachable;
 }
}
function __ZN20TextRenderingPrivate4Font15InitializeClassEv() {
 var $0 = 0, $1 = 0, $fontAlloc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fontAlloc = sp;
 __ZN20TextRenderingPrivate15GetFontsManager16StaticInitializeEv();
 ;HEAP32[$fontAlloc+0>>2]=HEAP32[803896+0>>2]|0;HEAP32[$fontAlloc+4>>2]=HEAP32[803896+4>>2]|0;HEAP32[$fontAlloc+8>>2]=HEAP32[803896+8>>2]|0;HEAP32[$fontAlloc+12>>2]=HEAP32[803896+12>>2]|0;
 $0 = (_Unity_FT_Init_FreeType(803736,$fontAlloc)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  HEAP8[803944>>0] = 1;
  STACKTOP = sp;return;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(803912,0,803720,502,1,0,0,0);
 HEAP8[803944>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font12CleanupClassEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP8[803808>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = HEAP32[803736>>2]|0;
  (_FT_Bitmap_Done($3,803816)|0);
  HEAP8[803808>>0] = 0;
 }
 $4 = HEAP8[803944>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = HEAP32[803736>>2]|0;
  (_Unity_FT_Done_FreeType($6)|0);
  HEAP8[803944>>0] = 0;
 }
 $7 = HEAP32[803728>>2]|0;
 $8 = HEAP32[628344>>2]|0;
 $9 = ($7|0)==(0|0);
 if (!($9)) {
  $10 = (($7) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefENS2_6OSFontEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($7,$11);
 }
 HEAP32[$0>>2] = $8;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($7,$$byval_copy);
 HEAP32[803728>>2] = 0;
 __ZN20TextRenderingPrivate15GetFontsManager13StaticDestroyEv();
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE21__push_back_slow_pathIKS1_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i8 = 0, $$0$i9 = 0, $$byval_copy5 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i$i = 0, $__v = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp + 32|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $__v = sp + 12|0;
 $3 = (($this) + 8|0);
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$this>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = (($10) + 1)|0;
 $12 = ($11|0)<(0);
 if ($12) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($8))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = ($17>>>0)<(1073741823);
 if ($18) {
  $21 = $17 << 1;
  $22 = ($21>>>0)<($11>>>0);
  $23 = $22 ? $11 : $21;
  $24 = (($__v) + 12|0);
  HEAP32[$24>>2] = 0;
  $25 = (($__v) + 16|0);
  HEAP32[$25>>2] = $3;
  $26 = ($23|0)==(0);
  if ($26) {
   $$0$i9 = 0;$29 = 0;$34 = $24;
  } else {
   $$0$i8 = $23;$112 = $24;
   label = 6;
  }
 } else {
  $19 = (($__v) + 12|0);
  HEAP32[$19>>2] = 0;
  $20 = (($__v) + 16|0);
  HEAP32[$20>>2] = $3;
  $$0$i8 = 2147483647;$112 = $19;
  label = 6;
 }
 if ((label|0) == 6) {
  $27 = ($$0$i8*12)|0;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($27,16,$$byval_copy5,0,803720,79)|0);
  $$0$i9 = $$0$i8;$29 = $28;$34 = $112;
 }
 HEAP32[$__v>>2] = $29;
 $30 = (($29) + (($10*12)|0)|0);
 $31 = (($__v) + 8|0);
 HEAP32[$31>>2] = $30;
 $32 = (($__v) + 4|0);
 HEAP32[$32>>2] = $30;
 $33 = (($29) + (($$0$i9*12)|0)|0);
 HEAP32[$34>>2] = $33;
 $35 = ($30|0)==(0|0);
 do {
  if ($35) {
   $65 = 0;
   label = 19;
  } else {
   $36 = HEAP8[$__x>>0]|0;
   $37 = $36 & 1;
   $38 = ($37<<24>>24)==(0);
   if ($38) {
    $43 = (($__x) + 1|0);
    $44 = $36&255;
    $45 = $44 >>> 1;
    $47 = $45;$62 = $43;
   } else {
    $39 = (($__x) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($__x) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $47 = $42;$62 = $40;
   }
   $46 = ($47>>>0)>(2147483631);
   if ($46) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    // unreachable;
   }
   $50 = ($47>>>0)<(11);
   if ($50) {
    $51 = $47 << 1;
    $52 = $51&255;
    HEAP8[$30>>0] = $52;
    $53 = (($30) + 1|0);
    $__p$0$i$i$i$i$i = $53;
   } else {
    $54 = (($47) + 16)|0;
    $55 = $54 & -16;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $56 = (invoke_iiiiiii(102,($55|0),16,($$byval_copy5|0),0,(803720|0),79)|0);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     break;
    }
    $59 = ((($29) + (($10*12)|0)|0) + 8|0);
    HEAP32[$59>>2] = $56;
    $60 = $55 | 1;
    HEAP32[$30>>2] = $60;
    $61 = ((($29) + (($10*12)|0)|0) + 4|0);
    HEAP32[$61>>2] = $47;
    $__p$0$i$i$i$i$i = $56;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($62|0),($47|0))|0;
   $63 = (($__p$0$i$i$i$i$i) + ($47)|0);
   HEAP8[$63>>0] = 0;
   $$pre = HEAP32[$31>>2]|0;
   $65 = $$pre;
   label = 19;
  }
 } while(0);
 if ((label|0) == 19) {
  $64 = (($65) + 12|0);
  HEAP32[$31>>2] = $64;
  __THREW__ = 0;
  invoke_vii(3431,($this|0),($__v|0));
  $66 = __THREW__; __THREW__ = 0;
  $67 = $66&1;
  if (!($67)) {
   $68 = HEAP32[$32>>2]|0;
   $69 = HEAP32[$31>>2]|0;
   $70 = ($69|0)==($68|0);
   L28: do {
    if (!($70)) {
     $72 = $69;
     while(1) {
      $71 = (($72) + -12|0);
      HEAP32[$31>>2] = $71;
      $73 = HEAP8[$71>>0]|0;
      $74 = $73 & 1;
      $75 = ($74<<24>>24)==(0);
      if (!($75)) {
       $77 = (($72) + -4|0);
       $78 = HEAP32[$77>>2]|0;
       HEAP32[$1>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($78|0),($$byval_copy5|0));
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        break;
       }
      }
      $76 = ($71|0)==($68|0);
      if ($76) {
       break L28;
      } else {
       $72 = $71;
      }
     }
     $81 = ___cxa_find_matching_catch()|0;
     $82 = tempRet0;
     ___cxa_call_unexpected(($81|0));
     // unreachable;
    }
   } while(0);
   $83 = HEAP32[$__v>>2]|0;
   $84 = ($83|0)==(0|0);
   if ($84) {
    STACKTOP = sp;return;
   }
   HEAP32[$0>>2] = 27;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($83|0),($$byval_copy5|0));
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    $87 = ___cxa_find_matching_catch()|0;
    $88 = tempRet0;
    ___cxa_call_unexpected(($87|0));
    // unreachable;
   } else {
    STACKTOP = sp;return;
   }
  }
 }
 $89 = ___cxa_find_matching_catch()|0;
 $90 = tempRet0;
 $91 = HEAP32[$32>>2]|0;
 $92 = HEAP32[$31>>2]|0;
 $93 = ($92|0)==($91|0);
 L44: do {
  if (!($93)) {
   $95 = $92;
   while(1) {
    $94 = (($95) + -12|0);
    HEAP32[$31>>2] = $94;
    $96 = HEAP8[$94>>0]|0;
    $97 = $96 & 1;
    $98 = ($97<<24>>24)==(0);
    if (!($98)) {
     $100 = (($95) + -4|0);
     $101 = HEAP32[$100>>2]|0;
     HEAP32[$2>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($101|0),($$byval_copy5|0));
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      break;
     }
    }
    $99 = ($94|0)==($91|0);
    if ($99) {
     break L44;
    } else {
     $95 = $94;
    }
   }
   $104 = ___cxa_find_matching_catch()|0;
   $105 = tempRet0;
   ___cxa_call_unexpected(($104|0));
   // unreachable;
  }
 } while(0);
 $106 = HEAP32[$__v>>2]|0;
 $107 = ($106|0)==(0|0);
 if ($107) {
  ___resumeException($89|0);
  // unreachable;
 }
 HEAP32[$1>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($106|0),($$byval_copy5|0));
 $108 = __THREW__; __THREW__ = 0;
 $109 = $108&1;
 if ($109) {
  $110 = ___cxa_find_matching_catch()|0;
  $111 = tempRet0;
  ___cxa_call_unexpected(($110|0));
  // unreachable;
 } else {
  ___resumeException($89|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS4_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $$01$i = 0, $$byval_copy = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__v) + 4|0);
 $5 = ($3|0)==($1|0);
 do {
  if ($5) {
   $$pre1 = HEAP32[$4>>2]|0;
   $36 = $$pre1;$37 = $1;
  } else {
   $$pre$i = HEAP32[$4>>2]|0;
   $$01$i = $3;$7 = $$pre$i;
   while(1) {
    $6 = (($7) + -12|0);
    $8 = (($$01$i) + -12|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9 & 1;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $16 = (($8) + 1|0);
     $17 = $9&255;
     $18 = $17 >>> 1;
     $20 = $18;$31 = $16;
    } else {
     $12 = (($$01$i) + -4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($$01$i) + -8|0);
     $15 = HEAP32[$14>>2]|0;
     $20 = $15;$31 = $13;
    }
    $19 = ($20>>>0)>(2147483631);
    if ($19) {
     label = 8;
     break;
    }
    $21 = ($20>>>0)<(11);
    if ($21) {
     $22 = $20 << 1;
     $23 = $22&255;
     HEAP8[$6>>0] = $23;
     $24 = (($6) + 1|0);
     $__p$0$i$i$i$i$i$i = $24;
    } else {
     $25 = (($20) + 16)|0;
     $26 = $25 & -16;
     HEAP32[$0>>2] = 59;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $27 = (__Z15malloc_internaljj10MemLabelIdiPKci($26,16,$$byval_copy,0,803720,79)|0);
     $28 = (($7) + -4|0);
     HEAP32[$28>>2] = $27;
     $29 = $26 | 1;
     HEAP32[$6>>2] = $29;
     $30 = (($7) + -8|0);
     HEAP32[$30>>2] = $20;
     $__p$0$i$i$i$i$i$i = $27;
    }
    _memcpy(($__p$0$i$i$i$i$i$i|0),($31|0),($20|0))|0;
    $32 = (($__p$0$i$i$i$i$i$i) + ($20)|0);
    HEAP8[$32>>0] = 0;
    $33 = HEAP32[$4>>2]|0;
    $34 = (($33) + -12|0);
    HEAP32[$4>>2] = $34;
    $35 = ($8|0)==($1|0);
    if ($35) {
     label = 13;
     break;
    } else {
     $$01$i = $8;$7 = $34;
    }
   }
   if ((label|0) == 8) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 13) {
    $$pre = HEAP32[$this>>2]|0;
    $36 = $34;$37 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $36;
 HEAP32[$4>>2] = $37;
 $38 = (($__v) + 8|0);
 $39 = HEAP32[$2>>2]|0;
 $40 = HEAP32[$38>>2]|0;
 HEAP32[$2>>2] = $40;
 HEAP32[$38>>2] = $39;
 $41 = (($this) + 8|0);
 $42 = (($__v) + 12|0);
 $43 = HEAP32[$41>>2]|0;
 $44 = HEAP32[$42>>2]|0;
 HEAP32[$41>>2] = $44;
 HEAP32[$42>>2] = $43;
 $45 = HEAP32[$4>>2]|0;
 HEAP32[$__v>>2] = $45;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEEC2ERKS5_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$byval_copy2 = 0, $$pre$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$this>>2] = 0;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = (($__x) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$__x>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 12)&-1;
 $12 = ($6|0)==($7|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = ($10|0)<(0);
 if ($13) {
  __THREW__ = 0;
  invoke_vi(3308,0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   // unreachable;
  }
 } else {
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (invoke_iiiiiii(102,($10|0),16,($$byval_copy2|0),0,(803720|0),79)|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   HEAP32[$3>>2] = $16;
   HEAP32[$this>>2] = $16;
   $19 = (($16) + (($11*12)|0)|0);
   HEAP32[$4>>2] = $19;
   $20 = HEAP32[$__x>>2]|0;
   $21 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_viii(2043,($this|0),($20|0),($21|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    STACKTOP = sp;return;
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $26 = HEAP32[$this>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  ___resumeException($24|0);
  // unreachable;
 }
 $28 = HEAP32[$3>>2]|0;
 $29 = ($28|0)==($26|0);
 do {
  if ($29) {
   $43 = $26;
  } else {
   $31 = $28;
   while(1) {
    $30 = (($31) + -12|0);
    HEAP32[$3>>2] = $30;
    $32 = HEAP8[$30>>0]|0;
    $33 = $32 & 1;
    $34 = ($33<<24>>24)==(0);
    if ($34) {
     $36 = $30;
    } else {
     $37 = (($31) + -4|0);
     $38 = HEAP32[$37>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($38|0),($$byval_copy2|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 14;
      break;
     }
     $$pre$i$i$i = HEAP32[$3>>2]|0;
     $36 = $$pre$i$i$i;
    }
    $35 = ($36|0)==($26|0);
    if ($35) {
     label = 15;
     break;
    } else {
     $31 = $36;
    }
   }
   if ((label|0) == 14) {
    $41 = ___cxa_find_matching_catch()|0;
    $42 = tempRet0;
    ___cxa_call_unexpected(($41|0));
    // unreachable;
   }
   else if ((label|0) == 15) {
    $$pre$i = HEAP32[$this>>2]|0;
    $43 = $$pre$i;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($43|0),($$byval_copy2|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  ___resumeException($24|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$01 = 0, $$byval_copy = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__first|0)==($__last|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 $$pre = HEAP32[$2>>2]|0;
 $$01 = $__first;$4 = $$pre;
 while(1) {
  $3 = ($4|0)==(0|0);
  if ($3) {
   $30 = 0;
  } else {
   $5 = HEAP8[$$01>>0]|0;
   $6 = $5 & 1;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $12 = (($$01) + 1|0);
    $13 = $5&255;
    $14 = $13 >>> 1;
    $16 = $14;$27 = $12;
   } else {
    $8 = (($$01) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($$01) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $16 = $11;$27 = $9;
   }
   $15 = ($16>>>0)>(2147483631);
   if ($15) {
    label = 8;
    break;
   }
   $17 = ($16>>>0)<(11);
   if ($17) {
    $18 = $16 << 1;
    $19 = $18&255;
    HEAP8[$4>>0] = $19;
    $20 = (($4) + 1|0);
    $__p$0$i$i$i$i$i = $20;
   } else {
    $21 = (($16) + 16)|0;
    $22 = $21 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $23 = (__Z15malloc_internaljj10MemLabelIdiPKci($22,16,$$byval_copy,0,803720,79)|0);
    $24 = (($4) + 8|0);
    HEAP32[$24>>2] = $23;
    $25 = $22 | 1;
    HEAP32[$4>>2] = $25;
    $26 = (($4) + 4|0);
    HEAP32[$26>>2] = $16;
    $__p$0$i$i$i$i$i = $23;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($27|0),($16|0))|0;
   $28 = (($__p$0$i$i$i$i$i) + ($16)|0);
   HEAP8[$28>>0] = 0;
   $$pre2 = HEAP32[$2>>2]|0;
   $30 = $$pre2;
  }
  $29 = (($30) + 12|0);
  HEAP32[$2>>2] = $29;
  $31 = (($$01) + 12|0);
  $32 = ($31|0)==($__last|0);
  if ($32) {
   label = 14;
   break;
  } else {
   $$01 = $31;$4 = $29;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE12__move_rangeEPS1_S6_S6_($this,$__from_s,$__from_e,$__to) {
 $this = $this|0;
 $__from_s = $__from_s|0;
 $__from_e = $__from_e|0;
 $__to = $__to|0;
 var $$012$i$i = 0, $$03$i$i = 0, $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$01 = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $__to;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($__from_s) + (($6*12)|0)|0);
 $8 = ($7>>>0)<($__from_e>>>0);
 L1: do {
  if ($8) {
   $10 = $2;$__i$01 = $7;
   while(1) {
    $9 = ($10|0)==(0|0);
    if ($9) {
     $37 = 0;
    } else {
     $11 = HEAP8[$__i$01>>0]|0;
     $12 = $11 & 1;
     $13 = ($12<<24>>24)==(0);
     if ($13) {
      $18 = (($__i$01) + 1|0);
      $19 = $11&255;
      $20 = $19 >>> 1;
      $22 = $20;$33 = $18;
     } else {
      $14 = (($__i$01) + 8|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($__i$01) + 4|0);
      $17 = HEAP32[$16>>2]|0;
      $22 = $17;$33 = $15;
     }
     $21 = ($22>>>0)>(2147483631);
     if ($21) {
      break;
     }
     $23 = ($22>>>0)<(11);
     if ($23) {
      $24 = $22 << 1;
      $25 = $24&255;
      HEAP8[$10>>0] = $25;
      $26 = (($10) + 1|0);
      $__p$0$i$i$i$i$i = $26;
     } else {
      $27 = (($22) + 16)|0;
      $28 = $27 & -16;
      HEAP32[$0>>2] = 59;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy,0,803720,79)|0);
      $30 = (($10) + 8|0);
      HEAP32[$30>>2] = $29;
      $31 = $28 | 1;
      HEAP32[$10>>2] = $31;
      $32 = (($10) + 4|0);
      HEAP32[$32>>2] = $22;
      $__p$0$i$i$i$i$i = $29;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($33|0),($22|0))|0;
     $34 = (($__p$0$i$i$i$i$i) + ($22)|0);
     HEAP8[$34>>0] = 0;
     $$pre = HEAP32[$1>>2]|0;
     $37 = $$pre;
    }
    $35 = (($__i$01) + 12|0);
    $36 = (($37) + 12|0);
    HEAP32[$1>>2] = $36;
    $38 = ($35>>>0)<($__from_e>>>0);
    if ($38) {
     $10 = $36;$__i$01 = $35;
    } else {
     break L1;
    }
   }
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
 } while(0);
 $39 = ($2|0)==($__to|0);
 if ($39) {
  STACKTOP = sp;return;
 } else {
  $$012$i$i = $7;$$03$i$i = $2;
 }
 while(1) {
  $40 = (($$03$i$i) + -12|0);
  $41 = (($$012$i$i) + -12|0);
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($40,$41)|0);
  $42 = ($41|0)==($__from_s|0);
  if ($42) {
   break;
  } else {
   $$012$i$i = $41;$$03$i$i = $40;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS4_EEPS1_($this,$__v,$__p) {
 $this = $this|0;
 $__v = $__v|0;
 $__p = $__p|0;
 var $$01$i = 0, $$01$i3 = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i$i = 0, $__p$0$i$i$i$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($__v) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==($__p|0);
 L1: do {
  if ($4) {
   $78 = $2;
  } else {
   $$01$i3 = $__p;$6 = $2;
   while(1) {
    $5 = (($6) + -12|0);
    $7 = (($$01$i3) + -12|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 1;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $15 = (($7) + 1|0);
     $16 = $8&255;
     $17 = $16 >>> 1;
     $19 = $17;$30 = $15;
    } else {
     $11 = (($$01$i3) + -4|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($$01$i3) + -8|0);
     $14 = HEAP32[$13>>2]|0;
     $19 = $14;$30 = $12;
    }
    $18 = ($19>>>0)>(2147483631);
    if ($18) {
     break;
    }
    $20 = ($19>>>0)<(11);
    if ($20) {
     $21 = $19 << 1;
     $22 = $21&255;
     HEAP8[$5>>0] = $22;
     $23 = (($5) + 1|0);
     $__p$0$i$i$i$i$i$i7 = $23;
    } else {
     $24 = (($19) + 16)|0;
     $25 = $24 & -16;
     HEAP32[$0>>2] = 59;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy1,0,803720,79)|0);
     $27 = (($6) + -4|0);
     HEAP32[$27>>2] = $26;
     $28 = $25 | 1;
     HEAP32[$5>>2] = $28;
     $29 = (($6) + -8|0);
     HEAP32[$29>>2] = $19;
     $__p$0$i$i$i$i$i$i7 = $26;
    }
    _memcpy(($__p$0$i$i$i$i$i$i7|0),($30|0),($19|0))|0;
    $31 = (($__p$0$i$i$i$i$i$i7) + ($19)|0);
    HEAP8[$31>>0] = 0;
    $32 = HEAP32[$1>>2]|0;
    $33 = (($32) + -12|0);
    HEAP32[$1>>2] = $33;
    $34 = ($7|0)==($3|0);
    if ($34) {
     $78 = $33;
     break L1;
    } else {
     $$01$i3 = $7;$6 = $33;
    }
   }
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
 } while(0);
 $35 = (($this) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($__v) + 8|0);
 $38 = ($36|0)==($__p|0);
 if ($38) {
  $70 = $78;
  $69 = HEAP32[$this>>2]|0;
  HEAP32[$this>>2] = $70;
  HEAP32[$1>>2] = $69;
  $71 = HEAP32[$35>>2]|0;
  $72 = HEAP32[$37>>2]|0;
  HEAP32[$35>>2] = $72;
  HEAP32[$37>>2] = $71;
  $73 = (($this) + 8|0);
  $74 = (($__v) + 12|0);
  $75 = HEAP32[$73>>2]|0;
  $76 = HEAP32[$74>>2]|0;
  HEAP32[$73>>2] = $76;
  HEAP32[$74>>2] = $75;
  $77 = HEAP32[$1>>2]|0;
  HEAP32[$__v>>2] = $77;
  STACKTOP = sp;return ($2|0);
 }
 $$pre$i = HEAP32[$37>>2]|0;
 $$01$i = $__p;$40 = $$pre$i;
 while(1) {
  $39 = ($40|0)==(0|0);
  if ($39) {
   $67 = 0;
  } else {
   $41 = HEAP8[$$01$i>>0]|0;
   $42 = $41 & 1;
   $43 = ($42<<24>>24)==(0);
   if ($43) {
    $48 = (($$01$i) + 1|0);
    $49 = $41&255;
    $50 = $49 >>> 1;
    $52 = $50;$63 = $48;
   } else {
    $44 = (($$01$i) + 8|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($$01$i) + 4|0);
    $47 = HEAP32[$46>>2]|0;
    $52 = $47;$63 = $45;
   }
   $51 = ($52>>>0)>(2147483631);
   if ($51) {
    label = 19;
    break;
   }
   $53 = ($52>>>0)<(11);
   if ($53) {
    $54 = $52 << 1;
    $55 = $54&255;
    HEAP8[$40>>0] = $55;
    $56 = (($40) + 1|0);
    $__p$0$i$i$i$i$i$i = $56;
   } else {
    $57 = (($52) + 16)|0;
    $58 = $57 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $59 = (__Z15malloc_internaljj10MemLabelIdiPKci($58,16,$$byval_copy1,0,803720,79)|0);
    $60 = (($40) + 8|0);
    HEAP32[$60>>2] = $59;
    $61 = $58 | 1;
    HEAP32[$40>>2] = $61;
    $62 = (($40) + 4|0);
    HEAP32[$62>>2] = $52;
    $__p$0$i$i$i$i$i$i = $59;
   }
   _memcpy(($__p$0$i$i$i$i$i$i|0),($63|0),($52|0))|0;
   $64 = (($__p$0$i$i$i$i$i$i) + ($52)|0);
   HEAP8[$64>>0] = 0;
   $$pre2$i = HEAP32[$37>>2]|0;
   $67 = $$pre2$i;
  }
  $65 = (($$01$i) + 12|0);
  $66 = (($67) + 12|0);
  HEAP32[$37>>2] = $66;
  $68 = ($65|0)==($36|0);
  if ($68) {
   break;
  } else {
   $$01$i = $65;$40 = $66;
  }
 }
 if ((label|0) == 19) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $$pre = HEAP32[$1>>2]|0;
 $70 = $$pre;
 $69 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $70;
 HEAP32[$1>>2] = $69;
 $71 = HEAP32[$35>>2]|0;
 $72 = HEAP32[$37>>2]|0;
 HEAP32[$35>>2] = $72;
 HEAP32[$37>>2] = $71;
 $73 = (($this) + 8|0);
 $74 = (($__v) + 12|0);
 $75 = HEAP32[$73>>2]|0;
 $76 = HEAP32[$74>>2]|0;
 HEAP32[$73>>2] = $76;
 HEAP32[$74>>2] = $75;
 $77 = HEAP32[$1>>2]|0;
 HEAP32[$__v>>2] = $77;
 STACKTOP = sp;return ($2|0);
}
function __ZNSt3__114__split_bufferI8UnityStrR13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE18__construct_at_endINS_13move_iteratorIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$byval_copy = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 8|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 while(1) {
  $5 = ($6|0)==(0|0);
  if ($5) {
   $33 = 0;$35 = $8;
  } else {
   $7 = HEAP8[$8>>0]|0;
   $9 = $7 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $15 = (($8) + 1|0);
    $16 = $7&255;
    $17 = $16 >>> 1;
    $19 = $17;$30 = $15;
   } else {
    $11 = (($8) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($8) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $19 = $14;$30 = $12;
   }
   $18 = ($19>>>0)>(2147483631);
   if ($18) {
    label = 8;
    break;
   }
   $20 = ($19>>>0)<(11);
   if ($20) {
    $21 = $19 << 1;
    $22 = $21&255;
    HEAP8[$6>>0] = $22;
    $23 = (($6) + 1|0);
    $__p$0$i$i$i$i$i = $23;
   } else {
    $24 = (($19) + 16)|0;
    $25 = $24 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy,0,803720,79)|0);
    $27 = (($6) + 8|0);
    HEAP32[$27>>2] = $26;
    $28 = $25 | 1;
    HEAP32[$6>>2] = $28;
    $29 = (($6) + 4|0);
    HEAP32[$29>>2] = $19;
    $__p$0$i$i$i$i$i = $26;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($30|0),($19|0))|0;
   $31 = (($__p$0$i$i$i$i$i) + ($19)|0);
   HEAP8[$31>>0] = 0;
   $$pre1 = HEAP32[$4>>2]|0;
   $$pre2 = HEAP32[$__first>>2]|0;
   $33 = $$pre1;$35 = $$pre2;
  }
  $32 = (($33) + 12|0);
  HEAP32[$4>>2] = $32;
  $34 = (($35) + 12|0);
  HEAP32[$__first>>2] = $34;
  $36 = ($34|0)==($2|0);
  if ($36) {
   label = 14;
   break;
  } else {
   $6 = $32;$8 = $34;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNK20TextRenderingPrivate7FontRefltERKS0_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$$$i$i = 0, $$$$i$i$i = 0, $$$i$i = 0, $$$i$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $22 = $6;
 } else {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $22 = $4;
 }
 $7 = HEAP8[$other>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $12 = $7&255;
  $13 = $12 >>> 1;
  $21 = $13;
 } else {
  $10 = (($other) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $21 = $11;
 }
 if ($2) {
  $16 = (($this) + 1|0);
  $24 = $16;
 } else {
  $14 = (($this) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $24 = $15;
 }
 if ($9) {
  $19 = (($other) + 1|0);
  $25 = $19;
 } else {
  $17 = (($other) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $25 = $18;
 }
 $20 = ($21>>>0)<($22>>>0);
 $23 = $20 ? $21 : $22;
 $26 = (_memcmp($24,$25,$23)|0);
 $27 = ($26|0)==(0);
 if ($27) {
  $28 = ($22>>>0)<($21>>>0);
  $$$i$i = $20&1;
  $$$$i$i = $28 ? -1 : $$$i$i;
  $30 = $$$$i$i;
 } else {
  $30 = $26;
 }
 $29 = ($30|0)<(0);
 if ($29) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($9) {
  $33 = $7&255;
  $34 = $33 >>> 1;
  $47 = $34;
 } else {
  $31 = (($other) + 4|0);
  $32 = HEAP32[$31>>2]|0;
  $47 = $32;
 }
 if ($2) {
  $37 = $0&255;
  $38 = $37 >>> 1;
  $46 = $38;
 } else {
  $35 = (($this) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $46 = $36;
 }
 if ($9) {
  $41 = (($other) + 1|0);
  $49 = $41;
 } else {
  $39 = (($other) + 8|0);
  $40 = HEAP32[$39>>2]|0;
  $49 = $40;
 }
 if ($2) {
  $44 = (($this) + 1|0);
  $50 = $44;
 } else {
  $42 = (($this) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $50 = $43;
 }
 $45 = ($46>>>0)<($47>>>0);
 $48 = $45 ? $46 : $47;
 $51 = (_memcmp($49,$50,$48)|0);
 $52 = ($51|0)==(0);
 if ($52) {
  $53 = ($47>>>0)<($46>>>0);
  $$$i$i$i = $45&1;
  $$$$i$i$i = $53 ? -1 : $$$i$i$i;
  $55 = $$$$i$i$i;
 } else {
  $55 = $51;
 }
 $54 = ($55|0)<(0);
 if ($54) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $56 = (($this) + 12|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($other) + 12|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($57>>>0)<($59>>>0);
 $$0 = $60;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefENS2_6OSFontEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefENS2_6OSFontEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefENS2_6OSFontEEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE7destroyEPNS_11__tree_nodeIS5_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = (($__nd) + 32|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 40|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 $11 = HEAP8[$4>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if (!($13)) {
  $14 = (($__nd) + 24|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefEP11FT_FaceRec_EENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefEP11FT_FaceRec_EENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN20TextRenderingPrivate7FontRefEP11FT_FaceRec_EENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = (($__nd) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  __ZdlPv($9);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4FontC2E10MemLabelId18ObjectCreationMode($this,$label,$mode) {
 $this = $this|0;
 $label = $label|0;
 $mode = $mode|0;
 var $$0 = 0, $$01 = 0, $$byval_copy9 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i12 = 0, $__new_last2$i$i$i$i$i19 = 0, $__new_last2$i$i$i$i$i37 = 0, $__new_last2$i$i$i$i$i44 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i13 = 0, $scevgep$i$i$i$i$i20 = 0, $scevgep$i$i$i$i$i38 = 0, $scevgep$i$i$i$i$i45 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i17 = 0, $scevgep4$i$i$i$i$i24 = 0, $scevgep4$i$i$i$i$i42 = 0;
 var $scevgep4$i$i$i$i$i49 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i15 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep$i$i$i$i$i40 = 0, $uglygep$i$i$i$i$i47 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i16 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep3$i$i$i$i$i41 = 0, $uglygep3$i$i$i$i$i48 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy9 = sp + 48|0;
 $0 = sp + 44|0;
 $1 = sp + 40|0;
 $2 = sp + 32|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = sp + 12|0;
 $7 = sp + 8|0;
 $8 = sp;
 $9 = sp + 20|0;
 $10 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $10;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode($this,$$byval_copy9,$mode);
 $11 = (($this) + 36|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 40|0);
 HEAP32[$12>>2] = 0;
 HEAP32[$this>>2] = ((803992 + 8|0));
 $13 = (($this) + 48|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 52|0);
 HEAP32[$14>>2] = 0;
 $15 = (($this) + 56|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 84|0);
 $17 = (($this) + 88|0);
 $18 = (($this) + 96|0);
 $19 = (($this) + 100|0);
 $20 = (($this) + 108|0);
 $21 = (($this) + 112|0);
 $22 = (($this) + 120|0);
 $23 = (($this) + 124|0);
 $24 = (($this) + 132|0);
 $25 = (($this) + 136|0);
 $26 = (($this) + 144|0);
 $27 = (($this) + 148|0);
 $28 = (($this) + 156|0);
 $29 = (($this) + 160|0);
 $30 = (($this) + 168|0);
 $31 = (($this) + 172|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 176|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 172|0);
 dest=$16+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$30>>2] = $33;
 $34 = (($this) + 184|0);
 HEAP32[$34>>2] = 256;
 $35 = (($this) + 188|0);
 HEAP32[$35>>2] = 256;
 $36 = (($this) + 196|0);
 HEAP32[$36>>2] = 1;
 $37 = (($this) + 64|0);
 HEAP32[$37>>2] = 1;
 $38 = (($this) + 68|0);
 HEAP32[$38>>2] = 0;
 $39 = (($this) + 32|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 208|0);
 HEAPF32[$40>>2] = Math_fround(0.0);
 $41 = (($this) + 204|0);
 HEAP32[$41>>2] = 0;
 $42 = (($this) + 212|0);
 HEAP32[$42>>2] = 0;
 $43 = (($this) + 80|0);
 HEAPF32[$43>>2] = Math_fround(0.100000001490116119385);
 __THREW__ = 0;
 invoke_vii(3432,($20|0),256);
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  label = 6;
 } else {
  HEAP32[$8>>2] = 0;
  $46 = (($8) + 4|0);
  HEAP32[$46>>2] = 0;
  __THREW__ = 0;
  invoke_viii(2044,($2|0),($30|0),($8|0));
  $47 = __THREW__; __THREW__ = 0;
  $48 = $47&1;
  if ($48) {
   label = 6;
  } else {
   $49 = HEAP32[$30>>2]|0;
   $50 = (($this) + 180|0);
   HEAP32[$50>>2] = $49;
   $51 = HEAP32[628344>>2]|0;
   HEAP32[$9>>2] = $51;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$9+0>>2]|0;
   $52 = (invoke_iiiiiii(103,12,($$byval_copy9|0),0,16,(804096|0),57)|0);
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if ($54) {
    label = 6;
   } else {
    __THREW__ = 0;
    invoke_vi(3723,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     $57 = (($this) + 216|0);
     HEAP32[$57>>2] = $52;
     STACKTOP = sp;return;
    }
    $60 = ___cxa_find_matching_catch()|0;
    $61 = tempRet0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$9+0>>2]|0;
    invoke_viiiiii(97,($52|0),($$byval_copy9|0),0,16,(804096|0),57);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     $155 = ___cxa_find_matching_catch(0|0)|0;
     $156 = tempRet0;
     ___clang_call_terminate($155);
     // unreachable;
    } else {
     $$0 = $61;$$01 = $60;$$pre$phiZ2D = $30;
    }
   }
  }
 }
 if ((label|0) == 6) {
  $58 = ___cxa_find_matching_catch()|0;
  $59 = tempRet0;
  $$0 = $59;$$01 = $58;$$pre$phiZ2D = $30;
 }
 $64 = HEAP32[$31>>2]|0;
 __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($$pre$phiZ2D,$64);
 $65 = HEAP32[$28>>2]|0;
 $66 = ($65|0)==(0|0);
 if (!($66)) {
  $67 = HEAP32[$29>>2]|0;
  $68 = ($67|0)==($65|0);
  if (!($68)) {
   $__new_last2$i$i$i$i$i44 = $65;
   $scevgep$i$i$i$i$i45 = (($67) + -16|0);
   $69 = (0 - ($__new_last2$i$i$i$i$i44))|0;
   $uglygep$i$i$i$i$i47 = (($scevgep$i$i$i$i$i45) + ($69)|0);
   $uglygep3$i$i$i$i$i48 = $uglygep$i$i$i$i$i47;
   $70 = $uglygep3$i$i$i$i$i48 >>> 4;
   $71 = $70 ^ -1;
   $scevgep4$i$i$i$i$i49 = (($67) + ($71<<4)|0);
   HEAP32[$29>>2] = $scevgep4$i$i$i$i$i49;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($65|0),($$byval_copy9|0));
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   $74 = ___cxa_find_matching_catch()|0;
   $75 = tempRet0;
   ___cxa_call_unexpected(($74|0));
   // unreachable;
  }
 }
 $76 = HEAP32[$26>>2]|0;
 $77 = ($76|0)==(0|0);
 if (!($77)) {
  $78 = HEAP32[$27>>2]|0;
  $79 = ($78|0)==($76|0);
  if (!($79)) {
   $__new_last2$i$i$i$i$i37 = $76;
   $scevgep$i$i$i$i$i38 = (($78) + -4|0);
   $80 = (0 - ($__new_last2$i$i$i$i$i37))|0;
   $uglygep$i$i$i$i$i40 = (($scevgep$i$i$i$i$i38) + ($80)|0);
   $uglygep3$i$i$i$i$i41 = $uglygep$i$i$i$i$i40;
   $81 = $uglygep3$i$i$i$i$i41 >>> 2;
   $82 = $81 ^ -1;
   $scevgep4$i$i$i$i$i42 = (($78) + ($82<<2)|0);
   HEAP32[$27>>2] = $scevgep4$i$i$i$i$i42;
  }
  HEAP32[$1>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($76|0),($$byval_copy9|0));
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if ($84) {
   $85 = ___cxa_find_matching_catch()|0;
   $86 = tempRet0;
   ___cxa_call_unexpected(($85|0));
   // unreachable;
  }
 }
 $87 = HEAP32[$24>>2]|0;
 $88 = ($87|0)==(0|0);
 if (!($88)) {
  $89 = HEAP32[$25>>2]|0;
  $90 = ($89|0)==($87|0);
  do {
   if ($90) {
    $104 = $87;
   } else {
    $92 = $89;
    while(1) {
     $91 = (($92) + -12|0);
     HEAP32[$25>>2] = $91;
     $93 = HEAP8[$91>>0]|0;
     $94 = $93 & 1;
     $95 = ($94<<24>>24)==(0);
     if ($95) {
      $97 = $91;
     } else {
      $98 = (($92) + -4|0);
      $99 = HEAP32[$98>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($99|0),($$byval_copy9|0));
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       label = 25;
       break;
      }
      $$pre$i$i$i$i$i = HEAP32[$25>>2]|0;
      $97 = $$pre$i$i$i$i$i;
     }
     $96 = ($97|0)==($87|0);
     if ($96) {
      label = 26;
      break;
     } else {
      $92 = $97;
     }
    }
    if ((label|0) == 25) {
     $102 = ___cxa_find_matching_catch()|0;
     $103 = tempRet0;
     ___cxa_call_unexpected(($102|0));
     // unreachable;
    }
    else if ((label|0) == 26) {
     $$pre$i$i$i = HEAP32[$24>>2]|0;
     $104 = $$pre$i$i$i;
     break;
    }
   }
  } while(0);
  HEAP32[$4>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($104|0),($$byval_copy9|0));
  $105 = __THREW__; __THREW__ = 0;
  $106 = $105&1;
  if ($106) {
   $107 = ___cxa_find_matching_catch()|0;
   $108 = tempRet0;
   ___cxa_call_unexpected(($107|0));
   // unreachable;
  }
 }
 $109 = HEAP32[$22>>2]|0;
 $110 = ($109|0)==(0|0);
 if (!($110)) {
  $111 = HEAP32[$23>>2]|0;
  $112 = ($111|0)==($109|0);
  if (!($112)) {
   HEAP32[$23>>2] = $109;
  }
  HEAP32[$5>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,($109|0),($$byval_copy9|0));
  $113 = __THREW__; __THREW__ = 0;
  $114 = $113&1;
  if ($114) {
   $115 = ___cxa_find_matching_catch()|0;
   $116 = tempRet0;
   ___cxa_call_unexpected(($115|0));
   // unreachable;
  }
 }
 $117 = HEAP32[$20>>2]|0;
 $118 = ($117|0)==(0|0);
 if (!($118)) {
  $119 = HEAP32[$21>>2]|0;
  $120 = ($119|0)==($117|0);
  if (!($120)) {
   $__new_last2$i$i$i$i$i19 = $117;
   $scevgep$i$i$i$i$i20 = (($119) + -56|0);
   $121 = (0 - ($__new_last2$i$i$i$i$i19))|0;
   $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($121)|0);
   $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
   $122 = (($uglygep3$i$i$i$i$i23>>>0) / 56)&-1;
   $123 = $122 ^ -1;
   $scevgep4$i$i$i$i$i24 = (($119) + (($123*56)|0)|0);
   HEAP32[$21>>2] = $scevgep4$i$i$i$i$i24;
  }
  HEAP32[$6>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$6+0>>2]|0;
  invoke_vii(2591,($117|0),($$byval_copy9|0));
  $124 = __THREW__; __THREW__ = 0;
  $125 = $124&1;
  if ($125) {
   $126 = ___cxa_find_matching_catch()|0;
   $127 = tempRet0;
   ___cxa_call_unexpected(($126|0));
   // unreachable;
  }
 }
 $128 = HEAP32[$18>>2]|0;
 $129 = ($128|0)==(0|0);
 if (!($129)) {
  $130 = HEAP32[$19>>2]|0;
  $131 = ($130|0)==($128|0);
  if (!($131)) {
   $__new_last2$i$i$i$i$i$i$i$i$i12 = $128;
   $scevgep$i$i$i$i$i$i$i$i$i13 = (($130) + -56|0);
   $132 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i12))|0;
   $uglygep$i$i$i$i$i$i$i$i$i15 = (($scevgep$i$i$i$i$i$i$i$i$i13) + ($132)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i16 = $uglygep$i$i$i$i$i$i$i$i$i15;
   $133 = (($uglygep3$i$i$i$i$i$i$i$i$i16>>>0) / 56)&-1;
   $134 = $133 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i17 = (($130) + (($134*56)|0)|0);
   HEAP32[$19>>2] = $scevgep4$i$i$i$i$i$i$i$i$i17;
  }
  __ZdlPv($128);
 }
 $135 = HEAP32[$16>>2]|0;
 $136 = ($135|0)==(0|0);
 if (!($136)) {
  $137 = HEAP32[$17>>2]|0;
  $138 = ($137|0)==($135|0);
  if (!($138)) {
   $__new_last2$i$i$i$i$i = $135;
   $scevgep$i$i$i$i$i = (($137) + -56|0);
   $139 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($139)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $140 = (($uglygep3$i$i$i$i$i>>>0) / 56)&-1;
   $141 = $140 ^ -1;
   $scevgep4$i$i$i$i$i = (($137) + (($141*56)|0)|0);
   HEAP32[$17>>2] = $scevgep4$i$i$i$i$i;
  }
  HEAP32[$7>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$7+0>>2]|0;
  invoke_vii(2591,($135|0),($$byval_copy9|0));
  $142 = __THREW__; __THREW__ = 0;
  $143 = $142&1;
  if ($143) {
   $144 = ___cxa_find_matching_catch()|0;
   $145 = tempRet0;
   ___cxa_call_unexpected(($144|0));
   // unreachable;
  }
 }
 $146 = HEAP32[$13>>2]|0;
 $147 = ($146|0)==(0|0);
 if (!($147)) {
  $148 = HEAP32[$14>>2]|0;
  $149 = ($148|0)==($146|0);
  if (!($149)) {
   $__new_last2$i$i$i$i$i$i$i$i$i = $146;
   $scevgep$i$i$i$i$i$i$i$i$i = (($148) + -8|0);
   $150 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($150)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
   $151 = $uglygep3$i$i$i$i$i$i$i$i$i >>> 3;
   $152 = $151 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i = (($148) + ($152<<3)|0);
   HEAP32[$14>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
  }
  __ZdlPv($146);
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $153 = __THREW__; __THREW__ = 0;
 $154 = $153&1;
 if ($154) {
  $155 = ___cxa_find_matching_catch(0|0)|0;
  $156 = tempRet0;
  ___clang_call_terminate($155);
  // unreachable;
 } else {
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZN20TextRenderingPrivate4Font5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 HEAPF32[$0>>2] = Math_fround(1.0);
 $1 = (($this) + 28|0);
 HEAPF32[$1>>2] = Math_fround(0.100000001490116119385);
 $2 = (($this) + 72|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 76|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK20TextRenderingPrivate4Font22GetCharacterRenderInfoEjijR5RectTIfES3_Rb($this,$charCode,$size,$style,$verts,$uvs,$flipped) {
 $this = $this|0;
 $charCode = $charCode|0;
 $size = $size|0;
 $style = $style|0;
 $verts = $verts|0;
 $uvs = $uvs|0;
 $flipped = $flipped|0;
 var $$0$i = 0, $$0$i11 = 0, $$0$i12 = 0, $$0$i2$i = 0, $$01 = 0, $$1 = 0, $$charCode$i = 0, $$neg3$i$i$i$i$i = 0, $$old = 0, $$old$old = 0, $$size = 0, $$size10 = 0, $$size13 = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$04$i$i$i$i$i = 0, $or$cond = 0;
 var $or$cond14 = 0, $or$cond2 = 0, $or$cond3 = 0, $sext$i = 0, $sext3$i = 0, $storemerge9 = 0, $v$off$i$i = 0, $v$off$i1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 2)) {
  $12 = $charCode&255;
  $v$off$i1$i = (($12) + -65)<<24>>24;
  $13 = ($v$off$i1$i&255)<(26);
  if ($13) {
   $14 = $charCode & 223;
   $15 = $14 | 32;
   $$0$i2$i = $15;
  } else {
   $$0$i2$i = $charCode;
  }
  $sext$i = $$0$i2$i << 24;
  $16 = $sext$i >> 24;
  $17 = (($this) + 72|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) - ($18))|0;
  $$0$i = $19;
  label = 7;
 } else if ((($1|0) == 1)) {
  $2 = $charCode&255;
  $v$off$i$i = (($2) + -97)<<24>>24;
  $3 = ($v$off$i$i&255)<(26);
  $4 = $charCode & 223;
  $$charCode$i = $3 ? $4 : $charCode;
  $sext3$i = $$charCode$i << 24;
  $5 = $sext3$i >> 24;
  $6 = (($this) + 72|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) - ($7))|0;
  $9 = (($this) + 32|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($size|0);
  $$size10 = $11 ? 0 : $size;
  $$0$i11 = $8;$$size13 = $$size10;
  label = 8;
 } else {
  $20 = (($this) + 72|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($charCode) - ($21))|0;
  $$0$i = $22;
  label = 7;
 }
 if ((label|0) == 7) {
  $23 = (($this) + 32|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==($size|0);
  $$size = $25 ? 0 : $size;
  $26 = ($1|0)==(-2);
  if ($26) {
   $$0$i12 = $$0$i;$$01 = $style;$$1 = $$size;
  } else {
   $$0$i11 = $$0$i;$$size13 = $$size;
   label = 8;
  }
 }
 if ((label|0) == 8) {
  $27 = $$size13 | $style;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i12 = $$0$i11;$$01 = $style;$$1 = $$size13;
  } else {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(804104,0,804096,98,1,0,0,0);
   $$0$i12 = $$0$i11;$$01 = 0;$$1 = 0;
  }
 }
 $29 = ($$0$i12>>>0)<(256);
 $30 = ($$1|0)==(0);
 $or$cond2 = $29 & $30;
 $31 = ($$01|0)==(0);
 $or$cond3 = $or$cond2 & $31;
 if ($or$cond3) {
  $32 = (($this) + 108|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($33) + (($$0$i12*56)|0)|0) + 20|0);
  ;HEAP32[$verts+0>>2]=HEAP32[$34+0>>2]|0;HEAP32[$verts+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$verts+8>>2]=HEAP32[$34+8>>2]|0;HEAP32[$verts+12>>2]=HEAP32[$34+12>>2]|0;
  $35 = HEAP32[$32>>2]|0;
  $36 = ((($35) + (($$0$i12*56)|0)|0) + 4|0);
  ;HEAP32[$uvs+0>>2]=HEAP32[$36+0>>2]|0;HEAP32[$uvs+4>>2]=HEAP32[$36+4>>2]|0;HEAP32[$uvs+8>>2]=HEAP32[$36+8>>2]|0;HEAP32[$uvs+12>>2]=HEAP32[$36+12>>2]|0;
  $37 = HEAP32[$32>>2]|0;
  $38 = ((($37) + (($$0$i12*56)|0)|0) + 52|0);
  $39 = HEAP8[$38>>0]|0;
  $storemerge9 = $39;
  HEAP8[$flipped>>0] = $storemerge9;
  STACKTOP = sp;return;
 }
 $40 = (($this) + 96|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($this) + 100|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==($41|0);
 if ($44) {
  $66 = $41;
 } else {
  $45 = $41;
  $46 = $43;
  $47 = (($46) - ($45))|0;
  $48 = (($47|0) / 56)&-1;
  $51 = $41;$__len$04$i$i$i$i$i = $48;
  while(1) {
   $49 = (($__len$04$i$i$i$i$i|0) / 2)&-1;
   $50 = (($51) + (($49*56)|0)|0);
   $52 = HEAP32[$50>>2]|0;
   $53 = ($52|0)==($$0$i12|0);
   if ($53) {
    $54 = ((($51) + (($49*56)|0)|0) + 40|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)<($$1|0);
    if ($56) {
     label = 19;
    } else {
     $57 = ($55|0)>($$1|0);
     if ($57) {
      $82 = $51;$__len$0$be$i$i$i$i$i = $49;
     } else {
      $58 = ((($51) + (($49*56)|0)|0) + 44|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ($59>>>0)<($$01>>>0);
      if ($60) {
       label = 19;
      } else {
       $82 = $51;$__len$0$be$i$i$i$i$i = $49;
      }
     }
    }
   } else {
    $61 = ($52>>>0)<($$0$i12>>>0);
    if ($61) {
     label = 19;
    } else {
     $82 = $51;$__len$0$be$i$i$i$i$i = $49;
    }
   }
   if ((label|0) == 19) {
    label = 0;
    $$sum$i$i$i$i$i = (($49) + 1)|0;
    $62 = (($51) + (($$sum$i$i$i$i$i*56)|0)|0);
    $$neg3$i$i$i$i$i = (($__len$04$i$i$i$i$i) + -1)|0;
    $63 = (($$neg3$i$i$i$i$i) - ($49))|0;
    $82 = $62;$__len$0$be$i$i$i$i$i = $63;
   }
   $64 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($64) {
    $66 = $82;
    break;
   } else {
    $51 = $82;$__len$04$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $65 = ($66|0)==($43|0);
 L31: do {
  if (!($65)) {
   $67 = HEAP32[$66>>2]|0;
   $68 = ($$0$i12|0)==($67|0);
   do {
    if ($68) {
     $69 = (($66) + 40|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($$1|0)<($70|0);
     if ($71) {
      break L31;
     }
     $72 = ($$1|0)>($70|0);
     if ($72) {
      $$old$old = ($66|0)==($43|0);
      if ($$old$old) {
       break L31;
      } else {
       break;
      }
     } else {
      $73 = (($66) + 44|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($$01>>>0)<($74>>>0);
      $76 = ($66|0)==($43|0);
      $or$cond = $75 | $76;
      if ($or$cond) {
       break L31;
      } else {
       break;
      }
     }
    } else {
     $77 = ($$0$i12>>>0)<($67>>>0);
     $$old = ($66|0)==($43|0);
     $or$cond14 = $77 | $$old;
     if ($or$cond14) {
      break L31;
     }
    }
   } while(0);
   $78 = (($66) + 20|0);
   ;HEAP32[$verts+0>>2]=HEAP32[$78+0>>2]|0;HEAP32[$verts+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$verts+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$verts+12>>2]=HEAP32[$78+12>>2]|0;
   $79 = (($66) + 4|0);
   ;HEAP32[$uvs+0>>2]=HEAP32[$79+0>>2]|0;HEAP32[$uvs+4>>2]=HEAP32[$79+4>>2]|0;HEAP32[$uvs+8>>2]=HEAP32[$79+8>>2]|0;HEAP32[$uvs+12>>2]=HEAP32[$79+12>>2]|0;
   $80 = (($66) + 52|0);
   $81 = HEAP8[$80>>0]|0;
   $storemerge9 = $81;
   HEAP8[$flipped>>0] = $storemerge9;
   STACKTOP = sp;return;
  }
 } while(0);
 ;HEAP32[$verts+0>>2]=0|0;HEAP32[$verts+4>>2]=0|0;HEAP32[$verts+8>>2]=0|0;HEAP32[$verts+12>>2]=0|0;
 ;HEAP32[$uvs+0>>2]=0|0;HEAP32[$uvs+4>>2]=0|0;HEAP32[$uvs+8>>2]=0|0;HEAP32[$uvs+12>>2]=0|0;
 $storemerge9 = 0;
 HEAP8[$flipped>>0] = $storemerge9;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font21HasCharacterInTextureEjij($this,$unicodeChar,$size,$style) {
 $this = $this|0;
 $unicodeChar = $unicodeChar|0;
 $size = $size|0;
 $style = $style|0;
 var $$0$i = 0, $$0$i2$i = 0, $$0$i7 = 0, $$0$i8 = 0, $$01 = 0, $$1 = 0, $$13 = 0, $$charCode$i = 0, $$neg3$i$i$i$i$i = 0, $$old = 0, $$old$old = 0, $$size = 0, $$size6 = 0, $$size9 = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0;
 var $__len$0$be$i$i$i$i$i = 0, $__len$04$i$i$i$i$i = 0, $or$cond = 0, $or$cond10 = 0, $or$cond4 = 0, $or$cond5 = 0, $sext$i = 0, $sext3$i = 0, $v$off$i$i = 0, $v$off$i1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 1)) {
  $2 = $unicodeChar&255;
  $v$off$i$i = (($2) + -97)<<24>>24;
  $3 = ($v$off$i$i&255)<(26);
  $4 = $unicodeChar & 223;
  $$charCode$i = $3 ? $4 : $unicodeChar;
  $sext3$i = $$charCode$i << 24;
  $5 = $sext3$i >> 24;
  $6 = (($this) + 72|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) - ($7))|0;
  $9 = (($this) + 32|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($size|0);
  $$size6 = $11 ? 0 : $size;
  $$0$i7 = $8;$$size9 = $$size6;
  label = 8;
 } else if ((($1|0) == 2)) {
  $12 = $unicodeChar&255;
  $v$off$i1$i = (($12) + -65)<<24>>24;
  $13 = ($v$off$i1$i&255)<(26);
  if ($13) {
   $14 = $unicodeChar & 223;
   $15 = $14 | 32;
   $$0$i2$i = $15;
  } else {
   $$0$i2$i = $unicodeChar;
  }
  $sext$i = $$0$i2$i << 24;
  $16 = $sext$i >> 24;
  $17 = (($this) + 72|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) - ($18))|0;
  $$0$i = $19;
  label = 7;
 } else {
  $20 = (($this) + 72|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($unicodeChar) - ($21))|0;
  $$0$i = $22;
  label = 7;
 }
 if ((label|0) == 7) {
  $23 = (($this) + 32|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==($size|0);
  $$size = $25 ? 0 : $size;
  $26 = ($1|0)==(-2);
  if ($26) {
   $$0$i8 = $$0$i;$$01 = $style;$$13 = $$size;
  } else {
   $$0$i7 = $$0$i;$$size9 = $$size;
   label = 8;
  }
 }
 if ((label|0) == 8) {
  $27 = $$size9 | $style;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i8 = $$0$i7;$$01 = $style;$$13 = $$size9;
  } else {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(804104,0,804096,140,1,0,0,0);
   $$0$i8 = $$0$i7;$$01 = 0;$$13 = 0;
  }
 }
 $29 = ($$0$i8>>>0)<(256);
 $30 = ($$13|0)==(0);
 $or$cond4 = $29 & $30;
 $31 = ($$01|0)==(0);
 $or$cond5 = $or$cond4 & $31;
 if ($or$cond5) {
  $32 = (($this) + 108|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($33) + (($$0$i8*56)|0)|0) + 36|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = $35 != Math_fround(0.0);
  if ($36) {
   $37 = (__Z14GetTimeManagerv()|0);
   $38 = (($37) + 128|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$32>>2]|0;
   $41 = ((($40) + (($$0$i8*56)|0)|0) + 48|0);
   HEAP32[$41>>2] = $39;
   $$1 = 1;
   STACKTOP = sp;return ($$1|0);
  }
 }
 $42 = (($this) + 96|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($this) + 100|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==($43|0);
 if ($46) {
  $68 = $43;
 } else {
  $47 = $43;
  $48 = $45;
  $49 = (($48) - ($47))|0;
  $50 = (($49|0) / 56)&-1;
  $53 = $43;$__len$04$i$i$i$i$i = $50;
  while(1) {
   $51 = (($__len$04$i$i$i$i$i|0) / 2)&-1;
   $52 = (($53) + (($51*56)|0)|0);
   $54 = HEAP32[$52>>2]|0;
   $55 = ($54|0)==($$0$i8|0);
   if ($55) {
    $56 = ((($53) + (($51*56)|0)|0) + 40|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ($57|0)<($$13|0);
    if ($58) {
     label = 20;
    } else {
     $59 = ($57|0)>($$13|0);
     if ($59) {
      $84 = $53;$__len$0$be$i$i$i$i$i = $51;
     } else {
      $60 = ((($53) + (($51*56)|0)|0) + 44|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61>>>0)<($$01>>>0);
      if ($62) {
       label = 20;
      } else {
       $84 = $53;$__len$0$be$i$i$i$i$i = $51;
      }
     }
    }
   } else {
    $63 = ($54>>>0)<($$0$i8>>>0);
    if ($63) {
     label = 20;
    } else {
     $84 = $53;$__len$0$be$i$i$i$i$i = $51;
    }
   }
   if ((label|0) == 20) {
    label = 0;
    $$sum$i$i$i$i$i = (($51) + 1)|0;
    $64 = (($53) + (($$sum$i$i$i$i$i*56)|0)|0);
    $$neg3$i$i$i$i$i = (($__len$04$i$i$i$i$i) + -1)|0;
    $65 = (($$neg3$i$i$i$i$i) - ($51))|0;
    $84 = $64;$__len$0$be$i$i$i$i$i = $65;
   }
   $66 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($66) {
    $68 = $84;
    break;
   } else {
    $53 = $84;$__len$04$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $67 = ($68|0)==($45|0);
 if ($67) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $69 = HEAP32[$68>>2]|0;
 $70 = ($$0$i8|0)==($69|0);
 do {
  if ($70) {
   $71 = (($68) + 40|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($$13|0)<($72|0);
   if ($73) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
   $74 = ($$13|0)>($72|0);
   if ($74) {
    $$old$old = ($68|0)==($45|0);
    if ($$old$old) {
     $$1 = 0;
    } else {
     break;
    }
    STACKTOP = sp;return ($$1|0);
   } else {
    $75 = (($68) + 44|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($$01>>>0)<($76>>>0);
    $78 = ($68|0)==($45|0);
    $or$cond = $77 | $78;
    if ($or$cond) {
     $$1 = 0;
    } else {
     break;
    }
    STACKTOP = sp;return ($$1|0);
   }
  } else {
   $79 = ($$0$i8>>>0)<($69>>>0);
   $$old = ($68|0)==($45|0);
   $or$cond10 = $79 | $$old;
   if ($or$cond10) {
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 } while(0);
 $80 = (__Z14GetTimeManagerv()|0);
 $81 = (($80) + 128|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = (($68) + 48|0);
 HEAP32[$83>>2] = $82;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZNK20TextRenderingPrivate4Font17GetCharacterWidthEjij($this,$charCode,$size,$style) {
 $this = $this|0;
 $charCode = $charCode|0;
 $size = $size|0;
 $style = $style|0;
 var $$0$i = 0, $$0$i2$i = 0, $$01$ph = 0, $$018 = 0, $$019 = 0, $$1 = Math_fround(0), $$13$ph = 0, $$136 = 0, $$137 = 0, $$charCode$i = 0, $$neg3$i$i$i$i$i = 0, $$old = 0, $$old$old = 0, $$pr = 0, $$pr$pre = 0, $$size = 0, $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i$i$i = 0, $__len$04$i$i$i$i$i = 0, $or$cond = 0;
 var $or$cond11 = 0, $or$cond4 = 0, $or$cond5 = 0, $sext$i = 0, $sext3$i = 0, $v$off$i$i = 0, $v$off$i1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($size|0);
 $$size = $2 ? 0 : $size;
 $3 = (($this) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-2);
 do {
  if ($5) {
   $$019 = $style;$$137 = $$size;
   label = 9;
  } else {
   $6 = $$size | $style;
   $7 = ($6|0)==(0);
   if ($7) {
    $$01$ph = $style;$$13$ph = $$size;$$pr = $4;
   } else {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(804104,0,804096,183,1,0,0,0);
    $$pr$pre = HEAP32[$3>>2]|0;
    $$01$ph = 0;$$13$ph = 0;$$pr = $$pr$pre;
   }
   if ((($$pr|0) == 1)) {
    $8 = $charCode&255;
    $v$off$i$i = (($8) + -97)<<24>>24;
    $9 = ($v$off$i$i&255)<(26);
    $10 = $charCode & 223;
    $$charCode$i = $9 ? $10 : $charCode;
    $sext3$i = $$charCode$i << 24;
    $11 = $sext3$i >> 24;
    $12 = (($this) + 72|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) - ($13))|0;
    $$0$i = $14;$$018 = $$01$ph;$$136 = $$13$ph;
    break;
   } else if (!((($$pr|0) == 2))) {
    $$019 = $$01$ph;$$137 = $$13$ph;
    label = 9;
    break;
   }
   $15 = $charCode&255;
   $v$off$i1$i = (($15) + -65)<<24>>24;
   $16 = ($v$off$i1$i&255)<(26);
   if ($16) {
    $17 = $charCode & 223;
    $18 = $17 | 32;
    $$0$i2$i = $18;
   } else {
    $$0$i2$i = $charCode;
   }
   $sext$i = $$0$i2$i << 24;
   $19 = $sext$i >> 24;
   $20 = (($this) + 72|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) - ($21))|0;
   $$0$i = $22;$$018 = $$01$ph;$$136 = $$13$ph;
  }
 } while(0);
 if ((label|0) == 9) {
  $23 = (($this) + 72|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($charCode) - ($24))|0;
  $$0$i = $25;$$018 = $$019;$$136 = $$137;
 }
 $26 = ($$0$i>>>0)<(256);
 $27 = ($$136|0)==(0);
 $or$cond4 = $26 & $27;
 $28 = ($$018|0)==(0);
 $or$cond5 = $or$cond4 & $28;
 if ($or$cond5) {
  $29 = (($this) + 108|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ((($30) + (($$0$i*56)|0)|0) + 36|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($this) + 60|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = Math_fround($32 * $34);
  $$1 = $35;
  STACKTOP = sp;return (Math_fround($$1));
 }
 $36 = (($this) + 96|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + 100|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==($37|0);
 if ($40) {
  $62 = $37;
 } else {
  $41 = $37;
  $42 = $39;
  $43 = (($42) - ($41))|0;
  $44 = (($43|0) / 56)&-1;
  $47 = $37;$__len$04$i$i$i$i$i = $44;
  while(1) {
   $45 = (($__len$04$i$i$i$i$i|0) / 2)&-1;
   $46 = (($47) + (($45*56)|0)|0);
   $48 = HEAP32[$46>>2]|0;
   $49 = ($48|0)==($$0$i|0);
   if ($49) {
    $50 = ((($47) + (($45*56)|0)|0) + 40|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($51|0)<($$136|0);
    if ($52) {
     label = 19;
    } else {
     $53 = ($51|0)>($$136|0);
     if ($53) {
      $79 = $47;$__len$0$be$i$i$i$i$i = $45;
     } else {
      $54 = ((($47) + (($45*56)|0)|0) + 44|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ($55>>>0)<($$018>>>0);
      if ($56) {
       label = 19;
      } else {
       $79 = $47;$__len$0$be$i$i$i$i$i = $45;
      }
     }
    }
   } else {
    $57 = ($48>>>0)<($$0$i>>>0);
    if ($57) {
     label = 19;
    } else {
     $79 = $47;$__len$0$be$i$i$i$i$i = $45;
    }
   }
   if ((label|0) == 19) {
    label = 0;
    $$sum$i$i$i$i$i = (($45) + 1)|0;
    $58 = (($47) + (($$sum$i$i$i$i$i*56)|0)|0);
    $$neg3$i$i$i$i$i = (($__len$04$i$i$i$i$i) + -1)|0;
    $59 = (($$neg3$i$i$i$i$i) - ($45))|0;
    $79 = $58;$__len$0$be$i$i$i$i$i = $59;
   }
   $60 = ($__len$0$be$i$i$i$i$i|0)==(0);
   if ($60) {
    $62 = $79;
    break;
   } else {
    $47 = $79;$__len$04$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
   }
  }
 }
 $61 = ($62|0)==($39|0);
 if ($61) {
  $$1 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$1));
 }
 $63 = HEAP32[$62>>2]|0;
 $64 = ($$0$i|0)==($63|0);
 do {
  if ($64) {
   $65 = (($62) + 40|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($$136|0)<($66|0);
   if ($67) {
    $$1 = Math_fround(0.0);
    STACKTOP = sp;return (Math_fround($$1));
   }
   $68 = ($$136|0)>($66|0);
   if ($68) {
    $$old$old = ($62|0)==($39|0);
    if ($$old$old) {
     $$1 = Math_fround(0.0);
    } else {
     break;
    }
    STACKTOP = sp;return (Math_fround($$1));
   } else {
    $69 = (($62) + 44|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($$018>>>0)<($70>>>0);
    $72 = ($62|0)==($39|0);
    $or$cond = $71 | $72;
    if ($or$cond) {
     $$1 = Math_fround(0.0);
    } else {
     break;
    }
    STACKTOP = sp;return (Math_fround($$1));
   }
  } else {
   $73 = ($$0$i>>>0)<($63>>>0);
   $$old = ($62|0)==($39|0);
   $or$cond11 = $73 | $$old;
   if ($or$cond11) {
    $$1 = Math_fround(0.0);
    STACKTOP = sp;return (Math_fround($$1));
   }
  }
 } while(0);
 $74 = (($62) + 36|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = (($this) + 60|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($75 * $77);
 $$1 = $78;
 STACKTOP = sp;return (Math_fround($$1));
}
function __Z13ApplyToMeshesv() {
 var $$lcssa = 0, $$lcssa11 = 0, $$lcssa13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__new_last2$i$i$i$i$i1 = 0, $i$015 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $meshes = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $meshes = sp;
 __ZN20TextRenderingPrivate17TextMeshGenerator5FlushEv();
 HEAP32[$meshes>>2] = 0;
 $0 = (($meshes) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($meshes) + 8|0);
 HEAP32[$1>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1530,102,($meshes|0),0)|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if ($3) {
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   $lpad$phi$index = $23;$lpad$phi$index2 = $24;
  } else {
   $4 = HEAP32[$0>>2]|0;
   $5 = HEAP32[$meshes>>2]|0;
   $6 = $5;
   $7 = ($4|0)==($5|0);
   L3: do {
    if ($7) {
     $$lcssa = $4;$$lcssa11 = $4;$$lcssa13 = $6;
    } else {
     $9 = $5;$i$015 = 0;
     while(1) {
      $8 = (($9) + ($i$015<<2)|0);
      $10 = HEAP32[$8>>2]|0;
      __THREW__ = 0;
      invoke_vi(3724,($10|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      $13 = (($i$015) + 1)|0;
      $14 = HEAP32[$0>>2]|0;
      $15 = HEAP32[$meshes>>2]|0;
      $16 = $14;
      $17 = $15;
      $18 = (($16) - ($17))|0;
      $19 = $18 >> 2;
      $20 = ($13>>>0)<($19>>>0);
      if ($20) {
       $9 = $15;$i$015 = $13;
      } else {
       $$lcssa = $14;$$lcssa11 = $15;$$lcssa13 = $17;
       break L3;
      }
     }
     $21 = ___cxa_find_matching_catch()|0;
     $22 = tempRet0;
     $lpad$phi$index = $21;$lpad$phi$index2 = $22;
     break L1;
    }
   } while(0);
   $32 = ($$lcssa11|0)==(0|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   $33 = ($$lcssa|0)==($$lcssa11|0);
   if (!($33)) {
    $scevgep$i$i$i$i$i = (($$lcssa) + -4|0);
    $34 = (0 - ($$lcssa13))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($34)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $35 = $uglygep3$i$i$i$i$i >>> 2;
    $36 = $35 ^ -1;
    $scevgep4$i$i$i$i$i = (($$lcssa) + ($36<<2)|0);
    HEAP32[$0>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($$lcssa11);
   STACKTOP = sp;return;
  }
 } while(0);
 $25 = HEAP32[$meshes>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $27 = HEAP32[$0>>2]|0;
 $28 = ($27|0)==($25|0);
 if (!($28)) {
  $__new_last2$i$i$i$i$i1 = $25;
  $scevgep$i$i$i$i$i2 = (($27) + -4|0);
  $29 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($29)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $30 = $uglygep3$i$i$i$i$i5 >>> 2;
  $31 = $30 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($27) + ($31<<2)|0);
  HEAP32[$0>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($25);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN20TextRenderingPrivate4Font12LoadAllFontsEv() {
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $fonts = 0, $i$010 = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $pos$i$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $temp$0$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 16|0;
 $0 = sp;
 $fonts = sp + 4|0;
 HEAP32[$fonts>>2] = 0;
 $1 = (($fonts) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($fonts) + 8|0);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 (invoke_iiii(1536,128,($fonts|0),0)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   label = 19;
  } else {
   $5 = HEAP32[$1>>2]|0;
   $6 = HEAP32[$fonts>>2]|0;
   $7 = $5;
   $8 = $6;
   $9 = (($7) - ($8))|0;
   $10 = $9 >> 2;
   $11 = ($10|0)==(0);
   L3: do {
    if (!($11)) {
     $13 = $6;$i$010 = 0;
     while(1) {
      $12 = (($13) + ($i$010<<2)|0);
      $14 = HEAP32[$12>>2]|0;
      $15 = ($14|0)==(0);
      if ($15) {
       $$0$i = 0;
      } else {
       HEAP32[$0>>2] = $14;
       $16 = HEAP32[560624>>2]|0;
       $17 = ($16|0)==(0|0);
       if ($17) {
        label = 13;
       } else {
        $18 = (($16) + 36|0);
        $19 = HEAP32[$18>>2]|0;
        $20 = (($16) + 4|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = ($19|0)==($21|0);
        do {
         if ($22) {
          $23 = (($16) + 28|0);
          $24 = HEAP32[$23>>2]|0;
          $25 = (($16) + 32|0);
          $26 = HEAP32[$25>>2]|0;
          $27 = (($24) + ($26<<3)|0);
          $43 = $27;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$16,$0);
          $28 = HEAP32[$pos$i$i$i$i>>2]|0;
          $29 = ($28|0)==(-1);
          $30 = (($16) + 28|0);
          $31 = HEAP32[$30>>2]|0;
          if ($29) {
           $32 = (($16) + 32|0);
           $33 = HEAP32[$32>>2]|0;
           $34 = (($31) + ($33<<3)|0);
           $43 = $34;
           break;
          } else {
           $35 = (($31) + ($28<<3)|0);
           $43 = $35;
           break;
          }
         }
        } while(0);
        $36 = HEAP32[560624>>2]|0;
        $37 = (($36) + 28|0);
        $38 = HEAP32[$37>>2]|0;
        $39 = (($36) + 32|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = (($38) + ($40<<3)|0);
        $42 = ($43|0)==($41|0);
        if ($42) {
         label = 13;
        } else {
         $44 = (($43) + 4|0);
         $45 = HEAP32[$44>>2]|0;
         $46 = ($45|0)==(0|0);
         if ($46) {
          label = 13;
         } else {
          $temp$0$i = $45;
         }
        }
       }
       if ((label|0) == 13) {
        label = 0;
        __THREW__ = 0;
        $47 = (invoke_ii(3215,($14|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break;
        } else {
         $temp$0$i = $47;
        }
       }
       $$0$i = $temp$0$i;
      }
      __THREW__ = 0;
      (invoke_ii(3413,($$0$i|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
      $52 = (($i$010) + 1)|0;
      $53 = ($52|0)==($10|0);
      if ($53) {
       break L3;
      }
      $$pre = HEAP32[$fonts>>2]|0;
      $13 = $$pre;$i$010 = $52;
     }
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     $lpad$phi$index = $54;$lpad$phi$index2 = $55;
     break L1;
    }
   } while(0);
   __THREW__ = 0;
   invoke_v(255);
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if ($66) {
    label = 19;
   } else {
    $67 = HEAP32[$fonts>>2]|0;
    $68 = ($67|0)==(0|0);
    if ($68) {
     STACKTOP = sp;return;
    }
    $69 = HEAP32[$1>>2]|0;
    $70 = ($69|0)==($67|0);
    if (!($70)) {
     $__new_last2$i$i$i$i$i = $67;
     $scevgep$i$i$i$i$i = (($69) + -4|0);
     $71 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($71)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $72 = $uglygep3$i$i$i$i$i >>> 2;
     $73 = $72 ^ -1;
     $scevgep4$i$i$i$i$i = (($69) + ($73<<2)|0);
     HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($67);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $56 = ___cxa_find_matching_catch()|0;
  $57 = tempRet0;
  $lpad$phi$index = $56;$lpad$phi$index2 = $57;
 }
 $58 = HEAP32[$fonts>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $60 = HEAP32[$1>>2]|0;
 $61 = ($60|0)==($58|0);
 if (!($61)) {
  $__new_last2$i$i$i$i$i1 = $58;
  $scevgep$i$i$i$i$i2 = (($60) + -4|0);
  $62 = (0 - ($__new_last2$i$i$i$i$i1))|0;
  $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($62)|0);
  $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
  $63 = $uglygep3$i$i$i$i$i5 >>> 2;
  $64 = $63 ^ -1;
  $scevgep4$i$i$i$i$i6 = (($60) + ($64<<2)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i6;
 }
 __ZdlPv($58);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN20TextRenderingPrivate4Font18ResetCachedTextureEv($this) {
 $this = $this|0;
 var $$0 = 0, $$byval_copy10 = 0, $$index = 0, $$index3 = 0, $$pr = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i = 0, $allocPtr$0 = 0, $data = 0, $phitmp$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i = 0, $texImg = 0;
 var $uglygep$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy10 = sp + 64|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $texImg = sp + 20|0;
 $data = sp + 40|0;
 $4 = (($this) + 76|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(-2);
 if (!($6)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($this) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 88|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($8|0);
 if (!($11)) {
  $__new_last2$i$i$i = $8;
  $scevgep$i$i$i = (($10) + -56|0);
  $12 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($12)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $13 = (($uglygep3$i$i$i>>>0) / 56)&-1;
  $14 = $13 ^ -1;
  $scevgep4$i$i$i = (($10) + (($14*56)|0)|0);
  HEAP32[$9>>2] = $scevgep4$i$i$i;
 }
 __ZN20TextRenderingPrivate4Font10CacheRectsEv($this);
 $15 = HEAP32[((640792 + 108|0))>>2]|0;
 $16 = ($15>>>0)>(4096);
 $17 = $16 ? 4096 : $15;
 $18 = (($this) + 184|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19>>>0)>($17>>>0);
 $$pre13 = (($this) + 188|0);
 if (!($20)) {
  $21 = HEAP32[$$pre13>>2]|0;
  $22 = ($21>>>0)>($17>>>0);
  if (!($22)) {
   $23 = (($this) + 40|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0);
   if ($25) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$1>>2] = $24;
   $26 = HEAP32[560624>>2]|0;
   $27 = ($26|0)==(0|0);
   if ($27) {
    label = 16;
   } else {
    $28 = (($26) + 36|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($26) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($29|0)==($31|0);
    do {
     if ($32) {
      $33 = (($26) + 28|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = (($26) + 32|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($34) + ($36<<3)|0);
      $53 = $37;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy10,$26,$1);
      $38 = HEAP32[$$byval_copy10>>2]|0;
      $39 = ($38|0)==(-1);
      $40 = (($26) + 28|0);
      $41 = HEAP32[$40>>2]|0;
      if ($39) {
       $42 = (($26) + 32|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = (($41) + ($43<<3)|0);
       $53 = $44;
       break;
      } else {
       $45 = (($41) + ($38<<3)|0);
       $53 = $45;
       break;
      }
     }
    } while(0);
    $46 = HEAP32[560624>>2]|0;
    $47 = (($46) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($46) + 32|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($48) + ($50<<3)|0);
    $52 = ($53|0)==($51|0);
    if ($52) {
     label = 16;
    } else {
     $54 = (($53) + 4|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==(0|0);
     if ($56) {
      label = 16;
     }
    }
   }
   if ((label|0) == 16) {
    $57 = HEAP32[$23>>2]|0;
    $58 = (__Z31ReadObjectFromPersistentManageri($57)|0);
    $phitmp$i = ($58|0)==(0|0);
    if ($phitmp$i) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $59 = (__Z17dynamic_pptr_castIP9Texture2D7TextureET_RK4PPtrIT0_E($23)|0);
   $60 = HEAP8[((640792 + 259|0))>>0]|0;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    $63 = (($59) + 129|0);
    HEAP8[$63>>0] = 1;
   } else {
    $62 = (($59) + 127|0);
    HEAP8[$62>>0] = 1;
   }
   $64 = HEAP32[$59>>2]|0;
   $65 = (($64) + 104|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (FUNCTION_TABLE_ii[$66 & 4095]($59)|0);
   $68 = HEAP32[$18>>2]|0;
   $69 = ($67|0)==($68|0);
   if ($69) {
    $70 = HEAP32[$59>>2]|0;
    $71 = (($70) + 108|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (FUNCTION_TABLE_ii[$72 & 4095]($59)|0);
    $74 = HEAP32[$$pre13>>2]|0;
    $75 = ($73|0)==($74|0);
    if ($75) {
     $76 = (($59) + 125|0);
     $77 = HEAP8[$76>>0]|0;
     $78 = ($77<<24>>24)==(0);
     if ($78) {
      $83 = $73;
      label = 24;
     } else {
      $90 = $73;
     }
    } else {
     $83 = $74;
     label = 24;
    }
   } else {
    $$pre10 = HEAP32[$$pre13>>2]|0;
    $83 = $$pre10;
    label = 24;
   }
   do {
    if ((label|0) == 24) {
     $79 = HEAP32[$59>>2]|0;
     $80 = (($79) + 148|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = HEAP32[$18>>2]|0;
     $84 = (FUNCTION_TABLE_iiiiiiii[$81 & 127]($59,$82,$83,1,0,1,0)|0);
     if ($84) {
      $85 = HEAP32[$59>>2]|0;
      $86 = (($85) + 152|0);
      $87 = HEAP32[$86>>2]|0;
      FUNCTION_TABLE_vi[$87 & 4095]($59);
      $$pre = HEAP32[$$pre13>>2]|0;
      $90 = $$pre;
      break;
     } else {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   } while(0);
   $88 = HEAP32[$18>>2]|0;
   $89 = Math_imul($90, $88)|0;
   $91 = (($89) + 15)|0;
   $92 = ($91>>>0)<(2000);
   do {
    if ($92) {
     $93 = ($89|0)==(0);
     if ($93) {
      $104 = 0;$113 = $90;$114 = $88;$allocPtr$0 = 0;
     } else {
      $94 = STACKTOP; STACKTOP = STACKTOP + ((((1*$91)|0)+15)&-16)|0;;
      $104 = 0;$113 = $90;$114 = $88;$allocPtr$0 = $94;
     }
    } else {
     $95 = HEAP32[628512>>2]|0;
     HEAP32[$2>>2] = $95;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
     $96 = (invoke_iiiiiii(102,($91|0),16,($$byval_copy10|0),0,(804096|0),547)|0);
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if (!($98)) {
      $$pre11 = HEAP32[$18>>2]|0;
      $$pre12 = HEAP32[$$pre13>>2]|0;
      $104 = $96;$113 = $$pre12;$114 = $$pre11;$allocPtr$0 = $96;
      break;
     }
     $99 = ___cxa_find_matching_catch()|0;
     $100 = tempRet0;
     $$index = $99;$$index3 = $100;$199 = $0;
     ___resumeException($$index|0);
     // unreachable;
    }
   } while(0);
   $108 = $allocPtr$0;
   $109 = (($108) + 15)|0;
   $110 = $109 & -16;
   $111 = $110;
   $112 = Math_imul($113, $114)|0;
   _memset(($111|0),0,($112|0))|0;
   $115 = HEAP32[$18>>2]|0;
   $116 = HEAP32[$$pre13>>2]|0;
   $117 = Math_imul($116, $115)|0;
   $118 = HEAP8[((640792 + 259|0))>>0]|0;
   $119 = ($118<<24>>24)==(0);
   if ($119) {
    __THREW__ = 0;
    $120 = (invoke_i(59)|0);
    $121 = __THREW__; __THREW__ = 0;
    $122 = $121&1;
    if ($122) {
     label = 32;
    } else {
     $123 = HEAP32[$120>>2]|0;
     $124 = (($123) + 476|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = (($59) + 44|0);
     $127 = HEAP32[$126>>2]|0;
     HEAP32[$3>>2] = $127;
     $128 = HEAP32[$18>>2]|0;
     $129 = HEAP32[$$pre13>>2]|0;
     __THREW__ = 0;
     $130 = (invoke_i(66)|0);
     $131 = __THREW__; __THREW__ = 0;
     $132 = $131&1;
     if ($132) {
      label = 32;
     } else {
      $133 = ($130|0)==(1);
      if ($133) {
       $134 = (($59) + 56|0);
       $135 = HEAP32[$134>>2]|0;
       $136 = $135;
      } else {
       $136 = 0;
      }
      __THREW__ = 0;
      ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_viiiiiiiiiii($125|0,($120|0),($$byval_copy10|0),($111|0),($117|0),0,0,0,($128|0),($129|0),1,($136|0));
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       label = 32;
      } else {
       $$pr = HEAP8[((640792 + 259|0))>>0]|0;
       $139 = ($$pr<<24>>24)==(0);
       if (!($139)) {
        label = 41;
       }
      }
     }
    }
   } else {
    label = 41;
   }
   do {
    if ((label|0) == 41) {
     ;HEAP32[$texImg+0>>2]=0|0;HEAP32[$texImg+4>>2]=0|0;HEAP32[$texImg+8>>2]=0|0;HEAP32[$texImg+12>>2]=0|0;HEAP32[$texImg+16>>2]=0|0;
     __THREW__ = 0;
     $140 = (invoke_iiiii(236,($59|0),($texImg|0),0,0)|0);
     $141 = __THREW__; __THREW__ = 0;
     $142 = $141&1;
     if ($142) {
      label = 32;
     } else {
      if ($140) {
       $143 = HEAP32[$18>>2]|0;
       $144 = HEAP32[$$pre13>>2]|0;
       __THREW__ = 0;
       invoke_viiiiii(125,($data|0),($143|0),($144|0),($143|0),1,($111|0));
       $145 = __THREW__; __THREW__ = 0;
       $146 = $145&1;
       if ($146) {
        label = 32;
        break;
       }
       __THREW__ = 0;
       invoke_viii(1729,($texImg|0),($data|0),0);
       $147 = __THREW__; __THREW__ = 0;
       $148 = $147&1;
       if ($148) {
        label = 32;
        break;
       }
      }
      $149 = HEAP8[((640792 + 259|0))>>0]|0;
      $150 = ($149<<24>>24)==(0);
      if (!($150)) {
       $151 = HEAP32[$59>>2]|0;
       $152 = (($151) + 152|0);
       $153 = HEAP32[$152>>2]|0;
       __THREW__ = 0;
       invoke_vi($153|0,($59|0));
       $154 = __THREW__; __THREW__ = 0;
       $155 = $154&1;
       if ($155) {
        label = 32;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 32) {
    $101 = ___cxa_find_matching_catch()|0;
    $102 = tempRet0;
    $103 = ($104|0)==(0|0);
    if ($103) {
     $$index = $101;$$index3 = $102;$199 = $0;
     ___resumeException($$index|0);
     // unreachable;
    }
    $105 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $105;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($104|0),($$byval_copy10|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     $197 = ___cxa_find_matching_catch(0|0)|0;
     $198 = tempRet0;
     ___clang_call_terminate($197);
     // unreachable;
    } else {
     $$index = $101;$$index3 = $102;$199 = $0;
     ___resumeException($$index|0);
     // unreachable;
    }
   }
   $156 = ($104|0)==(0|0);
   if (!($156)) {
    $157 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $157;
    ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($104,$$byval_copy10);
   }
   $158 = (($this) + 168|0);
   $159 = (($this) + 172|0);
   $160 = HEAP32[$159>>2]|0;
   __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($158,$160);
   $161 = (($this) + 176|0);
   HEAP32[$161>>2] = 0;
   $162 = (($this) + 172|0);
   HEAP32[$158>>2] = $162;
   HEAP32[$162>>2] = 0;
   $163 = (($this) + 156|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($this) + 160|0);
   $166 = HEAP32[$165>>2]|0;
   $167 = ($166|0)==($164|0);
   if (!($167)) {
    $__new_last2$i$i$i$i = $164;
    $scevgep$i$i$i$i = (($166) + -16|0);
    $168 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($168)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $169 = $uglygep3$i$i$i$i >>> 4;
    $170 = $169 ^ -1;
    $scevgep4$i$i$i$i = (($166) + ($170<<4)|0);
    HEAP32[$165>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 0;
   $171 = (($0) + 4|0);
   HEAP32[$171>>2] = 0;
   __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE15__insert_uniqueERKS3_($$byval_copy10,$158,$0);
   $172 = HEAP32[$158>>2]|0;
   $173 = (($this) + 180|0);
   HEAP32[$173>>2] = $172;
   $174 = (($this) + 200|0);
   HEAP32[$174>>2] = 0;
   $175 = (($this) + 196|0);
   $176 = (($this) + 32|0);
   $177 = HEAP32[$176>>2]|0;
   $178 = $177 << 3;
   $179 = (($178) + -1)|0;
   $180 = $179 >>> 16;
   $181 = $180 | $179;
   $182 = $181 >>> 8;
   $183 = $182 | $181;
   $184 = $183 >>> 4;
   $185 = $184 | $183;
   $186 = $185 >>> 2;
   $187 = $186 | $185;
   $188 = $187 >>> 1;
   $189 = $188 | $187;
   $190 = (($189) + 1)|0;
   $191 = HEAP32[$175>>2]|0;
   $192 = ($191>>>0)<($190>>>0);
   $193 = $192 ? $190 : $191;
   $194 = HEAP32[$18>>2]|0;
   $195 = ($194>>>0)<($193>>>0);
   $196 = $195 ? $194 : $193;
   HEAP32[$175>>2] = $196;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(804224,0,804096,517,1,0,0,0);
 HEAP32[$18>>2] = $17;
 HEAP32[$$pre13>>2] = $17;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20TextRenderingPrivate4Font13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $$byval_copy1 = 0, $$lcssa = Math_fround(0), $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0);
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $charNo$04 = 0, $phitmp = 0, $phitmp6 = 0, $storemerge = Math_fround(0), $temp$0$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 80|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = $5 < Math_fround(0.0);
 if ($6) {
  __ZNK13TextRendering4Font10GetTextureEv($2,$this);
  $7 = HEAP32[$2>>2]|0;
  $8 = ($7|0)==(0);
  do {
   if ($8) {
    $storemerge = Math_fround(1.0);
   } else {
    HEAP32[$1>>2] = $7;
    $9 = HEAP32[560624>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     label = 11;
    } else {
     $11 = (($9) + 36|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (($9) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($12|0)==($14|0);
     do {
      if ($15) {
       $16 = (($9) + 28|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = (($9) + 32|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = (($17) + ($19<<3)|0);
       $36 = $20;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy1,$9,$1);
       $21 = HEAP32[$$byval_copy1>>2]|0;
       $22 = ($21|0)==(-1);
       $23 = (($9) + 28|0);
       $24 = HEAP32[$23>>2]|0;
       if ($22) {
        $25 = (($9) + 32|0);
        $26 = HEAP32[$25>>2]|0;
        $27 = (($24) + ($26<<3)|0);
        $36 = $27;
        break;
       } else {
        $28 = (($24) + ($21<<3)|0);
        $36 = $28;
        break;
       }
      }
     } while(0);
     $29 = HEAP32[560624>>2]|0;
     $30 = (($29) + 28|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($29) + 32|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + ($33<<3)|0);
     $35 = ($36|0)==($34|0);
     if ($35) {
      label = 11;
     } else {
      $37 = (($36) + 4|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38|0)==(0|0);
      if ($39) {
       label = 11;
      } else {
       $temp$0$i8 = $38;
      }
     }
    }
    if ((label|0) == 11) {
     $40 = (__Z31ReadObjectFromPersistentManageri($7)|0);
     $41 = ($40|0)==(0|0);
     if ($41) {
      $storemerge = Math_fround(1.0);
      break;
     } else {
      $temp$0$i8 = $40;
     }
    }
    $42 = Math_fround(HEAPF32[$4>>2]);
    $43 = Math_fround(-$42);
    $44 = HEAP32[$temp$0$i8>>2]|0;
    $45 = (($44) + 104|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (FUNCTION_TABLE_ii[$46 & 4095]($temp$0$i8)|0);
    $48 = (Math_fround(($47|0)));
    $49 = Math_fround($43 / $48);
    $storemerge = $49;
   }
  } while(0);
  HEAPF32[$4>>2] = $storemerge;
  $50 = (($this) + 88|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($this) + 84|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($51|0)==($53|0);
  if ($54) {
   $$lcssa = $storemerge;
  } else {
   $56 = $storemerge;$59 = $53;$charNo$04 = 0;
   while(1) {
    $55 = Math_fround(Math_fround(1.0) / $56);
    $57 = Math_fround(Math_fround(-1.0) / $56);
    $58 = ((($59) + (($charNo$04*56)|0)|0) + 20|0);
    HEAPF32[$58>>2] = Math_fround(0.0);
    $60 = ((($59) + (($charNo$04*56)|0)|0) + 24|0);
    HEAPF32[$60>>2] = Math_fround(0.0);
    $61 = ((($59) + (($charNo$04*56)|0)|0) + 28|0);
    HEAPF32[$61>>2] = $55;
    $62 = ((($59) + (($charNo$04*56)|0)|0) + 32|0);
    HEAPF32[$62>>2] = $57;
    $63 = Math_fround(HEAPF32[$4>>2]);
    $64 = ((($59) + (($charNo$04*56)|0)|0) + 36|0);
    $65 = Math_fround(HEAPF32[$64>>2]);
    $66 = Math_fround($65 / $63);
    HEAPF32[$64>>2] = $66;
    $67 = (($charNo$04) + 1)|0;
    $68 = HEAP32[$50>>2]|0;
    $69 = HEAP32[$52>>2]|0;
    $70 = $68;
    $71 = $69;
    $72 = (($70) - ($71))|0;
    $73 = (($72|0) / 56)&-1;
    $74 = ($67>>>0)<($73>>>0);
    $75 = Math_fround(HEAPF32[$4>>2]);
    if ($74) {
     $56 = $75;$59 = $69;$charNo$04 = $67;
    } else {
     $$lcssa = $75;
     break;
    }
   }
  }
  $76 = (($this) + 28|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = Math_fround($77 / $$lcssa);
  HEAPF32[$76>>2] = $78;
 }
 __ZN20TextRenderingPrivate4Font10CacheRectsEv($this);
 $79 = (($this) + 76|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)==(-2);
 if ($81) {
  $82 = (($this) + 132|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($this) + 136|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($83|0)==($85|0);
  do {
   if ($86) {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(804176,0,804096,401,1,0,0,0);
    HEAP8[$3>>0] = 10;
    $87 = (($3) + 1|0);
    ;HEAP8[$87+0>>0]=HEAP8[804216+0>>0]|0;HEAP8[$87+1>>0]=HEAP8[804216+1>>0]|0;HEAP8[$87+2>>0]=HEAP8[804216+2>>0]|0;HEAP8[$87+3>>0]=HEAP8[804216+3>>0]|0;HEAP8[$87+4>>0]=HEAP8[804216+4>>0]|0;
    $88 = (($3) + 6|0);
    HEAP8[$88>>0] = 0;
    $89 = HEAP32[$84>>2]|0;
    $90 = (($this) + 140|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($89|0)==($91|0);
    if (!($92)) {
     $93 = ($89|0)==(0|0);
     if ($93) {
      $97 = 0;
     } else {
      HEAP8[$89>>0] = 10;
      $94 = (($89) + 1|0);
      ;HEAP8[$94+0>>0]=HEAP8[$87+0>>0]|0;HEAP8[$94+1>>0]=HEAP8[$87+1>>0]|0;HEAP8[$94+2>>0]=HEAP8[$87+2>>0]|0;HEAP8[$94+3>>0]=HEAP8[$87+3>>0]|0;HEAP8[$94+4>>0]=HEAP8[$87+4>>0]|0;
      $95 = (($89) + 6|0);
      HEAP8[$95>>0] = 0;
      $$pre$i = HEAP32[$84>>2]|0;
      $97 = $$pre$i;
     }
     $96 = (($97) + 12|0);
     HEAP32[$84>>2] = $96;
     break;
    }
    __THREW__ = 0;
    invoke_vii(3433,($82|0),($3|0));
    $98 = __THREW__; __THREW__ = 0;
    $99 = $98&1;
    if (!($99)) {
     $$pre = HEAP8[$3>>0]|0;
     $phitmp = $$pre & 1;
     $phitmp6 = ($phitmp<<24>>24)==(0);
     if ($phitmp6) {
      break;
     }
     $100 = (($3) + 8|0);
     $101 = HEAP32[$100>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($101|0),($$byval_copy1|0));
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if (!($103)) {
      break;
     }
     $104 = ___cxa_find_matching_catch()|0;
     $105 = tempRet0;
     ___cxa_call_unexpected(($104|0));
     // unreachable;
    }
    $106 = ___cxa_find_matching_catch()|0;
    $107 = tempRet0;
    $108 = HEAP8[$3>>0]|0;
    $109 = $108 & 1;
    $110 = ($109<<24>>24)==(0);
    if ($110) {
     ___resumeException($106|0);
     // unreachable;
    }
    $111 = (($3) + 8|0);
    $112 = HEAP32[$111>>2]|0;
    HEAP32[$0>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($112|0),($$byval_copy1|0));
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    if ($114) {
     $115 = ___cxa_find_matching_catch()|0;
     $116 = tempRet0;
     ___cxa_call_unexpected(($115|0));
     // unreachable;
    } else {
     ___resumeException($106|0);
     // unreachable;
    }
   }
  } while(0);
  __ZN20TextRenderingPrivate4Font16SetupDynamicFontEv($this);
  (__ZN20TextRenderingPrivate4Font18ResetCachedTextureEv($this)|0);
 }
 $117 = $awakeMode & 1;
 $118 = ($117|0)==(0);
 if (!($118)) {
  STACKTOP = sp;return;
 }
 __Z13ApplyToMeshesv();
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font10CacheRectsEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0;
 var $__new_last2$i$i$i1 = 0, $i$08 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i2 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i6 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i4 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i5 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 $$pre = $2;
 if ($5) {
  $10 = $2;
 } else {
  $scevgep$i$i$i = (($4) + -56|0);
  $6 = (0 - ($$pre))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($6)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $7 = (($uglygep3$i$i$i>>>0) / 56)&-1;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i = (($4) + (($8*56)|0)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i;
  $10 = $scevgep4$i$i$i;
 }
 $9 = $10;
 $11 = (($9) - ($$pre))|0;
 $12 = (($11|0) / 56)&-1;
 $13 = ($12>>>0)<(256);
 if ($13) {
  $14 = (256 - ($12))|0;
  __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE8__appendEj($1,$14);
 } else {
  $15 = ($12>>>0)>(256);
  if ($15) {
   $16 = (($2) + 14336|0);
   $17 = ($10|0)==($16|0);
   if (!($17)) {
    $__new_last2$i$i$i1 = $16;
    $scevgep$i$i$i2 = (($10) + -56|0);
    $18 = (0 - ($__new_last2$i$i$i1))|0;
    $uglygep$i$i$i4 = (($scevgep$i$i$i2) + ($18)|0);
    $uglygep3$i$i$i5 = $uglygep$i$i$i4;
    $19 = (($uglygep3$i$i$i5>>>0) / 56)&-1;
    $20 = $19 ^ -1;
    $scevgep4$i$i$i6 = (($10) + (($20*56)|0)|0);
    HEAP32[$3>>2] = $scevgep4$i$i$i6;
   }
  }
 }
 $21 = (($this) + 96|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 100|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==($22|0);
 if (!($25)) {
  $__new_last2$i$i$i$i$i = $22;
  $scevgep$i$i$i$i$i = (($24) + -56|0);
  $26 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($26)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $27 = (($uglygep3$i$i$i$i$i>>>0) / 56)&-1;
  $28 = $27 ^ -1;
  $scevgep4$i$i$i$i$i = (($24) + (($28*56)|0)|0);
  HEAP32[$23>>2] = $scevgep4$i$i$i$i$i;
 }
 $29 = (($this) + 88|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($this) + 84|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($30|0)==($32|0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = (($this) + 108|0);
 $35 = (($this) + 96|0);
 $37 = $32;$i$08 = 0;
 while(1) {
  $36 = (($37) + (($i$08*56)|0)|0);
  $38 = HEAP32[$36>>2]|0;
  $39 = ($38|0)==(-1);
  if ($39) {
   HEAP32[$36>>2] = $i$08;
   $41 = $i$08;
  } else {
   $41 = $38;
  }
  $40 = ($41>>>0)<(256);
  if ($40) {
   $42 = ((($37) + (($i$08*56)|0)|0) + 40|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0);
   if ($44) {
    $45 = ((($37) + (($i$08*56)|0)|0) + 44|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($46|0)==(0);
    if ($47) {
     $48 = HEAP32[$34>>2]|0;
     $49 = (($48) + (($41*56)|0)|0);
     dest=$49+0|0; src=$36+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP8[$49+52>>0]=HEAP8[$36+52>>0]|0;
    } else {
     label = 18;
    }
   } else {
    label = 18;
   }
  } else {
   label = 18;
  }
  if ((label|0) == 18) {
   label = 0;
   __ZN13sorted_vectorIN20TextRenderingPrivate4Font13CharacterInfoENSt3__14lessIS2_EENS3_9allocatorIS2_EEE10insert_oneERKS2_($0,$35,$36);
  }
  $50 = (($i$08) + 1)|0;
  $51 = HEAP32[$29>>2]|0;
  $52 = HEAP32[$31>>2]|0;
  $53 = $51;
  $54 = $52;
  $55 = (($53) - ($54))|0;
  $56 = (($55|0) / 56)&-1;
  $57 = ($50>>>0)<($56>>>0);
  if ($57) {
   $37 = $52;$i$08 = $50;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font21AddCharacterInfoEntryERK5RectTIfES4_fibij($this,$uv,$vert,$width,$character,$flipped,$size,$style) {
 $this = $this|0;
 $uv = $uv|0;
 $vert = $vert|0;
 $width = Math_fround($width);
 $character = $character|0;
 $flipped = $flipped|0;
 $size = $size|0;
 $style = $style|0;
 var $$pre$i = 0, $$size = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $inf = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 56|0;
 $inf = sp;
 $1 = (($this) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($character) - ($2))|0;
 $4 = (($inf) + 4|0);
 dest=$4+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $5 = (($inf) + 4|0);
 ;HEAP32[$5+0>>2]=HEAP32[$uv+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$uv+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$uv+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$uv+12>>2]|0;
 $6 = (($inf) + 20|0);
 ;HEAP32[$6+0>>2]=HEAP32[$vert+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$vert+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$vert+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$vert+12>>2]|0;
 $7 = (($inf) + 36|0);
 HEAPF32[$7>>2] = $width;
 HEAP32[$inf>>2] = $3;
 $8 = (($this) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($size|0);
 $11 = (($inf) + 40|0);
 $$size = $10 ? 0 : $size;
 HEAP32[$11>>2] = $$size;
 $12 = (($inf) + 44|0);
 HEAP32[$12>>2] = $style;
 $13 = (__Z14GetTimeManagerv()|0);
 $14 = (($13) + 128|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($inf) + 48|0);
 HEAP32[$16>>2] = $15;
 $17 = (($inf) + 52|0);
 $18 = $flipped&1;
 HEAP8[$17>>0] = $18;
 $19 = (($this) + 88|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 92|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($20|0)==($22|0);
 if ($23) {
  $27 = (($this) + 84|0);
  __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE21__push_back_slow_pathIKS3_EEvRT_($27,$inf);
 } else {
  $24 = ($20|0)==(0|0);
  if ($24) {
   $26 = 0;
  } else {
   dest=$20+0|0; src=$inf+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre$i = HEAP32[$19>>2]|0;
   $26 = $$pre$i;
  }
  $25 = (($26) + 56|0);
  HEAP32[$19>>2] = $25;
 }
 $28 = HEAP32[$inf>>2]|0;
 $29 = ($28>>>0)<(256);
 if ($29) {
  $30 = HEAP32[$11>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $32 = HEAP32[$12>>2]|0;
   $33 = ($32|0)==(0);
   if ($33) {
    $34 = (($this) + 108|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + (($28*56)|0)|0);
    dest=$36+0|0; src=$inf+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP8[$36+52>>0]=HEAP8[$inf+52>>0]|0;
    STACKTOP = sp;return;
   }
  }
 }
 $37 = (($this) + 96|0);
 __ZN13sorted_vectorIN20TextRenderingPrivate4Font13CharacterInfoENSt3__14lessIS2_EENS3_9allocatorIS2_EEE10insert_oneERKS2_($0,$37,$inf);
 STACKTOP = sp;return;
}
function __Z17dynamic_pptr_castIP9Texture2D7TextureET_RK4PPtrIT0_E($ptr) {
 $ptr = $ptr|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i$i = 0, $temp$0$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$ptr>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if (!($2)) {
   HEAP32[$0>>2] = $1;
   $3 = HEAP32[560624>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    label = 10;
   } else {
    $5 = (($3) + 36|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($3) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($6|0)==($8|0);
    do {
     if ($9) {
      $10 = (($3) + 28|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (($3) + 32|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = (($11) + ($13<<3)|0);
      $30 = $14;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i,$3,$0);
      $15 = HEAP32[$pos$i$i$i$i>>2]|0;
      $16 = ($15|0)==(-1);
      $17 = (($3) + 28|0);
      $18 = HEAP32[$17>>2]|0;
      if ($16) {
       $19 = (($3) + 32|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($18) + ($20<<3)|0);
       $30 = $21;
       break;
      } else {
       $22 = (($18) + ($15<<3)|0);
       $30 = $22;
       break;
      }
     }
    } while(0);
    $23 = HEAP32[560624>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + ($27<<3)|0);
    $29 = ($30|0)==($28|0);
    if ($29) {
     label = 10;
    } else {
     $31 = (($30) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==(0|0);
     if ($33) {
      label = 10;
     } else {
      $temp$0$i3 = $32;
     }
    }
   }
   if ((label|0) == 10) {
    $34 = HEAP32[$ptr>>2]|0;
    $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
    $36 = ($35|0)==(0|0);
    if ($36) {
     break;
    } else {
     $temp$0$i3 = $35;
    }
   }
   $37 = (($temp$0$i3) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = $38 >>> 21;
   $40 = HEAP32[560640>>2]|0;
   $41 = Math_imul($40, $39)|0;
   $42 = (($41) + 28)|0;
   $43 = $42 >> 5;
   $44 = $43 << 5;
   $45 = (($42) - ($44))|0;
   $46 = HEAP32[560632>>2]|0;
   $47 = (($46) + ($43<<2)|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = 1 << $45;
   $50 = $49 & $48;
   $51 = ($50|0)==(0);
   if (!($51)) {
    $$0$i1 = $temp$0$i3;
    STACKTOP = sp;return ($$0$i1|0);
   }
  }
 } while(0);
 $$0$i1 = 0;
 STACKTOP = sp;return ($$0$i1|0);
}
function __ZN20TextRenderingPrivate4Font21AddCharacterToTextureEjij($this,$unicodeChar,$size,$style) {
 $this = $this|0;
 $unicodeChar = $unicodeChar|0;
 $size = $size|0;
 $style = $style|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i15 = 0, $$0$i$i$i$i30 = 0, $$0$i$i$i34 = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$01$i$i$i32 = 0, $$byval_copy8 = 0, $$lcssa93 = 0, $$pr = 0, $$pre$i = 0, $$pre104 = 0, $$pre105 = 0, $$pre115 = 0, $$pre116 = 0, $$pre117 = 0, $$pre118 = 0;
 var $$pre119 = 0, $$pre120 = 0, $$pre121 = 0, $$pre122 = 0, $$pre123 = 0, $$pre124 = 0, $$pre125 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0);
 var $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0;
 var $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0;
 var $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0;
 var $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = Math_fround(0), $315 = 0, $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0);
 var $326 = 0, $327 = 0, $328 = Math_fround(0), $329 = Math_fround(0), $33 = 0, $330 = 0, $331 = Math_fround(0), $332 = Math_fround(0), $333 = Math_fround(0), $334 = 0, $335 = 0, $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0;
 var $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0;
 var $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0;
 var $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $__new_last2$i$i$i$i = 0, $advance = 0, $bitmap$0 = 0, $bufferWidth = 0, $charHeight = 0, $charWidth = 0, $data = 0, $destRect = 0;
 var $flipped$0$off0 = 0, $flippedBitmap = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond$i = 0, $or$cond$i17 = 0, $or$cond$i23 = 0, $or$cond2$i = 0, $or$cond2$i18 = 0, $or$cond2$i24 = 0, $or$cond4652 = 0, $r = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $storemerge253 = 0, $storemerge253$in = 0, $storemerge57 = 0, $storemerge57$in = 0, $texImg = 0, $uglygep$i$i$i$i = 0;
 var $uglygep3$i$i$i$i = 0, $uv = 0, $vert = 0, $x$087 = 0, $x1$094 = 0, $y$084 = 0, $y2$090 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy8 = sp + 200|0;
 $0 = sp + 192|0;
 $1 = sp + 184|0;
 $2 = sp + 176|0;
 $3 = sp + 168|0;
 $4 = sp + 160|0;
 $vert = sp + 144|0;
 $charWidth = sp + 140|0;
 $charHeight = sp + 136|0;
 $bufferWidth = sp + 132|0;
 $advance = sp + 128|0;
 $flippedBitmap = sp + 32|0;
 $r = sp;
 $5 = sp + 16|0;
 $6 = sp + 24|0;
 $7 = sp + 44|0;
 $texImg = sp + 48|0;
 $destRect = sp + 68|0;
 $data = sp + 88|0;
 $uv = sp + 112|0;
 ;HEAP32[$vert+0>>2]=0|0;HEAP32[$vert+4>>2]=0|0;HEAP32[$vert+8>>2]=0|0;HEAP32[$vert+12>>2]=0|0;
 HEAP32[$charWidth>>2] = 0;
 HEAP32[$charHeight>>2] = 0;
 HEAP32[$bufferWidth>>2] = 0;
 HEAPF32[$advance>>2] = Math_fround(0.0);
 $8 = (($this) + 204|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 | $style;
 $11 = (__ZN20TextRenderingPrivate4Font18GetCharacterBitmapERjS1_S1_R5RectTIfERfjij($this,$charWidth,$charHeight,$bufferWidth,$vert,$advance,$unicodeChar,$size,$10)|0);
 HEAP32[$flippedBitmap>>2] = 0;
 $12 = (($flippedBitmap) + 4|0);
 HEAP32[$12>>2] = 0;
 $13 = (($flippedBitmap) + 8|0);
 HEAP32[$13>>2] = 0;
 $14 = ($11|0)==(0|0);
 if ($14) {
  $15 = HEAP32[$charHeight>>2]|0;
  $16 = HEAP32[$charWidth>>2]|0;
  $17 = Math_imul($16, $15)|0;
  $18 = ($17|0)==(0);
  if ($18) {
   $20 = $16;$21 = $15;
   label = 5;
  } else {
   HEAP32[$charWidth>>2] = 0;
   HEAP32[$charHeight>>2] = 0;
   HEAPF32[$advance>>2] = Math_fround(0.0);
   $68 = 0;$70 = 0;
   label = 22;
  }
 } else {
  $$pre115 = HEAP32[$charWidth>>2]|0;
  $$pre116 = HEAP32[$charHeight>>2]|0;
  $20 = $$pre115;$21 = $$pre116;
  label = 5;
 }
 do {
  if ((label|0) == 5) {
   $19 = ($20>>>0)>($21>>>0);
   if ($19) {
    $22 = Math_imul($21, $20)|0;
    $23 = ($22|0)==(0);
    if ($23) {
     $27 = $20;
    } else {
     __THREW__ = 0;
     invoke_vii(2896,($flippedBitmap|0),($22|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 14;
      break;
     }
     $$pre117 = HEAP32[$charWidth>>2]|0;
     $27 = $$pre117;
    }
    $26 = ($27|0)==(0);
    $$pre118 = HEAP32[$charHeight>>2]|0;
    if ($26) {
     $64 = $$pre118;$65 = 0;
    } else {
     $29 = $$pre118;$379 = $$pre118;$380 = $27;$x$087 = 0;
     while(1) {
      $28 = ($29|0)==(0);
      if ($28) {
       $381 = $379;$382 = 0;$62 = $380;
      } else {
       $30 = $x$087 ^ -1;
       $37 = $380;$39 = $29;$y$084 = 0;
       while(1) {
        $31 = HEAP32[$bufferWidth>>2]|0;
        $32 = Math_imul($31, $y$084)|0;
        $33 = (($32) + ($x$087))|0;
        $34 = (($11) + ($33)|0);
        $35 = HEAP8[$34>>0]|0;
        $36 = (($37) + ($30))|0;
        $38 = Math_imul($36, $39)|0;
        $40 = $y$084 ^ -1;
        $41 = (($39) + ($40))|0;
        $42 = (($41) + ($38))|0;
        $43 = HEAP32[$flippedBitmap>>2]|0;
        $44 = (($43) + ($42)|0);
        HEAP8[$44>>0] = $35;
        $45 = (($y$084) + 1)|0;
        $46 = HEAP32[$charHeight>>2]|0;
        $47 = ($45>>>0)<($46>>>0);
        $$pre119 = HEAP32[$charWidth>>2]|0;
        if ($47) {
         $37 = $$pre119;$39 = $46;$y$084 = $45;
        } else {
         $381 = $46;$382 = $46;$62 = $$pre119;
         break;
        }
       }
      }
      $60 = (($x$087) + 1)|0;
      $61 = ($60>>>0)<($62>>>0);
      if ($61) {
       $29 = $382;$379 = $381;$380 = $62;$x$087 = $60;
      } else {
       $64 = $381;$65 = $62;
       break;
      }
     }
    }
    $63 = HEAP32[$flippedBitmap>>2]|0;
    HEAP32[$bufferWidth>>2] = $64;
    HEAP32[$charHeight>>2] = $65;
    HEAP32[$charWidth>>2] = $64;
    $bitmap$0 = $63;$flipped$0$off0 = 1;
    label = 32;
   } else {
    $68 = $20;$70 = $21;
    label = 22;
   }
  }
 } while(0);
 do {
  if ((label|0) == 22) {
   $66 = HEAP32[$bufferWidth>>2]|0;
   $67 = ($66>>>0)>($68>>>0);
   if ($67) {
    $69 = Math_imul($70, $68)|0;
    $71 = ($69|0)==(0);
    if ($71) {
     $75 = $68;
    } else {
     __THREW__ = 0;
     invoke_vii(2896,($flippedBitmap|0),($69|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      label = 14;
      break;
     }
     $$pre124 = HEAP32[$charWidth>>2]|0;
     $75 = $$pre124;
    }
    $74 = ($75|0)==(0);
    if ($74) {
     $$lcssa93 = 0;
    } else {
     $$pre105 = HEAP32[$charHeight>>2]|0;
     $383 = $75;$77 = $$pre105;$x1$094 = 0;
     while(1) {
      $76 = ($77|0)==(0);
      if ($76) {
       $384 = 0;$93 = $383;
      } else {
       $84 = $383;$y2$090 = 0;
       while(1) {
        $78 = HEAP32[$bufferWidth>>2]|0;
        $79 = Math_imul($78, $y2$090)|0;
        $80 = (($79) + ($x1$094))|0;
        $81 = (($11) + ($80)|0);
        $82 = HEAP8[$81>>0]|0;
        $83 = Math_imul($84, $y2$090)|0;
        $85 = (($83) + ($x1$094))|0;
        $86 = HEAP32[$flippedBitmap>>2]|0;
        $87 = (($86) + ($85)|0);
        HEAP8[$87>>0] = $82;
        $88 = (($y2$090) + 1)|0;
        $89 = HEAP32[$charHeight>>2]|0;
        $90 = ($88>>>0)<($89>>>0);
        $$pre125 = HEAP32[$charWidth>>2]|0;
        if ($90) {
         $84 = $$pre125;$y2$090 = $88;
        } else {
         $384 = $89;$93 = $$pre125;
         break;
        }
       }
      }
      $91 = (($x1$094) + 1)|0;
      $92 = ($91>>>0)<($93>>>0);
      if ($92) {
       $383 = $93;$77 = $384;$x1$094 = $91;
      } else {
       $$lcssa93 = $93;
       break;
      }
     }
    }
    $94 = HEAP32[$flippedBitmap>>2]|0;
    HEAP32[$bufferWidth>>2] = $$lcssa93;
    $bitmap$0 = $94;$flipped$0$off0 = 0;
    label = 32;
   } else {
    $bitmap$0 = $11;$flipped$0$off0 = 0;
    label = 32;
   }
  }
 } while(0);
 L37: do {
  if ((label|0) == 32) {
   $95 = (($this) + 68|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = (Math_fround(($96|0)));
   $98 = Math_fround(HEAPF32[$vert>>2]);
   $99 = Math_fround($98 - $97);
   HEAPF32[$vert>>2] = $99;
   $100 = (($vert) + 4|0);
   $101 = Math_fround(HEAPF32[$100>>2]);
   $102 = Math_fround($101 + $97);
   HEAPF32[$100>>2] = $102;
   $103 = $96 << 1;
   $104 = (Math_fround(($103|0)));
   $105 = (($vert) + 8|0);
   $106 = Math_fround(HEAPF32[$105>>2]);
   $107 = Math_fround($106 + $104);
   HEAPF32[$105>>2] = $107;
   $108 = (($vert) + 12|0);
   $109 = Math_fround(HEAPF32[$108>>2]);
   $110 = Math_fround($109 - $104);
   HEAPF32[$108>>2] = $110;
   $111 = (($this) + 180|0);
   $112 = (($this) + 168|0);
   $113 = (($this) + 172|0);
   $114 = (($this) + 200|0);
   $115 = (($this) + 184|0);
   $116 = (($this) + 196|0);
   $117 = (($this) + 188|0);
   $118 = (($this) + 172|0);
   $119 = (($this) + 176|0);
   $120 = (($this) + 156|0);
   $121 = (($this) + 160|0);
   $122 = (($4) + 4|0);
   $123 = (($this) + 64|0);
   $124 = (($r) + 4|0);
   $125 = (($r) + 8|0);
   $126 = (($r) + 12|0);
   $$pre104 = HEAP32[$111>>2]|0;
   $128 = $$pre104;
   L39: while(1) {
    $127 = ($128|0)==($113|0);
    L41: do {
     if (!($127)) {
      $$pre120 = HEAP32[$charWidth>>2]|0;
      $$pre121 = HEAP32[$123>>2]|0;
      $$pre122 = HEAP32[$95>>2]|0;
      $$pre123 = HEAP32[$charHeight>>2]|0;
      $130 = $128;
      while(1) {
       $129 = (($130) + 16|0);
       $131 = HEAP32[$129>>2]|0;
       $132 = (($130) + 20|0);
       $133 = HEAP32[$132>>2]|0;
       $134 = (($$pre121) + ($$pre120))|0;
       $135 = $$pre122 << 1;
       $136 = (($134) + ($135))|0;
       $137 = (($$pre123) + ($$pre121))|0;
       $138 = (($137) + ($135))|0;
       HEAP32[$r>>2] = $131;
       HEAP32[$124>>2] = $133;
       HEAP32[$125>>2] = $136;
       HEAP32[$126>>2] = $138;
       $139 = $131 | $133;
       $140 = ($139|0)<(0);
       L45: do {
        if (!($140)) {
         $141 = (($136) + ($131))|0;
         $142 = HEAP32[$116>>2]|0;
         $143 = ($141|0)>($142|0);
         if (!($143)) {
          $144 = (($133) + ($138))|0;
          $145 = ($144|0)>($142|0);
          if (!($145)) {
           $146 = HEAP32[$120>>2]|0;
           $147 = HEAP32[$121>>2]|0;
           $148 = ($146|0)==($147|0);
           if ($148) {
            label = 42;
            break L39;
           } else {
            $150 = $146;
           }
           while(1) {
            $149 = HEAP32[$150>>2]|0;
            $151 = (($150) + 8|0);
            $152 = HEAP32[$151>>2]|0;
            $153 = (($152) + ($149))|0;
            $154 = ($153|0)>($131|0);
            if ($154) {
             $155 = (($150) + 4|0);
             $156 = HEAP32[$155>>2]|0;
             $157 = (($150) + 12|0);
             $158 = HEAP32[$157>>2]|0;
             $159 = (($158) + ($156))|0;
             $160 = ($159|0)>($133|0);
             $161 = ($149|0)<($141|0);
             $or$cond$i = $160 & $161;
             $162 = ($156|0)<($144|0);
             $or$cond2$i = $or$cond$i & $162;
             if ($or$cond2$i) {
              break L45;
             }
            }
            $163 = (($150) + 16|0);
            $164 = ($163|0)==($147|0);
            if ($164) {
             label = 42;
             break L39;
            } else {
             $150 = $163;
            }
           }
          }
         }
        }
       } while(0);
       $340 = (($130) + 4|0);
       $341 = HEAP32[$340>>2]|0;
       $342 = ($341|0)==(0|0);
       if ($342) {
        $$01$i$i$i = $130;
        while(1) {
         $345 = (($$01$i$i$i) + 8|0);
         $346 = HEAP32[$345>>2]|0;
         $347 = HEAP32[$346>>2]|0;
         $348 = ($347|0)==($$01$i$i$i|0);
         if ($348) {
          $$0$i$i$i = $346;
          break;
         } else {
          $$01$i$i$i = $346;
         }
        }
       } else {
        $$0$i$i$i$i = $341;
        while(1) {
         $343 = HEAP32[$$0$i$i$i$i>>2]|0;
         $344 = ($343|0)==(0|0);
         if ($344) {
          $$0$i$i$i = $$0$i$i$i$i;
          break;
         } else {
          $$0$i$i$i$i = $343;
         }
        }
       }
       $349 = ($$0$i$i$i|0)==($113|0);
       if ($349) {
        break L41;
       }
       $130 = $$0$i$i$i;
      }
     }
    } while(0);
    $350 = HEAP32[$112>>2]|0;
    $351 = ($128|0)==($350|0);
    if (!($351)) {
     HEAP32[$111>>2] = $350;
     $128 = $350;
     continue;
    }
    $352 = HEAP32[$114>>2]|0;
    $353 = (($352) + 1)|0;
    $354 = HEAP32[$115>>2]|0;
    $355 = HEAP32[$116>>2]|0;
    $356 = (($354>>>0) / ($355>>>0))&-1;
    $357 = HEAP32[$117>>2]|0;
    $358 = (($357>>>0) / ($355>>>0))&-1;
    $359 = Math_imul($358, $356)|0;
    $360 = ($353>>>0)<($359>>>0);
    if (!($360)) {
     $$0 = 0;
     break;
    }
    HEAP32[$114>>2] = $353;
    $361 = HEAP32[$118>>2]|0;
    __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($112,$361);
    HEAP32[$119>>2] = 0;
    HEAP32[$112>>2] = $113;
    HEAP32[$113>>2] = 0;
    $362 = HEAP32[$120>>2]|0;
    $363 = HEAP32[$121>>2]|0;
    $364 = ($363|0)==($362|0);
    if (!($364)) {
     $__new_last2$i$i$i$i = $362;
     $scevgep$i$i$i$i = (($363) + -16|0);
     $365 = (0 - ($__new_last2$i$i$i$i))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($365)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $366 = $uglygep3$i$i$i$i >>> 4;
     $367 = $366 ^ -1;
     $scevgep4$i$i$i$i = (($363) + ($367<<4)|0);
     HEAP32[$121>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$4>>2] = 0;
    HEAP32[$122>>2] = 0;
    __THREW__ = 0;
    invoke_viii(2044,($3|0),($112|0),($4|0));
    $368 = __THREW__; __THREW__ = 0;
    $369 = $368&1;
    if ($369) {
     label = 13;
     break;
    }
    $370 = HEAP32[$112>>2]|0;
    HEAP32[$111>>2] = $370;
    $128 = $370;
   }
   if ((label|0) == 13) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    $lpad$phi$index = $48;$lpad$phi$index2 = $49;
    break;
   }
   if ((label|0) == 42) {
    $165 = ($131|0)<(1);
    L76: do {
     if ($165) {
      $187 = $131;
     } else {
      $storemerge57$in = $131;
      while(1) {
       $storemerge57 = (($storemerge57$in) + -1)|0;
       $166 = (($storemerge57) + ($136))|0;
       $167 = ($166|0)>($142|0);
       if ($167) {
        $187 = $storemerge57$in;
        break L76;
       }
       if (!($148)) {
        $169 = $146;
        while(1) {
         $168 = HEAP32[$169>>2]|0;
         $170 = (($169) + 8|0);
         $171 = HEAP32[$170>>2]|0;
         $172 = (($171) + ($168))|0;
         $173 = ($172|0)>($storemerge57|0);
         if ($173) {
          $174 = (($169) + 4|0);
          $175 = HEAP32[$174>>2]|0;
          $176 = (($169) + 12|0);
          $177 = HEAP32[$176>>2]|0;
          $178 = (($177) + ($175))|0;
          $179 = ($178|0)>($133|0);
          $180 = ($168|0)<($166|0);
          $or$cond$i17 = $179 & $180;
          $181 = ($175|0)<($144|0);
          $or$cond2$i18 = $or$cond$i17 & $181;
          if ($or$cond2$i18) {
           $187 = $storemerge57$in;
           break L76;
          }
         }
         $182 = (($169) + 16|0);
         $183 = ($182|0)==($147|0);
         if ($183) {
          break;
         } else {
          $169 = $182;
         }
        }
       }
       $184 = ($storemerge57|0)>(0);
       if (!($184)) {
        $187 = $storemerge57$in;
        break L76;
       }
       HEAP32[$r>>2] = $storemerge57;
       HEAP32[$124>>2] = $133;
       HEAP32[$125>>2] = $136;
       HEAP32[$126>>2] = $138;
       $185 = ($storemerge57$in|0)<(2);
       if ($185) {
        $187 = $storemerge57;
        break;
       } else {
        $storemerge57$in = $storemerge57;
       }
      }
     }
    } while(0);
    $186 = ($187|0)<(0);
    $188 = ($133|0)<(1);
    $or$cond4652 = $186 | $188;
    L89: do {
     if (!($or$cond4652)) {
      $189 = (($136) + ($187))|0;
      $storemerge253$in = $133;
      while(1) {
       $storemerge253 = (($storemerge253$in) + -1)|0;
       $190 = ($189|0)>($142|0);
       if ($190) {
        break L89;
       }
       $191 = (($storemerge253) + ($138))|0;
       $192 = ($191|0)>($142|0);
       if ($192) {
        break L89;
       }
       if (!($148)) {
        $194 = $146;
        while(1) {
         $193 = HEAP32[$194>>2]|0;
         $195 = (($194) + 8|0);
         $196 = HEAP32[$195>>2]|0;
         $197 = (($196) + ($193))|0;
         $198 = ($197|0)>($187|0);
         if ($198) {
          $199 = (($194) + 4|0);
          $200 = HEAP32[$199>>2]|0;
          $201 = (($194) + 12|0);
          $202 = HEAP32[$201>>2]|0;
          $203 = (($202) + ($200))|0;
          $204 = ($203|0)>($storemerge253|0);
          $205 = ($193|0)<($189|0);
          $or$cond$i23 = $204 & $205;
          $206 = ($200|0)<($191|0);
          $or$cond2$i24 = $or$cond$i23 & $206;
          if ($or$cond2$i24) {
           break L89;
          }
         }
         $207 = (($194) + 16|0);
         $208 = ($207|0)==($147|0);
         if ($208) {
          break;
         } else {
          $194 = $207;
         }
        }
       }
       $209 = ($storemerge253|0)>(0);
       if (!($209)) {
        break L89;
       }
       HEAP32[$r>>2] = $187;
       HEAP32[$124>>2] = $storemerge253;
       HEAP32[$125>>2] = $136;
       HEAP32[$126>>2] = $138;
       $210 = ($storemerge253$in|0)<(2);
       if ($210) {
        break;
       } else {
        $storemerge253$in = $storemerge253;
       }
      }
     }
    } while(0);
    $211 = (($this) + 164|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = ($147|0)==($212|0);
    if ($213) {
     $217 = (($this) + 156|0);
     __THREW__ = 0;
     invoke_vii(3434,($217|0),($r|0));
     $218 = __THREW__; __THREW__ = 0;
     $219 = $218&1;
     if ($219) {
      label = 14;
      break;
     }
    } else {
     $214 = ($147|0)==(0|0);
     if ($214) {
      $216 = 0;
     } else {
      ;HEAP32[$147+0>>2]=HEAP32[$r+0>>2]|0;HEAP32[$147+4>>2]=HEAP32[$r+4>>2]|0;HEAP32[$147+8>>2]=HEAP32[$r+8>>2]|0;HEAP32[$147+12>>2]=HEAP32[$r+12>>2]|0;
      $$pre$i = HEAP32[$121>>2]|0;
      $216 = $$pre$i;
     }
     $215 = (($216) + 16|0);
     HEAP32[$121>>2] = $215;
    }
    HEAP32[$111>>2] = $130;
    $220 = (($130) + 4|0);
    $221 = HEAP32[$220>>2]|0;
    $222 = ($221|0)==(0|0);
    if ($222) {
     $$01$i$i$i32 = $130;
     while(1) {
      $225 = (($$01$i$i$i32) + 8|0);
      $226 = HEAP32[$225>>2]|0;
      $227 = HEAP32[$226>>2]|0;
      $228 = ($227|0)==($$01$i$i$i32|0);
      if ($228) {
       $$0$i$i$i34 = $226;
       break;
      } else {
       $$01$i$i$i32 = $226;
      }
     }
    } else {
     $$0$i$i$i$i30 = $221;
     while(1) {
      $223 = HEAP32[$$0$i$i$i$i30>>2]|0;
      $224 = ($223|0)==(0|0);
      if ($224) {
       $$0$i$i$i34 = $$0$i$i$i$i30;
       break;
      } else {
       $$0$i$i$i$i30 = $223;
      }
     }
    }
    HEAP32[$111>>2] = $$0$i$i$i34;
    $229 = HEAP32[$220>>2]|0;
    $230 = ($229|0)==(0|0);
    if ($230) {
     $$01$i$i$i$i = $130;
     while(1) {
      $233 = (($$01$i$i$i$i) + 8|0);
      $234 = HEAP32[$233>>2]|0;
      $235 = HEAP32[$234>>2]|0;
      $236 = ($235|0)==($$01$i$i$i$i|0);
      if ($236) {
       $$0$i$i$i$i15 = $234;
       break;
      } else {
       $$01$i$i$i$i = $234;
      }
     }
    } else {
     $$0$i$i$i$i$i = $229;
     while(1) {
      $231 = HEAP32[$$0$i$i$i$i$i>>2]|0;
      $232 = ($231|0)==(0|0);
      if ($232) {
       $$0$i$i$i$i15 = $$0$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i = $231;
      }
     }
    }
    $237 = HEAP32[$112>>2]|0;
    $238 = ($237|0)==($130|0);
    if ($238) {
     HEAP32[$112>>2] = $$0$i$i$i$i15;
    }
    $239 = HEAP32[$119>>2]|0;
    $240 = (($239) + -1)|0;
    HEAP32[$119>>2] = $240;
    $241 = HEAP32[$118>>2]|0;
    __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($241,$130);
    HEAP32[$0>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($130|0),($$byval_copy8|0));
    $242 = __THREW__; __THREW__ = 0;
    $243 = $242&1;
    if ($243) {
     $244 = ___cxa_find_matching_catch()|0;
     $245 = tempRet0;
     ___cxa_call_unexpected(($244|0));
     // unreachable;
    }
    $246 = HEAP32[$r>>2]|0;
    $247 = HEAP32[$125>>2]|0;
    $248 = (($247) + ($246))|0;
    $249 = HEAP32[$124>>2]|0;
    HEAP32[$5>>2] = $248;
    $250 = (($5) + 4|0);
    HEAP32[$250>>2] = $249;
    __THREW__ = 0;
    invoke_viii(2044,($0|0),($112|0),($5|0));
    $251 = __THREW__; __THREW__ = 0;
    $252 = $251&1;
    if ($252) {
     label = 14;
     break;
    }
    $253 = HEAP32[$126>>2]|0;
    $254 = (($253) + ($249))|0;
    HEAP32[$6>>2] = $246;
    $255 = (($6) + 4|0);
    HEAP32[$255>>2] = $254;
    __THREW__ = 0;
    invoke_viii(2044,($1|0),($112|0),($6|0));
    $256 = __THREW__; __THREW__ = 0;
    $257 = $256&1;
    if ($257) {
     label = 14;
     break;
    }
    $258 = HEAP32[$114>>2]|0;
    $259 = HEAP32[$116>>2]|0;
    $260 = Math_imul($259, $258)|0;
    $261 = HEAP32[$115>>2]|0;
    $262 = (($260>>>0) % ($261>>>0))&-1;
    $263 = (($246) + ($262))|0;
    HEAP32[$r>>2] = $263;
    $264 = (($260>>>0) / ($261>>>0))&-1;
    $265 = Math_imul($259, $264)|0;
    $266 = (($249) + ($265))|0;
    HEAP32[$124>>2] = $266;
    $267 = ($bitmap$0|0)==(0|0);
    do {
     if (!($267)) {
      $268 = HEAP32[$bufferWidth>>2]|0;
      $269 = HEAP32[$charHeight>>2]|0;
      $270 = Math_imul($269, $268)|0;
      $271 = (($this) + 40|0);
      __THREW__ = 0;
      $272 = (invoke_ii(3414,($271|0))|0);
      $273 = __THREW__; __THREW__ = 0;
      $274 = $273&1;
      if ($274) {
       label = 14;
       break L37;
      }
      $275 = HEAP8[((640792 + 259|0))>>0]|0;
      $276 = ($275<<24>>24)==(0);
      if ($276) {
       __THREW__ = 0;
       $277 = (invoke_i(59)|0);
       $278 = __THREW__; __THREW__ = 0;
       $279 = $278&1;
       if ($279) {
        label = 14;
        break L37;
       }
       $280 = HEAP32[$277>>2]|0;
       $281 = (($280) + 476|0);
       $282 = HEAP32[$281>>2]|0;
       $283 = (($272) + 44|0);
       $284 = HEAP32[$283>>2]|0;
       HEAP32[$7>>2] = $284;
       $285 = HEAP32[$95>>2]|0;
       $286 = HEAP32[$bufferWidth>>2]|0;
       $287 = HEAP32[$charHeight>>2]|0;
       __THREW__ = 0;
       $288 = (invoke_i(66)|0);
       $289 = __THREW__; __THREW__ = 0;
       $290 = $289&1;
       if ($290) {
        label = 14;
        break L37;
       }
       $291 = ($288|0)==(1);
       if ($291) {
        $292 = (($272) + 56|0);
        $293 = HEAP32[$292>>2]|0;
        $296 = $293;
       } else {
        $296 = 0;
       }
       $294 = (($266) + ($285))|0;
       $295 = (($285) + ($263))|0;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$7+0>>2]|0;
       invoke_viiiiiiiiiii($282|0,($277|0),($$byval_copy8|0),($bitmap$0|0),($270|0),0,($295|0),($294|0),($286|0),($287|0),1,($296|0));
       $297 = __THREW__; __THREW__ = 0;
       $298 = $297&1;
       if ($298) {
        label = 14;
        break L37;
       }
       $$pr = HEAP8[((640792 + 259|0))>>0]|0;
       $299 = ($$pr<<24>>24)==(0);
       if ($299) {
        break;
       }
      }
      ;HEAP32[$texImg+0>>2]=0|0;HEAP32[$texImg+4>>2]=0|0;HEAP32[$texImg+8>>2]=0|0;HEAP32[$texImg+12>>2]=0|0;HEAP32[$texImg+16>>2]=0|0;
      __THREW__ = 0;
      $300 = (invoke_iiiii(236,($272|0),($texImg|0),0,0)|0);
      $301 = __THREW__; __THREW__ = 0;
      $302 = $301&1;
      if ($302) {
       label = 14;
       break L37;
      }
      if ($300) {
       $303 = HEAP32[$bufferWidth>>2]|0;
       $304 = HEAP32[$charHeight>>2]|0;
       __THREW__ = 0;
       invoke_viiiiii(108,($destRect|0),($texImg|0),($263|0),($266|0),($303|0),($304|0));
       $305 = __THREW__; __THREW__ = 0;
       $306 = $305&1;
       if ($306) {
        label = 14;
        break L37;
       }
       $307 = HEAP32[$bufferWidth>>2]|0;
       $308 = HEAP32[$charHeight>>2]|0;
       __THREW__ = 0;
       invoke_viiiiii(125,($data|0),($307|0),($308|0),($307|0),1,($bitmap$0|0));
       $309 = __THREW__; __THREW__ = 0;
       $310 = $309&1;
       if ($310) {
        label = 14;
        break L37;
       }
       __THREW__ = 0;
       invoke_viii(1729,($destRect|0),($data|0),0);
       $311 = __THREW__; __THREW__ = 0;
       $312 = $311&1;
       if ($312) {
        label = 14;
        break L37;
       }
      }
     }
    } while(0);
    $313 = HEAP32[$115>>2]|0;
    $314 = (Math_fround(($313>>>0)));
    $315 = HEAP32[$117>>2]|0;
    $316 = (Math_fround(($315>>>0)));
    $317 = (Math_fround(($263|0)));
    $318 = Math_fround($317 / $314);
    $319 = HEAP32[$charHeight>>2]|0;
    $320 = (($319) + ($266))|0;
    $321 = HEAP32[$95>>2]|0;
    $322 = $321 << 1;
    $323 = (($320) + ($322))|0;
    $324 = (Math_fround(($323>>>0)));
    $325 = Math_fround($324 / $316);
    $326 = HEAP32[$charWidth>>2]|0;
    $327 = (($326) + ($322))|0;
    $328 = (Math_fround(($327>>>0)));
    $329 = Math_fround($328 / $314);
    $330 = (($322) + ($319))|0;
    $331 = (Math_fround(($330>>>0)));
    $332 = Math_fround($331 / $316);
    $333 = Math_fround(-$332);
    HEAPF32[$uv>>2] = $318;
    $334 = (($uv) + 8|0);
    HEAPF32[$334>>2] = $329;
    $335 = (($uv) + 4|0);
    HEAPF32[$335>>2] = $325;
    $336 = (($uv) + 12|0);
    HEAPF32[$336>>2] = $333;
    $337 = Math_fround(HEAPF32[$advance>>2]);
    __THREW__ = 0;
    invoke_viiifiiii(1,($this|0),($uv|0),($vert|0),(+$337),($unicodeChar|0),($flipped$0$off0|0),($size|0),($style|0));
    $338 = __THREW__; __THREW__ = 0;
    $339 = $338&1;
    if ($339) {
     label = 14;
     break;
    } else {
     $$0 = 1;
    }
   }
   $371 = HEAP32[$flippedBitmap>>2]|0;
   $372 = ($371|0)==(0|0);
   if ($372) {
    STACKTOP = sp;return ($$0|0);
   }
   $373 = HEAP32[$12>>2]|0;
   $374 = ($373|0)==($371|0);
   if (!($374)) {
    HEAP32[$12>>2] = $371;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($371|0),($$byval_copy8|0));
   $375 = __THREW__; __THREW__ = 0;
   $376 = $375&1;
   if ($376) {
    $377 = ___cxa_find_matching_catch()|0;
    $378 = tempRet0;
    ___cxa_call_unexpected(($377|0));
    // unreachable;
   } else {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  $lpad$phi$index = $50;$lpad$phi$index2 = $51;
 }
 $52 = HEAP32[$flippedBitmap>>2]|0;
 $53 = ($52|0)==(0|0);
 if ($53) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $54 = HEAP32[$12>>2]|0;
 $55 = ($54|0)==($52|0);
 if (!($55)) {
  HEAP32[$12>>2] = $52;
 }
 HEAP32[$2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($52|0),($$byval_copy8|0));
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $58 = ___cxa_find_matching_catch()|0;
  $59 = tempRet0;
  ___cxa_call_unexpected(($58|0));
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN20TextRenderingPrivate4Font24CollectAllUsedCharactersEPtRiRPiRPj($this,$chars,$length,$sizes,$styles) {
 $this = $this|0;
 $chars = $chars|0;
 $length = $length|0;
 $sizes = $sizes|0;
 $styles = $styles|0;
 var $$arith = 0, $$arith2 = 0, $$overflow = 0, $$overflow3 = 0, $$usedThisFrame$0 = 0, $$usedThisFrame$2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ch2$011 = 0, $usedThisFrame$0$lcssa = 0, $usedThisFrame$021 = 0, $usedThisFrame$2$lcssa = 0, $usedThisFrame$215 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $usedThisFrame$0$lcssa = 0;
 } else {
  $6 = $1;$usedThisFrame$021 = 0;
  while(1) {
   $5 = (($6) + 48|0);
   $7 = HEAP32[$5>>2]|0;
   $8 = (__Z14GetTimeManagerv()|0);
   $9 = (($8) + 128|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($7|0)==($10|0);
   $12 = $11&1;
   $$usedThisFrame$0 = (($12) + ($usedThisFrame$021))|0;
   $13 = (($6) + 56|0);
   $14 = HEAP32[$2>>2]|0;
   $15 = ($13|0)==($14|0);
   if ($15) {
    $usedThisFrame$0$lcssa = $$usedThisFrame$0;
    break;
   } else {
    $6 = $13;$usedThisFrame$021 = $$usedThisFrame$0;
   }
  }
 }
 $16 = (($this) + 96|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 100|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($17|0)==($19|0);
 if ($20) {
  $usedThisFrame$2$lcssa = $usedThisFrame$0$lcssa;
 } else {
  $22 = $17;$usedThisFrame$215 = $usedThisFrame$0$lcssa;
  while(1) {
   $21 = (($22) + 48|0);
   $23 = HEAP32[$21>>2]|0;
   $24 = (__Z14GetTimeManagerv()|0);
   $25 = (($24) + 128|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($23|0)==($26|0);
   $28 = $27&1;
   $$usedThisFrame$2 = (($28) + ($usedThisFrame$215))|0;
   $29 = (($22) + 56|0);
   $30 = HEAP32[$18>>2]|0;
   $31 = ($29|0)==($30|0);
   if ($31) {
    $usedThisFrame$2$lcssa = $$usedThisFrame$2;
    break;
   } else {
    $22 = $29;$usedThisFrame$215 = $$usedThisFrame$2;
   }
  }
 }
 $32 = HEAP32[$length>>2]|0;
 $33 = (($32) + ($usedThisFrame$2$lcssa))|0;
 $$arith2 = $33<<1;
 $$overflow3 = ($33>>>0)>(2147483647);
 $34 = $$overflow3 ? -1 : $$arith2;
 $35 = (__Znaj($34)|0);
 $$arith = $33<<2;
 $$overflow = ($33>>>0)>(1073741823);
 $36 = $$overflow ? -1 : $$arith;
 $37 = (__Znaj($36)|0);
 HEAP32[$sizes>>2] = $37;
 $38 = (__Znaj($36)|0);
 HEAP32[$styles>>2] = $38;
 $39 = ($32|0)>(0);
 if ($39) {
  $40 = HEAP32[$sizes>>2]|0;
  $ch2$011 = 0;
  while(1) {
   $41 = (($chars) + ($ch2$011<<1)|0);
   $42 = HEAP16[$41>>1]|0;
   $43 = (($35) + ($ch2$011<<1)|0);
   HEAP16[$43>>1] = $42;
   $44 = (($40) + ($ch2$011<<2)|0);
   HEAP32[$44>>2] = -1;
   $45 = (($38) + ($ch2$011<<2)|0);
   HEAP32[$45>>2] = -1;
   $46 = (($ch2$011) + 1)|0;
   $47 = HEAP32[$length>>2]|0;
   $48 = ($46|0)<($47|0);
   if ($48) {
    $ch2$011 = $46;
   } else {
    break;
   }
  }
 }
 $49 = HEAP32[$0>>2]|0;
 $50 = HEAP32[$2>>2]|0;
 $51 = ($49|0)==($50|0);
 if (!($51)) {
  $53 = $49;
  while(1) {
   $52 = (($53) + 48|0);
   $54 = HEAP32[$52>>2]|0;
   $55 = (__Z14GetTimeManagerv()|0);
   $56 = (($55) + 128|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($54|0)==($57|0);
   if ($58) {
    $59 = HEAP32[$53>>2]|0;
    $60 = $59&65535;
    $61 = HEAP32[$length>>2]|0;
    $62 = (($35) + ($61<<1)|0);
    HEAP16[$62>>1] = $60;
    $63 = (($53) + 40|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = HEAP32[$sizes>>2]|0;
    $66 = (($65) + ($61<<2)|0);
    HEAP32[$66>>2] = $64;
    $67 = (($53) + 44|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = HEAP32[$length>>2]|0;
    $70 = HEAP32[$styles>>2]|0;
    $71 = (($70) + ($69<<2)|0);
    HEAP32[$71>>2] = $68;
    $72 = HEAP32[$length>>2]|0;
    $73 = (($72) + 1)|0;
    HEAP32[$length>>2] = $73;
   }
   $74 = (($53) + 56|0);
   $75 = HEAP32[$2>>2]|0;
   $76 = ($74|0)==($75|0);
   if ($76) {
    break;
   } else {
    $53 = $74;
   }
  }
 }
 $77 = HEAP32[$16>>2]|0;
 $78 = HEAP32[$18>>2]|0;
 $79 = ($77|0)==($78|0);
 if ($79) {
  STACKTOP = sp;return ($35|0);
 } else {
  $81 = $77;
 }
 while(1) {
  $80 = (($81) + 48|0);
  $82 = HEAP32[$80>>2]|0;
  $83 = (__Z14GetTimeManagerv()|0);
  $84 = (($83) + 128|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($82|0)==($85|0);
  if ($86) {
   $87 = HEAP32[$81>>2]|0;
   $88 = $87&65535;
   $89 = HEAP32[$length>>2]|0;
   $90 = (($35) + ($89<<1)|0);
   HEAP16[$90>>1] = $88;
   $91 = (($81) + 40|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = HEAP32[$sizes>>2]|0;
   $94 = (($93) + ($89<<2)|0);
   HEAP32[$94>>2] = $92;
   $95 = (($81) + 44|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = HEAP32[$length>>2]|0;
   $98 = HEAP32[$styles>>2]|0;
   $99 = (($98) + ($97<<2)|0);
   HEAP32[$99>>2] = $96;
   $100 = HEAP32[$length>>2]|0;
   $101 = (($100) + 1)|0;
   HEAP32[$length>>2] = $101;
  }
  $102 = (($81) + 56|0);
  $103 = HEAP32[$18>>2]|0;
  $104 = ($102|0)==($103|0);
  if ($104) {
   break;
  } else {
   $81 = $102;
  }
 }
 STACKTOP = sp;return ($35|0);
}
function __ZN20TextRenderingPrivate4Font16CacheFontForTextEPtiijNSt3__16vectorINS_16TextFormatChangeENS2_9allocatorIS4_EEEE($this,$chars,$length,$size,$style,$format) {
 $this = $this|0;
 $chars = $chars|0;
 $length = $length|0;
 $size = $size|0;
 $style = $style|0;
 $format = $format|0;
 var $$0 = 0, $$02 = 0, $$13 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$pre$phi4$iZ2D = 0, $$pre$phi6$iZ2D = 0, $$pre$phi8$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0.0, $166 = 0.0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i11 = 0, $didAdd$0$off0 = 0, $didAdd$1$off0$not = 0, $didAdd$1$off039 = 0, $didAdd$1$off040 = 0, $didAdd$1$off045 = 0, $didAdd$2$off0 = 0, $didNotFit$0$off0 = 0, $didNotFit$1$off0 = 0, $formatChange$043 = 0, $formatChange$1$lcssa = 0, $formatChange$126 = 0;
 var $formatStack = 0, $i$044 = 0, $i$1$lcssa = 0, $i$127 = 0, $invocation$i = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $maxFontSize$0 = 0, $maxFontSize$142 = 0, $maxFontSize$3 = 0, $maxFontSize$4 = 0, $or$cond = 0, $phitmp$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i12 = 0, $scevgep4$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i16 = 0, $sizes = 0, $styles = 0, $thisSize$0 = 0;
 var $thisSize$1 = 0, $thisSize$1$maxFontSize$1 = 0, $thisStyle$0 = 0, $tmpcast$i$byval_copy = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i14 = 0, $uglygep3$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $tmpcast$i$byval_copy = sp + 240|0;
 $invocation$i = sp;
 $0 = sp + 200|0;
 $1 = sp + 208|0;
 $2 = sp + 212|0;
 $sizes = sp + 216|0;
 $styles = sp + 220|0;
 $formatStack = sp + 224|0;
 HEAP32[$2>>2] = $length;
 $3 = (($this) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(-2);
 if (!($5)) {
  $$2 = 1;
  STACKTOP = sp;return ($$2|0);
 }
 $6 = (($this) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 do {
  if ($8) {
   label = 12;
  } else {
   HEAP32[$1>>2] = $7;
   $9 = HEAP32[560624>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($9) + 36|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($9) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($12|0)==($14|0);
    do {
     if ($15) {
      $16 = (($9) + 28|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($9) + 32|0);
      $19 = HEAP32[$18>>2]|0;
      $20 = (($17) + ($19<<3)|0);
      $36 = $20;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast$i$byval_copy,$9,$1);
      $21 = HEAP32[$tmpcast$i$byval_copy>>2]|0;
      $22 = ($21|0)==(-1);
      $23 = (($9) + 28|0);
      $24 = HEAP32[$23>>2]|0;
      if ($22) {
       $25 = (($9) + 32|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = (($24) + ($26<<3)|0);
       $36 = $27;
       break;
      } else {
       $28 = (($24) + ($21<<3)|0);
       $36 = $28;
       break;
      }
     }
    } while(0);
    $29 = HEAP32[560624>>2]|0;
    $30 = (($29) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) + 32|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($31) + ($33<<3)|0);
    $35 = ($36|0)==($34|0);
    if (!($35)) {
     $37 = (($36) + 4|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ($38|0)==(0|0);
     if (!($39)) {
      break;
     }
    }
   }
   $40 = HEAP32[$6>>2]|0;
   $41 = (__Z31ReadObjectFromPersistentManageri($40)|0);
   $phitmp$i = ($41|0)==(0|0);
   if ($phitmp$i) {
    label = 12;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $42 = (__ZN20TextRenderingPrivate4Font18ResetCachedTextureEv($this)|0);
  if (!($42)) {
   $$2 = 0;
   STACKTOP = sp;return ($$2|0);
  }
 }
 HEAP32[$sizes>>2] = 0;
 HEAP32[$styles>>2] = 0;
 $43 = (($formatStack) + 4|0);
 $44 = (($formatStack) + 8|0);
 $45 = (($format) + 4|0);
 $46 = (($this) + 32|0);
 $47 = (($this) + 88|0);
 $48 = (($this) + 84|0);
 $49 = (($this) + 184|0);
 $50 = (($this) + 188|0);
 $51 = (($this) + 196|0);
 $$02 = $chars;$60 = $length;$didAdd$0$off0 = 0;$maxFontSize$0 = 0;
 L21: while(1) {
  HEAP32[$formatStack>>2] = 0;
  HEAP32[$43>>2] = 0;
  HEAP32[$44>>2] = 0;
  $52 = (__Znwj(32)|0);
  $53 = (($52) + 32|0);
  $54 = ($52|0)==(0|0);
  if ($54) {
   $$pre$phi4$iZ2D = (4);$$pre$phi6$iZ2D = (8);$$pre$phi8$iZ2D = 0;
  } else {
   HEAP32[$52>>2] = 0;
   $55 = (($52) + 4|0);
   HEAP32[$55>>2] = -1;
   $56 = (($52) + 8|0);
   $57 = (($52) + 24|0);
   ;HEAP32[$56+0>>2]=0|0;HEAP32[$56+4>>2]=0|0;HEAP32[$56+8>>2]=0|0;HEAP32[$56+12>>2]=0|0;
   HEAPF32[$57>>2] = Math_fround(1.0);
   $58 = (($52) + 28|0);
   HEAPF32[$58>>2] = Math_fround(1.0);
   $$pre$phi4$iZ2D = $55;$$pre$phi6$iZ2D = $56;$$pre$phi8$iZ2D = $52;
  }
  HEAP32[$formatStack>>2] = $52;
  HEAP32[$43>>2] = $53;
  HEAP32[$44>>2] = $53;
  HEAP32[$$pre$phi4$iZ2D>>2] = -1;
  HEAP32[$$pre$phi6$iZ2D>>2] = $size;
  HEAP32[$$pre$phi8$iZ2D>>2] = $style;
  $59 = ($60|0)>(0);
  L26: do {
   if ($59) {
    $didAdd$1$off045 = $didAdd$0$off0;$formatChange$043 = 0;$i$044 = 0;$maxFontSize$142 = $maxFontSize$0;
    while(1) {
     $61 = HEAP32[$45>>2]|0;
     $62 = HEAP32[$format>>2]|0;
     $63 = $61;
     $64 = $62;
     $65 = (($63) - ($64))|0;
     $66 = (($65|0) / 44)&-1;
     $67 = ($formatChange$043>>>0)<($66>>>0);
     L29: do {
      if ($67) {
       $69 = $62;$formatChange$126 = $formatChange$043;$i$127 = $i$044;
       while(1) {
        $68 = (($69) + (($formatChange$126*44)|0)|0);
        $70 = HEAP32[$68>>2]|0;
        $71 = ($i$127|0)<($70|0);
        if ($71) {
         $formatChange$1$lcssa = $formatChange$126;$i$1$lcssa = $i$127;
         break L29;
        }
        $72 = ((($69) + (($formatChange$126*44)|0)|0) + 4|0);
        $73 = HEAP32[$72>>2]|0;
        __THREW__ = 0;
        invoke_vii(3435,($formatStack|0),($68|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 21;
         break L21;
        }
        $76 = (($73) + ($i$127))|0;
        $77 = (($formatChange$126) + 1)|0;
        $78 = HEAP32[$45>>2]|0;
        $79 = HEAP32[$format>>2]|0;
        $80 = $78;
        $81 = $79;
        $82 = (($80) - ($81))|0;
        $83 = (($82|0) / 44)&-1;
        $84 = ($77>>>0)<($83>>>0);
        if ($84) {
         $69 = $79;$formatChange$126 = $77;$i$127 = $76;
        } else {
         $formatChange$1$lcssa = $77;$i$1$lcssa = $76;
         break;
        }
       }
      } else {
       $formatChange$1$lcssa = $formatChange$043;$i$1$lcssa = $i$044;
      }
     } while(0);
     $98 = HEAP32[$2>>2]|0;
     $99 = ($i$1$lcssa|0)<($98|0);
     if (!($99)) {
      $$24 = $$02;$235 = $98;$didAdd$1$off040 = $didAdd$1$off045;$didNotFit$0$off0 = 0;$maxFontSize$3 = $maxFontSize$142;
      label = 54;
      break L26;
     }
     $100 = HEAP32[$43>>2]|0;
     $101 = (($100) + -24|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = (($100) + -32|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = HEAP32[$sizes>>2]|0;
     $106 = ($105|0)==(0|0);
     if ($106) {
      $thisSize$0 = $102;$thisStyle$0 = $104;
     } else {
      $107 = (($105) + ($i$1$lcssa<<2)|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = ($108|0)==(-1);
      if ($109) {
       $thisSize$0 = $102;$thisStyle$0 = $104;
      } else {
       $110 = HEAP32[$styles>>2]|0;
       $111 = (($110) + ($i$1$lcssa<<2)|0);
       $112 = HEAP32[$111>>2]|0;
       $thisSize$0 = $108;$thisStyle$0 = $112;
      }
     }
     $113 = ($thisSize$0|0)==(0);
     if ($113) {
      $114 = HEAP32[$46>>2]|0;
      $thisSize$1 = $114;
     } else {
      $thisSize$1 = $thisSize$0;
     }
     $115 = ($thisSize$1|0)>($maxFontSize$142|0);
     $thisSize$1$maxFontSize$1 = $115 ? $thisSize$1 : $maxFontSize$142;
     $116 = (($$02) + ($i$1$lcssa<<1)|0);
     $117 = HEAP16[$116>>1]|0;
     $118 = $117&65535;
     __THREW__ = 0;
     $119 = (invoke_iii(2607,($this|0),($118|0))|0);
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if ($121) {
      label = 22;
      break L21;
     }
     if ($119) {
      $122 = HEAP16[$116>>1]|0;
      $123 = $122&65535;
      __THREW__ = 0;
      $124 = (invoke_iiiii(276,($this|0),($123|0),($thisSize$1|0),($thisStyle$0|0))|0);
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if ($126) {
       label = 22;
       break L21;
      }
      if ($124) {
       $didAdd$2$off0 = $didAdd$1$off045;
      } else {
       __THREW__ = 0;
       $127 = (invoke_iiiii(277,($this|0),($118|0),($thisSize$1|0),($thisStyle$0|0))|0);
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        label = 22;
        break L21;
       }
       if ($127) {
        $didAdd$2$off0 = 1;
       } else {
        break;
       }
      }
     } else {
      $didAdd$2$off0 = $didAdd$1$off045;
     }
     $195 = (($i$1$lcssa) + 1)|0;
     $196 = ($195|0)<($98|0);
     if ($196) {
      $didAdd$1$off045 = $didAdd$2$off0;$formatChange$043 = $formatChange$1$lcssa;$i$044 = $195;$maxFontSize$142 = $thisSize$1$maxFontSize$1;
     } else {
      $$24 = $$02;$235 = $98;$didAdd$1$off040 = $didAdd$2$off0;$didNotFit$0$off0 = 0;$maxFontSize$3 = $thisSize$1$maxFontSize$1;
      label = 54;
      break L26;
     }
    }
    if ($106) {
     __THREW__ = 0;
     $154 = (invoke_iiiiii(219,($this|0),($$02|0),($2|0),($sizes|0),($styles|0))|0);
     $155 = __THREW__; __THREW__ = 0;
     $156 = $155&1;
     if ($156) {
      label = 23;
      break L21;
     }
     $157 = HEAP32[$2>>2]|0;
     $158 = (+($157|0));
     $159 = HEAP32[$47>>2]|0;
     $160 = HEAP32[$48>>2]|0;
     $161 = $159;
     $162 = $160;
     $163 = (($161) - ($162))|0;
     $164 = (($163|0) / 56)&-1;
     $165 = (+($164>>>0));
     $166 = $165 * 0.800000000000000044408;
     $167 = $158 > $166;
     if ($167) {
      $168 = HEAP32[$49>>2]|0;
      $169 = HEAP32[$50>>2]|0;
      $170 = ($168>>>0)<($169>>>0);
      if ($170) {
       $171 = $168 << 1;
       HEAP32[$49>>2] = $171;
       $190 = $171;
      } else {
       $172 = $169 << 1;
       HEAP32[$50>>2] = $172;
       $190 = $168;
      }
      $173 = $thisSize$1$maxFontSize$1 << 2;
      $174 = (($173) + -1)|0;
      $175 = $174 >>> 16;
      $176 = $175 | $174;
      $177 = $176 >>> 8;
      $178 = $177 | $176;
      $179 = $178 >>> 4;
      $180 = $179 | $178;
      $181 = $180 >>> 2;
      $182 = $181 | $180;
      $183 = $182 >>> 1;
      $184 = $183 | $182;
      $185 = (($184) + 1)|0;
      $186 = HEAP32[$51>>2]|0;
      $187 = ($186>>>0)<($185>>>0);
      $188 = $187 ? $185 : $186;
      $189 = ($190>>>0)<($188>>>0);
      $191 = $189 ? $190 : $188;
      HEAP32[$51>>2] = $191;
      $$13 = $154;$236 = $157;
     } else {
      $$13 = $154;$236 = $157;
     }
    } else {
     $130 = HEAP32[$49>>2]|0;
     $131 = HEAP32[$50>>2]|0;
     $132 = ($130>>>0)<($131>>>0);
     if ($132) {
      $133 = $130 << 1;
      HEAP32[$49>>2] = $133;
      $152 = $133;
     } else {
      $134 = $131 << 1;
      HEAP32[$50>>2] = $134;
      $152 = $130;
     }
     $135 = $thisSize$1$maxFontSize$1 << 2;
     $136 = (($135) + -1)|0;
     $137 = $136 >>> 16;
     $138 = $137 | $136;
     $139 = $138 >>> 8;
     $140 = $139 | $138;
     $141 = $140 >>> 4;
     $142 = $141 | $140;
     $143 = $142 >>> 2;
     $144 = $143 | $142;
     $145 = $144 >>> 1;
     $146 = $145 | $144;
     $147 = (($146) + 1)|0;
     $148 = HEAP32[$51>>2]|0;
     $149 = ($148>>>0)<($147>>>0);
     $150 = $149 ? $147 : $148;
     $151 = ($152>>>0)<($150>>>0);
     $153 = $151 ? $152 : $150;
     HEAP32[$51>>2] = $153;
     $$13 = $$02;$236 = $98;
    }
    __THREW__ = 0;
    $192 = (invoke_ii(3413,($this|0))|0);
    $193 = __THREW__; __THREW__ = 0;
    $194 = $193&1;
    if ($194) {
     label = 23;
     break L21;
    }
    if ($192) {
     $$24 = $$13;$235 = $236;$didAdd$1$off040 = $didAdd$1$off045;$didNotFit$0$off0 = 1;$maxFontSize$3 = $thisSize$1$maxFontSize$1;
     label = 54;
    } else {
     $$0 = 1;$$3 = $$13;$237 = $236;$didAdd$1$off039 = $didAdd$1$off045;$didNotFit$1$off0 = 1;$maxFontSize$4 = $thisSize$1$maxFontSize$1;
    }
   } else {
    $$24 = $$02;$235 = $60;$didAdd$1$off040 = $didAdd$0$off0;$didNotFit$0$off0 = 0;$maxFontSize$3 = $maxFontSize$0;
    label = 54;
   }
  } while(0);
  if ((label|0) == 54) {
   label = 0;
   $$0 = 0;$$3 = $$24;$237 = $235;$didAdd$1$off039 = $didAdd$1$off040;$didNotFit$1$off0 = $didNotFit$0$off0;$maxFontSize$4 = $maxFontSize$3;
  }
  $197 = HEAP32[$formatStack>>2]|0;
  $198 = ($197|0)==(0|0);
  if (!($198)) {
   $199 = HEAP32[$43>>2]|0;
   $200 = ($199|0)==($197|0);
   if (!($200)) {
    $__new_last2$i$i$i$i$i$i11 = $197;
    $scevgep$i$i$i$i$i$i12 = (($199) + -32|0);
    $201 = (0 - ($__new_last2$i$i$i$i$i$i11))|0;
    $uglygep$i$i$i$i$i$i14 = (($scevgep$i$i$i$i$i$i12) + ($201)|0);
    $uglygep3$i$i$i$i$i$i15 = $uglygep$i$i$i$i$i$i14;
    $202 = $uglygep3$i$i$i$i$i$i15 >>> 5;
    $203 = $202 ^ -1;
    $scevgep4$i$i$i$i$i$i16 = (($199) + ($203<<5)|0);
    HEAP32[$43>>2] = $scevgep4$i$i$i$i$i$i16;
   }
   __ZdlPv($197);
  }
  if ($$0) {
   $$2 = 0;
   label = 71;
   break;
  }
  if ($didNotFit$1$off0) {
   $$02 = $$3;$60 = $237;$didAdd$0$off0 = $didAdd$1$off039;$maxFontSize$0 = $maxFontSize$4;
  } else {
   label = 61;
   break;
  }
 }
 if ((label|0) == 21) {
  $85 = ___cxa_find_matching_catch()|0;
  $86 = tempRet0;
  $lpad$phi$index = $85;$lpad$phi$index3 = $86;
 }
 else if ((label|0) == 22) {
  $87 = ___cxa_find_matching_catch()|0;
  $88 = tempRet0;
  $lpad$phi$index = $87;$lpad$phi$index3 = $88;
 }
 else if ((label|0) == 23) {
  $89 = ___cxa_find_matching_catch()|0;
  $90 = tempRet0;
  $lpad$phi$index = $89;$lpad$phi$index3 = $90;
 }
 else if ((label|0) == 61) {
  $didAdd$1$off0$not = $didAdd$1$off039 ^ 1;
  $204 = HEAP8[((640792 + 259|0))>>0]|0;
  $205 = ($204<<24>>24)==(0);
  $or$cond = $205 | $didAdd$1$off0$not;
  if (!($or$cond)) {
   $206 = (__Z17dynamic_pptr_castIP9Texture2D7TextureET_RK4PPtrIT0_E($6)|0);
   $207 = HEAP32[$206>>2]|0;
   $208 = (($207) + 152|0);
   $209 = HEAP32[$208>>2]|0;
   FUNCTION_TABLE_vi[$209 & 4095]($206);
  }
  $210 = HEAP32[$sizes>>2]|0;
  $211 = ($210|0)==(0|0);
  if ($211) {
   $$2 = 1;
   STACKTOP = sp;return ($$2|0);
  }
  $212 = ($$3|0)==(0|0);
  if (!($212)) {
   __ZdaPv($$3);
  }
  __ZdaPv($210);
  $213 = HEAP32[$styles>>2]|0;
  $214 = ($213|0)==(0|0);
  if (!($214)) {
   __ZdaPv($213);
  }
  $215 = HEAP32[804384>>2]|0;
  $216 = (($215) + 1)|0;
  HEAP32[804384>>2] = $216;
  __Z13ApplyToMeshesv();
  $217 = HEAP32[804384>>2]|0;
  $218 = (($217) + -1)|0;
  HEAP32[804384>>2] = $218;
  $219 = ($218|0)==(0);
  if (!($219)) {
   $$2 = 1;
   STACKTOP = sp;return ($$2|0);
  }
  $220 = (__ZN9Scripting19ScriptingWrapperForEP6Object($this)|0);
  $221 = ($220|0)==(0|0);
  if ($221) {
   $$2 = 1;
   STACKTOP = sp;return ($$2|0);
  }
  $222 = (__Z19GetScriptingManagerv()|0);
  $223 = (($222) + 232|0);
  $224 = $223;
  $225 = $224;
  $226 = HEAP32[$225>>2]|0;
  $227 = (($224) + 4)|0;
  $228 = $227;
  $229 = HEAP32[$228>>2]|0;
  $230 = $0;
  $231 = $230;
  HEAP32[$231>>2] = $226;
  $232 = (($230) + 4)|0;
  $233 = $232;
  HEAP32[$233>>2] = $229;
  ;HEAP32[$tmpcast$i$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$i$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($invocation$i,$tmpcast$i$byval_copy);
  $234 = (($invocation$i) + 12|0);
  HEAP32[$234>>2] = $220;
  (__ZN19ScriptingInvocation6InvokeEv($invocation$i)|0);
  $$2 = 1;
  STACKTOP = sp;return ($$2|0);
 }
 else if ((label|0) == 71) {
  STACKTOP = sp;return ($$2|0);
 }
 $91 = HEAP32[$formatStack>>2]|0;
 $92 = ($91|0)==(0|0);
 if ($92) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $93 = HEAP32[$43>>2]|0;
 $94 = ($93|0)==($91|0);
 if (!($94)) {
  $__new_last2$i$i$i$i$i$i = $91;
  $scevgep$i$i$i$i$i$i = (($93) + -32|0);
  $95 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($95)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $96 = $uglygep3$i$i$i$i$i$i >>> 5;
  $97 = $96 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($93) + ($97<<5)|0);
  HEAP32[$43>>2] = $scevgep4$i$i$i$i$i$i;
 }
 __ZdlPv($91);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN20TextRenderingPrivate11FormatStack10PushFormatERNS_16TextFormatChangeE($this,$change) {
 $this = $this|0;
 $change = $change|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0;
 var $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($change) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32768;
 $3 = ($2|0)==(0);
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -32|0);
 if (!($3)) {
  $__new_last2$i$i$i = $6;
  $scevgep$i$i$i = (($5) + -32|0);
  $7 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($7)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $8 = $uglygep3$i$i$i >>> 5;
  $9 = $8 ^ -1;
  $scevgep4$i$i$i = (($5) + ($9<<5)|0);
  HEAP32[$4>>2] = $scevgep4$i$i$i;
  STACKTOP = sp;return;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)==($11|0);
 if ($12) {
  $16 = HEAP32[$this>>2]|0;
  $17 = $5;
  $18 = $16;
  $19 = (($17) - ($18))|0;
  $20 = $19 >> 5;
  $21 = (($20) + 1)|0;
  $22 = ($21>>>0)>(134217727);
  if ($22) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $23 = ($20>>>0)<(67108863);
  if ($23) {
   $24 = $19 >> 4;
   $25 = ($24>>>0)<($21>>>0);
   $26 = $25 ? $21 : $24;
   $27 = ($26|0)==(0);
   if ($27) {
    $$0$i3$i$i = 0;$31 = 0;
   } else {
    $$0$i2$i$i = $26;
    label = 11;
   }
  } else {
   $$0$i2$i$i = 134217727;
   label = 11;
  }
  if ((label|0) == 11) {
   $28 = $$0$i2$i$i << 5;
   $29 = (__Znwj($28)|0);
   $$0$i3$i$i = $$0$i2$i$i;$31 = $29;
  }
  $30 = (($31) + ($20<<5)|0);
  $32 = (($31) + ($$0$i3$i$i<<5)|0);
  $33 = ($30|0)==(0|0);
  if (!($33)) {
   ;HEAP32[$30+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$30+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$30+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$30+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$30+28>>2]=HEAP32[$6+28>>2]|0;
  }
  $34 = (($31) + ($21<<5)|0);
  _memcpy(($31|0),($16|0),($19|0))|0;
  HEAP32[$this>>2] = $31;
  HEAP32[$4>>2] = $34;
  HEAP32[$10>>2] = $32;
  $35 = ($16|0)==(0|0);
  if (!($35)) {
   __ZdlPv($16);
  }
 } else {
  $13 = ($5|0)==(0|0);
  if ($13) {
   $15 = 0;
  } else {
   ;HEAP32[$5+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$5+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$5+24>>2]=HEAP32[$6+24>>2]|0;HEAP32[$5+28>>2]=HEAP32[$6+28>>2]|0;
   $$pre$i = HEAP32[$4>>2]|0;
   $15 = $$pre$i;
  }
  $14 = (($15) + 32|0);
  HEAP32[$4>>2] = $14;
 }
 $36 = HEAP32[$0>>2]|0;
 $37 = $36 & 1;
 $38 = ($37|0)==(0);
 if ($38) {
  $44 = $36;
 } else {
  $39 = HEAP32[$4>>2]|0;
  $40 = (($39) + -32|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = $41 | 1;
  HEAP32[$40>>2] = $42;
  $$pre = HEAP32[$0>>2]|0;
  $44 = $$pre;
 }
 $43 = $44 & 2;
 $45 = ($43|0)==(0);
 if ($45) {
  $51 = $44;
 } else {
  $46 = HEAP32[$4>>2]|0;
  $47 = (($46) + -32|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = $48 | 2;
  HEAP32[$47>>2] = $49;
  $$pre1 = HEAP32[$0>>2]|0;
  $51 = $$pre1;
 }
 $50 = $51 & 4;
 $52 = ($50|0)==(0);
 if ($52) {
  $58 = $51;
 } else {
  $53 = HEAP32[$4>>2]|0;
  $54 = (($53) + -28|0);
  $55 = (($change) + 12|0);
  $56 = HEAP32[$55>>2]|0;
  HEAP32[$54>>2] = $56;
  $$pre2 = HEAP32[$0>>2]|0;
  $58 = $$pre2;
 }
 $57 = $58 & 8;
 $59 = ($57|0)==(0);
 if ($59) {
  $65 = $58;
 } else {
  $60 = (($change) + 16|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = HEAP32[$4>>2]|0;
  $63 = (($62) + -24|0);
  HEAP32[$63>>2] = $61;
  $$pre3 = HEAP32[$0>>2]|0;
  $65 = $$pre3;
 }
 $64 = $65 & 16;
 $66 = ($64|0)==(0);
 if ($66) {
  STACKTOP = sp;return;
 }
 $67 = (($change) + 20|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = HEAP32[$4>>2]|0;
 $70 = (($69) + -20|0);
 HEAP32[$70>>2] = $68;
 STACKTOP = sp;return;
}
function __ZNK20TextRenderingPrivate4Font22GetFontSizeFromSpacingEf($this,$spacing) {
 $this = $this|0;
 $spacing = Math_fround($spacing);
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (Math_fround(($1|0)));
 $3 = Math_fround($2 * $spacing);
 $4 = (($this) + 28|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = Math_fround($3 / $5);
 STACKTOP = sp;return (Math_fround($6));
}
function __ZN20TextRenderingPrivate4Font34GetNumCharactersThatFitWithinWidthERK11UTF16Stringfij($this,$text,$width,$size,$style) {
 $this = $this|0;
 $text = $text|0;
 $width = Math_fround($width);
 $size = $size|0;
 $style = $style|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i1 = 0, $currentWidth$011 = Math_fround(0);
 var $i$010 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i2 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i6 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i4 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$text>>2]|0;
 $2 = (($text) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = 0;
 $4 = (($0) + 4|0);
 HEAP32[$4>>2] = 0;
 $5 = (($0) + 8|0);
 HEAP32[$5>>2] = 0;
 __THREW__ = 0;
 (invoke_iiiiiii(124,($this|0),($1|0),($3|0),0,0,($0|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $27 = HEAP32[$0>>2]|0;
  $28 = ($27|0)==(0|0);
  if ($28) {
   ___resumeException($25|0);
   // unreachable;
  }
  $29 = HEAP32[$4>>2]|0;
  $30 = ($29|0)==($27|0);
  if (!($30)) {
   $__new_last2$i$i$i$i$i = $27;
   $scevgep$i$i$i$i$i = (($29) + -44|0);
   $31 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($31)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $32 = (($uglygep3$i$i$i$i$i>>>0) / 44)&-1;
   $33 = $32 ^ -1;
   $scevgep4$i$i$i$i$i = (($29) + (($33*44)|0)|0);
   HEAP32[$4>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($27);
  ___resumeException($25|0);
  // unreachable;
 }
 $8 = HEAP32[$0>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$4>>2]|0;
  $11 = ($10|0)==($8|0);
  if (!($11)) {
   $__new_last2$i$i$i$i$i1 = $8;
   $scevgep$i$i$i$i$i2 = (($10) + -44|0);
   $12 = (0 - ($__new_last2$i$i$i$i$i1))|0;
   $uglygep$i$i$i$i$i4 = (($scevgep$i$i$i$i$i2) + ($12)|0);
   $uglygep3$i$i$i$i$i5 = $uglygep$i$i$i$i$i4;
   $13 = (($uglygep3$i$i$i$i$i5>>>0) / 44)&-1;
   $14 = $13 ^ -1;
   $scevgep4$i$i$i$i$i6 = (($10) + (($14*44)|0)|0);
   HEAP32[$4>>2] = $scevgep4$i$i$i$i$i6;
  }
  __ZdlPv($8);
 }
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $currentWidth$011 = Math_fround(0.0);$i$010 = 0;
 }
 while(1) {
  $19 = HEAP32[$text>>2]|0;
  $20 = (($19) + ($i$010<<1)|0);
  $21 = HEAP16[$20>>1]|0;
  $22 = $21&65535;
  $23 = (Math_fround(__ZNK20TextRenderingPrivate4Font17GetCharacterWidthEjij($this,$22,$size,$style)));
  $24 = $23 == Math_fround(0.0);
  if ($24) {
   $$0 = -1;
   label = 14;
   break;
  }
  $34 = Math_fround($currentWidth$011 + $23);
  $35 = $34 > $width;
  $18 = (($i$010) + 1)|0;
  if ($35) {
   $$0 = $i$010;
   label = 14;
   break;
  }
  $17 = ($18>>>0)<($15>>>0);
  if ($17) {
   $currentWidth$011 = $34;$i$010 = $18;
  } else {
   $$0 = $15;
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z18RegisterClass_Fontv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(128,256,257,0,258);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(130)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN11NamedObject13RegisterClassEv();
 }
 HEAP8[$0>>0] = 8;
 $3 = (($0) + 1|0);
 HEAP8[$3>>0]=1953394502&255;HEAP8[$3+1>>0]=(1953394502>>8)&255;HEAP8[$3+2>>0]=(1953394502>>16)&255;HEAP8[$3+3>>0]=1953394502>>24;
 $4 = (($0) + 5|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,128,130,($0|0),220,(2608|0),0,0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate4Font7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(220,$$byval_copy2,1,16,804096,90)|0);
 HEAP32[$1>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(2045,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  STACKTOP = sp;return ($3|0);
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(804096|0),90);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch(0|0)|0;
  $11 = tempRet0;
  ___clang_call_terminate($10);
  // unreachable;
 } else {
  ___resumeException($6|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK20TextRenderingPrivate4Font25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 128;
}
function __ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804400,804392,$this,0);
 __ZN20TextRenderingPrivate4Font8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804400,804392,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN20TextRenderingPrivate4Font8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate4Font8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate4Font8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate4Font8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate4Font8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4FontD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate4FontD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4FontD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3725,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate4Font8TransferI17RemapPPtrTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN11NamedObject8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  HEAP32[$0>>2] = $8;
 }
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
 $12 = (($this) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$6>>2]|0;
 $18 = (FUNCTION_TABLE_iiii[$16 & 2047]($14,$13,$17)|0);
 $19 = HEAP8[$9>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  HEAP32[$12>>2] = $18;
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 $21 = (($this) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (Math_fround(($22|0)));
 $24 = (~~(($23)));
 HEAP32[$21>>2] = $24;
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,1);
 $25 = (($this) + 144|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 148|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($26|0)==($28|0);
 if ($29) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  STACKTOP = sp;return;
 } else {
  $31 = $26;
 }
 while(1) {
  $30 = HEAP32[$31>>2]|0;
  $32 = HEAP32[$2>>2]|0;
  $33 = HEAP32[$32>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = HEAP32[$6>>2]|0;
  $36 = (FUNCTION_TABLE_iiii[$34 & 2047]($32,$30,$35)|0);
  $37 = HEAP8[$9>>0]|0;
  $38 = ($37<<24>>24)==(0);
  if (!($38)) {
   HEAP32[$31>>2] = $36;
  }
  $39 = (($31) + 4|0);
  $40 = ($39|0)==($28|0);
  if ($40) {
   break;
  } else {
   $31 = $39;
  }
 }
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $$pre42 = 0, $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $fontSize = 0, $size$i$i$i = 0, $size$i$i$i29 = 0, $size$i$i$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size$i$i$i29 = sp + 12|0;
 $size$i$i$i7 = sp;
 $size$i$i$i = sp + 4|0;
 $fontSize = sp + 8|0;
 __ZN11NamedObject8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 72|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
  $10 = $3;$12 = $5;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre32 = HEAP32[$4>>2]|0;
  $10 = $$pre;$12 = $$pre32;
 }
 $8 = (($this) + 60|0);
 $9 = (($10) + 4|0);
 $11 = ($9>>>0)<($12>>>0);
 if ($11) {
  $13 = Math_fround(HEAPF32[$8>>2]);
  HEAPF32[$10>>2] = $13;
  HEAP32[$1>>2] = $9;
  $16 = $9;$18 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$8,4);
  $$pre33 = HEAP32[$1>>2]|0;
  $$pre34 = HEAP32[$4>>2]|0;
  $16 = $$pre33;$18 = $$pre34;
 }
 $14 = (($this) + 28|0);
 $15 = (($16) + 4|0);
 $17 = ($15>>>0)<($18>>>0);
 if ($17) {
  $19 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$16>>2] = $19;
  HEAP32[$1>>2] = $15;
  $22 = $15;$24 = $18;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$14,4);
  $$pre35 = HEAP32[$1>>2]|0;
  $$pre36 = HEAP32[$4>>2]|0;
  $22 = $$pre35;$24 = $$pre36;
 }
 $20 = (($this) + 64|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)<($24>>>0);
 if ($23) {
  $25 = HEAP32[$20>>2]|0;
  HEAP32[$22>>2] = $25;
  HEAP32[$1>>2] = $21;
  $28 = $21;$30 = $24;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$20,4);
  $$pre37 = HEAP32[$1>>2]|0;
  $$pre38 = HEAP32[$4>>2]|0;
  $28 = $$pre37;$30 = $$pre38;
 }
 $26 = (($this) + 68|0);
 $27 = (($28) + 4|0);
 $29 = ($27>>>0)<($30>>>0);
 if ($29) {
  $31 = HEAP32[$26>>2]|0;
  HEAP32[$28>>2] = $31;
  HEAP32[$1>>2] = $27;
  $34 = $27;$36 = $30;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$26,4);
  $$pre39 = HEAP32[$1>>2]|0;
  $$pre40 = HEAP32[$4>>2]|0;
  $34 = $$pre39;$36 = $$pre40;
 }
 $32 = (($this) + 76|0);
 $33 = (($34) + 4|0);
 $35 = ($33>>>0)<($36>>>0);
 if ($35) {
  $37 = HEAP32[$32>>2]|0;
  HEAP32[$34>>2] = $37;
  HEAP32[$1>>2] = $33;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$32,4);
 }
 $38 = (($this) + 36|0);
 __ZN4PPtrIN5Unity8MaterialEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($38,$transfer);
 $39 = HEAP32[$32>>2]|0;
 $40 = ($39|0)==(-2);
 do {
  if ($40) {
   HEAP32[$size$i$i$i7>>2] = 0;
   $59 = HEAP32[$1>>2]|0;
   $60 = (($59) + 4|0);
   $61 = HEAP32[$4>>2]|0;
   $62 = ($60>>>0)<($61>>>0);
   if ($62) {
    HEAP32[$59>>2] = 0;
    HEAP32[$1>>2] = $60;
    break;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i7,4);
    break;
   }
  } else {
   $41 = (($this) + 88|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($this) + 84|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = $42;
   $46 = $44;
   $47 = (($45) - ($46))|0;
   $48 = (($47|0) / 56)&-1;
   HEAP32[$size$i$i$i>>2] = $48;
   $49 = HEAP32[$1>>2]|0;
   $50 = (($49) + 4|0);
   $51 = HEAP32[$4>>2]|0;
   $52 = ($50>>>0)<($51>>>0);
   if ($52) {
    HEAP32[$49>>2] = $48;
    HEAP32[$1>>2] = $50;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i,4);
   }
   $53 = HEAP32[$41>>2]|0;
   $54 = HEAP32[$43>>2]|0;
   $55 = ($54|0)==($53|0);
   if (!($55)) {
    $56 = $54;
    while(1) {
     __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI19StreamedBinaryWriteILb0EEEEvRT_($56,$transfer);
     $57 = (($56) + 56|0);
     $58 = ($57|0)==($53|0);
     if ($58) {
      break;
     } else {
      $56 = $57;
     }
    }
   }
  }
 } while(0);
 $63 = (($this) + 40|0);
 __ZN4PPtrI7TextureE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($63,$transfer);
 $64 = (($this) + 44|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI10vector_mapINSt3__14pairIttEEfN20TextRenderingPrivate4Font14KerningCompareENS3_9allocatorINS4_IS5_fEEEEEEEvRT_17TransferMetaFlags($transfer,$64,0);
 $65 = (($this) + 80|0);
 $66 = HEAP32[$1>>2]|0;
 $67 = (($66) + 4|0);
 $68 = HEAP32[$4>>2]|0;
 $69 = ($67>>>0)<($68>>>0);
 if ($69) {
  $70 = Math_fround(HEAPF32[$65>>2]);
  HEAPF32[$66>>2] = $70;
  HEAP32[$1>>2] = $67;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$65,4);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $71 = (($this) + 124|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = (($this) + 120|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = $72;
 $76 = $74;
 $77 = (($75) - ($76))|0;
 HEAP32[$size$i$i$i29>>2] = $77;
 $78 = HEAP32[$1>>2]|0;
 $79 = (($78) + 4|0);
 $80 = HEAP32[$4>>2]|0;
 $81 = ($79>>>0)<($80>>>0);
 if ($81) {
  HEAP32[$78>>2] = $77;
  HEAP32[$1>>2] = $79;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i29,4);
 }
 $82 = HEAP32[$71>>2]|0;
 $83 = HEAP32[$73>>2]|0;
 $84 = ($83|0)==($82|0);
 if (!($84)) {
  $90 = $83;
  while(1) {
   $85 = HEAP32[$1>>2]|0;
   $86 = (($85) + 1|0);
   $87 = HEAP32[$4>>2]|0;
   $88 = ($86>>>0)<($87>>>0);
   if ($88) {
    $89 = HEAP8[$90>>0]|0;
    HEAP8[$85>>0] = $89;
    $91 = HEAP32[$1>>2]|0;
    $92 = (($91) + 1|0);
    HEAP32[$1>>2] = $92;
   } else {
    __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$90,1);
   }
   $93 = (($90) + 1|0);
   $94 = ($93|0)==($82|0);
   if ($94) {
    break;
   } else {
    $90 = $93;
   }
  }
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $95 = (($this) + 32|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = (Math_fround(($96|0)));
 HEAPF32[$fontSize>>2] = $97;
 $98 = HEAP32[$1>>2]|0;
 $99 = (($98) + 4|0);
 $100 = HEAP32[$4>>2]|0;
 $101 = ($99>>>0)<($100>>>0);
 if ($101) {
  HEAPF32[$98>>2] = $97;
  HEAP32[$1>>2] = $99;
  $106 = $99;$108 = $100;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$fontSize,4);
  $$pre41 = HEAP32[$1>>2]|0;
  $$pre42 = HEAP32[$4>>2]|0;
  $106 = $$pre41;$108 = $$pre42;
 }
 $102 = Math_fround(HEAPF32[$fontSize>>2]);
 $103 = (~~(($102)));
 HEAP32[$95>>2] = $103;
 $104 = (($this) + 208|0);
 $105 = (($106) + 4|0);
 $107 = ($105>>>0)<($108>>>0);
 if ($107) {
  $109 = Math_fround(HEAPF32[$104>>2]);
  HEAPF32[$106>>2] = $109;
  HEAP32[$1>>2] = $105;
  $112 = $105;$114 = $108;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$104,4);
  $$pre43 = HEAP32[$1>>2]|0;
  $$pre44 = HEAP32[$4>>2]|0;
  $112 = $$pre43;$114 = $$pre44;
 }
 $110 = (($this) + 204|0);
 $111 = (($112) + 4|0);
 $113 = ($111>>>0)<($114>>>0);
 if ($113) {
  $115 = HEAP32[$110>>2]|0;
  HEAP32[$112>>2] = $115;
  HEAP32[$1>>2] = $111;
  $125 = $111;$127 = $114;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$110,4);
  $$pre45 = HEAP32[$1>>2]|0;
  $$pre46 = HEAP32[$4>>2]|0;
  $125 = $$pre45;$127 = $$pre46;
 }
 $116 = (($this) + 136|0);
 $117 = HEAP32[$116>>2]|0;
 $118 = (($this) + 132|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = $117;
 $121 = $119;
 $122 = (($120) - ($121))|0;
 $123 = (($122|0) / 12)&-1;
 HEAP32[$size$i$i$i29>>2] = $123;
 $124 = (($125) + 4|0);
 $126 = ($124>>>0)<($127>>>0);
 if ($126) {
  HEAP32[$125>>2] = $123;
  HEAP32[$1>>2] = $124;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i29,4);
 }
 $128 = HEAP32[$116>>2]|0;
 $129 = HEAP32[$118>>2]|0;
 $130 = ($129|0)==($128|0);
 if (!($130)) {
  $131 = $129;
  while(1) {
   __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$131,0);
   __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
   $132 = (($131) + 12|0);
   $133 = ($132|0)==($128|0);
   if ($133) {
    break;
   } else {
    $131 = $132;
   }
  }
 }
 $134 = (($this) + 148|0);
 $135 = HEAP32[$134>>2]|0;
 $136 = (($this) + 144|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = $135;
 $139 = $137;
 $140 = (($138) - ($139))|0;
 $141 = $140 >> 2;
 HEAP32[$size$i$i$i29>>2] = $141;
 $142 = HEAP32[$1>>2]|0;
 $143 = (($142) + 4|0);
 $144 = HEAP32[$4>>2]|0;
 $145 = ($143>>>0)<($144>>>0);
 if ($145) {
  HEAP32[$142>>2] = $141;
  HEAP32[$1>>2] = $143;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$size$i$i$i29,4);
 }
 $146 = HEAP32[$134>>2]|0;
 $147 = HEAP32[$136>>2]|0;
 $148 = ($147|0)==($146|0);
 if (!($148)) {
  $149 = $147;
  while(1) {
   __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($149,$transfer);
   $150 = (($149) + 4|0);
   $151 = ($150|0)==($146|0);
   if ($151) {
    break;
   } else {
    $149 = $150;
   }
  }
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $152 = (($this) + 212|0);
 $153 = HEAP32[$1>>2]|0;
 $154 = (($153) + 4|0);
 $155 = HEAP32[$4>>2]|0;
 $156 = ($154>>>0)<($155>>>0);
 if ($156) {
  $157 = HEAP32[$152>>2]|0;
  HEAP32[$153>>2] = $157;
  HEAP32[$1>>2] = $154;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$152,4);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI10vector_mapINSt3__14pairIttEEfN20TextRenderingPrivate4Font14KerningCompareENS3_9allocatorINS4_IS5_fEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre1$i$i = 0, $$pre2$i$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp;
 $1 = (($data) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($data) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 HEAP32[$size>>2] = $8;
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = (($this) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11>>>0)<($13>>>0);
 if ($14) {
  HEAP32[$10>>2] = $8;
  HEAP32[$9>>2] = $11;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$size,4);
 }
 $15 = HEAP32[$1>>2]|0;
 $16 = HEAP32[$3>>2]|0;
 $17 = ($16|0)==($15|0);
 if ($17) {
  STACKTOP = sp;return;
 } else {
  $23 = $16;
 }
 while(1) {
  $18 = HEAP32[$9>>2]|0;
  $19 = (($18) + 2|0);
  $20 = HEAP32[$12>>2]|0;
  $21 = ($19>>>0)<($20>>>0);
  if ($21) {
   $22 = HEAP16[$23>>1]|0;
   HEAP16[$18>>1] = $22;
   HEAP32[$9>>2] = $19;
   $26 = $19;$28 = $20;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$23,2);
   $$pre$i$i$i$i = HEAP32[$9>>2]|0;
   $$pre2$i$i$i$i = HEAP32[$12>>2]|0;
   $26 = $$pre$i$i$i$i;$28 = $$pre2$i$i$i$i;
  }
  $24 = (($23) + 2|0);
  $25 = (($26) + 2|0);
  $27 = ($25>>>0)<($28>>>0);
  if ($27) {
   $29 = HEAP16[$24>>1]|0;
   HEAP16[$26>>1] = $29;
   HEAP32[$9>>2] = $25;
   $32 = $25;$34 = $28;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$24,2);
   $$pre$i$i = HEAP32[$9>>2]|0;
   $$pre1$i$i = HEAP32[$12>>2]|0;
   $32 = $$pre$i$i;$34 = $$pre1$i$i;
  }
  $30 = (($23) + 4|0);
  $31 = (($32) + 4|0);
  $33 = ($31>>>0)<($34>>>0);
  if ($33) {
   $35 = Math_fround(HEAPF32[$30>>2]);
   HEAPF32[$32>>2] = $35;
   HEAP32[$9>>2] = $31;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$30,4);
  }
  $36 = (($23) + 8|0);
  $37 = ($36|0)==($15|0);
  if ($37) {
   break;
  } else {
   $23 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  HEAP32[$1>>2] = $6;
  HEAP32[$0>>2] = $2;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$this,4);
 }
 $7 = (($this) + 4|0);
 __ZN5RectTIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($7,$transfer);
 $8 = (($this) + 20|0);
 __ZN5RectTIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 36|0);
 $10 = HEAP32[$0>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($11>>>0)<($12>>>0);
 if ($13) {
  $14 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$10>>2] = $14;
  HEAP32[$0>>2] = $11;
  $17 = $11;$19 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$9,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre1 = HEAP32[$3>>2]|0;
  $17 = $$pre;$19 = $$pre1;
 }
 $15 = (($this) + 52|0);
 $16 = (($17) + 1|0);
 $18 = ($16>>>0)<($19>>>0);
 if ($18) {
  $20 = HEAP8[$15>>0]|0;
  HEAP8[$17>>0] = $20;
  $21 = HEAP32[$0>>2]|0;
  $22 = (($21) + 1|0);
  HEAP32[$0>>2] = $22;
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($0,$15,1);
  __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate4Font8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i12 = 0, $$pre$i$i$i14 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i27 = 0, $$pre$i$i$i32 = 0, $$pre$i$i$i37 = 0, $$pre$i$i$i4 = 0, $$pre$i$i$i40 = 0, $$pre$i$i$i7 = 0, $$pre$phi$i$i$i28Z2D = 0, $$pre$phi$i$i$i33Z2D = 0, $$pre$phi$i$i$i38Z2D = 0, $$pre$phi$i$i$i8Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre41 = 0, $$pre42 = 0;
 var $$pre43 = 0, $$pre44 = 0, $$pre45 = 0, $$pre46 = 0, $$pre47 = 0, $$pre48 = 0, $$pre49 = 0, $$pre50 = 0, $$pre51 = 0, $$pre52 = 0, $$pre53 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0;
 var $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0), $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i16 = 0, $emptyCharacterInfo = 0, $fontSize = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i17 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i21 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i20 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $emptyCharacterInfo = sp + 4|0;
 $fontSize = sp + 16|0;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $1 = (($this) + 72|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre$i$i$i2 = HEAP32[$1>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre41 = HEAP32[$5>>2]|0;
  $13 = $$pre;$15 = $$pre41;$9 = $$pre$i$i$i2;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $13 = $4;$15 = $6;$9 = $8;
 }
 $10 = (_llvm_bswap_i32(($9|0))|0);
 HEAP32[$1>>2] = $10;
 $11 = (($this) + 60|0);
 $12 = (($13) + 4|0);
 $14 = ($12>>>0)>($15>>>0);
 if ($14) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$11,4);
  $$pre$i$i$i4 = HEAP32[$11>>2]|0;
  $$pre42 = HEAP32[$2>>2]|0;
  $$pre43 = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$iZ2D = $11;$18 = $$pre$i$i$i4;$22 = $$pre42;$24 = $$pre43;
 } else {
  $16 = Math_fround(HEAPF32[$13>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$2>>2] = $12;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $11;$18 = $17;$22 = $12;$24 = $15;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $19;
 $20 = (($this) + 28|0);
 $21 = (($22) + 4|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$20,4);
  $$pre$i$i$i7 = HEAP32[$20>>2]|0;
  $$pre44 = HEAP32[$2>>2]|0;
  $$pre45 = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$i8Z2D = $20;$27 = $$pre$i$i$i7;$31 = $$pre44;$33 = $$pre45;
 } else {
  $25 = Math_fround(HEAPF32[$22>>2]);
  HEAPF32[$20>>2] = $25;
  HEAP32[$2>>2] = $21;
  $26 = (HEAPF32[tempDoublePtr>>2]=$25,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i8Z2D = $20;$27 = $26;$31 = $21;$33 = $24;
 }
 $28 = (_llvm_bswap_i32(($27|0))|0);
 HEAP32[$$pre$phi$i$i$i8Z2D>>2] = $28;
 $29 = (($this) + 64|0);
 $30 = (($31) + 4|0);
 $32 = ($30>>>0)>($33>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$29,4);
  $$pre$i$i$i10 = HEAP32[$29>>2]|0;
  $$pre46 = HEAP32[$2>>2]|0;
  $$pre47 = HEAP32[$5>>2]|0;
  $35 = $$pre$i$i$i10;$39 = $$pre46;$41 = $$pre47;
 } else {
  $34 = HEAP32[$31>>2]|0;
  HEAP32[$29>>2] = $34;
  HEAP32[$2>>2] = $30;
  $35 = $34;$39 = $30;$41 = $33;
 }
 $36 = (_llvm_bswap_i32(($35|0))|0);
 HEAP32[$29>>2] = $36;
 $37 = (($this) + 68|0);
 $38 = (($39) + 4|0);
 $40 = ($38>>>0)>($41>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$37,4);
  $$pre$i$i$i12 = HEAP32[$37>>2]|0;
  $$pre48 = HEAP32[$2>>2]|0;
  $$pre49 = HEAP32[$5>>2]|0;
  $43 = $$pre$i$i$i12;$47 = $$pre48;$49 = $$pre49;
 } else {
  $42 = HEAP32[$39>>2]|0;
  HEAP32[$37>>2] = $42;
  HEAP32[$2>>2] = $38;
  $43 = $42;$47 = $38;$49 = $41;
 }
 $44 = (_llvm_bswap_i32(($43|0))|0);
 HEAP32[$37>>2] = $44;
 $45 = (($this) + 76|0);
 $46 = (($47) + 4|0);
 $48 = ($46>>>0)>($49>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$45,4);
  $$pre$i$i$i14 = HEAP32[$45>>2]|0;
  $51 = $$pre$i$i$i14;
 } else {
  $50 = HEAP32[$47>>2]|0;
  HEAP32[$45>>2] = $50;
  HEAP32[$2>>2] = $46;
  $51 = $50;
 }
 $52 = (_llvm_bswap_i32(($51|0))|0);
 HEAP32[$45>>2] = $52;
 $53 = (($this) + 36|0);
 __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($53,$transfer);
 $54 = HEAP32[$45>>2]|0;
 $55 = ($54|0)==(-2);
 do {
  if ($55) {
   HEAP32[$emptyCharacterInfo>>2] = 0;
   $57 = (($emptyCharacterInfo) + 4|0);
   HEAP32[$57>>2] = 0;
   $58 = (($emptyCharacterInfo) + 8|0);
   HEAP32[$58>>2] = 0;
   __THREW__ = 0;
   invoke_viii(2046,($transfer|0),($emptyCharacterInfo|0),0);
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if (!($60)) {
    $61 = HEAP32[$emptyCharacterInfo>>2]|0;
    $62 = ($61|0)==(0|0);
    if ($62) {
     break;
    }
    $63 = HEAP32[$57>>2]|0;
    $64 = ($63|0)==($61|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i = $61;
     $scevgep$i$i$i$i$i = (($63) + -56|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($65)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $66 = (($uglygep3$i$i$i$i$i>>>0) / 56)&-1;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i = (($63) + (($67*56)|0)|0);
     HEAP32[$57>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($61|0),($$byval_copy1|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if (!($69)) {
     break;
    }
    $70 = ___cxa_find_matching_catch()|0;
    $71 = tempRet0;
    ___cxa_call_unexpected(($70|0));
    // unreachable;
   }
   $72 = ___cxa_find_matching_catch()|0;
   $73 = tempRet0;
   $74 = HEAP32[$emptyCharacterInfo>>2]|0;
   $75 = ($74|0)==(0|0);
   if ($75) {
    ___resumeException($72|0);
    // unreachable;
   }
   $76 = HEAP32[$57>>2]|0;
   $77 = ($76|0)==($74|0);
   if (!($77)) {
    $__new_last2$i$i$i$i$i16 = $74;
    $scevgep$i$i$i$i$i17 = (($76) + -56|0);
    $78 = (0 - ($__new_last2$i$i$i$i$i16))|0;
    $uglygep$i$i$i$i$i19 = (($scevgep$i$i$i$i$i17) + ($78)|0);
    $uglygep3$i$i$i$i$i20 = $uglygep$i$i$i$i$i19;
    $79 = (($uglygep3$i$i$i$i$i20>>>0) / 56)&-1;
    $80 = $79 ^ -1;
    $scevgep4$i$i$i$i$i21 = (($76) + (($80*56)|0)|0);
    HEAP32[$57>>2] = $scevgep4$i$i$i$i$i21;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($74|0),($$byval_copy1|0));
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    $83 = ___cxa_find_matching_catch()|0;
    $84 = tempRet0;
    ___cxa_call_unexpected(($83|0));
    // unreachable;
   } else {
    ___resumeException($72|0);
    // unreachable;
   }
  } else {
   $56 = (($this) + 84|0);
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS6_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$56,0);
  }
 } while(0);
 $85 = (($this) + 40|0);
 __ZN4PPtrI7TextureE8TransferI18StreamedBinaryReadILb1EEEEvRT_($85,$transfer);
 $86 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapINSt3__14pairIttEEfN20TextRenderingPrivate4Font14KerningCompareENS3_9allocatorINS4_IS5_fEEEEEEEvRT_17TransferMetaFlags($transfer,$86,0);
 $87 = (($this) + 80|0);
 $88 = HEAP32[$2>>2]|0;
 $89 = (($88) + 4|0);
 $90 = HEAP32[$5>>2]|0;
 $91 = ($89>>>0)>($90>>>0);
 if ($91) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$87,4);
  $$pre$i$i$i27 = HEAP32[$87>>2]|0;
  $$pre$phi$i$i$i28Z2D = $87;$94 = $$pre$i$i$i27;
 } else {
  $92 = Math_fround(HEAPF32[$88>>2]);
  HEAPF32[$87>>2] = $92;
  HEAP32[$2>>2] = $89;
  $93 = (HEAPF32[tempDoublePtr>>2]=$92,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i28Z2D = $87;$94 = $93;
 }
 $95 = (_llvm_bswap_i32(($94|0))|0);
 HEAP32[$$pre$phi$i$i$i28Z2D>>2] = $95;
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $96 = (($this) + 120|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$96,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $97 = (($this) + 32|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (Math_fround(($98|0)));
 HEAPF32[$fontSize>>2] = $99;
 $100 = HEAP32[$2>>2]|0;
 $101 = (($100) + 4|0);
 $102 = HEAP32[$5>>2]|0;
 $103 = ($101>>>0)>($102>>>0);
 if ($103) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$fontSize,4);
  $$pre$i$i$i32 = HEAP32[$fontSize>>2]|0;
  $$pre50 = HEAP32[$2>>2]|0;
  $$pre51 = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$i33Z2D = $fontSize;$106 = $$pre$i$i$i32;$112 = $$pre50;$114 = $$pre51;
 } else {
  $104 = Math_fround(HEAPF32[$100>>2]);
  HEAPF32[$fontSize>>2] = $104;
  HEAP32[$2>>2] = $101;
  $105 = (HEAPF32[tempDoublePtr>>2]=$104,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i33Z2D = $fontSize;$106 = $105;$112 = $101;$114 = $102;
 }
 $107 = (_llvm_bswap_i32(($106|0))|0);
 HEAP32[$$pre$phi$i$i$i33Z2D>>2] = $107;
 $108 = (HEAP32[tempDoublePtr>>2]=$107,Math_fround(HEAPF32[tempDoublePtr>>2]));
 $109 = (~~(($108)));
 HEAP32[$97>>2] = $109;
 $110 = (($this) + 208|0);
 $111 = (($112) + 4|0);
 $113 = ($111>>>0)>($114>>>0);
 if ($113) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$110,4);
  $$pre$i$i$i37 = HEAP32[$110>>2]|0;
  $$pre52 = HEAP32[$2>>2]|0;
  $$pre53 = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$i38Z2D = $110;$117 = $$pre$i$i$i37;$121 = $$pre52;$123 = $$pre53;
 } else {
  $115 = Math_fround(HEAPF32[$112>>2]);
  HEAPF32[$110>>2] = $115;
  HEAP32[$2>>2] = $111;
  $116 = (HEAPF32[tempDoublePtr>>2]=$115,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i38Z2D = $110;$117 = $116;$121 = $111;$123 = $114;
 }
 $118 = (_llvm_bswap_i32(($117|0))|0);
 HEAP32[$$pre$phi$i$i$i38Z2D>>2] = $118;
 $119 = (($this) + 204|0);
 $120 = (($121) + 4|0);
 $122 = ($120>>>0)>($123>>>0);
 if ($122) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$119,4);
  $$pre$i$i$i40 = HEAP32[$119>>2]|0;
  $125 = $$pre$i$i$i40;
 } else {
  $124 = HEAP32[$121>>2]|0;
  HEAP32[$119>>2] = $124;
  HEAP32[$2>>2] = $120;
  $125 = $124;
 }
 $126 = (_llvm_bswap_i32(($125|0))|0);
 HEAP32[$119>>2] = $126;
 $127 = (($this) + 132|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStr13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$127,0);
 $128 = (($this) + 144|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$128,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $129 = (($this) + 212|0);
 $130 = HEAP32[$2>>2]|0;
 $131 = (($130) + 4|0);
 $132 = HEAP32[$5>>2]|0;
 $133 = ($131>>>0)>($132>>>0);
 if ($133) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$129,4);
  $$pre$i$i$i = HEAP32[$129>>2]|0;
  $135 = $$pre$i$i$i;
  $136 = (_llvm_bswap_i32(($135|0))|0);
  HEAP32[$129>>2] = $136;
  STACKTOP = sp;return;
 } else {
  $134 = HEAP32[$130>>2]|0;
  HEAP32[$129>>2] = $134;
  HEAP32[$2>>2] = $131;
  $135 = $134;
  $136 = (_llvm_bswap_i32(($135|0))|0);
  HEAP32[$129>>2] = $136;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS5_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 4|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = $21 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS5_L18MemLabelIdentifier27ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$byval_copy5 = 0, $$idx = 0, $$pre = 0, $$pre43 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i17 = 0, $__new_last2$i$i$i$i$i26 = 0, $scevgep$i$i = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i18 = 0, $scevgep$i$i$i$i$i27 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i22 = 0;
 var $scevgep4$i$i$i$i$i31 = 0, $scevgep8$i$i = 0, $scevgep8$i$i41 = 0, $temp = 0, $uglygep$i$i = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i20 = 0, $uglygep$i$i$i$i$i29 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i21 = 0, $uglygep3$i$i$i$i$i30 = 0, $uglygep6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $temp = sp + 8|0;
 $1 = sp + 20|0;
 $2 = sp + 24|0;
 $3 = (($v) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$v>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)<($sz>>>0);
 if (!($10)) {
  $70 = ($9>>>0)>($sz>>>0);
  if (!($70)) {
   STACKTOP = sp;return;
  }
  $71 = (($5) + ($sz<<2)|0);
  $$idx = $sz << 2;
  $72 = $$idx >> 2;
  $73 = ($72|0)==(0);
  do {
   if ($73) {
    $93 = 0;$95 = 0;$scevgep8$i$i41 = 0;
   } else {
    $74 = ($$idx|0)<(0);
    if ($74) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if (!($76)) {
      // unreachable;
     }
    } else {
     HEAP32[$0>>2] = 27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     $77 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy5|0),0,(804096|0),79)|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if (!($79)) {
      $80 = (($77) + ($72<<2)|0);
      $81 = ($sz|0)==(0);
      if ($81) {
       $93 = $77;$95 = $80;$scevgep8$i$i41 = $77;
       break;
      }
      $$sum = (($sz) + -1)|0;
      $scevgep$i$i = (($5) + ($$sum<<2)|0);
      $82 = (0 - ($7))|0;
      $uglygep$i$i = (($scevgep$i$i) + ($82)|0);
      $uglygep6$i$i = $uglygep$i$i;
      $84 = $77;$86 = $5;
      while(1) {
       $83 = ($84|0)==(0|0);
       if (!($83)) {
        $85 = HEAP32[$86>>2]|0;
        HEAP32[$84>>2] = $85;
       }
       $87 = (($84) + 4|0);
       $88 = (($86) + 4|0);
       $89 = ($88|0)==($71|0);
       if ($89) {
        break;
       } else {
        $84 = $87;$86 = $88;
       }
      }
      $90 = $uglygep6$i$i >>> 2;
      $91 = (($90) + 1)|0;
      $scevgep8$i$i = (($77) + ($91<<2)|0);
      $93 = $77;$95 = $80;$scevgep8$i$i41 = $scevgep8$i$i;
      break;
     }
    }
    $101 = ___cxa_find_matching_catch()|0;
    $102 = tempRet0;
    $$0 = $102;$$01 = $101;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $92 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $93;
  HEAP32[$3>>2] = $scevgep8$i$i41;
  $94 = (($v) + 8|0);
  HEAP32[$94>>2] = $95;
  $96 = ($92|0)==(0|0);
  if ($96) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($92|0),($$byval_copy5|0));
  $97 = __THREW__; __THREW__ = 0;
  $98 = $97&1;
  if ($98) {
   $99 = ___cxa_find_matching_catch()|0;
   $100 = tempRet0;
   ___cxa_call_unexpected(($99|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $11 = (($v) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($7))|0;
 $15 = $14 >> 2;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $69 = (($sz) - ($9))|0;
  __ZNSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEE8__appendEj($v,$69);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3436,($temp|0),($sz|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if (!($20)) {
   $21 = HEAP32[$v>>2]|0;
   HEAP32[$1>>2] = $21;
   $22 = HEAP32[$3>>2]|0;
   HEAP32[$2>>2] = $22;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viii(2047,($temp|0),($$byval_copy|0),($$byval_copy5|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$17>>2]|0;
    $26 = HEAP32[$temp>>2]|0;
    $27 = $25;
    $28 = $26;
    $29 = (($27) - ($28))|0;
    $30 = $29 >> 2;
    $31 = ($30>>>0)<($sz>>>0);
    if ($31) {
     $32 = (($sz) - ($30))|0;
     __THREW__ = 0;
     invoke_vii(3437,($temp|0),($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre43 = HEAP32[$17>>2]|0;
     $42 = $$pre;$44 = $$pre43;
    } else {
     $35 = ($30>>>0)>($sz>>>0);
     if ($35) {
      $36 = (($26) + ($sz<<2)|0);
      $37 = ($25|0)==($36|0);
      if ($37) {
       $42 = $26;$44 = $25;
      } else {
       $__new_last2$i$i$i = $36;
       $scevgep$i$i$i = (($25) + -4|0);
       $38 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($38)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $39 = $uglygep3$i$i$i >>> 2;
       $40 = $39 ^ -1;
       $scevgep4$i$i$i = (($25) + ($40<<2)|0);
       HEAP32[$17>>2] = $scevgep4$i$i$i;
       $42 = $26;$44 = $scevgep4$i$i$i;
      }
     } else {
      $42 = $26;$44 = $25;
     }
    }
    $41 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $41;
    HEAP32[$v>>2] = $42;
    $43 = HEAP32[$3>>2]|0;
    HEAP32[$17>>2] = $43;
    HEAP32[$3>>2] = $44;
    $45 = HEAP32[$18>>2]|0;
    $46 = HEAP32[$11>>2]|0;
    HEAP32[$18>>2] = $46;
    HEAP32[$11>>2] = $45;
    $47 = ($41|0)==(0|0);
    if ($47) {
     STACKTOP = sp;return;
    }
    $48 = ($43|0)==($41|0);
    if (!($48)) {
     $__new_last2$i$i$i$i$i17 = $41;
     $scevgep$i$i$i$i$i18 = (($43) + -4|0);
     $49 = (0 - ($__new_last2$i$i$i$i$i17))|0;
     $uglygep$i$i$i$i$i20 = (($scevgep$i$i$i$i$i18) + ($49)|0);
     $uglygep3$i$i$i$i$i21 = $uglygep$i$i$i$i$i20;
     $50 = $uglygep3$i$i$i$i$i21 >>> 2;
     $51 = $50 ^ -1;
     $scevgep4$i$i$i$i$i22 = (($43) + ($51<<2)|0);
     HEAP32[$17>>2] = $scevgep4$i$i$i$i$i22;
    }
    HEAP32[$$byval_copy>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
    invoke_vii(2591,($41|0),($$byval_copy5|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     ___cxa_call_unexpected(($54|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 $58 = HEAP32[$temp>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
 $60 = HEAP32[$17>>2]|0;
 $61 = ($60|0)==($58|0);
 if (!($61)) {
  $__new_last2$i$i$i$i$i26 = $58;
  $scevgep$i$i$i$i$i27 = (($60) + -4|0);
  $62 = (0 - ($__new_last2$i$i$i$i$i26))|0;
  $uglygep$i$i$i$i$i29 = (($scevgep$i$i$i$i$i27) + ($62)|0);
  $uglygep3$i$i$i$i$i30 = $uglygep$i$i$i$i$i29;
  $63 = $uglygep3$i$i$i$i$i30 >>> 2;
  $64 = $63 ^ -1;
  $scevgep4$i$i$i$i$i31 = (($60) + ($64<<2)|0);
  HEAP32[$17>>2] = $scevgep4$i$i$i$i$i31;
 }
 HEAP32[$$byval_copy>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$$byval_copy+0>>2]|0;
 invoke_vii(2591,($58|0),($$byval_copy5|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if ($66) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  ___cxa_call_unexpected(($67|0));
  // unreachable;
 } else {
  $$0 = $57;$$01 = $56;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i$i = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($5))|0;
 $13 = $12 >> 2;
 $14 = ($__n|0)==(0);
 if ($14) {
  $$pre$i = $3;$18 = 0;$21 = $10;
 } else {
  $15 = $__n << 2;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($15,16,$$byval_copy1,0,804096,79)|0);
  $$pre = HEAP32[$this>>2]|0;
  $$pre1 = HEAP32[$9>>2]|0;
  $$pre$i = $$pre;$18 = $16;$21 = $$pre1;
 }
 $17 = (($18) + ($13<<2)|0);
 $19 = (($18) + ($__n<<2)|0);
 $20 = ($21|0)==($$pre$i|0);
 if ($20) {
  $31 = $17;$33 = $21;
 } else {
  $__begin13$i$i = $$pre$i;
  $scevgep$i$i = (($21) + -4|0);
  $22 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($22)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $21;$26 = $17;
  while(1) {
   $23 = (($$01$i$i) + -4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($26) + -4|0);
   HEAP32[$25>>2] = $24;
   $27 = (($26) + -4|0);
   $28 = ($23|0)==($$pre$i|0);
   if ($28) {
    break;
   } else {
    $$01$i$i = $23;$26 = $27;
   }
  }
  $29 = $uglygep4$i$i >>> 2;
  $30 = $29 ^ -1;
  $$sum = (($13) + ($30))|0;
  $scevgep5$i$i = (($18) + ($$sum<<2)|0);
  $31 = $scevgep5$i$i;$33 = $$pre$i;
 }
 HEAP32[$this>>2] = $31;
 HEAP32[$9>>2] = $17;
 HEAP32[$1>>2] = $19;
 $32 = ($33|0)==(0|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($33|0),($$byval_copy1|0));
 $34 = __THREW__; __THREW__ = 0;
 $35 = $34&1;
 if ($35) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  ___cxa_call_unexpected(($36|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPS4_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS4_NS_15iterator_traitsISE_E9referenceEEE5valueEvE4typeESE_SE_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$promoted15$i16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i8 = 0, $scevgep$i17 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $scevgep8$i = 0, $scevgep8$i24 = 0, $uglygep$i = 0;
 var $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i9 = 0, $uglygep$i19 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep5$i$i = 0, $uglygep6$i = 0, $uglygep6$i20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $47 = ($9|0)==(0|0);
  do {
   if ($47) {
    $60 = $8;
   } else {
    $48 = (($this) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($9|0);
    if (!($50)) {
     $scevgep$i$i$i$i = (($49) + -4|0);
     $51 = (0 - ($11))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($51)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $52 = $uglygep3$i$i$i$i >>> 2;
     $53 = $52 ^ -1;
     $scevgep4$i$i$i$i = (($49) + ($53<<2)|0);
     HEAP32[$48>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$0>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy1|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     ___cxa_call_unexpected(($56|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$48>>2] = 0;
     HEAP32[$this>>2] = 0;
     $60 = 0;
     break;
    }
   }
  } while(0);
  $58 = ($5|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $59 = $60;
  $61 = $59 >> 2;
  $62 = ($61>>>0)<(1073741823);
  if ($62) {
   $63 = $59 >> 1;
   $64 = ($63>>>0)<($6>>>0);
   $65 = $64 ? $6 : $63;
   $66 = ($65|0)<(0);
   if ($66) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $65;
   }
  } else {
   $$0$i40 = 2147483647;
  }
  $67 = $$0$i40 << 2;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $68 = (__Z15malloc_internaljj10MemLabelIdiPKci($67,16,$$byval_copy1,0,804096,79)|0);
  $69 = (($this) + 4|0);
  HEAP32[$69>>2] = $68;
  HEAP32[$this>>2] = $68;
  $70 = (($68) + ($$0$i40<<2)|0);
  HEAP32[$7>>2] = $70;
  $71 = ($1|0)==($2|0);
  if ($71) {
   STACKTOP = sp;return;
  }
  $scevgep$i = (($2) + -4|0);
  $72 = (0 - ($4))|0;
  $uglygep$i = (($scevgep$i) + ($72)|0);
  $uglygep6$i = $uglygep$i;
  $73 = $uglygep6$i >>> 2;
  $75 = $68;$77 = $1;
  while(1) {
   $74 = ($75|0)==(0|0);
   if (!($74)) {
    $76 = HEAP32[$77>>2]|0;
    HEAP32[$75>>2] = $76;
   }
   $78 = (($75) + 4|0);
   $79 = (($77) + 4|0);
   $80 = ($79|0)==($2|0);
   if ($80) {
    break;
   } else {
    $75 = $78;$77 = $79;
   }
  }
  $81 = (($73) + 1)|0;
  $scevgep8$i = (($68) + ($81<<2)|0);
  HEAP32[$69>>2] = $scevgep8$i;
  STACKTOP = sp;return;
 } else {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 2;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + ($19<<2)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i$i = (($23) + -4|0);
   $24 = (0 - ($4))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($24)|0);
   $uglygep5$i$i = $uglygep$i$i;
   $25 = $uglygep5$i$i >>> 2;
   $$01$i$i = $9;$27 = $1;
   while(1) {
    $26 = HEAP32[$27>>2]|0;
    HEAP32[$$01$i$i>>2] = $26;
    $28 = (($27) + 4|0);
    $29 = (($$01$i$i) + 4|0);
    $30 = ($28|0)==($23|0);
    if ($30) {
     break;
    } else {
     $$01$i$i = $29;$27 = $28;
    }
   }
   $31 = (($25) + 1)|0;
   $scevgep6$i$i = (($9) + ($31<<2)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  if (!($__growing$0$off0)) {
   $43 = ($16|0)==($$0$lcssa$i$i|0);
   if ($43) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $$0$lcssa$i$i;
   $scevgep$i$i8 = (($16) + -4|0);
   $44 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i9 = (($scevgep$i$i8) + ($44)|0);
   $uglygep3$i$i = $uglygep$i$i9;
   $45 = $uglygep3$i$i >>> 2;
   $46 = $45 ^ -1;
   $scevgep4$i$i = (($16) + ($46<<2)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $32 = ($23|0)==($2|0);
  if ($32) {
   STACKTOP = sp;return;
  }
  $$promoted15$i16 = $23;
  $scevgep$i17 = (($2) + -4|0);
  $33 = (0 - ($$promoted15$i16))|0;
  $uglygep$i19 = (($scevgep$i17) + ($33)|0);
  $uglygep6$i20 = $uglygep$i19;
  $34 = $uglygep6$i20 >>> 2;
  $36 = $16;$38 = $23;
  while(1) {
   $35 = ($36|0)==(0|0);
   if (!($35)) {
    $37 = HEAP32[$38>>2]|0;
    HEAP32[$36>>2] = $37;
   }
   $39 = (($36) + 4|0);
   $40 = (($38) + 4|0);
   $41 = ($40|0)==($2|0);
   if ($41) {
    break;
   } else {
    $36 = $39;$38 = $40;
   }
  }
  $42 = (($34) + 1)|0;
  $scevgep8$i24 = (($16) + ($42<<2)|0);
  HEAP32[$15>>2] = $scevgep8$i24;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__begin13$i$i = 0, $scevgep$i = 0, $scevgep$i$i = 0, $scevgep$i4 = 0, $scevgep5$i$i = 0, $uglygep$i$i = 0, $uglygep4$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP32[$11>>2] = 0;
   }
   $12 = (($11) + 4|0);
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$11 = $12;
   }
  }
  $scevgep$i = (($4) + ($__n<<2)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = $17 >> 2;
 $19 = (($18) + ($__n))|0;
 $20 = ($19|0)<(0);
 if ($20) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $21 = (($5) - ($16))|0;
 $22 = $21 >> 2;
 $23 = ($22>>>0)<(1073741823);
 if ($23) {
  $24 = $21 >> 1;
  $25 = ($24>>>0)<($19>>>0);
  $26 = $25 ? $19 : $24;
  $27 = ($26|0)==(0);
  if ($27) {
   $$0$i58 = 0;$31 = 0;
  } else {
   $$0$i57 = $26;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $28 = $$0$i57 << 2;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $29 = (__Z15malloc_internaljj10MemLabelIdiPKci($28,16,$$byval_copy1,0,804096,79)|0);
  $$0$i58 = $$0$i57;$31 = $29;
 }
 $30 = (($31) + ($18<<2)|0);
 $$0$i2 = $__n;$33 = $30;
 while(1) {
  $32 = ($33|0)==(0|0);
  if (!($32)) {
   HEAP32[$33>>2] = 0;
  }
  $34 = (($33) + 4|0);
  $35 = (($$0$i2) + -1)|0;
  $36 = ($35|0)==(0);
  if ($36) {
   break;
  } else {
   $$0$i2 = $35;$33 = $34;
  }
 }
 $37 = (($31) + ($$0$i58<<2)|0);
 $scevgep$i4 = (($31) + ($19<<2)|0);
 $38 = HEAP32[$this>>2]|0;
 $39 = HEAP32[$3>>2]|0;
 $40 = ($39|0)==($38|0);
 if ($40) {
  $50 = $30;
 } else {
  $__begin13$i$i = $38;
  $scevgep$i$i = (($39) + -4|0);
  $41 = (0 - ($__begin13$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($41)|0);
  $uglygep4$i$i = $uglygep$i$i;
  $$01$i$i = $39;$45 = $30;
  while(1) {
   $42 = (($$01$i$i) + -4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($45) + -4|0);
   HEAP32[$44>>2] = $43;
   $46 = (($45) + -4|0);
   $47 = ($42|0)==($38|0);
   if ($47) {
    break;
   } else {
    $$01$i$i = $42;$45 = $46;
   }
  }
  $48 = $uglygep4$i$i >>> 2;
  $49 = $48 ^ -1;
  $$sum6 = (($18) + ($49))|0;
  $scevgep5$i$i = (($31) + ($$sum6<<2)|0);
  $50 = $scevgep5$i$i;
 }
 HEAP32[$this>>2] = $50;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $37;
 $51 = ($38|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($38|0),($$byval_copy1|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch()|0;
  $55 = tempRet0;
  ___cxa_call_unexpected(($54|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStr13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorI8UnityStr13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$29,0);
   __ZN18StreamedBinaryReadILb1EE5AlignEv($this);
   $30 = (($29) + 12|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorI8UnityStr13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy13 = 0, $$byval_copy8 = 0, $$idx = 0, $$pre = 0, $$pre$i$i$i$i$i16 = 0, $$pre$i$i$i$i$i8 = 0, $$pre$i$i$i10 = 0, $$pre$i$i$i18 = 0, $$pre$i$i$i5 = 0, $$pre36 = 0, $$pre37 = 0, $$pre38 = 0, $$pre39 = 0, $$pre40 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $temp = 0, $temp1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy13 = sp + 60|0;
 $$byval_copy8 = sp + 56|0;
 $0 = sp + 52|0;
 $1 = sp + 48|0;
 $2 = sp + 44|0;
 $3 = sp + 40|0;
 $4 = sp + 36|0;
 $5 = sp + 20|0;
 $temp = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $temp1 = sp + 24|0;
 $8 = (($v) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$v>>2]|0;
 $11 = $9;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = (($13|0) / 12)&-1;
 $15 = ($14>>>0)<($sz>>>0);
 if (!($15)) {
  $107 = ($14>>>0)>($sz>>>0);
  if (!($107)) {
   STACKTOP = sp;return;
  }
  $108 = (($10) + (($sz*12)|0)|0);
  HEAP32[$temp1>>2] = 0;
  $109 = (($temp1) + 4|0);
  HEAP32[$109>>2] = 0;
  $110 = (($temp1) + 8|0);
  HEAP32[$110>>2] = 0;
  $$idx = ($sz*12)|0;
  $111 = (($$idx|0) / 12)&-1;
  $112 = ($sz|0)==(0);
  do {
   if ($112) {
    $144 = $10;$145 = 0;$146 = $9;$147 = 0;$150 = 0;
   } else {
    $113 = ($$idx|0)<(0);
    if ($113) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if (!($115)) {
      // unreachable;
     }
    } else {
     HEAP32[$3>>2] = 27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$3+0>>2]|0;
     $116 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy13|0),0,(804096|0),79)|0);
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if (!($118)) {
      HEAP32[$109>>2] = $116;
      HEAP32[$temp1>>2] = $116;
      $119 = (($116) + (($111*12)|0)|0);
      HEAP32[$110>>2] = $119;
      HEAP32[$4>>2] = $10;
      HEAP32[$5>>2] = $108;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$4+0>>2]|0;
      ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$5+0>>2]|0;
      invoke_viii(2049,($temp1|0),($$byval_copy8|0),($$byval_copy13|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if (!($121)) {
       $$pre36 = HEAP32[$temp1>>2]|0;
       $$pre37 = HEAP32[$v>>2]|0;
       $$pre38 = HEAP32[$109>>2]|0;
       $$pre39 = HEAP32[$8>>2]|0;
       $$pre40 = HEAP32[$110>>2]|0;
       $144 = $$pre37;$145 = $$pre36;$146 = $$pre39;$147 = $$pre38;$150 = $$pre40;
       break;
      }
     }
    }
    $122 = ___cxa_find_matching_catch()|0;
    $123 = tempRet0;
    $124 = HEAP32[$temp1>>2]|0;
    $125 = ($124|0)==(0|0);
    if (!($125)) {
     $126 = HEAP32[$109>>2]|0;
     $127 = ($126|0)==($124|0);
     L17: do {
      if (!($127)) {
       $129 = $126;
       while(1) {
        $128 = (($129) + -12|0);
        HEAP32[$109>>2] = $128;
        $130 = HEAP8[$128>>0]|0;
        $131 = $130 & 1;
        $132 = ($131<<24>>24)==(0);
        if (!($132)) {
         $134 = (($129) + -4|0);
         $135 = HEAP32[$134>>2]|0;
         HEAP32[$$byval_copy8>>2] = 59;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy8+0>>2]|0;
         invoke_vii(2591,($135|0),($$byval_copy13|0));
         $136 = __THREW__; __THREW__ = 0;
         $137 = $136&1;
         if ($137) {
          break;
         }
        }
        $133 = ($128|0)==($124|0);
        if ($133) {
         break L17;
        } else {
         $129 = $128;
        }
       }
       $138 = ___cxa_find_matching_catch()|0;
       $139 = tempRet0;
       ___cxa_call_unexpected(($138|0));
       // unreachable;
      }
     } while(0);
     HEAP32[$0>>2] = 27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($124|0),($$byval_copy13|0));
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if ($141) {
      $142 = ___cxa_find_matching_catch()|0;
      $143 = tempRet0;
      ___cxa_call_unexpected(($142|0));
      // unreachable;
     }
    }
    $$0 = $123;$$01 = $122;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$temp1>>2] = $144;
  HEAP32[$v>>2] = $145;
  HEAP32[$109>>2] = $146;
  HEAP32[$8>>2] = $147;
  $148 = (($v) + 8|0);
  $149 = HEAP32[$148>>2]|0;
  HEAP32[$110>>2] = $149;
  HEAP32[$148>>2] = $150;
  $151 = ($144|0)==(0|0);
  if ($151) {
   STACKTOP = sp;return;
  }
  $152 = ($146|0)==($144|0);
  L33: do {
   if (!($152)) {
    $154 = $146;
    while(1) {
     $153 = (($154) + -12|0);
     HEAP32[$109>>2] = $153;
     $155 = HEAP8[$153>>0]|0;
     $156 = $155 & 1;
     $157 = ($156<<24>>24)==(0);
     if (!($157)) {
      $159 = (($154) + -4|0);
      $160 = HEAP32[$159>>2]|0;
      HEAP32[$2>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$2+0>>2]|0;
      invoke_vii(2591,($160|0),($$byval_copy13|0));
      $161 = __THREW__; __THREW__ = 0;
      $162 = $161&1;
      if ($162) {
       break;
      }
     }
     $158 = ($153|0)==($144|0);
     if ($158) {
      break L33;
     } else {
      $154 = $153;
     }
    }
    $163 = ___cxa_find_matching_catch()|0;
    $164 = tempRet0;
    ___cxa_call_unexpected(($163|0));
    // unreachable;
   }
  } while(0);
  HEAP32[$3>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($144|0),($$byval_copy13|0));
  $165 = __THREW__; __THREW__ = 0;
  $166 = $165&1;
  if ($166) {
   $167 = ___cxa_find_matching_catch()|0;
   $168 = tempRet0;
   ___cxa_call_unexpected(($167|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $16 = (($v) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17;
 $19 = (($18) - ($12))|0;
 $20 = (($19|0) / 12)&-1;
 $21 = ($20|0)==($sz|0);
 if ($21) {
  $106 = (($sz) - ($14))|0;
  __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE8__appendEj($v,$106);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $22 = (($temp) + 4|0);
 HEAP32[$22>>2] = 0;
 $23 = (($temp) + 8|0);
 HEAP32[$23>>2] = 0;
 __THREW__ = 0;
 invoke_vii(3438,($temp|0),($sz|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 L50: do {
  if (!($25)) {
   $26 = HEAP32[$v>>2]|0;
   HEAP32[$6>>2] = $26;
   $27 = HEAP32[$8>>2]|0;
   HEAP32[$7>>2] = $27;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$6+0>>2]|0;
   ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$7+0>>2]|0;
   invoke_viii(2048,($temp|0),($$byval_copy8|0),($$byval_copy13|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    $30 = HEAP32[$22>>2]|0;
    $31 = HEAP32[$temp>>2]|0;
    $32 = $30;
    $33 = $31;
    $34 = (($32) - ($33))|0;
    $35 = (($34|0) / 12)&-1;
    $36 = ($35>>>0)<($sz>>>0);
    L53: do {
     if ($36) {
      $37 = (($sz) - ($35))|0;
      __THREW__ = 0;
      invoke_vii(3439,($temp|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break L50;
      }
      $$pre = HEAP32[$22>>2]|0;
      $59 = $$pre;
     } else {
      $40 = ($35>>>0)>($sz>>>0);
      if ($40) {
       $41 = (($31) + (($sz*12)|0)|0);
       $42 = ($30|0)==($41|0);
       if ($42) {
        $59 = $30;
       } else {
        $44 = $30;
        while(1) {
         $43 = (($44) + -12|0);
         HEAP32[$22>>2] = $43;
         $45 = HEAP8[$43>>0]|0;
         $46 = $45 & 1;
         $47 = ($46<<24>>24)==(0);
         if ($47) {
          $49 = $43;
         } else {
          $50 = (($44) + -4|0);
          $51 = HEAP32[$50>>2]|0;
          HEAP32[$1>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
          invoke_vii(2591,($51|0),($$byval_copy13|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break;
          }
          $$pre$i$i$i5 = HEAP32[$22>>2]|0;
          $49 = $$pre$i$i$i5;
         }
         $48 = ($49|0)==($41|0);
         if ($48) {
          $59 = $41;
          break L53;
         } else {
          $44 = $49;
         }
        }
        $54 = ___cxa_find_matching_catch()|0;
        $55 = tempRet0;
        ___cxa_call_unexpected(($54|0));
        // unreachable;
       }
      } else {
       $59 = $30;
      }
     }
    } while(0);
    $56 = HEAP32[$temp>>2]|0;
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $56;
    $58 = HEAP32[$8>>2]|0;
    HEAP32[$22>>2] = $58;
    HEAP32[$8>>2] = $59;
    $60 = HEAP32[$23>>2]|0;
    $61 = HEAP32[$16>>2]|0;
    HEAP32[$23>>2] = $61;
    HEAP32[$16>>2] = $60;
    $62 = ($57|0)==(0|0);
    if ($62) {
     STACKTOP = sp;return;
    }
    $63 = ($58|0)==($57|0);
    do {
     if ($63) {
      $77 = $57;
     } else {
      $65 = $58;
      while(1) {
       $64 = (($65) + -12|0);
       HEAP32[$22>>2] = $64;
       $66 = HEAP8[$64>>0]|0;
       $67 = $66 & 1;
       $68 = ($67<<24>>24)==(0);
       if ($68) {
        $70 = $64;
       } else {
        $71 = (($65) + -4|0);
        $72 = HEAP32[$71>>2]|0;
        HEAP32[$$byval_copy8>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$$byval_copy8+0>>2]|0;
        invoke_vii(2591,($72|0),($$byval_copy13|0));
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 23;
         break;
        }
        $$pre$i$i$i$i$i8 = HEAP32[$22>>2]|0;
        $70 = $$pre$i$i$i$i$i8;
       }
       $69 = ($70|0)==($57|0);
       if ($69) {
        label = 24;
        break;
       } else {
        $65 = $70;
       }
      }
      if ((label|0) == 23) {
       $75 = ___cxa_find_matching_catch()|0;
       $76 = tempRet0;
       ___cxa_call_unexpected(($75|0));
       // unreachable;
      }
      else if ((label|0) == 24) {
       $$pre$i$i$i10 = HEAP32[$temp>>2]|0;
       $77 = $$pre$i$i$i10;
       break;
      }
     }
    } while(0);
    HEAP32[$0>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($77|0),($$byval_copy13|0));
    $78 = __THREW__; __THREW__ = 0;
    $79 = $78&1;
    if ($79) {
     $80 = ___cxa_find_matching_catch()|0;
     $81 = tempRet0;
     ___cxa_call_unexpected(($80|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $82 = ___cxa_find_matching_catch()|0;
 $83 = tempRet0;
 $84 = HEAP32[$temp>>2]|0;
 $85 = ($84|0)==(0|0);
 if ($85) {
  $$0 = $83;$$01 = $82;
  ___resumeException($$01|0);
  // unreachable;
 }
 $86 = HEAP32[$22>>2]|0;
 $87 = ($86|0)==($84|0);
 do {
  if ($87) {
   $101 = $84;
  } else {
   $89 = $86;
   while(1) {
    $88 = (($89) + -12|0);
    HEAP32[$22>>2] = $88;
    $90 = HEAP8[$88>>0]|0;
    $91 = $90 & 1;
    $92 = ($91<<24>>24)==(0);
    if ($92) {
     $94 = $88;
    } else {
     $95 = (($89) + -4|0);
     $96 = HEAP32[$95>>2]|0;
     HEAP32[$1>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($96|0),($$byval_copy13|0));
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      label = 34;
      break;
     }
     $$pre$i$i$i$i$i16 = HEAP32[$22>>2]|0;
     $94 = $$pre$i$i$i$i$i16;
    }
    $93 = ($94|0)==($84|0);
    if ($93) {
     label = 35;
     break;
    } else {
     $89 = $94;
    }
   }
   if ((label|0) == 34) {
    $99 = ___cxa_find_matching_catch()|0;
    $100 = tempRet0;
    ___cxa_call_unexpected(($99|0));
    // unreachable;
   }
   else if ((label|0) == 35) {
    $$pre$i$i$i18 = HEAP32[$temp>>2]|0;
    $101 = $$pre$i$i$i18;
    break;
   }
  }
 } while(0);
 HEAP32[$2>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy13+0>>2]=HEAP32[$2+0>>2]|0;
 invoke_vii(2591,($101|0),($$byval_copy13|0));
 $102 = __THREW__; __THREW__ = 0;
 $103 = $102&1;
 if ($103) {
  $104 = ___cxa_find_matching_catch()|0;
  $105 = tempRet0;
  ___cxa_call_unexpected(($104|0));
  // unreachable;
 } else {
  $$0 = $83;$$01 = $82;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 8|0);
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = (($13) - ($6))|0;
 $15 = (($14|0) / 12)&-1;
 $16 = (($__v) + 12|0);
 HEAP32[$16>>2] = 0;
 $17 = (($__v) + 16|0);
 HEAP32[$17>>2] = $10;
 $18 = ($__n|0)==(0);
 if ($18) {
  $21 = 0;
 } else {
  $19 = ($__n*12)|0;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,16,$$byval_copy4,0,804096,79)|0);
  $21 = $20;
 }
 HEAP32[$__v>>2] = $21;
 $22 = (($21) + (($15*12)|0)|0);
 $23 = (($__v) + 8|0);
 HEAP32[$23>>2] = $22;
 $24 = (($__v) + 4|0);
 HEAP32[$24>>2] = $22;
 $25 = (($21) + (($__n*12)|0)|0);
 HEAP32[$16>>2] = $25;
 __THREW__ = 0;
 invoke_vii(3431,($this|0),($__v|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  $51 = HEAP32[$24>>2]|0;
  $52 = HEAP32[$23>>2]|0;
  $53 = ($52|0)==($51|0);
  L25: do {
   if (!($53)) {
    $55 = $52;
    while(1) {
     $54 = (($55) + -12|0);
     HEAP32[$23>>2] = $54;
     $56 = HEAP8[$54>>0]|0;
     $57 = $56 & 1;
     $58 = ($57<<24>>24)==(0);
     if (!($58)) {
      $60 = (($55) + -4|0);
      $61 = HEAP32[$60>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($61|0),($$byval_copy4|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
     }
     $59 = ($54|0)==($51|0);
     if ($59) {
      break L25;
     } else {
      $55 = $54;
     }
    }
    $64 = ___cxa_find_matching_catch()|0;
    $65 = tempRet0;
    ___cxa_call_unexpected(($64|0));
    // unreachable;
   }
  } while(0);
  $66 = HEAP32[$__v>>2]|0;
  $67 = ($66|0)==(0|0);
  if ($67) {
   ___resumeException($49|0);
   // unreachable;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($66|0),($$byval_copy4|0));
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   $70 = ___cxa_find_matching_catch()|0;
   $71 = tempRet0;
   ___cxa_call_unexpected(($70|0));
   // unreachable;
  } else {
   ___resumeException($49|0);
   // unreachable;
  }
 } else {
  $28 = HEAP32[$24>>2]|0;
  $29 = HEAP32[$23>>2]|0;
  $30 = ($29|0)==($28|0);
  L9: do {
   if (!($30)) {
    $32 = $29;
    while(1) {
     $31 = (($32) + -12|0);
     HEAP32[$23>>2] = $31;
     $33 = HEAP8[$31>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if (!($35)) {
      $37 = (($32) + -4|0);
      $38 = HEAP32[$37>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($38|0),($$byval_copy4|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
     }
     $36 = ($31|0)==($28|0);
     if ($36) {
      break L9;
     } else {
      $32 = $31;
     }
    }
    $41 = ___cxa_find_matching_catch()|0;
    $42 = tempRet0;
    ___cxa_call_unexpected(($41|0));
    // unreachable;
   }
  } while(0);
  $43 = HEAP32[$__v>>2]|0;
  $44 = ($43|0)==(0|0);
  if ($44) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($43|0),($$byval_copy4|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   $47 = ___cxa_find_matching_catch()|0;
   $48 = tempRet0;
   ___cxa_call_unexpected(($47|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i10 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy6 = 0, $$byval_copy7 = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $__growing$0$off0 = 0, $scevgep$i = 0, $scevgep17$i = 0, $uglygep$i = 0, $uglygep16$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy7 = sp + 24|0;
 $$byval_copy6 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = HEAP32[$__first>>2]|0;
 $6 = HEAP32[$__last>>2]|0;
 $7 = $6;
 $8 = $5;
 $9 = (($7) - ($8))|0;
 $10 = (($9|0) / 12)&-1;
 $11 = (($this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$this>>2]|0;
 $14 = $12;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = (($16|0) / 12)&-1;
 $18 = ($10>>>0)>($17>>>0);
 if (!($18)) {
  $19 = (($this) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20;
  $22 = (($21) - ($15))|0;
  $23 = (($22|0) / 12)&-1;
  $24 = ($10>>>0)>($23>>>0);
  if ($24) {
   $25 = (($5) + (($23*12)|0)|0);
   $27 = $25;$__growing$0$off0 = 1;
  } else {
   $27 = $6;$__growing$0$off0 = 0;
  }
  $26 = ($5|0)==($27|0);
  if ($26) {
   $$0$lcssa$i$i = $13;
  } else {
   $scevgep$i = (($27) + -12|0);
   $28 = (0 - ($8))|0;
   $uglygep$i = (($scevgep$i) + ($28)|0);
   $uglygep16$i = $uglygep$i;
   $29 = (($uglygep16$i>>>0) / 12)&-1;
   $$01$i$i = $13;$30 = $5;
   while(1) {
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_($$01$i$i,$30)|0);
    $31 = (($30) + 12|0);
    $32 = (($$01$i$i) + 12|0);
    $33 = ($31|0)==($27|0);
    if ($33) {
     break;
    } else {
     $$01$i$i = $32;$30 = $31;
    }
   }
   $34 = (($29) + 1)|0;
   $scevgep17$i = (($13) + (($34*12)|0)|0);
   $$0$lcssa$i$i = $scevgep17$i;
  }
  if ($__growing$0$off0) {
   HEAP32[$1>>2] = $27;
   HEAP32[$2>>2] = $6;
   ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
   __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_($this,$$byval_copy6,$$byval_copy7);
   STACKTOP = sp;return;
  }
  $35 = HEAP32[$19>>2]|0;
  $36 = ($35|0)==($$0$lcssa$i$i|0);
  if ($36) {
   STACKTOP = sp;return;
  }
  $38 = $35;
  while(1) {
   $37 = (($38) + -12|0);
   HEAP32[$19>>2] = $37;
   $39 = HEAP8[$37>>0]|0;
   $40 = $39 & 1;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $43 = $37;
   } else {
    $44 = (($38) + -4|0);
    $45 = HEAP32[$44>>2]|0;
    HEAP32[$$byval_copy6>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy6+0>>2]|0;
    invoke_vii(2591,($45|0),($$byval_copy7|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 16;
     break;
    }
    $$pre$i$i = HEAP32[$19>>2]|0;
    $43 = $$pre$i$i;
   }
   $42 = ($43|0)==($$0$lcssa$i$i|0);
   if ($42) {
    label = 35;
    break;
   } else {
    $38 = $43;
   }
  }
  if ((label|0) == 16) {
   $48 = ___cxa_find_matching_catch()|0;
   $49 = tempRet0;
   ___cxa_call_unexpected(($48|0));
   // unreachable;
  }
  else if ((label|0) == 35) {
   STACKTOP = sp;return;
  }
 }
 $50 = ($13|0)==(0|0);
 do {
  if ($50) {
   $74 = $12;
  } else {
   $51 = (($this) + 4|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($52|0)==($13|0);
   do {
    if ($53) {
     $67 = $13;
    } else {
     $55 = $52;
     while(1) {
      $54 = (($55) + -12|0);
      HEAP32[$51>>2] = $54;
      $56 = HEAP8[$54>>0]|0;
      $57 = $56 & 1;
      $58 = ($57<<24>>24)==(0);
      if ($58) {
       $60 = $54;
      } else {
       $61 = (($55) + -4|0);
       $62 = HEAP32[$61>>2]|0;
       HEAP32[$0>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($62|0),($$byval_copy7|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 24;
        break;
       }
       $$pre$i$i$i$i = HEAP32[$51>>2]|0;
       $60 = $$pre$i$i$i$i;
      }
      $59 = ($60|0)==($13|0);
      if ($59) {
       label = 25;
       break;
      } else {
       $55 = $60;
      }
     }
     if ((label|0) == 24) {
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      ___cxa_call_unexpected(($65|0));
      // unreachable;
     }
     else if ((label|0) == 25) {
      $$pre$i = HEAP32[$this>>2]|0;
      $67 = $$pre$i;
      break;
     }
    }
   } while(0);
   HEAP32[$$byval_copy6>>2] = 27;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy6+0>>2]|0;
   invoke_vii(2591,($67|0),($$byval_copy7|0));
   $68 = __THREW__; __THREW__ = 0;
   $69 = $68&1;
   if ($69) {
    $70 = ___cxa_find_matching_catch()|0;
    $71 = tempRet0;
    ___cxa_call_unexpected(($70|0));
    // unreachable;
   } else {
    HEAP32[$11>>2] = 0;
    HEAP32[$51>>2] = 0;
    HEAP32[$this>>2] = 0;
    $74 = 0;
    break;
   }
  }
 } while(0);
 $72 = ($9|0)<(0);
 if ($72) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $73 = $74;
 $75 = (($73|0) / 12)&-1;
 $76 = ($75>>>0)<(1073741823);
 if ($76) {
  $77 = $75 << 1;
  $78 = ($77>>>0)<($10>>>0);
  $79 = $78 ? $10 : $77;
  $80 = ($79|0)<(0);
  if ($80) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i10 = $79;
  }
 } else {
  $$0$i10 = 2147483647;
 }
 $81 = ($$0$i10*12)|0;
 HEAP32[$$byval_copy6>>2] = 27;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy6+0>>2]|0;
 $82 = (__Z15malloc_internaljj10MemLabelIdiPKci($81,16,$$byval_copy7,0,804096,79)|0);
 $83 = (($this) + 4|0);
 HEAP32[$83>>2] = $82;
 HEAP32[$this>>2] = $82;
 $84 = (($82) + (($$0$i10*12)|0)|0);
 HEAP32[$11>>2] = $84;
 HEAP32[$3>>2] = $5;
 HEAP32[$4>>2] = $6;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$3+0>>2]|0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
 __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_($this,$$byval_copy6,$$byval_copy7);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$byval_copy = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__p$0$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = ($1|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $$pre = HEAP32[$4>>2]|0;
 $6 = $$pre;$8 = $1;
 while(1) {
  $5 = ($6|0)==(0|0);
  if ($5) {
   $33 = 0;$35 = $8;
  } else {
   $7 = HEAP8[$8>>0]|0;
   $9 = $7 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $15 = (($8) + 1|0);
    $16 = $7&255;
    $17 = $16 >>> 1;
    $19 = $17;$30 = $15;
   } else {
    $11 = (($8) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($8) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $19 = $14;$30 = $12;
   }
   $18 = ($19>>>0)>(2147483631);
   if ($18) {
    label = 8;
    break;
   }
   $20 = ($19>>>0)<(11);
   if ($20) {
    $21 = $19 << 1;
    $22 = $21&255;
    HEAP8[$6>>0] = $22;
    $23 = (($6) + 1|0);
    $__p$0$i$i$i$i$i = $23;
   } else {
    $24 = (($19) + 16)|0;
    $25 = $24 & -16;
    HEAP32[$0>>2] = 59;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,16,$$byval_copy,0,804096,79)|0);
    $27 = (($6) + 8|0);
    HEAP32[$27>>2] = $26;
    $28 = $25 | 1;
    HEAP32[$6>>2] = $28;
    $29 = (($6) + 4|0);
    HEAP32[$29>>2] = $19;
    $__p$0$i$i$i$i$i = $26;
   }
   _memcpy(($__p$0$i$i$i$i$i|0),($30|0),($19|0))|0;
   $31 = (($__p$0$i$i$i$i$i) + ($19)|0);
   HEAP8[$31>>0] = 0;
   $$pre1 = HEAP32[$4>>2]|0;
   $$pre2 = HEAP32[$__first>>2]|0;
   $33 = $$pre1;$35 = $$pre2;
  }
  $32 = (($33) + 12|0);
  HEAP32[$4>>2] = $32;
  $34 = (($35) + 12|0);
  HEAP32[$__first>>2] = $34;
  $36 = ($34|0)==($2|0);
  if ($36) {
   label = 14;
   break;
  } else {
   $6 = $32;$8 = $34;
  }
 }
 if ((label|0) == 8) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i114 = 0, $$0$i115 = 0, $$0$i9 = 0, $$byval_copy4 = 0, $$pre1$i = 0, $$pre1$i1113 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ($9>>>0)<($__n>>>0);
 if (!($10)) {
  $$0$i = $__n;$12 = $5;
  while(1) {
   $11 = ($12|0)==(0|0);
   if ($11) {
    $14 = 0;
   } else {
    ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;
    $$pre1$i = HEAP32[$4>>2]|0;
    $14 = $$pre1$i;
   }
   $13 = (($14) + 12|0);
   HEAP32[$4>>2] = $13;
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$12 = $13;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = (($this) + 8|0);
 $18 = HEAP32[$this>>2]|0;
 $19 = $18;
 $20 = (($7) - ($19))|0;
 $21 = (($20|0) / 12)&-1;
 $22 = (($21) + ($__n))|0;
 $23 = ($22|0)<(0);
 if ($23) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $24 = (($6) - ($19))|0;
 $25 = (($24|0) / 12)&-1;
 $26 = ($25>>>0)<(1073741823);
 if ($26) {
  $29 = $25 << 1;
  $30 = ($29>>>0)<($22>>>0);
  $31 = $30 ? $22 : $29;
  $32 = (($__v) + 12|0);
  HEAP32[$32>>2] = 0;
  $33 = (($__v) + 16|0);
  HEAP32[$33>>2] = $17;
  $34 = ($31|0)==(0);
  if ($34) {
   $$0$i115 = 0;$37 = 0;$42 = $32;
  } else {
   $$0$i114 = $31;$94 = $32;
   label = 10;
  }
 } else {
  $27 = (($__v) + 12|0);
  HEAP32[$27>>2] = 0;
  $28 = (($__v) + 16|0);
  HEAP32[$28>>2] = $17;
  $$0$i114 = 2147483647;$94 = $27;
  label = 10;
 }
 if ((label|0) == 10) {
  $35 = ($$0$i114*12)|0;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  $36 = (__Z15malloc_internaljj10MemLabelIdiPKci($35,16,$$byval_copy4,0,804096,79)|0);
  $$0$i115 = $$0$i114;$37 = $36;$42 = $94;
 }
 HEAP32[$__v>>2] = $37;
 $38 = (($37) + (($21*12)|0)|0);
 $39 = (($__v) + 8|0);
 HEAP32[$39>>2] = $38;
 $40 = (($__v) + 4|0);
 HEAP32[$40>>2] = $38;
 $41 = (($37) + (($$0$i115*12)|0)|0);
 HEAP32[$42>>2] = $41;
 $$0$i9 = $__n;$$pre1$i1113 = $38;
 while(1) {
  $43 = ($$pre1$i1113|0)==(0|0);
  if ($43) {
   $45 = 0;
  } else {
   ;HEAP32[$$pre1$i1113+0>>2]=0|0;HEAP32[$$pre1$i1113+4>>2]=0|0;HEAP32[$$pre1$i1113+8>>2]=0|0;
   $45 = $$pre1$i1113;
  }
  $44 = (($45) + 12|0);
  $46 = (($$0$i9) + -1)|0;
  $47 = ($46|0)==(0);
  if ($47) {
   break;
  } else {
   $$0$i9 = $46;$$pre1$i1113 = $44;
  }
 }
 HEAP32[$39>>2] = $44;
 __THREW__ = 0;
 invoke_vii(3431,($this|0),($__v|0));
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  $73 = HEAP32[$40>>2]|0;
  $74 = HEAP32[$39>>2]|0;
  $75 = ($74|0)==($73|0);
  L26: do {
   if (!($75)) {
    $77 = $74;
    while(1) {
     $76 = (($77) + -12|0);
     HEAP32[$39>>2] = $76;
     $78 = HEAP8[$76>>0]|0;
     $79 = $78 & 1;
     $80 = ($79<<24>>24)==(0);
     if (!($80)) {
      $82 = (($77) + -4|0);
      $83 = HEAP32[$82>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($83|0),($$byval_copy4|0));
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if ($85) {
       break;
      }
     }
     $81 = ($76|0)==($73|0);
     if ($81) {
      break L26;
     } else {
      $77 = $76;
     }
    }
    $86 = ___cxa_find_matching_catch()|0;
    $87 = tempRet0;
    ___cxa_call_unexpected(($86|0));
    // unreachable;
   }
  } while(0);
  $88 = HEAP32[$__v>>2]|0;
  $89 = ($88|0)==(0|0);
  if ($89) {
   ___resumeException($71|0);
   // unreachable;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($88|0),($$byval_copy4|0));
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   $92 = ___cxa_find_matching_catch()|0;
   $93 = tempRet0;
   ___cxa_call_unexpected(($92|0));
   // unreachable;
  } else {
   ___resumeException($71|0);
   // unreachable;
  }
 } else {
  $50 = HEAP32[$40>>2]|0;
  $51 = HEAP32[$39>>2]|0;
  $52 = ($51|0)==($50|0);
  L42: do {
   if (!($52)) {
    $54 = $51;
    while(1) {
     $53 = (($54) + -12|0);
     HEAP32[$39>>2] = $53;
     $55 = HEAP8[$53>>0]|0;
     $56 = $55 & 1;
     $57 = ($56<<24>>24)==(0);
     if (!($57)) {
      $59 = (($54) + -4|0);
      $60 = HEAP32[$59>>2]|0;
      HEAP32[$1>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($60|0),($$byval_copy4|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
     }
     $58 = ($53|0)==($50|0);
     if ($58) {
      break L42;
     } else {
      $54 = $53;
     }
    }
    $63 = ___cxa_find_matching_catch()|0;
    $64 = tempRet0;
    ___cxa_call_unexpected(($63|0));
    // unreachable;
   }
  } while(0);
  $65 = HEAP32[$__v>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($65|0),($$byval_copy4|0));
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if ($68) {
   $69 = ___cxa_find_matching_catch()|0;
   $70 = tempRet0;
   ___cxa_call_unexpected(($69|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre = HEAP32[$1>>2]|0;
   $$pre7 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre8 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$20 = $$pre8;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$20 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $22 = $$pre$i$i$i4;
 } else {
  $21 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $21;
  HEAP32[$1>>2] = $6;
  $22 = $21;
 }
 $23 = (_llvm_bswap_i32(($22|0))|0);
 HEAP32[$size1>>2] = $23;
 __Z14resize_trimmedINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$23);
 $24 = (($data) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$data>>2]|0;
 $27 = ($26|0)==($25|0);
 if ($27) {
  STACKTOP = sp;return;
 } else {
  $33 = $26;
 }
 while(1) {
  $28 = HEAP32[$1>>2]|0;
  $29 = (($28) + 1|0);
  $30 = HEAP32[$7>>2]|0;
  $31 = ($29>>>0)>($30>>>0);
  if ($31) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$33,1);
  } else {
   $32 = HEAP8[$28>>0]|0;
   HEAP8[$33>>0] = $32;
   $34 = HEAP32[$1>>2]|0;
   $35 = (($34) + 1|0);
   HEAP32[$1>>2] = $35;
  }
  $36 = (($33) + 1|0);
  $37 = ($36|0)==($25|0);
  if ($37) {
   break;
  } else {
   $33 = $36;
  }
 }
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre20 = 0, $$pre21 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = ($10>>>0)<($sz>>>0);
 if (!($11)) {
  $72 = ($10>>>0)>($sz>>>0);
  if (!($72)) {
   STACKTOP = sp;return;
  }
  $73 = (($7) + ($sz)|0);
  $74 = ($sz|0)==(0);
  do {
   if ($74) {
    $90 = 0;$91 = 0;$93 = 0;$95 = $7;
   } else {
    $75 = ($sz|0)<(0);
    if ($75) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if (!($77)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $78 = (invoke_iiiiiii(102,($sz|0),16,($$byval_copy7|0),0,(804096|0),79)|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      $82 = $78;$84 = $7;
      while(1) {
       $81 = ($82|0)==(0|0);
       if ($81) {
        $86 = 0;
       } else {
        $83 = HEAP8[$84>>0]|0;
        HEAP8[$82>>0] = $83;
        $86 = $82;
       }
       $85 = (($86) + 1|0);
       $87 = (($84) + 1|0);
       $88 = ($87|0)==($73|0);
       if ($88) {
        break;
       } else {
        $82 = $85;$84 = $87;
       }
      }
      $89 = (($78) + ($sz)|0);
      $$pre = HEAP32[$v>>2]|0;
      $90 = $78;$91 = $85;$93 = $89;$95 = $$pre;
      break;
     }
    }
    $100 = ___cxa_find_matching_catch()|0;
    $101 = tempRet0;
    $$0 = $101;$$01 = $100;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $90;
  HEAP32[$5>>2] = $91;
  $92 = (($v) + 8|0);
  HEAP32[$92>>2] = $93;
  $94 = ($95|0)==(0|0);
  if ($94) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($95|0),($$byval_copy7|0));
  $96 = __THREW__; __THREW__ = 0;
  $97 = $96&1;
  if ($97) {
   $98 = ___cxa_find_matching_catch()|0;
   $99 = tempRet0;
   ___cxa_call_unexpected(($98|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $12 = (($v) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($9))|0;
 $16 = ($15|0)==($sz|0);
 if ($16) {
  $71 = (($sz) - ($10))|0;
  __ZNSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEE8__appendEj($v,$71);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $17 = (($temp) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($temp) + 8|0);
 HEAP32[$18>>2] = 0;
 $19 = ($sz|0)==(0);
 if ($19) {
  label = 8;
 } else {
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (invoke_iiiiiii(102,($sz|0),16,($$byval_copy7|0),0,(804096|0),79)|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$17>>2]|0;
   $phitmp = $$pre1$i;
   $23 = (($20) + ($sz)|0);
   $24 = $$pre$i;
   $25 = (($phitmp) - ($24))|0;
   $$sum$i = (0 - ($25))|0;
   $26 = (($20) + ($$sum$i)|0);
   _memcpy(($26|0),($$pre$i|0),($25|0))|0;
   $27 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $26;
   HEAP32[$17>>2] = $20;
   HEAP32[$18>>2] = $23;
   $28 = ($27|0)==(0|0);
   if ($28) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($27|0),($$byval_copy7|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     $31 = ___cxa_find_matching_catch()|0;
     $32 = tempRet0;
     ___cxa_call_unexpected(($31|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $33 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $33;
   $34 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $34;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(2050,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    $37 = HEAP32[$17>>2]|0;
    $38 = HEAP32[$temp>>2]|0;
    $39 = $37;
    $40 = $38;
    $41 = (($39) - ($40))|0;
    $42 = ($41>>>0)<($sz>>>0);
    if ($42) {
     $43 = (($sz) - ($41))|0;
     __THREW__ = 0;
     invoke_vii(3440,($temp|0),($43|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     $$pre20 = HEAP32[$temp>>2]|0;
     $$pre21 = HEAP32[$17>>2]|0;
     $50 = $$pre20;$52 = $$pre21;
    } else {
     $46 = ($41>>>0)>($sz>>>0);
     if ($46) {
      $47 = (($38) + ($sz)|0);
      $48 = ($37|0)==($47|0);
      if ($48) {
       $50 = $38;$52 = $37;
      } else {
       HEAP32[$17>>2] = $47;
       $50 = $38;$52 = $47;
      }
     } else {
      $50 = $38;$52 = $37;
     }
    }
    $49 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $49;
    HEAP32[$v>>2] = $50;
    $51 = HEAP32[$5>>2]|0;
    HEAP32[$17>>2] = $51;
    HEAP32[$5>>2] = $52;
    $53 = HEAP32[$18>>2]|0;
    $54 = HEAP32[$12>>2]|0;
    HEAP32[$18>>2] = $54;
    HEAP32[$12>>2] = $53;
    $55 = ($49|0)==(0|0);
    if ($55) {
     STACKTOP = sp;return;
    }
    $56 = ($51|0)==($49|0);
    if (!($56)) {
     HEAP32[$17>>2] = $49;
    }
    HEAP32[$$byval_copy2>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($49|0),($$byval_copy7|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $59 = ___cxa_find_matching_catch()|0;
     $60 = tempRet0;
     ___cxa_call_unexpected(($59|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $61 = ___cxa_find_matching_catch()|0;
 $62 = tempRet0;
 $63 = HEAP32[$temp>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  $$0 = $62;$$01 = $61;
  ___resumeException($$01|0);
  // unreachable;
 }
 $65 = HEAP32[$17>>2]|0;
 $66 = ($65|0)==($63|0);
 if (!($66)) {
  HEAP32[$17>>2] = $63;
 }
 HEAP32[$$byval_copy2>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($63|0),($$byval_copy7|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch()|0;
  $70 = tempRet0;
  ___cxa_call_unexpected(($69|0));
  // unreachable;
 } else {
  $$0 = $62;$$01 = $61;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPcEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIcNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i31 = 0, $$byval_copy1 = 0, $$pre$i12 = 0, $$pre1$i = 0, $$pre1$i14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = ($5>>>0)>($11>>>0);
 if (!($12)) {
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14;
  $16 = (($15) - ($10))|0;
  $17 = ($5>>>0)>($16>>>0);
  if (!($17)) {
   $28 = $2;
   $29 = (($28) - ($4))|0;
   _memmove(($8|0),($1|0),($29|0))|0;
   $30 = (($8) + ($29)|0);
   $31 = HEAP32[$13>>2]|0;
   $32 = ($31|0)==($30|0);
   if ($32) {
    STACKTOP = sp;return;
   }
   HEAP32[$13>>2] = $30;
   STACKTOP = sp;return;
  }
  $18 = (($1) + ($16)|0);
  _memmove(($8|0),($1|0),($16|0))|0;
  $19 = ($18|0)==($2|0);
  if ($19) {
   STACKTOP = sp;return;
  }
  $$pre$i12 = HEAP32[$13>>2]|0;
  $21 = $$pre$i12;$23 = $18;
  while(1) {
   $20 = ($21|0)==(0|0);
   if ($20) {
    $25 = 0;
   } else {
    $22 = HEAP8[$23>>0]|0;
    HEAP8[$21>>0] = $22;
    $$pre1$i14 = HEAP32[$13>>2]|0;
    $25 = $$pre1$i14;
   }
   $24 = (($25) + 1|0);
   HEAP32[$13>>2] = $24;
   $26 = (($23) + 1|0);
   $27 = ($26|0)==($2|0);
   if ($27) {
    break;
   } else {
    $21 = $24;$23 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 $33 = ($8|0)==(0|0);
 do {
  if ($33) {
   $43 = $7;
  } else {
   $34 = (($this) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==($8|0);
   if (!($36)) {
    HEAP32[$34>>2] = $8;
   }
   HEAP32[$0>>2] = 27;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy1|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    ___cxa_call_unexpected(($39|0));
    // unreachable;
   } else {
    HEAP32[$6>>2] = 0;
    HEAP32[$34>>2] = 0;
    HEAP32[$this>>2] = 0;
    $43 = 0;
    break;
   }
  }
 } while(0);
 $41 = ($5|0)<(0);
 if ($41) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $42 = ($43>>>0)<((1073741823)>>>0);
 if ($42) {
  $44 = $43;
  $45 = $44 << 1;
  $46 = ($45>>>0)<($5>>>0);
  $47 = $46 ? $5 : $45;
  $48 = ($47|0)<(0);
  if ($48) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i31 = $47;
  }
 } else {
  $$0$i31 = 2147483647;
 }
 HEAP32[$0>>2] = 27;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $49 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i31,16,$$byval_copy1,0,804096,79)|0);
 $50 = (($this) + 4|0);
 HEAP32[$50>>2] = $49;
 HEAP32[$this>>2] = $49;
 $51 = (($49) + ($$0$i31)|0);
 HEAP32[$6>>2] = $51;
 $52 = ($1|0)==($2|0);
 if ($52) {
  STACKTOP = sp;return;
 } else {
  $54 = $49;$56 = $1;
 }
 while(1) {
  $53 = ($54|0)==(0|0);
  if ($53) {
   $58 = 0;
  } else {
   $55 = HEAP8[$56>>0]|0;
   HEAP8[$54>>0] = $55;
   $$pre1$i = HEAP32[$50>>2]|0;
   $58 = $$pre1$i;
  }
  $57 = (($58) + 1|0);
  HEAP32[$50>>2] = $57;
  $59 = (($56) + 1|0);
  $60 = ($59|0)==($2|0);
  if ($60) {
   break;
  } else {
   $54 = $57;$56 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $4;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $12 = 0;
   } else {
    HEAP8[$10>>0] = 0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $12 = $$pre1$i;
   }
   $11 = (($12) + 1|0);
   HEAP32[$3>>2] = $11;
   $13 = (($$0$i) + -1)|0;
   $14 = ($13|0)==(0);
   if ($14) {
    break;
   } else {
    $$0$i = $13;$10 = $11;
   }
  }
  STACKTOP = sp;return;
 }
 $15 = HEAP32[$this>>2]|0;
 $16 = $15;
 $17 = (($6) - ($16))|0;
 $18 = (($17) + ($__n))|0;
 $19 = ($18|0)<(0);
 if ($19) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $20 = (($5) - ($16))|0;
 $21 = ($20>>>0)<(1073741823);
 if ($21) {
  $22 = $20 << 1;
  $23 = ($22>>>0)<($18>>>0);
  $24 = $23 ? $18 : $22;
  $25 = ($24|0)==(0);
  if ($25) {
   $$0$i57 = 0;$28 = 0;
  } else {
   $$0$i56 = $24;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($$0$i56,16,$$byval_copy1,0,804096,79)|0);
  $$0$i57 = $$0$i56;$28 = $26;
 }
 $27 = (($28) + ($17)|0);
 $$0$i2 = $__n;$30 = $27;
 while(1) {
  $29 = ($30|0)==(0|0);
  if ($29) {
   $32 = 0;
  } else {
   HEAP8[$30>>0] = 0;
   $32 = $30;
  }
  $31 = (($32) + 1|0);
  $33 = (($$0$i2) + -1)|0;
  $34 = ($33|0)==(0);
  if ($34) {
   break;
  } else {
   $$0$i2 = $33;$30 = $31;
  }
 }
 $35 = (($28) + ($$0$i57)|0);
 $36 = HEAP32[$this>>2]|0;
 $37 = HEAP32[$3>>2]|0;
 $38 = $37;
 $39 = $36;
 $40 = (($38) - ($39))|0;
 $$sum = (($17) - ($40))|0;
 $41 = (($28) + ($$sum)|0);
 _memcpy(($41|0),($36|0),($40|0))|0;
 $42 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $41;
 HEAP32[$3>>2] = $31;
 HEAP32[$1>>2] = $35;
 $43 = ($42|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($42|0),($$byval_copy1|0));
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if ($45) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  ___cxa_call_unexpected(($46|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorINS0_4pairIifEE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre46 = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0;
 var $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i27 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 3;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + ($sz<<3)|0);
  $$idx = $sz << 3;
  $88 = $$idx >> 3;
  $89 = ($88|0)==(0);
  L6: do {
   if ($89) {
    $116 = 0;$117 = 0;$119 = 0;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(804096|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = (($93) + ($88<<3)|0);
      $97 = ($sz|0)==(0);
      if ($97) {
       $116 = $93;$117 = $93;$119 = $96;
       break;
      } else {
       $101 = $7;$99 = $93;
      }
      while(1) {
       $98 = ($99|0)==(0|0);
       if ($98) {
        $112 = 0;
       } else {
        $100 = $101;
        $102 = $100;
        $103 = HEAP32[$102>>2]|0;
        $104 = (($100) + 4)|0;
        $105 = $104;
        $106 = HEAP32[$105>>2]|0;
        $107 = $99;
        $108 = $107;
        HEAP32[$108>>2] = $103;
        $109 = (($107) + 4)|0;
        $110 = $109;
        HEAP32[$110>>2] = $106;
        $112 = $99;
       }
       $111 = (($112) + 8|0);
       $113 = (($101) + 8|0);
       $114 = ($113|0)==($87|0);
       if ($114) {
        $116 = $93;$117 = $111;$119 = $96;
        break L6;
       } else {
        $101 = $113;$99 = $111;
       }
      }
     }
    }
    $125 = ___cxa_find_matching_catch()|0;
    $126 = tempRet0;
    $$0 = $126;$$01 = $125;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  $115 = HEAP32[$v>>2]|0;
  HEAP32[$v>>2] = $116;
  HEAP32[$5>>2] = $117;
  $118 = (($v) + 8|0);
  HEAP32[$118>>2] = $119;
  $120 = ($115|0)==(0|0);
  if ($120) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($115|0),($$byval_copy7|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   $123 = ___cxa_find_matching_catch()|0;
   $124 = tempRet0;
   ___cxa_call_unexpected(($123|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = $16 >> 3;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorINS_4pairIifEE13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = $sz << 3;
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(804096|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + ($sz<<3)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = $28 >> 3;
   $$sum$i = (0 - ($29))|0;
   $30 = (($23) + ($$sum$i<<3)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(2051,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = $45 >> 3;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(3441,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + ($sz<<3)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -8|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = $uglygep3$i$i$i >>> 3;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + ($56<<3)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -8|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = $uglygep3$i$i$i$i$i19 >>> 3;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + ($67<<3)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -8|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = $uglygep3$i$i$i$i$i28 >>> 3;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + ($80<<3)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorINS_4pairIifEE13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i40 = 0, $$0$lcssa$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $$pre5$i = 0, $$pre5$i22 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $__growing$0$off0 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep$i$i8 = 0, $scevgep4$i$i = 0, $scevgep4$i$i$i$i = 0, $scevgep6$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep$i$i9 = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, $uglygep5$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 3;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 3;
 $14 = ($6>>>0)>($13>>>0);
 if ($14) {
  $57 = ($9|0)==(0|0);
  do {
   if ($57) {
    $70 = $8;
   } else {
    $58 = (($this) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59|0)==($9|0);
    if (!($60)) {
     $scevgep$i$i$i$i = (($59) + -8|0);
     $61 = (0 - ($11))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($61)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $62 = $uglygep3$i$i$i$i >>> 3;
     $63 = $62 ^ -1;
     $scevgep4$i$i$i$i = (($59) + ($63<<3)|0);
     HEAP32[$58>>2] = $scevgep4$i$i$i$i;
    }
    HEAP32[$0>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($9|0),($$byval_copy1|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     $66 = ___cxa_find_matching_catch()|0;
     $67 = tempRet0;
     ___cxa_call_unexpected(($66|0));
     // unreachable;
    } else {
     HEAP32[$7>>2] = 0;
     HEAP32[$58>>2] = 0;
     HEAP32[$this>>2] = 0;
     $70 = 0;
     break;
    }
   }
  } while(0);
  $68 = ($5|0)<(0);
  if ($68) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $69 = $70;
  $71 = $69 >> 3;
  $72 = ($71>>>0)<(1073741823);
  if ($72) {
   $73 = $69 >> 2;
   $74 = ($73>>>0)<($6>>>0);
   $75 = $74 ? $6 : $73;
   $76 = ($75|0)<(0);
   if ($76) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   } else {
    $$0$i40 = $75;
   }
  } else {
   $$0$i40 = 2147483647;
  }
  $77 = $$0$i40 << 3;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $78 = (__Z15malloc_internaljj10MemLabelIdiPKci($77,16,$$byval_copy1,0,804096,79)|0);
  $79 = (($this) + 4|0);
  HEAP32[$79>>2] = $78;
  HEAP32[$this>>2] = $78;
  $80 = (($78) + ($$0$i40<<3)|0);
  HEAP32[$7>>2] = $80;
  $81 = ($1|0)==($2|0);
  if ($81) {
   STACKTOP = sp;return;
  } else {
   $83 = $78;$85 = $1;
  }
  while(1) {
   $82 = ($83|0)==(0|0);
   if ($82) {
    $96 = 0;
   } else {
    $84 = $85;
    $86 = $84;
    $87 = HEAP32[$86>>2]|0;
    $88 = (($84) + 4)|0;
    $89 = $88;
    $90 = HEAP32[$89>>2]|0;
    $91 = $83;
    $92 = $91;
    HEAP32[$92>>2] = $87;
    $93 = (($91) + 4)|0;
    $94 = $93;
    HEAP32[$94>>2] = $90;
    $$pre5$i = HEAP32[$79>>2]|0;
    $96 = $$pre5$i;
   }
   $95 = (($96) + 8|0);
   HEAP32[$79>>2] = $95;
   $97 = (($85) + 8|0);
   $98 = ($97|0)==($2|0);
   if ($98) {
    break;
   } else {
    $83 = $95;$85 = $97;
   }
  }
  STACKTOP = sp;return;
 } else {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = $18 >> 3;
  $20 = ($6>>>0)>($19>>>0);
  if ($20) {
   $21 = (($1) + ($19<<3)|0);
   $23 = $21;$__growing$0$off0 = 1;
  } else {
   $23 = $2;$__growing$0$off0 = 0;
  }
  $22 = ($1|0)==($23|0);
  if ($22) {
   $$0$lcssa$i$i = $9;
  } else {
   $scevgep$i$i = (($23) + -8|0);
   $24 = (0 - ($4))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($24)|0);
   $uglygep5$i$i = $uglygep$i$i;
   $25 = $uglygep5$i$i >>> 3;
   $$01$i$i = $9;$27 = $1;
   while(1) {
    $26 = HEAP32[$27>>2]|0;
    HEAP32[$$01$i$i>>2] = $26;
    $28 = (($27) + 4|0);
    $29 = Math_fround(HEAPF32[$28>>2]);
    $30 = (($$01$i$i) + 4|0);
    HEAPF32[$30>>2] = $29;
    $31 = (($27) + 8|0);
    $32 = (($$01$i$i) + 8|0);
    $33 = ($31|0)==($23|0);
    if ($33) {
     break;
    } else {
     $$01$i$i = $32;$27 = $31;
    }
   }
   $34 = (($25) + 1)|0;
   $scevgep6$i$i = (($9) + ($34<<3)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  if (!($__growing$0$off0)) {
   $53 = ($16|0)==($$0$lcssa$i$i|0);
   if ($53) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $$0$lcssa$i$i;
   $scevgep$i$i8 = (($16) + -8|0);
   $54 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i9 = (($scevgep$i$i8) + ($54)|0);
   $uglygep3$i$i = $uglygep$i$i9;
   $55 = $uglygep3$i$i >>> 3;
   $56 = $55 ^ -1;
   $scevgep4$i$i = (($16) + ($56<<3)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $35 = ($23|0)==($2|0);
  if ($35) {
   STACKTOP = sp;return;
  } else {
   $37 = $16;$39 = $23;
  }
  while(1) {
   $36 = ($37|0)==(0|0);
   if ($36) {
    $50 = 0;
   } else {
    $38 = $39;
    $40 = $38;
    $41 = HEAP32[$40>>2]|0;
    $42 = (($38) + 4)|0;
    $43 = $42;
    $44 = HEAP32[$43>>2]|0;
    $45 = $37;
    $46 = $45;
    HEAP32[$46>>2] = $41;
    $47 = (($45) + 4)|0;
    $48 = $47;
    HEAP32[$48>>2] = $44;
    $$pre5$i22 = HEAP32[$15>>2]|0;
    $50 = $$pre5$i22;
   }
   $49 = (($50) + 8|0);
   HEAP32[$15>>2] = $49;
   $51 = (($39) + 8|0);
   $52 = ($51|0)==($2|0);
   if ($52) {
    break;
   } else {
    $37 = $49;$39 = $51;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorINS_4pairIifEE13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i57 = 0, $$0$i58 = 0, $$byval_copy1 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $scevgep$i = 0;
 var $scevgep$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if (!($10)) {
    HEAP32[$11>>2] = 0;
    $12 = (($11) + 4|0);
    HEAPF32[$12>>2] = Math_fround(0.0);
   }
   $13 = (($11) + 8|0);
   $14 = (($$0$i) + -1)|0;
   $15 = ($14|0)==(0);
   if ($15) {
    break;
   } else {
    $$0$i = $14;$11 = $13;
   }
  }
  $scevgep$i = (($4) + ($__n<<3)|0);
  HEAP32[$3>>2] = $scevgep$i;
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$this>>2]|0;
 $17 = $16;
 $18 = (($6) - ($17))|0;
 $19 = $18 >> 3;
 $20 = (($19) + ($__n))|0;
 $21 = ($20|0)<(0);
 if ($21) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = (($5) - ($17))|0;
 $23 = $22 >> 3;
 $24 = ($23>>>0)<(1073741823);
 if ($24) {
  $25 = $22 >> 2;
  $26 = ($25>>>0)<($20>>>0);
  $27 = $26 ? $20 : $25;
  $28 = ($27|0)==(0);
  if ($28) {
   $$0$i58 = 0;$32 = 0;
  } else {
   $$0$i57 = $27;
   label = 10;
  }
 } else {
  $$0$i57 = 2147483647;
  label = 10;
 }
 if ((label|0) == 10) {
  $29 = $$0$i57 << 3;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $30 = (__Z15malloc_internaljj10MemLabelIdiPKci($29,16,$$byval_copy1,0,804096,79)|0);
  $$0$i58 = $$0$i57;$32 = $30;
 }
 $31 = (($32) + ($19<<3)|0);
 $$0$i2 = $__n;$34 = $31;
 while(1) {
  $33 = ($34|0)==(0|0);
  if (!($33)) {
   HEAP32[$34>>2] = 0;
   $35 = (($34) + 4|0);
   HEAPF32[$35>>2] = Math_fround(0.0);
  }
  $36 = (($34) + 8|0);
  $37 = (($$0$i2) + -1)|0;
  $38 = ($37|0)==(0);
  if ($38) {
   break;
  } else {
   $$0$i2 = $37;$34 = $36;
  }
 }
 $39 = (($32) + ($$0$i58<<3)|0);
 $scevgep$i4 = (($32) + ($20<<3)|0);
 $40 = HEAP32[$this>>2]|0;
 $41 = HEAP32[$3>>2]|0;
 $42 = $41;
 $43 = $40;
 $44 = (($42) - ($43))|0;
 $45 = $44 >> 3;
 $$sum6 = (($19) - ($45))|0;
 $46 = (($32) + ($$sum6<<3)|0);
 _memcpy(($46|0),($40|0),($44|0))|0;
 $47 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $46;
 HEAP32[$3>>2] = $scevgep$i4;
 HEAP32[$1>>2] = $39;
 $48 = ($47|0)==(0|0);
 if ($48) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($47|0),($$byval_copy1|0));
 $49 = __THREW__; __THREW__ = 0;
 $50 = $49&1;
 if ($50) {
  $51 = ___cxa_find_matching_catch()|0;
  $52 = tempRet0;
  ___cxa_call_unexpected(($51|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI10vector_mapINSt3__14pairIttEEfN20TextRenderingPrivate4Font14KerningCompareENS3_9allocatorINS4_IS5_fEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre10 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0;
 var $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre$i$i$i = HEAP32[$size>>2]|0;
   $$pre8 = HEAP32[$1>>2]|0;
   $$pre9 = HEAP32[$7>>2]|0;
   $11 = $$pre$i$i$i;$14 = $$pre8;$16 = $$pre9;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $11 = $10;$14 = $6;$16 = $8;
  }
  $12 = (_llvm_bswap_i32(($11|0))|0);
  HEAP32[$size>>2] = $12;
  $13 = (($14) + 4|0);
  $15 = ($13>>>0)>($16>>>0);
  if ($15) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
   $$pre10 = HEAP32[$size>>2]|0;
   $18 = $$pre$i$i$i1;$21 = $$pre10;
  } else {
   $17 = HEAP32[$14>>2]|0;
   HEAP32[$offset>>2] = $17;
   HEAP32[$1>>2] = $13;
   $18 = $17;$21 = $12;
  }
  $19 = (_llvm_bswap_i32(($18|0))|0);
  HEAP32[$offset>>2] = $19;
  $20 = $21 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
  $23 = $$pre$i$i$i4;
 } else {
  $22 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $22;
  HEAP32[$1>>2] = $6;
  $23 = $22;
 }
 $24 = (_llvm_bswap_i32(($23|0))|0);
 HEAP32[$size1>>2] = $24;
 $25 = (($data) + 4|0);
 $26 = (($data) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$25>>2]|0;
 $29 = $27;
 $30 = $28;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 3;
 $33 = ($32>>>0)<($24>>>0);
 if ($33) {
  $34 = (($24) - ($32))|0;
  __ZNSt3__16vectorINS_4pairINS1_IttEEfEENS_9allocatorIS3_EEE8__appendEj($25,$34);
  $$pre = HEAP32[$26>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre7 = HEAP32[$$phi$trans$insert>>2]|0;
  $42 = $$pre7;$43 = $$pre;
 } else {
  $35 = ($32>>>0)>($24>>>0);
  if ($35) {
   $36 = (($28) + ($24<<3)|0);
   $37 = ($27|0)==($36|0);
   if ($37) {
    $42 = $28;$43 = $27;
   } else {
    $__new_last2$i$i$i$i = $36;
    $scevgep$i$i$i$i = (($27) + -8|0);
    $38 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($38)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $39 = $uglygep3$i$i$i$i >>> 3;
    $40 = $39 ^ -1;
    $scevgep4$i$i$i$i = (($27) + ($40<<3)|0);
    HEAP32[$26>>2] = $scevgep4$i$i$i$i;
    $42 = $28;$43 = $scevgep4$i$i$i$i;
   }
  } else {
   $42 = $28;$43 = $27;
  }
 }
 $41 = ($42|0)==($43|0);
 if ($41) {
  STACKTOP = sp;return;
 } else {
  $44 = $42;
 }
 while(1) {
  __ZN15SerializeTraitsINSt3__14pairINS1_IttEEfEEE8TransferI18StreamedBinaryReadILb1EEEEvRS3_RT_($44,$this);
  $45 = (($44) + 8|0);
  $46 = ($45|0)==($43|0);
  if ($46) {
   break;
  } else {
   $44 = $45;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15SerializeTraitsINSt3__14pairINS1_IttEEfEEE8TransferI18StreamedBinaryReadILb1EEEEvRS3_RT_($data,$transfer) {
 $data = $data|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i1$i$i = 0, $$pre$phi$i$i$iZ2D = 0, $$pre1 = 0, $$pre3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 2|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$data,2);
  $$pre$i$i$i$i$i = HEAP16[$data>>1]|0;
  $$pre$i$i = HEAP32[$0>>2]|0;
  $$pre3$i$i = HEAP32[$3>>2]|0;
  $15 = $$pre$i$i;$17 = $$pre3$i$i;$8 = $$pre$i$i$i$i$i;
 } else {
  $6 = HEAP16[$1>>1]|0;
  HEAP16[$data>>1] = $6;
  HEAP32[$0>>2] = $2;
  $15 = $2;$17 = $4;$8 = $6;
 }
 $7 = $8&65535;
 $9 = $7 << 8;
 $10 = $7 >>> 8;
 $11 = $9 | $10;
 $12 = $11&65535;
 HEAP16[$data>>1] = $12;
 $13 = (($data) + 2|0);
 $14 = (($15) + 2|0);
 $16 = ($14>>>0)>($17>>>0);
 if ($16) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$13,2);
  $$pre$i$i$i1$i$i = HEAP16[$13>>1]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre1 = HEAP32[$3>>2]|0;
  $20 = $$pre$i$i$i1$i$i;$27 = $$pre;$29 = $$pre1;
 } else {
  $18 = HEAP16[$15>>1]|0;
  HEAP16[$13>>1] = $18;
  HEAP32[$0>>2] = $14;
  $20 = $18;$27 = $14;$29 = $17;
 }
 $19 = $20&65535;
 $21 = $19 << 8;
 $22 = $19 >>> 8;
 $23 = $21 | $22;
 $24 = $23&65535;
 HEAP16[$13>>1] = $24;
 $25 = (($data) + 4|0);
 $26 = (($27) + 4|0);
 $28 = ($26>>>0)>($29>>>0);
 if ($28) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$25,4);
  $$pre$i$i$i = HEAP32[$25>>2]|0;
  $$pre$phi$i$i$iZ2D = $25;$32 = $$pre$i$i$i;
  $33 = (_llvm_bswap_i32(($32|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $33;
  STACKTOP = sp;return;
 } else {
  $30 = Math_fround(HEAPF32[$27>>2]);
  HEAPF32[$25>>2] = $30;
  HEAP32[$0>>2] = $26;
  $31 = (HEAPF32[tempDoublePtr>>2]=$30,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $25;$32 = $31;
  $33 = (_llvm_bswap_i32(($32|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $33;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorINS_4pairINS1_IttEEfEENS_9allocatorIS3_EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 3;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  $$0$i = $__n;$10 = $3;
  while(1) {
   $9 = ($10|0)==(0|0);
   if ($9) {
    $16 = 0;
   } else {
    $11 = $10;
    $12 = $11;
    HEAP16[$12>>1]=0&65535;HEAP16[$12+2>>1]=0>>>16;
    $13 = (($11) + 4)|0;
    $14 = $13;
    HEAP16[$14>>1]=0&65535;HEAP16[$14+2>>1]=0>>>16;
    $$pre1$i = HEAP32[$2>>2]|0;
    $16 = $$pre1$i;
   }
   $15 = (($16) + 8|0);
   HEAP32[$2>>2] = $15;
   $17 = (($$0$i) + -1)|0;
   $18 = ($17|0)==(0);
   if ($18) {
    break;
   } else {
    $$0$i = $17;$10 = $15;
   }
  }
  STACKTOP = sp;return;
 }
 $19 = HEAP32[$this>>2]|0;
 $20 = $19;
 $21 = (($5) - ($20))|0;
 $22 = $21 >> 3;
 $23 = (($22) + ($__n))|0;
 $24 = ($23>>>0)>(536870911);
 if ($24) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $25 = (($4) - ($20))|0;
 $26 = $25 >> 3;
 $27 = ($26>>>0)<(268435455);
 if ($27) {
  $28 = $25 >> 2;
  $29 = ($28>>>0)<($23>>>0);
  $30 = $29 ? $23 : $28;
  $31 = ($30|0)==(0);
  if ($31) {
   $$0$i57 = 0;$35 = 0;
  } else {
   $$0$i56 = $30;
   label = 9;
  }
 } else {
  $$0$i56 = 536870911;
  label = 9;
 }
 if ((label|0) == 9) {
  $32 = $$0$i56 << 3;
  $33 = (__Znwj($32)|0);
  $$0$i57 = $$0$i56;$35 = $33;
 }
 $34 = (($35) + ($22<<3)|0);
 $$0$i2 = $__n;$37 = $34;
 while(1) {
  $36 = ($37|0)==(0|0);
  if ($36) {
   $43 = 0;
  } else {
   $38 = $37;
   $39 = $38;
   HEAP16[$39>>1]=0&65535;HEAP16[$39+2>>1]=0>>>16;
   $40 = (($38) + 4)|0;
   $41 = $40;
   HEAP16[$41>>1]=0&65535;HEAP16[$41+2>>1]=0>>>16;
   $43 = $37;
  }
  $42 = (($43) + 8|0);
  $44 = (($$0$i2) + -1)|0;
  $45 = ($44|0)==(0);
  if ($45) {
   break;
  } else {
   $$0$i2 = $44;$37 = $42;
  }
 }
 $46 = (($35) + ($$0$i57<<3)|0);
 $47 = HEAP32[$this>>2]|0;
 $48 = HEAP32[$2>>2]|0;
 $49 = $48;
 $50 = $47;
 $51 = (($49) - ($50))|0;
 $52 = $51 >> 3;
 $$sum = (($22) - ($52))|0;
 $53 = (($35) + ($$sum<<3)|0);
 _memcpy(($53|0),($47|0),($51|0))|0;
 HEAP32[$this>>2] = $53;
 HEAP32[$2>>2] = $42;
 HEAP32[$0>>2] = $46;
 $54 = ($47|0)==(0|0);
 if ($54) {
  STACKTOP = sp;return;
 }
 __ZdlPv($47);
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 56|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*56)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
  $$pre$i$i$i = HEAP32[$this>>2]|0;
  $7 = $$pre$i$i$i;
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
  $7 = $6;
 }
 $8 = (_llvm_bswap_i32(($7|0))|0);
 HEAP32[$this>>2] = $8;
 $9 = (($this) + 4|0);
 __ZN5RectTIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($9,$transfer);
 $10 = (($this) + 20|0);
 __ZN5RectTIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 $11 = (($this) + 36|0);
 $12 = HEAP32[$0>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$3>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$11,4);
  $$pre$i$i$i1 = HEAP32[$11>>2]|0;
  $$pre = HEAP32[$0>>2]|0;
  $$pre2 = HEAP32[$3>>2]|0;
  $$pre$phi$i$i$iZ2D = $11;$18 = $$pre$i$i$i1;$22 = $$pre;$24 = $$pre2;
 } else {
  $16 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$0>>2] = $13;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $11;$18 = $17;$22 = $13;$24 = $14;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $19;
 $20 = (($this) + 52|0);
 $21 = (($22) + 1|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$20,1);
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$0>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$0>>2] = $27;
  __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __Z14resize_trimmedINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i27 = 0;
 var $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 56)&-1;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + (($sz*56)|0)|0);
  $$idx = ($sz*56)|0;
  $88 = (($$idx|0) / 56)&-1;
  $89 = ($sz|0)==(0);
  do {
   if ($89) {
    $104 = 0;$105 = 0;$107 = 0;$109 = $7;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(804096|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $97 = $93;$98 = $7;
      while(1) {
       $96 = ($97|0)==(0|0);
       if ($96) {
        $100 = 0;
       } else {
        dest=$97+0|0; src=$98+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $100 = $97;
       }
       $99 = (($100) + 56|0);
       $101 = (($98) + 56|0);
       $102 = ($101|0)==($87|0);
       if ($102) {
        break;
       } else {
        $97 = $99;$98 = $101;
       }
      }
      $103 = (($93) + (($88*56)|0)|0);
      $$pre = HEAP32[$v>>2]|0;
      $104 = $93;$105 = $99;$107 = $103;$109 = $$pre;
      break;
     }
    }
    $114 = ___cxa_find_matching_catch()|0;
    $115 = tempRet0;
    $$0 = $115;$$01 = $114;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $104;
  HEAP32[$5>>2] = $105;
  $106 = (($v) + 8|0);
  HEAP32[$106>>2] = $107;
  $108 = ($109|0)==(0|0);
  if ($108) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($109|0),($$byval_copy7|0));
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if ($111) {
   $112 = ___cxa_find_matching_catch()|0;
   $113 = tempRet0;
   ___cxa_call_unexpected(($112|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 56)&-1;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = ($sz*56)|0;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(804096|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + (($sz*56)|0)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = (($28|0) / -56)&-1;
   $30 = (($23) + (($29*56)|0)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(2052,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = (($45|0) / 56)&-1;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(3442,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre45 = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre45;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + (($sz*56)|0)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -56|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = (($uglygep3$i$i$i>>>0) / 56)&-1;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + (($56*56)|0)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -56|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = (($uglygep3$i$i$i$i$i19>>>0) / 56)&-1;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + (($67*56)|0)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -56|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = (($uglygep3$i$i$i$i$i28>>>0) / 56)&-1;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + (($80*56)|0)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 56)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 56)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = (($18|0) / 56)&-1;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = (($31|0) / 56)&-1;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + (($32*56)|0)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -56|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = (($uglygep3$i$i>>>0) / 56)&-1;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + (($38*56)|0)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + (($19*56)|0)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    dest=$24+0|0; src=$25+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 56|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 56|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -56|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = (($uglygep3$i$i$i$i>>>0) / 56)&-1;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + (($45*56)|0)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = (($51|0) / 56)&-1;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $53 << 1;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = ($$0$i37*56)|0;
 HEAP32[$0>>2] = 90;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,804096,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + (($$0$i37*56)|0)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   dest=$65+0|0; src=$66+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 56|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 56|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $14 = 0;
   } else {
    HEAP32[$11>>2] = -1;
    $12 = (($11) + 4|0);
    dest=$12+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$12+48>>0]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $14 = $$pre1$i;
   }
   $13 = (($14) + 56|0);
   HEAP32[$3>>2] = $13;
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$11 = $13;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($6) - ($18))|0;
 $20 = (($19|0) / 56)&-1;
 $21 = (($20) + ($__n))|0;
 $22 = ($21|0)<(0);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($5) - ($18))|0;
 $24 = (($23|0) / 56)&-1;
 $25 = ($24>>>0)<(1073741823);
 if ($25) {
  $26 = $24 << 1;
  $27 = ($26>>>0)<($21>>>0);
  $28 = $27 ? $21 : $26;
  $29 = ($28|0)==(0);
  if ($29) {
   $$0$i57 = 0;$33 = 0;
  } else {
   $$0$i56 = $28;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $30 = ($$0$i56*56)|0;
  HEAP32[$0>>2] = 90;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $31 = (__Z15malloc_internaljj10MemLabelIdiPKci($30,16,$$byval_copy1,0,804096,79)|0);
  $$0$i57 = $$0$i56;$33 = $31;
 }
 $32 = (($33) + (($20*56)|0)|0);
 $$0$i2 = $__n;$35 = $32;
 while(1) {
  $34 = ($35|0)==(0|0);
  if ($34) {
   $38 = 0;
  } else {
   HEAP32[$35>>2] = -1;
   $36 = (($35) + 4|0);
   dest=$36+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$36+48>>0]=0|0;
   $38 = $35;
  }
  $37 = (($38) + 56|0);
  $39 = (($$0$i2) + -1)|0;
  $40 = ($39|0)==(0);
  if ($40) {
   break;
  } else {
   $$0$i2 = $39;$35 = $37;
  }
 }
 $41 = (($33) + (($$0$i57*56)|0)|0);
 $42 = HEAP32[$this>>2]|0;
 $43 = HEAP32[$3>>2]|0;
 $44 = $43;
 $45 = $42;
 $46 = (($44) - ($45))|0;
 $47 = (($46|0) / -56)&-1;
 $$sum = (($47) + ($20))|0;
 $48 = (($33) + (($$sum*56)|0)|0);
 _memcpy(($48|0),($42|0),($46|0))|0;
 $49 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $48;
 HEAP32[$3>>2] = $37;
 HEAP32[$1>>2] = $41;
 $50 = ($49|0)==(0|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 90;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($49|0),($$byval_copy1|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  ___cxa_call_unexpected(($53|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS6_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i4 = 0, $$pre7 = 0, $$pre8 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre$i$i$i4 = HEAP32[$size1>>2]|0;
   $23 = $$pre$i$i$i4;
  } else {
   $22 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $22;
   HEAP32[$1>>2] = $6;
   $23 = $22;
  }
  $24 = (_llvm_bswap_i32(($23|0))|0);
  HEAP32[$size1>>2] = $24;
  __Z14resize_trimmedINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$24);
  $25 = (($data) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = HEAP32[$data>>2]|0;
  $28 = ($27|0)==($26|0);
  if ($28) {
   STACKTOP = sp;return;
  } else {
   $29 = $27;
  }
  while(1) {
   __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI18StreamedBinaryReadILb1EEEEvRT_($29,$this);
   $30 = (($29) + 56|0);
   $31 = ($30|0)==($26|0);
   if ($31) {
    break;
   } else {
    $29 = $30;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre$i$i$i = HEAP32[$size>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$7>>2]|0;
  $11 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre7;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $11 = $10;$14 = $6;$16 = $8;
 }
 $12 = (_llvm_bswap_i32(($11|0))|0);
 HEAP32[$size>>2] = $12;
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre$i$i$i1 = HEAP32[$offset>>2]|0;
  $$pre8 = HEAP32[$size>>2]|0;
  $18 = $$pre$i$i$i1;$21 = $$pre8;
 } else {
  $17 = HEAP32[$14>>2]|0;
  HEAP32[$offset>>2] = $17;
  HEAP32[$1>>2] = $13;
  $18 = $17;$21 = $12;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$offset>>2] = $19;
 $20 = ($21*56)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$19,$20)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __Z14resize_trimmedINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEvRT_j($v,$sz) {
 $v = $v|0;
 $sz = $sz|0;
 var $$0 = 0, $$01 = 0, $$byval_copy2 = 0, $$byval_copy7 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $$pre1$i = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i15 = 0, $__new_last2$i$i$i$i$i24 = 0, $phitmp = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i16 = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i20 = 0, $scevgep4$i$i$i$i$i29 = 0, $temp = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i18 = 0, $uglygep$i$i$i$i$i27 = 0;
 var $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i19 = 0, $uglygep3$i$i$i$i$i28 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $$byval_copy2 = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $temp = sp + 16|0;
 $3 = sp + 28|0;
 $4 = sp + 32|0;
 $5 = (($v) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$v>>2]|0;
 $8 = $6;
 $9 = $7;
 $10 = (($8) - ($9))|0;
 $11 = (($10|0) / 56)&-1;
 $12 = ($11>>>0)<($sz>>>0);
 if (!($12)) {
  $86 = ($11>>>0)>($sz>>>0);
  if (!($86)) {
   STACKTOP = sp;return;
  }
  $87 = (($7) + (($sz*56)|0)|0);
  $$idx = ($sz*56)|0;
  $88 = (($$idx|0) / 56)&-1;
  $89 = ($sz|0)==(0);
  do {
   if ($89) {
    $104 = 0;$105 = 0;$107 = 0;$109 = $7;
   } else {
    $90 = ($$idx|0)<(0);
    if ($90) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if (!($92)) {
      // unreachable;
     }
    } else {
     HEAP32[$2>>2] = 27;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
     $93 = (invoke_iiiiiii(102,($$idx|0),16,($$byval_copy7|0),0,(804096|0),79)|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $97 = $93;$98 = $7;
      while(1) {
       $96 = ($97|0)==(0|0);
       if ($96) {
        $100 = 0;
       } else {
        dest=$97+0|0; src=$98+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $100 = $97;
       }
       $99 = (($100) + 56|0);
       $101 = (($98) + 56|0);
       $102 = ($101|0)==($87|0);
       if ($102) {
        break;
       } else {
        $97 = $99;$98 = $101;
       }
      }
      $103 = (($93) + (($88*56)|0)|0);
      $$pre = HEAP32[$v>>2]|0;
      $104 = $93;$105 = $99;$107 = $103;$109 = $$pre;
      break;
     }
    }
    $114 = ___cxa_find_matching_catch()|0;
    $115 = tempRet0;
    $$0 = $115;$$01 = $114;
    ___resumeException($$01|0);
    // unreachable;
   }
  } while(0);
  HEAP32[$v>>2] = $104;
  HEAP32[$5>>2] = $105;
  $106 = (($v) + 8|0);
  HEAP32[$106>>2] = $107;
  $108 = ($109|0)==(0|0);
  if ($108) {
   STACKTOP = sp;return;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($109|0),($$byval_copy7|0));
  $110 = __THREW__; __THREW__ = 0;
  $111 = $110&1;
  if ($111) {
   $112 = ___cxa_find_matching_catch()|0;
   $113 = tempRet0;
   ___cxa_call_unexpected(($112|0));
   // unreachable;
  } else {
   STACKTOP = sp;return;
  }
 }
 $13 = (($v) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = (($15) - ($9))|0;
 $17 = (($16|0) / 56)&-1;
 $18 = ($17|0)==($sz|0);
 if ($18) {
  $85 = (($sz) - ($11))|0;
  __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE8__appendEj($v,$85);
  STACKTOP = sp;return;
 }
 HEAP32[$temp>>2] = 0;
 $19 = (($temp) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($temp) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = ($sz|0)==(0);
 if ($21) {
  label = 8;
 } else {
  $22 = ($sz*56)|0;
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
  $23 = (invoke_iiiiiii(102,($22|0),16,($$byval_copy7|0),0,(804096|0),79)|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $$pre$i = HEAP32[$temp>>2]|0;
   $$pre1$i = HEAP32[$19>>2]|0;
   $phitmp = $$pre1$i;
   $26 = (($23) + (($sz*56)|0)|0);
   $27 = $$pre$i;
   $28 = (($phitmp) - ($27))|0;
   $29 = (($28|0) / -56)&-1;
   $30 = (($23) + (($29*56)|0)|0);
   _memcpy(($30|0),($$pre$i|0),($28|0))|0;
   $31 = HEAP32[$temp>>2]|0;
   HEAP32[$temp>>2] = $30;
   HEAP32[$19>>2] = $23;
   HEAP32[$20>>2] = $26;
   $32 = ($31|0)==(0|0);
   if ($32) {
    label = 8;
   } else {
    HEAP32[$1>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($31|0),($$byval_copy7|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch()|0;
     $36 = tempRet0;
     ___cxa_call_unexpected(($35|0));
     // unreachable;
    } else {
     label = 8;
    }
   }
  }
 }
 do {
  if ((label|0) == 8) {
   $37 = HEAP32[$v>>2]|0;
   HEAP32[$3>>2] = $37;
   $38 = HEAP32[$5>>2]|0;
   HEAP32[$4>>2] = $38;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
   invoke_viii(2053,($temp|0),($$byval_copy2|0),($$byval_copy7|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = HEAP32[$19>>2]|0;
    $42 = HEAP32[$temp>>2]|0;
    $43 = $41;
    $44 = $42;
    $45 = (($43) - ($44))|0;
    $46 = (($45|0) / 56)&-1;
    $47 = ($46>>>0)<($sz>>>0);
    if ($47) {
     $48 = (($sz) - ($46))|0;
     __THREW__ = 0;
     invoke_vii(3432,($temp|0),($48|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $$pre45 = HEAP32[$temp>>2]|0;
     $$pre46 = HEAP32[$19>>2]|0;
     $58 = $$pre45;$60 = $$pre46;
    } else {
     $51 = ($46>>>0)>($sz>>>0);
     if ($51) {
      $52 = (($42) + (($sz*56)|0)|0);
      $53 = ($41|0)==($52|0);
      if ($53) {
       $58 = $42;$60 = $41;
      } else {
       $__new_last2$i$i$i = $52;
       $scevgep$i$i$i = (($41) + -56|0);
       $54 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($54)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $55 = (($uglygep3$i$i$i>>>0) / 56)&-1;
       $56 = $55 ^ -1;
       $scevgep4$i$i$i = (($41) + (($56*56)|0)|0);
       HEAP32[$19>>2] = $scevgep4$i$i$i;
       $58 = $42;$60 = $scevgep4$i$i$i;
      }
     } else {
      $58 = $42;$60 = $41;
     }
    }
    $57 = HEAP32[$v>>2]|0;
    HEAP32[$temp>>2] = $57;
    HEAP32[$v>>2] = $58;
    $59 = HEAP32[$5>>2]|0;
    HEAP32[$19>>2] = $59;
    HEAP32[$5>>2] = $60;
    $61 = HEAP32[$20>>2]|0;
    $62 = HEAP32[$13>>2]|0;
    HEAP32[$20>>2] = $62;
    HEAP32[$13>>2] = $61;
    $63 = ($57|0)==(0|0);
    if ($63) {
     STACKTOP = sp;return;
    }
    $64 = ($59|0)==($57|0);
    if (!($64)) {
     $__new_last2$i$i$i$i$i15 = $57;
     $scevgep$i$i$i$i$i16 = (($59) + -56|0);
     $65 = (0 - ($__new_last2$i$i$i$i$i15))|0;
     $uglygep$i$i$i$i$i18 = (($scevgep$i$i$i$i$i16) + ($65)|0);
     $uglygep3$i$i$i$i$i19 = $uglygep$i$i$i$i$i18;
     $66 = (($uglygep3$i$i$i$i$i19>>>0) / 56)&-1;
     $67 = $66 ^ -1;
     $scevgep4$i$i$i$i$i20 = (($59) + (($67*56)|0)|0);
     HEAP32[$19>>2] = $scevgep4$i$i$i$i$i20;
    }
    HEAP32[$$byval_copy2>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
    invoke_vii(2591,($57|0),($$byval_copy7|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     $70 = ___cxa_find_matching_catch()|0;
     $71 = tempRet0;
     ___cxa_call_unexpected(($70|0));
     // unreachable;
    } else {
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $72 = ___cxa_find_matching_catch()|0;
 $73 = tempRet0;
 $74 = HEAP32[$temp>>2]|0;
 $75 = ($74|0)==(0|0);
 if ($75) {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
 $76 = HEAP32[$19>>2]|0;
 $77 = ($76|0)==($74|0);
 if (!($77)) {
  $__new_last2$i$i$i$i$i24 = $74;
  $scevgep$i$i$i$i$i25 = (($76) + -56|0);
  $78 = (0 - ($__new_last2$i$i$i$i$i24))|0;
  $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($78)|0);
  $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
  $79 = (($uglygep3$i$i$i$i$i28>>>0) / 56)&-1;
  $80 = $79 ^ -1;
  $scevgep4$i$i$i$i$i29 = (($76) + (($80*56)|0)|0);
  HEAP32[$19>>2] = $scevgep4$i$i$i$i$i29;
 }
 HEAP32[$$byval_copy2>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$$byval_copy2+0>>2]|0;
 invoke_vii(2591,($74|0),($$byval_copy7|0));
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  ___cxa_call_unexpected(($83|0));
  // unreachable;
 } else {
  $$0 = $73;$$01 = $72;
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$0$i37 = 0, $$byval_copy1 = 0, $$pre$i17 = 0, $$pre5$i = 0, $$pre5$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i = 0, $uglygep3$i$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__first>>2]|0;
 $2 = HEAP32[$__last>>2]|0;
 $3 = $2;
 $4 = $1;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 56)&-1;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$this>>2]|0;
 $10 = $8;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = (($12|0) / 56)&-1;
 $14 = ($6>>>0)>($13>>>0);
 if (!($14)) {
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16;
  $18 = (($17) - ($11))|0;
  $19 = (($18|0) / 56)&-1;
  $20 = ($6>>>0)>($19>>>0);
  if (!($20)) {
   $30 = $2;
   $31 = (($30) - ($4))|0;
   $32 = (($31|0) / 56)&-1;
   _memmove(($9|0),($1|0),($31|0))|0;
   $33 = (($9) + (($32*56)|0)|0);
   $34 = HEAP32[$15>>2]|0;
   $35 = ($34|0)==($33|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $__new_last2$i$i = $33;
   $scevgep$i$i = (($34) + -56|0);
   $36 = (0 - ($__new_last2$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($36)|0);
   $uglygep3$i$i = $uglygep$i$i;
   $37 = (($uglygep3$i$i>>>0) / 56)&-1;
   $38 = $37 ^ -1;
   $scevgep4$i$i = (($34) + (($38*56)|0)|0);
   HEAP32[$15>>2] = $scevgep4$i$i;
   STACKTOP = sp;return;
  }
  $21 = (($1) + (($19*56)|0)|0);
  _memmove(($9|0),($1|0),($18|0))|0;
  $22 = ($21|0)==($2|0);
  if ($22) {
   STACKTOP = sp;return;
  }
  $$pre$i17 = HEAP32[$15>>2]|0;
  $24 = $$pre$i17;$25 = $21;
  while(1) {
   $23 = ($24|0)==(0|0);
   if ($23) {
    $27 = 0;
   } else {
    dest=$24+0|0; src=$25+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre5$i19 = HEAP32[$15>>2]|0;
    $27 = $$pre5$i19;
   }
   $26 = (($27) + 56|0);
   HEAP32[$15>>2] = $26;
   $28 = (($25) + 56|0);
   $29 = ($28|0)==($2|0);
   if ($29) {
    break;
   } else {
    $24 = $26;$25 = $28;
   }
  }
  STACKTOP = sp;return;
 }
 $39 = ($9|0)==(0|0);
 do {
  if ($39) {
   $52 = $8;
  } else {
   $40 = (($this) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==($9|0);
   if (!($42)) {
    $scevgep$i$i$i$i = (($41) + -56|0);
    $43 = (0 - ($11))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($43)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $44 = (($uglygep3$i$i$i$i>>>0) / 56)&-1;
    $45 = $44 ^ -1;
    $scevgep4$i$i$i$i = (($41) + (($45*56)|0)|0);
    HEAP32[$40>>2] = $scevgep4$i$i$i$i;
   }
   HEAP32[$0>>2] = 27;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($9|0),($$byval_copy1|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $48 = ___cxa_find_matching_catch()|0;
    $49 = tempRet0;
    ___cxa_call_unexpected(($48|0));
    // unreachable;
   } else {
    HEAP32[$7>>2] = 0;
    HEAP32[$40>>2] = 0;
    HEAP32[$this>>2] = 0;
    $52 = 0;
    break;
   }
  }
 } while(0);
 $50 = ($5|0)<(0);
 if ($50) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = $52;
 $53 = (($51|0) / 56)&-1;
 $54 = ($53>>>0)<(1073741823);
 if ($54) {
  $55 = $53 << 1;
  $56 = ($55>>>0)<($6>>>0);
  $57 = $56 ? $6 : $55;
  $58 = ($57|0)<(0);
  if ($58) {
   __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  } else {
   $$0$i37 = $57;
  }
 } else {
  $$0$i37 = 2147483647;
 }
 $59 = ($$0$i37*56)|0;
 HEAP32[$0>>2] = 27;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $60 = (__Z15malloc_internaljj10MemLabelIdiPKci($59,16,$$byval_copy1,0,804096,79)|0);
 $61 = (($this) + 4|0);
 HEAP32[$61>>2] = $60;
 HEAP32[$this>>2] = $60;
 $62 = (($60) + (($$0$i37*56)|0)|0);
 HEAP32[$7>>2] = $62;
 $63 = ($1|0)==($2|0);
 if ($63) {
  STACKTOP = sp;return;
 } else {
  $65 = $60;$66 = $1;
 }
 while(1) {
  $64 = ($65|0)==(0|0);
  if ($64) {
   $68 = 0;
  } else {
   dest=$65+0|0; src=$66+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $$pre5$i = HEAP32[$61>>2]|0;
   $68 = $$pre5$i;
  }
  $67 = (($68) + 56|0);
  HEAP32[$61>>2] = $67;
  $69 = (($66) + 56|0);
  $70 = ($69|0)==($2|0);
  if ($70) {
   break;
  } else {
   $65 = $67;$66 = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0, $$pre28 = Math_fround(0), $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i7 = 0, $emptyCharacterInfo = 0, $fontSize = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i8 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i12 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i10 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $0 = sp;
 $emptyCharacterInfo = sp + 4|0;
 $fontSize = sp + 16|0;
 __ZN11NamedObject8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $1 = (($this) + 72|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre19 = HEAP32[$5>>2]|0;
  $11 = $$pre;$13 = $$pre19;
 } else {
  $8 = HEAP32[$3>>2]|0;
  HEAP32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $11 = $4;$13 = $6;
 }
 $9 = (($this) + 60|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$9,4);
  $$pre20 = HEAP32[$2>>2]|0;
  $$pre21 = HEAP32[$5>>2]|0;
  $17 = $$pre20;$19 = $$pre21;
 } else {
  $14 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$9>>2] = $14;
  HEAP32[$2>>2] = $10;
  $17 = $10;$19 = $13;
 }
 $15 = (($this) + 28|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$15,4);
  $$pre22 = HEAP32[$2>>2]|0;
  $$pre23 = HEAP32[$5>>2]|0;
  $23 = $$pre22;$25 = $$pre23;
 } else {
  $20 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$15>>2] = $20;
  HEAP32[$2>>2] = $16;
  $23 = $16;$25 = $19;
 }
 $21 = (($this) + 64|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$21,4);
  $$pre24 = HEAP32[$2>>2]|0;
  $$pre25 = HEAP32[$5>>2]|0;
  $29 = $$pre24;$31 = $$pre25;
 } else {
  $26 = HEAP32[$23>>2]|0;
  HEAP32[$21>>2] = $26;
  HEAP32[$2>>2] = $22;
  $29 = $22;$31 = $25;
 }
 $27 = (($this) + 68|0);
 $28 = (($29) + 4|0);
 $30 = ($28>>>0)>($31>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$27,4);
  $$pre26 = HEAP32[$2>>2]|0;
  $$pre27 = HEAP32[$5>>2]|0;
  $35 = $$pre26;$37 = $$pre27;
 } else {
  $32 = HEAP32[$29>>2]|0;
  HEAP32[$27>>2] = $32;
  HEAP32[$2>>2] = $28;
  $35 = $28;$37 = $31;
 }
 $33 = (($this) + 76|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$33,4);
 } else {
  $38 = HEAP32[$35>>2]|0;
  HEAP32[$33>>2] = $38;
  HEAP32[$2>>2] = $34;
 }
 $39 = (($this) + 36|0);
 __ZN4PPtrIN5Unity8MaterialEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($39,$transfer);
 $40 = HEAP32[$33>>2]|0;
 $41 = ($40|0)==(-2);
 do {
  if ($41) {
   HEAP32[$emptyCharacterInfo>>2] = 0;
   $43 = (($emptyCharacterInfo) + 4|0);
   HEAP32[$43>>2] = 0;
   $44 = (($emptyCharacterInfo) + 8|0);
   HEAP32[$44>>2] = 0;
   __THREW__ = 0;
   invoke_viii(2054,($transfer|0),($emptyCharacterInfo|0),0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    $47 = HEAP32[$emptyCharacterInfo>>2]|0;
    $48 = ($47|0)==(0|0);
    if ($48) {
     break;
    }
    $49 = HEAP32[$43>>2]|0;
    $50 = ($49|0)==($47|0);
    if (!($50)) {
     $__new_last2$i$i$i$i$i = $47;
     $scevgep$i$i$i$i$i = (($49) + -56|0);
     $51 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($51)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $52 = (($uglygep3$i$i$i$i$i>>>0) / 56)&-1;
     $53 = $52 ^ -1;
     $scevgep4$i$i$i$i$i = (($49) + (($53*56)|0)|0);
     HEAP32[$43>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($47|0),($$byval_copy1|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     break;
    }
    $56 = ___cxa_find_matching_catch()|0;
    $57 = tempRet0;
    ___cxa_call_unexpected(($56|0));
    // unreachable;
   }
   $58 = ___cxa_find_matching_catch()|0;
   $59 = tempRet0;
   $60 = HEAP32[$emptyCharacterInfo>>2]|0;
   $61 = ($60|0)==(0|0);
   if ($61) {
    ___resumeException($58|0);
    // unreachable;
   }
   $62 = HEAP32[$43>>2]|0;
   $63 = ($62|0)==($60|0);
   if (!($63)) {
    $__new_last2$i$i$i$i$i7 = $60;
    $scevgep$i$i$i$i$i8 = (($62) + -56|0);
    $64 = (0 - ($__new_last2$i$i$i$i$i7))|0;
    $uglygep$i$i$i$i$i10 = (($scevgep$i$i$i$i$i8) + ($64)|0);
    $uglygep3$i$i$i$i$i11 = $uglygep$i$i$i$i$i10;
    $65 = (($uglygep3$i$i$i$i$i11>>>0) / 56)&-1;
    $66 = $65 ^ -1;
    $scevgep4$i$i$i$i$i12 = (($62) + (($66*56)|0)|0);
    HEAP32[$43>>2] = $scevgep4$i$i$i$i$i12;
   }
   HEAP32[$0>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($60|0),($$byval_copy1|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    ___cxa_call_unexpected(($69|0));
    // unreachable;
   } else {
    ___resumeException($58|0);
    // unreachable;
   }
  } else {
   $42 = (($this) + 84|0);
   __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS6_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$42,0);
  }
 } while(0);
 $71 = (($this) + 40|0);
 __ZN4PPtrI7TextureE8TransferI18StreamedBinaryReadILb0EEEEvRT_($71,$transfer);
 $72 = (($this) + 44|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapINSt3__14pairIttEEfN20TextRenderingPrivate4Font14KerningCompareENS3_9allocatorINS4_IS5_fEEEEEEEvRT_17TransferMetaFlags($transfer,$72,0);
 $73 = (($this) + 80|0);
 $74 = HEAP32[$2>>2]|0;
 $75 = (($74) + 4|0);
 $76 = HEAP32[$5>>2]|0;
 $77 = ($75>>>0)>($76>>>0);
 if ($77) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$73,4);
 } else {
  $78 = Math_fround(HEAPF32[$74>>2]);
  HEAPF32[$73>>2] = $78;
  HEAP32[$2>>2] = $75;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $79 = (($this) + 120|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$79,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $80 = (($this) + 32|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (Math_fround(($81|0)));
 HEAPF32[$fontSize>>2] = $82;
 $83 = HEAP32[$2>>2]|0;
 $84 = (($83) + 4|0);
 $85 = HEAP32[$5>>2]|0;
 $86 = ($84>>>0)>($85>>>0);
 if ($86) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$fontSize,4);
  $$pre28 = Math_fround(HEAPF32[$fontSize>>2]);
  $$pre29 = HEAP32[$2>>2]|0;
  $$pre30 = HEAP32[$5>>2]|0;
  $89 = $$pre28;$92 = $$pre29;$94 = $$pre30;
 } else {
  $87 = Math_fround(HEAPF32[$83>>2]);
  HEAPF32[$fontSize>>2] = $87;
  HEAP32[$2>>2] = $84;
  $89 = $87;$92 = $84;$94 = $85;
 }
 $88 = (~~(($89)));
 HEAP32[$80>>2] = $88;
 $90 = (($this) + 208|0);
 $91 = (($92) + 4|0);
 $93 = ($91>>>0)>($94>>>0);
 if ($93) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$90,4);
  $$pre31 = HEAP32[$2>>2]|0;
  $$pre32 = HEAP32[$5>>2]|0;
  $100 = $$pre32;$98 = $$pre31;
 } else {
  $95 = Math_fround(HEAPF32[$92>>2]);
  HEAPF32[$90>>2] = $95;
  HEAP32[$2>>2] = $91;
  $100 = $94;$98 = $91;
 }
 $96 = (($this) + 204|0);
 $97 = (($98) + 4|0);
 $99 = ($97>>>0)>($100>>>0);
 if ($99) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$96,4);
 } else {
  $101 = HEAP32[$98>>2]|0;
  HEAP32[$96>>2] = $101;
  HEAP32[$2>>2] = $97;
 }
 $102 = (($this) + 132|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStr13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$102,0);
 $103 = (($this) + 144|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$103,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $104 = (($this) + 212|0);
 $105 = HEAP32[$2>>2]|0;
 $106 = (($105) + 4|0);
 $107 = HEAP32[$5>>2]|0;
 $108 = ($106>>>0)>($107>>>0);
 if ($108) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$104,4);
  STACKTOP = sp;return;
 } else {
  $109 = HEAP32[$105>>2]|0;
  HEAP32[$104>>2] = $109;
  HEAP32[$2>>2] = $106;
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS5_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 4|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = $16 << 2;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStr13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorI8UnityStr13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$25,0);
   __ZN18StreamedBinaryReadILb0EE5AlignEv($this);
   $26 = (($25) + 12|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*12)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $19 = $$pre;
  } else {
   $18 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $18;
   HEAP32[$1>>2] = $6;
   $19 = $18;
  }
  __Z14resize_trimmedINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$19);
  $20 = HEAP32[$size1>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   STACKTOP = sp;return;
  }
  $22 = HEAP32[$data>>2]|0;
  __ZN18StreamedBinaryReadILb0EE10ReadDirectEPvi($this,$22,$20);
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $17 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $17 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$17,$16)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI10vector_mapINSt3__14pairIttEEfN20TextRenderingPrivate4Font14KerningCompareENS3_9allocatorINS4_IS5_fEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i$i = 0, $$pre$i$i$i$i = 0, $$pre1$i$i = 0, $$pre2$i$i$i$i = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $offset = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $size1 = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($4)) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
   $$pre7 = HEAP32[$1>>2]|0;
   $$pre8 = HEAP32[$7>>2]|0;
   $12 = $$pre7;$14 = $$pre8;
  } else {
   $10 = HEAP32[$5>>2]|0;
   HEAP32[$size>>2] = $10;
   HEAP32[$1>>2] = $6;
   $12 = $6;$14 = $8;
  }
  $11 = (($12) + 4|0);
  $13 = ($11>>>0)>($14>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
   $$pre9 = HEAP32[$offset>>2]|0;
   $18 = $$pre9;
  } else {
   $15 = HEAP32[$12>>2]|0;
   HEAP32[$offset>>2] = $15;
   HEAP32[$1>>2] = $11;
   $18 = $15;
  }
  $16 = HEAP32[$size>>2]|0;
  $17 = $16 << 3;
  (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
  $$pre = HEAP32[$size1>>2]|0;
  $29 = $$pre;
 } else {
  $19 = HEAP32[$5>>2]|0;
  HEAP32[$size1>>2] = $19;
  HEAP32[$1>>2] = $6;
  $29 = $19;
 }
 $20 = (($data) + 4|0);
 $21 = (($data) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$20>>2]|0;
 $24 = $22;
 $25 = $23;
 $26 = (($24) - ($25))|0;
 $27 = $26 >> 3;
 $28 = ($27>>>0)<($29>>>0);
 if ($28) {
  $30 = (($29) - ($27))|0;
  __ZNSt3__16vectorINS_4pairINS1_IttEEfEENS_9allocatorIS3_EEE8__appendEj($20,$30);
  $$pre5 = HEAP32[$21>>2]|0;
  $$phi$trans$insert = (($data) + 4|0);
  $$pre6 = HEAP32[$$phi$trans$insert>>2]|0;
  $38 = $$pre6;$39 = $$pre5;
 } else {
  $31 = ($27>>>0)>($29>>>0);
  if ($31) {
   $32 = (($23) + ($29<<3)|0);
   $33 = ($22|0)==($32|0);
   if ($33) {
    $38 = $23;$39 = $22;
   } else {
    $__new_last2$i$i$i$i = $32;
    $scevgep$i$i$i$i = (($22) + -8|0);
    $34 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($34)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $35 = $uglygep3$i$i$i$i >>> 3;
    $36 = $35 ^ -1;
    $scevgep4$i$i$i$i = (($22) + ($36<<3)|0);
    HEAP32[$21>>2] = $scevgep4$i$i$i$i;
    $38 = $23;$39 = $scevgep4$i$i$i$i;
   }
  } else {
   $38 = $23;$39 = $22;
  }
 }
 $37 = ($38|0)==($39|0);
 if ($37) {
  STACKTOP = sp;return;
 } else {
  $45 = $38;
 }
 while(1) {
  $40 = HEAP32[$1>>2]|0;
  $41 = (($40) + 2|0);
  $42 = HEAP32[$7>>2]|0;
  $43 = ($41>>>0)>($42>>>0);
  if ($43) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$45,2);
   $$pre$i$i$i$i = HEAP32[$1>>2]|0;
   $$pre2$i$i$i$i = HEAP32[$7>>2]|0;
   $48 = $$pre$i$i$i$i;$50 = $$pre2$i$i$i$i;
  } else {
   $44 = HEAP16[$40>>1]|0;
   HEAP16[$45>>1] = $44;
   HEAP32[$1>>2] = $41;
   $48 = $41;$50 = $42;
  }
  $46 = (($45) + 2|0);
  $47 = (($48) + 2|0);
  $49 = ($47>>>0)>($50>>>0);
  if ($49) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$46,2);
   $$pre$i$i = HEAP32[$1>>2]|0;
   $$pre1$i$i = HEAP32[$7>>2]|0;
   $54 = $$pre$i$i;$56 = $$pre1$i$i;
  } else {
   $51 = HEAP16[$48>>1]|0;
   HEAP16[$46>>1] = $51;
   HEAP32[$1>>2] = $47;
   $54 = $47;$56 = $50;
  }
  $52 = (($45) + 4|0);
  $53 = (($54) + 4|0);
  $55 = ($53>>>0)>($56>>>0);
  if ($55) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$52,4);
  } else {
   $57 = Math_fround(HEAPF32[$54>>2]);
   HEAPF32[$52>>2] = $57;
   HEAP32[$1>>2] = $53;
  }
  $58 = (($45) + 8|0);
  $59 = ($58|0)==($39|0);
  if ($59) {
   break;
  } else {
   $45 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 56|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*56)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($transfer) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($transfer) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)>($4>>>0);
 if ($5) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$this,4);
 } else {
  $6 = HEAP32[$1>>2]|0;
  HEAP32[$this>>2] = $6;
  HEAP32[$0>>2] = $2;
 }
 $7 = (($this) + 4|0);
 __ZN5RectTIfE8TransferI18StreamedBinaryReadILb0EEEEvRT_($7,$transfer);
 $8 = (($this) + 20|0);
 __ZN5RectTIfE8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 36|0);
 $10 = HEAP32[$0>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($11>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$9,4);
  $$pre = HEAP32[$0>>2]|0;
  $$pre1 = HEAP32[$3>>2]|0;
  $17 = $$pre;$19 = $$pre1;
 } else {
  $14 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$9>>2] = $14;
  HEAP32[$0>>2] = $11;
  $17 = $11;$19 = $12;
 }
 $15 = (($this) + 52|0);
 $16 = (($17) + 1|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($0,$15,1);
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 } else {
  $20 = HEAP8[$17>>0]|0;
  HEAP8[$15>>0] = $20;
  $21 = HEAP32[$0>>2]|0;
  $22 = (($21) + 1|0);
  HEAP32[$0>>2] = $22;
  __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
  STACKTOP = sp;return;
 }
}
function __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS6_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset = 0, $size = 0, $size1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $offset = sp + 8|0;
 $size = sp;
 $size1 = sp + 4|0;
 $1 = (($this) + 12|0);
 $2 = (($this) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if ($4) {
  if ($9) {
   __ZN12CachedReader15UpdateReadCacheEPvj($1,$size1,4);
   $$pre = HEAP32[$size1>>2]|0;
   $20 = $$pre;
  } else {
   $19 = HEAP32[$5>>2]|0;
   HEAP32[$size1>>2] = $19;
   HEAP32[$1>>2] = $6;
   $20 = $19;
  }
  __Z14resize_trimmedINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$20);
  $21 = (($data) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$data>>2]|0;
  $24 = ($23|0)==($22|0);
  if ($24) {
   STACKTOP = sp;return;
  } else {
   $25 = $23;
  }
  while(1) {
   __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI18StreamedBinaryReadILb0EEEEvRT_($25,$this);
   $26 = (($25) + 56|0);
   $27 = ($26|0)==($22|0);
   if ($27) {
    break;
   } else {
    $25 = $26;
   }
  }
  STACKTOP = sp;return;
 }
 if ($9) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$size,4);
  $$pre5 = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$7>>2]|0;
  $12 = $$pre5;$14 = $$pre6;
 } else {
  $10 = HEAP32[$5>>2]|0;
  HEAP32[$size>>2] = $10;
  HEAP32[$1>>2] = $6;
  $12 = $6;$14 = $8;
 }
 $11 = (($12) + 4|0);
 $13 = ($11>>>0)>($14>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$offset,4);
  $$pre7 = HEAP32[$offset>>2]|0;
  $18 = $$pre7;
 } else {
  $15 = HEAP32[$12>>2]|0;
  HEAP32[$offset>>2] = $15;
  HEAP32[$1>>2] = $11;
  $18 = $15;
 }
 $16 = HEAP32[$size>>2]|0;
 $17 = ($16*56)|0;
 (__ZN12CachedReader22FetchResourceImageDataEjj($1,$18,$17)|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$0 = 0, $$01 = 0, $$byval_copy8 = 0, $$pre = 0, $$pre$i = 0, $$pre53 = 0, $$sum = 0, $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0);
 var $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = Math_fround(0), $224 = Math_fround(0), $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i24 = 0, $__new_last2$i$i$i$i$i32 = 0, $__new_last2$i$i$i$i$i7 = 0, $charNo$050 = 0, $converter$i$i19 = 0, $converter$i$i2 = 0, $converter$i$i3 = 0, $emptyCharacterInfo = 0, $fontCountX = 0;
 var $fontCountY = 0, $fontSize = 0, $gridFont = 0, $info = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $perCharacterKerning = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i25 = 0, $scevgep$i$i$i$i$i33 = 0, $scevgep$i$i$i$i$i8 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i12 = 0, $scevgep4$i$i$i$i$i29 = 0, $scevgep4$i$i$i$i$i37 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i10 = 0, $uglygep$i$i$i$i$i27 = 0, $uglygep$i$i$i$i$i35 = 0, $uglygep3$i$i$i$i$i = 0;
 var $uglygep3$i$i$i$i$i11 = 0, $uglygep3$i$i$i$i$i28 = 0, $uglygep3$i$i$i$i$i36 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy8 = sp + 116|0;
 $0 = sp + 112|0;
 $converter$i$i19 = sp + 108|0;
 $1 = sp + 104|0;
 $2 = sp + 100|0;
 $converter$i$i3 = sp + 96|0;
 $converter$i$i2 = sp + 88|0;
 $emptyCharacterInfo = sp + 76|0;
 $gridFont = sp + 120|0;
 $fontCountX = sp + 72|0;
 $fontCountY = sp + 68|0;
 $perCharacterKerning = sp + 56|0;
 $info = sp;
 $fontSize = sp + 92|0;
 __ZN11NamedObject8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,4);
 $3 = (($this) + 72|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$3,804408,0);
 $4 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$4,804432,0);
 $5 = (($this) + 28|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$5,804448,0);
 $6 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$6,804464,0);
 $7 = (($this) + 68|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$7,804488,0);
 $8 = (($this) + 76|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$8,804512,0);
 $9 = (($this) + 36|0);
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804528,804952,$$byval_copy8,1)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ($10|0)>(0);
  if ($12) {
   __ZN4PPtrIN5Unity8MaterialEE8TransferI14SafeBinaryReadEEvRT_($9,$transfer);
  } else {
   $13 = HEAP32[$$byval_copy8>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    (FUNCTION_TABLE_iii[$13 & 4095]($9,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = ($15|0)==(-2);
 L9: do {
  if ($16) {
   HEAP32[$emptyCharacterInfo>>2] = 0;
   $24 = (($emptyCharacterInfo) + 4|0);
   HEAP32[$24>>2] = 0;
   $25 = (($emptyCharacterInfo) + 8|0);
   HEAP32[$25>>2] = 0;
   $26 = HEAP32[580760>>2]|0;
   __THREW__ = 0;
   $27 = (invoke_iiiiii(192,($transfer|0),(804552|0),($26|0),($converter$i$i3|0),1)|0);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   do {
    if (!($29)) {
     $30 = ($27|0)==(0);
     if (!($30)) {
      $31 = ($27|0)>(0);
      if ($31) {
       __THREW__ = 0;
       invoke_viii(2055,($transfer|0),($emptyCharacterInfo|0),0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
      } else {
       $34 = HEAP32[$converter$i$i3>>2]|0;
       $35 = ($34|0)==(0|0);
       if (!($35)) {
        __THREW__ = 0;
        (invoke_iii($34|0,($emptyCharacterInfo|0),($transfer|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
       }
      }
      __THREW__ = 0;
      invoke_vi(3389,($transfer|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
     }
     $40 = HEAP32[$emptyCharacterInfo>>2]|0;
     $41 = ($40|0)==(0|0);
     if ($41) {
      $115 = $26;
      break L9;
     }
     $42 = HEAP32[$24>>2]|0;
     $43 = ($42|0)==($40|0);
     if (!($43)) {
      $__new_last2$i$i$i$i$i = $40;
      $scevgep$i$i$i$i$i = (($42) + -56|0);
      $44 = (0 - ($__new_last2$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($44)|0);
      $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
      $45 = (($uglygep3$i$i$i$i$i>>>0) / 56)&-1;
      $46 = $45 ^ -1;
      $scevgep4$i$i$i$i$i = (($42) + (($46*56)|0)|0);
      HEAP32[$24>>2] = $scevgep4$i$i$i$i$i;
     }
     HEAP32[$2>>2] = 90;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($40|0),($$byval_copy8|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if (!($48)) {
      $115 = $26;
      break L9;
     }
     $49 = ___cxa_find_matching_catch()|0;
     $50 = tempRet0;
     ___cxa_call_unexpected(($49|0));
     // unreachable;
    }
   } while(0);
   $51 = ___cxa_find_matching_catch()|0;
   $52 = tempRet0;
   $53 = HEAP32[$emptyCharacterInfo>>2]|0;
   $54 = ($53|0)==(0|0);
   if ($54) {
    $$0 = $51;$$01 = $52;
    ___resumeException($$0|0);
    // unreachable;
   }
   $55 = HEAP32[$24>>2]|0;
   $56 = ($55|0)==($53|0);
   if (!($56)) {
    $__new_last2$i$i$i$i$i7 = $53;
    $scevgep$i$i$i$i$i8 = (($55) + -56|0);
    $57 = (0 - ($__new_last2$i$i$i$i$i7))|0;
    $uglygep$i$i$i$i$i10 = (($scevgep$i$i$i$i$i8) + ($57)|0);
    $uglygep3$i$i$i$i$i11 = $uglygep$i$i$i$i$i10;
    $58 = (($uglygep3$i$i$i$i$i11>>>0) / 56)&-1;
    $59 = $58 ^ -1;
    $scevgep4$i$i$i$i$i12 = (($55) + (($59*56)|0)|0);
    HEAP32[$24>>2] = $scevgep4$i$i$i$i$i12;
   }
   HEAP32[$1>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($53|0),($$byval_copy8|0));
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    $62 = ___cxa_find_matching_catch()|0;
    $63 = tempRet0;
    ___cxa_call_unexpected(($62|0));
    // unreachable;
   } else {
    $$0 = $51;$$01 = $52;
    ___resumeException($$0|0);
    // unreachable;
   }
  } else {
   $17 = (($this) + 84|0);
   $18 = HEAP32[580760>>2]|0;
   $19 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804552,$18,$converter$i$i2,1)|0);
   $20 = ($19|0)==(0);
   if ($20) {
    $115 = $18;
   } else {
    $21 = ($19|0)>(0);
    if ($21) {
     __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS5_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$17,0);
    } else {
     $22 = HEAP32[$converter$i$i2>>2]|0;
     $23 = ($22|0)==(0|0);
     if (!($23)) {
      (FUNCTION_TABLE_iii[$22 & 4095]($17,$transfer)|0);
     }
    }
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
    $115 = $18;
   }
  }
 } while(0);
 $64 = (($this) + 40|0);
 $65 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804576,804920,$$byval_copy8,1)|0);
 $66 = ($65|0)==(0);
 if (!($66)) {
  $67 = ($65|0)>(0);
  if ($67) {
   __ZN4PPtrI7TextureE8TransferI14SafeBinaryReadEEvRT_($64,$transfer);
  } else {
   $68 = HEAP32[$$byval_copy8>>2]|0;
   $69 = ($68|0)==(0|0);
   if (!($69)) {
    (FUNCTION_TABLE_iii[$68 & 4095]($64,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $70 = (($this) + 44|0);
 $71 = HEAP32[580600>>2]|0;
 $72 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804592,$71,$$byval_copy8,1)|0);
 $73 = ($72|0)==(0);
 if (!($73)) {
  $74 = ($72|0)>(0);
  if ($74) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapINSt3__14pairIttEEfN20TextRenderingPrivate4Font14KerningCompareENS2_9allocatorINS3_IS4_fEEEEEEEvRT_17TransferMetaFlags($transfer,$70,0);
  } else {
   $75 = HEAP32[$$byval_copy8>>2]|0;
   $76 = ($75|0)==(0|0);
   if (!($76)) {
    (FUNCTION_TABLE_iii[$75 & 4095]($70,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $77 = (__ZN14SafeBinaryRead12IsOldVersionEi($transfer,1)|0);
 if ($77) {
  $78 = Math_fround(HEAPF32[$5>>2]);
  $79 = Math_fround($78 + Math_fround(1.0));
  HEAPF32[$5>>2] = $79;
 }
 $80 = (($this) + 80|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$80,804608,0);
 $81 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,3)|0);
 L63: do {
  if ($81) {
   $82 = HEAP32[580544>>2]|0;
   $83 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804624,$82,$$byval_copy8,0)|0);
   $84 = ($83|0)==(0);
   if (!($84)) {
    $85 = ($83|0)>(0);
    do {
     if ($85) {
      $86 = (($transfer) + 12|0);
      $87 = (($transfer) + 80|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (($88) + 12|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = (($transfer) + 16|0);
      $92 = HEAP32[$91>>2]|0;
      $93 = (($transfer) + 28|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = (($transfer) + 32|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = Math_imul($96, $94)|0;
      $$sum$i$i$i$i$i = (($90) - ($97))|0;
      $98 = (($92) + ($$sum$i$i$i$i$i)|0);
      HEAP32[$86>>2] = $98;
      $99 = ($$sum$i$i$i$i$i|0)<(0);
      if (!($99)) {
       $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
       $100 = (($92) + ($$sum1$i$i$i$i$i)|0);
       $101 = (($transfer) + 20|0);
       $102 = HEAP32[$101>>2]|0;
       $103 = ($100>>>0)>($102>>>0);
       if (!($103)) {
        $104 = HEAP8[$98>>0]|0;
        HEAP8[$gridFont>>0] = $104;
        $$sum = (($$sum$i$i$i$i$i) + 1)|0;
        $105 = (($92) + ($$sum)|0);
        HEAP32[$86>>2] = $105;
        break;
       }
      }
      __ZN12CachedReader15UpdateReadCacheEPvj($86,$gridFont,1);
     } else {
      $106 = HEAP32[$$byval_copy8>>2]|0;
      $107 = ($106|0)==(0|0);
      if (!($107)) {
       (FUNCTION_TABLE_iii[$106 & 4095]($gridFont,$transfer)|0);
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($transfer);
   }
   $108 = HEAP8[$gridFont>>0]|0;
   $109 = ($108<<24>>24)==(0);
   if (!($109)) {
    __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$fontCountX,804640,0);
    __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$fontCountY,804656,0);
    $110 = HEAP32[$fontCountX>>2]|0;
    $111 = (0 - ($110))|0;
    $112 = (Math_fround(($111|0)));
    HEAPF32[$80>>2] = $112;
    HEAP32[$perCharacterKerning>>2] = 0;
    $113 = (($perCharacterKerning) + 4|0);
    HEAP32[$113>>2] = 0;
    $114 = (($perCharacterKerning) + 8|0);
    HEAP32[$114>>2] = 0;
    __THREW__ = 0;
    $116 = (invoke_iiiiii(192,($transfer|0),(804672|0),($115|0),($converter$i$i19|0),1)|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    L78: do {
     if ($118) {
      label = 70;
     } else {
      $119 = ($116|0)==(0);
      if (!($119)) {
       $120 = ($116|0)>(0);
       if ($120) {
        __THREW__ = 0;
        invoke_viii(2056,($transfer|0),($perCharacterKerning|0),0);
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if ($122) {
         label = 70;
         break;
        }
       } else {
        $123 = HEAP32[$converter$i$i19>>2]|0;
        $124 = ($123|0)==(0|0);
        if (!($124)) {
         __THREW__ = 0;
         (invoke_iii($123|0,($perCharacterKerning|0),($transfer|0))|0);
         $125 = __THREW__; __THREW__ = 0;
         $126 = $125&1;
         if ($126) {
          label = 70;
          break;
         }
        }
       }
       __THREW__ = 0;
       invoke_vi(3389,($transfer|0));
       $127 = __THREW__; __THREW__ = 0;
       $128 = $127&1;
       if ($128) {
        label = 70;
        break;
       }
      }
      $129 = HEAP32[$fontCountX>>2]|0;
      $130 = HEAP32[$fontCountY>>2]|0;
      $131 = Math_imul($130, $129)|0;
      $132 = ($131|0)>(0);
      L88: do {
       if ($132) {
        $133 = (($info) + 4|0);
        $134 = (($info) + 20|0);
        $135 = (($info) + 24|0);
        $136 = (($info) + 28|0);
        $137 = (($info) + 32|0);
        $138 = (($info) + 8|0);
        $139 = (($info) + 12|0);
        $140 = (($info) + 16|0);
        $141 = (($info) + 36|0);
        $142 = (($this) + 88|0);
        $143 = (($this) + 92|0);
        $144 = (($this) + 84|0);
        $146 = $129;$153 = $130;$charNo$050 = 0;
        while(1) {
         dest=$133+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$133+48>>0]=0|0;
         HEAP32[$info>>2] = $charNo$050;
         HEAPF32[$134>>2] = Math_fround(0.0);
         HEAPF32[$135>>2] = Math_fround(0.0);
         HEAPF32[$136>>2] = Math_fround(1.0);
         HEAPF32[$137>>2] = Math_fround(-1.0);
         $145 = (($charNo$050|0) % ($146|0))&-1;
         $147 = $145&65535;
         $148 = (($charNo$050|0) / ($146|0))&-1;
         $149 = $148&65535;
         $150 = (Math_fround(($146|0)));
         $151 = Math_fround(Math_fround(1.0) / $150);
         $152 = (Math_fround(($153|0)));
         $154 = Math_fround(Math_fround(1.0) / $152);
         $155 = (Math_fround(($147<<16>>16)));
         $156 = Math_fround($155 * $151);
         $157 = (Math_fround(($149<<16>>16)));
         $158 = Math_fround($157 * $154);
         $159 = Math_fround(Math_fround(1.0) - $158);
         $160 = Math_fround($159 - $154);
         $161 = Math_fround($151 + $156);
         $162 = Math_fround($161 - $156);
         $163 = Math_fround($159 - $160);
         HEAPF32[$133>>2] = $156;
         HEAPF32[$138>>2] = $160;
         HEAPF32[$139>>2] = $162;
         HEAPF32[$140>>2] = $163;
         HEAPF32[$141>>2] = Math_fround(1.0);
         $164 = HEAP32[$perCharacterKerning>>2]|0;
         $165 = HEAP32[$113>>2]|0;
         $166 = ($164|0)==($165|0);
         if (!($166)) {
          $167 = HEAP32[$3>>2]|0;
          $169 = $164;
          while(1) {
           $168 = HEAP32[$169>>2]|0;
           $170 = (($168) - ($167))|0;
           $171 = ($170|0)==($charNo$050|0);
           if ($171) {
            $172 = (($169) + 4|0);
            $173 = Math_fround(HEAPF32[$172>>2]);
            HEAPF32[$141>>2] = $173;
           }
           $189 = (($169) + 8|0);
           $190 = ($189|0)==($165|0);
           if ($190) {
            break;
           } else {
            $169 = $189;
           }
          }
         }
         $191 = HEAP32[$142>>2]|0;
         $192 = HEAP32[$143>>2]|0;
         $193 = ($191|0)==($192|0);
         if ($193) {
          __THREW__ = 0;
          invoke_vii(3443,($144|0),($info|0));
          $197 = __THREW__; __THREW__ = 0;
          $198 = $197&1;
          if ($198) {
           break;
          }
          $$pre = HEAP32[$fontCountX>>2]|0;
          $$pre53 = HEAP32[$fontCountY>>2]|0;
          $201 = $$pre53;$202 = $$pre;
         } else {
          $194 = ($191|0)==(0|0);
          if ($194) {
           $196 = 0;
          } else {
           dest=$191+0|0; src=$info+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
           $$pre$i = HEAP32[$142>>2]|0;
           $196 = $$pre$i;
          }
          $195 = (($196) + 56|0);
          HEAP32[$142>>2] = $195;
          $201 = $153;$202 = $146;
         }
         $199 = (($charNo$050) + 1)|0;
         $200 = Math_imul($201, $202)|0;
         $203 = ($199|0)<($200|0);
         if ($203) {
          $146 = $202;$153 = $201;$charNo$050 = $199;
         } else {
          break L88;
         }
        }
        $174 = ___cxa_find_matching_catch()|0;
        $175 = tempRet0;
        $lpad$phi$index = $174;$lpad$phi$index2 = $175;
        break L78;
       }
      } while(0);
      $204 = HEAP32[$perCharacterKerning>>2]|0;
      $205 = ($204|0)==(0|0);
      if ($205) {
       break L63;
      }
      $206 = HEAP32[$113>>2]|0;
      $207 = ($206|0)==($204|0);
      if (!($207)) {
       $__new_last2$i$i$i$i$i32 = $204;
       $scevgep$i$i$i$i$i33 = (($206) + -8|0);
       $208 = (0 - ($__new_last2$i$i$i$i$i32))|0;
       $uglygep$i$i$i$i$i35 = (($scevgep$i$i$i$i$i33) + ($208)|0);
       $uglygep3$i$i$i$i$i36 = $uglygep$i$i$i$i$i35;
       $209 = $uglygep3$i$i$i$i$i36 >>> 3;
       $210 = $209 ^ -1;
       $scevgep4$i$i$i$i$i37 = (($206) + ($210<<3)|0);
       HEAP32[$113>>2] = $scevgep4$i$i$i$i$i37;
      }
      HEAP32[$0>>2] = 27;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($204|0),($$byval_copy8|0));
      $211 = __THREW__; __THREW__ = 0;
      $212 = $211&1;
      if (!($212)) {
       break L63;
      }
      $213 = ___cxa_find_matching_catch()|0;
      $214 = tempRet0;
      ___cxa_call_unexpected(($213|0));
      // unreachable;
     }
    } while(0);
    if ((label|0) == 70) {
     $176 = ___cxa_find_matching_catch()|0;
     $177 = tempRet0;
     $lpad$phi$index = $176;$lpad$phi$index2 = $177;
    }
    $178 = HEAP32[$perCharacterKerning>>2]|0;
    $179 = ($178|0)==(0|0);
    if ($179) {
     $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
     ___resumeException($$0|0);
     // unreachable;
    }
    $180 = HEAP32[$113>>2]|0;
    $181 = ($180|0)==($178|0);
    if (!($181)) {
     $__new_last2$i$i$i$i$i24 = $178;
     $scevgep$i$i$i$i$i25 = (($180) + -8|0);
     $182 = (0 - ($__new_last2$i$i$i$i$i24))|0;
     $uglygep$i$i$i$i$i27 = (($scevgep$i$i$i$i$i25) + ($182)|0);
     $uglygep3$i$i$i$i$i28 = $uglygep$i$i$i$i$i27;
     $183 = $uglygep3$i$i$i$i$i28 >>> 3;
     $184 = $183 ^ -1;
     $scevgep4$i$i$i$i$i29 = (($180) + ($184<<3)|0);
     HEAP32[$113>>2] = $scevgep4$i$i$i$i$i29;
    }
    HEAP32[$0>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($178|0),($$byval_copy8|0));
    $185 = __THREW__; __THREW__ = 0;
    $186 = $185&1;
    if ($186) {
     $187 = ___cxa_find_matching_catch()|0;
     $188 = tempRet0;
     ___cxa_call_unexpected(($187|0));
     // unreachable;
    } else {
     $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
     ___resumeException($$0|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $215 = (($this) + 120|0);
 $216 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804696,$115,$$byval_copy8,1)|0);
 $217 = ($216|0)==(0);
 if (!($217)) {
  $218 = ($216|0)>(0);
  if ($218) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$215,0);
  } else {
   $219 = HEAP32[$$byval_copy8>>2]|0;
   $220 = ($219|0)==(0|0);
   if (!($220)) {
    (FUNCTION_TABLE_iii[$219 & 4095]($215,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $221 = (($this) + 32|0);
 $222 = HEAP32[$221>>2]|0;
 $223 = (Math_fround(($222|0)));
 HEAPF32[$fontSize>>2] = $223;
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$fontSize,804712,0);
 $224 = Math_fround(HEAPF32[$fontSize>>2]);
 $225 = (~~(($224)));
 HEAP32[$221>>2] = $225;
 $226 = (($this) + 208|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$226,804728,0);
 $227 = (($this) + 204|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$227,804744,0);
 $228 = (($this) + 132|0);
 $229 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804760,$115,$$byval_copy8,1)|0);
 $230 = ($229|0)==(0);
 if (!($230)) {
  $231 = ($229|0)>(0);
  if ($231) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8UnityStr13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$228,0);
  } else {
   $232 = HEAP32[$$byval_copy8>>2]|0;
   $233 = ($232|0)==(0|0);
   if (!($233)) {
    (FUNCTION_TABLE_iii[$232 & 4095]($228,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $234 = (($this) + 144|0);
 $235 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804776,$115,$$byval_copy8,1)|0);
 $236 = ($235|0)==(0);
 if ($236) {
  $240 = (($this) + 212|0);
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$240,804792,0);
  STACKTOP = sp;return;
 }
 $237 = ($235|0)>(0);
 if ($237) {
  __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS6_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($transfer,$234,0);
 } else {
  $238 = HEAP32[$$byval_copy8>>2]|0;
  $239 = ($238|0)==(0|0);
  if (!($239)) {
   (FUNCTION_TABLE_iii[$238 & 4095]($234,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 $240 = (($this) + 212|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$240,804792,0);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS6_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 2;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,804896,804896,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS5_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,804904,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 4|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,804904,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 4|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,804824,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,804840,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,804824,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,804840,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8UnityStr13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,804896,804896,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorI8UnityStr13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580712>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,$14,0,0)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $30 = 0;$33 = $24;$49 = $27;
      while(1) {
       $29 = Math_imul($30, $20)|0;
       $31 = (($29) + ($26))|0;
       $32 = (($33) + 20|0);
       HEAP32[$32>>2] = $31;
       $34 = (($33) + 12|0);
       HEAP32[$34>>2] = $31;
       $35 = (($33) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$33);
       $36 = $1;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = (($36) + 4)|0;
       $40 = $39;
       $41 = HEAP32[$40>>2]|0;
       $42 = $35;
       $43 = $42;
       HEAP32[$43>>2] = $38;
       $44 = (($42) + 4)|0;
       $45 = $44;
       HEAP32[$45>>2] = $41;
       $46 = HEAP32[$21>>2]|0;
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 1)|0;
       HEAP32[$46>>2] = $48;
       __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$49,0);
       $50 = (($49) + 12|0);
       $51 = ($50|0)==($11|0);
       if ($51) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$16>>2]|0;
       $30 = $$pre9;$33 = $$pre10;$49 = $50;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $52 = HEAP32[$data>>2]|0;
   $53 = ($52|0)==($11|0);
   if (!($53)) {
    $57 = $52;
    while(1) {
     $54 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,$14,$converter$i$i,0)|0);
     $55 = ($54|0)==(0);
     if (!($55)) {
      $56 = ($54|0)>(0);
      if ($56) {
       __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($this,$57,0);
      } else {
       $58 = HEAP32[$converter$i$i>>2]|0;
       $59 = ($58|0)==(0|0);
       if (!($59)) {
        (FUNCTION_TABLE_iii[$58 & 4095]($57,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $60 = (($57) + 12|0);
     $61 = ($60|0)==($11|0);
     if ($61) {
      break;
     } else {
      $57 = $60;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre8 = 0, $$pre9 = 0, $$sum$i$i$i = 0, $$sum1$i$i$i = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0;
 var $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 HEAP32[$size>>2] = $7;
 $8 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,804896,804896,$size)|0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$9);
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$size>>2]|0;
 $12 = ($11|0)==(0);
 L4: do {
  if (!($12)) {
   $13 = HEAP32[580552>>2]|0;
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,$13,0,0)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if (!($22)) {
    __ZN14SafeBinaryRead11EndTransferEv($this);
    $71 = HEAP32[$data>>2]|0;
    $72 = ($71|0)==($10|0);
    if ($72) {
     break;
    } else {
     $73 = $71;
    }
    while(1) {
     __ZN14SafeBinaryRead8TransferIcEEvRT_PKc17TransferMetaFlags($this,$73,804816,0);
     $74 = (($73) + 1|0);
     $75 = ($74|0)==($10|0);
     if ($75) {
      break L4;
     } else {
      $73 = $74;
     }
    }
   }
   $23 = HEAP32[$15>>2]|0;
   $24 = (($23) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = HEAP32[$data>>2]|0;
   $27 = ($26|0)==($10|0);
   L11: do {
    if (!($27)) {
     $28 = (($this) + 12|0);
     $29 = (($this) + 16|0);
     $30 = (($this) + 28|0);
     $31 = (($this) + 32|0);
     $32 = (($this) + 20|0);
     $34 = 0;$37 = $23;$66 = $26;
     while(1) {
      $33 = Math_imul($34, $19)|0;
      $35 = (($33) + ($25))|0;
      $36 = (($37) + 20|0);
      HEAP32[$36>>2] = $35;
      $38 = (($37) + 12|0);
      HEAP32[$38>>2] = $35;
      $39 = (($37) + 24|0);
      __ZNK16TypeTreeIterator8ChildrenEv($1,$37);
      $40 = $1;
      $41 = $40;
      $42 = HEAP32[$41>>2]|0;
      $43 = (($40) + 4)|0;
      $44 = $43;
      $45 = HEAP32[$44>>2]|0;
      $46 = $39;
      $47 = $46;
      HEAP32[$47>>2] = $42;
      $48 = (($46) + 4)|0;
      $49 = $48;
      HEAP32[$49>>2] = $45;
      $50 = HEAP32[$20>>2]|0;
      $51 = HEAP32[$50>>2]|0;
      $52 = (($51) + 1)|0;
      HEAP32[$50>>2] = $52;
      $53 = HEAP32[$15>>2]|0;
      $54 = (($53) + 12|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = HEAP32[$29>>2]|0;
      $57 = HEAP32[$30>>2]|0;
      $58 = HEAP32[$31>>2]|0;
      $59 = Math_imul($58, $57)|0;
      $$sum$i$i$i = (($55) - ($59))|0;
      $60 = (($56) + ($$sum$i$i$i)|0);
      HEAP32[$28>>2] = $60;
      $61 = ($$sum$i$i$i|0)<(0);
      if ($61) {
       label = 9;
      } else {
       $$sum1$i$i$i = (($$sum$i$i$i) + 1)|0;
       $62 = (($56) + ($$sum1$i$i$i)|0);
       $63 = HEAP32[$32>>2]|0;
       $64 = ($62>>>0)>($63>>>0);
       if ($64) {
        label = 9;
       } else {
        $65 = HEAP8[$60>>0]|0;
        HEAP8[$66>>0] = $65;
        $67 = HEAP32[$28>>2]|0;
        $68 = (($67) + 1|0);
        HEAP32[$28>>2] = $68;
       }
      }
      if ((label|0) == 9) {
       label = 0;
       __ZN12CachedReader15UpdateReadCacheEPvj($28,$66,1);
      }
      $69 = (($66) + 1|0);
      $70 = ($69|0)==($10|0);
      if ($70) {
       break L11;
      }
      $$pre = HEAP32[$20>>2]|0;
      $$pre8 = HEAP32[$$pre>>2]|0;
      $$pre9 = HEAP32[$15>>2]|0;
      $34 = $$pre8;$37 = $$pre9;$66 = $69;
     }
    }
   } while(0);
   __ZN14SafeBinaryRead11EndTransferEv($this);
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorINS1_4pairIifEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = $7 >> 3;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,804896,804896,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorINS0_4pairIifEE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = HEAP32[580608>>2]|0;
   $15 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,$14,0,1)|0);
   $16 = (($this) + 80|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (__ZNK16TypeTreeIterator7GetNodeEv($17)|0);
   $19 = (($18) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($this) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = ($15|0)==(2);
   if ($23) {
    $24 = HEAP32[$16>>2]|0;
    $25 = (($24) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$data>>2]|0;
    $28 = ($27|0)==($11|0);
    L8: do {
     if (!($28)) {
      $29 = HEAP32[580576>>2]|0;
      $30 = HEAP32[580656>>2]|0;
      $32 = 0;$35 = $24;$51 = $27;
      while(1) {
       $31 = Math_imul($32, $20)|0;
       $33 = (($31) + ($26))|0;
       $34 = (($35) + 20|0);
       HEAP32[$34>>2] = $33;
       $36 = (($35) + 12|0);
       HEAP32[$36>>2] = $33;
       $37 = (($35) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$35);
       $38 = $1;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = (($38) + 4)|0;
       $42 = $41;
       $43 = HEAP32[$42>>2]|0;
       $44 = $37;
       $45 = $44;
       HEAP32[$45>>2] = $40;
       $46 = (($44) + 4)|0;
       $47 = $46;
       HEAP32[$47>>2] = $43;
       $48 = HEAP32[$21>>2]|0;
       $49 = HEAP32[$48>>2]|0;
       $50 = (($49) + 1)|0;
       HEAP32[$48>>2] = $50;
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$51,$29,0);
       $52 = (($51) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$52,$30,0);
       $53 = (($51) + 8|0);
       $54 = ($53|0)==($11|0);
       if ($54) {
        break L8;
       }
       $$pre = HEAP32[$21>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$16>>2]|0;
       $32 = $$pre9;$35 = $$pre10;$51 = $53;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $55 = HEAP32[$data>>2]|0;
   $56 = ($55|0)==($11|0);
   if (!($56)) {
    $57 = HEAP32[580576>>2]|0;
    $58 = HEAP32[580656>>2]|0;
    $62 = $55;
    while(1) {
     $59 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,$14,$converter$i$i,1)|0);
     $60 = ($59|0)==(0);
     if (!($60)) {
      $61 = ($59|0)>(0);
      if ($61) {
       __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($this,$62,$57,0);
       $63 = (($62) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$63,$58,0);
      } else {
       $64 = HEAP32[$converter$i$i>>2]|0;
       $65 = ($64|0)==(0|0);
       if (!($65)) {
        (FUNCTION_TABLE_iii[$64 & 4095]($62,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $66 = (($62) + 8|0);
     $67 = ($66|0)==($11|0);
     if ($67) {
      break;
     } else {
      $62 = $66;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayI10vector_mapINSt3__14pairIttEEfN20TextRenderingPrivate4Font14KerningCompareENS2_9allocatorINS3_IS4_fEEEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $__new_last2$i$i$i$i = 0, $converter$i$i = 0, $converter$i$i$i2 = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $size = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $converter$i$i$i2 = sp + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($data) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 3;
 HEAP32[$size>>2] = $9;
 $10 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,804896,804896,$size)|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$size>>2]|0;
 $12 = (($data) + 4|0);
 $13 = HEAP32[$2>>2]|0;
 $14 = HEAP32[$12>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = $17 >> 3;
 $19 = ($18>>>0)<($11>>>0);
 if ($19) {
  $20 = (($11) - ($18))|0;
  __ZNSt3__16vectorINS_4pairINS1_IttEEfEENS_9allocatorIS3_EEE8__appendEj($12,$20);
  $$pre = HEAP32[$2>>2]|0;
  $$pre10 = HEAP32[$size>>2]|0;
  $28 = $$pre10;$44 = $$pre;
 } else {
  $21 = ($18>>>0)>($11>>>0);
  if ($21) {
   $22 = (($14) + ($11<<3)|0);
   $23 = ($13|0)==($22|0);
   if ($23) {
    $28 = $11;$44 = $13;
   } else {
    $__new_last2$i$i$i$i = $22;
    $scevgep$i$i$i$i = (($13) + -8|0);
    $24 = (0 - ($__new_last2$i$i$i$i))|0;
    $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($24)|0);
    $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
    $25 = $uglygep3$i$i$i$i >>> 3;
    $26 = $25 ^ -1;
    $scevgep4$i$i$i$i = (($13) + ($26<<3)|0);
    HEAP32[$2>>2] = $scevgep4$i$i$i$i;
    $28 = $11;$44 = $scevgep4$i$i$i$i;
   }
  } else {
   $28 = $11;$44 = $13;
  }
 }
 $27 = ($28|0)==(0);
 do {
  if (!($27)) {
   $29 = HEAP32[580608>>2]|0;
   $30 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,$29,0,1)|0);
   $31 = (($this) + 80|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (__ZNK16TypeTreeIterator7GetNodeEv($32)|0);
   $34 = (($33) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($this) + 84|0);
   $37 = HEAP32[$36>>2]|0;
   HEAP32[$37>>2] = 0;
   $38 = ($30|0)==(2);
   if ($38) {
    $39 = HEAP32[$31>>2]|0;
    $40 = (($39) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$4>>2]|0;
    $43 = ($42|0)==($44|0);
    L14: do {
     if (!($43)) {
      $45 = HEAP32[580576>>2]|0;
      $46 = HEAP32[580656>>2]|0;
      $48 = 0;$51 = $39;$70 = $42;
      while(1) {
       $47 = Math_imul($48, $35)|0;
       $49 = (($47) + ($41))|0;
       $50 = (($51) + 20|0);
       HEAP32[$50>>2] = $49;
       $52 = (($51) + 12|0);
       HEAP32[$52>>2] = $49;
       $53 = (($51) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$51);
       $54 = $1;
       $55 = $54;
       $56 = HEAP32[$55>>2]|0;
       $57 = (($54) + 4)|0;
       $58 = $57;
       $59 = HEAP32[$58>>2]|0;
       $60 = $53;
       $61 = $60;
       HEAP32[$61>>2] = $56;
       $62 = (($60) + 4)|0;
       $63 = $62;
       HEAP32[$63>>2] = $59;
       $64 = HEAP32[$36>>2]|0;
       $65 = HEAP32[$64>>2]|0;
       $66 = (($65) + 1)|0;
       HEAP32[$64>>2] = $66;
       $67 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$45,$29,$converter$i$i$i2,1)|0);
       $68 = ($67|0)==(0);
       if (!($68)) {
        $69 = ($67|0)>(0);
        if ($69) {
         __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($this,$70,$45,0);
         $71 = (($70) + 2|0);
         __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($this,$71,$46,0);
        } else {
         $72 = HEAP32[$converter$i$i$i2>>2]|0;
         $73 = ($72|0)==(0|0);
         if (!($73)) {
          (FUNCTION_TABLE_iii[$72 & 4095]($70,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $74 = (($70) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$74,$46,0);
       $75 = (($70) + 8|0);
       $76 = ($75|0)==($44|0);
       if ($76) {
        break L14;
       }
       $$pre11 = HEAP32[$36>>2]|0;
       $$pre12 = HEAP32[$$pre11>>2]|0;
       $$pre13 = HEAP32[$31>>2]|0;
       $48 = $$pre12;$51 = $$pre13;$70 = $75;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $77 = HEAP32[$4>>2]|0;
   $78 = ($77|0)==($44|0);
   if (!($78)) {
    $79 = HEAP32[580576>>2]|0;
    $80 = HEAP32[580656>>2]|0;
    $87 = $77;
    while(1) {
     $81 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,$29,$converter$i$i,1)|0);
     $82 = ($81|0)==(0);
     if (!($82)) {
      $83 = ($81|0)>(0);
      if ($83) {
       $84 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,$79,$29,$converter$i$i$i2,1)|0);
       $85 = ($84|0)==(0);
       if (!($85)) {
        $86 = ($84|0)>(0);
        if ($86) {
         __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($this,$87,$79,0);
         $88 = (($87) + 2|0);
         __ZN14SafeBinaryRead8TransferItEEvRT_PKc17TransferMetaFlags($this,$88,$80,0);
        } else {
         $89 = HEAP32[$converter$i$i$i2>>2]|0;
         $90 = ($89|0)==(0|0);
         if (!($90)) {
          (FUNCTION_TABLE_iii[$89 & 4095]($87,$this)|0);
         }
        }
        __ZN14SafeBinaryRead11EndTransferEv($this);
       }
       $91 = (($87) + 4|0);
       __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($this,$91,$80,0);
      } else {
       $92 = HEAP32[$converter$i$i>>2]|0;
       $93 = ($92|0)==(0|0);
       if (!($93)) {
        (FUNCTION_TABLE_iii[$92 & 4095]($87,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $94 = (($87) + 8|0);
     $95 = ($94|0)==($44|0);
     if ($95) {
      break;
     } else {
      $87 = $94;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,804896,804896,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,804936,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 56|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,804936,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 56|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$this,804856,0);
 $0 = (($this) + 4|0);
 __ZN14SafeBinaryRead8TransferI5RectTIfEEEvRT_PKc17TransferMetaFlags($transfer,$0,804864,0);
 $1 = (($this) + 20|0);
 __ZN14SafeBinaryRead8TransferI5RectTIfEEEvRT_PKc17TransferMetaFlags($transfer,$1,804872,0);
 $2 = (($this) + 36|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$2,804880,0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[580544>>2]|0;
 $5 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,804888,$4,$converter$i$i,0)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = ($5|0)>(0);
  do {
   if ($7) {
    $8 = (($transfer) + 12|0);
    $9 = (($transfer) + 80|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($transfer) + 16|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($transfer) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($transfer) + 32|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = Math_imul($18, $16)|0;
    $$sum$i$i$i$i$i = (($12) - ($19))|0;
    $20 = (($14) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$8>>2] = $20;
    $21 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($21)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $22 = (($14) + ($$sum1$i$i$i$i$i)|0);
     $23 = (($transfer) + 20|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($22>>>0)>($24>>>0);
     if (!($25)) {
      $26 = HEAP8[$20>>0]|0;
      HEAP8[$3>>0] = $26;
      $27 = HEAP32[$8>>2]|0;
      $28 = (($27) + 1|0);
      HEAP32[$8>>2] = $28;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($8,$3,1);
   } else {
    $29 = HEAP32[$converter$i$i>>2]|0;
    $30 = ($29|0)==(0|0);
    if (!($30)) {
     (FUNCTION_TABLE_iii[$29 & 4095]($3,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $31 = (__ZN14SafeBinaryRead16IsCurrentVersionEv($transfer)|0);
 if ($31) {
  STACKTOP = sp;return;
 }
 $32 = (($this) + 28|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 HEAPF32[$2>>2] = $33;
 STACKTOP = sp;return;
}
function __ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS5_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags($this,$data,$0) {
 $this = $this|0;
 $data = $data|0;
 $0 = $0|0;
 var $$pre = 0, $$pre10 = 0, $$pre9 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp + 12|0;
 $size = sp + 8|0;
 $1 = sp;
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 HEAP32[$size>>2] = $8;
 $9 = (__ZN14SafeBinaryRead18BeginArrayTransferEPKcS1_Ri($this,804896,804896,$size)|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = HEAP32[$size>>2]|0;
 __Z14resize_trimmedINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEvRT_j($data,$10);
 $11 = HEAP32[$2>>2]|0;
 $12 = HEAP32[$size>>2]|0;
 $13 = ($12|0)==(0);
 do {
  if (!($13)) {
   $14 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,804936,0,1)|0);
   $15 = (($this) + 80|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (__ZNK16TypeTreeIterator7GetNodeEv($16)|0);
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($this) + 84|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$21>>2] = 0;
   $22 = ($14|0)==(2);
   if ($22) {
    $23 = HEAP32[$15>>2]|0;
    $24 = (($23) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$data>>2]|0;
    $27 = ($26|0)==($11|0);
    L8: do {
     if (!($27)) {
      $29 = 0;$32 = $23;$48 = $26;
      while(1) {
       $28 = Math_imul($29, $19)|0;
       $30 = (($28) + ($25))|0;
       $31 = (($32) + 20|0);
       HEAP32[$31>>2] = $30;
       $33 = (($32) + 12|0);
       HEAP32[$33>>2] = $30;
       $34 = (($32) + 24|0);
       __ZNK16TypeTreeIterator8ChildrenEv($1,$32);
       $35 = $1;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $38 = (($35) + 4)|0;
       $39 = $38;
       $40 = HEAP32[$39>>2]|0;
       $41 = $34;
       $42 = $41;
       HEAP32[$42>>2] = $37;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $40;
       $45 = HEAP32[$20>>2]|0;
       $46 = HEAP32[$45>>2]|0;
       $47 = (($46) + 1)|0;
       HEAP32[$45>>2] = $47;
       __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI14SafeBinaryReadEEvRT_($48,$this);
       $49 = (($48) + 56|0);
       $50 = ($49|0)==($11|0);
       if ($50) {
        break L8;
       }
       $$pre = HEAP32[$20>>2]|0;
       $$pre9 = HEAP32[$$pre>>2]|0;
       $$pre10 = HEAP32[$15>>2]|0;
       $29 = $$pre9;$32 = $$pre10;$48 = $49;
      }
     }
    } while(0);
    __ZN14SafeBinaryRead11EndTransferEv($this);
    break;
   }
   __ZN14SafeBinaryRead11EndTransferEv($this);
   $51 = HEAP32[$data>>2]|0;
   $52 = ($51|0)==($11|0);
   if (!($52)) {
    $56 = $51;
    while(1) {
     $53 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($this,804816,804936,$converter$i$i,1)|0);
     $54 = ($53|0)==(0);
     if (!($54)) {
      $55 = ($53|0)>(0);
      if ($55) {
       __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI14SafeBinaryReadEEvRT_($56,$this);
      } else {
       $57 = HEAP32[$converter$i$i>>2]|0;
       $58 = ($57|0)==(0|0);
       if (!($58)) {
        (FUNCTION_TABLE_iii[$57 & 4095]($56,$this)|0);
       }
      }
      __ZN14SafeBinaryRead11EndTransferEv($this);
     }
     $59 = (($56) + 56|0);
     $60 = ($59|0)==($11|0);
     if ($60) {
      break;
     } else {
      $56 = $59;
     }
    }
   }
  }
 } while(0);
 __ZN14SafeBinaryRead16EndArrayTransferEv($this);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate4Font8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0);
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i10 = 0, $emptyCharacterInfo = 0, $fontSize = 0;
 var $p$i$i$i$i = 0, $p$i$i$i24 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i11 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i15 = 0, $size$i = 0, $size$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i13 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i14 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy3 = sp + 56|0;
 $size$i$i$i$i$i = sp;
 $p$i$i$i$i = sp + 160|0;
 $size$i = sp + 104|0;
 $0 = sp + 164|0;
 $p$i$i$i24 = sp + 80|0;
 $1 = sp + 72|0;
 $emptyCharacterInfo = sp + 92|0;
 $fontSize = sp + 76|0;
 __ZN11NamedObject8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,4);
 $2 = (($this) + 72|0);
 $3 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804408,$3,$2,0);
 $4 = (($transfer) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($transfer) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($6) + (($8*24)|0)|0) + 12|0);
 HEAP32[$9>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 60|0);
 $11 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804432,$11,$10,0);
 $12 = HEAP32[$4>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$7>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 28|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804448,$11,$16,0);
 $17 = HEAP32[$4>>2]|0;
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$7>>2]|0;
 $20 = ((($18) + (($19*24)|0)|0) + 12|0);
 HEAP32[$20>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $21 = (($this) + 64|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804464,$3,$21,0);
 $22 = HEAP32[$4>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$7>>2]|0;
 $25 = ((($23) + (($24*24)|0)|0) + 12|0);
 HEAP32[$25>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $26 = (($this) + 68|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804488,$3,$26,0);
 $27 = HEAP32[$4>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$7>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $31 = (($this) + 76|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804512,$3,$31,0);
 $32 = HEAP32[$4>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$7>>2]|0;
 $35 = ((($33) + (($34*24)|0)|0) + 12|0);
 HEAP32[$35>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $36 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804528,804952,$36,0);
 $37 = (($$byval_copy3) + 8|0);
 $38 = $37;
 $39 = $38;
 HEAP32[$39>>2] = 0;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = 0;
 HEAP32[$$byval_copy3>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804824,$3,$36,1);
 $42 = HEAP32[$4>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = HEAP32[$7>>2]|0;
 $45 = ((($43) + (($44*24)|0)|0) + 12|0);
 HEAP32[$45>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $46 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804840,$46,$37,1);
 $47 = HEAP32[$4>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$7>>2]|0;
 $50 = ((($48) + (($49*24)|0)|0) + 12|0);
 HEAP32[$50>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $51 = HEAP32[$31>>2]|0;
 $52 = ($51|0)==(-2);
 do {
  if ($52) {
   HEAP32[$emptyCharacterInfo>>2] = 0;
   $56 = (($emptyCharacterInfo) + 4|0);
   HEAP32[$56>>2] = 0;
   $57 = (($emptyCharacterInfo) + 8|0);
   HEAP32[$57>>2] = 0;
   $58 = HEAP32[580760>>2]|0;
   __THREW__ = 0;
   invoke_viiiii(86,($transfer|0),(804552|0),($58|0),($emptyCharacterInfo|0),0);
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if (!($60)) {
    HEAP32[$size$i>>2] = -1;
    $61 = (($size$i) + 4|0);
    dest=$61+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$61+48>>0]=0|0;
    __THREW__ = 0;
    invoke_viiiii(87,($transfer|0),(804896|0),(804896|0),($p$i$i$i$i|0),0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if (!($63)) {
     __THREW__ = 0;
     invoke_viiiii(86,($transfer|0),(804816|0),(804936|0),($size$i|0),0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if (!($65)) {
      __THREW__ = 0;
      invoke_vii(3444,($size$i|0),($transfer|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if (!($67)) {
       __THREW__ = 0;
       invoke_vi(3390,($transfer|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if (!($69)) {
        __THREW__ = 0;
        invoke_vi(3391,($transfer|0));
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if (!($71)) {
         __THREW__ = 0;
         invoke_vi(3390,($transfer|0));
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if (!($73)) {
          $74 = HEAP32[$emptyCharacterInfo>>2]|0;
          $75 = ($74|0)==(0|0);
          if ($75) {
           $142 = $58;
           break;
          }
          $76 = HEAP32[$56>>2]|0;
          $77 = ($76|0)==($74|0);
          if (!($77)) {
           $__new_last2$i$i$i$i$i = $74;
           $scevgep$i$i$i$i$i = (($76) + -56|0);
           $78 = (0 - ($__new_last2$i$i$i$i$i))|0;
           $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($78)|0);
           $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
           $79 = (($uglygep3$i$i$i$i$i>>>0) / 56)&-1;
           $80 = $79 ^ -1;
           $scevgep4$i$i$i$i$i = (($76) + (($80*56)|0)|0);
           HEAP32[$56>>2] = $scevgep4$i$i$i$i$i;
          }
          HEAP32[$1>>2] = 90;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
          invoke_vii(2591,($74|0),($$byval_copy3|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if (!($82)) {
           $142 = $58;
           break;
          }
          $83 = ___cxa_find_matching_catch()|0;
          $84 = tempRet0;
          ___cxa_call_unexpected(($83|0));
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
   $85 = ___cxa_find_matching_catch()|0;
   $86 = tempRet0;
   $87 = HEAP32[$emptyCharacterInfo>>2]|0;
   $88 = ($87|0)==(0|0);
   if ($88) {
    ___resumeException($85|0);
    // unreachable;
   }
   $89 = HEAP32[$56>>2]|0;
   $90 = ($89|0)==($87|0);
   if (!($90)) {
    $__new_last2$i$i$i$i$i10 = $87;
    $scevgep$i$i$i$i$i11 = (($89) + -56|0);
    $91 = (0 - ($__new_last2$i$i$i$i$i10))|0;
    $uglygep$i$i$i$i$i13 = (($scevgep$i$i$i$i$i11) + ($91)|0);
    $uglygep3$i$i$i$i$i14 = $uglygep$i$i$i$i$i13;
    $92 = (($uglygep3$i$i$i$i$i14>>>0) / 56)&-1;
    $93 = $92 ^ -1;
    $scevgep4$i$i$i$i$i15 = (($89) + (($93*56)|0)|0);
    HEAP32[$56>>2] = $scevgep4$i$i$i$i$i15;
   }
   HEAP32[$size$i$i$i$i$i>>2] = 90;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$size$i$i$i$i$i+0>>2]|0;
   invoke_vii(2591,($87|0),($$byval_copy3|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    $96 = ___cxa_find_matching_catch()|0;
    $97 = tempRet0;
    ___cxa_call_unexpected(($96|0));
    // unreachable;
   } else {
    ___resumeException($85|0);
    // unreachable;
   }
  } else {
   $53 = (($this) + 84|0);
   $54 = HEAP32[580760>>2]|0;
   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804552,$54,$53,0);
   HEAP32[$size$i$i$i$i$i>>2] = -1;
   $55 = (($size$i$i$i$i$i) + 4|0);
   dest=$55+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$55+48>>0]=0|0;
   __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,804896,804896,$$byval_copy3,0);
   __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804816,804936,$size$i$i$i$i$i,0);
   __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI13ProxyTransferEEvRT_($size$i$i$i$i$i,$transfer);
   __ZN13ProxyTransfer11EndTransferEv($transfer);
   __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
   __ZN13ProxyTransfer11EndTransferEv($transfer);
   $142 = $54;
  }
 } while(0);
 $98 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804576,804920,$98,1);
 $99 = (($$byval_copy3) + 8|0);
 $100 = $99;
 $101 = $100;
 HEAP32[$101>>2] = 0;
 $102 = (($100) + 4)|0;
 $103 = $102;
 HEAP32[$103>>2] = 0;
 HEAP32[$$byval_copy3>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804824,$3,$98,1);
 $104 = HEAP32[$4>>2]|0;
 $105 = HEAP32[$104>>2]|0;
 $106 = HEAP32[$7>>2]|0;
 $107 = ((($105) + (($106*24)|0)|0) + 12|0);
 HEAP32[$107>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804840,$46,$99,1);
 $108 = HEAP32[$4>>2]|0;
 $109 = HEAP32[$108>>2]|0;
 $110 = HEAP32[$7>>2]|0;
 $111 = ((($109) + (($110*24)|0)|0) + 12|0);
 HEAP32[$111>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $112 = (($this) + 44|0);
 $113 = HEAP32[580600>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804592,$113,$112,1);
 $114 = $size$i$i$i$i$i;
 $115 = $114;
 HEAP32[$115>>2] = 0;
 $116 = (($114) + 4)|0;
 $117 = $116;
 HEAP32[$117>>2] = 0;
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,804896,804896,$$byval_copy3,0);
 $118 = HEAP32[580608>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804816,$118,$size$i$i$i$i$i,0);
 $119 = HEAP32[580576>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$119,$118,$size$i$i$i$i$i,0);
 $120 = HEAP32[580720>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$119,$120,$size$i$i$i$i$i,0);
 $121 = HEAP32[$4>>2]|0;
 $122 = HEAP32[$121>>2]|0;
 $123 = HEAP32[$7>>2]|0;
 $124 = ((($122) + (($123*24)|0)|0) + 12|0);
 HEAP32[$124>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $125 = (($size$i$i$i$i$i) + 2|0);
 $126 = HEAP32[580656>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$126,$120,$125,0);
 $127 = HEAP32[$4>>2]|0;
 $128 = HEAP32[$127>>2]|0;
 $129 = HEAP32[$7>>2]|0;
 $130 = ((($128) + (($129*24)|0)|0) + 12|0);
 HEAP32[$130>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $131 = (($size$i$i$i$i$i) + 4|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,$126,$11,$131,0);
 $132 = HEAP32[$4>>2]|0;
 $133 = HEAP32[$132>>2]|0;
 $134 = HEAP32[$7>>2]|0;
 $135 = ((($133) + (($134*24)|0)|0) + 12|0);
 HEAP32[$135>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $136 = (($this) + 80|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804608,$11,$136,1);
 $137 = HEAP32[$4>>2]|0;
 $138 = HEAP32[$137>>2]|0;
 $139 = HEAP32[$7>>2]|0;
 $140 = ((($138) + (($139*24)|0)|0) + 12|0);
 HEAP32[$140>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $141 = (($this) + 120|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804696,$142,$141,1);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,804896,804896,$$byval_copy3,0);
 $143 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804816,$143,$size$i$i$i$i$i,0);
 $144 = HEAP32[$4>>2]|0;
 $145 = HEAP32[$144>>2]|0;
 $146 = HEAP32[$7>>2]|0;
 $147 = ((($145) + (($146*24)|0)|0) + 12|0);
 HEAP32[$147>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $148 = (($this) + 32|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = (Math_fround(($149|0)));
 HEAPF32[$fontSize>>2] = $150;
 $151 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804712,$151,$fontSize,1);
 $152 = HEAP32[$4>>2]|0;
 $153 = HEAP32[$152>>2]|0;
 $154 = HEAP32[$7>>2]|0;
 $155 = ((($153) + (($154*24)|0)|0) + 12|0);
 HEAP32[$155>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $156 = Math_fround(HEAPF32[$fontSize>>2]);
 $157 = (~~(($156)));
 HEAP32[$148>>2] = $157;
 $158 = (($this) + 208|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804728,$151,$158,1);
 $159 = HEAP32[$4>>2]|0;
 $160 = HEAP32[$159>>2]|0;
 $161 = HEAP32[$7>>2]|0;
 $162 = ((($160) + (($161*24)|0)|0) + 12|0);
 HEAP32[$162>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $163 = (($this) + 204|0);
 $164 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804744,$164,$163,1);
 $165 = HEAP32[$4>>2]|0;
 $166 = HEAP32[$165>>2]|0;
 $167 = HEAP32[$7>>2]|0;
 $168 = ((($166) + (($167*24)|0)|0) + 12|0);
 HEAP32[$168>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $169 = (($this) + 132|0);
 $170 = HEAP32[580760>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804760,$170,$169,1);
 ;HEAP32[$p$i$i$i24+0>>2]=0|0;HEAP32[$p$i$i$i24+4>>2]=0|0;HEAP32[$p$i$i$i24+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiii(87,($transfer|0),(804896|0),(804896|0),($size$i|0),0);
 $171 = __THREW__; __THREW__ = 0;
 $172 = $171&1;
 if (!($172)) {
  $173 = HEAP32[580712>>2]|0;
  __THREW__ = 0;
  invoke_viiiii(86,($transfer|0),(804816|0),($173|0),($p$i$i$i24|0),0);
  $174 = __THREW__; __THREW__ = 0;
  $175 = $174&1;
  if (!($175)) {
   __THREW__ = 0;
   invoke_viiiii(87,($transfer|0),(804896|0),(804896|0),($size$i$i$i$i$i|0),1);
   $176 = __THREW__; __THREW__ = 0;
   $177 = $176&1;
   if (!($177)) {
    __THREW__ = 0;
    invoke_viiiii(86,($transfer|0),(804816|0),($143|0),($p$i$i$i$i|0),0);
    $178 = __THREW__; __THREW__ = 0;
    $179 = $178&1;
    if (!($179)) {
     $180 = HEAP32[$4>>2]|0;
     $181 = HEAP32[$180>>2]|0;
     $182 = HEAP32[$7>>2]|0;
     $183 = ((($181) + (($182*24)|0)|0) + 12|0);
     HEAP32[$183>>2] = 1;
     __THREW__ = 0;
     invoke_vi(3390,($transfer|0));
     $184 = __THREW__; __THREW__ = 0;
     $185 = $184&1;
     if (!($185)) {
      __THREW__ = 0;
      invoke_vi(3391,($transfer|0));
      $186 = __THREW__; __THREW__ = 0;
      $187 = $186&1;
      if (!($187)) {
       __THREW__ = 0;
       invoke_vi(3392,($transfer|0));
       $188 = __THREW__; __THREW__ = 0;
       $189 = $188&1;
       if (!($189)) {
        __THREW__ = 0;
        invoke_vi(3390,($transfer|0));
        $190 = __THREW__; __THREW__ = 0;
        $191 = $190&1;
        if (!($191)) {
         __THREW__ = 0;
         invoke_vi(3391,($transfer|0));
         $192 = __THREW__; __THREW__ = 0;
         $193 = $192&1;
         if (!($193)) {
          $194 = HEAP8[$p$i$i$i24>>0]|0;
          $195 = $194 & 1;
          $196 = ($195<<24>>24)==(0);
          if ($196) {
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $214 = (($this) + 144|0);
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804776,$170,$214,1);
           HEAP32[$p$i$i$i$i>>2] = 0;
           __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,804896,804896,$size$i$i$i$i$i,0);
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804816,804904,$p$i$i$i$i,0);
           $215 = (($$byval_copy3) + 8|0);
           $216 = $215;
           $217 = $216;
           HEAP32[$217>>2] = 0;
           $218 = (($216) + 4)|0;
           $219 = $218;
           HEAP32[$219>>2] = 0;
           HEAP32[$$byval_copy3>>2] = 0;
           $220 = HEAP32[580592>>2]|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804824,$220,$p$i$i$i$i,1);
           $221 = HEAP32[$4>>2]|0;
           $222 = HEAP32[$221>>2]|0;
           $223 = HEAP32[$7>>2]|0;
           $224 = ((($222) + (($223*24)|0)|0) + 12|0);
           HEAP32[$224>>2] = 4;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $225 = HEAP32[580688>>2]|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804840,$225,$215,1);
           $226 = HEAP32[$4>>2]|0;
           $227 = HEAP32[$226>>2]|0;
           $228 = HEAP32[$7>>2]|0;
           $229 = ((($227) + (($228*24)|0)|0) + 12|0);
           HEAP32[$229>>2] = 8;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           __ZN13ProxyTransfer5AlignEv($transfer);
           $230 = (($this) + 212|0);
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804792,$220,$230,0);
           $231 = HEAP32[$4>>2]|0;
           $232 = HEAP32[$231>>2]|0;
           $233 = HEAP32[$7>>2]|0;
           $234 = ((($232) + (($233*24)|0)|0) + 12|0);
           HEAP32[$234>>2] = 4;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           STACKTOP = sp;return;
          }
          $197 = (($p$i$i$i24) + 8|0);
          $198 = HEAP32[$197>>2]|0;
          HEAP32[$size$i>>2] = 59;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$size$i+0>>2]|0;
          invoke_vii(2591,($198|0),($$byval_copy3|0));
          $199 = __THREW__; __THREW__ = 0;
          $200 = $199&1;
          if ($200) {
           $201 = ___cxa_find_matching_catch()|0;
           $202 = tempRet0;
           ___cxa_call_unexpected(($201|0));
           // unreachable;
          } else {
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $214 = (($this) + 144|0);
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804776,$170,$214,1);
           HEAP32[$p$i$i$i$i>>2] = 0;
           __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,804896,804896,$size$i$i$i$i$i,0);
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804816,804904,$p$i$i$i$i,0);
           $215 = (($$byval_copy3) + 8|0);
           $216 = $215;
           $217 = $216;
           HEAP32[$217>>2] = 0;
           $218 = (($216) + 4)|0;
           $219 = $218;
           HEAP32[$219>>2] = 0;
           HEAP32[$$byval_copy3>>2] = 0;
           $220 = HEAP32[580592>>2]|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804824,$220,$p$i$i$i$i,1);
           $221 = HEAP32[$4>>2]|0;
           $222 = HEAP32[$221>>2]|0;
           $223 = HEAP32[$7>>2]|0;
           $224 = ((($222) + (($223*24)|0)|0) + 12|0);
           HEAP32[$224>>2] = 4;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           $225 = HEAP32[580688>>2]|0;
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804840,$225,$215,1);
           $226 = HEAP32[$4>>2]|0;
           $227 = HEAP32[$226>>2]|0;
           $228 = HEAP32[$7>>2]|0;
           $229 = ((($227) + (($228*24)|0)|0) + 12|0);
           HEAP32[$229>>2] = 8;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           __ZN13ProxyTransfer5AlignEv($transfer);
           $230 = (($this) + 212|0);
           __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804792,$220,$230,0);
           $231 = HEAP32[$4>>2]|0;
           $232 = HEAP32[$231>>2]|0;
           $233 = HEAP32[$7>>2]|0;
           $234 = ((($232) + (($233*24)|0)|0) + 12|0);
           HEAP32[$234>>2] = 4;
           __ZN13ProxyTransfer11EndTransferEv($transfer);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $203 = ___cxa_find_matching_catch()|0;
 $204 = tempRet0;
 $205 = HEAP8[$p$i$i$i24>>0]|0;
 $206 = $205 & 1;
 $207 = ($206<<24>>24)==(0);
 if ($207) {
  ___resumeException($203|0);
  // unreachable;
 }
 $208 = (($p$i$i$i24) + 8|0);
 $209 = HEAP32[$208>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($209|0),($$byval_copy3|0));
 $210 = __THREW__; __THREW__ = 0;
 $211 = $210&1;
 if ($211) {
  $212 = ___cxa_find_matching_catch()|0;
  $213 = tempRet0;
  ___cxa_call_unexpected(($212|0));
  // unreachable;
 } else {
  ___resumeException($203|0);
  // unreachable;
 }
}
function __ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804856,$0,$this,0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*24)|0)|0) + 12|0);
 HEAP32[$6>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $7 = (($this) + 4|0);
 $8 = HEAP32[580648>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804864,$8,$7,0);
 __ZN5RectTIfE8TransferI13ProxyTransferEEvRT_($7,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($this) + 20|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804872,$8,$9,0);
 __ZN5RectTIfE8TransferI13ProxyTransferEEvRT_($9,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $10 = (($this) + 36|0);
 $11 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804880,$11,$10,0);
 $12 = HEAP32[$1>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$4>>2]|0;
 $15 = ((($13) + (($14*24)|0)|0) + 12|0);
 HEAP32[$15>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $16 = (($this) + 52|0);
 $17 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,804888,$17,$16,0);
 $18 = HEAP32[$1>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$4>>2]|0;
 $21 = ((($19) + (($20*24)|0)|0) + 12|0);
 HEAP32[$21>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20TextRenderingPrivate4Font7IntRectE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 4;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = $13 >> 4;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $13 >> 3;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = $$0$i2 << 4;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,804096,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + ($7<<4)|0);
 $24 = (($23) + ($$0$i3<<4)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  ;HEAP32[$22+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$__x+12>>2]|0;
 }
 $26 = (($23) + ($8<<4)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = $28;
 $30 = $27;
 $31 = (($29) - ($30))|0;
 $32 = $31 >> 4;
 $$sum1 = (($7) - ($32))|0;
 $33 = (($23) + ($$sum1<<4)|0);
 _memcpy(($33|0),($27|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$1>>2] = $26;
 HEAP32[$10>>2] = $24;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($__nd|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$2);
 $3 = (($__nd) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$4);
 HEAP32[$0>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($__nd|0),($$byval_copy|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  ___cxa_call_unexpected(($7|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN13sorted_vectorIN20TextRenderingPrivate4Font13CharacterInfoENSt3__14lessIS2_EENS3_9allocatorIS2_EEE10insert_oneERKS2_($agg$result,$this,$x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $x = $x|0;
 var $$byval_copy = 0, $$c$i$i$i4 = 0, $$neg3$i$i$i = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0$be$i$i$i = 0, $__len$04$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if ($5) {
  $32 = $2;
 } else {
  $6 = $2;
  $7 = $4;
  $8 = (($7) - ($6))|0;
  $9 = (($8|0) / 56)&-1;
  $10 = HEAP32[$x>>2]|0;
  $11 = (($x) + 40|0);
  $12 = (($x) + 44|0);
  $15 = $2;$__len$04$i$i$i = $9;
  while(1) {
   $13 = (($__len$04$i$i$i|0) / 2)&-1;
   $14 = (($15) + (($13*56)|0)|0);
   $16 = HEAP32[$14>>2]|0;
   $17 = ($16|0)==($10|0);
   if ($17) {
    $18 = ((($15) + (($13*56)|0)|0) + 40|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = HEAP32[$11>>2]|0;
    $21 = ($19|0)<($20|0);
    if ($21) {
     label = 8;
    } else {
     $22 = ($19|0)>($20|0);
     if ($22) {
      $51 = $15;$__len$0$be$i$i$i = $13;
     } else {
      $23 = ((($15) + (($13*56)|0)|0) + 44|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = HEAP32[$12>>2]|0;
      $26 = ($24>>>0)<($25>>>0);
      if ($26) {
       label = 8;
      } else {
       $51 = $15;$__len$0$be$i$i$i = $13;
      }
     }
    }
   } else {
    $27 = ($16>>>0)<($10>>>0);
    if ($27) {
     label = 8;
    } else {
     $51 = $15;$__len$0$be$i$i$i = $13;
    }
   }
   if ((label|0) == 8) {
    label = 0;
    $$sum$i$i$i = (($13) + 1)|0;
    $28 = (($15) + (($$sum$i$i$i*56)|0)|0);
    $$neg3$i$i$i = (($__len$04$i$i$i) + -1)|0;
    $29 = (($$neg3$i$i$i) - ($13))|0;
    $51 = $28;$__len$0$be$i$i$i = $29;
   }
   $30 = ($__len$0$be$i$i$i|0)==(0);
   if ($30) {
    $32 = $51;
    break;
   } else {
    $15 = $51;$__len$04$i$i$i = $__len$0$be$i$i$i;
   }
  }
 }
 $31 = ($32|0)==($4|0);
 do {
  if (!($31)) {
   $33 = HEAP32[$x>>2]|0;
   $34 = HEAP32[$32>>2]|0;
   $35 = ($33|0)==($34|0);
   if ($35) {
    $36 = (($x) + 40|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($32) + 40|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($37|0)<($39|0);
    if ($40) {
     break;
    }
    $41 = ($37|0)>($39|0);
    if (!($41)) {
     $42 = (($x) + 44|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($32) + 44|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($43>>>0)<($45>>>0);
     if ($46) {
      break;
     }
    }
   } else {
    $47 = ($33>>>0)<($34>>>0);
    if ($47) {
     break;
    }
   }
   HEAP32[$agg$result>>2] = $32;
   $50 = (($agg$result) + 4|0);
   HEAP8[$50>>0] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 HEAP32[$1>>2] = $32;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($0,$this,$$byval_copy,$x);
 $48 = HEAP32[$0>>2]|0;
 $$c$i$i$i4 = $48;
 HEAP32[$agg$result>>2] = $$c$i$i$i4;
 $49 = (($agg$result) + 4|0);
 HEAP8[$49>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i11 = 0, $$0$i12 = 0, $$pre = 0, $$pre$i10 = 0, $$sum = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$__position>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = (($4|0) / 56)&-1;
 $6 = (($0) + (($5*56)|0)|0);
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)<($10>>>0);
 if ($11) {
  $12 = ($6|0)==($8|0);
  if ($12) {
   $13 = ($6|0)==(0|0);
   if ($13) {
    $15 = 0;
   } else {
    dest=$6+0|0; src=$__x+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $$pre = HEAP32[$7>>2]|0;
    $15 = $$pre;
   }
   $14 = (($15) + 56|0);
   HEAP32[$7>>2] = $14;
   $__p$0 = $6;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($5) + 1)|0;
  $16 = (($0) + (($$sum*56)|0)|0);
  $17 = $8;
  $18 = $16;
  $19 = (($17) - ($18))|0;
  $20 = (($19|0) / 56)&-1;
  $$sum15 = (($20) + ($5))|0;
  $21 = (($0) + (($$sum15*56)|0)|0);
  $22 = ($21>>>0)<($8>>>0);
  if ($22) {
   $24 = $8;$__i$01$i = $21;
   while(1) {
    $23 = ($24|0)==(0|0);
    if ($23) {
     $27 = 0;
    } else {
     dest=$24+0|0; src=$__i$01$i+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $$pre$i10 = HEAP32[$7>>2]|0;
     $27 = $$pre$i10;
    }
    $25 = (($__i$01$i) + 56|0);
    $26 = (($27) + 56|0);
    HEAP32[$7>>2] = $26;
    $28 = ($25>>>0)<($8>>>0);
    if ($28) {
     $24 = $26;$__i$01$i = $25;
    } else {
     break;
    }
   }
  }
  $29 = (($19|0) / -56)&-1;
  $30 = (($8) + (($29*56)|0)|0);
  _memmove(($30|0),($6|0),($19|0))|0;
  $31 = ($6>>>0)>($__x>>>0);
  if ($31) {
   $__xr$0 = $__x;
  } else {
   $32 = HEAP32[$7>>2]|0;
   $33 = ($32>>>0)>($__x>>>0);
   $34 = (($__x) + 56|0);
   $$ = $33 ? $34 : $__x;
   $__xr$0 = $$;
  }
  dest=$6+0|0; src=$__xr$0+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP8[$6+52>>0]=HEAP8[$__xr$0+52>>0]|0;
  $__p$0 = $6;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $35 = $8;
 $36 = (($35) - ($3))|0;
 $37 = (($36|0) / 56)&-1;
 $38 = (($37) + 1)|0;
 $39 = ($38>>>0)>(76695844);
 if ($39) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $40 = $10;
 $41 = (($40) - ($3))|0;
 $42 = (($41|0) / 56)&-1;
 $43 = ($42>>>0)<(38347922);
 if ($43) {
  $46 = $42 << 1;
  $47 = ($46>>>0)<($38>>>0);
  $48 = $47 ? $38 : $46;
  $49 = $6;
  $50 = (($4|0) / 56)&-1;
  $51 = ($48|0)==(0);
  if ($51) {
   $$0$i12 = 0;$55 = 0;$56 = $50;$82 = $49;
  } else {
   $$0$i11 = $48;$96 = $50;$97 = $49;
   label = 18;
  }
 } else {
  $44 = $6;
  $45 = (($4|0) / 56)&-1;
  $$0$i11 = 76695844;$96 = $45;$97 = $44;
  label = 18;
 }
 if ((label|0) == 18) {
  $52 = ($$0$i11*56)|0;
  $53 = (__Znwj($52)|0);
  $$0$i12 = $$0$i11;$55 = $53;$56 = $96;$82 = $97;
 }
 $54 = (($55) + (($56*56)|0)|0);
 $57 = (($55) + (($$0$i12*56)|0)|0);
 $58 = ($56|0)==($$0$i12|0);
 do {
  if ($58) {
   $59 = ($56|0)>(0);
   $60 = (($4|0) / 56)&-1;
   if ($59) {
    $61 = (($60) + 1)|0;
    $62 = (($61|0) / -2)&-1;
    $$sum14 = (($62) + ($56))|0;
    $63 = (($55) + (($$sum14*56)|0)|0);
    $76 = $63;$91 = $57;
    break;
   }
   $64 = $60 << 1;
   $65 = ($64|0)==(0);
   $66 = $65 ? 1 : $64;
   $67 = ($66*56)|0;
   __THREW__ = 0;
   $68 = (invoke_ii(2988,($67|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if (!($70)) {
    $71 = $66 >>> 2;
    $72 = (($68) + (($71*56)|0)|0);
    $73 = (($68) + (($66*56)|0)|0);
    $74 = ($55|0)==(0|0);
    if ($74) {
     $76 = $72;$91 = $73;
     break;
    }
    __ZdlPv($55);
    $76 = $72;$91 = $73;
    break;
   }
   $93 = ___cxa_find_matching_catch()|0;
   $94 = tempRet0;
   $95 = ($55|0)==(0|0);
   if ($95) {
    ___resumeException($93|0);
    // unreachable;
   }
   __ZdlPv($55);
   ___resumeException($93|0);
   // unreachable;
  } else {
   $76 = $54;$91 = $57;
  }
 } while(0);
 $75 = ($76|0)==(0|0);
 if ($75) {
  $78 = 0;
 } else {
  dest=$76+0|0; src=$__x+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $78 = $76;
 }
 $77 = (($78) + 56|0);
 $79 = HEAP32[$this>>2]|0;
 $80 = $79;
 $81 = (($82) - ($80))|0;
 $83 = (($81|0) / -56)&-1;
 $84 = (($76) + (($83*56)|0)|0);
 _memcpy(($84|0),($79|0),($81|0))|0;
 $85 = HEAP32[$7>>2]|0;
 $86 = $85;
 $87 = (($86) - ($82))|0;
 $88 = (($87|0) / 56)&-1;
 _memcpy(($77|0),($6|0),($87|0))|0;
 $$sum13 = (($88) + 1)|0;
 $89 = (($78) + (($$sum13*56)|0)|0);
 $90 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $84;
 HEAP32[$7>>2] = $89;
 HEAP32[$9>>2] = $91;
 $92 = ($90|0)==(0|0);
 if ($92) {
  $__p$0 = $76;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 __ZdlPv($90);
 $__p$0 = $76;
 HEAP32[$agg$result>>2] = $__p$0;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE21__push_back_slow_pathIKS3_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$byval_copy1 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 56)&-1;
 $8 = (($7) + 1)|0;
 $9 = ($8|0)<(0);
 if ($9) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $10 = (($this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 56)&-1;
 $15 = ($14>>>0)<(1073741823);
 if ($15) {
  $16 = $14 << 1;
  $17 = ($16>>>0)<($8>>>0);
  $18 = $17 ? $8 : $16;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0$i3 = 0;$23 = 0;
  } else {
   $$0$i2 = $18;
   label = 5;
  }
 } else {
  $$0$i2 = 2147483647;
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = ($$0$i2*56)|0;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($20,16,$$byval_copy1,0,804096,79)|0);
  $$0$i3 = $$0$i2;$23 = $21;
 }
 $22 = (($23) + (($7*56)|0)|0);
 $24 = (($23) + (($$0$i3*56)|0)|0);
 $25 = ($22|0)==(0|0);
 if (!($25)) {
  dest=$22+0|0; src=$__x+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $26 = (($23) + (($8*56)|0)|0);
 $27 = HEAP32[$this>>2]|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = $28;
 $30 = $27;
 $31 = (($29) - ($30))|0;
 $32 = (($31|0) / -56)&-1;
 $$sum1 = (($32) + ($7))|0;
 $33 = (($23) + (($$sum1*56)|0)|0);
 _memcpy(($33|0),($27|0),($31|0))|0;
 $34 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $33;
 HEAP32[$1>>2] = $26;
 HEAP32[$10>>2] = $24;
 $35 = ($34|0)==(0|0);
 if ($35) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($34|0),($$byval_copy1|0));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  ___cxa_call_unexpected(($38|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$0$i$i$i = 0, $$0$i$i1$i = 0, $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $__parent = sp + 4|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $23 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $23;
   $$0$i = $23;$40 = $23;
  } else {
   $4 = HEAP32[$__v>>2]|0;
   $5 = (($__v) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + ($4))|0;
   $__nd$0$in$i = $2;
   while(1) {
    $8 = (($__nd$0$in$i) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($__nd$0$in$i) + 20|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($11) + ($9))|0;
    $13 = ($7|0)==($12|0);
    $14 = ($7|0)<($12|0);
    $15 = ($4|0)<($9|0);
    $$0$i$i1$i = $13 ? $15 : $14;
    if ($$0$i$i1$i) {
     $16 = HEAP32[$__nd$0$in$i>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $16;
      continue;
     }
    }
    $18 = ($12|0)<($7|0);
    $19 = ($9|0)<($4|0);
    $$0$i$i$i = $13 ? $19 : $18;
    if (!($$0$i$i$i)) {
     label = 9;
     break;
    }
    $20 = (($__nd$0$in$i) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $21;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$40 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $20;$40 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$40 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $24 = HEAP32[$$0$i>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $50 = 0;$__r$0 = $24;
  HEAP32[$agg$result>>2] = $__r$0;
  $49 = (($agg$result) + 4|0);
  HEAP8[$49>>0] = $50;
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 27;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $26 = (__Z15malloc_internaljj10MemLabelIdiPKci(24,16,$$byval_copy,0,804096,79)|0);
 $27 = (($26) + 16|0);
 $28 = $__v;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 4)|0;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = $27;
 $35 = $34;
 HEAP32[$35>>2] = $30;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = $33;
 HEAP32[$26>>2] = 0;
 $38 = (($26) + 4|0);
 HEAP32[$38>>2] = 0;
 $39 = (($26) + 8|0);
 HEAP32[$39>>2] = $40;
 HEAP32[$$0$i>>2] = $26;
 $41 = HEAP32[$this>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if ($43) {
  $45 = $26;
 } else {
  HEAP32[$this>>2] = $42;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $45 = $$pre$i;
 }
 $44 = HEAP32[$1>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($44,$45);
 $46 = (($this) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 1)|0;
 HEAP32[$46>>2] = $48;
 $50 = 1;$__r$0 = $26;
 HEAP32[$agg$result>>2] = $__r$0;
 $49 = (($agg$result) + 4|0);
 HEAP8[$49>>0] = $50;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i56 = 0, $$0$i57 = 0, $$byval_copy1 = 0, $$pre1$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 56)&-1;
 $9 = ($8>>>0)<($__n>>>0);
 if (!($9)) {
  $$0$i = $__n;$11 = $4;
  while(1) {
   $10 = ($11|0)==(0|0);
   if ($10) {
    $14 = 0;
   } else {
    HEAP32[$11>>2] = -1;
    $12 = (($11) + 4|0);
    dest=$12+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$12+48>>0]=0|0;
    $$pre1$i = HEAP32[$3>>2]|0;
    $14 = $$pre1$i;
   }
   $13 = (($14) + 56|0);
   HEAP32[$3>>2] = $13;
   $15 = (($$0$i) + -1)|0;
   $16 = ($15|0)==(0);
   if ($16) {
    break;
   } else {
    $$0$i = $15;$11 = $13;
   }
  }
  STACKTOP = sp;return;
 }
 $17 = HEAP32[$this>>2]|0;
 $18 = $17;
 $19 = (($6) - ($18))|0;
 $20 = (($19|0) / 56)&-1;
 $21 = (($20) + ($__n))|0;
 $22 = ($21|0)<(0);
 if ($22) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $23 = (($5) - ($18))|0;
 $24 = (($23|0) / 56)&-1;
 $25 = ($24>>>0)<(1073741823);
 if ($25) {
  $26 = $24 << 1;
  $27 = ($26>>>0)<($21>>>0);
  $28 = $27 ? $21 : $26;
  $29 = ($28|0)==(0);
  if ($29) {
   $$0$i57 = 0;$33 = 0;
  } else {
   $$0$i56 = $28;
   label = 9;
  }
 } else {
  $$0$i56 = 2147483647;
  label = 9;
 }
 if ((label|0) == 9) {
  $30 = ($$0$i56*56)|0;
  HEAP32[$0>>2] = 27;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $31 = (__Z15malloc_internaljj10MemLabelIdiPKci($30,16,$$byval_copy1,0,804096,79)|0);
  $$0$i57 = $$0$i56;$33 = $31;
 }
 $32 = (($33) + (($20*56)|0)|0);
 $$0$i2 = $__n;$35 = $32;
 while(1) {
  $34 = ($35|0)==(0|0);
  if ($34) {
   $38 = 0;
  } else {
   HEAP32[$35>>2] = -1;
   $36 = (($35) + 4|0);
   dest=$36+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP8[$36+48>>0]=0|0;
   $38 = $35;
  }
  $37 = (($38) + 56|0);
  $39 = (($$0$i2) + -1)|0;
  $40 = ($39|0)==(0);
  if ($40) {
   break;
  } else {
   $$0$i2 = $39;$35 = $37;
  }
 }
 $41 = (($33) + (($$0$i57*56)|0)|0);
 $42 = HEAP32[$this>>2]|0;
 $43 = HEAP32[$3>>2]|0;
 $44 = $43;
 $45 = $42;
 $46 = (($44) - ($45))|0;
 $47 = (($46|0) / -56)&-1;
 $$sum = (($47) + ($20))|0;
 $48 = (($33) + (($$sum*56)|0)|0);
 _memcpy(($48|0),($42|0),($46|0))|0;
 $49 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $48;
 HEAP32[$3>>2] = $37;
 HEAP32[$1>>2] = $41;
 $50 = ($49|0)==(0|0);
 if ($50) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($49|0),($$byval_copy1|0));
 $51 = __THREW__; __THREW__ = 0;
 $52 = $51&1;
 if ($52) {
  $53 = ___cxa_find_matching_catch()|0;
  $54 = tempRet0;
  ___cxa_call_unexpected(($53|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate4FontD2Ev($this) {
 $this = $this|0;
 var $$byval_copy14 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i62 = 0, $$pre$i$i$i64 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i$i$i35 = 0, $__new_last2$i$i$i$i$i$i$i$i$i80 = 0, $__new_last2$i$i$i$i$i$i$i$i$i98 = 0, $__new_last2$i$i$i$i$i11 = 0, $__new_last2$i$i$i$i$i19 = 0, $__new_last2$i$i$i$i$i26 = 0, $__new_last2$i$i$i$i$i42 = 0, $__new_last2$i$i$i$i$i51 = 0, $__new_last2$i$i$i$i$i71 = 0, $__new_last2$i$i$i$i$i89 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i$i36 = 0, $scevgep$i$i$i$i$i$i$i$i$i81 = 0, $scevgep$i$i$i$i$i$i$i$i$i99 = 0, $scevgep$i$i$i$i$i12 = 0, $scevgep$i$i$i$i$i20 = 0;
 var $scevgep$i$i$i$i$i27 = 0, $scevgep$i$i$i$i$i43 = 0, $scevgep$i$i$i$i$i52 = 0, $scevgep$i$i$i$i$i72 = 0, $scevgep$i$i$i$i$i90 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i$i103 = 0, $scevgep4$i$i$i$i$i$i$i$i$i40 = 0, $scevgep4$i$i$i$i$i$i$i$i$i85 = 0, $scevgep4$i$i$i$i$i16 = 0, $scevgep4$i$i$i$i$i24 = 0, $scevgep4$i$i$i$i$i31 = 0, $scevgep4$i$i$i$i$i47 = 0, $scevgep4$i$i$i$i$i56 = 0, $scevgep4$i$i$i$i$i76 = 0, $scevgep4$i$i$i$i$i94 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i$i101 = 0;
 var $uglygep$i$i$i$i$i$i$i$i$i38 = 0, $uglygep$i$i$i$i$i$i$i$i$i83 = 0, $uglygep$i$i$i$i$i14 = 0, $uglygep$i$i$i$i$i22 = 0, $uglygep$i$i$i$i$i29 = 0, $uglygep$i$i$i$i$i45 = 0, $uglygep$i$i$i$i$i54 = 0, $uglygep$i$i$i$i$i74 = 0, $uglygep$i$i$i$i$i92 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i$i102 = 0, $uglygep3$i$i$i$i$i$i$i$i$i39 = 0, $uglygep3$i$i$i$i$i$i$i$i$i84 = 0, $uglygep3$i$i$i$i$i15 = 0, $uglygep3$i$i$i$i$i23 = 0, $uglygep3$i$i$i$i$i30 = 0, $uglygep3$i$i$i$i$i46 = 0, $uglygep3$i$i$i$i$i55 = 0, $uglygep3$i$i$i$i$i75 = 0;
 var $uglygep3$i$i$i$i$i93 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy14 = sp + 32|0;
 $0 = sp + 28|0;
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 12|0;
 HEAP32[$this>>2] = ((803992 + 8|0));
 $8 = (($this) + 216|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[628296>>2]|0;
 $11 = ($9|0)==(0|0);
 if ($11) {
  label = 3;
 } else {
  __THREW__ = 0;
  invoke_vi(3726,($9|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  HEAP32[$7>>2] = $10;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$7+0>>2]|0;
  invoke_vii(2591,($9|0),($$byval_copy14|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   HEAP32[$8>>2] = 0;
   $16 = (($this) + 168|0);
   $17 = (($this) + 172|0);
   $18 = HEAP32[$17>>2]|0;
   __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($16,$18);
   $19 = (($this) + 156|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $22 = (($this) + 160|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==($20|0);
    if (!($24)) {
     $__new_last2$i$i$i$i$i = $20;
     $scevgep$i$i$i$i$i = (($23) + -16|0);
     $25 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($25)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $26 = $uglygep3$i$i$i$i$i >>> 4;
     $27 = $26 ^ -1;
     $scevgep4$i$i$i$i$i = (($23) + ($27<<4)|0);
     HEAP32[$22>>2] = $scevgep4$i$i$i$i$i;
    }
    HEAP32[$6>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_vii(2591,($20|0),($$byval_copy14|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     $30 = ___cxa_find_matching_catch()|0;
     $31 = tempRet0;
     ___cxa_call_unexpected(($30|0));
     // unreachable;
    }
   }
   $32 = (($this) + 144|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0|0);
   if (!($34)) {
    $35 = (($this) + 148|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==($33|0);
    if (!($37)) {
     $__new_last2$i$i$i$i$i11 = $33;
     $scevgep$i$i$i$i$i12 = (($36) + -4|0);
     $38 = (0 - ($__new_last2$i$i$i$i$i11))|0;
     $uglygep$i$i$i$i$i14 = (($scevgep$i$i$i$i$i12) + ($38)|0);
     $uglygep3$i$i$i$i$i15 = $uglygep$i$i$i$i$i14;
     $39 = $uglygep3$i$i$i$i$i15 >>> 2;
     $40 = $39 ^ -1;
     $scevgep4$i$i$i$i$i16 = (($36) + ($40<<2)|0);
     HEAP32[$35>>2] = $scevgep4$i$i$i$i$i16;
    }
    HEAP32[$5>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
    invoke_vii(2591,($33|0),($$byval_copy14|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     $43 = ___cxa_find_matching_catch()|0;
     $44 = tempRet0;
     ___cxa_call_unexpected(($43|0));
     // unreachable;
    }
   }
   $45 = (($this) + 132|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    $48 = (($this) + 136|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==($46|0);
    do {
     if ($50) {
      $64 = $46;
     } else {
      $52 = $49;
      while(1) {
       $51 = (($52) + -12|0);
       HEAP32[$48>>2] = $51;
       $53 = HEAP8[$51>>0]|0;
       $54 = $53 & 1;
       $55 = ($54<<24>>24)==(0);
       if ($55) {
        $57 = $51;
       } else {
        $58 = (($52) + -4|0);
        $59 = HEAP32[$58>>2]|0;
        HEAP32[$3>>2] = 59;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
        invoke_vii(2591,($59|0),($$byval_copy14|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 21;
         break;
        }
        $$pre$i$i$i$i$i = HEAP32[$48>>2]|0;
        $57 = $$pre$i$i$i$i$i;
       }
       $56 = ($57|0)==($46|0);
       if ($56) {
        label = 22;
        break;
       } else {
        $52 = $57;
       }
      }
      if ((label|0) == 21) {
       $62 = ___cxa_find_matching_catch()|0;
       $63 = tempRet0;
       ___cxa_call_unexpected(($62|0));
       // unreachable;
      }
      else if ((label|0) == 22) {
       $$pre$i$i$i = HEAP32[$45>>2]|0;
       $64 = $$pre$i$i$i;
       break;
      }
     }
    } while(0);
    HEAP32[$4>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($64|0),($$byval_copy14|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     $67 = ___cxa_find_matching_catch()|0;
     $68 = tempRet0;
     ___cxa_call_unexpected(($67|0));
     // unreachable;
    }
   }
   $69 = (($this) + 120|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==(0|0);
   if (!($71)) {
    $72 = (($this) + 124|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73|0)==($70|0);
    if (!($74)) {
     HEAP32[$72>>2] = $70;
    }
    HEAP32[$2>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($70|0),($$byval_copy14|0));
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     $77 = ___cxa_find_matching_catch()|0;
     $78 = tempRet0;
     ___cxa_call_unexpected(($77|0));
     // unreachable;
    }
   }
   $79 = (($this) + 108|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($80|0)==(0|0);
   if (!($81)) {
    $82 = (($this) + 112|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($83|0)==($80|0);
    if (!($84)) {
     $__new_last2$i$i$i$i$i19 = $80;
     $scevgep$i$i$i$i$i20 = (($83) + -56|0);
     $85 = (0 - ($__new_last2$i$i$i$i$i19))|0;
     $uglygep$i$i$i$i$i22 = (($scevgep$i$i$i$i$i20) + ($85)|0);
     $uglygep3$i$i$i$i$i23 = $uglygep$i$i$i$i$i22;
     $86 = (($uglygep3$i$i$i$i$i23>>>0) / 56)&-1;
     $87 = $86 ^ -1;
     $scevgep4$i$i$i$i$i24 = (($83) + (($87*56)|0)|0);
     HEAP32[$82>>2] = $scevgep4$i$i$i$i$i24;
    }
    HEAP32[$1>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($80|0),($$byval_copy14|0));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     $90 = ___cxa_find_matching_catch()|0;
     $91 = tempRet0;
     ___cxa_call_unexpected(($90|0));
     // unreachable;
    }
   }
   $92 = (($this) + 96|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0|0);
   if (!($94)) {
    $95 = (($this) + 100|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ($96|0)==($93|0);
    if (!($97)) {
     $__new_last2$i$i$i$i$i$i$i$i$i = $93;
     $scevgep$i$i$i$i$i$i$i$i$i = (($96) + -56|0);
     $98 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i$i) + ($98)|0);
     $uglygep3$i$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i$i;
     $99 = (($uglygep3$i$i$i$i$i$i$i$i$i>>>0) / 56)&-1;
     $100 = $99 ^ -1;
     $scevgep4$i$i$i$i$i$i$i$i$i = (($96) + (($100*56)|0)|0);
     HEAP32[$95>>2] = $scevgep4$i$i$i$i$i$i$i$i$i;
    }
    __ZdlPv($93);
   }
   $101 = (($this) + 84|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ($102|0)==(0|0);
   if (!($103)) {
    $104 = (($this) + 88|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($105|0)==($102|0);
    if (!($106)) {
     $__new_last2$i$i$i$i$i26 = $102;
     $scevgep$i$i$i$i$i27 = (($105) + -56|0);
     $107 = (0 - ($__new_last2$i$i$i$i$i26))|0;
     $uglygep$i$i$i$i$i29 = (($scevgep$i$i$i$i$i27) + ($107)|0);
     $uglygep3$i$i$i$i$i30 = $uglygep$i$i$i$i$i29;
     $108 = (($uglygep3$i$i$i$i$i30>>>0) / 56)&-1;
     $109 = $108 ^ -1;
     $scevgep4$i$i$i$i$i31 = (($105) + (($109*56)|0)|0);
     HEAP32[$104>>2] = $scevgep4$i$i$i$i$i31;
    }
    HEAP32[$0>>2] = 27;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($102|0),($$byval_copy14|0));
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if ($111) {
     $112 = ___cxa_find_matching_catch()|0;
     $113 = tempRet0;
     ___cxa_call_unexpected(($112|0));
     // unreachable;
    }
   }
   $114 = (($this) + 48|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ($115|0)==(0|0);
   if ($116) {
    __ZN11NamedObjectD2Ev($this);
    STACKTOP = sp;return;
   }
   $117 = (($this) + 52|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = ($118|0)==($115|0);
   if (!($119)) {
    $__new_last2$i$i$i$i$i$i$i$i$i35 = $115;
    $scevgep$i$i$i$i$i$i$i$i$i36 = (($118) + -8|0);
    $120 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i35))|0;
    $uglygep$i$i$i$i$i$i$i$i$i38 = (($scevgep$i$i$i$i$i$i$i$i$i36) + ($120)|0);
    $uglygep3$i$i$i$i$i$i$i$i$i39 = $uglygep$i$i$i$i$i$i$i$i$i38;
    $121 = $uglygep3$i$i$i$i$i$i$i$i$i39 >>> 3;
    $122 = $121 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i$i40 = (($118) + ($122<<3)|0);
    HEAP32[$117>>2] = $scevgep4$i$i$i$i$i$i$i$i$i40;
   }
   __ZdlPv($115);
   __ZN11NamedObjectD2Ev($this);
   STACKTOP = sp;return;
  }
 }
 $123 = ___cxa_find_matching_catch()|0;
 $124 = tempRet0;
 $125 = (($this) + 168|0);
 $126 = (($this) + 172|0);
 $127 = HEAP32[$126>>2]|0;
 __ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE7destroyEPNS_11__tree_nodeIS3_PvEE($125,$127);
 $128 = (($this) + 156|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ($129|0)==(0|0);
 if (!($130)) {
  $131 = (($this) + 160|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = ($132|0)==($129|0);
  if (!($133)) {
   $__new_last2$i$i$i$i$i42 = $129;
   $scevgep$i$i$i$i$i43 = (($132) + -16|0);
   $134 = (0 - ($__new_last2$i$i$i$i$i42))|0;
   $uglygep$i$i$i$i$i45 = (($scevgep$i$i$i$i$i43) + ($134)|0);
   $uglygep3$i$i$i$i$i46 = $uglygep$i$i$i$i$i45;
   $135 = $uglygep3$i$i$i$i$i46 >>> 4;
   $136 = $135 ^ -1;
   $scevgep4$i$i$i$i$i47 = (($132) + ($136<<4)|0);
   HEAP32[$131>>2] = $scevgep4$i$i$i$i$i47;
  }
  HEAP32[$6>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$6+0>>2]|0;
  invoke_vii(2591,($129|0),($$byval_copy14|0));
  $137 = __THREW__; __THREW__ = 0;
  $138 = $137&1;
  if ($138) {
   $139 = ___cxa_find_matching_catch()|0;
   $140 = tempRet0;
   ___cxa_call_unexpected(($139|0));
   // unreachable;
  }
 }
 $141 = (($this) + 144|0);
 $142 = HEAP32[$141>>2]|0;
 $143 = ($142|0)==(0|0);
 if (!($143)) {
  $144 = (($this) + 148|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = ($145|0)==($142|0);
  if (!($146)) {
   $__new_last2$i$i$i$i$i51 = $142;
   $scevgep$i$i$i$i$i52 = (($145) + -4|0);
   $147 = (0 - ($__new_last2$i$i$i$i$i51))|0;
   $uglygep$i$i$i$i$i54 = (($scevgep$i$i$i$i$i52) + ($147)|0);
   $uglygep3$i$i$i$i$i55 = $uglygep$i$i$i$i$i54;
   $148 = $uglygep3$i$i$i$i$i55 >>> 2;
   $149 = $148 ^ -1;
   $scevgep4$i$i$i$i$i56 = (($145) + ($149<<2)|0);
   HEAP32[$144>>2] = $scevgep4$i$i$i$i$i56;
  }
  HEAP32[$5>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,($142|0),($$byval_copy14|0));
  $150 = __THREW__; __THREW__ = 0;
  $151 = $150&1;
  if ($151) {
   $152 = ___cxa_find_matching_catch()|0;
   $153 = tempRet0;
   ___cxa_call_unexpected(($152|0));
   // unreachable;
  }
 }
 $154 = (($this) + 132|0);
 $155 = HEAP32[$154>>2]|0;
 $156 = ($155|0)==(0|0);
 if (!($156)) {
  $157 = (($this) + 136|0);
  $158 = HEAP32[$157>>2]|0;
  $159 = ($158|0)==($155|0);
  do {
   if ($159) {
    $173 = $155;
   } else {
    $161 = $158;
    while(1) {
     $160 = (($161) + -12|0);
     HEAP32[$157>>2] = $160;
     $162 = HEAP8[$160>>0]|0;
     $163 = $162 & 1;
     $164 = ($163<<24>>24)==(0);
     if ($164) {
      $166 = $160;
     } else {
      $167 = (($161) + -4|0);
      $168 = HEAP32[$167>>2]|0;
      HEAP32[$3>>2] = 59;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$3+0>>2]|0;
      invoke_vii(2591,($168|0),($$byval_copy14|0));
      $169 = __THREW__; __THREW__ = 0;
      $170 = $169&1;
      if ($170) {
       label = 66;
       break;
      }
      $$pre$i$i$i$i$i62 = HEAP32[$157>>2]|0;
      $166 = $$pre$i$i$i$i$i62;
     }
     $165 = ($166|0)==($155|0);
     if ($165) {
      label = 67;
      break;
     } else {
      $161 = $166;
     }
    }
    if ((label|0) == 66) {
     $171 = ___cxa_find_matching_catch()|0;
     $172 = tempRet0;
     ___cxa_call_unexpected(($171|0));
     // unreachable;
    }
    else if ((label|0) == 67) {
     $$pre$i$i$i64 = HEAP32[$154>>2]|0;
     $173 = $$pre$i$i$i64;
     break;
    }
   }
  } while(0);
  HEAP32[$4>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($173|0),($$byval_copy14|0));
  $174 = __THREW__; __THREW__ = 0;
  $175 = $174&1;
  if ($175) {
   $176 = ___cxa_find_matching_catch()|0;
   $177 = tempRet0;
   ___cxa_call_unexpected(($176|0));
   // unreachable;
  }
 }
 $178 = (($this) + 120|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = ($179|0)==(0|0);
 if (!($180)) {
  $181 = (($this) + 124|0);
  $182 = HEAP32[$181>>2]|0;
  $183 = ($182|0)==($179|0);
  if (!($183)) {
   HEAP32[$181>>2] = $179;
  }
  HEAP32[$2>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($179|0),($$byval_copy14|0));
  $184 = __THREW__; __THREW__ = 0;
  $185 = $184&1;
  if ($185) {
   $186 = ___cxa_find_matching_catch()|0;
   $187 = tempRet0;
   ___cxa_call_unexpected(($186|0));
   // unreachable;
  }
 }
 $188 = (($this) + 108|0);
 $189 = HEAP32[$188>>2]|0;
 $190 = ($189|0)==(0|0);
 if (!($190)) {
  $191 = (($this) + 112|0);
  $192 = HEAP32[$191>>2]|0;
  $193 = ($192|0)==($189|0);
  if (!($193)) {
   $__new_last2$i$i$i$i$i71 = $189;
   $scevgep$i$i$i$i$i72 = (($192) + -56|0);
   $194 = (0 - ($__new_last2$i$i$i$i$i71))|0;
   $uglygep$i$i$i$i$i74 = (($scevgep$i$i$i$i$i72) + ($194)|0);
   $uglygep3$i$i$i$i$i75 = $uglygep$i$i$i$i$i74;
   $195 = (($uglygep3$i$i$i$i$i75>>>0) / 56)&-1;
   $196 = $195 ^ -1;
   $scevgep4$i$i$i$i$i76 = (($192) + (($196*56)|0)|0);
   HEAP32[$191>>2] = $scevgep4$i$i$i$i$i76;
  }
  HEAP32[$1>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($189|0),($$byval_copy14|0));
  $197 = __THREW__; __THREW__ = 0;
  $198 = $197&1;
  if ($198) {
   $199 = ___cxa_find_matching_catch()|0;
   $200 = tempRet0;
   ___cxa_call_unexpected(($199|0));
   // unreachable;
  }
 }
 $201 = (($this) + 96|0);
 $202 = HEAP32[$201>>2]|0;
 $203 = ($202|0)==(0|0);
 if (!($203)) {
  $204 = (($this) + 100|0);
  $205 = HEAP32[$204>>2]|0;
  $206 = ($205|0)==($202|0);
  if (!($206)) {
   $__new_last2$i$i$i$i$i$i$i$i$i80 = $202;
   $scevgep$i$i$i$i$i$i$i$i$i81 = (($205) + -56|0);
   $207 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i80))|0;
   $uglygep$i$i$i$i$i$i$i$i$i83 = (($scevgep$i$i$i$i$i$i$i$i$i81) + ($207)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i84 = $uglygep$i$i$i$i$i$i$i$i$i83;
   $208 = (($uglygep3$i$i$i$i$i$i$i$i$i84>>>0) / 56)&-1;
   $209 = $208 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i85 = (($205) + (($209*56)|0)|0);
   HEAP32[$204>>2] = $scevgep4$i$i$i$i$i$i$i$i$i85;
  }
  __ZdlPv($202);
 }
 $210 = (($this) + 84|0);
 $211 = HEAP32[$210>>2]|0;
 $212 = ($211|0)==(0|0);
 if (!($212)) {
  $213 = (($this) + 88|0);
  $214 = HEAP32[$213>>2]|0;
  $215 = ($214|0)==($211|0);
  if (!($215)) {
   $__new_last2$i$i$i$i$i89 = $211;
   $scevgep$i$i$i$i$i90 = (($214) + -56|0);
   $216 = (0 - ($__new_last2$i$i$i$i$i89))|0;
   $uglygep$i$i$i$i$i92 = (($scevgep$i$i$i$i$i90) + ($216)|0);
   $uglygep3$i$i$i$i$i93 = $uglygep$i$i$i$i$i92;
   $217 = (($uglygep3$i$i$i$i$i93>>>0) / 56)&-1;
   $218 = $217 ^ -1;
   $scevgep4$i$i$i$i$i94 = (($214) + (($218*56)|0)|0);
   HEAP32[$213>>2] = $scevgep4$i$i$i$i$i94;
  }
  HEAP32[$0>>2] = 27;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy14+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($211|0),($$byval_copy14|0));
  $219 = __THREW__; __THREW__ = 0;
  $220 = $219&1;
  if ($220) {
   $221 = ___cxa_find_matching_catch()|0;
   $222 = tempRet0;
   ___cxa_call_unexpected(($221|0));
   // unreachable;
  }
 }
 $223 = (($this) + 48|0);
 $224 = HEAP32[$223>>2]|0;
 $225 = ($224|0)==(0|0);
 if (!($225)) {
  $226 = (($this) + 52|0);
  $227 = HEAP32[$226>>2]|0;
  $228 = ($227|0)==($224|0);
  if (!($228)) {
   $__new_last2$i$i$i$i$i$i$i$i$i98 = $224;
   $scevgep$i$i$i$i$i$i$i$i$i99 = (($227) + -8|0);
   $229 = (0 - ($__new_last2$i$i$i$i$i$i$i$i$i98))|0;
   $uglygep$i$i$i$i$i$i$i$i$i101 = (($scevgep$i$i$i$i$i$i$i$i$i99) + ($229)|0);
   $uglygep3$i$i$i$i$i$i$i$i$i102 = $uglygep$i$i$i$i$i$i$i$i$i101;
   $230 = $uglygep3$i$i$i$i$i$i$i$i$i102 >>> 3;
   $231 = $230 ^ -1;
   $scevgep4$i$i$i$i$i$i$i$i$i103 = (($227) + ($231<<3)|0);
   HEAP32[$226>>2] = $scevgep4$i$i$i$i$i$i$i$i$i103;
  }
  __ZdlPv($224);
 }
 __THREW__ = 0;
 invoke_vi(3423,($this|0));
 $232 = __THREW__; __THREW__ = 0;
 $233 = $232&1;
 if ($233) {
  $234 = ___cxa_find_matching_catch(0|0)|0;
  $235 = tempRet0;
  ___clang_call_terminate($234);
  // unreachable;
 } else {
  ___resumeException($123|0);
  // unreachable;
 }
}
function __Z7FTAllocP13FT_MemoryRec_l($0,$n) {
 $0 = $0|0;
 $n = $n|0;
 var $$byval_copy = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $1 = sp;
 $2 = HEAP32[628344>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Z15malloc_internaljj10MemLabelIdiPKci($n,16,$$byval_copy,0,804968,10)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z6FTFreeP13FT_MemoryRec_Pv($0,$p) {
 $0 = $0|0;
 $p = $p|0;
 var $$byval_copy = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $1 = sp;
 $2 = HEAP32[628344>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($p,$$byval_copy);
 STACKTOP = sp;return;
}
function __Z9FTReallocP13FT_MemoryRec_llPv($0,$oldSize,$n,$p) {
 $0 = $0|0;
 $oldSize = $oldSize|0;
 $n = $n|0;
 $p = $p|0;
 var $$byval_copy = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $1 = sp;
 $2 = HEAP32[628344>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Z16realloc_internalPvji10MemLabelIdiPKci($p,$n,16,$$byval_copy,0,804968,20)|0);
 STACKTOP = sp;return ($3|0);
}
function _Unity_FT_Init_FreeType($alibrary,$MyAlloc) {
 $alibrary = $alibrary|0;
 $MyAlloc = $MyAlloc|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[628344>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(16,$$byval_copy1,0,16,804968,32)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(804976,0,804968,39,1,0,0,0);
  $$0 = 7;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$3+0>>2]=HEAP32[$MyAlloc+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$MyAlloc+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$MyAlloc+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$MyAlloc+12>>2]|0;
 $5 = (_FT_New_Library($3,$alibrary)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  $8 = HEAP32[$alibrary>>2]|0;
  _FT_Add_Default_Modules($8);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $7 = HEAP32[628344>>2]|0;
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($3,$$byval_copy1);
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _Unity_FT_Done_FreeType($library) {
 $library = $library|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = ($library|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return 0;
 }
 $2 = HEAP32[$library>>2]|0;
 (_FT_Done_Library($library)|0);
 $3 = HEAP32[628344>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($2,$$byval_copy);
 STACKTOP = sp;return 0;
}
function __ZN20TextRenderingPrivate15GetFontsManager16StaticInitializeEv() {
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = HEAP32[628344>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $4 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy2,0,16,805032,28)|0);
 HEAP32[$4>>2] = 0;
 $5 = (($4) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 8|0);
 HEAP32[$6>>2] = 0;
 HEAP32[805040>>2] = $4;
 $7 = HEAP32[628344>>2]|0;
 HEAP32[$1>>2] = $7;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $8 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy2,0,16,805032,29)|0);
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 8|0);
 HEAP32[$10>>2] = 0;
 HEAP32[$8>>2] = $9;
 HEAP32[805048>>2] = $8;
 $11 = HEAP32[628344>>2]|0;
 HEAP32[$2>>2] = $11;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
 $12 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy2,0,16,805032,30)|0);
 HEAP32[$12>>2] = 0;
 $13 = (($12) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($12) + 8|0);
 HEAP32[$14>>2] = 0;
 HEAP32[805056>>2] = $12;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate15GetFontsManager13StaticDestroyEv() {
 var $$byval_copy5 = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i$i$i$i7 = 0, $$pre$i$i$i$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = HEAP32[805040>>2]|0;
 $5 = HEAP32[628344>>2]|0;
 $6 = ($4|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$4>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   $9 = (($4) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==($7|0);
   do {
    if ($11) {
     $25 = $7;
    } else {
     $13 = $10;
     while(1) {
      $12 = (($13) + -12|0);
      HEAP32[$9>>2] = $12;
      $14 = HEAP8[$12>>0]|0;
      $15 = $14 & 1;
      $16 = ($15<<24>>24)==(0);
      if ($16) {
       $18 = $12;
      } else {
       $19 = (($13) + -4|0);
       $20 = HEAP32[$19>>2]|0;
       HEAP32[$3>>2] = 59;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
       invoke_vii(2591,($20|0),($$byval_copy5|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        label = 9;
        break;
       }
       $$pre$i$i$i$i$i$i = HEAP32[$9>>2]|0;
       $18 = $$pre$i$i$i$i$i$i;
      }
      $17 = ($18|0)==($7|0);
      if ($17) {
       label = 10;
       break;
      } else {
       $13 = $18;
      }
     }
     if ((label|0) == 9) {
      $23 = ___cxa_find_matching_catch()|0;
      $24 = tempRet0;
      ___cxa_call_unexpected(($23|0));
      // unreachable;
     }
     else if ((label|0) == 10) {
      $$pre$i$i$i$i = HEAP32[$4>>2]|0;
      $25 = $$pre$i$i$i$i;
      break;
     }
    }
   } while(0);
   __ZdlPv($25);
  }
 }
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($4,$$byval_copy5);
 HEAP32[805040>>2] = 0;
 $26 = HEAP32[805048>>2]|0;
 $27 = HEAP32[628344>>2]|0;
 $28 = ($26|0)==(0|0);
 if (!($28)) {
  $29 = (($26) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_3mapIiN20TextRenderingPrivate13UnityFontInfoENS_4lessIiEENS5_INS_4pairIKiSA_EEEEEEEENS_19__map_value_compareIS7_SI_NSB_IS7_EELb1EEENS5_ISI_EEE7destroyEPNS_11__tree_nodeISI_PvEE($26,$30);
 }
 HEAP32[$0>>2] = $27;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($26,$$byval_copy5);
 HEAP32[805048>>2] = 0;
 $31 = HEAP32[805056>>2]|0;
 $32 = HEAP32[628344>>2]|0;
 $33 = ($31|0)==(0|0);
 if ($33) {
  HEAP32[$2>>2] = $32;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy5);
  HEAP32[805056>>2] = 0;
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$31>>2]|0;
 $35 = ($34|0)==(0|0);
 if ($35) {
  HEAP32[$2>>2] = $32;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy5);
  HEAP32[805056>>2] = 0;
  STACKTOP = sp;return;
 }
 $36 = (($31) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==($34|0);
 do {
  if ($38) {
   $52 = $34;
  } else {
   $40 = $37;
   while(1) {
    $39 = (($40) + -12|0);
    HEAP32[$36>>2] = $39;
    $41 = HEAP8[$39>>0]|0;
    $42 = $41 & 1;
    $43 = ($42<<24>>24)==(0);
    if ($43) {
     $45 = $39;
    } else {
     $46 = (($40) + -4|0);
     $47 = HEAP32[$46>>2]|0;
     HEAP32[$0>>2] = 59;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($47|0),($$byval_copy5|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      label = 22;
      break;
     }
     $$pre$i$i$i$i$i$i7 = HEAP32[$36>>2]|0;
     $45 = $$pre$i$i$i$i$i$i7;
    }
    $44 = ($45|0)==($34|0);
    if ($44) {
     label = 23;
     break;
    } else {
     $40 = $45;
    }
   }
   if ((label|0) == 22) {
    $50 = ___cxa_find_matching_catch()|0;
    $51 = tempRet0;
    ___cxa_call_unexpected(($50|0));
    // unreachable;
   }
   else if ((label|0) == 23) {
    $$pre$i$i$i$i8 = HEAP32[$31>>2]|0;
    $52 = $$pre$i$i$i$i8;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = 27;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(2591,($52|0),($$byval_copy5|0));
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 if ($54) {
  $55 = ___cxa_find_matching_catch()|0;
  $56 = tempRet0;
  ___cxa_call_unexpected(($55|0));
  // unreachable;
 } else {
  HEAP32[$2>>2] = $32;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($31,$$byval_copy5);
  HEAP32[805056>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate12GetFallbacksEv() {
 var $$0 = 0, $$01 = 0, $$byval_copy19 = 0, $$pre = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i29 = 0, $$pre$i45 = 0, $$pre$i61 = 0, $$pre$i77 = 0, $$pre$i93 = 0, $$pre107 = 0, $$pre109 = 0, $$pre111 = 0, $$pre112 = 0, $$pre113 = 0, $$pre114 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $phitmp = 0;
 var $phitmp120 = 0, $phitmp121 = 0, $phitmp122 = 0, $phitmp123 = 0, $phitmp124 = 0, $phitmp125 = 0, $phitmp126 = 0, $phitmp127 = 0, $phitmp128 = 0, $phitmp129 = 0, $phitmp130 = 0, $phitmp131 = 0, $phitmp132 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy19 = sp + 148|0;
 $0 = sp + 144|0;
 $1 = sp + 140|0;
 $2 = sp + 136|0;
 $3 = sp + 132|0;
 $4 = sp + 128|0;
 $5 = sp + 124|0;
 $6 = sp + 120|0;
 $7 = sp + 116|0;
 $8 = sp + 112|0;
 $9 = sp + 108|0;
 $10 = sp + 104|0;
 $11 = sp + 100|0;
 $12 = sp + 24|0;
 $13 = sp;
 $14 = sp + 4|0;
 $15 = sp + 8|0;
 $16 = sp + 12|0;
 $17 = sp + 28|0;
 $18 = sp + 40|0;
 $19 = sp + 52|0;
 $20 = sp + 64|0;
 $21 = sp + 76|0;
 $22 = sp + 88|0;
 $23 = HEAP32[805056>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($23) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($24|0)==($26|0);
 if (!($27)) {
  $261 = HEAP32[805056>>2]|0;
  STACKTOP = sp;return ($261|0);
 }
 HEAP8[$16>>0] = 10;
 $28 = (($16) + 1|0);
 ;HEAP8[$28+0>>0]=HEAP8[805064+0>>0]|0;HEAP8[$28+1>>0]=HEAP8[805064+1>>0]|0;HEAP8[$28+2>>0]=HEAP8[805064+2>>0]|0;HEAP8[$28+3>>0]=HEAP8[805064+3>>0]|0;HEAP8[$28+4>>0]=HEAP8[805064+4>>0]|0;
 $29 = (($16) + 6|0);
 HEAP8[$29>>0] = 0;
 $30 = (($23) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($24|0)==($31|0);
 do {
  if ($32) {
   __THREW__ = 0;
   invoke_vii(3433,($23|0),($16|0));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    $$pre = HEAP8[$16>>0]|0;
    $phitmp = $$pre & 1;
    $phitmp120 = ($phitmp<<24>>24)==(0);
    if ($phitmp120) {
     break;
    }
    $40 = (($16) + 8|0);
    $41 = HEAP32[$40>>2]|0;
    HEAP32[$14>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$14+0>>2]|0;
    invoke_vii(2591,($41|0),($$byval_copy19|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     break;
    }
    $44 = ___cxa_find_matching_catch()|0;
    $45 = tempRet0;
    ___cxa_call_unexpected(($44|0));
    // unreachable;
   }
   $187 = ___cxa_find_matching_catch()|0;
   $188 = tempRet0;
   $189 = HEAP8[$16>>0]|0;
   $190 = $189 & 1;
   $191 = ($190<<24>>24)==(0);
   if ($191) {
    $$0 = $188;$$01 = $187;
    ___resumeException($$01|0);
    // unreachable;
   }
   $192 = (($16) + 8|0);
   $193 = HEAP32[$192>>2]|0;
   HEAP32[$5>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_vii(2591,($193|0),($$byval_copy19|0));
   $194 = __THREW__; __THREW__ = 0;
   $195 = $194&1;
   if ($195) {
    $196 = ___cxa_find_matching_catch()|0;
    $197 = tempRet0;
    ___cxa_call_unexpected(($196|0));
    // unreachable;
   } else {
    $$0 = $188;$$01 = $187;
    ___resumeException($$01|0);
    // unreachable;
   }
  } else {
   $33 = ($24|0)==(0|0);
   if ($33) {
    $37 = 0;
   } else {
    HEAP8[$24>>0] = 10;
    $34 = (($24) + 1|0);
    ;HEAP8[$34+0>>0]=HEAP8[$28+0>>0]|0;HEAP8[$34+1>>0]=HEAP8[$28+1>>0]|0;HEAP8[$34+2>>0]=HEAP8[$28+2>>0]|0;HEAP8[$34+3>>0]=HEAP8[$28+3>>0]|0;HEAP8[$34+4>>0]=HEAP8[$28+4>>0]|0;
    $35 = (($24) + 6|0);
    HEAP8[$35>>0] = 0;
    $$pre$i = HEAP32[$25>>2]|0;
    $37 = $$pre$i;
   }
   $36 = (($37) + 12|0);
   HEAP32[$25>>2] = $36;
  }
 } while(0);
 $46 = HEAP32[805056>>2]|0;
 HEAP32[$0>>2] = 59;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
 $47 = (__Z15malloc_internaljj10MemLabelIdiPKci(32,16,$$byval_copy19,0,805032,79)|0);
 $48 = (($17) + 8|0);
 HEAP32[$48>>2] = $47;
 HEAP32[$17>>2] = 33;
 $49 = (($17) + 4|0);
 HEAP32[$49>>2] = 16;
 dest=$47+0|0; src=805072+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $50 = (($47) + 16|0);
 HEAP8[$50>>0] = 0;
 $51 = (($46) + 4|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($46) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($52|0)==($54|0);
 do {
  if ($55) {
   __THREW__ = 0;
   invoke_vii(3433,($46|0),($17|0));
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if ($66) {
    label = 64;
   } else {
    $$pre107 = HEAP8[$17>>0]|0;
    $phitmp121 = $$pre107 & 1;
    $phitmp122 = ($phitmp121<<24>>24)==(0);
    if (!($phitmp122)) {
     label = 17;
    }
   }
  } else {
   $56 = ($52|0)==(0|0);
   if ($56) {
    $64 = 0;
   } else {
    HEAP32[$13>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$13+0>>2]|0;
    $57 = (invoke_iiiiiii(102,32,16,($$byval_copy19|0),0,(805032|0),79)|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 64;
     break;
    }
    $60 = (($52) + 8|0);
    HEAP32[$60>>2] = $57;
    HEAP32[$52>>2] = 33;
    $61 = (($52) + 4|0);
    HEAP32[$61>>2] = 16;
    dest=$57+0|0; src=$47+0|0; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $62 = (($57) + 16|0);
    HEAP8[$62>>0] = 0;
    $$pre$i13 = HEAP32[$51>>2]|0;
    $64 = $$pre$i13;
   }
   $63 = (($64) + 12|0);
   HEAP32[$51>>2] = $63;
   label = 17;
  }
 } while(0);
 if ((label|0) == 17) {
  $67 = HEAP32[$48>>2]|0;
  HEAP32[$12>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$12+0>>2]|0;
  invoke_vii(2591,($67|0),($$byval_copy19|0));
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   $70 = ___cxa_find_matching_catch()|0;
   $71 = tempRet0;
   ___cxa_call_unexpected(($70|0));
   // unreachable;
  }
 }
 else if ((label|0) == 64) {
  $198 = ___cxa_find_matching_catch()|0;
  $199 = tempRet0;
  $200 = HEAP8[$17>>0]|0;
  $201 = $200 & 1;
  $202 = ($201<<24>>24)==(0);
  if ($202) {
   $$0 = $199;$$01 = $198;
   ___resumeException($$01|0);
   // unreachable;
  }
  $203 = HEAP32[$48>>2]|0;
  HEAP32[$4>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($203|0),($$byval_copy19|0));
  $204 = __THREW__; __THREW__ = 0;
  $205 = $204&1;
  if ($205) {
   $206 = ___cxa_find_matching_catch()|0;
   $207 = tempRet0;
   ___cxa_call_unexpected(($206|0));
   // unreachable;
  } else {
   $$0 = $199;$$01 = $198;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $72 = HEAP32[805056>>2]|0;
 HEAP32[$0>>2] = 59;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
 $73 = (__Z15malloc_internaljj10MemLabelIdiPKci(32,16,$$byval_copy19,0,805032,79)|0);
 $74 = (($18) + 8|0);
 HEAP32[$74>>2] = $73;
 HEAP32[$18>>2] = 33;
 $75 = (($18) + 4|0);
 HEAP32[$75>>2] = 20;
 dest=$73+0|0; src=805096+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $76 = (($73) + 20|0);
 HEAP8[$76>>0] = 0;
 $77 = (($72) + 4|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($72) + 8|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($78|0)==($80|0);
 do {
  if ($81) {
   __THREW__ = 0;
   invoke_vii(3433,($72|0),($18|0));
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   if ($92) {
    label = 67;
   } else {
    $$pre109 = HEAP8[$18>>0]|0;
    $phitmp123 = $$pre109 & 1;
    $phitmp124 = ($phitmp123<<24>>24)==(0);
    if (!($phitmp124)) {
     label = 26;
    }
   }
  } else {
   $82 = ($78|0)==(0|0);
   if ($82) {
    $90 = 0;
   } else {
    HEAP32[$11>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$11+0>>2]|0;
    $83 = (invoke_iiiiiii(102,32,16,($$byval_copy19|0),0,(805032|0),79)|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     label = 67;
     break;
    }
    $86 = (($78) + 8|0);
    HEAP32[$86>>2] = $83;
    HEAP32[$78>>2] = 33;
    $87 = (($78) + 4|0);
    HEAP32[$87>>2] = 20;
    dest=$83+0|0; src=$73+0|0; stop=dest+20|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $88 = (($83) + 20|0);
    HEAP8[$88>>0] = 0;
    $$pre$i29 = HEAP32[$77>>2]|0;
    $90 = $$pre$i29;
   }
   $89 = (($90) + 12|0);
   HEAP32[$77>>2] = $89;
   label = 26;
  }
 } while(0);
 if ((label|0) == 26) {
  $93 = HEAP32[$74>>2]|0;
  HEAP32[$10>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$10+0>>2]|0;
  invoke_vii(2591,($93|0),($$byval_copy19|0));
  $94 = __THREW__; __THREW__ = 0;
  $95 = $94&1;
  if ($95) {
   $96 = ___cxa_find_matching_catch()|0;
   $97 = tempRet0;
   ___cxa_call_unexpected(($96|0));
   // unreachable;
  }
 }
 else if ((label|0) == 67) {
  $208 = ___cxa_find_matching_catch()|0;
  $209 = tempRet0;
  $210 = HEAP8[$18>>0]|0;
  $211 = $210 & 1;
  $212 = ($211<<24>>24)==(0);
  if ($212) {
   $$0 = $209;$$01 = $208;
   ___resumeException($$01|0);
   // unreachable;
  }
  $213 = HEAP32[$74>>2]|0;
  HEAP32[$3>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($213|0),($$byval_copy19|0));
  $214 = __THREW__; __THREW__ = 0;
  $215 = $214&1;
  if ($215) {
   $216 = ___cxa_find_matching_catch()|0;
   $217 = tempRet0;
   ___cxa_call_unexpected(($216|0));
   // unreachable;
  } else {
   $$0 = $209;$$01 = $208;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $98 = HEAP32[805056>>2]|0;
 HEAP32[$0>>2] = 59;
 ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
 $99 = (__Z15malloc_internaljj10MemLabelIdiPKci(16,16,$$byval_copy19,0,805032,79)|0);
 $100 = (($19) + 8|0);
 HEAP32[$100>>2] = $99;
 HEAP32[$19>>2] = 17;
 $101 = (($19) + 4|0);
 HEAP32[$101>>2] = 15;
 dest=$99+0|0; src=805120+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $102 = (($99) + 15|0);
 HEAP8[$102>>0] = 0;
 $103 = (($98) + 4|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($98) + 8|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($104|0)==($106|0);
 do {
  if ($107) {
   __THREW__ = 0;
   invoke_vii(3433,($98|0),($19|0));
   $117 = __THREW__; __THREW__ = 0;
   $118 = $117&1;
   if ($118) {
    label = 70;
   } else {
    $$pre111 = HEAP8[$19>>0]|0;
    $phitmp125 = $$pre111 & 1;
    $phitmp126 = ($phitmp125<<24>>24)==(0);
    if (!($phitmp126)) {
     label = 35;
    }
   }
  } else {
   $108 = ($104|0)==(0|0);
   if ($108) {
    $116 = 0;
   } else {
    HEAP32[$9>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$9+0>>2]|0;
    $109 = (invoke_iiiiiii(102,16,16,($$byval_copy19|0),0,(805032|0),79)|0);
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if ($111) {
     label = 70;
     break;
    }
    $112 = (($104) + 8|0);
    HEAP32[$112>>2] = $109;
    HEAP32[$104>>2] = 17;
    $113 = (($104) + 4|0);
    HEAP32[$113>>2] = 15;
    dest=$109+0|0; src=$99+0|0; stop=dest+15|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $114 = (($109) + 15|0);
    HEAP8[$114>>0] = 0;
    $$pre$i45 = HEAP32[$103>>2]|0;
    $116 = $$pre$i45;
   }
   $115 = (($116) + 12|0);
   HEAP32[$103>>2] = $115;
   label = 35;
  }
 } while(0);
 if ((label|0) == 35) {
  $119 = HEAP32[$100>>2]|0;
  HEAP32[$8>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$8+0>>2]|0;
  invoke_vii(2591,($119|0),($$byval_copy19|0));
  $120 = __THREW__; __THREW__ = 0;
  $121 = $120&1;
  if ($121) {
   $122 = ___cxa_find_matching_catch()|0;
   $123 = tempRet0;
   ___cxa_call_unexpected(($122|0));
   // unreachable;
  }
 }
 else if ((label|0) == 70) {
  $218 = ___cxa_find_matching_catch()|0;
  $219 = tempRet0;
  $220 = HEAP8[$19>>0]|0;
  $221 = $220 & 1;
  $222 = ($221<<24>>24)==(0);
  if ($222) {
   $$0 = $219;$$01 = $218;
   ___resumeException($$01|0);
   // unreachable;
  }
  $223 = HEAP32[$100>>2]|0;
  HEAP32[$2>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($223|0),($$byval_copy19|0));
  $224 = __THREW__; __THREW__ = 0;
  $225 = $224&1;
  if ($225) {
   $226 = ___cxa_find_matching_catch()|0;
   $227 = tempRet0;
   ___cxa_call_unexpected(($226|0));
   // unreachable;
  } else {
   $$0 = $219;$$01 = $218;
   ___resumeException($$01|0);
   // unreachable;
  }
 }
 $124 = HEAP32[805056>>2]|0;
 HEAP8[$20>>0] = 10;
 $125 = (($20) + 1|0);
 ;HEAP8[$125+0>>0]=HEAP8[805136+0>>0]|0;HEAP8[$125+1>>0]=HEAP8[805136+1>>0]|0;HEAP8[$125+2>>0]=HEAP8[805136+2>>0]|0;HEAP8[$125+3>>0]=HEAP8[805136+3>>0]|0;HEAP8[$125+4>>0]=HEAP8[805136+4>>0]|0;
 $126 = (($20) + 6|0);
 HEAP8[$126>>0] = 0;
 $127 = (($124) + 4|0);
 $128 = HEAP32[$127>>2]|0;
 $129 = (($124) + 8|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($128|0)==($130|0);
 do {
  if ($131) {
   __THREW__ = 0;
   invoke_vii(3433,($124|0),($20|0));
   $137 = __THREW__; __THREW__ = 0;
   $138 = $137&1;
   if (!($138)) {
    $$pre112 = HEAP8[$20>>0]|0;
    $phitmp127 = $$pre112 & 1;
    $phitmp128 = ($phitmp127<<24>>24)==(0);
    if ($phitmp128) {
     break;
    }
    $139 = (($20) + 8|0);
    $140 = HEAP32[$139>>2]|0;
    HEAP32[$7>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$7+0>>2]|0;
    invoke_vii(2591,($140|0),($$byval_copy19|0));
    $141 = __THREW__; __THREW__ = 0;
    $142 = $141&1;
    if (!($142)) {
     break;
    }
    $143 = ___cxa_find_matching_catch()|0;
    $144 = tempRet0;
    ___cxa_call_unexpected(($143|0));
    // unreachable;
   }
   $228 = ___cxa_find_matching_catch()|0;
   $229 = tempRet0;
   $230 = HEAP8[$20>>0]|0;
   $231 = $230 & 1;
   $232 = ($231<<24>>24)==(0);
   if ($232) {
    $$0 = $229;$$01 = $228;
    ___resumeException($$01|0);
    // unreachable;
   }
   $233 = (($20) + 8|0);
   $234 = HEAP32[$233>>2]|0;
   HEAP32[$1>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($234|0),($$byval_copy19|0));
   $235 = __THREW__; __THREW__ = 0;
   $236 = $235&1;
   if ($236) {
    $237 = ___cxa_find_matching_catch()|0;
    $238 = tempRet0;
    ___cxa_call_unexpected(($237|0));
    // unreachable;
   } else {
    $$0 = $229;$$01 = $228;
    ___resumeException($$01|0);
    // unreachable;
   }
  } else {
   $132 = ($128|0)==(0|0);
   if ($132) {
    $136 = 0;
   } else {
    HEAP8[$128>>0] = 10;
    $133 = (($128) + 1|0);
    ;HEAP8[$133+0>>0]=HEAP8[$125+0>>0]|0;HEAP8[$133+1>>0]=HEAP8[$125+1>>0]|0;HEAP8[$133+2>>0]=HEAP8[$125+2>>0]|0;HEAP8[$133+3>>0]=HEAP8[$125+3>>0]|0;HEAP8[$133+4>>0]=HEAP8[$125+4>>0]|0;
    $134 = (($128) + 6|0);
    HEAP8[$134>>0] = 0;
    $$pre$i61 = HEAP32[$127>>2]|0;
    $136 = $$pre$i61;
   }
   $135 = (($136) + 12|0);
   HEAP32[$127>>2] = $135;
  }
 } while(0);
 $145 = HEAP32[805056>>2]|0;
 HEAP8[$21>>0] = 18;
 $146 = (($21) + 1|0);
 dest=$146+0|0; src=805144+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $147 = (($21) + 10|0);
 HEAP8[$147>>0] = 0;
 $148 = (($145) + 4|0);
 $149 = HEAP32[$148>>2]|0;
 $150 = (($145) + 8|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = ($149|0)==($151|0);
 do {
  if ($152) {
   __THREW__ = 0;
   invoke_vii(3433,($145|0),($21|0));
   $158 = __THREW__; __THREW__ = 0;
   $159 = $158&1;
   if (!($159)) {
    $$pre113 = HEAP8[$21>>0]|0;
    $phitmp129 = $$pre113 & 1;
    $phitmp130 = ($phitmp129<<24>>24)==(0);
    if ($phitmp130) {
     break;
    }
    $160 = (($21) + 8|0);
    $161 = HEAP32[$160>>2]|0;
    HEAP32[$6>>2] = 59;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$6+0>>2]|0;
    invoke_vii(2591,($161|0),($$byval_copy19|0));
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if (!($163)) {
     break;
    }
    $164 = ___cxa_find_matching_catch()|0;
    $165 = tempRet0;
    ___cxa_call_unexpected(($164|0));
    // unreachable;
   }
   $239 = ___cxa_find_matching_catch()|0;
   $240 = tempRet0;
   $241 = HEAP8[$21>>0]|0;
   $242 = $241 & 1;
   $243 = ($242<<24>>24)==(0);
   if ($243) {
    $$0 = $240;$$01 = $239;
    ___resumeException($$01|0);
    // unreachable;
   }
   $244 = (($21) + 8|0);
   $245 = HEAP32[$244>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($245|0),($$byval_copy19|0));
   $246 = __THREW__; __THREW__ = 0;
   $247 = $246&1;
   if ($247) {
    $248 = ___cxa_find_matching_catch()|0;
    $249 = tempRet0;
    ___cxa_call_unexpected(($248|0));
    // unreachable;
   } else {
    $$0 = $240;$$01 = $239;
    ___resumeException($$01|0);
    // unreachable;
   }
  } else {
   $153 = ($149|0)==(0|0);
   if ($153) {
    $157 = 0;
   } else {
    HEAP8[$149>>0] = 18;
    $154 = (($149) + 1|0);
    dest=$154+0|0; src=$146+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $155 = (($149) + 10|0);
    HEAP8[$155>>0] = 0;
    $$pre$i77 = HEAP32[$148>>2]|0;
    $157 = $$pre$i77;
   }
   $156 = (($157) + 12|0);
   HEAP32[$148>>2] = $156;
  }
 } while(0);
 $166 = HEAP32[805056>>2]|0;
 HEAP8[$22>>0] = 20;
 $167 = (($22) + 1|0);
 dest=$167+0|0; src=805160+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $168 = (($22) + 11|0);
 HEAP8[$168>>0] = 0;
 $169 = (($166) + 4|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = (($166) + 8|0);
 $172 = HEAP32[$171>>2]|0;
 $173 = ($170|0)==($172|0);
 if (!($173)) {
  $174 = ($170|0)==(0|0);
  if ($174) {
   $178 = 0;
  } else {
   HEAP8[$170>>0] = 20;
   $175 = (($170) + 1|0);
   dest=$175+0|0; src=$167+0|0; stop=dest+10|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
   $176 = (($170) + 11|0);
   HEAP8[$176>>0] = 0;
   $$pre$i93 = HEAP32[$169>>2]|0;
   $178 = $$pre$i93;
  }
  $177 = (($178) + 12|0);
  HEAP32[$169>>2] = $177;
  $261 = HEAP32[805056>>2]|0;
  STACKTOP = sp;return ($261|0);
 }
 __THREW__ = 0;
 invoke_vii(3433,($166|0),($22|0));
 $179 = __THREW__; __THREW__ = 0;
 $180 = $179&1;
 if ($180) {
  $250 = ___cxa_find_matching_catch()|0;
  $251 = tempRet0;
  $252 = HEAP8[$22>>0]|0;
  $253 = $252 & 1;
  $254 = ($253<<24>>24)==(0);
  if ($254) {
   $$0 = $251;$$01 = $250;
   ___resumeException($$01|0);
   // unreachable;
  }
  $255 = (($22) + 8|0);
  $256 = HEAP32[$255>>2]|0;
  HEAP32[$15>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$15+0>>2]|0;
  invoke_vii(2591,($256|0),($$byval_copy19|0));
  $257 = __THREW__; __THREW__ = 0;
  $258 = $257&1;
  if ($258) {
   $259 = ___cxa_find_matching_catch()|0;
   $260 = tempRet0;
   ___cxa_call_unexpected(($259|0));
   // unreachable;
  } else {
   $$0 = $251;$$01 = $250;
   ___resumeException($$01|0);
   // unreachable;
  }
 } else {
  $$pre114 = HEAP8[$22>>0]|0;
  $phitmp131 = $$pre114 & 1;
  $phitmp132 = ($phitmp131<<24>>24)==(0);
  if ($phitmp132) {
   $261 = HEAP32[805056>>2]|0;
   STACKTOP = sp;return ($261|0);
  }
  $181 = (($22) + 8|0);
  $182 = HEAP32[$181>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($182|0),($$byval_copy19|0));
  $183 = __THREW__; __THREW__ = 0;
  $184 = $183&1;
  if ($184) {
   $185 = ___cxa_find_matching_catch()|0;
   $186 = tempRet0;
   ___cxa_call_unexpected(($185|0));
   // unreachable;
  } else {
   $261 = HEAP32[805056>>2]|0;
   STACKTOP = sp;return ($261|0);
  }
 }
 return 0|0;
}
function __ZN20TextRenderingPrivate12GetFontPathsERNSt3__16vectorINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS5_IS7_EEEE($paths) {
 $paths = $paths|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$01 = 0, $$01$i$i$i = 0, $$39 = 0, $$40 = 0, $$41 = 0, $$42 = 0, $$byval_copy = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre35 = 0, $$pre37 = 0, $$pre5$i = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $dirPaths = 0, $extension = 0, $i$033 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $lpad$phi21$index = 0;
 var $lpad$phi21$index9 = 0, $v$off$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 40|0;
 $0 = sp;
 $dirPaths = sp + 4|0;
 $1 = sp + 16|0;
 $extension = sp + 28|0;
 $2 = HEAP32[$paths>>2]|0;
 $3 = (($paths) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($2|0);
 if (!($5)) {
  $7 = $4;
  while(1) {
   $6 = (($7) + -12|0);
   HEAP32[$3>>2] = $6;
   $8 = HEAP8[$6>>0]|0;
   $9 = $8 & 1;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    $12 = $6;
   } else {
    $13 = (($7) + -4|0);
    $14 = HEAP32[$13>>2]|0;
    __ZdlPv($14);
    $$pre$i$i$i = HEAP32[$3>>2]|0;
    $12 = $$pre$i$i$i;
   }
   $11 = ($12|0)==($2|0);
   if ($11) {
    break;
   } else {
    $7 = $12;
   }
  }
 }
 $15 = HEAP32[805040>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($15) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==($16|0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $21 = $18;
 while(1) {
  $20 = (($21) + -12|0);
  HEAP32[$17>>2] = $20;
  $22 = HEAP8[$20>>0]|0;
  $23 = $22 & 1;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   $26 = $20;
  } else {
   $37 = (($21) + -4|0);
   $38 = HEAP32[$37>>2]|0;
   HEAP32[$0>>2] = 59;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($38|0),($$byval_copy|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    label = 13;
    break;
   }
   $$pre$i$i$i3 = HEAP32[$17>>2]|0;
   $26 = $$pre$i$i$i3;
  }
  $25 = ($26|0)==($16|0);
  if ($25) {
   break;
  } else {
   $21 = $26;
  }
 }
 if ((label|0) == 13) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  ___cxa_call_unexpected(($41|0));
  // unreachable;
 }
 $$pre = HEAP32[805040>>2]|0;
 $$phi$trans$insert = (($$pre) + 4|0);
 $$pre35 = HEAP32[$$phi$trans$insert>>2]|0;
 $$pre37 = HEAP32[$$pre>>2]|0;
 $27 = ($$pre35|0)==($$pre37|0);
 if ($27) {
  STACKTOP = sp;return;
 }
 $28 = (($dirPaths) + 4|0);
 $29 = (($dirPaths) + 8|0);
 $30 = (($dirPaths) + 4|0);
 $31 = (($1) + 1|0);
 $32 = (($extension) + 1|0);
 $$pre5$i = (($extension) + 8|0);
 $33 = (($extension) + 4|0);
 $34 = (($paths) + 8|0);
 $35 = (($1) + 8|0);
 $36 = (($1) + 4|0);
 $44 = $$pre;$i$033 = 0;
 L23: while(1) {
  HEAP32[$28>>2] = 0;
  HEAP32[$29>>2] = 0;
  HEAP32[$dirPaths>>2] = $30;
  $43 = HEAP32[$44>>2]|0;
  $45 = (($43) + (($i$033*12)|0)|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46 & 1;
  $48 = ($47<<24>>24)==(0);
  if ($48) {
   $49 = (($45) + 1|0);
   $50 = $46&255;
   $51 = $50 >>> 1;
   $60 = $51;$69 = $49;
  } else {
   $52 = ((($43) + (($i$033*12)|0)|0) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ((($43) + (($i$033*12)|0)|0) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($55>>>0)>(4294967279);
   if ($56) {
    label = 17;
    break;
   } else {
    $60 = $55;$69 = $53;
   }
  }
  $59 = ($60>>>0)<(11);
  if ($59) {
   $61 = $60 << 1;
   $62 = $61&255;
   HEAP8[$1>>0] = $62;
   $__p$0$i$i$i$i = $31;
  } else {
   $63 = (($60) + 16)|0;
   $64 = $63 & -16;
   __THREW__ = 0;
   $65 = (invoke_ii(2988,($64|0))|0);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 60;
    break;
   }
   HEAP32[$35>>2] = $65;
   $68 = $64 | 1;
   HEAP32[$1>>2] = $68;
   HEAP32[$36>>2] = $60;
   $__p$0$i$i$i$i = $65;
  }
  _memcpy(($__p$0$i$i$i$i|0),($69|0),($60|0))|0;
  $70 = (($__p$0$i$i$i$i) + ($60)|0);
  HEAP8[$70>>0] = 0;
  __THREW__ = 0;
  $71 = (invoke_iii(2417,($1|0),($dirPaths|0))|0);
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   label = 63;
   break;
  }
  $74 = HEAP8[$1>>0]|0;
  $75 = $74 & 1;
  $76 = ($75<<24>>24)==(0);
  if (!($76)) {
   $77 = HEAP32[$35>>2]|0;
   __ZdlPv($77);
  }
  if ($71) {
   $78 = HEAP32[$dirPaths>>2]|0;
   $79 = ($78|0)==($30|0);
   if (!($79)) {
    $81 = $78;
    while(1) {
     $80 = (($81) + 16|0);
     __THREW__ = 0;
     invoke_vii(2752,($extension|0),($80|0));
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      label = 59;
      break L23;
     }
     $84 = HEAP8[$extension>>0]|0;
     $85 = $84 & 1;
     $86 = ($85<<24>>24)==(0);
     $87 = HEAP32[$$pre5$i>>2]|0;
     $$ = $86 ? $32 : $87;
     $89 = $84;$99 = $$;
     while(1) {
      $88 = $89 & 1;
      $90 = ($88<<24>>24)==(0);
      if ($90) {
       $93 = $89&255;
       $94 = $93 >>> 1;
       $96 = $32;$97 = $94;
      } else {
       $91 = HEAP32[$$pre5$i>>2]|0;
       $92 = HEAP32[$33>>2]|0;
       $96 = $91;$97 = $92;
      }
      $95 = (($96) + ($97)|0);
      $98 = ($99|0)==($95|0);
      if ($98) {
       break;
      }
      $100 = HEAP8[$99>>0]|0;
      $v$off$i$i = (($100) + -65)<<24>>24;
      $101 = ($v$off$i$i&255)<(26);
      if ($101) {
       $102 = $100&255;
       $103 = $102 | 32;
       $104 = $103&255;
       $$0$i$i = $104;
      } else {
       $$0$i$i = $100;
      }
      HEAP8[$99>>0] = $$0$i$i;
      $105 = (($99) + 1|0);
      $$pre$i = HEAP8[$extension>>0]|0;
      $89 = $$pre$i;$99 = $105;
     }
     $106 = HEAP32[$$pre5$i>>2]|0;
     $$39 = $90 ? $32 : $106;
     __THREW__ = 0;
     $107 = (invoke_iii(2609,($$39|0),(805176|0))|0);
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if ($109) {
      label = 65;
      break L23;
     }
     $110 = ($107|0)==(0);
     if ($110) {
      label = 45;
     } else {
      $111 = HEAP8[$extension>>0]|0;
      $112 = $111 & 1;
      $113 = ($112<<24>>24)==(0);
      $114 = HEAP32[$$pre5$i>>2]|0;
      $$40 = $113 ? $32 : $114;
      __THREW__ = 0;
      $115 = (invoke_iii(2609,($$40|0),(805184|0))|0);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       label = 65;
       break L23;
      }
      $118 = ($115|0)==(0);
      if ($118) {
       label = 45;
      } else {
       $119 = HEAP8[$extension>>0]|0;
       $120 = $119 & 1;
       $121 = ($120<<24>>24)==(0);
       $122 = HEAP32[$$pre5$i>>2]|0;
       $$41 = $121 ? $32 : $122;
       __THREW__ = 0;
       $123 = (invoke_iii(2609,($$41|0),(805192|0))|0);
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       if ($125) {
        label = 65;
        break L23;
       }
       $126 = ($123|0)==(0);
       if ($126) {
        label = 45;
       } else {
        $127 = HEAP8[$extension>>0]|0;
        $128 = $127 & 1;
        $129 = ($128<<24>>24)==(0);
        $130 = HEAP32[$$pre5$i>>2]|0;
        $$42 = $129 ? $32 : $130;
        __THREW__ = 0;
        $131 = (invoke_iii(2609,($$42|0),(805200|0))|0);
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if ($133) {
         label = 65;
         break L23;
        }
        $134 = ($131|0)==(0);
        if ($134) {
         label = 45;
        }
       }
      }
     }
     do {
      if ((label|0) == 45) {
       label = 0;
       $135 = HEAP32[$3>>2]|0;
       $136 = HEAP32[$34>>2]|0;
       $137 = ($135|0)==($136|0);
       if ($137) {
        __THREW__ = 0;
        invoke_vii(2523,($paths|0),($80|0));
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if ($165) {
         label = 65;
         break L23;
        } else {
         break;
        }
       }
       $138 = ($135|0)==(0|0);
       do {
        if (!($138)) {
         $139 = HEAP8[$80>>0]|0;
         $140 = $139 & 1;
         $141 = ($140<<24>>24)==(0);
         if ($141) {
          ;HEAP32[$135+0>>2]=HEAP32[$80+0>>2]|0;HEAP32[$135+4>>2]=HEAP32[$80+4>>2]|0;HEAP32[$135+8>>2]=HEAP32[$80+8>>2]|0;
          break;
         }
         $142 = (($81) + 24|0);
         $143 = HEAP32[$142>>2]|0;
         $144 = (($81) + 20|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = ($145>>>0)>(4294967279);
         if ($146) {
          label = 50;
          break L23;
         }
         $149 = ($145>>>0)<(11);
         if ($149) {
          $150 = $145 << 1;
          $151 = $150&255;
          HEAP8[$135>>0] = $151;
          $152 = (($135) + 1|0);
          $__p$0$i$i$i$i$i = $152;
         } else {
          $153 = (($145) + 16)|0;
          $154 = $153 & -16;
          __THREW__ = 0;
          $155 = (invoke_ii(2988,($154|0))|0);
          $156 = __THREW__; __THREW__ = 0;
          $157 = $156&1;
          if ($157) {
           label = 65;
           break L23;
          }
          $158 = (($135) + 8|0);
          HEAP32[$158>>2] = $155;
          $159 = $154 | 1;
          HEAP32[$135>>2] = $159;
          $160 = (($135) + 4|0);
          HEAP32[$160>>2] = $145;
          $__p$0$i$i$i$i$i = $155;
         }
         _memcpy(($__p$0$i$i$i$i$i|0),($143|0),($145|0))|0;
         $161 = (($__p$0$i$i$i$i$i) + ($145)|0);
         HEAP8[$161>>0] = 0;
        }
       } while(0);
       $162 = HEAP32[$3>>2]|0;
       $163 = (($162) + 12|0);
       HEAP32[$3>>2] = $163;
      }
     } while(0);
     $186 = HEAP8[$extension>>0]|0;
     $187 = $186 & 1;
     $188 = ($187<<24>>24)==(0);
     if (!($188)) {
      $189 = HEAP32[$$pre5$i>>2]|0;
      __ZdlPv($189);
     }
     $190 = (($81) + 4|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = ($191|0)==(0|0);
     if ($192) {
      $$01$i$i$i = $81;
      while(1) {
       $195 = (($$01$i$i$i) + 8|0);
       $196 = HEAP32[$195>>2]|0;
       $197 = HEAP32[$196>>2]|0;
       $198 = ($197|0)==($$01$i$i$i|0);
       if ($198) {
        $$0$i$i$i = $196;
        break;
       } else {
        $$01$i$i$i = $196;
       }
      }
     } else {
      $$0$i$i$i$i = $191;
      while(1) {
       $193 = HEAP32[$$0$i$i$i$i>>2]|0;
       $194 = ($193|0)==(0|0);
       if ($194) {
        $$0$i$i$i = $$0$i$i$i$i;
        break;
       } else {
        $$0$i$i$i$i = $193;
       }
      }
     }
     $199 = ($$0$i$i$i|0)==($30|0);
     if ($199) {
      break;
     } else {
      $81 = $$0$i$i$i;
     }
    }
   }
  }
  $200 = HEAP32[$28>>2]|0;
  __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($dirPaths,$200);
  $201 = (($i$033) + 1)|0;
  $202 = HEAP32[805040>>2]|0;
  $203 = (($202) + 4|0);
  $204 = HEAP32[$203>>2]|0;
  $205 = HEAP32[$202>>2]|0;
  $206 = $204;
  $207 = $205;
  $208 = (($206) - ($207))|0;
  $209 = (($208|0) / 12)&-1;
  $210 = ($201>>>0)<($209>>>0);
  if ($210) {
   $44 = $202;$i$033 = $201;
  } else {
   label = 77;
   break;
  }
 }
 do {
  if ((label|0) == 17) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    $170 = ___cxa_find_matching_catch()|0;
    $171 = tempRet0;
    $lpad$phi$index = $170;$lpad$phi$index3 = $171;
    label = 62;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 50) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $147 = __THREW__; __THREW__ = 0;
   $148 = $147&1;
   if ($148) {
    $180 = ___cxa_find_matching_catch()|0;
    $181 = tempRet0;
    $lpad$phi21$index = $180;$lpad$phi21$index9 = $181;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 59) {
   $166 = ___cxa_find_matching_catch()|0;
   $167 = tempRet0;
   $lpad$phi$index = $166;$lpad$phi$index3 = $167;
   label = 62;
  }
  else if ((label|0) == 60) {
   $168 = ___cxa_find_matching_catch()|0;
   $169 = tempRet0;
   $lpad$phi$index = $168;$lpad$phi$index3 = $169;
   label = 62;
  }
  else if ((label|0) == 63) {
   $172 = ___cxa_find_matching_catch()|0;
   $173 = tempRet0;
   $174 = HEAP8[$1>>0]|0;
   $175 = $174 & 1;
   $176 = ($175<<24>>24)==(0);
   if ($176) {
    $$0 = $173;$$01 = $172;
    $211 = HEAP32[$28>>2]|0;
    __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($dirPaths,$211);
    ___resumeException($$01|0);
    // unreachable;
   }
   $177 = HEAP32[$35>>2]|0;
   __ZdlPv($177);
   $$0 = $173;$$01 = $172;
   $211 = HEAP32[$28>>2]|0;
   __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($dirPaths,$211);
   ___resumeException($$01|0);
   // unreachable;
  }
  else if ((label|0) == 65) {
   $178 = ___cxa_find_matching_catch()|0;
   $179 = tempRet0;
   $lpad$phi21$index = $178;$lpad$phi21$index9 = $179;
  }
  else if ((label|0) == 77) {
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 62) {
  $$0 = $lpad$phi$index3;$$01 = $lpad$phi$index;
  $211 = HEAP32[$28>>2]|0;
  __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($dirPaths,$211);
  ___resumeException($$01|0);
  // unreachable;
 }
 $182 = HEAP8[$extension>>0]|0;
 $183 = $182 & 1;
 $184 = ($183<<24>>24)==(0);
 if ($184) {
  $$0 = $lpad$phi21$index9;$$01 = $lpad$phi21$index;
  $211 = HEAP32[$28>>2]|0;
  __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($dirPaths,$211);
  ___resumeException($$01|0);
  // unreachable;
 }
 $185 = HEAP32[$$pre5$i>>2]|0;
 __ZdlPv($185);
 $$0 = $lpad$phi21$index9;$$01 = $lpad$phi21$index;
 $211 = HEAP32[$28>>2]|0;
 __ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($dirPaths,$211);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN20TextRenderingPrivate21GetFontMetadataPresetERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERS6_S9_RjSA_iPiPb($name,$family_name,$style_name,$style_flags,$face_flags,$face_index,$num_faces,$face_found) {
 $name = $name|0;
 $family_name = $family_name|0;
 $style_name = $style_name|0;
 $style_flags = $style_flags|0;
 $face_flags = $face_flags|0;
 $face_index = $face_index|0;
 $num_faces = $num_faces|0;
 $face_found = $face_found|0;
 var $$0 = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$i$i$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fontfile_it = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fontfile_it = sp;
 $0 = HEAP32[805048>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_3mapIiN20TextRenderingPrivate13UnityFontInfoENS_4lessIiEENS5_INS_4pairIKiSA_EEEEEEEENS_19__map_value_compareIS7_SI_NSB_IS7_EELb1EEENS5_ISI_EEE4findIS7_EENS_15__tree_iteratorISI_PNS_11__tree_nodeISI_PvEEiEERKT_($fontfile_it,$0,$name);
 $1 = HEAP32[805048>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$fontfile_it>>2]|0;
 $4 = ($3|0)==($2|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($3) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($3) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$01$i$i$i$i$i = $8;
  while(1) {
   $14 = (($$01$i$i$i$i$i) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==($$01$i$i$i$i$i|0);
   if ($17) {
    $$01$i$i$i$i$i = $15;
   } else {
    $$0$i$i$i$i$i = $15;
    break;
   }
  }
 } else {
  $$0$i$i$i$i$i$i = $9;
  while(1) {
   $11 = (($$0$i$i$i$i$i$i) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
    break;
   } else {
    $$0$i$i$i$i$i$i = $12;
   }
  }
 }
 $18 = (($$0$i$i$i$i$i) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$num_faces>>2] = $19;
 if ($10) {
  $storemerge = 0;
 } else {
  $$0$ph7$i$i$i = $8;$$01$ph6$i$in$i$i = $9;
  L15: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $20 = (($$013$i$in$i$i) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)<($face_index|0);
    if (!($22)) {
     break;
    }
    $25 = (($$013$i$in$i$i) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L15;
    } else {
     $$013$i$in$i$i = $26;
    }
   }
   $23 = HEAP32[$$013$i$in$i$i>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $23;
   }
  }
  $28 = ($$0$ph5$i$i$i|0)==($8|0);
  if ($28) {
   $storemerge = 0;
  } else {
   $29 = (($$0$ph5$i$i$i) + 16|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)>($face_index|0);
   if ($31) {
    $storemerge = 0;
   } else {
    $32 = (($$0$ph5$i$i$i) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($family_name,$33)|0);
    $34 = (($$0$ph5$i$i$i) + 24|0);
    $35 = HEAP32[$34>>2]|0;
    (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($style_name,$35)|0);
    $36 = (($$0$ph5$i$i$i) + 28|0);
    $37 = HEAP32[$36>>2]|0;
    HEAP32[$style_flags>>2] = $37;
    $38 = (($$0$ph5$i$i$i) + 32|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$face_flags>>2] = $39;
    $storemerge = 1;
   }
  }
 }
 HEAP8[$face_found>>0] = $storemerge;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_3mapIiN20TextRenderingPrivate13UnityFontInfoENS_4lessIiEENS5_INS_4pairIKiSA_EEEEEEEENS_19__map_value_compareIS7_SI_NSB_IS7_EELb1EEENS5_ISI_EEE4findIS7_EENS_15__tree_iteratorISI_PNS_11__tree_nodeISI_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$$$i$i$i$i = 0, $$$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_3mapIiN20TextRenderingPrivate13UnityFontInfoENS_4lessIiEENS5_INS_4pairIKiSA_EEEEEEEENS_19__map_value_compareIS7_SI_NSB_IS7_EELb1EEENS5_ISI_EEE13__lower_boundIS7_EENS_15__tree_iteratorISI_PNS_11__tree_nodeISI_PvEEiEERKT_ST_ST_($__p,$this,$__v,$1,$2);
 $3 = HEAP32[$__p>>2]|0;
 $4 = ($3|0)==($2|0);
 if (!($4)) {
  $5 = (($3) + 16|0);
  $6 = HEAP8[$__v>>0]|0;
  $7 = $6 & 1;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $11 = $6&255;
   $12 = $11 >>> 1;
   $28 = $12;
  } else {
   $9 = (($__v) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $28 = $10;
  }
  $13 = HEAP8[$5>>0]|0;
  $14 = $13 & 1;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $18 = $13&255;
   $19 = $18 >>> 1;
   $27 = $19;
  } else {
   $16 = (($3) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   $27 = $17;
  }
  if ($8) {
   $22 = (($__v) + 1|0);
   $30 = $22;
  } else {
   $20 = (($__v) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $30 = $21;
  }
  if ($15) {
   $25 = (($5) + 1|0);
   $31 = $25;
  } else {
   $23 = (($3) + 24|0);
   $24 = HEAP32[$23>>2]|0;
   $31 = $24;
  }
  $26 = ($27>>>0)<($28>>>0);
  $29 = $26 ? $27 : $28;
  $32 = (_memcmp($30,$31,$29)|0);
  $33 = ($32|0)==(0);
  if ($33) {
   $34 = ($28>>>0)<($27>>>0);
   $$$i$i$i$i = $26&1;
   $$$$i$i$i$i = $34 ? -1 : $$$i$i$i$i;
   $36 = $$$$i$i$i$i;
  } else {
   $36 = $32;
  }
  $35 = ($36|0)<(0);
  if (!($35)) {
   HEAP32[$agg$result>>2] = $3;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_3mapIiN20TextRenderingPrivate13UnityFontInfoENS_4lessIiEENS5_INS_4pairIKiSA_EEEEEEEENS_19__map_value_compareIS7_SI_NSB_IS7_EELb1EEENS5_ISI_EEE13__lower_boundIS7_EENS_15__tree_iteratorISI_PNS_11__tree_nodeISI_PvEEiEERKT_ST_ST_($agg$result,$this,$__v,$__root,$__result) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 $__root = $__root|0;
 $__result = $__result|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i$us = 0, $$$i$i$i$i = 0, $$$i$i$i$i$us = 0, $$0$ph6 = 0, $$0$ph9 = 0, $$01$lcssa2 = 0, $$01$ph8 = 0, $$013 = 0, $$013$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__root|0)==(0|0);
 if ($0) {
  $$0$ph6 = $__result;
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
 $1 = HEAP8[$__v>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 $4 = $1&255;
 $5 = $4 >>> 1;
 $6 = (($__v) + 1|0);
 $7 = (($__v) + 8|0);
 $8 = (($__v) + 4|0);
 $$0$ph9 = $__result;$$01$ph8 = $__root;
 L4: while(1) {
  L6: do {
   if ($3) {
    $$013$us = $$01$ph8;
    while(1) {
     $9 = (($$013$us) + 16|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 & 1;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $17 = $10&255;
      $18 = $17 >>> 1;
      $19 = (($9) + 1|0);
      $21 = $18;$23 = $19;
     } else {
      $13 = (($$013$us) + 20|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($$013$us) + 24|0);
      $16 = HEAP32[$15>>2]|0;
      $21 = $14;$23 = $16;
     }
     $20 = ($5>>>0)<($21>>>0);
     $22 = $20 ? $5 : $21;
     $24 = (_memcmp($23,$6,$22)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = ($21>>>0)<($5>>>0);
      $$$i$i$i$i$us = $20&1;
      $$$$i$i$i$i$us = $26 ? -1 : $$$i$i$i$i$us;
      $28 = $$$$i$i$i$i$us;
     } else {
      $28 = $24;
     }
     $27 = ($28|0)<(0);
     if (!($27)) {
      $$01$lcssa2 = $$013$us;
      break L6;
     }
     $29 = (($$013$us) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013$us = $30;
     }
    }
   } else {
    $$013 = $$01$ph8;
    while(1) {
     $32 = (($$013) + 16|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = $33 & 1;
     $35 = ($34<<24>>24)==(0);
     if ($35) {
      $40 = $33&255;
      $41 = $40 >>> 1;
      $42 = (($32) + 1|0);
      $46 = $41;$48 = $42;
     } else {
      $36 = (($$013) + 20|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = (($$013) + 24|0);
      $39 = HEAP32[$38>>2]|0;
      $46 = $37;$48 = $39;
     }
     $43 = HEAP32[$8>>2]|0;
     $44 = HEAP32[$7>>2]|0;
     $45 = ($43>>>0)<($46>>>0);
     $47 = $45 ? $43 : $46;
     $49 = (_memcmp($48,$44,$47)|0);
     $50 = ($49|0)==(0);
     if ($50) {
      $51 = ($46>>>0)<($43>>>0);
      $$$i$i$i$i = $45&1;
      $$$$i$i$i$i = $51 ? -1 : $$$i$i$i$i;
      $53 = $$$$i$i$i$i;
     } else {
      $53 = $49;
     }
     $52 = ($53|0)<(0);
     if (!($52)) {
      $$01$lcssa2 = $$013;
      break L6;
     }
     $56 = (($$013) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0|0);
     if ($58) {
      $$0$ph6 = $$0$ph9;
      label = 19;
      break L4;
     } else {
      $$013 = $57;
     }
    }
   }
  } while(0);
  $54 = HEAP32[$$01$lcssa2>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$0$ph6 = $$01$lcssa2;
   label = 19;
   break;
  } else {
   $$0$ph9 = $$01$lcssa2;$$01$ph8 = $54;
  }
 }
 if ((label|0) == 19) {
  HEAP32[$agg$result>>2] = $$0$ph6;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_3mapIiN20TextRenderingPrivate13UnityFontInfoENS_4lessIiEENS5_INS_4pairIKiSA_EEEEEEEENS_19__map_value_compareIS7_SI_NSB_IS7_EELb1EEENS5_ISI_EEE7destroyEPNS_11__tree_nodeISI_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_3mapIiN20TextRenderingPrivate13UnityFontInfoENS_4lessIiEENS5_INS_4pairIKiSA_EEEEEEEENS_19__map_value_compareIS7_SI_NSB_IS7_EELb1EEENS5_ISI_EEE7destroyEPNS_11__tree_nodeISI_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_3mapIiN20TextRenderingPrivate13UnityFontInfoENS_4lessIiEENS5_INS_4pairIKiSA_EEEEEEEENS_19__map_value_compareIS7_SI_NSB_IS7_EELb1EEENS5_ISI_EEE7destroyEPNS_11__tree_nodeISI_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = (($__nd) + 28|0);
 $6 = (($__nd) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIiN20TextRenderingPrivate13UnityFontInfoEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($5,$7);
 $8 = HEAP8[$4>>0]|0;
 $9 = $8 & 1;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = (($__nd) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  __ZdlPv($12);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIiN20TextRenderingPrivate13UnityFontInfoEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiN20TextRenderingPrivate13UnityFontInfoEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiN20TextRenderingPrivate13UnityFontInfoEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __Z6GetTagR11UTF16StringRiRb($input,$pos,$closing) {
 $input = $input|0;
 $pos = $pos|0;
 $closing = $closing|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$not = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$019 = 0, $i$019$lcssa = 0, $i$01924 = 0, $j$07 = 0, $or$cond = 0, $or$cond30 = 0;
 var $paramPos$02 = 0, $v$off$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$pos>>2]|0;
 $1 = HEAP32[$input>>2]|0;
 $2 = (($1) + ($0<<1)|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(60);
 if (!($4)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($0) + 1)|0;
 $6 = (($input) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 if ($8) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($1) + ($5<<1)|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = ($10<<16>>16)==(47);
 $12 = $11&1;
 HEAP8[$closing>>0] = $12;
 $13 = (($0) + 2)|0;
 $$ = $11 ? $13 : $5;
 $i$019 = 0;
 while(1) {
  $14 = (805296 + ($i$019<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP8[$15>>0]|0;
  $17 = ($16<<24>>24)==(0);
  L9: do {
   if ($17) {
    label = 10;
   } else {
    $32 = $16;$j$07 = 0;
    while(1) {
     $22 = (($j$07) + ($$))|0;
     $23 = ($22|0)==($7|0);
     if ($23) {
      break L9;
     }
     $24 = (($1) + ($22<<1)|0);
     $25 = HEAP16[$24>>1]|0;
     $26 = $25&255;
     $v$off$i = (($26) + -65)<<24>>24;
     $27 = ($v$off$i&255)<(26);
     if ($27) {
      $28 = $25&65535;
      $29 = $28 | 32;
      $30 = $29&255;
      $$0$i = $30;
     } else {
      $$0$i = $26;
     }
     $31 = ($$0$i<<24>>24)==($32<<24>>24);
     $19 = (($j$07) + 1)|0;
     if (!($31)) {
      break L9;
     }
     $18 = (($15) + ($19)|0);
     $20 = HEAP8[$18>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      label = 10;
      break;
     } else {
      $32 = $20;$j$07 = $19;
     }
    }
   }
  } while(0);
  if ((label|0) == 10) {
   label = 0;
   $33 = (_strlen(($15|0))|0);
   $34 = (($33) + ($$))|0;
   $$phi$trans$insert = (($1) + ($34<<1)|0);
   $$pre = HEAP16[$$phi$trans$insert>>1]|0;
   $$not = $11 ^ 1;
   $35 = ($$pre<<16>>16)==(61);
   $or$cond30 = $35 & $$not;
   if ($or$cond30) {
    $i$019$lcssa = $i$019;
    label = 12;
    break;
   }
   $36 = ($$pre<<16>>16)==(32);
   $37 = ($i$019|0)==(5);
   $or$cond = $36 & $37;
   if ($or$cond) {
    $i$019$lcssa = 5;
    label = 12;
    break;
   }
   $43 = ($$pre<<16>>16)==(62);
   if ($43) {
    $i$01924 = $i$019;
    break;
   }
  }
  $46 = (($i$019) + 1)|0;
  $47 = ($46|0)<(10);
  if ($47) {
   $i$019 = $46;
  } else {
   $$0 = -1;
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return ($$0|0);
 }
 L24: do {
  if ((label|0) == 12) {
   $paramPos$02 = $34;
   while(1) {
    $42 = ($paramPos$02|0)<($7|0);
    $39 = (($paramPos$02) + 1)|0;
    if (!($42)) {
     $i$01924 = $i$019$lcssa;
     break L24;
    }
    $38 = (($1) + ($39<<1)|0);
    $40 = HEAP16[$38>>1]|0;
    $41 = ($40<<16>>16)==(62);
    if ($41) {
     $i$01924 = $i$019$lcssa;
     break;
    } else {
     $paramPos$02 = $39;
    }
   }
  }
 } while(0);
 $44 = (_strlen(($15|0))|0);
 $45 = (($44) + ($$))|0;
 HEAP32[$pos>>2] = $45;
 $$0 = $i$01924;
 STACKTOP = sp;return ($$0|0);
}
function __Z12GetParameterR11UTF16StringRib($agg$result,$input,$pos,$allowMultipleParamaters) {
 $agg$result = $agg$result|0;
 $input = $input|0;
 $pos = $pos|0;
 $allowMultipleParamaters = $allowMultipleParamaters|0;
 var $$0 = 0, $$02 = 0, $$in = 0, $$in18 = 0, $$in19 = 0, $$not = 0, $$off0 = 0, $$pn$i = 0, $$pn$i$us = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__cap$0$i = 0, $__cap$0$i$us = 0, $__p$0$i = 0, $__p$0$i$i = 0, $__p$0$i$us = 0, $__p$0$sum$pre$i = 0, $__p$0$sum$pre$i$us = 0, $__p$0$sum$pre$phi$i$usZZZ2D = 0, $__p$0$sum$pre$phi$iZZZ2D = 0, $__sz$0$i = 0, $__sz$0$i$us = 0, $extract$t = 0, $extract$t14 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $1 = HEAP32[$pos>>2]|0;
 $2 = HEAP32[$input>>2]|0;
 $3 = (($2) + ($1<<1)|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(61);
 L1: do {
  if ($5) {
   $6 = (($1) + 1)|0;
   HEAP32[$pos>>2] = $6;
   $7 = (($2) + ($6<<1)|0);
   $8 = HEAP16[$7>>1]|0;
   $9 = ($8<<16>>16)==(62);
   L3: do {
    if (!($9)) {
     $10 = (($input) + 4|0);
     $11 = (($agg$result) + 4|0);
     $12 = (($agg$result) + 1|0);
     $13 = (($agg$result) + 8|0);
     if ($allowMultipleParamaters) {
      $46 = $8;$49 = $6;
      while(1) {
       $$not = ($46<<16>>16)==(32);
       if ($$not) {
        break L3;
       }
       $47 = HEAP32[$10>>2]|0;
       $48 = ($49|0)<($47|0);
       if (!($48)) {
        break L3;
       }
       $50 = (($49) + 1)|0;
       HEAP32[$pos>>2] = $50;
       $51 = $46&255;
       $52 = HEAP8[$agg$result>>0]|0;
       $53 = $52 & 1;
       $54 = ($53<<24>>24)!=(0);
       if ($54) {
        $57 = HEAP32[$agg$result>>2]|0;
        $58 = $57 & -2;
        $59 = (($58) + -1)|0;
        $60 = HEAP32[$11>>2]|0;
        $__cap$0$i = $59;$__sz$0$i = $60;
       } else {
        $55 = $52&255;
        $56 = $55 >>> 1;
        $__cap$0$i = 10;$__sz$0$i = $56;
       }
       $61 = ($__sz$0$i|0)==($__cap$0$i|0);
       if ($61) {
        __THREW__ = 0;
        invoke_viiiiiii(61,($agg$result|0),($__cap$0$i|0),1,($__cap$0$i|0),($__cap$0$i|0),0,0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP8[$agg$result>>0]|0;
        $65 = $64 & 1;
        $66 = ($65<<24>>24)==(0);
        if ($66) {
         label = 26;
        } else {
         label = 27;
        }
       } else {
        if ($54) {
         label = 27;
        } else {
         label = 26;
        }
       }
       if ((label|0) == 26) {
        label = 0;
        $67 = $__sz$0$i << 1;
        $68 = (($67) + 2)|0;
        $69 = $68&255;
        HEAP8[$agg$result>>0] = $69;
        $__p$0$sum$pre$i = (($__sz$0$i) + 1)|0;
        $$pn$i = $12;$__p$0$sum$pre$phi$iZZZ2D = $__p$0$sum$pre$i;
       }
       else if ((label|0) == 27) {
        label = 0;
        $70 = HEAP32[$13>>2]|0;
        $71 = (($__sz$0$i) + 1)|0;
        HEAP32[$11>>2] = $71;
        $$pn$i = $70;$__p$0$sum$pre$phi$iZZZ2D = $71;
       }
       $__p$0$i = (($$pn$i) + ($__sz$0$i)|0);
       HEAP8[$__p$0$i>>0] = $51;
       $72 = (($$pn$i) + ($__p$0$sum$pre$phi$iZZZ2D)|0);
       HEAP8[$72>>0] = 0;
       $73 = HEAP32[$pos>>2]|0;
       $74 = HEAP32[$input>>2]|0;
       $75 = (($74) + ($73<<1)|0);
       $76 = HEAP16[$75>>1]|0;
       $77 = ($76<<16>>16)==(62);
       if ($77) {
        break L3;
       } else {
        $46 = $76;$49 = $73;
       }
      }
      $78 = ___cxa_find_matching_catch()|0;
      $79 = tempRet0;
      $lpad$phi$index = $78;$lpad$phi$index3 = $79;
      label = 31;
      break L1;
     } else {
      $extract$t = $8&255;
      $$off0 = $extract$t;$16 = $6;
      while(1) {
       $14 = HEAP32[$10>>2]|0;
       $15 = ($16|0)<($14|0);
       if (!($15)) {
        break L3;
       }
       $17 = (($16) + 1)|0;
       HEAP32[$pos>>2] = $17;
       $18 = HEAP8[$agg$result>>0]|0;
       $19 = $18 & 1;
       $20 = ($19<<24>>24)!=(0);
       if ($20) {
        $23 = HEAP32[$agg$result>>2]|0;
        $24 = $23 & -2;
        $25 = (($24) + -1)|0;
        $26 = HEAP32[$11>>2]|0;
        $__cap$0$i$us = $25;$__sz$0$i$us = $26;
       } else {
        $21 = $18&255;
        $22 = $21 >>> 1;
        $__cap$0$i$us = 10;$__sz$0$i$us = $22;
       }
       $27 = ($__sz$0$i$us|0)==($__cap$0$i$us|0);
       if ($27) {
        __THREW__ = 0;
        invoke_viiiiiii(61,($agg$result|0),($__cap$0$i$us|0),1,($__cap$0$i$us|0),($__cap$0$i$us|0),0,0);
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         break;
        }
        $30 = HEAP8[$agg$result>>0]|0;
        $31 = $30 & 1;
        $32 = ($31<<24>>24)==(0);
        if ($32) {
         label = 14;
        } else {
         label = 13;
        }
       } else {
        if ($20) {
         label = 13;
        } else {
         label = 14;
        }
       }
       if ((label|0) == 13) {
        label = 0;
        $33 = HEAP32[$13>>2]|0;
        $34 = (($__sz$0$i$us) + 1)|0;
        HEAP32[$11>>2] = $34;
        $$pn$i$us = $33;$__p$0$sum$pre$phi$i$usZZZ2D = $34;
       }
       else if ((label|0) == 14) {
        label = 0;
        $35 = $__sz$0$i$us << 1;
        $36 = (($35) + 2)|0;
        $37 = $36&255;
        HEAP8[$agg$result>>0] = $37;
        $__p$0$sum$pre$i$us = (($__sz$0$i$us) + 1)|0;
        $$pn$i$us = $12;$__p$0$sum$pre$phi$i$usZZZ2D = $__p$0$sum$pre$i$us;
       }
       $__p$0$i$us = (($$pn$i$us) + ($__sz$0$i$us)|0);
       HEAP8[$__p$0$i$us>>0] = $$off0;
       $38 = (($$pn$i$us) + ($__p$0$sum$pre$phi$i$usZZZ2D)|0);
       HEAP8[$38>>0] = 0;
       $39 = HEAP32[$pos>>2]|0;
       $40 = HEAP32[$input>>2]|0;
       $41 = (($40) + ($39<<1)|0);
       $42 = HEAP16[$41>>1]|0;
       $43 = ($42<<16>>16)==(62);
       $extract$t14 = $42&255;
       if ($43) {
        break L3;
       } else {
        $$off0 = $extract$t14;$16 = $39;
       }
      }
      $44 = ___cxa_find_matching_catch()|0;
      $45 = tempRet0;
      $lpad$phi$index = $44;$lpad$phi$index3 = $45;
      label = 31;
      break L1;
     }
    }
   } while(0);
   $$pre = HEAP8[$agg$result>>0]|0;
   $82 = $$pre & 1;
   $83 = ($82<<24>>24)==(0);
   if ($83) {
    $87 = $$pre;
    label = 34;
   } else {
    $84 = (($agg$result) + 4|0);
    $85 = HEAP32[$84>>2]|0;
    $172 = 0;$90 = $85;$97 = $$pre;
    label = 35;
   }
  } else {
   $87 = 0;
   label = 34;
  }
 } while(0);
 if ((label|0) == 34) {
  $86 = $87&255;
  $88 = $86 >>> 1;
  $172 = 1;$90 = $88;$97 = $87;
  label = 35;
 }
 L44: do {
  if ((label|0) == 35) {
   $89 = ($90>>>0)>(2);
   if (!($89)) {
    STACKTOP = sp;return;
   }
   if ($172) {
    $95 = (($agg$result) + 1|0);
    $96 = $97&255;
    $98 = $96 >>> 1;
    $99 = (($agg$result) + 1|0);
    $$in = $98;$$in18 = $95;$103 = $99;
   } else {
    $91 = (($agg$result) + 8|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = (($agg$result) + 4|0);
    $94 = HEAP32[$93>>2]|0;
    $$in = $94;$$in18 = $92;$103 = $92;
   }
   $100 = HEAP8[$$in18>>0]|0;
   $101 = (($$in) + -1)|0;
   $102 = (($103) + ($101)|0);
   $104 = HEAP8[$102>>0]|0;
   $105 = ($100<<24>>24)==($104<<24>>24);
   if (!($105)) {
    STACKTOP = sp;return;
   }
   if ($172) {
    $108 = (($agg$result) + 1|0);
    $110 = $108;
   } else {
    $106 = (($agg$result) + 8|0);
    $107 = HEAP32[$106>>2]|0;
    $110 = $107;
   }
   $109 = HEAP8[$110>>0]|0;
   $111 = ($109<<24>>24)==(39);
   if (!($111)) {
    if ($172) {
     $114 = (($agg$result) + 1|0);
     $116 = $114;
    } else {
     $112 = (($agg$result) + 8|0);
     $113 = HEAP32[$112>>2]|0;
     $116 = $113;
    }
    $115 = HEAP8[$116>>0]|0;
    $117 = ($115<<24>>24)==(34);
    if (!($117)) {
     STACKTOP = sp;return;
    }
   }
   if ($172) {
    $120 = $97&255;
    $121 = $120 >>> 1;
    $122 = $97&255;
    $123 = $122 >>> 1;
    $$in19 = $121;$126 = $123;
   } else {
    $118 = (($agg$result) + 4|0);
    $119 = HEAP32[$118>>2]|0;
    $$in19 = $119;$126 = $119;
   }
   $124 = (($$in19) + -2)|0;
   $125 = ($126|0)==(0);
   do {
    if ($125) {
     __THREW__ = 0;
     invoke_vi(3304,0);
     $127 = __THREW__; __THREW__ = 0;
     $128 = $127&1;
     if (!($128)) {
      // unreachable;
     }
    } else {
     if ($172) {
      $131 = (($agg$result) + 1|0);
      $133 = $131;
     } else {
      $129 = (($agg$result) + 8|0);
      $130 = HEAP32[$129>>2]|0;
      $133 = $130;
     }
     $132 = (($133) + 1|0);
     $134 = (($126) + -1)|0;
     $135 = ($134>>>0)<($124>>>0);
     $136 = $135 ? $134 : $124;
     $137 = ($136>>>0)>(4294967279);
     if ($137) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       break;
      }
      // unreachable;
     }
     $140 = ($136>>>0)<(11);
     if ($140) {
      $141 = $136 << 1;
      $142 = $141&255;
      HEAP8[$0>>0] = $142;
      $143 = (($0) + 1|0);
      $__p$0$i$i = $143;
     } else {
      $144 = (($136) + 16)|0;
      $145 = $144 & -16;
      __THREW__ = 0;
      $146 = (invoke_ii(2988,($145|0))|0);
      $147 = __THREW__; __THREW__ = 0;
      $148 = $147&1;
      if ($148) {
       break;
      }
      $149 = (($0) + 8|0);
      HEAP32[$149>>2] = $146;
      $150 = $145 | 1;
      HEAP32[$0>>2] = $150;
      $151 = (($0) + 4|0);
      HEAP32[$151>>2] = $136;
      $__p$0$i$i = $146;
     }
     _memcpy(($__p$0$i$i|0),($132|0),($136|0))|0;
     $152 = (($__p$0$i$i) + ($136)|0);
     HEAP8[$152>>0] = 0;
     __THREW__ = 0;
     (invoke_iii(2233,($agg$result|0),($0|0))|0);
     $153 = __THREW__; __THREW__ = 0;
     $154 = $153&1;
     if ($154) {
      $160 = ___cxa_find_matching_catch()|0;
      $161 = tempRet0;
      $162 = HEAP8[$0>>0]|0;
      $163 = $162 & 1;
      $164 = ($163<<24>>24)==(0);
      if ($164) {
       $$0 = $161;$$02 = $160;
       break L44;
      }
      $165 = (($0) + 8|0);
      $166 = HEAP32[$165>>2]|0;
      __ZdlPv($166);
      $$0 = $161;$$02 = $160;
      break L44;
     }
     $155 = HEAP8[$0>>0]|0;
     $156 = $155 & 1;
     $157 = ($156<<24>>24)==(0);
     if ($157) {
      STACKTOP = sp;return;
     }
     $158 = (($0) + 8|0);
     $159 = HEAP32[$158>>2]|0;
     __ZdlPv($159);
     STACKTOP = sp;return;
    }
   } while(0);
   $80 = ___cxa_find_matching_catch()|0;
   $81 = tempRet0;
   $lpad$phi$index = $80;$lpad$phi$index3 = $81;
   label = 31;
  }
 } while(0);
 if ((label|0) == 31) {
  $$0 = $lpad$phi$index3;$$02 = $lpad$phi$index;
 }
 $167 = HEAP8[$agg$result>>0]|0;
 $168 = $167 & 1;
 $169 = ($168<<24>>24)==(0);
 if ($169) {
  ___resumeException($$02|0);
  // unreachable;
 }
 $170 = (($agg$result) + 8|0);
 $171 = HEAP32[$170>>2]|0;
 __ZdlPv($171);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z14ParseHTMLColorNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$colorstring) {
 $agg$result = $agg$result|0;
 $colorstring = $colorstring|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$47 = 0, $$48 = 0, $$pn = 0, $$pn$i$i = 0, $$pn$i$i17 = 0, $$pre = 0, $$pre43 = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__cap$0$i$i = 0, $__cap$0$i$i13 = 0, $__p$0$i$i = 0, $__p$0$i$i$i = 0, $__p$0$i$i18 = 0, $__p$0$sum$pre$i$i = 0, $__p$0$sum$pre$i$i15 = 0, $__p$0$sum$pre$phi$i$i16ZZZ2D = 0, $__p$0$sum$pre$phi$i$iZZZ2D = 0, $__sz$0$i$i = 0, $__sz$0$i$i14 = 0, $color = 0, $i$0 = 0, $i1$038 = 0, $longcolorstring = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $color = sp + 24|0;
 $longcolorstring = sp;
 $0 = sp + 12|0;
 HEAP32[$color>>2] = -1;
 $1 = HEAP8[$colorstring>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($colorstring) + 1|0);
  $8 = $6;
 } else {
  $4 = (($colorstring) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $8 = $5;
 }
 $7 = HEAP8[$8>>0]|0;
 $9 = ($7<<24>>24)==(35);
 L5: do {
  if ($9) {
   if ($3) {
    $17 = $1&255;
    $18 = $17 >>> 1;
    $20 = $18;
   } else {
    $15 = (($colorstring) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $20 = $16;
   }
   $19 = ($20|0)==(4);
   if ($19) {
    label = 14;
   } else {
    if ($3) {
     $23 = $1&255;
     $24 = $23 >>> 1;
     $26 = $24;
    } else {
     $21 = (($colorstring) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     $26 = $22;
    }
    $25 = ($26|0)==(5);
    if ($25) {
     label = 14;
    }
   }
   do {
    if ((label|0) == 14) {
     HEAP8[$longcolorstring>>0] = 2;
     $27 = (($longcolorstring) + 1|0);
     HEAP8[$27>>0] = 35;
     $28 = (($longcolorstring) + 2|0);
     HEAP8[$28>>0] = 0;
     $29 = (($colorstring) + 1|0);
     $30 = (($longcolorstring) + 4|0);
     $31 = (($longcolorstring) + 8|0);
     $32 = (($colorstring) + 8|0);
     $33 = (($colorstring) + 4|0);
     $35 = $1;$i$0 = 1;
     L44: while(1) {
      $34 = $35 & 1;
      $36 = ($34<<24>>24)==(0);
      if ($36) {
       $38 = $35&255;
       $39 = $38 >>> 1;
       $41 = $39;
      } else {
       $37 = HEAP32[$33>>2]|0;
       $41 = $37;
      }
      $40 = ($i$0>>>0)<($41>>>0);
      if (!($40)) {
       label = 64;
       break;
      }
      if ($36) {
       $44 = $29;
      } else {
       $42 = HEAP32[$32>>2]|0;
       $44 = $42;
      }
      $43 = (($44) + ($i$0)|0);
      $45 = HEAP8[$43>>0]|0;
      $46 = HEAP8[$longcolorstring>>0]|0;
      $47 = $46 & 1;
      $48 = ($47<<24>>24)!=(0);
      if ($48) {
       $51 = HEAP32[$longcolorstring>>2]|0;
       $52 = $51 & -2;
       $53 = (($52) + -1)|0;
       $54 = HEAP32[$30>>2]|0;
       $55 = $51&255;
       $61 = $55;$__cap$0$i$i = $53;$__sz$0$i$i = $54;
      } else {
       $49 = $46&255;
       $50 = $49 >>> 1;
       $61 = $46;$__cap$0$i$i = 10;$__sz$0$i$i = $50;
      }
      $56 = ($__sz$0$i$i|0)==($__cap$0$i$i|0);
      do {
       if ($56) {
        $57 = ($__cap$0$i$i|0)==(-17);
        if ($57) {
         label = 26;
         break L44;
        }
        $60 = $61 & 1;
        $62 = ($60<<24>>24)==(0);
        $63 = HEAP32[$31>>2]|0;
        $$ = $62 ? $27 : $63;
        $64 = ($__cap$0$i$i>>>0)<(2147483623);
        if ($64) {
         $65 = (($__cap$0$i$i) + 1)|0;
         $66 = $__cap$0$i$i << 1;
         $67 = ($65>>>0)<($66>>>0);
         $68 = $67 ? $66 : $65;
         $69 = ($68>>>0)<(11);
         if ($69) {
          $72 = 11;
         } else {
          $70 = (($68) + 16)|0;
          $71 = $70 & -16;
          $72 = $71;
         }
        } else {
         $72 = -17;
        }
        __THREW__ = 0;
        $73 = (invoke_ii(2988,($72|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         $209 = $61;
         label = 60;
         break L44;
        }
        _memcpy(($73|0),($$|0),($__cap$0$i$i|0))|0;
        $76 = ($__cap$0$i$i|0)==(10);
        if (!($76)) {
         __ZdlPv($$);
        }
        HEAP32[$31>>2] = $73;
        $77 = $72 | 1;
        HEAP32[$longcolorstring>>2] = $77;
        $210 = $73;
        label = 38;
       } else {
        if ($48) {
         $$pre46 = HEAP32[$31>>2]|0;
         $210 = $$pre46;
         label = 38;
         break;
        } else {
         $78 = $__sz$0$i$i << 1;
         $79 = (($78) + 2)|0;
         $80 = $79&255;
         HEAP8[$longcolorstring>>0] = $80;
         $__p$0$sum$pre$i$i = (($__sz$0$i$i) + 1)|0;
         $$pn$i$i = $27;$__p$0$sum$pre$phi$i$iZZZ2D = $__p$0$sum$pre$i$i;
         break;
        }
       }
      } while(0);
      if ((label|0) == 38) {
       label = 0;
       $81 = (($__sz$0$i$i) + 1)|0;
       HEAP32[$30>>2] = $81;
       $$pn$i$i = $210;$__p$0$sum$pre$phi$i$iZZZ2D = $81;
      }
      $__p$0$i$i = (($$pn$i$i) + ($__sz$0$i$i)|0);
      HEAP8[$__p$0$i$i>>0] = $45;
      $82 = (($$pn$i$i) + ($__p$0$sum$pre$phi$i$iZZZ2D)|0);
      HEAP8[$82>>0] = 0;
      $83 = HEAP8[$colorstring>>0]|0;
      $84 = $83 & 1;
      $85 = ($84<<24>>24)==(0);
      if ($85) {
       $88 = $29;
      } else {
       $86 = HEAP32[$32>>2]|0;
       $88 = $86;
      }
      $87 = (($88) + ($i$0)|0);
      $89 = HEAP8[$87>>0]|0;
      $90 = HEAP8[$longcolorstring>>0]|0;
      $91 = $90 & 1;
      $92 = ($91<<24>>24)!=(0);
      if ($92) {
       $95 = HEAP32[$longcolorstring>>2]|0;
       $96 = $95 & -2;
       $97 = (($96) + -1)|0;
       $98 = HEAP32[$30>>2]|0;
       $99 = $95&255;
       $105 = $99;$__cap$0$i$i13 = $97;$__sz$0$i$i14 = $98;
      } else {
       $93 = $90&255;
       $94 = $93 >>> 1;
       $105 = $90;$__cap$0$i$i13 = 10;$__sz$0$i$i14 = $94;
      }
      $100 = ($__sz$0$i$i14|0)==($__cap$0$i$i13|0);
      do {
       if ($100) {
        $101 = ($__cap$0$i$i13|0)==(-17);
        if ($101) {
         label = 46;
         break L44;
        }
        $104 = $105 & 1;
        $106 = ($104<<24>>24)==(0);
        $107 = HEAP32[$31>>2]|0;
        $$47 = $106 ? $27 : $107;
        $108 = ($__cap$0$i$i13>>>0)<(2147483623);
        if ($108) {
         $109 = (($__cap$0$i$i13) + 1)|0;
         $110 = $__cap$0$i$i13 << 1;
         $111 = ($109>>>0)<($110>>>0);
         $112 = $111 ? $110 : $109;
         $113 = ($112>>>0)<(11);
         if ($113) {
          $116 = 11;
         } else {
          $114 = (($112) + 16)|0;
          $115 = $114 & -16;
          $116 = $115;
         }
        } else {
         $116 = -17;
        }
        __THREW__ = 0;
        $117 = (invoke_ii(2988,($116|0))|0);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         $209 = $105;
         label = 60;
         break L44;
        }
        _memcpy(($117|0),($$47|0),($__cap$0$i$i13|0))|0;
        $120 = ($__cap$0$i$i13|0)==(10);
        if (!($120)) {
         __ZdlPv($$47);
        }
        HEAP32[$31>>2] = $117;
        $121 = $116 | 1;
        HEAP32[$longcolorstring>>2] = $121;
        $211 = $117;
        label = 58;
       } else {
        if ($92) {
         $$pre45 = HEAP32[$31>>2]|0;
         $211 = $$pre45;
         label = 58;
         break;
        } else {
         $122 = $__sz$0$i$i14 << 1;
         $123 = (($122) + 2)|0;
         $124 = $123&255;
         HEAP8[$longcolorstring>>0] = $124;
         $__p$0$sum$pre$i$i15 = (($__sz$0$i$i14) + 1)|0;
         $$pn$i$i17 = $27;$__p$0$sum$pre$phi$i$i16ZZZ2D = $__p$0$sum$pre$i$i15;
         break;
        }
       }
      } while(0);
      if ((label|0) == 58) {
       label = 0;
       $125 = (($__sz$0$i$i14) + 1)|0;
       HEAP32[$30>>2] = $125;
       $$pn$i$i17 = $211;$__p$0$sum$pre$phi$i$i16ZZZ2D = $125;
      }
      $__p$0$i$i18 = (($$pn$i$i17) + ($__sz$0$i$i14)|0);
      HEAP8[$__p$0$i$i18>>0] = $89;
      $126 = (($$pn$i$i17) + ($__p$0$sum$pre$phi$i$i16ZZZ2D)|0);
      HEAP8[$126>>0] = 0;
      $127 = (($i$0) + 1)|0;
      $$pre = HEAP8[$colorstring>>0]|0;
      $35 = $$pre;$i$0 = $127;
     }
     if ((label|0) == 26) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 61;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 46) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       label = 61;
      } else {
       // unreachable;
      }
     }
     else if ((label|0) == 60) {
      $128 = ___cxa_find_matching_catch()|0;
      $129 = tempRet0;
      $133 = $209;$lpad$phi$index = $128;$lpad$phi$index2 = $129;
     }
     else if ((label|0) == 64) {
      __THREW__ = 0;
      (invoke_iii(2233,($colorstring|0),($longcolorstring|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       label = 61;
      } else {
       $138 = HEAP8[$longcolorstring>>0]|0;
       $139 = $138 & 1;
       $140 = ($139<<24>>24)==(0);
       if ($140) {
        break;
       }
       $141 = HEAP32[$31>>2]|0;
       __ZdlPv($141);
       break;
      }
     }
     if ((label|0) == 61) {
      $130 = ___cxa_find_matching_catch()|0;
      $131 = tempRet0;
      $$pre43 = HEAP8[$longcolorstring>>0]|0;
      $133 = $$pre43;$lpad$phi$index = $130;$lpad$phi$index2 = $131;
     }
     $132 = $133 & 1;
     $134 = ($132<<24>>24)==(0);
     if ($134) {
      $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
      ___resumeException($$01|0);
      // unreachable;
     }
     $135 = HEAP32[$31>>2]|0;
     __ZdlPv($135);
     $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
     ___resumeException($$01|0);
     // unreachable;
    }
   } while(0);
   $142 = HEAP8[$colorstring>>0]|0;
   $143 = $142 & 1;
   $144 = ($143<<24>>24)==(0);
   if ($144) {
    $147 = $142&255;
    $148 = $147 >>> 1;
    $150 = $148;
   } else {
    $145 = (($colorstring) + 4|0);
    $146 = HEAP32[$145>>2]|0;
    $150 = $146;
   }
   $149 = ($150|0)==(7);
   if (!($149)) {
    if ($144) {
     $153 = $142&255;
     $154 = $153 >>> 1;
     $156 = $154;
    } else {
     $151 = (($colorstring) + 4|0);
     $152 = HEAP32[$151>>2]|0;
     $156 = $152;
    }
    $155 = ($156|0)==(9);
    if (!($155)) {
     break;
    }
   }
   if ($144) {
    $161 = (($colorstring) + 1|0);
    $162 = $142&255;
    $163 = $162 >>> 1;
    $$pn = $161;$166 = $163;
   } else {
    $157 = (($colorstring) + 8|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($colorstring) + 4|0);
    $160 = HEAP32[$159>>2]|0;
    $$pn = $158;$166 = $160;
   }
   $164 = (($$pn) + 1|0);
   $165 = $166 >>> 1;
   __Z16HexStringToBytesPKcjPv($164,$165,$color);
  } else {
   $10 = (($0) + 1|0);
   $11 = (($colorstring) + 1|0);
   $12 = (($0) + 8|0);
   $13 = (($colorstring) + 8|0);
   $14 = (($0) + 4|0);
   $i1$038 = 0;
   while(1) {
    $169 = (805528 + ($i1$038<<2)|0);
    $170 = HEAP32[$169>>2]|0;
    $171 = (_strlen(($170|0))|0);
    $172 = ($171>>>0)>(4294967279);
    if ($172) {
     label = 81;
     break;
    }
    $173 = ($171>>>0)<(11);
    if ($173) {
     $174 = $171 << 1;
     $175 = $174&255;
     HEAP8[$0>>0] = $175;
     $187 = $175;$__p$0$i$i$i = $10;
    } else {
     $176 = (($171) + 16)|0;
     $177 = $176 & -16;
     $178 = (__Znwj($177)|0);
     HEAP32[$12>>2] = $178;
     $179 = $177 | 1;
     HEAP32[$0>>2] = $179;
     HEAP32[$14>>2] = $171;
     $180 = $179&255;
     $187 = $180;$__p$0$i$i$i = $178;
    }
    _memcpy(($__p$0$i$i$i|0),($170|0),($171|0))|0;
    $181 = (($__p$0$i$i$i) + ($171)|0);
    HEAP8[$181>>0] = 0;
    $182 = HEAP8[$colorstring>>0]|0;
    $183 = $182 & 1;
    $184 = ($183<<24>>24)==(0);
    if ($184) {
     $190 = $11;
    } else {
     $185 = HEAP32[$13>>2]|0;
     $190 = $185;
    }
    $186 = $187 & 1;
    $188 = ($186<<24>>24)==(0);
    $189 = HEAP32[$12>>2]|0;
    $$48 = $188 ? $10 : $189;
    __THREW__ = 0;
    $191 = (invoke_iii(2448,($190|0),($$48|0))|0);
    $192 = __THREW__; __THREW__ = 0;
    $193 = $192&1;
    if ($193) {
     label = 92;
     break;
    }
    $194 = ($191|0)==(0);
    $195 = HEAP8[$0>>0]|0;
    $196 = $195 & 1;
    $197 = ($196<<24>>24)==(0);
    if (!($197)) {
     $198 = HEAP32[$12>>2]|0;
     __ZdlPv($198);
    }
    $168 = (($i1$038) + 1)|0;
    if ($194) {
     label = 91;
     break;
    }
    $167 = ($168>>>0)<(22);
    if ($167) {
     $i1$038 = $168;
    } else {
     break L5;
    }
   }
   if ((label|0) == 81) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   else if ((label|0) == 91) {
    $199 = $i1$038 << 2;
    $200 = (805616 + ($199)|0);
    $201 = HEAP32[$200>>2]|0;
    HEAP32[$agg$result>>2] = $201;
    STACKTOP = sp;return;
   }
   else if ((label|0) == 92) {
    $202 = ___cxa_find_matching_catch()|0;
    $203 = tempRet0;
    $204 = HEAP8[$0>>0]|0;
    $205 = $204 & 1;
    $206 = ($205<<24>>24)==(0);
    if ($206) {
     $$0 = $203;$$01 = $202;
     ___resumeException($$01|0);
     // unreachable;
    }
    $207 = HEAP32[$12>>2]|0;
    __ZdlPv($207);
    $$0 = $203;$$01 = $202;
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $208 = HEAP32[$color>>2]|0;
 HEAP32[$agg$result>>2] = $208;
 STACKTOP = sp;return;
}
function __Z14ValidateFormatRNSt3__16vectorIN20TextRenderingPrivate16TextFormatChangeENS_9allocatorIS2_EEEE($format) {
 $format = $format|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$lcssa = 0, $$lcssa16 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$format>>2]|0;
 $1 = (($format) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 L1: do {
  if ($3) {
   $$lcssa = 0;$$lcssa16 = 0;
   label = 26;
  } else {
   $10 = 0;$11 = 0;$25 = 0;$5 = $0;$57 = $2;
   L2: while(1) {
    $4 = (($5) + 40|0);
    $6 = HEAP32[$4>>2]|0;
    $7 = $6 & 32768;
    $8 = ($7|0)==(0);
    do {
     if ($8) {
      $24 = ($11|0)==($25|0);
      if (!($24)) {
       $26 = ($11|0)==(0|0);
       if (!($26)) {
        HEAP32[$11>>2] = $6;
       }
       $27 = (($11) + 4|0);
       $53 = $57;$58 = $25;$59 = $27;$60 = $10;
       break;
      }
      $28 = $11;
      $29 = $10;
      $30 = (($28) - ($29))|0;
      $31 = $30 >> 2;
      $32 = (($31) + 1)|0;
      $33 = ($32>>>0)>(1073741823);
      if ($33) {
       label = 15;
       break L2;
      }
      $36 = ($31>>>0)<(536870911);
      if ($36) {
       $37 = $30 >> 1;
       $38 = ($37>>>0)<($32>>>0);
       $39 = $38 ? $32 : $37;
       $40 = ($39|0)==(0);
       if ($40) {
        $$0$i3$i$i = 0;$46 = 0;
       } else {
        $$0$i2$i$i = $39;
        label = 19;
       }
      } else {
       $$0$i2$i$i = 1073741823;
       label = 19;
      }
      if ((label|0) == 19) {
       label = 0;
       $41 = $$0$i2$i$i << 2;
       __THREW__ = 0;
       $42 = (invoke_ii(2988,($41|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 5;
        break L2;
       }
       $$0$i3$i$i = $$0$i2$i$i;$46 = $42;
      }
      $45 = (($46) + ($31<<2)|0);
      $47 = (($46) + ($$0$i3$i$i<<2)|0);
      $48 = ($45|0)==(0|0);
      if (!($48)) {
       HEAP32[$45>>2] = $6;
      }
      $49 = (($46) + ($32<<2)|0);
      _memcpy(($46|0),($10|0),($30|0))|0;
      $50 = ($10|0)==(0|0);
      if ($50) {
       $53 = $57;$58 = $47;$59 = $49;$60 = $46;
      } else {
       __ZdlPv($10);
       $$pre = HEAP32[$1>>2]|0;
       $53 = $$pre;$58 = $47;$59 = $49;$60 = $46;
      }
     } else {
      $9 = ($10|0)==($11|0);
      if ($9) {
       $$0 = 0;$56 = $10;
       break L1;
      }
      $12 = $6 & -32769;
      $13 = (($11) + -4|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = ($14|0)==($12|0);
      if (!($15)) {
       $$0 = 0;$56 = $10;
       break L1;
      }
      $__new_last2$i$i$i = $13;
      $21 = (0 - ($__new_last2$i$i$i))|0;
      $uglygep$i$i$i = (($13) + ($21)|0);
      $uglygep3$i$i$i = $uglygep$i$i$i;
      $22 = $uglygep3$i$i$i >>> 2;
      $23 = $22 ^ -1;
      $scevgep4$i$i$i = (($11) + ($23<<2)|0);
      $53 = $57;$58 = $25;$59 = $scevgep4$i$i$i;$60 = $10;
     }
    } while(0);
    $51 = (($5) + 44|0);
    $52 = ($51|0)==($53|0);
    if ($52) {
     $$lcssa = $59;$$lcssa16 = $60;
     label = 26;
     break L1;
    } else {
     $10 = $60;$11 = $59;$25 = $58;$5 = $51;$57 = $53;
    }
   }
   do {
    if ((label|0) == 5) {
     $16 = ___cxa_find_matching_catch()|0;
     $17 = tempRet0;
     $lpad$phi$index = $16;$lpad$phi$index2 = $17;
    }
    else if ((label|0) == 15) {
     __THREW__ = 0;
     invoke_vi(3308,0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      $18 = ___cxa_find_matching_catch()|0;
      $19 = tempRet0;
      $lpad$phi$index = $18;$lpad$phi$index2 = $19;
      break;
     } else {
      // unreachable;
     }
    }
   } while(0);
   $20 = ($10|0)==(0|0);
   if ($20) {
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   __ZdlPv($10);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 26) {
  $54 = ($$lcssa16|0)==($$lcssa|0);
  $$0 = $54;$56 = $$lcssa16;
 }
 $55 = ($56|0)==(0|0);
 if ($55) {
  STACKTOP = sp;return ($$0|0);
 }
 __ZdlPv($56);
 STACKTOP = sp;return ($$0|0);
}
function __Z20ParseImageParametersR11UTF16StringRiRN20TextRenderingPrivate16TextFormatChangeE($input,$pos,$change) {
 $input = $input|0;
 $pos = $pos|0;
 $change = $change|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$01 = 0, $$31 = 0, $$32 = 0, $$33 = 0, $$34 = 0, $$35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$09$i = 0, $j$04$i = 0, $v$off$i$i = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $vararg_buffer7 = sp;
 $0 = sp + 68|0;
 $1 = sp + 56|0;
 $2 = sp + 52|0;
 $3 = sp + 80|0;
 $4 = sp + 16|0;
 $5 = sp + 4|0;
 $6 = sp + 28|0;
 $7 = sp + 40|0;
 $8 = HEAP32[$pos>>2]|0;
 $9 = (($input) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)<($10|0);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($change) + 40|0);
 $13 = (($0) + 1|0);
 $14 = (($change) + 20|0);
 $15 = (($0) + 8|0);
 $16 = (($1) + 1|0);
 $17 = (($change) + 16|0);
 $18 = (($1) + 8|0);
 $19 = (($change) + 12|0);
 $20 = (($3) + 8|0);
 $21 = (($4) + 1|0);
 $22 = (($change) + 24|0);
 $23 = (($4) + 8|0);
 $24 = (($5) + 1|0);
 $25 = (($change) + 28|0);
 $26 = (($5) + 8|0);
 $27 = (($6) + 1|0);
 $28 = (($change) + 32|0);
 $29 = (($6) + 8|0);
 $30 = (($7) + 1|0);
 $31 = (($change) + 36|0);
 $32 = (($7) + 8|0);
 $35 = $8;$48 = $10;
 L4: while(1) {
  $33 = HEAP32[$input>>2]|0;
  $34 = (($33) + ($35<<1)|0);
  $36 = HEAP16[$34>>1]|0;
  $37 = ($36<<16>>16)==(62);
  if ($37) {
   label = 38;
   break;
  } else {
   $i$09$i = 0;
  }
  while(1) {
   $38 = (805296 + ($i$09$i<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP8[$39>>0]|0;
   $41 = ($40<<24>>24)==(0);
   L8: do {
    if ($41) {
     label = 10;
    } else {
     $57 = $40;$j$04$i = 0;
     while(1) {
      $46 = (($j$04$i) + ($35))|0;
      $47 = ($46|0)==($48|0);
      if ($47) {
       break L8;
      }
      $49 = (($33) + ($46<<1)|0);
      $50 = HEAP16[$49>>1]|0;
      $51 = $50&255;
      $v$off$i$i = (($51) + -65)<<24>>24;
      $52 = ($v$off$i$i&255)<(26);
      if ($52) {
       $53 = $50&65535;
       $54 = $53 | 32;
       $55 = $54&255;
       $$0$i$i = $55;
      } else {
       $$0$i$i = $51;
      }
      $56 = ($$0$i$i<<24>>24)==($57<<24>>24);
      $43 = (($j$04$i) + 1)|0;
      if (!($56)) {
       break L8;
      }
      $42 = (($39) + ($43)|0);
      $44 = HEAP8[$42>>0]|0;
      $45 = ($44<<24>>24)==(0);
      if ($45) {
       label = 10;
       break;
      } else {
       $57 = $44;$j$04$i = $43;
      }
     }
    }
   } while(0);
   if ((label|0) == 10) {
    label = 0;
    $58 = (_strlen(($39|0))|0);
    $59 = (($58) + ($35))|0;
    $60 = (($33) + ($59<<1)|0);
    $61 = HEAP16[$60>>1]|0;
    $62 = ($61<<16>>16)==(61);
    if ($62) {
     label = 12;
     break;
    }
   }
   $63 = (($i$09$i) + 1)|0;
   $64 = ($63|0)<(10);
   if ($64) {
    $i$09$i = $63;
   } else {
    $151 = $35;
    label = 36;
    break;
   }
  }
  L19: do {
   if ((label|0) == 12) {
    label = 0;
    HEAP32[$pos>>2] = $59;
    switch ($i$09$i|0) {
    case 7:  {
     __Z12GetParameterR11UTF16StringRib($5,$input,$pos,1);
     $126 = HEAP8[$5>>0]|0;
     $127 = $126 & 1;
     $128 = ($127<<24>>24)==(0);
     $129 = HEAP32[$26>>2]|0;
     $$33 = $128 ? $24 : $129;
     HEAP32[$vararg_buffer7>>2] = $25;
     (_sscanf($$33,805704,$vararg_buffer7)|0);
     $130 = HEAP8[$5>>0]|0;
     $131 = $130 & 1;
     $132 = ($131<<24>>24)==(0);
     if ($132) {
      break L19;
     }
     $133 = HEAP32[$26>>2]|0;
     __ZdlPv($133);
     break L19;
     break;
    }
    case 3:  {
     $84 = HEAP32[$12>>2]|0;
     $85 = $84 | 8;
     HEAP32[$12>>2] = $85;
     __Z12GetParameterR11UTF16StringRib($1,$input,$pos,1);
     $86 = HEAP8[$1>>0]|0;
     $87 = $86 & 1;
     $88 = ($87<<24>>24)==(0);
     $89 = HEAP32[$18>>2]|0;
     $$31 = $88 ? $16 : $89;
     __THREW__ = 0;
     $90 = (invoke_ii(3263,($$31|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 21;
      break L4;
     }
     HEAP32[$17>>2] = $90;
     $93 = HEAP8[$1>>0]|0;
     $94 = $93 & 1;
     $95 = ($94<<24>>24)==(0);
     if ($95) {
      break L19;
     }
     $96 = HEAP32[$18>>2]|0;
     __ZdlPv($96);
     break L19;
     break;
    }
    case 8:  {
     __Z12GetParameterR11UTF16StringRib($6,$input,$pos,1);
     $134 = HEAP8[$6>>0]|0;
     $135 = $134 & 1;
     $136 = ($135<<24>>24)==(0);
     $137 = HEAP32[$29>>2]|0;
     $$34 = $136 ? $27 : $137;
     HEAP32[$vararg_buffer7>>2] = $28;
     (_sscanf($$34,805704,$vararg_buffer7)|0);
     $138 = HEAP8[$6>>0]|0;
     $139 = $138 & 1;
     $140 = ($139<<24>>24)==(0);
     if ($140) {
      break L19;
     }
     $141 = HEAP32[$29>>2]|0;
     __ZdlPv($141);
     break L19;
     break;
    }
    case 9:  {
     __Z12GetParameterR11UTF16StringRib($7,$input,$pos,1);
     $142 = HEAP8[$7>>0]|0;
     $143 = $142 & 1;
     $144 = ($143<<24>>24)==(0);
     $145 = HEAP32[$32>>2]|0;
     $$35 = $144 ? $30 : $145;
     HEAP32[$vararg_buffer7>>2] = $31;
     (_sscanf($$35,805704,$vararg_buffer7)|0);
     $146 = HEAP8[$7>>0]|0;
     $147 = $146 & 1;
     $148 = ($147<<24>>24)==(0);
     if ($148) {
      break L19;
     }
     $149 = HEAP32[$32>>2]|0;
     __ZdlPv($149);
     break L19;
     break;
    }
    case -1:  {
     $151 = $59;
     label = 36;
     break L19;
     break;
    }
    case 2:  {
     $103 = HEAP32[$12>>2]|0;
     $104 = $103 | 4;
     HEAP32[$12>>2] = $104;
     __Z12GetParameterR11UTF16StringRib($3,$input,$pos,1);
     __THREW__ = 0;
     invoke_vii(3445,($2|0),($3|0));
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      label = 26;
      break L4;
     }
     $107 = HEAP32[$2>>2]|0;
     HEAP32[$19>>2] = $107;
     $108 = HEAP8[$3>>0]|0;
     $109 = $108 & 1;
     $110 = ($109<<24>>24)==(0);
     if ($110) {
      break L19;
     }
     $111 = HEAP32[$20>>2]|0;
     __ZdlPv($111);
     break L19;
     break;
    }
    case 4:  {
     $65 = HEAP32[$12>>2]|0;
     $66 = $65 | 16;
     HEAP32[$12>>2] = $66;
     __Z12GetParameterR11UTF16StringRib($0,$input,$pos,1);
     $67 = HEAP8[$0>>0]|0;
     $68 = $67 & 1;
     $69 = ($68<<24>>24)==(0);
     $70 = HEAP32[$15>>2]|0;
     $$ = $69 ? $13 : $70;
     __THREW__ = 0;
     $71 = (invoke_ii(3263,($$|0))|0);
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      label = 16;
      break L4;
     }
     HEAP32[$14>>2] = $71;
     $74 = HEAP8[$0>>0]|0;
     $75 = $74 & 1;
     $76 = ($75<<24>>24)==(0);
     if ($76) {
      break L19;
     }
     $77 = HEAP32[$15>>2]|0;
     __ZdlPv($77);
     break L19;
     break;
    }
    case 6:  {
     __Z12GetParameterR11UTF16StringRib($4,$input,$pos,1);
     $118 = HEAP8[$4>>0]|0;
     $119 = $118 & 1;
     $120 = ($119<<24>>24)==(0);
     $121 = HEAP32[$23>>2]|0;
     $$32 = $120 ? $21 : $121;
     HEAP32[$vararg_buffer7>>2] = $22;
     (_sscanf($$32,805704,$vararg_buffer7)|0);
     $122 = HEAP8[$4>>0]|0;
     $123 = $122 & 1;
     $124 = ($123<<24>>24)==(0);
     if ($124) {
      break L19;
     }
     $125 = HEAP32[$23>>2]|0;
     __ZdlPv($125);
     break L19;
     break;
    }
    default: {
     break L19;
    }
    }
   }
  } while(0);
  if ((label|0) == 36) {
   label = 0;
   $150 = (($151) + 1)|0;
   HEAP32[$pos>>2] = $150;
  }
  $152 = HEAP32[$pos>>2]|0;
  $153 = HEAP32[$9>>2]|0;
  $154 = ($152|0)<($153|0);
  if ($154) {
   $35 = $152;$48 = $153;
  } else {
   label = 38;
   break;
  }
 }
 if ((label|0) == 16) {
  $78 = ___cxa_find_matching_catch()|0;
  $79 = tempRet0;
  $80 = HEAP8[$0>>0]|0;
  $81 = $80 & 1;
  $82 = ($81<<24>>24)==(0);
  if ($82) {
   $$0 = $79;$$01 = $78;
   ___resumeException($$01|0);
   // unreachable;
  }
  $83 = HEAP32[$15>>2]|0;
  __ZdlPv($83);
  $$0 = $79;$$01 = $78;
  ___resumeException($$01|0);
  // unreachable;
 }
 else if ((label|0) == 21) {
  $97 = ___cxa_find_matching_catch()|0;
  $98 = tempRet0;
  $99 = HEAP8[$1>>0]|0;
  $100 = $99 & 1;
  $101 = ($100<<24>>24)==(0);
  if ($101) {
   $$0 = $98;$$01 = $97;
   ___resumeException($$01|0);
   // unreachable;
  }
  $102 = HEAP32[$18>>2]|0;
  __ZdlPv($102);
  $$0 = $98;$$01 = $97;
  ___resumeException($$01|0);
  // unreachable;
 }
 else if ((label|0) == 26) {
  $112 = ___cxa_find_matching_catch()|0;
  $113 = tempRet0;
  $114 = HEAP8[$3>>0]|0;
  $115 = $114 & 1;
  $116 = ($115<<24>>24)==(0);
  if ($116) {
   $$0 = $113;$$01 = $112;
   ___resumeException($$01|0);
   // unreachable;
  }
  $117 = HEAP32[$20>>2]|0;
  __ZdlPv($117);
  $$0 = $113;$$01 = $112;
  ___resumeException($$01|0);
  // unreachable;
 }
 else if ((label|0) == 38) {
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate15GetFormatStringER11UTF16StringRNSt3__16vectorINS_16TextFormatChangeENS2_9allocatorIS4_EEEEf($input,$format,$fontSizeScale) {
 $input = $input|0;
 $format = $format|0;
 $fontSizeScale = Math_fround($fontSizeScale);
 var $$ = 0, $$0 = 0, $$01 = 0, $$14 = 0, $$pre = 0, $$pre$i = 0, $$pre$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $change = 0;
 var $closing = 0, $floorf$i$i = Math_fround(0), $pos = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $storemerge13 = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $pos = sp + 84|0;
 $closing = sp + 88|0;
 $change = sp + 12|0;
 $0 = sp + 56|0;
 $1 = sp + 68|0;
 $2 = sp + 72|0;
 $3 = sp;
 HEAP32[$pos>>2] = 0;
 $4 = (($input) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 L1: do {
  if ($6) {
   $7 = (($change) + 8|0);
   $8 = (($change) + 12|0);
   $9 = (($change) + 16|0);
   $10 = (($change) + 20|0);
   $11 = (($change) + 24|0);
   $12 = (($change) + 32|0);
   $13 = (($change) + 28|0);
   $14 = (($change) + 36|0);
   $15 = (($change) + 40|0);
   $16 = (($0) + 1|0);
   $17 = (($0) + 8|0);
   $18 = (($change) + 12|0);
   $19 = (($2) + 8|0);
   $20 = (($3) + 1|0);
   $21 = (($3) + 8|0);
   $22 = (($change) + 4|0);
   $23 = (($format) + 4|0);
   $24 = (($format) + 8|0);
   $storemerge13 = 0;
   L3: while(1) {
    $25 = (__Z6GetTagR11UTF16StringRiRb($input,$pos,$closing)|0);
    $26 = ($25|0)==(-1);
    do {
     if ($26) {
      $$pre = HEAP32[$pos>>2]|0;
      $100 = $$pre;
     } else {
      HEAP32[$7>>2] = 0;
      HEAP32[$8>>2] = -1;
      HEAP32[$9>>2] = 0;
      HEAP32[$10>>2] = 0;
      HEAPF32[$11>>2] = Math_fround(0.0);
      HEAPF32[$12>>2] = Math_fround(1.0);
      HEAPF32[$13>>2] = Math_fround(0.0);
      HEAPF32[$14>>2] = Math_fround(1.0);
      HEAP32[$15>>2] = 32768;
      switch ($25|0) {
      case 4:  {
       HEAP32[$15>>2] = 16;
       $29 = 32784;
       break;
      }
      case 5:  {
       HEAP32[$15>>2] = 32;
       $29 = 32800;
       break;
      }
      case 2:  {
       HEAP32[$15>>2] = 4;
       $29 = 32772;
       break;
      }
      case 3:  {
       HEAP32[$15>>2] = 8;
       $29 = 32776;
       break;
      }
      case 0:  {
       HEAP32[$15>>2] = 1;
       $29 = 32769;
       break;
      }
      case 1:  {
       HEAP32[$15>>2] = 2;
       $29 = 32770;
       break;
      }
      default: {
       $29 = 32768;
      }
      }
      $27 = HEAP8[$closing>>0]|0;
      $28 = ($27<<24>>24)==(0);
      do {
       if ($28) {
        if ((($25|0) == 3)) {
         __Z12GetParameterR11UTF16StringRib($0,$input,$pos,0);
         $30 = HEAP8[$0>>0]|0;
         $31 = $30 & 1;
         $32 = ($31<<24>>24)==(0);
         $33 = HEAP32[$17>>2]|0;
         $$ = $32 ? $16 : $33;
         __THREW__ = 0;
         $34 = (invoke_ii(3263,($$|0))|0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          label = 18;
          break L3;
         }
         $37 = (Math_fround(($34|0)));
         $38 = Math_fround($37 * $fontSizeScale);
         $39 = Math_fround($38 + Math_fround(0.5));
         $floorf$i$i = (Math_fround(Math_floor((Math_fround($39)))));
         $40 = (~~(($floorf$i$i)));
         HEAP32[$9>>2] = $40;
         $41 = HEAP8[$0>>0]|0;
         $42 = $41 & 1;
         $43 = ($42<<24>>24)==(0);
         if ($43) {
          break;
         }
         $44 = HEAP32[$17>>2]|0;
         __ZdlPv($44);
         break;
        } else if ((($25|0) == 2)) {
         __Z12GetParameterR11UTF16StringRib($2,$input,$pos,0);
         __THREW__ = 0;
         invoke_vii(3445,($1|0),($2|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          label = 23;
          break L3;
         }
         $53 = HEAP32[$1>>2]|0;
         HEAP32[$18>>2] = $53;
         $54 = HEAP8[$2>>0]|0;
         $55 = $54 & 1;
         $56 = ($55<<24>>24)==(0);
         if ($56) {
          break;
         }
         $57 = HEAP32[$19>>2]|0;
         __ZdlPv($57);
         break;
        } else if ((($25|0) == 5)) {
         __Z20ParseImageParametersR11UTF16StringRiRN20TextRenderingPrivate16TextFormatChangeE($input,$pos,$change);
         break;
        } else if ((($25|0) == 4)) {
         __Z12GetParameterR11UTF16StringRib($3,$input,$pos,0);
         $64 = HEAP8[$3>>0]|0;
         $65 = $64 & 1;
         $66 = ($65<<24>>24)==(0);
         $67 = HEAP32[$21>>2]|0;
         $$14 = $66 ? $20 : $67;
         __THREW__ = 0;
         $68 = (invoke_ii(3263,($$14|0))|0);
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          label = 28;
          break L3;
         }
         HEAP32[$10>>2] = $68;
         $71 = HEAP8[$3>>0]|0;
         $72 = $71 & 1;
         $73 = ($72<<24>>24)==(0);
         if ($73) {
          break;
         }
         $74 = HEAP32[$21>>2]|0;
         __ZdlPv($74);
         break;
        } else {
         break;
        }
       } else {
        HEAP32[$15>>2] = $29;
       }
      } while(0);
      $81 = HEAP32[$pos>>2]|0;
      $82 = (1 - ($storemerge13))|0;
      $83 = (($82) + ($81))|0;
      HEAP32[$22>>2] = $83;
      HEAP32[$change>>2] = $storemerge13;
      $84 = HEAP32[$23>>2]|0;
      $85 = HEAP32[$24>>2]|0;
      $86 = ($84|0)==($85|0);
      if ($86) {
       __ZNSt3__16vectorIN20TextRenderingPrivate16TextFormatChangeENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($format,$change);
      } else {
       $87 = ($84|0)==(0|0);
       if ($87) {
        $89 = 0;
       } else {
        dest=$84+0|0; src=$change+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $$pre$i9 = HEAP32[$23>>2]|0;
        $89 = $$pre$i9;
       }
       $88 = (($89) + 44|0);
       HEAP32[$23>>2] = $88;
      }
      $90 = ($25|0)==(5);
      if ($90) {
       $91 = HEAP32[$15>>2]|0;
       $92 = $91 | 32768;
       HEAP32[$15>>2] = $92;
       HEAP32[$22>>2] = 0;
       $93 = HEAP32[$23>>2]|0;
       $94 = HEAP32[$24>>2]|0;
       $95 = ($93|0)==($94|0);
       if ($95) {
        __ZNSt3__16vectorIN20TextRenderingPrivate16TextFormatChangeENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($format,$change);
        $100 = $81;
        break;
       }
       $96 = ($93|0)==(0|0);
       if ($96) {
        $98 = 0;
       } else {
        dest=$93+0|0; src=$change+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $$pre$i = HEAP32[$23>>2]|0;
        $98 = $$pre$i;
       }
       $97 = (($98) + 44|0);
       HEAP32[$23>>2] = $97;
       $100 = $81;
      } else {
       $100 = $81;
      }
     }
    } while(0);
    $99 = (($100) + 1)|0;
    HEAP32[$pos>>2] = $99;
    $101 = HEAP32[$4>>2]|0;
    $102 = ($99|0)<($101|0);
    if ($102) {
     $storemerge13 = $99;
    } else {
     break L1;
    }
   }
   if ((label|0) == 18) {
    $45 = ___cxa_find_matching_catch()|0;
    $46 = tempRet0;
    $47 = HEAP8[$0>>0]|0;
    $48 = $47 & 1;
    $49 = ($48<<24>>24)==(0);
    if ($49) {
     $$0 = $46;$$01 = $45;
     ___resumeException($$01|0);
     // unreachable;
    }
    $50 = HEAP32[$17>>2]|0;
    __ZdlPv($50);
    $$0 = $46;$$01 = $45;
    ___resumeException($$01|0);
    // unreachable;
   }
   else if ((label|0) == 23) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    $60 = HEAP8[$2>>0]|0;
    $61 = $60 & 1;
    $62 = ($61<<24>>24)==(0);
    if ($62) {
     $$0 = $59;$$01 = $58;
     ___resumeException($$01|0);
     // unreachable;
    }
    $63 = HEAP32[$19>>2]|0;
    __ZdlPv($63);
    $$0 = $59;$$01 = $58;
    ___resumeException($$01|0);
    // unreachable;
   }
   else if ((label|0) == 28) {
    $75 = ___cxa_find_matching_catch()|0;
    $76 = tempRet0;
    $77 = HEAP8[$3>>0]|0;
    $78 = $77 & 1;
    $79 = ($78<<24>>24)==(0);
    if ($79) {
     $$0 = $76;$$01 = $75;
     ___resumeException($$01|0);
     // unreachable;
    }
    $80 = HEAP32[$21>>2]|0;
    __ZdlPv($80);
    $$0 = $76;$$01 = $75;
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $103 = (__Z14ValidateFormatRNSt3__16vectorIN20TextRenderingPrivate16TextFormatChangeENS_9allocatorIS2_EEEE($format)|0);
 if ($103) {
  STACKTOP = sp;return;
 }
 $104 = HEAP32[$format>>2]|0;
 $105 = (($format) + 4|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($106|0)==($104|0);
 if ($107) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i = $104;
 $scevgep$i$i$i = (($106) + -44|0);
 $108 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($108)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $109 = (($uglygep3$i$i$i>>>0) / 44)&-1;
 $110 = $109 ^ -1;
 $scevgep4$i$i$i = (($106) + (($110*44)|0)|0);
 HEAP32[$105>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20TextRenderingPrivate16TextFormatChangeENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 44)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(97612893);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 44)&-1;
 $14 = ($13>>>0)<(48806446);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 97612893;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*44)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*44)|0)|0);
 $23 = (($22) + (($$0$i3*44)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  dest=$21+0|0; src=$__x+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $25 = (($22) + (($7*44)|0)|0);
 $26 = (($5|0) / -44)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*44)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate19NativeTextGeneratorC2ERK11UTF16StringPNS_4FontE11ColorRGBA32iRK8Vector2fbifiibfbbP13dynamic_arrayIN2UI8UIVertexELj4EE($this,$_text,$_font,$_color,$_fontSize,$_desiredExtents,$_richText,$_fontStyle,$_lineSpacing,$_alignment,$_tabSize,$_pixelCorrect,$_fontSizeScale,$_swizzleColor,$_generateOutBounds,$_verts) {
 $this = $this|0;
 $_text = $_text|0;
 $_font = $_font|0;
 $_color = $_color|0;
 $_fontSize = $_fontSize|0;
 $_desiredExtents = $_desiredExtents|0;
 $_richText = $_richText|0;
 $_fontStyle = $_fontStyle|0;
 $_lineSpacing = Math_fround($_lineSpacing);
 $_alignment = $_alignment|0;
 $_tabSize = $_tabSize|0;
 $_pixelCorrect = $_pixelCorrect|0;
 $_fontSizeScale = Math_fround($_fontSizeScale);
 $_swizzleColor = $_swizzleColor|0;
 $_generateOutBounds = $_generateOutBounds|0;
 $_verts = $_verts|0;
 var $$5 = 0, $$56 = 0, $$byval_copy = 0, $$pre$phi4$iZ2D = 0, $$pre$phi6$iZ2D = 0, $$pre$phi8$iZ2D = 0, $$sink$i$i$sink = Math_fround(0), $$sink$i$i18$sink = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0;
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $__new_last2$i$i$i$i$i = 0, $lpad$phi$index = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = (($this) + 12|0);
 $3 = (($this) + 140|0);
 $4 = (($this) + 20|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = 61;
 $7 = (($this) + 28|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 32|0);
 HEAP32[$10>>2] = 61;
 $11 = (($this) + 44|0);
 HEAP32[$11>>2] = 0;
 $12 = (($this) + 52|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 56|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 48|0);
 HEAP32[$14>>2] = 61;
 $15 = (($this) + 60|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 72|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 64|0);
 HEAP32[$18>>2] = 61;
 $19 = (($this) + 76|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 84|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 88|0);
 HEAP32[$21>>2] = 0;
 $22 = (($this) + 80|0);
 HEAP32[$22>>2] = 61;
 $23 = (($this) + 92|0);
 HEAP32[$23>>2] = 0;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 104|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 96|0);
 HEAP32[$26>>2] = 61;
 $27 = (($this) + 108|0);
 HEAP32[$27>>2] = 0;
 $28 = (($this) + 116|0);
 HEAP32[$28>>2] = 0;
 $29 = (($this) + 120|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 112|0);
 HEAP32[$30>>2] = 61;
 $31 = (($this) + 124|0);
 HEAP32[$31>>2] = 0;
 $32 = (($this) + 132|0);
 HEAP32[$32>>2] = 0;
 $33 = (($this) + 136|0);
 HEAP32[$33>>2] = 0;
 $34 = (($this) + 128|0);
 HEAP32[$34>>2] = 61;
 $35 = (($this) + 140|0);
 HEAP32[$35>>2] = $_verts;
 $36 = (($this) + 144|0);
 HEAP32[$36>>2] = $_font;
 $37 = (($this) + 148|0);
 $38 = ($_fontSize|0)!=(0);
 if ($38) {
  $39 = (Math_fround(($_fontSize|0)));
  $40 = Math_fround($39 * $_fontSizeScale);
  $41 = Math_fround($40 + Math_fround(0.5));
  $42 = !($41 >= Math_fround(0.0));
  if ($42) {
   $43 = Math_fround($41 + Math_fround(-0.999999940395355224609));
   $$sink$i$i$sink = $43;
  } else {
   $$sink$i$i$sink = $41;
  }
 } else {
  $44 = (($_font) + 32|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (Math_fround(($45|0)));
  $47 = Math_fround($46 * $_fontSizeScale);
  $48 = Math_fround($47 + Math_fround(0.5));
  $49 = !($48 >= Math_fround(0.0));
  if ($49) {
   $50 = Math_fround($48 + Math_fround(-0.999999940395355224609));
   $$sink$i$i$sink = $50;
  } else {
   $$sink$i$i$sink = $48;
  }
 }
 $51 = (~~(($$sink$i$i$sink)));
 HEAP32[$37>>2] = $51;
 $52 = (($this) + 152|0);
 __THREW__ = 0;
 invoke_vii(3446,($52|0),($_text|0));
 $53 = __THREW__; __THREW__ = 0;
 $54 = $53&1;
 do {
  if ($54) {
   $130 = ___cxa_find_matching_catch()|0;
   $131 = tempRet0;
   $$5 = $131;$$56 = $130;
  } else {
   $55 = (($this) + 164|0);
   HEAP32[$55>>2] = $_alignment;
   $56 = (($this) + 168|0);
   $57 = $_desiredExtents;
   $58 = $57;
   $59 = HEAP32[$58>>2]|0;
   $60 = (($57) + 4)|0;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = $56;
   $64 = $63;
   HEAP32[$64>>2] = $59;
   $65 = (($63) + 4)|0;
   $66 = $65;
   HEAP32[$66>>2] = $62;
   $67 = (($this) + 176|0);
   $68 = $_richText&1;
   HEAP8[$67>>0] = $68;
   $69 = (($this) + 177|0);
   $70 = $_pixelCorrect&1;
   HEAP8[$69>>0] = $70;
   $71 = (($this) + 180|0);
   HEAP32[$71>>2] = $_fontStyle;
   $72 = (($this) + 184|0);
   HEAP32[$72>>2] = $_tabSize;
   $73 = (($this) + 188|0);
   HEAPF32[$73>>2] = $_lineSpacing;
   $74 = (($this) + 192|0);
   HEAPF32[$74>>2] = $_fontSizeScale;
   $75 = (($this) + 196|0);
   $76 = $_swizzleColor&1;
   HEAP8[$75>>0] = $76;
   $77 = (($this) + 197|0);
   $78 = $_generateOutBounds&1;
   HEAP8[$77>>0] = $78;
   $79 = (($this) + 200|0);
   HEAP32[$79>>2] = 0;
   $80 = (($this) + 204|0);
   HEAP32[$80>>2] = 0;
   $81 = (($this) + 208|0);
   HEAP32[$81>>2] = -1;
   $82 = (($this) + 212|0);
   HEAP32[$82>>2] = 0;
   $83 = (($this) + 216|0);
   HEAP32[$83>>2] = 0;
   $84 = (($this) + 220|0);
   HEAP32[$84>>2] = 0;
   $85 = (($this) + 232|0);
   dest=$85+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $86 = HEAP32[$_color>>2]|0;
   if ($38) {
    $87 = (Math_fround(($_fontSize|0)));
    $88 = Math_fround($87 * $_fontSizeScale);
    $89 = Math_fround($88 + Math_fround(0.5));
    $90 = !($89 >= Math_fround(0.0));
    if ($90) {
     $91 = Math_fround($89 + Math_fround(-0.999999940395355224609));
     $$sink$i$i18$sink = $91;
    } else {
     $$sink$i$i18$sink = $89;
    }
   } else {
    $92 = (($_font) + 32|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (Math_fround(($93|0)));
    $95 = Math_fround($94 * $_fontSizeScale);
    $96 = Math_fround($95 + Math_fround(0.5));
    $97 = !($96 >= Math_fround(0.0));
    if ($97) {
     $98 = Math_fround($96 + Math_fround(-0.999999940395355224609));
     $$sink$i$i18$sink = $98;
    } else {
     $$sink$i$i18$sink = $96;
    }
   }
   $99 = (~~(($$sink$i$i18$sink)));
   $100 = (($this) + 276|0);
   HEAP32[$100>>2] = 0;
   $101 = (($this) + 280|0);
   HEAP32[$101>>2] = 0;
   $102 = (($this) + 284|0);
   HEAP32[$102>>2] = 0;
   __THREW__ = 0;
   $103 = (invoke_ii(2988,32)|0);
   $104 = __THREW__; __THREW__ = 0;
   $105 = $104&1;
   if ($105) {
    $132 = ___cxa_find_matching_catch()|0;
    $133 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3501,($52|0));
    $134 = __THREW__; __THREW__ = 0;
    $135 = $134&1;
    if (!($135)) {
     $$5 = $133;$$56 = $132;
     break;
    }
    $156 = ___cxa_find_matching_catch(0|0)|0;
    $157 = tempRet0;
    $lpad$phi$index = $156;
    ___clang_call_terminate($lpad$phi$index);
    // unreachable;
   }
   $106 = (($103) + 32|0);
   $107 = ($103|0)==(0|0);
   if ($107) {
    $$pre$phi4$iZ2D = (4);$$pre$phi6$iZ2D = (8);$$pre$phi8$iZ2D = 0;
    HEAP32[$100>>2] = $103;
    HEAP32[$101>>2] = $106;
    HEAP32[$102>>2] = $106;
    HEAP32[$$pre$phi4$iZ2D>>2] = $86;
    HEAP32[$$pre$phi6$iZ2D>>2] = $99;
    HEAP32[$$pre$phi8$iZ2D>>2] = $_fontStyle;
    $112 = (($this) + 288|0);
    $113 = (($this) + 304|0);
    ;HEAP32[$112+0>>2]=0|0;HEAP32[$112+4>>2]=0|0;HEAP32[$112+8>>2]=0|0;HEAP32[$112+12>>2]=0|0;
    HEAP8[$113>>0] = 1;
    $114 = (($this) + 308|0);
    HEAP32[$114>>2] = 0;
    $115 = (($this) + 316|0);
    HEAP32[$115>>2] = 0;
    $116 = (($this) + 320|0);
    HEAP32[$116>>2] = 0;
    $117 = (($this) + 312|0);
    HEAP32[$117>>2] = 61;
    $118 = (($this) + 324|0);
    HEAP32[$118>>2] = 0;
    $119 = (($this) + 332|0);
    HEAP32[$119>>2] = 0;
    $120 = (($this) + 336|0);
    HEAP32[$120>>2] = 0;
    $121 = (($this) + 328|0);
    HEAP32[$121>>2] = 61;
    $122 = (($this) + 340|0);
    HEAP32[$122>>2] = 0;
    $123 = (($this) + 348|0);
    HEAP32[$123>>2] = 0;
    $124 = (($this) + 352|0);
    HEAP32[$124>>2] = 0;
    $125 = (($this) + 344|0);
    HEAP32[$125>>2] = 61;
    $126 = (($this) + 356|0);
    HEAP32[$126>>2] = 0;
    $127 = (($this) + 364|0);
    HEAP32[$127>>2] = 0;
    $128 = (($this) + 368|0);
    HEAP32[$128>>2] = 0;
    $129 = (($this) + 360|0);
    HEAP32[$129>>2] = 61;
    STACKTOP = sp;return;
   }
   HEAP32[$103>>2] = 0;
   $108 = (($103) + 4|0);
   HEAP32[$108>>2] = -1;
   $109 = (($103) + 8|0);
   $110 = (($103) + 24|0);
   ;HEAP32[$109+0>>2]=0|0;HEAP32[$109+4>>2]=0|0;HEAP32[$109+8>>2]=0|0;HEAP32[$109+12>>2]=0|0;
   HEAPF32[$110>>2] = Math_fround(1.0);
   $111 = (($103) + 28|0);
   HEAPF32[$111>>2] = Math_fround(1.0);
   $$pre$phi4$iZ2D = $108;$$pre$phi6$iZ2D = $109;$$pre$phi8$iZ2D = $103;
   HEAP32[$100>>2] = $103;
   HEAP32[$101>>2] = $106;
   HEAP32[$102>>2] = $106;
   HEAP32[$$pre$phi4$iZ2D>>2] = $86;
   HEAP32[$$pre$phi6$iZ2D>>2] = $99;
   HEAP32[$$pre$phi8$iZ2D>>2] = $_fontStyle;
   $112 = (($this) + 288|0);
   $113 = (($this) + 304|0);
   ;HEAP32[$112+0>>2]=0|0;HEAP32[$112+4>>2]=0|0;HEAP32[$112+8>>2]=0|0;HEAP32[$112+12>>2]=0|0;
   HEAP8[$113>>0] = 1;
   $114 = (($this) + 308|0);
   HEAP32[$114>>2] = 0;
   $115 = (($this) + 316|0);
   HEAP32[$115>>2] = 0;
   $116 = (($this) + 320|0);
   HEAP32[$116>>2] = 0;
   $117 = (($this) + 312|0);
   HEAP32[$117>>2] = 61;
   $118 = (($this) + 324|0);
   HEAP32[$118>>2] = 0;
   $119 = (($this) + 332|0);
   HEAP32[$119>>2] = 0;
   $120 = (($this) + 336|0);
   HEAP32[$120>>2] = 0;
   $121 = (($this) + 328|0);
   HEAP32[$121>>2] = 61;
   $122 = (($this) + 340|0);
   HEAP32[$122>>2] = 0;
   $123 = (($this) + 348|0);
   HEAP32[$123>>2] = 0;
   $124 = (($this) + 352|0);
   HEAP32[$124>>2] = 0;
   $125 = (($this) + 344|0);
   HEAP32[$125>>2] = 61;
   $126 = (($this) + 356|0);
   HEAP32[$126>>2] = 0;
   $127 = (($this) + 364|0);
   HEAP32[$127>>2] = 0;
   $128 = (($this) + 368|0);
   HEAP32[$128>>2] = 0;
   $129 = (($this) + 360|0);
   HEAP32[$129>>2] = 61;
   STACKTOP = sp;return;
  }
 } while(0);
 $137 = $3;
 while(1) {
  $136 = (($137) + -16|0);
  $138 = (($137) + -4|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = ($139|0)>(-1);
  if ($140) {
   $141 = HEAP32[$136>>2]|0;
   $142 = (($137) + -12|0);
   $143 = HEAP32[$142>>2]|0;
   HEAP32[$0>>2] = $143;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($141|0),($$byval_copy|0));
   $144 = __THREW__; __THREW__ = 0;
   $145 = $144&1;
   if ($145) {
    label = 28;
    break;
   }
   HEAP32[$136>>2] = 0;
  }
  $146 = ($136|0)==($2|0);
  if ($146) {
   break;
  } else {
   $137 = $136;
  }
 }
 if ((label|0) == 28) {
  $154 = ___cxa_find_matching_catch(0|0)|0;
  $155 = tempRet0;
  $lpad$phi$index = $154;
  ___clang_call_terminate($lpad$phi$index);
  // unreachable;
 }
 $147 = HEAP32[$this>>2]|0;
 $148 = ($147|0)==(0|0);
 if ($148) {
  ___resumeException($$56|0);
  // unreachable;
 }
 $149 = HEAP32[$1>>2]|0;
 $150 = ($149|0)==($147|0);
 if (!($150)) {
  $__new_last2$i$i$i$i$i = $147;
  $scevgep$i$i$i$i$i = (($149) + -44|0);
  $151 = (0 - ($__new_last2$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($151)|0);
  $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
  $152 = (($uglygep3$i$i$i$i$i>>>0) / 44)&-1;
  $153 = $152 ^ -1;
  $scevgep4$i$i$i$i$i = (($149) + (($153*44)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i$i$i;
 }
 __ZdlPv($147);
 ___resumeException($$56|0);
 // unreachable;
}
function __ZN20TextRenderingPrivate19NativeTextGenerator5SetupEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $$0$i = Math_fround(0), $$0$i$i = Math_fround(0), $$01 = 0, $$01$i$i$i = 0, $$1 = 0, $$12 = 0, $$byval_copy12 = 0, $$minFontSize$0 = 0, $$pre = 0, $$pre56 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0);
 var $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i18 = 0, $__new_last2$i$i$i$i$i29 = 0, $__new_last2$i$i$i$i$i37 = 0, $__new_last2$i$i$i$i$i8 = 0, $columnWidth$0 = Math_fround(0), $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $floorf$i$i$i$i = Math_fround(0), $maxFontSize$053 = 0, $maxFontSize$1 = 0, $maxFontSize$2 = 0, $minFontSize$0$lcssa = 0, $minFontSize$052 = 0, $minFontSize$1 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i19 = 0, $scevgep$i$i$i$i$i30 = 0, $scevgep$i$i$i$i$i38 = 0, $scevgep$i$i$i$i$i9 = 0;
 var $scevgep4$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i13 = 0, $scevgep4$i$i$i$i$i23 = 0, $scevgep4$i$i$i$i$i34 = 0, $scevgep4$i$i$i$i$i42 = 0, $str = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i11 = 0, $uglygep$i$i$i$i$i21 = 0, $uglygep$i$i$i$i$i32 = 0, $uglygep$i$i$i$i$i40 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i12 = 0, $uglygep3$i$i$i$i$i22 = 0, $uglygep3$i$i$i$i$i33 = 0, $uglygep3$i$i$i$i$i41 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy12 = sp;
 $0 = sp + 68|0;
 $1 = sp + 64|0;
 $2 = sp + 60|0;
 $3 = sp + 56|0;
 $4 = sp + 72|0;
 $5 = sp + 28|0;
 $6 = sp + 16|0;
 $str = sp + 4|0;
 $7 = sp + 32|0;
 $8 = sp + 44|0;
 $9 = (($this) + 176|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if (!($11)) {
  $12 = (($this) + 152|0);
  $13 = (($this) + 192|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  __ZN20TextRenderingPrivate15GetFormatStringER11UTF16StringRNSt3__16vectorINS_16TextFormatChangeENS2_9allocatorIS4_EEEEf($12,$this,$14);
 }
 $15 = (($this) + 148|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 228|0);
 HEAP32[$17>>2] = 1;
 $18 = HEAP32[$this>>2]|0;
 $19 = (($this) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($18|0)==($20|0);
 do {
  if ($21) {
   $74 = $16;$minFontSize$0$lcssa = 2147483647;
  } else {
   $22 = (($6) + 1|0);
   $23 = (($6) + 8|0);
   $24 = (($this) + 192|0);
   $26 = $18;$304 = 1;$maxFontSize$053 = $16;$minFontSize$052 = 2147483647;
   while(1) {
    $25 = (($26) + 40|0);
    $27 = HEAP32[$25>>2]|0;
    $28 = $27 & 8;
    $29 = ($28|0)==(0);
    if ($29) {
     $maxFontSize$2 = $maxFontSize$053;$minFontSize$1 = $minFontSize$052;
    } else {
     $30 = (($26) + 16|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==(0);
     if ($32) {
      $36 = HEAP32[$15>>2]|0;
      $37 = (Math_fround(($36|0)));
      $40 = $37;
     } else {
      $33 = (Math_fround(($31|0)));
      $34 = Math_fround(HEAPF32[$24>>2]);
      $35 = Math_fround($33 * $34);
      $40 = $35;
     }
     $38 = (Math_fround(($maxFontSize$053|0)));
     $39 = $40 > $38;
     if ($39) {
      $41 = (~~(($40)));
      $maxFontSize$1 = $41;
     } else {
      $maxFontSize$1 = $maxFontSize$053;
     }
     $42 = (Math_fround(($minFontSize$052|0)));
     $43 = $40 < $42;
     if ($43) {
      $44 = (~~(($40)));
      $maxFontSize$2 = $maxFontSize$1;$minFontSize$1 = $44;
     } else {
      $maxFontSize$2 = $maxFontSize$1;$minFontSize$1 = $minFontSize$052;
     }
    }
    $45 = $27 & 48;
    $46 = ($45|0)==(0);
    if ($46) {
     $305 = $304;
    } else {
     $47 = (($26) + 20|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48>>>0)>(7);
     if ($49) {
      HEAP32[$$byval_copy12>>2] = 8;
      __Z6FormatPKcz($6,805712,$$byval_copy12);
      $50 = HEAP8[$6>>0]|0;
      $51 = $50 & 1;
      $52 = ($51<<24>>24)==(0);
      $53 = HEAP32[$23>>2]|0;
      $$ = $52 ? $22 : $53;
      __THREW__ = 0;
      invoke_viiiiiiii(21,($$|0),0,(805760|0),190,512,0,0,(0|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      $56 = HEAP8[$6>>0]|0;
      $57 = $56 & 1;
      $58 = ($57<<24>>24)==(0);
      if (!($58)) {
       $59 = HEAP32[$23>>2]|0;
       __ZdlPv($59);
      }
      HEAP32[$47>>2] = 0;
      $$pre56 = HEAP32[$17>>2]|0;
      $67 = 0;$68 = $$pre56;
     } else {
      $67 = $48;$68 = $304;
     }
     $66 = ($67|0)<($68|0);
     if ($66) {
      $305 = $68;
     } else {
      $69 = (($67) + 1)|0;
      HEAP32[$17>>2] = $69;
      $305 = $69;
     }
    }
    $70 = (($26) + 44|0);
    $71 = HEAP32[$19>>2]|0;
    $72 = ($70|0)==($71|0);
    if ($72) {
     label = 24;
     break;
    } else {
     $26 = $70;$304 = $305;$maxFontSize$053 = $maxFontSize$2;$minFontSize$052 = $minFontSize$1;
    }
   }
   if ((label|0) == 24) {
    $$pre = HEAP32[$15>>2]|0;
    $74 = $$pre;$minFontSize$0$lcssa = $minFontSize$1;
    break;
   }
   $60 = ___cxa_find_matching_catch()|0;
   $61 = tempRet0;
   $62 = HEAP8[$6>>0]|0;
   $63 = $62 & 1;
   $64 = ($63<<24>>24)==(0);
   if ($64) {
    $$1 = $61;$$12 = $60;
    ___resumeException($$12|0);
    // unreachable;
   }
   $65 = HEAP32[$23>>2]|0;
   __ZdlPv($65);
   $$1 = $61;$$12 = $60;
   ___resumeException($$12|0);
   // unreachable;
  }
 } while(0);
 $73 = ($74|0)<($minFontSize$0$lcssa|0);
 $$minFontSize$0 = $73 ? $74 : $minFontSize$0$lcssa;
 __ZN11UTF16StringC2EPKc($str,805768);
 $75 = (($this) + 144|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = HEAP32[$str>>2]|0;
 $78 = (($str) + 4|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = HEAP32[$15>>2]|0;
 $81 = (($this) + 180|0);
 $82 = HEAP32[$81>>2]|0;
 HEAP32[$7>>2] = 0;
 $83 = (($7) + 4|0);
 HEAP32[$83>>2] = 0;
 $84 = (($7) + 8|0);
 HEAP32[$84>>2] = 0;
 __THREW__ = 0;
 (invoke_iiiiiii(124,($76|0),($77|0),($79|0),($80|0),($82|0),($7|0))|0);
 $85 = __THREW__; __THREW__ = 0;
 $86 = $85&1;
 do {
  if ($86) {
   $175 = ___cxa_find_matching_catch()|0;
   $176 = tempRet0;
   $177 = HEAP32[$7>>2]|0;
   $178 = ($177|0)==(0|0);
   if ($178) {
    $$0 = $176;$$01 = $175;
   } else {
    $179 = HEAP32[$83>>2]|0;
    $180 = ($179|0)==($177|0);
    if (!($180)) {
     $__new_last2$i$i$i$i$i8 = $177;
     $scevgep$i$i$i$i$i9 = (($179) + -44|0);
     $181 = (0 - ($__new_last2$i$i$i$i$i8))|0;
     $uglygep$i$i$i$i$i11 = (($scevgep$i$i$i$i$i9) + ($181)|0);
     $uglygep3$i$i$i$i$i12 = $uglygep$i$i$i$i$i11;
     $182 = (($uglygep3$i$i$i$i$i12>>>0) / 44)&-1;
     $183 = $182 ^ -1;
     $scevgep4$i$i$i$i$i13 = (($179) + (($183*44)|0)|0);
     HEAP32[$83>>2] = $scevgep4$i$i$i$i$i13;
    }
    __ZdlPv($177);
    $$0 = $176;$$01 = $175;
   }
  } else {
   $87 = HEAP32[$7>>2]|0;
   $88 = ($87|0)==(0|0);
   if (!($88)) {
    $89 = HEAP32[$83>>2]|0;
    $90 = ($89|0)==($87|0);
    if (!($90)) {
     $__new_last2$i$i$i$i$i37 = $87;
     $scevgep$i$i$i$i$i38 = (($89) + -44|0);
     $91 = (0 - ($__new_last2$i$i$i$i$i37))|0;
     $uglygep$i$i$i$i$i40 = (($scevgep$i$i$i$i$i38) + ($91)|0);
     $uglygep3$i$i$i$i$i41 = $uglygep$i$i$i$i$i40;
     $92 = (($uglygep3$i$i$i$i$i41>>>0) / 44)&-1;
     $93 = $92 ^ -1;
     $scevgep4$i$i$i$i$i42 = (($89) + (($93*44)|0)|0);
     HEAP32[$83>>2] = $scevgep4$i$i$i$i$i42;
    }
    __ZdlPv($87);
   }
   $94 = HEAP32[$75>>2]|0;
   $95 = (($this) + 152|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = (($this) + 156|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = HEAP32[$15>>2]|0;
   $100 = HEAP32[$81>>2]|0;
   HEAP32[$8>>2] = 0;
   $101 = (($8) + 4|0);
   HEAP32[$101>>2] = 0;
   $102 = (($8) + 8|0);
   HEAP32[$102>>2] = 0;
   $103 = HEAP32[$19>>2]|0;
   $104 = HEAP32[$this>>2]|0;
   $105 = $103;
   $106 = $104;
   $107 = (($105) - ($106))|0;
   $108 = (($107|0) / 44)&-1;
   $109 = ($103|0)==($104|0);
   do {
    if ($109) {
     label = 44;
    } else {
     $110 = ($108>>>0)>(97612893);
     if ($110) {
      __THREW__ = 0;
      invoke_vi(3308,0);
      $111 = __THREW__; __THREW__ = 0;
      $112 = $111&1;
      if (!($112)) {
       // unreachable;
      }
     } else {
      __THREW__ = 0;
      $113 = (invoke_ii(2988,($107|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if (!($115)) {
       HEAP32[$101>>2] = $113;
       HEAP32[$8>>2] = $113;
       $116 = (($113) + (($108*44)|0)|0);
       HEAP32[$102>>2] = $116;
       $$01$i$i$i = $104;$118 = $113;
       while(1) {
        $117 = ($118|0)==(0|0);
        if ($117) {
         $120 = 0;
        } else {
         dest=$118+0|0; src=$$01$i$i$i+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
         $120 = $118;
        }
        $119 = (($120) + 44|0);
        $121 = (($$01$i$i$i) + 44|0);
        $122 = ($121|0)==($103|0);
        if ($122) {
         break;
        } else {
         $$01$i$i$i = $121;$118 = $119;
        }
       }
       HEAP32[$101>>2] = $119;
       label = 44;
       break;
      }
     }
     $123 = ___cxa_find_matching_catch()|0;
     $124 = tempRet0;
     $125 = HEAP32[$8>>2]|0;
     $126 = ($125|0)==(0|0);
     if ($126) {
      $eh$lpad$body$index3Z2D = $124;$eh$lpad$body$indexZ2D = $123;
     } else {
      $127 = HEAP32[$101>>2]|0;
      $128 = ($127|0)==($125|0);
      if (!($128)) {
       $__new_last2$i$i$i$i$i29 = $125;
       $scevgep$i$i$i$i$i30 = (($127) + -44|0);
       $129 = (0 - ($__new_last2$i$i$i$i$i29))|0;
       $uglygep$i$i$i$i$i32 = (($scevgep$i$i$i$i$i30) + ($129)|0);
       $uglygep3$i$i$i$i$i33 = $uglygep$i$i$i$i$i32;
       $130 = (($uglygep3$i$i$i$i$i33>>>0) / 44)&-1;
       $131 = $130 ^ -1;
       $scevgep4$i$i$i$i$i34 = (($127) + (($131*44)|0)|0);
       HEAP32[$101>>2] = $scevgep4$i$i$i$i$i34;
      }
      __ZdlPv($125);
      $eh$lpad$body$index3Z2D = $124;$eh$lpad$body$indexZ2D = $123;
     }
    }
   } while(0);
   if ((label|0) == 44) {
    __THREW__ = 0;
    (invoke_iiiiiii(124,($94|0),($96|0),($98|0),($99|0),($100|0),($8|0))|0);
    $132 = __THREW__; __THREW__ = 0;
    $133 = $132&1;
    if ($133) {
     $184 = ___cxa_find_matching_catch()|0;
     $185 = tempRet0;
     $186 = HEAP32[$8>>2]|0;
     $187 = ($186|0)==(0|0);
     if ($187) {
      $$0 = $185;$$01 = $184;
      break;
     }
     $188 = HEAP32[$101>>2]|0;
     $189 = ($188|0)==($186|0);
     if (!($189)) {
      $__new_last2$i$i$i$i$i = $186;
      $scevgep$i$i$i$i$i = (($188) + -44|0);
      $190 = (0 - ($__new_last2$i$i$i$i$i))|0;
      $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($190)|0);
      $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
      $191 = (($uglygep3$i$i$i$i$i>>>0) / 44)&-1;
      $192 = $191 ^ -1;
      $scevgep4$i$i$i$i$i = (($188) + (($192*44)|0)|0);
      HEAP32[$101>>2] = $scevgep4$i$i$i$i$i;
     }
     __ZdlPv($186);
     $$0 = $185;$$01 = $184;
     break;
    }
    $134 = HEAP32[$8>>2]|0;
    $135 = ($134|0)==(0|0);
    if (!($135)) {
     $136 = HEAP32[$101>>2]|0;
     $137 = ($136|0)==($134|0);
     if (!($137)) {
      $__new_last2$i$i$i$i$i18 = $134;
      $scevgep$i$i$i$i$i19 = (($136) + -44|0);
      $138 = (0 - ($__new_last2$i$i$i$i$i18))|0;
      $uglygep$i$i$i$i$i21 = (($scevgep$i$i$i$i$i19) + ($138)|0);
      $uglygep3$i$i$i$i$i22 = $uglygep$i$i$i$i$i21;
      $139 = (($uglygep3$i$i$i$i$i22>>>0) / 44)&-1;
      $140 = $139 ^ -1;
      $scevgep4$i$i$i$i$i23 = (($136) + (($140*44)|0)|0);
      HEAP32[$101>>2] = $scevgep4$i$i$i$i$i23;
     }
     __ZdlPv($134);
    }
    $141 = HEAP32[$75>>2]|0;
    $142 = HEAP32[$15>>2]|0;
    $143 = HEAP32[$81>>2]|0;
    __THREW__ = 0;
    $144 = (Math_fround(+(invoke_fiiii(2,($141|0),32,($142|0),($143|0)))));
    $145 = __THREW__; __THREW__ = 0;
    $146 = $145&1;
    L79: do {
     if (!($146)) {
      $147 = $144 == Math_fround(0.0);
      $columnWidth$0 = $147 ? Math_fround(4.0) : $144;
      $148 = (($this) + 184|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = (Math_fround(($149|0)));
      $151 = Math_fround($columnWidth$0 * $150);
      $152 = (~~(($151)));
      HEAP32[$148>>2] = $152;
      $153 = HEAP32[$75>>2]|0;
      $154 = ($$minFontSize$0|0)==(0);
      if ($154) {
       label = 52;
      } else {
       $155 = (($153) + 32|0);
       $156 = HEAP32[$155>>2]|0;
       $157 = ($156|0)==(0);
       if ($157) {
        label = 52;
       } else {
        $160 = (($153) + 28|0);
        $161 = Math_fround(HEAPF32[$160>>2]);
        $162 = (Math_fround(($$minFontSize$0|0)));
        $163 = Math_fround($162 * $161);
        $164 = (Math_fround(($156|0)));
        $165 = Math_fround($163 / $164);
        $$0$i = $165;
       }
      }
      if ((label|0) == 52) {
       $158 = (($153) + 28|0);
       $159 = Math_fround(HEAPF32[$158>>2]);
       $$0$i = $159;
      }
      $166 = (($this) + 188|0);
      $167 = Math_fround(HEAPF32[$166>>2]);
      $168 = Math_fround($$0$i * $167);
      $169 = (($this) + 177|0);
      $170 = HEAP8[$169>>0]|0;
      $171 = ($170<<24>>24)==(0);
      if ($171) {
       $$0$i$i = $168;
      } else {
       $172 = Math_fround($168 + Math_fround(0.5));
       $floorf$i$i$i$i = (Math_fround(Math_floor((Math_fround($172)))));
       $$0$i$i = $floorf$i$i$i$i;
      }
      $193 = (($this) + 232|0);
      HEAPF32[$193>>2] = $$0$i$i;
      $194 = (($this) + 288|0);
      HEAPF32[$194>>2] = $$0$i$i;
      $195 = (($this) + 292|0);
      $196 = HEAP32[$195>>2]|0;
      $197 = (($this) + 296|0);
      $198 = HEAP32[$197>>2]|0;
      $199 = ($198|0)==($196|0);
      if (!($199)) {
       $__new_last2$i$i$i = $196;
       $scevgep$i$i$i = (($198) + -4|0);
       $200 = (0 - ($__new_last2$i$i$i))|0;
       $uglygep$i$i$i = (($scevgep$i$i$i) + ($200)|0);
       $uglygep3$i$i$i = $uglygep$i$i$i;
       $201 = $uglygep3$i$i$i >>> 2;
       $202 = $201 ^ -1;
       $scevgep4$i$i$i = (($198) + ($202<<2)|0);
       HEAP32[$197>>2] = $scevgep4$i$i$i;
      }
      $203 = (($this) + 264|0);
      HEAPF32[$203>>2] = Math_fround(0.0);
      $204 = (($this) + 268|0);
      HEAPF32[$204>>2] = Math_fround(0.0);
      $205 = (($this) + 272|0);
      HEAPF32[$205>>2] = Math_fround(0.0);
      $206 = HEAP32[$97>>2]|0;
      $207 = (($this) + 224|0);
      HEAP32[$207>>2] = $206;
      $208 = $206 << 2;
      $209 = (($208) + 4)|0;
      $210 = ($209|0)>(65535);
      if ($210) {
       __THREW__ = 0;
       invoke_viiiiiiii(21,(805776|0),0,(805760|0),227,1,0,0,(0|0));
       $211 = __THREW__; __THREW__ = 0;
       $212 = $211&1;
       if ($212) {
        break;
       }
       HEAP32[$207>>2] = 16382;
       $215 = 16382;
      } else {
       $215 = $206;
      }
      $213 = (($this) + 308|0);
      $214 = (($215) + 1)|0;
      $216 = (($this) + 316|0);
      HEAP32[$216>>2] = $214;
      $217 = (($this) + 320|0);
      $218 = HEAP32[$217>>2]|0;
      $219 = $218 & 2147483647;
      $220 = ($219>>>0)<($214>>>0);
      do {
       if ($220) {
        $221 = ($218|0)>(-1);
        if ($221) {
         HEAP32[$217>>2] = $214;
         $222 = HEAP32[$213>>2]|0;
         $223 = $214 << 3;
         $224 = (($this) + 312|0);
         $225 = HEAP32[$224>>2]|0;
         HEAP32[$0>>2] = $225;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$0+0>>2]|0;
         $226 = (invoke_iiiiiiii(108,($222|0),($223|0),4,($$byval_copy12|0),0,(805760|0),370)|0);
         $227 = __THREW__; __THREW__ = 0;
         $228 = $227&1;
         if ($228) {
          break L79;
         }
         HEAP32[$213>>2] = $226;
         break;
        } else {
         $229 = $214 << 3;
         $230 = (($this) + 312|0);
         $231 = HEAP32[$230>>2]|0;
         HEAP32[$1>>2] = $231;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
         $232 = (invoke_iiiiiii(102,($229|0),4,($$byval_copy12|0),0,(805760|0),352)|0);
         $233 = __THREW__; __THREW__ = 0;
         $234 = $233&1;
         if ($234) {
          break L79;
         }
         $235 = HEAP32[$213>>2]|0;
         $236 = HEAP32[$216>>2]|0;
         $237 = $236 << 3;
         _memcpy(($232|0),($235|0),($237|0))|0;
         HEAP32[$217>>2] = $214;
         HEAP32[$213>>2] = $232;
         break;
        }
       }
      } while(0);
      $238 = (($this) + 356|0);
      $239 = HEAP32[$207>>2]|0;
      $240 = (($239) + 1)|0;
      $241 = (($this) + 364|0);
      HEAP32[$241>>2] = $240;
      $242 = (($this) + 368|0);
      $243 = HEAP32[$242>>2]|0;
      $244 = $243 & 2147483647;
      $245 = ($244>>>0)<($240>>>0);
      do {
       if ($245) {
        $246 = ($243|0)>(-1);
        if ($246) {
         HEAP32[$242>>2] = $240;
         $247 = HEAP32[$238>>2]|0;
         $248 = $240 << 2;
         $249 = (($this) + 360|0);
         $250 = HEAP32[$249>>2]|0;
         HEAP32[$2>>2] = $250;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
         $251 = (invoke_iiiiiiii(108,($247|0),($248|0),4,($$byval_copy12|0),0,(805760|0),370)|0);
         $252 = __THREW__; __THREW__ = 0;
         $253 = $252&1;
         if ($253) {
          break L79;
         }
         HEAP32[$238>>2] = $251;
         break;
        } else {
         $254 = $240 << 2;
         $255 = (($this) + 360|0);
         $256 = HEAP32[$255>>2]|0;
         HEAP32[$3>>2] = $256;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$3+0>>2]|0;
         $257 = (invoke_iiiiiii(102,($254|0),4,($$byval_copy12|0),0,(805760|0),352)|0);
         $258 = __THREW__; __THREW__ = 0;
         $259 = $258&1;
         if ($259) {
          break L79;
         }
         $260 = HEAP32[$238>>2]|0;
         $261 = HEAP32[$241>>2]|0;
         $262 = $261 << 2;
         _memcpy(($257|0),($260|0),($262|0))|0;
         HEAP32[$242>>2] = $240;
         HEAP32[$238>>2] = $257;
         break;
        }
       }
      } while(0);
      $263 = (($this) + 140|0);
      $264 = HEAP32[$263>>2]|0;
      $265 = HEAP32[$207>>2]|0;
      $266 = $265 << 2;
      $267 = (($266) + 4)|0;
      $268 = (($264) + 8|0);
      HEAP32[$268>>2] = $267;
      $269 = (($264) + 12|0);
      $270 = HEAP32[$269>>2]|0;
      $271 = $270 & 2147483647;
      $272 = ($271>>>0)<($267>>>0);
      if (!($272)) {
       $290 = HEAP32[$263>>2]|0;
       $291 = HEAP32[$290>>2]|0;
       $292 = (($this) + 372|0);
       HEAP32[$292>>2] = $291;
       $293 = (($this) + 376|0);
       HEAP32[$293>>2] = $291;
       $294 = Math_fround(HEAPF32[$194>>2]);
       $295 = (($this) + 172|0);
       $296 = Math_fround(HEAPF32[$295>>2]);
       $297 = $294 <= $296;
       $298 = (($this) + 304|0);
       $299 = $297&1;
       HEAP8[$298>>0] = $299;
       __ZN11UTF16StringD2Ev($str);
       STACKTOP = sp;return ($297|0);
      }
      $273 = ($270|0)>(-1);
      if ($273) {
       HEAP32[$269>>2] = $267;
       $274 = HEAP32[$264>>2]|0;
       $275 = ($267*60)|0;
       $276 = (($264) + 4|0);
       $277 = HEAP32[$276>>2]|0;
       HEAP32[$4>>2] = $277;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
       $278 = (invoke_iiiiiiii(108,($274|0),($275|0),4,($$byval_copy12|0),0,(805760|0),370)|0);
       $279 = __THREW__; __THREW__ = 0;
       $280 = $279&1;
       if ($280) {
        break;
       }
       HEAP32[$264>>2] = $278;
       $290 = HEAP32[$263>>2]|0;
       $291 = HEAP32[$290>>2]|0;
       $292 = (($this) + 372|0);
       HEAP32[$292>>2] = $291;
       $293 = (($this) + 376|0);
       HEAP32[$293>>2] = $291;
       $294 = Math_fround(HEAPF32[$194>>2]);
       $295 = (($this) + 172|0);
       $296 = Math_fround(HEAPF32[$295>>2]);
       $297 = $294 <= $296;
       $298 = (($this) + 304|0);
       $299 = $297&1;
       HEAP8[$298>>0] = $299;
       __ZN11UTF16StringD2Ev($str);
       STACKTOP = sp;return ($297|0);
      } else {
       $281 = ($267*60)|0;
       $282 = (($264) + 4|0);
       $283 = HEAP32[$282>>2]|0;
       HEAP32[$5>>2] = $283;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$5+0>>2]|0;
       $284 = (invoke_iiiiiii(102,($281|0),4,($$byval_copy12|0),0,(805760|0),352)|0);
       $285 = __THREW__; __THREW__ = 0;
       $286 = $285&1;
       if ($286) {
        break;
       }
       $287 = HEAP32[$264>>2]|0;
       $288 = HEAP32[$268>>2]|0;
       $289 = ($288*60)|0;
       _memcpy(($284|0),($287|0),($289|0))|0;
       HEAP32[$269>>2] = $267;
       HEAP32[$264>>2] = $284;
       $290 = HEAP32[$263>>2]|0;
       $291 = HEAP32[$290>>2]|0;
       $292 = (($this) + 372|0);
       HEAP32[$292>>2] = $291;
       $293 = (($this) + 376|0);
       HEAP32[$293>>2] = $291;
       $294 = Math_fround(HEAPF32[$194>>2]);
       $295 = (($this) + 172|0);
       $296 = Math_fround(HEAPF32[$295>>2]);
       $297 = $294 <= $296;
       $298 = (($this) + 304|0);
       $299 = $297&1;
       HEAP8[$298>>0] = $299;
       __ZN11UTF16StringD2Ev($str);
       STACKTOP = sp;return ($297|0);
      }
     }
    } while(0);
    $173 = ___cxa_find_matching_catch()|0;
    $174 = tempRet0;
    $eh$lpad$body$index3Z2D = $174;$eh$lpad$body$indexZ2D = $173;
   }
   $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3501,($str|0));
 $300 = __THREW__; __THREW__ = 0;
 $301 = $300&1;
 if ($301) {
  $302 = ___cxa_find_matching_catch(0|0)|0;
  $303 = tempRet0;
  ___clang_call_terminate($302);
  // unreachable;
 } else {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$12|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN20TextRenderingPrivate19NativeTextGenerator15RegisterNewLineEif($this,$startOfCurrentLine,$currentLineHeight) {
 $this = $this|0;
 $startOfCurrentLine = $startOfCurrentLine|0;
 $currentLineHeight = Math_fround($currentLineHeight);
 var $$byval_copy3 = 0, $$pre$i$i = 0, $$pre$i$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 324|0);
 $2 = (($this) + 332|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 336|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if ($8) {
  $9 = $6 << 1;
  $10 = ($9|0)==(0);
  $11 = $10 ? 1 : $9;
  $12 = ($7>>>0)<($11>>>0);
  do {
   if ($12) {
    $13 = ($6|0)>(-1);
    if ($13) {
     HEAP32[$5>>2] = $11;
     $14 = HEAP32[$1>>2]|0;
     $15 = $11 << 2;
     $16 = (($this) + 328|0);
     $17 = HEAP32[$16>>2]|0;
     HEAP32[$0>>2] = $17;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy3,0,805760,370)|0);
     HEAP32[$1>>2] = $18;
     break;
    } else {
     $19 = $11 << 2;
     $20 = (($this) + 328|0);
     $21 = HEAP32[$20>>2]|0;
     HEAP32[$0>>2] = $21;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy3,0,805760,352)|0);
     $23 = HEAP32[$1>>2]|0;
     $24 = HEAP32[$2>>2]|0;
     $25 = $24 << 2;
     _memcpy(($22|0),($23|0),($25|0))|0;
     HEAP32[$5>>2] = $11;
     HEAP32[$1>>2] = $22;
     break;
    }
   }
  } while(0);
  $$pre$i$i = HEAP32[$2>>2]|0;
  $27 = $$pre$i$i;
 } else {
  $27 = $4;
 }
 $26 = (($27) + -1)|0;
 $28 = HEAP32[$1>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAP32[$29>>2] = $startOfCurrentLine;
 $30 = (($this) + 340|0);
 $31 = (($this) + 348|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 1)|0;
 HEAP32[$31>>2] = $33;
 $34 = (($this) + 352|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35 & 2147483647;
 $37 = ($33>>>0)>($36>>>0);
 if (!($37)) {
  $56 = $33;
  $55 = (($56) + -1)|0;
  $57 = HEAP32[$30>>2]|0;
  $58 = (($57) + ($55<<2)|0);
  HEAPF32[$58>>2] = $currentLineHeight;
  STACKTOP = sp;return;
 }
 $38 = $35 << 1;
 $39 = ($38|0)==(0);
 $40 = $39 ? 1 : $38;
 $41 = ($36>>>0)<($40>>>0);
 do {
  if ($41) {
   $42 = ($35|0)>(-1);
   if ($42) {
    HEAP32[$34>>2] = $40;
    $43 = HEAP32[$30>>2]|0;
    $44 = $40 << 2;
    $45 = (($this) + 344|0);
    $46 = HEAP32[$45>>2]|0;
    HEAP32[$0>>2] = $46;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $47 = (__Z16realloc_internalPvji10MemLabelIdiPKci($43,$44,4,$$byval_copy3,0,805760,370)|0);
    HEAP32[$30>>2] = $47;
    break;
   } else {
    $48 = $40 << 2;
    $49 = (($this) + 344|0);
    $50 = HEAP32[$49>>2]|0;
    HEAP32[$0>>2] = $50;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $51 = (__Z15malloc_internaljj10MemLabelIdiPKci($48,4,$$byval_copy3,0,805760,352)|0);
    $52 = HEAP32[$30>>2]|0;
    $53 = HEAP32[$31>>2]|0;
    $54 = $53 << 2;
    _memcpy(($51|0),($52|0),($54|0))|0;
    HEAP32[$34>>2] = $40;
    HEAP32[$30>>2] = $51;
    break;
   }
  }
 } while(0);
 $$pre$i$i1 = HEAP32[$31>>2]|0;
 $56 = $$pre$i$i1;
 $55 = (($56) + -1)|0;
 $57 = HEAP32[$30>>2]|0;
 $58 = (($57) + ($55<<2)|0);
 HEAPF32[$58>>2] = $currentLineHeight;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate19NativeTextGenerator15InsertLineBreakEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i = Math_fround(0), $$0$i$i$i = Math_fround(0), $$013$i$i = 0, $$013$i11$i = 0, $$025$i = 0, $$025$i$i = 0, $$025$i6$i = 0, $$04$i$i = 0, $$04$i10$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = Math_fround(0);
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0);
 var $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0);
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0;
 var $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $didItFit$0$off0 = 0, $floorf$i$i$i$i$i = Math_fround(0), $floorf$i$i$i$i$i2 = Math_fround(0), $vertexCount$06$i = 0, $vertexCount$06$i$i = 0, $vertexCount$06$i5$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 372|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 60|0);
 $3 = (($1) + 120|0);
 $4 = (($1) + 180|0);
 $5 = (($this) + 264|0);
 ;HEAP32[$4+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$5+8>>2]|0;
 _memmove(($3|0),($5|0),12)|0;
 ;HEAP32[$2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$3+8>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$3+8>>2]|0;
 $6 = HEAP32[$0>>2]|0;
 $7 = (($6) + 240|0);
 HEAP32[$0>>2] = $7;
 $8 = (($this) + 204|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 356|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($9<<2)|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($this) + 236|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($this) + 216|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 << 2;
 $18 = (($this) + 376|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + (($17*60)|0)|0);
 $21 = (($this) + 308|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + ($16<<3)|0);
 $24 = (($9) - ($16))|0;
 $25 = (($24) + 1)|0;
 $26 = (($this) + 164|0);
 $27 = HEAP32[$26>>2]|0;
 if ((($27|0) == 1)) {
  $47 = Math_fround($14 * Math_fround(-0.5));
  $48 = (($this) + 177|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = ($49<<24>>24)==(0);
  if ($50) {
   $$0$i$i$i = $47;
  } else {
   $51 = Math_fround($47 + Math_fround(0.5));
   $floorf$i$i$i$i$i2 = (Math_fround(Math_floor((Math_fround($51)))));
   $$0$i$i$i = $floorf$i$i$i$i$i2;
  }
  $52 = ($25|0)==(0);
  if (!($52)) {
   $53 = $25 << 2;
   $$025$i$i = $20;$vertexCount$06$i$i = $53;
   while(1) {
    $54 = (($vertexCount$06$i$i) + -1)|0;
    $55 = Math_fround(HEAPF32[$$025$i$i>>2]);
    $56 = Math_fround($$0$i$i$i + $55);
    HEAPF32[$$025$i$i>>2] = $56;
    $57 = (($$025$i$i) + 4|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($58 + Math_fround(0.0));
    HEAPF32[$57>>2] = $59;
    $60 = (($$025$i$i) + 60|0);
    $61 = ($54|0)==(0);
    if ($61) {
     break;
    } else {
     $$025$i$i = $60;$vertexCount$06$i$i = $54;
    }
   }
   $62 = ($23|0)==(0|0);
   if (!($62)) {
    $$013$i$i = $23;$$04$i$i = $25;
    while(1) {
     $63 = (($$04$i$i) + -1)|0;
     $64 = Math_fround(HEAPF32[$$013$i$i>>2]);
     $65 = Math_fround($$0$i$i$i + $64);
     HEAPF32[$$013$i$i>>2] = $65;
     $66 = (($$013$i$i) + 4|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = Math_fround($67 + Math_fround(0.0));
     HEAPF32[$66>>2] = $68;
     $69 = (($$013$i$i) + 8|0);
     $70 = ($63|0)==(0);
     if ($70) {
      break;
     } else {
      $$013$i$i = $69;$$04$i$i = $63;
     }
    }
   }
  }
 } else if ((($27|0) == 2)) {
  $28 = ($25|0)==(0);
  if (!($28)) {
   $29 = $25 << 2;
   $$025$i6$i = $20;$vertexCount$06$i5$i = $29;
   while(1) {
    $30 = (($vertexCount$06$i5$i) + -1)|0;
    $31 = Math_fround(HEAPF32[$$025$i6$i>>2]);
    $32 = Math_fround($31 - $14);
    HEAPF32[$$025$i6$i>>2] = $32;
    $33 = (($$025$i6$i) + 4|0);
    $34 = Math_fround(HEAPF32[$33>>2]);
    $35 = Math_fround($34 + Math_fround(0.0));
    HEAPF32[$33>>2] = $35;
    $36 = (($$025$i6$i) + 60|0);
    $37 = ($30|0)==(0);
    if ($37) {
     break;
    } else {
     $$025$i6$i = $36;$vertexCount$06$i5$i = $30;
    }
   }
   $38 = ($23|0)==(0|0);
   if (!($38)) {
    $$013$i11$i = $23;$$04$i10$i = $25;
    while(1) {
     $39 = (($$04$i10$i) + -1)|0;
     $40 = Math_fround(HEAPF32[$$013$i11$i>>2]);
     $41 = Math_fround($40 - $14);
     HEAPF32[$$013$i11$i>>2] = $41;
     $42 = (($$013$i11$i) + 4|0);
     $43 = Math_fround(HEAPF32[$42>>2]);
     $44 = Math_fround($43 + Math_fround(0.0));
     HEAPF32[$42>>2] = $44;
     $45 = (($$013$i11$i) + 8|0);
     $46 = ($39|0)==(0);
     if ($46) {
      break;
     } else {
      $$013$i11$i = $45;$$04$i10$i = $39;
     }
    }
   }
  }
 }
 $71 = (($this) + 232|0);
 $72 = Math_fround(HEAPF32[$71>>2]);
 $73 = (($this) + 144|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = (($74) + 76|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(-2);
 if ($77) {
  $81 = (($this) + 188|0);
  $82 = Math_fround(HEAPF32[$81>>2]);
  $83 = Math_fround($72 / $82);
  $84 = (Math_fround(__ZNK20TextRenderingPrivate4Font22GetFontSizeFromSpacingEf($74,$83)));
  $85 = HEAP32[$73>>2]|0;
  $86 = (($85) + 208|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = (($85) + 32|0);
  $89 = HEAP32[$88>>2]|0;
  $90 = (Math_fround(($89|0)));
  $91 = Math_fround($84 / $90);
  $92 = Math_fround($91 + Math_fround(-1.0));
  $93 = Math_fround($87 * $92);
  $94 = (($this) + 177|0);
  $95 = HEAP8[$94>>0]|0;
  $96 = ($95<<24>>24)==(0);
  if ($96) {
   $$0$i = $93;
  } else {
   $97 = Math_fround($93 + Math_fround(0.5));
   $floorf$i$i$i$i$i = (Math_fround(Math_floor((Math_fround($97)))));
   $$0$i = $floorf$i$i$i$i$i;
  }
 } else {
  $78 = (($this) + 288|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = Math_fround($72 - $79);
  $$0$i = $80;
 }
 $98 = $$0$i != Math_fround(0.0);
 $99 = HEAP32[$15>>2]|0;
 if ($98) {
  $100 = HEAP32[$8>>2]|0;
  $101 = ($100|0)==($99|0);
  if (!($101)) {
   $102 = HEAP32[$18>>2]|0;
   $103 = $99 << 2;
   $104 = (($100) - ($99))|0;
   $105 = (($102) + (($103*60)|0)|0);
   $106 = $104 << 2;
   $$025$i = $105;$vertexCount$06$i = $106;
   while(1) {
    $107 = (($vertexCount$06$i) + -1)|0;
    $108 = Math_fround(HEAPF32[$$025$i>>2]);
    $109 = Math_fround($108 + Math_fround(0.0));
    HEAPF32[$$025$i>>2] = $109;
    $110 = (($$025$i) + 4|0);
    $111 = Math_fround(HEAPF32[$110>>2]);
    $112 = Math_fround($$0$i + $111);
    HEAPF32[$110>>2] = $112;
    $113 = (($$025$i) + 60|0);
    $114 = ($107|0)==(0);
    if ($114) {
     break;
    } else {
     $$025$i = $113;$vertexCount$06$i = $107;
    }
   }
  }
 }
 $115 = Math_fround(HEAPF32[$71>>2]);
 __ZN20TextRenderingPrivate19NativeTextGenerator15RegisterNewLineEif($this,$99,$115);
 $116 = (($this) + 260|0);
 $117 = Math_fround(HEAPF32[$116>>2]);
 $118 = Math_fround(HEAPF32[$13>>2]);
 $119 = $117 < $118;
 $120 = $119 ? $118 : $117;
 HEAPF32[$116>>2] = $120;
 $121 = Math_fround(HEAPF32[$71>>2]);
 $122 = (($this) + 268|0);
 $123 = Math_fround(HEAPF32[$122>>2]);
 $124 = Math_fround($121 + $123);
 HEAPF32[$122>>2] = $124;
 $125 = HEAP32[$8>>2]|0;
 $126 = (($this) + 292|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = (($127) + ($125<<2)|0);
 $129 = Math_fround(HEAPF32[$128>>2]);
 $130 = Math_fround($124 + $129);
 $131 = (($this) + 172|0);
 $132 = Math_fround(HEAPF32[$131>>2]);
 $133 = $130 > $132;
 if ($133) {
  $134 = (($this) + 197|0);
  $135 = HEAP8[$134>>0]|0;
  $136 = ($135<<24>>24)==(0);
  if ($136) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $didItFit$0$off0 = 0;
  }
 } else {
  $didItFit$0$off0 = 1;
 }
 $137 = (($this) + 288|0);
 $138 = Math_fround(HEAPF32[$137>>2]);
 HEAPF32[$71>>2] = $138;
 HEAPF32[$5>>2] = Math_fround(0.0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $139 = (($this) + 252|0);
 HEAPF32[$139>>2] = Math_fround(0.0);
 $140 = (($this) + 256|0);
 HEAP32[$140>>2] = 0;
 $141 = (($125) + 1)|0;
 $142 = (($this) + 220|0);
 HEAP32[$142>>2] = $141;
 $143 = (($this) + 212|0);
 HEAP32[$143>>2] = $141;
 HEAP32[$15>>2] = $141;
 $$0 = $didItFit$0$off0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20TextRenderingPrivate19NativeTextGenerator9InsertTabEv($this) {
 $this = $this|0;
 var $$0 = 0, $$0$i = Math_fround(0), $$0$i$i$i = Math_fround(0), $$013$i = 0, $$013$i$i = 0, $$013$i11$i = 0, $$025$i = 0, $$025$i$i = 0, $$025$i6$i = 0, $$04$i = 0, $$04$i$i = 0, $$04$i10$i = 0, $$phi$trans$insert = 0, $$pre = Math_fround(0), $$pre$phi12Z2D = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $$sink$i = Math_fround(0), $0 = 0, $1 = Math_fround(0);
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0);
 var $118 = 0, $119 = 0, $12 = Math_fround(0), $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0);
 var $136 = 0, $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = 0, $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = Math_fround(0), $153 = Math_fround(0);
 var $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = 0, $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = Math_fround(0), $192 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0;
 var $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0);
 var $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $floorf$i$i$i$i$i = Math_fround(0), $floorf$i$i$i$i$i2 = Math_fround(0), $or$cond = 0, $vertexCount$06$i = 0, $vertexCount$06$i$i = 0, $vertexCount$06$i5$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 252|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 == Math_fround(0.0);
 if ($2) {
  $3 = (($this) + 264|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  $5 = (($this) + 244|0);
  HEAPF32[$5>>2] = $4;
  $6 = (($this) + 204|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($this) + 220|0);
  HEAP32[$8>>2] = $7;
  $$pre10 = (($this) + 264|0);
  $$pre$phi12Z2D = $$pre10;$$pre$phiZ2D = $$pre10;$14 = $4;
 } else {
  $$phi$trans$insert = (($this) + 264|0);
  $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
  $$pre$phi12Z2D = $$phi$trans$insert;$$pre$phiZ2D = $$phi$trans$insert;$14 = $$pre;
 }
 HEAPF32[$0>>2] = Math_fround(0.0);
 $9 = (($this) + 256|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 184|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (Math_fround(($11|0)));
 $13 = Math_fround($14 / $12);
 $15 = !($13 >= Math_fround(0.0));
 if ($15) {
  $16 = Math_fround($13 + Math_fround(-0.999999940395355224609));
  $$sink$i = $16;
 } else {
  $$sink$i = $13;
 }
 $17 = (~~(($$sink$i)));
 $18 = (($17) + 1)|0;
 $19 = (($this) + 168|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = $20 > Math_fround(0.0);
 $22 = Math_imul($11, $18)|0;
 $23 = (Math_fround(($22|0)));
 $24 = $23 > $20;
 $or$cond = $21 & $24;
 if (!($or$cond)) {
  HEAPF32[$$pre$phi12Z2D>>2] = $23;
  $178 = (($this) + 236|0);
  HEAPF32[$178>>2] = $23;
  $179 = (($this) + 372|0);
  $180 = HEAP32[$179>>2]|0;
  $181 = (($180) + 60|0);
  $182 = (($180) + 120|0);
  $183 = (($180) + 180|0);
  ;HEAP32[$183+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$183+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$183+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
  _memmove(($182|0),($$pre$phiZ2D|0),12)|0;
  ;HEAP32[$181+0>>2]=HEAP32[$182+0>>2]|0;HEAP32[$181+4>>2]=HEAP32[$182+4>>2]|0;HEAP32[$181+8>>2]=HEAP32[$182+8>>2]|0;
  ;HEAP32[$180+0>>2]=HEAP32[$182+0>>2]|0;HEAP32[$180+4>>2]=HEAP32[$182+4>>2]|0;HEAP32[$180+8>>2]=HEAP32[$182+8>>2]|0;
  $184 = HEAP32[$179>>2]|0;
  $185 = (($184) + 240|0);
  HEAP32[$179>>2] = $185;
  $186 = (($this) + 204|0);
  $187 = HEAP32[$186>>2]|0;
  $188 = (($187) + 1)|0;
  $189 = (($this) + 212|0);
  HEAP32[$189>>2] = $188;
  $190 = (($this) + 240|0);
  HEAPF32[$190>>2] = Math_fround(0.0);
  $191 = Math_fround(HEAPF32[$$pre$phi12Z2D>>2]);
  $192 = (($this) + 248|0);
  HEAPF32[$192>>2] = $191;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $25 = (($this) + 372|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 60|0);
 $28 = (($26) + 120|0);
 $29 = (($26) + 180|0);
 ;HEAP32[$29+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
 _memmove(($28|0),($$pre$phiZ2D|0),12)|0;
 ;HEAP32[$27+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$28+8>>2]|0;
 ;HEAP32[$26+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$28+8>>2]|0;
 $30 = HEAP32[$25>>2]|0;
 $31 = (($30) + 240|0);
 HEAP32[$25>>2] = $31;
 $32 = (($this) + 204|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 356|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + ($33<<2)|0);
 HEAPF32[$36>>2] = Math_fround(0.0);
 $37 = (($this) + 236|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($this) + 216|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = $40 << 2;
 $42 = (($this) + 376|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + (($41*60)|0)|0);
 $45 = (($this) + 308|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46) + ($40<<3)|0);
 $48 = (($33) - ($40))|0;
 $49 = (($48) + 1)|0;
 $50 = (($this) + 164|0);
 $51 = HEAP32[$50>>2]|0;
 if ((($51|0) == 1)) {
  $71 = Math_fround($38 * Math_fround(-0.5));
  $72 = (($this) + 177|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = ($73<<24>>24)==(0);
  if ($74) {
   $$0$i$i$i = $71;
  } else {
   $75 = Math_fround($71 + Math_fround(0.5));
   $floorf$i$i$i$i$i2 = (Math_fround(Math_floor((Math_fround($75)))));
   $$0$i$i$i = $floorf$i$i$i$i$i2;
  }
  $76 = ($49|0)==(0);
  if (!($76)) {
   $77 = $49 << 2;
   $$025$i$i = $44;$vertexCount$06$i$i = $77;
   while(1) {
    $78 = (($vertexCount$06$i$i) + -1)|0;
    $79 = Math_fround(HEAPF32[$$025$i$i>>2]);
    $80 = Math_fround($$0$i$i$i + $79);
    HEAPF32[$$025$i$i>>2] = $80;
    $81 = (($$025$i$i) + 4|0);
    $82 = Math_fround(HEAPF32[$81>>2]);
    $83 = Math_fround($82 + Math_fround(0.0));
    HEAPF32[$81>>2] = $83;
    $84 = (($$025$i$i) + 60|0);
    $85 = ($78|0)==(0);
    if ($85) {
     break;
    } else {
     $$025$i$i = $84;$vertexCount$06$i$i = $78;
    }
   }
   $86 = ($47|0)==(0|0);
   if (!($86)) {
    $$013$i$i = $47;$$04$i$i = $49;
    while(1) {
     $87 = (($$04$i$i) + -1)|0;
     $88 = Math_fround(HEAPF32[$$013$i$i>>2]);
     $89 = Math_fround($$0$i$i$i + $88);
     HEAPF32[$$013$i$i>>2] = $89;
     $90 = (($$013$i$i) + 4|0);
     $91 = Math_fround(HEAPF32[$90>>2]);
     $92 = Math_fround($91 + Math_fround(0.0));
     HEAPF32[$90>>2] = $92;
     $93 = (($$013$i$i) + 8|0);
     $94 = ($87|0)==(0);
     if ($94) {
      break;
     } else {
      $$013$i$i = $93;$$04$i$i = $87;
     }
    }
   }
  }
 } else if ((($51|0) == 2)) {
  $52 = ($49|0)==(0);
  if (!($52)) {
   $53 = $49 << 2;
   $$025$i6$i = $44;$vertexCount$06$i5$i = $53;
   while(1) {
    $54 = (($vertexCount$06$i5$i) + -1)|0;
    $55 = Math_fround(HEAPF32[$$025$i6$i>>2]);
    $56 = Math_fround($55 - $38);
    HEAPF32[$$025$i6$i>>2] = $56;
    $57 = (($$025$i6$i) + 4|0);
    $58 = Math_fround(HEAPF32[$57>>2]);
    $59 = Math_fround($58 + Math_fround(0.0));
    HEAPF32[$57>>2] = $59;
    $60 = (($$025$i6$i) + 60|0);
    $61 = ($54|0)==(0);
    if ($61) {
     break;
    } else {
     $$025$i6$i = $60;$vertexCount$06$i5$i = $54;
    }
   }
   $62 = ($47|0)==(0|0);
   if (!($62)) {
    $$013$i11$i = $47;$$04$i10$i = $49;
    while(1) {
     $63 = (($$04$i10$i) + -1)|0;
     $64 = Math_fround(HEAPF32[$$013$i11$i>>2]);
     $65 = Math_fround($64 - $38);
     HEAPF32[$$013$i11$i>>2] = $65;
     $66 = (($$013$i11$i) + 4|0);
     $67 = Math_fround(HEAPF32[$66>>2]);
     $68 = Math_fround($67 + Math_fround(0.0));
     HEAPF32[$66>>2] = $68;
     $69 = (($$013$i11$i) + 8|0);
     $70 = ($63|0)==(0);
     if ($70) {
      break;
     } else {
      $$013$i11$i = $69;$$04$i10$i = $63;
     }
    }
   }
  }
 }
 $95 = (($this) + 232|0);
 $96 = Math_fround(HEAPF32[$95>>2]);
 $97 = (($this) + 144|0);
 $98 = HEAP32[$97>>2]|0;
 $99 = (($98) + 76|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = ($100|0)==(-2);
 if ($101) {
  $105 = (($this) + 188|0);
  $106 = Math_fround(HEAPF32[$105>>2]);
  $107 = Math_fround($96 / $106);
  $108 = (Math_fround(__ZNK20TextRenderingPrivate4Font22GetFontSizeFromSpacingEf($98,$107)));
  $109 = HEAP32[$97>>2]|0;
  $110 = (($109) + 208|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = (($109) + 32|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (Math_fround(($113|0)));
  $115 = Math_fround($108 / $114);
  $116 = Math_fround($115 + Math_fround(-1.0));
  $117 = Math_fround($111 * $116);
  $118 = (($this) + 177|0);
  $119 = HEAP8[$118>>0]|0;
  $120 = ($119<<24>>24)==(0);
  if ($120) {
   $$0$i = $117;
  } else {
   $121 = Math_fround($117 + Math_fround(0.5));
   $floorf$i$i$i$i$i = (Math_fround(Math_floor((Math_fround($121)))));
   $$0$i = $floorf$i$i$i$i$i;
  }
 } else {
  $102 = (($this) + 288|0);
  $103 = Math_fround(HEAPF32[$102>>2]);
  $104 = Math_fround($96 - $103);
  $$0$i = $104;
 }
 $122 = $$0$i != Math_fround(0.0);
 $123 = HEAP32[$39>>2]|0;
 if ($122) {
  $124 = HEAP32[$45>>2]|0;
  $125 = (($124) + ($123<<3)|0);
  $126 = HEAP32[$32>>2]|0;
  $127 = (($126) - ($123))|0;
  $128 = ($126|0)==($123|0);
  if (!($128)) {
   $129 = HEAP32[$42>>2]|0;
   $130 = $123 << 2;
   $131 = (($129) + (($130*60)|0)|0);
   $132 = $127 << 2;
   $$025$i = $131;$vertexCount$06$i = $132;
   while(1) {
    $133 = (($vertexCount$06$i) + -1)|0;
    $134 = Math_fround(HEAPF32[$$025$i>>2]);
    $135 = Math_fround($134 + Math_fround(0.0));
    HEAPF32[$$025$i>>2] = $135;
    $136 = (($$025$i) + 4|0);
    $137 = Math_fround(HEAPF32[$136>>2]);
    $138 = Math_fround($$0$i + $137);
    HEAPF32[$136>>2] = $138;
    $139 = (($$025$i) + 60|0);
    $140 = ($133|0)==(0);
    if ($140) {
     break;
    } else {
     $$025$i = $139;$vertexCount$06$i = $133;
    }
   }
   $141 = ($125|0)==(0|0);
   if (!($141)) {
    $$013$i = $125;$$04$i = $127;
    while(1) {
     $142 = (($$04$i) + -1)|0;
     $143 = Math_fround(HEAPF32[$$013$i>>2]);
     $144 = Math_fround($143 + Math_fround(0.0));
     HEAPF32[$$013$i>>2] = $144;
     $145 = (($$013$i) + 4|0);
     $146 = Math_fround(HEAPF32[$145>>2]);
     $147 = Math_fround($$0$i + $146);
     HEAPF32[$145>>2] = $147;
     $148 = (($$013$i) + 8|0);
     $149 = ($142|0)==(0);
     if ($149) {
      break;
     } else {
      $$013$i = $148;$$04$i = $142;
     }
    }
   }
  }
 }
 $150 = Math_fround(HEAPF32[$95>>2]);
 __ZN20TextRenderingPrivate19NativeTextGenerator15RegisterNewLineEif($this,$123,$150);
 $151 = (($this) + 260|0);
 $152 = Math_fround(HEAPF32[$151>>2]);
 $153 = Math_fround(HEAPF32[$37>>2]);
 $154 = $152 < $153;
 $155 = $154 ? $153 : $152;
 HEAPF32[$151>>2] = $155;
 $156 = Math_fround(HEAPF32[$95>>2]);
 $157 = (($this) + 268|0);
 $158 = Math_fround(HEAPF32[$157>>2]);
 $159 = Math_fround($156 + $158);
 HEAPF32[$157>>2] = $159;
 $160 = HEAP32[$32>>2]|0;
 $161 = (($this) + 292|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = (($162) + ($160<<2)|0);
 $164 = Math_fround(HEAPF32[$163>>2]);
 $165 = Math_fround($159 + $164);
 $166 = (($this) + 172|0);
 $167 = Math_fround(HEAPF32[$166>>2]);
 $168 = $165 > $167;
 if ($168) {
  $169 = (($this) + 304|0);
  HEAP8[$169>>0] = 0;
  $170 = (($this) + 197|0);
  $171 = HEAP8[$170>>0]|0;
  $172 = ($171<<24>>24)==(0);
  if ($172) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $173 = (($this) + 288|0);
 $174 = Math_fround(HEAPF32[$173>>2]);
 HEAPF32[$95>>2] = $174;
 HEAPF32[$$pre$phi12Z2D>>2] = Math_fround(0.0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 HEAP32[$9>>2] = 0;
 $175 = (($160) + 1)|0;
 $176 = (($this) + 220|0);
 HEAP32[$176>>2] = $175;
 $177 = (($this) + 212|0);
 HEAP32[$177>>2] = $175;
 HEAP32[$39>>2] = $175;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20TextRenderingPrivate19NativeTextGenerator15InsertCharacterEi($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $$ = 0, $$0 = 0, $$0$i = Math_fround(0), $$0$i$i = Math_fround(0), $$0$i$i$i = Math_fround(0), $$0$i$i$i$i = 0, $$0$i$i$i$i$i$i$i = 0, $$0$i$i$i14 = Math_fround(0), $$0$i$i47 = Math_fround(0), $$013$i = 0, $$013$i$i = 0, $$013$i$i21 = 0, $$013$i11$i = 0, $$013$i11$i11 = 0, $$013$i33 = 0, $$025$i = 0, $$025$i$i = 0, $$025$i$i18 = 0, $$025$i28 = 0, $$025$i6$i = 0;
 var $$025$i6$i8 = 0, $$04$i = 0, $$04$i$i = 0, $$04$i$i20 = 0, $$04$i10$i = 0, $$04$i10$i10 = 0, $$04$i32 = 0, $$96 = 0, $$lcssa104 = Math_fround(0), $$neg2$i$i$i$i$i = 0, $$phi$trans$insert = 0, $$pre118 = Math_fround(0), $$sum$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0);
 var $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = Math_fround(0), $14 = 0;
 var $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0);
 var $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0);
 var $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = Math_fround(0), $187 = Math_fround(0), $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = Math_fround(0), $205 = Math_fround(0), $206 = Math_fround(0), $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = Math_fround(0), $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0, $291 = Math_fround(0), $292 = 0, $293 = Math_fround(0), $294 = Math_fround(0), $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = Math_fround(0), $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = Math_fround(0), $312 = Math_fround(0), $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = Math_fround(0), $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = Math_fround(0);
 var $320 = 0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = 0, $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0), $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = Math_fround(0);
 var $339 = 0, $34 = 0, $340 = Math_fround(0), $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = Math_fround(0), $350 = 0, $351 = Math_fround(0), $352 = Math_fround(0), $353 = Math_fround(0), $354 = 0, $355 = 0, $356 = Math_fround(0);
 var $357 = 0, $358 = 0, $359 = Math_fround(0), $36 = Math_fround(0), $360 = Math_fround(0), $361 = Math_fround(0), $362 = Math_fround(0), $363 = 0, $364 = 0, $365 = Math_fround(0), $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = Math_fround(0), $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0;
 var $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = Math_fround(0), $382 = 0, $383 = Math_fround(0), $384 = Math_fround(0), $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = Math_fround(0);
 var $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = Math_fround(0), $400 = Math_fround(0), $401 = Math_fround(0), $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = Math_fround(0);
 var $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = Math_fround(0), $421 = Math_fround(0), $422 = 0, $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = 0, $427 = 0, $428 = 0;
 var $429 = Math_fround(0), $43 = Math_fround(0), $430 = Math_fround(0), $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = 0, $436 = Math_fround(0), $437 = 0, $438 = 0, $439 = Math_fround(0), $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = Math_fround(0), $444 = Math_fround(0), $445 = 0, $446 = Math_fround(0);
 var $447 = Math_fround(0), $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = Math_fround(0), $453 = Math_fround(0), $454 = 0, $455 = Math_fround(0), $456 = Math_fround(0), $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = Math_fround(0), $461 = Math_fround(0), $462 = 0, $463 = Math_fround(0), $464 = Math_fround(0);
 var $465 = Math_fround(0), $466 = 0, $467 = Math_fround(0), $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0;
 var $483 = Math_fround(0), $484 = Math_fround(0), $485 = 0, $486 = Math_fround(0), $487 = Math_fround(0), $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = 0, $498 = 0, $499 = Math_fround(0), $5 = 0, $50 = 0;
 var $500 = 0, $501 = 0, $502 = Math_fround(0), $503 = 0, $504 = 0, $505 = 0, $506 = Math_fround(0), $507 = Math_fround(0), $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = Math_fround(0), $516 = Math_fround(0), $517 = 0, $518 = Math_fround(0);
 var $519 = Math_fround(0), $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = Math_fround(0), $526 = 0, $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0;
 var $537 = 0, $538 = 0, $539 = Math_fround(0), $54 = 0, $540 = Math_fround(0), $541 = 0, $542 = Math_fround(0), $543 = Math_fround(0), $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = Math_fround(0), $552 = Math_fround(0), $553 = 0, $554 = 0;
 var $555 = Math_fround(0), $556 = Math_fround(0), $557 = Math_fround(0), $558 = 0, $559 = Math_fround(0), $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = Math_fround(0), $564 = Math_fround(0), $565 = Math_fround(0), $566 = Math_fround(0), $567 = 0, $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = 0, $571 = Math_fround(0), $572 = Math_fround(0);
 var $573 = 0, $574 = 0, $575 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $__len$0$be$i$i$i$i$i = 0, $__len$03$i$i$i$i$i = 0, $charUv = 0, $flipped = 0, $floorf$i$i$i$i = Math_fround(0), $floorf$i$i$i$i$i = Math_fround(0), $floorf$i$i$i$i$i13 = Math_fround(0), $floorf$i$i$i$i$i35 = Math_fround(0), $floorf$i$i$i$i37 = Math_fround(0), $floorf$i$i$i$i40 = Math_fround(0), $floorf$i$i$i$i43 = Math_fround(0);
 var $floorf$i$i$i$i46 = Math_fround(0), $floorf$i$i$i$i49 = Math_fround(0), $i$0105 = 0, $i1$0102 = 0, $i2$0101 = 0, $kerning$0 = Math_fround(0), $outOfSpace$0$off0 = 0, $vert = 0, $vertexCount$06$i = 0, $vertexCount$06$i$i = 0, $vertexCount$06$i$i17 = 0, $vertexCount$06$i27 = 0, $vertexCount$06$i5$i = 0, $vertexCount$06$i5$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vert = sp + 16|0;
 $charUv = sp;
 $flipped = sp + 44|0;
 $0 = sp + 40|0;
 $1 = sp + 42|0;
 $2 = sp + 36|0;
 $3 = sp + 32|0;
 $4 = sp + 38|0;
 $5 = sp + 34|0;
 ;HEAP32[$vert+0>>2]=0|0;HEAP32[$vert+4>>2]=0|0;HEAP32[$vert+8>>2]=0|0;HEAP32[$vert+12>>2]=0|0;
 ;HEAP32[$charUv+0>>2]=0|0;HEAP32[$charUv+4>>2]=0|0;HEAP32[$charUv+8>>2]=0|0;HEAP32[$charUv+12>>2]=0|0;
 $6 = (($this) + 144|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 280|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + -24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + -32|0);
 $13 = HEAP32[$12>>2]|0;
 __ZNK20TextRenderingPrivate4Font22GetCharacterRenderInfoEjijR5RectTIfES3_Rb($7,$c,$11,$13,$vert,$charUv,$flipped);
 $14 = HEAP32[$6>>2]|0;
 $15 = HEAP32[$8>>2]|0;
 $16 = (($15) + -24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + -32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(__ZNK20TextRenderingPrivate4Font17GetCharacterWidthEjij($14,$c,$17,$19)));
 $21 = (($this) + 177|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $$0$i$i = $20;
 } else {
  $24 = Math_fround($20 + Math_fround(0.5));
  $floorf$i$i$i$i = (Math_fround(Math_floor((Math_fround($24)))));
  $$0$i$i = $floorf$i$i$i$i;
 }
 $25 = (($this) + 204|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($this) + 356|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + ($26<<2)|0);
 HEAPF32[$29>>2] = $$0$i$i;
 $30 = (($vert) + 4|0);
 $31 = Math_fround(HEAPF32[$30>>2]);
 if ($23) {
  HEAPF32[$30>>2] = $31;
  $32 = Math_fround(HEAPF32[$vert>>2]);
  $33 = (($vert) + 8|0);
  $34 = (($vert) + 12|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $$0$i$i47 = $35;$109 = $32;$113 = $31;$138 = $vert;$140 = $33;$45 = $34;
 } else {
  $36 = Math_fround($31 + Math_fround(0.5));
  $floorf$i$i$i$i37 = (Math_fround(Math_floor((Math_fround($36)))));
  HEAPF32[$30>>2] = $floorf$i$i$i$i37;
  $37 = Math_fround(HEAPF32[$vert>>2]);
  $38 = Math_fround($37 + Math_fround(0.5));
  $floorf$i$i$i$i40 = (Math_fround(Math_floor((Math_fround($38)))));
  HEAPF32[$vert>>2] = $floorf$i$i$i$i40;
  $39 = (($vert) + 8|0);
  $40 = Math_fround(HEAPF32[$39>>2]);
  $41 = Math_fround($40 + Math_fround(0.5));
  $floorf$i$i$i$i43 = (Math_fround(Math_floor((Math_fround($41)))));
  HEAPF32[$39>>2] = $floorf$i$i$i$i43;
  $42 = (($vert) + 12|0);
  $43 = Math_fround(HEAPF32[$42>>2]);
  $44 = Math_fround($43 + Math_fround(0.5));
  $floorf$i$i$i$i46 = (Math_fround(Math_floor((Math_fround($44)))));
  $$0$i$i47 = $floorf$i$i$i$i46;$109 = $floorf$i$i$i$i40;$113 = $floorf$i$i$i$i37;$138 = $vert;$140 = $39;$45 = $42;
 }
 HEAPF32[$45>>2] = $$0$i$i47;
 $46 = HEAP32[$6>>2]|0;
 $47 = (($46) + 48|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 52|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($48|0)==($50|0);
 if (!($51)) {
  $52 = (($this) + 208|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(-1);
  if (!($54)) {
   $55 = $50;
   $56 = $48;
   $57 = (($55) - ($56))|0;
   $58 = $57 >> 3;
   $59 = ($58|0)==(0);
   if ($59) {
    $77 = $48;
   } else {
    $60 = $53&255;
    $61 = $c&255;
    $64 = $48;$__len$03$i$i$i$i$i = $58;
    while(1) {
     $62 = (($__len$03$i$i$i$i$i|0) / 2)&-1;
     $63 = (($64) + ($62<<3)|0);
     $65 = HEAP16[$63>>1]|0;
     $66 = $65&255;
     $67 = ((($64) + ($62<<3)|0) + 2|0);
     $68 = HEAP16[$67>>1]|0;
     $69 = $68&255;
     $70 = ($66<<24>>24)==($60<<24>>24);
     $71 = ($66<<24>>24)<($60<<24>>24);
     $72 = ($69<<24>>24)<($61<<24>>24);
     $$0$i$i$i$i$i$i$i = $70 ? $72 : $71;
     if ($$0$i$i$i$i$i$i$i) {
      $$sum$i$i$i$i$i = (($62) + 1)|0;
      $73 = (($64) + ($$sum$i$i$i$i$i<<3)|0);
      $$neg2$i$i$i$i$i = (($__len$03$i$i$i$i$i) + -1)|0;
      $74 = (($$neg2$i$i$i$i$i) - ($62))|0;
      $575 = $73;$__len$0$be$i$i$i$i$i = $74;
     } else {
      $575 = $64;$__len$0$be$i$i$i$i$i = $62;
     }
     $75 = ($__len$0$be$i$i$i$i$i|0)==(0);
     if ($75) {
      $77 = $575;
      break;
     } else {
      $64 = $575;$__len$03$i$i$i$i$i = $__len$0$be$i$i$i$i$i;
     }
    }
   }
   $76 = ($77|0)==($50|0);
   if (!($76)) {
    $78 = $53&255;
    $79 = $c&255;
    $80 = HEAP16[$77>>1]|0;
    $81 = $80&255;
    $82 = (($77) + 2|0);
    $83 = HEAP16[$82>>1]|0;
    $84 = $83&255;
    $85 = ($78<<24>>24)==($81<<24>>24);
    $86 = ($78<<24>>24)<($81<<24>>24);
    $87 = ($79<<24>>24)<($84<<24>>24);
    $$0$i$i$i$i = $85 ? $87 : $86;
    $$96 = $$0$i$i$i$i ? $50 : $77;
    $88 = ($$96|0)==($50|0);
    if (!($88)) {
     $89 = (($$96) + 4|0);
     $90 = Math_fround(HEAPF32[$89>>2]);
     $91 = (($this) + 148|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($92|0)==(0);
     if ($93) {
      $kerning$0 = $90;
     } else {
      $94 = (Math_fround(($92|0)));
      $95 = Math_fround($90 * $94);
      $96 = (($46) + 32|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = (Math_fround(($97|0)));
      $99 = Math_fround($95 / $98);
      if ($23) {
       $kerning$0 = $99;
      } else {
       $100 = Math_fround($99 + Math_fround(0.5));
       $floorf$i$i$i$i49 = (Math_fround(Math_floor((Math_fround($100)))));
       $kerning$0 = $floorf$i$i$i$i49;
      }
     }
     $101 = (($this) + 264|0);
     $102 = Math_fround(HEAPF32[$101>>2]);
     $103 = Math_fround($kerning$0 + $102);
     HEAPF32[$101>>2] = $103;
    }
   }
  }
 }
 $104 = (($this) + 372|0);
 $105 = HEAP32[$104>>2]|0;
 $106 = (($this) + 264|0);
 $107 = Math_fround(HEAPF32[$106>>2]);
 $108 = Math_fround($109 + $107);
 $110 = (($this) + 268|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($111 - $113);
 $114 = (($this) + 272|0);
 $115 = Math_fround(HEAPF32[$114>>2]);
 $116 = Math_fround($115 + Math_fround(0.0));
 HEAPF32[$105>>2] = $108;
 $117 = (($105) + 4|0);
 HEAPF32[$117>>2] = $112;
 $118 = (($105) + 8|0);
 HEAPF32[$118>>2] = $116;
 $119 = HEAP8[$flipped>>0]|0;
 $120 = ($119<<24>>24)!=(0);
 $121 = $120 ? 2 : 0;
 $122 = HEAP32[$104>>2]|0;
 $123 = ((($122) + (($121*60)|0)|0) + 28|0);
 $124 = Math_fround(HEAPF32[$charUv>>2]);
 $125 = (($charUv) + 4|0);
 $126 = Math_fround(HEAPF32[$125>>2]);
 $127 = (($charUv) + 12|0);
 $128 = Math_fround(HEAPF32[$127>>2]);
 $129 = Math_fround($126 + $128);
 $130 = (HEAPF32[tempDoublePtr>>2]=$124,HEAP32[tempDoublePtr>>2]|0);
 $131 = (HEAPF32[tempDoublePtr>>2]=$129,HEAP32[tempDoublePtr>>2]|0);
 $132 = $123;
 $133 = $132;
 HEAP32[$133>>2] = $130;
 $134 = (($132) + 4)|0;
 $135 = $134;
 HEAP32[$135>>2] = $131;
 $136 = HEAP32[$104>>2]|0;
 $137 = Math_fround(HEAPF32[$138>>2]);
 $139 = Math_fround(HEAPF32[$140>>2]);
 $141 = Math_fround($137 + $139);
 $142 = Math_fround(HEAPF32[$30>>2]);
 $143 = Math_fround(HEAPF32[$106>>2]);
 $144 = Math_fround($141 + $143);
 $145 = Math_fround(HEAPF32[$110>>2]);
 $146 = Math_fround($145 - $142);
 $147 = Math_fround(HEAPF32[$114>>2]);
 $148 = Math_fround($147 + Math_fround(0.0));
 $149 = (($136) + 60|0);
 HEAPF32[$149>>2] = $144;
 $150 = (($136) + 64|0);
 HEAPF32[$150>>2] = $146;
 $151 = (($136) + 68|0);
 HEAPF32[$151>>2] = $148;
 $152 = HEAP32[$104>>2]|0;
 $153 = (($152) + 88|0);
 $154 = Math_fround(HEAPF32[$charUv>>2]);
 $155 = (($charUv) + 8|0);
 $156 = Math_fround(HEAPF32[$155>>2]);
 $157 = Math_fround($154 + $156);
 $158 = Math_fround(HEAPF32[$125>>2]);
 $159 = Math_fround(HEAPF32[$127>>2]);
 $160 = Math_fround($158 + $159);
 $161 = (HEAPF32[tempDoublePtr>>2]=$157,HEAP32[tempDoublePtr>>2]|0);
 $162 = (HEAPF32[tempDoublePtr>>2]=$160,HEAP32[tempDoublePtr>>2]|0);
 $163 = $153;
 $164 = $163;
 HEAP32[$164>>2] = $161;
 $165 = (($163) + 4)|0;
 $166 = $165;
 HEAP32[$166>>2] = $162;
 $167 = HEAP32[$104>>2]|0;
 $168 = Math_fround(HEAPF32[$138>>2]);
 $169 = Math_fround(HEAPF32[$140>>2]);
 $170 = Math_fround($168 + $169);
 $171 = Math_fround(HEAPF32[$30>>2]);
 $172 = Math_fround(HEAPF32[$45>>2]);
 $173 = Math_fround($171 + $172);
 $174 = Math_fround(HEAPF32[$106>>2]);
 $175 = Math_fround($170 + $174);
 $176 = Math_fround(HEAPF32[$110>>2]);
 $177 = Math_fround($176 - $173);
 $178 = Math_fround(HEAPF32[$114>>2]);
 $179 = Math_fround($178 + Math_fround(0.0));
 $180 = (($167) + 120|0);
 HEAPF32[$180>>2] = $175;
 $181 = (($167) + 124|0);
 HEAPF32[$181>>2] = $177;
 $182 = (($167) + 128|0);
 HEAPF32[$182>>2] = $179;
 $183 = $120 ? 0 : 2;
 $184 = HEAP32[$104>>2]|0;
 $185 = ((($184) + (($183*60)|0)|0) + 28|0);
 $186 = Math_fround(HEAPF32[$charUv>>2]);
 $187 = Math_fround(HEAPF32[$155>>2]);
 $188 = Math_fround($186 + $187);
 $189 = Math_fround(HEAPF32[$125>>2]);
 $190 = (HEAPF32[tempDoublePtr>>2]=$188,HEAP32[tempDoublePtr>>2]|0);
 $191 = (HEAPF32[tempDoublePtr>>2]=$189,HEAP32[tempDoublePtr>>2]|0);
 $192 = $185;
 $193 = $192;
 HEAP32[$193>>2] = $190;
 $194 = (($192) + 4)|0;
 $195 = $194;
 HEAP32[$195>>2] = $191;
 $196 = HEAP32[$104>>2]|0;
 $197 = Math_fround(HEAPF32[$138>>2]);
 $198 = Math_fround(HEAPF32[$30>>2]);
 $199 = Math_fround(HEAPF32[$45>>2]);
 $200 = Math_fround($198 + $199);
 $201 = Math_fround(HEAPF32[$106>>2]);
 $202 = Math_fround($197 + $201);
 $203 = Math_fround(HEAPF32[$110>>2]);
 $204 = Math_fround($203 - $200);
 $205 = Math_fround(HEAPF32[$114>>2]);
 $206 = Math_fround($205 + Math_fround(0.0));
 $207 = (($196) + 180|0);
 HEAPF32[$207>>2] = $202;
 $208 = (($196) + 184|0);
 HEAPF32[$208>>2] = $204;
 $209 = (($196) + 188|0);
 HEAPF32[$209>>2] = $206;
 $210 = HEAP32[$104>>2]|0;
 $211 = (($210) + 208|0);
 $212 = Math_fround(HEAPF32[$charUv>>2]);
 $213 = Math_fround(HEAPF32[$125>>2]);
 $214 = (HEAPF32[tempDoublePtr>>2]=$212,HEAP32[tempDoublePtr>>2]|0);
 $215 = (HEAPF32[tempDoublePtr>>2]=$213,HEAP32[tempDoublePtr>>2]|0);
 $216 = $211;
 $217 = $216;
 HEAP32[$217>>2] = $214;
 $218 = (($216) + 4)|0;
 $219 = $218;
 HEAP32[$219>>2] = $215;
 $220 = (($this) + 196|0);
 $221 = HEAP8[$220>>0]|0;
 $222 = ($221<<24>>24)==(0);
 $223 = HEAP32[$8>>2]|0;
 $224 = (($223) + -28|0);
 do {
  if ($222) {
   $242 = HEAP32[$224>>2]|0;
   $243 = $242&255;
   $244 = $242 >>> 8;
   $245 = $244&255;
   $246 = $242 >>> 16;
   $247 = $246&255;
   $248 = $242 >>> 24;
   $249 = $248&255;
   $256 = $249;$259 = $247;$263 = $245;$267 = $243;
  } else {
   $225 = HEAP8[((640792 + 258|0))>>0]|0;
   $226 = ($225<<24>>24)==(0);
   if ($226) {
    $234 = HEAP32[$224>>2]|0;
    $235 = $234&255;
    $236 = $234 >>> 8;
    $237 = $236&255;
    $238 = $234 >>> 16;
    $239 = $238&255;
    $240 = $234 >>> 24;
    $241 = $240&255;
    $256 = $241;$259 = $239;$263 = $237;$267 = $235;
    break;
   } else {
    $227 = (($223) + -26|0);
    $228 = HEAP8[$227>>0]|0;
    $229 = (($223) + -27|0);
    $230 = HEAP8[$229>>0]|0;
    $231 = HEAP8[$224>>0]|0;
    $232 = (($223) + -25|0);
    $233 = HEAP8[$232>>0]|0;
    $256 = $233;$259 = $231;$263 = $230;$267 = $228;
    break;
   }
  }
 } while(0);
 $250 = HEAP32[$104>>2]|0;
 $251 = (($250) + 24|0);
 $252 = (($250) + 84|0);
 $253 = (($250) + 144|0);
 $254 = (($250) + 204|0);
 $255 = $256&255;
 $257 = $255 << 24;
 $258 = $259&255;
 $260 = $258 << 16;
 $261 = $260 | $257;
 $262 = $263&255;
 $264 = $262 << 8;
 $265 = $261 | $264;
 $266 = $267&255;
 $268 = $265 | $266;
 HEAP32[$254>>2] = $268;
 HEAP32[$253>>2] = $268;
 HEAP32[$252>>2] = $268;
 HEAP32[$251>>2] = $268;
 $269 = (($250) + 240|0);
 HEAP32[$104>>2] = $269;
 $270 = HEAP32[$25>>2]|0;
 $271 = $270 << 2;
 $272 = (($223) + -20|0);
 $273 = HEAP32[$272>>2]|0;
 $274 = ((($this) + ($273<<4)|0) + 12|0);
 $275 = $271 | 1;
 $276 = $275&65535;
 HEAP16[$0>>1] = $276;
 __ZN13dynamic_arrayItLj2EE9push_backERKt($274,$0);
 $277 = $271 | 2;
 $278 = $277&65535;
 HEAP16[$1>>1] = $278;
 __ZN13dynamic_arrayItLj2EE9push_backERKt($274,$1);
 $279 = $271&65535;
 HEAP16[$2>>1] = $279;
 __ZN13dynamic_arrayItLj2EE9push_backERKt($274,$2);
 HEAP16[$3>>1] = $278;
 __ZN13dynamic_arrayItLj2EE9push_backERKt($274,$3);
 $280 = $271 | 3;
 $281 = $280&65535;
 HEAP16[$4>>1] = $281;
 __ZN13dynamic_arrayItLj2EE9push_backERKt($274,$4);
 HEAP16[$5>>1] = $279;
 __ZN13dynamic_arrayItLj2EE9push_backERKt($274,$5);
 $282 = HEAP32[$25>>2]|0;
 $283 = (($this) + 292|0);
 $284 = HEAP32[$283>>2]|0;
 $285 = (($284) + ($282<<2)|0);
 $286 = Math_fround(HEAPF32[$285>>2]);
 $287 = (($this) + 232|0);
 $288 = Math_fround(HEAPF32[$287>>2]);
 $289 = $286 > $288;
 if ($289) {
  HEAPF32[$287>>2] = $286;
 }
 $290 = (($this) + 168|0);
 $291 = Math_fround(HEAPF32[$290>>2]);
 $292 = $291 > Math_fround(0.0);
 $293 = Math_fround(HEAPF32[$106>>2]);
 if ($292) {
  $294 = Math_fround($$0$i$i + $293);
  $295 = $294 > $291;
  if ($295) {
   $296 = (($this) + 212|0);
   $297 = HEAP32[$296>>2]|0;
   $298 = (($this) + 216|0);
   $299 = HEAP32[$298>>2]|0;
   $300 = ($297|0)==($299|0);
   if ($300) {
    HEAP32[$296>>2] = $282;
    $301 = (($this) + 240|0);
    HEAPF32[$301>>2] = Math_fround(0.0);
    $302 = (($this) + 248|0);
    HEAPF32[$302>>2] = $293;
    $303 = (($this) + 244|0);
    HEAPF32[$303>>2] = $293;
    $304 = (($this) + 220|0);
    HEAP32[$304>>2] = $297;
    $309 = $282;
   } else {
    $309 = $297;
   }
   $305 = (($this) + 288|0);
   $306 = (($284) + ($299<<2)|0);
   $307 = Math_fround(HEAPF32[$306>>2]);
   $308 = ($299|0)<($309|0);
   L42: do {
    if ($308) {
     $311 = $307;$312 = $307;$i$0105 = $299;
     while(1) {
      $310 = $311 < $312;
      $313 = $310 ? $312 : $311;
      $314 = (($i$0105) + 1)|0;
      $315 = ($314|0)<($309|0);
      if (!($315)) {
       $$lcssa104 = $313;
       break L42;
      }
      $$phi$trans$insert = (($284) + ($314<<2)|0);
      $$pre118 = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
      $311 = $$pre118;$312 = $313;$i$0105 = $314;
     }
    } else {
     $$lcssa104 = $307;
    }
   } while(0);
   $316 = Math_fround(HEAPF32[$305>>2]);
   HEAPF32[$287>>2] = $316;
   $317 = ($309|0)>($282|0);
   if ($317) {
    $328 = $316;
   } else {
    $321 = $316;$i1$0102 = $309;
    while(1) {
     $318 = (($284) + ($i1$0102<<2)|0);
     $319 = Math_fround(HEAPF32[$318>>2]);
     $320 = $319 < $321;
     $322 = $320 ? $321 : $319;
     HEAPF32[$287>>2] = $322;
     $323 = (($i1$0102) + 1)|0;
     $324 = ($i1$0102|0)<($282|0);
     if ($324) {
      $321 = $322;$i1$0102 = $323;
     } else {
      $328 = $322;
      break;
     }
    }
   }
   $325 = Math_fround(HEAPF32[$110>>2]);
   $326 = Math_fround($$lcssa104 + $325);
   $327 = Math_fround($326 + $328);
   $329 = (($this) + 172|0);
   $330 = Math_fround(HEAPF32[$329>>2]);
   $331 = $327 > $330;
   if ($331) {
    $332 = (($this) + 304|0);
    HEAP8[$332>>0] = 0;
    $333 = (($this) + 197|0);
    $334 = HEAP8[$333>>0]|0;
    $335 = ($334<<24>>24)==(0);
    if ($335) {
     $336 = ($309|0)<($282|0);
     if ($336) {
      $340 = $$lcssa104;$i2$0101 = $309;
      while(1) {
       $337 = (($284) + ($i2$0101<<2)|0);
       $338 = Math_fround(HEAPF32[$337>>2]);
       $339 = $338 < $340;
       $341 = $339 ? $340 : $338;
       $342 = (($i2$0101) + 1)|0;
       $343 = ($342|0)<($282|0);
       if ($343) {
        $340 = $341;$i2$0101 = $342;
       } else {
        $349 = $341;$outOfSpace$0$off0 = 1;
        break;
       }
      }
     } else {
      $349 = $$lcssa104;$outOfSpace$0$off0 = 1;
     }
    } else {
     $349 = $$lcssa104;$outOfSpace$0$off0 = 0;
    }
   } else {
    $349 = $$lcssa104;$outOfSpace$0$off0 = 0;
   }
   $344 = HEAP32[$6>>2]|0;
   $345 = (($344) + 76|0);
   $346 = HEAP32[$345>>2]|0;
   $347 = ($346|0)==(-2);
   if ($347) {
    $350 = (($this) + 188|0);
    $351 = Math_fround(HEAPF32[$350>>2]);
    $352 = Math_fround($349 / $351);
    $353 = (Math_fround(__ZNK20TextRenderingPrivate4Font22GetFontSizeFromSpacingEf($344,$352)));
    $354 = HEAP32[$6>>2]|0;
    $355 = (($354) + 208|0);
    $356 = Math_fround(HEAPF32[$355>>2]);
    $357 = (($354) + 32|0);
    $358 = HEAP32[$357>>2]|0;
    $359 = (Math_fround(($358|0)));
    $360 = Math_fround($353 / $359);
    $361 = Math_fround($360 + Math_fround(-1.0));
    $362 = Math_fround($356 * $361);
    $363 = HEAP8[$21>>0]|0;
    $364 = ($363<<24>>24)==(0);
    if ($364) {
     $$0$i = $362;
    } else {
     $365 = Math_fround($362 + Math_fround(0.5));
     $floorf$i$i$i$i$i35 = (Math_fround(Math_floor((Math_fround($365)))));
     $$0$i = $floorf$i$i$i$i$i35;
    }
   } else {
    $348 = Math_fround($349 - $316);
    $$0$i = $348;
   }
   $366 = $$0$i != Math_fround(0.0);
   $367 = HEAP32[$298>>2]|0;
   if ($366) {
    $368 = (($this) + 308|0);
    $369 = HEAP32[$368>>2]|0;
    $370 = (($369) + ($367<<3)|0);
    $$ = $outOfSpace$0$off0 ? $25 : $296;
    $371 = HEAP32[$$>>2]|0;
    $372 = (($371) - ($367))|0;
    $373 = ($371|0)==($367|0);
    if (!($373)) {
     $374 = (($this) + 376|0);
     $375 = HEAP32[$374>>2]|0;
     $376 = $367 << 2;
     $377 = (($375) + (($376*60)|0)|0);
     $378 = $372 << 2;
     $$025$i28 = $377;$vertexCount$06$i27 = $378;
     while(1) {
      $379 = (($vertexCount$06$i27) + -1)|0;
      $380 = Math_fround(HEAPF32[$$025$i28>>2]);
      $381 = Math_fround($380 + Math_fround(0.0));
      HEAPF32[$$025$i28>>2] = $381;
      $382 = (($$025$i28) + 4|0);
      $383 = Math_fround(HEAPF32[$382>>2]);
      $384 = Math_fround($$0$i + $383);
      HEAPF32[$382>>2] = $384;
      $385 = (($$025$i28) + 60|0);
      $386 = ($379|0)==(0);
      if ($386) {
       break;
      } else {
       $$025$i28 = $385;$vertexCount$06$i27 = $379;
      }
     }
     $387 = ($370|0)==(0|0);
     if (!($387)) {
      $$013$i33 = $370;$$04$i32 = $372;
      while(1) {
       $388 = (($$04$i32) + -1)|0;
       $389 = Math_fround(HEAPF32[$$013$i33>>2]);
       $390 = Math_fround($389 + Math_fround(0.0));
       HEAPF32[$$013$i33>>2] = $390;
       $391 = (($$013$i33) + 4|0);
       $392 = Math_fround(HEAPF32[$391>>2]);
       $393 = Math_fround($$0$i + $392);
       HEAPF32[$391>>2] = $393;
       $394 = (($$013$i33) + 8|0);
       $395 = ($388|0)==(0);
       if ($395) {
        break;
       } else {
        $$013$i33 = $394;$$04$i32 = $388;
       }
      }
     }
    }
   }
   __ZN20TextRenderingPrivate19NativeTextGenerator15RegisterNewLineEif($this,$367,$349);
   if ($outOfSpace$0$off0) {
    $396 = HEAP32[$104>>2]|0;
    $397 = (($396) + -240|0);
    HEAP32[$104>>2] = $397;
    $398 = Math_fround(HEAPF32[$106>>2]);
    $399 = (($this) + 252|0);
    $400 = Math_fround(HEAPF32[$399>>2]);
    $401 = Math_fround($398 - $400);
    $402 = HEAP32[$298>>2]|0;
    $403 = $402 << 2;
    $404 = (($this) + 376|0);
    $405 = HEAP32[$404>>2]|0;
    $406 = (($405) + (($403*60)|0)|0);
    $407 = (($this) + 308|0);
    $408 = HEAP32[$407>>2]|0;
    $409 = (($408) + ($402<<3)|0);
    $410 = HEAP32[$25>>2]|0;
    $411 = (($this) + 256|0);
    $412 = HEAP32[$411>>2]|0;
    $413 = (($410) - ($412))|0;
    $414 = (($413) - ($402))|0;
    $415 = (($this) + 164|0);
    $416 = HEAP32[$415>>2]|0;
    if ((($416|0) == 2)) {
     $417 = ($413|0)==($402|0);
     if (!($417)) {
      $418 = $414 << 2;
      $$025$i6$i8 = $406;$vertexCount$06$i5$i7 = $418;
      while(1) {
       $419 = (($vertexCount$06$i5$i7) + -1)|0;
       $420 = Math_fround(HEAPF32[$$025$i6$i8>>2]);
       $421 = Math_fround($420 - $401);
       HEAPF32[$$025$i6$i8>>2] = $421;
       $422 = (($$025$i6$i8) + 4|0);
       $423 = Math_fround(HEAPF32[$422>>2]);
       $424 = Math_fround($423 + Math_fround(0.0));
       HEAPF32[$422>>2] = $424;
       $425 = (($$025$i6$i8) + 60|0);
       $426 = ($419|0)==(0);
       if ($426) {
        break;
       } else {
        $$025$i6$i8 = $425;$vertexCount$06$i5$i7 = $419;
       }
      }
      $427 = ($409|0)==(0|0);
      if (!($427)) {
       $$013$i11$i11 = $409;$$04$i10$i10 = $414;
       while(1) {
        $428 = (($$04$i10$i10) + -1)|0;
        $429 = Math_fround(HEAPF32[$$013$i11$i11>>2]);
        $430 = Math_fround($429 - $401);
        HEAPF32[$$013$i11$i11>>2] = $430;
        $431 = (($$013$i11$i11) + 4|0);
        $432 = Math_fround(HEAPF32[$431>>2]);
        $433 = Math_fround($432 + Math_fround(0.0));
        HEAPF32[$431>>2] = $433;
        $434 = (($$013$i11$i11) + 8|0);
        $435 = ($428|0)==(0);
        if ($435) {
         break;
        } else {
         $$013$i11$i11 = $434;$$04$i10$i10 = $428;
        }
       }
      }
     }
    } else if ((($416|0) == 1)) {
     $436 = Math_fround($401 * Math_fround(-0.5));
     $437 = HEAP8[$21>>0]|0;
     $438 = ($437<<24>>24)==(0);
     if ($438) {
      $$0$i$i$i14 = $436;
     } else {
      $439 = Math_fround($436 + Math_fround(0.5));
      $floorf$i$i$i$i$i13 = (Math_fround(Math_floor((Math_fround($439)))));
      $$0$i$i$i14 = $floorf$i$i$i$i$i13;
     }
     $440 = ($413|0)==($402|0);
     if (!($440)) {
      $441 = $414 << 2;
      $$025$i$i18 = $406;$vertexCount$06$i$i17 = $441;
      while(1) {
       $442 = (($vertexCount$06$i$i17) + -1)|0;
       $443 = Math_fround(HEAPF32[$$025$i$i18>>2]);
       $444 = Math_fround($$0$i$i$i14 + $443);
       HEAPF32[$$025$i$i18>>2] = $444;
       $445 = (($$025$i$i18) + 4|0);
       $446 = Math_fround(HEAPF32[$445>>2]);
       $447 = Math_fround($446 + Math_fround(0.0));
       HEAPF32[$445>>2] = $447;
       $448 = (($$025$i$i18) + 60|0);
       $449 = ($442|0)==(0);
       if ($449) {
        break;
       } else {
        $$025$i$i18 = $448;$vertexCount$06$i$i17 = $442;
       }
      }
      $450 = ($409|0)==(0|0);
      if (!($450)) {
       $$013$i$i21 = $409;$$04$i$i20 = $414;
       while(1) {
        $451 = (($$04$i$i20) + -1)|0;
        $452 = Math_fround(HEAPF32[$$013$i$i21>>2]);
        $453 = Math_fround($$0$i$i$i14 + $452);
        HEAPF32[$$013$i$i21>>2] = $453;
        $454 = (($$013$i$i21) + 4|0);
        $455 = Math_fround(HEAPF32[$454>>2]);
        $456 = Math_fround($455 + Math_fround(0.0));
        HEAPF32[$454>>2] = $456;
        $457 = (($$013$i$i21) + 8|0);
        $458 = ($451|0)==(0);
        if ($458) {
         break;
        } else {
         $$013$i$i21 = $457;$$04$i$i20 = $451;
        }
       }
      }
     }
    }
    $459 = (($this) + 260|0);
    $460 = Math_fround(HEAPF32[$459>>2]);
    $461 = Math_fround(HEAPF32[$106>>2]);
    $462 = $460 < $461;
    $463 = $462 ? $461 : $460;
    HEAPF32[$459>>2] = $463;
    $464 = Math_fround(HEAPF32[$110>>2]);
    $465 = Math_fround($349 + $464);
    HEAPF32[$110>>2] = $465;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $466 = (($this) + 244|0);
   $467 = Math_fround(HEAPF32[$466>>2]);
   $468 = HEAP32[$298>>2]|0;
   $469 = $468 << 2;
   $470 = (($this) + 376|0);
   $471 = HEAP32[$470>>2]|0;
   $472 = (($471) + (($469*60)|0)|0);
   $473 = (($this) + 308|0);
   $474 = HEAP32[$473>>2]|0;
   $475 = (($474) + ($468<<3)|0);
   $476 = HEAP32[$296>>2]|0;
   $477 = (($476) - ($468))|0;
   $478 = (($this) + 164|0);
   $479 = HEAP32[$478>>2]|0;
   if ((($479|0) == 1)) {
    $499 = Math_fround($467 * Math_fround(-0.5));
    $500 = HEAP8[$21>>0]|0;
    $501 = ($500<<24>>24)==(0);
    if ($501) {
     $$0$i$i$i = $499;
    } else {
     $502 = Math_fround($499 + Math_fround(0.5));
     $floorf$i$i$i$i$i = (Math_fround(Math_floor((Math_fround($502)))));
     $$0$i$i$i = $floorf$i$i$i$i$i;
    }
    $503 = ($476|0)==($468|0);
    if (!($503)) {
     $504 = $477 << 2;
     $$025$i$i = $472;$vertexCount$06$i$i = $504;
     while(1) {
      $505 = (($vertexCount$06$i$i) + -1)|0;
      $506 = Math_fround(HEAPF32[$$025$i$i>>2]);
      $507 = Math_fround($$0$i$i$i + $506);
      HEAPF32[$$025$i$i>>2] = $507;
      $508 = (($$025$i$i) + 4|0);
      $509 = Math_fround(HEAPF32[$508>>2]);
      $510 = Math_fround($509 + Math_fround(0.0));
      HEAPF32[$508>>2] = $510;
      $511 = (($$025$i$i) + 60|0);
      $512 = ($505|0)==(0);
      if ($512) {
       break;
      } else {
       $$025$i$i = $511;$vertexCount$06$i$i = $505;
      }
     }
     $513 = ($475|0)==(0|0);
     if (!($513)) {
      $$013$i$i = $475;$$04$i$i = $477;
      while(1) {
       $514 = (($$04$i$i) + -1)|0;
       $515 = Math_fround(HEAPF32[$$013$i$i>>2]);
       $516 = Math_fround($$0$i$i$i + $515);
       HEAPF32[$$013$i$i>>2] = $516;
       $517 = (($$013$i$i) + 4|0);
       $518 = Math_fround(HEAPF32[$517>>2]);
       $519 = Math_fround($518 + Math_fround(0.0));
       HEAPF32[$517>>2] = $519;
       $520 = (($$013$i$i) + 8|0);
       $521 = ($514|0)==(0);
       if ($521) {
        break;
       } else {
        $$013$i$i = $520;$$04$i$i = $514;
       }
      }
     }
    }
   } else if ((($479|0) == 2)) {
    $480 = ($476|0)==($468|0);
    if (!($480)) {
     $481 = $477 << 2;
     $$025$i6$i = $472;$vertexCount$06$i5$i = $481;
     while(1) {
      $482 = (($vertexCount$06$i5$i) + -1)|0;
      $483 = Math_fround(HEAPF32[$$025$i6$i>>2]);
      $484 = Math_fround($483 - $467);
      HEAPF32[$$025$i6$i>>2] = $484;
      $485 = (($$025$i6$i) + 4|0);
      $486 = Math_fround(HEAPF32[$485>>2]);
      $487 = Math_fround($486 + Math_fround(0.0));
      HEAPF32[$485>>2] = $487;
      $488 = (($$025$i6$i) + 60|0);
      $489 = ($482|0)==(0);
      if ($489) {
       break;
      } else {
       $$025$i6$i = $488;$vertexCount$06$i5$i = $482;
      }
     }
     $490 = ($475|0)==(0|0);
     if (!($490)) {
      $$013$i11$i = $475;$$04$i10$i = $477;
      while(1) {
       $491 = (($$04$i10$i) + -1)|0;
       $492 = Math_fround(HEAPF32[$$013$i11$i>>2]);
       $493 = Math_fround($492 - $467);
       HEAPF32[$$013$i11$i>>2] = $493;
       $494 = (($$013$i11$i) + 4|0);
       $495 = Math_fround(HEAPF32[$494>>2]);
       $496 = Math_fround($495 + Math_fround(0.0));
       HEAPF32[$494>>2] = $496;
       $497 = (($$013$i11$i) + 8|0);
       $498 = ($491|0)==(0);
       if ($498) {
        break;
       } else {
        $$013$i11$i = $497;$$04$i10$i = $491;
       }
      }
     }
    }
   }
   $522 = (($this) + 260|0);
   $523 = (($this) + 248|0);
   $524 = Math_fround(HEAPF32[$522>>2]);
   $525 = Math_fround(HEAPF32[$523>>2]);
   $526 = $524 < $525;
   $527 = $526 ? $525 : $524;
   HEAPF32[$522>>2] = $527;
   $528 = Math_fround(HEAPF32[$110>>2]);
   $529 = Math_fround($349 + $528);
   HEAPF32[$110>>2] = $529;
   $530 = (($474) + ($476<<3)|0);
   $531 = HEAP32[$25>>2]|0;
   $532 = (($531) - ($476))|0;
   $533 = (($532) + 1)|0;
   $534 = ($533|0)==(0);
   if (!($534)) {
    $535 = $476 << 2;
    $536 = (($471) + (($535*60)|0)|0);
    $537 = $533 << 2;
    $$025$i = $536;$vertexCount$06$i = $537;
    while(1) {
     $538 = (($vertexCount$06$i) + -1)|0;
     $539 = Math_fround(HEAPF32[$$025$i>>2]);
     $540 = Math_fround($539 - $525);
     HEAPF32[$$025$i>>2] = $540;
     $541 = (($$025$i) + 4|0);
     $542 = Math_fround(HEAPF32[$541>>2]);
     $543 = Math_fround($349 + $542);
     HEAPF32[$541>>2] = $543;
     $544 = (($$025$i) + 60|0);
     $545 = ($538|0)==(0);
     if ($545) {
      break;
     } else {
      $$025$i = $544;$vertexCount$06$i = $538;
     }
    }
    $546 = ($530|0)==(0|0);
    if (!($546)) {
     $$013$i = $530;$$04$i = $533;
     while(1) {
      $547 = (($$04$i) + -1)|0;
      $548 = Math_fround(HEAPF32[$$013$i>>2]);
      $549 = Math_fround($548 - $525);
      HEAPF32[$$013$i>>2] = $549;
      $550 = (($$013$i) + 4|0);
      $551 = Math_fround(HEAPF32[$550>>2]);
      $552 = Math_fround($349 + $551);
      HEAPF32[$550>>2] = $552;
      $553 = (($$013$i) + 8|0);
      $554 = ($547|0)==(0);
      if ($554) {
       break;
      } else {
       $$013$i = $553;$$04$i = $547;
      }
     }
    }
   }
   $555 = Math_fround(HEAPF32[$523>>2]);
   $556 = Math_fround(HEAPF32[$106>>2]);
   $557 = Math_fround($556 - $555);
   HEAPF32[$106>>2] = $557;
   $558 = (($this) + 240|0);
   $559 = Math_fround(HEAPF32[$558>>2]);
   $560 = (($this) + 236|0);
   HEAPF32[$560>>2] = $559;
   HEAP32[$298>>2] = $476;
   HEAPF32[$523>>2] = Math_fround(0.0);
   $561 = (($this) + 220|0);
   HEAP32[$561>>2] = $476;
   $566 = $557;
  } else {
   $566 = $293;
  }
 } else {
  $566 = $293;
 }
 $562 = (($this) + 240|0);
 $563 = Math_fround(HEAPF32[$562>>2]);
 $564 = Math_fround($$0$i$i + $563);
 HEAPF32[$562>>2] = $564;
 $565 = Math_fround($$0$i$i + $566);
 HEAPF32[$106>>2] = $565;
 $567 = (($this) + 252|0);
 $568 = Math_fround(HEAPF32[$567>>2]);
 $569 = Math_fround($$0$i$i + $568);
 $570 = (($this) + 236|0);
 $571 = Math_fround(HEAPF32[$570>>2]);
 $572 = Math_fround($571 + $569);
 HEAPF32[$570>>2] = $572;
 HEAPF32[$567>>2] = Math_fround(0.0);
 $573 = (($this) + 256|0);
 HEAP32[$573>>2] = 0;
 $574 = (($this) + 208|0);
 HEAP32[$574>>2] = $c;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13dynamic_arrayItLj2EE9push_backERKt($this,$t) {
 $this = $this|0;
 $t = $t|0;
 var $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = HEAP16[$t>>1]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[$2>>2] = $4;
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 2147483647;
 $8 = ($4>>>0)>($7>>>0);
 if (!($8)) {
  $27 = $4;
  $26 = (($27) + -1)|0;
  $28 = HEAP32[$this>>2]|0;
  $29 = (($28) + ($26<<1)|0);
  HEAP16[$29>>1] = $1;
  STACKTOP = sp;return;
 }
 $9 = $6 << 1;
 $10 = ($9|0)==(0);
 $11 = $10 ? 1 : $9;
 $12 = ($7>>>0)<($11>>>0);
 do {
  if ($12) {
   $13 = ($6|0)>(-1);
   if ($13) {
    HEAP32[$5>>2] = $11;
    $14 = HEAP32[$this>>2]|0;
    $15 = $11 << 1;
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,2,$$byval_copy1,0,805760,370)|0);
    HEAP32[$this>>2] = $18;
    break;
   } else {
    $19 = $11 << 1;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,2,$$byval_copy1,0,805760,352)|0);
    $23 = HEAP32[$this>>2]|0;
    $24 = HEAP32[$2>>2]|0;
    $25 = $24 << 1;
    _memcpy(($22|0),($23|0),($25|0))|0;
    HEAP32[$5>>2] = $11;
    HEAP32[$this>>2] = $22;
    break;
   }
  }
 } while(0);
 $$pre$i = HEAP32[$2>>2]|0;
 $27 = $$pre$i;
 $26 = (($27) + -1)|0;
 $28 = HEAP32[$this>>2]|0;
 $29 = (($28) + ($26<<1)|0);
 HEAP16[$29>>1] = $1;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate19NativeTextGenerator24ProcessFormatForPositionEv($this) {
 $this = $this|0;
 var $$ = Math_fround(0), $$0$i = Math_fround(0), $$0$i$i = Math_fround(0), $$0$i$i21 = Math_fround(0), $$0$i2$i$i = 0, $$0$i2$i$i14 = 0, $$0$i2$i$i6 = 0, $$0$i3$i$i = 0, $$0$i3$i$i16 = 0, $$0$i3$i$i8 = 0, $$lcssa = 0, $$lcssa63 = 0, $$pre = 0, $$pre$phi83Z2D = 0, $$pre$phiZ2D = 0, $$pre78 = 0, $$pre81 = 0, $$pre82 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = Math_fround(0), $135 = Math_fround(0);
 var $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0);
 var $154 = 0, $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = Math_fround(0), $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = Math_fround(0), $177 = Math_fround(0), $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0);
 var $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = Math_fround(0), $258 = Math_fround(0), $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0);
 var $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = Math_fround(0), $297 = 0, $298 = Math_fround(0);
 var $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = Math_fround(0), $301 = Math_fround(0), $302 = Math_fround(0), $303 = 0, $304 = Math_fround(0), $305 = Math_fround(0), $306 = 0, $307 = 0, $308 = 0, $309 = Math_fround(0), $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $floorf$i$i$i$i = Math_fround(0), $floorf$i$i$i$i20 = Math_fround(0), $j$065 = 0, $phitmp = 0;
 var $size$1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 10|0;
 $1 = sp;
 $2 = sp + 2|0;
 $3 = sp + 4|0;
 $4 = sp + 6|0;
 $5 = sp + 8|0;
 $6 = (($this) + 200|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$this>>2]|0;
 $11 = $9;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = (($13|0) / 44)&-1;
 $15 = ($7|0)<($14|0);
 L1: do {
  if ($15) {
   $16 = (($this) + 204|0);
   $17 = (($this) + 224|0);
   $18 = (($this) + 276|0);
   $19 = (($this) + 372|0);
   $20 = (($this) + 280|0);
   $21 = (($this) + 144|0);
   $22 = (($this) + 264|0);
   $23 = (($this) + 268|0);
   $24 = (($this) + 272|0);
   $25 = (($this) + 177|0);
   $26 = (($this) + 236|0);
   $27 = (($this) + 232|0);
   $28 = (($this) + 264|0);
   $29 = (($this) + 296|0);
   $30 = (($this) + 300|0);
   $31 = (($this) + 292|0);
   $34 = $10;$35 = $7;
   L3: while(1) {
    $32 = HEAP32[$16>>2]|0;
    $33 = (($34) + (($35*44)|0)|0);
    $36 = HEAP32[$33>>2]|0;
    $37 = ($32|0)<($36|0);
    if ($37) {
     $$pre$phi83Z2D = $21;$$pre$phiZ2D = $20;
     break L1;
    }
    $38 = ((($34) + (($35*44)|0)|0) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + ($32))|0;
    HEAP32[$16>>2] = $40;
    $41 = HEAP32[$17>>2]|0;
    $42 = ($40|0)>($41|0);
    if ($42) {
     break;
    }
    $43 = HEAP32[$38>>2]|0;
    $44 = ($43|0)>(0);
    L7: do {
     if ($44) {
      $j$065 = 1;
      while(1) {
       $72 = HEAP32[$19>>2]|0;
       $73 = (($72) + 60|0);
       $74 = (($72) + 120|0);
       $75 = (($72) + 180|0);
       ;HEAP32[$75+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$28+8>>2]|0;
       _memmove(($74|0),($28|0),12)|0;
       ;HEAP32[$73+0>>2]=HEAP32[$74+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$74+8>>2]|0;
       ;HEAP32[$72+0>>2]=HEAP32[$74+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$74+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$74+8>>2]|0;
       $76 = HEAP32[$19>>2]|0;
       $77 = (($76) + 240|0);
       HEAP32[$19>>2] = $77;
       $78 = HEAP32[$29>>2]|0;
       $79 = HEAP32[$30>>2]|0;
       $80 = ($78|0)==($79|0);
       if ($80) {
        $84 = HEAP32[$31>>2]|0;
        $85 = $78;
        $86 = $84;
        $87 = (($85) - ($86))|0;
        $88 = $87 >> 2;
        $89 = (($88) + 1)|0;
        $90 = ($89>>>0)>(1073741823);
        if ($90) {
         label = 25;
         break L3;
        }
        $91 = ($88>>>0)<(536870911);
        if ($91) {
         $92 = $87 >> 1;
         $93 = ($92>>>0)<($89>>>0);
         $94 = $93 ? $89 : $92;
         $95 = ($94|0)==(0);
         if ($95) {
          $$0$i3$i$i16 = 0;$99 = 0;
         } else {
          $$0$i2$i$i14 = $94;
          label = 28;
         }
        } else {
         $$0$i2$i$i14 = 1073741823;
         label = 28;
        }
        if ((label|0) == 28) {
         label = 0;
         $96 = $$0$i2$i$i14 << 2;
         $97 = (__Znwj($96)|0);
         $$0$i3$i$i16 = $$0$i2$i$i14;$99 = $97;
        }
        $98 = (($99) + ($88<<2)|0);
        $100 = (($99) + ($$0$i3$i$i16<<2)|0);
        $101 = ($98|0)==(0|0);
        if (!($101)) {
         $102 = Math_fround(HEAPF32[$27>>2]);
         HEAPF32[$98>>2] = $102;
        }
        $103 = (($99) + ($89<<2)|0);
        _memcpy(($99|0),($84|0),($87|0))|0;
        HEAP32[$31>>2] = $99;
        HEAP32[$29>>2] = $103;
        HEAP32[$30>>2] = $100;
        $104 = ($84|0)==(0|0);
        if (!($104)) {
         __ZdlPv($84);
        }
       } else {
        $81 = ($78|0)==(0|0);
        if (!($81)) {
         $82 = Math_fround(HEAPF32[$27>>2]);
         HEAPF32[$78>>2] = $82;
        }
        $83 = (($78) + 4|0);
        HEAP32[$29>>2] = $83;
       }
       $105 = HEAP32[$6>>2]|0;
       $106 = HEAP32[$this>>2]|0;
       $107 = ((($106) + (($105*44)|0)|0) + 4|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ($j$065|0)<($108|0);
       if (!($109)) {
        $$lcssa = $105;$$lcssa63 = $106;
        break L7;
       }
       $phitmp = (($j$065) + 1)|0;
       $j$065 = $phitmp;
      }
     } else {
      $$lcssa = $35;$$lcssa63 = $34;
     }
    } while(0);
    $110 = (($$lcssa63) + (($$lcssa*44)|0)|0);
    __ZN20TextRenderingPrivate11FormatStack10PushFormatERNS_16TextFormatChangeE($18,$110);
    $111 = HEAP32[$6>>2]|0;
    $112 = HEAP32[$this>>2]|0;
    $113 = ((($112) + (($111*44)|0)|0) + 40|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = $114 & 32800;
    $116 = ($115|0)==(32);
    if ($116) {
     $117 = HEAP32[$19>>2]|0;
     $118 = (($117) + -240|0);
     HEAP32[$19>>2] = $118;
     $119 = HEAP32[$20>>2]|0;
     $120 = (($119) + -24|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = (Math_fround(($121|0)));
     $123 = HEAP32[$21>>2]|0;
     $124 = (($123) + 32|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = ($125|0)==(0);
     if ($126) {
      $133 = (($123) + 208|0);
      $134 = Math_fround(HEAPF32[$133>>2]);
      $139 = $134;$size$1 = $134;
     } else {
      $127 = $122 == Math_fround(0.0);
      $128 = (Math_fround(($125|0)));
      $$ = $127 ? $128 : $122;
      $129 = Math_fround($$ / $128);
      $130 = (($123) + 208|0);
      $131 = Math_fround(HEAPF32[$130>>2]);
      $132 = Math_fround($129 * $131);
      $139 = $131;$size$1 = $132;
     }
     $135 = Math_fround(HEAPF32[$22>>2]);
     $136 = Math_fround($135 + Math_fround(0.0));
     $137 = Math_fround(HEAPF32[$23>>2]);
     $138 = Math_fround($139 + $137);
     $140 = Math_fround(HEAPF32[$24>>2]);
     $141 = Math_fround($140 + Math_fround(0.0));
     $142 = ((($112) + (($111*44)|0)|0) + 32|0);
     $143 = Math_fround(HEAPF32[$142>>2]);
     $144 = ((($112) + (($111*44)|0)|0) + 36|0);
     $145 = Math_fround(HEAPF32[$144>>2]);
     $146 = Math_fround($143 / $145);
     $147 = Math_fround($138 - $size$1);
     HEAPF32[$118>>2] = $136;
     $148 = (($117) + -236|0);
     HEAPF32[$148>>2] = $147;
     $149 = (($117) + -232|0);
     HEAPF32[$149>>2] = $141;
     $150 = HEAP32[$19>>2]|0;
     $151 = (($150) + 28|0);
     $152 = ((($112) + (($111*44)|0)|0) + 24|0);
     $153 = Math_fround(HEAPF32[$152>>2]);
     $154 = ((($112) + (($111*44)|0)|0) + 28|0);
     $155 = Math_fround(HEAPF32[$154>>2]);
     $156 = Math_fround(HEAPF32[$144>>2]);
     $157 = Math_fround($155 + $156);
     $158 = (HEAPF32[tempDoublePtr>>2]=$153,HEAP32[tempDoublePtr>>2]|0);
     $159 = (HEAPF32[tempDoublePtr>>2]=$157,HEAP32[tempDoublePtr>>2]|0);
     $160 = $151;
     $161 = $160;
     HEAP32[$161>>2] = $158;
     $162 = (($160) + 4)|0;
     $163 = $162;
     HEAP32[$163>>2] = $159;
     $164 = HEAP32[$19>>2]|0;
     $165 = Math_fround($size$1 * $146);
     $166 = Math_fround($136 + $165);
     $167 = (($164) + 60|0);
     HEAPF32[$167>>2] = $166;
     $168 = (($164) + 64|0);
     HEAPF32[$168>>2] = $147;
     $169 = (($164) + 68|0);
     HEAPF32[$169>>2] = $141;
     $170 = HEAP32[$19>>2]|0;
     $171 = (($170) + 88|0);
     $172 = Math_fround(HEAPF32[$152>>2]);
     $173 = Math_fround(HEAPF32[$142>>2]);
     $174 = Math_fround($172 + $173);
     $175 = Math_fround(HEAPF32[$154>>2]);
     $176 = Math_fround(HEAPF32[$144>>2]);
     $177 = Math_fround($175 + $176);
     $178 = (HEAPF32[tempDoublePtr>>2]=$174,HEAP32[tempDoublePtr>>2]|0);
     $179 = (HEAPF32[tempDoublePtr>>2]=$177,HEAP32[tempDoublePtr>>2]|0);
     $180 = $171;
     $181 = $180;
     HEAP32[$181>>2] = $178;
     $182 = (($180) + 4)|0;
     $183 = $182;
     HEAP32[$183>>2] = $179;
     $184 = HEAP32[$19>>2]|0;
     $185 = Math_fround($138 + Math_fround(0.0));
     $186 = (($184) + 120|0);
     HEAPF32[$186>>2] = $166;
     $187 = (($184) + 124|0);
     HEAPF32[$187>>2] = $185;
     $188 = (($184) + 128|0);
     HEAPF32[$188>>2] = $141;
     $189 = HEAP32[$19>>2]|0;
     $190 = (($189) + 148|0);
     $191 = Math_fround(HEAPF32[$152>>2]);
     $192 = Math_fround(HEAPF32[$142>>2]);
     $193 = Math_fround($191 + $192);
     $194 = Math_fround(HEAPF32[$154>>2]);
     $195 = (HEAPF32[tempDoublePtr>>2]=$193,HEAP32[tempDoublePtr>>2]|0);
     $196 = (HEAPF32[tempDoublePtr>>2]=$194,HEAP32[tempDoublePtr>>2]|0);
     $197 = $190;
     $198 = $197;
     HEAP32[$198>>2] = $195;
     $199 = (($197) + 4)|0;
     $200 = $199;
     HEAP32[$200>>2] = $196;
     $201 = HEAP32[$19>>2]|0;
     $202 = (($201) + 180|0);
     HEAPF32[$202>>2] = $136;
     $203 = (($201) + 184|0);
     HEAPF32[$203>>2] = $185;
     $204 = (($201) + 188|0);
     HEAPF32[$204>>2] = $141;
     $205 = HEAP32[$19>>2]|0;
     $206 = (($205) + 208|0);
     $207 = Math_fround(HEAPF32[$152>>2]);
     $208 = Math_fround(HEAPF32[$154>>2]);
     $209 = (HEAPF32[tempDoublePtr>>2]=$207,HEAP32[tempDoublePtr>>2]|0);
     $210 = (HEAPF32[tempDoublePtr>>2]=$208,HEAP32[tempDoublePtr>>2]|0);
     $211 = $206;
     $212 = $211;
     HEAP32[$212>>2] = $209;
     $213 = (($211) + 4)|0;
     $214 = $213;
     HEAP32[$214>>2] = $210;
     $215 = HEAP32[$20>>2]|0;
     $216 = (($215) + -28|0);
     $217 = HEAP8[((640792 + 258|0))>>0]|0;
     $218 = ($217<<24>>24)==(0);
     if ($218) {
      $226 = HEAP32[$216>>2]|0;
      $227 = $226&255;
      $228 = $226 >>> 8;
      $229 = $228&255;
      $230 = $226 >>> 16;
      $231 = $230&255;
      $232 = $226 >>> 24;
      $233 = $232&255;
      $240 = $233;$243 = $231;$247 = $229;$251 = $227;
     } else {
      $219 = (($215) + -26|0);
      $220 = HEAP8[$219>>0]|0;
      $221 = (($215) + -27|0);
      $222 = HEAP8[$221>>0]|0;
      $223 = HEAP8[$216>>0]|0;
      $224 = (($215) + -25|0);
      $225 = HEAP8[$224>>0]|0;
      $240 = $225;$243 = $223;$247 = $222;$251 = $220;
     }
     $234 = HEAP32[$19>>2]|0;
     $235 = (($234) + 24|0);
     $236 = (($234) + 84|0);
     $237 = (($234) + 144|0);
     $238 = (($234) + 204|0);
     $239 = $240&255;
     $241 = $239 << 24;
     $242 = $243&255;
     $244 = $242 << 16;
     $245 = $244 | $241;
     $246 = $247&255;
     $248 = $246 << 8;
     $249 = $245 | $248;
     $250 = $251&255;
     $252 = $249 | $250;
     HEAP32[$238>>2] = $252;
     HEAP32[$237>>2] = $252;
     HEAP32[$236>>2] = $252;
     HEAP32[$235>>2] = $252;
     $253 = HEAP8[$25>>0]|0;
     $254 = ($253<<24>>24)==(0);
     if ($254) {
      $$0$i$i21 = $165;
     } else {
      $255 = Math_fround($165 + Math_fround(0.5));
      $floorf$i$i$i$i20 = (Math_fround(Math_floor((Math_fround($255)))));
      $$0$i$i21 = $floorf$i$i$i$i20;
     }
     $256 = Math_fround(HEAPF32[$22>>2]);
     $257 = Math_fround($$0$i$i21 + $256);
     HEAPF32[$22>>2] = $257;
     $258 = Math_fround(HEAPF32[$23>>2]);
     $259 = Math_fround($258 + Math_fround(0.0));
     HEAPF32[$23>>2] = $259;
     $260 = Math_fround(HEAPF32[$24>>2]);
     $261 = Math_fround($260 + Math_fround(0.0));
     HEAPF32[$24>>2] = $261;
     HEAPF32[$26>>2] = $257;
     $262 = Math_fround(HEAPF32[$27>>2]);
     $263 = $262 < $165;
     if ($263) {
      HEAPF32[$27>>2] = $165;
     }
     $264 = (($234) + 240|0);
     HEAP32[$19>>2] = $264;
     $265 = HEAP32[$16>>2]|0;
     $266 = $265 << 2;
     $267 = (($266) + 65532)|0;
     $268 = (($215) + -20|0);
     $269 = HEAP32[$268>>2]|0;
     $270 = ((($this) + ($269<<4)|0) + 12|0);
     $271 = (($266) + 65533)|0;
     $272 = $271&65535;
     HEAP16[$0>>1] = $272;
     __ZN13dynamic_arrayItLj2EE9push_backERKt($270,$0);
     $273 = (($266) + 65534)|0;
     $274 = $273&65535;
     HEAP16[$1>>1] = $274;
     __ZN13dynamic_arrayItLj2EE9push_backERKt($270,$1);
     $275 = $267&65535;
     HEAP16[$2>>1] = $275;
     __ZN13dynamic_arrayItLj2EE9push_backERKt($270,$2);
     HEAP16[$3>>1] = $274;
     __ZN13dynamic_arrayItLj2EE9push_backERKt($270,$3);
     $276 = (($266) + 65535)|0;
     $277 = $276&65535;
     HEAP16[$4>>1] = $277;
     __ZN13dynamic_arrayItLj2EE9push_backERKt($270,$4);
     HEAP16[$5>>1] = $275;
     __ZN13dynamic_arrayItLj2EE9push_backERKt($270,$5);
     $$pre = HEAP32[$6>>2]|0;
     $$pre78 = HEAP32[$this>>2]|0;
     $279 = $$pre;$283 = $$pre78;
    } else {
     $279 = $111;$283 = $112;
    }
    $278 = (($279) + 1)|0;
    HEAP32[$6>>2] = $278;
    $280 = HEAP32[$8>>2]|0;
    $281 = $280;
    $282 = $283;
    $284 = (($281) - ($282))|0;
    $285 = (($284|0) / 44)&-1;
    $286 = ($278|0)<($285|0);
    if ($286) {
     $34 = $283;$35 = $278;
    } else {
     $$pre$phi83Z2D = $21;$$pre$phiZ2D = $20;
     break L1;
    }
   }
   if ((label|0) == 25) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   HEAP32[$16>>2] = $41;
   $45 = HEAP32[$29>>2]|0;
   $46 = HEAP32[$30>>2]|0;
   $47 = ($45|0)==($46|0);
   if (!($47)) {
    $48 = ($45|0)==(0|0);
    if (!($48)) {
     $49 = Math_fround(HEAPF32[$27>>2]);
     HEAPF32[$45>>2] = $49;
    }
    $50 = (($45) + 4|0);
    HEAP32[$29>>2] = $50;
    STACKTOP = sp;return;
   }
   $51 = HEAP32[$31>>2]|0;
   $52 = $45;
   $53 = $51;
   $54 = (($52) - ($53))|0;
   $55 = $54 >> 2;
   $56 = (($55) + 1)|0;
   $57 = ($56>>>0)>(1073741823);
   if ($57) {
    __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $58 = ($55>>>0)<(536870911);
   if ($58) {
    $59 = $54 >> 1;
    $60 = ($59>>>0)<($56>>>0);
    $61 = $60 ? $56 : $59;
    $62 = ($61|0)==(0);
    if ($62) {
     $$0$i3$i$i8 = 0;$66 = 0;
    } else {
     $$0$i2$i$i6 = $61;
     label = 15;
    }
   } else {
    $$0$i2$i$i6 = 1073741823;
    label = 15;
   }
   if ((label|0) == 15) {
    $63 = $$0$i2$i$i6 << 2;
    $64 = (__Znwj($63)|0);
    $$0$i3$i$i8 = $$0$i2$i$i6;$66 = $64;
   }
   $65 = (($66) + ($55<<2)|0);
   $67 = (($66) + ($$0$i3$i$i8<<2)|0);
   $68 = ($65|0)==(0|0);
   if (!($68)) {
    $69 = Math_fround(HEAPF32[$27>>2]);
    HEAPF32[$65>>2] = $69;
   }
   $70 = (($66) + ($56<<2)|0);
   _memcpy(($66|0),($51|0),($54|0))|0;
   HEAP32[$31>>2] = $66;
   HEAP32[$29>>2] = $70;
   HEAP32[$30>>2] = $67;
   $71 = ($51|0)==(0|0);
   if ($71) {
    STACKTOP = sp;return;
   }
   __ZdlPv($51);
   STACKTOP = sp;return;
  } else {
   $$pre81 = (($this) + 280|0);
   $$pre82 = (($this) + 144|0);
   $$pre$phi83Z2D = $$pre82;$$pre$phiZ2D = $$pre81;
  }
 } while(0);
 $287 = HEAP32[$$pre$phiZ2D>>2]|0;
 $288 = (($287) + -24|0);
 $289 = HEAP32[$288>>2]|0;
 $290 = HEAP32[$$pre$phi83Z2D>>2]|0;
 $291 = ($289|0)==(0);
 if ($291) {
  label = 50;
 } else {
  $292 = (($290) + 32|0);
  $293 = HEAP32[$292>>2]|0;
  $294 = ($293|0)==(0);
  if ($294) {
   label = 50;
  } else {
   $297 = (($290) + 28|0);
   $298 = Math_fround(HEAPF32[$297>>2]);
   $299 = (Math_fround(($289|0)));
   $300 = Math_fround($299 * $298);
   $301 = (Math_fround(($293|0)));
   $302 = Math_fround($300 / $301);
   $$0$i = $302;
  }
 }
 if ((label|0) == 50) {
  $295 = (($290) + 28|0);
  $296 = Math_fround(HEAPF32[$295>>2]);
  $$0$i = $296;
 }
 $303 = (($this) + 188|0);
 $304 = Math_fround(HEAPF32[$303>>2]);
 $305 = Math_fround($$0$i * $304);
 $306 = (($this) + 177|0);
 $307 = HEAP8[$306>>0]|0;
 $308 = ($307<<24>>24)==(0);
 if ($308) {
  $$0$i$i = $305;
 } else {
  $309 = Math_fround($305 + Math_fround(0.5));
  $floorf$i$i$i$i = (Math_fround(Math_floor((Math_fround($309)))));
  $$0$i$i = $floorf$i$i$i$i;
 }
 $310 = (($this) + 296|0);
 $311 = HEAP32[$310>>2]|0;
 $312 = (($this) + 300|0);
 $313 = HEAP32[$312>>2]|0;
 $314 = ($311|0)==($313|0);
 if (!($314)) {
  $315 = ($311|0)==(0|0);
  if (!($315)) {
   HEAPF32[$311>>2] = $$0$i$i;
  }
  $316 = (($311) + 4|0);
  HEAP32[$310>>2] = $316;
  STACKTOP = sp;return;
 }
 $317 = (($this) + 292|0);
 $318 = HEAP32[$317>>2]|0;
 $319 = $311;
 $320 = $318;
 $321 = (($319) - ($320))|0;
 $322 = $321 >> 2;
 $323 = (($322) + 1)|0;
 $324 = ($323>>>0)>(1073741823);
 if ($324) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $325 = ($322>>>0)<(536870911);
 if ($325) {
  $326 = $321 >> 1;
  $327 = ($326>>>0)<($323>>>0);
  $328 = $327 ? $323 : $326;
  $329 = ($328|0)==(0);
  if ($329) {
   $$0$i3$i$i = 0;$333 = 0;
  } else {
   $$0$i2$i$i = $328;
   label = 62;
  }
 } else {
  $$0$i2$i$i = 1073741823;
  label = 62;
 }
 if ((label|0) == 62) {
  $330 = $$0$i2$i$i << 2;
  $331 = (__Znwj($330)|0);
  $$0$i3$i$i = $$0$i2$i$i;$333 = $331;
 }
 $332 = (($333) + ($322<<2)|0);
 $334 = (($333) + ($$0$i3$i$i<<2)|0);
 $335 = ($332|0)==(0|0);
 if (!($335)) {
  HEAPF32[$332>>2] = $$0$i$i;
 }
 $336 = (($333) + ($323<<2)|0);
 _memcpy(($333|0),($318|0),($321|0))|0;
 HEAP32[$317>>2] = $333;
 HEAP32[$310>>2] = $336;
 HEAP32[$312>>2] = $334;
 $337 = ($318|0)==(0|0);
 if ($337) {
  STACKTOP = sp;return;
 }
 __ZdlPv($318);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate19NativeTextGenerator13ProcessStringEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $9 = 0, $c$0 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 204|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 224|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)<(0);
 L1: do {
  if ($3) {
   $$pre = (($this) + 304|0);
   $$pre$phiZ2D = $$pre;
  } else {
   $4 = (($this) + 152|0);
   $5 = (($this) + 308|0);
   $6 = (($this) + 264|0);
   $7 = (($this) + 268|0);
   $8 = (($this) + 304|0);
   $9 = (($this) + 197|0);
   $10 = (($this) + 372|0);
   $11 = (($this) + 264|0);
   $12 = (($this) + 144|0);
   $13 = (($this) + 280|0);
   $14 = (($this) + 356|0);
   $15 = (($this) + 252|0);
   $16 = (($this) + 244|0);
   $17 = (($this) + 220|0);
   $18 = (($this) + 256|0);
   $19 = (($this) + 212|0);
   $20 = (($this) + 240|0);
   $21 = (($this) + 248|0);
   while(1) {
    __ZN20TextRenderingPrivate19NativeTextGenerator24ProcessFormatForPositionEv($this);
    $22 = HEAP32[$0>>2]|0;
    $23 = HEAP32[$1>>2]|0;
    $24 = ($22|0)<($23|0);
    if ($24) {
     $25 = HEAP32[$4>>2]|0;
     $26 = (($25) + ($22<<1)|0);
     $27 = HEAP16[$26>>1]|0;
     $28 = $27&65535;
     $c$0 = $28;
    } else {
     $c$0 = 10;
    }
    $29 = HEAP32[$5>>2]|0;
    $30 = (($29) + ($22<<3)|0);
    $31 = Math_fround(HEAPF32[$6>>2]);
    $32 = Math_fround(HEAPF32[$7>>2]);
    $33 = (HEAPF32[tempDoublePtr>>2]=$31,HEAP32[tempDoublePtr>>2]|0);
    $34 = (HEAPF32[tempDoublePtr>>2]=$32,HEAP32[tempDoublePtr>>2]|0);
    $35 = $30;
    $36 = $35;
    HEAP32[$36>>2] = $33;
    $37 = (($35) + 4)|0;
    $38 = $37;
    HEAP32[$38>>2] = $34;
    if ((($c$0|0) == 10)) {
     $39 = (__ZN20TextRenderingPrivate19NativeTextGenerator15InsertLineBreakEv($this)|0);
     if (!($39)) {
      $40 = HEAP8[$8>>0]|0;
      $41 = ($40<<24>>24)==(0);
      if ($41) {
       $45 = 0;
      } else {
       $42 = HEAP32[$0>>2]|0;
       $43 = HEAP32[$1>>2]|0;
       $44 = ($42|0)==($43|0);
       $phitmp = $44&1;
       $45 = $phitmp;
      }
      HEAP8[$8>>0] = $45;
      $46 = HEAP8[$9>>0]|0;
      $47 = ($46<<24>>24)==(0);
      if ($47) {
       label = 11;
       break;
      }
     }
    } else if ((($c$0|0) == 9)) {
     $73 = (__ZN20TextRenderingPrivate19NativeTextGenerator9InsertTabEv($this)|0);
     if (!($73)) {
      $$0 = 0;
      label = 19;
      break;
     }
    } else if ((($c$0|0) == 32)) {
     $49 = HEAP32[$10>>2]|0;
     $50 = (($49) + 60|0);
     $51 = (($49) + 120|0);
     $52 = (($49) + 180|0);
     ;HEAP32[$52+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$52+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$52+8>>2]=HEAP32[$11+8>>2]|0;
     _memmove(($51|0),($11|0),12)|0;
     ;HEAP32[$50+0>>2]=HEAP32[$51+0>>2]|0;HEAP32[$50+4>>2]=HEAP32[$51+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$51+8>>2]|0;
     ;HEAP32[$49+0>>2]=HEAP32[$51+0>>2]|0;HEAP32[$49+4>>2]=HEAP32[$51+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$51+8>>2]|0;
     $53 = HEAP32[$10>>2]|0;
     $54 = (($53) + 240|0);
     HEAP32[$10>>2] = $54;
     $55 = HEAP32[$12>>2]|0;
     $56 = HEAP32[$13>>2]|0;
     $57 = (($56) + -24|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($56) + -32|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (Math_fround(__ZNK20TextRenderingPrivate4Font17GetCharacterWidthEjij($55,32,$58,$60)));
     $62 = HEAP32[$0>>2]|0;
     $63 = HEAP32[$14>>2]|0;
     $64 = (($63) + ($62<<2)|0);
     HEAPF32[$64>>2] = $61;
     $65 = Math_fround(HEAPF32[$15>>2]);
     $66 = $65 == Math_fround(0.0);
     $67 = Math_fround(HEAPF32[$11>>2]);
     if ($66) {
      HEAPF32[$16>>2] = $67;
      HEAP32[$17>>2] = $62;
     }
     $68 = Math_fround($61 + $65);
     HEAPF32[$15>>2] = $68;
     $69 = HEAP32[$18>>2]|0;
     $70 = (($69) + 1)|0;
     HEAP32[$18>>2] = $70;
     $71 = (($62) + 1)|0;
     HEAP32[$19>>2] = $71;
     HEAPF32[$20>>2] = Math_fround(0.0);
     $72 = Math_fround($61 + $67);
     HEAPF32[$21>>2] = $72;
     HEAPF32[$11>>2] = $72;
    } else {
     $74 = (__ZN20TextRenderingPrivate19NativeTextGenerator15InsertCharacterEi($this,$c$0)|0);
     if (!($74)) {
      $$0 = 0;
      label = 19;
      break;
     }
    }
    $75 = HEAP32[$0>>2]|0;
    $76 = (($75) + 1)|0;
    HEAP32[$0>>2] = $76;
    $77 = HEAP32[$1>>2]|0;
    $78 = ($75|0)<($77|0);
    if (!($78)) {
     $$pre$phiZ2D = $8;
     break L1;
    }
   }
   if ((label|0) == 11) {
    $48 = ($45<<24>>24)!=(0);
    $$0 = $48;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 19) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $79 = HEAP8[$$pre$phiZ2D>>0]|0;
 $80 = ($79<<24>>24)!=(0);
 $$0 = $80;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20TextRenderingPrivate19NativeTextGenerator9GetBoundsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $$0$i$i = Math_fround(0), $$0$i$i5 = Math_fround(0), $$0$i$i8 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0);
 var $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $floorf$i$i$i$i = Math_fround(0), $floorf$i$i$i$i1 = Math_fround(0), $floorf$i$i$i$i4 = Math_fround(0), $floorf$i$i$i$i7 = Math_fround(0);
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($agg$result) + 12|0);
 HEAPF32[$2>>2] = $1;
 $3 = (($this) + 164|0);
 $4 = HEAP32[$3>>2]|0;
 if ((($4|0) == 0)) {
  HEAPF32[$agg$result>>2] = Math_fround(0.0);
  $5 = (($this) + 260|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($this) + 177|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   $$0$i$i5 = $6;
  } else {
   $10 = Math_fround($6 + Math_fround(0.5));
   $floorf$i$i$i$i4 = (Math_fround(Math_floor((Math_fround($10)))));
   $$0$i$i5 = $floorf$i$i$i$i4;
  }
  $11 = (($agg$result) + 8|0);
  HEAPF32[$11>>2] = $$0$i$i5;
  STACKTOP = sp;return;
 } else if ((($4|0) == 2)) {
  $12 = (($this) + 260|0);
  $13 = Math_fround(HEAPF32[$12>>2]);
  $14 = (($this) + 177|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   $$0$i$i8 = $13;
  } else {
   $17 = Math_fround($13 + Math_fround(0.5));
   $floorf$i$i$i$i7 = (Math_fround(Math_floor((Math_fround($17)))));
   $$0$i$i8 = $floorf$i$i$i$i7;
  }
  $18 = Math_fround(-$$0$i$i8);
  HEAPF32[$agg$result>>2] = $18;
  $19 = $$0$i$i8 > Math_fround(-0.0);
  $20 = $19 ? $$0$i$i8 : $18;
  $21 = (($agg$result) + 8|0);
  HEAPF32[$21>>2] = $20;
  STACKTOP = sp;return;
 } else if ((($4|0) == 1)) {
  $22 = (($this) + 260|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = Math_fround($23 * Math_fround(0.5));
  $25 = (($this) + 177|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $28 = Math_fround(-$24);
   HEAPF32[$agg$result>>2] = $28;
   $$0$i$i = $23;
  } else {
   $29 = Math_fround($24 + Math_fround(0.5));
   $floorf$i$i$i$i1 = (Math_fround(Math_floor((Math_fround($29)))));
   $30 = Math_fround(-$floorf$i$i$i$i1);
   HEAPF32[$agg$result>>2] = $30;
   $31 = Math_fround($23 + Math_fround(0.5));
   $floorf$i$i$i$i = (Math_fround(Math_floor((Math_fround($31)))));
   $$0$i$i = $floorf$i$i$i$i;
  }
  $32 = (($agg$result) + 8|0);
  HEAPF32[$32>>2] = $$0$i$i;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate19NativeTextGenerator11SetMeshDataERNS_17TextMeshGeneratorE($this,$tmgen) {
 $this = $this|0;
 $tmgen = $tmgen|0;
 var $$byval_copy4 = 0, $$idx = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = Math_fround(0), $88 = Math_fround(0);
 var $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bounds = 0, $i$03 = 0, $i1$01 = 0, $mesh$0 = 0, $vertex$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy4 = sp + 64|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $bounds = sp + 16|0;
 $3 = sp + 40|0;
 $4 = sp + 52|0;
 $5 = HEAP32[$tmgen>>2]|0;
 $6 = ($5|0)==(0|0);
 do {
  if ($6) {
   $7 = HEAP32[628384>>2]|0;
   HEAP32[$1>>2] = $7;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   $8 = (__Znwj10MemLabelIdbiPKci(280,$$byval_copy4,1,16,805760,714)|0);
   $9 = HEAP32[628384>>2]|0;
   HEAP32[$2>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_viii(1698,($8|0),($$byval_copy4|0),0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($8)|0);
    HEAP32[$tmgen>>2] = $12;
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 24|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vi[$15 & 4095]($12);
    $16 = HEAP32[$12>>2]|0;
    $17 = (($16) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    FUNCTION_TABLE_vii[$18 & 4095]($12,4);
    $19 = HEAP32[$12>>2]|0;
    $20 = (($19) + 44|0);
    $21 = HEAP32[$20>>2]|0;
    FUNCTION_TABLE_vii[$21 & 4095]($12,61);
    $22 = (($12) + 275|0);
    HEAP8[$22>>0] = 1;
    $mesh$0 = $12;
    break;
   }
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_viiiiii(97,($8|0),($$byval_copy4|0),1,16,(805760|0),714);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $125 = ___cxa_find_matching_catch(0|0)|0;
    $126 = tempRet0;
    ___clang_call_terminate($125);
    // unreachable;
   } else {
    ___resumeException($23|0);
    // unreachable;
   }
  } else {
   __ZN4Mesh5ClearEb($5,1);
   $mesh$0 = $5;
  }
 } while(0);
 $27 = (($this) + 140|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 __ZN4Mesh14ResizeVerticesEjj($mesh$0,$30,13);
 $31 = HEAP8[((640792 + 258|0))>>0]|0;
 $32 = (($mesh$0) + 276|0);
 HEAP8[$32>>0] = $31;
 $33 = (($mesh$0) + 28|0);
 $34 = HEAP32[$27>>2]|0;
 $35 = (($34) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)>(0);
 if ($37) {
  $38 = HEAP32[$33>>2]|0;
  $39 = (($38) + 92|0);
  $40 = HEAP32[$39>>2]|0;
  $42 = $34;$i$03 = 0;$vertex$02 = $40;
  while(1) {
   $41 = HEAP32[$42>>2]|0;
   $43 = (($41) + (($i$03*60)|0)|0);
   ;HEAP32[$vertex$02+0>>2]=HEAP32[$43+0>>2]|0;HEAP32[$vertex$02+4>>2]=HEAP32[$43+4>>2]|0;HEAP32[$vertex$02+8>>2]=HEAP32[$43+8>>2]|0;
   $44 = (($vertex$02) + 12|0);
   $45 = HEAP32[$27>>2]|0;
   $46 = HEAP32[$45>>2]|0;
   $47 = ((($46) + (($i$03*60)|0)|0) + 24|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$44>>2] = $48;
   $49 = (($vertex$02) + 16|0);
   $50 = ((($46) + (($i$03*60)|0)|0) + 28|0);
   $51 = $50;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($51) + 4)|0;
   $55 = $54;
   $56 = HEAP32[$55>>2]|0;
   $57 = $49;
   $58 = $57;
   HEAP32[$58>>2] = $53;
   $59 = (($57) + 4)|0;
   $60 = $59;
   HEAP32[$60>>2] = $56;
   $61 = (($i$03) + 1)|0;
   $62 = (($vertex$02) + 24|0);
   $63 = HEAP32[$27>>2]|0;
   $64 = (($63) + 8|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = ($61|0)<($65|0);
   if ($66) {
    $42 = $63;$i$03 = $61;$vertex$02 = $62;
   } else {
    break;
   }
  }
 }
 $67 = (($this) + 228|0);
 $68 = HEAP32[$67>>2]|0;
 __ZN4Mesh15SetSubMeshCountEj($mesh$0,$68);
 $69 = HEAP32[$67>>2]|0;
 $70 = ($69|0)>(0);
 if ($70) {
  $127 = $69;$i1$01 = 0;
  while(1) {
   $71 = ((($this) + ($i1$01<<4)|0) + 20|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = ($72|0)==(0);
   if ($73) {
    $78 = $127;
   } else {
    $74 = ((($this) + ($i1$01<<4)|0) + 12|0);
    $75 = HEAP32[$74>>2]|0;
    (__ZN4Mesh17SetIndicesComplexEPKvjj16GfxPrimitiveTypei($mesh$0,$75,$72,$i1$01,0,1)|0);
    $$pre = HEAP32[$67>>2]|0;
    $78 = $$pre;
   }
   $76 = (($i1$01) + 1)|0;
   $77 = ($76|0)<($78|0);
   if ($77) {
    $127 = $78;$i1$01 = $76;
   } else {
    break;
   }
  }
 }
 ;HEAP32[$bounds+0>>2]=0|0;HEAP32[$bounds+4>>2]=0|0;HEAP32[$bounds+8>>2]=0|0;HEAP32[$bounds+12>>2]=0|0;HEAP32[$bounds+16>>2]=0|0;HEAP32[$bounds+20>>2]=0|0;
 $79 = (($tmgen) + 8|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = (($tmgen) + 12|0);
 $82 = Math_fround(HEAPF32[$81>>2]);
 HEAPF32[$3>>2] = $80;
 $83 = (($3) + 4|0);
 HEAPF32[$83>>2] = $82;
 $84 = (($3) + 8|0);
 HEAPF32[$84>>2] = Math_fround(0.0);
 __ZN4AABB11EncapsulateERK8Vector3f($bounds,$3);
 $85 = Math_fround(HEAPF32[$79>>2]);
 $86 = (($tmgen) + 16|0);
 $87 = Math_fround(HEAPF32[$86>>2]);
 $88 = Math_fround($85 + $87);
 $89 = Math_fround(HEAPF32[$81>>2]);
 $90 = (($tmgen) + 20|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($89 + $91);
 HEAPF32[$4>>2] = $88;
 $93 = (($4) + 4|0);
 HEAPF32[$93>>2] = $92;
 $94 = (($4) + 8|0);
 HEAPF32[$94>>2] = Math_fround(0.0);
 __ZN4AABB11EncapsulateERK8Vector3f($bounds,$4);
 $95 = (($mesh$0) + 168|0);
 ;HEAP32[$95+0>>2]=HEAP32[$bounds+0>>2]|0;HEAP32[$95+4>>2]=HEAP32[$bounds+4>>2]|0;HEAP32[$95+8>>2]=HEAP32[$bounds+8>>2]|0;HEAP32[$95+12>>2]=HEAP32[$bounds+12>>2]|0;HEAP32[$95+16>>2]=HEAP32[$bounds+16>>2]|0;HEAP32[$95+20>>2]=HEAP32[$bounds+20>>2]|0;
 $96 = HEAP32[$33>>2]|0;
 $97 = (($96) + 96|0);
 $98 = HEAP32[$97>>2]|0;
 __ZN4Mesh16SetChannelsDirtyEjb($mesh$0,$98,0);
 $99 = (($tmgen) + 76|0);
 $100 = (($this) + 308|0);
 $101 = ($100|0)==($99|0);
 if ($101) {
  STACKTOP = sp;return;
 }
 $102 = HEAP32[$100>>2]|0;
 $103 = (($this) + 316|0);
 $104 = HEAP32[$103>>2]|0;
 $$idx = $104 << 3;
 $105 = $$idx >> 3;
 $106 = (($tmgen) + 84|0);
 HEAP32[$106>>2] = $105;
 $107 = (($tmgen) + 88|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = $108 & 2147483647;
 $110 = ($109>>>0)<($105>>>0);
 do {
  if ($110) {
   $111 = ($108|0)>(-1);
   if ($111) {
    HEAP32[$107>>2] = $105;
    $112 = HEAP32[$99>>2]|0;
    $113 = (($tmgen) + 80|0);
    $114 = HEAP32[$113>>2]|0;
    HEAP32[$0>>2] = $114;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $115 = (__Z16realloc_internalPvji10MemLabelIdiPKci($112,$$idx,4,$$byval_copy4,0,805760,370)|0);
    HEAP32[$99>>2] = $115;
    $124 = $115;
    break;
   } else {
    $116 = (($tmgen) + 80|0);
    $117 = HEAP32[$116>>2]|0;
    HEAP32[$0>>2] = $117;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
    $118 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx,4,$$byval_copy4,0,805760,352)|0);
    $119 = HEAP32[$99>>2]|0;
    $120 = HEAP32[$106>>2]|0;
    $121 = $120 << 3;
    _memcpy(($118|0),($119|0),($121|0))|0;
    HEAP32[$107>>2] = $105;
    HEAP32[$99>>2] = $118;
    $124 = $118;
    break;
   }
  } else {
   $$pre$i = HEAP32[$99>>2]|0;
   $124 = $$pre$i;
  }
 } while(0);
 $122 = HEAP32[$106>>2]|0;
 $123 = $122 << 3;
 _memcpy(($124|0),($102|0),($123|0))|0;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate22ScriptingTextGenerator19GetStringRenderInfoERS0_RKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPNS_4FontE11ColorRGBA32ifibbiiNS0_16VerticalWrapModeENS0_18HorizontalWrapModeEbiRK8Vector2fSI_bb($result,$text,$font,$color,$size,$lineSpacing,$style,$richText,$resizeTextForBestFit,$resizeTextMinSize,$resizeTextMaxSize,$verticalOverFlow,$horizontalOverflow,$updateBounds,$anchor,$extents,$pivot,$swizzleVertColor,$generateOutOfBoundsCharacters) {
 $result = $result|0;
 $text = $text|0;
 $font = $font|0;
 $color = $color|0;
 $size = $size|0;
 $lineSpacing = Math_fround($lineSpacing);
 $style = $style|0;
 $richText = $richText|0;
 $resizeTextForBestFit = $resizeTextForBestFit|0;
 $resizeTextMinSize = $resizeTextMinSize|0;
 $resizeTextMaxSize = $resizeTextMaxSize|0;
 $verticalOverFlow = $verticalOverFlow|0;
 $horizontalOverflow = $horizontalOverflow|0;
 $updateBounds = $updateBounds|0;
 $anchor = $anchor|0;
 $extents = $extents|0;
 $pivot = $pivot|0;
 $swizzleVertColor = $swizzleVertColor|0;
 $generateOutOfBoundsCharacters = $generateOutOfBoundsCharacters|0;
 var $$ = 0, $$0$i = 0, $$0$i$i5$i49 = Math_fround(0), $$0$i$i8$i = Math_fround(0), $$010 = 0, $$011 = 0, $$08 = 0, $$09 = 0, $$1 = 0, $$2 = 0, $$50 = Math_fround(0), $$byval_copy1 = 0, $$not = 0, $$not31 = 0, $$not33 = 0, $$not35 = 0, $$not37 = 0, $$pre = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = 0;
 var $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0);
 var $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0);
 var $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = Math_fround(0), $189 = Math_fround(0), $19 = 0;
 var $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0;
 var $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alignment$0 = 0, $baseFontSize$0 = 0, $baseFontSize$1 = 0, $brmerge = 0, $brmerge30 = 0, $brmerge32 = 0;
 var $brmerge34 = 0, $brmerge36 = 0, $brmerge39 = 0, $cond = 0, $direction$0 = 0, $direction$2 = 0, $direction$3 = 0, $direction$4 = 0, $exitcond = 0, $exitcond57 = 0, $extentsToUse = 0, $first$0$off0 = 0, $first$2$off0 = 0, $first$3$off0 = 0, $floorf$i$i$i$i = Math_fround(0), $floorf$i$i$i$i$i = Math_fround(0), $floorf$i$i$i$i4$i = Math_fround(0), $floorf$i$i$i$i7$i = Math_fround(0), $floorf$i$i$i1$i = Math_fround(0), $floorf$i$i$i4$i = Math_fround(0);
 var $floorf$i$i$i7$i = Math_fround(0), $foundCorrectSize$0$off0 = 0, $foundCorrectSize$1$off0 = 0, $generator = 0, $i$051 = 0, $i1$052 = 0, $i2$054 = 0, $or$cond27 = 0, $or$cond28 = 0, $or$cond29 = 0, $renderSize$0 = 0, $renderSize$1 = 0, $resizeTextMinSize$resizeTextMaxSize = 0, $resultExtents$sroa$0$0 = Math_fround(0), $theString = 0, $updateBounds$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $$byval_copy1 = sp + 412|0;
 $0 = sp + 12|0;
 $1 = sp + 8|0;
 $extentsToUse = sp;
 $theString = sp + 16|0;
 $generator = sp + 28|0;
 $2 = sp + 408|0;
 $3 = (($result) + 48|0);
 HEAP8[$3>>0] = 0;
 $4 = ($font|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = ($resizeTextMinSize|0)>($resizeTextMaxSize|0);
 $resizeTextMinSize$resizeTextMaxSize = $5 ? $resizeTextMinSize : $resizeTextMaxSize;
 if ((($anchor|0) == 1) | (($anchor|0) == 4) | (($anchor|0) == 7)) {
  $alignment$0 = 1;
 } else {
  if ((($anchor|0) == 2) | (($anchor|0) == 5) | (($anchor|0) == 8)) {
   $alignment$0 = 2;
  } else {
   $alignment$0 = 0;
  }
 }
 $6 = $extents;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $extentsToUse;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = ($verticalOverFlow|0)==(1);
 if ($16) {
  $17 = (($extentsToUse) + 4|0);
  HEAPF32[$17>>2] = Math_fround(3.40282346638528859812E+38);
 }
 $18 = ($horizontalOverflow|0)==(1);
 if ($18) {
  HEAPF32[$extentsToUse>>2] = Math_fround(3.40282346638528859812E+38);
 }
 $19 = ($size|0)==(0);
 if ($19) {
  $20 = (($font) + 32|0);
  $21 = HEAP32[$20>>2]|0;
  $23 = $21;
 } else {
  $23 = $size;
 }
 $22 = ($resizeTextMinSize$resizeTextMaxSize|0)<($23|0);
 $or$cond27 = $22 & $resizeTextForBestFit;
 $baseFontSize$0 = $or$cond27 ? $resizeTextMinSize$resizeTextMaxSize : $23;
 $24 = ($baseFontSize$0|0)<($resizeTextMinSize|0);
 $or$cond28 = $24 & $resizeTextForBestFit;
 $baseFontSize$1 = $or$cond28 ? $resizeTextMinSize : $baseFontSize$0;
 $25 = HEAP8[$text>>0]|0;
 $26 = $25 & 1;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $30 = $25&255;
  $31 = $30 >>> 1;
  $32 = $31;
 } else {
  $28 = (($text) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  $32 = $29;
 }
 __ZN20TextRenderingPrivate22ScriptingTextGenerator9InitVertsEi($result,$32);
 $33 = HEAP8[$text>>0]|0;
 $34 = $33 & 1;
 $35 = ($34<<24>>24)==(0);
 if ($35) {
  $38 = (($text) + 1|0);
  $39 = $38;
 } else {
  $36 = (($text) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $39 = $37;
 }
 __ZN11UTF16StringC2EPKc($theString,$39);
 $40 = (($text) + 4|0);
 $41 = (($result) + 64|0);
 $42 = (($generator) + 232|0);
 $43 = (($extentsToUse) + 4|0);
 $44 = (($extents) + 4|0);
 $45 = (($generator) + 268|0);
 $46 = (($generator) + 164|0);
 $$not35 = $16 ^ 1;
 $updateBounds$not = $updateBounds ^ 1;
 $brmerge36 = $$not35 | $updateBounds$not;
 $$not37 = $18 ^ 1;
 $brmerge39 = $$not37 | $updateBounds$not;
 $47 = (($result) + 52|0);
 $48 = (($result) + 56|0);
 $49 = (($pivot) + 4|0);
 $50 = (($result) + 8|0);
 $51 = (($generator) + 316|0);
 $52 = (($generator) + 348|0);
 $53 = (($generator) + 372|0);
 $54 = (($generator) + 376|0);
 $55 = (($result) + 60|0);
 $56 = (($result) + 12|0);
 $57 = (($result) + 4|0);
 $58 = (($generator) + 324|0);
 $59 = (($result) + 32|0);
 $60 = (($generator) + 340|0);
 $61 = (($result) + 16|0);
 $62 = (($generator) + 308|0);
 $63 = (($generator) + 356|0);
 $64 = (($generator) + 260|0);
 $65 = (($generator) + 177|0);
 $66 = (Math_fround(($baseFontSize$1|0)));
 $$08 = $anchor;$direction$0 = 0;$first$0$off0 = 1;$foundCorrectSize$0$off0 = 0;$renderSize$0 = $baseFontSize$1;
 L25: while(1) {
  $67 = ($renderSize$0|0)>(0);
  $brmerge = $67 | $first$0$off0;
  if (!($brmerge)) {
   label = 86;
   break;
  }
  $68 = ($renderSize$0|0)==(0);
  $or$cond29 = $first$0$off0 & $68;
  if ($or$cond29) {
   $72 = Math_fround(1.0);
  } else {
   $69 = (Math_fround(($renderSize$0|0)));
   $70 = Math_fround($69 / $66);
   $72 = $70;
  }
  $71 = HEAP32[$color>>2]|0;
  HEAP32[$2>>2] = $71;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_viiiiiiiifiiifiii(1,($generator|0),($theString|0),($font|0),($$byval_copy1|0),($baseFontSize$1|0),($extentsToUse|0),($richText|0),($style|0),(+$lineSpacing),($alignment$0|0),4,1,(+$72),($swizzleVertColor|0),($generateOutOfBoundsCharacters|0),($result|0));
  $73 = __THREW__; __THREW__ = 0;
  $74 = $73&1;
  if ($74) {
   label = 28;
   break;
  }
  __THREW__ = 0;
  $75 = (invoke_ii(3415,($generator|0))|0);
  $76 = __THREW__; __THREW__ = 0;
  $77 = $76&1;
  if ($77) {
   label = 29;
   break;
  }
  if ($75) {
   __THREW__ = 0;
   $78 = (invoke_ii(3416,($generator|0))|0);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    label = 29;
    break;
   } else {
    $$0$i = $78;
   }
  } else {
   $$0$i = 0;
  }
  do {
   if ($resizeTextForBestFit) {
    if ($first$0$off0) {
     $$ = $$0$i ? 1 : -1;
     $direction$2 = $$;
    } else {
     $direction$2 = $direction$0;
    }
    $$not = ($direction$2|0)<(1);
    $brmerge30 = $$not | $foundCorrectSize$0$off0;
    if (!($brmerge30)) {
     $87 = (($renderSize$0) + 1)|0;
     $88 = ($87|0)<($resizeTextMinSize$resizeTextMaxSize|0);
     if ($88) {
      $89 = HEAP8[$text>>0]|0;
      $90 = $89 & 1;
      $91 = ($90<<24>>24)==(0);
      if ($91) {
       $93 = $89&255;
       $94 = $93 >>> 1;
       $95 = $94;
      } else {
       $92 = HEAP32[$40>>2]|0;
       $95 = $92;
      }
      if ($$0$i) {
       __THREW__ = 0;
       invoke_vii(3447,($result|0),($95|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if ($97) {
        label = 29;
        break L25;
       } else {
        $$09 = 2;$$2 = $$08;$direction$4 = $direction$2;$first$3$off0 = 0;$foundCorrectSize$1$off0 = 0;$renderSize$1 = $87;
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3447,($result|0),($95|0));
      $98 = __THREW__; __THREW__ = 0;
      $99 = $98&1;
      if ($99) {
       label = 29;
       break L25;
      }
      $100 = (($renderSize$0) + -1)|0;
      $$09 = 2;$$2 = $$08;$direction$4 = $direction$2;$first$3$off0 = 0;$foundCorrectSize$1$off0 = 1;$renderSize$1 = $100;
      break;
     }
    }
    $$not31 = ($direction$2|0)>(-1);
    $brmerge32 = $$not31 | $foundCorrectSize$0$off0;
    if ($brmerge32) {
     $direction$3 = $direction$2;$first$2$off0 = 0;
     label = 45;
    } else {
     $101 = (($renderSize$0) + -1)|0;
     $$not33 = ($101|0)<=($resizeTextMinSize|0);
     $brmerge34 = $$not33 | $$0$i;
     if ($brmerge34) {
      $direction$3 = $direction$2;$first$2$off0 = 0;
      label = 45;
     } else {
      $102 = HEAP8[$text>>0]|0;
      $103 = $102 & 1;
      $104 = ($103<<24>>24)==(0);
      if ($104) {
       $106 = $102&255;
       $107 = $106 >>> 1;
       $108 = $107;
      } else {
       $105 = HEAP32[$40>>2]|0;
       $108 = $105;
      }
      __THREW__ = 0;
      invoke_vii(3447,($result|0),($108|0));
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       label = 29;
       break L25;
      } else {
       $$09 = 2;$$2 = $$08;$direction$4 = $direction$2;$first$3$off0 = 0;$foundCorrectSize$1$off0 = 0;$renderSize$1 = $101;
      }
     }
    }
   } else {
    $direction$3 = $direction$0;$first$2$off0 = $first$0$off0;
    label = 45;
   }
  } while(0);
  if ((label|0) == 45) {
   label = 0;
   HEAP32[$41>>2] = $renderSize$0;
   $111 = Math_fround(HEAPF32[$42>>2]);
   $112 = Math_fround(HEAPF32[$43>>2]);
   $113 = $111 > $112;
   L61: do {
    if ($113) {
     switch ($$08|0) {
     case 3:  {
      $$1 = 0;
      break L61;
      break;
     }
     case 8:  {
      $$1 = 2;
      break L61;
      break;
     }
     case 7:  {
      $$1 = 1;
      break L61;
      break;
     }
     case 6:  {
      $$1 = 0;
      break L61;
      break;
     }
     case 5:  {
      $$1 = 2;
      break L61;
      break;
     }
     case 4:  {
      $$1 = 1;
      break L61;
      break;
     }
     default: {
      $$1 = $$08;
      break L61;
     }
     }
    } else {
     $$1 = $$08;
    }
   } while(0);
   $114 = Math_fround(HEAPF32[$extents>>2]);
   $115 = Math_fround(HEAPF32[$44>>2]);
   $116 = Math_fround(HEAPF32[$45>>2]);
   $117 = HEAP32[$46>>2]|0;
   if ((($117|0) == 1)) {
    $129 = Math_fround(HEAPF32[$64>>2]);
    $130 = HEAP8[$65>>0]|0;
    $131 = ($130<<24>>24)==(0);
    if ($131) {
     $$0$i$i5$i49 = $129;
    } else {
     $132 = Math_fround($129 + Math_fround(0.5));
     $floorf$i$i$i$i$i = (Math_fround(Math_floor((Math_fround($132)))));
     $$0$i$i5$i49 = $floorf$i$i$i$i$i;
    }
   } else if ((($117|0) == 0)) {
    $118 = Math_fround(HEAPF32[$64>>2]);
    $119 = HEAP8[$65>>0]|0;
    $120 = ($119<<24>>24)==(0);
    if ($120) {
     $$0$i$i5$i49 = $118;
    } else {
     $121 = Math_fround($118 + Math_fround(0.5));
     $floorf$i$i$i$i4$i = (Math_fround(Math_floor((Math_fround($121)))));
     $$0$i$i5$i49 = $floorf$i$i$i$i4$i;
    }
   } else if ((($117|0) == 2)) {
    $122 = Math_fround(HEAPF32[$64>>2]);
    $123 = HEAP8[$65>>0]|0;
    $124 = ($123<<24>>24)==(0);
    if ($124) {
     $$0$i$i8$i = $122;
    } else {
     $125 = Math_fround($122 + Math_fround(0.5));
     $floorf$i$i$i$i7$i = (Math_fround(Math_floor((Math_fround($125)))));
     $$0$i$i8$i = $floorf$i$i$i$i7$i;
    }
    $126 = Math_fround(-$$0$i$i8$i);
    $127 = $$0$i$i8$i > Math_fround(-0.0);
    $128 = $127 ? $$0$i$i8$i : $126;
    $$0$i$i5$i49 = $128;
   } else {
    $$0$i$i5$i49 = Math_fround(0.0);
   }
   $$50 = $brmerge36 ? $115 : $116;
   $resultExtents$sroa$0$0 = $brmerge39 ? $114 : $$0$i$i5$i49;
   HEAPF32[$47>>2] = $resultExtents$sroa$0$0;
   HEAPF32[$48>>2] = $$50;
   $133 = Math_fround($$50 - $116);
   switch ($$1|0) {
   case 2: case 5: case 8:  {
    $136 = Math_fround($resultExtents$sroa$0$0 + Math_fround(0.5));
    $floorf$i$i$i4$i = (Math_fround(Math_floor((Math_fround($136)))));
    $140 = $floorf$i$i$i4$i;
    break;
   }
   case 7: case 4: case 1:  {
    $134 = Math_fround($resultExtents$sroa$0$0 * Math_fround(0.5));
    $135 = Math_fround($134 + Math_fround(0.5));
    $floorf$i$i$i1$i = (Math_fround(Math_floor((Math_fround($135)))));
    $140 = $floorf$i$i$i1$i;
    break;
   }
   default: {
    $140 = Math_fround(0.0);
   }
   }
   $137 = Math_fround(HEAPF32[$pivot>>2]);
   $138 = Math_fround($137 * $resultExtents$sroa$0$0);
   $139 = Math_fround($140 - $138);
   switch ($$1|0) {
   case 5: case 4: case 3:  {
    $141 = Math_fround($133 * Math_fround(0.5));
    $142 = Math_fround($141 + Math_fround(0.5));
    $floorf$i$i$i7$i = (Math_fround(Math_floor((Math_fround($142)))));
    $148 = $floorf$i$i$i7$i;
    break;
   }
   case 6: case 7: case 8:  {
    $143 = Math_fround($133 + Math_fround(0.5));
    $floorf$i$i$i$i = (Math_fround(Math_floor((Math_fround($143)))));
    $148 = $floorf$i$i$i$i;
    break;
   }
   default: {
    $148 = Math_fround(0.0);
   }
   }
   $144 = Math_fround(HEAPF32[$49>>2]);
   $145 = Math_fround(Math_fround(1.0) - $144);
   $146 = Math_fround($145 * $$50);
   $147 = Math_fround($148 - $146);
   $149 = HEAP32[$50>>2]|0;
   $150 = ($149|0)>(0);
   if ($150) {
    $151 = HEAP32[$result>>2]|0;
    $i$051 = 0;
    while(1) {
     $152 = (($151) + (($i$051*60)|0)|0);
     $153 = Math_fround(HEAPF32[$152>>2]);
     $154 = Math_fround($139 + $153);
     HEAPF32[$152>>2] = $154;
     $155 = ((($151) + (($i$051*60)|0)|0) + 4|0);
     $156 = Math_fround(HEAPF32[$155>>2]);
     $157 = Math_fround($147 + $156);
     $158 = ((($151) + (($i$051*60)|0)|0) + 8|0);
     $159 = Math_fround(HEAPF32[$158>>2]);
     $160 = Math_fround($159 + Math_fround(0.0));
     HEAPF32[$158>>2] = $160;
     $161 = Math_fround($157 * Math_fround(-1.0));
     HEAPF32[$155>>2] = $161;
     $162 = (($i$051) + 1)|0;
     $163 = ($162|0)<($149|0);
     if ($163) {
      $i$051 = $162;
     } else {
      break;
     }
    }
   }
   $164 = HEAP32[$51>>2]|0;
   $165 = HEAP32[$52>>2]|0;
   __THREW__ = 0;
   invoke_viii(2057,($result|0),($165|0),($164|0));
   $166 = __THREW__; __THREW__ = 0;
   $167 = $166&1;
   if ($167) {
    label = 29;
    break;
   }
   $168 = ($164|0)>(0);
   if ($168) {
    $$pre = HEAP32[$61>>2]|0;
    $170 = $$pre;$i1$052 = 0;
    while(1) {
     $169 = (($170) + (($i1$052*12)|0)|0);
     $171 = HEAP32[$62>>2]|0;
     $172 = (($171) + ($i1$052<<3)|0);
     $173 = $172;
     $174 = $173;
     $175 = HEAP32[$174>>2]|0;
     $176 = (($173) + 4)|0;
     $177 = $176;
     $178 = HEAP32[$177>>2]|0;
     $179 = $169;
     $180 = $179;
     HEAP32[$180>>2] = $175;
     $181 = (($179) + 4)|0;
     $182 = $181;
     HEAP32[$182>>2] = $178;
     $183 = HEAP32[$61>>2]|0;
     $184 = (($183) + (($i1$052*12)|0)|0);
     $185 = Math_fround(HEAPF32[$184>>2]);
     $186 = Math_fround($139 + $185);
     HEAPF32[$184>>2] = $186;
     $187 = ((($183) + (($i1$052*12)|0)|0) + 4|0);
     $188 = Math_fround(HEAPF32[$187>>2]);
     $189 = Math_fround($147 + $188);
     $190 = Math_fround($189 * Math_fround(-1.0));
     HEAPF32[$187>>2] = $190;
     $191 = HEAP32[$63>>2]|0;
     $192 = (($191) + ($i1$052<<2)|0);
     $193 = Math_fround(HEAPF32[$192>>2]);
     $194 = ((($183) + (($i1$052*12)|0)|0) + 8|0);
     HEAPF32[$194>>2] = $193;
     $195 = (($i1$052) + 1)|0;
     $exitcond = ($195|0)==($164|0);
     if ($exitcond) {
      break;
     } else {
      $170 = $183;$i1$052 = $195;
     }
    }
   }
   $196 = ($165|0)>(0);
   if ($196) {
    $197 = HEAP32[$58>>2]|0;
    $198 = HEAP32[$59>>2]|0;
    $199 = HEAP32[$60>>2]|0;
    $i2$054 = 0;
    while(1) {
     $200 = (($197) + ($i2$054<<2)|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = (($198) + ($i2$054<<3)|0);
     HEAP32[$202>>2] = $201;
     $203 = (($199) + ($i2$054<<2)|0);
     $204 = Math_fround(HEAPF32[$203>>2]);
     $205 = (~~(($204)));
     $206 = ((($198) + ($i2$054<<3)|0) + 4|0);
     HEAP32[$206>>2] = $205;
     $207 = (($i2$054) + 1)|0;
     $exitcond57 = ($207|0)==($165|0);
     if ($exitcond57) {
      break;
     } else {
      $i2$054 = $207;
     }
    }
   }
   $208 = HEAP32[$53>>2]|0;
   $209 = HEAP32[$54>>2]|0;
   $210 = $208;
   $211 = $209;
   $212 = (($210) - ($211))|0;
   $213 = (($212|0) / 60)&-1;
   HEAP32[$55>>2] = $213;
   HEAP32[$50>>2] = $213;
   $214 = HEAP32[$56>>2]|0;
   $215 = $214 & 2147483647;
   $216 = ($215>>>0)<($213>>>0);
   do {
    if ($216) {
     $217 = ($214|0)>(-1);
     if ($217) {
      HEAP32[$56>>2] = $213;
      $218 = HEAP32[$result>>2]|0;
      $219 = HEAP32[$57>>2]|0;
      HEAP32[$0>>2] = $219;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $220 = (invoke_iiiiiiii(108,($218|0),($212|0),4,($$byval_copy1|0),0,(805760|0),370)|0);
      $221 = __THREW__; __THREW__ = 0;
      $222 = $221&1;
      if ($222) {
       label = 29;
       break L25;
      }
      HEAP32[$result>>2] = $220;
      break;
     } else {
      $223 = HEAP32[$57>>2]|0;
      HEAP32[$1>>2] = $223;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
      $224 = (invoke_iiiiiii(102,($212|0),4,($$byval_copy1|0),0,(805760|0),352)|0);
      $225 = __THREW__; __THREW__ = 0;
      $226 = $225&1;
      if ($226) {
       label = 29;
       break L25;
      }
      $227 = HEAP32[$result>>2]|0;
      $228 = HEAP32[$50>>2]|0;
      $229 = ($228*60)|0;
      _memcpy(($224|0),($227|0),($229|0))|0;
      HEAP32[$56>>2] = $213;
      HEAP32[$result>>2] = $224;
      break;
     }
    }
   } while(0);
   HEAP8[$3>>0] = 1;
   $$09 = 1;$$2 = $$1;$direction$4 = $direction$3;$first$3$off0 = $first$2$off0;$foundCorrectSize$1$off0 = $foundCorrectSize$0$off0;$renderSize$1 = $renderSize$0;
  }
  __THREW__ = 0;
  invoke_vi(3727,($generator|0));
  $230 = __THREW__; __THREW__ = 0;
  $231 = $230&1;
  if ($231) {
   label = 28;
   break;
  }
  $cond = ($$09|0)==(2);
  if ($cond) {
   $$08 = $$2;$direction$0 = $direction$4;$first$0$off0 = $first$3$off0;$foundCorrectSize$0$off0 = $foundCorrectSize$1$off0;$renderSize$0 = $renderSize$1;
  } else {
   label = 86;
   break;
  }
 }
 if ((label|0) == 28) {
  $81 = ___cxa_find_matching_catch()|0;
  $82 = tempRet0;
  $$010 = $82;$$011 = $81;
 }
 else if ((label|0) == 29) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3727,($generator|0));
  $85 = __THREW__; __THREW__ = 0;
  $86 = $85&1;
  if ($86) {
   $234 = ___cxa_find_matching_catch(0|0)|0;
   $235 = tempRet0;
   ___clang_call_terminate($234);
   // unreachable;
  } else {
   $$010 = $84;$$011 = $83;
  }
 }
 else if ((label|0) == 86) {
  __ZN11UTF16StringD2Ev($theString);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3501,($theString|0));
 $232 = __THREW__; __THREW__ = 0;
 $233 = $232&1;
 if ($233) {
  $234 = ___cxa_find_matching_catch(0|0)|0;
  $235 = tempRet0;
  ___clang_call_terminate($234);
  // unreachable;
 } else {
  ___resumeException($$011|0);
  // unreachable;
 }
}
function __ZN20TextRenderingPrivate22ScriptingTextGenerator9InitVertsEi($this,$numOfCharacters) {
 $this = $this|0;
 $numOfCharacters = $numOfCharacters|0;
 var $$01$i$i = 0, $$byval_copy1 = 0, $$sroa$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $0 = sp + 12|0;
 $$sroa$0 = sp;
 $1 = $numOfCharacters << 2;
 $2 = (($1) + 4)|0;
 ;HEAP32[$$sroa$0+0>>2]=HEAP32[616680+0>>2]|0;HEAP32[$$sroa$0+4>>2]=HEAP32[616680+4>>2]|0;HEAP32[$$sroa$0+8>>2]=HEAP32[616680+8>>2]|0;
 $3 = 616640;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 2147483647;
 $12 = ($11>>>0)<($2>>>0);
 do {
  if ($12) {
   $13 = ($10|0)>(-1);
   if ($13) {
    HEAP32[$9>>2] = $2;
    $14 = HEAP32[$this>>2]|0;
    $15 = ($2*60)|0;
    $16 = (($this) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = $17;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($14,$15,4,$$byval_copy1,0,805760,370)|0);
    HEAP32[$this>>2] = $18;
    break;
   } else {
    $19 = ($2*60)|0;
    $20 = (($this) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,805760,352)|0);
    $23 = HEAP32[$this>>2]|0;
    $24 = (($this) + 8|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25*60)|0;
    _memcpy(($22|0),($23|0),($26|0))|0;
    HEAP32[$9>>2] = $2;
    HEAP32[$this>>2] = $22;
    break;
   }
  }
 } while(0);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28>>>0)<($2>>>0);
 if (!($29)) {
  HEAP32[$27>>2] = $2;
  STACKTOP = sp;return;
 }
 $30 = HEAP32[$this>>2]|0;
 $31 = (($30) + (($2*60)|0)|0);
 $32 = ($28|0)==($2|0);
 if ($32) {
  HEAP32[$27>>2] = $2;
  STACKTOP = sp;return;
 }
 $33 = (($30) + (($28*60)|0)|0);
 $$01$i$i = $33;
 while(1) {
  $34 = ($$01$i$i|0)==(0|0);
  if (!($34)) {
   ;HEAP32[$$01$i$i+0>>2]=HEAP32[$$sroa$0+0>>2]|0;HEAP32[$$01$i$i+4>>2]=HEAP32[$$sroa$0+4>>2]|0;HEAP32[$$01$i$i+8>>2]=HEAP32[$$sroa$0+8>>2]|0;
   $35 = (($$01$i$i) + 12|0);
   HEAPF32[$35>>2] = Math_fround(0.0);
   $36 = (($$01$i$i) + 16|0);
   HEAPF32[$36>>2] = Math_fround(0.0);
   $37 = (($$01$i$i) + 20|0);
   HEAPF32[$37>>2] = Math_fround(-1.0);
   $38 = (($$01$i$i) + 24|0);
   HEAP32[$38>>2] = -1;
   $39 = (($$01$i$i) + 28|0);
   $40 = $39;
   $41 = $40;
   HEAP32[$41>>2] = $5;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $8;
   $44 = (($$01$i$i) + 36|0);
   $45 = $44;
   $46 = $45;
   HEAP32[$46>>2] = $5;
   $47 = (($45) + 4)|0;
   $48 = $47;
   HEAP32[$48>>2] = $8;
   $49 = (($$01$i$i) + 44|0);
   HEAPF32[$49>>2] = Math_fround(1.0);
   $50 = (($$01$i$i) + 48|0);
   HEAPF32[$50>>2] = Math_fround(0.0);
   $51 = (($$01$i$i) + 52|0);
   HEAPF32[$51>>2] = Math_fround(0.0);
   $52 = (($$01$i$i) + 56|0);
   HEAPF32[$52>>2] = Math_fround(-1.0);
  }
  $53 = (($$01$i$i) + 60|0);
  $54 = ($53|0)==($31|0);
  if ($54) {
   break;
  } else {
   $$01$i$i = $53;
  }
 }
 HEAP32[$27>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate22ScriptingTextGenerator19InitCharAndLineInfoEii($this,$lines,$charCount) {
 $this = $this|0;
 $lines = $lines|0;
 $charCount = $charCount|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 32|0);
 $2 = (($this) + 40|0);
 HEAP32[$2>>2] = $lines;
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2147483647;
 $6 = ($5>>>0)<($lines>>>0);
 do {
  if ($6) {
   $7 = ($4|0)>(-1);
   if ($7) {
    HEAP32[$3>>2] = $lines;
    $8 = HEAP32[$1>>2]|0;
    $9 = $lines << 3;
    $10 = (($this) + 36|0);
    $11 = HEAP32[$10>>2]|0;
    HEAP32[$0>>2] = $11;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $12 = (__Z16realloc_internalPvji10MemLabelIdiPKci($8,$9,4,$$byval_copy3,0,805760,370)|0);
    HEAP32[$1>>2] = $12;
    break;
   } else {
    $13 = $lines << 3;
    $14 = (($this) + 36|0);
    $15 = HEAP32[$14>>2]|0;
    HEAP32[$0>>2] = $15;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $16 = (__Z15malloc_internaljj10MemLabelIdiPKci($13,4,$$byval_copy3,0,805760,352)|0);
    $17 = HEAP32[$1>>2]|0;
    $18 = HEAP32[$2>>2]|0;
    $19 = $18 << 3;
    _memcpy(($16|0),($17|0),($19|0))|0;
    HEAP32[$3>>2] = $lines;
    HEAP32[$1>>2] = $16;
    break;
   }
  }
 } while(0);
 $20 = (($this) + 16|0);
 $21 = (($this) + 24|0);
 HEAP32[$21>>2] = $charCount;
 $22 = (($this) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 2147483647;
 $25 = ($24>>>0)<($charCount>>>0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $26 = ($23|0)>(-1);
 if ($26) {
  HEAP32[$22>>2] = $charCount;
  $27 = HEAP32[$20>>2]|0;
  $28 = ($charCount*12)|0;
  $29 = (($this) + 20|0);
  $30 = HEAP32[$29>>2]|0;
  HEAP32[$0>>2] = $30;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $31 = (__Z16realloc_internalPvji10MemLabelIdiPKci($27,$28,4,$$byval_copy3,0,805760,370)|0);
  HEAP32[$20>>2] = $31;
  STACKTOP = sp;return;
 } else {
  $32 = ($charCount*12)|0;
  $33 = (($this) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  HEAP32[$0>>2] = $34;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $35 = (__Z15malloc_internaljj10MemLabelIdiPKci($32,4,$$byval_copy3,0,805760,352)|0);
  $36 = HEAP32[$20>>2]|0;
  $37 = HEAP32[$21>>2]|0;
  $38 = ($37*12)|0;
  _memcpy(($35|0),($36|0),($38|0))|0;
  HEAP32[$22>>2] = $charCount;
  HEAP32[$20>>2] = $35;
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate19NativeTextGeneratorD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$5 = 0, $$56 = 0, $$6 = 0, $$67 = 0, $$byval_copy16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i = 0;
 var $__new_last2$i$i$i$i$i$i35 = 0, $__new_last2$i$i$i$i$i13 = 0, $__new_last2$i$i$i$i$i26 = 0, $__new_last2$i$i$i$i$i48 = 0, $lpad$phi$index = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i36 = 0, $scevgep$i$i$i$i$i14 = 0, $scevgep$i$i$i$i$i27 = 0, $scevgep$i$i$i$i$i49 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i40 = 0, $scevgep4$i$i$i$i$i18 = 0, $scevgep4$i$i$i$i$i31 = 0, $scevgep4$i$i$i$i$i53 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i38 = 0;
 var $uglygep$i$i$i$i$i16 = 0, $uglygep$i$i$i$i$i29 = 0, $uglygep$i$i$i$i$i51 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i39 = 0, $uglygep3$i$i$i$i$i17 = 0, $uglygep3$i$i$i$i$i30 = 0, $uglygep3$i$i$i$i$i52 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy16 = sp + 40|0;
 $0 = sp + 36|0;
 $1 = sp + 32|0;
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $4 = sp + 20|0;
 $5 = sp + 12|0;
 $6 = sp + 8|0;
 $7 = sp + 4|0;
 $8 = sp;
 $9 = sp + 16|0;
 $10 = (($this) + 368|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)>(-1);
 do {
  if ($12) {
   $13 = (($this) + 356|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($this) + 360|0);
   $16 = HEAP32[$15>>2]|0;
   HEAP32[$9>>2] = $16;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$9+0>>2]|0;
   invoke_vii(2591,($14|0),($$byval_copy16|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    HEAP32[$13>>2] = 0;
    label = 4;
    break;
   }
   $88 = ___cxa_find_matching_catch()|0;
   $89 = tempRet0;
   $90 = (($this) + 352|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = ($91|0)>(-1);
   if ($92) {
    $93 = (($this) + 340|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($this) + 344|0);
    $96 = HEAP32[$95>>2]|0;
    HEAP32[$4>>2] = $96;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$4+0>>2]|0;
    invoke_vii(2591,($94|0),($$byval_copy16|0));
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if ($98) {
     label = 72;
    } else {
     HEAP32[$93>>2] = 0;
     $$0 = $89;$$01 = $88;
     label = 37;
    }
   } else {
    $$0 = $89;$$01 = $88;
    label = 37;
   }
  } else {
   label = 4;
  }
 } while(0);
 L8: do {
  if ((label|0) == 4) {
   $19 = (($this) + 352|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)>(-1);
   do {
    if ($21) {
     $22 = (($this) + 340|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($this) + 344|0);
     $25 = HEAP32[$24>>2]|0;
     HEAP32[$8>>2] = $25;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$8+0>>2]|0;
     invoke_vii(2591,($23|0),($$byval_copy16|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      $99 = ___cxa_find_matching_catch()|0;
      $100 = tempRet0;
      $$0 = $100;$$01 = $99;
      label = 37;
      break L8;
     } else {
      HEAP32[$22>>2] = 0;
      break;
     }
    }
   } while(0);
   $28 = (($this) + 336|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>(-1);
   do {
    if ($30) {
     $31 = (($this) + 324|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($this) + 328|0);
     $34 = HEAP32[$33>>2]|0;
     HEAP32[$7>>2] = $34;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$7+0>>2]|0;
     invoke_vii(2591,($32|0),($$byval_copy16|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $101 = ___cxa_find_matching_catch()|0;
      $102 = tempRet0;
      $$1 = $102;$$12 = $101;
      label = 41;
      break L8;
     } else {
      HEAP32[$31>>2] = 0;
      break;
     }
    }
   } while(0);
   $37 = (($this) + 320|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)>(-1);
   do {
    if ($39) {
     $40 = (($this) + 308|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($this) + 312|0);
     $43 = HEAP32[$42>>2]|0;
     HEAP32[$6>>2] = $43;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$6+0>>2]|0;
     invoke_vii(2591,($41|0),($$byval_copy16|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      $112 = ___cxa_find_matching_catch()|0;
      $113 = tempRet0;
      $$2 = $113;$$23 = $112;
      label = 44;
      break L8;
     } else {
      HEAP32[$40>>2] = 0;
      break;
     }
    }
   } while(0);
   $46 = (($this) + 292|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    $49 = (($this) + 296|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($50|0)==($47|0);
    if (!($51)) {
     $__new_last2$i$i$i$i$i = $47;
     $scevgep$i$i$i$i$i = (($50) + -4|0);
     $52 = (0 - ($__new_last2$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($52)|0);
     $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
     $53 = $uglygep3$i$i$i$i$i >>> 2;
     $54 = $53 ^ -1;
     $scevgep4$i$i$i$i$i = (($50) + ($54<<2)|0);
     HEAP32[$49>>2] = $scevgep4$i$i$i$i$i;
    }
    __ZdlPv($47);
   }
   $55 = (($this) + 276|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($56|0)==(0|0);
   if (!($57)) {
    $58 = (($this) + 280|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59|0)==($56|0);
    if (!($60)) {
     $__new_last2$i$i$i$i$i$i = $56;
     $scevgep$i$i$i$i$i$i = (($59) + -32|0);
     $61 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($61)|0);
     $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
     $62 = $uglygep3$i$i$i$i$i$i >>> 5;
     $63 = $62 ^ -1;
     $scevgep4$i$i$i$i$i$i = (($59) + ($63<<5)|0);
     HEAP32[$58>>2] = $scevgep4$i$i$i$i$i$i;
    }
    __ZdlPv($56);
   }
   $64 = (($this) + 152|0);
   __THREW__ = 0;
   invoke_vi(3501,($64|0));
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if ($66) {
    $141 = ___cxa_find_matching_catch()|0;
    $142 = tempRet0;
    $$5 = $142;$$56 = $141;
    label = 60;
    break;
   }
   $67 = (($this) + 12|0);
   $68 = (($this) + 140|0);
   $70 = $68;
   while(1) {
    $69 = (($70) + -16|0);
    $71 = (($70) + -4|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)>(-1);
    if ($73) {
     $74 = HEAP32[$69>>2]|0;
     $75 = (($70) + -12|0);
     $76 = HEAP32[$75>>2]|0;
     HEAP32[$5>>2] = $76;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$5+0>>2]|0;
     invoke_vii(2591,($74|0),($$byval_copy16|0));
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      break;
     }
     HEAP32[$69>>2] = 0;
    }
    $79 = ($69|0)==($67|0);
    if ($79) {
     label = 27;
     break;
    } else {
     $70 = $69;
    }
   }
   if ((label|0) == 27) {
    $80 = HEAP32[$this>>2]|0;
    $81 = ($80|0)==(0|0);
    if ($81) {
     STACKTOP = sp;return;
    }
    $82 = (($this) + 4|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = ($83|0)==($80|0);
    if (!($84)) {
     $__new_last2$i$i$i$i$i13 = $80;
     $scevgep$i$i$i$i$i14 = (($83) + -44|0);
     $85 = (0 - ($__new_last2$i$i$i$i$i13))|0;
     $uglygep$i$i$i$i$i16 = (($scevgep$i$i$i$i$i14) + ($85)|0);
     $uglygep3$i$i$i$i$i17 = $uglygep$i$i$i$i$i16;
     $86 = (($uglygep3$i$i$i$i$i17>>>0) / 44)&-1;
     $87 = $86 ^ -1;
     $scevgep4$i$i$i$i$i18 = (($83) + (($87*44)|0)|0);
     HEAP32[$82>>2] = $scevgep4$i$i$i$i$i18;
    }
    __ZdlPv($80);
    STACKTOP = sp;return;
   }
   $146 = ___cxa_find_matching_catch()|0;
   $147 = tempRet0;
   $148 = ($67|0)==($69|0);
   if ($148) {
    $$6 = $147;$$67 = $146;
   } else {
    $150 = $69;
    while(1) {
     $149 = (($150) + -16|0);
     $151 = (($150) + -4|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = ($152|0)>(-1);
     if ($153) {
      $154 = HEAP32[$149>>2]|0;
      $155 = (($150) + -12|0);
      $156 = HEAP32[$155>>2]|0;
      HEAP32[$1>>2] = $156;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($154|0),($$byval_copy16|0));
      $157 = __THREW__; __THREW__ = 0;
      $158 = $157&1;
      if ($158) {
       break;
      }
      HEAP32[$149>>2] = 0;
     }
     $159 = ($149|0)==($67|0);
     if ($159) {
      $$6 = $147;$$67 = $146;
      break L8;
     } else {
      $150 = $149;
     }
    }
    $181 = ___cxa_find_matching_catch(0|0)|0;
    $182 = tempRet0;
    $lpad$phi$index = $181;
    ___clang_call_terminate($lpad$phi$index);
    // unreachable;
   }
  }
 } while(0);
 if ((label|0) == 37) {
  $103 = (($this) + 336|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = ($104|0)>(-1);
  if ($105) {
   $106 = (($this) + 324|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($this) + 328|0);
   $109 = HEAP32[$108>>2]|0;
   HEAP32[$3>>2] = $109;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($107|0),($$byval_copy16|0));
   $110 = __THREW__; __THREW__ = 0;
   $111 = $110&1;
   if ($111) {
    label = 72;
   } else {
    HEAP32[$106>>2] = 0;
    $$1 = $$0;$$12 = $$01;
    label = 41;
   }
  } else {
   $$1 = $$0;$$12 = $$01;
   label = 41;
  }
 }
 if ((label|0) == 41) {
  $114 = (($this) + 320|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = ($115|0)>(-1);
  if ($116) {
   $117 = (($this) + 308|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($this) + 312|0);
   $120 = HEAP32[$119>>2]|0;
   HEAP32[$2>>2] = $120;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($118|0),($$byval_copy16|0));
   $121 = __THREW__; __THREW__ = 0;
   $122 = $121&1;
   if ($122) {
    label = 72;
   } else {
    HEAP32[$117>>2] = 0;
    $$2 = $$1;$$23 = $$12;
    label = 44;
   }
  } else {
   $$2 = $$1;$$23 = $$12;
   label = 44;
  }
 }
 if ((label|0) == 44) {
  $123 = (($this) + 292|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($124|0)==(0|0);
  if (!($125)) {
   $126 = (($this) + 296|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)==($124|0);
   if (!($128)) {
    $__new_last2$i$i$i$i$i26 = $124;
    $scevgep$i$i$i$i$i27 = (($127) + -4|0);
    $129 = (0 - ($__new_last2$i$i$i$i$i26))|0;
    $uglygep$i$i$i$i$i29 = (($scevgep$i$i$i$i$i27) + ($129)|0);
    $uglygep3$i$i$i$i$i30 = $uglygep$i$i$i$i$i29;
    $130 = $uglygep3$i$i$i$i$i30 >>> 2;
    $131 = $130 ^ -1;
    $scevgep4$i$i$i$i$i31 = (($127) + ($131<<2)|0);
    HEAP32[$126>>2] = $scevgep4$i$i$i$i$i31;
   }
   __ZdlPv($124);
  }
  $132 = (($this) + 276|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($133|0)==(0|0);
  if (!($134)) {
   $135 = (($this) + 280|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ($136|0)==($133|0);
   if (!($137)) {
    $__new_last2$i$i$i$i$i$i35 = $133;
    $scevgep$i$i$i$i$i$i36 = (($136) + -32|0);
    $138 = (0 - ($__new_last2$i$i$i$i$i$i35))|0;
    $uglygep$i$i$i$i$i$i38 = (($scevgep$i$i$i$i$i$i36) + ($138)|0);
    $uglygep3$i$i$i$i$i$i39 = $uglygep$i$i$i$i$i$i38;
    $139 = $uglygep3$i$i$i$i$i$i39 >>> 5;
    $140 = $139 ^ -1;
    $scevgep4$i$i$i$i$i$i40 = (($136) + ($140<<5)|0);
    HEAP32[$135>>2] = $scevgep4$i$i$i$i$i$i40;
   }
   __ZdlPv($133);
  }
  $143 = (($this) + 152|0);
  __THREW__ = 0;
  invoke_vi(3501,($143|0));
  $144 = __THREW__; __THREW__ = 0;
  $145 = $144&1;
  if ($145) {
   label = 72;
  } else {
   $$5 = $$2;$$56 = $$23;
   label = 60;
  }
 }
 if ((label|0) == 72) {
  $185 = ___cxa_find_matching_catch(0|0)|0;
  $186 = tempRet0;
  $lpad$phi$index = $185;
  ___clang_call_terminate($lpad$phi$index);
  // unreachable;
 }
 L93: do {
  if ((label|0) == 60) {
   $160 = (($this) + 12|0);
   $161 = (($this) + 140|0);
   $163 = $161;
   while(1) {
    $162 = (($163) + -16|0);
    $164 = (($163) + -4|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = ($165|0)>(-1);
    if ($166) {
     $167 = HEAP32[$162>>2]|0;
     $168 = (($163) + -12|0);
     $169 = HEAP32[$168>>2]|0;
     HEAP32[$0>>2] = $169;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($167|0),($$byval_copy16|0));
     $170 = __THREW__; __THREW__ = 0;
     $171 = $170&1;
     if ($171) {
      break;
     }
     HEAP32[$162>>2] = 0;
    }
    $172 = ($162|0)==($160|0);
    if ($172) {
     $$6 = $$5;$$67 = $$56;
     break L93;
    } else {
     $163 = $162;
    }
   }
   $183 = ___cxa_find_matching_catch(0|0)|0;
   $184 = tempRet0;
   $lpad$phi$index = $183;
   ___clang_call_terminate($lpad$phi$index);
   // unreachable;
  }
 } while(0);
 $173 = HEAP32[$this>>2]|0;
 $174 = ($173|0)==(0|0);
 if ($174) {
  ___resumeException($$67|0);
  // unreachable;
 }
 $175 = (($this) + 4|0);
 $176 = HEAP32[$175>>2]|0;
 $177 = ($176|0)==($173|0);
 if (!($177)) {
  $__new_last2$i$i$i$i$i48 = $173;
  $scevgep$i$i$i$i$i49 = (($176) + -44|0);
  $178 = (0 - ($__new_last2$i$i$i$i$i48))|0;
  $uglygep$i$i$i$i$i51 = (($scevgep$i$i$i$i$i49) + ($178)|0);
  $uglygep3$i$i$i$i$i52 = $uglygep$i$i$i$i$i51;
  $179 = (($uglygep3$i$i$i$i$i52>>>0) / 44)&-1;
  $180 = $179 ^ -1;
  $scevgep4$i$i$i$i$i53 = (($176) + (($180*44)|0)|0);
  HEAP32[$175>>2] = $scevgep4$i$i$i$i$i53;
 }
 __ZdlPv($173);
 ___resumeException($$67|0);
 // unreachable;
}
function __ZN20TextRenderingPrivate8TextMesh17MainThreadCleanupEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 __Z19DestroySingleObjectP6Object($1);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh7GetMeshEv($this) {
 $this = $this|0;
 var $$0 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 80|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[628384>>2]|0;
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Znwj10MemLabelIdbiPKci(280,$$byval_copy2,1,16,805960,47)|0);
 $7 = HEAP32[628384>>2]|0;
 HEAP32[$1>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viii(1698,($6|0),($$byval_copy2|0),0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $10 = (__ZN6Object27AllocateAndAssignInstanceIDEPS_($6)|0);
  HEAP32[$2>>2] = $10;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 4095]($10);
  $14 = HEAP32[$2>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 4095]($14,4);
  $18 = HEAP32[$2>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 44|0);
  $21 = HEAP32[$20>>2]|0;
  FUNCTION_TABLE_vii[$21 & 4095]($18,61);
  $22 = HEAP32[$2>>2]|0;
  $$0 = $22;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($6|0),($$byval_copy2|0),1,16,(805960|0),47);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN20TextRenderingPrivate8TextMesh5ResetEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($this) + 52|0);
 HEAPF32[$1>>2] = Math_fround(1.0);
 $2 = (($this) + 50|0);
 HEAP16[$2>>1] = 0;
 $3 = (($this) + 48|0);
 HEAP16[$3>>1] = 0;
 $4 = (($this) + 56|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($this) + 60|0);
 HEAPF32[$5>>2] = Math_fround(4.0);
 STACKTOP = sp;return;
}
function __ZNK20TextRenderingPrivate8TextMesh7GetFontEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  HEAP32[$0>>2] = $3;
  $5 = HEAP32[560624>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = (($5) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($5) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($8|0)==($10|0);
   do {
    if ($11) {
     $12 = (($5) + 28|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($5) + 32|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($13) + ($15<<3)|0);
     $32 = $16;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$5,$0);
     $17 = HEAP32[$pos$i$i$i>>2]|0;
     $18 = ($17|0)==(-1);
     $19 = (($5) + 28|0);
     $20 = HEAP32[$19>>2]|0;
     if ($18) {
      $21 = (($5) + 32|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($20) + ($22<<3)|0);
      $32 = $23;
      break;
     } else {
      $24 = (($20) + ($17<<3)|0);
      $32 = $24;
      break;
     }
    }
   } while(0);
   $25 = HEAP32[560624>>2]|0;
   $26 = (($25) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 32|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + ($29<<3)|0);
   $31 = ($32|0)==($30|0);
   if (!($31)) {
    $33 = (($32) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)==(0|0);
    if (!($35)) {
     $$0 = $34;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
  $36 = HEAP32[$2>>2]|0;
  $37 = (__Z31ReadObjectFromPersistentManageri($36)|0);
  $38 = ($37|0)==(0|0);
  if (!($38)) {
   $$0 = $37;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $39 = HEAP32[805968>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $$0 = $39;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP8[$1>>0] = 18;
 $41 = (($1) + 1|0);
 dest=$41+0|0; src=805976+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $42 = (($1) + 10|0);
 HEAP8[$42>>0] = 0;
 __THREW__ = 0;
 $43 = (invoke_i(58)|0);
 $44 = __THREW__; __THREW__ = 0;
 $45 = $44&1;
 if (!($45)) {
  __THREW__ = 0;
  $46 = (invoke_iiii(1532,($43|0),128,($1|0))|0);
  $47 = __THREW__; __THREW__ = 0;
  $48 = $47&1;
  if (!($48)) {
   HEAP32[805968>>2] = $46;
   $49 = HEAP8[$1>>0]|0;
   $50 = $49 & 1;
   $51 = ($50<<24>>24)==(0);
   if ($51) {
    $$0 = $46;
    STACKTOP = sp;return ($$0|0);
   }
   $52 = (($1) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   __ZdlPv($53);
   $$pre = HEAP32[805968>>2]|0;
   $$0 = $$pre;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $54 = ___cxa_find_matching_catch()|0;
 $55 = tempRet0;
 $56 = HEAP8[$1>>0]|0;
 $57 = $56 & 1;
 $58 = ($57<<24>>24)==(0);
 if ($58) {
  ___resumeException($54|0);
  // unreachable;
 }
 $59 = (($1) + 8|0);
 $60 = HEAP32[$59>>2]|0;
 __ZdlPv($60);
 ___resumeException($54|0);
 // unreachable;
 return 0|0;
}
function __ZN20TextRenderingPrivate8TextMesh13AwakeFromLoadE17AwakeFromLoadMode($this,$awakeMode) {
 $this = $this|0;
 $awakeMode = $awakeMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (__ZNK5Unity10GameObject8IsActiveEv($2)|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (__ZNK5Unity10GameObject8IsActiveEv($5)|0);
  if ($7) {
   $8 = HEAP32[$1>>2]|0;
   $9 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($8,23)|0);
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (__ZN20TextRenderingPrivate8TextMesh7GetMeshEv($this)|0);
    $12 = ($11|0)==(0|0);
    if ($12) {
     HEAP32[$0>>2] = 0;
    } else {
     $13 = (($11) + 4|0);
     $14 = HEAP32[$13>>2]|0;
     HEAP32[$0>>2] = $14;
    }
    __ZN12MeshRenderer13SetSharedMeshE4PPtrI4MeshE($9,$0);
   }
  }
 }
 __ZN20TextRenderingPrivate8TextMesh11ApplyToMeshEv($this);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh11ApplyToMeshEv($this) {
 $this = $this|0;
 var $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0;
 var $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $offset = 0, $scale = 0, $tmpcast$byval_copy = 0, $xformBounds = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $tmpcast$byval_copy = sp + 96|0;
 $0 = sp + 84|0;
 $1 = sp + 80|0;
 $offset = sp + 72|0;
 $2 = sp + 56|0;
 $scale = sp + 36|0;
 $3 = sp + 24|0;
 $xformBounds = sp;
 $4 = sp + 48|0;
 $5 = (__ZN20TextRenderingPrivate8TextMesh7GetMeshEv($this)|0);
 $6 = (($this) + 28|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7 & 1;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $12 = (($6) + 1|0);
  $13 = $12;
 } else {
  $10 = (($this) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $13 = $11;
 }
 __ZN11UTF16StringC2EPKc($0,$13);
 __THREW__ = 0;
 $14 = (invoke_ii(3417,($this|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if (!($16)) {
  $17 = (($this) + 50|0);
  $18 = HEAP16[$17>>1]|0;
  $19 = $18 << 16 >> 16;
  $20 = (($this) + 48|0);
  $21 = HEAP16[$20>>1]|0;
  $22 = $21 << 16 >> 16;
  $23 = (($this) + 60|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($this) + 56|0);
  $26 = Math_fround(HEAPF32[$25>>2]);
  $27 = (($this) + 76|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)!=(0);
  $30 = (($this) + 72|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[$1>>2] = $31;
  $32 = (($this) + 64|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($this) + 68|0);
  $35 = HEAP32[$34>>2]|0;
  __THREW__ = 0;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  $36 = (invoke_iiiiifffiiiii(1,($0|0),($14|0),($19|0),($22|0),0.0,(+$24),(+$26),($29|0),0,($tmpcast$byval_copy|0),($33|0),($35|0))|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if (!($38)) {
   __ZN11UTF16StringD2Ev($0);
   $39 = (($36) + 16|0);
   $40 = Math_fround(HEAPF32[$39>>2]);
   $41 = (($36) + 20|0);
   $42 = Math_fround(HEAPF32[$41>>2]);
   $43 = Math_fround(-$40);
   $44 = Math_fround($42 * Math_fround(2.0));
   HEAPF32[$2>>2] = Math_fround(0.0);
   $45 = (($2) + 8|0);
   HEAPF32[$45>>2] = $43;
   $46 = (($2) + 4|0);
   HEAPF32[$46>>2] = Math_fround(0.0);
   $47 = (($2) + 12|0);
   HEAPF32[$47>>2] = $44;
   __ZN13TextRendering17TextMeshGenerator13GetTextOffsetERK5RectTIfE($offset,$36,$2);
   $48 = HEAP16[$20>>1]|0;
   $49 = $48 << 16 >> 16;
   if ((($49|0) == 1)) {
    $56 = Math_fround($40 * Math_fround(0.5));
    $57 = Math_fround(HEAPF32[$offset>>2]);
    $58 = Math_fround($56 + $57);
    HEAPF32[$offset>>2] = $58;
    $$pre$phiZ2D = $offset;
   } else if ((($49|0) == 2)) {
    $54 = Math_fround(HEAPF32[$offset>>2]);
    $55 = Math_fround($40 + $54);
    HEAPF32[$offset>>2] = $55;
    $$pre$phiZ2D = $offset;
   } else {
    $$pre$phiZ2D = $offset;
   }
   $59 = HEAP32[$36>>2]|0;
   $60 = (($this) + 52|0);
   $61 = Math_fround(HEAPF32[$60>>2]);
   $62 = Math_fround(-$61);
   HEAPF32[$scale>>2] = $61;
   $63 = (($scale) + 4|0);
   HEAPF32[$63>>2] = $62;
   $64 = (($scale) + 8|0);
   HEAPF32[$64>>2] = $61;
   $65 = (__ZNK20TextRenderingPrivate8TextMesh7GetFontEv($this)|0);
   $66 = (($65) + 80|0);
   $67 = Math_fround(HEAPF32[$66>>2]);
   $68 = Math_fround(HEAPF32[$scale>>2]);
   $69 = Math_fround($67 * $68);
   HEAPF32[$scale>>2] = $69;
   $70 = Math_fround(HEAPF32[$63>>2]);
   $71 = Math_fround($67 * $70);
   HEAPF32[$63>>2] = $71;
   $72 = Math_fround(HEAPF32[$64>>2]);
   $73 = Math_fround($67 * $72);
   HEAPF32[$64>>2] = $73;
   $74 = Math_fround(HEAPF32[$$pre$phiZ2D>>2]);
   $75 = Math_fround($74 * $69);
   $76 = (($offset) + 4|0);
   $77 = Math_fround(HEAPF32[$76>>2]);
   $78 = Math_fround($77 * $71);
   $79 = Math_fround(-$78);
   $80 = (($this) + 44|0);
   $81 = Math_fround(HEAPF32[$80>>2]);
   HEAPF32[$3>>2] = $75;
   $82 = (($3) + 4|0);
   HEAPF32[$82>>2] = $79;
   $83 = (($3) + 8|0);
   HEAPF32[$83>>2] = $81;
   (__ZN10Matrix4x4f12SetTranslateERK8Vector3f($tmpcast$byval_copy,$3)|0);
   (__ZN10Matrix4x4f5ScaleERK8Vector3f($tmpcast$byval_copy,$scale)|0);
   __ZN4Mesh15CopyTransformedERKS_RK10Matrix4x4f($5,$59,$tmpcast$byval_copy);
   $84 = (($5) + 168|0);
   ;HEAP32[$xformBounds+0>>2]=0|0;HEAP32[$xformBounds+4>>2]=0|0;HEAP32[$xformBounds+8>>2]=0|0;HEAP32[$xformBounds+12>>2]=0|0;HEAP32[$xformBounds+16>>2]=0|0;HEAP32[$xformBounds+20>>2]=0|0;
   __Z13TransformAABBRK4AABBRK10Matrix4x4fRS_($84,$tmpcast$byval_copy,$xformBounds);
   ;HEAP32[$84+0>>2]=HEAP32[$xformBounds+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$xformBounds+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$xformBounds+8>>2]|0;HEAP32[$84+12>>2]=HEAP32[$xformBounds+12>>2]|0;HEAP32[$84+16>>2]=HEAP32[$xformBounds+16>>2]|0;HEAP32[$84+20>>2]=HEAP32[$xformBounds+20>>2]|0;
   $85 = (($this) + 24|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($86,23)|0);
   $88 = ($87|0)==(0|0);
   if ($88) {
    STACKTOP = sp;return;
   }
   $89 = ($5|0)==(0|0);
   if ($89) {
    HEAP32[$4>>2] = 0;
   } else {
    $90 = (($5) + 4|0);
    $91 = HEAP32[$90>>2]|0;
    HEAP32[$4>>2] = $91;
   }
   __ZN12MeshRenderer13SetSharedMeshE4PPtrI4MeshE($87,$4);
   STACKTOP = sp;return;
  }
 }
 $50 = ___cxa_find_matching_catch()|0;
 $51 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3501,($0|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $92 = ___cxa_find_matching_catch(0|0)|0;
  $93 = tempRet0;
  ___clang_call_terminate($92);
  // unreachable;
 } else {
  ___resumeException($50|0);
  // unreachable;
 }
}
function __Z22RegisterClass_TextMeshv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(102,259,260,0,261);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(2)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN5Unity9Component13RegisterClassEv();
 }
 HEAP8[$0>>0] = 16;
 $3 = (($0) + 1|0);
 $4 = $3;
 $5 = $4;
 HEAP8[$5>>0]=1954047316&255;HEAP8[$5+1>>0]=(1954047316>>8)&255;HEAP8[$5+2>>0]=(1954047316>>16)&255;HEAP8[$5+3>>0]=1954047316>>24;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP8[$7>>0]=1752393037&255;HEAP8[$7+1>>0]=(1752393037>>8)&255;HEAP8[$7+2>>0]=(1752393037>>16)&255;HEAP8[$7+3>>0]=1752393037>>24;
 $8 = (($0) + 9|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,102,2,($0|0),84,(2610|0),0,0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = HEAP8[$0>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   ___resumeException($16|0);
   // unreachable;
  }
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  __ZdlPv($22);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $11 = HEAP8[$0>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   STACKTOP = sp;return;
  }
  $14 = (($0) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate8TextMesh15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(102,564640,2058,0);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(84,$$byval_copy2,1,16,805960,23)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$3>>2] = ((805840 + 8|0));
  $6 = (($3) + 28|0);
  $7 = (($3) + 72|0);
  $8 = (($3) + 80|0);
  HEAP32[$8>>2] = 0;
  $9 = (($3) + 64|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 68|0);
  HEAP32[$10>>2] = 0;
  $11 = (($3) + 76|0);
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;HEAP32[$6+12>>2]=0|0;
  HEAP8[$11>>0] = 1;
  HEAP32[$7>>2] = -1;
  STACKTOP = sp;return ($3|0);
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(805960|0),23);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch(0|0)|0;
  $17 = tempRet0;
  ___clang_call_terminate($16);
  // unreachable;
 } else {
  ___resumeException($12|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK20TextRenderingPrivate8TextMesh25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 102;
}
function __ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806008,805992,$this,0);
 __ZN20TextRenderingPrivate8TextMesh8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,806008,805992,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN20TextRenderingPrivate8TextMesh8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate8TextMesh8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate8TextMesh8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN20TextRenderingPrivate8TextMesh8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $8;
 STACKTOP = sp;return;
}
function __ZZN20TextRenderingPrivate8TextMesh15InitializeClassEvEN37FunctorImpl_TextMesh_kDidAddComponent4CallEPviR11MessageData($object,$0,$1) {
 $object = $object|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $2 = sp;
 $3 = (($object) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (__ZNK5Unity10GameObject8IsActiveEv($4)|0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$3>>2]|0;
 $8 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($7,23)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (__ZN20TextRenderingPrivate8TextMesh7GetMeshEv($object)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  HEAP32[$2>>2] = 0;
 } else {
  $12 = (($10) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$2>>2] = $13;
 }
 __ZN12MeshRenderer13SetSharedMeshE4PPtrI4MeshE($8,$2);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMeshD1Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((805840 + 8|0));
 $1 = (($this) + 28|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  __ZN5Unity9ComponentD2Ev($this);
  STACKTOP = sp;return;
 }
 $5 = (($this) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$0>>2] = 59;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($6|0),($$byval_copy|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  ___cxa_call_unexpected(($9|0));
  // unreachable;
 } else {
  __ZN5Unity9ComponentD2Ev($this);
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate8TextMeshD0Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $eh$lpad$body$i$indexZ2D = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((805840 + 8|0));
 $1 = (($this) + 28|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  $5 = (($this) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$0>>2] = 59;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($6|0),($$byval_copy|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   ___cxa_call_unexpected(($9|0));
   // unreachable;
  }
 }
 HEAP32[$this>>2] = ((562072 + 8|0));
 __THREW__ = 0;
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $29 = ___cxa_find_matching_catch(0|0)|0;
   $30 = tempRet0;
   __THREW__ = 0;
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $33 = ___cxa_find_matching_catch(0|0)|0;
    $34 = tempRet0;
    ___clang_call_terminate($33);
    // unreachable;
   } else {
    $eh$lpad$body$i$indexZ2D = $29;
    ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if (!($28)) {
   $eh$lpad$body$index8Z2D = $24;$eh$lpad$body$indexZ2D = $23;
   __ZdlPv($this);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  $35 = ___cxa_find_matching_catch(0|0)|0;
  $36 = tempRet0;
  $eh$lpad$body$i$indexZ2D = $35;
  ___clang_call_terminate($eh$lpad$body$i$indexZ2D);
  // unreachable;
 } else {
  HEAP32[$this>>2] = ((560936 + 8|0));
  __THREW__ = 0;
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   $15 = ___cxa_find_matching_catch()|0;
   $16 = tempRet0;
   __THREW__ = 0;
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    $19 = ___cxa_find_matching_catch(0|0)|0;
    $20 = tempRet0;
    ___clang_call_terminate($19);
    // unreachable;
   } else {
    $eh$lpad$body$index8Z2D = $16;$eh$lpad$body$indexZ2D = $15;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
  __THREW__ = 0;
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  $eh$lpad$body$index8Z2D = $38;$eh$lpad$body$indexZ2D = $37;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN20TextRenderingPrivate8TextMesh8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0;
 var $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $1 = (($this) + 44|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)<($6>>>0);
 if ($7) {
  $8 = Math_fround(HEAPF32[$1>>2]);
  HEAPF32[$3>>2] = $8;
  HEAP32[$2>>2] = $4;
  $11 = $4;$13 = $6;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$1,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre6 = HEAP32[$5>>2]|0;
  $11 = $$pre;$13 = $$pre6;
 }
 $9 = (($this) + 52|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)<($13>>>0);
 if ($12) {
  $14 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$11>>2] = $14;
  HEAP32[$2>>2] = $10;
  $17 = $10;$19 = $13;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$9,4);
  $$pre7 = HEAP32[$2>>2]|0;
  $$pre8 = HEAP32[$5>>2]|0;
  $17 = $$pre7;$19 = $$pre8;
 }
 $15 = (($this) + 56|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)<($19>>>0);
 if ($18) {
  $20 = Math_fround(HEAPF32[$15>>2]);
  HEAPF32[$17>>2] = $20;
  HEAP32[$2>>2] = $16;
  $23 = $16;$25 = $19;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$15,4);
  $$pre9 = HEAP32[$2>>2]|0;
  $$pre10 = HEAP32[$5>>2]|0;
  $23 = $$pre9;$25 = $$pre10;
 }
 $21 = (($this) + 50|0);
 $22 = (($23) + 2|0);
 $24 = ($22>>>0)<($25>>>0);
 if ($24) {
  $26 = HEAP16[$21>>1]|0;
  HEAP16[$23>>1] = $26;
  HEAP32[$2>>2] = $22;
  $29 = $22;$31 = $25;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$21,2);
  $$pre11 = HEAP32[$2>>2]|0;
  $$pre12 = HEAP32[$5>>2]|0;
  $29 = $$pre11;$31 = $$pre12;
 }
 $27 = (($this) + 48|0);
 $28 = (($29) + 2|0);
 $30 = ($28>>>0)<($31>>>0);
 if ($30) {
  $32 = HEAP16[$27>>1]|0;
  HEAP16[$29>>1] = $32;
  HEAP32[$2>>2] = $28;
  $35 = $28;$37 = $31;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$27,2);
  $$pre13 = HEAP32[$2>>2]|0;
  $$pre14 = HEAP32[$5>>2]|0;
  $35 = $$pre13;$37 = $$pre14;
 }
 $33 = (($this) + 60|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)<($37>>>0);
 if ($36) {
  $38 = Math_fround(HEAPF32[$33>>2]);
  HEAPF32[$35>>2] = $38;
  HEAP32[$2>>2] = $34;
  $41 = $34;$43 = $37;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$33,4);
  $$pre15 = HEAP32[$2>>2]|0;
  $$pre16 = HEAP32[$5>>2]|0;
  $41 = $$pre15;$43 = $$pre16;
 }
 $39 = (($this) + 64|0);
 $40 = (($41) + 4|0);
 $42 = ($40>>>0)<($43>>>0);
 if ($42) {
  $44 = HEAP32[$39>>2]|0;
  HEAP32[$41>>2] = $44;
  HEAP32[$2>>2] = $40;
  $47 = $40;$49 = $43;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$39,4);
  $$pre17 = HEAP32[$2>>2]|0;
  $$pre18 = HEAP32[$5>>2]|0;
  $47 = $$pre17;$49 = $$pre18;
 }
 $45 = (($this) + 68|0);
 $46 = (($47) + 4|0);
 $48 = ($46>>>0)<($49>>>0);
 if ($48) {
  $50 = HEAP32[$45>>2]|0;
  HEAP32[$47>>2] = $50;
  HEAP32[$2>>2] = $46;
  $53 = $46;$55 = $49;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$45,4);
  $$pre19 = HEAP32[$2>>2]|0;
  $$pre20 = HEAP32[$5>>2]|0;
  $53 = $$pre19;$55 = $$pre20;
 }
 $51 = (($this) + 76|0);
 $52 = (($53) + 1|0);
 $54 = ($52>>>0)<($55>>>0);
 if ($54) {
  $56 = HEAP8[$51>>0]|0;
  HEAP8[$53>>0] = $56;
  $57 = HEAP32[$2>>2]|0;
  $58 = (($57) + 1|0);
  HEAP32[$2>>2] = $58;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$51,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $59 = (($this) + 40|0);
 __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($59,$transfer);
 $60 = (($this) + 72|0);
 $61 = HEAP32[$2>>2]|0;
 $62 = (($61) + 4|0);
 $63 = HEAP32[$5>>2]|0;
 $64 = ($62>>>0)<($63>>>0);
 if ($64) {
  $65 = HEAP32[$60>>2]|0;
  HEAP32[$61>>2] = $65;
  HEAP32[$2>>2] = $62;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($2,$60,4);
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate8TextMesh8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i$i$i = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i12 = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i20 = 0, $$pre$i$i$i3 = 0, $$pre$i$i$i8 = 0, $$pre$phi$i$i$i17Z2D = 0, $$pre$phi$i$i$i4Z2D = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre22 = 0, $$pre23 = 0, $$pre24 = 0, $$pre25 = 0, $$pre26 = 0, $$pre27 = 0;
 var $$pre28 = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre33 = 0, $$pre34 = 0, $$pre35 = 0, $$pre36 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $1 = (($this) + 44|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre$i$i$i = HEAP32[$1>>2]|0;
  $$pre = HEAP32[$2>>2]|0;
  $$pre22 = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$iZ2D = $1;$10 = $$pre$i$i$i;$14 = $$pre;$16 = $$pre22;
 } else {
  $8 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $9 = (HEAPF32[tempDoublePtr>>2]=$8,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $1;$10 = $9;$14 = $4;$16 = $6;
 }
 $11 = (_llvm_bswap_i32(($10|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $11;
 $12 = (($this) + 52|0);
 $13 = (($14) + 4|0);
 $15 = ($13>>>0)>($16>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$12,4);
  $$pre$i$i$i3 = HEAP32[$12>>2]|0;
  $$pre23 = HEAP32[$2>>2]|0;
  $$pre24 = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$i4Z2D = $12;$19 = $$pre$i$i$i3;$23 = $$pre23;$25 = $$pre24;
 } else {
  $17 = Math_fround(HEAPF32[$14>>2]);
  HEAPF32[$12>>2] = $17;
  HEAP32[$2>>2] = $13;
  $18 = (HEAPF32[tempDoublePtr>>2]=$17,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i4Z2D = $12;$19 = $18;$23 = $13;$25 = $16;
 }
 $20 = (_llvm_bswap_i32(($19|0))|0);
 HEAP32[$$pre$phi$i$i$i4Z2D>>2] = $20;
 $21 = (($this) + 56|0);
 $22 = (($23) + 4|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$21,4);
  $$pre$i$i$i8 = HEAP32[$21>>2]|0;
  $$pre25 = HEAP32[$2>>2]|0;
  $$pre26 = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$i9Z2D = $21;$28 = $$pre$i$i$i8;$32 = $$pre25;$34 = $$pre26;
 } else {
  $26 = Math_fround(HEAPF32[$23>>2]);
  HEAPF32[$21>>2] = $26;
  HEAP32[$2>>2] = $22;
  $27 = (HEAPF32[tempDoublePtr>>2]=$26,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i9Z2D = $21;$28 = $27;$32 = $22;$34 = $25;
 }
 $29 = (_llvm_bswap_i32(($28|0))|0);
 HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $29;
 $30 = (($this) + 50|0);
 $31 = (($32) + 2|0);
 $33 = ($31>>>0)>($34>>>0);
 if ($33) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$30,2);
  $$pre$i$i$i11 = HEAP16[$30>>1]|0;
  $$pre27 = HEAP32[$2>>2]|0;
  $$pre28 = HEAP32[$5>>2]|0;
  $37 = $$pre$i$i$i11;$44 = $$pre27;$46 = $$pre28;
 } else {
  $35 = HEAP16[$32>>1]|0;
  HEAP16[$30>>1] = $35;
  HEAP32[$2>>2] = $31;
  $37 = $35;$44 = $31;$46 = $34;
 }
 $36 = $37&65535;
 $38 = $36 << 8;
 $39 = $36 >>> 8;
 $40 = $38 | $39;
 $41 = $40&65535;
 HEAP16[$30>>1] = $41;
 $42 = (($this) + 48|0);
 $43 = (($44) + 2|0);
 $45 = ($43>>>0)>($46>>>0);
 if ($45) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$42,2);
  $$pre$i$i$i12 = HEAP16[$42>>1]|0;
  $$pre29 = HEAP32[$2>>2]|0;
  $$pre30 = HEAP32[$5>>2]|0;
  $49 = $$pre$i$i$i12;$56 = $$pre29;$58 = $$pre30;
 } else {
  $47 = HEAP16[$44>>1]|0;
  HEAP16[$42>>1] = $47;
  HEAP32[$2>>2] = $43;
  $49 = $47;$56 = $43;$58 = $46;
 }
 $48 = $49&65535;
 $50 = $48 << 8;
 $51 = $48 >>> 8;
 $52 = $50 | $51;
 $53 = $52&65535;
 HEAP16[$42>>1] = $53;
 $54 = (($this) + 60|0);
 $55 = (($56) + 4|0);
 $57 = ($55>>>0)>($58>>>0);
 if ($57) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$54,4);
  $$pre$i$i$i16 = HEAP32[$54>>2]|0;
  $$pre31 = HEAP32[$2>>2]|0;
  $$pre32 = HEAP32[$5>>2]|0;
  $$pre$phi$i$i$i17Z2D = $54;$61 = $$pre$i$i$i16;$65 = $$pre31;$67 = $$pre32;
 } else {
  $59 = Math_fround(HEAPF32[$56>>2]);
  HEAPF32[$54>>2] = $59;
  HEAP32[$2>>2] = $55;
  $60 = (HEAPF32[tempDoublePtr>>2]=$59,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$i17Z2D = $54;$61 = $60;$65 = $55;$67 = $58;
 }
 $62 = (_llvm_bswap_i32(($61|0))|0);
 HEAP32[$$pre$phi$i$i$i17Z2D>>2] = $62;
 $63 = (($this) + 64|0);
 $64 = (($65) + 4|0);
 $66 = ($64>>>0)>($67>>>0);
 if ($66) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$63,4);
  $$pre$i$i$i19 = HEAP32[$63>>2]|0;
  $$pre33 = HEAP32[$2>>2]|0;
  $$pre34 = HEAP32[$5>>2]|0;
  $69 = $$pre$i$i$i19;$73 = $$pre33;$75 = $$pre34;
 } else {
  $68 = HEAP32[$65>>2]|0;
  HEAP32[$63>>2] = $68;
  HEAP32[$2>>2] = $64;
  $69 = $68;$73 = $64;$75 = $67;
 }
 $70 = (_llvm_bswap_i32(($69|0))|0);
 HEAP32[$63>>2] = $70;
 $71 = (($this) + 68|0);
 $72 = (($73) + 4|0);
 $74 = ($72>>>0)>($75>>>0);
 if ($74) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$71,4);
  $$pre$i$i$i20 = HEAP32[$71>>2]|0;
  $$pre35 = HEAP32[$2>>2]|0;
  $$pre36 = HEAP32[$5>>2]|0;
  $77 = $$pre$i$i$i20;$81 = $$pre35;$83 = $$pre36;
 } else {
  $76 = HEAP32[$73>>2]|0;
  HEAP32[$71>>2] = $76;
  HEAP32[$2>>2] = $72;
  $77 = $76;$81 = $72;$83 = $75;
 }
 $78 = (_llvm_bswap_i32(($77|0))|0);
 HEAP32[$71>>2] = $78;
 $79 = (($this) + 76|0);
 $80 = (($81) + 1|0);
 $82 = ($80>>>0)>($83>>>0);
 if ($82) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$79,1);
 } else {
  $84 = HEAP8[$81>>0]|0;
  HEAP8[$79>>0] = $84;
  $85 = HEAP32[$2>>2]|0;
  $86 = (($85) + 1|0);
  HEAP32[$2>>2] = $86;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $87 = (($this) + 40|0);
 __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI18StreamedBinaryReadILb1EEEEvRT_($87,$transfer);
 $88 = (($this) + 72|0);
 $89 = HEAP32[$2>>2]|0;
 $90 = (($89) + 4|0);
 $91 = HEAP32[$5>>2]|0;
 $92 = ($90>>>0)>($91>>>0);
 if ($92) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$88,4);
  $$pre$i$i$i$i$i$i = HEAP32[$88>>2]|0;
  $94 = $$pre$i$i$i$i$i$i;
  HEAP32[$88>>2] = $94;
  STACKTOP = sp;return;
 } else {
  $93 = HEAP32[$89>>2]|0;
  HEAP32[$88>>2] = $93;
  HEAP32[$2>>2] = $90;
  $94 = $93;
  HEAP32[$88>>2] = $94;
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate8TextMesh8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0;
 var $8 = Math_fround(0), $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity9Component8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 __ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $1 = (($this) + 44|0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4>>>0)>($6>>>0);
 if ($7) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$1,4);
  $$pre = HEAP32[$2>>2]|0;
  $$pre6 = HEAP32[$5>>2]|0;
  $11 = $$pre;$13 = $$pre6;
 } else {
  $8 = Math_fround(HEAPF32[$3>>2]);
  HEAPF32[$1>>2] = $8;
  HEAP32[$2>>2] = $4;
  $11 = $4;$13 = $6;
 }
 $9 = (($this) + 52|0);
 $10 = (($11) + 4|0);
 $12 = ($10>>>0)>($13>>>0);
 if ($12) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$9,4);
  $$pre7 = HEAP32[$2>>2]|0;
  $$pre8 = HEAP32[$5>>2]|0;
  $17 = $$pre7;$19 = $$pre8;
 } else {
  $14 = Math_fround(HEAPF32[$11>>2]);
  HEAPF32[$9>>2] = $14;
  HEAP32[$2>>2] = $10;
  $17 = $10;$19 = $13;
 }
 $15 = (($this) + 56|0);
 $16 = (($17) + 4|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$15,4);
  $$pre9 = HEAP32[$2>>2]|0;
  $$pre10 = HEAP32[$5>>2]|0;
  $23 = $$pre9;$25 = $$pre10;
 } else {
  $20 = Math_fround(HEAPF32[$17>>2]);
  HEAPF32[$15>>2] = $20;
  HEAP32[$2>>2] = $16;
  $23 = $16;$25 = $19;
 }
 $21 = (($this) + 50|0);
 $22 = (($23) + 2|0);
 $24 = ($22>>>0)>($25>>>0);
 if ($24) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$21,2);
  $$pre11 = HEAP32[$2>>2]|0;
  $$pre12 = HEAP32[$5>>2]|0;
  $29 = $$pre11;$31 = $$pre12;
 } else {
  $26 = HEAP16[$23>>1]|0;
  HEAP16[$21>>1] = $26;
  HEAP32[$2>>2] = $22;
  $29 = $22;$31 = $25;
 }
 $27 = (($this) + 48|0);
 $28 = (($29) + 2|0);
 $30 = ($28>>>0)>($31>>>0);
 if ($30) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$27,2);
  $$pre13 = HEAP32[$2>>2]|0;
  $$pre14 = HEAP32[$5>>2]|0;
  $35 = $$pre13;$37 = $$pre14;
 } else {
  $32 = HEAP16[$29>>1]|0;
  HEAP16[$27>>1] = $32;
  HEAP32[$2>>2] = $28;
  $35 = $28;$37 = $31;
 }
 $33 = (($this) + 60|0);
 $34 = (($35) + 4|0);
 $36 = ($34>>>0)>($37>>>0);
 if ($36) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$33,4);
  $$pre15 = HEAP32[$2>>2]|0;
  $$pre16 = HEAP32[$5>>2]|0;
  $41 = $$pre15;$43 = $$pre16;
 } else {
  $38 = Math_fround(HEAPF32[$35>>2]);
  HEAPF32[$33>>2] = $38;
  HEAP32[$2>>2] = $34;
  $41 = $34;$43 = $37;
 }
 $39 = (($this) + 64|0);
 $40 = (($41) + 4|0);
 $42 = ($40>>>0)>($43>>>0);
 if ($42) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$39,4);
  $$pre17 = HEAP32[$2>>2]|0;
  $$pre18 = HEAP32[$5>>2]|0;
  $47 = $$pre17;$49 = $$pre18;
 } else {
  $44 = HEAP32[$41>>2]|0;
  HEAP32[$39>>2] = $44;
  HEAP32[$2>>2] = $40;
  $47 = $40;$49 = $43;
 }
 $45 = (($this) + 68|0);
 $46 = (($47) + 4|0);
 $48 = ($46>>>0)>($49>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$45,4);
  $$pre19 = HEAP32[$2>>2]|0;
  $$pre20 = HEAP32[$5>>2]|0;
  $53 = $$pre19;$55 = $$pre20;
 } else {
  $50 = HEAP32[$47>>2]|0;
  HEAP32[$45>>2] = $50;
  HEAP32[$2>>2] = $46;
  $53 = $46;$55 = $49;
 }
 $51 = (($this) + 76|0);
 $52 = (($53) + 1|0);
 $54 = ($52>>>0)>($55>>>0);
 if ($54) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$51,1);
 } else {
  $56 = HEAP8[$53>>0]|0;
  HEAP8[$51>>0] = $56;
  $57 = HEAP32[$2>>2]|0;
  $58 = (($57) + 1|0);
  HEAP32[$2>>2] = $58;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $59 = (($this) + 40|0);
 __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI18StreamedBinaryReadILb0EEEEvRT_($59,$transfer);
 $60 = (($this) + 72|0);
 $61 = HEAP32[$2>>2]|0;
 $62 = (($61) + 4|0);
 $63 = HEAP32[$5>>2]|0;
 $64 = ($62>>>0)>($63>>>0);
 if ($64) {
  __ZN12CachedReader15UpdateReadCacheEPvj($2,$60,4);
  STACKTOP = sp;return;
 } else {
  $65 = HEAP32[$61>>2]|0;
  HEAP32[$60>>2] = $65;
  HEAP32[$2>>2] = $62;
  STACKTOP = sp;return;
 }
}
function __ZN20TextRenderingPrivate8TextMesh8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $converter$i$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i3 = sp;
 __ZN14SafeBinaryRead10SetVersionEi($transfer,3);
 __ZN5Unity9Component8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580712>>2]|0;
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,806016,$1,$converter$i$i3,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags($transfer,$0,0);
  } else {
   $5 = HEAP32[$converter$i$i3>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($0,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 44|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$7,806024,0);
 $8 = (($this) + 52|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$8,806040,0);
 $9 = (($this) + 56|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$9,806056,0);
 $10 = (($this) + 50|0);
 __ZN14SafeBinaryRead8TransferIsEEvRT_PKc17TransferMetaFlags($transfer,$10,806072,0);
 $11 = (($this) + 48|0);
 __ZN14SafeBinaryRead8TransferIsEEvRT_PKc17TransferMetaFlags($transfer,$11,806088,0);
 $12 = (($this) + 60|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$12,806104,0);
 $13 = (($this) + 64|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$13,806120,0);
 $14 = (($this) + 68|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$14,806136,0);
 $15 = (($this) + 76|0);
 $16 = HEAP32[580544>>2]|0;
 $17 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,806152,$16,$converter$i$i3,0)|0);
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = ($17|0)>(0);
  do {
   if ($19) {
    $20 = (($transfer) + 12|0);
    $21 = (($transfer) + 80|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + 12|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($transfer) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($transfer) + 28|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($transfer) + 32|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = Math_imul($30, $28)|0;
    $$sum$i$i$i$i$i = (($24) - ($31))|0;
    $32 = (($26) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$20>>2] = $32;
    $33 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($33)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $34 = (($26) + ($$sum1$i$i$i$i$i)|0);
     $35 = (($transfer) + 20|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($34>>>0)>($36>>>0);
     if (!($37)) {
      $38 = HEAP8[$32>>0]|0;
      HEAP8[$15>>0] = $38;
      $39 = HEAP32[$20>>2]|0;
      $40 = (($39) + 1|0);
      HEAP32[$20>>2] = $40;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($20,$15,1);
   } else {
    $41 = HEAP32[$converter$i$i3>>2]|0;
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     (FUNCTION_TABLE_iii[$41 & 4095]($15,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $43 = (($this) + 40|0);
 $44 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,806168,806232,$converter$i$i3,1)|0);
 $45 = ($44|0)==(0);
 if (!($45)) {
  $46 = ($44|0)>(0);
  if ($46) {
   __ZN4PPtrIN20TextRenderingPrivate4FontEE8TransferI14SafeBinaryReadEEvRT_($43,$transfer);
  } else {
   $47 = HEAP32[$converter$i$i3>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    (FUNCTION_TABLE_iii[$47 & 4095]($43,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $49 = (($this) + 72|0);
 $50 = HEAP32[580560>>2]|0;
 $51 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,806176,$50,$converter$i$i3,1)|0);
 $52 = ($51|0)==(0);
 if ($52) {
  STACKTOP = sp;return;
 }
 $53 = ($51|0)>(0);
 if ($53) {
  __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
  $54 = HEAP32[$transfer>>2]|0;
  $55 = $54 & 512;
  $56 = ($55|0)==(0);
  __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$49,806184,0);
  if (!($56)) {
   $57 = HEAP32[$49>>2]|0;
   $58 = (_llvm_bswap_i32(($57|0))|0);
   HEAP32[$49>>2] = $58;
  }
 } else {
  $59 = HEAP32[$converter$i$i3>>2]|0;
  $60 = ($59|0)==(0|0);
  if (!($60)) {
   (FUNCTION_TABLE_iii[$59 & 4095]($49,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate8TextMesh8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0;
 var $localIdentifier$i$i$i = 0, $p$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $localIdentifier$i$i$i = sp;
 $p$i$i$i = sp + 16|0;
 __ZN13ProxyTransfer10SetVersionEi($transfer,3);
 __ZN5Unity9Component8TransferI13ProxyTransferEEvRT_($this,$transfer);
 $0 = (($this) + 28|0);
 $1 = HEAP32[580712>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806016,$1,$0,0);
 __ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags($transfer,806248,806248,$localIdentifier$i$i$i,1);
 $2 = HEAP32[580552>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806224,$2,$p$i$i$i,0);
 $3 = (($transfer) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($5) + (($7*24)|0)|0) + 12|0);
 HEAP32[$8>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer16EndArrayTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $9 = (($this) + 44|0);
 $10 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806024,$10,$9,0);
 $11 = HEAP32[$3>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$6>>2]|0;
 $14 = ((($12) + (($13*24)|0)|0) + 12|0);
 HEAP32[$14>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $15 = (($this) + 52|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806040,$10,$15,0);
 $16 = HEAP32[$3>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP32[$6>>2]|0;
 $19 = ((($17) + (($18*24)|0)|0) + 12|0);
 HEAP32[$19>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $20 = (($this) + 56|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806056,$10,$20,0);
 $21 = HEAP32[$3>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$6>>2]|0;
 $24 = ((($22) + (($23*24)|0)|0) + 12|0);
 HEAP32[$24>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $25 = (($this) + 50|0);
 $26 = HEAP32[580672>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806072,$26,$25,0);
 $27 = HEAP32[$3>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$6>>2]|0;
 $30 = ((($28) + (($29*24)|0)|0) + 12|0);
 HEAP32[$30>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $31 = (($this) + 48|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806088,$26,$31,0);
 $32 = HEAP32[$3>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$6>>2]|0;
 $35 = ((($33) + (($34*24)|0)|0) + 12|0);
 HEAP32[$35>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $36 = (($this) + 60|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806104,$10,$36,0);
 $37 = HEAP32[$3>>2]|0;
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP32[$6>>2]|0;
 $40 = ((($38) + (($39*24)|0)|0) + 12|0);
 HEAP32[$40>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $41 = (($this) + 64|0);
 $42 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806120,$42,$41,0);
 $43 = HEAP32[$3>>2]|0;
 $44 = HEAP32[$43>>2]|0;
 $45 = HEAP32[$6>>2]|0;
 $46 = ((($44) + (($45*24)|0)|0) + 12|0);
 HEAP32[$46>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $47 = (($this) + 68|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806136,$42,$47,0);
 $48 = HEAP32[$3>>2]|0;
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$6>>2]|0;
 $51 = ((($49) + (($50*24)|0)|0) + 12|0);
 HEAP32[$51>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $52 = (($this) + 76|0);
 $53 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806152,$53,$52,0);
 $54 = HEAP32[$3>>2]|0;
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP32[$6>>2]|0;
 $57 = ((($55) + (($56*24)|0)|0) + 12|0);
 HEAP32[$57>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $58 = (($this) + 40|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806168,806232,$58,0);
 $59 = (($localIdentifier$i$i$i) + 8|0);
 $60 = $59;
 $61 = $60;
 HEAP32[$61>>2] = 0;
 $62 = (($60) + 4)|0;
 $63 = $62;
 HEAP32[$63>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806192,$42,$58,1);
 $64 = HEAP32[$3>>2]|0;
 $65 = HEAP32[$64>>2]|0;
 $66 = HEAP32[$6>>2]|0;
 $67 = ((($65) + (($66*24)|0)|0) + 12|0);
 HEAP32[$67>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $68 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806208,$68,$59,1);
 $69 = HEAP32[$3>>2]|0;
 $70 = HEAP32[$69>>2]|0;
 $71 = HEAP32[$6>>2]|0;
 $72 = ((($70) + (($71*24)|0)|0) + 12|0);
 HEAP32[$72>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $73 = (($this) + 72|0);
 $74 = HEAP32[580560>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806176,$74,$73,0);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $75 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,806184,$75,$73,1);
 $76 = HEAP32[$3>>2]|0;
 $77 = HEAP32[$76>>2]|0;
 $78 = HEAP32[$6>>2]|0;
 $79 = ((($77) + (($78*24)|0)|0) + 12|0);
 HEAP32[$79>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate17TextMeshGenerator3GetERK11UTF16StringPNS_4FontE10TextAnchor13TextAlignmentfffbb11ColorRGBA32ii($text,$font,$anchor,$alignment,$wordWrapWidth,$tabSize,$lineSpacing,$richText,$pixelCorrect,$color,$fontSize,$fontStyle) {
 $text = $text|0;
 $font = $font|0;
 $anchor = $anchor|0;
 $alignment = $alignment|0;
 $wordWrapWidth = Math_fround($wordWrapWidth);
 $tabSize = Math_fround($tabSize);
 $lineSpacing = Math_fround($lineSpacing);
 $richText = $richText|0;
 $pixelCorrect = $pixelCorrect|0;
 $color = $color|0;
 $fontSize = $fontSize|0;
 $fontStyle = $fontStyle|0;
 var $$0 = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$02 = 0, $$03 = 0, $$04 = 0, $$05 = 0, $$06 = 0, $$08 = 0, $$anchor = 0, $$lcssa = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0;
 var $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $not$ = 0, $or$cond = 0, $reportNonDynamicFontError$1$off0 = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = ($font|0)==(0|0);
 do {
  if ($2) {
   $3 = HEAP32[806280>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    HEAP8[$0>>0] = 18;
    $5 = (($0) + 1|0);
    dest=$5+0|0; src=806288+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
    $6 = (($0) + 10|0);
    HEAP8[$6>>0] = 0;
    __THREW__ = 0;
    $7 = (invoke_i(58)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(1532,($7|0),128,($0|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      HEAP32[806280>>2] = $10;
      $13 = HEAP8[$0>>0]|0;
      $14 = $13 & 1;
      $15 = ($14<<24>>24)==(0);
      if ($15) {
       $$02 = $10;
       break;
      }
      $16 = (($0) + 8|0);
      $17 = HEAP32[$16>>2]|0;
      __ZdlPv($17);
      $$pre = HEAP32[806280>>2]|0;
      $$02 = $$pre;
      break;
     }
    }
    $18 = ___cxa_find_matching_catch()|0;
    $19 = tempRet0;
    $20 = HEAP8[$0>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $$03 = $19;$$04 = $18;
     ___resumeException($$04|0);
     // unreachable;
    }
    $23 = (($0) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __ZdlPv($24);
    $$03 = $19;$$04 = $18;
    ___resumeException($$04|0);
    // unreachable;
   } else {
    $$02 = $3;
   }
  } else {
   $$02 = $font;
  }
 } while(0);
 $25 = (($$02) + 76|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(-2);
 if ($27) {
  $$05 = $fontStyle;$$06 = $fontSize;$reportNonDynamicFontError$1$off0 = 0;
 } else {
  $28 = $fontStyle | $fontSize;
  $not$ = ($28|0)!=(0);
  $$05 = 0;$$06 = 0;$reportNonDynamicFontError$1$off0 = $not$;
 }
 $29 = ($alignment|0)==(3);
 if ($29) {
  $30 = ($anchor|0)>(-1);
  $31 = ($anchor>>>0)<(9);
  $or$cond = $30 & $31;
  if ($or$cond) {
   $32 = (806304 + ($anchor<<2)|0);
   $33 = HEAP32[$32>>2]|0;
   $$08 = $33;
  } else {
   $$08 = 3;
  }
 } else {
  $$08 = $alignment;
 }
 $34 = HEAP32[806256>>2]|0;
 $35 = HEAP32[806264>>2]|0;
 $36 = ($34|0)==($35|0);
 L21: do {
  if (!($36)) {
   $37 = (($$02) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($anchor|0)==(9);
   $40 = (($text) + 4|0);
   $41 = $richText&1;
   $42 = $pixelCorrect&1;
   $43 = HEAP32[$color>>2]|0;
   $44 = $43&65535;
   $45 = $43&255;
   $46 = ($44&65535) >>> 8;
   $47 = $46&255;
   $48 = $43 >>> 16;
   $49 = $48&255;
   $50 = $43 >>> 24;
   $51 = $50&255;
   L23: do {
    if ($39) {
     $53 = $34;
     while(1) {
      $52 = HEAP32[$53>>2]|0;
      $54 = (($52) + 4|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ($55|0)==($38|0);
      do {
       if ($56) {
        $57 = (($52) + 32|0);
        $58 = Math_fround(HEAPF32[$57>>2]);
        $59 = $58 == $wordWrapWidth;
        if ($59) {
         $60 = (($52) + 44|0);
         $61 = Math_fround(HEAPF32[$60>>2]);
         $62 = $61 == $tabSize;
         if ($62) {
          $63 = (($52) + 40|0);
          $64 = Math_fround(HEAPF32[$63>>2]);
          $65 = $64 == $lineSpacing;
          if ($65) {
           $66 = (($52) + 68|0);
           $67 = HEAP32[$66>>2]|0;
           $68 = HEAP32[$40>>2]|0;
           $69 = ($67|0)==($68|0);
           if ($69) {
            $70 = HEAP32[$text>>2]|0;
            $71 = ($70|0)==(0|0);
            if (!($71)) {
             $72 = (($52) + 64|0);
             $73 = HEAP32[$72>>2]|0;
             $74 = $67 << 1;
             $75 = (_memcmp($73,$70,$74)|0);
             $76 = ($75|0)==(0);
             if (!($76)) {
              break;
             }
            }
            $77 = (($52) + 52|0);
            $78 = HEAP32[$77>>2]|0;
            $79 = ($78|0)==($$06|0);
            if ($79) {
             $80 = (($52) + 56|0);
             $81 = HEAP32[$80>>2]|0;
             $82 = ($81|0)==($$05|0);
             if ($82) {
              $83 = (($52) + 49|0);
              $84 = HEAP8[$83>>0]|0;
              $85 = $84&255;
              $86 = ($85|0)==($41|0);
              if ($86) {
               $87 = (($52) + 28|0);
               $88 = HEAP8[$87>>0]|0;
               $89 = $88&255;
               $90 = ($89|0)==($42|0);
               if ($90) {
                $91 = (($52) + 60|0);
                $92 = HEAP8[$91>>0]|0;
                $93 = ($92<<24>>24)==($45<<24>>24);
                if ($93) {
                 $94 = (($52) + 61|0);
                 $95 = HEAP8[$94>>0]|0;
                 $96 = ($95<<24>>24)==($47<<24>>24);
                 if (!($96)) {
                  break;
                 }
                 $97 = (($52) + 62|0);
                 $98 = HEAP8[$97>>0]|0;
                 $99 = ($98<<24>>24)==($49<<24>>24);
                 if (!($99)) {
                  break;
                 }
                 $100 = (($52) + 63|0);
                 $101 = HEAP8[$100>>0]|0;
                 $102 = ($101<<24>>24)==($51<<24>>24);
                 if ($102) {
                  $$lcssa = $52;
                  break L23;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      } while(0);
      $103 = (($53) + 4|0);
      $104 = ($103|0)==($35|0);
      if ($104) {
       break L21;
      } else {
       $53 = $103;
      }
     }
    } else {
     $106 = $34;
     while(1) {
      $105 = HEAP32[$106>>2]|0;
      $107 = (($105) + 4|0);
      $108 = HEAP32[$107>>2]|0;
      $109 = ($108|0)==($38|0);
      do {
       if ($109) {
        $110 = (($105) + 24|0);
        $111 = HEAP32[$110>>2]|0;
        $112 = ($111|0)==($anchor|0);
        if ($112) {
         $113 = (($105) + 36|0);
         $114 = HEAP32[$113>>2]|0;
         $115 = ($114|0)==($$08|0);
         if ($115) {
          $116 = (($105) + 32|0);
          $117 = Math_fround(HEAPF32[$116>>2]);
          $118 = $117 == $wordWrapWidth;
          if ($118) {
           $119 = (($105) + 44|0);
           $120 = Math_fround(HEAPF32[$119>>2]);
           $121 = $120 == $tabSize;
           if ($121) {
            $122 = (($105) + 40|0);
            $123 = Math_fround(HEAPF32[$122>>2]);
            $124 = $123 == $lineSpacing;
            if ($124) {
             $125 = (($105) + 68|0);
             $126 = HEAP32[$125>>2]|0;
             $127 = HEAP32[$40>>2]|0;
             $128 = ($126|0)==($127|0);
             if ($128) {
              $129 = HEAP32[$text>>2]|0;
              $130 = ($129|0)==(0|0);
              if (!($130)) {
               $131 = (($105) + 64|0);
               $132 = HEAP32[$131>>2]|0;
               $133 = $126 << 1;
               $134 = (_memcmp($132,$129,$133)|0);
               $135 = ($134|0)==(0);
               if (!($135)) {
                break;
               }
              }
              $136 = (($105) + 52|0);
              $137 = HEAP32[$136>>2]|0;
              $138 = ($137|0)==($$06|0);
              if ($138) {
               $139 = (($105) + 56|0);
               $140 = HEAP32[$139>>2]|0;
               $141 = ($140|0)==($$05|0);
               if ($141) {
                $142 = (($105) + 49|0);
                $143 = HEAP8[$142>>0]|0;
                $144 = $143&255;
                $145 = ($144|0)==($41|0);
                if ($145) {
                 $146 = (($105) + 28|0);
                 $147 = HEAP8[$146>>0]|0;
                 $148 = $147&255;
                 $149 = ($148|0)==($42|0);
                 if (!($149)) {
                  break;
                 }
                 $150 = (($105) + 60|0);
                 $151 = HEAP8[$150>>0]|0;
                 $152 = ($151<<24>>24)==($45<<24>>24);
                 if (!($152)) {
                  break;
                 }
                 $153 = (($105) + 61|0);
                 $154 = HEAP8[$153>>0]|0;
                 $155 = ($154<<24>>24)==($47<<24>>24);
                 if (!($155)) {
                  break;
                 }
                 $156 = (($105) + 62|0);
                 $157 = HEAP8[$156>>0]|0;
                 $158 = ($157<<24>>24)==($49<<24>>24);
                 if (!($158)) {
                  break;
                 }
                 $159 = (($105) + 63|0);
                 $160 = HEAP8[$159>>0]|0;
                 $161 = ($160<<24>>24)==($51<<24>>24);
                 if ($161) {
                  $$lcssa = $105;
                  break L23;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      } while(0);
      $166 = (($106) + 4|0);
      $167 = ($166|0)==($35|0);
      if ($167) {
       break L21;
      } else {
       $106 = $166;
      }
     }
    }
   } while(0);
   $162 = (__Z14GetTimeManagerv()|0);
   $163 = (($162) + 128|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (($$lcssa) + 92|0);
   HEAP32[$165>>2] = $164;
   $$0 = $$lcssa;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 if ($reportNonDynamicFontError$1$off0) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(806344,0,806416,86,512,0,0,0);
 }
 $168 = ($anchor|0)==(9);
 $$anchor = $168 ? 0 : $anchor;
 $169 = (__Znwj(96)|0);
 $170 = HEAP32[$color>>2]|0;
 HEAP32[$1>>2] = $170;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiifffiiiii(1,($169|0),($text|0),($$02|0),($$anchor|0),($$08|0),(+$wordWrapWidth),(+$tabSize),(+$lineSpacing),($richText|0),($pixelCorrect|0),($tmpcast$byval_copy|0),($$06|0),($$05|0));
 $171 = __THREW__; __THREW__ = 0;
 $172 = $171&1;
 if ($172) {
  $199 = ___cxa_find_matching_catch()|0;
  $200 = tempRet0;
  __ZdlPv($169);
  $$03 = $200;$$04 = $199;
  ___resumeException($$04|0);
  // unreachable;
 }
 __ZN20TextRenderingPrivate17TextMeshGenerator8GenerateEv($169);
 $173 = HEAP32[806264>>2]|0;
 $174 = HEAP32[806272>>2]|0;
 $175 = ($173|0)==($174|0);
 if (!($175)) {
  $176 = ($173|0)==(0|0);
  if ($176) {
   $178 = 0;
  } else {
   HEAP32[$173>>2] = $169;
   $$pre$i = HEAP32[806264>>2]|0;
   $178 = $$pre$i;
  }
  $177 = (($178) + 4|0);
  HEAP32[806264>>2] = $177;
  $$0 = $169;
  STACKTOP = sp;return ($$0|0);
 }
 $179 = HEAP32[806256>>2]|0;
 $180 = $173;
 $181 = $179;
 $182 = (($180) - ($181))|0;
 $183 = $182 >> 2;
 $184 = (($183) + 1)|0;
 $185 = ($184>>>0)>(1073741823);
 if ($185) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $186 = ($183>>>0)<(536870911);
 if ($186) {
  $187 = $182 >> 1;
  $188 = ($187>>>0)<($184>>>0);
  $189 = $188 ? $184 : $187;
  $190 = ($189|0)==(0);
  if ($190) {
   $$0$i3$i$i = 0;$194 = 0;
  } else {
   $$0$i2$i$i = $189;
   label = 62;
  }
 } else {
  $$0$i2$i$i = 1073741823;
  label = 62;
 }
 if ((label|0) == 62) {
  $191 = $$0$i2$i$i << 2;
  $192 = (__Znwj($191)|0);
  $$0$i3$i$i = $$0$i2$i$i;$194 = $192;
 }
 $193 = (($194) + ($183<<2)|0);
 $195 = (($194) + ($$0$i3$i$i<<2)|0);
 $196 = ($193|0)==(0|0);
 if (!($196)) {
  HEAP32[$193>>2] = $169;
 }
 $197 = (($194) + ($184<<2)|0);
 _memcpy(($194|0),($179|0),($182|0))|0;
 HEAP32[806256>>2] = $194;
 HEAP32[806264>>2] = $197;
 HEAP32[806272>>2] = $195;
 $198 = ($179|0)==(0|0);
 if ($198) {
  $$0 = $169;
  STACKTOP = sp;return ($$0|0);
 }
 __ZdlPv($179);
 $$0 = $169;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20TextRenderingPrivate17TextMeshGenerator8GenerateEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0;
 var $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0, $generator = 0, $temp$0$i$i = 0, $verts = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 464|0;
 $$byval_copy5 = sp + 456|0;
 $0 = sp + 448|0;
 $1 = sp + 444|0;
 $2 = sp + 440|0;
 $3 = sp + 436|0;
 $4 = sp + 432|0;
 $verts = sp + 416|0;
 $generator = sp + 20|0;
 $5 = sp + 16|0;
 $6 = sp + 8|0;
 $7 = sp;
 $8 = sp + 400|0;
 $9 = HEAP32[628512>>2]|0;
 HEAP32[$verts>>2] = 0;
 $10 = (($verts) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = (($verts) + 8|0);
 HEAP32[$11>>2] = 0;
 $12 = (($verts) + 12|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 64|0);
 $14 = (($this) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$4>>2] = $15;
 $16 = HEAP32[560624>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  label = 9;
 } else {
  $18 = (($16) + 36|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($16) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($19|0)==($21|0);
  do {
   if ($22) {
    $23 = (($16) + 28|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (($16) + 32|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + ($26<<3)|0);
    $43 = $27;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy5,$16,$4);
    $28 = HEAP32[$$byval_copy5>>2]|0;
    $29 = ($28|0)==(-1);
    $30 = (($16) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    if ($29) {
     $32 = (($16) + 32|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + ($33<<3)|0);
     $43 = $34;
     break;
    } else {
     $35 = (($31) + ($28<<3)|0);
     $43 = $35;
     break;
    }
   }
  } while(0);
  $36 = HEAP32[560624>>2]|0;
  $37 = (($36) + 28|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($36) + 32|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + ($40<<3)|0);
  $42 = ($43|0)==($41|0);
  if ($42) {
   label = 9;
  } else {
   $44 = (($43) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    label = 9;
   } else {
    $temp$0$i$i = $45;
    label = 10;
   }
  }
 }
 if ((label|0) == 9) {
  $47 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  $48 = (invoke_ii(3215,($47|0))|0);
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if ($50) {
   label = 15;
  } else {
   $temp$0$i$i = $48;
   label = 10;
  }
 }
 L13: do {
  if ((label|0) == 10) {
   $51 = (($this) + 60|0);
   $52 = HEAP32[$51>>2]|0;
   HEAP32[$5>>2] = $52;
   $53 = (($this) + 52|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($this) + 32|0);
   $56 = Math_fround(HEAPF32[$55>>2]);
   HEAPF32[$6>>2] = $56;
   $57 = (($6) + 4|0);
   HEAPF32[$57>>2] = Math_fround(3.40282346638528859812E+38);
   $58 = (($this) + 49|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = ($59<<24>>24)!=(0);
   $61 = (($this) + 56|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = (($this) + 40|0);
   $64 = Math_fround(HEAPF32[$63>>2]);
   $65 = (($this) + 36|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($this) + 44|0);
   $68 = Math_fround(HEAPF32[$67>>2]);
   $69 = (~~(($68)));
   $70 = (($this) + 28|0);
   $71 = HEAP8[$70>>0]|0;
   $72 = ($71<<24>>24)!=(0);
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
   invoke_viiiiiiiifiiifiii(1,($generator|0),($13|0),($temp$0$i$i|0),($$byval_copy5|0),($54|0),($6|0),($60|0),($62|0),(+$64),($66|0),($69|0),($72|0),1.0,1,0,($verts|0));
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    label = 15;
   } else {
    __THREW__ = 0;
    (invoke_ii(3415,($generator|0))|0);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    do {
     if ($76) {
      label = 16;
     } else {
      $77 = (($generator) + 224|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ($78*6)|0;
      $80 = ($78*12)|0;
      $81 = (($80) + 15)|0;
      $82 = ($81>>>0)<(2000);
      $83 = ($78|0)!=(0);
      if ($82) {
       if ($83) {
        $84 = STACKTOP; STACKTOP = STACKTOP + ((((1*$81)|0)+15)&-16)|0;;
        $98 = 0;$allocPtr$0 = $84;
        label = 23;
       } else {
        $98 = 0;$allocPtr$0 = 0;
        label = 23;
       }
      } else {
       if ($83) {
        $89 = HEAP32[628512>>2]|0;
        HEAP32[$7>>2] = $89;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$7+0>>2]|0;
        $90 = (invoke_iiiiiii(102,($81|0),16,($$byval_copy5|0),0,(806416|0),293)|0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         $93 = ___cxa_find_matching_catch()|0;
         $94 = tempRet0;
         $148 = $2;$149 = $94;$150 = $93;
        } else {
         $98 = $90;$allocPtr$0 = $90;
         label = 23;
        }
       } else {
        $98 = 0;$allocPtr$0 = 0;
        label = 23;
       }
      }
      if ((label|0) == 23) {
       $102 = $allocPtr$0;
       $103 = (($102) + 15)|0;
       $104 = $103 & -16;
       $105 = $104;
       $106 = (($105) + ($79<<1)|0);
       $107 = (($generator) + 24|0);
       $108 = HEAP32[$107>>2]|0;
       $109 = ($108|0)>(-1);
       $110 = (($generator) + 12|0);
       if ($109) {
        $111 = HEAP32[$110>>2]|0;
        $112 = (($generator) + 16|0);
        $113 = HEAP32[$112>>2]|0;
        HEAP32[$0>>2] = $113;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2591,($111|0),($$byval_copy5|0));
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if (!($115)) {
         HEAP32[$110>>2] = 0;
         label = 26;
        }
       } else {
        label = 26;
       }
       if ((label|0) == 26) {
        $116 = $106;
        $117 = (($116) - ($104))|0;
        $118 = $117 >>> 1;
        $119 = (($generator) + 20|0);
        $120 = $118 | -2147483648;
        HEAP32[$107>>2] = $120;
        HEAP32[$110>>2] = $105;
        HEAP32[$119>>2] = 0;
        __THREW__ = 0;
        (invoke_ii(3416,($generator|0))|0);
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if (!($122)) {
         __THREW__ = 0;
         invoke_vii(3448,($8|0),($generator|0));
         $123 = __THREW__; __THREW__ = 0;
         $124 = $123&1;
         if (!($124)) {
          $125 = (($this) + 8|0);
          ;HEAP32[$125+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$125+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$125+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$125+12>>2]=HEAP32[$8+12>>2]|0;
          __THREW__ = 0;
          invoke_vii(3449,($generator|0),($this|0));
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if (!($127)) {
           $128 = ($98|0)==(0|0);
           if (!($128)) {
            $129 = HEAP32[628512>>2]|0;
            HEAP32[$1>>2] = $129;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
            invoke_vii(2591,($98|0),($$byval_copy5|0));
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             label = 16;
             break;
            }
           }
           __THREW__ = 0;
           invoke_vi(3727,($generator|0));
           $132 = __THREW__; __THREW__ = 0;
           $133 = $132&1;
           if ($133) {
            label = 15;
            break L13;
           }
           $134 = HEAP32[$12>>2]|0;
           $135 = ($134|0)>(-1);
           if (!($135)) {
            STACKTOP = sp;return;
           }
           $136 = HEAP32[$verts>>2]|0;
           $137 = HEAP32[$10>>2]|0;
           HEAP32[$0>>2] = $137;
           ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
           __Z19free_alloc_internalPv10MemLabelId($136,$$byval_copy5);
           HEAP32[$verts>>2] = 0;
           STACKTOP = sp;return;
          }
         }
        }
       }
       $95 = ___cxa_find_matching_catch()|0;
       $96 = tempRet0;
       $97 = ($98|0)==(0|0);
       if ($97) {
        $148 = $2;$149 = $96;$150 = $95;
       } else {
        $99 = HEAP32[628512>>2]|0;
        HEAP32[$2>>2] = $99;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
        invoke_vii(2591,($98|0),($$byval_copy5|0));
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         $146 = ___cxa_find_matching_catch(0|0)|0;
         $147 = tempRet0;
         ___clang_call_terminate($146);
         // unreachable;
        } else {
         $148 = $2;$149 = $96;$150 = $95;
        }
       }
      }
      $$0 = $150;$$01 = $149;
     }
    } while(0);
    if ((label|0) == 16) {
     $87 = ___cxa_find_matching_catch()|0;
     $88 = tempRet0;
     $$0 = $87;$$01 = $88;
    }
    __THREW__ = 0;
    invoke_vi(3727,($generator|0));
    $138 = __THREW__; __THREW__ = 0;
    $139 = $138&1;
    if ($139) {
     $146 = ___cxa_find_matching_catch(0|0)|0;
     $147 = tempRet0;
     ___clang_call_terminate($146);
     // unreachable;
    } else {
     $$1 = $$0;$$12 = $$01;
    }
   }
  }
 } while(0);
 if ((label|0) == 15) {
  $85 = ___cxa_find_matching_catch()|0;
  $86 = tempRet0;
  $$1 = $85;$$12 = $86;
 }
 $140 = HEAP32[$12>>2]|0;
 $141 = ($140|0)>(-1);
 if (!($141)) {
  ___resumeException($$1|0);
  // unreachable;
 }
 $142 = HEAP32[$verts>>2]|0;
 $143 = HEAP32[$10>>2]|0;
 HEAP32[$3>>2] = $143;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 invoke_vii(2591,($142|0),($$byval_copy5|0));
 $144 = __THREW__; __THREW__ = 0;
 $145 = $144&1;
 if ($145) {
  $146 = ___cxa_find_matching_catch(0|0)|0;
  $147 = tempRet0;
  ___clang_call_terminate($146);
  // unreachable;
 }
 HEAP32[$verts>>2] = 0;
 ___resumeException($$1|0);
 // unreachable;
}
function __ZN20TextRenderingPrivate17TextMeshGenerator17GetCursorPositionERK5RectTIfEi($agg$result,$this,$screenRect,$textPosition) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $screenRect = $screenRect|0;
 $textPosition = $textPosition|0;
 var $$$textPosition = 0, $$1 = 0, $$textPosition = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = ($textPosition|0)<(0);
 if ($1) {
  $$1 = 0;
 } else {
  $2 = (($this) + 68|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)<($textPosition|0);
  $$textPosition = $4 ? $3 : $textPosition;
  $5 = $$textPosition << 2;
  $6 = (($5) + 4)|0;
  $7 = ($6|0)>(65535);
  $$$textPosition = $7 ? 16382 : $$textPosition;
  $$1 = $$$textPosition;
 }
 $8 = (($this) + 76|0);
 $9 = HEAP32[$8>>2]|0;
 __ZN13TextRendering17TextMeshGenerator13GetTextOffsetERK5RectTIfE($0,$this,$screenRect);
 $10 = (($9) + ($$1<<3)|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround(HEAPF32[$0>>2]);
 $13 = Math_fround($11 + $12);
 $14 = ((($9) + ($$1<<3)|0) + 4|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($0) + 4|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = Math_fround($15 + $17);
 HEAPF32[$agg$result>>2] = $13;
 $19 = (($agg$result) + 4|0);
 HEAPF32[$19>>2] = $18;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate17TextMeshGenerator24GetCursorIndexAtPositionERK5RectTIfERK8Vector2f($this,$screenRect,$pos) {
 $this = $this|0;
 $screenRect = $screenRect|0;
 $pos = $pos|0;
 var $$$i = 0, $$0 = 0, $$0$i1 = Math_fround(0), $$0$i2 = Math_fround(0), $$1$i = 0, $$end$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0);
 var $58 = 0, $59 = Math_fround(0), $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = Math_fround(0), $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0);
 var $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $end$0$ph = 0, $floorf$i$i$i = Math_fround(0), $next$0$i = Math_fround(0), $pos$i$i$i$i$i = 0, $prev$0$i = Math_fround(0), $start$0$ph = 0, $start$0$ph5 = 0, $temp$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i$i = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + -1)|0;
 __ZN13TextRendering17TextMeshGenerator13GetTextOffsetERK5RectTIfE($1,$this,$screenRect);
 $5 = Math_fround(HEAPF32[$pos>>2]);
 $6 = Math_fround(HEAPF32[$1>>2]);
 $7 = Math_fround($5 - $6);
 $8 = (($pos) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($1) + 4|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($this) + 76|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 HEAP32[$0>>2] = $16;
 $17 = HEAP32[560624>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  label = 9;
 } else {
  $19 = (($17) + 36|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($17) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($20|0)==($22|0);
  do {
   if ($23) {
    $24 = (($17) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($17) + 32|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($25) + ($27<<3)|0);
    $44 = $28;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i$i,$17,$0);
    $29 = HEAP32[$pos$i$i$i$i$i>>2]|0;
    $30 = ($29|0)==(-1);
    $31 = (($17) + 28|0);
    $32 = HEAP32[$31>>2]|0;
    if ($30) {
     $33 = (($17) + 32|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($32) + ($34<<3)|0);
     $44 = $35;
     break;
    } else {
     $36 = (($32) + ($29<<3)|0);
     $44 = $36;
     break;
    }
   }
  } while(0);
  $37 = HEAP32[560624>>2]|0;
  $38 = (($37) + 28|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + 32|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + ($41<<3)|0);
  $43 = ($44|0)==($42|0);
  if ($43) {
   label = 9;
  } else {
   $45 = (($44) + 4|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    label = 9;
   } else {
    $temp$0$i$i = $46;
   }
  }
 }
 if ((label|0) == 9) {
  $48 = HEAP32[$15>>2]|0;
  $49 = (__Z31ReadObjectFromPersistentManageri($48)|0);
  $temp$0$i$i = $49;
 }
 $50 = (($this) + 52|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)==(0);
 if ($52) {
  label = 12;
 } else {
  $53 = (($temp$0$i$i) + 32|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)==(0);
  if ($55) {
   label = 12;
  } else {
   $58 = (($temp$0$i$i) + 28|0);
   $59 = Math_fround(HEAPF32[$58>>2]);
   $60 = (Math_fround(($51|0)));
   $61 = Math_fround($60 * $59);
   $62 = (Math_fround(($54|0)));
   $63 = Math_fround($61 / $62);
   $$0$i2 = $63;
  }
 }
 if ((label|0) == 12) {
  $56 = (($temp$0$i$i) + 28|0);
  $57 = Math_fround(HEAPF32[$56>>2]);
  $$0$i2 = $57;
 }
 $64 = (($this) + 28|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = ($65<<24>>24)==(0);
 if ($66) {
  $$0$i1 = $$0$i2;
 } else {
  $67 = Math_fround($$0$i2 + Math_fround(0.5));
  $floorf$i$i$i = (Math_fround(Math_floor((Math_fround($67)))));
  $$0$i1 = $floorf$i$i$i;
 }
 $68 = Math_fround($12 - $$0$i1);
 $end$0$ph = $4;$start$0$ph = 0;
 L23: while(1) {
  $start$0$ph5 = $start$0$ph;
  L25: while(1) {
   $69 = ($start$0$ph5|0)>($end$0$ph|0);
   $70 = (($start$0$ph5) + ($end$0$ph))|0;
   $71 = $70 >> 1;
   $72 = (($14) + ($71<<3)|0);
   $73 = ((($14) + ($71<<3)|0) + 4|0);
   $74 = ($71|0)==($4|0);
   $75 = (($71) + 1)|0;
   $76 = $74 ? $4 : $75;
   $77 = ((($14) + ($76<<3)|0) + 4|0);
   $78 = (($14) + ($76<<3)|0);
   $79 = ($71|0)==(0);
   $80 = (($71) + -1)|0;
   $$$i = $79 ? 0 : $80;
   $81 = ((($14) + ($$$i<<3)|0) + 4|0);
   $82 = (($14) + ($$$i<<3)|0);
   while(1) {
    if ($69) {
     break L23;
    }
    $83 = Math_fround(HEAPF32[$73>>2]);
    $84 = !($83 <= $68);
    if (!($84)) {
     $start$0$ph5 = $75;
     continue L25;
    }
    $85 = $83 > $12;
    if ($85) {
     $end$0$ph = $80;$start$0$ph = $start$0$ph5;
     continue L23;
    }
    $86 = Math_fround(HEAPF32[$72>>2]);
    $87 = Math_fround(HEAPF32[$77>>2]);
    $88 = $87 == $83;
    if ($88) {
     $89 = Math_fround(HEAPF32[$78>>2]);
     $next$0$i = $89;
    } else {
     $next$0$i = Math_fround(1.0E+4);
    }
    $90 = Math_fround($86 + $next$0$i);
    $91 = Math_fround($90 * Math_fround(0.5));
    $92 = $91 < $7;
    if ($92) {
     $start$0$ph5 = $75;
     continue L25;
    }
    $93 = Math_fround(HEAPF32[$81>>2]);
    $94 = $93 == $83;
    if ($94) {
     $95 = Math_fround(HEAPF32[$82>>2]);
     $prev$0$i = $95;
    } else {
     $prev$0$i = Math_fround(-1.0E+4);
    }
    $96 = Math_fround($86 + $prev$0$i);
    $97 = Math_fround($96 * Math_fround(0.5));
    $98 = $97 > $7;
    $$1$i = $98&1;
    if ((($$1$i|0) == 1)) {
     $end$0$ph = $80;$start$0$ph = $start$0$ph5;
     continue L23;
    } else if ((($$1$i|0) == 0)) {
     $$0 = $71;
     label = 29;
     break L23;
    }
   }
  }
 }
 if ((label|0) == 29) {
  STACKTOP = sp;return ($$0|0);
 }
 $99 = ($end$0$ph|0)<(0);
 $$end$0 = $99 ? 0 : $end$0$ph;
 $$0 = $$end$0;
 STACKTOP = sp;return ($$0|0);
}
function __ZN20TextRenderingPrivate17TextMeshGenerator14GarbageCollectEv() {
 var $$0$i = 0, $$01$i = 0, $$byval_copy6 = 0, $$idx = 0, $$in = 0, $$pre = 0, $$pre11 = 0, $$pre12 = 0, $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy6 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (__Z14GetTimeManagerv()|0);
 $3 = (($2) + 128|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[806264>>2]|0;
 $6 = HEAP32[806256>>2]|0;
 $7 = $5;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 2;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $$in = $10;$14 = $6;$73 = $5;
 while(1) {
  $12 = (($$in) + -1)|0;
  $13 = (($14) + ($12<<2)|0);
  $15 = HEAP32[$13>>2]|0;
  $16 = (($15) + 92|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($4) - ($17))|0;
  $19 = ($18|0)>(5);
  if ($19) {
   $21 = ($15|0)==(0|0);
   if ($21) {
    $58 = $14;$61 = $73;
   } else {
    $22 = HEAP32[$15>>2]|0;
    $23 = ($22|0)==(0|0);
    if (!($23)) {
     __THREW__ = 0;
     invoke_vi(3709,($22|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 9;
      break;
     }
    }
    $37 = (($15) + 88|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)>(-1);
    if ($39) {
     $40 = (($15) + 76|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($15) + 80|0);
     $43 = HEAP32[$42>>2]|0;
     HEAP32[$0>>2] = $43;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($41|0),($$byval_copy6|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 16;
      break;
     }
     HEAP32[$40>>2] = 0;
    }
    $46 = (($15) + 64|0);
    __THREW__ = 0;
    invoke_vi(3501,($46|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 23;
     break;
    }
    __ZdlPv($15);
    $$pre = HEAP32[806256>>2]|0;
    $$pre11 = HEAP32[806264>>2]|0;
    $58 = $$pre;$61 = $$pre11;
   }
   $$idx = $12 << 2;
   $56 = $$idx >> 2;
   $57 = (($58) + ($56<<2)|0);
   $$sum$i = (($56) + 1)|0;
   $59 = (($58) + ($$sum$i<<2)|0);
   $60 = $61;
   $62 = $59;
   $63 = (($60) - ($62))|0;
   $64 = $63 >> 2;
   _memmove(($57|0),($59|0),($63|0))|0;
   $$sum1$i = (($64) + ($56))|0;
   $65 = (($58) + ($$sum1$i<<2)|0);
   $66 = HEAP32[806264>>2]|0;
   $67 = ($66|0)==($65|0);
   if ($67) {
    $74 = $65;
   } else {
    $__new_last2$i$i$i = $65;
    $scevgep$i$i$i = (($66) + -4|0);
    $68 = (0 - ($__new_last2$i$i$i))|0;
    $uglygep$i$i$i = (($scevgep$i$i$i) + ($68)|0);
    $uglygep3$i$i$i = $uglygep$i$i$i;
    $69 = $uglygep3$i$i$i >>> 2;
    $70 = $69 ^ -1;
    $scevgep4$i$i$i = (($66) + ($70<<2)|0);
    HEAP32[806264>>2] = $scevgep4$i$i$i;
    $74 = $scevgep4$i$i$i;
   }
  } else {
   $74 = $73;
  }
  $20 = ($12|0)==(0);
  if ($20) {
   label = 25;
   break;
  }
  $$pre12 = HEAP32[806256>>2]|0;
  $$in = $12;$14 = $$pre12;$73 = $74;
 }
 do {
  if ((label|0) == 9) {
   $26 = ___cxa_find_matching_catch()|0;
   $27 = tempRet0;
   $28 = (($15) + 88|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>(-1);
   if ($30) {
    $31 = (($15) + 76|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($15) + 80|0);
    $34 = HEAP32[$33>>2]|0;
    HEAP32[$1>>2] = $34;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($32|0),($$byval_copy6|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     $54 = ___cxa_find_matching_catch(0|0)|0;
     $55 = tempRet0;
     ___clang_call_terminate($54);
     // unreachable;
    } else {
     HEAP32[$31>>2] = 0;
     $$0$i = $27;$$01$i = $26;
     break;
    }
   } else {
    $$0$i = $27;$$01$i = $26;
   }
  }
  else if ((label|0) == 16) {
   $49 = ___cxa_find_matching_catch()|0;
   $50 = tempRet0;
   $$0$i = $50;$$01$i = $49;
  }
  else if ((label|0) == 23) {
   $71 = ___cxa_find_matching_catch()|0;
   $72 = tempRet0;
   $eh$lpad$body$index2Z2D = $72;$eh$lpad$body$indexZ2D = $71;
   __ZdlPv($15);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
  else if ((label|0) == 25) {
   STACKTOP = sp;return;
  }
 } while(0);
 $51 = (($15) + 64|0);
 __THREW__ = 0;
 invoke_vi(3501,($51|0));
 $52 = __THREW__; __THREW__ = 0;
 $53 = $52&1;
 if ($53) {
  $54 = ___cxa_find_matching_catch(0|0)|0;
  $55 = tempRet0;
  ___clang_call_terminate($54);
  // unreachable;
 }
 $eh$lpad$body$index2Z2D = $$0$i;$eh$lpad$body$indexZ2D = $$01$i;
 __ZdlPv($15);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZN20TextRenderingPrivate17TextMeshGenerator5FlushEv() {
 var $$0$i = 0, $$01$i = 0, $$byval_copy6 = 0, $$in = 0, $$lcssa = 0, $$pre = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy6 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[806264>>2]|0;
 $3 = HEAP32[806256>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7|0)==(0);
 L1: do {
  if ($8) {
   $$lcssa = $3;$52 = $2;
  } else {
   $$in = $7;$11 = $3;
   while(1) {
    $9 = (($$in) + -1)|0;
    $10 = (($11) + ($9<<2)|0);
    $12 = HEAP32[$10>>2]|0;
    $13 = ($12|0)==(0|0);
    if ($13) {
     $56 = $11;
    } else {
     $14 = HEAP32[$12>>2]|0;
     $15 = ($14|0)==(0|0);
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3709,($14|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       label = 6;
       break;
      }
     }
     $29 = (($12) + 88|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)>(-1);
     if ($31) {
      $32 = (($12) + 76|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($12) + 80|0);
      $35 = HEAP32[$34>>2]|0;
      HEAP32[$0>>2] = $35;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($33|0),($$byval_copy6|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 13;
       break;
      }
      HEAP32[$32>>2] = 0;
     }
     $38 = (($12) + 64|0);
     __THREW__ = 0;
     invoke_vi(3501,($38|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 19;
      break;
     }
     __ZdlPv($12);
     $$pre12 = HEAP32[806256>>2]|0;
     $56 = $$pre12;
    }
    $48 = ($9|0)==(0);
    if ($48) {
     label = 21;
     break;
    } else {
     $$in = $9;$11 = $56;
    }
   }
   do {
    if ((label|0) == 6) {
     $18 = ___cxa_find_matching_catch()|0;
     $19 = tempRet0;
     $20 = (($12) + 88|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)>(-1);
     if ($22) {
      $23 = (($12) + 76|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($12) + 80|0);
      $26 = HEAP32[$25>>2]|0;
      HEAP32[$1>>2] = $26;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($24|0),($$byval_copy6|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       $46 = ___cxa_find_matching_catch(0|0)|0;
       $47 = tempRet0;
       ___clang_call_terminate($46);
       // unreachable;
      } else {
       HEAP32[$23>>2] = 0;
       $$0$i = $19;$$01$i = $18;
       break;
      }
     } else {
      $$0$i = $19;$$01$i = $18;
     }
    }
    else if ((label|0) == 13) {
     $41 = ___cxa_find_matching_catch()|0;
     $42 = tempRet0;
     $$0$i = $42;$$01$i = $41;
    }
    else if ((label|0) == 19) {
     $49 = ___cxa_find_matching_catch()|0;
     $50 = tempRet0;
     $eh$lpad$body$index2Z2D = $50;$eh$lpad$body$indexZ2D = $49;
     __ZdlPv($12);
     ___resumeException($eh$lpad$body$indexZ2D|0);
     // unreachable;
    }
    else if ((label|0) == 21) {
     $$pre = HEAP32[806264>>2]|0;
     $$lcssa = $56;$52 = $$pre;
     break L1;
    }
   } while(0);
   $43 = (($12) + 64|0);
   __THREW__ = 0;
   invoke_vi(3501,($43|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $46 = ___cxa_find_matching_catch(0|0)|0;
    $47 = tempRet0;
    ___clang_call_terminate($46);
    // unreachable;
   }
   $eh$lpad$body$index2Z2D = $$0$i;$eh$lpad$body$indexZ2D = $$01$i;
   __ZdlPv($12);
   ___resumeException($eh$lpad$body$indexZ2D|0);
   // unreachable;
  }
 } while(0);
 $51 = ($52|0)==($$lcssa|0);
 if ($51) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i = $$lcssa;
 $scevgep$i$i$i = (($52) + -4|0);
 $53 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($53)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $54 = $uglygep3$i$i$i >>> 2;
 $55 = $54 ^ -1;
 $scevgep4$i$i$i = (($52) + ($55<<2)|0);
 HEAP32[806264>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate17TextMeshGeneratorC2ERK11UTF16StringPNS_4FontE10TextAnchor13TextAlignmentfffbb11ColorRGBA32ii($this,$text,$font,$anchor,$alignment,$wordWrapWidth,$tabSize,$lineSpacing,$richText,$pixelCorrect,$color,$fontSize,$fontStyle) {
 $this = $this|0;
 $text = $text|0;
 $font = $font|0;
 $anchor = $anchor|0;
 $alignment = $alignment|0;
 $wordWrapWidth = Math_fround($wordWrapWidth);
 $tabSize = Math_fround($tabSize);
 $lineSpacing = Math_fround($lineSpacing);
 $richText = $richText|0;
 $pixelCorrect = $pixelCorrect|0;
 $color = $color|0;
 $fontSize = $fontSize|0;
 $fontStyle = $fontStyle|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (($this) + 4|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 $3 = (($this) + 60|0);
 $4 = (($this) + 64|0);
 __ZN11UTF16StringC2ERKS_($4,$text);
 $5 = (($this) + 76|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 84|0);
 HEAP32[$6>>2] = 0;
 $7 = (($this) + 88|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 80|0);
 HEAP32[$8>>2] = 61;
 $9 = ($font|0)==(0|0);
 L1: do {
  if ($9) {
   $12 = HEAP32[806280>>2]|0;
   $13 = ($12|0)==(0|0);
   do {
    if ($13) {
     HEAP8[$1>>0] = 18;
     $15 = (($1) + 1|0);
     dest=$15+0|0; src=806288+0|0; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $16 = (($1) + 10|0);
     HEAP8[$16>>0] = 0;
     __THREW__ = 0;
     $17 = (invoke_i(58)|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      $20 = (invoke_iiii(1532,($17|0),128,($1|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       HEAP32[806280>>2] = $20;
       $23 = HEAP8[$1>>0]|0;
       $24 = $23 & 1;
       $25 = ($24<<24>>24)==(0);
       if ($25) {
        $37 = $20;
       } else {
        $26 = (($1) + 8|0);
        $27 = HEAP32[$26>>2]|0;
        __ZdlPv($27);
        $$pre = HEAP32[806280>>2]|0;
        $37 = $$pre;
       }
       $35 = (($this) + 4|0);
       $36 = ($37|0)==(0|0);
       if (!($36)) {
        $39 = $37;$41 = $35;
        break;
       }
       HEAP32[$35>>2] = 0;
       break L1;
      }
     }
     $28 = ___cxa_find_matching_catch()|0;
     $29 = tempRet0;
     $30 = HEAP8[$1>>0]|0;
     $31 = $30 & 1;
     $32 = ($31<<24>>24)==(0);
     if (!($32)) {
      $33 = (($1) + 8|0);
      $34 = HEAP32[$33>>2]|0;
      __ZdlPv($34);
     }
     $55 = HEAP32[$7>>2]|0;
     $56 = ($55|0)>(-1);
     do {
      if ($56) {
       $57 = HEAP32[$5>>2]|0;
       $58 = HEAP32[$8>>2]|0;
       HEAP32[$0>>2] = $58;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($57|0),($$byval_copy|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        $63 = ___cxa_find_matching_catch(0|0)|0;
        $64 = tempRet0;
        ___clang_call_terminate($63);
        // unreachable;
       } else {
        HEAP32[$5>>2] = 0;
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3501,($4|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      $63 = ___cxa_find_matching_catch(0|0)|0;
      $64 = tempRet0;
      ___clang_call_terminate($63);
      // unreachable;
     } else {
      ___resumeException($28|0);
      // unreachable;
     }
    } else {
     $14 = (($this) + 4|0);
     $39 = $12;$41 = $14;
    }
   } while(0);
   $38 = (($39) + 4|0);
   $40 = HEAP32[$38>>2]|0;
   HEAP32[$41>>2] = $40;
  } else {
   $10 = (($font) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   HEAP32[$2>>2] = $11;
  }
 } while(0);
 $42 = (($this) + 52|0);
 HEAP32[$42>>2] = $fontSize;
 $43 = (($this) + 56|0);
 HEAP32[$43>>2] = $fontStyle;
 $44 = (($this) + 24|0);
 HEAP32[$44>>2] = $anchor;
 $45 = (($this) + 36|0);
 HEAP32[$45>>2] = $alignment;
 $46 = (($this) + 32|0);
 HEAPF32[$46>>2] = $wordWrapWidth;
 $47 = (($this) + 44|0);
 HEAPF32[$47>>2] = $tabSize;
 $48 = (($this) + 92|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 40|0);
 HEAPF32[$49>>2] = $lineSpacing;
 HEAP32[$this>>2] = 0;
 $50 = (($this) + 49|0);
 $51 = $richText&1;
 HEAP8[$50>>0] = $51;
 $52 = (($this) + 28|0);
 $53 = $pixelCorrect&1;
 HEAP8[$52>>0] = $53;
 $54 = HEAP32[$color>>2]|0;
 HEAP32[$3>>2] = $54;
 STACKTOP = sp;return;
}
function _FT_Bitmap_New($abitmap) {
 $abitmap = $abitmap|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$abitmap+0>>2]=0|0;HEAP32[$abitmap+4>>2]=0|0;HEAP32[$abitmap+8>>2]=0|0;HEAP32[$abitmap+12>>2]=0|0;HEAP32[$abitmap+16>>2]=0|0;HEAP32[$abitmap+20>>2]=0|0;
 STACKTOP = sp;return;
}
function _FT_Bitmap_Copy($library,$source,$target) {
 $library = $library|0;
 $source = $source|0;
 $target = $target|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 HEAP32[$error>>2] = 0;
 $1 = (($source) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($source|0)==($target|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($source) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  ;HEAP32[$target+0>>2]=HEAP32[$source+0>>2]|0;HEAP32[$target+4>>2]=HEAP32[$source+4>>2]|0;HEAP32[$target+8>>2]=HEAP32[$source+8>>2]|0;HEAP32[$target+12>>2]=HEAP32[$source+12>>2]|0;HEAP32[$target+16>>2]=HEAP32[$source+16>>2]|0;HEAP32[$target+20>>2]=HEAP32[$source+20>>2]|0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ($2|0)<(0);
 $8 = (0 - ($2))|0;
 $$ = $7 ? $8 : $2;
 $9 = HEAP32[$source>>2]|0;
 $10 = Math_imul($9, $$)|0;
 $11 = (($target) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $22 = (_ft_mem_qalloc($0,$10,$error)|0);
  HEAP32[$11>>2] = $22;
  $25 = $22;
 } else {
  $14 = (($target) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)<(0);
  $17 = (0 - ($15))|0;
  $$1 = $16 ? $17 : $15;
  $18 = HEAP32[$target>>2]|0;
  $19 = Math_imul($$1, $18)|0;
  $20 = ($19|0)==($10|0);
  if ($20) {
   $25 = $12;
  } else {
   $21 = (_ft_mem_qrealloc($0,1,$19,$10,$12,$error)|0);
   HEAP32[$11>>2] = $21;
   $25 = $21;
  }
 }
 $23 = HEAP32[$error>>2]|0;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$target+0>>2]=HEAP32[$source+0>>2]|0;HEAP32[$target+4>>2]=HEAP32[$source+4>>2]|0;HEAP32[$target+8>>2]=HEAP32[$source+8>>2]|0;HEAP32[$target+12>>2]=HEAP32[$source+12>>2]|0;HEAP32[$target+16>>2]=HEAP32[$source+16>>2]|0;HEAP32[$target+20>>2]=HEAP32[$source+20>>2]|0;
 HEAP32[$11>>2] = $25;
 $26 = HEAP32[$4>>2]|0;
 _memcpy(($25|0),($26|0),($10|0))|0;
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Bitmap_Convert($library,$source,$target,$alignment) {
 $library = $library|0;
 $source = $source|0;
 $target = $target|0;
 $alignment = $alignment|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$off = 0, $$pre = 0, $$pre65 = 0, $$pre66 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error = 0, $i$012 = 0, $i15$054 = 0, $i4$020 = 0, $i7$040 = 0, $j$04 = 0, $j$17 = 0, $j10$025 = 0, $j10$133 = 0, $j18$045 = 0;
 var $pad$0 = 0, $s$014 = 0, $s13$052 = 0, $s2$018 = 0, $s5$038 = 0, $scevgep = 0, $scevgep58 = 0, $scevgep60 = 0, $scevgep61 = 0, $scevgep63 = 0, $scevgep64 = 0, $ss$0$lcssa = 0, $ss$02 = 0, $ss16$0$lcssa = 0, $ss16$043 = 0, $ss8$0$lcssa = 0, $ss8$023 = 0, $switch = 0, $t$013 = 0, $t14$053 = 0;
 var $t3$019 = 0, $t6$039 = 0, $tt$0$lcssa = 0, $tt$03 = 0, $tt$16 = 0, $tt17$0$lcssa = 0, $tt17$044 = 0, $tt9$0$lcssa = 0, $tt9$024 = 0, $tt9$132 = 0, $val1$08 = 0, $val12$034 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = ($library|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$library>>2]|0;
 $2 = (($source) + 18|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 << 24 >> 24;
 $$off = (($4) + -1)|0;
 $switch = ($$off>>>0)<(6);
 if ($switch) {
  $5 = HEAP32[$target>>2]|0;
  $6 = (($target) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = Math_imul($7, $5)|0;
  $9 = ($8|0)<(0);
  $10 = (0 - ($8))|0;
  $$ = $9 ? $10 : $8;
  $11 = (($target) + 18|0);
  HEAP8[$11>>0] = 2;
  $12 = HEAP32[$source>>2]|0;
  HEAP32[$target>>2] = $12;
  $13 = (($source) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($target) + 4|0);
  HEAP32[$15>>2] = $14;
  $16 = ($alignment|0)>(0);
  $17 = HEAP32[$13>>2]|0;
  if ($16) {
   $18 = (($17|0) % ($alignment|0))&-1;
   $19 = ($18|0)==(0);
   $20 = (($alignment) - ($18))|0;
   $$1 = $19 ? 0 : $20;
   $pad$0 = $$1;
  } else {
   $pad$0 = 0;
  }
  $21 = (($17) + ($pad$0))|0;
  HEAP32[$6>>2] = $21;
  $22 = ($21|0)>(0);
  if ($22) {
   $23 = (4294967295 / ($21>>>0))&-1;
   $24 = ($12>>>0)>($23>>>0);
   if ($24) {
    $$0 = 6;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $25 = Math_imul($21, $12)|0;
  $26 = ($25|0)>($$|0);
  if ($26) {
   $27 = (($target) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (_ft_mem_qrealloc($1,1,$$,$25,$28,$error)|0);
   HEAP32[$27>>2] = $29;
   $30 = HEAP32[$error>>2]|0;
   $31 = ($30|0)==(0);
   if (!($31)) {
    $$0 = $30;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } else {
  HEAP32[$error>>2] = 6;
 }
 $32 = HEAP8[$2>>0]|0;
 $33 = $32 << 24 >> 24;
 L17: do {
  switch ($33|0) {
  case 6: case 5: case 2:  {
   $100 = (($source) + 4|0);
   $101 = HEAP32[$100>>2]|0;
   $102 = (($source) + 12|0);
   $103 = HEAP32[$102>>2]|0;
   $104 = (($target) + 12|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = (($source) + 8|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($target) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = (($target) + 16|0);
   HEAP16[$110>>1] = 256;
   $111 = HEAP32[$source>>2]|0;
   $112 = ($111|0)>(0);
   if ($112) {
    $i4$020 = $111;$s2$018 = $103;$t3$019 = $105;
    while(1) {
     _memcpy(($t3$019|0),($s2$018|0),($101|0))|0;
     $113 = (($s2$018) + ($107)|0);
     $114 = (($t3$019) + ($109)|0);
     $115 = (($i4$020) + -1)|0;
     $116 = ($115|0)>(0);
     if ($116) {
      $i4$020 = $115;$s2$018 = $113;$t3$019 = $114;
     } else {
      break;
     }
    }
   }
   break;
  }
  case 3:  {
   $117 = (($source) + 12|0);
   $118 = HEAP32[$117>>2]|0;
   $119 = (($target) + 12|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = (($target) + 16|0);
   HEAP16[$121>>1] = 4;
   $122 = HEAP32[$source>>2]|0;
   $123 = ($122|0)>(0);
   if ($123) {
    $124 = (($source) + 4|0);
    $125 = (($source) + 8|0);
    $126 = (($target) + 8|0);
    $i7$040 = $122;$s5$038 = $118;$t6$039 = $120;
    while(1) {
     $127 = HEAP32[$124>>2]|0;
     $128 = $127 >> 2;
     $129 = ($128|0)>(0);
     if ($129) {
      $130 = $128 << 2;
      $scevgep60 = (($t6$039) + ($130)|0);
      $j10$025 = $128;$ss8$023 = $s5$038;$tt9$024 = $t6$039;
      while(1) {
       $131 = HEAP8[$ss8$023>>0]|0;
       $132 = $131&255;
       $133 = ($131&255) >>> 6;
       HEAP8[$tt9$024>>0] = $133;
       $134 = $132 >>> 4;
       $135 = $134 & 3;
       $136 = $135&255;
       $137 = (($tt9$024) + 1|0);
       HEAP8[$137>>0] = $136;
       $138 = $132 >>> 2;
       $139 = $138 & 3;
       $140 = $139&255;
       $141 = (($tt9$024) + 2|0);
       HEAP8[$141>>0] = $140;
       $142 = $132 & 3;
       $143 = $142&255;
       $144 = (($tt9$024) + 3|0);
       HEAP8[$144>>0] = $143;
       $145 = (($ss8$023) + 1|0);
       $146 = (($tt9$024) + 4|0);
       $147 = (($j10$025) + -1)|0;
       $148 = ($147|0)>(0);
       if ($148) {
        $j10$025 = $147;$ss8$023 = $145;$tt9$024 = $146;
       } else {
        break;
       }
      }
      $scevgep61 = (($s5$038) + ($128)|0);
      $$pre65 = HEAP32[$124>>2]|0;
      $150 = $$pre65;$ss8$0$lcssa = $scevgep61;$tt9$0$lcssa = $scevgep60;
     } else {
      $150 = $127;$ss8$0$lcssa = $s5$038;$tt9$0$lcssa = $t6$039;
     }
     $149 = $150 & 3;
     $151 = ($149|0)==(0);
     if (!($151)) {
      $152 = HEAP8[$ss8$0$lcssa>>0]|0;
      $153 = $152&255;
      $j10$133 = $149;$tt9$132 = $tt9$0$lcssa;$val12$034 = $153;
      while(1) {
       $154 = $val12$034 >>> 6;
       $155 = $154 & 3;
       $156 = $155&255;
       HEAP8[$tt9$132>>0] = $156;
       $157 = $val12$034 << 2;
       $158 = (($tt9$132) + 1|0);
       $159 = (($j10$133) + -1)|0;
       $160 = ($159|0)>(0);
       if ($160) {
        $j10$133 = $159;$tt9$132 = $158;$val12$034 = $157;
       } else {
        break;
       }
      }
     }
     $161 = (($i7$040) + -1)|0;
     $162 = ($161|0)>(0);
     if (!($162)) {
      break L17;
     }
     $163 = HEAP32[$126>>2]|0;
     $164 = HEAP32[$125>>2]|0;
     $165 = (($t6$039) + ($163)|0);
     $166 = (($s5$038) + ($164)|0);
     $i7$040 = $161;$s5$038 = $166;$t6$039 = $165;
    }
   }
   break;
  }
  case 4:  {
   $167 = (($source) + 12|0);
   $168 = HEAP32[$167>>2]|0;
   $169 = (($target) + 12|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = (($target) + 16|0);
   HEAP16[$171>>1] = 16;
   $172 = HEAP32[$source>>2]|0;
   $173 = ($172|0)>(0);
   if ($173) {
    $174 = (($source) + 4|0);
    $175 = (($source) + 8|0);
    $176 = (($target) + 8|0);
    $i15$054 = $172;$s13$052 = $168;$t14$053 = $170;
    while(1) {
     $177 = HEAP32[$174>>2]|0;
     $178 = $177 >> 1;
     $179 = ($178|0)>(0);
     if ($179) {
      $180 = $178 << 1;
      $scevgep63 = (($t14$053) + ($180)|0);
      $j18$045 = $178;$ss16$043 = $s13$052;$tt17$044 = $t14$053;
      while(1) {
       $181 = HEAP8[$ss16$043>>0]|0;
       $182 = $181&255;
       $183 = ($181&255) >>> 4;
       HEAP8[$tt17$044>>0] = $183;
       $184 = $182 & 15;
       $185 = $184&255;
       $186 = (($tt17$044) + 1|0);
       HEAP8[$186>>0] = $185;
       $187 = (($ss16$043) + 1|0);
       $188 = (($tt17$044) + 2|0);
       $189 = (($j18$045) + -1)|0;
       $190 = ($189|0)>(0);
       if ($190) {
        $j18$045 = $189;$ss16$043 = $187;$tt17$044 = $188;
       } else {
        break;
       }
      }
      $scevgep64 = (($s13$052) + ($178)|0);
      $$pre66 = HEAP32[$174>>2]|0;
      $192 = $$pre66;$ss16$0$lcssa = $scevgep64;$tt17$0$lcssa = $scevgep63;
     } else {
      $192 = $177;$ss16$0$lcssa = $s13$052;$tt17$0$lcssa = $t14$053;
     }
     $191 = $192 & 1;
     $193 = ($191|0)==(0);
     if (!($193)) {
      $194 = HEAP8[$ss16$0$lcssa>>0]|0;
      $195 = ($194&255) >>> 4;
      HEAP8[$tt17$0$lcssa>>0] = $195;
     }
     $196 = (($i15$054) + -1)|0;
     $197 = ($196|0)>(0);
     if (!($197)) {
      break L17;
     }
     $198 = HEAP32[$176>>2]|0;
     $199 = HEAP32[$175>>2]|0;
     $200 = (($t14$053) + ($198)|0);
     $201 = (($s13$052) + ($199)|0);
     $i15$054 = $196;$s13$052 = $201;$t14$053 = $200;
    }
   }
   break;
  }
  case 1:  {
   $34 = (($source) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($target) + 12|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($target) + 16|0);
   HEAP16[$38>>1] = 2;
   $39 = HEAP32[$source>>2]|0;
   $40 = ($39|0)>(0);
   if ($40) {
    $41 = (($source) + 4|0);
    $42 = (($source) + 8|0);
    $43 = (($target) + 8|0);
    $i$012 = $39;$s$014 = $35;$t$013 = $37;
    while(1) {
     $44 = HEAP32[$41>>2]|0;
     $45 = $44 >> 3;
     $46 = ($45|0)>(0);
     if ($46) {
      $47 = $45 << 3;
      $j$04 = $45;$ss$02 = $s$014;$tt$03 = $t$013;
      while(1) {
       $48 = HEAP8[$ss$02>>0]|0;
       $49 = $48&255;
       $50 = ($48&255) >>> 7;
       HEAP8[$tt$03>>0] = $50;
       $51 = $49 >>> 6;
       $52 = $51 & 1;
       $53 = $52&255;
       $54 = (($tt$03) + 1|0);
       HEAP8[$54>>0] = $53;
       $55 = $49 >>> 5;
       $56 = $55 & 1;
       $57 = $56&255;
       $58 = (($tt$03) + 2|0);
       HEAP8[$58>>0] = $57;
       $59 = $49 >>> 4;
       $60 = $59 & 1;
       $61 = $60&255;
       $62 = (($tt$03) + 3|0);
       HEAP8[$62>>0] = $61;
       $63 = $49 >>> 3;
       $64 = $63 & 1;
       $65 = $64&255;
       $66 = (($tt$03) + 4|0);
       HEAP8[$66>>0] = $65;
       $67 = $49 >>> 2;
       $68 = $67 & 1;
       $69 = $68&255;
       $70 = (($tt$03) + 5|0);
       HEAP8[$70>>0] = $69;
       $71 = $49 >>> 1;
       $72 = $71 & 1;
       $73 = $72&255;
       $74 = (($tt$03) + 6|0);
       HEAP8[$74>>0] = $73;
       $75 = $49 & 1;
       $76 = $75&255;
       $77 = (($tt$03) + 7|0);
       HEAP8[$77>>0] = $76;
       $78 = (($tt$03) + 8|0);
       $79 = (($ss$02) + 1|0);
       $80 = (($j$04) + -1)|0;
       $81 = ($80|0)>(0);
       if ($81) {
        $j$04 = $80;$ss$02 = $79;$tt$03 = $78;
       } else {
        break;
       }
      }
      $scevgep = (($s$014) + ($45)|0);
      $scevgep58 = (($t$013) + ($47)|0);
      $$pre = HEAP32[$41>>2]|0;
      $83 = $$pre;$ss$0$lcssa = $scevgep;$tt$0$lcssa = $scevgep58;
     } else {
      $83 = $44;$ss$0$lcssa = $s$014;$tt$0$lcssa = $t$013;
     }
     $82 = $83 & 7;
     $84 = ($82|0)==(0);
     if (!($84)) {
      $85 = HEAP8[$ss$0$lcssa>>0]|0;
      $86 = $85&255;
      $j$17 = $82;$tt$16 = $tt$0$lcssa;$val1$08 = $86;
      while(1) {
       $87 = $val1$08 >>> 7;
       $88 = $87 & 1;
       $89 = $88&255;
       HEAP8[$tt$16>>0] = $89;
       $90 = $val1$08 << 1;
       $91 = (($tt$16) + 1|0);
       $92 = (($j$17) + -1)|0;
       $93 = ($92|0)>(0);
       if ($93) {
        $j$17 = $92;$tt$16 = $91;$val1$08 = $90;
       } else {
        break;
       }
      }
     }
     $94 = (($i$012) + -1)|0;
     $95 = ($94|0)>(0);
     if (!($95)) {
      break L17;
     }
     $96 = HEAP32[$43>>2]|0;
     $97 = HEAP32[$42>>2]|0;
     $98 = (($t$013) + ($96)|0);
     $99 = (($s$014) + ($97)|0);
     $i$012 = $94;$s$014 = $99;$t$013 = $98;
    }
   }
   break;
  }
  default: {
  }
  }
 } while(0);
 $202 = HEAP32[$error>>2]|0;
 $$0 = $202;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Bitmap_Done($library,$bitmap) {
 $library = $library|0;
 $bitmap = $bitmap|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($library|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($bitmap|0)==(0|0);
 if ($1) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP32[$library>>2]|0;
 $3 = (($bitmap) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 _ft_mem_free($2,$4);
 ;HEAP32[$bitmap+0>>2]=0|0;HEAP32[$bitmap+4>>2]=0|0;HEAP32[$bitmap+8>>2]=0|0;HEAP32[$bitmap+12>>2]=0|0;HEAP32[$bitmap+16>>2]=0|0;HEAP32[$bitmap+20>>2]=0|0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_RoundFix($a) {
 $a = $a|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($a|0)>(-1);
 if ($0) {
  $1 = (($a) + 32768)|0;
  $2 = $1 & -65536;
  $6 = $2;
  STACKTOP = sp;return ($6|0);
 } else {
  $3 = (32768 - ($a))|0;
  $4 = $3 & -65536;
  $5 = (0 - ($4))|0;
  $6 = $5;
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function _FT_MulDiv($a,$b,$c) {
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 var $$0 = 0, $$01$i = 0, $$02 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$i = 0, $or$cond = 0, $or$cond3 = 0, $q$0$i = 0, $q$1$i = 0, $r$0$i = 0, $r$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($a|0)==(0);
 $1 = ($b|0)==($c|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$02 = $a;
  STACKTOP = sp;return ($$02|0);
 }
 $2 = ($a|0)<(0);
 $3 = (0 - ($a))|0;
 $4 = $2 ? $3 : $a;
 $5 = $b ^ $a;
 $6 = ($b|0)<(0);
 $7 = (0 - ($b))|0;
 $8 = $6 ? $7 : $b;
 $9 = $5 ^ $c;
 $10 = ($c|0)<(0);
 $11 = (0 - ($c))|0;
 $12 = $10 ? $11 : $c;
 $13 = ($4|0)<(46341);
 $14 = ($8|0)<(46341);
 $or$cond3 = $13 & $14;
 if ($or$cond3) {
  $$off = (($12) + -1)|0;
  $15 = ($$off>>>0)<(176095);
  if ($15) {
   $16 = Math_imul($8, $4)|0;
   $17 = $12 >> 1;
   $18 = (($17) + ($16))|0;
   $19 = (($18|0) / ($12|0))&-1;
   $$0 = $19;
  } else {
   label = 5;
  }
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $20 = ($12|0)>(0);
  if ($20) {
   $21 = $4 & 65535;
   $22 = $4 >>> 16;
   $23 = $8 & 65535;
   $24 = $8 >>> 16;
   $25 = Math_imul($23, $21)|0;
   $26 = Math_imul($24, $21)|0;
   $27 = Math_imul($23, $22)|0;
   $28 = Math_imul($24, $22)|0;
   $29 = (($26) + ($27))|0;
   $30 = ($29>>>0)<($27>>>0);
   $31 = $30&1;
   $32 = $31 << 16;
   $33 = $29 >>> 16;
   $34 = $29 << 16;
   $35 = (($34) + ($25))|0;
   $36 = ($35>>>0)<($34>>>0);
   $37 = $36&1;
   $38 = (($33) + ($28))|0;
   $39 = (($38) + ($32))|0;
   $40 = (($39) + ($37))|0;
   $41 = $12 >> 1;
   $42 = (($35) + ($41))|0;
   $43 = ($42>>>0)<($35>>>0);
   $44 = $43&1;
   $45 = (($40) + ($44))|0;
   $46 = ($45>>>0)<($12>>>0);
   if ($46) {
    $$01$i = $42;$i$0$i = 32;$q$0$i = 0;$r$0$i = $45;
    while(1) {
     $47 = $r$0$i << 1;
     $48 = $q$0$i << 1;
     $49 = $$01$i >>> 31;
     $50 = $47 | $49;
     $51 = ($50>>>0)<($12>>>0);
     if ($51) {
      $q$1$i = $48;$r$1$i = $50;
     } else {
      $52 = (($50) - ($12))|0;
      $53 = $48 | 1;
      $q$1$i = $53;$r$1$i = $52;
     }
     $54 = $$01$i << 1;
     $55 = (($i$0$i) + -1)|0;
     $56 = ($55|0)==(0);
     if ($56) {
      $$0 = $q$1$i;
      break;
     } else {
      $$01$i = $54;$i$0$i = $55;$q$0$i = $q$1$i;$r$0$i = $r$1$i;
     }
    }
   } else {
    $$0 = 2147483647;
   }
  } else {
   $$0 = 2147483647;
  }
 }
 $57 = ($9|0)<(0);
 $58 = (0 - ($$0))|0;
 $59 = $57 ? $58 : $$0;
 $$02 = $59;
 STACKTOP = sp;return ($$02|0);
}
function _FT_MulDiv_No_Round($a,$b,$c) {
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 var $$0 = 0, $$01 = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$i = 0, $or$cond = 0, $or$cond2 = 0, $or$cond3 = 0, $q$0$i = 0;
 var $q$1$i = 0, $r$0$i = 0, $r$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($a|0)==(0);
 $1 = ($b|0)==($c|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$01 = $a;
  STACKTOP = sp;return ($$01|0);
 }
 $2 = ($a|0)<(0);
 $3 = (0 - ($a))|0;
 $4 = $2 ? $3 : $a;
 $5 = $b ^ $a;
 $6 = ($b|0)<(0);
 $7 = (0 - ($b))|0;
 $8 = $6 ? $7 : $b;
 $9 = $5 ^ $c;
 $10 = ($c|0)<(0);
 $11 = (0 - ($c))|0;
 $12 = $10 ? $11 : $c;
 $13 = ($4|0)<(46341);
 $14 = ($8|0)<(46341);
 $or$cond2 = $13 & $14;
 $15 = ($12|0)>(0);
 $or$cond3 = $or$cond2 & $15;
 if ($or$cond3) {
  $16 = Math_imul($8, $4)|0;
  $17 = (($16|0) / ($12|0))&-1;
  $$0 = $17;
 } else {
  if ($15) {
   $18 = $4 & 65535;
   $19 = $4 >>> 16;
   $20 = $8 & 65535;
   $21 = $8 >>> 16;
   $22 = Math_imul($20, $18)|0;
   $23 = Math_imul($21, $18)|0;
   $24 = Math_imul($20, $19)|0;
   $25 = Math_imul($21, $19)|0;
   $26 = (($23) + ($24))|0;
   $27 = ($26>>>0)<($24>>>0);
   $28 = $27&1;
   $29 = $28 << 16;
   $30 = $26 >>> 16;
   $31 = $26 << 16;
   $32 = (($31) + ($22))|0;
   $33 = ($32>>>0)<($31>>>0);
   $34 = $33&1;
   $35 = (($30) + ($25))|0;
   $36 = (($35) + ($29))|0;
   $37 = (($36) + ($34))|0;
   $38 = ($37>>>0)<($12>>>0);
   if ($38) {
    $$01$i = $32;$i$0$i = 32;$q$0$i = 0;$r$0$i = $37;
    while(1) {
     $39 = $r$0$i << 1;
     $40 = $q$0$i << 1;
     $41 = $$01$i >>> 31;
     $42 = $39 | $41;
     $43 = ($42>>>0)<($12>>>0);
     if ($43) {
      $q$1$i = $40;$r$1$i = $42;
     } else {
      $44 = (($42) - ($12))|0;
      $45 = $40 | 1;
      $q$1$i = $45;$r$1$i = $44;
     }
     $46 = $$01$i << 1;
     $47 = (($i$0$i) + -1)|0;
     $48 = ($47|0)==(0);
     if ($48) {
      $$0 = $q$1$i;
      break;
     } else {
      $$01$i = $46;$i$0$i = $47;$q$0$i = $q$1$i;$r$0$i = $r$1$i;
     }
    }
   } else {
    $$0 = 2147483647;
   }
  } else {
   $$0 = 2147483647;
  }
 }
 $49 = ($9|0)<(0);
 $50 = (0 - ($$0))|0;
 $51 = $49 ? $50 : $$0;
 $$01 = $51;
 STACKTOP = sp;return ($$01|0);
}
function _FT_MulFix($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, $ua$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($a|0)==(0);
 $1 = ($b|0)==(65536);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$0 = $a;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($a|0)<(0);
 $3 = (0 - ($a))|0;
 $4 = $2 ? $3 : $a;
 $5 = $b ^ $a;
 $6 = ($b|0)<(0);
 $7 = (0 - ($b))|0;
 $8 = $6 ? $7 : $b;
 $9 = ($4>>>0)<(2049);
 $10 = ($8>>>0)<(1048577);
 $or$cond1 = $9 & $10;
 if ($or$cond1) {
  $11 = Math_imul($8, $4)|0;
  $12 = (($11) + 32768)|0;
  $13 = $12 >>> 16;
  $ua$0 = $13;
 } else {
  $14 = $4 & 65535;
  $15 = $4 >>> 16;
  $16 = Math_imul($15, $8)|0;
  $17 = $8 >>> 16;
  $18 = Math_imul($17, $14)|0;
  $19 = (($18) + ($16))|0;
  $20 = $8 & 65535;
  $21 = Math_imul($20, $14)|0;
  $22 = (($21) + 32768)|0;
  $23 = $22 >>> 16;
  $24 = (($19) + ($23))|0;
  $ua$0 = $24;
 }
 $25 = ($5|0)<(0);
 $26 = (0 - ($ua$0))|0;
 $27 = $25 ? $26 : $ua$0;
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function _FT_DivFix($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$i = 0, $q$0 = 0, $q$0$i = 0, $q$1$i = 0, $r$0$i = 0, $r$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($a|0)<(0);
 $1 = (0 - ($a))|0;
 $2 = $0 ? $1 : $a;
 $3 = $b ^ $a;
 $4 = ($b|0)<(0);
 $5 = (0 - ($b))|0;
 $6 = $4 ? $5 : $b;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   $q$0 = 2147483647;
  } else {
   $8 = $2 >> 16;
   $9 = ($8|0)==(0);
   $10 = $2 << 16;
   $11 = $6 >> 1;
   $12 = (($11) + ($10))|0;
   if ($9) {
    $13 = (($12>>>0) / ($6>>>0))&-1;
    $q$0 = $13;
    break;
   }
   $14 = ($12>>>0)<($10>>>0);
   $15 = $14&1;
   $16 = (($15) + ($8))|0;
   $17 = ($16>>>0)<($6>>>0);
   if ($17) {
    $$01$i = $12;$i$0$i = 32;$q$0$i = 0;$r$0$i = $16;
    while(1) {
     $18 = $r$0$i << 1;
     $19 = $q$0$i << 1;
     $20 = $$01$i >>> 31;
     $21 = $18 | $20;
     $22 = ($21>>>0)<($6>>>0);
     if ($22) {
      $q$1$i = $19;$r$1$i = $21;
     } else {
      $23 = (($21) - ($6))|0;
      $24 = $19 | 1;
      $q$1$i = $24;$r$1$i = $23;
     }
     $25 = $$01$i << 1;
     $26 = (($i$0$i) + -1)|0;
     $27 = ($26|0)==(0);
     if ($27) {
      $q$0 = $q$1$i;
      break;
     } else {
      $$01$i = $25;$i$0$i = $26;$q$0$i = $q$1$i;$r$0$i = $r$1$i;
     }
    }
   } else {
    $q$0 = 2147483647;
   }
  }
 } while(0);
 $28 = ($3|0)<(0);
 $29 = (0 - ($q$0))|0;
 $30 = $28 ? $29 : $q$0;
 STACKTOP = sp;return ($30|0);
}
function _FT_Matrix_Multiply_Scaled($a,$b,$scaling) {
 $a = $a|0;
 $b = $b|0;
 $scaling = $scaling|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $scaling << 16;
 $1 = ($a|0)==(0|0);
 $2 = ($b|0)==(0|0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$a>>2]|0;
 $4 = HEAP32[$b>>2]|0;
 $5 = (_FT_MulDiv($3,$4,$0)|0);
 $6 = (($a) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($b) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (_FT_MulDiv($7,$9,$0)|0);
 $11 = (($10) + ($5))|0;
 $12 = (($b) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_FT_MulDiv($3,$13,$0)|0);
 $15 = (($b) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (_FT_MulDiv($7,$16,$0)|0);
 $18 = (($17) + ($14))|0;
 $19 = (($a) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (_FT_MulDiv($20,$4,$0)|0);
 $22 = (($a) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (_FT_MulDiv($23,$9,$0)|0);
 $25 = (($24) + ($21))|0;
 $26 = (_FT_MulDiv($20,$13,$0)|0);
 $27 = (_FT_MulDiv($23,$16,$0)|0);
 $28 = (($27) + ($26))|0;
 HEAP32[$b>>2] = $11;
 HEAP32[$12>>2] = $18;
 HEAP32[$8>>2] = $25;
 HEAP32[$15>>2] = $28;
 STACKTOP = sp;return;
}
function _FT_Vector_Transform_Scaled($vector,$matrix,$scaling) {
 $vector = $vector|0;
 $matrix = $matrix|0;
 $scaling = $scaling|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $scaling << 16;
 $1 = ($vector|0)==(0|0);
 $2 = ($matrix|0)==(0|0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$vector>>2]|0;
 $4 = HEAP32[$matrix>>2]|0;
 $5 = (_FT_MulDiv($3,$4,$0)|0);
 $6 = (($vector) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($matrix) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (_FT_MulDiv($7,$9,$0)|0);
 $11 = (($10) + ($5))|0;
 $12 = (($matrix) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_FT_MulDiv($3,$13,$0)|0);
 $15 = (($matrix) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (_FT_MulDiv($7,$16,$0)|0);
 $18 = (($17) + ($14))|0;
 HEAP32[$vector>>2] = $11;
 HEAP32[$6>>2] = $18;
 STACKTOP = sp;return;
}
function _FT_SqrtFixed($x) {
 $x = $x|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0 = 0, $rem_hi$0 = 0, $rem_hi$1 = 0, $rem_lo$0 = 0, $root$0 = 0, $root$1 = 0, $root$2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($x|0)>(0);
 if ($0) {
  $count$0 = 24;$rem_hi$0 = 0;$rem_lo$0 = $x;$root$0 = 0;
 } else {
  $root$2 = 0;
  STACKTOP = sp;return ($root$2|0);
 }
 while(1) {
  $1 = $rem_hi$0 << 2;
  $2 = $rem_lo$0 >>> 30;
  $3 = $2 | $1;
  $4 = $rem_lo$0 << 2;
  $5 = $root$0 << 1;
  $6 = $root$0 << 2;
  $7 = $6 | 1;
  $8 = ($3>>>0)<($7>>>0);
  if ($8) {
   $rem_hi$1 = $3;$root$1 = $5;
  } else {
   $9 = (($3) - ($7))|0;
   $10 = $5 | 1;
   $rem_hi$1 = $9;$root$1 = $10;
  }
  $11 = (($count$0) + -1)|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $root$2 = $root$1;
   break;
  } else {
   $count$0 = $11;$rem_hi$0 = $rem_hi$1;$rem_lo$0 = $4;$root$0 = $root$1;
  }
 }
 STACKTOP = sp;return ($root$2|0);
}
function _ft_corner_orientation($in_x,$in_y,$out_x,$out_y) {
 $in_x = $in_x|0;
 $in_y = $in_y|0;
 $out_x = $out_x|0;
 $out_y = $out_y|0;
 var $$ = 0, $$in_x = 0, $$out_x = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $in_y$ = 0;
 var $out_y$ = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($in_y|0)==(0);
 if ($0) {
  $1 = ($in_x|0)>(-1);
  $2 = (0 - ($out_y))|0;
  $out_y$ = $1 ? $out_y : $2;
  STACKTOP = sp;return ($out_y$|0);
 }
 $3 = ($in_x|0)==(0);
 if ($3) {
  $4 = ($in_y|0)>(-1);
  $5 = (0 - ($out_x))|0;
  $$out_x = $4 ? $5 : $out_x;
  $result$0 = $$out_x;
  STACKTOP = sp;return ($result$0|0);
 }
 $6 = ($out_y|0)==(0);
 if ($6) {
  $7 = ($out_x|0)>(-1);
  $8 = (0 - ($in_y))|0;
  $in_y$ = $7 ? $in_y : $8;
  $result$0 = $in_y$;
  STACKTOP = sp;return ($result$0|0);
 }
 $9 = ($out_x|0)==(0);
 if ($9) {
  $10 = ($out_y|0)>(-1);
  $11 = (0 - ($in_x))|0;
  $$in_x = $10 ? $11 : $in_x;
  $result$0 = $$in_x;
  STACKTOP = sp;return ($result$0|0);
 }
 $12 = $in_x & 65535;
 $13 = $in_x >>> 16;
 $14 = $out_y & 65535;
 $15 = $out_y >>> 16;
 $16 = Math_imul($14, $12)|0;
 $17 = Math_imul($15, $12)|0;
 $18 = Math_imul($14, $13)|0;
 $19 = Math_imul($15, $13)|0;
 $20 = (($17) + ($18))|0;
 $21 = ($20>>>0)<($18>>>0);
 $22 = $21&1;
 $23 = $22 << 16;
 $24 = $20 >>> 16;
 $25 = $20 << 16;
 $26 = (($25) + ($16))|0;
 $27 = ($26>>>0)<($25>>>0);
 $28 = $27&1;
 $29 = (($24) + ($19))|0;
 $30 = (($29) + ($23))|0;
 $31 = (($30) + ($28))|0;
 $32 = $in_y & 65535;
 $33 = $in_y >>> 16;
 $34 = $out_x & 65535;
 $35 = $out_x >>> 16;
 $36 = Math_imul($34, $32)|0;
 $37 = Math_imul($35, $32)|0;
 $38 = Math_imul($34, $33)|0;
 $39 = Math_imul($35, $33)|0;
 $40 = (($37) + ($38))|0;
 $41 = ($40>>>0)<($38>>>0);
 $42 = $41&1;
 $43 = $42 << 16;
 $44 = $40 >>> 16;
 $45 = $40 << 16;
 $46 = (($45) + ($36))|0;
 $47 = ($46>>>0)<($45>>>0);
 $48 = $47&1;
 $49 = (($44) + ($39))|0;
 $50 = (($49) + ($43))|0;
 $51 = (($50) + ($48))|0;
 $52 = ($31>>>0)>($51>>>0);
 if ($52) {
  $result$0 = 1;
  STACKTOP = sp;return ($result$0|0);
 }
 $53 = ($31>>>0)<($51>>>0);
 if ($53) {
  $result$0 = -1;
  STACKTOP = sp;return ($result$0|0);
 }
 $54 = ($26>>>0)>($46>>>0);
 if ($54) {
  $result$0 = 1;
  STACKTOP = sp;return ($result$0|0);
 }
 $55 = ($26>>>0)<($46>>>0);
 $$ = $55 << 31 >> 31;
 $result$0 = $$;
 STACKTOP = sp;return ($result$0|0);
}
function _ft_corner_is_flat($in_x,$in_y,$out_x,$out_y) {
 $in_x = $in_x|0;
 $in_y = $in_y|0;
 $out_x = $out_x|0;
 $out_y = $out_y|0;
 var $$ = 0, $$in_x = 0, $$out_x = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ay$0 = 0, $ay$1 = 0, $ay$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($in_x|0)<(0);
 $1 = (0 - ($in_x))|0;
 $$in_x = $0 ? $1 : $in_x;
 $2 = ($in_y|0)<(0);
 $3 = (0 - ($in_y))|0;
 $ay$0 = $2 ? $3 : $in_y;
 $4 = ($out_x|0)<(0);
 $5 = (0 - ($out_x))|0;
 $$out_x = $4 ? $5 : $out_x;
 $6 = ($out_y|0)<(0);
 $7 = (0 - ($out_y))|0;
 $ay$1 = $6 ? $7 : $out_y;
 $8 = (($out_x) + ($in_x))|0;
 $9 = ($8|0)<(0);
 $10 = (0 - ($8))|0;
 $$ = $9 ? $10 : $8;
 $11 = (($out_y) + ($in_y))|0;
 $12 = ($11|0)<(0);
 $13 = (0 - ($11))|0;
 $ay$2 = $12 ? $13 : $11;
 $14 = (($ay$2) + ($$))|0;
 $15 = (($ay$0) + ($$in_x))|0;
 $16 = (($15) + ($$out_x))|0;
 $17 = (($16) + ($ay$1))|0;
 $18 = (($17) - ($14))|0;
 $19 = $14 >> 4;
 $20 = ($18|0)<($19|0);
 $21 = $20&1;
 STACKTOP = sp;return ($21|0);
}
function _FT_GlyphLoader_New($memory,$aloader) {
 $memory = $memory|0;
 $aloader = $aloader|0;
 var $0 = 0, $1 = 0, $2 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (_ft_mem_alloc($memory,96,$error)|0);
 $1 = HEAP32[$error>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return ($1|0);
 }
 HEAP32[$0>>2] = $memory;
 HEAP32[$aloader>>2] = $0;
 STACKTOP = sp;return ($1|0);
}
function _FT_GlyphLoader_Rewind($loader) {
 $loader = $loader|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($loader) + 20|0);
 $1 = (($loader) + 56|0);
 $2 = (($loader) + 22|0);
 HEAP16[$2>>1] = 0;
 HEAP16[$0>>1] = 0;
 $3 = (($loader) + 48|0);
 HEAP32[$3>>2] = 0;
 dest=$1+0|0; src=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function _FT_GlyphLoader_Done($loader) {
 $loader = $loader|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($loader|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$loader>>2]|0;
 $2 = (($loader) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 _ft_mem_free($1,$3);
 HEAP32[$2>>2] = 0;
 $4 = (($loader) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 _ft_mem_free($1,$5);
 HEAP32[$4>>2] = 0;
 $6 = (($loader) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 _ft_mem_free($1,$7);
 HEAP32[$6>>2] = 0;
 $8 = (($loader) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 _ft_mem_free($1,$9);
 HEAP32[$8>>2] = 0;
 $10 = (($loader) + 52|0);
 $11 = HEAP32[$10>>2]|0;
 _ft_mem_free($1,$11);
 HEAP32[$10>>2] = 0;
 $12 = (($loader) + 44|0);
 HEAP32[$12>>2] = 0;
 $13 = (($loader) + 4|0);
 HEAP32[$13>>2] = 0;
 $14 = (($loader) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($loader) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($loader) + 20|0);
 $17 = (($loader) + 56|0);
 $18 = (($loader) + 22|0);
 HEAP16[$18>>1] = 0;
 HEAP16[$16>>1] = 0;
 $19 = (($loader) + 48|0);
 HEAP32[$19>>2] = 0;
 dest=$17+0|0; src=$16+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 _ft_mem_free($1,$loader);
 STACKTOP = sp;return;
}
function _FT_GlyphLoader_CreateExtra($loader) {
 $loader = $loader|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$loader>>2]|0;
 $1 = (($loader) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 << 1;
 $4 = (_ft_mem_realloc($0,8,0,$3,0,$error)|0);
 $5 = (($loader) + 40|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$error>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($loader) + 16|0);
 HEAP8[$8>>0] = 1;
 $9 = HEAP32[$1>>2]|0;
 $10 = (($4) + ($9<<3)|0);
 $11 = (($loader) + 44|0);
 HEAP32[$11>>2] = $10;
 $12 = (($loader) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($loader) + 22|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = $15 << 16 >> 16;
 $17 = (($13) + ($16<<3)|0);
 $18 = (($loader) + 60|0);
 HEAP32[$18>>2] = $17;
 $19 = (($loader) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($16)|0);
 $22 = (($loader) + 64|0);
 HEAP32[$22>>2] = $21;
 $23 = (($loader) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($loader) + 20|0);
 $26 = HEAP16[$25>>1]|0;
 $27 = $26 << 16 >> 16;
 $28 = (($24) + ($27<<1)|0);
 $29 = (($loader) + 68|0);
 HEAP32[$29>>2] = $28;
 $30 = (($4) + ($16<<3)|0);
 $31 = (($loader) + 76|0);
 HEAP32[$31>>2] = $30;
 $$sum = (($9) + ($16))|0;
 $32 = (($4) + ($$sum<<3)|0);
 $33 = (($loader) + 80|0);
 HEAP32[$33>>2] = $32;
 STACKTOP = sp;return ($6|0);
}
function _FT_GlyphLoader_CheckPoints($loader,$n_points,$n_contours) {
 $loader = $loader|0;
 $n_points = $n_points|0;
 $n_contours = $n_contours|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $adjust$0 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$loader>>2]|0;
 HEAP32[$error>>2] = 0;
 $1 = (($loader) + 22|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 << 16 >> 16;
 $4 = (($loader) + 58|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 << 16 >> 16;
 $7 = (($3) + ($n_points))|0;
 $8 = (($7) + ($6))|0;
 $9 = (($loader) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 do {
  if ($11) {
   $12 = (($8) + 7)|0;
   $13 = $12 & -8;
   $14 = ($13>>>0)>(32767);
   if ($14) {
    $$0 = 10;
    STACKTOP = sp;return ($$0|0);
   }
   $15 = (($loader) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (_ft_mem_realloc($0,8,$10,$13,$16,$error)|0);
   HEAP32[$15>>2] = $17;
   $18 = HEAP32[$error>>2]|0;
   $19 = ($18|0)==(0);
   if ($19) {
    $20 = (($loader) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (_ft_mem_realloc($0,1,$10,$13,$21,$error)|0);
    HEAP32[$20>>2] = $22;
    $23 = HEAP32[$error>>2]|0;
    $24 = ($23|0)==(0);
    if ($24) {
     $25 = (($loader) + 16|0);
     $26 = HEAP8[$25>>0]|0;
     $27 = ($26<<24>>24)==(0);
     if (!($27)) {
      $28 = $10 << 1;
      $29 = $13 << 1;
      $30 = (($loader) + 40|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (_ft_mem_realloc($0,8,$28,$29,$31,$error)|0);
      HEAP32[$30>>2] = $32;
      $33 = HEAP32[$error>>2]|0;
      $34 = ($33|0)==(0);
      if (!($34)) {
       break;
      }
      $35 = (($32) + ($13<<3)|0);
      $36 = (($32) + ($10<<3)|0);
      $37 = $10 << 3;
      _memmove(($35|0),($36|0),($37|0))|0;
      $38 = HEAP32[$30>>2]|0;
      $39 = (($38) + ($13<<3)|0);
      $40 = (($loader) + 44|0);
      HEAP32[$40>>2] = $39;
     }
     HEAP32[$9>>2] = $13;
     $adjust$0 = 1;
     label = 9;
    }
   }
  } else {
   $adjust$0 = 0;
   label = 9;
  }
 } while(0);
 do {
  if ((label|0) == 9) {
   $41 = (($loader) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($loader) + 20|0);
   $44 = HEAP16[$43>>1]|0;
   $45 = $44 << 16 >> 16;
   $46 = (($loader) + 56|0);
   $47 = HEAP16[$46>>1]|0;
   $48 = $47 << 16 >> 16;
   $49 = (($45) + ($n_contours))|0;
   $50 = (($49) + ($48))|0;
   $51 = ($50>>>0)>($42>>>0);
   if ($51) {
    $52 = (($50) + 3)|0;
    $53 = $52 & -4;
    $54 = ($53>>>0)>(32767);
    if ($54) {
     $$0 = 10;
     STACKTOP = sp;return ($$0|0);
    }
    $55 = (($loader) + 32|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = (_ft_mem_realloc($0,2,$42,$53,$56,$error)|0);
    HEAP32[$55>>2] = $57;
    $58 = HEAP32[$error>>2]|0;
    $59 = ($58|0)==(0);
    if (!($59)) {
     break;
    }
    HEAP32[$41>>2] = $53;
    $$pre = HEAP16[$43>>1]|0;
    $72 = $$pre;$74 = $57;
   } else {
    $60 = ($adjust$0<<24>>24)==(0);
    if ($60) {
     break;
    }
    $$phi$trans$insert = (($loader) + 32|0);
    $$pre2 = HEAP32[$$phi$trans$insert>>2]|0;
    $72 = $44;$74 = $$pre2;
   }
   $61 = (($loader) + 24|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = HEAP16[$1>>1]|0;
   $64 = $63 << 16 >> 16;
   $65 = (($62) + ($64<<3)|0);
   $66 = (($loader) + 60|0);
   HEAP32[$66>>2] = $65;
   $67 = (($loader) + 28|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + ($64)|0);
   $70 = (($loader) + 64|0);
   HEAP32[$70>>2] = $69;
   $71 = $72 << 16 >> 16;
   $73 = (($74) + ($71<<1)|0);
   $75 = (($loader) + 68|0);
   HEAP32[$75>>2] = $73;
   $76 = (($loader) + 16|0);
   $77 = HEAP8[$76>>0]|0;
   $78 = ($77<<24>>24)==(0);
   if (!($78)) {
    $79 = (($loader) + 40|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($80) + ($64<<3)|0);
    $82 = (($loader) + 76|0);
    HEAP32[$82>>2] = $81;
    $83 = (($loader) + 44|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($84) + ($64<<3)|0);
    $86 = (($loader) + 80|0);
    HEAP32[$86>>2] = $85;
   }
  }
 } while(0);
 $87 = HEAP32[$error>>2]|0;
 $$0 = $87;
 STACKTOP = sp;return ($$0|0);
}
function _FT_GlyphLoader_CheckSubGlyphs($loader,$n_subs) {
 $loader = $loader|0;
 $n_subs = $n_subs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$loader>>2]|0;
 HEAP32[$error>>2] = 0;
 $1 = (($loader) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($loader) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + ($n_subs))|0;
 $6 = (($5) + ($4))|0;
 $7 = (($loader) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6>>>0)>($8>>>0);
 if (!($9)) {
  $20 = 0;
  STACKTOP = sp;return ($20|0);
 }
 $10 = (($6) + 1)|0;
 $11 = $10 & -2;
 $12 = (($loader) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_ft_mem_realloc($0,32,$8,$11,$13,$error)|0);
 HEAP32[$12>>2] = $14;
 $15 = HEAP32[$error>>2]|0;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $20 = $15;
  STACKTOP = sp;return ($20|0);
 }
 HEAP32[$7>>2] = $11;
 $17 = HEAP32[$1>>2]|0;
 $18 = (($14) + ($17<<5)|0);
 $19 = (($loader) + 88|0);
 HEAP32[$19>>2] = $18;
 $20 = 0;
 STACKTOP = sp;return ($20|0);
}
function _FT_GlyphLoader_Prepare($loader) {
 $loader = $loader|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($loader) + 58|0);
 HEAP16[$0>>1] = 0;
 $1 = (($loader) + 56|0);
 HEAP16[$1>>1] = 0;
 $2 = (($loader) + 84|0);
 HEAP32[$2>>2] = 0;
 $3 = (($loader) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($loader) + 22|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6 << 16 >> 16;
 $8 = (($4) + ($7<<3)|0);
 $9 = (($loader) + 60|0);
 HEAP32[$9>>2] = $8;
 $10 = (($loader) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($7)|0);
 $13 = (($loader) + 64|0);
 HEAP32[$13>>2] = $12;
 $14 = (($loader) + 32|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($loader) + 20|0);
 $17 = HEAP16[$16>>1]|0;
 $18 = $17 << 16 >> 16;
 $19 = (($15) + ($18<<1)|0);
 $20 = (($loader) + 68|0);
 HEAP32[$20>>2] = $19;
 $21 = (($loader) + 16|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if ($23) {
  $32 = (($loader) + 52|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($loader) + 48|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + ($35<<5)|0);
  $37 = (($loader) + 88|0);
  HEAP32[$37>>2] = $36;
  STACKTOP = sp;return;
 }
 $24 = (($loader) + 40|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($7<<3)|0);
 $27 = (($loader) + 76|0);
 HEAP32[$27>>2] = $26;
 $28 = (($loader) + 44|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + ($7<<3)|0);
 $31 = (($loader) + 80|0);
 HEAP32[$31>>2] = $30;
 $32 = (($loader) + 52|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($loader) + 48|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($33) + ($35<<5)|0);
 $37 = (($loader) + 88|0);
 HEAP32[$37>>2] = $36;
 STACKTOP = sp;return;
}
function _FT_GlyphLoader_Add($loader) {
 $loader = $loader|0;
 var $$pre = 0, $$pre2 = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $n$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($loader|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($loader) + 56|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 << 16 >> 16;
 $4 = (($loader) + 22|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 << 16 >> 16;
 $7 = (($loader) + 58|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $10 = (($9) + ($6))|0;
 $11 = $10&65535;
 HEAP16[$4>>1] = $11;
 $12 = (($loader) + 20|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13&65535;
 $15 = $2&65535;
 $16 = (($15) + ($14))|0;
 $17 = $16&65535;
 HEAP16[$12>>1] = $17;
 $18 = (($loader) + 84|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($loader) + 48|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19))|0;
 HEAP32[$20>>2] = $22;
 $23 = ($2<<16>>16)==(0);
 $$pre4 = (($loader) + 68|0);
 if ($23) {
  $35 = $11;$45 = $17;
 } else {
  $24 = HEAP32[$$pre4>>2]|0;
  $n$01 = 0;
  while(1) {
   $25 = (($24) + ($n$01<<1)|0);
   $26 = HEAP16[$25>>1]|0;
   $27 = $26&65535;
   $28 = (($27) + ($6))|0;
   $29 = $28&65535;
   HEAP16[$25>>1] = $29;
   $30 = (($n$01) + 1)|0;
   $31 = ($30>>>0)<($3>>>0);
   if ($31) {
    $n$01 = $30;
   } else {
    break;
   }
  }
  $$pre = HEAP16[$4>>1]|0;
  $$pre2 = HEAP16[$12>>1]|0;
  $35 = $$pre;$45 = $$pre2;
 }
 HEAP16[$7>>1] = 0;
 HEAP16[$1>>1] = 0;
 HEAP32[$18>>2] = 0;
 $32 = (($loader) + 24|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = $35 << 16 >> 16;
 $36 = (($33) + ($34<<3)|0);
 $37 = (($loader) + 60|0);
 HEAP32[$37>>2] = $36;
 $38 = (($loader) + 28|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($39) + ($34)|0);
 $41 = (($loader) + 64|0);
 HEAP32[$41>>2] = $40;
 $42 = (($loader) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $45 << 16 >> 16;
 $46 = (($43) + ($44<<1)|0);
 HEAP32[$$pre4>>2] = $46;
 $47 = (($loader) + 16|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = ($48<<24>>24)==(0);
 if (!($49)) {
  $50 = (($loader) + 40|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + ($34<<3)|0);
  $53 = (($loader) + 76|0);
  HEAP32[$53>>2] = $52;
  $54 = (($loader) + 44|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + ($34<<3)|0);
  $57 = (($loader) + 80|0);
  HEAP32[$57>>2] = $56;
 }
 $58 = (($loader) + 52|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + ($22<<5)|0);
 $61 = (($loader) + 88|0);
 HEAP32[$61>>2] = $60;
 STACKTOP = sp;return;
}
function _FT_Init_Class_ft_bitmap_glyph_class($clazz) {
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 52;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 1651078259;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 2611;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 3728;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 2612;
 $4 = (($clazz) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($clazz) + 24|0);
 HEAP32[$5>>2] = 3450;
 $6 = (($clazz) + 28|0);
 HEAP32[$6>>2] = 0;
 STACKTOP = sp;return;
}
function _ft_bitmap_glyph_init($bitmap_glyph,$slot) {
 $bitmap_glyph = $bitmap_glyph|0;
 $slot = $slot|0;
 var $$c = 0, $$c1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$bitmap_glyph>>2]|0;
 $1 = (($slot) + 72|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(1651078259);
 if (!($3)) {
  $error$0 = 18;
  STACKTOP = sp;return ($error$0|0);
 }
 $4 = (($slot) + 100|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($bitmap_glyph) + 20|0);
 $$c = $5;
 HEAP32[$6>>2] = $$c;
 $7 = (($slot) + 104|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($bitmap_glyph) + 24|0);
 $$c1 = $8;
 HEAP32[$9>>2] = $$c1;
 $10 = (($slot) + 156|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 & 1;
 $15 = ($14|0)==(0);
 $16 = (($bitmap_glyph) + 28|0);
 if ($15) {
  _FT_Bitmap_New($16);
  $22 = (($slot) + 76|0);
  $23 = (_FT_Bitmap_Copy($0,$22,$16)|0);
  $error$0 = $23;
  STACKTOP = sp;return ($error$0|0);
 } else {
  $17 = (($slot) + 76|0);
  ;HEAP32[$16+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$17+12>>2]|0;HEAP32[$16+16>>2]=HEAP32[$17+16>>2]|0;HEAP32[$16+20>>2]=HEAP32[$17+20>>2]|0;
  $18 = HEAP32[$10>>2]|0;
  $19 = (($18) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20 & -2;
  HEAP32[$19>>2] = $21;
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 return 0|0;
}
function _ft_bitmap_glyph_done($bitmap_glyph) {
 $bitmap_glyph = $bitmap_glyph|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$bitmap_glyph>>2]|0;
 $1 = (($bitmap_glyph) + 28|0);
 (_FT_Bitmap_Done($0,$1)|0);
 STACKTOP = sp;return;
}
function _ft_bitmap_glyph_copy($bitmap_source,$bitmap_target) {
 $bitmap_source = $bitmap_source|0;
 $bitmap_target = $bitmap_target|0;
 var $$c = 0, $$c1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$bitmap_source>>2]|0;
 $1 = (($bitmap_source) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($bitmap_target) + 20|0);
 $$c = $2;
 HEAP32[$3>>2] = $$c;
 $4 = (($bitmap_source) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($bitmap_target) + 24|0);
 $$c1 = $5;
 HEAP32[$6>>2] = $$c1;
 $7 = (($bitmap_source) + 28|0);
 $8 = (($bitmap_target) + 28|0);
 $9 = (_FT_Bitmap_Copy($0,$7,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function _ft_bitmap_glyph_bbox($bitmap_glyph,$cbox) {
 $bitmap_glyph = $bitmap_glyph|0;
 $cbox = $cbox|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($bitmap_glyph) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 6;
 HEAP32[$cbox>>2] = $2;
 $3 = (($bitmap_glyph) + 28|0);
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 << 6;
 $7 = (($6) + ($2))|0;
 $8 = (($cbox) + 8|0);
 HEAP32[$8>>2] = $7;
 $9 = (($bitmap_glyph) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 6;
 $12 = (($cbox) + 12|0);
 HEAP32[$12>>2] = $11;
 $13 = HEAP32[$3>>2]|0;
 $14 = $13 << 6;
 $15 = (($11) - ($14))|0;
 $16 = (($cbox) + 4|0);
 HEAP32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function _FT_Init_Class_ft_outline_glyph_class($clazz) {
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 40;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 1869968492;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 2613;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 3729;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 2614;
 $4 = (($clazz) + 20|0);
 HEAP32[$4>>2] = 2059;
 $5 = (($clazz) + 24|0);
 HEAP32[$5>>2] = 3451;
 $6 = (($clazz) + 28|0);
 HEAP32[$6>>2] = 2615;
 STACKTOP = sp;return;
}
function _ft_outline_glyph_init($outline_glyph,$slot) {
 $outline_glyph = $outline_glyph|0;
 $slot = $slot|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($slot) + 108|0);
 $1 = (($outline_glyph) + 20|0);
 $2 = (($slot) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(1869968492);
 if (!($4)) {
  $error$0 = 18;
  STACKTOP = sp;return ($error$0|0);
 }
 $5 = HEAP32[$outline_glyph>>2]|0;
 $6 = (($slot) + 110|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 << 16 >> 16;
 $9 = HEAP16[$0>>1]|0;
 $10 = $9 << 16 >> 16;
 $11 = (_FT_Outline_New($5,$8,$10,$1)|0);
 $12 = ($11|0)==(0);
 if (!($12)) {
  $error$0 = $11;
  STACKTOP = sp;return ($error$0|0);
 }
 (_FT_Outline_Copy($0,$1)|0);
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _ft_outline_glyph_done($outline_glyph) {
 $outline_glyph = $outline_glyph|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$outline_glyph>>2]|0;
 $1 = (($outline_glyph) + 20|0);
 (_FT_Outline_Done($0,$1)|0);
 STACKTOP = sp;return;
}
function _ft_outline_glyph_copy($outline_source,$outline_target) {
 $outline_source = $outline_source|0;
 $outline_target = $outline_target|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$outline_source>>2]|0;
 $1 = (($outline_source) + 20|0);
 $2 = (($1) + 2|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 << 16 >> 16;
 $5 = HEAP16[$1>>1]|0;
 $6 = $5 << 16 >> 16;
 $7 = (($outline_target) + 20|0);
 $8 = (_FT_Outline_New($0,$4,$6,$7)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  STACKTOP = sp;return ($8|0);
 }
 (_FT_Outline_Copy($1,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function _ft_outline_glyph_transform($outline_glyph,$matrix,$delta) {
 $outline_glyph = $outline_glyph|0;
 $matrix = $matrix|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($matrix|0)==(0|0);
 if (!($0)) {
  $1 = (($outline_glyph) + 20|0);
  _FT_Outline_Transform($1,$matrix);
 }
 $2 = ($delta|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($outline_glyph) + 20|0);
 $4 = HEAP32[$delta>>2]|0;
 $5 = (($delta) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 _FT_Outline_Translate($3,$4,$6);
 STACKTOP = sp;return;
}
function _ft_outline_glyph_bbox($outline_glyph,$bbox) {
 $outline_glyph = $outline_glyph|0;
 $bbox = $bbox|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($outline_glyph) + 20|0);
 _FT_Outline_Get_CBox($0,$bbox);
 STACKTOP = sp;return;
}
function _ft_outline_glyph_prepare($outline_glyph,$slot) {
 $outline_glyph = $outline_glyph|0;
 $slot = $slot|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($slot) + 72|0);
 HEAP32[$0>>2] = 1869968492;
 $1 = (($slot) + 108|0);
 $2 = (($outline_glyph) + 20|0);
 ;HEAP32[$1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$2+16>>2]|0;
 $3 = (($slot) + 124|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & -2;
 HEAP32[$3>>2] = $5;
 STACKTOP = sp;return 0;
}
function _ft_destroy_default_module_classes($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($library) + 196|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$library>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  _FT_Destroy_Class_tt_driver_class($library,$5);
 }
 $7 = (($2) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  _FT_Destroy_Class_cff_driver_class($library,$8);
 }
 $10 = (($2) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  _FT_Destroy_Class_psnames_module_class($library,$11);
 }
 $13 = (($2) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  _FT_Destroy_Class_pshinter_module_class($library,$14);
 }
 $16 = (($2) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  _FT_Destroy_Class_ft_raster1_renderer_class($library,$17);
 }
 $19 = (($2) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  _FT_Destroy_Class_sfnt_module_class($library,$20);
 }
 $22 = (($2) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  _FT_Destroy_Class_ft_smooth_renderer_class($library,$23);
 }
 _ft_mem_free($4,$2);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function _ft_create_default_module_classes($library) {
 $library = $library|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $clazz = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp + 4|0;
 $clazz = sp;
 $0 = (($library) + 196|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$library>>2]|0;
 HEAP32[$1>>2] = 0;
 $3 = (_ft_mem_alloc($2,32,$error)|0);
 $4 = HEAP32[$error>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;HEAP32[$3+24>>2]=0|0;HEAP32[$3+28>>2]=0|0;
 $6 = (_FT_Create_Class_tt_driver_class($library,$clazz)|0);
 HEAP32[$error>>2] = $6;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = HEAP32[$clazz>>2]|0;
  HEAP32[$3>>2] = $8;
  $9 = (_FT_Create_Class_cff_driver_class($library,$clazz)|0);
  HEAP32[$error>>2] = $9;
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = HEAP32[$clazz>>2]|0;
   $12 = (($3) + 4|0);
   HEAP32[$12>>2] = $11;
   $13 = (_FT_Create_Class_psnames_module_class($library,$clazz)|0);
   HEAP32[$error>>2] = $13;
   $14 = ($13|0)==(0);
   if ($14) {
    $15 = HEAP32[$clazz>>2]|0;
    $16 = (($3) + 8|0);
    HEAP32[$16>>2] = $15;
    $17 = (_FT_Create_Class_pshinter_module_class($library,$clazz)|0);
    HEAP32[$error>>2] = $17;
    $18 = ($17|0)==(0);
    if ($18) {
     $19 = HEAP32[$clazz>>2]|0;
     $20 = (($3) + 12|0);
     HEAP32[$20>>2] = $19;
     $21 = (_FT_Create_Class_ft_raster1_renderer_class($library,$clazz)|0);
     HEAP32[$error>>2] = $21;
     $22 = ($21|0)==(0);
     if ($22) {
      $23 = HEAP32[$clazz>>2]|0;
      $24 = (($3) + 16|0);
      HEAP32[$24>>2] = $23;
      $25 = (_FT_Create_Class_sfnt_module_class($library,$clazz)|0);
      HEAP32[$error>>2] = $25;
      $26 = ($25|0)==(0);
      if ($26) {
       $27 = HEAP32[$clazz>>2]|0;
       $28 = (($3) + 20|0);
       HEAP32[$28>>2] = $27;
       $29 = (_FT_Create_Class_ft_smooth_renderer_class($library,$clazz)|0);
       HEAP32[$error>>2] = $29;
       $30 = ($29|0)==(0);
       if ($30) {
        $31 = HEAP32[$clazz>>2]|0;
        $32 = (($3) + 24|0);
        HEAP32[$32>>2] = $31;
        HEAP32[$1>>2] = $3;
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 _ft_destroy_default_module_classes($library);
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Add_Default_Modules($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $cur$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($library) + 196|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $5 = $3;$cur$01 = $2;
 }
 while(1) {
  (_FT_Add_Module($library,$5)|0);
  $6 = (($cur$01) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   break;
  } else {
   $5 = $7;$cur$01 = $6;
  }
 }
 STACKTOP = sp;return;
}
function _ft_service_list_lookup($service_descriptors,$service_id) {
 $service_descriptors = $service_descriptors|0;
 $service_id = $service_id|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $desc$02 = 0, $or$cond = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($service_descriptors|0)==(0|0);
 $1 = ($service_id|0)==(0|0);
 $or$cond = $0 | $1;
 L1: do {
  if ($or$cond) {
   $result$0 = 0;
  } else {
   $2 = HEAP32[$service_descriptors>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    $result$0 = 0;
   } else {
    $7 = $2;$desc$02 = $service_descriptors;
    while(1) {
     $8 = (_strcmp($7,$service_id)|0);
     $9 = ($8|0)==(0);
     $5 = (($desc$02) + 8|0);
     if ($9) {
      break;
     }
     $4 = HEAP32[$5>>2]|0;
     $6 = ($4|0)==(0|0);
     if ($6) {
      $result$0 = 0;
      break L1;
     } else {
      $7 = $4;$desc$02 = $5;
     }
    }
    $10 = (($desc$02) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $result$0 = $11;
   }
  }
 } while(0);
 STACKTOP = sp;return ($result$0|0);
}
function _ft_validator_init($valid,$base,$limit,$level) {
 $valid = $valid|0;
 $base = $base|0;
 $limit = $limit|0;
 $level = $level|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$valid>>2] = $base;
 $0 = (($valid) + 4|0);
 HEAP32[$0>>2] = $limit;
 $1 = (($valid) + 8|0);
 HEAP32[$1>>2] = $level;
 $2 = (($valid) + 12|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function _ft_validator_error($valid,$error) {
 $valid = $valid|0;
 $error = $error|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($valid) + 12|0);
 HEAP32[$0>>2] = $error;
 STACKTOP = sp;return;
}
function _FT_Stream_New($library,$args,$astream) {
 $library = $library|0;
 $args = $args|0;
 $astream = $astream|0;
 var $$0 = 0, $$pr = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $stream$0$ph = 0, $stream$01 = 0, $stream$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$astream>>2] = 0;
 $0 = ($library|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($args|0)==(0|0);
 if ($1) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP32[$library>>2]|0;
 $3 = (_ft_mem_alloc($2,40,$error)|0);
 $4 = HEAP32[$error>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($3) + 28|0);
 HEAP32[$6>>2] = $2;
 $7 = HEAP32[$args>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 do {
  if ($9) {
   $14 = $7 & 4;
   $15 = ($14|0)==(0);
   if (!($15)) {
    $16 = (($args) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (_FT_Stream_Open($3,$17)|0);
    HEAP32[$error>>2] = $18;
    $19 = HEAP32[$16>>2]|0;
    $20 = (($3) + 16|0);
    HEAP32[$20>>2] = $19;
    $stream$0$ph = $3;
    label = 12;
    break;
   }
   $21 = $7 & 2;
   $22 = ($21|0)==(0);
   if (!($22)) {
    $23 = (($args) + 16|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0|0);
    if (!($25)) {
     _ft_mem_free($2,$3);
     $26 = HEAP32[$23>>2]|0;
     $stream$0$ph = $26;
     label = 12;
     break;
    }
   }
   HEAP32[$error>>2] = 6;
   $stream$01 = $3;
   label = 13;
  } else {
   $10 = (($args) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($args) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   _FT_Stream_OpenMemory($3,$11,$13);
   $stream$0$ph = $3;
   label = 12;
  }
 } while(0);
 if ((label|0) == 12) {
  $$pr = HEAP32[$error>>2]|0;
  $27 = ($$pr|0)==(0);
  if ($27) {
   $28 = (($stream$0$ph) + 28|0);
   HEAP32[$28>>2] = $2;
   $$pre = 0;$stream$1 = $stream$0$ph;
  } else {
   $stream$01 = $stream$0$ph;
   label = 13;
  }
 }
 if ((label|0) == 13) {
  _ft_mem_free($2,$stream$01);
  $$pre$pre = HEAP32[$error>>2]|0;
  $$pre = $$pre$pre;$stream$1 = 0;
 }
 HEAP32[$astream>>2] = $stream$1;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Stream_Free($stream,$external) {
 $stream = $stream|0;
 $external = $external|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($stream|0)==(0|0);
 if (!($0)) {
  $1 = (($stream) + 28|0);
  $2 = HEAP32[$1>>2]|0;
  _FT_Stream_Close($stream);
  $3 = ($external|0)==(0);
  if ($3) {
   _ft_mem_free($2,$stream);
  }
 }
 STACKTOP = sp;return;
}
function _ft_glyphslot_alloc_bitmap($slot,$size) {
 $slot = $slot|0;
 $size = $size|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($slot) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($slot) + 156|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  $12 = $7 | 1;
  HEAP32[$6>>2] = $12;
  $$pre = (($slot) + 88|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $10 = (($slot) + 88|0);
  $11 = HEAP32[$10>>2]|0;
  _ft_mem_free($3,$11);
  HEAP32[$10>>2] = 0;
  $$pre$phiZ2D = $10;
 }
 $13 = (_ft_mem_alloc($3,$size,$error)|0);
 HEAP32[$$pre$phiZ2D>>2] = $13;
 $14 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($14|0);
}
function _FT_New_GlyphSlot($face,$aslot) {
 $face = $face|0;
 $aslot = $aslot|0;
 var $$0 = 0, $$ph = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0;
 var $9 = 0, $error = 0, $error$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp + 4|0;
 $error = sp;
 $0 = ($face|0)==(0|0);
 if ($0) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($face) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($2) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (_ft_mem_alloc($7,$9,$error)|0);
 $11 = HEAP32[$error>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $76 = ($aslot|0)==(0|0);
  if ($76) {
   $$0 = $11;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$aslot>>2] = 0;
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($10) + 4|0);
 HEAP32[$13>>2] = $face;
 $14 = HEAP32[$1>>2]|0;
 $15 = (($14) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 HEAP32[$error$i>>2] = 0;
 $19 = (($14) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$10>>2] = $20;
 $21 = (_ft_mem_alloc($18,40,$error$i)|0);
 $22 = HEAP32[$error$i>>2]|0;
 $23 = ($22|0)==(0);
 do {
  if ($23) {
   $24 = (($10) + 156|0);
   HEAP32[$24>>2] = $21;
   $25 = HEAP32[$14>>2]|0;
   $26 = HEAP32[$25>>2]|0;
   $27 = $26 & 512;
   $28 = ($27|0)==(0);
   if ($28) {
    $29 = (_FT_GlyphLoader_New($18,$21)|0);
    HEAP32[$error$i>>2] = $29;
    $30 = ($29|0)==(0);
    if (!($30)) {
     $$ph = $29;
     label = 9;
     break;
    }
   }
   $31 = (($16) + 64|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    HEAP32[$error>>2] = 0;
   } else {
    $34 = (FUNCTION_TABLE_ii[$32 & 4095]($10)|0);
    HEAP32[$error>>2] = $34;
    $35 = ($34|0)==(0);
    if (!($35)) {
     break;
    }
   }
   $72 = (($face) + 84|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($10) + 8|0);
   HEAP32[$74>>2] = $73;
   HEAP32[$72>>2] = $10;
   $75 = ($aslot|0)==(0|0);
   if ($75) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$aslot>>2] = $10;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$ph = $22;
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  HEAP32[$error>>2] = $$ph;
 }
 $36 = HEAP32[$13>>2]|0;
 $37 = (($36) + 96|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 68|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  FUNCTION_TABLE_vi[$44 & 4095]($10);
 }
 $46 = (($10) + 156|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47|0)==(0|0);
 if ($48) {
  label = 16;
 } else {
  $49 = (($47) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 1;
  $52 = ($51|0)==(0);
  if ($52) {
   label = 16;
  } else {
   $53 = HEAP32[$13>>2]|0;
   $54 = (($53) + 100|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (($10) + 88|0);
   $57 = HEAP32[$56>>2]|0;
   _ft_mem_free($55,$57);
   HEAP32[$56>>2] = 0;
   $58 = HEAP32[$46>>2]|0;
   $59 = (($58) + 4|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = $60 & -2;
   HEAP32[$59>>2] = $61;
   $64 = $58;
  }
 }
 if ((label|0) == 16) {
  $62 = (($10) + 88|0);
  HEAP32[$62>>2] = 0;
  $64 = $47;
 }
 $63 = ($64|0)==(0|0);
 if (!($63)) {
  $65 = HEAP32[$38>>2]|0;
  $66 = HEAP32[$65>>2]|0;
  $67 = $66 & 512;
  $68 = ($67|0)==(0);
  if ($68) {
   $69 = HEAP32[$64>>2]|0;
   _FT_GlyphLoader_Done($69);
   $70 = HEAP32[$46>>2]|0;
   HEAP32[$70>>2] = 0;
   $$pre$i = HEAP32[$46>>2]|0;
   $71 = $$pre$i;
  } else {
   $71 = $64;
  }
  _ft_mem_free($42,$71);
  HEAP32[$46>>2] = 0;
 }
 _ft_mem_free($7,$10);
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Done_GlyphSlot($slot) {
 $slot = $slot|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cur$0 = 0, $cur$03 = 0, $cur$05 = 0, $prev$04 = 0, $prev$04$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($slot|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($slot) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($2) + 84|0);
 $cur$03 = HEAP32[$7>>2]|0;
 $8 = ($cur$03|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 } else {
  $cur$05 = $cur$03;$prev$04 = 0;
 }
 while(1) {
  $11 = ($cur$05|0)==($slot|0);
  if ($11) {
   break;
  }
  $9 = (($cur$05) + 8|0);
  $cur$0 = HEAP32[$9>>2]|0;
  $10 = ($cur$0|0)==(0|0);
  if ($10) {
   label = 19;
   break;
  } else {
   $prev$04$phi = $cur$05;$cur$05 = $cur$0;$prev$04 = $prev$04$phi;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return;
 }
 $12 = ($prev$04|0)==(0|0);
 $13 = (($slot) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 if ($12) {
  HEAP32[$7>>2] = $14;
 } else {
  $15 = (($prev$04) + 8|0);
  HEAP32[$15>>2] = $14;
 }
 $16 = HEAP32[$1>>2]|0;
 $17 = (($16) + 96|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 68|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  FUNCTION_TABLE_vi[$24 & 4095]($slot);
 }
 $26 = (($slot) + 156|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  label = 13;
 } else {
  $29 = (($27) + 4|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = $30 & 1;
  $32 = ($31|0)==(0);
  if ($32) {
   label = 13;
  } else {
   $33 = HEAP32[$1>>2]|0;
   $34 = (($33) + 100|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($slot) + 88|0);
   $37 = HEAP32[$36>>2]|0;
   _ft_mem_free($35,$37);
   HEAP32[$36>>2] = 0;
   $38 = HEAP32[$26>>2]|0;
   $39 = (($38) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $40 & -2;
   HEAP32[$39>>2] = $41;
   $44 = $38;
  }
 }
 if ((label|0) == 13) {
  $42 = (($slot) + 88|0);
  HEAP32[$42>>2] = 0;
  $44 = $27;
 }
 $43 = ($44|0)==(0|0);
 if (!($43)) {
  $45 = HEAP32[$18>>2]|0;
  $46 = HEAP32[$45>>2]|0;
  $47 = $46 & 512;
  $48 = ($47|0)==(0);
  if ($48) {
   $49 = HEAP32[$44>>2]|0;
   _FT_GlyphLoader_Done($49);
   $50 = HEAP32[$26>>2]|0;
   HEAP32[$50>>2] = 0;
   $$pre$i = HEAP32[$26>>2]|0;
   $51 = $$pre$i;
  } else {
   $51 = $44;
  }
  _ft_mem_free($22,$51);
  HEAP32[$26>>2] = 0;
 }
 _ft_mem_free($6,$slot);
 STACKTOP = sp;return;
}
function _FT_Set_Transform($face,$matrix,$delta) {
 $face = $face|0;
 $matrix = $matrix|0;
 $delta = $delta|0;
 var $$0 = 0, $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($face|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($face) + 128|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 28|0);
 HEAP32[$3>>2] = 0;
 $4 = ($matrix|0)==(0|0);
 $5 = (($2) + 4|0);
 if ($4) {
  HEAP32[$5>>2] = 65536;
  $6 = (($2) + 8|0);
  HEAP32[$6>>2] = 0;
  $7 = (($2) + 12|0);
  HEAP32[$7>>2] = 0;
  $8 = (($2) + 16|0);
  HEAP32[$8>>2] = 65536;
  $$0 = $5;
 } else {
  ;HEAP32[$5+0>>2]=HEAP32[$matrix+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$matrix+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$matrix+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$matrix+12>>2]|0;
  $$0 = $matrix;
 }
 $9 = (($$0) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($$0) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 | $10;
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = HEAP32[$$0>>2]|0;
  $16 = ($15|0)==(65536);
  if ($16) {
   $17 = (($$0) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(65536);
   if ($19) {
    $38 = 2;
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  HEAP32[$3>>2] = 1;
  $38 = 3;
 }
 $20 = ($delta|0)==(0|0);
 $21 = (($2) + 20|0);
 if ($20) {
  HEAP32[$21>>2] = 0;
  $22 = (($2) + 24|0);
  HEAP32[$22>>2] = 0;
  $$01 = $21;$36 = 0;
 } else {
  $23 = $delta;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $21;
  $30 = $29;
  HEAP32[$30>>2] = $25;
  $31 = (($29) + 4)|0;
  $32 = $31;
  HEAP32[$32>>2] = $28;
  $$pre = HEAP32[$delta>>2]|0;
  $$01 = $delta;$36 = $$pre;
 }
 $33 = (($$01) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 | $36;
 $37 = ($35|0)==(0);
 if ($37) {
  STACKTOP = sp;return;
 }
 HEAP32[$3>>2] = $38;
 STACKTOP = sp;return;
}
function _FT_Load_Glyph($face,$glyph_index,$load_flags) {
 $face = $face|0;
 $glyph_index = $glyph_index|0;
 $load_flags = $load_flags|0;
 var $$0 = 0, $$1 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $cur$12$i$i = 0, $error$0 = 0, $error$1 = 0, $error$2 = 0, $load_flags$ = 0, $mode2$0 = 0, $or$cond15 = 0, $result$0$i17 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($face|0)==(0|0);
 if ($0) {
  $$0 = 35;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($face) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 35;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($face) + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 35;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($5) + 156|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  label = 7;
 } else {
  $10 = (($8) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 & 1;
  $13 = ($12|0)==(0);
  if ($13) {
   label = 7;
  } else {
   $14 = (($5) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 100|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($5) + 88|0);
   $19 = HEAP32[$18>>2]|0;
   _ft_mem_free($17,$19);
   HEAP32[$18>>2] = 0;
   $20 = HEAP32[$7>>2]|0;
   $21 = (($20) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = $22 & -2;
   HEAP32[$21>>2] = $23;
  }
 }
 if ((label|0) == 7) {
  $24 = (($5) + 88|0);
  HEAP32[$24>>2] = 0;
 }
 $25 = (($5) + 24|0);
 $26 = (($5) + 94|0);
 HEAP8[$26>>0] = 0;
 $27 = (($5) + 100|0);
 $28 = (($5) + 72|0);
 dest=$25+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$28+0>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;HEAP32[$28+12>>2]=0|0;
 dest=$27+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $29 = (($face) + 96|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 168|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $load_flags & 1024;
 $36 = ($35|0)==(0);
 $37 = $load_flags | 2049;
 $load_flags$ = $36 ? $load_flags : $37;
 $38 = $load_flags$ & 1;
 $39 = ($38|0)==(0);
 if ($39) {
  $$1 = $load_flags$;
 } else {
  $40 = $load_flags$ & -15;
  $41 = $40 | 10;
  $$1 = $41;
 }
 $42 = ($34|0)==(0|0);
 L19: do {
  if ($42) {
   label = 30;
  } else {
   $43 = $$1 & 32770;
   $44 = ($43|0)==(0);
   if ($44) {
    $45 = HEAP32[$30>>2]|0;
    $46 = HEAP32[$45>>2]|0;
    $47 = $46 & 768;
    $48 = ($47|0)==(256);
    if ($48) {
     $49 = (($face) + 8|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = $50 & 8192;
     $52 = ($51|0)==(0);
     if ($52) {
      $53 = $$1 & 2048;
      $54 = ($53|0)==(0);
      do {
       if ($54) {
        $55 = (($face) + 128|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = (($56) + 12|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = ($58|0)==(0);
        $60 = (($56) + 4|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = ($61|0)==(0);
        if ($59) {
         if ($62) {
          label = 30;
          break L19;
         } else {
          break;
         }
        } else {
         if ($62) {
          break;
         } else {
          label = 30;
          break L19;
         }
        }
       }
      } while(0);
      $63 = $$1 & 32;
      $64 = ($63|0)==(0);
      if ($64) {
       $65 = $46 & 1024;
       $66 = ($65|0)==(0);
       if (!($66)) {
        $67 = $$1 & 983040;
        $68 = ($67|0)==(65536);
        if (!($68)) {
         $69 = (($face) + 128|0);
         $70 = HEAP32[$69>>2]|0;
         $71 = (($70) + 52|0);
         $72 = HEAP8[$71>>0]|0;
         $73 = ($72<<24>>24)==(0);
         if ($73) {
          $74 = $50 & 8;
          $75 = ($74|0)==(0);
          if ($75) {
           label = 30;
           break;
          }
          $76 = (($face) + 732|0);
          $77 = HEAP32[$76>>2]|0;
          $78 = ($77|0)==(0);
          if ($78) {
           label = 30;
           break;
          }
          $79 = (($face) + 260|0);
          $80 = (($79) + 26|0);
          $81 = HEAP16[$80>>1]|0;
          $82 = ($81<<16>>16)==(0);
          if (!($82)) {
           label = 30;
           break;
          }
         }
        }
       }
      }
      $83 = $50 & 2;
      $84 = ($83|0)==(0);
      if (!($84)) {
       $85 = $$1 & 8;
       $86 = ($85|0)==(0);
       if ($86) {
        $87 = (($30) + 20|0);
        $88 = HEAP32[$87>>2]|0;
        $89 = (($88) + 80|0);
        $90 = HEAP32[$89>>2]|0;
        $91 = HEAP32[$1>>2]|0;
        $92 = $$1 | 16384;
        $93 = (FUNCTION_TABLE_iiiii[$90 & 511]($5,$91,$glyph_index,$92)|0);
        $94 = ($93|0)==(0);
        if ($94) {
         $95 = HEAP32[$28>>2]|0;
         $96 = ($95|0)==(1651078259);
         if ($96) {
          $error$0 = 0;
          break;
         }
        }
       }
      }
      $97 = (($face) + 128|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = (($98) + 28|0);
      $100 = HEAP32[$99>>2]|0;
      HEAP32[$99>>2] = 0;
      $101 = HEAP32[$34>>2]|0;
      $102 = (($101) + 20|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = (($103) + 12|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = HEAP32[$1>>2]|0;
      $107 = (FUNCTION_TABLE_iiiiii[$105 & 255]($34,$5,$106,$glyph_index,$$1)|0);
      HEAP32[$99>>2] = $100;
      $error$0 = $107;
     } else {
      label = 30;
     }
    } else {
     label = 30;
    }
   } else {
    label = 30;
   }
  }
 } while(0);
 if ((label|0) == 30) {
  $108 = (($30) + 20|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($109) + 80|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = HEAP32[$1>>2]|0;
  $113 = (FUNCTION_TABLE_iiiii[$111 & 511]($5,$112,$glyph_index,$$1)|0);
  $114 = ($113|0)==(0);
  if (!($114)) {
   $$0 = $113;
   STACKTOP = sp;return ($$0|0);
  }
  $115 = HEAP32[$28>>2]|0;
  $116 = ($115|0)==(1869968492);
  if ($116) {
   $117 = (($5) + 108|0);
   $118 = (_FT_Outline_Check($117)|0);
   $119 = ($118|0)==(0);
   if (!($119)) {
    $$0 = $118;
    STACKTOP = sp;return ($$0|0);
   }
   $120 = $$1 & 2;
   $121 = ($120|0)==(0);
   if ($121) {
    $122 = $$1 & 16;
    $123 = ($122|0)==(0);
    if ($123) {
     $148 = (($5) + 44|0);
     $149 = HEAP32[$148>>2]|0;
     $150 = $149 & -64;
     HEAP32[$148>>2] = $150;
     $151 = (($5) + 48|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = $152 & -64;
     HEAP32[$151>>2] = $153;
     $154 = (($5) + 32|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = HEAP32[$25>>2]|0;
     $157 = (($155) + 63)|0;
     $158 = (($157) + ($156))|0;
     $159 = $158 & -64;
     $160 = (($5) + 36|0);
     $161 = HEAP32[$160>>2]|0;
     $162 = (($5) + 28|0);
     $163 = HEAP32[$162>>2]|0;
     $164 = (($161) - ($163))|0;
     $165 = $164 & -64;
     $166 = $155 & -64;
     HEAP32[$154>>2] = $166;
     $167 = (($161) + 63)|0;
     $168 = $167 & -64;
     HEAP32[$160>>2] = $168;
     $169 = (($159) - ($166))|0;
     HEAP32[$25>>2] = $169;
     $170 = (($168) - ($165))|0;
     HEAP32[$162>>2] = $170;
    } else {
     $124 = (($5) + 32|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = $125 & -64;
     HEAP32[$124>>2] = $126;
     $127 = (($5) + 36|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = (($128) + 63)|0;
     $130 = $129 & -64;
     HEAP32[$127>>2] = $130;
     $131 = (($5) + 44|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = HEAP32[$25>>2]|0;
     $134 = (($132) + 63)|0;
     $135 = (($134) + ($133))|0;
     $136 = $135 & -64;
     $137 = (($5) + 48|0);
     $138 = HEAP32[$137>>2]|0;
     $139 = (($5) + 28|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = (($138) + 63)|0;
     $142 = (($141) + ($140))|0;
     $143 = $142 & -64;
     $144 = $132 & -64;
     HEAP32[$131>>2] = $144;
     $145 = $138 & -64;
     HEAP32[$137>>2] = $145;
     $146 = (($136) - ($144))|0;
     HEAP32[$25>>2] = $146;
     $147 = (($143) - ($145))|0;
     HEAP32[$139>>2] = $147;
    }
    $171 = (($5) + 40|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = (($172) + 32)|0;
    $174 = $173 & -64;
    HEAP32[$171>>2] = $174;
    $175 = (($5) + 52|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = (($176) + 32)|0;
    $178 = $177 & -64;
    HEAP32[$175>>2] = $178;
    $error$0 = 0;
   } else {
    $error$0 = 0;
   }
  } else {
   $error$0 = 0;
  }
 }
 $179 = $$1 & 16;
 $180 = ($179|0)==(0);
 if ($180) {
  $185 = (($5) + 40|0);
  $186 = HEAP32[$185>>2]|0;
  $187 = (($5) + 64|0);
  HEAP32[$187>>2] = $186;
  $188 = (($5) + 68|0);
  HEAP32[$188>>2] = 0;
 } else {
  $181 = (($5) + 64|0);
  HEAP32[$181>>2] = 0;
  $182 = (($5) + 52|0);
  $183 = HEAP32[$182>>2]|0;
  $184 = (($5) + 68|0);
  HEAP32[$184>>2] = $183;
 }
 $189 = $$1 & 8192;
 $190 = ($189|0)==(0);
 if ($190) {
  $191 = (($face) + 8|0);
  $192 = HEAP32[$191>>2]|0;
  $193 = $192 & 1;
  $194 = ($193|0)==(0);
  if (!($194)) {
   $195 = HEAP32[$1>>2]|0;
   $196 = (($5) + 56|0);
   $197 = HEAP32[$196>>2]|0;
   $198 = (($195) + 16|0);
   $199 = HEAP32[$198>>2]|0;
   $200 = (_FT_MulDiv($197,$199,64)|0);
   HEAP32[$196>>2] = $200;
   $201 = (($5) + 60|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = (($195) + 20|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = (_FT_MulDiv($202,$204,64)|0);
   HEAP32[$201>>2] = $205;
  }
 }
 $206 = $$1 & 2048;
 $207 = ($206|0)==(0);
 if ($207) {
  $208 = (($face) + 128|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = (($209) + 28|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = ($211|0)==(0);
  if ($212) {
   $error$2 = $error$0;
  } else {
   $213 = (($5) + 4|0);
   $214 = HEAP32[$213>>2]|0;
   $215 = (($214) + 96|0);
   $216 = HEAP32[$215>>2]|0;
   $217 = (($216) + 4|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = (($218) + 164|0);
   $220 = HEAP32[$219>>2]|0;
   $221 = ($220|0)==(0|0);
   if ($221) {
    $$pre$i = HEAP32[$28>>2]|0;
    $235 = $$pre$i;
    label = 49;
   } else {
    $222 = (($220) + 24|0);
    $223 = HEAP32[$222>>2]|0;
    $224 = HEAP32[$28>>2]|0;
    $225 = ($223|0)==($224|0);
    if ($225) {
     $result$0$i17 = $220;
     label = 54;
    } else {
     $235 = $224;
     label = 49;
    }
   }
   L72: do {
    if ((label|0) == 49) {
     $226 = ($218|0)==(0|0);
     L74: do {
      if (!($226)) {
       $227 = (($218) + 156|0);
       $228 = HEAP32[$227>>2]|0;
       $229 = ($228|0)==(0|0);
       if (!($229)) {
        $cur$12$i$i = $228;
        while(1) {
         $230 = (($cur$12$i$i) + 8|0);
         $231 = HEAP32[$230>>2]|0;
         $232 = (($231) + 24|0);
         $233 = HEAP32[$232>>2]|0;
         $234 = ($233|0)==($235|0);
         if ($234) {
          break;
         }
         $236 = (($cur$12$i$i) + 4|0);
         $237 = HEAP32[$236>>2]|0;
         $238 = ($237|0)==(0|0);
         if ($238) {
          break L74;
         } else {
          $cur$12$i$i = $237;
         }
        }
        $239 = ($231|0)==(0|0);
        if (!($239)) {
         $result$0$i17 = $231;
         label = 54;
         break L72;
        }
       }
      }
     } while(0);
     $247 = ($235|0)==(1869968492);
     if ($247) {
      $248 = $211 & 1;
      $249 = ($248|0)==(0);
      if ($249) {
       $253 = $211;
      } else {
       $250 = (($5) + 108|0);
       $251 = (($209) + 4|0);
       _FT_Outline_Transform($250,$251);
       $$pre = HEAP32[$210>>2]|0;
       $253 = $$pre;
      }
      $252 = $253 & 2;
      $254 = ($252|0)==(0);
      if ($254) {
       $error$1 = $error$0;
      } else {
       $255 = (($5) + 108|0);
       $256 = (($209) + 20|0);
       $257 = HEAP32[$256>>2]|0;
       $258 = (($209) + 24|0);
       $259 = HEAP32[$258>>2]|0;
       _FT_Outline_Translate($255,$257,$259);
       $error$1 = $error$0;
      }
     } else {
      $error$1 = $error$0;
     }
    }
   } while(0);
   if ((label|0) == 54) {
    $240 = (($result$0$i17) + 20|0);
    $241 = HEAP32[$240>>2]|0;
    $242 = (($241) + 44|0);
    $243 = HEAP32[$242>>2]|0;
    $244 = (($209) + 4|0);
    $245 = (($209) + 20|0);
    $246 = (FUNCTION_TABLE_iiiii[$243 & 511]($result$0$i17,$5,$244,$245)|0);
    $error$1 = $246;
   }
   $260 = (($5) + 64|0);
   $261 = (($209) + 4|0);
   _FT_Vector_Transform($260,$261);
   $error$2 = $error$1;
  }
 } else {
  $error$2 = $error$0;
 }
 $262 = ($error$2|0)==(0);
 if (!($262)) {
  $$0 = $error$2;
  STACKTOP = sp;return ($$0|0);
 }
 $263 = HEAP32[$28>>2]|0;
 if ((($263|0) == 1668246896) | (($263|0) == 1651078259)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $264 = $$1 & 4;
 $265 = ($264|0)==(0);
 if ($265) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $266 = $$1 >>> 16;
 $267 = $266 & 15;
 $268 = (($5) + 4|0);
 $269 = HEAP32[$268>>2]|0;
 $270 = ($269|0)==(0|0);
 if ($270) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $271 = $$1 & 4096;
 $272 = ($271|0)==(0);
 $273 = ($267|0)!=(0);
 $or$cond15 = $273 | $272;
 $mode2$0 = $or$cond15 ? $267 : 2;
 $274 = (($269) + 96|0);
 $275 = HEAP32[$274>>2]|0;
 $276 = (($275) + 4|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = (_FT_Render_Glyph_Internal($277,$5,$mode2$0)|0);
 $$0 = $278;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Render_Glyph($slot,$render_mode) {
 $slot = $slot|0;
 $render_mode = $render_mode|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($slot|0)==(0|0);
 if ($0) {
  $$0 = 6;
 } else {
  $1 = (($slot) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if ($3) {
   $$0 = 6;
  } else {
   $4 = (($2) + 96|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (_FT_Render_Glyph_Internal($7,$slot,$render_mode)|0);
   $$0 = $8;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _FT_Get_Char_Index($face,$charcode) {
 $face = $face|0;
 $charcode = $charcode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($face|0)==(0|0);
 if ($0) {
  $result$0 = 0;
 } else {
  $1 = (($face) + 92|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if ($3) {
   $result$0 = 0;
  } else {
   $4 = (($2) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (FUNCTION_TABLE_iii[$7 & 4095]($2,$charcode)|0);
   $result$0 = $8;
  }
 }
 STACKTOP = sp;return ($result$0|0);
}
function _FT_New_Face($library,$pathname,$face_index,$aface) {
 $library = $library|0;
 $pathname = $pathname|0;
 $face_index = $face_index|0;
 $aface = $aface|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $args = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $args = sp;
 $0 = ($pathname|0)==(0|0);
 if ($0) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$args>>2] = 4;
 $1 = (($args) + 12|0);
 HEAP32[$1>>2] = $pathname;
 $2 = (($args) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (_FT_Open_Face($library,$args,$face_index,$aface)|0);
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Open_Face($library,$args,$face_index,$aface) {
 $library = $library|0;
 $args = $args|0;
 $face_index = $face_index|0;
 $aface = $aface|0;
 var $$0 = 0, $$0$i$i = 0, $$not = 0, $$not$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre21 = 0, $$pre22$pre$pre = 0, $$pre2237 = 0, $$pre2238 = 0, $$pre39 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $args2$i$i = 0, $cur$018 = 0, $error = 0, $error$0$i$i15 = 0, $error$0$i7 = 0, $error$0$i79 = 0, $error$1$i = 0, $error$1$i$i = 0, $error$2$$i$i = 0, $error$2$i$i = 0, $errors$i$i = 0, $face = 0, $file_names$i$i = 0, $header$i$i = 0, $i$0$i$i12 = 0, $i$010 = 0, $num_params$0 = 0;
 var $num_params1$0 = 0, $offsets$i$i = 0, $or$cond = 0, $or$cond$i$i = 0, $or$cond$i1$i = 0, $or$cond1 = 0, $or$cond1$i$i = 0, $params$0 = 0, $params2$0 = 0, $phitmp = 0, $sext = 0, $size = 0, $stream = 0, $stream2$i$i = 0, $vfs_rfork_has_no_font$0$i$i14 = 0, $vfs_rfork_has_no_font$1$$i$i = 0, $vfs_rfork_has_no_font$1$i$i = 0, $vfs_rfork_has_no_font$2$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $header$i$i = sp + 168|0;
 $file_names$i$i = sp + 128|0;
 $offsets$i$i = sp + 92|0;
 $errors$i$i = sp + 56|0;
 $args2$i$i = sp + 24|0;
 $stream2$i$i = sp + 16|0;
 $error = sp + 8|0;
 $stream = sp + 4|0;
 $face = sp;
 $size = sp + 12|0;
 HEAP32[$stream>>2] = 0;
 HEAP32[$face>>2] = 0;
 $0 = ($aface|0)!=(0|0);
 $$not = $0 ^ 1;
 $1 = ($face_index|0)>(-1);
 $or$cond = $1 & $$not;
 $2 = ($args|0)==(0|0);
 $or$cond1 = $or$cond | $2;
 if ($or$cond1) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$args>>2]|0;
 $4 = $3 & 2;
 $5 = ($4|0)==(0);
 if ($5) {
  $36 = 0;
 } else {
  $6 = (($args) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)!=(0|0);
  $phitmp = $8&1;
  $36 = $phitmp;
 }
 $9 = (_FT_Stream_New($library,$args,$stream)|0);
 HEAP32[$error>>2] = $9;
 $10 = ($9|0)==(0);
 L7: do {
  if ($10) {
   $11 = HEAP32[$library>>2]|0;
   $12 = HEAP32[$args>>2]|0;
   $13 = $12 & 8;
   $14 = ($13|0)==(0);
   do {
    if ($14) {
     label = 15;
    } else {
     $15 = (($args) + 20|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      label = 15;
     } else {
      $18 = HEAP32[$16>>2]|0;
      $19 = HEAP32[$18>>2]|0;
      $20 = $19 & 1;
      $21 = ($20|0)==(0);
      if ($21) {
       HEAP32[$error>>2] = 32;
       $$pre21 = HEAP32[$stream>>2]|0;
       $32 = $$pre21;
      } else {
       $22 = $12 & 16;
       $23 = ($22|0)==(0);
       if ($23) {
        $num_params$0 = 0;$params$0 = 0;
       } else {
        $24 = (($args) + 24|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = (($args) + 28|0);
        $27 = HEAP32[$26>>2]|0;
        $num_params$0 = $25;$params$0 = $27;
       }
       $28 = HEAP32[$stream>>2]|0;
       $29 = (_open_face($16,$28,$face_index,$num_params$0,$params$0,$face)|0);
       HEAP32[$error>>2] = $29;
       $30 = ($29|0)==(0);
       if ($30) {
        break;
       } else {
        $32 = $28;
       }
      }
      $31 = ($32|0)==(0|0);
      if ($31) {
       label = 100;
       break L7;
      }
      $33 = (($32) + 28|0);
      $34 = HEAP32[$33>>2]|0;
      _FT_Stream_Close($32);
      $35 = ($36<<24>>24)==(0);
      if (!($35)) {
       label = 100;
       break L7;
      }
      _ft_mem_free($34,$32);
      label = 100;
      break L7;
     }
    }
   } while(0);
   L21: do {
    if ((label|0) == 15) {
     $37 = (($library) + 24|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = ((($library) + ($38<<2)|0) + 28|0);
     $40 = ($38|0)>(0);
     if (!($40)) {
      label = 33;
      break L7;
     }
     $41 = (($library) + 28|0);
     $42 = (($args) + 24|0);
     $43 = (($args) + 28|0);
     $$pre2238 = 0;$cur$018 = $41;
     while(1) {
      $44 = HEAP32[$cur$018>>2]|0;
      $45 = HEAP32[$44>>2]|0;
      $46 = HEAP32[$45>>2]|0;
      $47 = $46 & 1;
      $48 = ($47|0)==(0);
      if ($48) {
       $$pre2237 = $$pre2238;
      } else {
       $49 = HEAP32[$args>>2]|0;
       $50 = $49 & 16;
       $51 = ($50|0)==(0);
       if ($51) {
        $num_params1$0 = 0;$params2$0 = 0;
       } else {
        $52 = HEAP32[$42>>2]|0;
        $53 = HEAP32[$43>>2]|0;
        $num_params1$0 = $52;$params2$0 = $53;
       }
       $54 = HEAP32[$stream>>2]|0;
       $55 = (_open_face($44,$54,$face_index,$num_params1$0,$params2$0,$face)|0);
       HEAP32[$error>>2] = $55;
       $56 = ($55|0)==(0);
       if ($56) {
        break L21;
       }
       $57 = HEAP32[$cur$018>>2]|0;
       $58 = HEAP32[$57>>2]|0;
       $59 = (($58) + 8|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = (_strcmp($60,806440)|0);
       $62 = ($61|0)==(0);
       if ($62) {
        $63 = $55 & 255;
        $64 = ($63|0)==(142);
        if ($64) {
         $65 = (_FT_Stream_Seek($54,0)|0);
         $66 = ($65|0)==(0);
         if (!($66)) {
          label = 24;
          break;
         }
         $67 = (_open_face_PS_from_sfnt_stream($library,$54,$face_index,0,0,$aface)|0);
         HEAP32[$error>>2] = $67;
         $68 = ($67|0)==(0);
         if ($68) {
          break;
         } else {
          $75 = $67;
         }
        } else {
         $75 = $55;
        }
       } else {
        $75 = $55;
       }
       $74 = $75 & 255;
       $76 = ($74|0)==(2);
       if ($76) {
        $$pre2237 = $75;
       } else {
        $80 = $75;
        label = 32;
        break L7;
       }
      }
      $77 = (($cur$018) + 4|0);
      $78 = ($77>>>0)<($39>>>0);
      if ($78) {
       $$pre2238 = $$pre2237;$cur$018 = $77;
      } else {
       $80 = $$pre2237;
       label = 32;
       break L7;
      }
     }
     if ((label|0) == 24) {
      $$pre22$pre$pre = HEAP32[$error>>2]|0;
      $80 = $$pre22$pre$pre;
      label = 32;
      break L7;
     }
     $69 = ($54|0)==(0|0);
     if (!($69)) {
      $70 = (($54) + 28|0);
      $71 = HEAP32[$70>>2]|0;
      _FT_Stream_Close($54);
      $72 = ($36<<24>>24)==(0);
      if ($72) {
       _ft_mem_free($71,$54);
      }
     }
     $73 = HEAP32[$error>>2]|0;
     $$0 = $73;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $181 = ($36<<24>>24)==(0);
   if (!($181)) {
    $182 = HEAP32[$face>>2]|0;
    $183 = (($182) + 8|0);
    $184 = HEAP32[$183>>2]|0;
    $185 = $184 | 1024;
    HEAP32[$183>>2] = $185;
   }
   $186 = (_ft_mem_alloc($11,12,$error)|0);
   $187 = HEAP32[$error>>2]|0;
   $188 = ($187|0)==(0);
   if ($188) {
    $189 = HEAP32[$face>>2]|0;
    $190 = (($186) + 8|0);
    HEAP32[$190>>2] = $189;
    $191 = (($189) + 96|0);
    $192 = HEAP32[$191>>2]|0;
    $193 = (($192) + 24|0);
    _FT_List_Add($193,$186);
    if ($1) {
     $194 = (_FT_New_GlyphSlot($189,0)|0);
     HEAP32[$error>>2] = $194;
     $195 = ($194|0)==(0);
     if (!($195)) {
      label = 100;
      break;
     }
     $196 = (_FT_New_Size($189,$size)|0);
     HEAP32[$error>>2] = $196;
     $197 = ($196|0)==(0);
     if (!($197)) {
      label = 100;
      break;
     }
     $198 = HEAP32[$size>>2]|0;
     $199 = (($189) + 88|0);
     HEAP32[$199>>2] = $198;
    }
    $200 = (($189) + 8|0);
    $201 = HEAP32[$200>>2]|0;
    $202 = $201 & 1;
    $203 = ($202|0)==(0);
    if (!($203)) {
     $204 = (($189) + 74|0);
     $205 = HEAP16[$204>>1]|0;
     $206 = ($205<<16>>16)<(0);
     if ($206) {
      $207 = $205&65535;
      $208 = (0 - ($207))|0;
      $209 = $208&65535;
      HEAP16[$204>>1] = $209;
      $213 = $209;
     } else {
      $213 = $205;
     }
     $210 = $201 & 32;
     $211 = ($210|0)==(0);
     if ($211) {
      $212 = (($189) + 78|0);
      HEAP16[$212>>1] = $213;
     }
    }
    $214 = $201 & 2;
    $215 = ($214|0)==(0);
    if (!($215)) {
     $216 = (($189) + 28|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = ($217|0)>(0);
     if ($218) {
      $$phi$trans$insert = (($189) + 32|0);
      $$pre = HEAP32[$$phi$trans$insert>>2]|0;
      $i$010 = 0;
      while(1) {
       $219 = (($$pre) + ($i$010<<4)|0);
       $220 = HEAP16[$219>>1]|0;
       $221 = ($220<<16>>16)<(0);
       if ($221) {
        $222 = $220&65535;
        $223 = (0 - ($222))|0;
        $224 = $223&65535;
        HEAP16[$219>>1] = $224;
       }
       $225 = ((($$pre) + ($i$010<<4)|0) + 8|0);
       $226 = HEAP32[$225>>2]|0;
       $227 = ($226|0)<(0);
       if ($227) {
        $228 = (0 - ($226))|0;
        $sext = $228 << 16;
        $229 = $sext >> 16;
        HEAP32[$225>>2] = $229;
       }
       $230 = ((($$pre) + ($i$010<<4)|0) + 12|0);
       $231 = HEAP32[$230>>2]|0;
       $232 = ($231|0)<(0);
       if ($232) {
        $233 = (0 - ($231))|0;
        HEAP32[$230>>2] = $233;
       }
       $234 = (($i$010) + 1)|0;
       $235 = ($234|0)<($217|0);
       if ($235) {
        $i$010 = $234;
       } else {
        break;
       }
      }
     }
    }
    $236 = (($189) + 128|0);
    $237 = HEAP32[$236>>2]|0;
    $238 = (($237) + 4|0);
    HEAP32[$238>>2] = 65536;
    $239 = (($237) + 8|0);
    HEAP32[$239>>2] = 0;
    $240 = (($237) + 12|0);
    HEAP32[$240>>2] = 0;
    $241 = (($237) + 16|0);
    HEAP32[$241>>2] = 65536;
    $242 = (($237) + 20|0);
    HEAP32[$242>>2] = 0;
    $243 = (($237) + 24|0);
    HEAP32[$243>>2] = 0;
    $244 = (($237) + 56|0);
    HEAP32[$244>>2] = 1;
    if ($0) {
     HEAP32[$aface>>2] = $189;
     break;
    }
    $245 = ($189|0)==(0|0);
    if (!($245)) {
     $246 = HEAP32[$191>>2]|0;
     $247 = ($246|0)==(0|0);
     if (!($247)) {
      HEAP32[$244>>2] = 0;
      $248 = (($246) + 8|0);
      $249 = HEAP32[$248>>2]|0;
      $250 = (($246) + 24|0);
      $251 = (_FT_List_Find($250,$189)|0);
      $252 = ($251|0)==(0|0);
      if (!($252)) {
       _FT_List_Remove($250,$251);
       _ft_mem_free($249,$251);
       _destroy_face($249,$189,$246);
      }
     }
    }
   } else {
    label = 100;
   }
  } else {
   $80 = $9;
   label = 32;
  }
 } while(0);
 do {
  if ((label|0) == 32) {
   $79 = $80 & 255;
   if ((($79|0) == 85) | (($79|0) == 2) | (($79|0) == 81)) {
    $81 = HEAP32[$stream>>2]|0;
    $82 = ($81|0)==(0|0);
    if ($82) {
     $error$0$i79 = 85;
     label = 47;
    } else {
     $83 = (_FT_Stream_Seek($81,0)|0);
     $84 = ($83|0)==(0);
     if ($84) {
      $85 = (_FT_Stream_Read($81,$header$i$i,128)|0);
      $86 = ($85|0)==(0);
      if ($86) {
       $87 = HEAP8[$header$i$i>>0]|0;
       $88 = ($87<<24>>24)==(0);
       if ($88) {
        $89 = (($header$i$i) + 74|0);
        $90 = HEAP8[$89>>0]|0;
        $91 = ($90<<24>>24)==(0);
        if ($91) {
         $92 = (($header$i$i) + 82|0);
         $93 = HEAP8[$92>>0]|0;
         $94 = ($93<<24>>24)==(0);
         if ($94) {
          $95 = (($header$i$i) + 1|0);
          $96 = HEAP8[$95>>0]|0;
          $97 = $96&255;
          $98 = ($96<<24>>24)==(0);
          $99 = ($96&255)>(33);
          $or$cond$i1$i = $98 | $99;
          if ($or$cond$i1$i) {
           label = 45;
          } else {
           $100 = (($header$i$i) + 63|0);
           $101 = HEAP8[$100>>0]|0;
           $102 = ($101<<24>>24)==(0);
           if ($102) {
            $103 = (($97) + 2)|0;
            $104 = (($header$i$i) + ($103)|0);
            $105 = HEAP8[$104>>0]|0;
            $106 = ($105<<24>>24)==(0);
            if ($106) {
             $107 = (($header$i$i) + 83|0);
             $108 = HEAP8[$107>>0]|0;
             $109 = $108&255;
             $110 = $109 << 24;
             $111 = (($header$i$i) + 84|0);
             $112 = HEAP8[$111>>0]|0;
             $113 = $112&255;
             $114 = $113 << 16;
             $115 = $114 | $110;
             $116 = (($header$i$i) + 85|0);
             $117 = HEAP8[$116>>0]|0;
             $118 = $117&255;
             $119 = $118 << 8;
             $120 = $115 | $119;
             $121 = (($header$i$i) + 86|0);
             $122 = HEAP8[$121>>0]|0;
             $123 = $122&255;
             $124 = $120 | $123;
             $125 = (($124) + 255)|0;
             $126 = $125 & -128;
             $127 = (_IsMacResource($library,$81,$126,$face_index,$aface)|0);
             $$0$i$i = $127;
             label = 44;
            } else {
             label = 45;
            }
           } else {
            label = 45;
           }
          }
         } else {
          label = 45;
         }
        } else {
         label = 45;
        }
       } else {
        label = 45;
       }
      } else {
       $$0$i$i = $85;
       label = 44;
      }
     } else {
      $$0$i$i = $83;
      label = 44;
     }
     if ((label|0) == 44) {
      $128 = $$0$i$i & 255;
      $129 = ($128|0)==(2);
      if ($129) {
       label = 45;
      } else {
       $error$0$i7 = $$0$i$i;
      }
     }
     if ((label|0) == 45) {
      $130 = (_IsMacResource($library,$81,0,$face_index,$aface)|0);
      $error$0$i7 = $130;
     }
     $131 = $error$0$i7 & 255;
     if ((($131|0) == 85) | (($131|0) == 2)) {
      $error$0$i79 = $error$0$i7;
      label = 47;
     } else {
      $error$1$i = $error$0$i7;
     }
    }
    if ((label|0) == 47) {
     $132 = HEAP32[$args>>2]|0;
     $133 = $132 & 4;
     $134 = ($133|0)==(0);
     if ($134) {
      $error$1$i = $error$0$i79;
     } else {
      $135 = HEAP32[$library>>2]|0;
      HEAP32[$stream2$i$i>>2] = 0;
      $136 = (($args) + 12|0);
      $137 = HEAP32[$136>>2]|0;
      _FT_Raccess_Guess($library,$81,$137,$file_names$i$i,$offsets$i$i,$errors$i$i);
      $138 = (($args2$i$i) + 12|0);
      $error$0$i$i15 = 2;$i$0$i$i12 = 0;$vfs_rfork_has_no_font$0$i$i14 = 0;
      while(1) {
       $139 = (_raccess_rule_by_darwin_vfs($i$0$i$i12)|0);
       $140 = ($139<<24>>24)!=(0);
       $$not$i$i = $140 ^ 1;
       $141 = ($vfs_rfork_has_no_font$0$i$i14<<24>>24)==(0);
       $or$cond$i$i = $141 | $$not$i$i;
       if ($or$cond$i$i) {
        $142 = (($errors$i$i) + ($i$0$i$i12<<2)|0);
        $143 = HEAP32[$142>>2]|0;
        $144 = ($143|0)==(0);
        if ($144) {
         HEAP32[$args2$i$i>>2] = 4;
         $145 = (($file_names$i$i) + ($i$0$i$i12<<2)|0);
         $146 = HEAP32[$145>>2]|0;
         $147 = ($146|0)==(0|0);
         if ($147) {
          $148 = HEAP32[$136>>2]|0;
          $149 = $148;
         } else {
          $149 = $146;
         }
         HEAP32[$138>>2] = $149;
         $150 = (_FT_Stream_New($library,$args2$i$i,$stream2$i$i)|0);
         $151 = ($150|0)==(81);
         $or$cond1$i$i = $140 & $151;
         $vfs_rfork_has_no_font$1$i$i = $or$cond1$i$i ? 1 : $vfs_rfork_has_no_font$0$i$i14;
         $152 = ($150|0)==(0);
         if ($152) {
          $153 = HEAP32[$stream2$i$i>>2]|0;
          $154 = (($offsets$i$i) + ($i$0$i$i12<<2)|0);
          $155 = HEAP32[$154>>2]|0;
          $156 = (_IsMacResource($library,$153,$155,$face_index,$aface)|0);
          $157 = ($153|0)==(0|0);
          if (!($157)) {
           $158 = (($153) + 28|0);
           $159 = HEAP32[$158>>2]|0;
           _FT_Stream_Close($153);
           _ft_mem_free($159,$153);
          }
          $160 = ($156|0)==(0);
          if ($160) {
           $error$2$i$i = 0;
           break;
          }
          $161 = ($139<<24>>24)==(0);
          $vfs_rfork_has_no_font$1$$i$i = $161 ? $vfs_rfork_has_no_font$1$i$i : 1;
          $error$1$i$i = $156;$vfs_rfork_has_no_font$2$i$i = $vfs_rfork_has_no_font$1$$i$i;
         } else {
          $error$1$i$i = $150;$vfs_rfork_has_no_font$2$i$i = $vfs_rfork_has_no_font$1$i$i;
         }
        } else {
         $error$1$i$i = $error$0$i$i15;$vfs_rfork_has_no_font$2$i$i = $vfs_rfork_has_no_font$0$i$i14;
        }
       } else {
        $error$1$i$i = $error$0$i$i15;$vfs_rfork_has_no_font$2$i$i = $vfs_rfork_has_no_font$0$i$i14;
       }
       $162 = (($i$0$i$i12) + 1)|0;
       $163 = ($162|0)<(9);
       if ($163) {
        $error$0$i$i15 = $error$1$i$i;$i$0$i$i12 = $162;$vfs_rfork_has_no_font$0$i$i14 = $vfs_rfork_has_no_font$2$i$i;
       } else {
        $error$2$i$i = $error$1$i$i;
        break;
       }
      }
      $164 = HEAP32[$file_names$i$i>>2]|0;
      $165 = ($164|0)==(0|0);
      if (!($165)) {
       _ft_mem_free($135,$164);
       HEAP32[$file_names$i$i>>2] = 0;
      }
      $166 = (($file_names$i$i) + 4|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = ($167|0)==(0|0);
      if (!($168)) {
       _ft_mem_free($135,$167);
       HEAP32[$166>>2] = 0;
      }
      $270 = (($file_names$i$i) + 8|0);
      $271 = HEAP32[$270>>2]|0;
      $272 = ($271|0)==(0|0);
      if (!($272)) {
       _ft_mem_free($135,$271);
       HEAP32[$270>>2] = 0;
      }
      $273 = (($file_names$i$i) + 12|0);
      $274 = HEAP32[$273>>2]|0;
      $275 = ($274|0)==(0|0);
      if (!($275)) {
       _ft_mem_free($135,$274);
       HEAP32[$273>>2] = 0;
      }
      $276 = (($file_names$i$i) + 16|0);
      $277 = HEAP32[$276>>2]|0;
      $278 = ($277|0)==(0|0);
      if (!($278)) {
       _ft_mem_free($135,$277);
       HEAP32[$276>>2] = 0;
      }
      $279 = (($file_names$i$i) + 20|0);
      $280 = HEAP32[$279>>2]|0;
      $281 = ($280|0)==(0|0);
      if (!($281)) {
       _ft_mem_free($135,$280);
       HEAP32[$279>>2] = 0;
      }
      $282 = (($file_names$i$i) + 24|0);
      $283 = HEAP32[$282>>2]|0;
      $284 = ($283|0)==(0|0);
      if (!($284)) {
       _ft_mem_free($135,$283);
       HEAP32[$282>>2] = 0;
      }
      $285 = (($file_names$i$i) + 28|0);
      $286 = HEAP32[$285>>2]|0;
      $287 = ($286|0)==(0|0);
      if (!($287)) {
       _ft_mem_free($135,$286);
       HEAP32[$285>>2] = 0;
      }
      $288 = (($file_names$i$i) + 32|0);
      $289 = HEAP32[$288>>2]|0;
      $290 = ($289|0)==(0|0);
      if (!($290)) {
       _ft_mem_free($135,$289);
       HEAP32[$288>>2] = 0;
      }
      $291 = ($error$2$i$i|0)==(0);
      $error$2$$i$i = $291 ? 0 : 2;
      $error$1$i = $error$2$$i$i;
     }
    }
    HEAP32[$error>>2] = $error$1$i;
    $169 = ($error$1$i|0)==(0);
    if (!($169)) {
     $174 = $error$1$i & 255;
     $175 = ($174|0)==(2);
     if (!($175)) {
      $177 = $81;
      label = 69;
      break;
     }
     HEAP32[$error>>2] = 2;
     $177 = $81;
     label = 69;
     break;
    }
    if (!($82)) {
     $170 = (($81) + 28|0);
     $171 = HEAP32[$170>>2]|0;
     _FT_Stream_Close($81);
     $172 = ($36<<24>>24)==(0);
     if ($172) {
      _ft_mem_free($171,$81);
     }
    }
    $173 = HEAP32[$error>>2]|0;
    $$0 = $173;
    STACKTOP = sp;return ($$0|0);
   } else {
    label = 33;
   }
  }
 } while(0);
 if ((label|0) == 33) {
  $$pre39 = HEAP32[$stream>>2]|0;
  $177 = $$pre39;
  label = 69;
 }
 if ((label|0) == 69) {
  $176 = ($177|0)==(0|0);
  if ($176) {
   label = 100;
  } else {
   $178 = (($177) + 28|0);
   $179 = HEAP32[$178>>2]|0;
   _FT_Stream_Close($177);
   $180 = ($36<<24>>24)==(0);
   if ($180) {
    _ft_mem_free($179,$177);
    label = 100;
   } else {
    label = 100;
   }
  }
 }
 if ((label|0) == 100) {
  $253 = HEAP32[$face>>2]|0;
  $254 = ($253|0)==(0|0);
  if (!($254)) {
   $255 = (($253) + 96|0);
   $256 = HEAP32[$255>>2]|0;
   $257 = ($256|0)==(0|0);
   if (!($257)) {
    $258 = (($253) + 128|0);
    $259 = HEAP32[$258>>2]|0;
    $260 = (($259) + 56|0);
    $261 = HEAP32[$260>>2]|0;
    $262 = (($261) + -1)|0;
    HEAP32[$260>>2] = $262;
    $263 = ($262|0)==(0);
    if ($263) {
     $264 = (($256) + 8|0);
     $265 = HEAP32[$264>>2]|0;
     $266 = (($256) + 24|0);
     $267 = (_FT_List_Find($266,$253)|0);
     $268 = ($267|0)==(0|0);
     if (!($268)) {
      _FT_List_Remove($266,$267);
      _ft_mem_free($265,$267);
      _destroy_face($265,$253,$256);
     }
    }
   }
  }
 }
 $269 = HEAP32[$error>>2]|0;
 $$0 = $269;
 STACKTOP = sp;return ($$0|0);
}
function _FT_New_Memory_Face($library,$file_base,$file_size,$face_index,$aface) {
 $library = $library|0;
 $file_base = $file_base|0;
 $file_size = $file_size|0;
 $face_index = $face_index|0;
 $aface = $aface|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $args = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $args = sp;
 $0 = ($file_base|0)==(0|0);
 if ($0) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$args>>2] = 1;
 $1 = (($args) + 4|0);
 HEAP32[$1>>2] = $file_base;
 $2 = (($args) + 8|0);
 HEAP32[$2>>2] = $file_size;
 $3 = (($args) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (_FT_Open_Face($library,$args,$face_index,$aface)|0);
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function _open_face_from_buffer($library,$base,$size,$face_index,$driver_name,$aface) {
 $library = $library|0;
 $base = $base|0;
 $size = $size|0;
 $face_index = $face_index|0;
 $driver_name = $driver_name|0;
 $aface = $aface|0;
 var $$0 = 0, $$0$i1 = 0, $$0$i2 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $cur$01$i = 0, $error$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $error$i = sp + 32|0;
 $args = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = ($library|0)==(0|0);
 if ($1) {
  $$0$i2 = 33;
 } else {
  $2 = ($base|0)==(0|0);
  if ($2) {
   $$0$i2 = 6;
  } else {
   $3 = (_ft_mem_alloc($0,40,$error$i)|0);
   $4 = HEAP32[$error$i>>2]|0;
   $5 = ($4|0)==(0);
   if ($5) {
    _FT_Stream_OpenMemory($3,$base,$size);
    $6 = (($3) + 24|0);
    HEAP32[$6>>2] = 3730;
    $$pre$i = HEAP32[$error$i>>2]|0;
    $7 = ($$pre$i|0)==(0);
    if ($7) {
     HEAP32[$args>>2] = 2;
     $8 = (($args) + 16|0);
     HEAP32[$8>>2] = $3;
     $9 = ($driver_name|0)==(0|0);
     if (!($9)) {
      HEAP32[$args>>2] = 10;
      $10 = (($library) + 24|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ((($library) + ($11<<2)|0) + 28|0);
      $13 = ($11|0)>(0);
      L8: do {
       if ($13) {
        $14 = (($library) + 28|0);
        $cur$01$i = $14;
        while(1) {
         $17 = HEAP32[$cur$01$i>>2]|0;
         $18 = HEAP32[$17>>2]|0;
         $19 = (($18) + 8|0);
         $20 = HEAP32[$19>>2]|0;
         $21 = (_strcmp($20,$driver_name)|0);
         $22 = ($21|0)==(0);
         $16 = (($cur$01$i) + 4|0);
         if ($22) {
          $$0$i1 = $17;
          break L8;
         }
         $15 = ($16>>>0)<($12>>>0);
         if ($15) {
          $cur$01$i = $16;
         } else {
          $$0$i1 = 0;
          break;
         }
        }
       } else {
        $$0$i1 = 0;
       }
      } while(0);
      $23 = (($args) + 20|0);
      HEAP32[$23>>2] = $$0$i1;
     }
     $24 = (_FT_Open_Face($library,$args,$face_index,$aface)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $26 = HEAP32[$aface>>2]|0;
      $27 = (($26) + 8|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = $28 & -1025;
      HEAP32[$27>>2] = $29;
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     } else {
      _FT_Stream_Close($3);
      _ft_mem_free($0,$3);
      $$0 = $24;
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     $$0$i2 = $$pre$i;
    }
   } else {
    $$0$i2 = $4;
   }
  }
 }
 _ft_mem_free($0,$base);
 $$0 = $$0$i2;
 STACKTOP = sp;return ($$0|0);
}
function _memory_stream_close($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$stream>>2]|0;
 _ft_mem_free($1,$2);
 $3 = (($stream) + 4|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$stream>>2] = 0;
 $4 = (($stream) + 24|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function _FT_Get_Module($library,$module_name) {
 $library = $library|0;
 $module_name = $module_name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cur$01 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($library|0)==(0|0);
 $1 = ($module_name|0)==(0|0);
 $or$cond = $0 | $1;
 L1: do {
  if ($or$cond) {
   $$0 = 0;
  } else {
   $2 = (($library) + 24|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ((($library) + ($3<<2)|0) + 28|0);
   $5 = ($3|0)>(0);
   if ($5) {
    $6 = (($library) + 28|0);
    $cur$01 = $6;
    while(1) {
     $9 = HEAP32[$cur$01>>2]|0;
     $10 = HEAP32[$9>>2]|0;
     $11 = (($10) + 8|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (_strcmp($12,$module_name)|0);
     $14 = ($13|0)==(0);
     $8 = (($cur$01) + 4|0);
     if ($14) {
      $$0 = $9;
      break L1;
     }
     $7 = ($8>>>0)<($4>>>0);
     if ($7) {
      $cur$01 = $8;
     } else {
      $$0 = 0;
      break;
     }
    }
   } else {
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _open_face_PS_from_sfnt_stream($library,$stream,$face_index,$num_params,$params,$aface) {
 $library = $library|0;
 $stream = $stream|0;
 $face_index = $face_index|0;
 $num_params = $num_params|0;
 $params = $params|0;
 $aface = $aface|0;
 var $$0$i$ph = 0, $$ph4 = 0, $$ph5 = 0, $$ph6 = 0, $$pr = 0, $$pre = 0, $$pre$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $error = 0, $error$i = 0, $i$02$i = 0, $or$cond$i = 0, $pstable_index$01$i = 0, $pstable_index$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp + 4|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_FT_Stream_Pos($stream)|0);
 $2 = (_FT_Stream_ReadULong($stream,$error$i)|0);
 $3 = HEAP32[$error$i>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $5 = ($2|0)==(1954115633);
   if ($5) {
    $6 = (_FT_Stream_ReadUShort($stream,$error$i)|0);
    $7 = HEAP32[$error$i>>2]|0;
    $8 = ($7|0)==(0);
    if ($8) {
     $9 = (_FT_Stream_Skip($stream,6)|0);
     HEAP32[$error$i>>2] = $9;
     $10 = ($9|0)==(0);
     if ($10) {
      $11 = $6&65535;
      $12 = ($6<<16>>16)==(0);
      if ($12) {
       $$0$i$ph = 142;
       label = 16;
      } else {
       $13 = ($face_index|0)>(-1);
       $14 = ($face_index|0)<(0);
       $51 = 0;$i$02$i = 0;$pstable_index$01$i = -1;
       while(1) {
        $17 = (_FT_Stream_ReadULong($stream,$error$i)|0);
        $18 = HEAP32[$error$i>>2]|0;
        $19 = ($18|0)==(0);
        if (!($19)) {
         $$0$i$ph = $18;
         label = 16;
         break L1;
        }
        $20 = (_FT_Stream_Skip($stream,4)|0);
        HEAP32[$error$i>>2] = $20;
        $21 = ($20|0)==(0);
        if (!($21)) {
         $$0$i$ph = $20;
         label = 16;
         break L1;
        }
        $22 = (_FT_Stream_ReadULong($stream,$error$i)|0);
        $23 = HEAP32[$error$i>>2]|0;
        $24 = ($23|0)==(0);
        if (!($24)) {
         $$0$i$ph = $23;
         label = 16;
         break L1;
        }
        $25 = (_FT_Stream_ReadULong($stream,$error$i)|0);
        $26 = HEAP32[$error$i>>2]|0;
        $27 = ($26|0)==(0);
        if (!($27)) {
         $$0$i$ph = $26;
         label = 16;
         break L1;
        }
        if ((($17|0) == 1128875040)) {
         $28 = (($pstable_index$01$i) + 1)|0;
         $29 = (($22) + 22)|0;
         $30 = (($25) + -22)|0;
         if ($14) {
          $$ph4 = $29;$$ph5 = $30;$$ph6 = 1;
          break;
         } else {
          $52 = 1;$53 = $29;$54 = $30;$pstable_index$1$i = $28;
         }
        } else if ((($17|0) == 1415139377)) {
         $31 = (($pstable_index$01$i) + 1)|0;
         $32 = (($22) + 24)|0;
         $33 = (($25) + -24)|0;
         if ($14) {
          $$ph4 = $32;$$ph5 = $33;$$ph6 = 0;
          break;
         } else {
          $52 = 0;$53 = $32;$54 = $33;$pstable_index$1$i = $31;
         }
        } else {
         $52 = $51;$53 = $22;$54 = $25;$pstable_index$1$i = $pstable_index$01$i;
        }
        $34 = ($pstable_index$1$i|0)==($face_index|0);
        $or$cond$i = $13 & $34;
        $16 = (($i$02$i) + 1)|0;
        if ($or$cond$i) {
         $$ph4 = $53;$$ph5 = $54;$$ph6 = $52;
         break;
        }
        $15 = ($16|0)<($11|0);
        if ($15) {
         $51 = $52;$i$02$i = $16;$pstable_index$01$i = $pstable_index$1$i;
        } else {
         $$0$i$ph = 142;
         label = 16;
         break L1;
        }
       }
       HEAP32[$error>>2] = 0;
       $35 = (($$ph4) + ($1))|0;
       $36 = (_FT_Stream_Seek($stream,$35)|0);
       $37 = ($36|0)==(0);
       if (!($37)) {
        $$pr = HEAP32[$error>>2]|0;
        $48 = $$pr;
        break;
       }
       $38 = (_ft_mem_alloc($0,$$ph5,$error)|0);
       $39 = HEAP32[$error>>2]|0;
       $40 = ($39|0)==(0);
       if ($40) {
        $41 = (_FT_Stream_Read($stream,$38,$$ph5)|0);
        HEAP32[$error>>2] = $41;
        $42 = ($41|0)==(0);
        if ($42) {
         $43 = $14 ? $face_index : 0;
         $44 = ($$ph6<<24>>24)!=(0);
         $45 = $44 ? 806424 : 806432;
         $46 = (_open_face_from_buffer($library,$38,$$ph5,$43,$45,$aface)|0);
         HEAP32[$error>>2] = $46;
         $48 = $46;
        } else {
         $48 = $41;
        }
       } else {
        $48 = $39;
       }
      }
     } else {
      $$0$i$ph = $9;
      label = 16;
     }
    } else {
     $$0$i$ph = $7;
     label = 16;
    }
   } else {
    $$0$i$ph = 2;
    label = 16;
   }
  } else {
   $$0$i$ph = $3;
   label = 16;
  }
 } while(0);
 if ((label|0) == 16) {
  HEAP32[$error>>2] = $$0$i$ph;
  $48 = $$0$i$ph;
 }
 $47 = ($48|0)==(2);
 if ($47) {
  $49 = (_FT_Stream_Seek($stream,$1)|0);
  $50 = ($49|0)==(0);
  $$pre = HEAP32[$error>>2]|0;
  $$pre$ = $50 ? $$pre : $49;
  STACKTOP = sp;return ($$pre$|0);
 } else {
  STACKTOP = sp;return ($48|0);
 }
 return 0|0;
}
function _open_face($driver,$stream,$face_index,$num_params,$params,$aface) {
 $driver = $driver|0;
 $stream = $stream|0;
 $face_index = $face_index|0;
 $num_params = $num_params|0;
 $params = $params|0;
 $aface = $aface|0;
 var $$lcssa2$i = 0, $$pre = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $error = 0, $internal$06 = 0, $n$03$i = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($driver) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($driver) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 36|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_ft_mem_alloc($3,$5,$error)|0);
 $7 = HEAP32[$error>>2]|0;
 $8 = ($7|0)==(0);
 do {
  if ($8) {
   $9 = (_ft_mem_alloc($3,60,$error)|0);
   $10 = HEAP32[$error>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = (($6) + 128|0);
    HEAP32[$12>>2] = $9;
    $13 = (($6) + 96|0);
    HEAP32[$13>>2] = $driver;
    $14 = (($6) + 100|0);
    HEAP32[$14>>2] = $3;
    $15 = (($6) + 104|0);
    HEAP32[$15>>2] = $stream;
    $16 = (($1) + 48|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if (!($18)) {
     $19 = (FUNCTION_TABLE_iiiiii[$17 & 255]($stream,$6,$face_index,$num_params,$params)|0);
     HEAP32[$error>>2] = $19;
     $phitmp = ($19|0)==(0);
     if (!($phitmp)) {
      $internal$06 = $9;
      break;
     }
    }
    $20 = (($6) + 40|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     HEAP32[$aface>>2] = $6;
     $84 = 0;
     STACKTOP = sp;return ($84|0);
    }
    $23 = (($6) + 36|0);
    $24 = HEAP32[$23>>2]|0;
    $$sum$i = (($24) + -1)|0;
    $25 = ($$sum$i|0)<(0);
    L11: do {
     if (!($25)) {
      $26 = (($21) + ($$sum$i<<2)|0);
      $27 = $21;
      $29 = $26;
      L13: while(1) {
       $28 = HEAP32[$29>>2]|0;
       $30 = (($28) + 4|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($31|0)==(1970170211);
       do {
        if ($32) {
         $33 = (($28) + 8|0);
         $34 = HEAP16[$33>>1]|0;
         if ((($34<<16>>16) == 3)) {
          $35 = (($28) + 10|0);
          $36 = HEAP16[$35>>1]|0;
          $37 = ($36<<16>>16)==(10);
          if (!($37)) {
           break;
          }
         } else if ((($34<<16>>16) == 0)) {
          $38 = (($28) + 10|0);
          $39 = HEAP16[$38>>1]|0;
          $40 = ($39<<16>>16)==(4);
          if (!($40)) {
           break;
          }
         } else {
          break;
         }
         $41 = $29;
         $42 = (($41) - ($27))|0;
         $43 = ($42|0)>(60);
         if (!($43)) {
          label = 15;
          break L13;
         }
        }
       } while(0);
       $44 = (($29) + -4|0);
       $45 = ($44>>>0)<($21>>>0);
       if ($45) {
        $48 = $26;
        break;
       } else {
        $29 = $44;
       }
      }
      if ((label|0) == 15) {
       $46 = (($6) + 92|0);
       HEAP32[$46>>2] = $28;
       break;
      }
      while(1) {
       $47 = HEAP32[$48>>2]|0;
       $49 = (($47) + 4|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)==(1970170211);
       if ($51) {
        $52 = $48;
        $53 = (($52) - ($27))|0;
        $54 = ($53|0)>(60);
        if (!($54)) {
         break;
        }
       }
       $55 = (($48) + -4|0);
       $56 = ($55>>>0)<($21>>>0);
       if ($56) {
        break L11;
       } else {
        $48 = $55;
       }
      }
      $57 = (($6) + 92|0);
      HEAP32[$57>>2] = $47;
     }
    } while(0);
    HEAP32[$aface>>2] = $6;
    $84 = 0;
    STACKTOP = sp;return ($84|0);
   } else {
    $internal$06 = $9;
   }
  } else {
   $internal$06 = 0;
  }
 } while(0);
 $58 = ($6|0)==(0|0);
 if (!($58)) {
  $59 = (($6) + 36|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($60|0)>(0);
  $62 = (($6) + 40|0);
  $63 = HEAP32[$62>>2]|0;
  if ($61) {
   $65 = $63;$n$03$i = 0;
   while(1) {
    $64 = (($65) + ($n$03$i<<2)|0);
    $66 = HEAP32[$64>>2]|0;
    $67 = (($66) + 12|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = HEAP32[$66>>2]|0;
    $70 = (($69) + 100|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($68) + 8|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = ($73|0)==(0|0);
    if (!($74)) {
     FUNCTION_TABLE_vi[$73 & 4095]($66);
    }
    _ft_mem_free($71,$66);
    $75 = HEAP32[$62>>2]|0;
    $76 = (($75) + ($n$03$i<<2)|0);
    HEAP32[$76>>2] = 0;
    $77 = (($n$03$i) + 1)|0;
    $78 = HEAP32[$59>>2]|0;
    $79 = ($77|0)<($78|0);
    $80 = HEAP32[$62>>2]|0;
    if ($79) {
     $65 = $80;$n$03$i = $77;
    } else {
     $$lcssa2$i = $80;
     break;
    }
   }
  } else {
   $$lcssa2$i = $63;
  }
  _ft_mem_free($3,$$lcssa2$i);
  HEAP32[$62>>2] = 0;
  HEAP32[$59>>2] = 0;
 }
 $81 = (($1) + 52|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)==(0|0);
 if (!($83)) {
  FUNCTION_TABLE_vi[$82 & 4095]($6);
 }
 _ft_mem_free($3,$internal$06);
 _ft_mem_free($3,$6);
 HEAP32[$aface>>2] = 0;
 $$pre = HEAP32[$error>>2]|0;
 $84 = $$pre;
 STACKTOP = sp;return ($84|0);
}
function _FT_New_Size($face,$asize) {
 $face = $face|0;
 $asize = $asize|0;
 var $$0 = 0, $$pr2$pre = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $node$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = ($face|0)==(0|0);
 if ($0) {
  $$0 = 35;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($asize|0)==(0|0);
 if ($1) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($face) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 34;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$asize>>2] = 0;
 $5 = HEAP32[$2>>2]|0;
 $6 = (($5) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($face) + 100|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 40|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (_ft_mem_alloc($9,$11,$error)|0);
 $13 = HEAP32[$error>>2]|0;
 $14 = ($13|0)==(0);
 do {
  if ($14) {
   $15 = (_ft_mem_alloc($9,12,$error)|0);
   $16 = HEAP32[$error>>2]|0;
   $17 = ($16|0)==(0);
   if ($17) {
    HEAP32[$12>>2] = $face;
    $18 = (($12) + 40|0);
    HEAP32[$18>>2] = 0;
    $19 = (($7) + 56|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if (!($21)) {
     $22 = (FUNCTION_TABLE_ii[$20 & 4095]($12)|0);
     HEAP32[$error>>2] = $22;
     $23 = ($22|0)==(0);
     if (!($23)) {
      $node$03 = $15;
      break;
     }
    }
    HEAP32[$asize>>2] = $12;
    $24 = (($15) + 8|0);
    HEAP32[$24>>2] = $12;
    $25 = (($face) + 108|0);
    _FT_List_Add($25,$15);
    $$pr2$pre = HEAP32[$error>>2]|0;
    $26 = ($$pr2$pre|0)==(0);
    if ($26) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    } else {
     $node$03 = $15;
    }
   } else {
    $node$03 = $15;
   }
  } else {
   $node$03 = 0;
  }
 } while(0);
 _ft_mem_free($9,$node$03);
 _ft_mem_free($9,$12);
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Done_Face($face) {
 $face = $face|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($face|0)==(0|0);
 if ($0) {
  $error$0 = 35;
 } else {
  $1 = (($face) + 96|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if ($3) {
   $error$0 = 35;
  } else {
   $4 = (($face) + 128|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($5) + 56|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = (($2) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($2) + 24|0);
    $13 = (_FT_List_Find($12,$face)|0);
    $14 = ($13|0)==(0|0);
    if ($14) {
     $error$0 = 35;
    } else {
     _FT_List_Remove($12,$13);
     _ft_mem_free($11,$13);
     _destroy_face($11,$face,$2);
     $error$0 = 0;
    }
   } else {
    $error$0 = 0;
   }
  }
 }
 STACKTOP = sp;return ($error$0|0);
}
function _destroy_face($memory,$face,$driver) {
 $memory = $memory|0;
 $face = $face|0;
 $driver = $driver|0;
 var $$lcssa2$i = 0, $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($driver) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 120|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($face) + 116|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_vi[$3 & 4095]($6);
 }
 $7 = (($face) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = $8;
  while(1) {
   _FT_Done_GlyphSlot($10);
   $11 = HEAP32[$7>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    break;
   } else {
    $10 = $11;
   }
  }
 }
 $13 = (($face) + 108|0);
 _FT_List_Finalize($13,2060,$memory,$driver);
 $14 = (($face) + 88|0);
 HEAP32[$14>>2] = 0;
 $15 = (($face) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  FUNCTION_TABLE_vi[$16 & 4095]($face);
 }
 $18 = ($face|0)==(0|0);
 if (!($18)) {
  $19 = (($face) + 36|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)>(0);
  $22 = (($face) + 40|0);
  $23 = HEAP32[$22>>2]|0;
  if ($21) {
   $25 = $23;$n$03$i = 0;
   while(1) {
    $24 = (($25) + ($n$03$i<<2)|0);
    $26 = HEAP32[$24>>2]|0;
    $27 = (($26) + 12|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$26>>2]|0;
    $30 = (($29) + 100|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($28) + 8|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     FUNCTION_TABLE_vi[$33 & 4095]($26);
    }
    _ft_mem_free($31,$26);
    $35 = HEAP32[$22>>2]|0;
    $36 = (($35) + ($n$03$i<<2)|0);
    HEAP32[$36>>2] = 0;
    $37 = (($n$03$i) + 1)|0;
    $38 = HEAP32[$19>>2]|0;
    $39 = ($37|0)<($38|0);
    $40 = HEAP32[$22>>2]|0;
    if ($39) {
     $25 = $40;$n$03$i = $37;
    } else {
     $$lcssa2$i = $40;
     break;
    }
   }
  } else {
   $$lcssa2$i = $23;
  }
  _ft_mem_free($memory,$$lcssa2$i);
  HEAP32[$22>>2] = 0;
  HEAP32[$19>>2] = 0;
 }
 $41 = (($1) + 52|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)==(0|0);
 if (!($43)) {
  FUNCTION_TABLE_vi[$42 & 4095]($face);
 }
 $44 = (($face) + 104|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45|0)==(0|0);
 if (!($46)) {
  $47 = (($face) + 8|0);
  $48 = HEAP32[$47>>2]|0;
  $$lobit = $48 & 1024;
  $49 = (($45) + 28|0);
  $50 = HEAP32[$49>>2]|0;
  _FT_Stream_Close($45);
  $51 = ($$lobit|0)==(0);
  if ($51) {
   _ft_mem_free($50,$45);
  }
 }
 HEAP32[$44>>2] = 0;
 $52 = (($face) + 128|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(0|0);
 if ($54) {
  _ft_mem_free($memory,$face);
  STACKTOP = sp;return;
 }
 _ft_mem_free($memory,$53);
 HEAP32[$52>>2] = 0;
 _ft_mem_free($memory,$face);
 STACKTOP = sp;return;
}
function _destroy_size($memory,$size,$driver) {
 $memory = $memory|0;
 $size = $size|0;
 $driver = $driver|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($size) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  FUNCTION_TABLE_vi[$1 & 4095]($size);
 }
 $3 = (($driver) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  FUNCTION_TABLE_vi[$6 & 4095]($size);
 }
 $8 = (($size) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 _ft_mem_free($memory,$9);
 HEAP32[$8>>2] = 0;
 _ft_mem_free($memory,$size);
 STACKTOP = sp;return;
}
function _FT_Match_Size($face,$req,$ignore_width,$size_index) {
 $face = $face|0;
 $req = $req|0;
 $ignore_width = $ignore_width|0;
 $size_index = $size_index|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0 = 0, $i$0$lcssa1 = 0, $i$02 = 0, $i$02$us = 0;
 var $w$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 35;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[$req>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = 7;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($req) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 $9 = (($req) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 if ($8) {
  $24 = $10;
 } else {
  $11 = Math_imul($10, $7)|0;
  $12 = (($11) + 36)|0;
  $13 = (($12|0) / 72)&-1;
  $24 = $13;
 }
 $14 = (($req) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0);
 $17 = (($req) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 if ($16) {
  $25 = $18;
 } else {
  $19 = Math_imul($18, $15)|0;
  $20 = (($19) + 36)|0;
  $21 = (($20|0) / 72)&-1;
  $25 = $21;
 }
 $22 = ($10|0)==(0);
 $23 = ($18|0)==(0);
 $$ = $23 ? $24 : $25;
 $w$0 = $22 ? $$ : $24;
 $h$0 = $22 ? $25 : $$;
 $26 = (($w$0) + 32)|0;
 $27 = (($h$0) + 32)|0;
 $28 = (($face) + 28|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)>(0);
 if (!($30)) {
  $$0 = 23;
  STACKTOP = sp;return ($$0|0);
 }
 $31 = (($face) + 32|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($ignore_width<<24>>24)==(0);
 L16: do {
  if ($33) {
   $i$02$us = 0;
   while(1) {
    $34 = ((($32) + ($i$02$us<<4)|0) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + 32)|0;
    $37 = $36 ^ $27;
    $38 = ($37>>>0)>(63);
    if (!($38)) {
     $39 = ((($32) + ($i$02$us<<4)|0) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($40) + 32)|0;
     $42 = $41 ^ $26;
     $43 = ($42>>>0)>(63);
     if (!($43)) {
      $i$0$lcssa1 = $i$02$us;
      break L16;
     }
    }
    $44 = (($i$02$us) + 1)|0;
    $45 = ($44|0)<($29|0);
    if ($45) {
     $i$02$us = $44;
    } else {
     $$0 = 23;
     break;
    }
   }
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$02 = 0;
   while(1) {
    $46 = ((($32) + ($i$02<<4)|0) + 12|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + 32)|0;
    $49 = $48 ^ $27;
    $50 = ($49>>>0)>(63);
    if (!($50)) {
     $i$0$lcssa1 = $i$02;
     break L16;
    }
    $52 = (($i$02) + 1)|0;
    $53 = ($52|0)<($29|0);
    if ($53) {
     $i$02 = $52;
    } else {
     $$0 = 23;
     break;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $51 = ($size_index|0)==(0|0);
 if ($51) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$size_index>>2] = $i$0$lcssa1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _ft_synthesize_vertical_metrics($metrics,$advance) {
 $metrics = $metrics|0;
 $advance = $advance|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $height$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($metrics) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($metrics) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)<(0);
 if ($4) {
  $5 = ($1|0)<($3|0);
  $$ = $5 ? $3 : $1;
  $height$0 = $$;
 } else {
  $6 = ($3|0)>(0);
  $7 = $6 ? $3 : 0;
  $$1 = (($1) - ($7))|0;
  $height$0 = $$1;
 }
 $8 = ($advance|0)==(0);
 if ($8) {
  $9 = ($height$0*12)|0;
  $10 = (($9|0) / 10)&-1;
  $$0 = $10;
 } else {
  $$0 = $advance;
 }
 $11 = (($metrics) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($metrics) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14|0) / 2)&-1;
 $16 = (($12) - ($15))|0;
 $17 = (($metrics) + 20|0);
 HEAP32[$17>>2] = $16;
 $18 = (($$0) - ($height$0))|0;
 $19 = (($18|0) / 2)&-1;
 $20 = (($metrics) + 24|0);
 HEAP32[$20>>2] = $19;
 $21 = (($metrics) + 28|0);
 HEAP32[$21>>2] = $$0;
 STACKTOP = sp;return;
}
function _FT_Select_Metrics($face,$strike_index) {
 $face = $face|0;
 $strike_index = $strike_index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + ($strike_index<<4)|0) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 32)|0;
 $7 = $6 >>> 6;
 $8 = $7&65535;
 $9 = (($1) + 12|0);
 HEAP16[$9>>1] = $8;
 $10 = ((($3) + ($strike_index<<4)|0) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 32)|0;
 $13 = $12 >>> 6;
 $14 = $13&65535;
 $15 = (($1) + 14|0);
 HEAP16[$15>>1] = $14;
 $16 = (($face) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 & 1;
 $19 = ($18|0)==(0);
 if ($19) {
  $60 = (($1) + 16|0);
  HEAP32[$60>>2] = 65536;
  $61 = (($1) + 20|0);
  HEAP32[$61>>2] = 65536;
  $62 = HEAP32[$10>>2]|0;
  $63 = (($1) + 24|0);
  HEAP32[$63>>2] = $62;
  $64 = (($1) + 28|0);
  HEAP32[$64>>2] = 0;
  $65 = (($3) + ($strike_index<<4)|0);
  $66 = HEAP16[$65>>1]|0;
  $67 = $66 << 16 >> 16;
  $68 = $67 << 6;
  $69 = (($1) + 32|0);
  HEAP32[$69>>2] = $68;
  $70 = HEAP32[$4>>2]|0;
  $71 = (($1) + 36|0);
  HEAP32[$71>>2] = $70;
  STACKTOP = sp;return;
 } else {
  $20 = (($face) + 68|0);
  $21 = HEAP16[$20>>1]|0;
  $22 = $21&65535;
  $23 = (_FT_DivFix($5,$22)|0);
  $24 = (($1) + 16|0);
  HEAP32[$24>>2] = $23;
  $25 = HEAP32[$10>>2]|0;
  $26 = HEAP16[$20>>1]|0;
  $27 = $26&65535;
  $28 = (_FT_DivFix($25,$27)|0);
  $29 = (($1) + 20|0);
  HEAP32[$29>>2] = $28;
  $30 = (($face) + 70|0);
  $31 = HEAP16[$30>>1]|0;
  $32 = $31 << 16 >> 16;
  $33 = (_FT_MulFix($32,$28)|0);
  $34 = (($33) + 63)|0;
  $35 = $34 & -64;
  $36 = (($1) + 24|0);
  HEAP32[$36>>2] = $35;
  $37 = (($face) + 72|0);
  $38 = HEAP16[$37>>1]|0;
  $39 = $38 << 16 >> 16;
  $40 = HEAP32[$29>>2]|0;
  $41 = (_FT_MulFix($39,$40)|0);
  $42 = $41 & -64;
  $43 = (($1) + 28|0);
  HEAP32[$43>>2] = $42;
  $44 = (($face) + 74|0);
  $45 = HEAP16[$44>>1]|0;
  $46 = $45 << 16 >> 16;
  $47 = HEAP32[$29>>2]|0;
  $48 = (_FT_MulFix($46,$47)|0);
  $49 = (($48) + 32)|0;
  $50 = $49 & -64;
  $51 = (($1) + 32|0);
  HEAP32[$51>>2] = $50;
  $52 = (($face) + 76|0);
  $53 = HEAP16[$52>>1]|0;
  $54 = $53 << 16 >> 16;
  $55 = HEAP32[$24>>2]|0;
  $56 = (_FT_MulFix($54,$55)|0);
  $57 = (($56) + 32)|0;
  $58 = $57 & -64;
  $59 = (($1) + 36|0);
  HEAP32[$59>>2] = $58;
  STACKTOP = sp;return;
 }
}
function _FT_Request_Metrics($face,$req) {
 $face = $face|0;
 $req = $req|0;
 var $$pr = 0, $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$w$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $h$0 = 0, $h$1 = 0, $scaled_h$0 = 0, $scaled_h$0$ph = 0, $scaled_h$1 = 0, $scaled_w$0 = 0, $scaled_w$0$ph = 0, $scaled_w$1 = 0, $w$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = (($face) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;
  $136 = (($1) + 16|0);
  HEAP32[$136>>2] = 65536;
  $137 = (($1) + 20|0);
  HEAP32[$137>>2] = 65536;
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$req>>2]|0;
 L5: do {
  switch ($7|0) {
  case 2:  {
   $18 = (($face) + 60|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($face) + 52|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) - ($21))|0;
   $23 = (($face) + 64|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($face) + 56|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($24) - ($26))|0;
   $h$0 = $27;$w$0 = $22;
   label = 11;
   break;
  }
  case 4:  {
   $38 = (($req) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($1) + 16|0);
   HEAP32[$40>>2] = $39;
   $41 = (($req) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($1) + 20|0);
   HEAP32[$43>>2] = $42;
   $44 = ($39|0)==(0);
   if ($44) {
    HEAP32[$40>>2] = $42;
    $scaled_h$0$ph = 0;$scaled_w$0$ph = 0;
    label = 23;
    break L5;
   }
   $45 = ($42|0)==(0);
   if ($45) {
    HEAP32[$43>>2] = $39;
    $scaled_h$0$ph = 0;$scaled_w$0$ph = 0;
    label = 23;
   } else {
    $scaled_h$0$ph = 0;$scaled_w$0$ph = 0;
    label = 23;
   }
   break;
  }
  case 0:  {
   $8 = (($face) + 68|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = $9&65535;
   $h$0 = $10;$w$0 = $10;
   label = 11;
   break;
  }
  case 1:  {
   $11 = (($face) + 70|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = $12 << 16 >> 16;
   $14 = (($face) + 72|0);
   $15 = HEAP16[$14>>1]|0;
   $16 = $15 << 16 >> 16;
   $17 = (($13) - ($16))|0;
   $h$0 = $17;$w$0 = $17;
   label = 11;
   break;
  }
  case 3:  {
   $28 = (($face) + 76|0);
   $29 = HEAP16[$28>>1]|0;
   $30 = $29 << 16 >> 16;
   $31 = (($face) + 70|0);
   $32 = HEAP16[$31>>1]|0;
   $33 = $32 << 16 >> 16;
   $34 = (($face) + 72|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = $35 << 16 >> 16;
   $37 = (($33) - ($36))|0;
   $h$0 = $37;$w$0 = $30;
   label = 11;
   break;
  }
  default: {
   $h$0 = 0;$w$0 = 0;
   label = 11;
  }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $46 = ($w$0|0)<(0);
   $47 = (0 - ($w$0))|0;
   $$w$0 = $46 ? $47 : $w$0;
   $48 = ($h$0|0)<(0);
   $49 = (0 - ($h$0))|0;
   $h$1 = $48 ? $49 : $h$0;
   $50 = (($req) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ($51|0)==(0);
   $53 = (($req) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   if ($52) {
    $67 = $54;
   } else {
    $55 = Math_imul($54, $51)|0;
    $56 = (($55) + 36)|0;
    $57 = (($56|0) / 72)&-1;
    $67 = $57;
   }
   $58 = (($req) + 16|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($59|0)==(0);
   $61 = (($req) + 8|0);
   $62 = HEAP32[$61>>2]|0;
   if ($60) {
    $72 = $62;
   } else {
    $63 = Math_imul($62, $59)|0;
    $64 = (($63) + 36)|0;
    $65 = (($64|0) / 72)&-1;
    $72 = $65;
   }
   $66 = ($54|0)==(0);
   if ($66) {
    $81 = (_FT_DivFix($72,$h$1)|0);
    $82 = (($1) + 20|0);
    HEAP32[$82>>2] = $81;
    $83 = (($1) + 16|0);
    HEAP32[$83>>2] = $81;
    $84 = (_FT_MulDiv($72,$$w$0,$h$1)|0);
    $scaled_h$0$ph = $72;$scaled_w$0$ph = $84;
    label = 23;
    break;
   }
   $68 = (_FT_DivFix($67,$$w$0)|0);
   $69 = (($1) + 16|0);
   HEAP32[$69>>2] = $68;
   $70 = HEAP32[$61>>2]|0;
   $71 = ($70|0)==(0);
   if ($71) {
    $79 = (($1) + 20|0);
    HEAP32[$79>>2] = $68;
    $80 = (_FT_MulDiv($67,$h$1,$$w$0)|0);
    $scaled_h$0$ph = $80;$scaled_w$0$ph = $67;
    label = 23;
    break;
   }
   $73 = (_FT_DivFix($72,$h$1)|0);
   $74 = (($1) + 20|0);
   HEAP32[$74>>2] = $73;
   $75 = HEAP32[$req>>2]|0;
   $76 = ($75|0)==(3);
   if ($76) {
    $77 = HEAP32[$69>>2]|0;
    $78 = ($73|0)>($77|0);
    if ($78) {
     HEAP32[$74>>2] = $77;
     $scaled_h$0$ph = $72;$scaled_w$0$ph = $67;
     label = 23;
     break;
    } else {
     HEAP32[$69>>2] = $73;
     $scaled_h$0$ph = $72;$scaled_w$0$ph = $67;
     label = 23;
     break;
    }
   } else {
    $86 = $75;$scaled_h$0 = $72;$scaled_w$0 = $67;
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $$pr = HEAP32[$req>>2]|0;
  $86 = $$pr;$scaled_h$0 = $scaled_h$0$ph;$scaled_w$0 = $scaled_w$0$ph;
 }
 $85 = ($86|0)==(0);
 if ($85) {
  $$pre = (($1) + 20|0);
  $$pre1 = (($1) + 16|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;$scaled_h$1 = $scaled_h$0;$scaled_w$1 = $scaled_w$0;
 } else {
  $87 = (($face) + 68|0);
  $88 = HEAP16[$87>>1]|0;
  $89 = $88&65535;
  $90 = (($1) + 16|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (_FT_MulFix($89,$91)|0);
  $93 = HEAP16[$87>>1]|0;
  $94 = $93&65535;
  $95 = (($1) + 20|0);
  $96 = HEAP32[$95>>2]|0;
  $97 = (_FT_MulFix($94,$96)|0);
  $$pre$phi2Z2D = $90;$$pre$phiZ2D = $95;$scaled_h$1 = $97;$scaled_w$1 = $92;
 }
 $98 = (($scaled_w$1) + 32)|0;
 $99 = $98 >>> 6;
 $100 = $99&65535;
 HEAP16[$2>>1] = $100;
 $101 = (($scaled_h$1) + 32)|0;
 $102 = $101 >>> 6;
 $103 = $102&65535;
 $104 = (($1) + 14|0);
 HEAP16[$104>>1] = $103;
 $105 = (($face) + 70|0);
 $106 = HEAP16[$105>>1]|0;
 $107 = $106 << 16 >> 16;
 $108 = HEAP32[$$pre$phiZ2D>>2]|0;
 $109 = (_FT_MulFix($107,$108)|0);
 $110 = (($109) + 63)|0;
 $111 = $110 & -64;
 $112 = (($1) + 24|0);
 HEAP32[$112>>2] = $111;
 $113 = (($face) + 72|0);
 $114 = HEAP16[$113>>1]|0;
 $115 = $114 << 16 >> 16;
 $116 = HEAP32[$$pre$phiZ2D>>2]|0;
 $117 = (_FT_MulFix($115,$116)|0);
 $118 = $117 & -64;
 $119 = (($1) + 28|0);
 HEAP32[$119>>2] = $118;
 $120 = (($face) + 74|0);
 $121 = HEAP16[$120>>1]|0;
 $122 = $121 << 16 >> 16;
 $123 = HEAP32[$$pre$phiZ2D>>2]|0;
 $124 = (_FT_MulFix($122,$123)|0);
 $125 = (($124) + 32)|0;
 $126 = $125 & -64;
 $127 = (($1) + 32|0);
 HEAP32[$127>>2] = $126;
 $128 = (($face) + 76|0);
 $129 = HEAP16[$128>>1]|0;
 $130 = $129 << 16 >> 16;
 $131 = HEAP32[$$pre$phi2Z2D>>2]|0;
 $132 = (_FT_MulFix($130,$131)|0);
 $133 = (($132) + 32)|0;
 $134 = $133 & -64;
 $135 = (($1) + 36|0);
 HEAP32[$135>>2] = $134;
 STACKTOP = sp;return;
}
function _FT_Request_Size($face,$req) {
 $face = $face|0;
 $req = $req|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0$i = 0, $i$02$us$i = 0, $or$cond = 0, $w$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($face|0)==(0|0);
 L1: do {
  if ($0) {
   $$0 = 35;
  } else {
   $1 = ($req|0)==(0|0);
   if ($1) {
    $$0 = 6;
   } else {
    $2 = (($req) + 4|0);
    $3 = HEAP32[$2>>2]|0;
    $4 = ($3|0)<(0);
    if ($4) {
     $$0 = 6;
    } else {
     $5 = (($req) + 8|0);
     $6 = HEAP32[$5>>2]|0;
     $7 = ($6|0)<(0);
     if ($7) {
      $$0 = 6;
     } else {
      $8 = HEAP32[$req>>2]|0;
      $9 = ($8>>>0)>(4);
      if ($9) {
       $$0 = 6;
      } else {
       $10 = (($face) + 96|0);
       $11 = HEAP32[$10>>2]|0;
       $12 = (($11) + 20|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = (($13) + 96|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = ($15|0)==(0|0);
       if (!($16)) {
        $17 = (($face) + 88|0);
        $18 = HEAP32[$17>>2]|0;
        $19 = (FUNCTION_TABLE_iii[$15 & 4095]($18,$req)|0);
        $$0 = $19;
        break;
       }
       $20 = (($face) + 8|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = $21 & 3;
       $23 = ($22|0)==(2);
       if (!($23)) {
        _FT_Request_Metrics($face,$req);
        $$0 = 0;
        break;
       }
       $24 = $21 & 2;
       $25 = ($24|0)==(0);
       if ($25) {
        $$0 = 35;
       } else {
        $26 = ($8|0)==(0);
        if ($26) {
         $27 = (($req) + 12|0);
         $28 = HEAP32[$27>>2]|0;
         $29 = ($28|0)==(0);
         if ($29) {
          $41 = $3;
         } else {
          $30 = Math_imul($28, $3)|0;
          $31 = (($30) + 36)|0;
          $32 = (($31|0) / 72)&-1;
          $41 = $32;
         }
         $33 = (($req) + 16|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = ($34|0)==(0);
         if ($35) {
          $42 = $6;
         } else {
          $36 = Math_imul($6, $34)|0;
          $37 = (($36) + 36)|0;
          $38 = (($37|0) / 72)&-1;
          $42 = $38;
         }
         $39 = ($3|0)==(0);
         $40 = ($6|0)==(0);
         $$$i = $40 ? $41 : $42;
         $w$0$i = $39 ? $$$i : $41;
         $h$0$i = $39 ? $42 : $$$i;
         $43 = (($w$0$i) + 32)|0;
         $44 = (($h$0$i) + 32)|0;
         $45 = (($face) + 28|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = ($46|0)>(0);
         if ($47) {
          $48 = (($face) + 32|0);
          $49 = HEAP32[$48>>2]|0;
          $i$02$us$i = 0;
          while(1) {
           $50 = ((($49) + ($i$02$us$i<<4)|0) + 12|0);
           $51 = HEAP32[$50>>2]|0;
           $52 = (($51) + 32)|0;
           $53 = $52 ^ $44;
           $54 = ($53>>>0)>(63);
           if (!($54)) {
            $55 = ((($49) + ($i$02$us$i<<4)|0) + 8|0);
            $56 = HEAP32[$55>>2]|0;
            $57 = (($56) + 32)|0;
            $58 = $57 ^ $43;
            $59 = ($58>>>0)>(63);
            if (!($59)) {
             break;
            }
           }
           $60 = (($i$02$us$i) + 1)|0;
           $61 = ($60|0)<($46|0);
           if ($61) {
            $i$02$us$i = $60;
           } else {
            $$0 = 23;
            break L1;
           }
          }
          $62 = ($i$02$us$i|0)>(-1);
          $63 = ($46|0)>($i$02$us$i|0);
          $or$cond = $62 & $63;
          if ($or$cond) {
           $64 = (($13) + 100|0);
           $65 = HEAP32[$64>>2]|0;
           $66 = ($65|0)==(0|0);
           if ($66) {
            _FT_Select_Metrics($face,$i$02$us$i);
            $$0 = 0;
            break;
           } else {
            $67 = (($face) + 88|0);
            $68 = HEAP32[$67>>2]|0;
            $69 = (FUNCTION_TABLE_iii[$65 & 4095]($68,$i$02$us$i)|0);
            $$0 = $69;
            break;
           }
          } else {
           $$0 = 6;
          }
         } else {
          $$0 = 23;
         }
        } else {
         $$0 = 7;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _FT_Set_Char_Size($face,$char_width,$char_height,$horz_resolution,$vert_resolution) {
 $face = $face|0;
 $char_width = $char_width|0;
 $char_height = $char_height|0;
 $horz_resolution = $horz_resolution|0;
 $vert_resolution = $vert_resolution|0;
 var $$$0 = 0, $$$01 = 0, $$$05 = 0, $$0 = 0, $$01 = 0, $$03 = 0, $$05 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $char_width$char_height = 0, $horz_resolution$vert_resolution = 0, $req = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $req = sp;
 $0 = ($char_width|0)==(0);
 if ($0) {
  $$03 = $char_height;$$05 = $char_height;
 } else {
  $1 = ($char_height|0)==(0);
  $char_width$char_height = $1 ? $char_width : $char_height;
  $$03 = $char_width$char_height;$$05 = $char_width;
 }
 $2 = ($horz_resolution|0)==(0);
 if ($2) {
  $$0 = $vert_resolution;$$01 = $vert_resolution;
 } else {
  $3 = ($vert_resolution|0)==(0);
  $horz_resolution$vert_resolution = $3 ? $horz_resolution : $vert_resolution;
  $$0 = $horz_resolution$vert_resolution;$$01 = $horz_resolution;
 }
 $4 = ($$05|0)<(64);
 $$$05 = $4 ? 64 : $$05;
 $5 = ($$03|0)<(64);
 $$14 = $5 ? 64 : $$03;
 $6 = ($$01|0)==(0);
 $$$01 = $6 ? 72 : $$01;
 $$$0 = $6 ? 72 : $$0;
 HEAP32[$req>>2] = 0;
 $7 = (($req) + 4|0);
 HEAP32[$7>>2] = $$$05;
 $8 = (($req) + 8|0);
 HEAP32[$8>>2] = $$14;
 $9 = (($req) + 12|0);
 HEAP32[$9>>2] = $$$01;
 $10 = (($req) + 16|0);
 HEAP32[$10>>2] = $$$0;
 $11 = (_FT_Request_Size($face,$req)|0);
 STACKTOP = sp;return ($11|0);
}
function _FT_Set_Pixel_Sizes($face,$pixel_width,$pixel_height) {
 $face = $face|0;
 $pixel_width = $pixel_width|0;
 $pixel_height = $pixel_height|0;
 var $$$01 = 0, $$$01$op = 0, $$0 = 0, $$01 = 0, $$1 = 0, $$1$op = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pixel_width$pixel_height = 0;
 var $req = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $req = sp;
 $0 = ($pixel_width|0)==(0);
 if ($0) {
  $$0 = $pixel_height;$$01 = $pixel_height;
 } else {
  $1 = ($pixel_height|0)==(0);
  $pixel_width$pixel_height = $1 ? $pixel_width : $pixel_height;
  $$0 = $pixel_width$pixel_height;$$01 = $pixel_width;
 }
 $2 = ($$01|0)==(0);
 $$$01 = $2 ? 1 : $$01;
 $3 = ($$0|0)==(0);
 $$1 = $3 ? 1 : $$0;
 $4 = ($$$01>>>0)<(65535);
 $5 = ($$1>>>0)<(65535);
 HEAP32[$req>>2] = 0;
 $$$01$op = $$$01 << 6;
 $6 = $4 ? $$$01$op : 4194240;
 $7 = (($req) + 4|0);
 HEAP32[$7>>2] = $6;
 $$1$op = $$1 << 6;
 $8 = $5 ? $$1$op : 4194240;
 $9 = (($req) + 8|0);
 HEAP32[$9>>2] = $8;
 $10 = (($req) + 12|0);
 HEAP32[$10>>2] = 0;
 $11 = (($req) + 16|0);
 HEAP32[$11>>2] = 0;
 $12 = (_FT_Request_Size($face,$req)|0);
 STACKTOP = sp;return ($12|0);
}
function _FT_CMap_New($clazz,$init_data,$charmap,$acmap) {
 $clazz = $clazz|0;
 $init_data = $init_data|0;
 $charmap = $charmap|0;
 $acmap = $acmap|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cmap$0 = 0, $error = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = ($clazz|0)==(0|0);
 $1 = ($charmap|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP32[$charmap>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($2) + 100|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$clazz>>2]|0;
 $7 = (_ft_mem_alloc($5,$6,$error)|0);
 $8 = HEAP32[$error>>2]|0;
 $9 = ($8|0)==(0);
 do {
  if ($9) {
   ;HEAP32[$7+0>>2]=HEAP32[$charmap+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$charmap+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$charmap+8>>2]|0;
   $10 = (($7) + 12|0);
   HEAP32[$10>>2] = $clazz;
   $11 = (($clazz) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    label = 6;
   } else {
    $14 = (FUNCTION_TABLE_iii[$12 & 4095]($7,$init_data)|0);
    HEAP32[$error>>2] = $14;
    $15 = ($14|0)==(0);
    if ($15) {
     label = 6;
    }
   }
   if ((label|0) == 6) {
    $16 = (($2) + 36|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 1)|0;
    $19 = (($2) + 40|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (_ft_mem_realloc($5,4,$17,$18,$20,$error)|0);
    HEAP32[$19>>2] = $21;
    $22 = HEAP32[$error>>2]|0;
    $23 = ($22|0)==(0);
    if ($23) {
     $24 = HEAP32[$16>>2]|0;
     $25 = (($24) + 1)|0;
     HEAP32[$16>>2] = $25;
     $26 = (($21) + ($24<<2)|0);
     HEAP32[$26>>2] = $7;
     $cmap$0 = $7;
     break;
    }
   }
   $29 = HEAP32[$10>>2]|0;
   $30 = HEAP32[$7>>2]|0;
   $31 = (($30) + 100|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($29) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    FUNCTION_TABLE_vi[$34 & 4095]($7);
   }
   _ft_mem_free($32,$7);
   $cmap$0 = 0;
  } else {
   $cmap$0 = $7;
  }
 } while(0);
 $27 = ($acmap|0)==(0|0);
 if (!($27)) {
  HEAP32[$acmap>>2] = $cmap$0;
 }
 $28 = HEAP32[$error>>2]|0;
 $$0 = $28;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Get_Glyph_Name($face,$glyph_index,$buffer,$buffer_max) {
 $face = $face|0;
 $glyph_index = $glyph_index|0;
 $buffer = $buffer|0;
 $buffer_max = $buffer_max|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, $magicptr = 0, $or$cond = 0, $svc$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buffer|0)==(0|0);
 $1 = ($buffer_max|0)==(0);
 $or$cond = $0 | $1;
 if (!($or$cond)) {
  HEAP8[$buffer>>0] = 0;
 }
 $2 = ($face|0)==(0|0);
 L4: do {
  if ($2) {
   $error$0 = 6;
  } else {
   $3 = (($face) + 16|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)<($glyph_index|0);
   if ($5) {
    $error$0 = 6;
   } else {
    $6 = (($face) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = $7 & 512;
    $9 = ($8|0)==(0);
    if ($9) {
     $error$0 = 6;
    } else {
     $10 = (($face) + 128|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($11) + 40|0);
     $13 = HEAP32[$12>>2]|0;
     $magicptr = $13;
     do {
      if ((($magicptr|0) == -2)) {
       $error$0 = 6;
       break L4;
      } else if ((($magicptr|0) == 0)) {
       $14 = (($face) + 96|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = HEAP32[$15>>2]|0;
       $17 = (($16) + 32|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = ($18|0)==(0|0);
       if ($19) {
        HEAP32[$12>>2] = (-2);
        $error$0 = 6;
        break L4;
       } else {
        $20 = (FUNCTION_TABLE_iii[$18 & 4095]($15,806456)|0);
        $21 = ($20|0)!=(0|0);
        $22 = $21 ? $20 : (-2);
        $23 = HEAP32[$10>>2]|0;
        $24 = (($23) + 40|0);
        HEAP32[$24>>2] = $22;
        $25 = ($20|0)==(0|0);
        if ($25) {
         $error$0 = 6;
         break L4;
        } else {
         $svc$02 = $20;
         break;
        }
       }
      } else {
       $svc$02 = $13;
      }
     } while(0);
     $26 = HEAP32[$svc$02>>2]|0;
     $27 = ($26|0)==(0|0);
     if ($27) {
      $error$0 = 6;
     } else {
      $28 = (FUNCTION_TABLE_iiiii[$26 & 511]($face,$glyph_index,$buffer,$buffer_max)|0);
      $error$0 = $28;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($error$0|0);
}
function _FT_Render_Glyph_Internal($library,$slot,$render_mode) {
 $library = $library|0;
 $slot = $slot|0;
 $render_mode = $render_mode|0;
 var $$ = 0, $$lcssa = 0, $$pre$phi63Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cur$0$i3 = 0;
 var $cur$12$i = 0, $cur$12$i4 = 0, $cur$12$i49$ph16 = 0, $cur$12$i49$ph1664 = 0, $cur$12$i49$ph18 = 0, $error$0$ph = 0, $error$0$us$us = 0, $error$2 = 0, $or$cond = 0, $or$cond$us$us = 0, $or$cond14 = 0, $or$cond15 = 0, $or$cond2 = 0, $renderer$1$lcssa22 = 0, $renderer$1$ph17 = 0, $renderer$1$ph1765 = 0, $renderer$1$ph19 = 0, $renderer$1$us$us = 0, $update$0$lcssa24 = 0, $update$0$ph = 0;
 var $update$0$us$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($slot) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 L1: do {
  if ((($1|0) == 1869968492)) {
   $2 = (($library) + 164|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($library) + 156|0);
   $5 = HEAP32[$4>>2]|0;
   $$pre$phi63Z2D = $4;$cur$12$i49$ph1664 = $5;$renderer$1$ph1765 = $3;
   label = 8;
  } else if ((($1|0) == 1651078259)) {
   $error$2 = 0;
   STACKTOP = sp;return ($error$2|0);
  } else {
   $6 = ($library|0)==(0|0);
   if ($6) {
    $error$0$us$us = 7;$renderer$1$us$us = 0;$update$0$us$us = 0;
   } else {
    $7 = (($library) + 156|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $$pre$phi63Z2D = $7;$cur$12$i49$ph1664 = 0;$renderer$1$ph1765 = 0;
     label = 8;
     break;
    } else {
     $cur$12$i = $8;
    }
    while(1) {
     $10 = (($cur$12$i) + 8|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($11) + 24|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==($1|0);
     if ($14) {
      $cur$12$i49$ph16 = $cur$12$i;$renderer$1$ph17 = $11;
      break;
     }
     $15 = (($cur$12$i) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      $cur$12$i49$ph16 = 0;$renderer$1$ph17 = 0;
      break;
     } else {
      $cur$12$i = $16;
     }
    }
    $18 = ($library|0)==(0|0);
    if ($18) {
     $error$0$us$us = 7;$renderer$1$us$us = $renderer$1$ph17;$update$0$us$us = 0;
    } else {
     $$pre$phi63Z2D = $7;$cur$12$i49$ph1664 = $cur$12$i49$ph16;$renderer$1$ph1765 = $renderer$1$ph17;
     label = 8;
     break;
    }
   }
   while(1) {
    $19 = ($renderer$1$us$us|0)==(0|0);
    if ($19) {
     $error$2 = $error$0$us$us;
     break;
    }
    $20 = (($renderer$1$us$us) + 68|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (FUNCTION_TABLE_iiiii[$21 & 511]($renderer$1$us$us,$slot,$render_mode,0)|0);
    $23 = ($22|0)!=(0);
    $24 = $22 & 255;
    $25 = ($24|0)==(19);
    $or$cond$us$us = $23 & $25;
    if ($or$cond$us$us) {
     $error$0$us$us = $22;$renderer$1$us$us = 0;$update$0$us$us = 1;
    } else {
     $$lcssa = $22;$47 = 1;$renderer$1$lcssa22 = $renderer$1$us$us;$update$0$lcssa24 = $update$0$us$us;
     break L1;
    }
   }
   STACKTOP = sp;return ($error$2|0);
  }
 } while(0);
 L15: do {
  if ((label|0) == 8) {
   $cur$12$i49$ph18 = $cur$12$i49$ph1664;$error$0$ph = 7;$renderer$1$ph19 = $renderer$1$ph1765;$update$0$ph = 0;
   L17: while(1) {
    $26 = ($renderer$1$ph19|0)==(0|0);
    if ($26) {
     $error$2 = $error$0$ph;
     break;
    }
    $27 = (($renderer$1$ph19) + 68|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (FUNCTION_TABLE_iiiii[$28 & 511]($renderer$1$ph19,$slot,$render_mode,0)|0);
    $30 = ($29|0)!=(0);
    $31 = $29 & 255;
    $32 = ($31|0)==(19);
    $or$cond = $30 & $32;
    if (!($or$cond)) {
     $$lcssa = $29;$47 = 0;$renderer$1$lcssa22 = $renderer$1$ph19;$update$0$lcssa24 = $update$0$ph;
     break L15;
    }
    $33 = HEAP32[$0>>2]|0;
    $34 = ($cur$12$i49$ph18|0)==(0|0);
    $35 = (($cur$12$i49$ph18) + 4|0);
    $$ = $34 ? $$pre$phi63Z2D : $35;
    $cur$0$i3 = HEAP32[$$>>2]|0;
    $36 = ($cur$0$i3|0)==(0|0);
    if ($36) {
     $cur$12$i49$ph18 = 0;$error$0$ph = $29;$renderer$1$ph19 = 0;$update$0$ph = 1;
     continue;
    } else {
     $cur$12$i4 = $cur$0$i3;
    }
    while(1) {
     $37 = (($cur$12$i4) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = (($38) + 24|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($33|0);
     if ($41) {
      $cur$12$i49$ph18 = $cur$12$i4;$error$0$ph = $29;$renderer$1$ph19 = $38;$update$0$ph = 1;
      continue L17;
     }
     $42 = (($cur$12$i4) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(0|0);
     if ($44) {
      $cur$12$i49$ph18 = 0;$error$0$ph = $29;$renderer$1$ph19 = 0;$update$0$ph = 1;
      continue L17;
     } else {
      $cur$12$i4 = $43;
     }
    }
   }
   STACKTOP = sp;return ($error$2|0);
  }
 } while(0);
 $45 = ($$lcssa|0)!=(0);
 $46 = ($update$0$lcssa24|0)==(0);
 $or$cond2 = $45 | $46;
 $or$cond14 = $or$cond2 | $47;
 $48 = ($renderer$1$lcssa22|0)==(0|0);
 $or$cond15 = $or$cond14 | $48;
 if ($or$cond15) {
  $error$2 = $$lcssa;
  STACKTOP = sp;return ($error$2|0);
 }
 $49 = (($library) + 156|0);
 $50 = (_FT_List_Find($49,$renderer$1$lcssa22)|0);
 $51 = ($50|0)==(0|0);
 if ($51) {
  $error$2 = 0;
  STACKTOP = sp;return ($error$2|0);
 }
 _FT_List_Up($49,$50);
 $52 = (($renderer$1$lcssa22) + 24|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ($53|0)==(1869968492);
 if (!($54)) {
  $error$2 = 0;
  STACKTOP = sp;return ($error$2|0);
 }
 $55 = (($library) + 164|0);
 HEAP32[$55>>2] = $renderer$1$lcssa22;
 $error$2 = 0;
 STACKTOP = sp;return ($error$2|0);
}
function _FT_Add_Module($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $$0 = 0, $$c$i = 0, $$pr$i = 0, $$pre = 0, $$pre$i = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cur$12$i$i$i = 0, $error = 0, $error$i = 0, $nn$06 = 0;
 var $result$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp + 4|0;
 $error = sp;
 $0 = ($library|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($clazz|0)==(0|0);
 if ($1) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($clazz) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(131076);
 if ($4) {
  $$0 = 4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($library) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = HEAP32[$library>>2]|0;
  HEAP32[$error>>2] = 0;
  $30 = $8;$40 = $library;
 } else {
  $9 = (($clazz) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $nn$06 = 0;
  while(1) {
   $13 = ((($library) + ($nn$06<<2)|0) + 28|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (_strcmp($17,$10)|0);
   $19 = ($18|0)==(0);
   $12 = (($nn$06) + 1)|0;
   if ($19) {
    label = 9;
    break;
   }
   $11 = ($12>>>0)<($6>>>0);
   if ($11) {
    $nn$06 = $12;
   } else {
    $27 = $6;
    break;
   }
  }
  do {
   if ((label|0) == 9) {
    $20 = (($clazz) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($15) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($21|0)>($23|0);
    if ($24) {
     (_FT_Remove_Module($library,$14)|0);
     $$pre = HEAP32[$5>>2]|0;
     $27 = $$pre;
     break;
    } else {
     $$0 = 5;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  $25 = HEAP32[$library>>2]|0;
  HEAP32[$error>>2] = 0;
  $26 = ($27>>>0)>(31);
  if ($26) {
   HEAP32[$error>>2] = 48;
   $$0 = 48;
   STACKTOP = sp;return ($$0|0);
  } else {
   $30 = $25;$40 = $library;
  }
 }
 $28 = (($clazz) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $31 = (_ft_mem_alloc($30,$29,$error)|0);
 $32 = HEAP32[$error>>2]|0;
 $33 = ($32|0)==(0);
 if (!($33)) {
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = (($31) + 4|0);
 HEAP32[$34>>2] = $library;
 $35 = (($31) + 8|0);
 HEAP32[$35>>2] = $30;
 HEAP32[$31>>2] = $clazz;
 $36 = HEAP32[$clazz>>2]|0;
 $37 = $36 & 2;
 $38 = ($37|0)==(0);
 do {
  if ($38) {
   label = 27;
  } else {
   $39 = HEAP32[$40>>2]|0;
   $41 = (_ft_mem_alloc($39,12,$error$i)|0);
   $42 = HEAP32[$error$i>>2]|0;
   $43 = ($42|0)==(0);
   if (!($43)) {
    HEAP32[$error>>2] = $42;
    break;
   }
   $44 = HEAP32[$31>>2]|0;
   $45 = (($31) + 20|0);
   HEAP32[$45>>2] = $44;
   $46 = (($44) + 36|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($31) + 24|0);
   $$c$i = $47;
   HEAP32[$48>>2] = $$c$i;
   $49 = HEAP32[$46>>2]|0;
   $50 = ($49|0)==(1869968492);
   if ($50) {
    $51 = (($44) + 56|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($52) + 4|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)==(0|0);
    if ($55) {
     label = 21;
    } else {
     $56 = (($31) + 60|0);
     $57 = (FUNCTION_TABLE_iii[$54 & 4095]($39,$56)|0);
     HEAP32[$error$i>>2] = $57;
     $58 = ($57|0)==(0);
     if ($58) {
      $59 = HEAP32[$51>>2]|0;
      $60 = (($59) + 16|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = (($31) + 64|0);
      HEAP32[$62>>2] = $61;
      $63 = (($44) + 40|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($31) + 68|0);
      HEAP32[$65>>2] = $64;
      label = 21;
     }
    }
   } else {
    label = 21;
   }
   if ((label|0) == 21) {
    $66 = (($41) + 8|0);
    HEAP32[$66>>2] = $31;
    $67 = (($library) + 156|0);
    _FT_List_Add($67,$41);
    $68 = (($library) + 156|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(0|0);
    L39: do {
     if ($70) {
      $result$0$i$i$i = 0;
     } else {
      $cur$12$i$i$i = $69;
      while(1) {
       $71 = (($cur$12$i$i$i) + 8|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = (($72) + 24|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = ($74|0)==(1869968492);
       if ($75) {
        $result$0$i$i$i = $72;
        break L39;
       }
       $76 = (($cur$12$i$i$i) + 4|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = ($77|0)==(0|0);
       if ($78) {
        $result$0$i$i$i = 0;
        break;
       } else {
        $cur$12$i$i$i = $77;
       }
      }
     }
    } while(0);
    $79 = (($library) + 164|0);
    HEAP32[$79>>2] = $result$0$i$i$i;
    $$pr$i = HEAP32[$error$i>>2]|0;
    $80 = ($$pr$i|0)==(0);
    if ($80) {
     HEAP32[$error>>2] = 0;
     label = 27;
     break;
    }
   }
   _ft_mem_free($39,$41);
   $$pre$i = HEAP32[$error$i>>2]|0;
   HEAP32[$error>>2] = $$pre$i;
   $81 = ($$pre$i|0)==(0);
   if ($81) {
    label = 27;
   }
  }
 } while(0);
 do {
  if ((label|0) == 27) {
   $82 = HEAP32[$31>>2]|0;
   $83 = HEAP32[$82>>2]|0;
   $84 = $83 & 4;
   $85 = ($84|0)==(0);
   if ($85) {
    $88 = $83;$91 = $82;
   } else {
    $86 = (($library) + 168|0);
    HEAP32[$86>>2] = $31;
    $$pre11 = HEAP32[$31>>2]|0;
    $$pre12 = HEAP32[$$pre11>>2]|0;
    $88 = $$pre12;$91 = $$pre11;
   }
   $87 = $88 & 1;
   $89 = ($87|0)==(0);
   if (!($89)) {
    $90 = (($31) + 20|0);
    HEAP32[$90>>2] = $91;
    $92 = $88 & 512;
    $93 = ($92|0)==(0);
    if ($93) {
     $94 = (($31) + 36|0);
     $95 = (_FT_GlyphLoader_New($30,$94)|0);
     HEAP32[$error>>2] = $95;
     $96 = ($95|0)==(0);
     if (!($96)) {
      break;
     }
    }
   }
   $97 = (($clazz) + 24|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==(0|0);
   if (!($99)) {
    $100 = (FUNCTION_TABLE_ii[$98 & 4095]($31)|0);
    HEAP32[$error>>2] = $100;
    $101 = ($100|0)==(0);
    if (!($101)) {
     break;
    }
   }
   $102 = HEAP32[$5>>2]|0;
   $103 = (($102) + 1)|0;
   HEAP32[$5>>2] = $103;
   $104 = ((($library) + ($102<<2)|0) + 28|0);
   HEAP32[$104>>2] = $31;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $105 = HEAP32[$31>>2]|0;
 $106 = HEAP32[$105>>2]|0;
 $107 = $106 & 513;
 $108 = ($107|0)==(1);
 if ($108) {
  $109 = (($31) + 36|0);
  $110 = HEAP32[$109>>2]|0;
  _FT_GlyphLoader_Done($110);
  $$pre13 = HEAP32[$31>>2]|0;
  $$pre15 = HEAP32[$$pre13>>2]|0;
  $112 = $$pre15;
 } else {
  $112 = $106;
 }
 $111 = $112 & 2;
 $113 = ($111|0)==(0);
 if (!($113)) {
  $114 = (($31) + 20|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($115) + 36|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = ($117|0)==(1869968492);
  if ($118) {
   $119 = (($31) + 60|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ($120|0)==(0|0);
   if (!($121)) {
    $122 = (($115) + 56|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = (($123) + 20|0);
    $125 = HEAP32[$124>>2]|0;
    FUNCTION_TABLE_vi[$125 & 4095]($120);
   }
  }
 }
 _ft_mem_free($30,$31);
 $$pre10 = HEAP32[$error>>2]|0;
 $$0 = $$pre10;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Remove_Module($library,$module) {
 $library = $library|0;
 $module = $module|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $cur$03 = 0;
 var $cur$11 = 0, $cur$12$i$i$i$i = 0, $result$0$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($library|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($module|0)==(0|0);
 if ($1) {
  $$0 = 34;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($library) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($library) + ($3<<2)|0) + 28|0);
 $5 = ($3|0)>(0);
 if (!($5)) {
  $$0 = 34;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($library) + 28|0);
 $cur$03 = $6;
 while(1) {
  $9 = HEAP32[$cur$03>>2]|0;
  $10 = ($9|0)==($module|0);
  $8 = (($cur$03) + 4|0);
  if ($10) {
   break;
  }
  $7 = ($8>>>0)<($4>>>0);
  if ($7) {
   $cur$03 = $8;
  } else {
   $$0 = 34;
   label = 30;
   break;
  }
 }
 if ((label|0) == 30) {
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($3) + -1)|0;
 HEAP32[$2>>2] = $11;
 $12 = ((($library) + ($11<<2)|0) + 28|0);
 $13 = ($cur$03>>>0)<($12>>>0);
 if ($13) {
  $cur$11 = $cur$03;
  while(1) {
   $14 = (($cur$11) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$cur$11>>2] = $15;
   $16 = ($14>>>0)<($12>>>0);
   if ($16) {
    $cur$11 = $14;
   } else {
    break;
   }
  }
 }
 HEAP32[$12>>2] = 0;
 $17 = (($module) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$module>>2]|0;
 $20 = (($module) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($module) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  FUNCTION_TABLE_vi[$23 & 4095]($module);
 }
 $25 = ($21|0)==(0|0);
 if (!($25)) {
  $26 = (($21) + 168|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($module|0);
  if ($28) {
   HEAP32[$26>>2] = 0;
  }
 }
 $29 = HEAP32[$module>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 2;
 $32 = ($31|0)==(0);
 if (!($32)) {
  $33 = HEAP32[$20>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($33) + 156|0);
  $36 = (_FT_List_Find($35,$module)|0);
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   $38 = (($module) + 20|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (($39) + 36|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(1869968492);
   if ($42) {
    $43 = (($module) + 60|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     $46 = (($39) + 56|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = (($47) + 20|0);
     $49 = HEAP32[$48>>2]|0;
     FUNCTION_TABLE_vi[$49 & 4095]($44);
    }
   }
   _FT_List_Remove($35,$36);
   _ft_mem_free($34,$36);
   $50 = ($33|0)==(0|0);
   L34: do {
    if ($50) {
     $result$0$i$i$i$i = 0;
    } else {
     $51 = (($33) + 156|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==(0|0);
     if ($53) {
      $result$0$i$i$i$i = 0;
     } else {
      $cur$12$i$i$i$i = $52;
      while(1) {
       $54 = (($cur$12$i$i$i$i) + 8|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = (($55) + 24|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = ($57|0)==(1869968492);
       if ($58) {
        $result$0$i$i$i$i = $55;
        break L34;
       }
       $59 = (($cur$12$i$i$i$i) + 4|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = ($60|0)==(0|0);
       if ($61) {
        $result$0$i$i$i$i = 0;
        break;
       } else {
        $cur$12$i$i$i$i = $60;
       }
      }
     }
    }
   } while(0);
   $62 = (($33) + 164|0);
   HEAP32[$62>>2] = $result$0$i$i$i$i;
  }
 }
 $63 = HEAP32[$module>>2]|0;
 $64 = HEAP32[$63>>2]|0;
 $65 = $64 & 1;
 $66 = ($65|0)==(0);
 if (!($66)) {
  $67 = (($module) + 24|0);
  $68 = HEAP32[$17>>2]|0;
  _FT_List_Finalize($67,2061,$68,$module);
  $69 = HEAP32[$module>>2]|0;
  $70 = HEAP32[$69>>2]|0;
  $71 = $70 & 512;
  $72 = ($71|0)==(0);
  if ($72) {
   $73 = (($module) + 36|0);
   $74 = HEAP32[$73>>2]|0;
   _FT_GlyphLoader_Done($74);
  }
 }
 $75 = (($19) + 28|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = ($76|0)==(0|0);
 if (!($77)) {
  FUNCTION_TABLE_vi[$76 & 4095]($module);
 }
 _ft_mem_free($18,$module);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Get_Module_Interface($library,$mod_name) {
 $library = $library|0;
 $mod_name = $mod_name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cur$01$i = 0;
 var $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($library|0)==(0|0);
 $1 = ($mod_name|0)==(0|0);
 $or$cond$i = $0 | $1;
 L1: do {
  if ($or$cond$i) {
   $18 = 0;
  } else {
   $2 = (($library) + 24|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ((($library) + ($3<<2)|0) + 28|0);
   $5 = ($3|0)>(0);
   if ($5) {
    $6 = (($library) + 28|0);
    $cur$01$i = $6;
    while(1) {
     $9 = HEAP32[$cur$01$i>>2]|0;
     $10 = HEAP32[$9>>2]|0;
     $11 = (($10) + 8|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (_strcmp($12,$mod_name)|0);
     $14 = ($13|0)==(0);
     $8 = (($cur$01$i) + 4|0);
     if ($14) {
      break;
     }
     $7 = ($8>>>0)<($4>>>0);
     if ($7) {
      $cur$01$i = $8;
     } else {
      $18 = 0;
      break L1;
     }
    }
    $15 = ($9|0)==(0|0);
    if ($15) {
     $18 = 0;
    } else {
     $16 = (($10) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = $17;
    }
   } else {
    $18 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($18|0);
}
function _ft_module_get_service($module,$service_id) {
 $module = $module|0;
 $service_id = $service_id|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cur$02 = 0, $result$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($module|0)==(0|0);
 L1: do {
  if ($0) {
   $result$3 = 0;
  } else {
   $1 = HEAP32[$module>>2]|0;
   $2 = (($1) + 32|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if (!($4)) {
    $5 = (FUNCTION_TABLE_iii[$3 & 4095]($module,$service_id)|0);
    $6 = ($5|0)==(0|0);
    if (!($6)) {
     $result$3 = $5;
     break;
    }
   }
   $7 = (($module) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 24|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ((($8) + ($10<<2)|0) + 28|0);
   $12 = ($10|0)>(0);
   if ($12) {
    $13 = (($8) + 28|0);
    $cur$02 = $13;
    while(1) {
     $14 = HEAP32[$cur$02>>2]|0;
     $15 = ($14|0)==($module|0);
     if (!($15)) {
      $16 = HEAP32[$14>>2]|0;
      $17 = (($16) + 32|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)==(0|0);
      if (!($19)) {
       $20 = (FUNCTION_TABLE_iii[$18 & 4095]($14,$service_id)|0);
       $21 = ($20|0)==(0|0);
       if (!($21)) {
        $result$3 = $20;
        break L1;
       }
      }
     }
     $22 = (($cur$02) + 4|0);
     $23 = ($22>>>0)<($11>>>0);
     if ($23) {
      $cur$02 = $22;
     } else {
      $result$3 = 0;
      break;
     }
    }
   } else {
    $result$3 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($result$3|0);
}
function _FT_New_Library($memory,$alibrary) {
 $memory = $memory|0;
 $alibrary = $alibrary|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = ($memory|0)==(0|0);
 if ($0) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (_ft_mem_alloc($memory,236,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $memory;
 $4 = (_ft_pic_container_init($1)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = (($1) + 176|0);
  HEAP32[$6>>2] = 16384;
  $7 = (_ft_mem_alloc($memory,16384,$error)|0);
  $8 = (($1) + 172|0);
  HEAP32[$8>>2] = $7;
  $9 = HEAP32[$error>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = (($1) + 12|0);
   HEAP32[$11>>2] = 2;
   $12 = (($1) + 16|0);
   HEAP32[$12>>2] = 4;
   $13 = (($1) + 20|0);
   HEAP32[$13>>2] = 8;
   $14 = (($1) + 232|0);
   HEAP32[$14>>2] = 1;
   HEAP32[$alibrary>>2] = $1;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 _ft_pic_container_destroy($1);
 _ft_mem_free($memory,$1);
 $15 = HEAP32[$error>>2]|0;
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Done_Library($library) {
 $library = $library|0;
 var $$0 = 0, $$pre$pre = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre21$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $n$04 = 0, $n$04$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($library|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($library) + 232|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -1)|0;
 HEAP32[$1>>2] = $3;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$library>>2]|0;
 $6 = (($library) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  FUNCTION_TABLE_vi[$7 & 4095]($library);
 }
 $9 = (($library) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0);
 if (!($11)) {
  $90 = $10;$n$04 = 0;
  while(1) {
   $12 = ((($library) + ($n$04<<2)|0) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (_strcmp($16,806472)|0);
   $18 = ($17|0)==(0);
   if ($18) {
    $19 = HEAP32[$14>>2]|0;
    $20 = $19 & 1;
    $21 = ($20|0)==(0);
    if ($21) {
     $47 = $90;
    } else {
     $22 = (($13) + 24|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      $47 = $90;
     } else {
      $26 = $23;
      while(1) {
       $25 = (($26) + 8|0);
       $27 = HEAP32[$25>>2]|0;
       $28 = ($27|0)==(0|0);
       if (!($28)) {
        $31 = (($27) + 96|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = ($32|0)==(0|0);
        if (!($33)) {
         $34 = (($27) + 128|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = (($35) + 56|0);
         $37 = HEAP32[$36>>2]|0;
         $38 = (($37) + -1)|0;
         HEAP32[$36>>2] = $38;
         $39 = ($38|0)==(0);
         if ($39) {
          $40 = (($32) + 8|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = (($32) + 24|0);
          $43 = (_FT_List_Find($42,$27)|0);
          $44 = ($43|0)==(0|0);
          if (!($44)) {
           _FT_List_Remove($42,$43);
           _ft_mem_free($41,$43);
           _destroy_face($41,$27,$32);
          }
         }
        }
       }
       $29 = HEAP32[$22>>2]|0;
       $30 = ($29|0)==(0|0);
       if ($30) {
        break;
       } else {
        $26 = $29;
       }
      }
      $$pre21$pre = HEAP32[$9>>2]|0;
      $47 = $$pre21$pre;
     }
    }
   } else {
    $47 = $90;
   }
   $45 = (($n$04) + 1)|0;
   $46 = ($45>>>0)<($47>>>0);
   if ($46) {
    $90 = $47;$n$04 = $45;
   } else {
    break;
   }
  }
  $48 = ($47|0)==(0);
  if (!($48)) {
   $$pre16 = $47;$91 = $47;$n$04$1 = 0;
   while(1) {
    $58 = ((($library) + ($n$04$1<<2)|0) + 28|0);
    $59 = HEAP32[$58>>2]|0;
    $$pre15 = HEAP32[$59>>2]|0;
    $60 = HEAP32[$$pre15>>2]|0;
    $61 = $60 & 1;
    $62 = ($61|0)==(0);
    if ($62) {
     $$pre17 = $$pre16;$88 = $91;
    } else {
     $63 = (($59) + 24|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = ($64|0)==(0|0);
     if ($65) {
      $$pre17 = $$pre16;$88 = $$pre16;
     } else {
      $67 = $64;
      while(1) {
       $66 = (($67) + 8|0);
       $68 = HEAP32[$66>>2]|0;
       $69 = ($68|0)==(0|0);
       if (!($69)) {
        $70 = (($68) + 96|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = ($71|0)==(0|0);
        if (!($72)) {
         $73 = (($68) + 128|0);
         $74 = HEAP32[$73>>2]|0;
         $75 = (($74) + 56|0);
         $76 = HEAP32[$75>>2]|0;
         $77 = (($76) + -1)|0;
         HEAP32[$75>>2] = $77;
         $78 = ($77|0)==(0);
         if ($78) {
          $79 = (($71) + 8|0);
          $80 = HEAP32[$79>>2]|0;
          $81 = (($71) + 24|0);
          $82 = (_FT_List_Find($81,$68)|0);
          $83 = ($82|0)==(0|0);
          if (!($83)) {
           _FT_List_Remove($81,$82);
           _ft_mem_free($80,$82);
           _destroy_face($80,$68,$71);
          }
         }
        }
       }
       $84 = HEAP32[$63>>2]|0;
       $85 = ($84|0)==(0|0);
       if ($85) {
        break;
       } else {
        $67 = $84;
       }
      }
      $$pre$pre = HEAP32[$9>>2]|0;
      $$pre17 = $$pre$pre;$88 = $$pre$pre;
     }
    }
    $86 = (($n$04$1) + 1)|0;
    $87 = ($86>>>0)<($88>>>0);
    if ($87) {
     $$pre16 = $$pre17;$91 = $88;$n$04$1 = $86;
    } else {
     break;
    }
   }
   $89 = ($88|0)==(0);
   if (!($89)) {
    $50 = $88;
    while(1) {
     $49 = (($50) + -1)|0;
     $51 = ((($library) + ($49<<2)|0) + 28|0);
     $52 = HEAP32[$51>>2]|0;
     (_FT_Remove_Module($library,$52)|0);
     $53 = HEAP32[$9>>2]|0;
     $54 = ($53|0)==(0);
     if ($54) {
      break;
     } else {
      $50 = $53;
     }
    }
   }
  }
 }
 $55 = (($library) + 172|0);
 $56 = HEAP32[$55>>2]|0;
 _ft_mem_free($5,$56);
 HEAP32[$55>>2] = 0;
 $57 = (($library) + 176|0);
 HEAP32[$57>>2] = 0;
 _ft_pic_container_destroy($library);
 _ft_mem_free($5,$library);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _ft_stub_set_char_sizes($size,$width,$height,$horz_res,$vert_res) {
 $size = $size|0;
 $width = $width|0;
 $height = $height|0;
 $horz_res = $horz_res|0;
 $vert_res = $vert_res|0;
 var $$$01 = 0, $$0 = 0, $$01 = 0, $$vert_res$horz_res = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $req = 0, $vert_res$horz_res = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $req = sp;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($0) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$req>>2] = 0;
 $8 = (($req) + 4|0);
 HEAP32[$8>>2] = $width;
 $9 = (($req) + 8|0);
 HEAP32[$9>>2] = $height;
 $10 = ($horz_res|0)==(0);
 $vert_res$horz_res = $10 ? $vert_res : $horz_res;
 $11 = ($vert_res|0)==(0);
 $$01 = $11 ? $vert_res$horz_res : $vert_res;
 $12 = ($vert_res$horz_res|0)==(0);
 $$vert_res$horz_res = $12 ? 72 : $vert_res$horz_res;
 $$$01 = $12 ? 72 : $$01;
 $13 = (($req) + 12|0);
 HEAP32[$13>>2] = $$vert_res$horz_res;
 $14 = (($req) + 16|0);
 HEAP32[$14>>2] = $$$01;
 $15 = (FUNCTION_TABLE_iii[$6 & 4095]($size,$req)|0);
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function _ft_stub_set_pixel_sizes($size,$width,$height) {
 $size = $size|0;
 $width = $width|0;
 $height = $height|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $req = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $req = sp;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($0) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$req>>2] = 0;
 $8 = $width << 6;
 $9 = (($req) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = $height << 6;
 $11 = (($req) + 8|0);
 HEAP32[$11>>2] = $10;
 $12 = (($req) + 12|0);
 HEAP32[$12>>2] = 0;
 $13 = (($req) + 16|0);
 HEAP32[$13>>2] = 0;
 $14 = (FUNCTION_TABLE_iii[$6 & 4095]($size,$req)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function _IsMacResource($library,$stream,$resource_offset,$face_index,$aface) {
 $library = $library|0;
 $stream = $stream|0;
 $resource_offset = $resource_offset|0;
 $face_index = $face_index|0;
 $aface = $aface|0;
 var $$0 = 0, $$0$i = 0, $$0$i3 = 0, $$face_index$i = 0, $$pre = 0, $$pre38 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count = 0, $data_offsets = 0, $error$i1 = 0, $i$0$i22 = 0, $i$1$i11 = 0, $len$0$i$lcssa = 0, $len$0$i13 = 0, $len$1$i = 0, $len$2$i = 0, $map_offset = 0;
 var $pfb_len$0$i$lcssa = 0, $pfb_len$0$i23 = 0, $pfb_lenpos$0$i$lcssa = 0, $pfb_lenpos$0$i15 = 0, $pfb_lenpos$1$i = 0, $pfb_lenpos$2$i = 0, $pfb_pos$0$i$lcssa = 0, $pfb_pos$0$i14 = 0, $pfb_pos$1$i = 0, $pfb_pos$2$i = 0, $phitmp$i = 0, $rdara_pos = 0, $rlen$0$i = 0, $type$0$i12 = 0, $type$1$i = 0, $type$2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $error$i1 = sp + 16|0;
 $map_offset = sp;
 $rdara_pos = sp + 4|0;
 $data_offsets = sp + 8|0;
 $count = sp + 12|0;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_FT_Raccess_Get_HeaderInfo($library,$stream,$resource_offset,$map_offset,$rdara_pos)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$map_offset>>2]|0;
 $4 = HEAP32[$rdara_pos>>2]|0;
 $5 = (_FT_Raccess_Get_DataOffsets($library,$stream,$3,$4,1347375956,$data_offsets,$count)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $107 = HEAP32[$map_offset>>2]|0;
  $108 = HEAP32[$rdara_pos>>2]|0;
  $109 = (_FT_Raccess_Get_DataOffsets($library,$stream,$107,$108,1936092788,$data_offsets,$count)|0);
  $110 = ($109|0)==(0);
  if (!($110)) {
   $$0 = $109;
   STACKTOP = sp;return ($$0|0);
  }
  $111 = HEAP32[$count>>2]|0;
  $112 = (($face_index|0) % ($111|0))&-1;
  $113 = HEAP32[$data_offsets>>2]|0;
  $114 = HEAP32[$library>>2]|0;
  $115 = ($112|0)==(-1);
  $$face_index$i = $115 ? 0 : $112;
  $116 = ($$face_index$i|0)<($111|0);
  do {
   if ($116) {
    $117 = (($113) + ($$face_index$i<<2)|0);
    $118 = HEAP32[$117>>2]|0;
    $119 = (_FT_Stream_Seek($stream,$118)|0);
    HEAP32[$error$i1>>2] = $119;
    $120 = ($119|0)==(0);
    if ($120) {
     $121 = (_FT_Stream_ReadULong($stream,$error$i1)|0);
     $122 = HEAP32[$error$i1>>2]|0;
     $123 = ($122|0)==(0);
     if ($123) {
      $124 = ($121|0)==(-1);
      if ($124) {
       $$0$i = 1;
      } else {
       $125 = (_open_face_PS_from_sfnt_stream($library,$stream,$$face_index$i,0,0,$aface)|0);
       HEAP32[$error$i1>>2] = $125;
       $126 = ($125|0)==(0);
       if ($126) {
        $$0$i = 0;
       } else {
        $127 = (($118) + 4)|0;
        $128 = (_FT_Stream_Seek($stream,$127)|0);
        $129 = ($128|0)==(0);
        if (!($129)) {
         $$pre38 = HEAP32[$error$i1>>2]|0;
         $$0$i = $$pre38;
         break;
        }
        $130 = (_ft_mem_alloc($114,$121,$error$i1)|0);
        $131 = HEAP32[$error$i1>>2]|0;
        $132 = ($131|0)==(0);
        if ($132) {
         $133 = (_FT_Stream_Read($stream,$130,$121)|0);
         HEAP32[$error$i1>>2] = $133;
         $134 = ($133|0)==(0);
         if ($134) {
          $135 = ($121|0)>(4);
          if ($135) {
           $136 = (_memcmp($130,806480,4)|0);
           $137 = ($136|0)!=(0);
           $phitmp$i = $137 ? 806440 : 806488;
           $138 = $phitmp$i;
          } else {
           $138 = 806440;
          }
          $139 = (_open_face_from_buffer($library,$130,$121,0,$138,$aface)|0);
          HEAP32[$error$i1>>2] = $139;
          $$0$i = $139;
         } else {
          $$0$i = $133;
         }
        } else {
         $$0$i = $131;
        }
       }
      }
     } else {
      $$0$i = $122;
     }
    } else {
     $$0$i = $119;
    }
   } else {
    $$0$i = 1;
   }
  } while(0);
  $140 = HEAP32[$data_offsets>>2]|0;
  _ft_mem_free($0,$140);
  HEAP32[$data_offsets>>2] = 0;
  $141 = ($$0$i|0)==(0);
  if (!($141)) {
   $$0 = $$0$i;
   STACKTOP = sp;return ($$0|0);
  }
  $142 = HEAP32[$count>>2]|0;
  $143 = HEAP32[$aface>>2]|0;
  HEAP32[$143>>2] = $142;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$data_offsets>>2]|0;
 $8 = HEAP32[$count>>2]|0;
 HEAP32[$error$i1>>2] = 1;
 $9 = HEAP32[$library>>2]|0;
 L29: do {
  if ((($face_index|0) == 0) | (($face_index|0) == -1)) {
   $10 = ($8|0)>(0);
   if ($10) {
    $i$0$i22 = 0;$pfb_len$0$i23 = 0;
    while(1) {
     $11 = (($7) + ($i$0$i22<<2)|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = (_FT_Stream_Seek($stream,$12)|0);
     HEAP32[$error$i1>>2] = $13;
     $14 = ($13|0)==(0);
     if (!($14)) {
      $$0$i3 = $13;
      break L29;
     }
     $15 = (_FT_Stream_ReadULong($stream,$error$i1)|0);
     $16 = HEAP32[$error$i1>>2]|0;
     $17 = ($16|0)==(0);
     if (!($17)) {
      $$0$i3 = $16;
      break L29;
     }
     $18 = (($pfb_len$0$i23) + 6)|0;
     $19 = (($18) + ($15))|0;
     $20 = (($i$0$i22) + 1)|0;
     $21 = ($20|0)<($8|0);
     if ($21) {
      $i$0$i22 = $20;$pfb_len$0$i23 = $19;
     } else {
      $pfb_len$0$i$lcssa = $19;
      break;
     }
    }
   } else {
    $pfb_len$0$i$lcssa = 0;
   }
   $22 = (($pfb_len$0$i$lcssa) + 2)|0;
   $23 = (_ft_mem_alloc($9,$22,$error$i1)|0);
   $24 = HEAP32[$error$i1>>2]|0;
   $25 = ($24|0)==(0);
   if ($25) {
    HEAP8[$23>>0] = -128;
    $26 = (($23) + 1|0);
    HEAP8[$26>>0] = 1;
    $27 = (($23) + 2|0);
    HEAP8[$27>>0]=0&255;HEAP8[$27+1>>0]=(0>>8)&255;HEAP8[$27+2>>0]=(0>>16)&255;HEAP8[$27+3>>0]=0>>24;
    L38: do {
     if ($10) {
      $i$1$i11 = 0;$len$0$i13 = 0;$pfb_lenpos$0$i15 = 2;$pfb_pos$0$i14 = 6;$type$0$i12 = 1;
      while(1) {
       $28 = (($7) + ($i$1$i11<<2)|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (_FT_Stream_Seek($stream,$29)|0);
       HEAP32[$error$i1>>2] = $30;
       $31 = ($30|0)==(0);
       if (!($31)) {
        break L38;
       }
       $32 = (_FT_Stream_ReadULong($stream,$error$i1)|0);
       $33 = HEAP32[$error$i1>>2]|0;
       $34 = ($33|0)==(0);
       if (!($34)) {
        $$0$i3 = $33;
        break L29;
       }
       $35 = (_FT_Stream_ReadUShort($stream,$error$i1)|0);
       $36 = HEAP32[$error$i1>>2]|0;
       $37 = ($36|0)==(0);
       if (!($37)) {
        $$0$i3 = $36;
        break L29;
       }
       $38 = $35&65535;
       $39 = $38 >>> 8;
       $40 = ($39|0)==(0);
       if ($40) {
        $len$2$i = $len$0$i13;$pfb_lenpos$2$i = $pfb_lenpos$0$i15;$pfb_pos$2$i = $pfb_pos$0$i14;$type$2$i = $type$0$i12;
       } else {
        $41 = ($32|0)>(2);
        $42 = (($32) + -2)|0;
        $rlen$0$i = $41 ? $42 : 0;
        $43 = ($39|0)==($type$0$i12|0);
        if ($43) {
         $44 = (($rlen$0$i) + ($len$0$i13))|0;
         $len$1$i = $44;$pfb_lenpos$1$i = $pfb_lenpos$0$i15;$pfb_pos$1$i = $pfb_pos$0$i14;$type$1$i = $type$0$i12;
        } else {
         $45 = (($pfb_lenpos$0$i15) + 3)|0;
         $46 = ($45|0)>($22|0);
         if ($46) {
          break L38;
         }
         $47 = $len$0$i13&255;
         $48 = (($23) + ($pfb_lenpos$0$i15)|0);
         HEAP8[$48>>0] = $47;
         $49 = $len$0$i13 >>> 8;
         $50 = $49&255;
         $51 = (($pfb_lenpos$0$i15) + 1)|0;
         $52 = (($23) + ($51)|0);
         HEAP8[$52>>0] = $50;
         $53 = $len$0$i13 >>> 16;
         $54 = $53&255;
         $55 = (($pfb_lenpos$0$i15) + 2)|0;
         $56 = (($23) + ($55)|0);
         HEAP8[$56>>0] = $54;
         $57 = $len$0$i13 >>> 24;
         $58 = $57&255;
         $59 = (($23) + ($45)|0);
         HEAP8[$59>>0] = $58;
         $60 = ($39|0)==(5);
         if ($60) {
          $len$0$i$lcssa = $len$0$i13;$pfb_lenpos$0$i$lcssa = $pfb_lenpos$0$i15;$pfb_pos$0$i$lcssa = $pfb_pos$0$i14;
          label = 24;
          break L38;
         }
         $61 = (($pfb_pos$0$i14) + 4)|0;
         $62 = ($61|0)>($pfb_len$0$i$lcssa|0);
         if ($62) {
          break L38;
         }
         $63 = (($pfb_pos$0$i14) + 1)|0;
         $64 = (($23) + ($pfb_pos$0$i14)|0);
         HEAP8[$64>>0] = -128;
         $65 = $39&255;
         $66 = (($pfb_pos$0$i14) + 2)|0;
         $67 = (($23) + ($63)|0);
         HEAP8[$67>>0] = $65;
         $68 = (($pfb_pos$0$i14) + 3)|0;
         $69 = (($23) + ($66)|0);
         HEAP8[$69>>0] = 0;
         $70 = (($23) + ($68)|0);
         HEAP8[$70>>0] = 0;
         $71 = (($pfb_pos$0$i14) + 5)|0;
         $72 = (($23) + ($61)|0);
         HEAP8[$72>>0] = 0;
         $73 = (($pfb_pos$0$i14) + 6)|0;
         $74 = (($23) + ($71)|0);
         HEAP8[$74>>0] = 0;
         $len$1$i = $rlen$0$i;$pfb_lenpos$1$i = $66;$pfb_pos$1$i = $73;$type$1$i = $39;
        }
        HEAP32[$error$i1>>2] = 1;
        $75 = ($pfb_pos$1$i|0)>($pfb_len$0$i$lcssa|0);
        if ($75) {
         break L38;
        }
        $76 = (($pfb_pos$1$i) + ($rlen$0$i))|0;
        $77 = ($76|0)>($pfb_len$0$i$lcssa|0);
        if ($77) {
         break L38;
        }
        $78 = (($23) + ($pfb_pos$1$i)|0);
        $79 = (_FT_Stream_Read($stream,$78,$rlen$0$i)|0);
        HEAP32[$error$i1>>2] = $79;
        $80 = ($79|0)==(0);
        if ($80) {
         $len$2$i = $len$1$i;$pfb_lenpos$2$i = $pfb_lenpos$1$i;$pfb_pos$2$i = $76;$type$2$i = $type$1$i;
        } else {
         break L38;
        }
       }
       $81 = (($i$1$i11) + 1)|0;
       $82 = ($81|0)<($8|0);
       if ($82) {
        $i$1$i11 = $81;$len$0$i13 = $len$2$i;$pfb_lenpos$0$i15 = $pfb_lenpos$2$i;$pfb_pos$0$i14 = $pfb_pos$2$i;$type$0$i12 = $type$2$i;
       } else {
        $len$0$i$lcssa = $len$2$i;$pfb_lenpos$0$i$lcssa = $pfb_lenpos$2$i;$pfb_pos$0$i$lcssa = $pfb_pos$2$i;
        label = 24;
        break;
       }
      }
     } else {
      $len$0$i$lcssa = 0;$pfb_lenpos$0$i$lcssa = 2;$pfb_pos$0$i$lcssa = 6;
      label = 24;
     }
    } while(0);
    if ((label|0) == 24) {
     $83 = ($pfb_pos$0$i$lcssa|0)>($pfb_len$0$i$lcssa|0);
     if (!($83)) {
      $84 = (($pfb_pos$0$i$lcssa) + 1)|0;
      $85 = (($23) + ($pfb_pos$0$i$lcssa)|0);
      HEAP8[$85>>0] = -128;
      $86 = (($23) + ($84)|0);
      HEAP8[$86>>0] = 3;
      $87 = (($pfb_lenpos$0$i$lcssa) + 3)|0;
      $88 = ($87|0)>($22|0);
      if (!($88)) {
       $89 = (($pfb_pos$0$i$lcssa) + 2)|0;
       $90 = $len$0$i$lcssa&255;
       $91 = (($23) + ($pfb_lenpos$0$i$lcssa)|0);
       HEAP8[$91>>0] = $90;
       $92 = $len$0$i$lcssa >>> 8;
       $93 = $92&255;
       $94 = (($pfb_lenpos$0$i$lcssa) + 1)|0;
       $95 = (($23) + ($94)|0);
       HEAP8[$95>>0] = $93;
       $96 = $len$0$i$lcssa >>> 16;
       $97 = $96&255;
       $98 = (($pfb_lenpos$0$i$lcssa) + 2)|0;
       $99 = (($23) + ($98)|0);
       HEAP8[$99>>0] = $97;
       $100 = $len$0$i$lcssa >>> 24;
       $101 = $100&255;
       $102 = (($23) + ($87)|0);
       HEAP8[$102>>0] = $101;
       $103 = (_open_face_from_buffer($library,$23,$89,0,806432,$aface)|0);
       $$0$i3 = $103;
       break;
      }
     }
    }
    _ft_mem_free($9,$23);
    $$pre = HEAP32[$error$i1>>2]|0;
    $$0$i3 = $$pre;
   } else {
    $$0$i3 = $24;
   }
  } else {
   $$0$i3 = 1;
  }
 } while(0);
 $104 = HEAP32[$data_offsets>>2]|0;
 _ft_mem_free($0,$104);
 HEAP32[$data_offsets>>2] = 0;
 $105 = ($$0$i3|0)==(0);
 if (!($105)) {
  $$0 = $$0$i3;
  STACKTOP = sp;return ($$0|0);
 }
 $106 = HEAP32[$aface>>2]|0;
 HEAP32[$106>>2] = 1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Outline_Decompose($outline,$func_interface,$user) {
 $outline = $outline|0;
 $func_interface = $func_interface|0;
 $user = $user|0;
 var $$0 = 0, $$sum = 0, $$sum$pn = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error$0 = 0, $first$019 = 0, $limit$0 = 0, $limit$1 = 0, $n$018 = 0, $or$cond = 0, $point$0 = 0, $point$1$be = 0, $point$112 = 0;
 var $point$27 = 0, $tags$0 = 0, $tags$1$be = 0, $tags$113 = 0, $tags$28 = 0, $v_control = 0, $v_middle = 0, $v_start = 0, $vec = 0, $vec1 = 0, $vec12 = 0, $vec2 = 0, $vec3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $v_control = sp + 16|0;
 $v_start = sp;
 $vec = sp + 56|0;
 $vec1 = sp + 8|0;
 $v_middle = sp + 24|0;
 $vec12 = sp + 32|0;
 $vec2 = sp + 40|0;
 $vec3 = sp + 48|0;
 $0 = ($outline|0)==(0|0);
 $1 = ($func_interface|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($func_interface) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($func_interface) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP16[$outline>>1]|0;
 $7 = ($6<<16>>16)>(0);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($outline) + 12|0);
 $9 = (($outline) + 4|0);
 $10 = (($v_start) + 4|0);
 $11 = (($outline) + 8|0);
 $12 = (($func_interface) + 4|0);
 $13 = (($vec12) + 4|0);
 $14 = (($vec2) + 4|0);
 $15 = (($vec3) + 4|0);
 $16 = (($func_interface) + 12|0);
 $17 = (($vec) + 4|0);
 $18 = (($v_control) + 4|0);
 $19 = (($vec1) + 4|0);
 $20 = (($v_middle) + 4|0);
 $21 = (($func_interface) + 8|0);
 $first$019 = 0;$n$018 = 0;
 L7: while(1) {
  $22 = HEAP32[$8>>2]|0;
  $23 = (($22) + ($n$018<<1)|0);
  $24 = HEAP16[$23>>1]|0;
  $25 = $24 << 16 >> 16;
  $26 = ($24<<16>>16)<(0);
  if ($26) {
   $$0 = 20;
   label = 29;
   break;
  }
  $27 = HEAP32[$9>>2]|0;
  $28 = (($27) + ($25<<3)|0);
  $29 = (($27) + ($first$019<<3)|0);
  $30 = $29;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 4)|0;
  $34 = $33;
  $35 = HEAP32[$34>>2]|0;
  $36 = $v_start;
  $37 = $36;
  HEAP32[$37>>2] = $32;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = $35;
  $40 = $32 << $3;
  $41 = (($40) - ($5))|0;
  HEAP32[$v_start>>2] = $41;
  $42 = $35 << $3;
  $43 = (($42) - ($5))|0;
  HEAP32[$10>>2] = $43;
  $44 = (($27) + ($25<<3)|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ((($27) + ($25<<3)|0) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = $45 << $3;
  $49 = (($48) - ($5))|0;
  $50 = $47 << $3;
  $51 = (($50) - ($5))|0;
  $52 = $v_start;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 4)|0;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = $v_control;
  $59 = $58;
  HEAP32[$59>>2] = $54;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = $57;
  $62 = HEAP32[$11>>2]|0;
  $63 = (($62) + ($first$019)|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = $64&255;
  $66 = $65 & 3;
  if ((($66|0) == 2)) {
   $$0 = 20;
   label = 29;
   break;
  } else if ((($66|0) == 0)) {
   $67 = (($62) + ($25)|0);
   $68 = HEAP8[$67>>0]|0;
   $69 = $68 & 3;
   $70 = ($69<<24>>24)==(1);
   if ($70) {
    HEAP32[$v_start>>2] = $49;
    HEAP32[$10>>2] = $51;
    $$sum4 = (($25) + -1)|0;
    $71 = (($27) + ($$sum4<<3)|0);
    $limit$0 = $71;
   } else {
    $72 = (($54) + ($49))|0;
    $73 = (($72|0) / 2)&-1;
    HEAP32[$v_start>>2] = $73;
    $74 = (($43) + ($51))|0;
    $75 = (($74|0) / 2)&-1;
    HEAP32[$10>>2] = $75;
    $limit$0 = $28;
   }
   $$sum = (($first$019) + -1)|0;
   $76 = (($62) + ($$sum)|0);
   $$sum$pn = $$sum;$limit$1 = $limit$0;$tags$0 = $76;
  } else {
   $$sum$pn = $first$019;$limit$1 = $28;$tags$0 = $63;
  }
  $point$0 = (($27) + ($$sum$pn<<3)|0);
  $77 = HEAP32[$func_interface>>2]|0;
  $78 = (FUNCTION_TABLE_iii[$77 & 4095]($v_start,$user)|0);
  $79 = ($78|0)==(0);
  if (!($79)) {
   $$0 = $78;
   label = 29;
   break;
  }
  $80 = ($point$0>>>0)<($limit$1>>>0);
  L18: do {
   if ($80) {
    $point$112 = $point$0;$tags$113 = $tags$0;
    L19: while(1) {
     $81 = (($point$112) + 8|0);
     $82 = (($tags$113) + 1|0);
     $83 = HEAP8[$82>>0]|0;
     $84 = $83&255;
     $85 = $84 & 3;
     if ((($85|0) == 0)) {
      $96 = HEAP32[$81>>2]|0;
      $97 = $96 << $3;
      $98 = (($97) - ($5))|0;
      HEAP32[$v_control>>2] = $98;
      $99 = (($point$112) + 12|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = $100 << $3;
      $102 = (($101) - ($5))|0;
      HEAP32[$18>>2] = $102;
      $103 = ($81>>>0)<($limit$1>>>0);
      if ($103) {
       $121 = $98;$124 = $102;$point$27 = $81;$tags$28 = $82;
      } else {
       label = 20;
       break;
      }
      while(1) {
       $104 = (($point$27) + 8|0);
       $105 = (($tags$28) + 1|0);
       $106 = HEAP8[$105>>0]|0;
       $107 = $106&255;
       $108 = $107 & 3;
       $109 = HEAP32[$104>>2]|0;
       $110 = $109 << $3;
       $111 = (($110) - ($5))|0;
       HEAP32[$vec1>>2] = $111;
       $112 = (($point$27) + 12|0);
       $113 = HEAP32[$112>>2]|0;
       $114 = $113 << $3;
       $115 = (($114) - ($5))|0;
       HEAP32[$19>>2] = $115;
       if ((($108|0) == 1)) {
        break;
       } else if (!((($108|0) == 0))) {
        $$0 = 20;
        label = 29;
        break L7;
       }
       $120 = (($111) + ($121))|0;
       $122 = (($120|0) / 2)&-1;
       HEAP32[$v_middle>>2] = $122;
       $123 = (($115) + ($124))|0;
       $125 = (($123|0) / 2)&-1;
       HEAP32[$20>>2] = $125;
       $126 = HEAP32[$21>>2]|0;
       $127 = (FUNCTION_TABLE_iiii[$126 & 2047]($v_control,$v_middle,$user)|0);
       $128 = ($127|0)==(0);
       if (!($128)) {
        $$0 = $127;
        label = 29;
        break L7;
       }
       $129 = $vec1;
       $130 = $129;
       $131 = HEAP32[$130>>2]|0;
       $132 = (($129) + 4)|0;
       $133 = $132;
       $134 = HEAP32[$133>>2]|0;
       $135 = $v_control;
       $136 = $135;
       HEAP32[$136>>2] = $131;
       $137 = (($135) + 4)|0;
       $138 = $137;
       HEAP32[$138>>2] = $134;
       $139 = ($104>>>0)<($limit$1>>>0);
       if ($139) {
        $121 = $131;$124 = $134;$point$27 = $104;$tags$28 = $105;
       } else {
        label = 20;
        break L19;
       }
      }
      $116 = HEAP32[$21>>2]|0;
      $117 = (FUNCTION_TABLE_iiii[$116 & 2047]($v_control,$vec1,$user)|0);
      $118 = ($117|0)==(0);
      if ($118) {
       $point$1$be = $104;$tags$1$be = $105;
      } else {
       $$0 = $117;
       label = 29;
       break L7;
      }
     } else if ((($85|0) == 1)) {
      $86 = HEAP32[$81>>2]|0;
      $87 = $86 << $3;
      $88 = (($87) - ($5))|0;
      HEAP32[$vec>>2] = $88;
      $89 = (($point$112) + 12|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = $90 << $3;
      $92 = (($91) - ($5))|0;
      HEAP32[$17>>2] = $92;
      $93 = HEAP32[$12>>2]|0;
      $94 = (FUNCTION_TABLE_iii[$93 & 4095]($vec,$user)|0);
      $95 = ($94|0)==(0);
      if ($95) {
       $point$1$be = $81;$tags$1$be = $82;
      } else {
       $$0 = $94;
       label = 29;
       break L7;
      }
     } else {
      $142 = (($point$112) + 16|0);
      $143 = ($142>>>0)>($limit$1>>>0);
      if ($143) {
       $$0 = 20;
       label = 29;
       break L7;
      }
      $144 = (($tags$113) + 2|0);
      $145 = HEAP8[$144>>0]|0;
      $146 = $145 & 3;
      $147 = ($146<<24>>24)==(2);
      if (!($147)) {
       $$0 = 20;
       label = 29;
       break L7;
      }
      $148 = (($point$112) + 24|0);
      $149 = (($point$112) + 8|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = $150 << $3;
      $152 = (($151) - ($5))|0;
      HEAP32[$vec12>>2] = $152;
      $153 = (($point$112) + 12|0);
      $154 = HEAP32[$153>>2]|0;
      $155 = $154 << $3;
      $156 = (($155) - ($5))|0;
      HEAP32[$13>>2] = $156;
      $157 = (($point$112) + 16|0);
      $158 = HEAP32[$157>>2]|0;
      $159 = $158 << $3;
      $160 = (($159) - ($5))|0;
      HEAP32[$vec2>>2] = $160;
      $161 = (($point$112) + 20|0);
      $162 = HEAP32[$161>>2]|0;
      $163 = $162 << $3;
      $164 = (($163) - ($5))|0;
      HEAP32[$14>>2] = $164;
      $165 = ($148>>>0)>($limit$1>>>0);
      if ($165) {
       label = 25;
       break;
      }
      $166 = (($tags$113) + 3|0);
      $167 = HEAP32[$148>>2]|0;
      $168 = $167 << $3;
      $169 = (($168) - ($5))|0;
      HEAP32[$vec3>>2] = $169;
      $170 = (($point$112) + 28|0);
      $171 = HEAP32[$170>>2]|0;
      $172 = $171 << $3;
      $173 = (($172) - ($5))|0;
      HEAP32[$15>>2] = $173;
      $174 = HEAP32[$16>>2]|0;
      $175 = (FUNCTION_TABLE_iiiii[$174 & 511]($vec12,$vec2,$vec3,$user)|0);
      $176 = ($175|0)==(0);
      if ($176) {
       $point$1$be = $148;$tags$1$be = $166;
      } else {
       $$0 = $175;
       label = 29;
       break L7;
      }
     }
     $119 = ($point$1$be>>>0)<($limit$1>>>0);
     if ($119) {
      $point$112 = $point$1$be;$tags$113 = $tags$1$be;
     } else {
      label = 26;
      break L18;
     }
    }
    if ((label|0) == 20) {
     label = 0;
     $140 = HEAP32[$21>>2]|0;
     $141 = (FUNCTION_TABLE_iiii[$140 & 2047]($v_control,$v_start,$user)|0);
     $error$0 = $141;
     break;
    }
    else if ((label|0) == 25) {
     label = 0;
     $177 = HEAP32[$16>>2]|0;
     $178 = (FUNCTION_TABLE_iiiii[$177 & 511]($vec12,$vec2,$v_start,$user)|0);
     $error$0 = $178;
     break;
    }
   } else {
    label = 26;
   }
  } while(0);
  if ((label|0) == 26) {
   label = 0;
   $179 = HEAP32[$12>>2]|0;
   $180 = (FUNCTION_TABLE_iii[$179 & 4095]($v_start,$user)|0);
   $error$0 = $180;
  }
  $181 = ($error$0|0)==(0);
  if (!($181)) {
   $$0 = $error$0;
   label = 29;
   break;
  }
  $182 = (($25) + 1)|0;
  $183 = (($n$018) + 1)|0;
  $184 = HEAP16[$outline>>1]|0;
  $185 = $184 << 16 >> 16;
  $186 = ($183|0)<($185|0);
  if ($186) {
   $first$019 = $182;$n$018 = $183;
  } else {
   $$0 = 0;
   label = 29;
   break;
  }
 }
 if ((label|0) == 29) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _FT_Outline_New_Internal($memory,$numPoints,$numContours,$anoutline) {
 $memory = $memory|0;
 $numPoints = $numPoints|0;
 $numContours = $numContours|0;
 $anoutline = $anoutline|0;
 var $$0 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = ($anoutline|0)==(0|0);
 $1 = ($memory|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$anoutline+0>>2]=0|0;HEAP32[$anoutline+4>>2]=0|0;HEAP32[$anoutline+8>>2]=0|0;HEAP32[$anoutline+12>>2]=0|0;HEAP32[$anoutline+16>>2]=0|0;
 $2 = (_ft_mem_realloc($memory,8,0,$numPoints,0,$error)|0);
 $3 = (($anoutline) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$error>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $9 = (_ft_mem_realloc($memory,1,0,$numPoints,0,$error)|0);
  $10 = (($anoutline) + 8|0);
  HEAP32[$10>>2] = $9;
  $11 = HEAP32[$error>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   $13 = (_ft_mem_realloc($memory,2,0,$numContours,0,$error)|0);
   $14 = (($anoutline) + 12|0);
   HEAP32[$14>>2] = $13;
   $15 = HEAP32[$error>>2]|0;
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = $numPoints&65535;
    $18 = (($anoutline) + 2|0);
    HEAP16[$18>>1] = $17;
    $19 = $numContours&65535;
    HEAP16[$anoutline>>1] = $19;
    $20 = (($anoutline) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $21 | 1;
    HEAP32[$20>>2] = $22;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $23 = (($anoutline) + 16|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 | 1;
  HEAP32[$23>>2] = $25;
  $$pre1 = HEAP32[$3>>2]|0;
  $$pre$phiZ2D = $10;$26 = $$pre1;
 } else {
  $6 = (($anoutline) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 | 1;
  HEAP32[$6>>2] = $8;
  $$pre2 = (($anoutline) + 8|0);
  $$pre$phiZ2D = $$pre2;$26 = $2;
 }
 _ft_mem_free($memory,$26);
 HEAP32[$3>>2] = 0;
 $27 = HEAP32[$$pre$phiZ2D>>2]|0;
 _ft_mem_free($memory,$27);
 HEAP32[$$pre$phiZ2D>>2] = 0;
 $28 = (($anoutline) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 _ft_mem_free($memory,$29);
 ;HEAP32[$anoutline+0>>2]=0|0;HEAP32[$anoutline+4>>2]=0|0;HEAP32[$anoutline+8>>2]=0|0;HEAP32[$anoutline+12>>2]=0|0;HEAP32[$anoutline+16>>2]=0|0;
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Outline_New($library,$numPoints,$numContours,$anoutline) {
 $library = $library|0;
 $numPoints = $numPoints|0;
 $numContours = $numContours|0;
 $anoutline = $anoutline|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($library|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$library>>2]|0;
 $2 = (_FT_Outline_New_Internal($1,$numPoints,$numContours,$anoutline)|0);
 $$0 = $2;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Outline_Check($outline) {
 $outline = $outline|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $end0$0$lcssa = 0, $end0$04 = 0, $n$05 = 0, $or$cond1 = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($outline|0)==(0|0);
 L1: do {
  if (!($0)) {
   $1 = (($outline) + 2|0);
   $2 = HEAP16[$1>>1]|0;
   $3 = $2 << 16 >> 16;
   $4 = HEAP16[$outline>>1]|0;
   $5 = $4 << 16 >> 16;
   $6 = $4 | $2;
   $7 = ($6<<16>>16)==(0);
   if ($7) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $8 = ($2<<16>>16)<(1);
   $9 = ($4<<16>>16)<(1);
   $or$cond1 = $8 | $9;
   if (!($or$cond1)) {
    $10 = ($4<<16>>16)>(0);
    if ($10) {
     $11 = (($outline) + 12|0);
     $12 = HEAP32[$11>>2]|0;
     $end0$04 = -1;$n$05 = 0;
     while(1) {
      $15 = (($12) + ($n$05<<1)|0);
      $16 = HEAP16[$15>>1]|0;
      $17 = $16 << 16 >> 16;
      $18 = ($17|0)>($end0$04|0);
      $19 = ($16<<16>>16)<($2<<16>>16);
      $or$cond2 = $18 & $19;
      $14 = (($n$05) + 1)|0;
      if (!($or$cond2)) {
       break L1;
      }
      $13 = ($14|0)<($5|0);
      if ($13) {
       $end0$04 = $17;$n$05 = $14;
      } else {
       $end0$0$lcssa = $17;
       break;
      }
     }
    } else {
     $end0$0$lcssa = -1;
    }
    $20 = (($3) + -1)|0;
    $21 = ($end0$0$lcssa|0)==($20|0);
    if ($21) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Outline_Copy($source,$target) {
 $source = $source|0;
 $target = $target|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($source|0)==(0|0);
 $1 = ($target|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($source) + 2|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3 << 16 >> 16;
 $5 = (($target) + 2|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = ($3<<16>>16)==($6<<16>>16);
 if (!($7)) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = HEAP16[$source>>1]|0;
 $9 = HEAP16[$target>>1]|0;
 $10 = ($8<<16>>16)==($9<<16>>16);
 if (!($10)) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ($source|0)==($target|0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($target) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($source) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $4 << 3;
 _memcpy(($13|0),($15|0),($16|0))|0;
 $17 = (($target) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($source) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP16[$2>>1]|0;
 $22 = $21 << 16 >> 16;
 _memcpy(($18|0),($20|0),($22|0))|0;
 $23 = (($target) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($source) + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP16[$source>>1]|0;
 $28 = $27 << 16 >> 16;
 $29 = $28 << 1;
 _memcpy(($24|0),($26|0),($29|0))|0;
 $30 = (($target) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = $31 & 1;
 $33 = (($source) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & -2;
 $36 = $35 | $32;
 HEAP32[$30>>2] = $36;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Outline_Done($library,$outline) {
 $library = $library|0;
 $outline = $outline|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($library|0)==(0|0);
 if ($0) {
  $$0 = 33;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$library>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = ($outline|0)==(0|0);
 $or$cond$i = $2 | $3;
 if ($or$cond$i) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($outline) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $8 = (($outline) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  _ft_mem_free($1,$9);
  HEAP32[$8>>2] = 0;
  $10 = (($outline) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  _ft_mem_free($1,$11);
  HEAP32[$10>>2] = 0;
  $12 = (($outline) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  _ft_mem_free($1,$13);
  HEAP32[$12>>2] = 0;
 }
 ;HEAP32[$outline+0>>2]=0|0;HEAP32[$outline+4>>2]=0|0;HEAP32[$outline+8>>2]=0|0;HEAP32[$outline+12>>2]=0|0;HEAP32[$outline+16>>2]=0|0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Outline_Get_CBox($outline,$acbox) {
 $outline = $outline|0;
 $acbox = $acbox|0;
 var $$pn3 = 0, $$pn3$phi = 0, $$xMin$0 = 0, $$yMin$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vec$0 = 0, $vec$01 = 0, $vec$07 = 0, $xMax$04 = 0, $xMax$1 = 0, $xMax$2 = 0, $xMin$06 = 0, $xMin$2 = 0, $yMax$02 = 0, $yMax$1 = 0, $yMax$2 = 0;
 var $yMin$05 = 0, $yMin$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($outline|0)==(0|0);
 $1 = ($acbox|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = (($outline) + 2|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(0);
 if ($4) {
  $xMax$2 = 0;$xMin$2 = 0;$yMax$2 = 0;$yMin$2 = 0;
 } else {
  $5 = $3 << 16 >> 16;
  $6 = (($outline) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($5<<3)|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = (($7) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($3<<16>>16)>(1);
  if ($12) {
   $vec$01 = (($7) + 8|0);
   $$pn3 = $7;$vec$07 = $vec$01;$xMax$04 = $9;$xMin$06 = $9;$yMax$02 = $11;$yMin$05 = $11;
   while(1) {
    $13 = HEAP32[$vec$07>>2]|0;
    $14 = ($13|0)<($xMin$06|0);
    $$xMin$0 = $14 ? $13 : $xMin$06;
    $15 = ($13|0)>($xMax$04|0);
    $xMax$1 = $15 ? $13 : $xMax$04;
    $16 = (($$pn3) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)<($yMin$05|0);
    $$yMin$0 = $18 ? $17 : $yMin$05;
    $19 = ($17|0)>($yMax$02|0);
    $yMax$1 = $19 ? $17 : $yMax$02;
    $vec$0 = (($vec$07) + 8|0);
    $20 = ($vec$0>>>0)<($8>>>0);
    if ($20) {
     $$pn3$phi = $vec$07;$vec$07 = $vec$0;$xMax$04 = $xMax$1;$xMin$06 = $$xMin$0;$yMax$02 = $yMax$1;$yMin$05 = $$yMin$0;$$pn3 = $$pn3$phi;
    } else {
     $xMax$2 = $xMax$1;$xMin$2 = $$xMin$0;$yMax$2 = $yMax$1;$yMin$2 = $$yMin$0;
     break;
    }
   }
  } else {
   $xMax$2 = $9;$xMin$2 = $9;$yMax$2 = $11;$yMin$2 = $11;
  }
 }
 HEAP32[$acbox>>2] = $xMin$2;
 $21 = (($acbox) + 8|0);
 HEAP32[$21>>2] = $xMax$2;
 $22 = (($acbox) + 4|0);
 HEAP32[$22>>2] = $yMin$2;
 $23 = (($acbox) + 12|0);
 HEAP32[$23>>2] = $yMax$2;
 STACKTOP = sp;return;
}
function _FT_Outline_Translate($outline,$xOffset,$yOffset) {
 $outline = $outline|0;
 $xOffset = $xOffset|0;
 $yOffset = $yOffset|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$01 = 0, $vec$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($outline|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($outline) + 2|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = ($2<<16>>16)>(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($outline) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $2 << 16 >> 16;
 $n$01 = 0;$vec$02 = $5;
 while(1) {
  $7 = HEAP32[$vec$02>>2]|0;
  $8 = (($7) + ($xOffset))|0;
  HEAP32[$vec$02>>2] = $8;
  $9 = (($vec$02) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($yOffset))|0;
  HEAP32[$9>>2] = $11;
  $12 = (($vec$02) + 8|0);
  $13 = (($n$01) + 1)<<16>>16;
  $14 = $13&65535;
  $15 = ($14|0)<($6|0);
  if ($15) {
   $n$01 = $13;$vec$02 = $12;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _FT_Vector_Transform($vector,$matrix) {
 $vector = $vector|0;
 $matrix = $matrix|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($vector|0)==(0|0);
 $1 = ($matrix|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$vector>>2]|0;
 $3 = HEAP32[$matrix>>2]|0;
 $4 = (_FT_MulFix($2,$3)|0);
 $5 = (($vector) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($matrix) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (_FT_MulFix($6,$8)|0);
 $10 = (($9) + ($4))|0;
 $11 = HEAP32[$vector>>2]|0;
 $12 = (($matrix) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_FT_MulFix($11,$13)|0);
 $15 = HEAP32[$5>>2]|0;
 $16 = (($matrix) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (_FT_MulFix($15,$17)|0);
 $19 = (($18) + ($14))|0;
 HEAP32[$vector>>2] = $10;
 HEAP32[$5>>2] = $19;
 STACKTOP = sp;return;
}
function _FT_Outline_Transform($outline,$matrix) {
 $outline = $outline|0;
 $matrix = $matrix|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vec$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($outline|0)==(0|0);
 $1 = ($matrix|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $2 = (($outline) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($outline) + 2|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5 << 16 >> 16;
 $7 = (($3) + ($6<<3)|0);
 $8 = ($5<<16>>16)>(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($matrix) + 4|0);
 $10 = (($matrix) + 8|0);
 $11 = (($matrix) + 12|0);
 $vec$01 = $3;
 while(1) {
  $12 = ($vec$01|0)==(0|0);
  if (!($12)) {
   $13 = HEAP32[$vec$01>>2]|0;
   $14 = HEAP32[$matrix>>2]|0;
   $15 = (_FT_MulFix($13,$14)|0);
   $16 = (($vec$01) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$9>>2]|0;
   $19 = (_FT_MulFix($17,$18)|0);
   $20 = (($19) + ($15))|0;
   $21 = HEAP32[$vec$01>>2]|0;
   $22 = HEAP32[$10>>2]|0;
   $23 = (_FT_MulFix($21,$22)|0);
   $24 = HEAP32[$16>>2]|0;
   $25 = HEAP32[$11>>2]|0;
   $26 = (_FT_MulFix($24,$25)|0);
   $27 = (($26) + ($23))|0;
   HEAP32[$vec$01>>2] = $20;
   HEAP32[$16>>2] = $27;
  }
  $28 = (($vec$01) + 8|0);
  $29 = ($28>>>0)<($7>>>0);
  if ($29) {
   $vec$01 = $28;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _FT_Raccess_Get_HeaderInfo($library,$stream,$rfork_offset,$map_offset,$rdata_pos) {
 $library = $library|0;
 $stream = $stream|0;
 $rfork_offset = $rfork_offset|0;
 $map_offset = $map_offset|0;
 $rdata_pos = $rdata_pos|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $allmatch$03 = 0, $allmatch$1 = 0, $allzeros$0$ = 0, $allzeros$02 = 0, $error = 0, $exitcond = 0, $head = 0, $head2 = 0, $i$04 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $error = sp;
 $head = sp + 24|0;
 $head2 = sp + 8|0;
 $0 = (_FT_Stream_Seek($stream,$rfork_offset)|0);
 HEAP32[$error>>2] = $0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (_FT_Stream_Read($stream,$head,16)|0);
 HEAP32[$error>>2] = $2;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP8[$head>>0]|0;
 $5 = $4&255;
 $6 = $5 << 24;
 $7 = (($head) + 1|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 << 16;
 $11 = $10 | $6;
 $12 = (($head) + 2|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 << 8;
 $16 = $11 | $15;
 $17 = (($head) + 3|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = $16 | $19;
 $21 = (($20) + ($rfork_offset))|0;
 HEAP32[$rdata_pos>>2] = $21;
 $22 = (($head) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 << 24;
 $26 = (($head) + 5|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 $29 = $28 << 16;
 $30 = $29 | $25;
 $31 = (($head) + 6|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = $33 << 8;
 $35 = $30 | $34;
 $36 = (($head) + 7|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37&255;
 $39 = $35 | $38;
 $40 = (($39) + ($rfork_offset))|0;
 $41 = (($head) + 8|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = $42&255;
 $44 = $43 << 24;
 $45 = (($head) + 9|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46&255;
 $48 = $47 << 16;
 $49 = $48 | $44;
 $50 = (($head) + 10|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = $51&255;
 $53 = $52 << 8;
 $54 = $49 | $53;
 $55 = (($head) + 11|0);
 $56 = HEAP8[$55>>0]|0;
 $57 = $56&255;
 $58 = $54 | $57;
 $59 = (($58) + ($21))|0;
 $60 = ($59|0)!=($40|0);
 $61 = ($39|0)==(0);
 $or$cond = $60 | $61;
 if ($or$cond) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $62 = (_FT_Stream_Seek($stream,$40)|0);
 HEAP32[$error>>2] = $62;
 $63 = ($62|0)==(0);
 if (!($63)) {
  $$0 = $62;
  STACKTOP = sp;return ($$0|0);
 }
 $64 = (($head) + 15|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = $65&255;
 $67 = (($66) + 1)|0;
 $68 = $67&255;
 $69 = (($head2) + 15|0);
 HEAP8[$69>>0] = $68;
 $70 = (_FT_Stream_Read($stream,$head2,16)|0);
 HEAP32[$error>>2] = $70;
 $71 = ($70|0)==(0);
 if ($71) {
  $allmatch$03 = 1;$allzeros$02 = 1;$i$04 = 0;
 } else {
  $$0 = $70;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $72 = (($head2) + ($i$04)|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = ($73<<24>>24)==(0);
  $allzeros$0$ = $74 ? $allzeros$02 : 0;
  $75 = (($head) + ($i$04)|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = ($73<<24>>24)==($76<<24>>24);
  $allmatch$1 = $77 ? $allmatch$03 : 0;
  $78 = (($i$04) + 1)|0;
  $exitcond = ($78|0)==(16);
  if ($exitcond) {
   break;
  } else {
   $allmatch$03 = $allmatch$1;$allzeros$02 = $allzeros$0$;$i$04 = $78;
  }
 }
 $79 = $allmatch$1 | $allzeros$0$;
 $80 = ($79|0)==(0);
 if ($80) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $81 = (_FT_Stream_Skip($stream,8)|0);
 HEAP32[$error>>2] = $81;
 $82 = (_FT_Stream_ReadUShort($stream,$error)|0);
 $83 = HEAP32[$error>>2]|0;
 $84 = ($83|0)==(0);
 if (!($84)) {
  $$0 = $83;
  STACKTOP = sp;return ($$0|0);
 }
 $85 = $82&65535;
 $86 = (($85) + ($40))|0;
 $87 = (_FT_Stream_Seek($stream,$86)|0);
 HEAP32[$error>>2] = $87;
 $88 = ($87|0)==(0);
 if (!($88)) {
  $$0 = $87;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$map_offset>>2] = $86;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Raccess_Get_DataOffsets($library,$stream,$map_offset,$rdata_pos,$tag,$offsets,$count) {
 $library = $library|0;
 $stream = $stream|0;
 $map_offset = $map_offset|0;
 $rdata_pos = $rdata_pos|0;
 $tag = $tag|0;
 $offsets = $offsets|0;
 $count = $count|0;
 var $$0 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $error = 0, $i$010 = 0, $j$04 = 0, $j$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_FT_Stream_Seek($stream,$map_offset)|0);
 HEAP32[$error>>2] = $1;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (_FT_Stream_ReadUShort($stream,$error)|0);
 $4 = HEAP32[$error>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = $3&65535;
 $i$010 = 0;
 while(1) {
  $9 = (_FT_Stream_ReadULong($stream,$error)|0);
  $10 = HEAP32[$error>>2]|0;
  $11 = ($10|0)==(0);
  if (!($11)) {
   $$0 = $10;
   label = 22;
   break;
  }
  $12 = (_FT_Stream_ReadUShort($stream,$error)|0);
  $13 = $12&65535;
  $14 = HEAP32[$error>>2]|0;
  $15 = ($14|0)==(0);
  if (!($15)) {
   $$0 = $14;
   label = 22;
   break;
  }
  $16 = (_FT_Stream_ReadUShort($stream,$error)|0);
  $17 = HEAP32[$error>>2]|0;
  $18 = ($17|0)==(0);
  if (!($18)) {
   $$0 = $17;
   label = 22;
   break;
  }
  $19 = ($9|0)==($tag|0);
  if ($19) {
   label = 9;
   break;
  }
  $7 = (($i$010) + 1)|0;
  $8 = ($i$010|0)<($6|0);
  if ($8) {
   $i$010 = $7;
  } else {
   $$0 = 1;
   label = 22;
   break;
  }
 }
 if ((label|0) == 9) {
  $20 = $16&65535;
  $21 = (($13) + 1)|0;
  HEAP32[$count>>2] = $21;
  $22 = (($20) + ($map_offset))|0;
  $23 = (_FT_Stream_Seek($stream,$22)|0);
  HEAP32[$error>>2] = $23;
  $24 = ($23|0)==(0);
  if (!($24)) {
   $$0 = $23;
   STACKTOP = sp;return ($$0|0);
  }
  $25 = HEAP32[$count>>2]|0;
  $26 = (_ft_mem_realloc($0,8,0,$25,0,$error)|0);
  $27 = HEAP32[$error>>2]|0;
  $28 = ($27|0)==(0);
  if (!($28)) {
   $$0 = $27;
   STACKTOP = sp;return ($$0|0);
  }
  $29 = HEAP32[$count>>2]|0;
  $30 = ($29|0)>(0);
  L21: do {
   if ($30) {
    $j$04 = 0;
    while(1) {
     $31 = (_FT_Stream_ReadUShort($stream,$error)|0);
     $32 = (($26) + ($j$04<<3)|0);
     HEAP16[$32>>1] = $31;
     $33 = HEAP32[$error>>2]|0;
     $34 = ($33|0)==(0);
     if (!($34)) {
      break L21;
     }
     $35 = (_FT_Stream_Skip($stream,2)|0);
     HEAP32[$error>>2] = $35;
     $36 = ($35|0)==(0);
     if (!($36)) {
      break L21;
     }
     $37 = (_FT_Stream_ReadULong($stream,$error)|0);
     $38 = HEAP32[$error>>2]|0;
     $39 = ($38|0)==(0);
     if (!($39)) {
      break L21;
     }
     $40 = (_FT_Stream_Skip($stream,4)|0);
     HEAP32[$error>>2] = $40;
     $41 = ($40|0)==(0);
     if (!($41)) {
      break L21;
     }
     $42 = $37 & 16777215;
     $43 = ((($26) + ($j$04<<3)|0) + 4|0);
     HEAP32[$43>>2] = $42;
     $44 = (($j$04) + 1)|0;
     $45 = HEAP32[$count>>2]|0;
     $46 = ($44|0)<($45|0);
     if ($46) {
      $j$04 = $44;
     } else {
      $$lcssa = $45;
      label = 17;
      break;
     }
    }
   } else {
    $$lcssa = $29;
    label = 17;
   }
  } while(0);
  if ((label|0) == 17) {
   _qsort($26,$$lcssa,8,2616);
   $47 = HEAP32[$count>>2]|0;
   $48 = (_ft_mem_realloc($0,4,0,$47,0,$error)|0);
   $49 = HEAP32[$error>>2]|0;
   $50 = ($49|0)==(0);
   if ($50) {
    $51 = HEAP32[$count>>2]|0;
    $52 = ($51|0)>(0);
    if ($52) {
     $j$11 = 0;
     while(1) {
      $53 = ((($26) + ($j$11<<3)|0) + 4|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = (($54) + ($rdata_pos))|0;
      $56 = (($48) + ($j$11<<2)|0);
      HEAP32[$56>>2] = $55;
      $57 = (($j$11) + 1)|0;
      $58 = HEAP32[$count>>2]|0;
      $59 = ($57|0)<($58|0);
      if ($59) {
       $j$11 = $57;
      } else {
       break;
      }
     }
    }
    HEAP32[$offsets>>2] = $48;
    HEAP32[$error>>2] = 0;
   }
  }
  _ft_mem_free($0,$26);
  $60 = HEAP32[$error>>2]|0;
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 22) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _ft_raccess_sort_ref_by_id($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP16[$a>>1]|0;
 $1 = HEAP16[$b>>1]|0;
 $2 = ($0&65535)<($1&65535);
 if ($2) {
  $$0 = -1;
 } else {
  $3 = ($0&65535)>($1&65535);
  $$ = $3&1;
  $$0 = $$;
 }
 STACKTOP = sp;return ($$0|0);
}
function _FT_Raccess_Guess($library,$stream,$base_name,$new_names,$offsets,$errors) {
 $library = $library|0;
 $stream = $stream|0;
 $base_name = $base_name|0;
 $new_names = $new_names|0;
 $offsets = $offsets|0;
 $errors = $errors|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond3 = 0;
 var $i$01 = 0, $i$01$us = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($stream|0)==(0|0);
 if ($0) {
  $i$01$us = 0;
  while(1) {
   $1 = (($new_names) + ($i$01$us<<2)|0);
   HEAP32[$1>>2] = 0;
   $2 = (($errors) + ($i$01$us<<2)|0);
   HEAP32[$2>>2] = 0;
   $3 = (($errors) + ($i$01$us<<2)|0);
   $4 = (806496 + ($i$01$us<<3)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($offsets) + ($i$01$us<<2)|0);
   $7 = (FUNCTION_TABLE_iiiiii[$5 & 255]($library,0,$base_name,$1,$6)|0);
   HEAP32[$3>>2] = $7;
   $8 = (($i$01$us) + 1)|0;
   $exitcond3 = ($8|0)==(9);
   if ($exitcond3) {
    break;
   } else {
    $i$01$us = $8;
   }
  }
  STACKTOP = sp;return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $9 = (($new_names) + ($i$01<<2)|0);
  HEAP32[$9>>2] = 0;
  $10 = (_FT_Stream_Seek($stream,0)|0);
  $11 = (($errors) + ($i$01<<2)|0);
  HEAP32[$11>>2] = $10;
  $phitmp = ($10|0)==(0);
  if ($phitmp) {
   $12 = (($errors) + ($i$01<<2)|0);
   $13 = (806496 + ($i$01<<3)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($offsets) + ($i$01<<2)|0);
   $16 = (FUNCTION_TABLE_iiiiii[$14 & 255]($library,$stream,$base_name,$9,$15)|0);
   HEAP32[$12>>2] = $16;
  }
  $17 = (($i$01) + 1)|0;
  $exitcond = ($17|0)==(9);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $17;
  }
 }
 STACKTOP = sp;return;
}
function _raccess_rule_by_darwin_vfs($rule_index) {
 $rule_index = $rule_index|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $phitmp = 0, $phitmp1 = 0, $phitmp2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($rule_index>>>0)>(8);
 if ($0) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $1 = ((806496 + ($rule_index<<3)|0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $phitmp = (($2) + -3)|0;
 $phitmp1 = ($phitmp>>>0)<(2);
 $phitmp2 = $phitmp1&1;
 $$0$i = $phitmp2;
 STACKTOP = sp;return ($$0$i|0);
}
function _raccess_guess_apple_double($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$result_file_name>>2] = 0;
 $0 = ($stream|0)==(0|0);
 if ($0) {
  $$0 = 81;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (_raccess_guess_apple_generic($stream,333319,$result_offset)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_apple_single($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$result_file_name>>2] = 0;
 $0 = ($stream|0)==(0|0);
 if ($0) {
  $$0 = 81;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (_raccess_guess_apple_generic($stream,333312,$result_offset)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_darwin_ufs_export($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args2$i = 0, $stream2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $args2$i = sp + 8|0;
 $stream2$i = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_raccess_make_file_name($0,$base_file_name,806656)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 64;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$args2$i>>2] = 4;
 $3 = (($args2$i) + 12|0);
 HEAP32[$3>>2] = $1;
 $4 = (_FT_Stream_New($library,$args2$i,$stream2$i)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = HEAP32[$stream2$i>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $$0$i$i = 81;$9 = 0;
  } else {
   $8 = (_raccess_guess_apple_generic($6,333319,$result_offset)|0);
   $$pre$i = HEAP32[$stream2$i>>2]|0;
   $$0$i$i = $8;$9 = $$pre$i;
  }
  _FT_Stream_Free($9,0);
  $10 = ($$0$i$i|0)==(0);
  if ($10) {
   HEAP32[$result_file_name>>2] = $1;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0$i1 = $$0$i$i;
  }
 } else {
  $$0$i1 = $4;
 }
 _ft_mem_free($0,$1);
 $$0 = $$0$i1;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_darwin_newvfs($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $error = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (_strlen(($base_file_name|0))|0);
 $1 = (($0) + 18)|0;
 $2 = HEAP32[$library>>2]|0;
 $3 = (_ft_mem_alloc($2,$1,$error)|0);
 $4 = HEAP32[$error>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 _memcpy(($3|0),($base_file_name|0),($0|0))|0;
 $6 = (($3) + ($0)|0);
 dest=$6+0|0; src=806632+0|0; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 HEAP32[$result_file_name>>2] = $3;
 HEAP32[$result_offset>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_darwin_hfsplus($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (_strlen(($base_file_name|0))|0);
 $1 = (($0) + 6)|0;
 $2 = HEAP32[$library>>2]|0;
 $3 = (_ft_mem_alloc($2,$1,$error)|0);
 $4 = HEAP32[$error>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 _memcpy(($3|0),($base_file_name|0),($0|0))|0;
 $6 = (($3) + ($0)|0);
 ;HEAP8[$6+0>>0]=HEAP8[806624+0>>0]|0;HEAP8[$6+1>>0]=HEAP8[806624+1>>0]|0;HEAP8[$6+2>>0]=HEAP8[806624+2>>0]|0;HEAP8[$6+3>>0]=HEAP8[806624+3>>0]|0;HEAP8[$6+4>>0]=HEAP8[806624+4>>0]|0;HEAP8[$6+5>>0]=HEAP8[806624+5>>0]|0;
 HEAP32[$result_file_name>>2] = $3;
 HEAP32[$result_offset>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_vfat($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_raccess_make_file_name($0,$base_file_name,806608)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 64;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$result_file_name>>2] = $1;
 HEAP32[$result_offset>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_linux_cap($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_raccess_make_file_name($0,$base_file_name,806592)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 64;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$result_file_name>>2] = $1;
 HEAP32[$result_offset>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_linux_double($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args2$i = 0, $stream2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $args2$i = sp + 8|0;
 $stream2$i = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_raccess_make_file_name($0,$base_file_name,806584)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 64;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$args2$i>>2] = 4;
 $3 = (($args2$i) + 12|0);
 HEAP32[$3>>2] = $1;
 $4 = (_FT_Stream_New($library,$args2$i,$stream2$i)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = HEAP32[$stream2$i>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $$0$i$i = 81;$9 = 0;
  } else {
   $8 = (_raccess_guess_apple_generic($6,333319,$result_offset)|0);
   $$pre$i = HEAP32[$stream2$i>>2]|0;
   $$0$i$i = $8;$9 = $$pre$i;
  }
  _FT_Stream_Free($9,0);
  $10 = ($$0$i$i|0)==(0);
  if ($10) {
   HEAP32[$result_file_name>>2] = $1;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0$i1 = $$0$i$i;
  }
 } else {
  $$0$i1 = $4;
 }
 _ft_mem_free($0,$1);
 $$0 = $$0$i1;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_linux_netatalk($library,$stream,$base_file_name,$result_file_name,$result_offset) {
 $library = $library|0;
 $stream = $stream|0;
 $base_file_name = $base_file_name|0;
 $result_file_name = $result_file_name|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args2$i = 0, $stream2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $args2$i = sp + 8|0;
 $stream2$i = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_raccess_make_file_name($0,$base_file_name,806568)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 64;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$args2$i>>2] = 4;
 $3 = (($args2$i) + 12|0);
 HEAP32[$3>>2] = $1;
 $4 = (_FT_Stream_New($library,$args2$i,$stream2$i)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = HEAP32[$stream2$i>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $$0$i$i = 81;$9 = 0;
  } else {
   $8 = (_raccess_guess_apple_generic($6,333319,$result_offset)|0);
   $$pre$i = HEAP32[$stream2$i>>2]|0;
   $$0$i$i = $8;$9 = $$pre$i;
  }
  _FT_Stream_Free($9,0);
  $10 = ($$0$i$i|0)==(0);
  if ($10) {
   HEAP32[$result_file_name>>2] = $1;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0$i1 = $$0$i$i;
  }
 } else {
  $$0$i1 = $4;
 }
 _ft_mem_free($0,$1);
 $$0 = $$0$i1;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_make_file_name($memory,$original_name,$insertion) {
 $memory = $memory|0;
 $original_name = $original_name|0;
 $insertion = $insertion|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $error = 0, $slash$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = (_strlen(($original_name|0))|0);
 $1 = (_strlen(($insertion|0))|0);
 $2 = (($1) + ($0))|0;
 $3 = (($2) + 1)|0;
 $4 = (_ft_mem_alloc($memory,$3,$error)|0);
 $5 = HEAP32[$error>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (_strrchr($original_name,47)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP8[$4>>0] = 0;
  $slash$0 = $original_name;
 } else {
  $9 = $7;
  $10 = $original_name;
  $11 = (($9) - ($10))|0;
  $12 = (($11) + 1)|0;
  (_strncpy(($4|0),($original_name|0),($12|0))|0);
  $13 = (($4) + ($12)|0);
  HEAP8[$13>>0] = 0;
  $14 = (($7) + 1|0);
  $slash$0 = $14;
 }
 $15 = (_strlen(($4|0))|0);
 $16 = (($2) - ($15))|0;
 (_strncat($4,$insertion,$16)|0);
 $17 = (_strlen(($4|0))|0);
 $18 = (($2) - ($17))|0;
 (_strncat($4,$slash$0,$18)|0);
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function _raccess_guess_apple_generic($stream,$magic,$result_offset) {
 $stream = $stream|0;
 $magic = $magic|0;
 $result_offset = $result_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (_FT_Stream_ReadULong($stream,$error)|0);
 $1 = HEAP32[$error>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $3 = ($0|0)==($magic|0);
   if ($3) {
    (_FT_Stream_ReadULong($stream,$error)|0);
    $4 = HEAP32[$error>>2]|0;
    $5 = ($4|0)==(0);
    if ($5) {
     $6 = (_FT_Stream_Skip($stream,16)|0);
     HEAP32[$error>>2] = $6;
     $7 = ($6|0)==(0);
     if ($7) {
      $8 = (_FT_Stream_ReadUShort($stream,$error)|0);
      $9 = HEAP32[$error>>2]|0;
      $10 = ($9|0)==(0);
      if ($10) {
       $11 = $8&65535;
       $12 = ($8<<16>>16)==(0);
       if ($12) {
        $$0 = 2;
       } else {
        $i$01 = 0;
        while(1) {
         $13 = (_FT_Stream_ReadULong($stream,$error)|0);
         $14 = HEAP32[$error>>2]|0;
         $15 = ($14|0)==(0);
         if (!($15)) {
          $$0 = $14;
          break L1;
         }
         $16 = ($13|0)==(2);
         if ($16) {
          $17 = (_FT_Stream_ReadULong($stream,$error)|0);
          $18 = HEAP32[$error>>2]|0;
          $19 = ($18|0)==(0);
          if ($19) {
           (_FT_Stream_ReadULong($stream,$error)|0);
           $20 = HEAP32[$error>>2]|0;
           $21 = ($20|0)==(0);
           if ($21) {
            break;
           }
          }
         } else {
          $22 = (_FT_Stream_Skip($stream,8)|0);
          HEAP32[$error>>2] = $22;
          $23 = ($22|0)==(0);
          if (!($23)) {
           $$0 = $22;
           break L1;
          }
         }
         $24 = (($i$01) + 1)|0;
         $25 = ($24|0)<($11|0);
         if ($25) {
          $i$01 = $24;
         } else {
          $$0 = 2;
          break L1;
         }
        }
        HEAP32[$result_offset>>2] = $17;
        $$0 = 0;
       }
      } else {
       $$0 = $9;
      }
     } else {
      $$0 = $6;
     }
    } else {
     $$0 = $4;
    }
   } else {
    $$0 = 2;
   }
  } else {
   $$0 = $1;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _FT_Stream_OpenMemory($stream,$base,$size) {
 $stream = $stream|0;
 $base = $base|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$stream>>2] = $base;
 $0 = (($stream) + 4|0);
 HEAP32[$0>>2] = $size;
 $1 = (($stream) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($stream) + 32|0);
 HEAP32[$2>>2] = 0;
 $3 = (($stream) + 20|0);
 HEAP32[$3>>2] = 0;
 $4 = (($stream) + 24|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function _FT_Stream_Close($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($stream|0)==(0|0);
 if (!($0)) {
  $1 = (($stream) + 24|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   FUNCTION_TABLE_vi[$2 & 4095]($stream);
  }
 }
 STACKTOP = sp;return;
}
function _FT_Stream_Seek($stream,$pos) {
 $stream = $stream|0;
 $pos = $pos|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $5 = (($stream) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6>>>0)<($pos>>>0);
  $$1 = $7 ? 85 : 0;
  $error$0 = $$1;
 } else {
  $3 = (FUNCTION_TABLE_iiiii[$1 & 511]($stream,$pos,0,0)|0);
  $4 = ($3|0)==(0);
  $$ = $4 ? 0 : 85;
  $error$0 = $$;
 }
 $8 = ($error$0|0)==(0);
 if (!($8)) {
  STACKTOP = sp;return ($error$0|0);
 }
 $9 = (($stream) + 8|0);
 HEAP32[$9>>2] = $pos;
 STACKTOP = sp;return ($error$0|0);
}
function _FT_Stream_Skip($stream,$distance) {
 $stream = $stream|0;
 $distance = $distance|0;
 var $$$i = 0, $$0 = 0, $$1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)<(0);
 if ($0) {
  $$0 = 85;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($stream) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($distance))|0;
 $4 = (($stream) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $9 = (($stream) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10>>>0)<($3>>>0);
  $$1$i = $11 ? 85 : 0;
  $error$0$i = $$1$i;
 } else {
  $7 = (FUNCTION_TABLE_iiiii[$5 & 511]($stream,$3,0,0)|0);
  $8 = ($7|0)==(0);
  $$$i = $8 ? 0 : 85;
  $error$0$i = $$$i;
 }
 $12 = ($error$0$i|0)==(0);
 if (!($12)) {
  $$0 = $error$0$i;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = $3;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Stream_Pos($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function _FT_Stream_Read($stream,$buffer,$count) {
 $stream = $stream|0;
 $buffer = $buffer|0;
 $count = $count|0;
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$$i = 0, $read_bytes$1$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($stream) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)>($1>>>0);
 if (!($4)) {
  $$0$i = 85;
  STACKTOP = sp;return ($$0$i|0);
 }
 $5 = (($stream) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $9 = (($3) - ($1))|0;
  $10 = ($9>>>0)>($count>>>0);
  $count$$i = $10 ? $count : $9;
  $11 = HEAP32[$stream>>2]|0;
  $12 = (($11) + ($1)|0);
  _memcpy(($buffer|0),($12|0),($count$$i|0))|0;
  $read_bytes$1$i = $count$$i;
 } else {
  $8 = (FUNCTION_TABLE_iiiii[$6 & 511]($stream,$1,$buffer,$count)|0);
  $read_bytes$1$i = $8;
 }
 $13 = (($read_bytes$1$i) + ($1))|0;
 HEAP32[$0>>2] = $13;
 $14 = ($read_bytes$1$i>>>0)<($count>>>0);
 $$$i = $14 ? 85 : 0;
 $$0$i = $$$i;
 STACKTOP = sp;return ($$0$i|0);
}
function _FT_Stream_ReadAt($stream,$pos,$buffer,$count) {
 $stream = $stream|0;
 $pos = $pos|0;
 $buffer = $buffer|0;
 $count = $count|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$ = 0, $read_bytes$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($pos>>>0);
 if (!($2)) {
  $$0 = 85;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($stream) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $7 = (($1) - ($pos))|0;
  $8 = ($7>>>0)>($count>>>0);
  $count$ = $8 ? $count : $7;
  $9 = HEAP32[$stream>>2]|0;
  $10 = (($9) + ($pos)|0);
  _memcpy(($buffer|0),($10|0),($count$|0))|0;
  $read_bytes$1 = $count$;
 } else {
  $6 = (FUNCTION_TABLE_iiiii[$4 & 511]($stream,$pos,$buffer,$count)|0);
  $read_bytes$1 = $6;
 }
 $11 = (($read_bytes$1) + ($pos))|0;
 $12 = (($stream) + 8|0);
 HEAP32[$12>>2] = $11;
 $13 = ($read_bytes$1>>>0)<($count>>>0);
 $$ = $13 ? 85 : 0;
 $$0 = $$;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Stream_ExtractFrame($stream,$count,$pbytes) {
 $stream = $stream|0;
 $count = $count|0;
 $pbytes = $pbytes|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_FT_Stream_EnterFrame($stream,$count)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return ($0|0);
 }
 $2 = (($stream) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$pbytes>>2] = $3;
 HEAP32[$2>>2] = 0;
 $4 = (($stream) + 36|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return ($0|0);
}
function _FT_Stream_EnterFrame($stream,$count) {
 $stream = $stream|0;
 $count = $count|0;
 var $$pre = 0, $$pre$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = (($stream) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $23 = (($stream) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($stream) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($24>>>0)>=($26>>>0);
  $28 = (($26) - ($24))|0;
  $29 = ($28>>>0)<($count>>>0);
  $or$cond = $27 | $29;
  if ($or$cond) {
   HEAP32[$error>>2] = 85;
   $35 = 85;
   STACKTOP = sp;return ($35|0);
  } else {
   $30 = HEAP32[$stream>>2]|0;
   $31 = (($30) + ($24)|0);
   $32 = (($stream) + 32|0);
   HEAP32[$32>>2] = $31;
   $$sum = (($24) + ($count))|0;
   $33 = (($30) + ($$sum)|0);
   $34 = (($stream) + 36|0);
   HEAP32[$34>>2] = $33;
   HEAP32[$23>>2] = $$sum;
   $35 = 0;
   STACKTOP = sp;return ($35|0);
  }
 }
 $3 = (($stream) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($stream) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6>>>0)<($count>>>0);
 if ($7) {
  HEAP32[$error>>2] = 85;
  $35 = 85;
  STACKTOP = sp;return ($35|0);
 }
 $8 = (_ft_mem_qalloc($4,$count,$error)|0);
 HEAP32[$stream>>2] = $8;
 $9 = HEAP32[$error>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $35 = $9;
  STACKTOP = sp;return ($35|0);
 }
 $11 = HEAP32[$0>>2]|0;
 $12 = (($stream) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiiii[$11 & 511]($stream,$13,$8,$count)|0);
 $15 = ($14>>>0)<($count>>>0);
 $16 = HEAP32[$stream>>2]|0;
 if ($15) {
  _ft_mem_free($4,$16);
  HEAP32[$stream>>2] = 0;
  HEAP32[$error>>2] = 85;
  $$pre = 85;$18 = 0;
 } else {
  $$pre$pre = HEAP32[$error>>2]|0;
  $$pre = $$pre$pre;$18 = $16;
 }
 $17 = (($stream) + 32|0);
 HEAP32[$17>>2] = $18;
 $19 = (($18) + ($count)|0);
 $20 = (($stream) + 36|0);
 HEAP32[$20>>2] = $19;
 $21 = HEAP32[$12>>2]|0;
 $22 = (($21) + ($14))|0;
 HEAP32[$12>>2] = $22;
 $35 = $$pre;
 STACKTOP = sp;return ($35|0);
}
function _FT_Stream_ReleaseFrame($stream,$pbytes) {
 $stream = $stream|0;
 $pbytes = $pbytes|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($stream|0)==(0|0);
 if (!($0)) {
  $1 = (($stream) + 20|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($stream) + 28|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = HEAP32[$pbytes>>2]|0;
   _ft_mem_free($5,$6);
   HEAP32[$pbytes>>2] = 0;
  }
 }
 HEAP32[$pbytes>>2] = 0;
 STACKTOP = sp;return;
}
function _FT_Stream_ExitFrame($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($stream) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$stream>>2]|0;
  _ft_mem_free($4,$5);
  HEAP32[$stream>>2] = 0;
 }
 $6 = (($stream) + 32|0);
 HEAP32[$6>>2] = 0;
 $7 = (($stream) + 36|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function _FT_Stream_GetChar($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($stream) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if (!($4)) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $5 = (($1) + 1|0);
 HEAP32[$0>>2] = $5;
 $6 = HEAP8[$1>>0]|0;
 $result$0 = $6;
 STACKTOP = sp;return ($result$0|0);
}
function _FT_Stream_GetUShort($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1|0);
 $3 = (($stream) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if (!($5)) {
  $p$0 = $1;$result$0 = 0;
  HEAP32[$0>>2] = $p$0;
  STACKTOP = sp;return ($result$0|0);
 }
 $6 = (($1) + 2|0);
 $7 = HEAP8[$1>>0]|0;
 $8 = $7&255;
 $9 = $8 << 8;
 $10 = HEAP8[$2>>0]|0;
 $11 = $10&255;
 $12 = $9 | $11;
 $13 = $12&65535;
 $p$0 = $6;$result$0 = $13;
 HEAP32[$0>>2] = $p$0;
 STACKTOP = sp;return ($result$0|0);
}
function _FT_Stream_GetULong($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 3|0);
 $3 = (($stream) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 if (!($5)) {
  $p$0 = $1;$result$0 = 0;
  HEAP32[$0>>2] = $p$0;
  STACKTOP = sp;return ($result$0|0);
 }
 $6 = (($1) + 4|0);
 $7 = HEAP8[$1>>0]|0;
 $8 = $7&255;
 $9 = $8 << 24;
 $10 = (($1) + 1|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 16;
 $14 = $13 | $9;
 $15 = (($1) + 2|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $17 << 8;
 $19 = $14 | $18;
 $20 = HEAP8[$2>>0]|0;
 $21 = $20&255;
 $22 = $19 | $21;
 $p$0 = $6;$result$0 = $22;
 HEAP32[$0>>2] = $p$0;
 STACKTOP = sp;return ($result$0|0);
}
function _FT_Stream_ReadChar($stream,$error) {
 $stream = $stream|0;
 $error = $error|0;
 var $$0 = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $result = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $result = sp;
 HEAP8[$result>>0] = 0;
 HEAP32[$error>>2] = 0;
 $0 = (($stream) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = (($stream) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 if ($2) {
  $7 = (($stream) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($4>>>0)<($8>>>0);
  if ($9) {
   $10 = HEAP32[$stream>>2]|0;
   $11 = (($10) + ($4)|0);
   $12 = HEAP8[$11>>0]|0;
   HEAP8[$result>>0] = $12;
   $14 = $4;$15 = $12;
   label = 6;
  } else {
   label = 7;
  }
 } else {
  $5 = (FUNCTION_TABLE_iiiii[$1 & 511]($stream,$4,$result,1)|0);
  $6 = ($5|0)==(1);
  if ($6) {
   $$pre = HEAP32[$3>>2]|0;
   $$pre1 = HEAP8[$result>>0]|0;
   $14 = $$pre;$15 = $$pre1;
   label = 6;
  } else {
   label = 7;
  }
 }
 if ((label|0) == 6) {
  $13 = (($14) + 1)|0;
  HEAP32[$3>>2] = $13;
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 7) {
  HEAP32[$error>>2] = 85;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _FT_Stream_ReadUShort($stream,$error) {
 $stream = $stream|0;
 $error = $error|0;
 var $$0 = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$01 = 0, $reads = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reads = sp;
 HEAP32[$error>>2] = 0;
 $0 = (($stream) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 $3 = (($stream) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 do {
  if ($5) {
   $6 = (($stream) + 20|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $11 = HEAP32[$stream>>2]|0;
    $12 = (($11) + ($1)|0);
    $13 = ($12|0)==(0|0);
    if ($13) {
     $23 = $1;$result$0 = 0;
    } else {
     $$pre = $1;$p$01 = $12;
     label = 6;
    }
   } else {
    $9 = (FUNCTION_TABLE_iiiii[$7 & 511]($stream,$1,$reads,2)|0);
    $10 = ($9|0)==(2);
    if (!($10)) {
     break;
    }
    $$pre$pre = HEAP32[$0>>2]|0;
    $$pre = $$pre$pre;$p$01 = $reads;
    label = 6;
   }
   if ((label|0) == 6) {
    $14 = HEAP8[$p$01>>0]|0;
    $15 = $14&255;
    $16 = $15 << 8;
    $17 = (($p$01) + 1|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18&255;
    $20 = $16 | $19;
    $21 = $20&65535;
    $23 = $$pre;$result$0 = $21;
   }
   $22 = (($23) + 2)|0;
   HEAP32[$0>>2] = $22;
   $$0 = $result$0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$error>>2] = 85;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Stream_ReadULong($stream,$error) {
 $stream = $stream|0;
 $error = $error|0;
 var $$0 = 0, $$pre = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$01 = 0, $reads = 0, $result$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $reads = sp;
 HEAP32[$error>>2] = 0;
 $0 = (($stream) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 3)|0;
 $3 = (($stream) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2>>>0)<($4>>>0);
 do {
  if ($5) {
   $6 = (($stream) + 20|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $11 = HEAP32[$stream>>2]|0;
    $12 = (($11) + ($1)|0);
    $13 = ($12|0)==(0|0);
    if ($13) {
     $32 = $1;$result$0 = 0;
    } else {
     $$pre = $1;$p$01 = $12;
     label = 6;
    }
   } else {
    $9 = (FUNCTION_TABLE_iiiii[$7 & 511]($stream,$1,$reads,4)|0);
    $10 = ($9|0)==(4);
    if (!($10)) {
     break;
    }
    $$pre$pre = HEAP32[$0>>2]|0;
    $$pre = $$pre$pre;$p$01 = $reads;
    label = 6;
   }
   if ((label|0) == 6) {
    $14 = HEAP8[$p$01>>0]|0;
    $15 = $14&255;
    $16 = $15 << 24;
    $17 = (($p$01) + 1|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = $18&255;
    $20 = $19 << 16;
    $21 = $20 | $16;
    $22 = (($p$01) + 2|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = $24 << 8;
    $26 = $21 | $25;
    $27 = (($p$01) + 3|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28&255;
    $30 = $26 | $29;
    $32 = $$pre;$result$0 = $30;
   }
   $31 = (($32) + 4)|0;
   HEAP32[$0>>2] = $31;
   $$0 = $result$0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$error>>2] = 85;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Stream_ReadFields($stream,$fields,$structure) {
 $stream = $stream|0;
 $fields = $fields|0;
 $structure = $structure|0;
 var $$0 = 0, $$01 = 0, $$01$be = 0, $$01$ph = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cursor$0 = 0, $cursor$0$be = 0, $cursor$0$ph = 0, $cursor$1 = 0, $error$1 = 0, $frame_accessed$0$ph = 0, $or$cond = 0, $sign_shift$0 = 0, $value$0 = 0, $value$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($fields|0)==(0|0);
 $1 = ($stream|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($stream) + 32|0);
 $3 = (($stream) + 36|0);
 $$01$ph = $fields;$frame_accessed$0$ph = 0;
 L4: while(1) {
  $cursor$0$ph = HEAP32[$2>>2]|0;
  $$01 = $$01$ph;$cursor$0 = $cursor$0$ph;
  L6: while(1) {
   $4 = HEAP8[$$01>>0]|0;
   $5 = $4&255;
   switch ($5|0) {
   case 25: case 24:  {
    $12 = (($$01) + 1|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = $13&255;
    $15 = (($cursor$0) + ($14)|0);
    $16 = HEAP32[$3>>2]|0;
    $17 = ($15>>>0)>($16>>>0);
    if ($17) {
     $error$1 = 85;
     break L4;
    }
    $18 = ($4<<24>>24)==(24);
    if ($18) {
     $19 = (($$01) + 2|0);
     $20 = HEAP16[$19>>1]|0;
     $21 = $20&65535;
     $22 = (($structure) + ($21)|0);
     _memcpy(($22|0),($cursor$0|0),($14|0))|0;
     $cursor$0$be = $15;
    } else {
     $cursor$0$be = $15;
    }
    break;
   }
   case 14: case 15:  {
    $34 = (($cursor$0) + 2|0);
    $35 = (($cursor$0) + 1|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = $36&255;
    $38 = $37 << 8;
    $39 = HEAP8[$cursor$0>>0]|0;
    $40 = $39&255;
    $41 = $38 | $40;
    $cursor$1 = $34;$sign_shift$0 = 16;$value$0 = $41;
    label = 18;
    break;
   }
   case 18: case 19:  {
    $60 = (($cursor$0) + 4|0);
    $61 = (($cursor$0) + 3|0);
    $62 = HEAP8[$61>>0]|0;
    $63 = $62&255;
    $64 = $63 << 24;
    $65 = (($cursor$0) + 2|0);
    $66 = HEAP8[$65>>0]|0;
    $67 = $66&255;
    $68 = $67 << 16;
    $69 = $68 | $64;
    $70 = (($cursor$0) + 1|0);
    $71 = HEAP8[$70>>0]|0;
    $72 = $71&255;
    $73 = $72 << 8;
    $74 = $69 | $73;
    $75 = HEAP8[$cursor$0>>0]|0;
    $76 = $75&255;
    $77 = $74 | $76;
    $cursor$1 = $60;$sign_shift$0 = 0;$value$0 = $77;
    label = 18;
    break;
   }
   case 20: case 21:  {
    $78 = (($cursor$0) + 3|0);
    $79 = HEAP8[$cursor$0>>0]|0;
    $80 = $79&255;
    $81 = $80 << 16;
    $82 = (($cursor$0) + 1|0);
    $83 = HEAP8[$82>>0]|0;
    $84 = $83&255;
    $85 = $84 << 8;
    $86 = $85 | $81;
    $87 = (($cursor$0) + 2|0);
    $88 = HEAP8[$87>>0]|0;
    $89 = $88&255;
    $90 = $86 | $89;
    $cursor$1 = $78;$sign_shift$0 = 8;$value$0 = $90;
    label = 18;
    break;
   }
   case 12: case 13:  {
    $26 = (($cursor$0) + 2|0);
    $27 = HEAP8[$cursor$0>>0]|0;
    $28 = $27&255;
    $29 = $28 << 8;
    $30 = (($cursor$0) + 1|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = $31&255;
    $33 = $29 | $32;
    $cursor$1 = $26;$sign_shift$0 = 16;$value$0 = $33;
    label = 18;
    break;
   }
   case 9: case 8:  {
    $23 = (($cursor$0) + 1|0);
    $24 = HEAP8[$cursor$0>>0]|0;
    $25 = $24&255;
    $cursor$1 = $23;$sign_shift$0 = 24;$value$0 = $25;
    label = 18;
    break;
   }
   case 22: case 23:  {
    $91 = (($cursor$0) + 3|0);
    $92 = (($cursor$0) + 2|0);
    $93 = HEAP8[$92>>0]|0;
    $94 = $93&255;
    $95 = $94 << 16;
    $96 = (($cursor$0) + 1|0);
    $97 = HEAP8[$96>>0]|0;
    $98 = $97&255;
    $99 = $98 << 8;
    $100 = $99 | $95;
    $101 = HEAP8[$cursor$0>>0]|0;
    $102 = $101&255;
    $103 = $100 | $102;
    $cursor$1 = $91;$sign_shift$0 = 8;$value$0 = $103;
    label = 18;
    break;
   }
   case 4:  {
    break L6;
    break;
   }
   case 16: case 17:  {
    $42 = (($cursor$0) + 4|0);
    $43 = HEAP8[$cursor$0>>0]|0;
    $44 = $43&255;
    $45 = $44 << 24;
    $46 = (($cursor$0) + 1|0);
    $47 = HEAP8[$46>>0]|0;
    $48 = $47&255;
    $49 = $48 << 16;
    $50 = $49 | $45;
    $51 = (($cursor$0) + 2|0);
    $52 = HEAP8[$51>>0]|0;
    $53 = $52&255;
    $54 = $53 << 8;
    $55 = $50 | $54;
    $56 = (($cursor$0) + 3|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = $57&255;
    $59 = $55 | $58;
    $cursor$1 = $42;$sign_shift$0 = 0;$value$0 = $59;
    label = 18;
    break;
   }
   default: {
    label = 17;
    break L4;
   }
   }
   do {
    if ((label|0) == 18) {
     label = 0;
     $104 = $4 & 1;
     $105 = ($104<<24>>24)==(0);
     if ($105) {
      $value$1 = $value$0;
     } else {
      $106 = $value$0 << $sign_shift$0;
      $107 = $106 >> $sign_shift$0;
      $value$1 = $107;
     }
     $108 = (($$01) + 2|0);
     $109 = HEAP16[$108>>1]|0;
     $110 = $109&65535;
     $111 = (($structure) + ($110)|0);
     $112 = (($$01) + 1|0);
     $113 = HEAP8[$112>>0]|0;
     $114 = $113&255;
     if ((($114|0) == 2)) {
      $116 = $value$1&65535;
      HEAP16[$111>>1] = $116;
      $cursor$0$be = $cursor$1;
      break;
     } else if ((($114|0) == 1)) {
      $115 = $value$1&255;
      HEAP8[$111>>0] = $115;
      $cursor$0$be = $cursor$1;
      break;
     } else if ((($114|0) == 4)) {
      HEAP32[$111>>2] = $value$1;
      $cursor$0$be = $cursor$1;
      break;
     } else {
      HEAP32[$111>>2] = $value$1;
      $cursor$0$be = $cursor$1;
      break;
     }
    }
   } while(0);
   $$01$be = (($$01) + 4|0);
   $$01 = $$01$be;$cursor$0 = $cursor$0$be;
  }
  $6 = (($$01) + 2|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = $7&65535;
  $9 = (_FT_Stream_EnterFrame($stream,$8)|0);
  $10 = ($9|0)==(0);
  if (!($10)) {
   $error$1 = $9;
   break;
  }
  $11 = (($$01) + 4|0);
  $$01$ph = $11;$frame_accessed$0$ph = 1;
 }
 if ((label|0) == 17) {
  HEAP32[$2>>2] = $cursor$0;
  $error$1 = 0;
 }
 $117 = ($frame_accessed$0$ph<<24>>24)==(0);
 if ($117) {
  $$0 = $error$1;
  STACKTOP = sp;return ($$0|0);
 }
 $118 = (($stream) + 20|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = ($119|0)==(0|0);
 if (!($120)) {
  $121 = (($stream) + 28|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = HEAP32[$stream>>2]|0;
  _ft_mem_free($122,$123);
  HEAP32[$stream>>2] = 0;
 }
 HEAP32[$2>>2] = 0;
 HEAP32[$3>>2] = 0;
 $$0 = $error$1;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Stream_Open($stream,$filepathname) {
 $stream = $stream|0;
 $filepathname = $filepathname|0;
 var $$0 = 0, $$c = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $filepathname$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($stream|0)==(0|0);
 if ($0) {
  $$0 = 40;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($stream) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($stream) + 16|0);
 $filepathname$c = $filepathname;
 HEAP32[$2>>2] = $filepathname$c;
 HEAP32[$stream>>2] = 0;
 $3 = (($stream) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($stream) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($stream) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (_fopen(($filepathname|0),(806664|0))|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 (_fseek(($6|0),0,2)|0);
 $8 = (_ftell(($6|0))|0);
 $9 = (($stream) + 4|0);
 HEAP32[$9>>2] = $8;
 $10 = ($8|0)==(0);
 if ($10) {
  (_fclose(($6|0))|0);
  $$0 = 81;
  STACKTOP = sp;return ($$0|0);
 } else {
  (_fseek(($6|0),0,0)|0);
  $$c = $6;
  HEAP32[$1>>2] = $$c;
  HEAP32[$4>>2] = 278;
  HEAP32[$5>>2] = 3731;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _ft_ansi_stream_io($stream,$offset,$buffer,$count) {
 $stream = $stream|0;
 $offset = $offset|0;
 $buffer = $buffer|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  $1 = (($stream) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2>>>0)<($offset>>>0);
  if ($3) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $4 = (($stream) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($stream) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==($offset|0);
 if (!($8)) {
  (_fseek(($5|0),($offset|0),0)|0);
 }
 $9 = (_fread(($buffer|0),1,($count|0),($5|0))|0);
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function _ft_ansi_stream_close($stream) {
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($stream) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 (_fclose(($1|0))|0);
 HEAP32[$0>>2] = 0;
 $2 = (($stream) + 4|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$stream>>2] = 0;
 STACKTOP = sp;return;
}
function _FT_Vector_Length($vec) {
 $vec = $vec|0;
 var $$$i = 0, $$$i1 = 0, $$0 = 0, $$1$i = 0, $$shift$3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $exitcond$i = 0, $i$0$i = 0, $shift$1$i = 0, $shift$2$i = 0, $shift$3$i = 0, $shift$5$i = 0, $x$0$i = 0;
 var $x$2$i = 0, $x$3$i = 0, $y$0$i = 0, $y$2$i = 0, $y$3$i = 0, $z$1$i = 0, $z$2$i = 0, $z$3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $vec;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = ($2|0)==(0);
 if ($6) {
  $7 = ($5|0)>(-1);
  $8 = (0 - ($5))|0;
  $9 = $7 ? $5 : $8;
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ($5|0)==(0);
 $11 = ($2|0)>(-1);
 $12 = (0 - ($2))|0;
 $13 = $11 ? $2 : $12;
 if ($10) {
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = ($5|0)>(-1);
 $15 = (0 - ($5))|0;
 $16 = $14 ? $5 : $15;
 $17 = $16 | $13;
 $18 = ($17|0)>(65535);
 $19 = $17 >> 16;
 $$$i = $18 ? $19 : $17;
 $$1$i = $18 ? 16 : 0;
 $20 = ($$$i|0)>(255);
 if ($20) {
  $21 = $$$i >> 8;
  $22 = $$1$i | 8;
  $shift$1$i = $22;$z$1$i = $21;
 } else {
  $shift$1$i = $$1$i;$z$1$i = $$$i;
 }
 $23 = ($z$1$i|0)>(15);
 if ($23) {
  $24 = $z$1$i >> 4;
  $25 = (($shift$1$i) + 4)|0;
  $shift$2$i = $25;$z$2$i = $24;
 } else {
  $shift$2$i = $shift$1$i;$z$2$i = $z$1$i;
 }
 $26 = ($z$2$i|0)>(3);
 if ($26) {
  $27 = $z$2$i >> 2;
  $28 = (($shift$2$i) + 2)|0;
  $shift$3$i = $28;$z$3$i = $27;
 } else {
  $shift$3$i = $shift$2$i;$z$3$i = $z$2$i;
 }
 $29 = ($z$3$i|0)>(1);
 $30 = $29&1;
 $$shift$3$i = (($30) + ($shift$3$i))|0;
 $31 = ($$shift$3$i|0)<(28);
 if ($31) {
  $32 = (27 - ($$shift$3$i))|0;
  $33 = $2 << $32;
  $34 = $5 << $32;
  $40 = $33;$43 = $34;$shift$5$i = $32;
 } else {
  $35 = (($$shift$3$i) + -27)|0;
  $36 = $2 >> $35;
  $37 = $5 >> $35;
  $38 = (27 - ($$shift$3$i))|0;
  $40 = $36;$43 = $37;$shift$5$i = $38;
 }
 $39 = ($40|0)<(0);
 if ($39) {
  $41 = (0 - ($40))|0;
  $42 = (0 - ($43))|0;
  $x$0$i = $41;$y$0$i = $42;
 } else {
  $x$0$i = $40;$y$0$i = $43;
 }
 $44 = ($y$0$i|0)<(0);
 $45 = $x$0$i << 1;
 if ($44) {
  $46 = (($y$0$i) + ($45))|0;
  $47 = $y$0$i << 1;
  $48 = (($x$0$i) - ($47))|0;
  $i$0$i = 0;$x$2$i = $48;$y$2$i = $46;
 } else {
  $49 = (($y$0$i) - ($45))|0;
  $50 = $y$0$i << 1;
  $51 = (($50) + ($x$0$i))|0;
  $i$0$i = 0;$x$2$i = $51;$y$2$i = $49;
 }
 while(1) {
  $52 = ($y$2$i|0)<(0);
  $53 = $x$2$i >> $i$0$i;
  if ($52) {
   $54 = (($y$2$i) + ($53))|0;
   $55 = $y$2$i >> $i$0$i;
   $56 = (($x$2$i) - ($55))|0;
   $x$3$i = $56;$y$3$i = $54;
  } else {
   $57 = (($y$2$i) - ($53))|0;
   $58 = $y$2$i >> $i$0$i;
   $59 = (($58) + ($x$2$i))|0;
   $x$3$i = $59;$y$3$i = $57;
  }
  $60 = (($i$0$i) + 1)|0;
  $exitcond$i = ($60|0)==(23);
  if ($exitcond$i) {
   break;
  } else {
   $i$0$i = $60;$x$2$i = $x$3$i;$y$2$i = $y$3$i;
  }
 }
 $61 = ($x$3$i|0)>(-1);
 $62 = (0 - ($x$3$i))|0;
 $63 = $61 ? $x$3$i : $62;
 $64 = $63 >>> 16;
 $65 = $63 & 65535;
 $66 = ($64*17797)|0;
 $67 = ($65*17797)|0;
 $68 = ($64*47593)|0;
 $69 = (($67) + ($68))|0;
 $70 = ($65*47593)|0;
 $71 = $70 >>> 16;
 $72 = ($69>>>0)>=($71>>>0);
 $73 = $72 ? $69 : $71;
 $74 = (($69) + ($71))|0;
 $75 = $74 >>> 16;
 $76 = (($75) + ($66))|0;
 $77 = ($74>>>0)<($73>>>0);
 $78 = (($76) + 65536)|0;
 $$$i1 = $77 ? $78 : $76;
 $79 = (0 - ($$$i1))|0;
 $80 = $61 ? $$$i1 : $79;
 $81 = ($shift$5$i|0)>(0);
 if ($81) {
  $82 = (($shift$5$i) + -1)|0;
  $83 = 1 << $82;
  $84 = (($80) + ($83))|0;
  $85 = $84 >> $shift$5$i;
  $$0 = $85;
  STACKTOP = sp;return ($$0|0);
 } else {
  $86 = (0 - ($shift$5$i))|0;
  $87 = $80 << $86;
  $$0 = $87;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _ft_mem_alloc($memory,$size,$p_error) {
 $memory = $memory|0;
 $size = $size|0;
 $p_error = $p_error|0;
 var $$$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $block$0$i3 = 0, $error$0$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)>(0);
 if ($0) {
  $3 = (($memory) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (FUNCTION_TABLE_iii[$4 & 4095]($memory,$size)|0);
  $6 = ($5|0)==(0|0);
  $$$i = $6 ? 64 : 0;
  if ($6) {
   $block$0$i3 = 0;$error$0$i2 = $$$i;
  } else {
   _memset(($5|0),0,($size|0))|0;
   $block$0$i3 = $5;$error$0$i2 = $$$i;
  }
 } else {
  $1 = $size >> 31;
  $2 = $1 & 6;
  $block$0$i3 = 0;$error$0$i2 = $2;
 }
 HEAP32[$p_error>>2] = $error$0$i2;
 STACKTOP = sp;return ($block$0$i3|0);
}
function _ft_mem_qalloc($memory,$size,$p_error) {
 $memory = $memory|0;
 $size = $size|0;
 $p_error = $p_error|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $block$0 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)>(0);
 if ($0) {
  $1 = (($memory) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (FUNCTION_TABLE_iii[$2 & 4095]($memory,$size)|0);
  $4 = ($3|0)==(0|0);
  $$ = $4 ? 64 : 0;
  $block$0 = $3;$error$0 = $$;
 } else {
  $5 = $size >> 31;
  $6 = $5 & 6;
  $block$0 = 0;$error$0 = $6;
 }
 HEAP32[$p_error>>2] = $error$0;
 STACKTOP = sp;return ($block$0|0);
}
function _ft_mem_realloc($memory,$item_size,$cur_count,$new_count,$block,$p_error) {
 $memory = $memory|0;
 $item_size = $item_size|0;
 $cur_count = $cur_count|0;
 $new_count = $new_count|0;
 $block = $block|0;
 $p_error = $p_error|0;
 var $$$i = 0, $$$i$i$i = 0, $$0$i = 0, $$0$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$$i = 0, $error$0$i2$i4$i = 0, $error$0$i2$i4$i2 = 0, $or$cond = 0;
 var $or$cond2$i = 0, $or$cond3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $cur_count | $item_size;
 $1 = $0 | $new_count;
 $2 = ($1|0)<(0);
 if ($2) {
  $$0$i3 = $block;$error$0$i2$i4$i2 = 6;
  HEAP32[$p_error>>2] = $error$0$i2$i4$i2;
  STACKTOP = sp;return ($$0$i3|0);
 }
 $3 = ($new_count|0)==(0);
 $4 = ($item_size|0)==(0);
 $or$cond2$i = $3 | $4;
 do {
  if ($or$cond2$i) {
   $5 = ($block|0)==(0|0);
   if ($5) {
    $$0$i = 0;$error$0$i2$i4$i = 0;
   } else {
    $6 = (($memory) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    FUNCTION_TABLE_vii[$7 & 4095]($memory,$block);
    $$0$i = 0;$error$0$i2$i4$i = 0;
   }
  } else {
   $8 = (2147483647 / ($item_size|0))&-1;
   $9 = ($8|0)<($new_count|0);
   if ($9) {
    $$0$i3 = $block;$error$0$i2$i4$i2 = 10;
    HEAP32[$p_error>>2] = $error$0$i2$i4$i2;
    STACKTOP = sp;return ($$0$i3|0);
   }
   $10 = ($cur_count|0)==(0);
   $11 = ($block|0)==(0|0);
   $or$cond3$i = $10 & $11;
   if (!($or$cond3$i)) {
    $20 = Math_imul($cur_count, $item_size)|0;
    $21 = Math_imul($new_count, $item_size)|0;
    $22 = (($memory) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (FUNCTION_TABLE_iiiii[$23 & 511]($memory,$20,$21,$block)|0);
    $25 = ($24|0)==(0|0);
    $$$i = $25 ? 64 : 0;
    $block$$i = $25 ? $block : $24;
    $$0$i = $block$$i;$error$0$i2$i4$i = $$$i;
    break;
   }
   $12 = Math_imul($new_count, $item_size)|0;
   $13 = ($12|0)>(0);
   if (!($13)) {
    $14 = $12 >> 31;
    $15 = $14 & 6;
    $$0$i = 0;$error$0$i2$i4$i = $15;
    break;
   }
   $16 = (($memory) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (FUNCTION_TABLE_iii[$17 & 4095]($memory,$12)|0);
   $19 = ($18|0)==(0|0);
   $$$i$i$i = $19 ? 64 : 0;
   if ($19) {
    $$0$i = 0;$error$0$i2$i4$i = $$$i$i$i;
   } else {
    _memset(($18|0),0,($12|0))|0;
    $$0$i = $18;$error$0$i2$i4$i = $$$i$i$i;
   }
  }
 } while(0);
 $26 = ($error$0$i2$i4$i|0)==(0);
 $27 = ($new_count|0)>($cur_count|0);
 $or$cond = $26 & $27;
 if (!($or$cond)) {
  $$0$i3 = $$0$i;$error$0$i2$i4$i2 = $error$0$i2$i4$i;
  HEAP32[$p_error>>2] = $error$0$i2$i4$i2;
  STACKTOP = sp;return ($$0$i3|0);
 }
 $28 = Math_imul($cur_count, $item_size)|0;
 $29 = (($$0$i) + ($28)|0);
 $30 = (($new_count) - ($cur_count))|0;
 $31 = Math_imul($30, $item_size)|0;
 _memset(($29|0),0,($31|0))|0;
 $$0$i3 = $$0$i;$error$0$i2$i4$i2 = 0;
 HEAP32[$p_error>>2] = $error$0$i2$i4$i2;
 STACKTOP = sp;return ($$0$i3|0);
}
function _ft_mem_qrealloc($memory,$item_size,$cur_count,$new_count,$block,$p_error) {
 $memory = $memory|0;
 $item_size = $item_size|0;
 $cur_count = $cur_count|0;
 $new_count = $new_count|0;
 $block = $block|0;
 $p_error = $p_error|0;
 var $$ = 0, $$$i$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$ = 0, $error$0$i2$i4 = 0, $or$cond2 = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $cur_count | $item_size;
 $1 = $0 | $new_count;
 $2 = ($1|0)<(0);
 do {
  if ($2) {
   $$0 = $block;$error$0$i2$i4 = 6;
  } else {
   $3 = ($new_count|0)==(0);
   $4 = ($item_size|0)==(0);
   $or$cond2 = $3 | $4;
   if ($or$cond2) {
    $5 = ($block|0)==(0|0);
    if ($5) {
     $$0 = 0;$error$0$i2$i4 = 0;
     break;
    }
    $6 = (($memory) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    FUNCTION_TABLE_vii[$7 & 4095]($memory,$block);
    $$0 = 0;$error$0$i2$i4 = 0;
    break;
   }
   $8 = (2147483647 / ($item_size|0))&-1;
   $9 = ($8|0)<($new_count|0);
   if ($9) {
    $$0 = $block;$error$0$i2$i4 = 10;
   } else {
    $10 = ($cur_count|0)==(0);
    $11 = ($block|0)==(0|0);
    $or$cond3 = $10 & $11;
    if (!($or$cond3)) {
     $20 = Math_imul($cur_count, $item_size)|0;
     $21 = Math_imul($new_count, $item_size)|0;
     $22 = (($memory) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (FUNCTION_TABLE_iiiii[$23 & 511]($memory,$20,$21,$block)|0);
     $25 = ($24|0)==(0|0);
     $$ = $25 ? 64 : 0;
     $block$ = $25 ? $block : $24;
     $$0 = $block$;$error$0$i2$i4 = $$;
     break;
    }
    $12 = Math_imul($new_count, $item_size)|0;
    $13 = ($12|0)>(0);
    if (!($13)) {
     $14 = $12 >> 31;
     $15 = $14 & 6;
     $$0 = 0;$error$0$i2$i4 = $15;
     break;
    }
    $16 = (($memory) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (FUNCTION_TABLE_iii[$17 & 4095]($memory,$12)|0);
    $19 = ($18|0)==(0|0);
    $$$i$i = $19 ? 64 : 0;
    if ($19) {
     $$0 = 0;$error$0$i2$i4 = $$$i$i;
    } else {
     _memset(($18|0),0,($12|0))|0;
     $$0 = $18;$error$0$i2$i4 = $$$i$i;
    }
   }
  }
 } while(0);
 HEAP32[$p_error>>2] = $error$0$i2$i4;
 STACKTOP = sp;return ($$0|0);
}
function _ft_mem_free($memory,$P) {
 $memory = $memory|0;
 $P = $P|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($P|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($memory) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095]($memory,$P);
 STACKTOP = sp;return;
}
function _ft_mem_strdup($memory,$str,$p_error) {
 $memory = $memory|0;
 $str = $str|0;
 $p_error = $p_error|0;
 var $$$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$0$i$i = 0, $error$0$i$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($str|0)==(0|0);
 if ($0) {
  $9 = 0;
  label = 4;
 } else {
  $1 = (_strlen(($str|0))|0);
  $2 = (($1) + 1)|0;
  $3 = ($2|0)>(0);
  if ($3) {
   $4 = (($memory) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (FUNCTION_TABLE_iii[$5 & 4095]($memory,$2)|0);
   $7 = ($6|0)==(0|0);
   $$$i$i = $7 ? 64 : 0;
   $12 = $2;$block$0$i$i = $6;$error$0$i$i = $$$i$i;
  } else {
   $9 = $2;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $8 = $9 >> 31;
  $10 = $8 & 6;
  $12 = $9;$block$0$i$i = 0;$error$0$i$i = $10;
 }
 $11 = ($error$0$i$i|0)!=(0);
 $or$cond$i = $11 | $0;
 if ($or$cond$i) {
  HEAP32[$p_error>>2] = $error$0$i$i;
  STACKTOP = sp;return ($block$0$i$i|0);
 }
 _memcpy(($block$0$i$i|0),($str|0),($12|0))|0;
 HEAP32[$p_error>>2] = $error$0$i$i;
 STACKTOP = sp;return ($block$0$i$i|0);
}
function _ft_mem_strcpyn($dst,$src,$size) {
 $dst = $dst|0;
 $src = $src|0;
 $size = $size|0;
 var $$01$lcssa = 0, $$014 = 0, $$02$lcssa = 0, $$023 = 0, $$05 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size>>>0)>(1);
 L1: do {
  if ($0) {
   $$014 = $src;$$023 = $dst;$$05 = $size;
   while(1) {
    $1 = HEAP8[$$014>>0]|0;
    $2 = ($1<<24>>24)==(0);
    if ($2) {
     $$01$lcssa = $$014;$$02$lcssa = $$023;
     break L1;
    }
    $3 = (($$014) + 1|0);
    $4 = (($$023) + 1|0);
    HEAP8[$$023>>0] = $1;
    $5 = (($$05) + -1)|0;
    $6 = ($5>>>0)>(1);
    if ($6) {
     $$014 = $3;$$023 = $4;$$05 = $5;
    } else {
     $$01$lcssa = $3;$$02$lcssa = $4;
     break;
    }
   }
  } else {
   $$01$lcssa = $src;$$02$lcssa = $dst;
  }
 } while(0);
 HEAP8[$$02$lcssa>>0] = 0;
 $7 = HEAP8[$$01$lcssa>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = $8&1;
 STACKTOP = sp;return ($9|0);
}
function _FT_List_Find($list,$data) {
 $list = $list|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $cur$0 = 0, $cur$01 = 0, $cur$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $cur$01 = HEAP32[$list>>2]|0;
 $0 = ($cur$01|0)==(0|0);
 L1: do {
  if ($0) {
   $$0 = 0;
  } else {
   $cur$02 = $cur$01;
   while(1) {
    $3 = (($cur$02) + 8|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($4|0)==($data|0);
    if ($5) {
     $$0 = $cur$02;
     break L1;
    }
    $1 = (($cur$02) + 4|0);
    $cur$0 = HEAP32[$1>>2]|0;
    $2 = ($cur$0|0)==(0|0);
    if ($2) {
     $$0 = 0;
     break;
    } else {
     $cur$02 = $cur$0;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _FT_List_Add($list,$node) {
 $list = $list|0;
 $node = $node|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($list) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($node) + 4|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$node>>2] = $1;
 $3 = ($1|0)==(0|0);
 if ($3) {
  HEAP32[$list>>2] = $node;
  HEAP32[$0>>2] = $node;
  STACKTOP = sp;return;
 } else {
  $4 = (($1) + 4|0);
  HEAP32[$4>>2] = $node;
  HEAP32[$0>>2] = $node;
  STACKTOP = sp;return;
 }
}
function _FT_List_Remove($list,$node) {
 $list = $list|0;
 $node = $node|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$node>>2]|0;
 $1 = (($node) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==(0|0);
 if ($3) {
  HEAP32[$list>>2] = $2;
 } else {
  $4 = (($0) + 4|0);
  HEAP32[$4>>2] = $2;
 }
 $5 = ($2|0)==(0|0);
 if ($5) {
  $6 = (($list) + 4|0);
  HEAP32[$6>>2] = $0;
  STACKTOP = sp;return;
 } else {
  HEAP32[$2>>2] = $0;
  STACKTOP = sp;return;
 }
}
function _FT_List_Up($list,$node) {
 $list = $list|0;
 $node = $node|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$node>>2]|0;
 $1 = (($node) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($0) + 4|0);
 HEAP32[$4>>2] = $2;
 $5 = ($2|0)==(0|0);
 if ($5) {
  $6 = (($list) + 4|0);
  HEAP32[$6>>2] = $0;
 } else {
  HEAP32[$2>>2] = $0;
 }
 HEAP32[$node>>2] = 0;
 $7 = HEAP32[$list>>2]|0;
 HEAP32[$1>>2] = $7;
 $8 = HEAP32[$list>>2]|0;
 HEAP32[$8>>2] = $node;
 HEAP32[$list>>2] = $node;
 STACKTOP = sp;return;
}
function _FT_List_Finalize($list,$destroy,$memory,$user) {
 $list = $list|0;
 $destroy = $destroy|0;
 $memory = $memory|0;
 $user = $user|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cur$01 = 0, $cur$01$us = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$list>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = ($destroy|0)==(0|0);
  $3 = (($memory) + 8|0);
  if ($2) {
   $cur$01$us = $0;
   while(1) {
    $4 = (($cur$01$us) + 4|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($cur$01$us|0)==(0|0);
    if (!($6)) {
     $7 = HEAP32[$3>>2]|0;
     FUNCTION_TABLE_vii[$7 & 4095]($memory,$cur$01$us);
    }
    $8 = ($5|0)==(0|0);
    if ($8) {
     break;
    } else {
     $cur$01$us = $5;
    }
   }
  } else {
   $cur$01 = $0;
   while(1) {
    $9 = (($cur$01) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($cur$01) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    FUNCTION_TABLE_viii[$destroy & 4095]($memory,$12,$user);
    $13 = ($cur$01|0)==(0|0);
    if (!($13)) {
     $15 = HEAP32[$3>>2]|0;
     FUNCTION_TABLE_vii[$15 & 4095]($memory,$cur$01);
    }
    $14 = ($10|0)==(0|0);
    if ($14) {
     break;
    } else {
     $cur$01 = $10;
    }
   }
  }
 }
 HEAP32[$list>>2] = 0;
 $16 = (($list) + 4|0);
 HEAP32[$16>>2] = 0;
 STACKTOP = sp;return;
}
function _FT_Init_Class_cff_service_glyph_dict($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 279;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 2617;
 STACKTOP = sp;return;
}
function _cff_get_glyph_name($face,$glyph_index,$buffer,$buffer_max) {
 $face = $face|0;
 $glyph_index = $glyph_index|0;
 $buffer = $buffer|0;
 $buffer_max = $buffer_max|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 692|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 2956|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $error$0 = 2;
  STACKTOP = sp;return ($error$0|0);
 }
 $5 = (($1) + 1160|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($glyph_index<<1)|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8&65535;
 $10 = (_cff_index_get_sid_string($1,$9)|0);
 $11 = ($10|0)==(0|0);
 if ($11) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 (_ft_mem_strcpyn($buffer,$10,$buffer_max)|0);
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _cff_get_name_index($face,$glyph_name) {
 $face = $face|0;
 $glyph_name = $glyph_name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $name$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 692|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_ft_module_get_service($3,806800)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($1) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($1) + 1160|0);
 $10 = (($4) + 20|0);
 $i$01 = 0;
 while(1) {
  $11 = HEAP32[$9>>2]|0;
  $12 = (($11) + ($i$01<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = ($13&65535)>(390);
  if ($15) {
   $16 = (($14) + -391)|0;
   $17 = (_cff_index_get_string($1,$16)|0);
   $name$0 = $17;
  } else {
   $18 = HEAP32[$10>>2]|0;
   $19 = (FUNCTION_TABLE_ii[$18 & 4095]($14)|0);
   $name$0 = $19;
  }
  $20 = ($name$0|0)==(0|0);
  if (!($20)) {
   $21 = (_strcmp($glyph_name,$name$0)|0);
   $22 = ($21|0)==(0);
   if ($22) {
    $$0 = $i$01;
    label = 10;
    break;
   }
  }
  $23 = (($i$01) + 1)|0;
  $24 = HEAP32[$6>>2]|0;
  $25 = ($23>>>0)<($24>>>0);
  if ($25) {
   $i$01 = $23;
  } else {
   $$0 = 0;
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _FT_Init_Class_cff_service_ps_info($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 2618;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 3418;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function _cff_ps_get_font_info($face,$afont_info) {
 $face = $face|0;
 $afont_info = $afont_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($face) + 692|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$error>>2] = 0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $45 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($45|0);
 }
 $3 = (($1) + 2960|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $6 = (($face) + 100|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (_ft_mem_alloc($7,32,$error)|0);
   $9 = HEAP32[$error>>2]|0;
   $10 = ($9|0)==(0);
   if ($10) {
    $11 = (($1) + 1324|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (_cff_index_get_sid_string($1,$12)|0);
    HEAP32[$8>>2] = $13;
    $14 = (($1) + 1328|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (_cff_index_get_sid_string($1,$15)|0);
    $17 = (($8) + 4|0);
    HEAP32[$17>>2] = $16;
    $18 = (($1) + 1336|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (_cff_index_get_sid_string($1,$19)|0);
    $21 = (($8) + 8|0);
    HEAP32[$21>>2] = $20;
    $22 = (($1) + 1340|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (_cff_index_get_sid_string($1,$23)|0);
    $25 = (($8) + 12|0);
    HEAP32[$25>>2] = $24;
    $26 = (($1) + 1344|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (_cff_index_get_sid_string($1,$27)|0);
    $29 = (($8) + 16|0);
    HEAP32[$29>>2] = $28;
    $30 = (($1) + 1352|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($8) + 20|0);
    HEAP32[$32>>2] = $31;
    $33 = (($1) + 1348|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = (($8) + 24|0);
    HEAP8[$35>>0] = $34;
    $36 = (($1) + 1356|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = $37&65535;
    $39 = (($8) + 26|0);
    HEAP16[$39>>1] = $38;
    $40 = (($1) + 1360|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $41&65535;
    $43 = (($8) + 28|0);
    HEAP16[$43>>1] = $42;
    HEAP32[$3>>2] = $8;
    $44 = $8;
    break;
   } else {
    $45 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($45|0);
   }
  } else {
   $44 = $4;
  }
 } while(0);
 ;HEAP32[$afont_info+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$afont_info+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$afont_info+8>>2]=HEAP32[$44+8>>2]|0;HEAP32[$afont_info+12>>2]=HEAP32[$44+12>>2]|0;HEAP32[$afont_info+16>>2]=HEAP32[$44+16>>2]|0;HEAP32[$afont_info+20>>2]=HEAP32[$44+20>>2]|0;HEAP32[$afont_info+24>>2]=HEAP32[$44+24>>2]|0;HEAP32[$afont_info+28>>2]=HEAP32[$44+28>>2]|0;
 $45 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($45|0);
}
function _cff_ps_has_glyph_names($face) {
 $face = $face|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 9;
 $$lobit = $2 & 1;
 STACKTOP = sp;return ($$lobit|0);
}
function _FT_Init_Class_cff_service_ps_name($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 3419;
 STACKTOP = sp;return;
}
function _cff_get_ps_name($face) {
 $face = $face|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 692|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1304|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function _FT_Init_Class_cff_service_get_cmap_info($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 2619;
 STACKTOP = sp;return;
}
function _cff_get_cmap_info($charmap,$cmap_info) {
 $charmap = $charmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$charmap>>2]|0;
 $1 = (($0) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$cmap_info>>2] = 0;
 $5 = (($cmap_info) + 4|0);
 HEAP32[$5>>2] = 0;
 $6 = (($charmap) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($4) + 204|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 56|0);
 $11 = ($7|0)==($10|0);
 if ($11) {
  $error$0 = 0;
 } else {
  $12 = (($9) + 96|0);
  $13 = ($7|0)==($12|0);
  if ($13) {
   $error$0 = 0;
  } else {
   $14 = (_FT_Get_Module($4,806792)|0);
   $15 = (_ft_module_get_service($14,806760)|0);
   $16 = ($15|0)==(0|0);
   if ($16) {
    $error$0 = 0;
   } else {
    $17 = HEAP32[$15>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $error$0 = 0;
    } else {
     $19 = (FUNCTION_TABLE_iii[$17 & 4095]($charmap,$cmap_info)|0);
     $error$0 = $19;
    }
   }
  }
 }
 STACKTOP = sp;return ($error$0|0);
}
function _FT_Init_Class_cff_service_cid_info($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 280;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 2620;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 1597;
 STACKTOP = sp;return;
}
function _cff_get_ros($face,$registry,$ordering,$supplement) {
 $face = $face|0;
 $registry = $registry|0;
 $ordering = $ordering|0;
 $supplement = $supplement|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 692|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 $3 = (($1) + 1456|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(65535);
 if ($5) {
  $error$0 = 6;
  STACKTOP = sp;return ($error$0|0);
 }
 $6 = ($registry|0)==(0|0);
 if (!($6)) {
  $7 = (($1) + 2964|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if ($9) {
   $10 = (_cff_index_get_sid_string($1,$4)|0);
   HEAP32[$7>>2] = $10;
   $11 = $10;
  } else {
   $11 = $8;
  }
  HEAP32[$registry>>2] = $11;
 }
 $12 = ($ordering|0)==(0|0);
 if (!($12)) {
  $13 = (($1) + 2968|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $16 = (($1) + 1460|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (_cff_index_get_sid_string($1,$17)|0);
   HEAP32[$13>>2] = $18;
   $19 = $18;
  } else {
   $19 = $14;
  }
  HEAP32[$ordering>>2] = $19;
 }
 $20 = ($supplement|0)==(0|0);
 if ($20) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 $21 = (($1) + 1464|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$supplement>>2] = $22;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _cff_get_is_cid($face,$is_cid) {
 $face = $face|0;
 $is_cid = $is_cid|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 692|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP8[$is_cid>>0] = 0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($1) + 1456|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(65535);
  if (!($5)) {
   HEAP8[$is_cid>>0] = 1;
  }
 }
 STACKTOP = sp;return 0;
}
function _cff_get_cid_from_glyph_index($face,$glyph_index,$cid) {
 $face = $face|0;
 $glyph_index = $glyph_index|0;
 $cid = $cid|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 692|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $error$0 = 0;
 } else {
  $3 = (($1) + 1456|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(65535);
  if ($5) {
   $error$0 = 6;
  } else {
   $6 = (($1) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7>>>0)<($glyph_index>>>0);
   if ($8) {
    $error$0 = 6;
   } else {
    $9 = ($cid|0)==(0|0);
    if ($9) {
     $error$0 = 0;
    } else {
     $10 = (($1) + 1160|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($11) + ($glyph_index<<1)|0);
     $13 = HEAP16[$12>>1]|0;
     $14 = $13&65535;
     HEAP32[$cid>>2] = $14;
     $error$0 = 0;
    }
   }
  }
 }
 STACKTOP = sp;return ($error$0|0);
}
function _FT_Destroy_Class_cff_services($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($clazz|0)==(0|0);
 if (!($0)) {
  $1 = HEAP32[$library>>2]|0;
  _ft_mem_free($1,$clazz);
 }
 STACKTOP = sp;return;
}
function _FT_Create_Class_cff_services($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,56,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = 806672;
 $4 = (($1) + 4|0);
 HEAP32[$4>>2] = 806696;
 $5 = (($1) + 8|0);
 HEAP32[$5>>2] = 806704;
 $6 = (($library) + 204|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 8|0);
 $9 = (($1) + 12|0);
 HEAP32[$9>>2] = $8;
 $10 = (($1) + 16|0);
 HEAP32[$10>>2] = 806720;
 $11 = HEAP32[$6>>2]|0;
 $12 = (($11) + 36|0);
 $13 = (($1) + 20|0);
 HEAP32[$13>>2] = $12;
 $14 = (($1) + 24|0);
 HEAP32[$14>>2] = 806744;
 $15 = HEAP32[$6>>2]|0;
 $16 = (($15) + 28|0);
 $17 = (($1) + 28|0);
 HEAP32[$17>>2] = $16;
 $18 = (($1) + 32|0);
 HEAP32[$18>>2] = 806760;
 $19 = HEAP32[$6>>2]|0;
 $20 = (($19) + 40|0);
 $21 = (($1) + 36|0);
 HEAP32[$21>>2] = $20;
 $22 = (($1) + 40|0);
 HEAP32[$22>>2] = 806776;
 $23 = HEAP32[$6>>2]|0;
 $24 = (($23) + 44|0);
 $25 = (($1) + 44|0);
 HEAP32[$25>>2] = $24;
 $26 = (($1) + 48|0);
 HEAP32[$26>>2] = 0;
 $27 = (($1) + 52|0);
 HEAP32[$27>>2] = 0;
 HEAP32[$output_class>>2] = $1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Destroy_Class_cff_driver_class($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 _cff_driver_class_pic_free($library);
 $1 = ($clazz|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$clazz);
 STACKTOP = sp;return;
}
function _FT_Create_Class_cff_driver_class($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,104,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_cff_driver_class_pic_init($library)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if ($5) {
  HEAP32[$1>>2] = 1281;
  $7 = (($1) + 4|0);
  HEAP32[$7>>2] = 44;
  $8 = (($1) + 8|0);
  HEAP32[$8>>2] = 806784;
  $9 = (($1) + 12|0);
  HEAP32[$9>>2] = 65536;
  $10 = (($1) + 16|0);
  HEAP32[$10>>2] = 131072;
  $11 = (($1) + 20|0);
  HEAP32[$11>>2] = 0;
  $12 = (($1) + 24|0);
  HEAP32[$12>>2] = 3420;
  $13 = (($1) + 28|0);
  HEAP32[$13>>2] = 3732;
  $14 = (($1) + 32|0);
  HEAP32[$14>>2] = 2621;
  $15 = (($1) + 36|0);
  HEAP32[$15>>2] = 800;
  $16 = (($1) + 40|0);
  HEAP32[$16>>2] = 48;
  $17 = (($1) + 44|0);
  HEAP32[$17>>2] = 172;
  $18 = (($1) + 48|0);
  HEAP32[$18>>2] = 220;
  $19 = (($1) + 52|0);
  HEAP32[$19>>2] = 3733;
  $20 = (($1) + 56|0);
  HEAP32[$20>>2] = 3421;
  $21 = (($1) + 60|0);
  HEAP32[$21>>2] = 3734;
  $22 = (($1) + 64|0);
  HEAP32[$22>>2] = 3422;
  $23 = (($1) + 68|0);
  HEAP32[$23>>2] = 3735;
  $24 = (($1) + 72|0);
  HEAP32[$24>>2] = 221;
  $25 = (($1) + 76|0);
  HEAP32[$25>>2] = 1598;
  $26 = (($1) + 80|0);
  HEAP32[$26>>2] = 281;
  $27 = (($1) + 84|0);
  HEAP32[$27>>2] = 282;
  $28 = (($1) + 88|0);
  HEAP32[$28>>2] = 0;
  $29 = (($1) + 92|0);
  HEAP32[$29>>2] = 222;
  $30 = (($1) + 96|0);
  HEAP32[$30>>2] = 2622;
  $31 = (($1) + 100|0);
  HEAP32[$31>>2] = 2623;
  HEAP32[$output_class>>2] = $1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  _ft_mem_free($0,$1);
  $6 = HEAP32[$error>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _cff_get_interface($driver,$module_interface) {
 $driver = $driver|0;
 $module_interface = $module_interface|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($driver) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 204|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (_ft_service_list_lookup($4,$module_interface)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$0>>2]|0;
 $8 = (_FT_Get_Module($7,806792)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = (($10) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iii[$12 & 4095]($8,$module_interface)|0);
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function _Load_Glyph($cffslot,$cffsize,$glyph_index,$load_flags) {
 $cffslot = $cffslot|0;
 $cffsize = $cffsize|0;
 $glyph_index = $glyph_index|0;
 $load_flags = $load_flags|0;
 var $$0 = 0, $$load_flags = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($cffslot|0)==(0|0);
 if ($0) {
  $$0 = 37;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($cffsize|0)==(0|0);
 $2 = $load_flags | 3;
 $$load_flags = $1 ? $2 : $load_flags;
 $3 = $$load_flags & 1;
 $4 = ($3|0)==(0);
 $size$0 = $4 ? $cffsize : 0;
 $5 = ($size$0|0)==(0|0);
 if (!($5)) {
  $6 = HEAP32[$cffsize>>2]|0;
  $7 = (($cffslot) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  if (!($9)) {
   $$0 = 35;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $10 = (_cff_slot_load($cffslot,$size$0,$glyph_index,$$load_flags)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function _cff_get_kerning($ttface,$left_glyph,$right_glyph,$kerning) {
 $ttface = $ttface|0;
 $left_glyph = $left_glyph|0;
 $right_glyph = $right_glyph|0;
 $kerning = $kerning|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ttface) + 532|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$kerning>>2] = 0;
 $2 = (($kerning) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ($1|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 0;
 }
 $4 = (($1) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($ttface,$left_glyph,$right_glyph)|0);
 HEAP32[$kerning>>2] = $6;
 STACKTOP = sp;return 0;
}
function _cff_get_advances($face,$start,$count,$flags,$advances) {
 $face = $face|0;
 $start = $start|0;
 $count = $count|0;
 $flags = $flags|0;
 $advances = $advances|0;
 var $$in = 0, $$load_flags$i = 0, $$load_flags$i$v = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$1 = 0, $nn$01 = 0, $size$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 88|0);
 $3 = ($count|0)==(0);
 if ($3) {
  $error$1 = 0;
  STACKTOP = sp;return ($error$1|0);
 }
 $4 = ($1|0)==(0|0);
 $5 = $flags & 16;
 $6 = ($5|0)==(0);
 $7 = (($1) + 60|0);
 $8 = (($1) + 56|0);
 $$in = $6 ? $8 : $7;
 $9 = (($1) + 4|0);
 if ($4) {
  $error$1 = 37;
  STACKTOP = sp;return ($error$1|0);
 } else {
  $nn$01 = 0;
 }
 while(1) {
  $10 = HEAP32[$2>>2]|0;
  $11 = (($nn$01) + ($start))|0;
  $12 = ($10|0)==(0|0);
  $$load_flags$i$v = $12 ? 259 : 256;
  $$load_flags$i = $$load_flags$i$v | $flags;
  $13 = $$load_flags$i & 1;
  $14 = ($13|0)==(0);
  $size$0$i = $14 ? $10 : 0;
  $15 = ($size$0$i|0)==(0|0);
  if (!($15)) {
   $16 = HEAP32[$10>>2]|0;
   $17 = HEAP32[$9>>2]|0;
   $18 = ($16|0)==($17|0);
   if (!($18)) {
    $error$1 = 35;
    label = 7;
    break;
   }
  }
  $19 = (_cff_slot_load($1,$size$0$i,$11,$$load_flags$i)|0);
  $20 = ($19|0)==(0);
  if (!($20)) {
   $error$1 = $19;
   label = 7;
   break;
  }
  $21 = HEAP32[$$in>>2]|0;
  $22 = (($advances) + ($nn$01<<2)|0);
  HEAP32[$22>>2] = $21;
  $23 = (($nn$01) + 1)|0;
  $24 = ($23>>>0)<($count>>>0);
  if ($24) {
   $nn$01 = $23;
  } else {
   $error$1 = 0;
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($error$1|0);
 }
 return 0|0;
}
function _cff_decoder_parse_charstrings($decoder,$charstring_base,$charstring_len) {
 $decoder = $decoder|0;
 $charstring_base = $charstring_base|0;
 $charstring_len = $charstring_len|0;
 var $$ = 0, $$0 = 0, $$100 = 0, $$100$off = 0, $$101 = 0, $$102 = 0, $$103 = 0, $$95 = 0, $$97 = 0, $$98 = 0, $$99 = 0, $$dx$0 = 0, $$idx$val = 0, $$idx104$val = 0, $$idx105$val = 0, $$idx106$val = 0, $$idx107$val = 0, $$idx108$val = 0, $$idx109$val = 0, $$idx109$val$pre = 0;
 var $$idx110$val = 0, $$idx111$val = 0, $$idx111$val$1 = 0, $$idx111$val$1$pre = 0, $$idx111$val$2 = 0, $$idx111$val$2$pre = 0, $$idx111$val$3 = 0, $$idx111$val$3$pre = 0, $$idx111$val$4 = 0, $$idx111$val$4$pre = 0, $$idx112$val = 0, $$idx112$val$1 = 0, $$idx112$val$2 = 0, $$idx112$val$3 = 0, $$idx112$val$4 = 0, $$idx113$val = 0, $$idx113$val$pre = 0, $$idx114$val = 0, $$idx115$val = 0, $$idx115$val$pre = 0;
 var $$idx116$val = 0, $$idx117$val = 0, $$idx117$val$pre = 0, $$idx118$val = 0, $$idx119$val = 0, $$idx119$val$pre = 0, $$idx120$val = 0, $$idx121$val = 0, $$idx121$val$pre = 0, $$idx122$val = 0, $$idx123$val = 0, $$idx124$val = 0, $$idx125$val = 0, $$idx125$val$pre = 0, $$idx126$val = 0, $$idx127$val = 0, $$idx127$val$pre = 0, $$idx128$val = 0, $$idx129$val = 0, $$idx129$val$pre = 0;
 var $$idx130$val = 0, $$idx131$val = 0, $$idx131$val$pre = 0, $$idx132$val = 0, $$idx133$val = 0, $$idx133$val$pre = 0, $$idx134$val = 0, $$idx135$val = 0, $$idx136$val = 0, $$idx139$val = 0, $$idx139$val$pre = 0, $$idx140$val = 0, $$idx141$val = 0, $$idx141$val$pre = 0, $$idx142$val = 0, $$idx143$val = 0, $$idx143$val$lcssa = 0, $$idx143$val$pre = 0, $$idx143$val389 = 0, $$idx143$val393 = 0;
 var $$idx144$val = 0, $$idx144$val390 = 0, $$idx145$val = 0, $$idx145$val$pre = 0, $$idx146$val = 0, $$idx147$val = 0, $$idx147$val$pre = 0, $$idx148$val = 0, $$idx151$val = 0, $$idx151$val$lcssa1147 = 0, $$idx151$val$lcssa1148 = 0, $$idx151$val$pre = 0, $$idx151$val403 = 0, $$idx151$val407 = 0, $$idx152$val = 0, $$idx152$val404 = 0, $$idx153$val = 0, $$idx154$val = 0, $$idx155$val = 0, $$idx155$val$pre = 0;
 var $$idx156$val = 0, $$idx157$val = 0, $$idx158$val = 0, $$idx159$val = 0, $$idx160$val = 0, $$idx161$val = 0, $$idx161$val$pre = 0, $$idx162$val = 0, $$idx163$val = 0, $$idx164$val = 0, $$idx165$val = 0, $$idx165$val$pre = 0, $$idx166$val = 0, $$idx167$val = 0, $$idx167$val$pre = 0, $$idx168$val = 0, $$idx169$val = 0, $$idx170$val = 0, $$idx171$val = 0, $$idx171$val$pre = 0;
 var $$idx172$val = 0, $$idx173$val = 0, $$idx173$val$pre = 0, $$idx174$val = 0, $$idx175$val = 0, $$idx176$val = 0, $$idx177$val = 0, $$idx177$val$pre = 0, $$idx178$val = 0, $$idx179$val = 0, $$idx179$val$pre = 0, $$idx180$val = 0, $$idx181$val = 0, $$idx182$val = 0, $$idx183$val = 0, $$idx184 = 0, $$idx184$val = 0, $$lcssa386 = 0, $$lcssa387 = 0, $$lcssa388 = 0;
 var $$lcssa4001152 = 0, $$lcssa4001153 = 0, $$lcssa4001154 = 0, $$lcssa4011149 = 0, $$lcssa4011150 = 0, $$lcssa4011151 = 0, $$neg356 = 0, $$off = 0, $$off355 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i187 = 0, $$pre$i191 = 0, $$pre$i195 = 0, $$pre$i200 = 0, $$pre$i204 = 0, $$pre$i208 = 0, $$pre$i213 = 0;
 var $$pre$i217 = 0, $$pre$i221 = 0, $$pre$i226 = 0, $$pre$i230 = 0, $$pre$i234 = 0, $$pre$i238 = 0, $$pre$i242 = 0, $$pre$i246 = 0, $$pre$i251 = 0, $$pre$i255 = 0, $$pre$i259 = 0, $$pre$i263 = 0, $$pre$i268 = 0, $$pre$i272 = 0, $$pre$i276 = 0, $$pre$i280 = 0, $$pre$i285 = 0, $$pre$i289 = 0, $$pre$i293 = 0, $$pre$i297 = 0;
 var $$pre$i301 = 0, $$pre$i305 = 0, $$pre$i310 = 0, $$pre$i314 = 0, $$pre$i318 = 0, $$pre$i322 = 0, $$pre$i326 = 0, $$pre$i330 = 0, $$pre$i335 = 0, $$pre$i335$1 = 0, $$pre$i335$2 = 0, $$pre$i335$3 = 0, $$pre$i335$4 = 0, $$pre$i339 = 0, $$pre$i344 = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i189Z2D = 0, $$pre$phi$i193Z2D = 0, $$pre$phi$i197Z2D = 0, $$pre$phi$i202Z2D = 0;
 var $$pre$phi$i206Z2D = 0, $$pre$phi$i210Z2D = 0, $$pre$phi$i215Z2D = 0, $$pre$phi$i219Z2D = 0, $$pre$phi$i223Z2D = 0, $$pre$phi$i228Z2D = 0, $$pre$phi$i232Z2D = 0, $$pre$phi$i236Z2D = 0, $$pre$phi$i240Z2D = 0, $$pre$phi$i244Z2D = 0, $$pre$phi$i248Z2D = 0, $$pre$phi$i253Z2D = 0, $$pre$phi$i257Z2D = 0, $$pre$phi$i261Z2D = 0, $$pre$phi$i265Z2D = 0, $$pre$phi$i270Z2D = 0, $$pre$phi$i274Z2D = 0, $$pre$phi$i278Z2D = 0, $$pre$phi$i282Z2D = 0, $$pre$phi$i287Z2D = 0;
 var $$pre$phi$i291Z2D = 0, $$pre$phi$i295Z2D = 0, $$pre$phi$i299Z2D = 0, $$pre$phi$i303Z2D = 0, $$pre$phi$i307Z2D = 0, $$pre$phi$i312Z2D = 0, $$pre$phi$i316Z2D = 0, $$pre$phi$i320Z2D = 0, $$pre$phi$i324Z2D = 0, $$pre$phi$i328Z2D = 0, $$pre$phi$i332Z2D = 0, $$pre$phi$i337$1Z2D = 0, $$pre$phi$i337$2Z2D = 0, $$pre$phi$i337$3Z2D = 0, $$pre$phi$i337$4Z2D = 0, $$pre$phi$i337Z2D = 0, $$pre$phi$i341Z2D = 0, $$pre$phi$i346Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi1123Z2D = 0;
 var $$pre$phi1128Z2D = 0, $$pre$phiZ2D = 0, $$pre1101 = 0, $$pre1102 = 0, $$pre1117 = 0, $$pre1118 = 0, $$pre1119 = 0, $$pre1121 = 0, $$pre1122 = 0, $$pre1129 = 0, $$sum = 0, $$sum11$pre = 0, $$sum1137 = 0, $$sum1138 = 0, $$sum1139 = 0, $$sum1140 = 0, $$sum1141 = 0, $$sum1142 = 0, $$sum1143 = 0, $$sum1144 = 0;
 var $$sum1145 = 0, $$sum1146 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum27 = 0, $$sum27$us = 0, $$sum28$us = 0, $$sum29$us = 0, $$sum30 = 0;
 var $$sum31$us = 0, $$sum32$us = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum38 = 0, $$sum39 = 0, $$sum4 = 0, $$sum41 = 0, $$sum42 = 0, $$sum43 = 0, $$sum44 = 0, $$sum45 = 0, $$sum46 = 0, $$sum47 = 0, $$sum48 = 0, $$sum49 = 0, $$sum5 = 0;
 var $$sum50 = 0, $$sum51 = 0, $$sum52 = 0, $$sum53 = 0, $$sum55 = 0, $$sum56 = 0, $$sum57 = 0, $$sum58 = 0, $$sum59 = 0, $$sum60 = 0, $$sum61 = 0, $$sum62 = 0, $$sum63 = 0, $$sum64 = 0, $$sum65 = 0, $$sum66 = 0, $$sum67 = 0, $$sum68 = 0, $$sum69 = 0, $$sum7 = 0;
 var $$sum70 = 0, $$sum72 = 0, $$sum74 = 0, $$sum757 = 0, $$sum758 = 0, $$sum76 = 0, $$sum77 = 0, $$sum79 = 0, $$sum8 = 0, $$sum80 = 0, $$sum82 = 0, $$sum84 = 0, $$sum86 = 0, $$sum88 = 0, $$sum89 = 0, $$sum91 = 0, $$sum93 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0;
 var $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0;
 var $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0;
 var $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0;
 var $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0;
 var $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0;
 var $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0;
 var $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0;
 var $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0;
 var $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0;
 var $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0;
 var $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0;
 var $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0;
 var $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0;
 var $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0;
 var $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0;
 var $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0;
 var $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0;
 var $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0;
 var $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0;
 var $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0;
 var $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0;
 var $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0;
 var $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0;
 var $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0;
 var $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0;
 var $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0;
 var $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0;
 var $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0;
 var $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0;
 var $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0;
 var $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0;
 var $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0;
 var $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0;
 var $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0;
 var $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0;
 var $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0;
 var $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0;
 var $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0;
 var $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0;
 var $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0;
 var $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0;
 var $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0;
 var $1775 = 0, $1776 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0;
 var $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0;
 var $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0;
 var $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0;
 var $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0;
 var $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0;
 var $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0;
 var $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0;
 var $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0;
 var $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0;
 var $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0;
 var $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0;
 var $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0;
 var $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0;
 var $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0;
 var $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0;
 var $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0;
 var $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0;
 var $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0;
 var $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0;
 var $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0;
 var $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0;
 var $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0;
 var $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0;
 var $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0;
 var $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0;
 var $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0;
 var $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0;
 var $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $args$0459 = 0, $args$11374 = 0, $args$12 = 0, $args$1452 = 0, $args$2442 = 0, $args$3 = 0;
 var $args$4435 = 0, $args$5 = 0, $args$6428 = 0, $args$7420 = 0, $args$8$lcssa1155 = 0, $args$8$lcssa1156 = 0, $args$8$lcssa1157 = 0, $args$8406 = 0, $args$9392 = 0, $builder$idx$val$i = 0, $builder$idx1$val$i = 0, $count9$0373 = 0, $dy$1 = 0, $exitcond = 0, $exitcond1061 = 0, $i$0361$us = 0, $i15$0358$us = 0, $idx$0 = 0, $idx12$0367 = 0, $idx12$0367$us = 0;
 var $idx12$1359 = 0, $idx12$1359$us = 0, $ip$0$be = 0, $ip$0$ph = 0, $ip$0737 = 0, $ip$1 = 0, $ip$2$ph = 0, $ip$2$ph$ph = 0, $ip$3 = 0, $limit$0$ph = 0, $limit$1 = 0, $nargs1$1 = 0, $nargs1$1$off = 0, $nargs2$1 = 0, $nargs2$1$off = 0, $nargs4$1418 = 0, $num_args$0 = 0, $num_args$1 = 0, $num_curves$0391 = 0, $num_lines$0405 = 0;
 var $op$0$ph = 0, $op$0$ph$ph = 0, $or$cond = 0, $or$cond1158 = 0, $or$cond1159 = 0, $phase$0451 = 0, $phase3$0419 = 0, $phitmp = 0, $phitmp10 = 0, $phitmp354 = 0, $phitmp54 = 0, $req_args$0 = 0, $req_args$0$not = 0, $req_args$0$not85 = 0, $req_args$0$not87 = 0, $req_args$0$not90 = 0, $root$0 = 0, $scevgep$sum = 0, $scevgep1047 = 0, $seed = 0;
 var $set_width_ok$0 = 0, $sext = 0, $shift$0 = 0, $smax = 0, $storemerge = 0, $storemerge40 = 0, $sum = 0, $sum71 = 0, $sum73 = 0, $sum75 = 0, $sum78 = 0, $sum81 = 0, $sum83 = 0, $sum92 = 0, $sum94 = 0, $val$0 = 0, $val19$0 = 0, $x$0$ph = 0, $x$10 = 0, $x$14 = 0;
 var $x$1461 = 0, $x$15376 = 0, $x$16 = 0, $x$2454 = 0, $x$3 = 0, $x$4444 = 0, $x$5 = 0, $x$6437 = 0, $x$7430 = 0, $x$8423 = 0, $x$9 = 0, $y$0$ph = 0, $y$10 = 0, $y$14 = 0, $y$1460 = 0, $y$15375 = 0, $y$16 = 0, $y$2453 = 0, $y$3 = 0, $y$4443 = 0;
 var $y$5436 = 0, $y$6 = 0, $y$7429 = 0, $y$8422 = 0, $y$9 = 0, $zone$0$ph = 0, $zone$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $seed = sp + 4|0;
 HEAP32[$0>>2] = $decoder;
 HEAP32[$1>>2] = $charstring_base;
 $2 = (($decoder) + 76|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1368|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($decoder) + 756|0);
 HEAP32[$6>>2] = 0;
 $7 = (($decoder) + 752|0);
 HEAP8[$7>>0] = 1;
 $8 = $seed;
 $9 = $0;
 $10 = $1;
 $11 = $10 ^ $9;
 $12 = $11 ^ $8;
 $13 = $12 >>> 10;
 $14 = $13 ^ $12;
 $15 = $12 >> 20;
 $16 = $14 ^ $15;
 $17 = $16 & 65535;
 $18 = ($17|0)==(0);
 $$ = $18 ? 29572 : $17;
 HEAP32[$seed>>2] = $$;
 $19 = (($decoder) + 80|0);
 $20 = (($decoder) + 276|0);
 HEAP32[$20>>2] = $19;
 $21 = (($decoder) + 280|0);
 $22 = (($decoder) + 676|0);
 HEAP32[$22>>2] = $21;
 $23 = (($decoder) + 68|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($decoder) + 64|0);
 HEAP8[$25>>0] = 0;
 HEAP32[$21>>2] = $charstring_base;
 $26 = (($charstring_base) + ($charstring_len)|0);
 $27 = (($decoder) + 284|0);
 HEAP32[$27>>2] = $26;
 $28 = (($decoder) + 288|0);
 HEAP32[$28>>2] = $charstring_base;
 $29 = (($decoder) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($decoder) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($24|0)!=(0|0);
 if ($33) {
  $34 = (($24) + 4|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_vi[$35 & 4095]($36);
  $$pre$phi1128Z2D = $24;
 } else {
  $$pre$phi1128Z2D = $24;
 }
 $37 = $19;
 $38 = ($5|0)==(2);
 $$95 = $38 ? 0 : 16;
 $39 = (($24) + 12|0);
 $40 = (($24) + 16|0);
 $41 = (($decoder) + 20|0);
 $42 = (($24) + 20|0);
 $$idx184 = (($decoder) + 65|0);
 $43 = (($decoder) + 12|0);
 $ip$0$ph = $charstring_base;$limit$0$ph = $26;$x$0$ph = $30;$y$0$ph = $32;$zone$0$ph = $21;
 L5: while(1) {
  $44 = ($ip$0$ph>>>0)<($limit$0$ph>>>0);
  if ($44) {
   $ip$0737 = $ip$0$ph;
  } else {
   $$0 = 0;
   label = 398;
   break;
  }
  L7: while(1) {
   $45 = (($ip$0737) + 1|0);
   $46 = HEAP8[$ip$0737>>0]|0;
   $47 = $46&255;
   $48 = ($46&255)>(31);
   $49 = ($46<<24>>24)==(28);
   $or$cond = $48 | $49;
   L9: do {
    if ($or$cond) {
     do {
      if ($49) {
       $50 = (($ip$0737) + 2|0);
       $51 = ($50>>>0)<($limit$0$ph>>>0);
       if (!($51)) {
        $$0 = 3;
        label = 398;
        break L5;
       }
       $52 = HEAP8[$45>>0]|0;
       $53 = $52&255;
       $54 = $53 << 8;
       $55 = HEAP8[$50>>0]|0;
       $56 = $55&255;
       $57 = $54 | $56;
       $sext = $57 << 16;
       $58 = $sext >> 16;
       $59 = (($ip$0737) + 3|0);
       $ip$1 = $59;$shift$0 = 16;$val$0 = $58;
      } else {
       $60 = ($46&255)<(247);
       if ($60) {
        $61 = (($47) + -139)|0;
        $ip$1 = $45;$shift$0 = 16;$val$0 = $61;
        break;
       }
       $62 = ($46&255)<(251);
       if ($62) {
        $63 = ($45>>>0)<($limit$0$ph>>>0);
        if (!($63)) {
         $$0 = 3;
         label = 398;
         break L5;
        }
        $64 = $47 << 8;
        $65 = (($64) + -63232)|0;
        $66 = (($ip$0737) + 2|0);
        $67 = HEAP8[$45>>0]|0;
        $68 = $67&255;
        $69 = $68 | $65;
        $70 = (($69) + 108)|0;
        $ip$1 = $66;$shift$0 = 16;$val$0 = $70;
        break;
       }
       $71 = ($46<<24>>24)==(-1);
       if ($71) {
        $80 = (($ip$0737) + 4|0);
        $81 = ($80>>>0)<($limit$0$ph>>>0);
        if (!($81)) {
         $$0 = 3;
         label = 398;
         break L5;
        }
        $82 = HEAP8[$45>>0]|0;
        $83 = $82&255;
        $84 = $83 << 24;
        $85 = (($ip$0737) + 2|0);
        $86 = HEAP8[$85>>0]|0;
        $87 = $86&255;
        $88 = $87 << 16;
        $89 = $88 | $84;
        $90 = (($ip$0737) + 3|0);
        $91 = HEAP8[$90>>0]|0;
        $92 = $91&255;
        $93 = $92 << 8;
        $94 = $89 | $93;
        $95 = HEAP8[$80>>0]|0;
        $96 = $95&255;
        $97 = $94 | $96;
        $98 = (($ip$0737) + 5|0);
        $ip$1 = $98;$shift$0 = $$95;$val$0 = $97;
        break;
       } else {
        $72 = ($45>>>0)<($limit$0$ph>>>0);
        if (!($72)) {
         $$0 = 3;
         label = 398;
         break L5;
        }
        $73 = (251 - ($47))|0;
        $74 = $73 << 8;
        $75 = (($ip$0737) + 2|0);
        $76 = HEAP8[$45>>0]|0;
        $77 = $76&255;
        $78 = (($74) + -108)|0;
        $79 = (($78) - ($77))|0;
        $ip$1 = $75;$shift$0 = 16;$val$0 = $79;
        break;
       }
      }
     } while(0);
     $99 = HEAP32[$0>>2]|0;
     $100 = (($99) + 276|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = $101;
     $103 = (($102) - ($37))|0;
     $104 = ($103|0)>(188);
     if ($104) {
      $$0 = 130;
      label = 398;
      break L5;
     }
     $105 = $val$0 << $shift$0;
     $106 = (($101) + 4|0);
     HEAP32[$100>>2] = $106;
     HEAP32[$101>>2] = $105;
     $ip$0$be = $ip$1;
    } else {
     $108 = HEAP32[$0>>2]|0;
     $109 = (($108) + 276|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = (($108) + 80|0);
     $112 = $110;
     $113 = $111;
     $114 = (($112) - ($113))|0;
     $115 = $114 >> 2;
     switch ($47|0) {
     case 10:  {
      label = 30;
      break L7;
      break;
     }
     case 6:  {
      label = 26;
      break L7;
      break;
     }
     case 8:  {
      label = 28;
      break L7;
      break;
     }
     case 5:  {
      label = 25;
      break L7;
      break;
     }
     case 7:  {
      label = 27;
      break L7;
      break;
     }
     case 9:  {
      label = 29;
      break L7;
      break;
     }
     case 12:  {
      break;
     }
     case 11:  {
      label = 31;
      break L7;
      break;
     }
     case 4:  {
      label = 24;
      break L7;
      break;
     }
     case 13:  {
      label = 66;
      break L7;
      break;
     }
     case 21:  {
      label = 72;
      break L7;
      break;
     }
     case 30:  {
      label = 80;
      break L7;
      break;
     }
     case 24:  {
      label = 75;
      break L7;
      break;
     }
     case 3:  {
      $ip$2$ph = $45;$op$0$ph = 20;
      break L7;
      break;
     }
     case 20:  {
      label = 71;
      break L7;
      break;
     }
     case 23:  {
      label = 74;
      break L7;
      break;
     }
     case 18:  {
      label = 69;
      break L7;
      break;
     }
     case 16:  {
      label = 68;
      break L7;
      break;
     }
     case 19:  {
      label = 70;
      break L7;
      break;
     }
     case 27:  {
      label = 78;
      break L7;
      break;
     }
     case 26:  {
      label = 77;
      break L7;
      break;
     }
     case 22:  {
      label = 73;
      break L7;
      break;
     }
     case 25:  {
      label = 76;
      break L7;
      break;
     }
     case 14:  {
      label = 67;
      break L7;
      break;
     }
     case 31:  {
      label = 81;
      break L7;
      break;
     }
     case 1:  {
      $ip$2$ph$ph = $45;$op$0$ph$ph = 19;
      label = 82;
      break L7;
      break;
     }
     case 29:  {
      label = 79;
      break L7;
      break;
     }
     default: {
      $ip$0$be = $45;
      break L9;
     }
     }
     $116 = ($45>>>0)<($limit$0$ph>>>0);
     if (!($116)) {
      $$0 = 3;
      label = 398;
      break L5;
     }
     $117 = (($ip$0737) + 2|0);
     $118 = HEAP8[$45>>0]|0;
     $119 = $118&255;
     switch ($119|0) {
     case 9:  {
      label = 41;
      break L7;
      break;
     }
     case 13:  {
      label = 45;
      break L7;
      break;
     }
     case 10:  {
      label = 42;
      break L7;
      break;
     }
     case 8:  {
      label = 40;
      break L7;
      break;
     }
     case 11:  {
      label = 43;
      break L7;
      break;
     }
     case 5:  {
      label = 37;
      break L7;
      break;
     }
     case 14:  {
      label = 46;
      break L7;
      break;
     }
     case 12:  {
      label = 44;
      break L7;
      break;
     }
     case 15:  {
      label = 47;
      break L7;
      break;
     }
     case 2:  {
      label = 34;
      break L7;
      break;
     }
     case 3:  {
      label = 35;
      break L7;
      break;
     }
     case 4:  {
      label = 36;
      break L7;
      break;
     }
     case 6:  {
      label = 38;
      break L7;
      break;
     }
     case 7:  {
      label = 39;
      break L7;
      break;
     }
     case 18:  {
      label = 50;
      break L7;
      break;
     }
     case 27:  {
      label = 57;
      break L7;
      break;
     }
     case 20:  {
      label = 51;
      break L7;
      break;
     }
     case 22:  {
      label = 53;
      break L7;
      break;
     }
     case 23:  {
      label = 54;
      break L7;
      break;
     }
     case 35:  {
      label = 63;
      break L7;
      break;
     }
     case 36:  {
      label = 64;
      break L7;
      break;
     }
     case 37:  {
      label = 65;
      break L7;
      break;
     }
     case 30:  {
      label = 60;
      break L7;
      break;
     }
     case 29:  {
      label = 59;
      break L7;
      break;
     }
     case 1:  {
      $ip$2$ph = $117;$op$0$ph = 20;
      break L7;
      break;
     }
     case 17:  {
      label = 49;
      break L7;
      break;
     }
     case 26:  {
      label = 56;
      break L7;
      break;
     }
     case 21:  {
      label = 52;
      break L7;
      break;
     }
     case 33:  {
      label = 61;
      break L7;
      break;
     }
     case 24:  {
      label = 55;
      break L7;
      break;
     }
     case 28:  {
      label = 58;
      break L7;
      break;
     }
     case 34:  {
      label = 62;
      break L7;
      break;
     }
     case 16:  {
      label = 48;
      break L7;
      break;
     }
     case 0:  {
      $ip$2$ph$ph = $117;$op$0$ph$ph = 25;
      label = 82;
      break L7;
      break;
     }
     default: {
      $ip$0$be = $117;
     }
     }
    }
   } while(0);
   $107 = ($ip$0$be>>>0)<($limit$0$ph>>>0);
   if ($107) {
    $ip$0737 = $ip$0$be;
   } else {
    $$0 = 0;
    label = 398;
    break L5;
   }
  }
  switch (label|0) {
   case 24: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 3;
    break;
   }
   case 25: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 4;
    break;
   }
   case 26: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 5;
    break;
   }
   case 27: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 6;
    break;
   }
   case 28: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 7;
    break;
   }
   case 29: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 53;
    break;
   }
   case 30: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 49;
    break;
   }
   case 31: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 51;
    break;
   }
   case 34: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 19;
    break;
   }
   case 35: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 44;
    break;
   }
   case 36: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 45;
    break;
   }
   case 37: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 46;
    break;
   }
   case 38: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 56;
    break;
   }
   case 39: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 57;
    break;
   }
   case 40: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 42;
    break;
   }
   case 41: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 26;
    break;
   }
   case 42: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 27;
    break;
   }
   case 43: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 28;
    break;
   }
   case 44: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 29;
    break;
   }
   case 45: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 43;
    break;
   }
   case 46: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 30;
    break;
   }
   case 47: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 47;
    break;
   }
   case 48: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 54;
    break;
   }
   case 49: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 55;
    break;
   }
   case 50: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 35;
    break;
   }
   case 51: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 40;
    break;
   }
   case 52: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 41;
    break;
   }
   case 53: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 48;
    break;
   }
   case 54: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 31;
    break;
   }
   case 55: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 32;
    break;
   }
   case 56: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 33;
    break;
   }
   case 57: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 39;
    break;
   }
   case 58: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 36;
    break;
   }
   case 59: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 37;
    break;
   }
   case 60: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 38;
    break;
   }
   case 61: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 58;
    break;
   }
   case 62: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 15;
    break;
   }
   case 63: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 14;
    break;
   }
   case 64: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 16;
    break;
   }
   case 65: {
    label = 0;
    $ip$2$ph = $117;$op$0$ph = 17;
    break;
   }
   case 66: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 52;
    break;
   }
   case 67: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 18;
    break;
   }
   case 68: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 34;
    break;
   }
   case 69: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 21;
    break;
   }
   case 70: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 23;
    break;
   }
   case 71: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 24;
    break;
   }
   case 72: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 1;
    break;
   }
   case 73: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 2;
    break;
   }
   case 74: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 22;
    break;
   }
   case 75: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 10;
    break;
   }
   case 76: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 11;
    break;
   }
   case 77: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 13;
    break;
   }
   case 78: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 8;
    break;
   }
   case 79: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 50;
    break;
   }
   case 80: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 12;
    break;
   }
   case 81: {
    label = 0;
    $ip$2$ph = $45;$op$0$ph = 9;
    break;
   }
   case 82: {
    label = 0;
    $ip$2$ph = $ip$2$ph$ph;$op$0$ph = $op$0$ph$ph;
    break;
   }
  }
  $120 = (806824 + ($op$0$ph)|0);
  $121 = HEAP8[$120>>0]|0;
  $122 = $121&255;
  $123 = $122 & 128;
  $124 = ($123|0)==(0);
  if ($124) {
   $num_args$1 = $115;$req_args$0 = $122;
  } else {
   $125 = ($114|0)>(0);
   $126 = (($108) + 752|0);
   L94: do {
    if ($125) {
     $127 = HEAP8[$126>>0]|0;
     $128 = ($127<<24>>24)==(0);
     if ($128) {
      $num_args$0 = $115;
     } else {
      switch ($op$0$ph|0) {
      case 24: case 23: case 1: case 22: case 21: case 20: case 19:  {
       $130 = $115 & 1;
       $set_width_ok$0 = $130;
       break;
      }
      case 18:  {
       $131 = $115 & -5;
       $132 = ($131|0)==(1);
       $133 = $132&1;
       $set_width_ok$0 = $133;
       break;
      }
      case 3: case 2:  {
       $129 = $115 & 2;
       $set_width_ok$0 = $129;
       break;
      }
      default: {
       $num_args$0 = $115;
       break L94;
      }
      }
      $134 = ($set_width_ok$0|0)==(0);
      if ($134) {
       $num_args$0 = $115;
      } else {
       $135 = (($108) + 748|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = HEAP32[$19>>2]|0;
       $138 = $137 >> 16;
       $139 = (($138) + ($136))|0;
       $140 = (($108) + 744|0);
       HEAP32[$140>>2] = $139;
       $141 = (($108) + 753|0);
       $142 = HEAP8[$141>>0]|0;
       $143 = ($142<<24>>24)==(0);
       if (!($143)) {
        $$0 = 0;
        label = 398;
        break L5;
       }
       $144 = (($115) + -1)|0;
       $num_args$0 = $144;
      }
     }
    } else {
     $num_args$0 = $115;
    }
   } while(0);
   HEAP8[$126>>0] = 0;
   $num_args$1 = $num_args$0;$req_args$0 = 0;
  }
  $145 = $req_args$0 & 15;
  $146 = ($num_args$1|0)<($145|0);
  if ($146) {
   $$0 = 129;
   label = 398;
   break;
  }
  $147 = (0 - ($145))|0;
  $148 = (($110) + ($147<<2)|0);
  $149 = (($num_args$1) - ($145))|0;
  L107: do {
   switch ($op$0$ph|0) {
   case 15:  {
    $1118 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $1119 = ($1118|0)==(0);
    if (!($1119)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $1120 = HEAP32[$43>>2]|0;
    $1121 = (($1120) + 22|0);
    $1122 = HEAP16[$1121>>1]|0;
    $1123 = $1122 << 16 >> 16;
    $1124 = (($1120) + 58|0);
    $1125 = HEAP16[$1124>>1]|0;
    $1126 = $1125 << 16 >> 16;
    $1127 = (($1123) + 6)|0;
    $1128 = (($1127) + ($1126))|0;
    $1129 = (($1120) + 4|0);
    $1130 = HEAP32[$1129>>2]|0;
    $1131 = ($1128>>>0)>($1130>>>0);
    if ($1131) {
     $1132 = (_FT_GlyphLoader_CheckPoints($1120,6,0)|0);
     $1133 = ($1132|0)==(0);
     if (!($1133)) {
      $$0 = 0;
      label = 398;
      break L5;
     }
    }
    $1134 = HEAP32[$148>>2]|0;
    $1135 = (($1134) + ($x$0$ph))|0;
    $$idx123$val = HEAP32[$41>>2]|0;
    $$idx124$val = HEAP8[$$idx184>>0]|0;
    $1136 = ($$idx124$val<<24>>24)==(0);
    if ($1136) {
     $$pre$i310 = (($$idx123$val) + 2|0);
     $$idx121$val = $$idx123$val;$$pre$phi$i312Z2D = $$pre$i310;
    } else {
     $1137 = (($$idx123$val) + 4|0);
     $1138 = HEAP32[$1137>>2]|0;
     $1139 = (($$idx123$val) + 2|0);
     $1140 = HEAP16[$1139>>1]|0;
     $1141 = $1140 << 16 >> 16;
     $1142 = (($$idx123$val) + 8|0);
     $1143 = HEAP32[$1142>>2]|0;
     $1144 = (($1143) + ($1141)|0);
     $1145 = $1135 >> 16;
     $1146 = (($1138) + ($1141<<3)|0);
     HEAP32[$1146>>2] = $1145;
     $1147 = $y$0$ph >> 16;
     $1148 = ((($1138) + ($1141<<3)|0) + 4|0);
     HEAP32[$1148>>2] = $1147;
     HEAP8[$1144>>0] = 2;
     $$idx121$val$pre = HEAP32[$41>>2]|0;
     $$idx121$val = $$idx121$val$pre;$$pre$phi$i312Z2D = $1139;
    }
    $1149 = HEAP16[$$pre$phi$i312Z2D>>1]|0;
    $1150 = (($1149) + 1)<<16>>16;
    HEAP16[$$pre$phi$i312Z2D>>1] = $1150;
    $$sum55 = (1 - ($145))|0;
    $1151 = (($110) + ($$sum55<<2)|0);
    $1152 = HEAP32[$1151>>2]|0;
    $1153 = (($1152) + ($1135))|0;
    $$sum56 = (2 - ($145))|0;
    $1154 = (($110) + ($$sum56<<2)|0);
    $1155 = HEAP32[$1154>>2]|0;
    $1156 = (($1155) + ($y$0$ph))|0;
    $$idx122$val = HEAP8[$$idx184>>0]|0;
    $1157 = ($$idx122$val<<24>>24)==(0);
    if ($1157) {
     $$pre$i314 = (($$idx121$val) + 2|0);
     $$idx119$val = $$idx121$val;$$pre$phi$i316Z2D = $$pre$i314;
    } else {
     $1158 = (($$idx121$val) + 4|0);
     $1159 = HEAP32[$1158>>2]|0;
     $1160 = (($$idx121$val) + 2|0);
     $1161 = HEAP16[$1160>>1]|0;
     $1162 = $1161 << 16 >> 16;
     $1163 = (($$idx121$val) + 8|0);
     $1164 = HEAP32[$1163>>2]|0;
     $1165 = (($1164) + ($1162)|0);
     $1166 = $1153 >> 16;
     $1167 = (($1159) + ($1162<<3)|0);
     HEAP32[$1167>>2] = $1166;
     $1168 = $1156 >> 16;
     $1169 = ((($1159) + ($1162<<3)|0) + 4|0);
     HEAP32[$1169>>2] = $1168;
     HEAP8[$1165>>0] = 2;
     $$idx119$val$pre = HEAP32[$41>>2]|0;
     $$idx119$val = $$idx119$val$pre;$$pre$phi$i316Z2D = $1160;
    }
    $1170 = HEAP16[$$pre$phi$i316Z2D>>1]|0;
    $1171 = (($1170) + 1)<<16>>16;
    HEAP16[$$pre$phi$i316Z2D>>1] = $1171;
    $$sum57 = (3 - ($145))|0;
    $1172 = (($110) + ($$sum57<<2)|0);
    $1173 = HEAP32[$1172>>2]|0;
    $1174 = (($1173) + ($1153))|0;
    $$idx120$val = HEAP8[$$idx184>>0]|0;
    $1175 = ($$idx120$val<<24>>24)==(0);
    if ($1175) {
     $$pre$i318 = (($$idx119$val) + 2|0);
     $$idx117$val = $$idx119$val;$$pre$phi$i320Z2D = $$pre$i318;
    } else {
     $1176 = (($$idx119$val) + 4|0);
     $1177 = HEAP32[$1176>>2]|0;
     $1178 = (($$idx119$val) + 2|0);
     $1179 = HEAP16[$1178>>1]|0;
     $1180 = $1179 << 16 >> 16;
     $1181 = (($$idx119$val) + 8|0);
     $1182 = HEAP32[$1181>>2]|0;
     $1183 = (($1182) + ($1180)|0);
     $1184 = $1174 >> 16;
     $1185 = (($1177) + ($1180<<3)|0);
     HEAP32[$1185>>2] = $1184;
     $1186 = $1156 >> 16;
     $1187 = ((($1177) + ($1180<<3)|0) + 4|0);
     HEAP32[$1187>>2] = $1186;
     HEAP8[$1183>>0] = 1;
     $$idx117$val$pre = HEAP32[$41>>2]|0;
     $$idx117$val = $$idx117$val$pre;$$pre$phi$i320Z2D = $1178;
    }
    $1188 = HEAP16[$$pre$phi$i320Z2D>>1]|0;
    $1189 = (($1188) + 1)<<16>>16;
    HEAP16[$$pre$phi$i320Z2D>>1] = $1189;
    $$sum58 = (4 - ($145))|0;
    $1190 = (($110) + ($$sum58<<2)|0);
    $1191 = HEAP32[$1190>>2]|0;
    $1192 = (($1191) + ($1174))|0;
    $$idx118$val = HEAP8[$$idx184>>0]|0;
    $1193 = ($$idx118$val<<24>>24)==(0);
    if ($1193) {
     $$pre$i322 = (($$idx117$val) + 2|0);
     $$idx115$val = $$idx117$val;$$pre$phi$i324Z2D = $$pre$i322;
    } else {
     $1194 = (($$idx117$val) + 4|0);
     $1195 = HEAP32[$1194>>2]|0;
     $1196 = (($$idx117$val) + 2|0);
     $1197 = HEAP16[$1196>>1]|0;
     $1198 = $1197 << 16 >> 16;
     $1199 = (($$idx117$val) + 8|0);
     $1200 = HEAP32[$1199>>2]|0;
     $1201 = (($1200) + ($1198)|0);
     $1202 = $1192 >> 16;
     $1203 = (($1195) + ($1198<<3)|0);
     HEAP32[$1203>>2] = $1202;
     $1204 = $1156 >> 16;
     $1205 = ((($1195) + ($1198<<3)|0) + 4|0);
     HEAP32[$1205>>2] = $1204;
     HEAP8[$1201>>0] = 2;
     $$idx115$val$pre = HEAP32[$41>>2]|0;
     $$idx115$val = $$idx115$val$pre;$$pre$phi$i324Z2D = $1196;
    }
    $1206 = HEAP16[$$pre$phi$i324Z2D>>1]|0;
    $1207 = (($1206) + 1)<<16>>16;
    HEAP16[$$pre$phi$i324Z2D>>1] = $1207;
    $$sum59 = (5 - ($145))|0;
    $1208 = (($110) + ($$sum59<<2)|0);
    $1209 = HEAP32[$1208>>2]|0;
    $1210 = (($1209) + ($1192))|0;
    $$idx116$val = HEAP8[$$idx184>>0]|0;
    $1211 = ($$idx116$val<<24>>24)==(0);
    if ($1211) {
     $$pre$i326 = (($$idx115$val) + 2|0);
     $$idx113$val = $$idx115$val;$$pre$phi$i328Z2D = $$pre$i326;
    } else {
     $1212 = (($$idx115$val) + 4|0);
     $1213 = HEAP32[$1212>>2]|0;
     $1214 = (($$idx115$val) + 2|0);
     $1215 = HEAP16[$1214>>1]|0;
     $1216 = $1215 << 16 >> 16;
     $1217 = (($$idx115$val) + 8|0);
     $1218 = HEAP32[$1217>>2]|0;
     $1219 = (($1218) + ($1216)|0);
     $1220 = $1210 >> 16;
     $1221 = (($1213) + ($1216<<3)|0);
     HEAP32[$1221>>2] = $1220;
     $1222 = $y$0$ph >> 16;
     $1223 = ((($1213) + ($1216<<3)|0) + 4|0);
     HEAP32[$1223>>2] = $1222;
     HEAP8[$1219>>0] = 2;
     $$idx113$val$pre = HEAP32[$41>>2]|0;
     $$idx113$val = $$idx113$val$pre;$$pre$phi$i328Z2D = $1214;
    }
    $1224 = HEAP16[$$pre$phi$i328Z2D>>1]|0;
    $1225 = (($1224) + 1)<<16>>16;
    HEAP16[$$pre$phi$i328Z2D>>1] = $1225;
    $$sum60 = (6 - ($145))|0;
    $1226 = (($110) + ($$sum60<<2)|0);
    $1227 = HEAP32[$1226>>2]|0;
    $1228 = (($1227) + ($1210))|0;
    $$idx114$val = HEAP8[$$idx184>>0]|0;
    $1229 = ($$idx114$val<<24>>24)==(0);
    if ($1229) {
     $$pre$i330 = (($$idx113$val) + 2|0);
     $$pre$phi$i332Z2D = $$pre$i330;
    } else {
     $1230 = (($$idx113$val) + 4|0);
     $1231 = HEAP32[$1230>>2]|0;
     $1232 = (($$idx113$val) + 2|0);
     $1233 = HEAP16[$1232>>1]|0;
     $1234 = $1233 << 16 >> 16;
     $1235 = (($$idx113$val) + 8|0);
     $1236 = HEAP32[$1235>>2]|0;
     $1237 = (($1236) + ($1234)|0);
     $1238 = $1228 >> 16;
     $1239 = (($1231) + ($1234<<3)|0);
     HEAP32[$1239>>2] = $1238;
     $1240 = $y$0$ph >> 16;
     $1241 = ((($1231) + ($1234<<3)|0) + 4|0);
     HEAP32[$1241>>2] = $1240;
     HEAP8[$1237>>0] = 1;
     $$pre$phi$i332Z2D = $1232;
    }
    $1242 = HEAP16[$$pre$phi$i332Z2D>>1]|0;
    $1243 = (($1242) + 1)<<16>>16;
    HEAP16[$$pre$phi$i332Z2D>>1] = $1243;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $1228;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 17:  {
    $1244 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $1245 = ($1244|0)==(0);
    if (!($1245)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $1246 = HEAP32[$43>>2]|0;
    $1247 = (($1246) + 22|0);
    $1248 = HEAP16[$1247>>1]|0;
    $1249 = $1248 << 16 >> 16;
    $1250 = (($1246) + 58|0);
    $1251 = HEAP16[$1250>>1]|0;
    $1252 = $1251 << 16 >> 16;
    $1253 = (($1249) + 6)|0;
    $1254 = (($1253) + ($1252))|0;
    $1255 = (($1246) + 4|0);
    $1256 = HEAP32[$1255>>2]|0;
    $1257 = ($1254>>>0)>($1256>>>0);
    if ($1257) {
     $1258 = (_FT_GlyphLoader_CheckPoints($1246,6,0)|0);
     $1259 = ($1258|0)==(0);
     if (!($1259)) {
      $$0 = 0;
      label = 398;
      break L5;
     }
    }
    $1260 = HEAP32[$148>>2]|0;
    $$sum1137 = (1 - ($145))|0;
    $1261 = (($110) + ($$sum1137<<2)|0);
    $1262 = HEAP32[$1261>>2]|0;
    $$sum1138 = (2 - ($145))|0;
    $1263 = (($110) + ($$sum1138<<2)|0);
    $1264 = HEAP32[$1263>>2]|0;
    $1265 = (($1264) + ($1260))|0;
    $$sum1139 = (($$sum1138) + 1)|0;
    $1266 = (($110) + ($$sum1139<<2)|0);
    $1267 = HEAP32[$1266>>2]|0;
    $1268 = (($1267) + ($1262))|0;
    $$sum1140 = (($$sum1138) + 2)|0;
    $1269 = (($110) + ($$sum1140<<2)|0);
    $1270 = HEAP32[$1269>>2]|0;
    $1271 = (($1270) + ($1265))|0;
    $$sum1141 = (($$sum1138) + 3)|0;
    $1272 = (($110) + ($$sum1141<<2)|0);
    $1273 = HEAP32[$1272>>2]|0;
    $1274 = (($1273) + ($1268))|0;
    $$sum1142 = (($$sum1138) + 4)|0;
    $1275 = (($110) + ($$sum1142<<2)|0);
    $1276 = HEAP32[$1275>>2]|0;
    $1277 = (($1276) + ($1271))|0;
    $$sum1143 = (($$sum1138) + 5)|0;
    $1278 = (($110) + ($$sum1143<<2)|0);
    $1279 = HEAP32[$1278>>2]|0;
    $1280 = (($1279) + ($1274))|0;
    $$sum1144 = (($$sum1138) + 6)|0;
    $1281 = (($110) + ($$sum1144<<2)|0);
    $1282 = HEAP32[$1281>>2]|0;
    $1283 = (($1282) + ($1277))|0;
    $$sum1145 = (($$sum1138) + 7)|0;
    $1284 = (($110) + ($$sum1145<<2)|0);
    $1285 = HEAP32[$1284>>2]|0;
    $1286 = (($1285) + ($1280))|0;
    $1287 = (0 - ($1283))|0;
    $1288 = ($1286|0)<(0);
    $1289 = (0 - ($1286))|0;
    $dy$1 = $1288 ? $1289 : $1286;
    $1290 = (($1260) + ($x$0$ph))|0;
    $1291 = (($1262) + ($y$0$ph))|0;
    $$idx111$val = HEAP32[$41>>2]|0;
    $$idx112$val = HEAP8[$$idx184>>0]|0;
    $1292 = ($$idx112$val<<24>>24)==(0);
    if ($1292) {
     $$pre$i335 = (($$idx111$val) + 2|0);
     $$idx111$val$1 = $$idx111$val;$$pre$phi$i337Z2D = $$pre$i335;$1308 = $1264;$1310 = $1267;
    } else {
     $1293 = (($$idx111$val) + 4|0);
     $1294 = HEAP32[$1293>>2]|0;
     $1295 = (($$idx111$val) + 2|0);
     $1296 = HEAP16[$1295>>1]|0;
     $1297 = $1296 << 16 >> 16;
     $1298 = (($$idx111$val) + 8|0);
     $1299 = HEAP32[$1298>>2]|0;
     $1300 = (($1299) + ($1297)|0);
     $1301 = $1290 >> 16;
     $1302 = (($1294) + ($1297<<3)|0);
     HEAP32[$1302>>2] = $1301;
     $1303 = $1291 >> 16;
     $1304 = ((($1294) + ($1297<<3)|0) + 4|0);
     HEAP32[$1304>>2] = $1303;
     HEAP8[$1300>>0] = 2;
     $$pre1101 = HEAP32[$1263>>2]|0;
     $$pre1102 = HEAP32[$1266>>2]|0;
     $$idx111$val$1$pre = HEAP32[$41>>2]|0;
     $$idx111$val$1 = $$idx111$val$1$pre;$$pre$phi$i337Z2D = $1295;$1308 = $$pre1101;$1310 = $$pre1102;
    }
    $1305 = HEAP16[$$pre$phi$i337Z2D>>1]|0;
    $1306 = (($1305) + 1)<<16>>16;
    HEAP16[$$pre$phi$i337Z2D>>1] = $1306;
    $1307 = (($1308) + ($1290))|0;
    $1309 = (($1310) + ($1291))|0;
    $$idx112$val$1 = HEAP8[$$idx184>>0]|0;
    $1311 = ($$idx112$val$1<<24>>24)==(0);
    if ($1311) {
     $$pre$i335$1 = (($$idx111$val$1) + 2|0);
     $$idx111$val$2 = $$idx111$val$1;$$pre$phi$i337$1Z2D = $$pre$i335$1;
    } else {
     $1696 = (($$idx111$val$1) + 4|0);
     $1697 = HEAP32[$1696>>2]|0;
     $1698 = (($$idx111$val$1) + 2|0);
     $1699 = HEAP16[$1698>>1]|0;
     $1700 = $1699 << 16 >> 16;
     $1701 = (($$idx111$val$1) + 8|0);
     $1702 = HEAP32[$1701>>2]|0;
     $1703 = (($1702) + ($1700)|0);
     $1704 = $1307 >> 16;
     $1705 = (($1697) + ($1700<<3)|0);
     HEAP32[$1705>>2] = $1704;
     $1706 = $1309 >> 16;
     $1707 = ((($1697) + ($1700<<3)|0) + 4|0);
     HEAP32[$1707>>2] = $1706;
     HEAP8[$1703>>0] = 2;
     $$idx111$val$2$pre = HEAP32[$41>>2]|0;
     $$idx111$val$2 = $$idx111$val$2$pre;$$pre$phi$i337$1Z2D = $1698;
    }
    $1708 = HEAP16[$$pre$phi$i337$1Z2D>>1]|0;
    $1709 = (($1708) + 1)<<16>>16;
    HEAP16[$$pre$phi$i337$1Z2D>>1] = $1709;
    $1710 = HEAP32[$1269>>2]|0;
    $1711 = (($1710) + ($1307))|0;
    $1712 = HEAP32[$1272>>2]|0;
    $1713 = (($1712) + ($1309))|0;
    $$idx112$val$2 = HEAP8[$$idx184>>0]|0;
    $1714 = ($$idx112$val$2<<24>>24)==(0);
    if ($1714) {
     $$pre$i335$2 = (($$idx111$val$2) + 2|0);
     $$idx111$val$3 = $$idx111$val$2;$$pre$phi$i337$2Z2D = $$pre$i335$2;
    } else {
     $1715 = (($$idx111$val$2) + 4|0);
     $1716 = HEAP32[$1715>>2]|0;
     $1717 = (($$idx111$val$2) + 2|0);
     $1718 = HEAP16[$1717>>1]|0;
     $1719 = $1718 << 16 >> 16;
     $1720 = (($$idx111$val$2) + 8|0);
     $1721 = HEAP32[$1720>>2]|0;
     $1722 = (($1721) + ($1719)|0);
     $1723 = $1711 >> 16;
     $1724 = (($1716) + ($1719<<3)|0);
     HEAP32[$1724>>2] = $1723;
     $1725 = $1713 >> 16;
     $1726 = ((($1716) + ($1719<<3)|0) + 4|0);
     HEAP32[$1726>>2] = $1725;
     HEAP8[$1722>>0] = 1;
     $$idx111$val$3$pre = HEAP32[$41>>2]|0;
     $$idx111$val$3 = $$idx111$val$3$pre;$$pre$phi$i337$2Z2D = $1717;
    }
    $1727 = HEAP16[$$pre$phi$i337$2Z2D>>1]|0;
    $1728 = (($1727) + 1)<<16>>16;
    HEAP16[$$pre$phi$i337$2Z2D>>1] = $1728;
    $1729 = HEAP32[$1275>>2]|0;
    $1730 = (($1729) + ($1711))|0;
    $1731 = HEAP32[$1278>>2]|0;
    $1732 = (($1731) + ($1713))|0;
    $$idx112$val$3 = HEAP8[$$idx184>>0]|0;
    $1733 = ($$idx112$val$3<<24>>24)==(0);
    if ($1733) {
     $$pre$i335$3 = (($$idx111$val$3) + 2|0);
     $$idx111$val$4 = $$idx111$val$3;$$pre$phi$i337$3Z2D = $$pre$i335$3;
    } else {
     $1734 = (($$idx111$val$3) + 4|0);
     $1735 = HEAP32[$1734>>2]|0;
     $1736 = (($$idx111$val$3) + 2|0);
     $1737 = HEAP16[$1736>>1]|0;
     $1738 = $1737 << 16 >> 16;
     $1739 = (($$idx111$val$3) + 8|0);
     $1740 = HEAP32[$1739>>2]|0;
     $1741 = (($1740) + ($1738)|0);
     $1742 = $1730 >> 16;
     $1743 = (($1735) + ($1738<<3)|0);
     HEAP32[$1743>>2] = $1742;
     $1744 = $1732 >> 16;
     $1745 = ((($1735) + ($1738<<3)|0) + 4|0);
     HEAP32[$1745>>2] = $1744;
     HEAP8[$1741>>0] = 2;
     $$idx111$val$4$pre = HEAP32[$41>>2]|0;
     $$idx111$val$4 = $$idx111$val$4$pre;$$pre$phi$i337$3Z2D = $1736;
    }
    $1746 = HEAP16[$$pre$phi$i337$3Z2D>>1]|0;
    $1747 = (($1746) + 1)<<16>>16;
    HEAP16[$$pre$phi$i337$3Z2D>>1] = $1747;
    $1748 = HEAP32[$1281>>2]|0;
    $1749 = (($1748) + ($1730))|0;
    $1750 = HEAP32[$1284>>2]|0;
    $1751 = (($1750) + ($1732))|0;
    $$idx112$val$4 = HEAP8[$$idx184>>0]|0;
    $1752 = ($$idx112$val$4<<24>>24)==(0);
    if ($1752) {
     $$pre$i335$4 = (($$idx111$val$4) + 2|0);
     $$idx109$val = $$idx111$val$4;$$pre$phi$i337$4Z2D = $$pre$i335$4;
    } else {
     $1753 = (($$idx111$val$4) + 4|0);
     $1754 = HEAP32[$1753>>2]|0;
     $1755 = (($$idx111$val$4) + 2|0);
     $1756 = HEAP16[$1755>>1]|0;
     $1757 = $1756 << 16 >> 16;
     $1758 = (($$idx111$val$4) + 8|0);
     $1759 = HEAP32[$1758>>2]|0;
     $1760 = (($1759) + ($1757)|0);
     $1761 = $1749 >> 16;
     $1762 = (($1754) + ($1757<<3)|0);
     HEAP32[$1762>>2] = $1761;
     $1763 = $1751 >> 16;
     $1764 = ((($1754) + ($1757<<3)|0) + 4|0);
     HEAP32[$1764>>2] = $1763;
     HEAP8[$1760>>0] = 2;
     $$idx109$val$pre = HEAP32[$41>>2]|0;
     $$idx109$val = $$idx109$val$pre;$$pre$phi$i337$4Z2D = $1755;
    }
    $1765 = HEAP16[$$pre$phi$i337$4Z2D>>1]|0;
    $1766 = (($1765) + 1)<<16>>16;
    HEAP16[$$pre$phi$i337$4Z2D>>1] = $1766;
    $$sum1146 = (($$sum1138) + 8)|0;
    $1767 = (($110) + ($$sum1146<<2)|0);
    $1768 = HEAP32[$1767>>2]|0;
    $1769 = (($1768) + ($1749))|0;
    $1770 = ($1283|0)<(0);
    $$dx$0 = $1770 ? $1287 : $1283;
    $1771 = ($$dx$0|0)>($dy$1|0);
    $1772 = (($1768) + ($1751))|0;
    $y$14 = $1771 ? $y$0$ph : $1772;
    $x$14 = $1771 ? $1769 : $x$0$ph;
    $$idx110$val = HEAP8[$$idx184>>0]|0;
    $1773 = ($$idx110$val<<24>>24)==(0);
    if ($1773) {
     $$pre$i339 = (($$idx109$val) + 2|0);
     $$pre$phi$i341Z2D = $$pre$i339;
    } else {
     $1312 = (($$idx109$val) + 4|0);
     $1313 = HEAP32[$1312>>2]|0;
     $1314 = (($$idx109$val) + 2|0);
     $1315 = HEAP16[$1314>>1]|0;
     $1316 = $1315 << 16 >> 16;
     $1317 = (($$idx109$val) + 8|0);
     $1318 = HEAP32[$1317>>2]|0;
     $1319 = (($1318) + ($1316)|0);
     $1320 = $x$14 >> 16;
     $1321 = (($1313) + ($1316<<3)|0);
     HEAP32[$1321>>2] = $1320;
     $1322 = $y$14 >> 16;
     $1323 = ((($1313) + ($1316<<3)|0) + 4|0);
     HEAP32[$1323>>2] = $1322;
     HEAP8[$1319>>0] = 1;
     $$pre$phi$i341Z2D = $1314;
    }
    $1324 = HEAP16[$$pre$phi$i341Z2D>>1]|0;
    $1325 = (($1324) + 1)<<16>>16;
    HEAP16[$$pre$phi$i341Z2D>>1] = $1325;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$14;$y$16 = $y$14;$zone$1 = $zone$0$ph;
    break;
   }
   case 14:  {
    $1326 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $1327 = ($1326|0)==(0);
    if (!($1327)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $1328 = HEAP32[$43>>2]|0;
    $1329 = (($1328) + 22|0);
    $1330 = HEAP16[$1329>>1]|0;
    $1331 = $1330 << 16 >> 16;
    $1332 = (($1328) + 58|0);
    $1333 = HEAP16[$1332>>1]|0;
    $1334 = $1333 << 16 >> 16;
    $1335 = (($1331) + 6)|0;
    $1336 = (($1335) + ($1334))|0;
    $1337 = (($1328) + 4|0);
    $1338 = HEAP32[$1337>>2]|0;
    $1339 = ($1336>>>0)>($1338>>>0);
    if ($1339) {
     $1340 = (_FT_GlyphLoader_CheckPoints($1328,6,0)|0);
     $1341 = ($1340|0)==(0);
     if ($1341) {
      $args$11374 = $148;$count9$0373 = 6;$x$15376 = $x$0$ph;$y$15375 = $y$0$ph;
     } else {
      $$0 = 0;
      label = 398;
      break L5;
     }
    } else {
     $args$11374 = $148;$count9$0373 = 6;$x$15376 = $x$0$ph;$y$15375 = $y$0$ph;
    }
    while(1) {
     $1342 = HEAP32[$args$11374>>2]|0;
     $1343 = (($1342) + ($x$15376))|0;
     $1344 = (($args$11374) + 4|0);
     $1345 = HEAP32[$1344>>2]|0;
     $1346 = (($1345) + ($y$15375))|0;
     $1347 = ($count9$0373|0)==(4);
     if ($1347) {
      $1363 = 1;
     } else {
      $1348 = ($count9$0373|0)==(1);
      $phitmp54 = $1348&1;
      $1363 = $phitmp54;
     }
     $$idx107$val = HEAP32[$41>>2]|0;
     $$idx108$val = HEAP8[$$idx184>>0]|0;
     $1349 = ($$idx108$val<<24>>24)==(0);
     if ($1349) {
      $$pre$i344 = (($$idx107$val) + 2|0);
      $$pre$phi$i346Z2D = $$pre$i344;
     } else {
      $1350 = (($$idx107$val) + 4|0);
      $1351 = HEAP32[$1350>>2]|0;
      $1352 = (($$idx107$val) + 2|0);
      $1353 = HEAP16[$1352>>1]|0;
      $1354 = $1353 << 16 >> 16;
      $1355 = (($$idx107$val) + 8|0);
      $1356 = HEAP32[$1355>>2]|0;
      $1357 = (($1356) + ($1354)|0);
      $1358 = $1343 >> 16;
      $1359 = (($1351) + ($1354<<3)|0);
      HEAP32[$1359>>2] = $1358;
      $1360 = $1346 >> 16;
      $1361 = ((($1351) + ($1354<<3)|0) + 4|0);
      HEAP32[$1361>>2] = $1360;
      $1362 = ($1363<<24>>24)!=(0);
      $1364 = $1362 ? 1 : 2;
      HEAP8[$1357>>0] = $1364;
      $$pre$phi$i346Z2D = $1352;
     }
     $1365 = HEAP16[$$pre$phi$i346Z2D>>1]|0;
     $1366 = (($1365) + 1)<<16>>16;
     HEAP16[$$pre$phi$i346Z2D>>1] = $1366;
     $1367 = (($args$11374) + 8|0);
     $1368 = (($count9$0373) + -1)|0;
     $1369 = ($1368|0)==(0);
     if ($1369) {
      $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $1343;$y$16 = $1346;$zone$1 = $zone$0$ph;
      break;
     } else {
      $args$11374 = $1367;$count9$0373 = $1368;$x$15376 = $1343;$y$15375 = $1346;
     }
    }
    break;
   }
   case 56:  {
    label = 329;
    break L5;
    break;
   }
   case 18:  {
    label = 330;
    break L5;
    break;
   }
   case 26:  {
    $1420 = HEAP32[$148>>2]|0;
    $1421 = ($1420|0)<(0);
    if ($1421) {
     $1422 = (0 - ($1420))|0;
     HEAP32[$148>>2] = $1422;
    }
    $$sum45 = (1 - ($145))|0;
    $1423 = (($110) + ($$sum45<<2)|0);
    $args$12 = $1423;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 29:  {
    $1432 = HEAP32[$148>>2]|0;
    $$sum42 = (1 - ($145))|0;
    $1433 = (($110) + ($$sum42<<2)|0);
    $1434 = HEAP32[$1433>>2]|0;
    $1435 = (_FT_DivFix($1432,$1434)|0);
    HEAP32[$148>>2] = $1435;
    $args$12 = $1433;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 32:  {
    $1448 = HEAP32[$148>>2]|0;
    $$sum38 = (1 - ($145))|0;
    $1449 = (($110) + ($$sum38<<2)|0);
    $1450 = HEAP32[$1449>>2]|0;
    $1451 = (_FT_MulFix($1448,$1450)|0);
    HEAP32[$148>>2] = $1451;
    $args$12 = $1449;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 27:  {
    $$sum44 = (1 - ($145))|0;
    $1424 = (($110) + ($$sum44<<2)|0);
    $1425 = HEAP32[$1424>>2]|0;
    $1426 = HEAP32[$148>>2]|0;
    $1427 = (($1426) + ($1425))|0;
    HEAP32[$148>>2] = $1427;
    $args$12 = $1424;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 33:  {
    $1452 = HEAP32[$148>>2]|0;
    $1453 = ($1452|0)>(0);
    L187: do {
     if ($1453) {
      $1454 = $1452;$root$0 = $1452;
      while(1) {
       $1455 = (_FT_DivFix($1454,$root$0)|0);
       $1456 = (($root$0) + 1)|0;
       $1457 = (($1456) + ($1455))|0;
       $1458 = $1457 >> 1;
       $1459 = ($1458|0)==($root$0|0);
       if ($1459) {
        $storemerge = $root$0;
        break L187;
       }
       $$pre1119 = HEAP32[$148>>2]|0;
       $1454 = $$pre1119;$root$0 = $1458;
      }
     } else {
      $storemerge = 0;
     }
    } while(0);
    HEAP32[$148>>2] = $storemerge;
    $$sum37 = (1 - ($145))|0;
    $1460 = (($110) + ($$sum37<<2)|0);
    $args$12 = $1460;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 30:  {
    $1436 = HEAP32[$148>>2]|0;
    $1437 = (0 - ($1436))|0;
    HEAP32[$148>>2] = $1437;
    $$sum41 = (1 - ($145))|0;
    $1438 = (($110) + ($$sum41<<2)|0);
    $args$12 = $1438;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 31:  {
    $1439 = HEAP32[$seed>>2]|0;
    $1440 = ($1439|0)>(32767);
    $1441 = $1440&1;
    $$101 = (($1441) + ($1439))|0;
    HEAP32[$148>>2] = $$101;
    $1442 = HEAP32[$seed>>2]|0;
    $1443 = (65536 - ($1442))|0;
    $1444 = (_FT_MulFix($1442,$1443)|0);
    $1445 = ($1444|0)==(0);
    $1446 = (($1444) + 10355)|0;
    $storemerge40 = $1445 ? $1446 : $1444;
    HEAP32[$seed>>2] = $storemerge40;
    $$sum39 = (1 - ($145))|0;
    $1447 = (($110) + ($$sum39<<2)|0);
    $args$12 = $1447;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 28:  {
    $$sum43 = (1 - ($145))|0;
    $1428 = (($110) + ($$sum43<<2)|0);
    $1429 = HEAP32[$1428>>2]|0;
    $1430 = HEAP32[$148>>2]|0;
    $1431 = (($1430) - ($1429))|0;
    HEAP32[$148>>2] = $1431;
    $args$12 = $1428;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 36:  {
    $1461 = HEAP32[$148>>2]|0;
    $$sum35 = (1 - ($145))|0;
    $1462 = (($110) + ($$sum35<<2)|0);
    $1463 = HEAP32[$1462>>2]|0;
    HEAP32[$148>>2] = $1463;
    HEAP32[$1462>>2] = $1461;
    $$sum36 = (2 - ($145))|0;
    $1464 = (($110) + ($$sum36<<2)|0);
    $args$12 = $1464;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 38:  {
    $1473 = HEAP32[$148>>2]|0;
    $1474 = $1473 >> 16;
    $$sum24 = (1 - ($145))|0;
    $1475 = (($110) + ($$sum24<<2)|0);
    $1476 = HEAP32[$1475>>2]|0;
    $1477 = $1476 >> 16;
    $1478 = ($1474|0)<(1);
    $$103 = $1478 ? 1 : $1474;
    $sum = (($$103) + ($145))|0;
    $$sum25 = (0 - ($sum))|0;
    $1479 = (($110) + ($$sum25<<2)|0);
    $1480 = ($1479>>>0)<($19>>>0);
    if ($1480) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $1481 = ($1477|0)>(-1);
    if (!($1481)) {
     $1496 = (($$103) + -1)|0;
     $1497 = ($1496|0)>(0);
     if ($1497) {
      $idx12$1359$us = $1477;
     } else {
      $idx12$1359 = $1477;
      while(1) {
       $1509 = HEAP32[$1479>>2]|0;
       $$sum27 = (($1496) - ($sum))|0;
       $1510 = (($110) + ($$sum27<<2)|0);
       HEAP32[$1510>>2] = $1509;
       $1511 = (($idx12$1359) + 1)|0;
       $exitcond = ($1511|0)==(0);
       if ($exitcond) {
        $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
        break L107;
       } else {
        $idx12$1359 = $1511;
       }
      }
     }
     while(1) {
      $1499 = HEAP32[$1479>>2]|0;
      $i15$0358$us = 0;
      while(1) {
       $1501 = (($i15$0358$us) + 1)|0;
       $$sum28$us = (($1501) - ($sum))|0;
       $1502 = (($110) + ($$sum28$us<<2)|0);
       $1503 = HEAP32[$1502>>2]|0;
       $$sum29$us = (($i15$0358$us) - ($sum))|0;
       $1504 = (($110) + ($$sum29$us<<2)|0);
       HEAP32[$1504>>2] = $1503;
       $1505 = ($1501|0)<($1496|0);
       if ($1505) {
        $i15$0358$us = $1501;
       } else {
        break;
       }
      }
      $$sum27$us = (($1496) - ($sum))|0;
      $1498 = (($110) + ($$sum27$us<<2)|0);
      HEAP32[$1498>>2] = $1499;
      $1500 = (($idx12$1359$us) + 1)|0;
      $exitcond1061 = ($1500|0)==(0);
      if ($exitcond1061) {
       $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
       break L107;
      } else {
       $idx12$1359$us = $1500;
      }
     }
    }
    $1482 = ($1477|0)>(0);
    if ($1482) {
     $1483 = (($$103) + -1)|0;
     $$sum30 = (($1483) - ($sum))|0;
     $1484 = (($110) + ($$sum30<<2)|0);
     $1485 = (($$103) + -2)|0;
     $1486 = ($1485|0)>(-1);
     $1487 = (1 - ($sum))|0;
     if ($1486) {
      $idx12$0367$us = $1477;
     } else {
      $idx12$0367 = $1477;
      while(1) {
       $1506 = HEAP32[$1484>>2]|0;
       HEAP32[$1479>>2] = $1506;
       $1507 = (($idx12$0367) + -1)|0;
       $1508 = ($1507|0)>(0);
       if ($1508) {
        $idx12$0367 = $1507;
       } else {
        $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
        break L107;
       }
      }
     }
     while(1) {
      $1488 = HEAP32[$1484>>2]|0;
      $i$0361$us = $1485;
      while(1) {
       $$sum31$us = (($i$0361$us) - ($sum))|0;
       $1491 = (($110) + ($$sum31$us<<2)|0);
       $1492 = HEAP32[$1491>>2]|0;
       $$sum32$us = (($1487) + ($i$0361$us))|0;
       $1493 = (($110) + ($$sum32$us<<2)|0);
       HEAP32[$1493>>2] = $1492;
       $1494 = (($i$0361$us) + -1)|0;
       $1495 = ($i$0361$us|0)>(0);
       if ($1495) {
        $i$0361$us = $1494;
       } else {
        break;
       }
      }
      HEAP32[$1479>>2] = $1488;
      $1489 = (($idx12$0367$us) + -1)|0;
      $1490 = ($1489|0)>(0);
      if ($1490) {
       $idx12$0367$us = $1489;
      } else {
       $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
       break;
      }
     }
    } else {
     $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    }
    break;
   }
   case 37:  {
    $1465 = HEAP32[$148>>2]|0;
    $1466 = $1465 >> 16;
    $1467 = ($1466|0)<(0);
    if ($1467) {
     $idx$0 = -1;
    } else {
     $1468 = (($149) + -2)|0;
     $1469 = ($1466|0)>($1468|0);
     $$102 = $1469 ? $1468 : $1466;
     $phitmp354 = $$102 ^ -1;
     $idx$0 = $phitmp354;
    }
    $$sum33 = (($idx$0) - ($145))|0;
    $1470 = (($110) + ($$sum33<<2)|0);
    $1471 = HEAP32[$1470>>2]|0;
    HEAP32[$148>>2] = $1471;
    $$sum34 = (1 - ($145))|0;
    $1472 = (($110) + ($$sum34<<2)|0);
    $args$12 = $1472;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 54:  {
    $$sum14 = (-2 - ($145))|0;
    $1577 = (($110) + ($$sum14<<2)|0);
    $1578 = HEAP32[$1577>>2]|0;
    $1579 = $1578 >> 16;
    $$sum15 = (($$sum14) - ($1579))|0;
    $1580 = (($110) + ($$sum15<<2)|0);
    $1581 = ($1580>>>0)<($19>>>0);
    if ($1581) {
     $$0 = 129;
     label = 398;
     break L5;
    } else {
     $args$12 = $1580;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    }
    break;
   }
   case 55:  {
    $$sum13 = (1 - ($145))|0;
    $1582 = (($110) + ($$sum13<<2)|0);
    $args$12 = $1582;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 44:  {
    $1583 = HEAP32[$148>>2]|0;
    $1584 = ($1583|0)==(0);
    $$sum11$pre = (1 - ($145))|0;
    $$pre1129 = (($110) + ($$sum11$pre<<2)|0);
    if ($1584) {
     $1587 = 0;
    } else {
     $1585 = HEAP32[$$pre1129>>2]|0;
     $1586 = ($1585|0)!=(0);
     $phitmp10 = $1586 ? 65536 : 0;
     $1587 = $phitmp10;
    }
    HEAP32[$148>>2] = $1587;
    $args$12 = $$pre1129;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 57:  {
    $1546 = HEAP32[$0>>2]|0;
    $1547 = (($1546) + 748|0);
    $1548 = HEAP32[$1547>>2]|0;
    $$sum17 = (2 - ($145))|0;
    $1549 = (($110) + ($$sum17<<2)|0);
    $1550 = HEAP32[$1549>>2]|0;
    $1551 = $1550 >> 16;
    $1552 = (($1551) + ($1548))|0;
    $1553 = (($1546) + 744|0);
    HEAP32[$1553>>2] = $1552;
    $1554 = HEAP32[$148>>2]|0;
    $1555 = (($1546) + 32|0);
    HEAP32[$1555>>2] = $1554;
    $$sum18 = (1 - ($145))|0;
    $1556 = (($110) + ($$sum18<<2)|0);
    $1557 = HEAP32[$1556>>2]|0;
    $1558 = (($1546) + 36|0);
    HEAP32[$1558>>2] = $1557;
    $1559 = (($1546) + 24|0);
    $1560 = HEAP32[$1559>>2]|0;
    $1561 = HEAP32[$148>>2]|0;
    $1562 = (($1561) + ($1560))|0;
    $1563 = (($1546) + 28|0);
    $1564 = HEAP32[$1563>>2]|0;
    $1565 = HEAP32[$1556>>2]|0;
    $1566 = (($1565) + ($1564))|0;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $1562;$y$16 = $1566;$zone$1 = $zone$0$ph;
    break;
   }
   case 52:  {
    $1529 = HEAP32[$0>>2]|0;
    $1530 = (($1529) + 748|0);
    $1531 = HEAP32[$1530>>2]|0;
    $$sum19 = (1 - ($145))|0;
    $1532 = (($110) + ($$sum19<<2)|0);
    $1533 = HEAP32[$1532>>2]|0;
    $1534 = $1533 >> 16;
    $1535 = (($1534) + ($1531))|0;
    $1536 = (($1529) + 744|0);
    HEAP32[$1536>>2] = $1535;
    $1537 = HEAP32[$148>>2]|0;
    $1538 = (($1529) + 32|0);
    HEAP32[$1538>>2] = $1537;
    $1539 = (($1529) + 36|0);
    HEAP32[$1539>>2] = 0;
    $1540 = (($1529) + 24|0);
    $1541 = HEAP32[$1540>>2]|0;
    $1542 = HEAP32[$148>>2]|0;
    $1543 = (($1542) + ($1541))|0;
    $1544 = (($1529) + 28|0);
    $1545 = HEAP32[$1544>>2]|0;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $1543;$y$16 = $1545;$zone$1 = $zone$0$ph;
    break;
   }
   case 40:  {
    $$sum21 = (1 - ($145))|0;
    $1515 = (($110) + ($$sum21<<2)|0);
    $1516 = HEAP32[$1515>>2]|0;
    $1517 = $1516 >> 16;
    $1518 = ($1517>>>0)<(32);
    if ($1518) {
     $1519 = HEAP32[$148>>2]|0;
     $1520 = HEAP32[$0>>2]|0;
     $1521 = ((($1520) + ($1517<<2)|0) + 760|0);
     HEAP32[$1521>>2] = $1519;
     $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    } else {
     $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    }
    break;
   }
   case 58:  {
    $1567 = HEAP32[$0>>2]|0;
    $1568 = (($1567) + 24|0);
    $1569 = HEAP32[$1568>>2]|0;
    $1570 = HEAP32[$148>>2]|0;
    $1571 = (($1570) + ($1569))|0;
    $1572 = (($1567) + 28|0);
    $1573 = HEAP32[$1572>>2]|0;
    $$sum16 = (1 - ($145))|0;
    $1574 = (($110) + ($$sum16<<2)|0);
    $1575 = HEAP32[$1574>>2]|0;
    $1576 = (($1575) + ($1573))|0;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $1571;$y$16 = $1576;$zone$1 = $zone$0$ph;
    break;
   }
   case 47:  {
    $1594 = HEAP32[$148>>2]|0;
    $1595 = ($1594|0)==(0);
    $1596 = $1595 ? 65536 : 0;
    HEAP32[$148>>2] = $1596;
    $$sum7 = (1 - ($145))|0;
    $1597 = (($110) + ($$sum7<<2)|0);
    $args$12 = $1597;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 45:  {
    $1588 = HEAP32[$148>>2]|0;
    $1589 = ($1588|0)==(0);
    $$sum8 = (1 - ($145))|0;
    $1590 = (($110) + ($$sum8<<2)|0);
    if ($1589) {
     $1591 = HEAP32[$1590>>2]|0;
     $1592 = ($1591|0)!=(0);
     $phitmp = $1592 ? 65536 : 0;
     $1593 = $phitmp;
    } else {
     $1593 = 65536;
    }
    HEAP32[$148>>2] = $1593;
    $args$12 = $1590;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 41:  {
    $1522 = HEAP32[$148>>2]|0;
    $1523 = $1522 >> 16;
    $1524 = ($1523>>>0)<(32);
    if ($1524) {
     $1525 = HEAP32[$0>>2]|0;
     $1526 = ((($1525) + ($1523<<2)|0) + 760|0);
     $1527 = HEAP32[$1526>>2]|0;
     $val19$0 = $1527;
    } else {
     $val19$0 = 0;
    }
    HEAP32[$148>>2] = $val19$0;
    $$sum20 = (1 - ($145))|0;
    $1528 = (($110) + ($$sum20<<2)|0);
    $args$12 = $1528;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 39:  {
    $1512 = HEAP32[$148>>2]|0;
    $$sum22 = (1 - ($145))|0;
    $1513 = (($110) + ($$sum22<<2)|0);
    HEAP32[$1513>>2] = $1512;
    $$sum23 = (2 - ($145))|0;
    $1514 = (($110) + ($$sum23<<2)|0);
    $args$12 = $1514;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 53:  {
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 48:  {
    $$sum = (2 - ($145))|0;
    $1598 = (($110) + ($$sum<<2)|0);
    $1599 = HEAP32[$1598>>2]|0;
    $$sum4 = (3 - ($145))|0;
    $1600 = (($110) + ($$sum4<<2)|0);
    $1601 = HEAP32[$1600>>2]|0;
    $1602 = ($1599|0)>($1601|0);
    $$sum5 = (1 - ($145))|0;
    $1603 = (($110) + ($$sum5<<2)|0);
    if ($1602) {
     $1604 = HEAP32[$1603>>2]|0;
     HEAP32[$148>>2] = $1604;
     $args$12 = $1603;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    } else {
     $args$12 = $1603;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    }
    break;
   }
   case 49:  {
    $1605 = HEAP32[$148>>2]|0;
    $1606 = $1605 >> 16;
    $1607 = HEAP32[$0>>2]|0;
    $1608 = (($1607) + 896|0);
    $1609 = HEAP32[$1608>>2]|0;
    $1610 = (($1609) + ($1606))|0;
    $1611 = (($1607) + 888|0);
    $1612 = HEAP32[$1611>>2]|0;
    $1613 = ($1610>>>0)<($1612>>>0);
    if (!($1613)) {
     $$0 = 3;
     label = 398;
     break L5;
    }
    $1614 = (($1607) + 280|0);
    $1615 = $zone$0$ph;
    $1616 = $1614;
    $1617 = (($1615) - ($1616))|0;
    $1618 = ($1617|0)>(372);
    if ($1618) {
     $$0 = 3;
     label = 398;
     break L5;
    }
    $1619 = (($zone$0$ph) + 8|0);
    HEAP32[$1619>>2] = $ip$2$ph;
    $1620 = (($zone$0$ph) + 12|0);
    $1621 = HEAP32[$0>>2]|0;
    $1622 = (($1621) + 904|0);
    $1623 = HEAP32[$1622>>2]|0;
    $1624 = (($1623) + ($1610<<2)|0);
    $1625 = HEAP32[$1624>>2]|0;
    HEAP32[$1620>>2] = $1625;
    $1626 = (($1610) + 1)|0;
    $1627 = HEAP32[$0>>2]|0;
    $1628 = (($1627) + 904|0);
    $1629 = HEAP32[$1628>>2]|0;
    $1630 = (($1629) + ($1626<<2)|0);
    $1631 = HEAP32[$1630>>2]|0;
    $1632 = (($zone$0$ph) + 16|0);
    HEAP32[$1632>>2] = $1631;
    $1633 = (($zone$0$ph) + 20|0);
    HEAP32[$1633>>2] = $1625;
    $1634 = ($1625|0)==(0|0);
    $1635 = ($1631|0)==($1625|0);
    $or$cond1158 = $1634 | $1635;
    if ($or$cond1158) {
     $$0 = 3;
     label = 398;
     break L5;
    }
    $1636 = HEAP32[$0>>2]|0;
    $1637 = (($1636) + 676|0);
    HEAP32[$1637>>2] = $1620;
    $1638 = HEAP32[$1620>>2]|0;
    $1639 = HEAP32[$1632>>2]|0;
    $args$12 = $148;$ip$3 = $1638;$limit$1 = $1639;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $1620;
    break;
   }
   case 50:  {
    $1640 = HEAP32[$148>>2]|0;
    $1641 = $1640 >> 16;
    $1642 = HEAP32[$0>>2]|0;
    $1643 = (($1642) + 900|0);
    $1644 = HEAP32[$1643>>2]|0;
    $1645 = (($1644) + ($1641))|0;
    $1646 = (($1642) + 892|0);
    $1647 = HEAP32[$1646>>2]|0;
    $1648 = ($1645>>>0)<($1647>>>0);
    if (!($1648)) {
     $$0 = 3;
     label = 398;
     break L5;
    }
    $1649 = (($1642) + 280|0);
    $1650 = $zone$0$ph;
    $1651 = $1649;
    $1652 = (($1650) - ($1651))|0;
    $1653 = ($1652|0)>(372);
    if ($1653) {
     $$0 = 3;
     label = 398;
     break L5;
    }
    $1654 = (($zone$0$ph) + 8|0);
    HEAP32[$1654>>2] = $ip$2$ph;
    $1655 = (($zone$0$ph) + 12|0);
    $1656 = HEAP32[$0>>2]|0;
    $1657 = (($1656) + 908|0);
    $1658 = HEAP32[$1657>>2]|0;
    $1659 = (($1658) + ($1645<<2)|0);
    $1660 = HEAP32[$1659>>2]|0;
    HEAP32[$1655>>2] = $1660;
    $1661 = (($1645) + 1)|0;
    $1662 = HEAP32[$0>>2]|0;
    $1663 = (($1662) + 908|0);
    $1664 = HEAP32[$1663>>2]|0;
    $1665 = (($1664) + ($1661<<2)|0);
    $1666 = HEAP32[$1665>>2]|0;
    $1667 = (($zone$0$ph) + 16|0);
    HEAP32[$1667>>2] = $1666;
    $1668 = (($zone$0$ph) + 20|0);
    HEAP32[$1668>>2] = $1660;
    $1669 = ($1660|0)==(0|0);
    $1670 = ($1666|0)==($1660|0);
    $or$cond1159 = $1669 | $1670;
    if ($or$cond1159) {
     $$0 = 3;
     label = 398;
     break L5;
    }
    $1671 = HEAP32[$0>>2]|0;
    $1672 = (($1671) + 676|0);
    HEAP32[$1672>>2] = $1655;
    $1673 = HEAP32[$1655>>2]|0;
    $1674 = HEAP32[$1667>>2]|0;
    $args$12 = $148;$ip$3 = $1673;$limit$1 = $1674;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $1655;
    break;
   }
   case 25: case 35:  {
    $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 51:  {
    $1675 = HEAP32[$0>>2]|0;
    $1676 = (($1675) + 676|0);
    $1677 = HEAP32[$1676>>2]|0;
    $1678 = (($1675) + 280|0);
    $1679 = ($1677>>>0)>($1678>>>0);
    if (!($1679)) {
     $$0 = 3;
     label = 398;
     break L5;
    }
    $1680 = (($1677) + -12|0);
    HEAP32[$1676>>2] = $1680;
    $1681 = HEAP32[$0>>2]|0;
    $1682 = (($1681) + 676|0);
    $1683 = HEAP32[$1682>>2]|0;
    $1684 = (($1683) + 8|0);
    $1685 = HEAP32[$1684>>2]|0;
    $1686 = (($1683) + 4|0);
    $1687 = HEAP32[$1686>>2]|0;
    $args$12 = $148;$ip$3 = $1685;$limit$1 = $1687;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $1683;
    break;
   }
   case 22: case 21: case 20: case 19:  {
    if ($33) {
     $150 = HEAP32[$39>>2]|0;
     $151 = HEAP32[$$pre$phi1128Z2D>>2]|0;
     $152 = ($op$0$ph|0)==(19);
     $153 = ($op$0$ph|0)==(21);
     $$97 = $152 | $153;
     $154 = $$97&1;
     $155 = (($149|0) / 2)&-1;
     $156 = $149 & -2;
     $sum94 = (($145) + ($156))|0;
     $$sum93 = (0 - ($sum94))|0;
     $157 = (($110) + ($$sum93<<2)|0);
     FUNCTION_TABLE_viiii[$150 & 511]($151,$154,$155,$157);
     $$pre$phiZ2D = $155;
    } else {
     $$pre1121 = (($149|0) / 2)&-1;
     $$pre$phiZ2D = $$pre1121;
    }
    $158 = HEAP32[$0>>2]|0;
    $159 = (($158) + 756|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = (($160) + ($$pre$phiZ2D))|0;
    HEAP32[$159>>2] = $161;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 7:  {
    $317 = ($149|0)<(6);
    if ($317) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $318 = (($149|0) % 6)&-1;
    $319 = (($149) - ($318))|0;
    $320 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $321 = ($320|0)==(0);
    if (!($321)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $322 = (($319|0) / 2)&-1;
    $$off = (($319) + 1)|0;
    $323 = ($$off>>>0)<(3);
    if (!($323)) {
     $324 = HEAP32[$43>>2]|0;
     $325 = (($324) + 22|0);
     $326 = HEAP16[$325>>1]|0;
     $327 = $326 << 16 >> 16;
     $328 = (($324) + 58|0);
     $329 = HEAP16[$328>>1]|0;
     $330 = $329 << 16 >> 16;
     $331 = (($327) + ($322))|0;
     $332 = (($331) + ($330))|0;
     $333 = (($324) + 4|0);
     $334 = HEAP32[$333>>2]|0;
     $335 = ($332>>>0)>($334>>>0);
     if ($335) {
      $336 = (_FT_GlyphLoader_CheckPoints($324,$322,0)|0);
      $337 = ($336|0)==(0);
      if (!($337)) {
       $$0 = 0;
       label = 398;
       break L5;
      }
     }
    }
    $sum81 = (($145) + ($319))|0;
    $$sum80 = (0 - ($sum81))|0;
    $338 = (($110) + ($$sum80<<2)|0);
    $339 = HEAP32[$0>>2]|0;
    $340 = (($339) + 276|0);
    $341 = HEAP32[$340>>2]|0;
    $342 = ($338>>>0)<($341>>>0);
    if ($342) {
     $args$2442 = $338;$x$4444 = $x$0$ph;$y$4443 = $y$0$ph;
     while(1) {
      $343 = HEAP32[$args$2442>>2]|0;
      $344 = (($343) + ($x$4444))|0;
      $345 = (($args$2442) + 4|0);
      $346 = HEAP32[$345>>2]|0;
      $347 = (($346) + ($y$4443))|0;
      $$idx181$val = HEAP32[$41>>2]|0;
      $$idx182$val = HEAP8[$$idx184>>0]|0;
      $348 = ($$idx182$val<<24>>24)==(0);
      if ($348) {
       $$pre$i187 = (($$idx181$val) + 2|0);
       $$idx179$val = $$idx181$val;$$pre$phi$i189Z2D = $$pre$i187;
      } else {
       $349 = (($$idx181$val) + 4|0);
       $350 = HEAP32[$349>>2]|0;
       $351 = (($$idx181$val) + 2|0);
       $352 = HEAP16[$351>>1]|0;
       $353 = $352 << 16 >> 16;
       $354 = (($$idx181$val) + 8|0);
       $355 = HEAP32[$354>>2]|0;
       $356 = (($355) + ($353)|0);
       $357 = $344 >> 16;
       $358 = (($350) + ($353<<3)|0);
       HEAP32[$358>>2] = $357;
       $359 = $347 >> 16;
       $360 = ((($350) + ($353<<3)|0) + 4|0);
       HEAP32[$360>>2] = $359;
       HEAP8[$356>>0] = 2;
       $$idx179$val$pre = HEAP32[$41>>2]|0;
       $$idx179$val = $$idx179$val$pre;$$pre$phi$i189Z2D = $351;
      }
      $361 = HEAP16[$$pre$phi$i189Z2D>>1]|0;
      $362 = (($361) + 1)<<16>>16;
      HEAP16[$$pre$phi$i189Z2D>>1] = $362;
      $363 = (($args$2442) + 8|0);
      $364 = HEAP32[$363>>2]|0;
      $365 = (($364) + ($344))|0;
      $366 = (($args$2442) + 12|0);
      $367 = HEAP32[$366>>2]|0;
      $368 = (($367) + ($347))|0;
      $$idx180$val = HEAP8[$$idx184>>0]|0;
      $369 = ($$idx180$val<<24>>24)==(0);
      if ($369) {
       $$pre$i191 = (($$idx179$val) + 2|0);
       $$idx177$val = $$idx179$val;$$pre$phi$i193Z2D = $$pre$i191;
      } else {
       $370 = (($$idx179$val) + 4|0);
       $371 = HEAP32[$370>>2]|0;
       $372 = (($$idx179$val) + 2|0);
       $373 = HEAP16[$372>>1]|0;
       $374 = $373 << 16 >> 16;
       $375 = (($$idx179$val) + 8|0);
       $376 = HEAP32[$375>>2]|0;
       $377 = (($376) + ($374)|0);
       $378 = $365 >> 16;
       $379 = (($371) + ($374<<3)|0);
       HEAP32[$379>>2] = $378;
       $380 = $368 >> 16;
       $381 = ((($371) + ($374<<3)|0) + 4|0);
       HEAP32[$381>>2] = $380;
       HEAP8[$377>>0] = 2;
       $$idx177$val$pre = HEAP32[$41>>2]|0;
       $$idx177$val = $$idx177$val$pre;$$pre$phi$i193Z2D = $372;
      }
      $382 = HEAP16[$$pre$phi$i193Z2D>>1]|0;
      $383 = (($382) + 1)<<16>>16;
      HEAP16[$$pre$phi$i193Z2D>>1] = $383;
      $384 = (($args$2442) + 16|0);
      $385 = HEAP32[$384>>2]|0;
      $386 = (($385) + ($365))|0;
      $387 = (($args$2442) + 20|0);
      $388 = HEAP32[$387>>2]|0;
      $389 = (($388) + ($368))|0;
      $$idx178$val = HEAP8[$$idx184>>0]|0;
      $390 = ($$idx178$val<<24>>24)==(0);
      if ($390) {
       $$pre$i195 = (($$idx177$val) + 2|0);
       $$pre$phi$i197Z2D = $$pre$i195;
      } else {
       $391 = (($$idx177$val) + 4|0);
       $392 = HEAP32[$391>>2]|0;
       $393 = (($$idx177$val) + 2|0);
       $394 = HEAP16[$393>>1]|0;
       $395 = $394 << 16 >> 16;
       $396 = (($$idx177$val) + 8|0);
       $397 = HEAP32[$396>>2]|0;
       $398 = (($397) + ($395)|0);
       $399 = $386 >> 16;
       $400 = (($392) + ($395<<3)|0);
       HEAP32[$400>>2] = $399;
       $401 = $389 >> 16;
       $402 = ((($392) + ($395<<3)|0) + 4|0);
       HEAP32[$402>>2] = $401;
       HEAP8[$398>>0] = 1;
       $$pre$phi$i197Z2D = $393;
      }
      $403 = HEAP16[$$pre$phi$i197Z2D>>1]|0;
      $404 = (($403) + 1)<<16>>16;
      HEAP16[$$pre$phi$i197Z2D>>1] = $404;
      $405 = (($args$2442) + 24|0);
      $406 = HEAP32[$0>>2]|0;
      $407 = (($406) + 276|0);
      $408 = HEAP32[$407>>2]|0;
      $409 = ($405>>>0)<($408>>>0);
      if ($409) {
       $args$2442 = $405;$x$4444 = $386;$y$4443 = $389;
      } else {
       $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $386;$y$16 = $389;$zone$1 = $zone$0$ph;
       break;
      }
     }
    } else {
     $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    }
    break;
   }
   case 1:  {
    $$idx106$val = HEAP32[$41>>2]|0;
    _cff_builder_close_contour($$idx106$val);
    HEAP8[$25>>0] = 0;
    $$sum88 = (-2 - ($145))|0;
    $192 = (($110) + ($$sum88<<2)|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = (($193) + ($x$0$ph))|0;
    $req_args$0$not90 = $req_args$0 | -16;
    $$sum89 = $req_args$0$not90 ^ 15;
    $195 = (($110) + ($$sum89<<2)|0);
    $196 = HEAP32[$195>>2]|0;
    $197 = (($196) + ($y$0$ph))|0;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $194;$y$16 = $197;$zone$1 = $zone$0$ph;
    break;
   }
   case 6: case 5:  {
    $254 = ($op$0$ph|0)==(5);
    $255 = $254&1;
    $256 = ($149|0)<(0);
    if ($256) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $257 = ($num_args$1|0)==($145|0);
    if ($257) {
     $args$12 = $148;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    } else {
     $258 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
     $259 = ($258|0)==(0);
     if (!($259)) {
      $$0 = 0;
      label = 398;
      break L5;
     }
     $260 = HEAP32[$43>>2]|0;
     $261 = (($260) + 22|0);
     $262 = HEAP16[$261>>1]|0;
     $263 = $262 << 16 >> 16;
     $264 = (($260) + 58|0);
     $265 = HEAP16[$264>>1]|0;
     $266 = $265 << 16 >> 16;
     $267 = (($263) + ($149))|0;
     $268 = (($267) + ($266))|0;
     $269 = (($260) + 4|0);
     $270 = HEAP32[$269>>2]|0;
     $271 = ($268>>>0)>($270>>>0);
     if ($271) {
      $272 = (_FT_GlyphLoader_CheckPoints($260,$149,0)|0);
      $273 = ($272|0)==(0);
      if (!($273)) {
       $$0 = 0;
       label = 398;
       break L5;
      }
     }
     $274 = HEAP32[$0>>2]|0;
     $275 = (($274) + 276|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = ($19>>>0)<($276>>>0);
     if ($277) {
      $args$1452 = $19;$phase$0451 = $255;$x$2454 = $x$0$ph;$y$2453 = $y$0$ph;
      while(1) {
       $278 = ($phase$0451|0)==(0);
       $279 = HEAP32[$args$1452>>2]|0;
       $280 = $278 ? $279 : 0;
       $y$3 = (($280) + ($y$2453))|0;
       $281 = $278 ? 0 : $279;
       $x$3 = (($281) + ($x$2454))|0;
       $282 = HEAP32[$43>>2]|0;
       $283 = (($282) + 22|0);
       $284 = HEAP16[$283>>1]|0;
       $285 = $284 << 16 >> 16;
       $286 = (($282) + 58|0);
       $287 = HEAP16[$286>>1]|0;
       $288 = $287 << 16 >> 16;
       $289 = (($285) + 1)|0;
       $290 = (($289) + ($288))|0;
       $291 = (($282) + 4|0);
       $292 = HEAP32[$291>>2]|0;
       $293 = ($290>>>0)>($292>>>0);
       if ($293) {
        $294 = (_FT_GlyphLoader_CheckPoints($282,1,0)|0);
        $295 = ($294|0)==(0);
        if (!($295)) {
         $$0 = 0;
         label = 398;
         break L5;
        }
       }
       $builder$idx$val$i = HEAP32[$41>>2]|0;
       $builder$idx1$val$i = HEAP8[$$idx184>>0]|0;
       $296 = ($builder$idx1$val$i<<24>>24)==(0);
       if ($296) {
        $$pre$i$i = (($builder$idx$val$i) + 2|0);
        $$pre$phi$i$iZ2D = $$pre$i$i;
       } else {
        $297 = (($builder$idx$val$i) + 4|0);
        $298 = HEAP32[$297>>2]|0;
        $299 = (($builder$idx$val$i) + 2|0);
        $300 = HEAP16[$299>>1]|0;
        $301 = $300 << 16 >> 16;
        $302 = (($builder$idx$val$i) + 8|0);
        $303 = HEAP32[$302>>2]|0;
        $304 = (($303) + ($301)|0);
        $305 = $x$3 >> 16;
        $306 = (($298) + ($301<<3)|0);
        HEAP32[$306>>2] = $305;
        $307 = $y$3 >> 16;
        $308 = ((($298) + ($301<<3)|0) + 4|0);
        HEAP32[$308>>2] = $307;
        HEAP8[$304>>0] = 1;
        $$pre$phi$i$iZ2D = $299;
       }
       $309 = HEAP16[$$pre$phi$i$iZ2D>>1]|0;
       $310 = (($309) + 1)<<16>>16;
       HEAP16[$$pre$phi$i$iZ2D>>1] = $310;
       $311 = (($args$1452) + 4|0);
       $312 = HEAP32[$0>>2]|0;
       $313 = (($312) + 276|0);
       $314 = HEAP32[$313>>2]|0;
       $315 = ($311>>>0)<($314>>>0);
       if (!($315)) {
        $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$3;$y$16 = $y$3;$zone$1 = $zone$0$ph;
        break L107;
       }
       $316 = $phase$0451 ^ 1;
       $args$1452 = $311;$phase$0451 = $316;$x$2454 = $x$3;$y$2453 = $y$3;
      }
     } else {
      $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
     }
    }
    break;
   }
   case 3:  {
    $$idx105$val = HEAP32[$41>>2]|0;
    _cff_builder_close_contour($$idx105$val);
    HEAP8[$25>>0] = 0;
    $req_args$0$not87 = $req_args$0 | -16;
    $$sum86 = $req_args$0$not87 ^ 15;
    $198 = (($110) + ($$sum86<<2)|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = (($199) + ($y$0$ph))|0;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $200;$zone$1 = $zone$0$ph;
    break;
   }
   case 4:  {
    $204 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $205 = ($204|0)==(0);
    if (!($205)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $206 = (($149|0) / 2)&-1;
    $$off355 = (($149) + 1)|0;
    $207 = ($$off355>>>0)<(3);
    if ($207) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $208 = HEAP32[$43>>2]|0;
    $209 = (($208) + 22|0);
    $210 = HEAP16[$209>>1]|0;
    $211 = $210 << 16 >> 16;
    $212 = (($208) + 58|0);
    $213 = HEAP16[$212>>1]|0;
    $214 = $213 << 16 >> 16;
    $215 = (($211) + ($206))|0;
    $216 = (($215) + ($214))|0;
    $217 = (($208) + 4|0);
    $218 = HEAP32[$217>>2]|0;
    $219 = ($216>>>0)>($218>>>0);
    if ($219) {
     $220 = (_FT_GlyphLoader_CheckPoints($208,$206,0)|0);
     $221 = ($220|0)==(0);
     if (!($221)) {
      $$0 = 0;
      label = 398;
      break L5;
     }
    }
    $222 = ($149|0)<(2);
    if ($222) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $223 = $149 & -2;
    $sum83 = (($145) + ($223))|0;
    $$sum82 = (0 - ($sum83))|0;
    $224 = (($110) + ($$sum82<<2)|0);
    $225 = HEAP32[$0>>2]|0;
    $226 = (($225) + 276|0);
    $227 = HEAP32[$226>>2]|0;
    $228 = ($224>>>0)<($227>>>0);
    if ($228) {
     $1774 = $225;$args$0459 = $224;$x$1461 = $x$0$ph;$y$1460 = $y$0$ph;
     while(1) {
      $229 = HEAP32[$args$0459>>2]|0;
      $230 = (($229) + ($x$1461))|0;
      $231 = (($args$0459) + 4|0);
      $232 = HEAP32[$231>>2]|0;
      $233 = (($232) + ($y$1460))|0;
      $$idx183$val = HEAP32[$41>>2]|0;
      $$idx184$val = HEAP8[$$idx184>>0]|0;
      $234 = ($$idx184$val<<24>>24)==(0);
      if ($234) {
       $$pre$i = (($$idx183$val) + 2|0);
       $$pre$phi$iZ2D = $$pre$i;$251 = $1774;
      } else {
       $235 = (($$idx183$val) + 4|0);
       $236 = HEAP32[$235>>2]|0;
       $237 = (($$idx183$val) + 2|0);
       $238 = HEAP16[$237>>1]|0;
       $239 = $238 << 16 >> 16;
       $240 = (($$idx183$val) + 8|0);
       $241 = HEAP32[$240>>2]|0;
       $242 = (($241) + ($239)|0);
       $243 = $230 >> 16;
       $244 = (($236) + ($239<<3)|0);
       HEAP32[$244>>2] = $243;
       $245 = $233 >> 16;
       $246 = ((($236) + ($239<<3)|0) + 4|0);
       HEAP32[$246>>2] = $245;
       HEAP8[$242>>0] = 1;
       $$pre = HEAP32[$0>>2]|0;
       $$pre$phi$iZ2D = $237;$251 = $$pre;
      }
      $247 = HEAP16[$$pre$phi$iZ2D>>1]|0;
      $248 = (($247) + 1)<<16>>16;
      HEAP16[$$pre$phi$iZ2D>>1] = $248;
      $249 = (($args$0459) + 8|0);
      $250 = (($251) + 276|0);
      $252 = HEAP32[$250>>2]|0;
      $253 = ($249>>>0)<($252>>>0);
      if ($253) {
       $1774 = $251;$args$0459 = $249;$x$1461 = $230;$y$1460 = $233;
      } else {
       $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $230;$y$16 = $233;$zone$1 = $zone$0$ph;
       break;
      }
     }
    } else {
     $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    }
    break;
   }
   case 24: case 23:  {
    $162 = ($149|0)>(0);
    if ($162) {
     if ($33) {
      $163 = HEAP32[$39>>2]|0;
      $164 = HEAP32[$$pre$phi1128Z2D>>2]|0;
      $165 = (($149|0) / 2)&-1;
      $166 = $149 & -2;
      $sum92 = (($145) + ($166))|0;
      $$sum91 = (0 - ($sum92))|0;
      $167 = (($110) + ($$sum91<<2)|0);
      FUNCTION_TABLE_viiii[$163 & 511]($164,0,$165,$167);
      $$pre$phi1123Z2D = $165;
     } else {
      $$pre1122 = (($149|0) / 2)&-1;
      $$pre$phi1123Z2D = $$pre1122;
     }
     $168 = HEAP32[$0>>2]|0;
     $169 = (($168) + 756|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = (($170) + ($$pre$phi1123Z2D))|0;
     HEAP32[$169>>2] = $171;
     $173 = $171;
    } else {
     $$pre1117 = HEAP32[$0>>2]|0;
     $$phi$trans$insert = (($$pre1117) + 756|0);
     $$pre1118 = HEAP32[$$phi$trans$insert>>2]|0;
     $173 = $$pre1118;
    }
    $172 = (($173) + 7)|0;
    $174 = $172 >> 3;
    $175 = (($ip$2$ph) + ($174)|0);
    $176 = ($175>>>0)<($limit$0$ph>>>0);
    if (!($176)) {
     $$0 = 3;
     label = 398;
     break L5;
    }
    do {
     if ($33) {
      $177 = ($op$0$ph|0)==(23);
      if ($177) {
       $178 = HEAP32[$40>>2]|0;
       $179 = HEAP32[$$pre$phi1128Z2D>>2]|0;
       $180 = HEAP32[$41>>2]|0;
       $181 = (($180) + 2|0);
       $182 = HEAP16[$181>>1]|0;
       $183 = $182 << 16 >> 16;
       FUNCTION_TABLE_viiii[$178 & 511]($179,$183,$173,$ip$2$ph);
       break;
      } else {
       $184 = HEAP32[$42>>2]|0;
       $185 = HEAP32[$$pre$phi1128Z2D>>2]|0;
       FUNCTION_TABLE_viii[$184 & 4095]($185,$173,$ip$2$ph);
       break;
      }
     }
    } while(0);
    $186 = HEAP32[$0>>2]|0;
    $187 = (($186) + 756|0);
    $188 = HEAP32[$187>>2]|0;
    $189 = (($188) + 7)|0;
    $190 = $189 >> 3;
    $191 = (($ip$2$ph) + ($190)|0);
    $args$12 = $19;$ip$3 = $191;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 2:  {
    $$idx104$val = HEAP32[$41>>2]|0;
    _cff_builder_close_contour($$idx104$val);
    HEAP8[$25>>0] = 0;
    $req_args$0$not85 = $req_args$0 | -16;
    $$sum84 = $req_args$0$not85 ^ 15;
    $201 = (($110) + ($$sum84<<2)|0);
    $202 = HEAP32[$201>>2]|0;
    $203 = (($202) + ($x$0$ph))|0;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $203;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   case 9: case 12:  {
    $602 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $603 = ($602|0)==(0);
    if (!($603)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $604 = ($149|0)<(4);
    if ($604) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $605 = (($149|0) % 4)&-1;
    $606 = (($149) - ($605))|0;
    $607 = ($605|0)>(0);
    $608 = $607&1;
    $$100 = (($608) + ($606))|0;
    $609 = (($$100|0) / 4)&-1;
    $610 = ($609*3)|0;
    $$100$off = (($$100) + 3)|0;
    $611 = ($$100$off>>>0)<(7);
    if ($611) {
     $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    } else {
     $612 = HEAP32[$43>>2]|0;
     $613 = (($612) + 22|0);
     $614 = HEAP16[$613>>1]|0;
     $615 = $614 << 16 >> 16;
     $616 = (($612) + 58|0);
     $617 = HEAP16[$616>>1]|0;
     $618 = $617 << 16 >> 16;
     $619 = (($615) + ($610))|0;
     $620 = (($619) + ($618))|0;
     $621 = (($612) + 4|0);
     $622 = HEAP32[$621>>2]|0;
     $623 = ($620>>>0)>($622>>>0);
     if ($623) {
      $624 = (_FT_GlyphLoader_CheckPoints($612,$610,0)|0);
      $625 = ($624|0)==(0);
      if (!($625)) {
       $$0 = 129;
       label = 398;
       break L5;
      }
     }
     $626 = ($$100|0)>(3);
     if ($626) {
      $sum73 = (($145) + ($$100))|0;
      $627 = ($op$0$ph|0)==(9);
      $$sum72 = (0 - ($sum73))|0;
      $628 = $627&1;
      $629 = (($110) + ($$sum72<<2)|0);
      $args$7420 = $629;$nargs4$1418 = $$100;$phase3$0419 = $628;$x$8423 = $x$0$ph;$y$8422 = $y$0$ph;
      while(1) {
       $630 = (($nargs4$1418) + -4)|0;
       $631 = ($phase3$0419|0)==(0);
       $632 = HEAP32[$args$7420>>2]|0;
       if ($631) {
        $692 = (($632) + ($y$8422))|0;
        $$idx157$val = HEAP32[$41>>2]|0;
        $$idx158$val = HEAP8[$$idx184>>0]|0;
        $693 = ($$idx158$val<<24>>24)==(0);
        if ($693) {
         $$pre$i238 = (($$idx157$val) + 2|0);
         $$idx155$val = $$idx157$val;$$pre$phi$i240Z2D = $$pre$i238;
        } else {
         $694 = (($$idx157$val) + 4|0);
         $695 = HEAP32[$694>>2]|0;
         $696 = (($$idx157$val) + 2|0);
         $697 = HEAP16[$696>>1]|0;
         $698 = $697 << 16 >> 16;
         $699 = (($$idx157$val) + 8|0);
         $700 = HEAP32[$699>>2]|0;
         $701 = (($700) + ($698)|0);
         $702 = $x$8423 >> 16;
         $703 = (($695) + ($698<<3)|0);
         HEAP32[$703>>2] = $702;
         $704 = $692 >> 16;
         $705 = ((($695) + ($698<<3)|0) + 4|0);
         HEAP32[$705>>2] = $704;
         HEAP8[$701>>0] = 2;
         $$idx155$val$pre = HEAP32[$41>>2]|0;
         $$idx155$val = $$idx155$val$pre;$$pre$phi$i240Z2D = $696;
        }
        $706 = HEAP16[$$pre$phi$i240Z2D>>1]|0;
        $707 = (($706) + 1)<<16>>16;
        HEAP16[$$pre$phi$i240Z2D>>1] = $707;
        $708 = (($args$7420) + 4|0);
        $709 = HEAP32[$708>>2]|0;
        $710 = (($709) + ($x$8423))|0;
        $711 = (($args$7420) + 8|0);
        $712 = HEAP32[$711>>2]|0;
        $713 = (($712) + ($692))|0;
        $$idx156$val = HEAP8[$$idx184>>0]|0;
        $714 = ($$idx156$val<<24>>24)==(0);
        if ($714) {
         $$pre$i242 = (($$idx155$val) + 2|0);
         $$pre$phi$i244Z2D = $$pre$i242;
        } else {
         $715 = (($$idx155$val) + 4|0);
         $716 = HEAP32[$715>>2]|0;
         $717 = (($$idx155$val) + 2|0);
         $718 = HEAP16[$717>>1]|0;
         $719 = $718 << 16 >> 16;
         $720 = (($$idx155$val) + 8|0);
         $721 = HEAP32[$720>>2]|0;
         $722 = (($721) + ($719)|0);
         $723 = $710 >> 16;
         $724 = (($716) + ($719<<3)|0);
         HEAP32[$724>>2] = $723;
         $725 = $713 >> 16;
         $726 = ((($716) + ($719<<3)|0) + 4|0);
         HEAP32[$726>>2] = $725;
         HEAP8[$722>>0] = 2;
         $$pre$phi$i244Z2D = $717;
        }
        $727 = HEAP16[$$pre$phi$i244Z2D>>1]|0;
        $728 = (($727) + 1)<<16>>16;
        HEAP16[$$pre$phi$i244Z2D>>1] = $728;
        $729 = (($args$7420) + 12|0);
        $730 = HEAP32[$729>>2]|0;
        $731 = (($730) + ($710))|0;
        $732 = ($630|0)==(1);
        if ($732) {
         $733 = (($args$7420) + 16|0);
         $734 = HEAP32[$733>>2]|0;
         $735 = (($734) + ($713))|0;
         $y$9 = $735;
        } else {
         $y$9 = $713;
        }
        $$idx153$val = HEAP32[$41>>2]|0;
        $$idx154$val = HEAP8[$$idx184>>0]|0;
        $736 = ($$idx154$val<<24>>24)==(0);
        if ($736) {
         $$pre$i246 = (($$idx153$val) + 2|0);
         $$pre$phi$i248Z2D = $$pre$i246;
        } else {
         $737 = (($$idx153$val) + 4|0);
         $738 = HEAP32[$737>>2]|0;
         $739 = (($$idx153$val) + 2|0);
         $740 = HEAP16[$739>>1]|0;
         $741 = $740 << 16 >> 16;
         $742 = (($$idx153$val) + 8|0);
         $743 = HEAP32[$742>>2]|0;
         $744 = (($743) + ($741)|0);
         $745 = $731 >> 16;
         $746 = (($738) + ($741<<3)|0);
         HEAP32[$746>>2] = $745;
         $747 = $y$9 >> 16;
         $748 = ((($738) + ($741<<3)|0) + 4|0);
         HEAP32[$748>>2] = $747;
         HEAP8[$744>>0] = 1;
         $$pre$phi$i248Z2D = $739;
        }
        $749 = HEAP16[$$pre$phi$i248Z2D>>1]|0;
        $750 = (($749) + 1)<<16>>16;
        HEAP16[$$pre$phi$i248Z2D>>1] = $750;
        $x$10 = $731;$y$10 = $y$9;
       } else {
        $633 = (($632) + ($x$8423))|0;
        $$idx163$val = HEAP32[$41>>2]|0;
        $$idx164$val = HEAP8[$$idx184>>0]|0;
        $634 = ($$idx164$val<<24>>24)==(0);
        if ($634) {
         $$pre$i226 = (($$idx163$val) + 2|0);
         $$idx161$val = $$idx163$val;$$pre$phi$i228Z2D = $$pre$i226;
        } else {
         $635 = (($$idx163$val) + 4|0);
         $636 = HEAP32[$635>>2]|0;
         $637 = (($$idx163$val) + 2|0);
         $638 = HEAP16[$637>>1]|0;
         $639 = $638 << 16 >> 16;
         $640 = (($$idx163$val) + 8|0);
         $641 = HEAP32[$640>>2]|0;
         $642 = (($641) + ($639)|0);
         $643 = $633 >> 16;
         $644 = (($636) + ($639<<3)|0);
         HEAP32[$644>>2] = $643;
         $645 = $y$8422 >> 16;
         $646 = ((($636) + ($639<<3)|0) + 4|0);
         HEAP32[$646>>2] = $645;
         HEAP8[$642>>0] = 2;
         $$idx161$val$pre = HEAP32[$41>>2]|0;
         $$idx161$val = $$idx161$val$pre;$$pre$phi$i228Z2D = $637;
        }
        $647 = HEAP16[$$pre$phi$i228Z2D>>1]|0;
        $648 = (($647) + 1)<<16>>16;
        HEAP16[$$pre$phi$i228Z2D>>1] = $648;
        $649 = (($args$7420) + 4|0);
        $650 = HEAP32[$649>>2]|0;
        $651 = (($650) + ($633))|0;
        $652 = (($args$7420) + 8|0);
        $653 = HEAP32[$652>>2]|0;
        $654 = (($653) + ($y$8422))|0;
        $$idx162$val = HEAP8[$$idx184>>0]|0;
        $655 = ($$idx162$val<<24>>24)==(0);
        if ($655) {
         $$pre$i230 = (($$idx161$val) + 2|0);
         $$pre$phi$i232Z2D = $$pre$i230;
        } else {
         $656 = (($$idx161$val) + 4|0);
         $657 = HEAP32[$656>>2]|0;
         $658 = (($$idx161$val) + 2|0);
         $659 = HEAP16[$658>>1]|0;
         $660 = $659 << 16 >> 16;
         $661 = (($$idx161$val) + 8|0);
         $662 = HEAP32[$661>>2]|0;
         $663 = (($662) + ($660)|0);
         $664 = $651 >> 16;
         $665 = (($657) + ($660<<3)|0);
         HEAP32[$665>>2] = $664;
         $666 = $654 >> 16;
         $667 = ((($657) + ($660<<3)|0) + 4|0);
         HEAP32[$667>>2] = $666;
         HEAP8[$663>>0] = 2;
         $$pre$phi$i232Z2D = $658;
        }
        $668 = HEAP16[$$pre$phi$i232Z2D>>1]|0;
        $669 = (($668) + 1)<<16>>16;
        HEAP16[$$pre$phi$i232Z2D>>1] = $669;
        $670 = (($args$7420) + 12|0);
        $671 = HEAP32[$670>>2]|0;
        $672 = (($671) + ($654))|0;
        $673 = ($630|0)==(1);
        if ($673) {
         $674 = (($args$7420) + 16|0);
         $675 = HEAP32[$674>>2]|0;
         $676 = (($675) + ($651))|0;
         $x$9 = $676;
        } else {
         $x$9 = $651;
        }
        $$idx159$val = HEAP32[$41>>2]|0;
        $$idx160$val = HEAP8[$$idx184>>0]|0;
        $677 = ($$idx160$val<<24>>24)==(0);
        if ($677) {
         $$pre$i234 = (($$idx159$val) + 2|0);
         $$pre$phi$i236Z2D = $$pre$i234;
        } else {
         $678 = (($$idx159$val) + 4|0);
         $679 = HEAP32[$678>>2]|0;
         $680 = (($$idx159$val) + 2|0);
         $681 = HEAP16[$680>>1]|0;
         $682 = $681 << 16 >> 16;
         $683 = (($$idx159$val) + 8|0);
         $684 = HEAP32[$683>>2]|0;
         $685 = (($684) + ($682)|0);
         $686 = $x$9 >> 16;
         $687 = (($679) + ($682<<3)|0);
         HEAP32[$687>>2] = $686;
         $688 = $672 >> 16;
         $689 = ((($679) + ($682<<3)|0) + 4|0);
         HEAP32[$689>>2] = $688;
         HEAP8[$685>>0] = 1;
         $$pre$phi$i236Z2D = $680;
        }
        $690 = HEAP16[$$pre$phi$i236Z2D>>1]|0;
        $691 = (($690) + 1)<<16>>16;
        HEAP16[$$pre$phi$i236Z2D>>1] = $691;
        $x$10 = $x$9;$y$10 = $672;
       }
       $751 = ($630|0)>(3);
       if (!($751)) {
        $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$10;$y$16 = $y$10;$zone$1 = $zone$0$ph;
        break L107;
       }
       $752 = $phase3$0419 ^ 1;
       $753 = (($args$7420) + 16|0);
       $args$7420 = $753;$nargs4$1418 = $630;$phase3$0419 = $752;$x$8423 = $x$10;$y$8422 = $y$10;
      }
     } else {
      $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
     }
    }
    break;
   }
   case 13:  {
    $410 = ($149|0)<(4);
    if ($410) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $411 = (($149|0) % 4)&-1;
    $412 = (($149) - ($411))|0;
    $413 = ($411|0)>(0);
    $414 = $413&1;
    $$98 = (($414) + ($412))|0;
    $415 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $416 = ($415|0)==(0);
    if (!($416)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $sum78 = (($$98) + ($145))|0;
    $$sum77 = (0 - ($sum78))|0;
    $417 = (($110) + ($$sum77<<2)|0);
    $418 = $$98 & 1;
    $419 = ($418|0)==(0);
    if ($419) {
     $args$3 = $417;$nargs1$1 = $$98;$x$5 = $x$0$ph;
    } else {
     $420 = HEAP32[$417>>2]|0;
     $421 = (($420) + ($x$0$ph))|0;
     $$sum79 = (1 - ($sum78))|0;
     $422 = (($110) + ($$sum79<<2)|0);
     $423 = (($$98) + -1)|0;
     $args$3 = $422;$nargs1$1 = $423;$x$5 = $421;
    }
    $424 = (($nargs1$1|0) / 4)&-1;
    $425 = ($424*3)|0;
    $nargs1$1$off = (($nargs1$1) + 3)|0;
    $426 = ($nargs1$1$off>>>0)<(7);
    if (!($426)) {
     $427 = HEAP32[$43>>2]|0;
     $428 = (($427) + 22|0);
     $429 = HEAP16[$428>>1]|0;
     $430 = $429 << 16 >> 16;
     $431 = (($427) + 58|0);
     $432 = HEAP16[$431>>1]|0;
     $433 = $432 << 16 >> 16;
     $434 = (($430) + ($425))|0;
     $435 = (($434) + ($433))|0;
     $436 = (($427) + 4|0);
     $437 = HEAP32[$436>>2]|0;
     $438 = ($435>>>0)>($437>>>0);
     if ($438) {
      $439 = (_FT_GlyphLoader_CheckPoints($427,$425,0)|0);
      $440 = ($439|0)==(0);
      if (!($440)) {
       $$0 = 0;
       label = 398;
       break L5;
      }
     }
    }
    $441 = HEAP32[$0>>2]|0;
    $442 = (($441) + 276|0);
    $443 = HEAP32[$442>>2]|0;
    $444 = ($args$3>>>0)<($443>>>0);
    if ($444) {
     $args$4435 = $args$3;$x$6437 = $x$5;$y$5436 = $y$0$ph;
     while(1) {
      $445 = HEAP32[$args$4435>>2]|0;
      $446 = (($445) + ($y$5436))|0;
      $$idx175$val = HEAP32[$41>>2]|0;
      $$idx176$val = HEAP8[$$idx184>>0]|0;
      $447 = ($$idx176$val<<24>>24)==(0);
      if ($447) {
       $$pre$i200 = (($$idx175$val) + 2|0);
       $$idx173$val = $$idx175$val;$$pre$phi$i202Z2D = $$pre$i200;
      } else {
       $448 = (($$idx175$val) + 4|0);
       $449 = HEAP32[$448>>2]|0;
       $450 = (($$idx175$val) + 2|0);
       $451 = HEAP16[$450>>1]|0;
       $452 = $451 << 16 >> 16;
       $453 = (($$idx175$val) + 8|0);
       $454 = HEAP32[$453>>2]|0;
       $455 = (($454) + ($452)|0);
       $456 = $x$6437 >> 16;
       $457 = (($449) + ($452<<3)|0);
       HEAP32[$457>>2] = $456;
       $458 = $446 >> 16;
       $459 = ((($449) + ($452<<3)|0) + 4|0);
       HEAP32[$459>>2] = $458;
       HEAP8[$455>>0] = 2;
       $$idx173$val$pre = HEAP32[$41>>2]|0;
       $$idx173$val = $$idx173$val$pre;$$pre$phi$i202Z2D = $450;
      }
      $460 = HEAP16[$$pre$phi$i202Z2D>>1]|0;
      $461 = (($460) + 1)<<16>>16;
      HEAP16[$$pre$phi$i202Z2D>>1] = $461;
      $462 = (($args$4435) + 4|0);
      $463 = HEAP32[$462>>2]|0;
      $464 = (($463) + ($x$6437))|0;
      $465 = (($args$4435) + 8|0);
      $466 = HEAP32[$465>>2]|0;
      $467 = (($466) + ($446))|0;
      $$idx174$val = HEAP8[$$idx184>>0]|0;
      $468 = ($$idx174$val<<24>>24)==(0);
      if ($468) {
       $$pre$i204 = (($$idx173$val) + 2|0);
       $$idx171$val = $$idx173$val;$$pre$phi$i206Z2D = $$pre$i204;
      } else {
       $469 = (($$idx173$val) + 4|0);
       $470 = HEAP32[$469>>2]|0;
       $471 = (($$idx173$val) + 2|0);
       $472 = HEAP16[$471>>1]|0;
       $473 = $472 << 16 >> 16;
       $474 = (($$idx173$val) + 8|0);
       $475 = HEAP32[$474>>2]|0;
       $476 = (($475) + ($473)|0);
       $477 = $464 >> 16;
       $478 = (($470) + ($473<<3)|0);
       HEAP32[$478>>2] = $477;
       $479 = $467 >> 16;
       $480 = ((($470) + ($473<<3)|0) + 4|0);
       HEAP32[$480>>2] = $479;
       HEAP8[$476>>0] = 2;
       $$idx171$val$pre = HEAP32[$41>>2]|0;
       $$idx171$val = $$idx171$val$pre;$$pre$phi$i206Z2D = $471;
      }
      $481 = HEAP16[$$pre$phi$i206Z2D>>1]|0;
      $482 = (($481) + 1)<<16>>16;
      HEAP16[$$pre$phi$i206Z2D>>1] = $482;
      $483 = (($args$4435) + 12|0);
      $484 = HEAP32[$483>>2]|0;
      $485 = (($484) + ($467))|0;
      $$idx172$val = HEAP8[$$idx184>>0]|0;
      $486 = ($$idx172$val<<24>>24)==(0);
      if ($486) {
       $$pre$i208 = (($$idx171$val) + 2|0);
       $$pre$phi$i210Z2D = $$pre$i208;
      } else {
       $487 = (($$idx171$val) + 4|0);
       $488 = HEAP32[$487>>2]|0;
       $489 = (($$idx171$val) + 2|0);
       $490 = HEAP16[$489>>1]|0;
       $491 = $490 << 16 >> 16;
       $492 = (($$idx171$val) + 8|0);
       $493 = HEAP32[$492>>2]|0;
       $494 = (($493) + ($491)|0);
       $495 = $464 >> 16;
       $496 = (($488) + ($491<<3)|0);
       HEAP32[$496>>2] = $495;
       $497 = $485 >> 16;
       $498 = ((($488) + ($491<<3)|0) + 4|0);
       HEAP32[$498>>2] = $497;
       HEAP8[$494>>0] = 1;
       $$pre$phi$i210Z2D = $489;
      }
      $499 = HEAP16[$$pre$phi$i210Z2D>>1]|0;
      $500 = (($499) + 1)<<16>>16;
      HEAP16[$$pre$phi$i210Z2D>>1] = $500;
      $501 = (($args$4435) + 16|0);
      $502 = HEAP32[$0>>2]|0;
      $503 = (($502) + 276|0);
      $504 = HEAP32[$503>>2]|0;
      $505 = ($501>>>0)<($504>>>0);
      if ($505) {
       $args$4435 = $501;$x$6437 = $464;$y$5436 = $485;
      } else {
       $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $464;$y$16 = $485;$zone$1 = $zone$0$ph;
       break;
      }
     }
    } else {
     $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$5;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    }
    break;
   }
   case 8:  {
    $506 = ($149|0)<(4);
    if ($506) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $507 = (($149|0) % 4)&-1;
    $508 = (($149) - ($507))|0;
    $509 = ($507|0)>(0);
    $510 = $509&1;
    $$99 = (($510) + ($508))|0;
    $511 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $512 = ($511|0)==(0);
    if (!($512)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $sum75 = (($$99) + ($145))|0;
    $$sum74 = (0 - ($sum75))|0;
    $513 = (($110) + ($$sum74<<2)|0);
    $514 = $$99 & 1;
    $515 = ($514|0)==(0);
    if ($515) {
     $args$5 = $513;$nargs2$1 = $$99;$y$6 = $y$0$ph;
    } else {
     $516 = HEAP32[$513>>2]|0;
     $517 = (($516) + ($y$0$ph))|0;
     $$sum76 = (1 - ($sum75))|0;
     $518 = (($110) + ($$sum76<<2)|0);
     $519 = (($$99) + -1)|0;
     $args$5 = $518;$nargs2$1 = $519;$y$6 = $517;
    }
    $520 = (($nargs2$1|0) / 4)&-1;
    $521 = ($520*3)|0;
    $nargs2$1$off = (($nargs2$1) + 3)|0;
    $522 = ($nargs2$1$off>>>0)<(7);
    if (!($522)) {
     $523 = HEAP32[$43>>2]|0;
     $524 = (($523) + 22|0);
     $525 = HEAP16[$524>>1]|0;
     $526 = $525 << 16 >> 16;
     $527 = (($523) + 58|0);
     $528 = HEAP16[$527>>1]|0;
     $529 = $528 << 16 >> 16;
     $530 = (($526) + ($521))|0;
     $531 = (($530) + ($529))|0;
     $532 = (($523) + 4|0);
     $533 = HEAP32[$532>>2]|0;
     $534 = ($531>>>0)>($533>>>0);
     if ($534) {
      $535 = (_FT_GlyphLoader_CheckPoints($523,$521,0)|0);
      $536 = ($535|0)==(0);
      if (!($536)) {
       $$0 = 0;
       label = 398;
       break L5;
      }
     }
    }
    $537 = HEAP32[$0>>2]|0;
    $538 = (($537) + 276|0);
    $539 = HEAP32[$538>>2]|0;
    $540 = ($args$5>>>0)<($539>>>0);
    if ($540) {
     $args$6428 = $args$5;$x$7430 = $x$0$ph;$y$7429 = $y$6;
     while(1) {
      $541 = HEAP32[$args$6428>>2]|0;
      $542 = (($541) + ($x$7430))|0;
      $$idx169$val = HEAP32[$41>>2]|0;
      $$idx170$val = HEAP8[$$idx184>>0]|0;
      $543 = ($$idx170$val<<24>>24)==(0);
      if ($543) {
       $$pre$i213 = (($$idx169$val) + 2|0);
       $$idx167$val = $$idx169$val;$$pre$phi$i215Z2D = $$pre$i213;
      } else {
       $544 = (($$idx169$val) + 4|0);
       $545 = HEAP32[$544>>2]|0;
       $546 = (($$idx169$val) + 2|0);
       $547 = HEAP16[$546>>1]|0;
       $548 = $547 << 16 >> 16;
       $549 = (($$idx169$val) + 8|0);
       $550 = HEAP32[$549>>2]|0;
       $551 = (($550) + ($548)|0);
       $552 = $542 >> 16;
       $553 = (($545) + ($548<<3)|0);
       HEAP32[$553>>2] = $552;
       $554 = $y$7429 >> 16;
       $555 = ((($545) + ($548<<3)|0) + 4|0);
       HEAP32[$555>>2] = $554;
       HEAP8[$551>>0] = 2;
       $$idx167$val$pre = HEAP32[$41>>2]|0;
       $$idx167$val = $$idx167$val$pre;$$pre$phi$i215Z2D = $546;
      }
      $556 = HEAP16[$$pre$phi$i215Z2D>>1]|0;
      $557 = (($556) + 1)<<16>>16;
      HEAP16[$$pre$phi$i215Z2D>>1] = $557;
      $558 = (($args$6428) + 4|0);
      $559 = HEAP32[$558>>2]|0;
      $560 = (($559) + ($542))|0;
      $561 = (($args$6428) + 8|0);
      $562 = HEAP32[$561>>2]|0;
      $563 = (($562) + ($y$7429))|0;
      $$idx168$val = HEAP8[$$idx184>>0]|0;
      $564 = ($$idx168$val<<24>>24)==(0);
      if ($564) {
       $$pre$i217 = (($$idx167$val) + 2|0);
       $$idx165$val = $$idx167$val;$$pre$phi$i219Z2D = $$pre$i217;
      } else {
       $565 = (($$idx167$val) + 4|0);
       $566 = HEAP32[$565>>2]|0;
       $567 = (($$idx167$val) + 2|0);
       $568 = HEAP16[$567>>1]|0;
       $569 = $568 << 16 >> 16;
       $570 = (($$idx167$val) + 8|0);
       $571 = HEAP32[$570>>2]|0;
       $572 = (($571) + ($569)|0);
       $573 = $560 >> 16;
       $574 = (($566) + ($569<<3)|0);
       HEAP32[$574>>2] = $573;
       $575 = $563 >> 16;
       $576 = ((($566) + ($569<<3)|0) + 4|0);
       HEAP32[$576>>2] = $575;
       HEAP8[$572>>0] = 2;
       $$idx165$val$pre = HEAP32[$41>>2]|0;
       $$idx165$val = $$idx165$val$pre;$$pre$phi$i219Z2D = $567;
      }
      $577 = HEAP16[$$pre$phi$i219Z2D>>1]|0;
      $578 = (($577) + 1)<<16>>16;
      HEAP16[$$pre$phi$i219Z2D>>1] = $578;
      $579 = (($args$6428) + 12|0);
      $580 = HEAP32[$579>>2]|0;
      $581 = (($580) + ($560))|0;
      $$idx166$val = HEAP8[$$idx184>>0]|0;
      $582 = ($$idx166$val<<24>>24)==(0);
      if ($582) {
       $$pre$i221 = (($$idx165$val) + 2|0);
       $$pre$phi$i223Z2D = $$pre$i221;
      } else {
       $583 = (($$idx165$val) + 4|0);
       $584 = HEAP32[$583>>2]|0;
       $585 = (($$idx165$val) + 2|0);
       $586 = HEAP16[$585>>1]|0;
       $587 = $586 << 16 >> 16;
       $588 = (($$idx165$val) + 8|0);
       $589 = HEAP32[$588>>2]|0;
       $590 = (($589) + ($587)|0);
       $591 = $581 >> 16;
       $592 = (($584) + ($587<<3)|0);
       HEAP32[$592>>2] = $591;
       $593 = $563 >> 16;
       $594 = ((($584) + ($587<<3)|0) + 4|0);
       HEAP32[$594>>2] = $593;
       HEAP8[$590>>0] = 1;
       $$pre$phi$i223Z2D = $585;
      }
      $595 = HEAP16[$$pre$phi$i223Z2D>>1]|0;
      $596 = (($595) + 1)<<16>>16;
      HEAP16[$$pre$phi$i223Z2D>>1] = $596;
      $597 = (($args$6428) + 16|0);
      $598 = HEAP32[$0>>2]|0;
      $599 = (($598) + 276|0);
      $600 = HEAP32[$599>>2]|0;
      $601 = ($597>>>0)<($600>>>0);
      if ($601) {
       $args$6428 = $597;$x$7430 = $581;$y$7429 = $563;
      } else {
       $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $581;$y$16 = $563;$zone$1 = $zone$0$ph;
       break;
      }
     }
    } else {
     $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $x$0$ph;$y$16 = $y$6;$zone$1 = $zone$0$ph;
    }
    break;
   }
   case 11:  {
    $754 = ($149|0)<(8);
    if ($754) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $755 = $149 & -2;
    $756 = (($755) + -6)|0;
    $757 = (($756|0) / 2)&-1;
    $758 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $759 = ($758|0)==(0);
    if (!($759)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $760 = (($757) + 3)|0;
    $761 = ($760|0)==(0);
    if (!($761)) {
     $762 = HEAP32[$43>>2]|0;
     $763 = (($762) + 22|0);
     $764 = HEAP16[$763>>1]|0;
     $765 = $764 << 16 >> 16;
     $766 = (($762) + 58|0);
     $767 = HEAP16[$766>>1]|0;
     $768 = $767 << 16 >> 16;
     $769 = (($765) + ($760))|0;
     $770 = (($769) + ($768))|0;
     $771 = (($762) + 4|0);
     $772 = HEAP32[$771>>2]|0;
     $773 = ($770>>>0)>($772>>>0);
     if ($773) {
      $774 = (_FT_GlyphLoader_CheckPoints($762,$760,0)|0);
      $775 = ($774|0)==(0);
      if (!($775)) {
       $$0 = 0;
       label = 398;
       break L5;
      }
     }
    }
    $sum71 = (($145) + ($755))|0;
    $$sum70 = (0 - ($sum71))|0;
    $776 = (($110) + ($$sum70<<2)|0);
    $777 = ($756|0)>(1);
    $778 = HEAP32[$776>>2]|0;
    $779 = (($778) + ($x$0$ph))|0;
    $$sum758 = (1 - ($sum71))|0;
    $780 = (($110) + ($$sum758<<2)|0);
    $781 = HEAP32[$780>>2]|0;
    $782 = (($781) + ($y$0$ph))|0;
    $$idx151$val403 = HEAP32[$41>>2]|0;
    $$idx152$val404 = HEAP8[$$idx184>>0]|0;
    $783 = ($$idx152$val404<<24>>24)==(0);
    if ($777) {
     $784 = (0 - ($757))|0;
     $785 = ($784|0)>(-1);
     $smax = $785 ? $784 : 2147483647;
     $786 = (($757) + ($smax))|0;
     $787 = $786 << 1;
     $788 = $req_args$0 & 15;
     $789 = (($755) + ($788))|0;
     $790 = (($787) - ($789))|0;
     $$idx151$val407 = $$idx151$val403;$1775 = $783;$800 = $779;$803 = $782;$args$8406 = $776;$num_lines$0405 = $757;
     while(1) {
      if ($1775) {
       $$pre$i251 = (($$idx151$val407) + 2|0);
       $$idx151$val = $$idx151$val407;$$pre$phi$i253Z2D = $$pre$i251;
      } else {
       $791 = (($$idx151$val407) + 4|0);
       $792 = HEAP32[$791>>2]|0;
       $793 = (($$idx151$val407) + 2|0);
       $794 = HEAP16[$793>>1]|0;
       $795 = $794 << 16 >> 16;
       $796 = (($$idx151$val407) + 8|0);
       $797 = HEAP32[$796>>2]|0;
       $798 = (($797) + ($795)|0);
       $799 = $800 >> 16;
       $801 = (($792) + ($795<<3)|0);
       HEAP32[$801>>2] = $799;
       $802 = $803 >> 16;
       $804 = ((($792) + ($795<<3)|0) + 4|0);
       HEAP32[$804>>2] = $802;
       HEAP8[$798>>0] = 1;
       $$idx151$val$pre = HEAP32[$41>>2]|0;
       $$idx151$val = $$idx151$val$pre;$$pre$phi$i253Z2D = $793;
      }
      $805 = HEAP16[$$pre$phi$i253Z2D>>1]|0;
      $806 = (($805) + 1)<<16>>16;
      HEAP16[$$pre$phi$i253Z2D>>1] = $806;
      $807 = (($args$8406) + 8|0);
      $808 = (($num_lines$0405) + -1)|0;
      $809 = ($808|0)>(0);
      $810 = HEAP32[$807>>2]|0;
      $811 = (($810) + ($800))|0;
      $812 = (($args$8406) + 12|0);
      $813 = HEAP32[$812>>2]|0;
      $814 = (($813) + ($803))|0;
      $$idx152$val = HEAP8[$$idx184>>0]|0;
      $815 = ($$idx152$val<<24>>24)==(0);
      if ($809) {
       $$idx151$val407 = $$idx151$val;$1775 = $815;$800 = $811;$803 = $814;$args$8406 = $807;$num_lines$0405 = $808;
      } else {
       break;
      }
     }
     $scevgep$sum = (($790) + 2)|0;
     $scevgep1047 = (($110) + ($scevgep$sum<<2)|0);
     if ($815) {
      $$idx151$val$lcssa1148 = $$idx151$val;$$lcssa4001154 = $811;$$lcssa4011151 = $814;$args$8$lcssa1157 = $scevgep1047;
      label = 237;
     } else {
      $$idx151$val$lcssa1147 = $$idx151$val;$$lcssa4001153 = $811;$$lcssa4011150 = $814;$args$8$lcssa1156 = $scevgep1047;
      label = 238;
     }
    } else {
     if ($783) {
      $$idx151$val$lcssa1148 = $$idx151$val403;$$lcssa4001154 = $779;$$lcssa4011151 = $782;$args$8$lcssa1157 = $776;
      label = 237;
     } else {
      $$idx151$val$lcssa1147 = $$idx151$val403;$$lcssa4001153 = $779;$$lcssa4011150 = $782;$args$8$lcssa1156 = $776;
      label = 238;
     }
    }
    if ((label|0) == 237) {
     label = 0;
     $$pre$i255 = (($$idx151$val$lcssa1148) + 2|0);
     $$idx147$val = $$idx151$val$lcssa1148;$$lcssa4001152 = $$lcssa4001154;$$lcssa4011149 = $$lcssa4011151;$$pre$phi$i257Z2D = $$pre$i255;$args$8$lcssa1155 = $args$8$lcssa1157;
    }
    else if ((label|0) == 238) {
     label = 0;
     $816 = (($$idx151$val$lcssa1147) + 4|0);
     $817 = HEAP32[$816>>2]|0;
     $818 = (($$idx151$val$lcssa1147) + 2|0);
     $819 = HEAP16[$818>>1]|0;
     $820 = $819 << 16 >> 16;
     $821 = (($$idx151$val$lcssa1147) + 8|0);
     $822 = HEAP32[$821>>2]|0;
     $823 = (($822) + ($820)|0);
     $824 = $$lcssa4001153 >> 16;
     $825 = (($817) + ($820<<3)|0);
     HEAP32[$825>>2] = $824;
     $826 = $$lcssa4011150 >> 16;
     $827 = ((($817) + ($820<<3)|0) + 4|0);
     HEAP32[$827>>2] = $826;
     HEAP8[$823>>0] = 2;
     $$idx147$val$pre = HEAP32[$41>>2]|0;
     $$idx147$val = $$idx147$val$pre;$$lcssa4001152 = $$lcssa4001153;$$lcssa4011149 = $$lcssa4011150;$$pre$phi$i257Z2D = $818;$args$8$lcssa1155 = $args$8$lcssa1156;
    }
    $828 = HEAP16[$$pre$phi$i257Z2D>>1]|0;
    $829 = (($828) + 1)<<16>>16;
    HEAP16[$$pre$phi$i257Z2D>>1] = $829;
    $830 = (($args$8$lcssa1155) + 8|0);
    $831 = HEAP32[$830>>2]|0;
    $832 = (($831) + ($$lcssa4001152))|0;
    $833 = (($args$8$lcssa1155) + 12|0);
    $834 = HEAP32[$833>>2]|0;
    $835 = (($834) + ($$lcssa4011149))|0;
    $$idx148$val = HEAP8[$$idx184>>0]|0;
    $836 = ($$idx148$val<<24>>24)==(0);
    if ($836) {
     $$pre$i259 = (($$idx147$val) + 2|0);
     $$idx145$val = $$idx147$val;$$pre$phi$i261Z2D = $$pre$i259;
    } else {
     $837 = (($$idx147$val) + 4|0);
     $838 = HEAP32[$837>>2]|0;
     $839 = (($$idx147$val) + 2|0);
     $840 = HEAP16[$839>>1]|0;
     $841 = $840 << 16 >> 16;
     $842 = (($$idx147$val) + 8|0);
     $843 = HEAP32[$842>>2]|0;
     $844 = (($843) + ($841)|0);
     $845 = $832 >> 16;
     $846 = (($838) + ($841<<3)|0);
     HEAP32[$846>>2] = $845;
     $847 = $835 >> 16;
     $848 = ((($838) + ($841<<3)|0) + 4|0);
     HEAP32[$848>>2] = $847;
     HEAP8[$844>>0] = 2;
     $$idx145$val$pre = HEAP32[$41>>2]|0;
     $$idx145$val = $$idx145$val$pre;$$pre$phi$i261Z2D = $839;
    }
    $849 = HEAP16[$$pre$phi$i261Z2D>>1]|0;
    $850 = (($849) + 1)<<16>>16;
    HEAP16[$$pre$phi$i261Z2D>>1] = $850;
    $851 = (($args$8$lcssa1155) + 16|0);
    $852 = HEAP32[$851>>2]|0;
    $853 = (($852) + ($832))|0;
    $854 = (($args$8$lcssa1155) + 20|0);
    $855 = HEAP32[$854>>2]|0;
    $856 = (($855) + ($835))|0;
    $$idx146$val = HEAP8[$$idx184>>0]|0;
    $857 = ($$idx146$val<<24>>24)==(0);
    if ($857) {
     $$pre$i263 = (($$idx145$val) + 2|0);
     $$pre$phi$i265Z2D = $$pre$i263;
    } else {
     $858 = (($$idx145$val) + 4|0);
     $859 = HEAP32[$858>>2]|0;
     $860 = (($$idx145$val) + 2|0);
     $861 = HEAP16[$860>>1]|0;
     $862 = $861 << 16 >> 16;
     $863 = (($$idx145$val) + 8|0);
     $864 = HEAP32[$863>>2]|0;
     $865 = (($864) + ($862)|0);
     $866 = $853 >> 16;
     $867 = (($859) + ($862<<3)|0);
     HEAP32[$867>>2] = $866;
     $868 = $856 >> 16;
     $869 = ((($859) + ($862<<3)|0) + 4|0);
     HEAP32[$869>>2] = $868;
     HEAP8[$865>>0] = 1;
     $$pre$phi$i265Z2D = $860;
    }
    $870 = HEAP16[$$pre$phi$i265Z2D>>1]|0;
    $871 = (($870) + 1)<<16>>16;
    HEAP16[$$pre$phi$i265Z2D>>1] = $871;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $853;$y$16 = $856;$zone$1 = $zone$0$ph;
    break;
   }
   case 10:  {
    $872 = ($149|0)<(8);
    if ($872) {
     $$0 = 129;
     label = 398;
     break L5;
    }
    $873 = (($149) + -2)|0;
    $874 = (($873|0) % 6)&-1;
    $875 = (($873|0) / 6)&-1;
    $876 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $877 = ($876|0)==(0);
    if (!($877)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $878 = ($875*3)|0;
    $879 = (($878) + 2)|0;
    $880 = ($879|0)==(0);
    if (!($880)) {
     $881 = HEAP32[$43>>2]|0;
     $882 = (($881) + 22|0);
     $883 = HEAP16[$882>>1]|0;
     $884 = $883 << 16 >> 16;
     $885 = (($881) + 58|0);
     $886 = HEAP16[$885>>1]|0;
     $887 = $886 << 16 >> 16;
     $888 = (($884) + ($879))|0;
     $889 = (($888) + ($887))|0;
     $890 = (($881) + 4|0);
     $891 = HEAP32[$890>>2]|0;
     $892 = ($889>>>0)>($891>>>0);
     if ($892) {
      $893 = (_FT_GlyphLoader_CheckPoints($881,$879,0)|0);
      $894 = ($893|0)==(0);
      if (!($894)) {
       $$0 = 0;
       label = 398;
       break L5;
      }
     }
    }
    $$neg356 = (2 - ($149))|0;
    $895 = (-2 - ($145))|0;
    $896 = (($895) + ($$neg356))|0;
    $$sum69 = (($896) + ($874))|0;
    $897 = (($110) + ($$sum69<<2)|0);
    $898 = ($873|0)>(5);
    $899 = HEAP32[$897>>2]|0;
    $900 = (($899) + ($x$0$ph))|0;
    $$sum757 = (($$sum69) + 1)|0;
    $901 = (($110) + ($$sum757<<2)|0);
    $902 = HEAP32[$901>>2]|0;
    $903 = (($902) + ($y$0$ph))|0;
    $$idx143$val389 = HEAP32[$41>>2]|0;
    $$idx144$val390 = HEAP8[$$idx184>>0]|0;
    $904 = ($$idx144$val390<<24>>24)==(0);
    if ($898) {
     $$idx143$val393 = $$idx143$val389;$1776 = $904;$914 = $900;$917 = $903;$args$9392 = $897;$num_curves$0391 = $875;
     while(1) {
      if ($1776) {
       $$pre$i268 = (($$idx143$val393) + 2|0);
       $$idx141$val = $$idx143$val393;$$pre$phi$i270Z2D = $$pre$i268;
      } else {
       $905 = (($$idx143$val393) + 4|0);
       $906 = HEAP32[$905>>2]|0;
       $907 = (($$idx143$val393) + 2|0);
       $908 = HEAP16[$907>>1]|0;
       $909 = $908 << 16 >> 16;
       $910 = (($$idx143$val393) + 8|0);
       $911 = HEAP32[$910>>2]|0;
       $912 = (($911) + ($909)|0);
       $913 = $914 >> 16;
       $915 = (($906) + ($909<<3)|0);
       HEAP32[$915>>2] = $913;
       $916 = $917 >> 16;
       $918 = ((($906) + ($909<<3)|0) + 4|0);
       HEAP32[$918>>2] = $916;
       HEAP8[$912>>0] = 2;
       $$idx141$val$pre = HEAP32[$41>>2]|0;
       $$idx141$val = $$idx141$val$pre;$$pre$phi$i270Z2D = $907;
      }
      $919 = HEAP16[$$pre$phi$i270Z2D>>1]|0;
      $920 = (($919) + 1)<<16>>16;
      HEAP16[$$pre$phi$i270Z2D>>1] = $920;
      $921 = (($args$9392) + 8|0);
      $922 = HEAP32[$921>>2]|0;
      $923 = (($922) + ($914))|0;
      $924 = (($args$9392) + 12|0);
      $925 = HEAP32[$924>>2]|0;
      $926 = (($925) + ($917))|0;
      $$idx142$val = HEAP8[$$idx184>>0]|0;
      $927 = ($$idx142$val<<24>>24)==(0);
      if ($927) {
       $$pre$i272 = (($$idx141$val) + 2|0);
       $$idx139$val = $$idx141$val;$$pre$phi$i274Z2D = $$pre$i272;
      } else {
       $928 = (($$idx141$val) + 4|0);
       $929 = HEAP32[$928>>2]|0;
       $930 = (($$idx141$val) + 2|0);
       $931 = HEAP16[$930>>1]|0;
       $932 = $931 << 16 >> 16;
       $933 = (($$idx141$val) + 8|0);
       $934 = HEAP32[$933>>2]|0;
       $935 = (($934) + ($932)|0);
       $936 = $923 >> 16;
       $937 = (($929) + ($932<<3)|0);
       HEAP32[$937>>2] = $936;
       $938 = $926 >> 16;
       $939 = ((($929) + ($932<<3)|0) + 4|0);
       HEAP32[$939>>2] = $938;
       HEAP8[$935>>0] = 2;
       $$idx139$val$pre = HEAP32[$41>>2]|0;
       $$idx139$val = $$idx139$val$pre;$$pre$phi$i274Z2D = $930;
      }
      $940 = HEAP16[$$pre$phi$i274Z2D>>1]|0;
      $941 = (($940) + 1)<<16>>16;
      HEAP16[$$pre$phi$i274Z2D>>1] = $941;
      $942 = (($args$9392) + 16|0);
      $943 = HEAP32[$942>>2]|0;
      $944 = (($943) + ($923))|0;
      $945 = (($args$9392) + 20|0);
      $946 = HEAP32[$945>>2]|0;
      $947 = (($946) + ($926))|0;
      $$idx140$val = HEAP8[$$idx184>>0]|0;
      $948 = ($$idx140$val<<24>>24)==(0);
      if ($948) {
       $$pre$i276 = (($$idx139$val) + 2|0);
       $$idx143$val = $$idx139$val;$$pre$phi$i278Z2D = $$pre$i276;
      } else {
       $949 = (($$idx139$val) + 4|0);
       $950 = HEAP32[$949>>2]|0;
       $951 = (($$idx139$val) + 2|0);
       $952 = HEAP16[$951>>1]|0;
       $953 = $952 << 16 >> 16;
       $954 = (($$idx139$val) + 8|0);
       $955 = HEAP32[$954>>2]|0;
       $956 = (($955) + ($953)|0);
       $957 = $944 >> 16;
       $958 = (($950) + ($953<<3)|0);
       HEAP32[$958>>2] = $957;
       $959 = $947 >> 16;
       $960 = ((($950) + ($953<<3)|0) + 4|0);
       HEAP32[$960>>2] = $959;
       HEAP8[$956>>0] = 1;
       $$idx143$val$pre = HEAP32[$41>>2]|0;
       $$idx143$val = $$idx143$val$pre;$$pre$phi$i278Z2D = $951;
      }
      $961 = HEAP16[$$pre$phi$i278Z2D>>1]|0;
      $962 = (($961) + 1)<<16>>16;
      HEAP16[$$pre$phi$i278Z2D>>1] = $962;
      $963 = (($args$9392) + 24|0);
      $964 = (($num_curves$0391) + -1)|0;
      $965 = ($964|0)>(0);
      $966 = HEAP32[$963>>2]|0;
      $967 = (($966) + ($944))|0;
      $968 = (($args$9392) + 28|0);
      $969 = HEAP32[$968>>2]|0;
      $970 = (($969) + ($947))|0;
      $$idx144$val = HEAP8[$$idx184>>0]|0;
      $971 = ($$idx144$val<<24>>24)==(0);
      if ($965) {
       $$idx143$val393 = $$idx143$val;$1776 = $971;$914 = $967;$917 = $970;$args$9392 = $963;$num_curves$0391 = $964;
      } else {
       $$idx143$val$lcssa = $$idx143$val;$$lcssa386 = $967;$$lcssa387 = $970;$$lcssa388 = $971;
       break;
      }
     }
    } else {
     $$idx143$val$lcssa = $$idx143$val389;$$lcssa386 = $900;$$lcssa387 = $903;$$lcssa388 = $904;
    }
    if ($$lcssa388) {
     $$pre$i280 = (($$idx143$val$lcssa) + 2|0);
     $$pre$phi$i282Z2D = $$pre$i280;
    } else {
     $972 = (($$idx143$val$lcssa) + 4|0);
     $973 = HEAP32[$972>>2]|0;
     $974 = (($$idx143$val$lcssa) + 2|0);
     $975 = HEAP16[$974>>1]|0;
     $976 = $975 << 16 >> 16;
     $977 = (($$idx143$val$lcssa) + 8|0);
     $978 = HEAP32[$977>>2]|0;
     $979 = (($978) + ($976)|0);
     $980 = $$lcssa386 >> 16;
     $981 = (($973) + ($976<<3)|0);
     HEAP32[$981>>2] = $980;
     $982 = $$lcssa387 >> 16;
     $983 = ((($973) + ($976<<3)|0) + 4|0);
     HEAP32[$983>>2] = $982;
     HEAP8[$979>>0] = 1;
     $$pre$phi$i282Z2D = $974;
    }
    $984 = HEAP16[$$pre$phi$i282Z2D>>1]|0;
    $985 = (($984) + 1)<<16>>16;
    HEAP16[$$pre$phi$i282Z2D>>1] = $985;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $$lcssa386;$y$16 = $$lcssa387;$zone$1 = $zone$0$ph;
    break;
   }
   case 16:  {
    $986 = (_cff_builder_start_point($decoder,$x$0$ph,$y$0$ph)|0);
    $987 = ($986|0)==(0);
    if (!($987)) {
     $$0 = 0;
     label = 398;
     break L5;
    }
    $988 = HEAP32[$43>>2]|0;
    $989 = (($988) + 22|0);
    $990 = HEAP16[$989>>1]|0;
    $991 = $990 << 16 >> 16;
    $992 = (($988) + 58|0);
    $993 = HEAP16[$992>>1]|0;
    $994 = $993 << 16 >> 16;
    $995 = (($991) + 6)|0;
    $996 = (($995) + ($994))|0;
    $997 = (($988) + 4|0);
    $998 = HEAP32[$997>>2]|0;
    $999 = ($996>>>0)>($998>>>0);
    if ($999) {
     $1000 = (_FT_GlyphLoader_CheckPoints($988,6,0)|0);
     $1001 = ($1000|0)==(0);
     if (!($1001)) {
      $$0 = 0;
      label = 398;
      break L5;
     }
    }
    $1002 = HEAP32[$148>>2]|0;
    $1003 = (($1002) + ($x$0$ph))|0;
    $$sum61 = (1 - ($145))|0;
    $1004 = (($110) + ($$sum61<<2)|0);
    $1005 = HEAP32[$1004>>2]|0;
    $1006 = (($1005) + ($y$0$ph))|0;
    $$idx135$val = HEAP32[$41>>2]|0;
    $$idx136$val = HEAP8[$$idx184>>0]|0;
    $1007 = ($$idx136$val<<24>>24)==(0);
    if ($1007) {
     $$pre$i285 = (($$idx135$val) + 2|0);
     $$idx133$val = $$idx135$val;$$pre$phi$i287Z2D = $$pre$i285;
    } else {
     $1008 = (($$idx135$val) + 4|0);
     $1009 = HEAP32[$1008>>2]|0;
     $1010 = (($$idx135$val) + 2|0);
     $1011 = HEAP16[$1010>>1]|0;
     $1012 = $1011 << 16 >> 16;
     $1013 = (($$idx135$val) + 8|0);
     $1014 = HEAP32[$1013>>2]|0;
     $1015 = (($1014) + ($1012)|0);
     $1016 = $1003 >> 16;
     $1017 = (($1009) + ($1012<<3)|0);
     HEAP32[$1017>>2] = $1016;
     $1018 = $1006 >> 16;
     $1019 = ((($1009) + ($1012<<3)|0) + 4|0);
     HEAP32[$1019>>2] = $1018;
     HEAP8[$1015>>0] = 2;
     $$idx133$val$pre = HEAP32[$41>>2]|0;
     $$idx133$val = $$idx133$val$pre;$$pre$phi$i287Z2D = $1010;
    }
    $1020 = HEAP16[$$pre$phi$i287Z2D>>1]|0;
    $1021 = (($1020) + 1)<<16>>16;
    HEAP16[$$pre$phi$i287Z2D>>1] = $1021;
    $$sum62 = (2 - ($145))|0;
    $1022 = (($110) + ($$sum62<<2)|0);
    $1023 = HEAP32[$1022>>2]|0;
    $1024 = (($1023) + ($1003))|0;
    $$sum63 = (3 - ($145))|0;
    $1025 = (($110) + ($$sum63<<2)|0);
    $1026 = HEAP32[$1025>>2]|0;
    $1027 = (($1026) + ($1006))|0;
    $$idx134$val = HEAP8[$$idx184>>0]|0;
    $1028 = ($$idx134$val<<24>>24)==(0);
    if ($1028) {
     $$pre$i289 = (($$idx133$val) + 2|0);
     $$idx131$val = $$idx133$val;$$pre$phi$i291Z2D = $$pre$i289;
    } else {
     $1029 = (($$idx133$val) + 4|0);
     $1030 = HEAP32[$1029>>2]|0;
     $1031 = (($$idx133$val) + 2|0);
     $1032 = HEAP16[$1031>>1]|0;
     $1033 = $1032 << 16 >> 16;
     $1034 = (($$idx133$val) + 8|0);
     $1035 = HEAP32[$1034>>2]|0;
     $1036 = (($1035) + ($1033)|0);
     $1037 = $1024 >> 16;
     $1038 = (($1030) + ($1033<<3)|0);
     HEAP32[$1038>>2] = $1037;
     $1039 = $1027 >> 16;
     $1040 = ((($1030) + ($1033<<3)|0) + 4|0);
     HEAP32[$1040>>2] = $1039;
     HEAP8[$1036>>0] = 2;
     $$idx131$val$pre = HEAP32[$41>>2]|0;
     $$idx131$val = $$idx131$val$pre;$$pre$phi$i291Z2D = $1031;
    }
    $1041 = HEAP16[$$pre$phi$i291Z2D>>1]|0;
    $1042 = (($1041) + 1)<<16>>16;
    HEAP16[$$pre$phi$i291Z2D>>1] = $1042;
    $$sum64 = (4 - ($145))|0;
    $1043 = (($110) + ($$sum64<<2)|0);
    $1044 = HEAP32[$1043>>2]|0;
    $1045 = (($1044) + ($1024))|0;
    $$idx132$val = HEAP8[$$idx184>>0]|0;
    $1046 = ($$idx132$val<<24>>24)==(0);
    if ($1046) {
     $$pre$i293 = (($$idx131$val) + 2|0);
     $$idx129$val = $$idx131$val;$$pre$phi$i295Z2D = $$pre$i293;
    } else {
     $1047 = (($$idx131$val) + 4|0);
     $1048 = HEAP32[$1047>>2]|0;
     $1049 = (($$idx131$val) + 2|0);
     $1050 = HEAP16[$1049>>1]|0;
     $1051 = $1050 << 16 >> 16;
     $1052 = (($$idx131$val) + 8|0);
     $1053 = HEAP32[$1052>>2]|0;
     $1054 = (($1053) + ($1051)|0);
     $1055 = $1045 >> 16;
     $1056 = (($1048) + ($1051<<3)|0);
     HEAP32[$1056>>2] = $1055;
     $1057 = $1027 >> 16;
     $1058 = ((($1048) + ($1051<<3)|0) + 4|0);
     HEAP32[$1058>>2] = $1057;
     HEAP8[$1054>>0] = 1;
     $$idx129$val$pre = HEAP32[$41>>2]|0;
     $$idx129$val = $$idx129$val$pre;$$pre$phi$i295Z2D = $1049;
    }
    $1059 = HEAP16[$$pre$phi$i295Z2D>>1]|0;
    $1060 = (($1059) + 1)<<16>>16;
    HEAP16[$$pre$phi$i295Z2D>>1] = $1060;
    $$sum65 = (5 - ($145))|0;
    $1061 = (($110) + ($$sum65<<2)|0);
    $1062 = HEAP32[$1061>>2]|0;
    $1063 = (($1062) + ($1045))|0;
    $$idx130$val = HEAP8[$$idx184>>0]|0;
    $1064 = ($$idx130$val<<24>>24)==(0);
    if ($1064) {
     $$pre$i297 = (($$idx129$val) + 2|0);
     $$idx127$val = $$idx129$val;$$pre$phi$i299Z2D = $$pre$i297;
    } else {
     $1065 = (($$idx129$val) + 4|0);
     $1066 = HEAP32[$1065>>2]|0;
     $1067 = (($$idx129$val) + 2|0);
     $1068 = HEAP16[$1067>>1]|0;
     $1069 = $1068 << 16 >> 16;
     $1070 = (($$idx129$val) + 8|0);
     $1071 = HEAP32[$1070>>2]|0;
     $1072 = (($1071) + ($1069)|0);
     $1073 = $1063 >> 16;
     $1074 = (($1066) + ($1069<<3)|0);
     HEAP32[$1074>>2] = $1073;
     $1075 = $1027 >> 16;
     $1076 = ((($1066) + ($1069<<3)|0) + 4|0);
     HEAP32[$1076>>2] = $1075;
     HEAP8[$1072>>0] = 2;
     $$idx127$val$pre = HEAP32[$41>>2]|0;
     $$idx127$val = $$idx127$val$pre;$$pre$phi$i299Z2D = $1067;
    }
    $1077 = HEAP16[$$pre$phi$i299Z2D>>1]|0;
    $1078 = (($1077) + 1)<<16>>16;
    HEAP16[$$pre$phi$i299Z2D>>1] = $1078;
    $$sum66 = (6 - ($145))|0;
    $1079 = (($110) + ($$sum66<<2)|0);
    $1080 = HEAP32[$1079>>2]|0;
    $1081 = (($1080) + ($1063))|0;
    $$idx128$val = HEAP8[$$idx184>>0]|0;
    $1082 = ($$idx128$val<<24>>24)==(0);
    if ($1082) {
     $$pre$i301 = (($$idx127$val) + 2|0);
     $$idx125$val = $$idx127$val;$$pre$phi$i303Z2D = $$pre$i301;
    } else {
     $$sum67 = (7 - ($145))|0;
     $1083 = (($110) + ($$sum67<<2)|0);
     $1084 = HEAP32[$1083>>2]|0;
     $1085 = (($1084) + ($1027))|0;
     $1086 = (($$idx127$val) + 4|0);
     $1087 = HEAP32[$1086>>2]|0;
     $1088 = (($$idx127$val) + 2|0);
     $1089 = HEAP16[$1088>>1]|0;
     $1090 = $1089 << 16 >> 16;
     $1091 = (($$idx127$val) + 8|0);
     $1092 = HEAP32[$1091>>2]|0;
     $1093 = (($1092) + ($1090)|0);
     $1094 = $1081 >> 16;
     $1095 = (($1087) + ($1090<<3)|0);
     HEAP32[$1095>>2] = $1094;
     $1096 = $1085 >> 16;
     $1097 = ((($1087) + ($1090<<3)|0) + 4|0);
     HEAP32[$1097>>2] = $1096;
     HEAP8[$1093>>0] = 2;
     $$idx125$val$pre = HEAP32[$41>>2]|0;
     $$idx125$val = $$idx125$val$pre;$$pre$phi$i303Z2D = $1088;
    }
    $1098 = HEAP16[$$pre$phi$i303Z2D>>1]|0;
    $1099 = (($1098) + 1)<<16>>16;
    HEAP16[$$pre$phi$i303Z2D>>1] = $1099;
    $$sum68 = (8 - ($145))|0;
    $1100 = (($110) + ($$sum68<<2)|0);
    $1101 = HEAP32[$1100>>2]|0;
    $1102 = (($1101) + ($1081))|0;
    $$idx126$val = HEAP8[$$idx184>>0]|0;
    $1103 = ($$idx126$val<<24>>24)==(0);
    if ($1103) {
     $$pre$i305 = (($$idx125$val) + 2|0);
     $$pre$phi$i307Z2D = $$pre$i305;
    } else {
     $1104 = (($$idx125$val) + 4|0);
     $1105 = HEAP32[$1104>>2]|0;
     $1106 = (($$idx125$val) + 2|0);
     $1107 = HEAP16[$1106>>1]|0;
     $1108 = $1107 << 16 >> 16;
     $1109 = (($$idx125$val) + 8|0);
     $1110 = HEAP32[$1109>>2]|0;
     $1111 = (($1110) + ($1108)|0);
     $1112 = $1102 >> 16;
     $1113 = (($1105) + ($1108<<3)|0);
     HEAP32[$1113>>2] = $1112;
     $1114 = $y$0$ph >> 16;
     $1115 = ((($1105) + ($1108<<3)|0) + 4|0);
     HEAP32[$1115>>2] = $1114;
     HEAP8[$1111>>0] = 1;
     $$pre$phi$i307Z2D = $1106;
    }
    $1116 = HEAP16[$$pre$phi$i307Z2D>>1]|0;
    $1117 = (($1116) + 1)<<16>>16;
    HEAP16[$$pre$phi$i307Z2D>>1] = $1117;
    $args$12 = $19;$ip$3 = $ip$2$ph;$limit$1 = $limit$0$ph;$x$16 = $1102;$y$16 = $y$0$ph;$zone$1 = $zone$0$ph;
    break;
   }
   default: {
    $$0 = 7;
    label = 398;
    break L5;
   }
   }
  } while(0);
  $1688 = HEAP32[$0>>2]|0;
  $1689 = (($1688) + 276|0);
  HEAP32[$1689>>2] = $args$12;
  $1690 = HEAP32[$0>>2]|0;
  $1691 = (($1690) + 276|0);
  $1692 = HEAP32[$1691>>2]|0;
  $1693 = $1692;
  $1694 = (($1693) - ($37))|0;
  $1695 = ($1694|0)>(188);
  if ($1695) {
   $$0 = 130;
   label = 398;
   break;
  } else {
   $ip$0$ph = $ip$3;$limit$0$ph = $limit$1;$x$0$ph = $x$16;$y$0$ph = $y$16;$zone$0$ph = $zone$1;
  }
 }
 if ((label|0) == 329) {
  $1370 = HEAP32[$0>>2]|0;
  $1371 = HEAP32[$148>>2]|0;
  $$sum50 = (1 - ($145))|0;
  $1372 = (($110) + ($$sum50<<2)|0);
  $1373 = HEAP32[$1372>>2]|0;
  $$sum51 = (2 - ($145))|0;
  $1374 = (($110) + ($$sum51<<2)|0);
  $1375 = HEAP32[$1374>>2]|0;
  $$sum52 = (3 - ($145))|0;
  $1376 = (($110) + ($$sum52<<2)|0);
  $1377 = HEAP32[$1376>>2]|0;
  $1378 = $1377 >> 16;
  $$sum53 = (4 - ($145))|0;
  $1379 = (($110) + ($$sum53<<2)|0);
  $1380 = HEAP32[$1379>>2]|0;
  $1381 = $1380 >> 16;
  $1382 = (_cff_operator_seac($1370,$1371,$1373,$1375,$1378,$1381)|0);
  $1383 = HEAP32[$43>>2]|0;
  _FT_GlyphLoader_Add($1383);
  $$0 = $1382;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 330) {
  $1384 = ($149|0)>(3);
  if ($1384) {
   $1385 = HEAP32[$0>>2]|0;
   $1386 = (($1385) + 744|0);
   $1387 = HEAP32[$1386>>2]|0;
   $$sum46 = (-4 - ($145))|0;
   $1388 = (($110) + ($$sum46<<2)|0);
   $1389 = HEAP32[$1388>>2]|0;
   $$sum47 = (-3 - ($145))|0;
   $1390 = (($110) + ($$sum47<<2)|0);
   $1391 = HEAP32[$1390>>2]|0;
   $$sum48 = (-2 - ($145))|0;
   $1392 = (($110) + ($$sum48<<2)|0);
   $1393 = HEAP32[$1392>>2]|0;
   $1394 = $1393 >> 16;
   $req_args$0$not = $req_args$0 | -16;
   $$sum49 = $req_args$0$not ^ 15;
   $1395 = (($110) + ($$sum49<<2)|0);
   $1396 = HEAP32[$1395>>2]|0;
   $1397 = $1396 >> 16;
   $1398 = (_cff_operator_seac($1385,0,$1389,$1391,$1394,$1397)|0);
   $1399 = HEAP32[$0>>2]|0;
   $1400 = (($1399) + 744|0);
   HEAP32[$1400>>2] = $1387;
   $$0 = $1398;
   STACKTOP = sp;return ($$0|0);
  }
  $$idx$val = HEAP32[$41>>2]|0;
  _cff_builder_close_contour($$idx$val);
  do {
   if ($33) {
    $1401 = (($24) + 8|0);
    $1402 = HEAP32[$1401>>2]|0;
    $1403 = HEAP32[$$pre$phi1128Z2D>>2]|0;
    $1404 = HEAP32[$41>>2]|0;
    $1405 = (($1404) + 2|0);
    $1406 = HEAP16[$1405>>1]|0;
    $1407 = $1406 << 16 >> 16;
    $1408 = (FUNCTION_TABLE_iii[$1402 & 4095]($1403,$1407)|0);
    $1409 = ($1408|0)==(0);
    if ($1409) {
     $1410 = (($24) + 24|0);
     $1411 = HEAP32[$1410>>2]|0;
     $1412 = HEAP32[$$pre$phi1128Z2D>>2]|0;
     $1413 = HEAP32[$41>>2]|0;
     $1414 = (($decoder) + 72|0);
     $1415 = HEAP32[$1414>>2]|0;
     $1416 = HEAP32[$0>>2]|0;
     $1417 = (($1416) + 920|0);
     $1418 = HEAP32[$1417>>2]|0;
     (FUNCTION_TABLE_iiiii[$1411 & 511]($1412,$1413,$1415,$1418)|0);
     break;
    } else {
     $$0 = 3;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  $1419 = HEAP32[$43>>2]|0;
  _FT_GlyphLoader_Add($1419);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 398) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _cff_builder_close_contour($builder$0$5$val) {
 $builder$0$5$val = $builder$0$5$val|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($builder$0$5$val|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP16[$builder$0$5$val>>1]|0;
 $2 = ($1<<16>>16)<(2);
 if ($2) {
  $21 = 0;
 } else {
  $3 = $1 << 16 >> 16;
  $4 = (($3) + -2)|0;
  $5 = (($builder$0$5$val) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($4<<1)|0);
  $8 = HEAP16[$7>>1]|0;
  $9 = $8 << 16 >> 16;
  $10 = (($9) + 1)|0;
  $21 = $10;
 }
 $11 = (($builder$0$5$val) + 2|0);
 $12 = HEAP16[$11>>1]|0;
 $13 = ($12<<16>>16)>(1);
 if ($13) {
  $14 = $12 << 16 >> 16;
  $15 = (($builder$0$5$val) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $$sum = (($14) + -1)|0;
  $17 = (($builder$0$5$val) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($$sum)|0);
  $20 = (($16) + ($21<<3)|0);
  $22 = HEAP32[$20>>2]|0;
  $23 = (($16) + ($$sum<<3)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($22|0)==($24|0);
  if ($25) {
   $26 = ((($16) + ($21<<3)|0) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($16) + ($$sum<<3)|0) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($27|0)==($29|0);
   if ($30) {
    $31 = HEAP8[$19>>0]|0;
    $32 = ($31<<24>>24)==(1);
    if ($32) {
     $33 = (($12) + -1)<<16>>16;
     HEAP16[$11>>1] = $33;
     $37 = $33;
    } else {
     $37 = $12;
    }
   } else {
    $37 = $12;
   }
  } else {
   $37 = $12;
  }
 } else {
  $37 = $12;
 }
 $34 = $1 << 16 >> 16;
 $35 = ($1<<16>>16)>(0);
 if (!($35)) {
  STACKTOP = sp;return;
 }
 $36 = $37 << 16 >> 16;
 $38 = (($36) + -1)|0;
 $39 = ($21|0)==($38|0);
 if ($39) {
  $40 = (($1) + -1)<<16>>16;
  HEAP16[$builder$0$5$val>>1] = $40;
  $41 = (($37) + -1)<<16>>16;
  HEAP16[$11>>1] = $41;
  STACKTOP = sp;return;
 } else {
  $42 = $38&65535;
  $43 = (($34) + -1)|0;
  $44 = (($builder$0$5$val) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + ($43<<1)|0);
  HEAP16[$46>>1] = $42;
  STACKTOP = sp;return;
 }
}
function _cff_builder_start_point($builder,$x,$y) {
 $builder = $builder|0;
 $x = $x|0;
 $y = $y|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $builder$idx$val$i = 0, $builder$idx1$val$i = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($builder) + 64|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 HEAP8[$0>>0] = 1;
 $3 = (($builder) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($builder) + 65|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $8 = HEAP16[$4>>1]|0;
  $9 = (($8) + 1)<<16>>16;
  HEAP16[$4>>1] = $9;
  $$pre = (($builder) + 12|0);
  $$pre$phiZ2D = $$pre;
 } else {
  $10 = (($builder) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 20|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13 << 16 >> 16;
  $15 = (($11) + 56|0);
  $16 = HEAP16[$15>>1]|0;
  $17 = $16 << 16 >> 16;
  $18 = (($14) + 1)|0;
  $19 = (($18) + ($17))|0;
  $20 = (($11) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($19>>>0)>($21>>>0);
  if ($22) {
   $23 = (_FT_GlyphLoader_CheckPoints($11,0,1)|0);
   $24 = ($23|0)==(0);
   if (!($24)) {
    $error$0 = $23;
    STACKTOP = sp;return ($error$0|0);
   }
  }
  $25 = HEAP16[$4>>1]|0;
  $26 = ($25<<16>>16)>(0);
  if ($26) {
   $27 = $25 << 16 >> 16;
   $28 = (($4) + 2|0);
   $29 = HEAP16[$28>>1]|0;
   $30 = $29&65535;
   $31 = (($30) + 65535)|0;
   $32 = $31&65535;
   $33 = (($27) + -1)|0;
   $34 = (($4) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + ($33<<1)|0);
   HEAP16[$36>>1] = $32;
   $$pre$i = HEAP16[$4>>1]|0;
   $38 = $$pre$i;
  } else {
   $38 = $25;
  }
  $37 = (($38) + 1)<<16>>16;
  HEAP16[$4>>1] = $37;
  $$pre$phiZ2D = $10;
 }
 $39 = HEAP32[$$pre$phiZ2D>>2]|0;
 $40 = (($39) + 22|0);
 $41 = HEAP16[$40>>1]|0;
 $42 = $41 << 16 >> 16;
 $43 = (($39) + 58|0);
 $44 = HEAP16[$43>>1]|0;
 $45 = $44 << 16 >> 16;
 $46 = (($42) + 1)|0;
 $47 = (($46) + ($45))|0;
 $48 = (($39) + 4|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($47>>>0)>($49>>>0);
 if ($50) {
  $51 = (_FT_GlyphLoader_CheckPoints($39,1,0)|0);
  $52 = ($51|0)==(0);
  if (!($52)) {
   $error$0 = $51;
   STACKTOP = sp;return ($error$0|0);
  }
 }
 $builder$idx$val$i = HEAP32[$3>>2]|0;
 $builder$idx1$val$i = HEAP8[$5>>0]|0;
 $53 = ($builder$idx1$val$i<<24>>24)==(0);
 if ($53) {
  $$pre$i$i = (($builder$idx$val$i) + 2|0);
  $$pre$phi$i$iZ2D = $$pre$i$i;
 } else {
  $54 = (($builder$idx$val$i) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($builder$idx$val$i) + 2|0);
  $57 = HEAP16[$56>>1]|0;
  $58 = $57 << 16 >> 16;
  $59 = (($builder$idx$val$i) + 8|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($60) + ($58)|0);
  $62 = $x >> 16;
  $63 = (($55) + ($58<<3)|0);
  HEAP32[$63>>2] = $62;
  $64 = $y >> 16;
  $65 = ((($55) + ($58<<3)|0) + 4|0);
  HEAP32[$65>>2] = $64;
  HEAP8[$61>>0] = 1;
  $$pre$phi$i$iZ2D = $56;
 }
 $66 = HEAP16[$$pre$phi$i$iZ2D>>1]|0;
 $67 = (($66) + 1)<<16>>16;
 HEAP16[$$pre$phi$i$iZ2D>>1] = $67;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _cff_operator_seac($decoder,$asb,$adx,$ady,$bchar,$achar) {
 $decoder = $decoder|0;
 $asb = $asb|0;
 $adx = $adx|0;
 $ady = $ady|0;
 $bchar = $bchar|0;
 $achar = $achar|0;
 var $$0 = 0, $$0$i = 0, $$idx$val = 0, $$idx1$val = 0, $$idx2$val = 0, $$idx3$val = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $charstring = 0;
 var $charstring_len = 0, $error$0 = 0, $n$02$i = 0, $n$02$i6 = 0, $or$cond$i = 0, $or$cond$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $charstring = sp + 4|0;
 $charstring_len = sp;
 $0 = (($decoder) + 924|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $$0 = 160;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($decoder) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($decoder) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($adx))|0;
 $8 = (($decoder) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($ady))|0;
 $11 = (($4) + 692|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1160|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 $16 = ($bchar>>>0)>(255);
 $or$cond$i = $15 | $16;
 L4: do {
  if ($or$cond$i) {
   $$0$i = -1;$27 = $14;
  } else {
   $17 = (_cff_get_standard_encoding($bchar)|0);
   $18 = (($12) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0);
   $$pre = HEAP32[$13>>2]|0;
   if ($20) {
    $$0$i = -1;$27 = $$pre;
   } else {
    $n$02$i = 0;
    while(1) {
     $23 = (($$pre) + ($n$02$i<<1)|0);
     $24 = HEAP16[$23>>1]|0;
     $25 = ($24<<16>>16)==($17<<16>>16);
     $22 = (($n$02$i) + 1)|0;
     if ($25) {
      $$0$i = $n$02$i;$27 = $$pre;
      break L4;
     }
     $21 = ($22>>>0)<($19>>>0);
     if ($21) {
      $n$02$i = $22;
     } else {
      $$0$i = -1;$27 = $$pre;
      break;
     }
    }
   }
  }
 } while(0);
 $26 = ($27|0)==(0|0);
 $28 = ($achar>>>0)>(255);
 $or$cond$i4 = $26 | $28;
 if ($or$cond$i4) {
  $$0 = 160;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (_cff_get_standard_encoding($achar)|0);
 $30 = (($12) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0);
 if ($32) {
  $$0 = 160;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP32[$13>>2]|0;
 $n$02$i6 = 0;
 while(1) {
  $36 = (($33) + ($n$02$i6<<1)|0);
  $37 = HEAP16[$36>>1]|0;
  $38 = ($37<<16>>16)==($29<<16>>16);
  $35 = (($n$02$i6) + 1)|0;
  if ($38) {
   break;
  }
  $34 = ($35>>>0)<($31>>>0);
  if ($34) {
   $n$02$i6 = $35;
  } else {
   $$0 = 160;
   label = 20;
   break;
  }
 }
 if ((label|0) == 20) {
  STACKTOP = sp;return ($$0|0);
 }
 $39 = $n$02$i6 | $$0$i;
 $40 = ($39|0)<(0);
 if ($40) {
  $$0 = 160;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = (($decoder) + 66|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = ($42<<24>>24)==(0);
 do {
  if (!($43)) {
   $44 = (($decoder) + 8|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (($45) + 156|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = HEAP32[$47>>2]|0;
   $49 = (_FT_GlyphLoader_CheckSubGlyphs($48,2)|0);
   $50 = ($49|0)==(0);
   if ($50) {
    $51 = (($48) + 88|0);
    $52 = HEAP32[$51>>2]|0;
    HEAP32[$52>>2] = $$0$i;
    $53 = (($52) + 4|0);
    HEAP16[$53>>1] = 514;
    $54 = (($52) + 8|0);
    HEAP32[$54>>2] = 0;
    $55 = (($52) + 12|0);
    HEAP32[$55>>2] = 0;
    $56 = (($52) + 32|0);
    HEAP32[$56>>2] = $n$02$i6;
    $57 = (($52) + 36|0);
    HEAP16[$57>>1] = 2;
    $58 = $7 >> 16;
    $59 = (($52) + 40|0);
    HEAP32[$59>>2] = $58;
    $60 = $10 >> 16;
    $61 = (($52) + 44|0);
    HEAP32[$61>>2] = $60;
    $62 = (($45) + 128|0);
    HEAP32[$62>>2] = 2;
    $63 = (($48) + 52|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (($45) + 132|0);
    HEAP32[$65>>2] = $64;
    $66 = (($45) + 72|0);
    HEAP32[$66>>2] = 1668246896;
    $67 = (($48) + 84|0);
    HEAP32[$67>>2] = 2;
    break;
   } else {
    $$0 = $49;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $68 = (($decoder) + 12|0);
 $69 = HEAP32[$68>>2]|0;
 _FT_GlyphLoader_Prepare($69);
 $$idx1$val = HEAP32[$11>>2]|0;
 $70 = (($$idx1$val) + 1176|0);
 $71 = (_cff_index_access_element($70,$$0$i,$charstring,$charstring_len)|0);
 $72 = ($71|0)==(0);
 if ($72) {
  HEAP8[$0>>0] = 1;
  $73 = HEAP32[$charstring>>2]|0;
  $74 = HEAP32[$charstring_len>>2]|0;
  $75 = (_cff_decoder_parse_charstrings($decoder,$73,$74)|0);
  HEAP8[$0>>0] = 0;
  $$idx2$val = HEAP32[$11>>2]|0;
  $76 = (($$idx2$val) + 1176|0);
  _cff_index_forget_element($76,$charstring);
  $77 = ($75|0)==(0);
  if (!($77)) {
   $$0 = $75;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $78 = $5;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = (($decoder) + 40|0);
 $85 = $84;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = (($85) + 4)|0;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = (($decoder) + 744|0);
 $92 = HEAP32[$91>>2]|0;
 HEAP32[$5>>2] = 0;
 HEAP32[$8>>2] = 0;
 $93 = (($7) - ($asb))|0;
 $94 = (($decoder) + 24|0);
 HEAP32[$94>>2] = $93;
 $95 = (($decoder) + 28|0);
 HEAP32[$95>>2] = $10;
 $$idx$val = HEAP32[$11>>2]|0;
 $96 = (($$idx$val) + 1176|0);
 $97 = (_cff_index_access_element($96,$n$02$i6,$charstring,$charstring_len)|0);
 $98 = ($97|0)==(0);
 if ($98) {
  HEAP8[$0>>0] = 1;
  $99 = HEAP32[$charstring>>2]|0;
  $100 = HEAP32[$charstring_len>>2]|0;
  $101 = (_cff_decoder_parse_charstrings($decoder,$99,$100)|0);
  HEAP8[$0>>0] = 0;
  $$idx3$val = HEAP32[$11>>2]|0;
  $102 = (($$idx3$val) + 1176|0);
  _cff_index_forget_element($102,$charstring);
  $103 = ($101|0)==(0);
  if ($103) {
   $error$0 = 0;
  } else {
   $$0 = $101;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $error$0 = $97;
 }
 $104 = $5;
 $105 = $104;
 HEAP32[$105>>2] = $80;
 $106 = (($104) + 4)|0;
 $107 = $106;
 HEAP32[$107>>2] = $83;
 $108 = $84;
 $109 = $108;
 HEAP32[$109>>2] = $87;
 $110 = (($108) + 4)|0;
 $111 = $110;
 HEAP32[$111>>2] = $90;
 HEAP32[$91>>2] = $92;
 HEAP32[$94>>2] = 0;
 HEAP32[$95>>2] = 0;
 $$0 = $error$0;
 STACKTOP = sp;return ($$0|0);
}
function _cff_slot_load($glyph,$size,$glyph_index,$load_flags) {
 $glyph = $glyph|0;
 $size = $size|0;
 $glyph_index = $glyph_index|0;
 $load_flags = $load_flags|0;
 var $$$i$i = 0, $$$i$i10 = 0, $$0 = 0, $$01 = 0, $$idx8$val = 0, $$idx9 = 0, $$idx9$val = 0, $$lobit = 0, $$not = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $advance = 0, $cbox = 0, $charstring = 0, $charstring_len = 0, $decoder = 0, $fd_index$0 = 0, $font_matrix = 0, $font_offset$sroa$0$0 = 0;
 var $font_offset$sroa$1$0 = 0, $force_scaling$0 = 0, $load_flags$ = 0, $metrics = 0, $n$017 = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond6 = 0, $phitmp = 0, $result$0$i$i = 0, $result$0$i$i11 = 0, $sub$0$i = 0, $vec$018 = 0, $vertAdvance = 0, $vertBearingY = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1008|0;
 $decoder = sp + 32|0;
 $font_matrix = sp + 968|0;
 $metrics = sp + 992|0;
 $charstring = sp + 960|0;
 $charstring_len = sp + 24|0;
 $cbox = sp + 8|0;
 $advance = sp;
 $vertBearingY = sp + 984|0;
 $vertAdvance = sp + 986|0;
 $0 = (($glyph) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 692|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1324|0);
 $5 = (($4) + 132|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(65535);
 if ($7) {
  label = 5;
 } else {
  $8 = (($3) + 1152|0);
  $9 = (($3) + 1164|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   label = 5;
  } else {
   $12 = ($glyph_index|0)==(0);
   if ($12) {
    $$01 = 0;
   } else {
    $13 = (_cff_charset_cid_to_gindex($8,$glyph_index)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     $$0 = 6;
     STACKTOP = sp;return ($$0|0);
    } else {
     $$01 = $13;
    }
   }
  }
 }
 if ((label|0) == 5) {
  $15 = (($3) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16>>>0)>($glyph_index>>>0);
  if ($17) {
   $$01 = $glyph_index;
  } else {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $18 = $load_flags & 1024;
 $19 = ($18|0)==(0);
 $20 = $load_flags | 3;
 $load_flags$ = $19 ? $load_flags : $20;
 $21 = (($glyph) + 164|0);
 HEAP32[$21>>2] = 65536;
 $22 = (($glyph) + 168|0);
 HEAP32[$22>>2] = 65536;
 $23 = ($size|0)!=(0|0);
 if ($23) {
  $24 = (($size) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  HEAP32[$21>>2] = $25;
  $26 = (($size) + 20|0);
  $27 = HEAP32[$26>>2]|0;
  HEAP32[$22>>2] = $27;
  $28 = HEAP32[$size>>2]|0;
  $29 = (($28) + 532|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) + 104|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($size) + 44|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(-1);
  if (!($35)) {
   $36 = (($30) + 140|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    $39 = $load_flags$ & 8;
    $40 = ($39|0)==(0);
    if ($40) {
     $41 = (($30) + 104|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($glyph) + 76|0);
     $44 = (FUNCTION_TABLE_iiiiiiii[$42 & 127]($1,$34,$$01,$load_flags$,$32,$43,$metrics)|0);
     $45 = ($44|0)==(0);
     if ($45) {
      $46 = (($glyph) + 110|0);
      HEAP16[$46>>1] = 0;
      $47 = (($glyph) + 108|0);
      HEAP16[$47>>1] = 0;
      $48 = (($metrics) + 1|0);
      $49 = HEAP8[$48>>0]|0;
      $50 = $49&255;
      $51 = $50 << 6;
      $52 = (($glyph) + 24|0);
      HEAP32[$52>>2] = $51;
      $53 = HEAP8[$metrics>>0]|0;
      $54 = $53&255;
      $55 = $54 << 6;
      $56 = (($glyph) + 28|0);
      HEAP32[$56>>2] = $55;
      $57 = (($metrics) + 2|0);
      $58 = HEAP8[$57>>0]|0;
      $59 = $58 << 24 >> 24;
      $60 = $59 << 6;
      $61 = (($glyph) + 32|0);
      HEAP32[$61>>2] = $60;
      $62 = (($metrics) + 3|0);
      $63 = HEAP8[$62>>0]|0;
      $64 = $63 << 24 >> 24;
      $65 = $64 << 6;
      $66 = (($glyph) + 36|0);
      HEAP32[$66>>2] = $65;
      $67 = (($metrics) + 4|0);
      $68 = HEAP8[$67>>0]|0;
      $69 = $68&255;
      $70 = $69 << 6;
      $71 = (($glyph) + 40|0);
      HEAP32[$71>>2] = $70;
      $72 = (($metrics) + 5|0);
      $73 = HEAP8[$72>>0]|0;
      $74 = $73 << 24 >> 24;
      $75 = $74 << 6;
      $76 = (($glyph) + 44|0);
      HEAP32[$76>>2] = $75;
      $77 = (($metrics) + 6|0);
      $78 = HEAP8[$77>>0]|0;
      $79 = $78 << 24 >> 24;
      $80 = $79 << 6;
      $81 = (($glyph) + 48|0);
      HEAP32[$81>>2] = $80;
      $82 = (($metrics) + 7|0);
      $83 = HEAP8[$82>>0]|0;
      $84 = $83&255;
      $85 = $84 << 6;
      $86 = (($glyph) + 52|0);
      HEAP32[$86>>2] = $85;
      $87 = (($glyph) + 72|0);
      HEAP32[$87>>2] = 1651078259;
      $88 = $load_flags$ & 16;
      $89 = ($88|0)==(0);
      $90 = (($glyph) + 100|0);
      if ($89) {
       HEAP32[$90>>2] = $59;
       $92 = (($glyph) + 104|0);
       HEAP32[$92>>2] = $64;
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      } else {
       HEAP32[$90>>2] = $74;
       $91 = (($glyph) + 104|0);
       HEAP32[$91>>2] = $79;
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $93 = $load_flags$ & 16384;
 $94 = ($93|0)==(0);
 if (!($94)) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $95 = (($3) + 1896|0);
 $96 = HEAP32[$95>>2]|0;
 $97 = ($96|0)==(0);
 if ($97) {
  $124 = (($4) + 48|0);
  ;HEAP32[$font_matrix+0>>2]=HEAP32[$124+0>>2]|0;HEAP32[$font_matrix+4>>2]=HEAP32[$124+4>>2]|0;HEAP32[$font_matrix+8>>2]=HEAP32[$124+8>>2]|0;HEAP32[$font_matrix+12>>2]=HEAP32[$124+12>>2]|0;
  $125 = (($3) + 1396|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (($3) + 1400|0);
  $128 = HEAP32[$127>>2]|0;
  $font_offset$sroa$0$0 = $126;$font_offset$sroa$1$0 = $128;$force_scaling$0 = 0;
 } else {
  $98 = (($3) + 2924|0);
  $99 = (_cff_fd_select_get($98,$$01)|0);
  $100 = $99&255;
  $101 = HEAP32[$95>>2]|0;
  $102 = ($100>>>0)<($101>>>0);
  if ($102) {
   $fd_index$0 = $99;
  } else {
   $103 = (($101) + 255)|0;
   $104 = $103&255;
   $fd_index$0 = $104;
  }
  $105 = (($4) + 68|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = $fd_index$0&255;
  $108 = (($3) + 1900|0);
  $109 = (($108) + ($107<<2)|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (($110) + 68|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = (($110) + 48|0);
  ;HEAP32[$font_matrix+0>>2]=HEAP32[$113+0>>2]|0;HEAP32[$font_matrix+4>>2]=HEAP32[$113+4>>2]|0;HEAP32[$font_matrix+8>>2]=HEAP32[$113+8>>2]|0;HEAP32[$font_matrix+12>>2]=HEAP32[$113+12>>2]|0;
  $114 = HEAP32[$109>>2]|0;
  $115 = (($114) + 72|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($114) + 76|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ($106|0)==($112|0);
  if ($119) {
   $font_offset$sroa$0$0 = $116;$font_offset$sroa$1$0 = $118;$force_scaling$0 = 0;
  } else {
   $120 = HEAP32[$21>>2]|0;
   $121 = (_FT_MulDiv($120,$106,$112)|0);
   HEAP32[$21>>2] = $121;
   $122 = HEAP32[$22>>2]|0;
   $123 = (_FT_MulDiv($122,$106,$112)|0);
   HEAP32[$22>>2] = $123;
   $font_offset$sroa$0$0 = $116;$font_offset$sroa$1$0 = $118;$force_scaling$0 = 1;
  }
 }
 $129 = (($glyph) + 108|0);
 $130 = (($glyph) + 110|0);
 HEAP16[$130>>1] = 0;
 HEAP16[$129>>1] = 0;
 $131 = $load_flags$ & 1;
 $132 = ($131|0)==(0);
 if ($132) {
  $133 = $load_flags$ >>> 1;
  $$lobit = $133 & 1;
  $134 = $$lobit ^ 1;
  $phitmp = $134&255;
  $156 = $phitmp;
 } else {
  $156 = 0;
 }
 $135 = (($glyph) + 72|0);
 HEAP32[$135>>2] = 1869968492;
 $136 = $load_flags$ >>> 16;
 $137 = $136 & 15;
 $138 = HEAP32[$2>>2]|0;
 $139 = (($decoder) + 65|0);
 _memset(($decoder|0),0,928)|0;
 HEAP8[$139>>0] = 1;
 $140 = (($decoder) + 4|0);
 HEAP32[$140>>2] = $1;
 $141 = (($decoder) + 8|0);
 HEAP32[$141>>2] = $glyph;
 $142 = (($1) + 100|0);
 $143 = HEAP32[$142>>2]|0;
 HEAP32[$decoder>>2] = $143;
 $144 = ($glyph|0)==(0|0);
 if (!($144)) {
  $145 = (($glyph) + 156|0);
  $146 = HEAP32[$145>>2]|0;
  $147 = HEAP32[$146>>2]|0;
  $148 = (($decoder) + 12|0);
  HEAP32[$148>>2] = $147;
  $149 = (($147) + 20|0);
  $150 = (($decoder) + 16|0);
  HEAP32[$150>>2] = $149;
  $151 = (($147) + 56|0);
  $152 = (($decoder) + 20|0);
  HEAP32[$152>>2] = $151;
  _FT_GlyphLoader_Rewind($147);
  $153 = (($decoder) + 72|0);
  HEAP32[$153>>2] = 0;
  $154 = (($decoder) + 68|0);
  HEAP32[$154>>2] = 0;
  $155 = ($156<<24>>24)==(0);
  $157 = ($size|0)==(0|0);
  $or$cond$i$i = $155 | $157;
  if (!($or$cond$i$i)) {
   $158 = (($size) + 40|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = HEAP32[$159>>2]|0;
   HEAP32[$153>>2] = $160;
   $161 = HEAP32[$145>>2]|0;
   $162 = (($161) + 36|0);
   $163 = HEAP32[$162>>2]|0;
   HEAP32[$154>>2] = $163;
  }
 }
 $164 = (($decoder) + 24|0);
 ;HEAP32[$164+0>>2]=0|0;HEAP32[$164+4>>2]=0|0;HEAP32[$164+8>>2]=0|0;HEAP32[$164+12>>2]=0|0;HEAP32[$164+16>>2]=0|0;HEAP32[$164+20>>2]=0|0;
 $165 = (($decoder) + 76|0);
 HEAP32[$165>>2] = $138;
 $166 = (($138) + 92|0);
 $167 = HEAP32[$166>>2]|0;
 $168 = (($decoder) + 892|0);
 HEAP32[$168>>2] = $167;
 $169 = (($138) + 1308|0);
 $170 = HEAP32[$169>>2]|0;
 $171 = (($decoder) + 908|0);
 HEAP32[$171>>2] = $170;
 $172 = (($138) + 1368|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = ($173|0)==(1);
 if ($174) {
  $result$0$i$i = 0;
 } else {
  $175 = ($167>>>0)<(1240);
  if ($175) {
   $result$0$i$i = 107;
  } else {
   $176 = ($167>>>0)<(33900);
   $$$i$i = $176 ? 1131 : 32768;
   $result$0$i$i = $$$i$i;
  }
 }
 $177 = (($decoder) + 900|0);
 HEAP32[$177>>2] = $result$0$i$i;
 $178 = (($decoder) + 920|0);
 HEAP32[$178>>2] = $137;
 $179 = $load_flags$ & 256;
 $180 = ($179|0)==(0);
 if (!($180)) {
  $181 = (($decoder) + 753|0);
  HEAP8[$181>>0] = 1;
 }
 $182 = $load_flags$ & 1024;
 $183 = (($decoder) + 66|0);
 HEAP8[$183>>0] = 0;
 $184 = HEAP32[$2>>2]|0;
 $185 = (($184) + 1176|0);
 $186 = (_cff_index_access_element($185,$$01,$charstring,$charstring_len)|0);
 $187 = ($186|0)==(0);
 if (!($187)) {
  $$0 = $186;
  STACKTOP = sp;return ($$0|0);
 }
 $188 = HEAP32[$140>>2]|0;
 $189 = (($188) + 692|0);
 $190 = HEAP32[$189>>2]|0;
 $191 = (($190) + 1324|0);
 $192 = (($190) + 1896|0);
 $193 = HEAP32[$192>>2]|0;
 $194 = ($193|0)==(0);
 if ($194) {
  $sub$0$i = $191;
 } else {
  $195 = (($190) + 2924|0);
  $196 = (_cff_fd_select_get($195,$$01)|0);
  $197 = $196&255;
  $198 = HEAP32[$192>>2]|0;
  $199 = ($197>>>0)<($198>>>0);
  if (!($199)) {
   $$0 = 3;
   STACKTOP = sp;return ($$0|0);
  }
  $200 = (($190) + 1900|0);
  $201 = (($200) + ($197<<2)|0);
  $202 = HEAP32[$201>>2]|0;
  $203 = (($decoder) + 68|0);
  $204 = HEAP32[$203>>2]|0;
  $205 = ($204|0)==(0|0);
  $206 = ($size|0)==(0|0);
  $or$cond$i = $205 | $206;
  if ($or$cond$i) {
   $sub$0$i = $202;
  } else {
   $207 = (($size) + 40|0);
   $208 = HEAP32[$207>>2]|0;
   $209 = ((($208) + ($197<<2)|0) + 4|0);
   $210 = HEAP32[$209>>2]|0;
   $211 = (($decoder) + 72|0);
   HEAP32[$211>>2] = $210;
   $sub$0$i = $202;
  }
 }
 $212 = (($sub$0$i) + 544|0);
 $213 = HEAP32[$212>>2]|0;
 $214 = (($decoder) + 888|0);
 HEAP32[$214>>2] = $213;
 $215 = (($sub$0$i) + 568|0);
 $216 = HEAP32[$215>>2]|0;
 $217 = (($decoder) + 904|0);
 HEAP32[$217>>2] = $216;
 $218 = HEAP32[$165>>2]|0;
 $219 = (($218) + 1368|0);
 $220 = HEAP32[$219>>2]|0;
 $221 = ($220|0)==(1);
 if ($221) {
  $result$0$i$i11 = 0;
 } else {
  $222 = ($213>>>0)<(1240);
  if ($222) {
   $result$0$i$i11 = 107;
  } else {
   $223 = ($213>>>0)<(33900);
   $$$i$i10 = $223 ? 1131 : 32768;
   $result$0$i$i11 = $$$i$i10;
  }
 }
 $224 = (($decoder) + 896|0);
 HEAP32[$224>>2] = $result$0$i$i11;
 $225 = (($sub$0$i) + 528|0);
 $226 = HEAP32[$225>>2]|0;
 $227 = (($decoder) + 744|0);
 HEAP32[$227>>2] = $226;
 $228 = (($sub$0$i) + 532|0);
 $229 = HEAP32[$228>>2]|0;
 $230 = (($decoder) + 748|0);
 HEAP32[$230>>2] = $229;
 $231 = HEAP32[$charstring>>2]|0;
 $232 = HEAP32[$charstring_len>>2]|0;
 $233 = (_cff_decoder_parse_charstrings($decoder,$231,$232)|0);
 $234 = HEAP32[$2>>2]|0;
 $235 = (($234) + 1176|0);
 _cff_index_forget_element($235,$charstring);
 $236 = ($233|0)==(0);
 if (!($236)) {
  $$0 = $233;
  STACKTOP = sp;return ($$0|0);
 }
 $237 = (($3) + 1176|0);
 $238 = (($237) + 24|0);
 $239 = HEAP32[$238>>2]|0;
 $240 = ($239|0)==(0|0);
 if (!($240)) {
  $241 = (($237) + 28|0);
  $242 = HEAP32[$241>>2]|0;
  $243 = (($239) + ($$01<<2)|0);
  $244 = HEAP32[$243>>2]|0;
  $$sum = (($244) + -1)|0;
  $245 = (($242) + ($$sum)|0);
  $246 = (($glyph) + 136|0);
  HEAP32[$246>>2] = $245;
  $247 = HEAP32[$charstring_len>>2]|0;
  $248 = (($glyph) + 140|0);
  HEAP32[$248>>2] = $247;
 }
 $$idx8$val = HEAP32[$141>>2]|0;
 $249 = ($$idx8$val|0)==(0|0);
 if (!($249)) {
  $$idx9 = (($decoder) + 16|0);
  $$idx9$val = HEAP32[$$idx9>>2]|0;
  $250 = (($$idx8$val) + 108|0);
  ;HEAP32[$250+0>>2]=HEAP32[$$idx9$val+0>>2]|0;HEAP32[$250+4>>2]=HEAP32[$$idx9$val+4>>2]|0;HEAP32[$250+8>>2]=HEAP32[$$idx9$val+8>>2]|0;HEAP32[$250+12>>2]=HEAP32[$$idx9$val+12>>2]|0;HEAP32[$250+16>>2]=HEAP32[$$idx9$val+16>>2]|0;
 }
 $251 = ($182|0)==(0);
 if (!($251)) {
  $252 = (($glyph) + 156|0);
  $253 = HEAP32[$252>>2]|0;
  $254 = (($decoder) + 32|0);
  $255 = HEAP32[$254>>2]|0;
  $256 = (($glyph) + 32|0);
  HEAP32[$256>>2] = $255;
  $257 = HEAP32[$227>>2]|0;
  $258 = (($glyph) + 40|0);
  HEAP32[$258>>2] = $257;
  $259 = (($253) + 12|0);
  ;HEAP32[$259+0>>2]=HEAP32[$font_matrix+0>>2]|0;HEAP32[$259+4>>2]=HEAP32[$font_matrix+4>>2]|0;HEAP32[$259+8>>2]=HEAP32[$font_matrix+8>>2]|0;HEAP32[$259+12>>2]=HEAP32[$font_matrix+12>>2]|0;
  $260 = (($253) + 28|0);
  HEAP32[$260>>2] = $font_offset$sroa$0$0;
  $261 = (($253) + 32|0);
  HEAP32[$261>>2] = $font_offset$sroa$1$0;
  $262 = (($253) + 8|0);
  HEAP8[$262>>0] = 1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $263 = (($glyph) + 24|0);
 $264 = HEAP32[$227>>2]|0;
 $265 = (($glyph) + 40|0);
 HEAP32[$265>>2] = $264;
 $266 = (($glyph) + 56|0);
 HEAP32[$266>>2] = $264;
 $267 = (($glyph) + 156|0);
 $268 = HEAP32[$267>>2]|0;
 $269 = (($268) + 8|0);
 HEAP8[$269>>0] = 0;
 $270 = (($1) + 296|0);
 $271 = HEAP8[$270>>0]|0;
 $272 = ($271<<24>>24)==(0);
 if ($272) {
  label = 50;
 } else {
  $273 = (($1) + 300|0);
  $274 = (($273) + 34|0);
  $275 = HEAP16[$274>>1]|0;
  $276 = ($275<<16>>16)==(0);
  if ($276) {
   label = 50;
  } else {
   $277 = (($273) + 36|0);
   $278 = HEAP32[$277>>2]|0;
   $279 = ($278|0)==(0|0);
   if ($279) {
    label = 50;
   } else {
    HEAP16[$vertBearingY>>1] = 0;
    HEAP16[$vertAdvance>>1] = 0;
    $280 = (($1) + 532|0);
    $281 = HEAP32[$280>>2]|0;
    $282 = (($281) + 156|0);
    $283 = HEAP32[$282>>2]|0;
    (FUNCTION_TABLE_iiiiii[$283 & 255]($1,1,$$01,$vertBearingY,$vertAdvance)|0);
    $284 = HEAP16[$vertBearingY>>1]|0;
    $285 = $284 << 16 >> 16;
    $286 = (($glyph) + 48|0);
    HEAP32[$286>>2] = $285;
    $287 = HEAP16[$vertAdvance>>1]|0;
    $288 = $287&65535;
    $289 = (($glyph) + 52|0);
    HEAP32[$289>>2] = $288;
    $312 = $288;$381 = 1;
   }
  }
 }
 do {
  if ((label|0) == 50) {
   $290 = (($1) + 368|0);
   $291 = HEAP16[$290>>1]|0;
   $292 = ($291<<16>>16)==(-1);
   if ($292) {
    $301 = (($1) + 216|0);
    $302 = (($301) + 4|0);
    $303 = HEAP16[$302>>1]|0;
    $304 = $303 << 16 >> 16;
    $305 = (($301) + 6|0);
    $306 = HEAP16[$305>>1]|0;
    $307 = $306 << 16 >> 16;
    $308 = (($304) - ($307))|0;
    $309 = (($glyph) + 52|0);
    HEAP32[$309>>2] = $308;
    $312 = $308;$381 = 0;
    break;
   } else {
    $293 = (($290) + 70|0);
    $294 = HEAP16[$293>>1]|0;
    $295 = $294 << 16 >> 16;
    $296 = (($290) + 72|0);
    $297 = HEAP16[$296>>1]|0;
    $298 = $297 << 16 >> 16;
    $299 = (($295) - ($298))|0;
    $300 = (($glyph) + 52|0);
    HEAP32[$300>>2] = $299;
    $312 = $299;$381 = 0;
    break;
   }
  }
 } while(0);
 $310 = (($glyph) + 52|0);
 $311 = (($glyph) + 60|0);
 HEAP32[$311>>2] = $312;
 HEAP32[$135>>2] = 1869968492;
 $313 = (($glyph) + 124|0);
 HEAP32[$313>>2] = 0;
 if ($23) {
  $314 = (($size) + 14|0);
  $315 = HEAP16[$314>>1]|0;
  $316 = ($315&65535)<(24);
  if ($316) {
   HEAP32[$313>>2] = 256;
   $317 = 260;
  } else {
   $317 = 4;
  }
 } else {
  $317 = 4;
 }
 HEAP32[$313>>2] = $317;
 $318 = HEAP32[$font_matrix>>2]|0;
 $319 = ($318|0)==(65536);
 do {
  if ($319) {
   $320 = (($font_matrix) + 12|0);
   $321 = HEAP32[$320>>2]|0;
   $322 = ($321|0)==(65536);
   if ($322) {
    $323 = (($font_matrix) + 4|0);
    $324 = HEAP32[$323>>2]|0;
    $325 = ($324|0)==(0);
    if (!($325)) {
     label = 60;
     break;
    }
    $326 = (($font_matrix) + 8|0);
    $327 = HEAP32[$326>>2]|0;
    $328 = ($327|0)==(0);
    if (!($328)) {
     label = 60;
    }
   } else {
    label = 60;
   }
  } else {
   label = 60;
  }
 } while(0);
 if ((label|0) == 60) {
  _FT_Outline_Transform($129,$font_matrix);
 }
 $329 = $font_offset$sroa$1$0 | $font_offset$sroa$0$0;
 $330 = ($329|0)==(0);
 if (!($330)) {
  _FT_Outline_Translate($129,$font_offset$sroa$0$0,$font_offset$sroa$1$0);
 }
 $331 = HEAP32[$265>>2]|0;
 HEAP32[$advance>>2] = $331;
 $332 = (($advance) + 4|0);
 HEAP32[$332>>2] = 0;
 _FT_Vector_Transform($advance,$font_matrix);
 $333 = HEAP32[$advance>>2]|0;
 $334 = (($333) + ($font_offset$sroa$0$0))|0;
 HEAP32[$265>>2] = $334;
 HEAP32[$advance>>2] = 0;
 $335 = HEAP32[$310>>2]|0;
 HEAP32[$332>>2] = $335;
 _FT_Vector_Transform($advance,$font_matrix);
 $336 = HEAP32[$332>>2]|0;
 $337 = (($336) + ($font_offset$sroa$1$0))|0;
 HEAP32[$310>>2] = $337;
 $$not = $132 ^ 1;
 $338 = ($force_scaling$0|0)==(0);
 $or$cond6 = $338 & $$not;
 if (!($or$cond6)) {
  $339 = (($glyph) + 112|0);
  $340 = HEAP32[$339>>2]|0;
  $341 = HEAP32[$21>>2]|0;
  $342 = HEAP32[$22>>2]|0;
  $343 = ($156<<24>>24)==(0);
  if ($343) {
   label = 66;
  } else {
   $344 = (($decoder) + 68|0);
   $345 = HEAP32[$344>>2]|0;
   $346 = ($345|0)==(0|0);
   if ($346) {
    label = 66;
   }
  }
  do {
   if ((label|0) == 66) {
    $347 = HEAP16[$130>>1]|0;
    $348 = ($347<<16>>16)>(0);
    if (!($348)) {
     break;
    }
    $349 = $347 << 16 >> 16;
    $n$017 = $349;$vec$018 = $340;
    while(1) {
     $350 = HEAP32[$vec$018>>2]|0;
     $351 = (_FT_MulFix($350,$341)|0);
     HEAP32[$vec$018>>2] = $351;
     $352 = (($vec$018) + 4|0);
     $353 = HEAP32[$352>>2]|0;
     $354 = (_FT_MulFix($353,$342)|0);
     HEAP32[$352>>2] = $354;
     $355 = (($n$017) + -1)|0;
     $356 = (($vec$018) + 8|0);
     $357 = ($355|0)>(0);
     if ($357) {
      $n$017 = $355;$vec$018 = $356;
     } else {
      break;
     }
    }
   }
  } while(0);
  $358 = HEAP32[$265>>2]|0;
  $359 = (_FT_MulFix($358,$341)|0);
  HEAP32[$265>>2] = $359;
  $360 = HEAP32[$310>>2]|0;
  $361 = (_FT_MulFix($360,$342)|0);
  HEAP32[$310>>2] = $361;
 }
 _FT_Outline_Get_CBox($129,$cbox);
 $362 = (($cbox) + 8|0);
 $363 = HEAP32[$362>>2]|0;
 $364 = HEAP32[$cbox>>2]|0;
 $365 = (($363) - ($364))|0;
 HEAP32[$263>>2] = $365;
 $366 = (($cbox) + 12|0);
 $367 = HEAP32[$366>>2]|0;
 $368 = (($cbox) + 4|0);
 $369 = HEAP32[$368>>2]|0;
 $370 = (($367) - ($369))|0;
 $371 = (($glyph) + 28|0);
 HEAP32[$371>>2] = $370;
 $372 = (($glyph) + 32|0);
 HEAP32[$372>>2] = $364;
 $373 = (($glyph) + 36|0);
 HEAP32[$373>>2] = $367;
 if ($381) {
  $374 = HEAP32[$265>>2]|0;
  $375 = (($374|0) / 2)&-1;
  $376 = (($364) - ($375))|0;
  $377 = (($glyph) + 44|0);
  HEAP32[$377>>2] = $376;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $378 = $load_flags$ & 16;
 $379 = ($378|0)==(0);
 if ($379) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $380 = HEAP32[$310>>2]|0;
 _ft_synthesize_vertical_metrics($263,$380);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _cff_get_standard_encoding($charcode) {
 $charcode = $charcode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($charcode>>>0)<(256);
 if ($0) {
  $1 = (806888 + ($charcode<<1)|0);
  $2 = HEAP16[$1>>1]|0;
  $3 = $2;
 } else {
  $3 = 0;
 }
 STACKTOP = sp;return ($3|0);
}
function _cff_index_access_element($idx,$element,$pbytes,$pbyte_len) {
 $idx = $idx|0;
 $element = $element|0;
 $pbytes = $pbytes|0;
 $pbyte_len = $pbyte_len|0;
 var $$0 = 0, $$1 = 0, $$ph = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre23 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $nn$02$i = 0, $nn$02$i5 = 0, $off1$0 = 0, $off1$0$ph = 0, $off1$012 = 0, $off1$013 = 0, $off1$014 = 0, $off2$0 = 0, $off2$015 = 0, $off2$1 = 0, $or$cond = 0, $result$01$i = 0, $result$01$i6 = 0, $tmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmp$i = sp;
 $0 = ($idx|0)==(0|0);
 if ($0) {
  $93 = 6;
  STACKTOP = sp;return ($93|0);
 }
 $1 = (($idx) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>($element>>>0);
 if (!($3)) {
  $93 = 6;
  STACKTOP = sp;return ($93|0);
 }
 $4 = HEAP32[$idx>>2]|0;
 $5 = (($idx) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 L7: do {
  if ($7) {
   $8 = (($idx) + 12|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = $9&255;
   $11 = Math_imul($10, $element)|0;
   $12 = (($idx) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 3)|0;
   $15 = (($14) + ($11))|0;
   $16 = (_FT_Stream_Seek($4,$15)|0);
   $17 = ($16|0)==(0);
   if (!($17)) {
    $93 = $16;
    STACKTOP = sp;return ($93|0);
   }
   $18 = HEAP32[$idx>>2]|0;
   $19 = HEAP8[$8>>0]|0;
   $20 = $19&255;
   $21 = (_FT_Stream_Read($18,$tmp$i,$20)|0);
   $22 = ($21|0)==(0);
   if (!($22)) {
    $93 = $21;
    STACKTOP = sp;return ($93|0);
   }
   $23 = HEAP8[$8>>0]|0;
   $24 = ($23<<24>>24)==(0);
   if ($24) {
    label = 20;
   } else {
    $25 = $23&255;
    $nn$02$i = 0;$result$01$i = 0;
    while(1) {
     $26 = $result$01$i << 8;
     $27 = (($tmp$i) + ($nn$02$i)|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = $28&255;
     $30 = $29 | $26;
     $31 = (($nn$02$i) + 1)|0;
     $32 = ($31|0)<($25|0);
     if ($32) {
      $nn$02$i = $31;$result$01$i = $30;
     } else {
      break;
     }
    }
    $33 = ($30|0)==(0);
    if ($33) {
     label = 20;
    } else {
     $$0 = $element;$37 = $23;
     while(1) {
      $34 = (($$0) + 1)|0;
      $35 = HEAP32[$idx>>2]|0;
      $36 = $37&255;
      $38 = (_FT_Stream_Read($35,$tmp$i,$36)|0);
      $39 = ($38|0)==(0);
      if ($39) {
       $40 = HEAP8[$8>>0]|0;
       $41 = ($40<<24>>24)==(0);
       if (!($41)) {
        $42 = $40&255;
        $nn$02$i5 = 0;$result$01$i6 = 0;
        while(1) {
         $43 = $result$01$i6 << 8;
         $44 = (($tmp$i) + ($nn$02$i5)|0);
         $45 = HEAP8[$44>>0]|0;
         $46 = $45&255;
         $47 = $46 | $43;
         $48 = (($nn$02$i5) + 1)|0;
         $49 = ($48|0)<($42|0);
         if ($49) {
          $nn$02$i5 = $48;$result$01$i6 = $47;
         } else {
          break;
         }
        }
        $50 = ($47|0)==(0);
        if (!($50)) {
         $off1$0 = $30;$off2$0 = $47;
         label = 22;
         break L7;
        }
       }
      }
      $51 = HEAP32[$1>>2]|0;
      $52 = ($34>>>0)<($51>>>0);
      if (!($52)) {
       $$ph = $38;$off1$0$ph = $30;
       label = 21;
       break L7;
      }
      $$pre = HEAP8[$8>>0]|0;
      $$0 = $34;$37 = $$pre;
     }
    }
   }
  } else {
   $53 = (($6) + ($element<<2)|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($54|0)==(0);
   if ($55) {
    label = 20;
   } else {
    $$1 = $element;
    while(1) {
     $56 = (($$1) + 1)|0;
     $57 = (($6) + ($56<<2)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0);
     if (!($59)) {
      $off1$0 = $54;$off2$0 = $58;
      label = 22;
      break L7;
     }
     $60 = ($56>>>0)<($2>>>0);
     if ($60) {
      $$1 = $56;
     } else {
      $$ph = 0;$off1$0$ph = $54;
      label = 21;
      break;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 20) {
  $61 = (($4) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $72 = $62;$94 = 0;$off1$014 = 0;$off2$015 = 0;
  label = 24;
 }
 else if ((label|0) == 21) {
  $63 = (($4) + 4|0);
  $64 = HEAP32[$63>>2]|0;
  $72 = $64;$94 = $$ph;$off1$014 = $off1$0$ph;$off2$015 = 0;
  label = 24;
 }
 else if ((label|0) == 22) {
  $65 = (($4) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (($66) + 1)|0;
  $68 = ($off2$0>>>0)>($67>>>0);
  if ($68) {
   $$phi$trans$insert = (($idx) + 16|0);
   $$pre23 = HEAP32[$$phi$trans$insert>>2]|0;
   $76 = $66;$78 = $$pre23;$95 = 0;$off1$013 = $off1$0;
   label = 25;
  } else {
   $72 = $66;$94 = 0;$off1$014 = $off1$0;$off2$015 = $off2$0;
   label = 24;
  }
 }
 if ((label|0) == 24) {
  $69 = (($idx) + 16|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (($72) + 1)|0;
  $73 = (($71) - ($off2$015))|0;
  $74 = ($70>>>0)>($73>>>0);
  if ($74) {
   $76 = $72;$78 = $70;$95 = $94;$off1$013 = $off1$014;
   label = 25;
  } else {
   $96 = $94;$off1$012 = $off1$014;$off2$1 = $off2$015;
  }
 }
 if ((label|0) == 25) {
  $75 = (($76) + 1)|0;
  $77 = (($75) - ($78))|0;
  $96 = $95;$off1$012 = $off1$013;$off2$1 = $77;
 }
 $79 = ($off1$012|0)!=(0);
 $80 = ($off2$1>>>0)>($off1$012>>>0);
 $or$cond = $79 & $80;
 if (!($or$cond)) {
  HEAP32[$pbytes>>2] = 0;
  HEAP32[$pbyte_len>>2] = 0;
  $93 = $96;
  STACKTOP = sp;return ($93|0);
 }
 $81 = (($off2$1) - ($off1$012))|0;
 HEAP32[$pbyte_len>>2] = $81;
 $82 = (($idx) + 28|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($83|0)==(0|0);
 if (!($84)) {
  $$sum = (($off1$012) + -1)|0;
  $85 = (($83) + ($$sum)|0);
  HEAP32[$pbytes>>2] = $85;
  $93 = $96;
  STACKTOP = sp;return ($93|0);
 }
 $86 = (($idx) + 16|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (($off1$012) + -1)|0;
 $89 = (($88) + ($87))|0;
 $90 = (_FT_Stream_Seek($4,$89)|0);
 $91 = ($90|0)==(0);
 if (!($91)) {
  $93 = $90;
  STACKTOP = sp;return ($93|0);
 }
 $92 = (_FT_Stream_ExtractFrame($4,$81,$pbytes)|0);
 $93 = $92;
 STACKTOP = sp;return ($93|0);
}
function _cff_index_forget_element($idx,$pbytes) {
 $idx = $idx|0;
 $pbytes = $pbytes|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($idx) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$idx>>2]|0;
 _FT_Stream_ReleaseFrame($3,$pbytes);
 STACKTOP = sp;return;
}
function _cff_index_get_name($font,$element) {
 $font = $font|0;
 $element = $element|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $byte_len = 0, $bytes = 0, $error = 0;
 var $name$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $bytes = sp + 8|0;
 $byte_len = sp;
 $error = sp + 4|0;
 $0 = (($font) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_cff_index_access_element($0,$element,$bytes,$byte_len)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $name$0 = 0;
  STACKTOP = sp;return ($name$0|0);
 }
 $6 = HEAP32[$byte_len>>2]|0;
 $7 = (($6) + 1)|0;
 $8 = (_ft_mem_alloc($3,$7,$error)|0);
 $9 = HEAP32[$error>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = HEAP32[$bytes>>2]|0;
  _memcpy(($8|0),($11|0),($6|0))|0;
  $12 = (($8) + ($6)|0);
  HEAP8[$12>>0] = 0;
 }
 $13 = (($font) + 48|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $name$0 = $8;
  STACKTOP = sp;return ($name$0|0);
 }
 $16 = HEAP32[$0>>2]|0;
 _FT_Stream_ReleaseFrame($16,$bytes);
 $name$0 = $8;
 STACKTOP = sp;return ($name$0|0);
}
function _cff_index_get_string($font,$element) {
 $font = $font|0;
 $element = $element|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($font) + 1312|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($element>>>0);
 if (!($2)) {
  $7 = 0;
  STACKTOP = sp;return ($7|0);
 }
 $3 = (($font) + 1316|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($element<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function _cff_index_get_sid_string($font,$sid) {
 $font = $font|0;
 $sid = $sid|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($sid|0)==(65535);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = ($sid>>>0)>(390);
   if ($1) {
    $2 = (($sid) + -391)|0;
    $3 = (($font) + 1312|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($4>>>0)>($2>>>0);
    if (!($5)) {
     $$0 = 0;
     break;
    }
    $6 = (($font) + 1316|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + ($2<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $$0 = $9;
    break;
   } else {
    $10 = (($font) + 2956|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0 = 0;
     break;
    }
    $13 = (($11) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (FUNCTION_TABLE_ii[$14 & 4095]($sid)|0);
    $$0 = $15;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _cff_fd_select_get($fdselect,$glyph_index) {
 $fdselect = $fdselect|0;
 $glyph_index = $glyph_index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $fd$0 = 0, $first$0 = 0, $p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$fdselect>>0]|0;
 $1 = $0&255;
 if ((($1|0) == 0)) {
  $2 = (($fdselect) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + ($glyph_index)|0);
  $5 = HEAP8[$4>>0]|0;
  $fd$0 = $5;
  STACKTOP = sp;return ($fd$0|0);
 } else if ((($1|0) == 3)) {
  $6 = (($fdselect) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($glyph_index) - ($7))|0;
  $9 = (($fdselect) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8>>>0)<($10>>>0);
  if ($11) {
   $12 = (($fdselect) + 24|0);
   $13 = HEAP8[$12>>0]|0;
   $fd$0 = $13;
   STACKTOP = sp;return ($fd$0|0);
  }
  $14 = (($fdselect) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($fdselect) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + ($17)|0);
  $19 = (($15) + 2|0);
  $20 = HEAP8[$15>>0]|0;
  $21 = $20&255;
  $22 = $21 << 8;
  $23 = (($15) + 1|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = $22 | $25;
  $first$0 = $26;$p$0 = $19;
  while(1) {
   $27 = ($first$0>>>0)>($glyph_index>>>0);
   if ($27) {
    $fd$0 = 0;
    label = 10;
    break;
   }
   $28 = HEAP8[$p$0>>0]|0;
   $29 = (($p$0) + 3|0);
   $30 = (($p$0) + 1|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = $31&255;
   $33 = $32 << 8;
   $34 = (($p$0) + 2|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = $33 | $36;
   $38 = ($37>>>0)>($glyph_index>>>0);
   if ($38) {
    label = 8;
    break;
   }
   $41 = ($29>>>0)<($18>>>0);
   if ($41) {
    $first$0 = $37;$p$0 = $29;
   } else {
    $fd$0 = 0;
    label = 10;
    break;
   }
  }
  if ((label|0) == 8) {
   HEAP32[$6>>2] = $first$0;
   $39 = (($37) - ($first$0))|0;
   HEAP32[$9>>2] = $39;
   $40 = (($fdselect) + 24|0);
   HEAP8[$40>>0] = $28;
   $fd$0 = $28;
   STACKTOP = sp;return ($fd$0|0);
  }
  else if ((label|0) == 10) {
   STACKTOP = sp;return ($fd$0|0);
  }
 } else {
  $fd$0 = 0;
  STACKTOP = sp;return ($fd$0|0);
 }
 return 0|0;
}
function _cff_charset_cid_to_gindex($charset,$cid) {
 $charset = $charset|0;
 $cid = $cid|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($charset) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($cid>>>0);
 if ($2) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $3 = (($charset) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($cid<<1)|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6&65535;
 $result$0 = $7;
 STACKTOP = sp;return ($result$0|0);
}
function _cff_font_load($library,$stream,$face_index,$font,$pure_cff) {
 $library = $library|0;
 $stream = $stream|0;
 $face_index = $face_index|0;
 $font = $font|0;
 $pure_cff = $pure_cff|0;
 var $$max_cid$0$i$i = 0, $$max_cid$0$i$i13 = 0, $$nleft$0$i = 0, $$ph = 0, $$pr$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i7 = 0, $$pre$phi$i23Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi36$iZ2D = 0, $$pre14$i = 0, $$pre33$i = 0, $$pre34$i = 0, $$pre35$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $byte_len$i = 0, $bytes$i = 0, $error = 0, $error$i24 = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i$i14 = 0, $exitcond$i6 = 0, $exitcond10$i = 0, $exitcond26$i = 0, $exitcond27$i = 0, $fd_index = 0, $gindex$03$us$i = 0, $glyph_code$011$i = 0, $glyph_sid$03$i = 0, $i$017$i = 0, $i$04$i$i = 0, $i$04$i$i12 = 0, $i$05$i = 0;
 var $idx$037 = 0, $idx$135 = 0, $j$0$i$i = 0, $j$0$i$i21 = 0, $j$01$i = 0, $j$01$i$i = 0, $j$01$i$i17 = 0, $j$02$i$i = 0, $j$02$i$i20 = 0, $j$025$i = 0, $j$17$i = 0, $j$18$i = 0, $j$2$lcssa$i = 0, $j$216$i = 0, $j$24$i = 0, $j$35$i = 0, $j$35$us$i = 0, $j$422$i = 0, $k$012$i = 0, $max_cid$0$lcssa$i$i15 = 0;
 var $max_cid$05$i$i = 0, $max_cid$05$i$i11 = 0, $name$0$i = 0, $nleft$0$i = 0, $or$cond$i = 0, $p$08$i = 0, $phitmp = 0, $phitmp$i = 0, $phitmp44 = 0, $string_index = 0, $umax$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $bytes$i = sp + 80|0;
 $byte_len$i = sp;
 $error$i24 = sp + 4|0;
 $error = sp + 8|0;
 $string_index = sp + 16|0;
 $fd_index = sp + 48|0;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 _memset(($font|0),0,2972)|0;
 ;HEAP32[$string_index+0>>2]=0|0;HEAP32[$string_index+4>>2]=0|0;HEAP32[$string_index+8>>2]=0|0;HEAP32[$string_index+12>>2]=0|0;HEAP32[$string_index+16>>2]=0|0;HEAP32[$string_index+20>>2]=0|0;HEAP32[$string_index+24>>2]=0|0;HEAP32[$string_index+28>>2]=0|0;
 HEAP32[$font>>2] = $stream;
 $2 = (($font) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = (($font) + 1324|0);
 $4 = (_FT_Stream_Pos($stream)|0);
 $5 = (_FT_Stream_ReadFields($stream,807400,$font)|0);
 HEAP32[$error>>2] = $5;
 $6 = ($5|0)==(0);
 L1: do {
  if ($6) {
   $7 = (($font) + 16|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(1);
   if ($9) {
    $10 = (($font) + 18|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11&255;
    $13 = ($11&255)<(4);
    if (!($13)) {
     $14 = (($font) + 19|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = ($15&255)>(4);
     if (!($16)) {
      $17 = (($12) + -4)|0;
      $18 = (_FT_Stream_Skip($stream,$17)|0);
      HEAP32[$error>>2] = $18;
      $19 = ($18|0)==(0);
      if (!($19)) {
       break;
      }
      $20 = (($font) + 20|0);
      $21 = (_cff_index_init($20,$stream,0)|0);
      HEAP32[$error>>2] = $21;
      $22 = ($21|0)==(0);
      if (!($22)) {
       break;
      }
      $23 = (($font) + 1208|0);
      $24 = (_cff_index_init($23,$stream,0)|0);
      HEAP32[$error>>2] = $24;
      $25 = ($24|0)==(0);
      if (!($25)) {
       break;
      }
      $26 = (_cff_index_init($string_index,$stream,1)|0);
      HEAP32[$error>>2] = $26;
      $27 = ($26|0)==(0);
      if (!($27)) {
       break;
      }
      $28 = (($font) + 84|0);
      $29 = (_cff_index_init($28,$stream,1)|0);
      HEAP32[$error>>2] = $29;
      $30 = ($29|0)==(0);
      if (!($30)) {
       break;
      }
      $31 = (($font) + 1316|0);
      $32 = (($font) + 1320|0);
      $33 = (_cff_index_get_pointers($string_index,$31,$32)|0);
      HEAP32[$error>>2] = $33;
      $34 = ($33|0)==(0);
      if (!($34)) {
       break;
      }
      $35 = (($string_index) + 8|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($font) + 1312|0);
      HEAP32[$37>>2] = $36;
      $38 = (($font) + 28|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = (($font) + 8|0);
      HEAP32[$40>>2] = $39;
      $41 = ($39|0)>($face_index|0);
      if (!($41)) {
       HEAP32[$error>>2] = 6;
      }
      $42 = ($face_index|0)<(0);
      if ($42) {
       break;
      }
      $43 = (_cff_subfont_load($3,$23,$face_index,$stream,$4,$library)|0);
      HEAP32[$error>>2] = $43;
      $44 = ($43|0)==(0);
      if (!($44)) {
       break;
      }
      $45 = (($font) + 1436|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = (($46) + ($4))|0;
      $48 = (_FT_Stream_Seek($stream,$47)|0);
      HEAP32[$error>>2] = $48;
      $49 = ($48|0)==(0);
      if (!($49)) {
       break;
      }
      $50 = (($font) + 1176|0);
      $51 = (_cff_index_init($50,$stream,0)|0);
      HEAP32[$error>>2] = $51;
      $52 = ($51|0)==(0);
      if (!($52)) {
       break;
      }
      $53 = (($font) + 1456|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($54|0)==(65535);
      if ($55) {
       $119 = (($font) + 1896|0);
       HEAP32[$119>>2] = 0;
      } else {
       $56 = (($font) + 1488|0);
       $57 = HEAP32[$56>>2]|0;
       $58 = (($57) + ($4))|0;
       $59 = (_FT_Stream_Seek($stream,$58)|0);
       HEAP32[$error>>2] = $59;
       $60 = ($59|0)==(0);
       if (!($60)) {
        break;
       }
       $61 = (_cff_index_init($fd_index,$stream,0)|0);
       HEAP32[$error>>2] = $61;
       $62 = ($61|0)==(0);
       if (!($62)) {
        break;
       }
       $63 = (($fd_index) + 8|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = ($64>>>0)>(256);
       L24: do {
        if ($65) {
         $425 = 0;
        } else {
         $66 = (($font) + 1896|0);
         HEAP32[$66>>2] = $64;
         $67 = (_ft_mem_realloc($1,572,0,$64,0,$error)|0);
         $68 = HEAP32[$error>>2]|0;
         $69 = ($68|0)==(0);
         if (!($69)) {
          $425 = $68;
          break;
         }
         $70 = HEAP32[$63>>2]|0;
         $71 = ($70|0)==(0);
         do {
          if (!($71)) {
           $idx$037 = 0;
           while(1) {
            $72 = (($67) + (($idx$037*572)|0)|0);
            $73 = ((($font) + ($idx$037<<2)|0) + 1900|0);
            HEAP32[$73>>2] = $72;
            $74 = (($idx$037) + 1)|0;
            $75 = ($74>>>0)<($70>>>0);
            if ($75) {
             $idx$037 = $74;
            } else {
             break;
            }
           }
           $phitmp44 = ($70|0)==(0);
           if ($phitmp44) {
            break;
           } else {
            $idx$135 = 0;
           }
           while(1) {
            $79 = ((($font) + ($idx$135<<2)|0) + 1900|0);
            $80 = HEAP32[$79>>2]|0;
            $81 = (_cff_subfont_load($80,$fd_index,$idx$135,$stream,$4,$library)|0);
            HEAP32[$error>>2] = $81;
            $82 = ($81|0)==(0);
            $78 = (($idx$135) + 1)|0;
            if (!($82)) {
             $425 = $81;
             break L24;
            }
            $76 = HEAP32[$63>>2]|0;
            $77 = ($78>>>0)<($76>>>0);
            if ($77) {
             $idx$135 = $78;
            } else {
             break;
            }
           }
          }
         } while(0);
         $83 = (($font) + 1184|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = (($font) + 1492|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = (($86) + ($4))|0;
         $88 = (_FT_Stream_Seek($stream,$87)|0);
         HEAP32[$bytes$i>>2] = $88;
         $89 = ($88|0)==(0);
         do {
          if ($89) {
           $90 = (_FT_Stream_ReadChar($stream,$bytes$i)|0);
           $91 = HEAP32[$bytes$i>>2]|0;
           $92 = ($91|0)==(0);
           if (!($92)) {
            $107 = $91;
            break;
           }
           $93 = (($font) + 2924|0);
           HEAP8[$93>>0] = $90;
           $94 = (($font) + 2944|0);
           HEAP32[$94>>2] = 0;
           $95 = $90&255;
           if ((($95|0) == 0)) {
            $96 = (($font) + 2936|0);
            HEAP32[$96>>2] = $84;
            $105 = $84;
           } else if ((($95|0) == 3)) {
            $97 = (_FT_Stream_ReadUShort($stream,$bytes$i)|0);
            $98 = HEAP32[$bytes$i>>2]|0;
            $99 = ($98|0)==(0);
            if (!($99)) {
             $107 = $98;
             break;
            }
            $100 = $97&65535;
            $101 = ($100*3)|0;
            $102 = (($101) + 2)|0;
            $103 = (($font) + 2936|0);
            HEAP32[$103>>2] = $102;
            $105 = $102;
           } else {
            HEAP32[$bytes$i>>2] = 3;
            $107 = 3;
            break;
           }
           $104 = (($font) + 2932|0);
           $106 = (_FT_Stream_ExtractFrame($stream,$105,$104)|0);
           HEAP32[$bytes$i>>2] = $106;
           $107 = $106;
          } else {
           $107 = $88;
          }
         } while(0);
         HEAP32[$error>>2] = $107;
         $425 = $107;
        }
       } while(0);
       $108 = HEAP32[$fd_index>>2]|0;
       $109 = ($108|0)==(0|0);
       if ($109) {
        $118 = $425;
       } else {
        $110 = (($108) + 28|0);
        $111 = HEAP32[$110>>2]|0;
        $112 = (($fd_index) + 28|0);
        $113 = HEAP32[$112>>2]|0;
        $114 = ($113|0)==(0|0);
        if (!($114)) {
         _FT_Stream_ReleaseFrame($108,$112);
        }
        $115 = (($fd_index) + 24|0);
        $116 = HEAP32[$115>>2]|0;
        _ft_mem_free($111,$116);
        ;HEAP32[$fd_index+0>>2]=0|0;HEAP32[$fd_index+4>>2]=0|0;HEAP32[$fd_index+8>>2]=0|0;HEAP32[$fd_index+12>>2]=0|0;HEAP32[$fd_index+16>>2]=0|0;HEAP32[$fd_index+20>>2]=0|0;HEAP32[$fd_index+24>>2]=0|0;HEAP32[$fd_index+28>>2]=0|0;
        $$pre = HEAP32[$error>>2]|0;
        $118 = $$pre;
       }
       $117 = ($118|0)==(0);
       if (!($117)) {
        break;
       }
      }
      $120 = HEAP32[$45>>2]|0;
      $121 = ($120|0)==(0);
      if ($121) {
       HEAP32[$error>>2] = 2;
       break;
      }
      $122 = (($font) + 1184|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = (($font) + 12|0);
      HEAP32[$124>>2] = $123;
      $125 = (($font) + 1308|0);
      $126 = (_cff_index_get_pointers($28,$125,0)|0);
      HEAP32[$error>>2] = $126;
      $127 = ($126|0)==(0);
      if (!($127)) {
       break;
      }
      $128 = HEAP32[$124>>2]|0;
      $129 = ($128|0)==(0);
      L58: do {
       if (!($129)) {
        $130 = HEAP32[$53>>2]|0;
        $131 = ($130|0)==(65535);
        if ($131) {
         $210 = 0;
        } else {
         $132 = ($pure_cff<<24>>24)!=(0);
         $phitmp = $132&1;
         $210 = $phitmp;
        }
        $133 = (($font) + 1152|0);
        $134 = (($font) + 1428|0);
        $135 = HEAP32[$134>>2]|0;
        $136 = HEAP32[$0>>2]|0;
        HEAP32[$byte_len$i>>2] = 0;
        $137 = ($135>>>0)>(2);
        L63: do {
         if ($137) {
          $138 = (($135) + ($4))|0;
          $139 = (($font) + 1156|0);
          HEAP32[$139>>2] = $138;
          $140 = (_FT_Stream_Seek($stream,$138)|0);
          HEAP32[$byte_len$i>>2] = $140;
          $141 = ($140|0)==(0);
          if (!($141)) {
           $$pre$phi$iZ2D = $139;
           label = 97;
           break;
          }
          $142 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
          $143 = $142&255;
          HEAP32[$133>>2] = $143;
          $144 = HEAP32[$byte_len$i>>2]|0;
          $145 = ($144|0)==(0);
          if (!($145)) {
           $$pre$phi$iZ2D = $139;
           label = 97;
           break;
          }
          $146 = (_ft_mem_realloc($136,2,0,$128,0,$byte_len$i)|0);
          $147 = (($font) + 1160|0);
          HEAP32[$147>>2] = $146;
          $148 = HEAP32[$byte_len$i>>2]|0;
          $149 = ($148|0)==(0);
          if (!($149)) {
           $$pre$phi$iZ2D = $139;
           label = 97;
           break;
          }
          HEAP16[$146>>1] = 0;
          $150 = HEAP32[$133>>2]|0;
          if ((($150|0) == 2) | (($150|0) == 1)) {
           $151 = ($128>>>0)>(1);
           if ($151) {
            $j$18$i = 1;
           } else {
            label = 83;
            break;
           }
           while(1) {
            $163 = (_FT_Stream_ReadUShort($stream,$byte_len$i)|0);
            $164 = HEAP32[$byte_len$i>>2]|0;
            $165 = ($164|0)==(0);
            if (!($165)) {
             $$pre$phi$iZ2D = $139;
             label = 97;
             break L63;
            }
            $166 = HEAP32[$133>>2]|0;
            $167 = ($166|0)==(2);
            if ($167) {
             $168 = (_FT_Stream_ReadUShort($stream,$byte_len$i)|0);
             $169 = $168&65535;
             $170 = HEAP32[$byte_len$i>>2]|0;
             $171 = ($170|0)==(0);
             if ($171) {
              $nleft$0$i = $169;
             } else {
              $$pre$phi$iZ2D = $139;
              label = 97;
              break L63;
             }
            } else {
             $172 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
             $173 = $172&255;
             $174 = HEAP32[$byte_len$i>>2]|0;
             $175 = ($174|0)==(0);
             if ($175) {
              $nleft$0$i = $173;
             } else {
              $$pre$phi$iZ2D = $139;
              label = 97;
              break L63;
             }
            }
            $176 = $163&65535;
            $177 = ($j$18$i>>>0)<($128>>>0);
            if ($177) {
             $178 = $nleft$0$i ^ 65535;
             $179 = $176 ^ 65535;
             $180 = ($176>>>0)>($178>>>0);
             $$nleft$0$i = $180 ? $179 : $nleft$0$i;
             $181 = HEAP32[$147>>2]|0;
             $182 = (($j$18$i) - ($128))|0;
             $183 = $$nleft$0$i ^ -1;
             $184 = ($182>>>0)>($183>>>0);
             $umax$i = $184 ? $182 : $183;
             $185 = (0 - ($umax$i))|0;
             $glyph_sid$03$i = $163;$i$05$i = 0;$j$24$i = $j$18$i;
             while(1) {
              $186 = (($181) + ($j$24$i<<1)|0);
              HEAP16[$186>>1] = $glyph_sid$03$i;
              $187 = (($i$05$i) + 1)|0;
              $188 = (($j$24$i) + 1)|0;
              $189 = (($glyph_sid$03$i) + 1)<<16>>16;
              $exitcond10$i = ($187|0)==($185|0);
              if ($exitcond10$i) {
               break;
              } else {
               $glyph_sid$03$i = $189;$i$05$i = $187;$j$24$i = $188;
              }
             }
             $161 = (($j$18$i) - ($umax$i))|0;
             $j$2$lcssa$i = $161;
            } else {
             $j$2$lcssa$i = $j$18$i;
            }
            $162 = ($j$2$lcssa$i>>>0)<($128>>>0);
            if ($162) {
             $j$18$i = $j$2$lcssa$i;
            } else {
             label = 83;
             break;
            }
           }
          } else if ((($150|0) == 0)) {
           $152 = $128 << 1;
           $153 = (($152) + -2)|0;
           $154 = (_FT_Stream_EnterFrame($stream,$153)|0);
           HEAP32[$byte_len$i>>2] = $154;
           $155 = ($154|0)==(0);
           if (!($155)) {
            $$pre$phi$iZ2D = $139;
            label = 97;
            break;
           }
           $156 = ($128>>>0)>(1);
           if ($156) {
            $j$01$i = 1;
            while(1) {
             $157 = (_FT_Stream_GetUShort($stream)|0);
             $158 = HEAP32[$147>>2]|0;
             $159 = (($158) + ($j$01$i<<1)|0);
             HEAP16[$159>>1] = $157;
             $160 = (($j$01$i) + 1)|0;
             $exitcond$i = ($160|0)==($128|0);
             if ($exitcond$i) {
              break;
             } else {
              $j$01$i = $160;
             }
            }
           }
           _FT_Stream_ExitFrame($stream);
           label = 83;
           break;
          } else {
           HEAP32[$byte_len$i>>2] = 3;
           $$pre$phi$iZ2D = $139;
           label = 97;
           break;
          }
         } else {
          $190 = (($font) + 1156|0);
          HEAP32[$190>>2] = $135;
          if ((($135|0) == 1)) {
           $197 = ($128>>>0)>(166);
           if ($197) {
            HEAP32[$byte_len$i>>2] = 3;
            $$pre$phi$iZ2D = $190;
            label = 97;
            break;
           }
           $198 = (_ft_mem_realloc($136,2,0,$128,0,$byte_len$i)|0);
           $199 = (($font) + 1160|0);
           HEAP32[$199>>2] = $198;
           $200 = HEAP32[$byte_len$i>>2]|0;
           $201 = ($200|0)==(0);
           if (!($201)) {
            $$pre$phi$iZ2D = $190;
            label = 97;
            break;
           }
           $202 = $128 << 1;
           _memcpy(($198|0),(808400|0),($202|0))|0;
           label = 83;
           break;
          } else if ((($135|0) == 2)) {
           $203 = ($128>>>0)>(87);
           if ($203) {
            HEAP32[$byte_len$i>>2] = 3;
            $$pre$phi$iZ2D = $190;
            label = 97;
            break;
           }
           $204 = (_ft_mem_realloc($136,2,0,$128,0,$byte_len$i)|0);
           $205 = (($font) + 1160|0);
           HEAP32[$205>>2] = $204;
           $206 = HEAP32[$byte_len$i>>2]|0;
           $207 = ($206|0)==(0);
           if (!($207)) {
            $$pre$phi$iZ2D = $190;
            label = 97;
            break;
           }
           $208 = $128 << 1;
           _memcpy(($204|0),(808736|0),($208|0))|0;
           label = 83;
           break;
          } else if ((($135|0) == 0)) {
           $191 = ($128>>>0)>(229);
           if ($191) {
            HEAP32[$byte_len$i>>2] = 3;
            $$pre$phi$iZ2D = $190;
            label = 97;
            break;
           }
           $192 = (_ft_mem_realloc($136,2,0,$128,0,$byte_len$i)|0);
           $193 = (($font) + 1160|0);
           HEAP32[$193>>2] = $192;
           $194 = HEAP32[$byte_len$i>>2]|0;
           $195 = ($194|0)==(0);
           if (!($195)) {
            $$pre$phi$iZ2D = $190;
            label = 97;
            break;
           }
           $196 = $128 << 1;
           _memcpy(($192|0),(807936|0),($196|0))|0;
           label = 83;
           break;
          } else {
           HEAP32[$byte_len$i>>2] = 3;
           $$pre$phi$iZ2D = $190;
           label = 97;
           break;
          }
         }
        } while(0);
        do {
         if ((label|0) == 83) {
          $209 = ($210<<24>>24)==(0);
          if ($209) {
           $$pr$i = HEAP32[$byte_len$i>>2]|0;
           $238 = $$pr$i;
          } else {
           HEAP32[$bytes$i>>2] = 0;
           $211 = (($font) + 1168|0);
           $212 = HEAP32[$211>>2]|0;
           $213 = ($212|0)==(0);
           do {
            if ($213) {
             $214 = (($font) + 1160|0);
             $215 = HEAP32[$214>>2]|0;
             $i$04$i$i = 0;$max_cid$05$i$i = 0;
             while(1) {
              $216 = (($215) + ($i$04$i$i<<1)|0);
              $217 = HEAP16[$216>>1]|0;
              $218 = ($217&65535)>($max_cid$05$i$i&65535);
              $$max_cid$0$i$i = $218 ? $217 : $max_cid$05$i$i;
              $219 = (($i$04$i$i) + 1)|0;
              $exitcond$i$i = ($219|0)==($128|0);
              if ($exitcond$i$i) {
               break;
              } else {
               $i$04$i$i = $219;$max_cid$05$i$i = $$max_cid$0$i$i;
              }
             }
             $220 = $$max_cid$0$i$i&65535;
             $221 = (($220) + 1)|0;
             $222 = (_ft_mem_realloc($136,2,0,$221,0,$bytes$i)|0);
             $223 = (($font) + 1164|0);
             HEAP32[$223>>2] = $222;
             $224 = HEAP32[$bytes$i>>2]|0;
             $225 = ($224|0)==(0);
             if (!($225)) {
              $236 = $224;
              break;
             }
             $j$01$i$i = (($128) + -1)|0;
             $226 = ($j$01$i$i|0)>(-1);
             if ($226) {
              $227 = (($font) + 1160|0);
              $228 = HEAP32[$227>>2]|0;
              $j$02$i$i = $j$01$i$i;
              while(1) {
               $229 = $j$02$i$i&65535;
               $230 = (($228) + ($j$02$i$i<<1)|0);
               $231 = HEAP16[$230>>1]|0;
               $232 = $231&65535;
               $233 = (($222) + ($232<<1)|0);
               HEAP16[$233>>1] = $229;
               $j$0$i$i = (($j$02$i$i) + -1)|0;
               $234 = ($j$0$i$i|0)>(-1);
               if ($234) {
                $j$02$i$i = $j$0$i$i;
               } else {
                break;
               }
              }
             }
             HEAP32[$211>>2] = $220;
             $235 = (($font) + 1172|0);
             HEAP32[$235>>2] = $128;
             $236 = 0;
            } else {
             $236 = 0;
            }
           } while(0);
           HEAP32[$byte_len$i>>2] = $236;
           $238 = $236;
          }
          $237 = ($238|0)==(0);
          if ($237) {
           HEAP32[$error>>2] = 0;
           break;
          } else {
           $$pre14$i = (($font) + 1156|0);
           $$pre$phi$iZ2D = $$pre14$i;
           label = 97;
           break;
          }
         }
        } while(0);
        if ((label|0) == 97) {
         $239 = (($font) + 1160|0);
         $240 = HEAP32[$239>>2]|0;
         _ft_mem_free($136,$240);
         HEAP32[$239>>2] = 0;
         $241 = (($font) + 1164|0);
         $242 = HEAP32[$241>>2]|0;
         _ft_mem_free($136,$242);
         HEAP32[$241>>2] = 0;
         HEAP32[$133>>2] = 0;
         HEAP32[$$pre$phi$iZ2D>>2] = 0;
         HEAP32[$239>>2] = 0;
         $$pre$i = HEAP32[$byte_len$i>>2]|0;
         HEAP32[$error>>2] = $$pre$i;
         $243 = ($$pre$i|0)==(0);
         if (!($243)) {
          break L1;
         }
        }
        $244 = HEAP32[$53>>2]|0;
        $245 = ($244|0)==(65535);
        if (!($245)) {
         break;
        }
        $246 = HEAP32[$124>>2]|0;
        $247 = (($font) + 1432|0);
        $248 = HEAP32[$247>>2]|0;
        HEAP32[$byte_len$i>>2] = 0;
        $249 = (($font) + 1160|0);
        $250 = HEAP32[$249>>2]|0;
        $251 = ($250|0)==(0|0);
        L133: do {
         if ($251) {
          HEAP32[$byte_len$i>>2] = 3;
          $$ph = 3;
         } else {
          $j$025$i = 0;
          while(1) {
           $252 = ((($font) + ($j$025$i<<1)|0) + 128|0);
           HEAP16[$252>>1] = 0;
           $253 = ((($font) + ($j$025$i<<1)|0) + 640|0);
           HEAP16[$253>>1] = 0;
           $254 = (($j$025$i) + 1)|0;
           $exitcond27$i = ($254|0)==(256);
           if ($exitcond27$i) {
            break;
           } else {
            $j$025$i = $254;
           }
          }
          $255 = ($248>>>0)>(1);
          L137: do {
           if ($255) {
            $256 = (($248) + ($4))|0;
            $257 = (($font) + 120|0);
            HEAP32[$257>>2] = $256;
            $258 = (_FT_Stream_Seek($stream,$256)|0);
            HEAP32[$byte_len$i>>2] = $258;
            $259 = ($258|0)==(0);
            if (!($259)) {
             $$ph = $258;
             break L133;
            }
            $260 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
            $261 = $260&255;
            $262 = (($font) + 116|0);
            HEAP32[$262>>2] = $261;
            $263 = HEAP32[$byte_len$i>>2]|0;
            $264 = ($263|0)==(0);
            if (!($264)) {
             $$ph = $263;
             break L133;
            }
            $265 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
            $266 = $265&255;
            $267 = HEAP32[$byte_len$i>>2]|0;
            $268 = ($267|0)==(0);
            if (!($268)) {
             $$ph = $267;
             break L133;
            }
            $269 = HEAP32[$262>>2]|0;
            $270 = $269 & 127;
            do {
             if ((($270|0) == 0)) {
              $271 = (($266) + 1)|0;
              $272 = (($font) + 124|0);
              HEAP32[$272>>2] = $271;
              $273 = (_FT_Stream_EnterFrame($stream,$266)|0);
              HEAP32[$byte_len$i>>2] = $273;
              $274 = ($273|0)==(0);
              if (!($274)) {
               $$ph = $273;
               break L133;
              }
              $275 = ($265<<24>>24)==(0);
              if (!($275)) {
               $276 = (($stream) + 32|0);
               $277 = HEAP32[$276>>2]|0;
               $j$17$i = 1;$p$08$i = $277;
               while(1) {
                $278 = (($p$08$i) + 1|0);
                $279 = HEAP8[$p$08$i>>0]|0;
                $280 = $279&255;
                $281 = ($j$17$i>>>0)<($246>>>0);
                if ($281) {
                 $282 = $j$17$i&65535;
                 $283 = ((($font) + ($280<<1)|0) + 640|0);
                 HEAP16[$283>>1] = $282;
                 $284 = HEAP32[$249>>2]|0;
                 $285 = (($284) + ($j$17$i<<1)|0);
                 $286 = HEAP16[$285>>1]|0;
                 $287 = ((($font) + ($280<<1)|0) + 128|0);
                 HEAP16[$287>>1] = $286;
                }
                $288 = (($j$17$i) + 1)|0;
                $289 = ($288>>>0)>($266>>>0);
                if ($289) {
                 break;
                } else {
                 $j$17$i = $288;$p$08$i = $278;
                }
               }
              }
              _FT_Stream_ExitFrame($stream);
             } else if ((($270|0) == 1)) {
              $290 = (($font) + 124|0);
              HEAP32[$290>>2] = 0;
              $291 = ($265<<24>>24)==(0);
              if ($291) {
               break;
              } else {
               $i$017$i = 1;$j$216$i = 0;
              }
              while(1) {
               $292 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
               $293 = $292&255;
               $294 = HEAP32[$byte_len$i>>2]|0;
               $295 = ($294|0)==(0);
               if (!($295)) {
                $$ph = $294;
                break L133;
               }
               $296 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
               $297 = HEAP32[$byte_len$i>>2]|0;
               $298 = ($297|0)==(0);
               if (!($298)) {
                $$ph = $297;
                break L133;
               }
               $299 = $296&255;
               $300 = (($299) + 1)|0;
               $301 = HEAP32[$290>>2]|0;
               $302 = ($300>>>0)>($301>>>0);
               if ($302) {
                HEAP32[$290>>2] = $300;
               }
               $303 = (($300) + ($i$017$i))|0;
               $304 = ($i$017$i>>>0)<($303>>>0);
               if ($304) {
                $305 = (($i$017$i) + 1)|0;
                $306 = (($305) + ($299))|0;
                $glyph_code$011$i = $293;$k$012$i = $i$017$i;
                while(1) {
                 $307 = ($k$012$i>>>0)<($246>>>0);
                 $308 = ($glyph_code$011$i>>>0)<(256);
                 $or$cond$i = $307 & $308;
                 if ($or$cond$i) {
                  $309 = $k$012$i&65535;
                  $310 = ((($font) + ($glyph_code$011$i<<1)|0) + 640|0);
                  HEAP16[$310>>1] = $309;
                  $311 = HEAP32[$249>>2]|0;
                  $312 = (($311) + ($k$012$i<<1)|0);
                  $313 = HEAP16[$312>>1]|0;
                  $314 = ((($font) + ($glyph_code$011$i<<1)|0) + 128|0);
                  HEAP16[$314>>1] = $313;
                 }
                 $315 = (($k$012$i) + 1)|0;
                 $316 = (($glyph_code$011$i) + 1)|0;
                 $exitcond$i6 = ($315|0)==($306|0);
                 if ($exitcond$i6) {
                  break;
                 } else {
                  $glyph_code$011$i = $316;$k$012$i = $315;
                 }
                }
               }
               $317 = (($j$216$i) + 1)|0;
               $318 = ($317>>>0)<($266>>>0);
               if ($318) {
                $i$017$i = $303;$j$216$i = $317;
               } else {
                break;
               }
              }
              $$pre$i7 = HEAP32[$290>>2]|0;
              $phitmp$i = ($$pre$i7>>>0)>(256);
              if (!($phitmp$i)) {
               break;
              }
              HEAP32[$290>>2] = 256;
             } else {
              HEAP32[$byte_len$i>>2] = 3;
              $$ph = 3;
              break L133;
             }
            } while(0);
            $319 = HEAP32[$262>>2]|0;
            $320 = $319 & 128;
            $321 = ($320|0)==(0);
            if ($321) {
             $$pre33$i = HEAP32[$byte_len$i>>2]|0;
             HEAP32[$error>>2] = $$pre33$i;
             $397 = ($$pre33$i|0)==(0);
             if ($397) {
              break L58;
             } else {
              break L1;
             }
            }
            $322 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
            $323 = $322&255;
            $324 = HEAP32[$byte_len$i>>2]|0;
            $325 = ($324|0)==(0);
            if (!($325)) {
             $$ph = $324;
             break L133;
            }
            $326 = ($322<<24>>24)==(0);
            if ($326) {
             break;
            }
            $327 = ($246|0)==(0);
            if ($327) {
             $j$35$i = 0;
             while(1) {
              $346 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
              $347 = $346&255;
              $348 = HEAP32[$byte_len$i>>2]|0;
              $349 = ($348|0)==(0);
              if (!($349)) {
               $$ph = $348;
               break L133;
              }
              $350 = (_FT_Stream_ReadUShort($stream,$byte_len$i)|0);
              $351 = HEAP32[$byte_len$i>>2]|0;
              $352 = ($351|0)==(0);
              if (!($352)) {
               $$ph = $351;
               break L133;
              }
              $353 = ((($font) + ($347<<1)|0) + 128|0);
              HEAP16[$353>>1] = $350;
              $354 = (($j$35$i) + 1)|0;
              $355 = ($354>>>0)<($323>>>0);
              if ($355) {
               $j$35$i = $354;
              } else {
               break L137;
              }
             }
            } else {
             $j$35$us$i = 0;
            }
            while(1) {
             $328 = (_FT_Stream_ReadChar($stream,$byte_len$i)|0);
             $329 = $328&255;
             $330 = HEAP32[$byte_len$i>>2]|0;
             $331 = ($330|0)==(0);
             if (!($331)) {
              $$ph = $330;
              break L133;
             }
             $332 = (_FT_Stream_ReadUShort($stream,$byte_len$i)|0);
             $333 = HEAP32[$byte_len$i>>2]|0;
             $334 = ($333|0)==(0);
             if (!($334)) {
              $$ph = $333;
              break L133;
             }
             $345 = ((($font) + ($329<<1)|0) + 128|0);
             HEAP16[$345>>1] = $332;
             $338 = HEAP32[$249>>2]|0;
             $gindex$03$us$i = 0;
             while(1) {
              $337 = (($338) + ($gindex$03$us$i<<1)|0);
              $339 = HEAP16[$337>>1]|0;
              $340 = ($339<<16>>16)==($332<<16>>16);
              $336 = (($gindex$03$us$i) + 1)|0;
              if ($340) {
               label = 136;
               break;
              }
              $335 = ($336>>>0)<($246>>>0);
              if ($335) {
               $gindex$03$us$i = $336;
              } else {
               break;
              }
             }
             if ((label|0) == 136) {
              label = 0;
              $341 = $gindex$03$us$i&65535;
              $342 = ((($font) + ($329<<1)|0) + 640|0);
              HEAP16[$342>>1] = $341;
             }
             $343 = (($j$35$us$i) + 1)|0;
             $344 = ($343>>>0)<($323>>>0);
             if ($344) {
              $j$35$us$i = $343;
             } else {
              break;
             }
            }
           } else {
            if ((($248|0) == 1)) {
             $357 = (($font) + 128|0);
             _memcpy(($357|0),(807424|0),512)|0;
            } else if ((($248|0) == 0)) {
             $356 = (($font) + 128|0);
             _memcpy(($356|0),(806888|0),512)|0;
            } else {
             HEAP32[$byte_len$i>>2] = 3;
             $$ph = 3;
             break L133;
            }
            $358 = (($font) + 124|0);
            HEAP32[$358>>2] = 0;
            $359 = HEAP32[$0>>2]|0;
            HEAP32[$bytes$i>>2] = 0;
            $360 = (($font) + 1168|0);
            $361 = HEAP32[$360>>2]|0;
            $362 = ($361|0)==(0);
            if ($362) {
             $363 = ($246|0)==(0);
             if ($363) {
              $max_cid$0$lcssa$i$i15 = 0;
             } else {
              $364 = HEAP32[$249>>2]|0;
              $i$04$i$i12 = 0;$max_cid$05$i$i11 = 0;
              while(1) {
               $365 = (($364) + ($i$04$i$i12<<1)|0);
               $366 = HEAP16[$365>>1]|0;
               $367 = ($366&65535)>($max_cid$05$i$i11&65535);
               $$max_cid$0$i$i13 = $367 ? $366 : $max_cid$05$i$i11;
               $368 = (($i$04$i$i12) + 1)|0;
               $exitcond$i$i14 = ($368|0)==($246|0);
               if ($exitcond$i$i14) {
                $max_cid$0$lcssa$i$i15 = $$max_cid$0$i$i13;
                break;
               } else {
                $i$04$i$i12 = $368;$max_cid$05$i$i11 = $$max_cid$0$i$i13;
               }
              }
             }
             $369 = $max_cid$0$lcssa$i$i15&65535;
             $370 = (($369) + 1)|0;
             $371 = (_ft_mem_realloc($359,2,0,$370,0,$bytes$i)|0);
             $372 = (($font) + 1164|0);
             HEAP32[$372>>2] = $371;
             $373 = HEAP32[$bytes$i>>2]|0;
             $374 = ($373|0)==(0);
             if (!($374)) {
              HEAP32[$byte_len$i>>2] = $373;
              $$ph = $373;
              break L133;
             }
             $j$01$i$i17 = (($246) + -1)|0;
             $375 = ($j$01$i$i17|0)>(-1);
             if ($375) {
              $376 = HEAP32[$249>>2]|0;
              $j$02$i$i20 = $j$01$i$i17;
              while(1) {
               $377 = $j$02$i$i20&65535;
               $378 = (($376) + ($j$02$i$i20<<1)|0);
               $379 = HEAP16[$378>>1]|0;
               $380 = $379&65535;
               $381 = (($371) + ($380<<1)|0);
               HEAP16[$381>>1] = $377;
               $j$0$i$i21 = (($j$02$i$i20) + -1)|0;
               $382 = ($j$0$i$i21|0)>(-1);
               if ($382) {
                $j$02$i$i20 = $j$0$i$i21;
               } else {
                break;
               }
              }
             }
             HEAP32[$360>>2] = $369;
             $383 = (($font) + 1172|0);
             HEAP32[$383>>2] = $246;
             $$pre$phi36$iZ2D = $372;
            } else {
             $$pre35$i = (($font) + 1164|0);
             $$pre$phi36$iZ2D = $$pre35$i;
            }
            HEAP32[$byte_len$i>>2] = 0;
            $j$422$i = 0;
            while(1) {
             $384 = ((($font) + ($j$422$i<<1)|0) + 128|0);
             $385 = HEAP16[$384>>1]|0;
             $386 = ($385<<16>>16)==(0);
             do {
              if ($386) {
               label = 161;
              } else {
               $387 = $385&65535;
               $388 = HEAP32[$360>>2]|0;
               $389 = ($388>>>0)<($387>>>0);
               if ($389) {
                label = 161;
                break;
               }
               $390 = HEAP32[$$pre$phi36$iZ2D>>2]|0;
               $391 = (($390) + ($387<<1)|0);
               $392 = HEAP16[$391>>1]|0;
               $393 = ($392<<16>>16)==(0);
               if ($393) {
                label = 161;
                break;
               }
               $394 = ((($font) + ($j$422$i<<1)|0) + 640|0);
               HEAP16[$394>>1] = $392;
               $395 = (($j$422$i) + 1)|0;
               HEAP32[$358>>2] = $395;
               $$pre$phi$i23Z2D = $395;
              }
             } while(0);
             if ((label|0) == 161) {
              label = 0;
              $396 = ((($font) + ($j$422$i<<1)|0) + 640|0);
              HEAP16[$396>>1] = 0;
              HEAP16[$384>>1] = 0;
              $$pre34$i = (($j$422$i) + 1)|0;
              $$pre$phi$i23Z2D = $$pre34$i;
             }
             $exitcond26$i = ($$pre$phi$i23Z2D|0)==(256);
             if ($exitcond26$i) {
              break;
             } else {
              $j$422$i = $$pre$phi$i23Z2D;
             }
            }
           }
          } while(0);
          HEAP32[$error>>2] = 0;
          break L58;
         }
        } while(0);
        HEAP32[$error>>2] = $$ph;
        break L1;
       }
      } while(0);
      $398 = HEAP32[$20>>2]|0;
      $399 = (($398) + 28|0);
      $400 = HEAP32[$399>>2]|0;
      $401 = (_cff_index_access_element($20,$face_index,$bytes$i,$byte_len$i)|0);
      HEAP32[$error$i24>>2] = $401;
      $402 = ($401|0)==(0);
      do {
       if ($402) {
        $403 = HEAP32[$byte_len$i>>2]|0;
        $404 = (($403) + 1)|0;
        $405 = (_ft_mem_alloc($400,$404,$error$i24)|0);
        $406 = HEAP32[$error$i24>>2]|0;
        $407 = ($406|0)==(0);
        if ($407) {
         $408 = HEAP32[$bytes$i>>2]|0;
         _memcpy(($405|0),($408|0),($403|0))|0;
         $409 = (($405) + ($403)|0);
         HEAP8[$409>>0] = 0;
        }
        $410 = (($font) + 48|0);
        $411 = HEAP32[$410>>2]|0;
        $412 = ($411|0)==(0|0);
        if (!($412)) {
         $name$0$i = $405;
         break;
        }
        $413 = HEAP32[$20>>2]|0;
        _FT_Stream_ReleaseFrame($413,$bytes$i);
        $name$0$i = $405;
       } else {
        $name$0$i = 0;
       }
      } while(0);
      $414 = (($font) + 1304|0);
      HEAP32[$414>>2] = $name$0$i;
      break;
     }
    }
   }
   HEAP32[$error>>2] = 2;
  }
 } while(0);
 $415 = HEAP32[$string_index>>2]|0;
 $416 = ($415|0)==(0|0);
 if ($416) {
  $424 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($424|0);
 }
 $417 = (($415) + 28|0);
 $418 = HEAP32[$417>>2]|0;
 $419 = (($string_index) + 28|0);
 $420 = HEAP32[$419>>2]|0;
 $421 = ($420|0)==(0|0);
 if (!($421)) {
  _FT_Stream_ReleaseFrame($415,$419);
 }
 $422 = (($string_index) + 24|0);
 $423 = HEAP32[$422>>2]|0;
 _ft_mem_free($418,$423);
 ;HEAP32[$string_index+0>>2]=0|0;HEAP32[$string_index+4>>2]=0|0;HEAP32[$string_index+8>>2]=0|0;HEAP32[$string_index+12>>2]=0|0;HEAP32[$string_index+16>>2]=0|0;HEAP32[$string_index+20>>2]=0|0;HEAP32[$string_index+24>>2]=0|0;HEAP32[$string_index+28>>2]=0|0;
 $424 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($424|0);
}
function _cff_index_init($idx,$stream,$load) {
 $idx = $idx|0;
 $stream = $stream|0;
 $load = $load|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $nn$02$i = 0, $or$cond = 0, $result$01$i = 0, $storemerge = 0, $tmp$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmp$i = sp + 4|0;
 $error = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$idx+0>>2]=0|0;HEAP32[$idx+4>>2]=0|0;HEAP32[$idx+8>>2]=0|0;HEAP32[$idx+12>>2]=0|0;HEAP32[$idx+16>>2]=0|0;HEAP32[$idx+20>>2]=0|0;HEAP32[$idx+24>>2]=0|0;HEAP32[$idx+28>>2]=0|0;
 HEAP32[$idx>>2] = $stream;
 $2 = (_FT_Stream_Pos($stream)|0);
 $3 = (($idx) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (_FT_Stream_ReadUShort($stream,$error)|0);
 $5 = HEAP32[$error>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $7 = $4&65535;
   $8 = ($4<<16>>16)==(0);
   if ($8) {
    $52 = 0;
    STACKTOP = sp;return ($52|0);
   }
   $9 = (_FT_Stream_ReadChar($stream,$error)|0);
   $10 = HEAP32[$error>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    $12 = $9&255;
    $13 = ($9<<24>>24)==(0);
    $14 = ($9&255)>(4);
    $or$cond = $13 | $14;
    if ($or$cond) {
     HEAP32[$error>>2] = 8;
     break;
    }
    $15 = (($idx) + 8|0);
    HEAP32[$15>>2] = $7;
    $16 = (($idx) + 12|0);
    HEAP8[$16>>0] = $9;
    $17 = (($7) + 1)|0;
    $18 = Math_imul($12, $17)|0;
    $19 = HEAP32[$3>>2]|0;
    $20 = (($18) + 3)|0;
    $21 = (($20) + ($19))|0;
    $22 = (($idx) + 16|0);
    HEAP32[$22>>2] = $21;
    $23 = (($18) - ($12))|0;
    $24 = (_FT_Stream_Skip($stream,$23)|0);
    HEAP32[$error>>2] = $24;
    $25 = ($24|0)==(0);
    if ($25) {
     $26 = HEAP32[$idx>>2]|0;
     $27 = HEAP8[$16>>0]|0;
     $28 = $27&255;
     $29 = (_FT_Stream_Read($26,$tmp$i,$28)|0);
     $30 = ($29|0)==(0);
     if (!($30)) {
      HEAP32[$error>>2] = $29;
      break;
     }
     $31 = HEAP8[$16>>0]|0;
     $32 = ($31<<24>>24)==(0);
     if ($32) {
      HEAP32[$error>>2] = $29;
     } else {
      $33 = $31&255;
      $nn$02$i = 0;$result$01$i = 0;
      while(1) {
       $34 = $result$01$i << 8;
       $35 = (($tmp$i) + ($nn$02$i)|0);
       $36 = HEAP8[$35>>0]|0;
       $37 = $36&255;
       $38 = $37 | $34;
       $39 = (($nn$02$i) + 1)|0;
       $40 = ($39|0)<($33|0);
       if ($40) {
        $nn$02$i = $39;$result$01$i = $38;
       } else {
        break;
       }
      }
      HEAP32[$error>>2] = $29;
      if (!($30)) {
       break;
      }
      $41 = ($38|0)==(0);
      if (!($41)) {
       $42 = (($38) + -1)|0;
       $43 = (($idx) + 20|0);
       HEAP32[$43>>2] = $42;
       $44 = ($load<<24>>24)==(0);
       if ($44) {
        $47 = (_FT_Stream_Skip($stream,$42)|0);
        $49 = $47;$storemerge = $47;
       } else {
        $45 = (($idx) + 28|0);
        $46 = (_FT_Stream_ExtractFrame($stream,$42,$45)|0);
        $49 = $46;$storemerge = $46;
       }
       HEAP32[$error>>2] = $storemerge;
       $48 = ($49|0)==(0);
       if ($48) {
        $52 = 0;
       } else {
        break;
       }
       STACKTOP = sp;return ($52|0);
      }
     }
     HEAP32[$error>>2] = 8;
    }
   }
  }
 } while(0);
 $50 = (($idx) + 24|0);
 $51 = HEAP32[$50>>2]|0;
 _ft_mem_free($1,$51);
 HEAP32[$50>>2] = 0;
 $$pre = HEAP32[$error>>2]|0;
 $52 = $$pre;
 STACKTOP = sp;return ($52|0);
}
function _cff_index_get_pointers($idx,$table,$pool) {
 $idx = $idx|0;
 $table = $table|0;
 $pool = $pool|0;
 var $$ = 0, $$pr$pre$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $$pre14 = 0, $$sum$us = 0, $$sum$us18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $cur_offset$03 = 0, $cur_offset$03$us = 0, $error = 0, $error$i = 0, $extra$04$us = 0, $extra$1$us = 0, $n$02 = 0, $n$02$us = 0, $new_bytes$0 = 0, $new_bytes$0$ = 0, $next_offset$0 = 0, $next_offset$0$us19 = 0, $or$cond = 0, $or$cond$us = 0, $or$cond1 = 0, $or$cond1$us = 0, $p$05$i = 0, $p$110$i = 0, $p$215$i = 0, $p$31$i = 0;
 var $phitmp$i = 0, $poff$06$i = 0, $poff$111$i = 0, $poff$216$i = 0, $poff$32$i = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp + 4|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = HEAP32[$idx>>2]|0;
 $1 = (($0) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$table>>2] = 0;
 $3 = (($idx) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 L1: do {
  if ($5) {
   HEAP32[$error$i>>2] = 0;
   $6 = HEAP32[$idx>>2]|0;
   $7 = (($6) + 28|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($idx) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   do {
    if (!($11)) {
     $12 = (($idx) + 12|0);
     $13 = HEAP8[$12>>0]|0;
     $14 = (($10) + 1)|0;
     $15 = $13&255;
     $16 = Math_imul($15, $14)|0;
     $17 = (_ft_mem_realloc($8,4,0,$14,0,$error$i)|0);
     HEAP32[$3>>2] = $17;
     $18 = HEAP32[$error$i>>2]|0;
     $19 = ($18|0)==(0);
     if ($19) {
      $20 = (($idx) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($21) + 3)|0;
      $23 = (_FT_Stream_Seek($6,$22)|0);
      HEAP32[$error$i>>2] = $23;
      $24 = ($23|0)==(0);
      if ($24) {
       $25 = (_FT_Stream_EnterFrame($6,$16)|0);
       HEAP32[$error$i>>2] = $25;
       $26 = ($25|0)==(0);
       if ($26) {
        $27 = HEAP32[$3>>2]|0;
        $28 = (($6) + 32|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = (($29) + ($16)|0);
        if ((($15|0) == 2)) {
         $32 = ($16|0)>(0);
         if ($32) {
          $p$110$i = $29;$poff$111$i = $27;
          while(1) {
           $40 = HEAP8[$p$110$i>>0]|0;
           $41 = $40&255;
           $42 = $41 << 8;
           $43 = (($p$110$i) + 1|0);
           $44 = HEAP8[$43>>0]|0;
           $45 = $44&255;
           $46 = $42 | $45;
           HEAP32[$poff$111$i>>2] = $46;
           $47 = (($p$110$i) + 2|0);
           $48 = (($poff$111$i) + 4|0);
           $49 = ($47>>>0)<($30>>>0);
           if ($49) {
            $p$110$i = $47;$poff$111$i = $48;
           } else {
            break;
           }
          }
         }
        } else if ((($15|0) == 1)) {
         $33 = ($16|0)>(0);
         if ($33) {
          $p$05$i = $29;$poff$06$i = $27;
          while(1) {
           $35 = HEAP8[$p$05$i>>0]|0;
           $36 = $35&255;
           HEAP32[$poff$06$i>>2] = $36;
           $37 = (($p$05$i) + 1|0);
           $38 = (($poff$06$i) + 4|0);
           $39 = ($37>>>0)<($30>>>0);
           if ($39) {
            $p$05$i = $37;$poff$06$i = $38;
           } else {
            break;
           }
          }
         }
        } else if ((($15|0) == 3)) {
         $31 = ($16|0)>(0);
         if ($31) {
          $p$215$i = $29;$poff$216$i = $27;
          while(1) {
           $50 = HEAP8[$p$215$i>>0]|0;
           $51 = $50 << 24 >> 24;
           $52 = $51 << 16;
           $53 = (($p$215$i) + 1|0);
           $54 = HEAP8[$53>>0]|0;
           $55 = $54&255;
           $56 = $55 << 8;
           $57 = $56 | $52;
           $58 = (($p$215$i) + 2|0);
           $59 = HEAP8[$58>>0]|0;
           $60 = $59&255;
           $61 = $57 | $60;
           HEAP32[$poff$216$i>>2] = $61;
           $62 = (($p$215$i) + 3|0);
           $63 = (($poff$216$i) + 4|0);
           $64 = ($62>>>0)<($30>>>0);
           if ($64) {
            $p$215$i = $62;$poff$216$i = $63;
           } else {
            break;
           }
          }
         }
        } else {
         $34 = ($16|0)>(0);
         if ($34) {
          $p$31$i = $29;$poff$32$i = $27;
          while(1) {
           $65 = HEAP8[$p$31$i>>0]|0;
           $66 = $65&255;
           $67 = $66 << 24;
           $68 = (($p$31$i) + 1|0);
           $69 = HEAP8[$68>>0]|0;
           $70 = $69&255;
           $71 = $70 << 16;
           $72 = $71 | $67;
           $73 = (($p$31$i) + 2|0);
           $74 = HEAP8[$73>>0]|0;
           $75 = $74&255;
           $76 = $75 << 8;
           $77 = $72 | $76;
           $78 = (($p$31$i) + 3|0);
           $79 = HEAP8[$78>>0]|0;
           $80 = $79&255;
           $81 = $77 | $80;
           HEAP32[$poff$32$i>>2] = $81;
           $82 = (($p$31$i) + 4|0);
           $83 = (($poff$32$i) + 4|0);
           $84 = ($82>>>0)<($30>>>0);
           if ($84) {
            $p$31$i = $82;$poff$32$i = $83;
           } else {
            break;
           }
          }
         }
        }
        _FT_Stream_ExitFrame($6);
        $$pr$pre$i = HEAP32[$error$i>>2]|0;
        $phitmp$i = ($$pr$pre$i|0)==(0);
        if ($phitmp$i) {
         break;
        }
       }
      }
     }
     $85 = HEAP32[$3>>2]|0;
     _ft_mem_free($8,$85);
     HEAP32[$3>>2] = 0;
     $$pre$i = HEAP32[$error$i>>2]|0;
     HEAP32[$error>>2] = $$pre$i;
     $86 = ($$pre$i|0)==(0);
     if ($86) {
      $$pre$phiZ2D = $9;
      break L1;
     }
     $151 = HEAP32[$error>>2]|0;
     STACKTOP = sp;return ($151|0);
    }
   } while(0);
   HEAP32[$error>>2] = 0;
   $$pre$phiZ2D = $9;
  } else {
   $$pre14 = (($idx) + 8|0);
   $$pre$phiZ2D = $$pre14;
  }
 } while(0);
 $87 = HEAP32[$$pre$phiZ2D>>2]|0;
 $88 = ($87|0)==(0);
 if ($88) {
  $151 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($151|0);
 }
 $89 = (($87) + 1)|0;
 $90 = (_ft_mem_realloc($2,4,0,$89,0,$error)|0);
 $91 = HEAP32[$error>>2]|0;
 $92 = ($91|0)==(0);
 if (!($92)) {
  $151 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($151|0);
 }
 $93 = ($pool|0)!=(0|0);
 $94 = (($idx) + 20|0);
 if ($93) {
  $95 = HEAP32[$94>>2]|0;
  $96 = HEAP32[$$pre$phiZ2D>>2]|0;
  $97 = (($96) + ($95))|0;
  $98 = (_ft_mem_alloc($2,$97,$error)|0);
  $99 = HEAP32[$error>>2]|0;
  $100 = ($99|0)==(0);
  if ($100) {
   $new_bytes$0 = $98;
  } else {
   $151 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($151|0);
  }
 } else {
  $new_bytes$0 = 0;
 }
 $101 = (($idx) + 28|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = HEAP32[$3>>2]|0;
 $104 = HEAP32[$103>>2]|0;
 $105 = (($104) + -1)|0;
 $106 = HEAP32[$94>>2]|0;
 $107 = ($105>>>0)>=($106>>>0);
 $$ = $107 ? 0 : $105;
 $new_bytes$0$ = $93 ? $new_bytes$0 : $102;
 $storemerge = (($new_bytes$0$) + ($$)|0);
 HEAP32[$90>>2] = $storemerge;
 $108 = HEAP32[$$pre$phiZ2D>>2]|0;
 $109 = ($108|0)==(0);
 L38: do {
  if (!($109)) {
   if ($93) {
    $119 = $108;$cur_offset$03$us = $$;$extra$04$us = 0;$n$02$us = 1;
   } else {
    $cur_offset$03 = $$;$n$02 = 1;
    while(1) {
     $139 = HEAP32[$3>>2]|0;
     $140 = (($139) + ($n$02<<2)|0);
     $141 = HEAP32[$140>>2]|0;
     $142 = (($141) + -1)|0;
     $143 = ($142|0)==(0);
     $144 = ($142>>>0)<($cur_offset$03>>>0);
     $or$cond = $143 | $144;
     if ($or$cond) {
      label = 33;
     } else {
      $145 = ($142>>>0)>=($106>>>0);
      $146 = ($n$02>>>0)<($108>>>0);
      $or$cond1 = $145 & $146;
      if ($or$cond1) {
       label = 33;
      } else {
       $next_offset$0 = $142;
      }
     }
     if ((label|0) == 33) {
      label = 0;
      $next_offset$0 = $cur_offset$03;
     }
     $147 = (($102) + ($next_offset$0)|0);
     $148 = (($90) + ($n$02<<2)|0);
     HEAP32[$148>>2] = $147;
     $149 = (($n$02) + 1)|0;
     $150 = ($149>>>0)>($108>>>0);
     if ($150) {
      break L38;
     } else {
      $cur_offset$03 = $next_offset$0;$n$02 = $149;
     }
    }
   }
   while(1) {
    $110 = HEAP32[$3>>2]|0;
    $111 = (($110) + ($n$02$us<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($112) + -1)|0;
    $114 = ($113|0)==(0);
    $115 = ($113>>>0)<($cur_offset$03$us>>>0);
    $or$cond$us = $114 | $115;
    if ($or$cond$us) {
     label = 27;
    } else {
     $116 = HEAP32[$94>>2]|0;
     $117 = ($113>>>0)>=($116>>>0);
     $118 = ($n$02$us>>>0)<($119>>>0);
     $or$cond1$us = $117 & $118;
     if ($or$cond1$us) {
      label = 27;
     } else {
      $$sum$us = (($113) + ($extra$04$us))|0;
      $122 = (($new_bytes$0) + ($$sum$us)|0);
      $123 = (($90) + ($n$02$us<<2)|0);
      HEAP32[$123>>2] = $122;
      $124 = ($113|0)==($cur_offset$03$us|0);
      if ($124) {
       $138 = $119;$extra$1$us = $extra$04$us;$next_offset$0$us19 = $113;
      } else {
       $125 = (($n$02$us) + -1)|0;
       $126 = (($90) + ($125<<2)|0);
       $127 = HEAP32[$126>>2]|0;
       $128 = (($102) + ($cur_offset$03$us)|0);
       $129 = $122;
       $130 = $127;
       $131 = (($129) - ($130))|0;
       _memcpy(($127|0),($128|0),($131|0))|0;
       $132 = HEAP32[$123>>2]|0;
       HEAP8[$132>>0] = 0;
       $133 = HEAP32[$123>>2]|0;
       $134 = (($133) + 1|0);
       HEAP32[$123>>2] = $134;
       $135 = (($extra$04$us) + 1)|0;
       $$pre = HEAP32[$$pre$phiZ2D>>2]|0;
       $138 = $$pre;$extra$1$us = $135;$next_offset$0$us19 = $113;
      }
     }
    }
    if ((label|0) == 27) {
     label = 0;
     $$sum$us18 = (($cur_offset$03$us) + ($extra$04$us))|0;
     $120 = (($new_bytes$0) + ($$sum$us18)|0);
     $121 = (($90) + ($n$02$us<<2)|0);
     HEAP32[$121>>2] = $120;
     $138 = $119;$extra$1$us = $extra$04$us;$next_offset$0$us19 = $cur_offset$03$us;
    }
    $136 = (($n$02$us) + 1)|0;
    $137 = ($136>>>0)>($138>>>0);
    if ($137) {
     break;
    } else {
     $119 = $138;$cur_offset$03$us = $next_offset$0$us19;$extra$04$us = $extra$1$us;$n$02$us = $136;
    }
   }
  }
 } while(0);
 HEAP32[$table>>2] = $90;
 if (!($93)) {
  $151 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($151|0);
 }
 HEAP32[$pool>>2] = $new_bytes$0;
 $151 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($151|0);
}
function _cff_subfont_load($font,$idx,$font_index,$stream,$base_offset,$library) {
 $font = $font|0;
 $idx = $idx|0;
 $font_index = $font_index|0;
 $stream = $stream|0;
 $base_offset = $base_offset|0;
 $library = $library|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $dict = 0, $dict_len = 0, $error$0 = 0, $error$2 = 0, $parser = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $parser = sp + 8|0;
 $dict = sp;
 $dict_len = sp + 4|0;
 HEAP32[$dict>>2] = 0;
 _cff_parser_init($parser,4096,$font,$library);
 _memset(($font|0),0,172)|0;
 $0 = (($font) + 32|0);
 HEAP32[$0>>2] = -6553600;
 $1 = (($font) + 36|0);
 HEAP32[$1>>2] = 3276800;
 $2 = (($font) + 44|0);
 HEAP32[$2>>2] = 2;
 $3 = (($font) + 48|0);
 HEAP32[$3>>2] = 65536;
 $4 = (($font) + 60|0);
 HEAP32[$4>>2] = 65536;
 $5 = (($font) + 156|0);
 HEAP32[$5>>2] = 8720;
 HEAP32[$font>>2] = 65535;
 $6 = (($font) + 4|0);
 HEAP32[$6>>2] = 65535;
 $7 = (($font) + 8|0);
 HEAP32[$7>>2] = 65535;
 $8 = (($font) + 12|0);
 HEAP32[$8>>2] = 65535;
 $9 = (($font) + 16|0);
 HEAP32[$9>>2] = 65535;
 $10 = (($font) + 20|0);
 HEAP32[$10>>2] = 65535;
 $11 = (($font) + 128|0);
 HEAP32[$11>>2] = 65535;
 $12 = (($font) + 132|0);
 HEAP32[$12>>2] = 65535;
 $13 = (($font) + 136|0);
 HEAP32[$13>>2] = 65535;
 $14 = (($font) + 172|0);
 HEAP32[$14>>2] = 65535;
 $15 = (_cff_index_access_element($idx,$font_index,$dict,$dict_len)|0);
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = HEAP32[$dict>>2]|0;
  $18 = HEAP32[$dict_len>>2]|0;
  $19 = (($17) + ($18)|0);
  $20 = (_cff_parser_run($parser,$17,$19)|0);
  $error$0 = $20;
 } else {
  $error$0 = $15;
 }
 $21 = (($idx) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $24 = HEAP32[$idx>>2]|0;
  _FT_Stream_ReleaseFrame($24,$dict);
 }
 $25 = ($error$0|0)==(0);
 if (!($25)) {
  $error$2 = $error$0;
  STACKTOP = sp;return ($error$2|0);
 }
 $26 = HEAP32[$12>>2]|0;
 $27 = ($26|0)==(65535);
 if (!($27)) {
  $error$2 = 0;
  STACKTOP = sp;return ($error$2|0);
 }
 $28 = (($font) + 116|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 do {
  if (!($30)) {
   $31 = (($font) + 120|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0);
   if (!($33)) {
    $34 = (($font) + 176|0);
    _memset(($34|0),0,360)|0;
    $35 = (($font) + 376|0);
    HEAP32[$35>>2] = 7;
    $36 = (($font) + 380|0);
    HEAP32[$36>>2] = 1;
    $37 = (($font) + 508|0);
    HEAP32[$37>>2] = -1;
    $38 = (($font) + 516|0);
    HEAP32[$38>>2] = 3932;
    $39 = (($font) + 372|0);
    HEAP32[$39>>2] = 2596864;
    _cff_parser_init($parser,8192,$34,$library);
    $40 = HEAP32[$28>>2]|0;
    $41 = (($40) + ($base_offset))|0;
    $42 = (_FT_Stream_Seek($stream,$41)|0);
    $43 = ($42|0)==(0);
    if (!($43)) {
     $error$2 = $42;
     STACKTOP = sp;return ($error$2|0);
    }
    $44 = HEAP32[$31>>2]|0;
    $45 = (_FT_Stream_EnterFrame($stream,$44)|0);
    $46 = ($45|0)==(0);
    if (!($46)) {
     $error$2 = $45;
     STACKTOP = sp;return ($error$2|0);
    }
    $47 = (($stream) + 32|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($stream) + 36|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (_cff_parser_run($parser,$48,$50)|0);
    _FT_Stream_ExitFrame($stream);
    $52 = ($51|0)==(0);
    if ($52) {
     $53 = HEAP8[$34>>0]|0;
     $54 = $53&255;
     $55 = $54 & 254;
     $56 = $55&255;
     HEAP8[$34>>0] = $56;
     break;
    } else {
     $error$2 = $51;
     STACKTOP = sp;return ($error$2|0);
    }
   }
  }
 } while(0);
 $57 = (($font) + 524|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0);
 if ($59) {
  $error$2 = 0;
  STACKTOP = sp;return ($error$2|0);
 }
 $60 = HEAP32[$28>>2]|0;
 $61 = (($58) + ($base_offset))|0;
 $62 = (($61) + ($60))|0;
 $63 = (_FT_Stream_Seek($stream,$62)|0);
 $64 = ($63|0)==(0);
 if (!($64)) {
  $error$2 = $63;
  STACKTOP = sp;return ($error$2|0);
 }
 $65 = (($font) + 536|0);
 $66 = (_cff_index_init($65,$stream,1)|0);
 $67 = ($66|0)==(0);
 if (!($67)) {
  $error$2 = $66;
  STACKTOP = sp;return ($error$2|0);
 }
 $68 = (($font) + 568|0);
 $69 = (_cff_index_get_pointers($65,$68,0)|0);
 $error$2 = $69;
 STACKTOP = sp;return ($error$2|0);
}
function _cff_font_done($font) {
 $font = $font|0;
 var $$idx = 0, $$idx$val = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $idx$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($font) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($font) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = (($3) + 28|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($font) + 112|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   _FT_Stream_ReleaseFrame($3,$7);
  }
  $10 = (($font) + 108|0);
  $11 = HEAP32[$10>>2]|0;
  _ft_mem_free($6,$11);
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;HEAP32[$2+28>>2]=0|0;
 }
 $12 = (($font) + 1208|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = (($13) + 28|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($font) + 1236|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if (!($19)) {
   _FT_Stream_ReleaseFrame($13,$17);
  }
  $20 = (($font) + 1232|0);
  $21 = HEAP32[$20>>2]|0;
  _ft_mem_free($16,$21);
  ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;HEAP32[$12+16>>2]=0|0;HEAP32[$12+20>>2]=0|0;HEAP32[$12+24>>2]=0|0;HEAP32[$12+28>>2]=0|0;
 }
 $22 = (($font) + 20|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if (!($24)) {
  $25 = (($23) + 28|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($font) + 48|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(0|0);
  if (!($29)) {
   _FT_Stream_ReleaseFrame($23,$27);
  }
  $30 = (($font) + 44|0);
  $31 = HEAP32[$30>>2]|0;
  _ft_mem_free($26,$31);
  ;HEAP32[$22+0>>2]=0|0;HEAP32[$22+4>>2]=0|0;HEAP32[$22+8>>2]=0|0;HEAP32[$22+12>>2]=0|0;HEAP32[$22+16>>2]=0|0;HEAP32[$22+20>>2]=0|0;HEAP32[$22+24>>2]=0|0;HEAP32[$22+28>>2]=0|0;
 }
 $32 = (($font) + 1176|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  $35 = (($33) + 28|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($font) + 1204|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($38|0)==(0|0);
  if (!($39)) {
   _FT_Stream_ReleaseFrame($33,$37);
  }
  $40 = (($font) + 1200|0);
  $41 = HEAP32[$40>>2]|0;
  _ft_mem_free($36,$41);
  ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;HEAP32[$32+20>>2]=0|0;HEAP32[$32+24>>2]=0|0;HEAP32[$32+28>>2]=0|0;
 }
 $42 = (($font) + 1896|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0);
 if (!($44)) {
  $105 = $43;$idx$06 = 0;
  while(1) {
   $45 = ((($font) + ($idx$06<<2)|0) + 1900|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(0|0);
   if ($47) {
    $62 = $105;
   } else {
    $48 = (($46) + 536|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==(0|0);
    if (!($50)) {
     $51 = (($49) + 28|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = (($46) + 564|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==(0|0);
     if (!($55)) {
      _FT_Stream_ReleaseFrame($49,$53);
     }
     $56 = (($46) + 560|0);
     $57 = HEAP32[$56>>2]|0;
     _ft_mem_free($52,$57);
     ;HEAP32[$48+0>>2]=0|0;HEAP32[$48+4>>2]=0|0;HEAP32[$48+8>>2]=0|0;HEAP32[$48+12>>2]=0|0;HEAP32[$48+16>>2]=0|0;HEAP32[$48+20>>2]=0|0;HEAP32[$48+24>>2]=0|0;HEAP32[$48+28>>2]=0|0;
    }
    $58 = (($46) + 568|0);
    $59 = HEAP32[$58>>2]|0;
    _ft_mem_free($1,$59);
    HEAP32[$58>>2] = 0;
    $$pre = HEAP32[$42>>2]|0;
    $62 = $$pre;
   }
   $60 = (($idx$06) + 1)|0;
   $61 = ($60>>>0)<($62>>>0);
   if ($61) {
    $105 = $62;$idx$06 = $60;
   } else {
    break;
   }
  }
  $63 = (($font) + 1900|0);
  $64 = HEAP32[$63>>2]|0;
  _ft_mem_free($1,$64);
  HEAP32[$63>>2] = 0;
 }
 $65 = (($font) + 116|0);
 HEAP32[$65>>2] = 0;
 $66 = (($font) + 120|0);
 HEAP32[$66>>2] = 0;
 $67 = (($font) + 124|0);
 HEAP32[$67>>2] = 0;
 $68 = HEAP32[$font>>2]|0;
 $$idx = (($68) + 28|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $69 = (($font) + 1164|0);
 $70 = HEAP32[$69>>2]|0;
 _ft_mem_free($$idx$val,$70);
 HEAP32[$69>>2] = 0;
 $71 = (($font) + 1168|0);
 HEAP32[$71>>2] = 0;
 $72 = (($font) + 1160|0);
 $73 = HEAP32[$72>>2]|0;
 _ft_mem_free($$idx$val,$73);
 HEAP32[$72>>2] = 0;
 $74 = (($font) + 1152|0);
 HEAP32[$74>>2] = 0;
 $75 = (($font) + 1156|0);
 HEAP32[$75>>2] = 0;
 $76 = (($font) + 1860|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ($77|0)==(0|0);
 if (!($78)) {
  $79 = (($77) + 28|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($font) + 1888|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($82|0)==(0|0);
  if (!($83)) {
   _FT_Stream_ReleaseFrame($77,$81);
  }
  $84 = (($font) + 1884|0);
  $85 = HEAP32[$84>>2]|0;
  _ft_mem_free($80,$85);
  ;HEAP32[$76+0>>2]=0|0;HEAP32[$76+4>>2]=0|0;HEAP32[$76+8>>2]=0|0;HEAP32[$76+12>>2]=0|0;HEAP32[$76+16>>2]=0|0;HEAP32[$76+20>>2]=0|0;HEAP32[$76+24>>2]=0|0;HEAP32[$76+28>>2]=0|0;
 }
 $86 = (($font) + 1892|0);
 $87 = HEAP32[$86>>2]|0;
 _ft_mem_free($1,$87);
 HEAP32[$86>>2] = 0;
 $88 = (($font) + 2932|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = ($89|0)==(0|0);
 if ($90) {
  $92 = (($font) + 2936|0);
  HEAP32[$92>>2] = 0;
  $93 = (($font) + 2924|0);
  HEAP8[$93>>0] = 0;
  $94 = (($font) + 2928|0);
  HEAP32[$94>>2] = 0;
  $95 = (($font) + 2960|0);
  $96 = HEAP32[$95>>2]|0;
  _ft_mem_free($1,$96);
  HEAP32[$95>>2] = 0;
  $97 = (($font) + 1304|0);
  $98 = HEAP32[$97>>2]|0;
  _ft_mem_free($1,$98);
  HEAP32[$97>>2] = 0;
  $99 = (($font) + 1308|0);
  $100 = HEAP32[$99>>2]|0;
  _ft_mem_free($1,$100);
  HEAP32[$99>>2] = 0;
  $101 = (($font) + 1316|0);
  $102 = HEAP32[$101>>2]|0;
  _ft_mem_free($1,$102);
  HEAP32[$101>>2] = 0;
  $103 = (($font) + 1320|0);
  $104 = HEAP32[$103>>2]|0;
  _ft_mem_free($1,$104);
  HEAP32[$103>>2] = 0;
  STACKTOP = sp;return;
 }
 $91 = HEAP32[$font>>2]|0;
 _FT_Stream_ReleaseFrame($91,$88);
 $92 = (($font) + 2936|0);
 HEAP32[$92>>2] = 0;
 $93 = (($font) + 2924|0);
 HEAP8[$93>>0] = 0;
 $94 = (($font) + 2928|0);
 HEAP32[$94>>2] = 0;
 $95 = (($font) + 2960|0);
 $96 = HEAP32[$95>>2]|0;
 _ft_mem_free($1,$96);
 HEAP32[$95>>2] = 0;
 $97 = (($font) + 1304|0);
 $98 = HEAP32[$97>>2]|0;
 _ft_mem_free($1,$98);
 HEAP32[$97>>2] = 0;
 $99 = (($font) + 1308|0);
 $100 = HEAP32[$99>>2]|0;
 _ft_mem_free($1,$100);
 HEAP32[$99>>2] = 0;
 $101 = (($font) + 1316|0);
 $102 = HEAP32[$101>>2]|0;
 _ft_mem_free($1,$102);
 HEAP32[$101>>2] = 0;
 $103 = (($font) + 1320|0);
 $104 = HEAP32[$103>>2]|0;
 _ft_mem_free($1,$104);
 HEAP32[$103>>2] = 0;
 STACKTOP = sp;return;
}
function _cff_size_done($cffsize) {
 $cffsize = $cffsize|0;
 var $$idx$val$idx = 0, $$idx$val$idx$val = 0, $$idx$val$idx$val$idx = 0, $$idx$val$idx$val$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cffsize>>2]|0;
 $1 = (($0) + 692|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($cffsize) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $$idx$val$idx = (($0) + 96|0);
 $$idx$val$idx$val = HEAP32[$$idx$val$idx>>2]|0;
 $$idx$val$idx$val$idx = (($$idx$val$idx$val) + 4|0);
 $$idx$val$idx$val$idx$val = HEAP32[$$idx$val$idx$val$idx>>2]|0;
 $6 = (($2) + 2952|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (_FT_Get_Module($$idx$val$idx$val$idx$val,808912)|0);
 $9 = ($8|0)==(0|0);
 $10 = ($7|0)==(0|0);
 $or$cond$i = $9 | $10;
 if ($or$cond$i) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$7>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (FUNCTION_TABLE_ii[$11 & 4095]($8)|0);
 $14 = ($13|0)==(0|0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (($13) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$16 & 4095]($17);
 $18 = (($2) + 1896|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(0);
 if ($20) {
  STACKTOP = sp;return;
 } else {
  $i$02 = $19;
 }
 while(1) {
  $21 = HEAP32[$15>>2]|0;
  $22 = (($i$02) + -1)|0;
  $23 = ((($4) + ($22<<2)|0) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_vi[$21 & 4095]($24);
  $25 = ($22|0)==(0);
  if ($25) {
   break;
  } else {
   $i$02 = $22;
  }
 }
 STACKTOP = sp;return;
}
function _cff_size_init($cffsize) {
 $cffsize = $cffsize|0;
 var $$idx$val = 0, $$idx$val$idx = 0, $$idx$val$idx$val = 0, $$idx$val$idx$val$idx = 0, $$idx$val$idx$val$idx$val = 0, $$idx$val$idx1 = 0, $$idx$val$idx1$val = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $i$0 = 0, $or$cond$i = 0, $priv = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $error = sp + 196|0;
 $priv = sp;
 HEAP32[$error>>2] = 0;
 $$idx$val = HEAP32[$cffsize>>2]|0;
 $$idx$val$idx = (($$idx$val) + 96|0);
 $$idx$val$idx$val = HEAP32[$$idx$val$idx>>2]|0;
 $$idx$val$idx1 = (($$idx$val) + 692|0);
 $$idx$val$idx1$val = HEAP32[$$idx$val$idx1>>2]|0;
 $$idx$val$idx$val$idx = (($$idx$val$idx$val) + 4|0);
 $$idx$val$idx$val$idx$val = HEAP32[$$idx$val$idx$val$idx>>2]|0;
 $0 = (($$idx$val$idx1$val) + 2952|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_FT_Get_Module($$idx$val$idx$val$idx$val,808912)|0);
 $3 = ($2|0)==(0|0);
 $4 = ($1|0)==(0|0);
 $or$cond$i = $3 | $4;
 do {
  if (!($or$cond$i)) {
   $5 = HEAP32[$1>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
    $8 = ($7|0)==(0|0);
    if (!($8)) {
     $9 = HEAP32[$cffsize>>2]|0;
     $10 = (($9) + 692|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($9) + 100|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (_ft_mem_alloc($13,1028,$error)|0);
     $15 = HEAP32[$error>>2]|0;
     $16 = ($15|0)==(0);
     if (!($16)) {
      $41 = $15;
      STACKTOP = sp;return ($41|0);
     }
     $17 = (($11) + 1324|0);
     _cff_make_private_dict($17,$priv);
     $18 = HEAP32[$7>>2]|0;
     $19 = HEAP32[$cffsize>>2]|0;
     $20 = (($19) + 100|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (FUNCTION_TABLE_iiii[$18 & 2047]($21,$priv,$14)|0);
     HEAP32[$error>>2] = $22;
     $23 = ($22|0)==(0);
     if (!($23)) {
      $41 = $22;
      STACKTOP = sp;return ($41|0);
     }
     $24 = (($11) + 1896|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($11) + 1900|0);
     $27 = (($14) + 4|0);
     $i$0 = $25;
     while(1) {
      $28 = ($i$0|0)==(0);
      if ($28) {
       label = 9;
       break;
      }
      $29 = (($i$0) + -1)|0;
      $30 = (($26) + ($29<<2)|0);
      $31 = HEAP32[$30>>2]|0;
      _cff_make_private_dict($31,$priv);
      $32 = HEAP32[$7>>2]|0;
      $33 = HEAP32[$cffsize>>2]|0;
      $34 = (($33) + 100|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = (($27) + ($29<<2)|0);
      $37 = (FUNCTION_TABLE_iiii[$32 & 2047]($35,$priv,$36)|0);
      HEAP32[$error>>2] = $37;
      $38 = ($37|0)==(0);
      if ($38) {
       $i$0 = $29;
      } else {
       $41 = $37;
       label = 11;
       break;
      }
     }
     if ((label|0) == 9) {
      $39 = (($cffsize) + 40|0);
      HEAP32[$39>>2] = $14;
      break;
     }
     else if ((label|0) == 11) {
      STACKTOP = sp;return ($41|0);
     }
    }
   }
  }
 } while(0);
 $40 = (($cffsize) + 44|0);
 HEAP32[$40>>2] = (-1);
 $$pre = HEAP32[$error>>2]|0;
 $41 = $$pre;
 STACKTOP = sp;return ($41|0);
}
function _cff_make_private_dict($subfont,$priv) {
 $subfont = $subfont|0;
 $priv = $priv|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $exitcond = 0, $exitcond22 = 0, $exitcond23 = 0, $exitcond24 = 0, $exitcond25 = 0, $exitcond26 = 0, $n$018 = 0, $n$114 = 0, $n$210 = 0, $n$36 = 0, $n$42 = 0, $n$51 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _memset(($priv|0),0,196)|0;
 $0 = (($subfont) + 176|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = (($priv) + 8|0);
 HEAP8[$2>>0] = $1;
 $3 = ($1<<24>>24)==(0);
 if (!($3)) {
  $4 = $1&255;
  $n$018 = 0;
  while(1) {
   $5 = ((($subfont) + ($n$018<<2)|0) + 180|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = $6&65535;
   $8 = ((($priv) + ($n$018<<1)|0) + 12|0);
   HEAP16[$8>>1] = $7;
   $9 = (($n$018) + 1)|0;
   $exitcond26 = ($9|0)==($4|0);
   if ($exitcond26) {
    break;
   } else {
    $n$018 = $9;
   }
  }
 }
 $10 = (($subfont) + 177|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = (($priv) + 9|0);
 HEAP8[$12>>0] = $11;
 $13 = ($11<<24>>24)==(0);
 if (!($13)) {
  $14 = $11&255;
  $n$114 = 0;
  while(1) {
   $15 = ((($subfont) + ($n$114<<2)|0) + 236|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16&65535;
   $18 = ((($priv) + ($n$114<<1)|0) + 40|0);
   HEAP16[$18>>1] = $17;
   $19 = (($n$114) + 1)|0;
   $exitcond25 = ($19|0)==($14|0);
   if ($exitcond25) {
    break;
   } else {
    $n$114 = $19;
   }
  }
 }
 $20 = (($subfont) + 178|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = (($priv) + 10|0);
 HEAP8[$22>>0] = $21;
 $23 = ($21<<24>>24)==(0);
 if (!($23)) {
  $24 = $21&255;
  $n$210 = 0;
  while(1) {
   $25 = ((($subfont) + ($n$210<<2)|0) + 276|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = $26&65535;
   $28 = ((($priv) + ($n$210<<1)|0) + 60|0);
   HEAP16[$28>>1] = $27;
   $29 = (($n$210) + 1)|0;
   $exitcond24 = ($29|0)==($24|0);
   if ($exitcond24) {
    break;
   } else {
    $n$210 = $29;
   }
  }
 }
 $30 = (($subfont) + 179|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = (($priv) + 11|0);
 HEAP8[$32>>0] = $31;
 $33 = ($31<<24>>24)==(0);
 if (!($33)) {
  $34 = $31&255;
  $n$36 = 0;
  while(1) {
   $35 = ((($subfont) + ($n$36<<2)|0) + 332|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = $36&65535;
   $38 = ((($priv) + ($n$36<<1)|0) + 88|0);
   HEAP16[$38>>1] = $37;
   $39 = (($n$36) + 1)|0;
   $exitcond23 = ($39|0)==($34|0);
   if ($exitcond23) {
    break;
   } else {
    $n$36 = $39;
   }
  }
 }
 $40 = (($subfont) + 372|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (($priv) + 108|0);
 HEAP32[$42>>2] = $41;
 $43 = (($subfont) + 376|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($priv) + 112|0);
 HEAP32[$45>>2] = $44;
 $46 = (($subfont) + 380|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($priv) + 116|0);
 HEAP32[$48>>2] = $47;
 $49 = (($subfont) + 384|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50&65535;
 $52 = (($priv) + 120|0);
 HEAP16[$52>>1] = $51;
 $53 = (($subfont) + 388|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54&65535;
 $56 = (($priv) + 122|0);
 HEAP16[$56>>1] = $55;
 $57 = (($subfont) + 392|0);
 $58 = HEAP8[$57>>0]|0;
 $59 = (($priv) + 124|0);
 HEAP8[$59>>0] = $58;
 $60 = ($58<<24>>24)==(0);
 if (!($60)) {
  $61 = $58&255;
  $n$42 = 0;
  while(1) {
   $62 = ((($subfont) + ($n$42<<2)|0) + 396|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = $63&65535;
   $65 = ((($priv) + ($n$42<<1)|0) + 128|0);
   HEAP16[$65>>1] = $64;
   $66 = (($n$42) + 1)|0;
   $exitcond22 = ($66|0)==($61|0);
   if ($exitcond22) {
    break;
   } else {
    $n$42 = $66;
   }
  }
 }
 $67 = (($subfont) + 393|0);
 $68 = HEAP8[$67>>0]|0;
 $69 = (($priv) + 125|0);
 HEAP8[$69>>0] = $68;
 $70 = ($68<<24>>24)==(0);
 if ($70) {
  $77 = (($subfont) + 500|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = (($priv) + 126|0);
  HEAP8[$79>>0] = $78;
  $80 = (($subfont) + 512|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($priv) + 184|0);
  HEAP32[$82>>2] = $81;
  $83 = (($subfont) + 508|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($priv) + 4|0);
  HEAP32[$85>>2] = $84;
  STACKTOP = sp;return;
 }
 $71 = $68&255;
 $n$51 = 0;
 while(1) {
  $72 = ((($subfont) + ($n$51<<2)|0) + 448|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = $73&65535;
  $75 = ((($priv) + ($n$51<<1)|0) + 154|0);
  HEAP16[$75>>1] = $74;
  $76 = (($n$51) + 1)|0;
  $exitcond = ($76|0)==($71|0);
  if ($exitcond) {
   break;
  } else {
   $n$51 = $76;
  }
 }
 $77 = (($subfont) + 500|0);
 $78 = HEAP8[$77>>0]|0;
 $79 = (($priv) + 126|0);
 HEAP8[$79>>0] = $78;
 $80 = (($subfont) + 512|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($priv) + 184|0);
 HEAP32[$82>>2] = $81;
 $83 = (($subfont) + 508|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = (($priv) + 4|0);
 HEAP32[$85>>2] = $84;
 STACKTOP = sp;return;
}
function _cff_size_select($size,$strike_index) {
 $size = $size|0;
 $strike_index = $strike_index|0;
 var $$idx$val = 0, $$idx$val$idx = 0, $$idx$val$idx$val = 0, $$idx$val$idx$val$idx = 0, $$idx$val$idx$val$idx$val = 0, $$idx$val$idx1 = 0, $$idx$val$idx1$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $or$cond$i = 0, $strike_index$c = 0, $x_scale$0 = 0, $y_scale$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($size) + 44|0);
 $strike_index$c = $strike_index;
 HEAP32[$0>>2] = $strike_index$c;
 $1 = HEAP32[$size>>2]|0;
 _FT_Select_Metrics($1,$strike_index);
 $$idx$val = HEAP32[$size>>2]|0;
 $$idx$val$idx = (($$idx$val) + 96|0);
 $$idx$val$idx$val = HEAP32[$$idx$val$idx>>2]|0;
 $$idx$val$idx1 = (($$idx$val) + 692|0);
 $$idx$val$idx1$val = HEAP32[$$idx$val$idx1>>2]|0;
 $$idx$val$idx$val$idx = (($$idx$val$idx$val) + 4|0);
 $$idx$val$idx$val$idx$val = HEAP32[$$idx$val$idx$val$idx>>2]|0;
 $2 = (($$idx$val$idx1$val) + 2952|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_FT_Get_Module($$idx$val$idx$val$idx$val,808912)|0);
 $5 = ($4|0)==(0|0);
 $6 = ($3|0)==(0|0);
 $or$cond$i = $5 | $6;
 if ($or$cond$i) {
  STACKTOP = sp;return 0;
 }
 $7 = HEAP32[$3>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return 0;
 }
 $9 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return 0;
 }
 $11 = HEAP32[$size>>2]|0;
 $12 = (($11) + 692|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($size) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 1324|0);
 $17 = (($16) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($9) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$15>>2]|0;
 $22 = (($size) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($size) + 20|0);
 $25 = HEAP32[$24>>2]|0;
 (FUNCTION_TABLE_iiiiii[$20 & 255]($21,$23,$25,0,0)|0);
 $26 = (($13) + 1896|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  STACKTOP = sp;return 0;
 }
 $29 = (($13) + 1900|0);
 $i$02 = $27;
 while(1) {
  $30 = (($i$02) + -1)|0;
  $31 = (($29) + ($30<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($32) + 68|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($18|0)==($34|0);
  $36 = HEAP32[$22>>2]|0;
  if ($35) {
   $40 = HEAP32[$24>>2]|0;
   $x_scale$0 = $36;$y_scale$0 = $40;
  } else {
   $37 = (_FT_MulDiv($36,$18,$34)|0);
   $38 = HEAP32[$24>>2]|0;
   $39 = (_FT_MulDiv($38,$18,$34)|0);
   $x_scale$0 = $37;$y_scale$0 = $39;
  }
  $41 = HEAP32[$19>>2]|0;
  $42 = ((($15) + ($30<<2)|0) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  (FUNCTION_TABLE_iiiiii[$41 & 255]($43,$x_scale$0,$y_scale$0,0,0)|0);
  $44 = ($30|0)==(0);
  if ($44) {
   break;
  } else {
   $i$02 = $30;
  }
 }
 STACKTOP = sp;return 0;
}
function _cff_size_request($size,$req) {
 $size = $size|0;
 $req = $req|0;
 var $$idx$val = 0, $$idx$val$idx = 0, $$idx$val$idx$val = 0, $$idx$val$idx$val$idx = 0, $$idx$val$idx$val$idx$val = 0, $$idx$val$idx1 = 0, $$idx$val$idx1$val = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $or$cond$i = 0, $strike_index = 0, $x_scale$0 = 0, $y_scale$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $strike_index = sp;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $13 = $0;
  } else {
   $5 = (($0) + 532|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 148|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (FUNCTION_TABLE_iiii[$8 & 2047]($0,$req,$strike_index)|0);
   $10 = ($9|0)==(0);
   if (!($10)) {
    $11 = (($size) + 44|0);
    HEAP32[$11>>2] = (-1);
    $$pre = HEAP32[$size>>2]|0;
    $13 = $$pre;
    break;
   }
   $12 = HEAP32[$strike_index>>2]|0;
   (_cff_size_select($size,$12)|0);
   STACKTOP = sp;return 0;
  }
 } while(0);
 _FT_Request_Metrics($13,$req);
 $$idx$val = HEAP32[$size>>2]|0;
 $$idx$val$idx = (($$idx$val) + 96|0);
 $$idx$val$idx$val = HEAP32[$$idx$val$idx>>2]|0;
 $$idx$val$idx1 = (($$idx$val) + 692|0);
 $$idx$val$idx1$val = HEAP32[$$idx$val$idx1>>2]|0;
 $$idx$val$idx$val$idx = (($$idx$val$idx$val) + 4|0);
 $$idx$val$idx$val$idx$val = HEAP32[$$idx$val$idx$val$idx>>2]|0;
 $14 = (($$idx$val$idx1$val) + 2952|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (_FT_Get_Module($$idx$val$idx$val$idx$val,808912)|0);
 $17 = ($16|0)==(0|0);
 $18 = ($15|0)==(0|0);
 $or$cond$i = $17 | $18;
 if ($or$cond$i) {
  STACKTOP = sp;return 0;
 }
 $19 = HEAP32[$15>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  STACKTOP = sp;return 0;
 }
 $21 = (FUNCTION_TABLE_ii[$19 & 4095]($16)|0);
 $22 = ($21|0)==(0|0);
 if ($22) {
  STACKTOP = sp;return 0;
 }
 $23 = HEAP32[$size>>2]|0;
 $24 = (($23) + 692|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($size) + 40|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 1324|0);
 $29 = (($28) + 68|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($21) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$27>>2]|0;
 $34 = (($size) + 16|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($size) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 (FUNCTION_TABLE_iiiiii[$32 & 255]($33,$35,$37,0,0)|0);
 $38 = (($25) + 1896|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0);
 if ($40) {
  STACKTOP = sp;return 0;
 }
 $41 = (($25) + 1900|0);
 $i$02 = $39;
 while(1) {
  $42 = (($i$02) + -1)|0;
  $43 = (($41) + ($42<<2)|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + 68|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($30|0)==($46|0);
  $48 = HEAP32[$34>>2]|0;
  if ($47) {
   $52 = HEAP32[$36>>2]|0;
   $x_scale$0 = $48;$y_scale$0 = $52;
  } else {
   $49 = (_FT_MulDiv($48,$30,$46)|0);
   $50 = HEAP32[$36>>2]|0;
   $51 = (_FT_MulDiv($50,$30,$46)|0);
   $x_scale$0 = $49;$y_scale$0 = $51;
  }
  $53 = HEAP32[$31>>2]|0;
  $54 = ((($27) + ($42<<2)|0) + 4|0);
  $55 = HEAP32[$54>>2]|0;
  (FUNCTION_TABLE_iiiiii[$53 & 255]($55,$x_scale$0,$y_scale$0,0,0)|0);
  $56 = ($42|0)==(0);
  if ($56) {
   break;
  } else {
   $i$02 = $42;
  }
 }
 STACKTOP = sp;return 0;
}
function _cff_slot_done($slot) {
 $slot = $slot|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($slot) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 36|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function _cff_slot_init($slot) {
 $slot = $slot|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($slot) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 692|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 2952|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return 0;
 }
 $7 = (($1) + 96|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (_FT_Get_Module($10,808912)|0);
 $12 = ($11|0)==(0|0);
 if ($12) {
  STACKTOP = sp;return 0;
 }
 $13 = (($5) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_ii[$14 & 4095]($11)|0);
 $16 = (($slot) + 156|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 36|0);
 HEAP32[$18>>2] = $15;
 STACKTOP = sp;return 0;
}
function _cff_face_init($stream,$cffface,$face_index,$num_params,$params) {
 $stream = $stream|0;
 $cffface = $cffface|0;
 $face_index = $face_index|0;
 $num_params = $num_params|0;
 $params = $params|0;
 var $$ = 0, $$0 = 0, $$3 = 0, $$5 = 0, $$6 = 0, $$81 = 0, $$off$us$1$i = 0, $$off$us$2$i = 0, $$off$us$3$i = 0, $$off$us$4$i = 0, $$off$us$5$i = 0, $$off$us$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert61 = 0, $$pre = 0, $$pre$phi65Z2D = 0, $$pre$phi72Z2D = 0, $$pre$phi74Z2D = 0, $$pre$phi76Z2D = 0, $$pre$phiZ2D = 0;
 var $$pre62 = 0, $$pre69 = 0, $$pre73 = 0, $$pre75 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $brmerge$not = 0, $clazz$0$in = 0, $cmaprec = 0;
 var $continue_search$0$ph10$i29 = 0, $continue_search$2$us$1$i = 0, $continue_search$2$us$2$i = 0, $continue_search$2$us$3$i = 0, $continue_search$2$us$4$i = 0, $continue_search$2$us$i = 0, $error = 0, $error$i10 = 0, $exitcond$i = 0, $family$0 = 0, $family$1$ph$be = 0, $family$1$ph38 = 0, $family$126 = 0, $flags$1 = 0, $flags$3 = 0, $flags$4 = 0, $fullp$0$ph$be = 0, $fullp$0$ph37 = 0, $i$030 = 0, $idx$010$i = 0;
 var $idx$1$i = 0, $idx$1$in7$i = 0, $idx$1$in7$i$phi = 0, $idx$14$i = 0, $idx$16$i = 0, $idx$18$i = 0, $indvars$iv$i$be = 0, $indvars$iv$i28 = 0, $nn$0$lcssa = 0, $nn$014 = 0, $nn$1 = 0, $not$ = 0, $not$11 = 0, $or$cond = 0, $or$cond2 = 0, $or$cond4 = 0, $or$cond7 = 0, $phitmp = 0, $phitmp82 = 0, $pure_cff$0 = 0;
 var $pure_cff$1 = 0, $scaling$0 = 0, $sext = 0, $sfnt_format$0 = 0, $storemerge = 0, $storemerge79 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $error$i10 = sp + 16|0;
 $error = sp;
 $cmaprec = sp + 4|0;
 $0 = (($cffface) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_FT_Get_Module_Interface($3,808928)|0);
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   label = 112;
  } else {
   $6 = HEAP32[$0>>2]|0;
   $7 = (_ft_module_get_service($6,808936)|0);
   $8 = (_FT_Get_Module_Interface($3,808912)|0);
   $9 = (_FT_Stream_Seek($stream,0)|0);
   HEAP32[$error>>2] = $9;
   $10 = ($9|0)==(0);
   if ($10) {
    $11 = (($4) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (FUNCTION_TABLE_iiiiii[$12 & 255]($stream,$cffface,$face_index,$num_params,$params)|0);
    HEAP32[$error>>2] = $13;
    $14 = ($13|0)==(0);
    if ($14) {
     $15 = (($cffface) + 148|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)==(1330926671);
     if (!($17)) {
      label = 112;
      break;
     }
     $18 = ($face_index|0)<(0);
     if ($18) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
     $19 = ($face_index|0)>(0);
     if ($19) {
      HEAP32[$error>>2] = 6;
      break;
     }
     $20 = (($cffface) + 508|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (FUNCTION_TABLE_iiiii[$21 & 511]($cffface,1751474532,$stream,0)|0);
     HEAP32[$error>>2] = $22;
     $23 = ($22|0)==(0);
     if ($23) {
      $24 = (($4) + 8|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (FUNCTION_TABLE_iiiiii[$25 & 255]($stream,$cffface,0,$num_params,$params)|0);
      HEAP32[$error>>2] = $26;
      $27 = ($26|0)==(0);
      if ($27) {
       $pure_cff$0 = 0;
      } else {
       break;
      }
     } else {
      $28 = (($4) + 40|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (FUNCTION_TABLE_iii[$29 & 4095]($cffface,$stream)|0);
      HEAP32[$error>>2] = $30;
      $31 = ($30|0)==(0);
      if ($31) {
       $pure_cff$0 = 1;
      } else {
       break;
      }
     }
     $32 = HEAP32[$20>>2]|0;
     $33 = (FUNCTION_TABLE_iiiii[$32 & 511]($cffface,1128678944,$stream,0)|0);
     HEAP32[$error>>2] = $33;
     $34 = ($33|0)==(0);
     if ($34) {
      $pure_cff$1 = $pure_cff$0;$sfnt_format$0 = 1;
     } else {
      break;
     }
    } else {
     $35 = (_FT_Stream_Seek($stream,0)|0);
     HEAP32[$error>>2] = $35;
     $36 = ($35|0)==(0);
     if (!($36)) {
      break;
     }
     HEAP32[$error>>2] = 0;
     $pure_cff$1 = 1;$sfnt_format$0 = 0;
    }
    $37 = (($cffface) + 100|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (_ft_mem_alloc($38,2972,$error)|0);
    $40 = HEAP32[$error>>2]|0;
    $41 = ($40|0)==(0);
    if ($41) {
     $42 = (($cffface) + 692|0);
     HEAP32[$42>>2] = $39;
     $43 = (_cff_font_load($3,$stream,$face_index,$39,$pure_cff$1)|0);
     HEAP32[$error>>2] = $43;
     $44 = ($43|0)==(0);
     if ($44) {
      $45 = (($39) + 2952|0);
      HEAP32[$45>>2] = $8;
      $46 = (($39) + 2956|0);
      HEAP32[$46>>2] = $7;
      $47 = (($cffface) + 4|0);
      HEAP32[$47>>2] = $face_index;
      $48 = (($39) + 12|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = (($cffface) + 16|0);
      HEAP32[$50>>2] = $49;
      $51 = (($39) + 1456|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = ($52|0)==(65535);
      $54 = ($7|0)==(0|0);
      $or$cond2 = $53 & $54;
      if ($or$cond2) {
       label = 112;
      } else {
       $55 = (($39) + 1388|0);
       $56 = HEAP8[$55>>0]|0;
       $57 = ($56<<24>>24)==(0);
       if ($57) {
        $58 = ($pure_cff$1<<24>>24)==(0);
        if ($58) {
         $59 = (($cffface) + 68|0);
         $60 = HEAP16[$59>>1]|0;
         $61 = $60&65535;
         $63 = $61;
        } else {
         $63 = 1000;
        }
        $62 = (($39) + 1392|0);
        HEAP32[$62>>2] = $63;
        $$pre$phi72Z2D = $62;
       } else {
        $$pre69 = (($39) + 1392|0);
        $$pre$phi72Z2D = $$pre69;
       }
       $64 = (($39) + 1372|0);
       $65 = (($39) + 1396|0);
       $66 = (($39) + 1384|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = ($67|0)<(0);
       $69 = (0 - ($67))|0;
       $70 = $68 ? $69 : $67;
       $71 = ($70|0)==(65536);
       if ($71) {
        $$phi$trans$insert = (($39) + 1400|0);
        $$pre = HEAP32[$$phi$trans$insert>>2]|0;
        $$pre$phiZ2D = $65;$93 = $$pre;
       } else {
        $72 = HEAP32[$$pre$phi72Z2D>>2]|0;
        $73 = (_FT_DivFix($72,$70)|0);
        HEAP32[$$pre$phi72Z2D>>2] = $73;
        $74 = HEAP32[$64>>2]|0;
        $75 = (_FT_DivFix($74,$70)|0);
        HEAP32[$64>>2] = $75;
        $76 = (($39) + 1380|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = (_FT_DivFix($77,$70)|0);
        HEAP32[$76>>2] = $78;
        $79 = (($39) + 1376|0);
        $80 = HEAP32[$79>>2]|0;
        $81 = (_FT_DivFix($80,$70)|0);
        HEAP32[$79>>2] = $81;
        $82 = HEAP32[$66>>2]|0;
        $83 = (_FT_DivFix($82,$70)|0);
        HEAP32[$66>>2] = $83;
        $84 = HEAP32[$65>>2]|0;
        $85 = (_FT_DivFix($84,$70)|0);
        HEAP32[$65>>2] = $85;
        $86 = (($39) + 1400|0);
        $87 = HEAP32[$86>>2]|0;
        $88 = (_FT_DivFix($87,$70)|0);
        HEAP32[$86>>2] = $88;
        $$pre$phiZ2D = $65;$93 = $88;
       }
       $89 = HEAP32[$$pre$phiZ2D>>2]|0;
       $90 = $89 >> 16;
       HEAP32[$$pre$phiZ2D>>2] = $90;
       $91 = (($39) + 1400|0);
       $92 = $93 >> 16;
       HEAP32[$91>>2] = $92;
       $94 = (($39) + 1896|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = ($95|0)==(0);
       if (!($96)) {
        $97 = (($39) + 1900|0);
        $i$030 = $95;
        while(1) {
         $98 = (($i$030) + -1)|0;
         $99 = (($97) + ($98<<2)|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = (($100) + 64|0);
         $102 = HEAP8[$101>>0]|0;
         $103 = ($102<<24>>24)==(0);
         do {
          if ($103) {
           $117 = (($100) + 48|0);
           ;HEAP32[$117+0>>2]=HEAP32[$64+0>>2]|0;HEAP32[$117+4>>2]=HEAP32[$64+4>>2]|0;HEAP32[$117+8>>2]=HEAP32[$64+8>>2]|0;HEAP32[$117+12>>2]=HEAP32[$64+12>>2]|0;
           $118 = (($100) + 72|0);
           $119 = $65;
           $120 = $119;
           $121 = HEAP32[$120>>2]|0;
           $122 = (($119) + 4)|0;
           $123 = $122;
           $124 = HEAP32[$123>>2]|0;
           $125 = $118;
           $126 = $125;
           HEAP32[$126>>2] = $121;
           $127 = (($125) + 4)|0;
           $128 = $127;
           HEAP32[$128>>2] = $124;
           $129 = HEAP32[$$pre$phi72Z2D>>2]|0;
           $130 = (($100) + 68|0);
           HEAP32[$130>>2] = $129;
           $$pre$phi74Z2D = $118;$$pre$phi76Z2D = $130;
          } else {
           $104 = HEAP8[$55>>0]|0;
           $105 = ($104<<24>>24)==(0);
           if ($105) {
            $$pre73 = (($100) + 72|0);
            $$pre75 = (($100) + 68|0);
            $$pre$phi74Z2D = $$pre73;$$pre$phi76Z2D = $$pre75;
            break;
           }
           $106 = HEAP32[$$pre$phi72Z2D>>2]|0;
           $107 = ($106>>>0)>(1);
           $108 = (($100) + 68|0);
           if ($107) {
            $109 = HEAP32[$108>>2]|0;
            $110 = ($109>>>0)>(1);
            if ($110) {
             $111 = ($106>>>0)<($109>>>0);
             $$ = $111 ? $106 : $109;
             $scaling$0 = $$;
            } else {
             $scaling$0 = 1;
            }
           } else {
            $scaling$0 = 1;
           }
           $112 = (($100) + 48|0);
           _FT_Matrix_Multiply_Scaled($64,$112,$scaling$0);
           $113 = (($100) + 72|0);
           _FT_Vector_Transform_Scaled($113,$64,$scaling$0);
           $114 = HEAP32[$108>>2]|0;
           $115 = HEAP32[$$pre$phi72Z2D>>2]|0;
           $116 = (_FT_MulDiv($114,$115,$scaling$0)|0);
           HEAP32[$108>>2] = $116;
           $$pre$phi74Z2D = $113;$$pre$phi76Z2D = $108;
          }
         } while(0);
         $131 = (($100) + 60|0);
         $132 = HEAP32[$131>>2]|0;
         $133 = ($132|0)<(0);
         $134 = (0 - ($132))|0;
         $135 = $133 ? $134 : $132;
         $136 = ($135|0)==(65536);
         if ($136) {
          $$phi$trans$insert61 = (($100) + 76|0);
          $$pre62 = HEAP32[$$phi$trans$insert61>>2]|0;
          $$pre$phi65Z2D = $$pre$phi74Z2D;$159 = $$pre62;
         } else {
          $137 = HEAP32[$$pre$phi76Z2D>>2]|0;
          $138 = (_FT_DivFix($137,$135)|0);
          HEAP32[$$pre$phi76Z2D>>2] = $138;
          $139 = (($100) + 48|0);
          $140 = HEAP32[$139>>2]|0;
          $141 = (_FT_DivFix($140,$135)|0);
          HEAP32[$139>>2] = $141;
          $142 = (($100) + 56|0);
          $143 = HEAP32[$142>>2]|0;
          $144 = (_FT_DivFix($143,$135)|0);
          HEAP32[$142>>2] = $144;
          $145 = (($100) + 52|0);
          $146 = HEAP32[$145>>2]|0;
          $147 = (_FT_DivFix($146,$135)|0);
          HEAP32[$145>>2] = $147;
          $148 = HEAP32[$131>>2]|0;
          $149 = (_FT_DivFix($148,$135)|0);
          HEAP32[$131>>2] = $149;
          $150 = HEAP32[$$pre$phi74Z2D>>2]|0;
          $151 = (_FT_DivFix($150,$135)|0);
          HEAP32[$$pre$phi74Z2D>>2] = $151;
          $152 = (($100) + 76|0);
          $153 = HEAP32[$152>>2]|0;
          $154 = (_FT_DivFix($153,$135)|0);
          HEAP32[$152>>2] = $154;
          $$pre$phi65Z2D = $$pre$phi74Z2D;$159 = $154;
         }
         $155 = HEAP32[$$pre$phi65Z2D>>2]|0;
         $156 = $155 >> 16;
         HEAP32[$$pre$phi65Z2D>>2] = $156;
         $157 = (($100) + 76|0);
         $158 = $159 >> 16;
         HEAP32[$157>>2] = $158;
         $160 = ($98|0)==(0);
         if ($160) {
          break;
         } else {
          $i$030 = $98;
         }
        }
       }
       $161 = ($pure_cff$1<<24>>24)==(0);
       if (!($161)) {
        $162 = (($39) + 8|0);
        $163 = HEAP32[$162>>2]|0;
        HEAP32[$cffface>>2] = $163;
        $164 = HEAP32[$51>>2]|0;
        $165 = ($164|0)==(65535);
        if ($165) {
         $169 = (($39) + 1184|0);
         $170 = HEAP32[$169>>2]|0;
         $storemerge = $170;
        } else {
         $166 = (($39) + 1168|0);
         $167 = HEAP32[$166>>2]|0;
         $168 = (($167) + 1)|0;
         $storemerge = $168;
        }
        HEAP32[$50>>2] = $storemerge;
        $171 = (($39) + 1408|0);
        $172 = HEAP32[$171>>2]|0;
        $173 = $172 >> 16;
        $174 = (($cffface) + 52|0);
        HEAP32[$174>>2] = $173;
        $175 = (($39) + 1412|0);
        $176 = HEAP32[$175>>2]|0;
        $177 = $176 >> 16;
        $178 = (($cffface) + 56|0);
        HEAP32[$178>>2] = $177;
        $179 = (($39) + 1416|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = (($180) + 65535)|0;
        $182 = $181 >> 16;
        $183 = (($cffface) + 60|0);
        HEAP32[$183>>2] = $182;
        $184 = (($39) + 1420|0);
        $185 = HEAP32[$184>>2]|0;
        $186 = (($185) + 65535)|0;
        $187 = $186 >> 16;
        $188 = (($cffface) + 64|0);
        HEAP32[$188>>2] = $187;
        $189 = HEAP32[$$pre$phi72Z2D>>2]|0;
        $190 = $189&65535;
        $191 = (($cffface) + 68|0);
        HEAP16[$191>>1] = $190;
        $192 = $187&65535;
        $193 = (($cffface) + 70|0);
        HEAP16[$193>>1] = $192;
        $194 = $177&65535;
        $195 = (($cffface) + 72|0);
        HEAP16[$195>>1] = $194;
        $196 = $189 & 65535;
        $197 = ($196*12)|0;
        $198 = (($197>>>0) / 10)&-1;
        $199 = (($cffface) + 74|0);
        $sext = $198 << 16;
        $200 = $sext >> 16;
        $201 = (($187) - ($177))|0;
        $202 = ($200|0)<($201|0);
        $$81 = $202 ? $201 : $198;
        $storemerge79 = $$81&65535;
        HEAP16[$199>>1] = $storemerge79;
        $203 = (($39) + 1356|0);
        $204 = HEAP32[$203>>2]|0;
        $205 = $204 >>> 16;
        $206 = $205&65535;
        $207 = (($cffface) + 80|0);
        HEAP16[$207>>1] = $206;
        $208 = (($39) + 1360|0);
        $209 = HEAP32[$208>>2]|0;
        $210 = $209 >>> 16;
        $211 = $210&65535;
        $212 = (($cffface) + 82|0);
        HEAP16[$212>>1] = $211;
        $213 = (_cff_index_get_name($39,$face_index)|0);
        $214 = (($cffface) + 20|0);
        HEAP32[$214>>2] = $213;
        $215 = ($213|0)==(0|0);
        L60: do {
         if ($215) {
          $289 = (($39) + 1496|0);
          $290 = HEAP32[$289>>2]|0;
          $291 = (_cff_index_get_sid_string($39,$290)|0);
          $292 = ($291|0)==(0|0);
          if ($292) {
           label = 75;
          } else {
           $293 = (_ft_mem_strdup($38,$291,$error$i10)|0);
           HEAP32[$214>>2] = $293;
           label = 75;
          }
         } else {
          $216 = (($39) + 1336|0);
          $217 = HEAP32[$216>>2]|0;
          $218 = (_cff_index_get_sid_string($39,$217)|0);
          $219 = HEAP32[$214>>2]|0;
          $220 = (_strlen(($219|0))|0);
          $221 = (($220) + 1)|0;
          $222 = (($219) + 6|0);
          $223 = ($221|0)>(6);
          L62: do {
           if ($223) {
            $224 = (($219) + 1|0);
            $225 = (($219) + 2|0);
            $226 = (($219) + 3|0);
            $227 = (($219) + 4|0);
            $228 = (($219) + 5|0);
            $continue_search$0$ph10$i29 = 1;$indvars$iv$i28 = $221;
            while(1) {
             $229 = HEAP8[$222>>0]|0;
             $230 = ($229<<24>>24)==(43);
             if (!($230)) {
              break L62;
             }
             $231 = HEAP8[$219>>0]|0;
             $$off$us$i = (($231) + -65)<<24>>24;
             $232 = ($$off$us$i&255)<(26);
             $continue_search$2$us$i = $232 ? $continue_search$0$ph10$i29 : 0;
             $233 = HEAP8[$224>>0]|0;
             $$off$us$1$i = (($233) + -65)<<24>>24;
             $234 = ($$off$us$1$i&255)<(26);
             $continue_search$2$us$1$i = $234 ? $continue_search$2$us$i : 0;
             $235 = HEAP8[$225>>0]|0;
             $$off$us$2$i = (($235) + -65)<<24>>24;
             $236 = ($$off$us$2$i&255)<(26);
             $continue_search$2$us$2$i = $236 ? $continue_search$2$us$1$i : 0;
             $237 = HEAP8[$226>>0]|0;
             $$off$us$3$i = (($237) + -65)<<24>>24;
             $238 = ($$off$us$3$i&255)<(26);
             $continue_search$2$us$3$i = $238 ? $continue_search$2$us$2$i : 0;
             $239 = HEAP8[$227>>0]|0;
             $$off$us$4$i = (($239) + -65)<<24>>24;
             $240 = ($$off$us$4$i&255)<(26);
             $continue_search$2$us$4$i = $240 ? $continue_search$2$us$3$i : 0;
             $241 = HEAP8[$228>>0]|0;
             $$off$us$5$i = (($241) + -65)<<24>>24;
             $242 = ($continue_search$2$us$4$i<<24>>24)==(0);
             $not$11 = ($$off$us$5$i&255)>(25);
             $243 = $242 | $not$11;
             if ($243) {
              break L62;
             }
             $244 = ($indvars$iv$i28|0)>(7);
             if ($244) {
              $idx$14$i = 7;
              while(1) {
               $246 = (($219) + ($idx$14$i)|0);
               $247 = HEAP8[$246>>0]|0;
               $248 = (($idx$14$i) + -7)|0;
               $249 = (($219) + ($248)|0);
               HEAP8[$249>>0] = $247;
               $250 = (($idx$14$i) + 1)|0;
               $exitcond$i = ($250|0)==($indvars$iv$i28|0);
               if ($exitcond$i) {
                break;
               } else {
                $idx$14$i = $250;
               }
              }
             }
             $indvars$iv$i$be = (($indvars$iv$i28) + -7)|0;
             $245 = ($indvars$iv$i$be|0)>(6);
             if ($245) {
              $continue_search$0$ph10$i29 = $continue_search$2$us$4$i;$indvars$iv$i28 = $indvars$iv$i$be;
             } else {
              break;
             }
            }
           }
          } while(0);
          $251 = (($39) + 1340|0);
          $252 = HEAP32[$251>>2]|0;
          $253 = ($252|0)==(0);
          if ($253) {
           $family$0 = $219;
          } else {
           $254 = (_cff_index_get_sid_string($39,$252)|0);
           $255 = ($254|0)==(0|0);
           $$3 = $255 ? $219 : $254;
           $family$0 = $$3;
          }
          $256 = ($218|0)==(0|0);
          $257 = ($family$0|0)==(0|0);
          $or$cond4 = $256 | $257;
          if ($or$cond4) {
           label = 75;
          } else {
           $258 = HEAP8[$218>>0]|0;
           $259 = ($258<<24>>24)==(0);
           if ($259) {
            label = 75;
           } else {
            $262 = $258;$family$1$ph38 = $family$0;$fullp$0$ph37 = $218;
            L77: while(1) {
             $family$126 = $family$1$ph38;
             while(1) {
              $260 = HEAP8[$family$126>>0]|0;
              $261 = ($262<<24>>24)==($260<<24>>24);
              if ($261) {
               label = 57;
               break;
              }
              if ((($262<<24>>24) == 45) | (($262<<24>>24) == 32)) {
               $family$1$ph$be = $family$126;
               break;
              }
              if ((($260<<24>>24) == 0)) {
               break L77;
              } else if (!((($260<<24>>24) == 45) | (($260<<24>>24) == 32))) {
               label = 75;
               break L60;
              }
              $266 = ($262<<24>>24)==(0);
              if ($266) {
               label = 75;
               break L60;
              }
              $267 = (($family$126) + 1|0);
              $family$126 = $267;
             }
             if ((label|0) == 57) {
              label = 0;
              $263 = (($family$126) + 1|0);
              $family$1$ph$be = $263;
             }
             $fullp$0$ph$be = (($fullp$0$ph37) + 1|0);
             $264 = HEAP8[$fullp$0$ph$be>>0]|0;
             $265 = ($264<<24>>24)==(0);
             if ($265) {
              label = 75;
              break L60;
             } else {
              $262 = $264;$family$1$ph38 = $family$1$ph$be;$fullp$0$ph37 = $fullp$0$ph$be;
             }
            }
            $268 = (_ft_mem_strdup($38,$fullp$0$ph37,$error$i10)|0);
            $269 = HEAP32[$214>>2]|0;
            $270 = (_strlen(($269|0))|0);
            $271 = (_strlen(($268|0))|0);
            $272 = ($270|0)>($271|0);
            L89: do {
             if ($272) {
              $273 = ($271|0)<(1);
              if (!($273)) {
               $idx$010$i = 1;
               while(1) {
                $276 = (($270) - ($idx$010$i))|0;
                $277 = (($269) + ($276)|0);
                $278 = HEAP8[$277>>0]|0;
                $279 = (($271) - ($idx$010$i))|0;
                $280 = (($268) + ($279)|0);
                $281 = HEAP8[$280>>0]|0;
                $282 = ($278<<24>>24)==($281<<24>>24);
                if (!($282)) {
                 break L89;
                }
                $274 = (($idx$010$i) + 1)|0;
                $275 = ($idx$010$i|0)<($271|0);
                if ($275) {
                 $idx$010$i = $274;
                } else {
                 break;
                }
               }
              }
              $283 = (($270) - ($271))|0;
              $idx$16$i = (($283) + -1)|0;
              $284 = ($idx$16$i|0)>(0);
              if ($284) {
               $idx$1$in7$i = $283;$idx$18$i = $idx$16$i;
              } else {
               break;
              }
              while(1) {
               $285 = (($269) + ($idx$18$i)|0);
               $286 = HEAP8[$285>>0]|0;
               if (!((($286<<24>>24) == 43) | (($286<<24>>24) == 95) | (($286<<24>>24) == 32) | (($286<<24>>24) == 45))) {
                break;
               }
               $idx$1$i = (($idx$18$i) + -1)|0;
               $287 = ($idx$1$i|0)>(0);
               if ($287) {
                $idx$1$in7$i$phi = $idx$18$i;$idx$18$i = $idx$1$i;$idx$1$in7$i = $idx$1$in7$i$phi;
               } else {
                break L89;
               }
              }
              $288 = (($269) + ($idx$1$in7$i)|0);
              HEAP8[$288>>0] = 0;
             }
            } while(0);
            $294 = ($268|0)==(0|0);
            if ($294) {
             label = 75;
             break;
            }
            $295 = (($cffface) + 24|0);
            HEAP32[$295>>2] = $268;
           }
          }
         }
        } while(0);
        if ((label|0) == 75) {
         $296 = (_ft_mem_strdup($38,808960,$error$i10)|0);
         $297 = (($cffface) + 24|0);
         HEAP32[$297>>2] = $296;
        }
        $298 = ($sfnt_format$0<<24>>24)==(0);
        $$5 = $298 ? 2065 : 2073;
        $299 = (($39) + 1348|0);
        $300 = HEAP8[$299>>0]|0;
        $301 = ($300<<24>>24)==(0);
        $302 = $$5 | 4;
        $flags$1 = $301 ? $$5 : $302;
        $303 = (($cffface) + 8|0);
        HEAP32[$303>>2] = $flags$1;
        $304 = (($39) + 1352|0);
        $305 = HEAP32[$304>>2]|0;
        $not$ = ($305|0)!=(0);
        $$6 = $not$&1;
        $306 = (($39) + 1344|0);
        $307 = HEAP32[$306>>2]|0;
        $308 = (_cff_index_get_sid_string($39,$307)|0);
        $309 = ($308|0)==(0|0);
        do {
         if ($309) {
          $flags$3 = $$6;
         } else {
          $310 = (_strcmp($308,808968)|0);
          $311 = ($310|0)==(0);
          if (!($311)) {
           $312 = (_strcmp($308,808976)|0);
           $313 = ($312|0)==(0);
           if (!($313)) {
            $flags$3 = $$6;
            break;
           }
          }
          $314 = $$6 | 2;
          $flags$3 = $314;
         }
        } while(0);
        $315 = $flags$3 & 2;
        $316 = ($315|0)==(0);
        do {
         if ($316) {
          $317 = (($cffface) + 24|0);
          $318 = HEAP32[$317>>2]|0;
          $319 = ($318|0)==(0|0);
          if ($319) {
           $flags$4 = $flags$3;
          } else {
           $320 = (_strncmp($318,808968,4)|0);
           $321 = ($320|0)==(0);
           if (!($321)) {
            $322 = (_strncmp($318,808976,5)|0);
            $323 = ($322|0)==(0);
            if (!($323)) {
             $flags$4 = $flags$3;
             break;
            }
           }
           $324 = $flags$3 | 2;
           $flags$4 = $324;
          }
         } else {
          $flags$4 = $flags$3;
         }
        } while(0);
        $325 = (($cffface) + 12|0);
        HEAP32[$325>>2] = $flags$4;
       }
       $326 = HEAP32[$51>>2]|0;
       $327 = ($326|0)==(65535);
       if ($327) {
        $328 = (($cffface) + 8|0);
        $329 = HEAP32[$328>>2]|0;
        $330 = $329 | 512;
        HEAP32[$328>>2] = $330;
       } else {
        $or$cond7 = $327 | $161;
        if (!($or$cond7)) {
         $331 = (($cffface) + 8|0);
         $332 = HEAP32[$331>>2]|0;
         $333 = $332 | 4096;
         HEAP32[$331>>2] = $333;
        }
       }
       $334 = (($cffface) + 36|0);
       $335 = HEAP32[$334>>2]|0;
       $336 = ($335|0)==(0);
       L126: do {
        if ($336) {
         $362 = 0;$nn$0$lcssa = 0;
         label = 98;
        } else {
         $337 = (($cffface) + 40|0);
         $338 = HEAP32[$337>>2]|0;
         $nn$014 = 0;
         while(1) {
          $341 = (($338) + ($nn$014<<2)|0);
          $342 = HEAP32[$341>>2]|0;
          $343 = (($342) + 8|0);
          $344 = HEAP16[$343>>1]|0;
          $345 = ($344<<16>>16)==(3);
          if ($345) {
           $346 = (($342) + 10|0);
           $347 = HEAP16[$346>>1]|0;
           $348 = ($347<<16>>16)==(1);
           if ($348) {
            $nn$1 = $nn$014;
            break L126;
           }
          } else {
           $349 = ($344<<16>>16)==(0);
           if ($349) {
            $nn$1 = $nn$014;
            break L126;
           }
          }
          $339 = (($nn$014) + 1)|0;
          $340 = ($339>>>0)<($335>>>0);
          if ($340) {
           $nn$014 = $339;
          } else {
           break;
          }
         }
         $phitmp = (($nn$014) + 2)|0;
         $phitmp82 = ($phitmp>>>0)>(15);
         $362 = $335;$nn$0$lcssa = $phitmp82;
         label = 98;
        }
       } while(0);
       if ((label|0) == 98) {
        $brmerge = $161 | $327;
        $brmerge$not = $brmerge ^ 1;
        $or$cond = $nn$0$lcssa | $brmerge$not;
        if ($or$cond) {
         break;
        }
        HEAP32[$cmaprec>>2] = $cffface;
        $350 = (($cmaprec) + 8|0);
        HEAP16[$350>>1] = 3;
        $351 = (($cmaprec) + 10|0);
        HEAP16[$351>>1] = 1;
        $352 = (($cmaprec) + 4|0);
        HEAP32[$352>>2] = 1970170211;
        $353 = (($3) + 204|0);
        $354 = HEAP32[$353>>2]|0;
        $355 = (($354) + 96|0);
        $356 = (_FT_CMap_New($355,0,$cmaprec,0)|0);
        HEAP32[$error>>2] = $356;
        if (!((($356|0) == 0) | (($356|0) == 163))) {
         break;
        }
        HEAP32[$error>>2] = 0;
        $357 = (($cffface) + 92|0);
        $358 = HEAP32[$357>>2]|0;
        $359 = ($358|0)==(0|0);
        if ($359) {
         $360 = HEAP32[$334>>2]|0;
         $361 = ($362|0)==($360|0);
         if ($361) {
          $nn$1 = $362;
         } else {
          $363 = (($cffface) + 40|0);
          $364 = HEAP32[$363>>2]|0;
          $365 = (($364) + ($362<<2)|0);
          $366 = HEAP32[$365>>2]|0;
          HEAP32[$357>>2] = $366;
          $nn$1 = $362;
         }
        } else {
         $nn$1 = $362;
        }
       }
       $367 = ($nn$1>>>0)>(15);
       if (!($367)) {
        $368 = (($39) + 124|0);
        $369 = HEAP32[$368>>2]|0;
        $370 = ($369|0)==(0);
        if (!($370)) {
         HEAP32[$cmaprec>>2] = $cffface;
         $371 = (($cmaprec) + 8|0);
         HEAP16[$371>>1] = 7;
         $372 = (($39) + 120|0);
         $373 = HEAP32[$372>>2]|0;
         $374 = ($373|0)==(0);
         do {
          if ($374) {
           $375 = (($cmaprec) + 10|0);
           HEAP16[$375>>1] = 0;
           $376 = (($cmaprec) + 4|0);
           HEAP32[$376>>2] = 1094995778;
           $377 = (($3) + 204|0);
           $378 = HEAP32[$377>>2]|0;
           $379 = (($378) + 56|0);
           $clazz$0$in = $379;
          } else {
           $380 = ($373|0)==(1);
           $381 = (($cmaprec) + 10|0);
           if ($380) {
            HEAP16[$381>>1] = 1;
            $382 = (($cmaprec) + 4|0);
            HEAP32[$382>>2] = 1094992453;
            $383 = (($3) + 204|0);
            $384 = HEAP32[$383>>2]|0;
            $385 = (($384) + 56|0);
            $clazz$0$in = $385;
            break;
           } else {
            HEAP16[$381>>1] = 2;
            $386 = (($cmaprec) + 4|0);
            HEAP32[$386>>2] = 1094992451;
            $387 = (($3) + 204|0);
            $388 = HEAP32[$387>>2]|0;
            $389 = (($388) + 56|0);
            $clazz$0$in = $389;
            break;
           }
          }
         } while(0);
         $390 = (_FT_CMap_New($clazz$0$in,0,$cmaprec,0)|0);
         HEAP32[$error>>2] = $390;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 112) {
  HEAP32[$error>>2] = 2;
 }
 $391 = HEAP32[$error>>2]|0;
 $$0 = $391;
 STACKTOP = sp;return ($$0|0);
}
function _cff_face_done($cffface) {
 $cffface = $cffface|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($cffface|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($cffface) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($cffface) + 532|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($4) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vi[$7 & 4095]($cffface);
 }
 $8 = (($cffface) + 692|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 _cff_font_done($9);
 $11 = HEAP32[$8>>2]|0;
 _ft_mem_free($2,$11);
 HEAP32[$8>>2] = 0;
 STACKTOP = sp;return;
}
function _cff_driver_init($module) {
 $module = $module|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _cff_driver_done($module) {
 $module = $module|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _cff_parser_init($parser,$code,$object,$library) {
 $parser = $parser|0;
 $code = $code|0;
 $object = $object|0;
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _memset(($parser|0),0,412)|0;
 $0 = (($parser) + 16|0);
 $1 = (($parser) + 404|0);
 HEAP32[$1>>2] = $0;
 $2 = (($parser) + 408|0);
 HEAP32[$2>>2] = $code;
 $3 = (($parser) + 412|0);
 HEAP32[$3>>2] = $object;
 HEAP32[$parser>>2] = $library;
 STACKTOP = sp;return;
}
function _FT_Destroy_Class_cff_field_handlers($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($clazz|0)==(0|0);
 if (!($0)) {
  $1 = HEAP32[$library>>2]|0;
  _ft_mem_free($1,$clazz);
 }
 STACKTOP = sp;return;
}
function _FT_Create_Class_cff_field_handlers($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,1456,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = 4;
 $4 = (($1) + 4|0);
 HEAP32[$4>>2] = 4096;
 $5 = (($1) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = (($1) + 12|0);
 HEAP8[$6>>0] = 4;
 $7 = (($1) + 16|0);
 HEAP32[$7>>2] = 0;
 $8 = (($1) + 20|0);
 HEAP32[$8>>2] = 0;
 $9 = (($1) + 24|0);
 HEAP32[$9>>2] = 0;
 $10 = (($1) + 28|0);
 HEAP32[$10>>2] = 4;
 $11 = (($1) + 32|0);
 HEAP32[$11>>2] = 4097;
 $12 = (($1) + 36|0);
 HEAP32[$12>>2] = 4;
 $13 = (($1) + 40|0);
 HEAP8[$13>>0] = 4;
 $14 = (($1) + 44|0);
 HEAP32[$14>>2] = 0;
 $15 = (($1) + 48|0);
 HEAP32[$15>>2] = 0;
 $16 = (($1) + 52|0);
 HEAP32[$16>>2] = 0;
 $17 = (($1) + 56|0);
 HEAP32[$17>>2] = 4;
 $18 = (($1) + 60|0);
 HEAP32[$18>>2] = 4352;
 $19 = (($1) + 64|0);
 HEAP32[$19>>2] = 8;
 $20 = (($1) + 68|0);
 HEAP8[$20>>0] = 4;
 $21 = (($1) + 72|0);
 HEAP32[$21>>2] = 0;
 $22 = (($1) + 76|0);
 HEAP32[$22>>2] = 0;
 $23 = (($1) + 80|0);
 HEAP32[$23>>2] = 0;
 $24 = (($1) + 84|0);
 HEAP32[$24>>2] = 4;
 $25 = (($1) + 88|0);
 HEAP32[$25>>2] = 4098;
 $26 = (($1) + 92|0);
 HEAP32[$26>>2] = 12;
 $27 = (($1) + 96|0);
 HEAP8[$27>>0] = 4;
 $28 = (($1) + 100|0);
 HEAP32[$28>>2] = 0;
 $29 = (($1) + 104|0);
 HEAP32[$29>>2] = 0;
 $30 = (($1) + 108|0);
 HEAP32[$30>>2] = 0;
 $31 = (($1) + 112|0);
 HEAP32[$31>>2] = 4;
 $32 = (($1) + 116|0);
 HEAP32[$32>>2] = 4099;
 $33 = (($1) + 120|0);
 HEAP32[$33>>2] = 16;
 $34 = (($1) + 124|0);
 HEAP8[$34>>0] = 4;
 $35 = (($1) + 128|0);
 HEAP32[$35>>2] = 0;
 $36 = (($1) + 132|0);
 HEAP32[$36>>2] = 0;
 $37 = (($1) + 136|0);
 HEAP32[$37>>2] = 0;
 $38 = (($1) + 140|0);
 HEAP32[$38>>2] = 4;
 $39 = (($1) + 144|0);
 HEAP32[$39>>2] = 4100;
 $40 = (($1) + 148|0);
 HEAP32[$40>>2] = 20;
 $41 = (($1) + 152|0);
 HEAP8[$41>>0] = 4;
 $42 = (($1) + 156|0);
 HEAP32[$42>>2] = 0;
 $43 = (($1) + 160|0);
 HEAP32[$43>>2] = 0;
 $44 = (($1) + 164|0);
 HEAP32[$44>>2] = 0;
 $45 = (($1) + 168|0);
 HEAP32[$45>>2] = 5;
 $46 = (($1) + 172|0);
 HEAP32[$46>>2] = 4353;
 $47 = (($1) + 176|0);
 HEAP32[$47>>2] = 24;
 $48 = (($1) + 180|0);
 HEAP8[$48>>0] = 1;
 $49 = (($1) + 184|0);
 HEAP32[$49>>2] = 0;
 $50 = (($1) + 188|0);
 HEAP32[$50>>2] = 0;
 $51 = (($1) + 192|0);
 HEAP32[$51>>2] = 0;
 $52 = (($1) + 196|0);
 HEAP32[$52>>2] = 2;
 $53 = (($1) + 200|0);
 HEAP32[$53>>2] = 4354;
 $54 = (($1) + 204|0);
 HEAP32[$54>>2] = 28;
 $55 = (($1) + 208|0);
 HEAP8[$55>>0] = 4;
 $56 = (($1) + 212|0);
 HEAP32[$56>>2] = 0;
 $57 = (($1) + 216|0);
 HEAP32[$57>>2] = 0;
 $58 = (($1) + 220|0);
 HEAP32[$58>>2] = 0;
 $59 = (($1) + 224|0);
 HEAP32[$59>>2] = 2;
 $60 = (($1) + 228|0);
 HEAP32[$60>>2] = 4355;
 $61 = (($1) + 232|0);
 HEAP32[$61>>2] = 32;
 $62 = (($1) + 236|0);
 HEAP8[$62>>0] = 4;
 $63 = (($1) + 240|0);
 HEAP32[$63>>2] = 0;
 $64 = (($1) + 244|0);
 HEAP32[$64>>2] = 0;
 $65 = (($1) + 248|0);
 HEAP32[$65>>2] = 0;
 $66 = (($1) + 252|0);
 HEAP32[$66>>2] = 2;
 $67 = (($1) + 256|0);
 HEAP32[$67>>2] = 4356;
 $68 = (($1) + 260|0);
 HEAP32[$68>>2] = 36;
 $69 = (($1) + 264|0);
 HEAP8[$69>>0] = 4;
 $70 = (($1) + 268|0);
 HEAP32[$70>>2] = 0;
 $71 = (($1) + 272|0);
 HEAP32[$71>>2] = 0;
 $72 = (($1) + 276|0);
 HEAP32[$72>>2] = 0;
 $73 = (($1) + 280|0);
 HEAP32[$73>>2] = 1;
 $74 = (($1) + 284|0);
 HEAP32[$74>>2] = 4357;
 $75 = (($1) + 288|0);
 HEAP32[$75>>2] = 40;
 $76 = (($1) + 292|0);
 HEAP8[$76>>0] = 4;
 $77 = (($1) + 296|0);
 HEAP32[$77>>2] = 0;
 $78 = (($1) + 300|0);
 HEAP32[$78>>2] = 0;
 $79 = (($1) + 304|0);
 HEAP32[$79>>2] = 0;
 $80 = (($1) + 308|0);
 HEAP32[$80>>2] = 1;
 $81 = (($1) + 312|0);
 HEAP32[$81>>2] = 4358;
 $82 = (($1) + 316|0);
 HEAP32[$82>>2] = 44;
 $83 = (($1) + 320|0);
 HEAP8[$83>>0] = 4;
 $84 = (($1) + 324|0);
 HEAP32[$84>>2] = 0;
 $85 = (($1) + 328|0);
 HEAP32[$85>>2] = 0;
 $86 = (($1) + 332|0);
 HEAP32[$86>>2] = 0;
 $87 = (($1) + 336|0);
 HEAP32[$87>>2] = 7;
 $88 = (($1) + 340|0);
 HEAP32[$88>>2] = 4359;
 $89 = (($1) + 344|0);
 HEAP32[$89>>2] = 0;
 $90 = (($1) + 348|0);
 HEAP8[$90>>0] = 0;
 $91 = (($1) + 352|0);
 HEAP32[$91>>2] = 3423;
 $92 = (($1) + 356|0);
 HEAP32[$92>>2] = 0;
 $93 = (($1) + 360|0);
 HEAP32[$93>>2] = 0;
 $94 = (($1) + 364|0);
 HEAP32[$94>>2] = 1;
 $95 = (($1) + 368|0);
 HEAP32[$95>>2] = 4109;
 $96 = (($1) + 372|0);
 HEAP32[$96>>2] = 80;
 $97 = (($1) + 376|0);
 HEAP8[$97>>0] = 4;
 $98 = (($1) + 380|0);
 HEAP32[$98>>2] = 0;
 $99 = (($1) + 384|0);
 HEAP32[$99>>2] = 0;
 $100 = (($1) + 388|0);
 HEAP32[$100>>2] = 0;
 $101 = (($1) + 392|0);
 HEAP32[$101>>2] = 7;
 $102 = (($1) + 396|0);
 HEAP32[$102>>2] = 4101;
 $103 = (($1) + 400|0);
 HEAP32[$103>>2] = 0;
 $104 = (($1) + 404|0);
 HEAP8[$104>>0] = 0;
 $105 = (($1) + 408|0);
 HEAP32[$105>>2] = 3424;
 $106 = (($1) + 412|0);
 HEAP32[$106>>2] = 0;
 $107 = (($1) + 416|0);
 HEAP32[$107>>2] = 0;
 $108 = (($1) + 420|0);
 HEAP32[$108>>2] = 1;
 $109 = (($1) + 424|0);
 HEAP32[$109>>2] = 4360;
 $110 = (($1) + 428|0);
 HEAP32[$110>>2] = 100;
 $111 = (($1) + 432|0);
 HEAP8[$111>>0] = 4;
 $112 = (($1) + 436|0);
 HEAP32[$112>>2] = 0;
 $113 = (($1) + 440|0);
 HEAP32[$113>>2] = 0;
 $114 = (($1) + 444|0);
 HEAP32[$114>>2] = 0;
 $115 = (($1) + 448|0);
 HEAP32[$115>>2] = 1;
 $116 = (($1) + 452|0);
 HEAP32[$116>>2] = 4111;
 $117 = (($1) + 456|0);
 HEAP32[$117>>2] = 104;
 $118 = (($1) + 460|0);
 HEAP8[$118>>0] = 4;
 $119 = (($1) + 464|0);
 HEAP32[$119>>2] = 0;
 $120 = (($1) + 468|0);
 HEAP32[$120>>2] = 0;
 $121 = (($1) + 472|0);
 HEAP32[$121>>2] = 0;
 $122 = (($1) + 476|0);
 HEAP32[$122>>2] = 1;
 $123 = (($1) + 480|0);
 HEAP32[$123>>2] = 4112;
 $124 = (($1) + 484|0);
 HEAP32[$124>>2] = 108;
 $125 = (($1) + 488|0);
 HEAP8[$125>>0] = 4;
 $126 = (($1) + 492|0);
 HEAP32[$126>>2] = 0;
 $127 = (($1) + 496|0);
 HEAP32[$127>>2] = 0;
 $128 = (($1) + 500|0);
 HEAP32[$128>>2] = 0;
 $129 = (($1) + 504|0);
 HEAP32[$129>>2] = 1;
 $130 = (($1) + 508|0);
 HEAP32[$130>>2] = 4113;
 $131 = (($1) + 512|0);
 HEAP32[$131>>2] = 112;
 $132 = (($1) + 516|0);
 HEAP8[$132>>0] = 4;
 $133 = (($1) + 520|0);
 HEAP32[$133>>2] = 0;
 $134 = (($1) + 524|0);
 HEAP32[$134>>2] = 0;
 $135 = (($1) + 528|0);
 HEAP32[$135>>2] = 0;
 $136 = (($1) + 532|0);
 HEAP32[$136>>2] = 7;
 $137 = (($1) + 536|0);
 HEAP32[$137>>2] = 4114;
 $138 = (($1) + 540|0);
 HEAP32[$138>>2] = 0;
 $139 = (($1) + 544|0);
 HEAP8[$139>>0] = 0;
 $140 = (($1) + 548|0);
 HEAP32[$140>>2] = 3425;
 $141 = (($1) + 552|0);
 HEAP32[$141>>2] = 0;
 $142 = (($1) + 556|0);
 HEAP32[$142>>2] = 0;
 $143 = (($1) + 560|0);
 HEAP32[$143>>2] = 1;
 $144 = (($1) + 564|0);
 HEAP32[$144>>2] = 4372;
 $145 = (($1) + 568|0);
 HEAP32[$145>>2] = 124;
 $146 = (($1) + 572|0);
 HEAP8[$146>>0] = 4;
 $147 = (($1) + 576|0);
 HEAP32[$147>>2] = 0;
 $148 = (($1) + 580|0);
 HEAP32[$148>>2] = 0;
 $149 = (($1) + 584|0);
 HEAP32[$149>>2] = 0;
 $150 = (($1) + 588|0);
 HEAP32[$150>>2] = 4;
 $151 = (($1) + 592|0);
 HEAP32[$151>>2] = 4373;
 $152 = (($1) + 596|0);
 HEAP32[$152>>2] = 128;
 $153 = (($1) + 600|0);
 HEAP8[$153>>0] = 4;
 $154 = (($1) + 604|0);
 HEAP32[$154>>2] = 0;
 $155 = (($1) + 608|0);
 HEAP32[$155>>2] = 0;
 $156 = (($1) + 612|0);
 HEAP32[$156>>2] = 0;
 $157 = (($1) + 616|0);
 HEAP32[$157>>2] = 7;
 $158 = (($1) + 620|0);
 HEAP32[$158>>2] = 4382;
 $159 = (($1) + 624|0);
 HEAP32[$159>>2] = 0;
 $160 = (($1) + 628|0);
 HEAP8[$160>>0] = 0;
 $161 = (($1) + 632|0);
 HEAP32[$161>>2] = 3426;
 $162 = (($1) + 636|0);
 HEAP32[$162>>2] = 0;
 $163 = (($1) + 640|0);
 HEAP32[$163>>2] = 0;
 $164 = (($1) + 644|0);
 HEAP32[$164>>2] = 1;
 $165 = (($1) + 648|0);
 HEAP32[$165>>2] = 4383;
 $166 = (($1) + 652|0);
 HEAP32[$166>>2] = 144;
 $167 = (($1) + 656|0);
 HEAP8[$167>>0] = 4;
 $168 = (($1) + 660|0);
 HEAP32[$168>>2] = 0;
 $169 = (($1) + 664|0);
 HEAP32[$169>>2] = 0;
 $170 = (($1) + 668|0);
 HEAP32[$170>>2] = 0;
 $171 = (($1) + 672|0);
 HEAP32[$171>>2] = 1;
 $172 = (($1) + 676|0);
 HEAP32[$172>>2] = 4384;
 $173 = (($1) + 680|0);
 HEAP32[$173>>2] = 148;
 $174 = (($1) + 684|0);
 HEAP8[$174>>0] = 4;
 $175 = (($1) + 688|0);
 HEAP32[$175>>2] = 0;
 $176 = (($1) + 692|0);
 HEAP32[$176>>2] = 0;
 $177 = (($1) + 696|0);
 HEAP32[$177>>2] = 0;
 $178 = (($1) + 700|0);
 HEAP32[$178>>2] = 1;
 $179 = (($1) + 704|0);
 HEAP32[$179>>2] = 4385;
 $180 = (($1) + 708|0);
 HEAP32[$180>>2] = 152;
 $181 = (($1) + 712|0);
 HEAP8[$181>>0] = 4;
 $182 = (($1) + 716|0);
 HEAP32[$182>>2] = 0;
 $183 = (($1) + 720|0);
 HEAP32[$183>>2] = 0;
 $184 = (($1) + 724|0);
 HEAP32[$184>>2] = 0;
 $185 = (($1) + 728|0);
 HEAP32[$185>>2] = 1;
 $186 = (($1) + 732|0);
 HEAP32[$186>>2] = 4386;
 $187 = (($1) + 736|0);
 HEAP32[$187>>2] = 156;
 $188 = (($1) + 740|0);
 HEAP8[$188>>0] = 4;
 $189 = (($1) + 744|0);
 HEAP32[$189>>2] = 0;
 $190 = (($1) + 748|0);
 HEAP32[$190>>2] = 0;
 $191 = (($1) + 752|0);
 HEAP32[$191>>2] = 0;
 $192 = (($1) + 756|0);
 HEAP32[$192>>2] = 1;
 $193 = (($1) + 760|0);
 HEAP32[$193>>2] = 4387;
 $194 = (($1) + 764|0);
 HEAP32[$194>>2] = 160;
 $195 = (($1) + 768|0);
 HEAP8[$195>>0] = 4;
 $196 = (($1) + 772|0);
 HEAP32[$196>>2] = 0;
 $197 = (($1) + 776|0);
 HEAP32[$197>>2] = 0;
 $198 = (($1) + 780|0);
 HEAP32[$198>>2] = 0;
 $199 = (($1) + 784|0);
 HEAP32[$199>>2] = 1;
 $200 = (($1) + 788|0);
 HEAP32[$200>>2] = 4388;
 $201 = (($1) + 792|0);
 HEAP32[$201>>2] = 164;
 $202 = (($1) + 796|0);
 HEAP8[$202>>0] = 4;
 $203 = (($1) + 800|0);
 HEAP32[$203>>2] = 0;
 $204 = (($1) + 804|0);
 HEAP32[$204>>2] = 0;
 $205 = (($1) + 808|0);
 HEAP32[$205>>2] = 0;
 $206 = (($1) + 812|0);
 HEAP32[$206>>2] = 1;
 $207 = (($1) + 816|0);
 HEAP32[$207>>2] = 4389;
 $208 = (($1) + 820|0);
 HEAP32[$208>>2] = 168;
 $209 = (($1) + 824|0);
 HEAP8[$209>>0] = 4;
 $210 = (($1) + 828|0);
 HEAP32[$210>>2] = 0;
 $211 = (($1) + 832|0);
 HEAP32[$211>>2] = 0;
 $212 = (($1) + 836|0);
 HEAP32[$212>>2] = 0;
 $213 = (($1) + 840|0);
 HEAP32[$213>>2] = 4;
 $214 = (($1) + 844|0);
 HEAP32[$214>>2] = 4390;
 $215 = (($1) + 848|0);
 HEAP32[$215>>2] = 172;
 $216 = (($1) + 852|0);
 HEAP8[$216>>0] = 4;
 $217 = (($1) + 856|0);
 HEAP32[$217>>2] = 0;
 $218 = (($1) + 860|0);
 HEAP32[$218>>2] = 0;
 $219 = (($1) + 864|0);
 HEAP32[$219>>2] = 0;
 $220 = (($1) + 868|0);
 HEAP32[$220>>2] = 6;
 $221 = (($1) + 872|0);
 HEAP32[$221>>2] = 8198;
 $222 = (($1) + 876|0);
 HEAP32[$222>>2] = 4;
 $223 = (($1) + 880|0);
 HEAP8[$223>>0] = 4;
 $224 = (($1) + 884|0);
 HEAP32[$224>>2] = 0;
 $225 = (($1) + 888|0);
 HEAP32[$225>>2] = 14;
 $226 = (($1) + 892|0);
 HEAP32[$226>>2] = 0;
 $227 = (($1) + 896|0);
 HEAP32[$227>>2] = 6;
 $228 = (($1) + 900|0);
 HEAP32[$228>>2] = 8199;
 $229 = (($1) + 904|0);
 HEAP32[$229>>2] = 60;
 $230 = (($1) + 908|0);
 HEAP8[$230>>0] = 4;
 $231 = (($1) + 912|0);
 HEAP32[$231>>2] = 0;
 $232 = (($1) + 916|0);
 HEAP32[$232>>2] = 10;
 $233 = (($1) + 920|0);
 HEAP32[$233>>2] = 1;
 $234 = (($1) + 924|0);
 HEAP32[$234>>2] = 6;
 $235 = (($1) + 928|0);
 HEAP32[$235>>2] = 8200;
 $236 = (($1) + 932|0);
 HEAP32[$236>>2] = 100;
 $237 = (($1) + 936|0);
 HEAP8[$237>>0] = 4;
 $238 = (($1) + 940|0);
 HEAP32[$238>>2] = 0;
 $239 = (($1) + 944|0);
 HEAP32[$239>>2] = 14;
 $240 = (($1) + 948|0);
 HEAP32[$240>>2] = 2;
 $241 = (($1) + 952|0);
 HEAP32[$241>>2] = 6;
 $242 = (($1) + 956|0);
 HEAP32[$242>>2] = 8201;
 $243 = (($1) + 960|0);
 HEAP32[$243>>2] = 156;
 $244 = (($1) + 964|0);
 HEAP8[$244>>0] = 4;
 $245 = (($1) + 968|0);
 HEAP32[$245>>2] = 0;
 $246 = (($1) + 972|0);
 HEAP32[$246>>2] = 10;
 $247 = (($1) + 976|0);
 HEAP32[$247>>2] = 3;
 $248 = (($1) + 980|0);
 HEAP32[$248>>2] = 3;
 $249 = (($1) + 984|0);
 HEAP32[$249>>2] = 8457;
 $250 = (($1) + 988|0);
 HEAP32[$250>>2] = 196;
 $251 = (($1) + 992|0);
 HEAP8[$251>>0] = 4;
 $252 = (($1) + 996|0);
 HEAP32[$252>>2] = 0;
 $253 = (($1) + 1000|0);
 HEAP32[$253>>2] = 0;
 $254 = (($1) + 1004|0);
 HEAP32[$254>>2] = 0;
 $255 = (($1) + 1008|0);
 HEAP32[$255>>2] = 1;
 $256 = (($1) + 1012|0);
 HEAP32[$256>>2] = 8458;
 $257 = (($1) + 1016|0);
 HEAP32[$257>>2] = 200;
 $258 = (($1) + 1020|0);
 HEAP8[$258>>0] = 4;
 $259 = (($1) + 1024|0);
 HEAP32[$259>>2] = 0;
 $260 = (($1) + 1028|0);
 HEAP32[$260>>2] = 0;
 $261 = (($1) + 1032|0);
 HEAP32[$261>>2] = 0;
 $262 = (($1) + 1036|0);
 HEAP32[$262>>2] = 1;
 $263 = (($1) + 1040|0);
 HEAP32[$263>>2] = 8459;
 $264 = (($1) + 1044|0);
 HEAP32[$264>>2] = 204;
 $265 = (($1) + 1048|0);
 HEAP8[$265>>0] = 4;
 $266 = (($1) + 1052|0);
 HEAP32[$266>>2] = 0;
 $267 = (($1) + 1056|0);
 HEAP32[$267>>2] = 0;
 $268 = (($1) + 1060|0);
 HEAP32[$268>>2] = 0;
 $269 = (($1) + 1064|0);
 HEAP32[$269>>2] = 1;
 $270 = (($1) + 1068|0);
 HEAP32[$270>>2] = 8202;
 $271 = (($1) + 1072|0);
 HEAP32[$271>>2] = 208;
 $272 = (($1) + 1076|0);
 HEAP8[$272>>0] = 4;
 $273 = (($1) + 1080|0);
 HEAP32[$273>>2] = 0;
 $274 = (($1) + 1084|0);
 HEAP32[$274>>2] = 0;
 $275 = (($1) + 1088|0);
 HEAP32[$275>>2] = 0;
 $276 = (($1) + 1092|0);
 HEAP32[$276>>2] = 1;
 $277 = (($1) + 1096|0);
 HEAP32[$277>>2] = 8203;
 $278 = (($1) + 1100|0);
 HEAP32[$278>>2] = 212;
 $279 = (($1) + 1104|0);
 HEAP8[$279>>0] = 4;
 $280 = (($1) + 1108|0);
 HEAP32[$280>>2] = 0;
 $281 = (($1) + 1112|0);
 HEAP32[$281>>2] = 0;
 $282 = (($1) + 1116|0);
 HEAP32[$282>>2] = 0;
 $283 = (($1) + 1120|0);
 HEAP32[$283>>2] = 6;
 $284 = (($1) + 1124|0);
 HEAP32[$284>>2] = 8460;
 $285 = (($1) + 1128|0);
 HEAP32[$285>>2] = 220;
 $286 = (($1) + 1132|0);
 HEAP8[$286>>0] = 4;
 $287 = (($1) + 1136|0);
 HEAP32[$287>>2] = 0;
 $288 = (($1) + 1140|0);
 HEAP32[$288>>2] = 13;
 $289 = (($1) + 1144|0);
 HEAP32[$289>>2] = 216;
 $290 = (($1) + 1148|0);
 HEAP32[$290>>2] = 6;
 $291 = (($1) + 1152|0);
 HEAP32[$291>>2] = 8461;
 $292 = (($1) + 1156|0);
 HEAP32[$292>>2] = 272;
 $293 = (($1) + 1160|0);
 HEAP8[$293>>0] = 4;
 $294 = (($1) + 1164|0);
 HEAP32[$294>>2] = 0;
 $295 = (($1) + 1168|0);
 HEAP32[$295>>2] = 13;
 $296 = (($1) + 1172|0);
 HEAP32[$296>>2] = 217;
 $297 = (($1) + 1176|0);
 HEAP32[$297>>2] = 5;
 $298 = (($1) + 1180|0);
 HEAP32[$298>>2] = 8462;
 $299 = (($1) + 1184|0);
 HEAP32[$299>>2] = 324;
 $300 = (($1) + 1188|0);
 HEAP8[$300>>0] = 1;
 $301 = (($1) + 1192|0);
 HEAP32[$301>>2] = 0;
 $302 = (($1) + 1196|0);
 HEAP32[$302>>2] = 0;
 $303 = (($1) + 1200|0);
 HEAP32[$303>>2] = 0;
 $304 = (($1) + 1204|0);
 HEAP32[$304>>2] = 2;
 $305 = (($1) + 1208|0);
 HEAP32[$305>>2] = 8463;
 $306 = (($1) + 1212|0);
 HEAP32[$306>>2] = 328;
 $307 = (($1) + 1216|0);
 HEAP8[$307>>0] = 4;
 $308 = (($1) + 1220|0);
 HEAP32[$308>>2] = 0;
 $309 = (($1) + 1224|0);
 HEAP32[$309>>2] = 0;
 $310 = (($1) + 1228|0);
 HEAP32[$310>>2] = 0;
 $311 = (($1) + 1232|0);
 HEAP32[$311>>2] = 1;
 $312 = (($1) + 1236|0);
 HEAP32[$312>>2] = 8464;
 $313 = (($1) + 1240|0);
 HEAP32[$313>>2] = 332;
 $314 = (($1) + 1244|0);
 HEAP8[$314>>0] = 4;
 $315 = (($1) + 1248|0);
 HEAP32[$315>>2] = 0;
 $316 = (($1) + 1252|0);
 HEAP32[$316>>2] = 0;
 $317 = (($1) + 1256|0);
 HEAP32[$317>>2] = 0;
 $318 = (($1) + 1260|0);
 HEAP32[$318>>2] = 1;
 $319 = (($1) + 1264|0);
 HEAP32[$319>>2] = 8465;
 $320 = (($1) + 1268|0);
 HEAP32[$320>>2] = 336;
 $321 = (($1) + 1272|0);
 HEAP8[$321>>0] = 4;
 $322 = (($1) + 1276|0);
 HEAP32[$322>>2] = 0;
 $323 = (($1) + 1280|0);
 HEAP32[$323>>2] = 0;
 $324 = (($1) + 1284|0);
 HEAP32[$324>>2] = 0;
 $325 = (($1) + 1288|0);
 HEAP32[$325>>2] = 2;
 $326 = (($1) + 1292|0);
 HEAP32[$326>>2] = 8466;
 $327 = (($1) + 1296|0);
 HEAP32[$327>>2] = 340;
 $328 = (($1) + 1300|0);
 HEAP8[$328>>0] = 4;
 $329 = (($1) + 1304|0);
 HEAP32[$329>>2] = 0;
 $330 = (($1) + 1308|0);
 HEAP32[$330>>2] = 0;
 $331 = (($1) + 1312|0);
 HEAP32[$331>>2] = 0;
 $332 = (($1) + 1316|0);
 HEAP32[$332>>2] = 1;
 $333 = (($1) + 1320|0);
 HEAP32[$333>>2] = 8467;
 $334 = (($1) + 1324|0);
 HEAP32[$334>>2] = 344;
 $335 = (($1) + 1328|0);
 HEAP8[$335>>0] = 4;
 $336 = (($1) + 1332|0);
 HEAP32[$336>>2] = 0;
 $337 = (($1) + 1336|0);
 HEAP32[$337>>2] = 0;
 $338 = (($1) + 1340|0);
 HEAP32[$338>>2] = 0;
 $339 = (($1) + 1344|0);
 HEAP32[$339>>2] = 1;
 $340 = (($1) + 1348|0);
 HEAP32[$340>>2] = 8211;
 $341 = (($1) + 1352|0);
 HEAP32[$341>>2] = 348;
 $342 = (($1) + 1356|0);
 HEAP8[$342>>0] = 4;
 $343 = (($1) + 1360|0);
 HEAP32[$343>>2] = 0;
 $344 = (($1) + 1364|0);
 HEAP32[$344>>2] = 0;
 $345 = (($1) + 1368|0);
 HEAP32[$345>>2] = 0;
 $346 = (($1) + 1372|0);
 HEAP32[$346>>2] = 1;
 $347 = (($1) + 1376|0);
 HEAP32[$347>>2] = 8212;
 $348 = (($1) + 1380|0);
 HEAP32[$348>>2] = 352;
 $349 = (($1) + 1384|0);
 HEAP8[$349>>0] = 4;
 $350 = (($1) + 1388|0);
 HEAP32[$350>>2] = 0;
 $351 = (($1) + 1392|0);
 HEAP32[$351>>2] = 0;
 $352 = (($1) + 1396|0);
 HEAP32[$352>>2] = 0;
 $353 = (($1) + 1400|0);
 HEAP32[$353>>2] = 1;
 $354 = (($1) + 1404|0);
 HEAP32[$354>>2] = 8213;
 $355 = (($1) + 1408|0);
 HEAP32[$355>>2] = 356;
 $356 = (($1) + 1412|0);
 HEAP8[$356>>0] = 4;
 $357 = (($1) + 1416|0);
 $358 = (($1) + 1444|0);
 HEAP32[$358>>2] = 0;
 $359 = (($1) + 1448|0);
 HEAP32[$359>>2] = 0;
 $360 = (($1) + 1452|0);
 HEAP32[$360>>2] = 0;
 ;HEAP32[$357+0>>2]=0|0;HEAP32[$357+4>>2]=0|0;HEAP32[$357+8>>2]=0|0;HEAP32[$357+12>>2]=0|0;HEAP32[$357+16>>2]=0|0;HEAP32[$357+20>>2]=0|0;HEAP8[$357+24>>0]=0|0;
 HEAP32[$output_class>>2] = $1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _cff_parse_font_matrix($parser) {
 $parser = $parser|0;
 var $$0$i = 0, $$idx = 0, $$idx$val = 0, $$idx11$val = 0, $$idx3$val = 0, $$idx5$val = 0, $$idx7$val = 0, $$idx9$val = 0, $$val = 0, $$val10 = 0, $$val2 = 0, $$val2$pre = 0, $$val4 = 0, $$val4$pre = 0, $$val6 = 0, $$val6$pre = 0, $$val8 = 0, $$val8$pre = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $error$0 = 0, $integer_length$0$lcssa$i = 0, $integer_length$02$i = 0, $or$cond = 0, $scaling = 0, $sext$i = 0, $sext$i$i = 0, $sext$i13 = 0, $sext$i17 = 0, $sext$i21 = 0, $sext$i25 = 0, $val$0$i = 0, $val$0$i$i = 0, $val$0$i1$i = 0, $val$0$i14 = 0, $val$0$i18 = 0, $val$0$i22 = 0, $val$0$i26 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $scaling = sp;
 $0 = (($parser) + 412|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 72|0);
 $3 = (($1) + 68|0);
 $4 = (($parser) + 404|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($parser) + 40|0);
 $7 = ($5>>>0)<($6>>>0);
 if ($7) {
  $error$0 = 161;
  STACKTOP = sp;return ($error$0|0);
 }
 $8 = (($1) + 48|0);
 $9 = (($parser) + 16|0);
 $10 = (($1) + 64|0);
 HEAP8[$10>>0] = 1;
 $$val = HEAP32[$9>>2]|0;
 $$idx = (($parser) + 20|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $11 = HEAP8[$$val>>0]|0;
 $12 = ($11<<24>>24)==(30);
 do {
  if ($12) {
   $13 = (_cff_parse_real($$val,$$idx$val,0,$scaling)|0);
   $$0$i = $13;
  } else {
   $14 = (($$val) + 1|0);
   $15 = $11&255;
   do {
    if ((($11<<24>>24) == 29)) {
     $26 = (($$val) + 5|0);
     $27 = ($26>>>0)>($$idx$val>>>0);
     if ($27) {
      $val$0$i1$i = 0;
     } else {
      $28 = HEAP8[$14>>0]|0;
      $29 = $28&255;
      $30 = $29 << 24;
      $31 = (($$val) + 2|0);
      $32 = HEAP8[$31>>0]|0;
      $33 = $32&255;
      $34 = $33 << 16;
      $35 = $34 | $30;
      $36 = (($$val) + 3|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = $37&255;
      $39 = $38 << 8;
      $40 = $35 | $39;
      $41 = (($$val) + 4|0);
      $42 = HEAP8[$41>>0]|0;
      $43 = $42&255;
      $44 = $40 | $43;
      $val$0$i$i = $44;
      label = 16;
     }
    } else if ((($11<<24>>24) == 28)) {
     $16 = (($$val) + 3|0);
     $17 = ($16>>>0)>($$idx$val>>>0);
     if ($17) {
      $val$0$i1$i = 0;
     } else {
      $18 = HEAP8[$14>>0]|0;
      $19 = $18&255;
      $20 = $19 << 8;
      $21 = (($$val) + 2|0);
      $22 = HEAP8[$21>>0]|0;
      $23 = $22&255;
      $24 = $20 | $23;
      $sext$i$i = $24 << 16;
      $25 = $sext$i$i >> 16;
      $val$0$i1$i = $25;
     }
    } else {
     $45 = ($11&255)<(247);
     if ($45) {
      $46 = (($15) + -139)|0;
      $val$0$i$i = $46;
      label = 16;
      break;
     }
     $47 = ($11&255)<(251);
     $48 = (($$val) + 2|0);
     $49 = ($48>>>0)>($$idx$val>>>0);
     if ($47) {
      if ($49) {
       $val$0$i1$i = 0;
       break;
      }
      $50 = $15 << 8;
      $51 = (($50) + -63232)|0;
      $52 = HEAP8[$14>>0]|0;
      $53 = $52&255;
      $54 = $53 | $51;
      $55 = (($54) + 108)|0;
      $val$0$i$i = $55;
      label = 16;
      break;
     } else {
      if ($49) {
       $val$0$i1$i = 0;
       break;
      }
      $56 = (251 - ($15))|0;
      $57 = $56 << 8;
      $58 = HEAP8[$14>>0]|0;
      $59 = $58&255;
      $60 = (($57) + -108)|0;
      $61 = (($60) - ($59))|0;
      $val$0$i$i = $61;
      label = 16;
      break;
     }
    }
   } while(0);
   if ((label|0) == 16) {
    $62 = ($val$0$i$i|0)>(32767);
    if ($62) {
     $integer_length$02$i = 5;
     while(1) {
      $65 = (808984 + ($integer_length$02$i<<2)|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ($val$0$i$i|0)<($66|0);
      $64 = (($integer_length$02$i) + 1)|0;
      if ($67) {
       $integer_length$0$lcssa$i = $integer_length$02$i;
       break;
      }
      $63 = ($64|0)<(10);
      if ($63) {
       $integer_length$02$i = $64;
      } else {
       $integer_length$0$lcssa$i = $64;
       break;
      }
     }
     $68 = (($integer_length$0$lcssa$i) + -5)|0;
     $69 = (808984 + ($68<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($val$0$i$i|0) / ($70|0))&-1;
     $72 = ($71|0)>(32767);
     if ($72) {
      $73 = (($integer_length$0$lcssa$i) + -4)|0;
      HEAP32[$scaling>>2] = $73;
      $74 = (808984 + ($73<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = (_FT_DivFix($val$0$i$i,$75)|0);
      $$0$i = $76;
      break;
     } else {
      HEAP32[$scaling>>2] = $68;
      $77 = (_FT_DivFix($val$0$i$i,$70)|0);
      $$0$i = $77;
      break;
     }
    } else {
     $val$0$i1$i = $val$0$i$i;
    }
   }
   HEAP32[$scaling>>2] = 0;
   $78 = $val$0$i1$i << 16;
   $$0$i = $78;
  }
 } while(0);
 HEAP32[$8>>2] = $$0$i;
 $79 = HEAP32[$scaling>>2]|0;
 $80 = (0 - ($79))|0;
 HEAP32[$scaling>>2] = $80;
 $81 = ($79|0)>(0);
 $82 = ($80|0)>(9);
 $or$cond = $81 | $82;
 if ($or$cond) {
  HEAP32[$8>>2] = 65536;
  $83 = (($1) + 56|0);
  HEAP32[$83>>2] = 0;
  $84 = (($1) + 52|0);
  HEAP32[$84>>2] = 0;
  $85 = (($1) + 60|0);
  HEAP32[$85>>2] = 65536;
  HEAP32[$2>>2] = 0;
  $86 = (($1) + 76|0);
  HEAP32[$86>>2] = 0;
  HEAP32[$3>>2] = 1;
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 $87 = (($parser) + 24|0);
 $$val10 = HEAP32[$$idx>>2]|0;
 $$idx11$val = HEAP32[$87>>2]|0;
 $88 = HEAP8[$$val10>>0]|0;
 $89 = ($88<<24>>24)==(30);
 if ($89) {
  $90 = (_cff_parse_real($$val10,$$idx11$val,$80,0)|0);
  $$val8$pre = HEAP32[$87>>2]|0;
  $$val8 = $$val8$pre;$144 = $90;
 } else {
  $91 = (($$val10) + 1|0);
  $92 = $88&255;
  do {
   if ((($88<<24>>24) == 29)) {
    $103 = (($$val10) + 5|0);
    $104 = ($103>>>0)>($$idx11$val>>>0);
    if ($104) {
     $val$0$i = 0;
    } else {
     $105 = HEAP8[$91>>0]|0;
     $106 = $105&255;
     $107 = $106 << 24;
     $108 = (($$val10) + 2|0);
     $109 = HEAP8[$108>>0]|0;
     $110 = $109&255;
     $111 = $110 << 16;
     $112 = $111 | $107;
     $113 = (($$val10) + 3|0);
     $114 = HEAP8[$113>>0]|0;
     $115 = $114&255;
     $116 = $115 << 8;
     $117 = $112 | $116;
     $118 = (($$val10) + 4|0);
     $119 = HEAP8[$118>>0]|0;
     $120 = $119&255;
     $121 = $117 | $120;
     $val$0$i = $121;
    }
   } else if ((($88<<24>>24) == 28)) {
    $93 = (($$val10) + 3|0);
    $94 = ($93>>>0)>($$idx11$val>>>0);
    if ($94) {
     $val$0$i = 0;
    } else {
     $95 = HEAP8[$91>>0]|0;
     $96 = $95&255;
     $97 = $96 << 8;
     $98 = (($$val10) + 2|0);
     $99 = HEAP8[$98>>0]|0;
     $100 = $99&255;
     $101 = $97 | $100;
     $sext$i = $101 << 16;
     $102 = $sext$i >> 16;
     $val$0$i = $102;
    }
   } else {
    $122 = ($88&255)<(247);
    if ($122) {
     $123 = (($92) + -139)|0;
     $val$0$i = $123;
     break;
    }
    $124 = ($88&255)<(251);
    $125 = (($$val10) + 2|0);
    $126 = ($125>>>0)>($$idx11$val>>>0);
    if ($124) {
     if ($126) {
      $val$0$i = 0;
      break;
     }
     $127 = $92 << 8;
     $128 = (($127) + -63232)|0;
     $129 = HEAP8[$91>>0]|0;
     $130 = $129&255;
     $131 = $130 | $128;
     $132 = (($131) + 108)|0;
     $val$0$i = $132;
     break;
    } else {
     if ($126) {
      $val$0$i = 0;
      break;
     }
     $133 = (251 - ($92))|0;
     $134 = $133 << 8;
     $135 = HEAP8[$91>>0]|0;
     $136 = $135&255;
     $137 = (($134) + -108)|0;
     $138 = (($137) - ($136))|0;
     $val$0$i = $138;
     break;
    }
   }
  } while(0);
  $139 = (808984 + ($80<<2)|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = $val$0$i << 16;
  $142 = Math_imul($141, $140)|0;
  $$val8 = $$idx11$val;$144 = $142;
 }
 $143 = (($1) + 56|0);
 HEAP32[$143>>2] = $144;
 $145 = (($parser) + 28|0);
 $146 = HEAP32[$scaling>>2]|0;
 $$idx9$val = HEAP32[$145>>2]|0;
 $147 = HEAP8[$$val8>>0]|0;
 $148 = ($147<<24>>24)==(30);
 if ($148) {
  $149 = (_cff_parse_real($$val8,$$idx9$val,$146,0)|0);
  $$val6$pre = HEAP32[$145>>2]|0;
  $$val6 = $$val6$pre;$203 = $149;
 } else {
  $150 = (($$val8) + 1|0);
  $151 = $147&255;
  do {
   if ((($147<<24>>24) == 29)) {
    $162 = (($$val8) + 5|0);
    $163 = ($162>>>0)>($$idx9$val>>>0);
    if ($163) {
     $val$0$i14 = 0;
    } else {
     $164 = HEAP8[$150>>0]|0;
     $165 = $164&255;
     $166 = $165 << 24;
     $167 = (($$val8) + 2|0);
     $168 = HEAP8[$167>>0]|0;
     $169 = $168&255;
     $170 = $169 << 16;
     $171 = $170 | $166;
     $172 = (($$val8) + 3|0);
     $173 = HEAP8[$172>>0]|0;
     $174 = $173&255;
     $175 = $174 << 8;
     $176 = $171 | $175;
     $177 = (($$val8) + 4|0);
     $178 = HEAP8[$177>>0]|0;
     $179 = $178&255;
     $180 = $176 | $179;
     $val$0$i14 = $180;
    }
   } else if ((($147<<24>>24) == 28)) {
    $152 = (($$val8) + 3|0);
    $153 = ($152>>>0)>($$idx9$val>>>0);
    if ($153) {
     $val$0$i14 = 0;
    } else {
     $154 = HEAP8[$150>>0]|0;
     $155 = $154&255;
     $156 = $155 << 8;
     $157 = (($$val8) + 2|0);
     $158 = HEAP8[$157>>0]|0;
     $159 = $158&255;
     $160 = $156 | $159;
     $sext$i13 = $160 << 16;
     $161 = $sext$i13 >> 16;
     $val$0$i14 = $161;
    }
   } else {
    $181 = ($147&255)<(247);
    if ($181) {
     $182 = (($151) + -139)|0;
     $val$0$i14 = $182;
     break;
    }
    $183 = ($147&255)<(251);
    $184 = (($$val8) + 2|0);
    $185 = ($184>>>0)>($$idx9$val>>>0);
    if ($183) {
     if ($185) {
      $val$0$i14 = 0;
      break;
     }
     $186 = $151 << 8;
     $187 = (($186) + -63232)|0;
     $188 = HEAP8[$150>>0]|0;
     $189 = $188&255;
     $190 = $189 | $187;
     $191 = (($190) + 108)|0;
     $val$0$i14 = $191;
     break;
    } else {
     if ($185) {
      $val$0$i14 = 0;
      break;
     }
     $192 = (251 - ($151))|0;
     $193 = $192 << 8;
     $194 = HEAP8[$150>>0]|0;
     $195 = $194&255;
     $196 = (($193) + -108)|0;
     $197 = (($196) - ($195))|0;
     $val$0$i14 = $197;
     break;
    }
   }
  } while(0);
  $198 = (808984 + ($146<<2)|0);
  $199 = HEAP32[$198>>2]|0;
  $200 = $val$0$i14 << 16;
  $201 = Math_imul($200, $199)|0;
  $$val6 = $$idx9$val;$203 = $201;
 }
 $202 = (($1) + 52|0);
 HEAP32[$202>>2] = $203;
 $204 = (($parser) + 32|0);
 $205 = HEAP32[$scaling>>2]|0;
 $$idx7$val = HEAP32[$204>>2]|0;
 $206 = HEAP8[$$val6>>0]|0;
 $207 = ($206<<24>>24)==(30);
 if ($207) {
  $208 = (_cff_parse_real($$val6,$$idx7$val,$205,0)|0);
  $$val4$pre = HEAP32[$204>>2]|0;
  $$val4 = $$val4$pre;$262 = $208;
 } else {
  $209 = (($$val6) + 1|0);
  $210 = $206&255;
  do {
   if ((($206<<24>>24) == 29)) {
    $221 = (($$val6) + 5|0);
    $222 = ($221>>>0)>($$idx7$val>>>0);
    if ($222) {
     $val$0$i18 = 0;
    } else {
     $223 = HEAP8[$209>>0]|0;
     $224 = $223&255;
     $225 = $224 << 24;
     $226 = (($$val6) + 2|0);
     $227 = HEAP8[$226>>0]|0;
     $228 = $227&255;
     $229 = $228 << 16;
     $230 = $229 | $225;
     $231 = (($$val6) + 3|0);
     $232 = HEAP8[$231>>0]|0;
     $233 = $232&255;
     $234 = $233 << 8;
     $235 = $230 | $234;
     $236 = (($$val6) + 4|0);
     $237 = HEAP8[$236>>0]|0;
     $238 = $237&255;
     $239 = $235 | $238;
     $val$0$i18 = $239;
    }
   } else if ((($206<<24>>24) == 28)) {
    $211 = (($$val6) + 3|0);
    $212 = ($211>>>0)>($$idx7$val>>>0);
    if ($212) {
     $val$0$i18 = 0;
    } else {
     $213 = HEAP8[$209>>0]|0;
     $214 = $213&255;
     $215 = $214 << 8;
     $216 = (($$val6) + 2|0);
     $217 = HEAP8[$216>>0]|0;
     $218 = $217&255;
     $219 = $215 | $218;
     $sext$i17 = $219 << 16;
     $220 = $sext$i17 >> 16;
     $val$0$i18 = $220;
    }
   } else {
    $240 = ($206&255)<(247);
    if ($240) {
     $241 = (($210) + -139)|0;
     $val$0$i18 = $241;
     break;
    }
    $242 = ($206&255)<(251);
    $243 = (($$val6) + 2|0);
    $244 = ($243>>>0)>($$idx7$val>>>0);
    if ($242) {
     if ($244) {
      $val$0$i18 = 0;
      break;
     }
     $245 = $210 << 8;
     $246 = (($245) + -63232)|0;
     $247 = HEAP8[$209>>0]|0;
     $248 = $247&255;
     $249 = $248 | $246;
     $250 = (($249) + 108)|0;
     $val$0$i18 = $250;
     break;
    } else {
     if ($244) {
      $val$0$i18 = 0;
      break;
     }
     $251 = (251 - ($210))|0;
     $252 = $251 << 8;
     $253 = HEAP8[$209>>0]|0;
     $254 = $253&255;
     $255 = (($252) + -108)|0;
     $256 = (($255) - ($254))|0;
     $val$0$i18 = $256;
     break;
    }
   }
  } while(0);
  $257 = (808984 + ($205<<2)|0);
  $258 = HEAP32[$257>>2]|0;
  $259 = $val$0$i18 << 16;
  $260 = Math_imul($259, $258)|0;
  $$val4 = $$idx7$val;$262 = $260;
 }
 $261 = (($1) + 60|0);
 HEAP32[$261>>2] = $262;
 $263 = (($parser) + 36|0);
 $264 = HEAP32[$scaling>>2]|0;
 $$idx5$val = HEAP32[$263>>2]|0;
 $265 = HEAP8[$$val4>>0]|0;
 $266 = ($265<<24>>24)==(30);
 if ($266) {
  $267 = (_cff_parse_real($$val4,$$idx5$val,$264,0)|0);
  $$val2$pre = HEAP32[$263>>2]|0;
  $$val2 = $$val2$pre;$320 = $267;
 } else {
  $268 = (($$val4) + 1|0);
  $269 = $265&255;
  do {
   if ((($265<<24>>24) == 29)) {
    $280 = (($$val4) + 5|0);
    $281 = ($280>>>0)>($$idx5$val>>>0);
    if ($281) {
     $val$0$i22 = 0;
    } else {
     $282 = HEAP8[$268>>0]|0;
     $283 = $282&255;
     $284 = $283 << 24;
     $285 = (($$val4) + 2|0);
     $286 = HEAP8[$285>>0]|0;
     $287 = $286&255;
     $288 = $287 << 16;
     $289 = $288 | $284;
     $290 = (($$val4) + 3|0);
     $291 = HEAP8[$290>>0]|0;
     $292 = $291&255;
     $293 = $292 << 8;
     $294 = $289 | $293;
     $295 = (($$val4) + 4|0);
     $296 = HEAP8[$295>>0]|0;
     $297 = $296&255;
     $298 = $294 | $297;
     $val$0$i22 = $298;
    }
   } else if ((($265<<24>>24) == 28)) {
    $270 = (($$val4) + 3|0);
    $271 = ($270>>>0)>($$idx5$val>>>0);
    if ($271) {
     $val$0$i22 = 0;
    } else {
     $272 = HEAP8[$268>>0]|0;
     $273 = $272&255;
     $274 = $273 << 8;
     $275 = (($$val4) + 2|0);
     $276 = HEAP8[$275>>0]|0;
     $277 = $276&255;
     $278 = $274 | $277;
     $sext$i21 = $278 << 16;
     $279 = $sext$i21 >> 16;
     $val$0$i22 = $279;
    }
   } else {
    $299 = ($265&255)<(247);
    if ($299) {
     $300 = (($269) + -139)|0;
     $val$0$i22 = $300;
     break;
    }
    $301 = ($265&255)<(251);
    $302 = (($$val4) + 2|0);
    $303 = ($302>>>0)>($$idx5$val>>>0);
    if ($301) {
     if ($303) {
      $val$0$i22 = 0;
      break;
     }
     $304 = $269 << 8;
     $305 = (($304) + -63232)|0;
     $306 = HEAP8[$268>>0]|0;
     $307 = $306&255;
     $308 = $307 | $305;
     $309 = (($308) + 108)|0;
     $val$0$i22 = $309;
     break;
    } else {
     if ($303) {
      $val$0$i22 = 0;
      break;
     }
     $310 = (251 - ($269))|0;
     $311 = $310 << 8;
     $312 = HEAP8[$268>>0]|0;
     $313 = $312&255;
     $314 = (($311) + -108)|0;
     $315 = (($314) - ($313))|0;
     $val$0$i22 = $315;
     break;
    }
   }
  } while(0);
  $316 = (808984 + ($264<<2)|0);
  $317 = HEAP32[$316>>2]|0;
  $318 = $val$0$i22 << 16;
  $319 = Math_imul($318, $317)|0;
  $$val2 = $$idx5$val;$320 = $319;
 }
 HEAP32[$2>>2] = $320;
 $321 = HEAP32[$scaling>>2]|0;
 $$idx3$val = HEAP32[$6>>2]|0;
 $322 = HEAP8[$$val2>>0]|0;
 $323 = ($322<<24>>24)==(30);
 if ($323) {
  $324 = (_cff_parse_real($$val2,$$idx3$val,$321,0)|0);
  $378 = $324;
 } else {
  $325 = (($$val2) + 1|0);
  $326 = $322&255;
  do {
   if ((($322<<24>>24) == 28)) {
    $327 = (($$val2) + 3|0);
    $328 = ($327>>>0)>($$idx3$val>>>0);
    if ($328) {
     $val$0$i26 = 0;
    } else {
     $329 = HEAP8[$325>>0]|0;
     $330 = $329&255;
     $331 = $330 << 8;
     $332 = (($$val2) + 2|0);
     $333 = HEAP8[$332>>0]|0;
     $334 = $333&255;
     $335 = $331 | $334;
     $sext$i25 = $335 << 16;
     $336 = $sext$i25 >> 16;
     $val$0$i26 = $336;
    }
   } else if ((($322<<24>>24) == 29)) {
    $337 = (($$val2) + 5|0);
    $338 = ($337>>>0)>($$idx3$val>>>0);
    if ($338) {
     $val$0$i26 = 0;
    } else {
     $339 = HEAP8[$325>>0]|0;
     $340 = $339&255;
     $341 = $340 << 24;
     $342 = (($$val2) + 2|0);
     $343 = HEAP8[$342>>0]|0;
     $344 = $343&255;
     $345 = $344 << 16;
     $346 = $345 | $341;
     $347 = (($$val2) + 3|0);
     $348 = HEAP8[$347>>0]|0;
     $349 = $348&255;
     $350 = $349 << 8;
     $351 = $346 | $350;
     $352 = (($$val2) + 4|0);
     $353 = HEAP8[$352>>0]|0;
     $354 = $353&255;
     $355 = $351 | $354;
     $val$0$i26 = $355;
    }
   } else {
    $356 = ($322&255)<(247);
    if ($356) {
     $357 = (($326) + -139)|0;
     $val$0$i26 = $357;
     break;
    }
    $358 = ($322&255)<(251);
    $359 = (($$val2) + 2|0);
    $360 = ($359>>>0)>($$idx3$val>>>0);
    if ($358) {
     if ($360) {
      $val$0$i26 = 0;
      break;
     }
     $361 = $326 << 8;
     $362 = (($361) + -63232)|0;
     $363 = HEAP8[$325>>0]|0;
     $364 = $363&255;
     $365 = $364 | $362;
     $366 = (($365) + 108)|0;
     $val$0$i26 = $366;
     break;
    } else {
     if ($360) {
      $val$0$i26 = 0;
      break;
     }
     $367 = (251 - ($326))|0;
     $368 = $367 << 8;
     $369 = HEAP8[$325>>0]|0;
     $370 = $369&255;
     $371 = (($368) + -108)|0;
     $372 = (($371) - ($370))|0;
     $val$0$i26 = $372;
     break;
    }
   }
  } while(0);
  $373 = (808984 + ($321<<2)|0);
  $374 = HEAP32[$373>>2]|0;
  $375 = $val$0$i26 << 16;
  $376 = Math_imul($375, $374)|0;
  $378 = $376;
 }
 $377 = (($1) + 76|0);
 HEAP32[$377>>2] = $378;
 $379 = HEAP32[$scaling>>2]|0;
 $380 = (808984 + ($379<<2)|0);
 $381 = HEAP32[$380>>2]|0;
 HEAP32[$3>>2] = $381;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _cff_parse_font_bbox($parser) {
 $parser = $parser|0;
 var $$idx$val = 0, $$idx2$val = 0, $$idx4$val = 0, $$idx6$val = 0, $$val = 0, $$val1 = 0, $$val3 = 0, $$val5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error$0 = 0, $sext$i = 0;
 var $sext$i12 = 0, $sext$i16 = 0, $sext$i8 = 0, $val$0$i = 0, $val$0$i13 = 0, $val$0$i17 = 0, $val$0$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($parser) + 412|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($parser) + 404|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($parser) + 32|0);
 $5 = ($3>>>0)<($4>>>0);
 if ($5) {
  $error$0 = 161;
  STACKTOP = sp;return ($error$0|0);
 }
 $6 = (($1) + 84|0);
 $7 = (($parser) + 16|0);
 $8 = (($parser) + 20|0);
 $$val5 = HEAP32[$7>>2]|0;
 $$idx6$val = HEAP32[$8>>2]|0;
 $9 = HEAP8[$$val5>>0]|0;
 $10 = ($9<<24>>24)==(30);
 if ($10) {
  $11 = (_cff_parse_real($$val5,$$idx6$val,0,0)|0);
  $61 = $11;
 } else {
  $12 = (($$val5) + 1|0);
  $13 = $9&255;
  do {
   if ((($9<<24>>24) == 28)) {
    $14 = (($$val5) + 3|0);
    $15 = ($14>>>0)>($$idx6$val>>>0);
    if ($15) {
     $val$0$i = 0;
    } else {
     $16 = HEAP8[$12>>0]|0;
     $17 = $16&255;
     $18 = $17 << 8;
     $19 = (($$val5) + 2|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = $20&255;
     $22 = $18 | $21;
     $sext$i = $22 << 16;
     $23 = $sext$i >> 16;
     $val$0$i = $23;
    }
   } else if ((($9<<24>>24) == 29)) {
    $24 = (($$val5) + 5|0);
    $25 = ($24>>>0)>($$idx6$val>>>0);
    if ($25) {
     $val$0$i = 0;
    } else {
     $26 = HEAP8[$12>>0]|0;
     $27 = $26&255;
     $28 = $27 << 24;
     $29 = (($$val5) + 2|0);
     $30 = HEAP8[$29>>0]|0;
     $31 = $30&255;
     $32 = $31 << 16;
     $33 = $32 | $28;
     $34 = (($$val5) + 3|0);
     $35 = HEAP8[$34>>0]|0;
     $36 = $35&255;
     $37 = $36 << 8;
     $38 = $33 | $37;
     $39 = (($$val5) + 4|0);
     $40 = HEAP8[$39>>0]|0;
     $41 = $40&255;
     $42 = $38 | $41;
     $val$0$i = $42;
    }
   } else {
    $43 = ($9&255)<(247);
    if ($43) {
     $44 = (($13) + -139)|0;
     $val$0$i = $44;
     break;
    }
    $45 = ($9&255)<(251);
    $46 = (($$val5) + 2|0);
    $47 = ($46>>>0)>($$idx6$val>>>0);
    if ($45) {
     if ($47) {
      $val$0$i = 0;
      break;
     }
     $48 = $13 << 8;
     $49 = (($48) + -63232)|0;
     $50 = HEAP8[$12>>0]|0;
     $51 = $50&255;
     $52 = $51 | $49;
     $53 = (($52) + 108)|0;
     $val$0$i = $53;
     break;
    } else {
     if ($47) {
      $val$0$i = 0;
      break;
     }
     $54 = (251 - ($13))|0;
     $55 = $54 << 8;
     $56 = HEAP8[$12>>0]|0;
     $57 = $56&255;
     $58 = (($55) + -108)|0;
     $59 = (($58) - ($57))|0;
     $val$0$i = $59;
     break;
    }
   }
  } while(0);
  $60 = $val$0$i << 16;
  $61 = $60;
 }
 $62 = (_FT_RoundFix($61)|0);
 HEAP32[$6>>2] = $62;
 $63 = (($parser) + 24|0);
 $$val3 = HEAP32[$8>>2]|0;
 $$idx4$val = HEAP32[$63>>2]|0;
 $64 = HEAP8[$$val3>>0]|0;
 $65 = ($64<<24>>24)==(30);
 if ($65) {
  $66 = (_cff_parse_real($$val3,$$idx4$val,0,0)|0);
  $116 = $66;
 } else {
  $67 = (($$val3) + 1|0);
  $68 = $64&255;
  do {
   if ((($64<<24>>24) == 29)) {
    $79 = (($$val3) + 5|0);
    $80 = ($79>>>0)>($$idx4$val>>>0);
    if ($80) {
     $val$0$i9 = 0;
    } else {
     $81 = HEAP8[$67>>0]|0;
     $82 = $81&255;
     $83 = $82 << 24;
     $84 = (($$val3) + 2|0);
     $85 = HEAP8[$84>>0]|0;
     $86 = $85&255;
     $87 = $86 << 16;
     $88 = $87 | $83;
     $89 = (($$val3) + 3|0);
     $90 = HEAP8[$89>>0]|0;
     $91 = $90&255;
     $92 = $91 << 8;
     $93 = $88 | $92;
     $94 = (($$val3) + 4|0);
     $95 = HEAP8[$94>>0]|0;
     $96 = $95&255;
     $97 = $93 | $96;
     $val$0$i9 = $97;
    }
   } else if ((($64<<24>>24) == 28)) {
    $69 = (($$val3) + 3|0);
    $70 = ($69>>>0)>($$idx4$val>>>0);
    if ($70) {
     $val$0$i9 = 0;
    } else {
     $71 = HEAP8[$67>>0]|0;
     $72 = $71&255;
     $73 = $72 << 8;
     $74 = (($$val3) + 2|0);
     $75 = HEAP8[$74>>0]|0;
     $76 = $75&255;
     $77 = $73 | $76;
     $sext$i8 = $77 << 16;
     $78 = $sext$i8 >> 16;
     $val$0$i9 = $78;
    }
   } else {
    $98 = ($64&255)<(247);
    if ($98) {
     $99 = (($68) + -139)|0;
     $val$0$i9 = $99;
     break;
    }
    $100 = ($64&255)<(251);
    $101 = (($$val3) + 2|0);
    $102 = ($101>>>0)>($$idx4$val>>>0);
    if ($100) {
     if ($102) {
      $val$0$i9 = 0;
      break;
     }
     $103 = $68 << 8;
     $104 = (($103) + -63232)|0;
     $105 = HEAP8[$67>>0]|0;
     $106 = $105&255;
     $107 = $106 | $104;
     $108 = (($107) + 108)|0;
     $val$0$i9 = $108;
     break;
    } else {
     if ($102) {
      $val$0$i9 = 0;
      break;
     }
     $109 = (251 - ($68))|0;
     $110 = $109 << 8;
     $111 = HEAP8[$67>>0]|0;
     $112 = $111&255;
     $113 = (($110) + -108)|0;
     $114 = (($113) - ($112))|0;
     $val$0$i9 = $114;
     break;
    }
   }
  } while(0);
  $115 = $val$0$i9 << 16;
  $116 = $115;
 }
 $117 = (_FT_RoundFix($116)|0);
 $118 = (($1) + 88|0);
 HEAP32[$118>>2] = $117;
 $119 = (($parser) + 28|0);
 $$val1 = HEAP32[$63>>2]|0;
 $$idx2$val = HEAP32[$119>>2]|0;
 $120 = HEAP8[$$val1>>0]|0;
 $121 = ($120<<24>>24)==(30);
 if ($121) {
  $122 = (_cff_parse_real($$val1,$$idx2$val,0,0)|0);
  $172 = $122;
 } else {
  $123 = (($$val1) + 1|0);
  $124 = $120&255;
  do {
   if ((($120<<24>>24) == 28)) {
    $125 = (($$val1) + 3|0);
    $126 = ($125>>>0)>($$idx2$val>>>0);
    if ($126) {
     $val$0$i13 = 0;
    } else {
     $127 = HEAP8[$123>>0]|0;
     $128 = $127&255;
     $129 = $128 << 8;
     $130 = (($$val1) + 2|0);
     $131 = HEAP8[$130>>0]|0;
     $132 = $131&255;
     $133 = $129 | $132;
     $sext$i12 = $133 << 16;
     $134 = $sext$i12 >> 16;
     $val$0$i13 = $134;
    }
   } else if ((($120<<24>>24) == 29)) {
    $135 = (($$val1) + 5|0);
    $136 = ($135>>>0)>($$idx2$val>>>0);
    if ($136) {
     $val$0$i13 = 0;
    } else {
     $137 = HEAP8[$123>>0]|0;
     $138 = $137&255;
     $139 = $138 << 24;
     $140 = (($$val1) + 2|0);
     $141 = HEAP8[$140>>0]|0;
     $142 = $141&255;
     $143 = $142 << 16;
     $144 = $143 | $139;
     $145 = (($$val1) + 3|0);
     $146 = HEAP8[$145>>0]|0;
     $147 = $146&255;
     $148 = $147 << 8;
     $149 = $144 | $148;
     $150 = (($$val1) + 4|0);
     $151 = HEAP8[$150>>0]|0;
     $152 = $151&255;
     $153 = $149 | $152;
     $val$0$i13 = $153;
    }
   } else {
    $154 = ($120&255)<(247);
    if ($154) {
     $155 = (($124) + -139)|0;
     $val$0$i13 = $155;
     break;
    }
    $156 = ($120&255)<(251);
    $157 = (($$val1) + 2|0);
    $158 = ($157>>>0)>($$idx2$val>>>0);
    if ($156) {
     if ($158) {
      $val$0$i13 = 0;
      break;
     }
     $159 = $124 << 8;
     $160 = (($159) + -63232)|0;
     $161 = HEAP8[$123>>0]|0;
     $162 = $161&255;
     $163 = $162 | $160;
     $164 = (($163) + 108)|0;
     $val$0$i13 = $164;
     break;
    } else {
     if ($158) {
      $val$0$i13 = 0;
      break;
     }
     $165 = (251 - ($124))|0;
     $166 = $165 << 8;
     $167 = HEAP8[$123>>0]|0;
     $168 = $167&255;
     $169 = (($166) + -108)|0;
     $170 = (($169) - ($168))|0;
     $val$0$i13 = $170;
     break;
    }
   }
  } while(0);
  $171 = $val$0$i13 << 16;
  $172 = $171;
 }
 $173 = (_FT_RoundFix($172)|0);
 $174 = (($1) + 92|0);
 HEAP32[$174>>2] = $173;
 $$val = HEAP32[$119>>2]|0;
 $$idx$val = HEAP32[$4>>2]|0;
 $175 = HEAP8[$$val>>0]|0;
 $176 = ($175<<24>>24)==(30);
 if ($176) {
  $177 = (_cff_parse_real($$val,$$idx$val,0,0)|0);
  $227 = $177;
 } else {
  $178 = (($$val) + 1|0);
  $179 = $175&255;
  do {
   if ((($175<<24>>24) == 29)) {
    $190 = (($$val) + 5|0);
    $191 = ($190>>>0)>($$idx$val>>>0);
    if ($191) {
     $val$0$i17 = 0;
    } else {
     $192 = HEAP8[$178>>0]|0;
     $193 = $192&255;
     $194 = $193 << 24;
     $195 = (($$val) + 2|0);
     $196 = HEAP8[$195>>0]|0;
     $197 = $196&255;
     $198 = $197 << 16;
     $199 = $198 | $194;
     $200 = (($$val) + 3|0);
     $201 = HEAP8[$200>>0]|0;
     $202 = $201&255;
     $203 = $202 << 8;
     $204 = $199 | $203;
     $205 = (($$val) + 4|0);
     $206 = HEAP8[$205>>0]|0;
     $207 = $206&255;
     $208 = $204 | $207;
     $val$0$i17 = $208;
    }
   } else if ((($175<<24>>24) == 28)) {
    $180 = (($$val) + 3|0);
    $181 = ($180>>>0)>($$idx$val>>>0);
    if ($181) {
     $val$0$i17 = 0;
    } else {
     $182 = HEAP8[$178>>0]|0;
     $183 = $182&255;
     $184 = $183 << 8;
     $185 = (($$val) + 2|0);
     $186 = HEAP8[$185>>0]|0;
     $187 = $186&255;
     $188 = $184 | $187;
     $sext$i16 = $188 << 16;
     $189 = $sext$i16 >> 16;
     $val$0$i17 = $189;
    }
   } else {
    $209 = ($175&255)<(247);
    if ($209) {
     $210 = (($179) + -139)|0;
     $val$0$i17 = $210;
     break;
    }
    $211 = ($175&255)<(251);
    $212 = (($$val) + 2|0);
    $213 = ($212>>>0)>($$idx$val>>>0);
    if ($211) {
     if ($213) {
      $val$0$i17 = 0;
      break;
     }
     $214 = $179 << 8;
     $215 = (($214) + -63232)|0;
     $216 = HEAP8[$178>>0]|0;
     $217 = $216&255;
     $218 = $217 | $215;
     $219 = (($218) + 108)|0;
     $val$0$i17 = $219;
     break;
    } else {
     if ($213) {
      $val$0$i17 = 0;
      break;
     }
     $220 = (251 - ($179))|0;
     $221 = $220 << 8;
     $222 = HEAP8[$178>>0]|0;
     $223 = $222&255;
     $224 = (($221) + -108)|0;
     $225 = (($224) - ($223))|0;
     $val$0$i17 = $225;
     break;
    }
   }
  } while(0);
  $226 = $val$0$i17 << 16;
  $227 = $226;
 }
 $228 = (_FT_RoundFix($227)|0);
 $229 = (($1) + 96|0);
 HEAP32[$229>>2] = $228;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _cff_parse_private_dict($parser) {
 $parser = $parser|0;
 var $$idx$val = 0, $$idx2$val = 0, $$val = 0, $$val$pre = 0, $$val1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $error$0 = 0, $sext$i = 0, $sext$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($parser) + 412|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($parser) + 404|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($parser) + 24|0);
 $5 = ($3>>>0)<($4>>>0);
 if ($5) {
  $error$0 = 161;
  STACKTOP = sp;return ($error$0|0);
 }
 $6 = (($parser) + 16|0);
 $7 = (($parser) + 20|0);
 $$val1 = HEAP32[$6>>2]|0;
 $$idx2$val = HEAP32[$7>>2]|0;
 $8 = HEAP8[$$val1>>0]|0;
 $9 = ($8<<24>>24)==(30);
 do {
  if ($9) {
   $10 = (_cff_parse_real($$val1,$$idx2$val,0,0)|0);
   $11 = $10 >> 16;
   $$val$pre = HEAP32[$7>>2]|0;
   $$val = $$val$pre;$61 = $11;
  } else {
   $12 = (($$val1) + 1|0);
   $13 = $8&255;
   if ((($8<<24>>24) == 28)) {
    $14 = (($$val1) + 3|0);
    $15 = ($14>>>0)>($$idx2$val>>>0);
    if ($15) {
     $$val = $$idx2$val;$61 = 0;
     break;
    }
    $16 = HEAP8[$12>>0]|0;
    $17 = $16&255;
    $18 = $17 << 8;
    $19 = (($$val1) + 2|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    $22 = $18 | $21;
    $sext$i = $22 << 16;
    $23 = $sext$i >> 16;
    $$val = $$idx2$val;$61 = $23;
    break;
   } else if ((($8<<24>>24) == 29)) {
    $24 = (($$val1) + 5|0);
    $25 = ($24>>>0)>($$idx2$val>>>0);
    if ($25) {
     $$val = $$idx2$val;$61 = 0;
     break;
    }
    $26 = HEAP8[$12>>0]|0;
    $27 = $26&255;
    $28 = $27 << 24;
    $29 = (($$val1) + 2|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = $30&255;
    $32 = $31 << 16;
    $33 = $32 | $28;
    $34 = (($$val1) + 3|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = $35&255;
    $37 = $36 << 8;
    $38 = $33 | $37;
    $39 = (($$val1) + 4|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = $40&255;
    $42 = $38 | $41;
    $$val = $$idx2$val;$61 = $42;
    break;
   } else {
    $43 = ($8&255)<(247);
    if ($43) {
     $44 = (($13) + -139)|0;
     $$val = $$idx2$val;$61 = $44;
     break;
    }
    $45 = ($8&255)<(251);
    $46 = (($$val1) + 2|0);
    $47 = ($46>>>0)>($$idx2$val>>>0);
    if ($45) {
     if ($47) {
      $$val = $$idx2$val;$61 = 0;
      break;
     }
     $48 = $13 << 8;
     $49 = (($48) + -63232)|0;
     $50 = HEAP8[$12>>0]|0;
     $51 = $50&255;
     $52 = $51 | $49;
     $53 = (($52) + 108)|0;
     $$val = $$idx2$val;$61 = $53;
     break;
    } else {
     if ($47) {
      $$val = $$idx2$val;$61 = 0;
      break;
     }
     $54 = (251 - ($13))|0;
     $55 = $54 << 8;
     $56 = HEAP8[$12>>0]|0;
     $57 = $56&255;
     $58 = (($55) + -108)|0;
     $59 = (($58) - ($57))|0;
     $$val = $$idx2$val;$61 = $59;
     break;
    }
   }
  }
 } while(0);
 $60 = (($1) + 120|0);
 HEAP32[$60>>2] = $61;
 $$idx$val = HEAP32[$4>>2]|0;
 $62 = HEAP8[$$val>>0]|0;
 $63 = ($62<<24>>24)==(30);
 do {
  if ($63) {
   $64 = (_cff_parse_real($$val,$$idx$val,0,0)|0);
   $65 = $64 >> 16;
   $115 = $65;
  } else {
   $66 = (($$val) + 1|0);
   $67 = $62&255;
   if ((($62<<24>>24) == 28)) {
    $68 = (($$val) + 3|0);
    $69 = ($68>>>0)>($$idx$val>>>0);
    if ($69) {
     $115 = 0;
     break;
    }
    $70 = HEAP8[$66>>0]|0;
    $71 = $70&255;
    $72 = $71 << 8;
    $73 = (($$val) + 2|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = $72 | $75;
    $sext$i4 = $76 << 16;
    $77 = $sext$i4 >> 16;
    $115 = $77;
    break;
   } else if ((($62<<24>>24) == 29)) {
    $78 = (($$val) + 5|0);
    $79 = ($78>>>0)>($$idx$val>>>0);
    if ($79) {
     $115 = 0;
     break;
    }
    $80 = HEAP8[$66>>0]|0;
    $81 = $80&255;
    $82 = $81 << 24;
    $83 = (($$val) + 2|0);
    $84 = HEAP8[$83>>0]|0;
    $85 = $84&255;
    $86 = $85 << 16;
    $87 = $86 | $82;
    $88 = (($$val) + 3|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = $89&255;
    $91 = $90 << 8;
    $92 = $87 | $91;
    $93 = (($$val) + 4|0);
    $94 = HEAP8[$93>>0]|0;
    $95 = $94&255;
    $96 = $92 | $95;
    $115 = $96;
    break;
   } else {
    $97 = ($62&255)<(247);
    if ($97) {
     $98 = (($67) + -139)|0;
     $115 = $98;
     break;
    }
    $99 = ($62&255)<(251);
    $100 = (($$val) + 2|0);
    $101 = ($100>>>0)>($$idx$val>>>0);
    if ($99) {
     if ($101) {
      $115 = 0;
      break;
     }
     $102 = $67 << 8;
     $103 = (($102) + -63232)|0;
     $104 = HEAP8[$66>>0]|0;
     $105 = $104&255;
     $106 = $105 | $103;
     $107 = (($106) + 108)|0;
     $115 = $107;
     break;
    } else {
     if ($101) {
      $115 = 0;
      break;
     }
     $108 = (251 - ($67))|0;
     $109 = $108 << 8;
     $110 = HEAP8[$66>>0]|0;
     $111 = $110&255;
     $112 = (($109) + -108)|0;
     $113 = (($112) - ($111))|0;
     $115 = $113;
     break;
    }
   }
  }
 } while(0);
 $114 = (($1) + 116|0);
 HEAP32[$114>>2] = $115;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _cff_parse_cid_ros($parser) {
 $parser = $parser|0;
 var $$idx$val = 0, $$idx2$val = 0, $$idx4$val = 0, $$val = 0, $$val$pre = 0, $$val1 = 0, $$val1$pre = 0, $$val3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error$0 = 0;
 var $sext$i = 0, $sext$i10 = 0, $sext$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($parser) + 412|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($parser) + 404|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($parser) + 28|0);
 $5 = ($3>>>0)<($4>>>0);
 if ($5) {
  $error$0 = 161;
  STACKTOP = sp;return ($error$0|0);
 }
 $6 = (($parser) + 16|0);
 $7 = (($parser) + 20|0);
 $$val3 = HEAP32[$6>>2]|0;
 $$idx4$val = HEAP32[$7>>2]|0;
 $8 = HEAP8[$$val3>>0]|0;
 $9 = ($8<<24>>24)==(30);
 do {
  if ($9) {
   $10 = (_cff_parse_real($$val3,$$idx4$val,0,0)|0);
   $11 = $10 >> 16;
   $$val1$pre = HEAP32[$7>>2]|0;
   $$val1 = $$val1$pre;$61 = $11;
  } else {
   $12 = (($$val3) + 1|0);
   $13 = $8&255;
   if ((($8<<24>>24) == 29)) {
    $24 = (($$val3) + 5|0);
    $25 = ($24>>>0)>($$idx4$val>>>0);
    if ($25) {
     $$val1 = $$idx4$val;$61 = 0;
     break;
    }
    $26 = HEAP8[$12>>0]|0;
    $27 = $26&255;
    $28 = $27 << 24;
    $29 = (($$val3) + 2|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = $30&255;
    $32 = $31 << 16;
    $33 = $32 | $28;
    $34 = (($$val3) + 3|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = $35&255;
    $37 = $36 << 8;
    $38 = $33 | $37;
    $39 = (($$val3) + 4|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = $40&255;
    $42 = $38 | $41;
    $$val1 = $$idx4$val;$61 = $42;
    break;
   } else if ((($8<<24>>24) == 28)) {
    $14 = (($$val3) + 3|0);
    $15 = ($14>>>0)>($$idx4$val>>>0);
    if ($15) {
     $$val1 = $$idx4$val;$61 = 0;
     break;
    }
    $16 = HEAP8[$12>>0]|0;
    $17 = $16&255;
    $18 = $17 << 8;
    $19 = (($$val3) + 2|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    $22 = $18 | $21;
    $sext$i = $22 << 16;
    $23 = $sext$i >> 16;
    $$val1 = $$idx4$val;$61 = $23;
    break;
   } else {
    $43 = ($8&255)<(247);
    if ($43) {
     $44 = (($13) + -139)|0;
     $$val1 = $$idx4$val;$61 = $44;
     break;
    }
    $45 = ($8&255)<(251);
    $46 = (($$val3) + 2|0);
    $47 = ($46>>>0)>($$idx4$val>>>0);
    if ($45) {
     if ($47) {
      $$val1 = $$idx4$val;$61 = 0;
      break;
     }
     $48 = $13 << 8;
     $49 = (($48) + -63232)|0;
     $50 = HEAP8[$12>>0]|0;
     $51 = $50&255;
     $52 = $51 | $49;
     $53 = (($52) + 108)|0;
     $$val1 = $$idx4$val;$61 = $53;
     break;
    } else {
     if ($47) {
      $$val1 = $$idx4$val;$61 = 0;
      break;
     }
     $54 = (251 - ($13))|0;
     $55 = $54 << 8;
     $56 = HEAP8[$12>>0]|0;
     $57 = $56&255;
     $58 = (($55) + -108)|0;
     $59 = (($58) - ($57))|0;
     $$val1 = $$idx4$val;$61 = $59;
     break;
    }
   }
  }
 } while(0);
 $60 = (($1) + 132|0);
 HEAP32[$60>>2] = $61;
 $62 = (($parser) + 24|0);
 $$idx2$val = HEAP32[$62>>2]|0;
 $63 = HEAP8[$$val1>>0]|0;
 $64 = ($63<<24>>24)==(30);
 do {
  if ($64) {
   $65 = (_cff_parse_real($$val1,$$idx2$val,0,0)|0);
   $66 = $65 >> 16;
   $$val$pre = HEAP32[$62>>2]|0;
   $$val = $$val$pre;$116 = $66;
  } else {
   $67 = (($$val1) + 1|0);
   $68 = $63&255;
   if ((($63<<24>>24) == 29)) {
    $79 = (($$val1) + 5|0);
    $80 = ($79>>>0)>($$idx2$val>>>0);
    if ($80) {
     $$val = $$idx2$val;$116 = 0;
     break;
    }
    $81 = HEAP8[$67>>0]|0;
    $82 = $81&255;
    $83 = $82 << 24;
    $84 = (($$val1) + 2|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = $86 << 16;
    $88 = $87 | $83;
    $89 = (($$val1) + 3|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = $90&255;
    $92 = $91 << 8;
    $93 = $88 | $92;
    $94 = (($$val1) + 4|0);
    $95 = HEAP8[$94>>0]|0;
    $96 = $95&255;
    $97 = $93 | $96;
    $$val = $$idx2$val;$116 = $97;
    break;
   } else if ((($63<<24>>24) == 28)) {
    $69 = (($$val1) + 3|0);
    $70 = ($69>>>0)>($$idx2$val>>>0);
    if ($70) {
     $$val = $$idx2$val;$116 = 0;
     break;
    }
    $71 = HEAP8[$67>>0]|0;
    $72 = $71&255;
    $73 = $72 << 8;
    $74 = (($$val1) + 2|0);
    $75 = HEAP8[$74>>0]|0;
    $76 = $75&255;
    $77 = $73 | $76;
    $sext$i6 = $77 << 16;
    $78 = $sext$i6 >> 16;
    $$val = $$idx2$val;$116 = $78;
    break;
   } else {
    $98 = ($63&255)<(247);
    if ($98) {
     $99 = (($68) + -139)|0;
     $$val = $$idx2$val;$116 = $99;
     break;
    }
    $100 = ($63&255)<(251);
    $101 = (($$val1) + 2|0);
    $102 = ($101>>>0)>($$idx2$val>>>0);
    if ($100) {
     if ($102) {
      $$val = $$idx2$val;$116 = 0;
      break;
     }
     $103 = $68 << 8;
     $104 = (($103) + -63232)|0;
     $105 = HEAP8[$67>>0]|0;
     $106 = $105&255;
     $107 = $106 | $104;
     $108 = (($107) + 108)|0;
     $$val = $$idx2$val;$116 = $108;
     break;
    } else {
     if ($102) {
      $$val = $$idx2$val;$116 = 0;
      break;
     }
     $109 = (251 - ($68))|0;
     $110 = $109 << 8;
     $111 = HEAP8[$67>>0]|0;
     $112 = $111&255;
     $113 = (($110) + -108)|0;
     $114 = (($113) - ($112))|0;
     $$val = $$idx2$val;$116 = $114;
     break;
    }
   }
  }
 } while(0);
 $115 = (($1) + 136|0);
 HEAP32[$115>>2] = $116;
 $$idx$val = HEAP32[$4>>2]|0;
 $117 = HEAP8[$$val>>0]|0;
 $118 = ($117<<24>>24)==(30);
 do {
  if ($118) {
   $119 = (_cff_parse_real($$val,$$idx$val,0,0)|0);
   $120 = $119 >> 16;
   $170 = $120;
  } else {
   $121 = (($$val) + 1|0);
   $122 = $117&255;
   if ((($117<<24>>24) == 28)) {
    $123 = (($$val) + 3|0);
    $124 = ($123>>>0)>($$idx$val>>>0);
    if ($124) {
     $170 = 0;
     break;
    }
    $125 = HEAP8[$121>>0]|0;
    $126 = $125&255;
    $127 = $126 << 8;
    $128 = (($$val) + 2|0);
    $129 = HEAP8[$128>>0]|0;
    $130 = $129&255;
    $131 = $127 | $130;
    $sext$i10 = $131 << 16;
    $132 = $sext$i10 >> 16;
    $170 = $132;
    break;
   } else if ((($117<<24>>24) == 29)) {
    $133 = (($$val) + 5|0);
    $134 = ($133>>>0)>($$idx$val>>>0);
    if ($134) {
     $170 = 0;
     break;
    }
    $135 = HEAP8[$121>>0]|0;
    $136 = $135&255;
    $137 = $136 << 24;
    $138 = (($$val) + 2|0);
    $139 = HEAP8[$138>>0]|0;
    $140 = $139&255;
    $141 = $140 << 16;
    $142 = $141 | $137;
    $143 = (($$val) + 3|0);
    $144 = HEAP8[$143>>0]|0;
    $145 = $144&255;
    $146 = $145 << 8;
    $147 = $142 | $146;
    $148 = (($$val) + 4|0);
    $149 = HEAP8[$148>>0]|0;
    $150 = $149&255;
    $151 = $147 | $150;
    $170 = $151;
    break;
   } else {
    $152 = ($117&255)<(247);
    if ($152) {
     $153 = (($122) + -139)|0;
     $170 = $153;
     break;
    }
    $154 = ($117&255)<(251);
    $155 = (($$val) + 2|0);
    $156 = ($155>>>0)>($$idx$val>>>0);
    if ($154) {
     if ($156) {
      $170 = 0;
      break;
     }
     $157 = $122 << 8;
     $158 = (($157) + -63232)|0;
     $159 = HEAP8[$121>>0]|0;
     $160 = $159&255;
     $161 = $160 | $158;
     $162 = (($161) + 108)|0;
     $170 = $162;
     break;
    } else {
     if ($156) {
      $170 = 0;
      break;
     }
     $163 = (251 - ($122))|0;
     $164 = $163 << 8;
     $165 = HEAP8[$121>>0]|0;
     $166 = $165&255;
     $167 = (($164) + -108)|0;
     $168 = (($167) - ($166))|0;
     $170 = $168;
     break;
    }
   }
  }
 } while(0);
 $169 = (($1) + 140|0);
 HEAP32[$169>>2] = $170;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _cff_parser_run($parser,$start,$limit) {
 $parser = $parser|0;
 $start = $start|0;
 $limit = $limit|0;
 var $$ = 0, $$idx$val = 0, $$idx6$val = 0, $$idx8 = 0, $$idx8$val = 0, $$mask = 0, $$p$0 = 0, $$pre = 0, $$val = 0, $$val5 = 0, $$val7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $code$0 = 0, $data$0$idx$val = 0, $data$0$val = 0, $data$029 = 0, $error$3 = 0, $field$024 = 0, $num_args$126 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond4 = 0, $p$0$pn = 0, $p$035 = 0;
 var $p$1 = 0, $p$2 = 0, $p$3 = 0, $q$028 = 0, $sext$i = 0, $sext$i12 = 0, $sext$i16 = 0, $sext$i9 = 0, $val$0 = 0, $val$0$i10 = 0, $val$0$i13 = 0, $val$127 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$parser>>2]|0;
 $1 = (($parser) + 16|0);
 $2 = (($parser) + 404|0);
 HEAP32[$2>>2] = $1;
 $3 = (($parser) + 4|0);
 HEAP32[$3>>2] = $start;
 $4 = (($parser) + 8|0);
 HEAP32[$4>>2] = $limit;
 $5 = (($parser) + 12|0);
 HEAP32[$5>>2] = $start;
 $6 = ($start>>>0)<($limit>>>0);
 if (!($6)) {
  $error$3 = 0;
  STACKTOP = sp;return ($error$3|0);
 }
 $7 = $1;
 $8 = (($parser) + 408|0);
 $9 = (($0) + 204|0);
 $10 = (($parser) + 412|0);
 $$idx8 = (($parser) + 20|0);
 $15 = $1;$p$035 = $start;
 L4: while(1) {
  $11 = HEAP8[$p$035>>0]|0;
  $12 = ($11&255)>(26);
  $13 = ($11<<24>>24)!=(31);
  $or$cond = $12 & $13;
  $14 = $15;
  $16 = (($14) - ($7))|0;
  $17 = $16 >> 2;
  do {
   if ($or$cond) {
    $18 = ($16|0)>(380);
    if ($18) {
     $error$3 = 6;
     label = 96;
     break L4;
    }
    $19 = (($15) + 4|0);
    HEAP32[$2>>2] = $19;
    HEAP32[$15>>2] = $p$035;
    if ((($11<<24>>24) == 30)) {
     $p$0$pn = $p$035;
     while(1) {
      $p$1 = (($p$0$pn) + 1|0);
      $20 = ($p$1>>>0)<($limit>>>0);
      if (!($20)) {
       $error$3 = 0;
       label = 96;
       break L4;
      }
      $21 = HEAP8[$p$1>>0]|0;
      $22 = $21&255;
      $$mask = $22 & 240;
      $23 = ($$mask|0)==(240);
      $24 = $22 & 15;
      $25 = ($24|0)==(15);
      $or$cond3 = $23 | $25;
      if ($or$cond3) {
       $p$3 = $p$1;
       break;
      } else {
       $p$0$pn = $p$1;
      }
     }
    } else if ((($11<<24>>24) == 28)) {
     $26 = (($p$035) + 2|0);
     $p$3 = $26;
     break;
    } else if ((($11<<24>>24) == 29)) {
     $27 = (($p$035) + 4|0);
     $p$3 = $27;
     break;
    } else {
     $28 = ($11&255)>(246);
     $29 = (($p$035) + 1|0);
     $$p$0 = $28 ? $29 : $p$035;
     $p$3 = $$p$0;
     break;
    }
   } else {
    HEAP32[$15>>2] = $p$035;
    $30 = ($11<<24>>24)==(12);
    if ($30) {
     $32 = (($p$035) + 1|0);
     $33 = ($32>>>0)<($limit>>>0);
     if (!($33)) {
      $error$3 = 6;
      label = 96;
      break L4;
     }
     $34 = HEAP8[$32>>0]|0;
     $35 = $34&255;
     $36 = $35 | 256;
     $code$0 = $36;$p$2 = $32;
    } else {
     $31 = $11&255;
     $code$0 = $31;$p$2 = $p$035;
    }
    $37 = HEAP32[$8>>2]|0;
    $38 = $37 | $code$0;
    $39 = HEAP32[$9>>2]|0;
    $40 = (($39) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0);
    L13: do {
     if (!($43)) {
      $55 = $42;$field$024 = $41;
      while(1) {
       $47 = (($field$024) + 4|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ($48|0)==($38|0);
       $45 = (($field$024) + 28|0);
       if ($49) {
        break;
       }
       $44 = HEAP32[$45>>2]|0;
       $46 = ($44|0)==(0);
       if ($46) {
        break L13;
       } else {
        $55 = $44;$field$024 = $45;
       }
      }
      $50 = HEAP32[$10>>2]|0;
      $51 = (($field$024) + 8|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (($50) + ($52)|0);
      $54 = ($55|0)!=(6);
      $56 = ($17|0)==(0);
      $or$cond4 = $54 & $56;
      if ($or$cond4) {
       $error$3 = 6;
       label = 96;
       break L4;
      }
      L19: do {
       switch ($55|0) {
       case 1: case 4: case 5:  {
        $$val7 = HEAP32[$1>>2]|0;
        $$idx8$val = HEAP32[$$idx8>>2]|0;
        $57 = HEAP8[$$val7>>0]|0;
        $58 = ($57<<24>>24)==(30);
        if ($58) {
         $59 = (_cff_parse_real($$val7,$$idx8$val,0,0)|0);
         $60 = $59 >> 16;
         $val$0 = $60;
         break L19;
        }
        $61 = (($$val7) + 1|0);
        $62 = $57&255;
        if ((($57<<24>>24) == 28)) {
         $63 = (($$val7) + 3|0);
         $64 = ($63>>>0)>($$idx8$val>>>0);
         if ($64) {
          $val$0 = 0;
          break L19;
         }
         $65 = HEAP8[$61>>0]|0;
         $66 = $65&255;
         $67 = $66 << 8;
         $68 = (($$val7) + 2|0);
         $69 = HEAP8[$68>>0]|0;
         $70 = $69&255;
         $71 = $67 | $70;
         $sext$i = $71 << 16;
         $72 = $sext$i >> 16;
         $val$0 = $72;
         break L19;
        } else if ((($57<<24>>24) == 29)) {
         $73 = (($$val7) + 5|0);
         $74 = ($73>>>0)>($$idx8$val>>>0);
         if ($74) {
          $val$0 = 0;
          break L19;
         }
         $75 = HEAP8[$61>>0]|0;
         $76 = $75&255;
         $77 = $76 << 24;
         $78 = (($$val7) + 2|0);
         $79 = HEAP8[$78>>0]|0;
         $80 = $79&255;
         $81 = $80 << 16;
         $82 = $81 | $77;
         $83 = (($$val7) + 3|0);
         $84 = HEAP8[$83>>0]|0;
         $85 = $84&255;
         $86 = $85 << 8;
         $87 = $82 | $86;
         $88 = (($$val7) + 4|0);
         $89 = HEAP8[$88>>0]|0;
         $90 = $89&255;
         $91 = $87 | $90;
         $val$0 = $91;
         break L19;
        } else {
         $92 = ($57&255)<(247);
         if ($92) {
          $93 = (($62) + -139)|0;
          $val$0 = $93;
          break L19;
         }
         $94 = ($57&255)<(251);
         $95 = (($$val7) + 2|0);
         $96 = ($95>>>0)>($$idx8$val>>>0);
         if ($94) {
          if ($96) {
           $val$0 = 0;
           break L19;
          }
          $97 = $62 << 8;
          $98 = (($97) + -63232)|0;
          $99 = HEAP8[$61>>0]|0;
          $100 = $99&255;
          $101 = $100 | $98;
          $102 = (($101) + 108)|0;
          $val$0 = $102;
          break L19;
         } else {
          if ($96) {
           $val$0 = 0;
           break L19;
          }
          $103 = (251 - ($62))|0;
          $104 = $103 << 8;
          $105 = HEAP8[$61>>0]|0;
          $106 = $105&255;
          $107 = (($104) + -108)|0;
          $108 = (($107) - ($106))|0;
          $val$0 = $108;
          break L19;
         }
        }
        break;
       }
       case 3:  {
        $$val = HEAP32[$1>>2]|0;
        $$idx$val = HEAP32[$$idx8>>2]|0;
        $161 = HEAP8[$$val>>0]|0;
        $162 = ($161<<24>>24)==(30);
        if ($162) {
         $163 = (_cff_parse_real($$val,$$idx$val,3,0)|0);
         $val$0 = $163;
         break L19;
        }
        $164 = (($$val) + 1|0);
        $165 = $161&255;
        do {
         if ((($161<<24>>24) == 28)) {
          $166 = (($$val) + 3|0);
          $167 = ($166>>>0)>($$idx$val>>>0);
          if ($167) {
           $val$0$i13 = 0;
          } else {
           $168 = HEAP8[$164>>0]|0;
           $169 = $168&255;
           $170 = $169 << 8;
           $171 = (($$val) + 2|0);
           $172 = HEAP8[$171>>0]|0;
           $173 = $172&255;
           $174 = $170 | $173;
           $sext$i12 = $174 << 16;
           $175 = $sext$i12 >> 16;
           $val$0$i13 = $175;
          }
         } else if ((($161<<24>>24) == 29)) {
          $176 = (($$val) + 5|0);
          $177 = ($176>>>0)>($$idx$val>>>0);
          if ($177) {
           $val$0$i13 = 0;
          } else {
           $178 = HEAP8[$164>>0]|0;
           $179 = $178&255;
           $180 = $179 << 24;
           $181 = (($$val) + 2|0);
           $182 = HEAP8[$181>>0]|0;
           $183 = $182&255;
           $184 = $183 << 16;
           $185 = $184 | $180;
           $186 = (($$val) + 3|0);
           $187 = HEAP8[$186>>0]|0;
           $188 = $187&255;
           $189 = $188 << 8;
           $190 = $185 | $189;
           $191 = (($$val) + 4|0);
           $192 = HEAP8[$191>>0]|0;
           $193 = $192&255;
           $194 = $190 | $193;
           $val$0$i13 = $194;
          }
         } else {
          $195 = ($161&255)<(247);
          if ($195) {
           $196 = (($165) + -139)|0;
           $val$0$i13 = $196;
           break;
          }
          $197 = ($161&255)<(251);
          $198 = (($$val) + 2|0);
          $199 = ($198>>>0)>($$idx$val>>>0);
          if ($197) {
           if ($199) {
            $val$0$i13 = 0;
            break;
           }
           $200 = $165 << 8;
           $201 = (($200) + -63232)|0;
           $202 = HEAP8[$164>>0]|0;
           $203 = $202&255;
           $204 = $203 | $201;
           $205 = (($204) + 108)|0;
           $val$0$i13 = $205;
           break;
          } else {
           if ($199) {
            $val$0$i13 = 0;
            break;
           }
           $206 = (251 - ($165))|0;
           $207 = $206 << 8;
           $208 = HEAP8[$164>>0]|0;
           $209 = $208&255;
           $210 = (($207) + -108)|0;
           $211 = (($210) - ($209))|0;
           $val$0$i13 = $211;
           break;
          }
         }
        } while(0);
        $212 = Math_imul($val$0$i13, 65536000)|0;
        $val$0 = $212;
        break;
       }
       case 2:  {
        $$val5 = HEAP32[$1>>2]|0;
        $$idx6$val = HEAP32[$$idx8>>2]|0;
        $109 = HEAP8[$$val5>>0]|0;
        $110 = ($109<<24>>24)==(30);
        if ($110) {
         $111 = (_cff_parse_real($$val5,$$idx6$val,0,0)|0);
         $val$0 = $111;
         break L19;
        }
        $112 = (($$val5) + 1|0);
        $113 = $109&255;
        do {
         if ((($109<<24>>24) == 29)) {
          $124 = (($$val5) + 5|0);
          $125 = ($124>>>0)>($$idx6$val>>>0);
          if ($125) {
           $val$0$i10 = 0;
          } else {
           $126 = HEAP8[$112>>0]|0;
           $127 = $126&255;
           $128 = $127 << 24;
           $129 = (($$val5) + 2|0);
           $130 = HEAP8[$129>>0]|0;
           $131 = $130&255;
           $132 = $131 << 16;
           $133 = $132 | $128;
           $134 = (($$val5) + 3|0);
           $135 = HEAP8[$134>>0]|0;
           $136 = $135&255;
           $137 = $136 << 8;
           $138 = $133 | $137;
           $139 = (($$val5) + 4|0);
           $140 = HEAP8[$139>>0]|0;
           $141 = $140&255;
           $142 = $138 | $141;
           $val$0$i10 = $142;
          }
         } else if ((($109<<24>>24) == 28)) {
          $114 = (($$val5) + 3|0);
          $115 = ($114>>>0)>($$idx6$val>>>0);
          if ($115) {
           $val$0$i10 = 0;
          } else {
           $116 = HEAP8[$112>>0]|0;
           $117 = $116&255;
           $118 = $117 << 8;
           $119 = (($$val5) + 2|0);
           $120 = HEAP8[$119>>0]|0;
           $121 = $120&255;
           $122 = $118 | $121;
           $sext$i9 = $122 << 16;
           $123 = $sext$i9 >> 16;
           $val$0$i10 = $123;
          }
         } else {
          $143 = ($109&255)<(247);
          if ($143) {
           $144 = (($113) + -139)|0;
           $val$0$i10 = $144;
           break;
          }
          $145 = ($109&255)<(251);
          $146 = (($$val5) + 2|0);
          $147 = ($146>>>0)>($$idx6$val>>>0);
          if ($145) {
           if ($147) {
            $val$0$i10 = 0;
            break;
           }
           $148 = $113 << 8;
           $149 = (($148) + -63232)|0;
           $150 = HEAP8[$112>>0]|0;
           $151 = $150&255;
           $152 = $151 | $149;
           $153 = (($152) + 108)|0;
           $val$0$i10 = $153;
           break;
          } else {
           if ($147) {
            $val$0$i10 = 0;
            break;
           }
           $154 = (251 - ($113))|0;
           $155 = $154 << 8;
           $156 = HEAP8[$112>>0]|0;
           $157 = $156&255;
           $158 = (($155) + -108)|0;
           $159 = (($158) - ($157))|0;
           $val$0$i10 = $159;
           break;
          }
         }
        } while(0);
        $160 = $val$0$i10 << 16;
        $val$0 = $160;
        break;
       }
       case 6:  {
        $218 = (($field$024) + 24|0);
        $219 = HEAP32[$218>>2]|0;
        $220 = (($50) + ($219)|0);
        $221 = (($field$024) + 20|0);
        $222 = HEAP32[$221>>2]|0;
        $223 = ($17>>>0)>($222>>>0);
        $$ = $223 ? $222 : $17;
        $224 = $$&255;
        HEAP8[$220>>0] = $224;
        $225 = ($$|0)==(0);
        if ($225) {
         break L13;
        }
        $226 = (($field$024) + 12|0);
        $data$029 = $1;$num_args$126 = $$;$q$028 = $53;$val$127 = 0;
        while(1) {
         $227 = (($data$029) + 4|0);
         $data$0$val = HEAP32[$data$029>>2]|0;
         $data$0$idx$val = HEAP32[$227>>2]|0;
         $228 = HEAP8[$data$0$val>>0]|0;
         $229 = ($228<<24>>24)==(30);
         do {
          if ($229) {
           $230 = (_cff_parse_real($data$0$val,$data$0$idx$val,0,0)|0);
           $231 = $230 >> 16;
           $281 = $231;
          } else {
           $232 = (($data$0$val) + 1|0);
           $233 = $228&255;
           if ((($228<<24>>24) == 28)) {
            $234 = (($data$0$val) + 3|0);
            $235 = ($234>>>0)>($data$0$idx$val>>>0);
            if ($235) {
             $281 = 0;
             break;
            }
            $236 = HEAP8[$232>>0]|0;
            $237 = $236&255;
            $238 = $237 << 8;
            $239 = (($data$0$val) + 2|0);
            $240 = HEAP8[$239>>0]|0;
            $241 = $240&255;
            $242 = $238 | $241;
            $sext$i16 = $242 << 16;
            $243 = $sext$i16 >> 16;
            $281 = $243;
            break;
           } else if ((($228<<24>>24) == 29)) {
            $244 = (($data$0$val) + 5|0);
            $245 = ($244>>>0)>($data$0$idx$val>>>0);
            if ($245) {
             $281 = 0;
             break;
            }
            $246 = HEAP8[$232>>0]|0;
            $247 = $246&255;
            $248 = $247 << 24;
            $249 = (($data$0$val) + 2|0);
            $250 = HEAP8[$249>>0]|0;
            $251 = $250&255;
            $252 = $251 << 16;
            $253 = $252 | $248;
            $254 = (($data$0$val) + 3|0);
            $255 = HEAP8[$254>>0]|0;
            $256 = $255&255;
            $257 = $256 << 8;
            $258 = $253 | $257;
            $259 = (($data$0$val) + 4|0);
            $260 = HEAP8[$259>>0]|0;
            $261 = $260&255;
            $262 = $258 | $261;
            $281 = $262;
            break;
           } else {
            $263 = ($228&255)<(247);
            if ($263) {
             $264 = (($233) + -139)|0;
             $281 = $264;
             break;
            }
            $265 = ($228&255)<(251);
            $266 = (($data$0$val) + 2|0);
            $267 = ($266>>>0)>($data$0$idx$val>>>0);
            if ($265) {
             if ($267) {
              $281 = 0;
              break;
             }
             $268 = $233 << 8;
             $269 = (($268) + -63232)|0;
             $270 = HEAP8[$232>>0]|0;
             $271 = $270&255;
             $272 = $271 | $269;
             $273 = (($272) + 108)|0;
             $281 = $273;
             break;
            } else {
             if ($267) {
              $281 = 0;
              break;
             }
             $274 = (251 - ($233))|0;
             $275 = $274 << 8;
             $276 = HEAP8[$232>>0]|0;
             $277 = $276&255;
             $278 = (($275) + -108)|0;
             $279 = (($278) - ($277))|0;
             $281 = $279;
             break;
            }
           }
          }
         } while(0);
         $280 = (($281) + ($val$127))|0;
         $282 = HEAP8[$226>>0]|0;
         $283 = $282&255;
         if ((($283|0) == 1)) {
          $284 = $280&255;
          HEAP8[$q$028>>0] = $284;
         } else if ((($283|0) == 2)) {
          $285 = $280&65535;
          HEAP16[$q$028>>1] = $285;
         } else if ((($283|0) == 4)) {
          HEAP32[$q$028>>2] = $280;
         } else {
          HEAP32[$q$028>>2] = $280;
         }
         $286 = (($num_args$126) + -1)|0;
         $287 = ($286|0)==(0);
         if ($287) {
          break L13;
         }
         $288 = HEAP8[$226>>0]|0;
         $289 = $288&255;
         $290 = (($q$028) + ($289)|0);
         $data$029 = $227;$num_args$126 = $286;$q$028 = $290;$val$127 = $280;
        }
        break;
       }
       default: {
        $291 = (($field$024) + 16|0);
        $292 = HEAP32[$291>>2]|0;
        $293 = (FUNCTION_TABLE_ii[$292 & 4095]($parser)|0);
        $294 = ($293|0)==(0);
        if ($294) {
         break L13;
        } else {
         $error$3 = $293;
         label = 96;
         break L4;
        }
       }
       }
      } while(0);
      $213 = (($field$024) + 12|0);
      $214 = HEAP8[$213>>0]|0;
      $215 = $214&255;
      if ((($215|0) == 1)) {
       $216 = $val$0&255;
       HEAP8[$53>>0] = $216;
       break;
      } else if ((($215|0) == 2)) {
       $217 = $val$0&65535;
       HEAP16[$53>>1] = $217;
       break;
      } else if ((($215|0) == 4)) {
       HEAP32[$53>>2] = $val$0;
       break;
      } else {
       HEAP32[$53>>2] = $val$0;
       break;
      }
     }
    } while(0);
    HEAP32[$2>>2] = $1;
    $p$3 = $p$2;
   }
  } while(0);
  $295 = (($p$3) + 1|0);
  $296 = ($295>>>0)<($limit>>>0);
  if (!($296)) {
   $error$3 = 0;
   label = 96;
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $15 = $$pre;$p$035 = $295;
 }
 if ((label|0) == 96) {
  STACKTOP = sp;return ($error$3|0);
 }
 return 0|0;
}
function _cff_parse_real($start,$limit,$power_ten,$scaling) {
 $start = $start|0;
 $limit = $limit|0;
 $power_ten = $power_ten|0;
 $scaling = $scaling|0;
 var $$lcssa38 = 0, $$lcssa42 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exponent$0 = 0, $exponent$0$ = 0, $exponent$1 = 0, $exponent$2 = 0, $exponent_add$0$ph = 0;
 var $exponent_add$0$ph26 = 0, $exponent_add$0$ph31 = 0, $exponent_add$1$ph = 0, $exponent_add$1$ph9 = 0, $exponent_add$1$ph9$us = 0, $exponent_add$2 = 0, $fraction_length$0$ph = 0, $fraction_length$1 = 0, $fraction_length$2 = 0, $fraction_length$3205 = 0, $integer_length$0$ph = 0, $nib$0 = 0, $nib$0$off = 0, $number$0$ph = 0, $number$1$ph = 0, $number$2 = 0, $number$3 = 0, $number$4 = 0, $number$5204 = 0, $or$cond2 = 0;
 var $p$0 = 0, $p$0$ph = 0, $p$0$ph28 = 0, $p$0$ph33 = 0, $p$1 = 0, $p$1$lcssa34 = 0, $p$1$us = 0, $p$2 = 0, $p$2$ph = 0, $p$2$ph11 = 0, $p$2$ph11$us = 0, $p$3 = 0, $p$3$us$us = 0, $p$4 = 0, $p$5 = 0, $p$6 = 0, $phase$0 = 0, $phase$0$ph = 0, $phase$0$ph24 = 0, $phase$0$ph30 = 0;
 var $phase$1 = 0, $phase$1$ph = 0, $phase$1$ph8 = 0, $phase$1$ph8$us = 0, $phase$2 = 0, $phase$3 = 0, $result$0 = 0, $result$0$ = 0, $sign$0$ph = 0, $sign$0$ph25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($scaling|0)!=(0|0);
 if ($0) {
  HEAP32[$scaling>>2] = 0;
  $exponent_add$0$ph = 0;$integer_length$0$ph = 0;$number$0$ph = 0;$p$0$ph = $start;$phase$0$ph = 4;$sign$0$ph = 0;
 } else {
  $exponent_add$0$ph = 0;$integer_length$0$ph = 0;$number$0$ph = 0;$p$0$ph = $start;$phase$0$ph = 4;$sign$0$ph = 0;
 }
 L3: while(1) {
  $1 = ($number$0$ph|0)>(214748363);
  $exponent_add$0$ph26 = $exponent_add$0$ph;$p$0$ph28 = $p$0$ph;$phase$0$ph24 = $phase$0$ph;$sign$0$ph25 = $sign$0$ph;
  L5: while(1) {
   $exponent_add$0$ph31 = $exponent_add$0$ph26;$p$0$ph33 = $p$0$ph28;$phase$0$ph30 = $phase$0$ph24;
   while(1) {
    if (!($1)) {
     $p$0 = $p$0$ph33;$phase$0 = $phase$0$ph30;
     break;
    }
    $2 = ($phase$0$ph30|0)==(0);
    if ($2) {
     $p$1$us = $p$0$ph33;
    } else {
     $3 = (($p$0$ph33) + 1|0);
     $4 = ($3>>>0)<($limit>>>0);
     if ($4) {
      $p$1$us = $3;
     } else {
      label = 60;
      break L3;
     }
    }
    $5 = HEAP8[$p$1$us>>0]|0;
    $6 = $5&255;
    $7 = $6 >>> $phase$0$ph30;
    $8 = $7 & 15;
    $9 = (4 - ($phase$0$ph30))|0;
    $10 = ($8|0)==(14);
    if ($10) {
     $exponent_add$0$ph26 = $exponent_add$0$ph31;$p$0$ph28 = $p$1$us;$phase$0$ph24 = $9;$sign$0$ph25 = 1;
     continue L5;
    }
    $11 = ($8>>>0)>(9);
    if ($11) {
     $$lcssa38 = $8;$$lcssa42 = $9;$p$1$lcssa34 = $p$1$us;
     label = 17;
     break L3;
    }
    $22 = (($exponent_add$0$ph31) + 1)|0;
    $exponent_add$0$ph31 = $22;$p$0$ph33 = $p$1$us;$phase$0$ph30 = $9;
   }
   while(1) {
    $12 = ($phase$0|0)==(0);
    if ($12) {
     $p$1 = $p$0;
    } else {
     $13 = (($p$0) + 1|0);
     $14 = ($13>>>0)<($limit>>>0);
     if ($14) {
      $p$1 = $13;
     } else {
      label = 60;
      break L3;
     }
    }
    $15 = HEAP8[$p$1>>0]|0;
    $16 = $15&255;
    $17 = $16 >>> $phase$0;
    $18 = $17 & 15;
    $19 = (4 - ($phase$0))|0;
    $20 = ($18|0)==(14);
    if ($20) {
     $exponent_add$0$ph26 = $exponent_add$0$ph31;$p$0$ph28 = $p$1;$phase$0$ph24 = $19;$sign$0$ph25 = 1;
     continue L5;
    }
    $21 = ($18>>>0)>(9);
    if ($21) {
     $$lcssa38 = $18;$$lcssa42 = $19;$p$1$lcssa34 = $p$1;
     label = 17;
     break L3;
    }
    $23 = $18 | $number$0$ph;
    $24 = ($23|0)==(0);
    if ($24) {
     $p$0 = $p$1;$phase$0 = $19;
    } else {
     break L5;
    }
   }
  }
  $25 = (($integer_length$0$ph) + 1)|0;
  $26 = ($number$0$ph*10)|0;
  $27 = (($18) + ($26))|0;
  $exponent_add$0$ph = $exponent_add$0$ph31;$integer_length$0$ph = $25;$number$0$ph = $27;$p$0$ph = $p$1;$phase$0$ph = $19;$sign$0$ph = $sign$0$ph25;
 }
 if ((label|0) == 17) {
  $28 = ($$lcssa38|0)==(10);
  L25: do {
   if ($28) {
    $exponent_add$1$ph = $exponent_add$0$ph31;$fraction_length$0$ph = 0;$number$1$ph = $number$0$ph;$p$2$ph = $p$1$lcssa34;$phase$1$ph = $$lcssa42;
    L26: while(1) {
     $29 = ($number$1$ph|0)<(214748364);
     $30 = ($fraction_length$0$ph|0)<(9);
     $or$cond2 = $29 & $30;
     if ($or$cond2) {
      $exponent_add$1$ph9$us = $exponent_add$1$ph;$p$2$ph11$us = $p$2$ph;$phase$1$ph8$us = $phase$1$ph;
     } else {
      $exponent_add$1$ph9 = $exponent_add$1$ph;$p$2$ph11 = $p$2$ph;$phase$1$ph8 = $phase$1$ph;
      break;
     }
     while(1) {
      $32 = ($phase$1$ph8$us|0)==(0);
      if ($32) {
       $p$3$us$us = $p$2$ph11$us;
      } else {
       $33 = (($p$2$ph11$us) + 1|0);
       $34 = ($33>>>0)<($limit>>>0);
       if ($34) {
        $p$3$us$us = $33;
       } else {
        label = 60;
        break L26;
       }
      }
      $35 = HEAP8[$p$3$us$us>>0]|0;
      $36 = $35&255;
      $37 = $36 >>> $phase$1$ph8$us;
      $38 = $37 & 15;
      $39 = (4 - ($phase$1$ph8$us))|0;
      $40 = ($38>>>0)>(9);
      if ($40) {
       $exponent_add$2 = $exponent_add$1$ph9$us;$fraction_length$1 = $fraction_length$0$ph;$nib$0 = $38;$number$2 = $number$1$ph;$p$4 = $p$3$us$us;$phase$2 = $39;
       break L25;
      }
      $41 = $38 | $number$1$ph;
      $42 = ($41|0)==(0);
      if (!($42)) {
       break;
      }
      $31 = (($exponent_add$1$ph9$us) + -1)|0;
      $exponent_add$1$ph9$us = $31;$p$2$ph11$us = $p$3$us$us;$phase$1$ph8$us = $39;
     }
     $55 = (($fraction_length$0$ph) + 1)|0;
     $56 = ($number$1$ph*10)|0;
     $57 = (($38) + ($56))|0;
     $exponent_add$1$ph = $exponent_add$1$ph9$us;$fraction_length$0$ph = $55;$number$1$ph = $57;$p$2$ph = $p$3$us$us;$phase$1$ph = $39;
    }
    if ((label|0) == 60) {
     STACKTOP = sp;return 0;
    }
    L38: while(1) {
     $p$2 = $p$2$ph11;$phase$1 = $phase$1$ph8;
     while(1) {
      $43 = ($phase$1|0)==(0);
      if ($43) {
       $p$3 = $p$2;
      } else {
       $44 = (($p$2) + 1|0);
       $45 = ($44>>>0)<($limit>>>0);
       if ($45) {
        $p$3 = $44;
       } else {
        break L38;
       }
      }
      $46 = HEAP8[$p$3>>0]|0;
      $47 = $46&255;
      $48 = $47 >>> $phase$1;
      $49 = $48 & 15;
      $50 = (4 - ($phase$1))|0;
      $51 = ($49>>>0)>(9);
      if ($51) {
       $exponent_add$2 = $exponent_add$1$ph9;$fraction_length$1 = $fraction_length$0$ph;$nib$0 = $49;$number$2 = $number$1$ph;$p$4 = $p$3;$phase$2 = $50;
       break L25;
      }
      $52 = $49 | $number$1$ph;
      $53 = ($52|0)==(0);
      if ($53) {
       break;
      } else {
       $p$2 = $p$3;$phase$1 = $50;
      }
     }
     $54 = (($exponent_add$1$ph9) + -1)|0;
     $exponent_add$1$ph9 = $54;$p$2$ph11 = $p$3;$phase$1$ph8 = $50;
    }
    STACKTOP = sp;return 0;
   } else {
    $exponent_add$2 = $exponent_add$0$ph31;$fraction_length$1 = 0;$nib$0 = $$lcssa38;$number$2 = $number$0$ph;$p$4 = $p$1$lcssa34;$phase$2 = $$lcssa42;
   }
  } while(0);
  $58 = ($nib$0|0)==(12);
  $nib$0$off = (($nib$0) + -11)|0;
  $59 = ($nib$0$off>>>0)<(2);
  do {
   if ($59) {
    $exponent$0 = 0;$p$5 = $p$4;$phase$3 = $phase$2;
    while(1) {
     $60 = ($phase$3|0)==(0);
     if ($60) {
      $p$6 = $p$5;
     } else {
      $61 = (($p$5) + 1|0);
      $62 = ($61>>>0)<($limit>>>0);
      if ($62) {
       $p$6 = $61;
      } else {
       label = 60;
       break;
      }
     }
     $63 = HEAP8[$p$6>>0]|0;
     $64 = $63&255;
     $65 = $64 >>> $phase$3;
     $66 = $65 & 15;
     $67 = ($66>>>0)>(9);
     if ($67) {
      label = 36;
      break;
     }
     $68 = (4 - ($phase$3))|0;
     $69 = ($exponent$0*10)|0;
     $70 = (($66) + ($69))|0;
     $71 = ($70|0)>(1000);
     if ($71) {
      label = 60;
      break;
     } else {
      $exponent$0 = $70;$p$5 = $p$6;$phase$3 = $68;
     }
    }
    if ((label|0) == 36) {
     $72 = (0 - ($exponent$0))|0;
     $exponent$0$ = $58 ? $72 : $exponent$0;
     $exponent$1 = $exponent$0$;
     break;
    }
    else if ((label|0) == 60) {
     STACKTOP = sp;return 0;
    }
   } else {
    $exponent$1 = 0;
   }
  } while(0);
  $73 = (($exponent_add$2) + ($power_ten))|0;
  $74 = (($73) + ($exponent$1))|0;
  if ($0) {
   $75 = (($fraction_length$1) + ($integer_length$0$ph))|0;
   $76 = (($74) + ($integer_length$0$ph))|0;
   $77 = ($75|0)<(6);
   if (!($77)) {
    $95 = (($75) + -5)|0;
    $96 = (808984 + ($95<<2)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($number$2|0) / ($97|0))&-1;
    $99 = ($98|0)>(32767);
    if ($99) {
     $100 = (($75) + -4)|0;
     $101 = (808984 + ($100<<2)|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = (_FT_DivFix($number$2,$102)|0);
     $104 = (($76) + -4)|0;
     HEAP32[$scaling>>2] = $104;
     $result$0 = $103;
     $131 = ($sign$0$ph25|0)==(0);
     $132 = (0 - ($result$0))|0;
     $result$0$ = $131 ? $result$0 : $132;
     STACKTOP = sp;return ($result$0$|0);
    } else {
     $105 = (_FT_DivFix($number$2,$97)|0);
     $106 = (($76) + -5)|0;
     HEAP32[$scaling>>2] = $106;
     $result$0 = $105;
     $131 = ($sign$0$ph25|0)==(0);
     $132 = (0 - ($result$0))|0;
     $result$0$ = $131 ? $result$0 : $132;
     STACKTOP = sp;return ($result$0$|0);
    }
   }
   $78 = ($number$2|0)>(32767);
   if ($78) {
    $79 = (_FT_DivFix($number$2,10)|0);
    $80 = (1 - ($75))|0;
    $81 = (($80) + ($76))|0;
    HEAP32[$scaling>>2] = $81;
    $result$0 = $79;
    $131 = ($sign$0$ph25|0)==(0);
    $132 = (0 - ($result$0))|0;
    $result$0$ = $131 ? $result$0 : $132;
    STACKTOP = sp;return ($result$0$|0);
   }
   $82 = ($76|0)>(0);
   if ($82) {
    $83 = ($76|0)<(5);
    $84 = $83 ? $76 : 5;
    $85 = (($76) - ($84))|0;
    $86 = (($84) - ($75))|0;
    $87 = (808984 + ($86<<2)|0);
    $88 = HEAP32[$87>>2]|0;
    $89 = Math_imul($88, $number$2)|0;
    $90 = ($89|0)>(32767);
    if ($90) {
     $91 = (($89|0) / 10)&-1;
     $92 = (($85) + 1)|0;
     $exponent$2 = $92;$number$3 = $91;
    } else {
     $exponent$2 = $85;$number$3 = $89;
    }
   } else {
    $93 = (($76) - ($75))|0;
    $exponent$2 = $93;$number$3 = $number$2;
   }
   $94 = $number$3 << 16;
   HEAP32[$scaling>>2] = $exponent$2;
   $result$0 = $94;
   $131 = ($sign$0$ph25|0)==(0);
   $132 = (0 - ($result$0))|0;
   $result$0$ = $131 ? $result$0 : $132;
   STACKTOP = sp;return ($result$0$|0);
  } else {
   $107 = (($74) + ($integer_length$0$ph))|0;
   $108 = ($107|0)<(0);
   $109 = (0 - ($107))|0;
   $110 = $108 ? $109 : $107;
   $111 = ($110|0)>(5);
   if ($111) {
    STACKTOP = sp;return 0;
   }
   $112 = (($fraction_length$1) - ($74))|0;
   if ($108) {
    $113 = (808984 + ($109<<2)|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = (($number$2|0) / ($114|0))&-1;
    $116 = (($fraction_length$1) + ($integer_length$0$ph))|0;
    $fraction_length$2 = $116;$number$4 = $115;
   } else {
    $fraction_length$2 = $112;$number$4 = $number$2;
   }
   $117 = ($fraction_length$2|0)==(10);
   if ($117) {
    $118 = (($number$4|0) / 10)&-1;
    $fraction_length$3205 = 9;$number$5204 = $118;
   } else {
    $119 = ($fraction_length$2|0)>(0);
    if ($119) {
     $fraction_length$3205 = $fraction_length$2;$number$5204 = $number$4;
    } else {
     $125 = (0 - ($fraction_length$2))|0;
     $126 = (808984 + ($125<<2)|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = Math_imul($127, $number$4)|0;
     $129 = ($128|0)>(32767);
     if ($129) {
      STACKTOP = sp;return 0;
     }
     $130 = $128 << 16;
     $result$0 = $130;
     $131 = ($sign$0$ph25|0)==(0);
     $132 = (0 - ($result$0))|0;
     $result$0$ = $131 ? $result$0 : $132;
     STACKTOP = sp;return ($result$0$|0);
    }
   }
   $120 = (808984 + ($fraction_length$3205<<2)|0);
   $121 = HEAP32[$120>>2]|0;
   $122 = (($number$5204|0) / ($121|0))&-1;
   $123 = ($122|0)>(32767);
   if ($123) {
    STACKTOP = sp;return 0;
   }
   $124 = (_FT_DivFix($number$5204,$121)|0);
   $result$0 = $124;
   $131 = ($sign$0$ph25|0)==(0);
   $132 = (0 - ($result$0))|0;
   $result$0$ = $131 ? $result$0 : $132;
   STACKTOP = sp;return ($result$0$|0);
  }
 }
 else if ((label|0) == 60) {
  STACKTOP = sp;return 0;
 }
 return 0|0;
}
function _FT_Init_Class_cff_cmap_encoding_class_rec($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 20;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 3427;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 3736;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 2624;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 2625;
 $4 = (($clazz) + 20|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;
 STACKTOP = sp;return;
}
function _cff_cmap_encoding_init($cmap) {
 $cmap = $cmap|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cmap>>2]|0;
 $1 = (($0) + 692|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 116|0);
 $4 = (($3) + 524|0);
 $5 = (($cmap) + 16|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return 0;
}
function _cff_cmap_encoding_done($cmap) {
 $cmap = $cmap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function _cff_cmap_encoding_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($char_code>>>0)<(256);
 if (!($0)) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $1 = (($cmap) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($char_code<<1)|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $result$0 = $5;
 STACKTOP = sp;return ($result$0|0);
}
function _cff_cmap_encoding_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $code$0 = 0, $code$0$in = 0, $result$0 = 0, $result$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$pchar_code>>2]|0;
 HEAP32[$pchar_code>>2] = 0;
 $1 = ($0>>>0)<(255);
 L1: do {
  if ($1) {
   $2 = (($cmap) + 16|0);
   $code$0$in = $0;$result$0 = 0;
   while(1) {
    $code$0 = (($code$0$in) + 1)|0;
    $3 = ($code$0>>>0)>(255);
    if ($3) {
     $result$1 = $result$0;
     break L1;
    }
    $4 = HEAP32[$2>>2]|0;
    $5 = (($4) + ($code$0<<1)|0);
    $6 = HEAP16[$5>>1]|0;
    $7 = $6&65535;
    $8 = ($6<<16>>16)==(0);
    if ($8) {
     $code$0$in = $code$0;$result$0 = $7;
    } else {
     break;
    }
   }
   HEAP32[$pchar_code>>2] = $code$0;
   $result$1 = $7;
  } else {
   $result$1 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($result$1|0);
}
function _FT_Init_Class_cff_cmap_unicode_class_rec($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 24;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 3428;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 3737;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 2626;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 2627;
 $4 = (($clazz) + 20|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;
 STACKTOP = sp;return;
}
function _cff_cmap_unicode_init($unicodes) {
 $unicodes = $unicodes|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$unicodes>>2]|0;
 $1 = (($0) + 692|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1160|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 163;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($2) + 2956|0);
 $7 = (($0) + 100|0);
 $8 = HEAP32[$6>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($8) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($2) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiiiiii[$11 & 255]($9,$unicodes,$13,2628,0,$0)|0);
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function _cff_cmap_unicode_done($unicodes) {
 $unicodes = $unicodes|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$unicodes>>2]|0;
 $1 = (($0) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($unicodes) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 _ft_mem_free($2,$4);
 HEAP32[$3>>2] = 0;
 $5 = (($unicodes) + 16|0);
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function _cff_cmap_unicode_char_index($unicodes,$char_code) {
 $unicodes = $unicodes|0;
 $char_code = $char_code|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$unicodes>>2]|0;
 $1 = (($0) + 692|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 2956|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iii[$6 & 4095]($unicodes,$char_code)|0);
 STACKTOP = sp;return ($7|0);
}
function _cff_cmap_unicode_char_next($unicodes,$pchar_code) {
 $unicodes = $unicodes|0;
 $pchar_code = $pchar_code|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$unicodes>>2]|0;
 $1 = (($0) + 692|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 2956|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iii[$6 & 4095]($unicodes,$pchar_code)|0);
 STACKTOP = sp;return ($7|0);
}
function _cff_sid_to_glyph_name($face,$idx) {
 $face = $face|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 692|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1160|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($idx<<1)|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = $5&65535;
 $7 = (_cff_index_get_sid_string($1,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function _FT_Init_Class_pscmaps_interface($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 3429;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 125;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 2629;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 2630;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 3430;
 $4 = (($clazz) + 20|0);
 HEAP32[$4>>2] = 3431;
 $5 = (($clazz) + 24|0);
 HEAP32[$5>>2] = 809024;
 $6 = (($clazz) + 28|0);
 HEAP32[$6>>2] = 809536;
 STACKTOP = sp;return;
}
function _ps_unicode_value($glyph_name) {
 $glyph_name = $glyph_name|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$pre = 0, $$pre27 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0$lcssa = 0, $count$021 = 0, $count1$016 = 0, $d$02 = 0, $d5$05 = 0, $p$0$lcssa = 0, $p$020 = 0, $p3$0 = 0;
 var $p3$014 = 0, $p3$018 = 0, $p6$0 = 0, $p6$023 = 0, $value$0$lcssa = 0, $value$019 = 0, $value2$012 = 0, $value2$017 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$glyph_name>>0]|0;
 $1 = ($0<<24>>24)==(117);
 do {
  if ($1) {
   $2 = (($glyph_name) + 1|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(110);
   do {
    if ($4) {
     $5 = (($glyph_name) + 2|0);
     $6 = HEAP8[$5>>0]|0;
     $7 = ($6<<24>>24)==(105);
     if ($7) {
      $8 = (($glyph_name) + 3|0);
      $count$021 = 4;$p$020 = $8;$value$019 = 0;
      while(1) {
       $9 = HEAP8[$p$020>>0]|0;
       $10 = $9&255;
       $11 = (($10) + -48)|0;
       $12 = ($11>>>0)>(9);
       if ($12) {
        $13 = (($10) + -65)|0;
        $14 = ($13>>>0)>(5);
        $15 = (($10) + -55)|0;
        $$ = $14 ? 16 : $15;
        $16 = ($$>>>0)>(15);
        if ($16) {
         $count$0$lcssa = $count$021;$p$0$lcssa = $p$020;$value$0$lcssa = $value$019;
         break;
        } else {
         $d$02 = $$;
        }
       } else {
        $d$02 = $11;
       }
       $17 = $value$019 << 4;
       $18 = (($d$02) + ($17))|0;
       $19 = (($count$021) + -1)|0;
       $20 = (($p$020) + 1|0);
       $21 = ($19|0)>(0);
       if ($21) {
        $count$021 = $19;$p$020 = $20;$value$019 = $18;
       } else {
        $count$0$lcssa = $19;$p$0$lcssa = $20;$value$0$lcssa = $18;
        break;
       }
      }
      $22 = ($count$0$lcssa|0)==(0);
      if ($22) {
       $23 = HEAP8[$p$0$lcssa>>0]|0;
       if ((($23<<24>>24) == 0)) {
        $$0 = $value$0$lcssa;
        STACKTOP = sp;return ($$0|0);
       } else if (!((($23<<24>>24) == 46))) {
        $26 = $3;$count1$016 = 6;$p3$018 = $2;$value2$017 = 0;
        break;
       }
       $24 = $value$0$lcssa | -2147483648;
       $$0 = $24;
       STACKTOP = sp;return ($$0|0);
      } else {
       $26 = $3;$count1$016 = 6;$p3$018 = $2;$value2$017 = 0;
      }
     } else {
      $26 = 110;$count1$016 = 6;$p3$018 = $2;$value2$017 = 0;
     }
    } else {
     $26 = $3;$count1$016 = 6;$p3$018 = $2;$value2$017 = 0;
    }
   } while(0);
   while(1) {
    $25 = $26&255;
    $27 = (($25) + -48)|0;
    $28 = ($27>>>0)>(9);
    if ($28) {
     $29 = (($25) + -65)|0;
     $30 = ($29>>>0)>(5);
     $31 = (($25) + -55)|0;
     $$1 = $30 ? 16 : $31;
     $32 = ($$1>>>0)>(15);
     if ($32) {
      label = 15;
      break;
     } else {
      $d5$05 = $$1;
     }
    } else {
     $d5$05 = $27;
    }
    $33 = $value2$017 << 4;
    $34 = (($d5$05) + ($33))|0;
    $35 = (($count1$016) + -1)|0;
    $p3$0 = (($p3$018) + 1|0);
    $36 = ($35|0)>(0);
    if (!($36)) {
     $p3$014 = $p3$0;$value2$012 = $34;
     break;
    }
    $$pre27 = HEAP8[$p3$0>>0]|0;
    $26 = $$pre27;$count1$016 = $35;$p3$018 = $p3$0;$value2$017 = $34;
   }
   if ((label|0) == 15) {
    $37 = ($count1$016|0)<(3);
    if ($37) {
     $p3$014 = $p3$018;$value2$012 = $value2$017;
    } else {
     $46 = $0;$p6$0 = $glyph_name;
     break;
    }
   }
   $38 = HEAP8[$p3$014>>0]|0;
   if ((($38<<24>>24) == 0)) {
    $$0 = $value2$012;
    STACKTOP = sp;return ($$0|0);
   } else if (!((($38<<24>>24) == 46))) {
    $46 = $0;$p6$0 = $glyph_name;
    break;
   }
   $39 = $value2$012 | -2147483648;
   $$0 = $39;
   STACKTOP = sp;return ($$0|0);
  } else {
   $46 = $0;$p6$0 = $glyph_name;
  }
 } while(0);
 while(1) {
  if ((($46<<24>>24) == 0)) {
   $p6$023 = $p6$0;
   break;
  } else if ((($46<<24>>24) == 46)) {
   $40 = ($p6$0>>>0)>($glyph_name>>>0);
   if ($40) {
    label = 21;
    break;
   }
  }
  $41 = (($p6$0) + 1|0);
  $$pre = HEAP8[$41>>0]|0;
  $46 = $$pre;$p6$0 = $41;
 }
 if ((label|0) == 21) {
  $42 = ($p6$0|0)==(0|0);
  if ($42) {
   $p6$023 = 0;
  } else {
   $44 = (_ft_get_adobe_glyph_index($glyph_name,$p6$0)|0);
   $45 = $44 | -2147483648;
   $$0 = $45;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $43 = (_ft_get_adobe_glyph_index($glyph_name,$p6$023)|0);
 $$0 = $43;
 STACKTOP = sp;return ($$0|0);
}
function _ps_unicodes_init($memory,$table,$num_glyphs,$get_glyph_name,$free_glyph_name,$glyph_data) {
 $memory = $memory|0;
 $table = $table|0;
 $num_glyphs = $num_glyphs|0;
 $get_glyph_name = $get_glyph_name|0;
 $free_glyph_name = $free_glyph_name|0;
 $glyph_data = $glyph_data|0;
 var $$pre = 0, $$pre17 = 0, $$pre17$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $error = 0, $exitcond = 0, $exitcond16 = 0, $extra_glyph_list_states = 0, $extra_glyphs = 0, $map$09 = 0, $map$09$us = 0, $map$1 = 0, $map$2 = 0, $map$2$us = 0, $map$4 = 0, $map$4$1 = 0, $map$4$2 = 0, $map$4$3 = 0, $map$4$4 = 0, $map$4$5 = 0, $map$4$6 = 0, $map$4$7 = 0, $map$4$8 = 0, $map$4$9 = 0;
 var $n$010 = 0, $n$010$us = 0, $n$02$i = 0, $n$02$i$us = 0, $n$02$i1 = 0, $n$02$i1$us = 0, $phitmp = 0, $split = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $error = sp + 80|0;
 $extra_glyph_list_states = sp;
 $extra_glyphs = sp + 40|0;
 dest=$extra_glyph_list_states+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($table) + 16|0);
 HEAP32[$0>>2] = 0;
 $1 = (($table) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = (($num_glyphs) + 10)|0;
 $3 = (_ft_mem_realloc($memory,8,0,$2,0,$error)|0);
 HEAP32[$1>>2] = $3;
 $4 = HEAP32[$error>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $72 = $4;
  STACKTOP = sp;return ($72|0);
 }
 $6 = ($num_glyphs|0)==(0);
 if ($6) {
  $map$4 = $3;
 } else {
  $7 = ($free_glyph_name|0)==(0|0);
  if ($7) {
   $map$09$us = $3;$n$010$us = 0;
   while(1) {
    $8 = (FUNCTION_TABLE_iii[$get_glyph_name & 4095]($glyph_data,$n$010$us)|0);
    $9 = ($8|0)==(0|0);
    if ($9) {
     $map$2$us = $map$09$us;
    } else {
     $n$02$i$us = 0;
     while(1) {
      $10 = (815208 + ($n$02$i$us<<2)|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (815120 + ($11)|0);
      $13 = (_strcmp($12,$8)|0);
      $14 = ($13|0)==(0);
      $15 = (($n$02$i$us) + 1)|0;
      if ($14) {
       label = 7;
       break;
      }
      $16 = ($15>>>0)<(10);
      if ($16) {
       $n$02$i$us = $15;
      } else {
       break;
      }
     }
     if ((label|0) == 7) {
      label = 0;
      $17 = (($extra_glyph_list_states) + ($n$02$i$us<<2)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = ($18|0)==(0);
      if ($19) {
       HEAP32[$17>>2] = 1;
       $20 = (($extra_glyphs) + ($n$02$i$us<<2)|0);
       HEAP32[$20>>2] = $n$010$us;
      }
     }
     $21 = (_ps_unicode_value($8)|0);
     $22 = $21 & 2147483647;
     $23 = ($22|0)==(0);
     if ($23) {
      $map$2$us = $map$09$us;
     } else {
      $n$02$i1$us = 0;
      while(1) {
       $24 = (815080 + ($n$02$i1$us<<2)|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = ($25|0)==($21|0);
       $27 = (($n$02$i1$us) + 1)|0;
       if ($26) {
        label = 12;
        break;
       }
       $28 = ($27>>>0)<(10);
       if ($28) {
        $n$02$i1$us = $27;
       } else {
        break;
       }
      }
      if ((label|0) == 12) {
       label = 0;
       $29 = (($extra_glyph_list_states) + ($n$02$i1$us<<2)|0);
       HEAP32[$29>>2] = 2;
      }
      HEAP32[$map$09$us>>2] = $21;
      $30 = (($map$09$us) + 4|0);
      HEAP32[$30>>2] = $n$010$us;
      $31 = (($map$09$us) + 8|0);
      $map$2$us = $31;
     }
    }
    $32 = (($n$010$us) + 1)|0;
    $exitcond16 = ($32|0)==($num_glyphs|0);
    if ($exitcond16) {
     $split = $map$2$us;
     break;
    } else {
     $map$09$us = $map$2$us;$n$010$us = $32;
    }
   }
  } else {
   $map$09 = $3;$n$010 = 0;
   while(1) {
    $33 = (FUNCTION_TABLE_iii[$get_glyph_name & 4095]($glyph_data,$n$010)|0);
    $34 = ($33|0)==(0|0);
    if ($34) {
     $map$2 = $map$09;
    } else {
     $n$02$i = 0;
     while(1) {
      $37 = (815208 + ($n$02$i<<2)|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (815120 + ($38)|0);
      $40 = (_strcmp($39,$33)|0);
      $41 = ($40|0)==(0);
      $36 = (($n$02$i) + 1)|0;
      if ($41) {
       label = 19;
       break;
      }
      $35 = ($36>>>0)<(10);
      if ($35) {
       $n$02$i = $36;
      } else {
       break;
      }
     }
     if ((label|0) == 19) {
      label = 0;
      $42 = (($extra_glyph_list_states) + ($n$02$i<<2)|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = ($43|0)==(0);
      if ($44) {
       HEAP32[$42>>2] = 1;
       $45 = (($extra_glyphs) + ($n$02$i<<2)|0);
       HEAP32[$45>>2] = $n$010;
      }
     }
     $46 = (_ps_unicode_value($33)|0);
     $47 = $46 & 2147483647;
     $48 = ($47|0)==(0);
     if ($48) {
      $map$1 = $map$09;
     } else {
      $n$02$i1 = 0;
      while(1) {
       $51 = (815080 + ($n$02$i1<<2)|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52|0)==($46|0);
       $50 = (($n$02$i1) + 1)|0;
       if ($53) {
        label = 24;
        break;
       }
       $49 = ($50>>>0)<(10);
       if ($49) {
        $n$02$i1 = $50;
       } else {
        break;
       }
      }
      if ((label|0) == 24) {
       label = 0;
       $54 = (($extra_glyph_list_states) + ($n$02$i1<<2)|0);
       HEAP32[$54>>2] = 2;
      }
      HEAP32[$map$09>>2] = $46;
      $55 = (($map$09) + 4|0);
      HEAP32[$55>>2] = $n$010;
      $56 = (($map$09) + 8|0);
      $map$1 = $56;
     }
     FUNCTION_TABLE_vii[$free_glyph_name & 4095]($glyph_data,$33);
     $map$2 = $map$1;
    }
    $57 = (($n$010) + 1)|0;
    $exitcond = ($57|0)==($num_glyphs|0);
    if ($exitcond) {
     $split = $map$2;
     break;
    } else {
     $map$09 = $map$2;$n$010 = $57;
    }
   }
  }
  $$pre = HEAP32[$extra_glyph_list_states>>2]|0;
  $phitmp = ($$pre|0)==(1);
  if ($phitmp) {
   HEAP32[$split>>2] = 916;
   $58 = HEAP32[$extra_glyphs>>2]|0;
   $59 = (($split) + 4|0);
   HEAP32[$59>>2] = $58;
   $60 = (($split) + 8|0);
   $map$4 = $60;
  } else {
   $map$4 = $split;
  }
 }
 $61 = (($extra_glyph_list_states) + 4|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(1);
 if ($63) {
  HEAP32[$map$4>>2] = 937;
  $73 = (($extra_glyphs) + 4|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = (($map$4) + 4|0);
  HEAP32[$75>>2] = $74;
  $76 = (($map$4) + 8|0);
  $map$4$1 = $76;
 } else {
  $map$4$1 = $map$4;
 }
 $77 = (($extra_glyph_list_states) + 8|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(1);
 if ($79) {
  HEAP32[$map$4$1>>2] = 8725;
  $80 = (($extra_glyphs) + 8|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (($map$4$1) + 4|0);
  HEAP32[$82>>2] = $81;
  $83 = (($map$4$1) + 8|0);
  $map$4$2 = $83;
 } else {
  $map$4$2 = $map$4$1;
 }
 $84 = (($extra_glyph_list_states) + 12|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($85|0)==(1);
 if ($86) {
  HEAP32[$map$4$2>>2] = 173;
  $87 = (($extra_glyphs) + 12|0);
  $88 = HEAP32[$87>>2]|0;
  $89 = (($map$4$2) + 4|0);
  HEAP32[$89>>2] = $88;
  $90 = (($map$4$2) + 8|0);
  $map$4$3 = $90;
 } else {
  $map$4$3 = $map$4$2;
 }
 $91 = (($extra_glyph_list_states) + 16|0);
 $92 = HEAP32[$91>>2]|0;
 $93 = ($92|0)==(1);
 if ($93) {
  HEAP32[$map$4$3>>2] = 713;
  $94 = (($extra_glyphs) + 16|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = (($map$4$3) + 4|0);
  HEAP32[$96>>2] = $95;
  $97 = (($map$4$3) + 8|0);
  $map$4$4 = $97;
 } else {
  $map$4$4 = $map$4$3;
 }
 $98 = (($extra_glyph_list_states) + 20|0);
 $99 = HEAP32[$98>>2]|0;
 $100 = ($99|0)==(1);
 if ($100) {
  HEAP32[$map$4$4>>2] = 956;
  $101 = (($extra_glyphs) + 20|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (($map$4$4) + 4|0);
  HEAP32[$103>>2] = $102;
  $104 = (($map$4$4) + 8|0);
  $map$4$5 = $104;
 } else {
  $map$4$5 = $map$4$4;
 }
 $105 = (($extra_glyph_list_states) + 24|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($106|0)==(1);
 if ($107) {
  HEAP32[$map$4$5>>2] = 8729;
  $108 = (($extra_glyphs) + 24|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($map$4$5) + 4|0);
  HEAP32[$110>>2] = $109;
  $111 = (($map$4$5) + 8|0);
  $map$4$6 = $111;
 } else {
  $map$4$6 = $map$4$5;
 }
 $112 = (($extra_glyph_list_states) + 28|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ($113|0)==(1);
 if ($114) {
  HEAP32[$map$4$6>>2] = 160;
  $115 = (($extra_glyphs) + 28|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($map$4$6) + 4|0);
  HEAP32[$117>>2] = $116;
  $118 = (($map$4$6) + 8|0);
  $map$4$7 = $118;
 } else {
  $map$4$7 = $map$4$6;
 }
 $119 = (($extra_glyph_list_states) + 32|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($120|0)==(1);
 if ($121) {
  HEAP32[$map$4$7>>2] = 538;
  $122 = (($extra_glyphs) + 32|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = (($map$4$7) + 4|0);
  HEAP32[$124>>2] = $123;
  $125 = (($map$4$7) + 8|0);
  $map$4$8 = $125;
 } else {
  $map$4$8 = $map$4$7;
 }
 $126 = (($extra_glyph_list_states) + 36|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = ($127|0)==(1);
 if ($128) {
  HEAP32[$map$4$8>>2] = 539;
  $129 = (($extra_glyphs) + 36|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (($map$4$8) + 4|0);
  HEAP32[$131>>2] = $130;
  $132 = (($map$4$8) + 8|0);
  $map$4$9 = $132;
 } else {
  $map$4$9 = $map$4$8;
 }
 $64 = HEAP32[$1>>2]|0;
 $133 = $map$4$9;
 $134 = $64;
 $135 = (($133) - ($134))|0;
 $69 = $135 >> 3;
 $136 = ($69|0)==(0);
 if ($136) {
  _ft_mem_free($memory,$64);
  HEAP32[$1>>2] = 0;
  $65 = HEAP32[$error>>2]|0;
  $66 = ($65|0)==(0);
  if ($66) {
   HEAP32[$error>>2] = 163;
   $$pre17 = 163;
  } else {
   $$pre17 = $65;
  }
 } else {
  $67 = $num_glyphs >>> 1;
  $68 = ($69>>>0)<($67>>>0);
  if ($68) {
   $70 = (_ft_mem_realloc($memory,8,$num_glyphs,$69,$64,$error)|0);
   HEAP32[$1>>2] = $70;
   HEAP32[$error>>2] = 0;
   $71 = $70;
  } else {
   $71 = $64;
  }
  _qsort($71,$69,8,2631);
  $$pre17$pre = HEAP32[$error>>2]|0;
  $$pre17 = $$pre17$pre;
 }
 HEAP32[$0>>2] = $69;
 $72 = $$pre17;
 STACKTOP = sp;return ($72|0);
}
function _ps_unicodes_char_index($table,$unicode) {
 $table = $table|0;
 $unicode = $unicode|0;
 var $$0 = 0, $$result$0 = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $max$0$ph9 = 0, $min$0$ph10 = 0, $min$04 = 0, $result$0$ph11 = 0, $result$05 = 0, $result$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($table) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $$sum = (($3) + -1)|0;
 $4 = ($$sum|0)<(0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($1) + ($$sum<<3)|0);
 $max$0$ph9 = $5;$min$0$ph10 = $1;$result$0$ph11 = 0;
 L4: while(1) {
  $6 = $max$0$ph9;
  $min$04 = $min$0$ph10;$result$05 = $result$0$ph11;
  while(1) {
   $7 = $min$04;
   $8 = (($6) - ($7))|0;
   $9 = $8 >> 4;
   $10 = (($min$04) + ($9<<3)|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==($unicode|0);
   if ($12) {
    $result$2 = $10;
    break L4;
   }
   $13 = $11 & 2147483647;
   $14 = ($13|0)==($unicode|0);
   $$result$0 = $14 ? $10 : $result$05;
   $15 = ($min$04|0)==($max$0$ph9|0);
   if ($15) {
    $result$2 = $$result$0;
    break L4;
   }
   $16 = ($13>>>0)<($unicode>>>0);
   if (!($16)) {
    break;
   }
   $$sum2 = (($9) + 1)|0;
   $17 = (($min$04) + ($$sum2<<3)|0);
   $18 = ($17>>>0)>($max$0$ph9>>>0);
   if ($18) {
    $result$2 = $$result$0;
    break L4;
   } else {
    $min$04 = $17;$result$05 = $$result$0;
   }
  }
  $$sum1 = (($9) + -1)|0;
  $19 = (($min$04) + ($$sum1<<3)|0);
  $20 = ($$sum1|0)<(0);
  if ($20) {
   $result$2 = $$result$0;
   break;
  } else {
   $max$0$ph9 = $19;$min$0$ph10 = $min$04;$result$0$ph11 = $$result$0;
  }
 }
 $21 = ($result$2|0)==(0|0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = (($result$2) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $$0 = $23;
 STACKTOP = sp;return ($$0|0);
}
function _ps_unicodes_char_next($table,$unicode) {
 $table = $table|0;
 $unicode = $unicode|0;
 var $$min$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $char_code$0 = 0, $max$0$ = 0, $max$05 = 0, $min$0$lcssa9 = 0, $min$04 = 0, $result$06 = 0, $result$1 = 0, $result$2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$unicode>>2]|0;
 $1 = (($0) + 1)|0;
 $2 = (($table) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $min$0$lcssa9 = 0;
   label = 9;
  } else {
   $5 = (($table) + 20|0);
   $6 = HEAP32[$5>>2]|0;
   $max$05 = $3;$min$04 = 0;$result$06 = 0;
   while(1) {
    $7 = (($max$05) - ($min$04))|0;
    $8 = $7 >>> 1;
    $9 = (($8) + ($min$04))|0;
    $10 = (($6) + ($9<<3)|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==($1|0);
    if ($12) {
     label = 4;
     break;
    }
    $15 = $11 & 2147483647;
    $16 = ($15|0)==($1|0);
    if ($16) {
     $17 = ((($6) + ($9<<3)|0) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $result$1 = $18;
    } else {
     $result$1 = $result$06;
    }
    $19 = ($15>>>0)<($1>>>0);
    $20 = (($9) + 1)|0;
    $$min$0 = $19 ? $20 : $min$04;
    $max$0$ = $19 ? $max$05 : $9;
    $21 = ($$min$0>>>0)<($max$0$>>>0);
    if ($21) {
     $max$05 = $max$0$;$min$04 = $$min$0;$result$06 = $result$1;
    } else {
     label = 8;
     break;
    }
   }
   if ((label|0) == 4) {
    $13 = ((($6) + ($9<<3)|0) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $char_code$0 = $1;$result$2 = $14;
    break;
   }
   else if ((label|0) == 8) {
    $22 = ($result$1|0)==(0);
    if ($22) {
     $min$0$lcssa9 = $$min$0;
     label = 9;
     break;
    } else {
     $char_code$0 = $1;$result$2 = $result$1;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $23 = ($min$0$lcssa9>>>0)<($3>>>0);
  if ($23) {
   $24 = (($table) + 20|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($25) + ($min$0$lcssa9<<3)|0) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + ($min$0$lcssa9<<3)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = $29 & 2147483647;
   $char_code$0 = $30;$result$2 = $27;
  } else {
   $char_code$0 = 0;$result$2 = 0;
  }
 }
 HEAP32[$unicode>>2] = $char_code$0;
 STACKTOP = sp;return ($result$2|0);
}
function _ps_get_macintosh_name($name_index) {
 $name_index = $name_index|0;
 var $$name_index = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($name_index>>>0)>(257);
 $$name_index = $0 ? 0 : $name_index;
 $1 = (814560 + ($$name_index<<1)|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 << 16 >> 16;
 $4 = (810080 + ($3)|0);
 STACKTOP = sp;return ($4|0);
}
function _ps_get_standard_strings($sid) {
 $sid = $sid|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($sid>>>0)>(390);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (813776 + ($sid<<1)|0);
  $2 = HEAP16[$1>>1]|0;
  $3 = $2 << 16 >> 16;
  $4 = (810080 + ($3)|0);
  $$0 = $4;
 }
 STACKTOP = sp;return ($$0|0);
}
function _FT_Destroy_Class_pscmaps_services($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($clazz|0)==(0|0);
 if (!($0)) {
  $1 = HEAP32[$library>>2]|0;
  _ft_mem_free($1,$clazz);
 }
 STACKTOP = sp;return;
}
function _FT_Create_Class_pscmaps_services($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,16,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = 810048;
 $4 = (($library) + 212|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = (($1) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($1) + 8|0);
 HEAP32[$8>>2] = 0;
 $9 = (($1) + 12|0);
 HEAP32[$9>>2] = 0;
 HEAP32[$output_class>>2] = $1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Destroy_Class_psnames_module_class($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 _psnames_module_class_pic_free($library);
 $1 = ($clazz|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$clazz);
 STACKTOP = sp;return;
}
function _FT_Create_Class_psnames_module_class($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,36,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_psnames_module_class_pic_init($library)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if ($5) {
  HEAP32[$1>>2] = 0;
  $7 = (($1) + 4|0);
  HEAP32[$7>>2] = 20;
  $8 = (($1) + 8|0);
  HEAP32[$8>>2] = 810072;
  $9 = (($1) + 12|0);
  HEAP32[$9>>2] = 65536;
  $10 = (($1) + 16|0);
  HEAP32[$10>>2] = 131072;
  $11 = (($library) + 212|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 4|0);
  $14 = (($1) + 20|0);
  HEAP32[$14>>2] = $13;
  $15 = (($1) + 24|0);
  HEAP32[$15>>2] = 0;
  $16 = (($1) + 28|0);
  HEAP32[$16>>2] = 0;
  $17 = (($1) + 32|0);
  HEAP32[$17>>2] = 2632;
  HEAP32[$output_class>>2] = $1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  _ft_mem_free($0,$1);
  $6 = HEAP32[$error>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _psnames_get_service($module,$service_id) {
 $module = $module|0;
 $service_id = $service_id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($module) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (_ft_service_list_lookup($4,$service_id)|0);
 STACKTOP = sp;return ($5|0);
}
function _compare_uni_maps($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$a>>2]|0;
 $1 = $0 & 2147483647;
 $2 = HEAP32[$b>>2]|0;
 $3 = $2 & 2147483647;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $5 = ($0>>>0)>($2>>>0);
  if ($5) {
   $$0 = 1;
  } else {
   $6 = ($0>>>0)<($2>>>0);
   $$ = $6 << 31 >> 31;
   $$0 = $$;
  }
 } else {
  $7 = ($1>>>0)>($3>>>0);
  if ($7) {
   $$0 = 1;
  } else {
   $8 = ($1>>>0)<($3>>>0);
   $$1 = $8 << 31 >> 31;
   $$0 = $$1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _ft_get_adobe_glyph_index($name,$limit) {
 $name = $name|0;
 $limit = $limit|0;
 var $$ = 0, $$0 = 0, $$0111 = 0, $$min$0 = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $count$05 = 0, $max$0$ = 0, $max$016 = 0, $min$015 = 0;
 var $or$cond = 0, $p$0$be = 0, $p$0$lcssa = 0, $p$010 = 0, $p$24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($name|0)!=(0|0);
 $1 = ($name>>>0)<($limit>>>0);
 $or$cond = $0 & $1;
 if (!($or$cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($name) + 1|0);
 $3 = HEAP8[$name>>0]|0;
 $4 = $3 << 24 >> 24;
 $max$016 = 52;$min$015 = 0;
 while(1) {
  $5 = (($max$016) + ($min$015))|0;
  $6 = $5 >> 1;
  $7 = $6 << 1;
  $$sum = (($7) + 2)|0;
  $8 = (815248 + ($$sum)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $10 << 8;
  $$sum2 = (($7) + 3)|0;
  $12 = (815248 + ($$sum2)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $11 | $14;
  $16 = (815248 + ($15)|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $18 & 127;
  $20 = ($19|0)==($4|0);
  if ($20) {
   break;
  }
  $22 = ($19|0)<($4|0);
  $23 = (($6) + 1)|0;
  $$min$0 = $22 ? $23 : $min$015;
  $max$0$ = $22 ? $max$016 : $6;
  $24 = ($$min$0|0)<($max$0$|0);
  if ($24) {
   $max$016 = $max$0$;$min$015 = $$min$0;
  } else {
   $$0 = 0;
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return ($$0|0);
 }
 $21 = ($2>>>0)<($limit>>>0);
 L10: do {
  if ($21) {
   $$0111 = $2;$42 = $17;$p$010 = $16;
   L11: while(1) {
    $38 = (($$0111) + 1|0);
    $39 = HEAP8[$$0111>>0]|0;
    $40 = $39 << 24 >> 24;
    $41 = ($42<<24>>24)<(0);
    $43 = (($p$010) + 1|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = $44&255;
    $46 = $45 & 127;
    L13: do {
     if ($41) {
      $47 = ($40|0)==($46|0);
      if ($47) {
       $69 = $44;$p$0$be = $43;
      } else {
       $$0 = 0;
       label = 16;
       break L11;
      }
     } else {
      $49 = ($46|0)==(0);
      if ($49) {
       $$0 = 0;
       label = 16;
       break L11;
      }
      $50 = $45 & 128;
      $51 = (($p$010) + 3|0);
      $52 = ($50|0)==(0);
      $$ = $52 ? $43 : $51;
      $53 = (($$) + 1|0);
      $count$05 = $46;$p$24 = $53;
      while(1) {
       $54 = HEAP8[$p$24>>0]|0;
       $55 = $54&255;
       $56 = $55 << 8;
       $57 = (($p$24) + 1|0);
       $58 = HEAP8[$57>>0]|0;
       $59 = $58&255;
       $60 = $56 | $59;
       $61 = (815248 + ($60)|0);
       $62 = HEAP8[$61>>0]|0;
       $63 = $62&255;
       $64 = $63 & 127;
       $65 = ($40|0)==($64|0);
       if ($65) {
        $69 = $62;$p$0$be = $61;
        break L13;
       }
       $66 = (($count$05) + -1)|0;
       $67 = (($p$24) + 2|0);
       $68 = ($66|0)>(0);
       if ($68) {
        $count$05 = $66;$p$24 = $67;
       } else {
        $$0 = 0;
        label = 16;
        break L11;
       }
      }
     }
    } while(0);
    $48 = ($38>>>0)<($limit>>>0);
    if ($48) {
     $$0111 = $38;$42 = $69;$p$010 = $p$0$be;
    } else {
     $26 = $69;$p$0$lcssa = $p$0$be;
     break L10;
    }
   }
   if ((label|0) == 16) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $26 = $17;$p$0$lcssa = $16;
  }
 } while(0);
 $25 = ($26<<24>>24)>(-1);
 if (!($25)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = (($p$0$lcssa) + 1|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)<(0);
 if (!($29)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (($p$0$lcssa) + 2|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31&255;
 $33 = $32 << 8;
 $34 = (($p$0$lcssa) + 3|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = $33 | $36;
 $$0 = $37;
 STACKTOP = sp;return ($$0|0);
}
function _psnames_module_class_pic_free($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 $1 = (($library) + 212|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  _FT_Destroy_Class_pscmaps_services($library,$4);
 }
 HEAP32[$2>>2] = 0;
 _ft_mem_free($0,$2);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function _psnames_module_class_pic_init($library) {
 $library = $library|0;
 var $$0 = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,36,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 dest=$1+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = (($library) + 212|0);
 HEAP32[$4>>2] = $1;
 $5 = (_FT_Create_Class_pscmaps_services($library,$1)|0);
 HEAP32[$error>>2] = $5;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (($1) + 4|0);
  _FT_Init_Class_pscmaps_interface($library,$7);
  $$pr = HEAP32[$error>>2]|0;
  $8 = ($$pr|0)==(0);
  if ($8) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $14 = $$pr;
  }
 } else {
  $14 = $5;
 }
 $9 = HEAP32[$library>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[$10>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  _FT_Destroy_Class_pscmaps_services($library,$12);
 }
 HEAP32[$10>>2] = 0;
 _ft_mem_free($9,$10);
 HEAP32[$4>>2] = 0;
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _sfnt_init_face($stream,$face,$face_index,$num_params,$params) {
 $stream = $stream|0;
 $face = $face|0;
 $face_index = $face_index|0;
 $num_params = $num_params|0;
 $params = $params|0;
 var $$0 = 0, $$face_index = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $error$i = 0, $n$010$i = 0, $sfnt$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp;
 $0 = (($face) + 532|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = (($face) + 96|0);
 do {
  if ($2) {
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (_FT_Get_Module_Interface($6,871248)|0);
   $8 = ($7|0)==(0|0);
   if ($8) {
    $$0 = 3;
    STACKTOP = sp;return ($$0|0);
   } else {
    HEAP32[$0>>2] = $7;
    $9 = HEAP32[$7>>2]|0;
    $10 = (($face) + 508|0);
    HEAP32[$10>>2] = $9;
    $sfnt$0$in = $7;
    break;
   }
  } else {
   $sfnt$0$in = $1;
  }
 } while(0);
 $11 = HEAP32[$3>>2]|0;
 $12 = (_ft_module_get_service($11,871256)|0);
 $13 = (($face) + 536|0);
 HEAP32[$13>>2] = $12;
 $14 = (($stream) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($face) + 132|0);
 HEAP32[$16>>2] = 0;
 $17 = (($face) + 136|0);
 HEAP32[$17>>2] = 0;
 $18 = (($face) + 140|0);
 HEAP32[$18>>2] = 0;
 $19 = (_FT_Stream_Pos($stream)|0);
 $20 = (_FT_Stream_ReadULong($stream,$error$i)|0);
 $21 = HEAP32[$error$i>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $$0 = $21;
  STACKTOP = sp;return ($$0|0);
 }
 if (!((($20|0) == 65536) | (($20|0) == 131072) | (($20|0) == 1330926671) | (($20|0) == 1953658213) | (($20|0) == 1953784678) | (($20|0) == 1954115633))) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$16>>2] = 1953784678;
 $23 = ($20|0)==(1953784678);
 do {
  if ($23) {
   $24 = (_FT_Stream_ReadFields($stream,871416,$16)|0);
   HEAP32[$error$i>>2] = $24;
   $25 = ($24|0)==(0);
   if (!($25)) {
    $$0 = $24;
    STACKTOP = sp;return ($$0|0);
   }
   $26 = HEAP32[$18>>2]|0;
   $27 = ($26|0)==(0);
   if ($27) {
    $$0 = 8;
    STACKTOP = sp;return ($$0|0);
   }
   $28 = (($stream) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = $29 >>> 5;
   $31 = ($26>>>0)>($30>>>0);
   if ($31) {
    $$0 = 10;
    STACKTOP = sp;return ($$0|0);
   }
   $32 = (_ft_mem_realloc($15,4,0,$26,0,$error$i)|0);
   $33 = (($face) + 144|0);
   HEAP32[$33>>2] = $32;
   $34 = HEAP32[$error$i>>2]|0;
   $35 = ($34|0)==(0);
   if (!($35)) {
    $$0 = $34;
    STACKTOP = sp;return ($$0|0);
   }
   $36 = HEAP32[$18>>2]|0;
   $37 = $36 << 2;
   $38 = (_FT_Stream_EnterFrame($stream,$37)|0);
   HEAP32[$error$i>>2] = $38;
   $39 = ($38|0)==(0);
   if (!($39)) {
    $$0 = $38;
    STACKTOP = sp;return ($$0|0);
   }
   $40 = HEAP32[$18>>2]|0;
   $41 = ($40|0)>(0);
   if ($41) {
    $n$010$i = 0;
    while(1) {
     $42 = (_FT_Stream_GetULong($stream)|0);
     $43 = HEAP32[$33>>2]|0;
     $44 = (($43) + ($n$010$i<<2)|0);
     HEAP32[$44>>2] = $42;
     $45 = (($n$010$i) + 1)|0;
     $46 = HEAP32[$18>>2]|0;
     $47 = ($45|0)<($46|0);
     if ($47) {
      $n$010$i = $45;
     } else {
      break;
     }
    }
   }
   _FT_Stream_ExitFrame($stream);
   $$pre$i = HEAP32[$error$i>>2]|0;
   $52 = ($$pre$i|0)==(0);
   if (!($52)) {
    $$0 = $$pre$i;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   HEAP32[$17>>2] = 65536;
   HEAP32[$18>>2] = 1;
   $48 = (_ft_mem_alloc($15,4,$error$i)|0);
   $49 = (($face) + 144|0);
   HEAP32[$49>>2] = $48;
   $50 = HEAP32[$error$i>>2]|0;
   $51 = ($50|0)==(0);
   if ($51) {
    HEAP32[$48>>2] = $19;
    break;
   } else {
    $$0 = $50;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $53 = ($face_index|0)<(0);
 $$face_index = $53 ? 0 : $face_index;
 $54 = HEAP32[$18>>2]|0;
 $55 = ($$face_index|0)<($54|0);
 if (!($55)) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $56 = (($face) + 144|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = (($57) + ($$face_index<<2)|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (_FT_Stream_Seek($stream,$59)|0);
 $61 = ($60|0)==(0);
 if (!($61)) {
  $$0 = $60;
  STACKTOP = sp;return ($$0|0);
 }
 $62 = (($sfnt$0$in) + 132|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (FUNCTION_TABLE_iii[$63 & 4095]($face,$stream)|0);
 $65 = ($64|0)==(0);
 if (!($65)) {
  $$0 = $64;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = HEAP32[$18>>2]|0;
 HEAP32[$face>>2] = $66;
 $67 = (($face) + 4|0);
 HEAP32[$67>>2] = $$face_index;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _sfnt_load_face($stream,$face,$face_index,$num_params,$params) {
 $stream = $stream|0;
 $face = $face|0;
 $face_index = $face_index|0;
 $num_params = $num_params|0;
 $params = $params|0;
 var $$ = 0, $$0$i = 0, $$19 = 0, $$4 = 0, $$5 = 0, $$7 = 0, $$ignore_preferred_subfamily$0 = 0, $$pr16 = 0, $$pr18 = 0, $$pre = 0, $$pre42 = 0, $$pre43 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $avgwidth$0 = 0, $cur$02$i = 0, $em_size$0 = 0, $error = 0;
 var $exitcond = 0, $flags$1 = 0, $flags$1$ = 0, $flags$3 = 0, $flags$3$ = 0, $flags$3$$ = 0, $flags$5 = 0, $flags$8 = 0, $has_outline$014 = 0, $has_outline$1 = 0, $i$027 = 0, $i1$021 = 0, $ignore_preferred_family$0$lcssa = 0, $ignore_preferred_family$029 = 0, $ignore_preferred_family$1 = 0, $ignore_preferred_subfamily$0$lcssa = 0, $ignore_preferred_subfamily$028 = 0, $ignore_preferred_subfamily$1 = 0, $is_apple_sbit$012 = 0, $m$023 = 0;
 var $metrics = 0, $or$cond = 0, $or$cond$i = 0, $or$cond3 = 0, $phitmp = 0, $phitmp46 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $error = sp + 28|0;
 $metrics = sp;
 $0 = (($face) + 532|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($num_params|0)>(0);
 if ($2) {
  $i$027 = 0;$ignore_preferred_family$029 = 0;$ignore_preferred_subfamily$028 = 0;
  while(1) {
   $3 = (($params) + ($i$027<<3)|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(1768386662);
   if ($5) {
    $ignore_preferred_family$1 = 1;$ignore_preferred_subfamily$1 = $ignore_preferred_subfamily$028;
   } else {
    $6 = ($4|0)==(1768386675);
    $$ignore_preferred_subfamily$0 = $6 ? 1 : $ignore_preferred_subfamily$028;
    $ignore_preferred_family$1 = $ignore_preferred_family$029;$ignore_preferred_subfamily$1 = $$ignore_preferred_subfamily$0;
   }
   $7 = (($i$027) + 1)|0;
   $exitcond = ($7|0)==($num_params|0);
   if ($exitcond) {
    $ignore_preferred_family$0$lcssa = $ignore_preferred_family$1;$ignore_preferred_subfamily$0$lcssa = $ignore_preferred_subfamily$1;
    break;
   } else {
    $i$027 = $7;$ignore_preferred_family$029 = $ignore_preferred_family$1;$ignore_preferred_subfamily$028 = $ignore_preferred_subfamily$1;
   }
  }
 } else {
  $ignore_preferred_family$0$lcssa = 0;$ignore_preferred_subfamily$0$lcssa = 0;
 }
 $8 = (_tt_face_lookup_table($face,1735162214)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $10 = (_tt_face_lookup_table($face,1128678944)|0);
  $11 = ($10|0)!=(0|0);
  $phitmp = $11&1;
  if ($11) {
   $341 = $phitmp;
   label = 9;
  } else {
   $12 = (($1) + 84|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $341 = 0;
    label = 9;
   } else {
    $15 = (FUNCTION_TABLE_iii[$13 & 4095]($face,$stream)|0);
    HEAP32[$error>>2] = $15;
    $16 = ($15|0)==(0);
    if ($16) {
     $342 = $phitmp;$is_apple_sbit$012 = 1;
    } else {
     $341 = $phitmp;
     label = 9;
    }
   }
  }
 } else {
  $341 = 1;
  label = 9;
 }
 if ((label|0) == 9) {
  $17 = (($1) + 32|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (FUNCTION_TABLE_iii[$18 & 4095]($face,$stream)|0);
  HEAP32[$error>>2] = $19;
  $20 = ($19|0)==(0);
  if ($20) {
   $342 = $341;$is_apple_sbit$012 = 0;
  } else {
   $340 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($340|0);
  }
 }
 $21 = (($face) + 178|0);
 $22 = HEAP16[$21>>1]|0;
 $23 = ($22<<16>>16)==(0);
 if ($23) {
  HEAP32[$error>>2] = 8;
  $340 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($340|0);
 }
 $24 = (($1) + 44|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_iii[$25 & 4095]($face,$stream)|0);
 HEAP32[$error>>2] = $26;
 $27 = (($1) + 40|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_iii[$28 & 4095]($face,$stream)|0);
 HEAP32[$error>>2] = $29;
 $30 = (($1) + 56|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (FUNCTION_TABLE_iii[$31 & 4095]($face,$stream)|0);
 HEAP32[$error>>2] = $32;
 $33 = (($1) + 52|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (FUNCTION_TABLE_iii[$34 & 4095]($face,$stream)|0);
 HEAP32[$error>>2] = $35;
 if ($is_apple_sbit$012) {
  $has_outline$1 = $342;
 } else {
  $36 = (($1) + 36|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (FUNCTION_TABLE_iiii[$37 & 2047]($face,$stream,0)|0);
  HEAP32[$error>>2] = $38;
  do {
   if ((($38|0) == 142)) {
    $43 = (($face) + 148|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==(1953658213);
    if ($45) {
     HEAP32[$error>>2] = 0;
     $has_outline$014 = 0;
     break;
    }
    HEAP32[$error>>2] = 143;
    $340 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($340|0);
   } else if ((($38|0) == 0)) {
    $39 = (($1) + 136|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (FUNCTION_TABLE_iiii[$40 & 2047]($face,$stream,0)|0);
    $42 = ($41|0)==(142);
    $$ = $42 ? 147 : $41;
    HEAP32[$error>>2] = $$;
    $47 = $$;
    label = 18;
   } else {
    $47 = $38;
    label = 18;
   }
  } while(0);
  if ((label|0) == 18) {
   $46 = ($47|0)==(0);
   if ($46) {
    $has_outline$014 = $342;
   } else {
    $340 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($340|0);
   }
  }
  $48 = HEAP32[$36>>2]|0;
  $49 = (FUNCTION_TABLE_iiii[$48 & 2047]($face,$stream,1)|0);
  HEAP32[$error>>2] = $49;
  $50 = ($49|0)==(0);
  if ($50) {
   $51 = (($1) + 136|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (FUNCTION_TABLE_iiii[$52 & 2047]($face,$stream,1)|0);
   HEAP32[$error>>2] = $53;
   $54 = ($53|0)==(0);
   if ($54) {
    $55 = (($face) + 296|0);
    HEAP8[$55>>0] = 1;
   } else {
    $343 = $53;
    label = 22;
   }
  } else {
   $343 = $49;
   label = 22;
  }
  if ((label|0) == 22) {
   if (!((($343|0) == 0) | (($343|0) == 142))) {
    $340 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($340|0);
   }
  }
  $56 = (($1) + 48|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (FUNCTION_TABLE_iii[$57 & 4095]($face,$stream)|0);
  HEAP32[$error>>2] = $58;
  $59 = ($58|0)==(0);
  if ($59) {
   $has_outline$1 = $has_outline$014;
  } else {
   $60 = (($face) + 368|0);
   HEAP16[$60>>1] = -1;
   $has_outline$1 = $has_outline$014;
  }
 }
 $61 = (($1) + 140|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)==(0|0);
 do {
  if (!($63)) {
   $64 = (FUNCTION_TABLE_iii[$62 & 4095]($face,$stream)|0);
   HEAP32[$error>>2] = $64;
   if ((($64|0) == 0)) {
    break;
   } else if ((($64|0) == 142)) {
    HEAP32[$error>>2] = 0;
    break;
   } else {
    $340 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($340|0);
   }
  }
 } while(0);
 $65 = (($1) + 80|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (FUNCTION_TABLE_iii[$66 & 4095]($face,$stream)|0);
 HEAP32[$error>>2] = $67;
 if ((($67|0) == 142)) {
  $68 = (($face) + 556|0);
  HEAP32[$68>>2] = 0;
 } else if (!((($67|0) == 0))) {
  $340 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($340|0);
 }
 $69 = (($1) + 76|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (FUNCTION_TABLE_iii[$70 & 4095]($face,$stream)|0);
 HEAP32[$error>>2] = $71;
 $72 = (($1) + 72|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (FUNCTION_TABLE_iii[$73 & 4095]($face,$stream)|0);
 HEAP32[$error>>2] = $74;
 $75 = (($face) + 264|0);
 $76 = HEAP16[$75>>1]|0;
 $77 = $76&65535;
 $78 = (($face) + 16|0);
 HEAP32[$78>>2] = $77;
 $79 = (($face) + 20|0);
 HEAP32[$79>>2] = 0;
 $80 = (($face) + 24|0);
 HEAP32[$80>>2] = 0;
 $81 = (($face) + 368|0);
 $82 = HEAP16[$81>>1]|0;
 $83 = ($82<<16>>16)==(-1);
 if ($83) {
  label = 40;
 } else {
  $84 = (($face) + 432|0);
  $85 = HEAP16[$84>>1]|0;
  $86 = $85 & 256;
  $87 = ($86<<16>>16)==(0);
  if ($87) {
   label = 40;
  } else {
   $88 = ($ignore_preferred_family$0$lcssa<<24>>24)==(0);
   do {
    if ($88) {
     $89 = (_tt_face_get_name($face,16,$79)|0);
     HEAP32[$error>>2] = $89;
     $90 = ($89|0)==(0);
     if ($90) {
      $$pre43 = HEAP32[$79>>2]|0;
      $phitmp46 = ($$pre43|0)==(0|0);
      if ($phitmp46) {
       label = 35;
       break;
      } else {
       break;
      }
     } else {
      $340 = HEAP32[$error>>2]|0;
      STACKTOP = sp;return ($340|0);
     }
    } else {
     label = 35;
    }
   } while(0);
   if ((label|0) == 35) {
    $91 = (_tt_face_get_name($face,1,$79)|0);
    HEAP32[$error>>2] = $91;
    $92 = ($91|0)==(0);
    if (!($92)) {
     $340 = HEAP32[$error>>2]|0;
     STACKTOP = sp;return ($340|0);
    }
   }
   $93 = ($ignore_preferred_subfamily$0$lcssa<<24>>24)==(0);
   if ($93) {
    $94 = (_tt_face_get_name($face,17,$80)|0);
    HEAP32[$error>>2] = $94;
    $95 = ($94|0)==(0);
    if (!($95)) {
     $340 = HEAP32[$error>>2]|0;
     STACKTOP = sp;return ($340|0);
    }
   }
   $96 = HEAP32[$80>>2]|0;
   $97 = ($96|0)==(0|0);
   if ($97) {
    $98 = (_tt_face_get_name($face,2,$80)|0);
    HEAP32[$error>>2] = $98;
    $99 = ($98|0)==(0);
    if (!($99)) {
     $340 = HEAP32[$error>>2]|0;
     STACKTOP = sp;return ($340|0);
    }
   }
  }
 }
 if ((label|0) == 40) {
  $100 = (_tt_face_get_name($face,21,$79)|0);
  HEAP32[$error>>2] = $100;
  $101 = ($100|0)==(0);
  if (!($101)) {
   $340 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($340|0);
  }
  $102 = HEAP32[$79>>2]|0;
  $103 = ($102|0)==(0|0);
  $104 = ($ignore_preferred_family$0$lcssa<<24>>24)==(0);
  $or$cond = $103 & $104;
  do {
   if ($or$cond) {
    $105 = (_tt_face_get_name($face,16,$79)|0);
    HEAP32[$error>>2] = $105;
    $106 = ($105|0)==(0);
    if ($106) {
     $$pr16 = HEAP32[$79>>2]|0;
     $108 = $$pr16;
     break;
    } else {
     $340 = HEAP32[$error>>2]|0;
     STACKTOP = sp;return ($340|0);
    }
   } else {
    $108 = $102;
   }
  } while(0);
  $107 = ($108|0)==(0|0);
  if ($107) {
   $109 = (_tt_face_get_name($face,1,$79)|0);
   HEAP32[$error>>2] = $109;
   $110 = ($109|0)==(0);
   if (!($110)) {
    $340 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($340|0);
   }
  }
  $111 = (_tt_face_get_name($face,22,$80)|0);
  HEAP32[$error>>2] = $111;
  $112 = ($111|0)==(0);
  if (!($112)) {
   $340 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($340|0);
  }
  $113 = HEAP32[$80>>2]|0;
  $114 = ($113|0)==(0|0);
  $115 = ($ignore_preferred_subfamily$0$lcssa<<24>>24)==(0);
  $or$cond3 = $114 & $115;
  do {
   if ($or$cond3) {
    $116 = (_tt_face_get_name($face,17,$80)|0);
    HEAP32[$error>>2] = $116;
    $117 = ($116|0)==(0);
    if ($117) {
     $$pr18 = HEAP32[$80>>2]|0;
     $119 = $$pr18;
     break;
    } else {
     $340 = HEAP32[$error>>2]|0;
     STACKTOP = sp;return ($340|0);
    }
   } else {
    $119 = $113;
   }
  } while(0);
  $118 = ($119|0)==(0|0);
  if ($118) {
   $120 = (_tt_face_get_name($face,2,$80)|0);
   HEAP32[$error>>2] = $120;
   $121 = ($120|0)==(0);
   if (!($121)) {
    $340 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($340|0);
   }
  }
 }
 $122 = (($face) + 8|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = ($has_outline$1<<24>>24)==(1);
 $125 = $124&1;
 $$4 = $123 | $125;
 $126 = $$4 | 24;
 $127 = ($35|0)==(0);
 if ($127) {
  $128 = (($face) + 468|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ($129|0)==(196608);
  $131 = $$4 | 536;
  $$5 = $130 ? $126 : $131;
  $flags$1 = $$5;
 } else {
  $flags$1 = $126;
 }
 $132 = (($face) + 480|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = ($133|0)==(0);
 $135 = $flags$1 | 4;
 $flags$1$ = $134 ? $flags$1 : $135;
 $136 = (($face) + 296|0);
 $137 = HEAP8[$136>>0]|0;
 $138 = ($137<<24>>24)==(0);
 $139 = $flags$1$ | 32;
 $flags$3 = $138 ? $flags$1$ : $139;
 $140 = (($face) + 784|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = ($141|0)==(0);
 $143 = $flags$3 | 64;
 $flags$3$ = $142 ? $flags$3 : $143;
 $144 = (_tt_face_lookup_table($face,1735162214)|0);
 $145 = ($144|0)==(0|0);
 if ($145) {
  $flags$5 = $flags$3$;
 } else {
  $146 = (_tt_face_lookup_table($face,1719034226)|0);
  $147 = ($146|0)==(0|0);
  if ($147) {
   $flags$5 = $flags$3$;
  } else {
   $148 = (_tt_face_lookup_table($face,1735811442)|0);
   $149 = ($148|0)==(0|0);
   $150 = $flags$3$ | 256;
   $flags$3$$ = $149 ? $flags$3$ : $150;
   $flags$5 = $flags$3$$;
  }
 }
 HEAP32[$122>>2] = $flags$5;
 if ($124) {
  $151 = HEAP16[$81>>1]|0;
  $152 = ($151<<16>>16)==(-1);
  if ($152) {
   label = 60;
  } else {
   $153 = (($face) + 432|0);
   $154 = HEAP16[$153>>1]|0;
   $155 = $154&65535;
   $156 = $155 & 512;
   $157 = ($156|0)==(0);
   $158 = $155 & 1;
   $$19 = $157 ? $158 : 1;
   $159 = ($154&65535) >>> 4;
   $160 = $159 & 2;
   $161 = $160&65535;
   $162 = $161 | $$19;
   $flags$8 = $162;
  }
 } else {
  label = 60;
 }
 if ((label|0) == 60) {
  $163 = (($face) + 204|0);
  $164 = HEAP16[$163>>1]|0;
  $165 = $164 & 1;
  $166 = ($165<<16>>16)==(0);
  $$7 = $166 ? 0 : 2;
  $167 = ($164&65535) >>> 1;
  $168 = $167 & 1;
  $169 = $168&65535;
  $170 = $169 | $$7;
  $flags$8 = $170;
 }
 $171 = (($face) + 12|0);
 HEAP32[$171>>2] = $flags$8;
 (_tt_face_build_cmaps($face)|0);
 $172 = (($face) + 36|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = ($173|0)>(0);
 if ($174) {
  $175 = (($face) + 40|0);
  $176 = HEAP32[$175>>2]|0;
  $m$023 = 0;
  while(1) {
   $177 = (($176) + ($m$023<<2)|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = (($178) + 8|0);
   $180 = HEAP16[$179>>1]|0;
   $181 = $180&65535;
   $182 = (($178) + 10|0);
   $183 = HEAP16[$182>>1]|0;
   $184 = $183&65535;
   $cur$02$i = 871280;
   while(1) {
    $185 = HEAP32[$cur$02$i>>2]|0;
    $186 = ($185|0)==($181|0);
    if ($186) {
     $187 = (($cur$02$i) + 4|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = ($188|0)==($184|0);
     $190 = ($188|0)==(-1);
     $or$cond$i = $189 | $190;
     if ($or$cond$i) {
      label = 66;
      break;
     }
    }
    $193 = (($cur$02$i) + 12|0);
    $194 = ($193>>>0)<(((871280 + 132|0))>>>0);
    if ($194) {
     $cur$02$i = $193;
    } else {
     $$0$i = 0;
     break;
    }
   }
   if ((label|0) == 66) {
    label = 0;
    $191 = (($cur$02$i) + 8|0);
    $192 = HEAP32[$191>>2]|0;
    $$0$i = $192;
   }
   $195 = (($178) + 4|0);
   HEAP32[$195>>2] = $$0$i;
   $196 = (($m$023) + 1)|0;
   $197 = ($196|0)<($173|0);
   if ($197) {
    $m$023 = $196;
   } else {
    break;
   }
  }
 }
 $198 = (($face) + 612|0);
 $199 = HEAP32[$198>>2]|0;
 $200 = ($199|0)==(0);
 do {
  if ($200) {
   $$pre = HEAP32[$122>>2]|0;
   $249 = $$pre;
  } else {
   $201 = (($face) + 104|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = (($202) + 28|0);
   $204 = HEAP32[$203>>2]|0;
   $205 = HEAP16[$21>>1]|0;
   $206 = ($205<<16>>16)==(0);
   if ($206) {
    label = 73;
   } else {
    $207 = (($face) + 370|0);
    $208 = HEAP16[$207>>1]|0;
    $209 = HEAP16[$81>>1]|0;
    $210 = ($209<<16>>16)==(-1);
    if ($210) {
     label = 73;
    } else {
     $avgwidth$0 = $208;$em_size$0 = $205;
    }
   }
   if ((label|0) == 73) {
    $avgwidth$0 = 0;$em_size$0 = 1;
   }
   $211 = (_ft_mem_realloc($204,16,0,$199,0,$error)|0);
   $212 = (($face) + 32|0);
   HEAP32[$212>>2] = $211;
   $213 = HEAP32[$error>>2]|0;
   $214 = ($213|0)==(0);
   if (!($214)) {
    $340 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($340|0);
   }
   $215 = (($1) + 152|0);
   $216 = (($metrics) + 20|0);
   $217 = $avgwidth$0 << 16 >> 16;
   $218 = $em_size$0&65535;
   $219 = $218 >>> 1;
   $227 = $211;$i1$021 = 0;
   while(1) {
    $220 = HEAP32[$215>>2]|0;
    $221 = (FUNCTION_TABLE_iiii[$220 & 2047]($face,$i1$021,$metrics)|0);
    HEAP32[$error>>2] = $221;
    $222 = ($221|0)==(0);
    if (!($222)) {
     label = 92;
     break;
    }
    $223 = HEAP32[$216>>2]|0;
    $224 = $223 >>> 6;
    $225 = $224&65535;
    $226 = (($227) + ($i1$021<<4)|0);
    HEAP16[$226>>1] = $225;
    $228 = HEAP16[$metrics>>1]|0;
    $229 = $228&65535;
    $230 = Math_imul($229, $217)|0;
    $231 = (($230) + ($219))|0;
    $232 = (($231|0) / ($218|0))&-1;
    $233 = $232&65535;
    $234 = ((($227) + ($i1$021<<4)|0) + 2|0);
    HEAP16[$234>>1] = $233;
    $235 = HEAP32[$metrics>>2]|0;
    $236 = $235 << 6;
    $237 = $236 & 4194240;
    $238 = ((($227) + ($i1$021<<4)|0) + 8|0);
    HEAP32[$238>>2] = $237;
    $239 = $235 >>> 16;
    $240 = $239 << 6;
    $241 = ((($227) + ($i1$021<<4)|0) + 12|0);
    HEAP32[$241>>2] = $240;
    $242 = ((($227) + ($i1$021<<4)|0) + 4|0);
    HEAP32[$242>>2] = $240;
    $243 = (($i1$021) + 1)|0;
    $244 = ($243>>>0)<($199>>>0);
    if (!($244)) {
     label = 79;
     break;
    }
    $$pre42 = HEAP32[$212>>2]|0;
    $227 = $$pre42;$i1$021 = $243;
   }
   if ((label|0) == 79) {
    $245 = HEAP32[$122>>2]|0;
    $246 = $245 | 2;
    HEAP32[$122>>2] = $246;
    $247 = (($face) + 28|0);
    HEAP32[$247>>2] = $199;
    $249 = $246;
    break;
   }
   else if ((label|0) == 92) {
    $340 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($340|0);
   }
  }
 } while(0);
 $248 = $249 & 3;
 $250 = ($248|0)==(0);
 if ($250) {
  $251 = $249 | 1;
  HEAP32[$122>>2] = $251;
  $253 = $251;
 } else {
  $253 = $249;
 }
 $252 = $253 & 1;
 $254 = ($252|0)==(0);
 if ($254) {
  $340 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($340|0);
 }
 $255 = (($face) + 196|0);
 $256 = HEAP16[$255>>1]|0;
 $257 = $256 << 16 >> 16;
 $258 = (($face) + 52|0);
 HEAP32[$258>>2] = $257;
 $259 = (($face) + 198|0);
 $260 = HEAP16[$259>>1]|0;
 $261 = $260 << 16 >> 16;
 $262 = (($face) + 56|0);
 HEAP32[$262>>2] = $261;
 $263 = (($face) + 200|0);
 $264 = HEAP16[$263>>1]|0;
 $265 = $264 << 16 >> 16;
 $266 = (($face) + 60|0);
 HEAP32[$266>>2] = $265;
 $267 = (($face) + 202|0);
 $268 = HEAP16[$267>>1]|0;
 $269 = $268 << 16 >> 16;
 $270 = (($face) + 64|0);
 HEAP32[$270>>2] = $269;
 $271 = HEAP16[$21>>1]|0;
 $272 = (($face) + 68|0);
 HEAP16[$272>>1] = $271;
 $273 = (($face) + 220|0);
 $274 = HEAP16[$273>>1]|0;
 $275 = (($face) + 70|0);
 HEAP16[$275>>1] = $274;
 $276 = (($face) + 222|0);
 $277 = HEAP16[$276>>1]|0;
 $278 = (($face) + 72|0);
 HEAP16[$278>>1] = $277;
 $279 = $274&65535;
 $280 = $277&65535;
 $281 = (($279) - ($280))|0;
 $282 = (($face) + 224|0);
 $283 = HEAP16[$282>>1]|0;
 $284 = $283&65535;
 $285 = (($281) + ($284))|0;
 $286 = $285&65535;
 $287 = (($face) + 74|0);
 HEAP16[$287>>1] = $286;
 $288 = $274 | $277;
 $289 = ($288<<16>>16)==(0);
 do {
  if ($289) {
   $290 = HEAP16[$81>>1]|0;
   $291 = ($290<<16>>16)==(-1);
   if ($291) {
    $324 = $285;
   } else {
    $292 = (($face) + 438|0);
    $293 = HEAP16[$292>>1]|0;
    $294 = (($face) + 440|0);
    $295 = HEAP16[$294>>1]|0;
    $296 = $293 | $295;
    $297 = ($296<<16>>16)==(0);
    if ($297) {
     $306 = (($face) + 444|0);
     $307 = HEAP16[$306>>1]|0;
     HEAP16[$275>>1] = $307;
     $308 = (($face) + 446|0);
     $309 = HEAP16[$308>>1]|0;
     $310 = $309&65535;
     $311 = (0 - ($310))|0;
     $312 = $311&65535;
     HEAP16[$278>>1] = $312;
     $313 = $307&65535;
     $314 = (($313) + ($310))|0;
     $315 = $314&65535;
     HEAP16[$287>>1] = $315;
     $324 = $314;
     break;
    } else {
     HEAP16[$275>>1] = $293;
     HEAP16[$278>>1] = $295;
     $298 = $293&65535;
     $299 = $295&65535;
     $300 = (($298) - ($299))|0;
     $301 = (($face) + 442|0);
     $302 = HEAP16[$301>>1]|0;
     $303 = $302&65535;
     $304 = (($300) + ($303))|0;
     $305 = $304&65535;
     HEAP16[$287>>1] = $305;
     $324 = $304;
     break;
    }
   }
  } else {
   $324 = $285;
  }
 } while(0);
 $316 = (($face) + 226|0);
 $317 = HEAP16[$316>>1]|0;
 $318 = (($face) + 76|0);
 HEAP16[$318>>1] = $317;
 $319 = HEAP8[$136>>0]|0;
 $320 = ($319<<24>>24)==(0);
 if ($320) {
  $sext = $324 << 16;
  $325 = $sext >> 16;
  $327 = $325;
 } else {
  $321 = (($face) + 310|0);
  $322 = HEAP16[$321>>1]|0;
  $323 = $322&65535;
  $327 = $323;
 }
 $326 = $327&65535;
 $328 = (($face) + 78|0);
 HEAP16[$328>>1] = $326;
 $329 = (($face) + 476|0);
 $330 = HEAP16[$329>>1]|0;
 $331 = $330&65535;
 $332 = (($face) + 478|0);
 $333 = HEAP16[$332>>1]|0;
 $334 = $333 << 16 >> 16;
 $335 = (($334|0) / 2)&-1;
 $336 = (($331) - ($335))|0;
 $337 = $336&65535;
 $338 = (($face) + 80|0);
 HEAP16[$338>>1] = $337;
 $339 = (($face) + 82|0);
 HEAP16[$339>>1] = $333;
 $340 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($340|0);
}
function _tt_face_get_name($face,$nameid,$name) {
 $face = $face|0;
 $nameid = $nameid|0;
 $name = $name|0;
 var $$found_apple_roman$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $convert$0 = 0, $error = 0, $found_apple_english$0$found_apple_roman$0 = 0;
 var $found_apple_english$07 = 0, $found_apple_english$1 = 0, $found_apple_roman$06 = 0, $found_apple_roman$1 = 0, $found_unicode$09 = 0, $found_unicode$1 = 0, $found_win$08 = 0, $found_win$1 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $is_english$010 = 0, $is_english$1 = 0, $or$cond = 0, $rec$04 = 0, $rec$1 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($face) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$error>>2] = 0;
 $2 = (($face) + 360|0);
 $3 = (($face) + 344|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(0);
 if ($5) {
  $result$0 = 0;
  HEAP32[$name>>2] = $result$0;
  $75 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($75|0);
 }
 $6 = HEAP32[$2>>2]|0;
 $found_apple_english$07 = -1;$found_apple_roman$06 = -1;$found_unicode$09 = -1;$found_win$08 = -1;$indvars$iv = 0;$is_english$010 = 0;$rec$04 = $6;
 while(1) {
  $7 = (($rec$04) + 6|0);
  $8 = HEAP16[$7>>1]|0;
  $9 = ($8<<16>>16)==($nameid<<16>>16);
  do {
   if ($9) {
    $10 = (($rec$04) + 8|0);
    $11 = HEAP16[$10>>1]|0;
    $12 = ($11<<16>>16)==(0);
    if ($12) {
     $found_apple_english$1 = $found_apple_english$07;$found_apple_roman$1 = $found_apple_roman$06;$found_unicode$1 = $found_unicode$09;$found_win$1 = $found_win$08;$is_english$1 = $is_english$010;
    } else {
     $13 = HEAP16[$rec$04>>1]|0;
     $14 = $13&65535;
     if ((($14|0) == 1)) {
      $15 = (($rec$04) + 4|0);
      $16 = HEAP16[$15>>1]|0;
      $17 = ($16<<16>>16)==(0);
      if ($17) {
       $found_apple_english$1 = $indvars$iv;$found_apple_roman$1 = $found_apple_roman$06;$found_unicode$1 = $found_unicode$09;$found_win$1 = $found_win$08;$is_english$1 = $is_english$010;
       break;
      }
      $18 = (($rec$04) + 2|0);
      $19 = HEAP16[$18>>1]|0;
      $20 = ($19<<16>>16)==(0);
      $$found_apple_roman$0 = $20 ? $indvars$iv : $found_apple_roman$06;
      $found_apple_english$1 = $found_apple_english$07;$found_apple_roman$1 = $$found_apple_roman$0;$found_unicode$1 = $found_unicode$09;$found_win$1 = $found_win$08;$is_english$1 = $is_english$010;
      break;
     } else if ((($14|0) == 2) | (($14|0) == 0)) {
      $found_apple_english$1 = $found_apple_english$07;$found_apple_roman$1 = $found_apple_roman$06;$found_unicode$1 = $indvars$iv;$found_win$1 = $found_win$08;$is_english$1 = $is_english$010;
      break;
     } else if ((($14|0) == 3)) {
      $21 = ($found_win$08|0)==(-1);
      if (!($21)) {
       $22 = (($rec$04) + 4|0);
       $23 = HEAP16[$22>>1]|0;
       $24 = $23 & 1023;
       $25 = ($24<<16>>16)==(9);
       if (!($25)) {
        $found_apple_english$1 = $found_apple_english$07;$found_apple_roman$1 = $found_apple_roman$06;$found_unicode$1 = $found_unicode$09;$found_win$1 = $found_win$08;$is_english$1 = $is_english$010;
        break;
       }
      }
      $26 = (($rec$04) + 2|0);
      $27 = HEAP16[$26>>1]|0;
      $28 = $27&65535;
      if (!((($28|0) == 10) | (($28|0) == 1) | (($28|0) == 0))) {
       $found_apple_english$1 = $found_apple_english$07;$found_apple_roman$1 = $found_apple_roman$06;$found_unicode$1 = $found_unicode$09;$found_win$1 = $found_win$08;$is_english$1 = $is_english$010;
       break;
      }
      $29 = (($rec$04) + 4|0);
      $30 = HEAP16[$29>>1]|0;
      $31 = $30 & 1023;
      $32 = ($31<<16>>16)==(9);
      $33 = $32&1;
      $found_apple_english$1 = $found_apple_english$07;$found_apple_roman$1 = $found_apple_roman$06;$found_unicode$1 = $found_unicode$09;$found_win$1 = $indvars$iv;$is_english$1 = $33;
      break;
     } else {
      $found_apple_english$1 = $found_apple_english$07;$found_apple_roman$1 = $found_apple_roman$06;$found_unicode$1 = $found_unicode$09;$found_win$1 = $found_win$08;$is_english$1 = $is_english$010;
      break;
     }
    }
   } else {
    $found_apple_english$1 = $found_apple_english$07;$found_apple_roman$1 = $found_apple_roman$06;$found_unicode$1 = $found_unicode$09;$found_win$1 = $found_win$08;$is_english$1 = $is_english$010;
   }
  } while(0);
  $indvars$iv$next = (($indvars$iv) + 1)|0;
  $34 = (($rec$04) + 20|0);
  $35 = $indvars$iv$next&65535;
  $36 = ($35&65535)<($4&65535);
  if ($36) {
   $found_apple_english$07 = $found_apple_english$1;$found_apple_roman$06 = $found_apple_roman$1;$found_unicode$09 = $found_unicode$1;$found_win$08 = $found_win$1;$indvars$iv = $indvars$iv$next;$is_english$010 = $is_english$1;$rec$04 = $34;
  } else {
   break;
  }
 }
 $37 = ($found_apple_english$1|0)>(-1);
 $found_apple_english$0$found_apple_roman$0 = $37 ? $found_apple_english$1 : $found_apple_roman$1;
 $38 = ($found_win$1|0)>(-1);
 if ($38) {
  $39 = ($found_apple_english$0$found_apple_roman$0|0)>(-1);
  $40 = ($is_english$1<<24>>24)==(0);
  $or$cond = $39 & $40;
  if ($or$cond) {
   label = 17;
  } else {
   $41 = HEAP32[$2>>2]|0;
   $42 = (($41) + (($found_win$1*20)|0)|0);
   $43 = ((($41) + (($found_win$1*20)|0)|0) + 2|0);
   $44 = HEAP16[$43>>1]|0;
   $45 = $44&65535;
   if ((($45|0) == 10) | (($45|0) == 0) | (($45|0) == 1)) {
    $convert$0 = 2633;$rec$1 = $42;
   } else {
    $result$0 = 0;
    HEAP32[$name>>2] = $result$0;
    $75 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($75|0);
   }
  }
 } else {
  label = 17;
 }
 do {
  if ((label|0) == 17) {
   $46 = ($found_apple_english$0$found_apple_roman$0|0)>(-1);
   if ($46) {
    $47 = HEAP32[$2>>2]|0;
    $48 = (($47) + (($found_apple_english$0$found_apple_roman$0*20)|0)|0);
    $convert$0 = 2634;$rec$1 = $48;
    break;
   }
   $49 = ($found_unicode$1|0)>(-1);
   if ($49) {
    $50 = HEAP32[$2>>2]|0;
    $51 = (($50) + (($found_unicode$1*20)|0)|0);
    $convert$0 = 2633;$rec$1 = $51;
    break;
   } else {
    $result$0 = 0;
    HEAP32[$name>>2] = $result$0;
    $75 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($75|0);
   }
  }
 } while(0);
 $52 = ($rec$1|0)==(0|0);
 if ($52) {
  $result$0 = 0;
  HEAP32[$name>>2] = $result$0;
  $75 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($75|0);
 }
 $53 = (($rec$1) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)==(0|0);
 do {
  if ($55) {
   $56 = (($face) + 364|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($rec$1) + 8|0);
   $59 = HEAP16[$58>>1]|0;
   $60 = $59&65535;
   $61 = (_ft_mem_realloc($1,1,0,$60,0,$error)|0);
   HEAP32[$53>>2] = $61;
   $62 = HEAP32[$error>>2]|0;
   $63 = ($62|0)==(0);
   if ($63) {
    $64 = (($rec$1) + 12|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (_FT_Stream_Seek($57,$65)|0);
    HEAP32[$error>>2] = $66;
    $67 = ($66|0)==(0);
    if ($67) {
     $68 = HEAP32[$53>>2]|0;
     $69 = HEAP16[$58>>1]|0;
     $70 = $69&65535;
     $71 = (_FT_Stream_Read($57,$68,$70)|0);
     HEAP32[$error>>2] = $71;
     $72 = ($71|0)==(0);
     if ($72) {
      break;
     }
    }
   }
   $73 = HEAP32[$53>>2]|0;
   _ft_mem_free($1,$73);
   HEAP32[$53>>2] = 0;
   HEAP16[$58>>1] = 0;
   $result$0 = 0;
   HEAP32[$name>>2] = $result$0;
   $75 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($75|0);
  }
 } while(0);
 $74 = (FUNCTION_TABLE_iii[$convert$0 & 4095]($rec$1,$1)|0);
 $result$0 = $74;
 HEAP32[$name>>2] = $result$0;
 $75 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($75|0);
}
function _sfnt_done_face($face) {
 $face = $face|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($face|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($face) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($face) + 532|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)!=(0|0);
 if ($5) {
  $6 = (($4) + 116|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   FUNCTION_TABLE_vi[$7 & 4095]($face);
  }
  $9 = (($4) + 144|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   FUNCTION_TABLE_vi[$10 & 4095]($face);
  }
 }
 _tt_face_done_kern($face);
 $12 = (($face) + 144|0);
 $13 = HEAP32[$12>>2]|0;
 _ft_mem_free($2,$13);
 HEAP32[$12>>2] = 0;
 $14 = (($face) + 140|0);
 HEAP32[$14>>2] = 0;
 $15 = (($face) + 156|0);
 $16 = HEAP32[$15>>2]|0;
 _ft_mem_free($2,$16);
 HEAP32[$15>>2] = 0;
 $17 = (($face) + 152|0);
 HEAP16[$17>>1] = 0;
 $18 = (($face) + 104|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($face) + 500|0);
 _FT_Stream_ReleaseFrame($19,$20);
 $21 = (($face) + 504|0);
 HEAP32[$21>>2] = 0;
 $22 = (($face) + 252|0);
 $23 = HEAP32[$22>>2]|0;
 _ft_mem_free($2,$23);
 HEAP32[$22>>2] = 0;
 $24 = (($face) + 256|0);
 $25 = HEAP32[$24>>2]|0;
 _ft_mem_free($2,$25);
 HEAP32[$24>>2] = 0;
 $26 = (($face) + 296|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)==(0);
 if (!($28)) {
  $29 = (($face) + 336|0);
  $30 = HEAP32[$29>>2]|0;
  _ft_mem_free($2,$30);
  HEAP32[$29>>2] = 0;
  $31 = (($face) + 340|0);
  $32 = HEAP32[$31>>2]|0;
  _ft_mem_free($2,$32);
  HEAP32[$31>>2] = 0;
  HEAP8[$26>>0] = 0;
 }
 $33 = (($face) + 552|0);
 $34 = HEAP32[$33>>2]|0;
 _ft_mem_free($2,$34);
 HEAP32[$33>>2] = 0;
 $35 = (($face) + 550|0);
 HEAP16[$35>>1] = 0;
 if ($5) {
  $36 = (($4) + 60|0);
  $37 = HEAP32[$36>>2]|0;
  FUNCTION_TABLE_vi[$37 & 4095]($face);
 }
 $38 = (($face) + 20|0);
 $39 = HEAP32[$38>>2]|0;
 _ft_mem_free($2,$39);
 HEAP32[$38>>2] = 0;
 $40 = (($face) + 24|0);
 $41 = HEAP32[$40>>2]|0;
 _ft_mem_free($2,$41);
 HEAP32[$40>>2] = 0;
 $42 = (($face) + 32|0);
 $43 = HEAP32[$42>>2]|0;
 _ft_mem_free($2,$43);
 HEAP32[$42>>2] = 0;
 $44 = (($face) + 28|0);
 HEAP32[$44>>2] = 0;
 $45 = (($face) + 700|0);
 $46 = HEAP32[$45>>2]|0;
 _ft_mem_free($2,$46);
 HEAP32[$45>>2] = 0;
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_name_entry_ascii_from_utf16($entry,$memory) {
 $entry = $entry|0;
 $memory = $memory|0;
 var $$0 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $n$02 = 0, $read$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($entry) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($entry) + 8|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = $4 >>> 1;
 $6 = (($5) + 1)|0;
 $7 = (_ft_mem_realloc($memory,1,0,$6,0,$error)|0);
 $8 = HEAP32[$error>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ($5|0)==(0);
 if (!($10)) {
  $n$02 = 0;$read$03 = $1;
  while(1) {
   $11 = (($read$03) + 2|0);
   $12 = HEAP8[$read$03>>0]|0;
   $13 = $12&255;
   $14 = $13 << 8;
   $15 = (($read$03) + 1|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = $16&255;
   $18 = $14 | $17;
   $$off = (($18) + -32)|0;
   $19 = ($$off>>>0)>(95);
   $20 = $19 ? 63 : $16;
   $21 = (($7) + ($n$02)|0);
   HEAP8[$21>>0] = $20;
   $22 = (($n$02) + 1)|0;
   $23 = ($22>>>0)<($5>>>0);
   if ($23) {
    $n$02 = $22;$read$03 = $11;
   } else {
    break;
   }
  }
 }
 $24 = (($7) + ($5)|0);
 HEAP8[$24>>0] = 0;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function _tt_name_entry_ascii_from_other($entry,$memory) {
 $entry = $entry|0;
 $memory = $memory|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0;
 var $exitcond = 0, $n$02 = 0, $or$cond = 0, $read$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($entry) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($entry) + 8|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($4) + 1)|0;
 $6 = (_ft_mem_realloc($memory,1,0,$5,0,$error)|0);
 $7 = HEAP32[$error>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = ($3<<16>>16)==(0);
 if (!($9)) {
  $n$02 = 0;$read$03 = $1;
  while(1) {
   $10 = (($read$03) + 1|0);
   $11 = HEAP8[$read$03>>0]|0;
   $12 = ($11&255)<(32);
   $13 = ($11<<24>>24)<(0);
   $or$cond = $12 | $13;
   $14 = $or$cond ? 63 : $11;
   $15 = (($6) + ($n$02)|0);
   HEAP8[$15>>0] = $14;
   $16 = (($n$02) + 1)|0;
   $exitcond = ($16|0)==($4|0);
   if ($exitcond) {
    break;
   } else {
    $n$02 = $16;$read$03 = $10;
   }
  }
 }
 $17 = (($6) + ($4)|0);
 HEAP8[$17>>0] = 0;
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Init_Class_sfnt_service_sfnt_table($clazz) {
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 223;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 2635;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 224;
 STACKTOP = sp;return;
}
function _get_sfnt_table($face,$tag) {
 $face = $face|0;
 $tag = $tag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $table$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($tag|0) {
 case 1:  {
  $10 = (($face) + 260|0);
  $table$0 = $10;
  break;
 }
 case 6:  {
  $11 = (($face) + 556|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if ($13) {
   $table$0 = 0;
  } else {
   $table$0 = $11;
  }
  break;
 }
 case 3:  {
  $1 = (($face) + 216|0);
  $table$0 = $1;
  break;
 }
 case 2:  {
  $6 = (($face) + 368|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = ($7<<16>>16)==(-1);
  if ($8) {
   $table$0 = 0;
  } else {
   $table$0 = $6;
  }
  break;
 }
 case 4:  {
  $2 = (($face) + 296|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if ($4) {
   $table$0 = 0;
  } else {
   $5 = (($face) + 300|0);
   $table$0 = $5;
  }
  break;
 }
 case 5:  {
  $9 = (($face) + 468|0);
  $table$0 = $9;
  break;
 }
 case 0:  {
  $0 = (($face) + 160|0);
  $table$0 = $0;
  break;
 }
 default: {
  $table$0 = 0;
 }
 }
 STACKTOP = sp;return ($table$0|0);
}
function _sfnt_table_info($face,$idx,$tag,$offset,$length) {
 $face = $face|0;
 $idx = $idx|0;
 $tag = $tag|0;
 $offset = $offset|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($offset|0)==(0|0);
 $1 = ($length|0)==(0|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($tag|0)==(0|0);
 $3 = (($face) + 152|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 do {
  if ($2) {
   $storemerge = $5;
  } else {
   $6 = ($5>>>0)>($idx>>>0);
   if ($6) {
    $7 = (($face) + 156|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($8) + ($idx<<4)|0);
    $10 = HEAP32[$9>>2]|0;
    HEAP32[$tag>>2] = $10;
    $11 = ((($8) + ($idx<<4)|0) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$offset>>2] = $12;
    $13 = ((($8) + ($idx<<4)|0) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $storemerge = $14;
    break;
   } else {
    $$0 = 142;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP32[$length>>2] = $storemerge;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Init_Class_sfnt_service_glyph_dict($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 283;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 2636;
 STACKTOP = sp;return;
}
function _sfnt_get_glyph_name($face,$glyph_index,$buffer,$buffer_max) {
 $face = $face|0;
 $glyph_index = $glyph_index|0;
 $buffer = $buffer|0;
 $buffer_max = $buffer_max|0;
 var $0 = 0, $1 = 0, $2 = 0, $gname = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $gname = sp;
 $0 = (_tt_face_get_ps_name($face,$glyph_index,$gname)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return ($0|0);
 }
 $2 = HEAP32[$gname>>2]|0;
 (_ft_mem_strcpyn($buffer,$2,$buffer_max)|0);
 STACKTOP = sp;return ($0|0);
}
function _sfnt_get_name_index($face,$glyph_name) {
 $face = $face|0;
 $glyph_name = $glyph_name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $gname = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $gname = sp;
 $0 = (($face) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<(1);
 L1: do {
  if ($2) {
   $$0 = 0;
  } else {
   $i$01 = 0;
   while(1) {
    $3 = (_tt_face_get_ps_name($face,$i$01,$gname)|0);
    $4 = ($3|0)==(0);
    if ($4) {
     $5 = HEAP32[$gname>>2]|0;
     $6 = (_strcmp($glyph_name,$5)|0);
     $7 = ($6|0)==(0);
     if ($7) {
      $$0 = $i$01;
      break L1;
     }
    }
    $8 = (($i$01) + 1)|0;
    $9 = ($8>>>0)<($1>>>0);
    if ($9) {
     $i$01 = $8;
    } else {
     $$0 = 0;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _FT_Init_Class_sfnt_service_ps_name($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 3432;
 STACKTOP = sp;return;
}
function _sfnt_get_ps_name($face) {
 $face = $face|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $error = 0, $error5 = 0, $found_apple$04 = 0, $found_apple$1 = 0, $found_win$05 = 0;
 var $found_win$1 = 0, $found_win$2 = 0, $len$01 = 0, $n$0$found_apple$0 = 0, $n$0$found_win$0 = 0, $n$06 = 0, $or$cond = 0, $p$03 = 0, $r$0$lcssa = 0, $r$02 = 0, $r$1 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp + 4|0;
 $error5 = sp;
 $0 = (($face) + 700|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($face) + 344|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($4<<16>>16)==(0);
 do {
  if ($5) {
   $result$0 = 0;
  } else {
   $6 = (($face) + 360|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $4&65535;
   $found_apple$04 = -1;$found_win$05 = -1;$n$06 = 0;
   while(1) {
    $9 = ((($7) + (($n$06*20)|0)|0) + 6|0);
    $10 = HEAP16[$9>>1]|0;
    $11 = ($10<<16>>16)==(6);
    do {
     if ($11) {
      $12 = ((($7) + (($n$06*20)|0)|0) + 8|0);
      $13 = HEAP16[$12>>1]|0;
      $14 = ($13<<16>>16)==(0);
      if ($14) {
       $found_apple$1 = $found_apple$04;$found_win$2 = $found_win$05;
      } else {
       $15 = (($7) + (($n$06*20)|0)|0);
       $16 = HEAP16[$15>>1]|0;
       $17 = ($16<<16>>16)==(3);
       if ($17) {
        $18 = ((($7) + (($n$06*20)|0)|0) + 2|0);
        $19 = HEAP16[$18>>1]|0;
        $20 = ($19<<16>>16)==(1);
        if (!($20)) {
         $found_apple$1 = $found_apple$04;$found_win$2 = $found_win$05;
         break;
        }
        $21 = ((($7) + (($n$06*20)|0)|0) + 4|0);
        $22 = HEAP16[$21>>1]|0;
        $23 = ($22<<16>>16)==(1033);
        $n$0$found_win$0 = $23 ? $n$06 : $found_win$05;
        $found_win$1 = $n$0$found_win$0;
       } else {
        $found_win$1 = $found_win$05;
       }
       $24 = ($16<<16>>16)==(1);
       if ($24) {
        $25 = ((($7) + (($n$06*20)|0)|0) + 2|0);
        $26 = HEAP16[$25>>1]|0;
        $27 = ($26<<16>>16)==(0);
        if ($27) {
         $28 = ((($7) + (($n$06*20)|0)|0) + 4|0);
         $29 = HEAP16[$28>>1]|0;
         $30 = ($29<<16>>16)==(0);
         $n$0$found_apple$0 = $30 ? $n$06 : $found_apple$04;
         $found_apple$1 = $n$0$found_apple$0;$found_win$2 = $found_win$1;
        } else {
         $found_apple$1 = $found_apple$04;$found_win$2 = $found_win$1;
        }
       } else {
        $found_apple$1 = $found_apple$04;$found_win$2 = $found_win$1;
       }
      }
     } else {
      $found_apple$1 = $found_apple$04;$found_win$2 = $found_win$05;
     }
    } while(0);
    $31 = (($n$06) + 1)|0;
    $32 = ($31|0)<($8|0);
    if ($32) {
     $found_apple$04 = $found_apple$1;$found_win$05 = $found_win$2;$n$06 = $31;
    } else {
     break;
    }
   }
   $33 = ($found_win$2|0)==(-1);
   if ($33) {
    $71 = ($found_apple$1|0)==(-1);
    if ($71) {
     $result$0 = 0;
     break;
    }
    $72 = (($face) + 100|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($face) + 360|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = ((($75) + (($found_apple$1*20)|0)|0) + 8|0);
    $77 = HEAP16[$76>>1]|0;
    $78 = $77&65535;
    HEAP32[$error5>>2] = 0;
    $79 = (($78) + 1)|0;
    $80 = (_ft_mem_alloc($73,$79,$error5)|0);
    $81 = HEAP32[$error5>>2]|0;
    $82 = ($81|0)==(0);
    if (!($82)) {
     $result$0 = $80;
     break;
    }
    $83 = (($face) + 364|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ((($75) + (($found_apple$1*20)|0)|0) + 12|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (_FT_Stream_Seek($84,$86)|0);
    HEAP32[$error5>>2] = $87;
    $88 = ($87|0)==(0);
    if ($88) {
     $89 = (_FT_Stream_Read($84,$80,$78)|0);
     HEAP32[$error5>>2] = $89;
     $90 = ($89|0)==(0);
     if ($90) {
      $93 = (($80) + ($78)|0);
      HEAP8[$93>>0] = 0;
      $result$0 = $80;
      break;
     }
    }
    HEAP32[$85>>2] = 0;
    HEAP16[$76>>1] = 0;
    $91 = ((($75) + (($found_apple$1*20)|0)|0) + 16|0);
    $92 = HEAP32[$91>>2]|0;
    _ft_mem_free($73,$92);
    HEAP32[$91>>2] = 0;
    _ft_mem_free($73,$80);
    $result$0 = 0;
    break;
   }
   $34 = (($face) + 100|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($face) + 360|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($37) + (($found_win$2*20)|0)|0) + 8|0);
   $39 = HEAP16[$38>>1]|0;
   $40 = $39&65535;
   $41 = $40 >>> 1;
   HEAP32[$error>>2] = 0;
   $42 = (($40) + 1)|0;
   $43 = (_ft_mem_alloc($35,$42,$error)|0);
   $44 = HEAP32[$error>>2]|0;
   $45 = ($44|0)==(0);
   if ($45) {
    $46 = (($face) + 364|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ((($37) + (($found_win$2*20)|0)|0) + 16|0);
    $49 = ((($37) + (($found_win$2*20)|0)|0) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (_FT_Stream_Seek($47,$50)|0);
    HEAP32[$error>>2] = $51;
    $52 = ($51|0)==(0);
    if ($52) {
     $53 = HEAP16[$38>>1]|0;
     $54 = $53&65535;
     $55 = (_FT_Stream_EnterFrame($47,$54)|0);
     HEAP32[$error>>2] = $55;
     $56 = ($55|0)==(0);
     if ($56) {
      $58 = ($41|0)==(0);
      if ($58) {
       $r$0$lcssa = $43;
      } else {
       $59 = (($47) + 32|0);
       $60 = HEAP32[$59>>2]|0;
       $len$01 = $41;$p$03 = $60;$r$02 = $43;
       while(1) {
        $61 = HEAP8[$p$03>>0]|0;
        $62 = ($61<<24>>24)==(0);
        if ($62) {
         $63 = (($p$03) + 1|0);
         $64 = HEAP8[$63>>0]|0;
         $65 = ($64&255)>(31);
         $66 = ($64<<24>>24)>(-1);
         $or$cond = $65 & $66;
         if ($or$cond) {
          $67 = (($r$02) + 1|0);
          HEAP8[$r$02>>0] = $64;
          $r$1 = $67;
         } else {
          $r$1 = $r$02;
         }
        } else {
         $r$1 = $r$02;
        }
        $68 = (($len$01) + -1)|0;
        $69 = (($p$03) + 2|0);
        $70 = ($68|0)==(0);
        if ($70) {
         $r$0$lcssa = $r$1;
         break;
        } else {
         $len$01 = $68;$p$03 = $69;$r$02 = $r$1;
        }
       }
      }
      HEAP8[$r$0$lcssa>>0] = 0;
      _FT_Stream_ExitFrame($47);
      $result$0 = $43;
      break;
     }
    }
    _ft_mem_free($35,$43);
    HEAP16[$38>>1] = 0;
    HEAP32[$49>>2] = 0;
    $57 = HEAP32[$48>>2]|0;
    _ft_mem_free($35,$57);
    HEAP32[$48>>2] = 0;
    $result$0 = 0;
   } else {
    $result$0 = $43;
   }
  }
 } while(0);
 HEAP32[$0>>2] = $result$0;
 $$0 = $result$0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Init_Class_tt_service_get_cmap_info($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 2637;
 STACKTOP = sp;return;
}
function _FT_Destroy_Class_sfnt_services($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($clazz|0)==(0|0);
 if (!($0)) {
  $1 = HEAP32[$library>>2]|0;
  _ft_mem_free($1,$clazz);
 }
 STACKTOP = sp;return;
}
function _FT_Create_Class_sfnt_services($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,40,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = 871432;
 $4 = (($library) + 220|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 24|0);
 $7 = (($1) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($1) + 8|0);
 HEAP32[$8>>2] = 871448;
 $9 = HEAP32[$4>>2]|0;
 $10 = (($9) + 12|0);
 $11 = (($1) + 12|0);
 HEAP32[$11>>2] = $10;
 $12 = (($1) + 16|0);
 HEAP32[$12>>2] = 871472;
 $13 = HEAP32[$4>>2]|0;
 $14 = (($13) + 4|0);
 $15 = (($1) + 20|0);
 HEAP32[$15>>2] = $14;
 $16 = (($1) + 24|0);
 HEAP32[$16>>2] = 871488;
 $17 = HEAP32[$4>>2]|0;
 $18 = (($17) + 16|0);
 $19 = (($1) + 28|0);
 HEAP32[$19>>2] = $18;
 $20 = (($1) + 32|0);
 HEAP32[$20>>2] = 0;
 $21 = (($1) + 36|0);
 HEAP32[$21>>2] = 0;
 HEAP32[$output_class>>2] = $1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Init_Class_sfnt_interface($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 284;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 225;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 226;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 3738;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 2638;
 $4 = (($clazz) + 20|0);
 HEAP32[$4>>2] = 223;
 $5 = (($clazz) + 24|0);
 HEAP32[$5>>2] = 285;
 $6 = (($clazz) + 28|0);
 HEAP32[$6>>2] = 1599;
 $7 = (($clazz) + 32|0);
 HEAP32[$7>>2] = 2639;
 $8 = (($clazz) + 36|0);
 HEAP32[$8>>2] = 1600;
 $9 = (($clazz) + 40|0);
 HEAP32[$9>>2] = 2640;
 $10 = (($clazz) + 44|0);
 HEAP32[$10>>2] = 2641;
 $11 = (($clazz) + 48|0);
 HEAP32[$11>>2] = 2642;
 $12 = (($clazz) + 52|0);
 HEAP32[$12>>2] = 2643;
 $13 = (($clazz) + 56|0);
 HEAP32[$13>>2] = 2644;
 $14 = (($clazz) + 60|0);
 HEAP32[$14>>2] = 3739;
 $15 = (($clazz) + 64|0);
 HEAP32[$15>>2] = 2645;
 $16 = (($clazz) + 68|0);
 HEAP32[$16>>2] = 3740;
 $17 = (($clazz) + 72|0);
 HEAP32[$17>>2] = 2646;
 $18 = (($clazz) + 76|0);
 HEAP32[$18>>2] = 2647;
 $19 = (($clazz) + 80|0);
 HEAP32[$19>>2] = 2648;
 $20 = (($clazz) + 84|0);
 HEAP32[$20>>2] = 2649;
 $21 = (($clazz) + 88|0);
 HEAP32[$21>>2] = 286;
 $22 = (($clazz) + 92|0);
 HEAP32[$22>>2] = 2650;
 $23 = (($clazz) + 96|0);
 HEAP32[$23>>2] = 126;
 $24 = (($clazz) + 100|0);
 HEAP32[$24>>2] = 1601;
 $25 = (($clazz) + 104|0);
 HEAP32[$25>>2] = 116;
 $26 = (($clazz) + 108|0);
 HEAP32[$26>>2] = 3741;
 $27 = (($clazz) + 112|0);
 HEAP32[$27>>2] = 1602;
 $28 = (($clazz) + 116|0);
 HEAP32[$28>>2] = 3742;
 $29 = (($clazz) + 120|0);
 HEAP32[$29>>2] = 1603;
 $30 = (($clazz) + 124|0);
 HEAP32[$30>>2] = 2651;
 $31 = (($clazz) + 128|0);
 HEAP32[$31>>2] = 1604;
 $32 = (($clazz) + 132|0);
 HEAP32[$32>>2] = 2652;
 $33 = (($clazz) + 136|0);
 HEAP32[$33>>2] = 1605;
 $34 = (($clazz) + 140|0);
 HEAP32[$34>>2] = 2653;
 $35 = (($clazz) + 144|0);
 HEAP32[$35>>2] = 3743;
 $36 = (($clazz) + 148|0);
 HEAP32[$36>>2] = 1606;
 $37 = (($clazz) + 152|0);
 HEAP32[$37>>2] = 1607;
 $38 = (($clazz) + 156|0);
 HEAP32[$38>>2] = 227;
 STACKTOP = sp;return;
}
function _sfnt_get_interface($module,$module_interface) {
 $module = $module|0;
 $module_interface = $module_interface|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($module) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 220|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (_ft_service_list_lookup($4,$module_interface)|0);
 STACKTOP = sp;return ($5|0);
}
function _tt_face_load_sfnt_header_stub($face,$stream,$face_index,$header) {
 $face = $face|0;
 $stream = $stream|0;
 $face_index = $face_index|0;
 $header = $header|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 7;
}
function _tt_face_load_directory_stub($face,$stream,$header) {
 $face = $face|0;
 $stream = $stream|0;
 $header = $header|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 7;
}
function _tt_face_load_hdmx_stub($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 7;
}
function _tt_face_free_hdmx_stub($face) {
 $face = $face|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _tt_face_set_sbit_strike_stub($face,$x_ppem,$y_ppem,$astrike_index) {
 $face = $face|0;
 $x_ppem = $x_ppem|0;
 $y_ppem = $y_ppem|0;
 $astrike_index = $astrike_index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $req = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $req = sp;
 HEAP32[$req>>2] = 0;
 $0 = (($req) + 4|0);
 HEAP32[$0>>2] = $x_ppem;
 $1 = (($req) + 8|0);
 HEAP32[$1>>2] = $y_ppem;
 $2 = (($req) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($req) + 16|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$astrike_index>>2] = 2147483647;
 $4 = (_tt_face_set_sbit_strike($face,$req,$astrike_index)|0);
 STACKTOP = sp;return ($4|0);
}
function _tt_face_load_sbit_stub($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 7;
}
function _tt_face_free_sbit_stub($face) {
 $face = $face|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _tt_face_load_charmap_stub($face,$cmap,$input) {
 $face = $face|0;
 $cmap = $cmap|0;
 $input = $input|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 7;
}
function _tt_face_free_charmap_stub($face,$cmap) {
 $face = $face|0;
 $cmap = $cmap|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _FT_Destroy_Class_sfnt_module_class($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 _sfnt_module_class_pic_free($library);
 $1 = ($clazz|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$clazz);
 STACKTOP = sp;return;
}
function _FT_Create_Class_sfnt_module_class($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,36,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_sfnt_module_class_pic_init($library)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if ($5) {
  HEAP32[$1>>2] = 0;
  $7 = (($1) + 4|0);
  HEAP32[$7>>2] = 20;
  $8 = (($1) + 8|0);
  HEAP32[$8>>2] = 871504;
  $9 = (($1) + 12|0);
  HEAP32[$9>>2] = 65536;
  $10 = (($1) + 16|0);
  HEAP32[$10>>2] = 131072;
  $11 = (($library) + 220|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 36|0);
  $14 = (($1) + 20|0);
  HEAP32[$14>>2] = $13;
  $15 = (($1) + 24|0);
  HEAP32[$15>>2] = 0;
  $16 = (($1) + 28|0);
  HEAP32[$16>>2] = 0;
  $17 = (($1) + 32|0);
  HEAP32[$17>>2] = 2638;
  HEAP32[$output_class>>2] = $1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  _ft_mem_free($0,$1);
  $6 = HEAP32[$error>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _tt_cmap_init($cmap,$table) {
 $cmap = $cmap|0;
 $table = $table|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 HEAP32[$0>>2] = $table;
 STACKTOP = sp;return 0;
}
function _tt_cmap0_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($char_code>>>0)<(256);
 if (!($0)) {
  $7 = 0;
  STACKTOP = sp;return ($7|0);
 }
 $1 = (($cmap) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($char_code) + 6)|0;
 $4 = (($2) + ($3)|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6;
 STACKTOP = sp;return ($7|0);
}
function _tt_cmap0_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var $$sum = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $charcode$0 = 0, $gindex$0 = 0, $gindex$1 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$pchar_code>>2]|0;
 $charcode$0 = $2;$gindex$0 = 0;
 while(1) {
  $3 = (($charcode$0) + 1)|0;
  $4 = ($3>>>0)<(256);
  if (!($4)) {
   $gindex$1 = $gindex$0;$result$0 = 0;
   break;
  }
  $$sum = (($charcode$0) + 7)|0;
  $5 = (($1) + ($$sum)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6&255;
  $8 = ($6<<24>>24)==(0);
  if ($8) {
   $charcode$0 = $3;$gindex$0 = $7;
  } else {
   $gindex$1 = $7;$result$0 = $3;
   break;
  }
 }
 HEAP32[$pchar_code>>2] = $result$0;
 STACKTOP = sp;return ($gindex$1|0);
}
function _tt_cmap0_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $n$02 = 0, $or$cond = 0, $p$03 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 2|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 << 8;
 $4 = (($table) + 3|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $3 | $6;
 $8 = (($table) + ($7)|0);
 $9 = (($valid) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 $12 = ($7>>>0)<(262);
 $or$cond = $11 | $12;
 if ($or$cond) {
  _ft_validator_error($valid,8);
 }
 $13 = (($valid) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return 0;
 }
 $16 = (($table) + 6|0);
 $17 = (($valid) + 20|0);
 $n$02 = 1;$p$03 = $16;
 while(1) {
  $18 = (($p$03) + 1|0);
  $19 = HEAP8[$p$03>>0]|0;
  $20 = $19&255;
  $21 = HEAP32[$17>>2]|0;
  $22 = ($20>>>0)<($21>>>0);
  if (!($22)) {
   _ft_validator_error($valid,16);
  }
  $exitcond = ($n$02|0)==(256);
  if ($exitcond) {
   break;
  }
  $phitmp = (($n$02) + 1)|0;
  $n$02 = $phitmp;$p$03 = $18;
 }
 STACKTOP = sp;return 0;
}
function _tt_cmap0_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($cmap_info) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP8[$2>>0]|0;
 $5 = $4&255;
 $6 = $5 << 8;
 $7 = (($1) + 5|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $6 | $9;
 HEAP32[$cmap_info>>2] = $10;
 STACKTOP = sp;return 0;
}
function _tt_cmap2_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $$masked$i = 0, $$sum = 0, $$sum$i = 0, $$sum1 = 0, $$sum1$i = 0, $$sum2$i = 0, $$sum3$i = 0, $$sum4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $8 = 0, $9 = 0, $or$cond = 0, $result$0 = 0, $sub$0$i$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($char_code>>>0)<(65536);
 if (!($2)) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $3 = $char_code >>> 8;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (($1) + 518|0);
  $6 = $char_code << 1;
  $7 = $6 & 510;
  $$sum3$i = (($7) + 6)|0;
  $8 = (($1) + ($$sum3$i)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = $10 << 8;
  $$sum4$i = (($7) + 7)|0;
  $12 = (($1) + ($$sum4$i)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $11 | $14;
  $16 = ($15|0)==(0);
  if ($16) {
   $sub$0$i$ph = $5;
  } else {
   $result$0 = 0;
   STACKTOP = sp;return ($result$0|0);
  }
 } else {
  $17 = $3 << 1;
  $$sum$i = (($17) + 6)|0;
  $18 = (($1) + ($$sum$i)|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19&255;
  $21 = $20 << 8;
  $$sum1$i = (($17) + 7)|0;
  $22 = (($1) + ($$sum1$i)|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $$masked$i = $24 & 248;
  $25 = $$masked$i | $21;
  $$sum2$i = (($25) + 518)|0;
  $26 = (($1) + ($$sum2$i)|0);
  $27 = ($25|0)==(0);
  if ($27) {
   $result$0 = 0;
   STACKTOP = sp;return ($result$0|0);
  } else {
   $sub$0$i$ph = $26;
  }
 }
 $28 = $char_code & 255;
 $29 = HEAP8[$sub$0$i$ph>>0]|0;
 $30 = $29&255;
 $31 = $30 << 8;
 $32 = (($sub$0$i$ph) + 1|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = $31 | $34;
 $36 = (($sub$0$i$ph) + 2|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37&255;
 $39 = $38 << 8;
 $40 = (($sub$0$i$ph) + 3|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41&255;
 $43 = $39 | $42;
 $44 = (($sub$0$i$ph) + 6|0);
 $45 = (($sub$0$i$ph) + 4|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46 << 24 >> 24;
 $48 = $47 << 8;
 $49 = (($sub$0$i$ph) + 5|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = $50&255;
 $52 = $48 | $51;
 $53 = HEAP8[$44>>0]|0;
 $54 = $53&255;
 $55 = $54 << 8;
 $56 = (($sub$0$i$ph) + 7|0);
 $57 = HEAP8[$56>>0]|0;
 $58 = $57&255;
 $59 = $55 | $58;
 $60 = (($28) - ($35))|0;
 $61 = ($60>>>0)>=($43>>>0);
 $62 = ($59|0)==(0);
 $or$cond = $61 | $62;
 if ($or$cond) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $63 = $60 << 1;
 $64 = (($59) + ($63))|0;
 $$sum = (($64) + 6)|0;
 $65 = (($sub$0$i$ph) + ($$sum)|0);
 $66 = HEAP8[$65>>0]|0;
 $67 = $66&255;
 $68 = $67 << 8;
 $$sum1 = (($64) + 7)|0;
 $69 = (($sub$0$i$ph) + ($$sum1)|0);
 $70 = HEAP8[$69>>0]|0;
 $71 = $70&255;
 $72 = $68 | $71;
 $73 = ($72|0)==(0);
 if ($73) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $74 = (($72) + ($52))|0;
 $75 = $74 & 65535;
 $result$0 = $75;
 STACKTOP = sp;return ($result$0|0);
}
function _tt_cmap2_char_next($cmap,$pcharcode) {
 $cmap = $cmap|0;
 $pcharcode = $pcharcode|0;
 var $$masked$i = 0, $$sum = 0, $$sum$i = 0, $$sum1$i = 0, $$sum2$i = 0, $$sum3$i = 0, $$sum4$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $char_lo$0 = 0, $charcode$09 = 0, $charcode$16 = 0, $charcode$2 = 0;
 var $gindex$4 = 0, $p$05 = 0, $pos$0 = 0, $pos$17 = 0, $result$0 = 0, $sub$0$i$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$pcharcode>>2]|0;
 $3 = (($2) + 1)|0;
 $4 = ($3>>>0)<(65536);
 if (!($4)) {
  $gindex$4 = 0;$result$0 = 0;
  HEAP32[$pcharcode>>2] = $result$0;
  STACKTOP = sp;return ($gindex$4|0);
 }
 $5 = (($1) + 518|0);
 $charcode$09 = $3;
 L4: while(1) {
  $6 = $charcode$09 >>> 8;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = $charcode$09 << 1;
   $9 = $8 & 510;
   $$sum3$i = (($9) + 6)|0;
   $10 = (($1) + ($$sum3$i)|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = $11&255;
   $13 = $12 << 8;
   $$sum4$i = (($9) + 7)|0;
   $14 = (($1) + ($$sum4$i)|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = $15&255;
   $17 = $13 | $16;
   $18 = ($17|0)==(0);
   if ($18) {
    $sub$0$i$ph = $5;
    label = 6;
   } else {
    $charcode$2 = $charcode$09;
   }
  } else {
   $19 = $6 << 1;
   $$sum$i = (($19) + 6)|0;
   $20 = (($1) + ($$sum$i)|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21&255;
   $23 = $22 << 8;
   $$sum1$i = (($19) + 7)|0;
   $24 = (($1) + ($$sum1$i)|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = $25&255;
   $$masked$i = $26 & 248;
   $27 = $$masked$i | $23;
   $$sum2$i = (($27) + 518)|0;
   $28 = (($1) + ($$sum2$i)|0);
   $29 = ($27|0)==(0);
   if ($29) {
    $charcode$2 = $charcode$09;
   } else {
    $sub$0$i$ph = $28;
    label = 6;
   }
  }
  if ((label|0) == 6) {
   label = 0;
   $30 = HEAP8[$sub$0$i$ph>>0]|0;
   $31 = $30&255;
   $32 = $31 << 8;
   $33 = (($sub$0$i$ph) + 1|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34&255;
   $36 = $32 | $35;
   $37 = (($sub$0$i$ph) + 2|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = $38&255;
   $40 = $39 << 8;
   $41 = (($sub$0$i$ph) + 3|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = $42&255;
   $44 = $40 | $43;
   $45 = (($sub$0$i$ph) + 6|0);
   $46 = (($sub$0$i$ph) + 4|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = $47 << 24 >> 24;
   $49 = $48 << 8;
   $50 = (($sub$0$i$ph) + 5|0);
   $51 = HEAP8[$50>>0]|0;
   $52 = $51&255;
   $53 = $49 | $52;
   $54 = HEAP8[$45>>0]|0;
   $55 = $54&255;
   $56 = $55 << 8;
   $57 = (($sub$0$i$ph) + 7|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = $58&255;
   $60 = $56 | $59;
   $61 = $charcode$09 & 255;
   $62 = ($60|0)==(0);
   if ($62) {
    $charcode$2 = $charcode$09;
   } else {
    $63 = ($61>>>0)<($36>>>0);
    $64 = (($61) - ($36))|0;
    $char_lo$0 = $63 ? $36 : $61;
    $pos$0 = $63 ? 0 : $64;
    $65 = $charcode$09 & -256;
    $66 = (($char_lo$0) + ($65))|0;
    $67 = ($pos$0>>>0)<($44>>>0);
    if ($67) {
     $68 = $pos$0 << 1;
     $69 = (($68) + 6)|0;
     $$sum = (($69) + ($60))|0;
     $70 = (($sub$0$i$ph) + ($$sum)|0);
     $charcode$16 = $66;$p$05 = $70;$pos$17 = $pos$0;
     while(1) {
      $71 = (($p$05) + 2|0);
      $72 = HEAP8[$p$05>>0]|0;
      $73 = $72&255;
      $74 = $73 << 8;
      $75 = (($p$05) + 1|0);
      $76 = HEAP8[$75>>0]|0;
      $77 = $76&255;
      $78 = $74 | $77;
      $79 = ($78|0)==(0);
      if (!($79)) {
       $80 = (($78) + ($53))|0;
       $81 = $80 & 65535;
       $82 = ($81|0)==(0);
       if (!($82)) {
        $gindex$4 = $81;$result$0 = $charcode$16;
        label = 13;
        break L4;
       }
      }
      $83 = (($pos$17) + 1)|0;
      $84 = (($charcode$16) + 1)|0;
      $85 = ($83>>>0)<($44>>>0);
      if ($85) {
       $charcode$16 = $84;$p$05 = $71;$pos$17 = $83;
      } else {
       $charcode$2 = $84;
       break;
      }
     }
    } else {
     $charcode$2 = $66;
    }
   }
  }
  $86 = (($charcode$2) + 256)|0;
  $87 = $86 & -256;
  $88 = ($87>>>0)<(65536);
  if ($88) {
   $charcode$09 = $87;
  } else {
   $gindex$4 = 0;$result$0 = 0;
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  HEAP32[$pcharcode>>2] = $result$0;
  STACKTOP = sp;return ($gindex$4|0);
 }
 return 0|0;
}
function _tt_cmap2_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $$max_subs$0 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $max_subs$07 = 0, $n$08 = 0, $n$15 = 0, $or$cond = 0, $p$09 = 0, $p$16 = 0, $p$24 = 0, $p$3 = 0, $scevgep = 0, $scevgep12$sum = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 2|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 << 8;
 $4 = (($table) + 3|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $3 | $6;
 $8 = (($table) + ($7)|0);
 $9 = (($valid) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)>($10>>>0);
 $12 = ($7>>>0)<(518);
 $or$cond = $11 | $12;
 if ($or$cond) {
  _ft_validator_error($valid,8);
 }
 $13 = (($table) + 6|0);
 $14 = (($valid) + 8|0);
 $scevgep = (($table) + 518|0);
 $max_subs$07 = 0;$n$08 = 0;$p$09 = $13;
 while(1) {
  $15 = (($p$09) + 2|0);
  $16 = HEAP8[$p$09>>0]|0;
  $17 = $16&255;
  $18 = $17 << 8;
  $19 = (($p$09) + 1|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20&255;
  $22 = $18 | $21;
  $23 = HEAP32[$14>>2]|0;
  $24 = ($23>>>0)>(1);
  if ($24) {
   $25 = $21 & 7;
   $26 = ($25|0)==(0);
   if (!($26)) {
    _ft_validator_error($valid,8);
   }
  }
  $27 = $22 >>> 3;
  $28 = ($27>>>0)>($max_subs$07>>>0);
  $$max_subs$0 = $28 ? $27 : $max_subs$07;
  $29 = (($n$08) + 1)|0;
  $exitcond = ($29|0)==(256);
  if ($exitcond) {
   break;
  } else {
   $max_subs$07 = $$max_subs$0;$n$08 = $29;$p$09 = $15;
  }
 }
 $30 = $$max_subs$0 << 3;
 $scevgep12$sum = (($30) + 526)|0;
 $31 = (($table) + ($scevgep12$sum)|0);
 $32 = HEAP32[$9>>2]|0;
 $33 = ($31>>>0)>($32>>>0);
 if ($33) {
  _ft_validator_error($valid,8);
 }
 $34 = (($valid) + 20|0);
 $n$15 = 0;$p$16 = $scevgep;
 while(1) {
  $35 = HEAP8[$p$16>>0]|0;
  $36 = $35&255;
  $37 = $36 << 8;
  $38 = (($p$16) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = $37 | $40;
  $42 = (($p$16) + 2|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = $43&255;
  $45 = $44 << 8;
  $46 = (($p$16) + 3|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = $47&255;
  $49 = $45 | $48;
  $50 = (($p$16) + 4|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51 << 24 >> 24;
  $53 = $52 << 8;
  $54 = (($p$16) + 5|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = $53 | $56;
  $58 = (($p$16) + 8|0);
  $59 = (($p$16) + 6|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = $60&255;
  $62 = $61 << 8;
  $63 = (($p$16) + 7|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = $64&255;
  $66 = $62 | $65;
  $67 = ($49|0)==(0);
  if ($67) {
   $p$3 = $58;
  } else {
   $68 = HEAP32[$14>>2]|0;
   $69 = ($68>>>0)>(1);
   do {
    if ($69) {
     $70 = ($41>>>0)>(255);
     if (!($70)) {
      $71 = (($49) + ($41))|0;
      $72 = ($71>>>0)>(256);
      if (!($72)) {
       break;
      }
     }
     _ft_validator_error($valid,8);
    }
   } while(0);
   $73 = ($66|0)==(0);
   if ($73) {
    $p$3 = $58;
   } else {
    $$sum = (($66) + 6)|0;
    $74 = (($p$16) + ($$sum)|0);
    $75 = ($74>>>0)<($31>>>0);
    if ($75) {
     label = 19;
    } else {
     $76 = $49 << 1;
     $$sum2 = (($$sum) + ($76))|0;
     $77 = (($p$16) + ($$sum2)|0);
     $78 = ($77>>>0)>($8>>>0);
     if ($78) {
      label = 19;
     }
    }
    if ((label|0) == 19) {
     label = 0;
     _ft_validator_error($valid,9);
    }
    $79 = HEAP32[$14>>2]|0;
    $80 = ($79|0)==(0);
    if ($80) {
     $p$3 = $58;
    } else {
     $81 = $49 << 1;
     $$sum3 = (($81) + 8)|0;
     $82 = (($p$16) + ($$sum3)|0);
     $83 = ($$sum3>>>0)>(8);
     if ($83) {
      $p$24 = $58;
      while(1) {
       $84 = (($p$24) + 2|0);
       $85 = HEAP8[$p$24>>0]|0;
       $86 = $85&255;
       $87 = $86 << 8;
       $88 = (($p$24) + 1|0);
       $89 = HEAP8[$88>>0]|0;
       $90 = $89&255;
       $91 = $87 | $90;
       $92 = ($91|0)==(0);
       if (!($92)) {
        $93 = (($91) + ($57))|0;
        $94 = $93 & 65535;
        $95 = HEAP32[$34>>2]|0;
        $96 = ($94>>>0)<($95>>>0);
        if (!($96)) {
         _ft_validator_error($valid,16);
        }
       }
       $97 = ($84>>>0)<($82>>>0);
       if ($97) {
        $p$24 = $84;
       } else {
        $p$3 = $84;
        break;
       }
      }
     } else {
      $p$3 = $58;
     }
    }
   }
  }
  $98 = (($n$15) + 1)|0;
  $99 = ($98>>>0)>($$max_subs$0>>>0);
  if ($99) {
   break;
  } else {
   $n$15 = $98;$p$16 = $p$3;
  }
 }
 STACKTOP = sp;return 0;
}
function _tt_cmap2_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($cmap_info) + 4|0);
 HEAP32[$3>>2] = 2;
 $4 = HEAP8[$2>>0]|0;
 $5 = $4&255;
 $6 = $5 << 8;
 $7 = (($1) + 5|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $6 | $9;
 HEAP32[$cmap_info>>2] = $10;
 STACKTOP = sp;return 0;
}
function _tt_cmap4_init($cmap,$table) {
 $cmap = $cmap|0;
 $table = $table|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 HEAP32[$0>>2] = $table;
 $1 = (($table) + 6|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 8;
 $5 = (($table) + 7|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $4 | $7;
 $9 = $8 >>> 1;
 $10 = (($cmap) + 32|0);
 HEAP32[$10>>2] = $9;
 $11 = (($cmap) + 24|0);
 HEAP32[$11>>2] = -1;
 $12 = (($cmap) + 28|0);
 HEAP32[$12>>2] = 0;
 STACKTOP = sp;return 0;
}
function _tt_cmap4_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $char_code;
 $1 = ($char_code>>>0)>(65535);
 do {
  if ($1) {
   $$0 = 0;
  } else {
   $2 = (($cmap) + 20|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = $3 & 1;
   $5 = ($4|0)==(0);
   if ($5) {
    $7 = (_tt_cmap4_char_map_binary($cmap,$0,0)|0);
    $$0 = $7;
    break;
   } else {
    $6 = (_tt_cmap4_char_map_linear($cmap,$0,0)|0);
    $$0 = $6;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap4_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$pchar_code>>2]|0;
 $1 = ($0>>>0)>(65534);
 do {
  if ($1) {
   $$0 = 0;
  } else {
   $2 = (($cmap) + 20|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = $3 & 1;
   $5 = ($4|0)==(0);
   if (!($5)) {
    $6 = (_tt_cmap4_char_map_linear($cmap,$pchar_code,1)|0);
    $$0 = $6;
    break;
   }
   $7 = (($cmap) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($0|0)==($8|0);
   if (!($9)) {
    $14 = (_tt_cmap4_char_map_binary($cmap,$pchar_code,1)|0);
    $$0 = $14;
    break;
   }
   _tt_cmap4_next($cmap);
   $10 = (($cmap) + 28|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $$0 = 0;
   } else {
    $13 = HEAP32[$7>>2]|0;
    HEAP32[$pchar_code>>2] = $13;
    $$0 = $11;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap4_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error$0$lcssa = 0, $error$019 = 0, $error$1 = 0, $exitcond = 0, $i$017 = 0, $last_end$022 = 0, $last_start$021 = 0, $length$0 = 0, $n$020 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond11 = 0, $or$cond12 = 0;
 var $or$cond13 = 0, $or$cond14 = 0, $or$cond15 = 0, $or$cond29 = 0, $p$016 = 0, $p_delta$025 = 0, $p_end$024 = 0, $p_offset$026 = 0, $p_start$023 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 2|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 << 8;
 $4 = (($table) + 3|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $3 | $6;
 $8 = ($7>>>0)<(16);
 if ($8) {
  _ft_validator_error($valid,8);
 }
 $9 = (($table) + ($7)|0);
 $10 = (($valid) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9>>>0)>($11>>>0);
 $13 = (($valid) + 8|0);
 if ($12) {
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0);
  if (!($15)) {
   _ft_validator_error($valid,8);
  }
  $16 = HEAP32[$10>>2]|0;
  $17 = $16;
  $18 = $table;
  $19 = (($17) - ($18))|0;
  $length$0 = $19;
 } else {
  $length$0 = $7;
 }
 $20 = (($table) + 6|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 $23 = $22 << 8;
 $24 = (($table) + 7|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25&255;
 $27 = $23 | $26;
 $28 = HEAP32[$13>>2]|0;
 $29 = ($28>>>0)>(1);
 if ($29) {
  $30 = $26 & 1;
  $31 = ($30|0)==(0);
  if (!($31)) {
   _ft_validator_error($valid,8);
  }
 }
 $32 = $27 >>> 1;
 $33 = $32 << 1;
 $34 = $32 << 3;
 $35 = (($34) + 16)|0;
 $36 = ($length$0>>>0)<($35>>>0);
 if ($36) {
  _ft_validator_error($valid,8);
 }
 $37 = HEAP32[$13>>2]|0;
 $38 = ($37>>>0)>(1);
 do {
  if ($38) {
   $39 = (($table) + 8|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40&255;
   $42 = $41 << 8;
   $43 = (($table) + 9|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = $44&255;
   $46 = $42 | $45;
   $47 = (($table) + 10|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = $48&255;
   $50 = $49 << 8;
   $51 = (($table) + 11|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = $52&255;
   $54 = $50 | $53;
   $55 = (($table) + 12|0);
   $56 = HEAP8[$55>>0]|0;
   $57 = $56&255;
   $58 = $57 << 8;
   $59 = (($table) + 13|0);
   $60 = HEAP8[$59>>0]|0;
   $61 = $60&255;
   $62 = $58 | $61;
   $63 = $60 | $44;
   $64 = $63 & 1;
   $65 = ($64<<24>>24)==(0);
   if (!($65)) {
    _ft_validator_error($valid,8);
   }
   $66 = $46 >>> 1;
   $67 = ($66>>>0)>($32>>>0);
   $68 = $66 << 1;
   $69 = ($68>>>0)<($32>>>0);
   $or$cond10 = $67 | $69;
   if (!($or$cond10)) {
    $70 = $62 >>> 1;
    $71 = (($70) + ($66))|0;
    $72 = ($71|0)==($32|0);
    if ($72) {
     $73 = 1 << $54;
     $74 = ($66|0)==($73|0);
     if ($74) {
      break;
     }
    }
   }
   _ft_validator_error($valid,8);
  }
 } while(0);
 $75 = (($table) + 14|0);
 $$sum = (($33) + 16)|0;
 $76 = (($table) + ($$sum)|0);
 $$sum2 = (($$sum) + ($33))|0;
 $77 = (($table) + ($$sum2)|0);
 $$sum3 = (($$sum2) + ($33))|0;
 $78 = (($table) + ($$sum3)|0);
 $$sum4 = (($$sum3) + ($33))|0;
 $79 = (($table) + ($$sum4)|0);
 $80 = HEAP32[$13>>2]|0;
 $81 = ($80>>>0)>(1);
 if ($81) {
  $$sum7 = (($33) + 12)|0;
  $82 = (($table) + ($$sum7)|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = $83&255;
  $85 = $84 << 8;
  $$sum8 = (($33) + 13)|0;
  $86 = (($table) + ($$sum8)|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = $87&255;
  $89 = $85 | $88;
  $90 = ($89|0)==(65535);
  if (!($90)) {
   _ft_validator_error($valid,8);
  }
 }
 $91 = ($32|0)==(0);
 if ($91) {
  $error$0$lcssa = 0;
  STACKTOP = sp;return ($error$0$lcssa|0);
 }
 $92 = (($32) + -1)|0;
 $93 = (($valid) + 20|0);
 $94 = (($table) + ($length$0)|0);
 $error$019 = 0;$last_end$022 = 0;$last_start$021 = 0;$n$020 = 0;$p_delta$025 = $77;$p_end$024 = $75;$p_offset$026 = $78;$p_start$023 = $76;
 while(1) {
  $95 = (($p_start$023) + 2|0);
  $96 = HEAP8[$p_start$023>>0]|0;
  $97 = $96&255;
  $98 = $97 << 8;
  $99 = (($p_start$023) + 1|0);
  $100 = HEAP8[$99>>0]|0;
  $101 = $100&255;
  $102 = $98 | $101;
  $103 = (($p_end$024) + 2|0);
  $104 = HEAP8[$p_end$024>>0]|0;
  $105 = $104&255;
  $106 = $105 << 8;
  $107 = (($p_end$024) + 1|0);
  $108 = HEAP8[$107>>0]|0;
  $109 = $108&255;
  $110 = $106 | $109;
  $111 = (($p_delta$025) + 2|0);
  $112 = HEAP8[$p_delta$025>>0]|0;
  $113 = $112 << 24 >> 24;
  $114 = $113 << 8;
  $115 = (($p_delta$025) + 1|0);
  $116 = HEAP8[$115>>0]|0;
  $117 = $116&255;
  $118 = $114 | $117;
  $119 = (($p_offset$026) + 2|0);
  $120 = HEAP8[$p_offset$026>>0]|0;
  $121 = $120&255;
  $122 = $121 << 8;
  $123 = (($p_offset$026) + 1|0);
  $124 = HEAP8[$123>>0]|0;
  $125 = $124&255;
  $126 = $122 | $125;
  $127 = ($102>>>0)>($110>>>0);
  if ($127) {
   _ft_validator_error($valid,8);
  }
  $128 = ($102>>>0)>($last_end$022>>>0);
  $129 = ($n$020|0)==(0);
  $or$cond11 = $128 | $129;
  do {
   if ($or$cond11) {
    $error$1 = $error$019;
   } else {
    $130 = HEAP32[$13>>2]|0;
    $131 = ($130|0)==(0);
    if (!($131)) {
     _ft_validator_error($valid,8);
     $error$1 = $error$019;
     break;
    }
    $132 = ($last_start$021>>>0)>($102>>>0);
    $133 = ($last_end$022>>>0)>($110>>>0);
    $or$cond12 = $132 | $133;
    if ($or$cond12) {
     $134 = $error$019 | 1;
     $error$1 = $134;
     break;
    } else {
     $135 = $error$019 | 2;
     $error$1 = $135;
     break;
    }
   }
  } while(0);
  do {
   if ((($126|0) == 65535)) {
    $172 = HEAP32[$13>>2]|0;
    $173 = ($172>>>0)>(1);
    if (!($173)) {
     $174 = ($n$020|0)==($92|0);
     $175 = ($102|0)==(65535);
     $or$cond14 = $174 & $175;
     $176 = ($110|0)==(65535);
     $or$cond15 = $or$cond14 & $176;
     if ($or$cond15) {
      break;
     }
    }
    _ft_validator_error($valid,8);
   } else if (!((($126|0) == 0))) {
    $136 = (($p_offset$026) + ($126)|0);
    $137 = HEAP32[$13>>2]|0;
    $138 = ($137|0)==(0);
    do {
     if ($138) {
      $145 = ($n$020|0)==($92|0);
      $146 = ($102|0)==(65535);
      $or$cond = $145 & $146;
      $147 = ($110|0)==(65535);
      $or$cond13 = $or$cond & $147;
      if (!($or$cond13)) {
       $148 = ($136>>>0)<($79>>>0);
       if (!($148)) {
        $149 = (($110) - ($102))|0;
        $150 = $149 << 1;
        $151 = (($150) + 2)|0;
        $$sum5 = (($151) + ($126))|0;
        $152 = (($p_offset$026) + ($$sum5)|0);
        $153 = HEAP32[$10>>2]|0;
        $154 = ($152>>>0)>($153>>>0);
        if (!($154)) {
         break;
        }
       }
       _ft_validator_error($valid,8);
      }
     } else {
      $139 = ($136>>>0)<($79>>>0);
      if (!($139)) {
       $140 = (($110) - ($102))|0;
       $141 = $140 << 1;
       $142 = (($141) + 2)|0;
       $$sum6 = (($142) + ($126))|0;
       $143 = (($p_offset$026) + ($$sum6)|0);
       $144 = ($143>>>0)>($94>>>0);
       if (!($144)) {
        break;
       }
      }
      _ft_validator_error($valid,8);
     }
    } while(0);
    $155 = HEAP32[$13>>2]|0;
    $156 = ($155|0)!=(0);
    $157 = ($102>>>0)<($110>>>0);
    $or$cond29 = $156 & $157;
    if ($or$cond29) {
     $i$017 = $102;$p$016 = $136;
     while(1) {
      $158 = (($p$016) + 2|0);
      $159 = HEAP8[$p$016>>0]|0;
      $160 = $159&255;
      $161 = $160 << 8;
      $162 = (($p$016) + 1|0);
      $163 = HEAP8[$162>>0]|0;
      $164 = $163&255;
      $165 = $161 | $164;
      $166 = ($165|0)==(0);
      if (!($166)) {
       $167 = (($165) + ($118))|0;
       $168 = $167 & 65535;
       $169 = HEAP32[$93>>2]|0;
       $170 = ($168>>>0)<($169>>>0);
       if (!($170)) {
        _ft_validator_error($valid,16);
       }
      }
      $171 = (($i$017) + 1)|0;
      $exitcond = ($171|0)==($110|0);
      if ($exitcond) {
       break;
      } else {
       $i$017 = $171;$p$016 = $158;
      }
     }
    }
   }
  } while(0);
  $177 = (($n$020) + 1)|0;
  $178 = ($177>>>0)<($32>>>0);
  if ($178) {
   $error$019 = $error$1;$last_end$022 = $110;$last_start$021 = $102;$n$020 = $177;$p_delta$025 = $111;$p_end$024 = $103;$p_offset$026 = $119;$p_start$023 = $95;
  } else {
   $error$0$lcssa = $error$1;
   break;
  }
 }
 STACKTOP = sp;return ($error$0$lcssa|0);
}
function _tt_cmap4_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($cmap_info) + 4|0);
 HEAP32[$3>>2] = 4;
 $4 = HEAP8[$2>>0]|0;
 $5 = $4&255;
 $6 = $5 << 8;
 $7 = (($1) + 5|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $6 | $9;
 HEAP32[$cmap_info>>2] = $10;
 STACKTOP = sp;return 0;
}
function _tt_cmap6_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 8;
 $6 = (($1) + 7|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $5 | $8;
 $10 = (($1) + 8|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 8;
 $14 = (($1) + 9|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = $13 | $16;
 $18 = (($char_code) - ($9))|0;
 $19 = ($18>>>0)<($17>>>0);
 if (!($19)) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $20 = $18 << 1;
 $$sum = (($20) + 10)|0;
 $21 = (($1) + ($$sum)|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22&255;
 $24 = $23 << 8;
 $$sum1 = (($20) + 11)|0;
 $25 = (($1) + ($$sum1)|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = $24 | $27;
 $result$0 = $28;
 STACKTOP = sp;return ($result$0|0);
}
function _tt_cmap6_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var $$ = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $char_code$12 = 0, $gindex$1 = 0, $idx$03 = 0, $p$01 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$pchar_code>>2]|0;
 $3 = (($2) + 1)|0;
 $4 = (($1) + 6|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 8;
 $8 = (($1) + 7|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $7 | $10;
 $12 = (($1) + 8|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 << 8;
 $16 = (($1) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ($3>>>0)>(65535);
 L1: do {
  if ($20) {
   $gindex$1 = 0;$result$0 = 0;
  } else {
   $21 = ($3>>>0)<($11>>>0);
   $$ = $21 ? $11 : $3;
   $22 = (($$) - ($11))|0;
   $23 = ($22>>>0)<($19>>>0);
   if ($23) {
    $24 = $22 << 1;
    $$sum = (($24) + 10)|0;
    $25 = (($1) + ($$sum)|0);
    $char_code$12 = $$;$idx$03 = $22;$p$01 = $25;
    while(1) {
     $26 = HEAP8[$p$01>>0]|0;
     $27 = $26&255;
     $28 = $27 << 8;
     $29 = (($p$01) + 1|0);
     $30 = HEAP8[$29>>0]|0;
     $31 = $30&255;
     $32 = $28 | $31;
     $33 = ($32|0)==(0);
     if (!($33)) {
      $gindex$1 = $32;$result$0 = $char_code$12;
      break L1;
     }
     $34 = (($p$01) + 2|0);
     $35 = (($char_code$12) + 1)|0;
     $36 = (($idx$03) + 1)|0;
     $37 = ($36>>>0)<($19>>>0);
     if ($37) {
      $char_code$12 = $35;$idx$03 = $36;$p$01 = $34;
     } else {
      $gindex$1 = 0;$result$0 = 0;
      break;
     }
    }
   } else {
    $gindex$1 = 0;$result$0 = 0;
   }
  }
 } while(0);
 HEAP32[$pchar_code>>2] = $result$0;
 STACKTOP = sp;return ($gindex$1|0);
}
function _tt_cmap6_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $or$cond = 0, $p$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 10|0);
 $1 = (($valid) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)>($2>>>0);
 if ($3) {
  _ft_validator_error($valid,8);
 }
 $4 = (($table) + 2|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 8;
 $8 = (($table) + 3|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $7 | $10;
 $12 = (($table) + 8|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 << 8;
 $16 = (($table) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = (($table) + ($11)|0);
 $21 = HEAP32[$1>>2]|0;
 $22 = ($20>>>0)>($21>>>0);
 if ($22) {
  label = 5;
 } else {
  $23 = $19 << 1;
  $24 = (($23) + 10)|0;
  $25 = ($11>>>0)<($24>>>0);
  if ($25) {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  _ft_validator_error($valid,8);
 }
 $26 = (($valid) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 $29 = ($19|0)==(0);
 $or$cond = $28 | $29;
 if ($or$cond) {
  STACKTOP = sp;return 0;
 }
 $30 = (($valid) + 20|0);
 $count$01 = $19;$p$02 = $0;
 while(1) {
  $31 = (($p$02) + 2|0);
  $32 = HEAP8[$p$02>>0]|0;
  $33 = $32&255;
  $34 = $33 << 8;
  $35 = (($p$02) + 1|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = $34 | $37;
  $39 = HEAP32[$30>>2]|0;
  $40 = ($38>>>0)<($39>>>0);
  if (!($40)) {
   _ft_validator_error($valid,16);
  }
  $41 = (($count$01) + -1)|0;
  $42 = ($41|0)==(0);
  if ($42) {
   break;
  } else {
   $count$01 = $41;$p$02 = $31;
  }
 }
 STACKTOP = sp;return 0;
}
function _tt_cmap6_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = (($cmap_info) + 4|0);
 HEAP32[$3>>2] = 6;
 $4 = HEAP8[$2>>0]|0;
 $5 = $4&255;
 $6 = $5 << 8;
 $7 = (($1) + 5|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $6 | $9;
 HEAP32[$cmap_info>>2] = $10;
 STACKTOP = sp;return 0;
}
function _tt_cmap8_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, $num_groups$02 = 0, $p$03 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8204|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = (($1) + 8205|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = (($1) + 8206|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = (($1) + 8207|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ($19|0)==(0);
 if ($20) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $21 = (($1) + 8208|0);
 $num_groups$02 = $19;$p$03 = $21;
 while(1) {
  $25 = HEAP8[$p$03>>0]|0;
  $26 = $25&255;
  $27 = $26 << 24;
  $28 = (($p$03) + 1|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $30 << 16;
  $32 = $31 | $27;
  $33 = (($p$03) + 2|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = $34&255;
  $36 = $35 << 8;
  $37 = $32 | $36;
  $38 = (($p$03) + 3|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = $37 | $40;
  $42 = (($p$03) + 8|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = $43&255;
  $45 = $44 << 24;
  $46 = (($p$03) + 9|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = $47&255;
  $49 = $48 << 16;
  $50 = $49 | $45;
  $51 = (($p$03) + 10|0);
  $52 = HEAP8[$51>>0]|0;
  $53 = $52&255;
  $54 = $53 << 8;
  $55 = $50 | $54;
  $56 = (($p$03) + 11|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57&255;
  $59 = ($41>>>0)>($char_code>>>0);
  if ($59) {
   $result$0 = 0;
   label = 7;
   break;
  }
  $60 = (($p$03) + 5|0);
  $61 = (($p$03) + 4|0);
  $62 = (($p$03) + 6|0);
  $63 = HEAP8[$60>>0]|0;
  $64 = HEAP8[$61>>0]|0;
  $65 = HEAP8[$62>>0]|0;
  $66 = $63&255;
  $67 = $64&255;
  $68 = (($p$03) + 7|0);
  $69 = $65&255;
  $70 = $66 << 16;
  $71 = $67 << 24;
  $72 = HEAP8[$68>>0]|0;
  $73 = $69 << 8;
  $74 = $71 | $70;
  $75 = $72&255;
  $76 = $74 | $73;
  $77 = $76 | $75;
  $78 = ($77>>>0)<($char_code>>>0);
  $24 = (($num_groups$02) + -1)|0;
  if (!($78)) {
   label = 6;
   break;
  }
  $22 = (($p$03) + 12|0);
  $23 = ($24|0)==(0);
  if ($23) {
   $result$0 = 0;
   label = 7;
   break;
  } else {
   $num_groups$02 = $24;$p$03 = $22;
  }
 }
 if ((label|0) == 6) {
  $79 = $55 | $58;
  $80 = (($char_code) - ($41))|0;
  $81 = (($80) + ($79))|0;
  $result$0 = $81;
  STACKTOP = sp;return ($result$0|0);
 }
 else if ((label|0) == 7) {
  STACKTOP = sp;return ($result$0|0);
 }
 return 0|0;
}
function _tt_cmap8_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var $$char_code$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $char_code$03 = 0, $gindex$2 = 0, $num_groups$02 = 0, $p$01 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8204|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = (($1) + 8205|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = (($1) + 8206|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = (($1) + 8207|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ($19|0)==(0);
 if ($20) {
  $gindex$2 = 0;$result$0 = 0;
  HEAP32[$pchar_code>>2] = $result$0;
  STACKTOP = sp;return ($gindex$2|0);
 }
 $21 = HEAP32[$pchar_code>>2]|0;
 $22 = (($1) + 8208|0);
 $23 = (($21) + 1)|0;
 $char_code$03 = $23;$num_groups$02 = $19;$p$01 = $22;
 while(1) {
  $24 = HEAP8[$p$01>>0]|0;
  $25 = $24&255;
  $26 = $25 << 24;
  $27 = (($p$01) + 1|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = $29 << 16;
  $31 = $30 | $26;
  $32 = (($p$01) + 2|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = $34 << 8;
  $36 = $31 | $35;
  $37 = (($p$01) + 3|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = $38&255;
  $40 = $36 | $39;
  $41 = (($p$01) + 4|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = $42&255;
  $44 = $43 << 24;
  $45 = (($p$01) + 5|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  $48 = $47 << 16;
  $49 = $48 | $44;
  $50 = (($p$01) + 6|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51&255;
  $53 = $52 << 8;
  $54 = $49 | $53;
  $55 = (($p$01) + 7|0);
  $56 = HEAP8[$55>>0]|0;
  $57 = $56&255;
  $58 = $54 | $57;
  $59 = (($p$01) + 12|0);
  $60 = ($char_code$03>>>0)<($40>>>0);
  $$char_code$0 = $60 ? $40 : $char_code$03;
  $61 = ($$char_code$0>>>0)>($58>>>0);
  if (!($61)) {
   $62 = (($p$01) + 9|0);
   $63 = (($p$01) + 8|0);
   $64 = (($p$01) + 10|0);
   $65 = HEAP8[$62>>0]|0;
   $66 = HEAP8[$63>>0]|0;
   $67 = HEAP8[$64>>0]|0;
   $68 = $65&255;
   $69 = $66&255;
   $70 = (($p$01) + 11|0);
   $71 = $67&255;
   $72 = $68 << 16;
   $73 = $69 << 24;
   $74 = HEAP8[$70>>0]|0;
   $75 = $71 << 8;
   $76 = $73 | $72;
   $77 = $74&255;
   $78 = $76 | $75;
   $79 = $78 | $77;
   $80 = (($$char_code$0) - ($40))|0;
   $81 = (($79) + ($80))|0;
   $82 = ($81|0)==(0);
   if (!($82)) {
    $gindex$2 = $81;$result$0 = $$char_code$0;
    label = 6;
    break;
   }
  }
  $83 = (($num_groups$02) + -1)|0;
  $84 = ($83|0)==(0);
  if ($84) {
   $gindex$2 = 0;$result$0 = 0;
   label = 6;
   break;
  } else {
   $char_code$03 = $$char_code$0;$num_groups$02 = $83;$p$01 = $59;
  }
 }
 if ((label|0) == 6) {
  HEAP32[$pchar_code>>2] = $result$0;
  STACKTOP = sp;return ($gindex$2|0);
 }
 return 0|0;
}
function _tt_cmap8_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$07 = 0;
 var $count$111 = 0, $exitcond = 0, $last$015 = 0, $n$014 = 0, $or$cond = 0, $or$cond5 = 0, $p$016 = 0, $start$06 = 0, $start$110 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 8208|0);
 $1 = (($valid) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)>($2>>>0);
 if ($3) {
  _ft_validator_error($valid,8);
 }
 $4 = (($table) + 4|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 24;
 $8 = (($table) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 16;
 $12 = $11 | $7;
 $13 = (($table) + 6|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 << 8;
 $17 = $12 | $16;
 $18 = (($table) + 7|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = $17 | $20;
 $22 = HEAP32[$1>>2]|0;
 $23 = $22;
 $24 = $table;
 $25 = (($23) - ($24))|0;
 $26 = ($21>>>0)>($25>>>0);
 $27 = ($21>>>0)<(8208);
 $or$cond = $26 | $27;
 if ($or$cond) {
  _ft_validator_error($valid,8);
 }
 $28 = (($table) + 8204|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = $30 << 24;
 $32 = (($table) + 8205|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = $34 << 16;
 $36 = $35 | $31;
 $37 = (($table) + 8206|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = $38&255;
 $40 = $39 << 8;
 $41 = $36 | $40;
 $42 = (($table) + 8207|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43&255;
 $45 = $41 | $44;
 $46 = ($45*12)|0;
 $$sum = (($46) + 8208)|0;
 $47 = (($table) + ($$sum)|0);
 $48 = HEAP32[$1>>2]|0;
 $49 = ($47>>>0)>($48>>>0);
 if ($49) {
  _ft_validator_error($valid,8);
 }
 $50 = ($45|0)==(0);
 if ($50) {
  STACKTOP = sp;return 0;
 }
 $51 = (($valid) + 8|0);
 $52 = (($valid) + 20|0);
 $last$015 = 0;$n$014 = 0;$p$016 = $0;
 while(1) {
  $53 = HEAP8[$p$016>>0]|0;
  $54 = $53&255;
  $55 = $54 << 24;
  $56 = (($p$016) + 1|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57&255;
  $59 = $58 << 16;
  $60 = $59 | $55;
  $61 = (($p$016) + 2|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = $62&255;
  $64 = $63 << 8;
  $65 = $60 | $64;
  $66 = (($p$016) + 3|0);
  $67 = HEAP8[$66>>0]|0;
  $68 = $67&255;
  $69 = $65 | $68;
  $70 = (($p$016) + 4|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71&255;
  $73 = $72 << 24;
  $74 = (($p$016) + 5|0);
  $75 = HEAP8[$74>>0]|0;
  $76 = $75&255;
  $77 = $76 << 16;
  $78 = $77 | $73;
  $79 = (($p$016) + 6|0);
  $80 = HEAP8[$79>>0]|0;
  $81 = $80&255;
  $82 = $81 << 8;
  $83 = $78 | $82;
  $84 = (($p$016) + 7|0);
  $85 = HEAP8[$84>>0]|0;
  $86 = $85&255;
  $87 = $83 | $86;
  $88 = (($p$016) + 12|0);
  $89 = (($p$016) + 8|0);
  $90 = HEAP8[$89>>0]|0;
  $91 = $90&255;
  $92 = $91 << 24;
  $93 = (($p$016) + 9|0);
  $94 = HEAP8[$93>>0]|0;
  $95 = $94&255;
  $96 = $95 << 16;
  $97 = $96 | $92;
  $98 = (($p$016) + 10|0);
  $99 = HEAP8[$98>>0]|0;
  $100 = $99&255;
  $101 = $100 << 8;
  $102 = $97 | $101;
  $103 = (($p$016) + 11|0);
  $104 = HEAP8[$103>>0]|0;
  $105 = $104&255;
  $106 = $102 | $105;
  $107 = ($69>>>0)>($87>>>0);
  if ($107) {
   _ft_validator_error($valid,8);
  }
  $108 = ($n$014|0)==(0);
  $109 = ($69>>>0)>($last$015>>>0);
  $or$cond5 = $108 | $109;
  if (!($or$cond5)) {
   _ft_validator_error($valid,8);
  }
  $110 = HEAP32[$51>>2]|0;
  $111 = ($110|0)==(0);
  do {
   if (!($111)) {
    $112 = (($87) - ($69))|0;
    $113 = (($112) + ($106))|0;
    $114 = HEAP32[$52>>2]|0;
    $115 = ($113>>>0)<($114>>>0);
    if (!($115)) {
     _ft_validator_error($valid,16);
    }
    $116 = (($112) + 1)|0;
    $117 = ($60|0)==(0);
    if ($117) {
     $140 = ($78|0)==(0);
     if (!($140)) {
      _ft_validator_error($valid,8);
     }
     $141 = ($116|0)==(0);
     if ($141) {
      break;
     } else {
      $count$111 = $116;$start$110 = $69;
     }
     while(1) {
      $142 = $start$110 >>> 3;
      $143 = $142 & 8191;
      $$sum2 = (($143) + 12)|0;
      $144 = (($table) + ($$sum2)|0);
      $145 = HEAP8[$144>>0]|0;
      $146 = $145&255;
      $147 = $start$110 & 7;
      $148 = 128 >>> $147;
      $149 = $146 & $148;
      $150 = ($149|0)==(0);
      if (!($150)) {
       _ft_validator_error($valid,8);
      }
      $151 = (($count$111) + -1)|0;
      $152 = (($start$110) + 1)|0;
      $153 = ($151|0)==(0);
      if ($153) {
       break;
      } else {
       $count$111 = $151;$start$110 = $152;
      }
     }
    } else {
     $118 = ($116|0)==(0);
     if ($118) {
      break;
     } else {
      $count$07 = $116;$start$06 = $69;
     }
     while(1) {
      $119 = $start$06 >>> 16;
      $120 = $start$06 >>> 19;
      $$sum3 = (($120) + 12)|0;
      $121 = (($table) + ($$sum3)|0);
      $122 = HEAP8[$121>>0]|0;
      $123 = $122&255;
      $124 = $119 & 7;
      $125 = 128 >>> $124;
      $126 = $123 & $125;
      $127 = ($126|0)==(0);
      if ($127) {
       _ft_validator_error($valid,8);
      }
      $128 = $start$06 >>> 3;
      $129 = $128 & 8191;
      $$sum4 = (($129) + 12)|0;
      $130 = (($table) + ($$sum4)|0);
      $131 = HEAP8[$130>>0]|0;
      $132 = $131&255;
      $133 = $start$06 & 7;
      $134 = 128 >>> $133;
      $135 = $132 & $134;
      $136 = ($135|0)==(0);
      if ($136) {
       _ft_validator_error($valid,8);
      }
      $137 = (($count$07) + -1)|0;
      $138 = (($start$06) + 1)|0;
      $139 = ($137|0)==(0);
      if ($139) {
       break;
      } else {
       $count$07 = $137;$start$06 = $138;
      }
     }
    }
   }
  } while(0);
  $154 = (($n$014) + 1)|0;
  $exitcond = ($154|0)==($45|0);
  if ($exitcond) {
   break;
  } else {
   $last$015 = $87;$n$014 = $154;$p$016 = $88;
  }
 }
 STACKTOP = sp;return 0;
}
function _tt_cmap8_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = (($cmap_info) + 4|0);
 HEAP32[$3>>2] = 8;
 $4 = HEAP8[$2>>0]|0;
 $5 = $4&255;
 $6 = $5 << 24;
 $7 = (($1) + 9|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 << 16;
 $11 = $10 | $6;
 $12 = (($1) + 10|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 << 8;
 $16 = $11 | $15;
 $17 = (($1) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = $16 | $19;
 HEAP32[$cmap_info>>2] = $20;
 STACKTOP = sp;return 0;
}
function _tt_cmap10_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = (($1) + 13|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = (($1) + 14|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = (($1) + 15|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = (($1) + 16|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 $23 = $22 << 24;
 $24 = (($1) + 17|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25&255;
 $27 = $26 << 16;
 $28 = $27 | $23;
 $29 = (($1) + 18|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = $30&255;
 $32 = $31 << 8;
 $33 = $28 | $32;
 $34 = (($1) + 19|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = $33 | $36;
 $38 = (($char_code) - ($19))|0;
 $39 = ($38>>>0)<($37>>>0);
 if (!($39)) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $40 = $38 << 1;
 $$sum = (($40) + 20)|0;
 $41 = (($1) + ($$sum)|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = $42&255;
 $44 = $43 << 8;
 $$sum1 = (($40) + 21)|0;
 $45 = (($1) + ($$sum1)|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46&255;
 $48 = $44 | $47;
 $result$0 = $48;
 STACKTOP = sp;return ($result$0|0);
}
function _tt_cmap10_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var $$ = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $char_code$1$lcssa = 0;
 var $char_code$12 = 0, $gindex$1 = 0, $idx$03 = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$pchar_code>>2]|0;
 $3 = (($2) + 1)|0;
 $4 = (($1) + 12|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 24;
 $8 = (($1) + 13|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 16;
 $12 = $11 | $7;
 $13 = (($1) + 14|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 << 8;
 $17 = $12 | $16;
 $18 = (($1) + 15|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = $17 | $20;
 $22 = (($1) + 16|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 << 24;
 $26 = (($1) + 17|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 $29 = $28 << 16;
 $30 = $29 | $25;
 $31 = (($1) + 18|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = $33 << 8;
 $35 = $30 | $34;
 $36 = (($1) + 19|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37&255;
 $39 = $35 | $38;
 $40 = ($3>>>0)<($21>>>0);
 $$ = $40 ? $21 : $3;
 $41 = (($$) - ($21))|0;
 $42 = ($41>>>0)<($39>>>0);
 if (!($42)) {
  $char_code$1$lcssa = $$;$gindex$1 = 0;
  HEAP32[$pchar_code>>2] = $char_code$1$lcssa;
  STACKTOP = sp;return ($gindex$1|0);
 }
 $43 = $41 << 1;
 $$sum = (($43) + 20)|0;
 $44 = (($1) + ($$sum)|0);
 $char_code$12 = $$;$idx$03 = $41;$p$01 = $44;
 while(1) {
  $45 = HEAP8[$p$01>>0]|0;
  $46 = $45&255;
  $47 = $46 << 8;
  $48 = (($p$01) + 1|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49&255;
  $51 = $47 | $50;
  $52 = ($51|0)==(0);
  if (!($52)) {
   $char_code$1$lcssa = $char_code$12;$gindex$1 = $51;
   label = 5;
   break;
  }
  $53 = (($p$01) + 2|0);
  $54 = (($char_code$12) + 1)|0;
  $55 = (($idx$03) + 1)|0;
  $56 = ($55>>>0)<($39>>>0);
  if ($56) {
   $char_code$12 = $54;$idx$03 = $55;$p$01 = $53;
  } else {
   $char_code$1$lcssa = $54;$gindex$1 = 0;
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  HEAP32[$pchar_code>>2] = $char_code$1$lcssa;
  STACKTOP = sp;return ($gindex$1|0);
 }
 return 0|0;
}
function _tt_cmap10_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $or$cond = 0, $p$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 20|0);
 $1 = (($valid) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)>($2>>>0);
 if ($3) {
  _ft_validator_error($valid,8);
 }
 $4 = (($table) + 4|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 24;
 $8 = (($table) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 16;
 $12 = $11 | $7;
 $13 = (($table) + 6|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 << 8;
 $17 = $12 | $16;
 $18 = (($table) + 7|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = $17 | $20;
 $22 = (($table) + 16|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 << 24;
 $26 = (($table) + 17|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 $29 = $28 << 16;
 $30 = $29 | $25;
 $31 = (($table) + 18|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = $33 << 8;
 $35 = $30 | $34;
 $36 = (($table) + 19|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37&255;
 $39 = $35 | $38;
 $40 = HEAP32[$1>>2]|0;
 $41 = $40;
 $42 = $table;
 $43 = (($41) - ($42))|0;
 $44 = ($21>>>0)>($43>>>0);
 if ($44) {
  label = 5;
 } else {
  $45 = $39 << 1;
  $46 = (($45) + 20)|0;
  $47 = ($21>>>0)<($46>>>0);
  if ($47) {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  _ft_validator_error($valid,8);
 }
 $48 = (($valid) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)==(0);
 $51 = ($39|0)==(0);
 $or$cond = $50 | $51;
 if ($or$cond) {
  STACKTOP = sp;return 0;
 }
 $52 = (($valid) + 20|0);
 $count$01 = $39;$p$02 = $0;
 while(1) {
  $53 = (($p$02) + 2|0);
  $54 = HEAP8[$p$02>>0]|0;
  $55 = $54&255;
  $56 = $55 << 8;
  $57 = (($p$02) + 1|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = $58&255;
  $60 = $56 | $59;
  $61 = HEAP32[$52>>2]|0;
  $62 = ($60>>>0)<($61>>>0);
  if (!($62)) {
   _ft_validator_error($valid,16);
  }
  $63 = (($count$01) + -1)|0;
  $64 = ($63|0)==(0);
  if ($64) {
   break;
  } else {
   $count$01 = $63;$p$02 = $53;
  }
 }
 STACKTOP = sp;return 0;
}
function _tt_cmap10_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = (($cmap_info) + 4|0);
 HEAP32[$3>>2] = 10;
 $4 = HEAP8[$2>>0]|0;
 $5 = $4&255;
 $6 = $5 << 24;
 $7 = (($1) + 9|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 << 16;
 $11 = $10 | $6;
 $12 = (($1) + 10|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 << 8;
 $16 = $11 | $15;
 $17 = (($1) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = $16 | $19;
 HEAP32[$cmap_info>>2] = $20;
 STACKTOP = sp;return 0;
}
function _tt_cmap12_init($cmap,$table) {
 $cmap = $cmap|0;
 $table = $table|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 HEAP32[$0>>2] = $table;
 $1 = (($table) + 12|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 24;
 $5 = (($table) + 13|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 << 16;
 $9 = $8 | $4;
 $10 = (($table) + 14|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 8;
 $14 = $9 | $13;
 $15 = (($table) + 15|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $14 | $17;
 $19 = (($cmap) + 40|0);
 HEAP32[$19>>2] = $18;
 $20 = (($cmap) + 24|0);
 HEAP8[$20>>0] = 0;
 STACKTOP = sp;return 0;
}
function _tt_cmap12_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $char_code;
 $1 = (_tt_cmap12_char_map_binary($cmap,$0,0)|0);
 STACKTOP = sp;return ($1|0);
}
function _tt_cmap12_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 do {
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (($cmap) + 24|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if (!($5)) {
    $6 = HEAP32[$pchar_code>>2]|0;
    $7 = ($1|0)==($6|0);
    if ($7) {
     _tt_cmap12_next($cmap);
     $8 = HEAP8[$3>>0]|0;
     $9 = ($8<<24>>24)==(0);
     if ($9) {
      $$0 = 0;
      break;
     }
     $10 = (($cmap) + 32|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==(0);
     if ($12) {
      $$0 = 0;
      break;
     }
     $13 = HEAP32[$0>>2]|0;
     HEAP32[$pchar_code>>2] = $13;
     $$0 = $11;
     break;
    }
   }
   $14 = (_tt_cmap12_char_map_binary($cmap,$pchar_code,1)|0);
   $$0 = $14;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap12_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $last$03 = 0, $n$01 = 0, $or$cond = 0, $p$02 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 16|0);
 $1 = (($valid) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)>($2>>>0);
 if ($3) {
  _ft_validator_error($valid,8);
 }
 $4 = (($table) + 4|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 24;
 $8 = (($table) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 16;
 $12 = $11 | $7;
 $13 = (($table) + 6|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 << 8;
 $17 = $12 | $16;
 $18 = (($table) + 7|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = $17 | $20;
 $22 = (($table) + 12|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 << 24;
 $26 = (($table) + 13|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 $29 = $28 << 16;
 $30 = $29 | $25;
 $31 = (($table) + 14|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = $33 << 8;
 $35 = $30 | $34;
 $36 = (($table) + 15|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37&255;
 $39 = $35 | $38;
 $40 = HEAP32[$1>>2]|0;
 $41 = $40;
 $42 = $table;
 $43 = (($41) - ($42))|0;
 $44 = ($21>>>0)>($43>>>0);
 if ($44) {
  label = 5;
 } else {
  $45 = ($39*12)|0;
  $46 = (($45) + 16)|0;
  $47 = ($21>>>0)<($46>>>0);
  if ($47) {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  _ft_validator_error($valid,8);
 }
 $48 = ($39|0)==(0);
 if ($48) {
  STACKTOP = sp;return 0;
 }
 $49 = (($valid) + 8|0);
 $50 = (($valid) + 20|0);
 $last$03 = 0;$n$01 = 0;$p$02 = $0;
 while(1) {
  $51 = HEAP8[$p$02>>0]|0;
  $52 = $51&255;
  $53 = $52 << 24;
  $54 = (($p$02) + 1|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = $56 << 16;
  $58 = $57 | $53;
  $59 = (($p$02) + 2|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = $60&255;
  $62 = $61 << 8;
  $63 = $58 | $62;
  $64 = (($p$02) + 3|0);
  $65 = HEAP8[$64>>0]|0;
  $66 = $65&255;
  $67 = $63 | $66;
  $68 = (($p$02) + 4|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = $69&255;
  $71 = $70 << 24;
  $72 = (($p$02) + 5|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = $73&255;
  $75 = $74 << 16;
  $76 = $75 | $71;
  $77 = (($p$02) + 6|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = $78&255;
  $80 = $79 << 8;
  $81 = $76 | $80;
  $82 = (($p$02) + 7|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = $83&255;
  $85 = $81 | $84;
  $86 = (($p$02) + 12|0);
  $87 = (($p$02) + 8|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = $88&255;
  $90 = $89 << 24;
  $91 = (($p$02) + 9|0);
  $92 = HEAP8[$91>>0]|0;
  $93 = $92&255;
  $94 = $93 << 16;
  $95 = $94 | $90;
  $96 = (($p$02) + 10|0);
  $97 = HEAP8[$96>>0]|0;
  $98 = $97&255;
  $99 = $98 << 8;
  $100 = $95 | $99;
  $101 = (($p$02) + 11|0);
  $102 = HEAP8[$101>>0]|0;
  $103 = $102&255;
  $104 = $100 | $103;
  $105 = ($67>>>0)>($85>>>0);
  if ($105) {
   _ft_validator_error($valid,8);
  }
  $106 = ($n$01|0)==(0);
  $107 = ($67>>>0)>($last$03>>>0);
  $or$cond = $106 | $107;
  if (!($or$cond)) {
   _ft_validator_error($valid,8);
  }
  $108 = HEAP32[$49>>2]|0;
  $109 = ($108|0)==(0);
  if (!($109)) {
   $110 = (($85) - ($67))|0;
   $111 = (($110) + ($104))|0;
   $112 = HEAP32[$50>>2]|0;
   $113 = ($111>>>0)<($112>>>0);
   if (!($113)) {
    _ft_validator_error($valid,16);
   }
  }
  $114 = (($n$01) + 1)|0;
  $exitcond = ($114|0)==($39|0);
  if ($exitcond) {
   break;
  } else {
   $last$03 = $85;$n$01 = $114;$p$02 = $86;
  }
 }
 STACKTOP = sp;return 0;
}
function _tt_cmap12_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = (($cmap_info) + 4|0);
 HEAP32[$3>>2] = 12;
 $4 = HEAP8[$2>>0]|0;
 $5 = $4&255;
 $6 = $5 << 24;
 $7 = (($1) + 9|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 << 16;
 $11 = $10 | $6;
 $12 = (($1) + 10|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 << 8;
 $16 = $11 | $15;
 $17 = (($1) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = $16 | $19;
 HEAP32[$cmap_info>>2] = $20;
 STACKTOP = sp;return 0;
}
function _tt_cmap13_init($cmap,$table) {
 $cmap = $cmap|0;
 $table = $table|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 HEAP32[$0>>2] = $table;
 $1 = (($table) + 12|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 24;
 $5 = (($table) + 13|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 << 16;
 $9 = $8 | $4;
 $10 = (($table) + 14|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 8;
 $14 = $9 | $13;
 $15 = (($table) + 15|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $14 | $17;
 $19 = (($cmap) + 40|0);
 HEAP32[$19>>2] = $18;
 $20 = (($cmap) + 24|0);
 HEAP8[$20>>0] = 0;
 STACKTOP = sp;return 0;
}
function _tt_cmap13_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $char_code;
 $1 = (_tt_cmap13_char_map_binary($cmap,$0,0)|0);
 STACKTOP = sp;return ($1|0);
}
function _tt_cmap13_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 do {
  if ($2) {
   $$0 = 0;
  } else {
   $3 = (($cmap) + 24|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if (!($5)) {
    $6 = HEAP32[$pchar_code>>2]|0;
    $7 = ($1|0)==($6|0);
    if ($7) {
     _tt_cmap13_next($cmap);
     $8 = HEAP8[$3>>0]|0;
     $9 = ($8<<24>>24)==(0);
     if ($9) {
      $$0 = 0;
      break;
     }
     $10 = (($cmap) + 32|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==(0);
     if ($12) {
      $$0 = 0;
      break;
     }
     $13 = HEAP32[$0>>2]|0;
     HEAP32[$pchar_code>>2] = $13;
     $$0 = $11;
     break;
    }
   }
   $14 = (_tt_cmap13_char_map_binary($cmap,$pchar_code,1)|0);
   $$0 = $14;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap13_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $last$03 = 0, $n$01 = 0, $or$cond = 0, $p$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 16|0);
 $1 = (($valid) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0>>>0)>($2>>>0);
 if ($3) {
  _ft_validator_error($valid,8);
 }
 $4 = (($table) + 4|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 24;
 $8 = (($table) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 16;
 $12 = $11 | $7;
 $13 = (($table) + 6|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 << 8;
 $17 = $12 | $16;
 $18 = (($table) + 7|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = $17 | $20;
 $22 = (($table) + 12|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 << 24;
 $26 = (($table) + 13|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 $29 = $28 << 16;
 $30 = $29 | $25;
 $31 = (($table) + 14|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = $33 << 8;
 $35 = $30 | $34;
 $36 = (($table) + 15|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37&255;
 $39 = $35 | $38;
 $40 = HEAP32[$1>>2]|0;
 $41 = $40;
 $42 = $table;
 $43 = (($41) - ($42))|0;
 $44 = ($21>>>0)>($43>>>0);
 if ($44) {
  label = 5;
 } else {
  $45 = ($39*12)|0;
  $46 = (($45) + 16)|0;
  $47 = ($21>>>0)<($46>>>0);
  if ($47) {
   label = 5;
  }
 }
 if ((label|0) == 5) {
  _ft_validator_error($valid,8);
 }
 $48 = ($39|0)==(0);
 if ($48) {
  STACKTOP = sp;return 0;
 }
 $49 = (($valid) + 8|0);
 $50 = (($valid) + 20|0);
 $last$03 = 0;$n$01 = 0;$p$02 = $0;
 while(1) {
  $51 = HEAP8[$p$02>>0]|0;
  $52 = $51&255;
  $53 = $52 << 24;
  $54 = (($p$02) + 1|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = $56 << 16;
  $58 = $57 | $53;
  $59 = (($p$02) + 2|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = $60&255;
  $62 = $61 << 8;
  $63 = $58 | $62;
  $64 = (($p$02) + 3|0);
  $65 = HEAP8[$64>>0]|0;
  $66 = $65&255;
  $67 = $63 | $66;
  $68 = (($p$02) + 4|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = $69&255;
  $71 = $70 << 24;
  $72 = (($p$02) + 5|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = $73&255;
  $75 = $74 << 16;
  $76 = $75 | $71;
  $77 = (($p$02) + 6|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = $78&255;
  $80 = $79 << 8;
  $81 = $76 | $80;
  $82 = (($p$02) + 7|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = $83&255;
  $85 = $81 | $84;
  $86 = (($p$02) + 12|0);
  $87 = (($p$02) + 8|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = $88&255;
  $90 = $89 << 24;
  $91 = (($p$02) + 9|0);
  $92 = HEAP8[$91>>0]|0;
  $93 = $92&255;
  $94 = $93 << 16;
  $95 = $94 | $90;
  $96 = (($p$02) + 10|0);
  $97 = HEAP8[$96>>0]|0;
  $98 = $97&255;
  $99 = $98 << 8;
  $100 = $95 | $99;
  $101 = (($p$02) + 11|0);
  $102 = HEAP8[$101>>0]|0;
  $103 = $102&255;
  $104 = $100 | $103;
  $105 = ($67>>>0)>($85>>>0);
  if ($105) {
   _ft_validator_error($valid,8);
  }
  $106 = ($n$01|0)==(0);
  $107 = ($67>>>0)>($last$03>>>0);
  $or$cond = $106 | $107;
  if (!($or$cond)) {
   _ft_validator_error($valid,8);
  }
  $108 = HEAP32[$49>>2]|0;
  $109 = ($108|0)==(0);
  if (!($109)) {
   $110 = HEAP32[$50>>2]|0;
   $111 = ($104>>>0)<($110>>>0);
   if (!($111)) {
    _ft_validator_error($valid,16);
   }
  }
  $112 = (($n$01) + 1)|0;
  $exitcond = ($112|0)==($39|0);
  if ($exitcond) {
   break;
  } else {
   $last$03 = $85;$n$01 = $112;$p$02 = $86;
  }
 }
 STACKTOP = sp;return 0;
}
function _tt_cmap13_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = (($cmap_info) + 4|0);
 HEAP32[$3>>2] = 13;
 $4 = HEAP8[$2>>0]|0;
 $5 = $4&255;
 $6 = $5 << 24;
 $7 = (($1) + 9|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 << 16;
 $11 = $10 | $6;
 $12 = (($1) + 10|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 << 8;
 $16 = $11 | $15;
 $17 = (($1) + 11|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = $16 | $19;
 HEAP32[$cmap_info>>2] = $20;
 STACKTOP = sp;return 0;
}
function _tt_cmap14_init($cmap,$table) {
 $cmap = $cmap|0;
 $table = $table|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 HEAP32[$0>>2] = $table;
 $1 = (($table) + 6|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = $3 << 24;
 $5 = (($table) + 7|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 << 16;
 $9 = $8 | $4;
 $10 = (($table) + 8|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 8;
 $14 = $9 | $13;
 $15 = (($table) + 9|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $14 | $17;
 $19 = (($cmap) + 24|0);
 HEAP32[$19>>2] = $18;
 $20 = (($cmap) + 28|0);
 HEAP32[$20>>2] = 0;
 $21 = (($cmap) + 32|0);
 HEAP32[$21>>2] = 0;
 STACKTOP = sp;return 0;
}
function _tt_cmap14_done($cmap) {
 $cmap = $cmap|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cmap) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = ($1|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($cmap) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($1,$5);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_cmap14_char_index($cmap,$char_code) {
 $cmap = $cmap|0;
 $char_code = $char_code|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function _tt_cmap14_char_next($cmap,$pchar_code) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$pchar_code>>2] = 0;
 STACKTOP = sp;return 0;
}
function _tt_cmap14_char_var_index($cmap,$ucmap,$charcode,$variantSelector) {
 $cmap = $cmap|0;
 $ucmap = $ucmap|0;
 $charcode = $charcode|0;
 $variantSelector = $variantSelector|0;
 var $$0 = 0, $$sum = 0, $$sum1$i11 = 0, $$sum1$i3 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2$i4 = 0, $$sum2$i8 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum26 = 0, $$sum27 = 0;
 var $$sum28 = 0, $$sum29 = 0, $$sum3$i5 = 0, $$sum3$i9 = 0, $$sum30 = 0, $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum38 = 0, $$sum4$i10 = 0, $$sum4$i6 = 0, $$sum5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $max$0$i = 0, $max$0$ph$i = 0, $max$0$ph14$i = 0, $max$0$ph8$i = 0, $min$0$ph$i = 0, $min$0$ph15$i = 0, $min$0$ph9$i = 0, $min$013$i = 0;
 var $min$06$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = (($1) + 7|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = (($1) + 8|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = (($1) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ($19|0)==(0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $max$0$ph8$i = $19;$min$0$ph9$i = 0;
 }
 L3: while(1) {
  $min$06$i = $min$0$ph9$i;
  while(1) {
   $25 = (($min$06$i) + ($max$0$ph8$i))|0;
   $22 = $25 >>> 1;
   $26 = ($22*11)|0;
   $$sum = (($26) + 10)|0;
   $27 = (($1) + ($$sum)|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = $28&255;
   $30 = $29 << 16;
   $$sum14 = (($26) + 11)|0;
   $31 = (($1) + ($$sum14)|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32&255;
   $34 = $33 << 8;
   $35 = $34 | $30;
   $$sum15 = (($26) + 12)|0;
   $36 = (($1) + ($$sum15)|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $39 = $35 | $38;
   $40 = ($39>>>0)>($variantSelector>>>0);
   if ($40) {
    break;
   }
   $41 = ($39>>>0)<($variantSelector>>>0);
   $24 = (($22) + 1)|0;
   if (!($41)) {
    label = 7;
    break L3;
   }
   $23 = ($24>>>0)<($max$0$ph8$i>>>0);
   if ($23) {
    $min$06$i = $24;
   } else {
    $$0 = 0;
    label = 24;
    break L3;
   }
  }
  $21 = ($min$06$i>>>0)<($22>>>0);
  if ($21) {
   $max$0$ph8$i = $22;$min$0$ph9$i = $min$06$i;
  } else {
   $$0 = 0;
   label = 24;
   break;
  }
 }
 if ((label|0) == 7) {
  $$sum16 = (($26) + 13)|0;
  $42 = (($1) + ($$sum16)|0);
  $43 = ($42|0)==(0|0);
  if ($43) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $$sum17 = (($26) + 17)|0;
  $44 = (($1) + ($$sum17)|0);
  $45 = HEAP8[$42>>0]|0;
  $46 = $45&255;
  $47 = $46 << 24;
  $$sum18 = (($26) + 14)|0;
  $48 = (($1) + ($$sum18)|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49&255;
  $51 = $50 << 16;
  $52 = $51 | $47;
  $$sum19 = (($26) + 15)|0;
  $53 = (($1) + ($$sum19)|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = $54&255;
  $56 = $55 << 8;
  $57 = $52 | $56;
  $$sum20 = (($26) + 16)|0;
  $58 = (($1) + ($$sum20)|0);
  $59 = HEAP8[$58>>0]|0;
  $60 = $59&255;
  $61 = $57 | $60;
  $62 = HEAP8[$44>>0]|0;
  $63 = $62&255;
  $64 = $63 << 24;
  $$sum21 = (($26) + 18)|0;
  $65 = (($1) + ($$sum21)|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = $67 << 16;
  $69 = $68 | $64;
  $$sum22 = (($26) + 19)|0;
  $70 = (($1) + ($$sum22)|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71&255;
  $73 = $72 << 8;
  $74 = $69 | $73;
  $$sum23 = (($26) + 20)|0;
  $75 = (($1) + ($$sum23)|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $76&255;
  $78 = $74 | $77;
  $79 = ($61|0)==(0);
  L17: do {
   if (!($79)) {
    $80 = (($1) + ($61)|0);
    $81 = HEAP8[$80>>0]|0;
    $82 = $81&255;
    $83 = $82 << 24;
    $$sum24 = (($61) + 1)|0;
    $84 = (($1) + ($$sum24)|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = $86 << 16;
    $88 = $87 | $83;
    $$sum25 = (($61) + 2)|0;
    $89 = (($1) + ($$sum25)|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = $90&255;
    $92 = $91 << 8;
    $93 = $88 | $92;
    $$sum26 = (($61) + 3)|0;
    $94 = (($1) + ($$sum26)|0);
    $95 = HEAP8[$94>>0]|0;
    $96 = $95&255;
    $97 = $93 | $96;
    $$sum2$i8 = (($61) + 4)|0;
    $$sum3$i9 = (($61) + 5)|0;
    $$sum4$i10 = (($61) + 6)|0;
    $$sum1$i11 = (($61) + 7)|0;
    $max$0$ph$i = $97;$min$0$ph$i = 0;
    while(1) {
     $max$0$i = $max$0$ph$i;
     while(1) {
      $98 = ($min$0$ph$i>>>0)<($max$0$i>>>0);
      if (!($98)) {
       break L17;
      }
      $99 = (($max$0$i) + ($min$0$ph$i))|0;
      $100 = $99 >>> 1;
      $101 = $100 << 2;
      $$sum35 = (($$sum2$i8) + ($101))|0;
      $102 = (($1) + ($$sum35)|0);
      $103 = HEAP8[$102>>0]|0;
      $104 = $103&255;
      $105 = $104 << 16;
      $$sum36 = (($$sum3$i9) + ($101))|0;
      $106 = (($1) + ($$sum36)|0);
      $107 = HEAP8[$106>>0]|0;
      $108 = $107&255;
      $109 = $108 << 8;
      $110 = $109 | $105;
      $$sum37 = (($$sum4$i10) + ($101))|0;
      $111 = (($1) + ($$sum37)|0);
      $112 = HEAP8[$111>>0]|0;
      $113 = $112&255;
      $114 = $110 | $113;
      $115 = ($114>>>0)>($charcode>>>0);
      if ($115) {
       $max$0$i = $100;
      } else {
       break;
      }
     }
     $$sum38 = (($$sum1$i11) + ($101))|0;
     $116 = (($1) + ($$sum38)|0);
     $117 = HEAP8[$116>>0]|0;
     $118 = $117&255;
     $119 = (($118) + ($114))|0;
     $120 = ($119>>>0)<($charcode>>>0);
     $121 = (($100) + 1)|0;
     if ($120) {
      $max$0$ph$i = $max$0$i;$min$0$ph$i = $121;
     } else {
      break;
     }
    }
    $122 = (($ucmap) + 12|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = (($123) + 12|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = (FUNCTION_TABLE_iii[$125 & 4095]($ucmap,$charcode)|0);
    $$0 = $126;
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $127 = ($78|0)==(0);
  if ($127) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $128 = (($1) + ($78)|0);
  $129 = HEAP8[$128>>0]|0;
  $130 = $129&255;
  $131 = $130 << 24;
  $$sum27 = (($78) + 1)|0;
  $132 = (($1) + ($$sum27)|0);
  $133 = HEAP8[$132>>0]|0;
  $134 = $133&255;
  $135 = $134 << 16;
  $136 = $135 | $131;
  $$sum28 = (($78) + 2)|0;
  $137 = (($1) + ($$sum28)|0);
  $138 = HEAP8[$137>>0]|0;
  $139 = $138&255;
  $140 = $139 << 8;
  $141 = $136 | $140;
  $$sum29 = (($78) + 3)|0;
  $142 = (($1) + ($$sum29)|0);
  $143 = HEAP8[$142>>0]|0;
  $144 = $143&255;
  $145 = $141 | $144;
  $146 = ($145|0)==(0);
  if ($146) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $$sum2$i4 = (($78) + 4)|0;
  $$sum3$i5 = (($78) + 5)|0;
  $$sum4$i6 = (($78) + 6)|0;
  $max$0$ph14$i = $145;$min$0$ph15$i = 0;
  L34: while(1) {
   $min$013$i = $min$0$ph15$i;
   while(1) {
    $151 = (($min$013$i) + ($max$0$ph14$i))|0;
    $148 = $151 >>> 1;
    $152 = ($148*5)|0;
    $$sum30 = (($$sum2$i4) + ($152))|0;
    $153 = (($1) + ($$sum30)|0);
    $154 = HEAP8[$153>>0]|0;
    $155 = $154&255;
    $156 = $155 << 16;
    $$sum31 = (($$sum3$i5) + ($152))|0;
    $157 = (($1) + ($$sum31)|0);
    $158 = HEAP8[$157>>0]|0;
    $159 = $158&255;
    $160 = $159 << 8;
    $161 = $160 | $156;
    $$sum32 = (($$sum4$i6) + ($152))|0;
    $162 = (($1) + ($$sum32)|0);
    $163 = HEAP8[$162>>0]|0;
    $164 = $163&255;
    $165 = $161 | $164;
    $166 = ($165>>>0)>($charcode>>>0);
    if ($166) {
     break;
    }
    $167 = ($165>>>0)<($charcode>>>0);
    $150 = (($148) + 1)|0;
    if (!($167)) {
     label = 23;
     break L34;
    }
    $149 = ($150>>>0)<($max$0$ph14$i>>>0);
    if ($149) {
     $min$013$i = $150;
    } else {
     $$0 = 0;
     label = 24;
     break L34;
    }
   }
   $147 = ($min$013$i>>>0)<($148>>>0);
   if ($147) {
    $max$0$ph14$i = $148;$min$0$ph15$i = $min$013$i;
   } else {
    $$0 = 0;
    label = 24;
    break;
   }
  }
  if ((label|0) == 23) {
   $$sum1$i3 = (($78) + 7)|0;
   $$sum33 = (($$sum1$i3) + ($152))|0;
   $168 = (($1) + ($$sum33)|0);
   $169 = HEAP8[$168>>0]|0;
   $170 = $169&255;
   $171 = $170 << 8;
   $$sum5$i = (($78) + 8)|0;
   $$sum34 = (($$sum5$i) + ($152))|0;
   $172 = (($1) + ($$sum34)|0);
   $173 = HEAP8[$172>>0]|0;
   $174 = $173&255;
   $175 = $171 | $174;
   $$0 = $175;
   STACKTOP = sp;return ($$0|0);
  }
  else if ((label|0) == 24) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 24) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _tt_cmap14_char_var_isdefault($cmap,$charcode,$variantSelector) {
 $cmap = $cmap|0;
 $charcode = $charcode|0;
 $variantSelector = $variantSelector|0;
 var $$0 = 0, $$sum = 0, $$sum1$i11 = 0, $$sum1$i3 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2$i4 = 0, $$sum2$i8 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum26 = 0, $$sum27 = 0;
 var $$sum28 = 0, $$sum29 = 0, $$sum3$i5 = 0, $$sum3$i9 = 0, $$sum30 = 0, $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum38 = 0, $$sum4$i10 = 0, $$sum4$i6 = 0, $$sum5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $max$0$i = 0, $max$0$ph$i = 0, $max$0$ph14$i = 0, $max$0$ph8$i = 0, $min$0$ph$i = 0, $min$0$ph15$i = 0, $min$0$ph9$i = 0, $min$013$i = 0, $min$06$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = (($1) + 7|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = (($1) + 8|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = (($1) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ($19|0)==(0);
 if ($20) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $max$0$ph8$i = $19;$min$0$ph9$i = 0;
 }
 L3: while(1) {
  $min$06$i = $min$0$ph9$i;
  while(1) {
   $25 = (($min$06$i) + ($max$0$ph8$i))|0;
   $22 = $25 >>> 1;
   $26 = ($22*11)|0;
   $$sum = (($26) + 10)|0;
   $27 = (($1) + ($$sum)|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = $28&255;
   $30 = $29 << 16;
   $$sum14 = (($26) + 11)|0;
   $31 = (($1) + ($$sum14)|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32&255;
   $34 = $33 << 8;
   $35 = $34 | $30;
   $$sum15 = (($26) + 12)|0;
   $36 = (($1) + ($$sum15)|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $39 = $35 | $38;
   $40 = ($39>>>0)>($variantSelector>>>0);
   if ($40) {
    break;
   }
   $41 = ($39>>>0)<($variantSelector>>>0);
   $24 = (($22) + 1)|0;
   if (!($41)) {
    label = 7;
    break L3;
   }
   $23 = ($24>>>0)<($max$0$ph8$i>>>0);
   if ($23) {
    $min$06$i = $24;
   } else {
    $$0 = -1;
    label = 24;
    break L3;
   }
  }
  $21 = ($min$06$i>>>0)<($22>>>0);
  if ($21) {
   $max$0$ph8$i = $22;$min$0$ph9$i = $min$06$i;
  } else {
   $$0 = -1;
   label = 24;
   break;
  }
 }
 if ((label|0) == 7) {
  $$sum16 = (($26) + 13)|0;
  $42 = (($1) + ($$sum16)|0);
  $43 = ($42|0)==(0|0);
  if ($43) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $44 = HEAP8[$42>>0]|0;
  $45 = $44&255;
  $46 = $45 << 24;
  $$sum17 = (($26) + 14)|0;
  $47 = (($1) + ($$sum17)|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = $48&255;
  $50 = $49 << 16;
  $51 = $50 | $46;
  $$sum18 = (($26) + 15)|0;
  $52 = (($1) + ($$sum18)|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53&255;
  $55 = $54 << 8;
  $56 = $51 | $55;
  $$sum19 = (($26) + 16)|0;
  $57 = (($1) + ($$sum19)|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = $58&255;
  $60 = $56 | $59;
  $$sum20 = (($26) + 17)|0;
  $61 = (($1) + ($$sum20)|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = $62&255;
  $64 = $63 << 24;
  $$sum21 = (($26) + 18)|0;
  $65 = (($1) + ($$sum21)|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = $67 << 16;
  $69 = $68 | $64;
  $$sum22 = (($26) + 19)|0;
  $70 = (($1) + ($$sum22)|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71&255;
  $73 = $72 << 8;
  $74 = $69 | $73;
  $$sum23 = (($26) + 20)|0;
  $75 = (($1) + ($$sum23)|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $76&255;
  $78 = $74 | $77;
  $79 = ($60|0)==(0);
  L16: do {
   if (!($79)) {
    $80 = (($1) + ($60)|0);
    $81 = HEAP8[$80>>0]|0;
    $82 = $81&255;
    $83 = $82 << 24;
    $$sum24 = (($60) + 1)|0;
    $84 = (($1) + ($$sum24)|0);
    $85 = HEAP8[$84>>0]|0;
    $86 = $85&255;
    $87 = $86 << 16;
    $88 = $87 | $83;
    $$sum25 = (($60) + 2)|0;
    $89 = (($1) + ($$sum25)|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = $90&255;
    $92 = $91 << 8;
    $93 = $88 | $92;
    $$sum26 = (($60) + 3)|0;
    $94 = (($1) + ($$sum26)|0);
    $95 = HEAP8[$94>>0]|0;
    $96 = $95&255;
    $97 = $93 | $96;
    $$sum2$i8 = (($60) + 4)|0;
    $$sum3$i9 = (($60) + 5)|0;
    $$sum4$i10 = (($60) + 6)|0;
    $$sum1$i11 = (($60) + 7)|0;
    $max$0$ph$i = $97;$min$0$ph$i = 0;
    while(1) {
     $max$0$i = $max$0$ph$i;
     while(1) {
      $98 = ($min$0$ph$i>>>0)<($max$0$i>>>0);
      if (!($98)) {
       break L16;
      }
      $99 = (($max$0$i) + ($min$0$ph$i))|0;
      $100 = $99 >>> 1;
      $101 = $100 << 2;
      $$sum35 = (($$sum2$i8) + ($101))|0;
      $102 = (($1) + ($$sum35)|0);
      $103 = HEAP8[$102>>0]|0;
      $104 = $103&255;
      $105 = $104 << 16;
      $$sum36 = (($$sum3$i9) + ($101))|0;
      $106 = (($1) + ($$sum36)|0);
      $107 = HEAP8[$106>>0]|0;
      $108 = $107&255;
      $109 = $108 << 8;
      $110 = $109 | $105;
      $$sum37 = (($$sum4$i10) + ($101))|0;
      $111 = (($1) + ($$sum37)|0);
      $112 = HEAP8[$111>>0]|0;
      $113 = $112&255;
      $114 = $110 | $113;
      $115 = ($114>>>0)>($charcode>>>0);
      if ($115) {
       $max$0$i = $100;
      } else {
       break;
      }
     }
     $$sum38 = (($$sum1$i11) + ($101))|0;
     $116 = (($1) + ($$sum38)|0);
     $117 = HEAP8[$116>>0]|0;
     $118 = $117&255;
     $119 = (($118) + ($114))|0;
     $120 = ($119>>>0)<($charcode>>>0);
     $121 = (($100) + 1)|0;
     if ($120) {
      $max$0$ph$i = $max$0$i;$min$0$ph$i = $121;
     } else {
      $$0 = 1;
      break;
     }
    }
    STACKTOP = sp;return ($$0|0);
   }
  } while(0);
  $122 = ($78|0)==(0);
  L26: do {
   if (!($122)) {
    $123 = (($1) + ($78)|0);
    $124 = HEAP8[$123>>0]|0;
    $125 = $124&255;
    $126 = $125 << 24;
    $$sum27 = (($78) + 1)|0;
    $127 = (($1) + ($$sum27)|0);
    $128 = HEAP8[$127>>0]|0;
    $129 = $128&255;
    $130 = $129 << 16;
    $131 = $130 | $126;
    $$sum28 = (($78) + 2)|0;
    $132 = (($1) + ($$sum28)|0);
    $133 = HEAP8[$132>>0]|0;
    $134 = $133&255;
    $135 = $134 << 8;
    $136 = $131 | $135;
    $$sum29 = (($78) + 3)|0;
    $137 = (($1) + ($$sum29)|0);
    $138 = HEAP8[$137>>0]|0;
    $139 = $138&255;
    $140 = $136 | $139;
    $141 = ($140|0)==(0);
    if (!($141)) {
     $$sum2$i4 = (($78) + 4)|0;
     $$sum3$i5 = (($78) + 5)|0;
     $$sum4$i6 = (($78) + 6)|0;
     $max$0$ph14$i = $140;$min$0$ph15$i = 0;
     L29: while(1) {
      $min$013$i = $min$0$ph15$i;
      while(1) {
       $146 = (($min$013$i) + ($max$0$ph14$i))|0;
       $143 = $146 >>> 1;
       $147 = ($143*5)|0;
       $$sum30 = (($$sum2$i4) + ($147))|0;
       $148 = (($1) + ($$sum30)|0);
       $149 = HEAP8[$148>>0]|0;
       $150 = $149&255;
       $151 = $150 << 16;
       $$sum31 = (($$sum3$i5) + ($147))|0;
       $152 = (($1) + ($$sum31)|0);
       $153 = HEAP8[$152>>0]|0;
       $154 = $153&255;
       $155 = $154 << 8;
       $156 = $155 | $151;
       $$sum32 = (($$sum4$i6) + ($147))|0;
       $157 = (($1) + ($$sum32)|0);
       $158 = HEAP8[$157>>0]|0;
       $159 = $158&255;
       $160 = $156 | $159;
       $161 = ($160>>>0)>($charcode>>>0);
       if ($161) {
        break;
       }
       $162 = ($160>>>0)<($charcode>>>0);
       $145 = (($143) + 1)|0;
       if (!($162)) {
        break L29;
       }
       $144 = ($145>>>0)<($max$0$ph14$i>>>0);
       if ($144) {
        $min$013$i = $145;
       } else {
        break L26;
       }
      }
      $142 = ($min$013$i>>>0)<($143>>>0);
      if ($142) {
       $max$0$ph14$i = $143;$min$0$ph15$i = $min$013$i;
      } else {
       break L26;
      }
     }
     $$sum1$i3 = (($78) + 7)|0;
     $$sum33 = (($$sum1$i3) + ($147))|0;
     $163 = (($1) + ($$sum33)|0);
     $164 = HEAP8[$163>>0]|0;
     $165 = $164&255;
     $166 = $165 << 8;
     $$sum5$i = (($78) + 8)|0;
     $$sum34 = (($$sum5$i) + ($147))|0;
     $167 = (($1) + ($$sum34)|0);
     $168 = HEAP8[$167>>0]|0;
     $169 = $168&255;
     $170 = $166 | $169;
     $171 = ($170|0)==(0);
     if (!($171)) {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  } while(0);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 24) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _tt_cmap14_variants($cmap,$memory) {
 $cmap = $cmap|0;
 $memory = $memory|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$i = 0, $exitcond = 0, $i$0$lcssa = 0, $i$03 = 0;
 var $p$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp;
 $0 = (($cmap) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cmap) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 1)|0;
 $5 = (($cmap) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$error$i>>2] = 0;
 $7 = ($6>>>0)<($4>>>0);
 do {
  if ($7) {
   $8 = (($cmap) + 36|0);
   HEAP32[$8>>2] = $memory;
   $9 = (($cmap) + 32|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (_ft_mem_realloc($memory,4,$6,$4,$10,$error$i)|0);
   HEAP32[$9>>2] = $11;
   $12 = HEAP32[$error$i>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    HEAP32[$5>>2] = $4;
    $29 = $11;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$phi$trans$insert = (($cmap) + 32|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $29 = $$pre;
  }
 } while(0);
 $14 = ($1|0)==(0);
 if ($14) {
  $i$0$lcssa = 0;
 } else {
  $15 = (($3) + 10|0);
  $i$03 = 0;$p$02 = $15;
  while(1) {
   $16 = HEAP8[$p$02>>0]|0;
   $17 = $16&255;
   $18 = $17 << 16;
   $19 = (($p$02) + 1|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20&255;
   $22 = $21 << 8;
   $23 = $22 | $18;
   $24 = (($p$02) + 2|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = $25&255;
   $27 = $23 | $26;
   $28 = (($29) + ($i$03<<2)|0);
   HEAP32[$28>>2] = $27;
   $30 = (($p$02) + 11|0);
   $31 = (($i$03) + 1)|0;
   $exitcond = ($31|0)==($1|0);
   if ($exitcond) {
    $i$0$lcssa = $1;
    break;
   } else {
    $i$03 = $31;$p$02 = $30;
   }
  }
 }
 $32 = (($29) + ($i$0$lcssa<<2)|0);
 HEAP32[$32>>2] = 0;
 $$0 = $29;
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap14_char_variants($cmap,$memory,$charCode) {
 $cmap = $cmap|0;
 $memory = $memory|0;
 $charCode = $charCode|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$sum = 0, $$sum1$i = 0, $$sum1$i2 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2$i = 0, $$sum2$i3 = 0, $$sum20 = 0, $$sum21 = 0;
 var $$sum22 = 0, $$sum3$i = 0, $$sum3$i4 = 0, $$sum4$i = 0, $$sum4$i5 = 0, $$sum5$i = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$038 = 0, $error$i = 0, $max$0$i = 0, $max$0$ph$i = 0, $max$0$ph14$i = 0, $min$0$ph$i = 0, $min$0$ph15$i = 0, $min$013$i = 0, $p$037 = 0;
 var $q$0$lcssa = 0, $q$035 = 0, $q$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp;
 $0 = (($cmap) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cmap) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 1)|0;
 $5 = (($cmap) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$error$i>>2] = 0;
 $7 = ($6>>>0)<($4>>>0);
 do {
  if ($7) {
   $8 = (($cmap) + 36|0);
   HEAP32[$8>>2] = $memory;
   $9 = (($cmap) + 32|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (_ft_mem_realloc($memory,4,$6,$4,$10,$error$i)|0);
   HEAP32[$9>>2] = $11;
   $12 = HEAP32[$error$i>>2]|0;
   $13 = ($12|0)==(0);
   if ($13) {
    HEAP32[$5>>2] = $4;
    $163 = $11;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$phi$trans$insert = (($cmap) + 32|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $163 = $$pre;
  }
 } while(0);
 $14 = ($1|0)==(0);
 if ($14) {
  $q$0$lcssa = $163;
 } else {
  $15 = (($3) + 10|0);
  $count$038 = $1;$p$037 = $15;$q$035 = $163;
  while(1) {
   $16 = HEAP8[$p$037>>0]|0;
   $17 = $16&255;
   $18 = $17 << 16;
   $19 = (($p$037) + 1|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20&255;
   $22 = $21 << 8;
   $23 = $22 | $18;
   $24 = (($p$037) + 2|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = $25&255;
   $27 = $23 | $26;
   $28 = (($p$037) + 3|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = $30 << 24;
   $32 = (($p$037) + 4|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = $33&255;
   $35 = $34 << 16;
   $36 = $35 | $31;
   $37 = (($p$037) + 5|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = $38&255;
   $40 = $39 << 8;
   $41 = $36 | $40;
   $42 = (($p$037) + 6|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = $43&255;
   $45 = $41 | $44;
   $46 = (($p$037) + 11|0);
   $47 = (($p$037) + 7|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = $48&255;
   $50 = $49 << 24;
   $51 = (($p$037) + 8|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = $52&255;
   $54 = $53 << 16;
   $55 = $54 | $50;
   $56 = (($p$037) + 9|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = $57&255;
   $59 = $58 << 8;
   $60 = $55 | $59;
   $61 = (($p$037) + 10|0);
   $62 = HEAP8[$61>>0]|0;
   $63 = $62&255;
   $64 = $60 | $63;
   $65 = ($45|0)==(0);
   L12: do {
    if ($65) {
     label = 13;
    } else {
     $66 = HEAP32[$2>>2]|0;
     $67 = (($66) + ($45)|0);
     $68 = HEAP8[$67>>0]|0;
     $69 = $68&255;
     $70 = $69 << 24;
     $$sum = (($45) + 1)|0;
     $71 = (($66) + ($$sum)|0);
     $72 = HEAP8[$71>>0]|0;
     $73 = $72&255;
     $74 = $73 << 16;
     $75 = $74 | $70;
     $$sum9 = (($45) + 2)|0;
     $76 = (($66) + ($$sum9)|0);
     $77 = HEAP8[$76>>0]|0;
     $78 = $77&255;
     $79 = $78 << 8;
     $80 = $75 | $79;
     $$sum10 = (($45) + 3)|0;
     $81 = (($66) + ($$sum10)|0);
     $82 = HEAP8[$81>>0]|0;
     $83 = $82&255;
     $84 = $80 | $83;
     $$sum2$i = (($45) + 4)|0;
     $$sum3$i = (($45) + 5)|0;
     $$sum4$i = (($45) + 6)|0;
     $$sum1$i = (($45) + 7)|0;
     $max$0$ph$i = $84;$min$0$ph$i = 0;
     while(1) {
      $max$0$i = $max$0$ph$i;
      while(1) {
       $85 = ($min$0$ph$i>>>0)<($max$0$i>>>0);
       if (!($85)) {
        label = 13;
        break L12;
       }
       $86 = (($max$0$i) + ($min$0$ph$i))|0;
       $87 = $86 >>> 1;
       $88 = $87 << 2;
       $$sum19 = (($$sum2$i) + ($88))|0;
       $89 = (($66) + ($$sum19)|0);
       $90 = HEAP8[$89>>0]|0;
       $91 = $90&255;
       $92 = $91 << 16;
       $$sum20 = (($$sum3$i) + ($88))|0;
       $93 = (($66) + ($$sum20)|0);
       $94 = HEAP8[$93>>0]|0;
       $95 = $94&255;
       $96 = $95 << 8;
       $97 = $96 | $92;
       $$sum21 = (($$sum4$i) + ($88))|0;
       $98 = (($66) + ($$sum21)|0);
       $99 = HEAP8[$98>>0]|0;
       $100 = $99&255;
       $101 = $97 | $100;
       $102 = ($101>>>0)>($charCode>>>0);
       if ($102) {
        $max$0$i = $87;
       } else {
        break;
       }
      }
      $$sum22 = (($$sum1$i) + ($88))|0;
      $103 = (($66) + ($$sum22)|0);
      $104 = HEAP8[$103>>0]|0;
      $105 = $104&255;
      $106 = (($105) + ($101))|0;
      $107 = ($106>>>0)<($charCode>>>0);
      $108 = (($87) + 1)|0;
      if ($107) {
       $max$0$ph$i = $max$0$i;$min$0$ph$i = $108;
      } else {
       label = 22;
       break;
      }
     }
    }
   } while(0);
   L20: do {
    if ((label|0) == 13) {
     label = 0;
     $109 = ($64|0)==(0);
     if ($109) {
      $q$1 = $q$035;
     } else {
      $110 = HEAP32[$2>>2]|0;
      $111 = (($110) + ($64)|0);
      $112 = HEAP8[$111>>0]|0;
      $113 = $112&255;
      $114 = $113 << 24;
      $$sum11 = (($64) + 1)|0;
      $115 = (($110) + ($$sum11)|0);
      $116 = HEAP8[$115>>0]|0;
      $117 = $116&255;
      $118 = $117 << 16;
      $119 = $118 | $114;
      $$sum12 = (($64) + 2)|0;
      $120 = (($110) + ($$sum12)|0);
      $121 = HEAP8[$120>>0]|0;
      $122 = $121&255;
      $123 = $122 << 8;
      $124 = $119 | $123;
      $$sum13 = (($64) + 3)|0;
      $125 = (($110) + ($$sum13)|0);
      $126 = HEAP8[$125>>0]|0;
      $127 = $126&255;
      $128 = $124 | $127;
      $129 = ($128|0)==(0);
      if ($129) {
       $q$1 = $q$035;
      } else {
       $$sum2$i3 = (($64) + 4)|0;
       $$sum3$i4 = (($64) + 5)|0;
       $$sum4$i5 = (($64) + 6)|0;
       $max$0$ph14$i = $128;$min$0$ph15$i = 0;
       L24: while(1) {
        $min$013$i = $min$0$ph15$i;
        while(1) {
         $134 = (($min$013$i) + ($max$0$ph14$i))|0;
         $131 = $134 >>> 1;
         $135 = ($131*5)|0;
         $$sum14 = (($$sum2$i3) + ($135))|0;
         $136 = (($110) + ($$sum14)|0);
         $137 = HEAP8[$136>>0]|0;
         $138 = $137&255;
         $139 = $138 << 16;
         $$sum15 = (($$sum3$i4) + ($135))|0;
         $140 = (($110) + ($$sum15)|0);
         $141 = HEAP8[$140>>0]|0;
         $142 = $141&255;
         $143 = $142 << 8;
         $144 = $143 | $139;
         $$sum16 = (($$sum4$i5) + ($135))|0;
         $145 = (($110) + ($$sum16)|0);
         $146 = HEAP8[$145>>0]|0;
         $147 = $146&255;
         $148 = $144 | $147;
         $149 = ($148>>>0)>($charCode>>>0);
         if ($149) {
          break;
         }
         $150 = ($148>>>0)<($charCode>>>0);
         $133 = (($131) + 1)|0;
         if (!($150)) {
          break L24;
         }
         $132 = ($133>>>0)<($max$0$ph14$i>>>0);
         if ($132) {
          $min$013$i = $133;
         } else {
          $q$1 = $q$035;
          break L20;
         }
        }
        $130 = ($min$013$i>>>0)<($131>>>0);
        if ($130) {
         $max$0$ph14$i = $131;$min$0$ph15$i = $min$013$i;
        } else {
         $q$1 = $q$035;
         break L20;
        }
       }
       $$sum1$i2 = (($64) + 7)|0;
       $$sum17 = (($$sum1$i2) + ($135))|0;
       $151 = (($110) + ($$sum17)|0);
       $152 = HEAP8[$151>>0]|0;
       $153 = $152&255;
       $154 = $153 << 8;
       $$sum5$i = (($64) + 8)|0;
       $$sum18 = (($$sum5$i) + ($135))|0;
       $155 = (($110) + ($$sum18)|0);
       $156 = HEAP8[$155>>0]|0;
       $157 = $156&255;
       $158 = $154 | $157;
       $159 = ($158|0)==(0);
       if ($159) {
        $q$1 = $q$035;
       } else {
        label = 22;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 22) {
    label = 0;
    HEAP32[$q$035>>2] = $27;
    $160 = (($q$035) + 4|0);
    $q$1 = $160;
   }
   $161 = (($count$038) + -1)|0;
   $162 = ($161|0)==(0);
   if ($162) {
    $q$0$lcssa = $q$1;
    break;
   } else {
    $count$038 = $161;$p$037 = $46;$q$035 = $q$1;
   }
  }
 }
 HEAP32[$q$0$lcssa>>2] = 0;
 $$0 = $163;
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap14_variant_chars($cmap,$memory,$variantSelector) {
 $cmap = $cmap|0;
 $memory = $memory|0;
 $variantSelector = $variantSelector|0;
 var $$0 = 0, $$01$i = 0, $$012$i = 0, $$012$i30 = 0, $$pre = 0, $$pre$phi153Z2D = 0, $$pre$phi157Z2D = 0, $$pre$phi161Z2D = 0, $$pre154 = 0, $$pre158 = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0;
 var $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum42 = 0, $$sum43 = 0, $$sum44 = 0, $$sum45 = 0, $$sum46 = 0, $$sum47 = 0, $$sum48 = 0, $$sum49 = 0, $$sum50 = 0, $$sum51 = 0, $$sum52 = 0, $$sum53 = 0, $$sum54 = 0, $$sum55 = 0, $$sum59 = 0, $$sum61 = 0, $$sum62 = 0;
 var $$sum63 = 0, $$sum64 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dcnt$0$lcssa = 0, $dcnt$0$ph = 0, $dcnt$089 = 0, $dcnt$095 = 0, $di$0$lcssa = 0, $di$0$ph = 0, $di$097 = 0, $di$1 = 0, $di$270 = 0, $dp$0$lcssa = 0, $dp$0$ph = 0, $dp$091 = 0;
 var $dp$096 = 0, $dp$169 = 0, $duni$0$lcssa = 0, $duni$0$ph = 0, $duni$087 = 0, $duni$094 = 0, $error$i = 0, $error$i23 = 0, $error$i36 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i31 = 0, $exitcond120 = 0, $exitcond123 = 0, $i$0$lcssa = 0, $i$0$lcssa$i = 0, $i$0$ph = 0, $i$03$i = 0, $i$03$i29 = 0, $i$093 = 0;
 var $i$182 = 0, $i$2 = 0, $i$3 = 0, $i$4 = 0, $i$475 = 0, $i$478 = 0, $i$572 = 0, $i$668 = 0, $i$766 = 0, $i$8 = 0, $k$083 = 0, $k$173 = 0, $k$267 = 0, $max$0$ph8$i = 0, $min$0$ph9$i = 0, $min$06$i = 0, $ni$0$ph = 0, $ni$1 = 0, $ni$277 = 0, $numRanges$02$i = 0;
 var $nuni$0$ph = 0, $p$0$ph = 0, $p$176 = 0, $tot$0$lcssa$i = 0, $tot$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i36 = sp + 8|0;
 $error$i23 = sp;
 $error$i = sp + 4|0;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = (($1) + 7|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = (($1) + 8|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = (($1) + 9|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ($19|0)==(0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $max$0$ph8$i = $19;$min$0$ph9$i = 0;
 }
 L3: while(1) {
  $min$06$i = $min$0$ph9$i;
  while(1) {
   $25 = (($min$06$i) + ($max$0$ph8$i))|0;
   $22 = $25 >>> 1;
   $26 = ($22*11)|0;
   $$sum = (($26) + 10)|0;
   $27 = (($1) + ($$sum)|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = $28&255;
   $30 = $29 << 16;
   $$sum42 = (($26) + 11)|0;
   $31 = (($1) + ($$sum42)|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32&255;
   $34 = $33 << 8;
   $35 = $34 | $30;
   $$sum43 = (($26) + 12)|0;
   $36 = (($1) + ($$sum43)|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $39 = $35 | $38;
   $40 = ($39>>>0)>($variantSelector>>>0);
   if ($40) {
    break;
   }
   $41 = ($39>>>0)<($variantSelector>>>0);
   $24 = (($22) + 1)|0;
   if (!($41)) {
    label = 7;
    break L3;
   }
   $23 = ($24>>>0)<($max$0$ph8$i>>>0);
   if ($23) {
    $min$06$i = $24;
   } else {
    $$0 = 0;
    label = 59;
    break L3;
   }
  }
  $21 = ($min$06$i>>>0)<($22>>>0);
  if ($21) {
   $max$0$ph8$i = $22;$min$0$ph9$i = $min$06$i;
  } else {
   $$0 = 0;
   label = 59;
   break;
  }
 }
 if ((label|0) == 7) {
  $$sum44 = (($26) + 13)|0;
  $42 = (($1) + ($$sum44)|0);
  $43 = ($42|0)==(0|0);
  if ($43) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $44 = HEAP8[$42>>0]|0;
  $45 = $44&255;
  $46 = $45 << 24;
  $$sum45 = (($26) + 14)|0;
  $47 = (($1) + ($$sum45)|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = $48&255;
  $50 = $49 << 16;
  $51 = $50 | $46;
  $$sum46 = (($26) + 15)|0;
  $52 = (($1) + ($$sum46)|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53&255;
  $55 = $54 << 8;
  $56 = $51 | $55;
  $$sum47 = (($26) + 16)|0;
  $57 = (($1) + ($$sum47)|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = $58&255;
  $60 = $56 | $59;
  $$sum48 = (($26) + 17)|0;
  $61 = (($1) + ($$sum48)|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = $62&255;
  $64 = $63 << 24;
  $$sum49 = (($26) + 18)|0;
  $65 = (($1) + ($$sum49)|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = $67 << 16;
  $69 = $68 | $64;
  $$sum50 = (($26) + 19)|0;
  $70 = (($1) + ($$sum50)|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71&255;
  $73 = $72 << 8;
  $74 = $69 | $73;
  $$sum51 = (($26) + 20)|0;
  $75 = (($1) + ($$sum51)|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $76&255;
  $78 = $74 | $77;
  $79 = ($78|0)==(0);
  $80 = $78 | $60;
  $81 = ($80|0)==(0);
  if ($81) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $82 = ($60|0)==(0);
  if ($82) {
   $83 = (($1) + ($78)|0);
   $84 = HEAP8[$83>>0]|0;
   $85 = $84&255;
   $86 = $85 << 24;
   $$sum61 = (($78) + 1)|0;
   $87 = (($1) + ($$sum61)|0);
   $88 = HEAP8[$87>>0]|0;
   $89 = $88&255;
   $90 = $89 << 16;
   $91 = $90 | $86;
   $$sum62 = (($78) + 2)|0;
   $92 = (($1) + ($$sum62)|0);
   $93 = HEAP8[$92>>0]|0;
   $94 = $93&255;
   $95 = $94 << 8;
   $96 = $91 | $95;
   $$sum63 = (($78) + 3)|0;
   $97 = (($1) + ($$sum63)|0);
   $98 = HEAP8[$97>>0]|0;
   $99 = $98&255;
   $100 = $96 | $99;
   $101 = (($100) + 1)|0;
   $102 = (($cmap) + 28|0);
   $103 = HEAP32[$102>>2]|0;
   HEAP32[$error$i23>>2] = 0;
   $104 = ($103>>>0)<($101>>>0);
   do {
    if ($104) {
     $105 = (($cmap) + 36|0);
     HEAP32[$105>>2] = $memory;
     $106 = (($cmap) + 32|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = (_ft_mem_realloc($memory,4,$103,$101,$107,$error$i23)|0);
     HEAP32[$106>>2] = $108;
     $109 = HEAP32[$error$i23>>2]|0;
     $110 = ($109|0)==(0);
     if ($110) {
      HEAP32[$102>>2] = $101;
      $$pre$phi153Z2D = $106;
      break;
     } else {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     $$pre = (($cmap) + 32|0);
     $$pre$phi153Z2D = $$pre;
    }
   } while(0);
   $111 = HEAP32[$$pre$phi153Z2D>>2]|0;
   $112 = ($100|0)==(0);
   if ($112) {
    $i$0$lcssa$i = 0;
   } else {
    $$sum64 = (($78) + 4)|0;
    $113 = (($1) + ($$sum64)|0);
    $$012$i = $113;$i$03$i = 0;
    while(1) {
     $114 = HEAP8[$$012$i>>0]|0;
     $115 = $114&255;
     $116 = $115 << 16;
     $117 = (($$012$i) + 1|0);
     $118 = HEAP8[$117>>0]|0;
     $119 = $118&255;
     $120 = $119 << 8;
     $121 = $120 | $116;
     $122 = (($$012$i) + 2|0);
     $123 = HEAP8[$122>>0]|0;
     $124 = $123&255;
     $125 = $121 | $124;
     $126 = (($111) + ($i$03$i<<2)|0);
     HEAP32[$126>>2] = $125;
     $127 = (($$012$i) + 5|0);
     $128 = (($i$03$i) + 1)|0;
     $exitcond$i = ($128|0)==($100|0);
     if ($exitcond$i) {
      $i$0$lcssa$i = $100;
      break;
     } else {
      $$012$i = $127;$i$03$i = $128;
     }
    }
   }
   $129 = (($111) + ($i$0$lcssa$i<<2)|0);
   HEAP32[$129>>2] = 0;
   $$0 = $111;
   STACKTOP = sp;return ($$0|0);
  }
  $130 = (($1) + ($60)|0);
  if ($79) {
   $131 = (_tt_cmap14_get_def_chars($cmap,$130,$memory)|0);
   $$0 = $131;
   STACKTOP = sp;return ($$0|0);
  }
  $132 = (($1) + ($78)|0);
  $133 = HEAP8[$132>>0]|0;
  $134 = $133&255;
  $135 = $134 << 24;
  $$sum2 = (($78) + 1)|0;
  $136 = (($1) + ($$sum2)|0);
  $137 = HEAP8[$136>>0]|0;
  $138 = $137&255;
  $139 = $138 << 16;
  $140 = $139 | $135;
  $$sum3 = (($78) + 2)|0;
  $141 = (($1) + ($$sum3)|0);
  $142 = HEAP8[$141>>0]|0;
  $143 = $142&255;
  $144 = $143 << 8;
  $145 = $140 | $144;
  $$sum4 = (($78) + 3)|0;
  $146 = (($1) + ($$sum4)|0);
  $147 = HEAP8[$146>>0]|0;
  $148 = $147&255;
  $149 = $145 | $148;
  $150 = HEAP8[$130>>0]|0;
  $151 = $150&255;
  $152 = $151 << 24;
  $$sum52 = (($60) + 1)|0;
  $153 = (($1) + ($$sum52)|0);
  $154 = HEAP8[$153>>0]|0;
  $155 = $154&255;
  $156 = $155 << 16;
  $157 = $156 | $152;
  $$sum53 = (($60) + 2)|0;
  $158 = (($1) + ($$sum53)|0);
  $159 = HEAP8[$158>>0]|0;
  $160 = $159&255;
  $161 = $160 << 8;
  $162 = $157 | $161;
  $$sum54 = (($60) + 3)|0;
  $163 = (($1) + ($$sum54)|0);
  $164 = HEAP8[$163>>0]|0;
  $165 = $164&255;
  $166 = $162 | $165;
  $167 = ($166|0)==(0);
  if ($167) {
   $tot$0$lcssa$i = 0;
  } else {
   $$sum55 = (($60) + 7)|0;
   $168 = (($1) + ($$sum55)|0);
   $$01$i = $168;$numRanges$02$i = $166;$tot$03$i = 0;
   while(1) {
    $169 = HEAP8[$$01$i>>0]|0;
    $170 = $169&255;
    $171 = (($tot$03$i) + 1)|0;
    $172 = (($171) + ($170))|0;
    $173 = (($$01$i) + 4|0);
    $174 = (($numRanges$02$i) + -1)|0;
    $175 = ($174|0)==(0);
    if ($175) {
     $tot$0$lcssa$i = $172;
     break;
    } else {
     $$01$i = $173;$numRanges$02$i = $174;$tot$03$i = $172;
    }
   }
  }
  $176 = ($149|0)==(0);
  if ($176) {
   $177 = (_tt_cmap14_get_def_chars($cmap,$130,$memory)|0);
   $$0 = $177;
   STACKTOP = sp;return ($$0|0);
  }
  $178 = ($tot$0$lcssa$i|0)==(0);
  $179 = (($149) + 1)|0;
  if ($178) {
   $180 = (($cmap) + 28|0);
   $181 = HEAP32[$180>>2]|0;
   HEAP32[$error$i36>>2] = 0;
   $182 = ($181>>>0)<($179>>>0);
   do {
    if ($182) {
     $183 = (($cmap) + 36|0);
     HEAP32[$183>>2] = $memory;
     $184 = (($cmap) + 32|0);
     $185 = HEAP32[$184>>2]|0;
     $186 = (_ft_mem_realloc($memory,4,$181,$179,$185,$error$i36)|0);
     HEAP32[$184>>2] = $186;
     $187 = HEAP32[$error$i36>>2]|0;
     $188 = ($187|0)==(0);
     if ($188) {
      HEAP32[$180>>2] = $179;
      $$pre$phi157Z2D = $184;
      break;
     } else {
      $$0 = 0;
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     $$pre154 = (($cmap) + 32|0);
     $$pre$phi157Z2D = $$pre154;
    }
   } while(0);
   $189 = HEAP32[$$pre$phi157Z2D>>2]|0;
   $$sum59 = (($78) + 4)|0;
   $190 = (($1) + ($$sum59)|0);
   $$012$i30 = $190;$i$03$i29 = 0;
   while(1) {
    $191 = HEAP8[$$012$i30>>0]|0;
    $192 = $191&255;
    $193 = $192 << 16;
    $194 = (($$012$i30) + 1|0);
    $195 = HEAP8[$194>>0]|0;
    $196 = $195&255;
    $197 = $196 << 8;
    $198 = $197 | $193;
    $199 = (($$012$i30) + 2|0);
    $200 = HEAP8[$199>>0]|0;
    $201 = $200&255;
    $202 = $198 | $201;
    $203 = (($189) + ($i$03$i29<<2)|0);
    HEAP32[$203>>2] = $202;
    $204 = (($$012$i30) + 5|0);
    $205 = (($i$03$i29) + 1)|0;
    $exitcond$i31 = ($205|0)==($149|0);
    if ($exitcond$i31) {
     break;
    } else {
     $$012$i30 = $204;$i$03$i29 = $205;
    }
   }
   $206 = (($189) + ($149<<2)|0);
   HEAP32[$206>>2] = 0;
   $$0 = $189;
   STACKTOP = sp;return ($$0|0);
  }
  $207 = (($179) + ($tot$0$lcssa$i))|0;
  $208 = (($cmap) + 28|0);
  $209 = HEAP32[$208>>2]|0;
  HEAP32[$error$i>>2] = 0;
  $210 = ($209>>>0)<($207>>>0);
  do {
   if ($210) {
    $211 = (($cmap) + 36|0);
    HEAP32[$211>>2] = $memory;
    $212 = (($cmap) + 32|0);
    $213 = HEAP32[$212>>2]|0;
    $214 = (_ft_mem_realloc($memory,4,$209,$207,$213,$error$i)|0);
    HEAP32[$212>>2] = $214;
    $215 = HEAP32[$error$i>>2]|0;
    $216 = ($215|0)==(0);
    if ($216) {
     HEAP32[$208>>2] = $207;
     $$pre$phi161Z2D = $212;
     break;
    } else {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $$pre158 = (($cmap) + 32|0);
    $$pre$phi161Z2D = $$pre158;
   }
  } while(0);
  $217 = HEAP32[$$pre$phi161Z2D>>2]|0;
  $$sum10 = (($60) + 7)|0;
  $218 = (($1) + ($$sum10)|0);
  $$sum11 = (($60) + 4)|0;
  $219 = (($1) + ($$sum11)|0);
  $220 = HEAP8[$219>>0]|0;
  $221 = $220&255;
  $222 = $221 << 16;
  $$sum12 = (($60) + 5)|0;
  $223 = (($1) + ($$sum12)|0);
  $224 = HEAP8[$223>>0]|0;
  $225 = $224&255;
  $226 = $225 << 8;
  $227 = $226 | $222;
  $$sum13 = (($60) + 6)|0;
  $228 = (($1) + ($$sum13)|0);
  $229 = HEAP8[$228>>0]|0;
  $230 = $229&255;
  $231 = $227 | $230;
  $$sum14 = (($60) + 8)|0;
  $232 = (($1) + ($$sum14)|0);
  $233 = HEAP8[$218>>0]|0;
  $234 = $233&255;
  $$sum16 = (($78) + 4)|0;
  $235 = (($1) + ($$sum16)|0);
  $236 = HEAP8[$235>>0]|0;
  $237 = $236&255;
  $238 = $237 << 16;
  $$sum17 = (($78) + 5)|0;
  $239 = (($1) + ($$sum17)|0);
  $240 = HEAP8[$239>>0]|0;
  $241 = $240&255;
  $242 = $241 << 8;
  $243 = $242 | $238;
  $$sum18 = (($78) + 6)|0;
  $244 = (($1) + ($$sum18)|0);
  $245 = HEAP8[$244>>0]|0;
  $246 = $245&255;
  $247 = $243 | $246;
  $$sum19 = (($78) + 9)|0;
  $248 = (($1) + ($$sum19)|0);
  $dcnt$0$ph = $234;$di$0$ph = 1;$dp$0$ph = $232;$duni$0$ph = $231;$i$0$ph = 0;$ni$0$ph = 1;$nuni$0$ph = $247;$p$0$ph = $248;
  L68: while(1) {
   $249 = (($dcnt$0$ph) + ($duni$0$ph))|0;
   $250 = ($nuni$0$ph>>>0)>($249>>>0);
   if ($250) {
    $dcnt$095 = $dcnt$0$ph;$di$097 = $di$0$ph;$dp$096 = $dp$0$ph;$duni$094 = $duni$0$ph;$i$093 = $i$0$ph;
    while(1) {
     $i$182 = $i$093;$k$083 = 0;
     while(1) {
      $251 = (($k$083) + ($duni$094))|0;
      $252 = (($i$182) + 1)|0;
      $253 = (($217) + ($i$182<<2)|0);
      HEAP32[$253>>2] = $251;
      $254 = (($k$083) + 1)|0;
      $255 = ($254>>>0)>($dcnt$095>>>0);
      if ($255) {
       break;
      } else {
       $i$182 = $252;$k$083 = $254;
      }
     }
     $256 = (($di$097) + 1)|0;
     $257 = ($256>>>0)>($166>>>0);
     if ($257) {
      $dcnt$089 = $dcnt$095;$di$1 = $256;$dp$091 = $dp$096;$duni$087 = $duni$094;$i$3 = $252;$ni$1 = $ni$0$ph;
      break L68;
     }
     $258 = (($dp$096) + 3|0);
     $259 = HEAP8[$dp$096>>0]|0;
     $260 = $259&255;
     $261 = $260 << 16;
     $262 = (($dp$096) + 1|0);
     $263 = HEAP8[$262>>0]|0;
     $264 = $263&255;
     $265 = $264 << 8;
     $266 = $265 | $261;
     $267 = (($dp$096) + 2|0);
     $268 = HEAP8[$267>>0]|0;
     $269 = $268&255;
     $270 = $266 | $269;
     $271 = (($dp$096) + 4|0);
     $272 = HEAP8[$258>>0]|0;
     $273 = $272&255;
     $274 = (($273) + ($270))|0;
     $275 = ($nuni$0$ph>>>0)>($274>>>0);
     if ($275) {
      $dcnt$095 = $273;$di$097 = $256;$dp$096 = $271;$duni$094 = $270;$i$093 = $252;
     } else {
      $dcnt$0$lcssa = $273;$di$0$lcssa = $256;$dp$0$lcssa = $271;$duni$0$lcssa = $270;$i$0$lcssa = $252;
      break;
     }
    }
   } else {
    $dcnt$0$lcssa = $dcnt$0$ph;$di$0$lcssa = $di$0$ph;$dp$0$lcssa = $dp$0$ph;$duni$0$lcssa = $duni$0$ph;$i$0$lcssa = $i$0$ph;
   }
   $276 = ($nuni$0$ph>>>0)<($duni$0$lcssa>>>0);
   if ($276) {
    $277 = (($i$0$lcssa) + 1)|0;
    $278 = (($217) + ($i$0$lcssa<<2)|0);
    HEAP32[$278>>2] = $nuni$0$ph;
    $i$2 = $277;
   } else {
    $i$2 = $i$0$lcssa;
   }
   $279 = (($ni$0$ph) + 1)|0;
   $280 = ($279>>>0)>($149>>>0);
   if ($280) {
    $dcnt$089 = $dcnt$0$lcssa;$di$1 = $di$0$lcssa;$dp$091 = $dp$0$lcssa;$duni$087 = $duni$0$lcssa;$i$3 = $i$2;$ni$1 = $279;
    break;
   }
   $281 = HEAP8[$p$0$ph>>0]|0;
   $282 = $281&255;
   $283 = $282 << 16;
   $284 = (($p$0$ph) + 1|0);
   $285 = HEAP8[$284>>0]|0;
   $286 = $285&255;
   $287 = $286 << 8;
   $288 = $287 | $283;
   $289 = (($p$0$ph) + 2|0);
   $290 = HEAP8[$289>>0]|0;
   $291 = $290&255;
   $292 = $288 | $291;
   $293 = (($p$0$ph) + 5|0);
   $dcnt$0$ph = $dcnt$0$lcssa;$di$0$ph = $di$0$lcssa;$dp$0$ph = $dp$0$lcssa;$duni$0$ph = $duni$0$lcssa;$i$0$ph = $i$2;$ni$0$ph = $279;$nuni$0$ph = $292;$p$0$ph = $293;
  }
  $294 = ($ni$1>>>0)>($149>>>0);
  if ($294) {
   $314 = ($di$1>>>0)>($166>>>0);
   if ($314) {
    $i$8 = $i$3;
   } else {
    $i$572 = $i$3;$k$173 = 0;
    while(1) {
     $316 = (($k$173) + ($duni$087))|0;
     $317 = (($i$572) + 1)|0;
     $318 = (($217) + ($i$572<<2)|0);
     HEAP32[$318>>2] = $316;
     $319 = (($k$173) + 1)|0;
     $320 = ($319>>>0)>($dcnt$089>>>0);
     if ($320) {
      break;
     } else {
      $i$572 = $317;$k$173 = $319;
     }
    }
    $315 = ($di$1>>>0)<($166>>>0);
    if ($315) {
     $di$270 = $di$1;$dp$169 = $dp$091;$i$668 = $317;
     while(1) {
      $321 = (($dp$169) + 3|0);
      $322 = HEAP8[$dp$169>>0]|0;
      $323 = $322&255;
      $324 = $323 << 16;
      $325 = (($dp$169) + 1|0);
      $326 = HEAP8[$325>>0]|0;
      $327 = $326&255;
      $328 = $327 << 8;
      $329 = $328 | $324;
      $330 = (($dp$169) + 2|0);
      $331 = HEAP8[$330>>0]|0;
      $332 = $331&255;
      $333 = $329 | $332;
      $334 = HEAP8[$321>>0]|0;
      $335 = $334&255;
      $i$766 = $i$668;$k$267 = 0;
      while(1) {
       $336 = (($k$267) + ($333))|0;
       $337 = (($i$766) + 1)|0;
       $338 = (($217) + ($i$766<<2)|0);
       HEAP32[$338>>2] = $336;
       $339 = (($k$267) + 1)|0;
       $exitcond = ($k$267|0)==($335|0);
       if ($exitcond) {
        break;
       } else {
        $i$766 = $337;$k$267 = $339;
       }
      }
      $340 = (($dp$169) + 4|0);
      $341 = (($i$668) + 1)|0;
      $342 = (($341) + ($335))|0;
      $343 = (($di$270) + 1)|0;
      $exitcond120 = ($343|0)==($166|0);
      if ($exitcond120) {
       $i$8 = $342;
       break;
      } else {
       $di$270 = $343;$dp$169 = $340;$i$668 = $342;
      }
     }
    } else {
     $i$8 = $317;
    }
   }
  } else {
   $295 = (($217) + ($i$3<<2)|0);
   HEAP32[$295>>2] = $nuni$0$ph;
   $i$475 = (($i$3) + 1)|0;
   $296 = ($ni$1>>>0)<($149>>>0);
   if ($296) {
    $297 = (($i$3) + ($149))|0;
    $298 = (($297) + 1)|0;
    $i$478 = $i$475;$ni$277 = $ni$1;$p$176 = $p$0$ph;
    while(1) {
     $299 = HEAP8[$p$176>>0]|0;
     $300 = $299&255;
     $301 = $300 << 16;
     $302 = (($p$176) + 1|0);
     $303 = HEAP8[$302>>0]|0;
     $304 = $303&255;
     $305 = $304 << 8;
     $306 = $305 | $301;
     $307 = (($p$176) + 2|0);
     $308 = HEAP8[$307>>0]|0;
     $309 = $308&255;
     $310 = $306 | $309;
     $311 = (($217) + ($i$478<<2)|0);
     HEAP32[$311>>2] = $310;
     $312 = (($p$176) + 5|0);
     $313 = (($ni$277) + 1)|0;
     $i$4 = (($i$478) + 1)|0;
     $exitcond123 = ($313|0)==($149|0);
     if ($exitcond123) {
      break;
     } else {
      $i$478 = $i$4;$ni$277 = $313;$p$176 = $312;
     }
    }
    $344 = (($298) - ($ni$1))|0;
    $i$8 = $344;
   } else {
    $i$8 = $i$475;
   }
  }
  $345 = (($217) + ($i$8<<2)|0);
  HEAP32[$345>>2] = 0;
  $$0 = $217;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 59) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _tt_cmap14_validate($table,$valid) {
 $table = $table|0;
 $valid = $valid|0;
 var $$sum = 0, $$sum10 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $defp$013 = 0, $exitcond = 0, $exitcond25 = 0, $exitcond26 = 0, $i$012 = 0, $i1$017 = 0;
 var $lastBase$011 = 0, $lastUni$018 = 0, $lastVarSel$021 = 0, $n$022 = 0, $ndp$016 = 0, $or$cond = 0, $p$023 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($table) + 2|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 << 24;
 $4 = (($table) + 3|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 16;
 $8 = $7 | $3;
 $9 = (($table) + 4|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = $11 << 8;
 $13 = $8 | $12;
 $14 = (($table) + 5|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = $13 | $16;
 $18 = (($table) + 10|0);
 $19 = (($table) + 6|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = $21 << 24;
 $23 = (($table) + 7|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = $24&255;
 $26 = $25 << 16;
 $27 = $26 | $22;
 $28 = (($table) + 8|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = $30 << 8;
 $32 = $27 | $31;
 $33 = (($table) + 9|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34&255;
 $36 = $32 | $35;
 $37 = (($valid) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38;
 $40 = $table;
 $41 = (($39) - ($40))|0;
 $42 = ($17>>>0)>($41>>>0);
 if ($42) {
  label = 3;
 } else {
  $43 = ($36*11)|0;
  $44 = (($43) + 10)|0;
  $45 = ($17>>>0)<($44>>>0);
  if ($45) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  _ft_validator_error($valid,8);
 }
 $46 = ($36|0)==(0);
 if ($46) {
  STACKTOP = sp;return 0;
 }
 $47 = (($valid) + 8|0);
 $48 = (($valid) + 20|0);
 $lastVarSel$021 = 1;$n$022 = 0;$p$023 = $18;
 while(1) {
  $49 = HEAP8[$p$023>>0]|0;
  $50 = $49&255;
  $51 = $50 << 16;
  $52 = (($p$023) + 1|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53&255;
  $55 = $54 << 8;
  $56 = $55 | $51;
  $57 = (($p$023) + 2|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = $58&255;
  $60 = $56 | $59;
  $61 = (($p$023) + 3|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = $62&255;
  $64 = $63 << 24;
  $65 = (($p$023) + 4|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = $67 << 16;
  $69 = $68 | $64;
  $70 = (($p$023) + 5|0);
  $71 = HEAP8[$70>>0]|0;
  $72 = $71&255;
  $73 = $72 << 8;
  $74 = $69 | $73;
  $75 = (($p$023) + 6|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $76&255;
  $78 = $74 | $77;
  $79 = (($p$023) + 11|0);
  $80 = (($p$023) + 7|0);
  $81 = HEAP8[$80>>0]|0;
  $82 = $81&255;
  $83 = $82 << 24;
  $84 = (($p$023) + 8|0);
  $85 = HEAP8[$84>>0]|0;
  $86 = $85&255;
  $87 = $86 << 16;
  $88 = $87 | $83;
  $89 = (($p$023) + 9|0);
  $90 = HEAP8[$89>>0]|0;
  $91 = $90&255;
  $92 = $91 << 8;
  $93 = $88 | $92;
  $94 = (($p$023) + 10|0);
  $95 = HEAP8[$94>>0]|0;
  $96 = $95&255;
  $97 = $93 | $96;
  $98 = ($78>>>0)<($17>>>0);
  $99 = ($97>>>0)<($17>>>0);
  $or$cond = $98 & $99;
  if (!($or$cond)) {
   _ft_validator_error($valid,8);
  }
  $100 = ($60>>>0)<($lastVarSel$021>>>0);
  if ($100) {
   _ft_validator_error($valid,8);
  }
  $101 = (($60) + 1)|0;
  $102 = ($78|0)==(0);
  if (!($102)) {
   $$sum5 = (($78) + 4)|0;
   $103 = (($table) + ($$sum5)|0);
   $104 = (($table) + ($78)|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = $105&255;
   $107 = $106 << 24;
   $$sum7 = (($78) + 1)|0;
   $108 = (($table) + ($$sum7)|0);
   $109 = HEAP8[$108>>0]|0;
   $110 = $109&255;
   $111 = $110 << 16;
   $112 = $111 | $107;
   $$sum8 = (($78) + 2)|0;
   $113 = (($table) + ($$sum8)|0);
   $114 = HEAP8[$113>>0]|0;
   $115 = $114&255;
   $116 = $115 << 8;
   $117 = $112 | $116;
   $$sum9 = (($78) + 3)|0;
   $118 = (($table) + ($$sum9)|0);
   $119 = HEAP8[$118>>0]|0;
   $120 = $119&255;
   $121 = $117 | $120;
   $122 = $121 << 2;
   $$sum10 = (($122) + ($$sum5))|0;
   $123 = (($table) + ($$sum10)|0);
   $124 = HEAP32[$37>>2]|0;
   $125 = ($123>>>0)>($124>>>0);
   if ($125) {
    _ft_validator_error($valid,8);
   }
   $126 = ($121|0)==(0);
   if (!($126)) {
    $defp$013 = $103;$i$012 = 0;$lastBase$011 = 0;
    while(1) {
     $127 = (($defp$013) + 3|0);
     $128 = HEAP8[$defp$013>>0]|0;
     $129 = $128&255;
     $130 = $129 << 16;
     $131 = (($defp$013) + 1|0);
     $132 = HEAP8[$131>>0]|0;
     $133 = $132&255;
     $134 = $133 << 8;
     $135 = $134 | $130;
     $136 = (($defp$013) + 2|0);
     $137 = HEAP8[$136>>0]|0;
     $138 = $137&255;
     $139 = $135 | $138;
     $140 = (($defp$013) + 4|0);
     $141 = HEAP8[$127>>0]|0;
     $142 = $141&255;
     $143 = (($139) + ($142))|0;
     $144 = ($143>>>0)>(1114111);
     if ($144) {
      _ft_validator_error($valid,8);
     }
     $145 = ($139>>>0)<($lastBase$011>>>0);
     if ($145) {
      _ft_validator_error($valid,8);
     }
     $146 = (($143) + 1)|0;
     $147 = (($i$012) + 1)|0;
     $exitcond = ($147|0)==($121|0);
     if ($exitcond) {
      break;
     } else {
      $defp$013 = $140;$i$012 = $147;$lastBase$011 = $146;
     }
    }
   }
  }
  $148 = ($97|0)==(0);
  if (!($148)) {
   $$sum = (($97) + 4)|0;
   $149 = (($table) + ($$sum)|0);
   $150 = (($table) + ($97)|0);
   $151 = HEAP8[$150>>0]|0;
   $152 = $151&255;
   $153 = $152 << 24;
   $$sum2 = (($97) + 1)|0;
   $154 = (($table) + ($$sum2)|0);
   $155 = HEAP8[$154>>0]|0;
   $156 = $155&255;
   $157 = $156 << 16;
   $158 = $157 | $153;
   $$sum3 = (($97) + 2)|0;
   $159 = (($table) + ($$sum3)|0);
   $160 = HEAP8[$159>>0]|0;
   $161 = $160&255;
   $162 = $161 << 8;
   $163 = $158 | $162;
   $$sum4 = (($97) + 3)|0;
   $164 = (($table) + ($$sum4)|0);
   $165 = HEAP8[$164>>0]|0;
   $166 = $165&255;
   $167 = $163 | $166;
   $168 = $167 << 2;
   $169 = HEAP32[$37>>2]|0;
   $170 = $169;
   $171 = $149;
   $172 = (($170) - ($171))|0;
   $173 = ($168>>>0)>($172>>>0);
   if ($173) {
    _ft_validator_error($valid,8);
   }
   $174 = ($167|0)==(0);
   if (!($174)) {
    $i1$017 = 0;$lastUni$018 = 0;$ndp$016 = $149;
    while(1) {
     $175 = HEAP8[$ndp$016>>0]|0;
     $176 = $175&255;
     $177 = $176 << 16;
     $178 = (($ndp$016) + 1|0);
     $179 = HEAP8[$178>>0]|0;
     $180 = $179&255;
     $181 = $180 << 8;
     $182 = $181 | $177;
     $183 = (($ndp$016) + 2|0);
     $184 = HEAP8[$183>>0]|0;
     $185 = $184&255;
     $186 = $182 | $185;
     $187 = (($ndp$016) + 5|0);
     $188 = (($ndp$016) + 3|0);
     $189 = HEAP8[$188>>0]|0;
     $190 = $189&255;
     $191 = $190 << 8;
     $192 = (($ndp$016) + 4|0);
     $193 = HEAP8[$192>>0]|0;
     $194 = $193&255;
     $195 = $191 | $194;
     $196 = ($186>>>0)>(1114111);
     if ($196) {
      _ft_validator_error($valid,8);
     }
     $197 = ($186>>>0)<($lastUni$018>>>0);
     if ($197) {
      _ft_validator_error($valid,8);
     }
     $198 = (($186) + 1)|0;
     $199 = HEAP32[$47>>2]|0;
     $200 = ($199|0)==(0);
     if (!($200)) {
      $201 = HEAP32[$48>>2]|0;
      $202 = ($195>>>0)<($201>>>0);
      if (!($202)) {
       _ft_validator_error($valid,16);
      }
     }
     $203 = (($i1$017) + 1)|0;
     $exitcond25 = ($203|0)==($167|0);
     if ($exitcond25) {
      break;
     } else {
      $i1$017 = $203;$lastUni$018 = $198;$ndp$016 = $187;
     }
    }
   }
  }
  $204 = (($n$022) + 1)|0;
  $exitcond26 = ($204|0)==($36|0);
  if ($exitcond26) {
   break;
  } else {
   $lastVarSel$021 = $101;$n$022 = $204;$p$023 = $79;
  }
 }
 STACKTOP = sp;return 0;
}
function _tt_cmap14_get_info($cmap,$cmap_info) {
 $cmap = $cmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap_info) + 4|0);
 HEAP32[$0>>2] = 14;
 HEAP32[$cmap_info>>2] = -1;
 STACKTOP = sp;return 0;
}
function _FT_Destroy_Class_tt_cmap_classes($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($clazz|0)==(0|0);
 if (!($0)) {
  $1 = HEAP32[$library>>2]|0;
  _ft_mem_free($1,$clazz);
 }
 STACKTOP = sp;return;
}
function _FT_Create_Class_tt_cmap_classes($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $error = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,508,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($1) + 40|0);
 HEAP32[$4>>2] = 24;
 $5 = (($1) + 44|0);
 HEAP32[$5>>2] = 2654;
 $6 = (($1) + 48|0);
 HEAP32[$6>>2] = 0;
 $7 = (($1) + 52|0);
 HEAP32[$7>>2] = 2655;
 $8 = (($1) + 56|0);
 HEAP32[$8>>2] = 2656;
 $9 = (($1) + 60|0);
 $10 = (($1) + 84|0);
 ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;HEAP32[$9+20>>2]=0|0;
 HEAP32[$10>>2] = 2657;
 $11 = (($1) + 88|0);
 HEAP32[$11>>2] = 2658;
 HEAP32[$1>>2] = $4;
 $12 = (($1) + 92|0);
 HEAP32[$12>>2] = 24;
 $13 = (($1) + 96|0);
 HEAP32[$13>>2] = 2654;
 $14 = (($1) + 100|0);
 HEAP32[$14>>2] = 0;
 $15 = (($1) + 104|0);
 HEAP32[$15>>2] = 2659;
 $16 = (($1) + 108|0);
 HEAP32[$16>>2] = 2660;
 $17 = (($1) + 112|0);
 $18 = (($1) + 132|0);
 ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;HEAP32[$17+16>>2]=0|0;
 HEAP32[$18>>2] = 2;
 $19 = (($1) + 136|0);
 HEAP32[$19>>2] = 2661;
 $20 = (($1) + 140|0);
 HEAP32[$20>>2] = 2662;
 $21 = (($1) + 4|0);
 HEAP32[$21>>2] = $12;
 $22 = (($1) + 144|0);
 HEAP32[$22>>2] = 56;
 $23 = (($1) + 148|0);
 HEAP32[$23>>2] = 2663;
 $24 = (($1) + 152|0);
 HEAP32[$24>>2] = 0;
 $25 = (($1) + 156|0);
 HEAP32[$25>>2] = 2664;
 $26 = (($1) + 160|0);
 HEAP32[$26>>2] = 2665;
 $27 = (($1) + 164|0);
 $28 = (($1) + 184|0);
 ;HEAP32[$27+0>>2]=0|0;HEAP32[$27+4>>2]=0|0;HEAP32[$27+8>>2]=0|0;HEAP32[$27+12>>2]=0|0;HEAP32[$27+16>>2]=0|0;
 HEAP32[$28>>2] = 4;
 $29 = (($1) + 188|0);
 HEAP32[$29>>2] = 2666;
 $30 = (($1) + 192|0);
 HEAP32[$30>>2] = 2667;
 $31 = (($1) + 8|0);
 HEAP32[$31>>2] = $22;
 $32 = (($1) + 196|0);
 HEAP32[$32>>2] = 24;
 $33 = (($1) + 200|0);
 HEAP32[$33>>2] = 2654;
 $34 = (($1) + 204|0);
 HEAP32[$34>>2] = 0;
 $35 = (($1) + 208|0);
 HEAP32[$35>>2] = 2668;
 $36 = (($1) + 212|0);
 HEAP32[$36>>2] = 2669;
 $37 = (($1) + 216|0);
 $38 = (($1) + 236|0);
 ;HEAP32[$37+0>>2]=0|0;HEAP32[$37+4>>2]=0|0;HEAP32[$37+8>>2]=0|0;HEAP32[$37+12>>2]=0|0;HEAP32[$37+16>>2]=0|0;
 HEAP32[$38>>2] = 6;
 $39 = (($1) + 240|0);
 HEAP32[$39>>2] = 2670;
 $40 = (($1) + 244|0);
 HEAP32[$40>>2] = 2671;
 $41 = (($1) + 12|0);
 HEAP32[$41>>2] = $32;
 $42 = (($1) + 248|0);
 HEAP32[$42>>2] = 24;
 $43 = (($1) + 252|0);
 HEAP32[$43>>2] = 2654;
 $44 = (($1) + 256|0);
 HEAP32[$44>>2] = 0;
 $45 = (($1) + 260|0);
 HEAP32[$45>>2] = 2672;
 $46 = (($1) + 264|0);
 HEAP32[$46>>2] = 2673;
 $47 = (($1) + 268|0);
 $48 = (($1) + 288|0);
 ;HEAP32[$47+0>>2]=0|0;HEAP32[$47+4>>2]=0|0;HEAP32[$47+8>>2]=0|0;HEAP32[$47+12>>2]=0|0;HEAP32[$47+16>>2]=0|0;
 HEAP32[$48>>2] = 8;
 $49 = (($1) + 292|0);
 HEAP32[$49>>2] = 2674;
 $50 = (($1) + 296|0);
 HEAP32[$50>>2] = 2675;
 $51 = (($1) + 16|0);
 HEAP32[$51>>2] = $42;
 $52 = (($1) + 300|0);
 HEAP32[$52>>2] = 24;
 $53 = (($1) + 304|0);
 HEAP32[$53>>2] = 2654;
 $54 = (($1) + 308|0);
 HEAP32[$54>>2] = 0;
 $55 = (($1) + 312|0);
 HEAP32[$55>>2] = 2676;
 $56 = (($1) + 316|0);
 HEAP32[$56>>2] = 2677;
 $57 = (($1) + 320|0);
 $58 = (($1) + 340|0);
 ;HEAP32[$57+0>>2]=0|0;HEAP32[$57+4>>2]=0|0;HEAP32[$57+8>>2]=0|0;HEAP32[$57+12>>2]=0|0;HEAP32[$57+16>>2]=0|0;
 HEAP32[$58>>2] = 10;
 $59 = (($1) + 344|0);
 HEAP32[$59>>2] = 2678;
 $60 = (($1) + 348|0);
 HEAP32[$60>>2] = 2679;
 $61 = (($1) + 20|0);
 HEAP32[$61>>2] = $52;
 $62 = (($1) + 352|0);
 HEAP32[$62>>2] = 44;
 $63 = (($1) + 356|0);
 HEAP32[$63>>2] = 2680;
 $64 = (($1) + 360|0);
 HEAP32[$64>>2] = 0;
 $65 = (($1) + 364|0);
 HEAP32[$65>>2] = 2681;
 $66 = (($1) + 368|0);
 HEAP32[$66>>2] = 2682;
 $67 = (($1) + 372|0);
 $68 = (($1) + 392|0);
 ;HEAP32[$67+0>>2]=0|0;HEAP32[$67+4>>2]=0|0;HEAP32[$67+8>>2]=0|0;HEAP32[$67+12>>2]=0|0;HEAP32[$67+16>>2]=0|0;
 HEAP32[$68>>2] = 12;
 $69 = (($1) + 396|0);
 HEAP32[$69>>2] = 2683;
 $70 = (($1) + 400|0);
 HEAP32[$70>>2] = 2684;
 $71 = (($1) + 24|0);
 HEAP32[$71>>2] = $62;
 $72 = (($1) + 404|0);
 HEAP32[$72>>2] = 44;
 $73 = (($1) + 408|0);
 HEAP32[$73>>2] = 2685;
 $74 = (($1) + 412|0);
 HEAP32[$74>>2] = 0;
 $75 = (($1) + 416|0);
 HEAP32[$75>>2] = 2686;
 $76 = (($1) + 420|0);
 HEAP32[$76>>2] = 2687;
 $77 = (($1) + 424|0);
 $78 = (($1) + 444|0);
 ;HEAP32[$77+0>>2]=0|0;HEAP32[$77+4>>2]=0|0;HEAP32[$77+8>>2]=0|0;HEAP32[$77+12>>2]=0|0;HEAP32[$77+16>>2]=0|0;
 HEAP32[$78>>2] = 13;
 $79 = (($1) + 448|0);
 HEAP32[$79>>2] = 2688;
 $80 = (($1) + 452|0);
 HEAP32[$80>>2] = 2689;
 $81 = (($1) + 28|0);
 HEAP32[$81>>2] = $72;
 $82 = (($1) + 456|0);
 HEAP32[$82>>2] = 40;
 $83 = (($1) + 460|0);
 HEAP32[$83>>2] = 2690;
 $84 = (($1) + 464|0);
 HEAP32[$84>>2] = 3744;
 $85 = (($1) + 468|0);
 HEAP32[$85>>2] = 2691;
 $86 = (($1) + 472|0);
 HEAP32[$86>>2] = 2692;
 $87 = (($1) + 476|0);
 HEAP32[$87>>2] = 287;
 $88 = (($1) + 480|0);
 HEAP32[$88>>2] = 1608;
 $89 = (($1) + 484|0);
 HEAP32[$89>>2] = 2693;
 $90 = (($1) + 488|0);
 HEAP32[$90>>2] = 1609;
 $91 = (($1) + 492|0);
 HEAP32[$91>>2] = 1610;
 $92 = (($1) + 496|0);
 HEAP32[$92>>2] = 14;
 $93 = (($1) + 500|0);
 HEAP32[$93>>2] = 2694;
 $94 = (($1) + 504|0);
 HEAP32[$94>>2] = 2695;
 $95 = (($1) + 32|0);
 HEAP32[$95>>2] = $82;
 $96 = (($1) + 36|0);
 HEAP32[$96>>2] = 0;
 HEAP32[$output_class>>2] = $1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _tt_face_build_cmaps($face) {
 $face = $face|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $charmap = 0, $clazz = 0;
 var $cmap = 0, $error = 0, $format = 0, $num_cmaps = 0, $p = 0, $pclazz = 0, $ttcmap = 0, $valid = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $num_cmaps = sp + 68|0;
 $p = sp + 64|0;
 $charmap = sp + 52|0;
 $cmap = sp + 48|0;
 $format = sp + 44|0;
 $pclazz = sp + 40|0;
 $clazz = sp + 32|0;
 $valid = sp + 8|0;
 $error = sp;
 $ttcmap = sp + 36|0;
 $0 = (($face) + 500|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 504|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3)|0);
 HEAP32[$p>>2] = $1;
 $5 = (($face) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$p>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 8;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$p>>2]|0;
 $12 = (($11) + 4|0);
 $13 = ($12>>>0)>($4>>>0);
 if ($13) {
  $$0 = 8;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = HEAP32[$p>>2]|0;
 $15 = (($14) + 2|0);
 HEAP32[$p>>2] = $15;
 $16 = HEAP32[$p>>2]|0;
 $17 = (($16) + -2|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = $19 << 8;
 $21 = HEAP32[$p>>2]|0;
 $22 = (($21) + -1|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 | $20;
 $26 = ($25|0)==(0);
 $27 = HEAP32[$p>>2]|0;
 if (!($26)) {
  $28 = (($27) + -2|0);
  HEAP32[$p>>2] = $28;
  $$0 = 8;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($27) + 2|0);
 HEAP32[$p>>2] = $29;
 $30 = HEAP32[$p>>2]|0;
 $31 = (($30) + -2|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = $33 << 8;
 $35 = HEAP32[$p>>2]|0;
 $36 = (($35) + -1|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = $37&255;
 $39 = $38 | $34;
 HEAP32[$num_cmaps>>2] = $39;
 $40 = HEAP32[$num_cmaps>>2]|0;
 $41 = HEAP32[$num_cmaps>>2]|0;
 $42 = ($41|0)==(0);
 if ($42) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = (($charmap) + 8|0);
 $44 = (($charmap) + 10|0);
 $45 = (($charmap) + 4|0);
 $46 = (($8) + 220|0);
 $47 = (($face) + 264|0);
 $48 = (($valid) + 20|0);
 $49 = (($valid) + 12|0);
 while(1) {
  $50 = HEAP32[$p>>2]|0;
  $51 = (($50) + 8|0);
  $52 = ($51>>>0)>($4>>>0);
  if ($52) {
   $$0 = 0;
   label = 18;
   break;
  }
  $53 = HEAP32[$p>>2]|0;
  $54 = (($53) + 2|0);
  HEAP32[$p>>2] = $54;
  $55 = HEAP32[$p>>2]|0;
  $56 = (($55) + -2|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57&255;
  $59 = $58 << 8;
  $60 = HEAP32[$p>>2]|0;
  $61 = (($60) + -1|0);
  $62 = HEAP8[$61>>0]|0;
  $63 = $62&255;
  $64 = $63 | $59;
  $65 = $64&65535;
  HEAP16[$43>>1] = $65;
  $66 = HEAP32[$p>>2]|0;
  $67 = (($66) + 2|0);
  HEAP32[$p>>2] = $67;
  $68 = HEAP32[$p>>2]|0;
  $69 = (($68) + -2|0);
  $70 = HEAP8[$69>>0]|0;
  $71 = $70&255;
  $72 = $71 << 8;
  $73 = HEAP32[$p>>2]|0;
  $74 = (($73) + -1|0);
  $75 = HEAP8[$74>>0]|0;
  $76 = $75&255;
  $77 = $76 | $72;
  $78 = $77&65535;
  HEAP16[$44>>1] = $78;
  HEAP32[$charmap>>2] = $face;
  HEAP32[$45>>2] = 0;
  $79 = HEAP32[$p>>2]|0;
  $80 = (($79) + 4|0);
  HEAP32[$p>>2] = $80;
  $81 = HEAP32[$p>>2]|0;
  $82 = (($81) + -4|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = $83&255;
  $85 = $84 << 24;
  $86 = HEAP32[$p>>2]|0;
  $87 = (($86) + -3|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = $88&255;
  $90 = $89 << 16;
  $91 = $90 | $85;
  $92 = HEAP32[$p>>2]|0;
  $93 = (($92) + -2|0);
  $94 = HEAP8[$93>>0]|0;
  $95 = $94&255;
  $96 = $95 << 8;
  $97 = $91 | $96;
  $98 = HEAP32[$p>>2]|0;
  $99 = (($98) + -1|0);
  $100 = HEAP8[$99>>0]|0;
  $101 = $100&255;
  $102 = $97 | $101;
  $103 = ($102|0)==(0);
  if (!($103)) {
   $104 = HEAP32[$2>>2]|0;
   $105 = (($104) + -2)|0;
   $106 = ($102>>>0)>($105>>>0);
   if (!($106)) {
    $107 = (($1) + ($102)|0);
    HEAP32[$cmap>>2] = $107;
    $108 = HEAP32[$cmap>>2]|0;
    $109 = HEAP8[$108>>0]|0;
    $110 = $109&255;
    $111 = $110 << 8;
    $112 = HEAP32[$cmap>>2]|0;
    $113 = (($112) + 1|0);
    $114 = HEAP8[$113>>0]|0;
    $115 = $114&255;
    $116 = $115 | $111;
    HEAP32[$format>>2] = $116;
    $117 = HEAP32[$46>>2]|0;
    $118 = (($117) + 20|0);
    $119 = HEAP32[$118>>2]|0;
    HEAP32[$pclazz>>2] = $119;
    $120 = HEAP32[$pclazz>>2]|0;
    $121 = HEAP32[$120>>2]|0;
    $122 = ($121|0)==(0|0);
    L20: do {
     if (!($122)) {
      while(1) {
       $123 = HEAP32[$pclazz>>2]|0;
       $124 = HEAP32[$123>>2]|0;
       HEAP32[$clazz>>2] = $124;
       $125 = HEAP32[$clazz>>2]|0;
       $126 = (($125) + 40|0);
       $127 = HEAP32[$126>>2]|0;
       $128 = HEAP32[$format>>2]|0;
       $129 = ($127|0)==($128|0);
       if ($129) {
        break;
       }
       $147 = HEAP32[$pclazz>>2]|0;
       $148 = (($147) + 4|0);
       HEAP32[$pclazz>>2] = $148;
       $149 = HEAP32[$pclazz>>2]|0;
       $150 = HEAP32[$149>>2]|0;
       $151 = ($150|0)==(0|0);
       if ($151) {
        break L20;
       }
      }
      HEAP32[$error>>2] = 0;
      $130 = HEAP32[$cmap>>2]|0;
      _ft_validator_init($valid,$130,$4,0);
      $131 = HEAP16[$47>>1]|0;
      $132 = $131&65535;
      HEAP32[$48>>2] = $132;
      $133 = HEAP32[$clazz>>2]|0;
      $134 = (($133) + 44|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = HEAP32[$cmap>>2]|0;
      $137 = (FUNCTION_TABLE_iii[$135 & 4095]($136,$valid)|0);
      HEAP32[$error>>2] = $137;
      $138 = HEAP32[$49>>2]|0;
      $139 = ($138|0)==(0);
      if ($139) {
       $140 = HEAP32[$clazz>>2]|0;
       $141 = HEAP32[$cmap>>2]|0;
       $142 = (_FT_CMap_New($140,$141,$charmap,$ttcmap)|0);
       $143 = ($142|0)==(0);
       if ($143) {
        $144 = HEAP32[$error>>2]|0;
        $145 = HEAP32[$ttcmap>>2]|0;
        $146 = (($145) + 20|0);
        HEAP32[$146>>2] = $144;
       }
      }
     }
    } while(0);
    $152 = HEAP32[$pclazz>>2]|0;
   }
  }
  $153 = HEAP32[$num_cmaps>>2]|0;
  $154 = (($153) + -1)|0;
  HEAP32[$num_cmaps>>2] = $154;
  $155 = HEAP32[$num_cmaps>>2]|0;
  $156 = ($155|0)==(0);
  if ($156) {
   $$0 = 0;
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _tt_get_cmap_info($charmap,$cmap_info) {
 $charmap = $charmap|0;
 $cmap_info = $cmap_info|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($charmap) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iii[$3 & 4095]($charmap,$cmap_info)|0);
 STACKTOP = sp;return ($4|0);
}
function _tt_cmap14_get_def_chars($cmap,$p,$memory) {
 $cmap = $cmap|0;
 $p = $p|0;
 $memory = $memory|0;
 var $$0 = 0, $$01$i = 0, $$017 = 0, $$pre = 0, $$pre$phi11Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $cnt$0 = 0, $error$i = 0, $numRanges$02$i = 0, $numRanges$05 = 0, $p$pn = 0, $phitmp = 0, $q$0$lcssa = 0, $q$06 = 0, $q$1 = 0, $scevgep$sum = 0, $scevgep9 = 0, $tot$0$lcssa$i = 0, $tot$03$i = 0, $uni$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp;
 $0 = HEAP8[$p>>0]|0;
 $1 = $0&255;
 $2 = $1 << 24;
 $3 = (($p) + 1|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = $5 << 16;
 $7 = $6 | $2;
 $8 = (($p) + 2|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 << 8;
 $12 = $7 | $11;
 $13 = (($p) + 3|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $12 | $15;
 $17 = ($16|0)==(0);
 if ($17) {
  $tot$0$lcssa$i = 1;
 } else {
  $18 = (($p) + 7|0);
  $$01$i = $18;$numRanges$02$i = $16;$tot$03$i = 0;
  while(1) {
   $19 = HEAP8[$$01$i>>0]|0;
   $20 = $19&255;
   $21 = (($tot$03$i) + 1)|0;
   $22 = (($21) + ($20))|0;
   $23 = (($$01$i) + 4|0);
   $24 = (($numRanges$02$i) + -1)|0;
   $25 = ($24|0)==(0);
   if ($25) {
    break;
   } else {
    $$01$i = $23;$numRanges$02$i = $24;$tot$03$i = $22;
   }
  }
  $phitmp = (($22) + 1)|0;
  $tot$0$lcssa$i = $phitmp;
 }
 $26 = (($cmap) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$error$i>>2] = 0;
 $28 = ($27>>>0)<($tot$0$lcssa$i>>>0);
 do {
  if ($28) {
   $29 = (($cmap) + 36|0);
   HEAP32[$29>>2] = $memory;
   $30 = (($cmap) + 32|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (_ft_mem_realloc($memory,4,$27,$tot$0$lcssa$i,$31,$error$i)|0);
   HEAP32[$30>>2] = $32;
   $33 = HEAP32[$error$i>>2]|0;
   $34 = ($33|0)==(0);
   if ($34) {
    HEAP32[$26>>2] = $tot$0$lcssa$i;
    $$pre$phi11Z2D = $30;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $$pre = (($cmap) + 32|0);
   $$pre$phi11Z2D = $$pre;
  }
 } while(0);
 $35 = HEAP32[$$pre$phi11Z2D>>2]|0;
 if ($17) {
  $q$0$lcssa = $35;
 } else {
  $numRanges$05 = $16;$p$pn = $p;$q$06 = $35;
  while(1) {
   $$017 = (($p$pn) + 4|0);
   $36 = (($p$pn) + 7|0);
   $37 = HEAP8[$$017>>0]|0;
   $38 = $37&255;
   $39 = $38 << 16;
   $40 = (($p$pn) + 5|0);
   $41 = HEAP8[$40>>0]|0;
   $42 = $41&255;
   $43 = $42 << 8;
   $44 = $43 | $39;
   $45 = (($p$pn) + 6|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = $46&255;
   $48 = $44 | $47;
   $49 = HEAP8[$36>>0]|0;
   $50 = $49&255;
   $51 = (($50) + 1)|0;
   $cnt$0 = $51;$q$1 = $q$06;$uni$0 = $48;
   while(1) {
    HEAP32[$q$1>>2] = $uni$0;
    $52 = (($uni$0) + 1)|0;
    $53 = (($q$1) + 4|0);
    $54 = (($cnt$0) + -1)|0;
    $55 = ($54|0)==(0);
    if ($55) {
     break;
    } else {
     $cnt$0 = $54;$q$1 = $53;$uni$0 = $52;
    }
   }
   $scevgep$sum = (($50) + 1)|0;
   $scevgep9 = (($q$06) + ($scevgep$sum<<2)|0);
   $56 = (($numRanges$05) + -1)|0;
   $57 = ($56|0)==(0);
   if ($57) {
    $q$0$lcssa = $scevgep9;
    break;
   } else {
    $numRanges$05 = $56;$p$pn = $$017;$q$06 = $scevgep9;
   }
  }
 }
 HEAP32[$q$0$lcssa>>2] = 0;
 $$0 = $35;
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap13_next($cmap) {
 $cmap = $cmap|0;
 var $$char_code$0 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $char_code$016 = 0, $n$015 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 L1: do {
  if (!($2)) {
   $3 = (($cmap) + 36|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($cmap) + 40|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   if ($7) {
    $8 = (($1) + 1)|0;
    $9 = (($cmap) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $char_code$016 = $8;$n$015 = $4;
    while(1) {
     $13 = ($n$015*12)|0;
     $$sum2 = (($13) + 16)|0;
     $14 = (($10) + ($$sum2)|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = $15&255;
     $17 = $16 << 24;
     $$sum3 = (($13) + 17)|0;
     $18 = (($10) + ($$sum3)|0);
     $19 = HEAP8[$18>>0]|0;
     $20 = $19&255;
     $21 = $20 << 16;
     $22 = $21 | $17;
     $$sum4 = (($13) + 18)|0;
     $23 = (($10) + ($$sum4)|0);
     $24 = HEAP8[$23>>0]|0;
     $25 = $24&255;
     $26 = $25 << 8;
     $27 = $22 | $26;
     $$sum5 = (($13) + 19)|0;
     $28 = (($10) + ($$sum5)|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = $29&255;
     $31 = $27 | $30;
     $$sum6 = (($13) + 24)|0;
     $32 = (($10) + ($$sum6)|0);
     $$sum7 = (($13) + 20)|0;
     $33 = (($10) + ($$sum7)|0);
     $34 = HEAP8[$33>>0]|0;
     $35 = $34&255;
     $36 = $35 << 24;
     $$sum8 = (($13) + 21)|0;
     $37 = (($10) + ($$sum8)|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = $38&255;
     $40 = $39 << 16;
     $41 = $40 | $36;
     $$sum9 = (($13) + 22)|0;
     $42 = (($10) + ($$sum9)|0);
     $43 = HEAP8[$42>>0]|0;
     $44 = $43&255;
     $45 = $44 << 8;
     $46 = $41 | $45;
     $$sum10 = (($13) + 23)|0;
     $47 = (($10) + ($$sum10)|0);
     $48 = HEAP8[$47>>0]|0;
     $49 = $48&255;
     $50 = $46 | $49;
     $51 = HEAP8[$32>>0]|0;
     $52 = $51&255;
     $53 = $52 << 24;
     $$sum11 = (($13) + 25)|0;
     $54 = (($10) + ($$sum11)|0);
     $55 = HEAP8[$54>>0]|0;
     $56 = $55&255;
     $57 = $56 << 16;
     $58 = $57 | $53;
     $$sum12 = (($13) + 26)|0;
     $59 = (($10) + ($$sum12)|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60&255;
     $62 = $61 << 8;
     $63 = $58 | $62;
     $$sum13 = (($13) + 27)|0;
     $64 = (($10) + ($$sum13)|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = $65&255;
     $67 = $63 | $66;
     $68 = ($char_code$016>>>0)<($31>>>0);
     $$char_code$0 = $68 ? $31 : $char_code$016;
     $69 = ($$char_code$0>>>0)>($50>>>0);
     $70 = ($67|0)==(0);
     $or$cond = $69 | $70;
     $12 = (($n$015) + 1)|0;
     if (!($or$cond)) {
      break;
     }
     $11 = ($12>>>0)<($6>>>0);
     if ($11) {
      $char_code$016 = $$char_code$0;$n$015 = $12;
     } else {
      break L1;
     }
    }
    HEAP32[$0>>2] = $$char_code$0;
    $71 = (($cmap) + 32|0);
    HEAP32[$71>>2] = $67;
    HEAP32[$3>>2] = $n$015;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $72 = (($cmap) + 24|0);
 HEAP8[$72>>0] = 0;
 STACKTOP = sp;return;
}
function _tt_cmap13_char_map_binary($cmap,$pchar_code,$next) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 $next = $next|0;
 var $$ = 0, $$0 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $gindex$0 = 0, $gindex$1 = 0, $max$0$ph35 = 0, $mid$2 = 0, $mid$2$c = 0, $min$0$ph36 = 0;
 var $min$029 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = (($1) + 13|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = (($1) + 14|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = (($1) + 15|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ($19|0)==(0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = HEAP32[$pchar_code>>2]|0;
 $22 = ($next<<24>>24)!=(0);
 $23 = $22&1;
 $$ = (($21) + ($23))|0;
 $max$0$ph35 = $19;$min$0$ph36 = 0;
 L4: while(1) {
  $min$029 = $min$0$ph36;
  while(1) {
   $28 = (($min$029) + ($max$0$ph35))|0;
   $25 = $28 >>> 1;
   $29 = ($25*12)|0;
   $$sum2 = (($29) + 16)|0;
   $30 = (($1) + ($$sum2)|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = $31&255;
   $33 = $32 << 24;
   $$sum3 = (($29) + 17)|0;
   $34 = (($1) + ($$sum3)|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = $36 << 16;
   $38 = $37 | $33;
   $$sum4 = (($29) + 18)|0;
   $39 = (($1) + ($$sum4)|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40&255;
   $42 = $41 << 8;
   $43 = $38 | $42;
   $$sum5 = (($29) + 19)|0;
   $44 = (($1) + ($$sum5)|0);
   $45 = HEAP8[$44>>0]|0;
   $46 = $45&255;
   $47 = $43 | $46;
   $$sum6 = (($29) + 24)|0;
   $$sum7 = (($29) + 20)|0;
   $48 = (($1) + ($$sum7)|0);
   $49 = HEAP8[$48>>0]|0;
   $50 = $49&255;
   $51 = $50 << 24;
   $$sum8 = (($29) + 21)|0;
   $52 = (($1) + ($$sum8)|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = $53&255;
   $55 = $54 << 16;
   $56 = $55 | $51;
   $$sum9 = (($29) + 22)|0;
   $57 = (($1) + ($$sum9)|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = $58&255;
   $60 = $59 << 8;
   $61 = $56 | $60;
   $$sum10 = (($29) + 23)|0;
   $62 = (($1) + ($$sum10)|0);
   $63 = HEAP8[$62>>0]|0;
   $64 = $63&255;
   $65 = $61 | $64;
   $66 = ($$>>>0)<($47>>>0);
   if ($66) {
    break;
   }
   $67 = ($$>>>0)>($65>>>0);
   $27 = (($25) + 1)|0;
   if (!($67)) {
    label = 8;
    break L4;
   }
   $26 = ($27>>>0)<($max$0$ph35>>>0);
   if ($26) {
    $min$029 = $27;
   } else {
    $gindex$0 = 0;
    break L4;
   }
  }
  $24 = ($min$029>>>0)<($25>>>0);
  if ($24) {
   $max$0$ph35 = $25;$min$0$ph36 = $min$029;
  } else {
   $gindex$0 = 0;
   break;
  }
 }
 if ((label|0) == 8) {
  $68 = (($1) + ($$sum6)|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = $69&255;
  $71 = $70 << 24;
  $$sum11 = (($29) + 25)|0;
  $72 = (($1) + ($$sum11)|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = $73&255;
  $75 = $74 << 16;
  $76 = $75 | $71;
  $$sum12 = (($29) + 26)|0;
  $77 = (($1) + ($$sum12)|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = $78&255;
  $80 = $79 << 8;
  $81 = $76 | $80;
  $$sum13 = (($29) + 27)|0;
  $82 = (($1) + ($$sum13)|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = $83&255;
  $85 = $81 | $84;
  $gindex$0 = $85;
 }
 if (!($22)) {
  $$0 = $gindex$0;
  STACKTOP = sp;return ($$0|0);
 }
 $86 = ($$>>>0)>($65>>>0);
 if ($86) {
  $87 = (($25) + 1)|0;
  $88 = ($87|0)==($19|0);
  if ($88) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $mid$2 = $87;
  }
 } else {
  $mid$2 = $25;
 }
 $89 = (($cmap) + 24|0);
 HEAP8[$89>>0] = 1;
 $90 = (($cmap) + 28|0);
 HEAP32[$90>>2] = $$;
 $91 = (($cmap) + 36|0);
 $mid$2$c = $mid$2;
 HEAP32[$91>>2] = $mid$2$c;
 $92 = ($gindex$0|0)==(0);
 do {
  if ($92) {
   _tt_cmap13_next($cmap);
   $93 = HEAP8[$89>>0]|0;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $95 = (($cmap) + 32|0);
    $96 = HEAP32[$95>>2]|0;
    $gindex$1 = $96;
    break;
   }
  } else {
   $97 = (($cmap) + 32|0);
   HEAP32[$97>>2] = $gindex$0;
   $gindex$1 = $gindex$0;
  }
 } while(0);
 $98 = ($gindex$1|0)==(0);
 if ($98) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $99 = HEAP32[$90>>2]|0;
 HEAP32[$pchar_code>>2] = $99;
 $$0 = $gindex$1;
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap12_next($cmap) {
 $cmap = $cmap|0;
 var $$char_code$0 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $char_code$020 = 0, $char_code$1$lcssa = 0, $char_code$115 = 0, $n$018 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 L1: do {
  if (!($2)) {
   $3 = (($cmap) + 36|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($cmap) + 40|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   if ($7) {
    $8 = (($1) + 1)|0;
    $9 = (($cmap) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $char_code$020 = $8;$n$018 = $4;
    L4: while(1) {
     $11 = ($n$018*12)|0;
     $$sum2 = (($11) + 16)|0;
     $12 = (($10) + ($$sum2)|0);
     $13 = HEAP8[$12>>0]|0;
     $14 = $13&255;
     $15 = $14 << 24;
     $$sum3 = (($11) + 17)|0;
     $16 = (($10) + ($$sum3)|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = $17&255;
     $19 = $18 << 16;
     $20 = $19 | $15;
     $$sum4 = (($11) + 18)|0;
     $21 = (($10) + ($$sum4)|0);
     $22 = HEAP8[$21>>0]|0;
     $23 = $22&255;
     $24 = $23 << 8;
     $25 = $20 | $24;
     $$sum5 = (($11) + 19)|0;
     $26 = (($10) + ($$sum5)|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = $27&255;
     $29 = $25 | $28;
     $$sum6 = (($11) + 24)|0;
     $30 = (($10) + ($$sum6)|0);
     $$sum7 = (($11) + 20)|0;
     $31 = (($10) + ($$sum7)|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = $32&255;
     $34 = $33 << 24;
     $$sum8 = (($11) + 21)|0;
     $35 = (($10) + ($$sum8)|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = $36&255;
     $38 = $37 << 16;
     $39 = $38 | $34;
     $$sum9 = (($11) + 22)|0;
     $40 = (($10) + ($$sum9)|0);
     $41 = HEAP8[$40>>0]|0;
     $42 = $41&255;
     $43 = $42 << 8;
     $44 = $39 | $43;
     $$sum10 = (($11) + 23)|0;
     $45 = (($10) + ($$sum10)|0);
     $46 = HEAP8[$45>>0]|0;
     $47 = $46&255;
     $48 = $44 | $47;
     $49 = HEAP8[$30>>0]|0;
     $50 = $49&255;
     $51 = $50 << 24;
     $$sum11 = (($11) + 25)|0;
     $52 = (($10) + ($$sum11)|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = $53&255;
     $55 = $54 << 16;
     $56 = $55 | $51;
     $$sum12 = (($11) + 26)|0;
     $57 = (($10) + ($$sum12)|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = $58&255;
     $60 = $59 << 8;
     $61 = $56 | $60;
     $$sum13 = (($11) + 27)|0;
     $62 = (($10) + ($$sum13)|0);
     $63 = HEAP8[$62>>0]|0;
     $64 = $63&255;
     $65 = $61 | $64;
     $66 = ($char_code$020>>>0)<($29>>>0);
     $$char_code$0 = $66 ? $29 : $char_code$020;
     $67 = ($$char_code$0>>>0)>($48>>>0);
     if ($67) {
      $char_code$1$lcssa = $$char_code$0;
     } else {
      $char_code$115 = $$char_code$0;
      while(1) {
       $70 = (($char_code$115) + ($65))|0;
       $71 = ($70|0)==($29|0);
       $69 = (($char_code$115) + 1)|0;
       if (!($71)) {
        break L4;
       }
       $68 = ($69>>>0)>($48>>>0);
       if ($68) {
        $char_code$1$lcssa = $69;
        break;
       } else {
        $char_code$115 = $69;
       }
      }
     }
     $74 = (($n$018) + 1)|0;
     $75 = ($74>>>0)<($6>>>0);
     if ($75) {
      $char_code$020 = $char_code$1$lcssa;$n$018 = $74;
     } else {
      break L1;
     }
    }
    $72 = (($70) - ($29))|0;
    HEAP32[$0>>2] = $char_code$115;
    $73 = (($cmap) + 32|0);
    HEAP32[$73>>2] = $72;
    HEAP32[$3>>2] = $n$018;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $76 = (($cmap) + 24|0);
 HEAP8[$76>>0] = 0;
 STACKTOP = sp;return;
}
function _tt_cmap12_char_map_binary($cmap,$pchar_code,$next) {
 $cmap = $cmap|0;
 $pchar_code = $pchar_code|0;
 $next = $next|0;
 var $$ = 0, $$0 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $gindex$0 = 0, $gindex$1 = 0, $max$0$ph37 = 0, $mid$2 = 0;
 var $mid$2$c = 0, $min$0$ph38 = 0, $min$031 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 24;
 $6 = (($1) + 13|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 << 16;
 $10 = $9 | $5;
 $11 = (($1) + 14|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = $12&255;
 $14 = $13 << 8;
 $15 = $10 | $14;
 $16 = (($1) + 15|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $15 | $18;
 $20 = ($19|0)==(0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = HEAP32[$pchar_code>>2]|0;
 $22 = ($next<<24>>24)!=(0);
 $23 = $22&1;
 $$ = (($21) + ($23))|0;
 $max$0$ph37 = $19;$min$0$ph38 = 0;
 L4: while(1) {
  $min$031 = $min$0$ph38;
  while(1) {
   $28 = (($min$031) + ($max$0$ph37))|0;
   $25 = $28 >>> 1;
   $29 = ($25*12)|0;
   $$sum2 = (($29) + 16)|0;
   $30 = (($1) + ($$sum2)|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = $31&255;
   $33 = $32 << 24;
   $$sum3 = (($29) + 17)|0;
   $34 = (($1) + ($$sum3)|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = $36 << 16;
   $38 = $37 | $33;
   $$sum4 = (($29) + 18)|0;
   $39 = (($1) + ($$sum4)|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40&255;
   $42 = $41 << 8;
   $43 = $38 | $42;
   $$sum5 = (($29) + 19)|0;
   $44 = (($1) + ($$sum5)|0);
   $45 = HEAP8[$44>>0]|0;
   $46 = $45&255;
   $47 = $43 | $46;
   $$sum6 = (($29) + 24)|0;
   $$sum7 = (($29) + 20)|0;
   $48 = (($1) + ($$sum7)|0);
   $49 = HEAP8[$48>>0]|0;
   $50 = $49&255;
   $51 = $50 << 24;
   $$sum8 = (($29) + 21)|0;
   $52 = (($1) + ($$sum8)|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = $53&255;
   $55 = $54 << 16;
   $56 = $55 | $51;
   $$sum9 = (($29) + 22)|0;
   $57 = (($1) + ($$sum9)|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = $58&255;
   $60 = $59 << 8;
   $61 = $56 | $60;
   $$sum10 = (($29) + 23)|0;
   $62 = (($1) + ($$sum10)|0);
   $63 = HEAP8[$62>>0]|0;
   $64 = $63&255;
   $65 = $61 | $64;
   $66 = ($$>>>0)<($47>>>0);
   if ($66) {
    break;
   }
   $67 = ($$>>>0)>($65>>>0);
   $27 = (($25) + 1)|0;
   if (!($67)) {
    label = 8;
    break L4;
   }
   $26 = ($27>>>0)<($max$0$ph37>>>0);
   if ($26) {
    $min$031 = $27;
   } else {
    $gindex$0 = 0;
    break L4;
   }
  }
  $24 = ($min$031>>>0)<($25>>>0);
  if ($24) {
   $max$0$ph37 = $25;$min$0$ph38 = $min$031;
  } else {
   $gindex$0 = 0;
   break;
  }
 }
 if ((label|0) == 8) {
  $68 = (($1) + ($$sum6)|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = $69&255;
  $71 = $70 << 24;
  $$sum11 = (($29) + 25)|0;
  $72 = (($1) + ($$sum11)|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = $73&255;
  $75 = $74 << 16;
  $76 = $75 | $71;
  $$sum12 = (($29) + 26)|0;
  $77 = (($1) + ($$sum12)|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = $78&255;
  $80 = $79 << 8;
  $81 = $76 | $80;
  $$sum13 = (($29) + 27)|0;
  $82 = (($1) + ($$sum13)|0);
  $83 = HEAP8[$82>>0]|0;
  $84 = $83&255;
  $85 = $81 | $84;
  $86 = (($$) - ($47))|0;
  $87 = (($86) + ($85))|0;
  $gindex$0 = $87;
 }
 if (!($22)) {
  $$0 = $gindex$0;
  STACKTOP = sp;return ($$0|0);
 }
 $88 = ($$>>>0)>($65>>>0);
 if ($88) {
  $89 = (($25) + 1)|0;
  $90 = ($89|0)==($19|0);
  if ($90) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $mid$2 = $89;
  }
 } else {
  $mid$2 = $25;
 }
 $91 = (($cmap) + 24|0);
 HEAP8[$91>>0] = 1;
 $92 = (($cmap) + 28|0);
 HEAP32[$92>>2] = $$;
 $93 = (($cmap) + 36|0);
 $mid$2$c = $mid$2;
 HEAP32[$93>>2] = $mid$2$c;
 $94 = ($gindex$0|0)==(0);
 do {
  if ($94) {
   _tt_cmap12_next($cmap);
   $95 = HEAP8[$91>>0]|0;
   $96 = ($95<<24>>24)==(0);
   if ($96) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $97 = (($cmap) + 32|0);
    $98 = HEAP32[$97>>2]|0;
    $gindex$1 = $98;
    break;
   }
  } else {
   $99 = (($cmap) + 32|0);
   HEAP32[$99>>2] = $gindex$0;
   $gindex$1 = $gindex$0;
  }
 } while(0);
 $100 = ($gindex$1|0)==(0);
 if ($100) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $101 = HEAP32[$92>>2]|0;
 HEAP32[$pchar_code>>2] = $101;
 $$0 = $gindex$1;
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap4_char_map_linear($cmap,$pcharcode,$next) {
 $cmap = $cmap|0;
 $pcharcode = $pcharcode|0;
 $next = $next|0;
 var $$ = 0, $$0 = 0, $$12$us = 0, $$13$us = 0, $$masked = 0, $$sum = 0, $$sum12 = 0, $$sum3 = 0, $$sum45 = 0, $$sum6$us = 0, $$sum7$us = 0, $$sum829 = 0, $$sum9$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $9 = 0, $charcode$024$us = 0, $delta$0$us = 0, $delta$016$us = 0, $gindex$1$us = 0, $i$021$us = 0, $offset$0$us = 0, $or$cond$us = 0, $or$cond10$us = 0, $or$cond11$us = 0, $or$cond14$us = 0, $or$cond15 = 0, $p$022$us = 0, $p$1$us = 0, $q$023$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 8;
 $6 = (($1) + 7|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $$masked = $8 & 254;
 $9 = $$masked | $5;
 $10 = $9 >>> 1;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[$pcharcode>>2]|0;
 $13 = ($next<<24>>24)!=(0);
 $14 = $13&1;
 $$ = (($12) + ($14))|0;
 $15 = ($$>>>0)<(65536);
 if (!($15)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = (($1) + 14|0);
 $$sum = (($9) + 16)|0;
 $17 = (($1) + ($$sum)|0);
 $$sum12 = $9 | 1;
 $$sum3 = $9 << 1;
 $$sum45 = $$sum3 | 1;
 $18 = (($10) + -1)|0;
 $$sum829 = $$sum3 | 2;
 $charcode$024$us = $$;
 while(1) {
  $i$021$us = 0;$p$022$us = $16;$q$023$us = $17;
  while(1) {
   $21 = (($p$022$us) + 2|0);
   $22 = HEAP8[$p$022$us>>0]|0;
   $23 = $22&255;
   $24 = $23 << 8;
   $25 = (($p$022$us) + 1|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = $26&255;
   $28 = $24 | $27;
   $29 = (($q$023$us) + 2|0);
   $30 = HEAP8[$q$023$us>>0]|0;
   $31 = $30&255;
   $32 = $31 << 8;
   $33 = (($q$023$us) + 1|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34&255;
   $36 = $32 | $35;
   $37 = ($charcode$024$us>>>0)<($36>>>0);
   $38 = ($charcode$024$us>>>0)>($28>>>0);
   $or$cond$us = $37 | $38;
   if ($or$cond$us) {
    $p$1$us = $21;
   } else {
    $39 = (($q$023$us) + ($9)|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = $40 << 24 >> 24;
    $42 = $41 << 8;
    $43 = (($q$023$us) + ($$sum12)|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = $44&255;
    $46 = $42 | $45;
    $47 = (($q$023$us) + ($$sum3)|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = $48&255;
    $50 = $49 << 8;
    $51 = (($q$023$us) + ($$sum45)|0);
    $52 = HEAP8[$51>>0]|0;
    $53 = $52&255;
    $54 = $50 | $53;
    $55 = ($i$021$us>>>0)>=($18>>>0);
    $56 = ($36|0)==(65535);
    $or$cond10$us = $55 & $56;
    $57 = ($28|0)==(65535);
    $or$cond11$us = $or$cond10$us & $57;
    if ($or$cond11$us) {
     $58 = HEAP32[$cmap>>2]|0;
     $59 = ($54|0)==(0);
     if ($59) {
      $delta$016$us = $46;
      label = 12;
      break;
     }
     $60 = (($58) + 504|0);
     $61 = (($58) + 500|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = HEAP32[$60>>2]|0;
     $64 = (($62) + ($63)|0);
     $$sum9$us = (($$sum829) + ($54))|0;
     $65 = (($q$023$us) + ($$sum9$us)|0);
     $66 = ($65>>>0)>($64>>>0);
     $$12$us = $66 ? 1 : $46;
     $$13$us = $66 ? 0 : $54;
     $delta$0$us = $$12$us;$offset$0$us = $$13$us;
    } else {
     $delta$0$us = $46;$offset$0$us = $54;
    }
    if ((($offset$0$us|0) == 0)) {
     $delta$016$us = $delta$0$us;
     label = 12;
     break;
    } else if ((($offset$0$us|0) == 65535)) {
     $p$1$us = $47;
    } else {
     label = 10;
     break;
    }
   }
   $84 = (($i$021$us) + 1)|0;
   $85 = ($84>>>0)<($10>>>0);
   if ($85) {
    $i$021$us = $84;$p$022$us = $p$1$us;$q$023$us = $29;
   } else {
    $gindex$1$us = 0;
    break;
   }
  }
  if ((label|0) == 10) {
   label = 0;
   $67 = (($charcode$024$us) - ($36))|0;
   $68 = $67 << 1;
   $69 = (($68) + ($$sum3))|0;
   $$sum6$us = (($69) + ($offset$0$us))|0;
   $70 = (($q$023$us) + ($$sum6$us)|0);
   $71 = HEAP8[$70>>0]|0;
   $72 = $71&255;
   $73 = $72 << 8;
   $$sum7$us = (($$sum6$us) + 1)|0;
   $74 = (($q$023$us) + ($$sum7$us)|0);
   $75 = HEAP8[$74>>0]|0;
   $76 = $75&255;
   $77 = $73 | $76;
   $78 = ($77|0)==(0);
   if ($78) {
    $gindex$1$us = 0;
   } else {
    $79 = (($77) + ($delta$0$us))|0;
    $80 = $79 & 65535;
    $gindex$1$us = $80;
   }
  }
  else if ((label|0) == 12) {
   label = 0;
   $81 = (($delta$016$us) + ($charcode$024$us))|0;
   $82 = $81 & 65535;
   $gindex$1$us = $82;
  }
  $83 = ($gindex$1$us|0)==(0);
  $or$cond14$us = $13 & $83;
  $20 = (($charcode$024$us) + 1)|0;
  if (!($or$cond14$us)) {
   break;
  }
  $19 = ($20>>>0)<(65536);
  if ($19) {
   $charcode$024$us = $20;
  } else {
   $$0 = 0;
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return ($$0|0);
 }
 $86 = ($next<<24>>24)==(0);
 $87 = ($gindex$1$us|0)==(0);
 $or$cond15 = $86 | $87;
 if ($or$cond15) {
  $$0 = $gindex$1$us;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$pcharcode>>2] = $charcode$024$us;
 $$0 = $gindex$1$us;
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap4_next($cmap) {
 $cmap = $cmap|0;
 var $$ = 0, $$charcode$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $charcode$0 = 0, $charcode$1 = 0, $charcode$2 = 0, $charcode$3 = 0, $p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>(65534);
 L1: do {
  if (!($2)) {
   $3 = (($1) + 1)|0;
   $4 = (($cmap) + 40|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3>>>0)<($5>>>0);
   $$ = $6 ? $5 : $3;
   $7 = (($cmap) + 52|0);
   $8 = (($cmap) + 44|0);
   $9 = (($cmap) + 48|0);
   $10 = (($cmap) + 36|0);
   $17 = $5;$charcode$0 = $$;
   L3: while(1) {
    $11 = HEAP32[$7>>2]|0;
    $12 = HEAP32[$8>>2]|0;
    $13 = HEAP32[$9>>2]|0;
    $14 = ($charcode$0>>>0)>($12>>>0);
    L5: do {
     if ($14) {
      $charcode$3 = $charcode$0;
     } else {
      $15 = ($11|0)==(0|0);
      if ($15) {
       $charcode$2 = $charcode$0;
       while(1) {
        $35 = (($charcode$2) + ($13))|0;
        $36 = $35 & 65535;
        $37 = ($36|0)==(0);
        if (!($37)) {
         label = 11;
         break L3;
        }
        $39 = (($charcode$2) + 1)|0;
        $40 = ($39>>>0)>($12>>>0);
        if ($40) {
         $charcode$3 = $39;
         break L5;
        } else {
         $charcode$2 = $39;
        }
       }
      }
      $16 = (($charcode$0) - ($17))|0;
      $18 = $16 << 1;
      $19 = (($11) + ($18)|0);
      $charcode$1 = $charcode$0;$p$0 = $19;
      while(1) {
       $20 = (($p$0) + 2|0);
       $21 = HEAP8[$p$0>>0]|0;
       $22 = $21&255;
       $23 = $22 << 8;
       $24 = (($p$0) + 1|0);
       $25 = HEAP8[$24>>0]|0;
       $26 = $25&255;
       $27 = $23 | $26;
       $28 = ($27|0)==(0);
       if (!($28)) {
        $29 = (($27) + ($13))|0;
        $30 = $29 & 65535;
        $31 = ($30|0)==(0);
        if (!($31)) {
         label = 8;
         break L3;
        }
       }
       $33 = (($charcode$1) + 1)|0;
       $34 = ($33>>>0)>($12>>>0);
       if ($34) {
        $charcode$3 = $33;
        break;
       } else {
        $charcode$1 = $33;$p$0 = $20;
       }
      }
     }
    } while(0);
    $41 = HEAP32[$10>>2]|0;
    $42 = (($41) + 1)|0;
    $43 = (_tt_cmap4_set_range($cmap,$42)|0);
    $44 = ($43|0)<(0);
    if ($44) {
     break L1;
    }
    $45 = HEAP32[$4>>2]|0;
    $46 = ($charcode$3>>>0)<($45>>>0);
    $$charcode$3 = $46 ? $45 : $charcode$3;
    $17 = $45;$charcode$0 = $$charcode$3;
   }
   if ((label|0) == 8) {
    HEAP32[$0>>2] = $charcode$1;
    $32 = (($cmap) + 28|0);
    HEAP32[$32>>2] = $30;
    STACKTOP = sp;return;
   }
   else if ((label|0) == 11) {
    HEAP32[$0>>2] = $charcode$2;
    $38 = (($cmap) + 28|0);
    HEAP32[$38>>2] = $36;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 HEAP32[$0>>2] = -1;
 $47 = (($cmap) + 28|0);
 HEAP32[$47>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_cmap4_char_map_binary($cmap,$pcharcode,$next) {
 $cmap = $cmap|0;
 $pcharcode = $pcharcode|0;
 $next = $next|0;
 var $$ = 0, $$0 = 0, $$56 = 0, $$57 = 0, $$58 = 0, $$masked = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum1516 = 0, $$sum17 = 0, $$sum1819 = 0, $$sum2 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0;
 var $$sum24 = 0, $$sum2526 = 0, $$sum27 = 0, $$sum2829 = 0, $$sum3 = 0, $$sum30 = 0, $$sum31 = 0, $$sum42 = 0, $$sum43 = 0, $$sum44 = 0, $$sum45 = 0, $$sum4647 = 0, $$sum48 = 0, $$sum4950 = 0, $$sum51 = 0, $$sum52 = 0, $$sum53 = 0, $$sum54 = 0, $$sum6 = 0, $$sum78 = 0;
 var $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $charcode$0$c = 0, $delta$0 = 0;
 var $delta$1$lcssa = 0, $delta$1$lcssa$ = 0, $delta$175 = 0, $delta$3$lcssa = 0, $delta$361 = 0, $delta$4 = 0, $delta$5 = 0, $end$0 = 0, $end$0$ph = 0, $end$1$lcssa = 0, $end$1$lcssa$ = 0, $end$177 = 0, $end$3$lcssa = 0, $end$363 = 0, $end$4 = 0, $end$5 = 0, $end$6 = 0, $gindex$0 = 0, $gindex$1 = 0, $i$0$lcssa = 0;
 var $i$074 = 0, $i$1$lcssa = 0, $i$160 = 0, $i$2 = 0, $max$0 = 0, $max$0$ph = 0, $mid$0 = 0, $mid$0$ph = 0, $mid$2$ = 0, $mid$2$lcssa = 0, $mid$272 = 0, $mid$4$i$1 = 0, $mid$4$lcssa = 0, $mid$459 = 0, $mid$6 = 0, $mid$7 = 0, $mid$8 = 0, $mid$9 = 0, $min$0$ph = 0, $offset$0 = 0;
 var $offset$1$lcssa = 0, $offset$1$lcssa$ = 0, $offset$176 = 0, $offset$3$lcssa = 0, $offset$362 = 0, $offset$4 = 0, $offset$5 = 0, $or$cond = 0, $or$cond55 = 0, $p$0$lcssa = 0, $p$073 = 0, $p$4 = 0, $p$5 = 0, $p$6 = 0, $start$0$lcssa = 0, $start$0$lcssa$ = 0, $start$078 = 0, $start$2$lcssa = 0, $start$264 = 0, $start$3 = 0;
 var $start$4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 6|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 << 8;
 $6 = (($1) + 7|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $$masked = $8 & 254;
 $9 = $$masked | $5;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$pcharcode>>2]|0;
 $12 = $9 >>> 1;
 $13 = ($next<<24>>24)!=(0);
 $14 = $13&1;
 $$ = (($11) + ($14))|0;
 $15 = (($9) + 2)|0;
 $end$0$ph = 65535;$max$0$ph = $12;$mid$0$ph = $12;$min$0$ph = 0;
 L4: while(1) {
  $end$0 = $end$0$ph;$max$0 = $max$0$ph;$mid$0 = $mid$0$ph;
  while(1) {
   $16 = ($min$0$ph>>>0)<($max$0>>>0);
   if (!($16)) {
    $end$6 = $end$0;$gindex$0 = 0;$mid$8 = $mid$0;
    break L4;
   }
   $17 = (($max$0) + ($min$0$ph))|0;
   $18 = $17 >>> 1;
   $19 = $18 << 1;
   $$sum = (($19) + 14)|0;
   $20 = (($1) + ($$sum)|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21&255;
   $23 = $22 << 8;
   $$sum2 = (($19) + 15)|0;
   $24 = (($1) + ($$sum2)|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = $25&255;
   $27 = $23 | $26;
   $$sum3 = (($$sum) + ($15))|0;
   $28 = (($1) + ($$sum3)|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = $29&255;
   $31 = $30 << 8;
   $$sum45 = $$sum3 | 1;
   $32 = (($1) + ($$sum45)|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = $33&255;
   $35 = $31 | $34;
   $36 = ($$>>>0)<($35>>>0);
   if ($36) {
    $end$0 = $27;$max$0 = $18;$mid$0 = $18;
   } else {
    break;
   }
  }
  $37 = ($$>>>0)>($27>>>0);
  $38 = (($18) + 1)|0;
  if ($37) {
   $end$0$ph = $27;$max$0$ph = $max$0;$mid$0$ph = $18;$min$0$ph = $38;
  } else {
   label = 7;
   break;
  }
 }
 do {
  if ((label|0) == 7) {
   $$sum6 = (($$sum3) + ($9))|0;
   $39 = (($1) + ($$sum6)|0);
   $40 = HEAP8[$39>>0]|0;
   $41 = $40 << 24 >> 24;
   $42 = $41 << 8;
   $$sum78 = $$sum6 | 1;
   $43 = (($1) + ($$sum78)|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = $44&255;
   $46 = $42 | $45;
   $$sum9 = (($$sum6) + ($9))|0;
   $47 = (($1) + ($$sum9)|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = $48&255;
   $50 = $49 << 8;
   $$sum10 = $$sum9 | 1;
   $51 = (($1) + ($$sum10)|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = $52&255;
   $54 = $50 | $53;
   $55 = (($12) + -1)|0;
   $56 = ($18>>>0)>=($55>>>0);
   $57 = ($35|0)==(65535);
   $or$cond = $56 & $57;
   $58 = ($27|0)==(65535);
   $or$cond55 = $or$cond & $58;
   if ($or$cond55) {
    $59 = HEAP32[$cmap>>2]|0;
    $60 = ($54|0)==(0);
    if ($60) {
     $delta$0 = $46;$offset$0 = 0;
    } else {
     $61 = (($59) + 504|0);
     $62 = (($59) + 500|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = HEAP32[$61>>2]|0;
     $65 = (($63) + ($64)|0);
     $$sum53 = (($$sum9) + 2)|0;
     $$sum54 = (($$sum53) + ($54))|0;
     $66 = (($1) + ($$sum54)|0);
     $67 = ($66>>>0)>($65>>>0);
     $$56 = $67 ? 1 : $46;
     $$57 = $67 ? 0 : $54;
     $delta$0 = $$56;$offset$0 = $$57;
    }
   } else {
    $delta$0 = $46;$offset$0 = $54;
   }
   $68 = (($cmap) + 20|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = $69 & 2;
   $71 = ($70|0)==(0);
   $72 = ($offset$0|0)==(65535);
   if ($71) {
    if ($72) {
     $end$6 = $27;$gindex$0 = 0;$mid$8 = $18;
     break;
    } else {
     $delta$5 = $delta$0;$end$5 = $27;$mid$7 = $18;$offset$5 = $offset$0;$p$6 = $47;$start$4 = $35;
    }
   } else {
    $$58 = $72 ? $38 : $18;
    $73 = ($18|0)==(0);
    L19: do {
     if ($73) {
      $delta$1$lcssa = $delta$0;$end$1$lcssa = $27;$i$0$lcssa = 0;$mid$2$lcssa = $$58;$offset$1$lcssa = $offset$0;$p$0$lcssa = $47;$start$0$lcssa = $35;
     } else {
      $delta$175 = $delta$0;$end$177 = $27;$i$074 = $18;$mid$272 = $$58;$offset$176 = $offset$0;$p$073 = $47;$start$078 = $35;
      while(1) {
       $74 = (($i$074) + -1)|0;
       $75 = $74 << 1;
       $$sum42 = (($75) + 14)|0;
       $76 = (($1) + ($$sum42)|0);
       $77 = HEAP8[$76>>0]|0;
       $78 = $77&255;
       $79 = $78 << 8;
       $$sum43 = (($75) + 15)|0;
       $80 = (($1) + ($$sum43)|0);
       $81 = HEAP8[$80>>0]|0;
       $82 = $81&255;
       $83 = $79 | $82;
       $84 = ($$>>>0)>($83>>>0);
       if ($84) {
        $delta$1$lcssa = $delta$175;$end$1$lcssa = $end$177;$i$0$lcssa = $i$074;$mid$2$lcssa = $mid$272;$offset$1$lcssa = $offset$176;$p$0$lcssa = $p$073;$start$0$lcssa = $start$078;
        break L19;
       }
       $$sum44 = (($$sum42) + ($15))|0;
       $85 = (($1) + ($$sum44)|0);
       $86 = HEAP8[$85>>0]|0;
       $87 = $86&255;
       $88 = $87 << 8;
       $$sum4647 = $$sum44 | 1;
       $89 = (($1) + ($$sum4647)|0);
       $90 = HEAP8[$89>>0]|0;
       $91 = $90&255;
       $92 = $88 | $91;
       $$sum48 = (($$sum44) + ($9))|0;
       $93 = (($1) + ($$sum48)|0);
       $94 = HEAP8[$93>>0]|0;
       $95 = $94 << 24 >> 24;
       $96 = $95 << 8;
       $$sum4950 = $$sum48 | 1;
       $97 = (($1) + ($$sum4950)|0);
       $98 = HEAP8[$97>>0]|0;
       $99 = $98&255;
       $100 = $96 | $99;
       $$sum51 = (($$sum48) + ($9))|0;
       $101 = (($1) + ($$sum51)|0);
       $102 = HEAP8[$101>>0]|0;
       $103 = $102&255;
       $104 = $103 << 8;
       $$sum52 = $$sum51 | 1;
       $105 = (($1) + ($$sum52)|0);
       $106 = HEAP8[$105>>0]|0;
       $107 = $106&255;
       $108 = $104 | $107;
       $109 = ($108|0)==(65535);
       $mid$2$ = $109 ? $mid$272 : $74;
       $110 = ($74|0)==(0);
       if ($110) {
        $delta$1$lcssa = $100;$end$1$lcssa = $83;$i$0$lcssa = 0;$mid$2$lcssa = $mid$2$;$offset$1$lcssa = $108;$p$0$lcssa = $101;$start$0$lcssa = $92;
        break;
       } else {
        $delta$175 = $100;$end$177 = $83;$i$074 = $74;$mid$272 = $mid$2$;$offset$176 = $108;$p$073 = $101;$start$078 = $92;
       }
      }
     }
    } while(0);
    $111 = ($mid$2$lcssa|0)==($38|0);
    if ($111) {
     $112 = ($i$0$lcssa|0)==($18|0);
     $delta$1$lcssa$ = $112 ? $delta$1$lcssa : $46;
     $offset$1$lcssa$ = $112 ? $offset$1$lcssa : $54;
     $end$1$lcssa$ = $112 ? $end$1$lcssa : $27;
     $start$0$lcssa$ = $112 ? $start$0$lcssa : $35;
     $113 = ($38>>>0)<($12>>>0);
     if ($113) {
      $delta$361 = $delta$1$lcssa$;$end$363 = $end$1$lcssa$;$i$160 = $38;$mid$459 = $18;$offset$362 = $offset$1$lcssa$;$start$264 = $start$0$lcssa$;
     } else {
      $end$6 = $end$1$lcssa$;$gindex$0 = 0;$mid$8 = $18;
      break;
     }
     while(1) {
      $114 = $i$160 << 1;
      $$sum22 = (($114) + 14)|0;
      $$sum24 = (($$sum22) + ($15))|0;
      $115 = (($1) + ($$sum24)|0);
      $116 = HEAP8[$115>>0]|0;
      $117 = $116&255;
      $118 = $117 << 8;
      $$sum2526 = $$sum24 | 1;
      $119 = (($1) + ($$sum2526)|0);
      $120 = HEAP8[$119>>0]|0;
      $121 = $120&255;
      $122 = $118 | $121;
      $123 = ($$>>>0)<($122>>>0);
      if ($123) {
       $delta$3$lcssa = $delta$361;$end$3$lcssa = $end$363;$i$1$lcssa = $i$160;$mid$4$lcssa = $mid$459;$offset$3$lcssa = $offset$362;$p$4 = $115;$start$2$lcssa = $start$264;
       break;
      }
      $$sum23 = (($114) + 15)|0;
      $124 = (($1) + ($$sum22)|0);
      $125 = (($1) + ($$sum23)|0);
      $126 = HEAP8[$124>>0]|0;
      $127 = HEAP8[$125>>0]|0;
      $128 = $126&255;
      $129 = $127&255;
      $130 = $128 << 8;
      $131 = $130 | $129;
      $$sum27 = (($$sum24) + ($9))|0;
      $132 = (($1) + ($$sum27)|0);
      $133 = HEAP8[$132>>0]|0;
      $134 = $133 << 24 >> 24;
      $135 = $134 << 8;
      $$sum2829 = $$sum27 | 1;
      $136 = (($1) + ($$sum2829)|0);
      $137 = HEAP8[$136>>0]|0;
      $138 = $137&255;
      $139 = $135 | $138;
      $$sum30 = (($$sum27) + ($9))|0;
      $140 = (($1) + ($$sum30)|0);
      $141 = HEAP8[$140>>0]|0;
      $142 = $141&255;
      $143 = $142 << 8;
      $$sum31 = $$sum30 | 1;
      $144 = (($1) + ($$sum31)|0);
      $145 = HEAP8[$144>>0]|0;
      $146 = $145&255;
      $147 = $143 | $146;
      $148 = ($147|0)==(65535);
      $mid$4$i$1 = $148 ? $mid$459 : $i$160;
      $149 = (($i$160) + 1)|0;
      $150 = ($149>>>0)<($12>>>0);
      if ($150) {
       $delta$361 = $139;$end$363 = $131;$i$160 = $149;$mid$459 = $mid$4$i$1;$offset$362 = $147;$start$264 = $122;
      } else {
       $delta$3$lcssa = $139;$end$3$lcssa = $131;$i$1$lcssa = $149;$mid$4$lcssa = $mid$4$i$1;$offset$3$lcssa = $147;$p$4 = $140;$start$2$lcssa = $122;
       break;
      }
     }
     $151 = (($i$1$lcssa) + -1)|0;
     $152 = ($mid$4$lcssa|0)==($18|0);
     if ($152) {
      $end$6 = $end$3$lcssa;$gindex$0 = 0;$mid$8 = $151;
      break;
     } else {
      $delta$4 = $delta$3$lcssa;$end$4 = $end$3$lcssa;$i$2 = $151;$mid$6 = $mid$4$lcssa;$offset$4 = $offset$3$lcssa;$p$5 = $p$4;$start$3 = $start$2$lcssa;
     }
    } else {
     $delta$4 = $delta$1$lcssa;$end$4 = $end$1$lcssa;$i$2 = $i$0$lcssa;$mid$6 = $mid$2$lcssa;$offset$4 = $offset$1$lcssa;$p$5 = $p$0$lcssa;$start$3 = $start$0$lcssa;
    }
    $153 = ($mid$6|0)==($i$2|0);
    if ($153) {
     $delta$5 = $delta$4;$end$5 = $end$4;$mid$7 = $mid$6;$offset$5 = $offset$4;$p$6 = $p$5;$start$4 = $start$3;
    } else {
     $154 = $mid$6 << 1;
     $$sum12 = (($154) + 14)|0;
     $155 = (($1) + ($$sum12)|0);
     $156 = HEAP8[$155>>0]|0;
     $157 = $156&255;
     $158 = $157 << 8;
     $$sum13 = (($154) + 15)|0;
     $159 = (($1) + ($$sum13)|0);
     $160 = HEAP8[$159>>0]|0;
     $161 = $160&255;
     $162 = $158 | $161;
     $$sum14 = (($$sum12) + ($15))|0;
     $163 = (($1) + ($$sum14)|0);
     $164 = HEAP8[$163>>0]|0;
     $165 = $164&255;
     $166 = $165 << 8;
     $$sum1516 = $$sum14 | 1;
     $167 = (($1) + ($$sum1516)|0);
     $168 = HEAP8[$167>>0]|0;
     $169 = $168&255;
     $170 = $166 | $169;
     $$sum17 = (($$sum14) + ($9))|0;
     $171 = (($1) + ($$sum17)|0);
     $172 = HEAP8[$171>>0]|0;
     $173 = $172 << 24 >> 24;
     $174 = $173 << 8;
     $$sum1819 = $$sum17 | 1;
     $175 = (($1) + ($$sum1819)|0);
     $176 = HEAP8[$175>>0]|0;
     $177 = $176&255;
     $178 = $174 | $177;
     $$sum20 = (($$sum17) + ($9))|0;
     $179 = (($1) + ($$sum20)|0);
     $180 = HEAP8[$179>>0]|0;
     $181 = $180&255;
     $182 = $181 << 8;
     $$sum21 = $$sum20 | 1;
     $183 = (($1) + ($$sum21)|0);
     $184 = HEAP8[$183>>0]|0;
     $185 = $184&255;
     $186 = $182 | $185;
     $delta$5 = $178;$end$5 = $162;$mid$7 = $mid$6;$offset$5 = $186;$p$6 = $179;$start$4 = $170;
    }
   }
   $187 = ($offset$5|0)==(0);
   if ($187) {
    $202 = (($delta$5) + ($$))|0;
    $203 = $202 & 65535;
    $end$6 = $end$5;$gindex$0 = $203;$mid$8 = $mid$7;
    break;
   }
   $188 = (($$) - ($start$4))|0;
   $189 = $188 << 1;
   $190 = (($189) + ($offset$5))|0;
   $191 = (($p$6) + ($190)|0);
   $192 = HEAP8[$191>>0]|0;
   $193 = $192&255;
   $194 = $193 << 8;
   $$sum11 = (($190) + 1)|0;
   $195 = (($p$6) + ($$sum11)|0);
   $196 = HEAP8[$195>>0]|0;
   $197 = $196&255;
   $198 = $194 | $197;
   $199 = ($198|0)==(0);
   if ($199) {
    $end$6 = $end$5;$gindex$0 = 0;$mid$8 = $mid$7;
   } else {
    $200 = (($198) + ($delta$5))|0;
    $201 = $200 & 65535;
    $end$6 = $end$5;$gindex$0 = $201;$mid$8 = $mid$7;
   }
  }
 } while(0);
 if (!($13)) {
  $$0 = $gindex$0;
  STACKTOP = sp;return ($$0|0);
 }
 $204 = ($$>>>0)>($end$6>>>0);
 if ($204) {
  $205 = (($mid$8) + 1)|0;
  $206 = ($205|0)==($12|0);
  if ($206) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $mid$9 = $205;
  }
 } else {
  $mid$9 = $mid$8;
 }
 $207 = (_tt_cmap4_set_range($cmap,$mid$9)|0);
 $208 = ($207|0)==(0);
 if (!($208)) {
  $209 = ($gindex$0|0)==(0);
  if ($209) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$pcharcode>>2] = $$;
  $$0 = $gindex$0;
  STACKTOP = sp;return ($$0|0);
 }
 $210 = (($cmap) + 24|0);
 $charcode$0$c = $$;
 HEAP32[$210>>2] = $charcode$0$c;
 $211 = ($gindex$0|0)==(0);
 if ($211) {
  HEAP32[$210>>2] = $charcode$0$c;
  _tt_cmap4_next($cmap);
  $213 = (($cmap) + 28|0);
  $214 = HEAP32[$213>>2]|0;
  $gindex$1 = $214;
 } else {
  $212 = (($cmap) + 28|0);
  HEAP32[$212>>2] = $gindex$0;
  $gindex$1 = $gindex$0;
 }
 $215 = ($gindex$1|0)==(0);
 if ($215) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $216 = HEAP32[$210>>2]|0;
 HEAP32[$pcharcode>>2] = $216;
 $$0 = $gindex$1;
 STACKTOP = sp;return ($$0|0);
}
function _tt_cmap4_set_range($cmap,$range_index) {
 $cmap = $cmap|0;
 $range_index = $range_index|0;
 var $$0 = 0, $$0125 = 0, $$sum = 0, $$sum1011 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum2 = 0, $$sum3 = 0, $$sum45 = 0, $$sum6 = 0, $$sum78 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond36 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($cmap) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($cmap) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3>>>0)>($range_index>>>0);
 if (!($4)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($cmap) + 44|0);
 $6 = $3 << 1;
 $7 = (($6) + 2)|0;
 $8 = (($cmap) + 40|0);
 $9 = (($cmap) + 48|0);
 $10 = (($3) + -1)|0;
 $$0125 = $range_index;
 while(1) {
  $11 = $$0125 << 1;
  $$sum = (($11) + 14)|0;
  $12 = (($1) + ($$sum)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 << 8;
  $$sum2 = (($11) + 15)|0;
  $16 = (($1) + ($$sum2)|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $15 | $18;
  HEAP32[$5>>2] = $19;
  $$sum3 = (($7) + ($$sum))|0;
  $20 = (($1) + ($$sum3)|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = $21&255;
  $23 = $22 << 8;
  $$sum45 = $$sum3 | 1;
  $24 = (($1) + ($$sum45)|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25&255;
  $27 = $23 | $26;
  HEAP32[$8>>2] = $27;
  $$sum6 = (($$sum3) + ($6))|0;
  $28 = (($1) + ($$sum6)|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29 << 24 >> 24;
  $31 = $30 << 8;
  $$sum78 = $$sum6 | 1;
  $32 = (($1) + ($$sum78)|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = $31 | $34;
  HEAP32[$9>>2] = $35;
  $$sum9 = (($$sum6) + ($6))|0;
  $36 = (($1) + ($$sum9)|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = $37&255;
  $39 = $38 << 8;
  $$sum1011 = $$sum9 | 1;
  $40 = (($1) + ($$sum1011)|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41&255;
  $43 = $39 | $42;
  $44 = ($$0125>>>0)>=($10>>>0);
  $45 = ($27|0)==(65535);
  $or$cond = $44 & $45;
  $46 = ($19|0)==(65535);
  $or$cond36 = $or$cond & $46;
  if ($or$cond36) {
   $47 = HEAP32[$cmap>>2]|0;
   $48 = ($43|0)==(0);
   if ($48) {
    $58 = 0;
    break;
   }
   $49 = (($47) + 504|0);
   $50 = (($47) + 500|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = HEAP32[$49>>2]|0;
   $53 = (($51) + ($52)|0);
   $$sum13 = (($$sum9) + 2)|0;
   $$sum14 = (($$sum13) + ($43))|0;
   $54 = (($1) + ($$sum14)|0);
   $55 = ($54>>>0)>($53>>>0);
   if ($55) {
    label = 6;
    break;
   }
  }
  if ((($43|0) == 0)) {
   $58 = 0;
   break;
  } else if (!((($43|0) == 65535))) {
   label = 8;
   break;
  }
  $60 = (($$0125) + 1)|0;
  $61 = ($60>>>0)<($3>>>0);
  if ($61) {
   $$0125 = $60;
  } else {
   $$0 = -1;
   label = 11;
   break;
  }
 }
 if ((label|0) == 6) {
  HEAP32[$9>>2] = 1;
  $58 = 0;
 }
 else if ((label|0) == 8) {
  $$sum12 = (($43) + ($$sum9))|0;
  $56 = (($1) + ($$sum12)|0);
  $58 = $56;
 }
 else if ((label|0) == 11) {
  STACKTOP = sp;return ($$0|0);
 }
 $57 = (($cmap) + 52|0);
 HEAP32[$57>>2] = $58;
 $59 = (($cmap) + 36|0);
 HEAP32[$59>>2] = $$0125;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _tt_face_load_hmtx($face,$stream,$vertical) {
 $face = $face|0;
 $stream = $stream|0;
 $vertical = $vertical|0;
 var $$ = 0, $$5 = 0, $$6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $cur$012 = 0;
 var $cur3$0$lcssa = 0, $cur3$09 = 0, $cur3$17 = 0, $error = 0, $longs$0$in = 0, $longs$04 = 0, $num_longs$2 = 0, $or$cond = 0, $p$0$lcssa = 0, $p$011 = 0, $p$18 = 0, $shorts$0$in = 0, $shorts$02 = 0, $shorts$03 = 0, $table_len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp + 4|0;
 $table_len = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($vertical<<24>>24)!=(0);
 $3 = (($face) + 508|0);
 $4 = HEAP32[$3>>2]|0;
 do {
  if ($2) {
   $5 = (FUNCTION_TABLE_iiiii[$4 & 511]($face,1986884728,$stream,$table_len)|0);
   HEAP32[$error>>2] = $5;
   $6 = ($5|0)==(0);
   if ($6) {
    $7 = (($face) + 340|0);
    $8 = (($face) + 336|0);
    $9 = (($face) + 334|0);
    $10 = HEAP16[$9>>1]|0;
    $11 = $10&65535;
    $12 = HEAP32[$table_len>>2]|0;
    $13 = $12 >>> 2;
    $14 = ($11>>>0)>($13>>>0);
    $$ = $14 ? $13 : $11;
    HEAP16[$9>>1] = 0;
    $31 = $12;$longs$0$in = $8;$num_longs$2 = $$;$shorts$0$in = $7;
    break;
   } else {
    $95 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($95|0);
   }
  } else {
   $15 = (FUNCTION_TABLE_iiiii[$4 & 511]($face,1752003704,$stream,$table_len)|0);
   HEAP32[$error>>2] = $15;
   $16 = ($15|0)==(0);
   if ($16) {
    $17 = (($face) + 256|0);
    $18 = (($face) + 252|0);
    $19 = (($face) + 250|0);
    $20 = HEAP16[$19>>1]|0;
    $21 = $20&65535;
    $22 = HEAP32[$table_len>>2]|0;
    $23 = $22 >>> 2;
    $24 = ($21>>>0)>($23>>>0);
    $$5 = $24 ? $23 : $21;
    HEAP16[$19>>1] = 0;
    $31 = $22;$longs$0$in = $18;$num_longs$2 = $$5;$shorts$0$in = $17;
    break;
   } else {
    $95 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($95|0);
   }
  }
 } while(0);
 $25 = (($face) + 264|0);
 $26 = HEAP16[$25>>1]|0;
 $27 = $26&65535;
 $28 = (($27) - ($num_longs$2))|0;
 $29 = $num_longs$2 << 2;
 $30 = (($31) - ($29))|0;
 $32 = $30 >>> 1;
 $33 = ($28|0)<(0);
 $$6 = $33 ? 0 : $28;
 $34 = (_ft_mem_realloc($1,4,0,$num_longs$2,0,$error)|0);
 HEAP32[$longs$0$in>>2] = $34;
 $35 = HEAP32[$error>>2]|0;
 $36 = ($35|0)==(0);
 if (!($36)) {
  $95 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($95|0);
 }
 $37 = (_ft_mem_realloc($1,2,0,$$6,0,$error)|0);
 HEAP32[$shorts$0$in>>2] = $37;
 $38 = HEAP32[$error>>2]|0;
 $39 = ($38|0)==(0);
 if (!($39)) {
  $95 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($95|0);
 }
 $40 = HEAP32[$table_len>>2]|0;
 $41 = (_FT_Stream_EnterFrame($stream,$40)|0);
 HEAP32[$error>>2] = $41;
 $42 = ($41|0)==(0);
 if (!($42)) {
  $95 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($95|0);
 }
 $43 = (($stream) + 32|0);
 $44 = HEAP32[$43>>2]|0;
 $longs$04 = HEAP32[$longs$0$in>>2]|0;
 $45 = (($longs$04) + ($num_longs$2<<2)|0);
 $46 = ($longs$04>>>0)<($45>>>0);
 if ($46) {
  $cur$012 = $longs$04;$p$011 = $44;
  while(1) {
   $47 = HEAP8[$p$011>>0]|0;
   $48 = $47&255;
   $49 = $48 << 8;
   $50 = (($p$011) + 1|0);
   $51 = HEAP8[$50>>0]|0;
   $52 = $51&255;
   $53 = $49 | $52;
   $54 = $53&65535;
   HEAP16[$cur$012>>1] = $54;
   $55 = (($p$011) + 4|0);
   $56 = (($p$011) + 2|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = $57 << 24 >> 24;
   $59 = $58 << 8;
   $60 = (($p$011) + 3|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61&255;
   $63 = $59 | $62;
   $64 = $63&65535;
   $65 = (($cur$012) + 2|0);
   HEAP16[$65>>1] = $64;
   $66 = (($cur$012) + 4|0);
   $67 = ($66>>>0)<($45>>>0);
   if ($67) {
    $cur$012 = $66;$p$011 = $55;
   } else {
    $p$0$lcssa = $55;
    break;
   }
  }
 } else {
  $p$0$lcssa = $44;
 }
 $shorts$02 = HEAP32[$shorts$0$in>>2]|0;
 $68 = ($$6|0)<($32|0);
 $69 = $68 ? $$6 : $32;
 $70 = (($shorts$02) + ($69<<1)|0);
 $71 = ($shorts$02>>>0)<($70>>>0);
 if ($71) {
  $cur3$09 = $shorts$02;$p$18 = $p$0$lcssa;
  while(1) {
   $72 = (($p$18) + 2|0);
   $73 = HEAP8[$p$18>>0]|0;
   $74 = $73 << 24 >> 24;
   $75 = $74 << 8;
   $76 = (($p$18) + 1|0);
   $77 = HEAP8[$76>>0]|0;
   $78 = $77&255;
   $79 = $75 | $78;
   $80 = $79&65535;
   HEAP16[$cur3$09>>1] = $80;
   $81 = (($cur3$09) + 2|0);
   $82 = ($81>>>0)<($70>>>0);
   if ($82) {
    $cur3$09 = $81;$p$18 = $72;
   } else {
    $cur3$0$lcssa = $81;
    break;
   }
  }
 } else {
  $cur3$0$lcssa = $shorts$02;
 }
 $83 = ($$6|0)>($32|0);
 $84 = ($32|0)!=(0);
 $or$cond = $83 & $84;
 if ($or$cond) {
  $85 = (($32) + -1)|0;
  $shorts$03 = HEAP32[$shorts$0$in>>2]|0;
  $86 = (($shorts$03) + ($85<<1)|0);
  $87 = HEAP16[$86>>1]|0;
  $88 = (($shorts$03) + ($$6<<1)|0);
  $89 = ($cur3$0$lcssa>>>0)<($88>>>0);
  if ($89) {
   $cur3$17 = $cur3$0$lcssa;
   while(1) {
    HEAP16[$cur3$17>>1] = $87;
    $90 = (($cur3$17) + 2|0);
    $91 = ($90>>>0)<($88>>>0);
    if ($91) {
     $cur3$17 = $90;
    } else {
     break;
    }
   }
  }
 }
 _FT_Stream_ExitFrame($stream);
 $92 = $num_longs$2&65535;
 if ($2) {
  $93 = (($face) + 334|0);
  HEAP16[$93>>1] = $92;
  $95 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($95|0);
 } else {
  $94 = (($face) + 250|0);
  HEAP16[$94>>1] = $92;
  $95 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($95|0);
 }
 return 0|0;
}
function _tt_face_load_hhea($face,$stream,$vertical) {
 $face = $face|0;
 $stream = $stream|0;
 $vertical = $vertical|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, $header$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($vertical<<24>>24)==(0);
 $1 = (($face) + 508|0);
 $2 = HEAP32[$1>>2]|0;
 if ($0) {
  $6 = (FUNCTION_TABLE_iiiii[$2 & 511]($face,1751672161,$stream,0)|0);
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = (($face) + 216|0);
   $header$0 = $8;
   label = 6;
  } else {
   $error$0 = $6;
  }
 } else {
  $3 = (FUNCTION_TABLE_iiiii[$2 & 511]($face,1986553185,$stream,0)|0);
  $4 = ($3|0)==(0);
  if ($4) {
   $5 = (($face) + 300|0);
   $header$0 = $5;
   label = 6;
  } else {
   $error$0 = $3;
  }
 }
 if ((label|0) == 6) {
  $9 = (_FT_Stream_ReadFields($stream,871512,$header$0)|0);
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = (($header$0) + 36|0);
   HEAP32[$11>>2] = 0;
   $12 = (($header$0) + 40|0);
   HEAP32[$12>>2] = 0;
   $error$0 = 0;
  } else {
   $error$0 = $9;
  }
 }
 STACKTOP = sp;return ($error$0|0);
}
function _tt_face_get_metrics($face,$vertical,$gindex,$abearing,$aadvance) {
 $face = $face|0;
 $vertical = $vertical|0;
 $gindex = $gindex|0;
 $abearing = $abearing|0;
 $aadvance = $aadvance|0;
 var $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 300|0);
 $1 = (($face) + 216|0);
 $2 = ($vertical<<24>>24)!=(0);
 $$sink = $2 ? $0 : $1;
 $3 = (($$sink) + 34|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4&65535;
 $6 = ($4<<16>>16)==(0);
 if (!($6)) {
  $7 = (($$sink) + 36|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   $10 = (($face) + 264|0);
   $11 = HEAP16[$10>>1]|0;
   $12 = $11&65535;
   $13 = ($12>>>0)>($gindex>>>0);
   if ($13) {
    $14 = ($5>>>0)>($gindex>>>0);
    if ($14) {
     $15 = ((($8) + ($gindex<<2)|0) + 2|0);
     $16 = HEAP16[$15>>1]|0;
     HEAP16[$abearing>>1] = $16;
     $17 = (($8) + ($gindex<<2)|0);
     $storemerge$in = $17;
    } else {
     $18 = (($gindex) - ($5))|0;
     $19 = (($$sink) + 40|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($20) + ($18<<1)|0);
     $22 = HEAP16[$21>>1]|0;
     HEAP16[$abearing>>1] = $22;
     $23 = (($5) + -1)|0;
     $24 = (($8) + ($23<<2)|0);
     $storemerge$in = $24;
    }
    $storemerge = HEAP16[$storemerge$in>>1]|0;
    HEAP16[$aadvance>>1] = $storemerge;
    STACKTOP = sp;return 0;
   }
  }
 }
 HEAP16[$aadvance>>1] = 0;
 HEAP16[$abearing>>1] = 0;
 STACKTOP = sp;return 0;
}
function _tt_face_free_ps_names($face) {
 $face = $face|0;
 var $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 628|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  HEAP8[$2>>0] = 0;
  STACKTOP = sp;return;
 }
 $5 = (($face) + 468|0);
 $6 = HEAP32[$5>>2]|0;
 if ((($6|0) == 131072)) {
  $7 = (($face) + 636|0);
  $8 = HEAP32[$7>>2]|0;
  _ft_mem_free($1,$8);
  HEAP32[$7>>2] = 0;
  $9 = (($face) + 632|0);
  HEAP16[$9>>1] = 0;
  $10 = (($face) + 634|0);
  $11 = HEAP16[$10>>1]|0;
  $12 = ($11<<16>>16)==(0);
  $13 = (($face) + 640|0);
  $14 = HEAP32[$13>>2]|0;
  if ($12) {
   $$lcssa2 = $14;
  } else {
   $16 = $14;$17 = 0;$n$03 = 0;
   while(1) {
    $15 = (($16) + ($17<<2)|0);
    $18 = HEAP32[$15>>2]|0;
    _ft_mem_free($1,$18);
    $19 = HEAP32[$13>>2]|0;
    $20 = (($19) + ($17<<2)|0);
    HEAP32[$20>>2] = 0;
    $21 = (($n$03) + 1)<<16>>16;
    $22 = $21&65535;
    $23 = HEAP16[$10>>1]|0;
    $24 = ($21&65535)<($23&65535);
    $25 = HEAP32[$13>>2]|0;
    if ($24) {
     $16 = $25;$17 = $22;$n$03 = $21;
    } else {
     $$lcssa2 = $25;
     break;
    }
   }
  }
  _ft_mem_free($1,$$lcssa2);
  HEAP32[$13>>2] = 0;
  HEAP16[$10>>1] = 0;
  HEAP8[$2>>0] = 0;
  STACKTOP = sp;return;
 } else if ((($6|0) == 163840)) {
  $26 = (($face) + 636|0);
  $27 = HEAP32[$26>>2]|0;
  _ft_mem_free($1,$27);
  HEAP32[$26>>2] = 0;
  $28 = (($face) + 632|0);
  HEAP16[$28>>1] = 0;
  HEAP8[$2>>0] = 0;
  STACKTOP = sp;return;
 } else {
  HEAP8[$2>>0] = 0;
  STACKTOP = sp;return;
 }
}
function _tt_face_get_ps_name($face,$idx,$PSname) {
 $face = $face|0;
 $idx = $idx|0;
 $PSname = $PSname|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($face|0)==(0|0);
 do {
  if ($0) {
   $$0 = 35;
  } else {
   $1 = (($face) + 264|0);
   $2 = HEAP16[$1>>1]|0;
   $3 = $2&65535;
   $4 = ($3>>>0)>($idx>>>0);
   if ($4) {
    $5 = (($face) + 536|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)==(0|0);
    if ($7) {
     $$0 = 7;
    } else {
     $8 = (($face) + 628|0);
     $9 = (($6) + 16|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = (FUNCTION_TABLE_ii[$10 & 4095](0)|0);
     HEAP32[$PSname>>2] = $11;
     $12 = (($face) + 468|0);
     $13 = HEAP32[$12>>2]|0;
     if ((($13|0) == 163840)) {
      $38 = HEAP8[$8>>0]|0;
      $39 = ($38<<24>>24)==(0);
      if ($39) {
       $40 = (_load_post_names($face)|0);
       $41 = ($40|0)==(0);
       if (!($41)) {
        $$0 = 0;
        break;
       }
      }
      $42 = (($face) + 632|0);
      $43 = HEAP16[$42>>1]|0;
      $44 = $43&65535;
      $45 = ($44>>>0)>($idx>>>0);
      if (!($45)) {
       $$0 = 0;
       break;
      }
      $46 = (($face) + 636|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + ($idx)|0);
      $49 = HEAP8[$48>>0]|0;
      $50 = $49 << 24 >> 24;
      $51 = (($50) + ($idx))|0;
      $52 = HEAP32[$9>>2]|0;
      $53 = (FUNCTION_TABLE_ii[$52 & 4095]($51)|0);
      HEAP32[$PSname>>2] = $53;
      $$0 = 0;
      break;
     } else if ((($13|0) == 131072)) {
      $17 = HEAP8[$8>>0]|0;
      $18 = ($17<<24>>24)==(0);
      if ($18) {
       $19 = (_load_post_names($face)|0);
       $20 = ($19|0)==(0);
       if (!($20)) {
        $$0 = 0;
        break;
       }
      }
      $21 = (($face) + 632|0);
      $22 = HEAP16[$21>>1]|0;
      $23 = $22&65535;
      $24 = ($23>>>0)>($idx>>>0);
      if (!($24)) {
       $$0 = 0;
       break;
      }
      $25 = (($face) + 636|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($26) + ($idx<<1)|0);
      $28 = HEAP16[$27>>1]|0;
      $29 = $28&65535;
      $30 = ($28&65535)<(258);
      if ($30) {
       $31 = HEAP32[$9>>2]|0;
       $32 = (FUNCTION_TABLE_ii[$31 & 4095]($29)|0);
       HEAP32[$PSname>>2] = $32;
       $$0 = 0;
       break;
      } else {
       $33 = (($29) + -258)|0;
       $34 = (($face) + 640|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = (($35) + ($33<<2)|0);
       $37 = HEAP32[$36>>2]|0;
       HEAP32[$PSname>>2] = $37;
       $$0 = 0;
       break;
      }
     } else if ((($13|0) == 65536)) {
      $14 = ($idx>>>0)<(258);
      if (!($14)) {
       $$0 = 0;
       break;
      }
      $15 = HEAP32[$9>>2]|0;
      $16 = (FUNCTION_TABLE_ii[$15 & 4095]($idx)|0);
      HEAP32[$PSname>>2] = $16;
      $$0 = 0;
      break;
     } else {
      $$0 = 0;
      break;
     }
    }
   } else {
    $$0 = 16;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _load_post_names($face) {
 $face = $face|0;
 var $$num_names$0$i = 0, $$pre$i = 0, $$pre$i4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error$0 = 0, $error$1 = 0;
 var $error$i = 0, $error$i1 = 0, $exitcond = 0, $indvars$iv$i = 0, $indvars$iv$next$i = 0, $indvars$iv$next26$i = 0, $indvars$iv$next32$i = 0, $indvars$iv25$i = 0, $indvars$iv31$i = 0, $len$0$i = 0, $lftr$wideiv = 0, $n$02$i = 0, $n$020$i = 0, $n1$017$i = 0, $n2$09$i = 0, $name_strings$0$i = 0, $num_names$0$lcssa$i = 0, $num_names$016$i = 0, $num_names$1$i = 0, $or$cond$i = 0;
 var $or$cond1$i = 0, $post_len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i1 = sp + 8|0;
 $error$i = sp;
 $post_len = sp + 4|0;
 $0 = (($face) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 508|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiiii[$3 & 511]($face,1886352244,$1,$post_len)|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  $error$1 = $4;
  STACKTOP = sp;return ($error$1|0);
 }
 $6 = (_FT_Stream_Pos($1)|0);
 $7 = HEAP32[$post_len>>2]|0;
 $8 = (($7) + ($6))|0;
 $9 = (($face) + 468|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (_FT_Stream_Skip($1,32)|0);
 $12 = ($11|0)==(0);
 if (!($12)) {
  $error$1 = $11;
  STACKTOP = sp;return ($error$1|0);
 }
 L7: do {
  if ((($10|0) == 163840)) {
   $88 = (($1) + 28|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = (_FT_Stream_ReadUShort($1,$error$i1)|0);
   $91 = $90&65535;
   $92 = HEAP32[$error$i1>>2]|0;
   $93 = ($92|0)==(0);
   if ($93) {
    $94 = (($face) + 264|0);
    $95 = HEAP16[$94>>1]|0;
    $96 = ($90&65535)>($95&65535);
    $97 = ($90&65535)>(258);
    $or$cond$i = $96 | $97;
    if ($or$cond$i) {
     HEAP32[$error$i1>>2] = 3;
     $error$0 = 3;
     break;
    }
    $98 = (_ft_mem_realloc($89,1,0,$91,0,$error$i1)|0);
    $99 = HEAP32[$error$i1>>2]|0;
    $100 = ($99|0)==(0);
    L13: do {
     if ($100) {
      $101 = (_FT_Stream_Read($1,$98,$91)|0);
      HEAP32[$error$i1>>2] = $101;
      $102 = ($101|0)==(0);
      if ($102) {
       $103 = ($90<<16>>16)==(0);
       L16: do {
        if (!($103)) {
         $n$02$i = 0;
         while(1) {
          $106 = (($98) + ($n$02$i)|0);
          $107 = HEAP8[$106>>0]|0;
          $108 = $107 << 24 >> 24;
          $109 = (($108) + ($n$02$i))|0;
          $110 = ($109|0)<(0);
          $111 = ($109|0)>($91|0);
          $or$cond1$i = $110 | $111;
          $105 = (($n$02$i) + 1)|0;
          if ($or$cond1$i) {
           break;
          }
          $104 = ($105|0)<($91|0);
          if ($104) {
           $n$02$i = $105;
          } else {
           break L16;
          }
         }
         HEAP32[$error$i1>>2] = 3;
         break L13;
        }
       } while(0);
       $112 = (($face) + 632|0);
       HEAP16[$112>>1] = $90;
       $113 = (($face) + 636|0);
       HEAP32[$113>>2] = $98;
       $error$0 = 0;
       break L7;
      }
     }
    } while(0);
    _ft_mem_free($89,$98);
    $$pre$i4 = HEAP32[$error$i1>>2]|0;
    $error$0 = $$pre$i4;
   } else {
    $error$0 = $92;
   }
  } else if ((($10|0) == 131072)) {
   $13 = (($1) + 28|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (_FT_Stream_ReadUShort($1,$error$i)|0);
   $16 = $15&65535;
   $17 = HEAP32[$error$i>>2]|0;
   $18 = ($17|0)==(0);
   if ($18) {
    $19 = (($face) + 264|0);
    $20 = HEAP16[$19>>1]|0;
    $21 = ($15&65535)>($20&65535);
    if ($21) {
     HEAP32[$error$i>>2] = 3;
     $error$0 = 3;
     break;
    }
    $22 = (_ft_mem_realloc($14,2,0,$16,0,$error$i)|0);
    $23 = HEAP32[$error$i>>2]|0;
    $24 = ($23|0)==(0);
    L28: do {
     if ($24) {
      $25 = $16 << 1;
      $26 = (_FT_Stream_EnterFrame($1,$25)|0);
      HEAP32[$error$i>>2] = $26;
      $27 = ($26|0)==(0);
      if ($27) {
       $28 = ($15<<16>>16)==(0);
       if ($28) {
        _FT_Stream_ExitFrame($1);
        $num_names$0$lcssa$i = 0;
       } else {
        $n$020$i = 0;
        while(1) {
         $29 = (_FT_Stream_GetUShort($1)|0);
         $30 = (($22) + ($n$020$i<<1)|0);
         HEAP16[$30>>1] = $29;
         $31 = (($n$020$i) + 1)|0;
         $32 = ($31|0)<($16|0);
         if ($32) {
          $n$020$i = $31;
         } else {
          break;
         }
        }
        _FT_Stream_ExitFrame($1);
        $n1$017$i = 0;$num_names$016$i = 0;
        while(1) {
         $33 = (($22) + ($n1$017$i<<1)|0);
         $34 = HEAP16[$33>>1]|0;
         $35 = ($34&65535)>(257);
         if ($35) {
          $36 = $34&65535;
          $37 = (($36) + -257)|0;
          $38 = $num_names$016$i&65535;
          $39 = ($37|0)>($38|0);
          $40 = $37&65535;
          $$num_names$0$i = $39 ? $40 : $num_names$016$i;
          $num_names$1$i = $$num_names$0$i;
         } else {
          $num_names$1$i = $num_names$016$i;
         }
         $41 = (($n1$017$i) + 1)|0;
         $42 = ($41|0)<($16|0);
         if ($42) {
          $n1$017$i = $41;$num_names$016$i = $num_names$1$i;
         } else {
          $num_names$0$lcssa$i = $num_names$1$i;
          break;
         }
        }
       }
       $43 = $num_names$0$lcssa$i&65535;
       $44 = (_ft_mem_realloc($14,4,0,$43,0,$error$i)|0);
       $45 = HEAP32[$error$i>>2]|0;
       $46 = ($45|0)==(0);
       if ($46) {
        $47 = ($num_names$0$lcssa$i<<16>>16)==(0);
        L43: do {
         if (!($47)) {
          $indvars$iv31$i = 0;$n2$09$i = 0;
          while(1) {
           $48 = (_FT_Stream_Pos($1)|0);
           $49 = ($48|0)<($8|0);
           if (!($49)) {
            label = 19;
            break;
           }
           $51 = (_FT_Stream_ReadChar($1,$error$i)|0);
           $52 = $51&255;
           $53 = HEAP32[$error$i>>2]|0;
           $54 = ($53|0)==(0);
           if (!($54)) {
            $indvars$iv$i = 0;
            break;
           }
           $55 = ($52|0)>($8|0);
           if ($55) {
            label = 23;
           } else {
            $56 = (_FT_Stream_Pos($1)|0);
            $57 = (($8) - ($52))|0;
            $58 = ($56|0)>($57|0);
            if ($58) {
             label = 23;
            } else {
             $len$0$i = $52;
            }
           }
           if ((label|0) == 23) {
            label = 0;
            $59 = (_FT_Stream_Pos($1)|0);
            $60 = (($8) - ($59))|0;
            $61 = ($60|0)<(0);
            if ($61) {
             $len$0$i = 0;
            } else {
             $62 = (_FT_Stream_Pos($1)|0);
             $63 = (($8) - ($62))|0;
             $len$0$i = $63;
            }
           }
           $64 = (($len$0$i) + 1)|0;
           $65 = (_ft_mem_realloc($14,1,0,$64,0,$error$i)|0);
           $66 = (($44) + ($indvars$iv31$i<<2)|0);
           HEAP32[$66>>2] = $65;
           $67 = HEAP32[$error$i>>2]|0;
           $68 = ($67|0)==(0);
           if (!($68)) {
            $indvars$iv$i = 0;
            break;
           }
           $69 = (_FT_Stream_Read($1,$65,$len$0$i)|0);
           HEAP32[$error$i>>2] = $69;
           $70 = ($69|0)==(0);
           if (!($70)) {
            $indvars$iv$i = 0;
            break;
           }
           $71 = HEAP32[$66>>2]|0;
           $72 = (($71) + ($len$0$i)|0);
           HEAP8[$72>>0] = 0;
           $indvars$iv$next32$i = (($indvars$iv31$i) + 1)|0;
           $73 = (($n2$09$i) + 1)<<16>>16;
           $74 = $indvars$iv$next32$i&65535;
           $75 = ($74&65535)<($num_names$0$lcssa$i&65535);
           if ($75) {
            $indvars$iv31$i = $indvars$iv$next32$i;$n2$09$i = $73;
           } else {
            break L43;
           }
          }
          L56: do {
           if ((label|0) == 19) {
            $50 = ($n2$09$i&65535)<($num_names$0$lcssa$i&65535);
            if ($50) {
             $indvars$iv25$i = $indvars$iv31$i;
            } else {
             break L43;
            }
            while(1) {
             $76 = (_ft_mem_realloc($14,1,0,1,0,$error$i)|0);
             $77 = (($44) + ($indvars$iv25$i<<2)|0);
             HEAP32[$77>>2] = $76;
             $78 = HEAP32[$error$i>>2]|0;
             $79 = ($78|0)==(0);
             if (!($79)) {
              $indvars$iv$i = 0;
              break L56;
             }
             HEAP8[$76>>0] = 0;
             $indvars$iv$next26$i = (($indvars$iv25$i) + 1)|0;
             $80 = $indvars$iv$next26$i&65535;
             $81 = ($80&65535)<($num_names$0$lcssa$i&65535);
             if ($81) {
              $indvars$iv25$i = $indvars$iv$next26$i;
             } else {
              break L43;
             }
            }
           }
          } while(0);
          while(1) {
           $86 = (($44) + ($indvars$iv$i<<2)|0);
           $87 = HEAP32[$86>>2]|0;
           _ft_mem_free($14,$87);
           HEAP32[$86>>2] = 0;
           $indvars$iv$next$i = (($indvars$iv$i) + 1)|0;
           $lftr$wideiv = $indvars$iv$next$i&65535;
           $exitcond = ($lftr$wideiv<<16>>16)==($num_names$0$lcssa$i<<16>>16);
           if ($exitcond) {
            $name_strings$0$i = $44;
            break L28;
           } else {
            $indvars$iv$i = $indvars$iv$next$i;
           }
          }
         }
        } while(0);
        $82 = (($face) + 632|0);
        HEAP16[$82>>1] = $15;
        $83 = (($face) + 634|0);
        HEAP16[$83>>1] = $num_names$0$lcssa$i;
        $84 = (($face) + 636|0);
        HEAP32[$84>>2] = $22;
        $85 = (($face) + 640|0);
        HEAP32[$85>>2] = $44;
        $error$0 = 0;
        break L7;
       } else {
        $name_strings$0$i = $44;
       }
      } else {
       $name_strings$0$i = 0;
      }
     } else {
      $name_strings$0$i = 0;
     }
    } while(0);
    _ft_mem_free($14,$name_strings$0$i);
    _ft_mem_free($14,$22);
    $$pre$i = HEAP32[$error$i>>2]|0;
    $error$0 = $$pre$i;
   } else {
    $error$0 = $17;
   }
  } else {
   $error$0 = 3;
  }
 } while(0);
 $114 = (($face) + 628|0);
 HEAP8[$114>>0] = 1;
 $error$1 = $error$0;
 STACKTOP = sp;return ($error$1|0);
}
function _tt_face_lookup_table($face,$tag) {
 $face = $face|0;
 $tag = $tag|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $entry$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 152|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($1) + ($4<<4)|0);
 $6 = ($3<<16>>16)==(0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $entry$01 = $1;
 }
 while(1) {
  $7 = HEAP32[$entry$01>>2]|0;
  $8 = ($7|0)==($tag|0);
  if ($8) {
   $9 = (($entry$01) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $$0 = $entry$01;
    label = 5;
    break;
   }
  }
  $12 = (($entry$01) + 16|0);
  $13 = ($12>>>0)<($5>>>0);
  if ($13) {
   $entry$01 = $12;
  } else {
   $$0 = 0;
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _tt_face_goto_table($face,$tag,$stream,$length) {
 $face = $face|0;
 $tag = $tag|0;
 $stream = $stream|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $entry$01$i = 0;
 var $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 152|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = $3&65535;
 $5 = (($1) + ($4<<4)|0);
 $6 = ($3<<16>>16)==(0);
 if ($6) {
  $error$0 = 142;
  STACKTOP = sp;return ($error$0|0);
 } else {
  $entry$01$i = $1;
 }
 while(1) {
  $7 = HEAP32[$entry$01$i>>2]|0;
  $8 = ($7|0)==($tag|0);
  if ($8) {
   $9 = (($entry$01$i) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   if (!($11)) {
    break;
   }
  }
  $12 = (($entry$01$i) + 16|0);
  $13 = ($12>>>0)<($5>>>0);
  if ($13) {
   $entry$01$i = $12;
  } else {
   $error$0 = 142;
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return ($error$0|0);
 }
 $14 = ($entry$01$i|0)==(0|0);
 if ($14) {
  $error$0 = 142;
  STACKTOP = sp;return ($error$0|0);
 }
 $15 = ($length|0)==(0|0);
 if (!($15)) {
  HEAP32[$length>>2] = $10;
 }
 $16 = (($entry$01$i) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (_FT_Stream_Seek($stream,$17)|0);
 $error$0 = $18;
 STACKTOP = sp;return ($error$0|0);
}
function _tt_face_load_font_dir($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$has_meta$0$i = 0, $$ph = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $entry$0$ = 0, $entry$01 = 0, $error = 0, $error$i = 0, $has_head$030$i = 0, $has_head$06$i = 0, $has_head$1$i = 0;
 var $has_meta$016$i = 0, $has_meta$032$i = 0, $has_meta$1$i = 0, $has_sing$011$i = 0, $has_sing$031$i = 0, $has_sing$1$i = 0, $nn$02 = 0, $nn$034$i = 0, $or$cond$i = 0, $sfnt = 0, $table$i = 0, $valid_entries$033$i = 0, $valid_entries$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $error$i = sp + 36|0;
 $table$i = sp;
 $sfnt = sp + 16|0;
 $error = sp + 32|0;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_FT_Stream_Pos($stream)|0);
 $3 = (($sfnt) + 12|0);
 HEAP32[$3>>2] = $2;
 $4 = (_FT_Stream_ReadULong($stream,$error)|0);
 HEAP32[$sfnt>>2] = $4;
 $5 = HEAP32[$error>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $89 = $5;
  STACKTOP = sp;return ($89|0);
 }
 $7 = (_FT_Stream_ReadFields($stream,871592,$sfnt)|0);
 HEAP32[$error>>2] = $7;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $89 = $7;
  STACKTOP = sp;return ($89|0);
 }
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 12)|0;
 $11 = (_FT_Stream_Seek($stream,$10)|0);
 HEAP32[$error$i>>2] = $11;
 $12 = ($11|0)==(0);
 L7: do {
  if ($12) {
   $13 = (($sfnt) + 4|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = ($14<<16>>16)==(0);
   if ($15) {
    HEAP16[$13>>1] = 0;
   } else {
    $16 = (($table$i) + 8|0);
    $17 = (($table$i) + 12|0);
    $18 = (($stream) + 4|0);
    $19 = (($9) + 28)|0;
    $39 = 0;$has_head$030$i = 0;$has_meta$032$i = 0;$has_sing$031$i = 0;$nn$034$i = 0;$valid_entries$033$i = 0;
    L11: while(1) {
     $20 = (_FT_Stream_ReadFields($stream,872176,$table$i)|0);
     HEAP32[$error$i>>2] = $20;
     $21 = ($20|0)==(0);
     if (!($21)) {
      label = 8;
      break;
     }
     $23 = HEAP32[$16>>2]|0;
     $24 = HEAP32[$17>>2]|0;
     $25 = (($24) + ($23))|0;
     $26 = HEAP32[$18>>2]|0;
     $27 = ($25>>>0)>($26>>>0);
     do {
      if ($27) {
       $has_head$1$i = $has_head$030$i;$has_meta$1$i = $has_meta$032$i;$has_sing$1$i = $has_sing$031$i;$valid_entries$1$i = $valid_entries$033$i;
      } else {
       $28 = (($valid_entries$033$i) + 1)<<16>>16;
       $29 = HEAP32[$table$i>>2]|0;
       if ((($29|0) == 1397313095)) {
        $has_head$1$i = $has_head$030$i;$has_meta$1$i = $has_meta$032$i;$has_sing$1$i = 1;$valid_entries$1$i = $28;
        break;
       } else if (!((($29|0) == 1651008868) | (($29|0) == 1751474532))) {
        $43 = ($29|0)==(1296389185);
        $$has_meta$0$i = $43 ? 1 : $has_meta$032$i;
        $has_head$1$i = $has_head$030$i;$has_meta$1$i = $$has_meta$0$i;$has_sing$1$i = $has_sing$031$i;$valid_entries$1$i = $28;
        break;
       }
       $30 = ($24>>>0)<(54);
       if ($30) {
        label = 12;
        break L11;
       }
       $31 = (($23) + 12)|0;
       $32 = (_FT_Stream_Seek($stream,$31)|0);
       HEAP32[$error$i>>2] = $32;
       $33 = ($32|0)==(0);
       if (!($33)) {
        $$ph = $32;
        break L7;
       }
       $34 = (_FT_Stream_ReadULong($stream,$error$i)|0);
       $35 = HEAP32[$error$i>>2]|0;
       $36 = ($35|0)==(0);
       if (!($36)) {
        $$ph = $35;
        break L7;
       }
       $37 = ($34|0)==(1594834165);
       if (!($37)) {
        label = 16;
        break L11;
       }
       $38 = $39 << 4;
       $40 = (($19) + ($38))|0;
       $41 = (_FT_Stream_Seek($stream,$40)|0);
       HEAP32[$error$i>>2] = $41;
       $42 = ($41|0)==(0);
       if ($42) {
        $has_head$1$i = 1;$has_meta$1$i = $has_meta$032$i;$has_sing$1$i = $has_sing$031$i;$valid_entries$1$i = $28;
       } else {
        $$ph = $41;
        break L7;
       }
      }
     } while(0);
     $44 = (($nn$034$i) + 1)<<16>>16;
     $45 = $44&65535;
     $46 = HEAP16[$13>>1]|0;
     $47 = ($44&65535)<($46&65535);
     if ($47) {
      $39 = $45;$has_head$030$i = $has_head$1$i;$has_meta$032$i = $has_meta$1$i;$has_sing$031$i = $has_sing$1$i;$nn$034$i = $44;$valid_entries$033$i = $valid_entries$1$i;
     } else {
      $48 = $valid_entries$1$i;$has_head$06$i = $has_head$1$i;$has_meta$016$i = $has_meta$1$i;$has_sing$011$i = $has_sing$1$i;
      break;
     }
    }
    if ((label|0) == 8) {
     $22 = (($nn$034$i) + -1)<<16>>16;
     HEAP16[$13>>1] = $22;
     $48 = $valid_entries$033$i;$has_head$06$i = $has_head$030$i;$has_meta$016$i = $has_meta$032$i;$has_sing$011$i = $has_sing$031$i;
    }
    else if ((label|0) == 12) {
     HEAP32[$error$i>>2] = 142;
     $$ph = 142;
     break;
    }
    else if ((label|0) == 16) {
     HEAP32[$error$i>>2] = 142;
     $$ph = 142;
     break;
    }
    HEAP16[$13>>1] = $48;
    $49 = ($48<<16>>16)==(0);
    if (!($49)) {
     $50 = ($has_head$06$i|0)==(0);
     if ($50) {
      $51 = ($has_sing$011$i|0)==(0);
      $52 = ($has_meta$016$i|0)==(0);
      $or$cond$i = $51 | $52;
      if ($or$cond$i) {
       HEAP32[$error$i>>2] = 142;
       $$ph = 142;
       break;
      }
     }
     HEAP32[$error>>2] = 0;
     $53 = (($face) + 152|0);
     HEAP16[$53>>1] = $48;
     $54 = HEAP32[$sfnt>>2]|0;
     $55 = (($face) + 148|0);
     HEAP32[$55>>2] = $54;
     $56 = $48&65535;
     $57 = (_ft_mem_realloc($1,16,0,$56,0,$error)|0);
     $58 = (($face) + 156|0);
     HEAP32[$58>>2] = $57;
     $59 = HEAP32[$error>>2]|0;
     $60 = ($59|0)==(0);
     if (!($60)) {
      $89 = $59;
      STACKTOP = sp;return ($89|0);
     }
     $61 = HEAP32[$3>>2]|0;
     $62 = (($61) + 12)|0;
     $63 = (_FT_Stream_Seek($stream,$62)|0);
     HEAP32[$error>>2] = $63;
     $64 = ($63|0)==(0);
     if (!($64)) {
      $89 = $63;
      STACKTOP = sp;return ($89|0);
     }
     $65 = HEAP16[$53>>1]|0;
     $66 = $65&65535;
     $67 = $66 << 4;
     $68 = (_FT_Stream_EnterFrame($stream,$67)|0);
     HEAP32[$error>>2] = $68;
     $69 = ($68|0)==(0);
     if (!($69)) {
      $89 = $68;
      STACKTOP = sp;return ($89|0);
     }
     $70 = HEAP16[$13>>1]|0;
     $71 = ($70<<16>>16)==(0);
     if (!($71)) {
      $72 = HEAP32[$58>>2]|0;
      $entry$01 = $72;$nn$02 = 0;
      while(1) {
       $73 = (_FT_Stream_GetULong($stream)|0);
       HEAP32[$entry$01>>2] = $73;
       $74 = (_FT_Stream_GetULong($stream)|0);
       $75 = (($entry$01) + 4|0);
       HEAP32[$75>>2] = $74;
       $76 = (_FT_Stream_GetULong($stream)|0);
       $77 = (($entry$01) + 8|0);
       HEAP32[$77>>2] = $76;
       $78 = (_FT_Stream_GetULong($stream)|0);
       $79 = (($entry$01) + 12|0);
       HEAP32[$79>>2] = $78;
       $80 = HEAP32[$77>>2]|0;
       $81 = (($80) + ($78))|0;
       $82 = HEAP32[$18>>2]|0;
       $83 = ($81>>>0)>($82>>>0);
       $84 = (($entry$01) + 16|0);
       $entry$0$ = $83 ? $entry$01 : $84;
       $85 = (($nn$02) + 1)|0;
       $86 = HEAP16[$13>>1]|0;
       $87 = $86&65535;
       $88 = ($85|0)<($87|0);
       if ($88) {
        $entry$01 = $entry$0$;$nn$02 = $85;
       } else {
        break;
       }
      }
     }
     _FT_Stream_ExitFrame($stream);
     $$pre = HEAP32[$error>>2]|0;
     $89 = $$pre;
     STACKTOP = sp;return ($89|0);
    }
   }
   HEAP32[$error$i>>2] = 2;
   $$ph = 2;
  } else {
   $$ph = $11;
  }
 } while(0);
 HEAP32[$error>>2] = $$ph;
 $89 = $$ph;
 STACKTOP = sp;return ($89|0);
}
function _tt_face_load_any($face,$tag,$offset,$buffer,$length) {
 $face = $face|0;
 $tag = $tag|0;
 $offset = $offset|0;
 $buffer = $buffer|0;
 $length = $length|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $entry$01$i = 0, $size$0 = 0, $size$0$pre = 0, $size$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($tag|0)==(0);
 do {
  if ($0) {
   $19 = (($face) + 104|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 4|0);
   $size$0$pre = HEAP32[$21>>2]|0;
   $$01 = $offset;$size$0 = $size$0$pre;
  } else {
   $1 = (($face) + 156|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = (($face) + 152|0);
   $4 = HEAP16[$3>>1]|0;
   $5 = $4&65535;
   $6 = (($2) + ($5<<4)|0);
   $7 = ($4<<16>>16)==(0);
   if ($7) {
    $$0 = 142;
    STACKTOP = sp;return ($$0|0);
   } else {
    $entry$01$i = $2;
   }
   while(1) {
    $8 = HEAP32[$entry$01$i>>2]|0;
    $9 = ($8|0)==($tag|0);
    if ($9) {
     $10 = (($entry$01$i) + 12|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==(0);
     if (!($12)) {
      break;
     }
    }
    $13 = (($entry$01$i) + 16|0);
    $14 = ($13>>>0)<($6>>>0);
    if ($14) {
     $entry$01$i = $13;
    } else {
     $$0 = 142;
     label = 13;
     break;
    }
   }
   if ((label|0) == 13) {
    STACKTOP = sp;return ($$0|0);
   }
   $15 = ($entry$01$i|0)==(0|0);
   if ($15) {
    $$0 = 142;
    STACKTOP = sp;return ($$0|0);
   } else {
    $16 = (($entry$01$i) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + ($offset))|0;
    $$01 = $18;$size$0 = $11;
    break;
   }
  }
 } while(0);
 $22 = ($length|0)==(0|0);
 if ($22) {
  $size$1 = $size$0;
 } else {
  $23 = HEAP32[$length>>2]|0;
  $24 = ($23|0)==(0);
  if ($24) {
   HEAP32[$length>>2] = $size$0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $size$1 = $23;
  }
 }
 $25 = (($face) + 104|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (_FT_Stream_ReadAt($26,$$01,$buffer,$size$1)|0);
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function _tt_face_load_head($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $error$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1751474532,$stream,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $error$0$i = $2;
  STACKTOP = sp;return ($error$0$i|0);
 }
 $4 = (($face) + 160|0);
 $5 = (_FT_Stream_ReadFields($stream,872088,$4)|0);
 $error$0$i = $5;
 STACKTOP = sp;return ($error$0$i|0);
}
function _tt_face_load_bhed($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $error$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1651008868,$stream,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $error$0$i = $2;
  STACKTOP = sp;return ($error$0$i|0);
 }
 $4 = (($face) + 160|0);
 $5 = (_FT_Stream_ReadFields($stream,872088,$4)|0);
 $error$0$i = $5;
 STACKTOP = sp;return ($error$0$i|0);
}
function _tt_face_load_maxp($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $error$0 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($face) + 260|0);
 $1 = (($face) + 508|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiiii[$2 & 511]($face,1835104368,$stream,0)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (_FT_Stream_ReadFields($stream,871616,$0)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = (($face) + 266|0);
   $8 = (($face) + 276|0);
   $9 = (($face) + 280|0);
   $10 = (($face) + 290|0);
   dest=$7+0|0; stop=dest+26|0; do { HEAP16[dest>>1]=0|0; dest=dest+2|0; } while ((dest|0) < (stop|0));
   $11 = HEAP32[$0>>2]|0;
   $12 = ($11|0)>(65535);
   if ($12) {
    $13 = (_FT_Stream_ReadFields($stream,871632,$0)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     $15 = HEAP16[$9>>1]|0;
     $16 = ($15&65535)<(64);
     if ($16) {
      HEAP16[$9>>1] = 64;
     }
     $17 = HEAP16[$8>>1]|0;
     $18 = ($17&65535)>(65531);
     if ($18) {
      HEAP16[$8>>1] = -5;
     }
     $19 = HEAP16[$10>>1]|0;
     $20 = ($19&65535)>(100);
     if ($20) {
      HEAP16[$10>>1] = 100;
      $error$0 = 0;
     } else {
      $error$0 = 0;
     }
    } else {
     $error$0 = $13;
    }
   } else {
    $error$0 = 0;
   }
  } else {
   $error$0 = $5;
  }
 } else {
  $error$0 = $3;
 }
 STACKTOP = sp;return ($error$0|0);
}
function _tt_face_load_name($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $entry$0$lcssa = 0, $entry$02 = 0, $entry$1 = 0;
 var $error = 0, $table_len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp + 4|0;
 $table_len = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 364|0);
 HEAP32[$2>>2] = $stream;
 $3 = (($face) + 508|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$4 & 511]($face,1851878757,$stream,$table_len)|0);
 HEAP32[$error>>2] = $5;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $53 = $5;
  STACKTOP = sp;return ($53|0);
 }
 $7 = (($face) + 348|0);
 $8 = (_FT_Stream_Pos($stream)|0);
 $9 = (_FT_Stream_ReadFields($stream,871696,$7)|0);
 HEAP32[$error>>2] = $9;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $53 = $9;
  STACKTOP = sp;return ($53|0);
 }
 $11 = (($8) + 6)|0;
 $12 = (($face) + 352|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13*12)|0;
 $15 = (($11) + ($14))|0;
 $16 = HEAP32[$table_len>>2]|0;
 $17 = (($16) + ($8))|0;
 $18 = ($15>>>0)>($17>>>0);
 if ($18) {
  HEAP32[$error>>2] = 145;
  $53 = 145;
  STACKTOP = sp;return ($53|0);
 }
 HEAP32[$12>>2] = 0;
 $19 = (_ft_mem_realloc($1,20,0,$13,0,$error)|0);
 $20 = (($face) + 360|0);
 HEAP32[$20>>2] = $19;
 $21 = HEAP32[$error>>2]|0;
 $22 = ($21|0)==(0);
 if (!($22)) {
  $53 = $21;
  STACKTOP = sp;return ($53|0);
 }
 $23 = (_FT_Stream_EnterFrame($stream,$14)|0);
 HEAP32[$error>>2] = $23;
 $24 = ($23|0)==(0);
 if (!($24)) {
  $53 = $23;
  STACKTOP = sp;return ($53|0);
 }
 $25 = HEAP32[$20>>2]|0;
 $26 = ($13|0)==(0);
 if ($26) {
  $47 = $25;$entry$0$lcssa = $25;
 } else {
  $27 = (($face) + 356|0);
  $count$01 = $13;$entry$02 = $25;
  while(1) {
   $28 = (_FT_Stream_ReadFields($stream,871720,$entry$02)|0);
   HEAP32[$error>>2] = $28;
   $29 = ($28|0)==(0);
   do {
    if ($29) {
     $30 = (($entry$02) + 8|0);
     $31 = HEAP16[$30>>1]|0;
     $32 = ($31<<16>>16)==(0);
     if ($32) {
      $entry$1 = $entry$02;
     } else {
      $33 = HEAP32[$27>>2]|0;
      $34 = (($33) + ($8))|0;
      $35 = (($entry$02) + 12|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($34) + ($36))|0;
      HEAP32[$35>>2] = $37;
      $38 = ($37>>>0)<($15>>>0);
      if (!($38)) {
       $39 = $31&65535;
       $40 = (($39) + ($37))|0;
       $41 = ($40>>>0)>($17>>>0);
       if (!($41)) {
        $42 = (($entry$02) + 20|0);
        $entry$1 = $42;
        break;
       }
      }
      HEAP32[$35>>2] = 0;
      HEAP16[$30>>1] = 0;
      $entry$1 = $entry$02;
     }
    } else {
     $entry$1 = $entry$02;
    }
   } while(0);
   $43 = (($count$01) + -1)|0;
   $44 = ($43|0)==(0);
   if ($44) {
    break;
   } else {
    $count$01 = $43;$entry$02 = $entry$1;
   }
  }
  $$pre = HEAP32[$20>>2]|0;
  $47 = $$pre;$entry$0$lcssa = $entry$1;
 }
 $45 = $entry$0$lcssa;
 $46 = $47;
 $48 = (($45) - ($46))|0;
 $49 = (($48|0) / 20)&-1;
 HEAP32[$12>>2] = $49;
 _FT_Stream_ExitFrame($stream);
 $50 = HEAP32[$12>>2]|0;
 $51 = $50&65535;
 $52 = (($face) + 344|0);
 HEAP16[$52>>1] = $51;
 $$pre3 = HEAP32[$error>>2]|0;
 $53 = $$pre3;
 STACKTOP = sp;return ($53|0);
}
function _tt_face_free_name($face) {
 $face = $face|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02 = 0, $entry$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($face) + 360|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($face) + 352|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==(0|0);
 if (!($8)) {
  $9 = ($7|0)==(0);
  if ($9) {
   $16 = $5;
  } else {
   $count$02 = $7;$entry$01 = $5;
   while(1) {
    $10 = (($entry$01) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    _ft_mem_free($3,$11);
    HEAP32[$10>>2] = 0;
    $12 = (($entry$01) + 8|0);
    HEAP16[$12>>1] = 0;
    $13 = (($count$02) + -1)|0;
    $14 = (($entry$01) + 20|0);
    $15 = ($13|0)==(0);
    if ($15) {
     break;
    } else {
     $count$02 = $13;$entry$01 = $14;
    }
   }
   $$pre = HEAP32[$4>>2]|0;
   $16 = $$pre;
  }
  _ft_mem_free($3,$16);
  HEAP32[$4>>2] = 0;
 }
 HEAP32[$6>>2] = 0;
 $17 = (($face) + 348|0);
 HEAP16[$17>>1] = 0;
 $18 = (($face) + 356|0);
 HEAP32[$18>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_face_load_cmap($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 504|0);
 $3 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1668112752,$stream,$2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = HEAP32[$2>>2]|0;
  $6 = (($face) + 500|0);
  $7 = (_FT_Stream_ExtractFrame($stream,$5,$6)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $error$0 = 0;
  } else {
   HEAP32[$2>>2] = 0;
   $error$0 = $7;
  }
 } else {
  $error$0 = $3;
 }
 STACKTOP = sp;return ($error$0|0);
}
function _tt_face_load_os2($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1330851634,$stream,0)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (($face) + 368|0);
  $5 = (_FT_Stream_ReadFields($stream,871752,$4)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = (($face) + 448|0);
   ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP16[$7+16>>1]=0|0;
   $8 = HEAP16[$4>>1]|0;
   $9 = ($8<<16>>16)==(0);
   if ($9) {
    $error$0 = 0;
   } else {
    $10 = (_FT_Stream_ReadFields($stream,871928,$4)|0);
    $11 = ($10|0)==(0);
    if ($11) {
     $12 = HEAP16[$4>>1]|0;
     $13 = ($12&65535)>(1);
     if ($13) {
      $14 = (_FT_Stream_ReadFields($stream,871944,$4)|0);
      $error$0 = $14;
     } else {
      $error$0 = 0;
     }
    } else {
     $error$0 = $10;
    }
   }
  } else {
   $error$0 = $5;
  }
 } else {
  $error$0 = $2;
 }
 STACKTOP = sp;return ($error$0|0);
}
function _tt_face_load_post($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1886352244,$stream,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($face) + 468|0);
 $5 = (_FT_Stream_ReadFields($stream,871976,$4)|0);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function _tt_face_load_pclt($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1346587732,$stream,0)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $error$0 = $2;
  STACKTOP = sp;return ($error$0|0);
 }
 $4 = (($face) + 556|0);
 $5 = (_FT_Stream_ReadFields($stream,872024,$4)|0);
 $error$0 = $5;
 STACKTOP = sp;return ($error$0|0);
}
function _tt_face_load_gasp($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $exitcond = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 508|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiiii[$3 & 511]($face,1734439792,$stream,0)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $29 = $4;
  STACKTOP = sp;return ($29|0);
 }
 $6 = (_FT_Stream_EnterFrame($stream,4)|0);
 HEAP32[$error>>2] = $6;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $29 = $6;
  STACKTOP = sp;return ($29|0);
 }
 $8 = (_FT_Stream_GetUShort($stream)|0);
 $9 = (($face) + 548|0);
 HEAP16[$9>>1] = $8;
 $10 = (_FT_Stream_GetUShort($stream)|0);
 $11 = (($face) + 550|0);
 HEAP16[$11>>1] = $10;
 _FT_Stream_ExitFrame($stream);
 $12 = HEAP16[$9>>1]|0;
 $13 = ($12&65535)>(1);
 if ($13) {
  HEAP16[$11>>1] = 0;
  HEAP32[$error>>2] = 8;
  $29 = 8;
  STACKTOP = sp;return ($29|0);
 }
 $14 = HEAP16[$11>>1]|0;
 $15 = $14&65535;
 $16 = (_ft_mem_realloc($1,4,0,$15,0,$error)|0);
 $17 = HEAP32[$error>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $29 = $17;
  STACKTOP = sp;return ($29|0);
 }
 $19 = $15 << 2;
 $20 = (_FT_Stream_EnterFrame($stream,$19)|0);
 HEAP32[$error>>2] = $20;
 $21 = ($20|0)==(0);
 if (!($21)) {
  $29 = $20;
  STACKTOP = sp;return ($29|0);
 }
 $22 = (($face) + 552|0);
 HEAP32[$22>>2] = $16;
 $23 = ($14<<16>>16)==(0);
 if (!($23)) {
  $j$01 = 0;
  while(1) {
   $24 = (_FT_Stream_GetUShort($stream)|0);
   $25 = (($16) + ($j$01<<2)|0);
   HEAP16[$25>>1] = $24;
   $26 = (_FT_Stream_GetUShort($stream)|0);
   $27 = ((($16) + ($j$01<<2)|0) + 2|0);
   HEAP16[$27>>1] = $26;
   $28 = (($j$01) + 1)|0;
   $exitcond = ($28|0)==($15|0);
   if ($exitcond) {
    break;
   } else {
    $j$01 = $28;
   }
  }
 }
 _FT_Stream_ExitFrame($stream);
 $$pre = HEAP32[$error>>2]|0;
 $29 = $$pre;
 STACKTOP = sp;return ($29|0);
}
function _tt_face_load_eblc($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$0$i$i = 0, $$ph = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$022 = 0, $count2$017 = 0, $count23$02 = 0, $count23$111 = 0, $error = 0, $error$i = 0, $error$i1$i = 0, $exitcond$i = 0, $exitcond5$i = 0, $n$04$i = 0;
 var $n$04$us$i = 0, $or$cond = 0, $range$01 = 0, $range$19 = 0, $strike$021 = 0, $strike1$016 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i1$i = sp + 8|0;
 $error$i = sp;
 $error = sp + 4|0;
 HEAP32[$error>>2] = 0;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 612|0);
 HEAP32[$2>>2] = 0;
 $3 = (($face) + 508|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$4 & 511]($face,1161972803,$stream,0)|0);
 HEAP32[$error>>2] = $5;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = HEAP32[$3>>2]|0;
  $8 = (FUNCTION_TABLE_iiiii[$7 & 511]($face,1651273571,$stream,0)|0);
  HEAP32[$error>>2] = $8;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $145 = $8;
   STACKTOP = sp;return ($145|0);
  }
 }
 $10 = (_FT_Stream_Pos($stream)|0);
 $11 = (_FT_Stream_EnterFrame($stream,8)|0);
 HEAP32[$error>>2] = $11;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $145 = $11;
  STACKTOP = sp;return ($145|0);
 }
 $13 = (_FT_Stream_GetULong($stream)|0);
 $14 = (_FT_Stream_GetULong($stream)|0);
 _FT_Stream_ExitFrame($stream);
 $15 = ($13|0)!=(131072);
 $16 = ($14>>>0)>(65535);
 $or$cond = $15 | $16;
 if ($or$cond) {
  HEAP32[$error>>2] = 3;
  $145 = 3;
  STACKTOP = sp;return ($145|0);
 }
 $17 = (_ft_mem_realloc($1,48,0,$14,0,$error)|0);
 $18 = (($face) + 616|0);
 HEAP32[$18>>2] = $17;
 $19 = HEAP32[$error>>2]|0;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $145 = $19;
  STACKTOP = sp;return ($145|0);
 }
 HEAP32[$2>>2] = $14;
 $21 = ($14*48)|0;
 $22 = (_FT_Stream_EnterFrame($stream,$21)|0);
 HEAP32[$error>>2] = $22;
 $23 = ($22|0)==(0);
 if (!($23)) {
  $145 = $22;
  STACKTOP = sp;return ($145|0);
 }
 $24 = ($14|0)==(0);
 L18: do {
  if ($24) {
   _FT_Stream_ExitFrame($stream);
  } else {
   $count$022 = $14;$strike$021 = $17;
   while(1) {
    $25 = (_FT_Stream_ReadFields($stream,872256,$strike$021)|0);
    HEAP32[$error>>2] = $25;
    $26 = ($25|0)==(0);
    if (!($26)) {
     break;
    }
    $27 = (($strike$021) + 16|0);
    $28 = (_FT_Stream_ReadFields($stream,872200,$27)|0);
    HEAP32[$error>>2] = $28;
    $29 = ($28|0)==(0);
    if (!($29)) {
     break;
    }
    $30 = (($strike$021) + 28|0);
    $31 = (_FT_Stream_ReadFields($stream,872200,$30)|0);
    HEAP32[$error>>2] = $31;
    $32 = ($31|0)==(0);
    if (!($32)) {
     break;
    }
    $33 = (_FT_Stream_ReadFields($stream,872280,$strike$021)|0);
    HEAP32[$error>>2] = $33;
    $34 = ($33|0)==(0);
    if (!($34)) {
     break;
    }
    $35 = (($count$022) + -1)|0;
    $36 = (($strike$021) + 48|0);
    $37 = ($35|0)==(0);
    if ($37) {
     break;
    } else {
     $count$022 = $35;$strike$021 = $36;
    }
   }
   _FT_Stream_ExitFrame($stream);
   if (!($24)) {
    $38 = HEAP32[$18>>2]|0;
    $count2$017 = $14;$strike1$016 = $38;
    L28: while(1) {
     $39 = HEAP32[$strike1$016>>2]|0;
     $40 = (($strike1$016) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = (($41) + ($10))|0;
     $43 = (_FT_Stream_Seek($stream,$42)|0);
     HEAP32[$error>>2] = $43;
     $44 = ($43|0)==(0);
     if (!($44)) {
      break L18;
     }
     $45 = HEAP32[$strike1$016>>2]|0;
     $46 = $45 << 3;
     $47 = (_FT_Stream_EnterFrame($stream,$46)|0);
     HEAP32[$error>>2] = $47;
     $48 = ($47|0)==(0);
     if (!($48)) {
      break L18;
     }
     $49 = HEAP32[$strike1$016>>2]|0;
     $50 = (_ft_mem_realloc($1,40,0,$49,0,$error)|0);
     $51 = (($strike1$016) + 4|0);
     HEAP32[$51>>2] = $50;
     $52 = HEAP32[$error>>2]|0;
     $53 = ($52|0)==(0);
     if (!($53)) {
      break L18;
     }
     $54 = ($39|0)==(0);
     if (!($54)) {
      $count23$02 = $39;$range$01 = $50;
      while(1) {
       $55 = (_FT_Stream_GetUShort($stream)|0);
       HEAP16[$range$01>>1] = $55;
       $56 = (_FT_Stream_GetUShort($stream)|0);
       $57 = (($range$01) + 2|0);
       HEAP16[$57>>1] = $56;
       $58 = HEAP32[$40>>2]|0;
       $59 = (($58) + ($10))|0;
       $60 = (_FT_Stream_GetULong($stream)|0);
       $61 = (($59) + ($60))|0;
       $62 = (($range$01) + 36|0);
       HEAP32[$62>>2] = $61;
       $63 = (($count23$02) + -1)|0;
       $64 = (($range$01) + 40|0);
       $65 = ($63|0)==(0);
       if ($65) {
        break;
       } else {
        $count23$02 = $63;$range$01 = $64;
       }
      }
     }
     _FT_Stream_ExitFrame($stream);
     $66 = HEAP32[$strike1$016>>2]|0;
     $67 = ($66|0)==(0);
     L37: do {
      if (!($67)) {
       $68 = HEAP32[$51>>2]|0;
       $count23$111 = $66;$range$19 = $68;
       while(1) {
        $69 = (($range$19) + 36|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = (_FT_Stream_Seek($stream,$70)|0);
        HEAP32[$error>>2] = $71;
        $72 = ($71|0)==(0);
        if (!($72)) {
         $145 = $71;
         label = 50;
         break L28;
        }
        $73 = (_FT_Stream_EnterFrame($stream,8)|0);
        HEAP32[$error>>2] = $73;
        $74 = ($73|0)==(0);
        if (!($74)) {
         $145 = $73;
         label = 50;
         break L28;
        }
        $75 = (_FT_Stream_GetUShort($stream)|0);
        $76 = (($range$19) + 4|0);
        HEAP16[$76>>1] = $75;
        $77 = (_FT_Stream_GetUShort($stream)|0);
        $78 = (($range$19) + 6|0);
        HEAP16[$78>>1] = $77;
        $79 = (_FT_Stream_GetULong($stream)|0);
        $80 = (($range$19) + 8|0);
        HEAP32[$80>>2] = $79;
        _FT_Stream_ExitFrame($stream);
        $81 = HEAP32[$0>>2]|0;
        $82 = HEAP16[$76>>1]|0;
        $83 = $82&65535;
        L43: do {
         switch ($83|0) {
         case 3: case 1:  {
          $84 = (($range$19) + 2|0);
          $85 = HEAP16[$84>>1]|0;
          $86 = HEAP16[$range$19>>1]|0;
          $87 = ($85&65535)<($86&65535);
          if ($87) {
           label = 28;
           break L28;
          }
          $88 = $85&65535;
          $89 = $86&65535;
          $90 = ($82<<16>>16)==(1);
          $91 = (($88) - ($89))|0;
          $92 = (($91) + 1)|0;
          $93 = (($range$19) + 24|0);
          HEAP32[$93>>2] = $92;
          $94 = (($91) + 2)|0;
          $95 = (_ft_mem_realloc($81,4,0,$94,0,$error$i)|0);
          $96 = (($range$19) + 28|0);
          HEAP32[$96>>2] = $95;
          $97 = HEAP32[$error$i>>2]|0;
          $98 = ($97|0)==(0);
          if (!($98)) {
           $$ph = $97;
           break L28;
          }
          $99 = $90 ? 4 : 2;
          $100 = Math_imul($94, $99)|0;
          $101 = (_FT_Stream_EnterFrame($stream,$100)|0);
          HEAP32[$error$i>>2] = $101;
          $102 = ($101|0)==(0);
          if (!($102)) {
           $$ph = $101;
           break L28;
          }
          $103 = ($94|0)==(0);
          if (!($103)) {
           $104 = (($88) + 2)|0;
           $105 = (($104) - ($89))|0;
           if ($90) {
            $n$04$us$i = 0;
            while(1) {
             $106 = HEAP32[$80>>2]|0;
             $107 = (_FT_Stream_GetULong($stream)|0);
             $108 = (($107) + ($106))|0;
             $109 = HEAP32[$96>>2]|0;
             $110 = (($109) + ($n$04$us$i<<2)|0);
             HEAP32[$110>>2] = $108;
             $111 = (($n$04$us$i) + 1)|0;
             $exitcond5$i = ($111|0)==($105|0);
             if ($exitcond5$i) {
              break;
             } else {
              $n$04$us$i = $111;
             }
            }
           } else {
            $n$04$i = 0;
            while(1) {
             $112 = HEAP32[$80>>2]|0;
             $113 = (_FT_Stream_GetUShort($stream)|0);
             $114 = $113&65535;
             $115 = (($114) + ($112))|0;
             $116 = HEAP32[$96>>2]|0;
             $117 = (($116) + ($n$04$i<<2)|0);
             HEAP32[$117>>2] = $115;
             $118 = (($n$04$i) + 1)|0;
             $exitcond$i = ($118|0)==($105|0);
             if ($exitcond$i) {
              break;
             } else {
              $n$04$i = $118;
             }
            }
           }
          }
          _FT_Stream_ExitFrame($stream);
          $$pre$i = HEAP32[$error$i>>2]|0;
          $137 = $$pre$i;
          break;
         }
         case 4:  {
          $127 = (_Load_SBit_Range_Codes($range$19,$stream,1)|0);
          HEAP32[$error$i>>2] = $127;
          $137 = $127;
          break;
         }
         case 5:  {
          $128 = (_FT_Stream_ReadULong($stream,$error$i1$i)|0);
          $129 = (($range$19) + 12|0);
          HEAP32[$129>>2] = $128;
          $130 = HEAP32[$error$i1$i>>2]|0;
          $131 = ($130|0)==(0);
          if (!($131)) {
           label = 41;
           break L28;
          }
          $132 = (($range$19) + 16|0);
          $133 = (_FT_Stream_ReadFields($stream,872344,$132)|0);
          $134 = ($133|0)!=(0);
          $135 = $134&1;
          HEAP32[$error$i>>2] = $135;
          if ($134) {
           $137 = $135;
           break L43;
          }
          $136 = (_Load_SBit_Range_Codes($range$19,$stream,0)|0);
          HEAP32[$error$i>>2] = $136;
          $137 = $136;
          break;
         }
         case 2:  {
          $119 = (_FT_Stream_ReadULong($stream,$error$i1$i)|0);
          $120 = (($range$19) + 12|0);
          HEAP32[$120>>2] = $119;
          $121 = HEAP32[$error$i1$i>>2]|0;
          $122 = ($121|0)==(0);
          if ($122) {
           $123 = (($range$19) + 16|0);
           $124 = (_FT_Stream_ReadFields($stream,872344,$123)|0);
           HEAP32[$error$i1$i>>2] = $124;
           $125 = ($124|0)!=(0);
           $126 = $125&1;
           $$0$i$i = $126;
          } else {
           $$0$i$i = $121;
          }
          HEAP32[$error$i>>2] = $$0$i$i;
          $137 = $$0$i$i;
          break;
         }
         default: {
          label = 44;
          break L28;
         }
         }
        } while(0);
        HEAP32[$error>>2] = $137;
        $138 = ($137|0)==(0);
        if (!($138)) {
         $145 = $137;
         label = 50;
         break L28;
        }
        $139 = (($count23$111) + -1)|0;
        $140 = (($range$19) + 40|0);
        $141 = ($139|0)==(0);
        if ($141) {
         break L37;
        } else {
         $count23$111 = $139;$range$19 = $140;
        }
       }
      }
     } while(0);
     $142 = (($count2$017) + -1)|0;
     $143 = (($strike1$016) + 48|0);
     $144 = ($142|0)==(0);
     if ($144) {
      break L18;
     } else {
      $count2$017 = $142;$strike1$016 = $143;
     }
    }
    if ((label|0) == 28) {
     HEAP32[$error$i>>2] = 3;
     $$ph = 3;
    }
    else if ((label|0) == 41) {
     HEAP32[$error$i>>2] = $130;
     $$ph = $130;
    }
    else if ((label|0) == 44) {
     HEAP32[$error$i>>2] = 3;
     $$ph = 3;
    }
    else if ((label|0) == 50) {
     STACKTOP = sp;return ($145|0);
    }
    HEAP32[$error>>2] = $$ph;
    $145 = $$ph;
    STACKTOP = sp;return ($145|0);
   }
  }
 } while(0);
 $$pre = HEAP32[$error>>2]|0;
 $145 = $$pre;
 STACKTOP = sp;return ($145|0);
}
function _tt_face_free_eblc($face) {
 $face = $face|0;
 var $$pre = 0, $$pre5$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $range$01 = 0, $strike$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 616|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($face) + 612|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + (($5*48)|0)|0);
 $7 = ($3|0)==(0|0);
 if ($7) {
  HEAP32[$4>>2] = 0;
  STACKTOP = sp;return;
 }
 $8 = ($5|0)>(0);
 if ($8) {
  $strike$03 = $3;
  while(1) {
   $9 = (($strike$03) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$strike$03>>2]|0;
   $12 = (($10) + (($11*40)|0)|0);
   $13 = ($10|0)==(0|0);
   if ($13) {
    $21 = 0;
   } else {
    $14 = ($11|0)>(0);
    if ($14) {
     $range$01 = $10;
     while(1) {
      $15 = (($range$01) + 28|0);
      $16 = HEAP32[$15>>2]|0;
      _ft_mem_free($1,$16);
      HEAP32[$15>>2] = 0;
      $17 = (($range$01) + 32|0);
      $18 = HEAP32[$17>>2]|0;
      _ft_mem_free($1,$18);
      HEAP32[$17>>2] = 0;
      $19 = (($range$01) + 40|0);
      $20 = ($19>>>0)<($12>>>0);
      if ($20) {
       $range$01 = $19;
      } else {
       break;
      }
     }
     $$pre5$pre = HEAP32[$9>>2]|0;
     $21 = $$pre5$pre;
    } else {
     $21 = $10;
    }
   }
   _ft_mem_free($1,$21);
   HEAP32[$9>>2] = 0;
   HEAP32[$strike$03>>2] = 0;
   $22 = (($strike$03) + 48|0);
   $23 = ($22>>>0)<($6>>>0);
   if ($23) {
    $strike$03 = $22;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$2>>2]|0;
  $24 = $$pre;
 } else {
  $24 = $3;
 }
 _ft_mem_free($1,$24);
 HEAP32[$2>>2] = 0;
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_face_set_sbit_strike($face,$req,$astrike_index) {
 $face = $face|0;
 $req = $req|0;
 $astrike_index = $astrike_index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_FT_Match_Size($face,$req,0,$astrike_index)|0);
 STACKTOP = sp;return ($0|0);
}
function _tt_face_load_strike_metrics($face,$strike_index,$metrics) {
 $face = $face|0;
 $strike_index = $strike_index|0;
 $metrics = $metrics|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 612|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($strike_index>>>0);
 if (!($2)) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($face) + 616|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($strike_index*48)|0)|0) + 44|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 HEAP16[$metrics>>1] = $7;
 $8 = ((($4) + (($strike_index*48)|0)|0) + 45|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = (($metrics) + 2|0);
 HEAP16[$11>>1] = $10;
 $12 = ((($4) + (($strike_index*48)|0)|0) + 16|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13 << 24 >> 24;
 $15 = $14 << 6;
 $16 = (($metrics) + 12|0);
 HEAP32[$16>>2] = $15;
 $17 = ((($4) + (($strike_index*48)|0)|0) + 17|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18 << 24 >> 24;
 $20 = $19 << 6;
 $21 = (($metrics) + 16|0);
 HEAP32[$21>>2] = $20;
 $22 = ((($4) + (($strike_index*48)|0)|0) + 22|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23 << 24 >> 24;
 $25 = ((($4) + (($strike_index*48)|0)|0) + 18|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = (($27) + ($24))|0;
 $29 = ((($4) + (($strike_index*48)|0)|0) + 23|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = $30 << 24 >> 24;
 $32 = (($28) + ($31))|0;
 $33 = $32 << 6;
 $34 = (($metrics) + 24|0);
 HEAP32[$34>>2] = $33;
 $35 = (($15) - ($20))|0;
 $36 = (($metrics) + 20|0);
 HEAP32[$36>>2] = $35;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _tt_find_sbit_image($face,$glyph_index,$strike_index,$arange,$astrike,$aglyph_offset) {
 $face = $face|0;
 $glyph_index = $glyph_index|0;
 $strike_index = $strike_index|0;
 $arange = $arange|0;
 $astrike = $astrike|0;
 $aglyph_offset = $aglyph_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 616|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($face) + 612|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4>>>0)>($strike_index>>>0);
  if ($5) {
   $6 = (($1) + (($strike_index*48)|0)|0);
   $7 = (_find_sbit_range($glyph_index,$6,$arange,$aglyph_offset)|0);
   $8 = ($7|0)==(0);
   if ($8) {
    HEAP32[$astrike>>2] = $6;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 HEAP32[$arange>>2] = 0;
 HEAP32[$astrike>>2] = 0;
 HEAP32[$aglyph_offset>>2] = 0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function _find_sbit_range($glyph_index,$strike,$arange,$aglyph_offset) {
 $glyph_index = $glyph_index|0;
 $strike = $strike|0;
 $arange = $arange|0;
 $aglyph_offset = $aglyph_offset|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $n$02 = 0, $or$cond = 0, $range$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($strike) + 40|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = ($2>>>0)>($glyph_index>>>0);
 L1: do {
  if (!($3)) {
   $4 = (($strike) + 42|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = $5&65535;
   $7 = ($6>>>0)<($glyph_index>>>0);
   if (!($7)) {
    $8 = (($strike) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = HEAP32[$strike>>2]|0;
    $11 = (($9) + (($10*40)|0)|0);
    $12 = ($9|0)!=(0|0);
    $13 = ($10|0)>(0);
    $or$cond = $12 & $13;
    if ($or$cond) {
     $range$07 = $9;
     while(1) {
      $14 = HEAP16[$range$07>>1]|0;
      $15 = $14&65535;
      $16 = ($15>>>0)>($glyph_index>>>0);
      if (!($16)) {
       $17 = (($range$07) + 2|0);
       $18 = HEAP16[$17>>1]|0;
       $19 = $18&65535;
       $20 = ($19>>>0)<($glyph_index>>>0);
       if (!($20)) {
        break;
       }
      }
      $59 = (($range$07) + 40|0);
      $60 = ($59>>>0)<($11>>>0);
      if ($60) {
       $range$07 = $59;
      } else {
       break L1;
      }
     }
     $21 = (($glyph_index) - ($15))|0;
     $22 = (($range$07) + 4|0);
     $23 = HEAP16[$22>>1]|0;
     $24 = $23&65535;
     L10: do {
      switch ($24|0) {
      case 5: case 4:  {
       $25 = (($range$07) + 24|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = ($26|0)==(0);
       if ($27) {
        break L1;
       }
       $28 = (($range$07) + 32|0);
       $29 = HEAP32[$28>>2]|0;
       $n$02 = 0;
       while(1) {
        $44 = (($29) + ($n$02<<1)|0);
        $45 = HEAP16[$44>>1]|0;
        $46 = $45&65535;
        $47 = ($46|0)==($glyph_index|0);
        $43 = (($n$02) + 1)|0;
        if ($47) {
         break;
        }
        $42 = ($43>>>0)<($26>>>0);
        if ($42) {
         $n$02 = $43;
        } else {
         break L1;
        }
       }
       $48 = ($23<<16>>16)==(4);
       if ($48) {
        $49 = (($range$07) + 28|0);
        $50 = HEAP32[$49>>2]|0;
        $51 = (($50) + ($n$02<<2)|0);
        $52 = HEAP32[$51>>2]|0;
        HEAP32[$aglyph_offset>>2] = $52;
        break L10;
       } else {
        $53 = (($range$07) + 8|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = (($range$07) + 12|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = Math_imul($56, $n$02)|0;
        $58 = (($57) + ($54))|0;
        HEAP32[$aglyph_offset>>2] = $58;
        break L10;
       }
       break;
      }
      case 3: case 1:  {
       $30 = $21 & 65535;
       $31 = (($range$07) + 28|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($32) + ($30<<2)|0);
       $34 = HEAP32[$33>>2]|0;
       HEAP32[$aglyph_offset>>2] = $34;
       break;
      }
      case 2:  {
       $35 = (($range$07) + 8|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = (($range$07) + 12|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = $21 & 65535;
       $40 = Math_imul($38, $39)|0;
       $41 = (($40) + ($36))|0;
       HEAP32[$aglyph_offset>>2] = $41;
       break;
      }
      default: {
       break L1;
      }
      }
     } while(0);
     HEAP32[$arange>>2] = $range$07;
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 HEAP32[$arange>>2] = 0;
 HEAP32[$aglyph_offset>>2] = 0;
 $$0 = 6;
 STACKTOP = sp;return ($$0|0);
}
function _tt_load_sbit_metrics($stream,$range,$metrics) {
 $stream = $stream|0;
 $range = $range|0;
 $metrics = $metrics|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $smetrics = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $smetrics = sp;
 $0 = (($range) + 6|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 switch ($2|0) {
 case 8: case 2: case 1:  {
  $3 = (_FT_Stream_ReadFields($stream,872312,$smetrics)|0);
  $4 = ($3|0)==(0);
  if (!($4)) {
   $$0 = $3;
   STACKTOP = sp;return ($$0|0);
  }
  $5 = HEAP8[$smetrics>>0]|0;
  HEAP8[$metrics>>0] = $5;
  $6 = (($smetrics) + 1|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = (($metrics) + 1|0);
  HEAP8[$8>>0] = $7;
  $9 = (($smetrics) + 2|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = (($metrics) + 2|0);
  HEAP8[$11>>0] = $10;
  $12 = (($smetrics) + 3|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = (($metrics) + 3|0);
  HEAP8[$14>>0] = $13;
  $15 = (($smetrics) + 4|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = (($metrics) + 4|0);
  HEAP8[$17>>0] = $16;
  $18 = (($metrics) + 5|0);
  HEAP8[$18>>0] = 0;
  $19 = (($metrics) + 6|0);
  HEAP8[$19>>0] = 0;
  $20 = (($metrics) + 7|0);
  HEAP8[$20>>0] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 9: case 7: case 6:  {
  $21 = (_FT_Stream_ReadFields($stream,872344,$metrics)|0);
  $$0 = $21;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $22 = (($range) + 4|0);
  $23 = HEAP16[$22>>1]|0;
  if (!((($23<<16>>16) == 5) | (($23<<16>>16) == 2))) {
   $$0 = 3;
   STACKTOP = sp;return ($$0|0);
  }
  $24 = (($range) + 16|0);
  $25 = $24;
  $26 = $25;
  $27 = HEAPU8[$26>>0]|(HEAPU8[$26+1>>0]<<8)|(HEAPU8[$26+2>>0]<<16)|(HEAPU8[$26+3>>0]<<24);
  $28 = (($25) + 4)|0;
  $29 = $28;
  $30 = HEAPU8[$29>>0]|(HEAPU8[$29+1>>0]<<8)|(HEAPU8[$29+2>>0]<<16)|(HEAPU8[$29+3>>0]<<24);
  $31 = $metrics;
  $32 = $31;
  HEAP8[$32>>0]=$27&255;HEAP8[$32+1>>0]=($27>>8)&255;HEAP8[$32+2>>0]=($27>>16)&255;HEAP8[$32+3>>0]=$27>>24;
  $33 = (($31) + 4)|0;
  $34 = $33;
  HEAP8[$34>>0]=$30&255;HEAP8[$34+1>>0]=($30>>8)&255;HEAP8[$34+2>>0]=($30>>16)&255;HEAP8[$34+3>>0]=$30>>24;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function _tt_face_load_sbit_image($face,$strike_index,$glyph_index,$load_flags,$stream,$map,$metrics) {
 $face = $face|0;
 $strike_index = $strike_index|0;
 $glyph_index = $glyph_index|0;
 $load_flags = $load_flags|0;
 $stream = $stream|0;
 $map = $map|0;
 $metrics = $metrics|0;
 var $$lcssa15$i = 0, $$pre$pre$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$048$i = 0, $count$048$i$us = 0, $count$133$i = 0, $count$135$i = 0, $cur$040$i$us = 0, $cur1$027$i = 0, $cur4$0$lcssa$i = 0;
 var $cur4$09$i = 0, $error$1 = 0, $glyph_offset = 0, $line$047$i$us = 0, $line$134$i = 0, $line$23$i = 0, $line$316$i = 0, $line$41$i = 0, $n$08$i = 0, $old$0$i = 0, $old$0$in$i = 0, $old$0$in$lcssa$i = 0, $old$0$in10$i = 0, $old$0$in7$i = 0, $range = 0, $rows$0$i = 0, $rows$1$ph$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $glyph_offset = sp + 4|0;
 $range = sp;
 $0 = (($face) + 616|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($face) + 612|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4>>>0)>($strike_index>>>0);
  if ($5) {
   $6 = (($1) + (($strike_index*48)|0)|0);
   $7 = (_find_sbit_range($glyph_index,$6,$range,$glyph_offset)|0);
   $8 = ($7|0)==(0);
   if ($8) {
    $9 = (($face) + 508|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (FUNCTION_TABLE_iiiii[$10 & 511]($face,1161970772,$stream,0)|0);
    $12 = ($11|0)==(0);
    if (!($12)) {
     $13 = HEAP32[$9>>2]|0;
     $14 = (FUNCTION_TABLE_iiiii[$13 & 511]($face,1650745716,$stream,0)|0);
     $15 = ($14|0)==(0);
     if (!($15)) {
      $error$1 = $14;
      STACKTOP = sp;return ($error$1|0);
     }
    }
    $16 = (_FT_Stream_Pos($stream)|0);
    $17 = HEAP32[$range>>2]|0;
    $18 = HEAP32[$glyph_offset>>2]|0;
    $19 = (($face) + 84|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (_Load_SBit_Image($6,$17,$16,$18,$20,0,0,$stream,$metrics,0)|0);
    $22 = ($21|0)==(0);
    if (!($22)) {
     $error$1 = $21;
     STACKTOP = sp;return ($error$1|0);
    }
    $23 = ((($1) + (($strike_index*48)|0)|0) + 47|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = $24 & 1;
    $26 = ($25<<24>>24)==(0);
    if (!($26)) {
     $27 = ((($1) + (($strike_index*48)|0)|0) + 16|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = $28 << 24 >> 24;
     $30 = ((($1) + (($strike_index*48)|0)|0) + 17|0);
     $31 = HEAP8[$30>>0]|0;
     $32 = $31 << 24 >> 24;
     $33 = (($29) - ($32))|0;
     $34 = (($metrics) + 1|0);
     $35 = HEAP8[$34>>0]|0;
     $36 = $35&255;
     $37 = (($36|0) / -2)&-1;
     $38 = $37&255;
     $39 = (($metrics) + 5|0);
     HEAP8[$39>>0] = $38;
     $40 = HEAP8[$metrics>>0]|0;
     $41 = $40&255;
     $42 = (($33) - ($41))|0;
     $43 = (($42|0) / 2)&-1;
     $44 = $43&255;
     $45 = (($metrics) + 6|0);
     HEAP8[$45>>0] = $44;
     $46 = ($33*12)|0;
     $47 = (($46|0) / 10)&-1;
     $48 = $47&255;
     $49 = (($metrics) + 7|0);
     HEAP8[$49>>0] = $48;
    }
    $50 = $load_flags & 64;
    $51 = ($50|0)==(0);
    if ($51) {
     $error$1 = 0;
     STACKTOP = sp;return ($error$1|0);
    }
    $52 = (($map) + 12|0);
    $53 = HEAP32[$map>>2]|0;
    $54 = (($map) + 8|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($53|0)>(0);
    L18: do {
     if ($56) {
      $57 = HEAP32[$52>>2]|0;
      $58 = ($55|0)>(0);
      if ($58) {
       $count$048$i$us = 0;$line$047$i$us = $57;
      } else {
       $count$048$i = 0;
       while(1) {
        $66 = (($count$048$i) + 1)|0;
        $67 = ($66|0)<($53|0);
        if ($67) {
         $count$048$i = $66;
        } else {
         break L18;
        }
       }
      }
      L23: while(1) {
       $63 = (($line$047$i$us) + ($55)|0);
       $cur$040$i$us = $line$047$i$us;
       while(1) {
        $59 = HEAP8[$cur$040$i$us>>0]|0;
        $60 = ($59<<24>>24)==(0);
        $61 = (($cur$040$i$us) + 1|0);
        if (!($60)) {
         break L23;
        }
        $62 = ($61>>>0)<($63>>>0);
        if ($62) {
         $cur$040$i$us = $61;
        } else {
         break;
        }
       }
       $64 = (($count$048$i$us) + 1)|0;
       $65 = ($64|0)<($53|0);
       if ($65) {
        $count$048$i$us = $64;$line$047$i$us = $63;
       } else {
        break L18;
       }
      }
      $68 = ($count$048$i$us|0)>(0);
      if ($68) {
       $69 = Math_imul($count$048$i$us, $55)|0;
       $70 = (($57) + ($69)|0);
       $71 = (($53) - ($count$048$i$us))|0;
       $72 = Math_imul($71, $55)|0;
       _memmove(($57|0),($70|0),($72|0))|0;
       $73 = HEAP8[$metrics>>0]|0;
       $74 = $73&255;
       $75 = (($74) - ($count$048$i$us))|0;
       $76 = $75&255;
       HEAP8[$metrics>>0] = $76;
       $77 = (($metrics) + 3|0);
       $78 = HEAP8[$77>>0]|0;
       $79 = $78&255;
       $80 = (($79) - ($count$048$i$us))|0;
       $81 = $80&255;
       HEAP8[$77>>0] = $81;
       $82 = (($metrics) + 6|0);
       $83 = HEAP8[$82>>0]|0;
       $84 = $83&255;
       $85 = (($84) - ($count$048$i$us))|0;
       $86 = $85&255;
       HEAP8[$82>>0] = $86;
       $87 = HEAP32[$map>>2]|0;
       $88 = (($87) - ($count$048$i$us))|0;
       HEAP32[$map>>2] = $88;
       $rows$0$i = $71;
      } else {
       $rows$0$i = $53;
      }
      $89 = ($rows$0$i|0)>(0);
      if ($89) {
       $90 = (($rows$0$i) + -1)|0;
       $91 = Math_imul($90, $55)|0;
       $92 = HEAP32[$52>>2]|0;
       $93 = (($92) + ($91)|0);
       $94 = (0 - ($55))|0;
       $count$135$i = 0;$line$134$i = $93;
       L35: while(1) {
        $95 = (($line$134$i) + ($55)|0);
        $cur1$027$i = $line$134$i;
        while(1) {
         $98 = HEAP8[$cur1$027$i>>0]|0;
         $99 = ($98<<24>>24)==(0);
         $97 = (($cur1$027$i) + 1|0);
         if (!($99)) {
          $count$133$i = $count$135$i;
          break L35;
         }
         $96 = ($97>>>0)<($95>>>0);
         if ($96) {
          $cur1$027$i = $97;
         } else {
          break;
         }
        }
        $100 = (($line$134$i) + ($94)|0);
        $101 = (($count$135$i) + 1)|0;
        $102 = ($101|0)<($rows$0$i|0);
        if ($102) {
         $count$135$i = $101;$line$134$i = $100;
        } else {
         $count$133$i = $101;
         break;
        }
       }
       $103 = ($count$133$i|0)>(0);
       if ($103) {
        $104 = HEAP8[$metrics>>0]|0;
        $105 = $104&255;
        $106 = (($105) - ($count$133$i))|0;
        $107 = $106&255;
        HEAP8[$metrics>>0] = $107;
        $108 = (($rows$0$i) - ($count$133$i))|0;
        $109 = HEAP32[$map>>2]|0;
        $110 = (($109) - ($count$133$i))|0;
        HEAP32[$map>>2] = $110;
        $rows$1$ph$i = $108;
       } else {
        $rows$1$ph$i = $rows$0$i;
       }
      } else {
       $rows$1$ph$i = $rows$0$i;
      }
      $111 = Math_imul($rows$1$ph$i, $55)|0;
      $112 = (($map) + 4|0);
      $113 = (($metrics) + 2|0);
      $114 = (($metrics) + 5|0);
      $115 = (($metrics) + 1|0);
      $116 = ($111|0)>(0);
      L44: while(1) {
       $117 = HEAP32[$52>>2]|0;
       $118 = (($117) + ($111)|0);
       if ($116) {
        $line$23$i = $117;
        while(1) {
         $120 = HEAP8[$line$23$i>>0]|0;
         $121 = ($120<<24>>24)<(0);
         if ($121) {
          label = 38;
          break L44;
         }
         $122 = (($line$23$i) + ($55)|0);
         $123 = ($122>>>0)<($118>>>0);
         if ($123) {
          $line$23$i = $122;
         } else {
          break;
         }
        }
        $124 = HEAP32[$112>>2]|0;
        $128 = $124;$line$316$i = $117;
        while(1) {
         $125 = HEAP8[$line$316$i>>0]|0;
         $126 = $125&255;
         $old$0$in7$i = $126 << 1;
         $127 = ($128|0)>(8);
         if ($127) {
          $cur4$09$i = $line$316$i;$n$08$i = 8;$old$0$in10$i = $old$0$in7$i;
          while(1) {
           $129 = (($cur4$09$i) + 1|0);
           $130 = HEAP8[$129>>0]|0;
           $131 = $130&255;
           $132 = $131 >>> 7;
           $133 = $132 | $old$0$in10$i;
           $134 = $133&255;
           HEAP8[$cur4$09$i>>0] = $134;
           $135 = (($n$08$i) + 8)|0;
           $old$0$in$i = $131 << 1;
           $136 = ($135|0)<($128|0);
           if ($136) {
            $cur4$09$i = $129;$n$08$i = $135;$old$0$in10$i = $old$0$in$i;
           } else {
            $cur4$0$lcssa$i = $129;$old$0$in$lcssa$i = $old$0$in$i;
            break;
           }
          }
         } else {
          $cur4$0$lcssa$i = $line$316$i;$old$0$in$lcssa$i = $old$0$in7$i;
         }
         $old$0$i = $old$0$in$lcssa$i&255;
         HEAP8[$cur4$0$lcssa$i>>0] = $old$0$i;
         $137 = (($line$316$i) + ($55)|0);
         $138 = ($137>>>0)<($118>>>0);
         $139 = HEAP32[$112>>2]|0;
         if ($138) {
          $128 = $139;$line$316$i = $137;
         } else {
          $$lcssa15$i = $139;
          break;
         }
        }
       } else {
        $119 = HEAP32[$112>>2]|0;
        $$lcssa15$i = $119;
       }
       $140 = (($$lcssa15$i) + -1)|0;
       HEAP32[$112>>2] = $140;
       $141 = HEAP8[$113>>0]|0;
       $142 = (($141) + 1)<<24>>24;
       HEAP8[$113>>0] = $142;
       $143 = HEAP8[$114>>0]|0;
       $144 = (($143) + 1)<<24>>24;
       HEAP8[$114>>0] = $144;
       $145 = HEAP8[$115>>0]|0;
       $146 = (($145) + -1)<<24>>24;
       HEAP8[$115>>0] = $146;
       $147 = HEAP32[$112>>2]|0;
       $148 = ($147|0)>(0);
       if (!($148)) {
        $150 = $147;
        break;
       }
      }
      if ((label|0) == 38) {
       $$pre$pre$i = HEAP32[$112>>2]|0;
       $150 = $$pre$pre$i;
      }
      L61: while(1) {
       $149 = (($150) + -1)|0;
       $151 = HEAP32[$52>>2]|0;
       $152 = $149 >> 3;
       $$sum$i = (($152) + ($111))|0;
       $153 = (($151) + ($$sum$i)|0);
       $154 = ($152|0)<($$sum$i|0);
       if ($154) {
        $155 = $149 & 7;
        $156 = (($151) + ($152)|0);
        $157 = 128 >>> $155;
        $line$41$i = $156;
        while(1) {
         $158 = HEAP8[$line$41$i>>0]|0;
         $159 = $158&255;
         $160 = $159 & $157;
         $161 = ($160|0)==(0);
         if (!($161)) {
          $error$1 = 0;
          label = 45;
          break L61;
         }
         $162 = (($line$41$i) + ($55)|0);
         $163 = ($162>>>0)<($153>>>0);
         if ($163) {
          $line$41$i = $162;
         } else {
          break;
         }
        }
       }
       HEAP32[$112>>2] = $149;
       $164 = HEAP8[$115>>0]|0;
       $165 = (($164) + -1)<<24>>24;
       HEAP8[$115>>0] = $165;
       $166 = HEAP32[$112>>2]|0;
       $167 = ($166|0)>(0);
       if ($167) {
        $150 = $166;
       } else {
        $error$1 = 0;
        label = 45;
        break;
       }
      }
      if ((label|0) == 45) {
       STACKTOP = sp;return ($error$1|0);
      }
     }
    } while(0);
    $168 = (($map) + 4|0);
    HEAP32[$168>>2] = 0;
    HEAP32[$map>>2] = 0;
    HEAP32[$54>>2] = 0;
    $169 = (($map) + 18|0);
    HEAP8[$169>>0] = 1;
    $error$1 = 0;
    STACKTOP = sp;return ($error$1|0);
   }
  }
 }
 HEAP32[$range>>2] = 0;
 HEAP32[$glyph_offset>>2] = 0;
 $error$1 = 6;
 STACKTOP = sp;return ($error$1|0);
}
function _Load_SBit_Image($strike,$range,$ebdt_pos,$glyph_offset,$slot,$x_offset,$y_offset,$stream,$metrics,$depth) {
 $strike = $strike|0;
 $range = $range|0;
 $ebdt_pos = $ebdt_pos|0;
 $glyph_offset = $glyph_offset|0;
 $slot = $slot|0;
 $x_offset = $x_offset|0;
 $y_offset = $y_offset|0;
 $stream = $stream|0;
 $metrics = $metrics|0;
 $depth = $depth|0;
 var $$0 = 0, $$0$i$ph = 0, $$07$i$i = 0, $$1$i$i = 0, $$1$us$i$i = 0, $$2$i$i = 0, $$2$us$i$i = 0, $$3$i$i = 0, $$4$i$i = 0, $$5$i$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $acc$04$i$i = 0, $acc$1$i$i = 0, $acc$1$us$i$i = 0, $acc$2$i$i = 0;
 var $acc$2$us$i$i = 0, $acc$3$i$i = 0, $acc$4$i$i = 0, $acc$5$$i$i = 0, $acc$5$i$i = 0, $comp$010 = 0, $comp$18 = 0, $count$0$i$i = 0, $count$0$us$i$i = 0, $count$011 = 0, $count$1$i$i = 0, $count$19 = 0, $cur$0$i$i = 0, $cur$0$us$i$i = 0, $cur$1$i$i = 0, $elem_metrics = 0, $elem_offset = 0, $elem_range = 0, $error = 0, $glyph_size$0$i = 0;
 var $height$05$i$i = 0, $indvars$iv$i$i = 0, $line_bits$op$op$i$i = 0, $line_buff$0$i$i = 0, $line_buff$16$i$i = 0, $line_length$0$i = 0, $loaded$03$i$i = 0, $loaded$1$i$i = 0, $loaded$1$us$i$i = 0, $loaded$2$i$i = 0, $loaded$2$us$i$i = 0, $loaded$3$i$i = 0, $loaded$4$i$i = 0, $loaded$5$$i$i = 0, $loaded$5$i$i = 0, $or$cond$i = 0, $pad_bytes$0$i = 0, $scevgep$i$i = 0, $scevgep1419$i$i = 0, $smetrics$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $smetrics$i = sp + 24|0;
 $error = sp;
 $elem_range = sp + 4|0;
 $elem_metrics = sp + 16|0;
 $elem_offset = sp + 8|0;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($slot) + 76|0);
 $3 = (($glyph_offset) + ($ebdt_pos))|0;
 $4 = (_FT_Stream_Seek($stream,$3)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($range) + 6|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7&65535;
 switch ($8|0) {
 case 9: case 7: case 6:  {
  $40 = (_FT_Stream_ReadFields($stream,872344,$metrics)|0);
  HEAP32[$error>>2] = $40;
  $41 = ($40|0)==(0);
  if (!($41)) {
   $$0 = $40;
   STACKTOP = sp;return ($$0|0);
  }
  break;
 }
 case 8: case 2: case 1:  {
  $9 = (_FT_Stream_ReadFields($stream,872312,$smetrics$i)|0);
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = HEAP8[$smetrics$i>>0]|0;
   HEAP8[$metrics>>0] = $11;
   $12 = (($smetrics$i) + 1|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = (($metrics) + 1|0);
   HEAP8[$14>>0] = $13;
   $15 = (($smetrics$i) + 2|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = (($metrics) + 2|0);
   HEAP8[$17>>0] = $16;
   $18 = (($smetrics$i) + 3|0);
   $19 = HEAP8[$18>>0]|0;
   $20 = (($metrics) + 3|0);
   HEAP8[$20>>0] = $19;
   $21 = (($smetrics$i) + 4|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = (($metrics) + 4|0);
   HEAP8[$23>>0] = $22;
   $24 = (($metrics) + 5|0);
   HEAP8[$24>>0] = 0;
   $25 = (($metrics) + 6|0);
   HEAP8[$25>>0] = 0;
   $26 = (($metrics) + 7|0);
   HEAP8[$26>>0] = 0;
   label = 7;
  } else {
   $$0$i$ph = $9;
   label = 8;
  }
  break;
 }
 default: {
  $27 = (($range) + 4|0);
  $28 = HEAP16[$27>>1]|0;
  if ((($28<<16>>16) == 5) | (($28<<16>>16) == 2)) {
   $29 = (($range) + 16|0);
   $30 = $29;
   $31 = $30;
   $32 = HEAPU8[$31>>0]|(HEAPU8[$31+1>>0]<<8)|(HEAPU8[$31+2>>0]<<16)|(HEAPU8[$31+3>>0]<<24);
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAPU8[$34>>0]|(HEAPU8[$34+1>>0]<<8)|(HEAPU8[$34+2>>0]<<16)|(HEAPU8[$34+3>>0]<<24);
   $36 = $metrics;
   $37 = $36;
   HEAP8[$37>>0]=$32&255;HEAP8[$37+1>>0]=($32>>8)&255;HEAP8[$37+2>>0]=($32>>16)&255;HEAP8[$37+3>>0]=$32>>24;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP8[$39>>0]=$35&255;HEAP8[$39+1>>0]=($35>>8)&255;HEAP8[$39+2>>0]=($35>>16)&255;HEAP8[$39+3>>0]=$35>>24;
   label = 7;
  } else {
   $$0$i$ph = 3;
   label = 8;
  }
 }
 }
 if ((label|0) == 7) {
  HEAP32[$error>>2] = 0;
 }
 else if ((label|0) == 8) {
  HEAP32[$error>>2] = $$0$i$ph;
  $$0 = $$0$i$ph;
  STACKTOP = sp;return ($$0|0);
 }
 $42 = ($depth|0)==(0);
 if ($42) {
  $43 = (($metrics) + 1|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = (($slot) + 80|0);
  HEAP32[$46>>2] = $45;
  $47 = HEAP8[$metrics>>0]|0;
  $48 = $47&255;
  HEAP32[$2>>2] = $48;
  $49 = (($strike) + 46|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = $50&255;
  if ((($51|0) == 2)) {
   $56 = (($slot) + 94|0);
   HEAP8[$56>>0] = 3;
   $57 = (($45) + 3)|0;
   $58 = $57 >>> 2;
   $59 = (($slot) + 84|0);
   HEAP32[$59>>2] = $58;
   $67 = $58;
  } else if ((($51|0) == 4)) {
   $60 = (($slot) + 94|0);
   HEAP8[$60>>0] = 4;
   $61 = (($45) + 1)|0;
   $62 = $61 >>> 1;
   $63 = (($slot) + 84|0);
   HEAP32[$63>>2] = $62;
   $67 = $62;
  } else if ((($51|0) == 1)) {
   $52 = (($slot) + 94|0);
   HEAP8[$52>>0] = 1;
   $53 = (($45) + 7)|0;
   $54 = $53 >>> 3;
   $55 = (($slot) + 84|0);
   HEAP32[$55>>2] = $54;
   $67 = $54;
  } else if ((($51|0) == 8)) {
   $64 = (($slot) + 94|0);
   HEAP8[$64>>0] = 2;
   $65 = (($slot) + 84|0);
   HEAP32[$65>>2] = $45;
   $67 = $45;
  } else {
   $$0 = 3;
   STACKTOP = sp;return ($$0|0);
  }
  $66 = Math_imul($67, $48)|0;
  $68 = ($66|0)==(0);
  if ($68) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $69 = (_ft_glyphslot_alloc_bitmap($slot,$66)|0);
  HEAP32[$error>>2] = $69;
  $70 = ($69|0)==(0);
  if (!($70)) {
   $$0 = $69;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $71 = HEAP16[$6>>1]|0;
 $72 = $71&65535;
 switch ($72|0) {
 case 7: case 6: case 5: case 2: case 1:  {
  $73 = (($strike) + 46|0);
  $74 = HEAP8[$73>>0]|0;
  $75 = $74&255;
  $76 = ($x_offset|0)<(0);
  if ($76) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
  $77 = (($metrics) + 1|0);
  $78 = HEAP8[$77>>0]|0;
  $79 = $78&255;
  $80 = (($79) + ($x_offset))|0;
  $81 = (($slot) + 80|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($80|0)>($82|0);
  $84 = ($y_offset|0)<(0);
  $or$cond$i = $83 | $84;
  if ($or$cond$i) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
  $85 = HEAP8[$metrics>>0]|0;
  $86 = $85&255;
  $87 = (($86) + ($y_offset))|0;
  $88 = HEAP32[$2>>2]|0;
  $89 = ($87|0)>($88|0);
  if ($89) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
  $90 = Math_imul($79, $75)|0;
  switch ($72|0) {
  case 6: case 1:  {
   if ((($75|0) == 4)) {
    $95 = (($79) + 1)|0;
    $96 = $95 >>> 1;
    $line_length$0$i = $96;
   } else if ((($75|0) == 1)) {
    $91 = (($79) + 7)|0;
    $92 = $91 >>> 3;
    $line_length$0$i = $92;
   } else if ((($75|0) == 2)) {
    $93 = (($79) + 3)|0;
    $94 = $93 >>> 2;
    $line_length$0$i = $94;
   } else {
    $line_length$0$i = $79;
   }
   $97 = Math_imul($line_length$0$i, $86)|0;
   $glyph_size$0$i = $97;$pad_bytes$0$i = 1;
   break;
  }
  case 7: case 5: case 2:  {
   $98 = Math_imul($86, $90)|0;
   $99 = (($98) + 7)|0;
   $100 = $99 >>> 3;
   $glyph_size$0$i = $100;$pad_bytes$0$i = 0;
   break;
  }
  default: {
   $$0 = 3;
   STACKTOP = sp;return ($$0|0);
  }
  }
  $101 = (_FT_Stream_EnterFrame($stream,$glyph_size$0$i)|0);
  $102 = ($101|0)==(0);
  if (!($102)) {
   $$0 = $101;
   STACKTOP = sp;return ($$0|0);
  }
  $103 = (($stream) + 32|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = Math_imul($75, $x_offset)|0;
  $106 = HEAP8[$metrics>>0]|0;
  $107 = $106&255;
  $108 = (($slot) + 84|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($slot) + 88|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ($109|0)<(0);
  if ($112) {
   $113 = HEAP32[$2>>2]|0;
   $114 = (($113) + -1)|0;
   $115 = (0 - ($109))|0;
   $116 = Math_imul($114, $115)|0;
   $117 = (($111) + ($116)|0);
   $line_buff$0$i$i = $117;
  } else {
   $line_buff$0$i$i = $111;
  }
  $118 = ($106<<24>>24)==(0);
  if (!($118)) {
   $119 = Math_imul($109, $y_offset)|0;
   $120 = $105 >> 3;
   $121 = (($119) + ($120))|0;
   $122 = (($line_buff$0$i$i) + ($121)|0);
   $123 = $105 & 7;
   $124 = (8 - ($123))|0;
   $125 = ($90>>>0)>(7);
   $126 = (($90) + -8)|0;
   $127 = ($123|0)==(0);
   $128 = ($pad_bytes$0$i<<24>>24)==(0);
   $129 = (15 - ($90))|0;
   $130 = ($129|0)>(0);
   $line_bits$op$op$i$i = $126 >>> 3;
   $131 = $130 ? 0 : $line_bits$op$op$i$i;
   $132 = (($120) + 1)|0;
   $133 = (($132) + ($131))|0;
   $134 = (($133) + ($119))|0;
   $scevgep$i$i = (($line_buff$0$i$i) + ($134)|0);
   $135 = $131 << 3;
   $136 = (($126) - ($135))|0;
   $$07$i$i = $104;$acc$04$i$i = 0;$height$05$i$i = $107;$indvars$iv$i$i = $scevgep$i$i;$line_buff$16$i$i = $122;$loaded$03$i$i = 0;
   while(1) {
    if ($125) {
     if ($127) {
      $$1$us$i$i = $$07$i$i;$acc$1$us$i$i = $acc$04$i$i;$count$0$us$i$i = $126;$cur$0$us$i$i = $line_buff$16$i$i;$loaded$1$us$i$i = $loaded$03$i$i;
      while(1) {
       $137 = ($loaded$1$us$i$i>>>0)<(8);
       if ($137) {
        $138 = (($$1$us$i$i) + 1|0);
        $139 = HEAP8[$$1$us$i$i>>0]|0;
        $140 = $139&255;
        $141 = (8 - ($loaded$1$us$i$i))|0;
        $142 = $140 << $141;
        $143 = $acc$1$us$i$i&65535;
        $144 = $142 | $143;
        $145 = $144&65535;
        $146 = (($loaded$1$us$i$i) + 8)|0;
        $$2$us$i$i = $138;$acc$2$us$i$i = $145;$loaded$2$us$i$i = $146;
       } else {
        $$2$us$i$i = $$1$us$i$i;$acc$2$us$i$i = $acc$1$us$i$i;$loaded$2$us$i$i = $loaded$1$us$i$i;
       }
       $147 = $acc$2$us$i$i&65535;
       $148 = ($acc$2$us$i$i&65535) >>> 8;
       $149 = $148&65535;
       $150 = HEAP8[$cur$0$us$i$i>>0]|0;
       $151 = $150&255;
       $152 = $151 | $149;
       $153 = $152&255;
       HEAP8[$cur$0$us$i$i>>0] = $153;
       $154 = (($cur$0$us$i$i) + 1|0);
       $155 = $147 << 8;
       $156 = $155&65535;
       $157 = (($loaded$2$us$i$i) + -8)|0;
       $158 = (($count$0$us$i$i) + -8)|0;
       $159 = ($158|0)>(-1);
       if ($159) {
        $$1$us$i$i = $$2$us$i$i;$acc$1$us$i$i = $156;$count$0$us$i$i = $158;$cur$0$us$i$i = $154;$loaded$1$us$i$i = $157;
       } else {
        $$3$i$i = $$2$us$i$i;$acc$3$i$i = $156;$count$1$i$i = $136;$cur$1$i$i = $indvars$iv$i$i;$loaded$3$i$i = $157;
        break;
       }
      }
     } else {
      $$1$i$i = $$07$i$i;$acc$1$i$i = $acc$04$i$i;$count$0$i$i = $126;$cur$0$i$i = $line_buff$16$i$i;$loaded$1$i$i = $loaded$03$i$i;
      while(1) {
       $160 = ($loaded$1$i$i>>>0)<(8);
       if ($160) {
        $161 = (($$1$i$i) + 1|0);
        $162 = HEAP8[$$1$i$i>>0]|0;
        $163 = $162&255;
        $164 = (8 - ($loaded$1$i$i))|0;
        $165 = $163 << $164;
        $166 = $acc$1$i$i&65535;
        $167 = $165 | $166;
        $168 = $167&65535;
        $169 = (($loaded$1$i$i) + 8)|0;
        $$2$i$i = $161;$acc$2$i$i = $168;$loaded$2$i$i = $169;
       } else {
        $$2$i$i = $$1$i$i;$acc$2$i$i = $acc$1$i$i;$loaded$2$i$i = $loaded$1$i$i;
       }
       $170 = $acc$2$i$i&65535;
       $171 = ($acc$2$i$i&65535) >>> 8;
       $172 = $171&65535;
       $173 = $172 >>> $123;
       $174 = HEAP8[$cur$0$i$i>>0]|0;
       $175 = $174&255;
       $176 = $175 | $173;
       $177 = $176&255;
       HEAP8[$cur$0$i$i>>0] = $177;
       $178 = $172 << $124;
       $179 = (($cur$0$i$i) + 1|0);
       $180 = HEAP8[$179>>0]|0;
       $181 = $180&255;
       $182 = $181 | $178;
       $183 = $182&255;
       HEAP8[$179>>0] = $183;
       $184 = $170 << 8;
       $185 = $184&65535;
       $186 = (($loaded$2$i$i) + -8)|0;
       $187 = (($count$0$i$i) + -8)|0;
       $188 = ($187|0)>(-1);
       if ($188) {
        $$1$i$i = $$2$i$i;$acc$1$i$i = $185;$count$0$i$i = $187;$cur$0$i$i = $179;$loaded$1$i$i = $186;
       } else {
        $$3$i$i = $$2$i$i;$acc$3$i$i = $185;$count$1$i$i = $136;$cur$1$i$i = $indvars$iv$i$i;$loaded$3$i$i = $186;
        break;
       }
      }
     }
    } else {
     $$3$i$i = $$07$i$i;$acc$3$i$i = $acc$04$i$i;$count$1$i$i = $90;$cur$1$i$i = $line_buff$16$i$i;$loaded$3$i$i = $loaded$03$i$i;
    }
    $189 = ($count$1$i$i|0)>(0);
    if ($189) {
     $190 = ($loaded$3$i$i|0)<($count$1$i$i|0);
     if ($190) {
      $191 = (($$3$i$i) + 1|0);
      $192 = HEAP8[$$3$i$i>>0]|0;
      $193 = $192&255;
      $194 = (8 - ($loaded$3$i$i))|0;
      $195 = $193 << $194;
      $196 = $acc$3$i$i&65535;
      $197 = $195 | $196;
      $198 = $197&65535;
      $199 = (($loaded$3$i$i) + 8)|0;
      $$4$i$i = $191;$acc$4$i$i = $198;$loaded$4$i$i = $199;
     } else {
      $$4$i$i = $$3$i$i;$acc$4$i$i = $acc$3$i$i;$loaded$4$i$i = $loaded$3$i$i;
     }
     $200 = $acc$4$i$i&65535;
     $201 = ($acc$4$i$i&65535) >>> 8;
     $202 = $201&65535;
     $203 = 255 >>> $count$1$i$i;
     $204 = $203 ^ 255;
     $205 = $202 & $204;
     $206 = $205 >>> $123;
     $207 = HEAP8[$cur$1$i$i>>0]|0;
     $208 = $207&255;
     $209 = $206 | $208;
     $210 = $209&255;
     HEAP8[$cur$1$i$i>>0] = $210;
     $211 = ($count$1$i$i|0)>($124|0);
     if ($211) {
      $212 = $205 << $124;
      $213 = (($cur$1$i$i) + 1|0);
      $214 = HEAP8[$213>>0]|0;
      $215 = $214&255;
      $216 = $215 | $212;
      $217 = $216&255;
      HEAP8[$213>>0] = $217;
     }
     $218 = $200 << $count$1$i$i;
     $219 = $218&65535;
     $220 = (($loaded$4$i$i) - ($count$1$i$i))|0;
     $$5$i$i = $$4$i$i;$acc$5$i$i = $219;$loaded$5$i$i = $220;
    } else {
     $$5$i$i = $$3$i$i;$acc$5$i$i = $acc$3$i$i;$loaded$5$i$i = $loaded$3$i$i;
    }
    $loaded$5$$i$i = $128 ? $loaded$5$i$i : 0;
    $acc$5$$i$i = $128 ? $acc$5$i$i : 0;
    $221 = (($line_buff$16$i$i) + ($109)|0);
    $222 = (($height$05$i$i) + -1)|0;
    $223 = ($222|0)>(0);
    $scevgep1419$i$i = (($indvars$iv$i$i) + ($109)|0);
    if ($223) {
     $$07$i$i = $$5$i$i;$acc$04$i$i = $acc$5$$i$i;$height$05$i$i = $222;$indvars$iv$i$i = $scevgep1419$i$i;$line_buff$16$i$i = $221;$loaded$03$i$i = $loaded$5$$i$i;
    } else {
     break;
    }
   }
  }
  _FT_Stream_ExitFrame($stream);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 8:  {
  $224 = (_FT_Stream_Skip($stream,1)|0);
  HEAP32[$error>>2] = $224;
  $225 = ($224|0)==(0);
  if (!($225)) {
   HEAP32[$error>>2] = 83;
   $$0 = 83;
   STACKTOP = sp;return ($$0|0);
  }
  break;
 }
 case 9:  {
  break;
 }
 default: {
  $$0 = 3;
  STACKTOP = sp;return ($$0|0);
 }
 }
 $226 = (_FT_Stream_ReadUShort($stream,$error)|0);
 $227 = HEAP32[$error>>2]|0;
 $228 = ($227|0)==(0);
 if (!($228)) {
  $$0 = $227;
  STACKTOP = sp;return ($$0|0);
 }
 $229 = $226&65535;
 $230 = (_ft_mem_realloc($1,4,0,$229,0,$error)|0);
 $231 = HEAP32[$error>>2]|0;
 $232 = ($231|0)==(0);
 if (!($232)) {
  $$0 = $231;
  STACKTOP = sp;return ($$0|0);
 }
 $233 = $229 << 2;
 $234 = (_FT_Stream_EnterFrame($stream,$233)|0);
 HEAP32[$error>>2] = $234;
 $235 = ($234|0)==(0);
 L97: do {
  if ($235) {
   $236 = ($226<<16>>16)==(0);
   if ($236) {
    _FT_Stream_ExitFrame($stream);
    break;
   } else {
    $comp$010 = $230;$count$011 = $226;
   }
   while(1) {
    $237 = (_FT_Stream_GetUShort($stream)|0);
    HEAP16[$comp$010>>1] = $237;
    $238 = (_FT_Stream_GetChar($stream)|0);
    $239 = (($comp$010) + 2|0);
    HEAP8[$239>>0] = $238;
    $240 = (_FT_Stream_GetChar($stream)|0);
    $241 = (($comp$010) + 3|0);
    HEAP8[$241>>0] = $240;
    $242 = (($count$011) + -1)<<16>>16;
    $243 = (($comp$010) + 4|0);
    $244 = ($242<<16>>16)==(0);
    if ($244) {
     break;
    } else {
     $comp$010 = $243;$count$011 = $242;
    }
   }
   _FT_Stream_ExitFrame($stream);
   if (!($236)) {
    $245 = (($depth) + 1)|0;
    $comp$18 = $230;$count$19 = $226;
    while(1) {
     $246 = HEAP16[$comp$18>>1]|0;
     $247 = $246&65535;
     $248 = (_find_sbit_range($247,$strike,$elem_range,$elem_offset)|0);
     HEAP32[$error>>2] = $248;
     $249 = ($248|0)==(0);
     if (!($249)) {
      break L97;
     }
     $250 = HEAP32[$elem_range>>2]|0;
     $251 = HEAP32[$elem_offset>>2]|0;
     $252 = (($comp$18) + 2|0);
     $253 = HEAP8[$252>>0]|0;
     $254 = $253 << 24 >> 24;
     $255 = (($254) + ($x_offset))|0;
     $256 = (($comp$18) + 3|0);
     $257 = HEAP8[$256>>0]|0;
     $258 = $257 << 24 >> 24;
     $259 = (($258) + ($y_offset))|0;
     $260 = (_Load_SBit_Image($strike,$250,$ebdt_pos,$251,$slot,$255,$259,$stream,$elem_metrics,$245)|0);
     HEAP32[$error>>2] = $260;
     $261 = ($260|0)==(0);
     if (!($261)) {
      break L97;
     }
     $262 = (($count$19) + -1)<<16>>16;
     $263 = (($comp$18) + 4|0);
     $264 = ($262<<16>>16)==(0);
     if ($264) {
      break;
     } else {
      $comp$18 = $263;$count$19 = $262;
     }
    }
   }
  }
 } while(0);
 _ft_mem_free($1,$230);
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _Load_SBit_Range_Codes($range,$stream,$load_offsets) {
 $range = $range|0;
 $stream = $stream|0;
 $load_offsets = $load_offsets|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $exitcond = 0;
 var $exitcond2 = 0, $n$01 = 0, $n$01$us = 0, $size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_FT_Stream_ReadULong($stream,$error)|0);
 $3 = HEAP32[$error>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  $36 = $3;
  STACKTOP = sp;return ($36|0);
 }
 $5 = (($range) + 24|0);
 HEAP32[$5>>2] = $2;
 $6 = ($load_offsets<<24>>24)!=(0);
 do {
  if ($6) {
   $7 = (_ft_mem_realloc($1,4,0,$2,0,$error)|0);
   $8 = (($range) + 28|0);
   HEAP32[$8>>2] = $7;
   $9 = HEAP32[$error>>2]|0;
   $10 = ($9|0)==(0);
   if ($10) {
    $11 = $2 << 2;
    $size$0 = $11;
    break;
   } else {
    $36 = $9;
    STACKTOP = sp;return ($36|0);
   }
  } else {
   $12 = $2 << 1;
   $size$0 = $12;
  }
 } while(0);
 $13 = (_ft_mem_realloc($1,2,0,$2,0,$error)|0);
 $14 = (($range) + 32|0);
 HEAP32[$14>>2] = $13;
 $15 = HEAP32[$error>>2]|0;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $36 = $15;
  STACKTOP = sp;return ($36|0);
 }
 $17 = (_FT_Stream_EnterFrame($stream,$size$0)|0);
 HEAP32[$error>>2] = $17;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $36 = $17;
  STACKTOP = sp;return ($36|0);
 }
 $19 = ($2|0)==(0);
 if (!($19)) {
  $20 = (($range) + 8|0);
  $21 = (($range) + 28|0);
  if ($6) {
   $n$01$us = 0;
   while(1) {
    $22 = (_FT_Stream_GetUShort($stream)|0);
    $23 = HEAP32[$14>>2]|0;
    $24 = (($23) + ($n$01$us<<1)|0);
    HEAP16[$24>>1] = $22;
    $25 = HEAP32[$20>>2]|0;
    $26 = (_FT_Stream_GetUShort($stream)|0);
    $27 = $26&65535;
    $28 = (($27) + ($25))|0;
    $29 = HEAP32[$21>>2]|0;
    $30 = (($29) + ($n$01$us<<2)|0);
    HEAP32[$30>>2] = $28;
    $31 = (($n$01$us) + 1)|0;
    $exitcond2 = ($31|0)==($2|0);
    if ($exitcond2) {
     break;
    } else {
     $n$01$us = $31;
    }
   }
  } else {
   $n$01 = 0;
   while(1) {
    $32 = (_FT_Stream_GetUShort($stream)|0);
    $33 = HEAP32[$14>>2]|0;
    $34 = (($33) + ($n$01<<1)|0);
    HEAP16[$34>>1] = $32;
    $35 = (($n$01) + 1)|0;
    $exitcond = ($35|0)==($2|0);
    if ($exitcond) {
     break;
    } else {
     $n$01 = $35;
    }
   }
  }
 }
 _FT_Stream_ExitFrame($stream);
 $$pre = HEAP32[$error>>2]|0;
 $36 = $$pre;
 STACKTOP = sp;return ($36|0);
}
function _tt_face_load_kern($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$ = 0, $$1 = 0, $$masked = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $avail$0$lcssa = 0, $avail$07 = 0, $avail$1 = 0, $cond = 0, $cond3 = 0, $count$0 = 0, $count$02 = 0, $count$06 = 0, $error$0 = 0, $nn$0$lcssa = 0;
 var $nn$010 = 0, $num_pairs$0 = 0, $old_pair$05 = 0, $ordered$0$lcssa = 0, $ordered$08 = 0, $ordered$1 = 0, $p$011 = 0, $p$14 = 0, $table_size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $table_size = sp;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1801810542,$stream,$table_size)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $error$0 = $2;
  STACKTOP = sp;return ($error$0|0);
 }
 $4 = HEAP32[$table_size>>2]|0;
 $5 = ($4>>>0)<(4);
 if ($5) {
  $error$0 = 142;
  STACKTOP = sp;return ($error$0|0);
 }
 $6 = (($face) + 772|0);
 $7 = (_FT_Stream_ExtractFrame($stream,$4,$6)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $error$0 = $7;
  STACKTOP = sp;return ($error$0|0);
 }
 $9 = HEAP32[$table_size>>2]|0;
 $10 = (($face) + 776|0);
 HEAP32[$10>>2] = $9;
 $11 = HEAP32[$6>>2]|0;
 $12 = (($11) + ($9)|0);
 $13 = (($11) + 2|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 << 8;
 $17 = (($11) + 3|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = $16 | $19;
 $21 = ($20>>>0)>(32);
 $$ = $21 ? 32 : $20;
 $22 = ($$|0)==(0);
 L10: do {
  if ($22) {
   $avail$0$lcssa = 0;$nn$0$lcssa = 0;$ordered$0$lcssa = 0;
  } else {
   $23 = (($11) + 4|0);
   $avail$07 = 0;$nn$010 = 0;$ordered$08 = 0;$p$011 = $23;
   while(1) {
    $24 = 1 << $nn$010;
    $25 = (($p$011) + 6|0);
    $26 = ($25>>>0)>($12>>>0);
    if ($26) {
     $avail$0$lcssa = $avail$07;$nn$0$lcssa = $nn$010;$ordered$0$lcssa = $ordered$08;
     break L10;
    }
    $27 = (($p$011) + 2|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28&255;
    $30 = $29 << 8;
    $31 = (($p$011) + 3|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = $32&255;
    $34 = $30 | $33;
    $35 = ($34>>>0)<(7);
    if ($35) {
     $avail$0$lcssa = $avail$07;$nn$0$lcssa = $nn$010;$ordered$0$lcssa = $ordered$08;
     break L10;
    }
    $36 = (($p$011) + 4|0);
    $37 = (($p$011) + 5|0);
    $38 = HEAP8[$36>>0]|0;
    $39 = HEAP8[$37>>0]|0;
    $40 = $38&255;
    $41 = $39&255;
    $42 = $40 << 8;
    $43 = (($p$011) + ($34)|0);
    $44 = ($43>>>0)>($12>>>0);
    $$1 = $44 ? $12 : $43;
    $$masked = $41 & 247;
    $45 = $$masked | $42;
    $46 = ($45|0)==(1);
    L16: do {
     if ($46) {
      $47 = (($p$011) + 14|0);
      $48 = ($47>>>0)>($12>>>0);
      if ($48) {
       $avail$1 = $avail$07;$ordered$1 = $ordered$08;
      } else {
       $49 = HEAP8[$25>>0]|0;
       $50 = $49&255;
       $51 = $50 << 8;
       $52 = (($p$011) + 7|0);
       $53 = HEAP8[$52>>0]|0;
       $54 = $53&255;
       $55 = $51 | $54;
       $56 = $$1;
       $57 = $47;
       $58 = (($56) - ($57))|0;
       $59 = ($55*6)|0;
       $60 = ($58|0)<($59|0);
       if ($60) {
        $61 = (($58|0) / 6)&-1;
        $num_pairs$0 = $61;
       } else {
        $num_pairs$0 = $55;
       }
       $62 = $24 | $avail$07;
       $63 = ($num_pairs$0|0)==(0);
       if ($63) {
        $avail$1 = $62;$ordered$1 = $ordered$08;
       } else {
        $count$02 = (($num_pairs$0) + -1)|0;
        $cond3 = ($count$02|0)==(0);
        if (!($cond3)) {
         $64 = (($p$011) + 15|0);
         $65 = (($p$011) + 16|0);
         $66 = HEAP8[$64>>0]|0;
         $67 = HEAP8[$47>>0]|0;
         $68 = HEAP8[$65>>0]|0;
         $69 = $66&255;
         $70 = $67&255;
         $71 = (($p$011) + 17|0);
         $72 = $68&255;
         $73 = $69 << 16;
         $74 = $70 << 24;
         $75 = HEAP8[$71>>0]|0;
         $76 = $72 << 8;
         $77 = $73 | $74;
         $78 = $75&255;
         $79 = $77 | $76;
         $80 = (($p$011) + 20|0);
         $81 = $79 | $78;
         $count$06 = $count$02;$old_pair$05 = $81;$p$14 = $80;
         while(1) {
          $83 = HEAP8[$p$14>>0]|0;
          $84 = $83&255;
          $85 = $84 << 24;
          $86 = (($p$14) + 1|0);
          $87 = HEAP8[$86>>0]|0;
          $88 = $87&255;
          $89 = $88 << 16;
          $90 = $89 | $85;
          $91 = (($p$14) + 2|0);
          $92 = HEAP8[$91>>0]|0;
          $93 = $92&255;
          $94 = $93 << 8;
          $95 = $90 | $94;
          $96 = (($p$14) + 3|0);
          $97 = HEAP8[$96>>0]|0;
          $98 = $97&255;
          $99 = $95 | $98;
          $100 = ($99>>>0)>($old_pair$05>>>0);
          if (!($100)) {
           $avail$1 = $62;$ordered$1 = $ordered$08;
           break L16;
          }
          $82 = (($p$14) + 6|0);
          $count$0 = (($count$06) + -1)|0;
          $cond = ($count$0|0)==(0);
          if ($cond) {
           break;
          } else {
           $count$06 = $count$0;$old_pair$05 = $99;$p$14 = $82;
          }
         }
        }
        $101 = $24 | $ordered$08;
        $avail$1 = $62;$ordered$1 = $101;
       }
      }
     } else {
      $avail$1 = $avail$07;$ordered$1 = $ordered$08;
     }
    } while(0);
    $102 = (($nn$010) + 1)|0;
    $103 = ($102>>>0)<($$>>>0);
    if ($103) {
     $avail$07 = $avail$1;$nn$010 = $102;$ordered$08 = $ordered$1;$p$011 = $$1;
    } else {
     $avail$0$lcssa = $avail$1;$nn$0$lcssa = $102;$ordered$0$lcssa = $ordered$1;
     break;
    }
   }
  }
 } while(0);
 $104 = (($face) + 780|0);
 HEAP32[$104>>2] = $nn$0$lcssa;
 $105 = (($face) + 784|0);
 HEAP32[$105>>2] = $avail$0$lcssa;
 $106 = (($face) + 788|0);
 HEAP32[$106>>2] = $ordered$0$lcssa;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _tt_face_done_kern($face) {
 $face = $face|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 772|0);
 _FT_Stream_ReleaseFrame($1,$2);
 $3 = (($face) + 776|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 STACKTOP = sp;return;
}
function _tt_face_get_kerning($face,$left_glyph,$right_glyph) {
 $face = $face|0;
 $left_glyph = $left_glyph|0;
 $right_glyph = $right_glyph|0;
 var $$ = 0, $$min$0 = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$value$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $count$018 = 0, $count2$013 = 0, $mask$016 = 0, $max$0$ = 0, $max$08 = 0, $min$07 = 0, $num_pairs$0 = 0, $p$015 = 0, $p$112 = 0, $result$0$lcssa = 0, $result$019 = 0;
 var $result$1 = 0, $value$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 772|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 776|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + ($3)|0);
 $5 = (($face) + 780|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $result$0$lcssa = 0;
  STACKTOP = sp;return ($result$0$lcssa|0);
 }
 $8 = (($1) + 4|0);
 $9 = (($face) + 784|0);
 $10 = $left_glyph << 16;
 $11 = $10 | $right_glyph;
 $12 = (($face) + 788|0);
 $count$018 = $6;$mask$016 = 1;$p$015 = $8;$result$019 = 0;
 while(1) {
  $13 = (($p$015) + 6|0);
  $14 = ($13>>>0)>($4>>>0);
  if ($14) {
   $result$0$lcssa = $result$019;
   label = 20;
   break;
  }
  $15 = (($p$015) + 2|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16&255;
  $18 = $17 << 8;
  $19 = (($p$015) + 3|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20&255;
  $22 = $18 | $21;
  $23 = (($p$015) + 4|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = (($p$015) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = (($p$015) + ($22)|0);
  $28 = ($27>>>0)>($4>>>0);
  $$ = $28 ? $4 : $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $29 & $mask$016;
  $31 = ($30|0)==(0);
  L7: do {
   if ($31) {
    $result$1 = $result$019;
   } else {
    $32 = (($p$015) + 14|0);
    $33 = ($32>>>0)>($$>>>0);
    if ($33) {
     $result$1 = $result$019;
    } else {
     $34 = HEAP8[$13>>0]|0;
     $35 = $34&255;
     $36 = $35 << 8;
     $37 = (($p$015) + 7|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = $38&255;
     $40 = $36 | $39;
     $41 = $$;
     $42 = $32;
     $43 = (($41) - ($42))|0;
     $44 = ($40*6)|0;
     $45 = ($43|0)<($44|0);
     if ($45) {
      $46 = (($43|0) / 6)&-1;
      $num_pairs$0 = $46;
     } else {
      $num_pairs$0 = $40;
     }
     $cond = ($24<<24>>24)==(0);
     if ($cond) {
      $47 = HEAP32[$12>>2]|0;
      $48 = $47 & $mask$016;
      $49 = ($48|0)==(0);
      $50 = ($num_pairs$0|0)==(0);
      if ($49) {
       if ($50) {
        $result$1 = $result$019;
        break;
       } else {
        $count2$013 = $num_pairs$0;$p$112 = $32;
       }
       while(1) {
        $84 = HEAP8[$p$112>>0]|0;
        $85 = $84&255;
        $86 = $85 << 24;
        $87 = (($p$112) + 1|0);
        $88 = HEAP8[$87>>0]|0;
        $89 = $88&255;
        $90 = $89 << 16;
        $91 = $90 | $86;
        $92 = (($p$112) + 2|0);
        $93 = HEAP8[$92>>0]|0;
        $94 = $93&255;
        $95 = $94 << 8;
        $96 = $91 | $95;
        $97 = (($p$112) + 3|0);
        $98 = HEAP8[$97>>0]|0;
        $99 = $98&255;
        $100 = $96 | $99;
        $101 = ($100|0)==($11|0);
        if ($101) {
         break;
        }
        $110 = (($p$112) + 6|0);
        $111 = (($count2$013) + -1)|0;
        $112 = ($111|0)==(0);
        if ($112) {
         $result$1 = $result$019;
         break L7;
        } else {
         $count2$013 = $111;$p$112 = $110;
        }
       }
       $102 = (($p$112) + 4|0);
       $103 = HEAP8[$102>>0]|0;
       $104 = $103 << 24 >> 24;
       $105 = $104 << 8;
       $106 = (($p$112) + 5|0);
       $107 = HEAP8[$106>>0]|0;
       $108 = $107&255;
       $109 = $105 | $108;
       $value$0 = $109;
      } else {
       if ($50) {
        $result$1 = $result$019;
        break;
       } else {
        $max$08 = $num_pairs$0;$min$07 = 0;
       }
       while(1) {
        $51 = (($max$08) + ($min$07))|0;
        $52 = $51 >>> 1;
        $53 = ($52*6)|0;
        $$sum2 = (($53) + 14)|0;
        $54 = (($p$015) + ($$sum2)|0);
        $55 = HEAP8[$54>>0]|0;
        $56 = $55&255;
        $57 = $56 << 24;
        $$sum3 = (($53) + 15)|0;
        $58 = (($p$015) + ($$sum3)|0);
        $59 = HEAP8[$58>>0]|0;
        $60 = $59&255;
        $61 = $60 << 16;
        $62 = $61 | $57;
        $$sum4 = (($53) + 16)|0;
        $63 = (($p$015) + ($$sum4)|0);
        $64 = HEAP8[$63>>0]|0;
        $65 = $64&255;
        $66 = $65 << 8;
        $67 = $62 | $66;
        $$sum5 = (($53) + 17)|0;
        $68 = (($p$015) + ($$sum5)|0);
        $69 = HEAP8[$68>>0]|0;
        $70 = $69&255;
        $71 = $67 | $70;
        $72 = ($71|0)==($11|0);
        if ($72) {
         break;
        }
        $81 = ($71>>>0)<($11>>>0);
        $82 = (($52) + 1)|0;
        $$min$0 = $81 ? $82 : $min$07;
        $max$0$ = $81 ? $max$08 : $52;
        $83 = ($$min$0>>>0)<($max$0$>>>0);
        if ($83) {
         $max$08 = $max$0$;$min$07 = $$min$0;
        } else {
         $result$1 = $result$019;
         break L7;
        }
       }
       $$sum1 = (($53) + 18)|0;
       $73 = (($p$015) + ($$sum1)|0);
       $74 = HEAP8[$73>>0]|0;
       $75 = $74 << 24 >> 24;
       $76 = $75 << 8;
       $$sum6 = (($53) + 19)|0;
       $77 = (($p$015) + ($$sum6)|0);
       $78 = HEAP8[$77>>0]|0;
       $79 = $78&255;
       $80 = $76 | $79;
       $value$0 = $80;
      }
      $113 = $26 & 8;
      $114 = ($113<<24>>24)==(0);
      $115 = $114 ? $result$019 : 0;
      $$value$0 = (($value$0) + ($115))|0;
      $result$1 = $$value$0;
     } else {
      $result$1 = $result$019;
     }
    }
   }
  } while(0);
  $116 = (($count$018) + -1)|0;
  $117 = $mask$016 << 1;
  $118 = ($116|0)==(0);
  if ($118) {
   $result$0$lcssa = $result$1;
   label = 20;
   break;
  } else {
   $count$018 = $116;$mask$016 = $117;$p$015 = $$;$result$019 = $result$1;
  }
 }
 if ((label|0) == 20) {
  STACKTOP = sp;return ($result$0$lcssa|0);
 }
 return 0|0;
}
function _FT_Init_Class_ft_grays_raster($clazz) {
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 1869968492;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 2696;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 2062;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 2697;
 $4 = (($clazz) + 20|0);
 HEAP32[$4>>2] = 3745;
 STACKTOP = sp;return;
}
function _gray_raster_new($memory,$araster) {
 $memory = $memory|0;
 $araster = $araster|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$araster>>2] = 0;
 $0 = (_ft_mem_alloc($memory,20,$error)|0);
 $1 = HEAP32[$error>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return ($1|0);
 }
 $3 = (($0) + 12|0);
 HEAP32[$3>>2] = $memory;
 HEAP32[$araster>>2] = $0;
 STACKTOP = sp;return ($1|0);
}
function _gray_raster_reset($raster,$pool_base,$pool_size) {
 $raster = $raster|0;
 $pool_base = $pool_base|0;
 $pool_size = $pool_size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($raster|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = ($pool_base|0)!=(0|0);
 $2 = ($pool_size|0)>(3323);
 $or$cond = $1 & $2;
 if ($or$cond) {
  $3 = (($raster) + 16|0);
  HEAP32[$3>>2] = $pool_base;
  $4 = (($pool_base) + 1280|0);
  HEAP32[$raster>>2] = $4;
  $5 = (($pool_size) + -1280)|0;
  $6 = $5 & -16;
  $7 = (($raster) + 4|0);
  HEAP32[$7>>2] = $6;
  $8 = $5 >>> 7;
  $9 = (($raster) + 8|0);
  HEAP32[$9>>2] = $8;
  STACKTOP = sp;return;
 } else {
  HEAP32[$raster>>2] = 0;
  $10 = (($raster) + 4|0);
  HEAP32[$10>>2] = 0;
  $11 = (($raster) + 16|0);
  HEAP32[$11>>2] = 0;
  STACKTOP = sp;return;
 }
}
function _gray_raster_render($raster,$params) {
 $raster = $raster|0;
 $params = $params|0;
 var $$0 = 0, $$pn2$i$i = 0, $$pn2$i$i$phi = 0, $$pre = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $band$i = 0, $bands$i = 0, $cell$0$i$i = 0, $cell$01$i$i = 0, $cell$04$i$i = 0, $cell_start$0$i = 0, $cover$02$i$i = 0, $error$i$i = 0, $exitcond = 0, $func_interface$i$i = 0, $max$i = 0, $max_y$i = 0, $min$i = 0, $n$i = 0, $num_bands$i = 0, $or$cond$i$i = 0, $vec$0$i$i = 0, $vec$01$i$i = 0, $vec$03$i$i = 0;
 var $x$03$i$i = 0, $yindex$04$i = 0, $yindex$06$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $error$i$i = sp + 368|0;
 $func_interface$i$i = sp + 344|0;
 $bands$i = sp + 24|0;
 $band$i = sp + 20|0;
 $n$i = sp + 16|0;
 $num_bands$i = sp + 8|0;
 $min$i = sp + 4|0;
 $max$i = sp;
 $max_y$i = sp + 12|0;
 $0 = (($params) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$params>>2]|0;
 $3 = ($raster|0)==(0|0);
 if ($3) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = HEAP32[$raster>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($raster) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0);
 if ($8) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = ($1|0)==(0|0);
 if ($9) {
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($1) + 2|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = $11 << 16 >> 16;
 $13 = ($11<<16>>16)==(0);
 if ($13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = HEAP16[$1>>1]|0;
 $15 = $14 << 16 >> 16;
 $16 = ($14<<16>>16)<(1);
 if ($16) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = (($1) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if ($19) {
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = (($1) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = (($15) + -1)|0;
 $24 = (($18) + ($23<<1)|0);
 $25 = HEAP16[$24>>1]|0;
 $26 = $25 << 16 >> 16;
 $27 = (($26) + 1)|0;
 $28 = ($12|0)==($27|0);
 if (!($28)) {
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($raster) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($params) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 & 2;
 $34 = ($33|0)==(0);
 if ($34) {
  $35 = ($2|0)==(0|0);
  if ($35) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
  $36 = (($2) + 4|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0);
  if ($38) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $39 = HEAP32[$2>>2]|0;
  $40 = ($39|0)==(0);
  if ($40) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $41 = (($2) + 12|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($42|0)==(0|0);
  if ($43) {
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $44 = $32 & 1;
 $45 = ($44|0)==(0);
 if ($45) {
  $$0 = 19;
  STACKTOP = sp;return ($$0|0);
 }
 do {
  if ($34) {
   $46 = (($30) + 1024|0);
   HEAP32[$46>>2] = 0;
   $47 = (($30) + 1028|0);
   HEAP32[$47>>2] = 0;
   $48 = (($2) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($30) + 1032|0);
   HEAP32[$50>>2] = $49;
   $51 = HEAP32[$2>>2]|0;
   $52 = (($30) + 1036|0);
   HEAP32[$52>>2] = $51;
   $62 = $4;
  } else {
   $53 = $32 & 4;
   $54 = ($53|0)==(0);
   $55 = (($30) + 1024|0);
   if ($54) {
    HEAP32[$55>>2] = -32768;
    $57 = (($30) + 1028|0);
    HEAP32[$57>>2] = -32768;
    $58 = (($30) + 1032|0);
    HEAP32[$58>>2] = 32767;
    $59 = (($30) + 1036|0);
    HEAP32[$59>>2] = 32767;
    $62 = $4;
    break;
   } else {
    $56 = (($params) + 32|0);
    ;HEAP32[$55+0>>2]=HEAP32[$56+0>>2]|0;HEAP32[$55+4>>2]=HEAP32[$56+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$56+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$56+12>>2]|0;
    $$pre = HEAP32[$raster>>2]|0;
    $62 = $$pre;
    break;
   }
  }
 } while(0);
 $60 = HEAP32[$6>>2]|0;
 $61 = (($30) + 1260|0);
 HEAP32[$61>>2] = $62;
 $63 = (($30) + 1264|0);
 HEAP32[$63>>2] = $60;
 $64 = (($30) + 1268|0);
 HEAP32[$64>>2] = $62;
 $65 = (($30) + 44|0);
 HEAP32[$65>>2] = 0;
 $66 = (($30) + 48|0);
 HEAP32[$66>>2] = 0;
 $67 = (($30) + 52|0);
 HEAP32[$67>>2] = 0;
 $68 = (($30) + 32|0);
 HEAP32[$68>>2] = 0;
 $69 = (($30) + 36|0);
 HEAP32[$69>>2] = 0;
 $70 = (($30) + 40|0);
 HEAP32[$70>>2] = 1;
 $71 = (($30) + 980|0);
 ;HEAP32[$71+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$71+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$71+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$71+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$71+16>>2]=HEAP32[$1+16>>2]|0;
 HEAP32[$67>>2] = 0;
 HEAP32[$70>>2] = 1;
 $72 = (($raster) + 8|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = (($30) + 1248|0);
 HEAP32[$74>>2] = $73;
 $75 = (($30) + 1232|0);
 HEAP32[$75>>2] = 0;
 $76 = HEAP32[$31>>2]|0;
 $77 = $76 & 2;
 $78 = ($77|0)==(0);
 if ($78) {
  $85 = (($30) + 1000|0);
  ;HEAP32[$85+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$85+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$85+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$85+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$85+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$85+20>>2]=HEAP32[$2+20>>2]|0;
  $86 = (($30) + 1236|0);
  HEAP32[$86>>2] = 425;
  $87 = (($30) + 1240|0);
  HEAP32[$87>>2] = $30;
 } else {
  $79 = (($params) + 12|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($30) + 1236|0);
  HEAP32[$81>>2] = $80;
  $82 = (($params) + 28|0);
  $83 = HEAP32[$82>>2]|0;
  $84 = (($30) + 1240|0);
  HEAP32[$84>>2] = $83;
 }
 $88 = (($30) + 984|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = (($30) + 982|0);
 $91 = HEAP16[$90>>1]|0;
 $92 = $91 << 16 >> 16;
 $93 = (($89) + ($92<<3)|0);
 $94 = ($91<<16>>16)<(1);
 if ($94) {
  $95 = (($30) + 8|0);
  ;HEAP32[$95+0>>2]=0|0;HEAP32[$95+4>>2]=0|0;HEAP32[$95+8>>2]=0|0;HEAP32[$95+12>>2]=0|0;
  $$pre$i = (($30) + 12|0);
  $$pre$phi$iZ2D = $$pre$i;$129 = 0;$134 = 0;$139 = 0;$144 = 0;
 } else {
  $96 = HEAP32[$89>>2]|0;
  $97 = (($30) + 12|0);
  HEAP32[$97>>2] = $96;
  $98 = (($30) + 8|0);
  HEAP32[$98>>2] = $96;
  $99 = (($89) + 4|0);
  $100 = HEAP32[$99>>2]|0;
  $101 = (($30) + 20|0);
  HEAP32[$101>>2] = $100;
  $102 = (($30) + 16|0);
  HEAP32[$102>>2] = $100;
  $103 = ($91<<16>>16)>(1);
  if ($103) {
   $vec$01$i$i = (($89) + 8|0);
   $$pn2$i$i = $89;$108 = $96;$110 = $96;$112 = $100;$114 = $100;$vec$03$i$i = $vec$01$i$i;
   while(1) {
    $104 = HEAP32[$vec$03$i$i>>2]|0;
    $105 = (($$pn2$i$i) + 12|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ($104|0)<($108|0);
    if ($107) {
     HEAP32[$98>>2] = $104;
     $311 = $104;
    } else {
     $311 = $108;
    }
    $109 = ($104|0)>($110|0);
    if ($109) {
     HEAP32[$97>>2] = $104;
     $312 = $104;
    } else {
     $312 = $110;
    }
    $111 = ($106|0)<($112|0);
    if ($111) {
     HEAP32[$102>>2] = $106;
     $313 = $106;
    } else {
     $313 = $112;
    }
    $113 = ($106|0)>($114|0);
    if ($113) {
     HEAP32[$101>>2] = $106;
     $314 = $106;
    } else {
     $314 = $114;
    }
    $vec$0$i$i = (($vec$03$i$i) + 8|0);
    $115 = ($vec$0$i$i>>>0)<($93>>>0);
    if ($115) {
     $$pn2$i$i$phi = $vec$03$i$i;$108 = $311;$110 = $312;$112 = $313;$114 = $314;$vec$03$i$i = $vec$0$i$i;$$pn2$i$i = $$pn2$i$i$phi;
    } else {
     $117 = $311;$119 = $313;$121 = $312;$124 = $314;
     break;
    }
   }
  } else {
   $117 = $96;$119 = $100;$121 = $96;$124 = $100;
  }
  $116 = $117 >> 6;
  HEAP32[$98>>2] = $116;
  $118 = $119 >> 6;
  HEAP32[$102>>2] = $118;
  $120 = (($121) + 63)|0;
  $122 = $120 >> 6;
  HEAP32[$97>>2] = $122;
  $123 = (($124) + 63)|0;
  $125 = $123 >> 6;
  HEAP32[$101>>2] = $125;
  $$pre$phi$iZ2D = $97;$129 = $122;$134 = $116;$139 = $125;$144 = $118;
 }
 $126 = (($30) + 1024|0);
 $127 = HEAP32[$126>>2]|0;
 $128 = ($129|0)>($127|0);
 if (!($128)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $130 = (($30) + 8|0);
 $131 = (($30) + 1032|0);
 $132 = HEAP32[$131>>2]|0;
 $133 = ($134|0)<($132|0);
 if (!($133)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $135 = (($30) + 20|0);
 $136 = (($30) + 1028|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($139|0)>($137|0);
 if (!($138)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $140 = (($30) + 16|0);
 $141 = (($30) + 1036|0);
 $142 = HEAP32[$141>>2]|0;
 $143 = ($144|0)<($142|0);
 if (!($143)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $145 = ($134|0)<($127|0);
 if ($145) {
  HEAP32[$130>>2] = $127;
  $151 = $127;
 } else {
  $151 = $134;
 }
 $146 = ($144|0)<($137|0);
 if ($146) {
  HEAP32[$140>>2] = $137;
  $155 = $137;
 } else {
  $155 = $144;
 }
 $147 = ($129|0)>($132|0);
 if ($147) {
  HEAP32[$$pre$phi$iZ2D>>2] = $132;
  $150 = $132;
 } else {
  $150 = $129;
 }
 $148 = ($139|0)>($142|0);
 if ($148) {
  HEAP32[$135>>2] = $142;
  $154 = $142;
 } else {
  $154 = $139;
 }
 $149 = (($150) - ($151))|0;
 $152 = (($30) + 24|0);
 HEAP32[$152>>2] = $149;
 $153 = (($154) - ($155))|0;
 $156 = (($30) + 28|0);
 HEAP32[$156>>2] = $153;
 $157 = HEAP32[$74>>2]|0;
 $158 = (($153|0) / ($157|0))&-1;
 HEAP32[$num_bands$i>>2] = $158;
 $159 = HEAP32[$num_bands$i>>2]|0;
 $160 = ($159|0)==(0);
 if ($160) {
  HEAP32[$num_bands$i>>2] = 1;
 }
 $161 = HEAP32[$num_bands$i>>2]|0;
 $162 = ($161|0)>(38);
 if ($162) {
  HEAP32[$num_bands$i>>2] = 39;
 }
 $163 = (($30) + 1252|0);
 HEAP32[$163>>2] = 0;
 $164 = HEAP32[$140>>2]|0;
 HEAP32[$min$i>>2] = $164;
 $165 = HEAP32[$135>>2]|0;
 HEAP32[$max_y$i>>2] = $165;
 HEAP32[$n$i>>2] = 0;
 $166 = HEAP32[$n$i>>2]|0;
 $167 = HEAP32[$num_bands$i>>2]|0;
 $168 = ($166|0)<($167|0);
 L106: do {
  if ($168) {
   $169 = (($bands$i) + 4|0);
   $170 = (($30) + 1272|0);
   $171 = (($func_interface$i$i) + 4|0);
   $172 = (($func_interface$i$i) + 8|0);
   $173 = (($func_interface$i$i) + 12|0);
   $174 = (($func_interface$i$i) + 16|0);
   $175 = (($func_interface$i$i) + 20|0);
   $176 = (($30) + 1256|0);
   $177 = (($30) + 1236|0);
   $178 = (($30) + 1244|0);
   $179 = (($30) + 1040|0);
   $180 = (($30) + 1240|0);
   L108: while(1) {
    $181 = HEAP32[$min$i>>2]|0;
    $182 = HEAP32[$74>>2]|0;
    $183 = (($182) + ($181))|0;
    HEAP32[$max$i>>2] = $183;
    $184 = HEAP32[$n$i>>2]|0;
    $185 = HEAP32[$num_bands$i>>2]|0;
    $186 = (($185) + -1)|0;
    $187 = ($184|0)==($186|0);
    if ($187) {
     label = 58;
    } else {
     $188 = HEAP32[$max$i>>2]|0;
     $189 = HEAP32[$max_y$i>>2]|0;
     $190 = ($188|0)>($189|0);
     if ($190) {
      label = 58;
     }
    }
    if ((label|0) == 58) {
     label = 0;
     $191 = HEAP32[$max_y$i>>2]|0;
     HEAP32[$max$i>>2] = $191;
    }
    $192 = HEAP32[$min$i>>2]|0;
    HEAP32[$bands$i>>2] = $192;
    $193 = HEAP32[$max$i>>2]|0;
    HEAP32[$169>>2] = $193;
    HEAP32[$band$i>>2] = $bands$i;
    $194 = HEAP32[$band$i>>2]|0;
    $195 = ($194>>>0)<($bands$i>>>0);
    if (!($195)) {
     while(1) {
      $196 = HEAP32[$61>>2]|0;
      HEAP32[$64>>2] = $196;
      $197 = HEAP32[$band$i>>2]|0;
      $198 = (($197) + 4|0);
      $199 = HEAP32[$198>>2]|0;
      $200 = HEAP32[$band$i>>2]|0;
      $201 = HEAP32[$200>>2]|0;
      $202 = (($199) - ($201))|0;
      HEAP32[$170>>2] = $202;
      $203 = $202 << 2;
      $204 = $203 & 12;
      $205 = ($204|0)==(0);
      if ($205) {
       $cell_start$0$i = $203;
      } else {
       $206 = (($203) + 16)|0;
       $207 = (($206) - ($204))|0;
       $cell_start$0$i = $207;
      }
      $208 = HEAP32[$63>>2]|0;
      $209 = $208 & -16;
      $210 = HEAP32[$61>>2]|0;
      $211 = (($210) + ($cell_start$0$i)|0);
      HEAP32[$65>>2] = $211;
      $212 = ($cell_start$0$i|0)<($209|0);
      do {
       if ($212) {
        $213 = (($209) - ($cell_start$0$i))|0;
        $214 = $213 >> 4;
        HEAP32[$66>>2] = $214;
        $215 = ($213|0)<(32);
        if ($215) {
         label = 86;
         break;
        }
        $216 = ($202|0)>(0);
        if ($216) {
         $yindex$04$i = 0;
         while(1) {
          $217 = HEAP32[$64>>2]|0;
          $218 = (($217) + ($yindex$04$i<<2)|0);
          HEAP32[$218>>2] = 0;
          $219 = (($yindex$04$i) + 1)|0;
          $exitcond = ($219|0)==($202|0);
          if ($exitcond) {
           break;
          } else {
           $yindex$04$i = $219;
          }
         }
        }
        HEAP32[$67>>2] = 0;
        HEAP32[$70>>2] = 1;
        $220 = HEAP32[$band$i>>2]|0;
        $221 = HEAP32[$220>>2]|0;
        HEAP32[$140>>2] = $221;
        $222 = HEAP32[$band$i>>2]|0;
        $223 = (($222) + 4|0);
        $224 = HEAP32[$223>>2]|0;
        HEAP32[$135>>2] = $224;
        $225 = HEAP32[$band$i>>2]|0;
        $226 = (($225) + 4|0);
        $227 = HEAP32[$226>>2]|0;
        $228 = HEAP32[$band$i>>2]|0;
        $229 = HEAP32[$228>>2]|0;
        $230 = (($227) - ($229))|0;
        HEAP32[$156>>2] = $230;
        HEAP32[$error$i$i>>2] = 0;
        HEAP32[$func_interface$i$i>>2] = 2698;
        HEAP32[$171>>2] = 2699;
        HEAP32[$172>>2] = 1611;
        HEAP32[$173>>2] = 288;
        HEAP32[$174>>2] = 0;
        HEAP32[$175>>2] = 0;
        HEAP32[$176>>2] = 0;
        $231 = (_FT_Outline_Decompose($71,$func_interface$i$i,$30)|0);
        HEAP32[$error$i$i>>2] = $231;
        _gray_record_cell($30);
        $232 = HEAP32[$176>>2]|0;
        $233 = ($232|0)==(0);
        if (!($233)) {
         HEAP32[$error$i$i>>2] = $232;
         HEAP32[$176>>2] = 0;
        }
        $234 = HEAP32[$error$i$i>>2]|0;
        if ((($234|0) == 64)) {
         label = 86;
         break;
        } else if (!((($234|0) == 0))) {
         $$0 = 1;
         label = 94;
         break L108;
        }
        $235 = HEAP32[$67>>2]|0;
        $236 = ($235|0)==(0);
        do {
         if (!($236)) {
          HEAP32[$75>>2] = 0;
          $237 = HEAP32[$170>>2]|0;
          $238 = ($237|0)>(0);
          if ($238) {
           $yindex$06$i$i = 0;
           while(1) {
            $239 = HEAP32[$64>>2]|0;
            $240 = (($239) + ($yindex$06$i$i<<2)|0);
            $cell$01$i$i = HEAP32[$240>>2]|0;
            $241 = ($cell$01$i$i|0)==(0|0);
            do {
             if (!($241)) {
              $cell$04$i$i = $cell$01$i$i;$cover$02$i$i = 0;$x$03$i$i = 0;
              while(1) {
               $242 = HEAP32[$cell$04$i$i>>2]|0;
               $243 = ($242|0)<=($x$03$i$i|0);
               $244 = ($cover$02$i$i|0)==(0);
               $or$cond$i$i = $243 | $244;
               if (!($or$cond$i$i)) {
                $245 = $cover$02$i$i << 9;
                $246 = (($242) - ($x$03$i$i))|0;
                _gray_hline($30,$x$03$i$i,$yindex$06$i$i,$245,$246);
               }
               $247 = (($cell$04$i$i) + 4|0);
               $248 = HEAP32[$247>>2]|0;
               $249 = (($248) + ($cover$02$i$i))|0;
               $250 = $249 << 9;
               $251 = (($cell$04$i$i) + 8|0);
               $252 = HEAP32[$251>>2]|0;
               $253 = (($250) - ($252))|0;
               $254 = ($250|0)==($252|0);
               do {
                if (!($254)) {
                 $255 = HEAP32[$cell$04$i$i>>2]|0;
                 $256 = ($255|0)>(-1);
                 if (!($256)) {
                  break;
                 }
                 _gray_hline($30,$255,$yindex$06$i$i,$253,1);
                }
               } while(0);
               $257 = HEAP32[$cell$04$i$i>>2]|0;
               $258 = (($257) + 1)|0;
               $259 = (($cell$04$i$i) + 12|0);
               $cell$0$i$i = HEAP32[$259>>2]|0;
               $260 = ($cell$0$i$i|0)==(0|0);
               if ($260) {
                break;
               } else {
                $cell$04$i$i = $cell$0$i$i;$cover$02$i$i = $249;$x$03$i$i = $258;
               }
              }
              $261 = ($249|0)==(0);
              if ($261) {
               break;
              }
              $262 = HEAP32[$152>>2]|0;
              $263 = (($262) - ($258))|0;
              _gray_hline($30,$258,$yindex$06$i$i,$250,$263);
             }
            } while(0);
            $264 = (($yindex$06$i$i) + 1)|0;
            $265 = HEAP32[$170>>2]|0;
            $266 = ($264|0)<($265|0);
            if ($266) {
             $yindex$06$i$i = $264;
            } else {
             break;
            }
           }
          }
          $267 = HEAP32[$177>>2]|0;
          $268 = ($267|0)==(0|0);
          if ($268) {
           break;
          }
          $269 = HEAP32[$75>>2]|0;
          $270 = ($269|0)>(0);
          if (!($270)) {
           break;
          }
          $271 = HEAP32[$178>>2]|0;
          $272 = HEAP32[$180>>2]|0;
          FUNCTION_TABLE_viiii[$267 & 511]($271,$269,$179,$272);
         }
        } while(0);
        $273 = HEAP32[$band$i>>2]|0;
        $274 = (($273) + -8|0);
        HEAP32[$band$i>>2] = $274;
       } else {
        label = 86;
       }
      } while(0);
      if ((label|0) == 86) {
       label = 0;
       $277 = HEAP32[$band$i>>2]|0;
       $278 = HEAP32[$277>>2]|0;
       $279 = HEAP32[$band$i>>2]|0;
       $280 = (($279) + 4|0);
       $281 = HEAP32[$280>>2]|0;
       $282 = (($281) - ($278))|0;
       $283 = $282 >> 1;
       $284 = (($283) + ($278))|0;
       $285 = ($283|0)==(0);
       if ($285) {
        $$0 = 1;
        label = 94;
        break L108;
       }
       $286 = (($278) - ($281))|0;
       $287 = HEAP32[$74>>2]|0;
       $288 = ($286|0)<($287|0);
       if (!($288)) {
        $289 = HEAP32[$163>>2]|0;
        $290 = (($289) + 1)|0;
        HEAP32[$163>>2] = $290;
       }
       $291 = HEAP32[$band$i>>2]|0;
       $292 = (($291) + 8|0);
       HEAP32[$292>>2] = $278;
       $293 = HEAP32[$band$i>>2]|0;
       $294 = (($293) + 12|0);
       HEAP32[$294>>2] = $284;
       $295 = HEAP32[$band$i>>2]|0;
       HEAP32[$295>>2] = $284;
       $296 = HEAP32[$band$i>>2]|0;
       $297 = (($296) + 4|0);
       HEAP32[$297>>2] = $281;
       $298 = HEAP32[$band$i>>2]|0;
       $299 = (($298) + 8|0);
       HEAP32[$band$i>>2] = $299;
      }
      $275 = HEAP32[$band$i>>2]|0;
      $276 = ($275>>>0)<($bands$i>>>0);
      if ($276) {
       break;
      }
     }
    }
    $300 = HEAP32[$n$i>>2]|0;
    $301 = (($300) + 1)|0;
    HEAP32[$n$i>>2] = $301;
    $302 = HEAP32[$max$i>>2]|0;
    HEAP32[$min$i>>2] = $302;
    $303 = HEAP32[$n$i>>2]|0;
    $304 = HEAP32[$num_bands$i>>2]|0;
    $305 = ($303|0)<($304|0);
    if (!($305)) {
     break L106;
    }
   }
   if ((label|0) == 94) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $306 = HEAP32[$163>>2]|0;
 $307 = ($306|0)>(8);
 if (!($307)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $308 = HEAP32[$74>>2]|0;
 $309 = ($308|0)>(16);
 if (!($309)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $310 = (($308|0) / 2)&-1;
 HEAP32[$74>>2] = $310;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _gray_raster_done($raster) {
 $raster = $raster|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($raster) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 _ft_mem_free($1,$raster);
 STACKTOP = sp;return;
}
function _gray_render_span($y,$count,$spans,$worker) {
 $y = $y|0;
 $count = $count|0;
 $spans = $spans|0;
 $worker = $worker|0;
 var $$013 = 0, $$04 = 0, $$pn = 0, $$pn6 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0$ph$sum = 0, $p$0$ph$sum5 = 0, $q$0 = 0, $q$1 = 0, $q$2 = 0;
 var $q$3 = 0, $q$4 = 0, $q$5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 1012|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($worker) + 1008|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_imul($3, $y)|0;
 $5 = ($3|0)>(-1);
 if ($5) {
  $6 = (($worker) + 1000|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + -1)|0;
  $9 = Math_imul($8, $3)|0;
  $$pn6 = $9;
 } else {
  $$pn6 = 0;
 }
 $$pn = (($$pn6) - ($4))|0;
 $10 = ($count|0)>(0);
 if ($10) {
  $$013 = $spans;$$04 = $count;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $11 = (($$013) + 4|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  L8: do {
   if (!($13)) {
    $14 = (($$013) + 2|0);
    $15 = HEAP16[$14>>1]|0;
    $16 = $15&65535;
    $17 = ($15&65535)>(7);
    $18 = HEAP16[$$013>>1]|0;
    $19 = $18 << 16 >> 16;
    $p$0$ph$sum = (($$pn) + ($19))|0;
    $20 = (($1) + ($p$0$ph$sum)|0);
    if ($17) {
     _memset(($20|0),($12|0),($16|0))|0;
     break;
    }
    switch ($16|0) {
    case 7:  {
     $$sum = (($19) + 1)|0;
     $p$0$ph$sum5 = (($$pn) + ($$sum))|0;
     $21 = (($1) + ($p$0$ph$sum5)|0);
     HEAP8[$20>>0] = $12;
     $q$0 = $21;
     label = 9;
     break;
    }
    case 6:  {
     $q$0 = $20;
     label = 9;
     break;
    }
    case 5:  {
     $q$1 = $20;
     label = 10;
     break;
    }
    case 2:  {
     $q$4 = $20;
     label = 13;
     break;
    }
    case 1:  {
     $q$5 = $20;
     break;
    }
    case 4:  {
     $q$2 = $20;
     label = 11;
     break;
    }
    case 3:  {
     $q$3 = $20;
     label = 12;
     break;
    }
    default: {
     break L8;
    }
    }
    if ((label|0) == 9) {
     label = 0;
     $22 = (($q$0) + 1|0);
     HEAP8[$q$0>>0] = $12;
     $q$1 = $22;
     label = 10;
    }
    if ((label|0) == 10) {
     label = 0;
     $23 = (($q$1) + 1|0);
     HEAP8[$q$1>>0] = $12;
     $q$2 = $23;
     label = 11;
    }
    if ((label|0) == 11) {
     label = 0;
     $24 = (($q$2) + 1|0);
     HEAP8[$q$2>>0] = $12;
     $q$3 = $24;
     label = 12;
    }
    if ((label|0) == 12) {
     label = 0;
     $25 = (($q$3) + 1|0);
     HEAP8[$q$3>>0] = $12;
     $q$4 = $25;
     label = 13;
    }
    if ((label|0) == 13) {
     label = 0;
     $26 = (($q$4) + 1|0);
     HEAP8[$q$4>>0] = $12;
     $q$5 = $26;
    }
    HEAP8[$q$5>>0] = $12;
   }
  } while(0);
  $27 = (($$04) + -1)|0;
  $28 = (($$013) + 6|0);
  $29 = ($27|0)>(0);
  if ($29) {
   $$013 = $28;$$04 = $27;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _gray_hline($worker,$x,$y,$area,$acount) {
 $worker = $worker|0;
 $x = $x|0;
 $y = $y|0;
 $area = $area|0;
 $acount = $acount|0;
 var $$ = 0, $$$2 = 0, $$2 = 0, $$3 = 0, $$not = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $coverage$1 = 0, $or$cond = 0, $or$cond5 = 0, $span$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $area >> 9;
 $1 = ($0|0)<(0);
 $2 = (0 - ($0))|0;
 $$2 = $1 ? $2 : $0;
 $3 = (($worker) + 996|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 2;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $11 = ($$2|0)>(255);
   $$$2 = $11 ? 255 : $$2;
   $coverage$1 = $$$2;
  } else {
   $7 = $$2 & 511;
   $8 = ($7>>>0)>(256);
   if ($8) {
    $9 = (512 - ($7))|0;
    $coverage$1 = $9;
    break;
   } else {
    $10 = ($7|0)==(256);
    $$3 = $10 ? 255 : $7;
    $coverage$1 = $$3;
    break;
   }
  }
 } while(0);
 $12 = (($worker) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($y))|0;
 $15 = (($worker) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($x))|0;
 $18 = ($17|0)<(32767);
 $$ = $18 ? $17 : 32767;
 $19 = ($coverage$1|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 $20 = (($worker) + 1232|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($worker) + 1040|0);
 $$sum = (($21) + -1)|0;
 $23 = ($21|0)>(0);
 $24 = (($worker) + 1244|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==($14|0);
 $or$cond5 = $23 & $26;
 if ($or$cond5) {
  $27 = ((($worker) + (($$sum*6)|0)|0) + 1040|0);
  $28 = HEAP16[$27>>1]|0;
  $29 = $28 << 16 >> 16;
  $30 = ((($worker) + (($$sum*6)|0)|0) + 1042|0);
  $31 = HEAP16[$30>>1]|0;
  $32 = $31&65535;
  $33 = (($32) + ($29))|0;
  $34 = ($33|0)==($$|0);
  if ($34) {
   $35 = ((($worker) + (($$sum*6)|0)|0) + 1044|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = $36&255;
   $38 = ($37|0)==($coverage$1|0);
   if ($38) {
    $39 = (($32) + ($acount))|0;
    $40 = $39&65535;
    HEAP16[$30>>1] = $40;
    STACKTOP = sp;return;
   } else {
    $43 = $14;
   }
  } else {
   $43 = $14;
  }
 } else {
  $43 = $25;
 }
 $41 = (($worker) + 1244|0);
 $42 = ($43|0)!=($14|0);
 $44 = ($21|0)>(31);
 $or$cond = $42 | $44;
 if ($or$cond) {
  $45 = (($worker) + 1236|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  $$not = $23 ^ 1;
  $brmerge = $47 | $$not;
  if (!($brmerge)) {
   $48 = (($worker) + 1240|0);
   $49 = HEAP32[$48>>2]|0;
   FUNCTION_TABLE_viiii[$46 & 511]($43,$21,$22,$49);
  }
  HEAP32[$20>>2] = 0;
  HEAP32[$41>>2] = $14;
  $span$0 = $22;
 } else {
  $50 = ((($worker) + (($21*6)|0)|0) + 1040|0);
  $span$0 = $50;
 }
 $51 = $$&65535;
 HEAP16[$span$0>>1] = $51;
 $52 = $acount&65535;
 $53 = (($span$0) + 2|0);
 HEAP16[$53>>1] = $52;
 $54 = $coverage$1&255;
 $55 = (($span$0) + 4|0);
 HEAP8[$55>>0] = $54;
 $56 = HEAP32[$20>>2]|0;
 $57 = (($56) + 1)|0;
 HEAP32[$20>>2] = $57;
 STACKTOP = sp;return;
}
function _gray_record_cell($worker) {
 $worker = $worker|0;
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pcell$0$lcssa$i = 0, $pcell$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($worker) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($worker) + 36|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 | $4;
 $8 = ($7|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$worker>>2]|0;
 $10 = (($worker) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)>($11|0);
 $$$i = $12 ? $11 : $9;
 $13 = (($worker) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($worker) + 1268|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + ($14<<2)|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 L7: do {
  if ($19) {
   $40 = 0;$pcell$0$lcssa$i = $17;
   label = 7;
  } else {
   $24 = $18;$pcell$03$i = $17;
   while(1) {
    $23 = HEAP32[$24>>2]|0;
    $25 = ($23|0)>($$$i|0);
    if ($25) {
     $40 = $24;$pcell$0$lcssa$i = $pcell$03$i;
     label = 7;
     break L7;
    }
    $26 = ($23|0)==($$$i|0);
    $21 = (($24) + 12|0);
    if ($26) {
     $$0$i = $24;
     break L7;
    }
    $20 = HEAP32[$21>>2]|0;
    $22 = ($20|0)==(0|0);
    if ($22) {
     $40 = 0;$pcell$0$lcssa$i = $21;
     label = 7;
     break;
    } else {
     $24 = $20;$pcell$03$i = $21;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 7) {
   $27 = (($worker) + 52|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($worker) + 48|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($28|0)<($30|0);
   if ($31) {
    $33 = (($worker) + 44|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($28) + 1)|0;
    HEAP32[$27>>2] = $35;
    $36 = (($34) + ($28<<4)|0);
    HEAP32[$36>>2] = $$$i;
    $37 = ((($34) + ($28<<4)|0) + 8|0);
    HEAP32[$37>>2] = 0;
    $38 = ((($34) + ($28<<4)|0) + 4|0);
    HEAP32[$38>>2] = 0;
    $39 = ((($34) + ($28<<4)|0) + 12|0);
    HEAP32[$39>>2] = $40;
    HEAP32[$pcell$0$lcssa$i>>2] = $36;
    $$0$i = $36;
    break;
   }
   $32 = (($worker) + 1256|0);
   HEAP32[$32>>2] = 64;
   STACKTOP = sp;return;
  }
 } while(0);
 $41 = ($$0$i|0)==(0|0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = HEAP32[$3>>2]|0;
 $43 = (($$0$i) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + ($42))|0;
 HEAP32[$43>>2] = $45;
 $46 = HEAP32[$5>>2]|0;
 $47 = (($$0$i) + 4|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46))|0;
 HEAP32[$47>>2] = $49;
 STACKTOP = sp;return;
}
function _gray_move_to($to,$worker) {
 $to = $to|0;
 $worker = $worker|0;
 var $$$i$i = 0, $$0 = 0, $$1$i = 0, $$ex$i = 0, $$ex$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _gray_record_cell($worker);
 $0 = (($worker) + 1256|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$to>>2]|0;
 $4 = $3 << 2;
 $5 = (($to) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 << 2;
 $8 = $4 >> 8;
 $9 = $7 >> 8;
 $10 = (($worker) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)<($8|0);
 $$ex$i = $12 ? $11 : $8;
 $13 = (($worker) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($$ex$i|0)<($14|0);
 $16 = (($14) + -1)|0;
 $$1$i = $15 ? $16 : $$ex$i;
 $17 = (($worker) + 32|0);
 HEAP32[$17>>2] = 0;
 $18 = (($worker) + 36|0);
 HEAP32[$18>>2] = 0;
 $19 = (($$1$i) - ($14))|0;
 HEAP32[$worker>>2] = $19;
 $20 = (($worker) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($9) - ($21))|0;
 $23 = (($worker) + 4|0);
 HEAP32[$23>>2] = $22;
 $24 = $9 << 8;
 $25 = (($worker) + 72|0);
 HEAP32[$25>>2] = $24;
 $26 = (($worker) + 40|0);
 HEAP32[$26>>2] = 0;
 $27 = ($11|0)<($$1$i|0);
 $$ex$i$i = $27 ? $11 : $$1$i;
 $28 = (($$ex$i$i) - ($14))|0;
 $29 = ($28|0)>(-1);
 $$$i$i = $29 ? $28 : -1;
 $30 = ($$$i$i|0)==($19|0);
 if (!($30)) {
  _gray_record_cell($worker);
  HEAP32[$17>>2] = 0;
  HEAP32[$18>>2] = 0;
 }
 HEAP32[$worker>>2] = $$$i$i;
 HEAP32[$23>>2] = $22;
 $31 = (($worker) + 28|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($22>>>0)<($32>>>0);
 if ($33) {
  $34 = (($worker) + 24|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($$$i$i|0)>=($35|0);
  $38 = $36;
 } else {
  $38 = 1;
 }
 $37 = $38&1;
 HEAP32[$26>>2] = $37;
 $39 = (($worker) + 64|0);
 HEAP32[$39>>2] = $4;
 $40 = (($worker) + 68|0);
 HEAP32[$40>>2] = $7;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _gray_line_to($to,$worker) {
 $to = $to|0;
 $worker = $worker|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$to>>2]|0;
 $1 = $0 << 2;
 $2 = (($to) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 2;
 _gray_render_line($worker,$1,$4);
 STACKTOP = sp;return 0;
}
function _gray_conic_to($control,$to,$worker) {
 $control = $control|0;
 $to = $to|0;
 $worker = $worker|0;
 var $$$1$i = 0, $$$i = 0, $$1$i = 0, $$phi$trans$insert4$i = 0, $$pre$i = 0, $$pre5$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $arc$0$i = 0, $arc$1$i = 0, $arc$2$i = 0, $dx$1$i = 0;
 var $level$0$i = 0, $levels$0$i = 0, $levels$1$i = 0, $levels$2$i = 0, $max$0$i = 0, $max$1$i = 0, $top$0$i = 0, $top$1$i = 0, $top$2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 76|0);
 $1 = HEAP32[$to>>2]|0;
 $2 = $1 << 2;
 HEAP32[$0>>2] = $2;
 $3 = (($to) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 2;
 $6 = (($worker) + 80|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$control>>2]|0;
 $8 = $7 << 2;
 $9 = (($worker) + 84|0);
 HEAP32[$9>>2] = $8;
 $10 = (($control) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 << 2;
 $13 = (($worker) + 88|0);
 HEAP32[$13>>2] = $12;
 $14 = (($worker) + 64|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($worker) + 92|0);
 HEAP32[$16>>2] = $15;
 $17 = (($worker) + 68|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($worker) + 96|0);
 HEAP32[$19>>2] = $18;
 $20 = $7 << 3;
 $21 = (($2) - ($20))|0;
 $22 = (($21) + ($15))|0;
 $23 = ($22|0)<(0);
 $24 = (0 - ($22))|0;
 $25 = $23 ? $24 : $22;
 $26 = $11 << 3;
 $27 = (($5) - ($26))|0;
 $28 = (($27) + ($18))|0;
 $29 = ($28|0)<(0);
 $30 = (0 - ($28))|0;
 $31 = $29 ? $30 : $28;
 $32 = ($25|0)<($31|0);
 $$$i = $32 ? $31 : $25;
 $33 = ($$$i|0)<(64);
 if ($33) {
  $86 = $2;$arc$1$i = $0;$levels$1$i = 0;$top$1$i = 0;
  label = 9;
 } else {
  $34 = ($12|0)<($5|0);
  $$1$i = $34 ? $12 : $5;
  $35 = ($12|0)>($5|0);
  $max$0$i = $35 ? $12 : $5;
  $36 = ($18|0)<($$1$i|0);
  $$$1$i = $36 ? $18 : $$1$i;
  $37 = $$$1$i >> 8;
  $38 = (($worker) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)<($39|0);
  if ($40) {
   $41 = ($18|0)>($max$0$i|0);
   $max$1$i = $41 ? $18 : $max$0$i;
   $42 = $max$1$i >> 8;
   $43 = (($worker) + 16|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($42|0)<($44|0);
   if ($45) {
    $86 = $2;$arc$1$i = $0;$levels$1$i = 0;$top$1$i = 0;
    label = 9;
   } else {
    $dx$1$i = $$$i;$level$0$i = 0;
    while(1) {
     $46 = $dx$1$i >> 2;
     $47 = (($level$0$i) + 1)|0;
     $48 = ($46|0)>(64);
     if ($48) {
      $dx$1$i = $46;$level$0$i = $47;
     } else {
      break;
     }
    }
    $49 = (($worker) + 852|0);
    HEAP32[$49>>2] = $47;
    $51 = $47;$arc$0$i = $0;$levels$0$i = $49;$top$0$i = 0;
    label = 6;
   }
  } else {
   $86 = $2;$arc$1$i = $0;$levels$1$i = 0;$top$1$i = 0;
   label = 9;
  }
 }
 L7: while(1) {
  do {
   if ((label|0) == 6) {
    label = 0;
    $50 = ($51|0)>(0);
    if ($50) {
     $52 = (($levels$0$i) + ($top$0$i<<2)|0);
     $53 = (($arc$0$i) + 16|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = (($arc$0$i) + 32|0);
     HEAP32[$55>>2] = $54;
     $56 = (($arc$0$i) + 8|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = (($57) + ($54))|0;
     $59 = (($58|0) / 2)&-1;
     $60 = (($arc$0$i) + 24|0);
     HEAP32[$60>>2] = $59;
     $61 = HEAP32[$arc$0$i>>2]|0;
     $62 = (($61) + ($57))|0;
     $63 = (($62|0) / 2)&-1;
     HEAP32[$56>>2] = $63;
     $64 = (($63) + ($59))|0;
     $65 = (($64|0) / 2)&-1;
     HEAP32[$53>>2] = $65;
     $66 = (($arc$0$i) + 20|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($arc$0$i) + 36|0);
     HEAP32[$68>>2] = $67;
     $69 = (($arc$0$i) + 12|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($70) + ($67))|0;
     $72 = (($71|0) / 2)&-1;
     $73 = (($arc$0$i) + 28|0);
     HEAP32[$73>>2] = $72;
     $74 = (($arc$0$i) + 4|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($75) + ($70))|0;
     $77 = (($76|0) / 2)&-1;
     HEAP32[$69>>2] = $77;
     $78 = (($77) + ($72))|0;
     $79 = (($78|0) / 2)&-1;
     HEAP32[$66>>2] = $79;
     $80 = (($arc$0$i) + 16|0);
     $81 = (($top$0$i) + 1)|0;
     $82 = (($51) + -1)|0;
     HEAP32[$52>>2] = $82;
     $83 = (($levels$0$i) + ($81<<2)|0);
     HEAP32[$83>>2] = $82;
     $arc$2$i = $80;$levels$2$i = $levels$0$i;$top$2$i = $81;
     break;
    } else {
     $$pre$i = HEAP32[$arc$0$i>>2]|0;
     $86 = $$pre$i;$arc$1$i = $arc$0$i;$levels$1$i = $levels$0$i;$top$1$i = $top$0$i;
     label = 9;
     continue L7;
    }
   }
   else if ((label|0) == 9) {
    label = 0;
    $84 = (($arc$1$i) + 4|0);
    $85 = HEAP32[$84>>2]|0;
    _gray_render_line($worker,$86,$85);
    $87 = (($top$1$i) + -1)|0;
    $88 = (($arc$1$i) + -16|0);
    $arc$2$i = $88;$levels$2$i = $levels$1$i;$top$2$i = $87;
   }
  } while(0);
  $89 = ($top$2$i|0)>(-1);
  if (!($89)) {
   break;
  }
  $$phi$trans$insert4$i = (($levels$2$i) + ($top$2$i<<2)|0);
  $$pre5$i = HEAP32[$$phi$trans$insert4$i>>2]|0;
  $51 = $$pre5$i;$arc$0$i = $arc$2$i;$levels$0$i = $levels$2$i;$top$0$i = $top$2$i;
  label = 6;
 }
 STACKTOP = sp;return 0;
}
function _gray_cubic_to($control1,$control2,$to,$worker) {
 $control1 = $control1|0;
 $control2 = $control2|0;
 $to = $to|0;
 $worker = $worker|0;
 var $$$$$i = 0, $$$$i = 0, $$$i = 0, $$phi$trans$insert5$i = 0, $$phi$trans$insert7$i = 0, $$pre$i = 0, $$pre2$pre$i = 0, $$pre6$i = 0, $$pre8$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arc$0$i = 0, $arc$1$i = 0, $max$0$i = 0, $max$1$i = 0, $max$2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 76|0);
 $1 = HEAP32[$to>>2]|0;
 $2 = $1 << 2;
 HEAP32[$0>>2] = $2;
 $3 = (($to) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 2;
 $6 = (($worker) + 80|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$control2>>2]|0;
 $8 = $7 << 2;
 $9 = (($worker) + 84|0);
 HEAP32[$9>>2] = $8;
 $10 = (($control2) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 << 2;
 $13 = (($worker) + 88|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$control1>>2]|0;
 $15 = $14 << 2;
 $16 = (($worker) + 92|0);
 HEAP32[$16>>2] = $15;
 $17 = (($control1) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 << 2;
 $20 = (($worker) + 96|0);
 HEAP32[$20>>2] = $19;
 $21 = (($worker) + 64|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($worker) + 100|0);
 HEAP32[$23>>2] = $22;
 $24 = (($worker) + 68|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($worker) + 104|0);
 HEAP32[$26>>2] = $25;
 $27 = ($12|0)<($5|0);
 $$$i = $27 ? $12 : $5;
 $28 = ($12|0)>($5|0);
 $max$0$i = $28 ? $12 : $5;
 $29 = ($19|0)<($$$i|0);
 $$$$i = $29 ? $19 : $$$i;
 $30 = ($19|0)>($max$0$i|0);
 $max$1$i = $30 ? $19 : $max$0$i;
 $31 = ($25|0)<($$$$i|0);
 $$$$$i = $31 ? $25 : $$$$i;
 $32 = $$$$$i >> 8;
 $33 = (($worker) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($32|0)<($34|0);
 if ($35) {
  $36 = ($25|0)>($max$1$i|0);
  $max$2$i = $36 ? $25 : $max$1$i;
  $37 = $max$2$i >> 8;
  $38 = (($worker) + 16|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37|0)<($39|0);
  if ($40) {
   $153 = $2;$arc$1$i = $0;
   label = 15;
  } else {
   $$pre$i = $2;$arc$0$i = $0;
  }
 } else {
  $153 = $2;$arc$1$i = $0;
  label = 15;
 }
 while(1) {
  if ((label|0) == 15) {
   label = 0;
   $151 = (($arc$1$i) + 4|0);
   $152 = HEAP32[$151>>2]|0;
   _gray_render_line($worker,$153,$152);
   $154 = ($arc$1$i|0)==($0|0);
   if ($154) {
    break;
   }
   $155 = (($arc$1$i) + -24|0);
   $$pre2$pre$i = HEAP32[$155>>2]|0;
   $$pre$i = $$pre2$pre$i;$arc$0$i = $155;
  }
  $41 = (($arc$0$i) + 24|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) - ($$pre$i))|0;
  $44 = (($arc$0$i) + 28|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($arc$0$i) + 4|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) - ($47))|0;
  $49 = ($43|0)<(0);
  $50 = (0 - ($43))|0;
  $51 = $49 ? $50 : $43;
  $52 = ($48|0)<(0);
  $53 = (0 - ($48))|0;
  $54 = $52 ? $53 : $48;
  $55 = ($51|0)>($54|0);
  if ($55) {
   $56 = ($51*236)|0;
   $57 = ($54*97)|0;
   $58 = (($57) + ($56))|0;
   $63 = $58;
  } else {
   $59 = ($51*97)|0;
   $60 = ($54*236)|0;
   $61 = (($60) + ($59))|0;
   $63 = $61;
  }
  $62 = $63 >> 8;
  $64 = ($62|0)>(32767);
  if ($64) {
   $$phi$trans$insert5$i = (($arc$0$i) + 8|0);
   $$pre6$i = HEAP32[$$phi$trans$insert5$i>>2]|0;
   $$phi$trans$insert7$i = (($arc$0$i) + 12|0);
   $$pre8$i = HEAP32[$$phi$trans$insert7$i>>2]|0;
   $118 = $$pre6$i;$137 = $$pre8$i;
  } else {
   $65 = ($62*42)|0;
   $66 = (($arc$0$i) + 8|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($67) - ($$pre$i))|0;
   $69 = (($arc$0$i) + 12|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($70) - ($47))|0;
   $72 = Math_imul($68, $48)|0;
   $73 = Math_imul($71, $43)|0;
   $74 = (($72) - ($73))|0;
   $75 = ($74|0)<(0);
   $76 = (0 - ($74))|0;
   $77 = $75 ? $76 : $74;
   $78 = ($77|0)>($65|0);
   if ($78) {
    $118 = $67;$137 = $70;
   } else {
    $79 = (($arc$0$i) + 16|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($80) - ($$pre$i))|0;
    $82 = (($arc$0$i) + 20|0);
    $83 = HEAP32[$82>>2]|0;
    $84 = (($83) - ($47))|0;
    $85 = Math_imul($81, $48)|0;
    $86 = Math_imul($84, $43)|0;
    $87 = (($85) - ($86))|0;
    $88 = ($87|0)<(0);
    $89 = (0 - ($87))|0;
    $90 = $88 ? $89 : $87;
    $91 = ($90|0)>($65|0);
    if ($91) {
     $118 = $67;$137 = $70;
    } else {
     $92 = Math_imul($71, $48)|0;
     $93 = Math_imul($68, $43)|0;
     $94 = (($92) + ($93))|0;
     $95 = ($94|0)<(0);
     if ($95) {
      $118 = $67;$137 = $70;
     } else {
      $96 = Math_imul($84, $48)|0;
      $97 = Math_imul($81, $43)|0;
      $98 = (($96) + ($97))|0;
      $99 = ($98|0)<(0);
      if ($99) {
       $118 = $67;$137 = $70;
      } else {
       $100 = (($45) - ($70))|0;
       $101 = Math_imul($100, $48)|0;
       $102 = (($42) - ($67))|0;
       $103 = Math_imul($102, $43)|0;
       $104 = (($101) + ($103))|0;
       $105 = ($104|0)<(0);
       if ($105) {
        $118 = $67;$137 = $70;
       } else {
        $106 = (($45) - ($83))|0;
        $107 = Math_imul($106, $48)|0;
        $108 = (($42) - ($80))|0;
        $109 = Math_imul($108, $43)|0;
        $110 = (($107) + ($109))|0;
        $111 = ($110|0)<(0);
        if ($111) {
         $118 = $67;$137 = $70;
        } else {
         $153 = $$pre$i;$arc$1$i = $arc$0$i;
         label = 15;
         continue;
        }
       }
      }
     }
    }
   }
  }
  $112 = (($arc$0$i) + 24|0);
  $113 = (($arc$0$i) + 48|0);
  HEAP32[$113>>2] = $42;
  $114 = (($arc$0$i) + 8|0);
  $115 = (($arc$0$i) + 16|0);
  $116 = HEAP32[$115>>2]|0;
  $117 = (($118) + ($$pre$i))|0;
  $119 = (($117|0) / 2)&-1;
  HEAP32[$114>>2] = $119;
  $120 = (($116) + ($42))|0;
  $121 = (($120|0) / 2)&-1;
  $122 = (($arc$0$i) + 40|0);
  HEAP32[$122>>2] = $121;
  $123 = (($116) + ($118))|0;
  $124 = (($123|0) / 2)&-1;
  $125 = (($124) + ($119))|0;
  $126 = (($125|0) / 2)&-1;
  HEAP32[$115>>2] = $126;
  $127 = (($124) + ($121))|0;
  $128 = (($127|0) / 2)&-1;
  $129 = (($arc$0$i) + 32|0);
  HEAP32[$129>>2] = $128;
  $130 = (($128) + ($126))|0;
  $131 = (($130|0) / 2)&-1;
  HEAP32[$112>>2] = $131;
  $132 = (($arc$0$i) + 52|0);
  HEAP32[$132>>2] = $45;
  $133 = (($arc$0$i) + 12|0);
  $134 = (($arc$0$i) + 20|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = (($137) + ($47))|0;
  $138 = (($136|0) / 2)&-1;
  HEAP32[$133>>2] = $138;
  $139 = (($135) + ($45))|0;
  $140 = (($139|0) / 2)&-1;
  $141 = (($arc$0$i) + 44|0);
  HEAP32[$141>>2] = $140;
  $142 = (($135) + ($137))|0;
  $143 = (($142|0) / 2)&-1;
  $144 = (($143) + ($138))|0;
  $145 = (($144|0) / 2)&-1;
  HEAP32[$134>>2] = $145;
  $146 = (($143) + ($140))|0;
  $147 = (($146|0) / 2)&-1;
  $148 = (($arc$0$i) + 36|0);
  HEAP32[$148>>2] = $147;
  $149 = (($147) + ($145))|0;
  $150 = (($149|0) / 2)&-1;
  HEAP32[$44>>2] = $150;
  $$pre$i = $131;$arc$0$i = $41;
 }
 STACKTOP = sp;return 0;
}
function _gray_render_line($worker,$to_x,$to_y) {
 $worker = $worker|0;
 $to_x = $to_x|0;
 $to_y = $to_y|0;
 var $$ = 0, $$$i = 0, $$$i14 = 0, $$$i19 = 0, $$$i9 = 0, $$1 = 0, $$32 = 0, $$4 = 0, $$7 = 0, $$ex$i = 0, $$ex$i13 = 0, $$ex$i18 = 0, $$ex$i8 = 0, $$lift$0 = 0, $$lobit = 0, $$lobit$not = 0, $$pre = 0, $$pre$i = 0, $$pre$i15 = 0, $$pre$phi$i16Z2D = 0;
 var $$pre$phi$iZ2D = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $delta$0 = 0, $ey1$023 = 0, $ey1$126 = 0, $lift$0 = 0, $mod$0 = 0, $mod$125 = 0, $p$0 = 0, $rem$0 = 0, $x$024 = 0, $x$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >> 8;
 $3 = $to_y >> 8;
 $4 = (($worker) + 68|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) - ($1))|0;
 $7 = $3 << 8;
 $8 = (($to_y) - ($7))|0;
 $9 = (($worker) + 64|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($to_x) - ($10))|0;
 $12 = (($to_y) - ($5))|0;
 $13 = ($2|0)>($3|0);
 $$ = $13 ? $3 : $2;
 $14 = (($worker) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($$|0)<($15|0);
 if (!($16)) {
  HEAP32[$9>>2] = $to_x;
  HEAP32[$4>>2] = $to_y;
  HEAP32[$0>>2] = $7;
  STACKTOP = sp;return;
 }
 $$1 = $13 ? $2 : $3;
 $17 = (($worker) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($$1|0)<($18|0);
 if ($19) {
  HEAP32[$9>>2] = $to_x;
  HEAP32[$4>>2] = $to_y;
  HEAP32[$0>>2] = $7;
  STACKTOP = sp;return;
 }
 $20 = ($2|0)==($3|0);
 if ($20) {
  _gray_render_scanline($worker,$2,$10,$6,$to_x,$8);
  HEAP32[$9>>2] = $to_x;
  HEAP32[$4>>2] = $to_y;
  HEAP32[$0>>2] = $7;
  STACKTOP = sp;return;
 }
 $21 = ($10|0)==($to_x|0);
 if ($21) {
  $22 = $to_x >> 8;
  $23 = $22 << 8;
  $24 = (($to_x) - ($23))|0;
  $25 = $24 << 1;
  $26 = $12 >> 31;
  $27 = (($26) + 256)|0;
  $28 = $27 & -256;
  $29 = $26 | 1;
  $30 = (($28) - ($6))|0;
  $31 = Math_imul($25, $30)|0;
  $32 = (($worker) + 32|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($33) + ($31))|0;
  HEAP32[$32>>2] = $34;
  $35 = (($worker) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + ($30))|0;
  HEAP32[$35>>2] = $37;
  $38 = (($29) + ($2))|0;
  $39 = (($38) - ($18))|0;
  $40 = (($worker) + 12|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)<($22|0);
  $$ex$i = $42 ? $41 : $22;
  $43 = (($worker) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($$ex$i) - ($44))|0;
  $46 = ($45|0)>(-1);
  $$$i = $46 ? $45 : -1;
  $47 = HEAP32[$worker>>2]|0;
  $48 = ($$$i|0)==($47|0);
  if ($48) {
   $49 = (($worker) + 4|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($39|0)==($50|0);
   if ($51) {
    $$pre$phi$iZ2D = $49;
   } else {
    label = 8;
   }
  } else {
   label = 8;
  }
  if ((label|0) == 8) {
   $52 = (($worker) + 40|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(0);
   if ($54) {
    _gray_record_cell($worker);
   }
   HEAP32[$32>>2] = 0;
   HEAP32[$35>>2] = 0;
   $$pre$i = (($worker) + 4|0);
   $$pre$phi$iZ2D = $$pre$i;
  }
  HEAP32[$worker>>2] = $$$i;
  HEAP32[$$pre$phi$iZ2D>>2] = $39;
  $55 = (($worker) + 28|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($39>>>0)<($56>>>0);
  if ($57) {
   $58 = (($worker) + 24|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($$$i|0)>=($59|0);
   $62 = $60;
  } else {
   $62 = 1;
  }
  $61 = $62&1;
  $63 = (($worker) + 40|0);
  HEAP32[$63>>2] = $61;
  $64 = $28 << 1;
  $65 = (($64) + -256)|0;
  $66 = Math_imul($65, $25)|0;
  $67 = ($38|0)==($3|0);
  if (!($67)) {
   $68 = (($worker) + 4|0);
   $69 = (($worker) + 24|0);
   $185 = $56;$83 = $$$i;$87 = $61;$ey1$023 = $38;
   while(1) {
    $70 = HEAP32[$32>>2]|0;
    $71 = (($70) + ($66))|0;
    HEAP32[$32>>2] = $71;
    $72 = HEAP32[$35>>2]|0;
    $73 = (($72) + ($65))|0;
    HEAP32[$35>>2] = $73;
    $74 = (($ey1$023) + ($29))|0;
    $75 = HEAP32[$17>>2]|0;
    $76 = (($74) - ($75))|0;
    $77 = HEAP32[$40>>2]|0;
    $78 = ($77|0)<($22|0);
    $$ex$i8 = $78 ? $77 : $22;
    $79 = HEAP32[$43>>2]|0;
    $80 = (($$ex$i8) - ($79))|0;
    $81 = ($80|0)>(-1);
    $$$i9 = $81 ? $80 : -1;
    $82 = ($$$i9|0)==($83|0);
    if ($82) {
     $84 = HEAP32[$68>>2]|0;
     $85 = ($76|0)==($84|0);
     if ($85) {
      $89 = $185;
     } else {
      label = 17;
     }
    } else {
     label = 17;
    }
    if ((label|0) == 17) {
     label = 0;
     $86 = ($87|0)==(0);
     if ($86) {
      _gray_record_cell($worker);
      $$pre$pre = HEAP32[$55>>2]|0;
      $$pre = $$pre$pre;
     } else {
      $$pre = $185;
     }
     HEAP32[$32>>2] = 0;
     HEAP32[$35>>2] = 0;
     $89 = $$pre;
    }
    HEAP32[$worker>>2] = $$$i9;
    HEAP32[$68>>2] = $76;
    $88 = ($76>>>0)<($89>>>0);
    if ($88) {
     $90 = HEAP32[$69>>2]|0;
     $91 = ($$$i9|0)>=($90|0);
     $93 = $91;
    } else {
     $93 = 1;
    }
    $92 = $93&1;
    HEAP32[$63>>2] = $92;
    $94 = ($74|0)==($3|0);
    if ($94) {
     break;
    } else {
     $185 = $89;$83 = $$$i9;$87 = $92;$ey1$023 = $74;
    }
   }
  }
  $95 = (($8) + -256)|0;
  $96 = (($95) + ($28))|0;
  $97 = Math_imul($25, $96)|0;
  $98 = HEAP32[$32>>2]|0;
  $99 = (($98) + ($97))|0;
  HEAP32[$32>>2] = $99;
  $100 = HEAP32[$35>>2]|0;
  $101 = (($100) + ($96))|0;
  HEAP32[$35>>2] = $101;
  HEAP32[$9>>2] = $to_x;
  HEAP32[$4>>2] = $to_y;
  HEAP32[$0>>2] = $7;
  STACKTOP = sp;return;
 }
 $102 = (256 - ($6))|0;
 $103 = ($12|0)<(0);
 $104 = (0 - ($12))|0;
 $$4 = $103 ? $6 : $102;
 $105 = $12 >> 31;
 $106 = (($105) + 256)|0;
 $107 = $106 & -256;
 $108 = $105 | 1;
 $$7 = $103 ? $104 : $12;
 $p$0 = Math_imul($$4, $11)|0;
 $109 = (($p$0|0) / ($$7|0))&-1;
 $110 = (($p$0|0) % ($$7|0))&-1;
 $111 = ($110|0)<(0);
 if ($111) {
  $112 = (($109) + -1)|0;
  $113 = (($110) + ($$7))|0;
  $delta$0 = $112;$mod$0 = $113;
 } else {
  $delta$0 = $109;$mod$0 = $110;
 }
 $114 = (($10) + ($delta$0))|0;
 _gray_render_scanline($worker,$2,$10,$6,$114,$107);
 $115 = (($108) + ($2))|0;
 $116 = $114 >> 8;
 $117 = HEAP32[$17>>2]|0;
 $118 = (($115) - ($117))|0;
 $119 = (($worker) + 12|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ($120|0)<($116|0);
 $$ex$i13 = $121 ? $120 : $116;
 $122 = (($worker) + 8|0);
 $123 = HEAP32[$122>>2]|0;
 $124 = (($$ex$i13) - ($123))|0;
 $125 = ($124|0)>(-1);
 $$$i14 = $125 ? $124 : -1;
 $126 = HEAP32[$worker>>2]|0;
 $127 = ($$$i14|0)==($126|0);
 if ($127) {
  $128 = (($worker) + 4|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = ($118|0)==($129|0);
  if ($130) {
   $$pre$phi$i16Z2D = $128;
  } else {
   label = 28;
  }
 } else {
  label = 28;
 }
 if ((label|0) == 28) {
  $131 = (($worker) + 40|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = ($132|0)==(0);
  if ($133) {
   _gray_record_cell($worker);
  }
  $134 = (($worker) + 32|0);
  HEAP32[$134>>2] = 0;
  $135 = (($worker) + 36|0);
  HEAP32[$135>>2] = 0;
  $$pre$i15 = (($worker) + 4|0);
  $$pre$phi$i16Z2D = $$pre$i15;
 }
 HEAP32[$worker>>2] = $$$i14;
 HEAP32[$$pre$phi$i16Z2D>>2] = $118;
 $136 = (($worker) + 28|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($118>>>0)<($137>>>0);
 if ($138) {
  $139 = (($worker) + 24|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = ($$$i14|0)>=($140|0);
  $143 = $141;
 } else {
  $143 = 1;
 }
 $142 = $143&1;
 $144 = (($worker) + 40|0);
 HEAP32[$144>>2] = $142;
 $145 = ($115|0)==($3|0);
 if ($145) {
  $x$1 = $114;
 } else {
  $146 = $11 << 8;
  $147 = (($146|0) / ($$7|0))&-1;
  $148 = (($146|0) % ($$7|0))&-1;
  $149 = ($148|0)<(0);
  if ($149) {
   $150 = (($147) + -1)|0;
   $151 = (($148) + ($$7))|0;
   $lift$0 = $150;$rem$0 = $151;
  } else {
   $lift$0 = $147;$rem$0 = $148;
  }
  $152 = (($mod$0) - ($$7))|0;
  $153 = (256 - ($107))|0;
  $154 = (($worker) + 4|0);
  $155 = (($worker) + 24|0);
  $156 = (($worker) + 32|0);
  $157 = (($worker) + 36|0);
  $ey1$126 = $115;$mod$125 = $152;$x$024 = $114;
  while(1) {
   $158 = (($mod$125) + ($rem$0))|0;
   $159 = ($158|0)>(-1);
   $$lobit = $158 >>> 31;
   $$lobit$not = $$lobit ^ 1;
   $$lift$0 = (($lift$0) + ($$lobit$not))|0;
   $160 = $159 ? $$7 : 0;
   $$32 = (($158) - ($160))|0;
   $161 = (($$lift$0) + ($x$024))|0;
   _gray_render_scanline($worker,$ey1$126,$x$024,$153,$161,$107);
   $162 = (($ey1$126) + ($108))|0;
   $163 = $161 >> 8;
   $164 = HEAP32[$17>>2]|0;
   $165 = (($162) - ($164))|0;
   $166 = HEAP32[$119>>2]|0;
   $167 = ($166|0)<($163|0);
   $$ex$i18 = $167 ? $166 : $163;
   $168 = HEAP32[$122>>2]|0;
   $169 = (($$ex$i18) - ($168))|0;
   $170 = ($169|0)>(-1);
   $$$i19 = $170 ? $169 : -1;
   $171 = HEAP32[$worker>>2]|0;
   $172 = ($$$i19|0)==($171|0);
   if ($172) {
    $173 = HEAP32[$154>>2]|0;
    $174 = ($165|0)==($173|0);
    if (!($174)) {
     label = 39;
    }
   } else {
    label = 39;
   }
   if ((label|0) == 39) {
    label = 0;
    $175 = HEAP32[$144>>2]|0;
    $176 = ($175|0)==(0);
    if ($176) {
     _gray_record_cell($worker);
    }
    HEAP32[$156>>2] = 0;
    HEAP32[$157>>2] = 0;
   }
   HEAP32[$worker>>2] = $$$i19;
   HEAP32[$154>>2] = $165;
   $177 = HEAP32[$136>>2]|0;
   $178 = ($165>>>0)<($177>>>0);
   if ($178) {
    $179 = HEAP32[$155>>2]|0;
    $180 = ($$$i19|0)>=($179|0);
    $182 = $180;
   } else {
    $182 = 1;
   }
   $181 = $182&1;
   HEAP32[$144>>2] = $181;
   $183 = ($162|0)==($3|0);
   if ($183) {
    $x$1 = $161;
    break;
   } else {
    $ey1$126 = $162;$mod$125 = $$32;$x$024 = $161;
   }
  }
 }
 $184 = (256 - ($107))|0;
 _gray_render_scanline($worker,$3,$x$1,$184,$to_x,$8);
 HEAP32[$9>>2] = $to_x;
 HEAP32[$4>>2] = $to_y;
 HEAP32[$0>>2] = $7;
 STACKTOP = sp;return;
}
function _gray_render_scanline($worker,$ey,$x1,$y1,$x2,$y2) {
 $worker = $worker|0;
 $ey = $ey|0;
 $x1 = $x1|0;
 $y1 = $y1|0;
 $x2 = $x2|0;
 $y2 = $y2|0;
 var $$ = 0, $$$i = 0, $$$i11 = 0, $$$i6 = 0, $$017 = 0, $$1 = 0, $$20 = 0, $$3 = 0, $$ex$i = 0, $$ex$i10 = 0, $$ex$i5 = 0, $$lift$0 = 0, $$lobit = 0, $$lobit$not = 0, $$pre = 0, $$pre$i = 0, $$pre$i7 = 0, $$pre$phi$i8Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$pre = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $delta$0 = 0, $ex1$016 = 0, $lift$0 = 0, $mod$0 = 0, $mod$118 = 0, $p$0 = 0, $rem$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($x2) - ($x1))|0;
 $1 = $x1 >> 8;
 $2 = $x2 >> 8;
 $3 = $1 << 8;
 $4 = (($x1) - ($3))|0;
 $5 = $2 << 8;
 $6 = (($x2) - ($5))|0;
 $7 = ($y1|0)==($y2|0);
 if ($7) {
  $8 = (($worker) + 16|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($ey) - ($9))|0;
  $11 = (($worker) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)<($2|0);
  $$ex$i = $13 ? $12 : $2;
  $14 = (($worker) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($$ex$i) - ($15))|0;
  $17 = ($16|0)>(-1);
  $$$i = $17 ? $16 : -1;
  $18 = HEAP32[$worker>>2]|0;
  $19 = ($$$i|0)==($18|0);
  if ($19) {
   $20 = (($worker) + 4|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($10|0)==($21|0);
   if ($22) {
    $$pre$phi$iZ2D = $20;
   } else {
    label = 4;
   }
  } else {
   label = 4;
  }
  if ((label|0) == 4) {
   $23 = (($worker) + 40|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0);
   if ($25) {
    _gray_record_cell($worker);
   }
   $26 = (($worker) + 32|0);
   HEAP32[$26>>2] = 0;
   $27 = (($worker) + 36|0);
   HEAP32[$27>>2] = 0;
   $$pre$i = (($worker) + 4|0);
   $$pre$phi$iZ2D = $$pre$i;
  }
  HEAP32[$worker>>2] = $$$i;
  HEAP32[$$pre$phi$iZ2D>>2] = $10;
  $28 = (($worker) + 28|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($10>>>0)<($29>>>0);
  if ($30) {
   $31 = (($worker) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($$$i|0)>=($32|0);
   $35 = $33;
  } else {
   $35 = 1;
  }
  $34 = $35&1;
  $36 = (($worker) + 40|0);
  HEAP32[$36>>2] = $34;
  STACKTOP = sp;return;
 }
 $37 = ($1|0)==($2|0);
 if ($37) {
  $38 = (($y2) - ($y1))|0;
  $39 = (($6) + ($4))|0;
  $40 = Math_imul($39, $38)|0;
  $41 = (($worker) + 32|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = (($42) + ($40))|0;
  HEAP32[$41>>2] = $43;
  $44 = (($worker) + 36|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + ($38))|0;
  HEAP32[$44>>2] = $46;
  STACKTOP = sp;return;
 }
 $47 = (256 - ($4))|0;
 $48 = (($y2) - ($y1))|0;
 $49 = ($0|0)<(0);
 $50 = (0 - ($0))|0;
 $$ = $49 ? $4 : $47;
 $51 = $0 >> 31;
 $52 = (($51) + 256)|0;
 $53 = $52 & -256;
 $$3 = $49 ? $50 : $0;
 $54 = $51 | 1;
 $p$0 = Math_imul($$, $48)|0;
 $55 = (($p$0|0) / ($$3|0))&-1;
 $56 = (($p$0|0) % ($$3|0))&-1;
 $57 = ($56|0)<(0);
 if ($57) {
  $58 = (($55) + -1)|0;
  $59 = (($56) + ($$3))|0;
  $delta$0 = $58;$mod$0 = $59;
 } else {
  $delta$0 = $55;$mod$0 = $56;
 }
 $60 = (($53) + ($4))|0;
 $61 = Math_imul($delta$0, $60)|0;
 $62 = (($worker) + 32|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + ($61))|0;
 HEAP32[$62>>2] = $64;
 $65 = (($worker) + 36|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($delta$0))|0;
 HEAP32[$65>>2] = $67;
 $68 = (($54) + ($1))|0;
 $69 = (($worker) + 16|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($ey) - ($70))|0;
 $72 = (($worker) + 12|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ($73|0)<($68|0);
 $$ex$i5 = $74 ? $73 : $68;
 $75 = (($worker) + 8|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($$ex$i5) - ($76))|0;
 $78 = ($77|0)>(-1);
 $$$i6 = $78 ? $77 : -1;
 $79 = HEAP32[$worker>>2]|0;
 $80 = ($$$i6|0)==($79|0);
 if ($80) {
  $81 = (($worker) + 4|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = ($71|0)==($82|0);
  if ($83) {
   $$pre$phi$i8Z2D = $81;
  } else {
   label = 16;
  }
 } else {
  label = 16;
 }
 if ((label|0) == 16) {
  $84 = (($worker) + 40|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($85|0)==(0);
  if ($86) {
   _gray_record_cell($worker);
  }
  HEAP32[$62>>2] = 0;
  HEAP32[$65>>2] = 0;
  $$pre$i7 = (($worker) + 4|0);
  $$pre$phi$i8Z2D = $$pre$i7;
 }
 HEAP32[$worker>>2] = $$$i6;
 HEAP32[$$pre$phi$i8Z2D>>2] = $71;
 $87 = (($worker) + 28|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ($71>>>0)<($88>>>0);
 if ($89) {
  $90 = (($worker) + 24|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($$$i6|0)>=($91|0);
  $94 = $92;
 } else {
  $94 = 1;
 }
 $93 = $94&1;
 $95 = (($worker) + 40|0);
 HEAP32[$95>>2] = $93;
 $96 = (($delta$0) + ($y1))|0;
 $97 = ($68|0)==($2|0);
 if ($97) {
  $$1 = $96;
 } else {
  $98 = (($delta$0) + ($y2))|0;
  $99 = (($98) - ($96))|0;
  $100 = $99 << 8;
  $101 = (($100|0) / ($$3|0))&-1;
  $102 = (($100|0) % ($$3|0))&-1;
  $103 = ($102|0)<(0);
  if ($103) {
   $104 = (($101) + -1)|0;
   $105 = (($102) + ($$3))|0;
   $lift$0 = $104;$rem$0 = $105;
  } else {
   $lift$0 = $101;$rem$0 = $102;
  }
  $106 = (($mod$0) - ($$3))|0;
  $107 = (($worker) + 4|0);
  $108 = (($worker) + 24|0);
  $$017 = $96;$127 = $$$i6;$131 = $93;$147 = $88;$ex1$016 = $68;$mod$118 = $106;
  while(1) {
   $109 = (($mod$118) + ($rem$0))|0;
   $110 = ($109|0)>(-1);
   $$lobit = $109 >>> 31;
   $$lobit$not = $$lobit ^ 1;
   $$lift$0 = (($lift$0) + ($$lobit$not))|0;
   $111 = $110 ? $$3 : 0;
   $$20 = (($109) - ($111))|0;
   $112 = $$lift$0 << 8;
   $113 = HEAP32[$62>>2]|0;
   $114 = (($113) + ($112))|0;
   HEAP32[$62>>2] = $114;
   $115 = HEAP32[$65>>2]|0;
   $116 = (($115) + ($$lift$0))|0;
   HEAP32[$65>>2] = $116;
   $117 = (($$lift$0) + ($$017))|0;
   $118 = (($ex1$016) + ($54))|0;
   $119 = HEAP32[$69>>2]|0;
   $120 = (($ey) - ($119))|0;
   $121 = HEAP32[$72>>2]|0;
   $122 = ($121|0)<($118|0);
   $$ex$i10 = $122 ? $121 : $118;
   $123 = HEAP32[$75>>2]|0;
   $124 = (($$ex$i10) - ($123))|0;
   $125 = ($124|0)>(-1);
   $$$i11 = $125 ? $124 : -1;
   $126 = ($$$i11|0)==($127|0);
   if ($126) {
    $128 = HEAP32[$107>>2]|0;
    $129 = ($120|0)==($128|0);
    if ($129) {
     $133 = $147;
    } else {
     label = 27;
    }
   } else {
    label = 27;
   }
   if ((label|0) == 27) {
    label = 0;
    $130 = ($131|0)==(0);
    if ($130) {
     _gray_record_cell($worker);
     $$pre$pre = HEAP32[$87>>2]|0;
     $$pre = $$pre$pre;
    } else {
     $$pre = $147;
    }
    HEAP32[$62>>2] = 0;
    HEAP32[$65>>2] = 0;
    $133 = $$pre;
   }
   HEAP32[$worker>>2] = $$$i11;
   HEAP32[$107>>2] = $120;
   $132 = ($120>>>0)<($133>>>0);
   if ($132) {
    $134 = HEAP32[$108>>2]|0;
    $135 = ($$$i11|0)>=($134|0);
    $137 = $135;
   } else {
    $137 = 1;
   }
   $136 = $137&1;
   HEAP32[$95>>2] = $136;
   $138 = ($118|0)==($2|0);
   if ($138) {
    $$1 = $117;
    break;
   } else {
    $$017 = $117;$127 = $$$i11;$131 = $136;$147 = $133;$ex1$016 = $118;$mod$118 = $$20;
   }
  }
 }
 $139 = (($y2) - ($$1))|0;
 $140 = (($6) + 256)|0;
 $141 = (($140) - ($53))|0;
 $142 = Math_imul($139, $141)|0;
 $143 = HEAP32[$62>>2]|0;
 $144 = (($142) + ($143))|0;
 HEAP32[$62>>2] = $144;
 $145 = HEAP32[$65>>2]|0;
 $146 = (($145) + ($139))|0;
 HEAP32[$65>>2] = $146;
 STACKTOP = sp;return;
}
function _FT_Destroy_Class_ft_smooth_renderer_class($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 _ft_smooth_renderer_class_pic_free($library);
 $1 = ($clazz|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$clazz);
 STACKTOP = sp;return;
}
function _FT_Create_Class_ft_smooth_renderer_class($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,60,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_ft_smooth_renderer_class_pic_init($library)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if ($5) {
  HEAP32[$1>>2] = 2;
  $7 = (($1) + 4|0);
  HEAP32[$7>>2] = 72;
  $8 = (($1) + 8|0);
  HEAP32[$8>>2] = 872384;
  $9 = (($1) + 12|0);
  HEAP32[$9>>2] = 65536;
  $10 = (($1) + 16|0);
  HEAP32[$10>>2] = 131072;
  $11 = (($1) + 20|0);
  HEAP32[$11>>2] = 0;
  $12 = (($1) + 24|0);
  HEAP32[$12>>2] = 3433;
  $13 = (($1) + 28|0);
  HEAP32[$13>>2] = 0;
  $14 = (($1) + 32|0);
  HEAP32[$14>>2] = 0;
  $15 = (($1) + 36|0);
  HEAP32[$15>>2] = 1869968492;
  $16 = (($1) + 40|0);
  HEAP32[$16>>2] = 289;
  $17 = (($1) + 44|0);
  HEAP32[$17>>2] = 290;
  $18 = (($1) + 48|0);
  HEAP32[$18>>2] = 2063;
  $19 = (($1) + 52|0);
  HEAP32[$19>>2] = 1612;
  $20 = (($library) + 224|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 4|0);
  $23 = (($1) + 56|0);
  HEAP32[$23>>2] = $22;
  HEAP32[$output_class>>2] = $1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  _ft_mem_free($0,$1);
  $6 = HEAP32[$error>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _ft_smooth_init($render) {
 $render = $render|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($render) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($render) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($render) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($1) + 172|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($1) + 176|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viii[$7 & 4095]($9,$11,$13);
 STACKTOP = sp;return 0;
}
function _ft_smooth_render($render,$slot,$mode,$origin) {
 $render = $render|0;
 $slot = $slot|0;
 $mode = $mode|0;
 $origin = $origin|0;
 var $$mode = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mode|0)==(1);
 $$mode = $0 ? 0 : $mode;
 $1 = (_ft_smooth_render_generic($render,$slot,$$mode,$origin,0)|0);
 STACKTOP = sp;return ($1|0);
}
function _ft_smooth_transform($render,$slot,$matrix,$delta) {
 $render = $render|0;
 $slot = $slot|0;
 $matrix = $matrix|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($slot) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($render) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  $error$0 = 6;
  STACKTOP = sp;return ($error$0|0);
 }
 $5 = ($matrix|0)==(0|0);
 if (!($5)) {
  $6 = (($slot) + 108|0);
  _FT_Outline_Transform($6,$matrix);
 }
 $7 = ($delta|0)==(0|0);
 if ($7) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 $8 = (($slot) + 108|0);
 $9 = HEAP32[$delta>>2]|0;
 $10 = (($delta) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 _FT_Outline_Translate($8,$9,$11);
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _ft_smooth_get_cbox($render,$slot,$cbox) {
 $render = $render|0;
 $slot = $slot|0;
 $cbox = $cbox|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$cbox+0>>2]=0|0;HEAP32[$cbox+4>>2]=0|0;HEAP32[$cbox+8>>2]=0|0;HEAP32[$cbox+12>>2]=0|0;
 $0 = (($slot) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($render) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($slot) + 108|0);
 _FT_Outline_Get_CBox($5,$cbox);
 STACKTOP = sp;return;
}
function _ft_smooth_set_mode($render,$mode_tag,$data) {
 $render = $render|0;
 $mode_tag = $mode_tag|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($render) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($render) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($7,$mode_tag,$data)|0);
 STACKTOP = sp;return ($8|0);
}
function _ft_smooth_render_generic($render,$slot,$mode,$origin,$required_mode) {
 $render = $render|0;
 $slot = $slot|0;
 $mode = $mode|0;
 $origin = $origin|0;
 $required_mode = $required_mode|0;
 var $$0 = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $cbox = 0, $end$08 = 0, $error = 0, $height$0 = 0, $hh$012 = 0, $hh1$06 = 0, $line$011 = 0, $or$cond = 0, $or$cond17 = 0, $or$cond19 = 0, $or$cond20 = 0, $params = 0, $pitch$0 = 0, $read$04 = 0, $width$0 = 0, $write$05 = 0, $xx$07 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $error = sp + 64|0;
 $cbox = sp;
 $params = sp + 16|0;
 $0 = ($mode|0)==(3);
 $1 = ($mode|0)==(4);
 $2 = (($slot) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($render) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  HEAP32[$error>>2] = 6;
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ($mode|0)==($required_mode|0);
 if (!($7)) {
  $$0 = 19;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($slot) + 108|0);
 $9 = ($origin|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$origin>>2]|0;
  $11 = (($origin) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  _FT_Outline_Translate($8,$10,$12);
 }
 _FT_Outline_Get_CBox($8,$cbox);
 $13 = HEAP32[$cbox>>2]|0;
 $14 = $13 & -64;
 HEAP32[$cbox>>2] = $14;
 $15 = (($cbox) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 & -64;
 HEAP32[$15>>2] = $17;
 $18 = (($cbox) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 63)|0;
 $21 = $20 & -64;
 HEAP32[$18>>2] = $21;
 $22 = (($cbox) + 12|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 63)|0;
 $25 = $24 & -64;
 HEAP32[$22>>2] = $25;
 $26 = ($14|0)<(0);
 $27 = (($14) + 2147483647)|0;
 $28 = ($21|0)>($27|0);
 $or$cond17 = $26 & $28;
 if ($or$cond17) {
  $$0 = 98;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = (($21) - ($14))|0;
 $30 = $29 >> 6;
 $31 = ($17|0)<(0);
 $32 = (($17) + 2147483647)|0;
 $33 = ($25|0)>($32|0);
 $or$cond19 = $31 & $33;
 if ($or$cond19) {
  $$0 = 98;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = (($25) - ($17))|0;
 $35 = $34 >> 6;
 $36 = (($slot) + 76|0);
 $37 = (($render) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($slot) + 156|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 & 1;
 $44 = ($43|0)==(0);
 if (!($44)) {
  $45 = (($slot) + 88|0);
  $46 = HEAP32[$45>>2]|0;
  _ft_mem_free($38,$46);
  HEAP32[$45>>2] = 0;
  $47 = HEAP32[$39>>2]|0;
  $48 = (($47) + 4|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = $49 & -2;
  HEAP32[$48>>2] = $50;
 }
 if ($0) {
  $51 = ($30*3)|0;
  $52 = (($51) + 3)|0;
  $53 = $52 & -4;
  $pitch$0 = $53;$width$0 = $51;
 } else {
  $pitch$0 = $30;$width$0 = $30;
 }
 if ($1) {
  $54 = ($35*3)|0;
  $height$0 = $54;
 } else {
  $height$0 = $35;
 }
 $55 = HEAP32[$cbox>>2]|0;
 $56 = HEAP32[$15>>2]|0;
 $57 = $55 >> 6;
 $58 = HEAP32[$22>>2]|0;
 $59 = $58 >> 6;
 $60 = ($width$0>>>0)>(32767);
 $61 = ($height$0>>>0)>(32767);
 $or$cond = $60 | $61;
 if ($or$cond) {
  $$0 = 98;
  STACKTOP = sp;return ($$0|0);
 }
 $62 = (($slot) + 94|0);
 HEAP8[$62>>0] = 2;
 $63 = (($slot) + 92|0);
 HEAP16[$63>>1] = 256;
 $64 = (($slot) + 80|0);
 HEAP32[$64>>2] = $width$0;
 HEAP32[$36>>2] = $height$0;
 $65 = (($slot) + 84|0);
 HEAP32[$65>>2] = $pitch$0;
 $66 = (0 - ($55))|0;
 $67 = (0 - ($56))|0;
 _FT_Outline_Translate($8,$66,$67);
 $68 = Math_imul($height$0, $pitch$0)|0;
 $69 = (_ft_mem_alloc($38,$68,$error)|0);
 $70 = (($slot) + 88|0);
 HEAP32[$70>>2] = $69;
 $71 = HEAP32[$error>>2]|0;
 $72 = ($71|0)==(0);
 if ($72) {
  $73 = HEAP32[$39>>2]|0;
  $74 = (($73) + 4|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = $75 | 1;
  HEAP32[$74>>2] = $76;
  HEAP32[$params>>2] = $36;
  $77 = (($params) + 4|0);
  HEAP32[$77>>2] = $8;
  $78 = (($params) + 8|0);
  HEAP32[$78>>2] = 1;
  $79 = (($render) + 64|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (($render) + 60|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (FUNCTION_TABLE_iii[$80 & 4095]($82,$params)|0);
  HEAP32[$error>>2] = $83;
  if ($0) {
   $84 = HEAP32[$70>>2]|0;
   $85 = ($35|0)==(0);
   $86 = ($30|0)==(0);
   $or$cond20 = $85 | $86;
   if (!($or$cond20)) {
    $hh$012 = $35;$line$011 = $84;
    while(1) {
     $87 = (($line$011) + ($width$0)|0);
     $end$08 = $87;$xx$07 = $30;
     while(1) {
      $88 = (($xx$07) + -1)|0;
      $89 = (($line$011) + ($88)|0);
      $90 = HEAP8[$89>>0]|0;
      $91 = (($end$08) + -3|0);
      HEAP8[$91>>0] = $90;
      $92 = (($end$08) + -2|0);
      HEAP8[$92>>0] = $90;
      $93 = (($end$08) + -1|0);
      HEAP8[$93>>0] = $90;
      $94 = ($88|0)==(0);
      if ($94) {
       break;
      } else {
       $end$08 = $91;$xx$07 = $88;
      }
     }
     $95 = (($hh$012) + -1)|0;
     $96 = (($line$011) + ($pitch$0)|0);
     $97 = ($95|0)==(0);
     if ($97) {
      break;
     } else {
      $hh$012 = $95;$line$011 = $96;
     }
    }
   }
  }
  if ($1) {
   $98 = HEAP32[$70>>2]|0;
   $99 = ($35|0)==(0);
   if (!($99)) {
    $100 = (($height$0) - ($35))|0;
    $101 = Math_imul($100, $pitch$0)|0;
    $102 = (($98) + ($101)|0);
    $$sum = $pitch$0 << 1;
    $$sum1 = (($$sum) + ($pitch$0))|0;
    $hh1$06 = $35;$read$04 = $102;$write$05 = $98;
    while(1) {
     _memcpy(($write$05|0),($read$04|0),($pitch$0|0))|0;
     $103 = (($write$05) + ($pitch$0)|0);
     _memcpy(($103|0),($read$04|0),($pitch$0|0))|0;
     $104 = (($write$05) + ($$sum)|0);
     _memcpy(($104|0),($read$04|0),($pitch$0|0))|0;
     $105 = (($write$05) + ($$sum1)|0);
     $106 = (($read$04) + ($pitch$0)|0);
     $107 = (($hh1$06) + -1)|0;
     $108 = ($107|0)==(0);
     if ($108) {
      break;
     } else {
      $hh1$06 = $107;$read$04 = $106;$write$05 = $105;
     }
    }
   }
  }
  _FT_Outline_Translate($8,$55,$56);
  $109 = HEAP32[$error>>2]|0;
  $110 = ($109|0)==(0);
  if ($110) {
   HEAP32[$2>>2] = 1651078259;
   $111 = (($slot) + 100|0);
   HEAP32[$111>>2] = $57;
   $112 = (($slot) + 104|0);
   HEAP32[$112>>2] = $59;
   $118 = 0;
  } else {
   $118 = $109;
  }
 } else {
  $118 = $71;
 }
 if ($9) {
  $$0 = $118;
  STACKTOP = sp;return ($$0|0);
 }
 $113 = HEAP32[$origin>>2]|0;
 $114 = (0 - ($113))|0;
 $115 = (($origin) + 4|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = (0 - ($116))|0;
 _FT_Outline_Translate($8,$114,$117);
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Init_Class_tt_service_gx_multi_masters($clazz) {
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 0;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 1613;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 2700;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 1614;
 STACKTOP = sp;return;
}
function _FT_Init_Class_tt_service_truetype_glyf($clazz) {
 $clazz = $clazz|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 1615;
 STACKTOP = sp;return;
}
function _FT_Destroy_Class_tt_services($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($clazz|0)==(0|0);
 if (!($0)) {
  $1 = HEAP32[$library>>2]|0;
  _ft_mem_free($1,$clazz);
 }
 STACKTOP = sp;return;
}
function _FT_Create_Class_tt_services($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,40,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$1>>2] = 872392;
 $4 = (($1) + 4|0);
 HEAP32[$4>>2] = 872416;
 $5 = (($1) + 8|0);
 HEAP32[$5>>2] = 872432;
 $6 = (($library) + 228|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = (($1) + 12|0);
 HEAP32[$9>>2] = $8;
 $10 = (($1) + 16|0);
 HEAP32[$10>>2] = 872448;
 $11 = (($1) + 20|0);
 HEAP32[$11>>2] = 872464;
 $12 = (($1) + 24|0);
 HEAP32[$12>>2] = 872472;
 $13 = HEAP32[$6>>2]|0;
 $14 = (($13) + 24|0);
 $15 = (($1) + 28|0);
 HEAP32[$15>>2] = $14;
 $16 = (($1) + 32|0);
 HEAP32[$16>>2] = 0;
 $17 = (($1) + 36|0);
 HEAP32[$17>>2] = 0;
 HEAP32[$output_class>>2] = $1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Destroy_Class_tt_driver_class($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 _tt_driver_class_pic_free($library);
 $1 = ($clazz|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$clazz);
 STACKTOP = sp;return;
}
function _FT_Create_Class_tt_driver_class($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,104,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_tt_driver_class_pic_init($library)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if ($5) {
  HEAP32[$1>>2] = 1281;
  $7 = (($1) + 4|0);
  HEAP32[$7>>2] = 84;
  $8 = (($1) + 8|0);
  HEAP32[$8>>2] = 872480;
  $9 = (($1) + 12|0);
  HEAP32[$9>>2] = 65536;
  $10 = (($1) + 16|0);
  HEAP32[$10>>2] = 131072;
  $11 = (($1) + 20|0);
  HEAP32[$11>>2] = 0;
  $12 = (($1) + 24|0);
  HEAP32[$12>>2] = 3434;
  $13 = (($1) + 28|0);
  HEAP32[$13>>2] = 3746;
  $14 = (($1) + 32|0);
  HEAP32[$14>>2] = 2701;
  $15 = (($1) + 36|0);
  HEAP32[$15>>2] = 800;
  $16 = (($1) + 40|0);
  HEAP32[$16>>2] = 304;
  $17 = (($1) + 44|0);
  HEAP32[$17>>2] = 160;
  $18 = (($1) + 48|0);
  HEAP32[$18>>2] = 228;
  $19 = (($1) + 52|0);
  HEAP32[$19>>2] = 3747;
  $20 = (($1) + 56|0);
  HEAP32[$20>>2] = 3435;
  $21 = (($1) + 60|0);
  HEAP32[$21>>2] = 3748;
  $22 = (($1) + 64|0);
  HEAP32[$22>>2] = 3436;
  $23 = (($1) + 68|0);
  HEAP32[$23>>2] = 0;
  $24 = (($1) + 72|0);
  HEAP32[$24>>2] = 221;
  $25 = (($1) + 76|0);
  HEAP32[$25>>2] = 1598;
  $26 = (($1) + 80|0);
  HEAP32[$26>>2] = 291;
  $27 = (($1) + 84|0);
  HEAP32[$27>>2] = 292;
  $28 = (($1) + 88|0);
  HEAP32[$28>>2] = 0;
  $29 = (($1) + 92|0);
  HEAP32[$29>>2] = 229;
  $30 = (($1) + 96|0);
  HEAP32[$30>>2] = 2702;
  $31 = (($1) + 100|0);
  HEAP32[$31>>2] = 2703;
  HEAP32[$output_class>>2] = $1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  _ft_mem_free($0,$1);
  $6 = HEAP32[$error>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _tt_get_interface($driver,$tt_interface) {
 $driver = $driver|0;
 $tt_interface = $tt_interface|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($driver) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 228|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (_ft_service_list_lookup($4,$tt_interface)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$0>>2]|0;
 $8 = (_FT_Get_Module($7,872496)|0);
 $9 = ($8|0)==(0|0);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[$8>>2]|0;
 $11 = (($10) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($12) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_iii[$15 & 4095]($driver,$tt_interface)|0);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function _Load_Glyph20750($ttslot,$ttsize,$glyph_index,$load_flags) {
 $ttslot = $ttslot|0;
 $ttsize = $ttsize|0;
 $glyph_index = $glyph_index|0;
 $load_flags = $load_flags|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $load_flags$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ttslot) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($ttslot|0)==(0|0);
 if ($2) {
  $$0 = 37;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($ttsize|0)==(0|0);
 if ($3) {
  $$0 = 36;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ($1|0)==(0|0);
 if ($4) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($1) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6>>>0)>($glyph_index>>>0);
 if (!($7)) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = $load_flags & 2;
 $9 = ($8|0)==(0);
 if ($9) {
  $$1 = $load_flags;
 } else {
  $10 = (($1) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 & 8192;
  $13 = ($12|0)==(0);
  $14 = $load_flags & -3;
  $load_flags$ = $13 ? $load_flags : $14;
  $15 = $load_flags$ >>> 14;
  $16 = $15 & 2;
  $17 = $16 | $load_flags$;
  $$1 = $17;
 }
 $18 = $$1 & 1025;
 $19 = ($18|0)==(0);
 if ($19) {
  $$2 = $$1;
 } else {
  $20 = (($1) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 >>> 12;
  $23 = $22 & 2;
  $24 = $23 ^ 11;
  $$ = $24 | $$1;
  $$2 = $$;
 }
 $25 = (_TT_Load_Glyph($ttsize,$ttslot,$glyph_index,$$2)|0);
 $$0 = $25;
 STACKTOP = sp;return ($$0|0);
}
function _tt_get_kerning($ttface,$left_glyph,$right_glyph,$kerning) {
 $ttface = $ttface|0;
 $left_glyph = $left_glyph|0;
 $right_glyph = $right_glyph|0;
 $kerning = $kerning|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ttface) + 532|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$kerning>>2] = 0;
 $2 = (($kerning) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ($1|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 0;
 }
 $4 = (($1) + 128|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$5 & 2047]($ttface,$left_glyph,$right_glyph)|0);
 HEAP32[$kerning>>2] = $6;
 STACKTOP = sp;return 0;
}
function _tt_get_advances($ttface,$start,$count,$flags,$advances) {
 $ttface = $ttface|0;
 $start = $start|0;
 $count = $count|0;
 $flags = $flags|0;
 $advances = $advances|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ah = 0, $aw = 0, $exitcond = 0, $exitcond6 = 0, $lsb = 0, $nn$04 = 0, $nn$11 = 0;
 var $tsb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tsb = sp + 6|0;
 $ah = sp;
 $lsb = sp + 2|0;
 $aw = sp + 4|0;
 $0 = $flags & 16;
 $1 = ($0|0)==(0);
 $2 = ($count|0)==(0);
 if ($1) {
  if ($2) {
   STACKTOP = sp;return 0;
  } else {
   $nn$11 = 0;
  }
  while(1) {
   $8 = (($nn$11) + ($start))|0;
   _TT_Get_HMetrics($ttface,$8,$lsb,$aw);
   $9 = HEAP16[$aw>>1]|0;
   $10 = $9&65535;
   $11 = (($advances) + ($nn$11<<2)|0);
   HEAP32[$11>>2] = $10;
   $12 = (($nn$11) + 1)|0;
   $exitcond = ($12|0)==($count|0);
   if ($exitcond) {
    break;
   } else {
    $nn$11 = $12;
   }
  }
  STACKTOP = sp;return 0;
 } else {
  if ($2) {
   STACKTOP = sp;return 0;
  } else {
   $nn$04 = 0;
  }
  while(1) {
   $3 = (($nn$04) + ($start))|0;
   _TT_Get_VMetrics($ttface,$3,$tsb,$ah);
   $4 = HEAP16[$ah>>1]|0;
   $5 = $4&65535;
   $6 = (($advances) + ($nn$04<<2)|0);
   HEAP32[$6>>2] = $5;
   $7 = (($nn$04) + 1)|0;
   $exitcond6 = ($7|0)==($count|0);
   if ($exitcond6) {
    break;
   } else {
    $nn$04 = $7;
   }
  }
  STACKTOP = sp;return 0;
 }
 return 0|0;
}
function _tt_size_request($size,$req) {
 $size = $size|0;
 $req = $req|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, $strike_index = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $strike_index = sp;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 2;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $26 = $0;$error$0 = 0;
  } else {
   $5 = (($0) + 532|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 148|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (FUNCTION_TABLE_iiii[$8 & 2047]($0,$req,$strike_index)|0);
   $10 = ($9|0)==(0);
   if (!($10)) {
    $11 = (($size) + 112|0);
    HEAP32[$11>>2] = -1;
    $$pre = HEAP32[$size>>2]|0;
    $26 = $$pre;$error$0 = $9;
    break;
   }
   $12 = HEAP32[$strike_index>>2]|0;
   $13 = HEAP32[$size>>2]|0;
   $14 = (($size) + 112|0);
   HEAP32[$14>>2] = $12;
   $15 = (($13) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16 & 1;
   $18 = ($17|0)==(0);
   if (!($18)) {
    _FT_Select_Metrics($13,$12);
    (_tt_size_reset($size)|0);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $19 = (($13) + 532|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($size) + 12|0);
   $22 = (($20) + 152|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (FUNCTION_TABLE_iiii[$23 & 2047]($13,$12,$21)|0);
   $25 = ($24|0)==(0);
   if ($25) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$14>>2] = -1;
   $$0 = $24;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 _FT_Request_Metrics($26,$req);
 $27 = HEAP32[$size>>2]|0;
 $28 = (($27) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = $29 & 1;
 $31 = ($30|0)==(0);
 if ($31) {
  $$0 = $error$0;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = (_tt_size_reset($size)|0);
 $33 = (($size) + 12|0);
 $34 = (($size) + 44|0);
 ;HEAP32[$33+0>>2]=HEAP32[$34+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$34+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$34+12>>2]|0;HEAP32[$33+16>>2]=HEAP32[$34+16>>2]|0;HEAP32[$33+20>>2]=HEAP32[$34+20>>2]|0;HEAP32[$33+24>>2]=HEAP32[$34+24>>2]|0;
 $$0 = $32;
 STACKTOP = sp;return ($$0|0);
}
function _tt_size_select($size,$strike_index) {
 $size = $size|0;
 $strike_index = $strike_index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($size) + 112|0);
 HEAP32[$1>>2] = $strike_index;
 $2 = (($0) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1;
 $5 = ($4|0)==(0);
 if (!($5)) {
  _FT_Select_Metrics($0,$strike_index);
  (_tt_size_reset($size)|0);
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 $6 = (($0) + 532|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($size) + 12|0);
 $9 = (($7) + 152|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiii[$10 & 2047]($0,$strike_index,$8)|0);
 $12 = ($11|0)==(0);
 if ($12) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 HEAP32[$1>>2] = -1;
 $error$0 = $11;
 STACKTOP = sp;return ($error$0|0);
}
function _tt_glyphzone_new($memory,$maxPoints,$maxContours,$zone) {
 $memory = $memory|0;
 $maxPoints = $maxPoints|0;
 $maxContours = $maxContours|0;
 $zone = $zone|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 dest=$zone+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$zone>>2] = $memory;
 $0 = $maxPoints&65535;
 $1 = (_ft_mem_realloc($memory,8,0,$0,0,$error)|0);
 $2 = (($zone) + 12|0);
 HEAP32[$2>>2] = $1;
 $3 = HEAP32[$error>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (_ft_mem_realloc($memory,8,0,$0,0,$error)|0);
  $6 = (($zone) + 16|0);
  HEAP32[$6>>2] = $5;
  $7 = HEAP32[$error>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = (_ft_mem_realloc($memory,8,0,$0,0,$error)|0);
   $10 = (($zone) + 20|0);
   HEAP32[$10>>2] = $9;
   $11 = HEAP32[$error>>2]|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = (_ft_mem_realloc($memory,1,0,$0,0,$error)|0);
    $14 = (($zone) + 24|0);
    HEAP32[$14>>2] = $13;
    $15 = HEAP32[$error>>2]|0;
    $16 = ($15|0)==(0);
    if ($16) {
     $17 = $maxContours << 16 >> 16;
     $18 = (_ft_mem_realloc($memory,2,0,$17,0,$error)|0);
     $19 = (($zone) + 28|0);
     HEAP32[$19>>2] = $18;
     $20 = HEAP32[$error>>2]|0;
     $21 = ($20|0)==(0);
     if ($21) {
      $33 = (($zone) + 4|0);
      HEAP16[$33>>1] = $maxPoints;
      $34 = (($zone) + 6|0);
      HEAP16[$34>>1] = $maxContours;
      $35 = 0;
      STACKTOP = sp;return ($35|0);
     } else {
      $36 = $20;
     }
    } else {
     $36 = $15;
    }
   } else {
    $36 = $11;
   }
  } else {
   $36 = $7;
  }
 } else {
  $36 = $3;
 }
 $22 = HEAP32[$zone>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $35 = $36;
  STACKTOP = sp;return ($35|0);
 }
 $24 = (($zone) + 28|0);
 $25 = HEAP32[$24>>2]|0;
 _ft_mem_free($22,$25);
 HEAP32[$24>>2] = 0;
 $26 = (($zone) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 _ft_mem_free($22,$27);
 HEAP32[$26>>2] = 0;
 $28 = (($zone) + 16|0);
 $29 = HEAP32[$28>>2]|0;
 _ft_mem_free($22,$29);
 HEAP32[$28>>2] = 0;
 $30 = HEAP32[$2>>2]|0;
 _ft_mem_free($22,$30);
 HEAP32[$2>>2] = 0;
 $31 = (($zone) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 _ft_mem_free($22,$32);
 HEAP32[$31>>2] = 0;
 ;HEAP32[$zone+0>>2]=0|0;HEAP32[$zone+4>>2]=0|0;HEAP32[$zone+8>>2]=0|0;
 $$pre = HEAP32[$error>>2]|0;
 $35 = $$pre;
 STACKTOP = sp;return ($35|0);
}
function _tt_face_init($stream,$ttface,$face_index,$num_params,$params) {
 $stream = $stream|0;
 $ttface = $ttface|0;
 $face_index = $face_index|0;
 $num_params = $num_params|0;
 $params = $params|0;
 var $$0 = 0, $$01$lcssa$i$i$i$i = 0, $$016$i$i$i$i = 0, $$12$i$i$i$i = 0, $$phi$trans$insert$i$i = 0, $$pre$i$i = 0, $$pre17$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $asize$i = 0, $buf$i = 0, $checksum$0$lcssa$i$i$i$i = 0, $checksum$06$i$i = 0, $checksum$07$i$i$i$i = 0, $checksum$1$i$i = 0, $checksum$1$lcssa$i$i$i$i = 0, $checksum$13$i$i$i$i = 0, $checksum$2$i$i = 0, $count$06$i = 0, $count$1$i = 0, $error$3 = 0;
 var $error$4 = 0, $glyph_index$05$i = 0, $glyph_index$1$i = 0, $has_cvt$010$i$i = 0, $has_cvt$1$i$i = 0, $has_cvt$2$i$i = 0, $i$011$i$i = 0, $i$04$i = 0, $i$04$i$i$i$i = 0, $j$07$i$i = 0, $j$11$i$i = 0, $j$11$us$i$i = 0, $k$0$i$i = 0, $nn$01$i$i = 0, $num_matched_ids$i$i = 0, $or$cond$i = 0, $phitmp = 0, $phitmp$i$i = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $asize$i = sp + 52|0;
 $buf$i = sp + 56|0;
 $num_matched_ids$i$i = sp;
 $0 = (($ttface) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_FT_Get_Module_Interface($3,872504)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (_FT_Stream_Seek($stream,0)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($4) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiii[$9 & 255]($stream,$ttface,$face_index,$num_params,$params)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($ttface) + 148|0);
 $13 = HEAP32[$12>>2]|0;
 if (!((($13|0) == 1953658213) | (($13|0) == 131072) | (($13|0) == 65536))) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($ttface) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 | 2048;
 HEAP32[$14>>2] = $16;
 $17 = ($face_index|0)<(0);
 if ($17) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($4) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_iiiiii[$19 & 255]($stream,$ttface,$face_index,$num_params,$params)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  $$0 = $20;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = ($ttface|0)==(0|0);
 L19: do {
  if (!($22)) {
   $23 = (($ttface) + 20|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0|0);
   L21: do {
    if ($25) {
     label = 11;
    } else {
     $nn$01$i$i = 0;
     while(1) {
      $28 = (872832 + (($nn$01$i$i*17)|0)|0);
      $29 = (_strstr($24,$28)|0);
      $30 = ($29|0)==(0|0);
      $27 = (($nn$01$i$i) + 1)|0;
      if (!($30)) {
       break L21;
      }
      $26 = ($27|0)<(8);
      if ($26) {
       $nn$01$i$i = $27;
      } else {
       label = 11;
       break;
      }
     }
    }
   } while(0);
   L25: do {
    if ((label|0) == 11) {
     dest=$num_matched_ids$i$i+0|0; stop=dest+52|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
     $31 = (($ttface) + 152|0);
     $32 = HEAP16[$31>>1]|0;
     $33 = ($32<<16>>16)==(0);
     if ($33) {
      $j$11$i$i = 0;
     } else {
      $34 = (($ttface) + 156|0);
      $35 = (($ttface) + 508|0);
      $36 = (($ttface) + 104|0);
      $140 = $32;$45 = 0;$has_cvt$010$i$i = 0;$i$011$i$i = 1;
      while(1) {
       $43 = HEAP32[$34>>2]|0;
       $44 = (($43) + ($45<<4)|0);
       $46 = HEAP32[$44>>2]|0;
       if ((($46|0) == 1668707360)) {
        $has_cvt$1$i$i = 1;$k$0$i$i = 0;
        label = 19;
       } else if ((($46|0) == 1718642541)) {
        $has_cvt$1$i$i = $has_cvt$010$i$i;$k$0$i$i = 1;
        label = 19;
       } else if ((($46|0) == 1886545264)) {
        $has_cvt$1$i$i = $has_cvt$010$i$i;$k$0$i$i = 2;
        label = 19;
       } else {
        $93 = $140;$has_cvt$2$i$i = $has_cvt$010$i$i;
       }
       if ((label|0) == 19) {
        label = 0;
        $48 = $43;$checksum$06$i$i = 0;$j$07$i$i = 0;
        while(1) {
         $47 = ((($48) + ($45<<4)|0) + 12|0);
         $49 = HEAP32[$47>>2]|0;
         $50 = (((872520 + (($j$07$i$i*24)|0)|0) + ($k$0$i$i<<3)|0) + 4|0);
         $51 = HEAP32[$50>>2]|0;
         $52 = ($49|0)==($51|0);
         if ($52) {
          $53 = ($checksum$06$i$i|0)==(0);
          do {
           if ($53) {
            $54 = HEAP32[$35>>2]|0;
            $55 = ($54|0)==(0|0);
            if ($55) {
             $checksum$1$i$i = 0;
            } else {
             $56 = (($48) + ($45<<4)|0);
             $57 = HEAP32[$56>>2]|0;
             $58 = HEAP32[$36>>2]|0;
             $59 = (FUNCTION_TABLE_iiiii[$54 & 511]($ttface,$57,$58,0)|0);
             $60 = ($59|0)==(0);
             if (!($60)) {
              $checksum$1$i$i = 0;
              break;
             }
             $61 = HEAP32[$36>>2]|0;
             $62 = HEAP32[$34>>2]|0;
             $63 = ((($62) + ($45<<4)|0) + 12|0);
             $64 = HEAP32[$63>>2]|0;
             $65 = (_FT_Stream_EnterFrame($61,$64)|0);
             $66 = ($65|0)==(0);
             if (!($66)) {
              $checksum$1$i$i = 0;
              break;
             }
             $67 = ($64>>>0)>(3);
             if ($67) {
              $$016$i$i$i$i = $64;$checksum$07$i$i$i$i = 0;
              while(1) {
               $69 = (_FT_Stream_GetULong($61)|0);
               $70 = (($69) + ($checksum$07$i$i$i$i))|0;
               $71 = (($$016$i$i$i$i) + -4)|0;
               $72 = ($71>>>0)>(3);
               if ($72) {
                $$016$i$i$i$i = $71;$checksum$07$i$i$i$i = $70;
               } else {
                $$01$lcssa$i$i$i$i = $71;$checksum$0$lcssa$i$i$i$i = $70;
                break;
               }
              }
             } else {
              $$01$lcssa$i$i$i$i = $64;$checksum$0$lcssa$i$i$i$i = 0;
             }
             $68 = ($$01$lcssa$i$i$i$i|0)==(0);
             if ($68) {
              $checksum$1$lcssa$i$i$i$i = $checksum$0$lcssa$i$i$i$i;
             } else {
              $$12$i$i$i$i = $$01$lcssa$i$i$i$i;$checksum$13$i$i$i$i = $checksum$0$lcssa$i$i$i$i;$i$04$i$i$i$i = 3;
              while(1) {
               $73 = (_FT_Stream_GetChar($61)|0);
               $74 = $73&255;
               $75 = $i$04$i$i$i$i << 3;
               $76 = $74 << $75;
               $77 = (($76) + ($checksum$13$i$i$i$i))|0;
               $78 = (($$12$i$i$i$i) + -1)|0;
               $79 = (($i$04$i$i$i$i) + -1)|0;
               $80 = ($78|0)==(0);
               if ($80) {
                $checksum$1$lcssa$i$i$i$i = $77;
                break;
               } else {
                $$12$i$i$i$i = $78;$checksum$13$i$i$i$i = $77;$i$04$i$i$i$i = $79;
               }
              }
             }
             _FT_Stream_ExitFrame($61);
             $checksum$1$i$i = $checksum$1$lcssa$i$i$i$i;
            }
           } else {
            $checksum$1$i$i = $checksum$06$i$i;
           }
          } while(0);
          $81 = ((872520 + (($j$07$i$i*24)|0)|0) + ($k$0$i$i<<3)|0);
          $82 = HEAP32[$81>>2]|0;
          $83 = ($82|0)==($checksum$1$i$i|0);
          $84 = (($num_matched_ids$i$i) + ($j$07$i$i<<2)|0);
          $85 = HEAP32[$84>>2]|0;
          if ($83) {
           $86 = (($85) + 1)|0;
           HEAP32[$84>>2] = $86;
           $88 = $86;
          } else {
           $88 = $85;
          }
          $87 = ($88|0)==(3);
          if ($87) {
           break L25;
          } else {
           $checksum$2$i$i = $checksum$1$i$i;
          }
         } else {
          $checksum$2$i$i = $checksum$06$i$i;
         }
         $89 = (($j$07$i$i) + 1)|0;
         $90 = ($89|0)<(13);
         if (!($90)) {
          break;
         }
         $91 = HEAP32[$34>>2]|0;
         $48 = $91;$checksum$06$i$i = $checksum$2$i$i;$j$07$i$i = $89;
        }
        $$pre17$i$i = HEAP16[$31>>1]|0;
        $93 = $$pre17$i$i;$has_cvt$2$i$i = $has_cvt$1$i$i;
       }
       $92 = ($i$011$i$i&65535)<($93&65535);
       if (!($92)) {
        break;
       }
       $94 = $i$011$i$i&65535;
       $phitmp$i$i = (($i$011$i$i) + 1)<<16>>16;
       $140 = $93;$45 = $94;$has_cvt$010$i$i = $has_cvt$2$i$i;$i$011$i$i = $phitmp$i$i;
      }
      $37 = ($has_cvt$2$i$i<<24>>24)==(0);
      if ($37) {
       $j$11$i$i = 0;
      } else {
       $j$11$us$i$i = 0;
       while(1) {
        $40 = (($num_matched_ids$i$i) + ($j$11$us$i$i<<2)|0);
        $41 = HEAP32[$40>>2]|0;
        $42 = ($41|0)==(3);
        $39 = (($j$11$us$i$i) + 1)|0;
        if ($42) {
         break L25;
        }
        $38 = ($39|0)<(13);
        if ($38) {
         $j$11$us$i$i = $39;
        } else {
         break L19;
        }
       }
      }
     }
     while(1) {
      $97 = ($j$11$i$i>>>0)<(5);
      $$phi$trans$insert$i$i = (($num_matched_ids$i$i) + ($j$11$i$i<<2)|0);
      $$pre$i$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
      if ($97) {
       $100 = $$pre$i$i;
      } else {
       $98 = (($$pre$i$i) + 1)|0;
       HEAP32[$$phi$trans$insert$i$i>>2] = $98;
       $100 = $98;
      }
      $99 = ($100|0)==(3);
      $96 = (($j$11$i$i) + 1)|0;
      if ($99) {
       break L25;
      }
      $95 = ($96|0)<(13);
      if ($95) {
       $j$11$i$i = $96;
      } else {
       break L19;
      }
     }
    }
   } while(0);
   $101 = HEAP32[$14>>2]|0;
   $102 = $101 | 8192;
   HEAP32[$14>>2] = $102;
  }
 } while(0);
 $103 = (_tt_face_load_hdmx($ttface,$stream)|0);
 $104 = ($103|0)==(0);
 if (!($104)) {
  $$0 = $103;
  STACKTOP = sp;return ($$0|0);
 }
 $105 = HEAP32[$14>>2]|0;
 $106 = $105 & 1;
 $107 = ($106|0)==(0);
 L77: do {
  if ($107) {
   $error$4 = 0;
  } else {
   $108 = (_tt_face_load_loca($ttface,$stream)|0);
   $109 = ($108|0)==(0);
   if ($109) {
    $110 = (_tt_face_load_cvt($ttface,$stream)|0);
    $111 = ($110|0)==(0);
    if ($111) {
     $112 = (_tt_face_load_fpgm($ttface,$stream)|0);
     $113 = ($112|0)==(0);
     if ($113) {
      $114 = (_tt_face_load_prep($ttface,$stream)|0);
      $error$3 = $114;
     } else {
      $error$3 = $112;
     }
    } else {
     $error$3 = $110;
    }
   } else {
    $error$3 = $108;
   }
   $115 = (($ttface) + 28|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = ($116|0)==(0);
   if ($117) {
    $error$4 = $error$3;
   } else {
    $118 = (($ttface) + 736|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($119|0)==(0|0);
    if ($120) {
     $error$4 = $error$3;
    } else {
     $121 = (($ttface) + 732|0);
     $122 = HEAP32[$121>>2]|0;
     $123 = ($122|0)==(0);
     if ($123) {
      $error$4 = $error$3;
     } else {
      $count$06$i = 0;$glyph_index$05$i = 0;$i$04$i = 0;
      while(1) {
       (_tt_face_get_location($ttface,$i$04$i,$asize$i)|0);
       $124 = HEAP32[$asize$i>>2]|0;
       $125 = ($124|0)==(0);
       if ($125) {
        $count$1$i = $count$06$i;$glyph_index$1$i = $glyph_index$05$i;
       } else {
        $126 = (($count$06$i) + 1)|0;
        $127 = ($126>>>0)>(1);
        if ($127) {
         $error$4 = $error$3;
         break L77;
        } else {
         $count$1$i = $126;$glyph_index$1$i = $i$04$i;
        }
       }
       $128 = (($i$04$i) + 1)|0;
       $129 = HEAP32[$121>>2]|0;
       $130 = ($128>>>0)<($129>>>0);
       if ($130) {
        $count$06$i = $count$1$i;$glyph_index$05$i = $glyph_index$1$i;$i$04$i = $128;
       } else {
        break;
       }
      }
      $131 = ($count$1$i|0)==(1);
      if ($131) {
       $132 = ($glyph_index$1$i|0)==(0);
       if (!($132)) {
        $133 = (_FT_Get_Glyph_Name($ttface,$glyph_index$1$i,$buf$i,8)|0);
        $134 = ($133|0)==(0);
        $135 = HEAP8[$buf$i>>0]|0;
        $136 = ($135<<24>>24)==(46);
        $or$cond$i = $134 & $136;
        if (!($or$cond$i)) {
         $error$4 = $error$3;
         break;
        }
        $137 = (_strncmp($buf$i,872512,8)|0);
        $phitmp = ($137|0)==(0);
        if (!($phitmp)) {
         $error$4 = $error$3;
         break;
        }
       }
       $138 = HEAP32[$14>>2]|0;
       $139 = $138 & -2;
       HEAP32[$14>>2] = $139;
       $error$4 = $error$3;
      } else {
       $error$4 = $error$3;
      }
     }
    }
   }
  }
 } while(0);
 _TT_Init_Glyph_Loading($ttface);
 $$0 = $error$4;
 STACKTOP = sp;return ($$0|0);
}
function _tt_face_done($ttface) {
 $ttface = $ttface|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ttface|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($ttface) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($ttface) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($ttface) + 532|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($ttface) + 692|0);
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_vi[$9 & 4095]($11);
 }
 $12 = ($6|0)==(0|0);
 if (!($12)) {
  $13 = (($6) + 12|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_vi[$14 & 4095]($ttface);
 }
 _tt_face_done_loca($ttface);
 _tt_face_free_hdmx($ttface);
 $15 = (($ttface) + 672|0);
 $16 = HEAP32[$15>>2]|0;
 _ft_mem_free($2,$16);
 HEAP32[$15>>2] = 0;
 $17 = (($ttface) + 668|0);
 HEAP32[$17>>2] = 0;
 $18 = (($ttface) + 656|0);
 _FT_Stream_ReleaseFrame($4,$18);
 $19 = (($ttface) + 664|0);
 _FT_Stream_ReleaseFrame($4,$19);
 $20 = (($ttface) + 652|0);
 HEAP32[$20>>2] = 0;
 $21 = (($ttface) + 660|0);
 HEAP32[$21>>2] = 0;
 $22 = (($ttface) + 712|0);
 $23 = HEAP32[$22>>2]|0;
 _tt_done_blend($2,$23);
 HEAP32[$22>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_size_run_fpgm($size,$pedantic) {
 $size = $size|0;
 $pedantic = $pedantic|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exec$0 = 0, $exec$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($size) + 292|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $5 = (($0) + 96|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 40|0);
  $exec$0$in = $7;
 } else {
  $4 = (($size) + 296|0);
  $exec$0$in = $4;
 }
 $exec$0 = HEAP32[$exec$0$in>>2]|0;
 $8 = ($exec$0|0)==(0|0);
 if ($8) {
  $$0 = 153;
  STACKTOP = sp;return ($$0|0);
 }
 (_TT_Load_Context($exec$0,$0,$size)|0);
 $9 = (($exec$0) + 428|0);
 HEAP32[$9>>2] = 0;
 $10 = (($exec$0) + 16|0);
 HEAP32[$10>>2] = 0;
 $11 = (($exec$0) + 476|0);
 HEAP32[$11>>2] = 64;
 $12 = (($exec$0) + 480|0);
 HEAP32[$12>>2] = 0;
 $13 = (($exec$0) + 484|0);
 HEAP32[$13>>2] = 0;
 $14 = (($exec$0) + 488|0);
 HEAP8[$14>>0] = 0;
 $15 = (($exec$0) + 564|0);
 HEAP32[$15>>2] = 65536;
 $16 = (($exec$0) + 561|0);
 HEAP8[$16>>0] = $pedantic;
 $17 = (($exec$0) + 216|0);
 $18 = (($exec$0) + 252|0);
 HEAP16[$18>>1] = 0;
 $19 = (($exec$0) + 260|0);
 HEAP32[$19>>2] = 0;
 $20 = (($exec$0) + 256|0);
 ;HEAP16[$17+0>>1]=0|0;HEAP16[$17+2>>1]=0|0;HEAP16[$17+4>>1]=0|0;HEAP16[$17+6>>1]=0|0;HEAP16[$17+8>>1]=0|0;HEAP16[$17+10>>1]=0|0;
 HEAP32[$20>>2] = 65536;
 $21 = (($0) + 656|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($0) + 652|0);
 $24 = HEAP32[$23>>2]|0;
 (_TT_Set_CodeRange($exec$0,1,$22,$24)|0);
 (_TT_Clear_CodeRange($exec$0,2)|0);
 (_TT_Clear_CodeRange($exec$0,3)|0);
 $25 = HEAP32[$23>>2]|0;
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = (_TT_Goto_CodeRange($exec$0,1,0)|0);
  $28 = ($27|0)==(0);
  if (!($28)) {
   $$0 = $27;
   STACKTOP = sp;return ($$0|0);
  }
  $29 = (($0) + 688|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (FUNCTION_TABLE_ii[$30 & 4095]($exec$0)|0);
  $32 = ($31|0)==(0);
  if (!($32)) {
   $$0 = $31;
   STACKTOP = sp;return ($$0|0);
  }
 }
 (_TT_Save_Context($exec$0,$size)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _tt_size_run_prep($size,$pedantic) {
 $size = $size|0;
 $pedantic = $pedantic|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, $exec$0 = 0, $exec$0$in = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($size) + 292|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $5 = (($0) + 96|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 40|0);
  $exec$0$in = $7;
 } else {
  $4 = (($size) + 296|0);
  $exec$0$in = $4;
 }
 $exec$0 = HEAP32[$exec$0$in>>2]|0;
 $8 = ($exec$0|0)==(0|0);
 if ($8) {
  $$0 = 153;
  STACKTOP = sp;return ($$0|0);
 }
 (_TT_Load_Context($exec$0,$0,$size)|0);
 $9 = (($exec$0) + 428|0);
 HEAP32[$9>>2] = 0;
 $10 = (($exec$0) + 16|0);
 HEAP32[$10>>2] = 0;
 $11 = (($exec$0) + 488|0);
 HEAP8[$11>>0] = 0;
 $12 = (($exec$0) + 561|0);
 HEAP8[$12>>0] = $pedantic;
 $13 = (($0) + 664|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($0) + 660|0);
 $16 = HEAP32[$15>>2]|0;
 (_TT_Set_CodeRange($exec$0,2,$14,$16)|0);
 (_TT_Clear_CodeRange($exec$0,3)|0);
 $17 = HEAP32[$15>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  $error$0 = 0;
 } else {
  $19 = (_TT_Goto_CodeRange($exec$0,2,0)|0);
  $20 = ($19|0)==(0);
  if ($20) {
   $21 = HEAP8[$1>>0]|0;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    $23 = (($0) + 688|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (FUNCTION_TABLE_ii[$24 & 4095]($exec$0)|0);
    $error$0 = $25;
   } else {
    $error$0 = 0;
   }
  } else {
   $error$0 = $19;
  }
 }
 $26 = (($size) + 172|0);
 $27 = (($exec$0) + 284|0);
 dest=$26+0|0; src=$27+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 (_TT_Save_Context($exec$0,$size)|0);
 $$0 = $error$0;
 STACKTOP = sp;return ($$0|0);
}
function _tt_size_ready_bytecode($size,$pedantic) {
 $size = $size|0;
 $pedantic = $pedantic|0;
 var $$c$i = 0, $$c1$i = 0, $$c3$i = 0, $$c4$i = 0, $$c5$i = 0, $$op = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error$1 = 0, $error$i = 0, $i$05 = 0, $i$13 = 0, $scevgep$i = 0, $storemerge$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp;
 $0 = (($size) + 300|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = HEAP32[$size>>2]|0;
   $4 = (($3) + 100|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($3) + 260|0);
   $7 = (($size) + 300|0);
   HEAP8[$7>>0] = 1;
   $8 = (($size) + 301|0);
   HEAP8[$8>>0] = 0;
   $9 = (($6) + 20|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = $10&65535;
   $12 = (($size) + 120|0);
   HEAP32[$12>>2] = $11;
   $13 = (($6) + 22|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = $14&65535;
   $16 = (($size) + 132|0);
   $$c$i = $15;
   HEAP32[$16>>2] = $$c$i;
   $17 = (($size) + 116|0);
   HEAP32[$17>>2] = 0;
   $18 = (($size) + 128|0);
   HEAP32[$18>>2] = 0;
   $19 = (($size) + 140|0);
   HEAP32[$19>>2] = 0;
   $20 = (($size) + 144|0);
   HEAP32[$20>>2] = 0;
   $21 = (($3) + 668|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($size) + 240|0);
   HEAP32[$23>>2] = $22;
   $24 = (($6) + 18|0);
   $25 = HEAP16[$24>>1]|0;
   $26 = (($size) + 248|0);
   HEAP16[$26>>1] = $25;
   $27 = (($size) + 72|0);
   $28 = (($27) + 37|0);
   HEAP8[$28>>0] = 0;
   $29 = (($27) + 38|0);
   HEAP8[$29>>0] = 0;
   $scevgep$i = (($size) + 92|0);
   ;HEAP32[$scevgep$i+0>>2]=0|0;HEAP32[$scevgep$i+4>>2]=0|0;HEAP32[$scevgep$i+8>>2]=0|0;HEAP32[$scevgep$i+12>>2]=0|0;
   $30 = (_ft_mem_realloc($5,16,0,$11,0,$error$i)|0);
   $31 = (($size) + 124|0);
   $$c1$i = $30;
   HEAP32[$31>>2] = $$c1$i;
   $32 = HEAP32[$error$i>>2]|0;
   $33 = ($32|0)==(0);
   if ($33) {
    $34 = HEAP32[$16>>2]|0;
    $35 = (_ft_mem_realloc($5,16,0,$34,0,$error$i)|0);
    $36 = (($size) + 136|0);
    HEAP32[$36>>2] = $35;
    $37 = HEAP32[$error$i>>2]|0;
    $38 = ($37|0)==(0);
    if ($38) {
     $39 = HEAP32[$23>>2]|0;
     $40 = (_ft_mem_realloc($5,4,0,$39,0,$error$i)|0);
     $41 = (($size) + 244|0);
     $$c3$i = $40;
     HEAP32[$41>>2] = $$c3$i;
     $42 = HEAP32[$error$i>>2]|0;
     $43 = ($42|0)==(0);
     if ($43) {
      $44 = HEAP16[$26>>1]|0;
      $45 = $44&65535;
      $46 = (_ft_mem_realloc($5,4,0,$45,0,$error$i)|0);
      $47 = (($size) + 252|0);
      $$c4$i = $46;
      HEAP32[$47>>2] = $$c4$i;
      $48 = HEAP32[$error$i>>2]|0;
      $49 = ($48|0)==(0);
      if ($49) {
       $50 = (($6) + 16|0);
       $51 = HEAP16[$50>>1]|0;
       $52 = $51&65535;
       $53 = (($52) + 4)|0;
       $54 = $53&65535;
       $55 = (($size) + 256|0);
       $56 = (_tt_glyphzone_new($5,$54,0,$55)|0);
       HEAP32[$error$i>>2] = $56;
       $57 = ($56|0)==(0);
       if ($57) {
        $58 = (($55) + 8|0);
        HEAP16[$58>>1] = $54;
        $59 = (($size) + 172|0);
        dest=$59+0|0; src=873120+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $60 = (($3) + 96|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = (($61) + 4|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = (($63) + 180|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = (($3) + 688|0);
        $$c5$i = $65;
        $67 = ($65|0)==(0|0);
        $storemerge$i = $67 ? (3437) : $$c5$i;
        HEAP32[$66>>2] = $storemerge$i;
        $68 = (_tt_size_run_fpgm($size,$pedantic)|0);
        HEAP32[$error$i>>2] = $68;
        $69 = ($68|0)==(0);
        if ($69) {
         $$pre$phiZ2D = $8;
         break;
        }
       }
      }
     }
    }
   }
   _tt_size_done_bytecode($size);
   $$pre$i = HEAP32[$error$i>>2]|0;
   $70 = ($$pre$i|0)==(0);
   if ($70) {
    $$pre$phiZ2D = $8;
   } else {
    $error$1 = $$pre$i;
    STACKTOP = sp;return ($error$1|0);
   }
  } else {
   $$pre = (($size) + 301|0);
   $$pre$phiZ2D = $$pre;
  }
 } while(0);
 $71 = HEAP8[$$pre$phiZ2D>>0]|0;
 $72 = ($71<<24>>24)==(0);
 if (!($72)) {
  $error$1 = 0;
  STACKTOP = sp;return ($error$1|0);
 }
 $73 = (($size) + 240|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($74|0)==(0);
 if (!($75)) {
  $76 = HEAP32[$size>>2]|0;
  $77 = (($76) + 672|0);
  $78 = (($size) + 88|0);
  $79 = (($size) + 244|0);
  $i$05 = 0;
  while(1) {
   $88 = HEAP32[$77>>2]|0;
   $89 = (($88) + ($i$05<<1)|0);
   $90 = HEAP16[$89>>1]|0;
   $91 = $90 << 16 >> 16;
   $92 = HEAP32[$78>>2]|0;
   $93 = (_FT_MulFix($91,$92)|0);
   $94 = HEAP32[$79>>2]|0;
   $95 = (($94) + ($i$05<<2)|0);
   HEAP32[$95>>2] = $93;
   $96 = (($i$05) + 1)|0;
   $97 = HEAP32[$73>>2]|0;
   $98 = ($96>>>0)<($97>>>0);
   if ($98) {
    $i$05 = $96;
   } else {
    break;
   }
  }
 }
 $80 = (($size) + 264|0);
 $81 = HEAP16[$80>>1]|0;
 $82 = ($81<<16>>16)==(0);
 if (!($82)) {
  $83 = (($size) + 268|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($size) + 272|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = $81&65535;
  $i$13 = 0;
  while(1) {
   $107 = (($84) + ($i$13<<3)|0);
   HEAP32[$107>>2] = 0;
   $108 = ((($84) + ($i$13<<3)|0) + 4|0);
   HEAP32[$108>>2] = 0;
   $109 = (($86) + ($i$13<<3)|0);
   HEAP32[$109>>2] = 0;
   $110 = ((($86) + ($i$13<<3)|0) + 4|0);
   HEAP32[$110>>2] = 0;
   $111 = (($i$13) + 1)|0;
   $112 = ($111>>>0)<($87>>>0);
   if ($112) {
    $i$13 = $111;
   } else {
    break;
   }
  }
 }
 $99 = (($size) + 248|0);
 $100 = HEAP16[$99>>1]|0;
 $101 = ($100<<16>>16)==(0);
 if (!($101)) {
  $102 = (($size) + 252|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = $100&65535;
  $105 = ($100&65535)>(1);
  $$op = $104 << 2;
  $106 = $105 ? $$op : 4;
  _memset(($103|0),0,($106|0))|0;
 }
 $113 = (($size) + 172|0);
 dest=$113+0|0; src=873120+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $114 = (_tt_size_run_prep($size,$pedantic)|0);
 $115 = ($114|0)==(0);
 if (!($115)) {
  $error$1 = $114;
  STACKTOP = sp;return ($error$1|0);
 }
 HEAP8[$$pre$phiZ2D>>0] = 1;
 $error$1 = 0;
 STACKTOP = sp;return ($error$1|0);
}
function _tt_size_init($ttsize) {
 $ttsize = $ttsize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ttsize) + 300|0);
 HEAP8[$0>>0] = 0;
 $1 = (($ttsize) + 301|0);
 HEAP8[$1>>0] = 0;
 $2 = (($ttsize) + 72|0);
 $3 = (($2) + 36|0);
 HEAP8[$3>>0] = 0;
 $4 = (($ttsize) + 112|0);
 HEAP32[$4>>2] = -1;
 STACKTOP = sp;return 0;
}
function _tt_size_done($ttsize) {
 $ttsize = $ttsize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ttsize) + 300|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  _tt_size_done_bytecode($ttsize);
 }
 $3 = (($ttsize) + 72|0);
 $4 = (($3) + 36|0);
 HEAP8[$4>>0] = 0;
 STACKTOP = sp;return;
}
function _tt_size_done_bytecode($ftsize) {
 $ftsize = $ftsize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ftsize>>2]|0;
 $1 = (($0) + 100|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($ftsize) + 292|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($ftsize) + 296|0);
  HEAP32[$6>>2] = 0;
  HEAP8[$3>>0] = 0;
 }
 $7 = (($ftsize) + 244|0);
 $8 = HEAP32[$7>>2]|0;
 _ft_mem_free($2,$8);
 HEAP32[$7>>2] = 0;
 $9 = (($ftsize) + 240|0);
 HEAP32[$9>>2] = 0;
 $10 = (($ftsize) + 252|0);
 $11 = HEAP32[$10>>2]|0;
 _ft_mem_free($2,$11);
 HEAP32[$10>>2] = 0;
 $12 = (($ftsize) + 248|0);
 HEAP16[$12>>1] = 0;
 $13 = (($ftsize) + 256|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $16 = (($13) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  _ft_mem_free($14,$17);
  HEAP32[$16>>2] = 0;
  $18 = (($13) + 24|0);
  $19 = HEAP32[$18>>2]|0;
  _ft_mem_free($14,$19);
  HEAP32[$18>>2] = 0;
  $20 = (($13) + 16|0);
  $21 = HEAP32[$20>>2]|0;
  _ft_mem_free($14,$21);
  HEAP32[$20>>2] = 0;
  $22 = (($13) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  _ft_mem_free($14,$23);
  HEAP32[$22>>2] = 0;
  $24 = (($13) + 20|0);
  $25 = HEAP32[$24>>2]|0;
  _ft_mem_free($14,$25);
  HEAP32[$24>>2] = 0;
  ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;
 }
 $26 = (($ftsize) + 124|0);
 $27 = HEAP32[$26>>2]|0;
 _ft_mem_free($2,$27);
 HEAP32[$26>>2] = 0;
 $28 = (($ftsize) + 136|0);
 $29 = HEAP32[$28>>2]|0;
 _ft_mem_free($2,$29);
 $30 = (($ftsize) + 116|0);
 HEAP32[$30>>2] = 0;
 $31 = (($ftsize) + 120|0);
 HEAP32[$31>>2] = 0;
 $32 = (($ftsize) + 128|0);
 $33 = (($ftsize) + 300|0);
 HEAP8[$33>>0] = 0;
 $34 = (($ftsize) + 301|0);
 ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;HEAP32[$32+12>>2]=0|0;HEAP32[$32+16>>2]=0|0;
 HEAP8[$34>>0] = 0;
 STACKTOP = sp;return;
}
function _tt_size_reset($size) {
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($size) + 72|0);
 $1 = (($size) + 108|0);
 HEAP8[$1>>0] = 0;
 $2 = HEAP32[$size>>2]|0;
 $3 = (($size) + 44|0);
 $4 = (($size) + 12|0);
 ;HEAP32[$3+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$4+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$4+20>>2]|0;HEAP32[$3+24>>2]=HEAP32[$4+24>>2]|0;
 $5 = HEAP16[$3>>1]|0;
 $6 = $5&65535;
 $7 = ($5<<16>>16)==(0);
 if ($7) {
  $$0 = 151;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($size) + 46|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = ($9<<16>>16)==(0);
 if ($10) {
  $$0 = 151;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($2) + 160|0);
 $12 = (($11) + 16|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13 & 8;
 $15 = ($14<<16>>16)==(0);
 if ($15) {
  $61 = $5;$62 = $9;
 } else {
  $16 = $6 << 6;
  $17 = (($2) + 68|0);
  $18 = HEAP16[$17>>1]|0;
  $19 = $18&65535;
  $20 = (_FT_DivFix($16,$19)|0);
  $21 = (($size) + 48|0);
  HEAP32[$21>>2] = $20;
  $22 = HEAP16[$8>>1]|0;
  $23 = $22&65535;
  $24 = $23 << 6;
  $25 = HEAP16[$17>>1]|0;
  $26 = $25&65535;
  $27 = (_FT_DivFix($24,$26)|0);
  $28 = (($size) + 52|0);
  HEAP32[$28>>2] = $27;
  $29 = (($2) + 70|0);
  $30 = HEAP16[$29>>1]|0;
  $31 = $30 << 16 >> 16;
  $32 = (_FT_MulFix($31,$27)|0);
  $33 = (($32) + 32)|0;
  $34 = $33 & -64;
  $35 = (($size) + 56|0);
  HEAP32[$35>>2] = $34;
  $36 = (($2) + 72|0);
  $37 = HEAP16[$36>>1]|0;
  $38 = $37 << 16 >> 16;
  $39 = HEAP32[$28>>2]|0;
  $40 = (_FT_MulFix($38,$39)|0);
  $41 = (($40) + 32)|0;
  $42 = $41 & -64;
  $43 = (($size) + 60|0);
  HEAP32[$43>>2] = $42;
  $44 = (($2) + 74|0);
  $45 = HEAP16[$44>>1]|0;
  $46 = $45 << 16 >> 16;
  $47 = HEAP32[$28>>2]|0;
  $48 = (_FT_MulFix($46,$47)|0);
  $49 = (($48) + 32)|0;
  $50 = $49 & -64;
  $51 = (($size) + 64|0);
  HEAP32[$51>>2] = $50;
  $52 = (($2) + 76|0);
  $53 = HEAP16[$52>>1]|0;
  $54 = $53 << 16 >> 16;
  $55 = HEAP32[$21>>2]|0;
  $56 = (_FT_MulFix($54,$55)|0);
  $57 = (($56) + 32)|0;
  $58 = $57 & -64;
  $59 = (($size) + 68|0);
  HEAP32[$59>>2] = $58;
  $$pre = HEAP16[$3>>1]|0;
  $$pre1 = HEAP16[$8>>1]|0;
  $61 = $$pre;$62 = $$pre1;
 }
 $60 = ($61&65535)<($62&65535);
 if ($60) {
  $71 = (($size) + 52|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($size) + 88|0);
  HEAP32[$73>>2] = $72;
  $74 = (($size) + 80|0);
  HEAP16[$74>>1] = $62;
  $75 = $61&65535;
  $76 = $62&65535;
  $77 = (_FT_MulDiv($75,65536,$76)|0);
  HEAP32[$0>>2] = $77;
  $78 = (($size) + 76|0);
  HEAP32[$78>>2] = 65536;
 } else {
  $63 = (($size) + 48|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($size) + 88|0);
  HEAP32[$65>>2] = $64;
  $66 = (($size) + 80|0);
  HEAP16[$66>>1] = $61;
  HEAP32[$0>>2] = 65536;
  $67 = $62&65535;
  $68 = $61&65535;
  $69 = (_FT_MulDiv($67,65536,$68)|0);
  $70 = (($size) + 76|0);
  HEAP32[$70>>2] = $69;
 }
 $79 = (($size) + 301|0);
 HEAP8[$79>>0] = 0;
 HEAP8[$1>>0] = 1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _tt_driver_init($ttdriver) {
 $ttdriver = $ttdriver|0;
 var $$ = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_TT_New_Context($ttdriver)|0);
 $1 = ($0|0)==(0|0);
 $$ = $1 ? 153 : 0;
 STACKTOP = sp;return ($$|0);
}
function _tt_driver_done($ttdriver) {
 $ttdriver = $ttdriver|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($ttdriver) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 (_TT_Done_Context($1)|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_slot_init($slot) {
 $slot = $slot|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($slot) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (_FT_GlyphLoader_CreateExtra($2)|0);
 STACKTOP = sp;return ($3|0);
}
function _tt_face_load_loca($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dist$0$lcssa = 0, $dist$03 = 0, $dist$1 = 0, $dist$2 = 0, $entry$0$lcssa = 0, $entry$02 = 0, $error$0 = 0, $or$cond = 0, $or$cond1 = 0;
 var $shift$0 = 0, $table_len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $table_len = sp;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 704|0);
 $3 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1735162214,$stream,$2)|0);
 if ((($3|0) == 142)) {
  HEAP32[$2>>2] = 0;
 } else if (!((($3|0) == 0))) {
  $error$0 = $3;
  STACKTOP = sp;return ($error$0|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$4 & 511]($face,1819239265,$stream,$table_len)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  $error$0 = 144;
  STACKTOP = sp;return ($error$0|0);
 }
 $7 = (($face) + 210|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = ($8<<16>>16)==(0);
 $10 = HEAP32[$table_len>>2]|0;
 do {
  if ($9) {
   $14 = ($10>>>0)>(131071);
   if ($14) {
    $error$0 = 8;
    STACKTOP = sp;return ($error$0|0);
   } else {
    $15 = $10 >>> 1;
    $16 = (($face) + 732|0);
    HEAP32[$16>>2] = $15;
    $22 = $15;$shift$0 = 1;
    break;
   }
  } else {
   $11 = ($10>>>0)>(262143);
   if ($11) {
    $error$0 = 8;
    STACKTOP = sp;return ($error$0|0);
   } else {
    $12 = $10 >>> 2;
    $13 = (($face) + 732|0);
    HEAP32[$13>>2] = $12;
    $22 = $12;$shift$0 = 2;
    break;
   }
  }
 } while(0);
 $17 = (($face) + 732|0);
 $18 = (($face) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + 1)|0;
 $21 = ($22|0)==($20|0);
 $23 = ($22>>>0)>($19>>>0);
 $or$cond = $21 | $23;
 do {
  if ($or$cond) {
   $48 = $10;
  } else {
   $24 = $20 << $shift$0;
   $25 = (($face) + 156|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($face) + 152|0);
   $28 = HEAP16[$27>>1]|0;
   $29 = $28&65535;
   $30 = (($26) + ($29<<4)|0);
   $31 = (_FT_Stream_Pos($stream)|0);
   $32 = ($28<<16>>16)==(0);
   if ($32) {
    $dist$0$lcssa = 2147483647;$entry$0$lcssa = $26;
   } else {
    $dist$03 = 2147483647;$entry$02 = $26;
    while(1) {
     $33 = (($entry$02) + 8|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) - ($31))|0;
     $36 = ($35|0)>(0);
     $37 = ($35|0)<($dist$03|0);
     $or$cond1 = $36 & $37;
     $dist$1 = $or$cond1 ? $35 : $dist$03;
     $38 = (($entry$02) + 16|0);
     $39 = ($38>>>0)<($30>>>0);
     if ($39) {
      $dist$03 = $dist$1;$entry$02 = $38;
     } else {
      $dist$0$lcssa = $dist$1;$entry$0$lcssa = $38;
      break;
     }
    }
   }
   $40 = ($entry$0$lcssa|0)==($30|0);
   if ($40) {
    $41 = (($stream) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) - ($31))|0;
    $dist$2 = $43;
   } else {
    $dist$2 = $dist$0$lcssa;
   }
   $44 = ($24|0)>($dist$2|0);
   if ($44) {
    $$pre = HEAP32[$table_len>>2]|0;
    $48 = $$pre;
    break;
   } else {
    $45 = HEAP32[$18>>2]|0;
    $46 = (($45) + 1)|0;
    HEAP32[$17>>2] = $46;
    HEAP32[$table_len>>2] = $24;
    $48 = $24;
    break;
   }
  }
 } while(0);
 $47 = (($face) + 736|0);
 $49 = (_FT_Stream_ExtractFrame($stream,$48,$47)|0);
 $error$0 = $49;
 STACKTOP = sp;return ($error$0|0);
}
function _tt_face_get_location($face,$gindex,$asize) {
 $face = $face|0;
 $gindex = $gindex|0;
 $asize = $asize|0;
 var $$0 = 0, $$pos2$1$ = 0, $$sum1011 = 0, $$sum1213 = 0, $$sum1415 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum20 = 0, $$sum34 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $pos1$0 = 0, $pos2$0 = 0, $pos2$1 = 0, $pos2$1$ = 0, $storemerge = 0, $storemerge1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 732|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($gindex>>>0);
 do {
  if ($2) {
   $3 = (($face) + 210|0);
   $4 = HEAP16[$3>>1]|0;
   $5 = ($4<<16>>16)==(0);
   $6 = (($face) + 736|0);
   $7 = HEAP32[$6>>2]|0;
   if (!($5)) {
    $8 = $gindex << 2;
    $9 = $1 << 2;
    $10 = (($7) + ($8)|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11&255;
    $13 = $12 << 24;
    $$sum1011 = $8 | 1;
    $14 = (($7) + ($$sum1011)|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = $15&255;
    $17 = $16 << 16;
    $18 = $17 | $13;
    $$sum1213 = $8 | 2;
    $19 = (($7) + ($$sum1213)|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    $22 = $21 << 8;
    $23 = $18 | $22;
    $$sum1415 = $8 | 3;
    $24 = (($7) + ($$sum1415)|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = $25&255;
    $27 = $23 | $26;
    $$sum16 = (($8) + 8)|0;
    $28 = ($$sum16|0)>($9|0);
    if ($28) {
     $pos1$0 = $27;$pos2$1 = $27;
     break;
    }
    $$sum17 = (($8) + 4)|0;
    $29 = (($7) + ($$sum17)|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = $30&255;
    $32 = $31 << 24;
    $$sum18 = (($8) + 5)|0;
    $33 = (($7) + ($$sum18)|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = $34&255;
    $36 = $35 << 16;
    $37 = $36 | $32;
    $$sum19 = (($8) + 6)|0;
    $38 = (($7) + ($$sum19)|0);
    $39 = HEAP8[$38>>0]|0;
    $40 = $39&255;
    $41 = $40 << 8;
    $42 = $37 | $41;
    $$sum20 = (($8) + 7)|0;
    $43 = (($7) + ($$sum20)|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = $44&255;
    $46 = $42 | $45;
    $pos1$0 = $27;$pos2$1 = $46;
    break;
   }
   $47 = $gindex << 1;
   $48 = $1 << 1;
   $49 = (($7) + ($47)|0);
   $50 = HEAP8[$49>>0]|0;
   $51 = $50&255;
   $52 = $51 << 8;
   $$sum34 = $47 | 1;
   $53 = (($7) + ($$sum34)|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = $54&255;
   $56 = $52 | $55;
   $$sum5 = (($47) + 4)|0;
   $57 = ($$sum5|0)>($48|0);
   if ($57) {
    $pos2$0 = $56;
   } else {
    $$sum6 = (($47) + 2)|0;
    $58 = (($7) + ($$sum6)|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    $61 = $60 << 8;
    $$sum7 = (($47) + 3)|0;
    $62 = (($7) + ($$sum7)|0);
    $63 = HEAP8[$62>>0]|0;
    $64 = $63&255;
    $65 = $61 | $64;
    $pos2$0 = $65;
   }
   $66 = $56 << 1;
   $67 = $pos2$0 << 1;
   $pos1$0 = $66;$pos2$1 = $67;
  } else {
   $pos1$0 = 0;$pos2$1 = 0;
  }
 } while(0);
 $68 = (($face) + 704|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($pos1$0>>>0)<($69>>>0);
 if (!($70)) {
  $$0 = 0;$storemerge1 = 0;
  HEAP32[$asize>>2] = $storemerge1;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = ($pos2$1>>>0)<($69>>>0);
 $pos2$1$ = $71 ? $pos2$1 : $69;
 $72 = ($pos2$1$>>>0)<($pos1$0>>>0);
 $$pos2$1$ = $72 ? $69 : $pos2$1$;
 $storemerge = (($$pos2$1$) - ($pos1$0))|0;
 $$0 = $pos1$0;$storemerge1 = $storemerge;
 HEAP32[$asize>>2] = $storemerge1;
 STACKTOP = sp;return ($$0|0);
}
function _tt_face_done_loca($face) {
 $face = $face|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 736|0);
 _FT_Stream_ReleaseFrame($1,$2);
 $3 = (($face) + 732|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_face_load_cvt($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cur$01 = 0, $error = 0, $table_len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp + 4|0;
 $table_len = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 508|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiiii[$3 & 511]($face,1668707360,$stream,$table_len)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($face) + 668|0);
  HEAP32[$6>>2] = 0;
  $7 = (($face) + 672|0);
  HEAP32[$7>>2] = 0;
  HEAP32[$error>>2] = 0;
  $30 = 0;
  STACKTOP = sp;return ($30|0);
 }
 $8 = HEAP32[$table_len>>2]|0;
 $9 = $8 >>> 1;
 $10 = (($face) + 668|0);
 HEAP32[$10>>2] = $9;
 $11 = (_ft_mem_realloc($1,2,0,$9,0,$error)|0);
 $12 = (($face) + 672|0);
 HEAP32[$12>>2] = $11;
 $13 = HEAP32[$error>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $30 = $13;
  STACKTOP = sp;return ($30|0);
 }
 $15 = HEAP32[$10>>2]|0;
 $16 = $15 << 1;
 $17 = (_FT_Stream_EnterFrame($stream,$16)|0);
 HEAP32[$error>>2] = $17;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $30 = $17;
  STACKTOP = sp;return ($30|0);
 }
 $19 = HEAP32[$12>>2]|0;
 $20 = HEAP32[$10>>2]|0;
 $21 = (($19) + ($20<<1)|0);
 $22 = ($20|0)>(0);
 if ($22) {
  $cur$01 = $19;
  while(1) {
   $23 = (_FT_Stream_GetUShort($stream)|0);
   HEAP16[$cur$01>>1] = $23;
   $24 = (($cur$01) + 2|0);
   $25 = ($24>>>0)<($21>>>0);
   if ($25) {
    $cur$01 = $24;
   } else {
    break;
   }
  }
 }
 _FT_Stream_ExitFrame($stream);
 $26 = (($face) + 708|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  $$pre = HEAP32[$error>>2]|0;
  $30 = $$pre;
  STACKTOP = sp;return ($30|0);
 } else {
  $29 = (_tt_face_vary_cvt($face,$stream)|0);
  HEAP32[$error>>2] = $29;
  $30 = $29;
  STACKTOP = sp;return ($30|0);
 }
 return 0|0;
}
function _tt_face_load_fpgm($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, $table_len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $table_len = sp;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1718642541,$stream,$table_len)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $6 = HEAP32[$table_len>>2]|0;
  $7 = (($face) + 652|0);
  HEAP32[$7>>2] = $6;
  $8 = (($face) + 656|0);
  $9 = (_FT_Stream_ExtractFrame($stream,$6,$8)|0);
  $error$0 = $9;
  STACKTOP = sp;return ($error$0|0);
 } else {
  $4 = (($face) + 656|0);
  HEAP32[$4>>2] = 0;
  $5 = (($face) + 652|0);
  HEAP32[$5>>2] = 0;
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 return 0|0;
}
function _tt_face_load_prep($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, $table_len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $table_len = sp;
 $0 = (($face) + 508|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iiiii[$1 & 511]($face,1886545264,$stream,$table_len)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $6 = HEAP32[$table_len>>2]|0;
  $7 = (($face) + 660|0);
  HEAP32[$7>>2] = $6;
  $8 = (($face) + 664|0);
  $9 = (_FT_Stream_ExtractFrame($stream,$6,$8)|0);
  $error$0 = $9;
  STACKTOP = sp;return ($error$0|0);
 } else {
  $4 = (($face) + 664|0);
  HEAP32[$4>>2] = 0;
  $5 = (($face) + 660|0);
  HEAP32[$5>>2] = 0;
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 return 0|0;
}
function _tt_face_load_hdmx($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $error = 0, $nn$0$lcssa = 0, $nn$02 = 0, $or$cond = 0, $or$cond1 = 0, $p$03 = 0, $table_size = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp + 4|0;
 $table_size = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 508|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiiii[$3 & 511]($face,1751412088,$stream,$table_size)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$table_size>>2]|0;
 $7 = ($6>>>0)<(8);
 if ($7) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($face) + 740|0);
 $9 = (_FT_Stream_ExtractFrame($stream,$6,$8)|0);
 HEAP32[$error>>2] = $9;
 $10 = ($9|0)==(0);
 do {
  if ($10) {
   $11 = HEAP32[$8>>2]|0;
   $12 = HEAP32[$table_size>>2]|0;
   $13 = (($11) + ($12)|0);
   $14 = HEAP8[$11>>0]|0;
   $15 = $14&255;
   $16 = $15 << 8;
   $17 = (($11) + 1|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = $18&255;
   $20 = $16 | $19;
   $21 = (($11) + 2|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = $22&255;
   $24 = $23 << 8;
   $25 = (($11) + 3|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = $26&255;
   $28 = $24 | $27;
   $29 = (($11) + 4|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = $30&255;
   $32 = $31 << 24;
   $33 = (($11) + 5|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34&255;
   $36 = $35 << 16;
   $37 = $36 | $32;
   $38 = (($11) + 6|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = $39&255;
   $41 = $40 << 8;
   $42 = $37 | $41;
   $43 = (($11) + 7|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = $44&255;
   $46 = $42 | $45;
   $47 = ($46>>>0)>(4294901759);
   $48 = $46 & 65535;
   $$ = $47 ? $48 : $46;
   $49 = ($20|0)!=(0);
   $50 = ($28>>>0)>(255);
   $or$cond = $49 | $50;
   $51 = ($$>>>0)>(65537);
   $or$cond1 = $or$cond | $51;
   if ($or$cond1) {
    HEAP32[$error>>2] = 3;
   } else {
    $52 = (_ft_mem_realloc($1,1,0,$28,0,$error)|0);
    $53 = (($face) + 756|0);
    HEAP32[$53>>2] = $52;
    $54 = HEAP32[$error>>2]|0;
    $55 = ($54|0)==(0);
    if ($55) {
     $56 = (($11) + 8|0);
     $57 = ($28|0)==(0);
     L12: do {
      if ($57) {
       $nn$0$lcssa = 0;
      } else {
       $nn$02 = 0;$p$03 = $56;
       while(1) {
        $58 = (($p$03) + ($$)|0);
        $59 = ($58>>>0)>($13>>>0);
        if ($59) {
         $nn$0$lcssa = $nn$02;
         break L12;
        }
        $60 = HEAP8[$p$03>>0]|0;
        $61 = HEAP32[$53>>2]|0;
        $62 = (($61) + ($nn$02)|0);
        HEAP8[$62>>0] = $60;
        $63 = (($nn$02) + 1)|0;
        $64 = ($63>>>0)<($28>>>0);
        if ($64) {
         $nn$02 = $63;$p$03 = $58;
        } else {
         $nn$0$lcssa = $63;
         break;
        }
       }
      }
     } while(0);
     $65 = (($face) + 748|0);
     HEAP32[$65>>2] = $nn$0$lcssa;
     $66 = HEAP32[$table_size>>2]|0;
     $67 = (($face) + 744|0);
     HEAP32[$67>>2] = $66;
     $68 = (($face) + 752|0);
     HEAP32[$68>>2] = $$;
     break;
    }
   }
   _FT_Stream_ReleaseFrame($stream,$8);
   $70 = (($face) + 744|0);
   HEAP32[$70>>2] = 0;
  }
 } while(0);
 $69 = HEAP32[$error>>2]|0;
 $$0 = $69;
 STACKTOP = sp;return ($$0|0);
}
function _tt_face_free_hdmx($face) {
 $face = $face|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($face) + 756|0);
 $5 = HEAP32[$4>>2]|0;
 _ft_mem_free($3,$5);
 HEAP32[$4>>2] = 0;
 $6 = (($face) + 740|0);
 _FT_Stream_ReleaseFrame($1,$6);
 STACKTOP = sp;return;
}
function _tt_face_get_device_metrics($face,$ppem,$gindex) {
 $face = $face|0;
 $ppem = $ppem|0;
 $gindex = $gindex|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $nn$03 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 752|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 740|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($face) + 748|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $7 = (($face) + 756|0);
 $8 = HEAP32[$7>>2]|0;
 $nn$03 = 0;
 while(1) {
  $11 = (($8) + ($nn$03)|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = $12&255;
  $14 = ($13|0)==($ppem|0);
  $10 = (($nn$03) + 1)|0;
  if ($14) {
   break;
  }
  $9 = ($10>>>0)<($5>>>0);
  if ($9) {
   $nn$03 = $10;
  } else {
   $result$0 = 0;
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($result$0|0);
 }
 $15 = (($gindex) + 2)|0;
 $16 = ($15>>>0)<($1>>>0);
 if (!($16)) {
  $result$0 = 0;
  STACKTOP = sp;return ($result$0|0);
 }
 $17 = Math_imul($nn$03, $1)|0;
 $$sum = (($gindex) + 10)|0;
 $$sum1 = (($$sum) + ($17))|0;
 $18 = (($3) + ($$sum1)|0);
 $result$0 = $18;
 STACKTOP = sp;return ($result$0|0);
}
function _TT_Get_HMetrics($face,$idx,$lsb,$aw) {
 $face = $face|0;
 $idx = $idx|0;
 $lsb = $lsb|0;
 $aw = $aw|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 532|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 156|0);
 $3 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_iiiiii[$3 & 255]($face,0,$idx,$lsb,$aw)|0);
 STACKTOP = sp;return;
}
function _TT_Get_VMetrics($face,$idx,$tsb,$ah) {
 $face = $face|0;
 $idx = $idx|0;
 $tsb = $tsb|0;
 $ah = $ah|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 296|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  HEAP16[$tsb>>1] = 0;
  $7 = (($face) + 68|0);
  $8 = HEAP16[$7>>1]|0;
  HEAP16[$ah>>1] = $8;
  STACKTOP = sp;return;
 } else {
  $3 = (($face) + 532|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 156|0);
  $6 = HEAP32[$5>>2]|0;
  (FUNCTION_TABLE_iiiiii[$6 & 255]($face,1,$idx,$tsb,$ah)|0);
  STACKTOP = sp;return;
 }
}
function _TT_Init_Glyph_Loading($face) {
 $face = $face|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($face) + 512|0);
 HEAP32[$0>>2] = 293;
 $1 = (($face) + 520|0);
 HEAP32[$1>>2] = 3438;
 $2 = (($face) + 524|0);
 HEAP32[$2>>2] = 3439;
 $3 = (($face) + 528|0);
 HEAP32[$3>>2] = 3440;
 $4 = (($face) + 516|0);
 HEAP32[$4>>2] = 3749;
 STACKTOP = sp;return;
}
function _TT_Access_Glyph_Frame($loader,$glyph_index,$offset,$byte_count) {
 $loader = $loader|0;
 $glyph_index = $glyph_index|0;
 $offset = $offset|0;
 $byte_count = $byte_count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($loader) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_FT_Stream_Seek($1,$offset)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_FT_Stream_EnterFrame($1,$byte_count)|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($1) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($loader) + 200|0);
 HEAP32[$8>>2] = $7;
 $9 = (($1) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($loader) + 204|0);
 HEAP32[$11>>2] = $10;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _TT_Load_Glyph_Header($loader) {
 $loader = $loader|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($loader) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($loader) + 204|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 10|0);
 $5 = ($4>>>0)>($3>>>0);
 if ($5) {
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP8[$1>>0]|0;
 $7 = $6 << 24 >> 24;
 $8 = $7 << 8;
 $9 = (($1) + 1|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = $8 | $11;
 $13 = $12&65535;
 $14 = (($loader) + 32|0);
 HEAP16[$14>>1] = $13;
 $15 = (($1) + 2|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16 << 24 >> 24;
 $18 = $17 << 8;
 $19 = (($1) + 3|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = $20&255;
 $22 = $18 | $21;
 $23 = (($loader) + 36|0);
 HEAP32[$23>>2] = $22;
 $24 = (($1) + 4|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25 << 24 >> 24;
 $27 = $26 << 8;
 $28 = (($1) + 5|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $31 = $27 | $30;
 $32 = (($loader) + 40|0);
 HEAP32[$32>>2] = $31;
 $33 = (($1) + 6|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34 << 24 >> 24;
 $36 = $35 << 8;
 $37 = (($1) + 7|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = $38&255;
 $40 = $36 | $39;
 $41 = (($loader) + 44|0);
 HEAP32[$41>>2] = $40;
 $42 = (($1) + 8|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43 << 24 >> 24;
 $45 = $44 << 8;
 $46 = (($1) + 9|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = $47&255;
 $49 = $45 | $48;
 $50 = (($loader) + 48|0);
 HEAP32[$50>>2] = $49;
 HEAP32[$0>>2] = $4;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _TT_Load_Simple_Glyph($load) {
 $load = $load|0;
 var $$ = 0, $$5 = 0, $$pn = 0, $$pn1 = 0, $$pn12 = 0, $$pn12$in = 0, $$pn3 = 0, $$pre = 0, $$pre52 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cont$0 = 0, $cont$1 = 0, $error$0 = 0, $flag$0$be = 0, $flag$035 = 0, $flag$222 = 0, $flag$316 = 0, $n_points$07 = 0, $n_points$0811 = 0, $p$0 = 0, $p$0$sum = 0;
 var $p$1$be = 0, $p$1$lcssa = 0, $p$136 = 0, $p$223 = 0, $p$3 = 0, $p$4$lcssa = 0, $p$417 = 0, $p$5 = 0, $prev_cont$0 = 0, $scevgep$sum = 0, $scevgep47 = 0, $sext = 0, $sext4 = 0, $vec$020 = 0, $vec$114 = 0, $x$021 = 0, $x$115 = 0, $y$0 = 0, $y1$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($load) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($load) + 204|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($load) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($load) + 32|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 << 16 >> 16;
 $9 = HEAP32[$load>>2]|0;
 $10 = ($7<<16>>16)==(0);
 if ($10) {
 } else {
  $11 = (($5) + 20|0);
  $12 = HEAP16[$11>>1]|0;
  $13 = $12 << 16 >> 16;
  $14 = (($5) + 56|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = $15 << 16 >> 16;
  $17 = (($13) + ($8))|0;
  $18 = (($17) + ($16))|0;
  $19 = (($5) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($18>>>0)>($20>>>0);
  if ($21) {
   $22 = (_FT_GlyphLoader_CheckPoints($5,0,$8)|0);
   $23 = ($22|0)==(0);
   if (!($23)) {
    $error$0 = $22;
    STACKTOP = sp;return ($error$0|0);
   }
  }
  $24 = ($7<<16>>16)>(4094);
  if ($24) {
   $error$0 = 20;
   STACKTOP = sp;return ($error$0|0);
  }
 }
 $$pn12$in = (($5) + 68|0);
 $$pn12 = HEAP32[$$pn12$in>>2]|0;
 $25 = (($$pn12) + ($8<<1)|0);
 $26 = $8 << 1;
 $27 = (($26) + 2)|0;
 $28 = (($1) + ($27)|0);
 $29 = ($28>>>0)>($3>>>0);
 if ($29) {
  $error$0 = 20;
  STACKTOP = sp;return ($error$0|0);
 }
 $30 = HEAP8[$1>>0]|0;
 $31 = $30&255;
 $32 = $31 << 8;
 $33 = (($1) + 1|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34&255;
 $36 = $32 | $35;
 $37 = ($7<<16>>16)>(0);
 if ($37) {
  $38 = $36&65535;
  HEAP16[$$pn12>>1] = $38;
  $$pn = $$pn12;$$pn3 = $1;$prev_cont$0 = $36;
 } else {
  $$pn = $$pn12;$$pn3 = $1;$prev_cont$0 = $36;
 }
 while(1) {
  $p$0 = (($$pn3) + 2|0);
  $cont$0 = (($$pn) + 2|0);
  $39 = ($cont$0>>>0)<($25>>>0);
  if (!($39)) {
   break;
  }
  $40 = HEAP8[$p$0>>0]|0;
  $41 = $40&255;
  $42 = $41 << 8;
  $43 = (($$pn3) + 3|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = $42 | $45;
  $47 = $46&65535;
  HEAP16[$cont$0>>1] = $47;
  $sext = $46 << 16;
  $sext4 = $prev_cont$0 << 16;
  $48 = ($sext|0)>($sext4|0);
  if ($48) {
   $$pn = $cont$0;$$pn3 = $p$0;$prev_cont$0 = $46;
  } else {
   $error$0 = 8;
   label = 52;
   break;
  }
 }
 if ((label|0) == 52) {
  STACKTOP = sp;return ($error$0|0);
 }
 do {
  if ($37) {
   $49 = HEAP16[$$pn>>1]|0;
   $50 = $49 << 16 >> 16;
   $51 = (($50) + 1)|0;
   $52 = ($51|0)<(0);
   if ($52) {
    $error$0 = 20;
    STACKTOP = sp;return ($error$0|0);
   } else {
    $53 = (($50) + 5)|0;
    $54 = ($53|0)==(0);
    if ($54) {
     $n_points$0811 = $51;
     break;
    } else {
     $62 = $53;$n_points$07 = $51;
     label = 14;
     break;
    }
   }
  } else {
   $62 = 4;$n_points$07 = 0;
   label = 14;
  }
 } while(0);
 if ((label|0) == 14) {
  $55 = (($5) + 22|0);
  $56 = HEAP16[$55>>1]|0;
  $57 = $56 << 16 >> 16;
  $58 = (($5) + 58|0);
  $59 = HEAP16[$58>>1]|0;
  $60 = $59 << 16 >> 16;
  $61 = (($57) + ($62))|0;
  $63 = (($61) + ($60))|0;
  $64 = (($5) + 4|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($63>>>0)>($65>>>0);
  if ($66) {
   $67 = (_FT_GlyphLoader_CheckPoints($5,$62,0)|0);
   $68 = ($67|0)==(0);
   if ($68) {
    $n_points$0811 = $n_points$07;
   } else {
    $error$0 = $67;
    STACKTOP = sp;return ($error$0|0);
   }
  } else {
   $n_points$0811 = $n_points$07;
  }
 }
 $69 = HEAP32[$$pn12$in>>2]|0;
 $$pn1 = $69;
 while(1) {
  $cont$1 = (($$pn1) + 2|0);
  $70 = ($cont$1>>>0)<($25>>>0);
  if (!($70)) {
   break;
  }
  $71 = HEAP16[$$pn1>>1]|0;
  $72 = HEAP16[$cont$1>>1]|0;
  $73 = ($71<<16>>16)<($72<<16>>16);
  if ($73) {
   $$pn1 = $cont$1;
  } else {
   $error$0 = 20;
   label = 52;
   break;
  }
 }
 if ((label|0) == 52) {
  STACKTOP = sp;return ($error$0|0);
 }
 $74 = (($load) + 8|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($75) + 140|0);
 HEAP32[$76>>2] = 0;
 $77 = (($75) + 136|0);
 HEAP32[$77>>2] = 0;
 $78 = (($$pn3) + 4|0);
 $79 = ($78>>>0)>($3>>>0);
 if ($79) {
  $error$0 = 20;
  STACKTOP = sp;return ($error$0|0);
 }
 $80 = HEAP8[$p$0>>0]|0;
 $81 = $80&255;
 $82 = $81 << 8;
 $83 = (($$pn3) + 3|0);
 $84 = HEAP8[$83>>0]|0;
 $85 = $84&255;
 $86 = $82 | $85;
 $87 = (($9) + 260|0);
 $88 = (($87) + 26|0);
 $89 = HEAP16[$88>>1]|0;
 $90 = $89&65535;
 $91 = ($86>>>0)>($90>>>0);
 if ($91) {
  $error$0 = 22;
  STACKTOP = sp;return ($error$0|0);
 }
 $92 = $3;
 $93 = $78;
 $94 = (($92) - ($93))|0;
 $95 = ($94|0)<($86|0);
 if ($95) {
  $error$0 = 22;
  STACKTOP = sp;return ($error$0|0);
 }
 $96 = (($load) + 16|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = $97 & 2;
 $99 = ($98|0)==(0);
 if ($99) {
  $100 = HEAP32[$74>>2]|0;
  $101 = (($100) + 140|0);
  HEAP32[$101>>2] = $86;
  $102 = (($load) + 160|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (($103) + 392|0);
  $105 = HEAP32[$104>>2]|0;
  $106 = (($100) + 136|0);
  HEAP32[$106>>2] = $105;
  $107 = HEAP32[$102>>2]|0;
  $108 = (($107) + 392|0);
  $109 = HEAP32[$108>>2]|0;
  _memcpy(($109|0),($78|0),($86|0))|0;
 }
 $p$0$sum = (($86) + 4)|0;
 $110 = (($$pn3) + ($p$0$sum)|0);
 $111 = (($5) + 64|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = (($112) + ($n_points$0811)|0);
 $114 = ($n_points$0811|0)>(0);
 do {
  if ($114) {
   $flag$035 = $112;$p$136 = $110;
   while(1) {
    $115 = (($p$136) + 1|0);
    $116 = ($115>>>0)>($3>>>0);
    if ($116) {
     $error$0 = 20;
     label = 52;
     break;
    }
    $117 = HEAP8[$p$136>>0]|0;
    $118 = (($flag$035) + 1|0);
    HEAP8[$flag$035>>0] = $117;
    $119 = $117 & 8;
    $120 = ($119<<24>>24)==(0);
    if ($120) {
     $flag$0$be = $118;$p$1$be = $115;
    } else {
     $122 = (($p$136) + 2|0);
     $123 = ($122>>>0)>($3>>>0);
     if ($123) {
      $error$0 = 20;
      label = 52;
      break;
     }
     $124 = HEAP8[$115>>0]|0;
     $125 = $124&255;
     $$sum2 = (($125) + 1)|0;
     $126 = (($flag$035) + ($$sum2)|0);
     $127 = ($126>>>0)>($113>>>0);
     if ($127) {
      $error$0 = 20;
      label = 52;
      break;
     }
     $128 = ($124<<24>>24)==(0);
     if ($128) {
      $flag$0$be = $118;$p$1$be = $122;
     } else {
      $129 = (($124) + -1)<<24>>24;
      $130 = $129&255;
      $131 = (($130) + 1)|0;
      _memset(($118|0),($117|0),($131|0))|0;
      $scevgep$sum = (($130) + 2)|0;
      $scevgep47 = (($flag$035) + ($scevgep$sum)|0);
      $flag$0$be = $scevgep47;$p$1$be = $122;
     }
    }
    $121 = ($flag$0$be>>>0)<($113>>>0);
    if ($121) {
     $flag$035 = $flag$0$be;$p$136 = $p$1$be;
    } else {
     label = 32;
     break;
    }
   }
   if ((label|0) == 32) {
    $$pre = HEAP32[$111>>2]|0;
    $198 = $$pre;$p$1$lcssa = $p$1$be;
    break;
   }
   else if ((label|0) == 52) {
    STACKTOP = sp;return ($error$0|0);
   }
  } else {
   $198 = $112;$p$1$lcssa = $110;
  }
 } while(0);
 $132 = (($5) + 60|0);
 $133 = HEAP32[$132>>2]|0;
 $134 = (($133) + ($n_points$0811<<3)|0);
 $135 = ($p$1$lcssa>>>0)>($3>>>0);
 if ($135) {
  $error$0 = 20;
  STACKTOP = sp;return ($error$0|0);
 }
 L68: do {
  if ($114) {
   $flag$222 = $198;$p$223 = $p$1$lcssa;$vec$020 = $133;$x$021 = 0;
   while(1) {
    $136 = HEAP8[$flag$222>>0]|0;
    $137 = $136&255;
    $138 = $137 & 2;
    $139 = ($138|0)==(0);
    if ($139) {
     $147 = $137 & 16;
     $148 = ($147|0)==(0);
     if ($148) {
      $149 = (($p$223) + 2|0);
      $150 = ($149>>>0)>($3>>>0);
      if ($150) {
       $error$0 = 20;
       label = 52;
       break;
      }
      $151 = HEAP8[$p$223>>0]|0;
      $152 = $151 << 24 >> 24;
      $153 = $152 << 8;
      $154 = (($p$223) + 1|0);
      $155 = HEAP8[$154>>0]|0;
      $156 = $155&255;
      $157 = $153 | $156;
      $p$3 = $149;$y$0 = $157;
     } else {
      $p$3 = $p$223;$y$0 = 0;
     }
    } else {
     $140 = (($p$223) + 1|0);
     $141 = ($140>>>0)>($3>>>0);
     if ($141) {
      $error$0 = 20;
      label = 52;
      break;
     }
     $142 = HEAP8[$p$223>>0]|0;
     $143 = $142&255;
     $144 = $137 & 16;
     $145 = ($144|0)==(0);
     $146 = (0 - ($143))|0;
     $$ = $145 ? $146 : $143;
     $p$3 = $140;$y$0 = $$;
    }
    $158 = (($y$0) + ($x$021))|0;
    HEAP32[$vec$020>>2] = $158;
    $159 = $137 & 237;
    $160 = $159&255;
    HEAP8[$flag$222>>0] = $160;
    $161 = (($vec$020) + 8|0);
    $162 = (($flag$222) + 1|0);
    $163 = ($161>>>0)<($134>>>0);
    if ($163) {
     $flag$222 = $162;$p$223 = $p$3;$vec$020 = $161;$x$021 = $158;
    } else {
     label = 42;
     break;
    }
   }
   if ((label|0) == 42) {
    $$pre52 = HEAP32[$132>>2]|0;
    $164 = (($$pre52) + ($n_points$0811<<3)|0);
    if (!($114)) {
     $p$4$lcssa = $p$3;
     break;
    }
    $165 = HEAP32[$111>>2]|0;
    $flag$316 = $165;$p$417 = $p$3;$vec$114 = $$pre52;$x$115 = 0;
    while(1) {
     $166 = HEAP8[$flag$316>>0]|0;
     $167 = $166&255;
     $168 = $167 & 4;
     $169 = ($168|0)==(0);
     if ($169) {
      $177 = $167 & 32;
      $178 = ($177|0)==(0);
      if ($178) {
       $179 = (($p$417) + 2|0);
       $180 = ($179>>>0)>($3>>>0);
       if ($180) {
        $error$0 = 20;
        label = 52;
        break;
       }
       $181 = HEAP8[$p$417>>0]|0;
       $182 = $181 << 24 >> 24;
       $183 = $182 << 8;
       $184 = (($p$417) + 1|0);
       $185 = HEAP8[$184>>0]|0;
       $186 = $185&255;
       $187 = $183 | $186;
       $p$5 = $179;$y1$0 = $187;
      } else {
       $p$5 = $p$417;$y1$0 = 0;
      }
     } else {
      $170 = (($p$417) + 1|0);
      $171 = ($170>>>0)>($3>>>0);
      if ($171) {
       $error$0 = 20;
       label = 52;
       break;
      }
      $172 = HEAP8[$p$417>>0]|0;
      $173 = $172&255;
      $174 = $167 & 32;
      $175 = ($174|0)==(0);
      $176 = (0 - ($173))|0;
      $$5 = $175 ? $176 : $173;
      $p$5 = $170;$y1$0 = $$5;
     }
     $188 = (($y1$0) + ($x$115))|0;
     $189 = (($vec$114) + 4|0);
     HEAP32[$189>>2] = $188;
     $190 = $167 & 1;
     $191 = $190&255;
     HEAP8[$flag$316>>0] = $191;
     $192 = (($vec$114) + 8|0);
     $193 = (($flag$316) + 1|0);
     $194 = ($192>>>0)<($164>>>0);
     if ($194) {
      $flag$316 = $193;$p$417 = $p$5;$vec$114 = $192;$x$115 = $188;
     } else {
      $p$4$lcssa = $p$5;
      break L68;
     }
    }
    if ((label|0) == 52) {
     STACKTOP = sp;return ($error$0|0);
    }
   }
   else if ((label|0) == 52) {
    STACKTOP = sp;return ($error$0|0);
   }
  } else {
   $p$4$lcssa = $p$1$lcssa;
  }
 } while(0);
 $195 = $n_points$0811&65535;
 $196 = (($5) + 58|0);
 HEAP16[$196>>1] = $195;
 $197 = (($5) + 56|0);
 HEAP16[$197>>1] = $7;
 HEAP32[$0>>2] = $p$4$lcssa;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _TT_Load_Composite_Glyph($loader) {
 $loader = $loader|0;
 var $$ = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$1 = 0, $error$0 = 0, $num_subglyphs$0 = 0, $p$0 = 0, $p$1 = 0, $p$2 = 0, $storemerge = 0, $xx$0 = 0;
 var $xy$0 = 0, $yx$0 = 0, $yy$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($loader) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($loader) + 204|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($loader) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 88|0);
 $num_subglyphs$0 = 0;$p$0 = $1;
 while(1) {
  $7 = (($num_subglyphs$0) + 1)|0;
  $8 = (_FT_GlyphLoader_CheckSubGlyphs($5,$7)|0);
  $9 = ($8|0)==(0);
  if (!($9)) {
   $error$0 = $8;
   label = 21;
   break;
  }
  $10 = (($p$0) + 4|0);
  $11 = ($10>>>0)>($3>>>0);
  if ($11) {
   $error$0 = 21;
   label = 21;
   break;
  }
  $12 = HEAP32[$6>>2]|0;
  $13 = ((($12) + ($num_subglyphs$0<<5)|0) + 12|0);
  HEAP32[$13>>2] = 0;
  $14 = ((($12) + ($num_subglyphs$0<<5)|0) + 8|0);
  HEAP32[$14>>2] = 0;
  $15 = HEAP8[$p$0>>0]|0;
  $16 = $15&255;
  $17 = $16 << 8;
  $18 = (($p$0) + 1|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19&255;
  $21 = $17 | $20;
  $22 = $21&65535;
  $23 = ((($12) + ($num_subglyphs$0<<5)|0) + 4|0);
  HEAP16[$23>>1] = $22;
  $24 = (($p$0) + 2|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25&255;
  $27 = $26 << 8;
  $28 = (($p$0) + 3|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $27 | $30;
  $32 = (($12) + ($num_subglyphs$0<<5)|0);
  HEAP32[$32>>2] = $31;
  $33 = $22 & 1;
  $34 = ($33<<16>>16)==(0);
  $$ = $34 ? 2 : 4;
  $35 = $20 & 8;
  $36 = ($35|0)==(0);
  do {
   if ($36) {
    $38 = $20 & 64;
    $39 = ($38|0)==(0);
    if ($39) {
     $41 = $20 >>> 4;
     $42 = $41 & 8;
     $43 = $42 | $$;
     $count$1 = $43;
     break;
    } else {
     $40 = (($$) + 4)|0;
     $count$1 = $40;
     break;
    }
   } else {
    $37 = (($$) + 2)|0;
    $count$1 = $37;
   }
  } while(0);
  $$sum = (($count$1) + 4)|0;
  $44 = (($p$0) + ($$sum)|0);
  $45 = ($44>>>0)>($3>>>0);
  if ($45) {
   $error$0 = 21;
   label = 21;
   break;
  }
  if ($34) {
   $62 = (($p$0) + 5|0);
   $63 = HEAP8[$10>>0]|0;
   $64 = $63 << 24 >> 24;
   HEAP32[$14>>2] = $64;
   $65 = (($p$0) + 6|0);
   $66 = HEAP8[$62>>0]|0;
   $67 = $66 << 24 >> 24;
   $p$1 = $65;$storemerge = $67;
  } else {
   $46 = HEAP8[$10>>0]|0;
   $47 = $46 << 24 >> 24;
   $48 = $47 << 8;
   $49 = (($p$0) + 5|0);
   $50 = HEAP8[$49>>0]|0;
   $51 = $50&255;
   $52 = $48 | $51;
   HEAP32[$14>>2] = $52;
   $53 = (($p$0) + 8|0);
   $54 = (($p$0) + 6|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55 << 24 >> 24;
   $57 = $56 << 8;
   $58 = (($p$0) + 7|0);
   $59 = HEAP8[$58>>0]|0;
   $60 = $59&255;
   $61 = $57 | $60;
   $p$1 = $53;$storemerge = $61;
  }
  HEAP32[$13>>2] = $storemerge;
  do {
   if ($36) {
    $77 = $20 & 64;
    $78 = ($77|0)==(0);
    if (!($78)) {
     $79 = HEAP8[$p$1>>0]|0;
     $80 = $79 << 24 >> 24;
     $81 = $80 << 8;
     $82 = (($p$1) + 1|0);
     $83 = HEAP8[$82>>0]|0;
     $84 = $83&255;
     $85 = $81 | $84;
     $86 = $85 << 2;
     $87 = (($p$1) + 4|0);
     $88 = (($p$1) + 2|0);
     $89 = HEAP8[$88>>0]|0;
     $90 = $89 << 24 >> 24;
     $91 = $90 << 8;
     $92 = (($p$1) + 3|0);
     $93 = HEAP8[$92>>0]|0;
     $94 = $93&255;
     $95 = $91 | $94;
     $96 = $95 << 2;
     $p$2 = $87;$xx$0 = $86;$xy$0 = 0;$yx$0 = 0;$yy$0 = $96;
     break;
    }
    $97 = $20 & 128;
    $98 = ($97|0)==(0);
    if ($98) {
     $p$2 = $p$1;$xx$0 = 65536;$xy$0 = 0;$yx$0 = 0;$yy$0 = 65536;
    } else {
     $99 = HEAP8[$p$1>>0]|0;
     $100 = $99 << 24 >> 24;
     $101 = $100 << 8;
     $102 = (($p$1) + 1|0);
     $103 = HEAP8[$102>>0]|0;
     $104 = $103&255;
     $105 = $101 | $104;
     $106 = $105 << 2;
     $107 = (($p$1) + 2|0);
     $108 = HEAP8[$107>>0]|0;
     $109 = $108 << 24 >> 24;
     $110 = $109 << 8;
     $111 = (($p$1) + 3|0);
     $112 = HEAP8[$111>>0]|0;
     $113 = $112&255;
     $114 = $110 | $113;
     $115 = $114 << 2;
     $116 = (($p$1) + 4|0);
     $117 = HEAP8[$116>>0]|0;
     $118 = $117 << 24 >> 24;
     $119 = $118 << 8;
     $120 = (($p$1) + 5|0);
     $121 = HEAP8[$120>>0]|0;
     $122 = $121&255;
     $123 = $119 | $122;
     $124 = $123 << 2;
     $125 = (($p$1) + 8|0);
     $126 = (($p$1) + 6|0);
     $127 = HEAP8[$126>>0]|0;
     $128 = $127 << 24 >> 24;
     $129 = $128 << 8;
     $130 = (($p$1) + 7|0);
     $131 = HEAP8[$130>>0]|0;
     $132 = $131&255;
     $133 = $129 | $132;
     $134 = $133 << 2;
     $p$2 = $125;$xx$0 = $106;$xy$0 = $124;$yx$0 = $115;$yy$0 = $134;
    }
   } else {
    $68 = (($p$1) + 2|0);
    $69 = HEAP8[$p$1>>0]|0;
    $70 = $69 << 24 >> 24;
    $71 = $70 << 8;
    $72 = (($p$1) + 1|0);
    $73 = HEAP8[$72>>0]|0;
    $74 = $73&255;
    $75 = $71 | $74;
    $76 = $75 << 2;
    $p$2 = $68;$xx$0 = $76;$xy$0 = 0;$yx$0 = 0;$yy$0 = $76;
   }
  } while(0);
  $135 = ((($12) + ($num_subglyphs$0<<5)|0) + 16|0);
  HEAP32[$135>>2] = $xx$0;
  $136 = ((($12) + ($num_subglyphs$0<<5)|0) + 20|0);
  HEAP32[$136>>2] = $xy$0;
  $137 = ((($12) + ($num_subglyphs$0<<5)|0) + 24|0);
  HEAP32[$137>>2] = $yx$0;
  $138 = ((($12) + ($num_subglyphs$0<<5)|0) + 28|0);
  HEAP32[$138>>2] = $yy$0;
  $139 = $22 & 32;
  $140 = ($139<<16>>16)==(0);
  if ($140) {
   label = 20;
   break;
  } else {
   $num_subglyphs$0 = $7;$p$0 = $p$2;
  }
 }
 if ((label|0) == 20) {
  $141 = (($5) + 84|0);
  HEAP32[$141>>2] = $7;
  $142 = (($loader) + 24|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = (_FT_Stream_Pos($143)|0);
  $145 = (($p$2) + ($144)|0);
  $146 = $145;
  $147 = $3;
  $148 = (($146) - ($147))|0;
  $149 = (($loader) + 168|0);
  HEAP32[$149>>2] = $148;
  HEAP32[$0>>2] = $p$2;
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return ($error$0|0);
 }
 return 0|0;
}
function _TT_Forget_Glyph_Frame($loader) {
 $loader = $loader|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($loader) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 _FT_Stream_ExitFrame($1);
 STACKTOP = sp;return;
}
function _TT_Load_Glyph($size,$glyph,$glyph_index,$load_flags) {
 $size = $size|0;
 $glyph = $glyph|0;
 $glyph_index = $glyph_index|0;
 $load_flags = $load_flags|0;
 var $$0 = 0, $$1$i = 0, $$in$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $advance$0$i = 0, $advance$1$i = 0, $advance$2$i = 0, $bbox$i = 0, $i$02$i = 0, $loader = 0, $metrics$i = 0, $sext$i = 0, $sext1$i = 0, $top$0$i = 0, $top$1$i = 0;
 var $y_scale$0$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $bbox$i = sp + 208|0;
 $metrics$i = sp + 224|0;
 $loader = sp;
 $0 = (($glyph) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($size) + 112|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(-1);
 if (!($4)) {
  $5 = $load_flags & 8;
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = (($1) + 532|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($1) + 104|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($8) + 104|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($glyph) + 76|0);
   $14 = (FUNCTION_TABLE_iiiiiiii[$12 & 127]($1,$3,$glyph_index,$load_flags,$10,$13,$metrics$i)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = (($glyph) + 110|0);
    HEAP16[$16>>1] = 0;
    $17 = (($glyph) + 108|0);
    HEAP16[$17>>1] = 0;
    $18 = (($metrics$i) + 1|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = $19&255;
    $21 = $20 << 6;
    $22 = (($glyph) + 24|0);
    HEAP32[$22>>2] = $21;
    $23 = HEAP8[$metrics$i>>0]|0;
    $24 = $23&255;
    $25 = $24 << 6;
    $26 = (($glyph) + 28|0);
    HEAP32[$26>>2] = $25;
    $27 = (($metrics$i) + 2|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = $28 << 24 >> 24;
    $30 = $29 << 6;
    $31 = (($glyph) + 32|0);
    HEAP32[$31>>2] = $30;
    $32 = (($metrics$i) + 3|0);
    $33 = HEAP8[$32>>0]|0;
    $34 = $33 << 24 >> 24;
    $35 = $34 << 6;
    $36 = (($glyph) + 36|0);
    HEAP32[$36>>2] = $35;
    $37 = (($metrics$i) + 4|0);
    $38 = HEAP8[$37>>0]|0;
    $39 = $38&255;
    $40 = $39 << 6;
    $41 = (($glyph) + 40|0);
    HEAP32[$41>>2] = $40;
    $42 = (($metrics$i) + 5|0);
    $43 = HEAP8[$42>>0]|0;
    $44 = $43 << 24 >> 24;
    $45 = $44 << 6;
    $46 = (($glyph) + 44|0);
    HEAP32[$46>>2] = $45;
    $47 = (($metrics$i) + 6|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = $48 << 24 >> 24;
    $50 = $49 << 6;
    $51 = (($glyph) + 48|0);
    HEAP32[$51>>2] = $50;
    $52 = (($metrics$i) + 7|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = $54 << 6;
    $56 = (($glyph) + 52|0);
    HEAP32[$56>>2] = $55;
    $57 = (($glyph) + 72|0);
    HEAP32[$57>>2] = 1651078259;
    $58 = $load_flags & 16;
    $59 = ($58|0)==(0);
    $60 = (($glyph) + 100|0);
    if ($59) {
     HEAP32[$60>>2] = $29;
     $61 = (($glyph) + 104|0);
     HEAP32[$61>>2] = $34;
    } else {
     HEAP32[$60>>2] = $44;
     $62 = (($glyph) + 104|0);
     HEAP32[$62>>2] = $49;
    }
    $63 = (($1) + 8|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = $64 & 1;
    $66 = ($65|0)==(0);
    if ($66) {
     $$0 = 0;
     STACKTOP = sp;return ($$0|0);
    }
    $67 = HEAP32[$0>>2]|0;
    $68 = (($67) + 104|0);
    $69 = HEAP32[$68>>2]|0;
    _memset(($loader|0),0,208)|0;
    $70 = (($67) + 508|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (FUNCTION_TABLE_iiiii[$71 & 511]($67,1735162214,$69,0)|0);
    if ((($72|0) == 0)) {
     $74 = (_FT_Stream_Pos($69)|0);
     $75 = (($loader) + 84|0);
     HEAP32[$75>>2] = $74;
     label = 11;
    } else if ((($72|0) == 142)) {
     $73 = (($loader) + 84|0);
     HEAP32[$73>>2] = 0;
     label = 11;
    }
    if ((label|0) == 11) {
     $76 = (($loader) + 16|0);
     HEAP32[$76>>2] = $load_flags;
     HEAP32[$loader>>2] = $67;
     $77 = (($loader) + 4|0);
     HEAP32[$77>>2] = $size;
     $78 = (($loader) + 8|0);
     HEAP32[$78>>2] = $glyph;
     $79 = (($loader) + 24|0);
     HEAP32[$79>>2] = $69;
    }
    (_load_truetype_glyph($loader,$glyph_index,0,1)|0);
    $80 = (($loader) + 60|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = (($glyph) + 56|0);
    HEAP32[$82>>2] = $81;
    $83 = (($loader) + 176|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($loader) + 48|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = (($86) + ($84))|0;
    $88 = (($loader) + 180|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = (($87) - ($89))|0;
    $91 = (($glyph) + 60|0);
    HEAP32[$91>>2] = $90;
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $92 = $load_flags & 1;
 $93 = ($92|0)!=(0);
 if (!($93)) {
  $94 = (($size) + 108|0);
  $95 = HEAP8[$94>>0]|0;
  $96 = ($95<<24>>24)==(0);
  if ($96) {
   $$0 = 36;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $97 = $load_flags & 16384;
 $98 = ($97|0)==(0);
 if (!($98)) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $99 = $load_flags & 128;
 $100 = $99&255;
 $101 = HEAP32[$0>>2]|0;
 $102 = (($101) + 104|0);
 $103 = HEAP32[$102>>2]|0;
 _memset(($loader|0),0,208)|0;
 $104 = $load_flags & 2;
 $105 = ($104|0)==(0);
 if ($105) {
  $106 = (($size) + 301|0);
  $107 = HEAP8[$106>>0]|0;
  $108 = ($107<<24>>24)==(0);
  if ($108) {
   $109 = (_tt_size_ready_bytecode($size,$100)|0);
   $110 = ($109|0)==(0);
   if (!($110)) {
    $$0 = $109;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $111 = (($size) + 292|0);
  $112 = HEAP8[$111>>0]|0;
  $113 = ($112<<24>>24)==(0);
  if ($113) {
   $115 = (($101) + 96|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (($116) + 40|0);
   $$in$i = $117;
  } else {
   $114 = (($size) + 296|0);
   $$in$i = $114;
  }
  $118 = HEAP32[$$in$i>>2]|0;
  $119 = ($118|0)==(0|0);
  if ($119) {
   $$0 = 153;
   STACKTOP = sp;return ($$0|0);
  }
  $120 = $load_flags & 983040;
  $121 = ($120|0)!=(131072);
  (_TT_Load_Context($118,$101,$size)|0);
  $122 = $121&1;
  $123 = (($118) + 604|0);
  $124 = HEAP8[$123>>0]|0;
  $125 = $124&255;
  $126 = ($122|0)==($125|0);
  if (!($126)) {
   $127 = $121&1;
   HEAP8[$123>>0] = $127;
   $128 = (($size) + 240|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = ($129|0)==(0);
   if (!($130)) {
    $131 = (($101) + 672|0);
    $132 = (($size) + 88|0);
    $133 = (($size) + 244|0);
    $i$02$i = 0;
    while(1) {
     $134 = HEAP32[$131>>2]|0;
     $135 = (($134) + ($i$02$i<<1)|0);
     $136 = HEAP16[$135>>1]|0;
     $137 = $136 << 16 >> 16;
     $138 = HEAP32[$132>>2]|0;
     $139 = (_FT_MulFix($137,$138)|0);
     $140 = HEAP32[$133>>2]|0;
     $141 = (($140) + ($i$02$i<<2)|0);
     HEAP32[$141>>2] = $139;
     $142 = (($i$02$i) + 1)|0;
     $143 = HEAP32[$128>>2]|0;
     $144 = ($142>>>0)<($143>>>0);
     if ($144) {
      $i$02$i = $142;
     } else {
      break;
     }
    }
   }
   (_tt_size_run_prep($size,$100)|0);
  }
  $145 = (($118) + 336|0);
  $146 = HEAP8[$145>>0]|0;
  $147 = $146 & 1;
  $148 = $147&255;
  $149 = $148 << 1;
  $150 = $149 | $load_flags;
  $151 = $146 & 2;
  $152 = ($151<<24>>24)==(0);
  if (!($152)) {
   $153 = (($118) + 284|0);
   dest=$153+0|0; src=873120+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $154 = (($118) + 561|0);
  HEAP8[$154>>0] = $100;
  $155 = (($loader) + 160|0);
  HEAP32[$155>>2] = $118;
  $156 = (($118) + 392|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = (($loader) + 164|0);
  HEAP32[$158>>2] = $157;
  $$1$i = $150;
 } else {
  $$1$i = $load_flags;
 }
 $159 = (($101) + 508|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = (FUNCTION_TABLE_iiiii[$160 & 511]($101,1735162214,$103,0)|0);
 if ((($161|0) == 142)) {
  $162 = (($loader) + 84|0);
  HEAP32[$162>>2] = 0;
 } else if ((($161|0) == 0)) {
  $163 = (_FT_Stream_Pos($103)|0);
  $164 = (($loader) + 84|0);
  HEAP32[$164>>2] = $163;
 } else {
  $$0 = $161;
  STACKTOP = sp;return ($$0|0);
 }
 $165 = (($glyph) + 156|0);
 $166 = HEAP32[$165>>2]|0;
 $167 = HEAP32[$166>>2]|0;
 _FT_GlyphLoader_Rewind($167);
 $168 = (($loader) + 12|0);
 HEAP32[$168>>2] = $167;
 $169 = (($loader) + 16|0);
 HEAP32[$169>>2] = $$1$i;
 HEAP32[$loader>>2] = $101;
 $170 = (($loader) + 4|0);
 HEAP32[$170>>2] = $size;
 $171 = (($loader) + 8|0);
 HEAP32[$171>>2] = $glyph;
 $172 = (($loader) + 24|0);
 HEAP32[$172>>2] = $103;
 $173 = (($glyph) + 72|0);
 HEAP32[$173>>2] = 1869968492;
 $174 = (($glyph) + 128|0);
 HEAP32[$174>>2] = 0;
 $175 = (($glyph) + 108|0);
 $176 = (($glyph) + 124|0);
 HEAP32[$176>>2] = 0;
 $177 = (_load_truetype_glyph($loader,$glyph_index,0,0)|0);
 $178 = ($177|0)==(0);
 if ($178) {
  $179 = HEAP32[$173>>2]|0;
  $180 = ($179|0)==(1668246896);
  $181 = HEAP32[$168>>2]|0;
  if ($180) {
   $182 = (($181) + 48|0);
   $183 = HEAP32[$182>>2]|0;
   HEAP32[$174>>2] = $183;
   $184 = (($181) + 52|0);
   $185 = HEAP32[$184>>2]|0;
   $186 = (($glyph) + 132|0);
   HEAP32[$186>>2] = $185;
  } else {
   $187 = (($181) + 20|0);
   ;HEAP32[$175+0>>2]=HEAP32[$187+0>>2]|0;HEAP32[$175+4>>2]=HEAP32[$187+4>>2]|0;HEAP32[$175+8>>2]=HEAP32[$187+8>>2]|0;HEAP32[$175+12>>2]=HEAP32[$187+12>>2]|0;HEAP32[$175+16>>2]=HEAP32[$187+16>>2]|0;
   $188 = HEAP32[$176>>2]|0;
   $189 = $188 & -513;
   HEAP32[$176>>2] = $189;
   $190 = (($loader) + 68|0);
   $191 = HEAP32[$190>>2]|0;
   $192 = ($191|0)==(0);
   if (!($192)) {
    $193 = (0 - ($191))|0;
    _FT_Outline_Translate($175,$193,0);
   }
  }
  do {
   if ($105) {
    $194 = (($loader) + 160|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = (($195) + 337|0);
    $197 = HEAP8[$196>>0]|0;
    $198 = ($197<<24>>24)==(0);
    if ($198) {
     $209 = HEAP32[$176>>2]|0;
     $210 = $209 | 8;
     HEAP32[$176>>2] = $210;
     break;
    }
    $199 = (($195) + 340|0);
    $200 = HEAP32[$199>>2]|0;
    if ((($200|0) == 5)) {
     $205 = HEAP32[$176>>2]|0;
     $206 = $205 | 16;
     HEAP32[$176>>2] = $206;
     break;
    } else if ((($200|0) == 1)) {
     break;
    } else if ((($200|0) == 4)) {
     $203 = HEAP32[$176>>2]|0;
     $204 = $203 | 48;
     HEAP32[$176>>2] = $204;
     break;
    } else if ((($200|0) == 0)) {
     $201 = HEAP32[$176>>2]|0;
     $202 = $201 | 32;
     HEAP32[$176>>2] = $202;
     break;
    } else {
     $207 = HEAP32[$176>>2]|0;
     $208 = $207 | 8;
     HEAP32[$176>>2] = $208;
     break;
    }
   }
  } while(0);
  $211 = HEAP32[$loader>>2]|0;
  $212 = HEAP32[$171>>2]|0;
  $213 = HEAP32[$170>>2]|0;
  $214 = HEAP32[$169>>2]|0;
  $215 = $214 & 1;
  $216 = ($215|0)==(0);
  if ($216) {
   $217 = (($213) + 20|0);
   $218 = HEAP32[$217>>2]|0;
   $y_scale$0$i = $218;
  } else {
   $y_scale$0$i = 65536;
  }
  $219 = (($212) + 72|0);
  $220 = HEAP32[$219>>2]|0;
  $221 = ($220|0)==(1668246896);
  if ($221) {
   $223 = (($loader) + 36|0);
   ;HEAP32[$bbox$i+0>>2]=HEAP32[$223+0>>2]|0;HEAP32[$bbox$i+4>>2]=HEAP32[$223+4>>2]|0;HEAP32[$bbox$i+8>>2]=HEAP32[$223+8>>2]|0;HEAP32[$bbox$i+12>>2]=HEAP32[$223+12>>2]|0;
  } else {
   $222 = (($212) + 108|0);
   _FT_Outline_Get_CBox($222,$bbox$i);
  }
  $224 = (($loader) + 60|0);
  $225 = HEAP32[$224>>2]|0;
  $226 = (($212) + 56|0);
  HEAP32[$226>>2] = $225;
  $227 = HEAP32[$bbox$i>>2]|0;
  $228 = (($212) + 32|0);
  HEAP32[$228>>2] = $227;
  $229 = (($bbox$i) + 12|0);
  $230 = HEAP32[$229>>2]|0;
  $231 = (($212) + 36|0);
  HEAP32[$231>>2] = $230;
  $232 = (($loader) + 76|0);
  $233 = HEAP32[$232>>2]|0;
  $234 = (($loader) + 68|0);
  $235 = HEAP32[$234>>2]|0;
  $236 = (($233) - ($235))|0;
  $237 = (($212) + 40|0);
  HEAP32[$237>>2] = $236;
  $238 = (($211) + 468|0);
  $239 = (($238) + 12|0);
  $240 = HEAP32[$239>>2]|0;
  $241 = ($240|0)==(0);
  if ($241) {
   $242 = HEAP32[$169>>2]|0;
   $243 = $242 & 2;
   $244 = ($243|0)==(0);
   if ($244) {
    $245 = (($213) + 12|0);
    $246 = HEAP16[$245>>1]|0;
    $247 = $246&65535;
    $248 = (_tt_face_get_device_metrics($211,$247,$glyph_index)|0);
    $249 = ($248|0)==(0|0);
    if (!($249)) {
     $250 = HEAP8[$248>>0]|0;
     $251 = $250&255;
     $252 = $251 << 6;
     HEAP32[$237>>2] = $252;
    }
   }
  }
  $253 = (($bbox$i) + 8|0);
  $254 = HEAP32[$253>>2]|0;
  $255 = HEAP32[$bbox$i>>2]|0;
  $256 = (($254) - ($255))|0;
  $257 = (($212) + 24|0);
  HEAP32[$257>>2] = $256;
  $258 = HEAP32[$229>>2]|0;
  $259 = (($bbox$i) + 4|0);
  $260 = HEAP32[$259>>2]|0;
  $261 = (($258) - ($260))|0;
  $262 = (($212) + 28|0);
  HEAP32[$262>>2] = $261;
  $263 = (($211) + 296|0);
  $264 = HEAP8[$263>>0]|0;
  $265 = ($264<<24>>24)==(0);
  if ($265) {
   label = 60;
  } else {
   $266 = (($211) + 300|0);
   $267 = (($266) + 34|0);
   $268 = HEAP16[$267>>1]|0;
   $269 = ($268<<16>>16)==(0);
   if ($269) {
    label = 60;
   } else {
    $270 = (($loader) + 188|0);
    $271 = HEAP32[$270>>2]|0;
    $272 = HEAP32[$229>>2]|0;
    $273 = (($271) - ($272))|0;
    $274 = (_FT_DivFix($273,$y_scale$0$i)|0);
    $sext1$i = $274 << 16;
    $275 = $sext1$i >> 16;
    $276 = HEAP32[$270>>2]|0;
    $277 = (($loader) + 196|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = ($276|0)>($278|0);
    if ($279) {
     $280 = (($276) - ($278))|0;
     $281 = (_FT_DivFix($280,$y_scale$0$i)|0);
     $282 = $281 & 65535;
     $advance$1$i = $282;$top$0$i = $275;
    } else {
     $advance$1$i = 0;$top$0$i = $275;
    }
   }
  }
  if ((label|0) == 60) {
   $283 = HEAP32[$229>>2]|0;
   $284 = HEAP32[$259>>2]|0;
   $285 = (($283) - ($284))|0;
   $286 = (_FT_DivFix($285,$y_scale$0$i)|0);
   $sext$i = $286 << 16;
   $287 = $sext$i >> 16;
   $288 = (($211) + 368|0);
   $289 = HEAP16[$288>>1]|0;
   $290 = ($289<<16>>16)==(-1);
   if ($290) {
    $298 = (($211) + 216|0);
    $299 = (($298) + 4|0);
    $300 = HEAP16[$299>>1]|0;
    $301 = $300 << 16 >> 16;
    $302 = (($298) + 6|0);
    $303 = HEAP16[$302>>1]|0;
    $304 = $303 << 16 >> 16;
    $305 = (($301) - ($304))|0;
    $advance$0$i = $305;
   } else {
    $291 = (($288) + 70|0);
    $292 = HEAP16[$291>>1]|0;
    $293 = $292 << 16 >> 16;
    $294 = (($288) + 72|0);
    $295 = HEAP16[$294>>1]|0;
    $296 = $295 << 16 >> 16;
    $297 = (($293) - ($296))|0;
    $advance$0$i = $297;
   }
   $306 = (($advance$0$i) - ($287))|0;
   $307 = (($306|0) / 2)&-1;
   $advance$1$i = $advance$0$i;$top$0$i = $307;
  }
  $308 = (($212) + 60|0);
  HEAP32[$308>>2] = $advance$1$i;
  $309 = HEAP32[$169>>2]|0;
  $310 = $309 & 1;
  $311 = ($310|0)==(0);
  if ($311) {
   $312 = (_FT_MulFix($top$0$i,$y_scale$0$i)|0);
   $313 = (_FT_MulFix($advance$1$i,$y_scale$0$i)|0);
   $advance$2$i = $313;$top$1$i = $312;
  } else {
   $advance$2$i = $advance$1$i;$top$1$i = $top$0$i;
  }
  $314 = HEAP32[$228>>2]|0;
  $315 = HEAP32[$237>>2]|0;
  $316 = (($315|0) / 2)&-1;
  $317 = (($314) - ($316))|0;
  $318 = (($212) + 44|0);
  HEAP32[$318>>2] = $317;
  $319 = (($212) + 48|0);
  HEAP32[$319>>2] = $top$1$i;
  $320 = (($212) + 52|0);
  HEAP32[$320>>2] = $advance$2$i;
 }
 if ($93) {
  $$0 = $177;
  STACKTOP = sp;return ($$0|0);
 }
 $321 = (($size) + 14|0);
 $322 = HEAP16[$321>>1]|0;
 $323 = ($322&65535)<(24);
 if (!($323)) {
  $$0 = $177;
  STACKTOP = sp;return ($$0|0);
 }
 $324 = HEAP32[$176>>2]|0;
 $325 = $324 | 256;
 HEAP32[$176>>2] = $325;
 $$0 = $177;
 STACKTOP = sp;return ($$0|0);
}
function _load_truetype_glyph($loader,$glyph_index,$recurse_count,$header_only) {
 $loader = $loader|0;
 $glyph_index = $glyph_index|0;
 $recurse_count = $recurse_count|0;
 $header_only = $header_only|0;
 var $$lcssa1$i = 0, $$not$i = 0, $$phi$trans$insert$i = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre$i4 = 0, $$pre$i7 = 0, $$pre$pre$i = 0, $$pre1$i = 0, $$pre40 = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre6$pre$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$sum = 0, $$sum$i = 0, $$sum3$i = 0, $$sum31 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0;
 var $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0;
 var $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $advance_height$i = 0, $deltas = 0, $deltas$i = 0, $error$3 = 0, $error$314 = 0, $error$316 = 0, $error$i = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i6 = 0, $exitcond6$i$i = 0;
 var $i$0$lcssa = 0, $i$02$i = 0, $i$026 = 0, $i$04$i = 0, $k$04$i$i = 0, $k$11$i$i = 0, $n$021 = 0, $num_points$0$lcssa = 0, $opened_frame$0 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond3 = 0, $or$cond6$i = 0, $or$cond7$i$i = 0, $sext = 0, $sext2 = 0, $subglyph$025 = 0, $subglyph2$0$lcssa = 0, $tmp$i = 0;
 var $vec$01$i = 0, $x$0$i = 0, $x$1$i = 0, $x_scale$0 = 0, $y$0$i = 0, $y$1$i = 0, $y_scale$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $error$i = sp + 12|0;
 $tmp$i = sp;
 $deltas$i = sp + 4|0;
 $advance_height$i = sp + 16|0;
 $deltas = sp + 8|0;
 $0 = HEAP32[$loader>>2]|0;
 $1 = (($loader) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$deltas>>2] = 0;
 $3 = ($recurse_count>>>0)>(1);
 if ($3) {
  $4 = (($0) + 260|0);
  $5 = (($4) + 30|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = $6&65535;
  $8 = ($7>>>0)<($recurse_count>>>0);
  if ($8) {
   $error$314 = 21;
   STACKTOP = sp;return ($error$314|0);
  }
 }
 $9 = (($0) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10>>>0)>($glyph_index>>>0);
 if (!($11)) {
  $error$314 = 16;
  STACKTOP = sp;return ($error$314|0);
 }
 $12 = (($loader) + 20|0);
 HEAP32[$12>>2] = $glyph_index;
 $13 = (($loader) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 1;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (($loader) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 48|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($18) + 52|0);
  $22 = HEAP32[$21>>2]|0;
  $x_scale$0 = $20;$y_scale$0 = $22;
 } else {
  $x_scale$0 = 65536;$y_scale$0 = 65536;
 }
 HEAP16[$error$i>>1] = 0;
 HEAP16[$tmp$i>>1] = 0;
 HEAP16[$deltas$i>>1] = 0;
 HEAP16[$advance_height$i>>1] = 0;
 $23 = (($0) + 532|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 156|0);
 $26 = HEAP32[$25>>2]|0;
 (FUNCTION_TABLE_iiiiii[$26 & 255]($0,0,$glyph_index,$error$i,$deltas$i)|0);
 $27 = (($0) + 296|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  HEAP16[$tmp$i>>1] = 0;
  $33 = (($0) + 68|0);
  $34 = HEAP16[$33>>1]|0;
  HEAP16[$advance_height$i>>1] = $34;
  $42 = 0;$45 = $34;
 } else {
  $30 = HEAP32[$23>>2]|0;
  $31 = (($30) + 156|0);
  $32 = HEAP32[$31>>2]|0;
  (FUNCTION_TABLE_iiiiii[$32 & 255]($0,1,$glyph_index,$tmp$i,$advance_height$i)|0);
  $$pre$i = HEAP16[$tmp$i>>1]|0;
  $$pre1$i = HEAP16[$advance_height$i>>1]|0;
  $42 = $$pre$i;$45 = $$pre1$i;
 }
 $35 = HEAP16[$error$i>>1]|0;
 $36 = $35 << 16 >> 16;
 $37 = (($loader) + 52|0);
 HEAP32[$37>>2] = $36;
 $38 = HEAP16[$deltas$i>>1]|0;
 $39 = $38&65535;
 $40 = (($loader) + 56|0);
 HEAP32[$40>>2] = $39;
 $41 = $42 << 16 >> 16;
 $43 = (($loader) + 176|0);
 HEAP32[$43>>2] = $41;
 $44 = $45&65535;
 $46 = (($loader) + 180|0);
 HEAP32[$46>>2] = $44;
 $47 = (($loader) + 64|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  HEAP8[$47>>0] = 1;
  $50 = (($loader) + 60|0);
  HEAP32[$50>>2] = $39;
 }
 $51 = (($loader) + 28|0);
 $52 = (_tt_face_get_location($0,$glyph_index,$51)|0);
 $53 = HEAP32[$51>>2]|0;
 $54 = ($53|0)>(0);
 if ($54) {
  $55 = (($loader) + 84|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0);
  if ($57) {
   $error$314 = 8;
   STACKTOP = sp;return ($error$314|0);
  }
  $58 = (($0) + 512|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = (($56) + ($52))|0;
  $61 = (FUNCTION_TABLE_iiiii[$59 & 511]($loader,$glyph_index,$60,$53)|0);
  $62 = ($61|0)==(0);
  if (!($62)) {
   $error$314 = $61;
   STACKTOP = sp;return ($error$314|0);
  }
  $63 = (($0) + 520|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (FUNCTION_TABLE_ii[$64 & 4095]($loader)|0);
  $66 = ($65|0)==(0);
  $67 = ($header_only<<24>>24)==(0);
  $or$cond = $66 & $67;
  if ($or$cond) {
   $$pr = HEAP32[$51>>2]|0;
   $69 = $$pr;$opened_frame$0 = 1;
   label = 16;
  } else {
   $error$316 = $65;
  }
 } else {
  $69 = $53;$opened_frame$0 = 0;
  label = 16;
 }
 if ((label|0) == 16) {
  $68 = ($69|0)==(0);
  do {
   if ($68) {
    label = 18;
   } else {
    $70 = (($loader) + 32|0);
    $71 = HEAP16[$70>>1]|0;
    $72 = ($71<<16>>16)==(0);
    if ($72) {
     label = 18;
    } else {
     $141 = (($loader) + 36|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = HEAP32[$37>>2]|0;
     $144 = (($142) - ($143))|0;
     $145 = (($loader) + 68|0);
     HEAP32[$145>>2] = $144;
     $146 = (($loader) + 72|0);
     HEAP32[$146>>2] = 0;
     $147 = HEAP32[$40>>2]|0;
     $148 = (($147) + ($144))|0;
     $149 = (($loader) + 76|0);
     HEAP32[$149>>2] = $148;
     $150 = (($loader) + 80|0);
     HEAP32[$150>>2] = 0;
     $151 = (($loader) + 184|0);
     HEAP32[$151>>2] = 0;
     $152 = HEAP32[$43>>2]|0;
     $153 = (($loader) + 48|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (($154) + ($152))|0;
     $156 = (($loader) + 188|0);
     HEAP32[$156>>2] = $155;
     $157 = (($loader) + 192|0);
     HEAP32[$157>>2] = 0;
     $158 = HEAP32[$46>>2]|0;
     $159 = (($155) - ($158))|0;
     $160 = (($loader) + 196|0);
     HEAP32[$160>>2] = $159;
     $161 = ($71<<16>>16)>(0);
     if ($161) {
      $162 = (($0) + 524|0);
      $163 = HEAP32[$162>>2]|0;
      $164 = (FUNCTION_TABLE_ii[$163 & 4095]($loader)|0);
      $165 = ($164|0)==(0);
      if (!($165)) {
       $error$3 = $164;
       break;
      }
      $166 = (($0) + 516|0);
      $167 = HEAP32[$166>>2]|0;
      FUNCTION_TABLE_vi[$167 & 4095]($loader);
      $168 = HEAP32[$1>>2]|0;
      $169 = (($168) + 58|0);
      $170 = HEAP16[$169>>1]|0;
      $171 = $170 << 16 >> 16;
      $172 = (($168) + 60|0);
      $173 = HEAP32[$172>>2]|0;
      $174 = (($173) + ($171<<3)|0);
      $175 = $145;
      $176 = $175;
      $177 = HEAP32[$176>>2]|0;
      $178 = (($175) + 4)|0;
      $179 = $178;
      $180 = HEAP32[$179>>2]|0;
      $181 = $174;
      $182 = $181;
      HEAP32[$182>>2] = $177;
      $183 = (($181) + 4)|0;
      $184 = $183;
      HEAP32[$184>>2] = $180;
      $185 = (($171) + 1)|0;
      $186 = HEAP32[$172>>2]|0;
      $187 = (($186) + ($185<<3)|0);
      $188 = $149;
      $189 = $188;
      $190 = HEAP32[$189>>2]|0;
      $191 = (($188) + 4)|0;
      $192 = $191;
      $193 = HEAP32[$192>>2]|0;
      $194 = $187;
      $195 = $194;
      HEAP32[$195>>2] = $190;
      $196 = (($194) + 4)|0;
      $197 = $196;
      HEAP32[$197>>2] = $193;
      $198 = (($171) + 2)|0;
      $199 = HEAP32[$172>>2]|0;
      $200 = (($199) + ($198<<3)|0);
      $201 = $151;
      $202 = $201;
      $203 = HEAP32[$202>>2]|0;
      $204 = (($201) + 4)|0;
      $205 = $204;
      $206 = HEAP32[$205>>2]|0;
      $207 = $200;
      $208 = $207;
      HEAP32[$208>>2] = $203;
      $209 = (($207) + 4)|0;
      $210 = $209;
      HEAP32[$210>>2] = $206;
      $211 = (($171) + 3)|0;
      $212 = HEAP32[$172>>2]|0;
      $213 = (($212) + ($211<<3)|0);
      $214 = $157;
      $215 = $214;
      $216 = HEAP32[$215>>2]|0;
      $217 = (($214) + 4)|0;
      $218 = $217;
      $219 = HEAP32[$218>>2]|0;
      $220 = $213;
      $221 = $220;
      HEAP32[$221>>2] = $216;
      $222 = (($220) + 4)|0;
      $223 = $222;
      HEAP32[$223>>2] = $219;
      $224 = (($168) + 64|0);
      $225 = HEAP32[$224>>2]|0;
      $226 = (($225) + ($171)|0);
      HEAP8[$226>>0] = 0;
      $227 = HEAP32[$224>>2]|0;
      $228 = (($227) + ($185)|0);
      HEAP8[$228>>0] = 0;
      $229 = HEAP32[$224>>2]|0;
      $230 = (($229) + ($198)|0);
      HEAP8[$230>>0] = 0;
      $231 = HEAP32[$224>>2]|0;
      $232 = (($231) + ($211)|0);
      HEAP8[$232>>0] = 0;
      $233 = (($171) + 4)|0;
      $234 = HEAP32[$loader>>2]|0;
      $235 = (($234) + 708|0);
      $236 = HEAP8[$235>>0]|0;
      $237 = ($236<<24>>24)==(0);
      if (!($237)) {
       $238 = (($234) + 100|0);
       $239 = HEAP32[$238>>2]|0;
       $240 = HEAP32[$12>>2]|0;
       $241 = (_TT_Vary_Get_Glyph_Deltas($234,$240,$deltas$i,$233)|0);
       $242 = ($241|0)==(0);
       if (!($242)) {
        $error$314 = $241;
        STACKTOP = sp;return ($error$314|0);
       }
       $243 = ($233|0)>(0);
       $244 = HEAP32[$deltas$i>>2]|0;
       if ($243) {
        $245 = HEAP32[$172>>2]|0;
        $i$02$i = 0;
        while(1) {
         $246 = (($244) + ($i$02$i<<3)|0);
         $247 = HEAP32[$246>>2]|0;
         $248 = (($245) + ($i$02$i<<3)|0);
         $249 = HEAP32[$248>>2]|0;
         $250 = (($249) + ($247))|0;
         HEAP32[$248>>2] = $250;
         $251 = ((($244) + ($i$02$i<<3)|0) + 4|0);
         $252 = HEAP32[$251>>2]|0;
         $253 = ((($245) + ($i$02$i<<3)|0) + 4|0);
         $254 = HEAP32[$253>>2]|0;
         $255 = (($254) + ($252))|0;
         HEAP32[$253>>2] = $255;
         $256 = (($i$02$i) + 1)|0;
         $exitcond$i = ($256|0)==($233|0);
         if ($exitcond$i) {
          break;
         } else {
          $i$02$i = $256;
         }
        }
       }
       _ft_mem_free($239,$244);
       HEAP32[$deltas$i>>2] = 0;
      }
      $257 = HEAP32[$13>>2]|0;
      $258 = $257 & 2;
      $259 = ($258|0)==(0);
      if ($259) {
       $260 = HEAP16[$169>>1]|0;
       $261 = (($loader) + 132|0);
       HEAP16[$261>>1] = $260;
       $262 = (($168) + 56|0);
       $263 = HEAP16[$262>>1]|0;
       $264 = (($loader) + 134|0);
       HEAP16[$264>>1] = $263;
       $265 = (($168) + 76|0);
       $266 = HEAP32[$265>>2]|0;
       $267 = (($loader) + 136|0);
       HEAP32[$267>>2] = $266;
       $268 = HEAP32[$172>>2]|0;
       $269 = (($loader) + 140|0);
       HEAP32[$269>>2] = $268;
       $270 = (($168) + 80|0);
       $271 = HEAP32[$270>>2]|0;
       $272 = (($loader) + 144|0);
       HEAP32[$272>>2] = $271;
       $273 = HEAP32[$224>>2]|0;
       $274 = (($loader) + 148|0);
       HEAP32[$274>>2] = $273;
       $275 = (($168) + 68|0);
       $276 = HEAP32[$275>>2]|0;
       $277 = (($loader) + 152|0);
       HEAP32[$277>>2] = $276;
       $278 = (($loader) + 156|0);
       HEAP16[$278>>1] = 0;
       $279 = $260&65535;
       $280 = $279 << 3;
       $281 = (($280) + 32)|0;
       _memcpy(($271|0),($268|0),($281|0))|0;
       $$pre$i4 = HEAP32[$13>>2]|0;
       $283 = $$pre$i4;
      } else {
       $283 = $257;
      }
      $282 = $283 & 1;
      $284 = ($282|0)==(0);
      if ($284) {
       $285 = HEAP32[$172>>2]|0;
       $286 = (($285) + ($233<<3)|0);
       $287 = (($loader) + 4|0);
       $288 = HEAP32[$287>>2]|0;
       $289 = (($288) + 48|0);
       $290 = HEAP32[$289>>2]|0;
       $291 = (($288) + 52|0);
       $292 = HEAP32[$291>>2]|0;
       $293 = ($233|0)>(0);
       if ($293) {
        $vec$01$i = $285;
        while(1) {
         $294 = HEAP32[$vec$01$i>>2]|0;
         $295 = (_FT_MulFix($294,$290)|0);
         HEAP32[$vec$01$i>>2] = $295;
         $296 = (($vec$01$i) + 4|0);
         $297 = HEAP32[$296>>2]|0;
         $298 = (_FT_MulFix($297,$292)|0);
         HEAP32[$296>>2] = $298;
         $299 = (($vec$01$i) + 8|0);
         $300 = ($299>>>0)<($286>>>0);
         if ($300) {
          $vec$01$i = $299;
         } else {
          break;
         }
        }
        $$pre5$i = HEAP32[$172>>2]|0;
        $$pre6$pre$i = HEAP32[$13>>2]|0;
        $$pre6$i = $$pre6$pre$i;$302 = $$pre5$i;
       } else {
        $$pre6$i = $283;$302 = $285;
       }
       $301 = (($302) + ($171<<3)|0);
       $303 = $301;
       $304 = $303;
       $305 = HEAP32[$304>>2]|0;
       $306 = (($303) + 4)|0;
       $307 = $306;
       $308 = HEAP32[$307>>2]|0;
       $309 = $145;
       $310 = $309;
       HEAP32[$310>>2] = $305;
       $311 = (($309) + 4)|0;
       $312 = $311;
       HEAP32[$312>>2] = $308;
       $313 = HEAP32[$172>>2]|0;
       $314 = (($313) + ($185<<3)|0);
       $315 = $314;
       $316 = $315;
       $317 = HEAP32[$316>>2]|0;
       $318 = (($315) + 4)|0;
       $319 = $318;
       $320 = HEAP32[$319>>2]|0;
       $321 = $149;
       $322 = $321;
       HEAP32[$322>>2] = $317;
       $323 = (($321) + 4)|0;
       $324 = $323;
       HEAP32[$324>>2] = $320;
       $325 = HEAP32[$172>>2]|0;
       $326 = (($325) + ($198<<3)|0);
       $327 = $326;
       $328 = $327;
       $329 = HEAP32[$328>>2]|0;
       $330 = (($327) + 4)|0;
       $331 = $330;
       $332 = HEAP32[$331>>2]|0;
       $333 = $151;
       $334 = $333;
       HEAP32[$334>>2] = $329;
       $335 = (($333) + 4)|0;
       $336 = $335;
       HEAP32[$336>>2] = $332;
       $337 = HEAP32[$172>>2]|0;
       $338 = (($337) + ($211<<3)|0);
       $339 = $338;
       $340 = $339;
       $341 = HEAP32[$340>>2]|0;
       $342 = (($339) + 4)|0;
       $343 = $342;
       $344 = HEAP32[$343>>2]|0;
       $345 = $157;
       $346 = $345;
       HEAP32[$346>>2] = $341;
       $347 = (($345) + 4)|0;
       $348 = $347;
       HEAP32[$348>>2] = $344;
       $350 = $$pre6$i;
      } else {
       $350 = $283;
      }
      $349 = $350 & 2;
      $351 = ($349|0)==(0);
      if ($351) {
       $352 = (($loader) + 132|0);
       $353 = HEAP16[$352>>1]|0;
       $354 = $353&65535;
       $355 = (($354) + 4)|0;
       $356 = $355&65535;
       HEAP16[$352>>1] = $356;
       $357 = (_TT_Hint_Glyph($loader,0)|0);
       $358 = ($357|0)==(0);
       if (!($358)) {
        $error$314 = $357;
        STACKTOP = sp;return ($error$314|0);
       }
      }
      _FT_GlyphLoader_Add($2);
      $error$314 = 0;
      STACKTOP = sp;return ($error$314|0);
     }
     $359 = ($71<<16>>16)==(-1);
     if ($359) {
      $360 = (($2) + 22|0);
      $361 = HEAP16[$360>>1]|0;
      $362 = $361 << 16 >> 16;
      $363 = (($2) + 20|0);
      $364 = HEAP16[$363>>1]|0;
      $365 = $364 << 16 >> 16;
      $366 = (($0) + 528|0);
      $367 = HEAP32[$366>>2]|0;
      $368 = (FUNCTION_TABLE_ii[$367 & 4095]($loader)|0);
      $369 = ($368|0)==(0);
      if ($369) {
       $370 = (($loader) + 168|0);
       $371 = HEAP32[$370>>2]|0;
       $372 = (($0) + 516|0);
       $373 = HEAP32[$372>>2]|0;
       FUNCTION_TABLE_vi[$373 & 4095]($loader);
       $374 = (($0) + 708|0);
       $375 = HEAP8[$374>>0]|0;
       $376 = ($375<<24>>24)==(0);
       if (!($376)) {
        $377 = (($0) + 100|0);
        $378 = HEAP32[$377>>2]|0;
        $379 = (($2) + 84|0);
        $380 = HEAP32[$379>>2]|0;
        $381 = (($380) + 4)|0;
        $382 = (_TT_Vary_Get_Glyph_Deltas($0,$glyph_index,$deltas,$381)|0);
        $383 = ($382|0)==(0);
        if (!($383)) {
         $error$314 = $382;
         STACKTOP = sp;return ($error$314|0);
        }
        $384 = HEAP32[$379>>2]|0;
        $385 = ($384|0)>(0);
        if ($385) {
         $386 = (($2) + 48|0);
         $387 = (($2) + 88|0);
         $388 = HEAP32[$386>>2]|0;
         $389 = HEAP32[$387>>2]|0;
         $390 = (($389) + ($388<<5)|0);
         $391 = HEAP32[$deltas>>2]|0;
         $i$026 = 0;$subglyph$025 = $390;
         while(1) {
          $392 = (($subglyph$025) + 4|0);
          $393 = HEAP16[$392>>1]|0;
          $394 = $393 & 2;
          $395 = ($394<<16>>16)==(0);
          if (!($395)) {
           $396 = (($391) + ($i$026<<3)|0);
           $397 = HEAP32[$396>>2]|0;
           $sext = $397 << 16;
           $398 = $sext >> 16;
           $399 = (($subglyph$025) + 8|0);
           $400 = HEAP32[$399>>2]|0;
           $401 = (($398) + ($400))|0;
           HEAP32[$399>>2] = $401;
           $402 = ((($391) + ($i$026<<3)|0) + 4|0);
           $403 = HEAP32[$402>>2]|0;
           $sext2 = $403 << 16;
           $404 = $sext2 >> 16;
           $405 = (($subglyph$025) + 12|0);
           $406 = HEAP32[$405>>2]|0;
           $407 = (($404) + ($406))|0;
           HEAP32[$405>>2] = $407;
          }
          $408 = (($i$026) + 1)|0;
          $409 = (($subglyph$025) + 32|0);
          $exitcond = ($408|0)==($384|0);
          if ($exitcond) {
           $411 = $391;$i$0$lcssa = $384;
           break;
          } else {
           $i$026 = $408;$subglyph$025 = $409;
          }
         }
        } else {
         $$pre40 = HEAP32[$deltas>>2]|0;
         $411 = $$pre40;$i$0$lcssa = 0;
        }
        $410 = (($411) + ($i$0$lcssa<<3)|0);
        $412 = HEAP32[$410>>2]|0;
        $413 = HEAP32[$145>>2]|0;
        $414 = (($413) + ($412))|0;
        HEAP32[$145>>2] = $414;
        $415 = ((($411) + ($i$0$lcssa<<3)|0) + 4|0);
        $416 = HEAP32[$415>>2]|0;
        $417 = HEAP32[$146>>2]|0;
        $418 = (($417) + ($416))|0;
        HEAP32[$146>>2] = $418;
        $419 = (($i$0$lcssa) + 1)|0;
        $420 = (($411) + ($419<<3)|0);
        $421 = HEAP32[$420>>2]|0;
        $422 = HEAP32[$149>>2]|0;
        $423 = (($422) + ($421))|0;
        HEAP32[$149>>2] = $423;
        $424 = ((($411) + ($419<<3)|0) + 4|0);
        $425 = HEAP32[$424>>2]|0;
        $426 = HEAP32[$150>>2]|0;
        $427 = (($426) + ($425))|0;
        HEAP32[$150>>2] = $427;
        $428 = (($i$0$lcssa) + 2)|0;
        $429 = (($411) + ($428<<3)|0);
        $430 = HEAP32[$429>>2]|0;
        $431 = HEAP32[$151>>2]|0;
        $432 = (($431) + ($430))|0;
        HEAP32[$151>>2] = $432;
        $433 = ((($411) + ($428<<3)|0) + 4|0);
        $434 = HEAP32[$433>>2]|0;
        $435 = HEAP32[$156>>2]|0;
        $436 = (($435) + ($434))|0;
        HEAP32[$156>>2] = $436;
        $437 = (($i$0$lcssa) + 3)|0;
        $438 = (($411) + ($437<<3)|0);
        $439 = HEAP32[$438>>2]|0;
        $440 = HEAP32[$157>>2]|0;
        $441 = (($440) + ($439))|0;
        HEAP32[$157>>2] = $441;
        $442 = ((($411) + ($437<<3)|0) + 4|0);
        $443 = HEAP32[$442>>2]|0;
        $444 = HEAP32[$160>>2]|0;
        $445 = (($444) + ($443))|0;
        HEAP32[$160>>2] = $445;
        _ft_mem_free($378,$411);
        HEAP32[$deltas>>2] = 0;
       }
       $446 = HEAP32[$13>>2]|0;
       $447 = $446 & 1;
       $448 = ($447|0)==(0);
       if ($448) {
        $449 = HEAP32[$145>>2]|0;
        $450 = (_FT_MulFix($449,$x_scale$0)|0);
        HEAP32[$145>>2] = $450;
        $451 = HEAP32[$149>>2]|0;
        $452 = (_FT_MulFix($451,$x_scale$0)|0);
        HEAP32[$149>>2] = $452;
        $453 = HEAP32[$156>>2]|0;
        $454 = (_FT_MulFix($453,$y_scale$0)|0);
        HEAP32[$156>>2] = $454;
        $455 = HEAP32[$160>>2]|0;
        $456 = (_FT_MulFix($455,$y_scale$0)|0);
        HEAP32[$160>>2] = $456;
        $$pre = HEAP32[$13>>2]|0;
        $458 = $$pre;
       } else {
        $458 = $446;
       }
       $457 = $458 & 1024;
       $459 = ($457|0)==(0);
       if (!($459)) {
        _FT_GlyphLoader_Add($2);
        $460 = (($loader) + 8|0);
        $461 = HEAP32[$460>>2]|0;
        $462 = (($461) + 72|0);
        HEAP32[$462>>2] = 1668246896;
        $error$314 = 0;
        STACKTOP = sp;return ($error$314|0);
       }
       $463 = (($2) + 84|0);
       $464 = HEAP32[$463>>2]|0;
       $465 = (($2) + 48|0);
       $466 = HEAP32[$465>>2]|0;
       $467 = (($loader) + 24|0);
       $468 = HEAP32[$467>>2]|0;
       $469 = HEAP32[$51>>2]|0;
       _FT_GlyphLoader_Add($2);
       $470 = ($464|0)==(0);
       L87: do {
        if ($470) {
         $num_points$0$lcssa = $362;$subglyph2$0$lcssa = 0;
        } else {
         $471 = (($2) + 52|0);
         $472 = (($recurse_count) + 1)|0;
         $473 = (($loader) + 4|0);
         $n$021 = 0;
         while(1) {
          $474 = HEAP32[$471>>2]|0;
          $$sum = (($n$021) + ($466))|0;
          $475 = $145;
          $476 = $475;
          $477 = HEAP32[$476>>2]|0;
          $478 = (($475) + 4)|0;
          $479 = $478;
          $480 = HEAP32[$479>>2]|0;
          $481 = $149;
          $482 = $481;
          $483 = HEAP32[$482>>2]|0;
          $484 = (($481) + 4)|0;
          $485 = $484;
          $486 = HEAP32[$485>>2]|0;
          $487 = $151;
          $488 = $487;
          $489 = HEAP32[$488>>2]|0;
          $490 = (($487) + 4)|0;
          $491 = $490;
          $492 = HEAP32[$491>>2]|0;
          $493 = $157;
          $494 = $493;
          $495 = HEAP32[$494>>2]|0;
          $496 = (($493) + 4)|0;
          $497 = $496;
          $498 = HEAP32[$497>>2]|0;
          $499 = HEAP16[$360>>1]|0;
          $500 = $499 << 16 >> 16;
          $501 = (($474) + ($$sum<<5)|0);
          $502 = HEAP32[$501>>2]|0;
          $503 = (_load_truetype_glyph($loader,$502,$472,0)|0);
          $504 = ($503|0)==(0);
          if (!($504)) {
           $error$314 = $503;
           break;
          }
          $505 = HEAP32[$471>>2]|0;
          $506 = (($505) + ($$sum<<5)|0);
          $507 = ((($505) + ($$sum<<5)|0) + 4|0);
          $508 = HEAP16[$507>>1]|0;
          $509 = $508 & 512;
          $510 = ($509<<16>>16)==(0);
          if ($510) {
           $511 = $145;
           $512 = $511;
           HEAP32[$512>>2] = $477;
           $513 = (($511) + 4)|0;
           $514 = $513;
           HEAP32[$514>>2] = $480;
           $515 = $149;
           $516 = $515;
           HEAP32[$516>>2] = $483;
           $517 = (($515) + 4)|0;
           $518 = $517;
           HEAP32[$518>>2] = $486;
           $519 = $151;
           $520 = $519;
           HEAP32[$520>>2] = $489;
           $521 = (($519) + 4)|0;
           $522 = $521;
           HEAP32[$522>>2] = $492;
           $523 = $157;
           $524 = $523;
           HEAP32[$524>>2] = $495;
           $525 = (($523) + 4)|0;
           $526 = $525;
           HEAP32[$526>>2] = $498;
          }
          $527 = HEAP16[$360>>1]|0;
          $528 = $527 << 16 >> 16;
          $529 = ($527<<16>>16)==($499<<16>>16);
          L95: do {
           if (!($529)) {
            $530 = HEAP32[$1>>2]|0;
            $531 = (($530) + 24|0);
            $532 = HEAP32[$531>>2]|0;
            $533 = (($530) + 22|0);
            $534 = HEAP16[$533>>1]|0;
            $535 = $534 << 16 >> 16;
            $536 = HEAP16[$507>>1]|0;
            $537 = $536 & 200;
            $538 = ($537<<16>>16)==(0);
            $$not$i = $538 ^ 1;
            $539 = ($534&65535)>($499&65535);
            $or$cond6$i = $539 & $$not$i;
            if ($or$cond6$i) {
             $540 = ((($505) + ($$sum<<5)|0) + 16|0);
             $i$04$i = $500;
             while(1) {
              $541 = (($532) + ($i$04$i<<3)|0);
              _FT_Vector_Transform($541,$540);
              $542 = (($i$04$i) + 1)|0;
              $exitcond$i6 = ($542|0)==($535|0);
              if ($exitcond$i6) {
               break;
              } else {
               $i$04$i = $542;
              }
             }
             $$pre$pre$i = HEAP16[$507>>1]|0;
             $544 = $$pre$pre$i;
            } else {
             $544 = $536;
            }
            $543 = $544 & 2;
            $545 = ($543<<16>>16)==(0);
            $546 = ((($505) + ($$sum<<5)|0) + 8|0);
            $547 = HEAP32[$546>>2]|0;
            $548 = ((($505) + ($$sum<<5)|0) + 12|0);
            $549 = HEAP32[$548>>2]|0;
            do {
             if ($545) {
              $550 = (($547) + ($362))|0;
              $551 = (($549) + ($500))|0;
              $552 = ($550>>>0)<($500>>>0);
              $553 = ($551>>>0)<($535>>>0);
              $or$cond$i = $552 & $553;
              if (!($or$cond$i)) {
               break L95;
              }
              $554 = HEAP32[$531>>2]|0;
              $555 = (($554) + ($550<<3)|0);
              $556 = HEAP32[$555>>2]|0;
              $557 = (($554) + ($551<<3)|0);
              $558 = HEAP32[$557>>2]|0;
              $559 = (($556) - ($558))|0;
              $560 = ((($554) + ($550<<3)|0) + 4|0);
              $561 = HEAP32[$560>>2]|0;
              $562 = ((($554) + ($551<<3)|0) + 4|0);
              $563 = HEAP32[$562>>2]|0;
              $564 = (($561) - ($563))|0;
              $x$1$i = $559;$y$1$i = $564;
             } else {
              $565 = $549 | $547;
              $566 = ($565|0)==(0);
              if ($566) {
               break L95;
              }
              do {
               if ($538) {
                $x$0$i = $547;$y$0$i = $549;
               } else {
                $567 = $544 & 2048;
                $568 = ($567<<16>>16)==(0);
                if ($568) {
                 $x$0$i = $547;$y$0$i = $549;
                 break;
                }
                $569 = ((($505) + ($$sum<<5)|0) + 16|0);
                $570 = HEAP32[$569>>2]|0;
                $571 = (_FT_MulFix($570,$570)|0);
                $572 = ((($505) + ($$sum<<5)|0) + 20|0);
                $573 = HEAP32[$572>>2]|0;
                $574 = (_FT_MulFix($573,$573)|0);
                $575 = (($574) + ($571))|0;
                $576 = (_FT_SqrtFixed($575)|0);
                $577 = ((($505) + ($$sum<<5)|0) + 28|0);
                $578 = HEAP32[$577>>2]|0;
                $579 = (_FT_MulFix($578,$578)|0);
                $580 = ((($505) + ($$sum<<5)|0) + 24|0);
                $581 = HEAP32[$580>>2]|0;
                $582 = (_FT_MulFix($581,$581)|0);
                $583 = (($582) + ($579))|0;
                $584 = (_FT_SqrtFixed($583)|0);
                $585 = (_FT_MulFix($547,$576)|0);
                $586 = (_FT_MulFix($549,$584)|0);
                $x$0$i = $585;$y$0$i = $586;
               }
              } while(0);
              $587 = HEAP32[$13>>2]|0;
              $588 = $587 & 1;
              $589 = ($588|0)==(0);
              if (!($589)) {
               $x$1$i = $x$0$i;$y$1$i = $y$0$i;
               break;
              }
              $590 = HEAP32[$473>>2]|0;
              $591 = (($590) + 48|0);
              $592 = HEAP32[$591>>2]|0;
              $593 = (($590) + 52|0);
              $594 = HEAP32[$593>>2]|0;
              $595 = (_FT_MulFix($x$0$i,$592)|0);
              $596 = (_FT_MulFix($y$0$i,$594)|0);
              $597 = HEAP16[$507>>1]|0;
              $598 = $597 & 4;
              $599 = ($598<<16>>16)==(0);
              if ($599) {
               $x$1$i = $595;$y$1$i = $596;
               break;
              }
              $600 = (($595) + 32)|0;
              $601 = $600 & -64;
              $602 = (($596) + 32)|0;
              $603 = $602 & -64;
              $x$1$i = $601;$y$1$i = $603;
             }
            } while(0);
            $604 = ($y$1$i|0)==(0);
            $605 = $x$1$i | $y$1$i;
            $606 = ($605|0)==(0);
            if ($606) {
             break;
            }
            $607 = ($x$1$i|0)==(0);
            $608 = (($535) - ($500))|0;
            $609 = ($534<<16>>16)==($499<<16>>16);
            $or$cond$i$i = $607 | $609;
            if (!($or$cond$i$i)) {
             $k$04$i$i = 0;
             while(1) {
              $$sum$i = (($k$04$i$i) + ($500))|0;
              $610 = (($532) + ($$sum$i<<3)|0);
              $611 = HEAP32[$610>>2]|0;
              $612 = (($611) + ($x$1$i))|0;
              HEAP32[$610>>2] = $612;
              $613 = (($k$04$i$i) + 1)|0;
              $exitcond6$i$i = ($613|0)==($608|0);
              if ($exitcond6$i$i) {
               break;
              } else {
               $k$04$i$i = $613;
              }
             }
            }
            $or$cond7$i$i = $604 | $609;
            if ($or$cond7$i$i) {
             break;
            } else {
             $k$11$i$i = 0;
            }
            while(1) {
             $$sum3$i = (($k$11$i$i) + ($500))|0;
             $614 = ((($532) + ($$sum3$i<<3)|0) + 4|0);
             $615 = HEAP32[$614>>2]|0;
             $616 = (($615) + ($y$1$i))|0;
             HEAP32[$614>>2] = $616;
             $617 = (($k$11$i$i) + 1)|0;
             $exitcond$i$i = ($617|0)==($608|0);
             if ($exitcond$i$i) {
              break;
             } else {
              $k$11$i$i = $617;
             }
            }
           }
          } while(0);
          $618 = (($n$021) + 1)|0;
          $619 = ($618>>>0)<($464>>>0);
          if ($619) {
           $n$021 = $618;
          } else {
           $num_points$0$lcssa = $528;$subglyph2$0$lcssa = $506;
           break L87;
          }
         }
         STACKTOP = sp;return ($error$314|0);
        }
       } while(0);
       HEAP32[$467>>2] = $468;
       HEAP32[$51>>2] = $469;
       HEAP32[$370>>2] = $371;
       $620 = HEAP32[$13>>2]|0;
       $621 = $620 & 2;
       $622 = ($621|0)==(0);
       if (!($622)) {
        $error$314 = 0;
        STACKTOP = sp;return ($error$314|0);
       }
       $623 = (($subglyph2$0$lcssa) + 4|0);
       $624 = HEAP16[$623>>1]|0;
       $625 = $624 & 256;
       $626 = ($625<<16>>16)!=(0);
       $627 = ($num_points$0$lcssa>>>0)>($362>>>0);
       $or$cond3 = $626 & $627;
       if (!($or$cond3)) {
        $error$314 = 0;
        STACKTOP = sp;return ($error$314|0);
       }
       $628 = HEAP32[$1>>2]|0;
       $629 = (($628) + 22|0);
       $630 = HEAP16[$629>>1]|0;
       $631 = $630 << 16 >> 16;
       $632 = (($631) + 4)|0;
       $633 = ($632|0)==(0);
       do {
        if ($633) {
         label = 87;
        } else {
         $634 = (($628) + 58|0);
         $635 = HEAP16[$634>>1]|0;
         $636 = $635 << 16 >> 16;
         $637 = (($632) + ($631))|0;
         $638 = (($637) + ($636))|0;
         $639 = (($628) + 4|0);
         $640 = HEAP32[$639>>2]|0;
         $641 = ($638>>>0)>($640>>>0);
         if (!($641)) {
          label = 87;
          break;
         }
         $642 = (_FT_GlyphLoader_CheckPoints($628,$632,0)|0);
         HEAP32[$error$i>>2] = $642;
         $643 = ($642|0)==(0);
         if ($643) {
          $$pre$i7 = HEAP16[$629>>1]|0;
          $645 = $$pre$i7;
          break;
         } else {
          $error$314 = 0;
          STACKTOP = sp;return ($error$314|0);
         }
        }
       } while(0);
       if ((label|0) == 87) {
        HEAP32[$error$i>>2] = 0;
        $645 = $630;
       }
       $644 = $645 << 16 >> 16;
       $646 = (($628) + 24|0);
       $647 = HEAP32[$646>>2]|0;
       $648 = (($647) + ($644<<3)|0);
       $649 = $145;
       $650 = $649;
       $651 = HEAP32[$650>>2]|0;
       $652 = (($649) + 4)|0;
       $653 = $652;
       $654 = HEAP32[$653>>2]|0;
       $655 = $648;
       $656 = $655;
       HEAP32[$656>>2] = $651;
       $657 = (($655) + 4)|0;
       $658 = $657;
       HEAP32[$658>>2] = $654;
       $659 = HEAP16[$629>>1]|0;
       $660 = $659 << 16 >> 16;
       $661 = (($660) + 1)|0;
       $662 = HEAP32[$646>>2]|0;
       $663 = (($662) + ($661<<3)|0);
       $664 = $149;
       $665 = $664;
       $666 = HEAP32[$665>>2]|0;
       $667 = (($664) + 4)|0;
       $668 = $667;
       $669 = HEAP32[$668>>2]|0;
       $670 = $663;
       $671 = $670;
       HEAP32[$671>>2] = $666;
       $672 = (($670) + 4)|0;
       $673 = $672;
       HEAP32[$673>>2] = $669;
       $674 = HEAP16[$629>>1]|0;
       $675 = $674 << 16 >> 16;
       $676 = (($675) + 2)|0;
       $677 = HEAP32[$646>>2]|0;
       $678 = (($677) + ($676<<3)|0);
       $679 = $151;
       $680 = $679;
       $681 = HEAP32[$680>>2]|0;
       $682 = (($679) + 4)|0;
       $683 = $682;
       $684 = HEAP32[$683>>2]|0;
       $685 = $678;
       $686 = $685;
       HEAP32[$686>>2] = $681;
       $687 = (($685) + 4)|0;
       $688 = $687;
       HEAP32[$688>>2] = $684;
       $689 = HEAP16[$629>>1]|0;
       $690 = $689 << 16 >> 16;
       $691 = (($690) + 3)|0;
       $692 = HEAP32[$646>>2]|0;
       $693 = (($692) + ($691<<3)|0);
       $694 = $157;
       $695 = $694;
       $696 = HEAP32[$695>>2]|0;
       $697 = (($694) + 4)|0;
       $698 = $697;
       $699 = HEAP32[$698>>2]|0;
       $700 = $693;
       $701 = $700;
       HEAP32[$701>>2] = $696;
       $702 = (($700) + 4)|0;
       $703 = $702;
       HEAP32[$703>>2] = $699;
       $704 = HEAP16[$629>>1]|0;
       $705 = $704 << 16 >> 16;
       $706 = (($628) + 28|0);
       $707 = HEAP32[$706>>2]|0;
       $708 = (($707) + ($705)|0);
       HEAP8[$708>>0] = 0;
       $709 = HEAP16[$629>>1]|0;
       $710 = $709 << 16 >> 16;
       $711 = (($710) + 1)|0;
       $712 = HEAP32[$706>>2]|0;
       $713 = (($712) + ($711)|0);
       HEAP8[$713>>0] = 0;
       $714 = HEAP16[$629>>1]|0;
       $715 = $714 << 16 >> 16;
       $716 = (($715) + 2)|0;
       $717 = HEAP32[$706>>2]|0;
       $718 = (($717) + ($716)|0);
       HEAP8[$718>>0] = 0;
       $719 = HEAP16[$629>>1]|0;
       $720 = $719 << 16 >> 16;
       $721 = (($720) + 3)|0;
       $722 = HEAP32[$706>>2]|0;
       $723 = (($722) + ($721)|0);
       HEAP8[$723>>0] = 0;
       $724 = HEAP32[$467>>2]|0;
       $725 = HEAP32[$370>>2]|0;
       $726 = (_FT_Stream_Seek($724,$725)|0);
       HEAP32[$error$i>>2] = $726;
       $727 = ($726|0)==(0);
       if (!($727)) {
        $error$314 = 0;
        STACKTOP = sp;return ($error$314|0);
       }
       $728 = (_FT_Stream_ReadUShort($724,$error$i)|0);
       $729 = HEAP32[$error$i>>2]|0;
       $730 = ($729|0)==(0);
       if (!($730)) {
        $error$314 = 0;
        STACKTOP = sp;return ($error$314|0);
       }
       $731 = HEAP32[$loader>>2]|0;
       $732 = (($731) + 260|0);
       $733 = (($732) + 26|0);
       $734 = HEAP16[$733>>1]|0;
       $735 = $728&65535;
       $736 = ($728&65535)>($734&65535);
       do {
        if ($736) {
         $737 = HEAP32[$51>>2]|0;
         $738 = ($735|0)>($737|0);
         if ($738) {
          $error$314 = 0;
          STACKTOP = sp;return ($error$314|0);
         }
         $739 = (($loader) + 160|0);
         $740 = HEAP32[$739>>2]|0;
         $741 = (($740) + 388|0);
         $742 = HEAP32[$741>>2]|0;
         HEAP32[$tmp$i>>2] = $742;
         $743 = (($740) + 8|0);
         $744 = HEAP32[$743>>2]|0;
         $745 = (($740) + 392|0);
         $746 = (_Update_Max($744,$tmp$i,1,$745,$735)|0);
         HEAP32[$error$i>>2] = $746;
         $747 = HEAP32[$tmp$i>>2]|0;
         $748 = $747 & 65535;
         $749 = HEAP32[$739>>2]|0;
         $750 = (($749) + 388|0);
         HEAP32[$750>>2] = $748;
         $751 = HEAP32[$error$i>>2]|0;
         $752 = ($751|0)==(0);
         if ($752) {
          $755 = $749;
          break;
         } else {
          $error$314 = 0;
         }
         STACKTOP = sp;return ($error$314|0);
        } else {
         $753 = ($728<<16>>16)==(0);
         if ($753) {
          $error$314 = 0;
          STACKTOP = sp;return ($error$314|0);
         } else {
          $$phi$trans$insert$i = (($loader) + 160|0);
          $$pre7$i = HEAP32[$$phi$trans$insert$i>>2]|0;
          $755 = $$pre7$i;
          break;
         }
        }
       } while(0);
       $754 = (($755) + 392|0);
       $756 = HEAP32[$754>>2]|0;
       $757 = (_FT_Stream_Read($724,$756,$735)|0);
       HEAP32[$error$i>>2] = $757;
       $758 = ($757|0)==(0);
       if (!($758)) {
        $error$314 = 0;
        STACKTOP = sp;return ($error$314|0);
       }
       $759 = (($loader) + 160|0);
       $760 = HEAP32[$759>>2]|0;
       $761 = (($760) + 392|0);
       $762 = HEAP32[$761>>2]|0;
       $763 = (($loader) + 8|0);
       $764 = HEAP32[$763>>2]|0;
       $765 = (($764) + 136|0);
       HEAP32[$765>>2] = $762;
       $766 = HEAP32[$763>>2]|0;
       $767 = (($766) + 140|0);
       HEAP32[$767>>2] = $735;
       $768 = HEAP32[$1>>2]|0;
       $769 = (($768) + 22|0);
       $770 = HEAP16[$769>>1]|0;
       $771 = $770&65535;
       $772 = (($771) - ($362))|0;
       $773 = $772&65535;
       $774 = (($loader) + 132|0);
       HEAP16[$774>>1] = $773;
       $775 = (($768) + 20|0);
       $776 = HEAP16[$775>>1]|0;
       $777 = $776&65535;
       $778 = (($777) - ($365))|0;
       $779 = $778&65535;
       $780 = (($loader) + 134|0);
       HEAP16[$780>>1] = $779;
       $781 = (($768) + 40|0);
       $782 = HEAP32[$781>>2]|0;
       $783 = (($782) + ($362<<3)|0);
       $784 = (($loader) + 136|0);
       HEAP32[$784>>2] = $783;
       $785 = (($768) + 24|0);
       $786 = HEAP32[$785>>2]|0;
       $787 = (($786) + ($362<<3)|0);
       $788 = (($loader) + 140|0);
       HEAP32[$788>>2] = $787;
       $789 = (($768) + 44|0);
       $790 = HEAP32[$789>>2]|0;
       $791 = (($790) + ($362<<3)|0);
       $792 = (($loader) + 144|0);
       HEAP32[$792>>2] = $791;
       $793 = (($768) + 28|0);
       $794 = HEAP32[$793>>2]|0;
       $795 = (($794) + ($362)|0);
       $796 = (($loader) + 148|0);
       HEAP32[$796>>2] = $795;
       $797 = (($768) + 32|0);
       $798 = HEAP32[$797>>2]|0;
       $799 = (($798) + ($365<<1)|0);
       $800 = (($loader) + 152|0);
       HEAP32[$800>>2] = $799;
       $801 = (($loader) + 156|0);
       HEAP16[$801>>1] = $361;
       $802 = $772 & 65535;
       $803 = ($802>>>0)>($362>>>0);
       do {
        if ($803) {
         $$sum31 = $362 << 1;
         $804 = (($794) + ($$sum31)|0);
         $805 = HEAP8[$804>>0]|0;
         $806 = $805&255;
         $807 = $806 & 231;
         $808 = $807&255;
         HEAP8[$804>>0] = $808;
         $809 = (($362) + 1)|0;
         $810 = HEAP16[$774>>1]|0;
         $811 = $810&65535;
         $812 = ($809>>>0)<($811>>>0);
         if ($812) {
          $814 = $809;
         } else {
          $$lcssa1$i = $811;
          break;
         }
         while(1) {
          $$pre8$i = HEAP32[$796>>2]|0;
          $813 = (($$pre8$i) + ($814)|0);
          $815 = HEAP8[$813>>0]|0;
          $816 = $815&255;
          $817 = $816 & 231;
          $818 = $817&255;
          HEAP8[$813>>0] = $818;
          $819 = (($814) + 1)|0;
          $820 = HEAP16[$774>>1]|0;
          $821 = $820&65535;
          $822 = ($819>>>0)<($821>>>0);
          if ($822) {
           $814 = $819;
          } else {
           $$lcssa1$i = $821;
           break;
          }
         }
        } else {
         $$lcssa1$i = $802;
        }
       } while(0);
       $823 = (($$lcssa1$i) + 4)|0;
       $824 = $823&65535;
       HEAP16[$774>>1] = $824;
       (_TT_Hint_Glyph($loader,1)|0);
       $error$314 = 0;
       STACKTOP = sp;return ($error$314|0);
      } else {
       $error$3 = $368;
      }
     } else {
      $error$3 = 20;
     }
    }
   }
  } while(0);
  do {
   if ((label|0) == 18) {
    $73 = (($loader) + 36|0);
    $74 = ($header_only<<24>>24)==(0);
    ;HEAP32[$73+0>>2]=0|0;HEAP32[$73+4>>2]=0|0;HEAP32[$73+8>>2]=0|0;HEAP32[$73+12>>2]=0|0;
    if ($74) {
     $75 = HEAP32[$37>>2]|0;
     $76 = (0 - ($75))|0;
     $77 = (($loader) + 68|0);
     HEAP32[$77>>2] = $76;
     $78 = (($loader) + 72|0);
     HEAP32[$78>>2] = 0;
     $79 = HEAP32[$40>>2]|0;
     $80 = (($79) - ($75))|0;
     $81 = (($loader) + 76|0);
     HEAP32[$81>>2] = $80;
     $82 = (($loader) + 80|0);
     HEAP32[$82>>2] = 0;
     $83 = (($loader) + 184|0);
     HEAP32[$83>>2] = 0;
     $84 = HEAP32[$43>>2]|0;
     $85 = (($loader) + 188|0);
     HEAP32[$85>>2] = $84;
     $86 = (($loader) + 192|0);
     HEAP32[$86>>2] = 0;
     $87 = HEAP32[$46>>2]|0;
     $88 = (($84) - ($87))|0;
     $89 = (($loader) + 196|0);
     HEAP32[$89>>2] = $88;
     $90 = HEAP32[$loader>>2]|0;
     $91 = (($90) + 708|0);
     $92 = HEAP8[$91>>0]|0;
     $93 = ($92<<24>>24)==(0);
     if (!($93)) {
      $94 = (($90) + 100|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = (_TT_Vary_Get_Glyph_Deltas($90,$glyph_index,$deltas,4)|0);
      $97 = ($96|0)==(0);
      if (!($97)) {
       $error$3 = $96;
       break;
      }
      $98 = HEAP32[$deltas>>2]|0;
      $99 = HEAP32[$98>>2]|0;
      $100 = HEAP32[$77>>2]|0;
      $101 = (($100) + ($99))|0;
      HEAP32[$77>>2] = $101;
      $102 = (($98) + 4|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = HEAP32[$78>>2]|0;
      $105 = (($104) + ($103))|0;
      HEAP32[$78>>2] = $105;
      $106 = (($98) + 8|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = HEAP32[$81>>2]|0;
      $109 = (($108) + ($107))|0;
      HEAP32[$81>>2] = $109;
      $110 = (($98) + 12|0);
      $111 = HEAP32[$110>>2]|0;
      $112 = HEAP32[$82>>2]|0;
      $113 = (($112) + ($111))|0;
      HEAP32[$82>>2] = $113;
      $114 = (($98) + 16|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = HEAP32[$83>>2]|0;
      $117 = (($116) + ($115))|0;
      HEAP32[$83>>2] = $117;
      $118 = (($98) + 20|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = HEAP32[$85>>2]|0;
      $121 = (($120) + ($119))|0;
      HEAP32[$85>>2] = $121;
      $122 = (($98) + 24|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = HEAP32[$86>>2]|0;
      $125 = (($124) + ($123))|0;
      HEAP32[$86>>2] = $125;
      $126 = (($98) + 28|0);
      $127 = HEAP32[$126>>2]|0;
      $128 = HEAP32[$89>>2]|0;
      $129 = (($128) + ($127))|0;
      HEAP32[$89>>2] = $129;
      _ft_mem_free($95,$98);
      HEAP32[$deltas>>2] = 0;
     }
     $130 = HEAP32[$13>>2]|0;
     $131 = $130 & 1;
     $132 = ($131|0)==(0);
     if ($132) {
      $133 = HEAP32[$77>>2]|0;
      $134 = (_FT_MulFix($133,$x_scale$0)|0);
      HEAP32[$77>>2] = $134;
      $135 = HEAP32[$81>>2]|0;
      $136 = (_FT_MulFix($135,$x_scale$0)|0);
      HEAP32[$81>>2] = $136;
      $137 = HEAP32[$85>>2]|0;
      $138 = (_FT_MulFix($137,$y_scale$0)|0);
      HEAP32[$85>>2] = $138;
      $139 = HEAP32[$89>>2]|0;
      $140 = (_FT_MulFix($139,$y_scale$0)|0);
      HEAP32[$89>>2] = $140;
      $error$3 = 0;
     } else {
      $error$3 = 0;
     }
    } else {
     $error$3 = 0;
    }
   }
  } while(0);
  $825 = ($opened_frame$0<<24>>24)==(0);
  if ($825) {
   $error$314 = $error$3;
   STACKTOP = sp;return ($error$314|0);
  } else {
   $error$316 = $error$3;
  }
 }
 $826 = (($0) + 516|0);
 $827 = HEAP32[$826>>2]|0;
 FUNCTION_TABLE_vi[$827 & 4095]($loader);
 $error$314 = $error$316;
 STACKTOP = sp;return ($error$314|0);
}
function _TT_Hint_Glyph($loader,$is_composite) {
 $loader = $loader|0;
 $is_composite = $is_composite|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond6$i = 0;
 var $k$04$i = 0, $phitmp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($loader) + 124|0);
 $1 = (($loader) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($loader) + 132|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6&65535;
 $8 = (($7) + -4)|0;
 $9 = (($loader) + 140|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($8<<3)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 32)|0;
 $14 = $13 & -64;
 $15 = ($14|0)==($12|0);
 if (!($15)) {
  $16 = (($14) - ($12))|0;
  $17 = ($6<<16>>16)==(0);
  if (!($17)) {
   $k$04$i = 0;
   while(1) {
    $18 = (($10) + ($k$04$i<<3)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($16) + ($19))|0;
    HEAP32[$18>>2] = $20;
    $21 = (($k$04$i) + 1)|0;
    $exitcond6$i = ($21|0)==($7|0);
    if ($exitcond6$i) {
     break;
    } else {
     $k$04$i = $21;
    }
   }
  }
 }
 $22 = ($4|0)!=(0);
 if ($22) {
  $23 = (($loader) + 136|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $7 << 3;
  _memcpy(($24|0),($10|0),($25|0))|0;
 }
 $26 = (($loader) + 160|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 284|0);
 $29 = (($loader) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 172|0);
 dest=$28+0|0; src=$31+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $32 = ($is_composite<<24>>24)==(0);
 if ($32) {
  $42 = HEAP32[$29>>2]|0;
  $43 = (($42) + 48|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = HEAP32[$26>>2]|0;
  $46 = (($45) + 220|0);
  HEAP32[$46>>2] = $44;
  $47 = (($42) + 52|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($45) + 224|0);
  HEAP32[$49>>2] = $48;
 } else {
  $33 = HEAP32[$26>>2]|0;
  $34 = (($33) + 220|0);
  HEAP32[$34>>2] = 65536;
  $35 = (($33) + 224|0);
  HEAP32[$35>>2] = 65536;
  $36 = (($loader) + 144|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = HEAP32[$9>>2]|0;
  $39 = HEAP16[$5>>1]|0;
  $40 = $39&65535;
  $41 = $40 << 3;
  _memcpy(($37|0),($38|0),($41|0))|0;
 }
 $50 = HEAP16[$5>>1]|0;
 $51 = $50&65535;
 $52 = (($51) + -3)|0;
 $53 = HEAP32[$9>>2]|0;
 $54 = (($53) + ($52<<3)|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 32)|0;
 $57 = $56 & -64;
 HEAP32[$54>>2] = $57;
 $58 = (($51) + -1)|0;
 $59 = ((($53) + ($58<<3)|0) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($60) + 32)|0;
 $62 = $61 & -64;
 HEAP32[$59>>2] = $62;
 if ($22) {
  $63 = (($loader) + 12|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($64) + 64|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = HEAP32[$26>>2]|0;
  $68 = (($67) + 392|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (_TT_Set_CodeRange($67,3,$69,$4)|0);
  $71 = ($70|0)==(0);
  if (!($71)) {
   $$0 = $70;
   STACKTOP = sp;return ($$0|0);
  }
  $72 = HEAP32[$26>>2]|0;
  $73 = (($72) + 560|0);
  HEAP8[$73>>0] = $is_composite;
  $74 = HEAP32[$26>>2]|0;
  $75 = (($74) + 144|0);
  dest=$75+0|0; src=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $76 = (($loader) + 16|0);
  $77 = HEAP32[$76>>2]|0;
  $78 = $77 & 1;
  $79 = ($78|0)==(0);
  if ($79) {
   $80 = HEAP32[$29>>2]|0;
   $81 = (($80) + 292|0);
   $82 = HEAP8[$81>>0]|0;
   $83 = ($82<<24>>24)!=(0);
   $phitmp = $83&1;
   $85 = $phitmp;
  } else {
   $85 = 0;
  }
  $84 = HEAP32[$26>>2]|0;
  $86 = (_TT_Run_Context($84,$85)|0);
  $87 = ($86|0)==(0);
  $$pre = HEAP32[$26>>2]|0;
  if (!($87)) {
   $88 = (($$pre) + 561|0);
   $89 = HEAP8[$88>>0]|0;
   $90 = ($89<<24>>24)==(0);
   if (!($90)) {
    $$0 = $86;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $91 = (($$pre) + 340|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = $92 << 5;
  $94 = HEAP8[$66>>0]|0;
  $95 = $94&255;
  $96 = $93 | $95;
  $97 = $96 | 4;
  $98 = $97&255;
  HEAP8[$66>>0] = $98;
 }
 $99 = (($loader) + 65|0);
 $100 = HEAP8[$99>>0]|0;
 $101 = ($100<<24>>24)==(0);
 if (!($101)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $102 = (($loader) + 68|0);
 $103 = HEAP16[$5>>1]|0;
 $104 = $103&65535;
 $105 = (($104) + -4)|0;
 $106 = HEAP32[$9>>2]|0;
 $107 = (($106) + ($105<<3)|0);
 $108 = $107;
 $109 = $108;
 $110 = HEAP32[$109>>2]|0;
 $111 = (($108) + 4)|0;
 $112 = $111;
 $113 = HEAP32[$112>>2]|0;
 $114 = $102;
 $115 = $114;
 HEAP32[$115>>2] = $110;
 $116 = (($114) + 4)|0;
 $117 = $116;
 HEAP32[$117>>2] = $113;
 $118 = (($loader) + 76|0);
 $119 = (($104) + -3)|0;
 $120 = (($106) + ($119<<3)|0);
 $121 = $120;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = (($121) + 4)|0;
 $125 = $124;
 $126 = HEAP32[$125>>2]|0;
 $127 = $118;
 $128 = $127;
 HEAP32[$128>>2] = $123;
 $129 = (($127) + 4)|0;
 $130 = $129;
 HEAP32[$130>>2] = $126;
 $131 = (($loader) + 184|0);
 $132 = (($104) + -2)|0;
 $133 = (($106) + ($132<<3)|0);
 $134 = $133;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = (($134) + 4)|0;
 $138 = $137;
 $139 = HEAP32[$138>>2]|0;
 $140 = $131;
 $141 = $140;
 HEAP32[$141>>2] = $136;
 $142 = (($140) + 4)|0;
 $143 = $142;
 HEAP32[$143>>2] = $139;
 $144 = (($loader) + 192|0);
 $145 = (($104) + -1)|0;
 $146 = (($106) + ($145<<3)|0);
 $147 = $146;
 $148 = $147;
 $149 = HEAP32[$148>>2]|0;
 $150 = (($147) + 4)|0;
 $151 = $150;
 $152 = HEAP32[$151>>2]|0;
 $153 = $144;
 $154 = $153;
 HEAP32[$154>>2] = $149;
 $155 = (($153) + 4)|0;
 $156 = $155;
 HEAP32[$156>>2] = $152;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _TT_Get_MM_Var($face,$master) {
 $face = $face|0;
 $master = $master|0;
 var $$pre = 0, $$pre45 = 0, $$pre46 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$022 = 0, $a$14 = 0, $axis_rec = 0;
 var $error = 0, $fvar_head = 0, $i$031 = 0, $i$126 = 0, $i$221 = 0, $i$316 = 0, $j$011 = 0, $n$07 = 0, $n$15 = 0, $next_coords$0$lcssa = 0, $next_coords$032 = 0, $next_coords$1$lcssa = 0, $next_coords$16 = 0, $next_name$027 = 0, $next_name$13 = 0, $ns$017 = 0, $phitmp = 0, $scevgep = 0, $scevgep38 = 0, $smax = 0;
 var $table_len = 0, $tmp1 = 0, $tmp2 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $table_len = sp + 44|0;
 $error = sp;
 $fvar_head = sp + 8|0;
 $axis_rec = sp + 24|0;
 $0 = (($face) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$error>>2] = 0;
 $4 = (($face) + 712|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 L1: do {
  if ($6) {
   $7 = (($face) + 508|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (FUNCTION_TABLE_iiiii[$8 & 511]($face,1735811442,$1,$table_len)|0);
   HEAP32[$error>>2] = $9;
   $10 = ($9|0)==(0);
   if (!($10)) {
    $212 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($212|0);
   }
   $11 = HEAP32[$7>>2]|0;
   $12 = (FUNCTION_TABLE_iiiii[$11 & 511]($face,1719034226,$1,$table_len)|0);
   HEAP32[$error>>2] = $12;
   $13 = ($12|0)==(0);
   if (!($13)) {
    $212 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($212|0);
   }
   $14 = (_FT_Stream_Pos($1)|0);
   $15 = (_FT_Stream_ReadFields($1,872968,$fvar_head)|0);
   HEAP32[$error>>2] = $15;
   $16 = ($15|0)==(0);
   if (!($16)) {
    $212 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($212|0);
   }
   $17 = HEAP32[$fvar_head>>2]|0;
   $18 = ($17|0)==(65536);
   if ($18) {
    $19 = (($fvar_head) + 6|0);
    $20 = HEAP16[$19>>1]|0;
    $21 = ($20<<16>>16)==(2);
    if ($21) {
     $22 = (($fvar_head) + 10|0);
     $23 = HEAP16[$22>>1]|0;
     $24 = ($23<<16>>16)==(20);
     if ($24) {
      $25 = (($fvar_head) + 8|0);
      $26 = HEAP16[$25>>1]|0;
      $27 = $26&65535;
      $28 = ($26&65535)>(16382);
      if (!($28)) {
       $29 = (($fvar_head) + 14|0);
       $30 = HEAP16[$29>>1]|0;
       $31 = $30&65535;
       $32 = $27 << 2;
       $33 = (($32) + 4)|0;
       $34 = ($31|0)==($33|0);
       if ($34) {
        $35 = (($fvar_head) + 12|0);
        $36 = HEAP16[$35>>1]|0;
        $37 = ($36&65535)>(32511);
        if (!($37)) {
         $38 = $36&65535;
         $39 = (($fvar_head) + 4|0);
         $40 = HEAP16[$39>>1]|0;
         $41 = $40&65535;
         $42 = ($27*20)|0;
         $43 = Math_imul($38, $31)|0;
         $44 = (($43) + ($42))|0;
         $45 = (($44) + ($41))|0;
         $46 = HEAP32[$table_len>>2]|0;
         $47 = ($45>>>0)>($46>>>0);
         if (!($47)) {
          $48 = (_ft_mem_alloc($3,40,$error)|0);
          HEAP32[$4>>2] = $48;
          $49 = HEAP32[$error>>2]|0;
          $50 = ($49|0)==(0);
          if (!($50)) {
           $212 = HEAP32[$error>>2]|0;
           STACKTOP = sp;return ($212|0);
          }
          $51 = HEAP16[$25>>1]|0;
          $52 = $51&65535;
          $53 = HEAP16[$35>>1]|0;
          $54 = $53&65535;
          $55 = $54 << 3;
          $56 = $54 << 2;
          $tmp1 = (($56) + 29)|0;
          $tmp2 = Math_imul($tmp1, $52)|0;
          $57 = (($55) + 20)|0;
          $58 = (($57) + ($tmp2))|0;
          $59 = (($48) + 12|0);
          HEAP32[$59>>2] = $58;
          $60 = (_ft_mem_alloc($3,$58,$error)|0);
          $61 = HEAP32[$error>>2]|0;
          $62 = ($61|0)==(0);
          if (!($62)) {
           $212 = HEAP32[$error>>2]|0;
           STACKTOP = sp;return ($212|0);
          }
          $63 = HEAP32[$4>>2]|0;
          $64 = (($63) + 8|0);
          HEAP32[$64>>2] = $60;
          $65 = HEAP16[$25>>1]|0;
          $66 = $65&65535;
          HEAP32[$60>>2] = $66;
          $67 = (($60) + 4|0);
          HEAP32[$67>>2] = -1;
          $68 = HEAP16[$35>>1]|0;
          $69 = $68&65535;
          $70 = (($60) + 8|0);
          HEAP32[$70>>2] = $69;
          $71 = (($60) + 20|0);
          $72 = (($60) + 12|0);
          HEAP32[$72>>2] = $71;
          $73 = (($71) + (($66*24)|0)|0);
          $74 = (($60) + 16|0);
          HEAP32[$74>>2] = $73;
          $75 = (($73) + ($69<<3)|0);
          $76 = ($68<<16>>16)==(0);
          if ($76) {
           $next_coords$0$lcssa = $75;
          } else {
           $77 = ($66*24)|0;
           $78 = $69 << 3;
           $79 = (($77) + ($78))|0;
           $80 = ($69>>>0)>(1);
           $smax = $80 ? $69 : 1;
           $81 = Math_imul($smax, $66)|0;
           $82 = $81 << 2;
           $83 = (($79) + ($82))|0;
           $84 = (($83) + 20)|0;
           $scevgep38 = (($60) + ($84)|0);
           $86 = $73;$i$031 = 0;$next_coords$032 = $75;
           while(1) {
            $85 = (($86) + ($i$031<<3)|0);
            HEAP32[$85>>2] = $next_coords$032;
            $87 = (($i$031) + 1)|0;
            $88 = ($87|0)<($69|0);
            if (!($88)) {
             break;
            }
            $89 = (($next_coords$032) + ($66<<2)|0);
            $$pre45 = HEAP32[$74>>2]|0;
            $86 = $$pre45;$i$031 = $87;$next_coords$032 = $89;
           }
           $next_coords$0$lcssa = $scevgep38;
          }
          $90 = ($65<<16>>16)==(0);
          L33: do {
           if (!($90)) {
            $i$126 = 0;$next_name$027 = $next_coords$0$lcssa;
            while(1) {
             $91 = HEAP32[$72>>2]|0;
             $92 = (($91) + (($i$126*24)|0)|0);
             HEAP32[$92>>2] = $next_name$027;
             $93 = (($i$126) + 1)|0;
             $94 = ($93|0)<($66|0);
             if (!($94)) {
              break L33;
             }
             $95 = (($next_name$027) + 5|0);
             $i$126 = $93;$next_name$027 = $95;
            }
           }
          } while(0);
          $96 = HEAP16[$39>>1]|0;
          $97 = $96&65535;
          $98 = (($97) + ($14))|0;
          $99 = (_FT_Stream_Seek($1,$98)|0);
          HEAP32[$error>>2] = $99;
          $100 = ($99|0)==(0);
          if (!($100)) {
           $212 = HEAP32[$error>>2]|0;
           STACKTOP = sp;return ($212|0);
          }
          $101 = HEAP16[$25>>1]|0;
          $102 = ($101<<16>>16)==(0);
          L42: do {
           if ($102) {
            $213 = 0;
           } else {
            $103 = HEAP32[$72>>2]|0;
            $104 = (($axis_rec) + 4|0);
            $105 = (($axis_rec) + 8|0);
            $106 = (($axis_rec) + 12|0);
            $107 = (($axis_rec) + 18|0);
            $a$022 = $103;$i$221 = 0;
            while(1) {
             $108 = (_FT_Stream_ReadFields($1,873008,$axis_rec)|0);
             HEAP32[$error>>2] = $108;
             $109 = ($108|0)==(0);
             if (!($109)) {
              break;
             }
             $110 = HEAP32[$axis_rec>>2]|0;
             $111 = (($a$022) + 16|0);
             HEAP32[$111>>2] = $110;
             $112 = HEAP32[$104>>2]|0;
             $113 = (($a$022) + 4|0);
             HEAP32[$113>>2] = $112;
             $114 = HEAP32[$105>>2]|0;
             $115 = (($a$022) + 8|0);
             HEAP32[$115>>2] = $114;
             $116 = HEAP32[$106>>2]|0;
             $117 = (($a$022) + 12|0);
             HEAP32[$117>>2] = $116;
             $118 = HEAP16[$107>>1]|0;
             $119 = $118&65535;
             $120 = (($a$022) + 20|0);
             HEAP32[$120>>2] = $119;
             $121 = $110 >>> 24;
             $122 = $121&255;
             $123 = HEAP32[$a$022>>2]|0;
             HEAP8[$123>>0] = $122;
             $124 = HEAP32[$111>>2]|0;
             $125 = $124 >>> 16;
             $126 = $125&255;
             $127 = HEAP32[$a$022>>2]|0;
             $128 = (($127) + 1|0);
             HEAP8[$128>>0] = $126;
             $129 = HEAP32[$111>>2]|0;
             $130 = $129 >>> 8;
             $131 = $130&255;
             $132 = HEAP32[$a$022>>2]|0;
             $133 = (($132) + 2|0);
             HEAP8[$133>>0] = $131;
             $134 = HEAP32[$111>>2]|0;
             $135 = $134&255;
             $136 = HEAP32[$a$022>>2]|0;
             $137 = (($136) + 3|0);
             HEAP8[$137>>0] = $135;
             $138 = HEAP32[$a$022>>2]|0;
             $139 = (($138) + 4|0);
             HEAP8[$139>>0] = 0;
             $140 = (($a$022) + 24|0);
             $141 = (($i$221) + 1)|0;
             $142 = HEAP16[$25>>1]|0;
             $143 = $142&65535;
             $144 = ($141|0)<($143|0);
             if ($144) {
              $a$022 = $140;$i$221 = $141;
             } else {
              $213 = $142;
              break L42;
             }
            }
            $212 = HEAP32[$error>>2]|0;
            STACKTOP = sp;return ($212|0);
           }
          } while(0);
          $145 = HEAP16[$35>>1]|0;
          $146 = ($145<<16>>16)==(0);
          if ($146) {
           break;
          }
          $147 = HEAP32[$74>>2]|0;
          $149 = $213;$i$316 = 1;$ns$017 = $147;
          while(1) {
           $148 = $149&65535;
           $150 = $148 << 2;
           $151 = (($150) + 4)|0;
           $152 = (_FT_Stream_EnterFrame($1,$151)|0);
           HEAP32[$error>>2] = $152;
           $153 = ($152|0)==(0);
           if (!($153)) {
            break;
           }
           $154 = (_FT_Stream_GetUShort($1)|0);
           $155 = $154&65535;
           $156 = (($ns$017) + 4|0);
           HEAP32[$156>>2] = $155;
           (_FT_Stream_GetUShort($1)|0);
           $157 = HEAP16[$25>>1]|0;
           $158 = ($157<<16>>16)==(0);
           if (!($158)) {
            $j$011 = 0;
            while(1) {
             $159 = (_FT_Stream_GetULong($1)|0);
             $160 = HEAP32[$ns$017>>2]|0;
             $161 = (($160) + ($j$011<<2)|0);
             HEAP32[$161>>2] = $159;
             $162 = (($j$011) + 1)|0;
             $163 = HEAP16[$25>>1]|0;
             $164 = $163&65535;
             $165 = ($162|0)<($164|0);
             if ($165) {
              $j$011 = $162;
             } else {
              break;
             }
            }
           }
           _FT_Stream_ExitFrame($1);
           $166 = HEAP16[$35>>1]|0;
           $167 = $166&65535;
           $168 = ($i$316|0)<($167|0);
           if (!($168)) {
            break L1;
           }
           $169 = (($ns$017) + 8|0);
           $$pre = HEAP16[$25>>1]|0;
           $phitmp = (($i$316) + 1)|0;
           $149 = $$pre;$i$316 = $phitmp;$ns$017 = $169;
          }
          $212 = HEAP32[$error>>2]|0;
          STACKTOP = sp;return ($212|0);
         }
        }
       }
      }
     }
    }
   }
   HEAP32[$error>>2] = 8;
   $212 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($212|0);
  }
 } while(0);
 $170 = ($master|0)==(0|0);
 if ($170) {
  $212 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($212|0);
 }
 $171 = HEAP32[$4>>2]|0;
 $172 = (($171) + 12|0);
 $173 = HEAP32[$172>>2]|0;
 $174 = (_ft_mem_alloc($3,$173,$error)|0);
 $175 = HEAP32[$error>>2]|0;
 $176 = ($175|0)==(0);
 if (!($176)) {
  $212 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($212|0);
 }
 $177 = HEAP32[$4>>2]|0;
 $178 = (($177) + 8|0);
 $179 = HEAP32[$178>>2]|0;
 $180 = (($177) + 12|0);
 $181 = HEAP32[$180>>2]|0;
 _memcpy(($174|0),($179|0),($181|0))|0;
 $182 = (($174) + 20|0);
 $183 = (($174) + 12|0);
 HEAP32[$183>>2] = $182;
 $184 = HEAP32[$174>>2]|0;
 $185 = (($182) + (($184*24)|0)|0);
 $186 = (($174) + 16|0);
 HEAP32[$186>>2] = $185;
 $187 = (($174) + 8|0);
 $188 = HEAP32[$187>>2]|0;
 $189 = (($185) + ($188<<3)|0);
 $190 = ($188|0)==(0);
 if ($190) {
  $next_coords$1$lcssa = $189;
 } else {
  $191 = ($184*24)|0;
  $192 = $188 << 3;
  $193 = (($191) + ($192))|0;
  $194 = ($188>>>0)>(1);
  $umax = $194 ? $188 : 1;
  $195 = Math_imul($184, $umax)|0;
  $196 = $195 << 2;
  $197 = (($193) + ($196))|0;
  $198 = (($197) + 20)|0;
  $scevgep = (($174) + ($198)|0);
  $200 = $185;$n$07 = 0;$next_coords$16 = $189;
  while(1) {
   $199 = (($200) + ($n$07<<3)|0);
   HEAP32[$199>>2] = $next_coords$16;
   $201 = (($n$07) + 1)|0;
   $202 = ($201>>>0)<($188>>>0);
   if (!($202)) {
    break;
   }
   $203 = (($next_coords$16) + ($184<<2)|0);
   $$pre46 = HEAP32[$186>>2]|0;
   $200 = $$pre46;$n$07 = $201;$next_coords$16 = $203;
  }
  $next_coords$1$lcssa = $scevgep;
 }
 $204 = ($184|0)==(0);
 if (!($204)) {
  $205 = HEAP32[$183>>2]|0;
  $a$14 = $205;$n$15 = 0;$next_name$13 = $next_coords$1$lcssa;
  while(1) {
   HEAP32[$a$14>>2] = $next_name$13;
   $206 = (($a$14) + 16|0);
   $207 = HEAP32[$206>>2]|0;
   if ((($207|0) == 1936486004)) {
    HEAP32[$a$14>>2] = 873072;
   } else if ((($207|0) == 2003265652)) {
    HEAP32[$a$14>>2] = 873040;
   } else if ((($207|0) == 2003072104)) {
    HEAP32[$a$14>>2] = 873048;
   } else if ((($207|0) == 1869640570)) {
    HEAP32[$a$14>>2] = 873056;
   }
   $208 = (($next_name$13) + 5|0);
   $209 = (($a$14) + 24|0);
   $210 = (($n$15) + 1)|0;
   $211 = ($210>>>0)<($184>>>0);
   if ($211) {
    $a$14 = $209;$n$15 = $210;$next_name$13 = $208;
   } else {
    break;
   }
  }
 }
 HEAP32[$master>>2] = $174;
 $212 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($212|0);
}
function _TT_Set_MM_Blend($face,$num_coords,$coords) {
 $face = $face|0;
 $num_coords = $num_coords|0;
 $coords = $coords|0;
 var $$off = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre10$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error = 0, $error$i = 0, $gvar_head$i = 0, $i$03 = 0, $i$09$i = 0;
 var $i$11 = 0, $i$17$i = 0, $i$23$i = 0, $j$01$i = 0, $manageCvt$0 = 0, $table_len$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $error$i = sp + 28|0;
 $table_len$i = sp;
 $gvar_head$i = sp + 4|0;
 $error = sp + 24|0;
 HEAP32[$error>>2] = 0;
 $0 = (($face) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 708|0);
 HEAP8[$2>>0] = 0;
 $3 = (($face) + 712|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   $6 = (_TT_Get_MM_Var($face,0)|0);
   HEAP32[$error>>2] = $6;
   $7 = ($6|0)==(0);
   if ($7) {
    $$pre = HEAP32[$3>>2]|0;
    $9 = $$pre;
    break;
   } else {
    $147 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($147|0);
   }
  } else {
   $9 = $4;
  }
 } while(0);
 $8 = (($9) + 8|0);
 $10 = HEAP32[$8>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==($num_coords|0);
 if (!($12)) {
  HEAP32[$error>>2] = 6;
  $147 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($147|0);
 }
 $13 = ($num_coords|0)==(0);
 L11: do {
  if (!($13)) {
   $i$03 = 0;
   while(1) {
    $16 = (($coords) + ($i$03<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $$off = (($17) + 65536)|0;
    $18 = ($$off>>>0)>(131072);
    $15 = (($i$03) + 1)|0;
    if ($18) {
     break;
    }
    $14 = ($15>>>0)<($num_coords>>>0);
    if ($14) {
     $i$03 = $15;
    } else {
     break L11;
    }
   }
   HEAP32[$error>>2] = 6;
   $147 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($147|0);
  }
 } while(0);
 $19 = (($9) + 36|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $22 = (($face) + 104|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($face) + 508|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (FUNCTION_TABLE_iiiii[$27 & 511]($face,1735811442,$23,$table_len$i)|0);
  HEAP32[$error$i>>2] = $28;
  $29 = ($28|0)==(0);
  do {
   if ($29) {
    $30 = (_FT_Stream_Pos($23)|0);
    $31 = (_FT_Stream_ReadFields($23,873080,$gvar_head$i)|0);
    HEAP32[$error$i>>2] = $31;
    $32 = ($31|0)==(0);
    if ($32) {
     $33 = (($gvar_head$i) + 6|0);
     $34 = HEAP16[$33>>1]|0;
     $35 = $34&65535;
     $36 = (($9) + 24|0);
     HEAP32[$36>>2] = $35;
     $37 = (($gvar_head$i) + 12|0);
     $38 = HEAP16[$37>>1]|0;
     $39 = $38&65535;
     $40 = (($9) + 32|0);
     HEAP32[$40>>2] = $39;
     $41 = (($gvar_head$i) + 16|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($42) + ($30))|0;
     $44 = HEAP32[$gvar_head$i>>2]|0;
     $45 = ($44|0)==(65536);
     if ($45) {
      $46 = (($gvar_head$i) + 4|0);
      $47 = HEAP16[$46>>1]|0;
      $48 = HEAP32[$8>>2]|0;
      $49 = HEAP32[$48>>2]|0;
      $50 = $49&65535;
      $51 = ($47<<16>>16)==($50<<16>>16);
      if ($51) {
       $52 = (($39) + 1)|0;
       $53 = (_ft_mem_realloc($25,4,0,$52,0,$error$i)|0);
       HEAP32[$19>>2] = $53;
       $54 = HEAP32[$error$i>>2]|0;
       $55 = ($54|0)==(0);
       if (!($55)) {
        $123 = $54;
        break;
       }
       $56 = (($gvar_head$i) + 14|0);
       $57 = HEAP16[$56>>1]|0;
       $58 = $57 & 1;
       $59 = ($58<<16>>16)==(0);
       $60 = HEAP32[$40>>2]|0;
       $61 = (($60) + 1)|0;
       if ($59) {
        $72 = $61 << 1;
        $73 = (_FT_Stream_EnterFrame($23,$72)|0);
        HEAP32[$error$i>>2] = $73;
        $74 = ($73|0)==(0);
        if ($74) {
         $i$17$i = 0;
        } else {
         $123 = $73;
         break;
        }
        while(1) {
         $75 = (_FT_Stream_GetUShort($23)|0);
         $76 = $75&65535;
         $77 = $76 << 1;
         $78 = (($77) + ($43))|0;
         $79 = HEAP32[$19>>2]|0;
         $80 = (($79) + ($i$17$i<<2)|0);
         HEAP32[$80>>2] = $78;
         $81 = (($i$17$i) + 1)|0;
         $82 = HEAP32[$40>>2]|0;
         $83 = ($81>>>0)>($82>>>0);
         if ($83) {
          break;
         } else {
          $i$17$i = $81;
         }
        }
        _FT_Stream_ExitFrame($23);
       } else {
        $62 = $61 << 2;
        $63 = (_FT_Stream_EnterFrame($23,$62)|0);
        HEAP32[$error$i>>2] = $63;
        $64 = ($63|0)==(0);
        if ($64) {
         $i$09$i = 0;
        } else {
         $123 = $63;
         break;
        }
        while(1) {
         $65 = (_FT_Stream_GetULong($23)|0);
         $66 = (($65) + ($43))|0;
         $67 = HEAP32[$19>>2]|0;
         $68 = (($67) + ($i$09$i<<2)|0);
         HEAP32[$68>>2] = $66;
         $69 = (($i$09$i) + 1)|0;
         $70 = HEAP32[$40>>2]|0;
         $71 = ($69>>>0)>($70>>>0);
         if ($71) {
          break;
         } else {
          $i$09$i = $69;
         }
        }
        _FT_Stream_ExitFrame($23);
       }
       $84 = HEAP32[$36>>2]|0;
       $85 = ($84|0)==(0);
       if (!($85)) {
        $86 = HEAP16[$46>>1]|0;
        $87 = $86&65535;
        $88 = Math_imul($87, $84)|0;
        $89 = (_ft_mem_realloc($25,4,0,$88,0,$error$i)|0);
        $90 = (($9) + 28|0);
        HEAP32[$90>>2] = $89;
        $91 = HEAP32[$error$i>>2]|0;
        $92 = ($91|0)==(0);
        if (!($92)) {
         $123 = $91;
         break;
        }
        $93 = (($gvar_head$i) + 8|0);
        $94 = HEAP32[$93>>2]|0;
        $95 = (($94) + ($30))|0;
        $96 = (_FT_Stream_Seek($23,$95)|0);
        HEAP32[$error$i>>2] = $96;
        $97 = ($96|0)==(0);
        if (!($97)) {
         $123 = $96;
         break;
        }
        $98 = HEAP32[$36>>2]|0;
        $99 = HEAP16[$46>>1]|0;
        $100 = $99&65535;
        $101 = $98 << 1;
        $102 = Math_imul($101, $100)|0;
        $103 = (_FT_Stream_EnterFrame($23,$102)|0);
        HEAP32[$error$i>>2] = $103;
        $104 = ($103|0)==(0);
        if (!($104)) {
         $123 = $103;
         break;
        }
        $105 = HEAP32[$36>>2]|0;
        $106 = ($105|0)==(0);
        if (!($106)) {
         $$pre$i = HEAP16[$46>>1]|0;
         $108 = $$pre$i;$148 = $105;$i$23$i = 0;
         while(1) {
          $107 = ($108<<16>>16)==(0);
          if ($107) {
           $122 = $148;$149 = 0;
          } else {
           $j$01$i = 0;
           while(1) {
            $109 = (_FT_Stream_GetUShort($23)|0);
            $110 = $109 << 16 >> 16;
            $111 = $110 << 2;
            $112 = HEAP16[$46>>1]|0;
            $113 = $112&65535;
            $114 = Math_imul($113, $i$23$i)|0;
            $115 = (($114) + ($j$01$i))|0;
            $116 = HEAP32[$90>>2]|0;
            $117 = (($116) + ($115<<2)|0);
            HEAP32[$117>>2] = $111;
            $118 = (($j$01$i) + 1)|0;
            $119 = ($118>>>0)<($113>>>0);
            if ($119) {
             $j$01$i = $118;
            } else {
             break;
            }
           }
           $$pre10$i = HEAP32[$36>>2]|0;
           $122 = $$pre10$i;$149 = $112;
          }
          $120 = (($i$23$i) + 1)|0;
          $121 = ($120>>>0)<($122>>>0);
          if ($121) {
           $108 = $149;$148 = $122;$i$23$i = $120;
          } else {
           break;
          }
         }
        }
        _FT_Stream_ExitFrame($23);
       }
       $$pr = HEAP32[$error$i>>2]|0;
       $123 = $$pr;
       break;
      }
     }
     HEAP32[$error$i>>2] = 8;
     $123 = 8;
    } else {
     $123 = $31;
    }
   } else {
    $123 = $28;
   }
  } while(0);
  HEAP32[$error>>2] = $123;
  $124 = ($123|0)==(0);
  if (!($124)) {
   $147 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($147|0);
  }
 }
 $125 = (($9) + 4|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = ($126|0)==(0|0);
 L57: do {
  if ($127) {
   $128 = (_ft_mem_realloc($1,4,0,$num_coords,0,$error)|0);
   HEAP32[$125>>2] = $128;
   $129 = HEAP32[$error>>2]|0;
   $130 = ($129|0)==(0);
   if ($130) {
    $139 = $128;$manageCvt$0 = 1;
   } else {
    $147 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($147|0);
   }
  } else {
   if ($13) {
    $139 = $126;$manageCvt$0 = 0;
   } else {
    $i$11 = 0;
    while(1) {
     $133 = (($126) + ($i$11<<2)|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($coords) + ($i$11<<2)|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = ($134|0)==($136|0);
     $132 = (($i$11) + 1)|0;
     if (!($137)) {
      $139 = $126;$manageCvt$0 = 2;
      break L57;
     }
     $131 = ($132>>>0)<($num_coords>>>0);
     if ($131) {
      $i$11 = $132;
     } else {
      $139 = $126;$manageCvt$0 = 0;
      break;
     }
    }
   }
  }
 } while(0);
 HEAP32[$9>>2] = $num_coords;
 $138 = $num_coords << 2;
 _memcpy(($139|0),($coords|0),($138|0))|0;
 HEAP8[$2>>0] = 1;
 $140 = (($face) + 672|0);
 $141 = HEAP32[$140>>2]|0;
 $142 = ($141|0)==(0|0);
 if ($142) {
  $147 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($147|0);
 }
 if ((($manageCvt$0|0) == 1)) {
  $145 = (($face) + 104|0);
  $146 = HEAP32[$145>>2]|0;
  (_tt_face_vary_cvt($face,$146)|0);
  $147 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($147|0);
 } else if ((($manageCvt$0|0) == 2)) {
  _ft_mem_free($1,$141);
  HEAP32[$140>>2] = 0;
  $143 = (($face) + 104|0);
  $144 = HEAP32[$143>>2]|0;
  (_tt_face_load_cvt($face,$144)|0);
  $147 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($147|0);
 } else {
  $147 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($147|0);
 }
 return 0|0;
}
function _tt_face_vary_cvt($face,$stream) {
 $face = $face|0;
 $stream = $stream|0;
 var $$mask = 0, $$pre = 0, $$pre25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error = 0, $exitcond = 0, $i$021 = 0, $im_end_coords$0 = 0, $im_end_coords$1 = 0, $im_start_coords$0 = 0, $im_start_coords$1 = 0, $j$01 = 0, $j$118 = 0, $j$23 = 0, $j$36 = 0, $j$414 = 0, $j$510 = 0, $offsetToData$022 = 0;
 var $offsetToData$1 = 0, $or$cond = 0, $or$cond27 = 0, $phitmp = 0, $point_count = 0, $table_len = 0, $tuple_coords$0 = 0, $tuple_coords$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp + 8|0;
 $table_len = sp;
 $point_count = sp + 4|0;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 712|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  HEAP32[$error>>2] = 0;
  $im_end_coords$1 = 0;$im_start_coords$1 = 0;$tuple_coords$1 = 0;
  _ft_mem_free($1,$tuple_coords$1);
  _ft_mem_free($1,$im_start_coords$1);
  _ft_mem_free($1,$im_end_coords$1);
  $142 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($142|0);
 }
 $5 = (($face) + 672|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  HEAP32[$error>>2] = 0;
  $im_end_coords$1 = 0;$im_start_coords$1 = 0;$tuple_coords$1 = 0;
  _ft_mem_free($1,$tuple_coords$1);
  _ft_mem_free($1,$im_start_coords$1);
  _ft_mem_free($1,$im_end_coords$1);
  $142 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($142|0);
 }
 $8 = (($face) + 508|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiii[$9 & 511]($face,1668702578,$stream,$table_len)|0);
 HEAP32[$error>>2] = $10;
 $11 = ($10|0)==(0);
 if (!($11)) {
  HEAP32[$error>>2] = 0;
  $im_end_coords$1 = 0;$im_start_coords$1 = 0;$tuple_coords$1 = 0;
  _ft_mem_free($1,$tuple_coords$1);
  _ft_mem_free($1,$im_start_coords$1);
  _ft_mem_free($1,$im_end_coords$1);
  $142 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($142|0);
 }
 $12 = HEAP32[$table_len>>2]|0;
 $13 = (_FT_Stream_EnterFrame($stream,$12)|0);
 HEAP32[$error>>2] = $13;
 $14 = ($13|0)==(0);
 if (!($14)) {
  HEAP32[$error>>2] = 0;
  $im_end_coords$1 = 0;$im_start_coords$1 = 0;$tuple_coords$1 = 0;
  _ft_mem_free($1,$tuple_coords$1);
  _ft_mem_free($1,$im_start_coords$1);
  _ft_mem_free($1,$im_end_coords$1);
  $142 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($142|0);
 }
 $15 = (($stream) + 32|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$stream>>2]|0;
 $18 = $16;
 $19 = $17;
 $20 = (($18) - ($19))|0;
 $21 = (_FT_Stream_GetULong($stream)|0);
 $22 = ($21|0)==(65536);
 if ($22) {
  $23 = HEAP32[$3>>2]|0;
  $24 = (_ft_mem_realloc($1,4,0,$23,0,$error)|0);
  $25 = HEAP32[$error>>2]|0;
  $26 = ($25|0)==(0);
  if ($26) {
   $27 = HEAP32[$3>>2]|0;
   $28 = (_ft_mem_realloc($1,4,0,$27,0,$error)|0);
   $29 = HEAP32[$error>>2]|0;
   $30 = ($29|0)==(0);
   if ($30) {
    $31 = HEAP32[$3>>2]|0;
    $32 = (_ft_mem_realloc($1,4,0,$31,0,$error)|0);
    $33 = HEAP32[$error>>2]|0;
    $34 = ($33|0)==(0);
    if ($34) {
     $35 = (_FT_Stream_GetUShort($stream)|0);
     $36 = (_FT_Stream_GetUShort($stream)|0);
     $37 = $35 & 4095;
     $38 = ($37<<16>>16)==(0);
     if ($38) {
      $im_end_coords$0 = $32;$im_start_coords$0 = $28;$tuple_coords$0 = $24;
     } else {
      $39 = $36&65535;
      $40 = (($20) + ($39))|0;
      $41 = (($face) + 668|0);
      $42 = $35&65535;
      $43 = $42 & 4095;
      $i$021 = 0;$offsetToData$022 = $40;
      while(1) {
       $44 = (_FT_Stream_GetUShort($stream)|0);
       $45 = $44&65535;
       $46 = (_FT_Stream_GetUShort($stream)|0);
       $47 = $46&65535;
       $48 = $47 & 32768;
       $49 = ($48|0)==(0);
       if ($49) {
        $59 = $47 & 16384;
        $60 = ($59|0)==(0);
        if (!($60)) {
         $61 = HEAP32[$3>>2]|0;
         $$mask = $61 & 2147483647;
         $62 = ($$mask|0)==(0);
         if (!($62)) {
          $j$118 = 0;
          while(1) {
           (_FT_Stream_GetUShort($stream)|0);
           $63 = (($j$118) + 1)|0;
           $64 = HEAP32[$3>>2]|0;
           $65 = $64 << 1;
           $66 = ($63>>>0)<($65>>>0);
           if ($66) {
            $j$118 = $63;
           } else {
            break;
           }
          }
         }
        }
       } else {
        $50 = HEAP32[$3>>2]|0;
        $51 = ($50|0)==(0);
        if ($51) {
         $70 = 0;
        } else {
         $j$01 = 0;
         while(1) {
          $52 = (_FT_Stream_GetUShort($stream)|0);
          $53 = $52 << 16 >> 16;
          $54 = $53 << 2;
          $55 = (($24) + ($j$01<<2)|0);
          HEAP32[$55>>2] = $54;
          $56 = (($j$01) + 1)|0;
          $57 = HEAP32[$3>>2]|0;
          $58 = ($56>>>0)<($57>>>0);
          if ($58) {
           $j$01 = $56;
          } else {
           $70 = $57;
           break;
          }
         }
        }
        $67 = $47 & 16384;
        $68 = ($67|0)==(0);
        $69 = ($70|0)==(0);
        $or$cond27 = $68 | $69;
        if (!($or$cond27)) {
         $j$23 = 0;
         while(1) {
          $71 = (_FT_Stream_GetUShort($stream)|0);
          $72 = $71 << 16 >> 16;
          $73 = $72 << 2;
          $74 = (($28) + ($j$23<<2)|0);
          HEAP32[$74>>2] = $73;
          $75 = (($j$23) + 1)|0;
          $76 = HEAP32[$3>>2]|0;
          $77 = ($75>>>0)<($76>>>0);
          if ($77) {
           $j$23 = $75;
          } else {
           break;
          }
         }
         $phitmp = ($76|0)==(0);
         if (!($phitmp)) {
          $j$36 = 0;
          while(1) {
           $78 = (_FT_Stream_GetUShort($stream)|0);
           $79 = $78 << 16 >> 16;
           $80 = $79 << 2;
           $81 = (($32) + ($j$36<<2)|0);
           HEAP32[$81>>2] = $80;
           $82 = (($j$36) + 1)|0;
           $83 = HEAP32[$3>>2]|0;
           $84 = ($82>>>0)<($83>>>0);
           if ($84) {
            $j$36 = $82;
           } else {
            break;
           }
          }
         }
        }
        $85 = (_ft_var_apply_tuple($3,$46,$24,$28,$32)|0);
        $86 = ($85|0)==(0);
        if (!($86)) {
         $87 = $47 & 8192;
         $88 = ($87|0)==(0);
         if (!($88)) {
          $89 = HEAP32[$15>>2]|0;
          $90 = HEAP32[$stream>>2]|0;
          $91 = $89;
          $92 = $90;
          $93 = (($91) - ($92))|0;
          $94 = (($90) + ($offsetToData$022)|0);
          HEAP32[$15>>2] = $94;
          $95 = (_ft_var_readpackedpoints($stream,$point_count)|0);
          $96 = HEAP32[$point_count>>2]|0;
          $97 = ($96|0)==(0);
          if ($97) {
           $98 = HEAP32[$41>>2]|0;
           $99 = $98;
          } else {
           $99 = $96;
          }
          $100 = (_ft_var_readpackeddeltas($stream,$99)|0);
          $101 = ($95|0)==(0|0);
          $102 = ($100|0)==(0|0);
          $or$cond = $101 | $102;
          do {
           if ($or$cond) {
            label = 38;
           } else {
            $103 = ($95|0)==((-1)|0);
            if ($103) {
             $104 = HEAP32[$41>>2]|0;
             $105 = ($104|0)==(0);
             if ($105) {
              break;
             }
             $$pre25 = HEAP32[$5>>2]|0;
             $107 = $$pre25;$j$414 = 0;
             while(1) {
              $106 = (($107) + ($j$414<<1)|0);
              $108 = HEAP16[$106>>1]|0;
              $109 = $108&65535;
              $110 = (($100) + ($j$414<<1)|0);
              $111 = HEAP16[$110>>1]|0;
              $112 = $111 << 16 >> 16;
              $113 = (_FT_MulFix($112,$85)|0);
              $114 = (($113) + ($109))|0;
              $115 = $114&65535;
              $116 = HEAP32[$5>>2]|0;
              $117 = (($116) + ($j$414<<1)|0);
              HEAP16[$117>>1] = $115;
              $118 = (($j$414) + 1)|0;
              $119 = HEAP32[$41>>2]|0;
              $120 = ($118>>>0)<($119>>>0);
              if ($120) {
               $107 = $116;$j$414 = $118;
              } else {
               label = 38;
               break;
              }
             }
            } else {
             if ($97) {
              label = 39;
              break;
             }
             $$pre = HEAP32[$5>>2]|0;
             $125 = $$pre;$j$510 = 0;
             while(1) {
              $121 = (($95) + ($j$510<<1)|0);
              $122 = HEAP16[$121>>1]|0;
              $123 = $122&65535;
              $124 = (($125) + ($123<<1)|0);
              $126 = HEAP16[$124>>1]|0;
              $127 = $126&65535;
              $128 = (($100) + ($j$510<<1)|0);
              $129 = HEAP16[$128>>1]|0;
              $130 = $129 << 16 >> 16;
              $131 = (_FT_MulFix($130,$85)|0);
              $132 = (($131) + ($127))|0;
              $133 = $132&65535;
              $134 = HEAP32[$5>>2]|0;
              $135 = (($134) + ($123<<1)|0);
              HEAP16[$135>>1] = $133;
              $136 = (($j$510) + 1)|0;
              $137 = ($136>>>0)<($96>>>0);
              if ($137) {
               $125 = $134;$j$510 = $136;
              } else {
               label = 38;
               break;
              }
             }
            }
           }
          } while(0);
          if ((label|0) == 38) {
           label = 0;
           $138 = ($95|0)==((-1)|0);
           if (!($138)) {
            label = 39;
           }
          }
          if ((label|0) == 39) {
           label = 0;
           _ft_mem_free($1,$95);
          }
          _ft_mem_free($1,$100);
          $139 = HEAP32[$stream>>2]|0;
          $140 = (($139) + ($93)|0);
          HEAP32[$15>>2] = $140;
         }
        }
       }
       $offsetToData$1 = (($45) + ($offsetToData$022))|0;
       $141 = (($i$021) + 1)|0;
       $exitcond = ($141|0)==($43|0);
       if ($exitcond) {
        $im_end_coords$0 = $32;$im_start_coords$0 = $28;$tuple_coords$0 = $24;
        break;
       } else {
        $i$021 = $141;$offsetToData$022 = $offsetToData$1;
       }
      }
     }
    } else {
     $im_end_coords$0 = $32;$im_start_coords$0 = $28;$tuple_coords$0 = $24;
    }
   } else {
    $im_end_coords$0 = 0;$im_start_coords$0 = $28;$tuple_coords$0 = $24;
   }
  } else {
   $im_end_coords$0 = 0;$im_start_coords$0 = 0;$tuple_coords$0 = $24;
  }
 } else {
  HEAP32[$error>>2] = 0;
  $im_end_coords$0 = 0;$im_start_coords$0 = 0;$tuple_coords$0 = 0;
 }
 _FT_Stream_ExitFrame($stream);
 $im_end_coords$1 = $im_end_coords$0;$im_start_coords$1 = $im_start_coords$0;$tuple_coords$1 = $tuple_coords$0;
 _ft_mem_free($1,$tuple_coords$1);
 _ft_mem_free($1,$im_start_coords$1);
 _ft_mem_free($1,$im_end_coords$1);
 $142 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($142|0);
}
function _TT_Set_Var_Design($face,$num_coords,$coords) {
 $face = $face|0;
 $num_coords = $num_coords|0;
 $coords = $coords|0;
 var $$lcssa$i = 0, $$pre = 0, $$pre21 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$014 = 0, $av$010 = 0, $error = 0, $error$i = 0, $i$010$i = 0, $i$013 = 0, $i$19 = 0, $j$02$i = 0, $j$02$in$i = 0;
 var $j$06 = 0, $j$14$i = 0, $normalized$0 = 0, $or$cond$i = 0, $segment$09$i = 0, $table_len$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp + 8|0;
 $table_len$i = sp;
 $error = sp + 4|0;
 HEAP32[$error>>2] = 0;
 $0 = (($face) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($face) + 712|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 do {
  if ($4) {
   $5 = (_TT_Get_MM_Var($face,0)|0);
   HEAP32[$error>>2] = $5;
   $6 = ($5|0)==(0);
   if ($6) {
    $$pre21 = HEAP32[$2>>2]|0;
    $8 = $$pre21;
    break;
   } else {
    $normalized$0 = 0;
    _ft_mem_free($1,$normalized$0);
    $146 = HEAP32[$error>>2]|0;
    STACKTOP = sp;return ($146|0);
   }
  } else {
   $8 = $3;
  }
 } while(0);
 $7 = (($8) + 8|0);
 $9 = HEAP32[$7>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($num_coords|0);
 if (!($11)) {
  HEAP32[$error>>2] = 6;
  $normalized$0 = 0;
  _ft_mem_free($1,$normalized$0);
  $146 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($146|0);
 }
 $12 = (_ft_mem_realloc($1,4,0,$num_coords,0,$error)|0);
 $13 = HEAP32[$error>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $normalized$0 = $12;
  _ft_mem_free($1,$normalized$0);
  $146 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($146|0);
 }
 $15 = HEAP32[$9>>2]|0;
 $16 = ($15|0)==(0);
 L14: do {
  if (!($16)) {
   $17 = (($9) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $a$014 = $18;$i$013 = 0;
   while(1) {
    $19 = (($coords) + ($i$013<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($a$014) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($20|0)>($22|0);
    if ($23) {
     break;
    }
    $24 = (($a$014) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($20|0)<($25|0);
    if ($26) {
     break;
    }
    $27 = (($a$014) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($20|0)<($28|0);
    do {
     if ($29) {
      $30 = (($20) - ($28))|0;
      $31 = (($25) - ($28))|0;
      $32 = (_FT_MulDiv($30,65536,$31)|0);
      $33 = (0 - ($32))|0;
      $34 = (($12) + ($i$013<<2)|0);
      HEAP32[$34>>2] = $33;
     } else {
      $35 = ($22|0)==($28|0);
      if ($35) {
       $36 = (($12) + ($i$013<<2)|0);
       HEAP32[$36>>2] = 0;
       break;
      } else {
       $37 = (($20) - ($28))|0;
       $38 = (($22) - ($28))|0;
       $39 = (_FT_MulDiv($37,65536,$38)|0);
       $40 = (($12) + ($i$013<<2)|0);
       HEAP32[$40>>2] = $39;
       break;
      }
     }
    } while(0);
    $41 = (($i$013) + 1)|0;
    $42 = (($a$014) + 24|0);
    $43 = HEAP32[$9>>2]|0;
    $44 = ($41>>>0)<($43>>>0);
    if ($44) {
     $a$014 = $42;$i$013 = $41;
    } else {
     break L14;
    }
   }
   HEAP32[$error>>2] = 6;
   $normalized$0 = $12;
   _ft_mem_free($1,$normalized$0);
   $146 = HEAP32[$error>>2]|0;
   STACKTOP = sp;return ($146|0);
  }
 } while(0);
 $45 = (($8) + 16|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if ($47) {
  $48 = (($face) + 104|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (($49) + 28|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = HEAP32[$2>>2]|0;
  HEAP32[$error$i>>2] = 0;
  $53 = (($52) + 16|0);
  HEAP8[$53>>0] = 1;
  $54 = (($face) + 508|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (FUNCTION_TABLE_iiiii[$55 & 511]($face,1635148146,$49,$table_len$i)|0);
  HEAP32[$error$i>>2] = $56;
  $57 = ($56|0)==(0);
  if ($57) {
   $58 = HEAP32[$table_len$i>>2]|0;
   $59 = (_FT_Stream_EnterFrame($49,$58)|0);
   HEAP32[$error$i>>2] = $59;
   $60 = ($59|0)==(0);
   if ($60) {
    $61 = (_FT_Stream_GetULong($49)|0);
    $62 = (_FT_Stream_GetULong($49)|0);
    $63 = ($61|0)==(65536);
    L34: do {
     if ($63) {
      $64 = (($52) + 8|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = HEAP32[$65>>2]|0;
      $67 = ($62|0)==($66|0);
      if ($67) {
       $68 = (_ft_mem_realloc($51,8,0,$62,0,$error$i)|0);
       $69 = (($52) + 20|0);
       HEAP32[$69>>2] = $68;
       $70 = HEAP32[$error$i>>2]|0;
       $71 = ($70|0)==(0);
       $72 = ($62|0)>(0);
       $or$cond$i = $71 & $72;
       if ($or$cond$i) {
        $i$010$i = 0;$segment$09$i = $68;
        while(1) {
         $73 = (_FT_Stream_GetUShort($49)|0);
         HEAP16[$segment$09$i>>1] = $73;
         $74 = $73&65535;
         $75 = (_ft_mem_realloc($51,8,0,$74,0,$error$i)|0);
         $76 = (($segment$09$i) + 4|0);
         HEAP32[$76>>2] = $75;
         $77 = HEAP32[$error$i>>2]|0;
         $78 = ($77|0)==(0);
         if (!($78)) {
          break;
         }
         $79 = HEAP16[$segment$09$i>>1]|0;
         $80 = ($79<<16>>16)==(0);
         if (!($80)) {
          $j$14$i = 0;
          while(1) {
           $90 = (_FT_Stream_GetUShort($49)|0);
           $91 = $90 << 16 >> 16;
           $92 = $91 << 2;
           $93 = HEAP32[$76>>2]|0;
           $94 = (($93) + ($j$14$i<<3)|0);
           HEAP32[$94>>2] = $92;
           $95 = (_FT_Stream_GetUShort($49)|0);
           $96 = $95 << 16 >> 16;
           $97 = $96 << 2;
           $98 = HEAP32[$76>>2]|0;
           $99 = ((($98) + ($j$14$i<<3)|0) + 4|0);
           HEAP32[$99>>2] = $97;
           $100 = (($j$14$i) + 1)|0;
           $101 = HEAP16[$segment$09$i>>1]|0;
           $102 = $101&65535;
           $103 = ($100|0)<($102|0);
           if ($103) {
            $j$14$i = $100;
           } else {
            break;
           }
          }
         }
         $104 = (($i$010$i) + 1)|0;
         $105 = (($segment$09$i) + 8|0);
         $106 = ($104|0)<($62|0);
         if ($106) {
          $i$010$i = $104;$segment$09$i = $105;
         } else {
          break L34;
         }
        }
        $81 = ($i$010$i|0)>(0);
        $82 = HEAP32[$69>>2]|0;
        if ($81) {
         $84 = $82;$j$02$in$i = $i$010$i;
         while(1) {
          $j$02$i = (($j$02$in$i) + -1)|0;
          $83 = ((($84) + ($j$02$i<<3)|0) + 4|0);
          $85 = HEAP32[$83>>2]|0;
          _ft_mem_free($51,$85);
          $86 = HEAP32[$69>>2]|0;
          $87 = ((($86) + ($j$02$i<<3)|0) + 4|0);
          HEAP32[$87>>2] = 0;
          $88 = ($j$02$i|0)>(0);
          $89 = HEAP32[$69>>2]|0;
          if ($88) {
           $84 = $89;$j$02$in$i = $j$02$i;
          } else {
           $$lcssa$i = $89;
           break;
          }
         }
        } else {
         $$lcssa$i = $82;
        }
        _ft_mem_free($51,$$lcssa$i);
        HEAP32[$69>>2] = 0;
       }
      }
     }
    } while(0);
    _FT_Stream_ExitFrame($49);
   }
  }
 }
 $107 = (($8) + 20|0);
 $108 = HEAP32[$107>>2]|0;
 $109 = ($108|0)==(0|0);
 if (!($109)) {
  $110 = HEAP32[$9>>2]|0;
  $111 = ($110|0)==(0);
  if (!($111)) {
   $147 = $110;$av$010 = $108;$i$19 = 0;
   while(1) {
    $112 = HEAP16[$av$010>>1]|0;
    $113 = ($112&65535)>(1);
    L55: do {
     if ($113) {
      $114 = (($12) + ($i$19<<2)|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = (($av$010) + 4|0);
      $117 = HEAP32[$116>>2]|0;
      $j$06 = 1;
      while(1) {
       $121 = (($117) + ($j$06<<3)|0);
       $122 = HEAP32[$121>>2]|0;
       $123 = ($115|0)<($122|0);
       $120 = (($j$06) + 1)|0;
       if ($123) {
        break;
       }
       $118 = $112&65535;
       $119 = ($120>>>0)<($118>>>0);
       if ($119) {
        $j$06 = $120;
       } else {
        $144 = $147;
        break L55;
       }
      }
      $124 = (($j$06) + -1)|0;
      $125 = (($117) + ($124<<3)|0);
      $126 = HEAP32[$125>>2]|0;
      $127 = (($115) - ($126))|0;
      $128 = (($122) - ($126))|0;
      $129 = (_FT_MulDiv($127,65536,$128)|0);
      $130 = HEAP32[$116>>2]|0;
      $131 = ((($130) + ($j$06<<3)|0) + 4|0);
      $132 = HEAP32[$131>>2]|0;
      $133 = ((($130) + ($124<<3)|0) + 4|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = (($132) - ($134))|0;
      $136 = (_FT_MulDiv($129,$135,65536)|0);
      $137 = HEAP32[$116>>2]|0;
      $138 = ((($137) + ($124<<3)|0) + 4|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = (($139) + ($136))|0;
      HEAP32[$114>>2] = $140;
      $$pre = HEAP32[$9>>2]|0;
      $144 = $$pre;
     } else {
      $144 = $147;
     }
    } while(0);
    $141 = (($i$19) + 1)|0;
    $142 = (($av$010) + 8|0);
    $143 = ($141>>>0)<($144>>>0);
    if ($143) {
     $147 = $144;$av$010 = $142;$i$19 = $141;
    } else {
     break;
    }
   }
  }
 }
 $145 = (_TT_Set_MM_Blend($face,$num_coords,$12)|0);
 HEAP32[$error>>2] = $145;
 $normalized$0 = $12;
 _ft_mem_free($1,$normalized$0);
 $146 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($146|0);
}
function _ft_var_apply_tuple($blend,$tupleIndex,$tuple_coords,$im_start_coords,$im_end_coords) {
 $blend = $blend|0;
 $tupleIndex = $tupleIndex|0;
 $tuple_coords = $tuple_coords|0;
 $im_start_coords = $im_start_coords|0;
 $im_end_coords = $im_end_coords|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $apply$03 = 0, $apply$03$us = 0, $apply$1 = 0, $apply$1$us = 0, $apply$2 = 0, $i$02 = 0, $i$02$us = 0;
 var $or$cond = 0, $or$cond$us = 0, $or$cond1 = 0, $or$cond1$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($blend) + 4|0);
 $1 = HEAP32[$blend>>2]|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $apply$2 = 65536;
  } else {
   $3 = $tupleIndex & 16384;
   $4 = ($3<<16>>16)==(0);
   if ($4) {
    $51 = $1;$apply$03$us = 65536;$i$02$us = 0;
    while(1) {
     $5 = (($tuple_coords) + ($i$02$us<<2)|0);
     $6 = HEAP32[$5>>2]|0;
     $7 = ($6|0)==(0);
     if ($7) {
      $21 = $51;$apply$1$us = $apply$03$us;
     } else {
      $8 = HEAP32[$0>>2]|0;
      $9 = (($8) + ($i$02$us<<2)|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       $apply$2 = 0;
       break L1;
      }
      $12 = ($10|0)<(0);
      $13 = ($6|0)>(0);
      $or$cond$us = $12 & $13;
      if ($or$cond$us) {
       $apply$2 = 0;
       break L1;
      }
      $14 = ($10|0)>(0);
      $15 = ($6|0)<(0);
      $or$cond1$us = $14 & $15;
      if ($or$cond1$us) {
       $apply$2 = 0;
       break L1;
      }
      $16 = (0 - ($10))|0;
      $17 = $14 ? $10 : $16;
      $18 = (_FT_MulDiv($apply$03$us,$17,65536)|0);
      $$pre = HEAP32[$blend>>2]|0;
      $21 = $$pre;$apply$1$us = $18;
     }
     $19 = (($i$02$us) + 1)|0;
     $20 = ($19>>>0)<($21>>>0);
     if ($20) {
      $51 = $21;$apply$03$us = $apply$1$us;$i$02$us = $19;
     } else {
      $apply$2 = $apply$1$us;
      break L1;
     }
    }
   } else {
    $apply$03 = 65536;$i$02 = 0;
   }
   while(1) {
    $22 = (($tuple_coords) + ($i$02<<2)|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0);
    do {
     if ($24) {
      $apply$1 = $apply$03;
     } else {
      $25 = HEAP32[$0>>2]|0;
      $26 = (($25) + ($i$02<<2)|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==(0);
      if ($28) {
       $apply$2 = 0;
       break L1;
      }
      $29 = ($27|0)<(0);
      $30 = ($23|0)>(0);
      $or$cond = $29 & $30;
      if ($or$cond) {
       $apply$2 = 0;
       break L1;
      }
      $31 = ($27|0)>(0);
      $32 = ($23|0)<(0);
      $or$cond1 = $31 & $32;
      if ($or$cond1) {
       $apply$2 = 0;
       break L1;
      }
      $33 = (($im_start_coords) + ($i$02<<2)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($27|0)>($34|0);
      if (!($35)) {
       $apply$2 = 0;
       break L1;
      }
      $36 = (($im_end_coords) + ($i$02<<2)|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = ($27|0)<($37|0);
      if (!($38)) {
       $apply$2 = 0;
       break L1;
      }
      $39 = ($27|0)<($23|0);
      if ($39) {
       $40 = (($27) - ($34))|0;
       $41 = (($23) - ($34))|0;
       $42 = (_FT_MulDiv($40,65536,$41)|0);
       $43 = (_FT_MulDiv($apply$03,$42,65536)|0);
       $apply$1 = $43;
       break;
      } else {
       $44 = (($37) - ($27))|0;
       $45 = (($37) - ($23))|0;
       $46 = (_FT_MulDiv($44,65536,$45)|0);
       $47 = (_FT_MulDiv($apply$03,$46,65536)|0);
       $apply$1 = $47;
       break;
      }
     }
    } while(0);
    $48 = (($i$02) + 1)|0;
    $49 = HEAP32[$blend>>2]|0;
    $50 = ($48>>>0)<($49>>>0);
    if ($50) {
     $apply$03 = $apply$1;$i$02 = $48;
    } else {
     $apply$2 = $apply$1;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($apply$2|0);
}
function _ft_var_readpackedpoints($stream,$point_cnt) {
 $stream = $stream|0;
 $point_cnt = $point_cnt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $error = 0, $first$03 = 0, $first$18 = 0, $i$0$be = 0, $i$013 = 0, $i$11 = 0, $i$26 = 0, $j$02 = 0, $j$17 = 0, $n$0 = 0, $smax = 0, $smax15 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$error>>2] = 0;
 $2 = (_FT_Stream_GetChar($stream)|0);
 $3 = $2&255;
 HEAP32[$point_cnt>>2] = $3;
 $4 = ($2<<24>>24)==(0);
 if ($4) {
  $$0 = (-1);
  STACKTOP = sp;return ($$0|0);
 }
 $5 = $3 & 128;
 $6 = ($5|0)==(0);
 if ($6) {
  $n$0 = $3;
 } else {
  $7 = (_FT_Stream_GetChar($stream)|0);
  $8 = $7&255;
  $9 = $3 << 8;
  $10 = $9 & 32512;
  $11 = $8 | $10;
  $n$0 = $11;
 }
 $12 = (_ft_mem_realloc($1,2,0,$n$0,0,$error)|0);
 $13 = HEAP32[$error>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = ($n$0|0)>(0);
 if ($15) {
  $i$013 = 0;
 } else {
  $$0 = $12;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $21 = (_FT_Stream_GetChar($stream)|0);
  $22 = $21&255;
  $23 = $22 & 128;
  $24 = ($23|0)==(0);
  if ($24) {
   $43 = (_FT_Stream_GetChar($stream)|0);
   $44 = $43&255;
   $20 = (($i$013) + 1)|0;
   $45 = (($12) + ($i$013<<1)|0);
   HEAP16[$45>>1] = $44;
   $46 = ($21<<24>>24)==(0);
   if ($46) {
    $$0 = $12;
    label = 18;
    break;
   }
   $47 = (($22) + ($20))|0;
   $48 = ($47|0)<($n$0|0);
   if (!($48)) {
    $$0 = $12;
    label = 18;
    break;
   }
   $49 = $43&255;
   $50 = ($22>>>0)>(1);
   $smax15 = $50 ? $22 : 1;
   $first$18 = $49;$i$26 = $20;$j$17 = 0;
   while(1) {
    $51 = (_FT_Stream_GetChar($stream)|0);
    $52 = $51&255;
    $53 = (($52) + ($first$18))|0;
    $54 = $53&65535;
    $55 = (($i$26) + 1)|0;
    $56 = (($12) + ($i$26<<1)|0);
    HEAP16[$56>>1] = $54;
    $57 = (($j$17) + 1)|0;
    $58 = ($57|0)<($22|0);
    if ($58) {
     $first$18 = $53;$i$26 = $55;$j$17 = $57;
    } else {
     break;
    }
   }
   $19 = (($20) + ($smax15))|0;
   $i$0$be = $19;
  } else {
   $25 = $22 & 127;
   $26 = (_FT_Stream_GetUShort($stream)|0);
   $17 = (($i$013) + 1)|0;
   $27 = (($12) + ($i$013<<1)|0);
   HEAP16[$27>>1] = $26;
   $28 = ($25|0)==(0);
   if ($28) {
    $$0 = $12;
    label = 18;
    break;
   }
   $29 = (($25) + ($17))|0;
   $30 = ($29|0)<($n$0|0);
   if (!($30)) {
    $$0 = $12;
    label = 18;
    break;
   }
   $31 = $26&65535;
   $32 = $21&255;
   $33 = $32 & 127;
   $34 = ($33>>>0)>(1);
   $smax = $34 ? $33 : 1;
   $first$03 = $31;$i$11 = $17;$j$02 = 0;
   while(1) {
    $35 = (_FT_Stream_GetUShort($stream)|0);
    $36 = $35&65535;
    $37 = (($36) + ($first$03))|0;
    $38 = $37&65535;
    $39 = (($i$11) + 1)|0;
    $40 = (($12) + ($i$11<<1)|0);
    HEAP16[$40>>1] = $38;
    $41 = (($j$02) + 1)|0;
    $42 = ($41|0)<($25|0);
    if ($42) {
     $first$03 = $37;$i$11 = $39;$j$02 = $41;
    } else {
     break;
    }
   }
   $16 = (($17) + ($smax))|0;
   $i$0$be = $16;
  }
  $18 = ($i$0$be|0)<($n$0|0);
  if ($18) {
   $i$013 = $i$0$be;
  } else {
   $$0 = $12;
   label = 18;
   break;
  }
 }
 if ((label|0) == 18) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _ft_var_readpackeddeltas($stream,$delta_cnt) {
 $stream = $stream|0;
 $delta_cnt = $delta_cnt|0;
 var $$0 = 0, $$not = 0, $$not34 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $exitcond = 0;
 var $exitcond32 = 0, $i$0 = 0, $i$212 = 0, $i$320 = 0, $i$4 = 0, $j$113 = 0, $j$221 = 0, $j$3 = 0, $scevgep = 0, $umax = 0, $umax$pn = 0, $umax31 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (($stream) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$error>>2] = 0;
 $2 = (_ft_mem_realloc($1,2,0,$delta_cnt,0,$error)|0);
 $3 = HEAP32[$error>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $i$0 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $5 = ($i$0>>>0)<($delta_cnt>>>0);
  if (!($5)) {
   $$0 = $2;
   label = 12;
   break;
  }
  $6 = (_FT_Stream_GetChar($stream)|0);
  $7 = $6&255;
  $8 = $7 & 128;
  $9 = ($8|0)==(0);
  do {
   if ($9) {
    $10 = $7 & 64;
    $11 = ($10|0)==(0);
    $12 = (($i$0) - ($delta_cnt))|0;
    $13 = $6&255;
    $$not34 = $13 | -64;
    $14 = $$not34 ^ 63;
    $15 = ($12>>>0)>($14>>>0);
    $umax31 = $15 ? $12 : $14;
    $16 = (0 - ($umax31))|0;
    if ($11) {
     $i$320 = $i$0;$j$221 = 0;
     while(1) {
      $21 = (_FT_Stream_GetChar($stream)|0);
      $22 = $21 << 24 >> 24;
      $23 = (($i$320) + 1)|0;
      $24 = (($2) + ($i$320<<1)|0);
      HEAP16[$24>>1] = $22;
      $25 = (($j$221) + 1)|0;
      $exitcond32 = ($25|0)==($16|0);
      if ($exitcond32) {
       break;
      } else {
       $i$320 = $23;$j$221 = $25;
      }
     }
     $j$3 = $16;$umax$pn = $umax31;
     break;
    } else {
     $i$212 = $i$0;$j$113 = 0;
     while(1) {
      $17 = (_FT_Stream_GetUShort($stream)|0);
      $18 = (($i$212) + 1)|0;
      $19 = (($2) + ($i$212<<1)|0);
      HEAP16[$19>>1] = $17;
      $20 = (($j$113) + 1)|0;
      $exitcond = ($20|0)==($16|0);
      if ($exitcond) {
       break;
      } else {
       $i$212 = $18;$j$113 = $20;
      }
     }
     $j$3 = $16;$umax$pn = $umax31;
     break;
    }
   } else {
    $26 = (($i$0) - ($delta_cnt))|0;
    $27 = $6&255;
    $$not = $27 | -64;
    $28 = $$not ^ 63;
    $29 = ($26>>>0)>($28>>>0);
    $umax = $29 ? $26 : $28;
    $30 = (0 - ($umax))|0;
    $31 = $i$0 << 1;
    $scevgep = (($2) + ($31)|0);
    $32 = Math_imul($umax, -2)|0;
    _memset(($scevgep|0),0,($32|0))|0;
    $j$3 = $30;$umax$pn = $umax;
   }
  } while(0);
  $i$4 = (($i$0) - ($umax$pn))|0;
  $33 = $7 & 63;
  $34 = ($j$3>>>0)>($33>>>0);
  if ($34) {
   $i$0 = $i$4;
  } else {
   break;
  }
 }
 if ((label|0) == 12) {
  STACKTOP = sp;return ($$0|0);
 }
 _ft_mem_free($1,$2);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _TT_Vary_Get_Glyph_Deltas($face,$glyph_index,$deltas,$n_points) {
 $face = $face|0;
 $glyph_index = $glyph_index|0;
 $deltas = $deltas|0;
 $n_points = $n_points|0;
 var $$0 = 0, $$pr = 0, $$pre = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error = 0, $exitcond = 0, $i$020 = 0, $j$03 = 0, $j$16 = 0, $j$29 = 0, $j$317 = 0, $j$413 = 0, $localpoints$021 = 0, $localpoints$1 = 0, $localpoints$2 = 0, $localpoints$3 = 0;
 var $offsetToData$0 = 0, $offsetToData$122 = 0, $offsetToData$2 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $phitmp = 0, $point_count = 0, $points$0 = 0, $sharedpoints$0 = 0, $spoint_count = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp + 8|0;
 $point_count = sp;
 $spoint_count = sp + 4|0;
 $0 = (($face) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($face) + 712|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[$spoint_count>>2] = 0;
 $6 = (($face) + 708|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $9 = ($5|0)==(0|0);
 $or$cond = $8 | $9;
 if ($or$cond) {
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (_ft_mem_realloc($3,8,0,$n_points,0,$error)|0);
 $11 = HEAP32[$error>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$deltas>>2] = $10;
 $13 = (($5) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14>>>0)>($glyph_index>>>0);
 if (!($15)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = (($5) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($glyph_index<<2)|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($glyph_index) + 1)|0;
 $21 = (($17) + ($20<<2)|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($19|0)==($22|0);
 if ($23) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = (_FT_Stream_Seek($1,$19)|0);
 HEAP32[$error>>2] = $24;
 $25 = ($24|0)==(0);
 if ($25) {
  $26 = HEAP32[$16>>2]|0;
  $27 = (($26) + ($20<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + ($glyph_index<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($28) - ($30))|0;
  $32 = (_FT_Stream_EnterFrame($1,$31)|0);
  HEAP32[$error>>2] = $32;
  $33 = ($32|0)==(0);
  if ($33) {
   $34 = (($1) + 32|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = HEAP32[$1>>2]|0;
   $37 = $35;
   $38 = $36;
   $39 = (($37) - ($38))|0;
   $40 = HEAP32[$5>>2]|0;
   $41 = (_ft_mem_realloc($3,4,0,$40,0,$error)|0);
   $42 = HEAP32[$error>>2]|0;
   $43 = ($42|0)==(0);
   if ($43) {
    $44 = HEAP32[$5>>2]|0;
    $45 = (_ft_mem_realloc($3,4,0,$44,0,$error)|0);
    $46 = HEAP32[$error>>2]|0;
    $47 = ($46|0)==(0);
    if ($47) {
     $48 = HEAP32[$5>>2]|0;
     $49 = (_ft_mem_realloc($3,4,0,$48,0,$error)|0);
     $50 = HEAP32[$error>>2]|0;
     $51 = ($50|0)==(0);
     if ($51) {
      $52 = (_FT_Stream_GetUShort($1)|0);
      $53 = $52&65535;
      $54 = (_FT_Stream_GetUShort($1)|0);
      $55 = $54&65535;
      $56 = (($55) + ($39))|0;
      $57 = $53 & 32768;
      $58 = ($57|0)==(0);
      if ($58) {
       $offsetToData$0 = $56;$sharedpoints$0 = 0;
      } else {
       $59 = HEAP32[$34>>2]|0;
       $60 = HEAP32[$1>>2]|0;
       $61 = $59;
       $62 = $60;
       $63 = (($61) - ($62))|0;
       $64 = (($60) + ($56)|0);
       HEAP32[$34>>2] = $64;
       $65 = (_ft_var_readpackedpoints($1,$spoint_count)|0);
       $66 = HEAP32[$34>>2]|0;
       $67 = HEAP32[$1>>2]|0;
       $68 = $66;
       $69 = $67;
       $70 = (($68) - ($69))|0;
       $71 = (($67) + ($63)|0);
       HEAP32[$34>>2] = $71;
       $offsetToData$0 = $70;$sharedpoints$0 = $65;
      }
      $72 = $53 & 4095;
      $73 = ($72|0)==(0);
      L23: do {
       if (!($73)) {
        $74 = (($5) + 24|0);
        $75 = (($5) + 28|0);
        $76 = HEAP32[$spoint_count>>2]|0;
        $77 = ($n_points|0)==(0);
        $i$020 = 0;$localpoints$021 = 0;$offsetToData$122 = $offsetToData$0;
        while(1) {
         $78 = (_FT_Stream_GetUShort($1)|0);
         $79 = $78&65535;
         $80 = (_FT_Stream_GetUShort($1)|0);
         $81 = $80&65535;
         $82 = $81 & 32768;
         $83 = ($82|0)==(0);
         if ($83) {
          $93 = $81 & 4095;
          $94 = HEAP32[$74>>2]|0;
          $95 = ($93>>>0)<($94>>>0);
          if (!($95)) {
           break;
          }
          $96 = HEAP32[$5>>2]|0;
          $97 = Math_imul($96, $93)|0;
          $98 = HEAP32[$75>>2]|0;
          $99 = (($98) + ($97<<2)|0);
          $100 = $96 << 2;
          _memcpy(($41|0),($99|0),($100|0))|0;
         } else {
          $84 = HEAP32[$5>>2]|0;
          $85 = ($84|0)==(0);
          if (!($85)) {
           $j$03 = 0;
           while(1) {
            $86 = (_FT_Stream_GetUShort($1)|0);
            $87 = $86 << 16 >> 16;
            $88 = $87 << 2;
            $89 = (($41) + ($j$03<<2)|0);
            HEAP32[$89>>2] = $88;
            $90 = (($j$03) + 1)|0;
            $91 = HEAP32[$5>>2]|0;
            $92 = ($90>>>0)<($91>>>0);
            if ($92) {
             $j$03 = $90;
            } else {
             break;
            }
           }
          }
         }
         $101 = $81 & 16384;
         $102 = ($101|0)==(0);
         if (!($102)) {
          $103 = HEAP32[$5>>2]|0;
          $104 = ($103|0)==(0);
          if (!($104)) {
           $j$16 = 0;
           while(1) {
            $105 = (_FT_Stream_GetUShort($1)|0);
            $106 = $105 << 16 >> 16;
            $107 = $106 << 2;
            $108 = (($45) + ($j$16<<2)|0);
            HEAP32[$108>>2] = $107;
            $109 = (($j$16) + 1)|0;
            $110 = HEAP32[$5>>2]|0;
            $111 = ($109>>>0)<($110>>>0);
            if ($111) {
             $j$16 = $109;
            } else {
             break;
            }
           }
           $phitmp = ($110|0)==(0);
           if (!($phitmp)) {
            $j$29 = 0;
            while(1) {
             $112 = (_FT_Stream_GetUShort($1)|0);
             $113 = $112 << 16 >> 16;
             $114 = $113 << 2;
             $115 = (($49) + ($j$29<<2)|0);
             HEAP32[$115>>2] = $114;
             $116 = (($j$29) + 1)|0;
             $117 = HEAP32[$5>>2]|0;
             $118 = ($116>>>0)<($117>>>0);
             if ($118) {
              $j$29 = $116;
             } else {
              break;
             }
            }
           }
          }
         }
         $119 = (_ft_var_apply_tuple($5,$80,$41,$45,$49)|0);
         $120 = ($119|0)==(0);
         if ($120) {
          $localpoints$3 = $localpoints$021;
         } else {
          $121 = HEAP32[$34>>2]|0;
          $122 = HEAP32[$1>>2]|0;
          $123 = $121;
          $124 = $122;
          $125 = (($123) - ($124))|0;
          $126 = $81 & 8192;
          $127 = ($126|0)==(0);
          if ($127) {
           HEAP32[$point_count>>2] = $76;
           $131 = $76;$localpoints$1 = $localpoints$021;$points$0 = $sharedpoints$0;
          } else {
           $128 = (($122) + ($offsetToData$122)|0);
           HEAP32[$34>>2] = $128;
           $129 = (_ft_var_readpackedpoints($1,$point_count)|0);
           $$pre = HEAP32[$point_count>>2]|0;
           $131 = $$pre;$localpoints$1 = $129;$points$0 = $129;
          }
          $130 = ($131|0)==(0);
          $132 = $130 ? $n_points : $131;
          $133 = (_ft_var_readpackeddeltas($1,$132)|0);
          $134 = (_ft_var_readpackeddeltas($1,$132)|0);
          $135 = ($points$0|0)==(0|0);
          $136 = ($134|0)==(0|0);
          $or$cond1 = $135 | $136;
          $137 = ($133|0)==(0|0);
          $or$cond2 = $or$cond1 | $137;
          L48: do {
           if (!($or$cond2)) {
            $138 = ($points$0|0)==((-1)|0);
            if ($138) {
             if ($77) {
              break;
             } else {
              $j$317 = 0;
             }
             while(1) {
              $139 = (($133) + ($j$317<<1)|0);
              $140 = HEAP16[$139>>1]|0;
              $141 = $140 << 16 >> 16;
              $142 = (_FT_MulFix($141,$119)|0);
              $143 = (($10) + ($j$317<<3)|0);
              $144 = HEAP32[$143>>2]|0;
              $145 = (($144) + ($142))|0;
              HEAP32[$143>>2] = $145;
              $146 = (($134) + ($j$317<<1)|0);
              $147 = HEAP16[$146>>1]|0;
              $148 = $147 << 16 >> 16;
              $149 = (_FT_MulFix($148,$119)|0);
              $150 = ((($10) + ($j$317<<3)|0) + 4|0);
              $151 = HEAP32[$150>>2]|0;
              $152 = (($151) + ($149))|0;
              HEAP32[$150>>2] = $152;
              $153 = (($j$317) + 1)|0;
              $exitcond = ($153|0)==($n_points|0);
              if ($exitcond) {
               break L48;
              } else {
               $j$317 = $153;
              }
             }
            }
            if ($130) {
             break;
            } else {
             $j$413 = 0;
            }
            while(1) {
             $154 = (($localpoints$1) + ($j$413<<1)|0);
             $155 = HEAP16[$154>>1]|0;
             $156 = $155&65535;
             $157 = ($156>>>0)<($n_points>>>0);
             if ($157) {
              $158 = (($133) + ($j$413<<1)|0);
              $159 = HEAP16[$158>>1]|0;
              $160 = $159 << 16 >> 16;
              $161 = (_FT_MulFix($160,$119)|0);
              $162 = HEAP16[$154>>1]|0;
              $163 = $162&65535;
              $164 = (($10) + ($163<<3)|0);
              $165 = HEAP32[$164>>2]|0;
              $166 = (($165) + ($161))|0;
              HEAP32[$164>>2] = $166;
              $167 = (($134) + ($j$413<<1)|0);
              $168 = HEAP16[$167>>1]|0;
              $169 = $168 << 16 >> 16;
              $170 = (_FT_MulFix($169,$119)|0);
              $171 = HEAP16[$154>>1]|0;
              $172 = $171&65535;
              $173 = ((($10) + ($172<<3)|0) + 4|0);
              $174 = HEAP32[$173>>2]|0;
              $175 = (($174) + ($170))|0;
              HEAP32[$173>>2] = $175;
             }
             $176 = (($j$413) + 1)|0;
             $177 = ($176>>>0)<($131>>>0);
             if ($177) {
              $j$413 = $176;
             } else {
              break;
             }
            }
           }
          } while(0);
          $178 = ($localpoints$1|0)==((-1)|0);
          if ($178) {
           $localpoints$2 = (-1);
          } else {
           _ft_mem_free($3,$localpoints$1);
           $localpoints$2 = 0;
          }
          _ft_mem_free($3,$133);
          _ft_mem_free($3,$134);
          $179 = HEAP32[$1>>2]|0;
          $180 = (($179) + ($125)|0);
          HEAP32[$34>>2] = $180;
          $localpoints$3 = $localpoints$2;
         }
         $offsetToData$2 = (($79) + ($offsetToData$122))|0;
         $181 = (($i$020) + 1)|0;
         $182 = ($181>>>0)<($72>>>0);
         if ($182) {
          $i$020 = $181;$localpoints$021 = $localpoints$3;$offsetToData$122 = $offsetToData$2;
         } else {
          break L23;
         }
        }
        HEAP32[$error>>2] = 8;
       }
      } while(0);
      _ft_mem_free($3,$41);
      _ft_mem_free($3,$45);
      _ft_mem_free($3,$49);
     }
    }
   }
   _FT_Stream_ExitFrame($1);
   $$pr = HEAP32[$error>>2]|0;
   $183 = ($$pr|0)==(0);
   if ($183) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 _ft_mem_free($3,$10);
 HEAP32[$deltas>>2] = 0;
 $$pre24 = HEAP32[$error>>2]|0;
 $$0 = $$pre24;
 STACKTOP = sp;return ($$0|0);
}
function _tt_done_blend($memory,$blend) {
 $memory = $memory|0;
 $blend = $blend|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($blend|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($blend) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 _ft_mem_free($memory,$2);
 HEAP32[$1>>2] = 0;
 $3 = (($blend) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 _ft_mem_free($memory,$4);
 HEAP32[$3>>2] = 0;
 $5 = (($blend) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = HEAP32[$blend>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $$lcssa = $6;
  } else {
   $11 = $6;$i$01 = 0;
   while(1) {
    $10 = ((($11) + ($i$01<<3)|0) + 4|0);
    $12 = HEAP32[$10>>2]|0;
    _ft_mem_free($memory,$12);
    $13 = HEAP32[$5>>2]|0;
    $14 = ((($13) + ($i$01<<3)|0) + 4|0);
    HEAP32[$14>>2] = 0;
    $15 = (($i$01) + 1)|0;
    $16 = HEAP32[$blend>>2]|0;
    $17 = ($15>>>0)<($16>>>0);
    $18 = HEAP32[$5>>2]|0;
    if ($17) {
     $11 = $18;$i$01 = $15;
    } else {
     $$lcssa = $18;
     break;
    }
   }
  }
  _ft_mem_free($memory,$$lcssa);
  HEAP32[$5>>2] = 0;
 }
 $19 = (($blend) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 _ft_mem_free($memory,$20);
 HEAP32[$19>>2] = 0;
 $21 = (($blend) + 36|0);
 $22 = HEAP32[$21>>2]|0;
 _ft_mem_free($memory,$22);
 HEAP32[$21>>2] = 0;
 _ft_mem_free($memory,$blend);
 STACKTOP = sp;return;
}
function _TT_Goto_CodeRange($exec,$range,$IP) {
 $exec = $exec|0;
 $range = $range|0;
 $IP = $IP|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($range) + -1)|0;
 $1 = ((($exec) + ($0<<3)|0) + 444|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($exec) + 356|0);
 HEAP32[$3>>2] = $2;
 $4 = ((($exec) + ($0<<3)|0) + 448|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($exec) + 364|0);
 HEAP32[$6>>2] = $5;
 $7 = (($exec) + 360|0);
 HEAP32[$7>>2] = $IP;
 $8 = (($exec) + 352|0);
 HEAP32[$8>>2] = $range;
 STACKTOP = sp;return 0;
}
function _TT_Set_CodeRange($exec,$range,$base,$length) {
 $exec = $exec|0;
 $range = $range|0;
 $base = $base|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($range) + -1)|0;
 $1 = ((($exec) + ($0<<3)|0) + 444|0);
 HEAP32[$1>>2] = $base;
 $2 = ((($exec) + ($0<<3)|0) + 448|0);
 HEAP32[$2>>2] = $length;
 STACKTOP = sp;return 0;
}
function _TT_Clear_CodeRange($exec,$range) {
 $exec = $exec|0;
 $range = $range|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($range) + -1)|0;
 $1 = ((($exec) + ($0<<3)|0) + 444|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($exec) + ($0<<3)|0) + 448|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return 0;
}
function _TT_Done_Context($exec) {
 $exec = $exec|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exec) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($exec) + 440|0);
 HEAP16[$2>>1] = 0;
 $3 = (($exec) + 442|0);
 HEAP16[$3>>1] = 0;
 $4 = (($exec) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 _ft_mem_free($1,$5);
 HEAP32[$4>>2] = 0;
 $6 = (($exec) + 20|0);
 HEAP32[$6>>2] = 0;
 $7 = (($exec) + 436|0);
 $8 = HEAP32[$7>>2]|0;
 _ft_mem_free($1,$8);
 HEAP32[$7>>2] = 0;
 $9 = (($exec) + 432|0);
 HEAP32[$9>>2] = 0;
 $10 = (($exec) + 428|0);
 HEAP32[$10>>2] = 0;
 $11 = (($exec) + 392|0);
 $12 = HEAP32[$11>>2]|0;
 _ft_mem_free($1,$12);
 HEAP32[$11>>2] = 0;
 $13 = (($exec) + 388|0);
 HEAP32[$13>>2] = 0;
 $14 = (($exec) + 4|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$exec>>2] = 0;
 _ft_mem_free($1,$exec);
 STACKTOP = sp;return 0;
}
function _Update_Max($memory,$size,$multiplier,$_pbuff,$new_max) {
 $memory = $memory|0;
 $size = $size|0;
 $multiplier = $multiplier|0;
 $_pbuff = $_pbuff|0;
 $new_max = $new_max|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$size>>2]|0;
 $1 = ($0>>>0)<($new_max>>>0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = Math_imul($0, $multiplier)|0;
 $3 = Math_imul($new_max, $multiplier)|0;
 $4 = HEAP32[$_pbuff>>2]|0;
 $5 = (_ft_mem_realloc($memory,1,$2,$3,$4,$error)|0);
 HEAP32[$_pbuff>>2] = $5;
 $6 = HEAP32[$error>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$size>>2] = $new_max;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _TT_Load_Context($exec,$face,$size) {
 $exec = $exec|0;
 $face = $face|0;
 $size = $size|0;
 var $$0 = 0, $$ph = 0, $$ph5 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $error$i1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i1 = sp;
 HEAP32[$exec>>2] = $face;
 $0 = (($exec) + 4|0);
 HEAP32[$0>>2] = $size;
 $1 = ($size|0)==(0|0);
 if (!($1)) {
  $2 = (($size) + 116|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($exec) + 396|0);
  HEAP32[$4>>2] = $3;
  $5 = (($size) + 120|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($exec) + 400|0);
  HEAP32[$7>>2] = $6;
  $8 = (($size) + 128|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($exec) + 408|0);
  HEAP32[$10>>2] = $9;
  $11 = (($size) + 132|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($exec) + 412|0);
  HEAP32[$13>>2] = $12;
  $14 = (($size) + 124|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($exec) + 404|0);
  HEAP32[$16>>2] = $15;
  $17 = (($size) + 136|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($exec) + 416|0);
  HEAP32[$19>>2] = $18;
  $20 = (($exec) + 244|0);
  $21 = (($size) + 72|0);
  dest=$20+0|0; src=$21+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $22 = (($exec) + 216|0);
  $23 = (($size) + 44|0);
  ;HEAP32[$22+0>>2]=HEAP32[$23+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$23+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$23+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$23+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$23+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$23+20>>2]|0;HEAP32[$22+24>>2]=HEAP32[$23+24>>2]|0;
  $24 = (($size) + 140|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($exec) + 420|0);
  HEAP32[$26>>2] = $25;
  $27 = (($size) + 144|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($exec) + 424|0);
  HEAP32[$29>>2] = $28;
  $30 = (($exec) + 444|0);
  $31 = (($size) + 148|0);
  $32 = $31;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $30;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  $42 = (($exec) + 452|0);
  $43 = (($size) + 156|0);
  $44 = $43;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = (($44) + 4)|0;
  $48 = $47;
  $49 = HEAP32[$48>>2]|0;
  $50 = $42;
  $51 = $50;
  HEAP32[$51>>2] = $46;
  $52 = (($50) + 4)|0;
  $53 = $52;
  HEAP32[$53>>2] = $49;
  $54 = (($exec) + 460|0);
  $55 = (($size) + 164|0);
  $56 = $55;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = (($56) + 4)|0;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = $54;
  $63 = $62;
  HEAP32[$63>>2] = $58;
  $64 = (($62) + 4)|0;
  $65 = $64;
  HEAP32[$65>>2] = $61;
  $66 = (($exec) + 284|0);
  $67 = (($size) + 172|0);
  dest=$66+0|0; src=$67+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $68 = (($size) + 240|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($exec) + 380|0);
  HEAP32[$70>>2] = $69;
  $71 = (($size) + 244|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($exec) + 384|0);
  HEAP32[$73>>2] = $72;
  $74 = (($size) + 248|0);
  $75 = HEAP16[$74>>1]|0;
  $76 = (($exec) + 468|0);
  HEAP16[$76>>1] = $75;
  $77 = (($size) + 252|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = (($exec) + 472|0);
  HEAP32[$79>>2] = $78;
  $80 = (($exec) + 180|0);
  $81 = (($size) + 256|0);
  dest=$80+0|0; src=$81+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $82 = (($exec) + 36|0);
  dest=$82+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $83 = (($exec) + 72|0);
  dest=$83+0|0; src=$82+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $84 = (($exec) + 108|0);
  dest=$84+0|0; src=$82+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 }
 $85 = (($exec) + 20|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($exec) + 8|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = (($exec) + 24|0);
 $90 = (($face) + 284|0);
 $91 = HEAP16[$90>>1]|0;
 $92 = $91&65535;
 $93 = (($92) + 32)|0;
 $94 = ($86>>>0)<($93>>>0);
 do {
  if ($94) {
   $95 = $86 << 2;
   $96 = $93 << 2;
   $97 = HEAP32[$89>>2]|0;
   $98 = (_ft_mem_realloc($88,1,$95,$96,$97,$error$i1)|0);
   HEAP32[$89>>2] = $98;
   $99 = HEAP32[$error$i1>>2]|0;
   $100 = ($99|0)==(0);
   if ($100) {
    $$pre = HEAP32[$87>>2]|0;
    $$ph = $93;$109 = $$pre;
    break;
   }
   HEAP32[$85>>2] = $86;
   $$0 = $99;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$ph = $86;$109 = $88;
  }
 } while(0);
 HEAP32[$85>>2] = $$ph;
 $101 = (($exec) + 388|0);
 $102 = HEAP32[$101>>2]|0;
 $103 = (($exec) + 392|0);
 $104 = (($face) + 286|0);
 $105 = HEAP16[$104>>1]|0;
 $106 = $105&65535;
 $107 = ($102>>>0)<($106>>>0);
 if ($107) {
  $108 = HEAP32[$103>>2]|0;
  $110 = (_ft_mem_realloc($109,1,$102,$106,$108,$error$i1)|0);
  HEAP32[$103>>2] = $110;
  $111 = HEAP32[$error$i1>>2]|0;
  $112 = ($111|0)==(0);
  if ($112) {
   $$ph5 = $106;
  } else {
   $113 = $102 & 65535;
   HEAP32[$101>>2] = $113;
   $$0 = $111;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$ph5 = $102;
 }
 $114 = $$ph5 & 65535;
 HEAP32[$101>>2] = $114;
 $115 = (($exec) + 144|0);
 $116 = (($exec) + 152|0);
 HEAP16[$116>>1] = 0;
 $117 = (($exec) + 154|0);
 HEAP16[$117>>1] = 0;
 $118 = (($exec) + 72|0);
 dest=$118+0|0; src=$115+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $119 = (($exec) + 108|0);
 dest=$119+0|0; src=$115+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $120 = (($exec) + 36|0);
 dest=$120+0|0; src=$115+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $121 = (($exec) + 488|0);
 HEAP8[$121>>0] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _TT_Save_Context($exec,$size) {
 $exec = $exec|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exec) + 396|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($size) + 116|0);
 HEAP32[$2>>2] = $1;
 $3 = (($exec) + 408|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($size) + 128|0);
 HEAP32[$5>>2] = $4;
 $6 = (($exec) + 420|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($size) + 140|0);
 HEAP32[$8>>2] = $7;
 $9 = (($exec) + 424|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($size) + 144|0);
 HEAP32[$11>>2] = $10;
 $12 = (($size) + 148|0);
 $13 = (($exec) + 444|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $12;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = (($size) + 156|0);
 $25 = (($exec) + 452|0);
 $26 = $25;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $24;
 $33 = $32;
 HEAP32[$33>>2] = $28;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $31;
 $36 = (($size) + 164|0);
 $37 = (($exec) + 460|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $36;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 STACKTOP = sp;return 0;
}
function _TT_Run_Context($exec,$debug) {
 $exec = $exec|0;
 $debug = $debug|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($exec) + 460|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($exec) + 356|0);
 HEAP32[$2>>2] = $1;
 $3 = (($exec) + 464|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($exec) + 364|0);
 HEAP32[$5>>2] = $4;
 $6 = (($exec) + 360|0);
 HEAP32[$6>>2] = 0;
 $7 = (($exec) + 352|0);
 HEAP32[$7>>2] = 3;
 $8 = (($exec) + 36|0);
 $9 = (($exec) + 144|0);
 dest=$8+0|0; src=$9+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $10 = (($exec) + 72|0);
 dest=$10+0|0; src=$9+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $11 = (($exec) + 108|0);
 dest=$11+0|0; src=$9+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $12 = (($exec) + 344|0);
 HEAP16[$12>>1] = 1;
 $13 = (($exec) + 346|0);
 HEAP16[$13>>1] = 1;
 $14 = (($exec) + 348|0);
 HEAP16[$14>>1] = 1;
 $15 = (($exec) + 294|0);
 HEAP16[$15>>1] = 16384;
 $16 = (($exec) + 296|0);
 HEAP16[$16>>1] = 0;
 $17 = (($exec) + 298|0);
 $18 = HEAPU16[$15>>1]|(HEAPU16[$15+2>>1]<<16);
 HEAP16[$17>>1]=$18&65535;HEAP16[$17+2>>1]=$18>>>16;
 $19 = (($exec) + 290|0);
 HEAP16[$19>>1]=$18&65535;HEAP16[$19+2>>1]=$18>>>16;
 $20 = (($exec) + 312|0);
 HEAP32[$20>>2] = 1;
 $21 = (($exec) + 304|0);
 HEAP32[$21>>2] = 1;
 $22 = (($exec) + 16|0);
 HEAP32[$22>>2] = 0;
 $23 = (($exec) + 428|0);
 HEAP32[$23>>2] = 0;
 $24 = HEAP32[$exec>>2]|0;
 $25 = (($24) + 688|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (FUNCTION_TABLE_ii[$26 & 4095]($exec)|0);
 STACKTOP = sp;return ($27|0);
}
function _TT_New_Context($driver) {
 $driver = $driver|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, $error$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i = sp + 4|0;
 $error = sp;
 $0 = (($driver) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($driver) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (_ft_mem_alloc($1,608,$error)|0);
 $6 = HEAP32[$error>>2]|0;
 $7 = ($6|0)==(0);
 if (!($7)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($5) + 8|0);
 HEAP32[$8>>2] = $1;
 $9 = (($5) + 432|0);
 HEAP32[$9>>2] = 32;
 $10 = (_ft_mem_realloc($1,16,0,32,0,$error$i)|0);
 $11 = (($5) + 436|0);
 HEAP32[$11>>2] = $10;
 $12 = HEAP32[$error$i>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  $14 = (($5) + 440|0);
  HEAP16[$14>>1] = 0;
  $15 = (($5) + 442|0);
  HEAP16[$15>>1] = 0;
  $16 = (($5) + 20|0);
  HEAP32[$16>>2] = 0;
  $17 = (($5) + 388|0);
  HEAP32[$17>>2] = 0;
  $18 = (($5) + 24|0);
  HEAP32[$18>>2] = 0;
  $19 = (($5) + 392|0);
  HEAP32[$19>>2] = 0;
  HEAP32[$5>>2] = 0;
  $20 = (($5) + 4|0);
  HEAP32[$20>>2] = 0;
  HEAP32[$error>>2] = 0;
 } else {
  $21 = HEAP32[$8>>2]|0;
  $22 = (($5) + 440|0);
  HEAP16[$22>>1] = 0;
  $23 = (($5) + 442|0);
  HEAP16[$23>>1] = 0;
  $24 = (($5) + 24|0);
  $25 = HEAP32[$24>>2]|0;
  _ft_mem_free($21,$25);
  HEAP32[$24>>2] = 0;
  $26 = (($5) + 20|0);
  HEAP32[$26>>2] = 0;
  $27 = HEAP32[$11>>2]|0;
  _ft_mem_free($21,$27);
  HEAP32[$11>>2] = 0;
  HEAP32[$9>>2] = 0;
  $28 = (($5) + 428|0);
  HEAP32[$28>>2] = 0;
  $29 = (($5) + 392|0);
  $30 = HEAP32[$29>>2]|0;
  _ft_mem_free($21,$30);
  HEAP32[$29>>2] = 0;
  $31 = (($5) + 388|0);
  HEAP32[$31>>2] = 0;
  $32 = (($5) + 4|0);
  HEAP32[$32>>2] = 0;
  HEAP32[$5>>2] = 0;
  _ft_mem_free($21,$5);
  $33 = HEAP32[$error$i>>2]|0;
  HEAP32[$error>>2] = $33;
  $34 = ($33|0)==(0);
  if (!($34)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$2>>2] = $5;
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function _TT_RunIns($exc) {
 $exc = $exc|0;
 var $$$$i = 0, $$$i = 0, $$$i$i = 0, $$$i$i125 = 0, $$$i$i149 = 0, $$$i$i245 = 0, $$$i110 = 0, $$$i153 = 0, $$$i177 = 0, $$$i179 = 0, $$$i218 = 0, $$$i230 = 0, $$$i238 = 0, $$$i3$i = 0, $$$i3$i151 = 0, $$$i4$i = 0, $$$i5$i = 0, $$$i83 = 0, $$$i98 = 0, $$0 = 0;
 var $$01$i$i = 0, $$01$i$i148 = 0, $$01$i$i244 = 0, $$01$i2$i = 0, $$01$i2$i150 = 0, $$01$i3$i = 0, $$1$i = 0, $$1$i$i = 0, $$1$i$i249 = 0, $$A$0$i = 0, $$A$0$i217 = 0, $$A$0$i70 = 0, $$a$i$i = 0, $$a$i$i147 = 0, $$a$i$i243 = 0, $$cvt_dist$1$i = 0, $$cvt_dist$2$i = 0, $$distance$0$i = 0, $$distance$0$i252 = 0, $$distance$01$i = 0;
 var $$distance$01$i253 = 0, $$idx = 0, $$idx$val = 0, $$idx41 = 0, $$idx41$val = 0, $$idx47 = 0, $$idx47$val = 0, $$idx49 = 0, $$idx49$val = 0, $$idx52 = 0, $$idx52$val = 0, $$idx54 = 0, $$idx54$val = 0, $$mux$i = 0, $$mux7$i = 0, $$off$i = 0, $$op$i = 0, $$pn$i = 0, $$pn$in$i = 0, $$pr$i = 0;
 var $$pr$i131 = 0, $$pr$pr$pr = 0, $$pr$pre$i = 0, $$pre = 0, $$pre$i100 = 0, $$pre$i108 = 0, $$pre$i134 = 0, $$pre$i139 = 0, $$pre$i143 = 0, $$pre$i158 = 0, $$pre$i165 = 0, $$pre$i169 = 0, $$pre$i182$pre = 0, $$pre$i194 = 0, $$pre$i210 = 0, $$pre$i224 = 0, $$pre$i247 = 0, $$pre$i64 = 0, $$pre$i93 = 0, $$pre$phi3$iZ2D = 0;
 var $$pre$phiZ2D = 0, $$pre1$i211 = 0, $$pre2$i = 0, $$pre2$i135 = 0, $$pre2$i137 = 0, $$pre2$i170 = 0, $$pre2$i212 = 0, $$pre3$i = 0, $$pre3$i171 = 0, $$pre3$i213 = 0, $$pre3$i75 = 0, $$pre4$i = 0, $$pre414 = 0, $$pre416 = 0, $$pre417 = 0, $$pre418 = 0, $$pre423 = 0, $$pre453 = 0, $$pre454 = 0, $$pre455 = 0;
 var $$pre456 = 0, $$pre457 = 0, $$pre458 = 0, $$pre459 = 0, $$pre460 = 0, $$pre461 = 0, $$pre477 = 0, $$pre5$i = 0, $$pre5$i225 = 0, $$pre6$i = 0, $$pre6$i109 = 0, $$pre6$i226 = 0, $$sum = 0, $$sum1 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0;
 var $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum25 = 0, $$sum260 = 0, $$sum261 = 0, $$sum262 = 0, $$sum263 = 0, $$sum264 = 0, $$sum265 = 0, $$sum266 = 0, $$sum267 = 0, $$sum268 = 0, $$sum269 = 0;
 var $$sum270 = 0, $$sum271 = 0, $$sum272 = 0, $$sum273 = 0, $$sum274 = 0, $$sum275 = 0, $$sum276 = 0, $$sum277 = 0, $$sum278 = 0, $$sum279 = 0, $$sum28 = 0, $$sum280 = 0, $$sum281 = 0, $$sum29 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0;
 var $$sum9 = 0, $$val = 0, $$val33 = 0, $$val34 = 0, $$val35 = 0, $$val36 = 0, $$val37 = 0, $$val38 = 0, $$val39 = 0, $$val40 = 0, $$val42 = 0, $$val43 = 0, $$val44 = 0, $$val45 = 0, $$val46 = 0, $$val48 = 0, $$val50 = 0, $$val51 = 0, $$val53 = 0, $$val55 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0;
 var $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0;
 var $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0;
 var $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0;
 var $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0;
 var $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0;
 var $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0;
 var $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0;
 var $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0;
 var $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0;
 var $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0;
 var $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0;
 var $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0;
 var $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0;
 var $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0;
 var $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0;
 var $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0;
 var $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0;
 var $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0;
 var $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0, $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0;
 var $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0, $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0;
 var $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0, $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0;
 var $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0, $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0;
 var $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0, $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0;
 var $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0, $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0;
 var $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0, $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0;
 var $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0, $1475 = 0, $1476 = 0, $1477 = 0, $1478 = 0, $1479 = 0, $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0;
 var $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0, $1495 = 0, $1496 = 0, $1497 = 0, $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0;
 var $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0, $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0;
 var $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0, $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0;
 var $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0, $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0;
 var $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0, $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0;
 var $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0, $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0;
 var $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0, $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0;
 var $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0, $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0;
 var $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0, $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0;
 var $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0, $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0;
 var $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0, $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0;
 var $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0, $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0;
 var $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0, $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0;
 var $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0, $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0;
 var $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0, $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0;
 var $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0, $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0;
 var $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0, $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0;
 var $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0, $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0;
 var $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0, $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0;
 var $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0, $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0;
 var $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0, $1848 = 0, $1849 = 0, $185 = 0, $1850 = 0, $1851 = 0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0, $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0;
 var $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0, $1876 = 0, $1877 = 0, $1878 = 0, $1879 = 0, $188 = 0;
 var $1880 = 0, $1881 = 0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0, $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0;
 var $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0, $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0, $1915 = 0;
 var $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0, $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0;
 var $1934 = 0, $1935 = 0, $1936 = 0, $1937 = 0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0, $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0;
 var $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0, $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0;
 var $1970 = 0, $1971 = 0, $1972 = 0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0, $1981 = 0, $1982 = 0, $1983 = 0, $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0;
 var $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0, $2 = 0, $20 = 0, $200 = 0, $2000 = 0, $2001 = 0, $2002 = 0, $2003 = 0, $2004 = 0;
 var $2005 = 0, $2006 = 0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0, $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0;
 var $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0, $2034 = 0, $2035 = 0, $2036 = 0, $2037 = 0, $2038 = 0, $2039 = 0, $204 = 0, $2040 = 0;
 var $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0, $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0, $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0;
 var $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0, $2067 = 0, $2068 = 0, $2069 = 0, $207 = 0, $2070 = 0, $2071 = 0, $2072 = 0, $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0;
 var $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0, $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0;
 var $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0, $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0, $2112 = 0;
 var $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0, $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0, $2130 = 0;
 var $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0, $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0, $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0;
 var $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0, $2162 = 0, $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0, $2167 = 0;
 var $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0, $2174 = 0, $2175 = 0, $2176 = 0, $2177 = 0, $2178 = 0, $2179 = 0, $218 = 0, $2180 = 0, $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0, $2185 = 0;
 var $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0, $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0, $22 = 0, $220 = 0, $2200 = 0, $2201 = 0, $2202 = 0;
 var $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0, $2210 = 0, $2211 = 0, $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0, $2216 = 0, $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0;
 var $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0, $2228 = 0, $2229 = 0, $223 = 0, $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0, $2234 = 0, $2235 = 0, $2236 = 0, $2237 = 0, $2238 = 0, $2239 = 0;
 var $224 = 0, $2240 = 0, $2241 = 0, $2242 = 0, $2243 = 0, $2244 = 0, $2245 = 0, $2246 = 0, $2247 = 0, $2248 = 0, $2249 = 0, $225 = 0, $2250 = 0, $2251 = 0, $2252 = 0, $2253 = 0, $2254 = 0, $2255 = 0, $2256 = 0, $2257 = 0;
 var $2258 = 0, $2259 = 0, $226 = 0, $2260 = 0, $2261 = 0, $2262 = 0, $2263 = 0, $2264 = 0, $2265 = 0, $2266 = 0, $2267 = 0, $2268 = 0, $2269 = 0, $227 = 0, $2270 = 0, $2271 = 0, $2272 = 0, $2273 = 0, $2274 = 0, $2275 = 0;
 var $2276 = 0, $2277 = 0, $2278 = 0, $2279 = 0, $228 = 0, $2280 = 0, $2281 = 0, $2282 = 0, $2283 = 0, $2284 = 0, $2285 = 0, $2286 = 0, $2287 = 0, $2288 = 0, $2289 = 0, $229 = 0, $2290 = 0, $2291 = 0, $2292 = 0, $2293 = 0;
 var $2294 = 0, $2295 = 0, $2296 = 0, $2297 = 0, $2298 = 0, $2299 = 0, $23 = 0, $230 = 0, $2300 = 0, $2301 = 0, $2302 = 0, $2303 = 0, $2304 = 0, $2305 = 0, $2306 = 0, $2307 = 0, $2308 = 0, $2309 = 0, $231 = 0, $2310 = 0;
 var $2311 = 0, $2312 = 0, $2313 = 0, $2314 = 0, $2315 = 0, $2316 = 0, $2317 = 0, $2318 = 0, $2319 = 0, $232 = 0, $2320 = 0, $2321 = 0, $2322 = 0, $2323 = 0, $2324 = 0, $2325 = 0, $2326 = 0, $2327 = 0, $2328 = 0, $2329 = 0;
 var $233 = 0, $2330 = 0, $2331 = 0, $2332 = 0, $2333 = 0, $2334 = 0, $2335 = 0, $2336 = 0, $2337 = 0, $2338 = 0, $2339 = 0, $234 = 0, $2340 = 0, $2341 = 0, $2342 = 0, $2343 = 0, $2344 = 0, $2345 = 0, $2346 = 0, $2347 = 0;
 var $2348 = 0, $2349 = 0, $235 = 0, $2350 = 0, $2351 = 0, $2352 = 0, $2353 = 0, $2354 = 0, $2355 = 0, $2356 = 0, $2357 = 0, $2358 = 0, $2359 = 0, $236 = 0, $2360 = 0, $2361 = 0, $2362 = 0, $2363 = 0, $2364 = 0, $2365 = 0;
 var $2366 = 0, $2367 = 0, $2368 = 0, $2369 = 0, $237 = 0, $2370 = 0, $2371 = 0, $2372 = 0, $2373 = 0, $2374 = 0, $2375 = 0, $2376 = 0, $2377 = 0, $2378 = 0, $2379 = 0, $238 = 0, $2380 = 0, $2381 = 0, $2382 = 0, $2383 = 0;
 var $2384 = 0, $2385 = 0, $2386 = 0, $2387 = 0, $2388 = 0, $2389 = 0, $239 = 0, $2390 = 0, $2391 = 0, $2392 = 0, $2393 = 0, $2394 = 0, $2395 = 0, $2396 = 0, $2397 = 0, $2398 = 0, $2399 = 0, $24 = 0, $240 = 0, $2400 = 0;
 var $2401 = 0, $2402 = 0, $2403 = 0, $2404 = 0, $2405 = 0, $2406 = 0, $2407 = 0, $2408 = 0, $2409 = 0, $241 = 0, $2410 = 0, $2411 = 0, $2412 = 0, $2413 = 0, $2414 = 0, $2415 = 0, $2416 = 0, $2417 = 0, $2418 = 0, $2419 = 0;
 var $242 = 0, $2420 = 0, $2421 = 0, $2422 = 0, $2423 = 0, $2424 = 0, $2425 = 0, $2426 = 0, $2427 = 0, $2428 = 0, $2429 = 0, $243 = 0, $2430 = 0, $2431 = 0, $2432 = 0, $2433 = 0, $2434 = 0, $2435 = 0, $2436 = 0, $2437 = 0;
 var $2438 = 0, $2439 = 0, $244 = 0, $2440 = 0, $2441 = 0, $2442 = 0, $2443 = 0, $2444 = 0, $2445 = 0, $2446 = 0, $2447 = 0, $2448 = 0, $2449 = 0, $245 = 0, $2450 = 0, $2451 = 0, $2452 = 0, $2453 = 0, $2454 = 0, $2455 = 0;
 var $2456 = 0, $2457 = 0, $2458 = 0, $2459 = 0, $246 = 0, $2460 = 0, $2461 = 0, $2462 = 0, $2463 = 0, $2464 = 0, $2465 = 0, $2466 = 0, $2467 = 0, $2468 = 0, $2469 = 0, $247 = 0, $2470 = 0, $2471 = 0, $2472 = 0, $2473 = 0;
 var $2474 = 0, $2475 = 0, $2476 = 0, $2477 = 0, $2478 = 0, $2479 = 0, $248 = 0, $2480 = 0, $2481 = 0, $2482 = 0, $2483 = 0, $2484 = 0, $2485 = 0, $2486 = 0, $2487 = 0, $2488 = 0, $2489 = 0, $249 = 0, $2490 = 0, $2491 = 0;
 var $2492 = 0, $2493 = 0, $2494 = 0, $2495 = 0, $2496 = 0, $2497 = 0, $2498 = 0, $2499 = 0, $25 = 0, $250 = 0, $2500 = 0, $2501 = 0, $2502 = 0, $2503 = 0, $2504 = 0, $2505 = 0, $2506 = 0, $2507 = 0, $2508 = 0, $2509 = 0;
 var $251 = 0, $2510 = 0, $2511 = 0, $2512 = 0, $2513 = 0, $2514 = 0, $2515 = 0, $2516 = 0, $2517 = 0, $2518 = 0, $2519 = 0, $252 = 0, $2520 = 0, $2521 = 0, $2522 = 0, $2523 = 0, $2524 = 0, $2525 = 0, $2526 = 0, $2527 = 0;
 var $2528 = 0, $2529 = 0, $253 = 0, $2530 = 0, $2531 = 0, $2532 = 0, $2533 = 0, $2534 = 0, $2535 = 0, $2536 = 0, $2537 = 0, $2538 = 0, $2539 = 0, $254 = 0, $2540 = 0, $2541 = 0, $2542 = 0, $2543 = 0, $2544 = 0, $2545 = 0;
 var $2546 = 0, $2547 = 0, $2548 = 0, $2549 = 0, $255 = 0, $2550 = 0, $2551 = 0, $2552 = 0, $2553 = 0, $2554 = 0, $2555 = 0, $2556 = 0, $2557 = 0, $2558 = 0, $2559 = 0, $256 = 0, $2560 = 0, $2561 = 0, $2562 = 0, $2563 = 0;
 var $2564 = 0, $2565 = 0, $2566 = 0, $2567 = 0, $2568 = 0, $2569 = 0, $257 = 0, $2570 = 0, $2571 = 0, $2572 = 0, $2573 = 0, $2574 = 0, $2575 = 0, $2576 = 0, $2577 = 0, $2578 = 0, $2579 = 0, $258 = 0, $2580 = 0, $2581 = 0;
 var $2582 = 0, $2583 = 0, $2584 = 0, $2585 = 0, $2586 = 0, $2587 = 0, $2588 = 0, $2589 = 0, $259 = 0, $2590 = 0, $2591 = 0, $2592 = 0, $2593 = 0, $2594 = 0, $2595 = 0, $2596 = 0, $2597 = 0, $2598 = 0, $2599 = 0, $26 = 0;
 var $260 = 0, $2600 = 0, $2601 = 0, $2602 = 0, $2603 = 0, $2604 = 0, $2605 = 0, $2606 = 0, $2607 = 0, $2608 = 0, $2609 = 0, $261 = 0, $2610 = 0, $2611 = 0, $2612 = 0, $2613 = 0, $2614 = 0, $2615 = 0, $2616 = 0, $2617 = 0;
 var $2618 = 0, $2619 = 0, $262 = 0, $2620 = 0, $2621 = 0, $2622 = 0, $2623 = 0, $2624 = 0, $2625 = 0, $2626 = 0, $2627 = 0, $2628 = 0, $2629 = 0, $263 = 0, $2630 = 0, $2631 = 0, $2632 = 0, $2633 = 0, $2634 = 0, $2635 = 0;
 var $2636 = 0, $2637 = 0, $2638 = 0, $2639 = 0, $264 = 0, $2640 = 0, $2641 = 0, $2642 = 0, $2643 = 0, $2644 = 0, $2645 = 0, $2646 = 0, $2647 = 0, $2648 = 0, $2649 = 0, $265 = 0, $2650 = 0, $2651 = 0, $2652 = 0, $2653 = 0;
 var $2654 = 0, $2655 = 0, $2656 = 0, $2657 = 0, $2658 = 0, $2659 = 0, $266 = 0, $2660 = 0, $2661 = 0, $2662 = 0, $2663 = 0, $2664 = 0, $2665 = 0, $2666 = 0, $2667 = 0, $2668 = 0, $2669 = 0, $267 = 0, $2670 = 0, $2671 = 0;
 var $2672 = 0, $2673 = 0, $2674 = 0, $2675 = 0, $2676 = 0, $2677 = 0, $2678 = 0, $2679 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0;
 var $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0;
 var $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0;
 var $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0;
 var $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0;
 var $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0;
 var $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0;
 var $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0;
 var $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0;
 var $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0;
 var $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0;
 var $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0;
 var $A$0$$i = 0, $A$0$$i216 = 0, $A$0$$i71 = 0, $A$0$i = 0, $A$0$i215 = 0, $A$0$i68 = 0, $A$2$i = 0, $B$1$i = 0, $C$0$i = 0, $D$0$i = 0, $I$01$i = 0, $I$01$i201 = 0, $K$0$$i = 0, $K$0$i = 0, $K$01$i = 0, $K$01$i156304 = 0, $K$01$i162 = 0, $K$01$i62 = 0, $K$1$$i = 0, $K$1$i = 0;
 var $K$2$i = 0, $R$0$i = 0, $V$i = 0, $V$idx$val$i = 0, $V$idx2$val$i = 0, $aOpc$op$i = 0, $aOpc$op$i69 = 0, $aRange$off$i = 0, $aRange$off$i$i = 0, $aRange$off$i$i90 = 0, $aRange$off$i$i95 = 0, $aRange$off$i188 = 0, $aRange$off$i207 = 0, $aRange$off$i235 = 0, $aRange$off$i56 = 0, $aRange$off$i80 = 0, $brmerge$i = 0, $brmerge6$i = 0, $contour$0$i = 0, $cur_range$0$ph$i = 0;
 var $cur_touched$0$ph$i = 0, $cvt_dist$0$i = 0, $cvt_dist$1$i = 0, $cvt_dist$2$i = 0, $cvt_dist$3$i = 0, $def$0$lcssa$i = 0, $def$0$lcssa$i221 = 0, $def$0$lcssa$i87 = 0, $def$01$i = 0, $def$01$i220 = 0, $def$01$i85 = 0, $def$02$i = 0, $def$02$i185 = 0, $def$02$i204 = 0, $def$02$i232 = 0, $def$02$i77 = 0, $def$0324 = 0, $def$1$i = 0, $def$1$i89 = 0, $distance$0$i = 0;
 var $distance$0$i250 = 0, $distance$0$i97 = 0, $distance$1$i = 0, $distance$1$i154 = 0, $distance$1$i254 = 0, $dx$i = 0, $dx$i105 = 0, $dx$i119 = 0, $dy$i = 0, $dy$i106 = 0, $dy$i120 = 0, $exitcond$i$i = 0, $first_point$0$i = 0, $i$01$i = 0, $i$01$i122 = 0, $i$01$i122$us = 0, $i$01$us$i = 0, $i$0286 = 0, $i$04$i$i = 0, $i$1$i$i = 0;
 var $i$12$i$i = 0, $ins_counter$0 = 0, $ins_counter$1 = 0, $k$02$i292 = 0, $last_point$0$i = 0, $last_point$0$i121 = 0, $mask$0$i = 0, $mask$1$i = 0, $nIfs$0$i = 0, $nIfs$0$i173$ph$be = 0, $nIfs$0$i173$ph328 = 0, $nIfs$1$i = 0, $new_dist$0$i = 0, $new_dist$0$us$i = 0, $not$or$cond$i = 0, $not$or$cond$i$demorgan = 0, $old_range$0$i = 0, $old_range$1$ph$i = 0, $or$cond$i = 0, $or$cond$i$i = 0;
 var $or$cond$i$i248 = 0, $or$cond$i112 = 0, $or$cond$i176 = 0, $or$cond$i214 = 0, $or$cond$i67 = 0, $or$cond259 = 0, $or$cond30 = 0, $org_dist$0$i = 0, $org_dist$1$i = 0, $orus_base$0$i = 0, $phitmp = 0, $phitmp$i = 0, $phitmp$i159 = 0, $phitmp$i166 = 0, $phitmp$i180 = 0, $point$0$i = 0, $point$14$i = 0, $point$2$i = 0, $point$2$in$i = 0, $point$3$i = 0;
 var $rec$0$lcssa$i = 0, $rec$01$i = 0, $refp$i = 0, $refp$i104 = 0, $refp$i118 = 0, $sext = 0, $sext$i = 0, $sext$i107 = 0, $sext$i163 = 0, $sext24 = 0, $sext26 = 0, $sext27 = 0, $storemerge479 = 0, $zp$i = 0, $zp$i103 = 0, $zp$i117 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $zp$i117 = sp + 112|0;
 $refp$i118 = sp + 148|0;
 $dx$i119 = sp + 108|0;
 $dy$i120 = sp + 104|0;
 $zp$i103 = sp + 68|0;
 $refp$i104 = sp + 152|0;
 $dx$i105 = sp + 64|0;
 $dy$i106 = sp + 44|0;
 $zp$i = sp + 8|0;
 $refp$i = sp + 150|0;
 $dx$i = sp + 4|0;
 $dy$i = sp;
 $V$i = sp + 48|0;
 $0 = (($exc) + 256|0);
 HEAP32[$0>>2] = 0;
 $1 = (($exc) + 216|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = (($exc) + 218|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = ($2<<16>>16)==($4<<16>>16);
 $6 = (($exc) + 592|0);
 if ($5) {
  HEAP32[$6>>2] = 2705;
  $9 = (($exc) + 596|0);
  HEAP32[$9>>2] = 2066;
  $10 = (($exc) + 600|0);
  HEAP32[$10>>2] = 2067;
 } else {
  HEAP32[$6>>2] = 2704;
  $7 = (($exc) + 596|0);
  HEAP32[$7>>2] = 2064;
  $8 = (($exc) + 600|0);
  HEAP32[$8>>2] = 2065;
 }
 _Compute_Funcs($exc);
 $11 = (($exc) + 312|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 255;
 switch ($13|0) {
 case 4:  {
  $16 = (($exc) + 568|0);
  HEAP32[$16>>2] = 1618;
  $$pre$phiZ2D = $16;
  break;
 }
 case 1:  {
  $15 = (($exc) + 568|0);
  HEAP32[$15>>2] = 1617;
  $$pre$phiZ2D = $15;
  break;
 }
 case 0:  {
  $18 = (($exc) + 568|0);
  HEAP32[$18>>2] = 1620;
  $$pre$phiZ2D = $18;
  break;
 }
 case 5:  {
  $14 = (($exc) + 568|0);
  HEAP32[$14>>2] = 1616;
  $$pre$phiZ2D = $14;
  break;
 }
 case 6:  {
  $20 = (($exc) + 568|0);
  HEAP32[$20>>2] = 1622;
  $$pre$phiZ2D = $20;
  break;
 }
 case 7:  {
  $21 = (($exc) + 568|0);
  HEAP32[$21>>2] = 1623;
  $$pre$phiZ2D = $21;
  break;
 }
 case 3:  {
  $17 = (($exc) + 568|0);
  HEAP32[$17>>2] = 1619;
  $$pre$phiZ2D = $17;
  break;
 }
 case 2:  {
  $19 = (($exc) + 568|0);
  HEAP32[$19>>2] = 1621;
  $$pre$phiZ2D = $19;
  break;
 }
 default: {
  $$pre477 = (($exc) + 568|0);
  $$pre$phiZ2D = $$pre477;
 }
 }
 $22 = (($exc) + 360|0);
 $23 = (($exc) + 356|0);
 $24 = (($exc) + 368|0);
 $25 = (($exc) + 372|0);
 $26 = (($exc) + 364|0);
 $27 = (($exc) + 16|0);
 $28 = (($exc) + 28|0);
 $29 = (($exc) + 561|0);
 $30 = (($exc) + 24|0);
 $31 = (($exc) + 32|0);
 $32 = (($exc) + 20|0);
 $33 = (($exc) + 376|0);
 $34 = (($exc) + 12|0);
 $35 = (($exc) + 72|0);
 $36 = (($exc) + 80|0);
 $37 = (($exc) + 380|0);
 $38 = (($exc) + 284|0);
 $39 = (($exc) + 44|0);
 $40 = (($exc) + 328|0);
 $41 = (($exc) + 324|0);
 $42 = (($exc) + 346|0);
 $43 = (($exc) + 48|0);
 $44 = (($exc) + 298|0);
 $45 = (($exc) + 84|0);
 $46 = (($exc) + 300|0);
 $47 = (($exc) + 88|0);
 $48 = (($exc) + 52|0);
 $49 = (($exc) + 576|0);
 $50 = (($exc) + 572|0);
 $51 = (($exc) + 316|0);
 $52 = (($exc) + 584|0);
 $53 = (($exc) + 308|0);
 $54 = (($exc) + 344|0);
 $55 = (($exc) + 320|0);
 $56 = (($exc) + 286|0);
 $57 = (($exc) + 288|0);
 $58 = (($exc) + 92|0);
 $59 = (($exc) + 56|0);
 $60 = (($exc) + 220|0);
 $61 = (($exc) + 224|0);
 $62 = (($exc) + 416|0);
 $63 = (($exc) + 408|0);
 $64 = (($exc) + 428|0);
 $65 = (($exc) + 432|0);
 $66 = (($exc) + 436|0);
 $67 = (($exc) + 352|0);
 $68 = (($exc) + 488|0);
 $69 = (($exc) + 294|0);
 $70 = (($exc) + 296|0);
 $71 = (($exc) + 290|0);
 $72 = (($exc) + 292|0);
 $73 = (($exc) + 294|0);
 $74 = (($exc) + 116|0);
 $75 = (($exc) + 124|0);
 $76 = (($exc) + 290|0);
 $77 = (($exc) + 298|0);
 $78 = (($exc) + 132|0);
 $79 = (($exc) + 36|0);
 $80 = (($exc) + 180|0);
 $81 = (($exc) + 144|0);
 $82 = (($exc) + 108|0);
 $83 = (($exc) + 348|0);
 $84 = (($exc) + 304|0);
 $85 = (($exc) + 60|0);
 $86 = (($exc) + 420|0);
 $87 = (($exc) + 404|0);
 $88 = (($exc) + 396|0);
 $89 = (($exc) + 400|0);
 $90 = (($exc) + 264|0);
 $91 = (($exc) + 154|0);
 $92 = (($exc) + 156|0);
 $93 = (($exc) + 160|0);
 $94 = (($V$i) + 4|0);
 $95 = (($exc) + 164|0);
 $96 = (($V$i) + 8|0);
 $97 = (($exc) + 152|0);
 $98 = (($V$i) + 12|0);
 $99 = (($exc) + 172|0);
 $100 = (($exc) + 176|0);
 $101 = (($exc) + 168|0);
 $102 = (($zp$i103) + 16|0);
 $103 = (($zp$i117) + 16|0);
 $104 = (($exc) + 118|0);
 $105 = (($exc) + 136|0);
 $106 = (($exc) + 120|0);
 $107 = (($exc) + 128|0);
 $108 = (($exc) + 588|0);
 $109 = (($exc) + 468|0);
 $110 = (($exc) + 472|0);
 $111 = (($exc) + 596|0);
 $112 = (($exc) + 332|0);
 $113 = (($exc) + 334|0);
 $114 = (($exc) + 260|0);
 $115 = (($exc) + 384|0);
 $116 = (($exc) + 600|0);
 $117 = (($exc) + 476|0);
 $118 = (($exc) + 484|0);
 $119 = (($exc) + 480|0);
 $120 = (($exc) + 282|0);
 $121 = (($exc) + 337|0);
 $122 = (($exc) + 281|0);
 $123 = (($exc) + 252|0);
 $124 = (($exc) + 604|0);
 $125 = (($exc) + 412|0);
 $126 = (($exc) + 424|0);
 $127 = (($exc) + 340|0);
 $128 = (($exc) + 336|0);
 $$pre = HEAP32[$22>>2]|0;
 $131 = $$pre;$ins_counter$0 = 0;
 L16: while(1) {
  $129 = HEAP32[$23>>2]|0;
  $130 = (($129) + ($131)|0);
  $132 = HEAP8[$130>>0]|0;
  HEAP8[$24>>0] = $132;
  $133 = $132&255;
  $134 = (873192 + ($133)|0);
  $135 = HEAP8[$134>>0]|0;
  $136 = $135 << 24 >> 24;
  HEAP32[$25>>2] = $136;
  $137 = $133 & 254;
  $138 = ($137|0)==(64);
  $139 = HEAP32[$26>>2]|0;
  if ($138) {
   $140 = ($131|0)<($139|0);
   if (!($140)) {
    label = 785;
    break;
   }
   $141 = (($131) + 1)|0;
   $142 = (($129) + ($141)|0);
   $143 = HEAP8[$142>>0]|0;
   $144 = $143&255;
   $145 = Math_imul($144, $136)|0;
   $146 = (2 - ($145))|0;
   HEAP32[$25>>2] = $146;
   $$pre$i169 = $146;
  } else {
   $$pre$i169 = $136;
  }
  $147 = (($$pre$i169) + ($131))|0;
  $148 = ($147|0)>($139|0);
  if ($148) {
   label = 785;
   break;
  }
  $149 = HEAP32[$27>>2]|0;
  $150 = (873448 + ($133)|0);
  $151 = HEAP8[$150>>0]|0;
  $152 = $151&255;
  $153 = $152 >>> 4;
  $154 = (($149) - ($153))|0;
  HEAP32[$28>>2] = $154;
  $155 = ($154|0)<(0);
  if ($155) {
   $156 = HEAP8[$29>>0]|0;
   $157 = ($156<<24>>24)==(0);
   if (!($157)) {
    label = 23;
    break;
   }
   $158 = ($151&255)>(15);
   if ($158) {
    $$pre414 = HEAP32[$30>>2]|0;
    $160 = 0;$i$0286 = 0;
    while(1) {
     $159 = (($$pre414) + ($160<<2)|0);
     HEAP32[$159>>2] = 0;
     $161 = (($i$0286) + 1)<<16>>16;
     $162 = $161&65535;
     $163 = HEAP8[$24>>0]|0;
     $164 = $163&255;
     $165 = (873448 + ($164)|0);
     $166 = HEAP8[$165>>0]|0;
     $167 = $166&255;
     $168 = $167 >>> 4;
     $169 = ($162>>>0)<($168>>>0);
     if ($169) {
      $160 = $162;$i$0286 = $161;
     } else {
      $$pre416 = $166;$2673 = $163;
      break;
     }
    }
   } else {
    $$pre416 = $151;$2673 = $132;
   }
   HEAP32[$28>>2] = 0;
   $171 = $2673;$173 = $$pre416;$176 = 0;
  } else {
   $171 = $132;$173 = $151;$176 = $154;
  }
  $170 = $171&255;
  $172 = $173&255;
  $174 = $172 & 15;
  $175 = (($174) + ($176))|0;
  HEAP32[$31>>2] = $175;
  $177 = HEAP32[$32>>2]|0;
  $178 = ($175>>>0)>($177>>>0);
  if ($178) {
   label = 27;
   break;
  }
  HEAP8[$33>>0] = 1;
  HEAP32[$34>>2] = 0;
  $179 = HEAP32[$30>>2]|0;
  $180 = (($179) + ($176<<2)|0);
  L33: do {
   switch ($170|0) {
   case 139:  {
    $$sum1 = (($176) + 1)|0;
    $2187 = (($179) + ($$sum1<<2)|0);
    $2188 = HEAP32[$2187>>2]|0;
    $2189 = HEAP32[$180>>2]|0;
    $2190 = ($2188|0)>($2189|0);
    if ($2190) {
     HEAP32[$180>>2] = $2188;
     label = 762;
    } else {
     label = 762;
    }
    break;
   }
   case 138:  {
    $$sum261 = (($176) + 2)|0;
    $2182 = (($179) + ($$sum261<<2)|0);
    $2183 = HEAP32[$2182>>2]|0;
    $$sum262 = (($176) + 1)|0;
    $2184 = (($179) + ($$sum262<<2)|0);
    $2185 = HEAP32[$2184>>2]|0;
    $2186 = HEAP32[$180>>2]|0;
    HEAP32[$2182>>2] = $2186;
    HEAP32[$2184>>2] = $2183;
    HEAP32[$180>>2] = $2185;
    label = 762;
    break;
   }
   case 141:  {
    $$val50 = HEAP32[$180>>2]|0;
    $2195 = ($$val50|0)>(-1);
    if ($2195) {
     HEAP32[$127>>2] = $$val50;
     label = 762;
    } else {
     label = 762;
    }
    break;
   }
   case 142:  {
    $$sum260 = (($176) + 1)|0;
    $$idx52 = (($179) + ($$sum260<<2)|0);
    $$idx52$val = HEAP32[$$idx52>>2]|0;
    $$off$i = (($$idx52$val) + -1)|0;
    $2196 = ($$off$i>>>0)>(1);
    if ($2196) {
     $2197 = HEAP8[$29>>0]|0;
     $2198 = ($2197<<24>>24)==(0);
     if ($2198) {
      label = 762;
      break L33;
     } else {
      label = 662;
      break L16;
     }
    } else {
     $$val51 = HEAP32[$180>>2]|0;
     $2199 = ($$val51|0)==(0);
     $$$i230 = $2199 ? 0 : $$idx52$val;
     $2200 = HEAP8[$128>>0]|0;
     $2201 = $2200&255;
     $2202 = $$idx52$val ^ 255;
     $2203 = $2201 & $2202;
     $2204 = $2203 | $$$i230;
     $2205 = $2204&255;
     HEAP8[$128>>0] = $2205;
     label = 762;
     break L33;
    }
    break;
   }
   case 143:  {
    $2206 = HEAP32[$62>>2]|0;
    $2207 = HEAP32[$63>>2]|0;
    $2208 = (($2206) + ($2207<<4)|0);
    $2209 = ($2207|0)>(0);
    L44: do {
     if ($2209) {
      $def$02$i232 = $2206;
      while(1) {
       $2210 = (($def$02$i232) + 8|0);
       $2211 = HEAP32[$2210>>2]|0;
       $2212 = $2211&255;
       $2213 = ($171<<24>>24)==($2212<<24>>24);
       if ($2213) {
        $2214 = (($def$02$i232) + 12|0);
        $2215 = HEAP8[$2214>>0]|0;
        $2216 = ($2215<<24>>24)==(0);
        if (!($2216)) {
         break;
        }
       }
       $2240 = (($def$02$i232) + 16|0);
       $2241 = ($2240>>>0)<($2208>>>0);
       if ($2241) {
        $def$02$i232 = $2240;
       } else {
        break L44;
       }
      }
      $2217 = HEAP32[$64>>2]|0;
      $2218 = HEAP32[$65>>2]|0;
      $2219 = ($2217|0)<($2218|0);
      if (!($2219)) {
       label = 668;
       break L16;
      }
      $2220 = HEAP32[$66>>2]|0;
      $2221 = (($2217) + 1)|0;
      HEAP32[$64>>2] = $2221;
      $2222 = HEAP32[$67>>2]|0;
      $2223 = (($2220) + ($2217<<4)|0);
      HEAP32[$2223>>2] = $2222;
      $2224 = HEAP32[$22>>2]|0;
      $2225 = (($2224) + 1)|0;
      $2226 = ((($2220) + ($2217<<4)|0) + 4|0);
      HEAP32[$2226>>2] = $2225;
      $2227 = ((($2220) + ($2217<<4)|0) + 8|0);
      HEAP32[$2227>>2] = 1;
      $2228 = (($def$02$i232) + 4|0);
      $2229 = HEAP32[$2228>>2]|0;
      $2230 = ((($2220) + ($2217<<4)|0) + 12|0);
      HEAP32[$2230>>2] = $2229;
      $2231 = HEAP32[$def$02$i232>>2]|0;
      $2232 = HEAP32[$2228>>2]|0;
      $aRange$off$i235 = (($2231) + -1)|0;
      $2233 = ($aRange$off$i235>>>0)>(2);
      do {
       if ($2233) {
        HEAP32[$34>>2] = 132;
       } else {
        $2234 = ((($exc) + ($aRange$off$i235<<3)|0) + 444|0);
        $2235 = HEAP32[$2234>>2]|0;
        $2236 = ($2235|0)==(0|0);
        if ($2236) {
         HEAP32[$34>>2] = 138;
         break;
        }
        $2237 = ((($exc) + ($aRange$off$i235<<3)|0) + 448|0);
        $2238 = HEAP32[$2237>>2]|0;
        $2239 = ($2238>>>0)<($2232>>>0);
        if ($2239) {
         HEAP32[$34>>2] = 131;
         break;
        } else {
         HEAP32[$23>>2] = $2235;
         HEAP32[$26>>2] = $2238;
         HEAP32[$22>>2] = $2232;
         HEAP32[$67>>2] = $2231;
         break;
        }
       }
      } while(0);
      HEAP8[$33>>0] = 0;
      label = 762;
      break L33;
     }
    } while(0);
    HEAP32[$34>>2] = 128;
    $2617 = $2206;$2618 = $2207;
    label = 764;
    break;
   }
   case 140:  {
    $$sum = (($176) + 1)|0;
    $2191 = (($179) + ($$sum<<2)|0);
    $2192 = HEAP32[$2191>>2]|0;
    $2193 = HEAP32[$180>>2]|0;
    $2194 = ($2192|0)<($2193|0);
    if ($2194) {
     HEAP32[$180>>2] = $2192;
     label = 762;
    } else {
     label = 762;
    }
    break;
   }
   case 127: case 126: case 89: case 33:  {
    label = 778;
    break;
   }
   case 5: case 4: case 3: case 2: case 1: case 0:  {
    $181 = $170 << 14;
    $182 = $181 & 16384;
    $183 = $182&65535;
    $184 = $182 ^ 16384;
    $185 = $184&65535;
    $186 = ($171&255)<(4);
    if ($186) {
     HEAP16[$69>>1] = $183;
     HEAP16[$70>>1] = $185;
     HEAP16[$71>>1] = $183;
     HEAP16[$72>>1] = $185;
    }
    $187 = $170 & 2;
    $188 = ($187|0)==(0);
    if ($188) {
     HEAP16[$44>>1] = $183;
     HEAP16[$46>>1] = $185;
    }
    _Compute_Funcs($exc);
    label = 762;
    break;
   }
   case 7: case 6:  {
    $$sum29 = (($176) + 1)|0;
    $189 = (($179) + ($$sum29<<2)|0);
    $190 = HEAP32[$189>>2]|0;
    $191 = $190&65535;
    $192 = HEAP32[$180>>2]|0;
    $193 = $190 & 65535;
    $194 = HEAP16[$74>>1]|0;
    $195 = ($194&65535)>($191&65535);
    if ($195) {
     $196 = $192&65535;
     $197 = HEAP16[$36>>1]|0;
     $198 = ($197&65535)>($196&65535);
     if ($198) {
      $201 = $192 & 65535;
      $202 = HEAP32[$47>>2]|0;
      $203 = HEAP32[$75>>2]|0;
      $204 = (($202) + ($201<<3)|0);
      $205 = HEAP32[$204>>2]|0;
      $206 = (($203) + ($193<<3)|0);
      $207 = HEAP32[$206>>2]|0;
      $208 = (($205) - ($207))|0;
      $209 = ((($202) + ($201<<3)|0) + 4|0);
      $210 = HEAP32[$209>>2]|0;
      $211 = ((($203) + ($193<<3)|0) + 4|0);
      $212 = HEAP32[$211>>2]|0;
      $213 = (($210) - ($212))|0;
      $214 = ($205|0)==($207|0);
      $215 = ($210|0)==($212|0);
      $or$cond$i = $214 & $215;
      $A$0$i = $or$cond$i ? 16384 : $208;
      $aOpc$op$i = $171 & 1;
      $216 = ($aOpc$op$i<<24>>24)==(0);
      $217 = $or$cond$i | $216;
      $218 = (0 - ($213))|0;
      $$A$0$i = $217 ? $213 : $A$0$i;
      $A$0$$i = $217 ? $A$0$i : $218;
      _Normalize($A$0$$i,$$A$0$i,$73);
      $219 = HEAPU16[$73>>1]|(HEAPU16[$73+2>>1]<<16);
      HEAP16[$76>>1]=$219&65535;HEAP16[$76+2>>1]=$219>>>16;
      _Compute_Funcs($exc);
      label = 762;
      break L33;
     }
    }
    $199 = HEAP8[$29>>0]|0;
    $200 = ($199<<24>>24)==(0);
    if ($200) {
     label = 762;
    } else {
     label = 37;
     break L16;
    }
    break;
   }
   case 9: case 8:  {
    $$sum28 = (($176) + 1)|0;
    $220 = (($179) + ($$sum28<<2)|0);
    $221 = HEAP32[$220>>2]|0;
    $222 = $221&65535;
    $223 = HEAP32[$180>>2]|0;
    $224 = $221 & 65535;
    $225 = HEAP16[$74>>1]|0;
    $226 = ($225&65535)>($222&65535);
    if ($226) {
     $227 = $223&65535;
     $228 = HEAP16[$36>>1]|0;
     $229 = ($228&65535)>($227&65535);
     if ($229) {
      $232 = $223 & 65535;
      $233 = HEAP32[$47>>2]|0;
      $234 = HEAP32[$75>>2]|0;
      $235 = (($233) + ($232<<3)|0);
      $236 = HEAP32[$235>>2]|0;
      $237 = (($234) + ($224<<3)|0);
      $238 = HEAP32[$237>>2]|0;
      $239 = (($236) - ($238))|0;
      $240 = ((($233) + ($232<<3)|0) + 4|0);
      $241 = HEAP32[$240>>2]|0;
      $242 = ((($234) + ($224<<3)|0) + 4|0);
      $243 = HEAP32[$242>>2]|0;
      $244 = (($241) - ($243))|0;
      $245 = ($236|0)==($238|0);
      $246 = ($241|0)==($243|0);
      $or$cond$i67 = $245 & $246;
      $A$0$i68 = $or$cond$i67 ? 16384 : $239;
      $aOpc$op$i69 = $171 & 1;
      $247 = ($aOpc$op$i69<<24>>24)==(0);
      $248 = $or$cond$i67 | $247;
      $249 = (0 - ($244))|0;
      $$A$0$i70 = $248 ? $244 : $A$0$i68;
      $A$0$$i71 = $248 ? $A$0$i68 : $249;
      _Normalize($A$0$$i71,$$A$0$i70,$77);
      _Compute_Funcs($exc);
      label = 762;
      break L33;
     }
    }
    $230 = HEAP8[$29>>0]|0;
    $231 = ($230<<24>>24)==(0);
    if ($231) {
     label = 762;
    } else {
     label = 42;
     break L16;
    }
    break;
   }
   case 10:  {
    $$sum25 = (($176) + 1)|0;
    $250 = (($179) + ($$sum25<<2)|0);
    $251 = HEAP32[$250>>2]|0;
    $sext26 = $251 << 16;
    $252 = $sext26 >> 16;
    $253 = HEAP32[$180>>2]|0;
    $sext27 = $253 << 16;
    $254 = $sext27 >> 16;
    _Normalize($254,$252,$73);
    $255 = HEAPU16[$73>>1]|(HEAPU16[$73+2>>1]<<16);
    HEAP16[$76>>1]=$255&65535;HEAP16[$76+2>>1]=$255>>>16;
    _Compute_Funcs($exc);
    label = 762;
    break;
   }
   case 11:  {
    $$sum23 = (($176) + 1)|0;
    $256 = (($179) + ($$sum23<<2)|0);
    $257 = HEAP32[$256>>2]|0;
    $sext = $257 << 16;
    $258 = $sext >> 16;
    $259 = HEAP32[$180>>2]|0;
    $sext24 = $259 << 16;
    $260 = $sext24 >> 16;
    _Normalize($260,$258,$77);
    _Compute_Funcs($exc);
    label = 762;
    break;
   }
   case 12:  {
    $261 = HEAP16[$69>>1]|0;
    $262 = $261 << 16 >> 16;
    HEAP32[$180>>2] = $262;
    $263 = HEAP16[$70>>1]|0;
    $264 = $263 << 16 >> 16;
    $$sum22 = (($176) + 1)|0;
    $265 = (($179) + ($$sum22<<2)|0);
    HEAP32[$265>>2] = $264;
    label = 762;
    break;
   }
   case 13:  {
    $266 = HEAP16[$44>>1]|0;
    $267 = $266 << 16 >> 16;
    HEAP32[$180>>2] = $267;
    $268 = HEAP16[$46>>1]|0;
    $269 = $268 << 16 >> 16;
    $$sum21 = (($176) + 1)|0;
    $270 = (($179) + ($$sum21<<2)|0);
    HEAP32[$270>>2] = $269;
    label = 762;
    break;
   }
   case 14:  {
    $271 = HEAPU16[$73>>1]|(HEAPU16[$73+2>>1]<<16);
    HEAP16[$77>>1]=$271&65535;HEAP16[$77+2>>1]=$271>>>16;
    _Compute_Funcs($exc);
    label = 762;
    break;
   }
   case 15:  {
    $272 = HEAP32[$180>>2]|0;
    $$sum275 = (($176) + 1)|0;
    $273 = (($179) + ($$sum275<<2)|0);
    $274 = HEAP32[$273>>2]|0;
    $$sum276 = (($176) + 2)|0;
    $275 = (($179) + ($$sum276<<2)|0);
    $276 = HEAP32[$275>>2]|0;
    $$sum277 = (($176) + 3)|0;
    $277 = (($179) + ($$sum277<<2)|0);
    $278 = HEAP32[$277>>2]|0;
    $279 = $278 & 65535;
    $280 = HEAP16[$39>>1]|0;
    $281 = $280&65535;
    $282 = ($279>>>0)<($281>>>0);
    if ($282) {
     $$sum278 = (($176) + 4)|0;
     $283 = (($179) + ($$sum278<<2)|0);
     $284 = HEAP32[$283>>2]|0;
     $285 = $284 & 65535;
     $286 = ($285>>>0)<($281>>>0);
     if ($286) {
      $287 = $274 & 65535;
      $288 = HEAP16[$36>>1]|0;
      $289 = $288&65535;
      $290 = ($287>>>0)<($289>>>0);
      if ($290) {
       $291 = $276 & 65535;
       $292 = ($291>>>0)<($289>>>0);
       if ($292) {
        $293 = $272 & 65535;
        $294 = HEAP16[$74>>1]|0;
        $295 = $294&65535;
        $296 = ($293>>>0)<($295>>>0);
        if ($296) {
         $299 = HEAP32[$48>>2]|0;
         $300 = (($299) + ($285<<3)|0);
         $301 = HEAP32[$300>>2]|0;
         $302 = (($299) + ($279<<3)|0);
         $303 = HEAP32[$302>>2]|0;
         $304 = (($301) - ($303))|0;
         $305 = ((($299) + ($285<<3)|0) + 4|0);
         $306 = HEAP32[$305>>2]|0;
         $307 = ((($299) + ($279<<3)|0) + 4|0);
         $308 = HEAP32[$307>>2]|0;
         $309 = HEAP32[$47>>2]|0;
         $310 = (($309) + ($291<<3)|0);
         $311 = HEAP32[$310>>2]|0;
         $312 = (($309) + ($287<<3)|0);
         $313 = HEAP32[$312>>2]|0;
         $314 = (($311) - ($313))|0;
         $315 = ((($309) + ($291<<3)|0) + 4|0);
         $316 = HEAP32[$315>>2]|0;
         $317 = ((($309) + ($287<<3)|0) + 4|0);
         $318 = HEAP32[$317>>2]|0;
         $319 = (($316) - ($318))|0;
         $320 = HEAP32[$78>>2]|0;
         $321 = (($320) + ($293)|0);
         $322 = HEAP8[$321>>0]|0;
         $323 = $322&255;
         $324 = $323 | 24;
         $325 = $324&255;
         HEAP8[$321>>0] = $325;
         $326 = (($308) - ($306))|0;
         $327 = (_FT_MulDiv($314,$326,64)|0);
         $328 = (_FT_MulDiv($319,$304,64)|0);
         $329 = (($328) + ($327))|0;
         $330 = ($329|0)<(0);
         $331 = (0 - ($329))|0;
         $332 = $330 ? $331 : $329;
         $333 = ($332|0)>(63);
         if ($333) {
          $334 = (($308) - ($318))|0;
          $335 = (($303) - ($313))|0;
          $336 = (_FT_MulDiv($335,$326,64)|0);
          $337 = (_FT_MulDiv($334,$304,64)|0);
          $338 = (($337) + ($336))|0;
          $339 = (_FT_MulDiv($338,$314,$329)|0);
          $340 = (_FT_MulDiv($338,$319,$329)|0);
          $341 = HEAP32[$47>>2]|0;
          $342 = (($341) + ($287<<3)|0);
          $343 = HEAP32[$342>>2]|0;
          $344 = (($343) + ($339))|0;
          $345 = HEAP32[$75>>2]|0;
          $346 = (($345) + ($293<<3)|0);
          HEAP32[$346>>2] = $344;
          $347 = ((($341) + ($287<<3)|0) + 4|0);
          $348 = HEAP32[$347>>2]|0;
          $349 = (($348) + ($340))|0;
          $350 = ((($345) + ($293<<3)|0) + 4|0);
          HEAP32[$350>>2] = $349;
          label = 762;
          break L33;
         } else {
          $351 = HEAP32[$47>>2]|0;
          $352 = (($351) + ($287<<3)|0);
          $353 = HEAP32[$352>>2]|0;
          $354 = (($351) + ($291<<3)|0);
          $355 = HEAP32[$354>>2]|0;
          $356 = (($355) + ($353))|0;
          $357 = HEAP32[$48>>2]|0;
          $358 = (($357) + ($279<<3)|0);
          $359 = HEAP32[$358>>2]|0;
          $360 = (($356) + ($359))|0;
          $361 = (($357) + ($285<<3)|0);
          $362 = HEAP32[$361>>2]|0;
          $363 = (($360) + ($362))|0;
          $364 = (($363|0) / 4)&-1;
          $365 = HEAP32[$75>>2]|0;
          $366 = (($365) + ($293<<3)|0);
          HEAP32[$366>>2] = $364;
          $367 = ((($351) + ($287<<3)|0) + 4|0);
          $368 = HEAP32[$367>>2]|0;
          $369 = ((($351) + ($291<<3)|0) + 4|0);
          $370 = HEAP32[$369>>2]|0;
          $371 = (($370) + ($368))|0;
          $372 = ((($357) + ($279<<3)|0) + 4|0);
          $373 = HEAP32[$372>>2]|0;
          $374 = (($371) + ($373))|0;
          $375 = ((($357) + ($285<<3)|0) + 4|0);
          $376 = HEAP32[$375>>2]|0;
          $377 = (($374) + ($376))|0;
          $378 = (($377|0) / 4)&-1;
          $379 = ((($365) + ($293<<3)|0) + 4|0);
          HEAP32[$379>>2] = $378;
          label = 762;
          break L33;
         }
        }
       }
      }
     }
    }
    $297 = HEAP8[$29>>0]|0;
    $298 = ($297<<24>>24)==(0);
    if ($298) {
     label = 762;
    } else {
     label = 55;
     break L16;
    }
    break;
   }
   case 18:  {
    $384 = HEAP32[$180>>2]|0;
    $385 = $384&65535;
    HEAP16[$57>>1] = $385;
    label = 762;
    break;
   }
   case 20:  {
    $391 = HEAP32[$180>>2]|0;
    if ((($391|0) == 0)) {
     dest=$35+0|0; src=$80+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    } else if ((($391|0) == 1)) {
     dest=$35+0|0; src=$81+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    } else {
     $392 = HEAP8[$29>>0]|0;
     $393 = ($392<<24>>24)==(0);
     if ($393) {
      label = 762;
      break L33;
     } else {
      label = 72;
      break L16;
     }
    }
    $394 = HEAP32[$180>>2]|0;
    $395 = $394&65535;
    HEAP16[$42>>1] = $395;
    label = 762;
    break;
   }
   case 17:  {
    $382 = HEAP32[$180>>2]|0;
    $383 = $382&65535;
    HEAP16[$56>>1] = $383;
    label = 762;
    break;
   }
   case 19:  {
    $386 = HEAP32[$180>>2]|0;
    if ((($386|0) == 0)) {
     dest=$79+0|0; src=$80+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    } else if ((($386|0) == 1)) {
     dest=$79+0|0; src=$81+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    } else {
     $387 = HEAP8[$29>>0]|0;
     $388 = ($387<<24>>24)==(0);
     if ($388) {
      label = 762;
      break L33;
     } else {
      label = 66;
      break L16;
     }
    }
    $389 = HEAP32[$180>>2]|0;
    $390 = $389&65535;
    HEAP16[$54>>1] = $390;
    label = 762;
    break;
   }
   case 16:  {
    $380 = HEAP32[$180>>2]|0;
    $381 = $380&65535;
    HEAP16[$38>>1] = $381;
    label = 762;
    break;
   }
   case 22:  {
    $401 = HEAP32[$180>>2]|0;
    if ((($401|0) == 0)) {
     dest=$79+0|0; src=$80+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    } else if ((($401|0) == 1)) {
     dest=$79+0|0; src=$81+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    } else {
     $402 = HEAP8[$29>>0]|0;
     $403 = ($402<<24>>24)==(0);
     if ($403) {
      label = 762;
      break L33;
     } else {
      label = 84;
      break L16;
     }
    }
    dest=$35+0|0; src=$79+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    dest=$82+0|0; src=$79+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $404 = HEAP32[$180>>2]|0;
    $405 = $404&65535;
    HEAP16[$54>>1] = $405;
    HEAP16[$42>>1] = $405;
    HEAP16[$83>>1] = $405;
    label = 762;
    break;
   }
   case 21:  {
    $396 = HEAP32[$180>>2]|0;
    if ((($396|0) == 0)) {
     dest=$82+0|0; src=$80+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    } else if ((($396|0) == 1)) {
     dest=$82+0|0; src=$81+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    } else {
     $397 = HEAP8[$29>>0]|0;
     $398 = ($397<<24>>24)==(0);
     if ($398) {
      label = 762;
      break L33;
     } else {
      label = 78;
      break L16;
     }
    }
    $399 = HEAP32[$180>>2]|0;
    $400 = $399&65535;
    HEAP16[$83>>1] = $400;
    label = 762;
    break;
   }
   case 23:  {
    $406 = HEAP32[$180>>2]|0;
    $407 = ($406|0)<(0);
    if ($407) {
     label = 87;
     break L16;
    }
    HEAP32[$84>>2] = $406;
    label = 762;
    break;
   }
   case 29:  {
    $439 = HEAP32[$180>>2]|0;
    HEAP32[$55>>2] = $439;
    label = 762;
    break;
   }
   case 31:  {
    $441 = HEAP32[$180>>2]|0;
    $442 = $441 >> 10;
    HEAP32[$40>>2] = $442;
    label = 762;
    break;
   }
   case 30:  {
    $440 = HEAP32[$180>>2]|0;
    HEAP32[$41>>2] = $440;
    label = 762;
    break;
   }
   case 25:  {
    HEAP32[$11>>2] = 0;
    HEAP32[$$pre$phiZ2D>>2] = 1620;
    label = 762;
    break;
   }
   case 27:  {
    $$pre2$i = HEAP32[$22>>2]|0;
    $$pre3$i75 = HEAP32[$26>>2]|0;
    $410 = $$pre$i169;$411 = $$pre2$i;$nIfs$0$i = 1;
    while(1) {
     $409 = (($410) + ($411))|0;
     HEAP32[$22>>2] = $409;
     $412 = ($409|0)<($$pre3$i75|0);
     if (!($412)) {
      label = 97;
      break L16;
     }
     $413 = (($129) + ($409)|0);
     $414 = HEAP8[$413>>0]|0;
     HEAP8[$24>>0] = $414;
     $415 = $414&255;
     $416 = (873192 + ($415)|0);
     $417 = HEAP8[$416>>0]|0;
     $418 = $417 << 24 >> 24;
     HEAP32[$25>>2] = $418;
     $419 = $415 & 254;
     $420 = ($419|0)==(64);
     if ($420) {
      $421 = (($409) + 1)|0;
      $422 = (($129) + ($421)|0);
      $423 = HEAP8[$422>>0]|0;
      $424 = $423&255;
      $425 = Math_imul($424, $418)|0;
      $426 = (2 - ($425))|0;
      HEAP32[$25>>2] = $426;
      $428 = $426;
     } else {
      $428 = $418;
     }
     $427 = (($428) + ($409))|0;
     $429 = ($427|0)>($$pre3$i75|0);
     if ($429) {
      label = 97;
      break L16;
     }
     if ((($415|0) == 88)) {
      $430 = (($nIfs$0$i) + 1)|0;
      $nIfs$1$i = $430;
     } else if ((($415|0) == 89)) {
      $431 = (($nIfs$0$i) + -1)|0;
      $nIfs$1$i = $431;
     } else {
      $nIfs$1$i = $nIfs$0$i;
     }
     $432 = ($nIfs$1$i|0)==(0);
     if ($432) {
      label = 762;
      break;
     } else {
      $410 = $428;$411 = $409;$nIfs$0$i = $nIfs$1$i;
     }
    }
    break;
   }
   case 28:  {
    $433 = HEAP32[$180>>2]|0;
    $434 = $433 | $176;
    $435 = ($434|0)==(0);
    if ($435) {
     HEAP32[$34>>2] = 132;
    }
    $436 = HEAP32[$22>>2]|0;
    $437 = (($436) + ($433))|0;
    HEAP32[$22>>2] = $437;
    $438 = ($437|0)<(0);
    if ($438) {
     HEAP32[$34>>2] = 132;
    }
    HEAP8[$33>>0] = 0;
    label = 762;
    break;
   }
   case 26:  {
    $408 = HEAP32[$180>>2]|0;
    HEAP32[$53>>2] = $408;
    label = 762;
    break;
   }
   case 24:  {
    HEAP32[$11>>2] = 1;
    HEAP32[$$pre$phiZ2D>>2] = 1617;
    label = 762;
    break;
   }
   case 36:  {
    $448 = HEAP32[$27>>2]|0;
    HEAP32[$180>>2] = $448;
    label = 762;
    break;
   }
   case 35:  {
    $445 = HEAP32[$180>>2]|0;
    $$sum19 = (($176) + 1)|0;
    $446 = (($179) + ($$sum19<<2)|0);
    $447 = HEAP32[$446>>2]|0;
    HEAP32[$180>>2] = $447;
    HEAP32[$446>>2] = $445;
    label = 762;
    break;
   }
   case 38:  {
    $$val = HEAP32[$180>>2]|0;
    $457 = ($$val|0)<(1);
    $458 = ($176|0)<($$val|0);
    $or$cond259 = $457 | $458;
    if ($or$cond259) {
     $459 = HEAP8[$29>>0]|0;
     $460 = ($459<<24>>24)==(0);
     if ($460) {
      label = 762;
      break L33;
     } else {
      label = 121;
      break L16;
     }
    } else {
     $461 = (($176) - ($$val))|0;
     $462 = (($179) + ($461<<2)|0);
     $463 = HEAP32[$462>>2]|0;
     $464 = (($461) + 1)|0;
     $465 = (($179) + ($464<<2)|0);
     $466 = $$val << 2;
     $467 = (($466) + -4)|0;
     _memmove(($462|0),($465|0),($467|0))|0;
     $468 = HEAP32[$28>>2]|0;
     $469 = (($468) + -1)|0;
     $470 = HEAP32[$30>>2]|0;
     $471 = (($470) + ($469<<2)|0);
     HEAP32[$471>>2] = $463;
     label = 762;
     break L33;
    }
    break;
   }
   case 37:  {
    $449 = HEAP32[$180>>2]|0;
    $450 = ($449|0)<(1);
    $451 = ($449|0)>($176|0);
    $or$cond30 = $450 | $451;
    if (!($or$cond30)) {
     $454 = (($176) - ($449))|0;
     $455 = (($179) + ($454<<2)|0);
     $456 = HEAP32[$455>>2]|0;
     HEAP32[$180>>2] = $456;
     label = 762;
     break L33;
    }
    $452 = HEAP8[$29>>0]|0;
    $453 = ($452<<24>>24)==(0);
    if (!($453)) {
     HEAP32[$34>>2] = 134;
    }
    HEAP32[$180>>2] = 0;
    label = 762;
    break;
   }
   case 34:  {
    HEAP32[$31>>2] = 0;
    label = 762;
    break;
   }
   case 39:  {
    $$val33 = HEAP32[$180>>2]|0;
    $$sum274 = (($176) + 1)|0;
    $$idx = (($179) + ($$sum274<<2)|0);
    $$idx$val = HEAP32[$$idx>>2]|0;
    $472 = $$val33&65535;
    $473 = $$idx$val&65535;
    $474 = $$val33 & 65535;
    $475 = HEAP16[$36>>1]|0;
    $476 = $475&65535;
    $477 = ($474>>>0)<($476>>>0);
    if ($477) {
     $478 = $$idx$val & 65535;
     $479 = HEAP16[$39>>1]|0;
     $480 = $479&65535;
     $481 = ($478>>>0)<($480>>>0);
     if ($481) {
      $484 = HEAP32[$50>>2]|0;
      $485 = HEAP32[$48>>2]|0;
      $486 = (($485) + ($478<<3)|0);
      $487 = HEAP32[$486>>2]|0;
      $488 = HEAP32[$47>>2]|0;
      $489 = (($488) + ($474<<3)|0);
      $490 = HEAP32[$489>>2]|0;
      $491 = (($487) - ($490))|0;
      $492 = ((($485) + ($478<<3)|0) + 4|0);
      $493 = HEAP32[$492>>2]|0;
      $494 = ((($488) + ($474<<3)|0) + 4|0);
      $495 = HEAP32[$494>>2]|0;
      $496 = (($493) - ($495))|0;
      $497 = (FUNCTION_TABLE_iiii[$484 & 2047]($exc,$491,$496)|0);
      $498 = (($497|0) / 2)&-1;
      $499 = HEAP32[$52>>2]|0;
      FUNCTION_TABLE_viiii[$499 & 511]($exc,$35,$472,$498);
      $500 = HEAP32[$52>>2]|0;
      $501 = (0 - ($498))|0;
      FUNCTION_TABLE_viiii[$500 & 511]($exc,$79,$473,$501);
      label = 762;
      break L33;
     }
    }
    $482 = HEAP8[$29>>0]|0;
    $483 = ($482<<24>>24)==(0);
    if ($483) {
     label = 762;
    } else {
     label = 126;
     break L16;
    }
    break;
   }
   case 32:  {
    $443 = HEAP32[$180>>2]|0;
    $$sum20 = (($176) + 1)|0;
    $444 = (($179) + ($$sum20<<2)|0);
    HEAP32[$444>>2] = $443;
    label = 762;
    break;
   }
   case 40:  {
    $502 = HEAP32[$62>>2]|0;
    $503 = HEAP32[$63>>2]|0;
    $504 = (($502) + ($503<<4)|0);
    $505 = ($503|0)>(0);
    L288: do {
     if ($505) {
      $def$02$i77 = $502;
      while(1) {
       $506 = (($def$02$i77) + 8|0);
       $507 = HEAP32[$506>>2]|0;
       $508 = $507&255;
       $509 = ($171<<24>>24)==($508<<24>>24);
       if ($509) {
        $510 = (($def$02$i77) + 12|0);
        $511 = HEAP8[$510>>0]|0;
        $512 = ($511<<24>>24)==(0);
        if (!($512)) {
         break;
        }
       }
       $536 = (($def$02$i77) + 16|0);
       $537 = ($536>>>0)<($504>>>0);
       if ($537) {
        $def$02$i77 = $536;
       } else {
        break L288;
       }
      }
      $513 = HEAP32[$64>>2]|0;
      $514 = HEAP32[$65>>2]|0;
      $515 = ($513|0)<($514|0);
      if (!($515)) {
       label = 132;
       break L16;
      }
      $516 = HEAP32[$66>>2]|0;
      $517 = (($513) + 1)|0;
      HEAP32[$64>>2] = $517;
      $518 = HEAP32[$67>>2]|0;
      $519 = (($516) + ($513<<4)|0);
      HEAP32[$519>>2] = $518;
      $520 = HEAP32[$22>>2]|0;
      $521 = (($520) + 1)|0;
      $522 = ((($516) + ($513<<4)|0) + 4|0);
      HEAP32[$522>>2] = $521;
      $523 = ((($516) + ($513<<4)|0) + 8|0);
      HEAP32[$523>>2] = 1;
      $524 = (($def$02$i77) + 4|0);
      $525 = HEAP32[$524>>2]|0;
      $526 = ((($516) + ($513<<4)|0) + 12|0);
      HEAP32[$526>>2] = $525;
      $527 = HEAP32[$def$02$i77>>2]|0;
      $528 = HEAP32[$524>>2]|0;
      $aRange$off$i80 = (($527) + -1)|0;
      $529 = ($aRange$off$i80>>>0)>(2);
      do {
       if ($529) {
        HEAP32[$34>>2] = 132;
       } else {
        $530 = ((($exc) + ($aRange$off$i80<<3)|0) + 444|0);
        $531 = HEAP32[$530>>2]|0;
        $532 = ($531|0)==(0|0);
        if ($532) {
         HEAP32[$34>>2] = 138;
         break;
        }
        $533 = ((($exc) + ($aRange$off$i80<<3)|0) + 448|0);
        $534 = HEAP32[$533>>2]|0;
        $535 = ($534>>>0)<($528>>>0);
        if ($535) {
         HEAP32[$34>>2] = 131;
         break;
        } else {
         HEAP32[$23>>2] = $531;
         HEAP32[$26>>2] = $534;
         HEAP32[$22>>2] = $528;
         HEAP32[$67>>2] = $527;
         break;
        }
       }
      } while(0);
      HEAP8[$33>>0] = 0;
      label = 762;
      break L33;
     }
    } while(0);
    HEAP32[$34>>2] = 128;
    $2617 = $502;$2618 = $503;
    label = 764;
    break;
   }
   case 41:  {
    $$val34 = HEAP32[$180>>2]|0;
    $538 = $$val34 & 65535;
    $539 = HEAP16[$39>>1]|0;
    $540 = $539&65535;
    $541 = ($538>>>0)<($540>>>0);
    if (!($541)) {
     $542 = HEAP8[$29>>0]|0;
     $543 = ($542<<24>>24)==(0);
     if ($543) {
      label = 762;
      break L33;
     } else {
      label = 145;
      break L16;
     }
    }
    $544 = HEAP16[$44>>1]|0;
    $545 = ($544<<16>>16)==(0);
    $$$i83 = $545 ? -1 : -9;
    $546 = HEAP16[$46>>1]|0;
    $547 = ($546<<16>>16)==(0);
    if ($547) {
     $mask$1$i = $$$i83;
    } else {
     $548 = $$$i83&255;
     $549 = $548 & 239;
     $550 = $549&255;
     $mask$1$i = $550;
    }
    $551 = HEAP32[$85>>2]|0;
    $552 = (($551) + ($538)|0);
    $553 = HEAP8[$552>>0]|0;
    $554 = $553 & $mask$1$i;
    HEAP8[$552>>0] = $554;
    label = 762;
    break;
   }
   case 42:  {
    $$sum273 = (($176) + 1)|0;
    $555 = (($179) + ($$sum273<<2)|0);
    $556 = HEAP32[$555>>2]|0;
    $557 = HEAP32[$86>>2]|0;
    $558 = (($557) + 1)|0;
    $559 = ($556>>>0)<($558>>>0);
    if (!($559)) {
     label = 168;
     break L16;
    }
    $560 = HEAP32[$87>>2]|0;
    $561 = HEAP32[$88>>2]|0;
    $562 = ($558|0)==($561|0);
    if ($562) {
     $563 = (($560) + ($556<<4)|0);
     $564 = ((($560) + ($556<<4)|0) + 8|0);
     $565 = HEAP32[$564>>2]|0;
     $566 = ($565|0)==($556|0);
     if ($566) {
      $def$1$i = $563;
     } else {
      label = 152;
     }
    } else {
     label = 152;
    }
    if ((label|0) == 152) {
     label = 0;
     $567 = (($560) + ($561<<4)|0);
     $568 = ($561|0)>(0);
     L320: do {
      if ($568) {
       $def$01$i = $560;
       while(1) {
        $571 = (($def$01$i) + 8|0);
        $572 = HEAP32[$571>>2]|0;
        $573 = ($572|0)==($556|0);
        $570 = (($def$01$i) + 16|0);
        if ($573) {
         $def$0$lcssa$i = $def$01$i;
         break L320;
        }
        $569 = ($570>>>0)<($567>>>0);
        if ($569) {
         $def$01$i = $570;
        } else {
         $def$0$lcssa$i = $570;
         break;
        }
       }
      } else {
       $def$0$lcssa$i = $560;
      }
     } while(0);
     $574 = ($def$0$lcssa$i|0)==($567|0);
     if ($574) {
      label = 168;
      break L16;
     } else {
      $def$1$i = $def$0$lcssa$i;
     }
    }
    $575 = (($def$1$i) + 12|0);
    $576 = HEAP8[$575>>0]|0;
    $577 = ($576<<24>>24)==(0);
    if ($577) {
     label = 168;
     break L16;
    }
    $578 = HEAP32[$64>>2]|0;
    $579 = HEAP32[$65>>2]|0;
    $580 = ($578|0)<($579|0);
    if (!($580)) {
     label = 158;
     break L16;
    }
    $581 = HEAP32[$180>>2]|0;
    $582 = ($581|0)>(0);
    if ($582) {
     $583 = HEAP32[$66>>2]|0;
     $584 = HEAP32[$67>>2]|0;
     $585 = (($583) + ($578<<4)|0);
     HEAP32[$585>>2] = $584;
     $586 = HEAP32[$22>>2]|0;
     $587 = (($586) + 1)|0;
     $588 = ((($583) + ($578<<4)|0) + 4|0);
     HEAP32[$588>>2] = $587;
     $589 = HEAP32[$180>>2]|0;
     $590 = ((($583) + ($578<<4)|0) + 8|0);
     HEAP32[$590>>2] = $589;
     $591 = (($def$1$i) + 4|0);
     $592 = HEAP32[$591>>2]|0;
     $593 = ((($583) + ($578<<4)|0) + 12|0);
     HEAP32[$593>>2] = $592;
     $594 = HEAP32[$64>>2]|0;
     $595 = (($594) + 1)|0;
     HEAP32[$64>>2] = $595;
     $596 = HEAP32[$def$1$i>>2]|0;
     $597 = HEAP32[$591>>2]|0;
     $aRange$off$i$i = (($596) + -1)|0;
     $598 = ($aRange$off$i$i>>>0)>(2);
     do {
      if ($598) {
       HEAP32[$34>>2] = 132;
      } else {
       $599 = ((($exc) + ($aRange$off$i$i<<3)|0) + 444|0);
       $600 = HEAP32[$599>>2]|0;
       $601 = ($600|0)==(0|0);
       if ($601) {
        HEAP32[$34>>2] = 138;
        break;
       }
       $602 = ((($exc) + ($aRange$off$i$i<<3)|0) + 448|0);
       $603 = HEAP32[$602>>2]|0;
       $604 = ($603>>>0)<($597>>>0);
       if ($604) {
        HEAP32[$34>>2] = 131;
        break;
       } else {
        HEAP32[$23>>2] = $600;
        HEAP32[$26>>2] = $603;
        HEAP32[$22>>2] = $597;
        HEAP32[$67>>2] = $596;
        break;
       }
      }
     } while(0);
     HEAP8[$33>>0] = 0;
     label = 762;
    } else {
     label = 762;
    }
    break;
   }
   case 43:  {
    $$val35 = HEAP32[$180>>2]|0;
    $605 = HEAP32[$86>>2]|0;
    $606 = (($605) + 1)|0;
    $607 = ($606>>>0)>($$val35>>>0);
    if (!($607)) {
     label = 187;
     break L16;
    }
    $608 = HEAP32[$87>>2]|0;
    $609 = HEAP32[$88>>2]|0;
    $610 = ($606|0)==($609|0);
    if ($610) {
     $611 = (($608) + ($$val35<<4)|0);
     $612 = ((($608) + ($$val35<<4)|0) + 8|0);
     $613 = HEAP32[$612>>2]|0;
     $614 = ($613|0)==($$val35|0);
     if ($614) {
      $def$1$i89 = $611;
     } else {
      label = 172;
     }
    } else {
     label = 172;
    }
    if ((label|0) == 172) {
     label = 0;
     $615 = (($608) + ($609<<4)|0);
     $616 = ($609|0)>(0);
     L345: do {
      if ($616) {
       $def$01$i85 = $608;
       while(1) {
        $619 = (($def$01$i85) + 8|0);
        $620 = HEAP32[$619>>2]|0;
        $621 = ($620|0)==($$val35|0);
        $618 = (($def$01$i85) + 16|0);
        if ($621) {
         $def$0$lcssa$i87 = $def$01$i85;
         break L345;
        }
        $617 = ($618>>>0)<($615>>>0);
        if ($617) {
         $def$01$i85 = $618;
        } else {
         $def$0$lcssa$i87 = $618;
         break;
        }
       }
      } else {
       $def$0$lcssa$i87 = $608;
      }
     } while(0);
     $622 = ($def$0$lcssa$i87|0)==($615|0);
     if ($622) {
      label = 187;
      break L16;
     } else {
      $def$1$i89 = $def$0$lcssa$i87;
     }
    }
    $623 = (($def$1$i89) + 12|0);
    $624 = HEAP8[$623>>0]|0;
    $625 = ($624<<24>>24)==(0);
    if ($625) {
     label = 187;
     break L16;
    }
    $626 = HEAP32[$64>>2]|0;
    $627 = HEAP32[$65>>2]|0;
    $628 = ($626|0)<($627|0);
    if (!($628)) {
     label = 178;
     break L16;
    }
    $629 = HEAP32[$66>>2]|0;
    $630 = HEAP32[$67>>2]|0;
    $631 = (($629) + ($626<<4)|0);
    HEAP32[$631>>2] = $630;
    $632 = HEAP32[$22>>2]|0;
    $633 = (($632) + 1)|0;
    $634 = ((($629) + ($626<<4)|0) + 4|0);
    HEAP32[$634>>2] = $633;
    $635 = ((($629) + ($626<<4)|0) + 8|0);
    HEAP32[$635>>2] = 1;
    $636 = (($def$1$i89) + 4|0);
    $637 = HEAP32[$636>>2]|0;
    $638 = ((($629) + ($626<<4)|0) + 12|0);
    HEAP32[$638>>2] = $637;
    $639 = HEAP32[$64>>2]|0;
    $640 = (($639) + 1)|0;
    HEAP32[$64>>2] = $640;
    $641 = HEAP32[$def$1$i89>>2]|0;
    $642 = HEAP32[$636>>2]|0;
    $aRange$off$i$i90 = (($641) + -1)|0;
    $643 = ($aRange$off$i$i90>>>0)>(2);
    do {
     if ($643) {
      HEAP32[$34>>2] = 132;
     } else {
      $644 = ((($exc) + ($aRange$off$i$i90<<3)|0) + 444|0);
      $645 = HEAP32[$644>>2]|0;
      $646 = ($645|0)==(0|0);
      if ($646) {
       HEAP32[$34>>2] = 138;
       break;
      }
      $647 = ((($exc) + ($aRange$off$i$i90<<3)|0) + 448|0);
      $648 = HEAP32[$647>>2]|0;
      $649 = ($648>>>0)<($642>>>0);
      if ($649) {
       HEAP32[$34>>2] = 131;
       break;
      } else {
       HEAP32[$23>>2] = $645;
       HEAP32[$26>>2] = $648;
       HEAP32[$22>>2] = $642;
       HEAP32[$67>>2] = $641;
       break;
      }
     }
    } while(0);
    HEAP8[$33>>0] = 0;
    label = 762;
    break;
   }
   case 44:  {
    $$val36 = HEAP32[$180>>2]|0;
    $650 = HEAP32[$87>>2]|0;
    $651 = HEAP32[$88>>2]|0;
    $652 = (($650) + ($651<<4)|0);
    $653 = ($651|0)>(0);
    L364: do {
     if ($653) {
      $rec$01$i = $650;
      while(1) {
       $656 = (($rec$01$i) + 8|0);
       $657 = HEAP32[$656>>2]|0;
       $658 = ($657|0)==($$val36|0);
       $655 = (($rec$01$i) + 16|0);
       if ($658) {
        $rec$0$lcssa$i = $rec$01$i;
        break L364;
       }
       $654 = ($655>>>0)<($652>>>0);
       if ($654) {
        $rec$01$i = $655;
       } else {
        $rec$0$lcssa$i = $655;
        break;
       }
      }
     } else {
      $rec$0$lcssa$i = $650;
     }
    } while(0);
    $659 = ($rec$0$lcssa$i|0)==($652|0);
    if ($659) {
     $660 = HEAP32[$89>>2]|0;
     $661 = ($651>>>0)<($660>>>0);
     if (!($661)) {
      label = 193;
      break L16;
     }
     $662 = (($651) + 1)|0;
     HEAP32[$88>>2] = $662;
    }
    $663 = ($$val36>>>0)>(65535);
    if ($663) {
     label = 196;
     break L16;
    }
    $664 = HEAP32[$67>>2]|0;
    HEAP32[$rec$0$lcssa$i>>2] = $664;
    $665 = $$val36 & 65535;
    $666 = (($rec$0$lcssa$i) + 8|0);
    HEAP32[$666>>2] = $665;
    $667 = HEAP32[$22>>2]|0;
    $668 = (($667) + 1)|0;
    $669 = (($rec$0$lcssa$i) + 4|0);
    HEAP32[$669>>2] = $668;
    $670 = (($rec$0$lcssa$i) + 12|0);
    HEAP8[$670>>0] = 1;
    $671 = HEAP32[$86>>2]|0;
    $672 = ($671>>>0)<($$val36>>>0);
    if ($672) {
     HEAP32[$86>>2] = $665;
    }
    $$pre$i93 = HEAP32[$25>>2]|0;
    $$pre5$i = HEAP32[$22>>2]|0;
    $$pre6$i = HEAP32[$26>>2]|0;
    $674 = $$pre$i93;$675 = $$pre5$i;
    while(1) {
     $673 = (($674) + ($675))|0;
     HEAP32[$22>>2] = $673;
     $676 = ($673|0)<($$pre6$i|0);
     if (!($676)) {
      label = 204;
      break L16;
     }
     $677 = HEAP32[$23>>2]|0;
     $678 = (($677) + ($673)|0);
     $679 = HEAP8[$678>>0]|0;
     HEAP8[$24>>0] = $679;
     $680 = $679&255;
     $681 = (873192 + ($680)|0);
     $682 = HEAP8[$681>>0]|0;
     $683 = $682 << 24 >> 24;
     HEAP32[$25>>2] = $683;
     $684 = $680 & 254;
     $685 = ($684|0)==(64);
     if ($685) {
      $686 = (($673) + 1)|0;
      $687 = (($677) + ($686)|0);
      $688 = HEAP8[$687>>0]|0;
      $689 = $688&255;
      $690 = Math_imul($689, $683)|0;
      $691 = (2 - ($690))|0;
      HEAP32[$25>>2] = $691;
      $693 = $691;
     } else {
      $693 = $683;
     }
     $692 = (($693) + ($673))|0;
     $694 = ($692|0)>($$pre6$i|0);
     if ($694) {
      label = 204;
      break L16;
     }
     if ((($680|0) == 45)) {
      label = 762;
      break;
     } else if ((($680|0) == 44) | (($680|0) == 137)) {
      label = 206;
      break L16;
     } else {
      $674 = $693;$675 = $673;
     }
    }
    break;
   }
   case 45:  {
    $695 = HEAP32[$64>>2]|0;
    $696 = ($695|0)<(1);
    if ($696) {
     label = 208;
     break L16;
    }
    $697 = (($695) + -1)|0;
    HEAP32[$64>>2] = $697;
    $698 = HEAP32[$66>>2]|0;
    $699 = ((($698) + ($697<<4)|0) + 8|0);
    $700 = HEAP32[$699>>2]|0;
    $701 = (($700) + -1)|0;
    HEAP32[$699>>2] = $701;
    HEAP8[$33>>0] = 0;
    $702 = HEAP32[$699>>2]|0;
    $703 = ($702|0)>(0);
    if ($703) {
     HEAP32[$64>>2] = $695;
     $704 = ((($698) + ($697<<4)|0) + 12|0);
     $705 = HEAP32[$704>>2]|0;
     HEAP32[$22>>2] = $705;
     label = 762;
     break L33;
    }
    $706 = (($698) + ($697<<4)|0);
    $707 = HEAP32[$706>>2]|0;
    $708 = ((($698) + ($697<<4)|0) + 4|0);
    $709 = HEAP32[$708>>2]|0;
    $aRange$off$i$i95 = (($707) + -1)|0;
    $710 = ($aRange$off$i$i95>>>0)>(2);
    if ($710) {
     label = 212;
     break L16;
    }
    $711 = ((($exc) + ($aRange$off$i$i95<<3)|0) + 444|0);
    $712 = HEAP32[$711>>2]|0;
    $713 = ($712|0)==(0|0);
    if ($713) {
     label = 214;
     break L16;
    }
    $714 = ((($exc) + ($aRange$off$i$i95<<3)|0) + 448|0);
    $715 = HEAP32[$714>>2]|0;
    $716 = ($715>>>0)<($709>>>0);
    if ($716) {
     label = 216;
     break L16;
    }
    HEAP32[$23>>2] = $712;
    HEAP32[$26>>2] = $715;
    HEAP32[$22>>2] = $709;
    HEAP32[$67>>2] = $707;
    label = 762;
    break;
   }
   case 49: case 48:  {
    $738 = HEAP16[$91>>1]|0;
    $739 = ($738<<16>>16)==(0);
    if ($739) {
     label = 762;
    } else {
     $740 = $171 & 1;
     $741 = ($740<<24>>24)==(0);
     $742 = HEAP32[$92>>2]|0;
     if ($741) {
      $745 = (($742) + 4|0);
      HEAP32[$V$i>>2] = $745;
      $746 = HEAP32[$93>>2]|0;
      $747 = (($746) + 4|0);
      HEAP32[$94>>2] = $747;
      $748 = HEAP32[$95>>2]|0;
      $749 = (($748) + 4|0);
      $mask$0$i = 16;$storemerge479 = $749;
     } else {
      HEAP32[$V$i>>2] = $742;
      $743 = HEAP32[$93>>2]|0;
      HEAP32[$94>>2] = $743;
      $744 = HEAP32[$95>>2]|0;
      $mask$0$i = 8;$storemerge479 = $744;
     }
     HEAP32[$96>>2] = $storemerge479;
     $750 = HEAP16[$97>>1]|0;
     $751 = $750&65535;
     HEAP32[$98>>2] = $751;
     $761 = $750;$contour$0$i = 0;$point$0$i = 0;
     while(1) {
      $752 = $contour$0$i << 16 >> 16;
      $753 = HEAP32[$99>>2]|0;
      $754 = (($753) + ($752<<1)|0);
      $755 = HEAP16[$754>>1]|0;
      $756 = $755&65535;
      $757 = HEAP16[$100>>1]|0;
      $758 = $757&65535;
      $759 = (($756) - ($758))|0;
      $760 = $761&65535;
      $762 = ($759>>>0)<($760>>>0);
      $763 = (($760) + -1)|0;
      $$$i98 = $762 ? $759 : $763;
      $764 = ($point$0$i>>>0)>($$$i98>>>0);
      L400: do {
       if ($764) {
        $point$3$i = $point$0$i;
       } else {
        $765 = HEAP32[$101>>2]|0;
        $point$14$i = $point$0$i;
        while(1) {
         $768 = (($765) + ($point$14$i)|0);
         $769 = HEAP8[$768>>0]|0;
         $770 = $769 & $mask$0$i;
         $771 = ($770<<24>>24)==(0);
         $767 = (($point$14$i) + 1)|0;
         if (!($771)) {
          $cur_touched$0$ph$i = $point$14$i;
          break;
         }
         $766 = ($767>>>0)>($$$i98>>>0);
         if ($766) {
          $point$3$i = $767;
          break L400;
         } else {
          $point$14$i = $767;
         }
        }
        L405: while(1) {
         $point$2$in$i = $cur_touched$0$ph$i;
         while(1) {
          $point$2$i = (($point$2$in$i) + 1)|0;
          $772 = ($point$2$i>>>0)>($$$i98>>>0);
          if ($772) {
           break L405;
          }
          $773 = HEAP32[$101>>2]|0;
          $774 = (($773) + ($point$2$i)|0);
          $775 = HEAP8[$774>>0]|0;
          $776 = $775 & $mask$0$i;
          $777 = ($776<<24>>24)==(0);
          if ($777) {
           $point$2$in$i = $point$2$i;
          } else {
           break;
          }
         }
         $778 = (($cur_touched$0$ph$i) + 1)|0;
         __iup_worker_interpolate($V$i,$778,$point$2$in$i,$cur_touched$0$ph$i,$point$2$i);
         $cur_touched$0$ph$i = $point$2$i;
        }
        $779 = ($cur_touched$0$ph$i|0)==($point$14$i|0);
        if (!($779)) {
         $796 = (($cur_touched$0$ph$i) + 1)|0;
         $797 = $796 & 65535;
         __iup_worker_interpolate($V$i,$797,$$$i98,$cur_touched$0$ph$i,$point$14$i);
         $798 = ($point$14$i|0)==(0);
         if ($798) {
          $point$3$i = $point$2$i;
          break;
         }
         $799 = (($point$14$i) + -1)|0;
         __iup_worker_interpolate($V$i,$point$0$i,$799,$cur_touched$0$ph$i,$point$14$i);
         $point$3$i = $point$2$i;
         break;
        }
        $V$idx$val$i = HEAP32[$V$i>>2]|0;
        $V$idx2$val$i = HEAP32[$94>>2]|0;
        $780 = (($V$idx2$val$i) + ($point$14$i<<3)|0);
        $781 = HEAP32[$780>>2]|0;
        $782 = (($V$idx$val$i) + ($point$14$i<<3)|0);
        $783 = HEAP32[$782>>2]|0;
        $784 = (($781) - ($783))|0;
        $785 = ($781|0)==($783|0);
        if ($785) {
         $point$3$i = $point$2$i;
        } else {
         $786 = ($point$0$i>>>0)<($point$14$i>>>0);
         if ($786) {
          $i$04$i$i = $point$0$i;
          while(1) {
           $788 = (($V$idx2$val$i) + ($i$04$i$i<<3)|0);
           $789 = HEAP32[$788>>2]|0;
           $790 = (($789) + ($784))|0;
           HEAP32[$788>>2] = $790;
           $791 = (($i$04$i$i) + 1)|0;
           $exitcond$i$i = ($791|0)==($point$14$i|0);
           if ($exitcond$i$i) {
            break;
           } else {
            $i$04$i$i = $791;
           }
          }
         }
         $787 = ($767>>>0)>($$$i98>>>0);
         if ($787) {
          $point$3$i = $point$2$i;
         } else {
          $i$12$i$i = $767;
          while(1) {
           $792 = (($V$idx2$val$i) + ($i$12$i$i<<3)|0);
           $793 = HEAP32[$792>>2]|0;
           $794 = (($793) + ($784))|0;
           HEAP32[$792>>2] = $794;
           $i$1$i$i = (($i$12$i$i) + 1)|0;
           $795 = ($i$1$i$i>>>0)>($$$i98>>>0);
           if ($795) {
            $point$3$i = $point$2$i;
            break;
           } else {
            $i$12$i$i = $i$1$i$i;
           }
          }
         }
        }
       }
      } while(0);
      $800 = (($contour$0$i) + 1)<<16>>16;
      $801 = HEAP16[$91>>1]|0;
      $802 = ($800<<16>>16)<($801<<16>>16);
      if (!($802)) {
       label = 762;
       break L33;
      }
      $$pre$i100 = HEAP16[$97>>1]|0;
      $761 = $$pre$i100;$contour$0$i = $800;$point$0$i = $point$3$i;
     }
    }
    break;
   }
   case 47: case 46:  {
    $$val37 = HEAP32[$180>>2]|0;
    $717 = $$val37&65535;
    $718 = $$val37 & 65535;
    $719 = HEAP16[$39>>1]|0;
    $720 = $719&65535;
    $721 = ($718>>>0)<($720>>>0);
    if (!($721)) {
     $722 = HEAP8[$29>>0]|0;
     $723 = ($722<<24>>24)==(0);
     if ($723) {
      label = 762;
      break L33;
     } else {
      label = 220;
      break L16;
     }
    }
    $724 = $171 & 1;
    $725 = ($724<<24>>24)==(0);
    if ($725) {
     $distance$0$i97 = 0;
    } else {
     $726 = HEAP32[$50>>2]|0;
     $727 = HEAP32[$48>>2]|0;
     $728 = (($727) + ($718<<3)|0);
     $729 = HEAP32[$728>>2]|0;
     $730 = ((($727) + ($718<<3)|0) + 4|0);
     $731 = HEAP32[$730>>2]|0;
     $732 = (FUNCTION_TABLE_iiii[$726 & 2047]($exc,$729,$731)|0);
     $733 = HEAP32[$$pre$phiZ2D>>2]|0;
     $734 = HEAP32[$90>>2]|0;
     $735 = (FUNCTION_TABLE_iiii[$733 & 2047]($exc,$732,$734)|0);
     $736 = (($735) - ($732))|0;
     $distance$0$i97 = $736;
    }
    $737 = HEAP32[$52>>2]|0;
    FUNCTION_TABLE_viiii[$737 & 511]($exc,$79,$717,$distance$0$i97);
    HEAP16[$38>>1] = $717;
    HEAP16[$56>>1] = $717;
    label = 762;
    break;
   }
   case 51: case 50:  {
    $803 = HEAP32[$27>>2]|0;
    $804 = HEAP32[$84>>2]|0;
    $805 = ($803|0)<($804|0);
    if ($805) {
     $806 = HEAP8[$29>>0]|0;
     $807 = ($806<<24>>24)==(0);
     if (!($807)) {
      HEAP32[$34>>2] = 134;
     }
    } else {
     $808 = (_Compute_Point_Displacement($exc,$dx$i,$dy$i,$zp$i,$refp$i)|0);
     $809 = ($808<<24>>24)==(0);
     if (!($809)) {
      label = 762;
      break L33;
     }
     $$pr$i = HEAP32[$84>>2]|0;
     $810 = ($$pr$i|0)>(0);
     if ($810) {
      $811 = HEAP32[$dy$i>>2]|0;
      $812 = HEAP32[$dx$i>>2]|0;
      while(1) {
       $813 = HEAP32[$28>>2]|0;
       $814 = (($813) + -1)|0;
       HEAP32[$28>>2] = $814;
       $815 = HEAP32[$30>>2]|0;
       $816 = (($815) + ($814<<2)|0);
       $817 = HEAP32[$816>>2]|0;
       $818 = $817 & 65535;
       $819 = HEAP16[$74>>1]|0;
       $820 = $819&65535;
       $821 = ($818>>>0)<($820>>>0);
       if ($821) {
        $824 = HEAP16[$44>>1]|0;
        $825 = ($824<<16>>16)==(0);
        if (!($825)) {
         $826 = HEAP32[$75>>2]|0;
         $827 = (($826) + ($818<<3)|0);
         $828 = HEAP32[$827>>2]|0;
         $829 = (($828) + ($812))|0;
         HEAP32[$827>>2] = $829;
         $830 = HEAP32[$78>>2]|0;
         $831 = (($830) + ($818)|0);
         $832 = HEAP8[$831>>0]|0;
         $833 = $832&255;
         $834 = $833 | 8;
         $835 = $834&255;
         HEAP8[$831>>0] = $835;
        }
        $836 = HEAP16[$46>>1]|0;
        $837 = ($836<<16>>16)==(0);
        if (!($837)) {
         $838 = HEAP32[$75>>2]|0;
         $839 = ((($838) + ($818<<3)|0) + 4|0);
         $840 = HEAP32[$839>>2]|0;
         $841 = (($840) + ($811))|0;
         HEAP32[$839>>2] = $841;
         $842 = HEAP32[$78>>2]|0;
         $843 = (($842) + ($818)|0);
         $844 = HEAP8[$843>>0]|0;
         $845 = $844&255;
         $846 = $845 | 16;
         $847 = $846&255;
         HEAP8[$843>>0] = $847;
        }
       } else {
        $822 = HEAP8[$29>>0]|0;
        $823 = ($822<<24>>24)==(0);
        if (!($823)) {
         label = 255;
         break L16;
        }
       }
       $848 = HEAP32[$84>>2]|0;
       $849 = (($848) + -1)|0;
       HEAP32[$84>>2] = $849;
       $850 = ($849|0)>(0);
       if (!($850)) {
        break;
       }
      }
     }
    }
    HEAP32[$84>>2] = 1;
    $851 = HEAP32[$28>>2]|0;
    HEAP32[$31>>2] = $851;
    label = 762;
    break;
   }
   case 53: case 52:  {
    $$val38 = HEAP32[$180>>2]|0;
    $sext$i107 = $$val38 << 16;
    $852 = $sext$i107 >> 16;
    $853 = HEAP16[$91>>1]|0;
    $854 = $853 << 16 >> 16;
    $855 = ($852>>>0)<($854>>>0);
    if (!($855)) {
     $856 = HEAP8[$29>>0]|0;
     $857 = ($856<<24>>24)==(0);
     if ($857) {
      label = 762;
      break L33;
     } else {
      label = 264;
      break L16;
     }
    }
    $858 = (_Compute_Point_Displacement($exc,$dx$i105,$dy$i106,$zp$i103,$refp$i104)|0);
    $859 = ($858<<24>>24)==(0);
    if ($859) {
     $860 = ($852|0)==(0);
     if ($860) {
      $$pre$i108 = HEAP32[$99>>2]|0;
      $$pre6$i109 = HEAP16[$100>>1]|0;
      $872 = $$pre$i108;$876 = $$pre6$i109;$first_point$0$i = 0;
     } else {
      $861 = (($852) + -1)|0;
      $862 = HEAP32[$99>>2]|0;
      $863 = (($862) + ($861<<1)|0);
      $864 = HEAP16[$863>>1]|0;
      $865 = $864&65535;
      $866 = (($865) + 1)|0;
      $867 = HEAP16[$100>>1]|0;
      $868 = $867&65535;
      $869 = (($866) - ($868))|0;
      $870 = $869&65535;
      $872 = $862;$876 = $867;$first_point$0$i = $870;
     }
     $871 = (($872) + ($852<<1)|0);
     $873 = HEAP16[$871>>1]|0;
     $874 = $873&65535;
     $875 = $876&65535;
     $877 = (($874) - ($875))|0;
     $878 = $877 & 65535;
     $879 = HEAP16[$74>>1]|0;
     $880 = $879&65535;
     $881 = ($878>>>0)<($880>>>0);
     if ($881) {
      $last_point$0$i = $877;
     } else {
      $882 = ($879<<16>>16)==(0);
      $883 = (($880) + -1)|0;
      $$$i110 = $882 ? 0 : $883;
      $last_point$0$i = $$$i110;
     }
     $884 = $first_point$0$i&65535;
     $885 = $last_point$0$i & 65535;
     $886 = ($884>>>0)>($885>>>0);
     if ($886) {
      label = 762;
     } else {
      $887 = HEAP32[$102>>2]|0;
      $888 = HEAP16[$refp$i104>>1]|0;
      $889 = HEAP32[$dy$i106>>2]|0;
      $890 = HEAP32[$dx$i105>>2]|0;
      $897 = $884;$i$01$i = $first_point$0$i;
      while(1) {
       $891 = HEAP32[$75>>2]|0;
       $892 = ($887|0)==($891|0);
       $893 = ($888<<16>>16)==($i$01$i<<16>>16);
       $or$cond$i112 = $892 & $893;
       if (!($or$cond$i112)) {
        $894 = HEAP16[$44>>1]|0;
        $895 = ($894<<16>>16)==(0);
        if (!($895)) {
         $896 = (($891) + ($897<<3)|0);
         $898 = HEAP32[$896>>2]|0;
         $899 = (($898) + ($890))|0;
         HEAP32[$896>>2] = $899;
         $900 = HEAP32[$78>>2]|0;
         $901 = (($900) + ($897)|0);
         $902 = HEAP8[$901>>0]|0;
         $903 = $902&255;
         $904 = $903 | 8;
         $905 = $904&255;
         HEAP8[$901>>0] = $905;
        }
        $906 = HEAP16[$46>>1]|0;
        $907 = ($906<<16>>16)==(0);
        if (!($907)) {
         $908 = HEAP32[$75>>2]|0;
         $909 = ((($908) + ($897<<3)|0) + 4|0);
         $910 = HEAP32[$909>>2]|0;
         $911 = (($910) + ($889))|0;
         HEAP32[$909>>2] = $911;
         $912 = HEAP32[$78>>2]|0;
         $913 = (($912) + ($897)|0);
         $914 = HEAP8[$913>>0]|0;
         $915 = $914&255;
         $916 = $915 | 16;
         $917 = $916&255;
         HEAP8[$913>>0] = $917;
        }
       }
       $918 = (($i$01$i) + 1)<<16>>16;
       $919 = $918&65535;
       $920 = ($919>>>0)>($885>>>0);
       if ($920) {
        label = 762;
        break;
       } else {
        $897 = $919;$i$01$i = $918;
       }
      }
     }
    } else {
     label = 762;
    }
    break;
   }
   case 55: case 54:  {
    $$val39 = HEAP32[$180>>2]|0;
    $921 = ($$val39>>>0)>(1);
    if ($921) {
     $922 = HEAP8[$29>>0]|0;
     $923 = ($922<<24>>24)==(0);
     if ($923) {
      label = 762;
      break L33;
     } else {
      label = 281;
      break L16;
     }
    }
    $924 = (_Compute_Point_Displacement($exc,$dx$i119,$dy$i120,$zp$i117,$refp$i118)|0);
    $925 = ($924<<24>>24)==(0);
    if ($925) {
     $926 = HEAP16[$83>>1]|0;
     if ((($926<<16>>16) == 0)) {
      $927 = HEAP16[$74>>1]|0;
      $928 = ($927<<16>>16)==(0);
      if ($928) {
       $last_point$0$i121 = 0;
      } else {
       $929 = $927&65535;
       $930 = (($929) + 65535)|0;
       $931 = $930&65535;
       $last_point$0$i121 = $931;
      }
     } else if ((($926<<16>>16) == 1)) {
      $932 = HEAP16[$104>>1]|0;
      $933 = ($932<<16>>16)>(0);
      if ($933) {
       $934 = $932 << 16 >> 16;
       $935 = (($934) + -1)|0;
       $936 = HEAP32[$105>>2]|0;
       $937 = (($936) + ($935<<1)|0);
       $938 = HEAP16[$937>>1]|0;
       $939 = HEAP16[$74>>1]|0;
       $940 = ($938&65535)<($939&65535);
       if ($940) {
        $last_point$0$i121 = $938;
       } else {
        $941 = HEAP8[$29>>0]|0;
        $942 = ($941<<24>>24)==(0);
        if ($942) {
         label = 762;
         break L33;
        } else {
         label = 289;
         break L16;
        }
       }
      } else {
       $last_point$0$i121 = 0;
      }
     } else {
      $last_point$0$i121 = 0;
     }
     $943 = HEAP32[$103>>2]|0;
     $944 = HEAP32[$75>>2]|0;
     $945 = ($943|0)==($944|0);
     $946 = HEAP16[$refp$i118>>1]|0;
     $947 = HEAP32[$dy$i120>>2]|0;
     $948 = HEAP32[$dx$i119>>2]|0;
     if ($945) {
      $i$01$us$i = 0;
      while(1) {
       $959 = ($946<<16>>16)==($i$01$us$i<<16>>16);
       if (!($959)) {
        $960 = HEAP16[$44>>1]|0;
        $961 = ($960<<16>>16)==(0);
        if (!($961)) {
         $962 = $i$01$us$i&65535;
         $963 = (($943) + ($962<<3)|0);
         $964 = HEAP32[$963>>2]|0;
         $965 = (($964) + ($948))|0;
         HEAP32[$963>>2] = $965;
        }
        $966 = HEAP16[$46>>1]|0;
        $967 = ($966<<16>>16)==(0);
        if (!($967)) {
         $968 = $i$01$us$i&65535;
         $969 = ((($943) + ($968<<3)|0) + 4|0);
         $970 = HEAP32[$969>>2]|0;
         $971 = (($970) + ($947))|0;
         HEAP32[$969>>2] = $971;
        }
       }
       $972 = (($i$01$us$i) + 1)<<16>>16;
       $973 = ($972&65535)>($last_point$0$i121&65535);
       if ($973) {
        label = 762;
        break L33;
       } else {
        $i$01$us$i = $972;
       }
      }
     }
     $949 = HEAP16[$44>>1]|0;
     $950 = ($949<<16>>16)==(0);
     $951 = HEAP16[$46>>1]|0;
     $952 = ($951<<16>>16)==(0);
     if ($950) {
      $i$01$i122$us = 0;
      while(1) {
       if (!($952)) {
        $953 = $i$01$i122$us&65535;
        $954 = ((($944) + ($953<<3)|0) + 4|0);
        $955 = HEAP32[$954>>2]|0;
        $956 = (($955) + ($947))|0;
        HEAP32[$954>>2] = $956;
       }
       $957 = (($i$01$i122$us) + 1)<<16>>16;
       $958 = ($957&65535)>($last_point$0$i121&65535);
       if ($958) {
        label = 762;
        break;
       } else {
        $i$01$i122$us = $957;
       }
      }
     } else {
      $i$01$i122 = 0;
      while(1) {
       $974 = $i$01$i122&65535;
       $975 = (($944) + ($974<<3)|0);
       $976 = HEAP32[$975>>2]|0;
       $977 = (($976) + ($948))|0;
       HEAP32[$975>>2] = $977;
       if (!($952)) {
        $978 = $i$01$i122&65535;
        $979 = ((($944) + ($978<<3)|0) + 4|0);
        $980 = HEAP32[$979>>2]|0;
        $981 = (($980) + ($947))|0;
        HEAP32[$979>>2] = $981;
       }
       $982 = (($i$01$i122) + 1)<<16>>16;
       $983 = ($982&65535)>($last_point$0$i121&65535);
       if ($983) {
        label = 762;
        break;
       } else {
        $i$01$i122 = $982;
       }
      }
     }
    } else {
     label = 762;
    }
    break;
   }
   case 57:  {
    $1073 = HEAP32[$27>>2]|0;
    $1074 = HEAP32[$84>>2]|0;
    $1075 = ($1073|0)<($1074|0);
    do {
     if ($1075) {
      $1076 = HEAP8[$29>>0]|0;
      $1077 = ($1076<<24>>24)==(0);
      if (!($1077)) {
       HEAP32[$34>>2] = 134;
      }
     } else {
      $1078 = HEAP16[$54>>1]|0;
      $1079 = ($1078<<16>>16)==(0);
      if ($1079) {
       $1090 = 1;
      } else {
       $1080 = HEAP16[$42>>1]|0;
       $1081 = ($1080<<16>>16)==(0);
       if ($1081) {
        $1090 = 1;
       } else {
        $1082 = HEAP16[$83>>1]|0;
        $1083 = ($1082<<16>>16)==(0);
        $1090 = $1083;
       }
      }
      $1084 = HEAP16[$56>>1]|0;
      $1085 = $1084&65535;
      $1086 = HEAP16[$39>>1]|0;
      $1087 = ($1084&65535)<($1086&65535);
      if (!($1087)) {
       $1088 = HEAP8[$29>>0]|0;
       $1089 = ($1088<<24>>24)==(0);
       if ($1089) {
        break;
       }
       HEAP32[$34>>2] = 134;
       break;
      }
      $$pn$in$i = $1090 ? $43 : $59;
      $$pn$i = HEAP32[$$pn$in$i>>2]|0;
      $orus_base$0$i = (($$pn$i) + ($1085<<3)|0);
      $1091 = HEAP32[$48>>2]|0;
      $1092 = (($1091) + ($1085<<3)|0);
      $1093 = HEAP16[$57>>1]|0;
      $1094 = $1093&65535;
      $1095 = HEAP16[$36>>1]|0;
      $1096 = ($1093&65535)<($1095&65535);
      if ($1096) {
       $1097 = HEAP32[$49>>2]|0;
       if ($1090) {
        $1098 = HEAP32[$45>>2]|0;
        $1099 = (($1098) + ($1094<<3)|0);
        $1100 = HEAP32[$1099>>2]|0;
        $1101 = HEAP32[$orus_base$0$i>>2]|0;
        $1102 = (($1100) - ($1101))|0;
        $1103 = ((($1098) + ($1094<<3)|0) + 4|0);
        $1104 = HEAP32[$1103>>2]|0;
        $1105 = ((($$pn$i) + ($1085<<3)|0) + 4|0);
        $1106 = HEAP32[$1105>>2]|0;
        $1107 = (($1104) - ($1106))|0;
        $1108 = (FUNCTION_TABLE_iiii[$1097 & 2047]($exc,$1102,$1107)|0);
        $old_range$0$i = $1108;
       } else {
        $1109 = HEAP32[$58>>2]|0;
        $1110 = (($1109) + ($1094<<3)|0);
        $1111 = HEAP32[$1110>>2]|0;
        $1112 = HEAP32[$orus_base$0$i>>2]|0;
        $1113 = (($1111) - ($1112))|0;
        $1114 = ((($1109) + ($1094<<3)|0) + 4|0);
        $1115 = HEAP32[$1114>>2]|0;
        $1116 = ((($$pn$i) + ($1085<<3)|0) + 4|0);
        $1117 = HEAP32[$1116>>2]|0;
        $1118 = (($1115) - ($1117))|0;
        $1119 = (FUNCTION_TABLE_iiii[$1097 & 2047]($exc,$1113,$1118)|0);
        $old_range$0$i = $1119;
       }
       $1120 = HEAP32[$50>>2]|0;
       $1121 = HEAP16[$57>>1]|0;
       $1122 = $1121&65535;
       $1123 = HEAP32[$47>>2]|0;
       $1124 = (($1123) + ($1122<<3)|0);
       $1125 = HEAP32[$1124>>2]|0;
       $1126 = HEAP32[$1092>>2]|0;
       $1127 = (($1125) - ($1126))|0;
       $1128 = ((($1123) + ($1122<<3)|0) + 4|0);
       $1129 = HEAP32[$1128>>2]|0;
       $1130 = ((($1091) + ($1085<<3)|0) + 4|0);
       $1131 = HEAP32[$1130>>2]|0;
       $1132 = (($1129) - ($1131))|0;
       $1133 = (FUNCTION_TABLE_iiii[$1120 & 2047]($exc,$1127,$1132)|0);
       $$pr$pre$i = HEAP32[$84>>2]|0;
       $$pr$i131 = $$pr$pre$i;$cur_range$0$ph$i = $1133;$old_range$1$ph$i = $old_range$0$i;
      } else {
       $$pr$i131 = $1074;$cur_range$0$ph$i = 0;$old_range$1$ph$i = 0;
      }
      $1134 = ($$pr$i131|0)>(0);
      if ($1134) {
       $1135 = ((($$pn$i) + ($1085<<3)|0) + 4|0);
       $1136 = ((($1091) + ($1085<<3)|0) + 4|0);
       $1137 = ($old_range$1$ph$i|0)==(0);
       if ($1090) {
        $2675 = $$pr$i131;
        while(1) {
         $1138 = HEAP32[$28>>2]|0;
         $1139 = (($1138) + -1)|0;
         HEAP32[$28>>2] = $1139;
         $1140 = HEAP32[$30>>2]|0;
         $1141 = (($1140) + ($1139<<2)|0);
         $1142 = HEAP32[$1141>>2]|0;
         $1143 = HEAP16[$74>>1]|0;
         $1144 = $1143&65535;
         $1145 = ($1142>>>0)<($1144>>>0);
         if ($1145) {
          $1148 = HEAP32[$49>>2]|0;
          $1149 = HEAP32[$106>>2]|0;
          $1150 = (($1149) + ($1142<<3)|0);
          $1151 = HEAP32[$1150>>2]|0;
          $1152 = HEAP32[$orus_base$0$i>>2]|0;
          $1153 = (($1151) - ($1152))|0;
          $1154 = ((($1149) + ($1142<<3)|0) + 4|0);
          $1155 = HEAP32[$1154>>2]|0;
          $1156 = HEAP32[$1135>>2]|0;
          $1157 = (($1155) - ($1156))|0;
          $1158 = (FUNCTION_TABLE_iiii[$1148 & 2047]($exc,$1153,$1157)|0);
          $1159 = HEAP32[$50>>2]|0;
          $1160 = HEAP32[$75>>2]|0;
          $1161 = (($1160) + ($1142<<3)|0);
          $1162 = HEAP32[$1161>>2]|0;
          $1163 = HEAP32[$1092>>2]|0;
          $1164 = (($1162) - ($1163))|0;
          $1165 = ((($1160) + ($1142<<3)|0) + 4|0);
          $1166 = HEAP32[$1165>>2]|0;
          $1167 = HEAP32[$1136>>2]|0;
          $1168 = (($1166) - ($1167))|0;
          $1169 = (FUNCTION_TABLE_iiii[$1159 & 2047]($exc,$1164,$1168)|0);
          $1170 = ($1158|0)==(0);
          $brmerge$i = $1170 | $1137;
          $$mux$i = $1170 ? 0 : $1169;
          if ($brmerge$i) {
           $new_dist$0$us$i = $$mux$i;
          } else {
           $1171 = (_FT_MulDiv($1158,$cur_range$0$ph$i,$old_range$1$ph$i)|0);
           $new_dist$0$us$i = $1171;
          }
          $1172 = HEAP32[$52>>2]|0;
          $1173 = $1142&65535;
          $1174 = (($new_dist$0$us$i) - ($1169))|0;
          FUNCTION_TABLE_viiii[$1172 & 511]($exc,$82,$1173,$1174);
          $$pre$i134 = HEAP32[$84>>2]|0;
          $1176 = $$pre$i134;
         } else {
          $1146 = HEAP8[$29>>0]|0;
          $1147 = ($1146<<24>>24)==(0);
          if ($1147) {
           $1176 = $2675;
          } else {
           label = 342;
           break L16;
          }
         }
         $1175 = (($1176) + -1)|0;
         HEAP32[$84>>2] = $1175;
         $1177 = ($1175|0)>(0);
         if ($1177) {
          $2675 = $1175;
         } else {
          break;
         }
        }
       } else {
        $2676 = $$pr$i131;
        while(1) {
         $1178 = HEAP32[$28>>2]|0;
         $1179 = (($1178) + -1)|0;
         HEAP32[$28>>2] = $1179;
         $1180 = HEAP32[$30>>2]|0;
         $1181 = (($1180) + ($1179<<2)|0);
         $1182 = HEAP32[$1181>>2]|0;
         $1183 = HEAP16[$74>>1]|0;
         $1184 = $1183&65535;
         $1185 = ($1182>>>0)<($1184>>>0);
         if ($1185) {
          $1188 = HEAP32[$49>>2]|0;
          $1189 = HEAP32[$107>>2]|0;
          $1190 = (($1189) + ($1182<<3)|0);
          $1191 = HEAP32[$1190>>2]|0;
          $1192 = HEAP32[$orus_base$0$i>>2]|0;
          $1193 = (($1191) - ($1192))|0;
          $1194 = ((($1189) + ($1182<<3)|0) + 4|0);
          $1195 = HEAP32[$1194>>2]|0;
          $1196 = HEAP32[$1135>>2]|0;
          $1197 = (($1195) - ($1196))|0;
          $1198 = (FUNCTION_TABLE_iiii[$1188 & 2047]($exc,$1193,$1197)|0);
          $1199 = HEAP32[$50>>2]|0;
          $1200 = HEAP32[$75>>2]|0;
          $1201 = (($1200) + ($1182<<3)|0);
          $1202 = HEAP32[$1201>>2]|0;
          $1203 = HEAP32[$1092>>2]|0;
          $1204 = (($1202) - ($1203))|0;
          $1205 = ((($1200) + ($1182<<3)|0) + 4|0);
          $1206 = HEAP32[$1205>>2]|0;
          $1207 = HEAP32[$1136>>2]|0;
          $1208 = (($1206) - ($1207))|0;
          $1209 = (FUNCTION_TABLE_iiii[$1199 & 2047]($exc,$1204,$1208)|0);
          $1210 = ($1198|0)==(0);
          $brmerge6$i = $1210 | $1137;
          $$mux7$i = $1210 ? 0 : $1209;
          if ($brmerge6$i) {
           $new_dist$0$i = $$mux7$i;
          } else {
           $1211 = (_FT_MulDiv($1198,$cur_range$0$ph$i,$old_range$1$ph$i)|0);
           $new_dist$0$i = $1211;
          }
          $1212 = HEAP32[$52>>2]|0;
          $1213 = $1182&65535;
          $1214 = (($new_dist$0$i) - ($1209))|0;
          FUNCTION_TABLE_viiii[$1212 & 511]($exc,$82,$1213,$1214);
          $$pre2$i135 = HEAP32[$84>>2]|0;
          $1216 = $$pre2$i135;
         } else {
          $1186 = HEAP8[$29>>0]|0;
          $1187 = ($1186<<24>>24)==(0);
          if ($1187) {
           $1216 = $2676;
          } else {
           label = 342;
           break L16;
          }
         }
         $1215 = (($1216) + -1)|0;
         HEAP32[$84>>2] = $1215;
         $1217 = ($1215|0)>(0);
         if ($1217) {
          $2676 = $1215;
         } else {
          break;
         }
        }
       }
      }
     }
    } while(0);
    HEAP32[$84>>2] = 1;
    $1218 = HEAP32[$28>>2]|0;
    HEAP32[$31>>2] = $1218;
    label = 762;
    break;
   }
   case 56:  {
    $984 = HEAP32[$27>>2]|0;
    $985 = HEAP32[$84>>2]|0;
    $986 = (($985) + 1)|0;
    $987 = ($984|0)<($986|0);
    L548: do {
     if ($987) {
      $988 = HEAP8[$29>>0]|0;
      $989 = ($988<<24>>24)==(0);
      if ($989) {
       $1072 = $176;
      } else {
       HEAP32[$34>>2] = 134;
       $1072 = $176;
      }
     } else {
      $990 = HEAP32[$180>>2]|0;
      $991 = HEAP16[$44>>1]|0;
      $992 = $991 << 16 >> 16;
      $993 = $992 ^ $990;
      $994 = ($990|0)<(0);
      $995 = (0 - ($990))|0;
      $$a$i$i = $994 ? $995 : $990;
      $996 = ($991<<16>>16)<(0);
      $997 = (0 - ($992))|0;
      $$01$i$i = $996 ? $997 : $992;
      $998 = $$a$i$i >>> 16;
      $999 = $$a$i$i & 65535;
      $1000 = Math_imul($999, $$01$i$i)|0;
      $1001 = Math_imul($998, $$01$i$i)|0;
      $1002 = $1001 >>> 16;
      $1003 = $1001 << 16;
      $1004 = $1003 | 8192;
      $1005 = (($1004) + ($1000))|0;
      $1006 = ($1005>>>0)<($1004>>>0);
      $1007 = $1006&1;
      $$$i$i125 = (($1007) + ($1002))|0;
      $1008 = $1005 >>> 14;
      $1009 = $$$i$i125 << 18;
      $1010 = $1009 | $1008;
      $1011 = ($993|0)>(-1);
      $1012 = (0 - ($1010))|0;
      $1013 = $1011 ? $1010 : $1012;
      $1014 = HEAP16[$46>>1]|0;
      $1015 = $1014 << 16 >> 16;
      $1016 = $1015 ^ $990;
      $1017 = ($1014<<16>>16)<(0);
      $1018 = (0 - ($1015))|0;
      $$01$i2$i = $1017 ? $1018 : $1015;
      $1019 = Math_imul($$01$i2$i, $999)|0;
      $1020 = Math_imul($$01$i2$i, $998)|0;
      $1021 = $1020 >>> 16;
      $1022 = $1020 << 16;
      $1023 = $1022 | 8192;
      $1024 = (($1023) + ($1019))|0;
      $1025 = ($1024>>>0)<($1023>>>0);
      $1026 = $1025&1;
      $$$i3$i = (($1026) + ($1021))|0;
      $1027 = $1024 >>> 14;
      $1028 = $$$i3$i << 18;
      $1029 = $1028 | $1027;
      $1030 = ($1016|0)>(-1);
      $1031 = (0 - ($1029))|0;
      $1032 = $1030 ? $1029 : $1031;
      $1033 = ($985|0)>(0);
      if ($1033) {
       $1035 = $176;$1037 = $179;
       while(1) {
        $1034 = (($1035) + -1)|0;
        HEAP32[$28>>2] = $1034;
        $1036 = (($1037) + ($1034<<2)|0);
        $1038 = HEAP32[$1036>>2]|0;
        $1039 = $1038 & 65535;
        $1040 = HEAP16[$74>>1]|0;
        $1041 = $1040&65535;
        $1042 = ($1039>>>0)<($1041>>>0);
        if ($1042) {
         $1045 = HEAP16[$44>>1]|0;
         $1046 = ($1045<<16>>16)==(0);
         if (!($1046)) {
          $1047 = HEAP32[$75>>2]|0;
          $1048 = (($1047) + ($1039<<3)|0);
          $1049 = HEAP32[$1048>>2]|0;
          $1050 = (($1049) + ($1013))|0;
          HEAP32[$1048>>2] = $1050;
          $1051 = HEAP32[$78>>2]|0;
          $1052 = (($1051) + ($1039)|0);
          $1053 = HEAP8[$1052>>0]|0;
          $1054 = $1053&255;
          $1055 = $1054 | 8;
          $1056 = $1055&255;
          HEAP8[$1052>>0] = $1056;
         }
         $1057 = HEAP16[$46>>1]|0;
         $1058 = ($1057<<16>>16)==(0);
         if (!($1058)) {
          $1059 = HEAP32[$75>>2]|0;
          $1060 = ((($1059) + ($1039<<3)|0) + 4|0);
          $1061 = HEAP32[$1060>>2]|0;
          $1062 = (($1061) + ($1032))|0;
          HEAP32[$1060>>2] = $1062;
          $1063 = HEAP32[$78>>2]|0;
          $1064 = (($1063) + ($1039)|0);
          $1065 = HEAP8[$1064>>0]|0;
          $1066 = $1065&255;
          $1067 = $1066 | 16;
          $1068 = $1067&255;
          HEAP8[$1064>>0] = $1068;
         }
        } else {
         $1043 = HEAP8[$29>>0]|0;
         $1044 = ($1043<<24>>24)==(0);
         if (!($1044)) {
          label = 310;
          break L16;
         }
        }
        $1069 = HEAP32[$84>>2]|0;
        $1070 = (($1069) + -1)|0;
        HEAP32[$84>>2] = $1070;
        $1071 = ($1070|0)>(0);
        $$pre455 = HEAP32[$28>>2]|0;
        if (!($1071)) {
         $1072 = $$pre455;
         break L548;
        }
        $$pre456 = HEAP32[$30>>2]|0;
        $1035 = $$pre455;$1037 = $$pre456;
       }
      } else {
       $1072 = $176;
      }
     }
    } while(0);
    HEAP32[$84>>2] = 1;
    HEAP32[$31>>2] = $1072;
    label = 762;
    break;
   }
   case 61:  {
    HEAP32[$11>>2] = 2;
    HEAP32[$$pre$phiZ2D>>2] = 1621;
    label = 762;
    break;
   }
   case 63: case 62:  {
    $$val40 = HEAP32[$180>>2]|0;
    $$sum270 = (($176) + 1)|0;
    $$idx41 = (($179) + ($$sum270<<2)|0);
    $$idx41$val = HEAP32[$$idx41>>2]|0;
    $1330 = $$val40&65535;
    $1331 = $$val40 & 65535;
    $1332 = HEAP16[$39>>1]|0;
    $1333 = $1332&65535;
    $1334 = ($1331>>>0)<($1333>>>0);
    if ($1334) {
     $1335 = HEAP32[$37>>2]|0;
     $1336 = ($1335>>>0)>($$idx41$val>>>0);
     if ($1336) {
      $1339 = HEAP32[$6>>2]|0;
      $1340 = (FUNCTION_TABLE_iii[$1339 & 4095]($exc,$$idx41$val)|0);
      $1341 = HEAP16[$54>>1]|0;
      $1342 = ($1341<<16>>16)==(0);
      if ($1342) {
       $1343 = HEAP16[$44>>1]|0;
       $1344 = $1343 << 16 >> 16;
       $1345 = $1344 ^ $1340;
       $1346 = ($1340|0)<(0);
       $1347 = (0 - ($1340))|0;
       $$a$i$i147 = $1346 ? $1347 : $1340;
       $1348 = ($1343<<16>>16)<(0);
       $1349 = (0 - ($1344))|0;
       $$01$i$i148 = $1348 ? $1349 : $1344;
       $1350 = $$a$i$i147 >>> 16;
       $1351 = $$a$i$i147 & 65535;
       $1352 = Math_imul($$01$i$i148, $1351)|0;
       $1353 = Math_imul($$01$i$i148, $1350)|0;
       $1354 = $1353 >>> 16;
       $1355 = $1353 << 16;
       $1356 = $1355 | 8192;
       $1357 = (($1356) + ($1352))|0;
       $1358 = ($1357>>>0)<($1356>>>0);
       $1359 = $1358&1;
       $$$i$i149 = (($1359) + ($1354))|0;
       $1360 = $1357 >>> 14;
       $1361 = $$$i$i149 << 18;
       $1362 = $1361 | $1360;
       $1363 = ($1345|0)>(-1);
       $1364 = (0 - ($1362))|0;
       $1365 = $1363 ? $1362 : $1364;
       $1366 = HEAP32[$43>>2]|0;
       $1367 = (($1366) + ($1331<<3)|0);
       HEAP32[$1367>>2] = $1365;
       $1368 = HEAP16[$46>>1]|0;
       $1369 = $1368 << 16 >> 16;
       $1370 = $1369 ^ $1340;
       $1371 = ($1368<<16>>16)<(0);
       $1372 = (0 - ($1369))|0;
       $$01$i2$i150 = $1371 ? $1372 : $1369;
       $1373 = Math_imul($$01$i2$i150, $1351)|0;
       $1374 = Math_imul($$01$i2$i150, $1350)|0;
       $1375 = $1374 >>> 16;
       $1376 = $1374 << 16;
       $1377 = $1376 | 8192;
       $1378 = (($1377) + ($1373))|0;
       $1379 = ($1378>>>0)<($1377>>>0);
       $1380 = $1379&1;
       $$$i3$i151 = (($1380) + ($1375))|0;
       $1381 = $1378 >>> 14;
       $1382 = $$$i3$i151 << 18;
       $1383 = $1382 | $1381;
       $1384 = ($1370|0)>(-1);
       $1385 = (0 - ($1383))|0;
       $1386 = $1384 ? $1383 : $1385;
       $1387 = ((($1366) + ($1331<<3)|0) + 4|0);
       HEAP32[$1387>>2] = $1386;
       $1388 = HEAP32[$48>>2]|0;
       $1389 = (($1388) + ($1331<<3)|0);
       $1390 = (($1366) + ($1331<<3)|0);
       $1391 = $1390;
       $1392 = $1391;
       $1393 = HEAP32[$1392>>2]|0;
       $1394 = (($1391) + 4)|0;
       $1395 = $1394;
       $1396 = HEAP32[$1395>>2]|0;
       $1397 = $1389;
       $1398 = $1397;
       HEAP32[$1398>>2] = $1393;
       $1399 = (($1397) + 4)|0;
       $1400 = $1399;
       HEAP32[$1400>>2] = $1396;
      }
      $1401 = HEAP32[$50>>2]|0;
      $1402 = HEAP32[$48>>2]|0;
      $1403 = (($1402) + ($1331<<3)|0);
      $1404 = HEAP32[$1403>>2]|0;
      $1405 = ((($1402) + ($1331<<3)|0) + 4|0);
      $1406 = HEAP32[$1405>>2]|0;
      $1407 = (FUNCTION_TABLE_iiii[$1401 & 2047]($exc,$1404,$1406)|0);
      $1408 = HEAP8[$24>>0]|0;
      $1409 = $1408 & 1;
      $1410 = ($1409<<24>>24)==(0);
      if ($1410) {
       $distance$1$i154 = $1340;
      } else {
       $1411 = (($1340) - ($1407))|0;
       $1412 = ($1411|0)<(0);
       $1413 = (0 - ($1411))|0;
       $1414 = $1412 ? $1413 : $1411;
       $1415 = HEAP32[$55>>2]|0;
       $1416 = ($1414|0)>($1415|0);
       $$$i153 = $1416 ? $1407 : $1340;
       $1417 = HEAP32[$$pre$phiZ2D>>2]|0;
       $1418 = HEAP32[$90>>2]|0;
       $1419 = (FUNCTION_TABLE_iiii[$1417 & 2047]($exc,$$$i153,$1418)|0);
       $distance$1$i154 = $1419;
      }
      $1420 = HEAP32[$52>>2]|0;
      $1421 = (($distance$1$i154) - ($1407))|0;
      FUNCTION_TABLE_viiii[$1420 & 511]($exc,$79,$1330,$1421);
     } else {
      label = 372;
     }
    } else {
     label = 372;
    }
    if ((label|0) == 372) {
     label = 0;
     $1337 = HEAP8[$29>>0]|0;
     $1338 = ($1337<<24>>24)==(0);
     if (!($1338)) {
      HEAP32[$34>>2] = 134;
     }
    }
    HEAP16[$38>>1] = $1330;
    HEAP16[$56>>1] = $1330;
    label = 762;
    break;
   }
   case 60:  {
    $1287 = HEAP32[$27>>2]|0;
    $1288 = HEAP32[$84>>2]|0;
    $1289 = ($1287|0)<($1288|0);
    L580: do {
     if ($1289) {
      label = 359;
     } else {
      $1290 = HEAP16[$38>>1]|0;
      $1291 = HEAP16[$39>>1]|0;
      $1292 = ($1290&65535)<($1291&65535);
      if ($1292) {
       $1295 = ($1288|0)>(0);
       if ($1295) {
        $1297 = $176;$1299 = $179;$2677 = $1288;
        while(1) {
         $1296 = (($1297) + -1)|0;
         HEAP32[$28>>2] = $1296;
         $1298 = (($1299) + ($1296<<2)|0);
         $1300 = HEAP32[$1298>>2]|0;
         $1301 = $1300 & 65535;
         $1302 = HEAP16[$36>>1]|0;
         $1303 = $1302&65535;
         $1304 = ($1301>>>0)<($1303>>>0);
         if ($1304) {
          $1307 = $1300&65535;
          $1308 = HEAP32[$50>>2]|0;
          $1309 = HEAP32[$47>>2]|0;
          $1310 = (($1309) + ($1301<<3)|0);
          $1311 = HEAP32[$1310>>2]|0;
          $1312 = HEAP32[$48>>2]|0;
          $1313 = HEAP16[$38>>1]|0;
          $1314 = $1313&65535;
          $1315 = (($1312) + ($1314<<3)|0);
          $1316 = HEAP32[$1315>>2]|0;
          $1317 = (($1311) - ($1316))|0;
          $1318 = ((($1309) + ($1301<<3)|0) + 4|0);
          $1319 = HEAP32[$1318>>2]|0;
          $1320 = ((($1312) + ($1314<<3)|0) + 4|0);
          $1321 = HEAP32[$1320>>2]|0;
          $1322 = (($1319) - ($1321))|0;
          $1323 = (FUNCTION_TABLE_iiii[$1308 & 2047]($exc,$1317,$1322)|0);
          $1324 = HEAP32[$52>>2]|0;
          $1325 = (0 - ($1323))|0;
          FUNCTION_TABLE_viiii[$1324 & 511]($exc,$35,$1307,$1325);
          $$pre$i143 = HEAP32[$84>>2]|0;
          $1327 = $$pre$i143;
         } else {
          $1305 = HEAP8[$29>>0]|0;
          $1306 = ($1305<<24>>24)==(0);
          if ($1306) {
           $1327 = $2677;
          } else {
           label = 364;
           break L16;
          }
         }
         $1326 = (($1327) + -1)|0;
         HEAP32[$84>>2] = $1326;
         $1328 = ($1326|0)>(0);
         $$pre457 = HEAP32[$28>>2]|0;
         if (!($1328)) {
          $1329 = $$pre457;
          break L580;
         }
         $$pre458 = HEAP32[$30>>2]|0;
         $1297 = $$pre457;$1299 = $$pre458;$2677 = $1326;
        }
       } else {
        $1329 = $176;
       }
      } else {
       label = 359;
      }
     }
    } while(0);
    if ((label|0) == 359) {
     label = 0;
     $1293 = HEAP8[$29>>0]|0;
     $1294 = ($1293<<24>>24)==(0);
     if ($1294) {
      $1329 = $176;
     } else {
      HEAP32[$34>>2] = 134;
      $1329 = $176;
     }
    }
    HEAP32[$84>>2] = 1;
    HEAP32[$31>>2] = $1329;
    label = 762;
    break;
   }
   case 59: case 58:  {
    $1219 = HEAP32[$180>>2]|0;
    $1220 = $1219&65535;
    $1221 = $1219 & 65535;
    $1222 = HEAP16[$36>>1]|0;
    $1223 = $1222&65535;
    $1224 = ($1221>>>0)<($1223>>>0);
    if ($1224) {
     $1225 = HEAP16[$38>>1]|0;
     $1226 = $1225&65535;
     $1227 = HEAP16[$39>>1]|0;
     $1228 = ($1225&65535)<($1227&65535);
     if ($1228) {
      $1231 = HEAP16[$42>>1]|0;
      $1232 = ($1231<<16>>16)==(0);
      if ($1232) {
       $1233 = HEAP32[$45>>2]|0;
       $1234 = (($1233) + ($1221<<3)|0);
       $1235 = HEAP32[$43>>2]|0;
       $1236 = (($1235) + ($1226<<3)|0);
       $1237 = $1236;
       $1238 = $1237;
       $1239 = HEAP32[$1238>>2]|0;
       $1240 = (($1237) + 4)|0;
       $1241 = $1240;
       $1242 = HEAP32[$1241>>2]|0;
       $1243 = $1234;
       $1244 = $1243;
       HEAP32[$1244>>2] = $1239;
       $1245 = (($1243) + 4)|0;
       $1246 = $1245;
       HEAP32[$1246>>2] = $1242;
       $1247 = HEAP32[$108>>2]|0;
       $$sum272 = (($176) + 1)|0;
       $1248 = (($179) + ($$sum272<<2)|0);
       $1249 = HEAP32[$1248>>2]|0;
       FUNCTION_TABLE_viiii[$1247 & 511]($exc,$35,$1220,$1249);
       $1250 = HEAP32[$47>>2]|0;
       $1251 = (($1250) + ($1221<<3)|0);
       $1252 = HEAP32[$45>>2]|0;
       $1253 = (($1252) + ($1221<<3)|0);
       $1254 = $1253;
       $1255 = $1254;
       $1256 = HEAP32[$1255>>2]|0;
       $1257 = (($1254) + 4)|0;
       $1258 = $1257;
       $1259 = HEAP32[$1258>>2]|0;
       $1260 = $1251;
       $1261 = $1260;
       HEAP32[$1261>>2] = $1256;
       $1262 = (($1260) + 4)|0;
       $1263 = $1262;
       HEAP32[$1263>>2] = $1259;
       $$pre$i139 = HEAP16[$38>>1]|0;
       $$pre$phi3$iZ2D = $1248;$1270 = $$pre$i139;
      } else {
       $$sum271 = (($176) + 1)|0;
       $$pre2$i137 = (($179) + ($$sum271<<2)|0);
       $$pre$phi3$iZ2D = $$pre2$i137;$1270 = $1225;
      }
      $1264 = HEAP32[$50>>2]|0;
      $1265 = HEAP32[$47>>2]|0;
      $1266 = (($1265) + ($1221<<3)|0);
      $1267 = HEAP32[$1266>>2]|0;
      $1268 = HEAP32[$48>>2]|0;
      $1269 = $1270&65535;
      $1271 = (($1268) + ($1269<<3)|0);
      $1272 = HEAP32[$1271>>2]|0;
      $1273 = (($1267) - ($1272))|0;
      $1274 = ((($1265) + ($1221<<3)|0) + 4|0);
      $1275 = HEAP32[$1274>>2]|0;
      $1276 = ((($1268) + ($1269<<3)|0) + 4|0);
      $1277 = HEAP32[$1276>>2]|0;
      $1278 = (($1275) - ($1277))|0;
      $1279 = (FUNCTION_TABLE_iiii[$1264 & 2047]($exc,$1273,$1278)|0);
      $1280 = HEAP32[$52>>2]|0;
      $1281 = HEAP32[$$pre$phi3$iZ2D>>2]|0;
      $1282 = (($1281) - ($1279))|0;
      FUNCTION_TABLE_viiii[$1280 & 511]($exc,$35,$1220,$1282);
      $1283 = HEAP16[$38>>1]|0;
      HEAP16[$56>>1] = $1283;
      HEAP16[$57>>1] = $1220;
      $1284 = HEAP8[$24>>0]|0;
      $1285 = $1284 & 1;
      $1286 = ($1285<<24>>24)==(0);
      if ($1286) {
       label = 762;
       break L33;
      }
      HEAP16[$38>>1] = $1220;
      label = 762;
      break L33;
     }
    }
    $1229 = HEAP8[$29>>0]|0;
    $1230 = ($1229<<24>>24)==(0);
    if ($1230) {
     label = 762;
    } else {
     label = 351;
     break L16;
    }
    break;
   }
   case 71: case 70:  {
    $1510 = HEAP32[$180>>2]|0;
    $1511 = HEAP16[$74>>1]|0;
    $1512 = $1511&65535;
    $1513 = ($1510>>>0)<($1512>>>0);
    do {
     if ($1513) {
      $1516 = $171 & 1;
      $1517 = ($1516<<24>>24)==(0);
      if ($1517) {
       $1525 = HEAP32[$50>>2]|0;
       $1526 = HEAP32[$75>>2]|0;
       $1527 = (($1526) + ($1510<<3)|0);
       $1528 = HEAP32[$1527>>2]|0;
       $1529 = ((($1526) + ($1510<<3)|0) + 4|0);
       $1530 = HEAP32[$1529>>2]|0;
       $1531 = (FUNCTION_TABLE_iiii[$1525 & 2047]($exc,$1528,$1530)|0);
       $R$0$i = $1531;
       break;
      } else {
       $1518 = HEAP32[$49>>2]|0;
       $1519 = HEAP32[$106>>2]|0;
       $1520 = (($1519) + ($1510<<3)|0);
       $1521 = HEAP32[$1520>>2]|0;
       $1522 = ((($1519) + ($1510<<3)|0) + 4|0);
       $1523 = HEAP32[$1522>>2]|0;
       $1524 = (FUNCTION_TABLE_iiii[$1518 & 2047]($exc,$1521,$1523)|0);
       $R$0$i = $1524;
       break;
      }
     } else {
      $1514 = HEAP8[$29>>0]|0;
      $1515 = ($1514<<24>>24)==(0);
      if ($1515) {
       $R$0$i = 0;
      } else {
       HEAP32[$34>>2] = 134;
       $R$0$i = 0;
      }
     }
    } while(0);
    HEAP32[$180>>2] = $R$0$i;
    label = 762;
    break;
   }
   case 66:  {
    $1476 = HEAP32[$180>>2]|0;
    $1477 = HEAP16[$109>>1]|0;
    $1478 = $1477&65535;
    $1479 = ($1476>>>0)<($1478>>>0);
    if ($1479) {
     $$sum18 = (($176) + 1)|0;
     $1482 = (($179) + ($$sum18<<2)|0);
     $1483 = HEAP32[$1482>>2]|0;
     $1484 = HEAP32[$110>>2]|0;
     $1485 = (($1484) + ($1476<<2)|0);
     HEAP32[$1485>>2] = $1483;
     label = 762;
     break L33;
    } else {
     $1480 = HEAP8[$29>>0]|0;
     $1481 = ($1480<<24>>24)==(0);
     if ($1481) {
      label = 762;
      break L33;
     } else {
      label = 395;
      break L16;
     }
    }
    break;
   }
   case 67:  {
    $1486 = HEAP32[$180>>2]|0;
    $1487 = HEAP16[$109>>1]|0;
    $1488 = $1487&65535;
    $1489 = ($1486>>>0)<($1488>>>0);
    if ($1489) {
     $1492 = HEAP32[$110>>2]|0;
     $1493 = (($1492) + ($1486<<2)|0);
     $1494 = HEAP32[$1493>>2]|0;
     HEAP32[$180>>2] = $1494;
     label = 762;
     break L33;
    }
    $1490 = HEAP8[$29>>0]|0;
    $1491 = ($1490<<24>>24)==(0);
    if (!($1491)) {
     label = 395;
     break L16;
    }
    HEAP32[$180>>2] = 0;
    label = 762;
    break;
   }
   case 69:  {
    $1503 = HEAP32[$180>>2]|0;
    $1504 = HEAP32[$37>>2]|0;
    $1505 = ($1503>>>0)<($1504>>>0);
    if ($1505) {
     $1508 = HEAP32[$6>>2]|0;
     $1509 = (FUNCTION_TABLE_iii[$1508 & 4095]($exc,$1503)|0);
     HEAP32[$180>>2] = $1509;
     label = 762;
     break L33;
    }
    $1506 = HEAP8[$29>>0]|0;
    $1507 = ($1506<<24>>24)==(0);
    if (!($1507)) {
     label = 395;
     break L16;
    }
    HEAP32[$180>>2] = 0;
    label = 762;
    break;
   }
   case 64:  {
    $1422 = HEAP32[$22>>2]|0;
    $1423 = (($1422) + 1)|0;
    $1424 = (($129) + ($1423)|0);
    $1425 = HEAP8[$1424>>0]|0;
    $1426 = $1425&255;
    $1427 = (($177) + 1)|0;
    $1428 = HEAP32[$27>>2]|0;
    $1429 = (($1427) - ($1428))|0;
    $1430 = ($1426>>>0)<($1429>>>0);
    if (!($1430)) {
     label = 383;
     break L16;
    }
    $1431 = ($1425<<24>>24)==(0);
    if (!($1431)) {
     $1432 = (($1422) + 2)|0;
     $1433 = (($129) + ($1432)|0);
     $1434 = HEAP8[$1433>>0]|0;
     $1435 = $1434&255;
     $1436 = (($176) + -1)|0;
     HEAP32[$180>>2] = $1435;
     $1437 = ($1425&255)<(2);
     if (!($1437)) {
      $1440 = 2;$K$01$i156304 = 2;
      while(1) {
       $$pre$i158 = HEAP32[$22>>2]|0;
       $phitmp$i159 = (($K$01$i156304) + 1)<<16>>16;
       $1438 = (($$pre$i158) + 1)|0;
       $1439 = (($1438) + ($1440))|0;
       $1441 = (($129) + ($1439)|0);
       $1442 = HEAP8[$1441>>0]|0;
       $1443 = $1442&255;
       $$sum269 = (($1436) + ($1440))|0;
       $1444 = (($179) + ($$sum269<<2)|0);
       HEAP32[$1444>>2] = $1443;
       $1445 = $phitmp$i159&65535;
       $1446 = ($1445>>>0)>($1426>>>0);
       if ($1446) {
        break;
       } else {
        $1440 = $1445;$K$01$i156304 = $phitmp$i159;
       }
      }
     }
    }
    $1447 = (($175) + ($1426))|0;
    HEAP32[$31>>2] = $1447;
    label = 762;
    break;
   }
   case 65:  {
    $1448 = HEAP32[$22>>2]|0;
    $1449 = (($1448) + 1)|0;
    $1450 = (($129) + ($1449)|0);
    $1451 = HEAP8[$1450>>0]|0;
    $1452 = $1451&255;
    $1453 = (($177) + 1)|0;
    $1454 = HEAP32[$27>>2]|0;
    $1455 = (($1453) - ($1454))|0;
    $1456 = ($1452>>>0)<($1455>>>0);
    if (!($1456)) {
     label = 387;
     break L16;
    }
    $1457 = (($1448) + 2)|0;
    HEAP32[$22>>2] = $1457;
    $1458 = ($1451<<24>>24)==(0);
    L636: do {
     if (!($1458)) {
      $1460 = $1457;$1471 = 0;$K$01$i162 = 1;
      while(1) {
       $1459 = (($1460) + 2)|0;
       HEAP32[$22>>2] = $1459;
       $1461 = (($129) + ($1460)|0);
       $1462 = HEAP8[$1461>>0]|0;
       $1463 = $1462&255;
       $1464 = $1463 << 8;
       $1465 = (($1460) + 1)|0;
       $1466 = (($129) + ($1465)|0);
       $1467 = HEAP8[$1466>>0]|0;
       $1468 = $1467&255;
       $1469 = $1464 | $1468;
       $sext$i163 = $1469 << 16;
       $1470 = $sext$i163 >> 16;
       $$sum268 = (($1471) + ($176))|0;
       $1472 = (($179) + ($$sum268<<2)|0);
       HEAP32[$1472>>2] = $1470;
       $1473 = $K$01$i162&65535;
       $1474 = ($1473>>>0)<($1452>>>0);
       if (!($1474)) {
        break L636;
       }
       $$pre$i165 = HEAP32[$22>>2]|0;
       $phitmp$i166 = (($K$01$i162) + 1)<<16>>16;
       $1460 = $$pre$i165;$1471 = $1473;$K$01$i162 = $phitmp$i166;
      }
     }
    } while(0);
    HEAP8[$33>>0] = 0;
    $1475 = (($175) + ($1452))|0;
    HEAP32[$31>>2] = $1475;
    label = 762;
    break;
   }
   case 72:  {
    $1532 = HEAP32[$180>>2]|0;
    $1533 = $1532 & 65535;
    $1534 = HEAP16[$74>>1]|0;
    $1535 = $1534&65535;
    $1536 = ($1533>>>0)<($1535>>>0);
    if (!($1536)) {
     $1537 = HEAP8[$29>>0]|0;
     $1538 = ($1537<<24>>24)==(0);
     if ($1538) {
      label = 762;
      break L33;
     } else {
      label = 416;
      break L16;
     }
    }
    $1539 = $1532&65535;
    $1540 = HEAP32[$50>>2]|0;
    $1541 = HEAP32[$75>>2]|0;
    $1542 = (($1541) + ($1533<<3)|0);
    $1543 = HEAP32[$1542>>2]|0;
    $1544 = ((($1541) + ($1533<<3)|0) + 4|0);
    $1545 = HEAP32[$1544>>2]|0;
    $1546 = (FUNCTION_TABLE_iiii[$1540 & 2047]($exc,$1543,$1545)|0);
    $1547 = HEAP32[$52>>2]|0;
    $$sum267 = (($176) + 1)|0;
    $1548 = (($179) + ($$sum267<<2)|0);
    $1549 = HEAP32[$1548>>2]|0;
    $1550 = (($1549) - ($1546))|0;
    FUNCTION_TABLE_viiii[$1547 & 511]($exc,$82,$1539,$1550);
    $1551 = HEAP16[$83>>1]|0;
    $1552 = ($1551<<16>>16)==(0);
    if ($1552) {
     $1553 = HEAP32[$106>>2]|0;
     $1554 = (($1553) + ($1533<<3)|0);
     $1555 = HEAP32[$75>>2]|0;
     $1556 = (($1555) + ($1533<<3)|0);
     $1557 = $1556;
     $1558 = $1557;
     $1559 = HEAP32[$1558>>2]|0;
     $1560 = (($1557) + 4)|0;
     $1561 = $1560;
     $1562 = HEAP32[$1561>>2]|0;
     $1563 = $1554;
     $1564 = $1563;
     HEAP32[$1564>>2] = $1559;
     $1565 = (($1563) + 4)|0;
     $1566 = $1565;
     HEAP32[$1566>>2] = $1562;
     label = 762;
    } else {
     label = 762;
    }
    break;
   }
   case 68:  {
    $1495 = HEAP32[$180>>2]|0;
    $1496 = HEAP32[$37>>2]|0;
    $1497 = ($1495>>>0)<($1496>>>0);
    if ($1497) {
     $1500 = HEAP32[$111>>2]|0;
     $$sum17 = (($176) + 1)|0;
     $1501 = (($179) + ($$sum17<<2)|0);
     $1502 = HEAP32[$1501>>2]|0;
     FUNCTION_TABLE_viii[$1500 & 4095]($exc,$1495,$1502);
     label = 762;
     break L33;
    } else {
     $1498 = HEAP8[$29>>0]|0;
     $1499 = ($1498<<24>>24)==(0);
     if ($1499) {
      label = 762;
      break L33;
     } else {
      label = 395;
      break L16;
     }
    }
    break;
   }
   case 74: case 73:  {
    $1567 = HEAP32[$180>>2]|0;
    $1568 = $1567 & 65535;
    $1569 = HEAP16[$39>>1]|0;
    $1570 = $1569&65535;
    $1571 = ($1568>>>0)<($1570>>>0);
    do {
     if ($1571) {
      $$sum266 = (($176) + 1)|0;
      $1572 = (($179) + ($$sum266<<2)|0);
      $1573 = HEAP32[$1572>>2]|0;
      $1574 = $1573 & 65535;
      $1575 = HEAP16[$36>>1]|0;
      $1576 = $1575&65535;
      $1577 = ($1574>>>0)<($1576>>>0);
      if ($1577) {
       $1580 = $171 & 1;
       $1581 = ($1580<<24>>24)==(0);
       if (!($1581)) {
        $1582 = HEAP32[$50>>2]|0;
        $1583 = HEAP32[$48>>2]|0;
        $1584 = (($1583) + ($1568<<3)|0);
        $1585 = HEAP32[$1584>>2]|0;
        $1586 = HEAP32[$47>>2]|0;
        $1587 = (($1586) + ($1574<<3)|0);
        $1588 = HEAP32[$1587>>2]|0;
        $1589 = (($1585) - ($1588))|0;
        $1590 = ((($1583) + ($1568<<3)|0) + 4|0);
        $1591 = HEAP32[$1590>>2]|0;
        $1592 = ((($1586) + ($1574<<3)|0) + 4|0);
        $1593 = HEAP32[$1592>>2]|0;
        $1594 = (($1591) - ($1593))|0;
        $1595 = (FUNCTION_TABLE_iiii[$1582 & 2047]($exc,$1589,$1594)|0);
        $D$0$i = $1595;
        break;
       }
       $1596 = HEAP16[$54>>1]|0;
       $1597 = ($1596<<16>>16)==(0);
       if (!($1597)) {
        $1598 = HEAP16[$42>>1]|0;
        $1599 = ($1598<<16>>16)==(0);
        if (!($1599)) {
         $1614 = HEAP32[$59>>2]|0;
         $1615 = (($1614) + ($1568<<3)|0);
         $1616 = HEAP32[$58>>2]|0;
         $1617 = (($1616) + ($1574<<3)|0);
         $1618 = HEAP32[$60>>2]|0;
         $1619 = HEAP32[$61>>2]|0;
         $1620 = ($1618|0)==($1619|0);
         if ($1620) {
          $1621 = HEAP32[$49>>2]|0;
          $1622 = HEAP32[$1615>>2]|0;
          $1623 = HEAP32[$1617>>2]|0;
          $1624 = (($1622) - ($1623))|0;
          $1625 = ((($1614) + ($1568<<3)|0) + 4|0);
          $1626 = HEAP32[$1625>>2]|0;
          $1627 = ((($1616) + ($1574<<3)|0) + 4|0);
          $1628 = HEAP32[$1627>>2]|0;
          $1629 = (($1626) - ($1628))|0;
          $1630 = (FUNCTION_TABLE_iiii[$1621 & 2047]($exc,$1624,$1629)|0);
          $1631 = HEAP32[$60>>2]|0;
          $1632 = (_FT_MulFix($1630,$1631)|0);
          $D$0$i = $1632;
          break;
         } else {
          $1633 = HEAP32[$1615>>2]|0;
          $1634 = HEAP32[$1617>>2]|0;
          $1635 = (($1633) - ($1634))|0;
          $1636 = (_FT_MulFix($1635,$1618)|0);
          $1637 = ((($1614) + ($1568<<3)|0) + 4|0);
          $1638 = HEAP32[$1637>>2]|0;
          $1639 = ((($1616) + ($1574<<3)|0) + 4|0);
          $1640 = HEAP32[$1639>>2]|0;
          $1641 = (($1638) - ($1640))|0;
          $1642 = HEAP32[$61>>2]|0;
          $1643 = (_FT_MulFix($1641,$1642)|0);
          $1644 = HEAP32[$49>>2]|0;
          $1645 = (FUNCTION_TABLE_iiii[$1644 & 2047]($exc,$1636,$1643)|0);
          $D$0$i = $1645;
          break;
         }
        }
       }
       $1600 = HEAP32[$43>>2]|0;
       $1601 = HEAP32[$45>>2]|0;
       $1602 = HEAP32[$49>>2]|0;
       $1603 = (($1600) + ($1568<<3)|0);
       $1604 = HEAP32[$1603>>2]|0;
       $1605 = (($1601) + ($1574<<3)|0);
       $1606 = HEAP32[$1605>>2]|0;
       $1607 = (($1604) - ($1606))|0;
       $1608 = ((($1600) + ($1568<<3)|0) + 4|0);
       $1609 = HEAP32[$1608>>2]|0;
       $1610 = ((($1601) + ($1574<<3)|0) + 4|0);
       $1611 = HEAP32[$1610>>2]|0;
       $1612 = (($1609) - ($1611))|0;
       $1613 = (FUNCTION_TABLE_iiii[$1602 & 2047]($exc,$1607,$1612)|0);
       $D$0$i = $1613;
      } else {
       label = 421;
      }
     } else {
      label = 421;
     }
    } while(0);
    if ((label|0) == 421) {
     label = 0;
     $1578 = HEAP8[$29>>0]|0;
     $1579 = ($1578<<24>>24)==(0);
     if ($1579) {
      $D$0$i = 0;
     } else {
      HEAP32[$34>>2] = 134;
      $D$0$i = 0;
     }
    }
    HEAP32[$180>>2] = $D$0$i;
    label = 762;
    break;
   }
   case 94:  {
    $1734 = HEAP32[$180>>2]|0;
    $1735 = $1734&65535;
    HEAP16[$112>>1] = $1735;
    label = 762;
    break;
   }
   case 95:  {
    $1736 = HEAP32[$180>>2]|0;
    $1737 = $1736&65535;
    HEAP16[$113>>1] = $1737;
    label = 762;
    break;
   }
   case 96:  {
    $$sum8 = (($176) + 1)|0;
    $1738 = (($179) + ($$sum8<<2)|0);
    $1739 = HEAP32[$1738>>2]|0;
    $1740 = HEAP32[$180>>2]|0;
    $1741 = (($1740) + ($1739))|0;
    HEAP32[$180>>2] = $1741;
    label = 762;
    break;
   }
   case 93:  {
    $$val44 = HEAP32[$180>>2]|0;
    _Ins_DELTAP($exc,$$val44);
    label = 762;
    break;
   }
   case 98:  {
    $$sum6 = (($176) + 1)|0;
    $1746 = (($179) + ($$sum6<<2)|0);
    $1747 = HEAP32[$1746>>2]|0;
    $1748 = ($1747|0)==(0);
    if ($1748) {
     label = 471;
     break L16;
    }
    $1749 = HEAP32[$180>>2]|0;
    $1750 = (_FT_MulDiv_No_Round($1749,64,$1747)|0);
    HEAP32[$180>>2] = $1750;
    label = 762;
    break;
   }
   case 97:  {
    $$sum7 = (($176) + 1)|0;
    $1742 = (($179) + ($$sum7<<2)|0);
    $1743 = HEAP32[$1742>>2]|0;
    $1744 = HEAP32[$180>>2]|0;
    $1745 = (($1744) - ($1743))|0;
    HEAP32[$180>>2] = $1745;
    label = 762;
    break;
   }
   case 76:  {
    $1647 = (_Current_Ppem($exc)|0);
    HEAP32[$180>>2] = $1647;
    label = 762;
    break;
   }
   case 87:  {
    $1684 = HEAP32[$$pre$phiZ2D>>2]|0;
    $1685 = HEAP32[$180>>2]|0;
    $1686 = (FUNCTION_TABLE_iiii[$1684 & 2047]($exc,$1685,0)|0);
    $1687 = $1686 & 127;
    $1688 = ($1687|0)==(0);
    $1689 = $1688&1;
    HEAP32[$180>>2] = $1689;
    label = 762;
    break;
   }
   case 88:  {
    $$val42 = HEAP32[$180>>2]|0;
    $1690 = ($$val42|0)==(0);
    if ($1690) {
     $$pre2$i170 = HEAP32[$22>>2]|0;
     $$pre3$i171 = HEAP32[$26>>2]|0;
     $1691 = (($$pre$i169) + ($$pre2$i170))|0;
     HEAP32[$22>>2] = $1691;
     $1692 = ($1691|0)<($$pre3$i171|0);
     if ($1692) {
      $2678 = $1691;$nIfs$0$i173$ph328 = 1;
     } else {
      label = 451;
      break L16;
     }
     while(1) {
      $1693 = ($nIfs$0$i173$ph328|0)==(1);
      $1695 = $2678;
      while(1) {
       $1694 = (($129) + ($1695)|0);
       $1696 = HEAP8[$1694>>0]|0;
       HEAP8[$24>>0] = $1696;
       $1697 = $1696&255;
       $1698 = (873192 + ($1697)|0);
       $1699 = HEAP8[$1698>>0]|0;
       $1700 = $1699 << 24 >> 24;
       HEAP32[$25>>2] = $1700;
       $1701 = $1697 & 254;
       $1702 = ($1701|0)==(64);
       if ($1702) {
        $1703 = (($1695) + 1)|0;
        $1704 = (($129) + ($1703)|0);
        $1705 = HEAP8[$1704>>0]|0;
        $1706 = $1705&255;
        $1707 = Math_imul($1706, $1700)|0;
        $1708 = (2 - ($1707))|0;
        HEAP32[$25>>2] = $1708;
        $1710 = $1708;
       } else {
        $1710 = $1700;
       }
       $1709 = (($1710) + ($1695))|0;
       $1711 = ($1709|0)>($$pre3$i171|0);
       if ($1711) {
        label = 451;
        break L16;
       }
       if ((($1697|0) == 27)) {
        if ($1693) {
         label = 762;
         break L33;
        }
       } else if ((($1697|0) == 89)) {
        label = 456;
        break;
       } else if ((($1697|0) == 88)) {
        label = 454;
        break;
       }
       HEAP32[$22>>2] = $1709;
       $1712 = ($1709|0)<($$pre3$i171|0);
       if ($1712) {
        $1695 = $1709;
       } else {
        label = 451;
        break L16;
       }
      }
      if ((label|0) == 454) {
       label = 0;
       $1713 = (($nIfs$0$i173$ph328) + 1)|0;
       $nIfs$0$i173$ph$be = $1713;
      }
      else if ((label|0) == 456) {
       label = 0;
       $1714 = (($nIfs$0$i173$ph328) + -1)|0;
       $1715 = ($1714|0)==(0);
       if ($1715) {
        label = 762;
        break L33;
       } else {
        $nIfs$0$i173$ph$be = $1714;
       }
      }
      HEAP32[$22>>2] = $1709;
      $1716 = ($1709|0)<($$pre3$i171|0);
      if ($1716) {
       $2678 = $1709;$nIfs$0$i173$ph328 = $nIfs$0$i173$ph$be;
      } else {
       label = 451;
       break L16;
      }
     }
    } else {
     label = 762;
    }
    break;
   }
   case 75:  {
    $1646 = (_Current_Ppem($exc)|0);
    HEAP32[$180>>2] = $1646;
    label = 762;
    break;
   }
   case 83:  {
    $1663 = HEAP32[$180>>2]|0;
    $$sum13 = (($176) + 1)|0;
    $1664 = (($179) + ($$sum13<<2)|0);
    $1665 = HEAP32[$1664>>2]|0;
    $1666 = ($1663|0)>=($1665|0);
    $1667 = $1666&1;
    HEAP32[$180>>2] = $1667;
    label = 762;
    break;
   }
   case 79:  {
    label = 436;
    break L16;
    break;
   }
   case 82:  {
    $1658 = HEAP32[$180>>2]|0;
    $$sum14 = (($176) + 1)|0;
    $1659 = (($179) + ($$sum14<<2)|0);
    $1660 = HEAP32[$1659>>2]|0;
    $1661 = ($1658|0)>($1660|0);
    $1662 = $1661&1;
    HEAP32[$180>>2] = $1662;
    label = 762;
    break;
   }
   case 78:  {
    HEAP8[$51>>0] = 0;
    label = 762;
    break;
   }
   case 84:  {
    $1668 = HEAP32[$180>>2]|0;
    $$sum12 = (($176) + 1)|0;
    $1669 = (($179) + ($$sum12<<2)|0);
    $1670 = HEAP32[$1669>>2]|0;
    $1671 = ($1668|0)==($1670|0);
    $1672 = $1671&1;
    HEAP32[$180>>2] = $1672;
    label = 762;
    break;
   }
   case 86:  {
    $1678 = HEAP32[$$pre$phiZ2D>>2]|0;
    $1679 = HEAP32[$180>>2]|0;
    $1680 = (FUNCTION_TABLE_iiii[$1678 & 2047]($exc,$1679,0)|0);
    $1681 = $1680 & 127;
    $1682 = ($1681|0)==(64);
    $1683 = $1682&1;
    HEAP32[$180>>2] = $1683;
    label = 762;
    break;
   }
   case 85:  {
    $1673 = HEAP32[$180>>2]|0;
    $$sum11 = (($176) + 1)|0;
    $1674 = (($179) + ($$sum11<<2)|0);
    $1675 = HEAP32[$1674>>2]|0;
    $1676 = ($1673|0)!=($1675|0);
    $1677 = $1676&1;
    HEAP32[$180>>2] = $1677;
    label = 762;
    break;
   }
   case 90:  {
    $1717 = HEAP32[$180>>2]|0;
    $1718 = ($1717|0)==(0);
    if ($1718) {
     $1723 = 0;
    } else {
     $$sum10 = (($176) + 1)|0;
     $1719 = (($179) + ($$sum10<<2)|0);
     $1720 = HEAP32[$1719>>2]|0;
     $1721 = ($1720|0)!=(0);
     $1723 = $1721;
    }
    $1722 = $1723&1;
    HEAP32[$180>>2] = $1722;
    label = 762;
    break;
   }
   case 91:  {
    $1724 = HEAP32[$180>>2]|0;
    $1725 = ($1724|0)==(0);
    if ($1725) {
     $$sum9 = (($176) + 1)|0;
     $1726 = (($179) + ($$sum9<<2)|0);
     $1727 = HEAP32[$1726>>2]|0;
     $1728 = ($1727|0)!=(0);
     $1730 = $1728;
    } else {
     $1730 = 1;
    }
    $1729 = $1730&1;
    HEAP32[$180>>2] = $1729;
    label = 762;
    break;
   }
   case 92:  {
    $1731 = HEAP32[$180>>2]|0;
    $1732 = ($1731|0)==(0);
    $1733 = $1732&1;
    HEAP32[$180>>2] = $1733;
    label = 762;
    break;
   }
   case 77:  {
    HEAP8[$51>>0] = 1;
    label = 762;
    break;
   }
   case 81:  {
    $1653 = HEAP32[$180>>2]|0;
    $$sum15 = (($176) + 1)|0;
    $1654 = (($179) + ($$sum15<<2)|0);
    $1655 = HEAP32[$1654>>2]|0;
    $1656 = ($1653|0)<=($1655|0);
    $1657 = $1656&1;
    HEAP32[$180>>2] = $1657;
    label = 762;
    break;
   }
   case 80:  {
    $1648 = HEAP32[$180>>2]|0;
    $$sum16 = (($176) + 1)|0;
    $1649 = (($179) + ($$sum16<<2)|0);
    $1650 = HEAP32[$1649>>2]|0;
    $1651 = ($1648|0)<($1650|0);
    $1652 = $1651&1;
    HEAP32[$180>>2] = $1652;
    label = 762;
    break;
   }
   case 103:  {
    $1763 = HEAP32[$180>>2]|0;
    $1764 = (($1763) + 63)|0;
    $1765 = $1764 & -64;
    HEAP32[$180>>2] = $1765;
    label = 762;
    break;
   }
   case 118:  {
    $1834 = HEAP32[$180>>2]|0;
    $1835 = $1834 & 192;
    if ((($1835|0) == 128)) {
     HEAP32[$117>>2] = 32768;
    } else if ((($1835|0) == 0)) {
     HEAP32[$117>>2] = 8192;
    } else if ((($1835|0) == 192)) {
     HEAP32[$117>>2] = 16384;
    } else if ((($1835|0) == 64)) {
     HEAP32[$117>>2] = 16384;
    }
    $1836 = $1834 & 48;
    if ((($1836|0) == 32)) {
     $1839 = HEAP32[$117>>2]|0;
     $1840 = (($1839|0) / 2)&-1;
     HEAP32[$119>>2] = $1840;
    } else if ((($1836|0) == 48)) {
     $1841 = HEAP32[$117>>2]|0;
     $1842 = ($1841*3)|0;
     $1843 = (($1842|0) / 4)&-1;
     HEAP32[$119>>2] = $1843;
    } else if ((($1836|0) == 0)) {
     HEAP32[$119>>2] = 0;
    } else if ((($1836|0) == 16)) {
     $1837 = HEAP32[$117>>2]|0;
     $1838 = (($1837|0) / 4)&-1;
     HEAP32[$119>>2] = $1838;
    }
    $1844 = $1834 & 15;
    $1845 = ($1844|0)==(0);
    if ($1845) {
     $1846 = HEAP32[$117>>2]|0;
     $1847 = (($1846) + -1)|0;
     $1853 = $1846;$1857 = $1847;
    } else {
     $1848 = (($1844) + -4)|0;
     $1849 = HEAP32[$117>>2]|0;
     $1850 = Math_imul($1849, $1848)|0;
     $1851 = (($1850|0) / 8)&-1;
     $1853 = $1849;$1857 = $1851;
    }
    $1852 = (($1853|0) / 256)&-1;
    HEAP32[$117>>2] = $1852;
    $1854 = HEAP32[$119>>2]|0;
    $1855 = (($1854|0) / 256)&-1;
    HEAP32[$119>>2] = $1855;
    $1856 = (($1857|0) / 256)&-1;
    HEAP32[$118>>2] = $1856;
    HEAP32[$11>>2] = 6;
    HEAP32[$$pre$phiZ2D>>2] = 1622;
    label = 762;
    break;
   }
   case 100:  {
    $1755 = HEAP32[$180>>2]|0;
    $1756 = ($1755|0)<(0);
    $1757 = (0 - ($1755))|0;
    $1758 = $1756 ? $1757 : $1755;
    HEAP32[$180>>2] = $1758;
    label = 762;
    break;
   }
   case 107: case 106: case 105: case 104:  {
    $1766 = HEAP32[$$pre$phiZ2D>>2]|0;
    $1767 = HEAP32[$180>>2]|0;
    $1768 = (($170) + -104)|0;
    $1769 = ((($exc) + ($1768<<2)|0) + 264|0);
    $1770 = HEAP32[$1769>>2]|0;
    $1771 = (FUNCTION_TABLE_iiii[$1766 & 2047]($exc,$1767,$1770)|0);
    HEAP32[$180>>2] = $1771;
    label = 762;
    break;
   }
   case 99:  {
    $1751 = HEAP32[$180>>2]|0;
    $$sum5 = (($176) + 1)|0;
    $1752 = (($179) + ($$sum5<<2)|0);
    $1753 = HEAP32[$1752>>2]|0;
    $1754 = (_FT_MulDiv($1751,$1753,64)|0);
    HEAP32[$180>>2] = $1754;
    label = 762;
    break;
   }
   case 101:  {
    $1759 = HEAP32[$180>>2]|0;
    $1760 = (0 - ($1759))|0;
    HEAP32[$180>>2] = $1760;
    label = 762;
    break;
   }
   case 114: case 113:  {
    $$val43 = HEAP32[$180>>2]|0;
    _Ins_DELTAP($exc,$$val43);
    label = 762;
    break;
   }
   case 111: case 110: case 109: case 108:  {
    $1772 = HEAP32[$180>>2]|0;
    $1773 = (($170) + -108)|0;
    $1774 = ((($exc) + ($1773<<2)|0) + 264|0);
    $1775 = HEAP32[$1774>>2]|0;
    $1776 = ($1772|0)>(-1);
    if ($1776) {
     $1777 = (($1775) + ($1772))|0;
     $1778 = ($1772|0)!=(0);
     $1779 = ($1777|0)<(0);
     $or$cond$i176 = $1778 & $1779;
     $$1$i = $or$cond$i176 ? 0 : $1777;
     $1782 = $$1$i;
    } else {
     $1780 = (($1772) - ($1775))|0;
     $1781 = ($1780|0)>(0);
     $$$i177 = $1781 ? 0 : $1780;
     $1782 = $$$i177;
    }
    HEAP32[$180>>2] = $1782;
    label = 762;
    break;
   }
   case 112:  {
    $1783 = HEAP32[$180>>2]|0;
    $1784 = HEAP32[$37>>2]|0;
    $1785 = ($1783>>>0)<($1784>>>0);
    if ($1785) {
     $$sum4 = (($176) + 1)|0;
     $1788 = (($179) + ($$sum4<<2)|0);
     $1789 = HEAP32[$1788>>2]|0;
     $1790 = HEAP32[$114>>2]|0;
     $1791 = (_FT_MulFix($1789,$1790)|0);
     $1792 = HEAP32[$115>>2]|0;
     $1793 = (($1792) + ($1783<<2)|0);
     HEAP32[$1793>>2] = $1791;
     label = 762;
     break L33;
    } else {
     $1786 = HEAP8[$29>>0]|0;
     $1787 = ($1786<<24>>24)==(0);
     if ($1787) {
      label = 762;
      break L33;
     } else {
      label = 395;
      break L16;
     }
    }
    break;
   }
   case 102:  {
    $1761 = HEAP32[$180>>2]|0;
    $1762 = $1761 & -64;
    HEAP32[$180>>2] = $1762;
    label = 762;
    break;
   }
   case 117: case 116: case 115:  {
    $$val45 = HEAP32[$180>>2]|0;
    $1794 = ($$val45|0)==(0);
    L747: do {
     if ($1794) {
      $1833 = $176;
     } else {
      $1795 = ($176|0)<(2);
      L749: do {
       if (!($1795)) {
        $1800 = $176;$1803 = $179;$k$02$i292 = 2;
        while(1) {
         $1799 = (($1800) + -2)|0;
         HEAP32[$28>>2] = $1799;
         $1801 = (($1800) + -1)|0;
         $1802 = (($1803) + ($1801<<2)|0);
         $1804 = HEAP32[$1802>>2]|0;
         $1805 = (($1803) + ($1799<<2)|0);
         $1806 = HEAP32[$1805>>2]|0;
         $1807 = HEAP32[$37>>2]|0;
         $1808 = ($1804>>>0)<($1807>>>0);
         if ($1808) {
          $1811 = $1806 >>> 4;
          $1812 = $1811 & 15;
          $1813 = HEAP8[$24>>0]|0;
          $1814 = $1813&255;
          if ((($1814|0) == 117)) {
           $1816 = $1812 | 32;
           $C$0$i = $1816;
          } else if ((($1814|0) == 116)) {
           $1815 = $1812 | 16;
           $C$0$i = $1815;
          } else {
           $C$0$i = $1812;
          }
          $1817 = HEAP16[$112>>1]|0;
          $1818 = $1817 << 16 >> 16;
          $1819 = (($1818) + ($C$0$i))|0;
          $1820 = (_Current_Ppem($exc)|0);
          $1821 = ($1820|0)==($1819|0);
          if ($1821) {
           $1822 = $1806 & 15;
           $1823 = (($1822) + -8)|0;
           $1824 = ($1823|0)>(-1);
           $1825 = (($1822) + -7)|0;
           $$$i179 = $1824 ? $1825 : $1823;
           $1826 = $$$i179 << 6;
           $1827 = HEAP16[$113>>1]|0;
           $1828 = $1827 << 16 >> 16;
           $1829 = 1 << $1828;
           $1830 = (($1826|0) / ($1829|0))&-1;
           $1831 = HEAP32[$116>>2]|0;
           FUNCTION_TABLE_viii[$1831 & 4095]($exc,$1804,$1830);
          }
         } else {
          $1809 = HEAP8[$29>>0]|0;
          $1810 = ($1809<<24>>24)==(0);
          if (!($1810)) {
           label = 496;
           break L16;
          }
         }
         $1832 = ($k$02$i292>>>0)>($$val45>>>0);
         $$pre$i182$pre = HEAP32[$28>>2]|0;
         if ($1832) {
          $1833 = $$pre$i182$pre;
          break L747;
         }
         $1796 = ($$pre$i182$pre|0)<(2);
         if ($1796) {
          break L749;
         }
         $phitmp$i180 = (($k$02$i292) + 1)|0;
         $$pre459 = HEAP32[$30>>2]|0;
         $1800 = $$pre$i182$pre;$1803 = $$pre459;$k$02$i292 = $phitmp$i180;
        }
       }
      } while(0);
      $1797 = HEAP8[$29>>0]|0;
      $1798 = ($1797<<24>>24)==(0);
      if (!($1798)) {
       HEAP32[$34>>2] = 129;
      }
      HEAP32[$28>>2] = 0;
      $1833 = 0;
     }
    } while(0);
    HEAP32[$31>>2] = $1833;
    label = 762;
    break;
   }
   case 124:  {
    HEAP32[$11>>2] = 4;
    HEAP32[$$pre$phiZ2D>>2] = 1618;
    label = 762;
    break;
   }
   case 125:  {
    HEAP32[$11>>2] = 3;
    HEAP32[$$pre$phiZ2D>>2] = 1619;
    label = 762;
    break;
   }
   case 128:  {
    $1936 = HEAP32[$27>>2]|0;
    $1937 = HEAP32[$84>>2]|0;
    $1938 = ($1936|0)<($1937|0);
    L771: do {
     if ($1938) {
      $1940 = HEAP8[$29>>0]|0;
      $1941 = ($1940<<24>>24)==(0);
      if ($1941) {
       $1962 = $176;
      } else {
       HEAP32[$34>>2] = 129;
       $1962 = $176;
      }
     } else {
      $1939 = ($1937|0)>(0);
      if ($1939) {
       $1943 = $176;$1945 = $179;$2679 = $1937;
       while(1) {
        $1942 = (($1943) + -1)|0;
        HEAP32[$28>>2] = $1942;
        $1944 = (($1945) + ($1942<<2)|0);
        $1946 = HEAP32[$1944>>2]|0;
        $1947 = $1946 & 65535;
        $1948 = HEAP16[$97>>1]|0;
        $1949 = $1948&65535;
        $1950 = ($1947>>>0)<($1949>>>0);
        if ($1950) {
         $1953 = HEAP32[$101>>2]|0;
         $1954 = (($1953) + ($1947)|0);
         $1955 = HEAP8[$1954>>0]|0;
         $1956 = $1955&255;
         $1957 = $1956 ^ 1;
         $1958 = $1957&255;
         HEAP8[$1954>>0] = $1958;
         $$pre$i194 = HEAP32[$84>>2]|0;
         $1960 = $$pre$i194;
        } else {
         $1951 = HEAP8[$29>>0]|0;
         $1952 = ($1951<<24>>24)==(0);
         if ($1952) {
          $1960 = $2679;
         } else {
          label = 568;
          break L16;
         }
        }
        $1959 = (($1960) + -1)|0;
        HEAP32[$84>>2] = $1959;
        $1961 = ($1959|0)>(0);
        $$pre460 = HEAP32[$28>>2]|0;
        if (!($1961)) {
         $1962 = $$pre460;
         break L771;
        }
        $$pre461 = HEAP32[$30>>2]|0;
        $1943 = $$pre460;$1945 = $$pre461;$2679 = $1959;
       }
      } else {
       $1962 = $176;
      }
     }
    } while(0);
    HEAP32[$84>>2] = 1;
    HEAP32[$31>>2] = $1962;
    label = 762;
    break;
   }
   case 122:  {
    HEAP32[$11>>2] = 5;
    HEAP32[$$pre$phiZ2D>>2] = 1616;
    label = 762;
    break;
   }
   case 123:  {
    $1900 = HEAP32[$62>>2]|0;
    $1901 = HEAP32[$63>>2]|0;
    $1902 = (($1900) + ($1901<<4)|0);
    $1903 = ($1901|0)>(0);
    L785: do {
     if ($1903) {
      $def$02$i185 = $1900;
      while(1) {
       $1904 = (($def$02$i185) + 8|0);
       $1905 = HEAP32[$1904>>2]|0;
       $1906 = $1905&255;
       $1907 = ($171<<24>>24)==($1906<<24>>24);
       if ($1907) {
        $1908 = (($def$02$i185) + 12|0);
        $1909 = HEAP8[$1908>>0]|0;
        $1910 = ($1909<<24>>24)==(0);
        if (!($1910)) {
         break;
        }
       }
       $1934 = (($def$02$i185) + 16|0);
       $1935 = ($1934>>>0)<($1902>>>0);
       if ($1935) {
        $def$02$i185 = $1934;
       } else {
        break L785;
       }
      }
      $1911 = HEAP32[$64>>2]|0;
      $1912 = HEAP32[$65>>2]|0;
      $1913 = ($1911|0)<($1912|0);
      if (!($1913)) {
       label = 549;
       break L16;
      }
      $1914 = HEAP32[$66>>2]|0;
      $1915 = (($1911) + 1)|0;
      HEAP32[$64>>2] = $1915;
      $1916 = HEAP32[$67>>2]|0;
      $1917 = (($1914) + ($1911<<4)|0);
      HEAP32[$1917>>2] = $1916;
      $1918 = HEAP32[$22>>2]|0;
      $1919 = (($1918) + 1)|0;
      $1920 = ((($1914) + ($1911<<4)|0) + 4|0);
      HEAP32[$1920>>2] = $1919;
      $1921 = ((($1914) + ($1911<<4)|0) + 8|0);
      HEAP32[$1921>>2] = 1;
      $1922 = (($def$02$i185) + 4|0);
      $1923 = HEAP32[$1922>>2]|0;
      $1924 = ((($1914) + ($1911<<4)|0) + 12|0);
      HEAP32[$1924>>2] = $1923;
      $1925 = HEAP32[$def$02$i185>>2]|0;
      $1926 = HEAP32[$1922>>2]|0;
      $aRange$off$i188 = (($1925) + -1)|0;
      $1927 = ($aRange$off$i188>>>0)>(2);
      do {
       if ($1927) {
        HEAP32[$34>>2] = 132;
       } else {
        $1928 = ((($exc) + ($aRange$off$i188<<3)|0) + 444|0);
        $1929 = HEAP32[$1928>>2]|0;
        $1930 = ($1929|0)==(0|0);
        if ($1930) {
         HEAP32[$34>>2] = 138;
         break;
        }
        $1931 = ((($exc) + ($aRange$off$i188<<3)|0) + 448|0);
        $1932 = HEAP32[$1931>>2]|0;
        $1933 = ($1932>>>0)<($1926>>>0);
        if ($1933) {
         HEAP32[$34>>2] = 131;
         break;
        } else {
         HEAP32[$23>>2] = $1929;
         HEAP32[$26>>2] = $1932;
         HEAP32[$22>>2] = $1926;
         HEAP32[$67>>2] = $1925;
         break;
        }
       }
      } while(0);
      HEAP8[$33>>0] = 0;
      label = 762;
      break L33;
     }
    } while(0);
    HEAP32[$34>>2] = 128;
    $2617 = $1900;$2618 = $1901;
    label = 764;
    break;
   }
   case 119:  {
    $1858 = HEAP32[$180>>2]|0;
    $1859 = $1858 & 192;
    if ((($1859|0) == 192)) {
     HEAP32[$117>>2] = 11585;
    } else if ((($1859|0) == 0)) {
     HEAP32[$117>>2] = 5792;
    } else if ((($1859|0) == 128)) {
     HEAP32[$117>>2] = 23170;
    } else if ((($1859|0) == 64)) {
     HEAP32[$117>>2] = 11585;
    }
    $1860 = $1858 & 48;
    if ((($1860|0) == 0)) {
     HEAP32[$119>>2] = 0;
    } else if ((($1860|0) == 16)) {
     $1861 = HEAP32[$117>>2]|0;
     $1862 = (($1861|0) / 4)&-1;
     HEAP32[$119>>2] = $1862;
    } else if ((($1860|0) == 48)) {
     $1865 = HEAP32[$117>>2]|0;
     $1866 = ($1865*3)|0;
     $1867 = (($1866|0) / 4)&-1;
     HEAP32[$119>>2] = $1867;
    } else if ((($1860|0) == 32)) {
     $1863 = HEAP32[$117>>2]|0;
     $1864 = (($1863|0) / 2)&-1;
     HEAP32[$119>>2] = $1864;
    }
    $1868 = $1858 & 15;
    $1869 = ($1868|0)==(0);
    if ($1869) {
     $1870 = HEAP32[$117>>2]|0;
     $1871 = (($1870) + -1)|0;
     $1877 = $1870;$1881 = $1871;
    } else {
     $1872 = (($1868) + -4)|0;
     $1873 = HEAP32[$117>>2]|0;
     $1874 = Math_imul($1873, $1872)|0;
     $1875 = (($1874|0) / 8)&-1;
     $1877 = $1873;$1881 = $1875;
    }
    $1876 = (($1877|0) / 256)&-1;
    HEAP32[$117>>2] = $1876;
    $1878 = HEAP32[$119>>2]|0;
    $1879 = (($1878|0) / 256)&-1;
    HEAP32[$119>>2] = $1879;
    $1880 = (($1881|0) / 256)&-1;
    HEAP32[$118>>2] = $1880;
    HEAP32[$11>>2] = 7;
    HEAP32[$$pre$phiZ2D>>2] = 1623;
    label = 762;
    break;
   }
   case 120:  {
    $$sum3 = (($176) + 1)|0;
    $1882 = (($179) + ($$sum3<<2)|0);
    $1883 = HEAP32[$1882>>2]|0;
    $1884 = ($1883|0)==(0);
    if ($1884) {
     label = 762;
    } else {
     $1885 = HEAP32[$180>>2]|0;
     $1886 = $1885 | $176;
     $1887 = ($1886|0)==(0);
     if ($1887) {
      HEAP32[$34>>2] = 132;
     }
     $1888 = HEAP32[$22>>2]|0;
     $1889 = (($1888) + ($1885))|0;
     HEAP32[$22>>2] = $1889;
     $1890 = ($1889|0)<(0);
     if ($1890) {
      HEAP32[$34>>2] = 132;
     }
     HEAP8[$33>>0] = 0;
     label = 762;
    }
    break;
   }
   case 121:  {
    $$sum2 = (($176) + 1)|0;
    $1891 = (($179) + ($$sum2<<2)|0);
    $1892 = HEAP32[$1891>>2]|0;
    $1893 = ($1892|0)==(0);
    if ($1893) {
     $1894 = HEAP32[$180>>2]|0;
     $1895 = $1894 | $176;
     $1896 = ($1895|0)==(0);
     if ($1896) {
      HEAP32[$34>>2] = 132;
     }
     $1897 = HEAP32[$22>>2]|0;
     $1898 = (($1897) + ($1894))|0;
     HEAP32[$22>>2] = $1898;
     $1899 = ($1898|0)<(0);
     if ($1899) {
      HEAP32[$34>>2] = 132;
     }
     HEAP8[$33>>0] = 0;
     label = 762;
    } else {
     label = 762;
    }
    break;
   }
   case 129:  {
    $$val46 = HEAP32[$180>>2]|0;
    $$sum265 = (($176) + 1)|0;
    $$idx47 = (($179) + ($$sum265<<2)|0);
    $$idx47$val = HEAP32[$$idx47>>2]|0;
    $1963 = $$idx47$val & 65535;
    $1964 = HEAP16[$97>>1]|0;
    $1965 = $1964&65535;
    $1966 = ($1963>>>0)<($1965>>>0);
    if ($1966) {
     $1967 = $$val46 & 65535;
     $1968 = ($1967>>>0)<($1965>>>0);
     if ($1968) {
      $1969 = $$val46&65535;
      $1970 = ($1967>>>0)>($1963>>>0);
      if ($1970) {
       label = 762;
       break L33;
      } else {
       $1975 = $1967;$I$01$i = $1969;
      }
      while(1) {
       $1973 = HEAP32[$101>>2]|0;
       $1974 = (($1973) + ($1975)|0);
       $1976 = HEAP8[$1974>>0]|0;
       $1977 = $1976&255;
       $1978 = $1977 | 1;
       $1979 = $1978&255;
       HEAP8[$1974>>0] = $1979;
       $1980 = (($I$01$i) + 1)<<16>>16;
       $1981 = $1980&65535;
       $1982 = ($1981>>>0)>($1963>>>0);
       if ($1982) {
        label = 762;
        break L33;
       } else {
        $1975 = $1981;$I$01$i = $1980;
       }
      }
     }
    }
    $1971 = HEAP8[$29>>0]|0;
    $1972 = ($1971<<24>>24)==(0);
    if ($1972) {
     label = 762;
    } else {
     label = 577;
     break L16;
    }
    break;
   }
   case 132: case 131:  {
    $2003 = HEAP32[$62>>2]|0;
    $2004 = HEAP32[$63>>2]|0;
    $2005 = (($2003) + ($2004<<4)|0);
    $2006 = ($2004|0)>(0);
    L845: do {
     if ($2006) {
      $def$02$i204 = $2003;
      while(1) {
       $2007 = (($def$02$i204) + 8|0);
       $2008 = HEAP32[$2007>>2]|0;
       $2009 = $2008&255;
       $2010 = ($171<<24>>24)==($2009<<24>>24);
       if ($2010) {
        $2011 = (($def$02$i204) + 12|0);
        $2012 = HEAP8[$2011>>0]|0;
        $2013 = ($2012<<24>>24)==(0);
        if (!($2013)) {
         break;
        }
       }
       $2037 = (($def$02$i204) + 16|0);
       $2038 = ($2037>>>0)<($2005>>>0);
       if ($2038) {
        $def$02$i204 = $2037;
       } else {
        break L845;
       }
      }
      $2014 = HEAP32[$64>>2]|0;
      $2015 = HEAP32[$65>>2]|0;
      $2016 = ($2014|0)<($2015|0);
      if (!($2016)) {
       label = 589;
       break L16;
      }
      $2017 = HEAP32[$66>>2]|0;
      $2018 = (($2014) + 1)|0;
      HEAP32[$64>>2] = $2018;
      $2019 = HEAP32[$67>>2]|0;
      $2020 = (($2017) + ($2014<<4)|0);
      HEAP32[$2020>>2] = $2019;
      $2021 = HEAP32[$22>>2]|0;
      $2022 = (($2021) + 1)|0;
      $2023 = ((($2017) + ($2014<<4)|0) + 4|0);
      HEAP32[$2023>>2] = $2022;
      $2024 = ((($2017) + ($2014<<4)|0) + 8|0);
      HEAP32[$2024>>2] = 1;
      $2025 = (($def$02$i204) + 4|0);
      $2026 = HEAP32[$2025>>2]|0;
      $2027 = ((($2017) + ($2014<<4)|0) + 12|0);
      HEAP32[$2027>>2] = $2026;
      $2028 = HEAP32[$def$02$i204>>2]|0;
      $2029 = HEAP32[$2025>>2]|0;
      $aRange$off$i207 = (($2028) + -1)|0;
      $2030 = ($aRange$off$i207>>>0)>(2);
      do {
       if ($2030) {
        HEAP32[$34>>2] = 132;
       } else {
        $2031 = ((($exc) + ($aRange$off$i207<<3)|0) + 444|0);
        $2032 = HEAP32[$2031>>2]|0;
        $2033 = ($2032|0)==(0|0);
        if ($2033) {
         HEAP32[$34>>2] = 138;
         break;
        }
        $2034 = ((($exc) + ($aRange$off$i207<<3)|0) + 448|0);
        $2035 = HEAP32[$2034>>2]|0;
        $2036 = ($2035>>>0)<($2029>>>0);
        if ($2036) {
         HEAP32[$34>>2] = 131;
         break;
        } else {
         HEAP32[$23>>2] = $2032;
         HEAP32[$26>>2] = $2035;
         HEAP32[$22>>2] = $2029;
         HEAP32[$67>>2] = $2028;
         break;
        }
       }
      } while(0);
      HEAP8[$33>>0] = 0;
      label = 762;
      break L33;
     }
    } while(0);
    HEAP32[$34>>2] = 128;
    $2617 = $2003;$2618 = $2004;
    label = 764;
    break;
   }
   case 130:  {
    $$val48 = HEAP32[$180>>2]|0;
    $$sum264 = (($176) + 1)|0;
    $$idx49 = (($179) + ($$sum264<<2)|0);
    $$idx49$val = HEAP32[$$idx49>>2]|0;
    $1983 = $$idx49$val & 65535;
    $1984 = HEAP16[$97>>1]|0;
    $1985 = $1984&65535;
    $1986 = ($1983>>>0)<($1985>>>0);
    if ($1986) {
     $1987 = $$val48 & 65535;
     $1988 = ($1987>>>0)<($1985>>>0);
     if ($1988) {
      $1989 = $$val48&65535;
      $1990 = ($1987>>>0)>($1983>>>0);
      if ($1990) {
       label = 762;
       break L33;
      } else {
       $1995 = $1987;$I$01$i201 = $1989;
      }
      while(1) {
       $1993 = HEAP32[$101>>2]|0;
       $1994 = (($1993) + ($1995)|0);
       $1996 = HEAP8[$1994>>0]|0;
       $1997 = $1996&255;
       $1998 = $1997 & 254;
       $1999 = $1998&255;
       HEAP8[$1994>>0] = $1999;
       $2000 = (($I$01$i201) + 1)<<16>>16;
       $2001 = $2000&65535;
       $2002 = ($2001>>>0)>($1983>>>0);
       if ($2002) {
        label = 762;
        break L33;
       } else {
        $1995 = $2001;$I$01$i201 = $2000;
       }
      }
     }
    }
    $1991 = HEAP8[$29>>0]|0;
    $1992 = ($1991<<24>>24)==(0);
    if ($1992) {
     label = 762;
    } else {
     label = 583;
     break L16;
    }
    break;
   }
   case 133:  {
    $2039 = HEAP32[$180>>2]|0;
    $2040 = $2039 & 255;
    if ((($2040|0) == 255)) {
     HEAP8[$121>>0] = 1;
     label = 762;
     break L33;
    } else if ((($2040|0) == 0)) {
     HEAP8[$121>>0] = 0;
     label = 762;
     break L33;
    } else {
     $2041 = $2039 & 256;
     $2042 = ($2041|0)==(0);
     if ($2042) {
      $2047 = $2039;
     } else {
      $2043 = HEAP16[$123>>1]|0;
      $2044 = $2043&65535;
      $2045 = ($2044>>>0)>($2040>>>0);
      if ($2045) {
       $2047 = $2039;
      } else {
       HEAP8[$121>>0] = 1;
       $$pre$i210 = HEAP32[$180>>2]|0;
       $2047 = $$pre$i210;
      }
     }
     $2046 = $2047 & 512;
     $2048 = ($2046|0)==(0);
     if ($2048) {
      $2052 = $2047;
     } else {
      $2049 = HEAP8[$122>>0]|0;
      $2050 = ($2049<<24>>24)==(0);
      if ($2050) {
       $2052 = $2047;
      } else {
       HEAP8[$121>>0] = 1;
       $$pre1$i211 = HEAP32[$180>>2]|0;
       $2052 = $$pre1$i211;
      }
     }
     $2051 = $2052 & 1024;
     $2053 = ($2051|0)==(0);
     if ($2053) {
      $2057 = $2052;
     } else {
      $2054 = HEAP8[$120>>0]|0;
      $2055 = ($2054<<24>>24)==(0);
      if ($2055) {
       $2057 = $2052;
      } else {
       HEAP8[$121>>0] = 1;
       $$pre2$i212 = HEAP32[$180>>2]|0;
       $2057 = $$pre2$i212;
      }
     }
     $2056 = $2057 & 2048;
     $2058 = ($2056|0)==(0);
     if ($2058) {
      $2063 = $2057;
     } else {
      $2059 = HEAP16[$123>>1]|0;
      $2060 = $2059&65535;
      $2061 = ($2060>>>0)>($2040>>>0);
      if ($2061) {
       HEAP8[$121>>0] = 0;
       $$pre3$i213 = HEAP32[$180>>2]|0;
       $2063 = $$pre3$i213;
      } else {
       $2063 = $2057;
      }
     }
     $2062 = $2063 & 4096;
     $2064 = ($2062|0)==(0);
     if ($2064) {
      $2068 = $2063;
     } else {
      $2065 = HEAP8[$122>>0]|0;
      $2066 = ($2065<<24>>24)==(0);
      if ($2066) {
       $2068 = $2063;
      } else {
       HEAP8[$121>>0] = 0;
       $$pre4$i = HEAP32[$180>>2]|0;
       $2068 = $$pre4$i;
      }
     }
     $2067 = $2068 & 8192;
     $2069 = ($2067|0)==(0);
     if ($2069) {
      label = 762;
      break L33;
     }
     $2070 = HEAP8[$120>>0]|0;
     $2071 = ($2070<<24>>24)==(0);
     if ($2071) {
      label = 762;
      break L33;
     }
     HEAP8[$121>>0] = 0;
     label = 762;
     break L33;
    }
    break;
   }
   case 136:  {
    $2115 = HEAP32[$180>>2]|0;
    $2116 = $2115 & 1;
    $2117 = ($2116|0)!=(0);
    $$$i218 = $2117 ? 35 : 0;
    $2118 = $2115 & 2;
    $2119 = ($2118|0)==(0);
    if ($2119) {
     $K$0$i = $$$i218;
    } else {
     $2120 = HEAP8[$122>>0]|0;
     $2121 = ($2120<<24>>24)==(0);
     $2122 = $$$i218 | 128;
     $$$$i = $2121 ? $$$i218 : $2122;
     $K$0$i = $$$$i;
    }
    $2123 = $2115 & 4;
    $2124 = ($2123|0)==(0);
    if ($2124) {
     $K$1$i = $K$0$i;
    } else {
     $2125 = HEAP8[$120>>0]|0;
     $2126 = ($2125<<24>>24)==(0);
     $2127 = $K$0$i | 256;
     $K$0$$i = $2126 ? $K$0$i : $2127;
     $K$1$i = $K$0$$i;
    }
    $2128 = $2115 & 32;
    $2129 = ($2128|0)==(0);
    if ($2129) {
     $K$2$i = $K$1$i;
    } else {
     $2130 = HEAP8[$124>>0]|0;
     $2131 = ($2130<<24>>24)==(0);
     $2132 = $K$1$i | 4096;
     $K$1$$i = $2131 ? $K$1$i : $2132;
     $K$2$i = $K$1$$i;
    }
    HEAP32[$180>>2] = $K$2$i;
    label = 762;
    break;
   }
   case 135: case 134:  {
    $2072 = HEAP32[$180>>2]|0;
    $2073 = $2072 & 65535;
    $2074 = HEAP16[$36>>1]|0;
    $2075 = $2074&65535;
    $2076 = ($2073>>>0)<($2075>>>0);
    if ($2076) {
     $$sum263 = (($176) + 1)|0;
     $2077 = (($179) + ($$sum263<<2)|0);
     $2078 = HEAP32[$2077>>2]|0;
     $2079 = $2078 & 65535;
     $2080 = HEAP16[$74>>1]|0;
     $2081 = $2080&65535;
     $2082 = ($2079>>>0)<($2081>>>0);
     if ($2082) {
      $2085 = HEAP32[$45>>2]|0;
      $2086 = HEAP32[$106>>2]|0;
      $2087 = (($2085) + ($2073<<3)|0);
      $2088 = HEAP32[$2087>>2]|0;
      $2089 = (($2086) + ($2079<<3)|0);
      $2090 = HEAP32[$2089>>2]|0;
      $2091 = (($2088) - ($2090))|0;
      $2092 = ((($2085) + ($2073<<3)|0) + 4|0);
      $2093 = HEAP32[$2092>>2]|0;
      $2094 = ((($2086) + ($2079<<3)|0) + 4|0);
      $2095 = HEAP32[$2094>>2]|0;
      $2096 = (($2093) - ($2095))|0;
      $2097 = ($2088|0)==($2090|0);
      $2098 = ($2093|0)==($2095|0);
      $or$cond$i214 = $2097 & $2098;
      $A$0$i215 = $or$cond$i214 ? 16384 : $2091;
      $$op$i = $171 & 1;
      $2099 = ($$op$i<<24>>24)!=(0);
      $not$or$cond$i$demorgan = $2097 & $2098;
      $not$or$cond$i = $not$or$cond$i$demorgan ^ 1;
      $2100 = $2099 & $not$or$cond$i;
      $2101 = (0 - ($2096))|0;
      $A$0$$i216 = $2100 ? $A$0$i215 : $2096;
      $$A$0$i217 = $2100 ? $2101 : $A$0$i215;
      _Normalize($$A$0$i217,$A$0$$i216,$76);
      $2102 = HEAP32[$47>>2]|0;
      $2103 = HEAP32[$75>>2]|0;
      $2104 = (($2102) + ($2073<<3)|0);
      $2105 = HEAP32[$2104>>2]|0;
      $2106 = (($2103) + ($2079<<3)|0);
      $2107 = HEAP32[$2106>>2]|0;
      $2108 = (($2105) - ($2107))|0;
      $2109 = ((($2102) + ($2073<<3)|0) + 4|0);
      $2110 = HEAP32[$2109>>2]|0;
      $2111 = ((($2103) + ($2079<<3)|0) + 4|0);
      $2112 = HEAP32[$2111>>2]|0;
      $2113 = (($2110) - ($2112))|0;
      $2114 = (0 - ($2113))|0;
      $B$1$i = $2100 ? $2108 : $2113;
      $A$2$i = $2100 ? $2114 : $2108;
      _Normalize($A$2$i,$B$1$i,$73);
      _Compute_Funcs($exc);
      label = 762;
      break L33;
     }
    }
    $2083 = HEAP8[$29>>0]|0;
    $2084 = ($2083<<24>>24)==(0);
    if ($2084) {
     label = 762;
    } else {
     label = 624;
     break L16;
    }
    break;
   }
   case 137:  {
    $2133 = HEAP32[$62>>2]|0;
    $2134 = HEAP32[$63>>2]|0;
    $2135 = (($2133) + ($2134<<4)|0);
    $2136 = ($2134|0)>(0);
    L914: do {
     if ($2136) {
      $2137 = HEAP32[$180>>2]|0;
      $def$01$i220 = $2133;
      while(1) {
       $2140 = (($def$01$i220) + 8|0);
       $2141 = HEAP32[$2140>>2]|0;
       $2142 = ($2141|0)==($2137|0);
       $2139 = (($def$01$i220) + 16|0);
       if ($2142) {
        $def$0$lcssa$i221 = $def$01$i220;
        break L914;
       }
       $2138 = ($2139>>>0)<($2135>>>0);
       if ($2138) {
        $def$01$i220 = $2139;
       } else {
        $def$0$lcssa$i221 = $2139;
        break;
       }
      }
     } else {
      $def$0$lcssa$i221 = $2133;
     }
    } while(0);
    $2143 = ($def$0$lcssa$i221|0)==($2135|0);
    if ($2143) {
     $2144 = HEAP32[$125>>2]|0;
     $2145 = ($2134>>>0)<($2144>>>0);
     if (!($2145)) {
      label = 639;
      break L16;
     }
     $2146 = (($2134) + 1)|0;
     HEAP32[$63>>2] = $2146;
    }
    $2147 = HEAP32[$180>>2]|0;
    $2148 = ($2147>>>0)>(255);
    if ($2148) {
     label = 642;
     break L16;
    }
    $2149 = $2147 & 255;
    $2150 = (($def$0$lcssa$i221) + 8|0);
    HEAP32[$2150>>2] = $2149;
    $2151 = HEAP32[$22>>2]|0;
    $2152 = (($2151) + 1)|0;
    $2153 = (($def$0$lcssa$i221) + 4|0);
    HEAP32[$2153>>2] = $2152;
    $2154 = HEAP32[$67>>2]|0;
    HEAP32[$def$0$lcssa$i221>>2] = $2154;
    $2155 = (($def$0$lcssa$i221) + 12|0);
    HEAP8[$2155>>0] = 1;
    $2156 = HEAP32[$180>>2]|0;
    $2157 = HEAP32[$126>>2]|0;
    $2158 = ($2156>>>0)>($2157>>>0);
    if ($2158) {
     $2159 = $2156 & 255;
     HEAP32[$126>>2] = $2159;
    }
    $$pre$i224 = HEAP32[$25>>2]|0;
    $$pre5$i225 = HEAP32[$22>>2]|0;
    $$pre6$i226 = HEAP32[$26>>2]|0;
    $2161 = $$pre$i224;$2162 = $$pre5$i225;
    while(1) {
     $2160 = (($2161) + ($2162))|0;
     HEAP32[$22>>2] = $2160;
     $2163 = ($2160|0)<($$pre6$i226|0);
     if (!($2163)) {
      label = 650;
      break L16;
     }
     $2164 = HEAP32[$23>>2]|0;
     $2165 = (($2164) + ($2160)|0);
     $2166 = HEAP8[$2165>>0]|0;
     HEAP8[$24>>0] = $2166;
     $2167 = $2166&255;
     $2168 = (873192 + ($2167)|0);
     $2169 = HEAP8[$2168>>0]|0;
     $2170 = $2169 << 24 >> 24;
     HEAP32[$25>>2] = $2170;
     $2171 = $2167 & 254;
     $2172 = ($2171|0)==(64);
     if ($2172) {
      $2173 = (($2160) + 1)|0;
      $2174 = (($2164) + ($2173)|0);
      $2175 = HEAP8[$2174>>0]|0;
      $2176 = $2175&255;
      $2177 = Math_imul($2176, $2170)|0;
      $2178 = (2 - ($2177))|0;
      HEAP32[$25>>2] = $2178;
      $2180 = $2178;
     } else {
      $2180 = $2170;
     }
     $2179 = (($2180) + ($2160))|0;
     $2181 = ($2179|0)>($$pre6$i226|0);
     if ($2181) {
      label = 650;
      break L16;
     }
     if ((($2167|0) == 45)) {
      label = 762;
      break;
     } else if ((($2167|0) == 44) | (($2167|0) == 137)) {
      label = 652;
      break L16;
     } else {
      $2161 = $2180;$2162 = $2160;
     }
    }
    break;
   }
   default: {
    $2242 = ($171&255)>(223);
    if ($2242) {
     $$val53 = HEAP32[$180>>2]|0;
     $$sum281 = (($176) + 1)|0;
     $$idx54 = (($179) + ($$sum281<<2)|0);
     $$idx54$val = HEAP32[$$idx54>>2]|0;
     $2243 = $$val53&65535;
     $2244 = (($$idx54$val) + 1)|0;
     $2245 = $$val53 & 65535;
     $2246 = HEAP16[$36>>1]|0;
     $2247 = $2246&65535;
     $2248 = ($2245>>>0)<($2247>>>0);
     if ($2248) {
      $2249 = HEAP32[$37>>2]|0;
      $2250 = (($2249) + 1)|0;
      $2251 = ($2244>>>0)<($2250>>>0);
      if ($2251) {
       $2252 = HEAP16[$38>>1]|0;
       $2253 = HEAP16[$39>>1]|0;
       $2254 = ($2252&65535)<($2253&65535);
       if ($2254) {
        $2257 = ($2244|0)==(0);
        if ($2257) {
         $cvt_dist$0$i = 0;
        } else {
         $2258 = HEAP32[$6>>2]|0;
         $2259 = (FUNCTION_TABLE_iii[$2258 & 4095]($exc,$$idx54$val)|0);
         $cvt_dist$0$i = $2259;
        }
        $2260 = HEAP32[$40>>2]|0;
        $2261 = (($cvt_dist$0$i) - ($2260))|0;
        $2262 = ($2261|0)<(0);
        $2263 = (0 - ($2261))|0;
        $2264 = $2262 ? $2263 : $2261;
        $2265 = HEAP32[$41>>2]|0;
        $2266 = ($2264|0)<($2265|0);
        if ($2266) {
         $2267 = ($cvt_dist$0$i|0)>(-1);
         $2268 = (0 - ($2260))|0;
         $$$i238 = $2267 ? $2260 : $2268;
         $cvt_dist$1$i = $$$i238;
        } else {
         $cvt_dist$1$i = $cvt_dist$0$i;
        }
        $2269 = HEAP16[$42>>1]|0;
        $2270 = ($2269<<16>>16)==(0);
        if ($2270) {
         $2271 = HEAP16[$38>>1]|0;
         $2272 = $2271&65535;
         $2273 = HEAP32[$43>>2]|0;
         $2274 = (($2273) + ($2272<<3)|0);
         $2275 = HEAP32[$2274>>2]|0;
         $2276 = HEAP16[$44>>1]|0;
         $2277 = $2276 << 16 >> 16;
         $2278 = $2277 ^ $cvt_dist$1$i;
         $2279 = ($cvt_dist$1$i|0)<(0);
         $2280 = (0 - ($cvt_dist$1$i))|0;
         $$a$i$i243 = $2279 ? $2280 : $cvt_dist$1$i;
         $2281 = ($2276<<16>>16)<(0);
         $2282 = (0 - ($2277))|0;
         $$01$i$i244 = $2281 ? $2282 : $2277;
         $2283 = $$a$i$i243 >>> 16;
         $2284 = $$a$i$i243 & 65535;
         $2285 = Math_imul($$01$i$i244, $2284)|0;
         $2286 = Math_imul($$01$i$i244, $2283)|0;
         $2287 = $2286 >>> 16;
         $2288 = $2286 << 16;
         $2289 = $2288 | 8192;
         $2290 = (($2289) + ($2285))|0;
         $2291 = ($2290>>>0)<($2289>>>0);
         $2292 = $2291&1;
         $$$i$i245 = (($2292) + ($2287))|0;
         $2293 = $2290 >>> 14;
         $2294 = $$$i$i245 << 18;
         $2295 = $2294 | $2293;
         $2296 = ($2278|0)>(-1);
         $2297 = (0 - ($2295))|0;
         $2298 = $2296 ? $2295 : $2297;
         $2299 = (($2298) + ($2275))|0;
         $2300 = HEAP32[$45>>2]|0;
         $2301 = (($2300) + ($2245<<3)|0);
         HEAP32[$2301>>2] = $2299;
         $2302 = ((($2273) + ($2272<<3)|0) + 4|0);
         $2303 = HEAP32[$2302>>2]|0;
         $2304 = HEAP16[$46>>1]|0;
         $2305 = $2304 << 16 >> 16;
         $2306 = $2305 ^ $cvt_dist$1$i;
         $2307 = ($2304<<16>>16)<(0);
         $2308 = (0 - ($2305))|0;
         $$01$i3$i = $2307 ? $2308 : $2305;
         $2309 = Math_imul($$01$i3$i, $2284)|0;
         $2310 = Math_imul($$01$i3$i, $2283)|0;
         $2311 = $2310 >>> 16;
         $2312 = $2310 << 16;
         $2313 = $2312 | 8192;
         $2314 = (($2313) + ($2309))|0;
         $2315 = ($2314>>>0)<($2313>>>0);
         $2316 = $2315&1;
         $$$i4$i = (($2316) + ($2311))|0;
         $2317 = $2314 >>> 14;
         $2318 = $$$i4$i << 18;
         $2319 = $2318 | $2317;
         $2320 = ($2306|0)>(-1);
         $2321 = (0 - ($2319))|0;
         $2322 = $2320 ? $2319 : $2321;
         $2323 = (($2322) + ($2303))|0;
         $2324 = ((($2300) + ($2245<<3)|0) + 4|0);
         HEAP32[$2324>>2] = $2323;
         $2325 = HEAP32[$47>>2]|0;
         $2326 = (($2325) + ($2245<<3)|0);
         $2327 = HEAP32[$48>>2]|0;
         $2328 = (($2327) + ($2245<<3)|0);
         $2329 = $2328;
         $2330 = $2329;
         $2331 = HEAP32[$2330>>2]|0;
         $2332 = (($2329) + 4)|0;
         $2333 = $2332;
         $2334 = HEAP32[$2333>>2]|0;
         $2335 = $2326;
         $2336 = $2335;
         HEAP32[$2336>>2] = $2331;
         $2337 = (($2335) + 4)|0;
         $2338 = $2337;
         HEAP32[$2338>>2] = $2334;
        }
        $2339 = HEAP32[$49>>2]|0;
        $2340 = HEAP32[$45>>2]|0;
        $2341 = (($2340) + ($2245<<3)|0);
        $2342 = HEAP32[$2341>>2]|0;
        $2343 = HEAP16[$38>>1]|0;
        $2344 = $2343&65535;
        $2345 = HEAP32[$43>>2]|0;
        $2346 = (($2345) + ($2344<<3)|0);
        $2347 = HEAP32[$2346>>2]|0;
        $2348 = (($2342) - ($2347))|0;
        $2349 = ((($2340) + ($2245<<3)|0) + 4|0);
        $2350 = HEAP32[$2349>>2]|0;
        $2351 = ((($2345) + ($2344<<3)|0) + 4|0);
        $2352 = HEAP32[$2351>>2]|0;
        $2353 = (($2350) - ($2352))|0;
        $2354 = (FUNCTION_TABLE_iiii[$2339 & 2047]($exc,$2348,$2353)|0);
        $2355 = HEAP32[$50>>2]|0;
        $2356 = HEAP32[$47>>2]|0;
        $2357 = (($2356) + ($2245<<3)|0);
        $2358 = HEAP32[$2357>>2]|0;
        $2359 = HEAP16[$38>>1]|0;
        $2360 = $2359&65535;
        $2361 = HEAP32[$48>>2]|0;
        $2362 = (($2361) + ($2360<<3)|0);
        $2363 = HEAP32[$2362>>2]|0;
        $2364 = (($2358) - ($2363))|0;
        $2365 = ((($2356) + ($2245<<3)|0) + 4|0);
        $2366 = HEAP32[$2365>>2]|0;
        $2367 = ((($2361) + ($2360<<3)|0) + 4|0);
        $2368 = HEAP32[$2367>>2]|0;
        $2369 = (($2366) - ($2368))|0;
        $2370 = (FUNCTION_TABLE_iiii[$2355 & 2047]($exc,$2364,$2369)|0);
        $2371 = HEAP8[$51>>0]|0;
        $2372 = ($2371<<24>>24)==(0);
        if ($2372) {
         $cvt_dist$2$i = $cvt_dist$1$i;
        } else {
         $2373 = $2354 ^ $cvt_dist$1$i;
         $2374 = ($2373|0)<(0);
         $2375 = (0 - ($cvt_dist$1$i))|0;
         $$cvt_dist$1$i = $2374 ? $2375 : $cvt_dist$1$i;
         $cvt_dist$2$i = $$cvt_dist$1$i;
        }
        $2376 = HEAP8[$24>>0]|0;
        $2377 = $2376&255;
        $2378 = $2377 & 4;
        $2379 = ($2378|0)==(0);
        do {
         if ($2379) {
          $2394 = $2377 & 3;
          $2395 = ((($exc) + ($2394<<2)|0) + 264|0);
          $2396 = HEAP32[$2395>>2]|0;
          $2397 = ($cvt_dist$2$i|0)>(-1);
          if ($2397) {
           $2398 = (($2396) + ($cvt_dist$2$i))|0;
           $2399 = ($cvt_dist$2$i|0)!=(0);
           $2400 = ($2398|0)<(0);
           $or$cond$i$i248 = $2399 & $2400;
           $$1$i$i249 = $or$cond$i$i248 ? 0 : $2398;
           $2404 = $2376;$distance$0$i250 = $$1$i$i249;
           break;
          } else {
           $2401 = (($cvt_dist$2$i) - ($2396))|0;
           $2402 = ($2401|0)>(0);
           $$$i5$i = $2402 ? 0 : $2401;
           $2404 = $2376;$distance$0$i250 = $$$i5$i;
           break;
          }
         } else {
          $2380 = HEAP16[$54>>1]|0;
          $2381 = HEAP16[$42>>1]|0;
          $2382 = ($2380<<16>>16)==($2381<<16>>16);
          if ($2382) {
           $2383 = (($cvt_dist$2$i) - ($2354))|0;
           $2384 = ($2383|0)<(0);
           $2385 = (0 - ($2383))|0;
           $2386 = $2384 ? $2385 : $2383;
           $2387 = HEAP32[$55>>2]|0;
           $2388 = ($2386|0)>($2387|0);
           $$cvt_dist$2$i = $2388 ? $2354 : $cvt_dist$2$i;
           $cvt_dist$3$i = $$cvt_dist$2$i;
          } else {
           $cvt_dist$3$i = $cvt_dist$2$i;
          }
          $2389 = HEAP32[$$pre$phiZ2D>>2]|0;
          $2390 = $2377 & 3;
          $2391 = ((($exc) + ($2390<<2)|0) + 264|0);
          $2392 = HEAP32[$2391>>2]|0;
          $2393 = (FUNCTION_TABLE_iiii[$2389 & 2047]($exc,$cvt_dist$3$i,$2392)|0);
          $$pre$i247 = HEAP8[$24>>0]|0;
          $2404 = $$pre$i247;$distance$0$i250 = $2393;
         }
        } while(0);
        $2403 = $2404 & 8;
        $2405 = ($2403<<24>>24)==(0);
        do {
         if ($2405) {
          $distance$1$i254 = $distance$0$i250;
         } else {
          $2406 = ($2354|0)>(-1);
          $2407 = HEAP32[$53>>2]|0;
          if ($2406) {
           $2408 = ($distance$0$i250|0)<($2407|0);
           $$distance$0$i252 = $2408 ? $2407 : $distance$0$i250;
           $distance$1$i254 = $$distance$0$i252;
           break;
          } else {
           $2409 = (0 - ($2407))|0;
           $2410 = ($distance$0$i250|0)>($2409|0);
           $$distance$01$i253 = $2410 ? $2409 : $distance$0$i250;
           $distance$1$i254 = $$distance$01$i253;
           break;
          }
         }
        } while(0);
        $2411 = HEAP32[$52>>2]|0;
        $2412 = (($distance$1$i254) - ($2370))|0;
        FUNCTION_TABLE_viiii[$2411 & 511]($exc,$35,$2243,$2412);
        $$pre417 = HEAP8[$24>>0]|0;
        $2415 = $$pre417;
       } else {
        label = 683;
       }
      } else {
       label = 683;
      }
     } else {
      label = 683;
     }
     if ((label|0) == 683) {
      label = 0;
      $2255 = HEAP8[$29>>0]|0;
      $2256 = ($2255<<24>>24)==(0);
      if ($2256) {
       $2415 = $171;
      } else {
       HEAP32[$34>>2] = 134;
       $2415 = $171;
      }
     }
     $2413 = HEAP16[$38>>1]|0;
     HEAP16[$56>>1] = $2413;
     $2414 = $2415 & 16;
     $2416 = ($2414<<24>>24)==(0);
     if (!($2416)) {
      HEAP16[$38>>1] = $2243;
     }
     HEAP16[$57>>1] = $2243;
     label = 762;
     break L33;
    }
    $2417 = ($171&255)>(191);
    if ($2417) {
     $$val55 = HEAP32[$180>>2]|0;
     $2418 = $$val55&65535;
     $2419 = $$val55 & 65535;
     $2420 = HEAP16[$36>>1]|0;
     $2421 = $2420&65535;
     $2422 = ($2419>>>0)<($2421>>>0);
     if ($2422) {
      $2423 = HEAP16[$38>>1]|0;
      $2424 = $2423&65535;
      $2425 = HEAP16[$39>>1]|0;
      $2426 = ($2423&65535)<($2425&65535);
      if ($2426) {
       $2429 = HEAP16[$54>>1]|0;
       $2430 = ($2429<<16>>16)==(0);
       do {
        if ($2430) {
         label = 715;
        } else {
         $2431 = HEAP16[$42>>1]|0;
         $2432 = ($2431<<16>>16)==(0);
         if ($2432) {
          label = 715;
         } else {
          $2447 = HEAP32[$58>>2]|0;
          $2448 = (($2447) + ($2419<<3)|0);
          $2449 = HEAP32[$59>>2]|0;
          $2450 = (($2449) + ($2424<<3)|0);
          $2451 = HEAP32[$60>>2]|0;
          $2452 = HEAP32[$61>>2]|0;
          $2453 = ($2451|0)==($2452|0);
          if ($2453) {
           $2454 = HEAP32[$49>>2]|0;
           $2455 = HEAP32[$2448>>2]|0;
           $2456 = HEAP32[$2450>>2]|0;
           $2457 = (($2455) - ($2456))|0;
           $2458 = ((($2447) + ($2419<<3)|0) + 4|0);
           $2459 = HEAP32[$2458>>2]|0;
           $2460 = ((($2449) + ($2424<<3)|0) + 4|0);
           $2461 = HEAP32[$2460>>2]|0;
           $2462 = (($2459) - ($2461))|0;
           $2463 = (FUNCTION_TABLE_iiii[$2454 & 2047]($exc,$2457,$2462)|0);
           $2464 = HEAP32[$60>>2]|0;
           $2465 = (_FT_MulFix($2463,$2464)|0);
           $org_dist$0$i = $2465;
           break;
          } else {
           $2466 = HEAP32[$2448>>2]|0;
           $2467 = HEAP32[$2450>>2]|0;
           $2468 = (($2466) - ($2467))|0;
           $2469 = (_FT_MulFix($2468,$2451)|0);
           $2470 = ((($2447) + ($2419<<3)|0) + 4|0);
           $2471 = HEAP32[$2470>>2]|0;
           $2472 = ((($2449) + ($2424<<3)|0) + 4|0);
           $2473 = HEAP32[$2472>>2]|0;
           $2474 = (($2471) - ($2473))|0;
           $2475 = HEAP32[$61>>2]|0;
           $2476 = (_FT_MulFix($2474,$2475)|0);
           $2477 = HEAP32[$49>>2]|0;
           $2478 = (FUNCTION_TABLE_iiii[$2477 & 2047]($exc,$2469,$2476)|0);
           $org_dist$0$i = $2478;
           break;
          }
         }
        }
       } while(0);
       if ((label|0) == 715) {
        label = 0;
        $2433 = HEAP32[$45>>2]|0;
        $2434 = HEAP32[$43>>2]|0;
        $2435 = HEAP32[$49>>2]|0;
        $2436 = (($2433) + ($2419<<3)|0);
        $2437 = HEAP32[$2436>>2]|0;
        $2438 = (($2434) + ($2424<<3)|0);
        $2439 = HEAP32[$2438>>2]|0;
        $2440 = (($2437) - ($2439))|0;
        $2441 = ((($2433) + ($2419<<3)|0) + 4|0);
        $2442 = HEAP32[$2441>>2]|0;
        $2443 = ((($2434) + ($2424<<3)|0) + 4|0);
        $2444 = HEAP32[$2443>>2]|0;
        $2445 = (($2442) - ($2444))|0;
        $2446 = (FUNCTION_TABLE_iiii[$2435 & 2047]($exc,$2440,$2445)|0);
        $org_dist$0$i = $2446;
       }
       $2479 = HEAP32[$40>>2]|0;
       $2480 = (($org_dist$0$i) - ($2479))|0;
       $2481 = ($2480|0)<(0);
       $2482 = (0 - ($2480))|0;
       $2483 = $2481 ? $2482 : $2480;
       $2484 = HEAP32[$41>>2]|0;
       $2485 = ($2483|0)<($2484|0);
       if ($2485) {
        $2486 = ($org_dist$0$i|0)>(-1);
        $2487 = (0 - ($2479))|0;
        $$$i = $2486 ? $2479 : $2487;
        $org_dist$1$i = $$$i;
       } else {
        $org_dist$1$i = $org_dist$0$i;
       }
       $2488 = HEAP8[$24>>0]|0;
       $2489 = $2488&255;
       $2490 = $2489 & 4;
       $2491 = ($2490|0)==(0);
       do {
        if ($2491) {
         $2497 = $2489 & 3;
         $2498 = ((($exc) + ($2497<<2)|0) + 264|0);
         $2499 = HEAP32[$2498>>2]|0;
         $2500 = ($org_dist$1$i|0)>(-1);
         if ($2500) {
          $2501 = (($2499) + ($org_dist$1$i))|0;
          $2502 = ($org_dist$1$i|0)!=(0);
          $2503 = ($2501|0)<(0);
          $or$cond$i$i = $2502 & $2503;
          $$1$i$i = $or$cond$i$i ? 0 : $2501;
          $2507 = $2488;$distance$0$i = $$1$i$i;
          break;
         } else {
          $2504 = (($org_dist$1$i) - ($2499))|0;
          $2505 = ($2504|0)>(0);
          $$$i$i = $2505 ? 0 : $2504;
          $2507 = $2488;$distance$0$i = $$$i$i;
          break;
         }
        } else {
         $2492 = HEAP32[$$pre$phiZ2D>>2]|0;
         $2493 = $2489 & 3;
         $2494 = ((($exc) + ($2493<<2)|0) + 264|0);
         $2495 = HEAP32[$2494>>2]|0;
         $2496 = (FUNCTION_TABLE_iiii[$2492 & 2047]($exc,$org_dist$1$i,$2495)|0);
         $$pre$i64 = HEAP8[$24>>0]|0;
         $2507 = $$pre$i64;$distance$0$i = $2496;
        }
       } while(0);
       $2506 = $2507 & 8;
       $2508 = ($2506<<24>>24)==(0);
       do {
        if ($2508) {
         $distance$1$i = $distance$0$i;
        } else {
         $2509 = ($org_dist$1$i|0)>(-1);
         $2510 = HEAP32[$53>>2]|0;
         if ($2509) {
          $2511 = ($distance$0$i|0)<($2510|0);
          $$distance$0$i = $2511 ? $2510 : $distance$0$i;
          $distance$1$i = $$distance$0$i;
          break;
         } else {
          $2512 = (0 - ($2510))|0;
          $2513 = ($distance$0$i|0)>($2512|0);
          $$distance$01$i = $2513 ? $2512 : $distance$0$i;
          $distance$1$i = $$distance$01$i;
          break;
         }
        }
       } while(0);
       $2514 = HEAP32[$50>>2]|0;
       $2515 = HEAP32[$47>>2]|0;
       $2516 = (($2515) + ($2419<<3)|0);
       $2517 = HEAP32[$2516>>2]|0;
       $2518 = HEAP32[$48>>2]|0;
       $2519 = HEAP16[$38>>1]|0;
       $2520 = $2519&65535;
       $2521 = (($2518) + ($2520<<3)|0);
       $2522 = HEAP32[$2521>>2]|0;
       $2523 = (($2517) - ($2522))|0;
       $2524 = ((($2515) + ($2419<<3)|0) + 4|0);
       $2525 = HEAP32[$2524>>2]|0;
       $2526 = ((($2518) + ($2520<<3)|0) + 4|0);
       $2527 = HEAP32[$2526>>2]|0;
       $2528 = (($2525) - ($2527))|0;
       $2529 = (FUNCTION_TABLE_iiii[$2514 & 2047]($exc,$2523,$2528)|0);
       $2530 = HEAP32[$52>>2]|0;
       $2531 = (($distance$1$i) - ($2529))|0;
       FUNCTION_TABLE_viiii[$2530 & 511]($exc,$35,$2418,$2531);
       $$pre418 = HEAP8[$24>>0]|0;
       $2534 = $$pre418;
      } else {
       label = 711;
      }
     } else {
      label = 711;
     }
     if ((label|0) == 711) {
      label = 0;
      $2427 = HEAP8[$29>>0]|0;
      $2428 = ($2427<<24>>24)==(0);
      if ($2428) {
       $2534 = $171;
      } else {
       HEAP32[$34>>2] = 134;
       $2534 = $171;
      }
     }
     $2532 = HEAP16[$38>>1]|0;
     HEAP16[$56>>1] = $2532;
     HEAP16[$57>>1] = $2418;
     $2533 = $2534 & 16;
     $2535 = ($2533<<24>>24)==(0);
     if ($2535) {
      label = 762;
      break L33;
     }
     HEAP16[$38>>1] = $2418;
     label = 762;
     break L33;
    }
    $2536 = ($171&255)>(183);
    if ($2536) {
     $2537 = (($170) + 65353)|0;
     $2538 = $2537 & 65535;
     $2539 = (($177) + 1)|0;
     $2540 = HEAP32[$27>>2]|0;
     $2541 = (($2539) - ($2540))|0;
     $2542 = ($2538>>>0)<($2541>>>0);
     if (!($2542)) {
      label = 735;
      break L16;
     }
     $2543 = HEAP32[$22>>2]|0;
     $2544 = (($2543) + 1)|0;
     HEAP32[$22>>2] = $2544;
     $2545 = ($2538|0)==(0);
     L147: do {
      if (!($2545)) {
       $2547 = $2544;$2558 = 0;$K$01$i62 = 1;
       while(1) {
        $2546 = (($2547) + 2)|0;
        HEAP32[$22>>2] = $2546;
        $2548 = (($129) + ($2547)|0);
        $2549 = HEAP8[$2548>>0]|0;
        $2550 = $2549&255;
        $2551 = $2550 << 8;
        $2552 = (($2547) + 1)|0;
        $2553 = (($129) + ($2552)|0);
        $2554 = HEAP8[$2553>>0]|0;
        $2555 = $2554&255;
        $2556 = $2551 | $2555;
        $sext$i = $2556 << 16;
        $2557 = $sext$i >> 16;
        $$sum280 = (($2558) + ($176))|0;
        $2559 = (($179) + ($$sum280<<2)|0);
        HEAP32[$2559>>2] = $2557;
        $2560 = $K$01$i62&65535;
        $2561 = ($2560>>>0)<($2538>>>0);
        if (!($2561)) {
         break L147;
        }
        $$pre3$i = HEAP32[$22>>2]|0;
        $phitmp$i = (($K$01$i62) + 1)<<16>>16;
        $2547 = $$pre3$i;$2558 = $2560;$K$01$i62 = $phitmp$i;
       }
      }
     } while(0);
     HEAP8[$33>>0] = 0;
     label = 762;
     break L33;
    }
    $2562 = ($171&255)>(175);
    if ($2562) {
     $2563 = (($170) + 65361)|0;
     $2564 = $2563 & 65535;
     $2565 = (($177) + 1)|0;
     $2566 = HEAP32[$27>>2]|0;
     $2567 = (($2565) - ($2566))|0;
     $2568 = ($2564>>>0)<($2567>>>0);
     if (!($2568)) {
      label = 744;
      break L16;
     }
     $2569 = ($2564|0)==(0);
     if ($2569) {
      label = 762;
      break L33;
     }
     $2570 = (($176) + -1)|0;
     $2573 = 1;$K$01$i = 2;
     while(1) {
      $2571 = HEAP32[$22>>2]|0;
      $2572 = (($2571) + ($2573))|0;
      $2574 = (($129) + ($2572)|0);
      $2575 = HEAP8[$2574>>0]|0;
      $2576 = $2575&255;
      $$sum279 = (($2570) + ($2573))|0;
      $2577 = (($179) + ($$sum279<<2)|0);
      HEAP32[$2577>>2] = $2576;
      $2578 = $K$01$i&65535;
      $2579 = ($2578>>>0)>($2564>>>0);
      if ($2579) {
       label = 762;
       break L33;
      }
      $phitmp = (($K$01$i) + 1)<<16>>16;
      $2573 = $2578;$K$01$i = $phitmp;
     }
    }
    $2580 = HEAP32[$62>>2]|0;
    $2581 = HEAP32[$63>>2]|0;
    $2582 = (($2580) + ($2581<<4)|0);
    $2583 = ($2581|0)>(0);
    L161: do {
     if ($2583) {
      $def$02$i = $2580;
      while(1) {
       $2584 = (($def$02$i) + 8|0);
       $2585 = HEAP32[$2584>>2]|0;
       $2586 = $2585&255;
       $2587 = ($171<<24>>24)==($2586<<24>>24);
       if ($2587) {
        $2588 = (($def$02$i) + 12|0);
        $2589 = HEAP8[$2588>>0]|0;
        $2590 = ($2589<<24>>24)==(0);
        if (!($2590)) {
         break;
        }
       }
       $2614 = (($def$02$i) + 16|0);
       $2615 = ($2614>>>0)<($2582>>>0);
       if ($2615) {
        $def$02$i = $2614;
       } else {
        break L161;
       }
      }
      $2591 = HEAP32[$64>>2]|0;
      $2592 = HEAP32[$65>>2]|0;
      $2593 = ($2591|0)<($2592|0);
      if (!($2593)) {
       label = 751;
       break L16;
      }
      $2594 = HEAP32[$66>>2]|0;
      $2595 = (($2591) + 1)|0;
      HEAP32[$64>>2] = $2595;
      $2596 = HEAP32[$67>>2]|0;
      $2597 = (($2594) + ($2591<<4)|0);
      HEAP32[$2597>>2] = $2596;
      $2598 = HEAP32[$22>>2]|0;
      $2599 = (($2598) + 1)|0;
      $2600 = ((($2594) + ($2591<<4)|0) + 4|0);
      HEAP32[$2600>>2] = $2599;
      $2601 = ((($2594) + ($2591<<4)|0) + 8|0);
      HEAP32[$2601>>2] = 1;
      $2602 = (($def$02$i) + 4|0);
      $2603 = HEAP32[$2602>>2]|0;
      $2604 = ((($2594) + ($2591<<4)|0) + 12|0);
      HEAP32[$2604>>2] = $2603;
      $2605 = HEAP32[$def$02$i>>2]|0;
      $2606 = HEAP32[$2602>>2]|0;
      $aRange$off$i56 = (($2605) + -1)|0;
      $2607 = ($aRange$off$i56>>>0)>(2);
      do {
       if ($2607) {
        HEAP32[$34>>2] = 132;
       } else {
        $2608 = ((($exc) + ($aRange$off$i56<<3)|0) + 444|0);
        $2609 = HEAP32[$2608>>2]|0;
        $2610 = ($2609|0)==(0|0);
        if ($2610) {
         HEAP32[$34>>2] = 138;
         break;
        }
        $2611 = ((($exc) + ($aRange$off$i56<<3)|0) + 448|0);
        $2612 = HEAP32[$2611>>2]|0;
        $2613 = ($2612>>>0)<($2606>>>0);
        if ($2613) {
         HEAP32[$34>>2] = 131;
         break;
        } else {
         HEAP32[$23>>2] = $2609;
         HEAP32[$26>>2] = $2612;
         HEAP32[$22>>2] = $2606;
         HEAP32[$67>>2] = $2605;
         break;
        }
       }
      } while(0);
      HEAP8[$33>>0] = 0;
      label = 762;
      break L33;
     }
    } while(0);
    HEAP32[$34>>2] = 128;
    $2617 = $2580;$2618 = $2581;
    label = 764;
   }
   }
  } while(0);
  do {
   if ((label|0) == 762) {
    label = 0;
    $$pr$pr$pr = HEAP32[$34>>2]|0;
    if ((($$pr$pr$pr|0) == 0)) {
     label = 778;
     break;
    } else if (!((($$pr$pr$pr|0) == 128))) {
     label = 786;
     break L16;
    }
    $$pre453 = HEAP32[$62>>2]|0;
    $$pre454 = HEAP32[$63>>2]|0;
    $2617 = $$pre453;$2618 = $$pre454;
    label = 764;
   }
  } while(0);
  if ((label|0) == 764) {
   label = 0;
   $2616 = (($2617) + ($2618<<4)|0);
   $2619 = ($2618|0)>(0);
   if ($2619) {
    $def$0324 = $2617;
   } else {
    label = 777;
    break;
   }
   while(1) {
    $2620 = (($def$0324) + 12|0);
    $2621 = HEAP8[$2620>>0]|0;
    $2622 = ($2621<<24>>24)==(0);
    if (!($2622)) {
     $2623 = HEAP8[$24>>0]|0;
     $2624 = (($def$0324) + 8|0);
     $2625 = HEAP32[$2624>>2]|0;
     $2626 = $2625&255;
     $2627 = ($2623<<24>>24)==($2626<<24>>24);
     if ($2627) {
      break;
     }
    }
    $2650 = (($def$0324) + 16|0);
    $2651 = ($2650>>>0)<($2616>>>0);
    if ($2651) {
     $def$0324 = $2650;
    } else {
     label = 777;
     break L16;
    }
   }
   $2628 = HEAP32[$64>>2]|0;
   $2629 = HEAP32[$65>>2]|0;
   $2630 = ($2628|0)<($2629|0);
   if (!($2630)) {
    label = 768;
    break;
   }
   $2631 = HEAP32[$66>>2]|0;
   $2632 = HEAP32[$67>>2]|0;
   $2633 = (($2631) + ($2628<<4)|0);
   HEAP32[$2633>>2] = $2632;
   $2634 = HEAP32[$22>>2]|0;
   $2635 = (($2634) + 1)|0;
   $2636 = ((($2631) + ($2628<<4)|0) + 4|0);
   HEAP32[$2636>>2] = $2635;
   $2637 = ((($2631) + ($2628<<4)|0) + 8|0);
   HEAP32[$2637>>2] = 1;
   $2638 = (($def$0324) + 4|0);
   $2639 = HEAP32[$2638>>2]|0;
   $2640 = ((($2631) + ($2628<<4)|0) + 12|0);
   HEAP32[$2640>>2] = $2639;
   $2641 = HEAP32[$def$0324>>2]|0;
   $2642 = HEAP32[$2638>>2]|0;
   $aRange$off$i = (($2641) + -1)|0;
   $2643 = ($aRange$off$i>>>0)>(2);
   if ($2643) {
    label = 770;
    break;
   }
   $2644 = ((($exc) + ($aRange$off$i<<3)|0) + 444|0);
   $2645 = HEAP32[$2644>>2]|0;
   $2646 = ($2645|0)==(0|0);
   if ($2646) {
    label = 772;
    break;
   }
   $2647 = ((($exc) + ($aRange$off$i<<3)|0) + 448|0);
   $2648 = HEAP32[$2647>>2]|0;
   $2649 = ($2648>>>0)<($2642>>>0);
   if ($2649) {
    label = 774;
    break;
   }
   HEAP32[$23>>2] = $2645;
   HEAP32[$26>>2] = $2648;
   HEAP32[$22>>2] = $2642;
   HEAP32[$67>>2] = $2641;
   $ins_counter$1 = $ins_counter$0;
  }
  else if ((label|0) == 778) {
   label = 0;
   $2652 = HEAP32[$31>>2]|0;
   HEAP32[$27>>2] = $2652;
   $2653 = HEAP8[$33>>0]|0;
   $2654 = ($2653<<24>>24)==(0);
   if (!($2654)) {
    $2655 = HEAP32[$25>>2]|0;
    $2656 = HEAP32[$22>>2]|0;
    $2657 = (($2656) + ($2655))|0;
    HEAP32[$22>>2] = $2657;
   }
   $2658 = (($ins_counter$0) + 1)|0;
   $2659 = ($ins_counter$0|0)>(999999);
   if ($2659) {
    $$0 = 139;
    label = 789;
    break;
   } else {
    $ins_counter$1 = $2658;
   }
  }
  $2660 = HEAP32[$22>>2]|0;
  $2661 = HEAP32[$26>>2]|0;
  $2662 = ($2660|0)<($2661|0);
  if (!($2662)) {
   label = 782;
   break;
  }
  $2665 = HEAP8[$68>>0]|0;
  $2666 = ($2665<<24>>24)==(0);
  if ($2666) {
   $131 = $2660;$ins_counter$0 = $ins_counter$1;
  } else {
   $$0 = 0;
   label = 789;
   break;
  }
 }
 switch (label|0) {
  case 23: {
   HEAP32[$34>>2] = 129;
   $2674 = 129;
   break;
  }
  case 27: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 37: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 42: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 55: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 66: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 72: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 78: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 84: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 87: {
   HEAP32[$34>>2] = 132;
   $2674 = 132;
   break;
  }
  case 97: {
   HEAP32[$34>>2] = 131;
   $2674 = 131;
   break;
  }
  case 121: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 126: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 132: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 145: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 158: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 168: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 178: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 187: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 193: {
   HEAP32[$34>>2] = 140;
   $2674 = 140;
   break;
  }
  case 196: {
   HEAP32[$34>>2] = 140;
   $2674 = 140;
   break;
  }
  case 204: {
   HEAP32[$34>>2] = 131;
   $2674 = 131;
   break;
  }
  case 206: {
   HEAP32[$34>>2] = 137;
   $2674 = 137;
   break;
  }
  case 208: {
   HEAP32[$34>>2] = 136;
   $2674 = 136;
   break;
  }
  case 212: {
   HEAP32[$34>>2] = 132;
   $2674 = 132;
   break;
  }
  case 214: {
   HEAP32[$34>>2] = 138;
   $2674 = 138;
   break;
  }
  case 216: {
   HEAP32[$34>>2] = 131;
   $2674 = 131;
   break;
  }
  case 220: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 255: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 264: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 281: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 289: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 310: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 342: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 351: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 364: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 383: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 387: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 395: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 416: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 436: {
   HEAP32[$34>>2] = 135;
   $2674 = 135;
   break;
  }
  case 451: {
   HEAP32[$34>>2] = 131;
   $2674 = 131;
   break;
  }
  case 471: {
   HEAP32[$34>>2] = 133;
   $2674 = 133;
   break;
  }
  case 496: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 549: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 568: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 577: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 583: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 589: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 624: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 639: {
   HEAP32[$34>>2] = 141;
   $2674 = 141;
   break;
  }
  case 642: {
   HEAP32[$34>>2] = 141;
   $2674 = 141;
   break;
  }
  case 650: {
   HEAP32[$34>>2] = 131;
   $2674 = 131;
   break;
  }
  case 652: {
   HEAP32[$34>>2] = 137;
   $2674 = 137;
   break;
  }
  case 662: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 668: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 735: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 744: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 751: {
   HEAP32[$34>>2] = 130;
   $2674 = 130;
   break;
  }
  case 768: {
   HEAP32[$34>>2] = 134;
   $2674 = 134;
   break;
  }
  case 770: {
   HEAP32[$34>>2] = 132;
   $2674 = 132;
   break;
  }
  case 772: {
   HEAP32[$34>>2] = 138;
   $2674 = 138;
   break;
  }
  case 774: {
   HEAP32[$34>>2] = 131;
   $2674 = 131;
   break;
  }
  case 777: {
   HEAP32[$34>>2] = 128;
   $2674 = 128;
   break;
  }
  case 782: {
   $2663 = HEAP32[$64>>2]|0;
   $2664 = ($2663|0)>(0);
   if ($2664) {
    HEAP32[$34>>2] = 131;
    $2674 = 131;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 785: {
   HEAP32[$34>>2] = 131;
   $2674 = 131;
   break;
  }
  case 786: {
   $2667 = ($$pr$pr$pr|0)==(0);
   if ($2667) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $2674 = $$pr$pr$pr;
   }
   break;
  }
  case 789: {
   STACKTOP = sp;return ($$0|0);
   break;
  }
 }
 $2668 = HEAP8[$68>>0]|0;
 $2669 = ($2668<<24>>24)==(0);
 if (!($2669)) {
  $$0 = $2674;
  STACKTOP = sp;return ($$0|0);
 }
 $2670 = (($exc) + 4|0);
 $2671 = HEAP32[$2670>>2]|0;
 $2672 = (($2671) + 301|0);
 HEAP8[$2672>>0] = 0;
 $$pre423 = HEAP32[$34>>2]|0;
 $$0 = $$pre423;
 STACKTOP = sp;return ($$0|0);
}
function _Read_CVT_Stretched($exc,$idx) {
 $exc = $exc|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $v$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $v$i$i = sp;
 $0 = (($exc) + 384|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($idx<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($exc) + 244|0);
 $5 = (($exc) + 256|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   $8 = (($exc) + 296|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = ($9<<16>>16)==(0);
   if ($10) {
    $11 = HEAP32[$4>>2]|0;
    HEAP32[$5>>2] = $11;
    $27 = $11;
    break;
   }
   $12 = (($exc) + 294|0);
   $13 = HEAP16[$12>>1]|0;
   $14 = ($13<<16>>16)==(0);
   if ($14) {
    $15 = (($exc) + 248|0);
    $16 = HEAP32[$15>>2]|0;
    HEAP32[$5>>2] = $16;
    $27 = $16;
    break;
   } else {
    $17 = $13 << 16 >> 16;
    $18 = HEAP32[$4>>2]|0;
    $19 = (_FT_MulDiv($17,$18,16384)|0);
    $20 = HEAP16[$8>>1]|0;
    $21 = $20 << 16 >> 16;
    $22 = (($exc) + 248|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (_FT_MulDiv($21,$23,16384)|0);
    HEAP32[$v$i$i>>2] = $19;
    $25 = (($v$i$i) + 4|0);
    HEAP32[$25>>2] = $24;
    $26 = (_FT_Vector_Length($v$i$i)|0);
    HEAP32[$5>>2] = $26;
    $27 = $26;
    break;
   }
  } else {
   $27 = $6;
  }
 } while(0);
 $28 = (_FT_MulFix($3,$27)|0);
 STACKTOP = sp;return ($28|0);
}
function _Write_CVT_Stretched($exc,$idx,$value) {
 $exc = $exc|0;
 $idx = $idx|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $v$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $v$i$i = sp;
 $0 = (($exc) + 244|0);
 $1 = (($exc) + 256|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = (($exc) + 296|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = ($5<<16>>16)==(0);
   if ($6) {
    $7 = HEAP32[$0>>2]|0;
    HEAP32[$1>>2] = $7;
    $23 = $7;
    break;
   }
   $8 = (($exc) + 294|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = ($9<<16>>16)==(0);
   if ($10) {
    $11 = (($exc) + 248|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$1>>2] = $12;
    $23 = $12;
    break;
   } else {
    $13 = $9 << 16 >> 16;
    $14 = HEAP32[$0>>2]|0;
    $15 = (_FT_MulDiv($13,$14,16384)|0);
    $16 = HEAP16[$4>>1]|0;
    $17 = $16 << 16 >> 16;
    $18 = (($exc) + 248|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (_FT_MulDiv($17,$19,16384)|0);
    HEAP32[$v$i$i>>2] = $15;
    $21 = (($v$i$i) + 4|0);
    HEAP32[$21>>2] = $20;
    $22 = (_FT_Vector_Length($v$i$i)|0);
    HEAP32[$1>>2] = $22;
    $23 = $22;
    break;
   }
  } else {
   $23 = $2;
  }
 } while(0);
 $24 = (_FT_DivFix($value,$23)|0);
 $25 = (($exc) + 384|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + ($idx<<2)|0);
 HEAP32[$27>>2] = $24;
 STACKTOP = sp;return;
}
function _Move_CVT_Stretched($exc,$idx,$value) {
 $exc = $exc|0;
 $idx = $idx|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $v$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $v$i$i = sp;
 $0 = (($exc) + 244|0);
 $1 = (($exc) + 256|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = (($exc) + 296|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = ($5<<16>>16)==(0);
   if ($6) {
    $7 = HEAP32[$0>>2]|0;
    HEAP32[$1>>2] = $7;
    $23 = $7;
    break;
   }
   $8 = (($exc) + 294|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = ($9<<16>>16)==(0);
   if ($10) {
    $11 = (($exc) + 248|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$1>>2] = $12;
    $23 = $12;
    break;
   } else {
    $13 = $9 << 16 >> 16;
    $14 = HEAP32[$0>>2]|0;
    $15 = (_FT_MulDiv($13,$14,16384)|0);
    $16 = HEAP16[$4>>1]|0;
    $17 = $16 << 16 >> 16;
    $18 = (($exc) + 248|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (_FT_MulDiv($17,$19,16384)|0);
    HEAP32[$v$i$i>>2] = $15;
    $21 = (($v$i$i) + 4|0);
    HEAP32[$21>>2] = $20;
    $22 = (_FT_Vector_Length($v$i$i)|0);
    HEAP32[$1>>2] = $22;
    $23 = $22;
    break;
   }
  } else {
   $23 = $2;
  }
 } while(0);
 $24 = (_FT_DivFix($value,$23)|0);
 $25 = (($exc) + 384|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + ($idx<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + ($24))|0;
 HEAP32[$27>>2] = $29;
 STACKTOP = sp;return;
}
function _Read_CVT($exc,$idx) {
 $exc = $exc|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 384|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($idx<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function _Write_CVT($exc,$idx,$value) {
 $exc = $exc|0;
 $idx = $idx|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 384|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($idx<<2)|0);
 HEAP32[$2>>2] = $value;
 STACKTOP = sp;return;
}
function _Move_CVT($exc,$idx,$value) {
 $exc = $exc|0;
 $idx = $idx|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 384|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($idx<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($value))|0;
 HEAP32[$2>>2] = $4;
 STACKTOP = sp;return;
}
function _Compute_Funcs($exc) {
 $exc = $exc|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmp = 0, $tmp1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 298|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 << 16 >> 16;
 $3 = ($1<<16>>16)==(16384);
 do {
  if ($3) {
   $4 = (($exc) + 294|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = $5 << 16 >> 16;
   $7 = $6 << 16;
   $8 = (($exc) + 564|0);
   HEAP32[$8>>2] = $7;
   $28 = $5;$46 = $7;
  } else {
   $9 = (($exc) + 300|0);
   $10 = HEAP16[$9>>1]|0;
   $11 = ($10<<16>>16)==(16384);
   if ($11) {
    $12 = (($exc) + 296|0);
    $13 = HEAP16[$12>>1]|0;
    $14 = $13 << 16 >> 16;
    $15 = $14 << 16;
    $16 = (($exc) + 564|0);
    HEAP32[$16>>2] = $15;
    $$phi$trans$insert = (($exc) + 294|0);
    $$pre = HEAP16[$$phi$trans$insert>>1]|0;
    $28 = $$pre;$46 = $15;
    break;
   } else {
    $17 = $10 << 16 >> 16;
    $18 = (($exc) + 294|0);
    $19 = HEAP16[$18>>1]|0;
    $20 = $19 << 16 >> 16;
    $21 = Math_imul($20, $2)|0;
    $22 = (($exc) + 296|0);
    $23 = HEAP16[$22>>1]|0;
    $24 = $23 << 16 >> 16;
    $25 = Math_imul($24, $17)|0;
    $tmp = (($25) + ($21))|0;
    $tmp1 = $tmp << 2;
    $26 = (($exc) + 564|0);
    HEAP32[$26>>2] = $tmp1;
    $28 = $19;$46 = $tmp1;
    break;
   }
  }
 } while(0);
 $27 = ($28<<16>>16)==(16384);
 do {
  if ($27) {
   $29 = (($exc) + 572|0);
   HEAP32[$29>>2] = 1624;
  } else {
   $30 = (($exc) + 296|0);
   $31 = HEAP16[$30>>1]|0;
   $32 = ($31<<16>>16)==(16384);
   $33 = (($exc) + 572|0);
   if ($32) {
    HEAP32[$33>>2] = 1625;
    break;
   } else {
    HEAP32[$33>>2] = 1626;
    break;
   }
  }
 } while(0);
 $34 = (($exc) + 290|0);
 $35 = HEAP16[$34>>1]|0;
 $36 = ($35<<16>>16)==(16384);
 do {
  if ($36) {
   $37 = (($exc) + 576|0);
   HEAP32[$37>>2] = 1624;
  } else {
   $38 = (($exc) + 292|0);
   $39 = HEAP16[$38>>1]|0;
   $40 = ($39<<16>>16)==(16384);
   $41 = (($exc) + 576|0);
   if ($40) {
    HEAP32[$41>>2] = 1625;
    break;
   } else {
    HEAP32[$41>>2] = 1627;
    break;
   }
  }
 } while(0);
 $42 = (($exc) + 584|0);
 HEAP32[$42>>2] = 426;
 $43 = (($exc) + 588|0);
 HEAP32[$43>>2] = 427;
 $44 = (($exc) + 564|0);
 $45 = ($46|0)==(1073741824);
 do {
  if ($45) {
   if ($3) {
    HEAP32[$42>>2] = 428;
    HEAP32[$43>>2] = 429;
    break;
   }
   $47 = (($exc) + 300|0);
   $48 = HEAP16[$47>>1]|0;
   $49 = ($48<<16>>16)==(16384);
   if ($49) {
    HEAP32[$42>>2] = 430;
    HEAP32[$43>>2] = 431;
   }
  }
 } while(0);
 $50 = ($46|0)<(0);
 $51 = (0 - ($46))|0;
 $52 = $50 ? $51 : $46;
 $53 = ($52|0)<(67108864);
 if (!($53)) {
  $54 = (($exc) + 256|0);
  HEAP32[$54>>2] = 0;
  STACKTOP = sp;return;
 }
 HEAP32[$44>>2] = 1073741824;
 $54 = (($exc) + 256|0);
 HEAP32[$54>>2] = 0;
 STACKTOP = sp;return;
}
function _Normalize($Vx,$Vy,$R) {
 $Vx = $Vx|0;
 $Vy = $Vy|0;
 $R = $R|0;
 var $$ = 0, $$01$lcssa = 0, $$0113 = 0, $$02 = 0, $$1 = 0, $$13$lcssa = 0, $$1312 = 0, $$2$lcssa = 0, $$210 = 0, $$24 = 0, $$3 = 0, $$35$ = 0, $$35$lcssa = 0, $$359 = 0, $$4 = 0, $$46 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $W$0$lcssa = 0, $not$ = 0, $v$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $v$i6 = sp;
 $0 = ($Vx|0)<(0);
 $1 = (0 - ($Vx))|0;
 $2 = $0 ? $1 : $Vx;
 $3 = ($2|0)<(65536);
 if ($3) {
  $4 = ($Vy|0)<(0);
  $5 = (0 - ($Vy))|0;
  $6 = $4 ? $5 : $Vy;
  $7 = ($6|0)<(65536);
  if ($7) {
   $8 = $Vx << 8;
   $9 = $Vy << 8;
   HEAP32[$v$i6>>2] = $8;
   $10 = (($v$i6) + 4|0);
   HEAP32[$10>>2] = $9;
   $11 = (_FT_Vector_Length($v$i6)|0);
   $12 = ($11|0)==(0);
   if ($12) {
    STACKTOP = sp;return;
   }
   $13 = (_FT_MulDiv($8,16384,$11)|0);
   $14 = $13&65535;
   HEAP16[$R>>1] = $14;
   $15 = (_FT_MulDiv($9,16384,$11)|0);
   $16 = $15&65535;
   $17 = (($R) + 2|0);
   HEAP16[$17>>1] = $16;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$v$i6>>2] = $Vx;
 $18 = (($v$i6) + 4|0);
 HEAP32[$18>>2] = $Vy;
 $19 = (_FT_Vector_Length($v$i6)|0);
 $20 = (_FT_MulDiv($Vx,16384,$19)|0);
 $21 = (_FT_MulDiv($Vy,16384,$19)|0);
 $22 = Math_imul($20, $20)|0;
 $23 = Math_imul($21, $21)|0;
 $24 = (($23) + ($22))|0;
 $25 = ($20|0)<(0);
 $26 = (0 - ($20))|0;
 $$02 = $25 ? $26 : $20;
 $27 = ($21|0)<(0);
 $28 = (0 - ($21))|0;
 $$ = $27 ? $28 : $21;
 $29 = ($24|0)<(268435456);
 if ($29) {
  $$0113 = $$;$$1312 = $$02;
  while(1) {
   $31 = ($$1312|0)<($$0113|0);
   $32 = $31&1;
   $$24 = (($32) + ($$1312))|0;
   $33 = $32 ^ 1;
   $$1 = (($33) + ($$0113))|0;
   $34 = Math_imul($$24, $$24)|0;
   $35 = Math_imul($$1, $$1)|0;
   $36 = (($35) + ($34))|0;
   $37 = ($36|0)<(268435456);
   if ($37) {
    $$0113 = $$1;$$1312 = $$24;
   } else {
    $$01$lcssa = $$1;$$13$lcssa = $$24;$W$0$lcssa = $36;
    break;
   }
  }
 } else {
  $$01$lcssa = $$;$$13$lcssa = $$02;$W$0$lcssa = $24;
 }
 $30 = ($W$0$lcssa|0)>(268451839);
 if ($30) {
  $$210 = $$01$lcssa;$$359 = $$13$lcssa;
  while(1) {
   $38 = ($$359|0)<($$210|0);
   $39 = $38 << 31 >> 31;
   $$46 = (($39) + ($$359))|0;
   $not$ = $38 ^ 1;
   $40 = $not$ << 31 >> 31;
   $$3 = (($40) + ($$210))|0;
   $41 = Math_imul($$46, $$46)|0;
   $42 = Math_imul($$3, $$3)|0;
   $43 = (($41) + ($42))|0;
   $44 = ($43|0)>(268451839);
   if ($44) {
    $$210 = $$3;$$359 = $$46;
   } else {
    $$2$lcssa = $$3;$$35$lcssa = $$46;
    break;
   }
  }
 } else {
  $$2$lcssa = $$01$lcssa;$$35$lcssa = $$13$lcssa;
 }
 $45 = ($20|0)>(-1);
 $46 = (0 - ($$35$lcssa))|0;
 $$35$ = $45 ? $$35$lcssa : $46;
 $47 = ($21|0)>(-1);
 $48 = (0 - ($$2$lcssa))|0;
 $$4 = $47 ? $$2$lcssa : $48;
 $49 = $$35$&65535;
 HEAP16[$R>>1] = $49;
 $50 = $$4&65535;
 $51 = (($R) + 2|0);
 HEAP16[$51>>1] = $50;
 STACKTOP = sp;return;
}
function _Round_To_Grid($exc,$distance,$compensation) {
 $exc = $exc|0;
 $distance = $distance|0;
 $compensation = $compensation|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)>(-1);
 if ($0) {
  $1 = (($distance) + 32)|0;
  $2 = (($1) + ($compensation))|0;
  $3 = ($distance|0)!=(0);
  $4 = ($2|0)>(0);
  $or$cond = $3 & $4;
  $5 = $2 & -64;
  $$1 = $or$cond ? $5 : 0;
  STACKTOP = sp;return ($$1|0);
 } else {
  $6 = (32 - ($distance))|0;
  $7 = (($6) + ($compensation))|0;
  $8 = $7 & -64;
  $9 = (0 - ($8))|0;
  $10 = ($9|0)>(0);
  $$ = $10 ? 0 : $9;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function _Round_To_Half_Grid($exc,$distance,$compensation) {
 $exc = $exc|0;
 $distance = $distance|0;
 $compensation = $compensation|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)>(-1);
 if ($0) {
  $1 = (($compensation) + ($distance))|0;
  $2 = $1 & -64;
  $3 = $2 | 32;
  $4 = ($distance|0)!=(0);
  $5 = ($3|0)<(0);
  $or$cond = $4 & $5;
  $$1 = $or$cond ? 0 : $3;
  STACKTOP = sp;return ($$1|0);
 } else {
  $6 = (($compensation) - ($distance))|0;
  $7 = $6 & -64;
  $8 = $7 | 32;
  $9 = (0 - ($8))|0;
  $10 = ($9|0)>(0);
  $$ = $10 ? 0 : $9;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function _Round_To_Double_Grid($exc,$distance,$compensation) {
 $exc = $exc|0;
 $distance = $distance|0;
 $compensation = $compensation|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)>(-1);
 if ($0) {
  $1 = (($distance) + 16)|0;
  $2 = (($1) + ($compensation))|0;
  $3 = ($distance|0)!=(0);
  $4 = ($2|0)>(0);
  $or$cond = $3 & $4;
  $5 = $2 & -32;
  $$1 = $or$cond ? $5 : 0;
  STACKTOP = sp;return ($$1|0);
 } else {
  $6 = (16 - ($distance))|0;
  $7 = (($6) + ($compensation))|0;
  $8 = $7 & -32;
  $9 = (0 - ($8))|0;
  $10 = ($9|0)>(0);
  $$ = $10 ? 0 : $9;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function _Current_Ppem($exc) {
 $exc = $exc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $v$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $v$i$i = sp;
 $0 = (($exc) + 252|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 $3 = (($exc) + 244|0);
 $4 = (($exc) + 256|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $7 = (($exc) + 296|0);
   $8 = HEAP16[$7>>1]|0;
   $9 = ($8<<16>>16)==(0);
   if ($9) {
    $10 = HEAP32[$3>>2]|0;
    HEAP32[$4>>2] = $10;
    $26 = $10;
    break;
   }
   $11 = (($exc) + 294|0);
   $12 = HEAP16[$11>>1]|0;
   $13 = ($12<<16>>16)==(0);
   if ($13) {
    $14 = (($exc) + 248|0);
    $15 = HEAP32[$14>>2]|0;
    HEAP32[$4>>2] = $15;
    $26 = $15;
    break;
   } else {
    $16 = $12 << 16 >> 16;
    $17 = HEAP32[$3>>2]|0;
    $18 = (_FT_MulDiv($16,$17,16384)|0);
    $19 = HEAP16[$7>>1]|0;
    $20 = $19 << 16 >> 16;
    $21 = (($exc) + 248|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (_FT_MulDiv($20,$22,16384)|0);
    HEAP32[$v$i$i>>2] = $18;
    $24 = (($v$i$i) + 4|0);
    HEAP32[$24>>2] = $23;
    $25 = (_FT_Vector_Length($v$i$i)|0);
    HEAP32[$4>>2] = $25;
    $26 = $25;
    break;
   }
  } else {
   $26 = $5;
  }
 } while(0);
 $27 = (_FT_MulFix($2,$26)|0);
 STACKTOP = sp;return ($27|0);
}
function _Ins_DELTAP($exc,$args$val) {
 $exc = $exc|0;
 $args$val = $args$val|0;
 var $$ = 0, $$phi$trans$insert$pre = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $C$0 = 0, $k$01 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($args$val|0)==(0);
 $$phi$trans$insert$pre = (($exc) + 28|0);
 L1: do {
  if (!($0)) {
   $1 = (($exc) + 24|0);
   $2 = (($exc) + 36|0);
   $3 = (($exc) + 44|0);
   $4 = (($exc) + 368|0);
   $5 = (($exc) + 332|0);
   $6 = (($exc) + 334|0);
   $7 = (($exc) + 584|0);
   $8 = (($exc) + 561|0);
   $9 = (($exc) + 12|0);
   $k$01 = 2;
   while(1) {
    $10 = HEAP32[$$phi$trans$insert$pre>>2]|0;
    $11 = ($10|0)<(2);
    if ($11) {
     break;
    }
    $14 = (($10) + -2)|0;
    HEAP32[$$phi$trans$insert$pre>>2] = $14;
    $15 = (($10) + -1)|0;
    $16 = HEAP32[$1>>2]|0;
    $17 = (($16) + ($15<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = $18&65535;
    $20 = (($16) + ($14<<2)|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $18 & 65535;
    $23 = HEAP16[$3>>1]|0;
    $24 = $23&65535;
    $25 = ($22>>>0)<($24>>>0);
    if ($25) {
     $26 = $21 >>> 4;
     $27 = $26 & 15;
     $28 = HEAP8[$4>>0]|0;
     $29 = $28&255;
     if ((($29|0) == 113)) {
      $30 = $27 | 16;
      $C$0 = $30;
     } else if ((($29|0) == 114)) {
      $31 = $27 | 32;
      $C$0 = $31;
     } else {
      $C$0 = $27;
     }
     $32 = HEAP16[$5>>1]|0;
     $33 = $32 << 16 >> 16;
     $34 = (($33) + ($C$0))|0;
     $35 = (_Current_Ppem($exc)|0);
     $36 = ($35|0)==($34|0);
     if ($36) {
      $37 = $21 & 15;
      $38 = (($37) + -8)|0;
      $39 = ($38|0)>(-1);
      $40 = (($37) + -7)|0;
      $$ = $39 ? $40 : $38;
      $41 = $$ << 6;
      $42 = HEAP16[$6>>1]|0;
      $43 = $42 << 16 >> 16;
      $44 = 1 << $43;
      $45 = (($41|0) / ($44|0))&-1;
      $46 = HEAP32[$7>>2]|0;
      FUNCTION_TABLE_viiii[$46 & 511]($exc,$2,$19,$45);
     }
    } else {
     $47 = HEAP8[$8>>0]|0;
     $48 = ($47<<24>>24)==(0);
     if (!($48)) {
      HEAP32[$9>>2] = 134;
     }
    }
    $49 = ($k$01>>>0)>($args$val>>>0);
    if ($49) {
     break L1;
    }
    $phitmp = (($k$01) + 1)|0;
    $k$01 = $phitmp;
   }
   $12 = HEAP8[$8>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if (!($13)) {
    HEAP32[$9>>2] = 129;
   }
   HEAP32[$$phi$trans$insert$pre>>2] = 0;
   $51 = 0;
   $50 = (($exc) + 32|0);
   HEAP32[$50>>2] = $51;
   STACKTOP = sp;return;
  }
 } while(0);
 $$pre = HEAP32[$$phi$trans$insert$pre>>2]|0;
 $51 = $$pre;
 $50 = (($exc) + 32|0);
 HEAP32[$50>>2] = $51;
 STACKTOP = sp;return;
}
function _Round_None($exc,$distance,$compensation) {
 $exc = $exc|0;
 $distance = $distance|0;
 $compensation = $compensation|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)>(-1);
 if ($0) {
  $1 = (($compensation) + ($distance))|0;
  $2 = ($distance|0)!=(0);
  $3 = ($1|0)<(0);
  $or$cond = $2 & $3;
  $$1 = $or$cond ? 0 : $1;
  STACKTOP = sp;return ($$1|0);
 } else {
  $4 = (($distance) - ($compensation))|0;
  $5 = ($4|0)>(0);
  $$ = $5 ? 0 : $4;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function _Round_Super($exc,$distance,$compensation) {
 $exc = $exc|0;
 $distance = $distance|0;
 $compensation = $compensation|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $val$0 = 0, $val$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)>(-1);
 if ($0) {
  $1 = (($exc) + 480|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($exc) + 484|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($compensation) + ($distance))|0;
  $6 = (($5) - ($2))|0;
  $7 = (($6) + ($4))|0;
  $8 = (($exc) + 476|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (0 - ($9))|0;
  $11 = $7 & $10;
  $12 = ($distance|0)!=(0);
  $13 = ($11|0)<(0);
  $or$cond = $12 & $13;
  $val$0 = $or$cond ? 0 : $11;
  $14 = (($val$0) + ($2))|0;
  $val$1 = $14;
  STACKTOP = sp;return ($val$1|0);
 } else {
  $15 = (($exc) + 484|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($exc) + 480|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($compensation) - ($distance))|0;
  $20 = (($19) + ($16))|0;
  $21 = (($20) - ($18))|0;
  $22 = (($exc) + 476|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (0 - ($23))|0;
  $25 = $21 & $24;
  $26 = (0 - ($25))|0;
  $27 = ($26|0)>(0);
  $$ = $27 ? 0 : $26;
  $28 = (($$) - ($18))|0;
  $val$1 = $28;
  STACKTOP = sp;return ($val$1|0);
 }
 return 0|0;
}
function _Round_Super_45($exc,$distance,$compensation) {
 $exc = $exc|0;
 $distance = $distance|0;
 $compensation = $compensation|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $val$0 = 0, $val$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)>(-1);
 if ($0) {
  $1 = (($exc) + 480|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($exc) + 484|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($compensation) + ($distance))|0;
  $6 = (($5) - ($2))|0;
  $7 = (($6) + ($4))|0;
  $8 = (($exc) + 476|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7|0) % ($9|0))&-1;
  $11 = (($7) - ($10))|0;
  $12 = ($distance|0)!=(0);
  $13 = ($11|0)<(0);
  $or$cond = $12 & $13;
  $val$0 = $or$cond ? 0 : $11;
  $14 = (($val$0) + ($2))|0;
  $val$1 = $14;
  STACKTOP = sp;return ($val$1|0);
 } else {
  $15 = (($exc) + 484|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($exc) + 480|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($compensation) - ($distance))|0;
  $20 = (($19) + ($16))|0;
  $21 = (($20) - ($18))|0;
  $22 = (($exc) + 476|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21|0) % ($23|0))&-1;
  $25 = (($24) - ($21))|0;
  $26 = ($25|0)>(0);
  $$ = $26 ? 0 : $25;
  $27 = (($$) - ($18))|0;
  $val$1 = $27;
  STACKTOP = sp;return ($val$1|0);
 }
 return 0|0;
}
function _Round_Up_To_Grid($exc,$distance,$compensation) {
 $exc = $exc|0;
 $distance = $distance|0;
 $compensation = $compensation|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)>(-1);
 if ($0) {
  $1 = (($distance) + 63)|0;
  $2 = (($1) + ($compensation))|0;
  $3 = ($distance|0)!=(0);
  $4 = ($2|0)>(0);
  $or$cond = $3 & $4;
  $5 = $2 & -64;
  $$1 = $or$cond ? $5 : 0;
  STACKTOP = sp;return ($$1|0);
 } else {
  $6 = (63 - ($distance))|0;
  $7 = (($6) + ($compensation))|0;
  $8 = $7 & -64;
  $9 = (0 - ($8))|0;
  $10 = ($9|0)>(0);
  $$ = $10 ? 0 : $9;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function _Round_Down_To_Grid($exc,$distance,$compensation) {
 $exc = $exc|0;
 $distance = $distance|0;
 $compensation = $compensation|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($distance|0)>(-1);
 if ($0) {
  $1 = (($compensation) + ($distance))|0;
  $2 = ($distance|0)!=(0);
  $3 = ($1|0)>(0);
  $or$cond = $2 & $3;
  $4 = $1 & -64;
  $$1 = $or$cond ? $4 : 0;
  STACKTOP = sp;return ($$1|0);
 } else {
  $5 = (($compensation) - ($distance))|0;
  $6 = $5 & -64;
  $7 = (0 - ($6))|0;
  $8 = ($7|0)>(0);
  $$ = $8 ? 0 : $7;
  STACKTOP = sp;return ($$|0);
 }
 return 0|0;
}
function _Compute_Point_Displacement($exc,$x,$y,$zone,$refp) {
 $exc = $exc|0;
 $x = $x|0;
 $y = $y|0;
 $zone = $zone|0;
 $refp = $refp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $p$0 = 0, $p$0$in = 0;
 var $zp$sroa$1$0 = 0, $zp$sroa$2$0 = 0, $zp$sroa$2$0$in = 0, $zp$sroa$2$0$in$in = 0, $zp$sroa$3$0 = 0, $zp$sroa$4$0 = 0, $zp$sroa$5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $zp$sroa$5 = sp;
 $0 = (($exc) + 368|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $19 = (($exc) + 72|0);
  $20 = $19;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + 4)|0;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($exc) + 80|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($exc) + 84|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($exc) + 88|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($exc) + 92|0);
  ;HEAP32[$zp$sroa$5+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$zp$sroa$5+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$zp$sroa$5+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$zp$sroa$5+12>>2]=HEAP32[$32+12>>2]|0;
  $33 = (($exc) + 288|0);
  $42 = $22;$45 = $25;$p$0$in = $33;$zp$sroa$2$0$in$in = $27;$zp$sroa$3$0 = $29;$zp$sroa$4$0 = $31;
 } else {
  $4 = (($exc) + 36|0);
  $5 = $4;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = (($5) + 4)|0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($exc) + 44|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($exc) + 48|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($exc) + 52|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($exc) + 56|0);
  ;HEAP32[$zp$sroa$5+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$zp$sroa$5+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$zp$sroa$5+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$zp$sroa$5+12>>2]=HEAP32[$17+12>>2]|0;
  $18 = (($exc) + 286|0);
  $42 = $7;$45 = $10;$p$0$in = $18;$zp$sroa$2$0$in$in = $12;$zp$sroa$3$0 = $14;$zp$sroa$4$0 = $16;
 }
 $zp$sroa$1$0 = $zp$sroa$2$0$in$in&65535;
 $p$0 = HEAP16[$p$0$in>>1]|0;
 $34 = $p$0&65535;
 $35 = ($p$0&65535)<($zp$sroa$1$0&65535);
 if ($35) {
  $zp$sroa$2$0$in = $zp$sroa$2$0$in$in >>> 16;
  $zp$sroa$2$0 = $zp$sroa$2$0$in&65535;
  $40 = $zone;
  $41 = $40;
  HEAP32[$41>>2] = $42;
  $43 = (($40) + 4)|0;
  $44 = $43;
  HEAP32[$44>>2] = $45;
  $46 = (($zone) + 8|0);
  HEAP16[$46>>1] = $zp$sroa$1$0;
  $47 = (($zone) + 10|0);
  HEAP16[$47>>1] = $zp$sroa$2$0;
  $48 = (($zone) + 12|0);
  HEAP32[$48>>2] = $zp$sroa$3$0;
  $49 = (($zone) + 16|0);
  HEAP32[$49>>2] = $zp$sroa$4$0;
  $50 = (($zone) + 20|0);
  ;HEAP32[$50+0>>2]=HEAP32[$zp$sroa$5+0>>2]|0;HEAP32[$50+4>>2]=HEAP32[$zp$sroa$5+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$zp$sroa$5+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$zp$sroa$5+12>>2]|0;
  HEAP16[$refp>>1] = $p$0;
  $51 = (($exc) + 572|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($zp$sroa$4$0) + ($34<<3)|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (($zp$sroa$3$0) + ($34<<3)|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($54) - ($56))|0;
  $58 = ((($zp$sroa$4$0) + ($34<<3)|0) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  $60 = ((($zp$sroa$3$0) + ($34<<3)|0) + 4|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($59) - ($61))|0;
  $63 = (FUNCTION_TABLE_iiii[$52 & 2047]($exc,$57,$62)|0);
  $64 = (($exc) + 298|0);
  $65 = HEAP16[$64>>1]|0;
  $66 = $65 << 16 >> 16;
  $67 = $66 << 16;
  $68 = (($exc) + 564|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (_FT_MulDiv($63,$67,$69)|0);
  HEAP32[$x>>2] = $70;
  $71 = (($exc) + 300|0);
  $72 = HEAP16[$71>>1]|0;
  $73 = $72 << 16 >> 16;
  $74 = $73 << 16;
  $75 = HEAP32[$68>>2]|0;
  $76 = (_FT_MulDiv($63,$74,$75)|0);
  HEAP32[$y>>2] = $76;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $36 = (($exc) + 561|0);
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)==(0);
 if (!($38)) {
  $39 = (($exc) + 12|0);
  HEAP32[$39>>2] = 134;
 }
 HEAP16[$refp>>1] = 0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __iup_worker_interpolate($worker,$p1,$p2,$ref1,$ref2) {
 $worker = $worker|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $ref1 = $ref1|0;
 $ref2 = $ref2|0;
 var $$ = 0, $$2 = 0, $$3 = 0, $$pre = 0, $$pre12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0;
 var $i$17 = 0, $or$cond = 0, $ref1$ref2 = 0, $ref2$ref1 = 0, $scale$08 = 0, $scale$1 = 0, $scale$2 = 0, $scale_valid$09 = 0, $scale_valid$1 = 0, $scale_valid$2 = 0, $x$0 = 0, $x1$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($p1>>>0)>($p2>>>0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($worker) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2>>>0)>($ref1>>>0);
 $4 = ($2>>>0)>($ref2>>>0);
 $or$cond = $3 & $4;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $5 = (($worker) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($ref1<<3)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + ($ref2<<3)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)>($10|0);
 $$ = $11 ? $8 : $10;
 $$2 = $11 ? $10 : $8;
 $ref1$ref2 = $11 ? $ref1 : $ref2;
 $ref2$ref1 = $11 ? $ref2 : $ref1;
 $12 = HEAP32[$worker>>2]|0;
 $13 = (($12) + ($ref2$ref1<<3)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + ($ref1$ref2<<3)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($worker) + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + ($ref2$ref1<<3)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) - ($14))|0;
 $22 = (($18) + ($ref1$ref2<<3)|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) - ($16))|0;
 $25 = ($$2|0)==($$|0);
 if ($25) {
  $i$04 = $p1;
  while(1) {
   $28 = (($12) + ($i$04<<3)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)>($14|0);
   $$3 = $30 ? $24 : $21;
   $x$0 = (($$3) + ($29))|0;
   $31 = (($18) + ($i$04<<3)|0);
   HEAP32[$31>>2] = $x$0;
   $32 = (($i$04) + 1)|0;
   $33 = ($32>>>0)>($p2>>>0);
   if ($33) {
    break;
   } else {
    $i$04 = $32;
   }
  }
  STACKTOP = sp;return;
 }
 $26 = (($23) - ($20))|0;
 $27 = (($$) - ($$2))|0;
 $35 = $12;$53 = $18;$i$17 = $p1;$scale$08 = 0;$scale_valid$09 = 0;
 while(1) {
  $34 = (($35) + ($i$17<<3)|0);
  $36 = HEAP32[$34>>2]|0;
  $37 = ($36|0)>($14|0);
  do {
   if ($37) {
    $39 = ($36|0)<($16|0);
    if (!($39)) {
     $40 = (($36) + ($24))|0;
     $50 = $53;$scale$2 = $scale$08;$scale_valid$2 = $scale_valid$09;$x1$0 = $40;
     break;
    }
    $41 = ($scale_valid$09<<24>>24)==(0);
    if ($41) {
     $42 = (_FT_MulDiv($26,65536,$27)|0);
     $scale$1 = $42;$scale_valid$1 = 1;
    } else {
     $scale$1 = $scale$08;$scale_valid$1 = $scale_valid$09;
    }
    $43 = HEAP32[$5>>2]|0;
    $44 = (($43) + ($i$17<<3)|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($45) - ($$2))|0;
    $47 = (_FT_MulFix($46,$scale$1)|0);
    $48 = (($47) + ($20))|0;
    $$pre = HEAP32[$17>>2]|0;
    $50 = $$pre;$scale$2 = $scale$1;$scale_valid$2 = $scale_valid$1;$x1$0 = $48;
   } else {
    $38 = (($36) + ($21))|0;
    $50 = $53;$scale$2 = $scale$08;$scale_valid$2 = $scale_valid$09;$x1$0 = $38;
   }
  } while(0);
  $49 = (($50) + ($i$17<<3)|0);
  HEAP32[$49>>2] = $x1$0;
  $51 = (($i$17) + 1)|0;
  $52 = ($51>>>0)>($p2>>>0);
  if ($52) {
   break;
  }
  $$pre12 = HEAP32[$worker>>2]|0;
  $35 = $$pre12;$53 = $50;$i$17 = $51;$scale$08 = $scale$2;$scale_valid$09 = $scale_valid$2;
 }
 STACKTOP = sp;return;
}
function _Project_x($exc,$dx,$dy) {
 $exc = $exc|0;
 $dx = $dx|0;
 $dy = $dy|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($dx|0);
}
function _Project_y($exc,$dx,$dy) {
 $exc = $exc|0;
 $dx = $dx|0;
 $dy = $dy|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($dy|0);
}
function _Project($exc,$dx,$dy) {
 $exc = $exc|0;
 $dx = $dx|0;
 $dy = $dy|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 294|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 << 16 >> 16;
 $3 = (($exc) + 296|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 << 16 >> 16;
 $6 = $dx & 65535;
 $7 = Math_imul($2, $6)|0;
 $8 = $dx >> 16;
 $9 = Math_imul($2, $8)|0;
 $10 = $9 << 16;
 $11 = (($10) + ($7))|0;
 $12 = $9 >> 16;
 $13 = $7 >> 31;
 $14 = ($11>>>0)<($7>>>0);
 $15 = $14&1;
 $16 = $dy & 65535;
 $17 = Math_imul($5, $16)|0;
 $18 = $dy >> 16;
 $19 = Math_imul($5, $18)|0;
 $20 = $19 << 16;
 $21 = (($20) + ($17))|0;
 $22 = $19 >> 16;
 $23 = $17 >> 31;
 $24 = ($21>>>0)<($17>>>0);
 $25 = $24&1;
 $26 = (($21) + ($11))|0;
 $27 = ($26>>>0)<($11>>>0);
 $28 = $27&1;
 $29 = (($12) + ($13))|0;
 $30 = (($29) + ($23))|0;
 $31 = (($30) + ($22))|0;
 $32 = (($31) + ($15))|0;
 $33 = (($32) + ($25))|0;
 $34 = (($33) + ($28))|0;
 $35 = $34 >> 31;
 $36 = (($35) + ($26))|0;
 $37 = ($36>>>0)<($26>>>0);
 $38 = $37&1;
 $39 = (($36) + 8192)|0;
 $40 = ($36>>>0)>(4294959103);
 $41 = $40&1;
 $42 = (($35) + ($34))|0;
 $43 = (($42) + ($38))|0;
 $44 = (($43) + ($41))|0;
 $45 = $44 << 18;
 $46 = $39 >>> 14;
 $47 = $45 | $46;
 STACKTOP = sp;return ($47|0);
}
function _Dual_Project($exc,$dx,$dy) {
 $exc = $exc|0;
 $dx = $dx|0;
 $dy = $dy|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 290|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 << 16 >> 16;
 $3 = (($exc) + 292|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 << 16 >> 16;
 $6 = $dx & 65535;
 $7 = Math_imul($2, $6)|0;
 $8 = $dx >> 16;
 $9 = Math_imul($2, $8)|0;
 $10 = $9 << 16;
 $11 = (($10) + ($7))|0;
 $12 = $9 >> 16;
 $13 = $7 >> 31;
 $14 = ($11>>>0)<($7>>>0);
 $15 = $14&1;
 $16 = $dy & 65535;
 $17 = Math_imul($5, $16)|0;
 $18 = $dy >> 16;
 $19 = Math_imul($5, $18)|0;
 $20 = $19 << 16;
 $21 = (($20) + ($17))|0;
 $22 = $19 >> 16;
 $23 = $17 >> 31;
 $24 = ($21>>>0)<($17>>>0);
 $25 = $24&1;
 $26 = (($21) + ($11))|0;
 $27 = ($26>>>0)<($11>>>0);
 $28 = $27&1;
 $29 = (($12) + ($13))|0;
 $30 = (($29) + ($23))|0;
 $31 = (($30) + ($22))|0;
 $32 = (($31) + ($15))|0;
 $33 = (($32) + ($25))|0;
 $34 = (($33) + ($28))|0;
 $35 = $34 >> 31;
 $36 = (($35) + ($26))|0;
 $37 = ($36>>>0)<($26>>>0);
 $38 = $37&1;
 $39 = (($36) + 8192)|0;
 $40 = ($36>>>0)>(4294959103);
 $41 = $40&1;
 $42 = (($35) + ($34))|0;
 $43 = (($42) + ($38))|0;
 $44 = (($43) + ($41))|0;
 $45 = $44 << 18;
 $46 = $39 >>> 14;
 $47 = $45 | $46;
 STACKTOP = sp;return ($47|0);
}
function _Direct_Move($exc,$zone,$point,$distance) {
 $exc = $exc|0;
 $zone = $zone|0;
 $point = $point|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 298|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(0);
 if (!($2)) {
  $3 = $1 << 16 >> 16;
  $4 = $3 << 16;
  $5 = (($exc) + 564|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (_FT_MulDiv($distance,$4,$6)|0);
  $8 = $point&65535;
  $9 = (($zone) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8<<3)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($7))|0;
  HEAP32[$11>>2] = $13;
  $14 = (($zone) + 24|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + ($8)|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $18 | 8;
  $20 = $19&255;
  HEAP8[$16>>0] = $20;
 }
 $21 = (($exc) + 300|0);
 $22 = HEAP16[$21>>1]|0;
 $23 = ($22<<16>>16)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = $22 << 16 >> 16;
 $25 = $24 << 16;
 $26 = (($exc) + 564|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (_FT_MulDiv($distance,$25,$27)|0);
 $29 = $point&65535;
 $30 = (($zone) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31) + ($29<<3)|0) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($33) + ($28))|0;
 HEAP32[$32>>2] = $34;
 $35 = (($zone) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + ($29)|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = $38&255;
 $40 = $39 | 16;
 $41 = $40&255;
 HEAP8[$37>>0] = $41;
 STACKTOP = sp;return;
}
function _Direct_Move_Orig($exc,$zone,$point,$distance) {
 $exc = $exc|0;
 $zone = $zone|0;
 $point = $point|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($exc) + 298|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(0);
 if (!($2)) {
  $3 = $1 << 16 >> 16;
  $4 = $3 << 16;
  $5 = (($exc) + 564|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (_FT_MulDiv($distance,$4,$6)|0);
  $8 = $point&65535;
  $9 = (($zone) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($8<<3)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($7))|0;
  HEAP32[$11>>2] = $13;
 }
 $14 = (($exc) + 300|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = ($15<<16>>16)==(0);
 if ($16) {
  STACKTOP = sp;return;
 }
 $17 = $15 << 16 >> 16;
 $18 = $17 << 16;
 $19 = (($exc) + 564|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (_FT_MulDiv($distance,$18,$20)|0);
 $22 = $point&65535;
 $23 = (($zone) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ((($24) + ($22<<3)|0) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + ($21))|0;
 HEAP32[$25>>2] = $27;
 STACKTOP = sp;return;
}
function _Direct_Move_X($exc,$zone,$point,$distance) {
 $exc = $exc|0;
 $zone = $zone|0;
 $point = $point|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $point&65535;
 $1 = (($zone) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<3)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($distance))|0;
 HEAP32[$3>>2] = $5;
 $6 = (($zone) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($0)|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 | 8;
 $12 = $11&255;
 HEAP8[$8>>0] = $12;
 STACKTOP = sp;return;
}
function _Direct_Move_Orig_X($exc,$zone,$point,$distance) {
 $exc = $exc|0;
 $zone = $zone|0;
 $point = $point|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $point&65535;
 $1 = (($zone) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($0<<3)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($distance))|0;
 HEAP32[$3>>2] = $5;
 STACKTOP = sp;return;
}
function _Direct_Move_Y($exc,$zone,$point,$distance) {
 $exc = $exc|0;
 $zone = $zone|0;
 $point = $point|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $point&65535;
 $1 = (($zone) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2) + ($0<<3)|0) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($distance))|0;
 HEAP32[$3>>2] = $5;
 $6 = (($zone) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($0)|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 | 16;
 $12 = $11&255;
 HEAP8[$8>>0] = $12;
 STACKTOP = sp;return;
}
function _Direct_Move_Orig_Y($exc,$zone,$point,$distance) {
 $exc = $exc|0;
 $zone = $zone|0;
 $point = $point|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $point&65535;
 $1 = (($zone) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2) + ($0<<3)|0) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($distance))|0;
 HEAP32[$3>>2] = $5;
 STACKTOP = sp;return;
}
function _ps_hints_done($hints) {
 $hints = $hints|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$hints>>2]|0;
 $1 = (($hints) + 16|0);
 _ps_dimension_done($1,$0);
 $2 = (($hints) + 52|0);
 _ps_dimension_done($2,$0);
 $3 = (($hints) + 4|0);
 HEAP32[$3>>2] = 0;
 HEAP32[$hints>>2] = 0;
 STACKTOP = sp;return;
}
function _ps_dimension_done($dimension,$memory) {
 $dimension = $dimension|0;
 $memory = $memory|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $count$01$i3 = 0, $mask$02$i = 0, $mask$02$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($dimension) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($dimension) + 32|0);
 $3 = ($1|0)==(0);
 if (!($3)) {
  $4 = HEAP32[$2>>2]|0;
  $count$01$i = $1;$mask$02$i = $4;
  while(1) {
   $5 = (($mask$02$i) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   _ft_mem_free($memory,$6);
   ;HEAP32[$mask$02$i+0>>2]=0|0;HEAP32[$mask$02$i+4>>2]=0|0;HEAP32[$mask$02$i+8>>2]=0|0;HEAP32[$mask$02$i+12>>2]=0|0;
   $7 = (($count$01$i) + -1)|0;
   $8 = (($mask$02$i) + 16|0);
   $9 = ($7|0)==(0);
   if ($9) {
    break;
   } else {
    $count$01$i = $7;$mask$02$i = $8;
   }
  }
 }
 $10 = HEAP32[$2>>2]|0;
 _ft_mem_free($memory,$10);
 HEAP32[$2>>2] = 0;
 $11 = (($dimension) + 24|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$0>>2] = 0;
 $12 = (($dimension) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($dimension) + 20|0);
 $15 = ($13|0)==(0);
 if (!($15)) {
  $16 = HEAP32[$14>>2]|0;
  $count$01$i3 = $13;$mask$02$i2 = $16;
  while(1) {
   $17 = (($mask$02$i2) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   _ft_mem_free($memory,$18);
   ;HEAP32[$mask$02$i2+0>>2]=0|0;HEAP32[$mask$02$i2+4>>2]=0|0;HEAP32[$mask$02$i2+8>>2]=0|0;HEAP32[$mask$02$i2+12>>2]=0|0;
   $19 = (($count$01$i3) + -1)|0;
   $20 = (($mask$02$i2) + 16|0);
   $21 = ($19|0)==(0);
   if ($21) {
    break;
   } else {
    $count$01$i3 = $19;$mask$02$i2 = $20;
   }
  }
 }
 $22 = HEAP32[$14>>2]|0;
 _ft_mem_free($memory,$22);
 HEAP32[$14>>2] = 0;
 $23 = (($dimension) + 12|0);
 HEAP32[$23>>2] = 0;
 HEAP32[$12>>2] = 0;
 $24 = (($dimension) + 8|0);
 $25 = HEAP32[$24>>2]|0;
 _ft_mem_free($memory,$25);
 HEAP32[$24>>2] = 0;
 HEAP32[$dimension>>2] = 0;
 $26 = (($dimension) + 4|0);
 HEAP32[$26>>2] = 0;
 STACKTOP = sp;return;
}
function _ps_hints_init($hints,$memory) {
 $hints = $hints|0;
 $memory = $memory|0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$hints+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$hints>>2] = $memory;
 STACKTOP = sp;return 0;
}
function _t1_hints_funcs_init($funcs) {
 $funcs = $funcs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$funcs+0|0; stop=dest+24|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 $0 = (($funcs) + 4|0);
 HEAP32[$0>>2] = 3750;
 $1 = (($funcs) + 8|0);
 HEAP32[$1>>2] = 2706;
 $2 = (($funcs) + 12|0);
 HEAP32[$2>>2] = 2068;
 $3 = (($funcs) + 16|0);
 HEAP32[$3>>2] = 2069;
 $4 = (($funcs) + 20|0);
 HEAP32[$4>>2] = 3452;
 $5 = (($funcs) + 24|0);
 HEAP32[$5>>2] = 294;
 STACKTOP = sp;return;
}
function _t1_hints_open($hints) {
 $hints = $hints|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hints) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($hints) + 12|0);
 HEAP32[$1>>2] = 1;
 $2 = (($hints) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (($hints) + 28|0);
 HEAP32[$3>>2] = 0;
 $4 = (($hints) + 40|0);
 HEAP32[$4>>2] = 0;
 $5 = (($hints) + 52|0);
 HEAP32[$5>>2] = 0;
 $6 = (($hints) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($hints) + 76|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function _ps_hints_close($hints,$end_point) {
 $hints = $hints|0;
 $end_point = $end_point|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hints) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = HEAP32[$hints>>2]|0;
  $4 = (($hints) + 16|0);
  $5 = (_ps_dimension_end($4,$end_point,$3)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = (($hints) + 52|0);
   $8 = (_ps_dimension_end($7,$end_point,$3)|0);
   $error$0 = $8;
  } else {
   $error$0 = $5;
  }
 } else {
  $error$0 = $1;
 }
 STACKTOP = sp;return ($error$0|0);
}
function _t1_hints_stem($hints,$dimension,$coords) {
 $hints = $hints|0;
 $dimension = $dimension|0;
 $coords = $coords|0;
 var $$dimension$i = 0, $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $stems = 0, $switch$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $stems = sp;
 $0 = HEAP32[$coords>>2]|0;
 $1 = (_FT_RoundFix($0)|0);
 $2 = $1 >> 16;
 HEAP32[$stems>>2] = $2;
 $3 = (($coords) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (_FT_RoundFix($4)|0);
 $6 = $5 >> 16;
 $7 = (($stems) + 4|0);
 HEAP32[$7>>2] = $6;
 $8 = (($hints) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($hints) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $$off$i = (($12) + -1)|0;
 $switch$i = ($$off$i>>>0)<(2);
 if (!($switch$i)) {
  STACKTOP = sp;return;
 }
 $13 = ($dimension>>>0)>(1);
 $$dimension$i = $13 ? 1 : $dimension;
 $14 = ((($hints) + (($$dimension$i*36)|0)|0) + 16|0);
 $15 = HEAP32[$hints>>2]|0;
 $16 = (($stems) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (_ps_dimension_add_t1stem($14,$2,$17,$15,0)|0);
 $19 = ($18|0)==(0);
 if ($19) {
  STACKTOP = sp;return;
 }
 HEAP32[$8>>2] = $18;
 STACKTOP = sp;return;
}
function _ps_hints_t1stem3($hints,$dimension,$stems) {
 $hints = $hints|0;
 $dimension = $dimension|0;
 $stems = $stems|0;
 var $$026 = 0, $$dimension = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond$i = 0, $cond21$i = 0, $count$023$i = 0, $count$07 = 0, $error$0 = 0, $error$i$i$i = 0, $error$i$i13$i = 0, $error$i$i3$i = 0;
 var $error$i$i9$i = 0, $idx = 0, $mask$0$i15$i = 0, $storemerge22$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $error$i$i13$i = sp + 24|0;
 $error$i$i9$i = sp;
 $error$i$i3$i = sp + 4|0;
 $error$i$i$i = sp + 8|0;
 $idx = sp + 12|0;
 $0 = (($hints) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$hints>>2]|0;
 $4 = ($dimension>>>0)>(1);
 $$dimension = $4 ? 1 : $dimension;
 $5 = ((($hints) + (($$dimension*36)|0)|0) + 16|0);
 $6 = (($hints) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(1);
 L4: do {
  if ($8) {
   $$026 = $stems;$count$07 = 0;
   while(1) {
    $9 = HEAP32[$$026>>2]|0;
    $10 = (_FT_RoundFix($9)|0);
    $11 = $10 >> 16;
    $12 = (($$026) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (_FT_RoundFix($13)|0);
    $15 = $14 >> 16;
    $16 = (($idx) + ($count$07<<2)|0);
    $17 = (_ps_dimension_add_t1stem($5,$11,$15,$3,$16)|0);
    $18 = ($17|0)==(0);
    if (!($18)) {
     $error$0 = $17;
     break L4;
    }
    $19 = (($count$07) + 1)|0;
    $20 = (($$026) + 8|0);
    $21 = ($19|0)<(3);
    if ($21) {
     $$026 = $20;$count$07 = $19;
    } else {
     break;
    }
   }
   $22 = HEAP32[$idx>>2]|0;
   $23 = (($idx) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($idx) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($hints) + (($$dimension*36)|0)|0) + 40|0);
   $28 = HEAP32[$27>>2]|0;
   $cond21$i = ($28|0)==(0);
   L9: do {
    if ($cond21$i) {
     label = 14;
    } else {
     $29 = ((($hints) + (($$dimension*36)|0)|0) + 48|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = $22 >> 3;
     $32 = $22 & 7;
     $33 = 128 >>> $32;
     $34 = $24 >> 3;
     $35 = $24 & 7;
     $36 = 128 >>> $35;
     $37 = $26 >> 3;
     $38 = $26 & 7;
     $39 = 128 >>> $38;
     $count$023$i = $28;$storemerge22$i = $30;
     while(1) {
      $40 = HEAP32[$storemerge22$i>>2]|0;
      $41 = ($40>>>0)>($22>>>0);
      if ($41) {
       $42 = (($storemerge22$i) + 8|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = (($43) + ($31)|0);
       $45 = HEAP8[$44>>0]|0;
       $46 = $45&255;
       $47 = $46 & $33;
       $48 = ($47|0)==(0);
       if (!($48)) {
        $mask$0$i15$i = $storemerge22$i;
        break L9;
       }
      }
      $49 = ($40>>>0)>($24>>>0);
      if ($49) {
       $50 = (($storemerge22$i) + 8|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + ($34)|0);
       $53 = HEAP8[$52>>0]|0;
       $54 = $53&255;
       $55 = $54 & $36;
       $56 = ($55|0)==(0);
       if (!($56)) {
        $mask$0$i15$i = $storemerge22$i;
        break L9;
       }
      }
      $57 = ($40>>>0)>($26>>>0);
      if ($57) {
       $58 = (($storemerge22$i) + 8|0);
       $59 = HEAP32[$58>>2]|0;
       $60 = (($59) + ($37)|0);
       $61 = HEAP8[$60>>0]|0;
       $62 = $61&255;
       $63 = $62 & $39;
       $64 = ($63|0)==(0);
       if (!($64)) {
        $mask$0$i15$i = $storemerge22$i;
        break L9;
       }
      }
      $65 = (($count$023$i) + -1)|0;
      $66 = (($storemerge22$i) + 16|0);
      $cond$i = ($65|0)==(0);
      if ($cond$i) {
       label = 14;
       break;
      } else {
       $count$023$i = $65;$storemerge22$i = $66;
      }
     }
    }
   } while(0);
   if ((label|0) == 14) {
    $67 = (($28) + 1)|0;
    $68 = ((($hints) + (($$dimension*36)|0)|0) + 44|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($67>>>0)>($69>>>0);
    if ($70) {
     HEAP32[$error$i$i13$i>>2] = 0;
     $71 = (($28) + 8)|0;
     $72 = $71 & -8;
     $73 = ((($hints) + (($$dimension*36)|0)|0) + 48|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (_ft_mem_realloc($3,16,$69,$72,$74,$error$i$i13$i)|0);
     HEAP32[$73>>2] = $75;
     $76 = HEAP32[$error$i$i13$i>>2]|0;
     $77 = ($76|0)==(0);
     if (!($77)) {
      $error$0 = $76;
      break;
     }
     HEAP32[$68>>2] = $72;
     $79 = $75;
    } else {
     $$phi$trans$insert$i = ((($hints) + (($$dimension*36)|0)|0) + 48|0);
     $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
     $79 = $$pre$i;
    }
    $78 = (($79) + ($28<<4)|0);
    HEAP32[$78>>2] = 0;
    $80 = ((($79) + ($28<<4)|0) + 12|0);
    HEAP32[$80>>2] = 0;
    HEAP32[$27>>2] = $67;
    $mask$0$i15$i = $78;
   }
   $81 = ($22|0)<(0);
   if (!($81)) {
    $82 = HEAP32[$mask$0$i15$i>>2]|0;
    $83 = ($82>>>0)>($22>>>0);
    if (!($83)) {
     $84 = (($22) + 1)|0;
     $85 = (($mask$0$i15$i) + 4|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($86) + 7)|0;
     $88 = $87 >>> 3;
     $89 = (($22) + 8)|0;
     $90 = $89 >>> 3;
     HEAP32[$error$i$i9$i>>2] = 0;
     $91 = ($90>>>0)>($88>>>0);
     if ($91) {
      $92 = (($90) + 7)|0;
      $93 = $92 & 1073741816;
      $94 = (($mask$0$i15$i) + 8|0);
      $95 = HEAP32[$94>>2]|0;
      $96 = (_ft_mem_realloc($3,1,$88,$93,$95,$error$i$i9$i)|0);
      HEAP32[$94>>2] = $96;
      $97 = HEAP32[$error$i$i9$i>>2]|0;
      $98 = ($97|0)==(0);
      if (!($98)) {
       $error$0 = $97;
       break;
      }
      $99 = $93 << 3;
      HEAP32[$85>>2] = $99;
     }
     HEAP32[$mask$0$i15$i>>2] = $84;
    }
    $100 = (($mask$0$i15$i) + 8|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = $22 >> 3;
    $103 = (($101) + ($102)|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = $104&255;
    $106 = $22 & 7;
    $107 = 128 >>> $106;
    $108 = $105 | $107;
    $109 = $108&255;
    HEAP8[$103>>0] = $109;
   }
   $110 = ($24|0)<(0);
   if (!($110)) {
    $111 = HEAP32[$mask$0$i15$i>>2]|0;
    $112 = ($111>>>0)>($24>>>0);
    if (!($112)) {
     $113 = (($24) + 1)|0;
     $114 = (($mask$0$i15$i) + 4|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = (($115) + 7)|0;
     $117 = $116 >>> 3;
     $118 = (($24) + 8)|0;
     $119 = $118 >>> 3;
     HEAP32[$error$i$i3$i>>2] = 0;
     $120 = ($119>>>0)>($117>>>0);
     if ($120) {
      $121 = (($119) + 7)|0;
      $122 = $121 & 1073741816;
      $123 = (($mask$0$i15$i) + 8|0);
      $124 = HEAP32[$123>>2]|0;
      $125 = (_ft_mem_realloc($3,1,$117,$122,$124,$error$i$i3$i)|0);
      HEAP32[$123>>2] = $125;
      $126 = HEAP32[$error$i$i3$i>>2]|0;
      $127 = ($126|0)==(0);
      if (!($127)) {
       $error$0 = $126;
       break;
      }
      $128 = $122 << 3;
      HEAP32[$114>>2] = $128;
     }
     HEAP32[$mask$0$i15$i>>2] = $113;
    }
    $129 = (($mask$0$i15$i) + 8|0);
    $130 = HEAP32[$129>>2]|0;
    $131 = $24 >> 3;
    $132 = (($130) + ($131)|0);
    $133 = HEAP8[$132>>0]|0;
    $134 = $133&255;
    $135 = $24 & 7;
    $136 = 128 >>> $135;
    $137 = $134 | $136;
    $138 = $137&255;
    HEAP8[$132>>0] = $138;
   }
   $139 = ($26|0)<(0);
   if ($139) {
    STACKTOP = sp;return;
   }
   $140 = HEAP32[$mask$0$i15$i>>2]|0;
   $141 = ($140>>>0)>($26>>>0);
   if (!($141)) {
    $142 = (($26) + 1)|0;
    $143 = (($mask$0$i15$i) + 4|0);
    $144 = HEAP32[$143>>2]|0;
    $145 = (($144) + 7)|0;
    $146 = $145 >>> 3;
    $147 = (($26) + 8)|0;
    $148 = $147 >>> 3;
    HEAP32[$error$i$i$i>>2] = 0;
    $149 = ($148>>>0)>($146>>>0);
    if ($149) {
     $150 = (($148) + 7)|0;
     $151 = $150 & 1073741816;
     $152 = (($mask$0$i15$i) + 8|0);
     $153 = HEAP32[$152>>2]|0;
     $154 = (_ft_mem_realloc($3,1,$146,$151,$153,$error$i$i$i)|0);
     HEAP32[$152>>2] = $154;
     $155 = HEAP32[$error$i$i$i>>2]|0;
     $156 = ($155|0)==(0);
     if (!($156)) {
      $error$0 = $155;
      break;
     }
     $157 = $151 << 3;
     HEAP32[$143>>2] = $157;
    }
    HEAP32[$mask$0$i15$i>>2] = $142;
   }
   $158 = (($mask$0$i15$i) + 8|0);
   $159 = HEAP32[$158>>2]|0;
   $160 = $26 >> 3;
   $161 = (($159) + ($160)|0);
   $162 = HEAP8[$161>>0]|0;
   $163 = $162&255;
   $164 = $26 & 7;
   $165 = 128 >>> $164;
   $166 = $163 | $165;
   $167 = $166&255;
   HEAP8[$161>>0] = $167;
   STACKTOP = sp;return;
  } else {
   $error$0 = 6;
  }
 } while(0);
 HEAP32[$0>>2] = $error$0;
 STACKTOP = sp;return;
}
function _ps_hints_t1reset($hints,$end_point) {
 $hints = $hints|0;
 $end_point = $end_point|0;
 var $$phi$trans$insert$i = 0, $$phi$trans$insert$i5 = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre1$i = 0, $$pre1$i6 = 0, $$sum$i$i = 0, $$sum$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, $error$i$i$i = 0, $error$i$i$i1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i$i$i1 = sp + 4|0;
 $error$i$i$i = sp;
 $0 = (($hints) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$hints>>2]|0;
 $4 = (($hints) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(1);
 do {
  if ($6) {
   $7 = (($hints) + 28|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    $14 = 0;
   } else {
    $10 = (($hints) + 36|0);
    $11 = HEAP32[$10>>2]|0;
    $$sum$i$i = (($8) + -1)|0;
    $12 = ((($11) + ($$sum$i$i<<4)|0) + 12|0);
    HEAP32[$12>>2] = $end_point;
    $$pre$i = HEAP32[$7>>2]|0;
    $14 = $$pre$i;
   }
   $13 = (($14) + 1)|0;
   $15 = (($hints) + 32|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($13>>>0)>($16>>>0);
   if ($17) {
    HEAP32[$error$i$i$i>>2] = 0;
    $18 = (($14) + 8)|0;
    $19 = $18 & -8;
    $20 = (($hints) + 36|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (_ft_mem_realloc($3,16,$16,$19,$21,$error$i$i$i)|0);
    HEAP32[$20>>2] = $22;
    $23 = HEAP32[$error$i$i$i>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     $error$0 = $23;
     break;
    }
    HEAP32[$15>>2] = $19;
    $26 = $22;
   } else {
    $$phi$trans$insert$i = (($hints) + 36|0);
    $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $26 = $$pre1$i;
   }
   $25 = (($26) + ($14<<4)|0);
   HEAP32[$25>>2] = 0;
   $27 = ((($26) + ($14<<4)|0) + 12|0);
   HEAP32[$27>>2] = 0;
   HEAP32[$7>>2] = $13;
   $28 = (($hints) + 64|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(0);
   if ($30) {
    $35 = 0;
   } else {
    $31 = (($hints) + 72|0);
    $32 = HEAP32[$31>>2]|0;
    $$sum$i$i2 = (($29) + -1)|0;
    $33 = ((($32) + ($$sum$i$i2<<4)|0) + 12|0);
    HEAP32[$33>>2] = $end_point;
    $$pre$i3 = HEAP32[$28>>2]|0;
    $35 = $$pre$i3;
   }
   $34 = (($35) + 1)|0;
   $36 = (($hints) + 68|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($34>>>0)>($37>>>0);
   if ($38) {
    HEAP32[$error$i$i$i1>>2] = 0;
    $39 = (($35) + 8)|0;
    $40 = $39 & -8;
    $41 = (($hints) + 72|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (_ft_mem_realloc($3,16,$37,$40,$42,$error$i$i$i1)|0);
    HEAP32[$41>>2] = $43;
    $44 = HEAP32[$error$i$i$i1>>2]|0;
    $45 = ($44|0)==(0);
    if (!($45)) {
     $error$0 = $44;
     break;
    }
    HEAP32[$36>>2] = $40;
    $47 = $43;
   } else {
    $$phi$trans$insert$i5 = (($hints) + 72|0);
    $$pre1$i6 = HEAP32[$$phi$trans$insert$i5>>2]|0;
    $47 = $$pre1$i6;
   }
   $46 = (($47) + ($35<<4)|0);
   HEAP32[$46>>2] = 0;
   $48 = ((($47) + ($35<<4)|0) + 12|0);
   HEAP32[$48>>2] = 0;
   HEAP32[$28>>2] = $34;
   STACKTOP = sp;return;
  } else {
   $error$0 = 6;
  }
 } while(0);
 HEAP32[$0>>2] = $error$0;
 STACKTOP = sp;return;
}
function _t2_hints_funcs_init($funcs) {
 $funcs = $funcs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$funcs+0>>2]=0|0;HEAP32[$funcs+4>>2]=0|0;HEAP32[$funcs+8>>2]=0|0;HEAP32[$funcs+12>>2]=0|0;HEAP32[$funcs+16>>2]=0|0;HEAP32[$funcs+20>>2]=0|0;
 $0 = (($funcs) + 4|0);
 HEAP32[$0>>2] = 3751;
 $1 = (($funcs) + 8|0);
 HEAP32[$1>>2] = 2706;
 $2 = (($funcs) + 12|0);
 HEAP32[$2>>2] = 432;
 $3 = (($funcs) + 16|0);
 HEAP32[$3>>2] = 433;
 $4 = (($funcs) + 20|0);
 HEAP32[$4>>2] = 2070;
 $5 = (($funcs) + 24|0);
 HEAP32[$5>>2] = 294;
 STACKTOP = sp;return;
}
function _t2_hints_open($hints) {
 $hints = $hints|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hints) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($hints) + 12|0);
 HEAP32[$1>>2] = 2;
 $2 = (($hints) + 16|0);
 HEAP32[$2>>2] = 0;
 $3 = (($hints) + 28|0);
 HEAP32[$3>>2] = 0;
 $4 = (($hints) + 40|0);
 HEAP32[$4>>2] = 0;
 $5 = (($hints) + 52|0);
 HEAP32[$5>>2] = 0;
 $6 = (($hints) + 64|0);
 HEAP32[$6>>2] = 0;
 $7 = (($hints) + 76|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function _t2_hints_stems($hints,$dimension,$count,$coords) {
 $hints = $hints|0;
 $dimension = $dimension|0;
 $count = $count|0;
 $coords = $coords|0;
 var $$ = 0, $$025$i = 0, $$034$i = 0, $$dimension$i = 0, $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$02 = 0, $n$14 = 0, $or$cond = 0, $stems = 0, $switch$i = 0, $total$09 = 0, $y$08 = 0, $y$1$lcssa17 = 0, $y$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $stems = sp;
 $0 = ($count|0)>(0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($hints) + 4|0);
 $2 = (($hints) + 12|0);
 $3 = ($dimension>>>0)>(1);
 $$dimension$i = $3 ? 1 : $dimension;
 $4 = ((($hints) + (($$dimension$i*36)|0)|0) + 16|0);
 $total$09 = $count;$y$08 = 0;
 while(1) {
  $5 = ($total$09|0)>(16);
  $$ = $5 ? 16 : $total$09;
  $6 = $$ << 1;
  $7 = ($$|0)>(0);
  if ($7) {
   $n$02 = 0;$y$11 = $y$08;
   while(1) {
    $8 = (($coords) + ($n$02<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + ($y$11))|0;
    $11 = (_FT_RoundFix($10)|0);
    $12 = $11 >> 16;
    $13 = (($stems) + ($n$02<<2)|0);
    HEAP32[$13>>2] = $12;
    $14 = (($n$02) + 1)|0;
    $15 = ($14|0)<($6|0);
    if ($15) {
     $n$02 = $14;$y$11 = $10;
    } else {
     break;
    }
   }
   if ($7) {
    $n$14 = 0;
    while(1) {
     $16 = $n$14 | 1;
     $17 = (($stems) + ($16<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($stems) + ($n$14<<2)|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) - ($20))|0;
     HEAP32[$17>>2] = $21;
     $22 = (($n$14) + 2)|0;
     $23 = ($22|0)<($6|0);
     if ($23) {
      $n$14 = $22;
     } else {
      $y$1$lcssa17 = $10;
      break;
     }
    }
   } else {
    $y$1$lcssa17 = $10;
   }
  } else {
   $y$1$lcssa17 = $y$08;
  }
  $24 = HEAP32[$1>>2]|0;
  $25 = ($24|0)==(0);
  L13: do {
   if ($25) {
    $26 = HEAP32[$2>>2]|0;
    $$off$i = (($26) + -1)|0;
    $switch$i = ($$off$i>>>0)>(1);
    $27 = ($$|0)==(0);
    $or$cond = $switch$i | $27;
    if (!($or$cond)) {
     $$025$i = $$;$$034$i = $stems;
     while(1) {
      $28 = HEAP32[$hints>>2]|0;
      $29 = HEAP32[$$034$i>>2]|0;
      $30 = (($$034$i) + 4|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (_ps_dimension_add_t1stem($4,$29,$31,$28,0)|0);
      $33 = ($32|0)==(0);
      if (!($33)) {
       break;
      }
      $34 = (($$025$i) + -1)|0;
      $35 = ($34|0)==(0);
      if ($35) {
       break L13;
      }
      $36 = (($$034$i) + 8|0);
      $$025$i = $34;$$034$i = $36;
     }
     HEAP32[$1>>2] = $32;
    }
   }
  } while(0);
  $37 = (($total$09) - ($$))|0;
  $38 = ($37|0)>(0);
  if ($38) {
   $total$09 = $37;$y$08 = $y$1$lcssa17;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _ps_hints_t2mask($hints,$end_point,$bit_count,$bytes) {
 $hints = $hints|0;
 $end_point = $end_point|0;
 $bit_count = $bit_count|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hints) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($hints) + 16|0);
 $4 = HEAP32[$hints>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($hints) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5))|0;
 $9 = ($8|0)==($bit_count|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (_ps_dimension_set_mask_bits($3,$bytes,$7,$5,$end_point,$4)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = (_ps_dimension_set_mask_bits($6,$bytes,0,$7,$end_point,$4)|0);
  $13 = ($12|0)==(0);
  if ($13) {
   STACKTOP = sp;return;
  } else {
   $error$0 = $12;
  }
 } else {
  $error$0 = $10;
 }
 HEAP32[$0>>2] = $error$0;
 STACKTOP = sp;return;
}
function _ps_hints_t2counter($hints,$bit_count,$bytes) {
 $hints = $hints|0;
 $bit_count = $bit_count|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($hints) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($hints) + 16|0);
 $4 = HEAP32[$hints>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($hints) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($5))|0;
 $9 = ($8|0)==($bit_count|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (_ps_dimension_set_mask_bits($3,$bytes,0,$5,0,$4)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = (_ps_dimension_set_mask_bits($6,$bytes,$5,$7,0,$4)|0);
  $13 = ($12|0)==(0);
  if ($13) {
   STACKTOP = sp;return;
  } else {
   $error$0 = $12;
  }
 } else {
  $error$0 = $10;
 }
 HEAP32[$0>>2] = $error$0;
 STACKTOP = sp;return;
}
function _ps_dimension_set_mask_bits($dim,$source,$source_pos,$source_bits,$end_point,$memory) {
 $dim = $dim|0;
 $source = $source|0;
 $source_pos = $source_pos|0;
 $source_bits = $source_bits|0;
 $end_point = $end_point|0;
 $memory = $memory|0;
 var $$$i = 0, $$05$i = 0, $$1$i = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $$pre1$i = 0, $$sum$i$i = 0, $$write$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $error$0 = 0;
 var $error$i$i = 0, $error$i$i$i = 0, $error$i$i$i$i = 0, $mask$0$i1$i$ph$i = 0, $read$06$i = 0, $read$1$i = 0, $rmask$07$i = 0, $rmask$1$i = 0, $wmask$09$i = 0, $write$08$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i$i = sp + 8|0;
 $error$i$i$i$i = sp;
 $error$i$i$i = sp + 4|0;
 $0 = (($dim) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $7 = 0;
 } else {
  $3 = (($dim) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $$sum$i$i = (($1) + -1)|0;
  $5 = ((($4) + ($$sum$i$i<<4)|0) + 12|0);
  HEAP32[$5>>2] = $end_point;
  $$pre$i = HEAP32[$0>>2]|0;
  $7 = $$pre$i;
 }
 $6 = (($7) + 1)|0;
 $8 = (($dim) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($6>>>0)>($9>>>0);
 do {
  if ($10) {
   HEAP32[$error$i$i$i>>2] = 0;
   $11 = (($7) + 8)|0;
   $12 = $11 & -8;
   $13 = (($dim) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (_ft_mem_realloc($memory,16,$9,$12,$14,$error$i$i$i)|0);
   HEAP32[$13>>2] = $15;
   $16 = HEAP32[$error$i$i$i>>2]|0;
   $17 = ($16|0)==(0);
   if ($17) {
    HEAP32[$8>>2] = $12;
    $19 = $15;
    break;
   } else {
    $error$0 = $16;
    STACKTOP = sp;return ($error$0|0);
   }
  } else {
   $$phi$trans$insert$i = (($dim) + 20|0);
   $$pre1$i = HEAP32[$$phi$trans$insert$i>>2]|0;
   $19 = $$pre1$i;
  }
 } while(0);
 $18 = (($19) + ($7<<4)|0);
 HEAP32[$18>>2] = 0;
 $20 = ((($19) + ($7<<4)|0) + 12|0);
 HEAP32[$20>>2] = 0;
 HEAP32[$0>>2] = $6;
 $21 = ($6|0)==(0);
 if ($21) {
  $22 = HEAP32[$8>>2]|0;
  $23 = ($22|0)==(0);
  do {
   if ($23) {
    HEAP32[$error$i$i$i$i>>2] = 0;
    $24 = (($dim) + 20|0);
    $25 = (_ft_mem_realloc($memory,16,0,8,$19,$error$i$i$i$i)|0);
    HEAP32[$24>>2] = $25;
    $26 = HEAP32[$error$i$i$i$i>>2]|0;
    $27 = ($26|0)==(0);
    if ($27) {
     HEAP32[$8>>2] = 8;
     $28 = $25;
     break;
    } else {
     $error$0 = $26;
     STACKTOP = sp;return ($error$0|0);
    }
   } else {
    $28 = $19;
   }
  } while(0);
  HEAP32[$28>>2] = 0;
  $29 = (($28) + 12|0);
  HEAP32[$29>>2] = 0;
  HEAP32[$0>>2] = 1;
  $mask$0$i1$i$ph$i = $28;
 } else {
  $30 = (($19) + ($7<<4)|0);
  $mask$0$i1$i$ph$i = $30;
 }
 $31 = (($mask$0$i1$i$ph$i) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 7)|0;
 $34 = $33 >>> 3;
 $35 = (($source_bits) + 7)|0;
 $36 = $35 >>> 3;
 HEAP32[$error$i$i>>2] = 0;
 $37 = ($36>>>0)>($34>>>0);
 do {
  if ($37) {
   $38 = (($36) + 7)|0;
   $39 = $38 & 1073741816;
   $40 = (($mask$0$i1$i$ph$i) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (_ft_mem_realloc($memory,1,$34,$39,$41,$error$i$i)|0);
   HEAP32[$40>>2] = $42;
   $43 = HEAP32[$error$i$i>>2]|0;
   $44 = ($43|0)==(0);
   if ($44) {
    $45 = $39 << 3;
    HEAP32[$31>>2] = $45;
    break;
   } else {
    $error$0 = $43;
    STACKTOP = sp;return ($error$0|0);
   }
  }
 } while(0);
 HEAP32[$mask$0$i1$i$ph$i>>2] = $source_bits;
 $46 = ($source_bits|0)==(0);
 if ($46) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 $47 = (($mask$0$i1$i$ph$i) + 8|0);
 $48 = $source_pos & 7;
 $49 = $source_pos >>> 3;
 $50 = HEAP32[$47>>2]|0;
 $51 = 128 >>> $48;
 $52 = (($source) + ($49)|0);
 $$05$i = $source_bits;$read$06$i = $52;$rmask$07$i = $51;$wmask$09$i = 128;$write$08$i = $50;
 while(1) {
  $53 = HEAP8[$write$08$i>>0]|0;
  $54 = $53&255;
  $55 = $wmask$09$i ^ 255;
  $56 = $54 & $55;
  $57 = HEAP8[$read$06$i>>0]|0;
  $58 = $57&255;
  $59 = $58 & $rmask$07$i;
  $60 = ($59|0)==(0);
  $61 = $60 ? 0 : $wmask$09$i;
  $$$i = $61 | $56;
  $62 = $$$i&255;
  HEAP8[$write$08$i>>0] = $62;
  $63 = $rmask$07$i >> 1;
  $64 = ($63|0)==(0);
  $65 = (($read$06$i) + 1|0);
  $read$1$i = $64 ? $65 : $read$06$i;
  $rmask$1$i = $64 ? 128 : $63;
  $66 = $wmask$09$i >> 1;
  $67 = ($66|0)==(0);
  $68 = (($write$08$i) + 1|0);
  $$write$0$i = $67 ? $68 : $write$08$i;
  $$1$i = $67 ? 128 : $66;
  $69 = (($$05$i) + -1)|0;
  $70 = ($69|0)==(0);
  if ($70) {
   $error$0 = 0;
   break;
  } else {
   $$05$i = $69;$read$06$i = $read$1$i;$rmask$07$i = $rmask$1$i;$wmask$09$i = $$1$i;$write$08$i = $$write$0$i;
  }
 }
 STACKTOP = sp;return ($error$0|0);
}
function _ps_dimension_add_t1stem($dim,$pos,$len,$memory,$aindex) {
 $dim = $dim|0;
 $pos = $pos|0;
 $len = $len|0;
 $memory = $memory|0;
 $aindex = $aindex|0;
 var $$ = 0, $$01 = 0, $$1 = 0, $$phi$trans$insert$i = 0, $$pos = 0, $$pre$i = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $error$0 = 0, $error$i$i = 0, $error$i$i$i = 0, $error$i$i3 = 0, $flags$1 = 0, $idx$0$lcssa = 0, $idx$014 = 0, $idx$018 = 0, $mask$0$i1$i$ph = 0, $storemerge17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error$i$i3 = sp + 8|0;
 $error$i$i$i = sp;
 $error$i$i = sp + 4|0;
 $0 = ($len|0)<(0);
 if ($0) {
  $1 = ($len|0)==(-21);
  $$ = $1 ? 3 : 1;
  $2 = $1 ? -21 : 0;
  $$pos = (($2) + ($pos))|0;
  $$01 = 0;$$1 = $$pos;$flags$1 = $$;
 } else {
  $$01 = $len;$$1 = $pos;$flags$1 = 0;
 }
 $3 = ($aindex|0)!=(0|0);
 if ($3) {
  HEAP32[$aindex>>2] = -1;
 }
 $4 = HEAP32[$dim>>2]|0;
 $5 = ($4|0)==(0);
 L7: do {
  if ($5) {
   $idx$0$lcssa = 0;
   label = 10;
  } else {
   $6 = (($dim) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $idx$018 = 0;$storemerge17 = $7;
   while(1) {
    $8 = HEAP32[$storemerge17>>2]|0;
    $9 = ($8|0)==($$1|0);
    if ($9) {
     $10 = (($storemerge17) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==($$01|0);
     if ($12) {
      $idx$014 = $idx$018;
      break L7;
     }
    }
    $13 = (($idx$018) + 1)|0;
    $14 = (($storemerge17) + 12|0);
    $15 = ($13>>>0)<($4>>>0);
    if ($15) {
     $idx$018 = $13;$storemerge17 = $14;
    } else {
     $idx$0$lcssa = $13;
     label = 10;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $16 = (($4) + 1)|0;
  $17 = (($dim) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($16>>>0)<($18>>>0);
  do {
   if (!($19)) {
    HEAP32[$error$i$i>>2] = 0;
    $20 = ($18>>>0)<($16>>>0);
    if ($20) {
     $21 = (($4) + 8)|0;
     $22 = $21 & -8;
     $23 = (($dim) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (_ft_mem_realloc($memory,12,$18,$22,$24,$error$i$i)|0);
     HEAP32[$23>>2] = $25;
     $26 = HEAP32[$error$i$i>>2]|0;
     $27 = ($26|0)==(0);
     if ($27) {
      HEAP32[$17>>2] = $22;
      break;
     } else {
      $error$0 = $26;
      STACKTOP = sp;return ($error$0|0);
     }
    }
   }
  } while(0);
  $28 = (($dim) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($29) + (($4*12)|0)|0);
  $31 = ((($29) + (($4*12)|0)|0) + 4|0);
  $32 = ((($29) + (($4*12)|0)|0) + 8|0);
  HEAP32[$dim>>2] = $16;
  HEAP32[$30>>2] = $$1;
  HEAP32[$31>>2] = $$01;
  HEAP32[$32>>2] = $flags$1;
  $idx$014 = $idx$0$lcssa;
 }
 $33 = (($dim) + 12|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 if ($35) {
  $36 = (($dim) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0);
  do {
   if ($38) {
    HEAP32[$error$i$i$i>>2] = 0;
    $39 = (($dim) + 20|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (_ft_mem_realloc($memory,16,0,8,$40,$error$i$i$i)|0);
    HEAP32[$39>>2] = $41;
    $42 = HEAP32[$error$i$i$i>>2]|0;
    $43 = ($42|0)==(0);
    if ($43) {
     HEAP32[$36>>2] = 8;
     $44 = $41;
     break;
    } else {
     $error$0 = $42;
     STACKTOP = sp;return ($error$0|0);
    }
   } else {
    $$phi$trans$insert$i = (($dim) + 20|0);
    $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $44 = $$pre$i;
   }
  } while(0);
  HEAP32[$44>>2] = 0;
  $45 = (($44) + 12|0);
  HEAP32[$45>>2] = 0;
  HEAP32[$33>>2] = 1;
  $mask$0$i1$i$ph = $44;
 } else {
  $46 = (($dim) + 20|0);
  $47 = HEAP32[$46>>2]|0;
  $$sum$i = (($34) + -1)|0;
  $48 = (($47) + ($$sum$i<<4)|0);
  $mask$0$i1$i$ph = $48;
 }
 $49 = ($idx$014|0)<(0);
 if (!($49)) {
  $50 = HEAP32[$mask$0$i1$i$ph>>2]|0;
  $51 = ($50>>>0)>($idx$014>>>0);
  if (!($51)) {
   $52 = (($idx$014) + 1)|0;
   $53 = (($mask$0$i1$i$ph) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($54) + 7)|0;
   $56 = $55 >>> 3;
   $57 = (($idx$014) + 8)|0;
   $58 = $57 >>> 3;
   HEAP32[$error$i$i3>>2] = 0;
   $59 = ($58>>>0)>($56>>>0);
   do {
    if ($59) {
     $60 = (($58) + 7)|0;
     $61 = $60 & 1073741816;
     $62 = (($mask$0$i1$i$ph) + 8|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = (_ft_mem_realloc($memory,1,$56,$61,$63,$error$i$i3)|0);
     HEAP32[$62>>2] = $64;
     $65 = HEAP32[$error$i$i3>>2]|0;
     $66 = ($65|0)==(0);
     if ($66) {
      $67 = $61 << 3;
      HEAP32[$53>>2] = $67;
      break;
     } else {
      $error$0 = $65;
      STACKTOP = sp;return ($error$0|0);
     }
    }
   } while(0);
   HEAP32[$mask$0$i1$i$ph>>2] = $52;
  }
  $68 = (($mask$0$i1$i$ph) + 8|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = $idx$014 >> 3;
  $71 = (($69) + ($70)|0);
  $72 = HEAP8[$71>>0]|0;
  $73 = $72&255;
  $74 = $idx$014 & 7;
  $75 = 128 >>> $74;
  $76 = $73 | $75;
  $77 = $76&255;
  HEAP8[$71>>0] = $77;
 }
 if (!($3)) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 HEAP32[$aindex>>2] = $idx$014;
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _ps_dimension_end($dim,$end_point,$memory) {
 $dim = $dim|0;
 $end_point = $end_point|0;
 $memory = $memory|0;
 var $$pre$i = 0, $$pre$i$i = 0, $$pre$phi$iZ2D = 0, $$pre$phi13$i$iZ2D = 0, $$pre11$i$i = 0, $$pre12$i$i = 0, $$sum$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$0$lcssa$i$i = 0, $count$06$i$i = 0, $dummy$i$i = 0, $error$2$i = 0, $error$i$i$i = 0, $exitcond$i$i = 0, $index1$0$i = 0, $index1$0$in13$i = 0;
 var $index1$0$in13$i$phi = 0, $index1$012$i = 0, $index1$014$i = 0, $index1$index2$i$i = 0, $index2$011$i = 0, $index2$index1$i$i = 0, $or$cond$i = 0, $or$cond$i$i = 0, $p1$0$lcssa$i$i = 0, $p1$05$i$i = 0, $p2$0$lcssa$i$i = 0, $p2$04$i$i = 0, $pos$09$i$i = 0, $pos$15$i$i = 0, $read$06$i$i = 0, $table$idx$i = 0, $table$idx$val$i = 0, $write$07$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $error$i$i$i = sp + 16|0;
 $dummy$i$i = sp;
 $0 = (($dim) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($dim) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $$sum$i = (($1) + -1)|0;
  $5 = ((($4) + ($$sum$i<<4)|0) + 12|0);
  HEAP32[$5>>2] = $end_point;
 }
 $6 = (($dim) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $index1$012$i = (($7) + -1)|0;
 $8 = ($index1$012$i|0)>(0);
 if (!($8)) {
  $error$2$i = 0;
  STACKTOP = sp;return ($error$2$i|0);
 }
 $table$idx$i = (($dim) + 32|0);
 $43 = $7;$index1$0$in13$i = $7;$index1$014$i = $index1$012$i;
 L7: while(1) {
  $9 = (($index1$0$in13$i) + -2)|0;
  $10 = ($9|0)>(-1);
  L9: do {
   if ($10) {
    $table$idx$val$i = HEAP32[$table$idx$i>>2]|0;
    $11 = ((($table$idx$val$i) + ($index1$014$i<<4)|0) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($table$idx$val$i) + ($index1$014$i<<4)|0);
    $14 = HEAP32[$13>>2]|0;
    $index2$011$i = $9;
    L11: while(1) {
     $15 = ((($table$idx$val$i) + ($index2$011$i<<4)|0) + 8|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($table$idx$val$i) + ($index2$011$i<<4)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = ($14>>>0)<=($18>>>0);
     $20 = $19 ? $14 : $18;
     $21 = ($20>>>0)>(7);
     if ($21) {
      $count$06$i$i = $20;$p1$05$i$i = $12;$p2$04$i$i = $16;
      while(1) {
       $22 = HEAP8[$p1$05$i$i>>0]|0;
       $23 = HEAP8[$p2$04$i$i>>0]|0;
       $24 = $23 & $22;
       $25 = ($24<<24>>24)==(0);
       if (!($25)) {
        break L11;
       }
       $26 = (($p1$05$i$i) + 1|0);
       $27 = (($p2$04$i$i) + 1|0);
       $28 = (($count$06$i$i) + -8)|0;
       $29 = ($28>>>0)>(7);
       if ($29) {
        $count$06$i$i = $28;$p1$05$i$i = $26;$p2$04$i$i = $27;
       } else {
        $count$0$lcssa$i$i = $28;$p1$0$lcssa$i$i = $26;$p2$0$lcssa$i$i = $27;
        break;
       }
      }
     } else {
      $count$0$lcssa$i$i = $20;$p1$0$lcssa$i$i = $12;$p2$0$lcssa$i$i = $16;
     }
     $30 = ($count$0$lcssa$i$i|0)==(0);
     if (!($30)) {
      $31 = HEAP8[$p1$0$lcssa$i$i>>0]|0;
      $32 = HEAP8[$p2$0$lcssa$i$i>>0]|0;
      $33 = $32 & $31;
      $34 = $33&255;
      $35 = 255 >>> $count$0$lcssa$i$i;
      $36 = $35 ^ -1;
      $37 = $34 & $36;
      $38 = ($37|0)==(0);
      if (!($38)) {
       break;
      }
     }
     $101 = (($index2$011$i) + -1)|0;
     $102 = ($index2$011$i|0)>(0);
     if ($102) {
      $index2$011$i = $101;
     } else {
      $103 = $43;
      break L9;
     }
    }
    $39 = ($index2$011$i|0)>($index1$014$i|0);
    $index1$index2$i$i = $39 ? $index2$011$i : $index1$014$i;
    $index2$index1$i$i = $39 ? $index1$014$i : $index2$011$i;
    $40 = ($index2$index1$i$i|0)<($index1$index2$i$i|0);
    $41 = ($index2$index1$i$i|0)>(-1);
    $or$cond$i$i = $40 & $41;
    $42 = ($index1$index2$i$i|0)<($43|0);
    $or$cond$i = $or$cond$i$i & $42;
    if ($or$cond$i) {
     $44 = (($table$idx$val$i) + ($index1$index2$i$i<<4)|0);
     $45 = (($table$idx$val$i) + ($index2$index1$i$i<<4)|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = HEAP32[$44>>2]|0;
     $48 = ($47|0)==(0);
     if (!($48)) {
      $49 = ($47>>>0)>($46>>>0);
      if ($49) {
       $50 = ((($table$idx$val$i) + ($index2$index1$i$i<<4)|0) + 4|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 7)|0;
       $53 = $52 >>> 3;
       $54 = (($47) + 7)|0;
       $55 = $54 >>> 3;
       HEAP32[$error$i$i$i>>2] = 0;
       $56 = ($55>>>0)>($53>>>0);
       if ($56) {
        $57 = (($55) + 7)|0;
        $58 = $57 & 1073741816;
        $59 = ((($table$idx$val$i) + ($index2$index1$i$i<<4)|0) + 8|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = (_ft_mem_realloc($memory,1,$53,$58,$60,$error$i$i$i)|0);
        HEAP32[$59>>2] = $61;
        $62 = HEAP32[$error$i$i$i>>2]|0;
        $63 = ($62|0)==(0);
        if (!($63)) {
         $error$2$i = $62;
         label = 32;
         break L7;
        }
        $64 = $58 << 3;
        HEAP32[$50>>2] = $64;
        $$pre$phi$iZ2D = $59;
       } else {
        $$pre$i = ((($table$idx$val$i) + ($index2$index1$i$i<<4)|0) + 8|0);
        $$pre$phi$iZ2D = $$pre$i;
       }
       $pos$09$i$i = $46;
       while(1) {
        $65 = HEAP32[$45>>2]|0;
        $66 = ($65>>>0)>($pos$09$i$i>>>0);
        if ($66) {
         $67 = HEAP32[$$pre$phi$iZ2D>>2]|0;
         $68 = $pos$09$i$i >> 3;
         $69 = (($67) + ($68)|0);
         $70 = HEAP8[$69>>0]|0;
         $71 = $70&255;
         $72 = $pos$09$i$i & 7;
         $73 = 128 >>> $72;
         $74 = $73 ^ 255;
         $75 = $71 & $74;
         $76 = $75&255;
         HEAP8[$69>>0] = $76;
        }
        $77 = (($pos$09$i$i) + 1)|0;
        $exitcond$i$i = ($77|0)==($47|0);
        if ($exitcond$i$i) {
         $$pre$phi13$i$iZ2D = $55;
         break;
        } else {
         $pos$09$i$i = $77;
        }
       }
      } else {
       $$pre11$i$i = (($47) + 7)|0;
       $$pre12$i$i = $$pre11$i$i >>> 3;
       $$pre$phi13$i$iZ2D = $$pre12$i$i;
      }
      $78 = ($$pre$phi13$i$iZ2D|0)==(0);
      if (!($78)) {
       $79 = ((($table$idx$val$i) + ($index2$index1$i$i<<4)|0) + 8|0);
       $80 = ((($table$idx$val$i) + ($index1$index2$i$i<<4)|0) + 8|0);
       $81 = HEAP32[$79>>2]|0;
       $82 = HEAP32[$80>>2]|0;
       $pos$15$i$i = $$pre$phi13$i$iZ2D;$read$06$i$i = $82;$write$07$i$i = $81;
       while(1) {
        $83 = HEAP8[$write$07$i$i>>0]|0;
        $84 = HEAP8[$read$06$i$i>>0]|0;
        $85 = $84 | $83;
        HEAP8[$write$07$i$i>>0] = $85;
        $86 = (($write$07$i$i) + 1|0);
        $87 = (($read$06$i$i) + 1|0);
        $88 = (($pos$15$i$i) + -1)|0;
        $89 = ($88|0)==(0);
        if ($89) {
         break;
        } else {
         $pos$15$i$i = $88;$read$06$i$i = $87;$write$07$i$i = $86;
        }
       }
      }
     }
     HEAP32[$44>>2] = 0;
     $90 = ((($table$idx$val$i) + ($index1$index2$i$i<<4)|0) + 12|0);
     HEAP32[$90>>2] = 0;
     $91 = HEAP32[$6>>2]|0;
     $92 = (($91) + -1)|0;
     $93 = (($92) - ($index1$index2$i$i))|0;
     $94 = ($93|0)>(0);
     if ($94) {
      ;HEAP32[$dummy$i$i+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$dummy$i$i+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$dummy$i$i+8>>2]=HEAP32[$44+8>>2]|0;HEAP32[$dummy$i$i+12>>2]=HEAP32[$44+12>>2]|0;
      $$sum$i$i = (($index1$index2$i$i) + 1)|0;
      $95 = (($table$idx$val$i) + ($$sum$i$i<<4)|0);
      $96 = $93 << 4;
      _memmove(($44|0),($95|0),($96|0))|0;
      $97 = (($table$idx$val$i) + ($92<<4)|0);
      ;HEAP32[$97+0>>2]=HEAP32[$dummy$i$i+0>>2]|0;HEAP32[$97+4>>2]=HEAP32[$dummy$i$i+4>>2]|0;HEAP32[$97+8>>2]=HEAP32[$dummy$i$i+8>>2]|0;HEAP32[$97+12>>2]=HEAP32[$dummy$i$i+12>>2]|0;
      $$pre$i$i = HEAP32[$6>>2]|0;
      $99 = $$pre$i$i;
     } else {
      $99 = $91;
     }
     $98 = (($99) + -1)|0;
     HEAP32[$6>>2] = $98;
     $103 = $98;
    } else {
     $103 = $43;
    }
   } else {
    $103 = $43;
   }
  } while(0);
  $index1$0$i = (($index1$014$i) + -1)|0;
  $100 = ($index1$0$i|0)>(0);
  if ($100) {
   $index1$0$in13$i$phi = $index1$014$i;$43 = $103;$index1$014$i = $index1$0$i;$index1$0$in13$i = $index1$0$in13$i$phi;
  } else {
   $error$2$i = 0;
   label = 32;
   break;
  }
 }
 if ((label|0) == 32) {
  STACKTOP = sp;return ($error$2$i|0);
 }
 return 0|0;
}
function _psh_blues_snap_stem($blues,$stem_top,$stem_bot,$alignment) {
 $blues = $blues|0;
 $stem_top = $stem_top|0;
 $stem_bot = $stem_bot|0;
 $alignment = $alignment|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$07 = 0, $count$12 = 0, $zone$08 = 0, $zone$13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$alignment>>2] = 0;
 $0 = (($blues) + 2080|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = HEAP32[$blues>>2]|0;
 $3 = ($2|0)==(0);
 L1: do {
  if ($3) {
   $45 = 2;
  } else {
   $4 = (($blues) + 4|0);
   $5 = (($blues) + 2076|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (0 - ($6))|0;
   $count$07 = $2;$zone$08 = $4;
   while(1) {
    $8 = (($zone$08) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($stem_top) - ($9))|0;
    $11 = ($10|0)<($7|0);
    if ($11) {
     $45 = 2;
     break L1;
    }
    $12 = (($zone$08) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + ($6))|0;
    $15 = ($14|0)<($stem_top|0);
    if (!($15)) {
     break;
    }
    $23 = (($count$07) + -1)|0;
    $24 = (($zone$08) + 32|0);
    $25 = ($23|0)==(0);
    if ($25) {
     $45 = 2;
     break L1;
    } else {
     $count$07 = $23;$zone$08 = $24;
    }
   }
   $16 = ($1<<24>>24)==(0);
   if ($16) {
    $17 = (($blues) + 2072|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($10|0)>($18|0);
    if ($19) {
     $45 = 2;
     break;
    }
   }
   HEAP32[$alignment>>2] = 1;
   $20 = (($zone$08) + 16|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($alignment) + 4|0);
   HEAP32[$22>>2] = $21;
   $45 = 3;
  }
 } while(0);
 $26 = (($blues) + 516|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $$sum = (($27) + -1)|0;
 $29 = ((($blues) + ($$sum<<5)|0) + 520|0);
 $30 = (($blues) + 2076|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (0 - ($31))|0;
 $count$12 = $27;$zone$13 = $29;
 while(1) {
  $33 = (($zone$13) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($34) - ($stem_bot))|0;
  $36 = ($35|0)<($32|0);
  if ($36) {
   label = 17;
   break;
  }
  $37 = (($zone$13) + 12|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) - ($31))|0;
  $40 = ($39|0)>($stem_bot|0);
  if (!($40)) {
   label = 13;
   break;
  }
  $49 = (($count$12) + -1)|0;
  $50 = (($zone$13) + -32|0);
  $51 = ($49|0)==(0);
  if ($51) {
   label = 17;
   break;
  } else {
   $count$12 = $49;$zone$13 = $50;
  }
 }
 if ((label|0) == 13) {
  $41 = ($1<<24>>24)==(0);
  if ($41) {
   $42 = (($blues) + 2072|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($35|0)<($43|0);
   if (!($44)) {
    STACKTOP = sp;return;
   }
  }
  HEAP32[$alignment>>2] = $45;
  $46 = (($zone$13) + 16|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($alignment) + 8|0);
  HEAP32[$48>>2] = $47;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 17) {
  STACKTOP = sp;return;
 }
}
function _psh_globals_set_scale($globals,$x_scale,$y_scale,$x_delta,$y_delta) {
 $globals = $globals|0;
 $x_scale = $x_scale|0;
 $y_scale = $y_scale|0;
 $x_delta = $x_delta|0;
 $y_delta = $y_delta|0;
 var $$$1$i = 0, $$$i = 0, $$$i10 = 0, $$$i5 = 0, $$1$i = 0, $$1$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$0$i = 0, $count$0$i7 = 0, $count$02$i = 0, $count$02$i1 = 0, $count$04$i = 0, $count$04$i3 = 0, $count$08$i = 0, $count1$05$1$i = 0, $count1$05$i = 0, $count2$03$1$i = 0, $count2$03$i = 0, $exitcond$i = 0, $num$013$i = 0, $table$0$i = 0, $threshold$0$lcssa$i = 0;
 var $threshold$014$i = 0, $width$03$i = 0, $width$03$i4 = 0, $zone$09$i = 0, $zone1$04$1$i = 0, $zone1$04$i = 0, $zone2$02$1$i = 0, $zone2$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($globals) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($x_scale|0);
 $3 = (($globals) + 204|0);
 if ($2) {
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($x_delta|0);
  if (!($5)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  HEAP32[$0>>2] = $x_scale;
  HEAP32[$3>>2] = $x_delta;
  $6 = (($globals) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = (($globals) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (_FT_MulFix($10,$x_scale)|0);
   $12 = (($globals) + 12|0);
   HEAP32[$12>>2] = $11;
   $13 = (($11) + 32)|0;
   $14 = $13 & -64;
   $15 = (($globals) + 16|0);
   HEAP32[$15>>2] = $14;
   $count$02$i = (($7) + -1)|0;
   $16 = ($count$02$i|0)==(0);
   if (!($16)) {
    $17 = (($globals) + 20|0);
    $count$04$i = $count$02$i;$width$03$i = $17;
    while(1) {
     $18 = HEAP32[$width$03$i>>2]|0;
     $19 = (_FT_MulFix($18,$x_scale)|0);
     $20 = HEAP32[$12>>2]|0;
     $21 = (($19) - ($20))|0;
     $22 = ($21|0)<(0);
     $23 = (0 - ($21))|0;
     $$$i = $22 ? $23 : $21;
     $24 = ($$$i|0)<(128);
     $$1$i = $24 ? $20 : $19;
     $25 = (($width$03$i) + 4|0);
     HEAP32[$25>>2] = $$1$i;
     $26 = (($$1$i) + 32)|0;
     $27 = $26 & -64;
     $28 = (($width$03$i) + 8|0);
     HEAP32[$28>>2] = $27;
     $29 = (($width$03$i) + 12|0);
     $count$0$i = (($count$04$i) + -1)|0;
     $30 = ($count$0$i|0)==(0);
     if ($30) {
      break;
     } else {
      $count$04$i = $count$0$i;$width$03$i = $29;
     }
    }
   }
  }
 }
 $31 = (($globals) + 404|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==($y_scale|0);
 $34 = (($globals) + 408|0);
 if ($33) {
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)==($y_delta|0);
  if ($36) {
   STACKTOP = sp;return 0;
  }
 }
 HEAP32[$31>>2] = $y_scale;
 HEAP32[$34>>2] = $y_delta;
 $37 = (($globals) + 208|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($38|0)==(0);
 if (!($39)) {
  $40 = (($globals) + 212|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (_FT_MulFix($41,$y_scale)|0);
  $43 = (($globals) + 216|0);
  HEAP32[$43>>2] = $42;
  $44 = (($42) + 32)|0;
  $45 = $44 & -64;
  $46 = (($globals) + 220|0);
  HEAP32[$46>>2] = $45;
  $count$02$i1 = (($38) + -1)|0;
  $47 = ($count$02$i1|0)==(0);
  if (!($47)) {
   $48 = (($globals) + 224|0);
   $count$04$i3 = $count$02$i1;$width$03$i4 = $48;
   while(1) {
    $49 = HEAP32[$width$03$i4>>2]|0;
    $50 = (_FT_MulFix($49,$y_scale)|0);
    $51 = HEAP32[$43>>2]|0;
    $52 = (($50) - ($51))|0;
    $53 = ($52|0)<(0);
    $54 = (0 - ($52))|0;
    $$$i5 = $53 ? $54 : $52;
    $55 = ($$$i5|0)<(128);
    $$1$i6 = $55 ? $51 : $50;
    $56 = (($width$03$i4) + 4|0);
    HEAP32[$56>>2] = $$1$i6;
    $57 = (($$1$i6) + 32)|0;
    $58 = $57 & -64;
    $59 = (($width$03$i4) + 8|0);
    HEAP32[$59>>2] = $58;
    $60 = (($width$03$i4) + 12|0);
    $count$0$i7 = (($count$04$i3) + -1)|0;
    $61 = ($count$0$i7|0)==(0);
    if ($61) {
     break;
    } else {
     $count$04$i3 = $count$0$i7;$width$03$i4 = $60;
    }
   }
  }
 }
 $62 = (($globals) + 412|0);
 $63 = ($y_scale|0)>(34359737);
 if ($63) {
  $64 = (($globals) + 2476|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = $65 << 3;
  $67 = (($66|0) / 125)&-1;
  $68 = ($67|0)>($y_scale|0);
  $69 = $68&1;
  $70 = (($globals) + 2492|0);
  HEAP8[$70>>0] = $69;
 } else {
  $71 = ($y_scale*125)|0;
  $72 = (($globals) + 2476|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = $73 << 3;
  $75 = ($71|0)<($74|0);
  $76 = $75&1;
  $77 = (($globals) + 2492|0);
  HEAP8[$77>>0] = $76;
 }
 $78 = (($globals) + 2480|0);
 $79 = HEAP32[$78>>2]|0;
 $80 = ($79|0)>(0);
 L24: do {
  if ($80) {
   $threshold$014$i = $79;
   while(1) {
    $83 = (_FT_MulFix($threshold$014$i,$y_scale)|0);
    $84 = ($83|0)>(32);
    $82 = (($threshold$014$i) + -1)|0;
    if (!($84)) {
     $threshold$0$lcssa$i = $threshold$014$i;
     break L24;
    }
    $81 = ($82|0)>(0);
    if ($81) {
     $threshold$014$i = $82;
    } else {
     $threshold$0$lcssa$i = $82;
     break;
    }
   }
  } else {
   $threshold$0$lcssa$i = $79;
  }
 } while(0);
 $85 = (($globals) + 2484|0);
 HEAP32[$85>>2] = $threshold$0$lcssa$i;
 $86 = (($globals) + 1960|0);
 $87 = (($globals) + 928|0);
 $88 = (($globals) + 1444|0);
 $num$013$i = 0;
 while(1) {
  if ((($num$013$i|0) == 0)) {
   $table$0$i = $62;
  } else if ((($num$013$i|0) == 1)) {
   $table$0$i = $87;
  } else if ((($num$013$i|0) == 2)) {
   $table$0$i = $88;
  } else {
   $table$0$i = $86;
  }
  $89 = HEAP32[$table$0$i>>2]|0;
  $90 = ($89|0)==(0);
  if (!($90)) {
   $91 = (($table$0$i) + 4|0);
   $count$08$i = $89;$zone$09$i = $91;
   while(1) {
    $92 = (($zone$09$i) + 8|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = (_FT_MulFix($93,$y_scale)|0);
    $95 = (($94) + ($y_delta))|0;
    $96 = (($zone$09$i) + 28|0);
    HEAP32[$96>>2] = $95;
    $97 = (($zone$09$i) + 12|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (_FT_MulFix($98,$y_scale)|0);
    $100 = (($99) + ($y_delta))|0;
    $101 = (($zone$09$i) + 24|0);
    HEAP32[$101>>2] = $100;
    $102 = HEAP32[$zone$09$i>>2]|0;
    $103 = (_FT_MulFix($102,$y_scale)|0);
    $104 = (($103) + ($y_delta))|0;
    $105 = (($zone$09$i) + 16|0);
    HEAP32[$105>>2] = $104;
    $106 = (($zone$09$i) + 4|0);
    $107 = HEAP32[$106>>2]|0;
    $108 = (_FT_MulFix($107,$y_scale)|0);
    $109 = (($zone$09$i) + 20|0);
    HEAP32[$109>>2] = $108;
    $110 = HEAP32[$105>>2]|0;
    $111 = (($110) + 32)|0;
    $112 = $111 & -64;
    HEAP32[$105>>2] = $112;
    $113 = (($count$08$i) + -1)|0;
    $114 = (($zone$09$i) + 32|0);
    $115 = ($113|0)==(0);
    if ($115) {
     break;
    } else {
     $count$08$i = $113;$zone$09$i = $114;
    }
   }
  }
  $116 = (($num$013$i) + 1)|0;
  $exitcond$i = ($116|0)==(4);
  if ($exitcond$i) {
   break;
  } else {
   $num$013$i = $116;
  }
 }
 $117 = HEAP32[$62>>2]|0;
 $118 = ($117|0)==(0);
 L42: do {
  if (!($118)) {
   $119 = (($globals) + 416|0);
   $120 = (($globals) + 1448|0);
   $count1$05$i = $117;$zone1$04$i = $119;
   while(1) {
    $121 = HEAP32[$88>>2]|0;
    $122 = ($121|0)==(0);
    L46: do {
     if (!($122)) {
      $count2$03$i = $121;$zone2$02$i = $120;
      while(1) {
       $123 = HEAP32[$zone1$04$i>>2]|0;
       $124 = HEAP32[$zone2$02$i>>2]|0;
       $125 = (($123) - ($124))|0;
       $126 = ($125|0)<(0);
       $127 = (0 - ($125))|0;
       $$$i10 = $126 ? $127 : $125;
       $128 = (_FT_MulFix($$$i10,$y_scale)|0);
       $129 = ($128|0)<(64);
       if ($129) {
        break;
       }
       $142 = (($count2$03$i) + -1)|0;
       $143 = (($zone2$02$i) + 32|0);
       $144 = ($142|0)==(0);
       if ($144) {
        break L46;
       } else {
        $count2$03$i = $142;$zone2$02$i = $143;
       }
      }
      $130 = (($zone2$02$i) + 28|0);
      $131 = HEAP32[$130>>2]|0;
      $132 = (($zone1$04$i) + 28|0);
      HEAP32[$132>>2] = $131;
      $133 = (($zone2$02$i) + 24|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = (($zone1$04$i) + 24|0);
      HEAP32[$135>>2] = $134;
      $136 = (($zone2$02$i) + 16|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = (($zone1$04$i) + 16|0);
      HEAP32[$138>>2] = $137;
      $139 = (($zone2$02$i) + 20|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = (($zone1$04$i) + 20|0);
      HEAP32[$141>>2] = $140;
     }
    } while(0);
    $145 = (($count1$05$i) + -1)|0;
    $146 = ($145|0)==(0);
    if ($146) {
     break L42;
    }
    $147 = (($zone1$04$i) + 32|0);
    $count1$05$i = $145;$zone1$04$i = $147;
   }
  }
 } while(0);
 $148 = HEAP32[$87>>2]|0;
 $149 = ($148|0)==(0);
 if ($149) {
  STACKTOP = sp;return 0;
 }
 $150 = (($globals) + 932|0);
 $151 = (($globals) + 1964|0);
 $count1$05$1$i = $148;$zone1$04$1$i = $150;
 while(1) {
  $152 = HEAP32[$86>>2]|0;
  $153 = ($152|0)==(0);
  L60: do {
   if (!($153)) {
    $count2$03$1$i = $152;$zone2$02$1$i = $151;
    while(1) {
     $154 = HEAP32[$zone1$04$1$i>>2]|0;
     $155 = HEAP32[$zone2$02$1$i>>2]|0;
     $156 = (($154) - ($155))|0;
     $157 = ($156|0)<(0);
     $158 = (0 - ($156))|0;
     $$$1$i = $157 ? $158 : $156;
     $159 = (_FT_MulFix($$$1$i,$y_scale)|0);
     $160 = ($159|0)<(64);
     if ($160) {
      break;
     }
     $161 = (($count2$03$1$i) + -1)|0;
     $162 = (($zone2$02$1$i) + 32|0);
     $163 = ($161|0)==(0);
     if ($163) {
      break L60;
     } else {
      $count2$03$1$i = $161;$zone2$02$1$i = $162;
     }
    }
    $164 = (($zone2$02$1$i) + 28|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = (($zone1$04$1$i) + 28|0);
    HEAP32[$166>>2] = $165;
    $167 = (($zone2$02$1$i) + 24|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = (($zone1$04$1$i) + 24|0);
    HEAP32[$169>>2] = $168;
    $170 = (($zone2$02$1$i) + 16|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = (($zone1$04$1$i) + 16|0);
    HEAP32[$172>>2] = $171;
    $173 = (($zone2$02$1$i) + 20|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = (($zone1$04$1$i) + 20|0);
    HEAP32[$175>>2] = $174;
   }
  } while(0);
  $176 = (($count1$05$1$i) + -1)|0;
  $177 = ($176|0)==(0);
  if ($177) {
   break;
  }
  $178 = (($zone1$04$1$i) + 32|0);
  $count1$05$1$i = $176;$zone1$04$1$i = $178;
 }
 STACKTOP = sp;return 0;
}
function _psh_globals_funcs_init($funcs) {
 $funcs = $funcs|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$funcs>>2] = 1628;
 $0 = (($funcs) + 4|0);
 HEAP32[$0>>2] = 230;
 $1 = (($funcs) + 8|0);
 HEAP32[$1>>2] = 3752;
 STACKTOP = sp;return;
}
function _psh_globals_new($memory,$priv,$aglobals) {
 $memory = $memory|0;
 $priv = $priv|0;
 $aglobals = $aglobals|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $count$05 = 0;
 var $count$12 = 0, $error = 0, $read$04 = 0, $read$11 = 0, $write$06 = 0, $write2$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = (_ft_mem_alloc($memory,2496,$error)|0);
 $1 = HEAP32[$error>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $75 = $1;
  HEAP32[$aglobals>>2] = $0;
  STACKTOP = sp;return ($75|0);
 }
 HEAP32[$0>>2] = $memory;
 $3 = (($0) + 4|0);
 $4 = (($0) + 208|0);
 $5 = (($0) + 212|0);
 $6 = (($priv) + 120|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7&65535;
 HEAP32[$5>>2] = $8;
 $9 = (($priv) + 124|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $22 = 0;
 } else {
  $12 = (($0) + 224|0);
  $13 = $10&255;
  $14 = (($priv) + 128|0);
  $count$05 = $13;$read$04 = $14;$write$06 = $12;
  while(1) {
   $15 = HEAP16[$read$04>>1]|0;
   $16 = $15 << 16 >> 16;
   HEAP32[$write$06>>2] = $16;
   $17 = (($write$06) + 12|0);
   $18 = (($read$04) + 2|0);
   $19 = (($count$05) + -1)|0;
   $20 = ($19|0)==(0);
   if ($20) {
    break;
   } else {
    $count$05 = $19;$read$04 = $18;$write$06 = $17;
   }
  }
  $$pre = HEAP8[$9>>0]|0;
  $22 = $$pre;
 }
 $21 = $22&255;
 $23 = (($21) + 1)|0;
 HEAP32[$4>>2] = $23;
 $24 = (($0) + 8|0);
 $25 = (($priv) + 122|0);
 $26 = HEAP16[$25>>1]|0;
 $27 = $26&65535;
 HEAP32[$24>>2] = $27;
 $28 = (($priv) + 125|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if ($30) {
  $41 = 0;
 } else {
  $31 = (($0) + 20|0);
  $32 = $29&255;
  $33 = (($priv) + 154|0);
  $count$12 = $32;$read$11 = $33;$write2$03 = $31;
  while(1) {
   $34 = HEAP16[$read$11>>1]|0;
   $35 = $34 << 16 >> 16;
   HEAP32[$write2$03>>2] = $35;
   $36 = (($write2$03) + 12|0);
   $37 = (($read$11) + 2|0);
   $38 = (($count$12) + -1)|0;
   $39 = ($38|0)==(0);
   if ($39) {
    break;
   } else {
    $count$12 = $38;$read$11 = $37;$write2$03 = $36;
   }
  }
  $$pre10 = HEAP8[$28>>0]|0;
  $41 = $$pre10;
 }
 $40 = $41&255;
 $42 = (($40) + 1)|0;
 HEAP32[$3>>2] = $42;
 $43 = (($0) + 412|0);
 $44 = (($priv) + 8|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = $45&255;
 $47 = (($priv) + 12|0);
 $48 = (($priv) + 9|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = $49&255;
 $51 = (($priv) + 40|0);
 $52 = (($priv) + 116|0);
 $53 = HEAP32[$52>>2]|0;
 _psh_blues_set_zones($43,$46,$47,$50,$51,$53,0);
 $54 = (($priv) + 10|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = $55&255;
 $57 = (($priv) + 60|0);
 $58 = (($priv) + 11|0);
 $59 = HEAP8[$58>>0]|0;
 $60 = $59&255;
 $61 = (($priv) + 88|0);
 $62 = HEAP32[$52>>2]|0;
 _psh_blues_set_zones($43,$56,$57,$60,$61,$62,1);
 $63 = (($priv) + 108|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($0) + 2476|0);
 HEAP32[$65>>2] = $64;
 $66 = (($priv) + 112|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($0) + 2480|0);
 HEAP32[$68>>2] = $67;
 $69 = HEAP32[$52>>2]|0;
 $70 = (($0) + 2488|0);
 HEAP32[$70>>2] = $69;
 $71 = (($0) + 200|0);
 HEAP32[$71>>2] = 0;
 $72 = (($0) + 204|0);
 HEAP32[$72>>2] = 0;
 $73 = (($0) + 404|0);
 HEAP32[$73>>2] = 0;
 $74 = (($0) + 408|0);
 HEAP32[$74>>2] = 0;
 $$pre11 = HEAP32[$error>>2]|0;
 $75 = $$pre11;
 HEAP32[$aglobals>>2] = $0;
 STACKTOP = sp;return ($75|0);
}
function _psh_globals_destroy($globals) {
 $globals = $globals|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($globals|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$globals>>2]|0;
 $2 = (($globals) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = (($globals) + 208|0);
 HEAP32[$3>>2] = 0;
 $4 = (($globals) + 412|0);
 HEAP32[$4>>2] = 0;
 $5 = (($globals) + 928|0);
 HEAP32[$5>>2] = 0;
 $6 = (($globals) + 1444|0);
 HEAP32[$6>>2] = 0;
 $7 = (($globals) + 1960|0);
 HEAP32[$7>>2] = 0;
 _ft_mem_free($1,$globals);
 STACKTOP = sp;return;
}
function _psh_blues_set_zones($target,$count,$blues,$count_others,$other_blues,$fuzz,$family) {
 $target = $target|0;
 $count = $count|0;
 $blues = $blues|0;
 $count_others = $count_others|0;
 $other_blues = $other_blues|0;
 $fuzz = $fuzz|0;
 $family = $family|0;
 var $$017 = 0, $$113 = 0, $$3 = 0, $$3$1 = 0, $$31 = 0, $$31$1 = 0, $$34 = 0, $$34$1 = 0, $$phi$trans$insert25 = 0, $$phi$trans$insert29 = 0, $$pre = 0, $$pre26 = 0, $$pre30 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $bot_table$0 = 0;
 var $scevgep$132 = 0, $scevgep31 = 0, $top$0 = 0, $top$0$1 = 0, $top$0$lcssa = 0, $top$0$lcssa$1 = 0, $top$02 = 0, $top$02$1 = 0, $top$05 = 0, $top$05$1 = 0, $top_table$0 = 0, $uglygep = 0, $uglygep$1 = 0, $zone$016 = 0, $zone1$012 = 0, $zone4$011 = 0, $zone4$011$1 = 0, $zone4$1$lcssa = 0, $zone4$1$lcssa$1 = 0, $zone4$13 = 0;
 var $zone4$13$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($family|0)==(0);
 if ($0) {
  $3 = (($target) + 516|0);
  $bot_table$0 = $3;$top_table$0 = $target;
 } else {
  $1 = (($target) + 1032|0);
  $2 = (($target) + 1548|0);
  $bot_table$0 = $2;$top_table$0 = $1;
 }
 HEAP32[$top_table$0>>2] = 0;
 HEAP32[$bot_table$0>>2] = 0;
 _psh_blues_set_zones_0(0,$count,$blues,$top_table$0,$bot_table$0);
 _psh_blues_set_zones_0(1,$count_others,$other_blues,$top_table$0,$bot_table$0);
 $4 = HEAP32[$top_table$0>>2]|0;
 $5 = HEAP32[$bot_table$0>>2]|0;
 $6 = ($4|0)>(0);
 if ($6) {
  $7 = (($top_table$0) + 4|0);
  $$017 = $4;$zone$016 = $7;
  while(1) {
   $8 = ($$017>>>0)>(1);
   if ($8) {
    $9 = (($zone$016) + 32|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = HEAP32[$zone$016>>2]|0;
    $12 = (($10) - ($11))|0;
    $13 = (($zone$016) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)>($12|0);
    if ($15) {
     HEAP32[$13>>2] = $12;
     $17 = $11;$19 = $12;
    } else {
     $17 = $11;$19 = $14;
    }
   } else {
    $$pre = HEAP32[$zone$016>>2]|0;
    $$phi$trans$insert25 = (($zone$016) + 4|0);
    $$pre26 = HEAP32[$$phi$trans$insert25>>2]|0;
    $17 = $$pre;$19 = $$pre26;
   }
   $16 = (($zone$016) + 12|0);
   HEAP32[$16>>2] = $17;
   $18 = (($17) + ($19))|0;
   $20 = (($zone$016) + 8|0);
   HEAP32[$20>>2] = $18;
   $21 = (($$017) + -1)|0;
   $22 = (($zone$016) + 32|0);
   $23 = ($21|0)==(0);
   if ($23) {
    break;
   } else {
    $$017 = $21;$zone$016 = $22;
   }
  }
 }
 $24 = ($5|0)>(0);
 if ($24) {
  $27 = (($bot_table$0) + 4|0);
  $$113 = $5;$zone1$012 = $27;
  while(1) {
   $28 = ($$113>>>0)>(1);
   $29 = HEAP32[$zone1$012>>2]|0;
   if ($28) {
    $30 = (($zone1$012) + 32|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($29) - ($31))|0;
    $33 = (($zone1$012) + 4|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)<($32|0);
    if ($35) {
     HEAP32[$33>>2] = $32;
     $38 = $32;
    } else {
     $38 = $34;
    }
   } else {
    $$phi$trans$insert29 = (($zone1$012) + 4|0);
    $$pre30 = HEAP32[$$phi$trans$insert29>>2]|0;
    $38 = $$pre30;
   }
   $36 = (($zone1$012) + 8|0);
   HEAP32[$36>>2] = $29;
   $37 = (($29) + ($38))|0;
   $39 = (($zone1$012) + 12|0);
   HEAP32[$39>>2] = $37;
   $40 = (($$113) + -1)|0;
   $41 = (($zone1$012) + 32|0);
   $42 = ($40|0)==(0);
   if ($42) {
    break;
   } else {
    $$113 = $40;$zone1$012 = $41;
   }
  }
 }
 $25 = $fuzz << 1;
 $zone4$011 = (($top_table$0) + 4|0);
 $26 = ($4|0)==(0);
 if (!($26)) {
  $43 = (($top_table$0) + 16|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) - ($fuzz))|0;
  HEAP32[$43>>2] = $45;
  $46 = (($top_table$0) + 12|0);
  $$31 = (($4) + -1)|0;
  $top$02 = HEAP32[$46>>2]|0;
  $47 = ($$31|0)==(0);
  if ($47) {
   $top$0$lcssa = $top$02;$zone4$1$lcssa = $zone4$011;
  } else {
   $uglygep = (($top_table$0) + -28|0);
   $48 = $4 << 3;
   $scevgep31 = (($uglygep) + ($48<<2)|0);
   $$34 = $$31;$top$05 = $top$02;$zone4$13 = $zone4$011;
   while(1) {
    $49 = (($zone4$13) + 32|0);
    $50 = (($zone4$13) + 44|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) - ($top$05))|0;
    $53 = ($52|0)<($25|0);
    if ($53) {
     $54 = (($52|0) / 2)&-1;
     $55 = (($54) + ($top$05))|0;
     HEAP32[$50>>2] = $55;
     $56 = (($zone4$13) + 8|0);
     HEAP32[$56>>2] = $55;
    } else {
     $57 = (($top$05) + ($fuzz))|0;
     $58 = (($zone4$13) + 8|0);
     HEAP32[$58>>2] = $57;
     $59 = (($51) - ($fuzz))|0;
     HEAP32[$50>>2] = $59;
    }
    $60 = (($zone4$13) + 40|0);
    $$3 = (($$34) + -1)|0;
    $top$0 = HEAP32[$60>>2]|0;
    $61 = ($$3|0)==(0);
    if ($61) {
     break;
    } else {
     $$34 = $$3;$top$05 = $top$0;$zone4$13 = $49;
    }
   }
   $top$0$lcssa = $top$0;$zone4$1$lcssa = $scevgep31;
  }
  $62 = (($top$0$lcssa) + ($fuzz))|0;
  $63 = (($zone4$1$lcssa) + 8|0);
  HEAP32[$63>>2] = $62;
 }
 $zone4$011$1 = (($bot_table$0) + 4|0);
 $64 = ($5|0)==(0);
 if ($64) {
  STACKTOP = sp;return;
 }
 $65 = (($bot_table$0) + 16|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) - ($fuzz))|0;
 HEAP32[$65>>2] = $67;
 $68 = (($bot_table$0) + 12|0);
 $$31$1 = (($5) + -1)|0;
 $top$02$1 = HEAP32[$68>>2]|0;
 $69 = ($$31$1|0)==(0);
 if ($69) {
  $top$0$lcssa$1 = $top$02$1;$zone4$1$lcssa$1 = $zone4$011$1;
 } else {
  $uglygep$1 = (($bot_table$0) + -28|0);
  $70 = $5 << 3;
  $scevgep$132 = (($uglygep$1) + ($70<<2)|0);
  $$34$1 = $$31$1;$top$05$1 = $top$02$1;$zone4$13$1 = $zone4$011$1;
  while(1) {
   $71 = (($zone4$13$1) + 32|0);
   $72 = (($zone4$13$1) + 44|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($73) - ($top$05$1))|0;
   $75 = ($74|0)<($25|0);
   if ($75) {
    $79 = (($74|0) / 2)&-1;
    $80 = (($79) + ($top$05$1))|0;
    HEAP32[$72>>2] = $80;
    $81 = (($zone4$13$1) + 8|0);
    HEAP32[$81>>2] = $80;
   } else {
    $76 = (($top$05$1) + ($fuzz))|0;
    $77 = (($zone4$13$1) + 8|0);
    HEAP32[$77>>2] = $76;
    $78 = (($73) - ($fuzz))|0;
    HEAP32[$72>>2] = $78;
   }
   $82 = (($zone4$13$1) + 40|0);
   $$3$1 = (($$34$1) + -1)|0;
   $top$0$1 = HEAP32[$82>>2]|0;
   $83 = ($$3$1|0)==(0);
   if ($83) {
    break;
   } else {
    $$34$1 = $$3$1;$top$05$1 = $top$0$1;$zone4$13$1 = $71;
   }
  }
  $top$0$lcssa$1 = $top$0$1;$zone4$1$lcssa$1 = $scevgep$132;
 }
 $84 = (($top$0$lcssa$1) + ($fuzz))|0;
 $85 = (($zone4$1$lcssa$1) + 8|0);
 HEAP32[$85>>2] = $84;
 STACKTOP = sp;return;
}
function _psh_blues_set_zones_0($is_others,$read_count,$read,$top_table,$bot_table) {
 $is_others = $is_others|0;
 $read_count = $read_count|0;
 $read = $read|0;
 $top_table = $top_table|0;
 $bot_table = $bot_table|0;
 var $$013 = 0, $$017 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $bot_table$pn = 0, $count$0 = 0, $count$12 = 0, $count$25 = 0, $count_bot$0$lcssa = 0, $count_bot$010 = 0, $count_bot$1 = 0, $count_top$0$lcssa = 0, $count_top$08 = 0, $count_top$1 = 0, $delta$0 = 0, $first$012 = 0, $first$1 = 0, $reference$0 = 0, $top$0 = 0, $zone$0$lcssa23 = 0, $zone$03 = 0;
 var $zones$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$top_table>>2]|0;
 $1 = HEAP32[$bot_table>>2]|0;
 $2 = ($read_count>>>0)>(1);
 if ($2) {
  $$013 = $read_count;$$017 = $read;$count_bot$010 = $1;$count_top$08 = $0;$first$012 = 1;
 } else {
  $count_bot$0$lcssa = $1;$count_top$0$lcssa = $0;
  HEAP32[$top_table>>2] = $count_top$0$lcssa;
  HEAP32[$bot_table>>2] = $count_bot$0$lcssa;
  STACKTOP = sp;return;
 }
 while(1) {
  $3 = $first$012 | $is_others;
  $4 = ($3<<24>>24)==(0);
  if ($4) {
   $11 = HEAP16[$$017>>1]|0;
   $12 = $11 << 16 >> 16;
   $13 = (($$017) + 2|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = $14 << 16 >> 16;
   $16 = (($15) - ($12))|0;
   $bot_table$pn = $top_table;$count$0 = $count_top$08;$delta$0 = $16;$first$1 = $first$012;$reference$0 = $12;$top$0 = 1;
  } else {
   $5 = (($$017) + 2|0);
   $6 = HEAP16[$5>>1]|0;
   $7 = $6 << 16 >> 16;
   $8 = HEAP16[$$017>>1]|0;
   $9 = $8 << 16 >> 16;
   $10 = (($9) - ($7))|0;
   $bot_table$pn = $bot_table;$count$0 = $count_bot$010;$delta$0 = $10;$first$1 = 0;$reference$0 = $7;$top$0 = 0;
  }
  $zones$0 = (($bot_table$pn) + 4|0);
  $17 = ($count$0|0)==(0);
  L9: do {
   if ($17) {
    $zone$0$lcssa23 = $zones$0;
    label = 16;
   } else {
    $count$12 = $count$0;$zone$03 = $zones$0;
    while(1) {
     $18 = HEAP32[$zone$03>>2]|0;
     $19 = ($reference$0|0)<($18|0);
     if ($19) {
      label = 14;
      break;
     }
     $20 = ($reference$0|0)==($18|0);
     if ($20) {
      break;
     }
     $26 = (($count$12) + -1)|0;
     $27 = (($zone$03) + 32|0);
     $28 = ($26|0)==(0);
     if ($28) {
      $zone$0$lcssa23 = $27;
      label = 16;
      break L9;
     } else {
      $count$12 = $26;$zone$03 = $27;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     $29 = ($count$12|0)==(0);
     if ($29) {
      $zone$0$lcssa23 = $zone$03;
      label = 16;
      break;
     } else {
      $count$25 = $count$12;
     }
     while(1) {
      $30 = (($zone$03) + ($count$25<<5)|0);
      $31 = (($count$25) + -1)|0;
      $32 = (($zone$03) + ($31<<5)|0);
      ;HEAP32[$30+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$30+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$30+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$30+12>>2]=HEAP32[$32+12>>2]|0;HEAP32[$30+16>>2]=HEAP32[$32+16>>2]|0;HEAP32[$30+20>>2]=HEAP32[$32+20>>2]|0;HEAP32[$30+24>>2]=HEAP32[$32+24>>2]|0;HEAP32[$30+28>>2]=HEAP32[$32+28>>2]|0;
      $33 = ($31|0)==(0);
      if ($33) {
       $zone$0$lcssa23 = $zone$03;
       label = 16;
       break L9;
      } else {
       $count$25 = $31;
      }
     }
    }
    $21 = (($zone$03) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($delta$0|0)<(0);
    if ($23) {
     $24 = ($delta$0|0)<($22|0);
     if (!($24)) {
      $count_bot$1 = $count_bot$010;$count_top$1 = $count_top$08;
      break;
     }
     HEAP32[$21>>2] = $delta$0;
     $count_bot$1 = $count_bot$010;$count_top$1 = $count_top$08;
     break;
    } else {
     $25 = ($delta$0|0)>($22|0);
     if (!($25)) {
      $count_bot$1 = $count_bot$010;$count_top$1 = $count_top$08;
      break;
     }
     HEAP32[$21>>2] = $delta$0;
     $count_bot$1 = $count_bot$010;$count_top$1 = $count_top$08;
     break;
    }
   }
  } while(0);
  do {
   if ((label|0) == 16) {
    label = 0;
    HEAP32[$zone$0$lcssa23>>2] = $reference$0;
    $34 = (($zone$0$lcssa23) + 4|0);
    HEAP32[$34>>2] = $delta$0;
    $35 = ($top$0<<24>>24)==(0);
    if ($35) {
     $37 = (($count_bot$010) + 1)|0;
     $count_bot$1 = $37;$count_top$1 = $count_top$08;
     break;
    } else {
     $36 = (($count_top$08) + 1)|0;
     $count_bot$1 = $count_bot$010;$count_top$1 = $36;
     break;
    }
   }
  } while(0);
  $38 = (($$017) + 4|0);
  $39 = (($$013) + -2)|0;
  $40 = ($39>>>0)>(1);
  if ($40) {
   $$013 = $39;$$017 = $38;$count_bot$010 = $count_bot$1;$count_top$08 = $count_top$1;$first$012 = $first$1;
  } else {
   $count_bot$0$lcssa = $count_bot$1;$count_top$0$lcssa = $count_top$1;
   break;
  }
 }
 HEAP32[$top_table>>2] = $count_top$0$lcssa;
 HEAP32[$bot_table>>2] = $count_bot$0$lcssa;
 STACKTOP = sp;return;
}
function _ps_hints_apply($ps_hints,$outline,$globals,$hint_mode) {
 $ps_hints = $ps_hints|0;
 $outline = $outline|0;
 $globals = $globals|0;
 $hint_mode = $hint_mode|0;
 var $$$i = 0, $$0 = 0, $$1$i = 0, $$2$i = 0, $$finished$1$i$i = 0, $$idx$val = 0, $$idx$val$i = 0, $$idx3$i = 0, $$idx3$val$i = 0, $$idx4 = 0, $$idx4$val = 0, $$idx5$i$pre = 0, $$idx5$i$pre$phiZZZ2D = 0, $$idx5$val$i = 0, $$idx6$i$pre = 0, $$idx6$i$pre$phiZZZ2D = 0, $$idx6$val$i = 0, $$idx7$i = 0, $$idx7$val$i = 0, $$idx8$i = 0;
 var $$idx8$val$i = 0, $$lobit$i = 0, $$phi$trans$insert = 0, $$pn$i = 0, $$pr = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i19 = 0, $$pre$i40 = 0, $$pre$i43 = 0, $$pre$phiZ2D = 0, $$pre118 = 0, $$pre120 = 0, $$pre121 = 0, $$pre28$i = 0, $$pre3$i = 0, $$pre36$i$i = 0, $$pre50$i = 0, $$pre53$i = 0;
 var $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0;
 var $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0;
 var $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0;
 var $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0;
 var $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0;
 var $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0;
 var $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0;
 var $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0;
 var $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0;
 var $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0;
 var $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0;
 var $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0;
 var $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0;
 var $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $after$0$i = 0, $after$0$i$i = 0, $after3$0$i = 0, $before$0$i = 0, $before$013$i$i = 0, $before$013$i$i$phi = 0, $before$1$i = 0, $before2$0$i = 0, $blue_count$01$i57 = 0, $blue_count$13$i59 = 0, $contour$013$i = 0, $contour$029$i = 0, $count$02$i = 0, $count$02$i25 = 0, $count$025$i = 0, $count$03$i = 0, $count$03$us$i = 0;
 var $count$03$us$i$i = 0, $count3$09$i = 0, $cur_a$0$i = 0, $cur_ab$0$i = 0, $cur_c$0$i = 0, $delta$014$i = 0, $delta$1$i = 0, $delta$2$i = 0, $dimension$071 = 0, $end$0$i$i = 0, $end$1$i$i = 0, $error$i28 = 0, $exitcond = 0, $finished$1$i$i = 0, $first$01$i = 0, $first$012$i = 0, $first$031$i = 0, $first$2$i = 0, $first$4$be$i = 0, $first$46$i = 0;
 var $fit_count$03$i = 0, $fit_count$1$i = 0, $glyph$idx1$val$i = 0, $glyph$idx2$val$idx$val$i = 0, $glyph_count$09$i = 0, $glyphrec = 0, $glyphrec$idx$val = 0, $glyphrec$idx10$val = 0, $glyphrec$idx11$val = 0, $glyphrec$idx12$val = 0, $glyphrec$idx2$val = 0, $glyphrec$idx3 = 0, $glyphrec$idx3$val = 0, $glyphrec$idx3$val$idx = 0, $glyphrec$idx3$val$idx$val = 0, $glyphrec$idx5$val = 0, $glyphrec$idx6$val = 0, $glyphrec$idx7$val$pr = 0, $glyphrec$idx8$val = 0, $glyphrec$idx9$val = 0;
 var $hint$01$i = 0, $in_x$0$i$i = 0, $in_y$0$i$i = 0, $insert$0$lcssa$i = 0, $insert$09$i = 0, $mask$0$idx$val$i = 0, $mask$0$idx4$i = 0, $mask$0$idx4$val$i = 0, $mask$015$i = 0, $n$019$i = 0, $n$02$i = 0, $n$02$us$i = 0, $n$020$i$i = 0, $n$030$i = 0, $n$1$i = 0, $n$2$i = 0, $n3$022$i = 0, $next$0$i = 0, $nn$0$lcssa$i = 0, $nn$01$i = 0;
 var $nn$1$i = 0, $nn$1$lcssa$i = 0, $num_contours$012$i = 0, $num_masks$013$i = 0, $num_strongs$0$$i = 0, $num_strongs$020$i = 0, $num_strongs$215$i = 0, $num_strongs$3$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond3$i$i = 0, $or$cond30$i = 0, $or$cond4$i$i = 0, $org_a$0$i = 0, $org_ab$0$i = 0, $orient_prev$0$i$i = 0, $phitmp = 0, $phitmp1 = 0, $point$0$first$0$i = 0;
 var $point$0$i = 0, $point$0$lcssa$i = 0, $point$01$i = 0, $point$01$i44 = 0, $point$01$us$i = 0, $point$02$i = 0, $point$02$i33 = 0, $point$02$us$i = 0, $point$02$us$i$i = 0, $point$021$i = 0, $point$024$i = 0, $point$07$i = 0, $point$1$i = 0, $point$116$i = 0, $point$19$i = 0, $point$2$i = 0, $point$24$i = 0, $point2$023$i = 0, $point4$010$i = 0, $rescale$0 = 0;
 var $result$0$i$i = 0, $result$0$i3$i = 0, $scale_ab$0$i = 0, $start$0$i$i = 0, $start$1$i$i = 0, $strongs$0$i = 0, $strongs_0$i = 0, $vec$01$i = 0, $vec$01$us$i = 0, $vec$01$us$i$i = 0, $x_scale$0 = 0, $zone$02$i56 = 0, $zone$14$i58 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $strongs_0$i = sp + 136|0;
 $error$i28 = sp;
 $glyphrec = sp + 8|0;
 $0 = (($outline) + 2|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP16[$outline>>1]|0;
 $4 = ($3<<16>>16)==(0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 dest=$glyphrec+0|0; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $5 = HEAP32[$globals>>2]|0;
 $6 = (($glyphrec) + 16|0);
 HEAP32[$6>>2] = $5;
 $7 = $1 << 16 >> 16;
 $8 = (_ft_mem_realloc($5,48,0,$7,0,$strongs_0$i)|0);
 $9 = (($glyphrec) + 8|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$strongs_0$i>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = HEAP16[$outline>>1]|0;
  $13 = $12 << 16 >> 16;
  $14 = (_ft_mem_realloc($5,8,0,$13,0,$strongs_0$i)|0);
  $15 = (($glyphrec) + 12|0);
  HEAP32[$15>>2] = $14;
  $16 = HEAP32[$strongs_0$i>>2]|0;
  $17 = ($16|0)==(0);
  if ($17) {
   $18 = HEAP16[$0>>1]|0;
   $19 = $18 << 16 >> 16;
   HEAP32[$glyphrec>>2] = $19;
   $20 = HEAP16[$outline>>1]|0;
   $21 = $20 << 16 >> 16;
   $22 = (($glyphrec) + 4|0);
   HEAP32[$22>>2] = $21;
   $23 = HEAP32[$9>>2]|0;
   $24 = ($20<<16>>16)==(0);
   if ($24) {
    $51 = $19;$55 = $23;
   } else {
    $25 = (($outline) + 12|0);
    $contour$029$i = $14;$first$031$i = 0;$n$030$i = 0;
    while(1) {
     $26 = HEAP32[$25>>2]|0;
     $27 = (($26) + ($n$030$i<<1)|0);
     $28 = HEAP16[$27>>1]|0;
     $29 = $28 << 16 >> 16;
     $30 = (($29) + 1)|0;
     $31 = (($30) - ($first$031$i))|0;
     $32 = (($23) + (($first$031$i*48)|0)|0);
     HEAP32[$contour$029$i>>2] = $32;
     $33 = (($contour$029$i) + 4|0);
     HEAP32[$33>>2] = $31;
     $34 = ($31|0)>(0);
     if ($34) {
      $35 = (($23) + (($29*48)|0)|0);
      HEAP32[$32>>2] = $35;
      $36 = ((($23) + (($first$031$i*48)|0)|0) + 8|0);
      HEAP32[$36>>2] = $contour$029$i;
      $37 = ($31|0)>(1);
      if ($37) {
       $count$025$i = $31;$point$024$i = $32;
       while(1) {
        $38 = (($point$024$i) + 48|0);
        $39 = (($point$024$i) + 4|0);
        HEAP32[$39>>2] = $38;
        HEAP32[$38>>2] = $point$024$i;
        $40 = (($point$024$i) + 56|0);
        HEAP32[$40>>2] = $contour$029$i;
        $41 = (($count$025$i) + -1)|0;
        $42 = ($41|0)>(1);
        if ($42) {
         $count$025$i = $41;$point$024$i = $38;
        } else {
         $point$0$lcssa$i = $35;
         break;
        }
       }
      } else {
       $point$0$lcssa$i = $32;
      }
      $43 = (($point$0$lcssa$i) + 4|0);
      HEAP32[$43>>2] = $32;
     }
     $44 = (($contour$029$i) + 8|0);
     $45 = (($n$030$i) + 1)|0;
     $46 = HEAP32[$22>>2]|0;
     $47 = ($45>>>0)<($46>>>0);
     if ($47) {
      $contour$029$i = $44;$first$031$i = $30;$n$030$i = $45;
     } else {
      break;
     }
    }
    $$pre$i = HEAP32[$9>>2]|0;
    $$pre50$i = HEAP32[$glyphrec>>2]|0;
    $51 = $$pre50$i;$55 = $$pre$i;
   }
   $48 = (($outline) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($51|0)==(0);
   if ($50) {
    $52 = (($glyphrec) + 20|0);
    HEAP32[$52>>2] = $outline;
    $53 = (($glyphrec) + 24|0);
    HEAP32[$53>>2] = $globals;
   } else {
    $54 = $55;
    $56 = (($outline) + 8|0);
    $n3$022$i = 0;$point2$023$i = $55;
    while(1) {
     $57 = HEAP32[$point2$023$i>>2]|0;
     $58 = $57;
     $59 = (($58) - ($54))|0;
     $60 = (($59|0) / 48)&-1;
     $61 = (($point2$023$i) + 4|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = $62;
     $64 = (($63) - ($54))|0;
     $65 = (($64|0) / 48)&-1;
     $66 = HEAP32[$56>>2]|0;
     $67 = (($66) + ($n3$022$i)|0);
     $68 = HEAP8[$67>>0]|0;
     $69 = $68 & 1;
     $70 = ($69<<24>>24)==(0);
     if ($70) {
      $71 = (($point2$023$i) + 12|0);
      HEAP32[$71>>2] = 1;
     }
     $72 = (($49) + ($n3$022$i<<3)|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = (($49) + ($60<<3)|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = (($73) - ($75))|0;
     $77 = ((($49) + ($n3$022$i<<3)|0) + 4|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ((($49) + ($60<<3)|0) + 4|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (($78) - ($80))|0;
     $82 = ($76|0)>(-1);
     $83 = (0 - ($76))|0;
     $84 = $82 ? $76 : $83;
     $85 = ($81|0)>(-1);
     $86 = (0 - ($81))|0;
     $87 = $85 ? $81 : $86;
     $88 = ($87*12)|0;
     $89 = ($88|0)<($84|0);
     if ($89) {
      $90 = $76 >> 31;
      $91 = $90 & -4;
      $92 = $91 | 2;
      $result$0$i$i = $92;
     } else {
      $93 = ($84*12)|0;
      $94 = ($93|0)<($87|0);
      if ($94) {
       $95 = $81 >> 31;
       $96 = $95 & 2;
       $97 = (($96) + -1)|0;
       $result$0$i$i = $97;
      } else {
       $result$0$i$i = 4;
      }
     }
     $98 = $result$0$i$i&255;
     $99 = (($point2$023$i) + 20|0);
     HEAP8[$99>>0] = $98;
     $100 = (($49) + ($65<<3)|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = HEAP32[$72>>2]|0;
     $103 = (($101) - ($102))|0;
     $104 = ((($49) + ($65<<3)|0) + 4|0);
     $105 = HEAP32[$104>>2]|0;
     $106 = HEAP32[$77>>2]|0;
     $107 = (($105) - ($106))|0;
     $108 = ($103|0)>(-1);
     $109 = (0 - ($103))|0;
     $110 = $108 ? $103 : $109;
     $111 = ($107|0)>(-1);
     $112 = (0 - ($107))|0;
     $113 = $111 ? $107 : $112;
     $114 = ($113*12)|0;
     $115 = ($114|0)<($110|0);
     if ($115) {
      $116 = $103 >> 31;
      $117 = $116 & -4;
      $118 = $117 | 2;
      $result$0$i3$i = $118;
     } else {
      $119 = ($110*12)|0;
      $120 = ($119|0)<($113|0);
      if ($120) {
       $121 = $107 >> 31;
       $122 = $121 & 2;
       $123 = (($122) + -1)|0;
       $result$0$i3$i = $123;
      } else {
       $result$0$i3$i = 4;
      }
     }
     $124 = $result$0$i3$i&255;
     $125 = (($point2$023$i) + 21|0);
     HEAP8[$125>>0] = $124;
     $126 = (($point2$023$i) + 12|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = $127 & 1;
     $129 = ($128|0)==(0);
     do {
      if ($129) {
       $131 = ($result$0$i$i|0)==($result$0$i3$i|0);
       if ($131) {
        $132 = ($result$0$i$i|0)==(4);
        if ($132) {
         $133 = (_ft_corner_is_flat($76,$81,$103,$107)|0);
         $134 = ($133|0)==(0);
         if ($134) {
          break;
         }
         $$pre53$i = HEAP32[$126>>2]|0;
         $136 = $$pre53$i;
        } else {
         $136 = $127;
        }
        $135 = $136 | 2;
        HEAP32[$126>>2] = $135;
       }
      } else {
       $130 = $127 | 2;
       HEAP32[$126>>2] = $130;
      }
     } while(0);
     $137 = (($n3$022$i) + 1)|0;
     $138 = (($point2$023$i) + 48|0);
     $139 = HEAP32[$glyphrec>>2]|0;
     $140 = ($137>>>0)<($139>>>0);
     if ($140) {
      $n3$022$i = $137;$point2$023$i = $138;
     } else {
      break;
     }
    }
    $141 = (($glyphrec) + 20|0);
    HEAP32[$141>>2] = $outline;
    $142 = (($glyphrec) + 24|0);
    HEAP32[$142>>2] = $globals;
    $143 = ($139|0)==(0);
    if (!($143)) {
     $glyph$idx2$val$idx$val$i = HEAP32[$48>>2]|0;
     $glyph$idx1$val$i = HEAP32[$9>>2]|0;
     $count$03$us$i$i = $139;$point$02$us$i$i = $glyph$idx1$val$i;$vec$01$us$i$i = $glyph$idx2$val$idx$val$i;
     while(1) {
      $144 = (($point$02$us$i$i) + 16|0);
      HEAP32[$144>>2] = 0;
      $145 = (($point$02$us$i$i) + 32|0);
      HEAP32[$145>>2] = 0;
      $146 = HEAP32[$vec$01$us$i$i>>2]|0;
      $147 = (($point$02$us$i$i) + 36|0);
      HEAP32[$147>>2] = $146;
      $148 = (($vec$01$us$i$i) + 4|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = (($point$02$us$i$i) + 40|0);
      HEAP32[$150>>2] = $149;
      $151 = (($count$03$us$i$i) + -1)|0;
      $152 = (($point$02$us$i$i) + 48|0);
      $153 = (($vec$01$us$i$i) + 8|0);
      $154 = ($151|0)==(0);
      if ($154) {
       break;
      } else {
       $count$03$us$i$i = $151;$point$02$us$i$i = $152;$vec$01$us$i$i = $153;
      }
     }
    }
   }
   $155 = HEAP32[$22>>2]|0;
   $156 = ($155|0)==(0);
   if (!($156)) {
    $n$020$i$i = 0;
    while(1) {
     $157 = HEAP32[$15>>2]|0;
     $158 = ((($157) + ($n$020$i$i<<3)|0) + 4|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ($159>>>0)<(4);
     L58: do {
      if (!($160)) {
       $161 = (($157) + ($n$020$i$i<<3)|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = (($162) + 36|0);
       $164 = (($162) + 40|0);
       $end$0$i$i = $162;
       while(1) {
        $165 = (($end$0$i$i) + 4|0);
        $166 = HEAP32[$165>>2]|0;
        $167 = ($166|0)==($162|0);
        if ($167) {
         break L58;
        }
        $168 = (($166) + 36|0);
        $169 = HEAP32[$168>>2]|0;
        $170 = HEAP32[$163>>2]|0;
        $171 = (($169) - ($170))|0;
        $172 = (($166) + 40|0);
        $173 = HEAP32[$172>>2]|0;
        $174 = HEAP32[$164>>2]|0;
        $175 = (($173) - ($174))|0;
        $176 = ($169|0)==($170|0);
        $177 = ($173|0)==($174|0);
        $or$cond$i$i = $176 & $177;
        if ($or$cond$i$i) {
         $end$0$i$i = $166;
        } else {
         break;
        }
       }
       $178 = HEAP32[$162>>2]|0;
       $179 = ($178|0)==($162|0);
       if (!($179)) {
        $181 = $178;$184 = $170;$188 = $174;$before$013$i$i = $162;
        while(1) {
         $180 = (($181) + 36|0);
         $182 = HEAP32[$180>>2]|0;
         $183 = (($184) - ($182))|0;
         $185 = (($181) + 40|0);
         $186 = HEAP32[$185>>2]|0;
         $187 = (($188) - ($186))|0;
         $189 = ($184|0)==($182|0);
         $190 = ($188|0)==($186|0);
         $or$cond3$i$i = $189 & $190;
         if (!($or$cond3$i$i)) {
          $191 = (_ft_corner_orientation($171,$175,$183,$187)|0);
          $192 = ($191|0)==(0);
          if (!($192)) {
           $end$1$i$i = $166;$in_x$0$i$i = $183;$in_y$0$i$i = $187;$orient_prev$0$i$i = $191;$start$0$i$i = $before$013$i$i;
           break;
          }
         }
         $193 = HEAP32[$181>>2]|0;
         $194 = ($193|0)==($162|0);
         if ($194) {
          break L58;
         }
         $$pre$i$i = HEAP32[$180>>2]|0;
         $$pre36$i$i = HEAP32[$185>>2]|0;
         $before$013$i$i$phi = $181;$181 = $193;$184 = $$pre$i$i;$188 = $$pre36$i$i;$before$013$i$i = $before$013$i$i$phi;
        }
        while(1) {
         $after$0$i$i = $end$1$i$i;$finished$1$i$i = 0;
         while(1) {
          $195 = (($after$0$i$i) + 4|0);
          $196 = HEAP32[$195>>2]|0;
          $197 = ($196|0)==($before$013$i$i|0);
          $$finished$1$i$i = $197 ? 1 : $finished$1$i$i;
          $198 = (($196) + 36|0);
          $199 = HEAP32[$198>>2]|0;
          $200 = (($after$0$i$i) + 36|0);
          $201 = HEAP32[$200>>2]|0;
          $202 = (($199) - ($201))|0;
          $203 = (($196) + 40|0);
          $204 = HEAP32[$203>>2]|0;
          $205 = (($after$0$i$i) + 40|0);
          $206 = HEAP32[$205>>2]|0;
          $207 = (($204) - ($206))|0;
          $208 = ($199|0)==($201|0);
          $209 = ($204|0)==($206|0);
          $or$cond4$i$i = $208 & $209;
          if ($or$cond4$i$i) {
           $after$0$i$i = $196;$finished$1$i$i = $$finished$1$i$i;
           continue;
          }
          $210 = (_ft_corner_orientation($in_x$0$i$i,$in_y$0$i$i,$202,$207)|0);
          $211 = ($210|0)==(0);
          if ($211) {
           $after$0$i$i = $196;$finished$1$i$i = $$finished$1$i$i;
          } else {
           break;
          }
         }
         $212 = $210 ^ $orient_prev$0$i$i;
         $213 = ($212|0)<(0);
         if ($213) {
          $start$1$i$i = $start$0$i$i;
          while(1) {
           $214 = (($start$1$i$i) + 12|0);
           $215 = HEAP32[$214>>2]|0;
           $216 = $215 | 4;
           HEAP32[$214>>2] = $216;
           $217 = (($start$1$i$i) + 4|0);
           $218 = HEAP32[$217>>2]|0;
           $219 = ($218|0)==($after$0$i$i|0);
           if ($219) {
            break;
           } else {
            $start$1$i$i = $218;
           }
          }
          $220 = (($after$0$i$i) + 12|0);
          $221 = HEAP32[$220>>2]|0;
          $222 = $221 | 4;
          HEAP32[$220>>2] = $222;
         }
         $223 = ($$finished$1$i$i|0)==(0);
         if ($223) {
          $end$1$i$i = $196;$in_x$0$i$i = $202;$in_y$0$i$i = $207;$orient_prev$0$i$i = $210;$start$0$i$i = $after$0$i$i;
         } else {
          break;
         }
        }
       }
      }
     } while(0);
     $224 = (($n$020$i$i) + 1)|0;
     $225 = HEAP32[$22>>2]|0;
     $226 = ($224>>>0)<($225>>>0);
     if ($226) {
      $n$020$i$i = $224;
     } else {
      break;
     }
    }
   }
   $227 = (($glyphrec) + 28|0);
   $228 = (($ps_hints) + 16|0);
   $229 = (($ps_hints) + 28|0);
   $230 = (_psh_hint_table_init($227,$228,$229,$5)|0);
   HEAP32[$strongs_0$i>>2] = $230;
   $231 = ($230|0)==(0);
   if ($231) {
    $232 = (($glyphrec) + 68|0);
    $233 = (($ps_hints) + 52|0);
    $234 = (($ps_hints) + 64|0);
    $235 = (_psh_hint_table_init($232,$233,$234,$5)|0);
    $236 = ($235|0)==(0);
    if ($236) {
     $237 = (($glyphrec) + 24|0);
     $238 = HEAP32[$237>>2]|0;
     $239 = (($238) + 200|0);
     $240 = HEAP32[$239>>2]|0;
     $241 = (($238) + 404|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = (($globals) + 416|0);
     $244 = HEAP32[$243>>2]|0;
     $245 = (_FT_MulFix($244,$242)|0);
     $246 = (($245) + 32)|0;
     $247 = $246 & -64;
     $248 = ($247|0)==(0);
     $249 = ($245|0)==($247|0);
     $or$cond = $248 | $249;
     if ($or$cond) {
      $rescale$0 = 0;
     } else {
      $250 = (_FT_MulDiv($242,$247,$245)|0);
      $251 = ($247|0)<($245|0);
      if ($251) {
       $252 = (($240|0) / 50)&-1;
       $253 = (($240) - ($252))|0;
       $x_scale$0 = $253;
      } else {
       $x_scale$0 = $240;
      }
      $254 = HEAP32[$237>>2]|0;
      (_psh_globals_set_scale($254,$x_scale$0,$250,0,0)|0);
      $rescale$0 = 1;
     }
     $255 = (($glyphrec) + 120|0);
     HEAP8[$255>>0] = 1;
     $256 = (($glyphrec) + 121|0);
     HEAP8[$256>>0] = 1;
     $257 = ($hint_mode|0)==(2);
     if ($257) {
      $261 = (($glyphrec) + 122|0);
      HEAP8[$261>>0] = 1;
      $263 = 1;
     } else {
      $258 = ($hint_mode|0)==(3);
      $phitmp = $258&1;
      $259 = (($glyphrec) + 122|0);
      HEAP8[$259>>0] = $phitmp;
      $260 = ($hint_mode|0)==(4);
      $phitmp1 = $260&1;
      $263 = $phitmp1;
     }
     $262 = (($glyphrec) + 123|0);
     HEAP8[$262>>0] = $263;
     $264 = ($hint_mode|0)!=(1);
     $265 = $264&1;
     $266 = (($glyphrec) + 124|0);
     HEAP8[$266>>0] = $265;
     $glyphrec$idx3 = (($glyphrec) + 20|0);
     $267 = (($globals) + 412|0);
     $268 = (($globals) + 416|0);
     $269 = (($globals) + 928|0);
     $270 = (($globals) + 2488|0);
     $271 = (($globals) + 2492|0);
     $272 = (($globals) + 2484|0);
     $273 = (($globals) + 428|0);
     $274 = ($rescale$0<<24>>24)==(0);
     $dimension$071 = 0;
     while(1) {
      $glyphrec$idx$val = HEAP32[$glyphrec>>2]|0;
      $glyphrec$idx2$val = HEAP32[$9>>2]|0;
      $glyphrec$idx3$val = HEAP32[$glyphrec$idx3>>2]|0;
      $glyphrec$idx3$val$idx = (($glyphrec$idx3$val) + 4|0);
      $glyphrec$idx3$val$idx$val = HEAP32[$glyphrec$idx3$val$idx>>2]|0;
      $275 = ($glyphrec$idx$val|0)==(0);
      if (!($275)) {
       $276 = ($dimension$071|0)==(0);
       if ($276) {
        $count$03$us$i = $glyphrec$idx$val;$point$02$us$i = $glyphrec$idx2$val;$vec$01$us$i = $glyphrec$idx3$val$idx$val;
        while(1) {
         $277 = (($point$02$us$i) + 16|0);
         HEAP32[$277>>2] = 0;
         $278 = (($point$02$us$i) + 32|0);
         HEAP32[$278>>2] = 0;
         $279 = HEAP32[$vec$01$us$i>>2]|0;
         $280 = (($point$02$us$i) + 36|0);
         HEAP32[$280>>2] = $279;
         $281 = (($vec$01$us$i) + 4|0);
         $282 = HEAP32[$281>>2]|0;
         $283 = (($point$02$us$i) + 40|0);
         HEAP32[$283>>2] = $282;
         $284 = (($count$03$us$i) + -1)|0;
         $285 = (($point$02$us$i) + 48|0);
         $286 = (($vec$01$us$i) + 8|0);
         $287 = ($284|0)==(0);
         if ($287) {
          break;
         } else {
          $count$03$us$i = $284;$point$02$us$i = $285;$vec$01$us$i = $286;
         }
        }
       } else {
        $count$03$i = $glyphrec$idx$val;$point$02$i = $glyphrec$idx2$val;$vec$01$i = $glyphrec$idx3$val$idx$val;
        while(1) {
         $288 = (($point$02$i) + 16|0);
         HEAP32[$288>>2] = 0;
         $289 = (($point$02$i) + 32|0);
         HEAP32[$289>>2] = 0;
         $290 = (($vec$01$i) + 4|0);
         $291 = HEAP32[$290>>2]|0;
         $292 = (($point$02$i) + 36|0);
         HEAP32[$292>>2] = $291;
         $293 = HEAP32[$vec$01$i>>2]|0;
         $294 = (($point$02$i) + 40|0);
         HEAP32[$294>>2] = $293;
         $295 = (($count$03$i) + -1)|0;
         $296 = (($point$02$i) + 48|0);
         $297 = (($vec$01$i) + 8|0);
         $298 = ($295|0)==(0);
         if ($298) {
          break;
         } else {
          $count$03$i = $295;$point$02$i = $296;$vec$01$i = $297;
         }
        }
       }
      }
      $299 = HEAP32[$22>>2]|0;
      $300 = ($299|0)==(0);
      L105: do {
       if ($300) {
        $n$1$i = 0;
       } else {
        $301 = HEAP32[$15>>2]|0;
        $835 = $299;$n$019$i = 0;
        while(1) {
         $302 = (($301) + ($n$019$i<<3)|0);
         $303 = HEAP32[$302>>2]|0;
         $304 = ((($301) + ($n$019$i<<3)|0) + 4|0);
         $305 = HEAP32[$304>>2]|0;
         $306 = ($305|0)==(0);
         if ($306) {
          $338 = $835;
         } else {
          $307 = (($303) + 36|0);
          $before$0$i = $303;
          while(1) {
           $308 = HEAP32[$before$0$i>>2]|0;
           $309 = ($308|0)==($303|0);
           if ($309) {
            $n$2$i = $n$019$i;
            label = 98;
            break L105;
           }
           $310 = (($308) + 36|0);
           $311 = HEAP32[$310>>2]|0;
           $312 = HEAP32[$307>>2]|0;
           $313 = ($311|0)==($312|0);
           if ($313) {
            $before$0$i = $308;
           } else {
            break;
           }
          }
          $314 = (($308) + 4|0);
          $315 = HEAP32[$314>>2]|0;
          $before$1$i = $308;$point$0$i = $315;
          L115: while(1) {
           $316 = (($point$0$i) + 36|0);
           $after$0$i = $point$0$i;
           while(1) {
            $317 = (($after$0$i) + 4|0);
            $318 = HEAP32[$317>>2]|0;
            $319 = ($318|0)==($315|0);
            if ($319) {
             break L115;
            }
            $320 = (($318) + 36|0);
            $321 = HEAP32[$320>>2]|0;
            $322 = HEAP32[$316>>2]|0;
            $323 = ($321|0)==($322|0);
            if ($323) {
             $after$0$i = $318;
            } else {
             break;
            }
           }
           $324 = (($before$1$i) + 36|0);
           $325 = HEAP32[$324>>2]|0;
           $326 = ($325|0)<($322|0);
           if ($326) {
            $327 = ($321|0)<($322|0);
            if ($327) {
             $point$1$i = $point$0$i;
             label = 83;
            }
           } else {
            $328 = ($321|0)>($322|0);
            if ($328) {
             $point$1$i = $point$0$i;
             label = 83;
            }
           }
           if ((label|0) == 83) {
            while(1) {
             label = 0;
             $329 = (($point$1$i) + 16|0);
             $330 = HEAP32[$329>>2]|0;
             $331 = $330 | 64;
             HEAP32[$329>>2] = $331;
             $332 = (($point$1$i) + 4|0);
             $333 = HEAP32[$332>>2]|0;
             $334 = ($333|0)==($318|0);
             if ($334) {
              break;
             } else {
              $point$1$i = $333;
              label = 83;
             }
            }
           }
           $335 = HEAP32[$318>>2]|0;
           $before$1$i = $335;$point$0$i = $318;
          }
          $$pre28$i = HEAP32[$22>>2]|0;
          $338 = $$pre28$i;
         }
         $336 = (($n$019$i) + 1)|0;
         $337 = ($336>>>0)<($338>>>0);
         if ($337) {
          $835 = $338;$n$019$i = $336;
         } else {
          $n$1$i = 0;
          break;
         }
        }
       }
      } while(0);
      L130: while(1) {
       if ((label|0) == 98) {
        label = 0;
        $366 = (($n$2$i) + 1)|0;
        $n$1$i = $366;
       }
       $339 = HEAP32[$glyphrec>>2]|0;
       $340 = ($n$1$i>>>0)<($339>>>0);
       if (!($340)) {
        break;
       }
       $341 = HEAP32[$9>>2]|0;
       $342 = (($341) + (($n$1$i*48)|0)|0);
       $343 = ((($341) + (($n$1$i*48)|0)|0) + 16|0);
       $344 = HEAP32[$343>>2]|0;
       $345 = $344 & 64;
       $346 = ($345|0)==(0);
       if ($346) {
        $n$2$i = $n$1$i;
        label = 98;
        continue;
       }
       $347 = ((($341) + (($n$1$i*48)|0)|0) + 40|0);
       $before2$0$i = $342;
       while(1) {
        $348 = HEAP32[$before2$0$i>>2]|0;
        $349 = ($348|0)==($342|0);
        if ($349) {
         $n$2$i = $n$1$i;
         label = 98;
         continue L130;
        }
        $350 = (($348) + 40|0);
        $351 = HEAP32[$350>>2]|0;
        $352 = HEAP32[$347>>2]|0;
        $353 = ($351|0)==($352|0);
        if ($353) {
         $before2$0$i = $348;
        } else {
         $after3$0$i = $342;
         break;
        }
       }
       while(1) {
        $354 = (($after3$0$i) + 4|0);
        $355 = HEAP32[$354>>2]|0;
        $356 = ($355|0)==($342|0);
        if ($356) {
         $n$2$i = $n$1$i;
         label = 98;
         continue L130;
        }
        $357 = (($355) + 40|0);
        $358 = HEAP32[$357>>2]|0;
        $359 = ($358|0)==($352|0);
        if ($359) {
         $after3$0$i = $355;
        } else {
         break;
        }
       }
       $360 = ($351|0)<($352|0);
       $361 = ($358|0)>($352|0);
       $or$cond$i = $360 & $361;
       if ($or$cond$i) {
        $362 = $344 | 128;
        HEAP32[$343>>2] = $362;
        $n$2$i = $n$1$i;
        label = 98;
        continue;
       }
       $363 = ($351|0)>($352|0);
       $364 = ($358|0)<($352|0);
       $or$cond30$i = $363 & $364;
       if (!($or$cond30$i)) {
        $n$2$i = $n$1$i;
        label = 98;
        continue;
       }
       $365 = $344 | 256;
       HEAP32[$343>>2] = $365;
       $n$2$i = $n$1$i;
       label = 98;
      }
      $367 = ((($glyphrec) + (($dimension$071*40)|0)|0) + 28|0);
      $368 = HEAP32[$237>>2]|0;
      $$idx$val = HEAP32[$367>>2]|0;
      $369 = ($$idx$val|0)==(0);
      if ($369) {
       $381 = $368;
      } else {
       $$idx4 = ((($glyphrec) + (($dimension$071*40)|0)|0) + 36|0);
       $$idx4$val = HEAP32[$$idx4>>2]|0;
       $count$02$i = $$idx$val;$hint$01$i = $$idx4$val;
       while(1) {
        _psh_hint_align($hint$01$i,$368,$dimension$071,$glyphrec);
        $370 = (($count$02$i) + -1)|0;
        $371 = (($hint$01$i) + 28|0);
        $372 = ($370|0)==(0);
        if ($372) {
         break;
        } else {
         $count$02$i = $370;$hint$01$i = $371;
        }
       }
       $$pre = HEAP32[$237>>2]|0;
       $381 = $$pre;
      }
      $373 = ((($glyphrec) + (($dimension$071*40)|0)|0) + 60|0);
      $374 = HEAP32[$373>>2]|0;
      $375 = (($374) + 8|0);
      $376 = HEAP32[$375>>2]|0;
      $377 = HEAP32[$374>>2]|0;
      $378 = ($dimension$071|0)==(0);
      $379 = $378 ? 1 : 2;
      $380 = ((($381) + (($dimension$071*204)|0)|0) + 200|0);
      $382 = HEAP32[$380>>2]|0;
      $383 = (_FT_DivFix(32,$382)|0);
      $384 = ($383|0)>(30);
      $$$i = $384 ? 30 : $383;
      $385 = ($377>>>0)>(1);
      L154: do {
       if ($385) {
        $386 = HEAP32[$glyphrec>>2]|0;
        $387 = ($386|0)==(0);
        if (!($387)) {
         $388 = (($376) + 12|0);
         $389 = HEAP32[$388>>2]|0;
         $390 = ($389>>>0)>($386>>>0);
         $$1$i = $390 ? $386 : $389;
         $$idx7$i = ((($glyphrec) + (($dimension$071*40)|0)|0) + 32|0);
         $$idx8$i = ((($glyphrec) + (($dimension$071*40)|0)|0) + 40|0);
         $$pn$i = $376;$394 = $386;$first$012$i = $$1$i;$num_masks$013$i = $377;
         while(1) {
          $mask$015$i = (($$pn$i) + 16|0);
          $391 = (($$pn$i) + 28|0);
          $392 = HEAP32[$391>>2]|0;
          $393 = ($392>>>0)>($394>>>0);
          $$2$i = $393 ? $394 : $392;
          $395 = (($$2$i) - ($first$012$i))|0;
          $396 = ($395|0)>(0);
          if ($396) {
           $397 = HEAP32[$9>>2]|0;
           $398 = (($397) + (($first$012$i*48)|0)|0);
           $mask$0$idx$val$i = HEAP32[$mask$015$i>>2]|0;
           $mask$0$idx4$i = (($$pn$i) + 24|0);
           $mask$0$idx4$val$i = HEAP32[$mask$0$idx4$i>>2]|0;
           _psh_hint_table_activate_mask($367,$mask$0$idx$val$i,$mask$0$idx4$val$i);
           $$idx7$val$i = HEAP32[$$idx7$i>>2]|0;
           $$idx8$val$i = HEAP32[$$idx8$i>>2]|0;
           _psh_hint_table_find_strong_points($$idx7$val$i,$$idx8$val$i,$398,$395,$$$i,$379);
          }
          $399 = (($num_masks$013$i) + -1)|0;
          $400 = ($399>>>0)>(1);
          if (!($400)) {
           $$idx5$i$pre$phiZZZ2D = $$idx7$i;$$idx6$i$pre$phiZZZ2D = $$idx8$i;
           label = 112;
           break L154;
          }
          $$pre$i19 = HEAP32[$glyphrec>>2]|0;
          $$pn$i = $mask$015$i;$394 = $$pre$i19;$first$012$i = $$2$i;$num_masks$013$i = $399;
         }
        }
       } else {
        $401 = ($377|0)==(1);
        if ($401) {
         $$idx5$i$pre = ((($glyphrec) + (($dimension$071*40)|0)|0) + 32|0);
         $$idx6$i$pre = ((($glyphrec) + (($dimension$071*40)|0)|0) + 40|0);
         $$idx5$i$pre$phiZZZ2D = $$idx5$i$pre;$$idx6$i$pre$phiZZZ2D = $$idx6$i$pre;
         label = 112;
        } else {
         label = 113;
        }
       }
      } while(0);
      if ((label|0) == 112) {
       label = 0;
       $402 = HEAP32[$glyphrec>>2]|0;
       $403 = HEAP32[$9>>2]|0;
       $404 = HEAP32[$373>>2]|0;
       $405 = (($404) + 8|0);
       $406 = HEAP32[$405>>2]|0;
       $$idx$val$i = HEAP32[$406>>2]|0;
       $$idx3$i = (($406) + 8|0);
       $$idx3$val$i = HEAP32[$$idx3$i>>2]|0;
       _psh_hint_table_activate_mask($367,$$idx$val$i,$$idx3$val$i);
       $$idx5$val$i = HEAP32[$$idx5$i$pre$phiZZZ2D>>2]|0;
       $$idx6$val$i = HEAP32[$$idx6$i$pre$phiZZZ2D>>2]|0;
       _psh_hint_table_find_strong_points($$idx5$val$i,$$idx6$val$i,$403,$402,$$$i,$379);
       label = 113;
      }
      if ((label|0) == 113) {
       label = 0;
       $$pr = HEAP32[$glyphrec>>2]|0;
       $407 = ($$pr|0)==(0);
       if (!($407)) {
        $408 = HEAP32[$9>>2]|0;
        $count3$09$i = $$pr;$point4$010$i = $408;
        while(1) {
         $409 = (($point4$010$i) + 32|0);
         $410 = HEAP32[$409>>2]|0;
         $411 = ($410|0)==(0|0);
         do {
          if (!($411)) {
           $412 = (($point4$010$i) + 16|0);
           $413 = HEAP32[$412>>2]|0;
           $414 = $413 & 16;
           $415 = ($414|0)==(0);
           if (!($415)) {
            break;
           }
           $416 = $413 | 16;
           HEAP32[$412>>2] = $416;
          }
         } while(0);
         $417 = (($count3$09$i) + -1)|0;
         $418 = (($point4$010$i) + 48|0);
         $419 = ($417|0)==(0);
         if ($419) {
          break;
         } else {
          $count3$09$i = $417;$point4$010$i = $418;
         }
        }
       }
      }
      $420 = ($dimension$071|0)==(1);
      if ($420) {
       $glyphrec$idx5$val = HEAP32[$glyphrec>>2]|0;
       $421 = ($glyphrec$idx5$val|0)==(0);
       if ($421) {
        $556 = 0;
       } else {
        $glyphrec$idx6$val = HEAP32[$9>>2]|0;
        $glyph_count$09$i = $glyphrec$idx5$val;$point$07$i = $glyphrec$idx6$val;
        while(1) {
         $422 = (($point$07$i) + 20|0);
         $423 = HEAP8[$422>>0]|0;
         if ((($423<<24>>24) == -2) | (($423<<24>>24) == 2)) {
          label = 124;
         } else {
          $424 = (($point$07$i) + 21|0);
          $425 = HEAP8[$424>>0]|0;
          if ((($425<<24>>24) == -2) | (($425<<24>>24) == 2)) {
           label = 124;
          }
         }
         L184: do {
          if ((label|0) == 124) {
           label = 0;
           $426 = (($point$07$i) + 16|0);
           $427 = HEAP32[$426>>2]|0;
           $428 = $427 & 16;
           $429 = ($428|0)==(0);
           if (!($429)) {
            break;
           }
           $430 = (($point$07$i) + 36|0);
           $431 = HEAP32[$430>>2]|0;
           $432 = HEAP32[$267>>2]|0;
           $433 = ($432|0)==(0);
           L187: do {
            if ($433) {
             $836 = $427;
            } else {
             $434 = (($point$07$i) + 44|0);
             $435 = HEAP32[$273>>2]|0;
             $436 = (($431) - ($435))|0;
             $437 = HEAP32[$270>>2]|0;
             $438 = (0 - ($437))|0;
             $439 = ($436|0)<($438|0);
             if ($439) {
              $836 = $427;
              break;
             } else {
              $450 = $437;$456 = $436;$460 = $427;$blue_count$01$i57 = $432;$zone$02$i56 = $268;
             }
             while(1) {
              $447 = (($zone$02$i56) + 8|0);
              $448 = HEAP32[$447>>2]|0;
              $449 = (($448) + ($450))|0;
              $451 = ($431|0)>($449|0);
              do {
               if ($451) {
                $837 = $460;
               } else {
                $452 = HEAP8[$271>>0]|0;
                $453 = ($452<<24>>24)==(0);
                if ($453) {
                 $454 = HEAP32[$272>>2]|0;
                 $455 = ($456|0)>($454|0);
                 if ($455) {
                  $837 = $460;
                  break;
                 }
                }
                $457 = (($zone$02$i56) + 24|0);
                $458 = HEAP32[$457>>2]|0;
                HEAP32[$434>>2] = $458;
                $459 = $460 | 48;
                HEAP32[$426>>2] = $459;
                $837 = $459;
               }
              } while(0);
              $461 = (($blue_count$01$i57) + -1)|0;
              $462 = ($461|0)==(0);
              if ($462) {
               $836 = $837;
               break L187;
              }
              $440 = (($zone$02$i56) + 32|0);
              $441 = (($zone$02$i56) + 44|0);
              $442 = HEAP32[$441>>2]|0;
              $443 = (($431) - ($442))|0;
              $444 = HEAP32[$270>>2]|0;
              $445 = (0 - ($444))|0;
              $446 = ($443|0)<($445|0);
              if ($446) {
               $836 = $837;
               break;
              } else {
               $450 = $444;$456 = $443;$460 = $837;$blue_count$01$i57 = $461;$zone$02$i56 = $440;
              }
             }
            }
           } while(0);
           $463 = HEAP32[$269>>2]|0;
           $464 = ($463|0)==(0);
           if ($464) {
            break;
           }
           $$sum$i = (($463) + -1)|0;
           $465 = (($point$07$i) + 44|0);
           $466 = ((($globals) + ($$sum$i<<5)|0) + 940|0);
           $467 = HEAP32[$466>>2]|0;
           $468 = (($467) - ($431))|0;
           $469 = HEAP32[$270>>2]|0;
           $470 = (0 - ($469))|0;
           $471 = ($468|0)<($470|0);
           if ($471) {
            break;
           }
           $472 = ((($globals) + ($$sum$i<<5)|0) + 932|0);
           $483 = $469;$489 = $468;$493 = $836;$blue_count$13$i59 = $463;$zone$14$i58 = $472;
           while(1) {
            $480 = (($zone$14$i58) + 12|0);
            $481 = HEAP32[$480>>2]|0;
            $482 = (($481) - ($483))|0;
            $484 = ($431|0)<($482|0);
            do {
             if ($484) {
              $838 = $493;
             } else {
              $485 = HEAP8[$271>>0]|0;
              $486 = ($485<<24>>24)==(0);
              if ($486) {
               $487 = HEAP32[$272>>2]|0;
               $488 = ($489|0)<($487|0);
               if (!($488)) {
                $838 = $493;
                break;
               }
              }
              $490 = (($zone$14$i58) + 28|0);
              $491 = HEAP32[$490>>2]|0;
              HEAP32[$465>>2] = $491;
              $492 = $493 | 48;
              HEAP32[$426>>2] = $492;
              $838 = $492;
             }
            } while(0);
            $494 = (($blue_count$13$i59) + -1)|0;
            $495 = ($494|0)==(0);
            if ($495) {
             break L184;
            }
            $473 = (($zone$14$i58) + -32|0);
            $474 = (($zone$14$i58) + -24|0);
            $475 = HEAP32[$474>>2]|0;
            $476 = (($475) - ($431))|0;
            $477 = HEAP32[$270>>2]|0;
            $478 = (0 - ($477))|0;
            $479 = ($476|0)<($478|0);
            if ($479) {
             break;
            } else {
             $483 = $477;$489 = $476;$493 = $838;$blue_count$13$i59 = $494;$zone$14$i58 = $473;
            }
           }
          }
         } while(0);
         $496 = (($glyph_count$09$i) + -1)|0;
         $497 = (($point$07$i) + 48|0);
         $498 = ($496|0)==(0);
         if ($498) {
          label = 143;
          break;
         } else {
          $glyph_count$09$i = $496;$point$07$i = $497;
         }
        }
       }
      } else {
       label = 143;
      }
      if ((label|0) == 143) {
       label = 0;
       $glyphrec$idx7$val$pr = HEAP32[$glyphrec>>2]|0;
       $glyphrec$idx9$val = HEAP32[$237>>2]|0;
       $499 = ((($glyphrec$idx9$val) + (($dimension$071*204)|0)|0) + 200|0);
       $500 = HEAP32[$499>>2]|0;
       $501 = ($glyphrec$idx7$val$pr|0)==(0);
       if ($501) {
        $556 = 0;
       } else {
        $glyphrec$idx8$val = HEAP32[$9>>2]|0;
        $count$02$i25 = $glyphrec$idx7$val$pr;$point$01$i = $glyphrec$idx8$val;
        while(1) {
         $502 = (($point$01$i) + 32|0);
         $503 = HEAP32[$502>>2]|0;
         $504 = ($503|0)==(0|0);
         if (!($504)) {
          $505 = (($point$01$i) + 16|0);
          $506 = HEAP32[$505>>2]|0;
          $507 = $506 & 512;
          $508 = ($507|0)==(0);
          do {
           if ($508) {
            $512 = $506 & 1024;
            $513 = ($512|0)==(0);
            if (!($513)) {
             $514 = (($503) + 8|0);
             $515 = HEAP32[$514>>2]|0;
             $516 = (($503) + 12|0);
             $517 = HEAP32[$516>>2]|0;
             $518 = (($517) + ($515))|0;
             $519 = (($point$01$i) + 44|0);
             HEAP32[$519>>2] = $518;
             break;
            }
            $520 = (($point$01$i) + 36|0);
            $521 = HEAP32[$520>>2]|0;
            $522 = HEAP32[$503>>2]|0;
            $523 = (($521) - ($522))|0;
            $524 = ($523|0)<(1);
            if ($524) {
             $525 = (($503) + 8|0);
             $526 = HEAP32[$525>>2]|0;
             $527 = (_FT_MulFix($523,$500)|0);
             $528 = (($527) + ($526))|0;
             $529 = (($point$01$i) + 44|0);
             HEAP32[$529>>2] = $528;
             break;
            }
            $530 = (($503) + 4|0);
            $531 = HEAP32[$530>>2]|0;
            $532 = ($523|0)<($531|0);
            $533 = (($503) + 8|0);
            $534 = HEAP32[$533>>2]|0;
            $535 = (($503) + 12|0);
            $536 = HEAP32[$535>>2]|0;
            if ($532) {
             $542 = (_FT_MulDiv($523,$536,$531)|0);
             $543 = (($542) + ($534))|0;
             $544 = (($point$01$i) + 44|0);
             HEAP32[$544>>2] = $543;
             break;
            } else {
             $537 = (($536) + ($534))|0;
             $538 = (($523) - ($531))|0;
             $539 = (_FT_MulFix($538,$500)|0);
             $540 = (($537) + ($539))|0;
             $541 = (($point$01$i) + 44|0);
             HEAP32[$541>>2] = $540;
             break;
            }
           } else {
            $509 = (($503) + 8|0);
            $510 = HEAP32[$509>>2]|0;
            $511 = (($point$01$i) + 44|0);
            HEAP32[$511>>2] = $510;
           }
          } while(0);
          $545 = HEAP32[$505>>2]|0;
          $546 = $545 | 32;
          HEAP32[$505>>2] = $546;
         }
         $547 = (($count$02$i25) + -1)|0;
         $548 = (($point$01$i) + 48|0);
         $549 = ($547|0)==(0);
         if ($549) {
          break;
         } else {
          $count$02$i25 = $547;$point$01$i = $548;
         }
        }
        $$pre118 = HEAP32[$glyphrec>>2]|0;
        $556 = $$pre118;
       }
      }
      $550 = HEAP32[$237>>2]|0;
      $551 = ((($550) + (($dimension$071*204)|0)|0) + 200|0);
      $552 = HEAP32[$551>>2]|0;
      $553 = HEAP32[$6>>2]|0;
      $554 = HEAP32[$9>>2]|0;
      $555 = (($554) + (($556*48)|0)|0);
      $557 = ($556|0)>(0);
      do {
       if ($557) {
        $num_strongs$020$i = 0;$point$021$i = $554;
        while(1) {
         $558 = (($point$021$i) + 16|0);
         $559 = HEAP32[$558>>2]|0;
         $560 = $559 >>> 4;
         $$lobit$i = $560 & 1;
         $num_strongs$0$$i = (($$lobit$i) + ($num_strongs$020$i))|0;
         $561 = (($point$021$i) + 48|0);
         $562 = ($561>>>0)<($555>>>0);
         if ($562) {
          $num_strongs$020$i = $num_strongs$0$$i;$point$021$i = $561;
         } else {
          break;
         }
        }
        $563 = ($num_strongs$0$$i|0)==(0);
        if ($563) {
         break;
        }
        $564 = ($num_strongs$0$$i>>>0)<(17);
        if ($564) {
         $strongs$0$i = $strongs_0$i;
        } else {
         $565 = (_ft_mem_realloc($553,4,0,$num_strongs$0$$i,0,$error$i28)|0);
         $566 = HEAP32[$error$i28>>2]|0;
         $567 = ($566|0)==(0);
         if ($567) {
          $strongs$0$i = $565;
         } else {
          break;
         }
        }
        $num_strongs$215$i = 0;$point$116$i = $554;
        while(1) {
         $571 = (($point$116$i) + 16|0);
         $572 = HEAP32[$571>>2]|0;
         $573 = $572 & 16;
         $574 = ($573|0)==(0);
         if ($574) {
          $num_strongs$3$i = $num_strongs$215$i;
         } else {
          $575 = (($strongs$0$i) + ($num_strongs$215$i<<2)|0);
          $576 = ($num_strongs$215$i|0)>(0);
          L246: do {
           if ($576) {
            $577 = (($point$116$i) + 36|0);
            $578 = HEAP32[$577>>2]|0;
            $insert$09$i = $575;
            while(1) {
             $579 = (($insert$09$i) + -4|0);
             $580 = HEAP32[$579>>2]|0;
             $581 = (($580) + 36|0);
             $582 = HEAP32[$581>>2]|0;
             $583 = ($582|0)>($578|0);
             if (!($583)) {
              $insert$0$lcssa$i = $insert$09$i;
              break L246;
             }
             HEAP32[$insert$09$i>>2] = $580;
             $584 = ($579>>>0)>($strongs$0$i>>>0);
             if ($584) {
              $insert$09$i = $579;
             } else {
              $insert$0$lcssa$i = $579;
              break;
             }
            }
           } else {
            $insert$0$lcssa$i = $575;
           }
          } while(0);
          HEAP32[$insert$0$lcssa$i>>2] = $point$116$i;
          $585 = (($num_strongs$215$i) + 1)|0;
          $num_strongs$3$i = $585;
         }
         $586 = (($point$116$i) + 48|0);
         $587 = ($586>>>0)<($555>>>0);
         if ($587) {
          $num_strongs$215$i = $num_strongs$3$i;$point$116$i = $586;
         } else {
          break;
         }
        }
        $568 = ($num_strongs$3$i|0)==(0);
        $569 = (($num_strongs$3$i) + -1)|0;
        $570 = (($strongs$0$i) + ($569<<2)|0);
        $point$24$i = $554;
        while(1) {
         $588 = (($point$24$i) + 16|0);
         $589 = HEAP32[$588>>2]|0;
         $590 = $589 & 16;
         $591 = ($590|0)==(0);
         do {
          if ($591) {
           $592 = (($point$24$i) + 12|0);
           $593 = HEAP32[$592>>2]|0;
           $594 = $593 & 2;
           $595 = ($594|0)==(0);
           if (!($595)) {
            $596 = (($point$24$i) + 20|0);
            $597 = HEAP8[$596>>0]|0;
            $598 = ($597<<24>>24)==(4);
            if ($598) {
             break;
            }
            $599 = (($point$24$i) + 21|0);
            $600 = HEAP8[$599>>0]|0;
            $601 = ($597<<24>>24)==($600<<24>>24);
            if (!($601)) {
             break;
            }
            $602 = $589 & 64;
            $603 = ($602|0)==(0);
            if ($603) {
             $604 = $593 & 4;
             $605 = ($604|0)==(0);
             if ($605) {
              break;
             }
            }
            $606 = $593 & -3;
            HEAP32[$592>>2] = $606;
           }
           $$phi$trans$insert = (($point$24$i) + 36|0);
           $$pre120 = HEAP32[$$phi$trans$insert>>2]|0;
           do {
            if ($568) {
             label = 183;
            } else {
             $nn$01$i = 0;
             while(1) {
              $609 = (($strongs$0$i) + ($nn$01$i<<2)|0);
              $610 = HEAP32[$609>>2]|0;
              $611 = (($610) + 36|0);
              $612 = HEAP32[$611>>2]|0;
              $613 = ($612|0)>($$pre120|0);
              $608 = (($nn$01$i) + 1)|0;
              if ($613) {
               $nn$0$lcssa$i = $nn$01$i;
               break;
              }
              $607 = ($608>>>0)<($num_strongs$3$i>>>0);
              if ($607) {
               $nn$01$i = $608;
              } else {
               $nn$0$lcssa$i = $608;
               break;
              }
             }
             $614 = ($nn$0$lcssa$i|0)==(0);
             if ($614) {
              label = 183;
              break;
             }
             $624 = (($nn$0$lcssa$i) + -1)|0;
             $625 = (($strongs$0$i) + ($624<<2)|0);
             $626 = HEAP32[$625>>2]|0;
             $nn$1$i = $num_strongs$3$i;
             while(1) {
              $627 = ($nn$1$i|0)==(0);
              if ($627) {
               $nn$1$lcssa$i = 0;
               break;
              }
              $628 = (($nn$1$i) + -1)|0;
              $629 = (($strongs$0$i) + ($628<<2)|0);
              $630 = HEAP32[$629>>2]|0;
              $631 = (($630) + 36|0);
              $632 = HEAP32[$631>>2]|0;
              $633 = ($632|0)<($$pre120|0);
              if ($633) {
               $nn$1$lcssa$i = $nn$1$i;
               break;
              } else {
               $nn$1$i = $628;
              }
             }
             $634 = ($nn$1$lcssa$i|0)==($num_strongs$3$i|0);
             if ($634) {
              $635 = HEAP32[$570>>2]|0;
              $636 = (($635) + 44|0);
              $637 = HEAP32[$636>>2]|0;
              $638 = (($635) + 36|0);
              $639 = HEAP32[$638>>2]|0;
              $640 = (($$pre120) - ($639))|0;
              $641 = (_FT_MulFix($640,$552)|0);
              $642 = (($641) + ($637))|0;
              $643 = (($point$24$i) + 44|0);
              HEAP32[$643>>2] = $642;
              break;
             }
             $644 = (($strongs$0$i) + ($nn$1$lcssa$i<<2)|0);
             $645 = HEAP32[$644>>2]|0;
             $646 = (($626) + 36|0);
             $647 = HEAP32[$646>>2]|0;
             $648 = ($$pre120|0)==($647|0);
             if ($648) {
              $649 = (($626) + 44|0);
              $650 = HEAP32[$649>>2]|0;
              $651 = (($point$24$i) + 44|0);
              HEAP32[$651>>2] = $650;
              break;
             }
             $652 = (($645) + 36|0);
             $653 = HEAP32[$652>>2]|0;
             $654 = ($$pre120|0)==($653|0);
             if ($654) {
              $655 = (($645) + 44|0);
              $656 = HEAP32[$655>>2]|0;
              $657 = (($point$24$i) + 44|0);
              HEAP32[$657>>2] = $656;
              break;
             } else {
              $658 = (($626) + 44|0);
              $659 = HEAP32[$658>>2]|0;
              $660 = (($$pre120) - ($647))|0;
              $661 = (($645) + 44|0);
              $662 = HEAP32[$661>>2]|0;
              $663 = (($662) - ($659))|0;
              $664 = (($653) - ($647))|0;
              $665 = (_FT_MulDiv($660,$663,$664)|0);
              $666 = (($665) + ($659))|0;
              $667 = (($point$24$i) + 44|0);
              HEAP32[$667>>2] = $666;
              break;
             }
            }
           } while(0);
           if ((label|0) == 183) {
            label = 0;
            $615 = HEAP32[$strongs$0$i>>2]|0;
            $616 = (($615) + 44|0);
            $617 = HEAP32[$616>>2]|0;
            $618 = (($615) + 36|0);
            $619 = HEAP32[$618>>2]|0;
            $620 = (($$pre120) - ($619))|0;
            $621 = (_FT_MulFix($620,$552)|0);
            $622 = (($621) + ($617))|0;
            $623 = (($point$24$i) + 44|0);
            HEAP32[$623>>2] = $622;
           }
           $668 = HEAP32[$588>>2]|0;
           $669 = $668 | 32;
           HEAP32[$588>>2] = $669;
          }
         } while(0);
         $670 = (($point$24$i) + 48|0);
         $671 = ($670>>>0)<($555>>>0);
         if ($671) {
          $point$24$i = $670;
         } else {
          break;
         }
        }
        $672 = ($strongs$0$i|0)==($strongs_0$i|0);
        if ($672) {
         break;
        }
        _ft_mem_free($553,$strongs$0$i);
       }
      } while(0);
      $glyphrec$idx10$val = HEAP32[$22>>2]|0;
      $glyphrec$idx12$val = HEAP32[$237>>2]|0;
      $673 = ((($glyphrec$idx12$val) + (($dimension$071*204)|0)|0) + 200|0);
      $674 = HEAP32[$673>>2]|0;
      $675 = ($glyphrec$idx10$val|0)==(0);
      if (!($675)) {
       $glyphrec$idx11$val = HEAP32[$15>>2]|0;
       $676 = ((($glyphrec$idx12$val) + (($dimension$071*204)|0)|0) + 204|0);
       $677 = HEAP32[$676>>2]|0;
       $contour$013$i = $glyphrec$idx11$val;$delta$014$i = $677;$num_contours$012$i = $glyphrec$idx10$val;
       while(1) {
        $678 = HEAP32[$contour$013$i>>2]|0;
        $679 = (($contour$013$i) + 4|0);
        $680 = HEAP32[$679>>2]|0;
        $681 = (($678) + (($680*48)|0)|0);
        $682 = ($680|0)>(0);
        L296: do {
         if ($682) {
          $first$01$i = 0;$fit_count$03$i = 0;$point$02$i33 = $678;
          while(1) {
           $683 = (($point$02$i33) + 16|0);
           $684 = HEAP32[$683>>2]|0;
           $685 = $684 & 32;
           $686 = ($685|0)==(0);
           if ($686) {
            $first$2$i = $first$01$i;$fit_count$1$i = $fit_count$03$i;
           } else {
            $687 = ($first$01$i|0)==(0|0);
            $point$0$first$0$i = $687 ? $point$02$i33 : $first$01$i;
            $688 = (($fit_count$03$i) + 1)|0;
            $first$2$i = $point$0$first$0$i;$fit_count$1$i = $688;
           }
           $689 = (($point$02$i33) + 48|0);
           $690 = ($689>>>0)<($681>>>0);
           if ($690) {
            $first$01$i = $first$2$i;$fit_count$03$i = $fit_count$1$i;$point$02$i33 = $689;
           } else {
            break;
           }
          }
          $691 = ($fit_count$1$i>>>0)<(2);
          if ($691) {
           $695 = ($fit_count$1$i|0)==(1);
           if ($695) {
            $696 = (($first$2$i) + 44|0);
            $697 = HEAP32[$696>>2]|0;
            $698 = (($first$2$i) + 36|0);
            $699 = HEAP32[$698>>2]|0;
            $700 = (_FT_MulFix($699,$674)|0);
            $701 = (($697) - ($700))|0;
            $delta$1$i = $701;
           } else {
            $delta$1$i = $delta$014$i;
           }
           $point$19$i = $678;
           while(1) {
            $702 = ($point$19$i|0)==($first$2$i|0);
            if (!($702)) {
             $703 = (($point$19$i) + 36|0);
             $704 = HEAP32[$703>>2]|0;
             $705 = (_FT_MulFix($704,$674)|0);
             $706 = (($705) + ($delta$1$i))|0;
             $707 = (($point$19$i) + 44|0);
             HEAP32[$707>>2] = $706;
            }
            $708 = (($point$19$i) + 48|0);
            $709 = ($708>>>0)<($681>>>0);
            if ($709) {
             $point$19$i = $708;
            } else {
             $delta$2$i = $delta$1$i;
             break L296;
            }
           }
          }
          $692 = (($first$2$i) + 4|0);
          $693 = HEAP32[$692>>2]|0;
          $694 = ($693|0)==($first$2$i|0);
          if ($694) {
           $delta$2$i = $delta$014$i;
           break;
          } else {
           $711 = $693;$740 = $692;$first$46$i = $first$2$i;
          }
          while(1) {
           $710 = (($711) + 16|0);
           $712 = HEAP32[$710>>2]|0;
           $713 = $712 & 32;
           $714 = ($713|0)==(0);
           if ($714) {
            $next$0$i = $711;
            while(1) {
             $715 = (($next$0$i) + 4|0);
             $716 = HEAP32[$715>>2]|0;
             $717 = (($716) + 16|0);
             $718 = HEAP32[$717>>2]|0;
             $719 = $718 & 32;
             $720 = ($719|0)==(0);
             if ($720) {
              $next$0$i = $716;
             } else {
              break;
             }
            }
            $721 = (($first$46$i) + 36|0);
            $722 = HEAP32[$721>>2]|0;
            $723 = (($716) + 36|0);
            $724 = HEAP32[$723>>2]|0;
            $725 = ($722|0)>($724|0);
            if ($725) {
             $732 = (($716) + 44|0);
             $733 = HEAP32[$732>>2]|0;
             $734 = (($722) - ($724))|0;
             $735 = (($first$46$i) + 44|0);
             $736 = HEAP32[$735>>2]|0;
             $737 = (($736) - ($733))|0;
             $cur_a$0$i = $733;$cur_ab$0$i = $737;$org_a$0$i = $724;$org_ab$0$i = $734;
            } else {
             $726 = (($first$46$i) + 44|0);
             $727 = HEAP32[$726>>2]|0;
             $728 = (($724) - ($722))|0;
             $729 = (($716) + 44|0);
             $730 = HEAP32[$729>>2]|0;
             $731 = (($730) - ($727))|0;
             $cur_a$0$i = $727;$cur_ab$0$i = $731;$org_a$0$i = $722;$org_ab$0$i = $728;
            }
            $738 = ($org_ab$0$i|0)>(0);
            if ($738) {
             $739 = (_FT_DivFix($cur_ab$0$i,$org_ab$0$i)|0);
             $$pre$i40 = HEAP32[$740>>2]|0;
             $839 = $$pre$i40;$scale_ab$0$i = $739;
            } else {
             $839 = $711;$scale_ab$0$i = 65536;
            }
            $741 = (($cur_ab$0$i) + ($cur_a$0$i))|0;
            $point$2$i = $839;
            while(1) {
             $742 = (($point$2$i) + 36|0);
             $743 = HEAP32[$742>>2]|0;
             $744 = (($743) - ($org_a$0$i))|0;
             $745 = ($744|0)<(1);
             do {
              if ($745) {
               $746 = (_FT_MulFix($744,$674)|0);
               $747 = (($746) + ($cur_a$0$i))|0;
               $cur_c$0$i = $747;
              } else {
               $748 = ($744|0)<($org_ab$0$i|0);
               if ($748) {
                $752 = (_FT_MulFix($744,$scale_ab$0$i)|0);
                $753 = (($752) + ($cur_a$0$i))|0;
                $cur_c$0$i = $753;
                break;
               } else {
                $749 = (($744) - ($org_ab$0$i))|0;
                $750 = (_FT_MulFix($749,$674)|0);
                $751 = (($741) + ($750))|0;
                $cur_c$0$i = $751;
                break;
               }
              }
             } while(0);
             $754 = (($point$2$i) + 44|0);
             HEAP32[$754>>2] = $cur_c$0$i;
             $755 = (($point$2$i) + 4|0);
             $756 = HEAP32[$755>>2]|0;
             $757 = ($756|0)==($716|0);
             if ($757) {
              break;
             } else {
              $point$2$i = $756;
             }
            }
            $758 = ($716|0)==($first$2$i|0);
            if ($758) {
             $delta$2$i = $delta$014$i;
             break L296;
            } else {
             $first$4$be$i = $716;
            }
           } else {
            $first$4$be$i = $711;
           }
           $759 = (($first$4$be$i) + 4|0);
           $760 = HEAP32[$759>>2]|0;
           $761 = ($760|0)==($first$2$i|0);
           if ($761) {
            $delta$2$i = $delta$014$i;
            break;
           } else {
            $711 = $760;$740 = $759;$first$46$i = $first$4$be$i;
           }
          }
         } else {
          $delta$2$i = $delta$014$i;
         }
        } while(0);
        $762 = (($num_contours$012$i) + -1)|0;
        $763 = (($contour$013$i) + 8|0);
        $764 = ($762|0)==(0);
        if ($764) {
         break;
        } else {
         $contour$013$i = $763;$delta$014$i = $delta$2$i;$num_contours$012$i = $762;
        }
       }
      }
      $765 = HEAP32[$9>>2]|0;
      $766 = HEAP32[$glyphrec$idx3>>2]|0;
      $767 = (($766) + 4|0);
      $768 = HEAP32[$767>>2]|0;
      $769 = (($766) + 8|0);
      $770 = HEAP32[$769>>2]|0;
      $771 = HEAP32[$glyphrec>>2]|0;
      $772 = ($771|0)==(0);
      if (!($772)) {
       $773 = $378 ? 32 : 64;
       if ($378) {
        $840 = $771;$n$02$us$i = 0;$point$01$us$i = $765;
        while(1) {
         $774 = (($point$01$us$i) + 44|0);
         $775 = HEAP32[$774>>2]|0;
         $776 = (($768) + ($n$02$us$i<<3)|0);
         HEAP32[$776>>2] = $775;
         $777 = (($point$01$us$i) + 16|0);
         $778 = HEAP32[$777>>2]|0;
         $779 = $778 & 16;
         $780 = ($779|0)==(0);
         if ($780) {
          $789 = $840;
         } else {
          $781 = (($770) + ($n$02$us$i)|0);
          $782 = HEAP8[$781>>0]|0;
          $783 = $782&255;
          $784 = $783 | $773;
          $785 = $784&255;
          HEAP8[$781>>0] = $785;
          $$pre$i43 = HEAP32[$glyphrec>>2]|0;
          $789 = $$pre$i43;
         }
         $786 = (($point$01$us$i) + 48|0);
         $787 = (($n$02$us$i) + 1)|0;
         $788 = ($787>>>0)<($789>>>0);
         if ($788) {
          $840 = $789;$n$02$us$i = $787;$point$01$us$i = $786;
         } else {
          break;
         }
        }
       } else {
        $841 = $771;$n$02$i = 0;$point$01$i44 = $765;
        while(1) {
         $790 = (($point$01$i44) + 44|0);
         $791 = HEAP32[$790>>2]|0;
         $792 = ((($768) + ($n$02$i<<3)|0) + 4|0);
         HEAP32[$792>>2] = $791;
         $793 = (($point$01$i44) + 16|0);
         $794 = HEAP32[$793>>2]|0;
         $795 = $794 & 16;
         $796 = ($795|0)==(0);
         if ($796) {
          $805 = $841;
         } else {
          $797 = (($770) + ($n$02$i)|0);
          $798 = HEAP8[$797>>0]|0;
          $799 = $798&255;
          $800 = $799 | $773;
          $801 = $800&255;
          HEAP8[$797>>0] = $801;
          $$pre3$i = HEAP32[$glyphrec>>2]|0;
          $805 = $$pre3$i;
         }
         $802 = (($point$01$i44) + 48|0);
         $803 = (($n$02$i) + 1)|0;
         $804 = ($803>>>0)<($805>>>0);
         if ($804) {
          $841 = $805;$n$02$i = $803;$point$01$i44 = $802;
         } else {
          break;
         }
        }
       }
      }
      if (!($274)) {
       $806 = HEAP32[$237>>2]|0;
       (_psh_globals_set_scale($806,$240,$242,0,0)|0);
      }
      $807 = (($dimension$071) + 1)|0;
      $exitcond = ($807|0)==(2);
      if ($exitcond) {
       $$pre$phiZ2D = $15;$834 = 0;
       break;
      } else {
       $dimension$071 = $807;
      }
     }
    } else {
     $$pre$phiZ2D = $15;$834 = $235;
    }
   } else {
    $$pre$phiZ2D = $15;$834 = $230;
   }
  } else {
   $$pre$phiZ2D = $15;$834 = $16;
  }
 } else {
  $$pre121 = (($glyphrec) + 12|0);
  $$pre$phiZ2D = $$pre121;$834 = $10;
 }
 $808 = HEAP32[$6>>2]|0;
 $809 = (($glyphrec) + 92|0);
 $810 = HEAP32[$809>>2]|0;
 _ft_mem_free($808,$810);
 HEAP32[$809>>2] = 0;
 $811 = (($glyphrec) + 88|0);
 HEAP32[$811>>2] = 0;
 $812 = (($glyphrec) + 96|0);
 HEAP32[$812>>2] = 0;
 $813 = (($glyphrec) + 80|0);
 $814 = HEAP32[$813>>2]|0;
 _ft_mem_free($808,$814);
 HEAP32[$813>>2] = 0;
 $815 = (($glyphrec) + 76|0);
 $816 = HEAP32[$815>>2]|0;
 _ft_mem_free($808,$816);
 HEAP32[$815>>2] = 0;
 $817 = (($glyphrec) + 72|0);
 HEAP32[$817>>2] = 0;
 $818 = (($glyphrec) + 68|0);
 HEAP32[$818>>2] = 0;
 $819 = (($glyphrec) + 84|0);
 HEAP32[$819>>2] = 0;
 $820 = (($glyphrec) + 52|0);
 $821 = HEAP32[$820>>2]|0;
 _ft_mem_free($808,$821);
 HEAP32[$820>>2] = 0;
 $822 = (($glyphrec) + 48|0);
 HEAP32[$822>>2] = 0;
 $823 = (($glyphrec) + 56|0);
 HEAP32[$823>>2] = 0;
 $824 = (($glyphrec) + 40|0);
 $825 = HEAP32[$824>>2]|0;
 _ft_mem_free($808,$825);
 HEAP32[$824>>2] = 0;
 $826 = (($glyphrec) + 36|0);
 $827 = HEAP32[$826>>2]|0;
 _ft_mem_free($808,$827);
 HEAP32[$826>>2] = 0;
 $828 = (($glyphrec) + 32|0);
 HEAP32[$828>>2] = 0;
 $829 = (($glyphrec) + 28|0);
 HEAP32[$829>>2] = 0;
 $830 = (($glyphrec) + 44|0);
 HEAP32[$830>>2] = 0;
 $831 = HEAP32[$9>>2]|0;
 _ft_mem_free($808,$831);
 HEAP32[$9>>2] = 0;
 $832 = HEAP32[$$pre$phiZ2D>>2]|0;
 _ft_mem_free($808,$832);
 HEAP32[$$pre$phiZ2D>>2] = 0;
 HEAP32[$glyphrec>>2] = 0;
 $833 = (($glyphrec) + 4|0);
 HEAP32[$833>>2] = 0;
 HEAP32[$6>>2] = 0;
 $$0 = $834;
 STACKTOP = sp;return ($$0|0);
}
function _psh_hint_table_activate_mask($table,$hint_mask$0$0$val,$hint_mask$0$2$val) {
 $table = $table|0;
 $hint_mask$0$0$val = $hint_mask$0$0$val|0;
 $hint_mask$0$2$val = $hint_mask$0$2$val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $count$08 = 0, $count$1 = 0, $cursor$010 = 0, $cursor$1 = 0, $exitcond = 0, $exitcond15 = 0, $hint$02$i = 0, $i1$04 = 0, $i2$03 = 0, $i2$03$in = 0, $idx$09 = 0, $mask$012 = 0, $mask$1 = 0, $table$idx$val = 0;
 var $table$idx1 = 0, $table$idx1$val = 0, $val$011 = 0, $val$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $table$idx$val = HEAP32[$table>>2]|0;
 $0 = ($table$idx$val|0)==(0);
 if (!($0)) {
  $table$idx1 = (($table) + 8|0);
  $table$idx1$val = HEAP32[$table$idx1>>2]|0;
  $count$01$i = $table$idx$val;$hint$02$i = $table$idx1$val;
  while(1) {
   $1 = (($hint$02$i) + 16|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = $2 & -5;
   HEAP32[$1>>2] = $3;
   $4 = (($hint$02$i) + 24|0);
   HEAP32[$4>>2] = -1;
   $5 = (($count$01$i) + -1)|0;
   $6 = (($hint$02$i) + 28|0);
   $7 = ($5|0)==(0);
   if ($7) {
    break;
   } else {
    $count$01$i = $5;$hint$02$i = $6;
   }
  }
 }
 $8 = ($hint_mask$0$0$val|0)==(0);
 if ($8) {
  $9 = (($table) + 4|0);
  HEAP32[$9>>2] = 0;
  STACKTOP = sp;return;
 }
 $10 = (($table) + 8|0);
 $11 = (($table) + 12|0);
 $count$08 = 0;$cursor$010 = $hint_mask$0$2$val;$idx$09 = 0;$mask$012 = 0;$val$011 = 0;
 while(1) {
  $12 = ($mask$012|0)==(0);
  if ($12) {
   $13 = (($cursor$010) + 1|0);
   $14 = HEAP8[$cursor$010>>0]|0;
   $15 = $14&255;
   $cursor$1 = $13;$mask$1 = 128;$val$1 = $15;
  } else {
   $cursor$1 = $cursor$010;$mask$1 = $mask$012;$val$1 = $val$011;
  }
  $16 = $mask$1 & $val$1;
  $17 = ($16|0)==(0);
  if ($17) {
   $count$1 = $count$08;
  } else {
   $18 = HEAP32[$10>>2]|0;
   $19 = (($18) + (($idx$09*28)|0)|0);
   $20 = ((($18) + (($idx$09*28)|0)|0) + 16|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $21 & 4;
   $23 = ($22|0)==(0);
   if ($23) {
    $24 = $21 | 4;
    HEAP32[$20>>2] = $24;
    $25 = HEAP32[$table>>2]|0;
    $26 = ($count$08>>>0)<($25>>>0);
    if ($26) {
     $27 = (($count$08) + 1)|0;
     $28 = HEAP32[$11>>2]|0;
     $29 = (($28) + ($count$08<<2)|0);
     HEAP32[$29>>2] = $19;
     $count$1 = $27;
    } else {
     $count$1 = $count$08;
    }
   } else {
    $count$1 = $count$08;
   }
  }
  $30 = $mask$1 >> 1;
  $31 = (($idx$09) + 1)|0;
  $exitcond15 = ($31|0)==($hint_mask$0$0$val|0);
  if ($exitcond15) {
   break;
  } else {
   $count$08 = $count$1;$cursor$010 = $cursor$1;$idx$09 = $31;$mask$012 = $30;$val$011 = $val$1;
  }
 }
 $32 = (($table) + 4|0);
 HEAP32[$32>>2] = $count$1;
 $33 = HEAP32[$11>>2]|0;
 $34 = ($count$1|0)>(1);
 if ($34) {
  $i1$04 = 1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $35 = (($33) + ($i1$04<<2)|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP32[$36>>2]|0;
  $i2$03$in = $i1$04;
  while(1) {
   $i2$03 = (($i2$03$in) + -1)|0;
   $38 = (($33) + ($i2$03<<2)|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)<($37|0);
   if ($41) {
    break;
   }
   $42 = (($33) + ($i2$03$in<<2)|0);
   HEAP32[$42>>2] = $39;
   HEAP32[$38>>2] = $36;
   $43 = ($i2$03|0)>(0);
   if ($43) {
    $i2$03$in = $i2$03;
   } else {
    break;
   }
  }
  $44 = (($i1$04) + 1)|0;
  $exitcond = ($44|0)==($count$1|0);
  if ($exitcond) {
   break;
  } else {
   $i1$04 = $44;
  }
 }
 STACKTOP = sp;return;
}
function _psh_hint_table_find_strong_points($table$0$1$val,$table$0$3$val,$point,$count,$threshold,$major_dir) {
 $table$0$1$val = $table$0$1$val|0;
 $table$0$3$val = $table$0$3$val|0;
 $point = $point|0;
 $count = $count|0;
 $threshold = $threshold|0;
 $major_dir = $major_dir|0;
 var $$ = 0, $$0123 = 0, $$024 = 0, $$6 = 0, $$not = 0, $$not43 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $brmerge = 0;
 var $brmerge42 = 0, $brmerge44 = 0, $nn$06 = 0, $nn1$02 = 0, $nn4$011 = 0, $nn4$116 = 0, $nn4$221 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond3 = 0, $or$cond41 = 0, $or$cond5 = 0, $or$cond8 = 0, $point_dir$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (0 - ($major_dir))|0;
 $2 = ($table$0$1$val|0)==(0);
 $3 = ($major_dir|0)==(2);
 $$ = $3 ? 128 : 256;
 $$6 = $3 ? 256 : 128;
 $$0123 = $count;$$024 = $point;
 while(1) {
  $4 = (($$024) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($$024) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & 16;
  $9 = ($8|0)==(0);
  L6: do {
   if ($9) {
    $10 = (($$024) + 20|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11 << 24 >> 24;
    $13 = ($12|0)==($major_dir|0);
    $14 = ($12|0)==($1|0);
    $or$cond41 = $13 | $14;
    if ($or$cond41) {
     $point_dir$0 = $12;
     label = 6;
    } else {
     $15 = (($$024) + 21|0);
     $16 = HEAP8[$15>>0]|0;
     $17 = $16 << 24 >> 24;
     $18 = ($17|0)==($major_dir|0);
     $19 = ($17|0)==($1|0);
     $or$cond = $18 | $19;
     if ($or$cond) {
      $point_dir$0 = $17;
      label = 6;
     }
    }
    if ((label|0) == 6) {
     label = 0;
     $20 = ($point_dir$0|0)==(0);
     if (!($20)) {
      $21 = ($point_dir$0|0)==($major_dir|0);
      if ($21) {
       if ($2) {
        break;
       } else {
        $nn$06 = 0;
       }
       while(1) {
        $24 = (($table$0$3$val) + ($nn$06<<2)|0);
        $25 = HEAP32[$24>>2]|0;
        $26 = HEAP32[$25>>2]|0;
        $27 = (($5) - ($26))|0;
        $28 = ($27|0)<($threshold|0);
        $29 = (0 - ($27))|0;
        $30 = ($29|0)<($threshold|0);
        $or$cond3 = $28 & $30;
        $23 = (($nn$06) + 1)|0;
        if ($or$cond3) {
         break;
        }
        $22 = ($23>>>0)<($table$0$1$val>>>0);
        if ($22) {
         $nn$06 = $23;
        } else {
         break L6;
        }
       }
       $31 = $7 | 528;
       HEAP32[$6>>2] = $31;
       $32 = (($$024) + 32|0);
       HEAP32[$32>>2] = $25;
       break;
      } else {
       $$not = ($point_dir$0|0)!=($1|0);
       $brmerge = $$not | $2;
       if ($brmerge) {
        break;
       } else {
        $nn1$02 = 0;
       }
       while(1) {
        $35 = (($table$0$3$val) + ($nn1$02<<2)|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = HEAP32[$36>>2]|0;
        $38 = (($5) - ($37))|0;
        $39 = (($36) + 4|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = (($38) - ($40))|0;
        $42 = ($41|0)<($threshold|0);
        $43 = (0 - ($41))|0;
        $44 = ($43|0)<($threshold|0);
        $or$cond5 = $42 & $44;
        $34 = (($nn1$02) + 1)|0;
        if ($or$cond5) {
         break;
        }
        $33 = ($34>>>0)<($table$0$1$val>>>0);
        if ($33) {
         $nn1$02 = $34;
        } else {
         break L6;
        }
       }
       $45 = $7 | 1040;
       HEAP32[$6>>2] = $45;
       $46 = (($$024) + 32|0);
       HEAP32[$46>>2] = $36;
       break;
      }
     }
    }
    $47 = $7 & 64;
    $48 = ($47|0)==(0);
    if (!($48)) {
     $49 = $7 & $$;
     $50 = ($49|0)==(0);
     L26: do {
      if ($50) {
       $62 = $7 & $$6;
       $63 = ($62|0)==(0);
       $brmerge42 = $63 | $2;
       if (!($brmerge42)) {
        $nn4$116 = 0;
        while(1) {
         $66 = (($table$0$3$val) + ($nn4$116<<2)|0);
         $67 = HEAP32[$66>>2]|0;
         $68 = HEAP32[$67>>2]|0;
         $69 = (($5) - ($68))|0;
         $70 = (($67) + 4|0);
         $71 = HEAP32[$70>>2]|0;
         $72 = (($69) - ($71))|0;
         $73 = ($72|0)<($threshold|0);
         $74 = (0 - ($72))|0;
         $75 = ($74|0)<($threshold|0);
         $or$cond10 = $73 & $75;
         $65 = (($nn4$116) + 1)|0;
         if ($or$cond10) {
          break;
         }
         $64 = ($65>>>0)<($table$0$1$val>>>0);
         if ($64) {
          $nn4$116 = $65;
         } else {
          break L26;
         }
        }
        $76 = (($$024) + 32|0);
        HEAP32[$76>>2] = $67;
        $77 = $7 | 1040;
        HEAP32[$6>>2] = $77;
       }
      } else {
       if (!($2)) {
        $nn4$011 = 0;
        while(1) {
         $53 = (($table$0$3$val) + ($nn4$011<<2)|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = HEAP32[$54>>2]|0;
         $56 = (($5) - ($55))|0;
         $57 = ($56|0)<($threshold|0);
         $58 = (0 - ($56))|0;
         $59 = ($58|0)<($threshold|0);
         $or$cond8 = $57 & $59;
         $52 = (($nn4$011) + 1)|0;
         if ($or$cond8) {
          break;
         }
         $51 = ($52>>>0)<($table$0$1$val>>>0);
         if ($51) {
          $nn4$011 = $52;
         } else {
          break L26;
         }
        }
        $60 = (($$024) + 32|0);
        HEAP32[$60>>2] = $54;
        $61 = $7 | 528;
        HEAP32[$6>>2] = $61;
       }
      }
     } while(0);
     $78 = (($$024) + 32|0);
     $79 = HEAP32[$78>>2]|0;
     $$not43 = ($79|0)!=(0|0);
     $brmerge44 = $$not43 | $2;
     if (!($brmerge44)) {
      $nn4$221 = 0;
      while(1) {
       $80 = (($table$0$3$val) + ($nn4$221<<2)|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = HEAP32[$81>>2]|0;
       $83 = ($5|0)<($82|0);
       if (!($83)) {
        $84 = (($81) + 4|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = (($85) + ($82))|0;
        $87 = ($5|0)>($86|0);
        if (!($87)) {
         break;
        }
       }
       $88 = (($nn4$221) + 1)|0;
       $89 = ($88>>>0)<($table$0$1$val>>>0);
       if ($89) {
        $nn4$221 = $88;
       } else {
        break L6;
       }
      }
      HEAP32[$78>>2] = $81;
     }
    }
   }
  } while(0);
  $90 = (($$0123) + -1)|0;
  $91 = (($$024) + 48|0);
  $92 = ($90|0)==(0);
  if ($92) {
   break;
  } else {
   $$0123 = $90;$$024 = $91;
  }
 }
 STACKTOP = sp;return;
}
function _psh_hint_align($hint,$globals,$dimension,$glyph) {
 $hint = $hint|0;
 $globals = $globals|0;
 $dimension = $dimension|0;
 $glyph = $glyph|0;
 var $$ = 0, $$$0$i = 0, $$$i = 0, $$$i3 = 0, $$0$i = 0, $$2 = 0, $$2$i = 0, $$not10 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $align = 0, $len$0 = 0, $len$1 = 0, $pos$0 = 0;
 var $pos$1 = 0, $pos$2 = 0, $right_disp$0 = 0, $sum = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $align = sp;
 $0 = ((($globals) + (($dimension*204)|0)|0) + 200|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($hint) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 8;
 $5 = ($4|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = ((($globals) + (($dimension*204)|0)|0) + 204|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$hint>>2]|0;
 $9 = (_FT_MulFix($8,$1)|0);
 $10 = (($9) + ($7))|0;
 $11 = (($hint) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (_FT_MulFix($12,$1)|0);
 if ((($dimension|0) == 1)) {
  $19 = (($glyph) + 121|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = ($20<<24>>24)==(0);
  if ($21) {
   label = 6;
  } else {
   $26 = (($glyph) + 123|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)!=(0);
   $145 = 1;$146 = $28;
  }
 } else if ((($dimension|0) == 0)) {
  $14 = (($glyph) + 120|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   label = 6;
  } else {
   $17 = (($glyph) + 122|0);
   $18 = HEAP8[$17>>0]|0;
   $$not10 = ($18<<24>>24)!=(0);
   $145 = 0;$146 = $$not10;
  }
 } else {
  $145 = 0;$146 = 0;
 }
 if ((label|0) == 6) {
  $22 = (($hint) + 8|0);
  HEAP32[$22>>2] = $10;
  $23 = (($hint) + 12|0);
  HEAP32[$23>>2] = $13;
  $24 = HEAP32[$2>>2]|0;
  $25 = $24 | 8;
  HEAP32[$2>>2] = $25;
  STACKTOP = sp;return;
 }
 $29 = (($hint) + 12|0);
 HEAP32[$29>>2] = $13;
 HEAP32[$align>>2] = 0;
 $30 = (($align) + 4|0);
 HEAP32[$30>>2] = 0;
 $31 = (($align) + 8|0);
 HEAP32[$31>>2] = 0;
 do {
  if ($145) {
   $32 = (($globals) + 412|0);
   $33 = HEAP32[$hint>>2]|0;
   $34 = HEAP32[$11>>2]|0;
   $35 = (($34) + ($33))|0;
   _psh_blues_snap_stem($32,$35,$33,$align);
   $$pre = HEAP32[$align>>2]|0;
   if ((($$pre|0) == 2)) {
    $39 = HEAP32[$31>>2]|0;
    $40 = (($hint) + 8|0);
    HEAP32[$40>>2] = $39;
    $137 = $39;
    break;
   } else if ((($$pre|0) == 1)) {
    $36 = HEAP32[$30>>2]|0;
    $37 = (($36) - ($13))|0;
    $38 = (($hint) + 8|0);
    HEAP32[$38>>2] = $37;
    $137 = $37;
    break;
   } else if ((($$pre|0) == 3)) {
    $41 = HEAP32[$31>>2]|0;
    $42 = (($hint) + 8|0);
    HEAP32[$42>>2] = $41;
    $43 = HEAP32[$30>>2]|0;
    $44 = (($43) - ($41))|0;
    HEAP32[$29>>2] = $44;
    $137 = $41;
    break;
   } else {
    label = 13;
    break;
   }
  } else {
   label = 13;
  }
 } while(0);
 if ((label|0) == 13) {
  $45 = (($hint) + 20|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($46|0)==(0|0);
  if ($47) {
   $pos$0 = $10;
  } else {
   $48 = (($46) + 16|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = $49 & 8;
   $51 = ($50|0)==(0);
   if ($51) {
    _psh_hint_align($46,$globals,$dimension,$glyph);
   }
   $52 = HEAP32[$46>>2]|0;
   $53 = (($46) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = $54 >> 1;
   $56 = (($46) + 8|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($46) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 >> 1;
   $61 = HEAP32[$hint>>2]|0;
   $62 = HEAP32[$11>>2]|0;
   $63 = $62 >> 1;
   $sum = (($55) + ($52))|0;
   $64 = (($61) - ($sum))|0;
   $65 = (($64) + ($63))|0;
   $66 = (_FT_MulFix($65,$1)|0);
   $67 = $13 >> 1;
   $68 = (($57) - ($67))|0;
   $69 = (($68) + ($60))|0;
   $70 = (($69) + ($66))|0;
   $pos$0 = $70;
  }
  $71 = (($hint) + 8|0);
  HEAP32[$71>>2] = $pos$0;
  HEAP32[$29>>2] = $13;
  $72 = (($glyph) + 124|0);
  $73 = HEAP8[$72>>0]|0;
  $74 = ($73<<24>>24)==(0);
  do {
   if ($74) {
    $len$0 = $13;$pos$1 = $pos$0;
   } else {
    $75 = ($13|0)<(65);
    if ($75) {
     $76 = ($13|0)>(31);
     if ($76) {
      $77 = $13 >> 1;
      $78 = (($pos$0) + ($77))|0;
      $79 = $78 & -64;
      $len$0 = 64;$pos$1 = $79;
      break;
     }
     $80 = ($13|0)>(0);
     $81 = (($pos$0) + 32)|0;
     $82 = $81 & -64;
     if (!($80)) {
      $len$0 = $13;$pos$1 = $82;
      break;
     }
     $83 = (($pos$0) + ($13))|0;
     $84 = (($83) + 32)|0;
     $85 = $84 & -64;
     $86 = (($82) - ($pos$0))|0;
     $87 = (($85) - ($83))|0;
     $88 = ($86|0)<(0);
     $89 = (0 - ($86))|0;
     $$ = $88 ? $89 : $86;
     $90 = ($87|0)<(0);
     $91 = (0 - ($87))|0;
     $right_disp$0 = $90 ? $91 : $87;
     $92 = ($$|0)>($right_disp$0|0);
     $$2 = $92 ? $85 : $82;
     $len$0 = $13;$pos$1 = $$2;
     break;
    }
    $93 = ((($globals) + (($dimension*204)|0)|0) + 12|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = (($13) - ($94))|0;
    $96 = ($95|0)<(0);
    $97 = (0 - ($95))|0;
    $$2$i = $96 ? $97 : $95;
    $98 = ($$2$i|0)<(40);
    if ($98) {
     $99 = ($94|0)<(48);
     $$$i3 = $99 ? 48 : $94;
     $$0$i = $$$i3;
    } else {
     $$0$i = $13;
    }
    $100 = ($$0$i|0)<(192);
    if (!($100)) {
     $108 = (($$0$i) + 32)|0;
     $109 = $108 & -64;
     $len$0 = $109;$pos$1 = $pos$0;
     break;
    }
    $101 = $$0$i & 63;
    $102 = $$0$i & -64;
    $103 = ($101>>>0)<(10);
    if ($103) {
     $len$0 = $$0$i;$pos$1 = $pos$0;
    } else {
     $104 = ($101>>>0)<(32);
     if ($104) {
      $105 = $102 | 10;
      $len$0 = $105;$pos$1 = $pos$0;
      break;
     } else {
      $106 = ($101>>>0)<(54);
      $107 = $102 | 54;
      $$$0$i = $106 ? $107 : $$0$i;
      $len$0 = $$$0$i;$pos$1 = $pos$0;
      break;
     }
    }
   }
  } while(0);
  $110 = (($pos$1) + 32)|0;
  $111 = $110 & -64;
  $112 = (($111) - ($pos$1))|0;
  $113 = (($110) + ($len$0))|0;
  $114 = $113 & -64;
  $115 = (($114) - ($pos$1))|0;
  $116 = (($115) - ($len$0))|0;
  $117 = ($112|0)<(0);
  $118 = (0 - ($112))|0;
  $119 = $117 ? $118 : $112;
  $120 = ($116|0)<(0);
  $121 = (0 - ($116))|0;
  $122 = $120 ? $121 : $116;
  $123 = ($119|0)>($122|0);
  $$$i = $123 ? $116 : $112;
  $124 = (($$$i) + ($pos$1))|0;
  HEAP32[$71>>2] = $124;
  HEAP32[$29>>2] = $len$0;
  $137 = $124;
 }
 do {
  if ($146) {
   $125 = (($hint) + 8|0);
   $126 = HEAP32[$29>>2]|0;
   $127 = ($126|0)<(64);
   if ($127) {
    $len$1 = 64;
   } else {
    $128 = (($126) + 32)|0;
    $129 = $128 & -64;
    $len$1 = $129;
   }
   $130 = HEAP32[$align>>2]|0;
   if ((($130|0) == 2)) {
    HEAP32[$29>>2] = $len$1;
    break;
   } else if ((($130|0) == 1)) {
    $131 = HEAP32[$30>>2]|0;
    $132 = (($131) - ($len$1))|0;
    HEAP32[$125>>2] = $132;
    HEAP32[$29>>2] = $len$1;
    break;
   } else if ((($130|0) == 3)) {
    break;
   } else {
    HEAP32[$29>>2] = $len$1;
    $133 = $len$1 & 64;
    $134 = ($133|0)==(0);
    $135 = $len$1 >> 1;
    $136 = (($135) + ($137))|0;
    if ($134) {
     $140 = (($136) + 32)|0;
     $141 = $140 & -64;
     $pos$2 = $141;
    } else {
     $138 = $136 & -64;
     $139 = $138 | 32;
     $pos$2 = $139;
    }
    $142 = (($pos$2) - ($135))|0;
    HEAP32[$125>>2] = $142;
    HEAP32[$29>>2] = $len$1;
    break;
   }
  }
 } while(0);
 $143 = HEAP32[$2>>2]|0;
 $144 = $143 | 8;
 HEAP32[$2>>2] = $144;
 STACKTOP = sp;return;
}
function _psh_hint_table_init($table,$hints,$hint_masks,$memory) {
 $table = $table|0;
 $hints = $hints|0;
 $hint_masks = $hint_masks|0;
 $memory = $memory|0;
 var $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx1$i = 0, $$idx1$i$i = 0, $$idx1$val$i = 0, $$idx1$val$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$011 = 0, $count$02$i = 0, $count$02$i$i = 0, $count$18 = 0, $cursor$03$i = 0, $cursor$1$i = 0, $error = 0, $exitcond = 0, $exitcond$i = 0, $idx$04 = 0, $idx$04$i = 0, $mask$0$idx$val = 0, $mask$0$idx1 = 0, $mask$0$idx1$val = 0, $mask$05$i = 0;
 var $mask$09 = 0, $mask$1$i = 0, $or$cond = 0, $read$013 = 0, $sorted$03$i = 0, $sorted$03$i$i = 0, $val$02$i = 0, $val$1$i = 0, $write$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$hints>>2]|0;
 $1 = $0 << 1;
 $2 = (_ft_mem_realloc($memory,4,0,$1,0,$error)|0);
 $3 = (($table) + 12|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$error>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $117 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($117|0);
 }
 $6 = (_ft_mem_realloc($memory,28,0,$0,0,$error)|0);
 $7 = (($table) + 8|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$error>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $117 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($117|0);
 }
 $10 = $1 | 1;
 $11 = (_ft_mem_realloc($memory,16,0,$10,0,$error)|0);
 $12 = (($table) + 24|0);
 HEAP32[$12>>2] = $11;
 $13 = HEAP32[$error>>2]|0;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $117 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($117|0);
 }
 HEAP32[$table>>2] = $0;
 $15 = HEAP32[$3>>2]|0;
 $16 = (($15) + ($0<<2)|0);
 $17 = (($table) + 16|0);
 HEAP32[$17>>2] = $16;
 $18 = (($table) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($table) + 20|0);
 HEAP32[$19>>2] = 0;
 $20 = (($table) + 28|0);
 HEAP32[$20>>2] = 0;
 $21 = ($0|0)==(0);
 if (!($21)) {
  $22 = (($hints) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$7>>2]|0;
  $count$011 = $0;$read$013 = $23;$write$012 = $24;
  while(1) {
   $25 = HEAP32[$read$013>>2]|0;
   HEAP32[$write$012>>2] = $25;
   $26 = (($read$013) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($write$012) + 4|0);
   HEAP32[$28>>2] = $27;
   $29 = (($read$013) + 8|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (($write$012) + 16|0);
   HEAP32[$31>>2] = $30;
   $32 = (($count$011) + -1)|0;
   $33 = (($write$012) + 28|0);
   $34 = (($read$013) + 12|0);
   $35 = ($32|0)==(0);
   if ($35) {
    break;
   } else {
    $count$011 = $32;$read$013 = $34;$write$012 = $33;
   }
  }
 }
 $36 = ($hint_masks|0)==(0|0);
 if (!($36)) {
  $37 = (($hint_masks) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$hint_masks>>2]|0;
  $40 = (($table) + 32|0);
  HEAP32[$40>>2] = $hint_masks;
  $41 = ($39|0)==(0);
  if (!($41)) {
   $count$18 = $39;$mask$09 = $38;
   while(1) {
    $mask$0$idx$val = HEAP32[$mask$09>>2]|0;
    $42 = ($mask$0$idx$val|0)==(0);
    if (!($42)) {
     $mask$0$idx1 = (($mask$09) + 8|0);
     $mask$0$idx1$val = HEAP32[$mask$0$idx1>>2]|0;
     $cursor$03$i = $mask$0$idx1$val;$idx$04$i = 0;$mask$05$i = 0;$val$02$i = 0;
     while(1) {
      $43 = ($mask$05$i|0)==(0);
      if ($43) {
       $44 = (($cursor$03$i) + 1|0);
       $45 = HEAP8[$cursor$03$i>>0]|0;
       $46 = $45&255;
       $cursor$1$i = $44;$mask$1$i = 128;$val$1$i = $46;
      } else {
       $cursor$1$i = $cursor$03$i;$mask$1$i = $mask$05$i;$val$1$i = $val$02$i;
      }
      $47 = $mask$1$i & $val$1$i;
      $48 = ($47|0)==(0);
      if (!($48)) {
       $49 = HEAP32[$7>>2]|0;
       $50 = (($49) + (($idx$04$i*28)|0)|0);
       $51 = HEAP32[$table>>2]|0;
       $52 = ($51>>>0)>($idx$04$i>>>0);
       if ($52) {
        $53 = ((($49) + (($idx$04$i*28)|0)|0) + 16|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = $54 & 4;
        $56 = ($55|0)==(0);
        if ($56) {
         $57 = $54 | 4;
         HEAP32[$53>>2] = $57;
         $58 = HEAP32[$17>>2]|0;
         $59 = HEAP32[$18>>2]|0;
         $60 = ((($49) + (($idx$04$i*28)|0)|0) + 20|0);
         HEAP32[$60>>2] = 0;
         $61 = ($59|0)==(0);
         L30: do {
          if (!($61)) {
           $$idx$val$i$i = HEAP32[$50>>2]|0;
           $$idx1$i$i = ((($49) + (($idx$04$i*28)|0)|0) + 4|0);
           $$idx1$val$i$i = HEAP32[$$idx1$i$i>>2]|0;
           $62 = (($$idx1$val$i$i) + ($$idx$val$i$i))|0;
           $count$02$i$i = $59;$sorted$03$i$i = $58;
           while(1) {
            $63 = HEAP32[$sorted$03$i$i>>2]|0;
            $64 = HEAP32[$63>>2]|0;
            $65 = ($62|0)<($64|0);
            if (!($65)) {
             $66 = (($63) + 4|0);
             $67 = HEAP32[$66>>2]|0;
             $68 = (($67) + ($64))|0;
             $69 = ($68|0)<($$idx$val$i$i|0);
             if (!($69)) {
              break;
             }
            }
            $70 = (($count$02$i$i) + -1)|0;
            $71 = (($sorted$03$i$i) + 4|0);
            $72 = ($70|0)==(0);
            if ($72) {
             break L30;
            } else {
             $count$02$i$i = $70;$sorted$03$i$i = $71;
            }
           }
           HEAP32[$60>>2] = $63;
          }
         } while(0);
         $73 = HEAP32[$table>>2]|0;
         $74 = ($59>>>0)<($73>>>0);
         if ($74) {
          $75 = (($59) + 1)|0;
          HEAP32[$18>>2] = $75;
          $76 = HEAP32[$17>>2]|0;
          $77 = (($76) + ($59<<2)|0);
          HEAP32[$77>>2] = $50;
         }
        }
       }
      }
      $78 = $mask$1$i >> 1;
      $79 = (($idx$04$i) + 1)|0;
      $exitcond$i = ($79|0)==($mask$0$idx$val|0);
      if ($exitcond$i) {
       break;
      } else {
       $cursor$03$i = $cursor$1$i;$idx$04$i = $79;$mask$05$i = $78;$val$02$i = $val$1$i;
      }
     }
    }
    $80 = (($count$18) + -1)|0;
    $81 = (($mask$09) + 16|0);
    $82 = ($80|0)==(0);
    if ($82) {
     break;
    } else {
     $count$18 = $80;$mask$09 = $81;
    }
   }
  }
 }
 $83 = HEAP32[$18>>2]|0;
 $84 = HEAP32[$table>>2]|0;
 $85 = ($83|0)==($84|0);
 $86 = ($84|0)==(0);
 $or$cond = $85 | $86;
 if ($or$cond) {
  $117 = HEAP32[$error>>2]|0;
  STACKTOP = sp;return ($117|0);
 } else {
  $90 = $84;$idx$04 = 0;
 }
 while(1) {
  $87 = HEAP32[$7>>2]|0;
  $88 = (($87) + (($idx$04*28)|0)|0);
  $89 = ($90>>>0)>($idx$04>>>0);
  if ($89) {
   $91 = ((($87) + (($idx$04*28)|0)|0) + 16|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = $92 & 4;
   $94 = ($93|0)==(0);
   if ($94) {
    $95 = $92 | 4;
    HEAP32[$91>>2] = $95;
    $96 = HEAP32[$17>>2]|0;
    $97 = HEAP32[$18>>2]|0;
    $98 = ((($87) + (($idx$04*28)|0)|0) + 20|0);
    HEAP32[$98>>2] = 0;
    $99 = ($97|0)==(0);
    L50: do {
     if (!($99)) {
      $$idx$val$i = HEAP32[$88>>2]|0;
      $$idx1$i = ((($87) + (($idx$04*28)|0)|0) + 4|0);
      $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
      $100 = (($$idx1$val$i) + ($$idx$val$i))|0;
      $count$02$i = $97;$sorted$03$i = $96;
      while(1) {
       $101 = HEAP32[$sorted$03$i>>2]|0;
       $102 = HEAP32[$101>>2]|0;
       $103 = ($100|0)<($102|0);
       if (!($103)) {
        $104 = (($101) + 4|0);
        $105 = HEAP32[$104>>2]|0;
        $106 = (($105) + ($102))|0;
        $107 = ($106|0)<($$idx$val$i|0);
        if (!($107)) {
         break;
        }
       }
       $108 = (($count$02$i) + -1)|0;
       $109 = (($sorted$03$i) + 4|0);
       $110 = ($108|0)==(0);
       if ($110) {
        break L50;
       } else {
        $count$02$i = $108;$sorted$03$i = $109;
       }
      }
      HEAP32[$98>>2] = $101;
     }
    } while(0);
    $111 = HEAP32[$table>>2]|0;
    $112 = ($97>>>0)<($111>>>0);
    if ($112) {
     $113 = (($97) + 1)|0;
     HEAP32[$18>>2] = $113;
     $114 = HEAP32[$17>>2]|0;
     $115 = (($114) + ($97<<2)|0);
     HEAP32[$115>>2] = $88;
     $118 = $111;
    } else {
     $118 = $111;
    }
   } else {
    $118 = $90;
   }
  } else {
   $118 = $90;
  }
  $116 = (($idx$04) + 1)|0;
  $exitcond = ($116|0)==($84|0);
  if ($exitcond) {
   break;
  } else {
   $90 = $118;$idx$04 = $116;
  }
 }
 $117 = HEAP32[$error>>2]|0;
 STACKTOP = sp;return ($117|0);
}
function _FT_Init_Class_pshinter_interface($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 3441;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 3442;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 3443;
 STACKTOP = sp;return;
}
function _pshinter_get_globals_funcs($module) {
 $module = $module|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($module) + 108|0);
 STACKTOP = sp;return ($0|0);
}
function _pshinter_get_t1_funcs($module) {
 $module = $module|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($module) + 120|0);
 STACKTOP = sp;return ($0|0);
}
function _pshinter_get_t2_funcs($module) {
 $module = $module|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($module) + 148|0);
 STACKTOP = sp;return ($0|0);
}
function _FT_Destroy_Class_pshinter_module_class($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 _pshinter_module_class_pic_free($library);
 $1 = ($clazz|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$clazz);
 STACKTOP = sp;return;
}
function _FT_Create_Class_pshinter_module_class($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,36,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_pshinter_module_class_pic_init($library)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if ($5) {
  HEAP32[$1>>2] = 0;
  $7 = (($1) + 4|0);
  HEAP32[$7>>2] = 176;
  $8 = (($1) + 8|0);
  HEAP32[$8>>2] = 873704;
  $9 = (($1) + 12|0);
  HEAP32[$9>>2] = 65536;
  $10 = (($1) + 16|0);
  HEAP32[$10>>2] = 131072;
  $11 = (($library) + 200|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($1) + 20|0);
  HEAP32[$13>>2] = $12;
  $14 = (($1) + 24|0);
  HEAP32[$14>>2] = 3444;
  $15 = (($1) + 28|0);
  HEAP32[$15>>2] = 3753;
  $16 = (($1) + 32|0);
  HEAP32[$16>>2] = 0;
  HEAP32[$output_class>>2] = $1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  _ft_mem_free($0,$1);
  $6 = HEAP32[$error>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _ps_hinter_init($module) {
 $module = $module|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($module) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($module) + 20|0);
 (_ps_hints_init($2,$1)|0);
 $3 = (($module) + 108|0);
 _psh_globals_funcs_init($3);
 $4 = (($module) + 120|0);
 _t1_hints_funcs_init($4);
 HEAP32[$4>>2] = $2;
 $5 = (($module) + 148|0);
 _t2_hints_funcs_init($5);
 HEAP32[$5>>2] = $2;
 STACKTOP = sp;return 0;
}
function _ps_hinter_done($module) {
 $module = $module|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($module) + 120|0);
 HEAP32[$0>>2] = 0;
 $1 = (($module) + 148|0);
 HEAP32[$1>>2] = 0;
 $2 = (($module) + 20|0);
 _ps_hints_done($2);
 STACKTOP = sp;return;
}
function _pshinter_module_class_pic_free($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($library) + 208|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$library>>2]|0;
 _ft_mem_free($3,$1);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function _pshinter_module_class_pic_init($library) {
 $library = $library|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,12,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
 $4 = (($library) + 208|0);
 HEAP32[$4>>2] = $1;
 _FT_Init_Class_pshinter_interface($library,$1);
 $5 = HEAP32[$error>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = HEAP32[$4>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = HEAP32[$library>>2]|0;
 _ft_mem_free($9,$7);
 HEAP32[$4>>2] = 0;
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _Render_Glyph($worker) {
 $worker = $worker|0;
 var $$ = 0, $$0 = 0, $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 144|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 256;
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$worker>>2] = 6;
  $6 = (($worker) + 16|0);
  HEAP32[$6>>2] = 32;
  $7 = (($worker) + 20|0);
  HEAP32[$7>>2] = 2;
  $9 = 6;
 } else {
  HEAP32[$worker>>2] = 12;
  $4 = (($worker) + 16|0);
  HEAP32[$4>>2] = 256;
  $5 = (($worker) + 20|0);
  HEAP32[$5>>2] = 30;
  $9 = 12;
 }
 $8 = 1 << $9;
 $10 = (($worker) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (($8|0) / 2)&-1;
 $12 = (($worker) + 8|0);
 HEAP32[$12>>2] = $11;
 $13 = (($9) + -6)|0;
 $14 = (($worker) + 12|0);
 HEAP32[$14>>2] = $13;
 $15 = (($worker) + 24|0);
 HEAP32[$15>>2] = $13;
 $16 = $1 & 8;
 $17 = ($16|0)==(0);
 if ($17) {
  $19 = $1 & 16;
  $20 = ($19|0)==(0);
  $21 = (($worker) + 180|0);
  $$ = $20 ? 0 : 4;
  HEAP8[$21>>0] = $$;
  $22 = $1 & 32;
  $23 = ($22|0)==(0);
  if ($23) {
   $24 = $$&255;
   $25 = $24 | 1;
   $26 = $25&255;
   HEAP8[$21>>0] = $26;
  }
 } else {
  $18 = (($worker) + 180|0);
  HEAP8[$18>>0] = 2;
 }
 $27 = $1 >>> 9;
 $$lobit = $27 & 1;
 $28 = $$lobit ^ 1;
 $29 = $28&255;
 $30 = (($worker) + 181|0);
 HEAP8[$30>>0] = $29;
 $31 = (($worker) + 164|0);
 HEAP32[$31>>2] = 2071;
 $32 = (($worker) + 168|0);
 HEAP32[$32>>2] = 135;
 $33 = (($worker) + 172|0);
 HEAP32[$33>>2] = 136;
 $34 = (($worker) + 176|0);
 HEAP32[$34>>2] = 3754;
 $35 = (($worker) + 1024|0);
 HEAP32[$35>>2] = 0;
 $36 = (($worker) + 960|0);
 HEAP16[$36>>1] = 0;
 $37 = (($worker) + 104|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (($38) + 65535)|0;
 $40 = $39&65535;
 $41 = (($worker) + 962|0);
 HEAP16[$41>>1] = $40;
 $42 = (($worker) + 108|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43&65535;
 $45 = (($worker) + 56|0);
 HEAP16[$45>>1] = $44;
 $46 = (($worker) + 116|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($worker) + 60|0);
 HEAP32[$48>>2] = $47;
 $49 = (_Render_Single_Pass($worker,0)|0);
 $50 = ($49|0)==(0);
 if (!($50)) {
  $$0 = $49;
  STACKTOP = sp;return ($$0|0);
 }
 $51 = HEAP8[$30>>0]|0;
 $52 = ($51<<24>>24)==(0);
 if (!($52)) {
  $53 = (($worker) + 180|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = ($54<<24>>24)==(2);
  if (!($55)) {
   HEAP32[$31>>2] = 2072;
   HEAP32[$32>>2] = 137;
   HEAP32[$33>>2] = 138;
   HEAP32[$34>>2] = 3755;
   HEAP32[$35>>2] = 0;
   HEAP16[$36>>1] = 0;
   $56 = HEAP32[$42>>2]|0;
   $57 = (($56) + 65535)|0;
   $58 = $57&65535;
   HEAP16[$41>>1] = $58;
   $59 = (_Render_Single_Pass($worker,1)|0);
   $60 = ($59|0)==(0);
   if (!($60)) {
    $$0 = $59;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _Vertical_Sweep_Init($worker,$min,$max) {
 $worker = $worker|0;
 $min = $min|0;
 $max = $max|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (0 - ($1))|0;
 $3 = $2&65535;
 $4 = (($worker) + 156|0);
 HEAP16[$4>>1] = $3;
 $5 = HEAP16[$min>>1]|0;
 $6 = $5 << 16 >> 16;
 $7 = Math_imul($6, $2)|0;
 $8 = (($worker) + 148|0);
 HEAP32[$8>>2] = $7;
 $9 = ($1|0)>(0);
 if ($9) {
  $10 = (($worker) + 104|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $6 ^ -1;
  $13 = (($11) + ($12))|0;
  $14 = Math_imul($13, $1)|0;
  HEAP32[$8>>2] = $14;
 }
 $15 = (($worker) + 158|0);
 HEAP16[$15>>1] = 0;
 $16 = (($worker) + 160|0);
 HEAP16[$16>>1] = 0;
 STACKTOP = sp;return;
}
function _Vertical_Sweep_Span($worker,$y,$x1,$x2,$left,$right) {
 $worker = $worker|0;
 $y = $y|0;
 $x1 = $x1|0;
 $x2 = $x2|0;
 $left = $left|0;
 $right = $right|0;
 var $$ = 0, $$lcssa = 0, $$sum = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $c2$01 = 0, $e2$0 = 0, $e2$1 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (0 - ($1))|0;
 $3 = (($x1) + -1)|0;
 $4 = (($3) + ($1))|0;
 $5 = $4 & $2;
 $6 = HEAP32[$worker>>2]|0;
 $7 = $5 >> $6;
 $8 = (($x2) - ($x1))|0;
 $9 = (($8) - ($1))|0;
 $10 = (($worker) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)>($11|0);
 if ($12) {
  $13 = $2 & $x2;
  $14 = $13 >> $6;
  $e2$0 = $14;
 } else {
  $e2$0 = $7;
 }
 $15 = ($e2$0|0)>(-1);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = (($worker) + 56|0);
 $17 = HEAP16[$16>>1]|0;
 $18 = $17&65535;
 $19 = ($7|0)<($18|0);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = ($7|0)<(0);
 $$ = $20 ? 0 : $7;
 $21 = ($e2$0|0)<($18|0);
 $22 = (($18) + -1)|0;
 $e2$1 = $21 ? $e2$0 : $22;
 $23 = $$ << 13;
 $24 = $23 >> 16;
 $25 = $e2$1 << 13;
 $26 = $25 >> 16;
 $27 = $$ & 7;
 $28 = 255 >>> $27;
 $29 = $e2$1 & 7;
 $30 = 127 >>> $29;
 $31 = $30 ^ 255;
 $32 = (($worker) + 158|0);
 $33 = HEAP16[$32>>1]|0;
 $34 = $33 << 16 >> 16;
 $35 = ($34|0)>($24|0);
 if ($35) {
  $36 = $24&65535;
  HEAP16[$32>>1] = $36;
 }
 $37 = (($worker) + 160|0);
 $38 = HEAP16[$37>>1]|0;
 $39 = $38 << 16 >> 16;
 $40 = ($39|0)<($26|0);
 if ($40) {
  $41 = $26&65535;
  HEAP16[$37>>1] = $41;
 }
 $42 = (($worker) + 60|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($worker) + 148|0);
 $45 = HEAP32[$44>>2]|0;
 $$sum = (($45) + ($24))|0;
 $46 = (($43) + ($$sum)|0);
 $47 = (($26) - ($24))|0;
 $48 = ($47|0)>(0);
 if (!($48)) {
  $62 = $31 & $28;
  $63 = HEAP8[$46>>0]|0;
  $64 = $63&255;
  $65 = $64 | $62;
  $66 = $65&255;
  HEAP8[$46>>0] = $66;
  STACKTOP = sp;return;
 }
 $49 = HEAP8[$46>>0]|0;
 $50 = $49&255;
 $51 = $50 | $28;
 $52 = $51&255;
 HEAP8[$46>>0] = $52;
 $c2$01 = (($47) + -1)|0;
 $53 = ($c2$01|0)>(0);
 $$sum3 = (($$sum) + 1)|0;
 $54 = (($43) + ($$sum3)|0);
 if ($53) {
  $55 = (($45) + ($26))|0;
  $56 = (($26) + -1)|0;
  $57 = (($56) - ($24))|0;
  _memset(($54|0),-1,($57|0))|0;
  $scevgep = (($43) + ($55)|0);
  $$lcssa = $scevgep;
 } else {
  $$lcssa = $54;
 }
 $58 = HEAP8[$$lcssa>>0]|0;
 $59 = $58&255;
 $60 = $59 | $31;
 $61 = $60&255;
 HEAP8[$$lcssa>>0] = $61;
 STACKTOP = sp;return;
}
function _Vertical_Sweep_Drop($worker,$y,$x1,$x2,$left,$right) {
 $worker = $worker|0;
 $y = $y|0;
 $x1 = $x1|0;
 $x2 = $x2|0;
 $left = $left|0;
 $right = $right|0;
 var $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $pxl$0 = 0, $pxl$0$ = 0, $pxl$1 = 0, $pxl$2 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($x1) + -1)|0;
 $3 = (($2) + ($1))|0;
 $4 = (0 - ($1))|0;
 $5 = $3 & $4;
 $6 = $4 & $x2;
 $7 = ($5|0)>($6|0);
 if ($7) {
  $8 = (($left) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 7;
  $11 = (($6) + ($1))|0;
  $12 = ($5|0)==($11|0);
  if (!($12)) {
   STACKTOP = sp;return;
  }
  if ((($10|0) == 4)) {
   $13 = (($2) + ($x2))|0;
   $14 = (($13|0) / 2)&-1;
   $15 = (($worker) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($14))|0;
   $18 = $17 & $4;
   $pxl$0 = $18;
  } else if ((($10|0) == 0)) {
   $pxl$0 = $6;
  } else if ((($10|0) == 5) | (($10|0) == 1)) {
   $19 = (($left) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==($right|0);
   if ($21) {
    $22 = (($left) + 16|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)<(1);
    if ($24) {
     $25 = $9 & 16;
     $26 = ($25|0)==(0);
     if ($26) {
      STACKTOP = sp;return;
     }
     $27 = (($x2) - ($x1))|0;
     $28 = (($worker) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27|0)<($29|0);
     if ($30) {
      STACKTOP = sp;return;
     }
    }
   }
   $31 = (($right) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==($left|0);
   if ($33) {
    $34 = (($left) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $y << 16 >> 16;
    $37 = ($35|0)==($36|0);
    if ($37) {
     $38 = $9 & 32;
     $39 = ($38|0)==(0);
     if ($39) {
      STACKTOP = sp;return;
     }
     $40 = (($x2) - ($x1))|0;
     $41 = (($worker) + 8|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($40|0)<($42|0);
     if ($43) {
      STACKTOP = sp;return;
     }
    }
   }
   $44 = ($10|0)==(1);
   if ($44) {
    $pxl$0 = $6;
   } else {
    $45 = (($2) + ($x2))|0;
    $46 = (($45|0) / 2)&-1;
    $47 = (($worker) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + ($46))|0;
    $50 = $49 & $4;
    $pxl$0 = $50;
   }
  } else {
   STACKTOP = sp;return;
  }
  $51 = ($pxl$0|0)<(0);
  $$pre = HEAP32[$worker>>2]|0;
  if ($51) {
   $pxl$1 = $5;
  } else {
   $52 = $pxl$0 >> $$pre;
   $53 = (($worker) + 56|0);
   $54 = HEAP16[$53>>1]|0;
   $55 = $54&65535;
   $56 = ($52|0)<($55|0);
   $pxl$0$ = $56 ? $pxl$0 : $6;
   $pxl$1 = $pxl$0$;
  }
  $57 = ($pxl$1|0)==($5|0);
  $58 = $57 ? $6 : $5;
  $59 = $58 >> $$pre;
  $60 = $59 & 7;
  $61 = ($59|0)>(-1);
  if ($61) {
   $62 = (($worker) + 56|0);
   $63 = HEAP16[$62>>1]|0;
   $64 = $63&65535;
   $65 = ($59|0)<($64|0);
   if ($65) {
    $66 = (($worker) + 148|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = $59 << 13;
    $69 = $68 >> 16;
    $70 = (($67) + ($69))|0;
    $71 = (($worker) + 60|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (($72) + ($70)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74&255;
    $76 = 128 >>> $60;
    $77 = $75 & $76;
    $78 = ($77|0)==(0);
    if ($78) {
     $80 = $$pre;$pxl$2 = $pxl$1;
    } else {
     STACKTOP = sp;return;
    }
   } else {
    $80 = $$pre;$pxl$2 = $pxl$1;
   }
  } else {
   $80 = $$pre;$pxl$2 = $pxl$1;
  }
 } else {
  $$pre6 = HEAP32[$worker>>2]|0;
  $80 = $$pre6;$pxl$2 = $5;
 }
 $79 = $pxl$2 >> $80;
 $81 = ($79|0)>(-1);
 if (!($81)) {
  STACKTOP = sp;return;
 }
 $82 = (($worker) + 56|0);
 $83 = HEAP16[$82>>1]|0;
 $84 = $83&65535;
 $85 = ($79|0)<($84|0);
 if (!($85)) {
  STACKTOP = sp;return;
 }
 $86 = $79 >>> 3;
 $87 = $86&65535;
 $88 = $79 & 7;
 $89 = (($worker) + 158|0);
 $90 = HEAP16[$89>>1]|0;
 $91 = $90 << 16 >> 16;
 $sext = $86 << 16;
 $92 = $sext >> 16;
 $93 = ($91|0)>($92|0);
 if ($93) {
  HEAP16[$89>>1] = $87;
 }
 $94 = (($worker) + 160|0);
 $95 = HEAP16[$94>>1]|0;
 $96 = $95 << 16 >> 16;
 $97 = ($96|0)<($92|0);
 if ($97) {
  HEAP16[$94>>1] = $87;
 }
 $98 = 128 >>> $88;
 $99 = (($worker) + 148|0);
 $100 = HEAP32[$99>>2]|0;
 $101 = (($100) + ($92))|0;
 $102 = (($worker) + 60|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = (($103) + ($101)|0);
 $105 = HEAP8[$104>>0]|0;
 $106 = $105&255;
 $107 = $106 | $98;
 $108 = $107&255;
 HEAP8[$104>>0] = $108;
 STACKTOP = sp;return;
}
function _Vertical_Sweep_Step($worker) {
 $worker = $worker|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 156|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 << 16 >> 16;
 $3 = (($worker) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($2))|0;
 HEAP32[$3>>2] = $5;
 STACKTOP = sp;return;
}
function _Render_Single_Pass($worker,$flipped) {
 $worker = $worker|0;
 $flipped = $flipped|0;
 var $$$i = 0, $$$i$i = 0, $$0 = 0, $$016$i$i$i = 0, $$016$i5$i$i = 0, $$10$lcssa29$i$i = 0, $$11$lcssa31$i$i = 0, $$12$i$i = 0, $$13$i$i = 0, $$14$i$i = 0, $$15$i$i = 0, $$15$i$i$i = 0, $$15$i9$i$i = 0, $$16$i$i = 0, $$17$i$i = 0, $$3$i$i = 0, $$4$i = 0, $$4$i$i = 0, $$5$i$i = 0, $$6$i$i = 0;
 var $$7$i$i = 0, $$8$i$i = 0, $$9$i$i = 0, $$c$i = 0, $$c$i$i = 0, $$in9 = 0, $$lcssa105$i = 0, $$lcssa25$i$i = 0, $$lcssa27$i$i = 0, $$phi$trans$insert$i$i = 0, $$pr = 0, $$pr$pre$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i1$i = 0, $$pre$i4$i = 0, $$pre133 = 0, $$pre134 = 0, $$pre147$i = 0;
 var $$sum$i$i = 0, $$sum2$i$i = 0, $$sum2$i$i$i = 0, $$sum2$i6$i$i = 0, $$sum3$i$i$i = 0, $$sum3$i3$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0;
 var $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0;
 var $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0;
 var $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0;
 var $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0;
 var $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0;
 var $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0;
 var $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0;
 var $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0;
 var $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0;
 var $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0;
 var $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0;
 var $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0;
 var $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0;
 var $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0;
 var $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0;
 var $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P$0123$i = 0, $P$2112$i = 0, $P$398$i = 0, $P$494$i = 0, $bottom$0$i$i = 0, $current$0$i$i = 0, $current$0$i11$i = 0, $current$0$i14$i = 0, $current$0$i31$i = 0;
 var $current$0$i34$i = 0, $current$0$i38$i = 0, $current$0$i57$i = 0, $current$0$i75$i = 0, $current$0$i83$i = 0, $current$0$i9$i = 0, $current$0$in$lcssa$i$i = 0, $current$0$in$lcssa$i80$i = 0, $current$0$in$lcssa$i88$i = 0, $current$0$in2$i$i = 0, $current$0$in2$i77$i = 0, $current$0$in2$i85$i = 0, $current$0$lcssa$i$i = 0, $current$0$lcssa$i79$i = 0, $current$0$lcssa$i87$i = 0, $current$03$i$i = 0, $current$03$i76$i = 0, $current$03$i84$i = 0, $current$08$i$i = 0, $current$08$i13$i = 0;
 var $current$08$i37$i = 0, $current$08$i56$i = 0, $current$1$be$i$i = 0, $current$1$be$i26$i = 0, $current$1$be$i50$i = 0, $current$1$be$i69$i = 0, $current$14$i$i = 0, $current$14$i22$i = 0, $current$14$i46$i = 0, $current$14$i65$i = 0, $draw_left$i = 0, $draw_right$i = 0, $dropouts$0101$i = 0, $dropouts$1$i = 0, $i$063$i = 0, $limit$0$i$i = 0, $limit$1$i$i = 0, $max_Y$i = 0, $min_Y$i = 0, $n$0$i$i$i = 0;
 var $n$0$i2$i$i = 0, $n$0$in$i$i$i = 0, $n$0$in$i1$i$i = 0, $n$022$i$i = 0, $n$17$i$i$i = 0, $n$17$i4$i$i = 0, $next$0$i$i = 0, $next$0$i28$i = 0, $next$0$i52$i = 0, $next$0$i71$i = 0, $next$0$in$i$i = 0, $next$0$in$i27$i = 0, $next$0$in$i51$i = 0, $next$0$in$i70$i = 0, $next$0$in1$i$i = 0, $next$0$in1$i17$i = 0, $next$0$in1$i41$i = 0, $next$0$in1$i60$i = 0, $next$0$in5$i$i = 0, $next$0$in5$i21$i = 0;
 var $next$0$in5$i45$i = 0, $next$0$in5$i64$i = 0, $next$02$i$i = 0, $next$02$i18$i = 0, $next$02$i42$i = 0, $next$02$i61$i = 0, $next$06$i$i = 0, $next$06$i20$i = 0, $next$06$i44$i = 0, $next$06$i63$i = 0, $not$$i = 0, $o$0$in$i = 0, $old$0$be$i$i = 0, $old$0$be$i25$i = 0, $old$0$be$i49$i = 0, $old$0$be$i68$i = 0, $old$0$i$i = 0, $old$0$i33$i = 0, $old$0$i8$i = 0, $old$03$i$i = 0;
 var $old$03$i23$i = 0, $old$03$i47$i = 0, $old$03$i66$i = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond5$i = 0, $or$cond7$i = 0, $p$023$i$i = 0, $phitmp$i = 0, $phitmp148$i = 0, $phitmp9$i = 0, $point$0$i$i = 0, $point$1$be$i$i = 0, $point$137$i$i = 0, $point$2$i$i = 0, $point$2$us$i$i = 0, $sext = 0, $sext$i = 0, $sext2$i = 0, $sext3$i = 0;
 var $start$064$i = 0, $storemerge = 0, $tags$0$i$i = 0, $tags$1$be$i$i = 0, $tags$136$i$i = 0, $tags$2$i$i = 0, $tags$2$us$i$i = 0, $top$0$i$i = 0, $v_control$sroa$0$0$i$i = 0, $v_control$sroa$0$0$lcssa$i$i = 0, $v_control$sroa$0$0$lcssa20$i$i = 0, $v_control$sroa$0$0$us$i$i = 0, $v_control$sroa$1$0$i$i = 0, $v_control$sroa$1$0$lcssa$i$i = 0, $v_control$sroa$1$0$lcssa23$i$i = 0, $v_control$sroa$1$0$us$i$i = 0, $v_start$sroa$0$1$i$i = 0, $v_start$sroa$0$2$i$i = 0, $v_start$sroa$1$1$i$i = 0, $v_start$sroa$1$2$i$i = 0;
 var $waiting$i = 0, $y$0$i$lcssa = 0, $y$0$i64 = 0, $y$1$lcssa$i = 0, $y$1106$i = 0, $y$2118$i = 0, $y_height$0$i63 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $min_Y$i = sp + 14|0;
 $max_Y$i = sp + 12|0;
 $waiting$i = sp + 4|0;
 $draw_left$i = sp;
 $draw_right$i = sp + 8|0;
 $0 = (($worker) + 1024|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(-1);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($worker) + 4|0);
 $4 = (($worker) + 80|0);
 $5 = (($worker) + 76|0);
 $6 = (($worker) + 28|0);
 $7 = (($worker) + 40|0);
 $8 = (($worker) + 44|0);
 $9 = (($worker) + 92|0);
 $10 = (($worker) + 87|0);
 $11 = (($worker) + 86|0);
 $12 = (($worker) + 32|0);
 $13 = (($worker) + 36|0);
 $14 = (($worker) + 48|0);
 $15 = (($worker) + 88|0);
 $16 = (($worker) + 84|0);
 $17 = (($worker) + 128|0);
 $18 = (($worker) + 100|0);
 $19 = (($worker) + 96|0);
 $20 = (($worker) + 140|0);
 $21 = (($worker) + 132|0);
 $22 = (($worker) + 24|0);
 $23 = (($worker) + 8|0);
 $24 = ($flipped<<24>>24)!=(0);
 $25 = (($worker) + 136|0);
 $26 = (($worker) + 68|0);
 $27 = (($worker) + 72|0);
 $28 = (($worker) + 180|0);
 $29 = (($worker) + 164|0);
 $30 = (($worker) + 176|0);
 $31 = (($worker) + 172|0);
 $32 = (($worker) + 168|0);
 $34 = $1;
 L4: while(1) {
  $33 = ((($worker) + ($34<<2)|0) + 962|0);
  $35 = HEAP16[$33>>1]|0;
  $36 = $35 << 16 >> 16;
  $37 = HEAP32[$3>>2]|0;
  $38 = Math_imul($36, $37)|0;
  HEAP32[$4>>2] = $38;
  $39 = ((($worker) + ($34<<2)|0) + 960|0);
  $40 = HEAP16[$39>>1]|0;
  $41 = $40 << 16 >> 16;
  $42 = Math_imul($41, $37)|0;
  HEAP32[$5>>2] = $42;
  $43 = HEAP32[$6>>2]|0;
  HEAP32[$7>>2] = $43;
  HEAP32[$8>>2] = 0;
  HEAP32[$9>>2] = 0;
  HEAP8[$10>>0] = 0;
  HEAP8[$11>>0] = 0;
  $44 = HEAP32[$12>>2]|0;
  $45 = (($44) + -32|0);
  HEAP32[$13>>2] = $45;
  HEAP32[$14>>2] = 0;
  HEAP32[$15>>2] = $43;
  $46 = (($43) + 8|0);
  $$c$i = $43;
  HEAP32[$46>>2] = $$c$i;
  HEAP16[$16>>1] = 0;
  $47 = HEAP16[$17>>1]|0;
  $48 = ($47<<16>>16)>(0);
  L6: do {
   if ($48) {
    $i$063$i = 0;$start$064$i = 0;
    while(1) {
     HEAP32[$18>>2] = 0;
     HEAP32[$19>>2] = 0;
     $49 = HEAP32[$20>>2]|0;
     $50 = (($49) + ($i$063$i<<1)|0);
     $51 = HEAP16[$50>>1]|0;
     $52 = HEAP32[$21>>2]|0;
     $53 = $51&65535;
     $54 = (($52) + ($53<<3)|0);
     $55 = (($52) + ($start$064$i<<3)|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = HEAP32[$22>>2]|0;
     $58 = $56 << $57;
     $59 = HEAP32[$23>>2]|0;
     $60 = (($58) - ($59))|0;
     $61 = ((($52) + ($start$064$i<<3)|0) + 4|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = $62 << $57;
     $64 = (($63) - ($59))|0;
     $65 = HEAP32[$54>>2]|0;
     $66 = $65 << $57;
     $67 = (($66) - ($59))|0;
     $68 = ((($52) + ($53<<3)|0) + 4|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = $69 << $57;
     $71 = (($70) - ($59))|0;
     $$$i$i = $24 ? $64 : $60;
     $$3$i$i = $24 ? $60 : $64;
     $$4$i$i = $24 ? $71 : $67;
     $$5$i$i = $24 ? $67 : $71;
     $72 = HEAP32[$25>>2]|0;
     $73 = (($72) + ($start$064$i)|0);
     $74 = HEAP8[$73>>0]|0;
     $75 = $74 & 4;
     $76 = ($75<<24>>24)==(0);
     if ($76) {
      $79 = $74;
     } else {
      $77 = ($74&255) >>> 5;
      HEAP8[$28>>0] = $77;
      $$pre$i$i = HEAP8[$73>>0]|0;
      $79 = $$pre$i$i;
     }
     $78 = $79&255;
     $80 = $78 & 3;
     if ((($80|0) == 0)) {
      $81 = (($72) + ($53)|0);
      $82 = HEAP8[$81>>0]|0;
      $83 = $82 & 3;
      $84 = ($83<<24>>24)==(1);
      if ($84) {
       $$sum2$i$i = (($53) + -1)|0;
       $85 = (($52) + ($$sum2$i$i<<3)|0);
       $limit$0$i$i = $85;$v_start$sroa$0$1$i$i = $$4$i$i;$v_start$sroa$1$1$i$i = $$5$i$i;
      } else {
       $86 = (($$4$i$i) + ($$$i$i))|0;
       $87 = (($86|0) / 2)&-1;
       $88 = (($$5$i$i) + ($$3$i$i))|0;
       $89 = (($88|0) / 2)&-1;
       $limit$0$i$i = $54;$v_start$sroa$0$1$i$i = $87;$v_start$sroa$1$1$i$i = $89;
      }
      $$sum$i$i = (($start$064$i) + -1)|0;
      $90 = (($52) + ($$sum$i$i<<3)|0);
      $91 = (($72) + ($$sum$i$i)|0);
      $limit$1$i$i = $limit$0$i$i;$point$0$i$i = $90;$tags$0$i$i = $91;$v_start$sroa$0$2$i$i = $v_start$sroa$0$1$i$i;$v_start$sroa$1$2$i$i = $v_start$sroa$1$1$i$i;
     } else if ((($80|0) == 2)) {
      label = 30;
      break L4;
     } else {
      $limit$1$i$i = $54;$point$0$i$i = $55;$tags$0$i$i = $73;$v_start$sroa$0$2$i$i = $$$i$i;$v_start$sroa$1$2$i$i = $$3$i$i;
     }
     HEAP32[$26>>2] = $v_start$sroa$0$2$i$i;
     HEAP32[$27>>2] = $v_start$sroa$1$2$i$i;
     $92 = ($point$0$i$i>>>0)<($limit$1$i$i>>>0);
     L19: do {
      if ($92) {
       $point$137$i$i = $point$0$i$i;$tags$136$i$i = $tags$0$i$i;
       L20: while(1) {
        $93 = (($point$137$i$i) + 8|0);
        $94 = (($tags$136$i$i) + 1|0);
        $95 = HEAP8[$94>>0]|0;
        $96 = $95&255;
        $97 = $96 & 3;
        if ((($97|0) == 0)) {
         $109 = HEAP32[$93>>2]|0;
         $110 = HEAP32[$22>>2]|0;
         $111 = $109 << $110;
         $112 = HEAP32[$23>>2]|0;
         $113 = (($111) - ($112))|0;
         $114 = (($point$137$i$i) + 12|0);
         $115 = HEAP32[$114>>2]|0;
         $116 = $115 << $110;
         $117 = (($116) - ($112))|0;
         $$8$i$i = $24 ? $117 : $113;
         $$9$i$i = $24 ? $113 : $117;
         L24: do {
          if ($24) {
           $point$2$us$i$i = $93;$tags$2$us$i$i = $94;$v_control$sroa$0$0$us$i$i = $$8$i$i;$v_control$sroa$1$0$us$i$i = $$9$i$i;
           while(1) {
            $118 = ($point$2$us$i$i>>>0)<($limit$1$i$i>>>0);
            if (!($118)) {
             $v_control$sroa$0$0$lcssa$i$i = $v_control$sroa$0$0$us$i$i;$v_control$sroa$1$0$lcssa$i$i = $v_control$sroa$1$0$us$i$i;
             label = 23;
             break L20;
            }
            $119 = (($point$2$us$i$i) + 8|0);
            $120 = (($tags$2$us$i$i) + 1|0);
            $121 = HEAP8[$120>>0]|0;
            $122 = $121&255;
            $123 = $122 & 3;
            $124 = HEAP32[$119>>2]|0;
            $125 = HEAP32[$22>>2]|0;
            $126 = $124 << $125;
            $127 = HEAP32[$23>>2]|0;
            $128 = (($126) - ($127))|0;
            $129 = (($point$2$us$i$i) + 12|0);
            $130 = HEAP32[$129>>2]|0;
            $131 = $130 << $125;
            $132 = (($131) - ($127))|0;
            if ((($123|0) == 1)) {
             $$10$lcssa29$i$i = $132;$$11$lcssa31$i$i = $128;$$lcssa25$i$i = $119;$$lcssa27$i$i = $120;$v_control$sroa$0$0$lcssa20$i$i = $v_control$sroa$0$0$us$i$i;$v_control$sroa$1$0$lcssa23$i$i = $v_control$sroa$1$0$us$i$i;
             break L24;
            } else if (!((($123|0) == 0))) {
             label = 30;
             break L4;
            }
            $133 = (($132) + ($v_control$sroa$0$0$us$i$i))|0;
            $134 = (($133|0) / 2)&-1;
            $135 = (($128) + ($v_control$sroa$1$0$us$i$i))|0;
            $136 = (($135|0) / 2)&-1;
            $137 = (_Conic_To($worker,$v_control$sroa$0$0$us$i$i,$v_control$sroa$1$0$us$i$i,$134,$136)|0);
            $138 = ($137<<24>>24)==(0);
            if ($138) {
             $point$2$us$i$i = $119;$tags$2$us$i$i = $120;$v_control$sroa$0$0$us$i$i = $132;$v_control$sroa$1$0$us$i$i = $128;
            } else {
             label = 83;
             break L6;
            }
           }
          } else {
           $point$2$i$i = $93;$tags$2$i$i = $94;$v_control$sroa$0$0$i$i = $$8$i$i;$v_control$sroa$1$0$i$i = $$9$i$i;
           while(1) {
            $139 = ($point$2$i$i>>>0)<($limit$1$i$i>>>0);
            if (!($139)) {
             $v_control$sroa$0$0$lcssa$i$i = $v_control$sroa$0$0$i$i;$v_control$sroa$1$0$lcssa$i$i = $v_control$sroa$1$0$i$i;
             label = 23;
             break L20;
            }
            $140 = (($point$2$i$i) + 8|0);
            $141 = (($tags$2$i$i) + 1|0);
            $142 = HEAP8[$141>>0]|0;
            $143 = $142&255;
            $144 = $143 & 3;
            $145 = HEAP32[$140>>2]|0;
            $146 = HEAP32[$22>>2]|0;
            $147 = $145 << $146;
            $148 = HEAP32[$23>>2]|0;
            $149 = (($147) - ($148))|0;
            $150 = (($point$2$i$i) + 12|0);
            $151 = HEAP32[$150>>2]|0;
            $152 = $151 << $146;
            $153 = (($152) - ($148))|0;
            if ((($144|0) == 1)) {
             $$10$lcssa29$i$i = $149;$$11$lcssa31$i$i = $153;$$lcssa25$i$i = $140;$$lcssa27$i$i = $141;$v_control$sroa$0$0$lcssa20$i$i = $v_control$sroa$0$0$i$i;$v_control$sroa$1$0$lcssa23$i$i = $v_control$sroa$1$0$i$i;
             break L24;
            } else if (!((($144|0) == 0))) {
             label = 30;
             break L4;
            }
            $157 = (($149) + ($v_control$sroa$0$0$i$i))|0;
            $158 = (($157|0) / 2)&-1;
            $159 = (($153) + ($v_control$sroa$1$0$i$i))|0;
            $160 = (($159|0) / 2)&-1;
            $161 = (_Conic_To($worker,$v_control$sroa$0$0$i$i,$v_control$sroa$1$0$i$i,$158,$160)|0);
            $162 = ($161<<24>>24)==(0);
            if ($162) {
             $point$2$i$i = $140;$tags$2$i$i = $141;$v_control$sroa$0$0$i$i = $149;$v_control$sroa$1$0$i$i = $153;
            } else {
             label = 83;
             break L6;
            }
           }
          }
         } while(0);
         $154 = (_Conic_To($worker,$v_control$sroa$0$0$lcssa20$i$i,$v_control$sroa$1$0$lcssa23$i$i,$$10$lcssa29$i$i,$$11$lcssa31$i$i)|0);
         $155 = ($154<<24>>24)==(0);
         if ($155) {
          $point$1$be$i$i = $$lcssa25$i$i;$tags$1$be$i$i = $$lcssa27$i$i;
         } else {
          label = 83;
          break L6;
         }
        } else if ((($97|0) == 1)) {
         $98 = HEAP32[$93>>2]|0;
         $99 = HEAP32[$22>>2]|0;
         $100 = $98 << $99;
         $101 = HEAP32[$23>>2]|0;
         $102 = (($100) - ($101))|0;
         $103 = (($point$137$i$i) + 12|0);
         $104 = HEAP32[$103>>2]|0;
         $105 = $104 << $99;
         $106 = (($105) - ($101))|0;
         $$6$i$i = $24 ? $106 : $102;
         $$7$i$i = $24 ? $102 : $106;
         $107 = (_Line_To($worker,$$6$i$i,$$7$i$i)|0);
         $108 = ($107<<24>>24)==(0);
         if ($108) {
          $point$1$be$i$i = $93;$tags$1$be$i$i = $94;
         } else {
          label = 83;
          break L6;
         }
        } else {
         $165 = (($point$137$i$i) + 16|0);
         $166 = ($165>>>0)>($limit$1$i$i>>>0);
         if ($166) {
          label = 30;
          break L4;
         }
         $167 = (($tags$136$i$i) + 2|0);
         $168 = HEAP8[$167>>0]|0;
         $169 = $168 & 3;
         $170 = ($169<<24>>24)==(2);
         if (!($170)) {
          label = 30;
          break L4;
         }
         $171 = (($point$137$i$i) + 24|0);
         $172 = (($point$137$i$i) + 8|0);
         $173 = HEAP32[$172>>2]|0;
         $174 = HEAP32[$22>>2]|0;
         $175 = $173 << $174;
         $176 = HEAP32[$23>>2]|0;
         $177 = (($175) - ($176))|0;
         $178 = (($point$137$i$i) + 12|0);
         $179 = HEAP32[$178>>2]|0;
         $180 = $179 << $174;
         $181 = (($180) - ($176))|0;
         $182 = (($point$137$i$i) + 16|0);
         $183 = HEAP32[$182>>2]|0;
         $184 = $183 << $174;
         $185 = (($184) - ($176))|0;
         $186 = (($point$137$i$i) + 20|0);
         $187 = HEAP32[$186>>2]|0;
         $188 = $187 << $174;
         $189 = (($188) - ($176))|0;
         $$12$i$i = $24 ? $181 : $177;
         $$13$i$i = $24 ? $177 : $181;
         $$14$i$i = $24 ? $189 : $185;
         $$15$i$i = $24 ? $185 : $189;
         $190 = ($171>>>0)>($limit$1$i$i>>>0);
         if ($190) {
          label = 28;
          break;
         }
         $191 = (($tags$136$i$i) + 3|0);
         $192 = HEAP32[$171>>2]|0;
         $193 = $192 << $174;
         $194 = (($193) - ($176))|0;
         $195 = (($point$137$i$i) + 28|0);
         $196 = HEAP32[$195>>2]|0;
         $197 = $196 << $174;
         $198 = (($197) - ($176))|0;
         $$16$i$i = $24 ? $198 : $194;
         $$17$i$i = $24 ? $194 : $198;
         $199 = (_Cubic_To($worker,$$12$i$i,$$13$i$i,$$14$i$i,$$15$i$i,$$16$i$i,$$17$i$i)|0);
         $200 = ($199<<24>>24)==(0);
         if ($200) {
          $point$1$be$i$i = $171;$tags$1$be$i$i = $191;
         } else {
          label = 83;
          break L6;
         }
        }
        $156 = ($point$1$be$i$i>>>0)<($limit$1$i$i>>>0);
        if ($156) {
         $point$137$i$i = $point$1$be$i$i;$tags$136$i$i = $tags$1$be$i$i;
        } else {
         label = 29;
         break L19;
        }
       }
       if ((label|0) == 23) {
        label = 0;
        $163 = (_Conic_To($worker,$v_control$sroa$0$0$lcssa$i$i,$v_control$sroa$1$0$lcssa$i$i,$v_start$sroa$0$2$i$i,$v_start$sroa$1$2$i$i)|0);
        $164 = ($163<<24>>24)==(0);
        if ($164) {
         break;
        } else {
         label = 83;
         break L6;
        }
       }
       else if ((label|0) == 28) {
        label = 0;
        $201 = (_Cubic_To($worker,$$12$i$i,$$13$i$i,$$14$i$i,$$15$i$i,$v_start$sroa$0$2$i$i,$v_start$sroa$1$2$i$i)|0);
        $202 = ($201<<24>>24)==(0);
        if ($202) {
         break;
        } else {
         label = 83;
         break L6;
        }
       }
      } else {
       label = 29;
      }
     } while(0);
     if ((label|0) == 29) {
      label = 0;
      $203 = (_Line_To($worker,$v_start$sroa$0$2$i$i,$v_start$sroa$1$2$i$i)|0);
      $204 = ($203<<24>>24)==(0);
      if (!($204)) {
       label = 83;
       break L6;
      }
     }
     $205 = HEAP32[$20>>2]|0;
     $206 = (($205) + ($i$063$i<<1)|0);
     $207 = HEAP16[$206>>1]|0;
     $208 = $207&65535;
     $209 = (($208) + 1)|0;
     $210 = HEAP32[$27>>2]|0;
     $211 = HEAP32[$3>>2]|0;
     $212 = (($211) + -1)|0;
     $213 = $212 & $210;
     $214 = ($213|0)==(0);
     if ($214) {
      $215 = HEAP32[$5>>2]|0;
      $216 = ($210|0)<($215|0);
      if (!($216)) {
       $217 = HEAP32[$4>>2]|0;
       $218 = ($210|0)>($217|0);
       if (!($218)) {
        $219 = HEAP32[$19>>2]|0;
        $220 = ($219|0)==(0|0);
        if (!($220)) {
         $221 = (($219) + 12|0);
         $222 = HEAP32[$221>>2]|0;
         $223 = HEAP32[$15>>2]|0;
         $224 = (($223) + 12|0);
         $225 = HEAP32[$224>>2]|0;
         $226 = $225 ^ $222;
         $227 = $226 & 8;
         $228 = ($227|0)==(0);
         if ($228) {
          $229 = HEAP32[$7>>2]|0;
          $230 = (($229) + -4|0);
          HEAP32[$7>>2] = $230;
         }
        }
       }
      }
     }
     $231 = HEAP32[$15>>2]|0;
     $232 = (($231) + 12|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = $233 & 8;
     $235 = ($234|0)==(0);
     if ($235) {
      $238 = (($210) + -1)|0;
      $239 = (($238) + ($211))|0;
      $240 = (0 - ($211))|0;
      $241 = $239 & $240;
      $242 = (($241) - ($210))|0;
      $243 = HEAP32[$23>>2]|0;
      $244 = ($242|0)>=($243|0);
      $o$0$in$i = $244;
     } else {
      $236 = HEAP32[$23>>2]|0;
      $237 = ($213|0)>=($236|0);
      $o$0$in$i = $237;
     }
     $245 = HEAP32[$7>>2]|0;
     $246 = (($231) + 8|0);
     $247 = HEAP32[$246>>2]|0;
     $248 = $245;
     $249 = $247;
     $250 = (($248) - ($249))|0;
     $251 = $250 >> 2;
     $252 = ($250|0)<(0);
     if ($252) {
      label = 41;
      break L4;
     }
     $253 = ($250|0)>(0);
     if ($253) {
      $254 = (($231) + 16|0);
      HEAP32[$254>>2] = $251;
      do {
       if ($o$0$in$i) {
        if ($235) {
         $256 = $233 | 32;
         HEAP32[$232>>2] = $256;
         break;
        } else {
         $255 = $233 | 16;
         HEAP32[$232>>2] = $255;
         break;
        }
       }
      } while(0);
      HEAP32[$15>>2] = $245;
      $257 = (($245) + 32|0);
      HEAP32[$7>>2] = $257;
      $258 = (($245) + 16|0);
      HEAP32[$258>>2] = 0;
      $259 = (($245) + 8|0);
      $$c$i$i = $257;
      HEAP32[$259>>2] = $$c$i$i;
      $260 = HEAP32[$15>>2]|0;
      $261 = (($231) + 28|0);
      HEAP32[$261>>2] = $260;
      $262 = HEAP16[$16>>1]|0;
      $263 = (($262) + 1)<<16>>16;
      HEAP16[$16>>1] = $263;
      $$pre$i1$i = HEAP32[$7>>2]|0;
      $266 = $$pre$i1$i;
     } else {
      $266 = $245;
     }
     $264 = HEAP32[$13>>2]|0;
     $265 = ($266>>>0)<($264>>>0);
     if (!($265)) {
      label = 49;
      break;
     }
     HEAP8[$10>>0] = 0;
     $267 = HEAP32[$19>>2]|0;
     $268 = ($267|0)==(0|0);
     if (!($268)) {
      $269 = (($231) + 28|0);
      HEAP32[$269>>2] = $267;
     }
     $270 = (($i$063$i) + 1)|0;
     $271 = HEAP16[$17>>1]|0;
     $272 = $271 << 16 >> 16;
     $273 = ($270|0)<($272|0);
     if (!($273)) {
      break;
     }
     $phitmp9$i = $209 & 65535;
     $i$063$i = $270;$start$064$i = $phitmp9$i;
    }
    if ((label|0) == 49) {
     label = 0;
     HEAP32[$8>>2] = 98;
     label = 84;
     break;
    }
    $$pre$i = HEAP16[$16>>1]|0;
    $274 = HEAP32[$9>>2]|0;
    $275 = ($$pre$i&65535)<(2);
    $276 = ($274|0)==(0|0);
    $or$cond$i$i = $275 | $276;
    if ($or$cond$i$i) {
     label = 81;
    } else {
     $277 = ($$pre$i<<16>>16)==(0);
     if ($277) {
      label = 82;
     } else {
      $n$022$i$i = $$pre$i;$p$023$i$i = $274;
      while(1) {
       $278 = ($n$022$i$i&65535)>(1);
       if ($278) {
        $279 = (($p$023$i$i) + 8|0);
        $280 = HEAP32[$279>>2]|0;
        $281 = (($p$023$i$i) + 16|0);
        $282 = HEAP32[$281>>2]|0;
        $283 = (($280) + ($282<<2)|0);
        $284 = (($p$023$i$i) + 4|0);
        HEAP32[$284>>2] = $283;
        $293 = $282;
       } else {
        $285 = (($p$023$i$i) + 4|0);
        HEAP32[$285>>2] = 0;
        $$phi$trans$insert$i$i = (($p$023$i$i) + 16|0);
        $$pre$i4$i = HEAP32[$$phi$trans$insert$i$i>>2]|0;
        $293 = $$pre$i4$i;
       }
       $286 = (($p$023$i$i) + 12|0);
       $287 = HEAP32[$286>>2]|0;
       $288 = $287 & 8;
       $289 = ($288|0)==(0);
       $290 = (($p$023$i$i) + 20|0);
       $291 = HEAP32[$290>>2]|0;
       if ($289) {
        $295 = (($291) - ($293))|0;
        $296 = (($295) + 1)|0;
        HEAP32[$290>>2] = $296;
        $297 = (($293) + -1)|0;
        $298 = (($p$023$i$i) + 8|0);
        $299 = HEAP32[$298>>2]|0;
        $300 = (($299) + ($297<<2)|0);
        HEAP32[$298>>2] = $300;
        $bottom$0$i$i = $296;$top$0$i$i = $291;
       } else {
        $292 = (($293) + -1)|0;
        $294 = (($292) + ($291))|0;
        $bottom$0$i$i = $291;$top$0$i$i = $294;
       }
       $301 = HEAP32[$14>>2]|0;
       $302 = HEAP32[$12>>2]|0;
       $n$0$in$i$i$i = $301;
       while(1) {
        $n$0$i$i$i = (($n$0$in$i$i$i) + -1)|0;
        $303 = ($n$0$in$i$i$i|0)>(0);
        if (!($303)) {
         $$15$i$i$i = $bottom$0$i$i;
         label = 68;
         break;
        }
        $$sum3$i$i$i = (($n$0$i$i$i) - ($301))|0;
        $304 = (($302) + ($$sum3$i$i$i<<2)|0);
        $305 = HEAP32[$304>>2]|0;
        $306 = ($305|0)>($bottom$0$i$i|0);
        if ($306) {
         $n$0$in$i$i$i = $n$0$i$i$i;
        } else {
         label = 65;
         break;
        }
       }
       do {
        if ((label|0) == 65) {
         label = 0;
         $307 = ($305|0)<($bottom$0$i$i|0);
         if ($307) {
          $$016$i$i$i = $bottom$0$i$i;$n$17$i$i$i = $n$0$i$i$i;
          while(1) {
           $$sum2$i$i$i = (($n$17$i$i$i) - ($301))|0;
           $308 = (($302) + ($$sum2$i$i$i<<2)|0);
           $309 = HEAP32[$308>>2]|0;
           HEAP32[$308>>2] = $$016$i$i$i;
           $310 = (($n$17$i$i$i) + -1)|0;
           $311 = ($n$17$i$i$i|0)>(0);
           if ($311) {
            $$016$i$i$i = $309;$n$17$i$i$i = $310;
           } else {
            $$15$i$i$i = $309;
            label = 68;
            break;
           }
          }
         } else {
          $312 = ($n$0$in$i$i$i|0)<(1);
          if ($312) {
           $$15$i$i$i = $bottom$0$i$i;
           label = 68;
           break;
          } else {
           $322 = $301;
           break;
          }
         }
        }
       } while(0);
       if ((label|0) == 68) {
        label = 0;
        $313 = HEAP32[$13>>2]|0;
        $314 = (($313) + -4|0);
        HEAP32[$13>>2] = $314;
        $315 = HEAP32[$7>>2]|0;
        $316 = ($314>>>0)>($315>>>0);
        if (!($316)) {
         label = 70;
         break;
        }
        $317 = (($301) + 1)|0;
        HEAP32[$14>>2] = $317;
        $318 = $301 ^ -1;
        $319 = (($302) + ($318<<2)|0);
        HEAP32[$319>>2] = $$15$i$i$i;
        $322 = $317;
       }
       $320 = (($top$0$i$i) + 1)|0;
       $n$0$in$i1$i$i = $322;
       while(1) {
        $n$0$i2$i$i = (($n$0$in$i1$i$i) + -1)|0;
        $321 = ($n$0$in$i1$i$i|0)>(0);
        if (!($321)) {
         $$15$i9$i$i = $320;
         label = 77;
         break;
        }
        $$sum3$i3$i$i = (($n$0$i2$i$i) - ($322))|0;
        $323 = (($302) + ($$sum3$i3$i$i<<2)|0);
        $324 = HEAP32[$323>>2]|0;
        $325 = ($324|0)>($320|0);
        if ($325) {
         $n$0$in$i1$i$i = $n$0$i2$i$i;
        } else {
         label = 74;
         break;
        }
       }
       do {
        if ((label|0) == 74) {
         label = 0;
         $326 = ($324|0)<($320|0);
         if ($326) {
          $$016$i5$i$i = $320;$n$17$i4$i$i = $n$0$i2$i$i;
          while(1) {
           $$sum2$i6$i$i = (($n$17$i4$i$i) - ($322))|0;
           $327 = (($302) + ($$sum2$i6$i$i<<2)|0);
           $328 = HEAP32[$327>>2]|0;
           HEAP32[$327>>2] = $$016$i5$i$i;
           $329 = (($n$17$i4$i$i) + -1)|0;
           $330 = ($n$17$i4$i$i|0)>(0);
           if ($330) {
            $$016$i5$i$i = $328;$n$17$i4$i$i = $329;
           } else {
            $$15$i9$i$i = $328;
            label = 77;
            break;
           }
          }
         } else {
          $331 = ($n$0$in$i1$i$i|0)<(1);
          if ($331) {
           $$15$i9$i$i = $320;
           label = 77;
           break;
          } else {
           break;
          }
         }
        }
       } while(0);
       if ((label|0) == 77) {
        label = 0;
        $332 = HEAP32[$13>>2]|0;
        $333 = (($332) + -4|0);
        HEAP32[$13>>2] = $333;
        $334 = HEAP32[$7>>2]|0;
        $335 = ($333>>>0)>($334>>>0);
        if (!($335)) {
         label = 79;
         break;
        }
        $336 = (($322) + 1)|0;
        HEAP32[$14>>2] = $336;
        $337 = $322 ^ -1;
        $338 = (($302) + ($337<<2)|0);
        HEAP32[$338>>2] = $$15$i9$i$i;
       }
       $339 = (($p$023$i$i) + 4|0);
       $340 = HEAP32[$339>>2]|0;
       $341 = (($n$022$i$i) + -1)<<16>>16;
       $342 = ($341<<16>>16)==(0);
       if ($342) {
        label = 82;
        break L6;
       } else {
        $n$022$i$i = $341;$p$023$i$i = $340;
       }
      }
      if ((label|0) == 70) {
       label = 0;
       HEAP32[$8>>2] = 98;
       label = 84;
       break;
      }
      else if ((label|0) == 79) {
       label = 0;
       HEAP32[$8>>2] = 98;
       label = 84;
       break;
      }
     }
    }
   } else {
    label = 81;
   }
  } while(0);
  if ((label|0) == 81) {
   label = 0;
   HEAP32[$9>>2] = 0;
   label = 82;
  }
  if ((label|0) == 82) {
   label = 0;
   $343 = HEAP32[$7>>2]|0;
   $344 = HEAP32[$13>>2]|0;
   $not$$i = ($343>>>0)<($344>>>0);
   if ($not$$i) {
    $370 = HEAP32[$9>>2]|0;
    $371 = ($370|0)==(0|0);
    if (!($371)) {
     HEAP32[$waiting$i>>2] = 0;
     HEAP32[$draw_left$i>>2] = 0;
     HEAP32[$draw_right$i>>2] = 0;
     $372 = HEAP32[$5>>2]|0;
     $373 = HEAP32[$worker>>2]|0;
     $374 = $372 >> $373;
     $375 = $374&65535;
     HEAP16[$max_Y$i>>1] = $375;
     $376 = HEAP32[$4>>2]|0;
     $377 = $376 >> $373;
     $378 = $377&65535;
     HEAP16[$min_Y$i>>1] = $378;
     $389 = $378;$394 = $375;$P$0123$i = $370;
     while(1) {
      $379 = (($P$0123$i) + 4|0);
      $380 = HEAP32[$379>>2]|0;
      $381 = (($P$0123$i) + 20|0);
      $382 = HEAP32[$381>>2]|0;
      $383 = (($P$0123$i) + 16|0);
      $384 = HEAP32[$383>>2]|0;
      $385 = (($382) + 65535)|0;
      $386 = (($385) + ($384))|0;
      $387 = $386&65535;
      $388 = $389 << 16 >> 16;
      $sext2$i = $382 << 16;
      $390 = $sext2$i >> 16;
      $391 = ($388|0)>($390|0);
      if ($391) {
       $392 = $382&65535;
       HEAP16[$min_Y$i>>1] = $392;
       $650 = $392;
      } else {
       $650 = $389;
      }
      $393 = $394 << 16 >> 16;
      $sext3$i = $386 << 16;
      $395 = $sext3$i >> 16;
      $396 = ($393|0)<($395|0);
      if ($396) {
       HEAP16[$max_Y$i>>1] = $387;
       $651 = $387;
      } else {
       $651 = $394;
      }
      HEAP32[$P$0123$i>>2] = 0;
      $397 = HEAP32[$waiting$i>>2]|0;
      $398 = ($397|0)==(0|0);
      L130: do {
       if ($398) {
        $current$0$in$lcssa$i$i = $waiting$i;$current$0$lcssa$i$i = 0;
       } else {
        $current$0$in2$i$i = $waiting$i;$current$03$i$i = $397;
        while(1) {
         $401 = HEAP32[$current$03$i$i>>2]|0;
         $402 = ($401|0)>(0);
         $399 = (($current$03$i$i) + 4|0);
         if ($402) {
          $current$0$in$lcssa$i$i = $current$0$in2$i$i;$current$0$lcssa$i$i = $current$03$i$i;
          break L130;
         }
         $current$0$i31$i = HEAP32[$399>>2]|0;
         $400 = ($current$0$i31$i|0)==(0|0);
         if ($400) {
          $current$0$in$lcssa$i$i = $399;$current$0$lcssa$i$i = 0;
          break;
         } else {
          $current$0$in2$i$i = $399;$current$03$i$i = $current$0$i31$i;
         }
        }
       }
      } while(0);
      HEAP32[$379>>2] = $current$0$lcssa$i$i;
      HEAP32[$current$0$in$lcssa$i$i>>2] = $P$0123$i;
      $403 = ($380|0)==(0|0);
      if ($403) {
       break;
      } else {
       $389 = $650;$394 = $651;$P$0123$i = $380;
      }
     }
     $404 = HEAP32[$14>>2]|0;
     $405 = ($404|0)==(0);
     if ($405) {
      label = 99;
      break;
     }
     $406 = HEAP32[$29>>2]|0;
     FUNCTION_TABLE_viii[$406 & 4095]($worker,$min_Y$i,$max_Y$i);
     $407 = HEAP32[$waiting$i>>2]|0;
     $408 = ($407|0)==(0|0);
     $$pre147$i = HEAP16[$min_Y$i>>1]|0;
     if (!($408)) {
      $409 = $$pre147$i&65535;
      $411 = $407;
      while(1) {
       $410 = (($411) + 20|0);
       $412 = HEAP32[$410>>2]|0;
       $413 = (($412) - ($409))|0;
       $414 = $413 & 65535;
       $415 = (($411) + 24|0);
       HEAP32[$415>>2] = $414;
       $416 = (($411) + 4|0);
       $417 = HEAP32[$416>>2]|0;
       $418 = ($417|0)==(0|0);
       if ($418) {
        break;
       } else {
        $411 = $417;
       }
      }
     }
     $419 = HEAP32[$14>>2]|0;
     $420 = ($419|0)>(0);
     L142: do {
      if ($420) {
       $421 = (0 - ($419))|0;
       $422 = HEAP32[$12>>2]|0;
       $423 = (($422) + ($421<<2)|0);
       $424 = HEAP32[$423>>2]|0;
       $425 = $$pre147$i << 16 >> 16;
       $426 = ($424|0)==($425|0);
       if ($426) {
        $427 = (($419) + -1)|0;
        HEAP32[$14>>2] = $427;
        $428 = ($427|0)>(0);
        if ($428) {
         $434 = $407;$y$0$i64 = $$pre147$i;$y_height$0$i63 = 0;
        } else {
         $y$0$i$lcssa = $$pre147$i;
         break;
        }
       } else {
        $434 = $407;$y$0$i64 = $$pre147$i;$y_height$0$i63 = 0;
       }
       while(1) {
        $433 = ($434|0)==(0|0);
        if (!($433)) {
         $P$2112$i = $434;
         while(1) {
          $435 = (($P$2112$i) + 4|0);
          $436 = HEAP32[$435>>2]|0;
          $437 = (($P$2112$i) + 24|0);
          $438 = HEAP32[$437>>2]|0;
          $439 = (($438) - ($y_height$0$i63))|0;
          HEAP32[$437>>2] = $439;
          $440 = ($438|0)==($y_height$0$i63|0);
          do {
           if ($440) {
            $old$0$i33$i = $waiting$i;
            while(1) {
             $current$0$i34$i = HEAP32[$old$0$i33$i>>2]|0;
             $441 = ($current$0$i34$i|0)==(0|0);
             if ($441) {
              break;
             }
             $442 = ($current$0$i34$i|0)==($P$2112$i|0);
             $443 = (($current$0$i34$i) + 4|0);
             if ($442) {
              label = 113;
              break;
             } else {
              $old$0$i33$i = $443;
             }
            }
            if ((label|0) == 113) {
             label = 0;
             $444 = HEAP32[$443>>2]|0;
             HEAP32[$old$0$i33$i>>2] = $444;
            }
            $445 = (($P$2112$i) + 12|0);
            $446 = HEAP32[$445>>2]|0;
            $447 = $446 & 8;
            $448 = ($447|0)==(0);
            $449 = HEAP32[$P$2112$i>>2]|0;
            if ($448) {
             $457 = HEAP32[$draw_right$i>>2]|0;
             $458 = ($457|0)==(0|0);
             L166: do {
              if ($458) {
               $current$0$in$lcssa$i80$i = $draw_right$i;$current$0$lcssa$i79$i = 0;
              } else {
               $current$0$in2$i77$i = $draw_right$i;$current$03$i76$i = $457;
               while(1) {
                $461 = HEAP32[$current$03$i76$i>>2]|0;
                $462 = ($449|0)<($461|0);
                $459 = (($current$03$i76$i) + 4|0);
                if ($462) {
                 $current$0$in$lcssa$i80$i = $current$0$in2$i77$i;$current$0$lcssa$i79$i = $current$03$i76$i;
                 break L166;
                }
                $current$0$i75$i = HEAP32[$459>>2]|0;
                $460 = ($current$0$i75$i|0)==(0|0);
                if ($460) {
                 $current$0$in$lcssa$i80$i = $459;$current$0$lcssa$i79$i = 0;
                 break;
                } else {
                 $current$0$in2$i77$i = $459;$current$03$i76$i = $current$0$i75$i;
                }
               }
              }
             } while(0);
             HEAP32[$435>>2] = $current$0$lcssa$i79$i;
             HEAP32[$current$0$in$lcssa$i80$i>>2] = $P$2112$i;
             break;
            } else {
             $450 = HEAP32[$draw_left$i>>2]|0;
             $451 = ($450|0)==(0|0);
             L160: do {
              if ($451) {
               $current$0$in$lcssa$i88$i = $draw_left$i;$current$0$lcssa$i87$i = 0;
              } else {
               $current$0$in2$i85$i = $draw_left$i;$current$03$i84$i = $450;
               while(1) {
                $454 = HEAP32[$current$03$i84$i>>2]|0;
                $455 = ($449|0)<($454|0);
                $452 = (($current$03$i84$i) + 4|0);
                if ($455) {
                 $current$0$in$lcssa$i88$i = $current$0$in2$i85$i;$current$0$lcssa$i87$i = $current$03$i84$i;
                 break L160;
                }
                $current$0$i83$i = HEAP32[$452>>2]|0;
                $453 = ($current$0$i83$i|0)==(0|0);
                if ($453) {
                 $current$0$in$lcssa$i88$i = $452;$current$0$lcssa$i87$i = 0;
                 break;
                } else {
                 $current$0$in2$i85$i = $452;$current$03$i84$i = $current$0$i83$i;
                }
               }
              }
             } while(0);
             HEAP32[$435>>2] = $current$0$lcssa$i87$i;
             HEAP32[$current$0$in$lcssa$i88$i>>2] = $P$2112$i;
             break;
            }
           }
          } while(0);
          $456 = ($436|0)==(0|0);
          if ($456) {
           break;
          } else {
           $P$2112$i = $436;
          }
         }
        }
        $463 = HEAP32[$draw_left$i>>2]|0;
        $464 = ($463|0)==(0|0);
        if ($464) {
         $652 = 0;
        } else {
         $current$08$i56$i = $463;
         while(1) {
          $465 = (($current$08$i56$i) + 8|0);
          $466 = HEAP32[$465>>2]|0;
          $467 = HEAP32[$466>>2]|0;
          HEAP32[$current$08$i56$i>>2] = $467;
          $468 = (($current$08$i56$i) + 12|0);
          $469 = HEAP32[$468>>2]|0;
          $470 = $469 >>> 2;
          $471 = $470 & 2;
          $472 = (($471) + -1)|0;
          $473 = (($466) + ($472<<2)|0);
          HEAP32[$465>>2] = $473;
          $474 = (($current$08$i56$i) + 16|0);
          $475 = HEAP32[$474>>2]|0;
          $476 = (($475) + -1)|0;
          HEAP32[$474>>2] = $476;
          $477 = (($current$08$i56$i) + 4|0);
          $current$0$i57$i = HEAP32[$477>>2]|0;
          $478 = ($current$0$i57$i|0)==(0|0);
          if ($478) {
           break;
          } else {
           $current$08$i56$i = $current$0$i57$i;
          }
         }
         $next$0$in1$i60$i = (($463) + 4|0);
         $next$02$i61$i = HEAP32[$next$0$in1$i60$i>>2]|0;
         $479 = ($next$02$i61$i|0)==(0|0);
         if ($479) {
          $652 = $463;
         } else {
          $653 = $463;$current$14$i65$i = $463;$next$0$in5$i64$i = $next$0$in1$i60$i;$next$06$i63$i = $next$02$i61$i;$old$03$i66$i = $draw_left$i;
          while(1) {
           $480 = HEAP32[$current$14$i65$i>>2]|0;
           $481 = HEAP32[$next$06$i63$i>>2]|0;
           $482 = ($480|0)>($481|0);
           if ($482) {
            HEAP32[$old$03$i66$i>>2] = $next$06$i63$i;
            $483 = (($next$06$i63$i) + 4|0);
            $484 = HEAP32[$483>>2]|0;
            HEAP32[$next$0$in5$i64$i>>2] = $484;
            HEAP32[$483>>2] = $current$14$i65$i;
            $485 = HEAP32[$draw_left$i>>2]|0;
            $654 = $485;$current$1$be$i69$i = $485;$old$0$be$i68$i = $draw_left$i;
           } else {
            $654 = $653;$current$1$be$i69$i = $next$06$i63$i;$old$0$be$i68$i = $next$0$in5$i64$i;
           }
           $next$0$in$i70$i = (($current$1$be$i69$i) + 4|0);
           $next$0$i71$i = HEAP32[$next$0$in$i70$i>>2]|0;
           $486 = ($next$0$i71$i|0)==(0|0);
           if ($486) {
            $652 = $654;
            break;
           } else {
            $653 = $654;$current$14$i65$i = $current$1$be$i69$i;$next$0$in5$i64$i = $next$0$in$i70$i;$next$06$i63$i = $next$0$i71$i;$old$03$i66$i = $old$0$be$i68$i;
           }
          }
         }
        }
        $487 = HEAP32[$draw_right$i>>2]|0;
        $488 = ($487|0)==(0|0);
        if ($488) {
         $655 = 0;$656 = $652;
        } else {
         $current$08$i37$i = $487;
         while(1) {
          $489 = (($current$08$i37$i) + 8|0);
          $490 = HEAP32[$489>>2]|0;
          $491 = HEAP32[$490>>2]|0;
          HEAP32[$current$08$i37$i>>2] = $491;
          $492 = (($current$08$i37$i) + 12|0);
          $493 = HEAP32[$492>>2]|0;
          $494 = $493 >>> 2;
          $495 = $494 & 2;
          $496 = (($495) + -1)|0;
          $497 = (($490) + ($496<<2)|0);
          HEAP32[$489>>2] = $497;
          $498 = (($current$08$i37$i) + 16|0);
          $499 = HEAP32[$498>>2]|0;
          $500 = (($499) + -1)|0;
          HEAP32[$498>>2] = $500;
          $501 = (($current$08$i37$i) + 4|0);
          $current$0$i38$i = HEAP32[$501>>2]|0;
          $502 = ($current$0$i38$i|0)==(0|0);
          if ($502) {
           break;
          } else {
           $current$08$i37$i = $current$0$i38$i;
          }
         }
         $next$0$in1$i41$i = (($487) + 4|0);
         $next$02$i42$i = HEAP32[$next$0$in1$i41$i>>2]|0;
         $503 = ($next$02$i42$i|0)==(0|0);
         if ($503) {
          $655 = $487;$656 = $652;
         } else {
          $657 = $487;$current$14$i46$i = $487;$next$0$in5$i45$i = $next$0$in1$i41$i;$next$06$i44$i = $next$02$i42$i;$old$03$i47$i = $draw_right$i;
          while(1) {
           $504 = HEAP32[$current$14$i46$i>>2]|0;
           $505 = HEAP32[$next$06$i44$i>>2]|0;
           $506 = ($504|0)>($505|0);
           if ($506) {
            HEAP32[$old$03$i47$i>>2] = $next$06$i44$i;
            $507 = (($next$06$i44$i) + 4|0);
            $508 = HEAP32[$507>>2]|0;
            HEAP32[$next$0$in5$i45$i>>2] = $508;
            HEAP32[$507>>2] = $current$14$i46$i;
            $509 = HEAP32[$draw_right$i>>2]|0;
            $658 = $509;$current$1$be$i50$i = $509;$old$0$be$i49$i = $draw_right$i;
           } else {
            $658 = $657;$current$1$be$i50$i = $next$06$i44$i;$old$0$be$i49$i = $next$0$in5$i45$i;
           }
           $next$0$in$i51$i = (($current$1$be$i50$i) + 4|0);
           $next$0$i52$i = HEAP32[$next$0$in$i51$i>>2]|0;
           $510 = ($next$0$i52$i|0)==(0|0);
           if ($510) {
            break;
           } else {
            $657 = $658;$current$14$i46$i = $current$1$be$i50$i;$next$0$in5$i45$i = $next$0$in$i51$i;$next$06$i44$i = $next$0$i52$i;$old$03$i47$i = $old$0$be$i49$i;
           }
          }
          $511 = HEAP32[$draw_left$i>>2]|0;
          $655 = $658;$656 = $511;
         }
        }
        $512 = HEAP32[$14>>2]|0;
        $513 = (($512) + -1)|0;
        HEAP32[$14>>2] = $513;
        $514 = (0 - ($512))|0;
        $515 = HEAP32[$12>>2]|0;
        $516 = (($515) + ($514<<2)|0);
        $517 = HEAP32[$516>>2]|0;
        $sext$i = $517 << 16;
        $518 = $sext$i >> 16;
        $519 = $y$0$i64&65535;
        $430 = (($518) - ($519))|0;
        $520 = $y$0$i64 << 16 >> 16;
        $521 = ($520|0)<($518|0);
        L194: do {
         if ($521) {
          $523 = $656;$659 = $655;$y$1106$i = $y$0$i64;
          while(1) {
           $522 = ($523|0)==(0|0);
           L197: do {
            if (!($522)) {
             $526 = $523;$528 = $659;$dropouts$0101$i = 0;
             while(1) {
              $525 = HEAP32[$526>>2]|0;
              $527 = HEAP32[$528>>2]|0;
              $529 = ($525|0)>($527|0);
              $$$i = $529 ? $527 : $525;
              $$4$i = $529 ? $525 : $527;
              $530 = HEAP32[$3>>2]|0;
              $531 = (0 - ($530))|0;
              $532 = $$$i & $531;
              $533 = (($530) + -1)|0;
              $534 = (($533) + ($$4$i))|0;
              $535 = $534 & $531;
              $536 = (($$4$i) - ($$$i))|0;
              $537 = ($536|0)>($530|0);
              $538 = ($532|0)==($$$i|0);
              $or$cond$i = $537 | $538;
              $539 = ($535|0)==($$4$i|0);
              $or$cond5$i = $or$cond$i | $539;
              do {
               if ($or$cond5$i) {
                label = 144;
               } else {
                $540 = ($532|0)>($535|0);
                $541 = (($532) + ($530))|0;
                $542 = ($535|0)==($541|0);
                $or$cond7$i = $540 | $542;
                if (!($or$cond7$i)) {
                 label = 144;
                 break;
                }
                $543 = (($526) + 12|0);
                $544 = HEAP32[$543>>2]|0;
                $545 = $544 & 7;
                $546 = ($545|0)==(2);
                if ($546) {
                 $dropouts$1$i = $dropouts$0101$i;
                 break;
                }
                HEAP32[$526>>2] = $$$i;
                HEAP32[$528>>2] = $$4$i;
                $547 = (($526) + 24|0);
                HEAP32[$547>>2] = 1;
                $548 = (($dropouts$0101$i) + 1)<<16>>16;
                $dropouts$1$i = $548;
               }
              } while(0);
              if ((label|0) == 144) {
               label = 0;
               $549 = HEAP32[$32>>2]|0;
               FUNCTION_TABLE_viiiiii[$549 & 255]($worker,$y$1106$i,$$$i,$$4$i,$526,$528);
               $dropouts$1$i = $dropouts$0101$i;
              }
              $550 = (($526) + 4|0);
              $551 = HEAP32[$550>>2]|0;
              $552 = ($551|0)==(0|0);
              if ($552) {
               break;
              }
              $553 = (($528) + 4|0);
              $$pre134 = HEAP32[$553>>2]|0;
              $526 = $551;$528 = $$pre134;$dropouts$0101$i = $dropouts$1$i;
             }
             $554 = ($dropouts$1$i<<16>>16)>(0);
             if (!($554)) {
              break;
             }
             $555 = HEAP32[$draw_left$i>>2]|0;
             $556 = ($555|0)==(0|0);
             if ($556) {
              break;
             } else {
              $$in9 = $draw_right$i;$637 = $555;
             }
             while(1) {
              $635 = HEAP32[$$in9>>2]|0;
              $636 = (($637) + 24|0);
              $638 = HEAP32[$636>>2]|0;
              $639 = ($638|0)==(0);
              if (!($639)) {
               HEAP32[$636>>2] = 0;
               $640 = HEAP32[$31>>2]|0;
               $641 = HEAP32[$637>>2]|0;
               $642 = HEAP32[$635>>2]|0;
               FUNCTION_TABLE_viiiiii[$640 & 255]($worker,$y$1106$i,$641,$642,$637,$635);
              }
              $643 = (($637) + 4|0);
              $644 = HEAP32[$643>>2]|0;
              $645 = ($644|0)==(0|0);
              if ($645) {
               break L197;
              }
              $646 = (($635) + 4|0);
              $$in9 = $646;$637 = $644;
             }
            }
           } while(0);
           $557 = HEAP32[$30>>2]|0;
           FUNCTION_TABLE_vi[$557 & 4095]($worker);
           $558 = (($y$1106$i) + 1)<<16>>16;
           $559 = $558 << 16 >> 16;
           $560 = ($559|0)<($518|0);
           $561 = HEAP32[$draw_left$i>>2]|0;
           if (!($560)) {
            $$lcssa105$i = $561;$y$1$lcssa$i = $558;
            break L194;
           }
           $562 = ($561|0)==(0|0);
           do {
            if ($562) {
             $661 = 0;
            } else {
             $current$08$i13$i = $561;
             while(1) {
              $563 = (($current$08$i13$i) + 8|0);
              $564 = HEAP32[$563>>2]|0;
              $565 = HEAP32[$564>>2]|0;
              HEAP32[$current$08$i13$i>>2] = $565;
              $566 = (($current$08$i13$i) + 12|0);
              $567 = HEAP32[$566>>2]|0;
              $568 = $567 >>> 2;
              $569 = $568 & 2;
              $570 = (($569) + -1)|0;
              $571 = (($564) + ($570<<2)|0);
              HEAP32[$563>>2] = $571;
              $572 = (($current$08$i13$i) + 16|0);
              $573 = HEAP32[$572>>2]|0;
              $574 = (($573) + -1)|0;
              HEAP32[$572>>2] = $574;
              $575 = (($current$08$i13$i) + 4|0);
              $current$0$i14$i = HEAP32[$575>>2]|0;
              $576 = ($current$0$i14$i|0)==(0|0);
              if ($576) {
               break;
              } else {
               $current$08$i13$i = $current$0$i14$i;
              }
             }
             $next$0$in1$i17$i = (($561) + 4|0);
             $next$02$i18$i = HEAP32[$next$0$in1$i17$i>>2]|0;
             $577 = ($next$02$i18$i|0)==(0|0);
             if ($577) {
              $661 = $561;
              break;
             } else {
              $662 = $561;$current$14$i22$i = $561;$next$0$in5$i21$i = $next$0$in1$i17$i;$next$06$i20$i = $next$02$i18$i;$old$03$i23$i = $draw_left$i;
             }
             while(1) {
              $578 = HEAP32[$current$14$i22$i>>2]|0;
              $579 = HEAP32[$next$06$i20$i>>2]|0;
              $580 = ($578|0)>($579|0);
              if ($580) {
               HEAP32[$old$03$i23$i>>2] = $next$06$i20$i;
               $581 = (($next$06$i20$i) + 4|0);
               $582 = HEAP32[$581>>2]|0;
               HEAP32[$next$0$in5$i21$i>>2] = $582;
               HEAP32[$581>>2] = $current$14$i22$i;
               $583 = HEAP32[$draw_left$i>>2]|0;
               $663 = $583;$current$1$be$i26$i = $583;$old$0$be$i25$i = $draw_left$i;
              } else {
               $663 = $662;$current$1$be$i26$i = $next$06$i20$i;$old$0$be$i25$i = $next$0$in5$i21$i;
              }
              $next$0$in$i27$i = (($current$1$be$i26$i) + 4|0);
              $next$0$i28$i = HEAP32[$next$0$in$i27$i>>2]|0;
              $584 = ($next$0$i28$i|0)==(0|0);
              if ($584) {
               $661 = $663;
               break;
              } else {
               $662 = $663;$current$14$i22$i = $current$1$be$i26$i;$next$0$in5$i21$i = $next$0$in$i27$i;$next$06$i20$i = $next$0$i28$i;$old$03$i23$i = $old$0$be$i25$i;
              }
             }
            }
           } while(0);
           $585 = HEAP32[$draw_right$i>>2]|0;
           $586 = ($585|0)==(0|0);
           if ($586) {
            $523 = $661;$659 = 0;$y$1106$i = $558;
            continue;
           } else {
            $current$08$i$i = $585;
           }
           while(1) {
            $587 = (($current$08$i$i) + 8|0);
            $588 = HEAP32[$587>>2]|0;
            $589 = HEAP32[$588>>2]|0;
            HEAP32[$current$08$i$i>>2] = $589;
            $590 = (($current$08$i$i) + 12|0);
            $591 = HEAP32[$590>>2]|0;
            $592 = $591 >>> 2;
            $593 = $592 & 2;
            $594 = (($593) + -1)|0;
            $595 = (($588) + ($594<<2)|0);
            HEAP32[$587>>2] = $595;
            $596 = (($current$08$i$i) + 16|0);
            $597 = HEAP32[$596>>2]|0;
            $598 = (($597) + -1)|0;
            HEAP32[$596>>2] = $598;
            $599 = (($current$08$i$i) + 4|0);
            $current$0$i11$i = HEAP32[$599>>2]|0;
            $600 = ($current$0$i11$i|0)==(0|0);
            if ($600) {
             break;
            } else {
             $current$08$i$i = $current$0$i11$i;
            }
           }
           $next$0$in1$i$i = (($585) + 4|0);
           $next$02$i$i = HEAP32[$next$0$in1$i$i>>2]|0;
           $601 = ($next$02$i$i|0)==(0|0);
           if ($601) {
            $523 = $661;$659 = $585;$y$1106$i = $558;
            continue;
           } else {
            $664 = $585;$current$14$i$i = $585;$next$0$in5$i$i = $next$0$in1$i$i;$next$06$i$i = $next$02$i$i;$old$03$i$i = $draw_right$i;
           }
           while(1) {
            $602 = HEAP32[$current$14$i$i>>2]|0;
            $603 = HEAP32[$next$06$i$i>>2]|0;
            $604 = ($602|0)>($603|0);
            if ($604) {
             HEAP32[$old$03$i$i>>2] = $next$06$i$i;
             $605 = (($next$06$i$i) + 4|0);
             $606 = HEAP32[$605>>2]|0;
             HEAP32[$next$0$in5$i$i>>2] = $606;
             HEAP32[$605>>2] = $current$14$i$i;
             $607 = HEAP32[$draw_right$i>>2]|0;
             $660 = $607;$current$1$be$i$i = $607;$old$0$be$i$i = $draw_right$i;
            } else {
             $660 = $664;$current$1$be$i$i = $next$06$i$i;$old$0$be$i$i = $next$0$in5$i$i;
            }
            $next$0$in$i$i = (($current$1$be$i$i) + 4|0);
            $next$0$i$i = HEAP32[$next$0$in$i$i>>2]|0;
            $608 = ($next$0$i$i|0)==(0|0);
            if ($608) {
             break;
            } else {
             $664 = $660;$current$14$i$i = $current$1$be$i$i;$next$0$in5$i$i = $next$0$in$i$i;$next$06$i$i = $next$0$i$i;$old$03$i$i = $old$0$be$i$i;
            }
           }
           $$pre = HEAP32[$draw_left$i>>2]|0;
           $523 = $$pre;$659 = $660;$y$1106$i = $558;
          }
         } else {
          $$lcssa105$i = $656;$y$1$lcssa$i = $y$0$i64;
         }
        } while(0);
        $524 = ($$lcssa105$i|0)==(0|0);
        if (!($524)) {
         $P$398$i = $$lcssa105$i;
         while(1) {
          $609 = (($P$398$i) + 4|0);
          $610 = HEAP32[$609>>2]|0;
          $611 = (($P$398$i) + 16|0);
          $612 = HEAP32[$611>>2]|0;
          $613 = ($612|0)==(0);
          L241: do {
           if ($613) {
            $old$0$i8$i = $draw_left$i;
            while(1) {
             $current$0$i9$i = HEAP32[$old$0$i8$i>>2]|0;
             $615 = ($current$0$i9$i|0)==(0|0);
             if ($615) {
              break L241;
             }
             $616 = ($current$0$i9$i|0)==($P$398$i|0);
             $617 = (($current$0$i9$i) + 4|0);
             if ($616) {
              break;
             } else {
              $old$0$i8$i = $617;
             }
            }
            $618 = HEAP32[$617>>2]|0;
            HEAP32[$old$0$i8$i>>2] = $618;
           }
          } while(0);
          $614 = ($610|0)==(0|0);
          if ($614) {
           break;
          } else {
           $P$398$i = $610;
          }
         }
        }
        $619 = HEAP32[$draw_right$i>>2]|0;
        $620 = ($619|0)==(0|0);
        if (!($620)) {
         $P$494$i = $619;
         while(1) {
          $621 = (($P$494$i) + 4|0);
          $622 = HEAP32[$621>>2]|0;
          $623 = (($P$494$i) + 16|0);
          $624 = HEAP32[$623>>2]|0;
          $625 = ($624|0)==(0);
          L251: do {
           if ($625) {
            $old$0$i$i = $draw_right$i;
            while(1) {
             $current$0$i$i = HEAP32[$old$0$i$i>>2]|0;
             $627 = ($current$0$i$i|0)==(0|0);
             if ($627) {
              break L251;
             }
             $628 = ($current$0$i$i|0)==($P$494$i|0);
             $629 = (($current$0$i$i) + 4|0);
             if ($628) {
              break;
             } else {
              $old$0$i$i = $629;
             }
            }
            $630 = HEAP32[$629>>2]|0;
            HEAP32[$old$0$i$i>>2] = $630;
           }
          } while(0);
          $626 = ($622|0)==(0|0);
          if ($626) {
           break;
          } else {
           $P$494$i = $622;
          }
         }
        }
        $$pr$pre$i = HEAP32[$14>>2]|0;
        $429 = ($$pr$pre$i|0)>(0);
        if (!($429)) {
         $y$0$i$lcssa = $y$1$lcssa$i;
         break L142;
        }
        $phitmp$i = $430 << 16;
        $phitmp148$i = $phitmp$i >> 16;
        $$pre133 = HEAP32[$waiting$i>>2]|0;
        $434 = $$pre133;$y$0$i64 = $y$1$lcssa$i;$y_height$0$i63 = $phitmp148$i;
       }
      } else {
       $y$0$i$lcssa = $$pre147$i;
      }
     } while(0);
     $431 = HEAP16[$max_Y$i>>1]|0;
     $432 = ($y$0$i$lcssa<<16>>16)>($431<<16>>16);
     if (!($432)) {
      $y$2118$i = $y$0$i$lcssa;
      while(1) {
       $631 = HEAP32[$30>>2]|0;
       FUNCTION_TABLE_vi[$631 & 4095]($worker);
       $632 = (($y$2118$i) + 1)<<16>>16;
       $633 = HEAP16[$max_Y$i>>1]|0;
       $634 = ($632<<16>>16)>($633<<16>>16);
       if ($634) {
        break;
       } else {
        $y$2118$i = $632;
       }
      }
     }
    }
    $647 = HEAP32[$0>>2]|0;
    $648 = (($647) + -1)|0;
    $storemerge = $648;
   } else {
    label = 83;
   }
  }
  if ((label|0) == 83) {
   label = 0;
   $$pr = HEAP32[$8>>2]|0;
   $345 = ($$pr|0)==(98);
   if ($345) {
    label = 84;
   } else {
    $$0 = 1;
    label = 181;
    break;
   }
  }
  if ((label|0) == 84) {
   label = 0;
   HEAP32[$8>>2] = 0;
   $346 = HEAP32[$0>>2]|0;
   $347 = ((($worker) + ($346<<2)|0) + 960|0);
   $348 = HEAP16[$347>>1]|0;
   $349 = ((($worker) + ($346<<2)|0) + 962|0);
   $350 = HEAP16[$349>>1]|0;
   $351 = $348 << 16 >> 16;
   $352 = $350 << 16 >> 16;
   $353 = (($352) + ($351))|0;
   $354 = (($353|0) / 2)&-1;
   $355 = $354&65535;
   $356 = ($346|0)>(6);
   if ($356) {
    label = 86;
    break;
   }
   $sext = $354 << 16;
   $357 = $sext >> 16;
   $358 = ($357|0)<($351|0);
   if ($358) {
    label = 86;
    break;
   }
   $359 = (($346) + 1)|0;
   $360 = ((($worker) + ($359<<2)|0) + 960|0);
   HEAP16[$360>>1] = $355;
   $361 = HEAP32[$0>>2]|0;
   $362 = (($361) + 1)|0;
   $363 = ((($worker) + ($362<<2)|0) + 962|0);
   HEAP16[$363>>1] = $350;
   $364 = (($357) + 65535)|0;
   $365 = $364&65535;
   $366 = HEAP32[$0>>2]|0;
   $367 = ((($worker) + ($366<<2)|0) + 962|0);
   HEAP16[$367>>1] = $365;
   $368 = HEAP32[$0>>2]|0;
   $369 = (($368) + 1)|0;
   $storemerge = $369;
  }
  HEAP32[$0>>2] = $storemerge;
  $649 = ($storemerge|0)>(-1);
  if ($649) {
   $34 = $storemerge;
  } else {
   $$0 = 0;
   label = 181;
   break;
  }
 }
 if ((label|0) == 30) {
  HEAP32[$8>>2] = 20;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 41) {
  HEAP32[$8>>2] = 99;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 86) {
  HEAP32[$0>>2] = 0;
  HEAP32[$8>>2] = 20;
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 99) {
  HEAP32[$8>>2] = 20;
  $$0 = 20;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 181) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _Horizontal_Sweep_Init($worker,$min,$max) {
 $worker = $worker|0;
 $min = $min|0;
 $max = $max|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _Horizontal_Sweep_Span($worker,$y,$x1,$x2,$left,$right) {
 $worker = $worker|0;
 $y = $y|0;
 $x1 = $x1|0;
 $x2 = $x2|0;
 $left = $left|0;
 $right = $right|0;
 var $$sum = 0, $$sum1 = 0, $$sum1$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($x2) - ($x1))|0;
 $1 = (($worker) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)<($2|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($x1) + -1)|0;
 $5 = (($4) + ($2))|0;
 $6 = (0 - ($2))|0;
 $7 = $5 & $6;
 $8 = $6 & $x2;
 $9 = ($7|0)==($8|0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($worker) + 60|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $y << 16 >> 16;
 $13 = $12 >> 3;
 $14 = $12 & 7;
 $15 = 128 >>> $14;
 $16 = HEAP32[$worker>>2]|0;
 $17 = $7 >> $16;
 $18 = ($17|0)>(-1);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $19 = (($worker) + 104|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($17|0)<($20|0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($worker) + 112|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = Math_imul($23, $17)|0;
 $$sum = (($13) - ($24))|0;
 $25 = ($23|0)>(0);
 if ($25) {
  $26 = (($20) + -1)|0;
  $27 = Math_imul($23, $26)|0;
  $$sum1 = (($$sum) + ($27))|0;
  $$sum1$pn = $$sum1;
 } else {
  $$sum1$pn = $$sum;
 }
 $p$0 = (($11) + ($$sum1$pn)|0);
 $28 = HEAP8[$p$0>>0]|0;
 $29 = $28&255;
 $30 = $29 | $15;
 $31 = $30&255;
 HEAP8[$p$0>>0] = $31;
 STACKTOP = sp;return;
}
function _Horizontal_Sweep_Drop($worker,$y,$x1,$x2,$left,$right) {
 $worker = $worker|0;
 $y = $y|0;
 $x1 = $x1|0;
 $x2 = $x2|0;
 $left = $left|0;
 $right = $right|0;
 var $$phi$trans$insert5 = 0, $$pre = 0, $$pre$phi11Z2D = 0, $$pre$phi15Z2D = 0, $$pre10 = 0, $$pre12 = 0, $$pre14 = 0, $$pre6 = 0, $$pre8 = 0, $$pre9 = 0, $$sum = 0, $$sum1 = 0, $$sum1$pn = 0, $$sum2 = 0, $$sum3 = 0, $$sum3$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $bits$0 = 0, $bits$1 = 0, $pxl$0 = 0, $pxl$0$ = 0, $pxl$1 = 0, $pxl$2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($x1) + -1)|0;
 $3 = (($2) + ($1))|0;
 $4 = (0 - ($1))|0;
 $5 = $3 & $4;
 $6 = $4 & $x2;
 $7 = ($5|0)>($6|0);
 if ($7) {
  $8 = (($left) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 7;
  $11 = (($6) + ($1))|0;
  $12 = ($5|0)==($11|0);
  if (!($12)) {
   STACKTOP = sp;return;
  }
  if ((($10|0) == 5) | (($10|0) == 1)) {
   $19 = (($left) + 28|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==($right|0);
   if ($21) {
    $22 = (($left) + 16|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)<(1);
    if ($24) {
     $25 = $9 & 16;
     $26 = ($25|0)==(0);
     if ($26) {
      STACKTOP = sp;return;
     }
     $27 = (($x2) - ($x1))|0;
     $28 = (($worker) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27|0)<($29|0);
     if ($30) {
      STACKTOP = sp;return;
     }
    }
   }
   $31 = (($right) + 28|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==($left|0);
   if ($33) {
    $34 = (($left) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $y << 16 >> 16;
    $37 = ($35|0)==($36|0);
    if ($37) {
     $38 = $9 & 32;
     $39 = ($38|0)==(0);
     if ($39) {
      STACKTOP = sp;return;
     }
     $40 = (($x2) - ($x1))|0;
     $41 = (($worker) + 8|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($40|0)<($42|0);
     if ($43) {
      STACKTOP = sp;return;
     }
    }
   }
   $44 = ($10|0)==(1);
   if ($44) {
    $pxl$0 = $6;
   } else {
    $45 = (($2) + ($x2))|0;
    $46 = (($45|0) / 2)&-1;
    $47 = (($worker) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) + ($46))|0;
    $50 = $49 & $4;
    $pxl$0 = $50;
   }
  } else if ((($10|0) == 4)) {
   $13 = (($2) + ($x2))|0;
   $14 = (($13|0) / 2)&-1;
   $15 = (($worker) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($14))|0;
   $18 = $17 & $4;
   $pxl$0 = $18;
  } else if ((($10|0) == 0)) {
   $pxl$0 = $6;
  } else {
   STACKTOP = sp;return;
  }
  $51 = ($pxl$0|0)<(0);
  $$pre = HEAP32[$worker>>2]|0;
  if ($51) {
   $pxl$1 = $5;
  } else {
   $52 = $pxl$0 >> $$pre;
   $53 = (($worker) + 104|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ($52|0)<($54|0);
   $pxl$0$ = $55 ? $pxl$0 : $6;
   $pxl$1 = $pxl$0$;
  }
  $56 = ($pxl$1|0)==($5|0);
  $57 = $56 ? $6 : $5;
  $58 = $57 >> $$pre;
  $59 = (($worker) + 60|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = $y << 16 >> 16;
  $62 = $61 >> 3;
  $63 = $61 & 7;
  $64 = 128 >>> $63;
  $65 = (($worker) + 104|0);
  $66 = (($worker) + 112|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = Math_imul($58, $67)|0;
  $$sum2 = (($62) - ($68))|0;
  $69 = ($67|0)>(0);
  if ($69) {
   $70 = HEAP32[$65>>2]|0;
   $71 = (($70) + -1)|0;
   $72 = Math_imul($71, $67)|0;
   $$sum3 = (($72) + ($$sum2))|0;
   $$sum3$pn = $$sum3;
  } else {
   $$sum3$pn = $$sum2;
  }
  $bits$0 = (($60) + ($$sum3$pn)|0);
  $73 = ($58|0)>(-1);
  if ($73) {
   $74 = HEAP32[$65>>2]|0;
   $75 = ($58|0)<($74|0);
   if ($75) {
    $76 = HEAP8[$bits$0>>0]|0;
    $77 = $76&255;
    $78 = $64 & $77;
    $79 = ($78|0)==(0);
    if ($79) {
     $$pre$phi11Z2D = $62;$$pre$phi15Z2D = $64;$81 = $$pre;$92 = $60;$pxl$2 = $pxl$1;
    } else {
     STACKTOP = sp;return;
    }
   } else {
    $$pre$phi11Z2D = $62;$$pre$phi15Z2D = $64;$81 = $$pre;$92 = $60;$pxl$2 = $pxl$1;
   }
  } else {
   $$pre$phi11Z2D = $62;$$pre$phi15Z2D = $64;$81 = $$pre;$92 = $60;$pxl$2 = $pxl$1;
  }
 } else {
  $$phi$trans$insert5 = (($worker) + 60|0);
  $$pre6 = HEAP32[$$phi$trans$insert5>>2]|0;
  $$pre8 = HEAP32[$worker>>2]|0;
  $$pre9 = $y << 16 >> 16;
  $$pre10 = $$pre9 >> 3;
  $$pre12 = $$pre9 & 7;
  $$pre14 = 128 >>> $$pre12;
  $$pre$phi11Z2D = $$pre10;$$pre$phi15Z2D = $$pre14;$81 = $$pre8;$92 = $$pre6;$pxl$2 = $5;
 }
 $80 = $pxl$2 >> $81;
 $82 = ($80|0)>(-1);
 if (!($82)) {
  STACKTOP = sp;return;
 }
 $83 = (($worker) + 104|0);
 $84 = HEAP32[$83>>2]|0;
 $85 = ($80|0)<($84|0);
 if (!($85)) {
  STACKTOP = sp;return;
 }
 $86 = (($worker) + 112|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = Math_imul($87, $80)|0;
 $$sum = (($$pre$phi11Z2D) - ($88))|0;
 $89 = ($87|0)>(0);
 if ($89) {
  $90 = (($84) + -1)|0;
  $91 = Math_imul($87, $90)|0;
  $$sum1 = (($$sum) + ($91))|0;
  $$sum1$pn = $$sum1;
 } else {
  $$sum1$pn = $$sum;
 }
 $bits$1 = (($92) + ($$sum1$pn)|0);
 $93 = HEAP8[$bits$1>>0]|0;
 $94 = $93&255;
 $95 = $94 | $$pre$phi15Z2D;
 $96 = $95&255;
 HEAP8[$bits$1>>0] = $96;
 STACKTOP = sp;return;
}
function _Horizontal_Sweep_Step($worker) {
 $worker = $worker|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _FT_Init_Class_ft_standard_raster($clazz) {
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$clazz>>2] = 1869968492;
 $0 = (($clazz) + 4|0);
 HEAP32[$0>>2] = 2707;
 $1 = (($clazz) + 8|0);
 HEAP32[$1>>2] = 2073;
 $2 = (($clazz) + 12|0);
 HEAP32[$2>>2] = 2074;
 $3 = (($clazz) + 16|0);
 HEAP32[$3>>2] = 2708;
 $4 = (($clazz) + 20|0);
 HEAP32[$4>>2] = 3756;
 STACKTOP = sp;return;
}
function _ft_black_new($memory,$araster) {
 $memory = $memory|0;
 $araster = $araster|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$araster>>2] = 0;
 $0 = (_ft_mem_alloc($memory,24,$error)|0);
 $1 = HEAP32[$error>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return ($1|0);
 }
 $3 = (($0) + 8|0);
 HEAP32[$3>>2] = $memory;
 HEAP32[$araster>>2] = $0;
 STACKTOP = sp;return ($1|0);
}
function _ft_black_reset($raster,$pool_base,$pool_size) {
 $raster = $raster|0;
 $pool_base = $pool_base|0;
 $pool_size = $pool_size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($raster|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = ($pool_base|0)!=(0|0);
 $2 = ($pool_size|0)>(3075);
 $or$cond = $1 & $2;
 if ($or$cond) {
  $3 = (($pool_base) + 1032|0);
  HEAP32[$raster>>2] = $3;
  $4 = (($pool_size) + -1032)|0;
  $5 = (($raster) + 4|0);
  HEAP32[$5>>2] = $4;
  $6 = (($raster) + 12|0);
  HEAP32[$6>>2] = $pool_base;
  STACKTOP = sp;return;
 } else {
  HEAP32[$raster>>2] = 0;
  $7 = (($raster) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($raster) + 12|0);
  HEAP32[$8>>2] = 0;
  STACKTOP = sp;return;
 }
}
function _ft_black_set_mode($raster,$mode,$palette) {
 $raster = $raster|0;
 $mode = $mode|0;
 $palette = $palette|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _ft_black_render($raster,$params) {
 $raster = $raster|0;
 $params = $params|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($params) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$params>>2]|0;
 $3 = ($raster|0)==(0|0);
 if ($3) {
  $$0 = 96;
 } else {
  $4 = HEAP32[$raster>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = 96;
  } else {
   $6 = (($raster) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   if ($8) {
    $$0 = 96;
   } else {
    $9 = ($1|0)==(0|0);
    if ($9) {
     $$0 = 20;
    } else {
     $10 = (($1) + 2|0);
     $11 = HEAP16[$10>>1]|0;
     $12 = $11 << 16 >> 16;
     $13 = ($11<<16>>16)==(0);
     if ($13) {
      $$0 = 0;
     } else {
      $14 = HEAP16[$1>>1]|0;
      $15 = $14 << 16 >> 16;
      $16 = ($14<<16>>16)<(1);
      if ($16) {
       $$0 = 0;
      } else {
       $17 = (($1) + 12|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = ($18|0)==(0|0);
       if ($19) {
        $$0 = 20;
       } else {
        $20 = (($1) + 4|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)==(0|0);
        if ($22) {
         $$0 = 20;
        } else {
         $23 = (($15) + -1)|0;
         $24 = (($18) + ($23<<1)|0);
         $25 = HEAP16[$24>>1]|0;
         $26 = $25 << 16 >> 16;
         $27 = (($26) + 1)|0;
         $28 = ($12|0)==($27|0);
         if ($28) {
          $29 = (($raster) + 12|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = (($params) + 8|0);
          $32 = HEAP32[$31>>2]|0;
          $33 = $32 & 2;
          $34 = ($33|0)==(0);
          if ($34) {
           $35 = ($2|0)==(0|0);
           if ($35) {
            $$0 = 20;
           } else {
            $36 = (($2) + 4|0);
            $37 = HEAP32[$36>>2]|0;
            $38 = ($37|0)==(0);
            if ($38) {
             $$0 = 0;
            } else {
             $39 = HEAP32[$2>>2]|0;
             $40 = ($39|0)==(0);
             if ($40) {
              $$0 = 0;
             } else {
              $41 = (($2) + 12|0);
              $42 = HEAP32[$41>>2]|0;
              $43 = ($42|0)==(0|0);
              if ($43) {
               $$0 = 20;
              } else {
               $44 = (($30) + 128|0);
               ;HEAP32[$44+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$44+16>>2]=HEAP32[$1+16>>2]|0;
               $45 = (($30) + 104|0);
               ;HEAP32[$45+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$45+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$45+20>>2]=HEAP32[$2+20>>2]|0;
               $46 = HEAP32[$raster>>2]|0;
               $47 = (($30) + 28|0);
               HEAP32[$47>>2] = $46;
               $48 = HEAP32[$6>>2]|0;
               $49 = $48 >>> 2;
               $50 = (($46) + ($49<<2)|0);
               $51 = (($30) + 32|0);
               HEAP32[$51>>2] = $50;
               $52 = HEAP32[$31>>2]|0;
               $53 = $52 & 1;
               $54 = ($53|0)==(0);
               if ($54) {
                $55 = (_Render_Glyph($30)|0);
                $$0 = $55;
               } else {
                $$0 = 19;
               }
              }
             }
            }
           }
          } else {
           $$0 = 19;
          }
         } else {
          $$0 = 20;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _ft_black_done($raster) {
 $raster = $raster|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($raster) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 _ft_mem_free($1,$raster);
 STACKTOP = sp;return;
}
function _Line_To($worker,$x,$y) {
 $worker = $worker|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$$v = 0, $$0 = 0, $$20 = 0, $$21 = 0, $$22 = 0, $$22$v = 0, $$c$i = 0, $$c$i10 = 0, $$not = 0, $$not1 = 0, $$not2 = 0, $$pre = 0, $$pre$i = 0, $$pre$i11 = 0, $$pre$phi25Z2D = 0, $$pre$phiZ2D = 0, $$pre24 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 do {
  if ((($1|0) == 0)) {
   $2 = (($worker) + 72|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)<($y|0);
   if ($4) {
    $5 = (($worker) + 4|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($3) + -1)|0;
    $8 = (($7) + ($6))|0;
    $9 = (0 - ($6))|0;
    $10 = $8 & $9;
    $11 = (($10) - ($3))|0;
    $12 = (($worker) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)<($13|0);
    $15 = (($worker) + 92|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    $18 = (($worker) + 40|0);
    $19 = HEAP32[$18>>2]|0;
    if ($17) {
     $20 = (($worker) + 88|0);
     HEAP32[$20>>2] = $19;
     HEAP32[$15>>2] = $19;
     $21 = (($19) + 32|0);
     HEAP32[$18>>2] = $21;
     $25 = $21;
    } else {
     $25 = $19;
    }
    $22 = (($worker) + 36|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($25>>>0)<($23>>>0);
    if (!($24)) {
     $46 = (($worker) + 44|0);
     HEAP32[$46>>2] = 98;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $26 = (($worker) + 88|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 12|0);
    HEAP32[$28>>2] = 0;
    $29 = (($27) + 20|0);
    HEAP32[$29>>2] = 0;
    $30 = (($27) + 16|0);
    HEAP32[$30>>2] = 0;
    $31 = (($27) + 8|0);
    HEAP32[$31>>2] = $25;
    $32 = HEAP32[$26>>2]|0;
    $33 = (($32) + 4|0);
    HEAP32[$33>>2] = 0;
    $34 = HEAP32[$26>>2]|0;
    $35 = (($34) + 28|0);
    HEAP32[$35>>2] = 0;
    $36 = (($worker) + 180|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = $37&255;
    $39 = HEAP32[$26>>2]|0;
    $40 = (($39) + 12|0);
    $$$v = $14 ? 8 : 40;
    $$ = $38 | $$$v;
    HEAP32[$40>>2] = $$;
    $41 = (($worker) + 96|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    if ($43) {
     HEAP32[$41>>2] = $39;
    }
    HEAP32[$0>>2] = 1;
    $44 = (($worker) + 86|0);
    HEAP8[$44>>0] = 1;
    $45 = (($worker) + 87|0);
    HEAP8[$45>>0] = 0;
    label = 55;
    break;
   }
   $47 = ($3|0)>($y|0);
   if ($47) {
    $48 = (($worker) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $$not2 = (($49) + -1)|0;
    $50 = $$not2 & $3;
    $51 = (($worker) + 8|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($50|0)<($52|0);
    $54 = (($worker) + 92|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==(0|0);
    $57 = (($worker) + 40|0);
    $58 = HEAP32[$57>>2]|0;
    if ($56) {
     $59 = (($worker) + 88|0);
     HEAP32[$59>>2] = $58;
     HEAP32[$54>>2] = $58;
     $60 = (($58) + 32|0);
     HEAP32[$57>>2] = $60;
     $64 = $60;
    } else {
     $64 = $58;
    }
    $61 = (($worker) + 36|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($64>>>0)<($62>>>0);
    if (!($63)) {
     $86 = (($worker) + 44|0);
     HEAP32[$86>>2] = 98;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $65 = (($worker) + 88|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = (($66) + 12|0);
    HEAP32[$67>>2] = 0;
    $68 = (($66) + 20|0);
    HEAP32[$68>>2] = 0;
    $69 = (($66) + 16|0);
    HEAP32[$69>>2] = 0;
    $70 = (($66) + 8|0);
    HEAP32[$70>>2] = $64;
    $71 = HEAP32[$65>>2]|0;
    $72 = (($71) + 4|0);
    HEAP32[$72>>2] = 0;
    $73 = HEAP32[$65>>2]|0;
    $74 = (($73) + 28|0);
    HEAP32[$74>>2] = 0;
    $75 = (($worker) + 180|0);
    $76 = HEAP8[$75>>0]|0;
    $77 = $76&255;
    $78 = HEAP32[$65>>2]|0;
    $79 = (($78) + 12|0);
    $80 = $77 | 16;
    $$20 = $53 ? $77 : $80;
    HEAP32[$79>>2] = $$20;
    $81 = (($worker) + 96|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ($82|0)==(0|0);
    if ($83) {
     HEAP32[$81>>2] = $78;
    }
    HEAP32[$0>>2] = 2;
    $84 = (($worker) + 86|0);
    HEAP8[$84>>0] = 1;
    $85 = (($worker) + 87|0);
    HEAP8[$85>>0] = 0;
    label = 56;
   } else {
    label = 54;
   }
  } else if ((($1|0) == 1)) {
   $87 = (($worker) + 72|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)>($y|0);
   if ($89) {
    $90 = (($worker) + 4|0);
    $91 = HEAP32[$90>>2]|0;
    $$not = (($91) + -1)|0;
    $92 = $$not & $88;
    $93 = (($worker) + 8|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($92|0)<($94|0);
    $96 = (($worker) + 40|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = (($worker) + 88|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (($99) + 8|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = $97;
    $103 = $101;
    $104 = (($102) - ($103))|0;
    $105 = $104 >> 2;
    $106 = ($104|0)<(0);
    if ($106) {
     $107 = (($worker) + 44|0);
     HEAP32[$107>>2] = 99;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $108 = ($104|0)>(0);
    if ($108) {
     $109 = (($99) + 16|0);
     HEAP32[$109>>2] = $105;
     do {
      if (!($95)) {
       $110 = (($99) + 12|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = $111 & 8;
       $113 = ($112|0)==(0);
       if ($113) {
        $115 = $111 | 32;
        HEAP32[$110>>2] = $115;
        break;
       } else {
        $114 = $111 | 16;
        HEAP32[$110>>2] = $114;
        break;
       }
      }
     } while(0);
     HEAP32[$98>>2] = $97;
     $116 = (($97) + 32|0);
     HEAP32[$96>>2] = $116;
     $117 = (($97) + 16|0);
     HEAP32[$117>>2] = 0;
     $118 = (($97) + 8|0);
     $$c$i = $116;
     HEAP32[$118>>2] = $$c$i;
     $119 = HEAP32[$98>>2]|0;
     $120 = (($99) + 28|0);
     HEAP32[$120>>2] = $119;
     $121 = (($worker) + 84|0);
     $122 = HEAP16[$121>>1]|0;
     $123 = (($122) + 1)<<16>>16;
     HEAP16[$121>>1] = $123;
     $$pre$i = HEAP32[$96>>2]|0;
     $127 = $$pre$i;
    } else {
     $127 = $97;
    }
    $124 = (($worker) + 36|0);
    $125 = HEAP32[$124>>2]|0;
    $126 = ($127>>>0)<($125>>>0);
    if (!($126)) {
     $128 = (($worker) + 44|0);
     HEAP32[$128>>2] = 98;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $129 = (($worker) + 87|0);
    HEAP8[$129>>0] = 0;
    $130 = HEAP32[$87>>2]|0;
    $131 = HEAP32[$90>>2]|0;
    $$not1 = (($131) + -1)|0;
    $132 = $$not1 & $130;
    $133 = HEAP32[$93>>2]|0;
    $134 = ($132|0)<($133|0);
    $135 = (($worker) + 92|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = ($136|0)==(0|0);
    if ($137) {
     HEAP32[$98>>2] = $127;
     HEAP32[$135>>2] = $127;
     $138 = (($127) + 32|0);
     HEAP32[$96>>2] = $138;
     $140 = $138;
    } else {
     $140 = $127;
    }
    $139 = ($140>>>0)<($125>>>0);
    if (!($139)) {
     $160 = (($worker) + 44|0);
     HEAP32[$160>>2] = 98;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $141 = HEAP32[$98>>2]|0;
    $142 = (($141) + 12|0);
    HEAP32[$142>>2] = 0;
    $143 = (($141) + 20|0);
    HEAP32[$143>>2] = 0;
    $144 = (($141) + 16|0);
    HEAP32[$144>>2] = 0;
    $145 = (($141) + 8|0);
    HEAP32[$145>>2] = $140;
    $146 = HEAP32[$98>>2]|0;
    $147 = (($146) + 4|0);
    HEAP32[$147>>2] = 0;
    $148 = HEAP32[$98>>2]|0;
    $149 = (($148) + 28|0);
    HEAP32[$149>>2] = 0;
    $150 = (($worker) + 180|0);
    $151 = HEAP8[$150>>0]|0;
    $152 = $151&255;
    $153 = HEAP32[$98>>2]|0;
    $154 = (($153) + 12|0);
    $155 = $152 | 16;
    $$21 = $134 ? $152 : $155;
    HEAP32[$154>>2] = $$21;
    $156 = (($worker) + 96|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = ($157|0)==(0|0);
    if ($158) {
     HEAP32[$156>>2] = $153;
    }
    HEAP32[$0>>2] = 2;
    $159 = (($worker) + 86|0);
    HEAP8[$159>>0] = 1;
    HEAP8[$129>>0] = 0;
    label = 56;
   } else {
    label = 55;
   }
  } else if ((($1|0) == 2)) {
   $161 = (($worker) + 72|0);
   $162 = HEAP32[$161>>2]|0;
   $163 = ($162|0)<($y|0);
   if ($163) {
    $164 = (($worker) + 4|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = (($162) + -1)|0;
    $167 = (($166) + ($165))|0;
    $168 = (0 - ($165))|0;
    $169 = $167 & $168;
    $170 = (($169) - ($162))|0;
    $171 = (($worker) + 8|0);
    $172 = HEAP32[$171>>2]|0;
    $173 = ($170|0)<($172|0);
    $174 = (($worker) + 40|0);
    $175 = HEAP32[$174>>2]|0;
    $176 = (($worker) + 88|0);
    $177 = HEAP32[$176>>2]|0;
    $178 = (($177) + 8|0);
    $179 = HEAP32[$178>>2]|0;
    $180 = $175;
    $181 = $179;
    $182 = (($180) - ($181))|0;
    $183 = $182 >> 2;
    $184 = ($182|0)<(0);
    if ($184) {
     $185 = (($worker) + 44|0);
     HEAP32[$185>>2] = 99;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $186 = ($182|0)>(0);
    if ($186) {
     $187 = (($177) + 16|0);
     HEAP32[$187>>2] = $183;
     do {
      if (!($173)) {
       $188 = (($177) + 12|0);
       $189 = HEAP32[$188>>2]|0;
       $190 = $189 & 8;
       $191 = ($190|0)==(0);
       if ($191) {
        $193 = $189 | 32;
        HEAP32[$188>>2] = $193;
        break;
       } else {
        $192 = $189 | 16;
        HEAP32[$188>>2] = $192;
        break;
       }
      }
     } while(0);
     HEAP32[$176>>2] = $175;
     $194 = (($175) + 32|0);
     HEAP32[$174>>2] = $194;
     $195 = (($175) + 16|0);
     HEAP32[$195>>2] = 0;
     $196 = (($175) + 8|0);
     $$c$i10 = $194;
     HEAP32[$196>>2] = $$c$i10;
     $197 = HEAP32[$176>>2]|0;
     $198 = (($177) + 28|0);
     HEAP32[$198>>2] = $197;
     $199 = (($worker) + 84|0);
     $200 = HEAP16[$199>>1]|0;
     $201 = (($200) + 1)<<16>>16;
     HEAP16[$199>>1] = $201;
     $$pre$i11 = HEAP32[$174>>2]|0;
     $205 = $$pre$i11;
    } else {
     $205 = $175;
    }
    $202 = (($worker) + 36|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = ($205>>>0)<($203>>>0);
    if (!($204)) {
     $206 = (($worker) + 44|0);
     HEAP32[$206>>2] = 98;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $207 = (($worker) + 87|0);
    HEAP8[$207>>0] = 0;
    $208 = HEAP32[$161>>2]|0;
    $209 = HEAP32[$164>>2]|0;
    $210 = (($208) + -1)|0;
    $211 = (($210) + ($209))|0;
    $212 = (0 - ($209))|0;
    $213 = $211 & $212;
    $214 = (($213) - ($208))|0;
    $215 = HEAP32[$171>>2]|0;
    $216 = ($214|0)<($215|0);
    $217 = (($worker) + 92|0);
    $218 = HEAP32[$217>>2]|0;
    $219 = ($218|0)==(0|0);
    if ($219) {
     HEAP32[$176>>2] = $205;
     HEAP32[$217>>2] = $205;
     $220 = (($205) + 32|0);
     HEAP32[$174>>2] = $220;
     $222 = $220;
    } else {
     $222 = $205;
    }
    $221 = ($222>>>0)<($203>>>0);
    if (!($221)) {
     $241 = (($worker) + 44|0);
     HEAP32[$241>>2] = 98;
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
    $223 = HEAP32[$176>>2]|0;
    $224 = (($223) + 12|0);
    HEAP32[$224>>2] = 0;
    $225 = (($223) + 20|0);
    HEAP32[$225>>2] = 0;
    $226 = (($223) + 16|0);
    HEAP32[$226>>2] = 0;
    $227 = (($223) + 8|0);
    HEAP32[$227>>2] = $222;
    $228 = HEAP32[$176>>2]|0;
    $229 = (($228) + 4|0);
    HEAP32[$229>>2] = 0;
    $230 = HEAP32[$176>>2]|0;
    $231 = (($230) + 28|0);
    HEAP32[$231>>2] = 0;
    $232 = (($worker) + 180|0);
    $233 = HEAP8[$232>>0]|0;
    $234 = $233&255;
    $235 = HEAP32[$176>>2]|0;
    $236 = (($235) + 12|0);
    $$22$v = $216 ? 8 : 40;
    $$22 = $234 | $$22$v;
    HEAP32[$236>>2] = $$22;
    $237 = (($worker) + 96|0);
    $238 = HEAP32[$237>>2]|0;
    $239 = ($238|0)==(0|0);
    if ($239) {
     HEAP32[$237>>2] = $235;
    }
    HEAP32[$0>>2] = 1;
    $240 = (($worker) + 86|0);
    HEAP8[$240>>0] = 1;
    HEAP8[$207>>0] = 0;
    label = 55;
   } else {
    label = 56;
   }
  } else {
   label = 54;
  }
 } while(0);
 if ((label|0) == 54) {
  $$pre = (($worker) + 68|0);
  $$pre24 = (($worker) + 72|0);
  $$pre$phi25Z2D = $$pre24;$$pre$phiZ2D = $$pre;
 }
 else if ((label|0) == 55) {
  $242 = (($worker) + 68|0);
  $243 = HEAP32[$242>>2]|0;
  $244 = (($worker) + 72|0);
  $245 = HEAP32[$244>>2]|0;
  $246 = (($worker) + 76|0);
  $247 = HEAP32[$246>>2]|0;
  $248 = (($worker) + 80|0);
  $249 = HEAP32[$248>>2]|0;
  $250 = (_Line_Up($worker,$243,$245,$x,$y,$247,$249)|0);
  $251 = ($250<<24>>24)==(0);
  if ($251) {
   $$pre$phi25Z2D = $244;$$pre$phiZ2D = $242;
  } else {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 56) {
  $252 = (($worker) + 68|0);
  $253 = HEAP32[$252>>2]|0;
  $254 = (($worker) + 72|0);
  $255 = HEAP32[$254>>2]|0;
  $256 = (($worker) + 76|0);
  $257 = HEAP32[$256>>2]|0;
  $258 = (($worker) + 80|0);
  $259 = HEAP32[$258>>2]|0;
  $260 = (($worker) + 86|0);
  $261 = HEAP8[$260>>0]|0;
  $262 = (0 - ($255))|0;
  $263 = (0 - ($y))|0;
  $264 = (0 - ($259))|0;
  $265 = (0 - ($257))|0;
  $266 = (_Line_Up($worker,$253,$262,$x,$263,$264,$265)|0);
  $267 = ($261<<24>>24)==(0);
  if (!($267)) {
   $268 = HEAP8[$260>>0]|0;
   $269 = ($268<<24>>24)==(0);
   if ($269) {
    $270 = (($worker) + 88|0);
    $271 = HEAP32[$270>>2]|0;
    $272 = (($271) + 20|0);
    $273 = HEAP32[$272>>2]|0;
    $274 = (0 - ($273))|0;
    HEAP32[$272>>2] = $274;
   }
  }
  $275 = ($266<<24>>24)==(0);
  if ($275) {
   $$pre$phi25Z2D = $254;$$pre$phiZ2D = $252;
  } else {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 HEAP32[$$pre$phiZ2D>>2] = $x;
 HEAP32[$$pre$phi25Z2D>>2] = $y;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _Conic_To($worker,$cx,$cy,$x,$y) {
 $worker = $worker|0;
 $cx = $cx|0;
 $cy = $cy|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$c$i = 0, $$not = 0, $$phi$trans$insert = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert23 = 0, $$pre = 0, $$pre$i = 0, $$pre22 = 0, $$pre24 = 0, $$pre26 = 0, $$pre27 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 184|0);
 $1 = (($worker) + 52|0);
 HEAP32[$1>>2] = $0;
 $2 = (($worker) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($worker) + 200|0);
 HEAP32[$4>>2] = $3;
 $5 = (($worker) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($worker) + 204|0);
 HEAP32[$7>>2] = $6;
 $8 = (($worker) + 192|0);
 HEAP32[$8>>2] = $cx;
 $9 = (($worker) + 196|0);
 HEAP32[$9>>2] = $cy;
 HEAP32[$0>>2] = $x;
 $10 = (($worker) + 188|0);
 HEAP32[$10>>2] = $y;
 $11 = (($worker) + 100|0);
 $12 = (($worker) + 76|0);
 $13 = (($worker) + 80|0);
 $14 = (($worker) + 86|0);
 $15 = (($worker) + 88|0);
 $16 = (($worker) + 4|0);
 $17 = (($worker) + 8|0);
 $18 = (($worker) + 92|0);
 $19 = (($worker) + 40|0);
 $20 = (($worker) + 36|0);
 $21 = (($worker) + 180|0);
 $22 = (($worker) + 96|0);
 $23 = (($worker) + 87|0);
 $24 = (($worker) + 84|0);
 $26 = $6;$27 = $y;$29 = $cy;$32 = $0;$43 = $x;
 L1: while(1) {
  $25 = ($26|0)>($27|0);
  $$ = $25 ? $26 : $27;
  $$1 = $25 ? $27 : $26;
  $28 = ($29|0)<($$1|0);
  $30 = ($29|0)>($$|0);
  $or$cond = $28 | $30;
  do {
   if ($or$cond) {
    $31 = (($32) + 12|0);
    $33 = (($32) + 20|0);
    $34 = (($32) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($32) + 32|0);
    HEAP32[$36>>2] = $35;
    $37 = (($32) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + ($35))|0;
    $40 = (($39|0) / 2)&-1;
    $41 = (($32) + 24|0);
    HEAP32[$41>>2] = $40;
    $42 = (($43) + ($38))|0;
    $44 = (($42|0) / 2)&-1;
    HEAP32[$37>>2] = $44;
    $45 = (($44) + ($40))|0;
    $46 = (($45|0) / 2)&-1;
    HEAP32[$34>>2] = $46;
    $47 = (($32) + 36|0);
    HEAP32[$47>>2] = $26;
    $48 = (($29) + ($26))|0;
    $49 = (($48|0) / 2)&-1;
    $50 = (($32) + 28|0);
    HEAP32[$50>>2] = $49;
    $51 = (($27) + ($29))|0;
    $52 = (($51|0) / 2)&-1;
    HEAP32[$31>>2] = $52;
    $53 = (($52) + ($49))|0;
    $54 = (($53|0) / 2)&-1;
    HEAP32[$33>>2] = $54;
    $55 = (($32) + 16|0);
    HEAP32[$1>>2] = $55;
   } else {
    $56 = ($26|0)==($27|0);
    if ($56) {
     $57 = (($32) + -16|0);
     HEAP32[$1>>2] = $57;
     break;
    }
    $58 = ($26|0)<($27|0);
    $59 = $58 ? 1 : 2;
    $60 = HEAP32[$11>>2]|0;
    $61 = ($60|0)==($59|0);
    if (!($61)) {
     $62 = HEAP32[$16>>2]|0;
     if ($58) {
      $63 = (($26) + -1)|0;
      $64 = (($63) + ($62))|0;
      $65 = (0 - ($62))|0;
      $66 = $64 & $65;
      $67 = (($66) - ($26))|0;
      $68 = HEAP32[$17>>2]|0;
      $69 = ($67|0)>=($68|0);
      $$sink = $69;
     } else {
      $$not = (($62) + -1)|0;
      $70 = $$not & $26;
      $71 = HEAP32[$17>>2]|0;
      $72 = ($70|0)>=($71|0);
      $$sink = $72;
     }
     $73 = ($60|0)==(0);
     $$pre27 = HEAP32[$19>>2]|0;
     if ($73) {
      $104 = $$pre27;
     } else {
      $74 = HEAP32[$15>>2]|0;
      $75 = (($74) + 8|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = $$pre27;
      $78 = $76;
      $79 = (($77) - ($78))|0;
      $80 = $79 >> 2;
      $81 = ($79|0)<(0);
      if ($81) {
       label = 12;
       break L1;
      }
      $83 = ($79|0)>(0);
      if ($83) {
       $84 = (($74) + 16|0);
       HEAP32[$84>>2] = $80;
       do {
        if ($$sink) {
         $85 = (($74) + 12|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = $86 & 8;
         $88 = ($87|0)==(0);
         if ($88) {
          $90 = $86 | 32;
          HEAP32[$85>>2] = $90;
          break;
         } else {
          $89 = $86 | 16;
          HEAP32[$85>>2] = $89;
          break;
         }
        }
       } while(0);
       HEAP32[$15>>2] = $$pre27;
       $91 = (($$pre27) + 32|0);
       HEAP32[$19>>2] = $91;
       $92 = (($$pre27) + 16|0);
       HEAP32[$92>>2] = 0;
       $93 = (($$pre27) + 8|0);
       $$c$i = $91;
       HEAP32[$93>>2] = $$c$i;
       $94 = HEAP32[$15>>2]|0;
       $95 = (($74) + 28|0);
       HEAP32[$95>>2] = $94;
       $96 = HEAP16[$24>>1]|0;
       $97 = (($96) + 1)<<16>>16;
       HEAP16[$24>>1] = $97;
       $$pre$i = HEAP32[$19>>2]|0;
       $100 = $$pre$i;
      } else {
       $100 = $$pre27;
      }
      $98 = HEAP32[$20>>2]|0;
      $99 = ($100>>>0)<($98>>>0);
      if (!($99)) {
       label = 20;
       break L1;
      }
      HEAP8[$23>>0] = 0;
      $104 = $100;
     }
     $102 = HEAP32[$18>>2]|0;
     $103 = ($102|0)==(0|0);
     if ($103) {
      HEAP32[$15>>2] = $104;
      HEAP32[$18>>2] = $104;
      $105 = (($104) + 32|0);
      HEAP32[$19>>2] = $105;
      $108 = $105;
     } else {
      $108 = $104;
     }
     $106 = HEAP32[$20>>2]|0;
     $107 = ($108>>>0)<($106>>>0);
     if (!($107)) {
      label = 25;
      break L1;
     }
     $110 = HEAP32[$15>>2]|0;
     $111 = (($110) + 12|0);
     HEAP32[$111>>2] = 0;
     $112 = (($110) + 20|0);
     HEAP32[$112>>2] = 0;
     $113 = (($110) + 16|0);
     HEAP32[$113>>2] = 0;
     $114 = (($110) + 8|0);
     HEAP32[$114>>2] = $108;
     $115 = HEAP32[$15>>2]|0;
     $116 = (($115) + 4|0);
     HEAP32[$116>>2] = 0;
     $117 = HEAP32[$15>>2]|0;
     $118 = (($117) + 28|0);
     HEAP32[$118>>2] = 0;
     $119 = HEAP8[$21>>0]|0;
     $120 = $119&255;
     $121 = HEAP32[$15>>2]|0;
     $122 = (($121) + 12|0);
     HEAP32[$122>>2] = $120;
     if ($58) {
      $123 = $120 | 8;
      HEAP32[$122>>2] = $123;
      if ($$sink) {
       $124 = $120 | 40;
       HEAP32[$122>>2] = $124;
      }
     } else {
      if ($$sink) {
       $125 = $120 | 16;
       HEAP32[$122>>2] = $125;
      }
     }
     $126 = HEAP32[$22>>2]|0;
     $127 = ($126|0)==(0|0);
     if ($127) {
      HEAP32[$22>>2] = $121;
     }
     HEAP32[$11>>2] = $59;
     HEAP8[$14>>0] = 1;
     HEAP8[$23>>0] = 0;
    }
    $128 = HEAP32[$12>>2]|0;
    $129 = HEAP32[$13>>2]|0;
    if ($58) {
     $130 = (_Bezier_Up($worker,2,3757,$128,$129)|0);
     $131 = ($130<<24>>24)==(0);
     if ($131) {
      break;
     } else {
      $$0 = 1;
      label = 43;
      break L1;
     }
    }
    $132 = HEAP32[$1>>2]|0;
    $133 = (($132) + 4|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = (0 - ($134))|0;
    HEAP32[$133>>2] = $135;
    $136 = (($132) + 12|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = (0 - ($137))|0;
    HEAP32[$136>>2] = $138;
    $139 = (($132) + 20|0);
    $140 = HEAP32[$139>>2]|0;
    $141 = (0 - ($140))|0;
    HEAP32[$139>>2] = $141;
    $142 = HEAP8[$14>>0]|0;
    $143 = (0 - ($129))|0;
    $144 = (0 - ($128))|0;
    $145 = (_Bezier_Up($worker,2,3757,$143,$144)|0);
    $146 = ($142<<24>>24)==(0);
    if (!($146)) {
     $147 = HEAP8[$14>>0]|0;
     $148 = ($147<<24>>24)==(0);
     if ($148) {
      $149 = HEAP32[$15>>2]|0;
      $150 = (($149) + 20|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = (0 - ($151))|0;
      HEAP32[$150>>2] = $152;
     }
    }
    $153 = HEAP32[$133>>2]|0;
    $154 = (0 - ($153))|0;
    HEAP32[$133>>2] = $154;
    $155 = ($145<<24>>24)==(0);
    if (!($155)) {
     $$0 = 1;
     label = 43;
     break L1;
    }
   }
  } while(0);
  $156 = HEAP32[$1>>2]|0;
  $157 = ($156>>>0)<($0>>>0);
  if ($157) {
   label = 42;
   break;
  }
  $$phi$trans$insert = (($156) + 20|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$phi$trans$insert21 = (($156) + 12|0);
  $$pre22 = HEAP32[$$phi$trans$insert21>>2]|0;
  $$phi$trans$insert23 = (($156) + 4|0);
  $$pre24 = HEAP32[$$phi$trans$insert23>>2]|0;
  $$pre26 = HEAP32[$156>>2]|0;
  $26 = $$pre;$27 = $$pre24;$29 = $$pre22;$32 = $156;$43 = $$pre26;
 }
 if ((label|0) == 12) {
  $82 = (($worker) + 44|0);
  HEAP32[$82>>2] = 99;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 20) {
  $101 = (($worker) + 44|0);
  HEAP32[$101>>2] = 98;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 25) {
  $109 = (($worker) + 44|0);
  HEAP32[$109>>2] = 98;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 42) {
  HEAP32[$2>>2] = $43;
  HEAP32[$5>>2] = $27;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 43) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _Cubic_To($worker,$cx1,$cy1,$cx2,$cy2,$x,$y) {
 $worker = $worker|0;
 $cx1 = $cx1|0;
 $cy1 = $cy1|0;
 $cx2 = $cx2|0;
 $cy2 = $cy2|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$c$i = 0, $$not = 0, $$phi$trans$insert = 0, $$phi$trans$insert21 = 0, $$phi$trans$insert23 = 0, $$phi$trans$insert25 = 0, $$pre = 0, $$pre$i = 0, $$pre22 = 0, $$pre24 = 0, $$pre26 = 0, $$pre28 = 0, $$pre29 = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $ymax2$0 = 0, $ymin2$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 184|0);
 $1 = (($worker) + 52|0);
 HEAP32[$1>>2] = $0;
 $2 = (($worker) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($worker) + 208|0);
 HEAP32[$4>>2] = $3;
 $5 = (($worker) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($worker) + 212|0);
 HEAP32[$7>>2] = $6;
 $8 = (($worker) + 200|0);
 HEAP32[$8>>2] = $cx1;
 $9 = (($worker) + 204|0);
 HEAP32[$9>>2] = $cy1;
 $10 = (($worker) + 192|0);
 HEAP32[$10>>2] = $cx2;
 $11 = (($worker) + 196|0);
 HEAP32[$11>>2] = $cy2;
 HEAP32[$0>>2] = $x;
 $12 = (($worker) + 188|0);
 HEAP32[$12>>2] = $y;
 $13 = (($worker) + 100|0);
 $14 = (($worker) + 76|0);
 $15 = (($worker) + 80|0);
 $16 = (($worker) + 86|0);
 $17 = (($worker) + 88|0);
 $18 = (($worker) + 4|0);
 $19 = (($worker) + 8|0);
 $20 = (($worker) + 92|0);
 $21 = (($worker) + 40|0);
 $22 = (($worker) + 36|0);
 $23 = (($worker) + 180|0);
 $24 = (($worker) + 96|0);
 $25 = (($worker) + 87|0);
 $26 = (($worker) + 84|0);
 $28 = $6;$29 = $y;$31 = $cy1;$32 = $cy2;$36 = $0;$48 = $x;
 L1: while(1) {
  $27 = ($28|0)<=($29|0);
  $$ = $27 ? $29 : $28;
  $$1 = $27 ? $28 : $29;
  $30 = ($31|0)>($32|0);
  $ymin2$0 = $30 ? $32 : $31;
  $ymax2$0 = $30 ? $31 : $32;
  $33 = ($ymin2$0|0)<($$1|0);
  $34 = ($ymax2$0|0)>($$|0);
  $or$cond = $33 | $34;
  do {
   if ($or$cond) {
    $35 = (($36) + 12|0);
    $37 = (($36) + 20|0);
    $38 = (($36) + 28|0);
    $39 = (($36) + 24|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($36) + 48|0);
    HEAP32[$41>>2] = $40;
    $42 = (($36) + 8|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($36) + 16|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = (($43) + 1)|0;
    $47 = (($48) + ($46))|0;
    $49 = $47 >> 1;
    HEAP32[$42>>2] = $49;
    $50 = (($40) + 1)|0;
    $51 = (($50) + ($45))|0;
    $52 = $51 >> 1;
    $53 = (($36) + 40|0);
    HEAP32[$53>>2] = $52;
    $54 = (($46) + ($45))|0;
    $55 = $54 >> 1;
    $56 = (($55) + 1)|0;
    $57 = (($56) + ($49))|0;
    $58 = $57 >> 1;
    HEAP32[$44>>2] = $58;
    $59 = (($56) + ($52))|0;
    $60 = $59 >> 1;
    $61 = (($36) + 32|0);
    HEAP32[$61>>2] = $60;
    $62 = (($58) + 1)|0;
    $63 = (($62) + ($60))|0;
    $64 = $63 >> 1;
    HEAP32[$39>>2] = $64;
    $65 = (($36) + 52|0);
    HEAP32[$65>>2] = $28;
    $66 = (($32) + 1)|0;
    $67 = (($29) + ($66))|0;
    $68 = $67 >> 1;
    HEAP32[$35>>2] = $68;
    $69 = (($28) + 1)|0;
    $70 = (($69) + ($31))|0;
    $71 = $70 >> 1;
    $72 = (($36) + 44|0);
    HEAP32[$72>>2] = $71;
    $73 = (($66) + ($31))|0;
    $74 = $73 >> 1;
    $75 = (($74) + 1)|0;
    $76 = (($75) + ($68))|0;
    $77 = $76 >> 1;
    HEAP32[$37>>2] = $77;
    $78 = (($75) + ($71))|0;
    $79 = $78 >> 1;
    $80 = (($36) + 36|0);
    HEAP32[$80>>2] = $79;
    $81 = (($77) + 1)|0;
    $82 = (($81) + ($79))|0;
    $83 = $82 >> 1;
    HEAP32[$38>>2] = $83;
    $84 = (($36) + 24|0);
    HEAP32[$1>>2] = $84;
   } else {
    $85 = ($28|0)==($29|0);
    if ($85) {
     $86 = (($36) + -24|0);
     HEAP32[$1>>2] = $86;
     break;
    }
    $87 = $27 ? 1 : 2;
    $88 = HEAP32[$13>>2]|0;
    $89 = ($88|0)==($87|0);
    if (!($89)) {
     $90 = HEAP32[$18>>2]|0;
     if ($27) {
      $91 = (($28) + -1)|0;
      $92 = (($91) + ($90))|0;
      $93 = (0 - ($90))|0;
      $94 = $92 & $93;
      $95 = (($94) - ($28))|0;
      $96 = HEAP32[$19>>2]|0;
      $97 = ($95|0)>=($96|0);
      $$sink = $97;
     } else {
      $$not = (($90) + -1)|0;
      $98 = $$not & $28;
      $99 = HEAP32[$19>>2]|0;
      $100 = ($98|0)>=($99|0);
      $$sink = $100;
     }
     $101 = ($88|0)==(0);
     $$pre29 = HEAP32[$21>>2]|0;
     if ($101) {
      $132 = $$pre29;
     } else {
      $102 = HEAP32[$17>>2]|0;
      $103 = (($102) + 8|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = $$pre29;
      $106 = $104;
      $107 = (($105) - ($106))|0;
      $108 = $107 >> 2;
      $109 = ($107|0)<(0);
      if ($109) {
       label = 12;
       break L1;
      }
      $111 = ($107|0)>(0);
      if ($111) {
       $112 = (($102) + 16|0);
       HEAP32[$112>>2] = $108;
       do {
        if ($$sink) {
         $113 = (($102) + 12|0);
         $114 = HEAP32[$113>>2]|0;
         $115 = $114 & 8;
         $116 = ($115|0)==(0);
         if ($116) {
          $118 = $114 | 32;
          HEAP32[$113>>2] = $118;
          break;
         } else {
          $117 = $114 | 16;
          HEAP32[$113>>2] = $117;
          break;
         }
        }
       } while(0);
       HEAP32[$17>>2] = $$pre29;
       $119 = (($$pre29) + 32|0);
       HEAP32[$21>>2] = $119;
       $120 = (($$pre29) + 16|0);
       HEAP32[$120>>2] = 0;
       $121 = (($$pre29) + 8|0);
       $$c$i = $119;
       HEAP32[$121>>2] = $$c$i;
       $122 = HEAP32[$17>>2]|0;
       $123 = (($102) + 28|0);
       HEAP32[$123>>2] = $122;
       $124 = HEAP16[$26>>1]|0;
       $125 = (($124) + 1)<<16>>16;
       HEAP16[$26>>1] = $125;
       $$pre$i = HEAP32[$21>>2]|0;
       $128 = $$pre$i;
      } else {
       $128 = $$pre29;
      }
      $126 = HEAP32[$22>>2]|0;
      $127 = ($128>>>0)<($126>>>0);
      if (!($127)) {
       label = 20;
       break L1;
      }
      HEAP8[$25>>0] = 0;
      $132 = $128;
     }
     $130 = HEAP32[$20>>2]|0;
     $131 = ($130|0)==(0|0);
     if ($131) {
      HEAP32[$17>>2] = $132;
      HEAP32[$20>>2] = $132;
      $133 = (($132) + 32|0);
      HEAP32[$21>>2] = $133;
      $136 = $133;
     } else {
      $136 = $132;
     }
     $134 = HEAP32[$22>>2]|0;
     $135 = ($136>>>0)<($134>>>0);
     if (!($135)) {
      label = 25;
      break L1;
     }
     $138 = HEAP32[$17>>2]|0;
     $139 = (($138) + 12|0);
     HEAP32[$139>>2] = 0;
     $140 = (($138) + 20|0);
     HEAP32[$140>>2] = 0;
     $141 = (($138) + 16|0);
     HEAP32[$141>>2] = 0;
     $142 = (($138) + 8|0);
     HEAP32[$142>>2] = $136;
     $143 = HEAP32[$17>>2]|0;
     $144 = (($143) + 4|0);
     HEAP32[$144>>2] = 0;
     $145 = HEAP32[$17>>2]|0;
     $146 = (($145) + 28|0);
     HEAP32[$146>>2] = 0;
     $147 = HEAP8[$23>>0]|0;
     $148 = $147&255;
     $149 = HEAP32[$17>>2]|0;
     $150 = (($149) + 12|0);
     HEAP32[$150>>2] = $148;
     if ($27) {
      $151 = $148 | 8;
      HEAP32[$150>>2] = $151;
      if ($$sink) {
       $152 = $148 | 40;
       HEAP32[$150>>2] = $152;
      }
     } else {
      if ($$sink) {
       $153 = $148 | 16;
       HEAP32[$150>>2] = $153;
      }
     }
     $154 = HEAP32[$24>>2]|0;
     $155 = ($154|0)==(0|0);
     if ($155) {
      HEAP32[$24>>2] = $149;
     }
     HEAP32[$13>>2] = $87;
     HEAP8[$16>>0] = 1;
     HEAP8[$25>>0] = 0;
    }
    $156 = HEAP32[$14>>2]|0;
    $157 = HEAP32[$15>>2]|0;
    if ($27) {
     $158 = (_Bezier_Up($worker,3,3758,$156,$157)|0);
     $159 = ($158<<24>>24)==(0);
     if ($159) {
      break;
     } else {
      $$0 = 1;
      label = 43;
      break L1;
     }
    }
    $160 = HEAP32[$1>>2]|0;
    $161 = (($160) + 4|0);
    $162 = HEAP32[$161>>2]|0;
    $163 = (0 - ($162))|0;
    HEAP32[$161>>2] = $163;
    $164 = (($160) + 12|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = (0 - ($165))|0;
    HEAP32[$164>>2] = $166;
    $167 = (($160) + 20|0);
    $168 = HEAP32[$167>>2]|0;
    $169 = (0 - ($168))|0;
    HEAP32[$167>>2] = $169;
    $170 = (($160) + 28|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = (0 - ($171))|0;
    HEAP32[$170>>2] = $172;
    $173 = HEAP8[$16>>0]|0;
    $174 = (0 - ($157))|0;
    $175 = (0 - ($156))|0;
    $176 = (_Bezier_Up($worker,3,3758,$174,$175)|0);
    $177 = ($173<<24>>24)==(0);
    if (!($177)) {
     $178 = HEAP8[$16>>0]|0;
     $179 = ($178<<24>>24)==(0);
     if ($179) {
      $180 = HEAP32[$17>>2]|0;
      $181 = (($180) + 20|0);
      $182 = HEAP32[$181>>2]|0;
      $183 = (0 - ($182))|0;
      HEAP32[$181>>2] = $183;
     }
    }
    $184 = HEAP32[$161>>2]|0;
    $185 = (0 - ($184))|0;
    HEAP32[$161>>2] = $185;
    $186 = ($176<<24>>24)==(0);
    if (!($186)) {
     $$0 = 1;
     label = 43;
     break L1;
    }
   }
  } while(0);
  $187 = HEAP32[$1>>2]|0;
  $188 = ($187>>>0)<($0>>>0);
  if ($188) {
   label = 42;
   break;
  }
  $$phi$trans$insert = (($187) + 28|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$phi$trans$insert21 = (($187) + 20|0);
  $$pre22 = HEAP32[$$phi$trans$insert21>>2]|0;
  $$phi$trans$insert23 = (($187) + 12|0);
  $$pre24 = HEAP32[$$phi$trans$insert23>>2]|0;
  $$phi$trans$insert25 = (($187) + 4|0);
  $$pre26 = HEAP32[$$phi$trans$insert25>>2]|0;
  $$pre28 = HEAP32[$187>>2]|0;
  $28 = $$pre;$29 = $$pre26;$31 = $$pre22;$32 = $$pre24;$36 = $187;$48 = $$pre28;
 }
 if ((label|0) == 12) {
  $110 = (($worker) + 44|0);
  HEAP32[$110>>2] = 99;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 20) {
  $129 = (($worker) + 44|0);
  HEAP32[$129>>2] = 98;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 25) {
  $137 = (($worker) + 44|0);
  HEAP32[$137>>2] = 98;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 42) {
  HEAP32[$2>>2] = $48;
  HEAP32[$5>>2] = $29;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 43) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _Split_Cubic($base) {
 $base = $base|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($base) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($base) + 48|0);
 HEAP32[$2>>2] = $1;
 $3 = (($base) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($base) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$base>>2]|0;
 $8 = (($4) + 1)|0;
 $9 = (($8) + ($7))|0;
 $10 = $9 >> 1;
 HEAP32[$3>>2] = $10;
 $11 = (($6) + 1)|0;
 $12 = (($11) + ($1))|0;
 $13 = $12 >> 1;
 $14 = (($base) + 40|0);
 HEAP32[$14>>2] = $13;
 $15 = (($8) + ($6))|0;
 $16 = $15 >> 1;
 $17 = (($16) + 1)|0;
 $18 = (($17) + ($10))|0;
 $19 = $18 >> 1;
 HEAP32[$5>>2] = $19;
 $20 = (($17) + ($13))|0;
 $21 = $20 >> 1;
 $22 = (($base) + 32|0);
 HEAP32[$22>>2] = $21;
 $23 = (($19) + 1)|0;
 $24 = (($23) + ($21))|0;
 $25 = $24 >> 1;
 HEAP32[$0>>2] = $25;
 $26 = (($base) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($base) + 52|0);
 HEAP32[$28>>2] = $27;
 $29 = (($base) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($base) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($base) + 4|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($30) + 1)|0;
 $36 = (($35) + ($34))|0;
 $37 = $36 >> 1;
 HEAP32[$29>>2] = $37;
 $38 = (($32) + 1)|0;
 $39 = (($38) + ($27))|0;
 $40 = $39 >> 1;
 $41 = (($base) + 44|0);
 HEAP32[$41>>2] = $40;
 $42 = (($35) + ($32))|0;
 $43 = $42 >> 1;
 $44 = (($43) + 1)|0;
 $45 = (($44) + ($37))|0;
 $46 = $45 >> 1;
 HEAP32[$31>>2] = $46;
 $47 = (($44) + ($40))|0;
 $48 = $47 >> 1;
 $49 = (($base) + 36|0);
 HEAP32[$49>>2] = $48;
 $50 = (($46) + 1)|0;
 $51 = (($50) + ($48))|0;
 $52 = $51 >> 1;
 HEAP32[$26>>2] = $52;
 STACKTOP = sp;return;
}
function _Bezier_Up($worker,$degree,$splitter,$miny,$maxy) {
 $worker = $worker|0;
 $degree = $degree|0;
 $splitter = $splitter|0;
 $miny = $miny|0;
 $maxy = $maxy|0;
 var $$0 = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $9 = 0, $arc$0$ph$be = 0, $arc$0$ph20 = 0, $arc$011 = 0, $e$0 = 0, $e$1$ph$be = 0, $e$1$ph17 = 0, $e0$0 = 0, $maxy$ = 0, $or$cond = 0, $or$cond110 = 0, $sext$mask = 0, $top$0 = 0, $top$1 = 0, $top$2$ph$be = 0, $top$2$ph15 = 0, $top$2$ph21 = 0, $top$4 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($worker) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + ($degree<<3)|0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($worker) + 40|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)<($miny|0);
 $9 = ($3|0)>($maxy|0);
 $or$cond = $8 | $9;
 if ($or$cond) {
  $79 = $1;$top$4 = $7;
 } else {
  $10 = (($worker) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (0 - ($11))|0;
  $13 = $5 & $12;
  $14 = ($13|0)>($maxy|0);
  $maxy$ = $14 ? $maxy : $13;
  $15 = ($3|0)<($miny|0);
  if ($15) {
   $e$0 = $miny;$e0$0 = $miny;$top$1 = $7;
  } else {
   $16 = (($3) + -1)|0;
   $17 = (($16) + ($11))|0;
   $18 = $17 & $12;
   $19 = (($11) + 65535)|0;
   $20 = $3 & 65535;
   $sext$mask = $20 & $19;
   $21 = ($sext$mask|0)==(0);
   if ($21) {
    $22 = (($worker) + 87|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = ($23<<24>>24)==(0);
    if ($24) {
     $top$0 = $7;
    } else {
     $25 = (($7) + -4|0);
     HEAP8[$22>>0] = 0;
     $top$0 = $25;
    }
    $26 = (($1) + ($degree<<3)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($top$0) + 4|0);
    HEAP32[$top$0>>2] = $27;
    $29 = (($11) + ($18))|0;
    $e$0 = $29;$e0$0 = $18;$top$1 = $28;
   } else {
    $e$0 = $18;$e0$0 = $18;$top$1 = $7;
   }
  }
  $30 = (($worker) + 86|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)==(0);
  if (!($32)) {
   $33 = HEAP32[$worker>>2]|0;
   $34 = $e0$0 >> $33;
   $35 = (($worker) + 88|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = (($36) + 20|0);
   HEAP32[$37>>2] = $34;
   HEAP8[$30>>0] = 0;
  }
  $38 = ($maxy$|0)<($e$0|0);
  if ($38) {
   $79 = $1;$top$4 = $top$1;
  } else {
   $39 = (($maxy$) - ($e$0))|0;
   $40 = HEAP32[$worker>>2]|0;
   $41 = $39 >> $40;
   $$sum = (($41) + 1)|0;
   $42 = (($top$1) + ($$sum<<2)|0);
   $43 = (($worker) + 36|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($42>>>0)<($44>>>0);
   if (!($45)) {
    HEAP32[$6>>2] = $top$1;
    $49 = (($worker) + 44|0);
    HEAP32[$49>>2] = 98;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $46 = (($worker) + 87|0);
   $47 = (($worker) + 16|0);
   $48 = (0 - ($degree))|0;
   $arc$0$ph20 = $1;$e$1$ph17 = $e$0;$top$2$ph21 = $top$1;
   L18: while(1) {
    $arc$011 = $arc$0$ph20;
    while(1) {
     HEAP8[$46>>0] = 0;
     $50 = (($arc$011) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)>($e$1$ph17|0);
     if (!($52)) {
      label = 19;
      break;
     }
     $53 = (($arc$011) + ($degree<<3)|0);
     $54 = ((($arc$011) + ($degree<<3)|0) + 4|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($51) - ($55))|0;
     $57 = HEAP32[$47>>2]|0;
     $58 = ($56|0)<($57|0);
     if ($58) {
      label = 16;
      break;
     }
     FUNCTION_TABLE_vi[$splitter & 4095]($arc$011);
     $59 = ($53>>>0)<($1>>>0);
     if ($59) {
      $top$2$ph15 = $top$2$ph21;
      break L18;
     } else {
      $arc$011 = $53;
     }
    }
    if ((label|0) == 16) {
     label = 0;
     $60 = HEAP32[$53>>2]|0;
     $61 = HEAP32[$arc$011>>2]|0;
     $62 = (($61) - ($60))|0;
     $63 = (($e$1$ph17) - ($55))|0;
     $64 = Math_imul($62, $63)|0;
     $65 = (($64|0) / ($56|0))&-1;
     $66 = (($65) + ($60))|0;
     $67 = (($top$2$ph21) + 4|0);
     HEAP32[$top$2$ph21>>2] = $66;
     $68 = HEAP32[$10>>2]|0;
     $69 = (($68) + ($e$1$ph17))|0;
     $e$1$ph$be = $69;$top$2$ph$be = $67;
    }
    else if ((label|0) == 19) {
     label = 0;
     $72 = ($51|0)==($e$1$ph17|0);
     if ($72) {
      HEAP8[$46>>0] = 1;
      $73 = HEAP32[$arc$011>>2]|0;
      $74 = (($top$2$ph21) + 4|0);
      HEAP32[$top$2$ph21>>2] = $73;
      $75 = HEAP32[$10>>2]|0;
      $76 = (($75) + ($e$1$ph17))|0;
      $e$1$ph$be = $76;$top$2$ph$be = $74;
     } else {
      $e$1$ph$be = $e$1$ph17;$top$2$ph$be = $top$2$ph21;
     }
    }
    $arc$0$ph$be = (($arc$011) + ($48<<3)|0);
    $70 = ($arc$0$ph$be>>>0)<($1>>>0);
    $71 = ($e$1$ph$be|0)>($maxy$|0);
    $or$cond110 = $70 | $71;
    if ($or$cond110) {
     $top$2$ph15 = $top$2$ph$be;
     break;
    } else {
     $arc$0$ph20 = $arc$0$ph$be;$e$1$ph17 = $e$1$ph$be;$top$2$ph21 = $top$2$ph$be;
    }
   }
   $$pre = HEAP32[$0>>2]|0;
   $79 = $$pre;$top$4 = $top$2$ph15;
  }
 }
 HEAP32[$6>>2] = $top$4;
 $77 = (0 - ($degree))|0;
 $78 = (($79) + ($77<<3)|0);
 HEAP32[$0>>2] = $78;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _Split_Conic($base) {
 $base = $base|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($base) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($base) + 32|0);
 HEAP32[$2>>2] = $1;
 $3 = (($base) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + ($4))|0;
 $6 = (($5|0) / 2)&-1;
 $7 = (($base) + 24|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$base>>2]|0;
 $9 = (($8) + ($4))|0;
 $10 = (($9|0) / 2)&-1;
 HEAP32[$3>>2] = $10;
 $11 = (($10) + ($6))|0;
 $12 = (($11|0) / 2)&-1;
 HEAP32[$0>>2] = $12;
 $13 = (($base) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($base) + 36|0);
 HEAP32[$15>>2] = $14;
 $16 = (($base) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($14) + ($17))|0;
 $19 = (($18|0) / 2)&-1;
 $20 = (($base) + 28|0);
 HEAP32[$20>>2] = $19;
 $21 = (($base) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + ($17))|0;
 $24 = (($23|0) / 2)&-1;
 HEAP32[$16>>2] = $24;
 $25 = (($24) + ($19))|0;
 $26 = (($25|0) / 2)&-1;
 HEAP32[$13>>2] = $26;
 STACKTOP = sp;return;
}
function _Line_Up($worker,$x1,$y1,$x2,$y2,$miny,$maxy) {
 $worker = $worker|0;
 $x1 = $x1|0;
 $y1 = $y1|0;
 $x2 = $x2|0;
 $y2 = $y2|0;
 $miny = $miny|0;
 $maxy = $maxy|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$23 = 0, $$3 = 0, $$pn = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $Ax$05 = 0, $Ax$1 = 0, $Dx$0 = 0, $Ix$0 = 0, $Rx$0 = 0, $e1$0 = 0, $e1$1 = 0, $e2$0 = 0, $f1$0 = 0, $f2$0 = 0;
 var $maxy$pn = 0, $or$cond = 0, $or$cond2 = 0, $scevgep = 0, $size$04 = 0, $smax = 0, $top$0$lcssa = 0, $top$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($x2) - ($x1))|0;
 $1 = (($y2) - ($y1))|0;
 $2 = ($1|0)<(1);
 $3 = ($y2|0)<($miny|0);
 $or$cond = $2 | $3;
 $4 = ($y1|0)>($maxy|0);
 $or$cond2 = $or$cond | $4;
 if ($or$cond2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($y1|0)<($miny|0);
 if ($5) {
  $6 = (($miny) - ($y1))|0;
  $7 = (_FT_MulDiv($0,$6,$1)|0);
  $8 = (($7) + ($x1))|0;
  $9 = HEAP32[$worker>>2]|0;
  $10 = $miny >> $9;
  $$01 = $8;$22 = $9;$e1$0 = $10;$f1$0 = 0;
 } else {
  $11 = HEAP32[$worker>>2]|0;
  $12 = $y1 >> $11;
  $13 = (($worker) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = $15 & $y1;
  $$01 = $x1;$22 = $11;$e1$0 = $12;$f1$0 = $16;
 }
 $17 = ($y2|0)>($maxy|0);
 if ($17) {
  $f2$0 = 0;$maxy$pn = $maxy;
 } else {
  $18 = (($worker) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + -1)|0;
  $21 = $20 & $y2;
  $f2$0 = $21;$maxy$pn = $y2;
 }
 $e2$0 = $maxy$pn >> $22;
 $23 = ($f1$0|0)>(0);
 do {
  if ($23) {
   $24 = ($e1$0|0)==($e2$0|0);
   if ($24) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $25 = (($worker) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($26) - ($f1$0))|0;
    $28 = (_FT_MulDiv($0,$27,$1)|0);
    $29 = (($28) + ($$01))|0;
    $30 = (($e1$0) + 1)|0;
    $$pre = (($worker) + 87|0);
    $$1 = $29;$$pre$phiZ2D = $$pre;$e1$1 = $30;
    break;
   }
  } else {
   $31 = (($worker) + 87|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = ($32<<24>>24)==(0);
   if ($33) {
    $$1 = $$01;$$pre$phiZ2D = $31;$e1$1 = $e1$0;
   } else {
    $34 = (($worker) + 40|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($35) + -4|0);
    HEAP32[$34>>2] = $36;
    HEAP8[$31>>0] = 0;
    $$1 = $$01;$$pre$phiZ2D = $31;$e1$1 = $e1$0;
   }
  }
 } while(0);
 $37 = ($f2$0|0)==(0);
 $38 = $37&1;
 HEAP8[$$pre$phiZ2D>>0] = $38;
 $39 = (($worker) + 86|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = ($40<<24>>24)==(0);
 if (!($41)) {
  $42 = (($worker) + 88|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 20|0);
  HEAP32[$44>>2] = $e1$1;
  HEAP8[$39>>0] = 0;
 }
 $45 = (($e2$0) - ($e1$1))|0;
 $46 = (($45) + 1)|0;
 $47 = (($worker) + 40|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($46<<2)|0);
 $50 = (($worker) + 36|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($49>>>0)<($51>>>0);
 if (!($52)) {
  $53 = (($worker) + 44|0);
  HEAP32[$53>>2] = 98;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $54 = ($0|0)>(0);
 $55 = (($worker) + 4|0);
 $56 = HEAP32[$55>>2]|0;
 if ($54) {
  $57 = (_FT_MulDiv($56,$0,$1)|0);
  $58 = HEAP32[$55>>2]|0;
  $59 = Math_imul($58, $0)|0;
  $$pn = $59;$Dx$0 = 1;$Ix$0 = $57;
 } else {
  $60 = (0 - ($0))|0;
  $61 = (_FT_MulDiv($56,$60,$1)|0);
  $62 = (0 - ($61))|0;
  $63 = HEAP32[$55>>2]|0;
  $64 = Math_imul($63, $60)|0;
  $$pn = $64;$Dx$0 = -1;$Ix$0 = $62;
 }
 $Rx$0 = (($$pn|0) % ($1|0))&-1;
 $65 = HEAP32[$47>>2]|0;
 $66 = ($45|0)>(-1);
 if ($66) {
  $67 = (0 - ($1))|0;
  $68 = (($e1$1) + -1)|0;
  $69 = (($68) - ($e2$0))|0;
  $70 = ($69|0)>(-1);
  $smax = $70 ? $69 : -1;
  $71 = (($e2$0) + ($smax))|0;
  $72 = (($71) + 2)|0;
  $73 = (($72) - ($e1$1))|0;
  $$23 = $$1;$Ax$05 = $67;$size$04 = $46;$top$06 = $65;
  while(1) {
   $74 = (($top$06) + 4|0);
   HEAP32[$top$06>>2] = $$23;
   $75 = (($$23) + ($Ix$0))|0;
   $76 = (($Ax$05) + ($Rx$0))|0;
   $77 = ($76|0)>(-1);
   if ($77) {
    $78 = (($76) - ($1))|0;
    $79 = (($75) + ($Dx$0))|0;
    $$3 = $79;$Ax$1 = $78;
   } else {
    $$3 = $75;$Ax$1 = $76;
   }
   $80 = (($size$04) + -1)|0;
   $81 = ($80|0)>(0);
   if ($81) {
    $$23 = $$3;$Ax$05 = $Ax$1;$size$04 = $80;$top$06 = $74;
   } else {
    break;
   }
  }
  $scevgep = (($65) + ($73<<2)|0);
  $top$0$lcssa = $scevgep;
 } else {
  $top$0$lcssa = $65;
 }
 HEAP32[$47>>2] = $top$0$lcssa;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _FT_Destroy_Class_ft_raster1_renderer_class($library,$clazz) {
 $library = $library|0;
 $clazz = $clazz|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 _ft_raster1_renderer_class_pic_free($library);
 $1 = ($clazz|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$clazz);
 STACKTOP = sp;return;
}
function _FT_Create_Class_ft_raster1_renderer_class($library,$output_class) {
 $library = $library|0;
 $output_class = $output_class|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,60,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (_ft_raster1_renderer_class_pic_init($library)|0);
 HEAP32[$error>>2] = $4;
 $5 = ($4|0)==(0);
 if ($5) {
  HEAP32[$1>>2] = 2;
  $7 = (($1) + 4|0);
  HEAP32[$7>>2] = 72;
  $8 = (($1) + 8|0);
  HEAP32[$8>>2] = 873720;
  $9 = (($1) + 12|0);
  HEAP32[$9>>2] = 65536;
  $10 = (($1) + 16|0);
  HEAP32[$10>>2] = 131072;
  $11 = (($1) + 20|0);
  HEAP32[$11>>2] = 0;
  $12 = (($1) + 24|0);
  HEAP32[$12>>2] = 3445;
  $13 = (($1) + 28|0);
  HEAP32[$13>>2] = 0;
  $14 = (($1) + 32|0);
  HEAP32[$14>>2] = 0;
  $15 = (($1) + 36|0);
  HEAP32[$15>>2] = 1869968492;
  $16 = (($1) + 40|0);
  HEAP32[$16>>2] = 295;
  $17 = (($1) + 44|0);
  HEAP32[$17>>2] = 296;
  $18 = (($1) + 48|0);
  HEAP32[$18>>2] = 2075;
  $19 = (($1) + 52|0);
  HEAP32[$19>>2] = 1629;
  $20 = (($library) + 216|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($21) + 4|0);
  $23 = (($1) + 56|0);
  HEAP32[$23>>2] = $22;
  HEAP32[$output_class>>2] = $1;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  _ft_mem_free($0,$1);
  $6 = HEAP32[$error>>2]|0;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _ft_raster1_init($render) {
 $render = $render|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($render) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($render) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($render) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($1) + 172|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($1) + 176|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viii[$7 & 4095]($9,$11,$13);
 STACKTOP = sp;return 0;
}
function _ft_raster1_render($render,$slot,$mode,$origin) {
 $render = $render|0;
 $slot = $slot|0;
 $mode = $mode|0;
 $origin = $origin|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $cbox = 0, $error = 0, $or$cond = 0, $params = 0, $pitch$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $error = sp + 64|0;
 $cbox = sp;
 $params = sp + 16|0;
 $0 = (($slot) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($render) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  HEAP32[$error>>2] = 6;
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($mode|0)==(2);
 $6 = (($render) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 6|0);
 $11 = HEAP8[$10>>0]|0;
 if ($5) {
  $13 = ($11<<24>>24)==(53);
  if ($13) {
   $$0 = 19;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $12 = ($11<<24>>24)==(49);
  if ($12) {
   $$0 = 19;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $14 = (($slot) + 108|0);
 $15 = ($origin|0)==(0|0);
 if (!($15)) {
  $16 = HEAP32[$origin>>2]|0;
  $17 = (($origin) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  _FT_Outline_Translate($14,$16,$18);
 }
 _FT_Outline_Get_CBox($14,$cbox);
 $19 = HEAP32[$cbox>>2]|0;
 $20 = (($19) + 32)|0;
 $21 = $20 & -64;
 HEAP32[$cbox>>2] = $21;
 $22 = (($cbox) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + 32)|0;
 $25 = $24 & -64;
 HEAP32[$22>>2] = $25;
 $26 = (($cbox) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 32)|0;
 $29 = $28 & -64;
 HEAP32[$26>>2] = $29;
 $30 = (($cbox) + 12|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 32)|0;
 $33 = $32 & -64;
 HEAP32[$30>>2] = $33;
 $34 = (($29) - ($21))|0;
 $35 = $34 >> 6;
 $36 = (($33) - ($25))|0;
 $37 = $36 >> 6;
 $38 = ($35>>>0)>(65535);
 $39 = ($37>>>0)>(65535);
 $or$cond = $38 | $39;
 if ($or$cond) {
  HEAP32[$error>>2] = 6;
  $$0 = 6;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = (($slot) + 76|0);
 $41 = (($render) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($slot) + 156|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 & 1;
 $48 = ($47|0)==(0);
 if (!($48)) {
  $49 = (($slot) + 88|0);
  $50 = HEAP32[$49>>2]|0;
  _ft_mem_free($42,$50);
  HEAP32[$49>>2] = 0;
  $51 = HEAP32[$43>>2]|0;
  $52 = (($51) + 4|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = $53 & -2;
  HEAP32[$52>>2] = $54;
 }
 $55 = $mode & 2;
 $56 = ($55|0)==(0);
 if ($56) {
  $57 = (($35) + 3)|0;
  $58 = $57 & -4;
  $59 = (($slot) + 94|0);
  HEAP8[$59>>0] = 2;
  $60 = (($slot) + 92|0);
  HEAP16[$60>>1] = 256;
  $pitch$0 = $58;
 } else {
  $61 = (($35) + 15)|0;
  $62 = $61 >>> 4;
  $63 = $62 << 1;
  $64 = (($slot) + 94|0);
  HEAP8[$64>>0] = 1;
  $pitch$0 = $63;
 }
 $65 = (($slot) + 80|0);
 HEAP32[$65>>2] = $35;
 HEAP32[$40>>2] = $37;
 $66 = (($slot) + 84|0);
 HEAP32[$66>>2] = $pitch$0;
 $67 = (_ft_mem_realloc($42,$37,0,$pitch$0,0,$error)|0);
 $68 = (($slot) + 88|0);
 HEAP32[$68>>2] = $67;
 $69 = HEAP32[$error>>2]|0;
 $70 = ($69|0)==(0);
 if (!($70)) {
  $$0 = $69;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = HEAP32[$43>>2]|0;
 $72 = (($71) + 4|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73 | 1;
 HEAP32[$72>>2] = $74;
 $75 = HEAP32[$cbox>>2]|0;
 $76 = (0 - ($75))|0;
 $77 = HEAP32[$22>>2]|0;
 $78 = (0 - ($77))|0;
 _FT_Outline_Translate($14,$76,$78);
 HEAP32[$params>>2] = $40;
 $79 = (($params) + 4|0);
 HEAP32[$79>>2] = $14;
 $80 = (($params) + 8|0);
 $81 = (($slot) + 94|0);
 $82 = HEAP8[$81>>0]|0;
 $83 = ($82<<24>>24)==(2);
 $$ = $83&1;
 HEAP32[$80>>2] = $$;
 $84 = (($render) + 64|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = (($render) + 60|0);
 $87 = HEAP32[$86>>2]|0;
 $88 = (FUNCTION_TABLE_iii[$85 & 4095]($87,$params)|0);
 HEAP32[$error>>2] = $88;
 $89 = HEAP32[$cbox>>2]|0;
 $90 = HEAP32[$22>>2]|0;
 _FT_Outline_Translate($14,$89,$90);
 $91 = HEAP32[$error>>2]|0;
 $92 = ($91|0)==(0);
 if (!($92)) {
  $$0 = $91;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = 1651078259;
 $93 = HEAP32[$cbox>>2]|0;
 $94 = $93 >> 6;
 $95 = (($slot) + 100|0);
 HEAP32[$95>>2] = $94;
 $96 = HEAP32[$30>>2]|0;
 $97 = $96 >> 6;
 $98 = (($slot) + 104|0);
 HEAP32[$98>>2] = $97;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _ft_raster1_transform($render,$slot,$matrix,$delta) {
 $render = $render|0;
 $slot = $slot|0;
 $matrix = $matrix|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($slot) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($render) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  $error$0 = 6;
  STACKTOP = sp;return ($error$0|0);
 }
 $5 = ($matrix|0)==(0|0);
 if (!($5)) {
  $6 = (($slot) + 108|0);
  _FT_Outline_Transform($6,$matrix);
 }
 $7 = ($delta|0)==(0|0);
 if ($7) {
  $error$0 = 0;
  STACKTOP = sp;return ($error$0|0);
 }
 $8 = (($slot) + 108|0);
 $9 = HEAP32[$delta>>2]|0;
 $10 = (($delta) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 _FT_Outline_Translate($8,$9,$11);
 $error$0 = 0;
 STACKTOP = sp;return ($error$0|0);
}
function _ft_raster1_get_cbox($render,$slot,$cbox) {
 $render = $render|0;
 $slot = $slot|0;
 $cbox = $cbox|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$cbox+0>>2]=0|0;HEAP32[$cbox+4>>2]=0|0;HEAP32[$cbox+8>>2]=0|0;HEAP32[$cbox+12>>2]=0|0;
 $0 = (($slot) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($render) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($slot) + 108|0);
 _FT_Outline_Get_CBox($5,$cbox);
 STACKTOP = sp;return;
}
function _ft_raster1_set_mode($render,$mode_tag,$data) {
 $render = $render|0;
 $mode_tag = $mode_tag|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($render) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 56|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($render) + 60|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($7,$mode_tag,$data)|0);
 STACKTOP = sp;return ($8|0);
}
function _ft_raster1_renderer_class_pic_free($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 $1 = (($library) + 216|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$2>>2] = $5;
 $6 = ($5|0)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$2);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function _ft_raster1_renderer_class_pic_init($library) {
 $library = $library|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = (($library) + 216|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 1)|0;
  HEAP32[$1>>2] = $4;
  $5 = HEAP32[$error>>2]|0;
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$library>>2]|0;
 $7 = (_ft_mem_alloc($6,28,$error)|0);
 $8 = HEAP32[$error>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;HEAP32[$7+24>>2]=0|0;
 HEAP32[$0>>2] = $7;
 HEAP32[$7>>2] = 1;
 $10 = (($7) + 4|0);
 _FT_Init_Class_ft_standard_raster($10);
 $11 = HEAP32[$error>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $13 = HEAP32[$library>>2]|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   $16 = HEAP32[$14>>2]|0;
   $17 = (($16) + -1)|0;
   HEAP32[$14>>2] = $17;
   $18 = ($17|0)==(0);
   if ($18) {
    _ft_mem_free($13,$14);
    HEAP32[$0>>2] = 0;
   }
  }
 }
 $19 = HEAP32[$error>>2]|0;
 $$0 = $19;
 STACKTOP = sp;return ($$0|0);
}
function _ft_pic_container_init($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($library) + 196|0);
 dest=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $1 = (_ft_base_pic_init($library)|0);
 STACKTOP = sp;return ($1|0);
}
function _ft_pic_container_destroy($library) {
 $library = $library|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _ft_base_pic_free($library);
 STACKTOP = sp;return;
}
function _ft_base_pic_free($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($library) + 196|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$library>>2]|0;
 _ft_destroy_default_module_classes($library);
 $4 = HEAP32[$0>>2]|0;
 _ft_mem_free($3,$4);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function _ft_base_pic_init($library) {
 $library = $library|0;
 var $$0 = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,68,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 dest=$1+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $4 = (($library) + 196|0);
 HEAP32[$4>>2] = $1;
 $5 = (_ft_create_default_module_classes($library)|0);
 HEAP32[$error>>2] = $5;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (($1) + 4|0);
  _FT_Init_Class_ft_outline_glyph_class($7);
  $8 = (($1) + 36|0);
  _FT_Init_Class_ft_bitmap_glyph_class($8);
  $$pr = HEAP32[$error>>2]|0;
  $9 = ($$pr|0)==(0);
  if ($9) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $14 = $$pr;
  }
 } else {
  $14 = $5;
 }
 $10 = HEAP32[$4>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[$library>>2]|0;
 _ft_destroy_default_module_classes($library);
 $13 = HEAP32[$4>>2]|0;
 _ft_mem_free($12,$13);
 HEAP32[$4>>2] = 0;
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _cff_driver_class_pic_free($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 $1 = (($library) + 204|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  _FT_Destroy_Class_cff_services($library,$4);
 }
 HEAP32[$2>>2] = 0;
 $6 = (($2) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  _FT_Destroy_Class_cff_field_handlers($library,$7);
 }
 HEAP32[$6>>2] = 0;
 _ft_mem_free($0,$2);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function _cff_driver_class_pic_init($library) {
 $library = $library|0;
 var $$0 = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,136,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 _memset(($1|0),0,136)|0;
 $4 = (($library) + 204|0);
 HEAP32[$4>>2] = $1;
 $5 = (_FT_Create_Class_cff_services($library,$1)|0);
 HEAP32[$error>>2] = $5;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (($1) + 4|0);
  $8 = (_FT_Create_Class_cff_field_handlers($library,$7)|0);
  HEAP32[$error>>2] = $8;
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = (($1) + 8|0);
   _FT_Init_Class_cff_service_ps_info($library,$10);
   $11 = (($1) + 28|0);
   _FT_Init_Class_cff_service_glyph_dict($library,$11);
   $12 = (($1) + 36|0);
   _FT_Init_Class_cff_service_ps_name($library,$12);
   $13 = (($1) + 40|0);
   _FT_Init_Class_cff_service_get_cmap_info($library,$13);
   $14 = (($1) + 44|0);
   _FT_Init_Class_cff_service_cid_info($library,$14);
   $15 = (($1) + 56|0);
   _FT_Init_Class_cff_cmap_encoding_class_rec($library,$15);
   $16 = (($1) + 96|0);
   _FT_Init_Class_cff_cmap_unicode_class_rec($library,$16);
   $$pr = HEAP32[$error>>2]|0;
   $17 = ($$pr|0)==(0);
   if ($17) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $26 = $$pr;
   }
  } else {
   $26 = $8;
  }
 } else {
  $26 = $5;
 }
 $18 = HEAP32[$library>>2]|0;
 $19 = HEAP32[$4>>2]|0;
 $20 = ($19|0)==(0|0);
 if ($20) {
  $$0 = $26;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = HEAP32[$19>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  _FT_Destroy_Class_cff_services($library,$21);
 }
 HEAP32[$19>>2] = 0;
 $23 = (($19) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  _FT_Destroy_Class_cff_field_handlers($library,$24);
 }
 HEAP32[$23>>2] = 0;
 _ft_mem_free($18,$19);
 HEAP32[$4>>2] = 0;
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _sfnt_module_class_pic_free($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 $1 = (($library) + 220|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  _FT_Destroy_Class_sfnt_services($library,$4);
 }
 HEAP32[$2>>2] = 0;
 $6 = (($2) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  _FT_Destroy_Class_tt_cmap_classes($library,$7);
 }
 HEAP32[$6>>2] = 0;
 _ft_mem_free($0,$2);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function _sfnt_module_class_pic_init($library) {
 $library = $library|0;
 var $$0 = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,196,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 _memset(($1|0),0,196)|0;
 $4 = (($library) + 220|0);
 HEAP32[$4>>2] = $1;
 $5 = (_FT_Create_Class_sfnt_services($library,$1)|0);
 HEAP32[$error>>2] = $5;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (($1) + 20|0);
  $8 = (_FT_Create_Class_tt_cmap_classes($library,$7)|0);
  HEAP32[$error>>2] = $8;
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = (($1) + 4|0);
   _FT_Init_Class_sfnt_service_glyph_dict($library,$10);
   $11 = (($1) + 12|0);
   _FT_Init_Class_sfnt_service_ps_name($library,$11);
   $12 = (($1) + 16|0);
   _FT_Init_Class_tt_service_get_cmap_info($library,$12);
   $13 = (($1) + 24|0);
   _FT_Init_Class_sfnt_service_sfnt_table($13);
   $14 = (($1) + 36|0);
   _FT_Init_Class_sfnt_interface($library,$14);
   $$pr = HEAP32[$error>>2]|0;
   $15 = ($$pr|0)==(0);
   if ($15) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $24 = $$pr;
   }
  } else {
   $24 = $8;
  }
 } else {
  $24 = $5;
 }
 $16 = HEAP32[$library>>2]|0;
 $17 = HEAP32[$4>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $$0 = $24;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = HEAP32[$17>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  _FT_Destroy_Class_sfnt_services($library,$19);
 }
 HEAP32[$17>>2] = 0;
 $21 = (($17) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  _FT_Destroy_Class_tt_cmap_classes($library,$22);
 }
 HEAP32[$21>>2] = 0;
 _ft_mem_free($16,$17);
 HEAP32[$4>>2] = 0;
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function _ft_smooth_renderer_class_pic_free($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 $1 = (($library) + 224|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = (($4) + -1)|0;
 HEAP32[$2>>2] = $5;
 $6 = ($5|0)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 _ft_mem_free($0,$2);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function _ft_smooth_renderer_class_pic_init($library) {
 $library = $library|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $error = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = (($library) + 224|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$1>>2]|0;
  $4 = (($3) + 1)|0;
  HEAP32[$1>>2] = $4;
  $5 = HEAP32[$error>>2]|0;
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[$library>>2]|0;
 $7 = (_ft_mem_alloc($6,28,$error)|0);
 $8 = HEAP32[$error>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;HEAP32[$7+12>>2]=0|0;HEAP32[$7+16>>2]=0|0;HEAP32[$7+20>>2]=0|0;HEAP32[$7+24>>2]=0|0;
 HEAP32[$0>>2] = $7;
 HEAP32[$7>>2] = 1;
 $10 = (($7) + 4|0);
 _FT_Init_Class_ft_grays_raster($10);
 $11 = HEAP32[$error>>2]|0;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $13 = HEAP32[$library>>2]|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = ($14|0)==(0|0);
  if (!($15)) {
   $16 = HEAP32[$14>>2]|0;
   $17 = (($16) + -1)|0;
   HEAP32[$14>>2] = $17;
   $18 = ($17|0)==(0);
   if ($18) {
    _ft_mem_free($13,$14);
    HEAP32[$0>>2] = 0;
   }
  }
 }
 $19 = HEAP32[$error>>2]|0;
 $$0 = $19;
 STACKTOP = sp;return ($$0|0);
}
function _tt_driver_class_pic_free($library) {
 $library = $library|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$library>>2]|0;
 $1 = (($library) + 228|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  _FT_Destroy_Class_tt_services($library,$4);
 }
 HEAP32[$2>>2] = 0;
 _ft_mem_free($0,$2);
 HEAP32[$1>>2] = 0;
 STACKTOP = sp;return;
}
function _tt_driver_class_pic_init($library) {
 $library = $library|0;
 var $$0 = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $error = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $error = sp;
 HEAP32[$error>>2] = 0;
 $0 = HEAP32[$library>>2]|0;
 $1 = (_ft_mem_alloc($0,28,$error)|0);
 $2 = HEAP32[$error>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;HEAP32[$1+24>>2]=0|0;
 $4 = (($library) + 228|0);
 HEAP32[$4>>2] = $1;
 $5 = (_FT_Create_Class_tt_services($library,$1)|0);
 HEAP32[$error>>2] = $5;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (($1) + 4|0);
  _FT_Init_Class_tt_service_gx_multi_masters($7);
  $8 = (($1) + 24|0);
  _FT_Init_Class_tt_service_truetype_glyf($8);
  $$pr = HEAP32[$error>>2]|0;
  $9 = ($$pr|0)==(0);
  if ($9) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $15 = $$pr;
  }
 } else {
  $15 = $5;
 }
 $10 = HEAP32[$library>>2]|0;
 $11 = HEAP32[$4>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[$11>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  _FT_Destroy_Class_tt_services($library,$13);
 }
 HEAP32[$11>>2] = 0;
 _ft_mem_free($10,$11);
 HEAP32[$4>>2] = 0;
 $$pre = HEAP32[$error>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function __Z27Font_Get_Custom_PropDynamicP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject($self_)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   $3 = $self_;
  } else {
   $4 = (($1) + 76|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(-2);
   $7 = $6&1;
   STACKTOP = sp;return ($7|0);
  }
 }
 __ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject($3);
 // unreachable;
 return 0|0;
}
function __Z25TextGenerator_CUSTOM_InitP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(68)|0);
 HEAP32[$0>>2] = 0;
 $1 = (($0) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($0) + 4|0);
 HEAP32[$3>>2] = 61;
 $4 = (($0) + 16|0);
 HEAP32[$4>>2] = 0;
 $5 = (($0) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($0) + 28|0);
 HEAP32[$6>>2] = 0;
 $7 = (($0) + 20|0);
 HEAP32[$7>>2] = 61;
 $8 = (($0) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = (($0) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = (($0) + 44|0);
 HEAP32[$10>>2] = 0;
 $11 = (($0) + 36|0);
 HEAP32[$11>>2] = 61;
 $12 = (($0) + 48|0);
 HEAP8[$12>>0] = 0;
 $13 = (($0) + 52|0);
 ;HEAP32[$13+0>>2]=0|0;HEAP32[$13+4>>2]=0|0;HEAP32[$13+8>>2]=0|0;HEAP32[$13+12>>2]=0|0;
 $14 = (($self_) + 8|0);
 HEAP32[$14>>2] = $0;
 STACKTOP = sp;return;
}
function __Z32TextGenerator_CUSTOM_Dispose_cppP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($self_) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3759,($2|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZdlPv($2);
  ___resumeException($6|0);
  // unreachable;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __Z56TextGenerator_CUSTOM_INTERNAL_CALL_Populate_Internal_cppP15ScriptingObjectP15ScriptingStringS0_RK10ColorRGBAfifihhiiiihiffffh($self_,$str_,$font_,$color,$fontSize,$lineSpacing,$style,$richText,$resizeTextForBestFit,$resizeTextMinSize,$resizeTextMaxSize,$verticalOverFlow,$horizontalOverflow,$updateBounds,$anchor,$extentsX,$extentsY,$pivotX,$pivotY,$generateOutOfBounds) {
 $self_ = $self_|0;
 $str_ = $str_|0;
 $font_ = $font_|0;
 $color = $color|0;
 $fontSize = $fontSize|0;
 $lineSpacing = Math_fround($lineSpacing);
 $style = $style|0;
 $richText = $richText|0;
 $resizeTextForBestFit = $resizeTextForBestFit|0;
 $resizeTextMinSize = $resizeTextMinSize|0;
 $resizeTextMaxSize = $resizeTextMaxSize|0;
 $verticalOverFlow = $verticalOverFlow|0;
 $horizontalOverflow = $horizontalOverflow|0;
 $updateBounds = $updateBounds|0;
 $anchor = $anchor|0;
 $extentsX = Math_fround($extentsX);
 $extentsY = Math_fround($extentsY);
 $pivotX = Math_fround($pivotX);
 $pivotY = Math_fround($pivotY);
 $generateOutOfBounds = $generateOutOfBounds|0;
 var $$0$i$i = 0, $$byval_copy = 0, $$op$i$i$i$i = Math_fround(0), $$op$i1$i$i$i = Math_fround(0), $$op$i2$i$i$i = Math_fround(0), $$op$i3$i$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = Math_fround(0), $45 = 0, $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $extents = 0;
 var $pivot = 0, $str = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp;
 $str = sp + 40|0;
 $extents = sp + 8|0;
 $pivot = sp + 16|0;
 $0 = sp + 24|0;
 $1 = sp + 36|0;
 __ZN11ICallStringC2EPv($str,$str_);
 HEAPF32[$extents>>2] = $extentsX;
 $2 = (($extents) + 4|0);
 HEAPF32[$2>>2] = $extentsY;
 HEAPF32[$pivot>>2] = $pivotX;
 $3 = (($pivot) + 4|0);
 HEAPF32[$3>>2] = $pivotY;
 $4 = ($self_|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$$byval_copy);
  // unreachable;
 }
 $5 = (($self_) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$$byval_copy);
  // unreachable;
 }
 __ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv($0,$str);
 $8 = ($font_|0)==(0|0);
 if ($8) {
  $$0$i$i = 0;
  label = 8;
 } else {
  __THREW__ = 0;
  $9 = (invoke_ii(3327,($font_|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = ($9|0)==(0|0);
   if ($12) {
    $$0$i$i = 0;
    label = 8;
   } else {
    $$0$i$i = $9;
    label = 8;
   }
  }
 }
 if ((label|0) == 8) {
  $13 = Math_fround(HEAPF32[$color>>2]);
  $14 = $13 < Math_fround(0.0);
  $15 = $14 ? Math_fround(0.0) : $13;
  $16 = $15 > Math_fround(1.0);
  $$op$i$i$i$i = Math_fround($15 * Math_fround(255.0));
  $17 = $16 ? Math_fround(255.0) : $$op$i$i$i$i;
  $18 = Math_fround($17 + Math_fround(0.5));
  $19 = (~~(($18))>>>0);
  $20 = $19&255;
  HEAP8[$1>>0] = $20;
  $21 = (($color) + 4|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = $22 < Math_fround(0.0);
  $24 = $23 ? Math_fround(0.0) : $22;
  $25 = $24 > Math_fround(1.0);
  $$op$i3$i$i$i = Math_fround($24 * Math_fround(255.0));
  $26 = $25 ? Math_fround(255.0) : $$op$i3$i$i$i;
  $27 = Math_fround($26 + Math_fround(0.5));
  $28 = (~~(($27))>>>0);
  $29 = $28&255;
  $30 = (($1) + 1|0);
  HEAP8[$30>>0] = $29;
  $31 = (($color) + 8|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = $32 < Math_fround(0.0);
  $34 = $33 ? Math_fround(0.0) : $32;
  $35 = $34 > Math_fround(1.0);
  $$op$i2$i$i$i = Math_fround($34 * Math_fround(255.0));
  $36 = $35 ? Math_fround(255.0) : $$op$i2$i$i$i;
  $37 = Math_fround($36 + Math_fround(0.5));
  $38 = (~~(($37))>>>0);
  $39 = $38&255;
  $40 = (($1) + 2|0);
  HEAP8[$40>>0] = $39;
  $41 = (($color) + 12|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = $42 < Math_fround(0.0);
  $44 = $43 ? Math_fround(0.0) : $42;
  $45 = $44 > Math_fround(1.0);
  $$op$i1$i$i$i = Math_fround($44 * Math_fround(255.0));
  $46 = $45 ? Math_fround(255.0) : $$op$i1$i$i$i;
  $47 = Math_fround($46 + Math_fround(0.5));
  $48 = (~~(($47))>>>0);
  $49 = $48&255;
  $50 = (($1) + 3|0);
  HEAP8[$50>>0] = $49;
  $51 = ($richText<<24>>24)!=(0);
  $52 = ($resizeTextForBestFit<<24>>24)!=(0);
  $53 = ($updateBounds<<24>>24)!=(0);
  $54 = ($generateOutOfBounds<<24>>24)!=(0);
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_viiiiifiiiiiiiiiiiii(1,($6|0),($0|0),($$0$i$i|0),($$byval_copy|0),($fontSize|0),(+$lineSpacing),($style|0),($51|0),($52|0),($resizeTextMinSize|0),($resizeTextMaxSize|0),($verticalOverFlow|0),($horizontalOverflow|0),($53|0),($anchor|0),($extents|0),($pivot|0),0,($54|0));
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if (!($56)) {
   $57 = HEAP8[$0>>0]|0;
   $58 = $57 & 1;
   $59 = ($58<<24>>24)==(0);
   if (!($59)) {
    $60 = (($0) + 8|0);
    $61 = HEAP32[$60>>2]|0;
    __ZdlPv($61);
   }
   $62 = HEAP32[$5>>2]|0;
   $63 = ($62|0)==(0|0);
   if ($63) {
    __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$$byval_copy);
    // unreachable;
   } else {
    $64 = (($62) + 48|0);
    $65 = HEAP8[$64>>0]|0;
    STACKTOP = sp;return ($65|0);
   }
  }
 }
 $66 = ___cxa_find_matching_catch()|0;
 $67 = tempRet0;
 $68 = HEAP8[$0>>0]|0;
 $69 = $68 & 1;
 $70 = ($69<<24>>24)==(0);
 if ($70) {
  ___resumeException($66|0);
  // unreachable;
 }
 $71 = (($0) + 8|0);
 $72 = HEAP32[$71>>2]|0;
 __ZdlPv($72);
 ___resumeException($66|0);
 // unreachable;
 return 0|0;
}
function __Z40TextGenerator_Get_Custom_PropRectExtentsP15ScriptingObject($agg$result,$self_) {
 $agg$result = $agg$result|0;
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 HEAPF32[$agg$result>>2] = Math_fround(0.0);
 $0 = (($agg$result) + 4|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = ($self_|0)==(0|0);
 if ($1) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer);
  // unreachable;
 }
 $2 = (($self_) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer);
  // unreachable;
 } else {
  $5 = (($3) + 52|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($agg$result) + 8|0);
  HEAPF32[$7>>2] = $6;
  $8 = (($3) + 56|0);
  $9 = Math_fround(HEAPF32[$8>>2]);
  $10 = (($agg$result) + 12|0);
  HEAPF32[$10>>2] = $9;
  STACKTOP = sp;return;
 }
}
function __Z40TextGenerator_Get_Custom_PropVertexCountP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 48|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $9 = 0;
    STACKTOP = sp;return ($9|0);
   }
   $7 = (($2) + 60|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8;
   STACKTOP = sp;return ($9|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z40TextGenerator_CUSTOM_GetVerticesInternalP15ScriptingObjectS0_($self_,$vertices) {
 $self_ = $self_|0;
 $vertices = $vertices|0;
 var $$pre$i = 0, $$pre1$i = 0, $$sroa$02$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $i$06$i$i = 0, $j$05$i$i = 0, $vararg_buffer1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer1 = sp + 24|0;
 $$sroa$02$i$i = sp;
 $0 = ($vertices|0)==(0|0);
 if ($0) {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(873728,$vararg_buffer1);
  // unreachable;
 }
 $1 = (__Z19GetScriptingManagerv()|0);
 $2 = (($1) + 588|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($self_|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $5 = (($self_) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $8 = (($vertices) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__Z21GetScriptingArraySizeP14ScriptingArray($9)|0);
 $11 = (($6) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = (__Z19scripting_array_newP14ScriptingClassjj($3,60,$12)|0);
  HEAP32[$8>>2] = $14;
  $$pre$i = HEAP32[$11>>2]|0;
  $15 = $14;$17 = $$pre$i;
 } else {
  $$pre1$i = HEAP32[$8>>2]|0;
  $15 = $$pre1$i;$17 = $12;
 }
 (__Z21GetScriptingArraySizeP14ScriptingArray($15)|0);
 $16 = ($17|0)>(0);
 if (!($16)) {
  $27 = HEAP32[$11>>2]|0;
  $28 = (($vertices) + 12|0);
  HEAP32[$28>>2] = $27;
  $29 = (($vertices) + 16|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  HEAP32[$29>>2] = $31;
  STACKTOP = sp;return;
 }
 $18 = HEAP32[$6>>2]|0;
 $i$06$i$i = 0;$j$05$i$i = $18;
 while(1) {
  ;HEAP32[$$sroa$02$i$i+0>>2]=HEAP32[$j$05$i$i+0>>2]|0;HEAP32[$$sroa$02$i$i+4>>2]=HEAP32[$j$05$i$i+4>>2]|0;HEAP32[$$sroa$02$i$i+8>>2]=HEAP32[$j$05$i$i+8>>2]|0;HEAP32[$$sroa$02$i$i+12>>2]=HEAP32[$j$05$i$i+12>>2]|0;HEAP32[$$sroa$02$i$i+16>>2]=HEAP32[$j$05$i$i+16>>2]|0;HEAP32[$$sroa$02$i$i+20>>2]=HEAP32[$j$05$i$i+20>>2]|0;
  $19 = (($j$05$i$i) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (($j$05$i$i) + 28|0);
  _memmove(($vararg_buffer1|0),($21|0),32)|0;
  $22 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($15,$i$06$i$i,60)|0);
  ;HEAP32[$22+0>>2]=HEAP32[$$sroa$02$i$i+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$$sroa$02$i$i+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$$sroa$02$i$i+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$$sroa$02$i$i+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$$sroa$02$i$i+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$$sroa$02$i$i+20>>2]|0;
  $23 = (($22) + 24|0);
  HEAP32[$23>>2] = $20;
  $24 = (($22) + 28|0);
  ;HEAP32[$24+0>>2]=HEAP32[$vararg_buffer1+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$vararg_buffer1+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$vararg_buffer1+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$vararg_buffer1+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$vararg_buffer1+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$vararg_buffer1+20>>2]|0;HEAP32[$24+24>>2]=HEAP32[$vararg_buffer1+24>>2]|0;HEAP32[$24+28>>2]=HEAP32[$vararg_buffer1+28>>2]|0;
  $25 = (($i$06$i$i) + 1)|0;
  $26 = (($j$05$i$i) + 60|0);
  $exitcond$i$i = ($25|0)==($17|0);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$06$i$i = $25;$j$05$i$i = $26;
  }
 }
 $27 = HEAP32[$11>>2]|0;
 $28 = (($vertices) + 12|0);
 HEAP32[$28>>2] = $27;
 $29 = (($vertices) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($30) + 1)|0;
 HEAP32[$29>>2] = $31;
 STACKTOP = sp;return;
}
function __Z37TextGenerator_CUSTOM_GetVerticesArrayP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $$sroa$0 = 0, $$sroa$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$08 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $vararg_buffer1 = sp + 56|0;
 $$sroa$0 = sp;
 $$sroa$2 = sp + 24|0;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $1 = (($self_) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $4 = (($2) + 48|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $12 = 0;
 } else {
  $7 = (($2) + 60|0);
  $8 = HEAP32[$7>>2]|0;
  $12 = $8;
 }
 $9 = (__Z19GetScriptingManagerv()|0);
 $10 = (($9) + 588|0);
 $11 = HEAP32[$10>>2]|0;
 $13 = (__Z19scripting_array_newP14ScriptingClassjj($11,60,$12)|0);
 $14 = ($12|0)==(0);
 if ($14) {
  STACKTOP = sp;return ($13|0);
 }
 $i$08 = 0;
 while(1) {
  $15 = HEAP32[$1>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   label = 9;
   break;
  }
  $17 = HEAP32[$15>>2]|0;
  $18 = (($17) + (($i$08*60)|0)|0);
  ;HEAP32[$$sroa$0+0>>2]=HEAP32[$18+0>>2]|0;HEAP32[$$sroa$0+4>>2]=HEAP32[$18+4>>2]|0;HEAP32[$$sroa$0+8>>2]=HEAP32[$18+8>>2]|0;HEAP32[$$sroa$0+12>>2]=HEAP32[$18+12>>2]|0;HEAP32[$$sroa$0+16>>2]=HEAP32[$18+16>>2]|0;HEAP32[$$sroa$0+20>>2]=HEAP32[$18+20>>2]|0;
  $19 = ((($17) + (($i$08*60)|0)|0) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($17) + (($i$08*60)|0)|0) + 28|0);
  ;HEAP32[$$sroa$2+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$$sroa$2+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$$sroa$2+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$$sroa$2+12>>2]=HEAP32[$21+12>>2]|0;HEAP32[$$sroa$2+16>>2]=HEAP32[$21+16>>2]|0;HEAP32[$$sroa$2+20>>2]=HEAP32[$21+20>>2]|0;HEAP32[$$sroa$2+24>>2]=HEAP32[$21+24>>2]|0;HEAP32[$$sroa$2+28>>2]=HEAP32[$21+28>>2]|0;
  $22 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($13,$i$08,60)|0);
  ;HEAP32[$22+0>>2]=HEAP32[$$sroa$0+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$$sroa$0+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$$sroa$0+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$$sroa$0+12>>2]|0;HEAP32[$22+16>>2]=HEAP32[$$sroa$0+16>>2]|0;HEAP32[$22+20>>2]=HEAP32[$$sroa$0+20>>2]|0;
  $23 = (($22) + 24|0);
  HEAP32[$23>>2] = $20;
  $24 = (($22) + 28|0);
  ;HEAP32[$24+0>>2]=HEAP32[$$sroa$2+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$$sroa$2+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$$sroa$2+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$$sroa$2+12>>2]|0;HEAP32[$24+16>>2]=HEAP32[$$sroa$2+16>>2]|0;HEAP32[$24+20>>2]=HEAP32[$$sroa$2+20>>2]|0;HEAP32[$24+24>>2]=HEAP32[$$sroa$2+24>>2]|0;HEAP32[$24+28>>2]=HEAP32[$$sroa$2+28>>2]|0;
  $25 = (($i$08) + 1)|0;
  $26 = ($25>>>0)<($12>>>0);
  if ($26) {
   $i$08 = $25;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 9) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 else if ((label|0) == 11) {
  STACKTOP = sp;return ($13|0);
 }
 return 0|0;
}
function __Z43TextGenerator_Get_Custom_PropCharacterCountP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 48|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $9 = 0;
    STACKTOP = sp;return ($9|0);
   }
   $7 = (($2) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8;
   STACKTOP = sp;return ($9|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z42TextGenerator_CUSTOM_GetCharactersInternalP15ScriptingObjectS0_($self_,$characters) {
 $self_ = $self_|0;
 $characters = $characters|0;
 var $$pre$i = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i$i = 0, $i$03$i$i = 0, $j$02$i$i = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = ($characters|0)==(0|0);
 if ($0) {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(873728,$vararg_buffer1);
  // unreachable;
 }
 $1 = (__Z19GetScriptingManagerv()|0);
 $2 = (($1) + 592|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($self_|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $5 = (($self_) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $8 = (($characters) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__Z21GetScriptingArraySizeP14ScriptingArray($9)|0);
 $11 = (($6) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = (__Z19scripting_array_newP14ScriptingClassjj($3,12,$12)|0);
  HEAP32[$8>>2] = $14;
  $$pre$i = HEAP32[$11>>2]|0;
  $15 = $14;$17 = $$pre$i;
 } else {
  $$pre1$i = HEAP32[$8>>2]|0;
  $15 = $$pre1$i;$17 = $12;
 }
 (__Z21GetScriptingArraySizeP14ScriptingArray($15)|0);
 $16 = ($17|0)>(0);
 if (!($16)) {
  $23 = HEAP32[$11>>2]|0;
  $24 = (($characters) + 12|0);
  HEAP32[$24>>2] = $23;
  $25 = (($characters) + 16|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 1)|0;
  HEAP32[$25>>2] = $27;
  STACKTOP = sp;return;
 }
 $18 = (($6) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $i$03$i$i = 0;$j$02$i$i = $19;
 while(1) {
  _memmove(($vararg_buffer1|0),($j$02$i$i|0),12)|0;
  $20 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($15,$i$03$i$i,12)|0);
  ;HEAP32[$20+0>>2]=HEAP32[$vararg_buffer1+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$vararg_buffer1+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$vararg_buffer1+8>>2]|0;
  $21 = (($i$03$i$i) + 1)|0;
  $22 = (($j$02$i$i) + 12|0);
  $exitcond$i$i = ($21|0)==($17|0);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$03$i$i = $21;$j$02$i$i = $22;
  }
 }
 $23 = HEAP32[$11>>2]|0;
 $24 = (($characters) + 12|0);
 HEAP32[$24>>2] = $23;
 $25 = (($characters) + 16|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$25>>2] = $27;
 STACKTOP = sp;return;
}
function __Z39TextGenerator_CUSTOM_GetCharactersArrayP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer1 = sp + 16|0;
 $0 = sp;
 $1 = ($self_|0)==(0|0);
 if ($1) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $2 = (($self_) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $5 = (($3) + 48|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $13 = 0;
 } else {
  $8 = (($3) + 24|0);
  $9 = HEAP32[$8>>2]|0;
  $13 = $9;
 }
 $10 = (__Z19GetScriptingManagerv()|0);
 $11 = (($10) + 592|0);
 $12 = HEAP32[$11>>2]|0;
 $14 = (__Z19scripting_array_newP14ScriptingClassjj($12,12,$13)|0);
 $15 = ($13|0)==(0);
 if ($15) {
  STACKTOP = sp;return ($14|0);
 }
 $i$05 = 0;
 while(1) {
  $16 = HEAP32[$2>>2]|0;
  $17 = ($16|0)==(0|0);
  if ($17) {
   label = 9;
   break;
  }
  $18 = (($16) + 16|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + (($i$05*12)|0)|0);
  ;HEAP32[$0+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$20+8>>2]|0;
  $21 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($14,$i$05,12)|0);
  ;HEAP32[$21+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$0+8>>2]|0;
  $22 = (($i$05) + 1)|0;
  $23 = ($22>>>0)<($13>>>0);
  if ($23) {
   $i$05 = $22;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 9) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 else if ((label|0) == 11) {
  STACKTOP = sp;return ($14|0);
 }
 return 0|0;
}
function __Z38TextGenerator_Get_Custom_PropLineCountP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 48|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $9 = 0;
    STACKTOP = sp;return ($9|0);
   }
   $7 = (($2) + 40|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = $8;
   STACKTOP = sp;return ($9|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z37TextGenerator_CUSTOM_GetLinesInternalP15ScriptingObjectS0_($self_,$lines) {
 $self_ = $self_|0;
 $lines = $lines|0;
 var $$pr$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond$i$i = 0, $i$04$i$i = 0, $j$03$i$i = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = ($lines|0)==(0|0);
 if ($0) {
  __ZN9Scripting22RaiseArgumentExceptionEPKcz(873728,$vararg_buffer1);
  // unreachable;
 }
 $1 = (__Z19GetScriptingManagerv()|0);
 $2 = (($1) + 596|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($self_|0)==(0|0);
 if ($4) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $5 = (($self_) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $8 = (($lines) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__Z21GetScriptingArraySizeP14ScriptingArray($9)|0);
 $11 = (($6) + 40|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)<($12>>>0);
 if ($13) {
  $14 = (__Z19scripting_array_newP14ScriptingClassjj($3,8,$12)|0);
  HEAP32[$8>>2] = $14;
  $$pr$i = HEAP32[$11>>2]|0;
  $15 = $14;$17 = $$pr$i;
 } else {
  $$pre$i = HEAP32[$8>>2]|0;
  $15 = $$pre$i;$17 = $12;
 }
 (__Z21GetScriptingArraySizeP14ScriptingArray($15)|0);
 $16 = ($17|0)>(0);
 if (!($16)) {
  $33 = HEAP32[$11>>2]|0;
  $34 = (($lines) + 12|0);
  HEAP32[$34>>2] = $33;
  $35 = (($lines) + 16|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 1)|0;
  HEAP32[$35>>2] = $37;
  STACKTOP = sp;return;
 }
 $18 = (($6) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $i$04$i$i = 0;$j$03$i$i = $19;
 while(1) {
  $20 = $j$03$i$i;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + 4)|0;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($15,$i$04$i$i,8)|0);
  $27 = $26;
  $28 = $27;
  HEAP32[$28>>2] = $22;
  $29 = (($27) + 4)|0;
  $30 = $29;
  HEAP32[$30>>2] = $25;
  $31 = (($i$04$i$i) + 1)|0;
  $32 = (($j$03$i$i) + 8|0);
  $exitcond$i$i = ($31|0)==($17|0);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$04$i$i = $31;$j$03$i$i = $32;
  }
 }
 $33 = HEAP32[$11>>2]|0;
 $34 = (($lines) + 12|0);
 HEAP32[$34>>2] = $33;
 $35 = (($lines) + 16|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$35>>2] = $37;
 STACKTOP = sp;return;
}
function __Z34TextGenerator_CUSTOM_GetLinesArrayP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = ($self_|0)==(0|0);
 if ($0) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $1 = (($self_) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 $4 = (($2) + 48|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $12 = 0;
 } else {
  $7 = (($2) + 40|0);
  $8 = HEAP32[$7>>2]|0;
  $12 = $8;
 }
 $9 = (__Z19GetScriptingManagerv()|0);
 $10 = (($9) + 596|0);
 $11 = HEAP32[$10>>2]|0;
 $13 = (__Z19scripting_array_newP14ScriptingClassjj($11,8,$12)|0);
 $14 = ($12|0)==(0);
 if ($14) {
  STACKTOP = sp;return ($13|0);
 } else {
  $i$06 = 0;
 }
 while(1) {
  $15 = HEAP32[$1>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   label = 8;
   break;
  }
  $17 = (($15) + 32|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($i$06<<3)|0);
  $20 = $19;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + 4)|0;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (__Z27scripting_array_element_ptrP14ScriptingArrayij($13,$i$06,8)|0);
  $27 = $26;
  $28 = $27;
  HEAP32[$28>>2] = $22;
  $29 = (($27) + 4)|0;
  $30 = $29;
  HEAP32[$30>>2] = $25;
  $31 = (($i$06) + 1)|0;
  $32 = ($31>>>0)<($12>>>0);
  if ($32) {
   $i$06 = $31;
  } else {
   label = 10;
   break;
  }
 }
 if ((label|0) == 8) {
  __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer1);
  // unreachable;
 }
 else if ((label|0) == 10) {
  STACKTOP = sp;return ($13|0);
 }
 return 0|0;
}
function __Z51TextGenerator_Get_Custom_PropFontSizeUsedForBestFitP15ScriptingObject($self_) {
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($self_|0)==(0|0);
 if (!($0)) {
  $1 = (($self_) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 64|0);
   $5 = HEAP32[$4>>2]|0;
   STACKTOP = sp;return ($5|0);
  }
 }
 __ZN9Scripting18RaiseNullExceptionEPKcz(874472,$vararg_buffer);
 // unreachable;
 return 0|0;
}
function __Z37Register_UnityEngine_Font_get_dynamicv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(873760,3446);
 STACKTOP = sp;return;
}
function __Z39Register_UnityEngine_TextGenerator_Initv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(873792,3760);
 STACKTOP = sp;return;
}
function __Z46Register_UnityEngine_TextGenerator_Dispose_cppv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(873824,3761);
 STACKTOP = sp;return;
}
function __Z70Register_UnityEngine_TextGenerator_INTERNAL_CALL_Populate_Internal_cppv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(873864,2);
 STACKTOP = sp;return;
}
function __Z50Register_UnityEngine_TextGenerator_get_rectExtentsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(873928,3453);
 STACKTOP = sp;return;
}
function __Z50Register_UnityEngine_TextGenerator_get_vertexCountv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(873976,3447);
 STACKTOP = sp;return;
}
function __Z54Register_UnityEngine_TextGenerator_GetVerticesInternalv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874024,3454);
 STACKTOP = sp;return;
}
function __Z51Register_UnityEngine_TextGenerator_GetVerticesArrayv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874072,3448);
 STACKTOP = sp;return;
}
function __Z53Register_UnityEngine_TextGenerator_get_characterCountv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874120,3449);
 STACKTOP = sp;return;
}
function __Z56Register_UnityEngine_TextGenerator_GetCharactersInternalv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874168,3455);
 STACKTOP = sp;return;
}
function __Z53Register_UnityEngine_TextGenerator_GetCharactersArrayv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874224,3450);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_TextGenerator_get_lineCountv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874272,3451);
 STACKTOP = sp;return;
}
function __Z51Register_UnityEngine_TextGenerator_GetLinesInternalv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874320,3456);
 STACKTOP = sp;return;
}
function __Z48Register_UnityEngine_TextGenerator_GetLinesArrayv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874368,3452);
 STACKTOP = sp;return;
}
function __Z61Register_UnityEngine_TextGenerator_get_fontSizeUsedForBestFitv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z22mono_add_internal_callPKcPKv(874416,3453);
 STACKTOP = sp;return;
}
function __ZN20TextRenderingPrivate22ScriptingTextGeneratorD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(-1);
 do {
  if ($6) {
   $7 = (($this) + 32|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 36|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$3>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy4|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    HEAP32[$7>>2] = 0;
    label = 4;
    break;
   }
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = (($this) + 28|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)>(-1);
   if ($32) {
    $33 = (($this) + 16|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($this) + 20|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$1>>2] = $36;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($34|0),($$byval_copy4|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $49 = ___cxa_find_matching_catch(0|0)|0;
     $50 = tempRet0;
     ___clang_call_terminate($49);
     // unreachable;
    } else {
     HEAP32[$33>>2] = 0;
     $$0 = $29;$$01 = $28;
     break;
    }
   } else {
    $$0 = $29;$$01 = $28;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $13 = (($this) + 28|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)>(-1);
   do {
    if ($15) {
     $16 = (($this) + 16|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($this) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$2>>2] = $19;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($17|0),($$byval_copy4|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      $39 = ___cxa_find_matching_catch()|0;
      $40 = tempRet0;
      $$0 = $40;$$01 = $39;
      break L10;
     } else {
      HEAP32[$16>>2] = 0;
      break;
     }
    }
   } while(0);
   $22 = (($this) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)>(-1);
   if (!($24)) {
    STACKTOP = sp;return;
   }
   $25 = HEAP32[$this>>2]|0;
   $26 = (($this) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$0>>2] = $27;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy4);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $41 = (($this) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)>(-1);
 if (!($43)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $44 = HEAP32[$this>>2]|0;
 $45 = (($this) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$0>>2] = $46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($44|0),($$byval_copy4|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN2UI14PrepareBatchesEPKNS_13UIInstructionES2_R13dynamic_arrayINS_17BatchInstructionsELj4EE($begin,$end,$batches) {
 $begin = $begin|0;
 $end = $end|0;
 $batches = $batches|0;
 var $$01 = 0, $$byval_copy1 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $iter$0$lcssa$i$ph = 0, $iter$01$i = 0, $iter$1$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = ($begin|0)==($end|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($batches) + 8|0);
 $3 = (($batches) + 12|0);
 $4 = (($batches) + 4|0);
 $$01 = $begin;
 while(1) {
  $5 = HEAP32[$2>>2]|0;
  $6 = (($5) + 1)|0;
  HEAP32[$2>>2] = $6;
  $7 = HEAP32[$3>>2]|0;
  $8 = $7 & 2147483647;
  $9 = ($6>>>0)>($8>>>0);
  if ($9) {
   $10 = $7 << 1;
   $11 = ($10|0)==(0);
   $12 = $11 ? 1 : $10;
   $13 = ($8>>>0)<($12>>>0);
   do {
    if ($13) {
     $14 = ($7|0)>(-1);
     if ($14) {
      HEAP32[$3>>2] = $12;
      $15 = HEAP32[$batches>>2]|0;
      $16 = $12 << 4;
      $17 = HEAP32[$4>>2]|0;
      HEAP32[$0>>2] = $17;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $18 = (__Z16realloc_internalPvji10MemLabelIdiPKci($15,$16,4,$$byval_copy1,0,874480,370)|0);
      HEAP32[$batches>>2] = $18;
      break;
     } else {
      $19 = $12 << 4;
      $20 = HEAP32[$4>>2]|0;
      HEAP32[$0>>2] = $20;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $21 = (__Z15malloc_internaljj10MemLabelIdiPKci($19,4,$$byval_copy1,0,874480,352)|0);
      $22 = HEAP32[$batches>>2]|0;
      $23 = HEAP32[$2>>2]|0;
      $24 = $23 << 4;
      _memcpy(($21|0),($22|0),($24|0))|0;
      HEAP32[$3>>2] = $12;
      HEAP32[$batches>>2] = $21;
      break;
     }
    }
   } while(0);
   $$pre$i = HEAP32[$2>>2]|0;
   $26 = $$pre$i;
  } else {
   $26 = $6;
  }
  $25 = (($26) + -1)|0;
  $27 = HEAP32[$batches>>2]|0;
  $28 = (($27) + ($25<<4)|0);
  HEAP32[$28>>2] = 0;
  $29 = ((($27) + ($25<<4)|0) + 4|0);
  HEAP32[$29>>2] = $$01;
  $30 = (($$01) + 148|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   $33 = (($$01) + 4|0);
   $49 = 0;$iter$01$i = $$01;
   while(1) {
    $36 = HEAP32[$$01>>2]|0;
    $37 = HEAP32[$iter$01$i>>2]|0;
    $38 = ($36|0)==($37|0);
    if (!($38)) {
     $iter$0$lcssa$i$ph = $iter$01$i;
     break;
    }
    $39 = HEAP32[$33>>2]|0;
    $40 = (($iter$01$i) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($39|0)==($41|0);
    if (!($42)) {
     $iter$0$lcssa$i$ph = $iter$01$i;
     break;
    }
    $43 = (($iter$01$i) + 148|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = ($44<<24>>24)==(0);
    if (!($45)) {
     $iter$0$lcssa$i$ph = $iter$01$i;
     break;
    }
    $46 = (($iter$01$i) + 140|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + ($49))|0;
    HEAP32[$28>>2] = $48;
    $50 = (($iter$01$i) + 152|0);
    $51 = ($50|0)==($end|0);
    if ($51) {
     $iter$0$lcssa$i$ph = $end;
     break;
    } else {
     $49 = $48;$iter$01$i = $50;
    }
   }
   $52 = ((($27) + ($25<<4)|0) + 12|0);
   HEAP8[$52>>0] = 1;
   $iter$1$i = $iter$0$lcssa$i$ph;
  } else {
   $34 = (($$01) + 152|0);
   $35 = ((($27) + ($25<<4)|0) + 12|0);
   HEAP8[$35>>0] = 0;
   $iter$1$i = $34;
  }
  $53 = $iter$1$i;
  $54 = $$01;
  $55 = (($53) - ($54))|0;
  $56 = (($55|0) / 152)&-1;
  $57 = ((($27) + ($25<<4)|0) + 8|0);
  HEAP32[$57>>2] = $56;
  $58 = (($$01) + (($56*152)|0)|0);
  $59 = ($58|0)==($end|0);
  if ($59) {
   break;
  } else {
   $$01 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI18DestroyBatchOutputERNS_11BatchOutputE($batchOutput) {
 $batchOutput = $batchOutput|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy5 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($batchOutput) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 __Z19DestroySingleObjectP6Object($4);
 HEAP32[$3>>2] = 0;
 $5 = (($batchOutput) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(-1);
 if ($7) {
  $8 = HEAP32[$batchOutput>>2]|0;
  $9 = (($batchOutput) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$0>>2] = $10;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($8,$$byval_copy5);
  HEAP32[$batchOutput>>2] = 0;
 }
 $11 = (($batchOutput) + 8|0);
 HEAP32[$11>>2] = 0;
 HEAP32[$5>>2] = 0;
 $12 = (($batchOutput) + 16|0);
 $13 = (($batchOutput) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(0);
 L4: do {
  if ($15) {
   $i$07 = 0;
   while(1) {
    $16 = HEAP32[$12>>2]|0;
    $17 = (($16) + ($i$07<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[628400>>2]|0;
    $20 = ($18|0)==(0|0);
    if (!($20)) {
     $21 = (($18) + 28|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)>(-1);
     if ($23) {
      $24 = (($18) + 16|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($18) + 20|0);
      $27 = HEAP32[$26>>2]|0;
      HEAP32[$1>>2] = $27;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
      invoke_vii(2591,($25|0),($$byval_copy5|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      HEAP32[$24>>2] = 0;
     }
     $30 = (($18) + 12|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)>(-1);
     if ($32) {
      $33 = HEAP32[$18>>2]|0;
      $34 = (($18) + 4|0);
      $35 = HEAP32[$34>>2]|0;
      HEAP32[$0>>2] = $35;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($33,$$byval_copy5);
      HEAP32[$18>>2] = 0;
     }
    }
    HEAP32[$2>>2] = $19;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($18,$$byval_copy5);
    $48 = HEAP32[$12>>2]|0;
    $49 = (($48) + ($i$07<<2)|0);
    HEAP32[$49>>2] = 0;
    $50 = (($i$07) + 1)|0;
    $51 = HEAP32[$13>>2]|0;
    $52 = ($50|0)<($51|0);
    if ($52) {
     $i$07 = $50;
    } else {
     break L4;
    }
   }
   $36 = ___cxa_find_matching_catch()|0;
   $37 = tempRet0;
   $38 = (($18) + 12|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ($39|0)>(-1);
   if (!($40)) {
    ___resumeException($36|0);
    // unreachable;
   }
   $41 = HEAP32[$18>>2]|0;
   $42 = (($18) + 4|0);
   $43 = HEAP32[$42>>2]|0;
   HEAP32[$0>>2] = $43;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($41|0),($$byval_copy5|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $46 = ___cxa_find_matching_catch(0|0)|0;
    $47 = tempRet0;
    ___clang_call_terminate($46);
    // unreachable;
   }
   HEAP32[$18>>2] = 0;
   ___resumeException($36|0);
   // unreachable;
  }
 } while(0);
 $53 = (($batchOutput) + 28|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54|0)>(-1);
 if (!($55)) {
  HEAP32[$13>>2] = 0;
  HEAP32[$53>>2] = 0;
  STACKTOP = sp;return;
 }
 $56 = HEAP32[$12>>2]|0;
 $57 = (($batchOutput) + 20|0);
 $58 = HEAP32[$57>>2]|0;
 HEAP32[$0>>2] = $58;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($56,$$byval_copy5);
 HEAP32[$12>>2] = 0;
 HEAP32[$13>>2] = 0;
 HEAP32[$53>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN2UI17CreateBatchOutputEPKNS_13UIInstructionEjfRNS_11BatchOutputE($inputInstructions,$instructionCount,$canvasAlpha,$batchOutput) {
 $inputInstructions = $inputInstructions|0;
 $instructionCount = $instructionCount|0;
 $canvasAlpha = Math_fround($canvasAlpha);
 $batchOutput = $batchOutput|0;
 var $$0$i48 = 0, $$01$i$i = 0, $$01$i$i26 = 0, $$1 = 0, $$12 = 0, $$byval_copy32 = 0, $$op$i$i$i$i$i = Math_fround(0), $$op$i$i$i1$i$i = Math_fround(0), $$op$i1$i$i$i$i = Math_fround(0), $$op$i1$i$i4$i$i = Math_fround(0), $$op$i2$i$i$i$i = Math_fround(0), $$op$i2$i$i3$i$i = Math_fround(0), $$op$i3$i$i$i$i = Math_fround(0), $$op$i3$i$i2$i$i = Math_fround(0), $$pre = 0, $$pre$i$i = 0, $$sink$i$i$i = Math_fround(0), $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0;
 var $173 = Math_fround(0), $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = Math_fround(0), $184 = 0, $185 = 0, $186 = 0, $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = 0, $204 = Math_fround(0), $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = 0;
 var $209 = 0, $21 = 0, $210 = Math_fround(0), $211 = 0, $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = 0, $219 = Math_fround(0), $22 = 0, $220 = Math_fround(0), $221 = 0, $222 = 0, $223 = 0, $224 = Math_fround(0), $225 = 0, $226 = Math_fround(0);
 var $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = Math_fround(0), $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0, $255 = Math_fround(0), $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = Math_fround(0);
 var $263 = Math_fround(0), $264 = Math_fround(0), $265 = Math_fround(0), $266 = 0, $267 = Math_fround(0), $268 = 0, $269 = Math_fround(0), $27 = 0, $270 = Math_fround(0), $271 = 0, $272 = 0, $273 = 0, $274 = Math_fround(0), $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = Math_fround(0), $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = Math_fround(0), $291 = Math_fround(0), $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0;
 var $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0;
 var $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0;
 var $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0;
 var $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0;
 var $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0;
 var $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0;
 var $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0;
 var $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0;
 var $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0;
 var $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0;
 var $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0;
 var $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0;
 var $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0;
 var $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0;
 var $551 = 0, $552 = 0, $553 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0, $batches = 0, $eh$lpad$body$index8Z2D = 0, $eh$lpad$body$indexZ2D = 0, $exitcond$i = 0, $exitcond20$i = 0, $exitcond21$i = 0, $exitcond23$i = 0, $i$014$i = 0;
 var $i$015$i$i = 0, $i$055 = 0, $i1$010$i = 0, $i1$010$i$i = 0, $i1$051 = 0, $i2$013$i$i = 0, $i2$049 = 0, $i2$07$i = 0, $i3$03$i = 0, $mat$i$i = 0, $mesh$idx$i = 0, $mesh$idx$val$i = 0, $mesh$idx$val$idx$i = 0, $mesh$idx$val$idx$val$i = 0, $or$cond = 0, $v$02$i$i = 0, $vertexCount$0$lcssa24$i = 0, $vertexCount$015$i = 0, $vertexData$017$i$i = 0, $vertexData$1$i$i = 0;
 var $vertexIndex$06$i = 0, $vertexIndex$1$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy32 = sp;
 $0 = sp + 168|0;
 $1 = sp + 164|0;
 $2 = sp + 160|0;
 $3 = sp + 156|0;
 $4 = sp + 152|0;
 $5 = sp + 148|0;
 $6 = sp + 144|0;
 $7 = sp + 140|0;
 $8 = sp + 136|0;
 $mat$i$i = sp + 72|0;
 $9 = sp + 172|0;
 $10 = sp + 20|0;
 $11 = sp + 16|0;
 $12 = sp + 8|0;
 $13 = sp + 12|0;
 $14 = sp + 64|0;
 $15 = sp + 32|0;
 $batches = sp + 40|0;
 $16 = sp + 56|0;
 $17 = sp + 60|0;
 $18 = sp + 68|0;
 __ZN2UI18DestroyBatchOutputERNS_11BatchOutputE($batchOutput);
 $19 = ($instructionCount*152)|0;
 $20 = (($19) + 15)|0;
 $21 = ($20>>>0)<(2000);
 $22 = ($instructionCount|0)!=(0);
 if ($21) {
  if ($22) {
   $23 = STACKTOP; STACKTOP = STACKTOP + ((((1*$20)|0)+15)&-16)|0;;
   $537 = 0;$allocPtr$0 = $23;
   label = 7;
  } else {
   $537 = 0;$allocPtr$0 = 0;
   label = 7;
  }
 } else {
  if ($22) {
   $24 = HEAP32[628512>>2]|0;
   HEAP32[$15>>2] = $24;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$15+0>>2]|0;
   $25 = (invoke_iiiiiii(102,($20|0),16,($$byval_copy32|0),0,(874480|0),247)|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $552 = 0;
    label = 6;
   } else {
    $537 = $25;$allocPtr$0 = $25;
    label = 7;
   }
  } else {
   $537 = 0;$allocPtr$0 = 0;
   label = 7;
  }
 }
 L6: do {
  if ((label|0) == 7) {
   $30 = $allocPtr$0;
   $31 = (($30) + 15)|0;
   $32 = $31 & -16;
   $33 = $32;
   __THREW__ = 0;
   $34 = (invoke_iiii(1630,($inputInstructions|0),($instructionCount|0),($33|0))|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    $552 = $537;
    label = 6;
   } else {
    $37 = HEAP32[628512>>2]|0;
    HEAP32[$batches>>2] = 0;
    $38 = (($batches) + 4|0);
    HEAP32[$38>>2] = $37;
    $39 = (($batches) + 8|0);
    HEAP32[$39>>2] = 0;
    $40 = (($batches) + 12|0);
    HEAP32[$40>>2] = 0;
    $41 = (($33) + (($34*152)|0)|0);
    __THREW__ = 0;
    invoke_viii(2076,($33|0),($41|0),($batches|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    L9: do {
     if ($43) {
      label = 80;
     } else {
      $44 = (($batchOutput) + 32|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45|0)==(0|0);
      if ($46) {
       $47 = HEAP32[628384>>2]|0;
       HEAP32[$11>>2] = $47;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$11+0>>2]|0;
       $48 = (invoke_iiiiiii(103,280,($$byval_copy32|0),1,16,(874480|0),1111)|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        label = 80;
        break;
       }
       HEAP32[$12>>2] = $47;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$12+0>>2]|0;
       invoke_viii(1698,($48|0),($$byval_copy32|0),0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        $53 = ___cxa_find_matching_catch()|0;
        $54 = tempRet0;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$11+0>>2]|0;
        invoke_viiiiii(97,($48|0),($$byval_copy32|0),1,16,(874480|0),1111);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if (!($56)) {
         $eh$lpad$body$index8Z2D = $54;$eh$lpad$body$indexZ2D = $53;
         break;
        }
        $57 = ___cxa_find_matching_catch(0|0)|0;
        $58 = tempRet0;
        ___clang_call_terminate($57);
        // unreachable;
       }
       __THREW__ = 0;
       $59 = (invoke_ii(3405,($48|0))|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 80;
        break;
       }
       $62 = HEAP32[$59>>2]|0;
       $63 = (($62) + 24|0);
       $64 = HEAP32[$63>>2]|0;
       __THREW__ = 0;
       invoke_vi($64|0,($59|0));
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        label = 80;
        break;
       }
       $67 = HEAP32[$59>>2]|0;
       $68 = (($67) + 12|0);
       $69 = HEAP32[$68>>2]|0;
       __THREW__ = 0;
       invoke_vii($69|0,($59|0),4);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 80;
        break;
       }
       $72 = HEAP32[$59>>2]|0;
       $73 = (($72) + 44|0);
       $74 = HEAP32[$73>>2]|0;
       __THREW__ = 0;
       invoke_vii($74|0,($59|0),61);
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        label = 80;
        break;
       }
       $77 = HEAP32[$59>>2]|0;
       $78 = (($77) + 36|0);
       $79 = HEAP32[$78>>2]|0;
       __THREW__ = 0;
       invoke_vii($79|0,($59|0),(874576|0));
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        label = 80;
        break;
       }
       HEAP32[$44>>2] = $59;
       $113 = $59;
      } else {
       $113 = $45;
      }
      $82 = HEAP32[$batches>>2]|0;
      $83 = HEAP32[$39>>2]|0;
      $84 = ($83|0)>(0);
      do {
       if ($84) {
        $i$014$i = 0;$vertexCount$015$i = 0;
        while(1) {
         $85 = (($82) + ($i$014$i<<4)|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = (($86) + ($vertexCount$015$i))|0;
         $88 = (($i$014$i) + 1)|0;
         $exitcond23$i = ($88|0)==($83|0);
         if ($exitcond23$i) {
          break;
         } else {
          $i$014$i = $88;$vertexCount$015$i = $87;
         }
        }
        $89 = ($87|0)>(65535);
        if ($89) {
         __THREW__ = 0;
         HEAP32[$$byval_copy32>>2] = 65535;
         invoke_viii(1617,($10|0),(874504|0),($$byval_copy32|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          label = 80;
          break L9;
         }
         $92 = HEAP8[$10>>0]|0;
         $93 = $92 & 1;
         $94 = ($93<<24>>24)==(0);
         if ($94) {
          $97 = (($10) + 1|0);
          $98 = $97;
         } else {
          $95 = (($10) + 8|0);
          $96 = HEAP32[$95>>2]|0;
          $98 = $96;
         }
         __THREW__ = 0;
         invoke_viiiiiiii(21,($98|0),0,(874480|0),150,1,0,0,(0|0));
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          $106 = ___cxa_find_matching_catch()|0;
          $107 = tempRet0;
          $108 = HEAP8[$10>>0]|0;
          $109 = $108 & 1;
          $110 = ($109<<24>>24)==(0);
          if ($110) {
           $eh$lpad$body$index8Z2D = $107;$eh$lpad$body$indexZ2D = $106;
           break L9;
          }
          $111 = (($10) + 8|0);
          $112 = HEAP32[$111>>2]|0;
          __ZdlPv($112);
          $eh$lpad$body$index8Z2D = $107;$eh$lpad$body$indexZ2D = $106;
          break L9;
         } else {
          $101 = HEAP8[$10>>0]|0;
          $102 = $101 & 1;
          $103 = ($102<<24>>24)==(0);
          if ($103) {
           $334 = $83;
           break;
          }
          $104 = (($10) + 8|0);
          $105 = HEAP32[$104>>2]|0;
          __ZdlPv($105);
          $334 = $83;
          break;
         }
        } else {
         $vertexCount$0$lcssa24$i = $87;
         label = 32;
        }
       } else {
        $vertexCount$0$lcssa24$i = 0;
        label = 32;
       }
      } while(0);
      if ((label|0) == 32) {
       __THREW__ = 0;
       invoke_viii(2025,($113|0),($vertexCount$0$lcssa24$i|0),159);
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        label = 80;
        break;
       }
       __THREW__ = 0;
       invoke_vii(3457,($113|0),($83|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 80;
        break;
       }
       L43: do {
        if ($84) {
         $i1$010$i = 0;
         while(1) {
          $118 = (($82) + ($i1$010$i<<4)|0);
          $119 = HEAP32[$118>>2]|0;
          $120 = (($119|0) / 4)&-1;
          $121 = ($120*6)|0;
          __THREW__ = 0;
          (invoke_iiiiiii(122,($113|0),(0|0),($121|0),($i1$010$i|0),0,9)|0);
          $122 = __THREW__; __THREW__ = 0;
          $123 = $122&1;
          if ($123) {
           break;
          }
          $124 = (($i1$010$i) + 1)|0;
          $exitcond21$i = ($124|0)==($83|0);
          if ($exitcond21$i) {
           break L43;
          } else {
           $i1$010$i = $124;
          }
         }
         $367 = ___cxa_find_matching_catch()|0;
         $368 = tempRet0;
         $eh$lpad$body$index8Z2D = $368;$eh$lpad$body$indexZ2D = $367;
         break L9;
        }
       } while(0);
       $125 = Math_fround($canvasAlpha * Math_fround(255.0));
       $126 = Math_fround($125 + Math_fround(0.5));
       $127 = !($126 >= Math_fround(0.0));
       if ($127) {
        $128 = Math_fround($126 + Math_fround(-0.999999940395355224609));
        $$sink$i$i$i = $128;
       } else {
        $$sink$i$i$i = $126;
       }
       L52: do {
        if ($84) {
         $129 = (~~(($$sink$i$i$i)));
         $mesh$idx$i = (($113) + 28|0);
         $130 = $129 & 255;
         $131 = (Math_fround(($130|0)));
         $132 = Math_fround($131 / Math_fround(255.0));
         $133 = (($9) + 4|0);
         $134 = (($9) + 8|0);
         $i2$07$i = 0;$vertexIndex$06$i = 0;
         L54: while(1) {
          $135 = ((($82) + ($i2$07$i<<4)|0) + 12|0);
          $136 = HEAP8[$135>>0]|0;
          $137 = ($136<<24>>24)==(0);
          if ($137) {
           $vertexIndex$1$i = $vertexIndex$06$i;
          } else {
           $mesh$idx$val$i = HEAP32[$mesh$idx$i>>2]|0;
           $mesh$idx$val$idx$i = (($mesh$idx$val$i) + 92|0);
           $mesh$idx$val$idx$val$i = HEAP32[$mesh$idx$val$idx$i>>2]|0;
           $138 = ((($82) + ($i2$07$i<<4)|0) + 8|0);
           $139 = HEAP32[$138>>2]|0;
           $140 = ($139|0)>(0);
           if ($140) {
            $141 = ($vertexIndex$06$i*60)|0;
            $142 = (($mesh$idx$val$idx$val$i) + ($141)|0);
            $143 = ((($82) + ($i2$07$i<<4)|0) + 4|0);
            $553 = $139;$i$015$i$i = 0;$vertexData$017$i$i = $142;
            while(1) {
             $144 = HEAP32[$143>>2]|0;
             $145 = ((($144) + (($i$015$i$i*152)|0)|0) + 140|0);
             $146 = HEAP32[$145>>2]|0;
             $147 = ($146|0)==(0);
             if ($147) {
              $302 = $553;$vertexData$1$i$i = $vertexData$017$i$i;
             } else {
              $148 = ((($144) + (($i$015$i$i*152)|0)|0) + 136|0);
              $149 = HEAP32[$148>>2]|0;
              $150 = (($149) + 24|0);
              $151 = ((($144) + (($i$015$i$i*152)|0)|0) + 12|0);
              dest=$mat$i$i+0|0; src=$151+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
              __THREW__ = 0;
              $152 = (invoke_i(59)|0);
              $153 = __THREW__; __THREW__ = 0;
              $154 = $153&1;
              if ($154) {
               break L54;
              }
              $155 = (($152) + 5933|0);
              $156 = HEAP8[$155>>0]|0;
              $157 = ($156<<24>>24)==(0);
              if (!($157)) {
               HEAPF32[$9>>2] = Math_fround(-0.5);
               HEAPF32[$133>>2] = Math_fround(-0.5);
               HEAPF32[$134>>2] = Math_fround(0.0);
               __THREW__ = 0;
               (invoke_iii(2709,($mat$i$i|0),($9|0))|0);
               $158 = __THREW__; __THREW__ = 0;
               $159 = $158&1;
               if ($159) {
                break L54;
               }
              }
              $160 = HEAP32[$145>>2]|0;
              __THREW__ = 0;
              invoke_viiiiiiiiiii(2,($vertexData$017$i$i|0),($mat$i$i|0),($160|0),($149|0),12,44,60,($150|0),60,20,0);
              $161 = __THREW__; __THREW__ = 0;
              $162 = $161&1;
              if ($162) {
               break L54;
              }
              $163 = ((($144) + (($i$015$i$i*152)|0)|0) + 116|0);
              $164 = Math_fround(HEAPF32[$163>>2]);
              $165 = ((($144) + (($i$015$i$i*152)|0)|0) + 120|0);
              $166 = Math_fround(HEAPF32[$165>>2]);
              $167 = ((($144) + (($i$015$i$i*152)|0)|0) + 124|0);
              $168 = Math_fround(HEAPF32[$167>>2]);
              $169 = ((($144) + (($i$015$i$i*152)|0)|0) + 128|0);
              $170 = Math_fround(HEAPF32[$169>>2]);
              $171 = Math_fround($132 * $170);
              $172 = ((($144) + (($i$015$i$i*152)|0)|0) + 132|0);
              $173 = Math_fround(HEAPF32[$172>>2]);
              $174 = Math_fround($171 * $173);
              $175 = HEAP8[((640792 + 258|0))>>0]|0;
              $176 = ($175<<24>>24)==(0);
              $177 = HEAP32[$145>>2]|0;
              $178 = ($177|0)>(0);
              do {
               if ($176) {
                if ($178) {
                 $i2$013$i$i = 0;
                } else {
                 $298 = $177;
                 break;
                }
                while(1) {
                 $242 = ((($vertexData$017$i$i) + (($i2$013$i$i*60)|0)|0) + 24|0);
                 $243 = HEAP8[$242>>0]|0;
                 $244 = $243&255;
                 $245 = (Math_fround(($244|0)));
                 $246 = Math_fround($245 / Math_fround(255.0));
                 $247 = ((($vertexData$017$i$i) + (($i2$013$i$i*60)|0)|0) + 25|0);
                 $248 = HEAP8[$247>>0]|0;
                 $249 = $248&255;
                 $250 = (Math_fround(($249|0)));
                 $251 = Math_fround($250 / Math_fround(255.0));
                 $252 = ((($vertexData$017$i$i) + (($i2$013$i$i*60)|0)|0) + 26|0);
                 $253 = HEAP8[$252>>0]|0;
                 $254 = $253&255;
                 $255 = (Math_fround(($254|0)));
                 $256 = Math_fround($255 / Math_fround(255.0));
                 $257 = ((($vertexData$017$i$i) + (($i2$013$i$i*60)|0)|0) + 27|0);
                 $258 = HEAP8[$257>>0]|0;
                 $259 = $258&255;
                 $260 = (Math_fround(($259|0)));
                 $261 = Math_fround($260 / Math_fround(255.0));
                 $262 = Math_fround($164 * $246);
                 $263 = Math_fround($166 * $251);
                 $264 = Math_fround($168 * $256);
                 $265 = Math_fround($174 * $261);
                 $266 = $262 < Math_fround(0.0);
                 $267 = $266 ? Math_fround(0.0) : $262;
                 $268 = $267 > Math_fround(1.0);
                 $$op$i$i$i$i$i = Math_fround($267 * Math_fround(255.0));
                 $269 = $268 ? Math_fround(255.0) : $$op$i$i$i$i$i;
                 $270 = Math_fround($269 + Math_fround(0.5));
                 $271 = (~~(($270))>>>0);
                 $272 = $271&255;
                 HEAP8[$242>>0] = $272;
                 $273 = $263 < Math_fround(0.0);
                 $274 = $273 ? Math_fround(0.0) : $263;
                 $275 = $274 > Math_fround(1.0);
                 $$op$i3$i$i$i$i = Math_fround($274 * Math_fround(255.0));
                 $276 = $275 ? Math_fround(255.0) : $$op$i3$i$i$i$i;
                 $277 = Math_fround($276 + Math_fround(0.5));
                 $278 = (~~(($277))>>>0);
                 $279 = $278&255;
                 HEAP8[$247>>0] = $279;
                 $280 = $264 < Math_fround(0.0);
                 $281 = $280 ? Math_fround(0.0) : $264;
                 $282 = $281 > Math_fround(1.0);
                 $$op$i2$i$i$i$i = Math_fround($281 * Math_fround(255.0));
                 $283 = $282 ? Math_fround(255.0) : $$op$i2$i$i$i$i;
                 $284 = Math_fround($283 + Math_fround(0.5));
                 $285 = (~~(($284))>>>0);
                 $286 = $285&255;
                 HEAP8[$252>>0] = $286;
                 $287 = $265 < Math_fround(0.0);
                 $288 = $287 ? Math_fround(0.0) : $265;
                 $289 = $288 > Math_fround(1.0);
                 $$op$i1$i$i$i$i = Math_fround($288 * Math_fround(255.0));
                 $290 = $289 ? Math_fround(255.0) : $$op$i1$i$i$i$i;
                 $291 = Math_fround($290 + Math_fround(0.5));
                 $292 = (~~(($291))>>>0);
                 $293 = $292&255;
                 HEAP8[$257>>0] = $293;
                 $294 = (($i2$013$i$i) + 1)|0;
                 $295 = HEAP32[$145>>2]|0;
                 $296 = ($294|0)<($295|0);
                 if ($296) {
                  $i2$013$i$i = $294;
                 } else {
                  $298 = $295;
                  break;
                 }
                }
               } else {
                if ($178) {
                 $i1$010$i$i = 0;
                } else {
                 $298 = $177;
                 break;
                }
                while(1) {
                 $179 = ((($vertexData$017$i$i) + (($i1$010$i$i*60)|0)|0) + 24|0);
                 $180 = HEAP8[$179>>0]|0;
                 $181 = $180&255;
                 $182 = (Math_fround(($181|0)));
                 $183 = Math_fround($182 / Math_fround(255.0));
                 $184 = ((($vertexData$017$i$i) + (($i1$010$i$i*60)|0)|0) + 25|0);
                 $185 = HEAP8[$184>>0]|0;
                 $186 = $185&255;
                 $187 = (Math_fround(($186|0)));
                 $188 = Math_fround($187 / Math_fround(255.0));
                 $189 = ((($vertexData$017$i$i) + (($i1$010$i$i*60)|0)|0) + 26|0);
                 $190 = HEAP8[$189>>0]|0;
                 $191 = $190&255;
                 $192 = (Math_fround(($191|0)));
                 $193 = Math_fround($192 / Math_fround(255.0));
                 $194 = ((($vertexData$017$i$i) + (($i1$010$i$i*60)|0)|0) + 27|0);
                 $195 = HEAP8[$194>>0]|0;
                 $196 = $195&255;
                 $197 = (Math_fround(($196|0)));
                 $198 = Math_fround($197 / Math_fround(255.0));
                 $199 = Math_fround($164 * $183);
                 $200 = Math_fround($166 * $188);
                 $201 = Math_fround($168 * $193);
                 $202 = Math_fround($174 * $198);
                 $203 = $199 < Math_fround(0.0);
                 $204 = $203 ? Math_fround(0.0) : $199;
                 $205 = $204 > Math_fround(1.0);
                 $$op$i$i$i1$i$i = Math_fround($204 * Math_fround(255.0));
                 $206 = $205 ? Math_fround(255.0) : $$op$i$i$i1$i$i;
                 $207 = Math_fround($206 + Math_fround(0.5));
                 $208 = (~~(($207))>>>0);
                 $209 = $200 < Math_fround(0.0);
                 $210 = $209 ? Math_fround(0.0) : $200;
                 $211 = $210 > Math_fround(1.0);
                 $$op$i3$i$i2$i$i = Math_fround($210 * Math_fround(255.0));
                 $212 = $211 ? Math_fround(255.0) : $$op$i3$i$i2$i$i;
                 $213 = Math_fround($212 + Math_fround(0.5));
                 $214 = (~~(($213))>>>0);
                 $215 = $214&255;
                 HEAP8[$184>>0] = $215;
                 $216 = $201 < Math_fround(0.0);
                 $217 = $216 ? Math_fround(0.0) : $201;
                 $218 = $217 > Math_fround(1.0);
                 $$op$i2$i$i3$i$i = Math_fround($217 * Math_fround(255.0));
                 $219 = $218 ? Math_fround(255.0) : $$op$i2$i$i3$i$i;
                 $220 = Math_fround($219 + Math_fround(0.5));
                 $221 = (~~(($220))>>>0);
                 $222 = $221&255;
                 HEAP8[$189>>0] = $222;
                 $223 = $202 < Math_fround(0.0);
                 $224 = $223 ? Math_fround(0.0) : $202;
                 $225 = $224 > Math_fround(1.0);
                 $$op$i1$i$i4$i$i = Math_fround($224 * Math_fround(255.0));
                 $226 = $225 ? Math_fround(255.0) : $$op$i1$i$i4$i$i;
                 $227 = Math_fround($226 + Math_fround(0.5));
                 $228 = (~~(($227))>>>0);
                 $229 = $228&255;
                 HEAP8[$194>>0] = $229;
                 $230 = $228 << 24;
                 $231 = $208 << 16;
                 $232 = $231 & 16711680;
                 $233 = $214 << 8;
                 $234 = $233 & 65280;
                 $235 = $221 & 255;
                 $236 = $234 | $232;
                 $237 = $236 | $235;
                 $238 = $237 | $230;
                 HEAP32[$179>>2] = $238;
                 $239 = (($i1$010$i$i) + 1)|0;
                 $240 = HEAP32[$145>>2]|0;
                 $241 = ($239|0)<($240|0);
                 if ($241) {
                  $i1$010$i$i = $239;
                 } else {
                  $298 = $240;
                  break;
                 }
                }
               }
              } while(0);
              $297 = ($298*60)|0;
              $299 = (($vertexData$017$i$i) + ($297)|0);
              $$pre$i$i = HEAP32[$138>>2]|0;
              $302 = $$pre$i$i;$vertexData$1$i$i = $299;
             }
             $300 = (($i$015$i$i) + 1)|0;
             $301 = ($300|0)<($302|0);
             if ($301) {
              $553 = $302;$i$015$i$i = $300;$vertexData$017$i$i = $vertexData$1$i$i;
             } else {
              break;
             }
            }
           }
           $303 = (($82) + ($i2$07$i<<4)|0);
           $304 = HEAP32[$303>>2]|0;
           $305 = (($304) + ($vertexIndex$06$i))|0;
           $vertexIndex$1$i = $305;
          }
          $306 = (($i2$07$i) + 1)|0;
          $exitcond20$i = ($306|0)==($83|0);
          if ($exitcond20$i) {
           break L52;
          } else {
           $i2$07$i = $306;$vertexIndex$06$i = $vertexIndex$1$i;
          }
         }
         $365 = ___cxa_find_matching_catch()|0;
         $366 = tempRet0;
         $eh$lpad$body$index8Z2D = $366;$eh$lpad$body$indexZ2D = $365;
         break L9;
        }
       } while(0);
       __THREW__ = 0;
       $307 = (invoke_iii(2710,($113|0),0)|0);
       $308 = __THREW__; __THREW__ = 0;
       $309 = $308&1;
       if ($309) {
        label = 80;
        break;
       }
       $310 = ($vertexCount$0$lcssa24$i|0)>(0);
       if ($310) {
        $$01$i$i = $307;$v$02$i$i = 0;
        while(1) {
         $311 = $v$02$i$i&65535;
         HEAP16[$$01$i$i>>1] = $311;
         $312 = $v$02$i$i | 1;
         $313 = $312&65535;
         $314 = (($$01$i$i) + 2|0);
         HEAP16[$314>>1] = $313;
         $315 = $v$02$i$i | 2;
         $316 = $315&65535;
         $317 = (($$01$i$i) + 4|0);
         HEAP16[$317>>1] = $316;
         $318 = (($$01$i$i) + 6|0);
         HEAP16[$318>>1] = $316;
         $319 = $v$02$i$i | 3;
         $320 = $319&65535;
         $321 = (($$01$i$i) + 8|0);
         HEAP16[$321>>1] = $320;
         $322 = (($$01$i$i) + 10|0);
         HEAP16[$322>>1] = $311;
         $323 = (($v$02$i$i) + 4)|0;
         $324 = (($$01$i$i) + 12|0);
         $325 = ($323|0)<($vertexCount$0$lcssa24$i|0);
         if ($325) {
          $$01$i$i = $324;$v$02$i$i = $323;
         } else {
          break;
         }
        }
       }
       L87: do {
        if ($84) {
         $i3$03$i = 0;
         while(1) {
          __THREW__ = 0;
          invoke_vii(3458,($113|0),($i3$03$i|0));
          $326 = __THREW__; __THREW__ = 0;
          $327 = $326&1;
          if ($327) {
           break;
          }
          $328 = (($i3$03$i) + 1)|0;
          $exitcond$i = ($328|0)==($83|0);
          if ($exitcond$i) {
           break L87;
          } else {
           $i3$03$i = $328;
          }
         }
         $363 = ___cxa_find_matching_catch()|0;
         $364 = tempRet0;
         $eh$lpad$body$index8Z2D = $364;$eh$lpad$body$indexZ2D = $363;
         break L9;
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3707,($113|0));
       $329 = __THREW__; __THREW__ = 0;
       $330 = $329&1;
       if ($330) {
        label = 80;
        break;
       }
       __THREW__ = 0;
       invoke_viii(2026,($113|0),159,1);
       $331 = __THREW__; __THREW__ = 0;
       $332 = $331&1;
       if ($332) {
        label = 80;
        break;
       }
       $$pre = HEAP32[$39>>2]|0;
       $334 = $$pre;
      }
      $333 = (($batchOutput) + 8|0);
      HEAP32[$333>>2] = $334;
      $335 = (($batchOutput) + 12|0);
      $336 = HEAP32[$335>>2]|0;
      $337 = $336 & 2147483647;
      $338 = ($337>>>0)<($334>>>0);
      do {
       if ($338) {
        $339 = ($336|0)>(-1);
        if ($339) {
         HEAP32[$335>>2] = $334;
         $340 = HEAP32[$batchOutput>>2]|0;
         $341 = $334 << 2;
         $342 = (($batchOutput) + 4|0);
         $343 = HEAP32[$342>>2]|0;
         HEAP32[$7>>2] = $343;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$7+0>>2]|0;
         $344 = (invoke_iiiiiiii(108,($340|0),($341|0),4,($$byval_copy32|0),0,(874480|0),370)|0);
         $345 = __THREW__; __THREW__ = 0;
         $346 = $345&1;
         if ($346) {
          label = 80;
          break L9;
         }
         HEAP32[$batchOutput>>2] = $344;
         break;
        } else {
         $347 = $334 << 2;
         $348 = (($batchOutput) + 4|0);
         $349 = HEAP32[$348>>2]|0;
         HEAP32[$8>>2] = $349;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$8+0>>2]|0;
         $350 = (invoke_iiiiiii(102,($347|0),4,($$byval_copy32|0),0,(874480|0),352)|0);
         $351 = __THREW__; __THREW__ = 0;
         $352 = $351&1;
         if ($352) {
          label = 80;
          break L9;
         }
         $353 = HEAP32[$batchOutput>>2]|0;
         $354 = HEAP32[$333>>2]|0;
         $355 = $354 << 2;
         _memcpy(($350|0),($353|0),($355|0))|0;
         HEAP32[$335>>2] = $334;
         HEAP32[$batchOutput>>2] = $350;
         break;
        }
       }
      } while(0);
      $356 = ($334|0)>(0);
      if ($356) {
       $357 = HEAP32[$batches>>2]|0;
       $i$055 = 0;
       while(1) {
        $358 = ((($357) + ($i$055<<4)|0) + 12|0);
        $359 = HEAP8[$358>>0]|0;
        $360 = ($359<<24>>24)==(0);
        if (!($360)) {
         $371 = ((($357) + ($i$055<<4)|0) + 4|0);
         $372 = HEAP32[$371>>2]|0;
         $373 = HEAP32[$372>>2]|0;
         $374 = HEAP32[$batchOutput>>2]|0;
         $375 = (($374) + ($i$055<<2)|0);
         HEAP32[$375>>2] = $373;
        }
        $376 = (($i$055) + 1)|0;
        $377 = ($376|0)<($334|0);
        if ($377) {
         $i$055 = $376;
        } else {
         break;
        }
       }
      }
      $378 = (($batchOutput) + 16|0);
      $379 = (($batchOutput) + 28|0);
      $380 = HEAP32[$379>>2]|0;
      $381 = $380 & 2147483647;
      $382 = ($381>>>0)<($334>>>0);
      do {
       if ($382) {
        $383 = ($380|0)>(-1);
        if ($383) {
         HEAP32[$379>>2] = $334;
         $384 = HEAP32[$378>>2]|0;
         $385 = $334 << 2;
         $386 = (($batchOutput) + 20|0);
         $387 = HEAP32[$386>>2]|0;
         HEAP32[$5>>2] = $387;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$5+0>>2]|0;
         $388 = (invoke_iiiiiiii(108,($384|0),($385|0),4,($$byval_copy32|0),0,(874480|0),370)|0);
         $389 = __THREW__; __THREW__ = 0;
         $390 = $389&1;
         if ($390) {
          label = 80;
          break L9;
         }
         HEAP32[$378>>2] = $388;
         break;
        } else {
         $391 = $334 << 2;
         $392 = (($batchOutput) + 20|0);
         $393 = HEAP32[$392>>2]|0;
         HEAP32[$6>>2] = $393;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$6+0>>2]|0;
         $394 = (invoke_iiiiiii(102,($391|0),4,($$byval_copy32|0),0,(874480|0),352)|0);
         $395 = __THREW__; __THREW__ = 0;
         $396 = $395&1;
         if ($396) {
          label = 80;
          break L9;
         }
         $397 = HEAP32[$378>>2]|0;
         $398 = (($batchOutput) + 24|0);
         $399 = HEAP32[$398>>2]|0;
         $400 = $399 << 2;
         _memcpy(($394|0),($397|0),($400|0))|0;
         HEAP32[$379>>2] = $334;
         HEAP32[$378>>2] = $394;
         break;
        }
       }
      } while(0);
      $401 = (($batchOutput) + 24|0);
      $402 = HEAP32[$401>>2]|0;
      $403 = ($402>>>0)<($334>>>0);
      if ($403) {
       $404 = HEAP32[$378>>2]|0;
       $405 = (($404) + ($334<<2)|0);
       $406 = ($402|0)==($334|0);
       if (!($406)) {
        $407 = (($404) + ($402<<2)|0);
        $$01$i$i26 = $407;
        while(1) {
         $408 = ($$01$i$i26|0)==(0|0);
         if (!($408)) {
          HEAP32[$$01$i$i26>>2] = 0;
         }
         $409 = (($$01$i$i26) + 4|0);
         $410 = ($409|0)==($405|0);
         if ($410) {
          break;
         } else {
          $$01$i$i26 = $409;
         }
        }
       }
      }
      HEAP32[$401>>2] = $334;
      L129: do {
       if ($356) {
        $411 = HEAP32[$batches>>2]|0;
        $412 = HEAP32[641904>>2]|0;
        $i1$051 = 0;
        L131: while(1) {
         $413 = ((($411) + ($i1$051<<4)|0) + 12|0);
         $414 = HEAP8[$413>>0]|0;
         $415 = ($414<<24>>24)==(0);
         do {
          if (!($415)) {
           $416 = ((($411) + ($i1$051<<4)|0) + 4|0);
           $417 = HEAP32[$416>>2]|0;
           $418 = (($417) + 4|0);
           $419 = HEAP32[$418>>2]|0;
           $420 = ($419|0)==(0);
           if (!($420)) {
            HEAP32[$4>>2] = $419;
            $421 = HEAP32[560624>>2]|0;
            $422 = ($421|0)==(0|0);
            do {
             if ($422) {
              label = 107;
             } else {
              $423 = (($421) + 36|0);
              $424 = HEAP32[$423>>2]|0;
              $425 = (($421) + 4|0);
              $426 = HEAP32[$425>>2]|0;
              $427 = ($424|0)==($426|0);
              do {
               if ($427) {
                $428 = (($421) + 28|0);
                $429 = HEAP32[$428>>2]|0;
                $430 = (($421) + 32|0);
                $431 = HEAP32[$430>>2]|0;
                $432 = (($429) + ($431<<3)|0);
                $448 = $432;
               } else {
                __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($$byval_copy32,$421,$4);
                $433 = HEAP32[$$byval_copy32>>2]|0;
                $434 = ($433|0)==(-1);
                $435 = (($421) + 28|0);
                $436 = HEAP32[$435>>2]|0;
                if ($434) {
                 $437 = (($421) + 32|0);
                 $438 = HEAP32[$437>>2]|0;
                 $439 = (($436) + ($438<<3)|0);
                 $448 = $439;
                 break;
                } else {
                 $440 = (($436) + ($433<<3)|0);
                 $448 = $440;
                 break;
                }
               }
              } while(0);
              $441 = HEAP32[560624>>2]|0;
              $442 = (($441) + 28|0);
              $443 = HEAP32[$442>>2]|0;
              $444 = (($441) + 32|0);
              $445 = HEAP32[$444>>2]|0;
              $446 = (($443) + ($445<<3)|0);
              $447 = ($448|0)==($446|0);
              if ($447) {
               label = 107;
               break;
              }
              $449 = (($448) + 4|0);
              $450 = HEAP32[$449>>2]|0;
              $451 = ($450|0)==(0|0);
              if ($451) {
               label = 107;
              } else {
               $$0$i48 = $450;
              }
             }
            } while(0);
            if ((label|0) == 107) {
             label = 0;
             __THREW__ = 0;
             $452 = (invoke_ii(3215,($419|0))|0);
             $453 = __THREW__; __THREW__ = 0;
             $454 = $453&1;
             if ($454) {
              break L131;
             }
             $455 = ($452|0)==(0|0);
             if ($455) {
              break;
             } else {
              $$0$i48 = $452;
             }
            }
            $456 = (($$0$i48) + 8|0);
            $457 = HEAP32[$456>>2]|0;
            $458 = $457 >>> 21;
            $459 = HEAP32[560640>>2]|0;
            $460 = Math_imul($459, $458)|0;
            $461 = (($460) + 27)|0;
            $462 = $461 >> 5;
            $463 = $462 << 5;
            $464 = (($461) - ($463))|0;
            $465 = HEAP32[560632>>2]|0;
            $466 = (($465) + ($462<<2)|0);
            $467 = HEAP32[$466>>2]|0;
            $468 = 1 << $464;
            $469 = $468 & $467;
            $470 = ($469|0)==(0);
            $471 = ($$0$i48|0)==(0|0);
            $or$cond = $470 | $471;
            if (!($or$cond)) {
             $472 = HEAP32[628400>>2]|0;
             HEAP32[$16>>2] = $472;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$16+0>>2]|0;
             $473 = (invoke_iiiiiii(103,36,($$byval_copy32|0),0,16,(874480|0),282)|0);
             $474 = __THREW__; __THREW__ = 0;
             $475 = $474&1;
             if ($475) {
              break L131;
             }
             $476 = HEAP32[628400>>2]|0;
             HEAP32[$473>>2] = 0;
             $477 = (($473) + 4|0);
             HEAP32[$477>>2] = $476;
             $478 = (($473) + 8|0);
             HEAP32[$478>>2] = 0;
             $479 = (($473) + 12|0);
             HEAP32[$479>>2] = 0;
             $480 = (($473) + 16|0);
             HEAP32[$480>>2] = 0;
             $481 = (($473) + 20|0);
             HEAP32[$481>>2] = $476;
             $482 = (($473) + 24|0);
             HEAP32[$482>>2] = 0;
             $483 = (($473) + 28|0);
             HEAP32[$483>>2] = 0;
             $484 = (($473) + 32|0);
             HEAP32[$484>>2] = $412;
             HEAP32[$3>>2] = -1;
             __THREW__ = 0;
             invoke_vii(2618,($3|0),(874488|0));
             $485 = __THREW__; __THREW__ = 0;
             $486 = $485&1;
             if ($486) {
              break L131;
             }
             $487 = HEAP32[$3>>2]|0;
             HEAP32[$17>>2] = $487;
             $488 = HEAP32[$$0$i48>>2]|0;
             $489 = (($488) + 92|0);
             $490 = HEAP32[$489>>2]|0;
             __THREW__ = 0;
             $491 = (invoke_ii($490|0,($$0$i48|0))|0);
             $492 = __THREW__; __THREW__ = 0;
             $493 = $492&1;
             if ($493) {
              break L131;
             }
             $494 = (($$0$i48) + 44|0);
             $495 = HEAP32[$494>>2]|0;
             HEAP32[$18>>2] = $495;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$18+0>>2]|0;
             invoke_viiii(434,($473|0),($17|0),($491|0),($$byval_copy32|0));
             $496 = __THREW__; __THREW__ = 0;
             $497 = $496&1;
             if ($497) {
              break L131;
             }
             $498 = HEAP32[$378>>2]|0;
             $499 = (($498) + ($i1$051<<2)|0);
             HEAP32[$499>>2] = $473;
            }
           }
          }
         } while(0);
         $500 = (($i1$051) + 1)|0;
         $501 = ($500|0)<($334|0);
         if ($501) {
          $i1$051 = $500;
         } else {
          break L129;
         }
        }
        $361 = ___cxa_find_matching_catch()|0;
        $362 = tempRet0;
        $eh$lpad$body$index8Z2D = $362;$eh$lpad$body$indexZ2D = $361;
        break L9;
       }
      } while(0);
      $502 = (($batchOutput) + 36|0);
      $503 = (($batchOutput) + 44|0);
      HEAP32[$503>>2] = $334;
      $504 = (($batchOutput) + 48|0);
      $505 = HEAP32[$504>>2]|0;
      $506 = $505 & 2147483647;
      $507 = ($506>>>0)<($334>>>0);
      do {
       if ($507) {
        $508 = ($505|0)>(-1);
        if ($508) {
         HEAP32[$504>>2] = $334;
         $509 = HEAP32[$502>>2]|0;
         $510 = (($batchOutput) + 40|0);
         $511 = HEAP32[$510>>2]|0;
         HEAP32[$1>>2] = $511;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$1+0>>2]|0;
         $512 = (invoke_iiiiiiii(108,($509|0),($334|0),1,($$byval_copy32|0),0,(874480|0),370)|0);
         $513 = __THREW__; __THREW__ = 0;
         $514 = $513&1;
         if ($514) {
          label = 80;
          break L9;
         }
         HEAP32[$502>>2] = $512;
         break;
        } else {
         $515 = (($batchOutput) + 40|0);
         $516 = HEAP32[$515>>2]|0;
         HEAP32[$2>>2] = $516;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$2+0>>2]|0;
         $517 = (invoke_iiiiiii(102,($334|0),1,($$byval_copy32|0),0,(874480|0),352)|0);
         $518 = __THREW__; __THREW__ = 0;
         $519 = $518&1;
         if ($519) {
          label = 80;
          break L9;
         }
         $520 = HEAP32[$502>>2]|0;
         $521 = HEAP32[$503>>2]|0;
         _memcpy(($517|0),($520|0),($521|0))|0;
         HEAP32[$504>>2] = $334;
         HEAP32[$502>>2] = $517;
         break;
        }
       }
      } while(0);
      if ($356) {
       $522 = HEAP32[$batches>>2]|0;
       $523 = HEAP32[$502>>2]|0;
       $i2$049 = 0;
       while(1) {
        $524 = ((($522) + ($i2$049<<4)|0) + 12|0);
        $525 = HEAP8[$524>>0]|0;
        $526 = (($523) + ($i2$049)|0);
        $527 = $525 ^ 1;
        HEAP8[$526>>0] = $527;
        $528 = (($i2$049) + 1)|0;
        $529 = ($528|0)<($334|0);
        if ($529) {
         $i2$049 = $528;
        } else {
         break;
        }
       }
      }
      $530 = HEAP32[$40>>2]|0;
      $531 = ($530|0)>(-1);
      if ($531) {
       $532 = HEAP32[$batches>>2]|0;
       $533 = HEAP32[$38>>2]|0;
       HEAP32[$0>>2] = $533;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($532|0),($$byval_copy32|0));
       $534 = __THREW__; __THREW__ = 0;
       $535 = $534&1;
       if ($535) {
        $552 = $537;
        label = 6;
        break L6;
       }
       HEAP32[$batches>>2] = 0;
      }
      $536 = ($537|0)==(0|0);
      if ($536) {
       STACKTOP = sp;return;
      }
      $538 = HEAP32[628512>>2]|0;
      HEAP32[$0>>2] = $538;
      ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($537,$$byval_copy32);
      STACKTOP = sp;return;
     }
    } while(0);
    if ((label|0) == 80) {
     $369 = ___cxa_find_matching_catch()|0;
     $370 = tempRet0;
     $eh$lpad$body$index8Z2D = $370;$eh$lpad$body$indexZ2D = $369;
    }
    $539 = HEAP32[$40>>2]|0;
    $540 = ($539|0)>(-1);
    if ($540) {
     $541 = HEAP32[$batches>>2]|0;
     $542 = HEAP32[$38>>2]|0;
     HEAP32[$13>>2] = $542;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$13+0>>2]|0;
     invoke_vii(2591,($541|0),($$byval_copy32|0));
     $543 = __THREW__; __THREW__ = 0;
     $544 = $543&1;
     if ($544) {
      $550 = ___cxa_find_matching_catch(0|0)|0;
      $551 = tempRet0;
      ___clang_call_terminate($550);
      // unreachable;
     } else {
      HEAP32[$batches>>2] = 0;
      $$1 = $eh$lpad$body$indexZ2D;$$12 = $eh$lpad$body$index8Z2D;$546 = $537;
      break;
     }
    } else {
     $$1 = $eh$lpad$body$indexZ2D;$$12 = $eh$lpad$body$index8Z2D;$546 = $537;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  $$1 = $28;$$12 = $29;$546 = $552;
 }
 $545 = ($546|0)==(0|0);
 if ($545) {
  ___resumeException($$1|0);
  // unreachable;
 }
 $547 = HEAP32[628512>>2]|0;
 HEAP32[$14>>2] = $547;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy32+0>>2]=HEAP32[$14+0>>2]|0;
 invoke_vii(2591,($546|0),($$byval_copy32|0));
 $548 = __THREW__; __THREW__ = 0;
 $549 = $548&1;
 if ($549) {
  $550 = ___cxa_find_matching_catch(0|0)|0;
  $551 = tempRet0;
  ___clang_call_terminate($550);
  // unreachable;
 } else {
  ___resumeException($$1|0);
  // unreachable;
 }
}
function __ZN2UI15SortForBatchingEPKNS_13UIInstructionEjPS0_($uiInstructions,$count,$outputUIInstructions) {
 $uiInstructions = $uiInstructions|0;
 $count = $count|0;
 $outputUIInstructions = $outputUIInstructions|0;
 var $$byval_copy9 = 0, $$index = 0, $$index3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0);
 var $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $allocPtr$0 = 0;
 var $exitcond = 0, $i$02 = 0, $visibleIndex$0$lcssa = 0, $visibleIndex$03 = 0, $visibleIndex$1 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy9 = sp;
 $0 = sp + 8|0;
 $1 = sp + 4|0;
 $2 = ($count*20)|0;
 $3 = (($2) + 15)|0;
 $4 = ($3>>>0)<(2000);
 $5 = ($count|0)!=(0);
 if ($4) {
  if ($5) {
   $6 = STACKTOP; STACKTOP = STACKTOP + ((((1*$3)|0)+15)&-16)|0;;
   $16 = 0;$allocPtr$0 = $6;
  } else {
   $16 = 0;$allocPtr$0 = 0;
  }
 } else {
  if ($5) {
   $7 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $7;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
   $8 = (invoke_iiiiiii(102,($3|0),16,($$byval_copy9|0),0,(874592|0),109)|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    $$index = $11;$$index3 = $12;$55 = $0;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $16 = $8;$allocPtr$0 = $8;
   }
  } else {
   $16 = 0;$allocPtr$0 = 0;
  }
 }
 $20 = $allocPtr$0;
 $21 = (($20) + 15)|0;
 $22 = $21 & -16;
 $23 = $22;
 __THREW__ = 0;
 invoke_viii(2077,($uiInstructions|0),($count|0),($23|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $15 = ($16|0)==(0|0);
  if ($15) {
   $$index = $13;$$index3 = $14;$55 = $0;
   ___resumeException($$index|0);
   // unreachable;
  }
  $17 = HEAP32[628512>>2]|0;
  HEAP32[$0>>2] = $17;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($16|0),($$byval_copy9|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   $53 = ___cxa_find_matching_catch(0|0)|0;
   $54 = tempRet0;
   ___clang_call_terminate($53);
   // unreachable;
  } else {
   $$index = $13;$$index3 = $14;$55 = $0;
   ___resumeException($$index|0);
   // unreachable;
  }
 }
 $26 = (($23) + (($count*20)|0)|0);
 __ZNSt3__16__sortIRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEvT0_S7_T_($23,$26,$$byval_copy9);
 $27 = ($count|0)>(0);
 if ($27) {
  $i$02 = 0;$visibleIndex$03 = 0;
  while(1) {
   $28 = (($23) + (($i$02*20)|0)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)==(-1);
   if ($30) {
    $visibleIndex$1 = $visibleIndex$03;
   } else {
    $31 = ((($23) + (($i$02*20)|0)|0) + 4|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($uiInstructions) + (($32*152)|0)|0);
    $34 = (($visibleIndex$03) + 1)|0;
    $35 = (($outputUIInstructions) + (($visibleIndex$03*152)|0)|0);
    dest=$35+0|0; src=$33+0|0; stop=dest+116|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $36 = ((($uiInstructions) + (($32*152)|0)|0) + 116|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = ((($uiInstructions) + (($32*152)|0)|0) + 120|0);
    $39 = Math_fround(HEAPF32[$38>>2]);
    $40 = ((($uiInstructions) + (($32*152)|0)|0) + 124|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    $42 = ((($uiInstructions) + (($32*152)|0)|0) + 128|0);
    $43 = Math_fround(HEAPF32[$42>>2]);
    $44 = ((($outputUIInstructions) + (($visibleIndex$03*152)|0)|0) + 116|0);
    HEAPF32[$44>>2] = $37;
    $45 = ((($outputUIInstructions) + (($visibleIndex$03*152)|0)|0) + 120|0);
    HEAPF32[$45>>2] = $39;
    $46 = ((($outputUIInstructions) + (($visibleIndex$03*152)|0)|0) + 124|0);
    HEAPF32[$46>>2] = $41;
    $47 = ((($outputUIInstructions) + (($visibleIndex$03*152)|0)|0) + 128|0);
    HEAPF32[$47>>2] = $43;
    $48 = ((($outputUIInstructions) + (($visibleIndex$03*152)|0)|0) + 132|0);
    $49 = ((($uiInstructions) + (($32*152)|0)|0) + 132|0);
    ;HEAP32[$48+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$48+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$48+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$48+12>>2]=HEAP32[$49+12>>2]|0;HEAP8[$48+16>>0]=HEAP8[$49+16>>0]|0;
    $visibleIndex$1 = $34;
   }
   $50 = (($i$02) + 1)|0;
   $exitcond = ($50|0)==($count|0);
   if ($exitcond) {
    $visibleIndex$0$lcssa = $visibleIndex$1;
    break;
   } else {
    $i$02 = $50;$visibleIndex$03 = $visibleIndex$1;
   }
  }
 } else {
  $visibleIndex$0$lcssa = 0;
 }
 $51 = ($16|0)==(0|0);
 if ($51) {
  STACKTOP = sp;return ($visibleIndex$0$lcssa|0);
 }
 $52 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $52;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($16,$$byval_copy9);
 STACKTOP = sp;return ($visibleIndex$0$lcssa|0);
}
function __ZN2UIL19PrepareDepthEntriesEPKNS_13UIInstructionEjPNS_14DepthSortEntryE($uiInstruction,$count,$output) {
 $uiInstruction = $uiInstruction|0;
 $count = $count|0;
 $output = $output|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0);
 var $62 = Math_fround(0), $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $allocPtr$0 = 0, $exitcond = 0, $exitcond8 = 0, $indvars$iv = 0, $indvars$iv$next = 0, $j$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = $count << 4;
 $3 = $2 | 15;
 $4 = ($3>>>0)<(2000);
 $5 = ($count|0)!=(0);
 if ($4) {
  if ($5) {
   $6 = STACKTOP; STACKTOP = STACKTOP + ((((1*$3)|0)+15)&-16)|0;;
   $82 = 0;$allocPtr$0 = $6;
  } else {
   label = 6;
  }
 } else {
  if ($5) {
   $7 = HEAP32[628512>>2]|0;
   HEAP32[$1>>2] = $7;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   $8 = (__Z15malloc_internaljj10MemLabelIdiPKci($3,16,$$byval_copy1,0,874592,46)|0);
   $82 = $8;$allocPtr$0 = $8;
  } else {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  $84 = $0;
  STACKTOP = sp;return;
 }
 $9 = $allocPtr$0;
 $10 = (($9) + 15)|0;
 $11 = $10 & -16;
 $12 = $11;
 $13 = ($count|0)>(0);
 if ($13) {
  $indvars$iv = 0;
  while(1) {
   $14 = (($output) + (($indvars$iv*20)|0)|0);
   $15 = ((($output) + (($indvars$iv*20)|0)|0) + 4|0);
   HEAP32[$15>>2] = $indvars$iv;
   $16 = ((($uiInstruction) + (($indvars$iv*152)|0)|0) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ((($output) + (($indvars$iv*20)|0)|0) + 8|0);
   HEAP32[$18>>2] = $17;
   $19 = (($uiInstruction) + (($indvars$iv*152)|0)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ((($output) + (($indvars$iv*20)|0)|0) + 12|0);
   HEAP32[$21>>2] = $20;
   $22 = ((($uiInstruction) + (($indvars$iv*152)|0)|0) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($output) + (($indvars$iv*20)|0)|0) + 16|0);
   HEAP32[$24>>2] = $23;
   $25 = ((($uiInstruction) + (($indvars$iv*152)|0)|0) + 140|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0);
   if ($27) {
    label = 10;
   } else {
    $28 = HEAP32[$19>>2]|0;
    $29 = ($28|0)==(0);
    if ($29) {
     label = 10;
    } else {
     label = 12;
    }
   }
   if ((label|0) == 10) {
    label = 0;
    $30 = ((($uiInstruction) + (($indvars$iv*152)|0)|0) + 148|0);
    $31 = HEAP8[$30>>0]|0;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     HEAP32[$14>>2] = -1;
    } else {
     label = 12;
    }
   }
   if ((label|0) == 12) {
    label = 0;
    $33 = (($12) + ($indvars$iv<<4)|0);
    $34 = ((($uiInstruction) + (($indvars$iv*152)|0)|0) + 100|0);
    ;HEAP32[$33+0>>2]=HEAP32[$34+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$34+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$34+12>>2]|0;
    $35 = Math_fround(HEAPF32[$34>>2]);
    $36 = ((($uiInstruction) + (($indvars$iv*152)|0)|0) + 104|0);
    $37 = Math_fround(HEAPF32[$36>>2]);
    $38 = ($indvars$iv|0)>(0);
    if ($38) {
     $39 = ((($uiInstruction) + (($indvars$iv*152)|0)|0) + 112|0);
     $40 = ((($uiInstruction) + (($indvars$iv*152)|0)|0) + 108|0);
     $41 = Math_fround(HEAPF32[$39>>2]);
     $42 = Math_fround(HEAPF32[$40>>2]);
     $43 = Math_fround($35 + $42);
     $44 = Math_fround($37 + $41);
     $74 = 0;$j$02 = 0;
     while(1) {
      $45 = (($output) + (($j$02*20)|0)|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(-1);
      do {
       if ($47) {
        $85 = $74;
       } else {
        $48 = (($12) + ($j$02<<4)|0);
        $49 = Math_fround(HEAPF32[$48>>2]);
        $50 = $43 < $49;
        $51 = ((($12) + ($j$02<<4)|0) + 8|0);
        $52 = Math_fround(HEAPF32[$51>>2]);
        $53 = Math_fround($49 + $52);
        $54 = $53 < $35;
        $55 = $50 | $54;
        $56 = ((($12) + ($j$02<<4)|0) + 4|0);
        $57 = Math_fround(HEAPF32[$56>>2]);
        $58 = $44 < $57;
        $59 = $55 | $58;
        $60 = ((($12) + ($j$02<<4)|0) + 12|0);
        $61 = Math_fround(HEAPF32[$60>>2]);
        $62 = Math_fround($57 + $61);
        $63 = $62 < $37;
        $64 = $59 | $63;
        if ($64) {
         $85 = $74;
        } else {
         $65 = HEAP32[$19>>2]|0;
         $66 = (($uiInstruction) + (($j$02*152)|0)|0);
         $67 = HEAP32[$66>>2]|0;
         $68 = ($65|0)==($67|0);
         if ($68) {
          $69 = HEAP32[$22>>2]|0;
          $70 = ((($uiInstruction) + (($j$02*152)|0)|0) + 4|0);
          $71 = HEAP32[$70>>2]|0;
          $72 = ($69|0)==($71|0);
          if ($72) {
           $73 = ($46|0)<($74|0);
           $75 = $73 ? $74 : $46;
           $85 = $75;
           break;
          }
         }
         $76 = (($46) + 1)|0;
         $77 = ($76|0)<($74|0);
         $78 = $77 ? $74 : $76;
         $85 = $78;
        }
       }
      } while(0);
      $79 = (($j$02) + 1)|0;
      $exitcond = ($79|0)==($indvars$iv|0);
      if ($exitcond) {
       $80 = $85;
       break;
      } else {
       $74 = $85;$j$02 = $79;
      }
     }
    } else {
     $80 = 0;
    }
    HEAP32[$14>>2] = $80;
   }
   $indvars$iv$next = (($indvars$iv) + 1)|0;
   $exitcond8 = ($indvars$iv$next|0)==($count|0);
   if ($exitcond8) {
    break;
   } else {
    $indvars$iv = $indvars$iv$next;
   }
  }
 }
 $81 = ($82|0)==(0|0);
 if ($81) {
  $84 = $0;
  STACKTOP = sp;return;
 }
 $83 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $83;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($82,$$byval_copy1);
 $84 = $0;
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$029 = 0, $__i$1 = 0, $__i$2 = 0;
 var $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$026 = 0, $__j$026$phi = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i24 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i24 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -20|0);
  $2 = (($$01$ph) + -40|0);
  $3 = (($$01$ph) + -8|0);
  $4 = (($$01$ph) + -4|0);
  $5 = (($$01$ph) + -12|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $6 = $$0;
   $7 = (($0) - ($6))|0;
   $8 = (($7|0) / 20)&-1;
   switch ($8|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 14;
    break L1;
    break;
   }
   case 3:  {
    label = 12;
    break L1;
    break;
   }
   case 4:  {
    label = 13;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 111;
    break L1;
    break;
   }
   default: {
   }
   }
   $33 = ($7|0)<(620);
   if ($33) {
    label = 16;
    break L1;
   }
   $34 = ($7|0)>(19980);
   $35 = (($7|0) / 40)&-1;
   $36 = (($$0) + (($35*20)|0)|0);
   if ($34) {
    $37 = (($7|0) / 80)&-1;
    $38 = (($$0) + (($37*20)|0)|0);
    $$sum = (($37) + ($35))|0;
    $39 = (($$0) + (($$sum*20)|0)|0);
    $40 = (__ZNSt3__17__sort5IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($$0,$38,$36,$39,$1,0)|0);
    $__n_swaps$0 = $40;
   } else {
    $41 = (__ZNSt3__17__sort3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_T_($$0,$36,$1,0)|0);
    $__n_swaps$0 = $41;
   }
   $42 = HEAP32[$$0>>2]|0;
   $43 = HEAP32[$36>>2]|0;
   $44 = ($42|0)==($43|0);
   do {
    if ($44) {
     $46 = (($$0) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ((($$0) + (($35*20)|0)|0) + 12|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($47|0)==($49|0);
     if (!($50)) {
      $51 = ($47|0)<($49|0);
      if ($51) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 27;
       break;
      }
     }
     $52 = (($$0) + 16|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ((($$0) + (($35*20)|0)|0) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($53|0)==($55|0);
     if ($56) {
      $58 = (($$0) + 8|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = ((($$0) + (($35*20)|0)|0) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($59|0)<($61|0);
      if ($62) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 27;
       break;
      }
     } else {
      $57 = ($53|0)<($55|0);
      if ($57) {
       $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
       break;
      } else {
       label = 27;
       break;
      }
     }
    } else {
     $45 = ($42|0)<($43|0);
     if ($45) {
      $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
     } else {
      label = 27;
     }
    }
   } while(0);
   L20: do {
    if ((label|0) == 27) {
     label = 0;
     $63 = ($$0|0)==($2|0);
     L22: do {
      if (!($63)) {
       $64 = ((($$0) + (($35*20)|0)|0) + 12|0);
       $65 = ((($$0) + (($35*20)|0)|0) + 16|0);
       $66 = ((($$0) + (($35*20)|0)|0) + 8|0);
       $153 = $2;$__j$026 = $1;
       L24: while(1) {
        $152 = HEAP32[$153>>2]|0;
        $154 = ($152|0)==($43|0);
        do {
         if ($154) {
          $156 = (($__j$026) + -8|0);
          $157 = HEAP32[$156>>2]|0;
          $158 = HEAP32[$64>>2]|0;
          $159 = ($157|0)==($158|0);
          if (!($159)) {
           $160 = ($157|0)<($158|0);
           if ($160) {
            break L24;
           } else {
            break;
           }
          }
          $161 = (($__j$026) + -4|0);
          $162 = HEAP32[$161>>2]|0;
          $163 = HEAP32[$65>>2]|0;
          $164 = ($162|0)==($163|0);
          if ($164) {
           $166 = (($__j$026) + -12|0);
           $167 = HEAP32[$166>>2]|0;
           $168 = HEAP32[$66>>2]|0;
           $169 = ($167|0)<($168|0);
           if ($169) {
            break L24;
           } else {
            break;
           }
          } else {
           $165 = ($162|0)<($163|0);
           if ($165) {
            break L24;
           } else {
            break;
           }
          }
         } else {
          $155 = ($152|0)<($43|0);
          if ($155) {
           break L24;
          }
         }
        } while(0);
        $170 = (($153) + -20|0);
        $171 = ($$0|0)==($170|0);
        if ($171) {
         break L22;
        } else {
         $__j$026$phi = $153;$153 = $170;$__j$026 = $__j$026$phi;
        }
       }
       ;HEAP32[$__t$i24+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$$0+16>>2]|0;
       ;HEAP32[$$0+0>>2]=HEAP32[$153+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$153+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$153+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$153+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$153+16>>2]|0;
       ;HEAP32[$153+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$153+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$153+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$153+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$153+16>>2]=HEAP32[$__t$i24+16>>2]|0;
       $172 = (($__n_swaps$0) + 1)|0;
       $__j$3 = $153;$__n_swaps$3 = $172;
       break L20;
      }
     } while(0);
     $67 = (($$0) + 20|0);
     $68 = HEAP32[$1>>2]|0;
     $69 = ($42|0)==($68|0);
     do {
      if ($69) {
       $71 = (($$0) + 12|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = HEAP32[$3>>2]|0;
       $74 = ($72|0)==($73|0);
       if (!($74)) {
        $75 = ($72|0)<($73|0);
        if ($75) {
         $__i$1 = $67;
         break;
        } else {
         label = 36;
         break;
        }
       }
       $76 = (($$0) + 16|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = HEAP32[$4>>2]|0;
       $79 = ($77|0)==($78|0);
       if ($79) {
        $81 = (($$0) + 8|0);
        $82 = HEAP32[$81>>2]|0;
        $83 = HEAP32[$5>>2]|0;
        $84 = ($82|0)<($83|0);
        if ($84) {
         $__i$1 = $67;
         break;
        } else {
         label = 36;
         break;
        }
       } else {
        $80 = ($77|0)<($78|0);
        if ($80) {
         $__i$1 = $67;
         break;
        } else {
         label = 36;
         break;
        }
       }
      } else {
       $70 = ($42|0)<($68|0);
       if ($70) {
        $__i$1 = $67;
       } else {
        label = 36;
       }
      }
     } while(0);
     if ((label|0) == 36) {
      label = 0;
      $85 = ($67|0)==($1|0);
      if ($85) {
       label = 111;
       break L1;
      }
      $86 = (($$0) + 12|0);
      $87 = (($$0) + 16|0);
      $88 = (($$0) + 8|0);
      $__i$029 = $67;
      L50: while(1) {
       $89 = HEAP32[$__i$029>>2]|0;
       $90 = ($42|0)==($89|0);
       do {
        if ($90) {
         $92 = HEAP32[$86>>2]|0;
         $93 = (($__i$029) + 12|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = ($92|0)==($94|0);
         if (!($95)) {
          $96 = ($92|0)<($94|0);
          if ($96) {
           break L50;
          } else {
           break;
          }
         }
         $97 = HEAP32[$87>>2]|0;
         $98 = (($__i$029) + 16|0);
         $99 = HEAP32[$98>>2]|0;
         $100 = ($97|0)==($99|0);
         if ($100) {
          $102 = HEAP32[$88>>2]|0;
          $103 = (($__i$029) + 8|0);
          $104 = HEAP32[$103>>2]|0;
          $105 = ($102|0)<($104|0);
          if ($105) {
           break L50;
          } else {
           break;
          }
         } else {
          $101 = ($97|0)<($99|0);
          if ($101) {
           break L50;
          } else {
           break;
          }
         }
        } else {
         $91 = ($42|0)<($89|0);
         if ($91) {
          break L50;
         }
        }
       } while(0);
       $107 = (($__i$029) + 20|0);
       $108 = ($107|0)==($1|0);
       if ($108) {
        label = 111;
        break L1;
       } else {
        $__i$029 = $107;
       }
      }
      ;HEAP32[$__t$i24+0>>2]=HEAP32[$__i$029+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$__i$029+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$__i$029+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$__i$029+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$__i$029+16>>2]|0;
      ;HEAP32[$__i$029+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$029+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$029+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$029+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__i$029+16>>2]=HEAP32[$1+16>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i24+16>>2]|0;
      $106 = (($__i$029) + 20|0);
      $__i$1 = $106;
     }
     $109 = ($__i$1|0)==($1|0);
     if ($109) {
      label = 111;
      break L1;
     }
     $110 = (($$0) + 8|0);
     $111 = (($$0) + 12|0);
     $112 = (($$0) + 16|0);
     $__i$2$ph = $__i$1;$__j$1$ph = $1;
     while(1) {
      $113 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      L67: while(1) {
       $114 = HEAP32[$__i$2>>2]|0;
       $115 = ($113|0)==($114|0);
       do {
        if ($115) {
         $117 = HEAP32[$111>>2]|0;
         $118 = (($__i$2) + 12|0);
         $119 = HEAP32[$118>>2]|0;
         $120 = ($117|0)==($119|0);
         if (!($120)) {
          $121 = ($117|0)<($119|0);
          if ($121) {
           $__j$2 = $__j$1$ph;
           break L67;
          } else {
           break;
          }
         }
         $122 = HEAP32[$112>>2]|0;
         $123 = (($__i$2) + 16|0);
         $124 = HEAP32[$123>>2]|0;
         $125 = ($122|0)==($124|0);
         if ($125) {
          $127 = HEAP32[$110>>2]|0;
          $128 = (($__i$2) + 8|0);
          $129 = HEAP32[$128>>2]|0;
          $130 = ($127|0)<($129|0);
          if ($130) {
           $__j$2 = $__j$1$ph;
           break L67;
          } else {
           break;
          }
         } else {
          $126 = ($122|0)<($124|0);
          if ($126) {
           $__j$2 = $__j$1$ph;
           break L67;
          } else {
           break;
          }
         }
        } else {
         $116 = ($113|0)<($114|0);
         if ($116) {
          $__j$2 = $__j$1$ph;
          break L67;
         }
        }
       } while(0);
       $131 = (($__i$2) + 20|0);
       $__i$2 = $131;
      }
      while(1) {
       $132 = (($__j$2) + -20|0);
       $133 = HEAP32[$132>>2]|0;
       $134 = ($113|0)==($133|0);
       if (!($134)) {
        $135 = ($113|0)<($133|0);
        if ($135) {
         $__j$2 = $132;
         continue;
        } else {
         break;
        }
       }
       $136 = HEAP32[$111>>2]|0;
       $137 = (($__j$2) + -8|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = ($136|0)==($138|0);
       if (!($139)) {
        $140 = ($136|0)<($138|0);
        if ($140) {
         $__j$2 = $132;
         continue;
        } else {
         break;
        }
       }
       $141 = HEAP32[$112>>2]|0;
       $142 = (($__j$2) + -4|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ($141|0)==($143|0);
       if ($144) {
        $146 = HEAP32[$110>>2]|0;
        $147 = (($__j$2) + -12|0);
        $148 = HEAP32[$147>>2]|0;
        $149 = ($146|0)<($148|0);
        if ($149) {
         $__j$2 = $132;
         continue;
        } else {
         break;
        }
       } else {
        $145 = ($141|0)<($143|0);
        if ($145) {
         $__j$2 = $132;
         continue;
        } else {
         break;
        }
       }
      }
      $150 = ($__i$2>>>0)<($132>>>0);
      if (!($150)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i24+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$__i$2+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$__i$2+16>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$132+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$132+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$132+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$132+12>>2]|0;HEAP32[$__i$2+16>>2]=HEAP32[$132+16>>2]|0;
      ;HEAP32[$132+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$132+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$132+16>>2]=HEAP32[$__t$i24+16>>2]|0;
      $151 = (($__i$2) + 20|0);
      $__i$2$ph = $151;$__j$1$ph = $132;
     }
    }
   } while(0);
   $173 = (($$0) + 20|0);
   $174 = ($173>>>0)<($__j$3>>>0);
   L93: do {
    if ($174) {
     $__i$3$ph = $173;$__j$4$ph = $__j$3;$__m$0$ph = $36;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $175 = HEAP32[$__m$0$ph>>2]|0;
      $176 = (($__m$0$ph) + 12|0);
      $177 = (($__m$0$ph) + 16|0);
      $178 = (($__m$0$ph) + 8|0);
      $__i$3 = $__i$3$ph;
      L96: while(1) {
       $179 = HEAP32[$__i$3>>2]|0;
       $180 = ($179|0)==($175|0);
       do {
        if ($180) {
         $182 = (($__i$3) + 12|0);
         $183 = HEAP32[$182>>2]|0;
         $184 = HEAP32[$176>>2]|0;
         $185 = ($183|0)==($184|0);
         if (!($185)) {
          $186 = ($183|0)<($184|0);
          if ($186) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L96;
          }
         }
         $187 = (($__i$3) + 16|0);
         $188 = HEAP32[$187>>2]|0;
         $189 = HEAP32[$177>>2]|0;
         $190 = ($188|0)==($189|0);
         if ($190) {
          $192 = (($__i$3) + 8|0);
          $193 = HEAP32[$192>>2]|0;
          $194 = HEAP32[$178>>2]|0;
          $195 = ($193|0)<($194|0);
          if ($195) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L96;
          }
         } else {
          $191 = ($188|0)<($189|0);
          if ($191) {
           break;
          } else {
           $__j$5 = $__j$4$ph;
           break L96;
          }
         }
        } else {
         $181 = ($179|0)<($175|0);
         if (!($181)) {
          $__j$5 = $__j$4$ph;
          break L96;
         }
        }
       } while(0);
       $196 = (($__i$3) + 20|0);
       $__i$3 = $196;
      }
      while(1) {
       $197 = (($__j$5) + -20|0);
       $198 = HEAP32[$197>>2]|0;
       $199 = ($198|0)==($175|0);
       if (!($199)) {
        $200 = ($198|0)<($175|0);
        if ($200) {
         break;
        } else {
         $__j$5 = $197;
         continue;
        }
       }
       $201 = (($__j$5) + -8|0);
       $202 = HEAP32[$201>>2]|0;
       $203 = HEAP32[$176>>2]|0;
       $204 = ($202|0)==($203|0);
       if (!($204)) {
        $205 = ($202|0)<($203|0);
        if ($205) {
         break;
        } else {
         $__j$5 = $197;
         continue;
        }
       }
       $206 = (($__j$5) + -4|0);
       $207 = HEAP32[$206>>2]|0;
       $208 = HEAP32[$177>>2]|0;
       $209 = ($207|0)==($208|0);
       if ($209) {
        $211 = (($__j$5) + -12|0);
        $212 = HEAP32[$211>>2]|0;
        $213 = HEAP32[$178>>2]|0;
        $214 = ($212|0)<($213|0);
        if ($214) {
         break;
        } else {
         $__j$5 = $197;
         continue;
        }
       } else {
        $210 = ($207|0)<($208|0);
        if ($210) {
         break;
        } else {
         $__j$5 = $197;
         continue;
        }
       }
      }
      $215 = ($__i$3>>>0)>($197>>>0);
      if ($215) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L93;
      }
      ;HEAP32[$__t$i24+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$__i$3+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$__i$3+16>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$197+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$197+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$197+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$197+12>>2]|0;HEAP32[$__i$3+16>>2]=HEAP32[$197+16>>2]|0;
      ;HEAP32[$197+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$197+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$197+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$197+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$197+16>>2]=HEAP32[$__t$i24+16>>2]|0;
      $216 = (($__n_swaps$4$ph) + 1)|0;
      $217 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $217 ? $197 : $__m$0$ph;
      $218 = (($__i$3) + 20|0);
      $__i$3$ph = $218;$__j$4$ph = $197;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $216;
     }
    } else {
     $__i$4 = $173;$__m$2 = $36;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $219 = ($__i$4|0)==($__m$2|0);
   L122: do {
    if ($219) {
     $__n_swaps$6 = $__n_swaps$5;
    } else {
     $220 = HEAP32[$__m$2>>2]|0;
     $221 = HEAP32[$__i$4>>2]|0;
     $222 = ($220|0)==($221|0);
     do {
      if ($222) {
       $224 = (($__m$2) + 12|0);
       $225 = HEAP32[$224>>2]|0;
       $226 = (($__i$4) + 12|0);
       $227 = HEAP32[$226>>2]|0;
       $228 = ($225|0)==($227|0);
       if (!($228)) {
        $229 = ($225|0)<($227|0);
        if ($229) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L122;
        }
       }
       $230 = (($__m$2) + 16|0);
       $231 = HEAP32[$230>>2]|0;
       $232 = (($__i$4) + 16|0);
       $233 = HEAP32[$232>>2]|0;
       $234 = ($231|0)==($233|0);
       if ($234) {
        $236 = (($__m$2) + 8|0);
        $237 = HEAP32[$236>>2]|0;
        $238 = (($__i$4) + 8|0);
        $239 = HEAP32[$238>>2]|0;
        $240 = ($237|0)<($239|0);
        if ($240) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L122;
        }
       } else {
        $235 = ($231|0)<($233|0);
        if ($235) {
         break;
        } else {
         $__n_swaps$6 = $__n_swaps$5;
         break L122;
        }
       }
      } else {
       $223 = ($220|0)<($221|0);
       if (!($223)) {
        $__n_swaps$6 = $__n_swaps$5;
        break L122;
       }
      }
     } while(0);
     ;HEAP32[$__t$i24+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$__i$4+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$__i$4+16>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;HEAP32[$__i$4+16>>2]=HEAP32[$__m$2+16>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$__m$2+16>>2]=HEAP32[$__t$i24+16>>2]|0;
     $241 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $241;
    }
   } while(0);
   $242 = ($__n_swaps$6|0)==(0);
   if ($242) {
    $243 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEbT0_S7_T_($$0,$__i$4,0)|0);
    $244 = (($__i$4) + 20|0);
    $245 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEbT0_S7_T_($244,$$01$ph,0)|0);
    if ($245) {
     label = 106;
     break;
    }
    if ($243) {
     $$0 = $244;
     continue;
    }
   }
   $246 = $__i$4;
   $247 = (($246) - ($6))|0;
   $248 = (($0) - ($246))|0;
   $249 = ($247|0)<($248|0);
   if (!($249)) {
    label = 110;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEvT0_S7_T_($$0,$__i$4,$__comp);
   $250 = (($__i$4) + 20|0);
   $$0 = $250;
  }
  if ((label|0) == 106) {
   label = 0;
   if ($243) {
    label = 111;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 110) {
   label = 0;
   $251 = (($__i$4) + 20|0);
   __ZNSt3__16__sortIRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEvT0_S7_T_($251,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $9 = HEAP32[$1>>2]|0;
  $10 = HEAP32[$$0>>2]|0;
  $11 = ($9|0)==($10|0);
  do {
   if ($11) {
    $13 = HEAP32[$3>>2]|0;
    $14 = (($$0) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13|0)==($15|0);
    if (!($16)) {
     $17 = ($13|0)<($15|0);
     if ($17) {
      break;
     }
     STACKTOP = sp;return;
    }
    $18 = HEAP32[$4>>2]|0;
    $19 = (($$0) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if ($21) {
     $23 = HEAP32[$5>>2]|0;
     $24 = (($$0) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($23|0)<($25|0);
     if ($26) {
      break;
     }
     STACKTOP = sp;return;
    } else {
     $22 = ($18|0)<($20|0);
     if ($22) {
      break;
     }
     STACKTOP = sp;return;
    }
   } else {
    $12 = ($9|0)<($10|0);
    if (!($12)) {
     STACKTOP = sp;return;
    }
   }
  } while(0);
  ;HEAP32[$__t$i24+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i24+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i24+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i24+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i24+16>>2]=HEAP32[$$0+16>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$1+16>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i24+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i24+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i24+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i24+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i24+16>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  $27 = (($$0) + 20|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_T_($$0,$27,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 13) {
  $28 = (($$0) + 20|0);
  $29 = (($$0) + 40|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$28,$29,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  $30 = (($$0) + 20|0);
  $31 = (($$0) + 40|0);
  $32 = (($$0) + 60|0);
  (__ZNSt3__17__sort5IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($$0,$30,$31,$32,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 16) {
  __ZNSt3__118__insertion_sort_3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEvT0_S7_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 111) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $__t$i8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i8 = sp;
 $0 = HEAP32[$__y>>2]|0;
 $1 = HEAP32[$__x>>2]|0;
 $2 = ($0|0)==($1|0);
 do {
  if ($2) {
   $4 = (($__y) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($__x) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5|0)==($7|0);
   if (!($8)) {
    $9 = ($5|0)<($7|0);
    $$0$i$i = $9;
    break;
   }
   $10 = (($__y) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($__x) + 16|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11|0)==($13|0);
   if ($14) {
    $16 = (($__y) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($__x) + 8|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($17|0)<($19|0);
    $$0$i$i = $20;
    break;
   } else {
    $15 = ($11|0)<($13|0);
    $$0$i$i = $15;
    break;
   }
  } else {
   $3 = ($0|0)<($1|0);
   $$0$i$i = $3;
  }
 } while(0);
 $21 = HEAP32[$__z>>2]|0;
 $22 = ($21|0)==($0|0);
 do {
  if ($22) {
   $24 = (($__z) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($__y) + 12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($25|0)==($27|0);
   if (!($28)) {
    $29 = ($25|0)<($27|0);
    $$0$i$i9 = $29;
    break;
   }
   $30 = (($__z) + 16|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($__y) + 16|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($31|0)==($33|0);
   if ($34) {
    $36 = (($__z) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($__y) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($37|0)<($39|0);
    $$0$i$i9 = $40;
    break;
   } else {
    $35 = ($31|0)<($33|0);
    $$0$i$i9 = $35;
    break;
   }
  } else {
   $23 = ($21|0)<($0|0);
   $$0$i$i9 = $23;
  }
 } while(0);
 if (!($$0$i$i)) {
  if (!($$0$i$i9)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i8+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__y+16>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i8+16>>2]|0;
  $41 = HEAP32[$__y>>2]|0;
  $42 = HEAP32[$__x>>2]|0;
  $43 = ($41|0)==($42|0);
  do {
   if ($43) {
    $45 = (($__y) + 12|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($__x) + 12|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($46|0)==($48|0);
    if (!($49)) {
     $50 = ($46|0)<($48|0);
     if ($50) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $51 = (($__y) + 16|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = (($__x) + 16|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($52|0)==($54|0);
    if ($55) {
     $57 = (($__y) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($__x) + 8|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($58|0)<($60|0);
     if ($61) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    } else {
     $56 = ($52|0)<($54|0);
     if ($56) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $44 = ($41|0)<($42|0);
    if (!($44)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x+16>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i8+16>>2]|0;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($$0$i$i9) {
  ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x+16>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__z+16>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i8+16>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$__t$i8+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__x+16>>2]|0;
 ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i8+16>>2]|0;
 $62 = HEAP32[$__z>>2]|0;
 $63 = HEAP32[$__y>>2]|0;
 $64 = ($62|0)==($63|0);
 do {
  if ($64) {
   $66 = (($__z) + 12|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($__y) + 12|0);
   $69 = HEAP32[$68>>2]|0;
   $70 = ($67|0)==($69|0);
   if (!($70)) {
    $71 = ($67|0)<($69|0);
    if ($71) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   $72 = (($__z) + 16|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($__y) + 16|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($73|0)==($75|0);
   if ($76) {
    $78 = (($__z) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = (($__y) + 8|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ($79|0)<($81|0);
    if ($82) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   } else {
    $77 = ($73|0)<($75|0);
    if ($77) {
     break;
    } else {
     $$0 = 1;
    }
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $65 = ($62|0)<($63|0);
   if (!($65)) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i8+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i8+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i8+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i8+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i8+16>>2]=HEAP32[$__y+16>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;
 ;HEAP32[$__z+0>>2]=HEAP32[$__t$i8+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i8+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i8+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i8+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i8+16>>2]|0;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i6 = sp;
 $0 = (__ZNSt3__17__sort3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_T_($__x1,$__x2,$__x3,0)|0);
 $1 = HEAP32[$__x4>>2]|0;
 $2 = HEAP32[$__x3>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $5 = (($__x4) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($__x3) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($6|0)==($8|0);
   if (!($9)) {
    $10 = ($6|0)<($8|0);
    if ($10) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $11 = (($__x4) + 16|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($__x3) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12|0)==($14|0);
   if ($15) {
    $17 = (($__x4) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__x3) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)<($20|0);
    if ($21) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $16 = ($12|0)<($14|0);
    if ($16) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $4 = ($1|0)<($2|0);
   if (!($4)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x3+16>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i6+16>>2]|0;
 $22 = (($0) + 1)|0;
 $23 = HEAP32[$__x3>>2]|0;
 $24 = HEAP32[$__x2>>2]|0;
 $25 = ($23|0)==($24|0);
 do {
  if ($25) {
   $27 = (($__x3) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($__x2) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($28|0)==($30|0);
   if (!($31)) {
    $32 = ($28|0)<($30|0);
    if ($32) {
     break;
    } else {
     $__r$0 = $22;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $33 = (($__x3) + 16|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($__x2) + 16|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($34|0)==($36|0);
   if ($37) {
    $39 = (($__x3) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($__x2) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($40|0)<($42|0);
    if ($43) {
     break;
    } else {
     $__r$0 = $22;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $38 = ($34|0)<($36|0);
    if ($38) {
     break;
    } else {
     $__r$0 = $22;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $26 = ($23|0)<($24|0);
   if (!($26)) {
    $__r$0 = $22;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x2+16>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i6+16>>2]|0;
 $44 = (($0) + 2)|0;
 $45 = HEAP32[$__x2>>2]|0;
 $46 = HEAP32[$__x1>>2]|0;
 $47 = ($45|0)==($46|0);
 do {
  if ($47) {
   $49 = (($__x2) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($__x1) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($50|0)==($52|0);
   if (!($53)) {
    $54 = ($50|0)<($52|0);
    if ($54) {
     break;
    } else {
     $__r$0 = $44;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $55 = (($__x2) + 16|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($__x1) + 16|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($56|0)==($58|0);
   if ($59) {
    $61 = (($__x2) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($__x1) + 8|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($62|0)<($64|0);
    if ($65) {
     break;
    } else {
     $__r$0 = $44;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $60 = ($56|0)<($58|0);
    if ($60) {
     break;
    } else {
     $__r$0 = $44;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $48 = ($45|0)<($46|0);
   if (!($48)) {
    $__r$0 = $44;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i6+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__x1+16>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i6+16>>2]|0;
 $66 = (($0) + 3)|0;
 $__r$0 = $66;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $__r$0 = 0, $__t$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i9 = sp;
 $0 = (__ZNSt3__17__sort4IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,0)|0);
 $1 = HEAP32[$__x5>>2]|0;
 $2 = HEAP32[$__x4>>2]|0;
 $3 = ($1|0)==($2|0);
 do {
  if ($3) {
   $5 = (($__x5) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($__x4) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($6|0)==($8|0);
   if (!($9)) {
    $10 = ($6|0)<($8|0);
    if ($10) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $11 = (($__x5) + 16|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($__x4) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12|0)==($14|0);
   if ($15) {
    $17 = (($__x5) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__x4) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)<($20|0);
    if ($21) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $16 = ($12|0)<($14|0);
    if ($16) {
     break;
    } else {
     $__r$0 = $0;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $4 = ($1|0)<($2|0);
   if (!($4)) {
    $__r$0 = $0;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i9+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__t$i9+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__t$i9+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__t$i9+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__t$i9+16>>2]=HEAP32[$__x4+16>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__x5+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__x5+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__x5+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__x5+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__x5+16>>2]|0;
 ;HEAP32[$__x5+0>>2]=HEAP32[$__t$i9+0>>2]|0;HEAP32[$__x5+4>>2]=HEAP32[$__t$i9+4>>2]|0;HEAP32[$__x5+8>>2]=HEAP32[$__t$i9+8>>2]|0;HEAP32[$__x5+12>>2]=HEAP32[$__t$i9+12>>2]|0;HEAP32[$__x5+16>>2]=HEAP32[$__t$i9+16>>2]|0;
 $22 = (($0) + 1)|0;
 $23 = HEAP32[$__x4>>2]|0;
 $24 = HEAP32[$__x3>>2]|0;
 $25 = ($23|0)==($24|0);
 do {
  if ($25) {
   $27 = (($__x4) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($__x3) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($28|0)==($30|0);
   if (!($31)) {
    $32 = ($28|0)<($30|0);
    if ($32) {
     break;
    } else {
     $__r$0 = $22;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $33 = (($__x4) + 16|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($__x3) + 16|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($34|0)==($36|0);
   if ($37) {
    $39 = (($__x4) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($__x3) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($40|0)<($42|0);
    if ($43) {
     break;
    } else {
     $__r$0 = $22;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $38 = ($34|0)<($36|0);
    if ($38) {
     break;
    } else {
     $__r$0 = $22;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $26 = ($23|0)<($24|0);
   if (!($26)) {
    $__r$0 = $22;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i9+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i9+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i9+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i9+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i9+16>>2]=HEAP32[$__x3+16>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i9+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i9+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i9+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i9+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i9+16>>2]|0;
 $44 = (($0) + 2)|0;
 $45 = HEAP32[$__x3>>2]|0;
 $46 = HEAP32[$__x2>>2]|0;
 $47 = ($45|0)==($46|0);
 do {
  if ($47) {
   $49 = (($__x3) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = (($__x2) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($50|0)==($52|0);
   if (!($53)) {
    $54 = ($50|0)<($52|0);
    if ($54) {
     break;
    } else {
     $__r$0 = $44;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $55 = (($__x3) + 16|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($__x2) + 16|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($56|0)==($58|0);
   if ($59) {
    $61 = (($__x3) + 8|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = (($__x2) + 8|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($62|0)<($64|0);
    if ($65) {
     break;
    } else {
     $__r$0 = $44;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $60 = ($56|0)<($58|0);
    if ($60) {
     break;
    } else {
     $__r$0 = $44;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $48 = ($45|0)<($46|0);
   if (!($48)) {
    $__r$0 = $44;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i9+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i9+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i9+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i9+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i9+16>>2]=HEAP32[$__x2+16>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i9+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i9+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i9+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i9+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i9+16>>2]|0;
 $66 = (($0) + 3)|0;
 $67 = HEAP32[$__x2>>2]|0;
 $68 = HEAP32[$__x1>>2]|0;
 $69 = ($67|0)==($68|0);
 do {
  if ($69) {
   $71 = (($__x2) + 12|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($__x1) + 12|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($72|0)==($74|0);
   if (!($75)) {
    $76 = ($72|0)<($74|0);
    if ($76) {
     break;
    } else {
     $__r$0 = $66;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
   $77 = (($__x2) + 16|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = (($__x1) + 16|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ($78|0)==($80|0);
   if ($81) {
    $83 = (($__x2) + 8|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($__x1) + 8|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($84|0)<($86|0);
    if ($87) {
     break;
    } else {
     $__r$0 = $66;
    }
    STACKTOP = sp;return ($__r$0|0);
   } else {
    $82 = ($78|0)<($80|0);
    if ($82) {
     break;
    } else {
     $__r$0 = $66;
    }
    STACKTOP = sp;return ($__r$0|0);
   }
  } else {
   $70 = ($67|0)<($68|0);
   if (!($70)) {
    $__r$0 = $66;
    STACKTOP = sp;return ($__r$0|0);
   }
  }
 } while(0);
 ;HEAP32[$__t$i9+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i9+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i9+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i9+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i9+16>>2]=HEAP32[$__x1+16>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i9+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i9+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i9+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i9+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i9+16>>2]|0;
 $88 = (($0) + 4)|0;
 $__r$0 = $88;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$05 = 0, $__j$04 = 0, $__j$04$phi = 0;
 var $__k$0$lcssa = 0, $__k$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 40|0);
 $1 = (($__first) + 20|0);
 (__ZNSt3__17__sort3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 60|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$05 = $2;$__j$04 = $0;
 }
 while(1) {
  $4 = HEAP32[$__i$05>>2]|0;
  $5 = HEAP32[$__j$04>>2]|0;
  $6 = ($4|0)==($5|0);
  do {
   if ($6) {
    $8 = (($__i$05) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($__j$04) + 12|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($9|0)==($11|0);
    if (!($12)) {
     $13 = ($9|0)<($11|0);
     if ($13) {
      $39 = $9;
      label = 10;
      break;
     } else {
      break;
     }
    }
    $14 = (($__i$05) + 16|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($__j$04) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($15|0)==($17|0);
    if ($18) {
     $20 = (($__i$05) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($__j$04) + 8|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($21|0)<($23|0);
     if ($24) {
      $39 = $9;
      label = 10;
      break;
     } else {
      break;
     }
    } else {
     $19 = ($15|0)<($17|0);
     if ($19) {
      $39 = $9;
      label = 10;
      break;
     } else {
      break;
     }
    }
   } else {
    $7 = ($4|0)<($5|0);
    if ($7) {
     $$phi$trans$insert = (($__i$05) + 12|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $39 = $$pre;
     label = 10;
    }
   }
  } while(0);
  if ((label|0) == 10) {
   label = 0;
   $25 = (($__i$05) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($__i$05) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($__i$05) + 16|0);
   $30 = HEAP32[$29>>2]|0;
   ;HEAP32[$__i$05+0>>2]=HEAP32[$__j$04+0>>2]|0;HEAP32[$__i$05+4>>2]=HEAP32[$__j$04+4>>2]|0;HEAP32[$__i$05+8>>2]=HEAP32[$__j$04+8>>2]|0;HEAP32[$__i$05+12>>2]=HEAP32[$__j$04+12>>2]|0;HEAP32[$__i$05+16>>2]=HEAP32[$__j$04+16>>2]|0;
   $31 = ($__j$04|0)==($__first|0);
   L17: do {
    if ($31) {
     $__k$0$lcssa = $__first;
    } else {
     $__k$03 = $__j$04;
     while(1) {
      $32 = (($__k$03) + -20|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = ($4|0)==($33|0);
      do {
       if ($34) {
        $36 = (($__k$03) + -8|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = ($39|0)==($37|0);
        if (!($38)) {
         $40 = ($39|0)<($37|0);
         if ($40) {
          break;
         } else {
          $__k$0$lcssa = $__k$03;
          break L17;
         }
        }
        $41 = (($__k$03) + -4|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = ($30|0)==($42|0);
        if ($43) {
         $45 = (($__k$03) + -12|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = ($28|0)<($46|0);
         if ($47) {
          break;
         } else {
          $__k$0$lcssa = $__k$03;
          break L17;
         }
        } else {
         $44 = ($30|0)<($42|0);
         if ($44) {
          break;
         } else {
          $__k$0$lcssa = $__k$03;
          break L17;
         }
        }
       } else {
        $35 = ($4|0)<($33|0);
        if (!($35)) {
         $__k$0$lcssa = $__k$03;
         break L17;
        }
       }
      } while(0);
      ;HEAP32[$__k$03+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$__k$03+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$__k$03+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$__k$03+12>>2]=HEAP32[$32+12>>2]|0;HEAP32[$__k$03+16>>2]=HEAP32[$32+16>>2]|0;
      $48 = ($32|0)==($__first|0);
      if ($48) {
       $__k$0$lcssa = $__first;
       break;
      } else {
       $__k$03 = $32;
      }
     }
    }
   } while(0);
   HEAP32[$__k$0$lcssa>>2] = $4;
   $49 = (($__k$0$lcssa) + 4|0);
   HEAP32[$49>>2] = $26;
   $50 = (($__k$0$lcssa) + 8|0);
   HEAP32[$50>>2] = $28;
   $51 = (($__k$0$lcssa) + 12|0);
   HEAP32[$51>>2] = $39;
   $52 = (($__k$0$lcssa) + 16|0);
   HEAP32[$52>>2] = $30;
  }
  $53 = (($__i$05) + 20|0);
  $54 = ($53|0)==($__last|0);
  if ($54) {
   break;
  } else {
   $__j$04$phi = $__i$05;$__i$05 = $53;$__j$04 = $__j$04$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $__count$08 = 0, $__count$1 = 0, $__i$09 = 0;
 var $__j$07 = 0, $__j$07$phi = 0, $__k$0$lcssa = 0, $__k$05 = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 20)&-1;
 switch ($3|0) {
 case 5:  {
  $31 = (($__first) + 20|0);
  $32 = (($__first) + 40|0);
  $33 = (($__first) + 60|0);
  $34 = (($__last) + -20|0);
  (__ZNSt3__17__sort5IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($__first,$31,$32,$33,$34,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)==($6|0);
  do {
   if ($7) {
    $9 = (($__last) + -8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($__first) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($10|0)==($12|0);
    if (!($13)) {
     $14 = ($10|0)<($12|0);
     if ($14) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
    $15 = (($__last) + -4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($__first) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($16|0)==($18|0);
    if ($19) {
     $21 = (($__last) + -12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($__first) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($22|0)<($24|0);
     if ($25) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    } else {
     $20 = ($16|0)<($18|0);
     if ($20) {
      break;
     } else {
      $$0 = 1;
     }
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $8 = ($5|0)<($6|0);
    if (!($8)) {
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  ;HEAP32[$__t$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i+16>>2]=HEAP32[$__first+16>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$4+16>>2]|0;
  ;HEAP32[$4+0>>2]=HEAP32[$__t$i+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__t$i+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__t$i+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$__t$i+12>>2]|0;HEAP32[$4+16>>2]=HEAP32[$__t$i+16>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $26 = (($__first) + 20|0);
  $27 = (($__last) + -20|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_T_($__first,$26,$27,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $28 = (($__first) + 20|0);
  $29 = (($__first) + 40|0);
  $30 = (($__last) + -20|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$28,$29,$30,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $35 = (($__first) + 40|0);
  $36 = (($__first) + 20|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN2UI14DepthSortEntryES3_EEPS3_EEjT0_S7_S7_T_($__first,$36,$35,0)|0);
  $37 = (($__first) + 60|0);
  $38 = ($37|0)==($__last|0);
  if ($38) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$08 = 0;$__i$09 = $37;$__j$07 = $35;
  }
  while(1) {
   $39 = HEAP32[$__i$09>>2]|0;
   $40 = HEAP32[$__j$07>>2]|0;
   $41 = ($39|0)==($40|0);
   do {
    if ($41) {
     $43 = (($__i$09) + 12|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($__j$07) + 12|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($44|0)==($46|0);
     if (!($47)) {
      $48 = ($44|0)<($46|0);
      if ($48) {
       $74 = $44;
       label = 22;
       break;
      } else {
       $__count$1 = $__count$08;
       break;
      }
     }
     $49 = (($__i$09) + 16|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = (($__j$07) + 16|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($50|0)==($52|0);
     if ($53) {
      $55 = (($__i$09) + 8|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = (($__j$07) + 8|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($56|0)<($58|0);
      if ($59) {
       $74 = $44;
       label = 22;
       break;
      } else {
       $__count$1 = $__count$08;
       break;
      }
     } else {
      $54 = ($50|0)<($52|0);
      if ($54) {
       $74 = $44;
       label = 22;
       break;
      } else {
       $__count$1 = $__count$08;
       break;
      }
     }
    } else {
     $42 = ($39|0)<($40|0);
     if ($42) {
      $$phi$trans$insert = (($__i$09) + 12|0);
      $$pre = HEAP32[$$phi$trans$insert>>2]|0;
      $74 = $$pre;
      label = 22;
     } else {
      $__count$1 = $__count$08;
     }
    }
   } while(0);
   if ((label|0) == 22) {
    label = 0;
    $60 = (($__i$09) + 4|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($__i$09) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($__i$09) + 16|0);
    $65 = HEAP32[$64>>2]|0;
    ;HEAP32[$__i$09+0>>2]=HEAP32[$__j$07+0>>2]|0;HEAP32[$__i$09+4>>2]=HEAP32[$__j$07+4>>2]|0;HEAP32[$__i$09+8>>2]=HEAP32[$__j$07+8>>2]|0;HEAP32[$__i$09+12>>2]=HEAP32[$__j$07+12>>2]|0;HEAP32[$__i$09+16>>2]=HEAP32[$__j$07+16>>2]|0;
    $66 = ($__j$07|0)==($__first|0);
    L19: do {
     if ($66) {
      $__k$0$lcssa = $__first;
     } else {
      $__k$05 = $__j$07;
      while(1) {
       $67 = (($__k$05) + -20|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = ($39|0)==($68|0);
       do {
        if ($69) {
         $71 = (($__k$05) + -8|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = ($74|0)==($72|0);
         if (!($73)) {
          $75 = ($74|0)<($72|0);
          if ($75) {
           break;
          } else {
           $__k$0$lcssa = $__k$05;
           break L19;
          }
         }
         $76 = (($__k$05) + -4|0);
         $77 = HEAP32[$76>>2]|0;
         $78 = ($65|0)==($77|0);
         if ($78) {
          $80 = (($__k$05) + -12|0);
          $81 = HEAP32[$80>>2]|0;
          $82 = ($63|0)<($81|0);
          if ($82) {
           break;
          } else {
           $__k$0$lcssa = $__k$05;
           break L19;
          }
         } else {
          $79 = ($65|0)<($77|0);
          if ($79) {
           break;
          } else {
           $__k$0$lcssa = $__k$05;
           break L19;
          }
         }
        } else {
         $70 = ($39|0)<($68|0);
         if (!($70)) {
          $__k$0$lcssa = $__k$05;
          break L19;
         }
        }
       } while(0);
       ;HEAP32[$__k$05+0>>2]=HEAP32[$67+0>>2]|0;HEAP32[$__k$05+4>>2]=HEAP32[$67+4>>2]|0;HEAP32[$__k$05+8>>2]=HEAP32[$67+8>>2]|0;HEAP32[$__k$05+12>>2]=HEAP32[$67+12>>2]|0;HEAP32[$__k$05+16>>2]=HEAP32[$67+16>>2]|0;
       $83 = ($67|0)==($__first|0);
       if ($83) {
        $__k$0$lcssa = $__first;
        break;
       } else {
        $__k$05 = $67;
       }
      }
     }
    } while(0);
    HEAP32[$__k$0$lcssa>>2] = $39;
    $84 = (($__k$0$lcssa) + 4|0);
    HEAP32[$84>>2] = $61;
    $85 = (($__k$0$lcssa) + 8|0);
    HEAP32[$85>>2] = $63;
    $86 = (($__k$0$lcssa) + 12|0);
    HEAP32[$86>>2] = $74;
    $87 = (($__k$0$lcssa) + 16|0);
    HEAP32[$87>>2] = $65;
    $88 = (($__count$08) + 1)|0;
    $89 = ($88|0)==(8);
    if ($89) {
     break;
    } else {
     $__count$1 = $88;
    }
   }
   $92 = (($__i$09) + 20|0);
   $93 = ($92|0)==($__last|0);
   if ($93) {
    $$0 = 1;
    label = 34;
    break;
   } else {
    $__j$07$phi = $__i$09;$__count$08 = $__count$1;$__i$09 = $92;$__j$07 = $__j$07$phi;
   }
  }
  if ((label|0) == 34) {
   STACKTOP = sp;return ($$0|0);
  }
  $90 = (($__i$09) + 20|0);
  $91 = ($90|0)==($__last|0);
  $$0 = $91;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZN2UI14CanvasRenderer10SyncBoundsENS0_8SyncFlagE($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $$lcssa = Math_fround(0), $$lcssa1 = Math_fround(0), $$lcssa12 = Math_fround(0), $$lcssa13 = Math_fround(0), $$lcssa14 = Math_fround(0), $$lcssa15 = Math_fround(0), $$lcssa16 = Math_fround(0), $$lcssa17 = Math_fround(0), $$lcssa2 = Math_fround(0), $$lcssa3 = Math_fround(0), $$lcssa4 = Math_fround(0), $$lcssa5 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = Math_fround(0);
 var $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0;
 var $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0);
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0;
 var $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$018 = 0, $i3$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag & 1;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = (($this) + 72|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 96|0);
  HEAP8[$4>>0] = 1;
  $5 = (($this) + 76|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 80|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = Math_fround(HEAPF32[616664>>2]);
  $10 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
  $11 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
  $12 = Math_fround(-$9);
  $13 = Math_fround(-$10);
  $14 = Math_fround(-$11);
  $15 = ((($8) + (($6*152)|0)|0) + 140|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)>(0);
  if ($17) {
   $18 = ((($8) + (($6*152)|0)|0) + 136|0);
   $19 = HEAP32[$18>>2]|0;
   $23 = $9;$28 = $10;$33 = $11;$36 = $12;$39 = $13;$42 = $14;$i$018 = 0;
   while(1) {
    $20 = (($19) + (($i$018*60)|0)|0);
    $21 = Math_fround(HEAPF32[$20>>2]);
    $22 = $21 < $23;
    $24 = $22 ? $21 : $23;
    $25 = ((($19) + (($i$018*60)|0)|0) + 4|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = $26 < $28;
    $29 = $27 ? $26 : $28;
    $30 = ((($19) + (($i$018*60)|0)|0) + 8|0);
    $31 = Math_fround(HEAPF32[$30>>2]);
    $32 = $31 < $33;
    $34 = $32 ? $31 : $33;
    $35 = $36 < $21;
    $37 = $35 ? $21 : $36;
    $38 = $39 < $26;
    $40 = $38 ? $26 : $39;
    $41 = $42 < $31;
    $43 = $41 ? $31 : $42;
    $44 = (($i$018) + 1)|0;
    $45 = ($44|0)<($16|0);
    if ($45) {
     $23 = $24;$28 = $29;$33 = $34;$36 = $37;$39 = $40;$42 = $43;$i$018 = $44;
    } else {
     $$lcssa12 = $43;$$lcssa13 = $40;$$lcssa14 = $37;$$lcssa15 = $34;$$lcssa16 = $29;$$lcssa17 = $24;
     break;
    }
   }
  } else {
   $$lcssa12 = $14;$$lcssa13 = $13;$$lcssa14 = $12;$$lcssa15 = $11;$$lcssa16 = $10;$$lcssa17 = $9;
  }
  $46 = ((($8) + (($6*152)|0)|0) + 76|0);
  HEAPF32[$46>>2] = $$lcssa17;
  $47 = ((($8) + (($6*152)|0)|0) + 80|0);
  HEAPF32[$47>>2] = $$lcssa16;
  $48 = ((($8) + (($6*152)|0)|0) + 84|0);
  HEAPF32[$48>>2] = $$lcssa15;
  $49 = ((($8) + (($6*152)|0)|0) + 88|0);
  HEAPF32[$49>>2] = $$lcssa14;
  $50 = ((($8) + (($6*152)|0)|0) + 92|0);
  HEAPF32[$50>>2] = $$lcssa13;
  $51 = ((($8) + (($6*152)|0)|0) + 96|0);
  HEAPF32[$51>>2] = $$lcssa12;
 }
 $52 = $flag & 2;
 $53 = ($52|0)==(0);
 if ($53) {
  STACKTOP = sp;return;
 }
 $54 = (($this) + 88|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + 96|0);
 HEAP8[$56>>0] = 1;
 $57 = (($this) + 92|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($55) + 80|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = Math_fround(HEAPF32[616664>>2]);
 $62 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $63 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $64 = Math_fround(-$61);
 $65 = Math_fround(-$62);
 $66 = Math_fround(-$63);
 $67 = ((($60) + (($58*152)|0)|0) + 140|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = ($68|0)>(0);
 if ($69) {
  $70 = ((($60) + (($58*152)|0)|0) + 136|0);
  $71 = HEAP32[$70>>2]|0;
  $75 = $61;$80 = $62;$85 = $63;$88 = $64;$91 = $65;$94 = $66;$i3$06 = 0;
  while(1) {
   $72 = (($71) + (($i3$06*60)|0)|0);
   $73 = Math_fround(HEAPF32[$72>>2]);
   $74 = $73 < $75;
   $76 = $74 ? $73 : $75;
   $77 = ((($71) + (($i3$06*60)|0)|0) + 4|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = $78 < $80;
   $81 = $79 ? $78 : $80;
   $82 = ((($71) + (($i3$06*60)|0)|0) + 8|0);
   $83 = Math_fround(HEAPF32[$82>>2]);
   $84 = $83 < $85;
   $86 = $84 ? $83 : $85;
   $87 = $88 < $73;
   $89 = $87 ? $73 : $88;
   $90 = $91 < $78;
   $92 = $90 ? $78 : $91;
   $93 = $94 < $83;
   $95 = $93 ? $83 : $94;
   $96 = (($i3$06) + 1)|0;
   $97 = ($96|0)<($68|0);
   if ($97) {
    $75 = $76;$80 = $81;$85 = $86;$88 = $89;$91 = $92;$94 = $95;$i3$06 = $96;
   } else {
    $$lcssa = $95;$$lcssa1 = $92;$$lcssa2 = $89;$$lcssa3 = $86;$$lcssa4 = $81;$$lcssa5 = $76;
    break;
   }
  }
 } else {
  $$lcssa = $66;$$lcssa1 = $65;$$lcssa2 = $64;$$lcssa3 = $63;$$lcssa4 = $62;$$lcssa5 = $61;
 }
 $98 = ((($60) + (($58*152)|0)|0) + 76|0);
 HEAPF32[$98>>2] = $$lcssa5;
 $99 = ((($60) + (($58*152)|0)|0) + 80|0);
 HEAPF32[$99>>2] = $$lcssa4;
 $100 = ((($60) + (($58*152)|0)|0) + 84|0);
 HEAPF32[$100>>2] = $$lcssa3;
 $101 = ((($60) + (($58*152)|0)|0) + 88|0);
 HEAPF32[$101>>2] = $$lcssa2;
 $102 = ((($60) + (($58*152)|0)|0) + 92|0);
 HEAPF32[$102>>2] = $$lcssa1;
 $103 = ((($60) + (($58*152)|0)|0) + 96|0);
 HEAPF32[$103>>2] = $$lcssa;
 STACKTOP = sp;return;
}
function __ZN2UI14CanvasRenderer13SyncWorldRectENS0_8SyncFlagE($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0;
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0);
 var $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0);
 var $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0);
 var $58 = Math_fround(0), $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = Math_fround(0), $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $worldBounds = 0, $worldBounds2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $worldBounds = sp + 72|0;
 $0 = sp;
 $worldBounds2 = sp + 24|0;
 $1 = sp + 48|0;
 $2 = $flag & 1;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($this) + 72|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 96|0);
  HEAP8[$6>>0] = 1;
  $7 = (($this) + 76|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($5) + 80|0);
  $10 = HEAP32[$9>>2]|0;
  ;HEAP32[$worldBounds+0>>2]=0|0;HEAP32[$worldBounds+4>>2]=0|0;HEAP32[$worldBounds+8>>2]=0|0;HEAP32[$worldBounds+12>>2]=0|0;HEAP32[$worldBounds+16>>2]=0|0;HEAP32[$worldBounds+20>>2]=0|0;
  $11 = (($0) + 4|0);
  $12 = (($0) + 8|0);
  $13 = (($0) + 12|0);
  $14 = (($0) + 16|0);
  $15 = (($0) + 20|0);
  $16 = ((($10) + (($8*152)|0)|0) + 88|0);
  ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = ((($10) + (($8*152)|0)|0) + 76|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = Math_fround($17 + $19);
  $21 = ((($10) + (($8*152)|0)|0) + 92|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = ((($10) + (($8*152)|0)|0) + 80|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = Math_fround($22 + $24);
  $26 = ((($10) + (($8*152)|0)|0) + 96|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = ((($10) + (($8*152)|0)|0) + 84|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = Math_fround($27 + $29);
  $31 = Math_fround($20 * Math_fround(0.5));
  $32 = Math_fround($25 * Math_fround(0.5));
  $33 = Math_fround($30 * Math_fround(0.5));
  HEAPF32[$0>>2] = $31;
  HEAPF32[$11>>2] = $32;
  HEAPF32[$12>>2] = $33;
  $34 = Math_fround(HEAPF32[$16>>2]);
  $35 = Math_fround(HEAPF32[$18>>2]);
  $36 = Math_fround($34 - $35);
  $37 = Math_fround(HEAPF32[$21>>2]);
  $38 = Math_fround(HEAPF32[$23>>2]);
  $39 = Math_fround($37 - $38);
  $40 = Math_fround(HEAPF32[$26>>2]);
  $41 = Math_fround(HEAPF32[$28>>2]);
  $42 = Math_fround($40 - $41);
  $43 = Math_fround($36 * Math_fround(0.5));
  $44 = Math_fround($39 * Math_fround(0.5));
  $45 = Math_fround($42 * Math_fround(0.5));
  HEAPF32[$13>>2] = $43;
  HEAPF32[$14>>2] = $44;
  HEAPF32[$15>>2] = $45;
  $46 = ((($10) + (($8*152)|0)|0) + 12|0);
  __Z17TransformAABBSlowRK4AABBRK10Matrix4x4fRS_($0,$46,$worldBounds);
  $47 = Math_fround(HEAPF32[$worldBounds>>2]);
  $48 = (($worldBounds) + 12|0);
  $49 = Math_fround(HEAPF32[$48>>2]);
  $50 = Math_fround($47 - $49);
  $51 = (($worldBounds) + 4|0);
  $52 = Math_fround(HEAPF32[$51>>2]);
  $53 = (($worldBounds) + 16|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = Math_fround($52 - $54);
  $56 = Math_fround($47 + $49);
  $57 = Math_fround($52 + $54);
  $58 = Math_fround($56 - $50);
  $59 = Math_fround($57 - $55);
  $60 = ((($10) + (($8*152)|0)|0) + 100|0);
  HEAPF32[$60>>2] = $50;
  $61 = ((($10) + (($8*152)|0)|0) + 108|0);
  HEAPF32[$61>>2] = $58;
  $62 = ((($10) + (($8*152)|0)|0) + 104|0);
  HEAPF32[$62>>2] = $55;
  $63 = ((($10) + (($8*152)|0)|0) + 112|0);
  HEAPF32[$63>>2] = $59;
 }
 $64 = $flag & 2;
 $65 = ($64|0)==(0);
 if ($65) {
  STACKTOP = sp;return;
 }
 $66 = (($this) + 88|0);
 $67 = HEAP32[$66>>2]|0;
 $68 = (($67) + 96|0);
 HEAP8[$68>>0] = 1;
 $69 = (($this) + 92|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = (($67) + 80|0);
 $72 = HEAP32[$71>>2]|0;
 ;HEAP32[$worldBounds2+0>>2]=0|0;HEAP32[$worldBounds2+4>>2]=0|0;HEAP32[$worldBounds2+8>>2]=0|0;HEAP32[$worldBounds2+12>>2]=0|0;HEAP32[$worldBounds2+16>>2]=0|0;HEAP32[$worldBounds2+20>>2]=0|0;
 $73 = (($1) + 4|0);
 $74 = (($1) + 8|0);
 $75 = (($1) + 12|0);
 $76 = (($1) + 16|0);
 $77 = (($1) + 20|0);
 $78 = ((($72) + (($70*152)|0)|0) + 88|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 $79 = Math_fround(HEAPF32[$78>>2]);
 $80 = ((($72) + (($70*152)|0)|0) + 76|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($79 + $81);
 $83 = ((($72) + (($70*152)|0)|0) + 92|0);
 $84 = Math_fround(HEAPF32[$83>>2]);
 $85 = ((($72) + (($70*152)|0)|0) + 80|0);
 $86 = Math_fround(HEAPF32[$85>>2]);
 $87 = Math_fround($84 + $86);
 $88 = ((($72) + (($70*152)|0)|0) + 96|0);
 $89 = Math_fround(HEAPF32[$88>>2]);
 $90 = ((($72) + (($70*152)|0)|0) + 84|0);
 $91 = Math_fround(HEAPF32[$90>>2]);
 $92 = Math_fround($89 + $91);
 $93 = Math_fround($82 * Math_fround(0.5));
 $94 = Math_fround($87 * Math_fround(0.5));
 $95 = Math_fround($92 * Math_fround(0.5));
 HEAPF32[$1>>2] = $93;
 HEAPF32[$73>>2] = $94;
 HEAPF32[$74>>2] = $95;
 $96 = Math_fround(HEAPF32[$78>>2]);
 $97 = Math_fround(HEAPF32[$80>>2]);
 $98 = Math_fround($96 - $97);
 $99 = Math_fround(HEAPF32[$83>>2]);
 $100 = Math_fround(HEAPF32[$85>>2]);
 $101 = Math_fround($99 - $100);
 $102 = Math_fround(HEAPF32[$88>>2]);
 $103 = Math_fround(HEAPF32[$90>>2]);
 $104 = Math_fround($102 - $103);
 $105 = Math_fround($98 * Math_fround(0.5));
 $106 = Math_fround($101 * Math_fround(0.5));
 $107 = Math_fround($104 * Math_fround(0.5));
 HEAPF32[$75>>2] = $105;
 HEAPF32[$76>>2] = $106;
 HEAPF32[$77>>2] = $107;
 $108 = ((($72) + (($70*152)|0)|0) + 12|0);
 __Z17TransformAABBSlowRK4AABBRK10Matrix4x4fRS_($1,$108,$worldBounds2);
 $109 = Math_fround(HEAPF32[$worldBounds2>>2]);
 $110 = (($worldBounds2) + 12|0);
 $111 = Math_fround(HEAPF32[$110>>2]);
 $112 = Math_fround($109 - $111);
 $113 = (($worldBounds2) + 4|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = (($worldBounds2) + 16|0);
 $116 = Math_fround(HEAPF32[$115>>2]);
 $117 = Math_fround($114 - $116);
 $118 = Math_fround($109 + $111);
 $119 = Math_fround($114 + $116);
 $120 = Math_fround($118 - $112);
 $121 = Math_fround($119 - $117);
 $122 = ((($72) + (($70*152)|0)|0) + 100|0);
 HEAPF32[$122>>2] = $112;
 $123 = ((($72) + (($70*152)|0)|0) + 108|0);
 HEAPF32[$123>>2] = $120;
 $124 = ((($72) + (($70*152)|0)|0) + 104|0);
 HEAPF32[$124>>2] = $117;
 $125 = ((($72) + (($70*152)|0)|0) + 112|0);
 HEAPF32[$125>>2] = $121;
 STACKTOP = sp;return;
}
function __ZN2UI14CanvasRenderer13SyncTransformENS0_8SyncFlagE($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $transformMatrix = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $transformMatrix = sp;
 $0 = $flag & 1;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = (($this) + 72|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 96|0);
  HEAP8[$4>>0] = 1;
  $5 = (($this) + 76|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 80|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($10)|0);
  (__ZNK9Transform24CalculateTransformMatrixER10Matrix4x4f($11,$transformMatrix)|0);
  $12 = HEAP32[$2>>2]|0;
  $13 = ((($8) + (($6*152)|0)|0) + 12|0);
  __Z19MultiplyMatrices3x4RK10Matrix4x4fS1_RS_($12,$transformMatrix,$13);
 }
 $14 = $flag & 2;
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($this) + 88|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 96|0);
 HEAP8[$18>>0] = 1;
 $19 = (($this) + 92|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($17) + 80|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($24)|0);
 (__ZNK9Transform24CalculateTransformMatrixER10Matrix4x4f($25,$transformMatrix)|0);
 $26 = HEAP32[$16>>2]|0;
 $27 = ((($22) + (($20*152)|0)|0) + 12|0);
 __Z19MultiplyMatrices3x4RK10Matrix4x4fS1_RS_($26,$transformMatrix,$27);
 STACKTOP = sp;return;
}
function __ZN2UI14CanvasRenderer18SyncInheritedAlphaENS0_8SyncFlagE($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__Z34FindAncestorComponentExactTypeImplRN5Unity10GameObjectEi($1,223)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $9 = 0;
 } else {
  $4 = (($2) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($5)|0);
  $9 = $6;
 }
 $7 = HEAP32[$0>>2]|0;
 $8 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($7)|0);
 $10 = (Math_fround(__ZN2UI20CalculateNestedAlphaEP9TransformPKS0_f($8,$9,Math_fround(1.0))));
 $11 = $flag & 1;
 $12 = ($11|0)==(0);
 if (!($12)) {
  $13 = (($this) + 72|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 96|0);
  HEAP8[$15>>0] = 1;
  $16 = (($this) + 76|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($14) + 80|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($19) + (($17*152)|0)|0) + 132|0);
  HEAPF32[$20>>2] = $10;
 }
 $21 = $flag & 2;
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = (($this) + 88|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + 96|0);
 HEAP8[$25>>0] = 1;
 $26 = (($this) + 92|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($24) + 80|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($29) + (($27*152)|0)|0) + 132|0);
 HEAPF32[$30>>2] = $10;
 STACKTOP = sp;return;
}
function __ZN2UI14CanvasRenderer14AttachToCanvasEPNS_6CanvasENS_8MaskModeE($this,$canvas,$maskMode) {
 $this = $this|0;
 $canvas = $canvas|0;
 $maskMode = $maskMode|0;
 var $$$i = 0, $$$i1 = 0, $$0$i$i = 0, $$flag$1$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = Math_fround(0), $99 = 0, $flag$1$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__Z34FindAncestorComponentExactTypeImplRN5Unity10GameObjectEi($1,223)|0);
 $3 = ($2|0)!=(0|0);
 $4 = ($2|0)==($canvas|0);
 $or$cond = $3 & $4;
 if (!($or$cond)) {
  STACKTOP = sp;return ($2|0);
 }
 $5 = $maskMode & 2;
 $6 = ($5|0)!=(0);
 $7 = (($this) + 88|0);
 $8 = (($this) + 72|0);
 $9 = $6 ? $7 : $8;
 $10 = (($canvas) + 108|0);
 __ZN2UI25AddCanvasRendererToCanvasEPNS_12CanvasHandleERNS_10CanvasDataE($9,$10);
 $11 = (($this) + 72|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)!=(0|0);
 $$$i1 = $13&1;
 $14 = (($this) + 88|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)!=(0|0);
 if ($13) {
  $$flag$1$i = $16 ? 3 : $$$i1;
  $18 = $$flag$1$i;
 } else {
  $flag$1$i = $16 ? 2 : $$$i1;
  $18 = $flag$1$i;
 }
 $17 = $18 & 1;
 $19 = ($17|0)==(0);
 do {
  if (!($19)) {
   $20 = (($12) + 96|0);
   HEAP8[$20>>0] = 1;
   $21 = (($this) + 76|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($12) + 80|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($this) + 68|0);
   $26 = HEAP8[$25>>0]|0;
   $27 = ($26<<24>>24)==(0);
   $28 = ((($24) + (($22*152)|0)|0) + 144|0);
   if ($27) {
    HEAP32[$28>>2] = 0;
    break;
   } else {
    HEAP32[$28>>2] = 1;
    break;
   }
  }
 } while(0);
 $29 = $18 & 2;
 $30 = ($29|0)==(0);
 if (!($30)) {
  $31 = (($15) + 96|0);
  HEAP8[$31>>0] = 1;
  $32 = (($this) + 92|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($15) + 80|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ((($35) + (($33*152)|0)|0) + 144|0);
  HEAP32[$36>>2] = 2;
 }
 if (!($19)) {
  $37 = (($12) + 96|0);
  HEAP8[$37>>0] = 1;
  $38 = (($this) + 76|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($12) + 80|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + (($39*152)|0)|0);
  $43 = ((($41) + (($39*152)|0)|0) + 144|0);
  $44 = HEAP32[$43>>2]|0;
  if ((($44|0) == 1)) {
   $45 = (($this) + 56|0);
   $46 = HEAP32[$45>>2]|0;
   HEAP32[$42>>2] = $46;
  } else if ((($44|0) == 2)) {
   $47 = (($this) + 60|0);
   $48 = HEAP32[$47>>2]|0;
   HEAP32[$42>>2] = $48;
  } else {
   $49 = (($this) + 52|0);
   $50 = HEAP32[$49>>2]|0;
   HEAP32[$42>>2] = $50;
  }
  $51 = (($this) + 64|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ((($41) + (($39*152)|0)|0) + 4|0);
  HEAP32[$53>>2] = $52;
 }
 if (!($30)) {
  $54 = (($15) + 96|0);
  HEAP8[$54>>0] = 1;
  $55 = (($this) + 92|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = (($15) + 80|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = (($58) + (($56*152)|0)|0);
  $60 = ((($58) + (($56*152)|0)|0) + 144|0);
  $61 = HEAP32[$60>>2]|0;
  if ((($61|0) == 1)) {
   $62 = (($this) + 56|0);
   $63 = HEAP32[$62>>2]|0;
   HEAP32[$59>>2] = $63;
  } else if ((($61|0) == 2)) {
   $64 = (($this) + 60|0);
   $65 = HEAP32[$64>>2]|0;
   HEAP32[$59>>2] = $65;
  } else {
   $66 = (($this) + 52|0);
   $67 = HEAP32[$66>>2]|0;
   HEAP32[$59>>2] = $67;
  }
  $68 = (($this) + 64|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = ((($58) + (($56*152)|0)|0) + 4|0);
  HEAP32[$70>>2] = $69;
 }
 if (!($19)) {
  $71 = (($12) + 96|0);
  HEAP8[$71>>0] = 1;
  $72 = (($this) + 76|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($12) + 80|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = (($this) + 28|0);
  $77 = Math_fround(HEAPF32[$76>>2]);
  $78 = (($this) + 32|0);
  $79 = Math_fround(HEAPF32[$78>>2]);
  $80 = (($this) + 36|0);
  $81 = Math_fround(HEAPF32[$80>>2]);
  $82 = (($this) + 40|0);
  $83 = Math_fround(HEAPF32[$82>>2]);
  $84 = ((($75) + (($73*152)|0)|0) + 116|0);
  HEAPF32[$84>>2] = $77;
  $85 = ((($75) + (($73*152)|0)|0) + 120|0);
  HEAPF32[$85>>2] = $79;
  $86 = ((($75) + (($73*152)|0)|0) + 124|0);
  HEAPF32[$86>>2] = $81;
  $87 = ((($75) + (($73*152)|0)|0) + 128|0);
  HEAPF32[$87>>2] = $83;
 }
 if (!($30)) {
  $88 = (($15) + 96|0);
  HEAP8[$88>>0] = 1;
  $89 = (($this) + 92|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = (($15) + 80|0);
  $92 = HEAP32[$91>>2]|0;
  $93 = (($this) + 28|0);
  $94 = Math_fround(HEAPF32[$93>>2]);
  $95 = (($this) + 32|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = (($this) + 36|0);
  $98 = Math_fround(HEAPF32[$97>>2]);
  $99 = (($this) + 40|0);
  $100 = Math_fround(HEAPF32[$99>>2]);
  $101 = ((($92) + (($90*152)|0)|0) + 116|0);
  HEAPF32[$101>>2] = $94;
  $102 = ((($92) + (($90*152)|0)|0) + 120|0);
  HEAPF32[$102>>2] = $96;
  $103 = ((($92) + (($90*152)|0)|0) + 124|0);
  HEAPF32[$103>>2] = $98;
  $104 = ((($92) + (($90*152)|0)|0) + 128|0);
  HEAPF32[$104>>2] = $100;
 }
 if (!($19)) {
  $105 = (($12) + 96|0);
  HEAP8[$105>>0] = 1;
  $106 = (($this) + 76|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (($12) + 80|0);
  $109 = HEAP32[$108>>2]|0;
  $110 = (($this) + 44|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = ((($109) + (($107*152)|0)|0) + 136|0);
  HEAP32[$112>>2] = $111;
  $113 = (($this) + 48|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = ((($109) + (($107*152)|0)|0) + 140|0);
  HEAP32[$115>>2] = $114;
 }
 if (!($30)) {
  $116 = HEAP32[$14>>2]|0;
  $117 = (($116) + 96|0);
  HEAP8[$117>>0] = 1;
  $118 = (($this) + 92|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = (($116) + 80|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = (($this) + 44|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = ((($121) + (($119*152)|0)|0) + 136|0);
  HEAP32[$124>>2] = $123;
  $125 = (($this) + 48|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ((($121) + (($119*152)|0)|0) + 140|0);
  HEAP32[$127>>2] = $126;
 }
 __ZN2UI14CanvasRenderer13SyncTransformENS0_8SyncFlagE($this,$18);
 __ZN2UI14CanvasRenderer10SyncBoundsENS0_8SyncFlagE($this,$18);
 __ZN2UI14CanvasRenderer13SyncWorldRectENS0_8SyncFlagE($this,$18);
 if (!($19)) {
  $128 = HEAP32[$11>>2]|0;
  $129 = (($128) + 96|0);
  HEAP8[$129>>0] = 1;
  $130 = (($this) + 76|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = (($128) + 80|0);
  $133 = HEAP32[$132>>2]|0;
  $134 = ($128|0)==(0|0);
  $$$i = $134 ? -1 : $131;
  $135 = ((($133) + (($131*152)|0)|0) + 8|0);
  HEAP32[$135>>2] = $$$i;
 }
 if (!($30)) {
  $136 = HEAP32[$14>>2]|0;
  $137 = (($136) + 96|0);
  HEAP8[$137>>0] = 1;
  $138 = (($this) + 92|0);
  $139 = HEAP32[$138>>2]|0;
  $140 = (($136) + 80|0);
  $141 = HEAP32[$140>>2]|0;
  $142 = HEAP32[$11>>2]|0;
  $143 = ($142|0)==(0|0);
  if ($143) {
   $$0$i$i = -1;
  } else {
   $144 = (($this) + 76|0);
   $145 = HEAP32[$144>>2]|0;
   $$0$i$i = $145;
  }
  $146 = ((($141) + (($139*152)|0)|0) + 8|0);
  HEAP32[$146>>2] = $$0$i$i;
 }
 __ZN2UI14CanvasRenderer18SyncInheritedAlphaENS0_8SyncFlagE($this,$18);
 STACKTOP = sp;return ($2|0);
}
function __ZN2UI6Canvas15AddNestedCanvasEPS0_($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 300|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 304|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if (!($4)) {
  $5 = ($1|0)==(0|0);
  if ($5) {
   $7 = 0;
  } else {
   HEAP32[$1>>2] = $node;
   $$pre$i = HEAP32[$0>>2]|0;
   $7 = $$pre$i;
  }
  $6 = (($7) + 4|0);
  HEAP32[$0>>2] = $6;
  $29 = (($this) + 205|0);
  HEAP8[$29>>0] = 1;
  STACKTOP = sp;return;
 }
 $8 = (($this) + 296|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $1;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + 1)|0;
 $15 = ($14>>>0)>(1073741823);
 if ($15) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = ($13>>>0)<(536870911);
 if ($16) {
  $17 = $12 >> 1;
  $18 = ($17>>>0)<($14>>>0);
  $19 = $18 ? $14 : $17;
  $20 = ($19|0)==(0);
  if ($20) {
   $$0$i3$i$i = 0;$24 = 0;
  } else {
   $$0$i2$i$i = $19;
   label = 9;
  }
 } else {
  $$0$i2$i$i = 1073741823;
  label = 9;
 }
 if ((label|0) == 9) {
  $21 = $$0$i2$i$i << 2;
  $22 = (__Znwj($21)|0);
  $$0$i3$i$i = $$0$i2$i$i;$24 = $22;
 }
 $23 = (($24) + ($13<<2)|0);
 $25 = (($24) + ($$0$i3$i$i<<2)|0);
 $26 = ($23|0)==(0|0);
 if (!($26)) {
  HEAP32[$23>>2] = $node;
 }
 $27 = (($24) + ($14<<2)|0);
 _memcpy(($24|0),($9|0),($12|0))|0;
 HEAP32[$8>>2] = $24;
 HEAP32[$0>>2] = $27;
 HEAP32[$2>>2] = $25;
 $28 = ($9|0)==(0|0);
 if ($28) {
  $29 = (($this) + 205|0);
  HEAP8[$29>>0] = 1;
  STACKTOP = sp;return;
 }
 __ZdlPv($9);
 $29 = (($this) + 205|0);
 HEAP8[$29>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas19SyncTransformParentEv($this) {
 $this = $this|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $newParentCanvas$0 = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($1)|0);
 $3 = (($2) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $newParentCanvas$0 = 0;
 } else {
  $6 = (($4) + 24|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__Z34FindAncestorComponentExactTypeImplRN5Unity10GameObjectEi($7,223)|0);
  $newParentCanvas$0 = $8;
 }
 $9 = (($this) + 260|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($newParentCanvas$0|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = ($10|0)==(0|0);
 L7: do {
  if ($12) {
   label = 12;
  } else {
   $13 = (($this) + 290|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $16 = (($10) + 296|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($10) + 300|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($17|0)==($19|0);
    if (!($20)) {
     $24 = $17;
     while(1) {
      $23 = HEAP32[$24>>2]|0;
      $25 = ($23|0)==($this|0);
      $22 = (($24) + 4|0);
      if ($25) {
       break;
      }
      $21 = ($22|0)==($19|0);
      if ($21) {
       break L7;
      } else {
       $24 = $22;
      }
     }
     $26 = $24;
     $27 = $17;
     $28 = (($26) - ($27))|0;
     $29 = $28 >> 2;
     $30 = (($17) + ($29<<2)|0);
     $$sum$i$i = (($29) + 1)|0;
     $31 = (($17) + ($$sum$i$i<<2)|0);
     $32 = $19;
     $33 = $31;
     $34 = (($32) - ($33))|0;
     $35 = $34 >> 2;
     _memmove(($30|0),($31|0),($34|0))|0;
     $$sum1$i$i = (($35) + ($29))|0;
     $36 = (($17) + ($$sum1$i$i<<2)|0);
     $37 = HEAP32[$18>>2]|0;
     $38 = ($37|0)==($36|0);
     if (!($38)) {
      $__new_last2$i$i$i$i = $36;
      $scevgep$i$i$i$i = (($37) + -4|0);
      $39 = (0 - ($__new_last2$i$i$i$i))|0;
      $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($39)|0);
      $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
      $40 = $uglygep3$i$i$i$i >>> 2;
      $41 = $40 ^ -1;
      $scevgep4$i$i$i$i = (($37) + ($41<<2)|0);
      HEAP32[$18>>2] = $scevgep4$i$i$i$i;
     }
     $42 = (($10) + 205|0);
     HEAP8[$42>>0] = 1;
    }
   } else {
    label = 12;
   }
  }
 } while(0);
 if ((label|0) == 12) {
  $43 = (__ZN2UI16GetCanvasManagerEv()|0);
  __ZN2UI13CanvasManager12RemoveCanvasEPNS_6CanvasE($43,$this);
 }
 $44 = ($newParentCanvas$0|0)==(0|0);
 if ($44) {
  label = 15;
 } else {
  $45 = (($this) + 290|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = ($46<<24>>24)==(0);
  if ($47) {
   __ZN2UI6Canvas15AddNestedCanvasEPS0_($newParentCanvas$0,$this);
  } else {
   label = 15;
  }
 }
 if ((label|0) == 15) {
  $48 = (__ZN2UI16GetCanvasManagerEv()|0);
  __ZN2UI13CanvasManager9AddCanvasEPNS_6CanvasE($48,$this);
 }
 HEAP32[$9>>2] = $newParentCanvas$0;
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas13AwakeFromLoadE17AwakeFromLoadMode($this,$mode) {
 $this = $this|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $data = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode($this,$mode);
 $0 = (($this) + 204|0);
 HEAP8[$0>>0] = 1;
 $1 = (($this) + 205|0);
 HEAP8[$1>>0] = 1;
 $2 = (__ZN2UI16GetCanvasManagerEv()|0);
 __ZN2UI13CanvasManager8SortListEv($2);
 $3 = (($this) + 29|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = ($mode|0)==(0);
 $or$cond = $5 & $6;
 if ($or$cond) {
  __ZN2UI6Canvas25UpdateCanvasRectTransformEv($this);
  $7 = (($data) + 8|0);
  HEAP32[$7>>2] = 0;
  $8 = (($data) + 4|0);
  HEAP32[$8>>2] = 0;
  HEAP32[$data>>2] = 0;
  $9 = (($this) + 24|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($10)|0);
  __ZN9Transform19BroadcastMessageAnyERK17MessageIdentifierR11MessageData($11,566696,$data);
 }
 $12 = $mode & 13;
 $13 = ($12|0)==(0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $14 = (__Z13GetTagManagerv()|0);
 $15 = (($this) + 284|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__ZN10TagManager32GetSortingLayerValueFromUniqueIDEi($14,$16)|0);
 $18 = $17&65535;
 $19 = (($this) + 292|0);
 HEAP16[$19>>1] = $18;
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas25UpdateCanvasRectTransformEv($this) {
 $this = $this|0;
 var $$op = Math_fround(0), $$op77 = Math_fround(0), $$pn = 0, $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0;
 var $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = Math_fround(0), $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = Math_fround(0), $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = Math_fround(0), $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = Math_fround(0), $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0);
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = Math_fround(0), $274 = 0;
 var $275 = Math_fround(0), $276 = 0.0, $277 = 0.0, $278 = 0, $279 = 0, $28 = Math_fround(0), $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0);
 var $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = Math_fround(0), $316 = Math_fround(0), $317 = Math_fround(0), $318 = Math_fround(0), $319 = 0.0, $32 = 0, $320 = 0.0, $321 = Math_fround(0), $322 = Math_fround(0), $323 = 0, $324 = Math_fround(0), $325 = Math_fround(0), $326 = Math_fround(0), $327 = Math_fround(0), $328 = Math_fround(0);
 var $329 = Math_fround(0), $33 = Math_fround(0), $330 = Math_fround(0), $331 = 0, $332 = Math_fround(0), $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = 0, $339 = Math_fround(0), $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = Math_fround(0), $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = Math_fround(0), $348 = Math_fround(0), $349 = 0, $35 = Math_fround(0), $350 = Math_fround(0), $351 = 0, $352 = Math_fround(0), $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = Math_fround(0), $36 = 0, $360 = 0, $361 = Math_fround(0), $362 = 0, $363 = Math_fround(0), $364 = Math_fround(0);
 var $365 = Math_fround(0), $366 = Math_fround(0), $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = Math_fround(0), $370 = Math_fround(0), $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = Math_fround(0), $379 = 0, $38 = Math_fround(0), $380 = Math_fround(0), $381 = 0, $382 = Math_fround(0);
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = Math_fround(0), $390 = 0, $391 = Math_fround(0), $392 = Math_fround(0), $393 = 0, $394 = Math_fround(0), $395 = Math_fround(0), $396 = 0, $397 = Math_fround(0), $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0;
 var $400 = 0, $401 = Math_fround(0), $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = Math_fround(0), $406 = Math_fround(0), $407 = 0, $408 = Math_fround(0), $409 = 0, $41 = Math_fround(0), $410 = Math_fround(0), $411 = 0, $412 = Math_fround(0), $413 = Math_fround(0), $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = 0;
 var $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = Math_fround(0), $423 = Math_fround(0), $424 = Math_fround(0), $425 = 0, $426 = Math_fround(0), $427 = 0, $428 = Math_fround(0), $429 = 0, $43 = Math_fround(0), $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = Math_fround(0), $436 = 0;
 var $437 = 0, $438 = Math_fround(0), $439 = 0, $44 = 0, $440 = 0, $441 = Math_fround(0), $442 = 0, $443 = 0, $444 = Math_fround(0), $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = Math_fround(0), $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = Math_fround(0), $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0;
 var $491 = Math_fround(0), $492 = Math_fround(0), $493 = Math_fround(0), $494 = 0, $495 = Math_fround(0), $496 = Math_fround(0), $497 = 0, $498 = Math_fround(0), $499 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $500 = Math_fround(0), $501 = Math_fround(0), $502 = Math_fround(0), $503 = Math_fround(0), $504 = Math_fround(0), $505 = Math_fround(0), $506 = 0, $507 = Math_fround(0), $508 = Math_fround(0);
 var $509 = Math_fround(0), $51 = 0, $510 = Math_fround(0), $511 = Math_fround(0), $512 = Math_fround(0), $513 = Math_fround(0), $514 = Math_fround(0), $515 = Math_fround(0), $516 = Math_fround(0), $517 = Math_fround(0), $518 = Math_fround(0), $519 = Math_fround(0), $52 = Math_fround(0), $520 = Math_fround(0), $521 = Math_fround(0), $522 = Math_fround(0), $523 = Math_fround(0), $524 = Math_fround(0), $525 = Math_fround(0), $526 = Math_fround(0);
 var $527 = Math_fround(0), $528 = Math_fround(0), $529 = Math_fround(0), $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = Math_fround(0), $533 = Math_fround(0), $534 = Math_fround(0), $535 = Math_fround(0), $536 = Math_fround(0), $537 = Math_fround(0), $538 = Math_fround(0), $539 = Math_fround(0), $54 = Math_fround(0), $540 = 0, $541 = Math_fround(0), $542 = Math_fround(0), $543 = 0, $544 = Math_fround(0);
 var $545 = Math_fround(0), $546 = 0, $547 = 0, $548 = Math_fround(0), $549 = Math_fround(0), $55 = 0, $550 = 0, $551 = 0, $552 = Math_fround(0), $553 = Math_fround(0), $554 = 0, $555 = 0, $556 = Math_fround(0), $557 = Math_fround(0), $558 = 0, $559 = 0, $56 = 0, $560 = Math_fround(0), $561 = Math_fround(0), $562 = 0;
 var $563 = 0, $564 = Math_fround(0), $565 = Math_fround(0), $566 = 0, $567 = 0, $568 = Math_fround(0), $569 = Math_fround(0), $57 = 0, $570 = 0, $571 = 0, $572 = Math_fround(0), $573 = Math_fround(0), $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0;
 var $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = 0;
 var $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = Math_fround(0), $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0);
 var $88 = 0, $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $camHeight$0 = Math_fround(0), $cameraParent$0 = 0, $cameraParent$0$in = 0, $cameraPos = 0, $cameraRot = 0, $canvasPos = 0, $or$cond = 0;
 var $or$cond76 = 0, $pos$i$i$i$i43 = 0, $r = 0, $scale$0 = Math_fround(0), $switch = 0, $temp$0$i = 0, $temp$0$i29 = 0, $temp$0$i35 = 0, $temp$0$i41 = 0, $temp$0$i47 = 0, $transformChangedMask$0 = 0, $transformChangedMask$1 = 0, $transformChangedMask$2 = 0, $transformChangedMask$275 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $pos$i$i$i$i43 = sp + 144|0;
 $0 = sp + 136|0;
 $1 = sp + 132|0;
 $2 = sp + 128|0;
 $3 = sp + 124|0;
 $4 = sp + 120|0;
 $r = sp + 104|0;
 $5 = sp + 88|0;
 $6 = sp + 56|0;
 $cameraPos = sp + 40|0;
 $cameraRot = sp + 24|0;
 $canvasPos = sp + 12|0;
 $7 = sp;
 $8 = sp + 72|0;
 $9 = (($this) + 24|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($10,224)|0);
 $12 = (($this) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 $switch = ($13>>>0)<(2);
 do {
  if ($switch) {
   $14 = (($this) + 260|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $17 = (($11) + 176|0);
    $18 = Math_fround(HEAPF32[$17>>2]);
    $19 = Math_fround(HEAPF32[616640>>2]);
    $20 = Math_fround($19 - $18);
    $21 = $20 < Math_fround(0.0);
    if ($21) {
     $22 = Math_fround(-$20);
     $35 = $22;
    } else {
     $35 = $20;
    }
    $23 = $18 < Math_fround(0.0);
    if ($23) {
     $24 = Math_fround(-$18);
     $28 = $24;
    } else {
     $28 = $18;
    }
    $25 = $19 < Math_fround(0.0);
    if ($25) {
     $26 = Math_fround(-$19);
     $29 = $26;
    } else {
     $29 = $19;
    }
    $27 = $28 < $29;
    $30 = $27 ? $29 : $28;
    $31 = Math_fround($30 * Math_fround(9.99999997475242707878E-7));
    $32 = $31 < Math_fround(7.99999979790300130844E-5);
    $33 = $32 ? Math_fround(7.99999979790300130844E-5) : $31;
    $34 = $35 < $33;
    if ($34) {
     $36 = (($11) + 180|0);
     $37 = Math_fround(HEAPF32[$36>>2]);
     $38 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
     $39 = Math_fround($38 - $37);
     $40 = $39 < Math_fround(0.0);
     if ($40) {
      $41 = Math_fround(-$39);
      $54 = $41;
     } else {
      $54 = $39;
     }
     $42 = $37 < Math_fround(0.0);
     if ($42) {
      $43 = Math_fround(-$37);
      $47 = $43;
     } else {
      $47 = $37;
     }
     $44 = $38 < Math_fround(0.0);
     if ($44) {
      $45 = Math_fround(-$38);
      $48 = $45;
     } else {
      $48 = $38;
     }
     $46 = $47 < $48;
     $49 = $46 ? $48 : $47;
     $50 = Math_fround($49 * Math_fround(9.99999997475242707878E-7));
     $51 = $50 < Math_fround(7.99999979790300130844E-5);
     $52 = $51 ? Math_fround(7.99999979790300130844E-5) : $50;
     $53 = $54 < $52;
     if ($53) {
      $68 = $19;
     } else {
      label = 17;
     }
    } else {
     label = 17;
    }
    if ((label|0) == 17) {
     $55 = 616640;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = (($55) + 4)|0;
     $59 = $58;
     $60 = HEAP32[$59>>2]|0;
     $61 = $17;
     $62 = $61;
     HEAP32[$62>>2] = $57;
     $63 = (($61) + 4)|0;
     $64 = $63;
     HEAP32[$64>>2] = $60;
     __ZN2UI13RectTransform9DirtyRectEv($11);
     $$pre = Math_fround(HEAPF32[616640>>2]);
     $68 = $$pre;
    }
    $65 = (($11) + 184|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    $67 = Math_fround($68 - $66);
    $69 = $67 < Math_fround(0.0);
    if ($69) {
     $70 = Math_fround(-$67);
     $83 = $70;
    } else {
     $83 = $67;
    }
    $71 = $66 < Math_fround(0.0);
    if ($71) {
     $72 = Math_fround(-$66);
     $76 = $72;
    } else {
     $76 = $66;
    }
    $73 = $68 < Math_fround(0.0);
    if ($73) {
     $74 = Math_fround(-$68);
     $77 = $74;
    } else {
     $77 = $68;
    }
    $75 = $76 < $77;
    $78 = $75 ? $77 : $76;
    $79 = Math_fround($78 * Math_fround(9.99999997475242707878E-7));
    $80 = $79 < Math_fround(7.99999979790300130844E-5);
    $81 = $80 ? Math_fround(7.99999979790300130844E-5) : $79;
    $82 = $83 < $81;
    if ($82) {
     $84 = (($11) + 188|0);
     $85 = Math_fround(HEAPF32[$84>>2]);
     $86 = Math_fround(HEAPF32[((616640 + 4|0))>>2]);
     $87 = Math_fround($86 - $85);
     $88 = $87 < Math_fround(0.0);
     if ($88) {
      $89 = Math_fround(-$87);
      $102 = $89;
     } else {
      $102 = $87;
     }
     $90 = $85 < Math_fround(0.0);
     if ($90) {
      $91 = Math_fround(-$85);
      $95 = $91;
     } else {
      $95 = $85;
     }
     $92 = $86 < Math_fround(0.0);
     if ($92) {
      $93 = Math_fround(-$86);
      $96 = $93;
     } else {
      $96 = $86;
     }
     $94 = $95 < $96;
     $97 = $94 ? $96 : $95;
     $98 = Math_fround($97 * Math_fround(9.99999997475242707878E-7));
     $99 = $98 < Math_fround(7.99999979790300130844E-5);
     $100 = $99 ? Math_fround(7.99999979790300130844E-5) : $98;
     $101 = $102 < $100;
     if (!($101)) {
      label = 32;
     }
    } else {
     label = 32;
    }
    if ((label|0) == 32) {
     $103 = 616640;
     $104 = $103;
     $105 = HEAP32[$104>>2]|0;
     $106 = (($103) + 4)|0;
     $107 = $106;
     $108 = HEAP32[$107>>2]|0;
     $109 = $65;
     $110 = $109;
     HEAP32[$110>>2] = $105;
     $111 = (($109) + 4)|0;
     $112 = $111;
     HEAP32[$112>>2] = $108;
     __ZN2UI13RectTransform9DirtyRectEv($11);
    }
    $113 = (($11) + 208|0);
    $114 = Math_fround(HEAPF32[$113>>2]);
    $115 = Math_fround(Math_fround(0.5) - $114);
    $116 = $115 < Math_fround(0.0);
    if ($116) {
     $117 = Math_fround(-$115);
     $126 = $117;
    } else {
     $126 = $115;
    }
    $118 = $114 < Math_fround(0.0);
    if ($118) {
     $119 = Math_fround(-$114);
     $121 = $119;
    } else {
     $121 = $114;
    }
    $120 = $121 < Math_fround(0.5);
    $$op = Math_fround($121 * Math_fround(9.99999997475242707878E-7));
    $122 = $120 ? Math_fround(4.99999998737621353939E-7) : $$op;
    $123 = $122 < Math_fround(7.99999979790300130844E-5);
    $124 = $123 ? Math_fround(7.99999979790300130844E-5) : $122;
    $125 = $126 < $124;
    if ($125) {
     $127 = (($11) + 212|0);
     $128 = Math_fround(HEAPF32[$127>>2]);
     $129 = Math_fround(Math_fround(0.5) - $128);
     $130 = $129 < Math_fround(0.0);
     if ($130) {
      $131 = Math_fround(-$129);
      $140 = $131;
     } else {
      $140 = $129;
     }
     $132 = $128 < Math_fround(0.0);
     if ($132) {
      $133 = Math_fround(-$128);
      $135 = $133;
     } else {
      $135 = $128;
     }
     $134 = $135 < Math_fround(0.5);
     $$op77 = Math_fround($135 * Math_fround(9.99999997475242707878E-7));
     $136 = $134 ? Math_fround(4.99999998737621353939E-7) : $$op77;
     $137 = $136 < Math_fround(7.99999979790300130844E-5);
     $138 = $137 ? Math_fround(7.99999979790300130844E-5) : $136;
     $139 = $140 < $138;
     if (!($139)) {
      label = 43;
     }
    } else {
     label = 43;
    }
    if ((label|0) == 43) {
     $141 = $113;
     $142 = $141;
     HEAP32[$142>>2] = 1056964608;
     $143 = (($141) + 4)|0;
     $144 = $143;
     HEAP32[$144>>2] = 1056964608;
     __ZN2UI13RectTransform9DirtyRectEv($11);
    }
    $145 = (__ZNK2UI6Canvas13GetRenderModeEv($this)|0);
    $146 = ($145|0)==(0);
    if ($146) {
     $147 = (__Z16GetScreenManagerv()|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = (($148) + 80|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = (FUNCTION_TABLE_ii[$150 & 4095]($147)|0);
     $152 = (Math_fround(($151|0)));
     $153 = (__Z16GetScreenManagerv()|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (($154) + 84|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = (FUNCTION_TABLE_ii[$156 & 4095]($153)|0);
     $158 = (Math_fround(($157|0)));
     $159 = (($this) + 268|0);
     $160 = Math_fround(HEAPF32[$159>>2]);
     $327 = $160;$328 = $152;$330 = $158;$scale$0 = $160;
    } else {
     $161 = (($this) + 36|0);
     $162 = HEAP32[$161>>2]|0;
     HEAP32[$3>>2] = $162;
     $163 = HEAP32[560624>>2]|0;
     $164 = ($163|0)==(0|0);
     if ($164) {
      label = 54;
     } else {
      $165 = (($163) + 36|0);
      $166 = HEAP32[$165>>2]|0;
      $167 = (($163) + 4|0);
      $168 = HEAP32[$167>>2]|0;
      $169 = ($166|0)==($168|0);
      do {
       if ($169) {
        $170 = (($163) + 28|0);
        $171 = HEAP32[$170>>2]|0;
        $172 = (($163) + 32|0);
        $173 = HEAP32[$172>>2]|0;
        $174 = (($171) + ($173<<3)|0);
        $190 = $174;
       } else {
        __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i43,$163,$3);
        $175 = HEAP32[$pos$i$i$i$i43>>2]|0;
        $176 = ($175|0)==(-1);
        $177 = (($163) + 28|0);
        $178 = HEAP32[$177>>2]|0;
        if ($176) {
         $179 = (($163) + 32|0);
         $180 = HEAP32[$179>>2]|0;
         $181 = (($178) + ($180<<3)|0);
         $190 = $181;
         break;
        } else {
         $182 = (($178) + ($175<<3)|0);
         $190 = $182;
         break;
        }
       }
      } while(0);
      $183 = HEAP32[560624>>2]|0;
      $184 = (($183) + 28|0);
      $185 = HEAP32[$184>>2]|0;
      $186 = (($183) + 32|0);
      $187 = HEAP32[$186>>2]|0;
      $188 = (($185) + ($187<<3)|0);
      $189 = ($190|0)==($188|0);
      if ($189) {
       label = 54;
      } else {
       $191 = (($190) + 4|0);
       $192 = HEAP32[$191>>2]|0;
       $193 = ($192|0)==(0|0);
       if ($193) {
        label = 54;
       } else {
        $temp$0$i29 = $192;
       }
      }
     }
     if ((label|0) == 54) {
      $194 = HEAP32[$161>>2]|0;
      $195 = (__Z31ReadObjectFromPersistentManageri($194)|0);
      $temp$0$i29 = $195;
     }
     __ZNK6Camera13GetCameraRectEb($r,$temp$0$i29,1);
     $196 = (($r) + 8|0);
     $197 = Math_fround(HEAPF32[$196>>2]);
     $198 = (($r) + 12|0);
     $199 = Math_fround(HEAPF32[$198>>2]);
     $200 = HEAP32[$161>>2]|0;
     HEAP32[$2>>2] = $200;
     $201 = HEAP32[560624>>2]|0;
     $202 = ($201|0)==(0|0);
     do {
      if ($202) {
       label = 63;
      } else {
       $203 = (($201) + 36|0);
       $204 = HEAP32[$203>>2]|0;
       $205 = (($201) + 4|0);
       $206 = HEAP32[$205>>2]|0;
       $207 = ($204|0)==($206|0);
       do {
        if ($207) {
         $208 = (($201) + 28|0);
         $209 = HEAP32[$208>>2]|0;
         $210 = (($201) + 32|0);
         $211 = HEAP32[$210>>2]|0;
         $212 = (($209) + ($211<<3)|0);
         $228 = $212;
        } else {
         __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i43,$201,$2);
         $213 = HEAP32[$pos$i$i$i$i43>>2]|0;
         $214 = ($213|0)==(-1);
         $215 = (($201) + 28|0);
         $216 = HEAP32[$215>>2]|0;
         if ($214) {
          $217 = (($201) + 32|0);
          $218 = HEAP32[$217>>2]|0;
          $219 = (($216) + ($218<<3)|0);
          $228 = $219;
          break;
         } else {
          $220 = (($216) + ($213<<3)|0);
          $228 = $220;
          break;
         }
        }
       } while(0);
       $221 = HEAP32[560624>>2]|0;
       $222 = (($221) + 28|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = (($221) + 32|0);
       $225 = HEAP32[$224>>2]|0;
       $226 = (($223) + ($225<<3)|0);
       $227 = ($228|0)==($226|0);
       if ($227) {
        label = 63;
        break;
       }
       $229 = (($228) + 4|0);
       $230 = HEAP32[$229>>2]|0;
       $231 = ($230|0)==(0|0);
       if ($231) {
        label = 63;
       } else {
        $temp$0$i35 = $230;
       }
      }
     } while(0);
     if ((label|0) == 63) {
      $232 = HEAP32[$161>>2]|0;
      $233 = (__Z31ReadObjectFromPersistentManageri($232)|0);
      $temp$0$i35 = $233;
     }
     $234 = (($temp$0$i35) + 616|0);
     $235 = HEAP8[$234>>0]|0;
     $236 = ($235<<24>>24)==(0);
     if ($236) {
      $274 = (($this) + 280|0);
      $275 = Math_fround(HEAPF32[$274>>2]);
      $276 = +$275;
      $277 = $276 * 2.0;
      $278 = HEAP32[$161>>2]|0;
      HEAP32[$0>>2] = $278;
      $279 = HEAP32[560624>>2]|0;
      $280 = ($279|0)==(0|0);
      do {
       if ($280) {
        label = 83;
       } else {
        $281 = (($279) + 36|0);
        $282 = HEAP32[$281>>2]|0;
        $283 = (($279) + 4|0);
        $284 = HEAP32[$283>>2]|0;
        $285 = ($282|0)==($284|0);
        do {
         if ($285) {
          $286 = (($279) + 28|0);
          $287 = HEAP32[$286>>2]|0;
          $288 = (($279) + 32|0);
          $289 = HEAP32[$288>>2]|0;
          $290 = (($287) + ($289<<3)|0);
          $306 = $290;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i43,$279,$0);
          $291 = HEAP32[$pos$i$i$i$i43>>2]|0;
          $292 = ($291|0)==(-1);
          $293 = (($279) + 28|0);
          $294 = HEAP32[$293>>2]|0;
          if ($292) {
           $295 = (($279) + 32|0);
           $296 = HEAP32[$295>>2]|0;
           $297 = (($294) + ($296<<3)|0);
           $306 = $297;
           break;
          } else {
           $298 = (($294) + ($291<<3)|0);
           $306 = $298;
           break;
          }
         }
        } while(0);
        $299 = HEAP32[560624>>2]|0;
        $300 = (($299) + 28|0);
        $301 = HEAP32[$300>>2]|0;
        $302 = (($299) + 32|0);
        $303 = HEAP32[$302>>2]|0;
        $304 = (($301) + ($303<<3)|0);
        $305 = ($306|0)==($304|0);
        if ($305) {
         label = 83;
         break;
        }
        $307 = (($306) + 4|0);
        $308 = HEAP32[$307>>2]|0;
        $309 = ($308|0)==(0|0);
        if ($309) {
         label = 83;
        } else {
         $temp$0$i47 = $308;
        }
       }
      } while(0);
      if ((label|0) == 83) {
       $310 = HEAP32[$161>>2]|0;
       $311 = (__Z31ReadObjectFromPersistentManageri($310)|0);
       $temp$0$i47 = $311;
      }
      $312 = (($temp$0$i47) + 452|0);
      $313 = Math_fround(HEAPF32[$312>>2]);
      $314 = Math_fround($313 * Math_fround(0.5));
      $315 = Math_fround($314 / Math_fround(360.0));
      $316 = Math_fround($315 * Math_fround(2.0));
      $317 = Math_fround($316 * Math_fround(3.14159274101257324219));
      $318 = (Math_fround(+(Math_tan((+$317)))));
      $319 = +$318;
      $320 = $277 * $319;
      $321 = Math_fround($320);
      $camHeight$0 = $321;
     } else {
      $237 = HEAP32[$161>>2]|0;
      HEAP32[$1>>2] = $237;
      $238 = HEAP32[560624>>2]|0;
      $239 = ($238|0)==(0|0);
      do {
       if ($239) {
        label = 73;
       } else {
        $240 = (($238) + 36|0);
        $241 = HEAP32[$240>>2]|0;
        $242 = (($238) + 4|0);
        $243 = HEAP32[$242>>2]|0;
        $244 = ($241|0)==($243|0);
        do {
         if ($244) {
          $245 = (($238) + 28|0);
          $246 = HEAP32[$245>>2]|0;
          $247 = (($238) + 32|0);
          $248 = HEAP32[$247>>2]|0;
          $249 = (($246) + ($248<<3)|0);
          $265 = $249;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i43,$238,$1);
          $250 = HEAP32[$pos$i$i$i$i43>>2]|0;
          $251 = ($250|0)==(-1);
          $252 = (($238) + 28|0);
          $253 = HEAP32[$252>>2]|0;
          if ($251) {
           $254 = (($238) + 32|0);
           $255 = HEAP32[$254>>2]|0;
           $256 = (($253) + ($255<<3)|0);
           $265 = $256;
           break;
          } else {
           $257 = (($253) + ($250<<3)|0);
           $265 = $257;
           break;
          }
         }
        } while(0);
        $258 = HEAP32[560624>>2]|0;
        $259 = (($258) + 28|0);
        $260 = HEAP32[$259>>2]|0;
        $261 = (($258) + 32|0);
        $262 = HEAP32[$261>>2]|0;
        $263 = (($260) + ($262<<3)|0);
        $264 = ($265|0)==($263|0);
        if ($264) {
         label = 73;
         break;
        }
        $266 = (($265) + 4|0);
        $267 = HEAP32[$266>>2]|0;
        $268 = ($267|0)==(0|0);
        if ($268) {
         label = 73;
        } else {
         $temp$0$i41 = $267;
        }
       }
      } while(0);
      if ((label|0) == 73) {
       $269 = HEAP32[$161>>2]|0;
       $270 = (__Z31ReadObjectFromPersistentManageri($269)|0);
       $temp$0$i41 = $270;
      }
      $271 = (($temp$0$i41) + 448|0);
      $272 = Math_fround(HEAPF32[$271>>2]);
      $273 = Math_fround($272 * Math_fround(2.0));
      $camHeight$0 = $273;
     }
     $322 = Math_fround($camHeight$0 / $199);
     $323 = (($this) + 268|0);
     $324 = Math_fround(HEAPF32[$323>>2]);
     $325 = Math_fround($322 * $324);
     $327 = $324;$328 = $197;$330 = $199;$scale$0 = $325;
    }
    $326 = Math_fround($328 / $327);
    $329 = Math_fround($330 / $327);
    $331 = (($11) + 200|0);
    $332 = Math_fround(HEAPF32[$331>>2]);
    $333 = $332 != $326;
    if ($333) {
     label = 88;
    } else {
     $334 = (($331) + 4|0);
     $335 = Math_fround(HEAPF32[$334>>2]);
     $336 = $335 != $329;
     if ($336) {
      label = 88;
     }
    }
    do {
     if ((label|0) == 88) {
      $337 = Math_fround($326 - $332);
      $338 = $337 < Math_fround(0.0);
      if ($338) {
       $339 = Math_fround(-$337);
       $352 = $339;
      } else {
       $352 = $337;
      }
      $340 = $332 < Math_fround(0.0);
      if ($340) {
       $341 = Math_fround(-$332);
       $345 = $341;
      } else {
       $345 = $332;
      }
      $342 = $326 < Math_fround(0.0);
      if ($342) {
       $343 = Math_fround(-$326);
       $346 = $343;
      } else {
       $346 = $326;
      }
      $344 = $345 < $346;
      $347 = $344 ? $346 : $345;
      $348 = Math_fround($347 * Math_fround(9.99999997475242707878E-7));
      $349 = $348 < Math_fround(7.99999979790300130844E-5);
      $350 = $349 ? Math_fround(7.99999979790300130844E-5) : $348;
      $351 = $352 < $350;
      if ($351) {
       $353 = (($11) + 204|0);
       $354 = Math_fround(HEAPF32[$353>>2]);
       $355 = Math_fround($329 - $354);
       $356 = $355 < Math_fround(0.0);
       if ($356) {
        $357 = Math_fround(-$355);
        $370 = $357;
       } else {
        $370 = $355;
       }
       $358 = $354 < Math_fround(0.0);
       if ($358) {
        $359 = Math_fround(-$354);
        $363 = $359;
       } else {
        $363 = $354;
       }
       $360 = $329 < Math_fround(0.0);
       if ($360) {
        $361 = Math_fround(-$329);
        $364 = $361;
       } else {
        $364 = $329;
       }
       $362 = $363 < $364;
       $365 = $362 ? $364 : $363;
       $366 = Math_fround($365 * Math_fround(9.99999997475242707878E-7));
       $367 = $366 < Math_fround(7.99999979790300130844E-5);
       $368 = $367 ? Math_fround(7.99999979790300130844E-5) : $366;
       $369 = $370 < $368;
       if ($369) {
        break;
       }
      }
      $371 = (HEAPF32[tempDoublePtr>>2]=$326,HEAP32[tempDoublePtr>>2]|0);
      $372 = (HEAPF32[tempDoublePtr>>2]=$329,HEAP32[tempDoublePtr>>2]|0);
      $373 = $331;
      $374 = $373;
      HEAP32[$374>>2] = $371;
      $375 = (($373) + 4)|0;
      $376 = $375;
      HEAP32[$376>>2] = $372;
      __ZN2UI13RectTransform9DirtyRectEv($11);
     }
    } while(0);
    $377 = (($11) + 56|0);
    $378 = Math_fround(HEAPF32[$377>>2]);
    $379 = (($11) + 60|0);
    $380 = Math_fround(HEAPF32[$379>>2]);
    $381 = (($11) + 64|0);
    $382 = Math_fround(HEAPF32[$381>>2]);
    $383 = $378 != $scale$0;
    $384 = $380 != $scale$0;
    $or$cond = $383 | $384;
    $385 = $382 != $scale$0;
    $or$cond76 = $or$cond | $385;
    if ($or$cond76) {
     HEAPF32[$377>>2] = $scale$0;
     HEAPF32[$379>>2] = $scale$0;
     HEAPF32[$381>>2] = $scale$0;
     $386 = (($11) + 135|0);
     $387 = HEAP8[$386>>0]|0;
     $388 = $387&255;
     $389 = $388 | 8;
     $390 = $389&255;
     HEAP8[$386>>0] = $390;
     __ZN9Transform24RecalculateTransformTypeEv($11);
     $transformChangedMask$0 = 8;
    } else {
     $transformChangedMask$0 = 0;
    }
    L156: do {
     if ($146) {
      $391 = Math_fround($328 * Math_fround(0.5));
      $392 = Math_fround($330 * Math_fround(0.5));
      $393 = (($11) + 192|0);
      $394 = Math_fround(HEAPF32[$393>>2]);
      $395 = Math_fround($391 - $394);
      $396 = $395 < Math_fround(0.0);
      if ($396) {
       $397 = Math_fround(-$395);
       $410 = $397;
      } else {
       $410 = $395;
      }
      $398 = $394 < Math_fround(0.0);
      if ($398) {
       $399 = Math_fround(-$394);
       $403 = $399;
      } else {
       $403 = $394;
      }
      $400 = $391 < Math_fround(0.0);
      if ($400) {
       $401 = Math_fround(-$391);
       $404 = $401;
      } else {
       $404 = $391;
      }
      $402 = $403 < $404;
      $405 = $402 ? $404 : $403;
      $406 = Math_fround($405 * Math_fround(9.99999997475242707878E-7));
      $407 = $406 < Math_fround(7.99999979790300130844E-5);
      $408 = $407 ? Math_fround(7.99999979790300130844E-5) : $406;
      $409 = $410 < $408;
      if ($409) {
       $411 = (($11) + 196|0);
       $412 = Math_fround(HEAPF32[$411>>2]);
       $413 = Math_fround($392 - $412);
       $414 = $413 < Math_fround(0.0);
       if ($414) {
        $415 = Math_fround(-$413);
        $428 = $415;
       } else {
        $428 = $413;
       }
       $416 = $412 < Math_fround(0.0);
       if ($416) {
        $417 = Math_fround(-$412);
        $421 = $417;
       } else {
        $421 = $412;
       }
       $418 = $392 < Math_fround(0.0);
       if ($418) {
        $419 = Math_fround(-$392);
        $422 = $419;
       } else {
        $422 = $392;
       }
       $420 = $421 < $422;
       $423 = $420 ? $422 : $421;
       $424 = Math_fround($423 * Math_fround(9.99999997475242707878E-7));
       $425 = $424 < Math_fround(7.99999979790300130844E-5);
       $426 = $425 ? Math_fround(7.99999979790300130844E-5) : $424;
       $427 = $428 < $426;
       if (!($427)) {
        label = 120;
       }
      } else {
       label = 120;
      }
      if ((label|0) == 120) {
       $429 = (HEAPF32[tempDoublePtr>>2]=$391,HEAP32[tempDoublePtr>>2]|0);
       $430 = (HEAPF32[tempDoublePtr>>2]=$392,HEAP32[tempDoublePtr>>2]|0);
       $431 = $393;
       $432 = $431;
       HEAP32[$432>>2] = $429;
       $433 = (($431) + 4)|0;
       $434 = $433;
       HEAP32[$434>>2] = $430;
       __ZN2UI13RectTransform9DirtyRectEv($11);
      }
      __ZNK9Transform11GetRotationEv($5,$11);
      $435 = Math_fround(HEAPF32[$5>>2]);
      $436 = $435 != Math_fround(0.0);
      do {
       if (!($436)) {
        $437 = (($5) + 4|0);
        $438 = Math_fround(HEAPF32[$437>>2]);
        $439 = $438 != Math_fround(0.0);
        if ($439) {
         break;
        }
        $440 = (($5) + 8|0);
        $441 = Math_fround(HEAPF32[$440>>2]);
        $442 = $441 != Math_fround(0.0);
        if ($442) {
         break;
        }
        $443 = (($5) + 12|0);
        $444 = Math_fround(HEAPF32[$443>>2]);
        $445 = $444 != Math_fround(1.0);
        if (!($445)) {
         $transformChangedMask$2 = $transformChangedMask$0;
         label = 147;
         break L156;
        }
       }
      } while(0);
      HEAPF32[$6>>2] = Math_fround(0.0);
      $446 = (($6) + 4|0);
      HEAPF32[$446>>2] = Math_fround(0.0);
      $447 = (($6) + 8|0);
      HEAPF32[$447>>2] = Math_fround(0.0);
      $448 = (($6) + 12|0);
      HEAPF32[$448>>2] = Math_fround(1.0);
      __ZN9Transform30SetRotationWithoutNotificationERK11Quaternionf($11,$6);
      $449 = $transformChangedMask$0 | 2;
      $transformChangedMask$275 = $449;
     } else {
      $450 = (($this) + 36|0);
      $451 = HEAP32[$450>>2]|0;
      HEAP32[$4>>2] = $451;
      $452 = HEAP32[560624>>2]|0;
      $453 = ($452|0)==(0|0);
      do {
       if ($453) {
        label = 134;
       } else {
        $454 = (($452) + 36|0);
        $455 = HEAP32[$454>>2]|0;
        $456 = (($452) + 4|0);
        $457 = HEAP32[$456>>2]|0;
        $458 = ($455|0)==($457|0);
        do {
         if ($458) {
          $459 = (($452) + 28|0);
          $460 = HEAP32[$459>>2]|0;
          $461 = (($452) + 32|0);
          $462 = HEAP32[$461>>2]|0;
          $463 = (($460) + ($462<<3)|0);
          $479 = $463;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i$i43,$452,$4);
          $464 = HEAP32[$pos$i$i$i$i43>>2]|0;
          $465 = ($464|0)==(-1);
          $466 = (($452) + 28|0);
          $467 = HEAP32[$466>>2]|0;
          if ($465) {
           $468 = (($452) + 32|0);
           $469 = HEAP32[$468>>2]|0;
           $470 = (($467) + ($469<<3)|0);
           $479 = $470;
           break;
          } else {
           $471 = (($467) + ($464<<3)|0);
           $479 = $471;
           break;
          }
         }
        } while(0);
        $472 = HEAP32[560624>>2]|0;
        $473 = (($472) + 28|0);
        $474 = HEAP32[$473>>2]|0;
        $475 = (($472) + 32|0);
        $476 = HEAP32[$475>>2]|0;
        $477 = (($474) + ($476<<3)|0);
        $478 = ($479|0)==($477|0);
        if ($478) {
         label = 134;
         break;
        }
        $480 = (($479) + 4|0);
        $481 = HEAP32[$480>>2]|0;
        $482 = ($481|0)==(0|0);
        if ($482) {
         label = 134;
        } else {
         $temp$0$i = $481;
        }
       }
      } while(0);
      if ((label|0) == 134) {
       $483 = HEAP32[$450>>2]|0;
       $484 = (__Z31ReadObjectFromPersistentManageri($483)|0);
       $temp$0$i = $484;
      }
      $485 = (($temp$0$i) + 24|0);
      $486 = HEAP32[$485>>2]|0;
      $487 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($486)|0);
      $$pn = $487;
      while(1) {
       $cameraParent$0$in = (($$pn) + 156|0);
       $cameraParent$0 = HEAP32[$cameraParent$0$in>>2]|0;
       $488 = ($cameraParent$0|0)==(0|0);
       if ($488) {
        break;
       }
       $489 = ($cameraParent$0|0)==($11|0);
       if ($489) {
        $transformChangedMask$2 = $transformChangedMask$0;
        label = 147;
        break L156;
       } else {
        $$pn = $cameraParent$0;
       }
      }
      __ZNK9Transform11GetPositionEv($cameraPos,$487);
      __ZNK9Transform11GetRotationEv($cameraRot,$487);
      $490 = (($this) + 280|0);
      $491 = Math_fround(HEAPF32[$490>>2]);
      $492 = Math_fround(HEAPF32[$cameraRot>>2]);
      $493 = Math_fround($492 * Math_fround(2.0));
      $494 = (($cameraRot) + 4|0);
      $495 = Math_fround(HEAPF32[$494>>2]);
      $496 = Math_fround($495 * Math_fround(2.0));
      $497 = (($cameraRot) + 8|0);
      $498 = Math_fround(HEAPF32[$497>>2]);
      $499 = Math_fround($498 * Math_fround(2.0));
      $500 = Math_fround($492 * $493);
      $501 = Math_fround($495 * $496);
      $502 = Math_fround($498 * $499);
      $503 = Math_fround($492 * $496);
      $504 = Math_fround($492 * $499);
      $505 = Math_fround($495 * $499);
      $506 = (($cameraRot) + 12|0);
      $507 = Math_fround(HEAPF32[$506>>2]);
      $508 = Math_fround($493 * $507);
      $509 = Math_fround($496 * $507);
      $510 = Math_fround($507 * $499);
      $511 = Math_fround($501 + $502);
      $512 = Math_fround(Math_fround(1.0) - $511);
      $513 = Math_fround($512 * Math_fround(0.0));
      $514 = Math_fround($503 - $510);
      $515 = Math_fround($514 * Math_fround(0.0));
      $516 = Math_fround($515 + $513);
      $517 = Math_fround($504 + $509);
      $518 = Math_fround($491 * $517);
      $519 = Math_fround($518 + $516);
      $520 = Math_fround($503 + $510);
      $521 = Math_fround($520 * Math_fround(0.0));
      $522 = Math_fround($500 + $502);
      $523 = Math_fround(Math_fround(1.0) - $522);
      $524 = Math_fround($523 * Math_fround(0.0));
      $525 = Math_fround($521 + $524);
      $526 = Math_fround($505 - $508);
      $527 = Math_fround($491 * $526);
      $528 = Math_fround($527 + $525);
      $529 = Math_fround($504 - $509);
      $530 = Math_fround($529 * Math_fround(0.0));
      $531 = Math_fround($505 + $508);
      $532 = Math_fround($531 * Math_fround(0.0));
      $533 = Math_fround($530 + $532);
      $534 = Math_fround($500 + $501);
      $535 = Math_fround(Math_fround(1.0) - $534);
      $536 = Math_fround($491 * $535);
      $537 = Math_fround($536 + $533);
      $538 = Math_fround(HEAPF32[$cameraPos>>2]);
      $539 = Math_fround($538 + $519);
      $540 = (($cameraPos) + 4|0);
      $541 = Math_fround(HEAPF32[$540>>2]);
      $542 = Math_fround($541 + $528);
      $543 = (($cameraPos) + 8|0);
      $544 = Math_fround(HEAPF32[$543>>2]);
      $545 = Math_fround($544 + $537);
      HEAPF32[$canvasPos>>2] = $539;
      $546 = (($canvasPos) + 4|0);
      HEAPF32[$546>>2] = $542;
      $547 = (($canvasPos) + 8|0);
      HEAPF32[$547>>2] = $545;
      __ZNK9Transform11GetPositionEv($7,$11);
      $548 = Math_fround(HEAPF32[$7>>2]);
      $549 = Math_fround(HEAPF32[$canvasPos>>2]);
      $550 = $548 != $549;
      do {
       if ($550) {
        label = 141;
       } else {
        $551 = (($7) + 4|0);
        $552 = Math_fround(HEAPF32[$551>>2]);
        $553 = Math_fround(HEAPF32[$546>>2]);
        $554 = $552 != $553;
        if ($554) {
         label = 141;
         break;
        }
        $555 = (($7) + 8|0);
        $556 = Math_fround(HEAPF32[$555>>2]);
        $557 = Math_fround(HEAPF32[$547>>2]);
        $558 = $556 != $557;
        if ($558) {
         label = 141;
        } else {
         $transformChangedMask$1 = $transformChangedMask$0;
        }
       }
      } while(0);
      if ((label|0) == 141) {
       __ZN9Transform30SetPositionWithoutNotificationERK8Vector3f($11,$canvasPos);
       $559 = $transformChangedMask$0 | 1;
       $transformChangedMask$1 = $559;
      }
      __ZNK9Transform11GetRotationEv($8,$11);
      $560 = Math_fround(HEAPF32[$8>>2]);
      $561 = Math_fround(HEAPF32[$cameraRot>>2]);
      $562 = $560 != $561;
      do {
       if (!($562)) {
        $563 = (($8) + 4|0);
        $564 = Math_fround(HEAPF32[$563>>2]);
        $565 = Math_fround(HEAPF32[$494>>2]);
        $566 = $564 != $565;
        if ($566) {
         break;
        }
        $567 = (($8) + 8|0);
        $568 = Math_fround(HEAPF32[$567>>2]);
        $569 = Math_fround(HEAPF32[$497>>2]);
        $570 = $568 != $569;
        if ($570) {
         break;
        }
        $571 = (($8) + 12|0);
        $572 = Math_fround(HEAPF32[$571>>2]);
        $573 = Math_fround(HEAPF32[$506>>2]);
        $574 = $572 != $573;
        if (!($574)) {
         $transformChangedMask$2 = $transformChangedMask$1;
         label = 147;
         break L156;
        }
       }
      } while(0);
      __ZN9Transform30SetRotationWithoutNotificationERK11Quaternionf($11,$cameraRot);
      $575 = $transformChangedMask$1 | 2;
      $transformChangedMask$275 = $575;
     }
    } while(0);
    if ((label|0) == 147) {
     $576 = ($transformChangedMask$2|0)==(0);
     if ($576) {
      break;
     } else {
      $transformChangedMask$275 = $transformChangedMask$2;
     }
    }
    __ZN9Transform20SendTransformChangedEi($11,$transformChangedMask$275);
   } else {
    label = 149;
   }
  } else {
   label = 149;
  }
 } while(0);
 if ((label|0) == 149) {
  $577 = (__ZNK2UI13RectTransform17GetDrivenByObjectEv($11)|0);
  $578 = ($577|0)==($this|0);
  if ($578) {
  }
 }
 $579 = (($this) + 296|0);
 $580 = HEAP32[$579>>2]|0;
 $581 = (($this) + 300|0);
 $582 = HEAP32[$581>>2]|0;
 $583 = ($580|0)==($582|0);
 if ($583) {
  STACKTOP = sp;return;
 } else {
  $585 = $580;
 }
 while(1) {
  $584 = HEAP32[$585>>2]|0;
  __ZN2UI6Canvas25UpdateCanvasRectTransformEv($584);
  $586 = (($585) + 4|0);
  $587 = HEAP32[$581>>2]|0;
  $588 = ($586|0)==($587|0);
  if ($588) {
   break;
  } else {
   $585 = $586;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas12AddToManagerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $this$tr$i$i = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp;
 $1 = (__ZN2UI16GetCanvasManagerEv()|0);
 __ZN2UI13CanvasManager9AddCanvasEPNS_6CanvasE($1,$this);
 __ZN2UI6Canvas19SyncTransformParentEv($this);
 __ZN2UI6Canvas25UpdateCanvasRectTransformEv($this);
 $this$tr$i$i = $this;
 while(1) {
  $2 = (($this$tr$i$i) + 260|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   break;
  } else {
   $this$tr$i$i = $3;
  }
 }
 $5 = (($this) + 108|0);
 $6 = (($this$tr$i$i) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($7)|0);
 __ZNK9Transform21GetWorldToLocalMatrixEv($0,$8);
 dest=$5+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $9 = (($this) + 260|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  $12 = (($this) + 204|0);
  HEAP8[$12>>0] = 1;
  $13 = (($this) + 205|0);
  HEAP8[$13>>0] = 1;
  STACKTOP = sp;return;
 } else {
  $14 = (($10) + 204|0);
  HEAP8[$14>>0] = 1;
  $15 = (($this) + 204|0);
  HEAP8[$15>>0] = 1;
  $16 = (($this) + 205|0);
  HEAP8[$16>>0] = 1;
  $17 = (($10) + 205|0);
  HEAP8[$17>>0] = 1;
  $18 = (($10) + 204|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN2UI6Canvas17RemoveFromManagerEv($this) {
 $this = $this|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $scevgep$i$i$i$i = 0;
 var $scevgep4$i$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   label = 3;
  } else {
   $3 = (($this) + 290|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $7 = (($1) + 296|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($1) + 300|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    if (!($11)) {
     $15 = $8;
     while(1) {
      $14 = HEAP32[$15>>2]|0;
      $16 = ($14|0)==($this|0);
      $13 = (($15) + 4|0);
      if ($16) {
       break;
      }
      $12 = ($13|0)==($10|0);
      if ($12) {
       break L1;
      } else {
       $15 = $13;
      }
     }
     $17 = $15;
     $18 = $8;
     $19 = (($17) - ($18))|0;
     $20 = $19 >> 2;
     $21 = (($8) + ($20<<2)|0);
     $$sum$i$i = (($20) + 1)|0;
     $22 = (($8) + ($$sum$i$i<<2)|0);
     $23 = $10;
     $24 = $22;
     $25 = (($23) - ($24))|0;
     $26 = $25 >> 2;
     _memmove(($21|0),($22|0),($25|0))|0;
     $$sum1$i$i = (($26) + ($20))|0;
     $27 = (($8) + ($$sum1$i$i<<2)|0);
     $28 = HEAP32[$9>>2]|0;
     $29 = ($28|0)==($27|0);
     if (!($29)) {
      $__new_last2$i$i$i$i = $27;
      $scevgep$i$i$i$i = (($28) + -4|0);
      $30 = (0 - ($__new_last2$i$i$i$i))|0;
      $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($30)|0);
      $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
      $31 = $uglygep3$i$i$i$i >>> 2;
      $32 = $31 ^ -1;
      $scevgep4$i$i$i$i = (($28) + ($32<<2)|0);
      HEAP32[$9>>2] = $scevgep4$i$i$i$i;
     }
     $33 = (($1) + 205|0);
     HEAP8[$33>>0] = 1;
    }
   } else {
    label = 3;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $6 = (__ZN2UI16GetCanvasManagerEv()|0);
  __ZN2UI13CanvasManager12RemoveCanvasEPNS_6CanvasE($6,$this);
 }
 HEAP32[$0>>2] = 0;
 $34 = (($this) + 208|0);
 __ZN2UI18DestroyBatchOutputERNS_11BatchOutputE($34);
 $35 = (($this) + 108|0);
 __ZN2UI17DestroyCanvasDataERNS_10CanvasDataE($35);
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas19GetProjectionMatrixEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $this$tr$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp;
 $1 = (($this) + 40|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $$pre = (($this) + 44|0);
  $$pre$phiZ2D = $$pre;
  STACKTOP = sp;return ($$pre$phiZ2D|0);
 }
 $4 = (__Z16GetScreenManagerv()|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 80|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($4)|0);
 $9 = (Math_fround(($8|0)));
 $10 = (__Z16GetScreenManagerv()|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 84|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_ii[$13 & 4095]($10)|0);
 $15 = (Math_fround(($14|0)));
 $16 = (($this) + 44|0);
 (__ZN10Matrix4x4f8SetOrthoEffffff($16,Math_fround(0.0),$9,Math_fround(0.0),$15,Math_fround(-1000.0),Math_fround(1000.0))|0);
 $this$tr$i = $this;
 while(1) {
  $17 = (($this$tr$i) + 260|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   break;
  } else {
   $this$tr$i = $18;
  }
 }
 $20 = (($this$tr$i) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($21)|0);
 __ZNK9Transform21GetLocalToWorldMatrixEv($0,$22);
 (__ZN10Matrix4x4fmLERKS_($16,$0)|0);
 $$pre$phiZ2D = $16;
 STACKTOP = sp;return ($$pre$phiZ2D|0);
}
function __ZNK2UI6Canvas13GetRenderModeEv($this) {
 $this = $this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 260|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (__ZNK2UI6Canvas13GetRenderModeEv($2)|0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(1);
 if (!($7)) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($this) + 36|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$0>>2] = $9;
 $11 = HEAP32[560624>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  label = 13;
 } else {
  $13 = (($11) + 36|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($11) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14|0)==($16|0);
  do {
   if ($17) {
    $18 = (($11) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($11) + 32|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($19) + ($21<<3)|0);
    $38 = $22;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$11,$0);
    $23 = HEAP32[$pos$i$i$i>>2]|0;
    $24 = ($23|0)==(-1);
    $25 = (($11) + 28|0);
    $26 = HEAP32[$25>>2]|0;
    if ($24) {
     $27 = (($11) + 32|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = (($26) + ($28<<3)|0);
     $38 = $29;
     break;
    } else {
     $30 = (($26) + ($23<<3)|0);
     $38 = $30;
     break;
    }
   }
  } while(0);
  $31 = HEAP32[560624>>2]|0;
  $32 = (($31) + 28|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + 32|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($33) + ($35<<3)|0);
  $37 = ($38|0)==($36|0);
  if ($37) {
   label = 13;
  } else {
   $39 = (($38) + 4|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    label = 13;
   }
  }
 }
 if ((label|0) == 13) {
  $42 = HEAP32[$8>>2]|0;
  $43 = (__Z31ReadObjectFromPersistentManageri($42)|0);
  $44 = ($43|0)==(0|0);
  if ($44) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$pre = HEAP32[$5>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function __ZN2UI6Canvas11DrawRawMeshEi($this,$batchedDataIndex) {
 $this = $this|0;
 $batchedDataIndex = $batchedDataIndex|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $i$02 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = (__Z12GetGfxDevicev()|0);
 $2 = (($this) + 208|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($batchedDataIndex<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $5;
 $7 = HEAP32[560624>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  label = 11;
 } else {
  $9 = (($7) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($7) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10|0)==($12|0);
  do {
   if ($13) {
    $14 = (($7) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($7) + 32|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + ($17<<3)|0);
    $34 = $18;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$7,$0);
    $19 = HEAP32[$pos$i$i$i>>2]|0;
    $20 = ($19|0)==(-1);
    $21 = (($7) + 28|0);
    $22 = HEAP32[$21>>2]|0;
    if ($20) {
     $23 = (($7) + 32|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($22) + ($24<<3)|0);
     $34 = $25;
     break;
    } else {
     $26 = (($22) + ($19<<3)|0);
     $34 = $26;
     break;
    }
   }
  } while(0);
  $27 = HEAP32[560624>>2]|0;
  $28 = (($27) + 28|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 32|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + ($31<<3)|0);
  $33 = ($34|0)==($32|0);
  if ($33) {
   label = 11;
  } else {
   $35 = (($34) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    label = 11;
   } else {
    $$in = $36;
   }
  }
 }
 if ((label|0) == 11) {
  $38 = HEAP32[$4>>2]|0;
  $39 = (__Z31ReadObjectFromPersistentManageri($38)|0);
  $40 = ($39|0)==(0|0);
  if ($40) {
   STACKTOP = sp;return;
  } else {
   $$in = $39;
  }
 }
 $41 = (__ZN5Unity8Material9GetShaderEv($$in)|0);
 $42 = (($41) + 52|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 32|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$43>>2]|0;
 $47 = (($46) + ($45<<2)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (__ZN5Unity8Material12GetPassCountEv($$in)|0);
 $50 = ($49|0)>(0);
 if (!($50)) {
  STACKTOP = sp;return;
 }
 $51 = (($this) + 224|0);
 $52 = (($this) + 240|0);
 $i$02 = 0;
 while(1) {
  $53 = HEAP32[$48>>2]|0;
  $54 = (($53) + ($i$02<<2)|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = (($55) + 584|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0);
  if ($58) {
   $59 = HEAP32[652824>>2]|0;
   $60 = (__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib($$in,$i$02,$59,0,1)|0);
   $61 = ($60|0)==(0|0);
   if (!($61)) {
    $62 = HEAP32[$51>>2]|0;
    $63 = (($62) + ($batchedDataIndex<<2)|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = ($64|0)==(0|0);
    if (!($65)) {
     $66 = HEAP32[$1>>2]|0;
     $67 = (($66) + 216|0);
     $68 = HEAP32[$67>>2]|0;
     FUNCTION_TABLE_vii[$68 & 4095]($1,$64);
    }
    $69 = HEAP32[$52>>2]|0;
    __ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_($60,$69,$batchedDataIndex,0,0);
   }
  }
  $70 = (($i$02) + 1)|0;
  $71 = (__ZN5Unity8Material12GetPassCountEv($$in)|0);
  $72 = ($70|0)<($71|0);
  if ($72) {
   $i$02 = $70;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas14RenderOverlaysEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert10 = 0, $$phi$trans$insert8 = 0, $$pre = 0, $$pre11 = 0, $$pre9 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$04 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (Math_fround(__ZNK2UI6Canvas20CalculateCanvasAlphaEv($this)));
 $1 = $0 > Math_fround(0.0);
 if ($1) {
  __ZN2UI6Canvas16UpdateBatchOrderEv($this);
  $2 = (($this) + 204|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   $5 = (($this) + 188|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($this) + 196|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 208|0);
   __ZN2UI17CreateBatchOutputEPKNS_13UIInstructionEjfRNS_11BatchOutputE($6,$8,$0,$9);
   HEAP8[$2>>0] = 0;
  }
  $10 = (($this) + 216|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   label = 6;
  } else {
   $$phi$trans$insert = (($this) + 300|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $$phi$trans$insert8 = (($this) + 296|0);
   $$pre9 = HEAP32[$$phi$trans$insert8>>2]|0;
   $20 = $$pre;$21 = $$pre9;
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  $13 = (($this) + 300|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($this) + 296|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14|0)==($16|0);
  if ($17) {
   STACKTOP = sp;return;
  } else {
   $20 = $14;$21 = $16;
  }
 }
 $18 = (($this) + 300|0);
 $19 = ($20|0)!=($21|0);
 $$phi$trans$insert10 = (($this) + 216|0);
 $$pre11 = HEAP32[$$phi$trans$insert10>>2]|0;
 $22 = ($$pre11|0)==(0);
 $or$cond = $19 & $22;
 if ($or$cond) {
  $24 = $21;
  while(1) {
   $23 = HEAP32[$24>>2]|0;
   __ZN2UI6Canvas14RenderOverlaysEv($23);
   $25 = (($24) + 4|0);
   $26 = HEAP32[$18>>2]|0;
   $27 = ($25|0)==($26|0);
   if ($27) {
    break;
   } else {
    $24 = $25;
   }
  }
  STACKTOP = sp;return;
 }
 $28 = (($this) + 216|0);
 $29 = ($$pre11|0)>(0);
 if (!($29)) {
  STACKTOP = sp;return;
 }
 $30 = (($this) + 244|0);
 $37 = $21;$i$04 = 0;
 while(1) {
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + ($i$04)|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   label = 14;
  } else {
   $35 = HEAP32[$18>>2]|0;
   $36 = ($37|0)==($35|0);
   if ($36) {
    label = 14;
   } else {
    $38 = HEAP32[$37>>2]|0;
    __ZN2UI6Canvas14RenderOverlaysEv($38);
    $39 = (($37) + 4|0);
    $54 = $39;
   }
  }
  if ((label|0) == 14) {
   label = 0;
   $40 = (__Z12GetGfxDevicev()|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + 104|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (__ZN2UI6Canvas19GetProjectionMatrixEv($this)|0);
   FUNCTION_TABLE_vii[$43 & 4095]($40,$44);
   $45 = HEAP32[$40>>2]|0;
   $46 = (($45) + 96|0);
   $47 = HEAP32[$46>>2]|0;
   FUNCTION_TABLE_vii[$47 & 4095]($40,616552);
   $48 = HEAP32[$40>>2]|0;
   $49 = (($48) + 100|0);
   $50 = HEAP32[$49>>2]|0;
   FUNCTION_TABLE_vii[$50 & 4095]($40,616552);
   __ZN2UI6Canvas11DrawRawMeshEi($this,$i$04);
   $54 = $37;
  }
  $51 = (($i$04) + 1)|0;
  $52 = HEAP32[$28>>2]|0;
  $53 = ($51|0)<($52|0);
  if ($53) {
   $37 = $54;$i$04 = $51;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas24DrawIntermediateRendererE10Matrix4x4fiiP6Camerat($this,$matrix,$i,$layer,$camera,$orderOffset) {
 $this = $this|0;
 $matrix = $matrix|0;
 $i = $i|0;
 $layer = $layer|0;
 $camera = $camera|0;
 $orderOffset = $orderOffset|0;
 var $$byval_copy3 = 0, $$idx = 0, $$idx7 = 0, $$pre$i = 0, $$pre$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $this$tr$i = 0;
 var $this$tr$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy3 = sp + 36|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = sp + 32|0;
 $3 = (($this) + 240|0);
 $4 = HEAP32[$3>>2]|0;
 $this$tr$i = $this;
 while(1) {
  $5 = (($this$tr$i) + 260|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   break;
  } else {
   $this$tr$i = $6;
  }
 }
 $8 = (($this$tr$i) + 240|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if ($10) {
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 } else {
  $11 = (($9) + 168|0);
  ;HEAP32[$1+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$11+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$11+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$11+20>>2]|0;
 }
 $12 = (($this) + 208|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + ($i<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$2>>2] = $15;
 $16 = (__Z48AddMeshIntermediateRendererWithDistanceSortOrderRK10Matrix4x4fP4MeshtRK4AABB4PPtrIN5Unity8MaterialEEibbiP6Camera($matrix,$4,$orderOffset,$1,$2,$layer,0,0,$i,$camera)|0);
 $17 = (($this) + 224|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + ($i<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $this$tr$i2 = $this;
 } else {
  $22 = (($16) + 204|0);
  $23 = ($22|0)==($20|0);
  if (!($23)) {
   $24 = HEAP32[$20>>2]|0;
   $25 = (($20) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $$idx = $26 << 4;
   $27 = $$idx >> 4;
   $28 = (($16) + 212|0);
   HEAP32[$28>>2] = $27;
   $29 = (($16) + 216|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $30 & 2147483647;
   $32 = ($31>>>0)<($27>>>0);
   do {
    if ($32) {
     $33 = ($30|0)>(-1);
     if ($33) {
      HEAP32[$29>>2] = $27;
      $34 = HEAP32[$22>>2]|0;
      $35 = (($16) + 208|0);
      $36 = HEAP32[$35>>2]|0;
      HEAP32[$0>>2] = $36;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $37 = (__Z16realloc_internalPvji10MemLabelIdiPKci($34,$$idx,4,$$byval_copy3,0,874960,370)|0);
      HEAP32[$22>>2] = $37;
      $46 = $37;
      break;
     } else {
      $38 = (($16) + 208|0);
      $39 = HEAP32[$38>>2]|0;
      HEAP32[$0>>2] = $39;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $40 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx,4,$$byval_copy3,0,874960,352)|0);
      $41 = HEAP32[$22>>2]|0;
      $42 = HEAP32[$28>>2]|0;
      $43 = $42 << 4;
      _memcpy(($40|0),($41|0),($43|0))|0;
      HEAP32[$29>>2] = $27;
      HEAP32[$22>>2] = $40;
      $46 = $40;
      break;
     }
    } else {
     $$pre$i = HEAP32[$22>>2]|0;
     $46 = $$pre$i;
    }
   } while(0);
   $44 = HEAP32[$28>>2]|0;
   $45 = $44 << 4;
   _memcpy(($46|0),($24|0),($45|0))|0;
   $47 = (($16) + 220|0);
   $48 = (($20) + 16|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = (($20) + 24|0);
   $51 = HEAP32[$50>>2]|0;
   $$idx7 = $51 << 2;
   $52 = $$idx7 >> 2;
   $53 = (($16) + 228|0);
   HEAP32[$53>>2] = $52;
   $54 = (($16) + 232|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = $55 & 2147483647;
   $57 = ($56>>>0)<($52>>>0);
   do {
    if ($57) {
     $58 = ($55|0)>(-1);
     if ($58) {
      HEAP32[$54>>2] = $52;
      $59 = HEAP32[$47>>2]|0;
      $60 = (($16) + 224|0);
      $61 = HEAP32[$60>>2]|0;
      HEAP32[$0>>2] = $61;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $62 = (__Z16realloc_internalPvji10MemLabelIdiPKci($59,$$idx7,4,$$byval_copy3,0,874960,370)|0);
      HEAP32[$47>>2] = $62;
      $71 = $62;
      break;
     } else {
      $63 = (($16) + 224|0);
      $64 = HEAP32[$63>>2]|0;
      HEAP32[$0>>2] = $64;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
      $65 = (__Z15malloc_internaljj10MemLabelIdiPKci($$idx7,4,$$byval_copy3,0,874960,352)|0);
      $66 = HEAP32[$47>>2]|0;
      $67 = HEAP32[$53>>2]|0;
      $68 = $67 << 2;
      _memcpy(($65|0),($66|0),($68|0))|0;
      HEAP32[$54>>2] = $52;
      HEAP32[$47>>2] = $65;
      $71 = $65;
      break;
     }
    } else {
     $$pre$i5 = HEAP32[$47>>2]|0;
     $71 = $$pre$i5;
    }
   } while(0);
   $69 = HEAP32[$53>>2]|0;
   $70 = $69 << 2;
   _memcpy(($71|0),($49|0),($70|0))|0;
  }
  $72 = (($20) + 32|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($16) + 236|0);
  HEAP32[$74>>2] = $73;
  __ZN21MaterialPropertyBlock11ComputeHashEv($22);
  $75 = (($16) + 168|0);
  HEAP32[$75>>2] = $22;
  $this$tr$i2 = $this;
 }
 while(1) {
  $76 = (($this$tr$i2) + 290|0);
  $77 = HEAP8[$76>>0]|0;
  $78 = ($77<<24>>24)==(0);
  if (!($78)) {
   label = 22;
   break;
  }
  $79 = (($this$tr$i2) + 260|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = ($80|0)==(0|0);
  if ($81) {
   label = 22;
   break;
  } else {
   $this$tr$i2 = $80;
  }
 }
 if ((label|0) == 22) {
  $82 = (__Z13GetTagManagerv()|0);
  $83 = (($this$tr$i2) + 284|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (__ZN10TagManager32GetSortingLayerValueFromUniqueIDEi($82,$84)|0);
  $86 = (($this$tr$i2) + 288|0);
  $87 = HEAP16[$86>>1]|0;
  $88 = $85 << 16;
  $89 = $88 ^ -2147483648;
  $90 = $87 << 16 >> 16;
  $91 = (($90) + 32768)|0;
  $92 = $91 | $89;
  $93 = (($16) + 172|0);
  HEAP32[$93>>2] = $92;
  STACKTOP = sp;return;
 }
}
function __ZN2UI6Canvas17EmitWorldGeometryEP6CameraRtb($this,$camera,$orderOffset,$updateRectTransform) {
 $this = $this|0;
 $camera = $camera|0;
 $orderOffset = $orderOffset|0;
 $updateRectTransform = $updateRectTransform|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert8 = 0, $$pre = 0, $$pre9 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $matrix = 0, $matrix$byval_copy = 0, $this$tr$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $matrix$byval_copy = sp + 64|0;
 $matrix = sp;
 if ($updateRectTransform) {
  __ZN2UI6Canvas25UpdateCanvasRectTransformEv($this);
 }
 $0 = (Math_fround(__ZNK2UI6Canvas20CalculateCanvasAlphaEv($this)));
 $1 = $0 > Math_fround(0.0);
 if ($1) {
  __ZN2UI6Canvas16UpdateBatchOrderEv($this);
  $2 = (($this) + 204|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   $5 = (($this) + 188|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($this) + 196|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 208|0);
   __ZN2UI17CreateBatchOutputEPKNS_13UIInstructionEjfRNS_11BatchOutputE($6,$8,$0,$9);
   HEAP8[$2>>0] = 0;
  }
  $10 = (($this) + 216|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0);
  if ($12) {
   label = 8;
  } else {
   $$phi$trans$insert = (($this) + 300|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $$phi$trans$insert8 = (($this) + 296|0);
   $$pre9 = HEAP32[$$phi$trans$insert8>>2]|0;
   $21 = $$pre;$22 = $$pre9;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  $13 = (($this) + 300|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($this) + 296|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($14|0)==($16|0);
  if ($17) {
   STACKTOP = sp;return;
  } else {
   $21 = $14;$22 = $16;
  }
 }
 $18 = (($this) + 300|0);
 $19 = (($this) + 296|0);
 $20 = ($21|0)==($22|0);
 if (!($20)) {
  $23 = (($this) + 216|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0);
  if ($25) {
   $27 = $22;
   while(1) {
    $26 = HEAP32[$27>>2]|0;
    __ZN2UI6Canvas17EmitWorldGeometryEP6CameraRtb($26,$camera,$orderOffset,$updateRectTransform);
    $28 = (($27) + 4|0);
    $29 = HEAP32[$18>>2]|0;
    $30 = ($28|0)==($29|0);
    if ($30) {
     break;
    } else {
     $27 = $28;
    }
   }
   STACKTOP = sp;return;
  }
 }
 $31 = (($this) + 24|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 40|0);
 $34 = HEAP32[$33>>2]|0;
 $this$tr$i = $this;
 while(1) {
  $35 = (($this$tr$i) + 260|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)==(0|0);
  if ($37) {
   break;
  } else {
   $this$tr$i = $36;
  }
 }
 $38 = (($this$tr$i) + 24|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($39)|0);
 __ZNK9Transform21GetLocalToWorldMatrixEv($matrix,$40);
 $41 = (($this) + 216|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)>(0);
 if (!($43)) {
  STACKTOP = sp;return;
 }
 $44 = HEAP32[$19>>2]|0;
 $45 = (($this) + 244|0);
 $52 = $44;$i$04 = 0;
 while(1) {
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + ($i$04)|0);
  $48 = HEAP8[$47>>0]|0;
  $49 = ($48<<24>>24)==(0);
  if ($49) {
   label = 19;
  } else {
   $50 = HEAP32[$18>>2]|0;
   $51 = ($52|0)==($50|0);
   if ($51) {
    label = 19;
   } else {
    $53 = HEAP32[$52>>2]|0;
    __ZN2UI6Canvas17EmitWorldGeometryEP6CameraRtb($53,$camera,$orderOffset,$updateRectTransform);
    $54 = (($52) + 4|0);
    $60 = $54;
   }
  }
  if ((label|0) == 19) {
   label = 0;
   $55 = HEAP16[$orderOffset>>1]|0;
   $56 = (($55) + 1)<<16>>16;
   HEAP16[$orderOffset>>1] = $56;
   dest=$matrix$byval_copy+0|0; src=$matrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   __ZN2UI6Canvas24DrawIntermediateRendererE10Matrix4x4fiiP6Camerat($this,$matrix$byval_copy,$i$04,$34,$camera,$56);
   $60 = $52;
  }
  $57 = (($i$04) + 1)|0;
  $58 = HEAP32[$41>>2]|0;
  $59 = ($57|0)<($58|0);
  if ($59) {
   $52 = $60;$i$04 = $57;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI20CalculateNestedAlphaEP9TransformPKS0_f($startPosition,$endPosition,$inheritedAlpha) {
 $startPosition = $startPosition|0;
 $endPosition = $endPosition|0;
 $inheritedAlpha = Math_fround($inheritedAlpha);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $alpha$0$lcssa = Math_fround(0), $alpha$02 = Math_fround(0), $alpha$1 = Math_fround(0), $currentPosition$03 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($startPosition|0)==($endPosition|0);
 L1: do {
  if ($0) {
   $alpha$0$lcssa = Math_fround(1.0);
  } else {
   $alpha$02 = Math_fround(1.0);$currentPosition$03 = $startPosition;
   while(1) {
    $1 = (($currentPosition$03) + 24|0);
    $2 = HEAP32[$1>>2]|0;
    $3 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($2,225)|0);
    $4 = ($3|0)==(0|0);
    if ($4) {
     $alpha$1 = $alpha$02;
    } else {
     $5 = (($3) + 28|0);
     $6 = Math_fround(HEAPF32[$5>>2]);
     $7 = Math_fround($alpha$02 * $6);
     $8 = (($3) + 34|0);
     $9 = HEAP8[$8>>0]|0;
     $10 = ($9<<24>>24)==(0);
     if ($10) {
      $alpha$1 = $7;
     } else {
      $$0 = $7;
      break;
     }
    }
    $11 = (($currentPosition$03) + 156|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($endPosition|0);
    if ($13) {
     $alpha$0$lcssa = $alpha$1;
     break L1;
    } else {
     $alpha$02 = $alpha$1;$currentPosition$03 = $12;
    }
   }
   STACKTOP = sp;return (Math_fround($$0));
  }
 } while(0);
 $14 = Math_fround($alpha$0$lcssa * $inheritedAlpha);
 $$0 = $14;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZNK2UI6Canvas20CalculateCanvasAlphaEv($this) {
 $this = $this|0;
 var $$0$i = Math_fround(0), $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = Math_fround(0), $27 = Math_fround(0), $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $alpha$0$lcssa$i = Math_fround(0), $alpha$02$i = Math_fround(0), $alpha$1$i = Math_fround(0), $currentPosition$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $12 = 0;$27 = Math_fround(1.0);
 } else {
  $3 = (Math_fround(__ZNK2UI6Canvas20CalculateCanvasAlphaEv($1)));
  $$pr = HEAP32[$0>>2]|0;
  $4 = ($$pr|0)==(0|0);
  if ($4) {
   $12 = 0;$27 = $3;
  } else {
   $5 = (($$pr) + 24|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($6)|0);
   $12 = $7;$27 = $3;
  }
 }
 $8 = (($this) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($9)|0);
 $11 = ($10|0)==($12|0);
 L5: do {
  if ($11) {
   $alpha$0$lcssa$i = Math_fround(1.0);
  } else {
   $alpha$02$i = Math_fround(1.0);$currentPosition$03$i = $10;
   while(1) {
    $13 = (($currentPosition$03$i) + 24|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($14,225)|0);
    $16 = ($15|0)==(0|0);
    if ($16) {
     $alpha$1$i = $alpha$02$i;
    } else {
     $17 = (($15) + 28|0);
     $18 = Math_fround(HEAPF32[$17>>2]);
     $19 = Math_fround($alpha$02$i * $18);
     $20 = (($15) + 34|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)==(0);
     if ($22) {
      $alpha$1$i = $19;
     } else {
      $$0$i = $19;
      break;
     }
    }
    $23 = (($currentPosition$03$i) + 156|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==($12|0);
    if ($25) {
     $alpha$0$lcssa$i = $alpha$1$i;
     break L5;
    } else {
     $alpha$02$i = $alpha$1$i;$currentPosition$03$i = $24;
    }
   }
   STACKTOP = sp;return (Math_fround($$0$i));
  }
 } while(0);
 $26 = Math_fround($27 * $alpha$0$lcssa$i);
 $$0$i = $26;
 STACKTOP = sp;return (Math_fround($$0$i));
}
function __ZN2UI18CompareCanvasDepthERK8ListNodeINS_6CanvasEES4_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK2UI6Canvas13GetRenderModeEv($1)|0);
 $3 = ($2|0)==(0);
 $4 = HEAP32[$0>>2]|0;
 if ($3) {
  $5 = (($4) + 288|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = (($b) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) + 288|0);
  $10 = HEAP16[$9>>1]|0;
  $11 = ($6<<16>>16)==($10<<16>>16);
  if ($11) {
   $31 = $8;
  } else {
   $12 = ($6<<16>>16)<($10<<16>>16);
   $$0 = $12;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $13 = (($4) + 292|0);
  $14 = HEAP16[$13>>1]|0;
  $15 = (($b) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 292|0);
  $18 = HEAP16[$17>>1]|0;
  $19 = ($14<<16>>16)==($18<<16>>16);
  if (!($19)) {
   $20 = ($14<<16>>16)<($18<<16>>16);
   $$0 = $20;
   STACKTOP = sp;return ($$0|0);
  }
  $21 = (($4) + 288|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = (($16) + 288|0);
  $24 = HEAP16[$23>>1]|0;
  $25 = ($22<<16>>16)==($24<<16>>16);
  if ($25) {
   $31 = $16;
  } else {
   $26 = ($22<<16>>16)<($24<<16>>16);
   $$0 = $26;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $27 = (($4) + 264|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = $28 == Math_fround(-1.0);
 if ($29) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (($31) + 264|0);
 $32 = Math_fround(HEAPF32[$30>>2]);
 $33 = $32 == Math_fround(-1.0);
 if ($33) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = $28 < $32;
 $$0 = $34;
 STACKTOP = sp;return ($$0|0);
}
function __ZN2UI14SyncInstuctionEPNS_6CanvasERNS_13UIInstructionE($canvas,$instruction) {
 $canvas = $canvas|0;
 $instruction = $instruction|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = Math_fround(0), $69 = Math_fround(0), $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = Math_fround(0), $74 = 0, $75 = Math_fround(0), $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = Math_fround(0);
 var $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $transformMatrix = 0, $worldBounds = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $transformMatrix = sp + 48|0;
 $worldBounds = sp;
 $0 = sp + 24|0;
 $1 = (($canvas) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi($2,224)|0);
 (__ZNK9Transform24CalculateTransformMatrixER10Matrix4x4f($3,$transformMatrix)|0);
 $4 = (($canvas) + 108|0);
 $5 = (($instruction) + 12|0);
 __Z19MultiplyMatrices3x4RK10Matrix4x4fS1_RS_($4,$transformMatrix,$5);
 $6 = (__ZN2UI13RectTransform7GetRectEv($3)|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($6) + 4|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($6) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($6) + 12|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = Math_fround(HEAPF32[616664>>2]);
 $15 = Math_fround(HEAPF32[((616664 + 4|0))>>2]);
 $16 = Math_fround(HEAPF32[((616664 + 8|0))>>2]);
 $17 = Math_fround(-$14);
 $18 = Math_fround(-$15);
 $19 = Math_fround(-$16);
 $20 = $7 < $14;
 $21 = $20 ? $7 : $14;
 $22 = $9 < $15;
 $23 = $22 ? $9 : $15;
 $24 = $16 > Math_fround(0.0);
 $25 = $24 ? Math_fround(0.0) : $16;
 $26 = $7 > $17;
 $27 = $26 ? $7 : $17;
 $28 = $9 > $18;
 $29 = $28 ? $9 : $18;
 $30 = $16 > Math_fround(-0.0);
 $31 = $30 ? Math_fround(0.0) : $19;
 $32 = Math_fround($7 + $11);
 $33 = $32 < $21;
 $34 = $33 ? $32 : $21;
 $35 = $27 < $32;
 $36 = $35 ? $32 : $27;
 $37 = Math_fround($9 + $13);
 $38 = $7 < $34;
 $39 = $38 ? $7 : $34;
 $40 = $37 < $23;
 $41 = $40 ? $37 : $23;
 $42 = $36 < $7;
 $43 = $42 ? $7 : $36;
 $44 = $29 < $37;
 $45 = $44 ? $37 : $29;
 $46 = $32 < $39;
 $47 = $46 ? $32 : $39;
 $48 = $43 < $32;
 $49 = $48 ? $32 : $43;
 $50 = (($instruction) + 76|0);
 HEAPF32[$50>>2] = $47;
 $51 = (($instruction) + 80|0);
 HEAPF32[$51>>2] = $41;
 $52 = (($instruction) + 84|0);
 HEAPF32[$52>>2] = $25;
 $53 = (($instruction) + 88|0);
 HEAPF32[$53>>2] = $49;
 $54 = (($instruction) + 92|0);
 HEAPF32[$54>>2] = $45;
 $55 = (($instruction) + 96|0);
 HEAPF32[$55>>2] = $31;
 ;HEAP32[$worldBounds+0>>2]=0|0;HEAP32[$worldBounds+4>>2]=0|0;HEAP32[$worldBounds+8>>2]=0|0;HEAP32[$worldBounds+12>>2]=0|0;HEAP32[$worldBounds+16>>2]=0|0;HEAP32[$worldBounds+20>>2]=0|0;
 $56 = (($0) + 4|0);
 $57 = (($0) + 8|0);
 $58 = (($0) + 12|0);
 $59 = (($0) + 16|0);
 $60 = (($0) + 20|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;
 $61 = Math_fround($49 + $47);
 $62 = Math_fround($45 + $41);
 $63 = Math_fround($31 + $25);
 $64 = Math_fround($61 * Math_fround(0.5));
 $65 = Math_fround($62 * Math_fround(0.5));
 $66 = Math_fround($63 * Math_fround(0.5));
 HEAPF32[$0>>2] = $64;
 HEAPF32[$56>>2] = $65;
 HEAPF32[$57>>2] = $66;
 $67 = Math_fround($49 - $47);
 $68 = Math_fround($45 - $41);
 $69 = Math_fround($31 - $25);
 $70 = Math_fround($67 * Math_fround(0.5));
 $71 = Math_fround($68 * Math_fround(0.5));
 $72 = Math_fround($69 * Math_fround(0.5));
 HEAPF32[$58>>2] = $70;
 HEAPF32[$59>>2] = $71;
 HEAPF32[$60>>2] = $72;
 __Z17TransformAABBSlowRK4AABBRK10Matrix4x4fRS_($0,$5,$worldBounds);
 $73 = Math_fround(HEAPF32[$worldBounds>>2]);
 $74 = (($worldBounds) + 12|0);
 $75 = Math_fround(HEAPF32[$74>>2]);
 $76 = Math_fround($73 - $75);
 $77 = (($worldBounds) + 4|0);
 $78 = Math_fround(HEAPF32[$77>>2]);
 $79 = (($worldBounds) + 16|0);
 $80 = Math_fround(HEAPF32[$79>>2]);
 $81 = Math_fround($78 - $80);
 $82 = Math_fround($73 + $75);
 $83 = Math_fround($78 + $80);
 $84 = Math_fround($82 - $76);
 $85 = Math_fround($83 - $81);
 $86 = (($instruction) + 100|0);
 HEAPF32[$86>>2] = $76;
 $87 = (($instruction) + 108|0);
 HEAPF32[$87>>2] = $84;
 $88 = (($instruction) + 104|0);
 HEAPF32[$88>>2] = $81;
 $89 = (($instruction) + 112|0);
 HEAPF32[$89>>2] = $85;
 $90 = (($instruction) + 148|0);
 HEAP8[$90>>0] = 1;
 $91 = (($instruction) + 140|0);
 HEAP32[$91>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas16UpdateBatchOrderEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy16 = 0, $$lcssa = 0, $$lcssa47 = 0, $$lcssa50 = 0, $$ph$ph$ph = 0, $$ph33$ph$ph = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre68 = 0, $$sink = 0, $$sink$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$053 = 0, $lastMask$0 = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, $nestedDepth$054 = 0, $nestedDepth$1 = 0, $or$cond = 0, $parent$01$i = 0, $parentCanvas$0 = 0, $renderers = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy16 = sp + 52|0;
 $0 = sp + 48|0;
 $1 = sp + 44|0;
 $2 = sp + 40|0;
 $3 = sp + 36|0;
 $4 = sp + 32|0;
 $5 = sp + 8|0;
 $6 = sp + 4|0;
 $7 = sp;
 $renderers = sp + 16|0;
 $8 = (($this) + 108|0);
 $9 = (($this) + 205|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = HEAP32[628512>>2]|0;
 HEAP32[$renderers>>2] = 0;
 $13 = (($renderers) + 4|0);
 HEAP32[$13>>2] = $12;
 $14 = (($renderers) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = (($renderers) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 __THREW__ = 0;
 invoke_viii(2078,($17|0),222,($renderers|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L4: do {
  if ($19) {
   label = 19;
  } else {
   __THREW__ = 0;
   invoke_vi(3762,($8|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    label = 19;
   } else {
    $22 = (($this) + 296|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($this) + 300|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($23|0)==($25|0);
    if (!($26)) {
     $28 = $23;
     while(1) {
      $27 = HEAP32[$28>>2]|0;
      $29 = (($27) + 264|0);
      HEAPF32[$29>>2] = Math_fround(-1.0);
      $30 = (($28) + 4|0);
      $31 = ($30|0)==($25|0);
      if ($31) {
       break;
      } else {
       $28 = $30;
      }
     }
    }
    $32 = HEAP32[628512>>2]|0;
    $33 = HEAP32[$14>>2]|0;
    $34 = ($33|0)>(0);
    L11: do {
     if ($34) {
      $35 = (($this) + 196|0);
      $36 = (($this) + 200|0);
      $37 = (($this) + 188|0);
      $38 = (($this) + 192|0);
      $40 = 0;$42 = 0;$92 = 0;$i$053 = 0;$nestedDepth$054 = 0;
      L13: while(1) {
       $39 = ($40|0)==(0);
       L15: do {
        if ($39) {
         $90 = 0;
        } else {
         $$sink$in = $40;
         while(1) {
          $$sink = (($$sink$in) + -1)|0;
          $41 = (($42) + ($$sink<<2)|0);
          $lastMask$0 = HEAP32[$41>>2]|0;
          $43 = HEAP32[$renderers>>2]|0;
          $44 = (($43) + ($i$053<<2)|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = ($lastMask$0|0)==($45|0);
          if ($46) {
           $90 = $$sink$in;
           break L15;
          }
          $47 = (($lastMask$0) + 24|0);
          $48 = HEAP32[$47>>2]|0;
          __THREW__ = 0;
          $49 = (invoke_ii(3220,($48|0))|0);
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           label = 21;
           break L13;
          }
          $52 = ($45|0)==(0|0);
          if (!($52)) {
           $53 = (($45) + 24|0);
           $54 = HEAP32[$53>>2]|0;
           __THREW__ = 0;
           $55 = (invoke_ii(3220,($54|0))|0);
           $56 = __THREW__; __THREW__ = 0;
           $57 = $56&1;
           if ($57) {
            label = 21;
            break L13;
           }
           $58 = (($55) + 156|0);
           $59 = HEAP32[$58>>2]|0;
           $60 = ($59|0)==(0|0);
           if (!($60)) {
            $parent$01$i = $59;
            while(1) {
             $61 = ($49|0)==($parent$01$i|0);
             if ($61) {
              $90 = $$sink$in;
              break L15;
             }
             $62 = (($parent$01$i) + 156|0);
             $63 = HEAP32[$62>>2]|0;
             $64 = ($63|0)==(0|0);
             if ($64) {
              break;
             } else {
              $parent$01$i = $63;
             }
            }
           }
          }
          __THREW__ = 0;
          (invoke_iiii(1631,($lastMask$0|0),($this|0),2)|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           label = 21;
           break L13;
          }
          $67 = ($$sink|0)==(0);
          if ($67) {
           $90 = 0;
           break;
          } else {
           $$sink$in = $$sink;
          }
         }
        }
       } while(0);
       $83 = HEAP32[$renderers>>2]|0;
       $84 = (($83) + ($i$053<<2)|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = (($85) + 68|0);
       $87 = HEAP8[$86>>0]|0;
       $88 = ($87<<24>>24)==(0);
       if ($88) {
        $111 = $85;$191 = $92;$192 = $90;$193 = $42;
       } else {
        $89 = (($90) + 1)|0;
        $91 = $92 & 2147483647;
        $93 = ($89>>>0)>($91>>>0);
        do {
         if ($93) {
          $94 = $92 << 1;
          $95 = ($94|0)==(0);
          $96 = $95 ? 1 : $94;
          $97 = ($91>>>0)<($96>>>0);
          if ($97) {
           $98 = ($92|0)>(-1);
           if ($98) {
            $99 = $96 << 2;
            HEAP32[$0>>2] = $32;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
            $100 = (invoke_iiiiiiii(108,($42|0),($99|0),4,($$byval_copy16|0),0,(874960|0),370)|0);
            $101 = __THREW__; __THREW__ = 0;
            $102 = $101&1;
            if ($102) {
             $$ph$ph$ph = $96;$$ph33$ph$ph = $42;
             label = 22;
             break L13;
            }
            $109 = $100;$194 = $96;
            break;
           } else {
            $103 = $96 << 2;
            HEAP32[$1>>2] = $32;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
            $104 = (invoke_iiiiiii(102,($103|0),4,($$byval_copy16|0),0,(874960|0),352)|0);
            $105 = __THREW__; __THREW__ = 0;
            $106 = $105&1;
            if ($106) {
             $$ph$ph$ph = $92;$$ph33$ph$ph = $42;
             label = 22;
             break L13;
            }
            $107 = $89 << 2;
            _memcpy(($104|0),($42|0),($107|0))|0;
            $109 = $104;$194 = $96;
            break;
           }
          } else {
           $109 = $42;$194 = $92;
          }
         } else {
          $109 = $42;$194 = $92;
         }
        } while(0);
        $108 = (($109) + ($90<<2)|0);
        HEAP32[$108>>2] = $85;
        $$pre = HEAP32[$renderers>>2]|0;
        $$phi$trans$insert = (($$pre) + ($i$053<<2)|0);
        $$pre68 = HEAP32[$$phi$trans$insert>>2]|0;
        $111 = $$pre68;$191 = $194;$192 = $89;$193 = $109;
       }
       $110 = (($111) + 70|0);
       $112 = HEAP8[$110>>0]|0;
       $113 = ($112<<24>>24)==(0);
       if ($113) {
        $114 = (($111) + 68|0);
        $115 = HEAP8[$114>>0]|0;
        $116 = $115&255;
        __THREW__ = 0;
        $117 = (invoke_iiii(1631,($111|0),($this|0),($116|0))|0);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         $$ph$ph$ph = $191;$$ph33$ph$ph = $193;
         label = 22;
         break;
        }
        $120 = ($117|0)==($this|0);
        if ($120) {
         $nestedDepth$1 = $nestedDepth$054;
        } else {
         $parentCanvas$0 = $117;
         while(1) {
          $121 = (($parentCanvas$0) + 260|0);
          $122 = HEAP32[$121>>2]|0;
          $123 = ($122|0)==(0|0);
          $124 = ($122|0)==($this|0);
          $or$cond = $123 | $124;
          if ($or$cond) {
           break;
          } else {
           $parentCanvas$0 = $122;
          }
         }
         $125 = (($parentCanvas$0) + 264|0);
         $126 = Math_fround(HEAPF32[$125>>2]);
         $127 = $126 == Math_fround(-1.0);
         if ($127) {
          $128 = HEAP32[$35>>2]|0;
          $129 = (($128) + 1)|0;
          HEAP32[$35>>2] = $129;
          $130 = HEAP32[$36>>2]|0;
          $131 = $130 & 2147483647;
          $132 = ($129>>>0)>($131>>>0);
          if ($132) {
           $133 = $130 << 1;
           $134 = ($133|0)==(0);
           $135 = $134 ? 1 : $133;
           $136 = ($131>>>0)<($135>>>0);
           do {
            if ($136) {
             $137 = ($130|0)>(-1);
             if ($137) {
              HEAP32[$36>>2] = $135;
              $138 = HEAP32[$37>>2]|0;
              $139 = ($135*152)|0;
              $140 = HEAP32[$38>>2]|0;
              HEAP32[$3>>2] = $140;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$3+0>>2]|0;
              $141 = (invoke_iiiiiiii(108,($138|0),($139|0),4,($$byval_copy16|0),0,(874960|0),370)|0);
              $142 = __THREW__; __THREW__ = 0;
              $143 = $142&1;
              if ($143) {
               $$ph$ph$ph = $191;$$ph33$ph$ph = $193;
               label = 22;
               break L13;
              }
              HEAP32[$37>>2] = $141;
              break;
             } else {
              $144 = ($135*152)|0;
              $145 = HEAP32[$38>>2]|0;
              HEAP32[$4>>2] = $145;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$4+0>>2]|0;
              $146 = (invoke_iiiiiii(102,($144|0),4,($$byval_copy16|0),0,(874960|0),352)|0);
              $147 = __THREW__; __THREW__ = 0;
              $148 = $147&1;
              if ($148) {
               $$ph$ph$ph = $191;$$ph33$ph$ph = $193;
               label = 22;
               break L13;
              }
              $149 = HEAP32[$37>>2]|0;
              $150 = HEAP32[$35>>2]|0;
              $151 = ($150*152)|0;
              _memcpy(($146|0),($149|0),($151|0))|0;
              HEAP32[$36>>2] = $135;
              HEAP32[$37>>2] = $146;
              break;
             }
            }
           } while(0);
           $$pre$i = HEAP32[$35>>2]|0;
           $153 = $$pre$i;
          } else {
           $153 = $129;
          }
          $152 = (($153) + -1)|0;
          $154 = HEAP32[$37>>2]|0;
          $155 = (($154) + (($152*152)|0)|0);
          __THREW__ = 0;
          invoke_vii(3459,($parentCanvas$0|0),($155|0));
          $156 = __THREW__; __THREW__ = 0;
          $157 = $156&1;
          if ($157) {
           $$ph$ph$ph = $191;$$ph33$ph$ph = $193;
           label = 22;
           break;
          }
          $158 = (($nestedDepth$054) + 1)|0;
          $159 = (Math_fround(($nestedDepth$054|0)));
          HEAPF32[$125>>2] = $159;
          $nestedDepth$1 = $158;
         } else {
          $nestedDepth$1 = $nestedDepth$054;
         }
        }
       } else {
        $nestedDepth$1 = $nestedDepth$054;
       }
       $160 = (($i$053) + 1)|0;
       $161 = HEAP32[$14>>2]|0;
       $162 = ($160|0)<($161|0);
       if ($162) {
        $40 = $192;$42 = $193;$92 = $191;$i$053 = $160;$nestedDepth$054 = $nestedDepth$1;
       } else {
        $$lcssa = $191;$$lcssa47 = $192;$$lcssa50 = $193;
        label = 8;
        break L11;
       }
      }
      if ((label|0) == 21) {
       $72 = ___cxa_find_matching_catch()|0;
       $73 = tempRet0;
       $79 = $92;$80 = $42;$lpad$phi$index = $72;$lpad$phi$index4 = $73;
       break;
      }
      else if ((label|0) == 22) {
       $74 = ___cxa_find_matching_catch()|0;
       $75 = tempRet0;
       $79 = $$ph$ph$ph;$80 = $$ph33$ph$ph;$lpad$phi$index = $74;$lpad$phi$index4 = $75;
       break;
      }
     } else {
      $$lcssa = 0;$$lcssa47 = 0;$$lcssa50 = 0;
      label = 8;
     }
    } while(0);
    do {
     if ((label|0) == 8) {
      $164 = $$lcssa47;
      while(1) {
       $163 = ($164|0)==(0);
       if ($163) {
        break;
       }
       $165 = (($164) + -1)|0;
       $166 = (($$lcssa50) + ($165<<2)|0);
       $167 = HEAP32[$166>>2]|0;
       __THREW__ = 0;
       (invoke_iiii(1631,($167|0),($this|0),2)|0);
       $168 = __THREW__; __THREW__ = 0;
       $169 = $168&1;
       if ($169) {
        label = 20;
        break;
       } else {
        $164 = $165;
       }
      }
      if ((label|0) == 20) {
       $70 = ___cxa_find_matching_catch()|0;
       $71 = tempRet0;
       $79 = $$lcssa;$80 = $$lcssa50;$lpad$phi$index = $70;$lpad$phi$index4 = $71;
       break;
      }
      $170 = HEAP32[$22>>2]|0;
      $171 = HEAP32[$24>>2]|0;
      $172 = ($170|0)==($171|0);
      if (!($172)) {
       HEAP32[$5>>2] = 2711;
       __THREW__ = 0;
       invoke_viii(2079,($170|0),($171|0),($5|0));
       $173 = __THREW__; __THREW__ = 0;
       $174 = $173&1;
       if ($174) {
        $76 = ___cxa_find_matching_catch()|0;
        $77 = tempRet0;
        $79 = $$lcssa;$80 = $$lcssa50;$lpad$phi$index = $76;$lpad$phi$index4 = $77;
        break;
       }
      }
      __ZN2UI6Canvas18UpdateEventIndexesEv($this);
      HEAP8[$9>>0] = 0;
      $175 = (($this) + 204|0);
      HEAP8[$175>>0] = 1;
      $176 = ($$lcssa|0)>(-1);
      if ($176) {
       HEAP32[$6>>2] = $32;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$6+0>>2]|0;
       invoke_vii(2591,($$lcssa50|0),($$byval_copy16|0));
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        label = 19;
        break L4;
       }
      }
      $179 = HEAP32[$15>>2]|0;
      $180 = ($179|0)>(-1);
      if (!($180)) {
       STACKTOP = sp;return;
      }
      $181 = HEAP32[$renderers>>2]|0;
      $182 = HEAP32[$13>>2]|0;
      HEAP32[$0>>2] = $182;
      ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($181,$$byval_copy16);
      HEAP32[$renderers>>2] = 0;
      STACKTOP = sp;return;
     }
    } while(0);
    $78 = ($79|0)>(-1);
    if ($78) {
     HEAP32[$2>>2] = $32;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($80|0),($$byval_copy16|0));
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if ($82) {
      $189 = ___cxa_find_matching_catch(0|0)|0;
      $190 = tempRet0;
      ___clang_call_terminate($189);
      // unreachable;
     } else {
      $$0 = $lpad$phi$index4;$$01 = $lpad$phi$index;
     }
    } else {
     $$0 = $lpad$phi$index4;$$01 = $lpad$phi$index;
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $68 = ___cxa_find_matching_catch()|0;
  $69 = tempRet0;
  $$0 = $69;$$01 = $68;
 }
 $183 = HEAP32[$15>>2]|0;
 $184 = ($183|0)>(-1);
 if (!($184)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $185 = HEAP32[$renderers>>2]|0;
 $186 = HEAP32[$13>>2]|0;
 HEAP32[$7>>2] = $186;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$7+0>>2]|0;
 invoke_vii(2591,($185|0),($$byval_copy16|0));
 $187 = __THREW__; __THREW__ = 0;
 $188 = $187&1;
 if ($188) {
  $189 = ___cxa_find_matching_catch(0|0)|0;
  $190 = tempRet0;
  ___clang_call_terminate($189);
  // unreachable;
 }
 HEAP32[$renderers>>2] = 0;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN2UI6Canvas18UpdateEventIndexesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $eventIndex = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $eventIndex = sp;
 $0 = (($this) + 260|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$eventIndex>>2] = 0;
  __ZN2UI6Canvas27UpdateEventIndexesRecursiveERi($this,$eventIndex);
  STACKTOP = sp;return;
 } else {
  __ZN2UI6Canvas18UpdateEventIndexesEv($1);
  STACKTOP = sp;return;
 }
}
function __ZN2UI6Canvas27UpdateEventIndexesRecursiveERi($this,$eventIndex) {
 $this = $this|0;
 $eventIndex = $eventIndex|0;
 var $$pre = 0, $$pre$phi12Z2D = 0, $$pre$phiZ2D = 0, $$pre10 = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $it$04 = 0, $it$1 = 0, $lastInstructionIndex$02 = 0, $nestedCanvasIndex$0$lcssa = 0, $nestedCanvasIndex$03 = 0, $nestedCanvasIndex$1 = 0;
 var $nestedCanvasIndex$21 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 172|0);
 $1 = (($this) + 180|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$pre10 = (($this) + 300|0);
  $$pre11 = (($this) + 296|0);
  $$pre$phi12Z2D = $$pre11;$$pre$phiZ2D = $$pre10;$nestedCanvasIndex$0$lcssa = 0;
 } else {
  $4 = HEAP32[$0>>2]|0;
  $5 = (($this) + 300|0);
  $6 = (($this) + 296|0);
  $48 = $4;$it$04 = $4;$lastInstructionIndex$02 = 0;$nestedCanvasIndex$03 = 0;
  while(1) {
   $14 = HEAP32[$it$04>>2]|0;
   $15 = (($14) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($lastInstructionIndex$02|0)<($16|0);
   if ($17) {
    $18 = HEAP32[$5>>2]|0;
    $19 = HEAP32[$6>>2]|0;
    $20 = $18;
    $21 = $19;
    $22 = (($20) - ($21))|0;
    $23 = $22 >> 2;
    $24 = ($nestedCanvasIndex$03>>>0)<($23>>>0);
    if ($24) {
     $25 = (($19) + ($nestedCanvasIndex$03<<2)|0);
     $26 = HEAP32[$25>>2]|0;
     __ZN2UI6Canvas27UpdateEventIndexesRecursiveERi($26,$eventIndex);
     $27 = (($nestedCanvasIndex$03) + 1)|0;
     $$pre = HEAP32[$0>>2]|0;
     $35 = $$pre;$it$1 = $it$04;$nestedCanvasIndex$1 = $27;
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    label = 0;
    $28 = HEAP32[$eventIndex>>2]|0;
    $29 = (($14) + 12|0);
    HEAP32[$29>>2] = $28;
    $30 = HEAP32[$eventIndex>>2]|0;
    $31 = (($30) + 1)|0;
    HEAP32[$eventIndex>>2] = $31;
    $32 = (($it$04) + 4|0);
    $35 = $48;$it$1 = $32;$nestedCanvasIndex$1 = $nestedCanvasIndex$03;
   }
   $phitmp = (($lastInstructionIndex$02) + 1)|0;
   $33 = HEAP32[$1>>2]|0;
   $34 = (($35) + ($33<<2)|0);
   $36 = ($it$1|0)==($34|0);
   if ($36) {
    $$pre$phi12Z2D = $6;$$pre$phiZ2D = $5;$nestedCanvasIndex$0$lcssa = $nestedCanvasIndex$1;
    break;
   } else {
    $48 = $35;$it$04 = $it$1;$lastInstructionIndex$02 = $phitmp;$nestedCanvasIndex$03 = $nestedCanvasIndex$1;
   }
  }
 }
 $7 = HEAP32[$$pre$phiZ2D>>2]|0;
 $8 = HEAP32[$$pre$phi12Z2D>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = ($nestedCanvasIndex$0$lcssa>>>0)<($12>>>0);
 if ($13) {
  $38 = $8;$nestedCanvasIndex$21 = $nestedCanvasIndex$0$lcssa;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $37 = (($38) + ($nestedCanvasIndex$21<<2)|0);
  $39 = HEAP32[$37>>2]|0;
  __ZN2UI6Canvas27UpdateEventIndexesRecursiveERi($39,$eventIndex);
  $40 = (($nestedCanvasIndex$21) + 1)|0;
  $41 = HEAP32[$$pre$phiZ2D>>2]|0;
  $42 = HEAP32[$$pre$phi12Z2D>>2]|0;
  $43 = $41;
  $44 = $42;
  $45 = (($43) - ($44))|0;
  $46 = $45 >> 2;
  $47 = ($40>>>0)<($46>>>0);
  if ($47) {
   $38 = $42;$nestedCanvasIndex$21 = $40;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas15InitializeClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN5Unity10GameObject22RegisterMessageHandlerEiRK17MessageIdentifierPFvPviR11MessageDataEi(223,564104,2080,100000);
 __ZN2UI23InitializeCanvasManagerEv();
 STACKTOP = sp;return;
}
function __ZZN2UI6Canvas15InitializeClassEvEN36FunctorImpl_Canvas_kTransformChanged4CallEPviR11MessageData($object,$messageID,$messageData) {
 $object = $object|0;
 $messageID = $messageID|0;
 $messageData = $messageData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $this$tr$i$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp;
 $1 = (($messageData) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($object) + 29|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = $2 & 32;
 $7 = ($6|0)==(0);
 if (!($7)) {
  __ZN2UI6Canvas19SyncTransformParentEv($object);
 }
 $8 = $2 & 128;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($object) + 260|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = (($11) + 205|0);
   HEAP8[$13>>0] = 1;
  }
 }
 $this$tr$i$i$i = $object;
 while(1) {
  $14 = (($this$tr$i$i$i) + 260|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   break;
  } else {
   $this$tr$i$i$i = $15;
  }
 }
 $17 = (($object) + 108|0);
 $18 = (($this$tr$i$i$i) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (__ZNK5Unity10GameObject23QueryComponentTransformEv($19)|0);
 __ZNK9Transform21GetWorldToLocalMatrixEv($0,$20);
 dest=$17+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $21 = (($object) + 260|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($22) + 204|0);
 HEAP8[$24>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas12CleanupClassEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN2UI20CleanupCanvasManagerEv();
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas16CheckConsistencyEv($this) {
 $this = $this|0;
 var $$sum$i$i = 0, $$sum1$i$i = 0, $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i = 0, $scevgep$i$i$i$i = 0, $scevgep4$i$i$i$i = 0, $uglygep$i$i$i$i = 0, $uglygep3$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 268|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 < Math_fround(0.00100000004749745130539);
 $3 = $2 ? Math_fround(0.00100000004749745130539) : $1;
 HEAPF32[$0>>2] = $3;
 $4 = (($this) + 260|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($5) + 296|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($5) + 300|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8|0)==($10|0);
 L4: do {
  if (!($11)) {
   $15 = $8;
   while(1) {
    $14 = HEAP32[$15>>2]|0;
    $16 = ($14|0)==($this|0);
    $13 = (($15) + 4|0);
    if ($16) {
     break;
    }
    $12 = ($13|0)==($10|0);
    if ($12) {
     break L4;
    } else {
     $15 = $13;
    }
   }
   $17 = (($this) + 290|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if ($19) {
    STACKTOP = sp;return;
   } else {
    $23 = $8;
   }
   while(1) {
    $22 = HEAP32[$23>>2]|0;
    $24 = ($22|0)==($this|0);
    $21 = (($23) + 4|0);
    if ($24) {
     label = 8;
     break;
    }
    $20 = ($21|0)==($10|0);
    if ($20) {
     break;
    } else {
     $23 = $21;
    }
   }
   if ((label|0) == 8) {
    $25 = $23;
    $26 = $8;
    $27 = (($25) - ($26))|0;
    $28 = $27 >> 2;
    $29 = (($8) + ($28<<2)|0);
    $$sum$i$i = (($28) + 1)|0;
    $30 = (($8) + ($$sum$i$i<<2)|0);
    $31 = $10;
    $32 = $30;
    $33 = (($31) - ($32))|0;
    $34 = $33 >> 2;
    _memmove(($29|0),($30|0),($33|0))|0;
    $$sum1$i$i = (($34) + ($28))|0;
    $35 = (($8) + ($$sum1$i$i<<2)|0);
    $36 = HEAP32[$9>>2]|0;
    $37 = ($36|0)==($35|0);
    if (!($37)) {
     $__new_last2$i$i$i$i = $35;
     $scevgep$i$i$i$i = (($36) + -4|0);
     $38 = (0 - ($__new_last2$i$i$i$i))|0;
     $uglygep$i$i$i$i = (($scevgep$i$i$i$i) + ($38)|0);
     $uglygep3$i$i$i$i = $uglygep$i$i$i$i;
     $39 = $uglygep3$i$i$i$i >>> 2;
     $40 = $39 ^ -1;
     $scevgep4$i$i$i$i = (($36) + ($40<<2)|0);
     HEAP32[$9>>2] = $scevgep4$i$i$i$i;
    }
    $41 = (($5) + 205|0);
    HEAP8[$41>>0] = 1;
   }
   $42 = (__ZN2UI16GetCanvasManagerEv()|0);
   __ZN2UI13CanvasManager9AddCanvasEPNS_6CanvasE($42,$this);
   STACKTOP = sp;return;
  }
 } while(0);
 $43 = (($this) + 290|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 __ZN2UI6Canvas15AddNestedCanvasEPS0_($5,$this);
 $46 = (__ZN2UI16GetCanvasManagerEv()|0);
 __ZN2UI13CanvasManager12RemoveCanvasEPNS_6CanvasE($46,$this);
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas13RegisterClassEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN6Object13ClassIDToRTTIEi(8)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN9Behaviour13RegisterClassEv();
 }
 HEAP8[$0>>0] = 12;
 $3 = (($0) + 1|0);
 ;HEAP8[$3+0>>0]=HEAP8[874744+0>>0]|0;HEAP8[$3+1>>0]=HEAP8[874744+1>>0]|0;HEAP8[$3+2>>0]=HEAP8[874744+2>>0]|0;HEAP8[$3+3>>0]=HEAP8[874744+3>>0]|0;HEAP8[$3+4>>0]=HEAP8[874744+4>>0]|0;HEAP8[$3+5>>0]=HEAP8[874744+5>>0]|0;
 $4 = (($0) + 7|0);
 HEAP8[$4>>0] = 0;
 __THREW__ = 0;
 invoke_viiiiiii(63,223,8,($0|0),308,(2712|0),0,1);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $14 = HEAP8[$0>>0]|0;
  $15 = $14 & 1;
  $16 = ($15<<24>>24)==(0);
  if ($16) {
   ___resumeException($12|0);
   // unreachable;
  }
  $17 = (($0) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  __ZdlPv($18);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $7 = HEAP8[$0>>0]|0;
  $8 = $7 & 1;
  $9 = ($8<<24>>24)==(0);
  if ($9) {
   STACKTOP = sp;return;
  }
  $10 = (($0) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZN2UI6Canvas7PRODUCEE10MemLabelId18ObjectCreationMode($label,$mode) {
 $label = $label|0;
 $mode = $mode|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$label>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 $3 = (__Znwj10MemLabelIdbiPKci(308,$$byval_copy2,1,16,874960,24)|0);
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(1657,($3|0),($$byval_copy2|0),($mode|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = (($3) + 28|0);
  HEAP8[$6>>0] = 1;
  $7 = (($3) + 29|0);
  HEAP8[$7>>0] = 0;
  HEAP32[$3>>2] = ((874600 + 8|0));
  $8 = (($3) + 32|0);
  HEAP32[$8>>2] = 2;
  $9 = (($3) + 36|0);
  HEAP32[$9>>2] = 0;
  $10 = (($3) + 40|0);
  HEAP8[$10>>0] = 1;
  $11 = (($3) + 172|0);
  HEAP32[$11>>2] = 0;
  $12 = (($3) + 180|0);
  HEAP32[$12>>2] = 0;
  $13 = (($3) + 184|0);
  HEAP32[$13>>2] = 0;
  $14 = (($3) + 176|0);
  HEAP32[$14>>2] = 61;
  $15 = (($3) + 188|0);
  HEAP32[$15>>2] = 0;
  $16 = (($3) + 196|0);
  HEAP32[$16>>2] = 0;
  $17 = (($3) + 200|0);
  HEAP32[$17>>2] = 0;
  $18 = (($3) + 192|0);
  HEAP32[$18>>2] = 61;
  $19 = (($3) + 208|0);
  HEAP32[$19>>2] = 0;
  $20 = (($3) + 216|0);
  HEAP32[$20>>2] = 0;
  $21 = (($3) + 220|0);
  HEAP32[$21>>2] = 0;
  $22 = (($3) + 212|0);
  HEAP32[$22>>2] = 61;
  $23 = (($3) + 224|0);
  HEAP32[$23>>2] = 0;
  $24 = (($3) + 232|0);
  HEAP32[$24>>2] = 0;
  $25 = (($3) + 236|0);
  HEAP32[$25>>2] = 0;
  $26 = (($3) + 228|0);
  HEAP32[$26>>2] = 61;
  $27 = (($3) + 240|0);
  HEAP32[$27>>2] = 0;
  $28 = (($3) + 244|0);
  HEAP32[$28>>2] = 0;
  $29 = (($3) + 252|0);
  HEAP32[$29>>2] = 0;
  $30 = (($3) + 256|0);
  HEAP32[$30>>2] = 0;
  $31 = (($3) + 248|0);
  HEAP32[$31>>2] = 61;
  $32 = (($3) + 260|0);
  HEAP32[$32>>2] = 0;
  $33 = (($3) + 264|0);
  HEAPF32[$33>>2] = Math_fround(0.0);
  $34 = (($3) + 268|0);
  HEAPF32[$34>>2] = Math_fround(1.0);
  $35 = (($3) + 272|0);
  HEAPF32[$35>>2] = Math_fround(100.0);
  $36 = (($3) + 276|0);
  HEAP8[$36>>0] = 0;
  $37 = (($3) + 277|0);
  HEAP8[$37>>0] = 1;
  $38 = (($3) + 280|0);
  HEAPF32[$38>>2] = Math_fround(100.0);
  $39 = (($3) + 284|0);
  HEAP32[$39>>2] = 0;
  $40 = (($3) + 288|0);
  HEAP16[$40>>1] = 0;
  $41 = (($3) + 290|0);
  HEAP8[$41>>0] = 0;
  $42 = (($3) + 292|0);
  HEAP16[$42>>1] = 0;
  $43 = (($3) + 296|0);
  HEAP32[$43>>2] = 0;
  $44 = (($3) + 300|0);
  HEAP32[$44>>2] = 0;
  $45 = (($3) + 304|0);
  HEAP32[$45>>2] = 0;
  STACKTOP = sp;return ($3|0);
 }
 $46 = ___cxa_find_matching_catch()|0;
 $47 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_viiiiii(97,($3|0),($$byval_copy2|0),1,16,(874960|0),24);
 $48 = __THREW__; __THREW__ = 0;
 $49 = $48&1;
 if ($49) {
  $50 = ___cxa_find_matching_catch(0|0)|0;
  $51 = tempRet0;
  ___clang_call_terminate($50);
  // unreachable;
 } else {
  ___resumeException($46|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNK2UI6Canvas25GetClassIDVirtualInternalEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 223;
}
function __ZN2UI6Canvas23VirtualRedirectTransferER13ProxyTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874752,874744,$this,0);
 __ZN2UI6Canvas8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas23VirtualRedirectTransferER14SafeBinaryRead($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $converter$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i = sp;
 $0 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,874752,874744,$converter$i$i,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = ($0|0)>(0);
 if ($2) {
  __ZN2UI6Canvas8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 } else {
  $3 = HEAP32[$converter$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   (FUNCTION_TABLE_iii[$3 & 4095]($this,$transfer)|0);
  }
 }
 __ZN14SafeBinaryRead11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas23VirtualRedirectTransferER18StreamedBinaryReadILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN2UI6Canvas8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas23VirtualRedirectTransferER18StreamedBinaryReadILb1EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN2UI6Canvas8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN2UI6Canvas8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 STACKTOP = sp;return;
}
function __ZN2UI6Canvas23VirtualRedirectTransferER17RemapPPtrTransfer($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI17RemapPPtrTransferEEvRT_($this,$transfer);
 __ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags($transfer,2048);
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($transfer) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiii[$5 & 2047]($3,$1,$7)|0);
 $9 = (($transfer) + 32|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $8;
 __ZN17RemapPPtrTransfer11PopMetaFlagEv($transfer);
 STACKTOP = sp;return;
}
function __Z20RegisterClass_Canvasv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z31RegisterInitializeClassCallbackiPFvvES0_S0_S0_(223,262,263,0,264);
 STACKTOP = sp;return;
}
function __ZN2UI6CanvasD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN2UI6CanvasD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN2UI6CanvasD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3763,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN2UI6Canvas8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<($5>>>0);
 if ($6) {
  $7 = HEAP32[$0>>2]|0;
  HEAP32[$2>>2] = $7;
  HEAP32[$1>>2] = $3;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$0,4);
 }
 $8 = (($this) + 36|0);
 __ZN4PPtrI6CameraE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 280|0);
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($11>>>0)<($12>>>0);
 if ($13) {
  $14 = Math_fround(HEAPF32[$9>>2]);
  HEAPF32[$10>>2] = $14;
  HEAP32[$1>>2] = $11;
  $17 = $11;$19 = $12;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$9,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre3 = HEAP32[$4>>2]|0;
  $17 = $$pre;$19 = $$pre3;
 }
 $15 = (($this) + 276|0);
 $16 = (($17) + 1|0);
 $18 = ($16>>>0)<($19>>>0);
 if ($18) {
  $20 = HEAP8[$15>>0]|0;
  HEAP8[$17>>0] = $20;
  $21 = HEAP32[$1>>2]|0;
  $22 = (($21) + 1|0);
  HEAP32[$1>>2] = $22;
  $25 = $22;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$15,1);
  $$pre4 = HEAP32[$1>>2]|0;
  $25 = $$pre4;
 }
 $23 = (($this) + 277|0);
 $24 = (($25) + 1|0);
 $26 = HEAP32[$4>>2]|0;
 $27 = ($24>>>0)<($26>>>0);
 if ($27) {
  $28 = HEAP8[$23>>0]|0;
  HEAP8[$25>>0] = $28;
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 1|0);
  HEAP32[$1>>2] = $30;
  $33 = $30;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$23,1);
  $$pre5 = HEAP32[$1>>2]|0;
  $33 = $$pre5;
 }
 $31 = (($this) + 290|0);
 $32 = (($33) + 1|0);
 $34 = HEAP32[$4>>2]|0;
 $35 = ($32>>>0)<($34>>>0);
 if ($35) {
  $36 = HEAP8[$31>>0]|0;
  HEAP8[$33>>0] = $36;
  $37 = HEAP32[$1>>2]|0;
  $38 = (($37) + 1|0);
  HEAP32[$1>>2] = $38;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$31,1);
 }
 __ZN19StreamedBinaryWriteILb0EE5AlignEv($transfer);
 $39 = (($this) + 284|0);
 $40 = HEAP32[$1>>2]|0;
 $41 = (($40) + 4|0);
 $42 = HEAP32[$4>>2]|0;
 $43 = ($41>>>0)<($42>>>0);
 if ($43) {
  $44 = HEAP32[$39>>2]|0;
  HEAP32[$40>>2] = $44;
  HEAP32[$1>>2] = $41;
  $47 = $41;$49 = $42;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$39,4);
  $$pre6 = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $47 = $$pre6;$49 = $$pre7;
 }
 $45 = (($this) + 288|0);
 $46 = (($47) + 2|0);
 $48 = ($46>>>0)<($49>>>0);
 if ($48) {
  $50 = HEAP16[$45>>1]|0;
  HEAP16[$47>>1] = $50;
  HEAP32[$1>>2] = $46;
  STACKTOP = sp;return;
 } else {
  __ZN12CachedWriter16UpdateWriteCacheEPKvj($1,$45,2);
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI6CameraE8TransferI19StreamedBinaryWriteILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $30 = (($transfer) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 4|0);
  $33 = (($transfer) + 20|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $36 = HEAP32[$this>>2]|0;
   HEAP32[$31>>2] = $36;
   HEAP32[$30>>2] = $32;
   $38 = $32;$40 = $34;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$this,4);
   $$pre = HEAP32[$30>>2]|0;
   $$pre3 = HEAP32[$33>>2]|0;
   $38 = $$pre;$40 = $$pre3;
  }
  $37 = (($38) + 8|0);
  $39 = ($37>>>0)<($40>>>0);
  if ($39) {
   $41 = $0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = (($41) + 4)|0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = $38;
   $48 = $47;
   HEAP32[$48>>2] = $43;
   $49 = (($47) + 4)|0;
   $50 = $49;
   HEAP32[$50>>2] = $46;
   HEAP32[$30>>2] = $37;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($30,$0,8);
   STACKTOP = sp;return;
  }
 } else {
  $8 = HEAP32[$this>>2]|0;
  __Z43InstanceIDToLocalSerializedObjectIdentifieriR31LocalSerializedObjectIdentifier($8,$localIdentifier);
  $9 = (($transfer) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 4|0);
  $12 = (($transfer) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($11>>>0)<($13>>>0);
  if ($14) {
   $15 = HEAP32[$localIdentifier>>2]|0;
   HEAP32[$10>>2] = $15;
   HEAP32[$9>>2] = $11;
   $17 = $11;$19 = $13;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$localIdentifier,4);
   $$pre4 = HEAP32[$9>>2]|0;
   $$pre5 = HEAP32[$12>>2]|0;
   $17 = $$pre4;$19 = $$pre5;
  }
  $16 = (($17) + 8|0);
  $18 = ($16>>>0)<($19>>>0);
  if ($18) {
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $17;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   HEAP32[$9>>2] = $16;
   STACKTOP = sp;return;
  } else {
   __ZN12CachedWriter16UpdateWriteCacheEPKvj($9,$0,8);
   STACKTOP = sp;return;
  }
 }
}
function __ZN2UI6Canvas8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i2 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$iZ2D = 0, $$pre10 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0);
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
  $$pre$i$i$i1 = HEAP32[$0>>2]|0;
  $8 = $$pre$i$i$i1;
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
  $8 = $7;
 }
 $9 = (_llvm_bswap_i32(($8|0))|0);
 HEAP32[$0>>2] = $9;
 $10 = (($this) + 36|0);
 __ZN4PPtrI6CameraE8TransferI18StreamedBinaryReadILb1EEEEvRT_($10,$transfer);
 $11 = (($this) + 280|0);
 $12 = HEAP32[$1>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$4>>2]|0;
 $15 = ($13>>>0)>($14>>>0);
 if ($15) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$11,4);
  $$pre$i$i$i2 = HEAP32[$11>>2]|0;
  $$pre = HEAP32[$1>>2]|0;
  $$pre6 = HEAP32[$4>>2]|0;
  $$pre$phi$i$i$iZ2D = $11;$18 = $$pre$i$i$i2;$22 = $$pre;$24 = $$pre6;
 } else {
  $16 = Math_fround(HEAPF32[$12>>2]);
  HEAPF32[$11>>2] = $16;
  HEAP32[$1>>2] = $13;
  $17 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
  $$pre$phi$i$i$iZ2D = $11;$18 = $17;$22 = $13;$24 = $14;
 }
 $19 = (_llvm_bswap_i32(($18|0))|0);
 HEAP32[$$pre$phi$i$i$iZ2D>>2] = $19;
 $20 = (($this) + 276|0);
 $21 = (($22) + 1|0);
 $23 = ($21>>>0)>($24>>>0);
 if ($23) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$20,1);
  $$pre7 = HEAP32[$1>>2]|0;
  $30 = $$pre7;
 } else {
  $25 = HEAP8[$22>>0]|0;
  HEAP8[$20>>0] = $25;
  $26 = HEAP32[$1>>2]|0;
  $27 = (($26) + 1|0);
  HEAP32[$1>>2] = $27;
  $30 = $27;
 }
 $28 = (($this) + 277|0);
 $29 = (($30) + 1|0);
 $31 = HEAP32[$4>>2]|0;
 $32 = ($29>>>0)>($31>>>0);
 if ($32) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$28,1);
  $$pre8 = HEAP32[$1>>2]|0;
  $38 = $$pre8;
 } else {
  $33 = HEAP8[$30>>0]|0;
  HEAP8[$28>>0] = $33;
  $34 = HEAP32[$1>>2]|0;
  $35 = (($34) + 1|0);
  HEAP32[$1>>2] = $35;
  $38 = $35;
 }
 $36 = (($this) + 290|0);
 $37 = (($38) + 1|0);
 $39 = HEAP32[$4>>2]|0;
 $40 = ($37>>>0)>($39>>>0);
 if ($40) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$36,1);
 } else {
  $41 = HEAP8[$38>>0]|0;
  HEAP8[$36>>0] = $41;
  $42 = HEAP32[$1>>2]|0;
  $43 = (($42) + 1|0);
  HEAP32[$1>>2] = $43;
 }
 __ZN18StreamedBinaryReadILb1EE5AlignEv($transfer);
 $44 = (($this) + 284|0);
 $45 = HEAP32[$1>>2]|0;
 $46 = (($45) + 4|0);
 $47 = HEAP32[$4>>2]|0;
 $48 = ($46>>>0)>($47>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$44,4);
  $$pre$i$i$i5 = HEAP32[$44>>2]|0;
  $$pre9 = HEAP32[$1>>2]|0;
  $$pre10 = HEAP32[$4>>2]|0;
  $50 = $$pre$i$i$i5;$54 = $$pre9;$56 = $$pre10;
 } else {
  $49 = HEAP32[$45>>2]|0;
  HEAP32[$44>>2] = $49;
  HEAP32[$1>>2] = $46;
  $50 = $49;$54 = $46;$56 = $47;
 }
 $51 = (_llvm_bswap_i32(($50|0))|0);
 HEAP32[$44>>2] = $51;
 $52 = (($this) + 288|0);
 $53 = (($54) + 2|0);
 $55 = ($53>>>0)>($56>>>0);
 if ($55) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$52,2);
  $$pre$i$i$i = HEAP16[$52>>1]|0;
  $59 = $$pre$i$i$i;
  $58 = $59&65535;
  $60 = $58 << 8;
  $61 = $58 >>> 8;
  $62 = $60 | $61;
  $63 = $62&65535;
  HEAP16[$52>>1] = $63;
  STACKTOP = sp;return;
 } else {
  $57 = HEAP16[$54>>1]|0;
  HEAP16[$52>>1] = $57;
  HEAP32[$1>>2] = $53;
  $59 = $57;
  $58 = $59&65535;
  $60 = $58 << 8;
  $61 = $58 >>> 8;
  $62 = $60 | $61;
  $63 = $62&65535;
  HEAP16[$52>>1] = $63;
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI6CameraE8TransferI18StreamedBinaryReadILb1EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$phi$trans$insert2$i$i$i = 0, $$phi$trans$insert2$i$i$i6 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i1 = 0, $$pre$i$i$i11 = 0, $$pre$i$i$i5 = 0, $$pre$phi$i$i$i9Z2D = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi6$i$i$i8Z2D = 0, $$pre$phi6$i$i$iZ2D = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i$i$i = 0, $$pre3$i$i$i7 = 0, $$pre5$i$i$i = 0, $$pre5$i$i$i3 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  $35 = (($transfer) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 4|0);
  $38 = (($transfer) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$this,4);
   $$pre$i$i$i1 = HEAP32[$this>>2]|0;
   $$pre = HEAP32[$35>>2]|0;
   $$pre13 = HEAP32[$38>>2]|0;
   $42 = $$pre$i$i$i1;$45 = $$pre;$47 = $$pre13;
  } else {
   $41 = HEAP32[$36>>2]|0;
   HEAP32[$this>>2] = $41;
   HEAP32[$35>>2] = $37;
   $42 = $41;$45 = $37;$47 = $39;
  }
  $43 = (_llvm_bswap_i32(($42|0))|0);
  HEAP32[$this>>2] = $43;
  $44 = (($45) + 8|0);
  $46 = ($44>>>0)>($47>>>0);
  if ($46) {
   __ZN12CachedReader15UpdateReadCacheEPvj($35,$0,8);
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i = (($0) + 4|0);
   $$pre3$i$i$i = HEAP32[$$phi$trans$insert2$i$i$i>>2]|0;
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$phi$trans$insert2$i$i$i;$58 = $$pre$i$i$i;$60 = $$pre3$i$i$i;
  } else {
   $48 = $45;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $0;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   HEAP32[$35>>2] = $44;
   $$pre5$i$i$i = (($0) + 4|0);
   $$pre$phi$i$i$iZ2D = $0;$$pre$phi6$i$i$iZ2D = $$pre5$i$i$i;$58 = $50;$60 = $53;
  }
  $59 = (_llvm_bswap_i32(($58|0))|0);
  $61 = (_llvm_bswap_i32(($60|0))|0);
  HEAP32[$$pre$phi$i$i$iZ2D>>2] = $61;
  HEAP32[$$pre$phi6$i$i$iZ2D>>2] = $59;
  STACKTOP = sp;return;
 } else {
  $8 = (($transfer) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = (($transfer) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($10>>>0)>($12>>>0);
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre$i$i$i11 = HEAP32[$localIdentifier>>2]|0;
   $$pre14 = HEAP32[$8>>2]|0;
   $$pre15 = HEAP32[$11>>2]|0;
   $15 = $$pre$i$i$i11;$18 = $$pre14;$20 = $$pre15;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $15 = $14;$18 = $10;$20 = $12;
  }
  $16 = (_llvm_bswap_i32(($15|0))|0);
  HEAP32[$localIdentifier>>2] = $16;
  $17 = (($18) + 8|0);
  $19 = ($17>>>0)>($20>>>0);
  if ($19) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   $$pre$i$i$i5 = HEAP32[$0>>2]|0;
   $$phi$trans$insert2$i$i$i6 = (($0) + 4|0);
   $$pre3$i$i$i7 = HEAP32[$$phi$trans$insert2$i$i$i6>>2]|0;
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$phi$trans$insert2$i$i$i6;$31 = $$pre$i$i$i5;$33 = $$pre3$i$i$i7;
  } else {
   $21 = $18;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $0;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   HEAP32[$8>>2] = $17;
   $$pre5$i$i$i3 = (($0) + 4|0);
   $$pre$phi$i$i$i9Z2D = $0;$$pre$phi6$i$i$i8Z2D = $$pre5$i$i$i3;$31 = $23;$33 = $26;
  }
  $32 = (_llvm_bswap_i32(($31|0))|0);
  $34 = (_llvm_bswap_i32(($33|0))|0);
  HEAP32[$$pre$phi$i$i$i9Z2D>>2] = $34;
  HEAP32[$$pre$phi6$i$i$i8Z2D>>2] = $32;
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN2UI6Canvas8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9Behaviour8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer);
 $0 = (($this) + 32|0);
 $1 = (($transfer) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = (($transfer) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)>($5>>>0);
 if ($6) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$0,4);
 } else {
  $7 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $7;
  HEAP32[$1>>2] = $3;
 }
 $8 = (($this) + 36|0);
 __ZN4PPtrI6CameraE8TransferI18StreamedBinaryReadILb0EEEEvRT_($8,$transfer);
 $9 = (($this) + 280|0);
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$4>>2]|0;
 $13 = ($11>>>0)>($12>>>0);
 if ($13) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$9,4);
  $$pre = HEAP32[$1>>2]|0;
  $$pre3 = HEAP32[$4>>2]|0;
  $17 = $$pre;$19 = $$pre3;
 } else {
  $14 = Math_fround(HEAPF32[$10>>2]);
  HEAPF32[$9>>2] = $14;
  HEAP32[$1>>2] = $11;
  $17 = $11;$19 = $12;
 }
 $15 = (($this) + 276|0);
 $16 = (($17) + 1|0);
 $18 = ($16>>>0)>($19>>>0);
 if ($18) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$15,1);
  $$pre4 = HEAP32[$1>>2]|0;
  $25 = $$pre4;
 } else {
  $20 = HEAP8[$17>>0]|0;
  HEAP8[$15>>0] = $20;
  $21 = HEAP32[$1>>2]|0;
  $22 = (($21) + 1|0);
  HEAP32[$1>>2] = $22;
  $25 = $22;
 }
 $23 = (($this) + 277|0);
 $24 = (($25) + 1|0);
 $26 = HEAP32[$4>>2]|0;
 $27 = ($24>>>0)>($26>>>0);
 if ($27) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$23,1);
  $$pre5 = HEAP32[$1>>2]|0;
  $33 = $$pre5;
 } else {
  $28 = HEAP8[$25>>0]|0;
  HEAP8[$23>>0] = $28;
  $29 = HEAP32[$1>>2]|0;
  $30 = (($29) + 1|0);
  HEAP32[$1>>2] = $30;
  $33 = $30;
 }
 $31 = (($this) + 290|0);
 $32 = (($33) + 1|0);
 $34 = HEAP32[$4>>2]|0;
 $35 = ($32>>>0)>($34>>>0);
 if ($35) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$31,1);
 } else {
  $36 = HEAP8[$33>>0]|0;
  HEAP8[$31>>0] = $36;
  $37 = HEAP32[$1>>2]|0;
  $38 = (($37) + 1|0);
  HEAP32[$1>>2] = $38;
 }
 __ZN18StreamedBinaryReadILb0EE5AlignEv($transfer);
 $39 = (($this) + 284|0);
 $40 = HEAP32[$1>>2]|0;
 $41 = (($40) + 4|0);
 $42 = HEAP32[$4>>2]|0;
 $43 = ($41>>>0)>($42>>>0);
 if ($43) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$39,4);
  $$pre6 = HEAP32[$1>>2]|0;
  $$pre7 = HEAP32[$4>>2]|0;
  $47 = $$pre6;$49 = $$pre7;
 } else {
  $44 = HEAP32[$40>>2]|0;
  HEAP32[$39>>2] = $44;
  HEAP32[$1>>2] = $41;
  $47 = $41;$49 = $42;
 }
 $45 = (($this) + 288|0);
 $46 = (($47) + 2|0);
 $48 = ($46>>>0)>($49>>>0);
 if ($48) {
  __ZN12CachedReader15UpdateReadCacheEPvj($1,$45,2);
  STACKTOP = sp;return;
 } else {
  $50 = HEAP16[$47>>1]|0;
  HEAP16[$45>>1] = $50;
  HEAP32[$1>>2] = $46;
  STACKTOP = sp;return;
 }
}
function __ZN4PPtrI6CameraE8TransferI18StreamedBinaryReadILb0EEEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$pre = 0, $$pre3 = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 $8 = (($transfer) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 4|0);
 $11 = (($transfer) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($10>>>0)>($12>>>0);
 if ($7) {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$this,4);
   $$pre = HEAP32[$8>>2]|0;
   $$pre3 = HEAP32[$11>>2]|0;
   $31 = $$pre;$33 = $$pre3;
  } else {
   $29 = HEAP32[$9>>2]|0;
   HEAP32[$this>>2] = $29;
   HEAP32[$8>>2] = $10;
   $31 = $10;$33 = $12;
  }
  $30 = (($31) + 8|0);
  $32 = ($30>>>0)>($33>>>0);
  if ($32) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
   STACKTOP = sp;return;
  } else {
   $34 = $31;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $0;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   HEAP32[$8>>2] = $30;
   STACKTOP = sp;return;
  }
 } else {
  if ($13) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$localIdentifier,4);
   $$pre4 = HEAP32[$8>>2]|0;
   $$pre5 = HEAP32[$11>>2]|0;
   $16 = $$pre4;$18 = $$pre5;
  } else {
   $14 = HEAP32[$9>>2]|0;
   HEAP32[$localIdentifier>>2] = $14;
   HEAP32[$8>>2] = $10;
   $16 = $10;$18 = $12;
  }
  $15 = (($16) + 8|0);
  $17 = ($15>>>0)>($18>>>0);
  if ($17) {
   __ZN12CachedReader15UpdateReadCacheEPvj($8,$0,8);
  } else {
   $19 = $16;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $0;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   HEAP32[$8>>2] = $15;
  }
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN2UI6Canvas8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $$sum$i$i$i = 0, $$sum$i$i$i$i$i = 0, $$sum$i$i$i$i$i3 = 0, $$sum$i$i$i$i$i8 = 0, $$sum1$i$i$i = 0, $$sum1$i$i$i$i$i = 0, $$sum1$i$i$i$i$i4 = 0, $$sum1$i$i$i$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $converter$i$i12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $converter$i$i12 = sp;
 __ZN9Behaviour8TransferI14SafeBinaryReadEEvRT_($this,$transfer);
 __ZN14SafeBinaryRead10SetVersionEi($transfer,2);
 $0 = (($this) + 32|0);
 __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$0,874760,0);
 $1 = (($this) + 36|0);
 $2 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,874776,874944,$converter$i$i12,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = ($2|0)>(0);
  if ($4) {
   __ZN4PPtrI6CameraE8TransferI14SafeBinaryReadEEvRT_($1,$transfer);
  } else {
   $5 = HEAP32[$converter$i$i12>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    (FUNCTION_TABLE_iii[$5 & 4095]($1,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $7 = (($this) + 280|0);
 __ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags($transfer,$7,874792,0);
 $8 = (($this) + 276|0);
 $9 = HEAP32[580544>>2]|0;
 $10 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,874808,$9,$converter$i$i12,0)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  $12 = ($10|0)>(0);
  do {
   if ($12) {
    $13 = (($transfer) + 12|0);
    $14 = (($transfer) + 80|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($15) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($transfer) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($transfer) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($transfer) + 32|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $21)|0;
    $$sum$i$i$i$i$i = (($17) - ($24))|0;
    $25 = (($19) + ($$sum$i$i$i$i$i)|0);
    HEAP32[$13>>2] = $25;
    $26 = ($$sum$i$i$i$i$i|0)<(0);
    if (!($26)) {
     $$sum1$i$i$i$i$i = (($$sum$i$i$i$i$i) + 1)|0;
     $27 = (($19) + ($$sum1$i$i$i$i$i)|0);
     $28 = (($transfer) + 20|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($27>>>0)>($29>>>0);
     if (!($30)) {
      $31 = HEAP8[$25>>0]|0;
      HEAP8[$8>>0] = $31;
      $32 = HEAP32[$13>>2]|0;
      $33 = (($32) + 1|0);
      HEAP32[$13>>2] = $33;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($13,$8,1);
   } else {
    $34 = HEAP32[$converter$i$i12>>2]|0;
    $35 = ($34|0)==(0|0);
    if (!($35)) {
     (FUNCTION_TABLE_iii[$34 & 4095]($8,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $36 = (($this) + 277|0);
 $37 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,874824,$9,$converter$i$i12,0)|0);
 $38 = ($37|0)==(0);
 if (!($38)) {
  $39 = ($37|0)>(0);
  do {
   if ($39) {
    $40 = (($transfer) + 12|0);
    $41 = (($transfer) + 80|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) + 12|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($transfer) + 16|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (($transfer) + 28|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($transfer) + 32|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = Math_imul($50, $48)|0;
    $$sum$i$i$i$i$i3 = (($44) - ($51))|0;
    $52 = (($46) + ($$sum$i$i$i$i$i3)|0);
    HEAP32[$40>>2] = $52;
    $53 = ($$sum$i$i$i$i$i3|0)<(0);
    if (!($53)) {
     $$sum1$i$i$i$i$i4 = (($$sum$i$i$i$i$i3) + 1)|0;
     $54 = (($46) + ($$sum1$i$i$i$i$i4)|0);
     $55 = (($transfer) + 20|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($54>>>0)>($56>>>0);
     if (!($57)) {
      $58 = HEAP8[$52>>0]|0;
      HEAP8[$36>>0] = $58;
      $59 = HEAP32[$40>>2]|0;
      $60 = (($59) + 1|0);
      HEAP32[$40>>2] = $60;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($40,$36,1);
   } else {
    $61 = HEAP32[$converter$i$i12>>2]|0;
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     (FUNCTION_TABLE_iii[$61 & 4095]($36,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $63 = (($this) + 290|0);
 $64 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,874848,$9,$converter$i$i12,0)|0);
 $65 = ($64|0)==(0);
 if (!($65)) {
  $66 = ($64|0)>(0);
  do {
   if ($66) {
    $67 = (($transfer) + 12|0);
    $68 = (($transfer) + 80|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($69) + 12|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = (($transfer) + 16|0);
    $73 = HEAP32[$72>>2]|0;
    $74 = (($transfer) + 28|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($transfer) + 32|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = Math_imul($77, $75)|0;
    $$sum$i$i$i$i$i8 = (($71) - ($78))|0;
    $79 = (($73) + ($$sum$i$i$i$i$i8)|0);
    HEAP32[$67>>2] = $79;
    $80 = ($$sum$i$i$i$i$i8|0)<(0);
    if (!($80)) {
     $$sum1$i$i$i$i$i9 = (($$sum$i$i$i$i$i8) + 1)|0;
     $81 = (($73) + ($$sum1$i$i$i$i$i9)|0);
     $82 = (($transfer) + 20|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($81>>>0)>($83>>>0);
     if (!($84)) {
      $85 = HEAP8[$79>>0]|0;
      HEAP8[$63>>0] = $85;
      $86 = HEAP32[$67>>2]|0;
      $87 = (($86) + 1|0);
      HEAP32[$67>>2] = $87;
      break;
     }
    }
    __ZN12CachedReader15UpdateReadCacheEPvj($67,$63,1);
   } else {
    $88 = HEAP32[$converter$i$i12>>2]|0;
    $89 = ($88|0)==(0|0);
    if (!($89)) {
     (FUNCTION_TABLE_iii[$88 & 4095]($63,$transfer)|0);
    }
   }
  } while(0);
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $90 = (($this) + 284|0);
 __ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags($transfer,$90,874872,0);
 $91 = (($this) + 288|0);
 $92 = HEAP32[580672>>2]|0;
 $93 = (__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb($transfer,874896,$92,$converter$i$i12,0)|0);
 $94 = ($93|0)==(0);
 if (!($94)) {
  $95 = ($93|0)>(0);
  if ($95) {
   $96 = (($transfer) + 12|0);
   $97 = (($transfer) + 80|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = (($98) + 12|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = (($transfer) + 16|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = (($transfer) + 28|0);
   $104 = HEAP32[$103>>2]|0;
   $105 = (($transfer) + 32|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $104)|0;
   $$sum$i$i$i = (($100) - ($107))|0;
   $108 = (($102) + ($$sum$i$i$i)|0);
   HEAP32[$96>>2] = $108;
   $109 = ($$sum$i$i$i|0)<(0);
   if ($109) {
    label = 39;
   } else {
    $$sum1$i$i$i = (($$sum$i$i$i) + 2)|0;
    $110 = (($102) + ($$sum1$i$i$i)|0);
    $111 = (($transfer) + 20|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = ($110>>>0)>($112>>>0);
    if ($113) {
     label = 39;
    } else {
     $114 = HEAP16[$108>>1]|0;
     HEAP16[$91>>1] = $114;
     HEAP32[$96>>2] = $110;
    }
   }
   if ((label|0) == 39) {
    __ZN12CachedReader15UpdateReadCacheEPvj($96,$91,2);
   }
   $115 = HEAP32[$transfer>>2]|0;
   $116 = $115 & 512;
   $117 = ($116|0)==(0);
   if (!($117)) {
    $118 = HEAP16[$91>>1]|0;
    $119 = $118&65535;
    $120 = $119 << 8;
    $121 = $119 >>> 8;
    $122 = $120 | $121;
    $123 = $122&65535;
    HEAP16[$91>>1] = $123;
   }
  } else {
   $124 = HEAP32[$converter$i$i12>>2]|0;
   $125 = ($124|0)==(0|0);
   if (!($125)) {
    (FUNCTION_TABLE_iii[$124 & 4095]($91,$transfer)|0);
   }
  }
  __ZN14SafeBinaryRead11EndTransferEv($transfer);
 }
 $126 = (__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi($transfer,1)|0);
 if (!($126)) {
  STACKTOP = sp;return;
 }
 $127 = HEAP32[$0>>2]|0;
 $128 = ($127|0)==(1);
 if (!($128)) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 2;
 STACKTOP = sp;return;
}
function __ZN4PPtrI6CameraE8TransferI14SafeBinaryReadEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $localIdentifier = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier = sp;
 $0 = (($localIdentifier) + 8|0);
 $1 = $0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$localIdentifier>>2] = 0;
 $5 = HEAP32[$transfer>>2]|0;
 $6 = $5 & 1;
 $7 = ($6|0)==(0);
 if ($7) {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$this,874912,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,874928,0);
  STACKTOP = sp;return;
 } else {
  __ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags($transfer,$localIdentifier,874912,0);
  __ZN14SafeBinaryRead8TransferIxEEvRT_PKc17TransferMetaFlags($transfer,$0,874928,0);
  __Z43LocalSerializedObjectIdentifierToInstanceIDRK31LocalSerializedObjectIdentifierRi($localIdentifier,$this);
  STACKTOP = sp;return;
 }
}
function __ZN2UI6Canvas8TransferI13ProxyTransferEEvRT_($this,$transfer) {
 $this = $this|0;
 $transfer = $transfer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $localIdentifier$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localIdentifier$i$i$i = sp;
 __ZN9Behaviour8TransferI13ProxyTransferEEvRT_($this,$transfer);
 __ZN13ProxyTransfer10SetVersionEi($transfer,2);
 $0 = (($this) + 32|0);
 $1 = HEAP32[580592>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874760,$1,$0,0);
 $2 = (($transfer) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($transfer) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4) + (($6*24)|0)|0) + 12|0);
 HEAP32[$7>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $8 = (($this) + 36|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874776,874944,$8,2048);
 $9 = (($localIdentifier$i$i$i) + 8|0);
 $10 = $9;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = 0;
 HEAP32[$localIdentifier$i$i$i>>2] = 0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874912,$1,$8,1);
 $14 = HEAP32[$2>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($15) + (($16*24)|0)|0) + 12|0);
 HEAP32[$17>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $18 = HEAP32[580688>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874928,$18,$9,1);
 $19 = HEAP32[$2>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$5>>2]|0;
 $22 = ((($20) + (($21*24)|0)|0) + 12|0);
 HEAP32[$22>>2] = 8;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $23 = (($this) + 280|0);
 $24 = HEAP32[580584>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874792,$24,$23,0);
 $25 = HEAP32[$2>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$5>>2]|0;
 $28 = ((($26) + (($27*24)|0)|0) + 12|0);
 HEAP32[$28>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $29 = (($this) + 276|0);
 $30 = HEAP32[580544>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874808,$30,$29,0);
 $31 = HEAP32[$2>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$5>>2]|0;
 $34 = ((($32) + (($33*24)|0)|0) + 12|0);
 HEAP32[$34>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $35 = (($this) + 277|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874824,$30,$35,0);
 $36 = HEAP32[$2>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP32[$5>>2]|0;
 $39 = ((($37) + (($38*24)|0)|0) + 12|0);
 HEAP32[$39>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $40 = (($this) + 290|0);
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874848,$30,$40,0);
 $41 = HEAP32[$2>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$5>>2]|0;
 $44 = ((($42) + (($43*24)|0)|0) + 12|0);
 HEAP32[$44>>2] = 1;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 __ZN13ProxyTransfer5AlignEv($transfer);
 $45 = (($this) + 284|0);
 $46 = HEAP32[580752>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874872,$46,$45,1);
 $47 = HEAP32[$2>>2]|0;
 $48 = HEAP32[$47>>2]|0;
 $49 = HEAP32[$5>>2]|0;
 $50 = ((($48) + (($49*24)|0)|0) + 12|0);
 HEAP32[$50>>2] = 4;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 $51 = (($this) + 288|0);
 $52 = HEAP32[580672>>2]|0;
 __ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags($transfer,874896,$52,$51,1);
 $53 = HEAP32[$2>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = HEAP32[$5>>2]|0;
 $56 = ((($54) + (($55*24)|0)|0) + 12|0);
 HEAP32[$56>>2] = 2;
 __ZN13ProxyTransfer11EndTransferEv($transfer);
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEvT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$017$ph = 0, $$10 = 0, $$1016 = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$024 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0;
 var $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $0 = sp + 228|0;
 $1 = sp + 216|0;
 $2 = sp + 204|0;
 $3 = sp + 192|0;
 $4 = sp + 180|0;
 $5 = sp + 168|0;
 $6 = sp + 156|0;
 $7 = sp + 144|0;
 $8 = sp + 132|0;
 $9 = sp + 120|0;
 $10 = sp + 108|0;
 $11 = sp + 36|0;
 $12 = sp;
 $13 = sp + 12|0;
 $14 = sp + 24|0;
 $15 = sp + 48|0;
 $16 = sp + 60|0;
 $17 = sp + 72|0;
 $18 = sp + 84|0;
 $19 = sp + 96|0;
 $20 = (($2) + 4|0);
 $21 = (($2) + 8|0);
 $22 = (($3) + 4|0);
 $23 = (($3) + 8|0);
 $24 = (($18) + 4|0);
 $25 = (($18) + 8|0);
 $26 = (($19) + 4|0);
 $27 = (($19) + 8|0);
 $28 = (($14) + 4|0);
 $29 = (($14) + 8|0);
 $30 = (($15) + 4|0);
 $31 = (($15) + 8|0);
 $32 = (($16) + 4|0);
 $33 = (($16) + 8|0);
 $34 = (($17) + 4|0);
 $35 = (($17) + 8|0);
 $36 = (($12) + 4|0);
 $37 = (($12) + 8|0);
 $38 = (($13) + 4|0);
 $39 = (($13) + 8|0);
 $40 = (($4) + 4|0);
 $41 = (($4) + 8|0);
 $42 = (($5) + 4|0);
 $43 = (($5) + 8|0);
 $44 = (($8) + 4|0);
 $45 = (($8) + 8|0);
 $46 = (($9) + 4|0);
 $47 = (($9) + 8|0);
 $48 = (($10) + 4|0);
 $49 = (($10) + 8|0);
 $50 = (($11) + 4|0);
 $51 = (($11) + 8|0);
 $52 = (($6) + 4|0);
 $53 = (($6) + 8|0);
 $54 = (($7) + 4|0);
 $55 = (($7) + 8|0);
 $$0$ph = $__first;$$017$ph = $__last;
 L1: while(1) {
  $56 = $$017$ph;
  $57 = (($$017$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $58 = $$0;
   $59 = (($56) - ($58))|0;
   $60 = $59 >> 2;
   switch ($60|0) {
   case 1: case 0:  {
    label = 65;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 4:  {
    label = 9;
    break L1;
    break;
   }
   case 3:  {
    label = 8;
    break L1;
    break;
   }
   case 5:  {
    label = 10;
    break L1;
    break;
   }
   default: {
   }
   }
   $81 = ($59|0)<(124);
   if ($81) {
    label = 12;
    break L1;
   }
   $82 = ($59|0)>(3996);
   $83 = (($60|0) / 2)&-1;
   $84 = (($$0) + ($83<<2)|0);
   if ($82) {
    $85 = (($60|0) / 4)&-1;
    $86 = (($$0) + ($85<<2)|0);
    $$sum = (($85) + ($83))|0;
    $87 = (($$0) + ($$sum<<2)|0);
    $88 = (__ZNSt3__17__sort5IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_SC_SC_T_($$0,$86,$84,$87,$57,$__comp)|0);
    $__n_swaps$0 = $88;
   } else {
    $89 = (__ZNSt3__17__sort3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_T_($$0,$84,$57,$__comp)|0);
    $__n_swaps$0 = $89;
   }
   $90 = HEAP32[$__comp>>2]|0;
   $91 = HEAP32[$$0>>2]|0;
   HEAP32[$2>>2] = 0;
   HEAP32[$20>>2] = 0;
   HEAP32[$21>>2] = $91;
   $92 = HEAP32[$84>>2]|0;
   HEAP32[$3>>2] = 0;
   HEAP32[$22>>2] = 0;
   HEAP32[$23>>2] = $92;
   __THREW__ = 0;
   $93 = (invoke_iii($90|0,($2|0),($3|0))|0);
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 23;
    break L1;
   }
   do {
    if ($93) {
     $__j$3 = $57;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $57;
     while(1) {
      $96 = (($__j$0) + -4|0);
      $97 = ($$0|0)==($96|0);
      if ($97) {
       break;
      }
      $144 = HEAP32[$__comp>>2]|0;
      $145 = HEAP32[$96>>2]|0;
      HEAP32[$12>>2] = 0;
      HEAP32[$36>>2] = 0;
      HEAP32[$37>>2] = $145;
      $146 = HEAP32[$84>>2]|0;
      HEAP32[$13>>2] = 0;
      HEAP32[$38>>2] = 0;
      HEAP32[$39>>2] = $146;
      __THREW__ = 0;
      $147 = (invoke_iii($144|0,($12|0),($13|0))|0);
      $148 = __THREW__; __THREW__ = 0;
      $149 = $148&1;
      if ($149) {
       label = 42;
       break L1;
      }
      if ($147) {
       label = 41;
       break;
      } else {
       $__j$0 = $96;
      }
     }
     if ((label|0) == 41) {
      label = 0;
      $150 = HEAP32[$$0>>2]|0;
      $151 = HEAP32[$96>>2]|0;
      HEAP32[$$0>>2] = $151;
      HEAP32[$96>>2] = $150;
      $152 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $96;$__n_swaps$3 = $152;
      break;
     }
     $98 = (($$0) + 4|0);
     $99 = HEAP32[$__comp>>2]|0;
     $100 = HEAP32[$$0>>2]|0;
     HEAP32[$4>>2] = 0;
     HEAP32[$40>>2] = 0;
     HEAP32[$41>>2] = $100;
     $101 = HEAP32[$57>>2]|0;
     HEAP32[$5>>2] = 0;
     HEAP32[$42>>2] = 0;
     HEAP32[$43>>2] = $101;
     __THREW__ = 0;
     $102 = (invoke_iii($99|0,($4|0),($5|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 24;
      break L1;
     }
     if ($102) {
      $__i$1 = $98;
     } else {
      $105 = ($98|0)==($57|0);
      if ($105) {
       label = 65;
       break L1;
      } else {
       $__i$024 = $98;
      }
      while(1) {
       $112 = HEAP32[$__comp>>2]|0;
       $113 = HEAP32[$$0>>2]|0;
       HEAP32[$6>>2] = 0;
       HEAP32[$52>>2] = 0;
       HEAP32[$53>>2] = $113;
       $114 = HEAP32[$__i$024>>2]|0;
       HEAP32[$7>>2] = 0;
       HEAP32[$54>>2] = 0;
       HEAP32[$55>>2] = $114;
       __THREW__ = 0;
       $115 = (invoke_iii($112|0,($6|0),($7|0))|0);
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 28;
        break L1;
       }
       $107 = (($__i$024) + 4|0);
       if ($115) {
        break;
       }
       $106 = ($107|0)==($57|0);
       if ($106) {
        label = 65;
        break L1;
       } else {
        $__i$024 = $107;
       }
      }
      $118 = HEAP32[$__i$024>>2]|0;
      $119 = HEAP32[$57>>2]|0;
      HEAP32[$__i$024>>2] = $119;
      HEAP32[$57>>2] = $118;
      $__i$1 = $107;
     }
     $122 = ($__i$1|0)==($57|0);
     if ($122) {
      label = 65;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $57;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $123 = HEAP32[$__comp>>2]|0;
       $124 = HEAP32[$$0>>2]|0;
       HEAP32[$8>>2] = 0;
       HEAP32[$44>>2] = 0;
       HEAP32[$45>>2] = $124;
       $125 = HEAP32[$__i$2>>2]|0;
       HEAP32[$9>>2] = 0;
       HEAP32[$46>>2] = 0;
       HEAP32[$47>>2] = $125;
       __THREW__ = 0;
       $126 = (invoke_iii($123|0,($8|0),($9|0))|0);
       $127 = __THREW__; __THREW__ = 0;
       $128 = $127&1;
       if ($128) {
        label = 33;
        break L1;
       }
       $129 = (($__i$2) + 4|0);
       if ($126) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $129;
       }
      }
      while(1) {
       $132 = HEAP32[$__comp>>2]|0;
       $133 = HEAP32[$$0>>2]|0;
       HEAP32[$10>>2] = 0;
       HEAP32[$48>>2] = 0;
       HEAP32[$49>>2] = $133;
       $134 = (($__j$2) + -4|0);
       $135 = HEAP32[$134>>2]|0;
       HEAP32[$11>>2] = 0;
       HEAP32[$50>>2] = 0;
       HEAP32[$51>>2] = $135;
       __THREW__ = 0;
       $136 = (invoke_iii($132|0,($10|0),($11|0))|0);
       $137 = __THREW__; __THREW__ = 0;
       $138 = $137&1;
       if ($138) {
        label = 36;
        break L1;
       }
       if ($136) {
        $__j$2 = $134;
       } else {
        break;
       }
      }
      $141 = ($__i$2>>>0)<($134>>>0);
      if (!($141)) {
       $$0 = $__i$2;
       continue L3;
      }
      $142 = HEAP32[$__i$2>>2]|0;
      $143 = HEAP32[$134>>2]|0;
      HEAP32[$__i$2>>2] = $143;
      HEAP32[$134>>2] = $142;
      $__i$2$ph = $129;$__j$1$ph = $134;
     }
    }
   } while(0);
   $155 = (($$0) + 4|0);
   $156 = ($155>>>0)<($__j$3>>>0);
   L40: do {
    if ($156) {
     $__i$3$ph = $155;$__j$4$ph = $__j$3;$__m$0$ph = $84;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $157 = HEAP32[$__comp>>2]|0;
       $158 = HEAP32[$__i$3>>2]|0;
       HEAP32[$14>>2] = 0;
       HEAP32[$28>>2] = 0;
       HEAP32[$29>>2] = $158;
       $159 = HEAP32[$__m$0$ph>>2]|0;
       HEAP32[$15>>2] = 0;
       HEAP32[$30>>2] = 0;
       HEAP32[$31>>2] = $159;
       __THREW__ = 0;
       $160 = (invoke_iii($157|0,($14|0),($15|0))|0);
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       if ($162) {
        label = 47;
        break L1;
       }
       $163 = (($__i$3) + 4|0);
       if ($160) {
        $__i$3 = $163;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $166 = HEAP32[$__comp>>2]|0;
       $167 = (($__j$5) + -4|0);
       $168 = HEAP32[$167>>2]|0;
       HEAP32[$16>>2] = 0;
       HEAP32[$32>>2] = 0;
       HEAP32[$33>>2] = $168;
       $169 = HEAP32[$__m$0$ph>>2]|0;
       HEAP32[$17>>2] = 0;
       HEAP32[$34>>2] = 0;
       HEAP32[$35>>2] = $169;
       __THREW__ = 0;
       $170 = (invoke_iii($166|0,($16|0),($17|0))|0);
       $171 = __THREW__; __THREW__ = 0;
       $172 = $171&1;
       if ($172) {
        label = 50;
        break L1;
       }
       if ($170) {
        break;
       } else {
        $__j$5 = $167;
       }
      }
      $175 = ($__i$3>>>0)>($167>>>0);
      if ($175) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L40;
      }
      $176 = HEAP32[$__i$3>>2]|0;
      $177 = HEAP32[$167>>2]|0;
      HEAP32[$__i$3>>2] = $177;
      HEAP32[$167>>2] = $176;
      $178 = (($__n_swaps$4$ph) + 1)|0;
      $179 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $179 ? $167 : $__m$0$ph;
      $__i$3$ph = $163;$__j$4$ph = $167;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $178;
     }
    } else {
     $__i$4 = $155;$__m$2 = $84;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $180 = ($__i$4|0)==($__m$2|0);
   if ($180) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $181 = HEAP32[$__comp>>2]|0;
    $182 = HEAP32[$__m$2>>2]|0;
    HEAP32[$18>>2] = 0;
    HEAP32[$24>>2] = 0;
    HEAP32[$25>>2] = $182;
    $183 = HEAP32[$__i$4>>2]|0;
    HEAP32[$19>>2] = 0;
    HEAP32[$26>>2] = 0;
    HEAP32[$27>>2] = $183;
    __THREW__ = 0;
    $184 = (invoke_iii($181|0,($18|0),($19|0))|0);
    $185 = __THREW__; __THREW__ = 0;
    $186 = $185&1;
    if ($186) {
     label = 57;
     break L1;
    }
    if ($184) {
     $187 = HEAP32[$__i$4>>2]|0;
     $188 = HEAP32[$__m$2>>2]|0;
     HEAP32[$__i$4>>2] = $188;
     HEAP32[$__m$2>>2] = $187;
     $189 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $189;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $192 = ($__n_swaps$6|0)==(0);
   if ($192) {
    $193 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEbT0_SC_T_($$0,$__i$4,$__comp)|0);
    $194 = (($__i$4) + 4|0);
    $195 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEbT0_SC_T_($194,$$017$ph,$__comp)|0);
    if ($195) {
     label = 60;
     break;
    }
    if ($193) {
     $$0 = $194;
     continue;
    }
   }
   $196 = $__i$4;
   $197 = (($196) - ($58))|0;
   $198 = (($56) - ($196))|0;
   $199 = ($197|0)<($198|0);
   if (!($199)) {
    label = 64;
    break;
   }
   __ZNSt3__16__sortIRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEvT0_SC_T_($$0,$__i$4,$__comp);
   $200 = (($__i$4) + 4|0);
   $$0 = $200;
  }
  if ((label|0) == 60) {
   label = 0;
   if ($193) {
    label = 65;
    break;
   } else {
    $$0$ph = $$0;$$017$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 64) {
   label = 0;
   $201 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEvT0_SC_T_($201,$$017$ph,$__comp);
   $$0$ph = $$0;$$017$ph = $__i$4;
   continue;
  }
 }
 switch (label|0) {
  case 4: {
   $61 = HEAP32[$__comp>>2]|0;
   $62 = HEAP32[$57>>2]|0;
   HEAP32[$0>>2] = 0;
   $63 = (($0) + 4|0);
   HEAP32[$63>>2] = 0;
   $64 = (($0) + 8|0);
   HEAP32[$64>>2] = $62;
   $65 = HEAP32[$$0>>2]|0;
   HEAP32[$1>>2] = 0;
   $66 = (($1) + 4|0);
   HEAP32[$66>>2] = 0;
   $67 = (($1) + 8|0);
   HEAP32[$67>>2] = $65;
   __THREW__ = 0;
   $68 = (invoke_iii($61|0,($0|0),($1|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    $73 = ___cxa_find_matching_catch()|0;
    $74 = tempRet0;
    $$10 = $74;$$1016 = $73;
    ___resumeException($$1016|0);
    // unreachable;
   }
   if (!($68)) {
    STACKTOP = sp;return;
   }
   $71 = HEAP32[$$0>>2]|0;
   $72 = HEAP32[$57>>2]|0;
   HEAP32[$$0>>2] = $72;
   HEAP32[$57>>2] = $71;
   STACKTOP = sp;return;
   break;
  }
  case 8: {
   $75 = (($$0) + 4|0);
   (__ZNSt3__17__sort3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_T_($$0,$75,$57,$__comp)|0);
   STACKTOP = sp;return;
   break;
  }
  case 9: {
   $76 = (($$0) + 4|0);
   $77 = (($$0) + 8|0);
   (__ZNSt3__17__sort4IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_SC_T_($$0,$76,$77,$57,$__comp)|0);
   STACKTOP = sp;return;
   break;
  }
  case 10: {
   $78 = (($$0) + 4|0);
   $79 = (($$0) + 8|0);
   $80 = (($$0) + 12|0);
   (__ZNSt3__17__sort5IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_SC_SC_T_($$0,$78,$79,$80,$57,$__comp)|0);
   STACKTOP = sp;return;
   break;
  }
  case 12: {
   __ZNSt3__118__insertion_sort_3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEvT0_SC_T_($$0,$$017$ph,$__comp);
   STACKTOP = sp;return;
   break;
  }
  case 23: {
   $108 = ___cxa_find_matching_catch()|0;
   $109 = tempRet0;
   $$10 = $109;$$1016 = $108;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 24: {
   $110 = ___cxa_find_matching_catch()|0;
   $111 = tempRet0;
   $$10 = $111;$$1016 = $110;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 28: {
   $120 = ___cxa_find_matching_catch()|0;
   $121 = tempRet0;
   $$10 = $121;$$1016 = $120;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 33: {
   $130 = ___cxa_find_matching_catch()|0;
   $131 = tempRet0;
   $$10 = $131;$$1016 = $130;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 36: {
   $139 = ___cxa_find_matching_catch()|0;
   $140 = tempRet0;
   $$10 = $140;$$1016 = $139;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 42: {
   $153 = ___cxa_find_matching_catch()|0;
   $154 = tempRet0;
   $$10 = $154;$$1016 = $153;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 47: {
   $164 = ___cxa_find_matching_catch()|0;
   $165 = tempRet0;
   $$10 = $165;$$1016 = $164;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 50: {
   $173 = ___cxa_find_matching_catch()|0;
   $174 = tempRet0;
   $$10 = $174;$$1016 = $173;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 57: {
   $190 = ___cxa_find_matching_catch()|0;
   $191 = tempRet0;
   $$10 = $191;$$1016 = $190;
   ___resumeException($$1016|0);
   // unreachable;
   break;
  }
  case 65: {
   STACKTOP = sp;return;
   break;
  }
 }
}
function __ZNSt3__17__sort3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$07 = 0, $$5 = 0, $$56 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 108|0;
 $1 = sp + 96|0;
 $2 = sp + 84|0;
 $3 = sp + 72|0;
 $4 = sp + 60|0;
 $5 = sp + 48|0;
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp;
 $9 = sp + 36|0;
 $10 = HEAP32[$__c>>2]|0;
 $11 = HEAP32[$__y>>2]|0;
 HEAP32[$0>>2] = 0;
 $12 = (($0) + 4|0);
 HEAP32[$12>>2] = 0;
 $13 = (($0) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = HEAP32[$__x>>2]|0;
 HEAP32[$1>>2] = 0;
 $15 = (($1) + 4|0);
 HEAP32[$15>>2] = 0;
 $16 = (($1) + 8|0);
 HEAP32[$16>>2] = $14;
 __THREW__ = 0;
 $17 = (invoke_iii($10|0,($0|0),($1|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $30 = ___cxa_find_matching_catch()|0;
  $31 = tempRet0;
  $$5 = $31;$$56 = $30;
  ___resumeException($$56|0);
  // unreachable;
 }
 $20 = HEAP32[$__c>>2]|0;
 $21 = HEAP32[$__z>>2]|0;
 if (!($17)) {
  HEAP32[$2>>2] = 0;
  $22 = (($2) + 4|0);
  HEAP32[$22>>2] = 0;
  $23 = (($2) + 8|0);
  HEAP32[$23>>2] = $21;
  $24 = HEAP32[$__y>>2]|0;
  HEAP32[$3>>2] = 0;
  $25 = (($3) + 4|0);
  HEAP32[$25>>2] = 0;
  $26 = (($3) + 8|0);
  HEAP32[$26>>2] = $24;
  __THREW__ = 0;
  $27 = (invoke_iii($20|0,($2|0),($3|0))|0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   $$5 = $33;$$56 = $32;
   ___resumeException($$56|0);
   // unreachable;
  }
  if (!($27)) {
   $$07 = 0;
   STACKTOP = sp;return ($$07|0);
  }
  $34 = HEAP32[$__y>>2]|0;
  $35 = HEAP32[$__z>>2]|0;
  HEAP32[$__y>>2] = $35;
  HEAP32[$__z>>2] = $34;
  $36 = HEAP32[$__c>>2]|0;
  $37 = HEAP32[$__y>>2]|0;
  HEAP32[$4>>2] = 0;
  $38 = (($4) + 4|0);
  HEAP32[$38>>2] = 0;
  $39 = (($4) + 8|0);
  HEAP32[$39>>2] = $37;
  $40 = HEAP32[$__x>>2]|0;
  HEAP32[$5>>2] = 0;
  $41 = (($5) + 4|0);
  HEAP32[$41>>2] = 0;
  $42 = (($5) + 8|0);
  HEAP32[$42>>2] = $40;
  __THREW__ = 0;
  $43 = (invoke_iii($36|0,($4|0),($5|0))|0);
  $44 = __THREW__; __THREW__ = 0;
  $45 = $44&1;
  if ($45) {
   $48 = ___cxa_find_matching_catch()|0;
   $49 = tempRet0;
   $$5 = $49;$$56 = $48;
   ___resumeException($$56|0);
   // unreachable;
  }
  if (!($43)) {
   $$07 = 1;
   STACKTOP = sp;return ($$07|0);
  }
  $46 = HEAP32[$__x>>2]|0;
  $47 = HEAP32[$__y>>2]|0;
  HEAP32[$__x>>2] = $47;
  HEAP32[$__y>>2] = $46;
  $$07 = 2;
  STACKTOP = sp;return ($$07|0);
 }
 HEAP32[$6>>2] = 0;
 $50 = (($6) + 4|0);
 HEAP32[$50>>2] = 0;
 $51 = (($6) + 8|0);
 HEAP32[$51>>2] = $21;
 $52 = HEAP32[$__y>>2]|0;
 HEAP32[$7>>2] = 0;
 $53 = (($7) + 4|0);
 HEAP32[$53>>2] = 0;
 $54 = (($7) + 8|0);
 HEAP32[$54>>2] = $52;
 __THREW__ = 0;
 $55 = (invoke_iii($20|0,($6|0),($7|0))|0);
 $56 = __THREW__; __THREW__ = 0;
 $57 = $56&1;
 if ($57) {
  $60 = ___cxa_find_matching_catch()|0;
  $61 = tempRet0;
  $$5 = $61;$$56 = $60;
  ___resumeException($$56|0);
  // unreachable;
 }
 $58 = HEAP32[$__x>>2]|0;
 if ($55) {
  $59 = HEAP32[$__z>>2]|0;
  HEAP32[$__x>>2] = $59;
  HEAP32[$__z>>2] = $58;
  $$07 = 1;
  STACKTOP = sp;return ($$07|0);
 }
 $62 = HEAP32[$__y>>2]|0;
 HEAP32[$__x>>2] = $62;
 HEAP32[$__y>>2] = $58;
 $63 = HEAP32[$__c>>2]|0;
 $64 = HEAP32[$__z>>2]|0;
 HEAP32[$8>>2] = 0;
 $65 = (($8) + 4|0);
 HEAP32[$65>>2] = 0;
 $66 = (($8) + 8|0);
 HEAP32[$66>>2] = $64;
 HEAP32[$9>>2] = 0;
 $67 = (($9) + 4|0);
 HEAP32[$67>>2] = 0;
 $68 = (($9) + 8|0);
 HEAP32[$68>>2] = $58;
 __THREW__ = 0;
 $69 = (invoke_iii($63|0,($8|0),($9|0))|0);
 $70 = __THREW__; __THREW__ = 0;
 $71 = $70&1;
 if ($71) {
  $74 = ___cxa_find_matching_catch()|0;
  $75 = tempRet0;
  $$5 = $75;$$56 = $74;
  ___resumeException($$56|0);
  // unreachable;
 }
 if (!($69)) {
  $$07 = 1;
  STACKTOP = sp;return ($$07|0);
 }
 $72 = HEAP32[$__y>>2]|0;
 $73 = HEAP32[$__z>>2]|0;
 HEAP32[$__y>>2] = $73;
 HEAP32[$__z>>2] = $72;
 $$07 = 2;
 STACKTOP = sp;return ($$07|0);
}
function __ZNSt3__17__sort4IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_SC_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $$3 = 0, $$34 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 60|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 $6 = (__ZNSt3__17__sort3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_T_($__x1,$__x2,$__x3,$__c)|0);
 $7 = HEAP32[$__c>>2]|0;
 $8 = HEAP32[$__x4>>2]|0;
 HEAP32[$0>>2] = 0;
 $9 = (($0) + 4|0);
 HEAP32[$9>>2] = 0;
 $10 = (($0) + 8|0);
 HEAP32[$10>>2] = $8;
 $11 = HEAP32[$__x3>>2]|0;
 HEAP32[$1>>2] = 0;
 $12 = (($1) + 4|0);
 HEAP32[$12>>2] = 0;
 $13 = (($1) + 8|0);
 HEAP32[$13>>2] = $11;
 __THREW__ = 0;
 $14 = (invoke_iii($7|0,($0|0),($1|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $$3 = $47;$$34 = $46;
  ___resumeException($$34|0);
  // unreachable;
 }
 if (!($14)) {
  $__r$0 = $6;
  STACKTOP = sp;return ($__r$0|0);
 }
 $17 = HEAP32[$__x3>>2]|0;
 $18 = HEAP32[$__x4>>2]|0;
 HEAP32[$__x3>>2] = $18;
 HEAP32[$__x4>>2] = $17;
 $19 = HEAP32[$__c>>2]|0;
 $20 = HEAP32[$__x3>>2]|0;
 HEAP32[$2>>2] = 0;
 $21 = (($2) + 4|0);
 HEAP32[$21>>2] = 0;
 $22 = (($2) + 8|0);
 HEAP32[$22>>2] = $20;
 $23 = HEAP32[$__x2>>2]|0;
 HEAP32[$3>>2] = 0;
 $24 = (($3) + 4|0);
 HEAP32[$24>>2] = 0;
 $25 = (($3) + 8|0);
 HEAP32[$25>>2] = $23;
 __THREW__ = 0;
 $26 = (invoke_iii($19|0,($2|0),($3|0))|0);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $$3 = $49;$$34 = $48;
  ___resumeException($$34|0);
  // unreachable;
 }
 $29 = (($6) + 1)|0;
 if (!($26)) {
  $__r$0 = $29;
  STACKTOP = sp;return ($__r$0|0);
 }
 $30 = HEAP32[$__x2>>2]|0;
 $31 = HEAP32[$__x3>>2]|0;
 HEAP32[$__x2>>2] = $31;
 HEAP32[$__x3>>2] = $30;
 $32 = HEAP32[$__c>>2]|0;
 $33 = HEAP32[$__x2>>2]|0;
 HEAP32[$4>>2] = 0;
 $34 = (($4) + 4|0);
 HEAP32[$34>>2] = 0;
 $35 = (($4) + 8|0);
 HEAP32[$35>>2] = $33;
 $36 = HEAP32[$__x1>>2]|0;
 HEAP32[$5>>2] = 0;
 $37 = (($5) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($5) + 8|0);
 HEAP32[$38>>2] = $36;
 __THREW__ = 0;
 $39 = (invoke_iii($32|0,($4|0),($5|0))|0);
 $40 = __THREW__; __THREW__ = 0;
 $41 = $40&1;
 if ($41) {
  $50 = ___cxa_find_matching_catch()|0;
  $51 = tempRet0;
  $$3 = $51;$$34 = $50;
  ___resumeException($$34|0);
  // unreachable;
 }
 $42 = (($6) + 2)|0;
 if (!($39)) {
  $__r$0 = $42;
  STACKTOP = sp;return ($__r$0|0);
 }
 $43 = HEAP32[$__x1>>2]|0;
 $44 = HEAP32[$__x2>>2]|0;
 HEAP32[$__x1>>2] = $44;
 HEAP32[$__x2>>2] = $43;
 $45 = (($6) + 3)|0;
 $__r$0 = $45;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_SC_SC_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $$4 = 0, $$45 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 84|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 $6 = sp + 60|0;
 $7 = sp + 72|0;
 $8 = (__ZNSt3__17__sort4IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_SC_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $9 = HEAP32[$__c>>2]|0;
 $10 = HEAP32[$__x5>>2]|0;
 HEAP32[$0>>2] = 0;
 $11 = (($0) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($0) + 8|0);
 HEAP32[$12>>2] = $10;
 $13 = HEAP32[$__x4>>2]|0;
 HEAP32[$1>>2] = 0;
 $14 = (($1) + 4|0);
 HEAP32[$14>>2] = 0;
 $15 = (($1) + 8|0);
 HEAP32[$15>>2] = $13;
 __THREW__ = 0;
 $16 = (invoke_iii($9|0,($0|0),($1|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $61 = ___cxa_find_matching_catch()|0;
  $62 = tempRet0;
  $$4 = $62;$$45 = $61;
  ___resumeException($$45|0);
  // unreachable;
 }
 if (!($16)) {
  $__r$0 = $8;
  STACKTOP = sp;return ($__r$0|0);
 }
 $19 = HEAP32[$__x4>>2]|0;
 $20 = HEAP32[$__x5>>2]|0;
 HEAP32[$__x4>>2] = $20;
 HEAP32[$__x5>>2] = $19;
 $21 = HEAP32[$__c>>2]|0;
 $22 = HEAP32[$__x4>>2]|0;
 HEAP32[$2>>2] = 0;
 $23 = (($2) + 4|0);
 HEAP32[$23>>2] = 0;
 $24 = (($2) + 8|0);
 HEAP32[$24>>2] = $22;
 $25 = HEAP32[$__x3>>2]|0;
 HEAP32[$3>>2] = 0;
 $26 = (($3) + 4|0);
 HEAP32[$26>>2] = 0;
 $27 = (($3) + 8|0);
 HEAP32[$27>>2] = $25;
 __THREW__ = 0;
 $28 = (invoke_iii($21|0,($2|0),($3|0))|0);
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 if ($30) {
  $63 = ___cxa_find_matching_catch()|0;
  $64 = tempRet0;
  $$4 = $64;$$45 = $63;
  ___resumeException($$45|0);
  // unreachable;
 }
 $31 = (($8) + 1)|0;
 if (!($28)) {
  $__r$0 = $31;
  STACKTOP = sp;return ($__r$0|0);
 }
 $32 = HEAP32[$__x3>>2]|0;
 $33 = HEAP32[$__x4>>2]|0;
 HEAP32[$__x3>>2] = $33;
 HEAP32[$__x4>>2] = $32;
 $34 = HEAP32[$__c>>2]|0;
 $35 = HEAP32[$__x3>>2]|0;
 HEAP32[$4>>2] = 0;
 $36 = (($4) + 4|0);
 HEAP32[$36>>2] = 0;
 $37 = (($4) + 8|0);
 HEAP32[$37>>2] = $35;
 $38 = HEAP32[$__x2>>2]|0;
 HEAP32[$5>>2] = 0;
 $39 = (($5) + 4|0);
 HEAP32[$39>>2] = 0;
 $40 = (($5) + 8|0);
 HEAP32[$40>>2] = $38;
 __THREW__ = 0;
 $41 = (invoke_iii($34|0,($4|0),($5|0))|0);
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $65 = ___cxa_find_matching_catch()|0;
  $66 = tempRet0;
  $$4 = $66;$$45 = $65;
  ___resumeException($$45|0);
  // unreachable;
 }
 $44 = (($8) + 2)|0;
 if (!($41)) {
  $__r$0 = $44;
  STACKTOP = sp;return ($__r$0|0);
 }
 $45 = HEAP32[$__x2>>2]|0;
 $46 = HEAP32[$__x3>>2]|0;
 HEAP32[$__x2>>2] = $46;
 HEAP32[$__x3>>2] = $45;
 $47 = HEAP32[$__c>>2]|0;
 $48 = HEAP32[$__x2>>2]|0;
 HEAP32[$6>>2] = 0;
 $49 = (($6) + 4|0);
 HEAP32[$49>>2] = 0;
 $50 = (($6) + 8|0);
 HEAP32[$50>>2] = $48;
 $51 = HEAP32[$__x1>>2]|0;
 HEAP32[$7>>2] = 0;
 $52 = (($7) + 4|0);
 HEAP32[$52>>2] = 0;
 $53 = (($7) + 8|0);
 HEAP32[$53>>2] = $51;
 __THREW__ = 0;
 $54 = (invoke_iii($47|0,($6|0),($7|0))|0);
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $67 = ___cxa_find_matching_catch()|0;
  $68 = tempRet0;
  $$4 = $68;$$45 = $67;
  ___resumeException($$45|0);
  // unreachable;
 }
 $57 = (($8) + 3)|0;
 if (!($54)) {
  $__r$0 = $57;
  STACKTOP = sp;return ($__r$0|0);
 }
 $58 = HEAP32[$__x1>>2]|0;
 $59 = HEAP32[$__x2>>2]|0;
 HEAP32[$__x1>>2] = $59;
 HEAP32[$__x2>>2] = $58;
 $60 = (($8) + 4)|0;
 $__r$0 = $60;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEvT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$27 = 0, $$sink$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$013 = 0;
 var $__j$012 = 0, $__j$012$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 36|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = (($__first) + 8|0);
 $5 = (($__first) + 4|0);
 (__ZNSt3__17__sort3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_T_($__first,$5,$4,$__comp)|0);
 $6 = (($__first) + 12|0);
 $7 = ($6|0)==($__last|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($0) + 4|0);
 $9 = (($0) + 8|0);
 $10 = (($1) + 4|0);
 $11 = (($1) + 8|0);
 $12 = (($2) + 4|0);
 $13 = (($2) + 8|0);
 $14 = (($3) + 4|0);
 $15 = (($3) + 8|0);
 $__i$013 = $6;$__j$012 = $4;
 L4: while(1) {
  $16 = HEAP32[$__comp>>2]|0;
  $17 = HEAP32[$__i$013>>2]|0;
  HEAP32[$0>>2] = 0;
  HEAP32[$8>>2] = 0;
  HEAP32[$9>>2] = $17;
  $18 = HEAP32[$__j$012>>2]|0;
  HEAP32[$1>>2] = 0;
  HEAP32[$10>>2] = 0;
  HEAP32[$11>>2] = $18;
  __THREW__ = 0;
  $19 = (invoke_iii($16|0,($0|0),($1|0))|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   label = 10;
   break;
  }
  if ($19) {
   $22 = HEAP32[$__i$013>>2]|0;
   $__j$1 = $__i$013;$__k$0 = $__j$012;
   while(1) {
    $23 = HEAP32[$__k$0>>2]|0;
    HEAP32[$__j$1>>2] = $23;
    $24 = ($__k$0|0)==($__first|0);
    if ($24) {
     $__k$0$lcssa = $__first;
     break;
    }
    $25 = HEAP32[$__comp>>2]|0;
    HEAP32[$2>>2] = 0;
    HEAP32[$12>>2] = 0;
    HEAP32[$13>>2] = $22;
    $26 = (($__k$0) + -4|0);
    $27 = HEAP32[$26>>2]|0;
    HEAP32[$3>>2] = 0;
    HEAP32[$14>>2] = 0;
    HEAP32[$15>>2] = $27;
    __THREW__ = 0;
    $28 = (invoke_iii($25|0,($2|0),($3|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     label = 11;
     break L4;
    }
    if ($28) {
     $__j$1$phi = $__k$0;$__k$0 = $26;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAP32[$__k$0$lcssa>>2] = $22;
  }
  $35 = (($__i$013) + 4|0);
  $36 = ($35|0)==($__last|0);
  if ($36) {
   label = 13;
   break;
  } else {
   $__j$012$phi = $__i$013;$__i$013 = $35;$__j$012 = $__j$012$phi;
  }
 }
 if ((label|0) == 10) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  $$27 = $31;$$sink$index2 = $32;
  ___resumeException($$27|0);
  // unreachable;
 }
 else if ((label|0) == 11) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  $$27 = $33;$$sink$index2 = $34;
  ___resumeException($$27|0);
  // unreachable;
 }
 else if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEbT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$02 = 0, $$3 = 0, $$39 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__count$018 = 0, $__count$1 = 0, $__i$019 = 0, $__j$017 = 0, $__j$017$phi = 0, $__j$1 = 0;
 var $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 60|0;
 $1 = sp;
 $2 = sp + 12|0;
 $3 = sp + 24|0;
 $4 = sp + 36|0;
 $5 = sp + 48|0;
 $6 = $__last;
 $7 = $__first;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 switch ($9|0) {
 case 5:  {
  $30 = (($__first) + 4|0);
  $31 = (($__first) + 8|0);
  $32 = (($__first) + 12|0);
  $33 = (($__last) + -4|0);
  (__ZNSt3__17__sort5IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_SC_SC_T_($__first,$30,$31,$32,$33,$__comp)|0);
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
  break;
 }
 case 4:  {
  $27 = (($__first) + 4|0);
  $28 = (($__first) + 8|0);
  $29 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_SC_T_($__first,$27,$28,$29,$__comp)|0);
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
  break;
 }
 case 3:  {
  $25 = (($__first) + 4|0);
  $26 = (($__last) + -4|0);
  (__ZNSt3__17__sort3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_T_($__first,$25,$26,$__comp)|0);
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
  break;
 }
 case 2:  {
  $10 = HEAP32[$__comp>>2]|0;
  $11 = (($__last) + -4|0);
  $12 = HEAP32[$11>>2]|0;
  HEAP32[$0>>2] = 0;
  $13 = (($0) + 4|0);
  HEAP32[$13>>2] = 0;
  $14 = (($0) + 8|0);
  HEAP32[$14>>2] = $12;
  $15 = HEAP32[$__first>>2]|0;
  HEAP32[$1>>2] = 0;
  $16 = (($1) + 4|0);
  HEAP32[$16>>2] = 0;
  $17 = (($1) + 8|0);
  HEAP32[$17>>2] = $15;
  __THREW__ = 0;
  $18 = (invoke_iii($10|0,($0|0),($1|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   $$3 = $24;$$39 = $23;
   ___resumeException($$39|0);
   // unreachable;
  }
  if (!($18)) {
   $$02 = 1;
   STACKTOP = sp;return ($$02|0);
  }
  $21 = HEAP32[$__first>>2]|0;
  $22 = HEAP32[$11>>2]|0;
  HEAP32[$__first>>2] = $22;
  HEAP32[$11>>2] = $21;
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
  break;
 }
 case 1: case 0:  {
  $$02 = 1;
  STACKTOP = sp;return ($$02|0);
  break;
 }
 default: {
  $34 = (($__first) + 8|0);
  $35 = (($__first) + 4|0);
  (__ZNSt3__17__sort3IRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEjT0_SC_SC_T_($__first,$35,$34,$__comp)|0);
  $36 = (($__first) + 12|0);
  $37 = ($36|0)==($__last|0);
  if ($37) {
   $$02 = 1;
   STACKTOP = sp;return ($$02|0);
  }
  $38 = (($2) + 4|0);
  $39 = (($2) + 8|0);
  $40 = (($3) + 4|0);
  $41 = (($3) + 8|0);
  $42 = (($4) + 4|0);
  $43 = (($4) + 8|0);
  $44 = (($5) + 4|0);
  $45 = (($5) + 8|0);
  $__count$018 = 0;$__i$019 = $36;$__j$017 = $34;
  L12: while(1) {
   $46 = HEAP32[$__comp>>2]|0;
   $47 = HEAP32[$__i$019>>2]|0;
   HEAP32[$2>>2] = 0;
   HEAP32[$38>>2] = 0;
   HEAP32[$39>>2] = $47;
   $48 = HEAP32[$__j$017>>2]|0;
   HEAP32[$3>>2] = 0;
   HEAP32[$40>>2] = 0;
   HEAP32[$41>>2] = $48;
   __THREW__ = 0;
   $49 = (invoke_iii($46|0,($2|0),($3|0))|0);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    label = 19;
    break;
   }
   if ($49) {
    $52 = HEAP32[$__i$019>>2]|0;
    $__j$1 = $__i$019;$__k$0 = $__j$017;
    while(1) {
     $53 = HEAP32[$__k$0>>2]|0;
     HEAP32[$__j$1>>2] = $53;
     $54 = ($__k$0|0)==($__first|0);
     if ($54) {
      $__k$0$lcssa = $__first;
      break;
     }
     $55 = HEAP32[$__comp>>2]|0;
     HEAP32[$4>>2] = 0;
     HEAP32[$42>>2] = 0;
     HEAP32[$43>>2] = $52;
     $56 = (($__k$0) + -4|0);
     $57 = HEAP32[$56>>2]|0;
     HEAP32[$5>>2] = 0;
     HEAP32[$44>>2] = 0;
     HEAP32[$45>>2] = $57;
     __THREW__ = 0;
     $58 = (invoke_iii($55|0,($4|0),($5|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 20;
      break L12;
     }
     if ($58) {
      $__j$1$phi = $__k$0;$__k$0 = $56;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $52;
    $61 = (($__count$018) + 1)|0;
    $62 = ($61|0)==(8);
    if ($62) {
     label = 18;
     break;
    } else {
     $__count$1 = $61;
    }
   } else {
    $__count$1 = $__count$018;
   }
   $69 = (($__i$019) + 4|0);
   $70 = ($69|0)==($__last|0);
   if ($70) {
    $$02 = 1;
    label = 22;
    break;
   } else {
    $__j$017$phi = $__i$019;$__count$018 = $__count$1;$__i$019 = $69;$__j$017 = $__j$017$phi;
   }
  }
  if ((label|0) == 18) {
   $63 = (($__i$019) + 4|0);
   $64 = ($63|0)==($__last|0);
   $$02 = $64;
   STACKTOP = sp;return ($$02|0);
  }
  else if ((label|0) == 19) {
   $65 = ___cxa_find_matching_catch()|0;
   $66 = tempRet0;
   $$3 = $66;$$39 = $65;
   ___resumeException($$39|0);
   // unreachable;
  }
  else if ((label|0) == 20) {
   $67 = ___cxa_find_matching_catch()|0;
   $68 = tempRet0;
   $$3 = $68;$$39 = $67;
   ___resumeException($$39|0);
   // unreachable;
  }
  else if ((label|0) == 22) {
   STACKTOP = sp;return ($$02|0);
  }
 }
 }
 return 0|0;
}
function __ZN2UI6CanvasD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$byval_copy19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $eh$lpad$body9$indexZ2D = 0, $scevgep$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i = 0, $uglygep$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy19 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 HEAP32[$this>>2] = ((874600 + 8|0));
 $4 = (($this) + 296|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($this) + 300|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($5|0);
  if (!($9)) {
   $__new_last2$i$i$i$i$i = $5;
   $scevgep$i$i$i$i$i = (($8) + -4|0);
   $10 = (0 - ($__new_last2$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($10)|0);
   $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
   $11 = $uglygep3$i$i$i$i$i >>> 2;
   $12 = $11 ^ -1;
   $scevgep4$i$i$i$i$i = (($8) + ($12<<2)|0);
   HEAP32[$7>>2] = $scevgep4$i$i$i$i$i;
  }
  __ZdlPv($5);
 }
 $13 = (($this) + 208|0);
 __THREW__ = 0;
 invoke_vi(3764,($13|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $49 = ___cxa_find_matching_catch()|0;
  $50 = tempRet0;
  $51 = (($this) + 200|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)>(-1);
  do {
   if ($53) {
    $54 = (($this) + 188|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($this) + 192|0);
    $57 = HEAP32[$56>>2]|0;
    HEAP32[$1>>2] = $57;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($55|0),($$byval_copy19|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if (!($59)) {
     HEAP32[$54>>2] = 0;
     break;
    }
    $69 = ___cxa_find_matching_catch(0|0)|0;
    $70 = tempRet0;
    $71 = (($this) + 184|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ($72|0)>(-1);
    if (!($73)) {
     $eh$lpad$body9$indexZ2D = $69;
     ___clang_call_terminate($eh$lpad$body9$indexZ2D);
     // unreachable;
    }
    $74 = (($this) + 172|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = (($this) + 176|0);
    $77 = HEAP32[$76>>2]|0;
    HEAP32[$0>>2] = $77;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($75|0),($$byval_copy19|0));
    $78 = __THREW__; __THREW__ = 0;
    $79 = $78&1;
    if ($79) {
     $80 = ___cxa_find_matching_catch(0|0)|0;
     $81 = tempRet0;
     ___clang_call_terminate($80);
     // unreachable;
    }
    HEAP32[$74>>2] = 0;
    $eh$lpad$body9$indexZ2D = $69;
    ___clang_call_terminate($eh$lpad$body9$indexZ2D);
    // unreachable;
   }
  } while(0);
  $60 = (($this) + 184|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ($61|0)>(-1);
  if ($62) {
   $63 = (($this) + 172|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = (($this) + 176|0);
   $66 = HEAP32[$65>>2]|0;
   HEAP32[$0>>2] = $66;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($64|0),($$byval_copy19|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if (!($68)) {
    HEAP32[$63>>2] = 0;
    $$1 = $50;$$12 = $49;
    label = 29;
   }
  } else {
   $$1 = $50;$$12 = $49;
   label = 29;
  }
 } else {
  $16 = (($this) + 200|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)>(-1);
  do {
   if ($18) {
    $19 = (($this) + 188|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($this) + 192|0);
    $22 = HEAP32[$21>>2]|0;
    HEAP32[$3>>2] = $22;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$3+0>>2]|0;
    invoke_vii(2591,($20|0),($$byval_copy19|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     HEAP32[$19>>2] = 0;
     label = 9;
     break;
    }
    $34 = ___cxa_find_matching_catch()|0;
    $35 = tempRet0;
    $36 = (($this) + 184|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)>(-1);
    if ($38) {
     $39 = (($this) + 172|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($this) + 176|0);
     $42 = HEAP32[$41>>2]|0;
     HEAP32[$0>>2] = $42;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_vii(2591,($40|0),($$byval_copy19|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      $45 = ___cxa_find_matching_catch(0|0)|0;
      $46 = tempRet0;
      ___clang_call_terminate($45);
      // unreachable;
     } else {
      HEAP32[$39>>2] = 0;
      $eh$lpad$body$index3Z2D = $35;$eh$lpad$body$indexZ2D = $34;
      break;
     }
    } else {
     $eh$lpad$body$index3Z2D = $35;$eh$lpad$body$indexZ2D = $34;
    }
   } else {
    label = 9;
   }
  } while(0);
  do {
   if ((label|0) == 9) {
    $25 = (($this) + 184|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)>(-1);
    if (!($27)) {
     __ZN9BehaviourD2Ev($this);
     STACKTOP = sp;return;
    }
    $28 = (($this) + 172|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($this) + 176|0);
    $31 = HEAP32[$30>>2]|0;
    HEAP32[$2>>2] = $31;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy19+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(2591,($29|0),($$byval_copy19|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     $47 = ___cxa_find_matching_catch()|0;
     $48 = tempRet0;
     $eh$lpad$body$index3Z2D = $48;$eh$lpad$body$indexZ2D = $47;
     break;
    }
    HEAP32[$28>>2] = 0;
    __ZN9BehaviourD2Ev($this);
    STACKTOP = sp;return;
   }
  } while(0);
  $$1 = $eh$lpad$body$index3Z2D;$$12 = $eh$lpad$body$indexZ2D;
  label = 29;
 }
 if ((label|0) == 29) {
  __THREW__ = 0;
  invoke_vi(3410,($this|0));
  $82 = __THREW__; __THREW__ = 0;
  $83 = $82&1;
  if (!($83)) {
   ___resumeException($$12|0);
   // unreachable;
  }
 }
 $84 = ___cxa_find_matching_catch(0|0)|0;
 $85 = tempRet0;
 $eh$lpad$body9$indexZ2D = $84;
 ___clang_call_terminate($eh$lpad$body9$indexZ2D);
 // unreachable;
}
function __ZN2UI11BatchOutputD2Ev($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy4 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = (($this) + 48|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(-1);
 do {
  if ($6) {
   $7 = (($this) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 40|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$3>>2] = $10;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
   invoke_vii(2591,($8|0),($$byval_copy4|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    HEAP32[$7>>2] = 0;
    label = 4;
    break;
   }
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = (($this) + 28|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($31|0)>(-1);
   if ($32) {
    $33 = (($this) + 16|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = (($this) + 20|0);
    $36 = HEAP32[$35>>2]|0;
    HEAP32[$1>>2] = $36;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
    invoke_vii(2591,($34|0),($$byval_copy4|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     $49 = ___cxa_find_matching_catch(0|0)|0;
     $50 = tempRet0;
     ___clang_call_terminate($49);
     // unreachable;
    } else {
     HEAP32[$33>>2] = 0;
     $$0 = $29;$$01 = $28;
     break;
    }
   } else {
    $$0 = $29;$$01 = $28;
   }
  } else {
   label = 4;
  }
 } while(0);
 L10: do {
  if ((label|0) == 4) {
   $13 = (($this) + 28|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)>(-1);
   do {
    if ($15) {
     $16 = (($this) + 16|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($this) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$2>>2] = $19;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_vii(2591,($17|0),($$byval_copy4|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      $39 = ___cxa_find_matching_catch()|0;
      $40 = tempRet0;
      $$0 = $40;$$01 = $39;
      break L10;
     } else {
      HEAP32[$16>>2] = 0;
      break;
     }
    }
   } while(0);
   $22 = (($this) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)>(-1);
   if (!($24)) {
    STACKTOP = sp;return;
   }
   $25 = HEAP32[$this>>2]|0;
   $26 = (($this) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   HEAP32[$0>>2] = $27;
   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($25,$$byval_copy4);
   HEAP32[$this>>2] = 0;
   STACKTOP = sp;return;
  }
 } while(0);
 $41 = (($this) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($42|0)>(-1);
 if (!($43)) {
  ___resumeException($$01|0);
  // unreachable;
 }
 $44 = HEAP32[$this>>2]|0;
 $45 = (($this) + 4|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$0>>2] = $46;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($44|0),($$byval_copy4|0));
 $47 = __THREW__; __THREW__ = 0;
 $48 = $47&1;
 if ($48) {
  $49 = ___cxa_find_matching_catch(0|0)|0;
  $50 = tempRet0;
  ___clang_call_terminate($49);
  // unreachable;
 }
 HEAP32[$this>>2] = 0;
 ___resumeException($$01|0);
 // unreachable;
}
function __ZN2UI13CanvasManager9AddCanvasEPNS_6CanvasE($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$byval_copy = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 HEAP32[$0>>2] = $node;
 $3 = (__ZNK2UI6Canvas13GetRenderModeEv($node)|0);
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   $5 = HEAP32[$this>>2]|0;
   $6 = (($this) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5|0)==($7|0);
   if ($8) {
    $22 = $7;
   } else {
    $9 = (($node) + 288|0);
    $10 = HEAP16[$9>>1]|0;
    $14 = $5;
    while(1) {
     $13 = HEAP32[$14>>2]|0;
     $15 = (($13) + 288|0);
     $16 = HEAP16[$15>>1]|0;
     $17 = ($16<<16>>16)<($10<<16>>16);
     $12 = (($14) + 4|0);
     if ($17) {
      break;
     }
     $11 = ($12|0)==($7|0);
     if ($11) {
      $22 = $7;
      break L1;
     } else {
      $14 = $12;
     }
    }
    HEAP32[$1>>2] = $14;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
    __ZNSt3__16vectorIPN2UI6CanvasENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($2,$this,$$byval_copy,$0);
    STACKTOP = sp;return;
   }
  } else {
   $$phi$trans$insert = (($this) + 4|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   $22 = $$pre;
  }
 } while(0);
 $18 = (($this) + 4|0);
 $19 = (($this) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($22|0)==($20|0);
 if (!($21)) {
  $23 = ($22|0)==(0|0);
  if ($23) {
   $25 = 0;
  } else {
   HEAP32[$22>>2] = $node;
   $$pre$i = HEAP32[$18>>2]|0;
   $25 = $$pre$i;
  }
  $24 = (($25) + 4|0);
  HEAP32[$18>>2] = $24;
  STACKTOP = sp;return;
 }
 $26 = HEAP32[$this>>2]|0;
 $27 = $22;
 $28 = $26;
 $29 = (($27) - ($28))|0;
 $30 = $29 >> 2;
 $31 = (($30) + 1)|0;
 $32 = ($31>>>0)>(1073741823);
 if ($32) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $33 = ($30>>>0)<(536870911);
 if ($33) {
  $34 = $29 >> 1;
  $35 = ($34>>>0)<($31>>>0);
  $36 = $35 ? $31 : $34;
  $37 = ($36|0)==(0);
  if ($37) {
   $$0$i3$i$i = 0;$41 = 0;
  } else {
   $$0$i2$i$i = $36;
   label = 16;
  }
 } else {
  $$0$i2$i$i = 1073741823;
  label = 16;
 }
 if ((label|0) == 16) {
  $38 = $$0$i2$i$i << 2;
  $39 = (__Znwj($38)|0);
  $$0$i3$i$i = $$0$i2$i$i;$41 = $39;
 }
 $40 = (($41) + ($30<<2)|0);
 $42 = (($41) + ($$0$i3$i$i<<2)|0);
 $43 = ($40|0)==(0|0);
 if (!($43)) {
  HEAP32[$40>>2] = $node;
 }
 $44 = (($41) + ($31<<2)|0);
 _memcpy(($41|0),($26|0),($29|0))|0;
 HEAP32[$this>>2] = $41;
 HEAP32[$18>>2] = $44;
 HEAP32[$19>>2] = $42;
 $45 = ($26|0)==(0|0);
 if ($45) {
  STACKTOP = sp;return;
 }
 __ZdlPv($26);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIPN2UI6CanvasENS_9allocatorIS3_EEE6insertENS_11__wrap_iterIPKS3_EERS8_($agg$result,$this,$__position,$__x) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__position = $__position|0;
 $__x = $__x|0;
 var $$ = 0, $$0$i11 = 0, $$0$i12 = 0, $$pre = 0, $$pre$i10 = 0, $$sum = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$01$i = 0, $__p$0 = 0, $__xr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$__position>>2]|0;
 $2 = $1;
 $3 = $0;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($0) + ($5<<2)|0);
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($8>>>0)<($10>>>0);
 if ($11) {
  $12 = ($6|0)==($8|0);
  if ($12) {
   $13 = ($6|0)==(0|0);
   if ($13) {
    $16 = 0;
   } else {
    $14 = HEAP32[$__x>>2]|0;
    HEAP32[$6>>2] = $14;
    $$pre = HEAP32[$7>>2]|0;
    $16 = $$pre;
   }
   $15 = (($16) + 4|0);
   HEAP32[$7>>2] = $15;
   $__p$0 = $6;
   HEAP32[$agg$result>>2] = $__p$0;
   STACKTOP = sp;return;
  }
  $$sum = (($5) + 1)|0;
  $17 = (($0) + ($$sum<<2)|0);
  $18 = $8;
  $19 = $17;
  $20 = (($18) - ($19))|0;
  $21 = $20 >> 2;
  $$sum15 = (($21) + ($5))|0;
  $22 = (($0) + ($$sum15<<2)|0);
  $23 = ($22>>>0)<($8>>>0);
  if ($23) {
   $25 = $8;$__i$01$i = $22;
   while(1) {
    $24 = ($25|0)==(0|0);
    if ($24) {
     $29 = 0;
    } else {
     $26 = HEAP32[$__i$01$i>>2]|0;
     HEAP32[$25>>2] = $26;
     $$pre$i10 = HEAP32[$7>>2]|0;
     $29 = $$pre$i10;
    }
    $27 = (($__i$01$i) + 4|0);
    $28 = (($29) + 4|0);
    HEAP32[$7>>2] = $28;
    $30 = ($27>>>0)<($8>>>0);
    if ($30) {
     $25 = $28;$__i$01$i = $27;
    } else {
     break;
    }
   }
  }
  $31 = (0 - ($21))|0;
  $32 = (($8) + ($31<<2)|0);
  _memmove(($32|0),($6|0),($20|0))|0;
  $33 = ($6>>>0)>($__x>>>0);
  if ($33) {
   $__xr$0 = $__x;
  } else {
   $34 = HEAP32[$7>>2]|0;
   $35 = ($34>>>0)>($__x>>>0);
   $36 = (($__x) + 4|0);
   $$ = $35 ? $36 : $__x;
   $__xr$0 = $$;
  }
  $37 = HEAP32[$__xr$0>>2]|0;
  HEAP32[$6>>2] = $37;
  $__p$0 = $6;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 $38 = $8;
 $39 = (($38) - ($3))|0;
 $40 = $39 >> 2;
 $41 = (($40) + 1)|0;
 $42 = ($41>>>0)>(1073741823);
 if ($42) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $43 = $10;
 $44 = (($43) - ($3))|0;
 $45 = $44 >> 2;
 $46 = ($45>>>0)<(536870911);
 if ($46) {
  $49 = $44 >> 1;
  $50 = ($49>>>0)<($41>>>0);
  $51 = $50 ? $41 : $49;
  $52 = $6;
  $53 = $4 >> 2;
  $54 = ($51|0)==(0);
  if ($54) {
   $$0$i12 = 0;$58 = 0;$59 = $53;$85 = $52;
  } else {
   $$0$i11 = $51;$100 = $53;$101 = $52;
   label = 18;
  }
 } else {
  $47 = $6;
  $48 = $4 >> 2;
  $$0$i11 = 1073741823;$100 = $48;$101 = $47;
  label = 18;
 }
 if ((label|0) == 18) {
  $55 = $$0$i11 << 2;
  $56 = (__Znwj($55)|0);
  $$0$i12 = $$0$i11;$58 = $56;$59 = $100;$85 = $101;
 }
 $57 = (($58) + ($59<<2)|0);
 $60 = (($58) + ($$0$i12<<2)|0);
 $61 = ($59|0)==($$0$i12|0);
 do {
  if ($61) {
   $62 = ($59|0)>(0);
   if ($62) {
    $63 = (($59) + 1)|0;
    $64 = (($63|0) / -2)&-1;
    $$sum14 = (($64) + ($59))|0;
    $65 = (($58) + ($$sum14<<2)|0);
    $78 = $65;$95 = $60;
    break;
   }
   $66 = $59 << 1;
   $67 = ($59|0)==(0);
   $68 = $67 ? 1 : $66;
   $69 = $68 << 2;
   __THREW__ = 0;
   $70 = (invoke_ii(2988,($69|0))|0);
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if (!($72)) {
    $73 = $68 >>> 2;
    $74 = (($70) + ($73<<2)|0);
    $75 = (($70) + ($68<<2)|0);
    $76 = ($58|0)==(0|0);
    if ($76) {
     $78 = $74;$95 = $75;
     break;
    }
    __ZdlPv($58);
    $78 = $74;$95 = $75;
    break;
   }
   $97 = ___cxa_find_matching_catch()|0;
   $98 = tempRet0;
   $99 = ($58|0)==(0|0);
   if ($99) {
    ___resumeException($97|0);
    // unreachable;
   }
   __ZdlPv($58);
   ___resumeException($97|0);
   // unreachable;
  } else {
   $78 = $57;$95 = $60;
  }
 } while(0);
 $77 = ($78|0)==(0|0);
 if ($77) {
  $81 = 0;
 } else {
  $79 = HEAP32[$__x>>2]|0;
  HEAP32[$78>>2] = $79;
  $81 = $78;
 }
 $80 = (($81) + 4|0);
 $82 = HEAP32[$this>>2]|0;
 $83 = $82;
 $84 = (($85) - ($83))|0;
 $86 = $84 >> 2;
 $87 = (0 - ($86))|0;
 $88 = (($78) + ($87<<2)|0);
 _memcpy(($88|0),($82|0),($84|0))|0;
 $89 = HEAP32[$7>>2]|0;
 $90 = $89;
 $91 = (($90) - ($85))|0;
 $92 = $91 >> 2;
 _memcpy(($80|0),($6|0),($91|0))|0;
 $$sum13 = (($92) + 1)|0;
 $93 = (($81) + ($$sum13<<2)|0);
 $94 = HEAP32[$this>>2]|0;
 HEAP32[$this>>2] = $88;
 HEAP32[$7>>2] = $93;
 HEAP32[$9>>2] = $95;
 $96 = ($94|0)==(0|0);
 if ($96) {
  $__p$0 = $78;
  HEAP32[$agg$result>>2] = $__p$0;
  STACKTOP = sp;return;
 }
 __ZdlPv($94);
 $__p$0 = $78;
 HEAP32[$agg$result>>2] = $__p$0;
 STACKTOP = sp;return;
}
function __ZN2UI13CanvasManager12RemoveCanvasEPNS_6CanvasE($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $$sum$i = 0, $$sum1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $7 = $0;
 }
 while(1) {
  $6 = HEAP32[$7>>2]|0;
  $8 = ($6|0)==($node|0);
  $5 = (($7) + 4|0);
  if ($8) {
   break;
  }
  $4 = ($5|0)==($2|0);
  if ($4) {
   label = 6;
   break;
  } else {
   $7 = $5;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
 $9 = $7;
 $10 = $0;
 $11 = (($9) - ($10))|0;
 $12 = $11 >> 2;
 $13 = (($0) + ($12<<2)|0);
 $$sum$i = (($12) + 1)|0;
 $14 = (($0) + ($$sum$i<<2)|0);
 $15 = $2;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = $17 >> 2;
 _memmove(($13|0),($14|0),($17|0))|0;
 $$sum1$i = (($18) + ($12))|0;
 $19 = (($0) + ($$sum1$i<<2)|0);
 $20 = HEAP32[$1>>2]|0;
 $21 = ($20|0)==($19|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i = $19;
 $scevgep$i$i$i = (($20) + -4|0);
 $22 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($22)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $23 = $uglygep3$i$i$i >>> 2;
 $24 = $23 ^ -1;
 $scevgep4$i$i$i = (($20) + ($24<<2)|0);
 HEAP32[$1>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __ZN2UI11CompareFuncERK8ListNodeINS_6CanvasEES4_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $this$tr$i = 0, $this$tr$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK2UI6Canvas13GetRenderModeEv($1)|0);
 $3 = (($b) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK2UI6Canvas13GetRenderModeEv($4)|0);
 $6 = ($2|0)==($5|0);
 if (!($6)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ((($2|0) == 1)) {
  $14 = HEAP32[$0>>2]|0;
  $this$tr$i1 = $14;
  while(1) {
   $15 = (($this$tr$i1) + 260|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    break;
   } else {
    $this$tr$i1 = $16;
   }
  }
  $18 = (($this$tr$i1) + 280|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = HEAP32[$3>>2]|0;
  $this$tr$i = $20;
  while(1) {
   $21 = (($this$tr$i) + 260|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    break;
   } else {
    $this$tr$i = $22;
   }
  }
  $24 = (($this$tr$i) + 280|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = $19 > $25;
  $$0 = $26;
  STACKTOP = sp;return ($$0|0);
 } else if ((($2|0) == 0)) {
  $7 = HEAP32[$0>>2]|0;
  $8 = (($7) + 288|0);
  $9 = HEAP16[$8>>1]|0;
  $10 = HEAP32[$3>>2]|0;
  $11 = (($10) + 288|0);
  $12 = HEAP16[$11>>1]|0;
  $13 = ($9<<16>>16)<($12<<16>>16);
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN2UI13CanvasManager8SortListEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = 2713;
 __ZNSt3__16__sortIRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEvT0_SC_T_($1,$3,$0);
 STACKTOP = sp;return;
}
function __ZN2UI13CanvasManager14RenderOverlaysEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $viewcoord = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $viewcoord = sp;
 $1 = sp + 16|0;
 $2 = (__Z12GetGfxDevicev()|0);
 $3 = (__Z16GetRenderManagerv()|0);
 $4 = (($3) + 56|0);
 __Z14RectfToRectIntRK5RectTIfE($viewcoord,$4);
 __Z22FlipScreenRectIfNeededRK9GfxDeviceR5RectTIiE($2,$viewcoord);
 $5 = HEAP32[$2>>2]|0;
 $6 = (($5) + 172|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($2,$viewcoord);
 $8 = HEAP32[652824>>2]|0;
 $9 = (($8) + 20|0);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,874968);
 $10 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = $10;
 __ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf($9,$1,Math_fround(8.0));
 $11 = HEAP32[$this>>2]|0;
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($11|0)==($13|0);
 if ($14) {
  STACKTOP = sp;return;
 } else {
  $16 = $11;
 }
 while(1) {
  $15 = HEAP32[$16>>2]|0;
  $17 = (__ZNK2UI6Canvas13GetRenderModeEv($15)|0);
  $18 = ($17|0)==(0);
  if ($18) {
   __ZN2UI6Canvas14RenderOverlaysEv($15);
  }
  $19 = (($16) + 4|0);
  $20 = HEAP32[$12>>2]|0;
  $21 = ($19|0)==($20|0);
  if ($21) {
   break;
  } else {
   $16 = $19;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI13CanvasManager30EmitScreenSpaceCamerasGeometryEv($this) {
 $this = $this|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $orderOffset = 0, $temp$0$i = 0, $this$tr$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 $orderOffset = sp + 16|0;
 $3 = HEAP32[652824>>2]|0;
 $4 = (($3) + 20|0);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,874968);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[$2>>2] = $5;
 __ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf($4,$2,Math_fround(4.0));
 HEAP16[$orderOffset>>1] = 0;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($this) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $11 = $6;
 while(1) {
  $10 = HEAP32[$11>>2]|0;
  $12 = (__ZNK2UI6Canvas13GetRenderModeEv($10)|0);
  $13 = ($12|0)==(1);
  if ($13) {
   $this$tr$i = $10;
   while(1) {
    $14 = (($this$tr$i) + 260|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     break;
    } else {
     $this$tr$i = $15;
    }
   }
   $17 = (($this$tr$i) + 36|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(0);
   if ($19) {
    $$0$i = 0;
   } else {
    HEAP32[$1>>2] = $18;
    $20 = HEAP32[560624>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     label = 14;
    } else {
     $22 = (($20) + 36|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($20) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($23|0)==($25|0);
     do {
      if ($26) {
       $27 = (($20) + 28|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = (($20) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = (($28) + ($30<<3)|0);
       $47 = $31;
      } else {
       __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($0,$20,$1);
       $32 = HEAP32[$0>>2]|0;
       $33 = ($32|0)==(-1);
       $34 = (($20) + 28|0);
       $35 = HEAP32[$34>>2]|0;
       if ($33) {
        $36 = (($20) + 32|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = (($35) + ($37<<3)|0);
        $47 = $38;
        break;
       } else {
        $39 = (($35) + ($32<<3)|0);
        $47 = $39;
        break;
       }
      }
     } while(0);
     $40 = HEAP32[560624>>2]|0;
     $41 = (($40) + 28|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($40) + 32|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + ($44<<3)|0);
     $46 = ($47|0)==($45|0);
     if ($46) {
      label = 14;
     } else {
      $48 = (($47) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       label = 14;
      } else {
       $temp$0$i = $49;
      }
     }
    }
    if ((label|0) == 14) {
     label = 0;
     $51 = (__Z31ReadObjectFromPersistentManageri($18)|0);
     $temp$0$i = $51;
    }
    $$0$i = $temp$0$i;
   }
   __ZN2UI6Canvas17EmitWorldGeometryEP6CameraRtb($10,$$0$i,$orderOffset,0);
  }
  $52 = (($11) + 4|0);
  $53 = HEAP32[$7>>2]|0;
  $54 = ($52|0)==($53|0);
  if ($54) {
   break;
  } else {
   $11 = $52;
  }
 }
 STACKTOP = sp;return;
}
function __ZN2UI23InitializeCanvasManagerEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628400>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,1,16,875024,172)|0);
 HEAP32[$2>>2] = 0;
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = 0;
 HEAP32[875032>>2] = $2;
 HEAP32[579424>>2] = 166;
 HEAP32[579432>>2] = 167;
 HEAP32[579440>>2] = 149;
 HEAP32[579448>>2] = 153;
 HEAP32[579456>>2] = 165;
 STACKTOP = sp;return;
}
function __ZZN2UI23InitializeCanvasManagerEvEN30CanvasManagerEmitWorldGeometry7ForwardEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $orderOffset$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $1 = sp;
 $orderOffset$i = sp + 8|0;
 $2 = HEAP32[875032>>2]|0;
 $3 = HEAP32[652824>>2]|0;
 $4 = (($3) + 20|0);
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,874968);
 $5 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = $5;
 __ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf($4,$1,Math_fround(4.0));
 HEAP16[$orderOffset$i>>1] = 0;
 $6 = HEAP32[$2>>2]|0;
 $7 = (($2) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  STACKTOP = sp;return;
 } else {
  $11 = $6;
 }
 while(1) {
  $10 = HEAP32[$11>>2]|0;
  $12 = (__ZNK2UI6Canvas13GetRenderModeEv($10)|0);
  $13 = ($12|0)==(2);
  if ($13) {
   __ZN2UI6Canvas17EmitWorldGeometryEP6CameraRtb($10,0,$orderOffset$i,0);
  }
  $14 = (($11) + 4|0);
  $15 = HEAP32[$7>>2]|0;
  $16 = ($14|0)==($15|0);
  if ($16) {
   break;
  } else {
   $11 = $14;
  }
 }
 STACKTOP = sp;return;
}
function __ZZN2UI23InitializeCanvasManagerEvEN42CanvasmanagerEmitScreenSpaceCameraGeometry7ForwardE_0v() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[875032>>2]|0;
 __ZN2UI13CanvasManager30EmitScreenSpaceCamerasGeometryEv($0);
 STACKTOP = sp;return;
}
function __ZZN2UI23InitializeCanvasManagerEvEN27CanvasManagerRenderOverlays7ForwardE_1v() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[875032>>2]|0;
 __ZN2UI13CanvasManager14RenderOverlaysEv($0);
 STACKTOP = sp;return;
}
function __ZZN2UI23InitializeCanvasManagerEvEN25UpdateCanvasRectTransform7ForwardE_2v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[875032>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $6 = $1;
 }
 while(1) {
  $5 = HEAP32[$6>>2]|0;
  __ZN2UI6Canvas25UpdateCanvasRectTransformEv($5);
  $7 = (($6) + 4|0);
  $8 = HEAP32[$2>>2]|0;
  $9 = ($7|0)==($8|0);
  if ($9) {
   break;
  } else {
   $6 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZZN2UI23InitializeCanvasManagerEvEN18WillRenderCanvases7ForwardE_3v() {
 var $$byval_copy = 0, $0 = 0, $willRender$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $$byval_copy = sp + 208|0;
 $willRender$i = sp;
 $0 = sp + 200|0;
 __ZN9Scripting9GetMethodEPKcS1_S1_S1_($0,637592,637608,874992,875000);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp($willRender$i,$$byval_copy);
 (__ZN19ScriptingInvocation6InvokeEv($willRender$i)|0);
 STACKTOP = sp;return;
}
function __ZN2UI20CleanupCanvasManagerEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[875032>>2]|0;
 $2 = HEAP32[628400>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$1>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($1) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==($4|0);
   if (!($8)) {
    $__new_last2$i$i$i$i$i$i$i$i = $4;
    $scevgep$i$i$i$i$i$i$i$i = (($7) + -4|0);
    $9 = (0 - ($__new_last2$i$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i$i) + ($9)|0);
    $uglygep3$i$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i$i;
    $10 = $uglygep3$i$i$i$i$i$i$i$i >>> 2;
    $11 = $10 ^ -1;
    $scevgep4$i$i$i$i$i$i$i$i = (($7) + ($11<<2)|0);
    HEAP32[$6>>2] = $scevgep4$i$i$i$i$i$i$i$i;
   }
   __ZdlPv($4);
  }
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[875032>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN2UI16GetCanvasManagerEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[875032>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN2UI25AddCanvasRendererToCanvasEPNS_12CanvasHandleERNS_10CanvasDataE($handle,$canvas) {
 $handle = $handle|0;
 $canvas = $canvas|0;
 var $$byval_copy3 = 0, $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy3 = sp + 4|0;
 $0 = sp;
 $1 = (($canvas) + 64|0);
 $2 = (($canvas) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($handle) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = (($canvas) + 80|0);
 $6 = (($canvas) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($handle) + 4|0);
 HEAP32[$8>>2] = $7;
 HEAP32[$handle>>2] = $canvas;
 $9 = HEAP32[$6>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[$6>>2] = $10;
 $11 = (($canvas) + 92|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 2147483647;
 $14 = ($10>>>0)>($13>>>0);
 if ($14) {
  $15 = $12 << 1;
  $16 = ($15|0)==(0);
  $17 = $16 ? 1 : $15;
  $18 = ($13>>>0)<($17>>>0);
  do {
   if ($18) {
    $19 = ($12|0)>(-1);
    if ($19) {
     HEAP32[$11>>2] = $17;
     $20 = HEAP32[$5>>2]|0;
     $21 = ($17*152)|0;
     $22 = (($canvas) + 84|0);
     $23 = HEAP32[$22>>2]|0;
     HEAP32[$0>>2] = $23;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $24 = (__Z16realloc_internalPvji10MemLabelIdiPKci($20,$21,4,$$byval_copy3,0,875040,370)|0);
     HEAP32[$5>>2] = $24;
     break;
    } else {
     $25 = ($17*152)|0;
     $26 = (($canvas) + 84|0);
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$0>>2] = $27;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($25,4,$$byval_copy3,0,875040,352)|0);
     $29 = HEAP32[$5>>2]|0;
     $30 = HEAP32[$6>>2]|0;
     $31 = ($30*152)|0;
     _memcpy(($28|0),($29|0),($31|0))|0;
     HEAP32[$11>>2] = $17;
     HEAP32[$5>>2] = $28;
     break;
    }
   }
  } while(0);
  $$pre$i = HEAP32[$6>>2]|0;
  $33 = $$pre$i;
 } else {
  $33 = $10;
 }
 $32 = (($33) + -1)|0;
 $34 = HEAP32[$5>>2]|0;
 $35 = ((($34) + (($32*152)|0)|0) + 148|0);
 HEAP8[$35>>0] = 0;
 $36 = HEAP32[$2>>2]|0;
 $37 = (($36) + 1)|0;
 HEAP32[$2>>2] = $37;
 $38 = (($canvas) + 76|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39 & 2147483647;
 $41 = ($37>>>0)>($40>>>0);
 if (!($41)) {
  $60 = $37;
  $59 = (($60) + -1)|0;
  $61 = HEAP32[$1>>2]|0;
  $62 = (($61) + ($59<<2)|0);
  HEAP32[$62>>2] = $handle;
  $63 = (($canvas) + 96|0);
  HEAP8[$63>>0] = 1;
  $64 = (($canvas) + 97|0);
  HEAP8[$64>>0] = 1;
  STACKTOP = sp;return;
 }
 $42 = $39 << 1;
 $43 = ($42|0)==(0);
 $44 = $43 ? 1 : $42;
 $45 = ($40>>>0)<($44>>>0);
 do {
  if ($45) {
   $46 = ($39|0)>(-1);
   if ($46) {
    HEAP32[$38>>2] = $44;
    $47 = HEAP32[$1>>2]|0;
    $48 = $44 << 2;
    $49 = (($canvas) + 68|0);
    $50 = HEAP32[$49>>2]|0;
    HEAP32[$0>>2] = $50;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $51 = (__Z16realloc_internalPvji10MemLabelIdiPKci($47,$48,4,$$byval_copy3,0,875040,370)|0);
    HEAP32[$1>>2] = $51;
    break;
   } else {
    $52 = $44 << 2;
    $53 = (($canvas) + 68|0);
    $54 = HEAP32[$53>>2]|0;
    HEAP32[$0>>2] = $54;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
    $55 = (__Z15malloc_internaljj10MemLabelIdiPKci($52,4,$$byval_copy3,0,875040,352)|0);
    $56 = HEAP32[$1>>2]|0;
    $57 = HEAP32[$2>>2]|0;
    $58 = $57 << 2;
    _memcpy(($55|0),($56|0),($58|0))|0;
    HEAP32[$38>>2] = $44;
    HEAP32[$1>>2] = $55;
    break;
   }
  }
 } while(0);
 $$pre$i$i = HEAP32[$2>>2]|0;
 $60 = $$pre$i$i;
 $59 = (($60) + -1)|0;
 $61 = HEAP32[$1>>2]|0;
 $62 = (($61) + ($59<<2)|0);
 HEAP32[$62>>2] = $handle;
 $63 = (($canvas) + 96|0);
 HEAP8[$63>>0] = 1;
 $64 = (($canvas) + 97|0);
 HEAP8[$64>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN2UI15ClearCanvasDataERNS_10CanvasDataE($canvasData) {
 $canvasData = $canvasData|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($canvasData) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  HEAP32[$0>>2] = 0;
  $16 = (($canvasData) + 88|0);
  HEAP32[$16>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($canvasData) + 64|0);
 $17 = $1;$i$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $15 = $17;
  } else {
   $8 = HEAP32[$6>>2]|0;
   $9 = ($8|0)==($canvasData|0);
   if ($9) {
    HEAP32[$6>>2] = 0;
    $10 = (($6) + 4|0);
    HEAP32[$10>>2] = -1;
    $11 = (($6) + 8|0);
    HEAP32[$11>>2] = -1;
    $12 = (($6) + 12|0);
    HEAP32[$12>>2] = -1;
    $$pre = HEAP32[$0>>2]|0;
    $15 = $$pre;
   } else {
    $15 = $17;
   }
  }
  $13 = (($i$01) + 1)|0;
  $14 = ($13|0)<($15|0);
  if ($14) {
   $17 = $15;$i$01 = $13;
  } else {
   break;
  }
 }
 HEAP32[$0>>2] = 0;
 $16 = (($canvasData) + 88|0);
 HEAP32[$16>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN2UI17DestroyCanvasDataERNS_10CanvasDataE($canvasData) {
 $canvasData = $canvasData|0;
 var $$byval_copy1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($canvasData) + 64|0);
 $2 = (($canvasData) + 72|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $31 = $3;$i$02 = 0;
  while(1) {
   $5 = HEAP32[$1>>2]|0;
   $6 = (($5) + ($i$02<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $16 = $31;
   } else {
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==($canvasData|0);
    if ($10) {
     HEAP32[$7>>2] = 0;
     $11 = (($7) + 4|0);
     HEAP32[$11>>2] = -1;
     $12 = (($7) + 8|0);
     HEAP32[$12>>2] = -1;
     $13 = (($7) + 12|0);
     HEAP32[$13>>2] = -1;
     $$pre = HEAP32[$2>>2]|0;
     $16 = $$pre;
    } else {
     $16 = $31;
    }
   }
   $14 = (($i$02) + 1)|0;
   $15 = ($14|0)<($16|0);
   if ($15) {
    $31 = $16;$i$02 = $14;
   } else {
    break;
   }
  }
 }
 $17 = (($canvasData) + 76|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)>(-1);
 if ($19) {
  $20 = HEAP32[$1>>2]|0;
  $21 = (($canvasData) + 68|0);
  $22 = HEAP32[$21>>2]|0;
  HEAP32[$0>>2] = $22;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($20,$$byval_copy1);
  HEAP32[$1>>2] = 0;
 }
 HEAP32[$2>>2] = 0;
 HEAP32[$17>>2] = 0;
 $23 = (($canvasData) + 92|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)>(-1);
 if (!($25)) {
  $30 = (($canvasData) + 88|0);
  HEAP32[$30>>2] = 0;
  HEAP32[$23>>2] = 0;
  STACKTOP = sp;return;
 }
 $26 = (($canvasData) + 80|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($canvasData) + 84|0);
 $29 = HEAP32[$28>>2]|0;
 HEAP32[$0>>2] = $29;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($27,$$byval_copy1);
 HEAP32[$26>>2] = 0;
 $30 = (($canvasData) + 88|0);
 HEAP32[$30>>2] = 0;
 HEAP32[$23>>2] = 0;
 STACKTOP = sp;return;
}
function __Z17RegisterModule_UIv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $i$01$i$i1 = 0;
 var $i$01$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i = 0;
 while(1) {
  $3 = ((($0) + ($i$01$i$i<<2)|0) + 64|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  $2 = (($i$01$i$i) + 1)|0;
  if ($5) {
   label = 4;
   break;
  }
  $1 = ($2|0)<(16);
  if ($1) {
   $i$01$i$i = $2;
  } else {
   break;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$3>>2] = 265;
 }
 $6 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i2 = 0;
 while(1) {
  $9 = (($6) + ($i$01$i$i2<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  $8 = (($i$01$i$i2) + 1)|0;
  if ($11) {
   label = 8;
   break;
  }
  $7 = ($8|0)<(16);
  if ($7) {
   $i$01$i$i2 = $8;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  HEAP32[$9>>2] = 266;
 }
 $12 = (__ZN13ModuleManager3GetEv()|0);
 $i$01$i$i1 = 0;
 while(1) {
  $15 = ((($12) + ($i$01$i$i1<<2)|0) + 128|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($16|0)==(0|0);
  $14 = (($i$01$i$i1) + 1)|0;
  if ($17) {
   break;
  }
  $13 = ($14|0)<(16);
  if ($13) {
   $i$01$i$i1 = $14;
  } else {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  STACKTOP = sp;return;
 }
 HEAP32[$15>>2] = 267;
 STACKTOP = sp;return;
}
function __ZL23RegisterModuleICalls_UIv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL19InitializeModule_UIv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL16CleanupModule_UIv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN4half8selftestEv() {
 var $$0$i$i = 0, $$off$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $e$01$i$i = 0, $e$1$i$i = 0, $exitcond$i = 0, $exitcond$i$i = 0, $i$01$i = 0, $i$01$i$i = 0, $m$02$i$i = 0, $m$1$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$01$i = 0;
 while(1) {
  $0 = $i$01$i >>> 15;
  $1 = $0 & 1;
  $2 = $i$01$i >>> 10;
  $3 = $2 & 31;
  $4 = $i$01$i & 1023;
  do {
   if ((($3|0) == 31)) {
    $12 = ($4|0)==(0);
    $13 = $1 << 31;
    $14 = $13 | 2139095040;
    if ($12) {
     $$0$i$i = $14;
    } else {
     $15 = $4 << 13;
     $16 = $14 | $15;
     $$0$i$i = $16;
    }
   } else if ((($3|0) == 0)) {
    $5 = ($4|0)==(0);
    if ($5) {
     $6 = $1 << 31;
     $$0$i$i = $6;
     break;
    } else {
     $e$01$i$i = 0;$m$02$i$i = $4;
    }
    while(1) {
     $7 = $m$02$i$i << 1;
     $8 = (($e$01$i$i) + -1)|0;
     $9 = $7 & 1024;
     $10 = ($9|0)==(0);
     if ($10) {
      $e$01$i$i = $8;$m$02$i$i = $7;
     } else {
      break;
     }
    }
    $11 = $7 & -1026;
    $e$1$i$i = $e$01$i$i;$m$1$i$i = $11;
    label = 9;
   } else {
    $e$1$i$i = $3;$m$1$i$i = $4;
    label = 9;
   }
  } while(0);
  if ((label|0) == 9) {
   label = 0;
   $17 = $m$1$i$i << 13;
   $18 = $1 << 31;
   $19 = $e$1$i$i << 23;
   $20 = (($19) + 939524096)|0;
   $21 = $20 | $18;
   $22 = $21 | $17;
   $$0$i$i = $22;
  }
  $23 = (875048 + ($i$01$i<<2)|0);
  HEAP32[$23>>2] = $$0$i$i;
  $24 = (($i$01$i) + 1)|0;
  $exitcond$i = ($24|0)==(65536);
  if ($exitcond$i) {
   $i$01$i$i = 0;
   break;
  } else {
   $i$01$i = $24;
  }
 }
 while(1) {
  $$off$i$i = (($i$01$i$i) + -113)|0;
  $25 = ($$off$i$i>>>0)>(28);
  if ($25) {
   $26 = (1137192 + ($i$01$i$i<<1)|0);
   HEAP16[$26>>1] = 0;
   $27 = $i$01$i$i | 256;
   $28 = (1137192 + ($27<<1)|0);
   HEAP16[$28>>1] = 0;
  } else {
   $29 = $i$01$i$i << 10;
   $30 = (($29) + -114688)|0;
   $31 = $30&65535;
   $32 = (1137192 + ($i$01$i$i<<1)|0);
   HEAP16[$32>>1] = $31;
   $33 = $30 | 32768;
   $34 = $33&65535;
   $35 = $i$01$i$i | 256;
   $36 = (1137192 + ($35<<1)|0);
   HEAP16[$36>>1] = $34;
  }
  $37 = (($i$01$i$i) + 1)|0;
  $exitcond$i$i = ($37|0)==(256);
  if ($exitcond$i$i) {
   break;
  } else {
   $i$01$i$i = $37;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN4half7convertEi($i) {
 $i = $i|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = Math_fround(0);
 var $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0), $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0);
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $e$0 = 0, $f$i = 0, $m$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $f$i = sp;
 $0 = $i >>> 16;
 $1 = $0 & 32768;
 $2 = $i >>> 23;
 $3 = $2 & 255;
 $4 = (($3) + -112)|0;
 $5 = $i & 8388607;
 $6 = ($4|0)<(1);
 if ($6) {
  $7 = ($4|0)<(-10);
  if ($7) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $8 = $5 | 8388608;
  $9 = (113 - ($3))|0;
  $10 = $8 >>> $9;
  $11 = $10 & 4096;
  $12 = ($11|0)==(0);
  $13 = (($10) + 8192)|0;
  $$ = $12 ? $10 : $13;
  $14 = $$ >>> 13;
  $15 = $14 | $1;
  $16 = $15&65535;
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 $17 = ($4|0)==(143);
 if ($17) {
  $18 = ($5|0)==(0);
  $19 = $1 | 31744;
  if ($18) {
   $20 = $19&65535;
   $$0 = $20;
   STACKTOP = sp;return ($$0|0);
  } else {
   $21 = $5 >>> 13;
   $22 = $19 | $21;
   $23 = $22&65535;
   $$0 = $23;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $24 = $i & 4096;
 $25 = ($24|0)==(0);
 if ($25) {
  $e$0 = $4;$m$1 = $5;
 } else {
  $26 = (($5) + 8192)|0;
  $27 = $26 & 8388608;
  $28 = ($27|0)==(0);
  $29 = (($3) + -111)|0;
  $$1 = $28 ? $4 : $29;
  $$2 = $28 ? $26 : 0;
  $e$0 = $$1;$m$1 = $$2;
 }
 $30 = ($e$0|0)>(30);
 if ($30) {
  HEAPF32[$f$i>>2] = Math_fround(1.0E+10);
  $31 = Math_fround(HEAPF32[$f$i>>2]);
  $32 = Math_fround(HEAPF32[$f$i>>2]);
  $33 = Math_fround($31 * $32);
  HEAPF32[$f$i>>2] = $33;
  $34 = Math_fround(HEAPF32[$f$i>>2]);
  $35 = Math_fround(HEAPF32[$f$i>>2]);
  $36 = Math_fround($34 * $35);
  HEAPF32[$f$i>>2] = $36;
  $37 = Math_fround(HEAPF32[$f$i>>2]);
  $38 = Math_fround(HEAPF32[$f$i>>2]);
  $39 = Math_fround($37 * $38);
  HEAPF32[$f$i>>2] = $39;
  $40 = Math_fround(HEAPF32[$f$i>>2]);
  $41 = Math_fround(HEAPF32[$f$i>>2]);
  $42 = Math_fround($40 * $41);
  HEAPF32[$f$i>>2] = $42;
  $43 = Math_fround(HEAPF32[$f$i>>2]);
  $44 = Math_fround(HEAPF32[$f$i>>2]);
  $45 = Math_fround($43 * $44);
  HEAPF32[$f$i>>2] = $45;
  $46 = Math_fround(HEAPF32[$f$i>>2]);
  $47 = Math_fround(HEAPF32[$f$i>>2]);
  $48 = Math_fround($46 * $47);
  HEAPF32[$f$i>>2] = $48;
  $49 = Math_fround(HEAPF32[$f$i>>2]);
  $50 = Math_fround(HEAPF32[$f$i>>2]);
  $51 = Math_fround($49 * $50);
  HEAPF32[$f$i>>2] = $51;
  $52 = Math_fround(HEAPF32[$f$i>>2]);
  $53 = Math_fround(HEAPF32[$f$i>>2]);
  $54 = Math_fround($52 * $53);
  HEAPF32[$f$i>>2] = $54;
  $55 = Math_fround(HEAPF32[$f$i>>2]);
  $56 = Math_fround(HEAPF32[$f$i>>2]);
  $57 = Math_fround($55 * $56);
  HEAPF32[$f$i>>2] = $57;
  $58 = Math_fround(HEAPF32[$f$i>>2]);
  $59 = Math_fround(HEAPF32[$f$i>>2]);
  $60 = Math_fround($58 * $59);
  HEAPF32[$f$i>>2] = $60;
  $61 = Math_fround(HEAPF32[$f$i>>2]);
  $62 = $1 | 31744;
  $63 = $62&65535;
  $$0 = $63;
  STACKTOP = sp;return ($$0|0);
 } else {
  $64 = $e$0 << 10;
  $65 = $64 | $1;
  $66 = $m$1 >>> 13;
  $67 = $65 | $66;
  $68 = $67&65535;
  $$0 = $68;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __GLOBAL__I_a21124() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN4half8selftestEv()|0);
 HEAP8[1138216>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN6prcore6BitmapC2EjjRKNS_11PixelFormatE($this,$w,$h,$pxf) {
 $this = $this|0;
 $w = $w|0;
 $h = $h|0;
 $pxf = $pxf|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6prcore7SurfaceC2Ev($this);
 HEAP32[$this>>2] = $w;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $h;
 $1 = HEAP32[$pxf>>2]|0;
 $2 = $1 >>> 3;
 $3 = $2 & 8191;
 $4 = Math_imul($3, $w)|0;
 $5 = (($this) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$pxf>>2]|0;
 $7 = (($this) + 12|0);
 HEAP32[$7>>2] = $6;
 $8 = (($pxf) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 16|0);
 HEAP32[$10>>2] = $9;
 $11 = (($pxf) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 20|0);
 HEAP32[$13>>2] = $12;
 $14 = (($pxf) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 24|0);
 HEAP32[$16>>2] = $15;
 $17 = (($pxf) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 28|0);
 HEAP32[$19>>2] = $18;
 $20 = (($this) + 32|0);
 $21 = (($pxf) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$20>>2] = $22;
 $23 = (($this) + 36|0);
 $24 = (($pxf) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 HEAP32[$23>>2] = $25;
 $26 = Math_imul($4, $h)|0;
 $27 = (($26) + ($3))|0;
 $28 = (__Znaj($27)|0);
 $29 = (($this) + 40|0);
 HEAP32[$29>>2] = $28;
 STACKTOP = sp;return;
}
function __ZN6prcore6BitmapD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __ZdaPv($1);
 }
 STACKTOP = sp;return;
}
function __ZN6prcore7Surface14BlitImageFloatERKS0_NS0_8BlitModeE($this,$source,$mode) {
 $this = $this|0;
 $source = $source|0;
 $mode = $mode|0;
 var $$0 = 0, $$01 = 0, $$off0 = 0, $$pre = 0, $$pre13 = 0, $$pre14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $mode$off = 0, $or$cond = 0, $phitmp$i$i = 0;
 var $phitmp$i$i3 = 0, $phitmp$i$i9 = 0, $source2 = 0, $sourceFloat = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $sourceFloat = sp + 44|0;
 $source2 = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$source>>2]|0;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($source) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($4|0)==($6|0);
  if ($7) {
   $$off0 = 0;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $mode$off = (($mode) + -1)|0;
  $8 = ($mode$off>>>0)<(2);
  $$off0 = $8;
 }
 $9 = (($source) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)<(0);
 if ($11) {
  if (!($$off0)) {
   __ZL26BlitIntegerToFloatInternalRN6prcore7SurfaceERKS0_($this,$source);
   STACKTOP = sp;return;
  }
  $12 = (($source) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($this) + 12|0);
  __ZN6prcore6BitmapC2EjjRKNS_11PixelFormatE($sourceFloat,$1,$13,$14);
  __THREW__ = 0;
  invoke_vii(3460,($sourceFloat|0),($source|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  L12: do {
   if (!($16)) {
    $17 = HEAP32[$14>>2]|0;
    $18 = $17 & 536870912;
    $19 = ($18|0)==(0);
    do {
     if ($19) {
      $26 = $17 & 1073741824;
      $27 = ($26|0)==(0);
      if (!($27)) {
       $28 = (($this) + 16|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($sourceFloat) + 16|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($29|0)==($31|0);
       if ($32) {
        $33 = (($this) + 20|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = (($sourceFloat) + 20|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = ($34|0)==($36|0);
        if ($37) {
         $38 = (($this) + 24|0);
         $39 = HEAP32[$38>>2]|0;
         $40 = (($sourceFloat) + 24|0);
         $41 = HEAP32[$40>>2]|0;
         $42 = ($39|0)==($41|0);
         if ($42) {
          $43 = (($this) + 28|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = (($sourceFloat) + 28|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = ($44|0)==($46|0);
          if ($47) {
           $48 = (($sourceFloat) + 12|0);
           $49 = HEAP32[$48>>2]|0;
           $phitmp$i$i = ($17|0)==($49|0);
           if ($phitmp$i$i) {
            __THREW__ = 0;
            invoke_viiiiiiii(21,(1138312|0),0,(1138304|0),489,1,0,0,(0|0));
            $52 = __THREW__; __THREW__ = 0;
            $53 = $52&1;
            if ($53) {
             break L12;
            } else {
             break;
            }
           }
          }
         }
        }
       }
       __THREW__ = 0;
       invoke_viiiiiiii(21,(1138224|0),0,(1138304|0),484,1,0,0,(0|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break L12;
       }
      }
     } else {
      __THREW__ = 0;
      invoke_vii(3461,($this|0),($sourceFloat|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break L12;
      }
     }
    } while(0);
    __ZN6prcore6BitmapD2Ev($sourceFloat);
    STACKTOP = sp;return;
   }
  } while(0);
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3765,($sourceFloat|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   $149 = ___cxa_find_matching_catch(0|0)|0;
   $150 = tempRet0;
   ___clang_call_terminate($149);
   // unreachable;
  } else {
   $$0 = $22;$$01 = $23;
   ___resumeException($$0|0);
   // unreachable;
  }
 }
 $54 = (($this) + 12|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)<(0);
 if ($56) {
  if (!($$off0)) {
   __ZL26BlitFloatToIntegerInternalRN6prcore7SurfaceERKS0_($this,$source);
   STACKTOP = sp;return;
  }
  $57 = (($this) + 4|0);
  $58 = HEAP32[$57>>2]|0;
  __ZN6prcore6BitmapC2EjjRKNS_11PixelFormatE($source2,$0,$58,$9);
  $59 = HEAP32[$9>>2]|0;
  $60 = $59 & 1073741824;
  $61 = ($60|0)==(0);
  do {
   if ($61) {
    label = 31;
   } else {
    $62 = (($source2) + 16|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($source) + 16|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($63|0)==($65|0);
    if ($66) {
     $67 = (($source2) + 20|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($source) + 20|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($68|0)==($70|0);
     if ($71) {
      $72 = (($source2) + 24|0);
      $73 = HEAP32[$72>>2]|0;
      $74 = (($source) + 24|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($73|0)==($75|0);
      if ($76) {
       $77 = (($source2) + 28|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = (($source) + 28|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = ($78|0)==($80|0);
       if ($81) {
        $82 = (($source2) + 12|0);
        $83 = HEAP32[$82>>2]|0;
        $phitmp$i$i3 = ($83|0)==($59|0);
        if ($phitmp$i$i3) {
         __THREW__ = 0;
         invoke_viiiiiiii(21,(1138312|0),0,(1138304|0),489,1,0,0,(0|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         } else {
          label = 31;
          break;
         }
        }
       }
      }
     }
    }
    __THREW__ = 0;
    invoke_viiiiiiii(21,(1138224|0),0,(1138304|0),484,1,0,0,(0|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     label = 31;
    }
   }
  } while(0);
  do {
   if ((label|0) == 31) {
    $92 = HEAP32[$9>>2]|0;
    $93 = $92 & 536870912;
    $94 = ($93|0)==(0);
    if (!($94)) {
     __THREW__ = 0;
     invoke_vii(3461,($source2|0),($source|0));
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3462,($this|0),($source2|0));
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if (!($98)) {
     __ZN6prcore6BitmapD2Ev($source2);
     STACKTOP = sp;return;
    }
   }
  } while(0);
  $88 = ___cxa_find_matching_catch()|0;
  $89 = tempRet0;
  __THREW__ = 0;
  invoke_vi(3765,($source2|0));
  $90 = __THREW__; __THREW__ = 0;
  $91 = $90&1;
  if ($91) {
   $149 = ___cxa_find_matching_catch(0|0)|0;
   $150 = tempRet0;
   ___clang_call_terminate($149);
   // unreachable;
  } else {
   $$0 = $88;$$01 = $89;
   ___resumeException($$0|0);
   // unreachable;
  }
 }
 $99 = $10 & 1073741824;
 $100 = ($99|0)!=(0);
 if (!($$off0)) {
  if ($100) {
   $135 = $55 & 1073741824;
   $136 = ($135|0)==(0);
   if ($136) {
    $138 = $55;
   } else {
    __Z13BlitCopyFloatI4halfS0_EvRN6prcore7SurfaceERKS2_($this,$source);
    $$pre13 = HEAP32[$54>>2]|0;
    $138 = $$pre13;
   }
   $137 = $138 & 536870912;
   $139 = ($137|0)==(0);
   if (!($139)) {
    __Z13BlitCopyFloatIf4halfEvRN6prcore7SurfaceERKS2_($this,$source);
   }
  }
  $140 = HEAP32[$9>>2]|0;
  $141 = $140 & 536870912;
  $142 = ($141|0)==(0);
  if ($142) {
   STACKTOP = sp;return;
  }
  $143 = HEAP32[$54>>2]|0;
  $144 = $143 & 1073741824;
  $145 = ($144|0)==(0);
  if ($145) {
   $147 = $143;
  } else {
   __Z13BlitCopyFloatI4halffEvRN6prcore7SurfaceERKS2_($this,$source);
   $$pre14 = HEAP32[$54>>2]|0;
   $147 = $$pre14;
  }
  $146 = $147 & 536870912;
  $148 = ($146|0)==(0);
  if ($148) {
   STACKTOP = sp;return;
  }
  __Z13BlitCopyFloatIffEvRN6prcore7SurfaceERKS1_($this,$source);
  STACKTOP = sp;return;
 }
 if ($100) {
  $101 = $55 & 1073741824;
  $102 = ($101|0)==(0);
  do {
   if (!($102)) {
    $103 = (($this) + 16|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = (($source) + 16|0);
    $106 = HEAP32[$105>>2]|0;
    $107 = ($104|0)==($106|0);
    if ($107) {
     $108 = (($this) + 20|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = (($source) + 20|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ($109|0)==($111|0);
     if ($112) {
      $113 = (($this) + 24|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = (($source) + 24|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = ($114|0)==($116|0);
      if ($117) {
       $118 = (($this) + 28|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = (($source) + 28|0);
       $121 = HEAP32[$120>>2]|0;
       $122 = ($119|0)==($121|0);
       $phitmp$i$i9 = ($55|0)==($10|0);
       $or$cond = $122 & $phitmp$i$i9;
       if ($or$cond) {
        __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1138312,0,1138304,489,1,0,0,0);
        break;
       }
      }
     }
    }
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1138224,0,1138304,484,1,0,0,0);
   }
  } while(0);
  $123 = HEAP32[$54>>2]|0;
  $124 = $123 & 536870912;
  $125 = ($124|0)==(0);
  if (!($125)) {
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1138224,0,1138304,484,1,0,0,0);
  }
 }
 $126 = HEAP32[$9>>2]|0;
 $127 = $126 & 536870912;
 $128 = ($127|0)==(0);
 if ($128) {
  STACKTOP = sp;return;
 }
 $129 = HEAP32[$54>>2]|0;
 $130 = $129 & 1073741824;
 $131 = ($130|0)==(0);
 if ($131) {
  $133 = $129;
 } else {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1138224,0,1138304,484,1,0,0,0);
  $$pre = HEAP32[$54>>2]|0;
  $133 = $$pre;
 }
 $132 = $133 & 536870912;
 $134 = ($132|0)==(0);
 if ($134) {
  STACKTOP = sp;return;
 }
 __ZL17BlitBilinearFloatIffEvRN6prcore7SurfaceERKS1_($this,$source);
 STACKTOP = sp;return;
}
function __ZL26BlitIntegerToFloatInternalRN6prcore7SurfaceERKS0_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$311 = 0, $$315 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $source2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $0 = sp + 184|0;
 $1 = sp;
 $2 = sp + 28|0;
 $3 = sp + 56|0;
 $4 = sp + 84|0;
 $source2 = sp + 112|0;
 $5 = sp + 156|0;
 $6 = (($dest) + 12|0);
 $7 = (($source) + 12|0);
 HEAP32[$0>>2] = -1879048160;
 $8 = (($0) + 4|0);
 HEAP32[$8>>2] = 16711680;
 $9 = (($0) + 8|0);
 HEAP32[$9>>2] = 65280;
 $10 = (($0) + 12|0);
 HEAP32[$10>>2] = 255;
 $11 = (($0) + 16|0);
 HEAP32[$11>>2] = -16777216;
 $12 = (($0) + 22|0);
 $13 = (($0) + 26|0);
 HEAP8[$13>>0] = 23;
 HEAP8[$12>>0] = 8;
 $14 = (($0) + 21|0);
 $15 = (($0) + 25|0);
 __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$14,$15);
 $16 = (($0) + 20|0);
 $17 = (($0) + 24|0);
 __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$16,$17);
 $18 = (($0) + 23|0);
 $19 = (($0) + 27|0);
 HEAP8[$19>>0] = 31;
 HEAP8[$18>>0] = 8;
 $20 = (($source) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$8>>2]|0;
 $23 = ($21|0)==($22|0);
 if ($23) {
  $24 = (($source) + 20|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$9>>2]|0;
  $27 = ($25|0)==($26|0);
  if ($27) {
   $28 = (($source) + 24|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$10>>2]|0;
   $31 = ($29|0)==($30|0);
   if ($31) {
    $32 = (($source) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$11>>2]|0;
    $35 = ($33|0)==($34|0);
    if ($35) {
     $36 = HEAP32[$7>>2]|0;
     $37 = HEAP32[$0>>2]|0;
     $38 = ($36|0)==($37|0);
     if (!($38)) {
      label = 6;
     }
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
  } else {
   label = 6;
  }
 } else {
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$1>>2] = -1879048160;
   $39 = (($1) + 4|0);
   HEAP32[$39>>2] = 65280;
   $40 = (($1) + 8|0);
   HEAP32[$40>>2] = 16711680;
   $41 = (($1) + 12|0);
   HEAP32[$41>>2] = -16777216;
   $42 = (($1) + 16|0);
   HEAP32[$42>>2] = 255;
   $43 = (($1) + 22|0);
   $44 = (($1) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$43,$44);
   $45 = (($1) + 21|0);
   $46 = (($1) + 25|0);
   HEAP8[$46>>0] = 23;
   HEAP8[$45>>0] = 8;
   $47 = (($1) + 20|0);
   $48 = (($1) + 24|0);
   HEAP8[$48>>0] = 31;
   HEAP8[$47>>0] = 8;
   $49 = (($1) + 23|0);
   $50 = (($1) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$49,$50);
   $51 = HEAP32[$20>>2]|0;
   $52 = HEAP32[$39>>2]|0;
   $53 = ($51|0)==($52|0);
   if ($53) {
    $54 = (($source) + 20|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$40>>2]|0;
    $57 = ($55|0)==($56|0);
    if ($57) {
     $58 = (($source) + 24|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = HEAP32[$41>>2]|0;
     $61 = ($59|0)==($60|0);
     if ($61) {
      $62 = (($source) + 28|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = HEAP32[$42>>2]|0;
      $65 = ($63|0)==($64|0);
      if ($65) {
       $66 = HEAP32[$7>>2]|0;
       $67 = HEAP32[$1>>2]|0;
       $68 = ($66|0)==($67|0);
       if ($68) {
        break;
       }
      }
     }
    }
   }
   HEAP32[$2>>2] = -1879048168;
   $69 = (($2) + 4|0);
   HEAP32[$69>>2] = 16711680;
   $70 = (($2) + 8|0);
   HEAP32[$70>>2] = 65280;
   $71 = (($2) + 12|0);
   HEAP32[$71>>2] = 255;
   $72 = (($2) + 16|0);
   HEAP32[$72>>2] = 0;
   $73 = (($2) + 22|0);
   $74 = (($2) + 26|0);
   HEAP8[$74>>0] = 23;
   HEAP8[$73>>0] = 8;
   $75 = (($2) + 21|0);
   $76 = (($2) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$75,$76);
   $77 = (($2) + 20|0);
   $78 = (($2) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$77,$78);
   $79 = (($2) + 23|0);
   $80 = (($2) + 27|0);
   HEAP8[$80>>0] = -1;
   HEAP8[$79>>0] = 0;
   $81 = HEAP32[$20>>2]|0;
   $82 = HEAP32[$69>>2]|0;
   $83 = ($81|0)==($82|0);
   if ($83) {
    $84 = (($source) + 20|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = HEAP32[$70>>2]|0;
    $87 = ($85|0)==($86|0);
    if ($87) {
     $88 = (($source) + 24|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = HEAP32[$71>>2]|0;
     $91 = ($89|0)==($90|0);
     if ($91) {
      $92 = (($source) + 28|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = HEAP32[$72>>2]|0;
      $95 = ($93|0)==($94|0);
      if ($95) {
       $96 = HEAP32[$7>>2]|0;
       $97 = HEAP32[$2>>2]|0;
       $98 = ($96|0)==($97|0);
       if ($98) {
        break;
       }
      }
     }
    }
   }
   HEAP32[$3>>2] = -1879048168;
   $99 = (($3) + 4|0);
   HEAP32[$99>>2] = 255;
   $100 = (($3) + 8|0);
   HEAP32[$100>>2] = 65280;
   $101 = (($3) + 12|0);
   HEAP32[$101>>2] = 16711680;
   $102 = (($3) + 16|0);
   HEAP32[$102>>2] = 0;
   $103 = (($3) + 22|0);
   $104 = (($3) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$103,$104);
   $105 = (($3) + 21|0);
   $106 = (($3) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$105,$106);
   $107 = (($3) + 20|0);
   $108 = (($3) + 24|0);
   HEAP8[$108>>0] = 23;
   HEAP8[$107>>0] = 8;
   $109 = (($3) + 23|0);
   $110 = (($3) + 27|0);
   HEAP8[$110>>0] = -1;
   HEAP8[$109>>0] = 0;
   $111 = HEAP32[$20>>2]|0;
   $112 = HEAP32[$99>>2]|0;
   $113 = ($111|0)==($112|0);
   if ($113) {
    $114 = (($source) + 20|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = HEAP32[$100>>2]|0;
    $117 = ($115|0)==($116|0);
    if ($117) {
     $118 = (($source) + 24|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = HEAP32[$101>>2]|0;
     $121 = ($119|0)==($120|0);
     if ($121) {
      $122 = (($source) + 28|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = HEAP32[$102>>2]|0;
      $125 = ($123|0)==($124|0);
      if ($125) {
       $126 = HEAP32[$7>>2]|0;
       $127 = HEAP32[$3>>2]|0;
       $128 = ($126|0)==($127|0);
       if ($128) {
        break;
       }
      }
     }
    }
   }
   HEAP32[$4>>2] = -2013265912;
   $129 = (($4) + 4|0);
   HEAP32[$129>>2] = 0;
   $130 = (($4) + 8|0);
   HEAP32[$130>>2] = 0;
   $131 = (($4) + 12|0);
   HEAP32[$131>>2] = 255;
   $132 = (($4) + 16|0);
   HEAP32[$132>>2] = 0;
   $133 = (($4) + 20|0);
   HEAP32[$133>>2] = 0;
   $134 = (($4) + 24|0);
   HEAP32[$134>>2] = 0;
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$133,$134);
   $135 = (($4) + 23|0);
   $136 = (($4) + 27|0);
   HEAP8[$136>>0] = -1;
   HEAP8[$135>>0] = 0;
   $137 = HEAP32[$20>>2]|0;
   $138 = HEAP32[$129>>2]|0;
   $139 = ($137|0)==($138|0);
   if ($139) {
    $140 = (($source) + 20|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = HEAP32[$130>>2]|0;
    $143 = ($141|0)==($142|0);
    if ($143) {
     $144 = (($source) + 24|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = HEAP32[$131>>2]|0;
     $147 = ($145|0)==($146|0);
     if ($147) {
      $148 = (($source) + 28|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = HEAP32[$132>>2]|0;
      $151 = ($149|0)==($150|0);
      if ($151) {
       $152 = HEAP32[$7>>2]|0;
       $153 = HEAP32[$4>>2]|0;
       $154 = ($152|0)==($153|0);
       if ($154) {
        break;
       }
      }
     }
    }
   }
   $160 = HEAP32[$source>>2]|0;
   $161 = (($source) + 4|0);
   $162 = HEAP32[$161>>2]|0;
   HEAP32[$5>>2] = -1879048160;
   $163 = (($5) + 4|0);
   HEAP32[$163>>2] = 16711680;
   $164 = (($5) + 8|0);
   HEAP32[$164>>2] = 65280;
   $165 = (($5) + 12|0);
   HEAP32[$165>>2] = 255;
   $166 = (($5) + 16|0);
   HEAP32[$166>>2] = -16777216;
   $167 = (($5) + 22|0);
   $168 = (($5) + 26|0);
   HEAP8[$168>>0] = 23;
   HEAP8[$167>>0] = 8;
   $169 = (($5) + 21|0);
   $170 = (($5) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$169,$170);
   $171 = (($5) + 20|0);
   $172 = (($5) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$171,$172);
   $173 = (($5) + 23|0);
   $174 = (($5) + 27|0);
   HEAP8[$174>>0] = 31;
   HEAP8[$173>>0] = 8;
   __THREW__ = 0;
   invoke_viiii(435,($source2|0),($160|0),($162|0),($5|0));
   $175 = __THREW__; __THREW__ = 0;
   $176 = $175&1;
   if ($176) {
    $182 = ___cxa_find_matching_catch()|0;
    $183 = tempRet0;
    $$311 = $183;$$315 = $182;
    ___resumeException($$315|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_viii(1737,($source2|0),($source|0),0);
   $177 = __THREW__; __THREW__ = 0;
   $178 = $177&1;
   do {
    if (!($178)) {
     $179 = HEAP32[$6>>2]|0;
     $180 = $179 & 536870912;
     $181 = ($180|0)==(0);
     if ($181) {
      $188 = $179 & 1073741824;
      $189 = ($188|0)==(0);
      if (!($189)) {
       __THREW__ = 0;
       invoke_vii(3463,($dest|0),($source2|0));
       $190 = __THREW__; __THREW__ = 0;
       $191 = $190&1;
       if ($191) {
        break;
       }
      }
     } else {
      __ZL18BlitIntegerToFloatIfEvRN6prcore7SurfaceERKS1_($dest,$source2);
     }
     __ZN6prcore6BitmapD2Ev($source2);
     STACKTOP = sp;return;
    }
   } while(0);
   $184 = ___cxa_find_matching_catch()|0;
   $185 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3765,($source2|0));
   $186 = __THREW__; __THREW__ = 0;
   $187 = $186&1;
   if ($187) {
    $192 = ___cxa_find_matching_catch(0|0)|0;
    $193 = tempRet0;
    ___clang_call_terminate($192);
    // unreachable;
   } else {
    $$311 = $185;$$315 = $184;
    ___resumeException($$315|0);
    // unreachable;
   }
  }
 } while(0);
 $155 = HEAP32[$6>>2]|0;
 $156 = $155 & 536870912;
 $157 = ($156|0)==(0);
 if (!($157)) {
  __ZL18BlitIntegerToFloatIfEvRN6prcore7SurfaceERKS1_($dest,$source);
  STACKTOP = sp;return;
 }
 $158 = $155 & 1073741824;
 $159 = ($158|0)==(0);
 if ($159) {
  STACKTOP = sp;return;
 }
 __ZL18BlitIntegerToFloatI4halfEvRN6prcore7SurfaceERKS2_($dest,$source);
 STACKTOP = sp;return;
}
function __ZL17BlitBilinearFloatIffEvRN6prcore7SurfaceERKS1_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$ = 0, $$1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = Math_fround(0);
 var $113 = Math_fround(0), $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = Math_fround(0), $13 = 0, $130 = 0;
 var $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0), $134 = 0, $135 = 0, $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0);
 var $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = 0;
 var $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = 0, $99 = 0, $count$01$i = 0, $dest$02$i = 0, $or$cond = 0, $phitmp$i = 0, $u$03$i = 0, $v$0 = 0;
 var $v$12 = 0, $vstep$0 = 0, $y$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($dest) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($source) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $5 = (($dest) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($source) + 20|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  if ($9) {
   $10 = (($dest) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($source) + 24|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11|0)==($13|0);
   if ($14) {
    $15 = (($dest) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($source) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($16|0)==($18|0);
    if ($19) {
     $20 = (($dest) + 12|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($source) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $phitmp$i = ($21|0)==($23|0);
     if ($phitmp$i) {
      $24 = $21 & 65528;
      $25 = ($24|0)==(128);
      if (!($25)) {
       __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1138312,0,1138304,489,1,0,0,0);
       STACKTOP = sp;return;
      }
      $26 = (($dest) + 40|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = HEAP32[$dest>>2]|0;
      $29 = HEAP32[$source>>2]|0;
      $30 = ($28>>>0)<($29>>>0);
      if ($30) {
       $31 = $29 << 16;
       $32 = (($31>>>0) / ($28>>>0))&-1;
       $33 = $32 >>> 1;
       $34 = (($33) + -32768)|0;
       $163 = $32;$170 = $34;
      } else {
       $35 = (($28) + -1)|0;
       $36 = ($35|0)!=(0);
       $$ = $36 ? $35 : 1;
       $37 = $29 << 16;
       $38 = (($37) + -65536)|0;
       $39 = (($38>>>0) / ($$>>>0))&-1;
       $163 = $39;$170 = 0;
      }
      $40 = (($dest) + 4|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($source) + 4|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = ($41>>>0)<($43>>>0);
      if ($44) {
       $45 = $43 << 16;
       $46 = (($45>>>0) / ($41>>>0))&-1;
       $47 = $46 >>> 1;
       $48 = (($47) + -32768)|0;
       $v$0 = $48;$vstep$0 = $46;
      } else {
       $49 = (($41) + -1)|0;
       $50 = ($49|0)!=(0);
       $$1 = $50 ? $49 : 1;
       $51 = $43 << 16;
       $52 = (($51) + -65536)|0;
       $53 = (($52>>>0) / ($$1>>>0))&-1;
       $v$0 = 0;$vstep$0 = $53;
      }
      $54 = (($source) + 40|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = (($43) + -1)|0;
      $57 = (($source) + 8|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = Math_imul($56, $58)|0;
      $60 = ($41|0)==(0);
      if ($60) {
       STACKTOP = sp;return;
      }
      $61 = ($28|0)==(0);
      $62 = (($dest) + 8|0);
      $63 = HEAP32[$62>>2]|0;
      $167 = $27;$v$12 = $v$0;$y$03 = 0;
      while(1) {
       $64 = $v$12 >>> 16;
       $65 = Math_imul($58, $64)|0;
       $66 = (($55) + ($65)|0);
       $$sum = (($65) + ($58))|0;
       $67 = (($55) + ($$sum)|0);
       $68 = (($41) + -1)|0;
       $69 = ($y$03|0)==($68|0);
       $70 = ($$sum|0)>($59|0);
       $or$cond = $69 & $70;
       $71 = $or$cond ? $66 : $67;
       $72 = $v$12 & 65535;
       $73 = (Math_fround(($72>>>0)));
       $74 = Math_fround($73 * Math_fround(1.52587890625E-5));
       $75 = Math_fround(Math_fround(1.0) - $74);
       if (!($61)) {
        $count$01$i = $28;$dest$02$i = $167;$u$03$i = $170;
        while(1) {
         $76 = (($count$01$i) + -1)|0;
         $77 = $u$03$i >>> 16;
         $78 = $77 << 2;
         $79 = $u$03$i & 65535;
         $80 = (Math_fround(($79>>>0)));
         $81 = Math_fround($80 * Math_fround(1.52587890625E-5));
         $82 = Math_fround(Math_fround(1.0) - $81);
         $83 = (($66) + ($78<<2)|0);
         $84 = Math_fround(HEAPF32[$83>>2]);
         $85 = Math_fround($84 * $82);
         $86 = (($78) + 4)|0;
         $87 = (($66) + ($86<<2)|0);
         $88 = Math_fround(HEAPF32[$87>>2]);
         $89 = Math_fround($81 * $88);
         $90 = Math_fround($85 + $89);
         $91 = (($71) + ($78<<2)|0);
         $92 = Math_fround(HEAPF32[$91>>2]);
         $93 = Math_fround($82 * $92);
         $94 = (($71) + ($86<<2)|0);
         $95 = Math_fround(HEAPF32[$94>>2]);
         $96 = Math_fround($81 * $95);
         $97 = Math_fround($93 + $96);
         $98 = $78 | 1;
         $99 = (($66) + ($98<<2)|0);
         $100 = Math_fround(HEAPF32[$99>>2]);
         $101 = Math_fround($82 * $100);
         $102 = (($78) + 5)|0;
         $103 = (($66) + ($102<<2)|0);
         $104 = Math_fround(HEAPF32[$103>>2]);
         $105 = Math_fround($81 * $104);
         $106 = Math_fround($101 + $105);
         $107 = (($71) + ($98<<2)|0);
         $108 = Math_fround(HEAPF32[$107>>2]);
         $109 = Math_fround($82 * $108);
         $110 = (($71) + ($102<<2)|0);
         $111 = Math_fround(HEAPF32[$110>>2]);
         $112 = Math_fround($81 * $111);
         $113 = Math_fround($109 + $112);
         $114 = $78 | 2;
         $115 = (($66) + ($114<<2)|0);
         $116 = Math_fround(HEAPF32[$115>>2]);
         $117 = Math_fround($82 * $116);
         $118 = (($78) + 6)|0;
         $119 = (($66) + ($118<<2)|0);
         $120 = Math_fround(HEAPF32[$119>>2]);
         $121 = Math_fround($81 * $120);
         $122 = Math_fround($117 + $121);
         $123 = (($71) + ($114<<2)|0);
         $124 = Math_fround(HEAPF32[$123>>2]);
         $125 = Math_fround($82 * $124);
         $126 = (($71) + ($118<<2)|0);
         $127 = Math_fround(HEAPF32[$126>>2]);
         $128 = Math_fround($81 * $127);
         $129 = Math_fround($125 + $128);
         $130 = $78 | 3;
         $131 = (($66) + ($130<<2)|0);
         $132 = Math_fround(HEAPF32[$131>>2]);
         $133 = Math_fround($82 * $132);
         $134 = (($78) + 7)|0;
         $135 = (($66) + ($134<<2)|0);
         $136 = Math_fround(HEAPF32[$135>>2]);
         $137 = Math_fround($81 * $136);
         $138 = Math_fround($133 + $137);
         $139 = (($71) + ($130<<2)|0);
         $140 = Math_fround(HEAPF32[$139>>2]);
         $141 = Math_fround($82 * $140);
         $142 = (($71) + ($134<<2)|0);
         $143 = Math_fround(HEAPF32[$142>>2]);
         $144 = Math_fround($81 * $143);
         $145 = Math_fround($141 + $144);
         $146 = Math_fround($75 * $90);
         $147 = Math_fround($74 * $97);
         $148 = Math_fround($146 + $147);
         HEAPF32[$dest$02$i>>2] = $148;
         $149 = Math_fround($75 * $106);
         $150 = Math_fround($74 * $113);
         $151 = Math_fround($149 + $150);
         $152 = (($dest$02$i) + 4|0);
         HEAPF32[$152>>2] = $151;
         $153 = Math_fround($75 * $122);
         $154 = Math_fround($74 * $129);
         $155 = Math_fround($153 + $154);
         $156 = (($dest$02$i) + 8|0);
         HEAPF32[$156>>2] = $155;
         $157 = Math_fround($75 * $138);
         $158 = Math_fround($74 * $145);
         $159 = Math_fround($157 + $158);
         $160 = (($dest$02$i) + 12|0);
         HEAPF32[$160>>2] = $159;
         $161 = (($dest$02$i) + 16|0);
         $162 = (($u$03$i) + ($163))|0;
         $164 = ($76|0)==(0);
         if ($164) {
          break;
         } else {
          $count$01$i = $76;$dest$02$i = $161;$u$03$i = $162;
         }
        }
       }
       $165 = (($v$12) + ($vstep$0))|0;
       $166 = (($167) + ($63)|0);
       $168 = (($y$03) + 1)|0;
       $169 = ($168>>>0)<($41>>>0);
       if ($169) {
        $167 = $166;$v$12 = $165;$y$03 = $168;
       } else {
        break;
       }
      }
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1138224,0,1138304,484,1,0,0,0);
 STACKTOP = sp;return;
}
function __ZL26BlitFloatToIntegerInternalRN6prcore7SurfaceERKS0_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$311 = 0, $$315 = 0, $$pre = 0, $$pre136 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $source3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $0 = sp + 184|0;
 $1 = sp;
 $2 = sp + 28|0;
 $3 = sp + 56|0;
 $4 = sp + 84|0;
 $source3 = sp + 112|0;
 $5 = sp + 156|0;
 $6 = (($dest) + 12|0);
 $7 = (($source) + 12|0);
 HEAP32[$0>>2] = -1879048160;
 $8 = (($0) + 4|0);
 HEAP32[$8>>2] = 16711680;
 $9 = (($0) + 8|0);
 HEAP32[$9>>2] = 65280;
 $10 = (($0) + 12|0);
 HEAP32[$10>>2] = 255;
 $11 = (($0) + 16|0);
 HEAP32[$11>>2] = -16777216;
 $12 = (($0) + 22|0);
 $13 = (($0) + 26|0);
 HEAP8[$13>>0] = 23;
 HEAP8[$12>>0] = 8;
 $14 = (($0) + 21|0);
 $15 = (($0) + 25|0);
 __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$14,$15);
 $16 = (($0) + 20|0);
 $17 = (($0) + 24|0);
 __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$16,$17);
 $18 = (($0) + 23|0);
 $19 = (($0) + 27|0);
 HEAP8[$19>>0] = 31;
 HEAP8[$18>>0] = 8;
 $20 = (($dest) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$8>>2]|0;
 $23 = ($21|0)==($22|0);
 if ($23) {
  $24 = (($dest) + 20|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = HEAP32[$9>>2]|0;
  $27 = ($25|0)==($26|0);
  if ($27) {
   $28 = (($dest) + 24|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = HEAP32[$10>>2]|0;
   $31 = ($29|0)==($30|0);
   if ($31) {
    $32 = (($dest) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$11>>2]|0;
    $35 = ($33|0)==($34|0);
    if ($35) {
     $36 = HEAP32[$6>>2]|0;
     $37 = HEAP32[$0>>2]|0;
     $38 = ($36|0)==($37|0);
     if (!($38)) {
      label = 6;
     }
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
  } else {
   label = 6;
  }
 } else {
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   HEAP32[$1>>2] = -1879048160;
   $39 = (($1) + 4|0);
   HEAP32[$39>>2] = 65280;
   $40 = (($1) + 8|0);
   HEAP32[$40>>2] = 16711680;
   $41 = (($1) + 12|0);
   HEAP32[$41>>2] = -16777216;
   $42 = (($1) + 16|0);
   HEAP32[$42>>2] = 255;
   $43 = (($1) + 22|0);
   $44 = (($1) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$43,$44);
   $45 = (($1) + 21|0);
   $46 = (($1) + 25|0);
   HEAP8[$46>>0] = 23;
   HEAP8[$45>>0] = 8;
   $47 = (($1) + 20|0);
   $48 = (($1) + 24|0);
   HEAP8[$48>>0] = 31;
   HEAP8[$47>>0] = 8;
   $49 = (($1) + 23|0);
   $50 = (($1) + 27|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$49,$50);
   $51 = HEAP32[$20>>2]|0;
   $52 = HEAP32[$39>>2]|0;
   $53 = ($51|0)==($52|0);
   if ($53) {
    $54 = (($dest) + 20|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$40>>2]|0;
    $57 = ($55|0)==($56|0);
    if ($57) {
     $58 = (($dest) + 24|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = HEAP32[$41>>2]|0;
     $61 = ($59|0)==($60|0);
     if ($61) {
      $62 = (($dest) + 28|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = HEAP32[$42>>2]|0;
      $65 = ($63|0)==($64|0);
      if ($65) {
       $66 = HEAP32[$6>>2]|0;
       $67 = HEAP32[$1>>2]|0;
       $68 = ($66|0)==($67|0);
       if ($68) {
        break;
       }
      }
     }
    }
   }
   HEAP32[$2>>2] = -1879048168;
   $69 = (($2) + 4|0);
   HEAP32[$69>>2] = 16711680;
   $70 = (($2) + 8|0);
   HEAP32[$70>>2] = 65280;
   $71 = (($2) + 12|0);
   HEAP32[$71>>2] = 255;
   $72 = (($2) + 16|0);
   HEAP32[$72>>2] = 0;
   $73 = (($2) + 22|0);
   $74 = (($2) + 26|0);
   HEAP8[$74>>0] = 23;
   HEAP8[$73>>0] = 8;
   $75 = (($2) + 21|0);
   $76 = (($2) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$75,$76);
   $77 = (($2) + 20|0);
   $78 = (($2) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$77,$78);
   $79 = (($2) + 23|0);
   $80 = (($2) + 27|0);
   HEAP8[$80>>0] = -1;
   HEAP8[$79>>0] = 0;
   $81 = HEAP32[$20>>2]|0;
   $82 = HEAP32[$69>>2]|0;
   $83 = ($81|0)==($82|0);
   if ($83) {
    $84 = (($dest) + 20|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = HEAP32[$70>>2]|0;
    $87 = ($85|0)==($86|0);
    if ($87) {
     $88 = (($dest) + 24|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = HEAP32[$71>>2]|0;
     $91 = ($89|0)==($90|0);
     if ($91) {
      $92 = (($dest) + 28|0);
      $93 = HEAP32[$92>>2]|0;
      $94 = HEAP32[$72>>2]|0;
      $95 = ($93|0)==($94|0);
      if ($95) {
       $96 = HEAP32[$6>>2]|0;
       $97 = HEAP32[$2>>2]|0;
       $98 = ($96|0)==($97|0);
       if ($98) {
        break;
       }
      }
     }
    }
   }
   HEAP32[$3>>2] = -1879048168;
   $99 = (($3) + 4|0);
   HEAP32[$99>>2] = 255;
   $100 = (($3) + 8|0);
   HEAP32[$100>>2] = 65280;
   $101 = (($3) + 12|0);
   HEAP32[$101>>2] = 16711680;
   $102 = (($3) + 16|0);
   HEAP32[$102>>2] = 0;
   $103 = (($3) + 22|0);
   $104 = (($3) + 26|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$103,$104);
   $105 = (($3) + 21|0);
   $106 = (($3) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$105,$106);
   $107 = (($3) + 20|0);
   $108 = (($3) + 24|0);
   HEAP8[$108>>0] = 23;
   HEAP8[$107>>0] = 8;
   $109 = (($3) + 23|0);
   $110 = (($3) + 27|0);
   HEAP8[$110>>0] = -1;
   HEAP8[$109>>0] = 0;
   $111 = HEAP32[$20>>2]|0;
   $112 = HEAP32[$99>>2]|0;
   $113 = ($111|0)==($112|0);
   if ($113) {
    $114 = (($dest) + 20|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = HEAP32[$100>>2]|0;
    $117 = ($115|0)==($116|0);
    if ($117) {
     $118 = (($dest) + 24|0);
     $119 = HEAP32[$118>>2]|0;
     $120 = HEAP32[$101>>2]|0;
     $121 = ($119|0)==($120|0);
     if ($121) {
      $122 = (($dest) + 28|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = HEAP32[$102>>2]|0;
      $125 = ($123|0)==($124|0);
      if ($125) {
       $126 = HEAP32[$6>>2]|0;
       $127 = HEAP32[$3>>2]|0;
       $128 = ($126|0)==($127|0);
       if ($128) {
        break;
       }
      }
     }
    }
   }
   HEAP32[$4>>2] = -2013265912;
   $129 = (($4) + 4|0);
   HEAP32[$129>>2] = 0;
   $130 = (($4) + 8|0);
   HEAP32[$130>>2] = 0;
   $131 = (($4) + 12|0);
   HEAP32[$131>>2] = 255;
   $132 = (($4) + 16|0);
   HEAP32[$132>>2] = 0;
   $133 = (($4) + 20|0);
   HEAP32[$133>>2] = 0;
   $134 = (($4) + 24|0);
   HEAP32[$134>>2] = 0;
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$133,$134);
   $135 = (($4) + 23|0);
   $136 = (($4) + 27|0);
   HEAP8[$136>>0] = -1;
   HEAP8[$135>>0] = 0;
   $137 = HEAP32[$20>>2]|0;
   $138 = HEAP32[$129>>2]|0;
   $139 = ($137|0)==($138|0);
   if ($139) {
    $140 = (($dest) + 20|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = HEAP32[$130>>2]|0;
    $143 = ($141|0)==($142|0);
    if ($143) {
     $144 = (($dest) + 24|0);
     $145 = HEAP32[$144>>2]|0;
     $146 = HEAP32[$131>>2]|0;
     $147 = ($145|0)==($146|0);
     if ($147) {
      $148 = (($dest) + 28|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = HEAP32[$132>>2]|0;
      $151 = ($149|0)==($150|0);
      if ($151) {
       $152 = HEAP32[$6>>2]|0;
       $153 = HEAP32[$4>>2]|0;
       $154 = ($152|0)==($153|0);
       if ($154) {
        break;
       }
      }
     }
    }
   }
   $161 = HEAP32[$dest>>2]|0;
   $162 = (($dest) + 4|0);
   $163 = HEAP32[$162>>2]|0;
   HEAP32[$5>>2] = -1879048160;
   $164 = (($5) + 4|0);
   HEAP32[$164>>2] = 16711680;
   $165 = (($5) + 8|0);
   HEAP32[$165>>2] = 65280;
   $166 = (($5) + 12|0);
   HEAP32[$166>>2] = 255;
   $167 = (($5) + 16|0);
   HEAP32[$167>>2] = -16777216;
   $168 = (($5) + 22|0);
   $169 = (($5) + 26|0);
   HEAP8[$169>>0] = 23;
   HEAP8[$168>>0] = 8;
   $170 = (($5) + 21|0);
   $171 = (($5) + 25|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,$170,$171);
   $172 = (($5) + 20|0);
   $173 = (($5) + 24|0);
   __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,$172,$173);
   $174 = (($5) + 23|0);
   $175 = (($5) + 27|0);
   HEAP8[$175>>0] = 31;
   HEAP8[$174>>0] = 8;
   __THREW__ = 0;
   invoke_viiii(435,($source3|0),($161|0),($163|0),($5|0));
   $176 = __THREW__; __THREW__ = 0;
   $177 = $176&1;
   if ($177) {
    $181 = ___cxa_find_matching_catch()|0;
    $182 = tempRet0;
    $$311 = $182;$$315 = $181;
    ___resumeException($$315|0);
    // unreachable;
   }
   $178 = HEAP32[$7>>2]|0;
   $179 = $178 & 1073741824;
   $180 = ($179|0)==(0);
   if ($180) {
    $188 = $178;
   } else {
    __ZL18BlitFloatToIntegerI4halfEvRN6prcore7SurfaceERKS2_($source3,$source);
    $$pre136 = HEAP32[$7>>2]|0;
    $188 = $$pre136;
   }
   $187 = $188 & 536870912;
   $189 = ($187|0)==(0);
   if (!($189)) {
    __ZL18BlitFloatToIntegerIfEvRN6prcore7SurfaceERKS1_($source3,$source);
   }
   __THREW__ = 0;
   invoke_viii(1737,($dest|0),($source3|0),0);
   $190 = __THREW__; __THREW__ = 0;
   $191 = $190&1;
   if (!($191)) {
    __ZN6prcore6BitmapD2Ev($source3);
    STACKTOP = sp;return;
   }
   $183 = ___cxa_find_matching_catch()|0;
   $184 = tempRet0;
   __THREW__ = 0;
   invoke_vi(3765,($source3|0));
   $185 = __THREW__; __THREW__ = 0;
   $186 = $185&1;
   if ($186) {
    $192 = ___cxa_find_matching_catch(0|0)|0;
    $193 = tempRet0;
    ___clang_call_terminate($192);
    // unreachable;
   } else {
    $$311 = $184;$$315 = $183;
    ___resumeException($$315|0);
    // unreachable;
   }
  }
 } while(0);
 $155 = HEAP32[$7>>2]|0;
 $156 = $155 & 1073741824;
 $157 = ($156|0)==(0);
 if ($157) {
  $159 = $155;
 } else {
  __ZL18BlitFloatToIntegerI4halfEvRN6prcore7SurfaceERKS2_($dest,$source);
  $$pre = HEAP32[$7>>2]|0;
  $159 = $$pre;
 }
 $158 = $159 & 536870912;
 $160 = ($158|0)==(0);
 if ($160) {
  STACKTOP = sp;return;
 }
 __ZL18BlitFloatToIntegerIfEvRN6prcore7SurfaceERKS1_($dest,$source);
 STACKTOP = sp;return;
}
function __Z13BlitCopyFloatI4halfS0_EvRN6prcore7SurfaceERKS2_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$04$i = 0, $$04$i136 = 0, $$04$i145 = 0, $$04$i18 = 0, $$04$i27 = 0, $$04$i44 = 0, $$04$i53 = 0, $$04$i62 = 0, $$04$i70 = 0, $$04$i79 = 0, $$04$i88 = 0, $$04$i9 = 0, $$06$i = 0, $$06$i156 = 0, $$06$i168 = 0, $$06$i180 = 0, $$06$i192 = 0, $$06$i204 = 0, $$06$i216 = 0, $$06$i226 = 0;
 var $$06$i237 = 0, $$06$i248 = 0, $$06$i259 = 0, $$06$i270 = 0, $$1 = 0, $$11$i = 0, $$11$i11 = 0, $$11$i138 = 0, $$11$i147 = 0, $$11$i20 = 0, $$11$i29 = 0, $$11$i46 = 0, $$11$i55 = 0, $$11$i64 = 0, $$11$i72 = 0, $$11$i81 = 0, $$11$i90 = 0, $$13$i = 0, $$13$i159 = 0, $$13$i171 = 0;
 var $$13$i183 = 0, $$13$i195 = 0, $$13$i207 = 0, $$13$i218 = 0, $$13$i228 = 0, $$13$i239 = 0, $$13$i250 = 0, $$13$i261 = 0, $$13$i272 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$in$i = 0, $$in$i111 = 0, $$in$i34 = 0, $$in$i94 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0);
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0);
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = Math_fround(0), $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = Math_fround(0), $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0$i = Math_fround(0), $a$0$i104 = Math_fround(0), $a$0$i128 = Math_fround(0), $a$0$i37 = Math_fround(0), $a0$0 = 0, $a0$0$be$i = 0, $a0$0$be$i108 = 0, $a0$0$be$i130 = 0, $a0$0$be$i38 = 0, $a0$04$i = 0;
 var $a0$04$i116 = 0, $a0$04$i35 = 0, $a0$04$i97 = 0, $a1$0 = 0, $a1$06$i = 0, $a1$06$i95 = 0, $a1$08$i = 0, $a1$08$i112 = 0, $a1$1$i = 0, $a1$1$i103 = 0, $a1$1$i127 = 0, $a1$1$i36 = 0, $b$0$i = Math_fround(0), $b$0$i126 = Math_fround(0), $b0$03$i = 0, $b0$03$i98 = 0, $b0$1$i = 0, $b0$1$i107 = 0, $b1$07$i = 0, $b1$07$i113 = 0;
 var $b1$1$i = 0, $b1$1$i125 = 0, $d$0311 = 0, $d$05$i = 0, $d$05$i135 = 0, $d$05$i144 = 0, $d$05$i17 = 0, $d$05$i26 = 0, $d$05$i43 = 0, $d$05$i52 = 0, $d$05$i61 = 0, $d$05$i69 = 0, $d$05$i78 = 0, $d$05$i8 = 0, $d$05$i87 = 0, $d$07$i = 0, $d$07$i155 = 0, $d$07$i167 = 0, $d$07$i179 = 0, $d$07$i191 = 0;
 var $d$07$i203 = 0, $d$07$i215 = 0, $d$07$i225 = 0, $d$07$i236 = 0, $d$07$i247 = 0, $d$07$i258 = 0, $d$07$i269 = 0, $d$12$i = 0, $d$12$i10 = 0, $d$12$i137 = 0, $d$12$i146 = 0, $d$12$i19 = 0, $d$12$i28 = 0, $d$12$i45 = 0, $d$12$i54 = 0, $d$12$i63 = 0, $d$12$i71 = 0, $d$12$i80 = 0, $d$12$i89 = 0, $d$14$i = 0;
 var $d$14$i158 = 0, $d$14$i170 = 0, $d$14$i182 = 0, $d$14$i194 = 0, $d$14$i206 = 0, $d$14$i217 = 0, $d$14$i227 = 0, $d$14$i238 = 0, $d$14$i249 = 0, $d$14$i260 = 0, $d$14$i271 = 0, $exitcond = 0, $g$0$i = Math_fround(0), $g$0$i123 = Math_fround(0), $g0$0 = 0, $g0$02$i = 0, $g0$02$i99 = 0, $g0$1$i = 0, $g0$1$i106 = 0, $g1$0 = 0;
 var $g1$06$i = 0, $g1$06$i114 = 0, $g1$1$i = 0, $g1$1$i122 = 0, $i$0$i = Math_fround(0), $i$0$i102 = Math_fround(0), $i0$03$i = 0, $i0$03$i117 = 0, $i0$1$i = 0, $i0$1$i129 = 0, $i1$05$i = 0, $i1$05$i96 = 0, $i1$1$i = 0, $i1$1$i101 = 0, $phitmp = 0, $phitmp$i = Math_fround(0), $phitmp$i124 = Math_fround(0), $phitmp1$i = Math_fround(0), $phitmp1$i121 = Math_fround(0), $phitmp2$i = Math_fround(0);
 var $phitmp2$i118 = Math_fround(0), $r$0$i = Math_fround(0), $r$0$i120 = Math_fround(0), $r0$01$i = 0, $r0$01$i100 = 0, $r0$1$i = 0, $r0$1$i105 = 0, $r1$05$i = 0, $r1$05$i115 = 0, $r1$1$i = 0, $r1$1$i119 = 0, $s$0310 = 0, $s$06$i = 0, $s$06$i134 = 0, $s$06$i143 = 0, $s$06$i16 = 0, $s$06$i25 = 0, $s$06$i42 = 0, $s$06$i51 = 0, $s$06$i60 = 0;
 var $s$06$i68 = 0, $s$06$i7 = 0, $s$06$i77 = 0, $s$06$i86 = 0, $s$08$i = 0, $s$08$i154 = 0, $s$08$i166 = 0, $s$08$i178 = 0, $s$08$i190 = 0, $s$08$i202 = 0, $s$08$i214 = 0, $s$08$i224 = 0, $s$08$i235 = 0, $s$08$i246 = 0, $s$08$i257 = 0, $s$08$i268 = 0, $y$0309 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$dest>>2]|0;
 $1 = (($dest) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($dest) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($source) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4>>>0) / ($0>>>0))&-1;
 $8 = $7 >>> 1;
 $9 = HEAP32[$source>>2]|0;
 $10 = (($6>>>0) / ($9>>>0))&-1;
 $11 = $10 >>> 1;
 $12 = (($dest) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 27;
 $15 = $14 & 2;
 $16 = (($source) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 >>> 28;
 $19 = $18 & 1;
 $20 = $19 | $15;
 $21 = ($2|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($source) + 40|0);
 $23 = (($dest) + 40|0);
 $24 = HEAP32[$22>>2]|0;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($dest) + 38|0);
 $27 = (($dest) + 37|0);
 $28 = (($dest) + 36|0);
 $29 = (($dest) + 39|0);
 $30 = (($dest) + 16|0);
 $31 = (($dest) + 20|0);
 $32 = (($dest) + 24|0);
 $33 = (($dest) + 28|0);
 $34 = (($source) + 38|0);
 $35 = (($source) + 37|0);
 $36 = (($source) + 36|0);
 $37 = (($source) + 39|0);
 $38 = (($source) + 16|0);
 $39 = (($source) + 20|0);
 $40 = (($source) + 24|0);
 $41 = (($source) + 28|0);
 $42 = ($0|0)==(0);
 $84 = $13;$d$0311 = $25;$s$0310 = $24;$y$0309 = 1;
 while(1) {
  $43 = HEAP8[$26>>0]|0;
  $44 = $43&255;
  $45 = (($d$0311) + ($44<<1)|0);
  $46 = HEAP8[$27>>0]|0;
  $47 = $46&255;
  $48 = (($d$0311) + ($47<<1)|0);
  $49 = HEAP8[$28>>0]|0;
  $50 = $49&255;
  $51 = (($d$0311) + ($50<<1)|0);
  $52 = HEAP8[$29>>0]|0;
  $53 = $52&255;
  $54 = (($d$0311) + ($53<<1)|0);
  $55 = HEAP32[$30>>2]|0;
  $56 = ($55|0)==(0);
  $$1 = $56 ? 0 : $45;
  $57 = HEAP32[$31>>2]|0;
  $58 = ($57|0)==(0);
  $g0$0 = $58 ? 0 : $48;
  $59 = HEAP32[$32>>2]|0;
  $60 = ($59|0)==(0);
  $$2 = $60 ? 0 : $51;
  $61 = HEAP32[$33>>2]|0;
  $62 = ($61|0)==(0);
  $a0$0 = $62 ? 0 : $54;
  $63 = HEAP8[$34>>0]|0;
  $64 = $63&255;
  $65 = (($s$0310) + ($64<<1)|0);
  $66 = HEAP8[$35>>0]|0;
  $67 = $66&255;
  $68 = (($s$0310) + ($67<<1)|0);
  $69 = HEAP8[$36>>0]|0;
  $70 = $69&255;
  $71 = (($s$0310) + ($70<<1)|0);
  $72 = HEAP8[$37>>0]|0;
  $73 = $72&255;
  $74 = (($s$0310) + ($73<<1)|0);
  $75 = HEAP32[$38>>2]|0;
  $76 = ($75|0)==(0);
  $$3 = $76 ? 0 : $65;
  $77 = HEAP32[$39>>2]|0;
  $78 = ($77|0)==(0);
  $g1$0 = $78 ? 0 : $68;
  $79 = HEAP32[$40>>2]|0;
  $80 = ($79|0)==(0);
  $$4 = $80 ? 0 : $71;
  $81 = HEAP32[$41>>2]|0;
  $82 = ($81|0)==(0);
  $a1$0 = $82 ? 0 : $74;
  $83 = $84 & 1073741824;
  $85 = ($83|0)==(0);
  L6: do {
   if (!($85)) {
    $86 = HEAP32[$16>>2]|0;
    $87 = $86 & 1073741824;
    $88 = ($87|0)==(0);
    L8: do {
     if (!($88)) {
      if ((($20|0) == 0)) {
       $89 = ($$2|0)==(0|0);
       L12: do {
        if (!($89)) {
         $90 = ($$4|0)==(0|0);
         if (!($90)) {
          if ($42) {
           break;
          } else {
           $$06$i270 = $0;$d$07$i269 = $$2;$s$08$i268 = $$4;
          }
          while(1) {
           $91 = (($$06$i270) + -1)|0;
           $92 = HEAP16[$s$08$i268>>1]|0;
           HEAP16[$d$07$i269>>1] = $92;
           $93 = (($d$07$i269) + ($8<<1)|0);
           $94 = (($s$08$i268) + ($11<<1)|0);
           $95 = ($91|0)==(0);
           if ($95) {
            break L12;
           } else {
            $$06$i270 = $91;$d$07$i269 = $93;$s$08$i268 = $94;
           }
          }
         }
         if (!($42)) {
          $$13$i272 = $0;$d$14$i271 = $$2;
          while(1) {
           $96 = (($$13$i272) + -1)|0;
           $97 = (1137192 + 254|0);
           $98 = HEAP16[$97>>1]|0;
           $99 = ($98<<16>>16)==(0);
           if ($99) {
            $100 = (__ZN4half7convertEi(1065353216)|0);
            $101 = $100;
           } else {
            $101 = $98;
           }
           HEAP16[$d$14$i271>>1] = $101;
           $102 = ($96|0)==(0);
           if ($102) {
            break L12;
           }
           $103 = (($d$14$i271) + ($8<<1)|0);
           $$13$i272 = $96;$d$14$i271 = $103;
          }
         }
        }
       } while(0);
       $104 = ($a0$0|0)==(0|0);
       if ($104) {
        break;
       }
       $105 = ($a1$0|0)==(0|0);
       if (!($105)) {
        if ($42) {
         break;
        } else {
         $$06$i259 = $0;$d$07$i258 = $a0$0;$s$08$i257 = $a1$0;
        }
        while(1) {
         $106 = (($$06$i259) + -1)|0;
         $107 = HEAP16[$s$08$i257>>1]|0;
         HEAP16[$d$07$i258>>1] = $107;
         $108 = (($d$07$i258) + ($8<<1)|0);
         $109 = (($s$08$i257) + ($11<<1)|0);
         $110 = ($106|0)==(0);
         if ($110) {
          break L8;
         } else {
          $$06$i259 = $106;$d$07$i258 = $108;$s$08$i257 = $109;
         }
        }
       }
       if ($42) {
        break;
       } else {
        $$13$i261 = $0;$d$14$i260 = $a0$0;
       }
       while(1) {
        $111 = (($$13$i261) + -1)|0;
        $112 = (1137192 + 254|0);
        $113 = HEAP16[$112>>1]|0;
        $114 = ($113<<16>>16)==(0);
        if ($114) {
         $115 = (__ZN4half7convertEi(1065353216)|0);
         $116 = $115;
        } else {
         $116 = $113;
        }
        HEAP16[$d$14$i260>>1] = $116;
        $117 = ($111|0)==(0);
        if ($117) {
         break L8;
        }
        $118 = (($d$14$i260) + ($8<<1)|0);
        $$13$i261 = $111;$d$14$i260 = $118;
       }
      } else if ((($20|0) == 1)) {
       __Z12COPY_FI_FRGBI4halfS0_EvjjjPvS1_PKvS3_S3_S3_($0,$8,$11,$$2,$a0$0,$$3,$g1$0,$$4,$a1$0);
       break;
      } else if ((($20|0) == 2)) {
       __Z12COPY_FRGB_FII4halfS0_EvjjjPvS1_S1_S1_PKvS3_($0,$8,$11,$$1,$g0$0,$$2,$a0$0,$$4,$a1$0);
       break;
      } else if ((($20|0) == 3)) {
       $119 = ($$1|0)==(0|0);
       L41: do {
        if (!($119)) {
         $120 = ($$3|0)==(0|0);
         if (!($120)) {
          if ($42) {
           break;
          } else {
           $$06$i248 = $0;$d$07$i247 = $$1;$s$08$i246 = $$3;
          }
          while(1) {
           $121 = (($$06$i248) + -1)|0;
           $122 = HEAP16[$s$08$i246>>1]|0;
           HEAP16[$d$07$i247>>1] = $122;
           $123 = (($d$07$i247) + ($8<<1)|0);
           $124 = (($s$08$i246) + ($11<<1)|0);
           $125 = ($121|0)==(0);
           if ($125) {
            break L41;
           } else {
            $$06$i248 = $121;$d$07$i247 = $123;$s$08$i246 = $124;
           }
          }
         }
         if (!($42)) {
          $$13$i250 = $0;$d$14$i249 = $$1;
          while(1) {
           $126 = (($$13$i250) + -1)|0;
           $127 = (1137192 + 254|0);
           $128 = HEAP16[$127>>1]|0;
           $129 = ($128<<16>>16)==(0);
           if ($129) {
            $130 = (__ZN4half7convertEi(1065353216)|0);
            $131 = $130;
           } else {
            $131 = $128;
           }
           HEAP16[$d$14$i249>>1] = $131;
           $132 = ($126|0)==(0);
           if ($132) {
            break L41;
           }
           $133 = (($d$14$i249) + ($8<<1)|0);
           $$13$i250 = $126;$d$14$i249 = $133;
          }
         }
        }
       } while(0);
       $134 = ($g0$0|0)==(0|0);
       L55: do {
        if (!($134)) {
         $135 = ($g1$0|0)==(0|0);
         if (!($135)) {
          if ($42) {
           break;
          } else {
           $$06$i237 = $0;$d$07$i236 = $g0$0;$s$08$i235 = $g1$0;
          }
          while(1) {
           $136 = (($$06$i237) + -1)|0;
           $137 = HEAP16[$s$08$i235>>1]|0;
           HEAP16[$d$07$i236>>1] = $137;
           $138 = (($d$07$i236) + ($8<<1)|0);
           $139 = (($s$08$i235) + ($11<<1)|0);
           $140 = ($136|0)==(0);
           if ($140) {
            break L55;
           } else {
            $$06$i237 = $136;$d$07$i236 = $138;$s$08$i235 = $139;
           }
          }
         }
         if (!($42)) {
          $$13$i239 = $0;$d$14$i238 = $g0$0;
          while(1) {
           $141 = (($$13$i239) + -1)|0;
           $142 = (1137192 + 254|0);
           $143 = HEAP16[$142>>1]|0;
           $144 = ($143<<16>>16)==(0);
           if ($144) {
            $145 = (__ZN4half7convertEi(1065353216)|0);
            $146 = $145;
           } else {
            $146 = $143;
           }
           HEAP16[$d$14$i238>>1] = $146;
           $147 = ($141|0)==(0);
           if ($147) {
            break L55;
           }
           $148 = (($d$14$i238) + ($8<<1)|0);
           $$13$i239 = $141;$d$14$i238 = $148;
          }
         }
        }
       } while(0);
       $149 = ($$2|0)==(0|0);
       L69: do {
        if (!($149)) {
         $150 = ($$4|0)==(0|0);
         if (!($150)) {
          if ($42) {
           break;
          } else {
           $$06$i226 = $0;$d$07$i225 = $$2;$s$08$i224 = $$4;
          }
          while(1) {
           $151 = (($$06$i226) + -1)|0;
           $152 = HEAP16[$s$08$i224>>1]|0;
           HEAP16[$d$07$i225>>1] = $152;
           $153 = (($d$07$i225) + ($8<<1)|0);
           $154 = (($s$08$i224) + ($11<<1)|0);
           $155 = ($151|0)==(0);
           if ($155) {
            break L69;
           } else {
            $$06$i226 = $151;$d$07$i225 = $153;$s$08$i224 = $154;
           }
          }
         }
         if (!($42)) {
          $$13$i228 = $0;$d$14$i227 = $$2;
          while(1) {
           $156 = (($$13$i228) + -1)|0;
           $157 = (1137192 + 254|0);
           $158 = HEAP16[$157>>1]|0;
           $159 = ($158<<16>>16)==(0);
           if ($159) {
            $160 = (__ZN4half7convertEi(1065353216)|0);
            $161 = $160;
           } else {
            $161 = $158;
           }
           HEAP16[$d$14$i227>>1] = $161;
           $162 = ($156|0)==(0);
           if ($162) {
            break L69;
           }
           $163 = (($d$14$i227) + ($8<<1)|0);
           $$13$i228 = $156;$d$14$i227 = $163;
          }
         }
        }
       } while(0);
       $164 = ($a0$0|0)==(0|0);
       if ($164) {
        break;
       }
       $165 = ($a1$0|0)==(0|0);
       if (!($165)) {
        if ($42) {
         break;
        } else {
         $$06$i216 = $0;$d$07$i215 = $a0$0;$s$08$i214 = $a1$0;
        }
        while(1) {
         $166 = (($$06$i216) + -1)|0;
         $167 = HEAP16[$s$08$i214>>1]|0;
         HEAP16[$d$07$i215>>1] = $167;
         $168 = (($d$07$i215) + ($8<<1)|0);
         $169 = (($s$08$i214) + ($11<<1)|0);
         $170 = ($166|0)==(0);
         if ($170) {
          break L8;
         } else {
          $$06$i216 = $166;$d$07$i215 = $168;$s$08$i214 = $169;
         }
        }
       }
       if ($42) {
        break;
       } else {
        $$13$i218 = $0;$d$14$i217 = $a0$0;
       }
       while(1) {
        $171 = (($$13$i218) + -1)|0;
        $172 = (1137192 + 254|0);
        $173 = HEAP16[$172>>1]|0;
        $174 = ($173<<16>>16)==(0);
        if ($174) {
         $175 = (__ZN4half7convertEi(1065353216)|0);
         $176 = $175;
        } else {
         $176 = $173;
        }
        HEAP16[$d$14$i217>>1] = $176;
        $177 = ($171|0)==(0);
        if ($177) {
         break L8;
        }
        $178 = (($d$14$i217) + ($8<<1)|0);
        $$13$i218 = $171;$d$14$i217 = $178;
       }
      } else {
       break;
      }
     }
    } while(0);
    $179 = HEAP32[$16>>2]|0;
    $180 = $179 & 536870912;
    $181 = ($180|0)==(0);
    if (!($181)) {
     if ((($20|0) == 0)) {
      $182 = ($$2|0)==(0|0);
      L99: do {
       if (!($182)) {
        $183 = ($$4|0)==(0|0);
        if ($183) {
         if ($42) {
          break;
         } else {
          $$13$i207 = $0;$d$14$i206 = $$2;
         }
         while(1) {
          $203 = (($$13$i207) + -1)|0;
          $204 = (1137192 + 254|0);
          $205 = HEAP16[$204>>1]|0;
          $206 = ($205<<16>>16)==(0);
          if ($206) {
           $207 = (__ZN4half7convertEi(1065353216)|0);
           $208 = $207;
          } else {
           $208 = $205;
          }
          HEAP16[$d$14$i206>>1] = $208;
          $209 = ($203|0)==(0);
          if ($209) {
           break L99;
          }
          $210 = (($d$14$i206) + ($8<<1)|0);
          $$13$i207 = $203;$d$14$i206 = $210;
         }
        }
        if (!($42)) {
         $$06$i204 = $0;$d$07$i203 = $$2;$s$08$i202 = $$4;
         while(1) {
          $184 = (($$06$i204) + -1)|0;
          $185 = Math_fround(HEAPF32[$s$08$i202>>2]);
          $186 = $185 == Math_fround(0.0);
          do {
           if ($186) {
            $199 = 0;
           } else {
            $187 = (HEAPF32[tempDoublePtr>>2]=$185,HEAP32[tempDoublePtr>>2]|0);
            $188 = $187 >>> 23;
            $189 = (1137192 + ($188<<1)|0);
            $190 = HEAP16[$189>>1]|0;
            $191 = ($190<<16>>16)==(0);
            if ($191) {
             $198 = (__ZN4half7convertEi($187)|0);
             $199 = $198;
             break;
            } else {
             $192 = $190&65535;
             $193 = $187 & 8388607;
             $194 = (($193) + 4096)|0;
             $195 = $194 >>> 13;
             $196 = (($192) + ($195))|0;
             $197 = $196&65535;
             $199 = $197;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i203>>1] = $199;
          $200 = (($d$07$i203) + ($8<<1)|0);
          $201 = (($s$08$i202) + ($11<<2)|0);
          $202 = ($184|0)==(0);
          if ($202) {
           break;
          } else {
           $$06$i204 = $184;$d$07$i203 = $200;$s$08$i202 = $201;
          }
         }
        }
       }
      } while(0);
      $211 = ($a0$0|0)==(0|0);
      if ($211) {
       break;
      }
      $212 = ($a1$0|0)==(0|0);
      if ($212) {
       if ($42) {
        break;
       } else {
        $$13$i195 = $0;$d$14$i194 = $a0$0;
       }
       while(1) {
        $232 = (($$13$i195) + -1)|0;
        $233 = (1137192 + 254|0);
        $234 = HEAP16[$233>>1]|0;
        $235 = ($234<<16>>16)==(0);
        if ($235) {
         $236 = (__ZN4half7convertEi(1065353216)|0);
         $237 = $236;
        } else {
         $237 = $234;
        }
        HEAP16[$d$14$i194>>1] = $237;
        $238 = ($232|0)==(0);
        if ($238) {
         break L6;
        }
        $239 = (($d$14$i194) + ($8<<1)|0);
        $$13$i195 = $232;$d$14$i194 = $239;
       }
      }
      if ($42) {
       break;
      }
      $$06$i192 = $0;$d$07$i191 = $a0$0;$s$08$i190 = $a1$0;
      while(1) {
       $213 = (($$06$i192) + -1)|0;
       $214 = Math_fround(HEAPF32[$s$08$i190>>2]);
       $215 = $214 == Math_fround(0.0);
       do {
        if ($215) {
         $228 = 0;
        } else {
         $216 = (HEAPF32[tempDoublePtr>>2]=$214,HEAP32[tempDoublePtr>>2]|0);
         $217 = $216 >>> 23;
         $218 = (1137192 + ($217<<1)|0);
         $219 = HEAP16[$218>>1]|0;
         $220 = ($219<<16>>16)==(0);
         if ($220) {
          $227 = (__ZN4half7convertEi($216)|0);
          $228 = $227;
          break;
         } else {
          $221 = $219&65535;
          $222 = $216 & 8388607;
          $223 = (($222) + 4096)|0;
          $224 = $223 >>> 13;
          $225 = (($221) + ($224))|0;
          $226 = $225&65535;
          $228 = $226;
          break;
         }
        }
       } while(0);
       HEAP16[$d$07$i191>>1] = $228;
       $229 = (($d$07$i191) + ($8<<1)|0);
       $230 = (($s$08$i190) + ($11<<2)|0);
       $231 = ($213|0)==(0);
       if ($231) {
        break;
       } else {
        $$06$i192 = $213;$d$07$i191 = $229;$s$08$i190 = $230;
       }
      }
     } else if ((($20|0) == 3)) {
      $240 = ($$1|0)==(0|0);
      L140: do {
       if (!($240)) {
        $241 = ($$3|0)==(0|0);
        if ($241) {
         if ($42) {
          break;
         } else {
          $$13$i183 = $0;$d$14$i182 = $$1;
         }
         while(1) {
          $261 = (($$13$i183) + -1)|0;
          $262 = (1137192 + 254|0);
          $263 = HEAP16[$262>>1]|0;
          $264 = ($263<<16>>16)==(0);
          if ($264) {
           $265 = (__ZN4half7convertEi(1065353216)|0);
           $266 = $265;
          } else {
           $266 = $263;
          }
          HEAP16[$d$14$i182>>1] = $266;
          $267 = ($261|0)==(0);
          if ($267) {
           break L140;
          }
          $268 = (($d$14$i182) + ($8<<1)|0);
          $$13$i183 = $261;$d$14$i182 = $268;
         }
        }
        if (!($42)) {
         $$06$i180 = $0;$d$07$i179 = $$1;$s$08$i178 = $$3;
         while(1) {
          $242 = (($$06$i180) + -1)|0;
          $243 = Math_fround(HEAPF32[$s$08$i178>>2]);
          $244 = $243 == Math_fround(0.0);
          do {
           if ($244) {
            $257 = 0;
           } else {
            $245 = (HEAPF32[tempDoublePtr>>2]=$243,HEAP32[tempDoublePtr>>2]|0);
            $246 = $245 >>> 23;
            $247 = (1137192 + ($246<<1)|0);
            $248 = HEAP16[$247>>1]|0;
            $249 = ($248<<16>>16)==(0);
            if ($249) {
             $256 = (__ZN4half7convertEi($245)|0);
             $257 = $256;
             break;
            } else {
             $250 = $248&65535;
             $251 = $245 & 8388607;
             $252 = (($251) + 4096)|0;
             $253 = $252 >>> 13;
             $254 = (($250) + ($253))|0;
             $255 = $254&65535;
             $257 = $255;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i179>>1] = $257;
          $258 = (($d$07$i179) + ($8<<1)|0);
          $259 = (($s$08$i178) + ($11<<2)|0);
          $260 = ($242|0)==(0);
          if ($260) {
           break;
          } else {
           $$06$i180 = $242;$d$07$i179 = $258;$s$08$i178 = $259;
          }
         }
        }
       }
      } while(0);
      $269 = ($g0$0|0)==(0|0);
      L161: do {
       if (!($269)) {
        $270 = ($g1$0|0)==(0|0);
        if ($270) {
         if ($42) {
          break;
         } else {
          $$13$i171 = $0;$d$14$i170 = $g0$0;
         }
         while(1) {
          $290 = (($$13$i171) + -1)|0;
          $291 = (1137192 + 254|0);
          $292 = HEAP16[$291>>1]|0;
          $293 = ($292<<16>>16)==(0);
          if ($293) {
           $294 = (__ZN4half7convertEi(1065353216)|0);
           $295 = $294;
          } else {
           $295 = $292;
          }
          HEAP16[$d$14$i170>>1] = $295;
          $296 = ($290|0)==(0);
          if ($296) {
           break L161;
          }
          $297 = (($d$14$i170) + ($8<<1)|0);
          $$13$i171 = $290;$d$14$i170 = $297;
         }
        }
        if (!($42)) {
         $$06$i168 = $0;$d$07$i167 = $g0$0;$s$08$i166 = $g1$0;
         while(1) {
          $271 = (($$06$i168) + -1)|0;
          $272 = Math_fround(HEAPF32[$s$08$i166>>2]);
          $273 = $272 == Math_fround(0.0);
          do {
           if ($273) {
            $286 = 0;
           } else {
            $274 = (HEAPF32[tempDoublePtr>>2]=$272,HEAP32[tempDoublePtr>>2]|0);
            $275 = $274 >>> 23;
            $276 = (1137192 + ($275<<1)|0);
            $277 = HEAP16[$276>>1]|0;
            $278 = ($277<<16>>16)==(0);
            if ($278) {
             $285 = (__ZN4half7convertEi($274)|0);
             $286 = $285;
             break;
            } else {
             $279 = $277&65535;
             $280 = $274 & 8388607;
             $281 = (($280) + 4096)|0;
             $282 = $281 >>> 13;
             $283 = (($279) + ($282))|0;
             $284 = $283&65535;
             $286 = $284;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i167>>1] = $286;
          $287 = (($d$07$i167) + ($8<<1)|0);
          $288 = (($s$08$i166) + ($11<<2)|0);
          $289 = ($271|0)==(0);
          if ($289) {
           break;
          } else {
           $$06$i168 = $271;$d$07$i167 = $287;$s$08$i166 = $288;
          }
         }
        }
       }
      } while(0);
      $298 = ($$2|0)==(0|0);
      L182: do {
       if (!($298)) {
        $299 = ($$4|0)==(0|0);
        if ($299) {
         if ($42) {
          break;
         } else {
          $$13$i159 = $0;$d$14$i158 = $$2;
         }
         while(1) {
          $319 = (($$13$i159) + -1)|0;
          $320 = (1137192 + 254|0);
          $321 = HEAP16[$320>>1]|0;
          $322 = ($321<<16>>16)==(0);
          if ($322) {
           $323 = (__ZN4half7convertEi(1065353216)|0);
           $324 = $323;
          } else {
           $324 = $321;
          }
          HEAP16[$d$14$i158>>1] = $324;
          $325 = ($319|0)==(0);
          if ($325) {
           break L182;
          }
          $326 = (($d$14$i158) + ($8<<1)|0);
          $$13$i159 = $319;$d$14$i158 = $326;
         }
        }
        if (!($42)) {
         $$06$i156 = $0;$d$07$i155 = $$2;$s$08$i154 = $$4;
         while(1) {
          $300 = (($$06$i156) + -1)|0;
          $301 = Math_fround(HEAPF32[$s$08$i154>>2]);
          $302 = $301 == Math_fround(0.0);
          do {
           if ($302) {
            $315 = 0;
           } else {
            $303 = (HEAPF32[tempDoublePtr>>2]=$301,HEAP32[tempDoublePtr>>2]|0);
            $304 = $303 >>> 23;
            $305 = (1137192 + ($304<<1)|0);
            $306 = HEAP16[$305>>1]|0;
            $307 = ($306<<16>>16)==(0);
            if ($307) {
             $314 = (__ZN4half7convertEi($303)|0);
             $315 = $314;
             break;
            } else {
             $308 = $306&65535;
             $309 = $303 & 8388607;
             $310 = (($309) + 4096)|0;
             $311 = $310 >>> 13;
             $312 = (($308) + ($311))|0;
             $313 = $312&65535;
             $315 = $313;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i155>>1] = $315;
          $316 = (($d$07$i155) + ($8<<1)|0);
          $317 = (($s$08$i154) + ($11<<2)|0);
          $318 = ($300|0)==(0);
          if ($318) {
           break;
          } else {
           $$06$i156 = $300;$d$07$i155 = $316;$s$08$i154 = $317;
          }
         }
        }
       }
      } while(0);
      $327 = ($a0$0|0)==(0|0);
      if ($327) {
       break;
      }
      $328 = ($a1$0|0)==(0|0);
      if ($328) {
       if ($42) {
        break;
       } else {
        $$13$i = $0;$d$14$i = $a0$0;
       }
       while(1) {
        $348 = (($$13$i) + -1)|0;
        $349 = (1137192 + 254|0);
        $350 = HEAP16[$349>>1]|0;
        $351 = ($350<<16>>16)==(0);
        if ($351) {
         $352 = (__ZN4half7convertEi(1065353216)|0);
         $353 = $352;
        } else {
         $353 = $350;
        }
        HEAP16[$d$14$i>>1] = $353;
        $354 = ($348|0)==(0);
        if ($354) {
         break L6;
        }
        $355 = (($d$14$i) + ($8<<1)|0);
        $$13$i = $348;$d$14$i = $355;
       }
      }
      if ($42) {
       break;
      }
      $$06$i = $0;$d$07$i = $a0$0;$s$08$i = $a1$0;
      while(1) {
       $329 = (($$06$i) + -1)|0;
       $330 = Math_fround(HEAPF32[$s$08$i>>2]);
       $331 = $330 == Math_fround(0.0);
       do {
        if ($331) {
         $344 = 0;
        } else {
         $332 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
         $333 = $332 >>> 23;
         $334 = (1137192 + ($333<<1)|0);
         $335 = HEAP16[$334>>1]|0;
         $336 = ($335<<16>>16)==(0);
         if ($336) {
          $343 = (__ZN4half7convertEi($332)|0);
          $344 = $343;
          break;
         } else {
          $337 = $335&65535;
          $338 = $332 & 8388607;
          $339 = (($338) + 4096)|0;
          $340 = $339 >>> 13;
          $341 = (($337) + ($340))|0;
          $342 = $341&65535;
          $344 = $342;
          break;
         }
        }
       } while(0);
       HEAP16[$d$07$i>>1] = $344;
       $345 = (($d$07$i) + ($8<<1)|0);
       $346 = (($s$08$i) + ($11<<2)|0);
       $347 = ($329|0)==(0);
       if ($347) {
        break;
       } else {
        $$06$i = $329;$d$07$i = $345;$s$08$i = $346;
       }
      }
     } else if ((($20|0) == 1)) {
      __Z12COPY_FI_FRGBI4halffEvjjjPvS1_PKvS3_S3_S3_($0,$8,$11,$$2,$a0$0,$$3,$g1$0,$$4,$a1$0);
      break;
     } else if ((($20|0) == 2)) {
      __Z12COPY_FRGB_FII4halffEvjjjPvS1_S1_S1_PKvS3_($0,$8,$11,$$1,$g0$0,$$2,$a0$0,$$4,$a1$0);
      break;
     } else {
      break;
     }
    }
   }
  } while(0);
  $356 = HEAP32[$12>>2]|0;
  $357 = $356 & 536870912;
  $358 = ($357|0)==(0);
  L225: do {
   if (!($358)) {
    $359 = HEAP32[$16>>2]|0;
    $360 = $359 & 1073741824;
    $361 = ($360|0)==(0);
    L227: do {
     if (!($361)) {
      if ((($20|0) == 0)) {
       $362 = ($$2|0)==(0|0);
       L231: do {
        if (!($362)) {
         $363 = ($$4|0)==(0|0);
         if ($363) {
          if ($42) {
           break;
          } else {
           $$11$i147 = $0;$d$12$i146 = $$2;
          }
          while(1) {
           $372 = (($$11$i147) + -1)|0;
           HEAPF32[$d$12$i146>>2] = Math_fround(1.0);
           $373 = (($d$12$i146) + ($8<<2)|0);
           $374 = ($372|0)==(0);
           if ($374) {
            break L231;
           } else {
            $$11$i147 = $372;$d$12$i146 = $373;
           }
          }
         }
         if (!($42)) {
          $$04$i145 = $0;$d$05$i144 = $$2;$s$06$i143 = $$4;
          while(1) {
           $364 = (($$04$i145) + -1)|0;
           $365 = HEAP16[$s$06$i143>>1]|0;
           $366 = $365&65535;
           $367 = (875048 + ($366<<2)|0);
           $368 = Math_fround(HEAPF32[$367>>2]);
           HEAPF32[$d$05$i144>>2] = $368;
           $369 = (($d$05$i144) + ($8<<2)|0);
           $370 = (($s$06$i143) + ($11<<1)|0);
           $371 = ($364|0)==(0);
           if ($371) {
            break;
           } else {
            $$04$i145 = $364;$d$05$i144 = $369;$s$06$i143 = $370;
           }
          }
         }
        }
       } while(0);
       $375 = ($a0$0|0)==(0|0);
       if ($375) {
        break;
       }
       $376 = ($a1$0|0)==(0|0);
       if ($376) {
        if ($42) {
         break;
        } else {
         $$11$i138 = $0;$d$12$i137 = $a0$0;
        }
        while(1) {
         $385 = (($$11$i138) + -1)|0;
         HEAPF32[$d$12$i137>>2] = Math_fround(1.0);
         $386 = (($d$12$i137) + ($8<<2)|0);
         $387 = ($385|0)==(0);
         if ($387) {
          break L227;
         } else {
          $$11$i138 = $385;$d$12$i137 = $386;
         }
        }
       }
       if ($42) {
        break;
       }
       $$04$i136 = $0;$d$05$i135 = $a0$0;$s$06$i134 = $a1$0;
       while(1) {
        $377 = (($$04$i136) + -1)|0;
        $378 = HEAP16[$s$06$i134>>1]|0;
        $379 = $378&65535;
        $380 = (875048 + ($379<<2)|0);
        $381 = Math_fround(HEAPF32[$380>>2]);
        HEAPF32[$d$05$i135>>2] = $381;
        $382 = (($d$05$i135) + ($8<<2)|0);
        $383 = (($s$06$i134) + ($11<<1)|0);
        $384 = ($377|0)==(0);
        if ($384) {
         break;
        } else {
         $$04$i136 = $377;$d$05$i135 = $382;$s$06$i134 = $383;
        }
       }
      } else if ((($20|0) == 1)) {
       if ($42) {
        break;
       }
       $$in$i111 = $0;$a0$04$i116 = $a0$0;$a1$08$i112 = $a1$0;$b1$07$i113 = $$4;$g1$06$i114 = $g1$0;$i0$03$i117 = $$2;$r1$05$i115 = $$3;
       while(1) {
        $388 = (($$in$i111) + -1)|0;
        $389 = ($r1$05$i115|0)==(0|0);
        if ($389) {
         $r$0$i120 = Math_fround(0.298999994993209838867);$r1$1$i119 = 0;
        } else {
         $390 = HEAP16[$r1$05$i115>>1]|0;
         $391 = $390&65535;
         $392 = (875048 + ($391<<2)|0);
         $393 = Math_fround(HEAPF32[$392>>2]);
         $394 = (($r1$05$i115) + ($11<<1)|0);
         $phitmp2$i118 = Math_fround($393 * Math_fround(0.298999994993209838867));
         $r$0$i120 = $phitmp2$i118;$r1$1$i119 = $394;
        }
        $395 = ($g1$06$i114|0)==(0|0);
        if ($395) {
         $g$0$i123 = Math_fround(0.587000012397766113281);$g1$1$i122 = 0;
        } else {
         $396 = HEAP16[$g1$06$i114>>1]|0;
         $397 = $396&65535;
         $398 = (875048 + ($397<<2)|0);
         $399 = Math_fround(HEAPF32[$398>>2]);
         $400 = (($g1$06$i114) + ($11<<1)|0);
         $phitmp1$i121 = Math_fround($399 * Math_fround(0.587000012397766113281));
         $g$0$i123 = $phitmp1$i121;$g1$1$i122 = $400;
        }
        $401 = ($b1$07$i113|0)==(0|0);
        if ($401) {
         $b$0$i126 = Math_fround(0.114000000059604644775);$b1$1$i125 = 0;
        } else {
         $402 = HEAP16[$b1$07$i113>>1]|0;
         $403 = $402&65535;
         $404 = (875048 + ($403<<2)|0);
         $405 = Math_fround(HEAPF32[$404>>2]);
         $406 = (($b1$07$i113) + ($11<<1)|0);
         $phitmp$i124 = Math_fround($405 * Math_fround(0.114000000059604644775));
         $b$0$i126 = $phitmp$i124;$b1$1$i125 = $406;
        }
        $407 = ($a1$08$i112|0)==(0|0);
        if ($407) {
         $a$0$i128 = Math_fround(1.0);$a1$1$i127 = 0;
        } else {
         $408 = HEAP16[$a1$08$i112>>1]|0;
         $409 = $408&65535;
         $410 = (875048 + ($409<<2)|0);
         $411 = Math_fround(HEAPF32[$410>>2]);
         $412 = (($a1$08$i112) + ($11<<1)|0);
         $a$0$i128 = $411;$a1$1$i127 = $412;
        }
        $413 = ($i0$03$i117|0)==(0|0);
        if ($413) {
         $i0$1$i129 = 0;
        } else {
         $414 = Math_fround($g$0$i123 + $b$0$i126);
         $415 = Math_fround($r$0$i120 + $414);
         HEAPF32[$i0$03$i117>>2] = $415;
         $416 = (($i0$03$i117) + ($8<<2)|0);
         $i0$1$i129 = $416;
        }
        $417 = ($a0$04$i116|0)==(0|0);
        if ($417) {
         $a0$0$be$i130 = 0;
        } else {
         HEAPF32[$a0$04$i116>>2] = $a$0$i128;
         $418 = (($a0$04$i116) + ($8<<2)|0);
         $a0$0$be$i130 = $418;
        }
        $419 = ($388|0)==(0);
        if ($419) {
         break;
        } else {
         $$in$i111 = $388;$a0$04$i116 = $a0$0$be$i130;$a1$08$i112 = $a1$1$i127;$b1$07$i113 = $b1$1$i125;$g1$06$i114 = $g1$1$i122;$i0$03$i117 = $i0$1$i129;$r1$05$i115 = $r1$1$i119;
        }
       }
      } else if ((($20|0) == 3)) {
       $442 = ($$1|0)==(0|0);
       L274: do {
        if (!($442)) {
         $443 = ($$3|0)==(0|0);
         if ($443) {
          if ($42) {
           break;
          } else {
           $$11$i90 = $0;$d$12$i89 = $$1;
          }
          while(1) {
           $452 = (($$11$i90) + -1)|0;
           HEAPF32[$d$12$i89>>2] = Math_fround(1.0);
           $453 = (($d$12$i89) + ($8<<2)|0);
           $454 = ($452|0)==(0);
           if ($454) {
            break L274;
           } else {
            $$11$i90 = $452;$d$12$i89 = $453;
           }
          }
         }
         if (!($42)) {
          $$04$i88 = $0;$d$05$i87 = $$1;$s$06$i86 = $$3;
          while(1) {
           $444 = (($$04$i88) + -1)|0;
           $445 = HEAP16[$s$06$i86>>1]|0;
           $446 = $445&65535;
           $447 = (875048 + ($446<<2)|0);
           $448 = Math_fround(HEAPF32[$447>>2]);
           HEAPF32[$d$05$i87>>2] = $448;
           $449 = (($d$05$i87) + ($8<<2)|0);
           $450 = (($s$06$i86) + ($11<<1)|0);
           $451 = ($444|0)==(0);
           if ($451) {
            break;
           } else {
            $$04$i88 = $444;$d$05$i87 = $449;$s$06$i86 = $450;
           }
          }
         }
        }
       } while(0);
       $455 = ($g0$0|0)==(0|0);
       L285: do {
        if (!($455)) {
         $456 = ($g1$0|0)==(0|0);
         if ($456) {
          if ($42) {
           break;
          } else {
           $$11$i81 = $0;$d$12$i80 = $g0$0;
          }
          while(1) {
           $465 = (($$11$i81) + -1)|0;
           HEAPF32[$d$12$i80>>2] = Math_fround(1.0);
           $466 = (($d$12$i80) + ($8<<2)|0);
           $467 = ($465|0)==(0);
           if ($467) {
            break L285;
           } else {
            $$11$i81 = $465;$d$12$i80 = $466;
           }
          }
         }
         if (!($42)) {
          $$04$i79 = $0;$d$05$i78 = $g0$0;$s$06$i77 = $g1$0;
          while(1) {
           $457 = (($$04$i79) + -1)|0;
           $458 = HEAP16[$s$06$i77>>1]|0;
           $459 = $458&65535;
           $460 = (875048 + ($459<<2)|0);
           $461 = Math_fround(HEAPF32[$460>>2]);
           HEAPF32[$d$05$i78>>2] = $461;
           $462 = (($d$05$i78) + ($8<<2)|0);
           $463 = (($s$06$i77) + ($11<<1)|0);
           $464 = ($457|0)==(0);
           if ($464) {
            break;
           } else {
            $$04$i79 = $457;$d$05$i78 = $462;$s$06$i77 = $463;
           }
          }
         }
        }
       } while(0);
       $468 = ($$2|0)==(0|0);
       L296: do {
        if (!($468)) {
         $469 = ($$4|0)==(0|0);
         if ($469) {
          if ($42) {
           break;
          } else {
           $$11$i72 = $0;$d$12$i71 = $$2;
          }
          while(1) {
           $478 = (($$11$i72) + -1)|0;
           HEAPF32[$d$12$i71>>2] = Math_fround(1.0);
           $479 = (($d$12$i71) + ($8<<2)|0);
           $480 = ($478|0)==(0);
           if ($480) {
            break L296;
           } else {
            $$11$i72 = $478;$d$12$i71 = $479;
           }
          }
         }
         if (!($42)) {
          $$04$i70 = $0;$d$05$i69 = $$2;$s$06$i68 = $$4;
          while(1) {
           $470 = (($$04$i70) + -1)|0;
           $471 = HEAP16[$s$06$i68>>1]|0;
           $472 = $471&65535;
           $473 = (875048 + ($472<<2)|0);
           $474 = Math_fround(HEAPF32[$473>>2]);
           HEAPF32[$d$05$i69>>2] = $474;
           $475 = (($d$05$i69) + ($8<<2)|0);
           $476 = (($s$06$i68) + ($11<<1)|0);
           $477 = ($470|0)==(0);
           if ($477) {
            break;
           } else {
            $$04$i70 = $470;$d$05$i69 = $475;$s$06$i68 = $476;
           }
          }
         }
        }
       } while(0);
       $481 = ($a0$0|0)==(0|0);
       if ($481) {
        break;
       }
       $482 = ($a1$0|0)==(0|0);
       if ($482) {
        if ($42) {
         break;
        } else {
         $$11$i64 = $0;$d$12$i63 = $a0$0;
        }
        while(1) {
         $491 = (($$11$i64) + -1)|0;
         HEAPF32[$d$12$i63>>2] = Math_fround(1.0);
         $492 = (($d$12$i63) + ($8<<2)|0);
         $493 = ($491|0)==(0);
         if ($493) {
          break L227;
         } else {
          $$11$i64 = $491;$d$12$i63 = $492;
         }
        }
       }
       if ($42) {
        break;
       }
       $$04$i62 = $0;$d$05$i61 = $a0$0;$s$06$i60 = $a1$0;
       while(1) {
        $483 = (($$04$i62) + -1)|0;
        $484 = HEAP16[$s$06$i60>>1]|0;
        $485 = $484&65535;
        $486 = (875048 + ($485<<2)|0);
        $487 = Math_fround(HEAPF32[$486>>2]);
        HEAPF32[$d$05$i61>>2] = $487;
        $488 = (($d$05$i61) + ($8<<2)|0);
        $489 = (($s$06$i60) + ($11<<1)|0);
        $490 = ($483|0)==(0);
        if ($490) {
         break;
        } else {
         $$04$i62 = $483;$d$05$i61 = $488;$s$06$i60 = $489;
        }
       }
      } else if ((($20|0) == 2)) {
       if ($42) {
        break;
       }
       $$in$i94 = $0;$a0$04$i97 = $a0$0;$a1$06$i95 = $a1$0;$b0$03$i98 = $$2;$g0$02$i99 = $g0$0;$i1$05$i96 = $$4;$r0$01$i100 = $$1;
       while(1) {
        $420 = (($$in$i94) + -1)|0;
        $421 = ($i1$05$i96|0)==(0|0);
        if ($421) {
         $i$0$i102 = Math_fround(1.0);$i1$1$i101 = 0;
        } else {
         $422 = HEAP16[$i1$05$i96>>1]|0;
         $423 = $422&65535;
         $424 = (875048 + ($423<<2)|0);
         $425 = Math_fround(HEAPF32[$424>>2]);
         $426 = (($i1$05$i96) + ($11<<1)|0);
         $i$0$i102 = $425;$i1$1$i101 = $426;
        }
        $427 = ($a1$06$i95|0)==(0|0);
        if ($427) {
         $a$0$i104 = Math_fround(1.0);$a1$1$i103 = 0;
        } else {
         $428 = HEAP16[$a1$06$i95>>1]|0;
         $429 = $428&65535;
         $430 = (875048 + ($429<<2)|0);
         $431 = Math_fround(HEAPF32[$430>>2]);
         $432 = (($a1$06$i95) + ($11<<1)|0);
         $a$0$i104 = $431;$a1$1$i103 = $432;
        }
        $433 = ($r0$01$i100|0)==(0|0);
        if ($433) {
         $r0$1$i105 = 0;
        } else {
         HEAPF32[$r0$01$i100>>2] = $i$0$i102;
         $434 = (($r0$01$i100) + ($8<<2)|0);
         $r0$1$i105 = $434;
        }
        $435 = ($g0$02$i99|0)==(0|0);
        if ($435) {
         $g0$1$i106 = 0;
        } else {
         HEAPF32[$g0$02$i99>>2] = $i$0$i102;
         $436 = (($g0$02$i99) + ($8<<2)|0);
         $g0$1$i106 = $436;
        }
        $437 = ($b0$03$i98|0)==(0|0);
        if ($437) {
         $b0$1$i107 = 0;
        } else {
         HEAPF32[$b0$03$i98>>2] = $i$0$i102;
         $438 = (($b0$03$i98) + ($8<<2)|0);
         $b0$1$i107 = $438;
        }
        $439 = ($a0$04$i97|0)==(0|0);
        if ($439) {
         $a0$0$be$i108 = 0;
        } else {
         HEAPF32[$a0$04$i97>>2] = $a$0$i104;
         $440 = (($a0$04$i97) + ($8<<2)|0);
         $a0$0$be$i108 = $440;
        }
        $441 = ($420|0)==(0);
        if ($441) {
         break;
        } else {
         $$in$i94 = $420;$a0$04$i97 = $a0$0$be$i108;$a1$06$i95 = $a1$1$i103;$b0$03$i98 = $b0$1$i107;$g0$02$i99 = $g0$1$i106;$i1$05$i96 = $i1$1$i101;$r0$01$i100 = $r0$1$i105;
        }
       }
      } else {
       break;
      }
     }
    } while(0);
    $494 = $359 & 536870912;
    $495 = ($494|0)==(0);
    if (!($495)) {
     if ((($20|0) == 0)) {
      $496 = ($$2|0)==(0|0);
      L342: do {
       if (!($496)) {
        $497 = ($$4|0)==(0|0);
        if ($497) {
         if ($42) {
          break;
         } else {
          $$11$i55 = $0;$d$12$i54 = $$2;
         }
         while(1) {
          $503 = (($$11$i55) + -1)|0;
          HEAPF32[$d$12$i54>>2] = Math_fround(1.0);
          $504 = (($d$12$i54) + ($8<<2)|0);
          $505 = ($503|0)==(0);
          if ($505) {
           break L342;
          } else {
           $$11$i55 = $503;$d$12$i54 = $504;
          }
         }
        }
        if (!($42)) {
         $$04$i53 = $0;$d$05$i52 = $$2;$s$06$i51 = $$4;
         while(1) {
          $498 = (($$04$i53) + -1)|0;
          $499 = Math_fround(HEAPF32[$s$06$i51>>2]);
          HEAPF32[$d$05$i52>>2] = $499;
          $500 = (($d$05$i52) + ($8<<2)|0);
          $501 = (($s$06$i51) + ($11<<2)|0);
          $502 = ($498|0)==(0);
          if ($502) {
           break;
          } else {
           $$04$i53 = $498;$d$05$i52 = $500;$s$06$i51 = $501;
          }
         }
        }
       }
      } while(0);
      $506 = ($a0$0|0)==(0|0);
      if ($506) {
       break;
      }
      $507 = ($a1$0|0)==(0|0);
      if ($507) {
       if ($42) {
        break;
       } else {
        $$11$i46 = $0;$d$12$i45 = $a0$0;
       }
       while(1) {
        $513 = (($$11$i46) + -1)|0;
        HEAPF32[$d$12$i45>>2] = Math_fround(1.0);
        $514 = (($d$12$i45) + ($8<<2)|0);
        $515 = ($513|0)==(0);
        if ($515) {
         break L225;
        } else {
         $$11$i46 = $513;$d$12$i45 = $514;
        }
       }
      }
      if ($42) {
       break;
      }
      $$04$i44 = $0;$d$05$i43 = $a0$0;$s$06$i42 = $a1$0;
      while(1) {
       $508 = (($$04$i44) + -1)|0;
       $509 = Math_fround(HEAPF32[$s$06$i42>>2]);
       HEAPF32[$d$05$i43>>2] = $509;
       $510 = (($d$05$i43) + ($8<<2)|0);
       $511 = (($s$06$i42) + ($11<<2)|0);
       $512 = ($508|0)==(0);
       if ($512) {
        break;
       } else {
        $$04$i44 = $508;$d$05$i43 = $510;$s$06$i42 = $511;
       }
      }
     } else if ((($20|0) == 1)) {
      if ($42) {
       break;
      }
      $$in$i34 = $0;$a0$04$i35 = $a0$0;$a1$08$i = $a1$0;$b1$07$i = $$4;$g1$06$i = $g1$0;$i0$03$i = $$2;$r1$05$i = $$3;
      while(1) {
       $516 = (($$in$i34) + -1)|0;
       $517 = ($r1$05$i|0)==(0|0);
       if ($517) {
        $r$0$i = Math_fround(0.298999994993209838867);$r1$1$i = 0;
       } else {
        $518 = Math_fround(HEAPF32[$r1$05$i>>2]);
        $519 = (($r1$05$i) + ($11<<2)|0);
        $phitmp2$i = Math_fround($518 * Math_fround(0.298999994993209838867));
        $r$0$i = $phitmp2$i;$r1$1$i = $519;
       }
       $520 = ($g1$06$i|0)==(0|0);
       if ($520) {
        $g$0$i = Math_fround(0.587000012397766113281);$g1$1$i = 0;
       } else {
        $521 = Math_fround(HEAPF32[$g1$06$i>>2]);
        $522 = (($g1$06$i) + ($11<<2)|0);
        $phitmp1$i = Math_fround($521 * Math_fround(0.587000012397766113281));
        $g$0$i = $phitmp1$i;$g1$1$i = $522;
       }
       $523 = ($b1$07$i|0)==(0|0);
       if ($523) {
        $b$0$i = Math_fround(0.114000000059604644775);$b1$1$i = 0;
       } else {
        $524 = Math_fround(HEAPF32[$b1$07$i>>2]);
        $525 = (($b1$07$i) + ($11<<2)|0);
        $phitmp$i = Math_fround($524 * Math_fround(0.114000000059604644775));
        $b$0$i = $phitmp$i;$b1$1$i = $525;
       }
       $526 = ($a1$08$i|0)==(0|0);
       if ($526) {
        $a$0$i37 = Math_fround(1.0);$a1$1$i36 = 0;
       } else {
        $527 = Math_fround(HEAPF32[$a1$08$i>>2]);
        $528 = (($a1$08$i) + ($11<<2)|0);
        $a$0$i37 = $527;$a1$1$i36 = $528;
       }
       $529 = ($i0$03$i|0)==(0|0);
       if ($529) {
        $i0$1$i = 0;
       } else {
        $530 = Math_fround($g$0$i + $b$0$i);
        $531 = Math_fround($r$0$i + $530);
        HEAPF32[$i0$03$i>>2] = $531;
        $532 = (($i0$03$i) + ($8<<2)|0);
        $i0$1$i = $532;
       }
       $533 = ($a0$04$i35|0)==(0|0);
       if ($533) {
        $a0$0$be$i38 = 0;
       } else {
        HEAPF32[$a0$04$i35>>2] = $a$0$i37;
        $534 = (($a0$04$i35) + ($8<<2)|0);
        $a0$0$be$i38 = $534;
       }
       $535 = ($516|0)==(0);
       if ($535) {
        break;
       } else {
        $$in$i34 = $516;$a0$04$i35 = $a0$0$be$i38;$a1$08$i = $a1$1$i36;$b1$07$i = $b1$1$i;$g1$06$i = $g1$1$i;$i0$03$i = $i0$1$i;$r1$05$i = $r1$1$i;
       }
      }
     } else if ((($20|0) == 2)) {
      if ($42) {
       break;
      }
      $$in$i = $0;$a0$04$i = $a0$0;$a1$06$i = $a1$0;$b0$03$i = $$2;$g0$02$i = $g0$0;$i1$05$i = $$4;$r0$01$i = $$1;
      while(1) {
       $536 = (($$in$i) + -1)|0;
       $537 = ($i1$05$i|0)==(0|0);
       if ($537) {
        $i$0$i = Math_fround(1.0);$i1$1$i = 0;
       } else {
        $538 = Math_fround(HEAPF32[$i1$05$i>>2]);
        $539 = (($i1$05$i) + ($11<<2)|0);
        $i$0$i = $538;$i1$1$i = $539;
       }
       $540 = ($a1$06$i|0)==(0|0);
       if ($540) {
        $a$0$i = Math_fround(1.0);$a1$1$i = 0;
       } else {
        $541 = Math_fround(HEAPF32[$a1$06$i>>2]);
        $542 = (($a1$06$i) + ($11<<2)|0);
        $a$0$i = $541;$a1$1$i = $542;
       }
       $543 = ($r0$01$i|0)==(0|0);
       if ($543) {
        $r0$1$i = 0;
       } else {
        HEAPF32[$r0$01$i>>2] = $i$0$i;
        $544 = (($r0$01$i) + ($8<<2)|0);
        $r0$1$i = $544;
       }
       $545 = ($g0$02$i|0)==(0|0);
       if ($545) {
        $g0$1$i = 0;
       } else {
        HEAPF32[$g0$02$i>>2] = $i$0$i;
        $546 = (($g0$02$i) + ($8<<2)|0);
        $g0$1$i = $546;
       }
       $547 = ($b0$03$i|0)==(0|0);
       if ($547) {
        $b0$1$i = 0;
       } else {
        HEAPF32[$b0$03$i>>2] = $i$0$i;
        $548 = (($b0$03$i) + ($8<<2)|0);
        $b0$1$i = $548;
       }
       $549 = ($a0$04$i|0)==(0|0);
       if ($549) {
        $a0$0$be$i = 0;
       } else {
        HEAPF32[$a0$04$i>>2] = $a$0$i;
        $550 = (($a0$04$i) + ($8<<2)|0);
        $a0$0$be$i = $550;
       }
       $551 = ($536|0)==(0);
       if ($551) {
        break;
       } else {
        $$in$i = $536;$a0$04$i = $a0$0$be$i;$a1$06$i = $a1$1$i;$b0$03$i = $b0$1$i;$g0$02$i = $g0$1$i;$i1$05$i = $i1$1$i;$r0$01$i = $r0$1$i;
       }
      }
     } else if ((($20|0) == 3)) {
      $552 = ($$1|0)==(0|0);
      L407: do {
       if (!($552)) {
        $553 = ($$3|0)==(0|0);
        if ($553) {
         if ($42) {
          break;
         } else {
          $$11$i29 = $0;$d$12$i28 = $$1;
         }
         while(1) {
          $559 = (($$11$i29) + -1)|0;
          HEAPF32[$d$12$i28>>2] = Math_fround(1.0);
          $560 = (($d$12$i28) + ($8<<2)|0);
          $561 = ($559|0)==(0);
          if ($561) {
           break L407;
          } else {
           $$11$i29 = $559;$d$12$i28 = $560;
          }
         }
        }
        if (!($42)) {
         $$04$i27 = $0;$d$05$i26 = $$1;$s$06$i25 = $$3;
         while(1) {
          $554 = (($$04$i27) + -1)|0;
          $555 = Math_fround(HEAPF32[$s$06$i25>>2]);
          HEAPF32[$d$05$i26>>2] = $555;
          $556 = (($d$05$i26) + ($8<<2)|0);
          $557 = (($s$06$i25) + ($11<<2)|0);
          $558 = ($554|0)==(0);
          if ($558) {
           break;
          } else {
           $$04$i27 = $554;$d$05$i26 = $556;$s$06$i25 = $557;
          }
         }
        }
       }
      } while(0);
      $562 = ($g0$0|0)==(0|0);
      L418: do {
       if (!($562)) {
        $563 = ($g1$0|0)==(0|0);
        if ($563) {
         if ($42) {
          break;
         } else {
          $$11$i20 = $0;$d$12$i19 = $g0$0;
         }
         while(1) {
          $569 = (($$11$i20) + -1)|0;
          HEAPF32[$d$12$i19>>2] = Math_fround(1.0);
          $570 = (($d$12$i19) + ($8<<2)|0);
          $571 = ($569|0)==(0);
          if ($571) {
           break L418;
          } else {
           $$11$i20 = $569;$d$12$i19 = $570;
          }
         }
        }
        if (!($42)) {
         $$04$i18 = $0;$d$05$i17 = $g0$0;$s$06$i16 = $g1$0;
         while(1) {
          $564 = (($$04$i18) + -1)|0;
          $565 = Math_fround(HEAPF32[$s$06$i16>>2]);
          HEAPF32[$d$05$i17>>2] = $565;
          $566 = (($d$05$i17) + ($8<<2)|0);
          $567 = (($s$06$i16) + ($11<<2)|0);
          $568 = ($564|0)==(0);
          if ($568) {
           break;
          } else {
           $$04$i18 = $564;$d$05$i17 = $566;$s$06$i16 = $567;
          }
         }
        }
       }
      } while(0);
      $572 = ($$2|0)==(0|0);
      L429: do {
       if (!($572)) {
        $573 = ($$4|0)==(0|0);
        if ($573) {
         if ($42) {
          break;
         } else {
          $$11$i11 = $0;$d$12$i10 = $$2;
         }
         while(1) {
          $579 = (($$11$i11) + -1)|0;
          HEAPF32[$d$12$i10>>2] = Math_fround(1.0);
          $580 = (($d$12$i10) + ($8<<2)|0);
          $581 = ($579|0)==(0);
          if ($581) {
           break L429;
          } else {
           $$11$i11 = $579;$d$12$i10 = $580;
          }
         }
        }
        if (!($42)) {
         $$04$i9 = $0;$d$05$i8 = $$2;$s$06$i7 = $$4;
         while(1) {
          $574 = (($$04$i9) + -1)|0;
          $575 = Math_fround(HEAPF32[$s$06$i7>>2]);
          HEAPF32[$d$05$i8>>2] = $575;
          $576 = (($d$05$i8) + ($8<<2)|0);
          $577 = (($s$06$i7) + ($11<<2)|0);
          $578 = ($574|0)==(0);
          if ($578) {
           break;
          } else {
           $$04$i9 = $574;$d$05$i8 = $576;$s$06$i7 = $577;
          }
         }
        }
       }
      } while(0);
      $582 = ($a0$0|0)==(0|0);
      if ($582) {
       break;
      }
      $583 = ($a1$0|0)==(0|0);
      if ($583) {
       if ($42) {
        break;
       } else {
        $$11$i = $0;$d$12$i = $a0$0;
       }
       while(1) {
        $589 = (($$11$i) + -1)|0;
        HEAPF32[$d$12$i>>2] = Math_fround(1.0);
        $590 = (($d$12$i) + ($8<<2)|0);
        $591 = ($589|0)==(0);
        if ($591) {
         break L225;
        } else {
         $$11$i = $589;$d$12$i = $590;
        }
       }
      }
      if ($42) {
       break;
      }
      $$04$i = $0;$d$05$i = $a0$0;$s$06$i = $a1$0;
      while(1) {
       $584 = (($$04$i) + -1)|0;
       $585 = Math_fround(HEAPF32[$s$06$i>>2]);
       HEAPF32[$d$05$i>>2] = $585;
       $586 = (($d$05$i) + ($8<<2)|0);
       $587 = (($s$06$i) + ($11<<2)|0);
       $588 = ($584|0)==(0);
       if ($588) {
        break;
       } else {
        $$04$i = $584;$d$05$i = $586;$s$06$i = $587;
       }
      }
     } else {
      break;
     }
    }
   }
  } while(0);
  $exitcond = ($y$0309|0)==($2|0);
  if ($exitcond) {
   break;
  }
  $592 = (($s$0310) + ($6)|0);
  $593 = (($d$0311) + ($4)|0);
  $phitmp = (($y$0309) + 1)|0;
  $84 = $356;$d$0311 = $593;$s$0310 = $592;$y$0309 = $phitmp;
 }
 STACKTOP = sp;return;
}
function __Z13BlitCopyFloatIf4halfEvRN6prcore7SurfaceERKS2_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$04$i = 0, $$04$i136 = 0, $$04$i145 = 0, $$04$i18 = 0, $$04$i27 = 0, $$04$i44 = 0, $$04$i53 = 0, $$04$i62 = 0, $$04$i70 = 0, $$04$i79 = 0, $$04$i88 = 0, $$04$i9 = 0, $$06$i = 0, $$06$i156 = 0, $$06$i168 = 0, $$06$i180 = 0, $$06$i192 = 0, $$06$i204 = 0, $$06$i216 = 0, $$06$i226 = 0;
 var $$06$i237 = 0, $$06$i248 = 0, $$06$i259 = 0, $$06$i270 = 0, $$1 = 0, $$11$i = 0, $$11$i11 = 0, $$11$i138 = 0, $$11$i147 = 0, $$11$i20 = 0, $$11$i29 = 0, $$11$i46 = 0, $$11$i55 = 0, $$11$i64 = 0, $$11$i72 = 0, $$11$i81 = 0, $$11$i90 = 0, $$13$i = 0, $$13$i159 = 0, $$13$i171 = 0;
 var $$13$i183 = 0, $$13$i195 = 0, $$13$i207 = 0, $$13$i218 = 0, $$13$i228 = 0, $$13$i239 = 0, $$13$i250 = 0, $$13$i261 = 0, $$13$i272 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$in$i = 0, $$in$i111 = 0, $$in$i34 = 0, $$in$i94 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0);
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0);
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = Math_fround(0), $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = Math_fround(0), $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0$i = Math_fround(0), $a$0$i104 = Math_fround(0), $a$0$i128 = Math_fround(0), $a$0$i37 = Math_fround(0), $a0$0 = 0, $a0$0$be$i = 0, $a0$0$be$i108 = 0, $a0$0$be$i130 = 0, $a0$0$be$i38 = 0, $a0$04$i = 0;
 var $a0$04$i116 = 0, $a0$04$i35 = 0, $a0$04$i97 = 0, $a1$0 = 0, $a1$06$i = 0, $a1$06$i95 = 0, $a1$08$i = 0, $a1$08$i112 = 0, $a1$1$i = 0, $a1$1$i103 = 0, $a1$1$i127 = 0, $a1$1$i36 = 0, $b$0$i = Math_fround(0), $b$0$i126 = Math_fround(0), $b0$03$i = 0, $b0$03$i98 = 0, $b0$1$i = 0, $b0$1$i107 = 0, $b1$07$i = 0, $b1$07$i113 = 0;
 var $b1$1$i = 0, $b1$1$i125 = 0, $d$0311 = 0, $d$05$i = 0, $d$05$i135 = 0, $d$05$i144 = 0, $d$05$i17 = 0, $d$05$i26 = 0, $d$05$i43 = 0, $d$05$i52 = 0, $d$05$i61 = 0, $d$05$i69 = 0, $d$05$i78 = 0, $d$05$i8 = 0, $d$05$i87 = 0, $d$07$i = 0, $d$07$i155 = 0, $d$07$i167 = 0, $d$07$i179 = 0, $d$07$i191 = 0;
 var $d$07$i203 = 0, $d$07$i215 = 0, $d$07$i225 = 0, $d$07$i236 = 0, $d$07$i247 = 0, $d$07$i258 = 0, $d$07$i269 = 0, $d$12$i = 0, $d$12$i10 = 0, $d$12$i137 = 0, $d$12$i146 = 0, $d$12$i19 = 0, $d$12$i28 = 0, $d$12$i45 = 0, $d$12$i54 = 0, $d$12$i63 = 0, $d$12$i71 = 0, $d$12$i80 = 0, $d$12$i89 = 0, $d$14$i = 0;
 var $d$14$i158 = 0, $d$14$i170 = 0, $d$14$i182 = 0, $d$14$i194 = 0, $d$14$i206 = 0, $d$14$i217 = 0, $d$14$i227 = 0, $d$14$i238 = 0, $d$14$i249 = 0, $d$14$i260 = 0, $d$14$i271 = 0, $exitcond = 0, $g$0$i = Math_fround(0), $g$0$i123 = Math_fround(0), $g0$0 = 0, $g0$02$i = 0, $g0$02$i99 = 0, $g0$1$i = 0, $g0$1$i106 = 0, $g1$0 = 0;
 var $g1$06$i = 0, $g1$06$i114 = 0, $g1$1$i = 0, $g1$1$i122 = 0, $i$0$i = Math_fround(0), $i$0$i102 = Math_fround(0), $i0$03$i = 0, $i0$03$i117 = 0, $i0$1$i = 0, $i0$1$i129 = 0, $i1$05$i = 0, $i1$05$i96 = 0, $i1$1$i = 0, $i1$1$i101 = 0, $phitmp = 0, $phitmp$i = Math_fround(0), $phitmp$i124 = Math_fround(0), $phitmp1$i = Math_fround(0), $phitmp1$i121 = Math_fround(0), $phitmp2$i = Math_fround(0);
 var $phitmp2$i118 = Math_fround(0), $r$0$i = Math_fround(0), $r$0$i120 = Math_fround(0), $r0$01$i = 0, $r0$01$i100 = 0, $r0$1$i = 0, $r0$1$i105 = 0, $r1$05$i = 0, $r1$05$i115 = 0, $r1$1$i = 0, $r1$1$i119 = 0, $s$0310 = 0, $s$06$i = 0, $s$06$i134 = 0, $s$06$i143 = 0, $s$06$i16 = 0, $s$06$i25 = 0, $s$06$i42 = 0, $s$06$i51 = 0, $s$06$i60 = 0;
 var $s$06$i68 = 0, $s$06$i7 = 0, $s$06$i77 = 0, $s$06$i86 = 0, $s$08$i = 0, $s$08$i154 = 0, $s$08$i166 = 0, $s$08$i178 = 0, $s$08$i190 = 0, $s$08$i202 = 0, $s$08$i214 = 0, $s$08$i224 = 0, $s$08$i235 = 0, $s$08$i246 = 0, $s$08$i257 = 0, $s$08$i268 = 0, $y$0309 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$dest>>2]|0;
 $1 = (($dest) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($dest) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($source) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4>>>0) / ($0>>>0))&-1;
 $8 = $7 >>> 2;
 $9 = HEAP32[$source>>2]|0;
 $10 = (($6>>>0) / ($9>>>0))&-1;
 $11 = $10 >>> 1;
 $12 = (($dest) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 27;
 $15 = $14 & 2;
 $16 = (($source) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 >>> 28;
 $19 = $18 & 1;
 $20 = $19 | $15;
 $21 = ($2|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($source) + 40|0);
 $23 = (($dest) + 40|0);
 $24 = HEAP32[$22>>2]|0;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($dest) + 38|0);
 $27 = (($dest) + 37|0);
 $28 = (($dest) + 36|0);
 $29 = (($dest) + 39|0);
 $30 = (($dest) + 16|0);
 $31 = (($dest) + 20|0);
 $32 = (($dest) + 24|0);
 $33 = (($dest) + 28|0);
 $34 = (($source) + 38|0);
 $35 = (($source) + 37|0);
 $36 = (($source) + 36|0);
 $37 = (($source) + 39|0);
 $38 = (($source) + 16|0);
 $39 = (($source) + 20|0);
 $40 = (($source) + 24|0);
 $41 = (($source) + 28|0);
 $42 = ($0|0)==(0);
 $84 = $13;$d$0311 = $25;$s$0310 = $24;$y$0309 = 1;
 while(1) {
  $43 = HEAP8[$26>>0]|0;
  $44 = $43&255;
  $45 = (($d$0311) + ($44<<2)|0);
  $46 = HEAP8[$27>>0]|0;
  $47 = $46&255;
  $48 = (($d$0311) + ($47<<2)|0);
  $49 = HEAP8[$28>>0]|0;
  $50 = $49&255;
  $51 = (($d$0311) + ($50<<2)|0);
  $52 = HEAP8[$29>>0]|0;
  $53 = $52&255;
  $54 = (($d$0311) + ($53<<2)|0);
  $55 = HEAP32[$30>>2]|0;
  $56 = ($55|0)==(0);
  $$1 = $56 ? 0 : $45;
  $57 = HEAP32[$31>>2]|0;
  $58 = ($57|0)==(0);
  $g0$0 = $58 ? 0 : $48;
  $59 = HEAP32[$32>>2]|0;
  $60 = ($59|0)==(0);
  $$2 = $60 ? 0 : $51;
  $61 = HEAP32[$33>>2]|0;
  $62 = ($61|0)==(0);
  $a0$0 = $62 ? 0 : $54;
  $63 = HEAP8[$34>>0]|0;
  $64 = $63&255;
  $65 = (($s$0310) + ($64<<1)|0);
  $66 = HEAP8[$35>>0]|0;
  $67 = $66&255;
  $68 = (($s$0310) + ($67<<1)|0);
  $69 = HEAP8[$36>>0]|0;
  $70 = $69&255;
  $71 = (($s$0310) + ($70<<1)|0);
  $72 = HEAP8[$37>>0]|0;
  $73 = $72&255;
  $74 = (($s$0310) + ($73<<1)|0);
  $75 = HEAP32[$38>>2]|0;
  $76 = ($75|0)==(0);
  $$3 = $76 ? 0 : $65;
  $77 = HEAP32[$39>>2]|0;
  $78 = ($77|0)==(0);
  $g1$0 = $78 ? 0 : $68;
  $79 = HEAP32[$40>>2]|0;
  $80 = ($79|0)==(0);
  $$4 = $80 ? 0 : $71;
  $81 = HEAP32[$41>>2]|0;
  $82 = ($81|0)==(0);
  $a1$0 = $82 ? 0 : $74;
  $83 = $84 & 1073741824;
  $85 = ($83|0)==(0);
  L6: do {
   if (!($85)) {
    $86 = HEAP32[$16>>2]|0;
    $87 = $86 & 1073741824;
    $88 = ($87|0)==(0);
    L8: do {
     if (!($88)) {
      if ((($20|0) == 0)) {
       $89 = ($$2|0)==(0|0);
       L12: do {
        if (!($89)) {
         $90 = ($$4|0)==(0|0);
         if (!($90)) {
          if ($42) {
           break;
          } else {
           $$06$i270 = $0;$d$07$i269 = $$2;$s$08$i268 = $$4;
          }
          while(1) {
           $91 = (($$06$i270) + -1)|0;
           $92 = HEAP16[$s$08$i268>>1]|0;
           HEAP16[$d$07$i269>>1] = $92;
           $93 = (($d$07$i269) + ($8<<1)|0);
           $94 = (($s$08$i268) + ($11<<1)|0);
           $95 = ($91|0)==(0);
           if ($95) {
            break L12;
           } else {
            $$06$i270 = $91;$d$07$i269 = $93;$s$08$i268 = $94;
           }
          }
         }
         if (!($42)) {
          $$13$i272 = $0;$d$14$i271 = $$2;
          while(1) {
           $96 = (($$13$i272) + -1)|0;
           $97 = (1137192 + 254|0);
           $98 = HEAP16[$97>>1]|0;
           $99 = ($98<<16>>16)==(0);
           if ($99) {
            $100 = (__ZN4half7convertEi(1065353216)|0);
            $101 = $100;
           } else {
            $101 = $98;
           }
           HEAP16[$d$14$i271>>1] = $101;
           $102 = ($96|0)==(0);
           if ($102) {
            break L12;
           }
           $103 = (($d$14$i271) + ($8<<1)|0);
           $$13$i272 = $96;$d$14$i271 = $103;
          }
         }
        }
       } while(0);
       $104 = ($a0$0|0)==(0|0);
       if ($104) {
        break;
       }
       $105 = ($a1$0|0)==(0|0);
       if (!($105)) {
        if ($42) {
         break;
        } else {
         $$06$i259 = $0;$d$07$i258 = $a0$0;$s$08$i257 = $a1$0;
        }
        while(1) {
         $106 = (($$06$i259) + -1)|0;
         $107 = HEAP16[$s$08$i257>>1]|0;
         HEAP16[$d$07$i258>>1] = $107;
         $108 = (($d$07$i258) + ($8<<1)|0);
         $109 = (($s$08$i257) + ($11<<1)|0);
         $110 = ($106|0)==(0);
         if ($110) {
          break L8;
         } else {
          $$06$i259 = $106;$d$07$i258 = $108;$s$08$i257 = $109;
         }
        }
       }
       if ($42) {
        break;
       } else {
        $$13$i261 = $0;$d$14$i260 = $a0$0;
       }
       while(1) {
        $111 = (($$13$i261) + -1)|0;
        $112 = (1137192 + 254|0);
        $113 = HEAP16[$112>>1]|0;
        $114 = ($113<<16>>16)==(0);
        if ($114) {
         $115 = (__ZN4half7convertEi(1065353216)|0);
         $116 = $115;
        } else {
         $116 = $113;
        }
        HEAP16[$d$14$i260>>1] = $116;
        $117 = ($111|0)==(0);
        if ($117) {
         break L8;
        }
        $118 = (($d$14$i260) + ($8<<1)|0);
        $$13$i261 = $111;$d$14$i260 = $118;
       }
      } else if ((($20|0) == 1)) {
       __Z12COPY_FI_FRGBI4halfS0_EvjjjPvS1_PKvS3_S3_S3_($0,$8,$11,$$2,$a0$0,$$3,$g1$0,$$4,$a1$0);
       break;
      } else if ((($20|0) == 3)) {
       $119 = ($$1|0)==(0|0);
       L40: do {
        if (!($119)) {
         $120 = ($$3|0)==(0|0);
         if (!($120)) {
          if ($42) {
           break;
          } else {
           $$06$i248 = $0;$d$07$i247 = $$1;$s$08$i246 = $$3;
          }
          while(1) {
           $121 = (($$06$i248) + -1)|0;
           $122 = HEAP16[$s$08$i246>>1]|0;
           HEAP16[$d$07$i247>>1] = $122;
           $123 = (($d$07$i247) + ($8<<1)|0);
           $124 = (($s$08$i246) + ($11<<1)|0);
           $125 = ($121|0)==(0);
           if ($125) {
            break L40;
           } else {
            $$06$i248 = $121;$d$07$i247 = $123;$s$08$i246 = $124;
           }
          }
         }
         if (!($42)) {
          $$13$i250 = $0;$d$14$i249 = $$1;
          while(1) {
           $126 = (($$13$i250) + -1)|0;
           $127 = (1137192 + 254|0);
           $128 = HEAP16[$127>>1]|0;
           $129 = ($128<<16>>16)==(0);
           if ($129) {
            $130 = (__ZN4half7convertEi(1065353216)|0);
            $131 = $130;
           } else {
            $131 = $128;
           }
           HEAP16[$d$14$i249>>1] = $131;
           $132 = ($126|0)==(0);
           if ($132) {
            break L40;
           }
           $133 = (($d$14$i249) + ($8<<1)|0);
           $$13$i250 = $126;$d$14$i249 = $133;
          }
         }
        }
       } while(0);
       $134 = ($g0$0|0)==(0|0);
       L54: do {
        if (!($134)) {
         $135 = ($g1$0|0)==(0|0);
         if (!($135)) {
          if ($42) {
           break;
          } else {
           $$06$i237 = $0;$d$07$i236 = $g0$0;$s$08$i235 = $g1$0;
          }
          while(1) {
           $136 = (($$06$i237) + -1)|0;
           $137 = HEAP16[$s$08$i235>>1]|0;
           HEAP16[$d$07$i236>>1] = $137;
           $138 = (($d$07$i236) + ($8<<1)|0);
           $139 = (($s$08$i235) + ($11<<1)|0);
           $140 = ($136|0)==(0);
           if ($140) {
            break L54;
           } else {
            $$06$i237 = $136;$d$07$i236 = $138;$s$08$i235 = $139;
           }
          }
         }
         if (!($42)) {
          $$13$i239 = $0;$d$14$i238 = $g0$0;
          while(1) {
           $141 = (($$13$i239) + -1)|0;
           $142 = (1137192 + 254|0);
           $143 = HEAP16[$142>>1]|0;
           $144 = ($143<<16>>16)==(0);
           if ($144) {
            $145 = (__ZN4half7convertEi(1065353216)|0);
            $146 = $145;
           } else {
            $146 = $143;
           }
           HEAP16[$d$14$i238>>1] = $146;
           $147 = ($141|0)==(0);
           if ($147) {
            break L54;
           }
           $148 = (($d$14$i238) + ($8<<1)|0);
           $$13$i239 = $141;$d$14$i238 = $148;
          }
         }
        }
       } while(0);
       $149 = ($$2|0)==(0|0);
       L68: do {
        if (!($149)) {
         $150 = ($$4|0)==(0|0);
         if (!($150)) {
          if ($42) {
           break;
          } else {
           $$06$i226 = $0;$d$07$i225 = $$2;$s$08$i224 = $$4;
          }
          while(1) {
           $151 = (($$06$i226) + -1)|0;
           $152 = HEAP16[$s$08$i224>>1]|0;
           HEAP16[$d$07$i225>>1] = $152;
           $153 = (($d$07$i225) + ($8<<1)|0);
           $154 = (($s$08$i224) + ($11<<1)|0);
           $155 = ($151|0)==(0);
           if ($155) {
            break L68;
           } else {
            $$06$i226 = $151;$d$07$i225 = $153;$s$08$i224 = $154;
           }
          }
         }
         if (!($42)) {
          $$13$i228 = $0;$d$14$i227 = $$2;
          while(1) {
           $156 = (($$13$i228) + -1)|0;
           $157 = (1137192 + 254|0);
           $158 = HEAP16[$157>>1]|0;
           $159 = ($158<<16>>16)==(0);
           if ($159) {
            $160 = (__ZN4half7convertEi(1065353216)|0);
            $161 = $160;
           } else {
            $161 = $158;
           }
           HEAP16[$d$14$i227>>1] = $161;
           $162 = ($156|0)==(0);
           if ($162) {
            break L68;
           }
           $163 = (($d$14$i227) + ($8<<1)|0);
           $$13$i228 = $156;$d$14$i227 = $163;
          }
         }
        }
       } while(0);
       $164 = ($a0$0|0)==(0|0);
       if ($164) {
        break;
       }
       $165 = ($a1$0|0)==(0|0);
       if (!($165)) {
        if ($42) {
         break;
        } else {
         $$06$i216 = $0;$d$07$i215 = $a0$0;$s$08$i214 = $a1$0;
        }
        while(1) {
         $166 = (($$06$i216) + -1)|0;
         $167 = HEAP16[$s$08$i214>>1]|0;
         HEAP16[$d$07$i215>>1] = $167;
         $168 = (($d$07$i215) + ($8<<1)|0);
         $169 = (($s$08$i214) + ($11<<1)|0);
         $170 = ($166|0)==(0);
         if ($170) {
          break L8;
         } else {
          $$06$i216 = $166;$d$07$i215 = $168;$s$08$i214 = $169;
         }
        }
       }
       if ($42) {
        break;
       } else {
        $$13$i218 = $0;$d$14$i217 = $a0$0;
       }
       while(1) {
        $171 = (($$13$i218) + -1)|0;
        $172 = (1137192 + 254|0);
        $173 = HEAP16[$172>>1]|0;
        $174 = ($173<<16>>16)==(0);
        if ($174) {
         $175 = (__ZN4half7convertEi(1065353216)|0);
         $176 = $175;
        } else {
         $176 = $173;
        }
        HEAP16[$d$14$i217>>1] = $176;
        $177 = ($171|0)==(0);
        if ($177) {
         break L8;
        }
        $178 = (($d$14$i217) + ($8<<1)|0);
        $$13$i218 = $171;$d$14$i217 = $178;
       }
      } else if ((($20|0) == 2)) {
       __Z12COPY_FRGB_FII4halfS0_EvjjjPvS1_S1_S1_PKvS3_($0,$8,$11,$$1,$g0$0,$$2,$a0$0,$$4,$a1$0);
       break;
      } else {
       break;
      }
     }
    } while(0);
    $179 = HEAP32[$16>>2]|0;
    $180 = $179 & 536870912;
    $181 = ($180|0)==(0);
    if (!($181)) {
     if ((($20|0) == 0)) {
      $182 = ($$2|0)==(0|0);
      L99: do {
       if (!($182)) {
        $183 = ($$4|0)==(0|0);
        if ($183) {
         if ($42) {
          break;
         } else {
          $$13$i207 = $0;$d$14$i206 = $$2;
         }
         while(1) {
          $203 = (($$13$i207) + -1)|0;
          $204 = (1137192 + 254|0);
          $205 = HEAP16[$204>>1]|0;
          $206 = ($205<<16>>16)==(0);
          if ($206) {
           $207 = (__ZN4half7convertEi(1065353216)|0);
           $208 = $207;
          } else {
           $208 = $205;
          }
          HEAP16[$d$14$i206>>1] = $208;
          $209 = ($203|0)==(0);
          if ($209) {
           break L99;
          }
          $210 = (($d$14$i206) + ($8<<1)|0);
          $$13$i207 = $203;$d$14$i206 = $210;
         }
        }
        if (!($42)) {
         $$06$i204 = $0;$d$07$i203 = $$2;$s$08$i202 = $$4;
         while(1) {
          $184 = (($$06$i204) + -1)|0;
          $185 = Math_fround(HEAPF32[$s$08$i202>>2]);
          $186 = $185 == Math_fround(0.0);
          do {
           if ($186) {
            $199 = 0;
           } else {
            $187 = (HEAPF32[tempDoublePtr>>2]=$185,HEAP32[tempDoublePtr>>2]|0);
            $188 = $187 >>> 23;
            $189 = (1137192 + ($188<<1)|0);
            $190 = HEAP16[$189>>1]|0;
            $191 = ($190<<16>>16)==(0);
            if ($191) {
             $198 = (__ZN4half7convertEi($187)|0);
             $199 = $198;
             break;
            } else {
             $192 = $190&65535;
             $193 = $187 & 8388607;
             $194 = (($193) + 4096)|0;
             $195 = $194 >>> 13;
             $196 = (($192) + ($195))|0;
             $197 = $196&65535;
             $199 = $197;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i203>>1] = $199;
          $200 = (($d$07$i203) + ($8<<1)|0);
          $201 = (($s$08$i202) + ($11<<2)|0);
          $202 = ($184|0)==(0);
          if ($202) {
           break;
          } else {
           $$06$i204 = $184;$d$07$i203 = $200;$s$08$i202 = $201;
          }
         }
        }
       }
      } while(0);
      $211 = ($a0$0|0)==(0|0);
      if ($211) {
       break;
      }
      $212 = ($a1$0|0)==(0|0);
      if ($212) {
       if ($42) {
        break;
       } else {
        $$13$i195 = $0;$d$14$i194 = $a0$0;
       }
       while(1) {
        $232 = (($$13$i195) + -1)|0;
        $233 = (1137192 + 254|0);
        $234 = HEAP16[$233>>1]|0;
        $235 = ($234<<16>>16)==(0);
        if ($235) {
         $236 = (__ZN4half7convertEi(1065353216)|0);
         $237 = $236;
        } else {
         $237 = $234;
        }
        HEAP16[$d$14$i194>>1] = $237;
        $238 = ($232|0)==(0);
        if ($238) {
         break L6;
        }
        $239 = (($d$14$i194) + ($8<<1)|0);
        $$13$i195 = $232;$d$14$i194 = $239;
       }
      }
      if ($42) {
       break;
      }
      $$06$i192 = $0;$d$07$i191 = $a0$0;$s$08$i190 = $a1$0;
      while(1) {
       $213 = (($$06$i192) + -1)|0;
       $214 = Math_fround(HEAPF32[$s$08$i190>>2]);
       $215 = $214 == Math_fround(0.0);
       do {
        if ($215) {
         $228 = 0;
        } else {
         $216 = (HEAPF32[tempDoublePtr>>2]=$214,HEAP32[tempDoublePtr>>2]|0);
         $217 = $216 >>> 23;
         $218 = (1137192 + ($217<<1)|0);
         $219 = HEAP16[$218>>1]|0;
         $220 = ($219<<16>>16)==(0);
         if ($220) {
          $227 = (__ZN4half7convertEi($216)|0);
          $228 = $227;
          break;
         } else {
          $221 = $219&65535;
          $222 = $216 & 8388607;
          $223 = (($222) + 4096)|0;
          $224 = $223 >>> 13;
          $225 = (($221) + ($224))|0;
          $226 = $225&65535;
          $228 = $226;
          break;
         }
        }
       } while(0);
       HEAP16[$d$07$i191>>1] = $228;
       $229 = (($d$07$i191) + ($8<<1)|0);
       $230 = (($s$08$i190) + ($11<<2)|0);
       $231 = ($213|0)==(0);
       if ($231) {
        break;
       } else {
        $$06$i192 = $213;$d$07$i191 = $229;$s$08$i190 = $230;
       }
      }
     } else if ((($20|0) == 2)) {
      __Z12COPY_FRGB_FII4halffEvjjjPvS1_S1_S1_PKvS3_($0,$8,$11,$$1,$g0$0,$$2,$a0$0,$$4,$a1$0);
      break;
     } else if ((($20|0) == 3)) {
      $240 = ($$1|0)==(0|0);
      L141: do {
       if (!($240)) {
        $241 = ($$3|0)==(0|0);
        if ($241) {
         if ($42) {
          break;
         } else {
          $$13$i183 = $0;$d$14$i182 = $$1;
         }
         while(1) {
          $261 = (($$13$i183) + -1)|0;
          $262 = (1137192 + 254|0);
          $263 = HEAP16[$262>>1]|0;
          $264 = ($263<<16>>16)==(0);
          if ($264) {
           $265 = (__ZN4half7convertEi(1065353216)|0);
           $266 = $265;
          } else {
           $266 = $263;
          }
          HEAP16[$d$14$i182>>1] = $266;
          $267 = ($261|0)==(0);
          if ($267) {
           break L141;
          }
          $268 = (($d$14$i182) + ($8<<1)|0);
          $$13$i183 = $261;$d$14$i182 = $268;
         }
        }
        if (!($42)) {
         $$06$i180 = $0;$d$07$i179 = $$1;$s$08$i178 = $$3;
         while(1) {
          $242 = (($$06$i180) + -1)|0;
          $243 = Math_fround(HEAPF32[$s$08$i178>>2]);
          $244 = $243 == Math_fround(0.0);
          do {
           if ($244) {
            $257 = 0;
           } else {
            $245 = (HEAPF32[tempDoublePtr>>2]=$243,HEAP32[tempDoublePtr>>2]|0);
            $246 = $245 >>> 23;
            $247 = (1137192 + ($246<<1)|0);
            $248 = HEAP16[$247>>1]|0;
            $249 = ($248<<16>>16)==(0);
            if ($249) {
             $256 = (__ZN4half7convertEi($245)|0);
             $257 = $256;
             break;
            } else {
             $250 = $248&65535;
             $251 = $245 & 8388607;
             $252 = (($251) + 4096)|0;
             $253 = $252 >>> 13;
             $254 = (($250) + ($253))|0;
             $255 = $254&65535;
             $257 = $255;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i179>>1] = $257;
          $258 = (($d$07$i179) + ($8<<1)|0);
          $259 = (($s$08$i178) + ($11<<2)|0);
          $260 = ($242|0)==(0);
          if ($260) {
           break;
          } else {
           $$06$i180 = $242;$d$07$i179 = $258;$s$08$i178 = $259;
          }
         }
        }
       }
      } while(0);
      $269 = ($g0$0|0)==(0|0);
      L162: do {
       if (!($269)) {
        $270 = ($g1$0|0)==(0|0);
        if ($270) {
         if ($42) {
          break;
         } else {
          $$13$i171 = $0;$d$14$i170 = $g0$0;
         }
         while(1) {
          $290 = (($$13$i171) + -1)|0;
          $291 = (1137192 + 254|0);
          $292 = HEAP16[$291>>1]|0;
          $293 = ($292<<16>>16)==(0);
          if ($293) {
           $294 = (__ZN4half7convertEi(1065353216)|0);
           $295 = $294;
          } else {
           $295 = $292;
          }
          HEAP16[$d$14$i170>>1] = $295;
          $296 = ($290|0)==(0);
          if ($296) {
           break L162;
          }
          $297 = (($d$14$i170) + ($8<<1)|0);
          $$13$i171 = $290;$d$14$i170 = $297;
         }
        }
        if (!($42)) {
         $$06$i168 = $0;$d$07$i167 = $g0$0;$s$08$i166 = $g1$0;
         while(1) {
          $271 = (($$06$i168) + -1)|0;
          $272 = Math_fround(HEAPF32[$s$08$i166>>2]);
          $273 = $272 == Math_fround(0.0);
          do {
           if ($273) {
            $286 = 0;
           } else {
            $274 = (HEAPF32[tempDoublePtr>>2]=$272,HEAP32[tempDoublePtr>>2]|0);
            $275 = $274 >>> 23;
            $276 = (1137192 + ($275<<1)|0);
            $277 = HEAP16[$276>>1]|0;
            $278 = ($277<<16>>16)==(0);
            if ($278) {
             $285 = (__ZN4half7convertEi($274)|0);
             $286 = $285;
             break;
            } else {
             $279 = $277&65535;
             $280 = $274 & 8388607;
             $281 = (($280) + 4096)|0;
             $282 = $281 >>> 13;
             $283 = (($279) + ($282))|0;
             $284 = $283&65535;
             $286 = $284;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i167>>1] = $286;
          $287 = (($d$07$i167) + ($8<<1)|0);
          $288 = (($s$08$i166) + ($11<<2)|0);
          $289 = ($271|0)==(0);
          if ($289) {
           break;
          } else {
           $$06$i168 = $271;$d$07$i167 = $287;$s$08$i166 = $288;
          }
         }
        }
       }
      } while(0);
      $298 = ($$2|0)==(0|0);
      L183: do {
       if (!($298)) {
        $299 = ($$4|0)==(0|0);
        if ($299) {
         if ($42) {
          break;
         } else {
          $$13$i159 = $0;$d$14$i158 = $$2;
         }
         while(1) {
          $319 = (($$13$i159) + -1)|0;
          $320 = (1137192 + 254|0);
          $321 = HEAP16[$320>>1]|0;
          $322 = ($321<<16>>16)==(0);
          if ($322) {
           $323 = (__ZN4half7convertEi(1065353216)|0);
           $324 = $323;
          } else {
           $324 = $321;
          }
          HEAP16[$d$14$i158>>1] = $324;
          $325 = ($319|0)==(0);
          if ($325) {
           break L183;
          }
          $326 = (($d$14$i158) + ($8<<1)|0);
          $$13$i159 = $319;$d$14$i158 = $326;
         }
        }
        if (!($42)) {
         $$06$i156 = $0;$d$07$i155 = $$2;$s$08$i154 = $$4;
         while(1) {
          $300 = (($$06$i156) + -1)|0;
          $301 = Math_fround(HEAPF32[$s$08$i154>>2]);
          $302 = $301 == Math_fround(0.0);
          do {
           if ($302) {
            $315 = 0;
           } else {
            $303 = (HEAPF32[tempDoublePtr>>2]=$301,HEAP32[tempDoublePtr>>2]|0);
            $304 = $303 >>> 23;
            $305 = (1137192 + ($304<<1)|0);
            $306 = HEAP16[$305>>1]|0;
            $307 = ($306<<16>>16)==(0);
            if ($307) {
             $314 = (__ZN4half7convertEi($303)|0);
             $315 = $314;
             break;
            } else {
             $308 = $306&65535;
             $309 = $303 & 8388607;
             $310 = (($309) + 4096)|0;
             $311 = $310 >>> 13;
             $312 = (($308) + ($311))|0;
             $313 = $312&65535;
             $315 = $313;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i155>>1] = $315;
          $316 = (($d$07$i155) + ($8<<1)|0);
          $317 = (($s$08$i154) + ($11<<2)|0);
          $318 = ($300|0)==(0);
          if ($318) {
           break;
          } else {
           $$06$i156 = $300;$d$07$i155 = $316;$s$08$i154 = $317;
          }
         }
        }
       }
      } while(0);
      $327 = ($a0$0|0)==(0|0);
      if ($327) {
       break;
      }
      $328 = ($a1$0|0)==(0|0);
      if ($328) {
       if ($42) {
        break;
       } else {
        $$13$i = $0;$d$14$i = $a0$0;
       }
       while(1) {
        $348 = (($$13$i) + -1)|0;
        $349 = (1137192 + 254|0);
        $350 = HEAP16[$349>>1]|0;
        $351 = ($350<<16>>16)==(0);
        if ($351) {
         $352 = (__ZN4half7convertEi(1065353216)|0);
         $353 = $352;
        } else {
         $353 = $350;
        }
        HEAP16[$d$14$i>>1] = $353;
        $354 = ($348|0)==(0);
        if ($354) {
         break L6;
        }
        $355 = (($d$14$i) + ($8<<1)|0);
        $$13$i = $348;$d$14$i = $355;
       }
      }
      if ($42) {
       break;
      }
      $$06$i = $0;$d$07$i = $a0$0;$s$08$i = $a1$0;
      while(1) {
       $329 = (($$06$i) + -1)|0;
       $330 = Math_fround(HEAPF32[$s$08$i>>2]);
       $331 = $330 == Math_fround(0.0);
       do {
        if ($331) {
         $344 = 0;
        } else {
         $332 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
         $333 = $332 >>> 23;
         $334 = (1137192 + ($333<<1)|0);
         $335 = HEAP16[$334>>1]|0;
         $336 = ($335<<16>>16)==(0);
         if ($336) {
          $343 = (__ZN4half7convertEi($332)|0);
          $344 = $343;
          break;
         } else {
          $337 = $335&65535;
          $338 = $332 & 8388607;
          $339 = (($338) + 4096)|0;
          $340 = $339 >>> 13;
          $341 = (($337) + ($340))|0;
          $342 = $341&65535;
          $344 = $342;
          break;
         }
        }
       } while(0);
       HEAP16[$d$07$i>>1] = $344;
       $345 = (($d$07$i) + ($8<<1)|0);
       $346 = (($s$08$i) + ($11<<2)|0);
       $347 = ($329|0)==(0);
       if ($347) {
        break;
       } else {
        $$06$i = $329;$d$07$i = $345;$s$08$i = $346;
       }
      }
     } else if ((($20|0) == 1)) {
      __Z12COPY_FI_FRGBI4halffEvjjjPvS1_PKvS3_S3_S3_($0,$8,$11,$$2,$a0$0,$$3,$g1$0,$$4,$a1$0);
      break;
     } else {
      break;
     }
    }
   }
  } while(0);
  $356 = HEAP32[$12>>2]|0;
  $357 = $356 & 536870912;
  $358 = ($357|0)==(0);
  L225: do {
   if (!($358)) {
    $359 = HEAP32[$16>>2]|0;
    $360 = $359 & 1073741824;
    $361 = ($360|0)==(0);
    L227: do {
     if (!($361)) {
      if ((($20|0) == 0)) {
       $362 = ($$2|0)==(0|0);
       L231: do {
        if (!($362)) {
         $363 = ($$4|0)==(0|0);
         if ($363) {
          if ($42) {
           break;
          } else {
           $$11$i147 = $0;$d$12$i146 = $$2;
          }
          while(1) {
           $372 = (($$11$i147) + -1)|0;
           HEAPF32[$d$12$i146>>2] = Math_fround(1.0);
           $373 = (($d$12$i146) + ($8<<2)|0);
           $374 = ($372|0)==(0);
           if ($374) {
            break L231;
           } else {
            $$11$i147 = $372;$d$12$i146 = $373;
           }
          }
         }
         if (!($42)) {
          $$04$i145 = $0;$d$05$i144 = $$2;$s$06$i143 = $$4;
          while(1) {
           $364 = (($$04$i145) + -1)|0;
           $365 = HEAP16[$s$06$i143>>1]|0;
           $366 = $365&65535;
           $367 = (875048 + ($366<<2)|0);
           $368 = Math_fround(HEAPF32[$367>>2]);
           HEAPF32[$d$05$i144>>2] = $368;
           $369 = (($d$05$i144) + ($8<<2)|0);
           $370 = (($s$06$i143) + ($11<<1)|0);
           $371 = ($364|0)==(0);
           if ($371) {
            break;
           } else {
            $$04$i145 = $364;$d$05$i144 = $369;$s$06$i143 = $370;
           }
          }
         }
        }
       } while(0);
       $375 = ($a0$0|0)==(0|0);
       if ($375) {
        break;
       }
       $376 = ($a1$0|0)==(0|0);
       if ($376) {
        if ($42) {
         break;
        } else {
         $$11$i138 = $0;$d$12$i137 = $a0$0;
        }
        while(1) {
         $385 = (($$11$i138) + -1)|0;
         HEAPF32[$d$12$i137>>2] = Math_fround(1.0);
         $386 = (($d$12$i137) + ($8<<2)|0);
         $387 = ($385|0)==(0);
         if ($387) {
          break L227;
         } else {
          $$11$i138 = $385;$d$12$i137 = $386;
         }
        }
       }
       if ($42) {
        break;
       }
       $$04$i136 = $0;$d$05$i135 = $a0$0;$s$06$i134 = $a1$0;
       while(1) {
        $377 = (($$04$i136) + -1)|0;
        $378 = HEAP16[$s$06$i134>>1]|0;
        $379 = $378&65535;
        $380 = (875048 + ($379<<2)|0);
        $381 = Math_fround(HEAPF32[$380>>2]);
        HEAPF32[$d$05$i135>>2] = $381;
        $382 = (($d$05$i135) + ($8<<2)|0);
        $383 = (($s$06$i134) + ($11<<1)|0);
        $384 = ($377|0)==(0);
        if ($384) {
         break;
        } else {
         $$04$i136 = $377;$d$05$i135 = $382;$s$06$i134 = $383;
        }
       }
      } else if ((($20|0) == 1)) {
       if ($42) {
        break;
       }
       $$in$i111 = $0;$a0$04$i116 = $a0$0;$a1$08$i112 = $a1$0;$b1$07$i113 = $$4;$g1$06$i114 = $g1$0;$i0$03$i117 = $$2;$r1$05$i115 = $$3;
       while(1) {
        $388 = (($$in$i111) + -1)|0;
        $389 = ($r1$05$i115|0)==(0|0);
        if ($389) {
         $r$0$i120 = Math_fround(0.298999994993209838867);$r1$1$i119 = 0;
        } else {
         $390 = HEAP16[$r1$05$i115>>1]|0;
         $391 = $390&65535;
         $392 = (875048 + ($391<<2)|0);
         $393 = Math_fround(HEAPF32[$392>>2]);
         $394 = (($r1$05$i115) + ($11<<1)|0);
         $phitmp2$i118 = Math_fround($393 * Math_fround(0.298999994993209838867));
         $r$0$i120 = $phitmp2$i118;$r1$1$i119 = $394;
        }
        $395 = ($g1$06$i114|0)==(0|0);
        if ($395) {
         $g$0$i123 = Math_fround(0.587000012397766113281);$g1$1$i122 = 0;
        } else {
         $396 = HEAP16[$g1$06$i114>>1]|0;
         $397 = $396&65535;
         $398 = (875048 + ($397<<2)|0);
         $399 = Math_fround(HEAPF32[$398>>2]);
         $400 = (($g1$06$i114) + ($11<<1)|0);
         $phitmp1$i121 = Math_fround($399 * Math_fround(0.587000012397766113281));
         $g$0$i123 = $phitmp1$i121;$g1$1$i122 = $400;
        }
        $401 = ($b1$07$i113|0)==(0|0);
        if ($401) {
         $b$0$i126 = Math_fround(0.114000000059604644775);$b1$1$i125 = 0;
        } else {
         $402 = HEAP16[$b1$07$i113>>1]|0;
         $403 = $402&65535;
         $404 = (875048 + ($403<<2)|0);
         $405 = Math_fround(HEAPF32[$404>>2]);
         $406 = (($b1$07$i113) + ($11<<1)|0);
         $phitmp$i124 = Math_fround($405 * Math_fround(0.114000000059604644775));
         $b$0$i126 = $phitmp$i124;$b1$1$i125 = $406;
        }
        $407 = ($a1$08$i112|0)==(0|0);
        if ($407) {
         $a$0$i128 = Math_fround(1.0);$a1$1$i127 = 0;
        } else {
         $408 = HEAP16[$a1$08$i112>>1]|0;
         $409 = $408&65535;
         $410 = (875048 + ($409<<2)|0);
         $411 = Math_fround(HEAPF32[$410>>2]);
         $412 = (($a1$08$i112) + ($11<<1)|0);
         $a$0$i128 = $411;$a1$1$i127 = $412;
        }
        $413 = ($i0$03$i117|0)==(0|0);
        if ($413) {
         $i0$1$i129 = 0;
        } else {
         $414 = Math_fround($g$0$i123 + $b$0$i126);
         $415 = Math_fround($r$0$i120 + $414);
         HEAPF32[$i0$03$i117>>2] = $415;
         $416 = (($i0$03$i117) + ($8<<2)|0);
         $i0$1$i129 = $416;
        }
        $417 = ($a0$04$i116|0)==(0|0);
        if ($417) {
         $a0$0$be$i130 = 0;
        } else {
         HEAPF32[$a0$04$i116>>2] = $a$0$i128;
         $418 = (($a0$04$i116) + ($8<<2)|0);
         $a0$0$be$i130 = $418;
        }
        $419 = ($388|0)==(0);
        if ($419) {
         break;
        } else {
         $$in$i111 = $388;$a0$04$i116 = $a0$0$be$i130;$a1$08$i112 = $a1$1$i127;$b1$07$i113 = $b1$1$i125;$g1$06$i114 = $g1$1$i122;$i0$03$i117 = $i0$1$i129;$r1$05$i115 = $r1$1$i119;
        }
       }
      } else if ((($20|0) == 2)) {
       if ($42) {
        break;
       }
       $$in$i94 = $0;$a0$04$i97 = $a0$0;$a1$06$i95 = $a1$0;$b0$03$i98 = $$2;$g0$02$i99 = $g0$0;$i1$05$i96 = $$4;$r0$01$i100 = $$1;
       while(1) {
        $420 = (($$in$i94) + -1)|0;
        $421 = ($i1$05$i96|0)==(0|0);
        if ($421) {
         $i$0$i102 = Math_fround(1.0);$i1$1$i101 = 0;
        } else {
         $422 = HEAP16[$i1$05$i96>>1]|0;
         $423 = $422&65535;
         $424 = (875048 + ($423<<2)|0);
         $425 = Math_fround(HEAPF32[$424>>2]);
         $426 = (($i1$05$i96) + ($11<<1)|0);
         $i$0$i102 = $425;$i1$1$i101 = $426;
        }
        $427 = ($a1$06$i95|0)==(0|0);
        if ($427) {
         $a$0$i104 = Math_fround(1.0);$a1$1$i103 = 0;
        } else {
         $428 = HEAP16[$a1$06$i95>>1]|0;
         $429 = $428&65535;
         $430 = (875048 + ($429<<2)|0);
         $431 = Math_fround(HEAPF32[$430>>2]);
         $432 = (($a1$06$i95) + ($11<<1)|0);
         $a$0$i104 = $431;$a1$1$i103 = $432;
        }
        $433 = ($r0$01$i100|0)==(0|0);
        if ($433) {
         $r0$1$i105 = 0;
        } else {
         HEAPF32[$r0$01$i100>>2] = $i$0$i102;
         $434 = (($r0$01$i100) + ($8<<2)|0);
         $r0$1$i105 = $434;
        }
        $435 = ($g0$02$i99|0)==(0|0);
        if ($435) {
         $g0$1$i106 = 0;
        } else {
         HEAPF32[$g0$02$i99>>2] = $i$0$i102;
         $436 = (($g0$02$i99) + ($8<<2)|0);
         $g0$1$i106 = $436;
        }
        $437 = ($b0$03$i98|0)==(0|0);
        if ($437) {
         $b0$1$i107 = 0;
        } else {
         HEAPF32[$b0$03$i98>>2] = $i$0$i102;
         $438 = (($b0$03$i98) + ($8<<2)|0);
         $b0$1$i107 = $438;
        }
        $439 = ($a0$04$i97|0)==(0|0);
        if ($439) {
         $a0$0$be$i108 = 0;
        } else {
         HEAPF32[$a0$04$i97>>2] = $a$0$i104;
         $440 = (($a0$04$i97) + ($8<<2)|0);
         $a0$0$be$i108 = $440;
        }
        $441 = ($420|0)==(0);
        if ($441) {
         break;
        } else {
         $$in$i94 = $420;$a0$04$i97 = $a0$0$be$i108;$a1$06$i95 = $a1$1$i103;$b0$03$i98 = $b0$1$i107;$g0$02$i99 = $g0$1$i106;$i1$05$i96 = $i1$1$i101;$r0$01$i100 = $r0$1$i105;
        }
       }
      } else if ((($20|0) == 3)) {
       $442 = ($$1|0)==(0|0);
       L296: do {
        if (!($442)) {
         $443 = ($$3|0)==(0|0);
         if ($443) {
          if ($42) {
           break;
          } else {
           $$11$i90 = $0;$d$12$i89 = $$1;
          }
          while(1) {
           $452 = (($$11$i90) + -1)|0;
           HEAPF32[$d$12$i89>>2] = Math_fround(1.0);
           $453 = (($d$12$i89) + ($8<<2)|0);
           $454 = ($452|0)==(0);
           if ($454) {
            break L296;
           } else {
            $$11$i90 = $452;$d$12$i89 = $453;
           }
          }
         }
         if (!($42)) {
          $$04$i88 = $0;$d$05$i87 = $$1;$s$06$i86 = $$3;
          while(1) {
           $444 = (($$04$i88) + -1)|0;
           $445 = HEAP16[$s$06$i86>>1]|0;
           $446 = $445&65535;
           $447 = (875048 + ($446<<2)|0);
           $448 = Math_fround(HEAPF32[$447>>2]);
           HEAPF32[$d$05$i87>>2] = $448;
           $449 = (($d$05$i87) + ($8<<2)|0);
           $450 = (($s$06$i86) + ($11<<1)|0);
           $451 = ($444|0)==(0);
           if ($451) {
            break;
           } else {
            $$04$i88 = $444;$d$05$i87 = $449;$s$06$i86 = $450;
           }
          }
         }
        }
       } while(0);
       $455 = ($g0$0|0)==(0|0);
       L307: do {
        if (!($455)) {
         $456 = ($g1$0|0)==(0|0);
         if ($456) {
          if ($42) {
           break;
          } else {
           $$11$i81 = $0;$d$12$i80 = $g0$0;
          }
          while(1) {
           $465 = (($$11$i81) + -1)|0;
           HEAPF32[$d$12$i80>>2] = Math_fround(1.0);
           $466 = (($d$12$i80) + ($8<<2)|0);
           $467 = ($465|0)==(0);
           if ($467) {
            break L307;
           } else {
            $$11$i81 = $465;$d$12$i80 = $466;
           }
          }
         }
         if (!($42)) {
          $$04$i79 = $0;$d$05$i78 = $g0$0;$s$06$i77 = $g1$0;
          while(1) {
           $457 = (($$04$i79) + -1)|0;
           $458 = HEAP16[$s$06$i77>>1]|0;
           $459 = $458&65535;
           $460 = (875048 + ($459<<2)|0);
           $461 = Math_fround(HEAPF32[$460>>2]);
           HEAPF32[$d$05$i78>>2] = $461;
           $462 = (($d$05$i78) + ($8<<2)|0);
           $463 = (($s$06$i77) + ($11<<1)|0);
           $464 = ($457|0)==(0);
           if ($464) {
            break;
           } else {
            $$04$i79 = $457;$d$05$i78 = $462;$s$06$i77 = $463;
           }
          }
         }
        }
       } while(0);
       $468 = ($$2|0)==(0|0);
       L318: do {
        if (!($468)) {
         $469 = ($$4|0)==(0|0);
         if ($469) {
          if ($42) {
           break;
          } else {
           $$11$i72 = $0;$d$12$i71 = $$2;
          }
          while(1) {
           $478 = (($$11$i72) + -1)|0;
           HEAPF32[$d$12$i71>>2] = Math_fround(1.0);
           $479 = (($d$12$i71) + ($8<<2)|0);
           $480 = ($478|0)==(0);
           if ($480) {
            break L318;
           } else {
            $$11$i72 = $478;$d$12$i71 = $479;
           }
          }
         }
         if (!($42)) {
          $$04$i70 = $0;$d$05$i69 = $$2;$s$06$i68 = $$4;
          while(1) {
           $470 = (($$04$i70) + -1)|0;
           $471 = HEAP16[$s$06$i68>>1]|0;
           $472 = $471&65535;
           $473 = (875048 + ($472<<2)|0);
           $474 = Math_fround(HEAPF32[$473>>2]);
           HEAPF32[$d$05$i69>>2] = $474;
           $475 = (($d$05$i69) + ($8<<2)|0);
           $476 = (($s$06$i68) + ($11<<1)|0);
           $477 = ($470|0)==(0);
           if ($477) {
            break;
           } else {
            $$04$i70 = $470;$d$05$i69 = $475;$s$06$i68 = $476;
           }
          }
         }
        }
       } while(0);
       $481 = ($a0$0|0)==(0|0);
       if ($481) {
        break;
       }
       $482 = ($a1$0|0)==(0|0);
       if ($482) {
        if ($42) {
         break;
        } else {
         $$11$i64 = $0;$d$12$i63 = $a0$0;
        }
        while(1) {
         $491 = (($$11$i64) + -1)|0;
         HEAPF32[$d$12$i63>>2] = Math_fround(1.0);
         $492 = (($d$12$i63) + ($8<<2)|0);
         $493 = ($491|0)==(0);
         if ($493) {
          break L227;
         } else {
          $$11$i64 = $491;$d$12$i63 = $492;
         }
        }
       }
       if ($42) {
        break;
       }
       $$04$i62 = $0;$d$05$i61 = $a0$0;$s$06$i60 = $a1$0;
       while(1) {
        $483 = (($$04$i62) + -1)|0;
        $484 = HEAP16[$s$06$i60>>1]|0;
        $485 = $484&65535;
        $486 = (875048 + ($485<<2)|0);
        $487 = Math_fround(HEAPF32[$486>>2]);
        HEAPF32[$d$05$i61>>2] = $487;
        $488 = (($d$05$i61) + ($8<<2)|0);
        $489 = (($s$06$i60) + ($11<<1)|0);
        $490 = ($483|0)==(0);
        if ($490) {
         break;
        } else {
         $$04$i62 = $483;$d$05$i61 = $488;$s$06$i60 = $489;
        }
       }
      } else {
       break;
      }
     }
    } while(0);
    $494 = $359 & 536870912;
    $495 = ($494|0)==(0);
    if (!($495)) {
     if ((($20|0) == 1)) {
      if ($42) {
       break;
      }
      $$in$i34 = $0;$a0$04$i35 = $a0$0;$a1$08$i = $a1$0;$b1$07$i = $$4;$g1$06$i = $g1$0;$i0$03$i = $$2;$r1$05$i = $$3;
      while(1) {
       $516 = (($$in$i34) + -1)|0;
       $517 = ($r1$05$i|0)==(0|0);
       if ($517) {
        $r$0$i = Math_fround(0.298999994993209838867);$r1$1$i = 0;
       } else {
        $518 = Math_fround(HEAPF32[$r1$05$i>>2]);
        $519 = (($r1$05$i) + ($11<<2)|0);
        $phitmp2$i = Math_fround($518 * Math_fround(0.298999994993209838867));
        $r$0$i = $phitmp2$i;$r1$1$i = $519;
       }
       $520 = ($g1$06$i|0)==(0|0);
       if ($520) {
        $g$0$i = Math_fround(0.587000012397766113281);$g1$1$i = 0;
       } else {
        $521 = Math_fround(HEAPF32[$g1$06$i>>2]);
        $522 = (($g1$06$i) + ($11<<2)|0);
        $phitmp1$i = Math_fround($521 * Math_fround(0.587000012397766113281));
        $g$0$i = $phitmp1$i;$g1$1$i = $522;
       }
       $523 = ($b1$07$i|0)==(0|0);
       if ($523) {
        $b$0$i = Math_fround(0.114000000059604644775);$b1$1$i = 0;
       } else {
        $524 = Math_fround(HEAPF32[$b1$07$i>>2]);
        $525 = (($b1$07$i) + ($11<<2)|0);
        $phitmp$i = Math_fround($524 * Math_fround(0.114000000059604644775));
        $b$0$i = $phitmp$i;$b1$1$i = $525;
       }
       $526 = ($a1$08$i|0)==(0|0);
       if ($526) {
        $a$0$i37 = Math_fround(1.0);$a1$1$i36 = 0;
       } else {
        $527 = Math_fround(HEAPF32[$a1$08$i>>2]);
        $528 = (($a1$08$i) + ($11<<2)|0);
        $a$0$i37 = $527;$a1$1$i36 = $528;
       }
       $529 = ($i0$03$i|0)==(0|0);
       if ($529) {
        $i0$1$i = 0;
       } else {
        $530 = Math_fround($g$0$i + $b$0$i);
        $531 = Math_fround($r$0$i + $530);
        HEAPF32[$i0$03$i>>2] = $531;
        $532 = (($i0$03$i) + ($8<<2)|0);
        $i0$1$i = $532;
       }
       $533 = ($a0$04$i35|0)==(0|0);
       if ($533) {
        $a0$0$be$i38 = 0;
       } else {
        HEAPF32[$a0$04$i35>>2] = $a$0$i37;
        $534 = (($a0$04$i35) + ($8<<2)|0);
        $a0$0$be$i38 = $534;
       }
       $535 = ($516|0)==(0);
       if ($535) {
        break;
       } else {
        $$in$i34 = $516;$a0$04$i35 = $a0$0$be$i38;$a1$08$i = $a1$1$i36;$b1$07$i = $b1$1$i;$g1$06$i = $g1$1$i;$i0$03$i = $i0$1$i;$r1$05$i = $r1$1$i;
       }
      }
     } else if ((($20|0) == 0)) {
      $496 = ($$2|0)==(0|0);
      L364: do {
       if (!($496)) {
        $497 = ($$4|0)==(0|0);
        if ($497) {
         if ($42) {
          break;
         } else {
          $$11$i55 = $0;$d$12$i54 = $$2;
         }
         while(1) {
          $503 = (($$11$i55) + -1)|0;
          HEAPF32[$d$12$i54>>2] = Math_fround(1.0);
          $504 = (($d$12$i54) + ($8<<2)|0);
          $505 = ($503|0)==(0);
          if ($505) {
           break L364;
          } else {
           $$11$i55 = $503;$d$12$i54 = $504;
          }
         }
        }
        if (!($42)) {
         $$04$i53 = $0;$d$05$i52 = $$2;$s$06$i51 = $$4;
         while(1) {
          $498 = (($$04$i53) + -1)|0;
          $499 = Math_fround(HEAPF32[$s$06$i51>>2]);
          HEAPF32[$d$05$i52>>2] = $499;
          $500 = (($d$05$i52) + ($8<<2)|0);
          $501 = (($s$06$i51) + ($11<<2)|0);
          $502 = ($498|0)==(0);
          if ($502) {
           break;
          } else {
           $$04$i53 = $498;$d$05$i52 = $500;$s$06$i51 = $501;
          }
         }
        }
       }
      } while(0);
      $506 = ($a0$0|0)==(0|0);
      if ($506) {
       break;
      }
      $507 = ($a1$0|0)==(0|0);
      if ($507) {
       if ($42) {
        break;
       } else {
        $$11$i46 = $0;$d$12$i45 = $a0$0;
       }
       while(1) {
        $513 = (($$11$i46) + -1)|0;
        HEAPF32[$d$12$i45>>2] = Math_fround(1.0);
        $514 = (($d$12$i45) + ($8<<2)|0);
        $515 = ($513|0)==(0);
        if ($515) {
         break L225;
        } else {
         $$11$i46 = $513;$d$12$i45 = $514;
        }
       }
      }
      if ($42) {
       break;
      }
      $$04$i44 = $0;$d$05$i43 = $a0$0;$s$06$i42 = $a1$0;
      while(1) {
       $508 = (($$04$i44) + -1)|0;
       $509 = Math_fround(HEAPF32[$s$06$i42>>2]);
       HEAPF32[$d$05$i43>>2] = $509;
       $510 = (($d$05$i43) + ($8<<2)|0);
       $511 = (($s$06$i42) + ($11<<2)|0);
       $512 = ($508|0)==(0);
       if ($512) {
        break;
       } else {
        $$04$i44 = $508;$d$05$i43 = $510;$s$06$i42 = $511;
       }
      }
     } else if ((($20|0) == 2)) {
      if ($42) {
       break;
      }
      $$in$i = $0;$a0$04$i = $a0$0;$a1$06$i = $a1$0;$b0$03$i = $$2;$g0$02$i = $g0$0;$i1$05$i = $$4;$r0$01$i = $$1;
      while(1) {
       $536 = (($$in$i) + -1)|0;
       $537 = ($i1$05$i|0)==(0|0);
       if ($537) {
        $i$0$i = Math_fround(1.0);$i1$1$i = 0;
       } else {
        $538 = Math_fround(HEAPF32[$i1$05$i>>2]);
        $539 = (($i1$05$i) + ($11<<2)|0);
        $i$0$i = $538;$i1$1$i = $539;
       }
       $540 = ($a1$06$i|0)==(0|0);
       if ($540) {
        $a$0$i = Math_fround(1.0);$a1$1$i = 0;
       } else {
        $541 = Math_fround(HEAPF32[$a1$06$i>>2]);
        $542 = (($a1$06$i) + ($11<<2)|0);
        $a$0$i = $541;$a1$1$i = $542;
       }
       $543 = ($r0$01$i|0)==(0|0);
       if ($543) {
        $r0$1$i = 0;
       } else {
        HEAPF32[$r0$01$i>>2] = $i$0$i;
        $544 = (($r0$01$i) + ($8<<2)|0);
        $r0$1$i = $544;
       }
       $545 = ($g0$02$i|0)==(0|0);
       if ($545) {
        $g0$1$i = 0;
       } else {
        HEAPF32[$g0$02$i>>2] = $i$0$i;
        $546 = (($g0$02$i) + ($8<<2)|0);
        $g0$1$i = $546;
       }
       $547 = ($b0$03$i|0)==(0|0);
       if ($547) {
        $b0$1$i = 0;
       } else {
        HEAPF32[$b0$03$i>>2] = $i$0$i;
        $548 = (($b0$03$i) + ($8<<2)|0);
        $b0$1$i = $548;
       }
       $549 = ($a0$04$i|0)==(0|0);
       if ($549) {
        $a0$0$be$i = 0;
       } else {
        HEAPF32[$a0$04$i>>2] = $a$0$i;
        $550 = (($a0$04$i) + ($8<<2)|0);
        $a0$0$be$i = $550;
       }
       $551 = ($536|0)==(0);
       if ($551) {
        break;
       } else {
        $$in$i = $536;$a0$04$i = $a0$0$be$i;$a1$06$i = $a1$1$i;$b0$03$i = $b0$1$i;$g0$02$i = $g0$1$i;$i1$05$i = $i1$1$i;$r0$01$i = $r0$1$i;
       }
      }
     } else if ((($20|0) == 3)) {
      $552 = ($$1|0)==(0|0);
      L407: do {
       if (!($552)) {
        $553 = ($$3|0)==(0|0);
        if ($553) {
         if ($42) {
          break;
         } else {
          $$11$i29 = $0;$d$12$i28 = $$1;
         }
         while(1) {
          $559 = (($$11$i29) + -1)|0;
          HEAPF32[$d$12$i28>>2] = Math_fround(1.0);
          $560 = (($d$12$i28) + ($8<<2)|0);
          $561 = ($559|0)==(0);
          if ($561) {
           break L407;
          } else {
           $$11$i29 = $559;$d$12$i28 = $560;
          }
         }
        }
        if (!($42)) {
         $$04$i27 = $0;$d$05$i26 = $$1;$s$06$i25 = $$3;
         while(1) {
          $554 = (($$04$i27) + -1)|0;
          $555 = Math_fround(HEAPF32[$s$06$i25>>2]);
          HEAPF32[$d$05$i26>>2] = $555;
          $556 = (($d$05$i26) + ($8<<2)|0);
          $557 = (($s$06$i25) + ($11<<2)|0);
          $558 = ($554|0)==(0);
          if ($558) {
           break;
          } else {
           $$04$i27 = $554;$d$05$i26 = $556;$s$06$i25 = $557;
          }
         }
        }
       }
      } while(0);
      $562 = ($g0$0|0)==(0|0);
      L418: do {
       if (!($562)) {
        $563 = ($g1$0|0)==(0|0);
        if ($563) {
         if ($42) {
          break;
         } else {
          $$11$i20 = $0;$d$12$i19 = $g0$0;
         }
         while(1) {
          $569 = (($$11$i20) + -1)|0;
          HEAPF32[$d$12$i19>>2] = Math_fround(1.0);
          $570 = (($d$12$i19) + ($8<<2)|0);
          $571 = ($569|0)==(0);
          if ($571) {
           break L418;
          } else {
           $$11$i20 = $569;$d$12$i19 = $570;
          }
         }
        }
        if (!($42)) {
         $$04$i18 = $0;$d$05$i17 = $g0$0;$s$06$i16 = $g1$0;
         while(1) {
          $564 = (($$04$i18) + -1)|0;
          $565 = Math_fround(HEAPF32[$s$06$i16>>2]);
          HEAPF32[$d$05$i17>>2] = $565;
          $566 = (($d$05$i17) + ($8<<2)|0);
          $567 = (($s$06$i16) + ($11<<2)|0);
          $568 = ($564|0)==(0);
          if ($568) {
           break;
          } else {
           $$04$i18 = $564;$d$05$i17 = $566;$s$06$i16 = $567;
          }
         }
        }
       }
      } while(0);
      $572 = ($$2|0)==(0|0);
      L429: do {
       if (!($572)) {
        $573 = ($$4|0)==(0|0);
        if ($573) {
         if ($42) {
          break;
         } else {
          $$11$i11 = $0;$d$12$i10 = $$2;
         }
         while(1) {
          $579 = (($$11$i11) + -1)|0;
          HEAPF32[$d$12$i10>>2] = Math_fround(1.0);
          $580 = (($d$12$i10) + ($8<<2)|0);
          $581 = ($579|0)==(0);
          if ($581) {
           break L429;
          } else {
           $$11$i11 = $579;$d$12$i10 = $580;
          }
         }
        }
        if (!($42)) {
         $$04$i9 = $0;$d$05$i8 = $$2;$s$06$i7 = $$4;
         while(1) {
          $574 = (($$04$i9) + -1)|0;
          $575 = Math_fround(HEAPF32[$s$06$i7>>2]);
          HEAPF32[$d$05$i8>>2] = $575;
          $576 = (($d$05$i8) + ($8<<2)|0);
          $577 = (($s$06$i7) + ($11<<2)|0);
          $578 = ($574|0)==(0);
          if ($578) {
           break;
          } else {
           $$04$i9 = $574;$d$05$i8 = $576;$s$06$i7 = $577;
          }
         }
        }
       }
      } while(0);
      $582 = ($a0$0|0)==(0|0);
      if ($582) {
       break;
      }
      $583 = ($a1$0|0)==(0|0);
      if ($583) {
       if ($42) {
        break;
       } else {
        $$11$i = $0;$d$12$i = $a0$0;
       }
       while(1) {
        $589 = (($$11$i) + -1)|0;
        HEAPF32[$d$12$i>>2] = Math_fround(1.0);
        $590 = (($d$12$i) + ($8<<2)|0);
        $591 = ($589|0)==(0);
        if ($591) {
         break L225;
        } else {
         $$11$i = $589;$d$12$i = $590;
        }
       }
      }
      if ($42) {
       break;
      }
      $$04$i = $0;$d$05$i = $a0$0;$s$06$i = $a1$0;
      while(1) {
       $584 = (($$04$i) + -1)|0;
       $585 = Math_fround(HEAPF32[$s$06$i>>2]);
       HEAPF32[$d$05$i>>2] = $585;
       $586 = (($d$05$i) + ($8<<2)|0);
       $587 = (($s$06$i) + ($11<<2)|0);
       $588 = ($584|0)==(0);
       if ($588) {
        break;
       } else {
        $$04$i = $584;$d$05$i = $586;$s$06$i = $587;
       }
      }
     } else {
      break;
     }
    }
   }
  } while(0);
  $exitcond = ($y$0309|0)==($2|0);
  if ($exitcond) {
   break;
  }
  $592 = (($s$0310) + ($6)|0);
  $593 = (($d$0311) + ($4)|0);
  $phitmp = (($y$0309) + 1)|0;
  $84 = $356;$d$0311 = $593;$s$0310 = $592;$y$0309 = $phitmp;
 }
 STACKTOP = sp;return;
}
function __Z13BlitCopyFloatI4halffEvRN6prcore7SurfaceERKS2_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$04$i = 0, $$04$i136 = 0, $$04$i145 = 0, $$04$i18 = 0, $$04$i27 = 0, $$04$i44 = 0, $$04$i53 = 0, $$04$i62 = 0, $$04$i70 = 0, $$04$i79 = 0, $$04$i88 = 0, $$04$i9 = 0, $$06$i = 0, $$06$i156 = 0, $$06$i168 = 0, $$06$i180 = 0, $$06$i192 = 0, $$06$i204 = 0, $$06$i216 = 0, $$06$i226 = 0;
 var $$06$i237 = 0, $$06$i248 = 0, $$06$i259 = 0, $$06$i270 = 0, $$1 = 0, $$11$i = 0, $$11$i11 = 0, $$11$i138 = 0, $$11$i147 = 0, $$11$i20 = 0, $$11$i29 = 0, $$11$i46 = 0, $$11$i55 = 0, $$11$i64 = 0, $$11$i72 = 0, $$11$i81 = 0, $$11$i90 = 0, $$13$i = 0, $$13$i159 = 0, $$13$i171 = 0;
 var $$13$i183 = 0, $$13$i195 = 0, $$13$i207 = 0, $$13$i218 = 0, $$13$i228 = 0, $$13$i239 = 0, $$13$i250 = 0, $$13$i261 = 0, $$13$i272 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$in$i = 0, $$in$i111 = 0, $$in$i34 = 0, $$in$i94 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0);
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0);
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = Math_fround(0), $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = Math_fround(0), $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0$i = Math_fround(0), $a$0$i104 = Math_fround(0), $a$0$i128 = Math_fround(0), $a$0$i37 = Math_fround(0), $a0$0 = 0, $a0$0$be$i = 0, $a0$0$be$i108 = 0, $a0$0$be$i130 = 0, $a0$0$be$i38 = 0, $a0$04$i = 0;
 var $a0$04$i116 = 0, $a0$04$i35 = 0, $a0$04$i97 = 0, $a1$0 = 0, $a1$06$i = 0, $a1$06$i95 = 0, $a1$08$i = 0, $a1$08$i112 = 0, $a1$1$i = 0, $a1$1$i103 = 0, $a1$1$i127 = 0, $a1$1$i36 = 0, $b$0$i = Math_fround(0), $b$0$i126 = Math_fround(0), $b0$03$i = 0, $b0$03$i98 = 0, $b0$1$i = 0, $b0$1$i107 = 0, $b1$07$i = 0, $b1$07$i113 = 0;
 var $b1$1$i = 0, $b1$1$i125 = 0, $d$0311 = 0, $d$05$i = 0, $d$05$i135 = 0, $d$05$i144 = 0, $d$05$i17 = 0, $d$05$i26 = 0, $d$05$i43 = 0, $d$05$i52 = 0, $d$05$i61 = 0, $d$05$i69 = 0, $d$05$i78 = 0, $d$05$i8 = 0, $d$05$i87 = 0, $d$07$i = 0, $d$07$i155 = 0, $d$07$i167 = 0, $d$07$i179 = 0, $d$07$i191 = 0;
 var $d$07$i203 = 0, $d$07$i215 = 0, $d$07$i225 = 0, $d$07$i236 = 0, $d$07$i247 = 0, $d$07$i258 = 0, $d$07$i269 = 0, $d$12$i = 0, $d$12$i10 = 0, $d$12$i137 = 0, $d$12$i146 = 0, $d$12$i19 = 0, $d$12$i28 = 0, $d$12$i45 = 0, $d$12$i54 = 0, $d$12$i63 = 0, $d$12$i71 = 0, $d$12$i80 = 0, $d$12$i89 = 0, $d$14$i = 0;
 var $d$14$i158 = 0, $d$14$i170 = 0, $d$14$i182 = 0, $d$14$i194 = 0, $d$14$i206 = 0, $d$14$i217 = 0, $d$14$i227 = 0, $d$14$i238 = 0, $d$14$i249 = 0, $d$14$i260 = 0, $d$14$i271 = 0, $exitcond = 0, $g$0$i = Math_fround(0), $g$0$i123 = Math_fround(0), $g0$0 = 0, $g0$02$i = 0, $g0$02$i99 = 0, $g0$1$i = 0, $g0$1$i106 = 0, $g1$0 = 0;
 var $g1$06$i = 0, $g1$06$i114 = 0, $g1$1$i = 0, $g1$1$i122 = 0, $i$0$i = Math_fround(0), $i$0$i102 = Math_fround(0), $i0$03$i = 0, $i0$03$i117 = 0, $i0$1$i = 0, $i0$1$i129 = 0, $i1$05$i = 0, $i1$05$i96 = 0, $i1$1$i = 0, $i1$1$i101 = 0, $phitmp = 0, $phitmp$i = Math_fround(0), $phitmp$i124 = Math_fround(0), $phitmp1$i = Math_fround(0), $phitmp1$i121 = Math_fround(0), $phitmp2$i = Math_fround(0);
 var $phitmp2$i118 = Math_fround(0), $r$0$i = Math_fround(0), $r$0$i120 = Math_fround(0), $r0$01$i = 0, $r0$01$i100 = 0, $r0$1$i = 0, $r0$1$i105 = 0, $r1$05$i = 0, $r1$05$i115 = 0, $r1$1$i = 0, $r1$1$i119 = 0, $s$0310 = 0, $s$06$i = 0, $s$06$i134 = 0, $s$06$i143 = 0, $s$06$i16 = 0, $s$06$i25 = 0, $s$06$i42 = 0, $s$06$i51 = 0, $s$06$i60 = 0;
 var $s$06$i68 = 0, $s$06$i7 = 0, $s$06$i77 = 0, $s$06$i86 = 0, $s$08$i = 0, $s$08$i154 = 0, $s$08$i166 = 0, $s$08$i178 = 0, $s$08$i190 = 0, $s$08$i202 = 0, $s$08$i214 = 0, $s$08$i224 = 0, $s$08$i235 = 0, $s$08$i246 = 0, $s$08$i257 = 0, $s$08$i268 = 0, $y$0309 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$dest>>2]|0;
 $1 = (($dest) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($dest) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($source) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4>>>0) / ($0>>>0))&-1;
 $8 = $7 >>> 1;
 $9 = HEAP32[$source>>2]|0;
 $10 = (($6>>>0) / ($9>>>0))&-1;
 $11 = $10 >>> 2;
 $12 = (($dest) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 27;
 $15 = $14 & 2;
 $16 = (($source) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 >>> 28;
 $19 = $18 & 1;
 $20 = $19 | $15;
 $21 = ($2|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($source) + 40|0);
 $23 = (($dest) + 40|0);
 $24 = HEAP32[$22>>2]|0;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($dest) + 38|0);
 $27 = (($dest) + 37|0);
 $28 = (($dest) + 36|0);
 $29 = (($dest) + 39|0);
 $30 = (($dest) + 16|0);
 $31 = (($dest) + 20|0);
 $32 = (($dest) + 24|0);
 $33 = (($dest) + 28|0);
 $34 = (($source) + 38|0);
 $35 = (($source) + 37|0);
 $36 = (($source) + 36|0);
 $37 = (($source) + 39|0);
 $38 = (($source) + 16|0);
 $39 = (($source) + 20|0);
 $40 = (($source) + 24|0);
 $41 = (($source) + 28|0);
 $42 = ($0|0)==(0);
 $84 = $13;$d$0311 = $25;$s$0310 = $24;$y$0309 = 1;
 while(1) {
  $43 = HEAP8[$26>>0]|0;
  $44 = $43&255;
  $45 = (($d$0311) + ($44<<1)|0);
  $46 = HEAP8[$27>>0]|0;
  $47 = $46&255;
  $48 = (($d$0311) + ($47<<1)|0);
  $49 = HEAP8[$28>>0]|0;
  $50 = $49&255;
  $51 = (($d$0311) + ($50<<1)|0);
  $52 = HEAP8[$29>>0]|0;
  $53 = $52&255;
  $54 = (($d$0311) + ($53<<1)|0);
  $55 = HEAP32[$30>>2]|0;
  $56 = ($55|0)==(0);
  $$1 = $56 ? 0 : $45;
  $57 = HEAP32[$31>>2]|0;
  $58 = ($57|0)==(0);
  $g0$0 = $58 ? 0 : $48;
  $59 = HEAP32[$32>>2]|0;
  $60 = ($59|0)==(0);
  $$2 = $60 ? 0 : $51;
  $61 = HEAP32[$33>>2]|0;
  $62 = ($61|0)==(0);
  $a0$0 = $62 ? 0 : $54;
  $63 = HEAP8[$34>>0]|0;
  $64 = $63&255;
  $65 = (($s$0310) + ($64<<2)|0);
  $66 = HEAP8[$35>>0]|0;
  $67 = $66&255;
  $68 = (($s$0310) + ($67<<2)|0);
  $69 = HEAP8[$36>>0]|0;
  $70 = $69&255;
  $71 = (($s$0310) + ($70<<2)|0);
  $72 = HEAP8[$37>>0]|0;
  $73 = $72&255;
  $74 = (($s$0310) + ($73<<2)|0);
  $75 = HEAP32[$38>>2]|0;
  $76 = ($75|0)==(0);
  $$3 = $76 ? 0 : $65;
  $77 = HEAP32[$39>>2]|0;
  $78 = ($77|0)==(0);
  $g1$0 = $78 ? 0 : $68;
  $79 = HEAP32[$40>>2]|0;
  $80 = ($79|0)==(0);
  $$4 = $80 ? 0 : $71;
  $81 = HEAP32[$41>>2]|0;
  $82 = ($81|0)==(0);
  $a1$0 = $82 ? 0 : $74;
  $83 = $84 & 1073741824;
  $85 = ($83|0)==(0);
  L6: do {
   if (!($85)) {
    $86 = HEAP32[$16>>2]|0;
    $87 = $86 & 1073741824;
    $88 = ($87|0)==(0);
    L8: do {
     if (!($88)) {
      if ((($20|0) == 0)) {
       $89 = ($$2|0)==(0|0);
       L12: do {
        if (!($89)) {
         $90 = ($$4|0)==(0|0);
         if (!($90)) {
          if ($42) {
           break;
          }
          $$06$i270 = $0;$d$07$i269 = $$2;$s$08$i268 = $$4;
          while(1) {
           $91 = (($$06$i270) + -1)|0;
           $92 = HEAP16[$s$08$i268>>1]|0;
           HEAP16[$d$07$i269>>1] = $92;
           $93 = (($d$07$i269) + ($8<<1)|0);
           $94 = (($s$08$i268) + ($11<<1)|0);
           $95 = ($91|0)==(0);
           if ($95) {
            break L12;
           } else {
            $$06$i270 = $91;$d$07$i269 = $93;$s$08$i268 = $94;
           }
          }
         }
         if (!($42)) {
          $$13$i272 = $0;$d$14$i271 = $$2;
          while(1) {
           $96 = (($$13$i272) + -1)|0;
           $97 = (1137192 + 254|0);
           $98 = HEAP16[$97>>1]|0;
           $99 = ($98<<16>>16)==(0);
           if ($99) {
            $100 = (__ZN4half7convertEi(1065353216)|0);
            $101 = $100;
           } else {
            $101 = $98;
           }
           HEAP16[$d$14$i271>>1] = $101;
           $102 = ($96|0)==(0);
           if ($102) {
            break L12;
           }
           $103 = (($d$14$i271) + ($8<<1)|0);
           $$13$i272 = $96;$d$14$i271 = $103;
          }
         }
        }
       } while(0);
       $104 = ($a0$0|0)==(0|0);
       if ($104) {
        break;
       }
       $105 = ($a1$0|0)==(0|0);
       if (!($105)) {
        if ($42) {
         break;
        }
        $$06$i259 = $0;$d$07$i258 = $a0$0;$s$08$i257 = $a1$0;
        while(1) {
         $106 = (($$06$i259) + -1)|0;
         $107 = HEAP16[$s$08$i257>>1]|0;
         HEAP16[$d$07$i258>>1] = $107;
         $108 = (($d$07$i258) + ($8<<1)|0);
         $109 = (($s$08$i257) + ($11<<1)|0);
         $110 = ($106|0)==(0);
         if ($110) {
          break L8;
         } else {
          $$06$i259 = $106;$d$07$i258 = $108;$s$08$i257 = $109;
         }
        }
       }
       if ($42) {
        break;
       } else {
        $$13$i261 = $0;$d$14$i260 = $a0$0;
       }
       while(1) {
        $111 = (($$13$i261) + -1)|0;
        $112 = (1137192 + 254|0);
        $113 = HEAP16[$112>>1]|0;
        $114 = ($113<<16>>16)==(0);
        if ($114) {
         $115 = (__ZN4half7convertEi(1065353216)|0);
         $116 = $115;
        } else {
         $116 = $113;
        }
        HEAP16[$d$14$i260>>1] = $116;
        $117 = ($111|0)==(0);
        if ($117) {
         break L8;
        }
        $118 = (($d$14$i260) + ($8<<1)|0);
        $$13$i261 = $111;$d$14$i260 = $118;
       }
      } else if ((($20|0) == 2)) {
       __Z12COPY_FRGB_FII4halfS0_EvjjjPvS1_S1_S1_PKvS3_($0,$8,$11,$$1,$g0$0,$$2,$a0$0,$$4,$a1$0);
       break;
      } else if ((($20|0) == 3)) {
       $119 = ($$1|0)==(0|0);
       L42: do {
        if (!($119)) {
         $120 = ($$3|0)==(0|0);
         if (!($120)) {
          if ($42) {
           break;
          }
          $$06$i248 = $0;$d$07$i247 = $$1;$s$08$i246 = $$3;
          while(1) {
           $121 = (($$06$i248) + -1)|0;
           $122 = HEAP16[$s$08$i246>>1]|0;
           HEAP16[$d$07$i247>>1] = $122;
           $123 = (($d$07$i247) + ($8<<1)|0);
           $124 = (($s$08$i246) + ($11<<1)|0);
           $125 = ($121|0)==(0);
           if ($125) {
            break L42;
           } else {
            $$06$i248 = $121;$d$07$i247 = $123;$s$08$i246 = $124;
           }
          }
         }
         if (!($42)) {
          $$13$i250 = $0;$d$14$i249 = $$1;
          while(1) {
           $126 = (($$13$i250) + -1)|0;
           $127 = (1137192 + 254|0);
           $128 = HEAP16[$127>>1]|0;
           $129 = ($128<<16>>16)==(0);
           if ($129) {
            $130 = (__ZN4half7convertEi(1065353216)|0);
            $131 = $130;
           } else {
            $131 = $128;
           }
           HEAP16[$d$14$i249>>1] = $131;
           $132 = ($126|0)==(0);
           if ($132) {
            break L42;
           }
           $133 = (($d$14$i249) + ($8<<1)|0);
           $$13$i250 = $126;$d$14$i249 = $133;
          }
         }
        }
       } while(0);
       $134 = ($g0$0|0)==(0|0);
       L57: do {
        if (!($134)) {
         $135 = ($g1$0|0)==(0|0);
         if (!($135)) {
          if ($42) {
           break;
          }
          $$06$i237 = $0;$d$07$i236 = $g0$0;$s$08$i235 = $g1$0;
          while(1) {
           $136 = (($$06$i237) + -1)|0;
           $137 = HEAP16[$s$08$i235>>1]|0;
           HEAP16[$d$07$i236>>1] = $137;
           $138 = (($d$07$i236) + ($8<<1)|0);
           $139 = (($s$08$i235) + ($11<<1)|0);
           $140 = ($136|0)==(0);
           if ($140) {
            break L57;
           } else {
            $$06$i237 = $136;$d$07$i236 = $138;$s$08$i235 = $139;
           }
          }
         }
         if (!($42)) {
          $$13$i239 = $0;$d$14$i238 = $g0$0;
          while(1) {
           $141 = (($$13$i239) + -1)|0;
           $142 = (1137192 + 254|0);
           $143 = HEAP16[$142>>1]|0;
           $144 = ($143<<16>>16)==(0);
           if ($144) {
            $145 = (__ZN4half7convertEi(1065353216)|0);
            $146 = $145;
           } else {
            $146 = $143;
           }
           HEAP16[$d$14$i238>>1] = $146;
           $147 = ($141|0)==(0);
           if ($147) {
            break L57;
           }
           $148 = (($d$14$i238) + ($8<<1)|0);
           $$13$i239 = $141;$d$14$i238 = $148;
          }
         }
        }
       } while(0);
       $149 = ($$2|0)==(0|0);
       L72: do {
        if (!($149)) {
         $150 = ($$4|0)==(0|0);
         if (!($150)) {
          if ($42) {
           break;
          }
          $$06$i226 = $0;$d$07$i225 = $$2;$s$08$i224 = $$4;
          while(1) {
           $151 = (($$06$i226) + -1)|0;
           $152 = HEAP16[$s$08$i224>>1]|0;
           HEAP16[$d$07$i225>>1] = $152;
           $153 = (($d$07$i225) + ($8<<1)|0);
           $154 = (($s$08$i224) + ($11<<1)|0);
           $155 = ($151|0)==(0);
           if ($155) {
            break L72;
           } else {
            $$06$i226 = $151;$d$07$i225 = $153;$s$08$i224 = $154;
           }
          }
         }
         if (!($42)) {
          $$13$i228 = $0;$d$14$i227 = $$2;
          while(1) {
           $156 = (($$13$i228) + -1)|0;
           $157 = (1137192 + 254|0);
           $158 = HEAP16[$157>>1]|0;
           $159 = ($158<<16>>16)==(0);
           if ($159) {
            $160 = (__ZN4half7convertEi(1065353216)|0);
            $161 = $160;
           } else {
            $161 = $158;
           }
           HEAP16[$d$14$i227>>1] = $161;
           $162 = ($156|0)==(0);
           if ($162) {
            break L72;
           }
           $163 = (($d$14$i227) + ($8<<1)|0);
           $$13$i228 = $156;$d$14$i227 = $163;
          }
         }
        }
       } while(0);
       $164 = ($a0$0|0)==(0|0);
       if ($164) {
        break;
       }
       $165 = ($a1$0|0)==(0|0);
       if (!($165)) {
        if ($42) {
         break;
        }
        $$06$i216 = $0;$d$07$i215 = $a0$0;$s$08$i214 = $a1$0;
        while(1) {
         $166 = (($$06$i216) + -1)|0;
         $167 = HEAP16[$s$08$i214>>1]|0;
         HEAP16[$d$07$i215>>1] = $167;
         $168 = (($d$07$i215) + ($8<<1)|0);
         $169 = (($s$08$i214) + ($11<<1)|0);
         $170 = ($166|0)==(0);
         if ($170) {
          break L8;
         } else {
          $$06$i216 = $166;$d$07$i215 = $168;$s$08$i214 = $169;
         }
        }
       }
       if ($42) {
        break;
       } else {
        $$13$i218 = $0;$d$14$i217 = $a0$0;
       }
       while(1) {
        $171 = (($$13$i218) + -1)|0;
        $172 = (1137192 + 254|0);
        $173 = HEAP16[$172>>1]|0;
        $174 = ($173<<16>>16)==(0);
        if ($174) {
         $175 = (__ZN4half7convertEi(1065353216)|0);
         $176 = $175;
        } else {
         $176 = $173;
        }
        HEAP16[$d$14$i217>>1] = $176;
        $177 = ($171|0)==(0);
        if ($177) {
         break L8;
        }
        $178 = (($d$14$i217) + ($8<<1)|0);
        $$13$i218 = $171;$d$14$i217 = $178;
       }
      } else if ((($20|0) == 1)) {
       __Z12COPY_FI_FRGBI4halfS0_EvjjjPvS1_PKvS3_S3_S3_($0,$8,$11,$$2,$a0$0,$$3,$g1$0,$$4,$a1$0);
       break;
      } else {
       break;
      }
     }
    } while(0);
    $179 = HEAP32[$16>>2]|0;
    $180 = $179 & 536870912;
    $181 = ($180|0)==(0);
    if (!($181)) {
     if ((($20|0) == 0)) {
      $182 = ($$2|0)==(0|0);
      L105: do {
       if (!($182)) {
        $183 = ($$4|0)==(0|0);
        if ($183) {
         if ($42) {
          break;
         } else {
          $$13$i207 = $0;$d$14$i206 = $$2;
         }
         while(1) {
          $203 = (($$13$i207) + -1)|0;
          $204 = (1137192 + 254|0);
          $205 = HEAP16[$204>>1]|0;
          $206 = ($205<<16>>16)==(0);
          if ($206) {
           $207 = (__ZN4half7convertEi(1065353216)|0);
           $208 = $207;
          } else {
           $208 = $205;
          }
          HEAP16[$d$14$i206>>1] = $208;
          $209 = ($203|0)==(0);
          if ($209) {
           break L105;
          }
          $210 = (($d$14$i206) + ($8<<1)|0);
          $$13$i207 = $203;$d$14$i206 = $210;
         }
        }
        if (!($42)) {
         $$06$i204 = $0;$d$07$i203 = $$2;$s$08$i202 = $$4;
         while(1) {
          $184 = (($$06$i204) + -1)|0;
          $185 = Math_fround(HEAPF32[$s$08$i202>>2]);
          $186 = $185 == Math_fround(0.0);
          do {
           if ($186) {
            $199 = 0;
           } else {
            $187 = (HEAPF32[tempDoublePtr>>2]=$185,HEAP32[tempDoublePtr>>2]|0);
            $188 = $187 >>> 23;
            $189 = (1137192 + ($188<<1)|0);
            $190 = HEAP16[$189>>1]|0;
            $191 = ($190<<16>>16)==(0);
            if ($191) {
             $198 = (__ZN4half7convertEi($187)|0);
             $199 = $198;
             break;
            } else {
             $192 = $190&65535;
             $193 = $187 & 8388607;
             $194 = (($193) + 4096)|0;
             $195 = $194 >>> 13;
             $196 = (($192) + ($195))|0;
             $197 = $196&65535;
             $199 = $197;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i203>>1] = $199;
          $200 = (($d$07$i203) + ($8<<1)|0);
          $201 = (($s$08$i202) + ($11<<2)|0);
          $202 = ($184|0)==(0);
          if ($202) {
           break;
          } else {
           $$06$i204 = $184;$d$07$i203 = $200;$s$08$i202 = $201;
          }
         }
        }
       }
      } while(0);
      $211 = ($a0$0|0)==(0|0);
      if ($211) {
       break;
      }
      $212 = ($a1$0|0)==(0|0);
      if ($212) {
       if ($42) {
        break;
       } else {
        $$13$i195 = $0;$d$14$i194 = $a0$0;
       }
       while(1) {
        $232 = (($$13$i195) + -1)|0;
        $233 = (1137192 + 254|0);
        $234 = HEAP16[$233>>1]|0;
        $235 = ($234<<16>>16)==(0);
        if ($235) {
         $236 = (__ZN4half7convertEi(1065353216)|0);
         $237 = $236;
        } else {
         $237 = $234;
        }
        HEAP16[$d$14$i194>>1] = $237;
        $238 = ($232|0)==(0);
        if ($238) {
         break L6;
        }
        $239 = (($d$14$i194) + ($8<<1)|0);
        $$13$i195 = $232;$d$14$i194 = $239;
       }
      }
      if ($42) {
       break;
      } else {
       $$06$i192 = $0;$d$07$i191 = $a0$0;$s$08$i190 = $a1$0;
      }
      while(1) {
       $213 = (($$06$i192) + -1)|0;
       $214 = Math_fround(HEAPF32[$s$08$i190>>2]);
       $215 = $214 == Math_fround(0.0);
       do {
        if ($215) {
         $228 = 0;
        } else {
         $216 = (HEAPF32[tempDoublePtr>>2]=$214,HEAP32[tempDoublePtr>>2]|0);
         $217 = $216 >>> 23;
         $218 = (1137192 + ($217<<1)|0);
         $219 = HEAP16[$218>>1]|0;
         $220 = ($219<<16>>16)==(0);
         if ($220) {
          $227 = (__ZN4half7convertEi($216)|0);
          $228 = $227;
          break;
         } else {
          $221 = $219&65535;
          $222 = $216 & 8388607;
          $223 = (($222) + 4096)|0;
          $224 = $223 >>> 13;
          $225 = (($221) + ($224))|0;
          $226 = $225&65535;
          $228 = $226;
          break;
         }
        }
       } while(0);
       HEAP16[$d$07$i191>>1] = $228;
       $229 = (($d$07$i191) + ($8<<1)|0);
       $230 = (($s$08$i190) + ($11<<2)|0);
       $231 = ($213|0)==(0);
       if ($231) {
        break;
       } else {
        $$06$i192 = $213;$d$07$i191 = $229;$s$08$i190 = $230;
       }
      }
     } else if ((($20|0) == 1)) {
      __Z12COPY_FI_FRGBI4halffEvjjjPvS1_PKvS3_S3_S3_($0,$8,$11,$$2,$a0$0,$$3,$g1$0,$$4,$a1$0);
      break;
     } else if ((($20|0) == 3)) {
      $240 = ($$1|0)==(0|0);
      L145: do {
       if (!($240)) {
        $241 = ($$3|0)==(0|0);
        if ($241) {
         if ($42) {
          break;
         } else {
          $$13$i183 = $0;$d$14$i182 = $$1;
         }
         while(1) {
          $261 = (($$13$i183) + -1)|0;
          $262 = (1137192 + 254|0);
          $263 = HEAP16[$262>>1]|0;
          $264 = ($263<<16>>16)==(0);
          if ($264) {
           $265 = (__ZN4half7convertEi(1065353216)|0);
           $266 = $265;
          } else {
           $266 = $263;
          }
          HEAP16[$d$14$i182>>1] = $266;
          $267 = ($261|0)==(0);
          if ($267) {
           break L145;
          }
          $268 = (($d$14$i182) + ($8<<1)|0);
          $$13$i183 = $261;$d$14$i182 = $268;
         }
        }
        if (!($42)) {
         $$06$i180 = $0;$d$07$i179 = $$1;$s$08$i178 = $$3;
         while(1) {
          $242 = (($$06$i180) + -1)|0;
          $243 = Math_fround(HEAPF32[$s$08$i178>>2]);
          $244 = $243 == Math_fround(0.0);
          do {
           if ($244) {
            $257 = 0;
           } else {
            $245 = (HEAPF32[tempDoublePtr>>2]=$243,HEAP32[tempDoublePtr>>2]|0);
            $246 = $245 >>> 23;
            $247 = (1137192 + ($246<<1)|0);
            $248 = HEAP16[$247>>1]|0;
            $249 = ($248<<16>>16)==(0);
            if ($249) {
             $256 = (__ZN4half7convertEi($245)|0);
             $257 = $256;
             break;
            } else {
             $250 = $248&65535;
             $251 = $245 & 8388607;
             $252 = (($251) + 4096)|0;
             $253 = $252 >>> 13;
             $254 = (($250) + ($253))|0;
             $255 = $254&65535;
             $257 = $255;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i179>>1] = $257;
          $258 = (($d$07$i179) + ($8<<1)|0);
          $259 = (($s$08$i178) + ($11<<2)|0);
          $260 = ($242|0)==(0);
          if ($260) {
           break;
          } else {
           $$06$i180 = $242;$d$07$i179 = $258;$s$08$i178 = $259;
          }
         }
        }
       }
      } while(0);
      $269 = ($g0$0|0)==(0|0);
      L165: do {
       if (!($269)) {
        $270 = ($g1$0|0)==(0|0);
        if ($270) {
         if ($42) {
          break;
         } else {
          $$13$i171 = $0;$d$14$i170 = $g0$0;
         }
         while(1) {
          $290 = (($$13$i171) + -1)|0;
          $291 = (1137192 + 254|0);
          $292 = HEAP16[$291>>1]|0;
          $293 = ($292<<16>>16)==(0);
          if ($293) {
           $294 = (__ZN4half7convertEi(1065353216)|0);
           $295 = $294;
          } else {
           $295 = $292;
          }
          HEAP16[$d$14$i170>>1] = $295;
          $296 = ($290|0)==(0);
          if ($296) {
           break L165;
          }
          $297 = (($d$14$i170) + ($8<<1)|0);
          $$13$i171 = $290;$d$14$i170 = $297;
         }
        }
        if (!($42)) {
         $$06$i168 = $0;$d$07$i167 = $g0$0;$s$08$i166 = $g1$0;
         while(1) {
          $271 = (($$06$i168) + -1)|0;
          $272 = Math_fround(HEAPF32[$s$08$i166>>2]);
          $273 = $272 == Math_fround(0.0);
          do {
           if ($273) {
            $286 = 0;
           } else {
            $274 = (HEAPF32[tempDoublePtr>>2]=$272,HEAP32[tempDoublePtr>>2]|0);
            $275 = $274 >>> 23;
            $276 = (1137192 + ($275<<1)|0);
            $277 = HEAP16[$276>>1]|0;
            $278 = ($277<<16>>16)==(0);
            if ($278) {
             $285 = (__ZN4half7convertEi($274)|0);
             $286 = $285;
             break;
            } else {
             $279 = $277&65535;
             $280 = $274 & 8388607;
             $281 = (($280) + 4096)|0;
             $282 = $281 >>> 13;
             $283 = (($279) + ($282))|0;
             $284 = $283&65535;
             $286 = $284;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i167>>1] = $286;
          $287 = (($d$07$i167) + ($8<<1)|0);
          $288 = (($s$08$i166) + ($11<<2)|0);
          $289 = ($271|0)==(0);
          if ($289) {
           break;
          } else {
           $$06$i168 = $271;$d$07$i167 = $287;$s$08$i166 = $288;
          }
         }
        }
       }
      } while(0);
      $298 = ($$2|0)==(0|0);
      L185: do {
       if (!($298)) {
        $299 = ($$4|0)==(0|0);
        if ($299) {
         if ($42) {
          break;
         } else {
          $$13$i159 = $0;$d$14$i158 = $$2;
         }
         while(1) {
          $319 = (($$13$i159) + -1)|0;
          $320 = (1137192 + 254|0);
          $321 = HEAP16[$320>>1]|0;
          $322 = ($321<<16>>16)==(0);
          if ($322) {
           $323 = (__ZN4half7convertEi(1065353216)|0);
           $324 = $323;
          } else {
           $324 = $321;
          }
          HEAP16[$d$14$i158>>1] = $324;
          $325 = ($319|0)==(0);
          if ($325) {
           break L185;
          }
          $326 = (($d$14$i158) + ($8<<1)|0);
          $$13$i159 = $319;$d$14$i158 = $326;
         }
        }
        if (!($42)) {
         $$06$i156 = $0;$d$07$i155 = $$2;$s$08$i154 = $$4;
         while(1) {
          $300 = (($$06$i156) + -1)|0;
          $301 = Math_fround(HEAPF32[$s$08$i154>>2]);
          $302 = $301 == Math_fround(0.0);
          do {
           if ($302) {
            $315 = 0;
           } else {
            $303 = (HEAPF32[tempDoublePtr>>2]=$301,HEAP32[tempDoublePtr>>2]|0);
            $304 = $303 >>> 23;
            $305 = (1137192 + ($304<<1)|0);
            $306 = HEAP16[$305>>1]|0;
            $307 = ($306<<16>>16)==(0);
            if ($307) {
             $314 = (__ZN4half7convertEi($303)|0);
             $315 = $314;
             break;
            } else {
             $308 = $306&65535;
             $309 = $303 & 8388607;
             $310 = (($309) + 4096)|0;
             $311 = $310 >>> 13;
             $312 = (($308) + ($311))|0;
             $313 = $312&65535;
             $315 = $313;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i155>>1] = $315;
          $316 = (($d$07$i155) + ($8<<1)|0);
          $317 = (($s$08$i154) + ($11<<2)|0);
          $318 = ($300|0)==(0);
          if ($318) {
           break;
          } else {
           $$06$i156 = $300;$d$07$i155 = $316;$s$08$i154 = $317;
          }
         }
        }
       }
      } while(0);
      $327 = ($a0$0|0)==(0|0);
      if ($327) {
       break;
      }
      $328 = ($a1$0|0)==(0|0);
      if ($328) {
       if ($42) {
        break;
       } else {
        $$13$i = $0;$d$14$i = $a0$0;
       }
       while(1) {
        $348 = (($$13$i) + -1)|0;
        $349 = (1137192 + 254|0);
        $350 = HEAP16[$349>>1]|0;
        $351 = ($350<<16>>16)==(0);
        if ($351) {
         $352 = (__ZN4half7convertEi(1065353216)|0);
         $353 = $352;
        } else {
         $353 = $350;
        }
        HEAP16[$d$14$i>>1] = $353;
        $354 = ($348|0)==(0);
        if ($354) {
         break L6;
        }
        $355 = (($d$14$i) + ($8<<1)|0);
        $$13$i = $348;$d$14$i = $355;
       }
      }
      if ($42) {
       break;
      } else {
       $$06$i = $0;$d$07$i = $a0$0;$s$08$i = $a1$0;
      }
      while(1) {
       $329 = (($$06$i) + -1)|0;
       $330 = Math_fround(HEAPF32[$s$08$i>>2]);
       $331 = $330 == Math_fround(0.0);
       do {
        if ($331) {
         $344 = 0;
        } else {
         $332 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
         $333 = $332 >>> 23;
         $334 = (1137192 + ($333<<1)|0);
         $335 = HEAP16[$334>>1]|0;
         $336 = ($335<<16>>16)==(0);
         if ($336) {
          $343 = (__ZN4half7convertEi($332)|0);
          $344 = $343;
          break;
         } else {
          $337 = $335&65535;
          $338 = $332 & 8388607;
          $339 = (($338) + 4096)|0;
          $340 = $339 >>> 13;
          $341 = (($337) + ($340))|0;
          $342 = $341&65535;
          $344 = $342;
          break;
         }
        }
       } while(0);
       HEAP16[$d$07$i>>1] = $344;
       $345 = (($d$07$i) + ($8<<1)|0);
       $346 = (($s$08$i) + ($11<<2)|0);
       $347 = ($329|0)==(0);
       if ($347) {
        break;
       } else {
        $$06$i = $329;$d$07$i = $345;$s$08$i = $346;
       }
      }
     } else if ((($20|0) == 2)) {
      __Z12COPY_FRGB_FII4halffEvjjjPvS1_S1_S1_PKvS3_($0,$8,$11,$$1,$g0$0,$$2,$a0$0,$$4,$a1$0);
      break;
     } else {
      break;
     }
    }
   }
  } while(0);
  $356 = HEAP32[$12>>2]|0;
  $357 = $356 & 536870912;
  $358 = ($357|0)==(0);
  do {
   if (!($358)) {
    $359 = HEAP32[$16>>2]|0;
    $360 = $359 & 1073741824;
    $361 = ($360|0)==(0);
    L227: do {
     if (!($361)) {
      if ((($20|0) == 0)) {
       $362 = ($$2|0)==(0|0);
       L231: do {
        if (!($362)) {
         $363 = ($$4|0)==(0|0);
         if ($363) {
          if ($42) {
           break;
          } else {
           $$11$i147 = $0;$d$12$i146 = $$2;
          }
          while(1) {
           $372 = (($$11$i147) + -1)|0;
           HEAPF32[$d$12$i146>>2] = Math_fround(1.0);
           $373 = (($d$12$i146) + ($8<<2)|0);
           $374 = ($372|0)==(0);
           if ($374) {
            break L231;
           } else {
            $$11$i147 = $372;$d$12$i146 = $373;
           }
          }
         }
         if (!($42)) {
          $$04$i145 = $0;$d$05$i144 = $$2;$s$06$i143 = $$4;
          while(1) {
           $364 = (($$04$i145) + -1)|0;
           $365 = HEAP16[$s$06$i143>>1]|0;
           $366 = $365&65535;
           $367 = (875048 + ($366<<2)|0);
           $368 = Math_fround(HEAPF32[$367>>2]);
           HEAPF32[$d$05$i144>>2] = $368;
           $369 = (($d$05$i144) + ($8<<2)|0);
           $370 = (($s$06$i143) + ($11<<1)|0);
           $371 = ($364|0)==(0);
           if ($371) {
            break;
           } else {
            $$04$i145 = $364;$d$05$i144 = $369;$s$06$i143 = $370;
           }
          }
         }
        }
       } while(0);
       $375 = ($a0$0|0)==(0|0);
       if ($375) {
        break;
       }
       $376 = ($a1$0|0)==(0|0);
       if ($376) {
        if ($42) {
         break;
        } else {
         $$11$i138 = $0;$d$12$i137 = $a0$0;
        }
        while(1) {
         $385 = (($$11$i138) + -1)|0;
         HEAPF32[$d$12$i137>>2] = Math_fround(1.0);
         $386 = (($d$12$i137) + ($8<<2)|0);
         $387 = ($385|0)==(0);
         if ($387) {
          break L227;
         } else {
          $$11$i138 = $385;$d$12$i137 = $386;
         }
        }
       }
       if ($42) {
        break;
       }
       $$04$i136 = $0;$d$05$i135 = $a0$0;$s$06$i134 = $a1$0;
       while(1) {
        $377 = (($$04$i136) + -1)|0;
        $378 = HEAP16[$s$06$i134>>1]|0;
        $379 = $378&65535;
        $380 = (875048 + ($379<<2)|0);
        $381 = Math_fround(HEAPF32[$380>>2]);
        HEAPF32[$d$05$i135>>2] = $381;
        $382 = (($d$05$i135) + ($8<<2)|0);
        $383 = (($s$06$i134) + ($11<<1)|0);
        $384 = ($377|0)==(0);
        if ($384) {
         break;
        } else {
         $$04$i136 = $377;$d$05$i135 = $382;$s$06$i134 = $383;
        }
       }
      } else if ((($20|0) == 1)) {
       if ($42) {
        break;
       }
       $$in$i111 = $0;$a0$04$i116 = $a0$0;$a1$08$i112 = $a1$0;$b1$07$i113 = $$4;$g1$06$i114 = $g1$0;$i0$03$i117 = $$2;$r1$05$i115 = $$3;
       while(1) {
        $388 = (($$in$i111) + -1)|0;
        $389 = ($r1$05$i115|0)==(0|0);
        if ($389) {
         $r$0$i120 = Math_fround(0.298999994993209838867);$r1$1$i119 = 0;
        } else {
         $390 = HEAP16[$r1$05$i115>>1]|0;
         $391 = $390&65535;
         $392 = (875048 + ($391<<2)|0);
         $393 = Math_fround(HEAPF32[$392>>2]);
         $394 = (($r1$05$i115) + ($11<<1)|0);
         $phitmp2$i118 = Math_fround($393 * Math_fround(0.298999994993209838867));
         $r$0$i120 = $phitmp2$i118;$r1$1$i119 = $394;
        }
        $395 = ($g1$06$i114|0)==(0|0);
        if ($395) {
         $g$0$i123 = Math_fround(0.587000012397766113281);$g1$1$i122 = 0;
        } else {
         $396 = HEAP16[$g1$06$i114>>1]|0;
         $397 = $396&65535;
         $398 = (875048 + ($397<<2)|0);
         $399 = Math_fround(HEAPF32[$398>>2]);
         $400 = (($g1$06$i114) + ($11<<1)|0);
         $phitmp1$i121 = Math_fround($399 * Math_fround(0.587000012397766113281));
         $g$0$i123 = $phitmp1$i121;$g1$1$i122 = $400;
        }
        $401 = ($b1$07$i113|0)==(0|0);
        if ($401) {
         $b$0$i126 = Math_fround(0.114000000059604644775);$b1$1$i125 = 0;
        } else {
         $402 = HEAP16[$b1$07$i113>>1]|0;
         $403 = $402&65535;
         $404 = (875048 + ($403<<2)|0);
         $405 = Math_fround(HEAPF32[$404>>2]);
         $406 = (($b1$07$i113) + ($11<<1)|0);
         $phitmp$i124 = Math_fround($405 * Math_fround(0.114000000059604644775));
         $b$0$i126 = $phitmp$i124;$b1$1$i125 = $406;
        }
        $407 = ($a1$08$i112|0)==(0|0);
        if ($407) {
         $a$0$i128 = Math_fround(1.0);$a1$1$i127 = 0;
        } else {
         $408 = HEAP16[$a1$08$i112>>1]|0;
         $409 = $408&65535;
         $410 = (875048 + ($409<<2)|0);
         $411 = Math_fround(HEAPF32[$410>>2]);
         $412 = (($a1$08$i112) + ($11<<1)|0);
         $a$0$i128 = $411;$a1$1$i127 = $412;
        }
        $413 = ($i0$03$i117|0)==(0|0);
        if ($413) {
         $i0$1$i129 = 0;
        } else {
         $414 = Math_fround($g$0$i123 + $b$0$i126);
         $415 = Math_fround($r$0$i120 + $414);
         HEAPF32[$i0$03$i117>>2] = $415;
         $416 = (($i0$03$i117) + ($8<<2)|0);
         $i0$1$i129 = $416;
        }
        $417 = ($a0$04$i116|0)==(0|0);
        if ($417) {
         $a0$0$be$i130 = 0;
        } else {
         HEAPF32[$a0$04$i116>>2] = $a$0$i128;
         $418 = (($a0$04$i116) + ($8<<2)|0);
         $a0$0$be$i130 = $418;
        }
        $419 = ($388|0)==(0);
        if ($419) {
         break;
        } else {
         $$in$i111 = $388;$a0$04$i116 = $a0$0$be$i130;$a1$08$i112 = $a1$1$i127;$b1$07$i113 = $b1$1$i125;$g1$06$i114 = $g1$1$i122;$i0$03$i117 = $i0$1$i129;$r1$05$i115 = $r1$1$i119;
        }
       }
      } else if ((($20|0) == 3)) {
       $442 = ($$1|0)==(0|0);
       L274: do {
        if (!($442)) {
         $443 = ($$3|0)==(0|0);
         if ($443) {
          if ($42) {
           break;
          } else {
           $$11$i90 = $0;$d$12$i89 = $$1;
          }
          while(1) {
           $452 = (($$11$i90) + -1)|0;
           HEAPF32[$d$12$i89>>2] = Math_fround(1.0);
           $453 = (($d$12$i89) + ($8<<2)|0);
           $454 = ($452|0)==(0);
           if ($454) {
            break L274;
           } else {
            $$11$i90 = $452;$d$12$i89 = $453;
           }
          }
         }
         if (!($42)) {
          $$04$i88 = $0;$d$05$i87 = $$1;$s$06$i86 = $$3;
          while(1) {
           $444 = (($$04$i88) + -1)|0;
           $445 = HEAP16[$s$06$i86>>1]|0;
           $446 = $445&65535;
           $447 = (875048 + ($446<<2)|0);
           $448 = Math_fround(HEAPF32[$447>>2]);
           HEAPF32[$d$05$i87>>2] = $448;
           $449 = (($d$05$i87) + ($8<<2)|0);
           $450 = (($s$06$i86) + ($11<<1)|0);
           $451 = ($444|0)==(0);
           if ($451) {
            break;
           } else {
            $$04$i88 = $444;$d$05$i87 = $449;$s$06$i86 = $450;
           }
          }
         }
        }
       } while(0);
       $455 = ($g0$0|0)==(0|0);
       L285: do {
        if (!($455)) {
         $456 = ($g1$0|0)==(0|0);
         if ($456) {
          if ($42) {
           break;
          } else {
           $$11$i81 = $0;$d$12$i80 = $g0$0;
          }
          while(1) {
           $465 = (($$11$i81) + -1)|0;
           HEAPF32[$d$12$i80>>2] = Math_fround(1.0);
           $466 = (($d$12$i80) + ($8<<2)|0);
           $467 = ($465|0)==(0);
           if ($467) {
            break L285;
           } else {
            $$11$i81 = $465;$d$12$i80 = $466;
           }
          }
         }
         if (!($42)) {
          $$04$i79 = $0;$d$05$i78 = $g0$0;$s$06$i77 = $g1$0;
          while(1) {
           $457 = (($$04$i79) + -1)|0;
           $458 = HEAP16[$s$06$i77>>1]|0;
           $459 = $458&65535;
           $460 = (875048 + ($459<<2)|0);
           $461 = Math_fround(HEAPF32[$460>>2]);
           HEAPF32[$d$05$i78>>2] = $461;
           $462 = (($d$05$i78) + ($8<<2)|0);
           $463 = (($s$06$i77) + ($11<<1)|0);
           $464 = ($457|0)==(0);
           if ($464) {
            break;
           } else {
            $$04$i79 = $457;$d$05$i78 = $462;$s$06$i77 = $463;
           }
          }
         }
        }
       } while(0);
       $468 = ($$2|0)==(0|0);
       L296: do {
        if (!($468)) {
         $469 = ($$4|0)==(0|0);
         if ($469) {
          if ($42) {
           break;
          } else {
           $$11$i72 = $0;$d$12$i71 = $$2;
          }
          while(1) {
           $478 = (($$11$i72) + -1)|0;
           HEAPF32[$d$12$i71>>2] = Math_fround(1.0);
           $479 = (($d$12$i71) + ($8<<2)|0);
           $480 = ($478|0)==(0);
           if ($480) {
            break L296;
           } else {
            $$11$i72 = $478;$d$12$i71 = $479;
           }
          }
         }
         if (!($42)) {
          $$04$i70 = $0;$d$05$i69 = $$2;$s$06$i68 = $$4;
          while(1) {
           $470 = (($$04$i70) + -1)|0;
           $471 = HEAP16[$s$06$i68>>1]|0;
           $472 = $471&65535;
           $473 = (875048 + ($472<<2)|0);
           $474 = Math_fround(HEAPF32[$473>>2]);
           HEAPF32[$d$05$i69>>2] = $474;
           $475 = (($d$05$i69) + ($8<<2)|0);
           $476 = (($s$06$i68) + ($11<<1)|0);
           $477 = ($470|0)==(0);
           if ($477) {
            break;
           } else {
            $$04$i70 = $470;$d$05$i69 = $475;$s$06$i68 = $476;
           }
          }
         }
        }
       } while(0);
       $481 = ($a0$0|0)==(0|0);
       if ($481) {
        break;
       }
       $482 = ($a1$0|0)==(0|0);
       if ($482) {
        if ($42) {
         break;
        } else {
         $$11$i64 = $0;$d$12$i63 = $a0$0;
        }
        while(1) {
         $491 = (($$11$i64) + -1)|0;
         HEAPF32[$d$12$i63>>2] = Math_fround(1.0);
         $492 = (($d$12$i63) + ($8<<2)|0);
         $493 = ($491|0)==(0);
         if ($493) {
          break L227;
         } else {
          $$11$i64 = $491;$d$12$i63 = $492;
         }
        }
       }
       if ($42) {
        break;
       }
       $$04$i62 = $0;$d$05$i61 = $a0$0;$s$06$i60 = $a1$0;
       while(1) {
        $483 = (($$04$i62) + -1)|0;
        $484 = HEAP16[$s$06$i60>>1]|0;
        $485 = $484&65535;
        $486 = (875048 + ($485<<2)|0);
        $487 = Math_fround(HEAPF32[$486>>2]);
        HEAPF32[$d$05$i61>>2] = $487;
        $488 = (($d$05$i61) + ($8<<2)|0);
        $489 = (($s$06$i60) + ($11<<1)|0);
        $490 = ($483|0)==(0);
        if ($490) {
         break;
        } else {
         $$04$i62 = $483;$d$05$i61 = $488;$s$06$i60 = $489;
        }
       }
      } else if ((($20|0) == 2)) {
       if ($42) {
        break;
       }
       $$in$i94 = $0;$a0$04$i97 = $a0$0;$a1$06$i95 = $a1$0;$b0$03$i98 = $$2;$g0$02$i99 = $g0$0;$i1$05$i96 = $$4;$r0$01$i100 = $$1;
       while(1) {
        $420 = (($$in$i94) + -1)|0;
        $421 = ($i1$05$i96|0)==(0|0);
        if ($421) {
         $i$0$i102 = Math_fround(1.0);$i1$1$i101 = 0;
        } else {
         $422 = HEAP16[$i1$05$i96>>1]|0;
         $423 = $422&65535;
         $424 = (875048 + ($423<<2)|0);
         $425 = Math_fround(HEAPF32[$424>>2]);
         $426 = (($i1$05$i96) + ($11<<1)|0);
         $i$0$i102 = $425;$i1$1$i101 = $426;
        }
        $427 = ($a1$06$i95|0)==(0|0);
        if ($427) {
         $a$0$i104 = Math_fround(1.0);$a1$1$i103 = 0;
        } else {
         $428 = HEAP16[$a1$06$i95>>1]|0;
         $429 = $428&65535;
         $430 = (875048 + ($429<<2)|0);
         $431 = Math_fround(HEAPF32[$430>>2]);
         $432 = (($a1$06$i95) + ($11<<1)|0);
         $a$0$i104 = $431;$a1$1$i103 = $432;
        }
        $433 = ($r0$01$i100|0)==(0|0);
        if ($433) {
         $r0$1$i105 = 0;
        } else {
         HEAPF32[$r0$01$i100>>2] = $i$0$i102;
         $434 = (($r0$01$i100) + ($8<<2)|0);
         $r0$1$i105 = $434;
        }
        $435 = ($g0$02$i99|0)==(0|0);
        if ($435) {
         $g0$1$i106 = 0;
        } else {
         HEAPF32[$g0$02$i99>>2] = $i$0$i102;
         $436 = (($g0$02$i99) + ($8<<2)|0);
         $g0$1$i106 = $436;
        }
        $437 = ($b0$03$i98|0)==(0|0);
        if ($437) {
         $b0$1$i107 = 0;
        } else {
         HEAPF32[$b0$03$i98>>2] = $i$0$i102;
         $438 = (($b0$03$i98) + ($8<<2)|0);
         $b0$1$i107 = $438;
        }
        $439 = ($a0$04$i97|0)==(0|0);
        if ($439) {
         $a0$0$be$i108 = 0;
        } else {
         HEAPF32[$a0$04$i97>>2] = $a$0$i104;
         $440 = (($a0$04$i97) + ($8<<2)|0);
         $a0$0$be$i108 = $440;
        }
        $441 = ($420|0)==(0);
        if ($441) {
         break;
        } else {
         $$in$i94 = $420;$a0$04$i97 = $a0$0$be$i108;$a1$06$i95 = $a1$1$i103;$b0$03$i98 = $b0$1$i107;$g0$02$i99 = $g0$1$i106;$i1$05$i96 = $i1$1$i101;$r0$01$i100 = $r0$1$i105;
        }
       }
      } else {
       break;
      }
     }
    } while(0);
    $494 = $359 & 536870912;
    $495 = ($494|0)==(0);
    if (!($495)) {
     if ((($20|0) == 0)) {
      $496 = ($$2|0)==(0|0);
      do {
       if (!($496)) {
        $497 = ($$4|0)==(0|0);
        if ($497) {
         if ($42) {
          break;
         } else {
          $$11$i55 = $0;$d$12$i54 = $$2;
         }
         while(1) {
          $503 = (($$11$i55) + -1)|0;
          HEAPF32[$d$12$i54>>2] = Math_fround(1.0);
          $504 = (($d$12$i54) + ($8<<2)|0);
          $505 = ($503|0)==(0);
          if ($505) {
           break;
          } else {
           $$11$i55 = $503;$d$12$i54 = $504;
          }
         }
        } else {
         if ($42) {
          break;
         } else {
          $$04$i53 = $0;$d$05$i52 = $$2;$s$06$i51 = $$4;
         }
         while(1) {
          $498 = (($$04$i53) + -1)|0;
          $499 = Math_fround(HEAPF32[$s$06$i51>>2]);
          HEAPF32[$d$05$i52>>2] = $499;
          $500 = (($d$05$i52) + ($8<<2)|0);
          $501 = (($s$06$i51) + ($11<<2)|0);
          $502 = ($498|0)==(0);
          if ($502) {
           break;
          } else {
           $$04$i53 = $498;$d$05$i52 = $500;$s$06$i51 = $501;
          }
         }
        }
       }
      } while(0);
      $506 = ($a0$0|0)==(0|0);
      if ($506) {
       break;
      }
      $507 = ($a1$0|0)==(0|0);
      if ($507) {
       if ($42) {
        break;
       } else {
        $$11$i46 = $0;$d$12$i45 = $a0$0;
       }
       while(1) {
        $513 = (($$11$i46) + -1)|0;
        HEAPF32[$d$12$i45>>2] = Math_fround(1.0);
        $514 = (($d$12$i45) + ($8<<2)|0);
        $515 = ($513|0)==(0);
        if ($515) {
         break;
        } else {
         $$11$i46 = $513;$d$12$i45 = $514;
        }
       }
      } else {
       if ($42) {
        break;
       } else {
        $$04$i44 = $0;$d$05$i43 = $a0$0;$s$06$i42 = $a1$0;
       }
       while(1) {
        $508 = (($$04$i44) + -1)|0;
        $509 = Math_fround(HEAPF32[$s$06$i42>>2]);
        HEAPF32[$d$05$i43>>2] = $509;
        $510 = (($d$05$i43) + ($8<<2)|0);
        $511 = (($s$06$i42) + ($11<<2)|0);
        $512 = ($508|0)==(0);
        if ($512) {
         break;
        } else {
         $$04$i44 = $508;$d$05$i43 = $510;$s$06$i42 = $511;
        }
       }
      }
     } else if ((($20|0) == 1)) {
      if ($42) {
       break;
      }
      $$in$i34 = $0;$a0$04$i35 = $a0$0;$a1$08$i = $a1$0;$b1$07$i = $$4;$g1$06$i = $g1$0;$i0$03$i = $$2;$r1$05$i = $$3;
      while(1) {
       $516 = (($$in$i34) + -1)|0;
       $517 = ($r1$05$i|0)==(0|0);
       if ($517) {
        $r$0$i = Math_fround(0.298999994993209838867);$r1$1$i = 0;
       } else {
        $518 = Math_fround(HEAPF32[$r1$05$i>>2]);
        $519 = (($r1$05$i) + ($11<<2)|0);
        $phitmp2$i = Math_fround($518 * Math_fround(0.298999994993209838867));
        $r$0$i = $phitmp2$i;$r1$1$i = $519;
       }
       $520 = ($g1$06$i|0)==(0|0);
       if ($520) {
        $g$0$i = Math_fround(0.587000012397766113281);$g1$1$i = 0;
       } else {
        $521 = Math_fround(HEAPF32[$g1$06$i>>2]);
        $522 = (($g1$06$i) + ($11<<2)|0);
        $phitmp1$i = Math_fround($521 * Math_fround(0.587000012397766113281));
        $g$0$i = $phitmp1$i;$g1$1$i = $522;
       }
       $523 = ($b1$07$i|0)==(0|0);
       if ($523) {
        $b$0$i = Math_fround(0.114000000059604644775);$b1$1$i = 0;
       } else {
        $524 = Math_fround(HEAPF32[$b1$07$i>>2]);
        $525 = (($b1$07$i) + ($11<<2)|0);
        $phitmp$i = Math_fround($524 * Math_fround(0.114000000059604644775));
        $b$0$i = $phitmp$i;$b1$1$i = $525;
       }
       $526 = ($a1$08$i|0)==(0|0);
       if ($526) {
        $a$0$i37 = Math_fround(1.0);$a1$1$i36 = 0;
       } else {
        $527 = Math_fround(HEAPF32[$a1$08$i>>2]);
        $528 = (($a1$08$i) + ($11<<2)|0);
        $a$0$i37 = $527;$a1$1$i36 = $528;
       }
       $529 = ($i0$03$i|0)==(0|0);
       if ($529) {
        $i0$1$i = 0;
       } else {
        $530 = Math_fround($g$0$i + $b$0$i);
        $531 = Math_fround($r$0$i + $530);
        HEAPF32[$i0$03$i>>2] = $531;
        $532 = (($i0$03$i) + ($8<<2)|0);
        $i0$1$i = $532;
       }
       $533 = ($a0$04$i35|0)==(0|0);
       if ($533) {
        $a0$0$be$i38 = 0;
       } else {
        HEAPF32[$a0$04$i35>>2] = $a$0$i37;
        $534 = (($a0$04$i35) + ($8<<2)|0);
        $a0$0$be$i38 = $534;
       }
       $535 = ($516|0)==(0);
       if ($535) {
        break;
       } else {
        $$in$i34 = $516;$a0$04$i35 = $a0$0$be$i38;$a1$08$i = $a1$1$i36;$b1$07$i = $b1$1$i;$g1$06$i = $g1$1$i;$i0$03$i = $i0$1$i;$r1$05$i = $r1$1$i;
       }
      }
     } else if ((($20|0) == 2)) {
      if ($42) {
       break;
      }
      $$in$i = $0;$a0$04$i = $a0$0;$a1$06$i = $a1$0;$b0$03$i = $$2;$g0$02$i = $g0$0;$i1$05$i = $$4;$r0$01$i = $$1;
      while(1) {
       $536 = (($$in$i) + -1)|0;
       $537 = ($i1$05$i|0)==(0|0);
       if ($537) {
        $i$0$i = Math_fround(1.0);$i1$1$i = 0;
       } else {
        $538 = Math_fround(HEAPF32[$i1$05$i>>2]);
        $539 = (($i1$05$i) + ($11<<2)|0);
        $i$0$i = $538;$i1$1$i = $539;
       }
       $540 = ($a1$06$i|0)==(0|0);
       if ($540) {
        $a$0$i = Math_fround(1.0);$a1$1$i = 0;
       } else {
        $541 = Math_fround(HEAPF32[$a1$06$i>>2]);
        $542 = (($a1$06$i) + ($11<<2)|0);
        $a$0$i = $541;$a1$1$i = $542;
       }
       $543 = ($r0$01$i|0)==(0|0);
       if ($543) {
        $r0$1$i = 0;
       } else {
        HEAPF32[$r0$01$i>>2] = $i$0$i;
        $544 = (($r0$01$i) + ($8<<2)|0);
        $r0$1$i = $544;
       }
       $545 = ($g0$02$i|0)==(0|0);
       if ($545) {
        $g0$1$i = 0;
       } else {
        HEAPF32[$g0$02$i>>2] = $i$0$i;
        $546 = (($g0$02$i) + ($8<<2)|0);
        $g0$1$i = $546;
       }
       $547 = ($b0$03$i|0)==(0|0);
       if ($547) {
        $b0$1$i = 0;
       } else {
        HEAPF32[$b0$03$i>>2] = $i$0$i;
        $548 = (($b0$03$i) + ($8<<2)|0);
        $b0$1$i = $548;
       }
       $549 = ($a0$04$i|0)==(0|0);
       if ($549) {
        $a0$0$be$i = 0;
       } else {
        HEAPF32[$a0$04$i>>2] = $a$0$i;
        $550 = (($a0$04$i) + ($8<<2)|0);
        $a0$0$be$i = $550;
       }
       $551 = ($536|0)==(0);
       if ($551) {
        break;
       } else {
        $$in$i = $536;$a0$04$i = $a0$0$be$i;$a1$06$i = $a1$1$i;$b0$03$i = $b0$1$i;$g0$02$i = $g0$1$i;$i1$05$i = $i1$1$i;$r0$01$i = $r0$1$i;
       }
      }
     } else if ((($20|0) == 3)) {
      $552 = ($$1|0)==(0|0);
      do {
       if (!($552)) {
        $553 = ($$3|0)==(0|0);
        if ($553) {
         if ($42) {
          break;
         } else {
          $$11$i29 = $0;$d$12$i28 = $$1;
         }
         while(1) {
          $559 = (($$11$i29) + -1)|0;
          HEAPF32[$d$12$i28>>2] = Math_fround(1.0);
          $560 = (($d$12$i28) + ($8<<2)|0);
          $561 = ($559|0)==(0);
          if ($561) {
           break;
          } else {
           $$11$i29 = $559;$d$12$i28 = $560;
          }
         }
        } else {
         if ($42) {
          break;
         } else {
          $$04$i27 = $0;$d$05$i26 = $$1;$s$06$i25 = $$3;
         }
         while(1) {
          $554 = (($$04$i27) + -1)|0;
          $555 = Math_fround(HEAPF32[$s$06$i25>>2]);
          HEAPF32[$d$05$i26>>2] = $555;
          $556 = (($d$05$i26) + ($8<<2)|0);
          $557 = (($s$06$i25) + ($11<<2)|0);
          $558 = ($554|0)==(0);
          if ($558) {
           break;
          } else {
           $$04$i27 = $554;$d$05$i26 = $556;$s$06$i25 = $557;
          }
         }
        }
       }
      } while(0);
      $562 = ($g0$0|0)==(0|0);
      do {
       if (!($562)) {
        $563 = ($g1$0|0)==(0|0);
        if ($563) {
         if ($42) {
          break;
         } else {
          $$11$i20 = $0;$d$12$i19 = $g0$0;
         }
         while(1) {
          $569 = (($$11$i20) + -1)|0;
          HEAPF32[$d$12$i19>>2] = Math_fround(1.0);
          $570 = (($d$12$i19) + ($8<<2)|0);
          $571 = ($569|0)==(0);
          if ($571) {
           break;
          } else {
           $$11$i20 = $569;$d$12$i19 = $570;
          }
         }
        } else {
         if ($42) {
          break;
         } else {
          $$04$i18 = $0;$d$05$i17 = $g0$0;$s$06$i16 = $g1$0;
         }
         while(1) {
          $564 = (($$04$i18) + -1)|0;
          $565 = Math_fround(HEAPF32[$s$06$i16>>2]);
          HEAPF32[$d$05$i17>>2] = $565;
          $566 = (($d$05$i17) + ($8<<2)|0);
          $567 = (($s$06$i16) + ($11<<2)|0);
          $568 = ($564|0)==(0);
          if ($568) {
           break;
          } else {
           $$04$i18 = $564;$d$05$i17 = $566;$s$06$i16 = $567;
          }
         }
        }
       }
      } while(0);
      $572 = ($$2|0)==(0|0);
      do {
       if (!($572)) {
        $573 = ($$4|0)==(0|0);
        if ($573) {
         if ($42) {
          break;
         } else {
          $$11$i11 = $0;$d$12$i10 = $$2;
         }
         while(1) {
          $579 = (($$11$i11) + -1)|0;
          HEAPF32[$d$12$i10>>2] = Math_fround(1.0);
          $580 = (($d$12$i10) + ($8<<2)|0);
          $581 = ($579|0)==(0);
          if ($581) {
           break;
          } else {
           $$11$i11 = $579;$d$12$i10 = $580;
          }
         }
        } else {
         if ($42) {
          break;
         } else {
          $$04$i9 = $0;$d$05$i8 = $$2;$s$06$i7 = $$4;
         }
         while(1) {
          $574 = (($$04$i9) + -1)|0;
          $575 = Math_fround(HEAPF32[$s$06$i7>>2]);
          HEAPF32[$d$05$i8>>2] = $575;
          $576 = (($d$05$i8) + ($8<<2)|0);
          $577 = (($s$06$i7) + ($11<<2)|0);
          $578 = ($574|0)==(0);
          if ($578) {
           break;
          } else {
           $$04$i9 = $574;$d$05$i8 = $576;$s$06$i7 = $577;
          }
         }
        }
       }
      } while(0);
      $582 = ($a0$0|0)==(0|0);
      if ($582) {
       break;
      }
      $583 = ($a1$0|0)==(0|0);
      if ($583) {
       if ($42) {
        break;
       } else {
        $$11$i = $0;$d$12$i = $a0$0;
       }
       while(1) {
        $589 = (($$11$i) + -1)|0;
        HEAPF32[$d$12$i>>2] = Math_fround(1.0);
        $590 = (($d$12$i) + ($8<<2)|0);
        $591 = ($589|0)==(0);
        if ($591) {
         break;
        } else {
         $$11$i = $589;$d$12$i = $590;
        }
       }
      } else {
       if ($42) {
        break;
       } else {
        $$04$i = $0;$d$05$i = $a0$0;$s$06$i = $a1$0;
       }
       while(1) {
        $584 = (($$04$i) + -1)|0;
        $585 = Math_fround(HEAPF32[$s$06$i>>2]);
        HEAPF32[$d$05$i>>2] = $585;
        $586 = (($d$05$i) + ($8<<2)|0);
        $587 = (($s$06$i) + ($11<<2)|0);
        $588 = ($584|0)==(0);
        if ($588) {
         break;
        } else {
         $$04$i = $584;$d$05$i = $586;$s$06$i = $587;
        }
       }
      }
     } else {
      break;
     }
    }
   }
  } while(0);
  $exitcond = ($y$0309|0)==($2|0);
  if ($exitcond) {
   break;
  }
  $592 = (($s$0310) + ($6)|0);
  $593 = (($d$0311) + ($4)|0);
  $phitmp = (($y$0309) + 1)|0;
  $84 = $356;$d$0311 = $593;$s$0310 = $592;$y$0309 = $phitmp;
 }
 STACKTOP = sp;return;
}
function __Z13BlitCopyFloatIffEvRN6prcore7SurfaceERKS1_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$04$i = 0, $$04$i136 = 0, $$04$i145 = 0, $$04$i18 = 0, $$04$i27 = 0, $$04$i44 = 0, $$04$i53 = 0, $$04$i62 = 0, $$04$i70 = 0, $$04$i79 = 0, $$04$i88 = 0, $$04$i9 = 0, $$06$i = 0, $$06$i156 = 0, $$06$i168 = 0, $$06$i180 = 0, $$06$i192 = 0, $$06$i204 = 0, $$06$i216 = 0, $$06$i226 = 0;
 var $$06$i237 = 0, $$06$i248 = 0, $$06$i259 = 0, $$06$i270 = 0, $$1 = 0, $$11$i = 0, $$11$i11 = 0, $$11$i138 = 0, $$11$i147 = 0, $$11$i20 = 0, $$11$i29 = 0, $$11$i46 = 0, $$11$i55 = 0, $$11$i64 = 0, $$11$i72 = 0, $$11$i81 = 0, $$11$i90 = 0, $$13$i = 0, $$13$i159 = 0, $$13$i171 = 0;
 var $$13$i183 = 0, $$13$i195 = 0, $$13$i207 = 0, $$13$i218 = 0, $$13$i228 = 0, $$13$i239 = 0, $$13$i250 = 0, $$13$i261 = 0, $$13$i272 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$in$i = 0, $$in$i111 = 0, $$in$i34 = 0, $$in$i94 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = Math_fround(0), $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = Math_fround(0), $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = Math_fround(0), $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = Math_fround(0), $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = Math_fround(0), $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = Math_fround(0), $412 = 0, $413 = 0, $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0);
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = Math_fround(0), $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = Math_fround(0), $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = Math_fround(0);
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = Math_fround(0), $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = Math_fround(0), $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = Math_fround(0), $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = Math_fround(0), $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = Math_fround(0), $519 = 0, $52 = 0, $520 = 0, $521 = Math_fround(0), $522 = 0, $523 = 0, $524 = Math_fround(0), $525 = 0, $526 = 0, $527 = Math_fround(0), $528 = 0, $529 = 0, $53 = 0, $530 = Math_fround(0), $531 = Math_fround(0), $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = Math_fround(0), $539 = 0, $54 = 0, $540 = 0, $541 = Math_fround(0), $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = Math_fround(0), $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = Math_fround(0), $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = Math_fround(0), $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = Math_fround(0), $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0$i = Math_fround(0), $a$0$i104 = Math_fround(0), $a$0$i128 = Math_fround(0), $a$0$i37 = Math_fround(0), $a0$0 = 0, $a0$0$be$i = 0, $a0$0$be$i108 = 0, $a0$0$be$i130 = 0, $a0$0$be$i38 = 0, $a0$04$i = 0;
 var $a0$04$i116 = 0, $a0$04$i35 = 0, $a0$04$i97 = 0, $a1$0 = 0, $a1$06$i = 0, $a1$06$i95 = 0, $a1$08$i = 0, $a1$08$i112 = 0, $a1$1$i = 0, $a1$1$i103 = 0, $a1$1$i127 = 0, $a1$1$i36 = 0, $b$0$i = Math_fround(0), $b$0$i126 = Math_fround(0), $b0$03$i = 0, $b0$03$i98 = 0, $b0$1$i = 0, $b0$1$i107 = 0, $b1$07$i = 0, $b1$07$i113 = 0;
 var $b1$1$i = 0, $b1$1$i125 = 0, $d$0311 = 0, $d$05$i = 0, $d$05$i135 = 0, $d$05$i144 = 0, $d$05$i17 = 0, $d$05$i26 = 0, $d$05$i43 = 0, $d$05$i52 = 0, $d$05$i61 = 0, $d$05$i69 = 0, $d$05$i78 = 0, $d$05$i8 = 0, $d$05$i87 = 0, $d$07$i = 0, $d$07$i155 = 0, $d$07$i167 = 0, $d$07$i179 = 0, $d$07$i191 = 0;
 var $d$07$i203 = 0, $d$07$i215 = 0, $d$07$i225 = 0, $d$07$i236 = 0, $d$07$i247 = 0, $d$07$i258 = 0, $d$07$i269 = 0, $d$12$i = 0, $d$12$i10 = 0, $d$12$i137 = 0, $d$12$i146 = 0, $d$12$i19 = 0, $d$12$i28 = 0, $d$12$i45 = 0, $d$12$i54 = 0, $d$12$i63 = 0, $d$12$i71 = 0, $d$12$i80 = 0, $d$12$i89 = 0, $d$14$i = 0;
 var $d$14$i158 = 0, $d$14$i170 = 0, $d$14$i182 = 0, $d$14$i194 = 0, $d$14$i206 = 0, $d$14$i217 = 0, $d$14$i227 = 0, $d$14$i238 = 0, $d$14$i249 = 0, $d$14$i260 = 0, $d$14$i271 = 0, $exitcond = 0, $g$0$i = Math_fround(0), $g$0$i123 = Math_fround(0), $g0$0 = 0, $g0$02$i = 0, $g0$02$i99 = 0, $g0$1$i = 0, $g0$1$i106 = 0, $g1$0 = 0;
 var $g1$06$i = 0, $g1$06$i114 = 0, $g1$1$i = 0, $g1$1$i122 = 0, $i$0$i = Math_fround(0), $i$0$i102 = Math_fround(0), $i0$03$i = 0, $i0$03$i117 = 0, $i0$1$i = 0, $i0$1$i129 = 0, $i1$05$i = 0, $i1$05$i96 = 0, $i1$1$i = 0, $i1$1$i101 = 0, $phitmp = 0, $phitmp$i = Math_fround(0), $phitmp$i124 = Math_fround(0), $phitmp1$i = Math_fround(0), $phitmp1$i121 = Math_fround(0), $phitmp2$i = Math_fround(0);
 var $phitmp2$i118 = Math_fround(0), $r$0$i = Math_fround(0), $r$0$i120 = Math_fround(0), $r0$01$i = 0, $r0$01$i100 = 0, $r0$1$i = 0, $r0$1$i105 = 0, $r1$05$i = 0, $r1$05$i115 = 0, $r1$1$i = 0, $r1$1$i119 = 0, $s$0310 = 0, $s$06$i = 0, $s$06$i134 = 0, $s$06$i143 = 0, $s$06$i16 = 0, $s$06$i25 = 0, $s$06$i42 = 0, $s$06$i51 = 0, $s$06$i60 = 0;
 var $s$06$i68 = 0, $s$06$i7 = 0, $s$06$i77 = 0, $s$06$i86 = 0, $s$08$i = 0, $s$08$i154 = 0, $s$08$i166 = 0, $s$08$i178 = 0, $s$08$i190 = 0, $s$08$i202 = 0, $s$08$i214 = 0, $s$08$i224 = 0, $s$08$i235 = 0, $s$08$i246 = 0, $s$08$i257 = 0, $s$08$i268 = 0, $y$0309 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$dest>>2]|0;
 $1 = (($dest) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($dest) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($source) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4>>>0) / ($0>>>0))&-1;
 $8 = $7 >>> 2;
 $9 = HEAP32[$source>>2]|0;
 $10 = (($6>>>0) / ($9>>>0))&-1;
 $11 = $10 >>> 2;
 $12 = (($dest) + 12|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 >>> 27;
 $15 = $14 & 2;
 $16 = (($source) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = $17 >>> 28;
 $19 = $18 & 1;
 $20 = $19 | $15;
 $21 = ($2|0)==(0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = (($source) + 40|0);
 $23 = (($dest) + 40|0);
 $24 = HEAP32[$22>>2]|0;
 $25 = HEAP32[$23>>2]|0;
 $26 = (($dest) + 38|0);
 $27 = (($dest) + 37|0);
 $28 = (($dest) + 36|0);
 $29 = (($dest) + 39|0);
 $30 = (($dest) + 16|0);
 $31 = (($dest) + 20|0);
 $32 = (($dest) + 24|0);
 $33 = (($dest) + 28|0);
 $34 = (($source) + 38|0);
 $35 = (($source) + 37|0);
 $36 = (($source) + 36|0);
 $37 = (($source) + 39|0);
 $38 = (($source) + 16|0);
 $39 = (($source) + 20|0);
 $40 = (($source) + 24|0);
 $41 = (($source) + 28|0);
 $42 = ($0|0)==(0);
 $84 = $13;$d$0311 = $25;$s$0310 = $24;$y$0309 = 1;
 while(1) {
  $43 = HEAP8[$26>>0]|0;
  $44 = $43&255;
  $45 = (($d$0311) + ($44<<2)|0);
  $46 = HEAP8[$27>>0]|0;
  $47 = $46&255;
  $48 = (($d$0311) + ($47<<2)|0);
  $49 = HEAP8[$28>>0]|0;
  $50 = $49&255;
  $51 = (($d$0311) + ($50<<2)|0);
  $52 = HEAP8[$29>>0]|0;
  $53 = $52&255;
  $54 = (($d$0311) + ($53<<2)|0);
  $55 = HEAP32[$30>>2]|0;
  $56 = ($55|0)==(0);
  $$1 = $56 ? 0 : $45;
  $57 = HEAP32[$31>>2]|0;
  $58 = ($57|0)==(0);
  $g0$0 = $58 ? 0 : $48;
  $59 = HEAP32[$32>>2]|0;
  $60 = ($59|0)==(0);
  $$2 = $60 ? 0 : $51;
  $61 = HEAP32[$33>>2]|0;
  $62 = ($61|0)==(0);
  $a0$0 = $62 ? 0 : $54;
  $63 = HEAP8[$34>>0]|0;
  $64 = $63&255;
  $65 = (($s$0310) + ($64<<2)|0);
  $66 = HEAP8[$35>>0]|0;
  $67 = $66&255;
  $68 = (($s$0310) + ($67<<2)|0);
  $69 = HEAP8[$36>>0]|0;
  $70 = $69&255;
  $71 = (($s$0310) + ($70<<2)|0);
  $72 = HEAP8[$37>>0]|0;
  $73 = $72&255;
  $74 = (($s$0310) + ($73<<2)|0);
  $75 = HEAP32[$38>>2]|0;
  $76 = ($75|0)==(0);
  $$3 = $76 ? 0 : $65;
  $77 = HEAP32[$39>>2]|0;
  $78 = ($77|0)==(0);
  $g1$0 = $78 ? 0 : $68;
  $79 = HEAP32[$40>>2]|0;
  $80 = ($79|0)==(0);
  $$4 = $80 ? 0 : $71;
  $81 = HEAP32[$41>>2]|0;
  $82 = ($81|0)==(0);
  $a1$0 = $82 ? 0 : $74;
  $83 = $84 & 1073741824;
  $85 = ($83|0)==(0);
  L6: do {
   if (!($85)) {
    $86 = HEAP32[$16>>2]|0;
    $87 = $86 & 1073741824;
    $88 = ($87|0)==(0);
    L8: do {
     if (!($88)) {
      if ((($20|0) == 0)) {
       $89 = ($$2|0)==(0|0);
       L12: do {
        if (!($89)) {
         $90 = ($$4|0)==(0|0);
         if (!($90)) {
          if ($42) {
           break;
          }
          $$06$i270 = $0;$d$07$i269 = $$2;$s$08$i268 = $$4;
          while(1) {
           $91 = (($$06$i270) + -1)|0;
           $92 = HEAP16[$s$08$i268>>1]|0;
           HEAP16[$d$07$i269>>1] = $92;
           $93 = (($d$07$i269) + ($8<<1)|0);
           $94 = (($s$08$i268) + ($11<<1)|0);
           $95 = ($91|0)==(0);
           if ($95) {
            break L12;
           } else {
            $$06$i270 = $91;$d$07$i269 = $93;$s$08$i268 = $94;
           }
          }
         }
         if (!($42)) {
          $$13$i272 = $0;$d$14$i271 = $$2;
          while(1) {
           $96 = (($$13$i272) + -1)|0;
           $97 = (1137192 + 254|0);
           $98 = HEAP16[$97>>1]|0;
           $99 = ($98<<16>>16)==(0);
           if ($99) {
            $100 = (__ZN4half7convertEi(1065353216)|0);
            $101 = $100;
           } else {
            $101 = $98;
           }
           HEAP16[$d$14$i271>>1] = $101;
           $102 = ($96|0)==(0);
           if ($102) {
            break L12;
           }
           $103 = (($d$14$i271) + ($8<<1)|0);
           $$13$i272 = $96;$d$14$i271 = $103;
          }
         }
        }
       } while(0);
       $104 = ($a0$0|0)==(0|0);
       if ($104) {
        break;
       }
       $105 = ($a1$0|0)==(0|0);
       if (!($105)) {
        if ($42) {
         break;
        }
        $$06$i259 = $0;$d$07$i258 = $a0$0;$s$08$i257 = $a1$0;
        while(1) {
         $106 = (($$06$i259) + -1)|0;
         $107 = HEAP16[$s$08$i257>>1]|0;
         HEAP16[$d$07$i258>>1] = $107;
         $108 = (($d$07$i258) + ($8<<1)|0);
         $109 = (($s$08$i257) + ($11<<1)|0);
         $110 = ($106|0)==(0);
         if ($110) {
          break L8;
         } else {
          $$06$i259 = $106;$d$07$i258 = $108;$s$08$i257 = $109;
         }
        }
       }
       if ($42) {
        break;
       } else {
        $$13$i261 = $0;$d$14$i260 = $a0$0;
       }
       while(1) {
        $111 = (($$13$i261) + -1)|0;
        $112 = (1137192 + 254|0);
        $113 = HEAP16[$112>>1]|0;
        $114 = ($113<<16>>16)==(0);
        if ($114) {
         $115 = (__ZN4half7convertEi(1065353216)|0);
         $116 = $115;
        } else {
         $116 = $113;
        }
        HEAP16[$d$14$i260>>1] = $116;
        $117 = ($111|0)==(0);
        if ($117) {
         break L8;
        }
        $118 = (($d$14$i260) + ($8<<1)|0);
        $$13$i261 = $111;$d$14$i260 = $118;
       }
      } else if ((($20|0) == 1)) {
       __Z12COPY_FI_FRGBI4halfS0_EvjjjPvS1_PKvS3_S3_S3_($0,$8,$11,$$2,$a0$0,$$3,$g1$0,$$4,$a1$0);
       break;
      } else if ((($20|0) == 2)) {
       __Z12COPY_FRGB_FII4halfS0_EvjjjPvS1_S1_S1_PKvS3_($0,$8,$11,$$1,$g0$0,$$2,$a0$0,$$4,$a1$0);
       break;
      } else if ((($20|0) == 3)) {
       $119 = ($$1|0)==(0|0);
       L43: do {
        if (!($119)) {
         $120 = ($$3|0)==(0|0);
         if (!($120)) {
          if ($42) {
           break;
          }
          $$06$i248 = $0;$d$07$i247 = $$1;$s$08$i246 = $$3;
          while(1) {
           $121 = (($$06$i248) + -1)|0;
           $122 = HEAP16[$s$08$i246>>1]|0;
           HEAP16[$d$07$i247>>1] = $122;
           $123 = (($d$07$i247) + ($8<<1)|0);
           $124 = (($s$08$i246) + ($11<<1)|0);
           $125 = ($121|0)==(0);
           if ($125) {
            break L43;
           } else {
            $$06$i248 = $121;$d$07$i247 = $123;$s$08$i246 = $124;
           }
          }
         }
         if (!($42)) {
          $$13$i250 = $0;$d$14$i249 = $$1;
          while(1) {
           $126 = (($$13$i250) + -1)|0;
           $127 = (1137192 + 254|0);
           $128 = HEAP16[$127>>1]|0;
           $129 = ($128<<16>>16)==(0);
           if ($129) {
            $130 = (__ZN4half7convertEi(1065353216)|0);
            $131 = $130;
           } else {
            $131 = $128;
           }
           HEAP16[$d$14$i249>>1] = $131;
           $132 = ($126|0)==(0);
           if ($132) {
            break L43;
           }
           $133 = (($d$14$i249) + ($8<<1)|0);
           $$13$i250 = $126;$d$14$i249 = $133;
          }
         }
        }
       } while(0);
       $134 = ($g0$0|0)==(0|0);
       L58: do {
        if (!($134)) {
         $135 = ($g1$0|0)==(0|0);
         if (!($135)) {
          if ($42) {
           break;
          }
          $$06$i237 = $0;$d$07$i236 = $g0$0;$s$08$i235 = $g1$0;
          while(1) {
           $136 = (($$06$i237) + -1)|0;
           $137 = HEAP16[$s$08$i235>>1]|0;
           HEAP16[$d$07$i236>>1] = $137;
           $138 = (($d$07$i236) + ($8<<1)|0);
           $139 = (($s$08$i235) + ($11<<1)|0);
           $140 = ($136|0)==(0);
           if ($140) {
            break L58;
           } else {
            $$06$i237 = $136;$d$07$i236 = $138;$s$08$i235 = $139;
           }
          }
         }
         if (!($42)) {
          $$13$i239 = $0;$d$14$i238 = $g0$0;
          while(1) {
           $141 = (($$13$i239) + -1)|0;
           $142 = (1137192 + 254|0);
           $143 = HEAP16[$142>>1]|0;
           $144 = ($143<<16>>16)==(0);
           if ($144) {
            $145 = (__ZN4half7convertEi(1065353216)|0);
            $146 = $145;
           } else {
            $146 = $143;
           }
           HEAP16[$d$14$i238>>1] = $146;
           $147 = ($141|0)==(0);
           if ($147) {
            break L58;
           }
           $148 = (($d$14$i238) + ($8<<1)|0);
           $$13$i239 = $141;$d$14$i238 = $148;
          }
         }
        }
       } while(0);
       $149 = ($$2|0)==(0|0);
       L73: do {
        if (!($149)) {
         $150 = ($$4|0)==(0|0);
         if (!($150)) {
          if ($42) {
           break;
          }
          $$06$i226 = $0;$d$07$i225 = $$2;$s$08$i224 = $$4;
          while(1) {
           $151 = (($$06$i226) + -1)|0;
           $152 = HEAP16[$s$08$i224>>1]|0;
           HEAP16[$d$07$i225>>1] = $152;
           $153 = (($d$07$i225) + ($8<<1)|0);
           $154 = (($s$08$i224) + ($11<<1)|0);
           $155 = ($151|0)==(0);
           if ($155) {
            break L73;
           } else {
            $$06$i226 = $151;$d$07$i225 = $153;$s$08$i224 = $154;
           }
          }
         }
         if (!($42)) {
          $$13$i228 = $0;$d$14$i227 = $$2;
          while(1) {
           $156 = (($$13$i228) + -1)|0;
           $157 = (1137192 + 254|0);
           $158 = HEAP16[$157>>1]|0;
           $159 = ($158<<16>>16)==(0);
           if ($159) {
            $160 = (__ZN4half7convertEi(1065353216)|0);
            $161 = $160;
           } else {
            $161 = $158;
           }
           HEAP16[$d$14$i227>>1] = $161;
           $162 = ($156|0)==(0);
           if ($162) {
            break L73;
           }
           $163 = (($d$14$i227) + ($8<<1)|0);
           $$13$i228 = $156;$d$14$i227 = $163;
          }
         }
        }
       } while(0);
       $164 = ($a0$0|0)==(0|0);
       if ($164) {
        break;
       }
       $165 = ($a1$0|0)==(0|0);
       if (!($165)) {
        if ($42) {
         break;
        }
        $$06$i216 = $0;$d$07$i215 = $a0$0;$s$08$i214 = $a1$0;
        while(1) {
         $166 = (($$06$i216) + -1)|0;
         $167 = HEAP16[$s$08$i214>>1]|0;
         HEAP16[$d$07$i215>>1] = $167;
         $168 = (($d$07$i215) + ($8<<1)|0);
         $169 = (($s$08$i214) + ($11<<1)|0);
         $170 = ($166|0)==(0);
         if ($170) {
          break L8;
         } else {
          $$06$i216 = $166;$d$07$i215 = $168;$s$08$i214 = $169;
         }
        }
       }
       if ($42) {
        break;
       } else {
        $$13$i218 = $0;$d$14$i217 = $a0$0;
       }
       while(1) {
        $171 = (($$13$i218) + -1)|0;
        $172 = (1137192 + 254|0);
        $173 = HEAP16[$172>>1]|0;
        $174 = ($173<<16>>16)==(0);
        if ($174) {
         $175 = (__ZN4half7convertEi(1065353216)|0);
         $176 = $175;
        } else {
         $176 = $173;
        }
        HEAP16[$d$14$i217>>1] = $176;
        $177 = ($171|0)==(0);
        if ($177) {
         break L8;
        }
        $178 = (($d$14$i217) + ($8<<1)|0);
        $$13$i218 = $171;$d$14$i217 = $178;
       }
      } else {
       break;
      }
     }
    } while(0);
    $179 = HEAP32[$16>>2]|0;
    $180 = $179 & 536870912;
    $181 = ($180|0)==(0);
    if (!($181)) {
     if ((($20|0) == 0)) {
      $182 = ($$2|0)==(0|0);
      L105: do {
       if (!($182)) {
        $183 = ($$4|0)==(0|0);
        if ($183) {
         if ($42) {
          break;
         } else {
          $$13$i207 = $0;$d$14$i206 = $$2;
         }
         while(1) {
          $203 = (($$13$i207) + -1)|0;
          $204 = (1137192 + 254|0);
          $205 = HEAP16[$204>>1]|0;
          $206 = ($205<<16>>16)==(0);
          if ($206) {
           $207 = (__ZN4half7convertEi(1065353216)|0);
           $208 = $207;
          } else {
           $208 = $205;
          }
          HEAP16[$d$14$i206>>1] = $208;
          $209 = ($203|0)==(0);
          if ($209) {
           break L105;
          }
          $210 = (($d$14$i206) + ($8<<1)|0);
          $$13$i207 = $203;$d$14$i206 = $210;
         }
        }
        if (!($42)) {
         $$06$i204 = $0;$d$07$i203 = $$2;$s$08$i202 = $$4;
         while(1) {
          $184 = (($$06$i204) + -1)|0;
          $185 = Math_fround(HEAPF32[$s$08$i202>>2]);
          $186 = $185 == Math_fround(0.0);
          do {
           if ($186) {
            $199 = 0;
           } else {
            $187 = (HEAPF32[tempDoublePtr>>2]=$185,HEAP32[tempDoublePtr>>2]|0);
            $188 = $187 >>> 23;
            $189 = (1137192 + ($188<<1)|0);
            $190 = HEAP16[$189>>1]|0;
            $191 = ($190<<16>>16)==(0);
            if ($191) {
             $198 = (__ZN4half7convertEi($187)|0);
             $199 = $198;
             break;
            } else {
             $192 = $190&65535;
             $193 = $187 & 8388607;
             $194 = (($193) + 4096)|0;
             $195 = $194 >>> 13;
             $196 = (($192) + ($195))|0;
             $197 = $196&65535;
             $199 = $197;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i203>>1] = $199;
          $200 = (($d$07$i203) + ($8<<1)|0);
          $201 = (($s$08$i202) + ($11<<2)|0);
          $202 = ($184|0)==(0);
          if ($202) {
           break;
          } else {
           $$06$i204 = $184;$d$07$i203 = $200;$s$08$i202 = $201;
          }
         }
        }
       }
      } while(0);
      $211 = ($a0$0|0)==(0|0);
      if ($211) {
       break;
      }
      $212 = ($a1$0|0)==(0|0);
      if ($212) {
       if ($42) {
        break;
       } else {
        $$13$i195 = $0;$d$14$i194 = $a0$0;
       }
       while(1) {
        $232 = (($$13$i195) + -1)|0;
        $233 = (1137192 + 254|0);
        $234 = HEAP16[$233>>1]|0;
        $235 = ($234<<16>>16)==(0);
        if ($235) {
         $236 = (__ZN4half7convertEi(1065353216)|0);
         $237 = $236;
        } else {
         $237 = $234;
        }
        HEAP16[$d$14$i194>>1] = $237;
        $238 = ($232|0)==(0);
        if ($238) {
         break L6;
        }
        $239 = (($d$14$i194) + ($8<<1)|0);
        $$13$i195 = $232;$d$14$i194 = $239;
       }
      }
      if ($42) {
       break;
      } else {
       $$06$i192 = $0;$d$07$i191 = $a0$0;$s$08$i190 = $a1$0;
      }
      while(1) {
       $213 = (($$06$i192) + -1)|0;
       $214 = Math_fround(HEAPF32[$s$08$i190>>2]);
       $215 = $214 == Math_fround(0.0);
       do {
        if ($215) {
         $228 = 0;
        } else {
         $216 = (HEAPF32[tempDoublePtr>>2]=$214,HEAP32[tempDoublePtr>>2]|0);
         $217 = $216 >>> 23;
         $218 = (1137192 + ($217<<1)|0);
         $219 = HEAP16[$218>>1]|0;
         $220 = ($219<<16>>16)==(0);
         if ($220) {
          $227 = (__ZN4half7convertEi($216)|0);
          $228 = $227;
          break;
         } else {
          $221 = $219&65535;
          $222 = $216 & 8388607;
          $223 = (($222) + 4096)|0;
          $224 = $223 >>> 13;
          $225 = (($221) + ($224))|0;
          $226 = $225&65535;
          $228 = $226;
          break;
         }
        }
       } while(0);
       HEAP16[$d$07$i191>>1] = $228;
       $229 = (($d$07$i191) + ($8<<1)|0);
       $230 = (($s$08$i190) + ($11<<2)|0);
       $231 = ($213|0)==(0);
       if ($231) {
        break;
       } else {
        $$06$i192 = $213;$d$07$i191 = $229;$s$08$i190 = $230;
       }
      }
     } else if ((($20|0) == 2)) {
      __Z12COPY_FRGB_FII4halffEvjjjPvS1_S1_S1_PKvS3_($0,$8,$11,$$1,$g0$0,$$2,$a0$0,$$4,$a1$0);
      break;
     } else if ((($20|0) == 3)) {
      $240 = ($$1|0)==(0|0);
      L145: do {
       if (!($240)) {
        $241 = ($$3|0)==(0|0);
        if ($241) {
         if ($42) {
          break;
         } else {
          $$13$i183 = $0;$d$14$i182 = $$1;
         }
         while(1) {
          $261 = (($$13$i183) + -1)|0;
          $262 = (1137192 + 254|0);
          $263 = HEAP16[$262>>1]|0;
          $264 = ($263<<16>>16)==(0);
          if ($264) {
           $265 = (__ZN4half7convertEi(1065353216)|0);
           $266 = $265;
          } else {
           $266 = $263;
          }
          HEAP16[$d$14$i182>>1] = $266;
          $267 = ($261|0)==(0);
          if ($267) {
           break L145;
          }
          $268 = (($d$14$i182) + ($8<<1)|0);
          $$13$i183 = $261;$d$14$i182 = $268;
         }
        }
        if (!($42)) {
         $$06$i180 = $0;$d$07$i179 = $$1;$s$08$i178 = $$3;
         while(1) {
          $242 = (($$06$i180) + -1)|0;
          $243 = Math_fround(HEAPF32[$s$08$i178>>2]);
          $244 = $243 == Math_fround(0.0);
          do {
           if ($244) {
            $257 = 0;
           } else {
            $245 = (HEAPF32[tempDoublePtr>>2]=$243,HEAP32[tempDoublePtr>>2]|0);
            $246 = $245 >>> 23;
            $247 = (1137192 + ($246<<1)|0);
            $248 = HEAP16[$247>>1]|0;
            $249 = ($248<<16>>16)==(0);
            if ($249) {
             $256 = (__ZN4half7convertEi($245)|0);
             $257 = $256;
             break;
            } else {
             $250 = $248&65535;
             $251 = $245 & 8388607;
             $252 = (($251) + 4096)|0;
             $253 = $252 >>> 13;
             $254 = (($250) + ($253))|0;
             $255 = $254&65535;
             $257 = $255;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i179>>1] = $257;
          $258 = (($d$07$i179) + ($8<<1)|0);
          $259 = (($s$08$i178) + ($11<<2)|0);
          $260 = ($242|0)==(0);
          if ($260) {
           break;
          } else {
           $$06$i180 = $242;$d$07$i179 = $258;$s$08$i178 = $259;
          }
         }
        }
       }
      } while(0);
      $269 = ($g0$0|0)==(0|0);
      L165: do {
       if (!($269)) {
        $270 = ($g1$0|0)==(0|0);
        if ($270) {
         if ($42) {
          break;
         } else {
          $$13$i171 = $0;$d$14$i170 = $g0$0;
         }
         while(1) {
          $290 = (($$13$i171) + -1)|0;
          $291 = (1137192 + 254|0);
          $292 = HEAP16[$291>>1]|0;
          $293 = ($292<<16>>16)==(0);
          if ($293) {
           $294 = (__ZN4half7convertEi(1065353216)|0);
           $295 = $294;
          } else {
           $295 = $292;
          }
          HEAP16[$d$14$i170>>1] = $295;
          $296 = ($290|0)==(0);
          if ($296) {
           break L165;
          }
          $297 = (($d$14$i170) + ($8<<1)|0);
          $$13$i171 = $290;$d$14$i170 = $297;
         }
        }
        if (!($42)) {
         $$06$i168 = $0;$d$07$i167 = $g0$0;$s$08$i166 = $g1$0;
         while(1) {
          $271 = (($$06$i168) + -1)|0;
          $272 = Math_fround(HEAPF32[$s$08$i166>>2]);
          $273 = $272 == Math_fround(0.0);
          do {
           if ($273) {
            $286 = 0;
           } else {
            $274 = (HEAPF32[tempDoublePtr>>2]=$272,HEAP32[tempDoublePtr>>2]|0);
            $275 = $274 >>> 23;
            $276 = (1137192 + ($275<<1)|0);
            $277 = HEAP16[$276>>1]|0;
            $278 = ($277<<16>>16)==(0);
            if ($278) {
             $285 = (__ZN4half7convertEi($274)|0);
             $286 = $285;
             break;
            } else {
             $279 = $277&65535;
             $280 = $274 & 8388607;
             $281 = (($280) + 4096)|0;
             $282 = $281 >>> 13;
             $283 = (($279) + ($282))|0;
             $284 = $283&65535;
             $286 = $284;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i167>>1] = $286;
          $287 = (($d$07$i167) + ($8<<1)|0);
          $288 = (($s$08$i166) + ($11<<2)|0);
          $289 = ($271|0)==(0);
          if ($289) {
           break;
          } else {
           $$06$i168 = $271;$d$07$i167 = $287;$s$08$i166 = $288;
          }
         }
        }
       }
      } while(0);
      $298 = ($$2|0)==(0|0);
      L185: do {
       if (!($298)) {
        $299 = ($$4|0)==(0|0);
        if ($299) {
         if ($42) {
          break;
         } else {
          $$13$i159 = $0;$d$14$i158 = $$2;
         }
         while(1) {
          $319 = (($$13$i159) + -1)|0;
          $320 = (1137192 + 254|0);
          $321 = HEAP16[$320>>1]|0;
          $322 = ($321<<16>>16)==(0);
          if ($322) {
           $323 = (__ZN4half7convertEi(1065353216)|0);
           $324 = $323;
          } else {
           $324 = $321;
          }
          HEAP16[$d$14$i158>>1] = $324;
          $325 = ($319|0)==(0);
          if ($325) {
           break L185;
          }
          $326 = (($d$14$i158) + ($8<<1)|0);
          $$13$i159 = $319;$d$14$i158 = $326;
         }
        }
        if (!($42)) {
         $$06$i156 = $0;$d$07$i155 = $$2;$s$08$i154 = $$4;
         while(1) {
          $300 = (($$06$i156) + -1)|0;
          $301 = Math_fround(HEAPF32[$s$08$i154>>2]);
          $302 = $301 == Math_fround(0.0);
          do {
           if ($302) {
            $315 = 0;
           } else {
            $303 = (HEAPF32[tempDoublePtr>>2]=$301,HEAP32[tempDoublePtr>>2]|0);
            $304 = $303 >>> 23;
            $305 = (1137192 + ($304<<1)|0);
            $306 = HEAP16[$305>>1]|0;
            $307 = ($306<<16>>16)==(0);
            if ($307) {
             $314 = (__ZN4half7convertEi($303)|0);
             $315 = $314;
             break;
            } else {
             $308 = $306&65535;
             $309 = $303 & 8388607;
             $310 = (($309) + 4096)|0;
             $311 = $310 >>> 13;
             $312 = (($308) + ($311))|0;
             $313 = $312&65535;
             $315 = $313;
             break;
            }
           }
          } while(0);
          HEAP16[$d$07$i155>>1] = $315;
          $316 = (($d$07$i155) + ($8<<1)|0);
          $317 = (($s$08$i154) + ($11<<2)|0);
          $318 = ($300|0)==(0);
          if ($318) {
           break;
          } else {
           $$06$i156 = $300;$d$07$i155 = $316;$s$08$i154 = $317;
          }
         }
        }
       }
      } while(0);
      $327 = ($a0$0|0)==(0|0);
      if ($327) {
       break;
      }
      $328 = ($a1$0|0)==(0|0);
      if ($328) {
       if ($42) {
        break;
       } else {
        $$13$i = $0;$d$14$i = $a0$0;
       }
       while(1) {
        $348 = (($$13$i) + -1)|0;
        $349 = (1137192 + 254|0);
        $350 = HEAP16[$349>>1]|0;
        $351 = ($350<<16>>16)==(0);
        if ($351) {
         $352 = (__ZN4half7convertEi(1065353216)|0);
         $353 = $352;
        } else {
         $353 = $350;
        }
        HEAP16[$d$14$i>>1] = $353;
        $354 = ($348|0)==(0);
        if ($354) {
         break L6;
        }
        $355 = (($d$14$i) + ($8<<1)|0);
        $$13$i = $348;$d$14$i = $355;
       }
      }
      if ($42) {
       break;
      } else {
       $$06$i = $0;$d$07$i = $a0$0;$s$08$i = $a1$0;
      }
      while(1) {
       $329 = (($$06$i) + -1)|0;
       $330 = Math_fround(HEAPF32[$s$08$i>>2]);
       $331 = $330 == Math_fround(0.0);
       do {
        if ($331) {
         $344 = 0;
        } else {
         $332 = (HEAPF32[tempDoublePtr>>2]=$330,HEAP32[tempDoublePtr>>2]|0);
         $333 = $332 >>> 23;
         $334 = (1137192 + ($333<<1)|0);
         $335 = HEAP16[$334>>1]|0;
         $336 = ($335<<16>>16)==(0);
         if ($336) {
          $343 = (__ZN4half7convertEi($332)|0);
          $344 = $343;
          break;
         } else {
          $337 = $335&65535;
          $338 = $332 & 8388607;
          $339 = (($338) + 4096)|0;
          $340 = $339 >>> 13;
          $341 = (($337) + ($340))|0;
          $342 = $341&65535;
          $344 = $342;
          break;
         }
        }
       } while(0);
       HEAP16[$d$07$i>>1] = $344;
       $345 = (($d$07$i) + ($8<<1)|0);
       $346 = (($s$08$i) + ($11<<2)|0);
       $347 = ($329|0)==(0);
       if ($347) {
        break;
       } else {
        $$06$i = $329;$d$07$i = $345;$s$08$i = $346;
       }
      }
     } else if ((($20|0) == 1)) {
      __Z12COPY_FI_FRGBI4halffEvjjjPvS1_PKvS3_S3_S3_($0,$8,$11,$$2,$a0$0,$$3,$g1$0,$$4,$a1$0);
      break;
     } else {
      break;
     }
    }
   }
  } while(0);
  $356 = HEAP32[$12>>2]|0;
  $357 = $356 & 536870912;
  $358 = ($357|0)==(0);
  do {
   if (!($358)) {
    $359 = HEAP32[$16>>2]|0;
    $360 = $359 & 1073741824;
    $361 = ($360|0)==(0);
    L227: do {
     if (!($361)) {
      if ((($20|0) == 2)) {
       if ($42) {
        break;
       }
       $$in$i94 = $0;$a0$04$i97 = $a0$0;$a1$06$i95 = $a1$0;$b0$03$i98 = $$2;$g0$02$i99 = $g0$0;$i1$05$i96 = $$4;$r0$01$i100 = $$1;
       while(1) {
        $420 = (($$in$i94) + -1)|0;
        $421 = ($i1$05$i96|0)==(0|0);
        if ($421) {
         $i$0$i102 = Math_fround(1.0);$i1$1$i101 = 0;
        } else {
         $422 = HEAP16[$i1$05$i96>>1]|0;
         $423 = $422&65535;
         $424 = (875048 + ($423<<2)|0);
         $425 = Math_fround(HEAPF32[$424>>2]);
         $426 = (($i1$05$i96) + ($11<<1)|0);
         $i$0$i102 = $425;$i1$1$i101 = $426;
        }
        $427 = ($a1$06$i95|0)==(0|0);
        if ($427) {
         $a$0$i104 = Math_fround(1.0);$a1$1$i103 = 0;
        } else {
         $428 = HEAP16[$a1$06$i95>>1]|0;
         $429 = $428&65535;
         $430 = (875048 + ($429<<2)|0);
         $431 = Math_fround(HEAPF32[$430>>2]);
         $432 = (($a1$06$i95) + ($11<<1)|0);
         $a$0$i104 = $431;$a1$1$i103 = $432;
        }
        $433 = ($r0$01$i100|0)==(0|0);
        if ($433) {
         $r0$1$i105 = 0;
        } else {
         HEAPF32[$r0$01$i100>>2] = $i$0$i102;
         $434 = (($r0$01$i100) + ($8<<2)|0);
         $r0$1$i105 = $434;
        }
        $435 = ($g0$02$i99|0)==(0|0);
        if ($435) {
         $g0$1$i106 = 0;
        } else {
         HEAPF32[$g0$02$i99>>2] = $i$0$i102;
         $436 = (($g0$02$i99) + ($8<<2)|0);
         $g0$1$i106 = $436;
        }
        $437 = ($b0$03$i98|0)==(0|0);
        if ($437) {
         $b0$1$i107 = 0;
        } else {
         HEAPF32[$b0$03$i98>>2] = $i$0$i102;
         $438 = (($b0$03$i98) + ($8<<2)|0);
         $b0$1$i107 = $438;
        }
        $439 = ($a0$04$i97|0)==(0|0);
        if ($439) {
         $a0$0$be$i108 = 0;
        } else {
         HEAPF32[$a0$04$i97>>2] = $a$0$i104;
         $440 = (($a0$04$i97) + ($8<<2)|0);
         $a0$0$be$i108 = $440;
        }
        $441 = ($420|0)==(0);
        if ($441) {
         break;
        } else {
         $$in$i94 = $420;$a0$04$i97 = $a0$0$be$i108;$a1$06$i95 = $a1$1$i103;$b0$03$i98 = $b0$1$i107;$g0$02$i99 = $g0$1$i106;$i1$05$i96 = $i1$1$i101;$r0$01$i100 = $r0$1$i105;
        }
       }
      } else if ((($20|0) == 3)) {
       $442 = ($$1|0)==(0|0);
       L253: do {
        if (!($442)) {
         $443 = ($$3|0)==(0|0);
         if ($443) {
          if ($42) {
           break;
          } else {
           $$11$i90 = $0;$d$12$i89 = $$1;
          }
          while(1) {
           $452 = (($$11$i90) + -1)|0;
           HEAPF32[$d$12$i89>>2] = Math_fround(1.0);
           $453 = (($d$12$i89) + ($8<<2)|0);
           $454 = ($452|0)==(0);
           if ($454) {
            break L253;
           } else {
            $$11$i90 = $452;$d$12$i89 = $453;
           }
          }
         }
         if (!($42)) {
          $$04$i88 = $0;$d$05$i87 = $$1;$s$06$i86 = $$3;
          while(1) {
           $444 = (($$04$i88) + -1)|0;
           $445 = HEAP16[$s$06$i86>>1]|0;
           $446 = $445&65535;
           $447 = (875048 + ($446<<2)|0);
           $448 = Math_fround(HEAPF32[$447>>2]);
           HEAPF32[$d$05$i87>>2] = $448;
           $449 = (($d$05$i87) + ($8<<2)|0);
           $450 = (($s$06$i86) + ($11<<1)|0);
           $451 = ($444|0)==(0);
           if ($451) {
            break;
           } else {
            $$04$i88 = $444;$d$05$i87 = $449;$s$06$i86 = $450;
           }
          }
         }
        }
       } while(0);
       $455 = ($g0$0|0)==(0|0);
       L264: do {
        if (!($455)) {
         $456 = ($g1$0|0)==(0|0);
         if ($456) {
          if ($42) {
           break;
          } else {
           $$11$i81 = $0;$d$12$i80 = $g0$0;
          }
          while(1) {
           $465 = (($$11$i81) + -1)|0;
           HEAPF32[$d$12$i80>>2] = Math_fround(1.0);
           $466 = (($d$12$i80) + ($8<<2)|0);
           $467 = ($465|0)==(0);
           if ($467) {
            break L264;
           } else {
            $$11$i81 = $465;$d$12$i80 = $466;
           }
          }
         }
         if (!($42)) {
          $$04$i79 = $0;$d$05$i78 = $g0$0;$s$06$i77 = $g1$0;
          while(1) {
           $457 = (($$04$i79) + -1)|0;
           $458 = HEAP16[$s$06$i77>>1]|0;
           $459 = $458&65535;
           $460 = (875048 + ($459<<2)|0);
           $461 = Math_fround(HEAPF32[$460>>2]);
           HEAPF32[$d$05$i78>>2] = $461;
           $462 = (($d$05$i78) + ($8<<2)|0);
           $463 = (($s$06$i77) + ($11<<1)|0);
           $464 = ($457|0)==(0);
           if ($464) {
            break;
           } else {
            $$04$i79 = $457;$d$05$i78 = $462;$s$06$i77 = $463;
           }
          }
         }
        }
       } while(0);
       $468 = ($$2|0)==(0|0);
       L275: do {
        if (!($468)) {
         $469 = ($$4|0)==(0|0);
         if ($469) {
          if ($42) {
           break;
          } else {
           $$11$i72 = $0;$d$12$i71 = $$2;
          }
          while(1) {
           $478 = (($$11$i72) + -1)|0;
           HEAPF32[$d$12$i71>>2] = Math_fround(1.0);
           $479 = (($d$12$i71) + ($8<<2)|0);
           $480 = ($478|0)==(0);
           if ($480) {
            break L275;
           } else {
            $$11$i72 = $478;$d$12$i71 = $479;
           }
          }
         }
         if (!($42)) {
          $$04$i70 = $0;$d$05$i69 = $$2;$s$06$i68 = $$4;
          while(1) {
           $470 = (($$04$i70) + -1)|0;
           $471 = HEAP16[$s$06$i68>>1]|0;
           $472 = $471&65535;
           $473 = (875048 + ($472<<2)|0);
           $474 = Math_fround(HEAPF32[$473>>2]);
           HEAPF32[$d$05$i69>>2] = $474;
           $475 = (($d$05$i69) + ($8<<2)|0);
           $476 = (($s$06$i68) + ($11<<1)|0);
           $477 = ($470|0)==(0);
           if ($477) {
            break;
           } else {
            $$04$i70 = $470;$d$05$i69 = $475;$s$06$i68 = $476;
           }
          }
         }
        }
       } while(0);
       $481 = ($a0$0|0)==(0|0);
       if ($481) {
        break;
       }
       $482 = ($a1$0|0)==(0|0);
       if ($482) {
        if ($42) {
         break;
        } else {
         $$11$i64 = $0;$d$12$i63 = $a0$0;
        }
        while(1) {
         $491 = (($$11$i64) + -1)|0;
         HEAPF32[$d$12$i63>>2] = Math_fround(1.0);
         $492 = (($d$12$i63) + ($8<<2)|0);
         $493 = ($491|0)==(0);
         if ($493) {
          break L227;
         } else {
          $$11$i64 = $491;$d$12$i63 = $492;
         }
        }
       }
       if ($42) {
        break;
       }
       $$04$i62 = $0;$d$05$i61 = $a0$0;$s$06$i60 = $a1$0;
       while(1) {
        $483 = (($$04$i62) + -1)|0;
        $484 = HEAP16[$s$06$i60>>1]|0;
        $485 = $484&65535;
        $486 = (875048 + ($485<<2)|0);
        $487 = Math_fround(HEAPF32[$486>>2]);
        HEAPF32[$d$05$i61>>2] = $487;
        $488 = (($d$05$i61) + ($8<<2)|0);
        $489 = (($s$06$i60) + ($11<<1)|0);
        $490 = ($483|0)==(0);
        if ($490) {
         break;
        } else {
         $$04$i62 = $483;$d$05$i61 = $488;$s$06$i60 = $489;
        }
       }
      } else if ((($20|0) == 0)) {
       $362 = ($$2|0)==(0|0);
       L296: do {
        if (!($362)) {
         $363 = ($$4|0)==(0|0);
         if ($363) {
          if ($42) {
           break;
          } else {
           $$11$i147 = $0;$d$12$i146 = $$2;
          }
          while(1) {
           $372 = (($$11$i147) + -1)|0;
           HEAPF32[$d$12$i146>>2] = Math_fround(1.0);
           $373 = (($d$12$i146) + ($8<<2)|0);
           $374 = ($372|0)==(0);
           if ($374) {
            break L296;
           } else {
            $$11$i147 = $372;$d$12$i146 = $373;
           }
          }
         }
         if (!($42)) {
          $$04$i145 = $0;$d$05$i144 = $$2;$s$06$i143 = $$4;
          while(1) {
           $364 = (($$04$i145) + -1)|0;
           $365 = HEAP16[$s$06$i143>>1]|0;
           $366 = $365&65535;
           $367 = (875048 + ($366<<2)|0);
           $368 = Math_fround(HEAPF32[$367>>2]);
           HEAPF32[$d$05$i144>>2] = $368;
           $369 = (($d$05$i144) + ($8<<2)|0);
           $370 = (($s$06$i143) + ($11<<1)|0);
           $371 = ($364|0)==(0);
           if ($371) {
            break;
           } else {
            $$04$i145 = $364;$d$05$i144 = $369;$s$06$i143 = $370;
           }
          }
         }
        }
       } while(0);
       $375 = ($a0$0|0)==(0|0);
       if ($375) {
        break;
       }
       $376 = ($a1$0|0)==(0|0);
       if ($376) {
        if ($42) {
         break;
        } else {
         $$11$i138 = $0;$d$12$i137 = $a0$0;
        }
        while(1) {
         $385 = (($$11$i138) + -1)|0;
         HEAPF32[$d$12$i137>>2] = Math_fround(1.0);
         $386 = (($d$12$i137) + ($8<<2)|0);
         $387 = ($385|0)==(0);
         if ($387) {
          break L227;
         } else {
          $$11$i138 = $385;$d$12$i137 = $386;
         }
        }
       }
       if ($42) {
        break;
       }
       $$04$i136 = $0;$d$05$i135 = $a0$0;$s$06$i134 = $a1$0;
       while(1) {
        $377 = (($$04$i136) + -1)|0;
        $378 = HEAP16[$s$06$i134>>1]|0;
        $379 = $378&65535;
        $380 = (875048 + ($379<<2)|0);
        $381 = Math_fround(HEAPF32[$380>>2]);
        HEAPF32[$d$05$i135>>2] = $381;
        $382 = (($d$05$i135) + ($8<<2)|0);
        $383 = (($s$06$i134) + ($11<<1)|0);
        $384 = ($377|0)==(0);
        if ($384) {
         break;
        } else {
         $$04$i136 = $377;$d$05$i135 = $382;$s$06$i134 = $383;
        }
       }
      } else if ((($20|0) == 1)) {
       if ($42) {
        break;
       }
       $$in$i111 = $0;$a0$04$i116 = $a0$0;$a1$08$i112 = $a1$0;$b1$07$i113 = $$4;$g1$06$i114 = $g1$0;$i0$03$i117 = $$2;$r1$05$i115 = $$3;
       while(1) {
        $388 = (($$in$i111) + -1)|0;
        $389 = ($r1$05$i115|0)==(0|0);
        if ($389) {
         $r$0$i120 = Math_fround(0.298999994993209838867);$r1$1$i119 = 0;
        } else {
         $390 = HEAP16[$r1$05$i115>>1]|0;
         $391 = $390&65535;
         $392 = (875048 + ($391<<2)|0);
         $393 = Math_fround(HEAPF32[$392>>2]);
         $394 = (($r1$05$i115) + ($11<<1)|0);
         $phitmp2$i118 = Math_fround($393 * Math_fround(0.298999994993209838867));
         $r$0$i120 = $phitmp2$i118;$r1$1$i119 = $394;
        }
        $395 = ($g1$06$i114|0)==(0|0);
        if ($395) {
         $g$0$i123 = Math_fround(0.587000012397766113281);$g1$1$i122 = 0;
        } else {
         $396 = HEAP16[$g1$06$i114>>1]|0;
         $397 = $396&65535;
         $398 = (875048 + ($397<<2)|0);
         $399 = Math_fround(HEAPF32[$398>>2]);
         $400 = (($g1$06$i114) + ($11<<1)|0);
         $phitmp1$i121 = Math_fround($399 * Math_fround(0.587000012397766113281));
         $g$0$i123 = $phitmp1$i121;$g1$1$i122 = $400;
        }
        $401 = ($b1$07$i113|0)==(0|0);
        if ($401) {
         $b$0$i126 = Math_fround(0.114000000059604644775);$b1$1$i125 = 0;
        } else {
         $402 = HEAP16[$b1$07$i113>>1]|0;
         $403 = $402&65535;
         $404 = (875048 + ($403<<2)|0);
         $405 = Math_fround(HEAPF32[$404>>2]);
         $406 = (($b1$07$i113) + ($11<<1)|0);
         $phitmp$i124 = Math_fround($405 * Math_fround(0.114000000059604644775));
         $b$0$i126 = $phitmp$i124;$b1$1$i125 = $406;
        }
        $407 = ($a1$08$i112|0)==(0|0);
        if ($407) {
         $a$0$i128 = Math_fround(1.0);$a1$1$i127 = 0;
        } else {
         $408 = HEAP16[$a1$08$i112>>1]|0;
         $409 = $408&65535;
         $410 = (875048 + ($409<<2)|0);
         $411 = Math_fround(HEAPF32[$410>>2]);
         $412 = (($a1$08$i112) + ($11<<1)|0);
         $a$0$i128 = $411;$a1$1$i127 = $412;
        }
        $413 = ($i0$03$i117|0)==(0|0);
        if ($413) {
         $i0$1$i129 = 0;
        } else {
         $414 = Math_fround($g$0$i123 + $b$0$i126);
         $415 = Math_fround($r$0$i120 + $414);
         HEAPF32[$i0$03$i117>>2] = $415;
         $416 = (($i0$03$i117) + ($8<<2)|0);
         $i0$1$i129 = $416;
        }
        $417 = ($a0$04$i116|0)==(0|0);
        if ($417) {
         $a0$0$be$i130 = 0;
        } else {
         HEAPF32[$a0$04$i116>>2] = $a$0$i128;
         $418 = (($a0$04$i116) + ($8<<2)|0);
         $a0$0$be$i130 = $418;
        }
        $419 = ($388|0)==(0);
        if ($419) {
         break;
        } else {
         $$in$i111 = $388;$a0$04$i116 = $a0$0$be$i130;$a1$08$i112 = $a1$1$i127;$b1$07$i113 = $b1$1$i125;$g1$06$i114 = $g1$1$i122;$i0$03$i117 = $i0$1$i129;$r1$05$i115 = $r1$1$i119;
        }
       }
      } else {
       break;
      }
     }
    } while(0);
    $494 = $359 & 536870912;
    $495 = ($494|0)==(0);
    if (!($495)) {
     if ((($20|0) == 0)) {
      $496 = ($$2|0)==(0|0);
      do {
       if (!($496)) {
        $497 = ($$4|0)==(0|0);
        if ($497) {
         if ($42) {
          break;
         } else {
          $$11$i55 = $0;$d$12$i54 = $$2;
         }
         while(1) {
          $503 = (($$11$i55) + -1)|0;
          HEAPF32[$d$12$i54>>2] = Math_fround(1.0);
          $504 = (($d$12$i54) + ($8<<2)|0);
          $505 = ($503|0)==(0);
          if ($505) {
           break;
          } else {
           $$11$i55 = $503;$d$12$i54 = $504;
          }
         }
        } else {
         if ($42) {
          break;
         } else {
          $$04$i53 = $0;$d$05$i52 = $$2;$s$06$i51 = $$4;
         }
         while(1) {
          $498 = (($$04$i53) + -1)|0;
          $499 = Math_fround(HEAPF32[$s$06$i51>>2]);
          HEAPF32[$d$05$i52>>2] = $499;
          $500 = (($d$05$i52) + ($8<<2)|0);
          $501 = (($s$06$i51) + ($11<<2)|0);
          $502 = ($498|0)==(0);
          if ($502) {
           break;
          } else {
           $$04$i53 = $498;$d$05$i52 = $500;$s$06$i51 = $501;
          }
         }
        }
       }
      } while(0);
      $506 = ($a0$0|0)==(0|0);
      if ($506) {
       break;
      }
      $507 = ($a1$0|0)==(0|0);
      if ($507) {
       if ($42) {
        break;
       } else {
        $$11$i46 = $0;$d$12$i45 = $a0$0;
       }
       while(1) {
        $513 = (($$11$i46) + -1)|0;
        HEAPF32[$d$12$i45>>2] = Math_fround(1.0);
        $514 = (($d$12$i45) + ($8<<2)|0);
        $515 = ($513|0)==(0);
        if ($515) {
         break;
        } else {
         $$11$i46 = $513;$d$12$i45 = $514;
        }
       }
      } else {
       if ($42) {
        break;
       } else {
        $$04$i44 = $0;$d$05$i43 = $a0$0;$s$06$i42 = $a1$0;
       }
       while(1) {
        $508 = (($$04$i44) + -1)|0;
        $509 = Math_fround(HEAPF32[$s$06$i42>>2]);
        HEAPF32[$d$05$i43>>2] = $509;
        $510 = (($d$05$i43) + ($8<<2)|0);
        $511 = (($s$06$i42) + ($11<<2)|0);
        $512 = ($508|0)==(0);
        if ($512) {
         break;
        } else {
         $$04$i44 = $508;$d$05$i43 = $510;$s$06$i42 = $511;
        }
       }
      }
     } else if ((($20|0) == 2)) {
      if ($42) {
       break;
      } else {
       $$in$i = $0;$a0$04$i = $a0$0;$a1$06$i = $a1$0;$b0$03$i = $$2;$g0$02$i = $g0$0;$i1$05$i = $$4;$r0$01$i = $$1;
      }
      while(1) {
       $536 = (($$in$i) + -1)|0;
       $537 = ($i1$05$i|0)==(0|0);
       if ($537) {
        $i$0$i = Math_fround(1.0);$i1$1$i = 0;
       } else {
        $538 = Math_fround(HEAPF32[$i1$05$i>>2]);
        $539 = (($i1$05$i) + ($11<<2)|0);
        $i$0$i = $538;$i1$1$i = $539;
       }
       $540 = ($a1$06$i|0)==(0|0);
       if ($540) {
        $a$0$i = Math_fround(1.0);$a1$1$i = 0;
       } else {
        $541 = Math_fround(HEAPF32[$a1$06$i>>2]);
        $542 = (($a1$06$i) + ($11<<2)|0);
        $a$0$i = $541;$a1$1$i = $542;
       }
       $543 = ($r0$01$i|0)==(0|0);
       if ($543) {
        $r0$1$i = 0;
       } else {
        HEAPF32[$r0$01$i>>2] = $i$0$i;
        $544 = (($r0$01$i) + ($8<<2)|0);
        $r0$1$i = $544;
       }
       $545 = ($g0$02$i|0)==(0|0);
       if ($545) {
        $g0$1$i = 0;
       } else {
        HEAPF32[$g0$02$i>>2] = $i$0$i;
        $546 = (($g0$02$i) + ($8<<2)|0);
        $g0$1$i = $546;
       }
       $547 = ($b0$03$i|0)==(0|0);
       if ($547) {
        $b0$1$i = 0;
       } else {
        HEAPF32[$b0$03$i>>2] = $i$0$i;
        $548 = (($b0$03$i) + ($8<<2)|0);
        $b0$1$i = $548;
       }
       $549 = ($a0$04$i|0)==(0|0);
       if ($549) {
        $a0$0$be$i = 0;
       } else {
        HEAPF32[$a0$04$i>>2] = $a$0$i;
        $550 = (($a0$04$i) + ($8<<2)|0);
        $a0$0$be$i = $550;
       }
       $551 = ($536|0)==(0);
       if ($551) {
        break;
       } else {
        $$in$i = $536;$a0$04$i = $a0$0$be$i;$a1$06$i = $a1$1$i;$b0$03$i = $b0$1$i;$g0$02$i = $g0$1$i;$i1$05$i = $i1$1$i;$r0$01$i = $r0$1$i;
       }
      }
     } else if ((($20|0) == 1)) {
      if ($42) {
       break;
      } else {
       $$in$i34 = $0;$a0$04$i35 = $a0$0;$a1$08$i = $a1$0;$b1$07$i = $$4;$g1$06$i = $g1$0;$i0$03$i = $$2;$r1$05$i = $$3;
      }
      while(1) {
       $516 = (($$in$i34) + -1)|0;
       $517 = ($r1$05$i|0)==(0|0);
       if ($517) {
        $r$0$i = Math_fround(0.298999994993209838867);$r1$1$i = 0;
       } else {
        $518 = Math_fround(HEAPF32[$r1$05$i>>2]);
        $519 = (($r1$05$i) + ($11<<2)|0);
        $phitmp2$i = Math_fround($518 * Math_fround(0.298999994993209838867));
        $r$0$i = $phitmp2$i;$r1$1$i = $519;
       }
       $520 = ($g1$06$i|0)==(0|0);
       if ($520) {
        $g$0$i = Math_fround(0.587000012397766113281);$g1$1$i = 0;
       } else {
        $521 = Math_fround(HEAPF32[$g1$06$i>>2]);
        $522 = (($g1$06$i) + ($11<<2)|0);
        $phitmp1$i = Math_fround($521 * Math_fround(0.587000012397766113281));
        $g$0$i = $phitmp1$i;$g1$1$i = $522;
       }
       $523 = ($b1$07$i|0)==(0|0);
       if ($523) {
        $b$0$i = Math_fround(0.114000000059604644775);$b1$1$i = 0;
       } else {
        $524 = Math_fround(HEAPF32[$b1$07$i>>2]);
        $525 = (($b1$07$i) + ($11<<2)|0);
        $phitmp$i = Math_fround($524 * Math_fround(0.114000000059604644775));
        $b$0$i = $phitmp$i;$b1$1$i = $525;
       }
       $526 = ($a1$08$i|0)==(0|0);
       if ($526) {
        $a$0$i37 = Math_fround(1.0);$a1$1$i36 = 0;
       } else {
        $527 = Math_fround(HEAPF32[$a1$08$i>>2]);
        $528 = (($a1$08$i) + ($11<<2)|0);
        $a$0$i37 = $527;$a1$1$i36 = $528;
       }
       $529 = ($i0$03$i|0)==(0|0);
       if ($529) {
        $i0$1$i = 0;
       } else {
        $530 = Math_fround($g$0$i + $b$0$i);
        $531 = Math_fround($r$0$i + $530);
        HEAPF32[$i0$03$i>>2] = $531;
        $532 = (($i0$03$i) + ($8<<2)|0);
        $i0$1$i = $532;
       }
       $533 = ($a0$04$i35|0)==(0|0);
       if ($533) {
        $a0$0$be$i38 = 0;
       } else {
        HEAPF32[$a0$04$i35>>2] = $a$0$i37;
        $534 = (($a0$04$i35) + ($8<<2)|0);
        $a0$0$be$i38 = $534;
       }
       $535 = ($516|0)==(0);
       if ($535) {
        break;
       } else {
        $$in$i34 = $516;$a0$04$i35 = $a0$0$be$i38;$a1$08$i = $a1$1$i36;$b1$07$i = $b1$1$i;$g1$06$i = $g1$1$i;$i0$03$i = $i0$1$i;$r1$05$i = $r1$1$i;
       }
      }
     } else if ((($20|0) == 3)) {
      $552 = ($$1|0)==(0|0);
      do {
       if (!($552)) {
        $553 = ($$3|0)==(0|0);
        if ($553) {
         if ($42) {
          break;
         } else {
          $$11$i29 = $0;$d$12$i28 = $$1;
         }
         while(1) {
          $559 = (($$11$i29) + -1)|0;
          HEAPF32[$d$12$i28>>2] = Math_fround(1.0);
          $560 = (($d$12$i28) + ($8<<2)|0);
          $561 = ($559|0)==(0);
          if ($561) {
           break;
          } else {
           $$11$i29 = $559;$d$12$i28 = $560;
          }
         }
        } else {
         if ($42) {
          break;
         } else {
          $$04$i27 = $0;$d$05$i26 = $$1;$s$06$i25 = $$3;
         }
         while(1) {
          $554 = (($$04$i27) + -1)|0;
          $555 = Math_fround(HEAPF32[$s$06$i25>>2]);
          HEAPF32[$d$05$i26>>2] = $555;
          $556 = (($d$05$i26) + ($8<<2)|0);
          $557 = (($s$06$i25) + ($11<<2)|0);
          $558 = ($554|0)==(0);
          if ($558) {
           break;
          } else {
           $$04$i27 = $554;$d$05$i26 = $556;$s$06$i25 = $557;
          }
         }
        }
       }
      } while(0);
      $562 = ($g0$0|0)==(0|0);
      do {
       if (!($562)) {
        $563 = ($g1$0|0)==(0|0);
        if ($563) {
         if ($42) {
          break;
         } else {
          $$11$i20 = $0;$d$12$i19 = $g0$0;
         }
         while(1) {
          $569 = (($$11$i20) + -1)|0;
          HEAPF32[$d$12$i19>>2] = Math_fround(1.0);
          $570 = (($d$12$i19) + ($8<<2)|0);
          $571 = ($569|0)==(0);
          if ($571) {
           break;
          } else {
           $$11$i20 = $569;$d$12$i19 = $570;
          }
         }
        } else {
         if ($42) {
          break;
         } else {
          $$04$i18 = $0;$d$05$i17 = $g0$0;$s$06$i16 = $g1$0;
         }
         while(1) {
          $564 = (($$04$i18) + -1)|0;
          $565 = Math_fround(HEAPF32[$s$06$i16>>2]);
          HEAPF32[$d$05$i17>>2] = $565;
          $566 = (($d$05$i17) + ($8<<2)|0);
          $567 = (($s$06$i16) + ($11<<2)|0);
          $568 = ($564|0)==(0);
          if ($568) {
           break;
          } else {
           $$04$i18 = $564;$d$05$i17 = $566;$s$06$i16 = $567;
          }
         }
        }
       }
      } while(0);
      $572 = ($$2|0)==(0|0);
      do {
       if (!($572)) {
        $573 = ($$4|0)==(0|0);
        if ($573) {
         if ($42) {
          break;
         } else {
          $$11$i11 = $0;$d$12$i10 = $$2;
         }
         while(1) {
          $579 = (($$11$i11) + -1)|0;
          HEAPF32[$d$12$i10>>2] = Math_fround(1.0);
          $580 = (($d$12$i10) + ($8<<2)|0);
          $581 = ($579|0)==(0);
          if ($581) {
           break;
          } else {
           $$11$i11 = $579;$d$12$i10 = $580;
          }
         }
        } else {
         if ($42) {
          break;
         } else {
          $$04$i9 = $0;$d$05$i8 = $$2;$s$06$i7 = $$4;
         }
         while(1) {
          $574 = (($$04$i9) + -1)|0;
          $575 = Math_fround(HEAPF32[$s$06$i7>>2]);
          HEAPF32[$d$05$i8>>2] = $575;
          $576 = (($d$05$i8) + ($8<<2)|0);
          $577 = (($s$06$i7) + ($11<<2)|0);
          $578 = ($574|0)==(0);
          if ($578) {
           break;
          } else {
           $$04$i9 = $574;$d$05$i8 = $576;$s$06$i7 = $577;
          }
         }
        }
       }
      } while(0);
      $582 = ($a0$0|0)==(0|0);
      if ($582) {
       break;
      }
      $583 = ($a1$0|0)==(0|0);
      if ($583) {
       if ($42) {
        break;
       } else {
        $$11$i = $0;$d$12$i = $a0$0;
       }
       while(1) {
        $589 = (($$11$i) + -1)|0;
        HEAPF32[$d$12$i>>2] = Math_fround(1.0);
        $590 = (($d$12$i) + ($8<<2)|0);
        $591 = ($589|0)==(0);
        if ($591) {
         break;
        } else {
         $$11$i = $589;$d$12$i = $590;
        }
       }
      } else {
       if ($42) {
        break;
       } else {
        $$04$i = $0;$d$05$i = $a0$0;$s$06$i = $a1$0;
       }
       while(1) {
        $584 = (($$04$i) + -1)|0;
        $585 = Math_fround(HEAPF32[$s$06$i>>2]);
        HEAPF32[$d$05$i>>2] = $585;
        $586 = (($d$05$i) + ($8<<2)|0);
        $587 = (($s$06$i) + ($11<<2)|0);
        $588 = ($584|0)==(0);
        if ($588) {
         break;
        } else {
         $$04$i = $584;$d$05$i = $586;$s$06$i = $587;
        }
       }
      }
     } else {
      break;
     }
    }
   }
  } while(0);
  $exitcond = ($y$0309|0)==($2|0);
  if ($exitcond) {
   break;
  }
  $592 = (($s$0310) + ($6)|0);
  $593 = (($d$0311) + ($4)|0);
  $phitmp = (($y$0309) + 1)|0;
  $84 = $356;$d$0311 = $593;$s$0310 = $592;$y$0309 = $phitmp;
 }
 STACKTOP = sp;return;
}
function __Z12COPY_FI_FRGBI4halfS0_EvjjjPvS1_PKvS3_S3_S3_($count,$pitch0,$pitch1,$i0_,$a0_,$r1_,$g1_,$b1_,$a1_) {
 $count = $count|0;
 $pitch0 = $pitch0|0;
 $pitch1 = $pitch1|0;
 $i0_ = $i0_|0;
 $a0_ = $a0_|0;
 $r1_ = $r1_|0;
 $g1_ = $g1_|0;
 $b1_ = $b1_|0;
 $a1_ = $a1_|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $a$0 = Math_fround(0), $a0$0$be = 0, $a0$06 = 0, $a1$010 = 0, $a1$1 = 0, $b$0 = Math_fround(0), $b1$09 = 0, $b1$1 = 0, $g$0 = Math_fround(0), $g1$08 = 0, $g1$1 = 0, $i0$05 = 0, $i0$1 = 0, $phitmp = Math_fround(0), $phitmp3 = Math_fround(0), $phitmp4 = Math_fround(0), $r$0 = Math_fround(0), $r1$07 = 0;
 var $r1$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $$in = $count;$a0$06 = $a0_;$a1$010 = $a1_;$b1$09 = $b1_;$g1$08 = $g1_;$i0$05 = $i0_;$r1$07 = $r1_;
 while(1) {
  $1 = (($$in) + -1)|0;
  $2 = ($r1$07|0)==(0|0);
  if ($2) {
   $r$0 = Math_fround(0.298999994993209838867);$r1$1 = 0;
  } else {
   $3 = HEAP16[$r1$07>>1]|0;
   $4 = $3&65535;
   $5 = (875048 + ($4<<2)|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = (($r1$07) + ($pitch1<<1)|0);
   $phitmp4 = Math_fround($6 * Math_fround(0.298999994993209838867));
   $r$0 = $phitmp4;$r1$1 = $7;
  }
  $8 = ($g1$08|0)==(0|0);
  if ($8) {
   $g$0 = Math_fround(0.587000012397766113281);$g1$1 = 0;
  } else {
   $9 = HEAP16[$g1$08>>1]|0;
   $10 = $9&65535;
   $11 = (875048 + ($10<<2)|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = (($g1$08) + ($pitch1<<1)|0);
   $phitmp3 = Math_fround($12 * Math_fround(0.587000012397766113281));
   $g$0 = $phitmp3;$g1$1 = $13;
  }
  $14 = ($b1$09|0)==(0|0);
  if ($14) {
   $b$0 = Math_fround(0.114000000059604644775);$b1$1 = 0;
  } else {
   $15 = HEAP16[$b1$09>>1]|0;
   $16 = $15&65535;
   $17 = (875048 + ($16<<2)|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = (($b1$09) + ($pitch1<<1)|0);
   $phitmp = Math_fround($18 * Math_fround(0.114000000059604644775));
   $b$0 = $phitmp;$b1$1 = $19;
  }
  $20 = ($a1$010|0)==(0|0);
  if ($20) {
   $a$0 = Math_fround(1.0);$a1$1 = 0;
  } else {
   $21 = HEAP16[$a1$010>>1]|0;
   $22 = $21&65535;
   $23 = (875048 + ($22<<2)|0);
   $24 = Math_fround(HEAPF32[$23>>2]);
   $25 = (($a1$010) + ($pitch1<<1)|0);
   $a$0 = $24;$a1$1 = $25;
  }
  $26 = ($i0$05|0)==(0|0);
  if ($26) {
   $i0$1 = 0;
  } else {
   $27 = Math_fround($g$0 + $b$0);
   $28 = Math_fround($r$0 + $27);
   $29 = $28 == Math_fround(0.0);
   do {
    if ($29) {
     $42 = 0;
    } else {
     $30 = (HEAPF32[tempDoublePtr>>2]=$28,HEAP32[tempDoublePtr>>2]|0);
     $31 = $30 >>> 23;
     $32 = (1137192 + ($31<<1)|0);
     $33 = HEAP16[$32>>1]|0;
     $34 = ($33<<16>>16)==(0);
     if ($34) {
      $41 = (__ZN4half7convertEi($30)|0);
      $42 = $41;
      break;
     } else {
      $35 = $33&65535;
      $36 = $30 & 8388607;
      $37 = (($36) + 4096)|0;
      $38 = $37 >>> 13;
      $39 = (($35) + ($38))|0;
      $40 = $39&65535;
      $42 = $40;
      break;
     }
    }
   } while(0);
   HEAP16[$i0$05>>1] = $42;
   $43 = (($i0$05) + ($pitch0<<1)|0);
   $i0$1 = $43;
  }
  $44 = ($a0$06|0)==(0|0);
  if ($44) {
   $a0$0$be = 0;
  } else {
   $45 = $a$0 == Math_fround(0.0);
   do {
    if ($45) {
     $58 = 0;
    } else {
     $46 = (HEAPF32[tempDoublePtr>>2]=$a$0,HEAP32[tempDoublePtr>>2]|0);
     $47 = $46 >>> 23;
     $48 = (1137192 + ($47<<1)|0);
     $49 = HEAP16[$48>>1]|0;
     $50 = ($49<<16>>16)==(0);
     if ($50) {
      $57 = (__ZN4half7convertEi($46)|0);
      $58 = $57;
      break;
     } else {
      $51 = $49&65535;
      $52 = $46 & 8388607;
      $53 = (($52) + 4096)|0;
      $54 = $53 >>> 13;
      $55 = (($51) + ($54))|0;
      $56 = $55&65535;
      $58 = $56;
      break;
     }
    }
   } while(0);
   HEAP16[$a0$06>>1] = $58;
   $59 = (($a0$06) + ($pitch0<<1)|0);
   $a0$0$be = $59;
  }
  $60 = ($1|0)==(0);
  if ($60) {
   break;
  } else {
   $$in = $1;$a0$06 = $a0$0$be;$a1$010 = $a1$1;$b1$09 = $b1$1;$g1$08 = $g1$1;$i0$05 = $i0$1;$r1$07 = $r1$1;
  }
 }
 STACKTOP = sp;return;
}
function __Z12COPY_FRGB_FII4halfS0_EvjjjPvS1_S1_S1_PKvS3_($count,$pitch0,$pitch1,$r0_,$g0_,$b0_,$a0_,$i1_,$a1_) {
 $count = $count|0;
 $pitch0 = $pitch0|0;
 $pitch1 = $pitch1|0;
 $r0_ = $r0_|0;
 $g0_ = $g0_|0;
 $b0_ = $b0_|0;
 $a0_ = $a0_|0;
 $i1_ = $i1_|0;
 $a1_ = $a1_|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0;
 var $a$0 = Math_fround(0), $a0$0$be = 0, $a0$010 = 0, $a1$012 = 0, $a1$1 = 0, $b0$09 = 0, $b0$1 = 0, $g0$08 = 0, $g0$1 = 0, $i$0 = Math_fround(0), $i1$011 = 0, $i1$1 = 0, $r0$07 = 0, $r0$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $$in = $count;$a0$010 = $a0_;$a1$012 = $a1_;$b0$09 = $b0_;$g0$08 = $g0_;$i1$011 = $i1_;$r0$07 = $r0_;
 while(1) {
  $1 = (($$in) + -1)|0;
  $2 = ($i1$011|0)==(0|0);
  if ($2) {
   $i$0 = Math_fround(1.0);$i1$1 = 0;
  } else {
   $3 = HEAP16[$i1$011>>1]|0;
   $4 = $3&65535;
   $5 = (875048 + ($4<<2)|0);
   $6 = Math_fround(HEAPF32[$5>>2]);
   $7 = (($i1$011) + ($pitch1<<1)|0);
   $i$0 = $6;$i1$1 = $7;
  }
  $8 = ($a1$012|0)==(0|0);
  if ($8) {
   $a$0 = Math_fround(1.0);$a1$1 = 0;
  } else {
   $9 = HEAP16[$a1$012>>1]|0;
   $10 = $9&65535;
   $11 = (875048 + ($10<<2)|0);
   $12 = Math_fround(HEAPF32[$11>>2]);
   $13 = (($a1$012) + ($pitch1<<1)|0);
   $a$0 = $12;$a1$1 = $13;
  }
  $14 = ($r0$07|0)==(0|0);
  if ($14) {
   $r0$1 = 0;
  } else {
   $15 = $i$0 == Math_fround(0.0);
   do {
    if ($15) {
     $28 = 0;
    } else {
     $16 = (HEAPF32[tempDoublePtr>>2]=$i$0,HEAP32[tempDoublePtr>>2]|0);
     $17 = $16 >>> 23;
     $18 = (1137192 + ($17<<1)|0);
     $19 = HEAP16[$18>>1]|0;
     $20 = ($19<<16>>16)==(0);
     if ($20) {
      $27 = (__ZN4half7convertEi($16)|0);
      $28 = $27;
      break;
     } else {
      $21 = $19&65535;
      $22 = $16 & 8388607;
      $23 = (($22) + 4096)|0;
      $24 = $23 >>> 13;
      $25 = (($21) + ($24))|0;
      $26 = $25&65535;
      $28 = $26;
      break;
     }
    }
   } while(0);
   HEAP16[$r0$07>>1] = $28;
   $29 = (($r0$07) + ($pitch0<<1)|0);
   $r0$1 = $29;
  }
  $30 = ($g0$08|0)==(0|0);
  if ($30) {
   $g0$1 = 0;
  } else {
   $31 = $i$0 == Math_fround(0.0);
   do {
    if ($31) {
     $44 = 0;
    } else {
     $32 = (HEAPF32[tempDoublePtr>>2]=$i$0,HEAP32[tempDoublePtr>>2]|0);
     $33 = $32 >>> 23;
     $34 = (1137192 + ($33<<1)|0);
     $35 = HEAP16[$34>>1]|0;
     $36 = ($35<<16>>16)==(0);
     if ($36) {
      $43 = (__ZN4half7convertEi($32)|0);
      $44 = $43;
      break;
     } else {
      $37 = $35&65535;
      $38 = $32 & 8388607;
      $39 = (($38) + 4096)|0;
      $40 = $39 >>> 13;
      $41 = (($37) + ($40))|0;
      $42 = $41&65535;
      $44 = $42;
      break;
     }
    }
   } while(0);
   HEAP16[$g0$08>>1] = $44;
   $45 = (($g0$08) + ($pitch0<<1)|0);
   $g0$1 = $45;
  }
  $46 = ($b0$09|0)==(0|0);
  if ($46) {
   $b0$1 = 0;
  } else {
   $47 = $i$0 == Math_fround(0.0);
   do {
    if ($47) {
     $60 = 0;
    } else {
     $48 = (HEAPF32[tempDoublePtr>>2]=$i$0,HEAP32[tempDoublePtr>>2]|0);
     $49 = $48 >>> 23;
     $50 = (1137192 + ($49<<1)|0);
     $51 = HEAP16[$50>>1]|0;
     $52 = ($51<<16>>16)==(0);
     if ($52) {
      $59 = (__ZN4half7convertEi($48)|0);
      $60 = $59;
      break;
     } else {
      $53 = $51&65535;
      $54 = $48 & 8388607;
      $55 = (($54) + 4096)|0;
      $56 = $55 >>> 13;
      $57 = (($53) + ($56))|0;
      $58 = $57&65535;
      $60 = $58;
      break;
     }
    }
   } while(0);
   HEAP16[$b0$09>>1] = $60;
   $61 = (($b0$09) + ($pitch0<<1)|0);
   $b0$1 = $61;
  }
  $62 = ($a0$010|0)==(0|0);
  if ($62) {
   $a0$0$be = 0;
  } else {
   $63 = $a$0 == Math_fround(0.0);
   do {
    if ($63) {
     $76 = 0;
    } else {
     $64 = (HEAPF32[tempDoublePtr>>2]=$a$0,HEAP32[tempDoublePtr>>2]|0);
     $65 = $64 >>> 23;
     $66 = (1137192 + ($65<<1)|0);
     $67 = HEAP16[$66>>1]|0;
     $68 = ($67<<16>>16)==(0);
     if ($68) {
      $75 = (__ZN4half7convertEi($64)|0);
      $76 = $75;
      break;
     } else {
      $69 = $67&65535;
      $70 = $64 & 8388607;
      $71 = (($70) + 4096)|0;
      $72 = $71 >>> 13;
      $73 = (($69) + ($72))|0;
      $74 = $73&65535;
      $76 = $74;
      break;
     }
    }
   } while(0);
   HEAP16[$a0$010>>1] = $76;
   $77 = (($a0$010) + ($pitch0<<1)|0);
   $a0$0$be = $77;
  }
  $78 = ($1|0)==(0);
  if ($78) {
   break;
  } else {
   $$in = $1;$a0$010 = $a0$0$be;$a1$012 = $a1$1;$b0$09 = $b0$1;$g0$08 = $g0$1;$i1$011 = $i1$1;$r0$07 = $r0$1;
  }
 }
 STACKTOP = sp;return;
}
function __Z12COPY_FI_FRGBI4halffEvjjjPvS1_PKvS3_S3_S3_($count,$pitch0,$pitch1,$i0_,$a0_,$r1_,$g1_,$b1_,$a1_) {
 $count = $count|0;
 $pitch0 = $pitch0|0;
 $pitch1 = $pitch1|0;
 $i0_ = $i0_|0;
 $a0_ = $a0_|0;
 $r1_ = $r1_|0;
 $g1_ = $g1_|0;
 $b1_ = $b1_|0;
 $a1_ = $a1_|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $a$0 = Math_fround(0), $a0$0$be = 0, $a0$06 = 0, $a1$010 = 0, $a1$1 = 0, $b$0 = Math_fround(0), $b1$09 = 0, $b1$1 = 0, $g$0 = Math_fround(0), $g1$08 = 0;
 var $g1$1 = 0, $i0$05 = 0, $i0$1 = 0, $phitmp = Math_fround(0), $phitmp3 = Math_fround(0), $phitmp4 = Math_fround(0), $r$0 = Math_fround(0), $r1$07 = 0, $r1$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $$in = $count;$a0$06 = $a0_;$a1$010 = $a1_;$b1$09 = $b1_;$g1$08 = $g1_;$i0$05 = $i0_;$r1$07 = $r1_;
 while(1) {
  $1 = (($$in) + -1)|0;
  $2 = ($r1$07|0)==(0|0);
  if ($2) {
   $r$0 = Math_fround(0.298999994993209838867);$r1$1 = 0;
  } else {
   $3 = Math_fround(HEAPF32[$r1$07>>2]);
   $4 = (($r1$07) + ($pitch1<<2)|0);
   $phitmp4 = Math_fround($3 * Math_fround(0.298999994993209838867));
   $r$0 = $phitmp4;$r1$1 = $4;
  }
  $5 = ($g1$08|0)==(0|0);
  if ($5) {
   $g$0 = Math_fround(0.587000012397766113281);$g1$1 = 0;
  } else {
   $6 = Math_fround(HEAPF32[$g1$08>>2]);
   $7 = (($g1$08) + ($pitch1<<2)|0);
   $phitmp3 = Math_fround($6 * Math_fround(0.587000012397766113281));
   $g$0 = $phitmp3;$g1$1 = $7;
  }
  $8 = ($b1$09|0)==(0|0);
  if ($8) {
   $b$0 = Math_fround(0.114000000059604644775);$b1$1 = 0;
  } else {
   $9 = Math_fround(HEAPF32[$b1$09>>2]);
   $10 = (($b1$09) + ($pitch1<<2)|0);
   $phitmp = Math_fround($9 * Math_fround(0.114000000059604644775));
   $b$0 = $phitmp;$b1$1 = $10;
  }
  $11 = ($a1$010|0)==(0|0);
  if ($11) {
   $a$0 = Math_fround(1.0);$a1$1 = 0;
  } else {
   $12 = Math_fround(HEAPF32[$a1$010>>2]);
   $13 = (($a1$010) + ($pitch1<<2)|0);
   $a$0 = $12;$a1$1 = $13;
  }
  $14 = ($i0$05|0)==(0|0);
  if ($14) {
   $i0$1 = 0;
  } else {
   $15 = Math_fround($g$0 + $b$0);
   $16 = Math_fround($r$0 + $15);
   $17 = $16 == Math_fround(0.0);
   do {
    if ($17) {
     $30 = 0;
    } else {
     $18 = (HEAPF32[tempDoublePtr>>2]=$16,HEAP32[tempDoublePtr>>2]|0);
     $19 = $18 >>> 23;
     $20 = (1137192 + ($19<<1)|0);
     $21 = HEAP16[$20>>1]|0;
     $22 = ($21<<16>>16)==(0);
     if ($22) {
      $29 = (__ZN4half7convertEi($18)|0);
      $30 = $29;
      break;
     } else {
      $23 = $21&65535;
      $24 = $18 & 8388607;
      $25 = (($24) + 4096)|0;
      $26 = $25 >>> 13;
      $27 = (($23) + ($26))|0;
      $28 = $27&65535;
      $30 = $28;
      break;
     }
    }
   } while(0);
   HEAP16[$i0$05>>1] = $30;
   $31 = (($i0$05) + ($pitch0<<1)|0);
   $i0$1 = $31;
  }
  $32 = ($a0$06|0)==(0|0);
  if ($32) {
   $a0$0$be = 0;
  } else {
   $33 = $a$0 == Math_fround(0.0);
   do {
    if ($33) {
     $46 = 0;
    } else {
     $34 = (HEAPF32[tempDoublePtr>>2]=$a$0,HEAP32[tempDoublePtr>>2]|0);
     $35 = $34 >>> 23;
     $36 = (1137192 + ($35<<1)|0);
     $37 = HEAP16[$36>>1]|0;
     $38 = ($37<<16>>16)==(0);
     if ($38) {
      $45 = (__ZN4half7convertEi($34)|0);
      $46 = $45;
      break;
     } else {
      $39 = $37&65535;
      $40 = $34 & 8388607;
      $41 = (($40) + 4096)|0;
      $42 = $41 >>> 13;
      $43 = (($39) + ($42))|0;
      $44 = $43&65535;
      $46 = $44;
      break;
     }
    }
   } while(0);
   HEAP16[$a0$06>>1] = $46;
   $47 = (($a0$06) + ($pitch0<<1)|0);
   $a0$0$be = $47;
  }
  $48 = ($1|0)==(0);
  if ($48) {
   break;
  } else {
   $$in = $1;$a0$06 = $a0$0$be;$a1$010 = $a1$1;$b1$09 = $b1$1;$g1$08 = $g1$1;$i0$05 = $i0$1;$r1$07 = $r1$1;
  }
 }
 STACKTOP = sp;return;
}
function __Z12COPY_FRGB_FII4halffEvjjjPvS1_S1_S1_PKvS3_($count,$pitch0,$pitch1,$r0_,$g0_,$b0_,$a0_,$i1_,$a1_) {
 $count = $count|0;
 $pitch0 = $pitch0|0;
 $pitch1 = $pitch1|0;
 $r0_ = $r0_|0;
 $g0_ = $g0_|0;
 $b0_ = $b0_|0;
 $a0_ = $a0_|0;
 $i1_ = $i1_|0;
 $a1_ = $a1_|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $a$0 = Math_fround(0), $a0$0$be = 0, $a0$010 = 0, $a1$012 = 0, $a1$1 = 0, $b0$09 = 0;
 var $b0$1 = 0, $g0$08 = 0, $g0$1 = 0, $i$0 = Math_fround(0), $i1$011 = 0, $i1$1 = 0, $r0$07 = 0, $r0$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $$in = $count;$a0$010 = $a0_;$a1$012 = $a1_;$b0$09 = $b0_;$g0$08 = $g0_;$i1$011 = $i1_;$r0$07 = $r0_;
 while(1) {
  $1 = (($$in) + -1)|0;
  $2 = ($i1$011|0)==(0|0);
  if ($2) {
   $i$0 = Math_fround(1.0);$i1$1 = 0;
  } else {
   $3 = Math_fround(HEAPF32[$i1$011>>2]);
   $4 = (($i1$011) + ($pitch1<<2)|0);
   $i$0 = $3;$i1$1 = $4;
  }
  $5 = ($a1$012|0)==(0|0);
  if ($5) {
   $a$0 = Math_fround(1.0);$a1$1 = 0;
  } else {
   $6 = Math_fround(HEAPF32[$a1$012>>2]);
   $7 = (($a1$012) + ($pitch1<<2)|0);
   $a$0 = $6;$a1$1 = $7;
  }
  $8 = ($r0$07|0)==(0|0);
  if ($8) {
   $r0$1 = 0;
  } else {
   $9 = $i$0 == Math_fround(0.0);
   do {
    if ($9) {
     $22 = 0;
    } else {
     $10 = (HEAPF32[tempDoublePtr>>2]=$i$0,HEAP32[tempDoublePtr>>2]|0);
     $11 = $10 >>> 23;
     $12 = (1137192 + ($11<<1)|0);
     $13 = HEAP16[$12>>1]|0;
     $14 = ($13<<16>>16)==(0);
     if ($14) {
      $21 = (__ZN4half7convertEi($10)|0);
      $22 = $21;
      break;
     } else {
      $15 = $13&65535;
      $16 = $10 & 8388607;
      $17 = (($16) + 4096)|0;
      $18 = $17 >>> 13;
      $19 = (($15) + ($18))|0;
      $20 = $19&65535;
      $22 = $20;
      break;
     }
    }
   } while(0);
   HEAP16[$r0$07>>1] = $22;
   $23 = (($r0$07) + ($pitch0<<1)|0);
   $r0$1 = $23;
  }
  $24 = ($g0$08|0)==(0|0);
  if ($24) {
   $g0$1 = 0;
  } else {
   $25 = $i$0 == Math_fround(0.0);
   do {
    if ($25) {
     $38 = 0;
    } else {
     $26 = (HEAPF32[tempDoublePtr>>2]=$i$0,HEAP32[tempDoublePtr>>2]|0);
     $27 = $26 >>> 23;
     $28 = (1137192 + ($27<<1)|0);
     $29 = HEAP16[$28>>1]|0;
     $30 = ($29<<16>>16)==(0);
     if ($30) {
      $37 = (__ZN4half7convertEi($26)|0);
      $38 = $37;
      break;
     } else {
      $31 = $29&65535;
      $32 = $26 & 8388607;
      $33 = (($32) + 4096)|0;
      $34 = $33 >>> 13;
      $35 = (($31) + ($34))|0;
      $36 = $35&65535;
      $38 = $36;
      break;
     }
    }
   } while(0);
   HEAP16[$g0$08>>1] = $38;
   $39 = (($g0$08) + ($pitch0<<1)|0);
   $g0$1 = $39;
  }
  $40 = ($b0$09|0)==(0|0);
  if ($40) {
   $b0$1 = 0;
  } else {
   $41 = $i$0 == Math_fround(0.0);
   do {
    if ($41) {
     $54 = 0;
    } else {
     $42 = (HEAPF32[tempDoublePtr>>2]=$i$0,HEAP32[tempDoublePtr>>2]|0);
     $43 = $42 >>> 23;
     $44 = (1137192 + ($43<<1)|0);
     $45 = HEAP16[$44>>1]|0;
     $46 = ($45<<16>>16)==(0);
     if ($46) {
      $53 = (__ZN4half7convertEi($42)|0);
      $54 = $53;
      break;
     } else {
      $47 = $45&65535;
      $48 = $42 & 8388607;
      $49 = (($48) + 4096)|0;
      $50 = $49 >>> 13;
      $51 = (($47) + ($50))|0;
      $52 = $51&65535;
      $54 = $52;
      break;
     }
    }
   } while(0);
   HEAP16[$b0$09>>1] = $54;
   $55 = (($b0$09) + ($pitch0<<1)|0);
   $b0$1 = $55;
  }
  $56 = ($a0$010|0)==(0|0);
  if ($56) {
   $a0$0$be = 0;
  } else {
   $57 = $a$0 == Math_fround(0.0);
   do {
    if ($57) {
     $70 = 0;
    } else {
     $58 = (HEAPF32[tempDoublePtr>>2]=$a$0,HEAP32[tempDoublePtr>>2]|0);
     $59 = $58 >>> 23;
     $60 = (1137192 + ($59<<1)|0);
     $61 = HEAP16[$60>>1]|0;
     $62 = ($61<<16>>16)==(0);
     if ($62) {
      $69 = (__ZN4half7convertEi($58)|0);
      $70 = $69;
      break;
     } else {
      $63 = $61&65535;
      $64 = $58 & 8388607;
      $65 = (($64) + 4096)|0;
      $66 = $65 >>> 13;
      $67 = (($63) + ($66))|0;
      $68 = $67&65535;
      $70 = $68;
      break;
     }
    }
   } while(0);
   HEAP16[$a0$010>>1] = $70;
   $71 = (($a0$010) + ($pitch0<<1)|0);
   $a0$0$be = $71;
  }
  $72 = ($1|0)==(0);
  if ($72) {
   break;
  } else {
   $$in = $1;$a0$010 = $a0$0$be;$a1$012 = $a1$1;$b0$09 = $b0$1;$g0$08 = $g0$1;$i1$011 = $i1$1;$r0$07 = $r0$1;
  }
 }
 STACKTOP = sp;return;
}
function __ZL18BlitFloatToIntegerI4halfEvRN6prcore7SurfaceERKS2_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$op = Math_fround(0), $$op11 = Math_fround(0), $$op15 = Math_fround(0), $$op7 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = Math_fround(0), $161 = Math_fround(0), $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a0$031 = 0, $a0$1 = 0, $a06$021 = 0, $a06$1 = 0, $a1$036 = 0, $a1$1 = 0, $a19$023 = 0, $a19$1 = 0, $b0$030 = 0, $b0$1 = 0;
 var $b05$020 = 0, $b05$1 = 0, $b1$035 = 0, $b1$1 = 0, $b18$022 = 0, $b18$1 = 0, $d$045 = 0, $d$127 = 0, $exitcond = 0, $exitcond47 = 0, $exitcond48 = 0, $exitcond49 = 0, $g0$029 = 0, $g0$1 = 0, $g04$019 = 0, $g04$1 = 0, $g1$034 = 0, $g1$1 = 0, $or$cond = 0, $phitmp = Math_fround(0);
 var $phitmp10 = Math_fround(0), $phitmp12 = Math_fround(0), $phitmp13 = 0, $phitmp14 = Math_fround(0), $phitmp16 = Math_fround(0), $phitmp17 = 0, $phitmp4 = Math_fround(0), $phitmp5 = 0, $phitmp6 = Math_fround(0), $phitmp8 = Math_fround(0), $phitmp9 = 0, $r0$032 = 0, $r0$1 = 0, $r03$018 = 0, $r03$1 = 0, $r1$033 = 0, $r1$1 = 0, $s$044 = 0, $s$126 = 0, $x$037 = 0;
 var $x10$024 = 0, $y$043 = 0, $y1$025 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($dest) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($source) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$dest>>2]|0;
 $5 = (($dest) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($dest) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($source) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$source>>2]|0;
 $12 = (($10>>>0) / ($11>>>0))&-1;
 $13 = $12 >>> 1;
 $14 = (($dest) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 >>> 3;
 $17 = $16 & 8191;
 $18 = (($dest) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)!=(0);
 $21 = (($dest) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)!=(0);
 $24 = (($dest) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)!=(0);
 $27 = (($dest) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)!=(0);
 $30 = (($source) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0);
 $33 = (($source) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 $36 = (($source) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)!=(0);
 $39 = (($source) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)!=(0);
 $42 = (($source) + 12|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 & 268435456;
 $45 = ($44|0)==(0);
 if ($45) {
  $124 = $43 & 134217728;
  $125 = ($124|0)==(0);
  $126 = ($6|0)==(0);
  $or$cond = $125 | $126;
  if ($or$cond) {
   STACKTOP = sp;return;
  }
  $127 = (($dest) + 38|0);
  $128 = (($dest) + 37|0);
  $129 = (($dest) + 36|0);
  $130 = (($dest) + 39|0);
  $131 = (($source) + 36|0);
  $132 = (($source) + 39|0);
  $133 = ($4|0)==(0);
  $d$127 = $1;$s$126 = $3;$y1$025 = 0;
  while(1) {
   if (!($133)) {
    $134 = HEAP8[$130>>0]|0;
    $135 = HEAP8[$129>>0]|0;
    $136 = HEAP8[$128>>0]|0;
    $137 = HEAP8[$127>>0]|0;
    $138 = HEAP8[$132>>0]|0;
    $139 = HEAP8[$131>>0]|0;
    $140 = $134&255;
    $141 = $135&255;
    $142 = $136&255;
    $143 = $137&255;
    $144 = $138&255;
    $145 = $139&255;
    $146 = $140 >>> 3;
    $147 = $141 >>> 3;
    $148 = $142 >>> 3;
    $149 = $143 >>> 3;
    $150 = (($s$126) + ($144<<1)|0);
    $151 = (($s$126) + ($145<<1)|0);
    $152 = (($d$127) + ($146)|0);
    $153 = (($d$127) + ($147)|0);
    $154 = (($d$127) + ($148)|0);
    $155 = (($d$127) + ($149)|0);
    $a06$021 = $152;$a19$023 = $150;$b05$020 = $153;$b18$022 = $151;$g04$019 = $154;$r03$018 = $155;$x10$024 = 0;
    while(1) {
     if ($38) {
      $156 = HEAP16[$b18$022>>1]|0;
      $157 = $156&65535;
      $158 = (875048 + ($157<<2)|0);
      $159 = Math_fround(HEAPF32[$158>>2]);
      $160 = Math_fround($159 * Math_fround(255.0));
      $161 = Math_fround($160 + Math_fround(0.5));
      $162 = (~~(($161))&255);
      $163 = (($b18$022) + ($13<<1)|0);
      $172 = $162;$b18$1 = $163;
     } else {
      $172 = -1;$b18$1 = $b18$022;
     }
     if ($41) {
      $164 = HEAP16[$a19$023>>1]|0;
      $165 = $164&65535;
      $166 = (875048 + ($165<<2)|0);
      $167 = Math_fround(HEAPF32[$166>>2]);
      $168 = Math_fround($167 * Math_fround(255.0));
      $169 = Math_fround($168 + Math_fround(0.5));
      $170 = (~~(($169))&255);
      $171 = (($a19$023) + ($13<<1)|0);
      $176 = $170;$a19$1 = $171;
     } else {
      $176 = -1;$a19$1 = $a19$023;
     }
     if ($20) {
      HEAP8[$r03$018>>0] = $172;
      $173 = (($r03$018) + ($17)|0);
      $r03$1 = $173;
     } else {
      $r03$1 = $r03$018;
     }
     if ($23) {
      HEAP8[$g04$019>>0] = $172;
      $174 = (($g04$019) + ($17)|0);
      $g04$1 = $174;
     } else {
      $g04$1 = $g04$019;
     }
     if ($26) {
      HEAP8[$b05$020>>0] = $172;
      $175 = (($b05$020) + ($17)|0);
      $b05$1 = $175;
     } else {
      $b05$1 = $b05$020;
     }
     if ($29) {
      HEAP8[$a06$021>>0] = $176;
      $177 = (($a06$021) + ($17)|0);
      $a06$1 = $177;
     } else {
      $a06$1 = $a06$021;
     }
     $178 = (($x10$024) + 1)|0;
     $exitcond = ($178|0)==($4|0);
     if ($exitcond) {
      break;
     } else {
      $a06$021 = $a06$1;$a19$023 = $a19$1;$b05$020 = $b05$1;$b18$022 = $b18$1;$g04$019 = $g04$1;$r03$018 = $r03$1;$x10$024 = $178;
     }
    }
   }
   $179 = (($d$127) + ($8)|0);
   $180 = (($s$126) + ($10)|0);
   $181 = (($y1$025) + 1)|0;
   $exitcond47 = ($181|0)==($6|0);
   if ($exitcond47) {
    break;
   } else {
    $d$127 = $179;$s$126 = $180;$y1$025 = $181;
   }
  }
  STACKTOP = sp;return;
 }
 $46 = ($6|0)==(0);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = (($dest) + 38|0);
 $48 = (($dest) + 37|0);
 $49 = (($dest) + 36|0);
 $50 = (($dest) + 39|0);
 $51 = (($source) + 38|0);
 $52 = (($source) + 37|0);
 $53 = (($source) + 36|0);
 $54 = (($source) + 39|0);
 $55 = ($4|0)==(0);
 $d$045 = $1;$s$044 = $3;$y$043 = 0;
 while(1) {
  if (!($55)) {
   $56 = HEAP8[$50>>0]|0;
   $57 = HEAP8[$49>>0]|0;
   $58 = HEAP8[$48>>0]|0;
   $59 = HEAP8[$47>>0]|0;
   $60 = HEAP8[$54>>0]|0;
   $61 = HEAP8[$53>>0]|0;
   $62 = HEAP8[$52>>0]|0;
   $63 = HEAP8[$51>>0]|0;
   $64 = $56&255;
   $65 = $57&255;
   $66 = $58&255;
   $67 = $59&255;
   $68 = $60&255;
   $69 = $61&255;
   $70 = $62&255;
   $71 = $63&255;
   $72 = $64 >>> 3;
   $73 = $65 >>> 3;
   $74 = $66 >>> 3;
   $75 = $67 >>> 3;
   $76 = (($s$044) + ($68<<1)|0);
   $77 = (($s$044) + ($69<<1)|0);
   $78 = (($s$044) + ($70<<1)|0);
   $79 = (($s$044) + ($71<<1)|0);
   $80 = (($d$045) + ($72)|0);
   $81 = (($d$045) + ($73)|0);
   $82 = (($d$045) + ($74)|0);
   $83 = (($d$045) + ($75)|0);
   $a0$031 = $80;$a1$036 = $76;$b0$030 = $81;$b1$035 = $77;$g0$029 = $82;$g1$034 = $78;$r0$032 = $83;$r1$033 = $79;$x$037 = 0;
   while(1) {
    if ($32) {
     $112 = -1;$r1$1 = $r1$033;
    } else {
     $84 = HEAP16[$r1$033>>1]|0;
     $85 = $84&65535;
     $86 = (875048 + ($85<<2)|0);
     $87 = Math_fround(HEAPF32[$86>>2]);
     $88 = $87 < Math_fround(0.0);
     if ($88) {
      $182 = 0;
     } else {
      $89 = $87 > Math_fround(1.0);
      $$op = Math_fround($87 * Math_fround(255.0));
      $phitmp = $89 ? Math_fround(255.0) : $$op;
      $phitmp4 = Math_fround($phitmp + Math_fround(0.5));
      $phitmp5 = (~~(($phitmp4))&255);
      $182 = $phitmp5;
     }
     $90 = (($r1$033) + ($13<<1)|0);
     $112 = $182;$r1$1 = $90;
    }
    if ($35) {
     $114 = -1;$g1$1 = $g1$034;
    } else {
     $91 = HEAP16[$g1$034>>1]|0;
     $92 = $91&65535;
     $93 = (875048 + ($92<<2)|0);
     $94 = Math_fround(HEAPF32[$93>>2]);
     $95 = $94 < Math_fround(0.0);
     if ($95) {
      $183 = 0;
     } else {
      $96 = $94 > Math_fround(1.0);
      $$op7 = Math_fround($94 * Math_fround(255.0));
      $phitmp6 = $96 ? Math_fround(255.0) : $$op7;
      $phitmp8 = Math_fround($phitmp6 + Math_fround(0.5));
      $phitmp9 = (~~(($phitmp8))&255);
      $183 = $phitmp9;
     }
     $97 = (($g1$034) + ($13<<1)|0);
     $114 = $183;$g1$1 = $97;
    }
    if ($38) {
     $98 = HEAP16[$b1$035>>1]|0;
     $99 = $98&65535;
     $100 = (875048 + ($99<<2)|0);
     $101 = Math_fround(HEAPF32[$100>>2]);
     $102 = $101 < Math_fround(0.0);
     if ($102) {
      $184 = 0;
     } else {
      $103 = $101 > Math_fround(1.0);
      $$op15 = Math_fround($101 * Math_fround(255.0));
      $phitmp14 = $103 ? Math_fround(255.0) : $$op15;
      $phitmp16 = Math_fround($phitmp14 + Math_fround(0.5));
      $phitmp17 = (~~(($phitmp16))&255);
      $184 = $phitmp17;
     }
     $104 = (($b1$035) + ($13<<1)|0);
     $116 = $184;$b1$1 = $104;
    } else {
     $116 = -1;$b1$1 = $b1$035;
    }
    if ($41) {
     $105 = HEAP16[$a1$036>>1]|0;
     $106 = $105&65535;
     $107 = (875048 + ($106<<2)|0);
     $108 = Math_fround(HEAPF32[$107>>2]);
     $109 = $108 < Math_fround(0.0);
     if ($109) {
      $185 = 0;
     } else {
      $110 = $108 > Math_fround(1.0);
      $$op11 = Math_fround($108 * Math_fround(255.0));
      $phitmp10 = $110 ? Math_fround(255.0) : $$op11;
      $phitmp12 = Math_fround($phitmp10 + Math_fround(0.5));
      $phitmp13 = (~~(($phitmp12))&255);
      $185 = $phitmp13;
     }
     $111 = (($a1$036) + ($13<<1)|0);
     $118 = $185;$a1$1 = $111;
    } else {
     $118 = -1;$a1$1 = $a1$036;
    }
    if ($20) {
     HEAP8[$r0$032>>0] = $112;
     $113 = (($r0$032) + ($17)|0);
     $r0$1 = $113;
    } else {
     $r0$1 = $r0$032;
    }
    if ($23) {
     HEAP8[$g0$029>>0] = $114;
     $115 = (($g0$029) + ($17)|0);
     $g0$1 = $115;
    } else {
     $g0$1 = $g0$029;
    }
    if ($26) {
     HEAP8[$b0$030>>0] = $116;
     $117 = (($b0$030) + ($17)|0);
     $b0$1 = $117;
    } else {
     $b0$1 = $b0$030;
    }
    if ($29) {
     HEAP8[$a0$031>>0] = $118;
     $119 = (($a0$031) + ($17)|0);
     $a0$1 = $119;
    } else {
     $a0$1 = $a0$031;
    }
    $120 = (($x$037) + 1)|0;
    $exitcond48 = ($120|0)==($4|0);
    if ($exitcond48) {
     break;
    } else {
     $a0$031 = $a0$1;$a1$036 = $a1$1;$b0$030 = $b0$1;$b1$035 = $b1$1;$g0$029 = $g0$1;$g1$034 = $g1$1;$r0$032 = $r0$1;$r1$033 = $r1$1;$x$037 = $120;
    }
   }
  }
  $121 = (($d$045) + ($8)|0);
  $122 = (($s$044) + ($10)|0);
  $123 = (($y$043) + 1)|0;
  $exitcond49 = ($123|0)==($6|0);
  if ($exitcond49) {
   break;
  } else {
   $d$045 = $121;$s$044 = $122;$y$043 = $123;
  }
 }
 STACKTOP = sp;return;
}
function __ZL18BlitFloatToIntegerIfEvRN6prcore7SurfaceERKS1_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $$op = Math_fround(0), $$op11 = Math_fround(0), $$op15 = Math_fround(0), $$op7 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0;
 var $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0), $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0);
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $a0$031 = 0, $a0$1 = 0, $a06$021 = 0, $a06$1 = 0, $a1$036 = 0, $a1$1 = 0, $a19$023 = 0, $a19$1 = 0;
 var $b0$030 = 0, $b0$1 = 0, $b05$020 = 0, $b05$1 = 0, $b1$035 = 0, $b1$1 = 0, $b18$022 = 0, $b18$1 = 0, $d$045 = 0, $d$127 = 0, $exitcond = 0, $exitcond47 = 0, $exitcond48 = 0, $exitcond49 = 0, $g0$029 = 0, $g0$1 = 0, $g04$019 = 0, $g04$1 = 0, $g1$034 = 0, $g1$1 = 0;
 var $or$cond = 0, $phitmp = Math_fround(0), $phitmp10 = Math_fround(0), $phitmp12 = Math_fround(0), $phitmp13 = 0, $phitmp14 = Math_fround(0), $phitmp16 = Math_fround(0), $phitmp17 = 0, $phitmp4 = Math_fround(0), $phitmp5 = 0, $phitmp6 = Math_fround(0), $phitmp8 = Math_fround(0), $phitmp9 = 0, $r0$032 = 0, $r0$1 = 0, $r03$018 = 0, $r03$1 = 0, $r1$033 = 0, $r1$1 = 0, $s$044 = 0;
 var $s$126 = 0, $x$037 = 0, $x10$024 = 0, $y$043 = 0, $y1$025 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($dest) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($source) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$dest>>2]|0;
 $5 = (($dest) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($dest) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($source) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$source>>2]|0;
 $12 = (($10>>>0) / ($11>>>0))&-1;
 $13 = $12 >>> 2;
 $14 = (($dest) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 >>> 3;
 $17 = $16 & 8191;
 $18 = (($dest) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)!=(0);
 $21 = (($dest) + 20|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)!=(0);
 $24 = (($dest) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)!=(0);
 $27 = (($dest) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)!=(0);
 $30 = (($source) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0);
 $33 = (($source) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0);
 $36 = (($source) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)!=(0);
 $39 = (($source) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)!=(0);
 $42 = (($source) + 12|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 & 268435456;
 $45 = ($44|0)==(0);
 if ($45) {
  $112 = $43 & 134217728;
  $113 = ($112|0)==(0);
  $114 = ($6|0)==(0);
  $or$cond = $113 | $114;
  if ($or$cond) {
   STACKTOP = sp;return;
  }
  $115 = (($dest) + 38|0);
  $116 = (($dest) + 37|0);
  $117 = (($dest) + 36|0);
  $118 = (($dest) + 39|0);
  $119 = (($source) + 36|0);
  $120 = (($source) + 39|0);
  $121 = ($4|0)==(0);
  $d$127 = $1;$s$126 = $3;$y1$025 = 0;
  while(1) {
   if (!($121)) {
    $122 = HEAP8[$118>>0]|0;
    $123 = HEAP8[$117>>0]|0;
    $124 = HEAP8[$116>>0]|0;
    $125 = HEAP8[$115>>0]|0;
    $126 = HEAP8[$120>>0]|0;
    $127 = HEAP8[$119>>0]|0;
    $128 = $122&255;
    $129 = $123&255;
    $130 = $124&255;
    $131 = $125&255;
    $132 = $126&255;
    $133 = $127&255;
    $134 = $128 >>> 3;
    $135 = $129 >>> 3;
    $136 = $130 >>> 3;
    $137 = $131 >>> 3;
    $138 = (($s$126) + ($132<<2)|0);
    $139 = (($s$126) + ($133<<2)|0);
    $140 = (($d$127) + ($134)|0);
    $141 = (($d$127) + ($135)|0);
    $142 = (($d$127) + ($136)|0);
    $143 = (($d$127) + ($137)|0);
    $a06$021 = $140;$a19$023 = $138;$b05$020 = $141;$b18$022 = $139;$g04$019 = $142;$r03$018 = $143;$x10$024 = 0;
    while(1) {
     if ($38) {
      $144 = Math_fround(HEAPF32[$b18$022>>2]);
      $145 = Math_fround($144 * Math_fround(255.0));
      $146 = Math_fround($145 + Math_fround(0.5));
      $147 = (~~(($146))&255);
      $148 = (($b18$022) + ($13<<2)|0);
      $154 = $147;$b18$1 = $148;
     } else {
      $154 = -1;$b18$1 = $b18$022;
     }
     if ($41) {
      $149 = Math_fround(HEAPF32[$a19$023>>2]);
      $150 = Math_fround($149 * Math_fround(255.0));
      $151 = Math_fround($150 + Math_fround(0.5));
      $152 = (~~(($151))&255);
      $153 = (($a19$023) + ($13<<2)|0);
      $158 = $152;$a19$1 = $153;
     } else {
      $158 = -1;$a19$1 = $a19$023;
     }
     if ($20) {
      HEAP8[$r03$018>>0] = $154;
      $155 = (($r03$018) + ($17)|0);
      $r03$1 = $155;
     } else {
      $r03$1 = $r03$018;
     }
     if ($23) {
      HEAP8[$g04$019>>0] = $154;
      $156 = (($g04$019) + ($17)|0);
      $g04$1 = $156;
     } else {
      $g04$1 = $g04$019;
     }
     if ($26) {
      HEAP8[$b05$020>>0] = $154;
      $157 = (($b05$020) + ($17)|0);
      $b05$1 = $157;
     } else {
      $b05$1 = $b05$020;
     }
     if ($29) {
      HEAP8[$a06$021>>0] = $158;
      $159 = (($a06$021) + ($17)|0);
      $a06$1 = $159;
     } else {
      $a06$1 = $a06$021;
     }
     $160 = (($x10$024) + 1)|0;
     $exitcond = ($160|0)==($4|0);
     if ($exitcond) {
      break;
     } else {
      $a06$021 = $a06$1;$a19$023 = $a19$1;$b05$020 = $b05$1;$b18$022 = $b18$1;$g04$019 = $g04$1;$r03$018 = $r03$1;$x10$024 = $160;
     }
    }
   }
   $161 = (($d$127) + ($8)|0);
   $162 = (($s$126) + ($10)|0);
   $163 = (($y1$025) + 1)|0;
   $exitcond47 = ($163|0)==($6|0);
   if ($exitcond47) {
    break;
   } else {
    $d$127 = $161;$s$126 = $162;$y1$025 = $163;
   }
  }
  STACKTOP = sp;return;
 }
 $46 = ($6|0)==(0);
 if ($46) {
  STACKTOP = sp;return;
 }
 $47 = (($dest) + 38|0);
 $48 = (($dest) + 37|0);
 $49 = (($dest) + 36|0);
 $50 = (($dest) + 39|0);
 $51 = (($source) + 38|0);
 $52 = (($source) + 37|0);
 $53 = (($source) + 36|0);
 $54 = (($source) + 39|0);
 $55 = ($4|0)==(0);
 $d$045 = $1;$s$044 = $3;$y$043 = 0;
 while(1) {
  if (!($55)) {
   $56 = HEAP8[$50>>0]|0;
   $57 = HEAP8[$49>>0]|0;
   $58 = HEAP8[$48>>0]|0;
   $59 = HEAP8[$47>>0]|0;
   $60 = HEAP8[$54>>0]|0;
   $61 = HEAP8[$53>>0]|0;
   $62 = HEAP8[$52>>0]|0;
   $63 = HEAP8[$51>>0]|0;
   $64 = $56&255;
   $65 = $57&255;
   $66 = $58&255;
   $67 = $59&255;
   $68 = $60&255;
   $69 = $61&255;
   $70 = $62&255;
   $71 = $63&255;
   $72 = $64 >>> 3;
   $73 = $65 >>> 3;
   $74 = $66 >>> 3;
   $75 = $67 >>> 3;
   $76 = (($s$044) + ($68<<2)|0);
   $77 = (($s$044) + ($69<<2)|0);
   $78 = (($s$044) + ($70<<2)|0);
   $79 = (($s$044) + ($71<<2)|0);
   $80 = (($d$045) + ($72)|0);
   $81 = (($d$045) + ($73)|0);
   $82 = (($d$045) + ($74)|0);
   $83 = (($d$045) + ($75)|0);
   $a0$031 = $80;$a1$036 = $76;$b0$030 = $81;$b1$035 = $77;$g0$029 = $82;$g1$034 = $78;$r0$032 = $83;$r1$033 = $79;$x$037 = 0;
   while(1) {
    if ($32) {
     $100 = -1;$r1$1 = $r1$033;
    } else {
     $84 = Math_fround(HEAPF32[$r1$033>>2]);
     $85 = $84 < Math_fround(0.0);
     if ($85) {
      $164 = 0;
     } else {
      $86 = $84 > Math_fround(1.0);
      $$op = Math_fround($84 * Math_fround(255.0));
      $phitmp = $86 ? Math_fround(255.0) : $$op;
      $phitmp4 = Math_fround($phitmp + Math_fround(0.5));
      $phitmp5 = (~~(($phitmp4))&255);
      $164 = $phitmp5;
     }
     $87 = (($r1$033) + ($13<<2)|0);
     $100 = $164;$r1$1 = $87;
    }
    if ($35) {
     $102 = -1;$g1$1 = $g1$034;
    } else {
     $88 = Math_fround(HEAPF32[$g1$034>>2]);
     $89 = $88 < Math_fround(0.0);
     if ($89) {
      $165 = 0;
     } else {
      $90 = $88 > Math_fround(1.0);
      $$op7 = Math_fround($88 * Math_fround(255.0));
      $phitmp6 = $90 ? Math_fround(255.0) : $$op7;
      $phitmp8 = Math_fround($phitmp6 + Math_fround(0.5));
      $phitmp9 = (~~(($phitmp8))&255);
      $165 = $phitmp9;
     }
     $91 = (($g1$034) + ($13<<2)|0);
     $102 = $165;$g1$1 = $91;
    }
    if ($38) {
     $92 = Math_fround(HEAPF32[$b1$035>>2]);
     $93 = $92 < Math_fround(0.0);
     if ($93) {
      $166 = 0;
     } else {
      $94 = $92 > Math_fround(1.0);
      $$op15 = Math_fround($92 * Math_fround(255.0));
      $phitmp14 = $94 ? Math_fround(255.0) : $$op15;
      $phitmp16 = Math_fround($phitmp14 + Math_fround(0.5));
      $phitmp17 = (~~(($phitmp16))&255);
      $166 = $phitmp17;
     }
     $95 = (($b1$035) + ($13<<2)|0);
     $104 = $166;$b1$1 = $95;
    } else {
     $104 = -1;$b1$1 = $b1$035;
    }
    if ($41) {
     $96 = Math_fround(HEAPF32[$a1$036>>2]);
     $97 = $96 < Math_fround(0.0);
     if ($97) {
      $167 = 0;
     } else {
      $98 = $96 > Math_fround(1.0);
      $$op11 = Math_fround($96 * Math_fround(255.0));
      $phitmp10 = $98 ? Math_fround(255.0) : $$op11;
      $phitmp12 = Math_fround($phitmp10 + Math_fround(0.5));
      $phitmp13 = (~~(($phitmp12))&255);
      $167 = $phitmp13;
     }
     $99 = (($a1$036) + ($13<<2)|0);
     $106 = $167;$a1$1 = $99;
    } else {
     $106 = -1;$a1$1 = $a1$036;
    }
    if ($20) {
     HEAP8[$r0$032>>0] = $100;
     $101 = (($r0$032) + ($17)|0);
     $r0$1 = $101;
    } else {
     $r0$1 = $r0$032;
    }
    if ($23) {
     HEAP8[$g0$029>>0] = $102;
     $103 = (($g0$029) + ($17)|0);
     $g0$1 = $103;
    } else {
     $g0$1 = $g0$029;
    }
    if ($26) {
     HEAP8[$b0$030>>0] = $104;
     $105 = (($b0$030) + ($17)|0);
     $b0$1 = $105;
    } else {
     $b0$1 = $b0$030;
    }
    if ($29) {
     HEAP8[$a0$031>>0] = $106;
     $107 = (($a0$031) + ($17)|0);
     $a0$1 = $107;
    } else {
     $a0$1 = $a0$031;
    }
    $108 = (($x$037) + 1)|0;
    $exitcond48 = ($108|0)==($4|0);
    if ($exitcond48) {
     break;
    } else {
     $a0$031 = $a0$1;$a1$036 = $a1$1;$b0$030 = $b0$1;$b1$035 = $b1$1;$g0$029 = $g0$1;$g1$034 = $g1$1;$r0$032 = $r0$1;$r1$033 = $r1$1;$x$037 = $108;
    }
   }
  }
  $109 = (($d$045) + ($8)|0);
  $110 = (($s$044) + ($10)|0);
  $111 = (($y$043) + 1)|0;
  $exitcond49 = ($111|0)==($6|0);
  if ($exitcond49) {
   break;
  } else {
   $d$045 = $109;$s$044 = $110;$y$043 = $111;
  }
 }
 STACKTOP = sp;return;
}
function __ZL18BlitIntegerToFloatIfEvRN6prcore7SurfaceERKS1_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = Math_fround(0), $162 = Math_fround(0), $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = Math_fround(0), $167 = Math_fround(0), $168 = Math_fround(0), $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = Math_fround(0), $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0;
 var $98 = Math_fround(0), $99 = Math_fround(0), $a0$019 = 0, $a0$1 = 0, $a08$06 = 0, $a08$1 = 0, $a1$015 = 0, $a1$1 = 0, $a15$04 = 0, $a15$1 = 0, $b0$018 = 0, $b0$1 = 0, $b07$05 = 0, $b07$1 = 0, $b1$014 = 0, $b1$1 = 0, $b14$03 = 0, $b14$1 = 0, $d$028 = 0, $d$110 = 0;
 var $exitcond = 0, $exitcond30 = 0, $exitcond31 = 0, $exitcond32 = 0, $g0$017 = 0, $g0$1 = 0, $g1$013 = 0, $g1$1 = 0, $g13$02 = 0, $g13$1 = 0, $or$cond = 0, $r0$016 = 0, $r0$1 = 0, $r1$012 = 0, $r1$1 = 0, $r12$01 = 0, $r12$1 = 0, $s$027 = 0, $s$18 = 0, $x$020 = 0;
 var $x9$07 = 0, $y$026 = 0, $y1$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($dest) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($source) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$dest>>2]|0;
 $5 = (($dest) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($dest) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($source) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8>>>0) / ($4>>>0))&-1;
 $12 = $11 >>> 2;
 $13 = (($source) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 >>> 3;
 $16 = $15 & 8191;
 $17 = (($dest) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 $20 = (($dest) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 $23 = (($dest) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)!=(0);
 $26 = (($dest) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)!=(0);
 $29 = (($source) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)!=(0);
 $32 = (($source) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)!=(0);
 $35 = (($source) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)!=(0);
 $38 = (($source) + 28|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)!=(0);
 $41 = (($dest) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 & 268435456;
 $44 = ($43|0)==(0);
 if ($44) {
  $115 = $42 & 134217728;
  $116 = ($115|0)==(0);
  $117 = ($6|0)==(0);
  $or$cond = $116 | $117;
  if ($or$cond) {
   STACKTOP = sp;return;
  }
  $118 = (($source) + 38|0);
  $119 = (($source) + 37|0);
  $120 = (($source) + 36|0);
  $121 = (($source) + 39|0);
  $122 = (($dest) + 36|0);
  $123 = (($dest) + 39|0);
  $124 = ($4|0)==(0);
  $d$110 = $1;$s$18 = $3;$y1$09 = 0;
  while(1) {
   if (!($124)) {
    $125 = HEAP8[$121>>0]|0;
    $126 = HEAP8[$120>>0]|0;
    $127 = HEAP8[$119>>0]|0;
    $128 = HEAP8[$118>>0]|0;
    $129 = HEAP8[$123>>0]|0;
    $130 = HEAP8[$122>>0]|0;
    $131 = $125&255;
    $132 = $126&255;
    $133 = $127&255;
    $134 = $128&255;
    $135 = $129&255;
    $136 = $130&255;
    $137 = $131 >>> 3;
    $138 = $132 >>> 3;
    $139 = $133 >>> 3;
    $140 = $134 >>> 3;
    $141 = (($d$110) + ($135<<2)|0);
    $142 = (($d$110) + ($136<<2)|0);
    $143 = (($s$18) + ($137)|0);
    $144 = (($s$18) + ($138)|0);
    $145 = (($s$18) + ($139)|0);
    $146 = (($s$18) + ($140)|0);
    $a08$06 = $141;$a15$04 = $143;$b07$05 = $142;$b14$03 = $144;$g13$02 = $145;$r12$01 = $146;$x9$07 = 0;
    while(1) {
     if ($31) {
      $147 = HEAP8[$r12$01>>0]|0;
      $148 = (($r12$01) + ($16)|0);
      $156 = $147;$r12$1 = $148;
     } else {
      $156 = -1;$r12$1 = $r12$01;
     }
     if ($34) {
      $149 = HEAP8[$g13$02>>0]|0;
      $150 = (($g13$02) + ($16)|0);
      $160 = $149;$g13$1 = $150;
     } else {
      $160 = -1;$g13$1 = $g13$02;
     }
     if ($37) {
      $151 = HEAP8[$b14$03>>0]|0;
      $152 = (($b14$03) + ($16)|0);
      $164 = $151;$b14$1 = $152;
     } else {
      $164 = -1;$b14$1 = $b14$03;
     }
     if ($40) {
      $153 = HEAP8[$a15$04>>0]|0;
      $154 = (($a15$04) + ($16)|0);
      $174 = $153;$a15$1 = $154;
     } else {
      $174 = -1;$a15$1 = $a15$04;
     }
     if ($25) {
      $155 = $156&255;
      $157 = (Math_fround(($155|0)));
      $158 = Math_fround($157 / Math_fround(255.0));
      $159 = $160&255;
      $161 = (Math_fround(($159|0)));
      $162 = Math_fround($161 / Math_fround(255.0));
      $163 = $164&255;
      $165 = (Math_fround(($163|0)));
      $166 = Math_fround($165 / Math_fround(255.0));
      $167 = Math_fround($166 * Math_fround(0.114000000059604644775));
      $168 = Math_fround($162 * Math_fround(0.587000012397766113281));
      $169 = Math_fround($168 + $167);
      $170 = Math_fround($158 * Math_fround(0.298999994993209838867));
      $171 = Math_fround($170 + $169);
      HEAPF32[$b07$05>>2] = $171;
      $172 = (($b07$05) + ($12<<2)|0);
      $b07$1 = $172;
     } else {
      $b07$1 = $b07$05;
     }
     if ($28) {
      $173 = $174&255;
      $175 = (Math_fround(($173|0)));
      $176 = Math_fround($175 / Math_fround(255.0));
      HEAPF32[$a08$06>>2] = $176;
      $177 = (($a08$06) + ($12<<2)|0);
      $a08$1 = $177;
     } else {
      $a08$1 = $a08$06;
     }
     $178 = (($x9$07) + 1)|0;
     $exitcond = ($178|0)==($4|0);
     if ($exitcond) {
      break;
     } else {
      $a08$06 = $a08$1;$a15$04 = $a15$1;$b07$05 = $b07$1;$b14$03 = $b14$1;$g13$02 = $g13$1;$r12$01 = $r12$1;$x9$07 = $178;
     }
    }
   }
   $179 = (($d$110) + ($8)|0);
   $180 = (($s$18) + ($10)|0);
   $181 = (($y1$09) + 1)|0;
   $exitcond30 = ($181|0)==($6|0);
   if ($exitcond30) {
    break;
   } else {
    $d$110 = $179;$s$18 = $180;$y1$09 = $181;
   }
  }
  STACKTOP = sp;return;
 }
 $45 = ($6|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $46 = (($source) + 38|0);
 $47 = (($source) + 37|0);
 $48 = (($source) + 36|0);
 $49 = (($source) + 39|0);
 $50 = (($dest) + 38|0);
 $51 = (($dest) + 37|0);
 $52 = (($dest) + 36|0);
 $53 = (($dest) + 39|0);
 $54 = ($4|0)==(0);
 $d$028 = $1;$s$027 = $3;$y$026 = 0;
 while(1) {
  if (!($54)) {
   $55 = HEAP8[$49>>0]|0;
   $56 = HEAP8[$48>>0]|0;
   $57 = HEAP8[$47>>0]|0;
   $58 = HEAP8[$46>>0]|0;
   $59 = HEAP8[$53>>0]|0;
   $60 = HEAP8[$52>>0]|0;
   $61 = HEAP8[$51>>0]|0;
   $62 = HEAP8[$50>>0]|0;
   $63 = $55&255;
   $64 = $56&255;
   $65 = $57&255;
   $66 = $58&255;
   $67 = $59&255;
   $68 = $60&255;
   $69 = $61&255;
   $70 = $62&255;
   $71 = $63 >>> 3;
   $72 = $64 >>> 3;
   $73 = $65 >>> 3;
   $74 = $66 >>> 3;
   $75 = (($d$028) + ($67<<2)|0);
   $76 = (($d$028) + ($68<<2)|0);
   $77 = (($d$028) + ($69<<2)|0);
   $78 = (($d$028) + ($70<<2)|0);
   $79 = (($s$027) + ($71)|0);
   $80 = (($s$027) + ($72)|0);
   $81 = (($s$027) + ($73)|0);
   $82 = (($s$027) + ($74)|0);
   $a0$019 = $75;$a1$015 = $79;$b0$018 = $76;$b1$014 = $80;$g0$017 = $77;$g1$013 = $81;$r0$016 = $78;$r1$012 = $82;$x$020 = 0;
   while(1) {
    if ($31) {
     $83 = HEAP8[$r1$012>>0]|0;
     $84 = (($r1$012) + ($16)|0);
     $92 = $83;$r1$1 = $84;
    } else {
     $92 = -1;$r1$1 = $r1$012;
    }
    if ($34) {
     $85 = HEAP8[$g1$013>>0]|0;
     $86 = (($g1$013) + ($16)|0);
     $97 = $85;$g1$1 = $86;
    } else {
     $97 = -1;$g1$1 = $g1$013;
    }
    if ($37) {
     $87 = HEAP8[$b1$014>>0]|0;
     $88 = (($b1$014) + ($16)|0);
     $102 = $87;$b1$1 = $88;
    } else {
     $102 = -1;$b1$1 = $b1$014;
    }
    if ($40) {
     $89 = HEAP8[$a1$015>>0]|0;
     $90 = (($a1$015) + ($16)|0);
     $107 = $89;$a1$1 = $90;
    } else {
     $107 = -1;$a1$1 = $a1$015;
    }
    if ($19) {
     $r0$1 = $r0$016;
    } else {
     $91 = $92&255;
     $93 = (Math_fround(($91|0)));
     $94 = Math_fround($93 * Math_fround(0.00392156885936856269836));
     HEAPF32[$r0$016>>2] = $94;
     $95 = (($r0$016) + ($12<<2)|0);
     $r0$1 = $95;
    }
    if ($22) {
     $g0$1 = $g0$017;
    } else {
     $96 = $97&255;
     $98 = (Math_fround(($96|0)));
     $99 = Math_fround($98 * Math_fround(0.00392156885936856269836));
     HEAPF32[$g0$017>>2] = $99;
     $100 = (($g0$017) + ($12<<2)|0);
     $g0$1 = $100;
    }
    if ($25) {
     $101 = $102&255;
     $103 = (Math_fround(($101|0)));
     $104 = Math_fround($103 * Math_fround(0.00392156885936856269836));
     HEAPF32[$b0$018>>2] = $104;
     $105 = (($b0$018) + ($12<<2)|0);
     $b0$1 = $105;
    } else {
     $b0$1 = $b0$018;
    }
    if ($28) {
     $106 = $107&255;
     $108 = (Math_fround(($106|0)));
     $109 = Math_fround($108 * Math_fround(0.00392156885936856269836));
     HEAPF32[$a0$019>>2] = $109;
     $110 = (($a0$019) + ($12<<2)|0);
     $a0$1 = $110;
    } else {
     $a0$1 = $a0$019;
    }
    $111 = (($x$020) + 1)|0;
    $exitcond31 = ($111|0)==($4|0);
    if ($exitcond31) {
     break;
    } else {
     $a0$019 = $a0$1;$a1$015 = $a1$1;$b0$018 = $b0$1;$b1$014 = $b1$1;$g0$017 = $g0$1;$g1$013 = $g1$1;$r0$016 = $r0$1;$r1$012 = $r1$1;$x$020 = $111;
    }
   }
  }
  $112 = (($d$028) + ($8)|0);
  $113 = (($s$027) + ($10)|0);
  $114 = (($y$026) + 1)|0;
  $exitcond32 = ($114|0)==($6|0);
  if ($exitcond32) {
   break;
  } else {
   $d$028 = $112;$s$027 = $113;$y$026 = $114;
  }
 }
 STACKTOP = sp;return;
}
function __ZL18BlitIntegerToFloatI4halfEvRN6prcore7SurfaceERKS2_($dest,$source) {
 $dest = $dest|0;
 $source = $source|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0, $216 = 0, $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0, $220 = 0, $221 = Math_fround(0), $222 = Math_fround(0), $223 = Math_fround(0);
 var $224 = Math_fround(0), $225 = Math_fround(0), $226 = Math_fround(0), $227 = Math_fround(0), $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = Math_fround(0), $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0);
 var $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a0$029 = 0, $a0$1 = 0, $a08$016 = 0, $a08$1 = 0, $a1$025 = 0, $a1$1 = 0, $a15$014 = 0, $a15$1 = 0, $b0$028 = 0, $b0$1 = 0, $b07$015 = 0, $b07$1 = 0, $b1$024 = 0, $b1$1 = 0;
 var $b14$013 = 0, $b14$1 = 0, $d$038 = 0, $d$120 = 0, $exitcond = 0, $exitcond40 = 0, $exitcond41 = 0, $exitcond42 = 0, $g0$027 = 0, $g0$1 = 0, $g1$023 = 0, $g1$1 = 0, $g13$012 = 0, $g13$1 = 0, $or$cond = 0, $r0$026 = 0, $r0$1 = 0, $r1$022 = 0, $r1$1 = 0, $r12$011 = 0;
 var $r12$1 = 0, $s$037 = 0, $s$118 = 0, $x$030 = 0, $x9$017 = 0, $y$036 = 0, $y1$019 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($dest) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($source) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$dest>>2]|0;
 $5 = (($dest) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($dest) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($source) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8>>>0) / ($4>>>0))&-1;
 $12 = $11 >>> 1;
 $13 = (($source) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 >>> 3;
 $16 = $15 & 8191;
 $17 = (($dest) + 16|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0);
 $20 = (($dest) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0);
 $23 = (($dest) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)!=(0);
 $26 = (($dest) + 28|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)!=(0);
 $29 = (($source) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)!=(0);
 $32 = (($source) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)!=(0);
 $35 = (($source) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)!=(0);
 $38 = (($source) + 28|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)!=(0);
 $41 = (($dest) + 12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42 & 268435456;
 $44 = ($43|0)==(0);
 if ($44) {
  $171 = $42 & 134217728;
  $172 = ($171|0)==(0);
  $173 = ($6|0)==(0);
  $or$cond = $172 | $173;
  if ($or$cond) {
   STACKTOP = sp;return;
  }
  $174 = (($source) + 38|0);
  $175 = (($source) + 37|0);
  $176 = (($source) + 36|0);
  $177 = (($source) + 39|0);
  $178 = (($dest) + 36|0);
  $179 = (($dest) + 39|0);
  $180 = ($4|0)==(0);
  $d$120 = $1;$s$118 = $3;$y1$019 = 0;
  while(1) {
   if (!($180)) {
    $181 = HEAP8[$177>>0]|0;
    $182 = HEAP8[$176>>0]|0;
    $183 = HEAP8[$175>>0]|0;
    $184 = HEAP8[$174>>0]|0;
    $185 = HEAP8[$179>>0]|0;
    $186 = HEAP8[$178>>0]|0;
    $187 = $181&255;
    $188 = $182&255;
    $189 = $183&255;
    $190 = $184&255;
    $191 = $185&255;
    $192 = $186&255;
    $193 = $187 >>> 3;
    $194 = $188 >>> 3;
    $195 = $189 >>> 3;
    $196 = $190 >>> 3;
    $197 = (($d$120) + ($191<<1)|0);
    $198 = (($d$120) + ($192<<1)|0);
    $199 = (($s$118) + ($193)|0);
    $200 = (($s$118) + ($194)|0);
    $201 = (($s$118) + ($195)|0);
    $202 = (($s$118) + ($196)|0);
    $a08$016 = $197;$a15$014 = $199;$b07$015 = $198;$b14$013 = $200;$g13$012 = $201;$r12$011 = $202;$x9$017 = 0;
    while(1) {
     if ($31) {
      $203 = HEAP8[$r12$011>>0]|0;
      $204 = (($r12$011) + ($16)|0);
      $212 = $203;$r12$1 = $204;
     } else {
      $212 = -1;$r12$1 = $r12$011;
     }
     if ($34) {
      $205 = HEAP8[$g13$012>>0]|0;
      $206 = (($g13$012) + ($16)|0);
      $216 = $205;$g13$1 = $206;
     } else {
      $216 = -1;$g13$1 = $g13$012;
     }
     if ($37) {
      $207 = HEAP8[$b14$013>>0]|0;
      $208 = (($b14$013) + ($16)|0);
      $220 = $207;$b14$1 = $208;
     } else {
      $220 = -1;$b14$1 = $b14$013;
     }
     if ($40) {
      $209 = HEAP8[$a15$014>>0]|0;
      $210 = (($a15$014) + ($16)|0);
      $244 = $209;$a15$1 = $210;
     } else {
      $244 = -1;$a15$1 = $a15$014;
     }
     if ($25) {
      $211 = $212&255;
      $213 = (Math_fround(($211|0)));
      $214 = Math_fround($213 / Math_fround(255.0));
      $215 = $216&255;
      $217 = (Math_fround(($215|0)));
      $218 = Math_fround($217 / Math_fround(255.0));
      $219 = $220&255;
      $221 = (Math_fround(($219|0)));
      $222 = Math_fround($221 / Math_fround(255.0));
      $223 = Math_fround($222 * Math_fround(0.114000000059604644775));
      $224 = Math_fround($218 * Math_fround(0.587000012397766113281));
      $225 = Math_fround($224 + $223);
      $226 = Math_fround($214 * Math_fround(0.298999994993209838867));
      $227 = Math_fround($226 + $225);
      $228 = $227 == Math_fround(0.0);
      do {
       if ($228) {
        $241 = 0;
       } else {
        $229 = (HEAPF32[tempDoublePtr>>2]=$227,HEAP32[tempDoublePtr>>2]|0);
        $230 = $229 >>> 23;
        $231 = (1137192 + ($230<<1)|0);
        $232 = HEAP16[$231>>1]|0;
        $233 = ($232<<16>>16)==(0);
        if ($233) {
         $240 = (__ZN4half7convertEi($229)|0);
         $241 = $240;
         break;
        } else {
         $234 = $232&65535;
         $235 = $229 & 8388607;
         $236 = (($235) + 4096)|0;
         $237 = $236 >>> 13;
         $238 = (($234) + ($237))|0;
         $239 = $238&65535;
         $241 = $239;
         break;
        }
       }
      } while(0);
      HEAP16[$b07$015>>1] = $241;
      $242 = (($b07$015) + ($12<<1)|0);
      $b07$1 = $242;
     } else {
      $b07$1 = $b07$015;
     }
     if ($28) {
      $243 = $244&255;
      $245 = (Math_fround(($243|0)));
      $246 = Math_fround($245 / Math_fround(255.0));
      $247 = $246 == Math_fround(0.0);
      do {
       if ($247) {
        $260 = 0;
       } else {
        $248 = (HEAPF32[tempDoublePtr>>2]=$246,HEAP32[tempDoublePtr>>2]|0);
        $249 = $248 >>> 23;
        $250 = (1137192 + ($249<<1)|0);
        $251 = HEAP16[$250>>1]|0;
        $252 = ($251<<16>>16)==(0);
        if ($252) {
         $259 = (__ZN4half7convertEi($248)|0);
         $260 = $259;
         break;
        } else {
         $253 = $251&65535;
         $254 = $248 & 8388607;
         $255 = (($254) + 4096)|0;
         $256 = $255 >>> 13;
         $257 = (($253) + ($256))|0;
         $258 = $257&65535;
         $260 = $258;
         break;
        }
       }
      } while(0);
      HEAP16[$a08$016>>1] = $260;
      $261 = (($a08$016) + ($12<<1)|0);
      $a08$1 = $261;
     } else {
      $a08$1 = $a08$016;
     }
     $262 = (($x9$017) + 1)|0;
     $exitcond = ($262|0)==($4|0);
     if ($exitcond) {
      break;
     } else {
      $a08$016 = $a08$1;$a15$014 = $a15$1;$b07$015 = $b07$1;$b14$013 = $b14$1;$g13$012 = $g13$1;$r12$011 = $r12$1;$x9$017 = $262;
     }
    }
   }
   $263 = (($d$120) + ($8)|0);
   $264 = (($s$118) + ($10)|0);
   $265 = (($y1$019) + 1)|0;
   $exitcond40 = ($265|0)==($6|0);
   if ($exitcond40) {
    break;
   } else {
    $d$120 = $263;$s$118 = $264;$y1$019 = $265;
   }
  }
  STACKTOP = sp;return;
 }
 $45 = ($6|0)==(0);
 if ($45) {
  STACKTOP = sp;return;
 }
 $46 = (($source) + 38|0);
 $47 = (($source) + 37|0);
 $48 = (($source) + 36|0);
 $49 = (($source) + 39|0);
 $50 = (($dest) + 38|0);
 $51 = (($dest) + 37|0);
 $52 = (($dest) + 36|0);
 $53 = (($dest) + 39|0);
 $54 = ($4|0)==(0);
 $d$038 = $1;$s$037 = $3;$y$036 = 0;
 while(1) {
  if (!($54)) {
   $55 = HEAP8[$49>>0]|0;
   $56 = HEAP8[$48>>0]|0;
   $57 = HEAP8[$47>>0]|0;
   $58 = HEAP8[$46>>0]|0;
   $59 = HEAP8[$53>>0]|0;
   $60 = HEAP8[$52>>0]|0;
   $61 = HEAP8[$51>>0]|0;
   $62 = HEAP8[$50>>0]|0;
   $63 = $55&255;
   $64 = $56&255;
   $65 = $57&255;
   $66 = $58&255;
   $67 = $59&255;
   $68 = $60&255;
   $69 = $61&255;
   $70 = $62&255;
   $71 = $63 >>> 3;
   $72 = $64 >>> 3;
   $73 = $65 >>> 3;
   $74 = $66 >>> 3;
   $75 = (($d$038) + ($67<<1)|0);
   $76 = (($d$038) + ($68<<1)|0);
   $77 = (($d$038) + ($69<<1)|0);
   $78 = (($d$038) + ($70<<1)|0);
   $79 = (($s$037) + ($71)|0);
   $80 = (($s$037) + ($72)|0);
   $81 = (($s$037) + ($73)|0);
   $82 = (($s$037) + ($74)|0);
   $a0$029 = $75;$a1$025 = $79;$b0$028 = $76;$b1$024 = $80;$g0$027 = $77;$g1$023 = $81;$r0$026 = $78;$r1$022 = $82;$x$030 = 0;
   while(1) {
    if ($31) {
     $83 = HEAP8[$r1$022>>0]|0;
     $84 = (($r1$022) + ($16)|0);
     $92 = $83;$r1$1 = $84;
    } else {
     $92 = -1;$r1$1 = $r1$022;
    }
    if ($34) {
     $85 = HEAP8[$g1$023>>0]|0;
     $86 = (($g1$023) + ($16)|0);
     $111 = $85;$g1$1 = $86;
    } else {
     $111 = -1;$g1$1 = $g1$023;
    }
    if ($37) {
     $87 = HEAP8[$b1$024>>0]|0;
     $88 = (($b1$024) + ($16)|0);
     $130 = $87;$b1$1 = $88;
    } else {
     $130 = -1;$b1$1 = $b1$024;
    }
    if ($40) {
     $89 = HEAP8[$a1$025>>0]|0;
     $90 = (($a1$025) + ($16)|0);
     $149 = $89;$a1$1 = $90;
    } else {
     $149 = -1;$a1$1 = $a1$025;
    }
    if ($19) {
     $r0$1 = $r0$026;
    } else {
     $91 = $92&255;
     $93 = (Math_fround(($91|0)));
     $94 = Math_fround($93 * Math_fround(0.00392156885936856269836));
     $95 = $94 == Math_fround(0.0);
     do {
      if ($95) {
       $108 = 0;
      } else {
       $96 = (HEAPF32[tempDoublePtr>>2]=$94,HEAP32[tempDoublePtr>>2]|0);
       $97 = $96 >>> 23;
       $98 = (1137192 + ($97<<1)|0);
       $99 = HEAP16[$98>>1]|0;
       $100 = ($99<<16>>16)==(0);
       if ($100) {
        $107 = (__ZN4half7convertEi($96)|0);
        $108 = $107;
        break;
       } else {
        $101 = $99&65535;
        $102 = $96 & 8388607;
        $103 = (($102) + 4096)|0;
        $104 = $103 >>> 13;
        $105 = (($101) + ($104))|0;
        $106 = $105&65535;
        $108 = $106;
        break;
       }
      }
     } while(0);
     HEAP16[$r0$026>>1] = $108;
     $109 = (($r0$026) + ($12<<1)|0);
     $r0$1 = $109;
    }
    if ($22) {
     $g0$1 = $g0$027;
    } else {
     $110 = $111&255;
     $112 = (Math_fround(($110|0)));
     $113 = Math_fround($112 * Math_fround(0.00392156885936856269836));
     $114 = $113 == Math_fround(0.0);
     do {
      if ($114) {
       $127 = 0;
      } else {
       $115 = (HEAPF32[tempDoublePtr>>2]=$113,HEAP32[tempDoublePtr>>2]|0);
       $116 = $115 >>> 23;
       $117 = (1137192 + ($116<<1)|0);
       $118 = HEAP16[$117>>1]|0;
       $119 = ($118<<16>>16)==(0);
       if ($119) {
        $126 = (__ZN4half7convertEi($115)|0);
        $127 = $126;
        break;
       } else {
        $120 = $118&65535;
        $121 = $115 & 8388607;
        $122 = (($121) + 4096)|0;
        $123 = $122 >>> 13;
        $124 = (($120) + ($123))|0;
        $125 = $124&65535;
        $127 = $125;
        break;
       }
      }
     } while(0);
     HEAP16[$g0$027>>1] = $127;
     $128 = (($g0$027) + ($12<<1)|0);
     $g0$1 = $128;
    }
    if ($25) {
     $129 = $130&255;
     $131 = (Math_fround(($129|0)));
     $132 = Math_fround($131 * Math_fround(0.00392156885936856269836));
     $133 = $132 == Math_fround(0.0);
     do {
      if ($133) {
       $146 = 0;
      } else {
       $134 = (HEAPF32[tempDoublePtr>>2]=$132,HEAP32[tempDoublePtr>>2]|0);
       $135 = $134 >>> 23;
       $136 = (1137192 + ($135<<1)|0);
       $137 = HEAP16[$136>>1]|0;
       $138 = ($137<<16>>16)==(0);
       if ($138) {
        $145 = (__ZN4half7convertEi($134)|0);
        $146 = $145;
        break;
       } else {
        $139 = $137&65535;
        $140 = $134 & 8388607;
        $141 = (($140) + 4096)|0;
        $142 = $141 >>> 13;
        $143 = (($139) + ($142))|0;
        $144 = $143&65535;
        $146 = $144;
        break;
       }
      }
     } while(0);
     HEAP16[$b0$028>>1] = $146;
     $147 = (($b0$028) + ($12<<1)|0);
     $b0$1 = $147;
    } else {
     $b0$1 = $b0$028;
    }
    if ($28) {
     $148 = $149&255;
     $150 = (Math_fround(($148|0)));
     $151 = Math_fround($150 * Math_fround(0.00392156885936856269836));
     $152 = $151 == Math_fround(0.0);
     do {
      if ($152) {
       $165 = 0;
      } else {
       $153 = (HEAPF32[tempDoublePtr>>2]=$151,HEAP32[tempDoublePtr>>2]|0);
       $154 = $153 >>> 23;
       $155 = (1137192 + ($154<<1)|0);
       $156 = HEAP16[$155>>1]|0;
       $157 = ($156<<16>>16)==(0);
       if ($157) {
        $164 = (__ZN4half7convertEi($153)|0);
        $165 = $164;
        break;
       } else {
        $158 = $156&65535;
        $159 = $153 & 8388607;
        $160 = (($159) + 4096)|0;
        $161 = $160 >>> 13;
        $162 = (($158) + ($161))|0;
        $163 = $162&65535;
        $165 = $163;
        break;
       }
      }
     } while(0);
     HEAP16[$a0$029>>1] = $165;
     $166 = (($a0$029) + ($12<<1)|0);
     $a0$1 = $166;
    } else {
     $a0$1 = $a0$029;
    }
    $167 = (($x$030) + 1)|0;
    $exitcond41 = ($167|0)==($4|0);
    if ($exitcond41) {
     break;
    } else {
     $a0$029 = $a0$1;$a1$025 = $a1$1;$b0$028 = $b0$1;$b1$024 = $b1$1;$g0$027 = $g0$1;$g1$023 = $g1$1;$r0$026 = $r0$1;$r1$022 = $r1$1;$x$030 = $167;
    }
   }
  }
  $168 = (($d$038) + ($8)|0);
  $169 = (($s$037) + ($10)|0);
  $170 = (($y$036) + 1)|0;
  $exitcond42 = ($170|0)==($6|0);
  if ($exitcond42) {
   break;
  } else {
   $d$038 = $168;$s$037 = $169;$y$036 = $170;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7BlitterC2ERKN6prcore11PixelFormatES3_i($this,$dest,$source,$type) {
 $this = $this|0;
 $dest = $dest|0;
 $source = $source|0;
 $type = $type|0;
 var $$$i = 0, $$$i$i = 0, $$$i$i24 = 0, $$$i$i39 = 0, $$$i$i54 = 0, $$$i$i69 = 0, $$$i$i9 = 0, $$$i112 = 0, $$$i127 = 0, $$$i140 = 0, $$$i155 = 0, $$$i168 = 0, $$$i193 = 0, $$$i208 = 0, $$$i221 = 0, $$$i235 = 0, $$$i260 = 0, $$$i285 = 0, $$$i311 = 0, $$$i324 = 0;
 var $$$i339 = 0, $$$i352 = 0, $$$i367 = 0, $$$i380 = 0, $$$i395 = 0, $$$i408 = 0, $$$i433 = 0, $$$i448 = 0, $$$i461 = 0, $$$i475 = 0, $$$i500 = 0, $$$i525 = 0, $$$i84 = 0, $$$i99 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i10 = 0, $$0$i$i25 = 0, $$0$i$i40 = 0, $$0$i$i55 = 0;
 var $$0$i$i70 = 0, $$0$i100 = 0, $$0$i113 = 0, $$0$i128 = 0, $$0$i141 = 0, $$0$i156 = 0, $$0$i169 = 0, $$0$i194 = 0, $$0$i209 = 0, $$0$i222 = 0, $$0$i236 = 0, $$0$i261 = 0, $$0$i286 = 0, $$0$i312 = 0, $$0$i325 = 0, $$0$i340 = 0, $$0$i353 = 0, $$0$i368 = 0, $$0$i381 = 0, $$0$i396 = 0;
 var $$0$i409 = 0, $$0$i434 = 0, $$0$i449 = 0, $$0$i462 = 0, $$0$i476 = 0, $$0$i501 = 0, $$0$i526 = 0, $$0$i85 = 0, $$1$i = 0, $$1$i$i = 0, $$1$i$i12 = 0, $$1$i$i27 = 0, $$1$i$i42 = 0, $$1$i$i57 = 0, $$1$i$i72 = 0, $$1$i102 = 0, $$1$i115 = 0, $$1$i130 = 0, $$1$i143 = 0, $$1$i158 = 0;
 var $$1$i171 = 0, $$1$i196 = 0, $$1$i211 = 0, $$1$i224 = 0, $$1$i238 = 0, $$1$i263 = 0, $$1$i288 = 0, $$1$i314 = 0, $$1$i327 = 0, $$1$i342 = 0, $$1$i355 = 0, $$1$i370 = 0, $$1$i383 = 0, $$1$i398 = 0, $$1$i411 = 0, $$1$i436 = 0, $$1$i451 = 0, $$1$i464 = 0, $$1$i478 = 0, $$1$i503 = 0;
 var $$1$i528 = 0, $$1$i87 = 0, $$2$i = 0, $$2$i$i = 0, $$2$i$i14 = 0, $$2$i$i29 = 0, $$2$i$i44 = 0, $$2$i$i59 = 0, $$2$i$i74 = 0, $$2$i104 = 0, $$2$i117 = 0, $$2$i132 = 0, $$2$i145 = 0, $$2$i160 = 0, $$2$i173 = 0, $$2$i198 = 0, $$2$i213 = 0, $$2$i226 = 0, $$2$i240 = 0, $$2$i265 = 0;
 var $$2$i290 = 0, $$2$i316 = 0, $$2$i329 = 0, $$2$i344 = 0, $$2$i357 = 0, $$2$i372 = 0, $$2$i385 = 0, $$2$i400 = 0, $$2$i413 = 0, $$2$i438 = 0, $$2$i453 = 0, $$2$i466 = 0, $$2$i480 = 0, $$2$i505 = 0, $$2$i530 = 0, $$2$i89 = 0, $$3$i = 0, $$3$i$i = 0, $$3$i$i16 = 0, $$3$i$i31 = 0;
 var $$3$i$i46 = 0, $$3$i$i61 = 0, $$3$i$i76 = 0, $$3$i106 = 0, $$3$i119 = 0, $$3$i134 = 0, $$3$i147 = 0, $$3$i162 = 0, $$3$i175 = 0, $$3$i200 = 0, $$3$i215 = 0, $$3$i228 = 0, $$3$i242 = 0, $$3$i267 = 0, $$3$i292 = 0, $$3$i318 = 0, $$3$i331 = 0, $$3$i346 = 0, $$3$i359 = 0, $$3$i374 = 0;
 var $$3$i387 = 0, $$3$i402 = 0, $$3$i415 = 0, $$3$i440 = 0, $$3$i455 = 0, $$3$i468 = 0, $$3$i482 = 0, $$3$i507 = 0, $$3$i532 = 0, $$3$i91 = 0, $$4$i = 0, $$4$i$i = 0, $$4$i$i18 = 0, $$4$i$i33 = 0, $$4$i$i48 = 0, $$4$i$i63 = 0, $$4$i$i78 = 0, $$4$i108 = 0, $$4$i121 = 0, $$4$i136 = 0;
 var $$4$i149 = 0, $$4$i164 = 0, $$4$i177 = 0, $$4$i202 = 0, $$4$i217 = 0, $$4$i230 = 0, $$4$i244 = 0, $$4$i269 = 0, $$4$i294 = 0, $$4$i320 = 0, $$4$i333 = 0, $$4$i348 = 0, $$4$i361 = 0, $$4$i376 = 0, $$4$i389 = 0, $$4$i404 = 0, $$4$i417 = 0, $$4$i442 = 0, $$4$i457 = 0, $$4$i470 = 0;
 var $$4$i484 = 0, $$4$i509 = 0, $$4$i534 = 0, $$4$i93 = 0, $$693 = 0, $$694 = 0, $$695 = 0, $$696 = 0, $$697 = 0, $$698 = 0, $$699 = 0, $$destidx$0 = 0, $$neg2$i = 0, $$neg2$i20 = 0, $$neg2$i35 = 0, $$neg2$i50 = 0, $$neg2$i65 = 0, $$neg2$i80 = 0, $$neg701 = 0, $$neg703 = 0;
 var $$neg705 = 0, $$neg717 = 0, $$neg719 = 0, $$neg721 = 0, $$sourceidx$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0;
 var $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0;
 var $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0;
 var $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0;
 var $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0;
 var $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0;
 var $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0;
 var $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0;
 var $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0;
 var $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0;
 var $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0;
 var $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0;
 var $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0, $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0;
 var $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0;
 var $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0;
 var $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0;
 var $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0;
 var $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0;
 var $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0;
 var $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0, $1344 = 0, $1345 = 0, $1346 = 0, $1347 = 0, $1348 = 0, $1349 = 0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0;
 var $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0;
 var $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0;
 var $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0, $1398 = 0, $1399 = 0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0, $1404 = 0, $1405 = 0, $1406 = 0;
 var $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0;
 var $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0, $1431 = 0, $1432 = 0, $1433 = 0, $1434 = 0, $1435 = 0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0;
 var $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0;
 var $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0;
 var $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0;
 var $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0;
 var $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0;
 var $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0;
 var $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0;
 var $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0;
 var $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0;
 var $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0;
 var $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0;
 var $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0;
 var $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0;
 var $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0;
 var $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0;
 var $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0;
 var $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0;
 var $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0;
 var $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0;
 var $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0;
 var $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0;
 var $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0;
 var $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0;
 var $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0;
 var $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0;
 var $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0;
 var $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0;
 var $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0;
 var $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $base$0$i = 0, $base$0$i$i = 0, $base$0$i$i11 = 0, $base$0$i$i26 = 0, $base$0$i$i41 = 0, $base$0$i$i56 = 0;
 var $base$0$i$i71 = 0, $base$0$i101 = 0, $base$0$i114 = 0, $base$0$i129 = 0, $base$0$i142 = 0, $base$0$i157 = 0, $base$0$i170 = 0, $base$0$i195 = 0, $base$0$i210 = 0, $base$0$i223 = 0, $base$0$i237 = 0, $base$0$i262 = 0, $base$0$i287 = 0, $base$0$i313 = 0, $base$0$i326 = 0, $base$0$i341 = 0, $base$0$i354 = 0, $base$0$i369 = 0, $base$0$i382 = 0, $base$0$i397 = 0;
 var $base$0$i410 = 0, $base$0$i435 = 0, $base$0$i450 = 0, $base$0$i463 = 0, $base$0$i477 = 0, $base$0$i502 = 0, $base$0$i527 = 0, $base$0$i86 = 0, $base$1$i = 0, $base$1$i$i = 0, $base$1$i$i13 = 0, $base$1$i$i28 = 0, $base$1$i$i43 = 0, $base$1$i$i58 = 0, $base$1$i$i73 = 0, $base$1$i103 = 0, $base$1$i116 = 0, $base$1$i131 = 0, $base$1$i144 = 0, $base$1$i159 = 0;
 var $base$1$i172 = 0, $base$1$i197 = 0, $base$1$i212 = 0, $base$1$i225 = 0, $base$1$i239 = 0, $base$1$i264 = 0, $base$1$i289 = 0, $base$1$i315 = 0, $base$1$i328 = 0, $base$1$i343 = 0, $base$1$i356 = 0, $base$1$i371 = 0, $base$1$i384 = 0, $base$1$i399 = 0, $base$1$i412 = 0, $base$1$i437 = 0, $base$1$i452 = 0, $base$1$i465 = 0, $base$1$i479 = 0, $base$1$i504 = 0;
 var $base$1$i529 = 0, $base$1$i88 = 0, $base$2$i = 0, $base$2$i$i = 0, $base$2$i$i15 = 0, $base$2$i$i30 = 0, $base$2$i$i45 = 0, $base$2$i$i60 = 0, $base$2$i$i75 = 0, $base$2$i105 = 0, $base$2$i118 = 0, $base$2$i133 = 0, $base$2$i146 = 0, $base$2$i161 = 0, $base$2$i174 = 0, $base$2$i199 = 0, $base$2$i214 = 0, $base$2$i227 = 0, $base$2$i241 = 0, $base$2$i266 = 0;
 var $base$2$i291 = 0, $base$2$i317 = 0, $base$2$i330 = 0, $base$2$i345 = 0, $base$2$i358 = 0, $base$2$i373 = 0, $base$2$i386 = 0, $base$2$i401 = 0, $base$2$i414 = 0, $base$2$i439 = 0, $base$2$i454 = 0, $base$2$i467 = 0, $base$2$i481 = 0, $base$2$i506 = 0, $base$2$i531 = 0, $base$2$i90 = 0, $base$3$i = 0, $base$3$i$i = 0, $base$3$i$i17 = 0, $base$3$i$i32 = 0;
 var $base$3$i$i47 = 0, $base$3$i$i62 = 0, $base$3$i$i77 = 0, $base$3$i107 = 0, $base$3$i120 = 0, $base$3$i135 = 0, $base$3$i148 = 0, $base$3$i163 = 0, $base$3$i176 = 0, $base$3$i201 = 0, $base$3$i216 = 0, $base$3$i229 = 0, $base$3$i243 = 0, $base$3$i268 = 0, $base$3$i293 = 0, $base$3$i319 = 0, $base$3$i332 = 0, $base$3$i347 = 0, $base$3$i360 = 0, $base$3$i375 = 0;
 var $base$3$i388 = 0, $base$3$i403 = 0, $base$3$i416 = 0, $base$3$i441 = 0, $base$3$i456 = 0, $base$3$i469 = 0, $base$3$i483 = 0, $base$3$i508 = 0, $base$3$i533 = 0, $base$3$i92 = 0, $base$4$i = 0, $base$4$i$i = 0, $base$4$i$i19 = 0, $base$4$i$i34 = 0, $base$4$i$i49 = 0, $base$4$i$i64 = 0, $base$4$i$i79 = 0, $base$4$i109 = 0, $base$4$i122 = 0, $base$4$i137 = 0;
 var $base$4$i150 = 0, $base$4$i165 = 0, $base$4$i178 = 0, $base$4$i203 = 0, $base$4$i218 = 0, $base$4$i231 = 0, $base$4$i245 = 0, $base$4$i270 = 0, $base$4$i295 = 0, $base$4$i321 = 0, $base$4$i334 = 0, $base$4$i349 = 0, $base$4$i362 = 0, $base$4$i377 = 0, $base$4$i390 = 0, $base$4$i405 = 0, $base$4$i418 = 0, $base$4$i443 = 0, $base$4$i458 = 0, $base$4$i471 = 0;
 var $base$4$i485 = 0, $base$4$i510 = 0, $base$4$i535 = 0, $base$4$i94 = 0, $destidx$0$lcssa = 0, $destidx$0737 = 0, $mask$$i = 0, $mask$$i$i = 0, $mask$$i$i23 = 0, $mask$$i$i38 = 0, $mask$$i$i53 = 0, $mask$$i$i68 = 0, $mask$$i$i8 = 0, $mask$$i111 = 0, $mask$$i126 = 0, $mask$$i139 = 0, $mask$$i154 = 0, $mask$$i167 = 0, $mask$$i192 = 0, $mask$$i207 = 0;
 var $mask$$i220 = 0, $mask$$i234 = 0, $mask$$i259 = 0, $mask$$i284 = 0, $mask$$i310 = 0, $mask$$i323 = 0, $mask$$i338 = 0, $mask$$i351 = 0, $mask$$i366 = 0, $mask$$i379 = 0, $mask$$i394 = 0, $mask$$i407 = 0, $mask$$i432 = 0, $mask$$i447 = 0, $mask$$i460 = 0, $mask$$i474 = 0, $mask$$i499 = 0, $mask$$i524 = 0, $mask$$i83 = 0, $mask$$i98 = 0;
 var $not$ = 0, $not$4 = 0, $not$5 = 0, $not$6 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i124 = 0, $or$cond$i152 = 0, $or$cond$i205 = 0, $or$cond$i308 = 0, $or$cond$i336 = 0, $or$cond$i364 = 0, $or$cond$i392 = 0, $or$cond$i445 = 0, $or$cond$i96 = 0, $or$cond7 = 0, $sourceidx$0$lcssa = 0, $sourceidx$0738 = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = (($this) + 136|0);
 HEAP32[$1>>2] = 0;
 dest=$0+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $2 = HEAP8[1139728>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  HEAP32[1139416>>2] = -2013265912;
  HEAP32[((1139416 + 4|0))>>2] = 0;
  HEAP32[((1139416 + 8|0))>>2] = 0;
  HEAP32[((1139416 + 12|0))>>2] = 255;
  HEAP32[((1139416 + 16|0))>>2] = 0;
  HEAP32[((1139416 + 20|0))>>2] = 0;
  HEAP32[((1139416 + 24|0))>>2] = 0;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,((1139416 + 20|0)),((1139416 + 24|0)));
  HEAP8[((1139416 + 27|0))>>0] = -1;
  HEAP8[((1139416 + 23|0))>>0] = 0;
  HEAP32[((1139416 + 28|0))>>2] = -2013265912;
  HEAP32[((1139416 + 32|0))>>2] = 0;
  HEAP32[((1139416 + 36|0))>>2] = 0;
  HEAP32[((1139416 + 40|0))>>2] = 255;
  HEAP32[((1139416 + 44|0))>>2] = 0;
  HEAP32[((1139416 + 48|0))>>2] = 0;
  HEAP32[((1139416 + 52|0))>>2] = 0;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,((1139416 + 48|0)),((1139416 + 52|0)));
  HEAP8[((1139416 + 55|0))>>0] = -1;
  HEAP8[((1139416 + 51|0))>>0] = 0;
  HEAP32[((1139416 + 56|0))>>2] = -1879048184;
  HEAP32[((1139416 + 60|0))>>2] = 224;
  HEAP32[((1139416 + 64|0))>>2] = 28;
  HEAP32[((1139416 + 68|0))>>2] = 3;
  HEAP32[((1139416 + 72|0))>>2] = 0;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,224,((1139416 + 78|0)),((1139416 + 82|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,28,((1139416 + 77|0)),((1139416 + 81|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,3,((1139416 + 76|0)),((1139416 + 80|0)));
  HEAP8[((1139416 + 83|0))>>0] = -1;
  HEAP8[((1139416 + 79|0))>>0] = 0;
  HEAP32[((1139416 + 84|0))>>2] = -1879048176;
  HEAP32[((1139416 + 88|0))>>2] = 63488;
  HEAP32[((1139416 + 92|0))>>2] = 2016;
  HEAP32[((1139416 + 96|0))>>2] = 31;
  HEAP32[((1139416 + 100|0))>>2] = 0;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,63488,((1139416 + 106|0)),((1139416 + 110|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,2016,((1139416 + 105|0)),((1139416 + 109|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,31,((1139416 + 104|0)),((1139416 + 108|0)));
  HEAP8[((1139416 + 111|0))>>0] = -1;
  HEAP8[((1139416 + 107|0))>>0] = 0;
  HEAP32[((1139416 + 112|0))>>2] = -1879048168;
  HEAP32[((1139416 + 116|0))>>2] = 16711680;
  HEAP32[((1139416 + 120|0))>>2] = 65280;
  HEAP32[((1139416 + 124|0))>>2] = 255;
  HEAP32[((1139416 + 128|0))>>2] = 0;
  HEAP8[((1139416 + 138|0))>>0] = 23;
  HEAP8[((1139416 + 134|0))>>0] = 8;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,((1139416 + 133|0)),((1139416 + 137|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,((1139416 + 132|0)),((1139416 + 136|0)));
  HEAP8[((1139416 + 139|0))>>0] = -1;
  HEAP8[((1139416 + 135|0))>>0] = 0;
  HEAP32[((1139416 + 140|0))>>2] = -1879048176;
  HEAP32[((1139416 + 144|0))>>2] = 31744;
  HEAP32[((1139416 + 148|0))>>2] = 992;
  HEAP32[((1139416 + 152|0))>>2] = 31;
  HEAP32[((1139416 + 156|0))>>2] = 32768;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,31744,((1139416 + 162|0)),((1139416 + 166|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,992,((1139416 + 161|0)),((1139416 + 165|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,31,((1139416 + 160|0)),((1139416 + 164|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,32768,((1139416 + 163|0)),((1139416 + 167|0)));
  HEAP32[((1139416 + 168|0))>>2] = -1879048176;
  HEAP32[((1139416 + 172|0))>>2] = 3840;
  HEAP32[((1139416 + 176|0))>>2] = 240;
  HEAP32[((1139416 + 180|0))>>2] = 15;
  HEAP32[((1139416 + 184|0))>>2] = 61440;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,3840,((1139416 + 190|0)),((1139416 + 194|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,240,((1139416 + 189|0)),((1139416 + 193|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,15,((1139416 + 188|0)),((1139416 + 192|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,61440,((1139416 + 191|0)),((1139416 + 195|0)));
  HEAP32[((1139416 + 196|0))>>2] = -1879048160;
  HEAP32[((1139416 + 200|0))>>2] = 16711680;
  HEAP32[((1139416 + 204|0))>>2] = 65280;
  HEAP32[((1139416 + 208|0))>>2] = 255;
  HEAP32[((1139416 + 212|0))>>2] = -16777216;
  HEAP8[((1139416 + 222|0))>>0] = 23;
  HEAP8[((1139416 + 218|0))>>0] = 8;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,((1139416 + 217|0)),((1139416 + 221|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,((1139416 + 216|0)),((1139416 + 220|0)));
  HEAP8[((1139416 + 223|0))>>0] = 31;
  HEAP8[((1139416 + 219|0))>>0] = 8;
  HEAP32[((1139416 + 224|0))>>2] = -1879048168;
  HEAP32[((1139416 + 228|0))>>2] = 255;
  HEAP32[((1139416 + 232|0))>>2] = 65280;
  HEAP32[((1139416 + 236|0))>>2] = 16711680;
  HEAP32[((1139416 + 240|0))>>2] = 0;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,((1139416 + 246|0)),((1139416 + 250|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,((1139416 + 245|0)),((1139416 + 249|0)));
  HEAP8[((1139416 + 248|0))>>0] = 23;
  HEAP8[((1139416 + 244|0))>>0] = 8;
  HEAP8[((1139416 + 251|0))>>0] = -1;
  HEAP8[((1139416 + 247|0))>>0] = 0;
  HEAP32[((1139416 + 252|0))>>2] = -1879048160;
  HEAP32[((1139416 + 256|0))>>2] = 255;
  HEAP32[((1139416 + 260|0))>>2] = 65280;
  HEAP32[((1139416 + 264|0))>>2] = 16711680;
  HEAP32[((1139416 + 268|0))>>2] = -16777216;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,255,((1139416 + 274|0)),((1139416 + 278|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,65280,((1139416 + 273|0)),((1139416 + 277|0)));
  HEAP8[((1139416 + 276|0))>>0] = 23;
  HEAP8[((1139416 + 272|0))>>0] = 8;
  HEAP8[((1139416 + 279|0))>>0] = 31;
  HEAP8[((1139416 + 275|0))>>0] = 8;
  HEAP32[((1139416 + 280|0))>>2] = -1879048176;
  HEAP32[((1139416 + 284|0))>>2] = 61440;
  HEAP32[((1139416 + 288|0))>>2] = 3840;
  HEAP32[((1139416 + 292|0))>>2] = 240;
  HEAP32[((1139416 + 296|0))>>2] = 15;
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,61440,((1139416 + 302|0)),((1139416 + 306|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,3840,((1139416 + 301|0)),((1139416 + 305|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,240,((1139416 + 300|0)),((1139416 + 304|0)));
  __ZNK6prcore11PixelFormat11ComputeMaskEjRhS1_(0,15,((1139416 + 303|0)),((1139416 + 307|0)));
  HEAP8[1139728>>0] = 1;
 }
 $4 = HEAP32[$source>>2]|0;
 $5 = $4 & 65528;
 $6 = ($5>>>0)>(32);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$dest>>2]|0;
 $8 = $7 & 65528;
 $9 = ($8>>>0)>(32);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 132|0);
 HEAP32[$10>>2] = $type;
 $11 = HEAP32[$source>>2]|0;
 $12 = (($this) + 104|0);
 HEAP32[$12>>2] = $11;
 $13 = (($source) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 108|0);
 HEAP32[$15>>2] = $14;
 $16 = (($source) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 112|0);
 HEAP32[$18>>2] = $17;
 $19 = (($source) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 116|0);
 HEAP32[$21>>2] = $20;
 $22 = (($source) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($this) + 120|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 124|0);
 $26 = (($source) + 20|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$25>>2] = $27;
 $28 = (($this) + 128|0);
 $29 = (($source) + 24|0);
 $30 = HEAP32[$29>>2]|0;
 HEAP32[$28>>2] = $30;
 $31 = HEAP32[$dest>>2]|0;
 HEAP32[$0>>2] = $31;
 $32 = (($dest) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($this) + 80|0);
 HEAP32[$34>>2] = $33;
 $35 = (($dest) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($this) + 84|0);
 HEAP32[$37>>2] = $36;
 $38 = (($dest) + 12|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($this) + 88|0);
 HEAP32[$40>>2] = $39;
 $41 = (($dest) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($this) + 92|0);
 HEAP32[$43>>2] = $42;
 $44 = (($this) + 96|0);
 $45 = (($dest) + 20|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$44>>2] = $46;
 $47 = (($this) + 100|0);
 $48 = (($dest) + 24|0);
 $49 = HEAP32[$48>>2]|0;
 HEAP32[$47>>2] = $49;
 $50 = HEAP32[$13>>2]|0;
 $sourceidx$0738 = 0;
 while(1) {
  $51 = ((1139416 + (($sourceidx$0738*28)|0)|0) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($52|0)==($50|0);
  if ($53) {
   $54 = ((1139416 + (($sourceidx$0738*28)|0)|0) + 8|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = HEAP32[$16>>2]|0;
   $57 = ($55|0)==($56|0);
   if ($57) {
    $58 = ((1139416 + (($sourceidx$0738*28)|0)|0) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = HEAP32[$19>>2]|0;
    $61 = ($59|0)==($60|0);
    if ($61) {
     $62 = ((1139416 + (($sourceidx$0738*28)|0)|0) + 16|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = HEAP32[$22>>2]|0;
     $65 = ($63|0)==($64|0);
     if ($65) {
      $66 = (1139416 + (($sourceidx$0738*28)|0)|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = HEAP32[$source>>2]|0;
      $69 = ($67|0)==($68|0);
      if ($69) {
       $sourceidx$0$lcssa = $sourceidx$0738;
       break;
      }
     }
    }
   }
  }
  $70 = (($sourceidx$0738) + 1)|0;
  $71 = ($70|0)<(11);
  if ($71) {
   $sourceidx$0738 = $70;
  } else {
   $sourceidx$0$lcssa = $70;
   break;
  }
 }
 $72 = ($sourceidx$0$lcssa|0)==(11);
 $$sourceidx$0 = $72 ? -1 : $sourceidx$0$lcssa;
 $73 = HEAP32[$32>>2]|0;
 $destidx$0737 = 0;
 while(1) {
  $74 = ((1139416 + (($destidx$0737*28)|0)|0) + 4|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)==($73|0);
  if ($76) {
   $77 = ((1139416 + (($destidx$0737*28)|0)|0) + 8|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = HEAP32[$35>>2]|0;
   $80 = ($78|0)==($79|0);
   if ($80) {
    $81 = ((1139416 + (($destidx$0737*28)|0)|0) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = HEAP32[$38>>2]|0;
    $84 = ($82|0)==($83|0);
    if ($84) {
     $85 = ((1139416 + (($destidx$0737*28)|0)|0) + 16|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = HEAP32[$41>>2]|0;
     $88 = ($86|0)==($87|0);
     if ($88) {
      $89 = (1139416 + (($destidx$0737*28)|0)|0);
      $90 = HEAP32[$89>>2]|0;
      $91 = HEAP32[$dest>>2]|0;
      $92 = ($90|0)==($91|0);
      if ($92) {
       $destidx$0$lcssa = $destidx$0737;
       break;
      }
     }
    }
   }
  }
  $93 = (($destidx$0737) + 1)|0;
  $94 = ($93|0)<(11);
  if ($94) {
   $destidx$0737 = $93;
  } else {
   $destidx$0$lcssa = $93;
   break;
  }
 }
 $95 = ($destidx$0$lcssa|0)==(11);
 $$destidx$0 = $95 ? -1 : $destidx$0$lcssa;
 if ((($type|0) == 1)) {
  $637 = HEAP32[$source>>2]|0;
  $638 = $637 & 134217728;
  $639 = ($638|0)==(0);
  $640 = $637 >>> 3;
  $641 = $640 & 8191;
  $642 = (($641) + -1)|0;
  if ($639) {
   $645 = (1140368 + ($642<<2)|0);
   $646 = HEAP32[$645>>2]|0;
   HEAP32[$1>>2] = $646;
   STACKTOP = sp;return;
  } else {
   $643 = (1140352 + ($642<<2)|0);
   $644 = HEAP32[$643>>2]|0;
   HEAP32[$1>>2] = $644;
   STACKTOP = sp;return;
  }
 } else if ((($type|0) == 3)) {
  $647 = ($$sourceidx$0|0)==(-1);
  $648 = ($$destidx$0|0)==(-1);
  $or$cond7 = $647 | $648;
  if (!($or$cond7)) {
   $649 = ((1140384 + (($$sourceidx$0*44)|0)|0) + ($$destidx$0<<2)|0);
   $650 = HEAP32[$649>>2]|0;
   HEAP32[$1>>2] = $650;
   $651 = ($650|0)==(0|0);
   if (!($651)) {
    STACKTOP = sp;return;
   }
  }
  $652 = HEAP32[$dest>>2]|0;
  $653 = $652 & 134217728;
  $654 = ($653|0)==(0);
  $655 = HEAP32[$source>>2]|0;
  $656 = $655 & 134217728;
  $657 = ($656|0)!=(0);
  if (!($654)) {
   $$696 = $657 ? $19 : $16;
   $658 = HEAP32[$$696>>2]|0;
   $659 = ($658|0)==(0);
   if ($659) {
    $660 = (($this) + 8|0);
    HEAP32[$660>>2] = 0;
    $661 = (($this) + 4|0);
    HEAP32[$661>>2] = 0;
    HEAP32[$this>>2] = 0;
   } else {
    $662 = ($658>>>0)>(65535);
    do {
     if ($662) {
      $663 = ($658>>>0)>(16777215);
      if ($663) {
       $664 = $658 >>> 24;
       $$0$i286 = $664;$base$0$i287 = 24;
       break;
      } else {
       $665 = $658 >>> 16;
       $$0$i286 = $665;$base$0$i287 = 16;
       break;
      }
     } else {
      $666 = $658 & 65280;
      $667 = ($666|0)==(0);
      $668 = $658 >>> 8;
      $mask$$i284 = $667 ? $658 : $668;
      $$$i285 = $667 ? 0 : 8;
      $$0$i286 = $mask$$i284;$base$0$i287 = $$$i285;
     }
    } while(0);
    $669 = $$0$i286 & 65280;
    $670 = ($669|0)==(0);
    if ($670) {
     $$1$i288 = $$0$i286;$base$1$i289 = $base$0$i287;
    } else {
     $671 = (($base$0$i287) + 8)|0;
     $672 = $$0$i286 >>> 8;
     $$1$i288 = $672;$base$1$i289 = $671;
    }
    $673 = $$1$i288 & 240;
    $674 = ($673|0)==(0);
    if ($674) {
     $$2$i290 = $$1$i288;$base$2$i291 = $base$1$i289;
    } else {
     $675 = (($base$1$i289) + 4)|0;
     $676 = $$1$i288 >>> 4;
     $$2$i290 = $676;$base$2$i291 = $675;
    }
    $677 = $$2$i290 & 12;
    $678 = ($677|0)==(0);
    if ($678) {
     $$3$i292 = $$2$i290;$base$3$i293 = $base$2$i291;
    } else {
     $679 = (($base$2$i291) + 2)|0;
     $680 = $$2$i290 >>> 2;
     $$3$i292 = $680;$base$3$i293 = $679;
    }
    $681 = $$3$i292 & 2;
    $682 = ($681|0)==(0);
    if ($682) {
     $$4$i294 = $$3$i292;$base$4$i295 = $base$3$i293;
    } else {
     $683 = (($base$3$i293) + 1)|0;
     $684 = $$3$i292 >>> 1;
     $$4$i294 = $684;$base$4$i295 = $683;
    }
    $685 = $$4$i294 & 1;
    $$neg717 = (8 - ($base$4$i295))|0;
    $686 = (($$neg717) - ($685))|0;
    $687 = ($686|0)>(0);
    if ($687) {
     HEAP32[$this>>2] = $686;
     $688 = (($this) + 4|0);
     HEAP32[$688>>2] = 0;
     $692 = 0;$694 = $686;
    } else {
     HEAP32[$this>>2] = 0;
     $689 = (0 - ($686))|0;
     $690 = (($this) + 4|0);
     HEAP32[$690>>2] = $689;
     $692 = $689;$694 = 0;
    }
    $691 = $658 >>> $692;
    $693 = $691 << $694;
    $695 = $693 & 255;
    $696 = (($this) + 8|0);
    HEAP32[$696>>2] = $695;
   }
   $697 = (($this) + 12|0);
   $698 = HEAP32[$source>>2]|0;
   $699 = $698 & 134217728;
   $700 = ($699|0)==(0);
   $$697 = $700 ? $16 : $19;
   $701 = HEAP32[$$697>>2]|0;
   $702 = ($701|0)==(0);
   if ($702) {
    $703 = (($this) + 20|0);
    HEAP32[$703>>2] = 0;
    $704 = (($this) + 16|0);
    HEAP32[$704>>2] = 0;
    HEAP32[$697>>2] = 0;
   } else {
    $705 = ($701>>>0)>(65535);
    do {
     if ($705) {
      $706 = ($701>>>0)>(16777215);
      if ($706) {
       $707 = $701 >>> 24;
       $$0$i261 = $707;$base$0$i262 = 24;
       break;
      } else {
       $708 = $701 >>> 16;
       $$0$i261 = $708;$base$0$i262 = 16;
       break;
      }
     } else {
      $709 = $701 & 65280;
      $710 = ($709|0)==(0);
      $711 = $701 >>> 8;
      $mask$$i259 = $710 ? $701 : $711;
      $$$i260 = $710 ? 0 : 8;
      $$0$i261 = $mask$$i259;$base$0$i262 = $$$i260;
     }
    } while(0);
    $712 = $$0$i261 & 65280;
    $713 = ($712|0)==(0);
    if ($713) {
     $$1$i263 = $$0$i261;$base$1$i264 = $base$0$i262;
    } else {
     $714 = (($base$0$i262) + 8)|0;
     $715 = $$0$i261 >>> 8;
     $$1$i263 = $715;$base$1$i264 = $714;
    }
    $716 = $$1$i263 & 240;
    $717 = ($716|0)==(0);
    if ($717) {
     $$2$i265 = $$1$i263;$base$2$i266 = $base$1$i264;
    } else {
     $718 = (($base$1$i264) + 4)|0;
     $719 = $$1$i263 >>> 4;
     $$2$i265 = $719;$base$2$i266 = $718;
    }
    $720 = $$2$i265 & 12;
    $721 = ($720|0)==(0);
    if ($721) {
     $$3$i267 = $$2$i265;$base$3$i268 = $base$2$i266;
    } else {
     $722 = (($base$2$i266) + 2)|0;
     $723 = $$2$i265 >>> 2;
     $$3$i267 = $723;$base$3$i268 = $722;
    }
    $724 = $$3$i267 & 2;
    $725 = ($724|0)==(0);
    if ($725) {
     $$4$i269 = $$3$i267;$base$4$i270 = $base$3$i268;
    } else {
     $726 = (($base$3$i268) + 1)|0;
     $727 = $$3$i267 >>> 1;
     $$4$i269 = $727;$base$4$i270 = $726;
    }
    $728 = $$4$i269 & 1;
    $$neg719 = (8 - ($base$4$i270))|0;
    $729 = (($$neg719) - ($728))|0;
    $730 = ($729|0)>(0);
    if ($730) {
     HEAP32[$697>>2] = $729;
     $731 = (($this) + 16|0);
     HEAP32[$731>>2] = 0;
     $735 = 0;$737 = $729;
    } else {
     HEAP32[$697>>2] = 0;
     $732 = (0 - ($729))|0;
     $733 = (($this) + 16|0);
     HEAP32[$733>>2] = $732;
     $735 = $732;$737 = 0;
    }
    $734 = $701 >>> $735;
    $736 = $734 << $737;
    $738 = $736 & 255;
    $739 = (($this) + 20|0);
    HEAP32[$739>>2] = $738;
   }
   $740 = (($this) + 24|0);
   $741 = HEAP32[$19>>2]|0;
   $742 = ($741|0)==(0);
   if ($742) {
    $743 = (($this) + 32|0);
    HEAP32[$743>>2] = 0;
    $744 = (($this) + 28|0);
    HEAP32[$744>>2] = 0;
    HEAP32[$740>>2] = 0;
   } else {
    $745 = ($741>>>0)>(65535);
    do {
     if ($745) {
      $746 = ($741>>>0)>(16777215);
      if ($746) {
       $747 = $741 >>> 24;
       $$0$i236 = $747;$base$0$i237 = 24;
       break;
      } else {
       $748 = $741 >>> 16;
       $$0$i236 = $748;$base$0$i237 = 16;
       break;
      }
     } else {
      $749 = $741 & 65280;
      $750 = ($749|0)==(0);
      $751 = $741 >>> 8;
      $mask$$i234 = $750 ? $741 : $751;
      $$$i235 = $750 ? 0 : 8;
      $$0$i236 = $mask$$i234;$base$0$i237 = $$$i235;
     }
    } while(0);
    $752 = $$0$i236 & 65280;
    $753 = ($752|0)==(0);
    if ($753) {
     $$1$i238 = $$0$i236;$base$1$i239 = $base$0$i237;
    } else {
     $754 = (($base$0$i237) + 8)|0;
     $755 = $$0$i236 >>> 8;
     $$1$i238 = $755;$base$1$i239 = $754;
    }
    $756 = $$1$i238 & 240;
    $757 = ($756|0)==(0);
    if ($757) {
     $$2$i240 = $$1$i238;$base$2$i241 = $base$1$i239;
    } else {
     $758 = (($base$1$i239) + 4)|0;
     $759 = $$1$i238 >>> 4;
     $$2$i240 = $759;$base$2$i241 = $758;
    }
    $760 = $$2$i240 & 12;
    $761 = ($760|0)==(0);
    if ($761) {
     $$3$i242 = $$2$i240;$base$3$i243 = $base$2$i241;
    } else {
     $762 = (($base$2$i241) + 2)|0;
     $763 = $$2$i240 >>> 2;
     $$3$i242 = $763;$base$3$i243 = $762;
    }
    $764 = $$3$i242 & 2;
    $765 = ($764|0)==(0);
    if ($765) {
     $$4$i244 = $$3$i242;$base$4$i245 = $base$3$i243;
    } else {
     $766 = (($base$3$i243) + 1)|0;
     $767 = $$3$i242 >>> 1;
     $$4$i244 = $767;$base$4$i245 = $766;
    }
    $768 = $$4$i244 & 1;
    $$neg721 = (8 - ($base$4$i245))|0;
    $769 = (($$neg721) - ($768))|0;
    $770 = ($769|0)>(0);
    if ($770) {
     HEAP32[$740>>2] = $769;
     $771 = (($this) + 28|0);
     HEAP32[$771>>2] = 0;
     $775 = 0;$777 = $769;
    } else {
     HEAP32[$740>>2] = 0;
     $772 = (0 - ($769))|0;
     $773 = (($this) + 28|0);
     HEAP32[$773>>2] = $772;
     $775 = $772;$777 = 0;
    }
    $774 = $741 >>> $775;
    $776 = $774 << $777;
    $778 = $776 & 255;
    $779 = (($this) + 32|0);
    HEAP32[$779>>2] = $778;
   }
   $780 = (($this) + 36|0);
   $781 = HEAP32[$22>>2]|0;
   $782 = HEAP32[$41>>2]|0;
   $783 = ($781|0)==(0);
   $784 = ($782|0)==(0);
   $or$cond$i205 = $783 | $784;
   if ($or$cond$i205) {
    $785 = (($this) + 44|0);
    HEAP32[$785>>2] = 0;
    $786 = (($this) + 40|0);
    HEAP32[$786>>2] = 0;
    HEAP32[$780>>2] = 0;
   } else {
    $787 = ($782>>>0)>(65535);
    do {
     if ($787) {
      $788 = ($782>>>0)>(16777215);
      if ($788) {
       $789 = $782 >>> 24;
       $$0$i222 = $789;$base$0$i223 = 24;
       break;
      } else {
       $790 = $782 >>> 16;
       $$0$i222 = $790;$base$0$i223 = 16;
       break;
      }
     } else {
      $791 = $782 & 65280;
      $792 = ($791|0)==(0);
      $793 = $782 >>> 8;
      $mask$$i220 = $792 ? $782 : $793;
      $$$i221 = $792 ? 0 : 8;
      $$0$i222 = $mask$$i220;$base$0$i223 = $$$i221;
     }
    } while(0);
    $794 = $$0$i222 & 65280;
    $795 = ($794|0)==(0);
    if ($795) {
     $$1$i224 = $$0$i222;$base$1$i225 = $base$0$i223;
    } else {
     $796 = (($base$0$i223) + 8)|0;
     $797 = $$0$i222 >>> 8;
     $$1$i224 = $797;$base$1$i225 = $796;
    }
    $798 = $$1$i224 & 240;
    $799 = ($798|0)==(0);
    if ($799) {
     $$2$i226 = $$1$i224;$base$2$i227 = $base$1$i225;
    } else {
     $800 = (($base$1$i225) + 4)|0;
     $801 = $$1$i224 >>> 4;
     $$2$i226 = $801;$base$2$i227 = $800;
    }
    $802 = $$2$i226 & 12;
    $803 = ($802|0)==(0);
    if ($803) {
     $$3$i228 = $$2$i226;$base$3$i229 = $base$2$i227;
    } else {
     $804 = (($base$2$i227) + 2)|0;
     $805 = $$2$i226 >>> 2;
     $$3$i228 = $805;$base$3$i229 = $804;
    }
    $806 = $$3$i228 & 2;
    $807 = ($806|0)==(0);
    if ($807) {
     $$4$i230 = $$3$i228;$base$4$i231 = $base$3$i229;
    } else {
     $808 = (($base$3$i229) + 1)|0;
     $809 = $$3$i228 >>> 1;
     $$4$i230 = $809;$base$4$i231 = $808;
    }
    $810 = $$4$i230 & 1;
    $811 = ($781>>>0)>(65535);
    do {
     if ($811) {
      $812 = ($781>>>0)>(16777215);
      if ($812) {
       $813 = $781 >>> 24;
       $$0$i209 = $813;$base$0$i210 = 24;
       break;
      } else {
       $814 = $781 >>> 16;
       $$0$i209 = $814;$base$0$i210 = 16;
       break;
      }
     } else {
      $815 = $781 & 65280;
      $816 = ($815|0)==(0);
      $817 = $781 >>> 8;
      $mask$$i207 = $816 ? $781 : $817;
      $$$i208 = $816 ? 0 : 8;
      $$0$i209 = $mask$$i207;$base$0$i210 = $$$i208;
     }
    } while(0);
    $818 = $$0$i209 & 65280;
    $819 = ($818|0)==(0);
    if ($819) {
     $$1$i211 = $$0$i209;$base$1$i212 = $base$0$i210;
    } else {
     $820 = (($base$0$i210) + 8)|0;
     $821 = $$0$i209 >>> 8;
     $$1$i211 = $821;$base$1$i212 = $820;
    }
    $822 = $$1$i211 & 240;
    $823 = ($822|0)==(0);
    if ($823) {
     $$2$i213 = $$1$i211;$base$2$i214 = $base$1$i212;
    } else {
     $824 = (($base$1$i212) + 4)|0;
     $825 = $$1$i211 >>> 4;
     $$2$i213 = $825;$base$2$i214 = $824;
    }
    $826 = $$2$i213 & 12;
    $827 = ($826|0)==(0);
    if ($827) {
     $$3$i215 = $$2$i213;$base$3$i216 = $base$2$i214;
    } else {
     $828 = (($base$2$i214) + 2)|0;
     $829 = $$2$i213 >>> 2;
     $$3$i215 = $829;$base$3$i216 = $828;
    }
    $830 = $$3$i215 & 2;
    $831 = ($830|0)==(0);
    if ($831) {
     $$4$i217 = $$3$i215;$base$4$i218 = $base$3$i216;
    } else {
     $832 = (($base$3$i216) + 1)|0;
     $833 = $$3$i215 >>> 1;
     $$4$i217 = $833;$base$4$i218 = $832;
    }
    $834 = $$4$i217 & 1;
    $835 = (($810) + ($base$4$i231))|0;
    $836 = (($835) - ($base$4$i218))|0;
    $837 = (($836) - ($834))|0;
    $838 = ($837|0)>(0);
    if ($838) {
     HEAP32[$780>>2] = $837;
     $839 = (($this) + 40|0);
     HEAP32[$839>>2] = 0;
     $843 = 0;$845 = $837;
    } else {
     HEAP32[$780>>2] = 0;
     $840 = (0 - ($837))|0;
     $841 = (($this) + 40|0);
     HEAP32[$841>>2] = $840;
     $843 = $840;$845 = 0;
    }
    $842 = $781 >>> $843;
    $844 = $842 << $845;
    $846 = $844 & $782;
    $847 = (($this) + 44|0);
    HEAP32[$847>>2] = $846;
   }
   $848 = (($this) + 60|0);
   $849 = HEAP32[$38>>2]|0;
   $850 = ($849|0)==(0);
   if ($850) {
    $851 = (($this) + 68|0);
    HEAP32[$851>>2] = 0;
    $852 = (($this) + 64|0);
    HEAP32[$852>>2] = 0;
    HEAP32[$848>>2] = 0;
   } else {
    $853 = ($849>>>0)>(65535);
    do {
     if ($853) {
      $854 = ($849>>>0)>(16777215);
      if ($854) {
       $855 = $849 >>> 24;
       $$0$i194 = $855;$base$0$i195 = 24;
       break;
      } else {
       $856 = $849 >>> 16;
       $$0$i194 = $856;$base$0$i195 = 16;
       break;
      }
     } else {
      $857 = $849 & 65280;
      $858 = ($857|0)==(0);
      $859 = $849 >>> 8;
      $mask$$i192 = $858 ? $849 : $859;
      $$$i193 = $858 ? 0 : 8;
      $$0$i194 = $mask$$i192;$base$0$i195 = $$$i193;
     }
    } while(0);
    $860 = $$0$i194 & 65280;
    $861 = ($860|0)==(0);
    if ($861) {
     $$1$i196 = $$0$i194;$base$1$i197 = $base$0$i195;
    } else {
     $862 = (($base$0$i195) + 8)|0;
     $863 = $$0$i194 >>> 8;
     $$1$i196 = $863;$base$1$i197 = $862;
    }
    $864 = $$1$i196 & 240;
    $865 = ($864|0)==(0);
    if ($865) {
     $$2$i198 = $$1$i196;$base$2$i199 = $base$1$i197;
    } else {
     $866 = (($base$1$i197) + 4)|0;
     $867 = $$1$i196 >>> 4;
     $$2$i198 = $867;$base$2$i199 = $866;
    }
    $868 = $$2$i198 & 12;
    $869 = ($868|0)==(0);
    if ($869) {
     $$3$i200 = $$2$i198;$base$3$i201 = $base$2$i199;
    } else {
     $870 = (($base$2$i199) + 2)|0;
     $871 = $$2$i198 >>> 2;
     $$3$i200 = $871;$base$3$i201 = $870;
    }
    $872 = $$3$i200 & 2;
    $873 = ($872|0)==(0);
    if ($873) {
     $$4$i202 = $$3$i200;$base$4$i203 = $base$3$i201;
    } else {
     $874 = (($base$3$i201) + 1)|0;
     $875 = $$3$i200 >>> 1;
     $$4$i202 = $875;$base$4$i203 = $874;
    }
    $876 = $$4$i202 & 1;
    $877 = (($base$4$i203) + -8)|0;
    $878 = (($877) + ($876))|0;
    $879 = ($878|0)>(0);
    if ($879) {
     HEAP32[$848>>2] = $878;
     $880 = (($this) + 64|0);
     HEAP32[$880>>2] = 0;
     $884 = 0;$886 = $878;
    } else {
     HEAP32[$848>>2] = 0;
     $881 = (0 - ($878))|0;
     $882 = (($this) + 64|0);
     HEAP32[$882>>2] = $881;
     $884 = $881;$886 = 0;
    }
    $883 = 255 >>> $884;
    $885 = $883 << $886;
    $887 = $885 & $849;
    $888 = (($this) + 68|0);
    HEAP32[$888>>2] = $887;
   }
   $889 = HEAP32[$22>>2]|0;
   $not$4 = ($889|0)==(0);
   $890 = HEAP32[$41>>2]|0;
   $891 = $not$4 ? $890 : 0;
   $892 = (($this) + 72|0);
   HEAP32[$892>>2] = $891;
   $893 = HEAP32[$dest>>2]|0;
   $894 = $893 >>> 3;
   $895 = $894 & 8191;
   $896 = (($895) + -1)|0;
   $897 = HEAP32[$source>>2]|0;
   $898 = $897 >>> 3;
   $899 = $898 & 8191;
   $900 = (($899) + -1)|0;
   $901 = ((1140872 + ($900<<4)|0) + ($896<<2)|0);
   $902 = HEAP32[$901>>2]|0;
   HEAP32[$1>>2] = $902;
   STACKTOP = sp;return;
  }
  $$698 = $657 ? $19 : $13;
  $903 = HEAP32[$$698>>2]|0;
  $904 = ($903|0)==(0);
  $905 = ($73|0)==(0);
  $or$cond$i152 = $904 | $905;
  if ($or$cond$i152) {
   $906 = (($this) + 8|0);
   HEAP32[$906>>2] = 0;
   $907 = (($this) + 4|0);
   HEAP32[$907>>2] = 0;
   HEAP32[$this>>2] = 0;
  } else {
   $908 = ($73>>>0)>(65535);
   do {
    if ($908) {
     $909 = ($73>>>0)>(16777215);
     if ($909) {
      $910 = $73 >>> 24;
      $$0$i169 = $910;$base$0$i170 = 24;
      break;
     } else {
      $911 = $73 >>> 16;
      $$0$i169 = $911;$base$0$i170 = 16;
      break;
     }
    } else {
     $912 = $73 & 65280;
     $913 = ($912|0)==(0);
     $914 = $73 >>> 8;
     $mask$$i167 = $913 ? $73 : $914;
     $$$i168 = $913 ? 0 : 8;
     $$0$i169 = $mask$$i167;$base$0$i170 = $$$i168;
    }
   } while(0);
   $915 = $$0$i169 & 65280;
   $916 = ($915|0)==(0);
   if ($916) {
    $$1$i171 = $$0$i169;$base$1$i172 = $base$0$i170;
   } else {
    $917 = (($base$0$i170) + 8)|0;
    $918 = $$0$i169 >>> 8;
    $$1$i171 = $918;$base$1$i172 = $917;
   }
   $919 = $$1$i171 & 240;
   $920 = ($919|0)==(0);
   if ($920) {
    $$2$i173 = $$1$i171;$base$2$i174 = $base$1$i172;
   } else {
    $921 = (($base$1$i172) + 4)|0;
    $922 = $$1$i171 >>> 4;
    $$2$i173 = $922;$base$2$i174 = $921;
   }
   $923 = $$2$i173 & 12;
   $924 = ($923|0)==(0);
   if ($924) {
    $$3$i175 = $$2$i173;$base$3$i176 = $base$2$i174;
   } else {
    $925 = (($base$2$i174) + 2)|0;
    $926 = $$2$i173 >>> 2;
    $$3$i175 = $926;$base$3$i176 = $925;
   }
   $927 = $$3$i175 & 2;
   $928 = ($927|0)==(0);
   if ($928) {
    $$4$i177 = $$3$i175;$base$4$i178 = $base$3$i176;
   } else {
    $929 = (($base$3$i176) + 1)|0;
    $930 = $$3$i175 >>> 1;
    $$4$i177 = $930;$base$4$i178 = $929;
   }
   $931 = $$4$i177 & 1;
   $932 = ($903>>>0)>(65535);
   do {
    if ($932) {
     $933 = ($903>>>0)>(16777215);
     if ($933) {
      $934 = $903 >>> 24;
      $$0$i156 = $934;$base$0$i157 = 24;
      break;
     } else {
      $935 = $903 >>> 16;
      $$0$i156 = $935;$base$0$i157 = 16;
      break;
     }
    } else {
     $936 = $903 & 65280;
     $937 = ($936|0)==(0);
     $938 = $903 >>> 8;
     $mask$$i154 = $937 ? $903 : $938;
     $$$i155 = $937 ? 0 : 8;
     $$0$i156 = $mask$$i154;$base$0$i157 = $$$i155;
    }
   } while(0);
   $939 = $$0$i156 & 65280;
   $940 = ($939|0)==(0);
   if ($940) {
    $$1$i158 = $$0$i156;$base$1$i159 = $base$0$i157;
   } else {
    $941 = (($base$0$i157) + 8)|0;
    $942 = $$0$i156 >>> 8;
    $$1$i158 = $942;$base$1$i159 = $941;
   }
   $943 = $$1$i158 & 240;
   $944 = ($943|0)==(0);
   if ($944) {
    $$2$i160 = $$1$i158;$base$2$i161 = $base$1$i159;
   } else {
    $945 = (($base$1$i159) + 4)|0;
    $946 = $$1$i158 >>> 4;
    $$2$i160 = $946;$base$2$i161 = $945;
   }
   $947 = $$2$i160 & 12;
   $948 = ($947|0)==(0);
   if ($948) {
    $$3$i162 = $$2$i160;$base$3$i163 = $base$2$i161;
   } else {
    $949 = (($base$2$i161) + 2)|0;
    $950 = $$2$i160 >>> 2;
    $$3$i162 = $950;$base$3$i163 = $949;
   }
   $951 = $$3$i162 & 2;
   $952 = ($951|0)==(0);
   if ($952) {
    $$4$i164 = $$3$i162;$base$4$i165 = $base$3$i163;
   } else {
    $953 = (($base$3$i163) + 1)|0;
    $954 = $$3$i162 >>> 1;
    $$4$i164 = $954;$base$4$i165 = $953;
   }
   $955 = $$4$i164 & 1;
   $956 = (($931) + ($base$4$i178))|0;
   $957 = (($956) - ($base$4$i165))|0;
   $958 = (($957) - ($955))|0;
   $959 = ($958|0)>(0);
   if ($959) {
    HEAP32[$this>>2] = $958;
    $960 = (($this) + 4|0);
    HEAP32[$960>>2] = 0;
    $964 = 0;$966 = $958;
   } else {
    HEAP32[$this>>2] = 0;
    $961 = (0 - ($958))|0;
    $962 = (($this) + 4|0);
    HEAP32[$962>>2] = $961;
    $964 = $961;$966 = 0;
   }
   $963 = $903 >>> $964;
   $965 = $963 << $966;
   $967 = $965 & $73;
   $968 = (($this) + 8|0);
   HEAP32[$968>>2] = $967;
  }
  $969 = (($this) + 12|0);
  $970 = HEAP32[$source>>2]|0;
  $971 = $970 & 134217728;
  $972 = ($971|0)==(0);
  $$699 = $972 ? $16 : $19;
  $973 = HEAP32[$$699>>2]|0;
  $974 = HEAP32[$35>>2]|0;
  $975 = ($973|0)==(0);
  $976 = ($974|0)==(0);
  $or$cond$i124 = $975 | $976;
  if ($or$cond$i124) {
   $977 = (($this) + 20|0);
   HEAP32[$977>>2] = 0;
   $978 = (($this) + 16|0);
   HEAP32[$978>>2] = 0;
   HEAP32[$969>>2] = 0;
  } else {
   $979 = ($974>>>0)>(65535);
   do {
    if ($979) {
     $980 = ($974>>>0)>(16777215);
     if ($980) {
      $981 = $974 >>> 24;
      $$0$i141 = $981;$base$0$i142 = 24;
      break;
     } else {
      $982 = $974 >>> 16;
      $$0$i141 = $982;$base$0$i142 = 16;
      break;
     }
    } else {
     $983 = $974 & 65280;
     $984 = ($983|0)==(0);
     $985 = $974 >>> 8;
     $mask$$i139 = $984 ? $974 : $985;
     $$$i140 = $984 ? 0 : 8;
     $$0$i141 = $mask$$i139;$base$0$i142 = $$$i140;
    }
   } while(0);
   $986 = $$0$i141 & 65280;
   $987 = ($986|0)==(0);
   if ($987) {
    $$1$i143 = $$0$i141;$base$1$i144 = $base$0$i142;
   } else {
    $988 = (($base$0$i142) + 8)|0;
    $989 = $$0$i141 >>> 8;
    $$1$i143 = $989;$base$1$i144 = $988;
   }
   $990 = $$1$i143 & 240;
   $991 = ($990|0)==(0);
   if ($991) {
    $$2$i145 = $$1$i143;$base$2$i146 = $base$1$i144;
   } else {
    $992 = (($base$1$i144) + 4)|0;
    $993 = $$1$i143 >>> 4;
    $$2$i145 = $993;$base$2$i146 = $992;
   }
   $994 = $$2$i145 & 12;
   $995 = ($994|0)==(0);
   if ($995) {
    $$3$i147 = $$2$i145;$base$3$i148 = $base$2$i146;
   } else {
    $996 = (($base$2$i146) + 2)|0;
    $997 = $$2$i145 >>> 2;
    $$3$i147 = $997;$base$3$i148 = $996;
   }
   $998 = $$3$i147 & 2;
   $999 = ($998|0)==(0);
   if ($999) {
    $$4$i149 = $$3$i147;$base$4$i150 = $base$3$i148;
   } else {
    $1000 = (($base$3$i148) + 1)|0;
    $1001 = $$3$i147 >>> 1;
    $$4$i149 = $1001;$base$4$i150 = $1000;
   }
   $1002 = $$4$i149 & 1;
   $1003 = ($973>>>0)>(65535);
   do {
    if ($1003) {
     $1004 = ($973>>>0)>(16777215);
     if ($1004) {
      $1005 = $973 >>> 24;
      $$0$i128 = $1005;$base$0$i129 = 24;
      break;
     } else {
      $1006 = $973 >>> 16;
      $$0$i128 = $1006;$base$0$i129 = 16;
      break;
     }
    } else {
     $1007 = $973 & 65280;
     $1008 = ($1007|0)==(0);
     $1009 = $973 >>> 8;
     $mask$$i126 = $1008 ? $973 : $1009;
     $$$i127 = $1008 ? 0 : 8;
     $$0$i128 = $mask$$i126;$base$0$i129 = $$$i127;
    }
   } while(0);
   $1010 = $$0$i128 & 65280;
   $1011 = ($1010|0)==(0);
   if ($1011) {
    $$1$i130 = $$0$i128;$base$1$i131 = $base$0$i129;
   } else {
    $1012 = (($base$0$i129) + 8)|0;
    $1013 = $$0$i128 >>> 8;
    $$1$i130 = $1013;$base$1$i131 = $1012;
   }
   $1014 = $$1$i130 & 240;
   $1015 = ($1014|0)==(0);
   if ($1015) {
    $$2$i132 = $$1$i130;$base$2$i133 = $base$1$i131;
   } else {
    $1016 = (($base$1$i131) + 4)|0;
    $1017 = $$1$i130 >>> 4;
    $$2$i132 = $1017;$base$2$i133 = $1016;
   }
   $1018 = $$2$i132 & 12;
   $1019 = ($1018|0)==(0);
   if ($1019) {
    $$3$i134 = $$2$i132;$base$3$i135 = $base$2$i133;
   } else {
    $1020 = (($base$2$i133) + 2)|0;
    $1021 = $$2$i132 >>> 2;
    $$3$i134 = $1021;$base$3$i135 = $1020;
   }
   $1022 = $$3$i134 & 2;
   $1023 = ($1022|0)==(0);
   if ($1023) {
    $$4$i136 = $$3$i134;$base$4$i137 = $base$3$i135;
   } else {
    $1024 = (($base$3$i135) + 1)|0;
    $1025 = $$3$i134 >>> 1;
    $$4$i136 = $1025;$base$4$i137 = $1024;
   }
   $1026 = $$4$i136 & 1;
   $1027 = (($1002) + ($base$4$i150))|0;
   $1028 = (($1027) - ($base$4$i137))|0;
   $1029 = (($1028) - ($1026))|0;
   $1030 = ($1029|0)>(0);
   if ($1030) {
    HEAP32[$969>>2] = $1029;
    $1031 = (($this) + 16|0);
    HEAP32[$1031>>2] = 0;
    $1035 = 0;$1037 = $1029;
   } else {
    HEAP32[$969>>2] = 0;
    $1032 = (0 - ($1029))|0;
    $1033 = (($this) + 16|0);
    HEAP32[$1033>>2] = $1032;
    $1035 = $1032;$1037 = 0;
   }
   $1034 = $973 >>> $1035;
   $1036 = $1034 << $1037;
   $1038 = $1036 & $974;
   $1039 = (($this) + 20|0);
   HEAP32[$1039>>2] = $1038;
  }
  $1040 = (($this) + 24|0);
  $1041 = HEAP32[$19>>2]|0;
  $1042 = HEAP32[$38>>2]|0;
  $1043 = ($1041|0)==(0);
  $1044 = ($1042|0)==(0);
  $or$cond$i96 = $1043 | $1044;
  if ($or$cond$i96) {
   $1045 = (($this) + 32|0);
   HEAP32[$1045>>2] = 0;
   $1046 = (($this) + 28|0);
   HEAP32[$1046>>2] = 0;
   HEAP32[$1040>>2] = 0;
  } else {
   $1047 = ($1042>>>0)>(65535);
   do {
    if ($1047) {
     $1048 = ($1042>>>0)>(16777215);
     if ($1048) {
      $1049 = $1042 >>> 24;
      $$0$i113 = $1049;$base$0$i114 = 24;
      break;
     } else {
      $1050 = $1042 >>> 16;
      $$0$i113 = $1050;$base$0$i114 = 16;
      break;
     }
    } else {
     $1051 = $1042 & 65280;
     $1052 = ($1051|0)==(0);
     $1053 = $1042 >>> 8;
     $mask$$i111 = $1052 ? $1042 : $1053;
     $$$i112 = $1052 ? 0 : 8;
     $$0$i113 = $mask$$i111;$base$0$i114 = $$$i112;
    }
   } while(0);
   $1054 = $$0$i113 & 65280;
   $1055 = ($1054|0)==(0);
   if ($1055) {
    $$1$i115 = $$0$i113;$base$1$i116 = $base$0$i114;
   } else {
    $1056 = (($base$0$i114) + 8)|0;
    $1057 = $$0$i113 >>> 8;
    $$1$i115 = $1057;$base$1$i116 = $1056;
   }
   $1058 = $$1$i115 & 240;
   $1059 = ($1058|0)==(0);
   if ($1059) {
    $$2$i117 = $$1$i115;$base$2$i118 = $base$1$i116;
   } else {
    $1060 = (($base$1$i116) + 4)|0;
    $1061 = $$1$i115 >>> 4;
    $$2$i117 = $1061;$base$2$i118 = $1060;
   }
   $1062 = $$2$i117 & 12;
   $1063 = ($1062|0)==(0);
   if ($1063) {
    $$3$i119 = $$2$i117;$base$3$i120 = $base$2$i118;
   } else {
    $1064 = (($base$2$i118) + 2)|0;
    $1065 = $$2$i117 >>> 2;
    $$3$i119 = $1065;$base$3$i120 = $1064;
   }
   $1066 = $$3$i119 & 2;
   $1067 = ($1066|0)==(0);
   if ($1067) {
    $$4$i121 = $$3$i119;$base$4$i122 = $base$3$i120;
   } else {
    $1068 = (($base$3$i120) + 1)|0;
    $1069 = $$3$i119 >>> 1;
    $$4$i121 = $1069;$base$4$i122 = $1068;
   }
   $1070 = $$4$i121 & 1;
   $1071 = ($1041>>>0)>(65535);
   do {
    if ($1071) {
     $1072 = ($1041>>>0)>(16777215);
     if ($1072) {
      $1073 = $1041 >>> 24;
      $$0$i100 = $1073;$base$0$i101 = 24;
      break;
     } else {
      $1074 = $1041 >>> 16;
      $$0$i100 = $1074;$base$0$i101 = 16;
      break;
     }
    } else {
     $1075 = $1041 & 65280;
     $1076 = ($1075|0)==(0);
     $1077 = $1041 >>> 8;
     $mask$$i98 = $1076 ? $1041 : $1077;
     $$$i99 = $1076 ? 0 : 8;
     $$0$i100 = $mask$$i98;$base$0$i101 = $$$i99;
    }
   } while(0);
   $1078 = $$0$i100 & 65280;
   $1079 = ($1078|0)==(0);
   if ($1079) {
    $$1$i102 = $$0$i100;$base$1$i103 = $base$0$i101;
   } else {
    $1080 = (($base$0$i101) + 8)|0;
    $1081 = $$0$i100 >>> 8;
    $$1$i102 = $1081;$base$1$i103 = $1080;
   }
   $1082 = $$1$i102 & 240;
   $1083 = ($1082|0)==(0);
   if ($1083) {
    $$2$i104 = $$1$i102;$base$2$i105 = $base$1$i103;
   } else {
    $1084 = (($base$1$i103) + 4)|0;
    $1085 = $$1$i102 >>> 4;
    $$2$i104 = $1085;$base$2$i105 = $1084;
   }
   $1086 = $$2$i104 & 12;
   $1087 = ($1086|0)==(0);
   if ($1087) {
    $$3$i106 = $$2$i104;$base$3$i107 = $base$2$i105;
   } else {
    $1088 = (($base$2$i105) + 2)|0;
    $1089 = $$2$i104 >>> 2;
    $$3$i106 = $1089;$base$3$i107 = $1088;
   }
   $1090 = $$3$i106 & 2;
   $1091 = ($1090|0)==(0);
   if ($1091) {
    $$4$i108 = $$3$i106;$base$4$i109 = $base$3$i107;
   } else {
    $1092 = (($base$3$i107) + 1)|0;
    $1093 = $$3$i106 >>> 1;
    $$4$i108 = $1093;$base$4$i109 = $1092;
   }
   $1094 = $$4$i108 & 1;
   $1095 = (($1070) + ($base$4$i122))|0;
   $1096 = (($1095) - ($base$4$i109))|0;
   $1097 = (($1096) - ($1094))|0;
   $1098 = ($1097|0)>(0);
   if ($1098) {
    HEAP32[$1040>>2] = $1097;
    $1099 = (($this) + 28|0);
    HEAP32[$1099>>2] = 0;
    $1103 = 0;$1105 = $1097;
   } else {
    HEAP32[$1040>>2] = 0;
    $1100 = (0 - ($1097))|0;
    $1101 = (($this) + 28|0);
    HEAP32[$1101>>2] = $1100;
    $1103 = $1100;$1105 = 0;
   }
   $1102 = $1041 >>> $1103;
   $1104 = $1102 << $1105;
   $1106 = $1104 & $1042;
   $1107 = (($this) + 32|0);
   HEAP32[$1107>>2] = $1106;
  }
  $1108 = (($this) + 36|0);
  $1109 = HEAP32[$22>>2]|0;
  $1110 = HEAP32[$41>>2]|0;
  $1111 = ($1109|0)==(0);
  $1112 = ($1110|0)==(0);
  $or$cond$i = $1111 | $1112;
  if ($or$cond$i) {
   $1113 = (($this) + 44|0);
   HEAP32[$1113>>2] = 0;
   $1114 = (($this) + 40|0);
   HEAP32[$1114>>2] = 0;
   HEAP32[$1108>>2] = 0;
  } else {
   $1115 = ($1110>>>0)>(65535);
   do {
    if ($1115) {
     $1116 = ($1110>>>0)>(16777215);
     if ($1116) {
      $1117 = $1110 >>> 24;
      $$0$i85 = $1117;$base$0$i86 = 24;
      break;
     } else {
      $1118 = $1110 >>> 16;
      $$0$i85 = $1118;$base$0$i86 = 16;
      break;
     }
    } else {
     $1119 = $1110 & 65280;
     $1120 = ($1119|0)==(0);
     $1121 = $1110 >>> 8;
     $mask$$i83 = $1120 ? $1110 : $1121;
     $$$i84 = $1120 ? 0 : 8;
     $$0$i85 = $mask$$i83;$base$0$i86 = $$$i84;
    }
   } while(0);
   $1122 = $$0$i85 & 65280;
   $1123 = ($1122|0)==(0);
   if ($1123) {
    $$1$i87 = $$0$i85;$base$1$i88 = $base$0$i86;
   } else {
    $1124 = (($base$0$i86) + 8)|0;
    $1125 = $$0$i85 >>> 8;
    $$1$i87 = $1125;$base$1$i88 = $1124;
   }
   $1126 = $$1$i87 & 240;
   $1127 = ($1126|0)==(0);
   if ($1127) {
    $$2$i89 = $$1$i87;$base$2$i90 = $base$1$i88;
   } else {
    $1128 = (($base$1$i88) + 4)|0;
    $1129 = $$1$i87 >>> 4;
    $$2$i89 = $1129;$base$2$i90 = $1128;
   }
   $1130 = $$2$i89 & 12;
   $1131 = ($1130|0)==(0);
   if ($1131) {
    $$3$i91 = $$2$i89;$base$3$i92 = $base$2$i90;
   } else {
    $1132 = (($base$2$i90) + 2)|0;
    $1133 = $$2$i89 >>> 2;
    $$3$i91 = $1133;$base$3$i92 = $1132;
   }
   $1134 = $$3$i91 & 2;
   $1135 = ($1134|0)==(0);
   if ($1135) {
    $$4$i93 = $$3$i91;$base$4$i94 = $base$3$i92;
   } else {
    $1136 = (($base$3$i92) + 1)|0;
    $1137 = $$3$i91 >>> 1;
    $$4$i93 = $1137;$base$4$i94 = $1136;
   }
   $1138 = $$4$i93 & 1;
   $1139 = ($1109>>>0)>(65535);
   do {
    if ($1139) {
     $1140 = ($1109>>>0)>(16777215);
     if ($1140) {
      $1141 = $1109 >>> 24;
      $$0$i = $1141;$base$0$i = 24;
      break;
     } else {
      $1142 = $1109 >>> 16;
      $$0$i = $1142;$base$0$i = 16;
      break;
     }
    } else {
     $1143 = $1109 & 65280;
     $1144 = ($1143|0)==(0);
     $1145 = $1109 >>> 8;
     $mask$$i = $1144 ? $1109 : $1145;
     $$$i = $1144 ? 0 : 8;
     $$0$i = $mask$$i;$base$0$i = $$$i;
    }
   } while(0);
   $1146 = $$0$i & 65280;
   $1147 = ($1146|0)==(0);
   if ($1147) {
    $$1$i = $$0$i;$base$1$i = $base$0$i;
   } else {
    $1148 = (($base$0$i) + 8)|0;
    $1149 = $$0$i >>> 8;
    $$1$i = $1149;$base$1$i = $1148;
   }
   $1150 = $$1$i & 240;
   $1151 = ($1150|0)==(0);
   if ($1151) {
    $$2$i = $$1$i;$base$2$i = $base$1$i;
   } else {
    $1152 = (($base$1$i) + 4)|0;
    $1153 = $$1$i >>> 4;
    $$2$i = $1153;$base$2$i = $1152;
   }
   $1154 = $$2$i & 12;
   $1155 = ($1154|0)==(0);
   if ($1155) {
    $$3$i = $$2$i;$base$3$i = $base$2$i;
   } else {
    $1156 = (($base$2$i) + 2)|0;
    $1157 = $$2$i >>> 2;
    $$3$i = $1157;$base$3$i = $1156;
   }
   $1158 = $$3$i & 2;
   $1159 = ($1158|0)==(0);
   if ($1159) {
    $$4$i = $$3$i;$base$4$i = $base$3$i;
   } else {
    $1160 = (($base$3$i) + 1)|0;
    $1161 = $$3$i >>> 1;
    $$4$i = $1161;$base$4$i = $1160;
   }
   $1162 = $$4$i & 1;
   $1163 = (($1138) + ($base$4$i94))|0;
   $1164 = (($1163) - ($base$4$i))|0;
   $1165 = (($1164) - ($1162))|0;
   $1166 = ($1165|0)>(0);
   if ($1166) {
    HEAP32[$1108>>2] = $1165;
    $1167 = (($this) + 40|0);
    HEAP32[$1167>>2] = 0;
    $1171 = 0;$1173 = $1165;
   } else {
    HEAP32[$1108>>2] = 0;
    $1168 = (0 - ($1165))|0;
    $1169 = (($this) + 40|0);
    HEAP32[$1169>>2] = $1168;
    $1171 = $1168;$1173 = 0;
   }
   $1170 = $1109 >>> $1171;
   $1172 = $1170 << $1173;
   $1174 = $1172 & $1110;
   $1175 = (($this) + 44|0);
   HEAP32[$1175>>2] = $1174;
  }
  $1176 = HEAP32[$22>>2]|0;
  $not$ = ($1176|0)==(0);
  $1177 = HEAP32[$41>>2]|0;
  $1178 = $not$ ? $1177 : 0;
  $1179 = (($this) + 72|0);
  HEAP32[$1179>>2] = $1178;
  $1180 = HEAP32[$dest>>2]|0;
  $1181 = $1180 >>> 3;
  $1182 = $1181 & 8191;
  $1183 = (($1182) + -1)|0;
  $1184 = HEAP32[$source>>2]|0;
  $1185 = $1184 >>> 3;
  $1186 = $1185 & 8191;
  $1187 = (($1186) + -1)|0;
  $1188 = ((1140936 + ($1187<<4)|0) + ($1183<<2)|0);
  $1189 = HEAP32[$1188>>2]|0;
  HEAP32[$1>>2] = $1189;
  STACKTOP = sp;return;
 } else if ((($type|0) == 2)) {
  $96 = ($$sourceidx$0|0)==(-1);
  $97 = ($$destidx$0|0)==(-1);
  $or$cond = $96 | $97;
  if (!($or$cond)) {
   $98 = ((1139736 + (($$sourceidx$0*44)|0)|0) + ($$destidx$0<<2)|0);
   $99 = HEAP32[$98>>2]|0;
   HEAP32[$1>>2] = $99;
   $100 = ($99|0)==(0|0);
   if (!($100)) {
    STACKTOP = sp;return;
   }
  }
  $101 = HEAP32[$dest>>2]|0;
  $102 = $101 & 134217728;
  $103 = ($102|0)==(0);
  $104 = HEAP32[$source>>2]|0;
  $105 = $104 & 134217728;
  $106 = ($105|0)!=(0);
  $$694 = $106 ? $19 : $13;
  $107 = HEAP32[$$694>>2]|0;
  $108 = ($107|0)==(0);
  if (!($103)) {
   if ($108) {
    $109 = (($this) + 8|0);
    HEAP32[$109>>2] = 0;
    $110 = (($this) + 4|0);
    HEAP32[$110>>2] = 0;
    HEAP32[$this>>2] = 0;
   } else {
    $111 = ($107>>>0)>(65535);
    do {
     if ($111) {
      $112 = ($107>>>0)>(16777215);
      if ($112) {
       $113 = $107 >>> 24;
       $$0$i526 = $113;$base$0$i527 = 24;
       break;
      } else {
       $114 = $107 >>> 16;
       $$0$i526 = $114;$base$0$i527 = 16;
       break;
      }
     } else {
      $115 = $107 & 65280;
      $116 = ($115|0)==(0);
      $117 = $107 >>> 8;
      $mask$$i524 = $116 ? $107 : $117;
      $$$i525 = $116 ? 0 : 8;
      $$0$i526 = $mask$$i524;$base$0$i527 = $$$i525;
     }
    } while(0);
    $118 = $$0$i526 & 65280;
    $119 = ($118|0)==(0);
    if ($119) {
     $$1$i528 = $$0$i526;$base$1$i529 = $base$0$i527;
    } else {
     $120 = (($base$0$i527) + 8)|0;
     $121 = $$0$i526 >>> 8;
     $$1$i528 = $121;$base$1$i529 = $120;
    }
    $122 = $$1$i528 & 240;
    $123 = ($122|0)==(0);
    if ($123) {
     $$2$i530 = $$1$i528;$base$2$i531 = $base$1$i529;
    } else {
     $124 = (($base$1$i529) + 4)|0;
     $125 = $$1$i528 >>> 4;
     $$2$i530 = $125;$base$2$i531 = $124;
    }
    $126 = $$2$i530 & 12;
    $127 = ($126|0)==(0);
    if ($127) {
     $$3$i532 = $$2$i530;$base$3$i533 = $base$2$i531;
    } else {
     $128 = (($base$2$i531) + 2)|0;
     $129 = $$2$i530 >>> 2;
     $$3$i532 = $129;$base$3$i533 = $128;
    }
    $130 = $$3$i532 & 2;
    $131 = ($130|0)==(0);
    if ($131) {
     $$4$i534 = $$3$i532;$base$4$i535 = $base$3$i533;
    } else {
     $132 = (($base$3$i533) + 1)|0;
     $133 = $$3$i532 >>> 1;
     $$4$i534 = $133;$base$4$i535 = $132;
    }
    $134 = $$4$i534 & 1;
    $$neg701 = (8 - ($base$4$i535))|0;
    $135 = (($$neg701) - ($134))|0;
    $136 = ($135|0)>(0);
    if ($136) {
     HEAP32[$this>>2] = $135;
     $137 = (($this) + 4|0);
     HEAP32[$137>>2] = 0;
     $141 = 0;$143 = $135;
    } else {
     HEAP32[$this>>2] = 0;
     $138 = (0 - ($135))|0;
     $139 = (($this) + 4|0);
     HEAP32[$139>>2] = $138;
     $141 = $138;$143 = 0;
    }
    $140 = $107 >>> $141;
    $142 = $140 << $143;
    $144 = $142 & 255;
    $145 = (($this) + 8|0);
    HEAP32[$145>>2] = $144;
   }
   $146 = (($this) + 12|0);
   $147 = HEAP32[$source>>2]|0;
   $148 = $147 & 134217728;
   $149 = ($148|0)==(0);
   $$693 = $149 ? $16 : $19;
   $150 = HEAP32[$$693>>2]|0;
   $151 = ($150|0)==(0);
   if ($151) {
    $152 = (($this) + 20|0);
    HEAP32[$152>>2] = 0;
    $153 = (($this) + 16|0);
    HEAP32[$153>>2] = 0;
    HEAP32[$146>>2] = 0;
   } else {
    $154 = ($150>>>0)>(65535);
    do {
     if ($154) {
      $155 = ($150>>>0)>(16777215);
      if ($155) {
       $156 = $150 >>> 24;
       $$0$i501 = $156;$base$0$i502 = 24;
       break;
      } else {
       $157 = $150 >>> 16;
       $$0$i501 = $157;$base$0$i502 = 16;
       break;
      }
     } else {
      $158 = $150 & 65280;
      $159 = ($158|0)==(0);
      $160 = $150 >>> 8;
      $mask$$i499 = $159 ? $150 : $160;
      $$$i500 = $159 ? 0 : 8;
      $$0$i501 = $mask$$i499;$base$0$i502 = $$$i500;
     }
    } while(0);
    $161 = $$0$i501 & 65280;
    $162 = ($161|0)==(0);
    if ($162) {
     $$1$i503 = $$0$i501;$base$1$i504 = $base$0$i502;
    } else {
     $163 = (($base$0$i502) + 8)|0;
     $164 = $$0$i501 >>> 8;
     $$1$i503 = $164;$base$1$i504 = $163;
    }
    $165 = $$1$i503 & 240;
    $166 = ($165|0)==(0);
    if ($166) {
     $$2$i505 = $$1$i503;$base$2$i506 = $base$1$i504;
    } else {
     $167 = (($base$1$i504) + 4)|0;
     $168 = $$1$i503 >>> 4;
     $$2$i505 = $168;$base$2$i506 = $167;
    }
    $169 = $$2$i505 & 12;
    $170 = ($169|0)==(0);
    if ($170) {
     $$3$i507 = $$2$i505;$base$3$i508 = $base$2$i506;
    } else {
     $171 = (($base$2$i506) + 2)|0;
     $172 = $$2$i505 >>> 2;
     $$3$i507 = $172;$base$3$i508 = $171;
    }
    $173 = $$3$i507 & 2;
    $174 = ($173|0)==(0);
    if ($174) {
     $$4$i509 = $$3$i507;$base$4$i510 = $base$3$i508;
    } else {
     $175 = (($base$3$i508) + 1)|0;
     $176 = $$3$i507 >>> 1;
     $$4$i509 = $176;$base$4$i510 = $175;
    }
    $177 = $$4$i509 & 1;
    $$neg703 = (8 - ($base$4$i510))|0;
    $178 = (($$neg703) - ($177))|0;
    $179 = ($178|0)>(0);
    if ($179) {
     HEAP32[$146>>2] = $178;
     $180 = (($this) + 16|0);
     HEAP32[$180>>2] = 0;
     $184 = 0;$186 = $178;
    } else {
     HEAP32[$146>>2] = 0;
     $181 = (0 - ($178))|0;
     $182 = (($this) + 16|0);
     HEAP32[$182>>2] = $181;
     $184 = $181;$186 = 0;
    }
    $183 = $150 >>> $184;
    $185 = $183 << $186;
    $187 = $185 & 255;
    $188 = (($this) + 20|0);
    HEAP32[$188>>2] = $187;
   }
   $189 = (($this) + 24|0);
   $190 = HEAP32[$19>>2]|0;
   $191 = ($190|0)==(0);
   if ($191) {
    $192 = (($this) + 32|0);
    HEAP32[$192>>2] = 0;
    $193 = (($this) + 28|0);
    HEAP32[$193>>2] = 0;
    HEAP32[$189>>2] = 0;
   } else {
    $194 = ($190>>>0)>(65535);
    do {
     if ($194) {
      $195 = ($190>>>0)>(16777215);
      if ($195) {
       $196 = $190 >>> 24;
       $$0$i476 = $196;$base$0$i477 = 24;
       break;
      } else {
       $197 = $190 >>> 16;
       $$0$i476 = $197;$base$0$i477 = 16;
       break;
      }
     } else {
      $198 = $190 & 65280;
      $199 = ($198|0)==(0);
      $200 = $190 >>> 8;
      $mask$$i474 = $199 ? $190 : $200;
      $$$i475 = $199 ? 0 : 8;
      $$0$i476 = $mask$$i474;$base$0$i477 = $$$i475;
     }
    } while(0);
    $201 = $$0$i476 & 65280;
    $202 = ($201|0)==(0);
    if ($202) {
     $$1$i478 = $$0$i476;$base$1$i479 = $base$0$i477;
    } else {
     $203 = (($base$0$i477) + 8)|0;
     $204 = $$0$i476 >>> 8;
     $$1$i478 = $204;$base$1$i479 = $203;
    }
    $205 = $$1$i478 & 240;
    $206 = ($205|0)==(0);
    if ($206) {
     $$2$i480 = $$1$i478;$base$2$i481 = $base$1$i479;
    } else {
     $207 = (($base$1$i479) + 4)|0;
     $208 = $$1$i478 >>> 4;
     $$2$i480 = $208;$base$2$i481 = $207;
    }
    $209 = $$2$i480 & 12;
    $210 = ($209|0)==(0);
    if ($210) {
     $$3$i482 = $$2$i480;$base$3$i483 = $base$2$i481;
    } else {
     $211 = (($base$2$i481) + 2)|0;
     $212 = $$2$i480 >>> 2;
     $$3$i482 = $212;$base$3$i483 = $211;
    }
    $213 = $$3$i482 & 2;
    $214 = ($213|0)==(0);
    if ($214) {
     $$4$i484 = $$3$i482;$base$4$i485 = $base$3$i483;
    } else {
     $215 = (($base$3$i483) + 1)|0;
     $216 = $$3$i482 >>> 1;
     $$4$i484 = $216;$base$4$i485 = $215;
    }
    $217 = $$4$i484 & 1;
    $$neg705 = (8 - ($base$4$i485))|0;
    $218 = (($$neg705) - ($217))|0;
    $219 = ($218|0)>(0);
    if ($219) {
     HEAP32[$189>>2] = $218;
     $220 = (($this) + 28|0);
     HEAP32[$220>>2] = 0;
     $224 = 0;$226 = $218;
    } else {
     HEAP32[$189>>2] = 0;
     $221 = (0 - ($218))|0;
     $222 = (($this) + 28|0);
     HEAP32[$222>>2] = $221;
     $224 = $221;$226 = 0;
    }
    $223 = $190 >>> $224;
    $225 = $223 << $226;
    $227 = $225 & 255;
    $228 = (($this) + 32|0);
    HEAP32[$228>>2] = $227;
   }
   $229 = (($this) + 36|0);
   $230 = HEAP32[$22>>2]|0;
   $231 = HEAP32[$41>>2]|0;
   $232 = ($230|0)==(0);
   $233 = ($231|0)==(0);
   $or$cond$i445 = $232 | $233;
   if ($or$cond$i445) {
    $234 = (($this) + 44|0);
    HEAP32[$234>>2] = 0;
    $235 = (($this) + 40|0);
    HEAP32[$235>>2] = 0;
    HEAP32[$229>>2] = 0;
   } else {
    $236 = ($231>>>0)>(65535);
    do {
     if ($236) {
      $237 = ($231>>>0)>(16777215);
      if ($237) {
       $238 = $231 >>> 24;
       $$0$i462 = $238;$base$0$i463 = 24;
       break;
      } else {
       $239 = $231 >>> 16;
       $$0$i462 = $239;$base$0$i463 = 16;
       break;
      }
     } else {
      $240 = $231 & 65280;
      $241 = ($240|0)==(0);
      $242 = $231 >>> 8;
      $mask$$i460 = $241 ? $231 : $242;
      $$$i461 = $241 ? 0 : 8;
      $$0$i462 = $mask$$i460;$base$0$i463 = $$$i461;
     }
    } while(0);
    $243 = $$0$i462 & 65280;
    $244 = ($243|0)==(0);
    if ($244) {
     $$1$i464 = $$0$i462;$base$1$i465 = $base$0$i463;
    } else {
     $245 = (($base$0$i463) + 8)|0;
     $246 = $$0$i462 >>> 8;
     $$1$i464 = $246;$base$1$i465 = $245;
    }
    $247 = $$1$i464 & 240;
    $248 = ($247|0)==(0);
    if ($248) {
     $$2$i466 = $$1$i464;$base$2$i467 = $base$1$i465;
    } else {
     $249 = (($base$1$i465) + 4)|0;
     $250 = $$1$i464 >>> 4;
     $$2$i466 = $250;$base$2$i467 = $249;
    }
    $251 = $$2$i466 & 12;
    $252 = ($251|0)==(0);
    if ($252) {
     $$3$i468 = $$2$i466;$base$3$i469 = $base$2$i467;
    } else {
     $253 = (($base$2$i467) + 2)|0;
     $254 = $$2$i466 >>> 2;
     $$3$i468 = $254;$base$3$i469 = $253;
    }
    $255 = $$3$i468 & 2;
    $256 = ($255|0)==(0);
    if ($256) {
     $$4$i470 = $$3$i468;$base$4$i471 = $base$3$i469;
    } else {
     $257 = (($base$3$i469) + 1)|0;
     $258 = $$3$i468 >>> 1;
     $$4$i470 = $258;$base$4$i471 = $257;
    }
    $259 = $$4$i470 & 1;
    $260 = ($230>>>0)>(65535);
    do {
     if ($260) {
      $261 = ($230>>>0)>(16777215);
      if ($261) {
       $262 = $230 >>> 24;
       $$0$i449 = $262;$base$0$i450 = 24;
       break;
      } else {
       $263 = $230 >>> 16;
       $$0$i449 = $263;$base$0$i450 = 16;
       break;
      }
     } else {
      $264 = $230 & 65280;
      $265 = ($264|0)==(0);
      $266 = $230 >>> 8;
      $mask$$i447 = $265 ? $230 : $266;
      $$$i448 = $265 ? 0 : 8;
      $$0$i449 = $mask$$i447;$base$0$i450 = $$$i448;
     }
    } while(0);
    $267 = $$0$i449 & 65280;
    $268 = ($267|0)==(0);
    if ($268) {
     $$1$i451 = $$0$i449;$base$1$i452 = $base$0$i450;
    } else {
     $269 = (($base$0$i450) + 8)|0;
     $270 = $$0$i449 >>> 8;
     $$1$i451 = $270;$base$1$i452 = $269;
    }
    $271 = $$1$i451 & 240;
    $272 = ($271|0)==(0);
    if ($272) {
     $$2$i453 = $$1$i451;$base$2$i454 = $base$1$i452;
    } else {
     $273 = (($base$1$i452) + 4)|0;
     $274 = $$1$i451 >>> 4;
     $$2$i453 = $274;$base$2$i454 = $273;
    }
    $275 = $$2$i453 & 12;
    $276 = ($275|0)==(0);
    if ($276) {
     $$3$i455 = $$2$i453;$base$3$i456 = $base$2$i454;
    } else {
     $277 = (($base$2$i454) + 2)|0;
     $278 = $$2$i453 >>> 2;
     $$3$i455 = $278;$base$3$i456 = $277;
    }
    $279 = $$3$i455 & 2;
    $280 = ($279|0)==(0);
    if ($280) {
     $$4$i457 = $$3$i455;$base$4$i458 = $base$3$i456;
    } else {
     $281 = (($base$3$i456) + 1)|0;
     $282 = $$3$i455 >>> 1;
     $$4$i457 = $282;$base$4$i458 = $281;
    }
    $283 = $$4$i457 & 1;
    $284 = (($259) + ($base$4$i471))|0;
    $285 = (($284) - ($base$4$i458))|0;
    $286 = (($285) - ($283))|0;
    $287 = ($286|0)>(0);
    if ($287) {
     HEAP32[$229>>2] = $286;
     $288 = (($this) + 40|0);
     HEAP32[$288>>2] = 0;
     $292 = 0;$294 = $286;
    } else {
     HEAP32[$229>>2] = 0;
     $289 = (0 - ($286))|0;
     $290 = (($this) + 40|0);
     HEAP32[$290>>2] = $289;
     $292 = $289;$294 = 0;
    }
    $291 = $230 >>> $292;
    $293 = $291 << $294;
    $295 = $293 & $231;
    $296 = (($this) + 44|0);
    HEAP32[$296>>2] = $295;
   }
   $297 = (($this) + 60|0);
   $298 = HEAP32[$38>>2]|0;
   $299 = ($298|0)==(0);
   if ($299) {
    $300 = (($this) + 68|0);
    HEAP32[$300>>2] = 0;
    $301 = (($this) + 64|0);
    HEAP32[$301>>2] = 0;
    HEAP32[$297>>2] = 0;
   } else {
    $302 = ($298>>>0)>(65535);
    do {
     if ($302) {
      $303 = ($298>>>0)>(16777215);
      if ($303) {
       $304 = $298 >>> 24;
       $$0$i434 = $304;$base$0$i435 = 24;
       break;
      } else {
       $305 = $298 >>> 16;
       $$0$i434 = $305;$base$0$i435 = 16;
       break;
      }
     } else {
      $306 = $298 & 65280;
      $307 = ($306|0)==(0);
      $308 = $298 >>> 8;
      $mask$$i432 = $307 ? $298 : $308;
      $$$i433 = $307 ? 0 : 8;
      $$0$i434 = $mask$$i432;$base$0$i435 = $$$i433;
     }
    } while(0);
    $309 = $$0$i434 & 65280;
    $310 = ($309|0)==(0);
    if ($310) {
     $$1$i436 = $$0$i434;$base$1$i437 = $base$0$i435;
    } else {
     $311 = (($base$0$i435) + 8)|0;
     $312 = $$0$i434 >>> 8;
     $$1$i436 = $312;$base$1$i437 = $311;
    }
    $313 = $$1$i436 & 240;
    $314 = ($313|0)==(0);
    if ($314) {
     $$2$i438 = $$1$i436;$base$2$i439 = $base$1$i437;
    } else {
     $315 = (($base$1$i437) + 4)|0;
     $316 = $$1$i436 >>> 4;
     $$2$i438 = $316;$base$2$i439 = $315;
    }
    $317 = $$2$i438 & 12;
    $318 = ($317|0)==(0);
    if ($318) {
     $$3$i440 = $$2$i438;$base$3$i441 = $base$2$i439;
    } else {
     $319 = (($base$2$i439) + 2)|0;
     $320 = $$2$i438 >>> 2;
     $$3$i440 = $320;$base$3$i441 = $319;
    }
    $321 = $$3$i440 & 2;
    $322 = ($321|0)==(0);
    if ($322) {
     $$4$i442 = $$3$i440;$base$4$i443 = $base$3$i441;
    } else {
     $323 = (($base$3$i441) + 1)|0;
     $324 = $$3$i440 >>> 1;
     $$4$i442 = $324;$base$4$i443 = $323;
    }
    $325 = $$4$i442 & 1;
    $326 = (($base$4$i443) + -8)|0;
    $327 = (($326) + ($325))|0;
    $328 = ($327|0)>(0);
    if ($328) {
     HEAP32[$297>>2] = $327;
     $329 = (($this) + 64|0);
     HEAP32[$329>>2] = 0;
     $333 = 0;$335 = $327;
    } else {
     HEAP32[$297>>2] = 0;
     $330 = (0 - ($327))|0;
     $331 = (($this) + 64|0);
     HEAP32[$331>>2] = $330;
     $333 = $330;$335 = 0;
    }
    $332 = 255 >>> $333;
    $334 = $332 << $335;
    $336 = $334 & $298;
    $337 = (($this) + 68|0);
    HEAP32[$337>>2] = $336;
   }
   $338 = HEAP32[$22>>2]|0;
   $not$6 = ($338|0)==(0);
   $339 = HEAP32[$41>>2]|0;
   $340 = $not$6 ? $339 : 0;
   $341 = (($this) + 72|0);
   HEAP32[$341>>2] = $340;
   $342 = HEAP32[$dest>>2]|0;
   $343 = $342 >>> 3;
   $344 = $343 & 8191;
   $345 = (($344) + -1)|0;
   $346 = HEAP32[$source>>2]|0;
   $347 = $346 >>> 3;
   $348 = $347 & 8191;
   $349 = (($348) + -1)|0;
   $350 = ((1140224 + ($349<<4)|0) + ($345<<2)|0);
   $351 = HEAP32[$350>>2]|0;
   HEAP32[$1>>2] = $351;
   STACKTOP = sp;return;
  }
  $352 = ($73|0)==(0);
  $or$cond$i392 = $108 | $352;
  if ($or$cond$i392) {
   $353 = (($this) + 8|0);
   HEAP32[$353>>2] = 0;
   $354 = (($this) + 4|0);
   HEAP32[$354>>2] = 0;
   HEAP32[$this>>2] = 0;
  } else {
   $355 = ($73>>>0)>(65535);
   do {
    if ($355) {
     $356 = ($73>>>0)>(16777215);
     if ($356) {
      $357 = $73 >>> 24;
      $$0$i409 = $357;$base$0$i410 = 24;
      break;
     } else {
      $358 = $73 >>> 16;
      $$0$i409 = $358;$base$0$i410 = 16;
      break;
     }
    } else {
     $359 = $73 & 65280;
     $360 = ($359|0)==(0);
     $361 = $73 >>> 8;
     $mask$$i407 = $360 ? $73 : $361;
     $$$i408 = $360 ? 0 : 8;
     $$0$i409 = $mask$$i407;$base$0$i410 = $$$i408;
    }
   } while(0);
   $362 = $$0$i409 & 65280;
   $363 = ($362|0)==(0);
   if ($363) {
    $$1$i411 = $$0$i409;$base$1$i412 = $base$0$i410;
   } else {
    $364 = (($base$0$i410) + 8)|0;
    $365 = $$0$i409 >>> 8;
    $$1$i411 = $365;$base$1$i412 = $364;
   }
   $366 = $$1$i411 & 240;
   $367 = ($366|0)==(0);
   if ($367) {
    $$2$i413 = $$1$i411;$base$2$i414 = $base$1$i412;
   } else {
    $368 = (($base$1$i412) + 4)|0;
    $369 = $$1$i411 >>> 4;
    $$2$i413 = $369;$base$2$i414 = $368;
   }
   $370 = $$2$i413 & 12;
   $371 = ($370|0)==(0);
   if ($371) {
    $$3$i415 = $$2$i413;$base$3$i416 = $base$2$i414;
   } else {
    $372 = (($base$2$i414) + 2)|0;
    $373 = $$2$i413 >>> 2;
    $$3$i415 = $373;$base$3$i416 = $372;
   }
   $374 = $$3$i415 & 2;
   $375 = ($374|0)==(0);
   if ($375) {
    $$4$i417 = $$3$i415;$base$4$i418 = $base$3$i416;
   } else {
    $376 = (($base$3$i416) + 1)|0;
    $377 = $$3$i415 >>> 1;
    $$4$i417 = $377;$base$4$i418 = $376;
   }
   $378 = $$4$i417 & 1;
   $379 = ($107>>>0)>(65535);
   do {
    if ($379) {
     $380 = ($107>>>0)>(16777215);
     if ($380) {
      $381 = $107 >>> 24;
      $$0$i396 = $381;$base$0$i397 = 24;
      break;
     } else {
      $382 = $107 >>> 16;
      $$0$i396 = $382;$base$0$i397 = 16;
      break;
     }
    } else {
     $383 = $107 & 65280;
     $384 = ($383|0)==(0);
     $385 = $107 >>> 8;
     $mask$$i394 = $384 ? $107 : $385;
     $$$i395 = $384 ? 0 : 8;
     $$0$i396 = $mask$$i394;$base$0$i397 = $$$i395;
    }
   } while(0);
   $386 = $$0$i396 & 65280;
   $387 = ($386|0)==(0);
   if ($387) {
    $$1$i398 = $$0$i396;$base$1$i399 = $base$0$i397;
   } else {
    $388 = (($base$0$i397) + 8)|0;
    $389 = $$0$i396 >>> 8;
    $$1$i398 = $389;$base$1$i399 = $388;
   }
   $390 = $$1$i398 & 240;
   $391 = ($390|0)==(0);
   if ($391) {
    $$2$i400 = $$1$i398;$base$2$i401 = $base$1$i399;
   } else {
    $392 = (($base$1$i399) + 4)|0;
    $393 = $$1$i398 >>> 4;
    $$2$i400 = $393;$base$2$i401 = $392;
   }
   $394 = $$2$i400 & 12;
   $395 = ($394|0)==(0);
   if ($395) {
    $$3$i402 = $$2$i400;$base$3$i403 = $base$2$i401;
   } else {
    $396 = (($base$2$i401) + 2)|0;
    $397 = $$2$i400 >>> 2;
    $$3$i402 = $397;$base$3$i403 = $396;
   }
   $398 = $$3$i402 & 2;
   $399 = ($398|0)==(0);
   if ($399) {
    $$4$i404 = $$3$i402;$base$4$i405 = $base$3$i403;
   } else {
    $400 = (($base$3$i403) + 1)|0;
    $401 = $$3$i402 >>> 1;
    $$4$i404 = $401;$base$4$i405 = $400;
   }
   $402 = $$4$i404 & 1;
   $403 = (($378) + ($base$4$i418))|0;
   $404 = (($403) - ($base$4$i405))|0;
   $405 = (($404) - ($402))|0;
   $406 = ($405|0)>(0);
   if ($406) {
    HEAP32[$this>>2] = $405;
    $407 = (($this) + 4|0);
    HEAP32[$407>>2] = 0;
    $411 = 0;$413 = $405;
   } else {
    HEAP32[$this>>2] = 0;
    $408 = (0 - ($405))|0;
    $409 = (($this) + 4|0);
    HEAP32[$409>>2] = $408;
    $411 = $408;$413 = 0;
   }
   $410 = $107 >>> $411;
   $412 = $410 << $413;
   $414 = $412 & $73;
   $415 = (($this) + 8|0);
   HEAP32[$415>>2] = $414;
  }
  $416 = (($this) + 12|0);
  $417 = HEAP32[$source>>2]|0;
  $418 = $417 & 134217728;
  $419 = ($418|0)==(0);
  $$695 = $419 ? $16 : $19;
  $420 = HEAP32[$$695>>2]|0;
  $421 = HEAP32[$35>>2]|0;
  $422 = ($420|0)==(0);
  $423 = ($421|0)==(0);
  $or$cond$i364 = $422 | $423;
  if ($or$cond$i364) {
   $424 = (($this) + 20|0);
   HEAP32[$424>>2] = 0;
   $425 = (($this) + 16|0);
   HEAP32[$425>>2] = 0;
   HEAP32[$416>>2] = 0;
  } else {
   $426 = ($421>>>0)>(65535);
   do {
    if ($426) {
     $427 = ($421>>>0)>(16777215);
     if ($427) {
      $428 = $421 >>> 24;
      $$0$i381 = $428;$base$0$i382 = 24;
      break;
     } else {
      $429 = $421 >>> 16;
      $$0$i381 = $429;$base$0$i382 = 16;
      break;
     }
    } else {
     $430 = $421 & 65280;
     $431 = ($430|0)==(0);
     $432 = $421 >>> 8;
     $mask$$i379 = $431 ? $421 : $432;
     $$$i380 = $431 ? 0 : 8;
     $$0$i381 = $mask$$i379;$base$0$i382 = $$$i380;
    }
   } while(0);
   $433 = $$0$i381 & 65280;
   $434 = ($433|0)==(0);
   if ($434) {
    $$1$i383 = $$0$i381;$base$1$i384 = $base$0$i382;
   } else {
    $435 = (($base$0$i382) + 8)|0;
    $436 = $$0$i381 >>> 8;
    $$1$i383 = $436;$base$1$i384 = $435;
   }
   $437 = $$1$i383 & 240;
   $438 = ($437|0)==(0);
   if ($438) {
    $$2$i385 = $$1$i383;$base$2$i386 = $base$1$i384;
   } else {
    $439 = (($base$1$i384) + 4)|0;
    $440 = $$1$i383 >>> 4;
    $$2$i385 = $440;$base$2$i386 = $439;
   }
   $441 = $$2$i385 & 12;
   $442 = ($441|0)==(0);
   if ($442) {
    $$3$i387 = $$2$i385;$base$3$i388 = $base$2$i386;
   } else {
    $443 = (($base$2$i386) + 2)|0;
    $444 = $$2$i385 >>> 2;
    $$3$i387 = $444;$base$3$i388 = $443;
   }
   $445 = $$3$i387 & 2;
   $446 = ($445|0)==(0);
   if ($446) {
    $$4$i389 = $$3$i387;$base$4$i390 = $base$3$i388;
   } else {
    $447 = (($base$3$i388) + 1)|0;
    $448 = $$3$i387 >>> 1;
    $$4$i389 = $448;$base$4$i390 = $447;
   }
   $449 = $$4$i389 & 1;
   $450 = ($420>>>0)>(65535);
   do {
    if ($450) {
     $451 = ($420>>>0)>(16777215);
     if ($451) {
      $452 = $420 >>> 24;
      $$0$i368 = $452;$base$0$i369 = 24;
      break;
     } else {
      $453 = $420 >>> 16;
      $$0$i368 = $453;$base$0$i369 = 16;
      break;
     }
    } else {
     $454 = $420 & 65280;
     $455 = ($454|0)==(0);
     $456 = $420 >>> 8;
     $mask$$i366 = $455 ? $420 : $456;
     $$$i367 = $455 ? 0 : 8;
     $$0$i368 = $mask$$i366;$base$0$i369 = $$$i367;
    }
   } while(0);
   $457 = $$0$i368 & 65280;
   $458 = ($457|0)==(0);
   if ($458) {
    $$1$i370 = $$0$i368;$base$1$i371 = $base$0$i369;
   } else {
    $459 = (($base$0$i369) + 8)|0;
    $460 = $$0$i368 >>> 8;
    $$1$i370 = $460;$base$1$i371 = $459;
   }
   $461 = $$1$i370 & 240;
   $462 = ($461|0)==(0);
   if ($462) {
    $$2$i372 = $$1$i370;$base$2$i373 = $base$1$i371;
   } else {
    $463 = (($base$1$i371) + 4)|0;
    $464 = $$1$i370 >>> 4;
    $$2$i372 = $464;$base$2$i373 = $463;
   }
   $465 = $$2$i372 & 12;
   $466 = ($465|0)==(0);
   if ($466) {
    $$3$i374 = $$2$i372;$base$3$i375 = $base$2$i373;
   } else {
    $467 = (($base$2$i373) + 2)|0;
    $468 = $$2$i372 >>> 2;
    $$3$i374 = $468;$base$3$i375 = $467;
   }
   $469 = $$3$i374 & 2;
   $470 = ($469|0)==(0);
   if ($470) {
    $$4$i376 = $$3$i374;$base$4$i377 = $base$3$i375;
   } else {
    $471 = (($base$3$i375) + 1)|0;
    $472 = $$3$i374 >>> 1;
    $$4$i376 = $472;$base$4$i377 = $471;
   }
   $473 = $$4$i376 & 1;
   $474 = (($449) + ($base$4$i390))|0;
   $475 = (($474) - ($base$4$i377))|0;
   $476 = (($475) - ($473))|0;
   $477 = ($476|0)>(0);
   if ($477) {
    HEAP32[$416>>2] = $476;
    $478 = (($this) + 16|0);
    HEAP32[$478>>2] = 0;
    $482 = 0;$484 = $476;
   } else {
    HEAP32[$416>>2] = 0;
    $479 = (0 - ($476))|0;
    $480 = (($this) + 16|0);
    HEAP32[$480>>2] = $479;
    $482 = $479;$484 = 0;
   }
   $481 = $420 >>> $482;
   $483 = $481 << $484;
   $485 = $483 & $421;
   $486 = (($this) + 20|0);
   HEAP32[$486>>2] = $485;
  }
  $487 = (($this) + 24|0);
  $488 = HEAP32[$19>>2]|0;
  $489 = HEAP32[$38>>2]|0;
  $490 = ($488|0)==(0);
  $491 = ($489|0)==(0);
  $or$cond$i336 = $490 | $491;
  if ($or$cond$i336) {
   $492 = (($this) + 32|0);
   HEAP32[$492>>2] = 0;
   $493 = (($this) + 28|0);
   HEAP32[$493>>2] = 0;
   HEAP32[$487>>2] = 0;
  } else {
   $494 = ($489>>>0)>(65535);
   do {
    if ($494) {
     $495 = ($489>>>0)>(16777215);
     if ($495) {
      $496 = $489 >>> 24;
      $$0$i353 = $496;$base$0$i354 = 24;
      break;
     } else {
      $497 = $489 >>> 16;
      $$0$i353 = $497;$base$0$i354 = 16;
      break;
     }
    } else {
     $498 = $489 & 65280;
     $499 = ($498|0)==(0);
     $500 = $489 >>> 8;
     $mask$$i351 = $499 ? $489 : $500;
     $$$i352 = $499 ? 0 : 8;
     $$0$i353 = $mask$$i351;$base$0$i354 = $$$i352;
    }
   } while(0);
   $501 = $$0$i353 & 65280;
   $502 = ($501|0)==(0);
   if ($502) {
    $$1$i355 = $$0$i353;$base$1$i356 = $base$0$i354;
   } else {
    $503 = (($base$0$i354) + 8)|0;
    $504 = $$0$i353 >>> 8;
    $$1$i355 = $504;$base$1$i356 = $503;
   }
   $505 = $$1$i355 & 240;
   $506 = ($505|0)==(0);
   if ($506) {
    $$2$i357 = $$1$i355;$base$2$i358 = $base$1$i356;
   } else {
    $507 = (($base$1$i356) + 4)|0;
    $508 = $$1$i355 >>> 4;
    $$2$i357 = $508;$base$2$i358 = $507;
   }
   $509 = $$2$i357 & 12;
   $510 = ($509|0)==(0);
   if ($510) {
    $$3$i359 = $$2$i357;$base$3$i360 = $base$2$i358;
   } else {
    $511 = (($base$2$i358) + 2)|0;
    $512 = $$2$i357 >>> 2;
    $$3$i359 = $512;$base$3$i360 = $511;
   }
   $513 = $$3$i359 & 2;
   $514 = ($513|0)==(0);
   if ($514) {
    $$4$i361 = $$3$i359;$base$4$i362 = $base$3$i360;
   } else {
    $515 = (($base$3$i360) + 1)|0;
    $516 = $$3$i359 >>> 1;
    $$4$i361 = $516;$base$4$i362 = $515;
   }
   $517 = $$4$i361 & 1;
   $518 = ($488>>>0)>(65535);
   do {
    if ($518) {
     $519 = ($488>>>0)>(16777215);
     if ($519) {
      $520 = $488 >>> 24;
      $$0$i340 = $520;$base$0$i341 = 24;
      break;
     } else {
      $521 = $488 >>> 16;
      $$0$i340 = $521;$base$0$i341 = 16;
      break;
     }
    } else {
     $522 = $488 & 65280;
     $523 = ($522|0)==(0);
     $524 = $488 >>> 8;
     $mask$$i338 = $523 ? $488 : $524;
     $$$i339 = $523 ? 0 : 8;
     $$0$i340 = $mask$$i338;$base$0$i341 = $$$i339;
    }
   } while(0);
   $525 = $$0$i340 & 65280;
   $526 = ($525|0)==(0);
   if ($526) {
    $$1$i342 = $$0$i340;$base$1$i343 = $base$0$i341;
   } else {
    $527 = (($base$0$i341) + 8)|0;
    $528 = $$0$i340 >>> 8;
    $$1$i342 = $528;$base$1$i343 = $527;
   }
   $529 = $$1$i342 & 240;
   $530 = ($529|0)==(0);
   if ($530) {
    $$2$i344 = $$1$i342;$base$2$i345 = $base$1$i343;
   } else {
    $531 = (($base$1$i343) + 4)|0;
    $532 = $$1$i342 >>> 4;
    $$2$i344 = $532;$base$2$i345 = $531;
   }
   $533 = $$2$i344 & 12;
   $534 = ($533|0)==(0);
   if ($534) {
    $$3$i346 = $$2$i344;$base$3$i347 = $base$2$i345;
   } else {
    $535 = (($base$2$i345) + 2)|0;
    $536 = $$2$i344 >>> 2;
    $$3$i346 = $536;$base$3$i347 = $535;
   }
   $537 = $$3$i346 & 2;
   $538 = ($537|0)==(0);
   if ($538) {
    $$4$i348 = $$3$i346;$base$4$i349 = $base$3$i347;
   } else {
    $539 = (($base$3$i347) + 1)|0;
    $540 = $$3$i346 >>> 1;
    $$4$i348 = $540;$base$4$i349 = $539;
   }
   $541 = $$4$i348 & 1;
   $542 = (($517) + ($base$4$i362))|0;
   $543 = (($542) - ($base$4$i349))|0;
   $544 = (($543) - ($541))|0;
   $545 = ($544|0)>(0);
   if ($545) {
    HEAP32[$487>>2] = $544;
    $546 = (($this) + 28|0);
    HEAP32[$546>>2] = 0;
    $550 = 0;$552 = $544;
   } else {
    HEAP32[$487>>2] = 0;
    $547 = (0 - ($544))|0;
    $548 = (($this) + 28|0);
    HEAP32[$548>>2] = $547;
    $550 = $547;$552 = 0;
   }
   $549 = $488 >>> $550;
   $551 = $549 << $552;
   $553 = $551 & $489;
   $554 = (($this) + 32|0);
   HEAP32[$554>>2] = $553;
  }
  $555 = (($this) + 36|0);
  $556 = HEAP32[$22>>2]|0;
  $557 = HEAP32[$41>>2]|0;
  $558 = ($556|0)==(0);
  $559 = ($557|0)==(0);
  $or$cond$i308 = $558 | $559;
  if ($or$cond$i308) {
   $560 = (($this) + 44|0);
   HEAP32[$560>>2] = 0;
   $561 = (($this) + 40|0);
   HEAP32[$561>>2] = 0;
   HEAP32[$555>>2] = 0;
  } else {
   $562 = ($557>>>0)>(65535);
   do {
    if ($562) {
     $563 = ($557>>>0)>(16777215);
     if ($563) {
      $564 = $557 >>> 24;
      $$0$i325 = $564;$base$0$i326 = 24;
      break;
     } else {
      $565 = $557 >>> 16;
      $$0$i325 = $565;$base$0$i326 = 16;
      break;
     }
    } else {
     $566 = $557 & 65280;
     $567 = ($566|0)==(0);
     $568 = $557 >>> 8;
     $mask$$i323 = $567 ? $557 : $568;
     $$$i324 = $567 ? 0 : 8;
     $$0$i325 = $mask$$i323;$base$0$i326 = $$$i324;
    }
   } while(0);
   $569 = $$0$i325 & 65280;
   $570 = ($569|0)==(0);
   if ($570) {
    $$1$i327 = $$0$i325;$base$1$i328 = $base$0$i326;
   } else {
    $571 = (($base$0$i326) + 8)|0;
    $572 = $$0$i325 >>> 8;
    $$1$i327 = $572;$base$1$i328 = $571;
   }
   $573 = $$1$i327 & 240;
   $574 = ($573|0)==(0);
   if ($574) {
    $$2$i329 = $$1$i327;$base$2$i330 = $base$1$i328;
   } else {
    $575 = (($base$1$i328) + 4)|0;
    $576 = $$1$i327 >>> 4;
    $$2$i329 = $576;$base$2$i330 = $575;
   }
   $577 = $$2$i329 & 12;
   $578 = ($577|0)==(0);
   if ($578) {
    $$3$i331 = $$2$i329;$base$3$i332 = $base$2$i330;
   } else {
    $579 = (($base$2$i330) + 2)|0;
    $580 = $$2$i329 >>> 2;
    $$3$i331 = $580;$base$3$i332 = $579;
   }
   $581 = $$3$i331 & 2;
   $582 = ($581|0)==(0);
   if ($582) {
    $$4$i333 = $$3$i331;$base$4$i334 = $base$3$i332;
   } else {
    $583 = (($base$3$i332) + 1)|0;
    $584 = $$3$i331 >>> 1;
    $$4$i333 = $584;$base$4$i334 = $583;
   }
   $585 = $$4$i333 & 1;
   $586 = ($556>>>0)>(65535);
   do {
    if ($586) {
     $587 = ($556>>>0)>(16777215);
     if ($587) {
      $588 = $556 >>> 24;
      $$0$i312 = $588;$base$0$i313 = 24;
      break;
     } else {
      $589 = $556 >>> 16;
      $$0$i312 = $589;$base$0$i313 = 16;
      break;
     }
    } else {
     $590 = $556 & 65280;
     $591 = ($590|0)==(0);
     $592 = $556 >>> 8;
     $mask$$i310 = $591 ? $556 : $592;
     $$$i311 = $591 ? 0 : 8;
     $$0$i312 = $mask$$i310;$base$0$i313 = $$$i311;
    }
   } while(0);
   $593 = $$0$i312 & 65280;
   $594 = ($593|0)==(0);
   if ($594) {
    $$1$i314 = $$0$i312;$base$1$i315 = $base$0$i313;
   } else {
    $595 = (($base$0$i313) + 8)|0;
    $596 = $$0$i312 >>> 8;
    $$1$i314 = $596;$base$1$i315 = $595;
   }
   $597 = $$1$i314 & 240;
   $598 = ($597|0)==(0);
   if ($598) {
    $$2$i316 = $$1$i314;$base$2$i317 = $base$1$i315;
   } else {
    $599 = (($base$1$i315) + 4)|0;
    $600 = $$1$i314 >>> 4;
    $$2$i316 = $600;$base$2$i317 = $599;
   }
   $601 = $$2$i316 & 12;
   $602 = ($601|0)==(0);
   if ($602) {
    $$3$i318 = $$2$i316;$base$3$i319 = $base$2$i317;
   } else {
    $603 = (($base$2$i317) + 2)|0;
    $604 = $$2$i316 >>> 2;
    $$3$i318 = $604;$base$3$i319 = $603;
   }
   $605 = $$3$i318 & 2;
   $606 = ($605|0)==(0);
   if ($606) {
    $$4$i320 = $$3$i318;$base$4$i321 = $base$3$i319;
   } else {
    $607 = (($base$3$i319) + 1)|0;
    $608 = $$3$i318 >>> 1;
    $$4$i320 = $608;$base$4$i321 = $607;
   }
   $609 = $$4$i320 & 1;
   $610 = (($585) + ($base$4$i334))|0;
   $611 = (($610) - ($base$4$i321))|0;
   $612 = (($611) - ($609))|0;
   $613 = ($612|0)>(0);
   if ($613) {
    HEAP32[$555>>2] = $612;
    $614 = (($this) + 40|0);
    HEAP32[$614>>2] = 0;
    $618 = 0;$620 = $612;
   } else {
    HEAP32[$555>>2] = 0;
    $615 = (0 - ($612))|0;
    $616 = (($this) + 40|0);
    HEAP32[$616>>2] = $615;
    $618 = $615;$620 = 0;
   }
   $617 = $556 >>> $618;
   $619 = $617 << $620;
   $621 = $619 & $557;
   $622 = (($this) + 44|0);
   HEAP32[$622>>2] = $621;
  }
  $623 = HEAP32[$22>>2]|0;
  $not$5 = ($623|0)==(0);
  $624 = HEAP32[$41>>2]|0;
  $625 = $not$5 ? $624 : 0;
  $626 = (($this) + 72|0);
  HEAP32[$626>>2] = $625;
  $627 = HEAP32[$dest>>2]|0;
  $628 = $627 >>> 3;
  $629 = $628 & 8191;
  $630 = (($629) + -1)|0;
  $631 = HEAP32[$source>>2]|0;
  $632 = $631 >>> 3;
  $633 = $632 & 8191;
  $634 = (($633) + -1)|0;
  $635 = ((1140288 + ($634<<4)|0) + ($630<<2)|0);
  $636 = HEAP32[$635>>2]|0;
  HEAP32[$1>>2] = $636;
  STACKTOP = sp;return;
 } else if ((($type|0) == 5)) {
  $1190 = ($$sourceidx$0|0)==(-1);
  if (!($1190)) {
   $1191 = (1141000 + ($$sourceidx$0<<2)|0);
   $1192 = HEAP32[$1191>>2]|0;
   HEAP32[$1>>2] = $1192;
   $1193 = 250 >>> $$sourceidx$0;
   $1194 = $1193 & 1;
   $1195 = ($1194|0)==(0);
   if (!($1195)) {
    STACKTOP = sp;return;
   }
  }
  $1196 = HEAP32[$source>>2]|0;
  $1197 = $1196 & 134217728;
  $1198 = ($1197|0)==(0);
  if (!($1198)) {
   $1199 = (($this) + 60|0);
   $1200 = HEAP32[$19>>2]|0;
   $1201 = ($1200|0)==(0);
   if ($1201) {
    HEAP32[$1199>>2] = 0;
    $1202 = (($this) + 64|0);
    HEAP32[$1202>>2] = 32;
    $1203 = (($this) + 68|0);
    HEAP32[$1203>>2] = 0;
   } else {
    $1204 = ($1200>>>0)>(65535);
    do {
     if ($1204) {
      $1205 = ($1200>>>0)>(16777215);
      if ($1205) {
       $1206 = $1200 >>> 24;
       $$0$i$i70 = $1206;$base$0$i$i71 = 24;
       break;
      } else {
       $1207 = $1200 >>> 16;
       $$0$i$i70 = $1207;$base$0$i$i71 = 16;
       break;
      }
     } else {
      $1208 = $1200 & 65280;
      $1209 = ($1208|0)==(0);
      $1210 = $1200 >>> 8;
      $mask$$i$i68 = $1209 ? $1200 : $1210;
      $$$i$i69 = $1209 ? 0 : 8;
      $$0$i$i70 = $mask$$i$i68;$base$0$i$i71 = $$$i$i69;
     }
    } while(0);
    $1211 = $$0$i$i70 & 65280;
    $1212 = ($1211|0)==(0);
    if ($1212) {
     $$1$i$i72 = $$0$i$i70;$base$1$i$i73 = $base$0$i$i71;
    } else {
     $1213 = (($base$0$i$i71) + 8)|0;
     $1214 = $$0$i$i70 >>> 8;
     $$1$i$i72 = $1214;$base$1$i$i73 = $1213;
    }
    $1215 = $$1$i$i72 & 240;
    $1216 = ($1215|0)==(0);
    if ($1216) {
     $$2$i$i74 = $$1$i$i72;$base$2$i$i75 = $base$1$i$i73;
    } else {
     $1217 = (($base$1$i$i73) + 4)|0;
     $1218 = $$1$i$i72 >>> 4;
     $$2$i$i74 = $1218;$base$2$i$i75 = $1217;
    }
    $1219 = $$2$i$i74 & 12;
    $1220 = ($1219|0)==(0);
    if ($1220) {
     $$3$i$i76 = $$2$i$i74;$base$3$i$i77 = $base$2$i$i75;
    } else {
     $1221 = (($base$2$i$i75) + 2)|0;
     $1222 = $$2$i$i74 >>> 2;
     $$3$i$i76 = $1222;$base$3$i$i77 = $1221;
    }
    $1223 = $$3$i$i76 & 2;
    $1224 = ($1223|0)==(0);
    if ($1224) {
     $$4$i$i78 = $$3$i$i76;$base$4$i$i79 = $base$3$i$i77;
    } else {
     $1225 = (($base$3$i$i77) + 1)|0;
     $1226 = $$3$i$i76 >>> 1;
     $$4$i$i78 = $1226;$base$4$i$i79 = $1225;
    }
    $1227 = $$4$i$i78 & 1;
    $$neg2$i80 = (8 - ($base$4$i$i79))|0;
    $1228 = (($$neg2$i80) - ($1227))|0;
    $1229 = ($1228|0)>(0);
    if ($1229) {
     HEAP32[$1199>>2] = $1228;
     $1230 = (($this) + 64|0);
     HEAP32[$1230>>2] = 0;
     $1234 = $1228;$1236 = 0;
    } else {
     HEAP32[$1199>>2] = 0;
     $1231 = (0 - ($1228))|0;
     $1232 = (($this) + 64|0);
     HEAP32[$1232>>2] = $1231;
     $1234 = 0;$1236 = $1231;
    }
    $1233 = 255 >>> $1234;
    $1235 = $1233 << $1236;
    $1237 = $1235 & $1200;
    $1238 = (($this) + 68|0);
    HEAP32[$1238>>2] = $1237;
   }
   $1239 = (($this) + 36|0);
   $1240 = HEAP32[$22>>2]|0;
   $1241 = ($1240|0)==(0);
   if ($1241) {
    HEAP32[$1239>>2] = 0;
    $1242 = (($this) + 40|0);
    HEAP32[$1242>>2] = 32;
    $1243 = (($this) + 44|0);
    HEAP32[$1243>>2] = 0;
   } else {
    $1244 = ($1240>>>0)>(65535);
    do {
     if ($1244) {
      $1245 = ($1240>>>0)>(16777215);
      if ($1245) {
       $1246 = $1240 >>> 24;
       $$0$i$i55 = $1246;$base$0$i$i56 = 24;
       break;
      } else {
       $1247 = $1240 >>> 16;
       $$0$i$i55 = $1247;$base$0$i$i56 = 16;
       break;
      }
     } else {
      $1248 = $1240 & 65280;
      $1249 = ($1248|0)==(0);
      $1250 = $1240 >>> 8;
      $mask$$i$i53 = $1249 ? $1240 : $1250;
      $$$i$i54 = $1249 ? 0 : 8;
      $$0$i$i55 = $mask$$i$i53;$base$0$i$i56 = $$$i$i54;
     }
    } while(0);
    $1251 = $$0$i$i55 & 65280;
    $1252 = ($1251|0)==(0);
    if ($1252) {
     $$1$i$i57 = $$0$i$i55;$base$1$i$i58 = $base$0$i$i56;
    } else {
     $1253 = (($base$0$i$i56) + 8)|0;
     $1254 = $$0$i$i55 >>> 8;
     $$1$i$i57 = $1254;$base$1$i$i58 = $1253;
    }
    $1255 = $$1$i$i57 & 240;
    $1256 = ($1255|0)==(0);
    if ($1256) {
     $$2$i$i59 = $$1$i$i57;$base$2$i$i60 = $base$1$i$i58;
    } else {
     $1257 = (($base$1$i$i58) + 4)|0;
     $1258 = $$1$i$i57 >>> 4;
     $$2$i$i59 = $1258;$base$2$i$i60 = $1257;
    }
    $1259 = $$2$i$i59 & 12;
    $1260 = ($1259|0)==(0);
    if ($1260) {
     $$3$i$i61 = $$2$i$i59;$base$3$i$i62 = $base$2$i$i60;
    } else {
     $1261 = (($base$2$i$i60) + 2)|0;
     $1262 = $$2$i$i59 >>> 2;
     $$3$i$i61 = $1262;$base$3$i$i62 = $1261;
    }
    $1263 = $$3$i$i61 & 2;
    $1264 = ($1263|0)==(0);
    if ($1264) {
     $$4$i$i63 = $$3$i$i61;$base$4$i$i64 = $base$3$i$i62;
    } else {
     $1265 = (($base$3$i$i62) + 1)|0;
     $1266 = $$3$i$i61 >>> 1;
     $$4$i$i63 = $1266;$base$4$i$i64 = $1265;
    }
    $1267 = $$4$i$i63 & 1;
    $$neg2$i65 = (8 - ($base$4$i$i64))|0;
    $1268 = (($$neg2$i65) - ($1267))|0;
    $1269 = ($1268|0)>(0);
    if ($1269) {
     HEAP32[$1239>>2] = $1268;
     $1270 = (($this) + 40|0);
     HEAP32[$1270>>2] = 0;
     $1274 = $1268;$1276 = 0;
    } else {
     HEAP32[$1239>>2] = 0;
     $1271 = (0 - ($1268))|0;
     $1272 = (($this) + 40|0);
     HEAP32[$1272>>2] = $1271;
     $1274 = 0;$1276 = $1271;
    }
    $1273 = 255 >>> $1274;
    $1275 = $1273 << $1276;
    $1277 = $1275 & $1240;
    $1278 = (($this) + 44|0);
    HEAP32[$1278>>2] = $1277;
   }
   $1279 = HEAP32[$source>>2]|0;
   $1280 = $1279 >>> 3;
   $1281 = $1280 & 8191;
   $1282 = (($1281) + -1)|0;
   $1283 = (1141048 + ($1282<<2)|0);
   $1284 = HEAP32[$1283>>2]|0;
   HEAP32[$1>>2] = $1284;
   STACKTOP = sp;return;
  }
  $1285 = ($50|0)==(0);
  if ($1285) {
   HEAP32[$this>>2] = 0;
   $1286 = (($this) + 4|0);
   HEAP32[$1286>>2] = 32;
   $1287 = (($this) + 8|0);
   HEAP32[$1287>>2] = 0;
  } else {
   $1288 = ($50>>>0)>(65535);
   do {
    if ($1288) {
     $1289 = ($50>>>0)>(16777215);
     if ($1289) {
      $1290 = $50 >>> 24;
      $$0$i$i40 = $1290;$base$0$i$i41 = 24;
      break;
     } else {
      $1291 = $50 >>> 16;
      $$0$i$i40 = $1291;$base$0$i$i41 = 16;
      break;
     }
    } else {
     $1292 = $50 & 65280;
     $1293 = ($1292|0)==(0);
     $1294 = $50 >>> 8;
     $mask$$i$i38 = $1293 ? $50 : $1294;
     $$$i$i39 = $1293 ? 0 : 8;
     $$0$i$i40 = $mask$$i$i38;$base$0$i$i41 = $$$i$i39;
    }
   } while(0);
   $1295 = $$0$i$i40 & 65280;
   $1296 = ($1295|0)==(0);
   if ($1296) {
    $$1$i$i42 = $$0$i$i40;$base$1$i$i43 = $base$0$i$i41;
   } else {
    $1297 = (($base$0$i$i41) + 8)|0;
    $1298 = $$0$i$i40 >>> 8;
    $$1$i$i42 = $1298;$base$1$i$i43 = $1297;
   }
   $1299 = $$1$i$i42 & 240;
   $1300 = ($1299|0)==(0);
   if ($1300) {
    $$2$i$i44 = $$1$i$i42;$base$2$i$i45 = $base$1$i$i43;
   } else {
    $1301 = (($base$1$i$i43) + 4)|0;
    $1302 = $$1$i$i42 >>> 4;
    $$2$i$i44 = $1302;$base$2$i$i45 = $1301;
   }
   $1303 = $$2$i$i44 & 12;
   $1304 = ($1303|0)==(0);
   if ($1304) {
    $$3$i$i46 = $$2$i$i44;$base$3$i$i47 = $base$2$i$i45;
   } else {
    $1305 = (($base$2$i$i45) + 2)|0;
    $1306 = $$2$i$i44 >>> 2;
    $$3$i$i46 = $1306;$base$3$i$i47 = $1305;
   }
   $1307 = $$3$i$i46 & 2;
   $1308 = ($1307|0)==(0);
   if ($1308) {
    $$4$i$i48 = $$3$i$i46;$base$4$i$i49 = $base$3$i$i47;
   } else {
    $1309 = (($base$3$i$i47) + 1)|0;
    $1310 = $$3$i$i46 >>> 1;
    $$4$i$i48 = $1310;$base$4$i$i49 = $1309;
   }
   $1311 = $$4$i$i48 & 1;
   $$neg2$i50 = (8 - ($base$4$i$i49))|0;
   $1312 = (($$neg2$i50) - ($1311))|0;
   $1313 = ($1312|0)>(0);
   if ($1313) {
    HEAP32[$this>>2] = $1312;
    $1314 = (($this) + 4|0);
    HEAP32[$1314>>2] = 0;
    $1318 = $1312;$1320 = 0;
   } else {
    HEAP32[$this>>2] = 0;
    $1315 = (0 - ($1312))|0;
    $1316 = (($this) + 4|0);
    HEAP32[$1316>>2] = $1315;
    $1318 = 0;$1320 = $1315;
   }
   $1317 = 255 >>> $1318;
   $1319 = $1317 << $1320;
   $1321 = $1319 & $50;
   $1322 = (($this) + 8|0);
   HEAP32[$1322>>2] = $1321;
  }
  $1323 = (($this) + 12|0);
  $1324 = HEAP32[$16>>2]|0;
  $1325 = ($1324|0)==(0);
  if ($1325) {
   HEAP32[$1323>>2] = 0;
   $1326 = (($this) + 16|0);
   HEAP32[$1326>>2] = 32;
   $1327 = (($this) + 20|0);
   HEAP32[$1327>>2] = 0;
  } else {
   $1328 = ($1324>>>0)>(65535);
   do {
    if ($1328) {
     $1329 = ($1324>>>0)>(16777215);
     if ($1329) {
      $1330 = $1324 >>> 24;
      $$0$i$i25 = $1330;$base$0$i$i26 = 24;
      break;
     } else {
      $1331 = $1324 >>> 16;
      $$0$i$i25 = $1331;$base$0$i$i26 = 16;
      break;
     }
    } else {
     $1332 = $1324 & 65280;
     $1333 = ($1332|0)==(0);
     $1334 = $1324 >>> 8;
     $mask$$i$i23 = $1333 ? $1324 : $1334;
     $$$i$i24 = $1333 ? 0 : 8;
     $$0$i$i25 = $mask$$i$i23;$base$0$i$i26 = $$$i$i24;
    }
   } while(0);
   $1335 = $$0$i$i25 & 65280;
   $1336 = ($1335|0)==(0);
   if ($1336) {
    $$1$i$i27 = $$0$i$i25;$base$1$i$i28 = $base$0$i$i26;
   } else {
    $1337 = (($base$0$i$i26) + 8)|0;
    $1338 = $$0$i$i25 >>> 8;
    $$1$i$i27 = $1338;$base$1$i$i28 = $1337;
   }
   $1339 = $$1$i$i27 & 240;
   $1340 = ($1339|0)==(0);
   if ($1340) {
    $$2$i$i29 = $$1$i$i27;$base$2$i$i30 = $base$1$i$i28;
   } else {
    $1341 = (($base$1$i$i28) + 4)|0;
    $1342 = $$1$i$i27 >>> 4;
    $$2$i$i29 = $1342;$base$2$i$i30 = $1341;
   }
   $1343 = $$2$i$i29 & 12;
   $1344 = ($1343|0)==(0);
   if ($1344) {
    $$3$i$i31 = $$2$i$i29;$base$3$i$i32 = $base$2$i$i30;
   } else {
    $1345 = (($base$2$i$i30) + 2)|0;
    $1346 = $$2$i$i29 >>> 2;
    $$3$i$i31 = $1346;$base$3$i$i32 = $1345;
   }
   $1347 = $$3$i$i31 & 2;
   $1348 = ($1347|0)==(0);
   if ($1348) {
    $$4$i$i33 = $$3$i$i31;$base$4$i$i34 = $base$3$i$i32;
   } else {
    $1349 = (($base$3$i$i32) + 1)|0;
    $1350 = $$3$i$i31 >>> 1;
    $$4$i$i33 = $1350;$base$4$i$i34 = $1349;
   }
   $1351 = $$4$i$i33 & 1;
   $$neg2$i35 = (8 - ($base$4$i$i34))|0;
   $1352 = (($$neg2$i35) - ($1351))|0;
   $1353 = ($1352|0)>(0);
   if ($1353) {
    HEAP32[$1323>>2] = $1352;
    $1354 = (($this) + 16|0);
    HEAP32[$1354>>2] = 0;
    $1358 = $1352;$1360 = 0;
   } else {
    HEAP32[$1323>>2] = 0;
    $1355 = (0 - ($1352))|0;
    $1356 = (($this) + 16|0);
    HEAP32[$1356>>2] = $1355;
    $1358 = 0;$1360 = $1355;
   }
   $1357 = 255 >>> $1358;
   $1359 = $1357 << $1360;
   $1361 = $1359 & $1324;
   $1362 = (($this) + 20|0);
   HEAP32[$1362>>2] = $1361;
  }
  $1363 = (($this) + 24|0);
  $1364 = HEAP32[$19>>2]|0;
  $1365 = ($1364|0)==(0);
  if ($1365) {
   HEAP32[$1363>>2] = 0;
   $1366 = (($this) + 28|0);
   HEAP32[$1366>>2] = 32;
   $1367 = (($this) + 32|0);
   HEAP32[$1367>>2] = 0;
  } else {
   $1368 = ($1364>>>0)>(65535);
   do {
    if ($1368) {
     $1369 = ($1364>>>0)>(16777215);
     if ($1369) {
      $1370 = $1364 >>> 24;
      $$0$i$i10 = $1370;$base$0$i$i11 = 24;
      break;
     } else {
      $1371 = $1364 >>> 16;
      $$0$i$i10 = $1371;$base$0$i$i11 = 16;
      break;
     }
    } else {
     $1372 = $1364 & 65280;
     $1373 = ($1372|0)==(0);
     $1374 = $1364 >>> 8;
     $mask$$i$i8 = $1373 ? $1364 : $1374;
     $$$i$i9 = $1373 ? 0 : 8;
     $$0$i$i10 = $mask$$i$i8;$base$0$i$i11 = $$$i$i9;
    }
   } while(0);
   $1375 = $$0$i$i10 & 65280;
   $1376 = ($1375|0)==(0);
   if ($1376) {
    $$1$i$i12 = $$0$i$i10;$base$1$i$i13 = $base$0$i$i11;
   } else {
    $1377 = (($base$0$i$i11) + 8)|0;
    $1378 = $$0$i$i10 >>> 8;
    $$1$i$i12 = $1378;$base$1$i$i13 = $1377;
   }
   $1379 = $$1$i$i12 & 240;
   $1380 = ($1379|0)==(0);
   if ($1380) {
    $$2$i$i14 = $$1$i$i12;$base$2$i$i15 = $base$1$i$i13;
   } else {
    $1381 = (($base$1$i$i13) + 4)|0;
    $1382 = $$1$i$i12 >>> 4;
    $$2$i$i14 = $1382;$base$2$i$i15 = $1381;
   }
   $1383 = $$2$i$i14 & 12;
   $1384 = ($1383|0)==(0);
   if ($1384) {
    $$3$i$i16 = $$2$i$i14;$base$3$i$i17 = $base$2$i$i15;
   } else {
    $1385 = (($base$2$i$i15) + 2)|0;
    $1386 = $$2$i$i14 >>> 2;
    $$3$i$i16 = $1386;$base$3$i$i17 = $1385;
   }
   $1387 = $$3$i$i16 & 2;
   $1388 = ($1387|0)==(0);
   if ($1388) {
    $$4$i$i18 = $$3$i$i16;$base$4$i$i19 = $base$3$i$i17;
   } else {
    $1389 = (($base$3$i$i17) + 1)|0;
    $1390 = $$3$i$i16 >>> 1;
    $$4$i$i18 = $1390;$base$4$i$i19 = $1389;
   }
   $1391 = $$4$i$i18 & 1;
   $$neg2$i20 = (8 - ($base$4$i$i19))|0;
   $1392 = (($$neg2$i20) - ($1391))|0;
   $1393 = ($1392|0)>(0);
   if ($1393) {
    HEAP32[$1363>>2] = $1392;
    $1394 = (($this) + 28|0);
    HEAP32[$1394>>2] = 0;
    $1398 = $1392;$1400 = 0;
   } else {
    HEAP32[$1363>>2] = 0;
    $1395 = (0 - ($1392))|0;
    $1396 = (($this) + 28|0);
    HEAP32[$1396>>2] = $1395;
    $1398 = 0;$1400 = $1395;
   }
   $1397 = 255 >>> $1398;
   $1399 = $1397 << $1400;
   $1401 = $1399 & $1364;
   $1402 = (($this) + 32|0);
   HEAP32[$1402>>2] = $1401;
  }
  $1403 = (($this) + 36|0);
  $1404 = HEAP32[$22>>2]|0;
  $1405 = ($1404|0)==(0);
  if ($1405) {
   HEAP32[$1403>>2] = 0;
   $1406 = (($this) + 40|0);
   HEAP32[$1406>>2] = 32;
   $1407 = (($this) + 44|0);
   HEAP32[$1407>>2] = 0;
  } else {
   $1408 = ($1404>>>0)>(65535);
   do {
    if ($1408) {
     $1409 = ($1404>>>0)>(16777215);
     if ($1409) {
      $1410 = $1404 >>> 24;
      $$0$i$i = $1410;$base$0$i$i = 24;
      break;
     } else {
      $1411 = $1404 >>> 16;
      $$0$i$i = $1411;$base$0$i$i = 16;
      break;
     }
    } else {
     $1412 = $1404 & 65280;
     $1413 = ($1412|0)==(0);
     $1414 = $1404 >>> 8;
     $mask$$i$i = $1413 ? $1404 : $1414;
     $$$i$i = $1413 ? 0 : 8;
     $$0$i$i = $mask$$i$i;$base$0$i$i = $$$i$i;
    }
   } while(0);
   $1415 = $$0$i$i & 65280;
   $1416 = ($1415|0)==(0);
   if ($1416) {
    $$1$i$i = $$0$i$i;$base$1$i$i = $base$0$i$i;
   } else {
    $1417 = (($base$0$i$i) + 8)|0;
    $1418 = $$0$i$i >>> 8;
    $$1$i$i = $1418;$base$1$i$i = $1417;
   }
   $1419 = $$1$i$i & 240;
   $1420 = ($1419|0)==(0);
   if ($1420) {
    $$2$i$i = $$1$i$i;$base$2$i$i = $base$1$i$i;
   } else {
    $1421 = (($base$1$i$i) + 4)|0;
    $1422 = $$1$i$i >>> 4;
    $$2$i$i = $1422;$base$2$i$i = $1421;
   }
   $1423 = $$2$i$i & 12;
   $1424 = ($1423|0)==(0);
   if ($1424) {
    $$3$i$i = $$2$i$i;$base$3$i$i = $base$2$i$i;
   } else {
    $1425 = (($base$2$i$i) + 2)|0;
    $1426 = $$2$i$i >>> 2;
    $$3$i$i = $1426;$base$3$i$i = $1425;
   }
   $1427 = $$3$i$i & 2;
   $1428 = ($1427|0)==(0);
   if ($1428) {
    $$4$i$i = $$3$i$i;$base$4$i$i = $base$3$i$i;
   } else {
    $1429 = (($base$3$i$i) + 1)|0;
    $1430 = $$3$i$i >>> 1;
    $$4$i$i = $1430;$base$4$i$i = $1429;
   }
   $1431 = $$4$i$i & 1;
   $$neg2$i = (8 - ($base$4$i$i))|0;
   $1432 = (($$neg2$i) - ($1431))|0;
   $1433 = ($1432|0)>(0);
   if ($1433) {
    HEAP32[$1403>>2] = $1432;
    $1434 = (($this) + 40|0);
    HEAP32[$1434>>2] = 0;
    $1438 = $1432;$1440 = 0;
   } else {
    HEAP32[$1403>>2] = 0;
    $1435 = (0 - ($1432))|0;
    $1436 = (($this) + 40|0);
    HEAP32[$1436>>2] = $1435;
    $1438 = 0;$1440 = $1435;
   }
   $1437 = 255 >>> $1438;
   $1439 = $1437 << $1440;
   $1441 = $1439 & $1404;
   $1442 = (($this) + 44|0);
   HEAP32[$1442>>2] = $1441;
  }
  $1443 = HEAP32[$source>>2]|0;
  $1444 = $1443 >>> 3;
  $1445 = $1444 & 8191;
  $1446 = (($1445) + -1)|0;
  $1447 = (1141064 + ($1446<<2)|0);
  $1448 = HEAP32[$1447>>2]|0;
  HEAP32[$1>>2] = $1448;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZL21inner_remap_i8_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0;
 var $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 & 224;
  $11 = $10 >>> 3;
  $12 = $9 >>> 6;
  $13 = $12 | $10;
  $14 = $13 | $11;
  $15 = $14&255;
  $16 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $15;
  $17 = ($6|0)==(0);
  if ($17) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $16;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_i8_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$02 = $1;$dest$01 = $3;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 << 8;
  $11 = $10 & 63488;
  $12 = $9 << 3;
  $13 = $12 & 2016;
  $14 = $9 >>> 3;
  $15 = $13 | $14;
  $16 = $15 | $11;
  $17 = $16&65535;
  $18 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $17;
  $19 = ($6|0)==(0);
  if ($19) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $18;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_i8_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  HEAP8[$dest$01>>0] = $8;
  $9 = (($dest$01) + 1|0);
  HEAP8[$9>>0] = $8;
  $10 = (($dest$01) + 2|0);
  HEAP8[$10>>0] = $8;
  $11 = (($dest$01) + 3|0);
  $12 = ($6|0)==(0);
  if ($12) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $11;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_i8_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$01 = 0, $dest$02 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$01 = $1;$dest$02 = $3;$src$03 = $5;
 while(1) {
  $6 = (($count$01) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 & 248;
  $11 = $10 << 7;
  $12 = $10 << 2;
  $13 = $9 >>> 3;
  $14 = $13 | $12;
  $15 = $14 | $11;
  $16 = $15 | 32768;
  $17 = $16&65535;
  $18 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $17;
  $19 = ($6|0)==(0);
  if ($19) {
   break;
  } else {
   $count$01 = $6;$dest$02 = $18;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_i8_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0;
 var $dest$02 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$01 = $1;$dest$02 = $3;$src$03 = $5;
 while(1) {
  $6 = (($count$01) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 & 240;
  $11 = $10 << 4;
  $12 = $9 >>> 4;
  $13 = $10 | $12;
  $14 = $13 | $11;
  $15 = $14 | 61440;
  $16 = $15&65535;
  $17 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $16;
  $18 = ($6|0)==(0);
  if ($18) {
   break;
  } else {
   $count$01 = $6;$dest$02 = $17;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_i8_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$02 = $1;$dest$01 = $3;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 << 16;
  $11 = $9 << 8;
  $12 = $9 | $11;
  $13 = $12 | $10;
  $14 = $13 | -16777216;
  $15 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $14;
  $16 = ($6|0)==(0);
  if ($16) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $15;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_rgb332_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 & 224;
  $11 = ((1138392 + ($10<<2)|0) + 2|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = $12&255;
  $14 = $9 << 3;
  $15 = $14 & 224;
  $16 = ((1138392 + ($15<<2)|0) + 1|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = (($18) + ($13))|0;
  $20 = $9 << 6;
  $21 = $20 & 192;
  $22 = (1138392 + ($21<<2)|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = (($19) + ($24))|0;
  $26 = $25&255;
  $27 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $26;
  $28 = ($6|0)==(0);
  if ($28) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $27;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL25inner_remap_rgb332_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$02 = $1;$dest$01 = $3;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 << 8;
  $11 = $10 & 57344;
  $12 = $9 << 6;
  $13 = $12 & 1792;
  $14 = $11 | $13;
  $15 = $9 << 3;
  $16 = $15 & 24;
  $17 = $14 | $16;
  $18 = $17&65535;
  $19 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $18;
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $19;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL25inner_remap_rgb332_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 & 224;
  $11 = $9 << 3;
  $12 = $11 & 224;
  $13 = $9 << 6;
  $14 = $13&255;
  HEAP8[$dest$01>>0] = $14;
  $15 = $12&255;
  $16 = (($dest$01) + 1|0);
  HEAP8[$16>>0] = $15;
  $17 = $10&255;
  $18 = (($dest$01) + 2|0);
  HEAP8[$18>>0] = $17;
  $19 = (($dest$01) + 3|0);
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $19;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb332_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$02 = $1;$dest$01 = $3;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 << 7;
  $11 = $10 & 28672;
  $12 = $9 << 5;
  $13 = $12 & 896;
  $14 = $9 << 3;
  $15 = $14 & 24;
  $16 = $13 | $11;
  $17 = $16 | $15;
  $18 = $17 | 32768;
  $19 = $18&65535;
  $20 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $19;
  $21 = ($6|0)==(0);
  if ($21) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $20;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb332_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$02 = $1;$dest$01 = $3;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 << 4;
  $11 = $10 & 3584;
  $12 = $9 << 3;
  $13 = $12 & 224;
  $14 = $9 << 2;
  $15 = $14 & 12;
  $16 = $13 | $11;
  $17 = $16 | $15;
  $18 = $17 | 61440;
  $19 = $18&65535;
  $20 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $19;
  $21 = ($6|0)==(0);
  if ($21) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $20;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb332_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$02 = $1;$dest$01 = $3;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 1|0);
  $8 = HEAP8[$src$03>>0]|0;
  $9 = $8&255;
  $10 = $9 << 16;
  $11 = $10 & 14680064;
  $12 = $9 << 11;
  $13 = $12 & 57344;
  $14 = $9 << 6;
  $15 = $14 & 192;
  $16 = $13 | $11;
  $17 = $16 | $15;
  $18 = $17 | -16777216;
  $19 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $18;
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $19;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_rgb565_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 >>> 8;
  $11 = $10 & 248;
  $12 = ((1138392 + ($11<<2)|0) + 2|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $9 >>> 3;
  $16 = $15 & 252;
  $17 = ((1138392 + ($16<<2)|0) + 1|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = (($19) + ($14))|0;
  $21 = $9 << 3;
  $22 = $21 & 248;
  $23 = (1138392 + ($22<<2)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = (($20) + ($25))|0;
  $27 = $26&255;
  $28 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $27;
  $29 = ($6|0)==(0);
  if ($29) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $28;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL25inner_remap_rgb565_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 >>> 8;
  $11 = $10 & 224;
  $12 = $9 >>> 6;
  $13 = $12 & 28;
  $14 = $11 | $13;
  $15 = $9 >>> 3;
  $16 = $15 & 3;
  $17 = $14 | $16;
  $18 = $17&255;
  $19 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $18;
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $19;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL33inner_remap_rgb565_rgb888_correctP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$01 = $1;$dest$02 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$01) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 & 2016;
  $11 = $9 << 8;
  $12 = $11 & 16252928;
  $13 = $9 << 3;
  $14 = $13 & 458752;
  $15 = $12 | $14;
  $16 = $10 << 5;
  $17 = $10 >>> 1;
  $18 = $17 & 768;
  $19 = $18 | $16;
  $20 = $9 >>> 2;
  $21 = $20 & 7;
  $22 = $21 | $13;
  $23 = $22&255;
  HEAP8[$dest$02>>0] = $23;
  $24 = $19 >>> 8;
  $25 = $24&255;
  $26 = (($dest$02) + 1|0);
  HEAP8[$26>>0] = $25;
  $27 = $15 >>> 16;
  $28 = $27&255;
  $29 = (($dest$02) + 2|0);
  HEAP8[$29>>0] = $28;
  $30 = (($dest$02) + 3|0);
  $31 = ($6|0)==(0);
  if ($31) {
   break;
  } else {
   $count$01 = $6;$dest$02 = $30;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb565_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$07 = 0;
 var $count$1 = 0, $count2$01 = 0, $dest$08 = 0, $dest$1 = 0, $dest$22 = 0, $dest$3 = 0, $scevgep = 0, $scevgep12 = 0, $src$09 = 0, $src$1 = 0, $src$23 = 0, $src$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$info>>2]|0;
 $3 = (($info) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $1;
 $6 = $2;
 $7 = $6 ^ $5;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($4|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $count$07 = $4;$dest$08 = $2;$src$09 = $1;
  }
  while(1) {
   $11 = (($count$07) + -1)|0;
   $12 = (($src$09) + 2|0);
   $13 = HEAP16[$src$09>>1]|0;
   $14 = $13&65535;
   $15 = $14 >>> 1;
   $16 = $15 & 32736;
   $17 = $14 & 31;
   $18 = $17 | $16;
   $19 = $18 | 32768;
   $20 = $19&65535;
   $21 = (($dest$08) + 2|0);
   HEAP16[$dest$08>>1] = $20;
   $22 = ($11|0)==(0);
   if ($22) {
    break;
   } else {
    $count$07 = $11;$dest$08 = $21;$src$09 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $23 = $5 & 2;
 $24 = ($23|0)==(0);
 if ($24) {
  $count$1 = $4;$dest$1 = $2;$src$1 = $1;
 } else {
  $25 = (($1) + 2|0);
  $26 = HEAP16[$1>>1]|0;
  $27 = $26&65535;
  $28 = $27 >>> 1;
  $29 = $28 & 32736;
  $30 = $27 & 31;
  $31 = $30 | $29;
  $32 = $31 | 32768;
  $33 = $32&65535;
  $34 = (($2) + 2|0);
  HEAP16[$2>>1] = $33;
  $35 = (($4) + -1)|0;
  $count$1 = $35;$dest$1 = $34;$src$1 = $25;
 }
 $36 = $count$1 >>> 1;
 $37 = ($36|0)==(0);
 if ($37) {
  $dest$3 = $dest$1;$src$3 = $src$1;
 } else {
  $38 = $36 << 1;
  $scevgep = (($dest$1) + ($38<<1)|0);
  $count2$01 = $36;$dest$22 = $dest$1;$src$23 = $src$1;
  while(1) {
   $39 = (($count2$01) + -1)|0;
   $40 = HEAP32[$src$23>>2]|0;
   $41 = (($src$23) + 4|0);
   $42 = $40 >>> 1;
   $43 = $42 & 2145419232;
   $44 = $40 & 2031647;
   $45 = $44 | $43;
   $46 = $45 | -2147450880;
   HEAP32[$dest$22>>2] = $46;
   $47 = (($dest$22) + 4|0);
   $48 = ($39|0)==(0);
   if ($48) {
    break;
   } else {
    $count2$01 = $39;$dest$22 = $47;$src$23 = $41;
   }
  }
  $scevgep12 = (($src$1) + ($38<<1)|0);
  $dest$3 = $scevgep;$src$3 = $scevgep12;
 }
 $49 = $count$1 & 1;
 $50 = ($49|0)==(0);
 if ($50) {
  STACKTOP = sp;return;
 }
 $51 = HEAP16[$src$3>>1]|0;
 $52 = $51&65535;
 $53 = $52 >>> 1;
 $54 = $53 & 32736;
 $55 = $52 & 31;
 $56 = $55 | $54;
 $57 = $56 | 32768;
 $58 = $57&65535;
 HEAP16[$dest$3>>1] = $58;
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb565_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $count$07 = 0, $count$1 = 0, $count2$01 = 0, $dest$08 = 0, $dest$1 = 0;
 var $dest$22 = 0, $dest$3 = 0, $scevgep = 0, $scevgep12 = 0, $src$09 = 0, $src$1 = 0, $src$23 = 0, $src$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$info>>2]|0;
 $3 = (($info) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $1;
 $6 = $2;
 $7 = $6 ^ $5;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($4|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $count$07 = $4;$dest$08 = $2;$src$09 = $1;
  }
  while(1) {
   $11 = (($count$07) + -1)|0;
   $12 = (($src$09) + 2|0);
   $13 = HEAP16[$src$09>>1]|0;
   $14 = $13&65535;
   $15 = $14 >>> 4;
   $16 = $15 & 3840;
   $17 = $14 >>> 3;
   $18 = $17 & 240;
   $19 = $14 >>> 1;
   $20 = $19 & 15;
   $21 = $18 | $16;
   $22 = $21 | $20;
   $23 = $22 | 61440;
   $24 = $23&65535;
   $25 = (($dest$08) + 2|0);
   HEAP16[$dest$08>>1] = $24;
   $26 = ($11|0)==(0);
   if ($26) {
    break;
   } else {
    $count$07 = $11;$dest$08 = $25;$src$09 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $27 = $5 & 2;
 $28 = ($27|0)==(0);
 if ($28) {
  $count$1 = $4;$dest$1 = $2;$src$1 = $1;
 } else {
  $29 = (($1) + 2|0);
  $30 = HEAP16[$1>>1]|0;
  $31 = $30&65535;
  $32 = $31 >>> 4;
  $33 = $32 & 3840;
  $34 = $31 >>> 3;
  $35 = $34 & 240;
  $36 = $31 >>> 1;
  $37 = $36 & 15;
  $38 = $35 | $33;
  $39 = $38 | $37;
  $40 = $39 | 61440;
  $41 = $40&65535;
  $42 = (($2) + 2|0);
  HEAP16[$2>>1] = $41;
  $43 = (($4) + -1)|0;
  $count$1 = $43;$dest$1 = $42;$src$1 = $29;
 }
 $44 = $count$1 >>> 1;
 $45 = ($44|0)==(0);
 if ($45) {
  $dest$3 = $dest$1;$src$3 = $src$1;
 } else {
  $46 = $44 << 1;
  $scevgep = (($dest$1) + ($46<<1)|0);
  $count2$01 = $44;$dest$22 = $dest$1;$src$23 = $src$1;
  while(1) {
   $47 = (($count2$01) + -1)|0;
   $48 = HEAP32[$src$23>>2]|0;
   $49 = (($src$23) + 4|0);
   $50 = $48 >>> 4;
   $51 = $50 & 251662080;
   $52 = $48 >>> 3;
   $53 = $52 & 15728880;
   $54 = $48 >>> 1;
   $55 = $54 & 983055;
   $56 = $53 | $51;
   $57 = $56 | $55;
   $58 = $57 | -268374016;
   HEAP32[$dest$22>>2] = $58;
   $59 = (($dest$22) + 4|0);
   $60 = ($47|0)==(0);
   if ($60) {
    break;
   } else {
    $count2$01 = $47;$dest$22 = $59;$src$23 = $49;
   }
  }
  $scevgep12 = (($src$1) + ($46<<1)|0);
  $dest$3 = $scevgep;$src$3 = $scevgep12;
 }
 $61 = $count$1 & 1;
 $62 = ($61|0)==(0);
 if ($62) {
  STACKTOP = sp;return;
 }
 $63 = HEAP16[$src$3>>1]|0;
 $64 = $63&65535;
 $65 = $64 >>> 4;
 $66 = $65 & 3840;
 $67 = $64 >>> 3;
 $68 = $67 & 240;
 $69 = $64 >>> 1;
 $70 = $69 & 15;
 $71 = $68 | $66;
 $72 = $71 | $70;
 $73 = $72 | 61440;
 $74 = $73&65535;
 HEAP16[$dest$3>>1] = $74;
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb565_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 << 8;
  $11 = $10 & 16252928;
  $12 = $9 << 5;
  $13 = $12 & 64512;
  $14 = $9 << 3;
  $15 = $14 & 248;
  $16 = $13 | $11;
  $17 = $16 | $15;
  $18 = $17 | -16777216;
  $19 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $18;
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $19;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL33inner_remap_rgb565_bgr888_correctP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$01 = $1;$dest$02 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$01) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 & 2016;
  $11 = $9 >>> 8;
  $12 = $11 & 248;
  $13 = $9 >>> 13;
  $14 = $12 | $13;
  $15 = $10 << 5;
  $16 = $10 >>> 1;
  $17 = $15 | $16;
  $18 = $9 << 19;
  $19 = $9 << 14;
  $20 = $19 & 458752;
  $21 = $20 | $18;
  $22 = $14&255;
  HEAP8[$dest$02>>0] = $22;
  $23 = $17 >>> 8;
  $24 = $23&255;
  $25 = (($dest$02) + 1|0);
  HEAP8[$25>>0] = $24;
  $26 = $21 >>> 16;
  $27 = $26&255;
  $28 = (($dest$02) + 2|0);
  HEAP8[$28>>0] = $27;
  $29 = (($dest$02) + 3|0);
  $30 = ($6|0)==(0);
  if ($30) {
   break;
  } else {
   $count$01 = $6;$dest$02 = $29;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_rgb888_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$03 = $1;$dest$02 = $4;$src$04 = $5;
 while(1) {
  $6 = (($count$03) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $7 = $src$0$val&255;
  $8 = $src$0$idx$val&255;
  $9 = $src$0$idx1$val&255;
  $10 = (($src$04) + 3|0);
  $11 = ((1138392 + ($9<<2)|0) + 2|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = $12&255;
  $14 = ((1138392 + ($8<<2)|0) + 1|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15&255;
  $17 = (($16) + ($13))|0;
  $18 = (1138392 + ($7<<2)|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19&255;
  $21 = (($17) + ($20))|0;
  $22 = $21&255;
  $23 = (($dest$02) + 1|0);
  HEAP8[$dest$02>>0] = $22;
  $24 = ($6|0)==(0);
  if ($24) {
   break;
  } else {
   $count$03 = $6;$dest$02 = $23;$src$04 = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZL25inner_remap_rgb888_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$03 = 0, $dest$02 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$03 = $1;$dest$02 = $4;$src$04 = $5;
 while(1) {
  $6 = (($count$03) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $7 = $src$0$val&255;
  $8 = $src$0$idx$val&255;
  $9 = $src$0$idx1$val&255;
  $10 = (($src$04) + 3|0);
  $11 = $9 & 224;
  $12 = $8 >>> 3;
  $13 = $12 & 28;
  $14 = $7 >>> 6;
  $15 = $13 | $14;
  $16 = $15 | $11;
  $17 = $16&255;
  $18 = (($dest$02) + 1|0);
  HEAP8[$dest$02>>0] = $17;
  $19 = ($6|0)==(0);
  if ($19) {
   break;
  } else {
   $count$03 = $6;$dest$02 = $18;$src$04 = $10;
  }
 }
 STACKTOP = sp;return;
}
function __ZL25inner_remap_rgb888_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$03 = 0, $dest$02 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$03 = $1;$dest$02 = $3;$src$04 = $5;
 while(1) {
  $6 = (($count$03) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $7 = $src$0$val&255;
  $8 = $src$0$idx$val&255;
  $9 = $8 << 3;
  $10 = $src$0$idx1$val&255;
  $11 = $10 << 8;
  $12 = (($src$04) + 3|0);
  $13 = $11 & 63488;
  $14 = $9 & 2016;
  $15 = $7 >>> 3;
  $16 = $14 | $15;
  $17 = $16 | $13;
  $18 = $17&65535;
  $19 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $18;
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$03 = $6;$dest$02 = $19;$src$04 = $12;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb888_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$03 = $1;$dest$02 = $3;$src$04 = $5;
 while(1) {
  $6 = (($count$03) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $7 = $src$0$val&255;
  $8 = $src$0$idx$val&255;
  $9 = $8 << 2;
  $10 = $src$0$idx1$val&255;
  $11 = $10 << 7;
  $12 = (($src$04) + 3|0);
  $13 = $11 & 31744;
  $14 = $9 & 992;
  $15 = $7 >>> 3;
  $16 = $15 | $14;
  $17 = $16 | $13;
  $18 = $17 | 32768;
  $19 = $18&65535;
  $20 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $19;
  $21 = ($6|0)==(0);
  if ($21) {
   break;
  } else {
   $count$03 = $6;$dest$02 = $20;$src$04 = $12;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb888_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$03 = 0, $dest$02 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$03 = $1;$dest$02 = $3;$src$04 = $5;
 while(1) {
  $6 = (($count$03) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $7 = $src$0$val&255;
  $8 = $src$0$idx$val&255;
  $9 = $src$0$idx1$val&255;
  $10 = $9 << 4;
  $11 = (($src$04) + 3|0);
  $12 = $10 & 3840;
  $13 = $8 & 240;
  $14 = $7 >>> 4;
  $15 = $14 | $13;
  $16 = $15 | $12;
  $17 = $16 | 61440;
  $18 = $17&65535;
  $19 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $18;
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$03 = $6;$dest$02 = $19;$src$04 = $11;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_rgb888_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0, $dest$03 = 0;
 var $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $count$04 = $1;$dest$03 = $3;$src$02 = $5;
 while(1) {
  $6 = (($count$04) + -1)|0;
  $src$0$val = HEAP8[$src$02>>0]|0;
  $src$0$idx = (($src$02) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$02) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $7 = $src$0$val&255;
  $8 = $src$0$idx$val&255;
  $9 = $8 << 8;
  $10 = $src$0$idx1$val&255;
  $11 = $10 << 16;
  $12 = $7 | $9;
  $13 = $12 | $11;
  $14 = $13 | -16777216;
  $15 = (($dest$03) + 4|0);
  HEAP32[$dest$03>>2] = $14;
  $16 = (($src$02) + 3|0);
  $17 = ($6|0)==(0);
  if ($17) {
   break;
  } else {
   $count$04 = $6;$dest$03 = $15;$src$02 = $16;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_argb1555_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 >>> 7;
  $11 = $10 & 248;
  $12 = ((1138392 + ($11<<2)|0) + 2|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $9 >>> 2;
  $16 = $15 & 248;
  $17 = ((1138392 + ($16<<2)|0) + 1|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = (($19) + ($14))|0;
  $21 = $9 << 3;
  $22 = $21 & 248;
  $23 = (1138392 + ($22<<2)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = (($20) + ($25))|0;
  $27 = $26&255;
  $28 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $27;
  $29 = ($6|0)==(0);
  if ($29) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $28;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb1555_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 >>> 7;
  $11 = $10 & 224;
  $12 = $9 >>> 5;
  $13 = $12 & 28;
  $14 = $11 | $13;
  $15 = $9 >>> 3;
  $16 = $15 & 3;
  $17 = $14 | $16;
  $18 = $17&255;
  $19 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $18;
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $19;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb1555_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$07 = 0, $count$1 = 0, $count2$01 = 0, $dest$08 = 0, $dest$1 = 0, $dest$22 = 0, $dest$3 = 0, $scevgep = 0, $scevgep12 = 0;
 var $src$09 = 0, $src$1 = 0, $src$23 = 0, $src$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$info>>2]|0;
 $3 = (($info) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $1;
 $6 = $2;
 $7 = $6 ^ $5;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($4|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $count$07 = $4;$dest$08 = $2;$src$09 = $1;
  }
  while(1) {
   $11 = (($count$07) + -1)|0;
   $12 = (($src$09) + 2|0);
   $13 = HEAP16[$src$09>>1]|0;
   $14 = $13&65535;
   $15 = $14 & 32767;
   $16 = $14 & 32736;
   $17 = (($15) + ($16))|0;
   $18 = $17&65535;
   $19 = (($dest$08) + 2|0);
   HEAP16[$dest$08>>1] = $18;
   $20 = ($11|0)==(0);
   if ($20) {
    break;
   } else {
    $count$07 = $11;$dest$08 = $19;$src$09 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $21 = $5 & 2;
 $22 = ($21|0)==(0);
 if ($22) {
  $count$1 = $4;$dest$1 = $2;$src$1 = $1;
 } else {
  $23 = (($1) + 2|0);
  $24 = HEAP16[$1>>1]|0;
  $25 = $24&65535;
  $26 = $25 & 32767;
  $27 = $25 & 32736;
  $28 = (($26) + ($27))|0;
  $29 = $28&65535;
  $30 = (($2) + 2|0);
  HEAP16[$2>>1] = $29;
  $31 = (($4) + -1)|0;
  $count$1 = $31;$dest$1 = $30;$src$1 = $23;
 }
 $32 = $count$1 >>> 1;
 $33 = ($32|0)==(0);
 if ($33) {
  $dest$3 = $dest$1;$src$3 = $src$1;
 } else {
  $34 = $32 << 1;
  $scevgep = (($dest$1) + ($34<<1)|0);
  $count2$01 = $32;$dest$22 = $dest$1;$src$23 = $src$1;
  while(1) {
   $35 = (($count2$01) + -1)|0;
   $36 = HEAP32[$src$23>>2]|0;
   $37 = $36 & 2147450879;
   $38 = (($src$23) + 4|0);
   $39 = $36 & 2145419232;
   $40 = (($37) + ($39))|0;
   HEAP32[$dest$22>>2] = $40;
   $41 = (($dest$22) + 4|0);
   $42 = ($35|0)==(0);
   if ($42) {
    break;
   } else {
    $count2$01 = $35;$dest$22 = $41;$src$23 = $38;
   }
  }
  $scevgep12 = (($src$1) + ($34<<1)|0);
  $dest$3 = $scevgep;$src$3 = $scevgep12;
 }
 $43 = $count$1 & 1;
 $44 = ($43|0)==(0);
 if ($44) {
  STACKTOP = sp;return;
 }
 $45 = HEAP16[$src$3>>1]|0;
 $46 = $45&65535;
 $47 = $46 & 32767;
 $48 = $46 & 32736;
 $49 = (($47) + ($48))|0;
 $50 = $49&65535;
 HEAP16[$dest$3>>1] = $50;
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb1555_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 << 3;
  $11 = $10&255;
  HEAP8[$dest$01>>0] = $11;
  $12 = $9 >>> 2;
  $13 = $12 & 248;
  $14 = $13&255;
  $15 = (($dest$01) + 1|0);
  HEAP8[$15>>0] = $14;
  $16 = $9 >>> 7;
  $17 = $16 & 248;
  $18 = $17&255;
  $19 = (($dest$01) + 2|0);
  HEAP8[$19>>0] = $18;
  $20 = (($dest$01) + 3|0);
  $21 = ($6|0)==(0);
  if ($21) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $20;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_remap_argb1555_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $count$07 = 0, $count$1 = 0, $count2$01 = 0, $dest$08 = 0, $dest$1 = 0, $dest$22 = 0, $dest$3 = 0, $scevgep = 0, $scevgep12 = 0, $src$09 = 0, $src$1 = 0, $src$23 = 0, $src$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$info>>2]|0;
 $3 = (($info) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $1;
 $6 = $2;
 $7 = $6 ^ $5;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($4|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $count$07 = $4;$dest$08 = $2;$src$09 = $1;
  }
  while(1) {
   $11 = (($count$07) + -1)|0;
   $12 = (($src$09) + 2|0);
   $13 = HEAP16[$src$09>>1]|0;
   $14 = $13&65535;
   $15 = $14 >>> 3;
   $16 = $15 & 3840;
   $17 = $14 >>> 2;
   $18 = $17 & 240;
   $19 = $16 | $18;
   $20 = $14 >>> 1;
   $21 = $20 & 15;
   $22 = $19 | $21;
   $23 = $15 & 4096;
   $24 = (65536 - ($23))|0;
   $25 = $22 | $24;
   $26 = $25&65535;
   $27 = (($dest$08) + 2|0);
   HEAP16[$dest$08>>1] = $26;
   $28 = ($11|0)==(0);
   if ($28) {
    break;
   } else {
    $count$07 = $11;$dest$08 = $27;$src$09 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $29 = $5 & 2;
 $30 = ($29|0)==(0);
 if ($30) {
  $count$1 = $4;$dest$1 = $2;$src$1 = $1;
 } else {
  $31 = (($1) + 2|0);
  $32 = HEAP16[$1>>1]|0;
  $33 = $32&65535;
  $34 = $33 >>> 3;
  $35 = $34 & 3840;
  $36 = $33 >>> 2;
  $37 = $36 & 240;
  $38 = $35 | $37;
  $39 = $33 >>> 1;
  $40 = $39 & 15;
  $41 = $38 | $40;
  $42 = $34 & 4096;
  $43 = (65536 - ($42))|0;
  $44 = $41 | $43;
  $45 = $44&65535;
  $46 = (($2) + 2|0);
  HEAP16[$2>>1] = $45;
  $47 = (($4) + -1)|0;
  $count$1 = $47;$dest$1 = $46;$src$1 = $31;
 }
 $48 = $count$1 >>> 1;
 $49 = ($48|0)==(0);
 if ($49) {
  $dest$3 = $dest$1;$src$3 = $src$1;
 } else {
  $50 = $48 << 1;
  $scevgep = (($dest$1) + ($50<<1)|0);
  $count2$01 = $48;$dest$22 = $dest$1;$src$23 = $src$1;
  while(1) {
   $51 = (($count2$01) + -1)|0;
   $52 = HEAP32[$src$23>>2]|0;
   $53 = (($src$23) + 4|0);
   $54 = $52 >>> 3;
   $55 = $54 & 251662080;
   $56 = $52 >>> 2;
   $57 = $56 & 15728880;
   $58 = $55 | $57;
   $59 = $52 >>> 1;
   $60 = $59 & 983055;
   $61 = $58 | $60;
   $62 = $52 >>> 4;
   $63 = $62 & 2048;
   $64 = (0 - ($63))|0;
   $65 = $64 & -268374016;
   $66 = $61 | $65;
   HEAP32[$dest$22>>2] = $66;
   $67 = (($dest$22) + 4|0);
   $68 = ($51|0)==(0);
   if ($68) {
    break;
   } else {
    $count2$01 = $51;$dest$22 = $67;$src$23 = $53;
   }
  }
  $scevgep12 = (($src$1) + ($50<<1)|0);
  $dest$3 = $scevgep;$src$3 = $scevgep12;
 }
 $69 = $count$1 & 1;
 $70 = ($69|0)==(0);
 if ($70) {
  STACKTOP = sp;return;
 }
 $71 = HEAP16[$src$3>>1]|0;
 $72 = $71&65535;
 $73 = $72 >>> 3;
 $74 = $73 & 3840;
 $75 = $72 >>> 2;
 $76 = $75 & 240;
 $77 = $74 | $76;
 $78 = $72 >>> 1;
 $79 = $78 & 15;
 $80 = $77 | $79;
 $81 = $73 & 4096;
 $82 = (65536 - ($81))|0;
 $83 = $80 | $82;
 $84 = $83&65535;
 HEAP16[$dest$3>>1] = $84;
 STACKTOP = sp;return;
}
function __ZL29inner_remap_argb1555_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 << 9;
  $11 = $10 & 16252928;
  $12 = $9 << 6;
  $13 = $12 & 63488;
  $14 = $11 | $13;
  $15 = $9 << 3;
  $16 = $15 & 248;
  $17 = $14 | $16;
  $18 = $9 & 32768;
  $19 = (0 - ($18))|0;
  $20 = $19 & -16777216;
  $21 = $17 | $20;
  $22 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $21;
  $23 = ($6|0)==(0);
  if ($23) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $22;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_argb4444_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 >>> 8;
  $11 = $10 & 15;
  $12 = ((1138392 + ($11<<2)|0) + 2|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $9 & 240;
  $16 = ((1138392 + ($15<<2)|0) + 1|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = (($18) + ($14))|0;
  $20 = $9 << 4;
  $21 = $20 & 240;
  $22 = (1138392 + ($21<<2)|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = (($19) + ($24))|0;
  $26 = $25&255;
  $27 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $26;
  $28 = ($6|0)==(0);
  if ($28) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $27;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb4444_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 >>> 4;
  $11 = $10 & 224;
  $12 = $9 >>> 3;
  $13 = $12 & 28;
  $14 = $11 | $13;
  $15 = $9 >>> 2;
  $16 = $15 & 3;
  $17 = $14 | $16;
  $18 = $17&255;
  $19 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $18;
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $19;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb4444_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $count$07 = 0, $count$1 = 0, $count2$01 = 0, $dest$08 = 0, $dest$1 = 0, $dest$22 = 0, $dest$3 = 0, $scevgep = 0, $scevgep12 = 0;
 var $src$09 = 0, $src$1 = 0, $src$23 = 0, $src$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$info>>2]|0;
 $3 = (($info) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $1;
 $6 = $2;
 $7 = $6 ^ $5;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($4|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $count$07 = $4;$dest$08 = $2;$src$09 = $1;
  }
  while(1) {
   $11 = (($count$07) + -1)|0;
   $12 = (($src$09) + 2|0);
   $13 = HEAP16[$src$09>>1]|0;
   $14 = $13&65535;
   $15 = $14 << 4;
   $16 = $15 & 61440;
   $17 = $14 << 3;
   $18 = $17 & 1920;
   $19 = $16 | $18;
   $20 = $14 << 1;
   $21 = $20 & 30;
   $22 = $19 | $21;
   $23 = $22&65535;
   $24 = (($dest$08) + 2|0);
   HEAP16[$dest$08>>1] = $23;
   $25 = ($11|0)==(0);
   if ($25) {
    break;
   } else {
    $count$07 = $11;$dest$08 = $24;$src$09 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $26 = $5 & 2;
 $27 = ($26|0)==(0);
 if ($27) {
  $count$1 = $4;$dest$1 = $2;$src$1 = $1;
 } else {
  $28 = (($1) + 2|0);
  $29 = HEAP16[$1>>1]|0;
  $30 = $29&65535;
  $31 = $30 << 4;
  $32 = $31 & 61440;
  $33 = $30 << 3;
  $34 = $33 & 1920;
  $35 = $32 | $34;
  $36 = $30 << 1;
  $37 = $36 & 30;
  $38 = $35 | $37;
  $39 = $38&65535;
  $40 = (($2) + 2|0);
  HEAP16[$2>>1] = $39;
  $41 = (($4) + -1)|0;
  $count$1 = $41;$dest$1 = $40;$src$1 = $28;
 }
 $42 = $count$1 >>> 1;
 $43 = ($42|0)==(0);
 if ($43) {
  $dest$3 = $dest$1;$src$3 = $src$1;
 } else {
  $44 = $42 << 1;
  $scevgep = (($dest$1) + ($44<<1)|0);
  $count2$01 = $42;$dest$22 = $dest$1;$src$23 = $src$1;
  while(1) {
   $45 = (($count2$01) + -1)|0;
   $46 = HEAP32[$src$23>>2]|0;
   $47 = (($src$23) + 4|0);
   $48 = $46 << 4;
   $49 = $48 & -268374016;
   $50 = $46 << 3;
   $51 = $50 & 125831040;
   $52 = $49 | $51;
   $53 = $46 << 1;
   $54 = $53 & 1966110;
   $55 = $52 | $54;
   HEAP32[$dest$22>>2] = $55;
   $56 = (($dest$22) + 4|0);
   $57 = ($45|0)==(0);
   if ($57) {
    break;
   } else {
    $count2$01 = $45;$dest$22 = $56;$src$23 = $47;
   }
  }
  $scevgep12 = (($src$1) + ($44<<1)|0);
  $dest$3 = $scevgep;$src$3 = $scevgep12;
 }
 $58 = $count$1 & 1;
 $59 = ($58|0)==(0);
 if ($59) {
  STACKTOP = sp;return;
 }
 $60 = HEAP16[$src$3>>1]|0;
 $61 = $60&65535;
 $62 = $61 << 4;
 $63 = $62 & 61440;
 $64 = $61 << 3;
 $65 = $64 & 1920;
 $66 = $63 | $65;
 $67 = $61 << 1;
 $68 = $67 & 30;
 $69 = $66 | $68;
 $70 = $69&65535;
 HEAP16[$dest$3>>1] = $70;
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb4444_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 & 240;
  $11 = $9 << 4;
  $12 = $11&255;
  HEAP8[$dest$01>>0] = $12;
  $13 = $10&255;
  $14 = (($dest$01) + 1|0);
  HEAP8[$14>>0] = $13;
  $15 = $9 >>> 4;
  $16 = $15 & 240;
  $17 = $16&255;
  $18 = (($dest$01) + 2|0);
  HEAP8[$18>>0] = $17;
  $19 = (($dest$01) + 3|0);
  $20 = ($6|0)==(0);
  if ($20) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $19;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_remap_argb4444_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $count$07 = 0;
 var $count$1 = 0, $count2$01 = 0, $dest$08 = 0, $dest$1 = 0, $dest$22 = 0, $dest$3 = 0, $scevgep = 0, $scevgep12 = 0, $src$09 = 0, $src$1 = 0, $src$23 = 0, $src$3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$info>>2]|0;
 $3 = (($info) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $1;
 $6 = $2;
 $7 = $6 ^ $5;
 $8 = $7 & 2;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = ($4|0)==(0);
  if ($10) {
   STACKTOP = sp;return;
  } else {
   $count$07 = $4;$dest$08 = $2;$src$09 = $1;
  }
  while(1) {
   $11 = (($count$07) + -1)|0;
   $12 = (($src$09) + 2|0);
   $13 = HEAP16[$src$09>>1]|0;
   $14 = $13&65535;
   $15 = $14 << 3;
   $16 = $15 & 30720;
   $17 = $14 << 2;
   $18 = $17 & 960;
   $19 = $14 << 1;
   $20 = $19 & 30;
   $21 = $14 & 32768;
   $22 = $18 | $21;
   $23 = $22 | $16;
   $24 = $23 | $20;
   $25 = $24&65535;
   $26 = (($dest$08) + 2|0);
   HEAP16[$dest$08>>1] = $25;
   $27 = ($11|0)==(0);
   if ($27) {
    break;
   } else {
    $count$07 = $11;$dest$08 = $26;$src$09 = $12;
   }
  }
  STACKTOP = sp;return;
 }
 $28 = $5 & 2;
 $29 = ($28|0)==(0);
 if ($29) {
  $count$1 = $4;$dest$1 = $2;$src$1 = $1;
 } else {
  $30 = (($1) + 2|0);
  $31 = HEAP16[$1>>1]|0;
  $32 = $31&65535;
  $33 = $32 << 3;
  $34 = $33 & 30720;
  $35 = $32 << 2;
  $36 = $35 & 960;
  $37 = $32 << 1;
  $38 = $37 & 30;
  $39 = $32 & 32768;
  $40 = $36 | $39;
  $41 = $40 | $34;
  $42 = $41 | $38;
  $43 = $42&65535;
  $44 = (($2) + 2|0);
  HEAP16[$2>>1] = $43;
  $45 = (($4) + -1)|0;
  $count$1 = $45;$dest$1 = $44;$src$1 = $30;
 }
 $46 = $count$1 >>> 1;
 $47 = ($46|0)==(0);
 if ($47) {
  $dest$3 = $dest$1;$src$3 = $src$1;
 } else {
  $48 = $46 << 1;
  $scevgep = (($dest$1) + ($48<<1)|0);
  $count2$01 = $46;$dest$22 = $dest$1;$src$23 = $src$1;
  while(1) {
   $49 = (($count2$01) + -1)|0;
   $50 = HEAP32[$src$23>>2]|0;
   $51 = (($src$23) + 4|0);
   $52 = $50 << 3;
   $53 = $52 & 2013296640;
   $54 = $50 << 2;
   $55 = $54 & 62915520;
   $56 = $50 << 1;
   $57 = $56 & 1966110;
   $58 = $50 & -2147450880;
   $59 = $55 | $58;
   $60 = $59 | $53;
   $61 = $60 | $57;
   HEAP32[$dest$22>>2] = $61;
   $62 = (($dest$22) + 4|0);
   $63 = ($49|0)==(0);
   if ($63) {
    break;
   } else {
    $count2$01 = $49;$dest$22 = $62;$src$23 = $51;
   }
  }
  $scevgep12 = (($src$1) + ($48<<1)|0);
  $dest$3 = $scevgep;$src$3 = $scevgep12;
 }
 $64 = $count$1 & 1;
 $65 = ($64|0)==(0);
 if ($65) {
  STACKTOP = sp;return;
 }
 $66 = HEAP16[$src$3>>1]|0;
 $67 = $66&65535;
 $68 = $67 << 3;
 $69 = $68 & 30720;
 $70 = $67 << 2;
 $71 = $70 & 960;
 $72 = $67 << 1;
 $73 = $72 & 30;
 $74 = $67 & 32768;
 $75 = $71 | $74;
 $76 = $75 | $69;
 $77 = $76 | $73;
 $78 = $77&65535;
 HEAP16[$dest$3>>1] = $78;
 STACKTOP = sp;return;
}
function __ZL37inner_remap_argb4444_argb8888_correctP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 << 12;
  $11 = $10 & 251658240;
  $12 = $9 << 8;
  $13 = $12 & 983040;
  $14 = $9 << 4;
  $15 = $14 & 3840;
  $16 = $9 & 15;
  $17 = $13 | $16;
  $18 = $17 | $11;
  $19 = $18 | $15;
  $20 = $19 << 4;
  $21 = $20 | $19;
  $22 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $21;
  $23 = ($6|0)==(0);
  if ($23) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $22;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_remap_argb4444_abgr8888_correctP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 << 12;
  $11 = $10 & 251658240;
  $12 = $9 >>> 8;
  $13 = $12 & 15;
  $14 = $11 | $13;
  $15 = $9 << 4;
  $16 = $15 & 3840;
  $17 = $14 | $16;
  $18 = $9 << 16;
  $19 = $18 & 983040;
  $20 = $17 | $19;
  $21 = $20 << 4;
  $22 = $21 | $20;
  $23 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $22;
  $24 = ($6|0)==(0);
  if ($24) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $23;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_argb8888_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 4|0);
  $8 = HEAP32[$src$03>>2]|0;
  $9 = $8 >>> 16;
  $10 = $9 & 255;
  $11 = ((1138392 + ($10<<2)|0) + 2|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = $12&255;
  $14 = $8 >>> 8;
  $15 = $14 & 255;
  $16 = ((1138392 + ($15<<2)|0) + 1|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = (($18) + ($13))|0;
  $20 = $8 & 255;
  $21 = (1138392 + ($20<<2)|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = (($19) + ($23))|0;
  $25 = $24&255;
  $26 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $25;
  $27 = ($6|0)==(0);
  if ($27) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $26;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb8888_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 4|0);
  $8 = HEAP32[$src$03>>2]|0;
  $9 = $8 >>> 16;
  $10 = $9 & 224;
  $11 = $8 >>> 11;
  $12 = $11 & 28;
  $13 = $10 | $12;
  $14 = $8 >>> 6;
  $15 = $14 & 3;
  $16 = $13 | $15;
  $17 = $16&255;
  $18 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $17;
  $19 = ($6|0)==(0);
  if ($19) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $18;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb8888_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 4|0);
  $8 = HEAP32[$src$03>>2]|0;
  $9 = $8 >>> 8;
  $10 = $9 & 63488;
  $11 = $8 >>> 5;
  $12 = $11 & 2016;
  $13 = $10 | $12;
  $14 = $8 >>> 3;
  $15 = $14 & 31;
  $16 = $13 | $15;
  $17 = $16&65535;
  $18 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $17;
  $19 = ($6|0)==(0);
  if ($19) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $18;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL27inner_remap_argb8888_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0;
 var $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 4|0);
  $8 = HEAP32[$src$03>>2]|0;
  $9 = $8&255;
  HEAP8[$dest$01>>0] = $9;
  $10 = $8 >>> 8;
  $11 = $10&255;
  $12 = (($dest$01) + 1|0);
  HEAP8[$12>>0] = $11;
  $13 = $8 >>> 16;
  $14 = $13&255;
  $15 = (($dest$01) + 2|0);
  HEAP8[$15>>0] = $14;
  $16 = (($dest$01) + 3|0);
  $17 = ($6|0)==(0);
  if ($17) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $16;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_remap_argb8888_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 4|0);
  $8 = HEAP32[$src$03>>2]|0;
  $9 = $8 >>> 9;
  $10 = $9 & 31744;
  $11 = $8 >>> 6;
  $12 = $11 & 992;
  $13 = $10 | $12;
  $14 = $8 >>> 3;
  $15 = $14 & 31;
  $16 = $13 | $15;
  $17 = $8 >>> 16;
  $18 = $17 & 32768;
  $19 = $16 | $18;
  $20 = $19&65535;
  $21 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $20;
  $22 = ($6|0)==(0);
  if ($22) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $21;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_remap_argb8888_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 4|0);
  $8 = HEAP32[$src$03>>2]|0;
  $9 = $8 >>> 12;
  $10 = $9 & 3840;
  $11 = $8 >>> 8;
  $12 = $11 & 240;
  $13 = $10 | $12;
  $14 = $8 >>> 4;
  $15 = $14 & 15;
  $16 = $13 | $15;
  $17 = $8 >>> 16;
  $18 = $17 & 61440;
  $19 = $16 | $18;
  $20 = $19&65535;
  $21 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $20;
  $22 = ($6|0)==(0);
  if ($22) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $21;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_remap_rgba4444_argb8888_correctP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 << 4;
  $11 = $10 & 983040;
  $12 = $9 & 3840;
  $13 = $11 | $12;
  $14 = $9 >>> 4;
  $15 = $14 & 15;
  $16 = $13 | $15;
  $17 = $9 << 24;
  $18 = $17 & 251658240;
  $19 = $16 | $18;
  $20 = $19 << 4;
  $21 = $20 | $19;
  $22 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $21;
  $23 = ($6|0)==(0);
  if ($23) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $22;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_remap_rgba4444_abgr8888_correctP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $6 = (($count$02) + -1)|0;
  $7 = (($src$03) + 2|0);
  $8 = HEAP16[$src$03>>1]|0;
  $9 = $8&65535;
  $10 = $9 >>> 12;
  $11 = $9 & 3840;
  $12 = $10 | $11;
  $13 = $9 << 12;
  $14 = $13 & 983040;
  $15 = $12 | $14;
  $16 = $9 << 24;
  $17 = $16 & 251658240;
  $18 = $15 | $17;
  $19 = $18 << 4;
  $20 = $19 | $18;
  $21 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $20;
  $22 = ($6|0)==(0);
  if ($22) {
   break;
  } else {
   $count$02 = $6;$dest$01 = $21;$src$03 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_1rgba_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02$i = $1;$dest$01$i = $4;$src$03$i = $5;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP8[$src$03$i>>0]|0;
  $23 = $22&255;
  $24 = HEAP32[$6>>2]|0;
  $25 = $23 >>> $24;
  $26 = HEAP32[$blitter>>2]|0;
  $27 = $25 << $26;
  $28 = HEAP32[$7>>2]|0;
  $29 = $27 & $28;
  $30 = ((1138392 + ($29<<2)|0) + 2|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31&255;
  $33 = HEAP32[$8>>2]|0;
  $34 = $23 >>> $33;
  $35 = HEAP32[$9>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$10>>2]|0;
  $38 = $36 & $37;
  $39 = ((1138392 + ($38<<2)|0) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = (($41) + ($32))|0;
  $43 = HEAP32[$11>>2]|0;
  $44 = $23 >>> $43;
  $45 = HEAP32[$12>>2]|0;
  $46 = $44 << $45;
  $47 = HEAP32[$13>>2]|0;
  $48 = $46 & $47;
  $49 = (1138392 + ($48<<2)|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = $50&255;
  $52 = (($42) + ($51))|0;
  $53 = HEAP32[$14>>2]|0;
  $54 = $52 >>> $53;
  $55 = HEAP32[$15>>2]|0;
  $56 = $54 << $55;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 & $57;
  $59 = HEAP32[$17>>2]|0;
  $60 = $23 >>> $59;
  $61 = HEAP32[$18>>2]|0;
  $62 = $60 << $61;
  $63 = HEAP32[$19>>2]|0;
  $64 = $62 & $63;
  $65 = $64 | $58;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 | $66;
  $68 = $67&255;
  HEAP8[$dest$01$i>>0] = $68;
  $69 = (($dest$01$i) + 1|0);
  $70 = (($src$03$i) + 1|0);
  $71 = ($21|0)==(0);
  if ($71) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $69;$src$03$i = $70;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_1rgba_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre$i = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre16$i = 0, $$pre17$i = 0, $$pre18$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $$pre$i = HEAP32[$6>>2]|0;
 $$pre4$i = HEAP32[$blitter>>2]|0;
 $$pre5$i = HEAP32[$7>>2]|0;
 $$pre6$i = HEAP32[$8>>2]|0;
 $$pre7$i = HEAP32[$9>>2]|0;
 $$pre8$i = HEAP32[$10>>2]|0;
 $$pre9$i = HEAP32[$11>>2]|0;
 $$pre10$i = HEAP32[$12>>2]|0;
 $$pre11$i = HEAP32[$13>>2]|0;
 $$pre12$i = HEAP32[$14>>2]|0;
 $$pre13$i = HEAP32[$15>>2]|0;
 $$pre14$i = HEAP32[$16>>2]|0;
 $$pre15$i = HEAP32[$17>>2]|0;
 $$pre16$i = HEAP32[$18>>2]|0;
 $$pre17$i = HEAP32[$19>>2]|0;
 $$pre18$i = HEAP32[$20>>2]|0;
 $count$02$i = $1;$dest$01$i = $3;$src$03$i = $5;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP8[$src$03$i>>0]|0;
  $23 = $22&255;
  $24 = $23 >>> $$pre$i;
  $25 = $24 << $$pre4$i;
  $26 = $25 & $$pre5$i;
  $27 = ((1138392 + ($26<<2)|0) + 2|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = $23 >>> $$pre6$i;
  $31 = $30 << $$pre7$i;
  $32 = $31 & $$pre8$i;
  $33 = ((1138392 + ($32<<2)|0) + 1|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = $34&255;
  $36 = (($35) + ($29))|0;
  $37 = $23 >>> $$pre9$i;
  $38 = $37 << $$pre10$i;
  $39 = $38 & $$pre11$i;
  $40 = (1138392 + ($39<<2)|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41&255;
  $43 = (($36) + ($42))|0;
  $44 = $43 >>> $$pre12$i;
  $45 = $44 << $$pre13$i;
  $46 = $45 & $$pre14$i;
  $47 = $23 >>> $$pre15$i;
  $48 = $47 << $$pre16$i;
  $49 = $48 & $$pre17$i;
  $50 = $49 | $$pre18$i;
  $51 = $50 | $46;
  $52 = $51&65535;
  HEAP16[$dest$01$i>>1] = $52;
  $53 = (($dest$01$i) + 2|0);
  $54 = (($src$03$i) + 1|0);
  $55 = ($21|0)==(0);
  if ($55) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $53;$src$03$i = $54;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_1rgba_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0;
 var $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $22 = HEAP8[$src$03>>0]|0;
  $23 = $22&255;
  $24 = HEAP32[$6>>2]|0;
  $25 = $23 >>> $24;
  $26 = HEAP32[$blitter>>2]|0;
  $27 = $25 << $26;
  $28 = HEAP32[$7>>2]|0;
  $29 = $27 & $28;
  $30 = ((1138392 + ($29<<2)|0) + 2|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31&255;
  $33 = HEAP32[$8>>2]|0;
  $34 = $23 >>> $33;
  $35 = HEAP32[$9>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$10>>2]|0;
  $38 = $36 & $37;
  $39 = ((1138392 + ($38<<2)|0) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = (($41) + ($32))|0;
  $43 = HEAP32[$11>>2]|0;
  $44 = $23 >>> $43;
  $45 = HEAP32[$12>>2]|0;
  $46 = $44 << $45;
  $47 = HEAP32[$13>>2]|0;
  $48 = $46 & $47;
  $49 = (1138392 + ($48<<2)|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = $50&255;
  $52 = (($42) + ($51))|0;
  $53 = HEAP32[$14>>2]|0;
  $54 = $52 >>> $53;
  $55 = HEAP32[$15>>2]|0;
  $56 = $54 << $55;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 & $57;
  $59 = (($src$03) + 1|0);
  $60 = HEAP32[$17>>2]|0;
  $61 = $23 >>> $60;
  $62 = HEAP32[$18>>2]|0;
  $63 = $61 << $62;
  $64 = HEAP32[$19>>2]|0;
  $65 = $63 & $64;
  $66 = $65 | $58;
  $67 = HEAP32[$20>>2]|0;
  $68 = $66 | $67;
  $69 = $68&255;
  HEAP8[$dest$01>>0] = $69;
  $70 = $68 >>> 8;
  $71 = $70&255;
  $72 = (($dest$01) + 1|0);
  HEAP8[$72>>0] = $71;
  $73 = $68 >>> 16;
  $74 = $73&255;
  $75 = (($dest$01) + 2|0);
  HEAP8[$75>>0] = $74;
  $76 = (($dest$01) + 3|0);
  $77 = ($21|0)==(0);
  if ($77) {
   break;
  } else {
   $count$02 = $21;$dest$01 = $76;$src$03 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_1rgba_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02$i = $1;$dest$01$i = $3;$src$03$i = $5;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP8[$src$03$i>>0]|0;
  $23 = $22&255;
  $24 = HEAP32[$6>>2]|0;
  $25 = $23 >>> $24;
  $26 = HEAP32[$blitter>>2]|0;
  $27 = $25 << $26;
  $28 = HEAP32[$7>>2]|0;
  $29 = $27 & $28;
  $30 = ((1138392 + ($29<<2)|0) + 2|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31&255;
  $33 = HEAP32[$8>>2]|0;
  $34 = $23 >>> $33;
  $35 = HEAP32[$9>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$10>>2]|0;
  $38 = $36 & $37;
  $39 = ((1138392 + ($38<<2)|0) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = (($41) + ($32))|0;
  $43 = HEAP32[$11>>2]|0;
  $44 = $23 >>> $43;
  $45 = HEAP32[$12>>2]|0;
  $46 = $44 << $45;
  $47 = HEAP32[$13>>2]|0;
  $48 = $46 & $47;
  $49 = (1138392 + ($48<<2)|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = $50&255;
  $52 = (($42) + ($51))|0;
  $53 = HEAP32[$14>>2]|0;
  $54 = $52 >>> $53;
  $55 = HEAP32[$15>>2]|0;
  $56 = $54 << $55;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 & $57;
  $59 = HEAP32[$17>>2]|0;
  $60 = $23 >>> $59;
  $61 = HEAP32[$18>>2]|0;
  $62 = $60 << $61;
  $63 = HEAP32[$19>>2]|0;
  $64 = $62 & $63;
  $65 = $64 | $58;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 | $66;
  HEAP32[$dest$01$i>>2] = $67;
  $68 = (($dest$01$i) + 4|0);
  $69 = (($src$03$i) + 1|0);
  $70 = ($21|0)==(0);
  if ($70) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $68;$src$03$i = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_2rgba_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02$i = $1;$dest$01$i = $5;$src$03$i = $4;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP16[$src$03$i>>1]|0;
  $23 = $22&65535;
  $24 = HEAP32[$6>>2]|0;
  $25 = $23 >>> $24;
  $26 = HEAP32[$blitter>>2]|0;
  $27 = $25 << $26;
  $28 = HEAP32[$7>>2]|0;
  $29 = $27 & $28;
  $30 = ((1138392 + ($29<<2)|0) + 2|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31&255;
  $33 = HEAP32[$8>>2]|0;
  $34 = $23 >>> $33;
  $35 = HEAP32[$9>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$10>>2]|0;
  $38 = $36 & $37;
  $39 = ((1138392 + ($38<<2)|0) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = (($41) + ($32))|0;
  $43 = HEAP32[$11>>2]|0;
  $44 = $23 >>> $43;
  $45 = HEAP32[$12>>2]|0;
  $46 = $44 << $45;
  $47 = HEAP32[$13>>2]|0;
  $48 = $46 & $47;
  $49 = (1138392 + ($48<<2)|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = $50&255;
  $52 = (($42) + ($51))|0;
  $53 = HEAP32[$14>>2]|0;
  $54 = $52 >>> $53;
  $55 = HEAP32[$15>>2]|0;
  $56 = $54 << $55;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 & $57;
  $59 = HEAP32[$17>>2]|0;
  $60 = $23 >>> $59;
  $61 = HEAP32[$18>>2]|0;
  $62 = $60 << $61;
  $63 = HEAP32[$19>>2]|0;
  $64 = $62 & $63;
  $65 = $64 | $58;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 | $66;
  $68 = $67&255;
  HEAP8[$dest$01$i>>0] = $68;
  $69 = (($dest$01$i) + 1|0);
  $70 = (($src$03$i) + 2|0);
  $71 = ($21|0)==(0);
  if ($71) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $69;$src$03$i = $70;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_2rgba_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre$i = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre16$i = 0, $$pre17$i = 0, $$pre18$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $$pre$i = HEAP32[$6>>2]|0;
 $$pre4$i = HEAP32[$blitter>>2]|0;
 $$pre5$i = HEAP32[$7>>2]|0;
 $$pre6$i = HEAP32[$8>>2]|0;
 $$pre7$i = HEAP32[$9>>2]|0;
 $$pre8$i = HEAP32[$10>>2]|0;
 $$pre9$i = HEAP32[$11>>2]|0;
 $$pre10$i = HEAP32[$12>>2]|0;
 $$pre11$i = HEAP32[$13>>2]|0;
 $$pre12$i = HEAP32[$14>>2]|0;
 $$pre13$i = HEAP32[$15>>2]|0;
 $$pre14$i = HEAP32[$16>>2]|0;
 $$pre15$i = HEAP32[$17>>2]|0;
 $$pre16$i = HEAP32[$18>>2]|0;
 $$pre17$i = HEAP32[$19>>2]|0;
 $$pre18$i = HEAP32[$20>>2]|0;
 $count$02$i = $1;$dest$01$i = $4;$src$03$i = $5;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP16[$src$03$i>>1]|0;
  $23 = $22&65535;
  $24 = $23 >>> $$pre$i;
  $25 = $24 << $$pre4$i;
  $26 = $25 & $$pre5$i;
  $27 = ((1138392 + ($26<<2)|0) + 2|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = $23 >>> $$pre6$i;
  $31 = $30 << $$pre7$i;
  $32 = $31 & $$pre8$i;
  $33 = ((1138392 + ($32<<2)|0) + 1|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = $34&255;
  $36 = (($35) + ($29))|0;
  $37 = $23 >>> $$pre9$i;
  $38 = $37 << $$pre10$i;
  $39 = $38 & $$pre11$i;
  $40 = (1138392 + ($39<<2)|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41&255;
  $43 = (($36) + ($42))|0;
  $44 = $43 >>> $$pre12$i;
  $45 = $44 << $$pre13$i;
  $46 = $45 & $$pre14$i;
  $47 = $23 >>> $$pre15$i;
  $48 = $47 << $$pre16$i;
  $49 = $48 & $$pre17$i;
  $50 = $49 | $$pre18$i;
  $51 = $50 | $46;
  $52 = $51&65535;
  HEAP16[$dest$01$i>>1] = $52;
  $53 = (($dest$01$i) + 2|0);
  $54 = (($src$03$i) + 2|0);
  $55 = ($21|0)==(0);
  if ($55) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $53;$src$03$i = $54;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_2rgba_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0;
 var $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $22 = HEAP16[$src$03>>1]|0;
  $23 = $22&65535;
  $24 = HEAP32[$6>>2]|0;
  $25 = $23 >>> $24;
  $26 = HEAP32[$blitter>>2]|0;
  $27 = $25 << $26;
  $28 = HEAP32[$7>>2]|0;
  $29 = $27 & $28;
  $30 = ((1138392 + ($29<<2)|0) + 2|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31&255;
  $33 = HEAP32[$8>>2]|0;
  $34 = $23 >>> $33;
  $35 = HEAP32[$9>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$10>>2]|0;
  $38 = $36 & $37;
  $39 = ((1138392 + ($38<<2)|0) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = (($41) + ($32))|0;
  $43 = HEAP32[$11>>2]|0;
  $44 = $23 >>> $43;
  $45 = HEAP32[$12>>2]|0;
  $46 = $44 << $45;
  $47 = HEAP32[$13>>2]|0;
  $48 = $46 & $47;
  $49 = (1138392 + ($48<<2)|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = $50&255;
  $52 = (($42) + ($51))|0;
  $53 = HEAP32[$14>>2]|0;
  $54 = $52 >>> $53;
  $55 = HEAP32[$15>>2]|0;
  $56 = $54 << $55;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 & $57;
  $59 = (($src$03) + 2|0);
  $60 = HEAP32[$17>>2]|0;
  $61 = $23 >>> $60;
  $62 = HEAP32[$18>>2]|0;
  $63 = $61 << $62;
  $64 = HEAP32[$19>>2]|0;
  $65 = $63 & $64;
  $66 = $65 | $58;
  $67 = HEAP32[$20>>2]|0;
  $68 = $66 | $67;
  $69 = $68&255;
  HEAP8[$dest$01>>0] = $69;
  $70 = $68 >>> 8;
  $71 = $70&255;
  $72 = (($dest$01) + 1|0);
  HEAP8[$72>>0] = $71;
  $73 = $68 >>> 16;
  $74 = $73&255;
  $75 = (($dest$01) + 2|0);
  HEAP8[$75>>0] = $74;
  $76 = (($dest$01) + 3|0);
  $77 = ($21|0)==(0);
  if ($77) {
   break;
  } else {
   $count$02 = $21;$dest$01 = $76;$src$03 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_2rgba_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02$i = $1;$dest$01$i = $4;$src$03$i = $5;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP16[$src$03$i>>1]|0;
  $23 = $22&65535;
  $24 = HEAP32[$6>>2]|0;
  $25 = $23 >>> $24;
  $26 = HEAP32[$blitter>>2]|0;
  $27 = $25 << $26;
  $28 = HEAP32[$7>>2]|0;
  $29 = $27 & $28;
  $30 = ((1138392 + ($29<<2)|0) + 2|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31&255;
  $33 = HEAP32[$8>>2]|0;
  $34 = $23 >>> $33;
  $35 = HEAP32[$9>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$10>>2]|0;
  $38 = $36 & $37;
  $39 = ((1138392 + ($38<<2)|0) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = (($41) + ($32))|0;
  $43 = HEAP32[$11>>2]|0;
  $44 = $23 >>> $43;
  $45 = HEAP32[$12>>2]|0;
  $46 = $44 << $45;
  $47 = HEAP32[$13>>2]|0;
  $48 = $46 & $47;
  $49 = (1138392 + ($48<<2)|0);
  $50 = HEAP8[$49>>0]|0;
  $51 = $50&255;
  $52 = (($42) + ($51))|0;
  $53 = HEAP32[$14>>2]|0;
  $54 = $52 >>> $53;
  $55 = HEAP32[$15>>2]|0;
  $56 = $54 << $55;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 & $57;
  $59 = HEAP32[$17>>2]|0;
  $60 = $23 >>> $59;
  $61 = HEAP32[$18>>2]|0;
  $62 = $60 << $61;
  $63 = HEAP32[$19>>2]|0;
  $64 = $62 & $63;
  $65 = $64 | $58;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 | $66;
  HEAP32[$dest$01$i>>2] = $67;
  $68 = (($dest$01$i) + 4|0);
  $69 = (($src$03$i) + 2|0);
  $70 = ($21|0)==(0);
  if ($70) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $68;$src$03$i = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_3rgba_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$03 = 0, $src$0$idx = 0;
 var $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02 = $1;$dest$03 = $4;$src$04 = $5;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $22 = $src$0$val&255;
  $23 = $src$0$idx$val&255;
  $24 = $23 << 8;
  $25 = $24 | $22;
  $26 = $src$0$idx1$val&255;
  $27 = $26 << 16;
  $28 = $25 | $27;
  $29 = HEAP32[$6>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$7>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$8>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$9>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$10>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$11>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$12>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$13>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$14>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$15>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$16>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$17>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$18>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$19>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$20>>2]|0;
  $72 = $70 | $71;
  $73 = $72&255;
  $74 = (($dest$03) + 1|0);
  HEAP8[$dest$03>>0] = $73;
  $75 = (($src$04) + 3|0);
  $76 = ($21|0)==(0);
  if ($76) {
   break;
  } else {
   $count$02 = $21;$dest$03 = $74;$src$04 = $75;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_3rgba_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$03 = 0, $src$0$idx = 0;
 var $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $$pre = HEAP32[$6>>2]|0;
 $$pre5 = HEAP32[$blitter>>2]|0;
 $$pre6 = HEAP32[$7>>2]|0;
 $$pre7 = HEAP32[$8>>2]|0;
 $$pre8 = HEAP32[$9>>2]|0;
 $$pre9 = HEAP32[$10>>2]|0;
 $$pre10 = HEAP32[$11>>2]|0;
 $$pre11 = HEAP32[$12>>2]|0;
 $$pre12 = HEAP32[$13>>2]|0;
 $$pre13 = HEAP32[$14>>2]|0;
 $$pre14 = HEAP32[$15>>2]|0;
 $$pre15 = HEAP32[$16>>2]|0;
 $$pre16 = HEAP32[$17>>2]|0;
 $$pre17 = HEAP32[$18>>2]|0;
 $$pre18 = HEAP32[$19>>2]|0;
 $$pre19 = HEAP32[$20>>2]|0;
 $count$02 = $1;$dest$03 = $3;$src$04 = $5;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $22 = $src$0$val&255;
  $23 = $src$0$idx$val&255;
  $24 = $23 << 8;
  $25 = $24 | $22;
  $26 = $src$0$idx1$val&255;
  $27 = $26 << 16;
  $28 = $25 | $27;
  $29 = $28 >>> $$pre;
  $30 = $29 << $$pre5;
  $31 = $30 & $$pre6;
  $32 = ((1138392 + ($31<<2)|0) + 2|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = $28 >>> $$pre7;
  $36 = $35 << $$pre8;
  $37 = $36 & $$pre9;
  $38 = ((1138392 + ($37<<2)|0) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = (($40) + ($34))|0;
  $42 = $28 >>> $$pre10;
  $43 = $42 << $$pre11;
  $44 = $43 & $$pre12;
  $45 = (1138392 + ($44<<2)|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  $48 = (($41) + ($47))|0;
  $49 = $48 >>> $$pre13;
  $50 = $49 << $$pre14;
  $51 = $50 & $$pre15;
  $52 = $28 >>> $$pre16;
  $53 = $52 << $$pre17;
  $54 = $53 & $$pre18;
  $55 = $54 | $51;
  $56 = $55 | $$pre19;
  $57 = $56&65535;
  $58 = (($dest$03) + 2|0);
  HEAP16[$dest$03>>1] = $57;
  $59 = (($src$04) + 3|0);
  $60 = ($21|0)==(0);
  if ($60) {
   break;
  } else {
   $count$02 = $21;$dest$03 = $58;$src$04 = $59;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_3rgba_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, $count$02 = 0, $dest$03 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02 = $1;$dest$03 = $4;$src$04 = $5;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $22 = $src$0$val&255;
  $23 = $src$0$idx$val&255;
  $24 = $23 << 8;
  $25 = $24 | $22;
  $26 = $src$0$idx1$val&255;
  $27 = $26 << 16;
  $28 = $25 | $27;
  $29 = HEAP32[$6>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$7>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$8>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$9>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$10>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$11>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$12>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$13>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$14>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$15>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$16>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$17>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$18>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$19>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$20>>2]|0;
  $72 = $70 | $71;
  $73 = (($src$04) + 3|0);
  $74 = $72&255;
  HEAP8[$dest$03>>0] = $74;
  $75 = $72 >>> 8;
  $76 = $75&255;
  $77 = (($dest$03) + 1|0);
  HEAP8[$77>>0] = $76;
  $78 = $72 >>> 16;
  $79 = $78&255;
  $80 = (($dest$03) + 2|0);
  HEAP8[$80>>0] = $79;
  $81 = (($dest$03) + 3|0);
  $82 = ($21|0)==(0);
  if ($82) {
   break;
  } else {
   $count$02 = $21;$dest$03 = $81;$src$04 = $73;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_3rgba_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$03 = 0, $src$0$idx = 0, $src$0$idx$val = 0;
 var $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02 = $1;$dest$03 = $3;$src$04 = $5;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $22 = $src$0$val&255;
  $23 = $src$0$idx$val&255;
  $24 = $23 << 8;
  $25 = $24 | $22;
  $26 = $src$0$idx1$val&255;
  $27 = $26 << 16;
  $28 = $25 | $27;
  $29 = HEAP32[$6>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$7>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$8>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$9>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$10>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$11>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$12>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$13>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$14>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$15>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$16>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$17>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$18>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$19>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$20>>2]|0;
  $72 = $70 | $71;
  $73 = (($dest$03) + 4|0);
  HEAP32[$dest$03>>2] = $72;
  $74 = (($src$04) + 3|0);
  $75 = ($21|0)==(0);
  if ($75) {
   break;
  } else {
   $count$02 = $21;$dest$03 = $73;$src$04 = $74;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_4rgba_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02$i = $1;$dest$01$i = $5;$src$03$i = $4;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP32[$src$03$i>>2]|0;
  $23 = HEAP32[$6>>2]|0;
  $24 = $22 >>> $23;
  $25 = HEAP32[$blitter>>2]|0;
  $26 = $24 << $25;
  $27 = HEAP32[$7>>2]|0;
  $28 = $26 & $27;
  $29 = ((1138392 + ($28<<2)|0) + 2|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = HEAP32[$8>>2]|0;
  $33 = $22 >>> $32;
  $34 = HEAP32[$9>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$10>>2]|0;
  $37 = $35 & $36;
  $38 = ((1138392 + ($37<<2)|0) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = (($40) + ($31))|0;
  $42 = HEAP32[$11>>2]|0;
  $43 = $22 >>> $42;
  $44 = HEAP32[$12>>2]|0;
  $45 = $43 << $44;
  $46 = HEAP32[$13>>2]|0;
  $47 = $45 & $46;
  $48 = (1138392 + ($47<<2)|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49&255;
  $51 = (($41) + ($50))|0;
  $52 = HEAP32[$14>>2]|0;
  $53 = $51 >>> $52;
  $54 = HEAP32[$15>>2]|0;
  $55 = $53 << $54;
  $56 = HEAP32[$16>>2]|0;
  $57 = $55 & $56;
  $58 = HEAP32[$17>>2]|0;
  $59 = $22 >>> $58;
  $60 = HEAP32[$18>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$19>>2]|0;
  $63 = $61 & $62;
  $64 = $63 | $57;
  $65 = HEAP32[$20>>2]|0;
  $66 = $64 | $65;
  $67 = $66&255;
  HEAP8[$dest$01$i>>0] = $67;
  $68 = (($dest$01$i) + 1|0);
  $69 = (($src$03$i) + 4|0);
  $70 = ($21|0)==(0);
  if ($70) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $68;$src$03$i = $69;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_4rgba_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre$i = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre16$i = 0, $$pre17$i = 0, $$pre18$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $$pre$i = HEAP32[$6>>2]|0;
 $$pre4$i = HEAP32[$blitter>>2]|0;
 $$pre5$i = HEAP32[$7>>2]|0;
 $$pre6$i = HEAP32[$8>>2]|0;
 $$pre7$i = HEAP32[$9>>2]|0;
 $$pre8$i = HEAP32[$10>>2]|0;
 $$pre9$i = HEAP32[$11>>2]|0;
 $$pre10$i = HEAP32[$12>>2]|0;
 $$pre11$i = HEAP32[$13>>2]|0;
 $$pre12$i = HEAP32[$14>>2]|0;
 $$pre13$i = HEAP32[$15>>2]|0;
 $$pre14$i = HEAP32[$16>>2]|0;
 $$pre15$i = HEAP32[$17>>2]|0;
 $$pre16$i = HEAP32[$18>>2]|0;
 $$pre17$i = HEAP32[$19>>2]|0;
 $$pre18$i = HEAP32[$20>>2]|0;
 $count$02$i = $1;$dest$01$i = $4;$src$03$i = $5;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP32[$src$03$i>>2]|0;
  $23 = $22 >>> $$pre$i;
  $24 = $23 << $$pre4$i;
  $25 = $24 & $$pre5$i;
  $26 = ((1138392 + ($25<<2)|0) + 2|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = $22 >>> $$pre6$i;
  $30 = $29 << $$pre7$i;
  $31 = $30 & $$pre8$i;
  $32 = ((1138392 + ($31<<2)|0) + 1|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = (($34) + ($28))|0;
  $36 = $22 >>> $$pre9$i;
  $37 = $36 << $$pre10$i;
  $38 = $37 & $$pre11$i;
  $39 = (1138392 + ($38<<2)|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40&255;
  $42 = (($35) + ($41))|0;
  $43 = $42 >>> $$pre12$i;
  $44 = $43 << $$pre13$i;
  $45 = $44 & $$pre14$i;
  $46 = $22 >>> $$pre15$i;
  $47 = $46 << $$pre16$i;
  $48 = $47 & $$pre17$i;
  $49 = $48 | $$pre18$i;
  $50 = $49 | $45;
  $51 = $50&65535;
  HEAP16[$dest$01$i>>1] = $51;
  $52 = (($dest$01$i) + 2|0);
  $53 = (($src$03$i) + 4|0);
  $54 = ($21|0)==(0);
  if ($54) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $52;$src$03$i = $53;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_4rgba_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $src$03 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $22 = HEAP32[$src$03>>2]|0;
  $23 = HEAP32[$6>>2]|0;
  $24 = $22 >>> $23;
  $25 = HEAP32[$blitter>>2]|0;
  $26 = $24 << $25;
  $27 = HEAP32[$7>>2]|0;
  $28 = $26 & $27;
  $29 = ((1138392 + ($28<<2)|0) + 2|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = HEAP32[$8>>2]|0;
  $33 = $22 >>> $32;
  $34 = HEAP32[$9>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$10>>2]|0;
  $37 = $35 & $36;
  $38 = ((1138392 + ($37<<2)|0) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = (($40) + ($31))|0;
  $42 = HEAP32[$11>>2]|0;
  $43 = $22 >>> $42;
  $44 = HEAP32[$12>>2]|0;
  $45 = $43 << $44;
  $46 = HEAP32[$13>>2]|0;
  $47 = $45 & $46;
  $48 = (1138392 + ($47<<2)|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49&255;
  $51 = (($41) + ($50))|0;
  $52 = HEAP32[$14>>2]|0;
  $53 = $51 >>> $52;
  $54 = HEAP32[$15>>2]|0;
  $55 = $53 << $54;
  $56 = HEAP32[$16>>2]|0;
  $57 = $55 & $56;
  $58 = (($src$03) + 4|0);
  $59 = HEAP32[$17>>2]|0;
  $60 = $22 >>> $59;
  $61 = HEAP32[$18>>2]|0;
  $62 = $60 << $61;
  $63 = HEAP32[$19>>2]|0;
  $64 = $62 & $63;
  $65 = $64 | $57;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 | $66;
  $68 = $67&255;
  HEAP8[$dest$01>>0] = $68;
  $69 = $67 >>> 8;
  $70 = $69&255;
  $71 = (($dest$01) + 1|0);
  HEAP8[$71>>0] = $70;
  $72 = $67 >>> 16;
  $73 = $72&255;
  $74 = (($dest$01) + 2|0);
  HEAP8[$74>>0] = $73;
  $75 = (($dest$01) + 3|0);
  $76 = ($21|0)==(0);
  if ($76) {
   break;
  } else {
   $count$02 = $21;$dest$01 = $75;$src$03 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZL21inner_remap_4rgba_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0, $src$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 64|0);
 $15 = (($blitter) + 60|0);
 $16 = (($blitter) + 68|0);
 $17 = (($blitter) + 40|0);
 $18 = (($blitter) + 36|0);
 $19 = (($blitter) + 44|0);
 $20 = (($blitter) + 72|0);
 $count$02$i = $1;$dest$01$i = $4;$src$03$i = $5;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = HEAP32[$src$03$i>>2]|0;
  $23 = HEAP32[$6>>2]|0;
  $24 = $22 >>> $23;
  $25 = HEAP32[$blitter>>2]|0;
  $26 = $24 << $25;
  $27 = HEAP32[$7>>2]|0;
  $28 = $26 & $27;
  $29 = ((1138392 + ($28<<2)|0) + 2|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = HEAP32[$8>>2]|0;
  $33 = $22 >>> $32;
  $34 = HEAP32[$9>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$10>>2]|0;
  $37 = $35 & $36;
  $38 = ((1138392 + ($37<<2)|0) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = (($40) + ($31))|0;
  $42 = HEAP32[$11>>2]|0;
  $43 = $22 >>> $42;
  $44 = HEAP32[$12>>2]|0;
  $45 = $43 << $44;
  $46 = HEAP32[$13>>2]|0;
  $47 = $45 & $46;
  $48 = (1138392 + ($47<<2)|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49&255;
  $51 = (($41) + ($50))|0;
  $52 = HEAP32[$14>>2]|0;
  $53 = $51 >>> $52;
  $54 = HEAP32[$15>>2]|0;
  $55 = $53 << $54;
  $56 = HEAP32[$16>>2]|0;
  $57 = $55 & $56;
  $58 = HEAP32[$17>>2]|0;
  $59 = $22 >>> $58;
  $60 = HEAP32[$18>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$19>>2]|0;
  $63 = $61 & $62;
  $64 = $63 | $57;
  $65 = HEAP32[$20>>2]|0;
  $66 = $64 | $65;
  HEAP32[$dest$01$i>>2] = $66;
  $67 = (($dest$01$i) + 4|0);
  $68 = (($src$03$i) + 4|0);
  $69 = ($21|0)==(0);
  if ($69) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $67;$src$03$i = $68;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_1rgba_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$03$i = $1;$dest$02$i = $4;$src$01$i = $5;
 while(1) {
  $18 = (($count$03$i) + -1)|0;
  $19 = HEAP8[$src$01$i>>0]|0;
  $20 = $19&255;
  $21 = HEAP32[$6>>2]|0;
  $22 = $20 >>> $21;
  $23 = HEAP32[$blitter>>2]|0;
  $24 = $22 << $23;
  $25 = HEAP32[$7>>2]|0;
  $26 = $24 & $25;
  $27 = HEAP32[$8>>2]|0;
  $28 = $20 >>> $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 << $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $30 & $31;
  $33 = $32 | $26;
  $34 = HEAP32[$11>>2]|0;
  $35 = $20 >>> $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 << $36;
  $38 = HEAP32[$13>>2]|0;
  $39 = $37 & $38;
  $40 = $33 | $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $20 >>> $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 << $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $44 & $45;
  $47 = $40 | $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 | $48;
  $50 = $49&255;
  HEAP8[$dest$02$i>>0] = $50;
  $51 = (($dest$02$i) + 1|0);
  $52 = (($src$01$i) + 1|0);
  $53 = ($18|0)==(0);
  if ($53) {
   break;
  } else {
   $count$03$i = $18;$dest$02$i = $51;$src$01$i = $52;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_1rgba_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre$i = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $$pre$i = HEAP32[$6>>2]|0;
 $$pre4$i = HEAP32[$blitter>>2]|0;
 $$pre5$i = HEAP32[$7>>2]|0;
 $$pre6$i = HEAP32[$8>>2]|0;
 $$pre7$i = HEAP32[$9>>2]|0;
 $$pre8$i = HEAP32[$10>>2]|0;
 $$pre9$i = HEAP32[$11>>2]|0;
 $$pre10$i = HEAP32[$12>>2]|0;
 $$pre11$i = HEAP32[$13>>2]|0;
 $$pre12$i = HEAP32[$14>>2]|0;
 $$pre13$i = HEAP32[$15>>2]|0;
 $$pre14$i = HEAP32[$16>>2]|0;
 $$pre15$i = HEAP32[$17>>2]|0;
 $count$03$i = $1;$dest$02$i = $3;$src$01$i = $5;
 while(1) {
  $18 = (($count$03$i) + -1)|0;
  $19 = HEAP8[$src$01$i>>0]|0;
  $20 = $19&255;
  $21 = $20 >>> $$pre$i;
  $22 = $21 << $$pre4$i;
  $23 = $22 & $$pre5$i;
  $24 = $20 >>> $$pre6$i;
  $25 = $24 << $$pre7$i;
  $26 = $25 & $$pre8$i;
  $27 = $20 >>> $$pre9$i;
  $28 = $27 << $$pre10$i;
  $29 = $28 & $$pre11$i;
  $30 = $20 >>> $$pre12$i;
  $31 = $30 << $$pre13$i;
  $32 = $31 & $$pre14$i;
  $33 = $23 | $$pre15$i;
  $34 = $33 | $26;
  $35 = $34 | $29;
  $36 = $35 | $32;
  $37 = $36&65535;
  HEAP16[$dest$02$i>>1] = $37;
  $38 = (($dest$02$i) + 2|0);
  $39 = (($src$01$i) + 1|0);
  $40 = ($18|0)==(0);
  if ($40) {
   break;
  } else {
   $count$03$i = $18;$dest$02$i = $38;$src$01$i = $39;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_1rgba_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$02 = $1;$dest$01 = $4;$src$03 = $5;
 while(1) {
  $18 = (($count$02) + -1)|0;
  $19 = HEAP8[$src$03>>0]|0;
  $20 = $19&255;
  $21 = HEAP32[$6>>2]|0;
  $22 = $20 >>> $21;
  $23 = HEAP32[$blitter>>2]|0;
  $24 = $22 << $23;
  $25 = HEAP32[$7>>2]|0;
  $26 = $24 & $25;
  $27 = HEAP32[$8>>2]|0;
  $28 = $20 >>> $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 << $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $30 & $31;
  $33 = $32 | $26;
  $34 = HEAP32[$11>>2]|0;
  $35 = $20 >>> $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 << $36;
  $38 = HEAP32[$13>>2]|0;
  $39 = $37 & $38;
  $40 = $33 | $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $20 >>> $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 << $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $44 & $45;
  $47 = $40 | $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 | $48;
  $50 = $49&255;
  HEAP8[$dest$01>>0] = $50;
  $51 = $49 >>> 8;
  $52 = $51&255;
  $53 = (($dest$01) + 1|0);
  HEAP8[$53>>0] = $52;
  $54 = $49 >>> 16;
  $55 = $54&255;
  $56 = (($dest$01) + 2|0);
  HEAP8[$56>>0] = $55;
  $57 = (($dest$01) + 3|0);
  $58 = (($src$03) + 1|0);
  $59 = ($18|0)==(0);
  if ($59) {
   break;
  } else {
   $count$02 = $18;$dest$01 = $57;$src$03 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_1rgba_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$03$i = $1;$dest$02$i = $3;$src$01$i = $5;
 while(1) {
  $18 = (($count$03$i) + -1)|0;
  $19 = HEAP8[$src$01$i>>0]|0;
  $20 = $19&255;
  $21 = HEAP32[$6>>2]|0;
  $22 = $20 >>> $21;
  $23 = HEAP32[$blitter>>2]|0;
  $24 = $22 << $23;
  $25 = HEAP32[$7>>2]|0;
  $26 = $24 & $25;
  $27 = HEAP32[$8>>2]|0;
  $28 = $20 >>> $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 << $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $30 & $31;
  $33 = $32 | $26;
  $34 = HEAP32[$11>>2]|0;
  $35 = $20 >>> $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 << $36;
  $38 = HEAP32[$13>>2]|0;
  $39 = $37 & $38;
  $40 = $33 | $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $20 >>> $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 << $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $44 & $45;
  $47 = $40 | $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 | $48;
  HEAP32[$dest$02$i>>2] = $49;
  $50 = (($dest$02$i) + 4|0);
  $51 = (($src$01$i) + 1|0);
  $52 = ($18|0)==(0);
  if ($52) {
   break;
  } else {
   $count$03$i = $18;$dest$02$i = $50;$src$01$i = $51;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_2rgba_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$03$i = $1;$dest$02$i = $5;$src$01$i = $4;
 while(1) {
  $18 = (($count$03$i) + -1)|0;
  $19 = HEAP16[$src$01$i>>1]|0;
  $20 = $19&65535;
  $21 = HEAP32[$6>>2]|0;
  $22 = $20 >>> $21;
  $23 = HEAP32[$blitter>>2]|0;
  $24 = $22 << $23;
  $25 = HEAP32[$7>>2]|0;
  $26 = $24 & $25;
  $27 = HEAP32[$8>>2]|0;
  $28 = $20 >>> $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 << $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $30 & $31;
  $33 = $32 | $26;
  $34 = HEAP32[$11>>2]|0;
  $35 = $20 >>> $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 << $36;
  $38 = HEAP32[$13>>2]|0;
  $39 = $37 & $38;
  $40 = $33 | $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $20 >>> $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 << $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $44 & $45;
  $47 = $40 | $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 | $48;
  $50 = $49&255;
  HEAP8[$dest$02$i>>0] = $50;
  $51 = (($dest$02$i) + 1|0);
  $52 = (($src$01$i) + 2|0);
  $53 = ($18|0)==(0);
  if ($53) {
   break;
  } else {
   $count$03$i = $18;$dest$02$i = $51;$src$01$i = $52;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_2rgba_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$blitter>>2]|0;
 $9 = (($blitter) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($blitter) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($blitter) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($blitter) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($blitter) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($blitter) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($blitter) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($blitter) + 40|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($blitter) + 36|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($blitter) + 44|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($blitter) + 72|0);
 $30 = HEAP32[$29>>2]|0;
 $count$03$i = $1;$dest$02$i = $4;$src$01$i = $5;
 while(1) {
  $31 = (($count$03$i) + -1)|0;
  $32 = HEAP16[$src$01$i>>1]|0;
  $33 = $32&65535;
  $34 = $33 >>> $7;
  $35 = $34 << $8;
  $36 = $35 & $10;
  $37 = $33 >>> $12;
  $38 = $37 << $14;
  $39 = $38 & $16;
  $40 = $33 >>> $18;
  $41 = $40 << $20;
  $42 = $41 & $22;
  $43 = $33 >>> $24;
  $44 = $43 << $26;
  $45 = $44 & $28;
  $46 = $36 | $30;
  $47 = $46 | $39;
  $48 = $47 | $42;
  $49 = $48 | $45;
  $50 = $49&65535;
  HEAP16[$dest$02$i>>1] = $50;
  $51 = (($dest$02$i) + 2|0);
  $52 = (($src$01$i) + 2|0);
  $53 = ($31|0)==(0);
  if ($53) {
   break;
  } else {
   $count$03$i = $31;$dest$02$i = $51;$src$01$i = $52;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_2rgba_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02 = 0, $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $18 = (($count$02) + -1)|0;
  $19 = HEAP16[$src$03>>1]|0;
  $20 = $19&65535;
  $21 = HEAP32[$6>>2]|0;
  $22 = $20 >>> $21;
  $23 = HEAP32[$blitter>>2]|0;
  $24 = $22 << $23;
  $25 = HEAP32[$7>>2]|0;
  $26 = $24 & $25;
  $27 = HEAP32[$8>>2]|0;
  $28 = $20 >>> $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 << $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $30 & $31;
  $33 = $32 | $26;
  $34 = HEAP32[$11>>2]|0;
  $35 = $20 >>> $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 << $36;
  $38 = HEAP32[$13>>2]|0;
  $39 = $37 & $38;
  $40 = $33 | $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $20 >>> $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 << $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $44 & $45;
  $47 = $40 | $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 | $48;
  $50 = $49&255;
  HEAP8[$dest$01>>0] = $50;
  $51 = $49 >>> 8;
  $52 = $51&255;
  $53 = (($dest$01) + 1|0);
  HEAP8[$53>>0] = $52;
  $54 = $49 >>> 16;
  $55 = $54&255;
  $56 = (($dest$01) + 2|0);
  HEAP8[$56>>0] = $55;
  $57 = (($dest$01) + 3|0);
  $58 = (($src$03) + 2|0);
  $59 = ($18|0)==(0);
  if ($59) {
   break;
  } else {
   $count$02 = $18;$dest$01 = $57;$src$03 = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_2rgba_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$03$i = $1;$dest$02$i = $4;$src$01$i = $5;
 while(1) {
  $18 = (($count$03$i) + -1)|0;
  $19 = HEAP16[$src$01$i>>1]|0;
  $20 = $19&65535;
  $21 = HEAP32[$6>>2]|0;
  $22 = $20 >>> $21;
  $23 = HEAP32[$blitter>>2]|0;
  $24 = $22 << $23;
  $25 = HEAP32[$7>>2]|0;
  $26 = $24 & $25;
  $27 = HEAP32[$8>>2]|0;
  $28 = $20 >>> $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 << $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $30 & $31;
  $33 = $32 | $26;
  $34 = HEAP32[$11>>2]|0;
  $35 = $20 >>> $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 << $36;
  $38 = HEAP32[$13>>2]|0;
  $39 = $37 & $38;
  $40 = $33 | $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $20 >>> $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 << $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $44 & $45;
  $47 = $40 | $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 | $48;
  HEAP32[$dest$02$i>>2] = $49;
  $50 = (($dest$02$i) + 4|0);
  $51 = (($src$01$i) + 2|0);
  $52 = ($18|0)==(0);
  if ($52) {
   break;
  } else {
   $count$03$i = $18;$dest$02$i = $50;$src$01$i = $51;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_3rgba_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0;
 var $dest$02 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$03 = $1;$dest$02 = $4;$src$04 = $5;
 while(1) {
  $18 = (($count$03) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $19 = $src$0$val&255;
  $20 = $src$0$idx$val&255;
  $21 = $20 << 8;
  $22 = $21 | $19;
  $23 = $src$0$idx1$val&255;
  $24 = $23 << 16;
  $25 = $22 | $24;
  $26 = HEAP32[$6>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$7>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$8>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$9>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$10>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$11>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$12>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$13>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$14>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$15>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$16>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$17>>2]|0;
  $54 = $52 | $53;
  $55 = $54&255;
  $56 = (($dest$02) + 1|0);
  HEAP8[$dest$02>>0] = $55;
  $57 = (($src$04) + 3|0);
  $58 = ($18|0)==(0);
  if ($58) {
   break;
  } else {
   $count$03 = $18;$dest$02 = $56;$src$04 = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_3rgba_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre5 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0;
 var $dest$02 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $$pre = HEAP32[$6>>2]|0;
 $$pre5 = HEAP32[$blitter>>2]|0;
 $$pre6 = HEAP32[$7>>2]|0;
 $$pre7 = HEAP32[$8>>2]|0;
 $$pre8 = HEAP32[$9>>2]|0;
 $$pre9 = HEAP32[$10>>2]|0;
 $$pre10 = HEAP32[$11>>2]|0;
 $$pre11 = HEAP32[$12>>2]|0;
 $$pre12 = HEAP32[$13>>2]|0;
 $$pre13 = HEAP32[$14>>2]|0;
 $$pre14 = HEAP32[$15>>2]|0;
 $$pre15 = HEAP32[$16>>2]|0;
 $$pre16 = HEAP32[$17>>2]|0;
 $count$03 = $1;$dest$02 = $3;$src$04 = $5;
 while(1) {
  $18 = (($count$03) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $19 = $src$0$val&255;
  $20 = $src$0$idx$val&255;
  $21 = $20 << 8;
  $22 = $21 | $19;
  $23 = $src$0$idx1$val&255;
  $24 = $23 << 16;
  $25 = $22 | $24;
  $26 = $25 >>> $$pre;
  $27 = $26 << $$pre5;
  $28 = $27 & $$pre6;
  $29 = $25 >>> $$pre7;
  $30 = $29 << $$pre8;
  $31 = $30 & $$pre9;
  $32 = $31 | $28;
  $33 = $25 >>> $$pre10;
  $34 = $33 << $$pre11;
  $35 = $34 & $$pre12;
  $36 = $32 | $35;
  $37 = $25 >>> $$pre13;
  $38 = $37 << $$pre14;
  $39 = $38 & $$pre15;
  $40 = $36 | $39;
  $41 = $40 | $$pre16;
  $42 = $41&65535;
  $43 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $42;
  $44 = (($src$04) + 3|0);
  $45 = ($18|0)==(0);
  if ($45) {
   break;
  } else {
   $count$03 = $18;$dest$02 = $43;$src$04 = $44;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_3rgba_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$03 = 0, $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$02 = $1;$dest$03 = $4;$src$04 = $5;
 while(1) {
  $18 = (($count$02) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $19 = $src$0$val&255;
  $20 = $src$0$idx$val&255;
  $21 = $20 << 8;
  $22 = $21 | $19;
  $23 = $src$0$idx1$val&255;
  $24 = $23 << 16;
  $25 = $22 | $24;
  $26 = HEAP32[$6>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$7>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$8>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$9>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$10>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$11>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$12>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$13>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$14>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$15>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$16>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$17>>2]|0;
  $54 = $52 | $53;
  $55 = (($src$04) + 3|0);
  $56 = $54&255;
  HEAP8[$dest$03>>0] = $56;
  $57 = $54 >>> 8;
  $58 = $57&255;
  $59 = (($dest$03) + 1|0);
  HEAP8[$59>>0] = $58;
  $60 = $54 >>> 16;
  $61 = $60&255;
  $62 = (($dest$03) + 2|0);
  HEAP8[$62>>0] = $61;
  $63 = (($dest$03) + 3|0);
  $64 = ($18|0)==(0);
  if ($64) {
   break;
  } else {
   $count$02 = $18;$dest$03 = $63;$src$04 = $55;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_3rgba_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0;
 var $src$0$idx = 0, $src$0$idx$val = 0, $src$0$idx1 = 0, $src$0$idx1$val = 0, $src$0$val = 0, $src$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$info>>2]|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$03 = $1;$dest$02 = $3;$src$04 = $5;
 while(1) {
  $18 = (($count$03) + -1)|0;
  $src$0$val = HEAP8[$src$04>>0]|0;
  $src$0$idx = (($src$04) + 1|0);
  $src$0$idx$val = HEAP8[$src$0$idx>>0]|0;
  $src$0$idx1 = (($src$04) + 2|0);
  $src$0$idx1$val = HEAP8[$src$0$idx1>>0]|0;
  $19 = $src$0$val&255;
  $20 = $src$0$idx$val&255;
  $21 = $20 << 8;
  $22 = $21 | $19;
  $23 = $src$0$idx1$val&255;
  $24 = $23 << 16;
  $25 = $22 | $24;
  $26 = HEAP32[$6>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$7>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$8>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$9>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$10>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$11>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$12>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$13>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$14>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$15>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$16>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$17>>2]|0;
  $54 = $52 | $53;
  $55 = (($dest$02) + 4|0);
  HEAP32[$dest$02>>2] = $54;
  $56 = (($src$04) + 3|0);
  $57 = ($18|0)==(0);
  if ($57) {
   break;
  } else {
   $count$03 = $18;$dest$02 = $55;$src$04 = $56;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_4rgba_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$03$i = $1;$dest$02$i = $5;$src$01$i = $4;
 while(1) {
  $18 = (($count$03$i) + -1)|0;
  $19 = HEAP32[$src$01$i>>2]|0;
  $20 = HEAP32[$6>>2]|0;
  $21 = $19 >>> $20;
  $22 = HEAP32[$blitter>>2]|0;
  $23 = $21 << $22;
  $24 = HEAP32[$7>>2]|0;
  $25 = $23 & $24;
  $26 = HEAP32[$8>>2]|0;
  $27 = $19 >>> $26;
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 & $30;
  $32 = $31 | $25;
  $33 = HEAP32[$11>>2]|0;
  $34 = $19 >>> $33;
  $35 = HEAP32[$12>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$13>>2]|0;
  $38 = $36 & $37;
  $39 = $32 | $38;
  $40 = HEAP32[$14>>2]|0;
  $41 = $19 >>> $40;
  $42 = HEAP32[$15>>2]|0;
  $43 = $41 << $42;
  $44 = HEAP32[$16>>2]|0;
  $45 = $43 & $44;
  $46 = $39 | $45;
  $47 = HEAP32[$17>>2]|0;
  $48 = $46 | $47;
  $49 = $48&255;
  HEAP8[$dest$02$i>>0] = $49;
  $50 = (($dest$02$i) + 1|0);
  $51 = (($src$01$i) + 4|0);
  $52 = ($18|0)==(0);
  if ($52) {
   break;
  } else {
   $count$03$i = $18;$dest$02$i = $50;$src$01$i = $51;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_4rgba_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$blitter>>2]|0;
 $9 = (($blitter) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($blitter) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($blitter) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($blitter) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($blitter) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($blitter) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($blitter) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($blitter) + 40|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($blitter) + 36|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($blitter) + 44|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($blitter) + 72|0);
 $30 = HEAP32[$29>>2]|0;
 $count$03$i = $1;$dest$02$i = $4;$src$01$i = $5;
 while(1) {
  $31 = (($count$03$i) + -1)|0;
  $32 = HEAP32[$src$01$i>>2]|0;
  $33 = $32 >>> $7;
  $34 = $33 << $8;
  $35 = $34 & $10;
  $36 = $32 >>> $12;
  $37 = $36 << $14;
  $38 = $37 & $16;
  $39 = $32 >>> $18;
  $40 = $39 << $20;
  $41 = $40 & $22;
  $42 = $32 >>> $24;
  $43 = $42 << $26;
  $44 = $43 & $28;
  $45 = $35 | $30;
  $46 = $45 | $38;
  $47 = $46 | $41;
  $48 = $47 | $44;
  $49 = $48&65535;
  HEAP16[$dest$02$i>>1] = $49;
  $50 = (($dest$02$i) + 2|0);
  $51 = (($src$01$i) + 4|0);
  $52 = ($31|0)==(0);
  if ($52) {
   break;
  } else {
   $count$03$i = $31;$dest$02$i = $50;$src$01$i = $51;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_4rgba_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0;
 var $dest$01 = 0, $src$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$info>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$02 = $1;$dest$01 = $5;$src$03 = $4;
 while(1) {
  $18 = (($count$02) + -1)|0;
  $19 = HEAP32[$src$03>>2]|0;
  $20 = HEAP32[$6>>2]|0;
  $21 = $19 >>> $20;
  $22 = HEAP32[$blitter>>2]|0;
  $23 = $21 << $22;
  $24 = HEAP32[$7>>2]|0;
  $25 = $23 & $24;
  $26 = HEAP32[$8>>2]|0;
  $27 = $19 >>> $26;
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 & $30;
  $32 = $31 | $25;
  $33 = HEAP32[$11>>2]|0;
  $34 = $19 >>> $33;
  $35 = HEAP32[$12>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$13>>2]|0;
  $38 = $36 & $37;
  $39 = $32 | $38;
  $40 = HEAP32[$14>>2]|0;
  $41 = $19 >>> $40;
  $42 = HEAP32[$15>>2]|0;
  $43 = $41 << $42;
  $44 = HEAP32[$16>>2]|0;
  $45 = $43 & $44;
  $46 = $39 | $45;
  $47 = HEAP32[$17>>2]|0;
  $48 = $46 | $47;
  $49 = $48&255;
  HEAP8[$dest$01>>0] = $49;
  $50 = $48 >>> 8;
  $51 = $50&255;
  $52 = (($dest$01) + 1|0);
  HEAP8[$52>>0] = $51;
  $53 = $48 >>> 16;
  $54 = $53&255;
  $55 = (($dest$01) + 2|0);
  HEAP8[$55>>0] = $54;
  $56 = (($dest$01) + 3|0);
  $57 = (($src$03) + 4|0);
  $58 = ($18|0)==(0);
  if ($58) {
   break;
  } else {
   $count$02 = $18;$dest$01 = $56;$src$03 = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZL23inner_remap_4rgba_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03$i = 0, $dest$02$i = 0, $src$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($info) + 4|0);
 $4 = HEAP32[$info>>2]|0;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($blitter) + 4|0);
 $7 = (($blitter) + 8|0);
 $8 = (($blitter) + 16|0);
 $9 = (($blitter) + 12|0);
 $10 = (($blitter) + 20|0);
 $11 = (($blitter) + 28|0);
 $12 = (($blitter) + 24|0);
 $13 = (($blitter) + 32|0);
 $14 = (($blitter) + 40|0);
 $15 = (($blitter) + 36|0);
 $16 = (($blitter) + 44|0);
 $17 = (($blitter) + 72|0);
 $count$03$i = $1;$dest$02$i = $4;$src$01$i = $5;
 while(1) {
  $18 = (($count$03$i) + -1)|0;
  $19 = HEAP32[$src$01$i>>2]|0;
  $20 = HEAP32[$6>>2]|0;
  $21 = $19 >>> $20;
  $22 = HEAP32[$blitter>>2]|0;
  $23 = $21 << $22;
  $24 = HEAP32[$7>>2]|0;
  $25 = $23 & $24;
  $26 = HEAP32[$8>>2]|0;
  $27 = $19 >>> $26;
  $28 = HEAP32[$9>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$10>>2]|0;
  $31 = $29 & $30;
  $32 = $31 | $25;
  $33 = HEAP32[$11>>2]|0;
  $34 = $19 >>> $33;
  $35 = HEAP32[$12>>2]|0;
  $36 = $34 << $35;
  $37 = HEAP32[$13>>2]|0;
  $38 = $36 & $37;
  $39 = $32 | $38;
  $40 = HEAP32[$14>>2]|0;
  $41 = $19 >>> $40;
  $42 = HEAP32[$15>>2]|0;
  $43 = $41 << $42;
  $44 = HEAP32[$16>>2]|0;
  $45 = $43 & $44;
  $46 = $39 | $45;
  $47 = HEAP32[$17>>2]|0;
  $48 = $46 | $47;
  HEAP32[$dest$02$i>>2] = $48;
  $49 = (($dest$02$i) + 4|0);
  $50 = (($src$01$i) + 4|0);
  $51 = ($18|0)==(0);
  if ($51) {
   break;
  } else {
   $count$03$i = $18;$dest$02$i = $49;$src$01$i = $50;
  }
 }
 STACKTOP = sp;return;
}
function __ZL17inner_stretch_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0, $u$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($info) + 20|0);
 $count$03 = $3;$dest$02 = $6;$u$01 = $7;
 while(1) {
  $9 = (($count$03) + -1)|0;
  $10 = $u$01 >>> 16;
  $11 = (($1) + ($10)|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = (($dest$02) + 1|0);
  HEAP8[$dest$02>>0] = $12;
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + ($u$01))|0;
  $16 = ($9|0)==(0);
  if ($16) {
   break;
  } else {
   $count$03 = $9;$dest$02 = $13;$u$01 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZL17inner_stretch_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0, $u$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $count$03 = $3;$dest$02 = $5;$u$01 = $7;
 while(1) {
  $10 = (($count$03) + -1)|0;
  $11 = $u$01 >>> 16;
  $12 = (($1) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $13;
  $15 = (($9) + ($u$01))|0;
  $16 = ($10|0)==(0);
  if ($16) {
   break;
  } else {
   $count$03 = $10;$dest$02 = $14;$u$01 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZL17inner_stretch_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$05 = 0, $dest$04 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($info) + 20|0);
 $count$05 = $3;$dest$04 = $6;$u$03 = $7;
 while(1) {
  $9 = (($count$05) + -1)|0;
  $10 = $u$03 >>> 16;
  $11 = ($10*3)|0;
  $12 = (($1) + ($11)|0);
  $$val = HEAP8[$12>>0]|0;
  $$sum = (($11) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($11) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  HEAP8[$dest$04>>0] = $$val;
  $13 = (($dest$04) + 1|0);
  HEAP8[$13>>0] = $$idx$val;
  $14 = (($dest$04) + 2|0);
  HEAP8[$14>>0] = $$idx1$val;
  $15 = (($dest$04) + 3|0);
  $16 = HEAP32[$8>>2]|0;
  $17 = (($16) + ($u$03))|0;
  $18 = ($9|0)==(0);
  if ($18) {
   break;
  } else {
   $count$05 = $9;$dest$04 = $15;$u$03 = $17;
  }
 }
 STACKTOP = sp;return;
}
function __ZL17inner_stretch_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0, $u$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 20|0);
 $count$03 = $3;$dest$02 = $5;$u$01 = $7;
 while(1) {
  $9 = (($count$03) + -1)|0;
  $10 = $u$01 >>> 16;
  $11 = (($1) + ($10<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($dest$02) + 4|0);
  HEAP32[$dest$02>>2] = $12;
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + ($u$01))|0;
  $16 = ($9|0)==(0);
  if ($16) {
   break;
  } else {
   $count$03 = $9;$dest$02 = $13;$u$01 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZL19inner_stretch_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0, $u$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($info) + 20|0);
 $count$03 = $3;$dest$02 = $6;$u$01 = $7;
 while(1) {
  $9 = (($count$03) + -1)|0;
  $10 = $u$01 >>> 16;
  $11 = (($1) + ($10)|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = (($dest$02) + 1|0);
  HEAP8[$dest$02>>0] = $12;
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + ($u$01))|0;
  $16 = ($9|0)==(0);
  if ($16) {
   break;
  } else {
   $count$03 = $9;$dest$02 = $13;$u$01 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZL19inner_stretch_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0, $u$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 20|0);
 $9 = HEAP32[$8>>2]|0;
 $count$03 = $3;$dest$02 = $5;$u$01 = $7;
 while(1) {
  $10 = (($count$03) + -1)|0;
  $11 = $u$01 >>> 16;
  $12 = (($1) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $13;
  $15 = (($9) + ($u$01))|0;
  $16 = ($10|0)==(0);
  if ($16) {
   break;
  } else {
   $count$03 = $10;$dest$02 = $14;$u$01 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZL19inner_stretch_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$05 = 0, $dest$04 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($info) + 20|0);
 $count$05 = $3;$dest$04 = $6;$u$03 = $7;
 while(1) {
  $9 = (($count$05) + -1)|0;
  $10 = $u$03 >>> 16;
  $11 = ($10*3)|0;
  $12 = (($1) + ($11)|0);
  $$val = HEAP8[$12>>0]|0;
  $$sum = (($11) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($11) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  HEAP8[$dest$04>>0] = $$val;
  $13 = (($dest$04) + 1|0);
  HEAP8[$13>>0] = $$idx$val;
  $14 = (($dest$04) + 2|0);
  HEAP8[$14>>0] = $$idx1$val;
  $15 = (($dest$04) + 3|0);
  $16 = HEAP32[$8>>2]|0;
  $17 = (($16) + ($u$03))|0;
  $18 = ($9|0)==(0);
  if ($18) {
   break;
  } else {
   $count$05 = $9;$dest$04 = $15;$u$03 = $17;
  }
 }
 STACKTOP = sp;return;
}
function __ZL19inner_stretch_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$02 = 0, $u$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 20|0);
 $count$03 = $3;$dest$02 = $5;$u$01 = $7;
 while(1) {
  $9 = (($count$03) + -1)|0;
  $10 = $u$01 >>> 16;
  $11 = (($1) + ($10<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($dest$02) + 4|0);
  HEAP32[$dest$02>>2] = $12;
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + ($u$01))|0;
  $16 = ($9|0)==(0);
  if ($16) {
   break;
  } else {
   $count$03 = $9;$dest$02 = $13;$u$01 = $15;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_i8_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 & 224;
  $16 = $15 >>> 3;
  $17 = $14 >>> 6;
  $18 = $17 | $15;
  $19 = $18 | $16;
  $20 = $19&255;
  $21 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $20;
  $22 = (($u$03) + ($1))|0;
  $23 = ($10|0)==(0);
  if ($23) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $21;$u$03 = $22;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_i8_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 << 8;
  $16 = $15 & 63488;
  $17 = $14 << 3;
  $18 = $17 & 2016;
  $19 = $14 >>> 3;
  $20 = $18 | $19;
  $21 = $20 | $16;
  $22 = $21&65535;
  $23 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $22;
  $24 = (($u$03) + ($1))|0;
  $25 = ($10|0)==(0);
  if ($25) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $23;$u$03 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_i8_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0;
 var $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  HEAP8[$dest$01>>0] = $13;
  $14 = (($dest$01) + 1|0);
  HEAP8[$14>>0] = $13;
  $15 = (($dest$01) + 2|0);
  HEAP8[$15>>0] = $13;
  $16 = (($dest$01) + 3|0);
  $17 = (($u$03) + ($1))|0;
  $18 = ($10|0)==(0);
  if ($18) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $16;$u$03 = $17;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_i8_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$01 = $5;$dest$02 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$01) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 & 248;
  $16 = $15 << 7;
  $17 = $15 << 2;
  $18 = $14 >>> 3;
  $19 = $18 | $17;
  $20 = $19 | $16;
  $21 = $20 | 32768;
  $22 = $21&65535;
  $23 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $22;
  $24 = (($u$03) + ($1))|0;
  $25 = ($10|0)==(0);
  if ($25) {
   break;
  } else {
   $count$01 = $10;$dest$02 = $23;$u$03 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_i8_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$01 = $5;$dest$02 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$01) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 & 240;
  $16 = $15 << 4;
  $17 = $14 >>> 4;
  $18 = $15 | $17;
  $19 = $18 | $16;
  $20 = $19 | 61440;
  $21 = $20&65535;
  $22 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $21;
  $23 = (($u$03) + ($1))|0;
  $24 = ($10|0)==(0);
  if ($24) {
   break;
  } else {
   $count$01 = $10;$dest$02 = $22;$u$03 = $23;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_i8_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 << 16;
  $16 = $14 << 8;
  $17 = $14 | $16;
  $18 = $17 | $15;
  $19 = $18 | -16777216;
  $20 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $19;
  $21 = (($u$03) + ($1))|0;
  $22 = ($10|0)==(0);
  if ($22) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $20;$u$03 = $21;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_rgb332_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 & 224;
  $16 = ((1138392 + ($15<<2)|0) + 2|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $14 << 3;
  $20 = $19 & 224;
  $21 = ((1138392 + ($20<<2)|0) + 1|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = (($23) + ($18))|0;
  $25 = $14 << 6;
  $26 = $25 & 192;
  $27 = (1138392 + ($26<<2)|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = (($24) + ($29))|0;
  $31 = $30&255;
  $32 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $31;
  $33 = (($u$03) + ($1))|0;
  $34 = ($10|0)==(0);
  if ($34) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $32;$u$03 = $33;
  }
 }
 STACKTOP = sp;return;
}
function __ZL33inner_stretch_remap_rgb332_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 << 8;
  $16 = $15 & 57344;
  $17 = $14 << 6;
  $18 = $17 & 1792;
  $19 = $16 | $18;
  $20 = $14 << 3;
  $21 = $20 & 24;
  $22 = $19 | $21;
  $23 = $22&65535;
  $24 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL33inner_stretch_remap_rgb332_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 & 224;
  $16 = $14 << 3;
  $17 = $16 & 224;
  $18 = $14 << 6;
  $19 = $18&255;
  HEAP8[$dest$01>>0] = $19;
  $20 = $17&255;
  $21 = (($dest$01) + 1|0);
  HEAP8[$21>>0] = $20;
  $22 = $15&255;
  $23 = (($dest$01) + 2|0);
  HEAP8[$23>>0] = $22;
  $24 = (($dest$01) + 3|0);
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb332_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 << 7;
  $16 = $15 & 28672;
  $17 = $14 << 5;
  $18 = $17 & 896;
  $19 = $14 << 3;
  $20 = $19 & 24;
  $21 = $18 | $16;
  $22 = $21 | $20;
  $23 = $22 | 32768;
  $24 = $23&65535;
  $25 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $24;
  $26 = (($u$03) + ($1))|0;
  $27 = ($10|0)==(0);
  if ($27) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $25;$u$03 = $26;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb332_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 << 4;
  $16 = $15 & 3584;
  $17 = $14 << 3;
  $18 = $17 & 224;
  $19 = $14 << 2;
  $20 = $19 & 12;
  $21 = $18 | $16;
  $22 = $21 | $20;
  $23 = $22 | 61440;
  $24 = $23&65535;
  $25 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $24;
  $26 = (($u$03) + ($1))|0;
  $27 = ($10|0)==(0);
  if ($27) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $25;$u$03 = $26;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb332_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 << 16;
  $16 = $15 & 14680064;
  $17 = $14 << 11;
  $18 = $17 & 57344;
  $19 = $14 << 6;
  $20 = $19 & 192;
  $21 = $18 | $16;
  $22 = $21 | $20;
  $23 = $22 | -16777216;
  $24 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_rgb565_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 8;
  $16 = $15 & 248;
  $17 = ((1138392 + ($16<<2)|0) + 2|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $14 >>> 3;
  $21 = $20 & 252;
  $22 = ((1138392 + ($21<<2)|0) + 1|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = (($24) + ($19))|0;
  $26 = $14 << 3;
  $27 = $26 & 248;
  $28 = (1138392 + ($27<<2)|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = (($25) + ($30))|0;
  $32 = $31&255;
  $33 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $32;
  $34 = (($u$03) + ($1))|0;
  $35 = ($10|0)==(0);
  if ($35) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $33;$u$03 = $34;
  }
 }
 STACKTOP = sp;return;
}
function __ZL33inner_stretch_remap_rgb565_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 8;
  $16 = $15 & 224;
  $17 = $14 >>> 6;
  $18 = $17 & 28;
  $19 = $16 | $18;
  $20 = $14 >>> 3;
  $21 = $20 & 3;
  $22 = $19 | $21;
  $23 = $22&255;
  $24 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL33inner_stretch_remap_rgb565_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 << 3;
  $16 = $15&255;
  HEAP8[$dest$01>>0] = $16;
  $17 = $14 >>> 3;
  $18 = $17 & 252;
  $19 = $18&255;
  $20 = (($dest$01) + 1|0);
  HEAP8[$20>>0] = $19;
  $21 = $14 >>> 8;
  $22 = $21 & 248;
  $23 = $22&255;
  $24 = (($dest$01) + 2|0);
  HEAP8[$24>>0] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = (($dest$01) + 3|0);
  $27 = ($10|0)==(0);
  if ($27) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $26;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb565_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 1;
  $16 = $15 & 32736;
  $17 = $14 & 31;
  $18 = $17 | $16;
  $19 = $18 | 32768;
  $20 = $19&65535;
  $21 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $20;
  $22 = (($u$03) + ($1))|0;
  $23 = ($10|0)==(0);
  if ($23) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $21;$u$03 = $22;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb565_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 4;
  $16 = $15 & 3840;
  $17 = $14 >>> 3;
  $18 = $17 & 240;
  $19 = $14 >>> 1;
  $20 = $19 & 15;
  $21 = $18 | $16;
  $22 = $21 | $20;
  $23 = $22 | 61440;
  $24 = $23&65535;
  $25 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $24;
  $26 = (($u$03) + ($1))|0;
  $27 = ($10|0)==(0);
  if ($27) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $25;$u$03 = $26;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb565_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 << 8;
  $16 = $15 & 16252928;
  $17 = $14 << 5;
  $18 = $17 & 64512;
  $19 = $14 << 3;
  $20 = $19 & 248;
  $21 = $18 | $16;
  $22 = $21 | $20;
  $23 = $22 | -16777216;
  $24 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_rgb888_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0;
 var $dest$03 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$04 = $5;$dest$03 = $8;$u$05 = $9;
 while(1) {
  $10 = (($count$04) + -1)|0;
  $11 = $u$05 >>> 16;
  $12 = ($11*3)|0;
  $13 = (($3) + ($12)|0);
  $$val = HEAP8[$13>>0]|0;
  $$sum = (($12) + 1)|0;
  $$idx = (($3) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($12) + 2)|0;
  $$idx1 = (($3) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $14 = $$val&255;
  $15 = $$idx$val&255;
  $16 = $$idx1$val&255;
  $17 = ((1138392 + ($16<<2)|0) + 2|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = ((1138392 + ($15<<2)|0) + 1|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = $21&255;
  $23 = (($22) + ($19))|0;
  $24 = (1138392 + ($14<<2)|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25&255;
  $27 = (($23) + ($26))|0;
  $28 = $27&255;
  $29 = (($dest$03) + 1|0);
  HEAP8[$dest$03>>0] = $28;
  $30 = (($u$05) + ($1))|0;
  $31 = ($10|0)==(0);
  if ($31) {
   break;
  } else {
   $count$04 = $10;$dest$03 = $29;$u$05 = $30;
  }
 }
 STACKTOP = sp;return;
}
function __ZL33inner_stretch_remap_rgb888_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0, $dest$03 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$04 = $5;$dest$03 = $8;$u$05 = $9;
 while(1) {
  $10 = (($count$04) + -1)|0;
  $11 = $u$05 >>> 16;
  $12 = ($11*3)|0;
  $13 = (($3) + ($12)|0);
  $$val = HEAP8[$13>>0]|0;
  $$sum = (($12) + 1)|0;
  $$idx = (($3) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($12) + 2)|0;
  $$idx1 = (($3) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $14 = $$val&255;
  $15 = $$idx$val&255;
  $16 = $$idx1$val&255;
  $17 = $16 & 224;
  $18 = $15 >>> 3;
  $19 = $18 & 28;
  $20 = $14 >>> 6;
  $21 = $19 | $20;
  $22 = $21 | $17;
  $23 = $22&255;
  $24 = (($dest$03) + 1|0);
  HEAP8[$dest$03>>0] = $23;
  $25 = (($u$05) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$04 = $10;$dest$03 = $24;$u$05 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL33inner_stretch_remap_rgb888_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0, $dest$03 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$04 = $5;$dest$03 = $7;$u$05 = $9;
 while(1) {
  $10 = (($count$04) + -1)|0;
  $11 = $u$05 >>> 16;
  $12 = ($11*3)|0;
  $13 = (($3) + ($12)|0);
  $$val = HEAP8[$13>>0]|0;
  $$sum = (($12) + 1)|0;
  $$idx = (($3) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($12) + 2)|0;
  $$idx1 = (($3) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $14 = $$val&255;
  $15 = $$idx$val&255;
  $16 = $15 << 3;
  $17 = $$idx1$val&255;
  $18 = $17 << 8;
  $19 = $18 & 63488;
  $20 = $16 & 2016;
  $21 = $14 >>> 3;
  $22 = $20 | $21;
  $23 = $22 | $19;
  $24 = $23&65535;
  $25 = (($dest$03) + 2|0);
  HEAP16[$dest$03>>1] = $24;
  $26 = (($u$05) + ($1))|0;
  $27 = ($10|0)==(0);
  if ($27) {
   break;
  } else {
   $count$04 = $10;$dest$03 = $25;$u$05 = $26;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb888_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0, $dest$03 = 0, $u$05 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$04 = $5;$dest$03 = $7;$u$05 = $9;
 while(1) {
  $10 = (($count$04) + -1)|0;
  $11 = $u$05 >>> 16;
  $12 = ($11*3)|0;
  $13 = (($3) + ($12)|0);
  $$val = HEAP8[$13>>0]|0;
  $$sum = (($12) + 1)|0;
  $$idx = (($3) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($12) + 2)|0;
  $$idx1 = (($3) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $14 = $$val&255;
  $15 = $$idx$val&255;
  $16 = $15 << 2;
  $17 = $$idx1$val&255;
  $18 = $17 << 7;
  $19 = $18 & 31744;
  $20 = $16 & 992;
  $21 = $14 >>> 3;
  $22 = $21 | $20;
  $23 = $22 | $19;
  $24 = $23 | 32768;
  $25 = $24&65535;
  $26 = (($dest$03) + 2|0);
  HEAP16[$dest$03>>1] = $25;
  $27 = (($u$05) + ($1))|0;
  $28 = ($10|0)==(0);
  if ($28) {
   break;
  } else {
   $count$04 = $10;$dest$03 = $26;$u$05 = $27;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb888_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0, $dest$03 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$04 = $5;$dest$03 = $7;$u$05 = $9;
 while(1) {
  $10 = (($count$04) + -1)|0;
  $11 = $u$05 >>> 16;
  $12 = ($11*3)|0;
  $13 = (($3) + ($12)|0);
  $$val = HEAP8[$13>>0]|0;
  $$sum = (($12) + 1)|0;
  $$idx = (($3) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($12) + 2)|0;
  $$idx1 = (($3) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $14 = $$val&255;
  $15 = $$idx$val&255;
  $16 = $$idx1$val&255;
  $17 = $16 << 4;
  $18 = $17 & 3840;
  $19 = $15 & 240;
  $20 = $14 >>> 4;
  $21 = $20 | $19;
  $22 = $21 | $18;
  $23 = $22 | 61440;
  $24 = $23&65535;
  $25 = (($dest$03) + 2|0);
  HEAP16[$dest$03>>1] = $24;
  $26 = (($u$05) + ($1))|0;
  $27 = ($10|0)==(0);
  if ($27) {
   break;
  } else {
   $count$04 = $10;$dest$03 = $25;$u$05 = $26;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_rgb888_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$05 = 0, $dest$04 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$05 = $5;$dest$04 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$05) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = ($11*3)|0;
  $13 = (($3) + ($12)|0);
  $$val = HEAP8[$13>>0]|0;
  $$sum = (($12) + 1)|0;
  $$idx = (($3) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($12) + 2)|0;
  $$idx1 = (($3) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $14 = $$val&255;
  $15 = $$idx$val&255;
  $16 = $15 << 8;
  $17 = $$idx1$val&255;
  $18 = $17 << 16;
  $19 = $14 | $16;
  $20 = $19 | $18;
  $21 = $20 | -16777216;
  $22 = (($dest$04) + 4|0);
  HEAP32[$dest$04>>2] = $21;
  $23 = (($u$03) + ($1))|0;
  $24 = ($10|0)==(0);
  if ($24) {
   break;
  } else {
   $count$05 = $10;$dest$04 = $22;$u$03 = $23;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_argb1555_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 7;
  $16 = $15 & 248;
  $17 = ((1138392 + ($16<<2)|0) + 2|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $14 >>> 2;
  $21 = $20 & 248;
  $22 = ((1138392 + ($21<<2)|0) + 1|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = (($24) + ($19))|0;
  $26 = $14 << 3;
  $27 = $26 & 248;
  $28 = (1138392 + ($27<<2)|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = (($25) + ($30))|0;
  $32 = $31&255;
  $33 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $32;
  $34 = (($u$03) + ($1))|0;
  $35 = ($10|0)==(0);
  if ($35) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $33;$u$03 = $34;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb1555_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 7;
  $16 = $15 & 224;
  $17 = $14 >>> 5;
  $18 = $17 & 28;
  $19 = $16 | $18;
  $20 = $14 >>> 3;
  $21 = $20 & 3;
  $22 = $19 | $21;
  $23 = $22&255;
  $24 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb1555_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 & 32767;
  $16 = $14 & 32736;
  $17 = (($15) + ($16))|0;
  $18 = $17&65535;
  $19 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $18;
  $20 = (($u$03) + ($1))|0;
  $21 = ($10|0)==(0);
  if ($21) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $19;$u$03 = $20;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb1555_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 << 3;
  $16 = $15&255;
  HEAP8[$dest$01>>0] = $16;
  $17 = $14 >>> 2;
  $18 = $17 & 248;
  $19 = $18&255;
  $20 = (($dest$01) + 1|0);
  HEAP8[$20>>0] = $19;
  $21 = $14 >>> 7;
  $22 = $21 & 248;
  $23 = $22&255;
  $24 = (($dest$01) + 2|0);
  HEAP8[$24>>0] = $23;
  $25 = (($dest$01) + 3|0);
  $26 = (($u$03) + ($1))|0;
  $27 = ($10|0)==(0);
  if ($27) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $25;$u$03 = $26;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_stretch_remap_argb1555_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 3;
  $16 = $15 & 3840;
  $17 = $14 >>> 2;
  $18 = $17 & 240;
  $19 = $16 | $18;
  $20 = $14 >>> 1;
  $21 = $20 & 15;
  $22 = $19 | $21;
  $23 = $15 & 4096;
  $24 = (65536 - ($23))|0;
  $25 = $22 | $24;
  $26 = $25&65535;
  $27 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $26;
  $28 = (($u$03) + ($1))|0;
  $29 = ($10|0)==(0);
  if ($29) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $27;$u$03 = $28;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_stretch_remap_argb1555_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 << 9;
  $16 = $15 & 16252928;
  $17 = $14 << 6;
  $18 = $17 & 63488;
  $19 = $16 | $18;
  $20 = $14 << 3;
  $21 = $20 & 248;
  $22 = $19 | $21;
  $23 = $14 & 32768;
  $24 = (0 - ($23))|0;
  $25 = $24 & -16777216;
  $26 = $22 | $25;
  $27 = (($dest$01) + 4|0);
  HEAP32[$dest$01>>2] = $26;
  $28 = (($u$03) + ($1))|0;
  $29 = ($10|0)==(0);
  if ($29) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $27;$u$03 = $28;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_argb4444_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 8;
  $16 = $15 & 15;
  $17 = ((1138392 + ($16<<2)|0) + 2|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $14 & 240;
  $21 = ((1138392 + ($20<<2)|0) + 1|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = (($23) + ($19))|0;
  $25 = $14 << 4;
  $26 = $25 & 240;
  $27 = (1138392 + ($26<<2)|0);
  $28 = HEAP8[$27>>0]|0;
  $29 = $28&255;
  $30 = (($24) + ($29))|0;
  $31 = $30&255;
  $32 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $31;
  $33 = (($u$03) + ($1))|0;
  $34 = ($10|0)==(0);
  if ($34) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $32;$u$03 = $33;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb4444_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 >>> 4;
  $16 = $15 & 224;
  $17 = $14 >>> 3;
  $18 = $17 & 28;
  $19 = $16 | $18;
  $20 = $14 >>> 2;
  $21 = $20 & 3;
  $22 = $19 | $21;
  $23 = $22&255;
  $24 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb4444_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 << 4;
  $16 = $15 & 61440;
  $17 = $14 << 3;
  $18 = $17 & 1920;
  $19 = $16 | $18;
  $20 = $14 << 1;
  $21 = $20 & 30;
  $22 = $19 | $21;
  $23 = $22&65535;
  $24 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb4444_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 & 240;
  $16 = $14 << 4;
  $17 = $16&255;
  HEAP8[$dest$01>>0] = $17;
  $18 = $15&255;
  $19 = (($dest$01) + 1|0);
  HEAP8[$19>>0] = $18;
  $20 = $14 >>> 4;
  $21 = $20 & 240;
  $22 = $21&255;
  $23 = (($dest$01) + 2|0);
  HEAP8[$23>>0] = $22;
  $24 = (($dest$01) + 3|0);
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_stretch_remap_argb4444_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 << 3;
  $16 = $15 & 30720;
  $17 = $14 << 2;
  $18 = $17 & 960;
  $19 = $14 << 1;
  $20 = $19 & 30;
  $21 = $14 & 32768;
  $22 = $18 | $21;
  $23 = $22 | $16;
  $24 = $23 | $20;
  $25 = $24&65535;
  $26 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $25;
  $27 = (($u$03) + ($1))|0;
  $28 = ($10|0)==(0);
  if ($28) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $26;$u$03 = $27;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_stretch_remap_argb4444_argb8888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$01 = $5;$dest$02 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$01) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<1)|0);
  $13 = HEAP16[$12>>1]|0;
  $14 = $13&65535;
  $15 = $14 & 61440;
  $16 = $14 << 12;
  $17 = $16 & 15728640;
  $18 = $14 << 8;
  $19 = $18 & 61440;
  $20 = $17 | $19;
  $21 = $14 << 4;
  $22 = $21 & 240;
  $23 = $20 | $22;
  $24 = $15 << 16;
  $25 = $23 | $24;
  $26 = $15 << 12;
  $27 = $25 | $26;
  $28 = (($dest$02) + 4|0);
  HEAP32[$dest$02>>2] = $27;
  $29 = (($u$03) + ($1))|0;
  $30 = ($10|0)==(0);
  if ($30) {
   break;
  } else {
   $count$01 = $10;$dest$02 = $28;$u$03 = $29;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_argb8888_i8P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 >>> 16;
  $15 = $14 & 255;
  $16 = ((1138392 + ($15<<2)|0) + 2|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $13 >>> 8;
  $20 = $19 & 255;
  $21 = ((1138392 + ($20<<2)|0) + 1|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = (($23) + ($18))|0;
  $25 = $13 & 255;
  $26 = (1138392 + ($25<<2)|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = (($24) + ($28))|0;
  $30 = $29&255;
  $31 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $30;
  $32 = (($u$03) + ($1))|0;
  $33 = ($10|0)==(0);
  if ($33) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $31;$u$03 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb8888_rgb332P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 >>> 16;
  $15 = $14 & 224;
  $16 = $13 >>> 11;
  $17 = $16 & 28;
  $18 = $15 | $17;
  $19 = $13 >>> 6;
  $20 = $19 & 3;
  $21 = $18 | $20;
  $22 = $21&255;
  $23 = (($dest$01) + 1|0);
  HEAP8[$dest$01>>0] = $22;
  $24 = (($u$03) + ($1))|0;
  $25 = ($10|0)==(0);
  if ($25) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $23;$u$03 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb8888_rgb565P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 >>> 8;
  $15 = $14 & 63488;
  $16 = $13 >>> 5;
  $17 = $16 & 2016;
  $18 = $15 | $17;
  $19 = $13 >>> 3;
  $20 = $19 & 31;
  $21 = $18 | $20;
  $22 = $21&65535;
  $23 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $22;
  $24 = (($u$03) + ($1))|0;
  $25 = ($10|0)==(0);
  if ($25) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $23;$u$03 = $24;
  }
 }
 STACKTOP = sp;return;
}
function __ZL35inner_stretch_remap_argb8888_rgb888P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $count$02 = $5;$dest$01 = $8;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13&255;
  HEAP8[$dest$01>>0] = $14;
  $15 = $13 >>> 8;
  $16 = $15&255;
  $17 = (($dest$01) + 1|0);
  HEAP8[$17>>0] = $16;
  $18 = $13 >>> 16;
  $19 = $18&255;
  $20 = (($dest$01) + 2|0);
  HEAP8[$20>>0] = $19;
  $21 = (($dest$01) + 3|0);
  $22 = (($u$03) + ($1))|0;
  $23 = ($10|0)==(0);
  if ($23) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $21;$u$03 = $22;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_stretch_remap_argb8888_argb1555P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 >>> 9;
  $15 = $14 & 31744;
  $16 = $13 >>> 6;
  $17 = $16 & 992;
  $18 = $13 >>> 3;
  $19 = $18 & 31;
  $20 = $17 | $15;
  $21 = $20 | $19;
  $22 = $21 | 32768;
  $23 = $22&65535;
  $24 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL37inner_stretch_remap_argb8888_argb4444P7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $count$02 = $5;$dest$01 = $7;$u$03 = $9;
 while(1) {
  $10 = (($count$02) + -1)|0;
  $11 = $u$03 >>> 16;
  $12 = (($3) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 >>> 12;
  $15 = $14 & 3840;
  $16 = $13 >>> 8;
  $17 = $16 & 240;
  $18 = $13 >>> 4;
  $19 = $18 & 15;
  $20 = $17 | $15;
  $21 = $20 | $19;
  $22 = $21 | 61440;
  $23 = $22&65535;
  $24 = (($dest$01) + 2|0);
  HEAP16[$dest$01>>1] = $23;
  $25 = (($u$03) + ($1))|0;
  $26 = ($10|0)==(0);
  if ($26) {
   break;
  } else {
   $count$02 = $10;$dest$01 = $24;$u$03 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_1rgba_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0;
 var $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01$i = $3;$dest$02$i = $6;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25)|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = HEAP32[$8>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$9>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$10>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$13>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$14>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$15>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$16>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$17>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$18>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$19>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$21>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$22>>2]|0;
  $72 = $70 | $71;
  $73 = $72&255;
  HEAP8[$dest$02$i>>0] = $73;
  $74 = HEAP32[$23>>2]|0;
  $75 = (($74) + ($u$03$i))|0;
  $76 = (($dest$02$i) + 1|0);
  $77 = ($24|0)==(0);
  if ($77) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $76;$u$03$i = $75;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_1rgba_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre$i = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre16$i = 0, $$pre17$i = 0, $$pre18$i = 0, $$pre19$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0;
 var $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $$pre$i = HEAP32[$8>>2]|0;
 $$pre4$i = HEAP32[$blitter>>2]|0;
 $$pre5$i = HEAP32[$9>>2]|0;
 $$pre6$i = HEAP32[$10>>2]|0;
 $$pre7$i = HEAP32[$11>>2]|0;
 $$pre8$i = HEAP32[$12>>2]|0;
 $$pre9$i = HEAP32[$13>>2]|0;
 $$pre10$i = HEAP32[$14>>2]|0;
 $$pre11$i = HEAP32[$15>>2]|0;
 $$pre12$i = HEAP32[$16>>2]|0;
 $$pre13$i = HEAP32[$17>>2]|0;
 $$pre14$i = HEAP32[$18>>2]|0;
 $$pre15$i = HEAP32[$19>>2]|0;
 $$pre16$i = HEAP32[$20>>2]|0;
 $$pre17$i = HEAP32[$21>>2]|0;
 $$pre18$i = HEAP32[$22>>2]|0;
 $$pre19$i = HEAP32[$23>>2]|0;
 $count$01$i = $3;$dest$02$i = $5;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25)|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = $28 >>> $$pre$i;
  $30 = $29 << $$pre4$i;
  $31 = $30 & $$pre5$i;
  $32 = ((1138392 + ($31<<2)|0) + 2|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = $28 >>> $$pre6$i;
  $36 = $35 << $$pre7$i;
  $37 = $36 & $$pre8$i;
  $38 = ((1138392 + ($37<<2)|0) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = (($40) + ($34))|0;
  $42 = $28 >>> $$pre9$i;
  $43 = $42 << $$pre10$i;
  $44 = $43 & $$pre11$i;
  $45 = (1138392 + ($44<<2)|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  $48 = (($41) + ($47))|0;
  $49 = $48 >>> $$pre12$i;
  $50 = $49 << $$pre13$i;
  $51 = $50 & $$pre14$i;
  $52 = $28 >>> $$pre15$i;
  $53 = $52 << $$pre16$i;
  $54 = $53 & $$pre17$i;
  $55 = $54 | $$pre18$i;
  $56 = $55 | $51;
  $57 = $56&65535;
  HEAP16[$dest$02$i>>1] = $57;
  $58 = (($u$03$i) + ($$pre19$i))|0;
  $59 = (($dest$02$i) + 2|0);
  $60 = ($24|0)==(0);
  if ($60) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $59;$u$03$i = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_1rgba_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01 = $3;$dest$02 = $6;$u$03 = $7;
 while(1) {
  $24 = (($count$01) + -1)|0;
  $25 = $u$03 >>> 16;
  $26 = (($1) + ($25)|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = HEAP32[$8>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$9>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$10>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$13>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$14>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$15>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$16>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$17>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$18>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$19>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$21>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$22>>2]|0;
  $72 = $70 | $71;
  $73 = $72&255;
  HEAP8[$dest$02>>0] = $73;
  $74 = $72 >>> 8;
  $75 = $74&255;
  $76 = (($dest$02) + 1|0);
  HEAP8[$76>>0] = $75;
  $77 = $72 >>> 16;
  $78 = $77&255;
  $79 = (($dest$02) + 2|0);
  HEAP8[$79>>0] = $78;
  $80 = (($dest$02) + 3|0);
  $81 = HEAP32[$23>>2]|0;
  $82 = (($81) + ($u$03))|0;
  $83 = ($24|0)==(0);
  if ($83) {
   break;
  } else {
   $count$01 = $24;$dest$02 = $80;$u$03 = $82;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_1rgba_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0, $u$03$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01$i = $3;$dest$02$i = $5;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25)|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = HEAP32[$8>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$9>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$10>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$13>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$14>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$15>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$16>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$17>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$18>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$19>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$21>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$22>>2]|0;
  $72 = $70 | $71;
  HEAP32[$dest$02$i>>2] = $72;
  $73 = HEAP32[$23>>2]|0;
  $74 = (($73) + ($u$03$i))|0;
  $75 = (($dest$02$i) + 4|0);
  $76 = ($24|0)==(0);
  if ($76) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $75;$u$03$i = $74;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_2rgba_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0;
 var $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01$i = $3;$dest$02$i = $6;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25<<1)|0);
  $27 = HEAP16[$26>>1]|0;
  $28 = $27&65535;
  $29 = HEAP32[$8>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$9>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$10>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$13>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$14>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$15>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$16>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$17>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$18>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$19>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$21>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$22>>2]|0;
  $72 = $70 | $71;
  $73 = $72&255;
  HEAP8[$dest$02$i>>0] = $73;
  $74 = HEAP32[$23>>2]|0;
  $75 = (($74) + ($u$03$i))|0;
  $76 = (($dest$02$i) + 1|0);
  $77 = ($24|0)==(0);
  if ($77) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $76;$u$03$i = $75;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_2rgba_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre$i = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre16$i = 0, $$pre17$i = 0, $$pre18$i = 0, $$pre19$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0;
 var $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $$pre$i = HEAP32[$8>>2]|0;
 $$pre4$i = HEAP32[$blitter>>2]|0;
 $$pre5$i = HEAP32[$9>>2]|0;
 $$pre6$i = HEAP32[$10>>2]|0;
 $$pre7$i = HEAP32[$11>>2]|0;
 $$pre8$i = HEAP32[$12>>2]|0;
 $$pre9$i = HEAP32[$13>>2]|0;
 $$pre10$i = HEAP32[$14>>2]|0;
 $$pre11$i = HEAP32[$15>>2]|0;
 $$pre12$i = HEAP32[$16>>2]|0;
 $$pre13$i = HEAP32[$17>>2]|0;
 $$pre14$i = HEAP32[$18>>2]|0;
 $$pre15$i = HEAP32[$19>>2]|0;
 $$pre16$i = HEAP32[$20>>2]|0;
 $$pre17$i = HEAP32[$21>>2]|0;
 $$pre18$i = HEAP32[$22>>2]|0;
 $$pre19$i = HEAP32[$23>>2]|0;
 $count$01$i = $3;$dest$02$i = $5;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25<<1)|0);
  $27 = HEAP16[$26>>1]|0;
  $28 = $27&65535;
  $29 = $28 >>> $$pre$i;
  $30 = $29 << $$pre4$i;
  $31 = $30 & $$pre5$i;
  $32 = ((1138392 + ($31<<2)|0) + 2|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = $28 >>> $$pre6$i;
  $36 = $35 << $$pre7$i;
  $37 = $36 & $$pre8$i;
  $38 = ((1138392 + ($37<<2)|0) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = (($40) + ($34))|0;
  $42 = $28 >>> $$pre9$i;
  $43 = $42 << $$pre10$i;
  $44 = $43 & $$pre11$i;
  $45 = (1138392 + ($44<<2)|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46&255;
  $48 = (($41) + ($47))|0;
  $49 = $48 >>> $$pre12$i;
  $50 = $49 << $$pre13$i;
  $51 = $50 & $$pre14$i;
  $52 = $28 >>> $$pre15$i;
  $53 = $52 << $$pre16$i;
  $54 = $53 & $$pre17$i;
  $55 = $54 | $$pre18$i;
  $56 = $55 | $51;
  $57 = $56&65535;
  HEAP16[$dest$02$i>>1] = $57;
  $58 = (($u$03$i) + ($$pre19$i))|0;
  $59 = (($dest$02$i) + 2|0);
  $60 = ($24|0)==(0);
  if ($60) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $59;$u$03$i = $58;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_2rgba_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01 = $3;$dest$02 = $6;$u$03 = $7;
 while(1) {
  $24 = (($count$01) + -1)|0;
  $25 = $u$03 >>> 16;
  $26 = (($1) + ($25<<1)|0);
  $27 = HEAP16[$26>>1]|0;
  $28 = $27&65535;
  $29 = HEAP32[$8>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$9>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$10>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$13>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$14>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$15>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$16>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$17>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$18>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$19>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$21>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$22>>2]|0;
  $72 = $70 | $71;
  $73 = $72&255;
  HEAP8[$dest$02>>0] = $73;
  $74 = $72 >>> 8;
  $75 = $74&255;
  $76 = (($dest$02) + 1|0);
  HEAP8[$76>>0] = $75;
  $77 = $72 >>> 16;
  $78 = $77&255;
  $79 = (($dest$02) + 2|0);
  HEAP8[$79>>0] = $78;
  $80 = (($dest$02) + 3|0);
  $81 = HEAP32[$23>>2]|0;
  $82 = (($81) + ($u$03))|0;
  $83 = ($24|0)==(0);
  if ($83) {
   break;
  } else {
   $count$01 = $24;$dest$02 = $80;$u$03 = $82;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_2rgba_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0, $u$03$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01$i = $3;$dest$02$i = $5;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25<<1)|0);
  $27 = HEAP16[$26>>1]|0;
  $28 = $27&65535;
  $29 = HEAP32[$8>>2]|0;
  $30 = $28 >>> $29;
  $31 = HEAP32[$blitter>>2]|0;
  $32 = $30 << $31;
  $33 = HEAP32[$9>>2]|0;
  $34 = $32 & $33;
  $35 = ((1138392 + ($34<<2)|0) + 2|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = HEAP32[$10>>2]|0;
  $39 = $28 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($37))|0;
  $48 = HEAP32[$13>>2]|0;
  $49 = $28 >>> $48;
  $50 = HEAP32[$14>>2]|0;
  $51 = $49 << $50;
  $52 = HEAP32[$15>>2]|0;
  $53 = $51 & $52;
  $54 = (1138392 + ($53<<2)|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = $55&255;
  $57 = (($47) + ($56))|0;
  $58 = HEAP32[$16>>2]|0;
  $59 = $57 >>> $58;
  $60 = HEAP32[$17>>2]|0;
  $61 = $59 << $60;
  $62 = HEAP32[$18>>2]|0;
  $63 = $61 & $62;
  $64 = HEAP32[$19>>2]|0;
  $65 = $28 >>> $64;
  $66 = HEAP32[$20>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$21>>2]|0;
  $69 = $67 & $68;
  $70 = $69 | $63;
  $71 = HEAP32[$22>>2]|0;
  $72 = $70 | $71;
  HEAP32[$dest$02$i>>2] = $72;
  $73 = HEAP32[$23>>2]|0;
  $74 = (($73) + ($u$03$i))|0;
  $75 = (($dest$02$i) + 4|0);
  $76 = ($24|0)==(0);
  if ($76) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $75;$u$03$i = $74;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_3rgba_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $count$03 = 0, $dest$04 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$03 = $3;$dest$04 = $6;$u$05 = $7;
 while(1) {
  $24 = (($count$03) + -1)|0;
  $25 = $u$05 >>> 16;
  $26 = ($25*3)|0;
  $27 = (($1) + ($26)|0);
  $$val = HEAP8[$27>>0]|0;
  $$sum = (($26) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($26) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $28 = $$val&255;
  $29 = $$idx$val&255;
  $30 = $29 << 8;
  $31 = $30 | $28;
  $32 = $$idx1$val&255;
  $33 = $32 << 16;
  $34 = $31 | $33;
  $35 = HEAP32[$8>>2]|0;
  $36 = $34 >>> $35;
  $37 = HEAP32[$blitter>>2]|0;
  $38 = $36 << $37;
  $39 = HEAP32[$9>>2]|0;
  $40 = $38 & $39;
  $41 = ((1138392 + ($40<<2)|0) + 2|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = $42&255;
  $44 = HEAP32[$10>>2]|0;
  $45 = $34 >>> $44;
  $46 = HEAP32[$11>>2]|0;
  $47 = $45 << $46;
  $48 = HEAP32[$12>>2]|0;
  $49 = $47 & $48;
  $50 = ((1138392 + ($49<<2)|0) + 1|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51&255;
  $53 = (($52) + ($43))|0;
  $54 = HEAP32[$13>>2]|0;
  $55 = $34 >>> $54;
  $56 = HEAP32[$14>>2]|0;
  $57 = $55 << $56;
  $58 = HEAP32[$15>>2]|0;
  $59 = $57 & $58;
  $60 = (1138392 + ($59<<2)|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = $61&255;
  $63 = (($53) + ($62))|0;
  $64 = HEAP32[$16>>2]|0;
  $65 = $63 >>> $64;
  $66 = HEAP32[$17>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$18>>2]|0;
  $69 = $67 & $68;
  $70 = HEAP32[$19>>2]|0;
  $71 = $34 >>> $70;
  $72 = HEAP32[$20>>2]|0;
  $73 = $71 << $72;
  $74 = HEAP32[$21>>2]|0;
  $75 = $73 & $74;
  $76 = $75 | $69;
  $77 = HEAP32[$22>>2]|0;
  $78 = $76 | $77;
  $79 = $78&255;
  $80 = (($dest$04) + 1|0);
  HEAP8[$dest$04>>0] = $79;
  $81 = HEAP32[$23>>2]|0;
  $82 = (($81) + ($u$05))|0;
  $83 = ($24|0)==(0);
  if ($83) {
   break;
  } else {
   $count$03 = $24;$dest$04 = $80;$u$05 = $82;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_3rgba_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre19 = 0, $$pre20 = 0, $$pre21 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0;
 var $$pre9 = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $count$03 = 0, $dest$04 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $$pre = HEAP32[$8>>2]|0;
 $$pre6 = HEAP32[$blitter>>2]|0;
 $$pre7 = HEAP32[$9>>2]|0;
 $$pre8 = HEAP32[$10>>2]|0;
 $$pre9 = HEAP32[$11>>2]|0;
 $$pre10 = HEAP32[$12>>2]|0;
 $$pre11 = HEAP32[$13>>2]|0;
 $$pre12 = HEAP32[$14>>2]|0;
 $$pre13 = HEAP32[$15>>2]|0;
 $$pre14 = HEAP32[$16>>2]|0;
 $$pre15 = HEAP32[$17>>2]|0;
 $$pre16 = HEAP32[$18>>2]|0;
 $$pre17 = HEAP32[$19>>2]|0;
 $$pre18 = HEAP32[$20>>2]|0;
 $$pre19 = HEAP32[$21>>2]|0;
 $$pre20 = HEAP32[$22>>2]|0;
 $$pre21 = HEAP32[$23>>2]|0;
 $count$03 = $3;$dest$04 = $5;$u$05 = $7;
 while(1) {
  $24 = (($count$03) + -1)|0;
  $25 = $u$05 >>> 16;
  $26 = ($25*3)|0;
  $27 = (($1) + ($26)|0);
  $$val = HEAP8[$27>>0]|0;
  $$sum = (($26) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($26) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $28 = $$val&255;
  $29 = $$idx$val&255;
  $30 = $29 << 8;
  $31 = $30 | $28;
  $32 = $$idx1$val&255;
  $33 = $32 << 16;
  $34 = $31 | $33;
  $35 = $34 >>> $$pre;
  $36 = $35 << $$pre6;
  $37 = $36 & $$pre7;
  $38 = ((1138392 + ($37<<2)|0) + 2|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39&255;
  $41 = $34 >>> $$pre8;
  $42 = $41 << $$pre9;
  $43 = $42 & $$pre10;
  $44 = ((1138392 + ($43<<2)|0) + 1|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($46) + ($40))|0;
  $48 = $34 >>> $$pre11;
  $49 = $48 << $$pre12;
  $50 = $49 & $$pre13;
  $51 = (1138392 + ($50<<2)|0);
  $52 = HEAP8[$51>>0]|0;
  $53 = $52&255;
  $54 = (($47) + ($53))|0;
  $55 = $54 >>> $$pre14;
  $56 = $55 << $$pre15;
  $57 = $56 & $$pre16;
  $58 = $34 >>> $$pre17;
  $59 = $58 << $$pre18;
  $60 = $59 & $$pre19;
  $61 = $60 | $57;
  $62 = $61 | $$pre20;
  $63 = $62&65535;
  $64 = (($dest$04) + 2|0);
  HEAP16[$dest$04>>1] = $63;
  $65 = (($$pre21) + ($u$05))|0;
  $66 = ($24|0)==(0);
  if ($66) {
   break;
  } else {
   $count$03 = $24;$dest$04 = $64;$u$05 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_3rgba_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $count$03 = 0, $dest$04 = 0, $u$05 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$03 = $3;$dest$04 = $6;$u$05 = $7;
 while(1) {
  $24 = (($count$03) + -1)|0;
  $25 = $u$05 >>> 16;
  $26 = ($25*3)|0;
  $27 = (($1) + ($26)|0);
  $$val = HEAP8[$27>>0]|0;
  $$sum = (($26) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($26) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $28 = $$val&255;
  $29 = $$idx$val&255;
  $30 = $29 << 8;
  $31 = $30 | $28;
  $32 = $$idx1$val&255;
  $33 = $32 << 16;
  $34 = $31 | $33;
  $35 = HEAP32[$8>>2]|0;
  $36 = $34 >>> $35;
  $37 = HEAP32[$blitter>>2]|0;
  $38 = $36 << $37;
  $39 = HEAP32[$9>>2]|0;
  $40 = $38 & $39;
  $41 = ((1138392 + ($40<<2)|0) + 2|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = $42&255;
  $44 = HEAP32[$10>>2]|0;
  $45 = $34 >>> $44;
  $46 = HEAP32[$11>>2]|0;
  $47 = $45 << $46;
  $48 = HEAP32[$12>>2]|0;
  $49 = $47 & $48;
  $50 = ((1138392 + ($49<<2)|0) + 1|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51&255;
  $53 = (($52) + ($43))|0;
  $54 = HEAP32[$13>>2]|0;
  $55 = $34 >>> $54;
  $56 = HEAP32[$14>>2]|0;
  $57 = $55 << $56;
  $58 = HEAP32[$15>>2]|0;
  $59 = $57 & $58;
  $60 = (1138392 + ($59<<2)|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = $61&255;
  $63 = (($53) + ($62))|0;
  $64 = HEAP32[$16>>2]|0;
  $65 = $63 >>> $64;
  $66 = HEAP32[$17>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$18>>2]|0;
  $69 = $67 & $68;
  $70 = HEAP32[$19>>2]|0;
  $71 = $34 >>> $70;
  $72 = HEAP32[$20>>2]|0;
  $73 = $71 << $72;
  $74 = HEAP32[$21>>2]|0;
  $75 = $73 & $74;
  $76 = $75 | $69;
  $77 = HEAP32[$22>>2]|0;
  $78 = $76 | $77;
  $79 = $78&255;
  HEAP8[$dest$04>>0] = $79;
  $80 = $78 >>> 8;
  $81 = $80&255;
  $82 = (($dest$04) + 1|0);
  HEAP8[$82>>0] = $81;
  $83 = $78 >>> 16;
  $84 = $83&255;
  $85 = (($dest$04) + 2|0);
  HEAP8[$85>>0] = $84;
  $86 = (($dest$04) + 3|0);
  $87 = HEAP32[$23>>2]|0;
  $88 = (($87) + ($u$05))|0;
  $89 = ($24|0)==(0);
  if ($89) {
   break;
  } else {
   $count$03 = $24;$dest$04 = $86;$u$05 = $88;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_3rgba_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $count$03 = 0, $dest$04 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$03 = $3;$dest$04 = $5;$u$05 = $7;
 while(1) {
  $24 = (($count$03) + -1)|0;
  $25 = $u$05 >>> 16;
  $26 = ($25*3)|0;
  $27 = (($1) + ($26)|0);
  $$val = HEAP8[$27>>0]|0;
  $$sum = (($26) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($26) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $28 = $$val&255;
  $29 = $$idx$val&255;
  $30 = $29 << 8;
  $31 = $30 | $28;
  $32 = $$idx1$val&255;
  $33 = $32 << 16;
  $34 = $31 | $33;
  $35 = HEAP32[$8>>2]|0;
  $36 = $34 >>> $35;
  $37 = HEAP32[$blitter>>2]|0;
  $38 = $36 << $37;
  $39 = HEAP32[$9>>2]|0;
  $40 = $38 & $39;
  $41 = ((1138392 + ($40<<2)|0) + 2|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = $42&255;
  $44 = HEAP32[$10>>2]|0;
  $45 = $34 >>> $44;
  $46 = HEAP32[$11>>2]|0;
  $47 = $45 << $46;
  $48 = HEAP32[$12>>2]|0;
  $49 = $47 & $48;
  $50 = ((1138392 + ($49<<2)|0) + 1|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51&255;
  $53 = (($52) + ($43))|0;
  $54 = HEAP32[$13>>2]|0;
  $55 = $34 >>> $54;
  $56 = HEAP32[$14>>2]|0;
  $57 = $55 << $56;
  $58 = HEAP32[$15>>2]|0;
  $59 = $57 & $58;
  $60 = (1138392 + ($59<<2)|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = $61&255;
  $63 = (($53) + ($62))|0;
  $64 = HEAP32[$16>>2]|0;
  $65 = $63 >>> $64;
  $66 = HEAP32[$17>>2]|0;
  $67 = $65 << $66;
  $68 = HEAP32[$18>>2]|0;
  $69 = $67 & $68;
  $70 = HEAP32[$19>>2]|0;
  $71 = $34 >>> $70;
  $72 = HEAP32[$20>>2]|0;
  $73 = $71 << $72;
  $74 = HEAP32[$21>>2]|0;
  $75 = $73 & $74;
  $76 = $75 | $69;
  $77 = HEAP32[$22>>2]|0;
  $78 = $76 | $77;
  $79 = (($dest$04) + 4|0);
  HEAP32[$dest$04>>2] = $78;
  $80 = HEAP32[$23>>2]|0;
  $81 = (($80) + ($u$05))|0;
  $82 = ($24|0)==(0);
  if ($82) {
   break;
  } else {
   $count$03 = $24;$dest$04 = $79;$u$05 = $81;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_4rgba_1iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0, $u$03$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01$i = $3;$dest$02$i = $6;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$8>>2]|0;
  $29 = $27 >>> $28;
  $30 = HEAP32[$blitter>>2]|0;
  $31 = $29 << $30;
  $32 = HEAP32[$9>>2]|0;
  $33 = $31 & $32;
  $34 = ((1138392 + ($33<<2)|0) + 2|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35&255;
  $37 = HEAP32[$10>>2]|0;
  $38 = $27 >>> $37;
  $39 = HEAP32[$11>>2]|0;
  $40 = $38 << $39;
  $41 = HEAP32[$12>>2]|0;
  $42 = $40 & $41;
  $43 = ((1138392 + ($42<<2)|0) + 1|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = (($45) + ($36))|0;
  $47 = HEAP32[$13>>2]|0;
  $48 = $27 >>> $47;
  $49 = HEAP32[$14>>2]|0;
  $50 = $48 << $49;
  $51 = HEAP32[$15>>2]|0;
  $52 = $50 & $51;
  $53 = (1138392 + ($52<<2)|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = $54&255;
  $56 = (($46) + ($55))|0;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 >>> $57;
  $59 = HEAP32[$17>>2]|0;
  $60 = $58 << $59;
  $61 = HEAP32[$18>>2]|0;
  $62 = $60 & $61;
  $63 = HEAP32[$19>>2]|0;
  $64 = $27 >>> $63;
  $65 = HEAP32[$20>>2]|0;
  $66 = $64 << $65;
  $67 = HEAP32[$21>>2]|0;
  $68 = $66 & $67;
  $69 = $68 | $62;
  $70 = HEAP32[$22>>2]|0;
  $71 = $69 | $70;
  $72 = $71&255;
  HEAP8[$dest$02$i>>0] = $72;
  $73 = HEAP32[$23>>2]|0;
  $74 = (($73) + ($u$03$i))|0;
  $75 = (($dest$02$i) + 1|0);
  $76 = ($24|0)==(0);
  if ($76) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $75;$u$03$i = $74;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_4rgba_2iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre$i = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre16$i = 0, $$pre17$i = 0, $$pre18$i = 0, $$pre19$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0, $u$03$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $$pre$i = HEAP32[$8>>2]|0;
 $$pre4$i = HEAP32[$blitter>>2]|0;
 $$pre5$i = HEAP32[$9>>2]|0;
 $$pre6$i = HEAP32[$10>>2]|0;
 $$pre7$i = HEAP32[$11>>2]|0;
 $$pre8$i = HEAP32[$12>>2]|0;
 $$pre9$i = HEAP32[$13>>2]|0;
 $$pre10$i = HEAP32[$14>>2]|0;
 $$pre11$i = HEAP32[$15>>2]|0;
 $$pre12$i = HEAP32[$16>>2]|0;
 $$pre13$i = HEAP32[$17>>2]|0;
 $$pre14$i = HEAP32[$18>>2]|0;
 $$pre15$i = HEAP32[$19>>2]|0;
 $$pre16$i = HEAP32[$20>>2]|0;
 $$pre17$i = HEAP32[$21>>2]|0;
 $$pre18$i = HEAP32[$22>>2]|0;
 $$pre19$i = HEAP32[$23>>2]|0;
 $count$01$i = $3;$dest$02$i = $5;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 >>> $$pre$i;
  $29 = $28 << $$pre4$i;
  $30 = $29 & $$pre5$i;
  $31 = ((1138392 + ($30<<2)|0) + 2|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = $32&255;
  $34 = $27 >>> $$pre6$i;
  $35 = $34 << $$pre7$i;
  $36 = $35 & $$pre8$i;
  $37 = ((1138392 + ($36<<2)|0) + 1|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = $38&255;
  $40 = (($39) + ($33))|0;
  $41 = $27 >>> $$pre9$i;
  $42 = $41 << $$pre10$i;
  $43 = $42 & $$pre11$i;
  $44 = (1138392 + ($43<<2)|0);
  $45 = HEAP8[$44>>0]|0;
  $46 = $45&255;
  $47 = (($40) + ($46))|0;
  $48 = $47 >>> $$pre12$i;
  $49 = $48 << $$pre13$i;
  $50 = $49 & $$pre14$i;
  $51 = $27 >>> $$pre15$i;
  $52 = $51 << $$pre16$i;
  $53 = $52 & $$pre17$i;
  $54 = $53 | $$pre18$i;
  $55 = $54 | $50;
  $56 = $55&65535;
  HEAP16[$dest$02$i>>1] = $56;
  $57 = (($u$03$i) + ($$pre19$i))|0;
  $58 = (($dest$02$i) + 2|0);
  $59 = ($24|0)==(0);
  if ($59) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $58;$u$03$i = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_4rgba_3iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01 = $3;$dest$02 = $6;$u$03 = $7;
 while(1) {
  $24 = (($count$01) + -1)|0;
  $25 = $u$03 >>> 16;
  $26 = (($1) + ($25<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$8>>2]|0;
  $29 = $27 >>> $28;
  $30 = HEAP32[$blitter>>2]|0;
  $31 = $29 << $30;
  $32 = HEAP32[$9>>2]|0;
  $33 = $31 & $32;
  $34 = ((1138392 + ($33<<2)|0) + 2|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35&255;
  $37 = HEAP32[$10>>2]|0;
  $38 = $27 >>> $37;
  $39 = HEAP32[$11>>2]|0;
  $40 = $38 << $39;
  $41 = HEAP32[$12>>2]|0;
  $42 = $40 & $41;
  $43 = ((1138392 + ($42<<2)|0) + 1|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = (($45) + ($36))|0;
  $47 = HEAP32[$13>>2]|0;
  $48 = $27 >>> $47;
  $49 = HEAP32[$14>>2]|0;
  $50 = $48 << $49;
  $51 = HEAP32[$15>>2]|0;
  $52 = $50 & $51;
  $53 = (1138392 + ($52<<2)|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = $54&255;
  $56 = (($46) + ($55))|0;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 >>> $57;
  $59 = HEAP32[$17>>2]|0;
  $60 = $58 << $59;
  $61 = HEAP32[$18>>2]|0;
  $62 = $60 & $61;
  $63 = HEAP32[$19>>2]|0;
  $64 = $27 >>> $63;
  $65 = HEAP32[$20>>2]|0;
  $66 = $64 << $65;
  $67 = HEAP32[$21>>2]|0;
  $68 = $66 & $67;
  $69 = $68 | $62;
  $70 = HEAP32[$22>>2]|0;
  $71 = $69 | $70;
  $72 = $71&255;
  HEAP8[$dest$02>>0] = $72;
  $73 = $71 >>> 8;
  $74 = $73&255;
  $75 = (($dest$02) + 1|0);
  HEAP8[$75>>0] = $74;
  $76 = $71 >>> 16;
  $77 = $76&255;
  $78 = (($dest$02) + 2|0);
  HEAP8[$78>>0] = $77;
  $79 = (($dest$02) + 3|0);
  $80 = HEAP32[$23>>2]|0;
  $81 = (($80) + ($u$03))|0;
  $82 = ($24|0)==(0);
  if ($82) {
   break;
  } else {
   $count$01 = $24;$dest$02 = $79;$u$03 = $81;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_remap_4rgba_4iaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $count$01$i = 0, $dest$02$i = 0, $u$03$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 64|0);
 $17 = (($blitter) + 60|0);
 $18 = (($blitter) + 68|0);
 $19 = (($blitter) + 40|0);
 $20 = (($blitter) + 36|0);
 $21 = (($blitter) + 44|0);
 $22 = (($blitter) + 72|0);
 $23 = (($info) + 20|0);
 $count$01$i = $3;$dest$02$i = $5;$u$03$i = $7;
 while(1) {
  $24 = (($count$01$i) + -1)|0;
  $25 = $u$03$i >>> 16;
  $26 = (($1) + ($25<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = HEAP32[$8>>2]|0;
  $29 = $27 >>> $28;
  $30 = HEAP32[$blitter>>2]|0;
  $31 = $29 << $30;
  $32 = HEAP32[$9>>2]|0;
  $33 = $31 & $32;
  $34 = ((1138392 + ($33<<2)|0) + 2|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35&255;
  $37 = HEAP32[$10>>2]|0;
  $38 = $27 >>> $37;
  $39 = HEAP32[$11>>2]|0;
  $40 = $38 << $39;
  $41 = HEAP32[$12>>2]|0;
  $42 = $40 & $41;
  $43 = ((1138392 + ($42<<2)|0) + 1|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = (($45) + ($36))|0;
  $47 = HEAP32[$13>>2]|0;
  $48 = $27 >>> $47;
  $49 = HEAP32[$14>>2]|0;
  $50 = $48 << $49;
  $51 = HEAP32[$15>>2]|0;
  $52 = $50 & $51;
  $53 = (1138392 + ($52<<2)|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = $54&255;
  $56 = (($46) + ($55))|0;
  $57 = HEAP32[$16>>2]|0;
  $58 = $56 >>> $57;
  $59 = HEAP32[$17>>2]|0;
  $60 = $58 << $59;
  $61 = HEAP32[$18>>2]|0;
  $62 = $60 & $61;
  $63 = HEAP32[$19>>2]|0;
  $64 = $27 >>> $63;
  $65 = HEAP32[$20>>2]|0;
  $66 = $64 << $65;
  $67 = HEAP32[$21>>2]|0;
  $68 = $66 & $67;
  $69 = $68 | $62;
  $70 = HEAP32[$22>>2]|0;
  $71 = $69 | $70;
  HEAP32[$dest$02$i>>2] = $71;
  $72 = HEAP32[$23>>2]|0;
  $73 = (($72) + ($u$03$i))|0;
  $74 = (($dest$02$i) + 4|0);
  $75 = ($24|0)==(0);
  if ($75) {
   break;
  } else {
   $count$01$i = $24;$dest$02$i = $74;$u$03$i = $73;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_1rgba_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02$i = 0, $dest$01$i = 0, $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02$i = $3;$dest$01$i = $6;$u$03$i = $7;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = $u$03$i >>> 16;
  $23 = (($1) + ($22)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = HEAP32[$8>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$9>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$10>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$11>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$13>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$16>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$18>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$19>>2]|0;
  $54 = $52 | $53;
  $55 = $54&255;
  HEAP8[$dest$01$i>>0] = $55;
  $56 = HEAP32[$20>>2]|0;
  $57 = (($56) + ($u$03$i))|0;
  $58 = (($dest$01$i) + 1|0);
  $59 = ($21|0)==(0);
  if ($59) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $58;$u$03$i = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_1rgba_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$pre$i = 0, $$pre10$i = 0, $$pre11$i = 0, $$pre12$i = 0, $$pre13$i = 0, $$pre14$i = 0, $$pre15$i = 0, $$pre16$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$pre9$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02$i = 0, $dest$01$i = 0, $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $$pre$i = HEAP32[$8>>2]|0;
 $$pre4$i = HEAP32[$blitter>>2]|0;
 $$pre5$i = HEAP32[$9>>2]|0;
 $$pre6$i = HEAP32[$10>>2]|0;
 $$pre7$i = HEAP32[$11>>2]|0;
 $$pre8$i = HEAP32[$12>>2]|0;
 $$pre9$i = HEAP32[$13>>2]|0;
 $$pre10$i = HEAP32[$14>>2]|0;
 $$pre11$i = HEAP32[$15>>2]|0;
 $$pre12$i = HEAP32[$16>>2]|0;
 $$pre13$i = HEAP32[$17>>2]|0;
 $$pre14$i = HEAP32[$18>>2]|0;
 $$pre15$i = HEAP32[$19>>2]|0;
 $$pre16$i = HEAP32[$20>>2]|0;
 $count$02$i = $3;$dest$01$i = $5;$u$03$i = $7;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = $u$03$i >>> 16;
  $23 = (($1) + ($22)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = $25 >>> $$pre$i;
  $27 = $26 << $$pre4$i;
  $28 = $27 & $$pre5$i;
  $29 = $25 >>> $$pre6$i;
  $30 = $29 << $$pre7$i;
  $31 = $30 & $$pre8$i;
  $32 = $25 >>> $$pre9$i;
  $33 = $32 << $$pre10$i;
  $34 = $33 & $$pre11$i;
  $35 = $25 >>> $$pre12$i;
  $36 = $35 << $$pre13$i;
  $37 = $36 & $$pre14$i;
  $38 = $28 | $$pre15$i;
  $39 = $38 | $31;
  $40 = $39 | $34;
  $41 = $40 | $37;
  $42 = $41&65535;
  HEAP16[$dest$01$i>>1] = $42;
  $43 = (($u$03$i) + ($$pre16$i))|0;
  $44 = (($dest$01$i) + 2|0);
  $45 = ($21|0)==(0);
  if ($45) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $44;$u$03$i = $43;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_1rgba_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02 = $3;$dest$01 = $6;$u$03 = $7;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $22 = $u$03 >>> 16;
  $23 = (($1) + ($22)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = HEAP32[$8>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$9>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$10>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$11>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$13>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$16>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$18>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$19>>2]|0;
  $54 = $52 | $53;
  $55 = $54&255;
  HEAP8[$dest$01>>0] = $55;
  $56 = $54 >>> 8;
  $57 = $56&255;
  $58 = (($dest$01) + 1|0);
  HEAP8[$58>>0] = $57;
  $59 = $54 >>> 16;
  $60 = $59&255;
  $61 = (($dest$01) + 2|0);
  HEAP8[$61>>0] = $60;
  $62 = (($dest$01) + 3|0);
  $63 = HEAP32[$20>>2]|0;
  $64 = (($63) + ($u$03))|0;
  $65 = ($21|0)==(0);
  if ($65) {
   break;
  } else {
   $count$02 = $21;$dest$01 = $62;$u$03 = $64;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_1rgba_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0;
 var $dest$01$i = 0, $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02$i = $3;$dest$01$i = $5;$u$03$i = $7;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = $u$03$i >>> 16;
  $23 = (($1) + ($22)|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = HEAP32[$8>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$9>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$10>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$11>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$13>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$16>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$18>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$19>>2]|0;
  $54 = $52 | $53;
  HEAP32[$dest$01$i>>2] = $54;
  $55 = HEAP32[$20>>2]|0;
  $56 = (($55) + ($u$03$i))|0;
  $57 = (($dest$01$i) + 4|0);
  $58 = ($21|0)==(0);
  if ($58) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $57;$u$03$i = $56;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_2rgba_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02$i = 0, $dest$01$i = 0, $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02$i = $3;$dest$01$i = $6;$u$03$i = $7;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = $u$03$i >>> 16;
  $23 = (($1) + ($22<<1)|0);
  $24 = HEAP16[$23>>1]|0;
  $25 = $24&65535;
  $26 = HEAP32[$8>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$9>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$10>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$11>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$13>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$16>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$18>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$19>>2]|0;
  $54 = $52 | $53;
  $55 = $54&255;
  HEAP8[$dest$01$i>>0] = $55;
  $56 = HEAP32[$20>>2]|0;
  $57 = (($56) + ($u$03$i))|0;
  $58 = (($dest$01$i) + 1|0);
  $59 = ($21|0)==(0);
  if ($59) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $58;$u$03$i = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_2rgba_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $count$02$i = 0, $dest$01$i = 0, $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$blitter>>2]|0;
 $11 = (($blitter) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($blitter) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($blitter) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($blitter) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($blitter) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($blitter) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($blitter) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($blitter) + 40|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($blitter) + 36|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($blitter) + 44|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($blitter) + 72|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($info) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $count$02$i = $3;$dest$01$i = $5;$u$03$i = $7;
 while(1) {
  $35 = (($count$02$i) + -1)|0;
  $36 = $u$03$i >>> 16;
  $37 = (($1) + ($36<<1)|0);
  $38 = HEAP16[$37>>1]|0;
  $39 = $38&65535;
  $40 = $39 >>> $9;
  $41 = $40 << $10;
  $42 = $41 & $12;
  $43 = $39 >>> $14;
  $44 = $43 << $16;
  $45 = $44 & $18;
  $46 = $39 >>> $20;
  $47 = $46 << $22;
  $48 = $47 & $24;
  $49 = $39 >>> $26;
  $50 = $49 << $28;
  $51 = $50 & $30;
  $52 = $42 | $32;
  $53 = $52 | $45;
  $54 = $53 | $48;
  $55 = $54 | $51;
  $56 = $55&65535;
  HEAP16[$dest$01$i>>1] = $56;
  $57 = (($u$03$i) + ($34))|0;
  $58 = (($dest$01$i) + 2|0);
  $59 = ($35|0)==(0);
  if ($59) {
   break;
  } else {
   $count$02$i = $35;$dest$01$i = $58;$u$03$i = $57;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_2rgba_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02 = $3;$dest$01 = $6;$u$03 = $7;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $22 = $u$03 >>> 16;
  $23 = (($1) + ($22<<1)|0);
  $24 = HEAP16[$23>>1]|0;
  $25 = $24&65535;
  $26 = HEAP32[$8>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$9>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$10>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$11>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$13>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$16>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$18>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$19>>2]|0;
  $54 = $52 | $53;
  $55 = $54&255;
  HEAP8[$dest$01>>0] = $55;
  $56 = $54 >>> 8;
  $57 = $56&255;
  $58 = (($dest$01) + 1|0);
  HEAP8[$58>>0] = $57;
  $59 = $54 >>> 16;
  $60 = $59&255;
  $61 = (($dest$01) + 2|0);
  HEAP8[$61>>0] = $60;
  $62 = (($dest$01) + 3|0);
  $63 = HEAP32[$20>>2]|0;
  $64 = (($63) + ($u$03))|0;
  $65 = ($21|0)==(0);
  if ($65) {
   break;
  } else {
   $count$02 = $21;$dest$01 = $62;$u$03 = $64;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_2rgba_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0;
 var $dest$01$i = 0, $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02$i = $3;$dest$01$i = $5;$u$03$i = $7;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = $u$03$i >>> 16;
  $23 = (($1) + ($22<<1)|0);
  $24 = HEAP16[$23>>1]|0;
  $25 = $24&65535;
  $26 = HEAP32[$8>>2]|0;
  $27 = $25 >>> $26;
  $28 = HEAP32[$blitter>>2]|0;
  $29 = $27 << $28;
  $30 = HEAP32[$9>>2]|0;
  $31 = $29 & $30;
  $32 = HEAP32[$10>>2]|0;
  $33 = $25 >>> $32;
  $34 = HEAP32[$11>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$12>>2]|0;
  $37 = $35 & $36;
  $38 = $37 | $31;
  $39 = HEAP32[$13>>2]|0;
  $40 = $25 >>> $39;
  $41 = HEAP32[$14>>2]|0;
  $42 = $40 << $41;
  $43 = HEAP32[$15>>2]|0;
  $44 = $42 & $43;
  $45 = $38 | $44;
  $46 = HEAP32[$16>>2]|0;
  $47 = $25 >>> $46;
  $48 = HEAP32[$17>>2]|0;
  $49 = $47 << $48;
  $50 = HEAP32[$18>>2]|0;
  $51 = $49 & $50;
  $52 = $45 | $51;
  $53 = HEAP32[$19>>2]|0;
  $54 = $52 | $53;
  HEAP32[$dest$01$i>>2] = $54;
  $55 = HEAP32[$20>>2]|0;
  $56 = (($55) + ($u$03$i))|0;
  $57 = (($dest$01$i) + 4|0);
  $58 = ($21|0)==(0);
  if ($58) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $57;$u$03$i = $56;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_3rgba_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0, $dest$03 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$04 = $3;$dest$03 = $6;$u$05 = $7;
 while(1) {
  $21 = (($count$04) + -1)|0;
  $22 = $u$05 >>> 16;
  $23 = ($22*3)|0;
  $24 = (($1) + ($23)|0);
  $$val = HEAP8[$24>>0]|0;
  $$sum = (($23) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($23) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $25 = $$val&255;
  $26 = $$idx$val&255;
  $27 = $26 << 8;
  $28 = $27 | $25;
  $29 = $$idx1$val&255;
  $30 = $29 << 16;
  $31 = $28 | $30;
  $32 = HEAP32[$8>>2]|0;
  $33 = $31 >>> $32;
  $34 = HEAP32[$blitter>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$9>>2]|0;
  $37 = $35 & $36;
  $38 = HEAP32[$10>>2]|0;
  $39 = $31 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = $43 | $37;
  $45 = HEAP32[$13>>2]|0;
  $46 = $31 >>> $45;
  $47 = HEAP32[$14>>2]|0;
  $48 = $46 << $47;
  $49 = HEAP32[$15>>2]|0;
  $50 = $48 & $49;
  $51 = $44 | $50;
  $52 = HEAP32[$16>>2]|0;
  $53 = $31 >>> $52;
  $54 = HEAP32[$17>>2]|0;
  $55 = $53 << $54;
  $56 = HEAP32[$18>>2]|0;
  $57 = $55 & $56;
  $58 = $51 | $57;
  $59 = HEAP32[$19>>2]|0;
  $60 = $58 | $59;
  $61 = $60&255;
  $62 = (($dest$03) + 1|0);
  HEAP8[$dest$03>>0] = $61;
  $63 = HEAP32[$20>>2]|0;
  $64 = (($63) + ($u$05))|0;
  $65 = ($21|0)==(0);
  if ($65) {
   break;
  } else {
   $count$04 = $21;$dest$03 = $62;$u$05 = $64;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_3rgba_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre12 = 0, $$pre13 = 0, $$pre14 = 0, $$pre15 = 0, $$pre16 = 0, $$pre17 = 0, $$pre18 = 0, $$pre6 = 0, $$pre7 = 0, $$pre8 = 0, $$pre9 = 0, $$sum = 0, $$sum2 = 0;
 var $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0, $dest$03 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $$pre = HEAP32[$8>>2]|0;
 $$pre6 = HEAP32[$blitter>>2]|0;
 $$pre7 = HEAP32[$9>>2]|0;
 $$pre8 = HEAP32[$10>>2]|0;
 $$pre9 = HEAP32[$11>>2]|0;
 $$pre10 = HEAP32[$12>>2]|0;
 $$pre11 = HEAP32[$13>>2]|0;
 $$pre12 = HEAP32[$14>>2]|0;
 $$pre13 = HEAP32[$15>>2]|0;
 $$pre14 = HEAP32[$16>>2]|0;
 $$pre15 = HEAP32[$17>>2]|0;
 $$pre16 = HEAP32[$18>>2]|0;
 $$pre17 = HEAP32[$19>>2]|0;
 $$pre18 = HEAP32[$20>>2]|0;
 $count$04 = $3;$dest$03 = $5;$u$05 = $7;
 while(1) {
  $21 = (($count$04) + -1)|0;
  $22 = $u$05 >>> 16;
  $23 = ($22*3)|0;
  $24 = (($1) + ($23)|0);
  $$val = HEAP8[$24>>0]|0;
  $$sum = (($23) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($23) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $25 = $$val&255;
  $26 = $$idx$val&255;
  $27 = $26 << 8;
  $28 = $27 | $25;
  $29 = $$idx1$val&255;
  $30 = $29 << 16;
  $31 = $28 | $30;
  $32 = $31 >>> $$pre;
  $33 = $32 << $$pre6;
  $34 = $33 & $$pre7;
  $35 = $31 >>> $$pre8;
  $36 = $35 << $$pre9;
  $37 = $36 & $$pre10;
  $38 = $37 | $34;
  $39 = $31 >>> $$pre11;
  $40 = $39 << $$pre12;
  $41 = $40 & $$pre13;
  $42 = $38 | $41;
  $43 = $31 >>> $$pre14;
  $44 = $43 << $$pre15;
  $45 = $44 & $$pre16;
  $46 = $42 | $45;
  $47 = $46 | $$pre17;
  $48 = $47&65535;
  $49 = (($dest$03) + 2|0);
  HEAP16[$dest$03>>1] = $48;
  $50 = (($$pre18) + ($u$05))|0;
  $51 = ($21|0)==(0);
  if ($51) {
   break;
  } else {
   $count$04 = $21;$dest$03 = $49;$u$05 = $50;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_3rgba_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $count$04 = 0;
 var $dest$03 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$04 = $3;$dest$03 = $6;$u$05 = $7;
 while(1) {
  $21 = (($count$04) + -1)|0;
  $22 = $u$05 >>> 16;
  $23 = ($22*3)|0;
  $24 = (($1) + ($23)|0);
  $$val = HEAP8[$24>>0]|0;
  $$sum = (($23) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($23) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $25 = $$val&255;
  $26 = $$idx$val&255;
  $27 = $26 << 8;
  $28 = $27 | $25;
  $29 = $$idx1$val&255;
  $30 = $29 << 16;
  $31 = $28 | $30;
  $32 = HEAP32[$8>>2]|0;
  $33 = $31 >>> $32;
  $34 = HEAP32[$blitter>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$9>>2]|0;
  $37 = $35 & $36;
  $38 = HEAP32[$10>>2]|0;
  $39 = $31 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = $43 | $37;
  $45 = HEAP32[$13>>2]|0;
  $46 = $31 >>> $45;
  $47 = HEAP32[$14>>2]|0;
  $48 = $46 << $47;
  $49 = HEAP32[$15>>2]|0;
  $50 = $48 & $49;
  $51 = $44 | $50;
  $52 = HEAP32[$16>>2]|0;
  $53 = $31 >>> $52;
  $54 = HEAP32[$17>>2]|0;
  $55 = $53 << $54;
  $56 = HEAP32[$18>>2]|0;
  $57 = $55 & $56;
  $58 = $51 | $57;
  $59 = HEAP32[$19>>2]|0;
  $60 = $58 | $59;
  $61 = $60&255;
  HEAP8[$dest$03>>0] = $61;
  $62 = $60 >>> 8;
  $63 = $62&255;
  $64 = (($dest$03) + 1|0);
  HEAP8[$64>>0] = $63;
  $65 = $60 >>> 16;
  $66 = $65&255;
  $67 = (($dest$03) + 2|0);
  HEAP8[$67>>0] = $66;
  $68 = (($dest$03) + 3|0);
  $69 = HEAP32[$20>>2]|0;
  $70 = (($69) + ($u$05))|0;
  $71 = ($21|0)==(0);
  if ($71) {
   break;
  } else {
   $count$04 = $21;$dest$03 = $68;$u$05 = $70;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_3rgba_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$sum = 0, $$sum2 = 0, $$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $count$04 = 0, $dest$03 = 0, $u$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$04 = $3;$dest$03 = $5;$u$05 = $7;
 while(1) {
  $21 = (($count$04) + -1)|0;
  $22 = $u$05 >>> 16;
  $23 = ($22*3)|0;
  $24 = (($1) + ($23)|0);
  $$val = HEAP8[$24>>0]|0;
  $$sum = (($23) + 1)|0;
  $$idx = (($1) + ($$sum)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$sum2 = (($23) + 2)|0;
  $$idx1 = (($1) + ($$sum2)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $25 = $$val&255;
  $26 = $$idx$val&255;
  $27 = $26 << 8;
  $28 = $27 | $25;
  $29 = $$idx1$val&255;
  $30 = $29 << 16;
  $31 = $28 | $30;
  $32 = HEAP32[$8>>2]|0;
  $33 = $31 >>> $32;
  $34 = HEAP32[$blitter>>2]|0;
  $35 = $33 << $34;
  $36 = HEAP32[$9>>2]|0;
  $37 = $35 & $36;
  $38 = HEAP32[$10>>2]|0;
  $39 = $31 >>> $38;
  $40 = HEAP32[$11>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$12>>2]|0;
  $43 = $41 & $42;
  $44 = $43 | $37;
  $45 = HEAP32[$13>>2]|0;
  $46 = $31 >>> $45;
  $47 = HEAP32[$14>>2]|0;
  $48 = $46 << $47;
  $49 = HEAP32[$15>>2]|0;
  $50 = $48 & $49;
  $51 = $44 | $50;
  $52 = HEAP32[$16>>2]|0;
  $53 = $31 >>> $52;
  $54 = HEAP32[$17>>2]|0;
  $55 = $53 << $54;
  $56 = HEAP32[$18>>2]|0;
  $57 = $55 & $56;
  $58 = $51 | $57;
  $59 = HEAP32[$19>>2]|0;
  $60 = $58 | $59;
  $61 = (($dest$03) + 4|0);
  HEAP32[$dest$03>>2] = $60;
  $62 = HEAP32[$20>>2]|0;
  $63 = (($62) + ($u$05))|0;
  $64 = ($21|0)==(0);
  if ($64) {
   break;
  } else {
   $count$04 = $21;$dest$03 = $61;$u$05 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_4rgba_1rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0;
 var $dest$01$i = 0, $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02$i = $3;$dest$01$i = $6;$u$03$i = $7;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = $u$03$i >>> 16;
  $23 = (($1) + ($22<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$8>>2]|0;
  $26 = $24 >>> $25;
  $27 = HEAP32[$blitter>>2]|0;
  $28 = $26 << $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 & $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $24 >>> $31;
  $33 = HEAP32[$11>>2]|0;
  $34 = $32 << $33;
  $35 = HEAP32[$12>>2]|0;
  $36 = $34 & $35;
  $37 = $36 | $30;
  $38 = HEAP32[$13>>2]|0;
  $39 = $24 >>> $38;
  $40 = HEAP32[$14>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$15>>2]|0;
  $43 = $41 & $42;
  $44 = $37 | $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $24 >>> $45;
  $47 = HEAP32[$17>>2]|0;
  $48 = $46 << $47;
  $49 = HEAP32[$18>>2]|0;
  $50 = $48 & $49;
  $51 = $44 | $50;
  $52 = HEAP32[$19>>2]|0;
  $53 = $51 | $52;
  $54 = $53&255;
  HEAP8[$dest$01$i>>0] = $54;
  $55 = HEAP32[$20>>2]|0;
  $56 = (($55) + ($u$03$i))|0;
  $57 = (($dest$01$i) + 1|0);
  $58 = ($21|0)==(0);
  if ($58) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $57;$u$03$i = $56;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_4rgba_2rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0;
 var $dest$01$i = 0, $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$blitter>>2]|0;
 $11 = (($blitter) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($blitter) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($blitter) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($blitter) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($blitter) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($blitter) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($blitter) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($blitter) + 40|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($blitter) + 36|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($blitter) + 44|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($blitter) + 72|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($info) + 20|0);
 $34 = HEAP32[$33>>2]|0;
 $count$02$i = $3;$dest$01$i = $5;$u$03$i = $7;
 while(1) {
  $35 = (($count$02$i) + -1)|0;
  $36 = $u$03$i >>> 16;
  $37 = (($1) + ($36<<2)|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = $38 >>> $9;
  $40 = $39 << $10;
  $41 = $40 & $12;
  $42 = $38 >>> $14;
  $43 = $42 << $16;
  $44 = $43 & $18;
  $45 = $38 >>> $20;
  $46 = $45 << $22;
  $47 = $46 & $24;
  $48 = $38 >>> $26;
  $49 = $48 << $28;
  $50 = $49 & $30;
  $51 = $41 | $32;
  $52 = $51 | $44;
  $53 = $52 | $47;
  $54 = $53 | $50;
  $55 = $54&65535;
  HEAP16[$dest$01$i>>1] = $55;
  $56 = (($u$03$i) + ($34))|0;
  $57 = (($dest$01$i) + 2|0);
  $58 = ($35|0)==(0);
  if ($58) {
   break;
  } else {
   $count$02$i = $35;$dest$01$i = $57;$u$03$i = $56;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_4rgba_3rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02 = 0, $dest$01 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($info) + 16|0);
 $6 = HEAP32[$info>>2]|0;
 $7 = HEAP32[$5>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02 = $3;$dest$01 = $6;$u$03 = $7;
 while(1) {
  $21 = (($count$02) + -1)|0;
  $22 = $u$03 >>> 16;
  $23 = (($1) + ($22<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$8>>2]|0;
  $26 = $24 >>> $25;
  $27 = HEAP32[$blitter>>2]|0;
  $28 = $26 << $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 & $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $24 >>> $31;
  $33 = HEAP32[$11>>2]|0;
  $34 = $32 << $33;
  $35 = HEAP32[$12>>2]|0;
  $36 = $34 & $35;
  $37 = $36 | $30;
  $38 = HEAP32[$13>>2]|0;
  $39 = $24 >>> $38;
  $40 = HEAP32[$14>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$15>>2]|0;
  $43 = $41 & $42;
  $44 = $37 | $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $24 >>> $45;
  $47 = HEAP32[$17>>2]|0;
  $48 = $46 << $47;
  $49 = HEAP32[$18>>2]|0;
  $50 = $48 & $49;
  $51 = $44 | $50;
  $52 = HEAP32[$19>>2]|0;
  $53 = $51 | $52;
  $54 = $53&255;
  HEAP8[$dest$01>>0] = $54;
  $55 = $53 >>> 8;
  $56 = $55&255;
  $57 = (($dest$01) + 1|0);
  HEAP8[$57>>0] = $56;
  $58 = $53 >>> 16;
  $59 = $58&255;
  $60 = (($dest$01) + 2|0);
  HEAP8[$60>>0] = $59;
  $61 = (($dest$01) + 3|0);
  $62 = HEAP32[$20>>2]|0;
  $63 = (($62) + ($u$03))|0;
  $64 = ($21|0)==(0);
  if ($64) {
   break;
  } else {
   $count$02 = $21;$dest$01 = $61;$u$03 = $63;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_remap_4rgba_4rgbaP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$02$i = 0, $dest$01$i = 0;
 var $u$03$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$info>>2]|0;
 $6 = (($info) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($blitter) + 4|0);
 $9 = (($blitter) + 8|0);
 $10 = (($blitter) + 16|0);
 $11 = (($blitter) + 12|0);
 $12 = (($blitter) + 20|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 32|0);
 $16 = (($blitter) + 40|0);
 $17 = (($blitter) + 36|0);
 $18 = (($blitter) + 44|0);
 $19 = (($blitter) + 72|0);
 $20 = (($info) + 20|0);
 $count$02$i = $3;$dest$01$i = $5;$u$03$i = $7;
 while(1) {
  $21 = (($count$02$i) + -1)|0;
  $22 = $u$03$i >>> 16;
  $23 = (($1) + ($22<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = HEAP32[$8>>2]|0;
  $26 = $24 >>> $25;
  $27 = HEAP32[$blitter>>2]|0;
  $28 = $26 << $27;
  $29 = HEAP32[$9>>2]|0;
  $30 = $28 & $29;
  $31 = HEAP32[$10>>2]|0;
  $32 = $24 >>> $31;
  $33 = HEAP32[$11>>2]|0;
  $34 = $32 << $33;
  $35 = HEAP32[$12>>2]|0;
  $36 = $34 & $35;
  $37 = $36 | $30;
  $38 = HEAP32[$13>>2]|0;
  $39 = $24 >>> $38;
  $40 = HEAP32[$14>>2]|0;
  $41 = $39 << $40;
  $42 = HEAP32[$15>>2]|0;
  $43 = $41 & $42;
  $44 = $37 | $43;
  $45 = HEAP32[$16>>2]|0;
  $46 = $24 >>> $45;
  $47 = HEAP32[$17>>2]|0;
  $48 = $46 << $47;
  $49 = HEAP32[$18>>2]|0;
  $50 = $48 & $49;
  $51 = $44 | $50;
  $52 = HEAP32[$19>>2]|0;
  $53 = $51 | $52;
  HEAP32[$dest$01$i>>2] = $53;
  $54 = HEAP32[$20>>2]|0;
  $55 = (($54) + ($u$03$i))|0;
  $56 = (($dest$01$i) + 4|0);
  $57 = ($21|0)==(0);
  if ($57) {
   break;
  } else {
   $count$02$i = $21;$dest$01$i = $56;$u$03$i = $55;
  }
 }
 STACKTOP = sp;return;
}
function __ZL25inner_stretch_i8_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 8;
 $3 = (256 - ($2))|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($info) + 16|0);
 $12 = HEAP32[$info>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 $14 = (($info) + 20|0);
 $count$01 = $9;$dest$02 = $12;$u$03 = $13;
 while(1) {
  $15 = (($count$01) + -1)|0;
  $16 = $u$03 >>> 16;
  $17 = $u$03 >>> 8;
  $18 = $17 & 255;
  $19 = (256 - ($18))|0;
  $20 = (($5) + ($16)|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = $21&255;
  $23 = $22 << 16;
  $24 = (($7) + ($16)|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25&255;
  $27 = $23 | $26;
  $28 = (($16) + 1)|0;
  $29 = (($5) + ($28)|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = $31 << 16;
  $33 = (($7) + ($28)|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = $34&255;
  $36 = $32 | $35;
  $37 = Math_imul($27, $19)|0;
  $38 = Math_imul($36, $18)|0;
  $39 = (($38) + ($37))|0;
  $40 = $39 >>> 16;
  $41 = $40 & 65280;
  $42 = Math_imul($41, $3)|0;
  $43 = $39 & 65280;
  $44 = Math_imul($43, $2)|0;
  $45 = (($42) + ($44))|0;
  $46 = $45 >>> 16;
  $47 = $46&255;
  $48 = (($dest$02) + 1|0);
  HEAP8[$dest$02>>0] = $47;
  $49 = HEAP32[$14>>2]|0;
  $50 = (($49) + ($u$03))|0;
  $51 = ($15|0)==(0);
  if ($51) {
   break;
  } else {
   $count$01 = $15;$dest$02 = $48;$u$03 = $50;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_rgb565_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 11;
 $3 = (32 - ($2))|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$info>>2]|0;
 $12 = (($info) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($info) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $count$01 = $9;$dest$02 = $11;$u$03 = $13;
 while(1) {
  $16 = (($count$01) + -1)|0;
  $17 = $u$03 >>> 16;
  $18 = $u$03 >>> 11;
  $19 = $18 & 31;
  $20 = (32 - ($19))|0;
  $21 = (($5) + ($17<<1)|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22&65535;
  $24 = $23 << 16;
  $25 = (($7) + ($17<<1)|0);
  $26 = HEAP16[$25>>1]|0;
  $27 = $26&65535;
  $28 = $24 | $27;
  $29 = (($17) + 1)|0;
  $30 = (($5) + ($29<<1)|0);
  $31 = HEAP16[$30>>1]|0;
  $32 = $31&65535;
  $33 = $32 << 16;
  $34 = (($7) + ($29<<1)|0);
  $35 = HEAP16[$34>>1]|0;
  $36 = $35&65535;
  $37 = $33 | $36;
  $38 = $28 & 132184095;
  $39 = $37 & 132184095;
  $40 = $28 >>> 5;
  $41 = $40 & 130086975;
  $42 = $37 >>> 5;
  $43 = $42 & 130086975;
  $44 = Math_imul($41, $20)|0;
  $45 = Math_imul($43, $19)|0;
  $46 = (($45) + ($44))|0;
  $47 = Math_imul($38, $20)|0;
  $48 = Math_imul($39, $19)|0;
  $49 = (($48) + ($47))|0;
  $50 = $49 >>> 5;
  $51 = $46 >>> 16;
  $52 = $51 & 63519;
  $53 = Math_imul($52, $3)|0;
  $54 = $50 & 63519;
  $55 = Math_imul($54, $2)|0;
  $56 = (($53) + ($55))|0;
  $57 = $56 >>> 5;
  $58 = $57 & 63519;
  $59 = $49 >>> 21;
  $60 = $59 & 2016;
  $61 = Math_imul($60, $3)|0;
  $62 = $46 & 2016;
  $63 = Math_imul($62, $2)|0;
  $64 = (($61) + ($63))|0;
  $65 = $64 >>> 5;
  $66 = $65 & 2016;
  $67 = $58 | $66;
  $68 = $67&65535;
  $69 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $68;
  $70 = (($15) + ($u$03))|0;
  $71 = ($16|0)==(0);
  if ($71) {
   break;
  } else {
   $count$01 = $16;$dest$02 = $69;$u$03 = $70;
  }
 }
 STACKTOP = sp;return;
}
function __ZL29inner_stretch_rgb888_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx10 = 0, $$idx10$val = 0, $$idx3 = 0, $$idx3$val = 0, $$idx4 = 0, $$idx4$val = 0, $$idx6 = 0, $$idx6$val = 0, $$idx7 = 0, $$idx7$val = 0, $$idx9 = 0, $$idx9$val = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0;
 var $$val = 0, $$val2 = 0, $$val5 = 0, $$val8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $9 = 0, $count$021 = 0, $dest$022 = 0, $tmp = 0, $tmp18 = 0, $tmp19 = 0, $tmp20 = 0, $u$023 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 8;
 $3 = (256 - ($2))|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($info) + 16|0);
 $12 = HEAP32[$info>>2]|0;
 $13 = HEAP32[$11>>2]|0;
 $14 = (($info) + 20|0);
 $count$021 = $9;$dest$022 = $12;$u$023 = $13;
 while(1) {
  $15 = (($count$021) + -1)|0;
  $16 = $u$023 >>> 16;
  $17 = $u$023 >>> 8;
  $18 = $17 & 255;
  $19 = (256 - ($18))|0;
  $20 = ($16*3)|0;
  $21 = (($5) + ($20)|0);
  $$val8 = HEAP8[$21>>0]|0;
  $$sum = (($20) + 1)|0;
  $$idx9 = (($5) + ($$sum)|0);
  $$idx9$val = HEAP8[$$idx9>>0]|0;
  $$sum11 = (($20) + 2)|0;
  $$idx10 = (($5) + ($$sum11)|0);
  $$idx10$val = HEAP8[$$idx10>>0]|0;
  $22 = $$val8&255;
  $23 = $$idx9$val&255;
  $24 = $$idx10$val&255;
  $25 = $24 << 16;
  $26 = $25 | $22;
  $27 = (($20) + 3)|0;
  $28 = (($5) + ($27)|0);
  $$val5 = HEAP8[$28>>0]|0;
  $$sum12 = (($20) + 4)|0;
  $$idx6 = (($5) + ($$sum12)|0);
  $$idx6$val = HEAP8[$$idx6>>0]|0;
  $$sum13 = (($20) + 5)|0;
  $$idx7 = (($5) + ($$sum13)|0);
  $$idx7$val = HEAP8[$$idx7>>0]|0;
  $29 = $$val5&255;
  $30 = $$idx6$val&255;
  $31 = $$idx7$val&255;
  $32 = $31 << 16;
  $33 = $32 | $29;
  $34 = (($7) + ($20)|0);
  $$val2 = HEAP8[$34>>0]|0;
  $$idx3 = (($7) + ($$sum)|0);
  $$idx3$val = HEAP8[$$idx3>>0]|0;
  $$idx4 = (($7) + ($$sum11)|0);
  $$idx4$val = HEAP8[$$idx4>>0]|0;
  $35 = $$val2&255;
  $36 = $$idx3$val&255;
  $37 = $$idx4$val&255;
  $38 = $37 << 16;
  $39 = $38 | $35;
  $40 = (($7) + ($27)|0);
  $$val = HEAP8[$40>>0]|0;
  $$idx = (($7) + ($$sum12)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$idx1 = (($7) + ($$sum13)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $41 = $$val&255;
  $42 = $$idx$val&255;
  $43 = $$idx1$val&255;
  $44 = $43 << 16;
  $45 = $44 | $41;
  $46 = Math_imul($23, $19)|0;
  $47 = Math_imul($30, $18)|0;
  $tmp = (($47) + ($46))|0;
  $tmp18 = $tmp << 8;
  $48 = $tmp18 & 16711680;
  $49 = Math_imul($36, $19)|0;
  $50 = Math_imul($42, $18)|0;
  $tmp19 = (($50) + ($49))|0;
  $tmp20 = $tmp19 << 8;
  $51 = $tmp20 & 16711680;
  $52 = Math_imul($26, $19)|0;
  $53 = Math_imul($33, $18)|0;
  $54 = (($53) + ($52))|0;
  $55 = $54 >>> 8;
  $56 = $55 & 16711935;
  $57 = Math_imul($39, $19)|0;
  $58 = Math_imul($45, $18)|0;
  $59 = (($58) + ($57))|0;
  $60 = $59 >>> 8;
  $61 = $60 & 16711935;
  $62 = Math_imul($48, $3)|0;
  $63 = Math_imul($51, $2)|0;
  $64 = (($63) + ($62))|0;
  $65 = $64 >>> 24;
  $66 = Math_imul($56, $3)|0;
  $67 = Math_imul($61, $2)|0;
  $68 = (($67) + ($66))|0;
  $69 = $68 >>> 8;
  $70 = $69&255;
  HEAP8[$dest$022>>0] = $70;
  $71 = $65&255;
  $72 = (($dest$022) + 1|0);
  HEAP8[$72>>0] = $71;
  $73 = $68 >>> 24;
  $74 = $73&255;
  $75 = (($dest$022) + 2|0);
  HEAP8[$75>>0] = $74;
  $76 = (($dest$022) + 3|0);
  $77 = HEAP32[$14>>2]|0;
  $78 = (($77) + ($u$023))|0;
  $79 = ($15|0)==(0);
  if ($79) {
   break;
  } else {
   $count$021 = $15;$dest$022 = $76;$u$023 = $78;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_argb1555_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 11;
 $3 = (32 - ($2))|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$info>>2]|0;
 $12 = (($info) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($info) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $count$01 = $9;$dest$02 = $11;$u$03 = $13;
 while(1) {
  $16 = (($count$01) + -1)|0;
  $17 = $u$03 >>> 16;
  $18 = $u$03 >>> 11;
  $19 = $18 & 31;
  $20 = (32 - ($19))|0;
  $21 = (($5) + ($17<<1)|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22&65535;
  $24 = $23 << 16;
  $25 = (($7) + ($17<<1)|0);
  $26 = HEAP16[$25>>1]|0;
  $27 = $26&65535;
  $28 = $24 | $27;
  $29 = (($17) + 1)|0;
  $30 = (($5) + ($29<<1)|0);
  $31 = HEAP16[$30>>1]|0;
  $32 = $31&65535;
  $33 = $32 << 16;
  $34 = (($7) + ($29<<1)|0);
  $35 = HEAP16[$34>>1]|0;
  $36 = $35&65535;
  $37 = $33 | $36;
  $38 = $23 & 32768;
  $39 = $28 & 65043487;
  $40 = $37 & 65043487;
  $41 = $28 >>> 5;
  $42 = $41 & 65075231;
  $43 = $37 >>> 5;
  $44 = $43 & 65075231;
  $45 = Math_imul($42, $20)|0;
  $46 = Math_imul($44, $19)|0;
  $47 = (($46) + ($45))|0;
  $48 = Math_imul($39, $20)|0;
  $49 = Math_imul($40, $19)|0;
  $50 = (($49) + ($48))|0;
  $51 = $50 >>> 5;
  $52 = $47 >>> 16;
  $53 = $52 & 31775;
  $54 = Math_imul($53, $3)|0;
  $55 = $51 & 31775;
  $56 = Math_imul($55, $2)|0;
  $57 = (($54) + ($56))|0;
  $58 = $57 >>> 5;
  $59 = $58 & 31775;
  $60 = $50 >>> 21;
  $61 = $60 & 992;
  $62 = Math_imul($61, $3)|0;
  $63 = $47 & 992;
  $64 = Math_imul($63, $2)|0;
  $65 = (($62) + ($64))|0;
  $66 = $65 >>> 5;
  $67 = $66 & 992;
  $68 = $67 | $38;
  $69 = $68 | $59;
  $70 = $69&65535;
  $71 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $70;
  $72 = (($15) + ($u$03))|0;
  $73 = ($16|0)==(0);
  if ($73) {
   break;
  } else {
   $count$01 = $16;$dest$02 = $71;$u$03 = $72;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_argb4444_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 12;
 $3 = (16 - ($2))|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$info>>2]|0;
 $12 = (($info) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($info) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $count$01 = $9;$dest$02 = $11;$u$03 = $13;
 while(1) {
  $16 = (($count$01) + -1)|0;
  $17 = $u$03 >>> 16;
  $18 = $u$03 >>> 12;
  $19 = $18 & 15;
  $20 = (16 - ($19))|0;
  $21 = (($5) + ($17<<1)|0);
  $22 = HEAP16[$21>>1]|0;
  $23 = $22&65535;
  $24 = $23 << 16;
  $25 = (($7) + ($17<<1)|0);
  $26 = HEAP16[$25>>1]|0;
  $27 = $26&65535;
  $28 = $24 | $27;
  $29 = (($17) + 1)|0;
  $30 = (($5) + ($29<<1)|0);
  $31 = HEAP16[$30>>1]|0;
  $32 = $31&65535;
  $33 = $32 << 16;
  $34 = (($7) + ($29<<1)|0);
  $35 = HEAP16[$34>>1]|0;
  $36 = $35&65535;
  $37 = $33 | $36;
  $38 = $28 & 252645135;
  $39 = $37 & 252645135;
  $40 = $28 >>> 4;
  $41 = $40 & 252645135;
  $42 = $37 >>> 4;
  $43 = $42 & 252645135;
  $44 = Math_imul($41, $20)|0;
  $45 = Math_imul($43, $19)|0;
  $46 = (($45) + ($44))|0;
  $47 = $46 >>> 4;
  $48 = Math_imul($38, $20)|0;
  $49 = Math_imul($39, $19)|0;
  $50 = (($49) + ($48))|0;
  $51 = $50 >>> 4;
  $52 = $46 >>> 20;
  $53 = $52 & 3855;
  $54 = Math_imul($53, $3)|0;
  $55 = $47 & 3855;
  $56 = Math_imul($55, $2)|0;
  $57 = (($54) + ($56))|0;
  $58 = $57 & 61680;
  $59 = $50 >>> 20;
  $60 = $59 & 3855;
  $61 = Math_imul($60, $3)|0;
  $62 = $51 & 3855;
  $63 = Math_imul($62, $2)|0;
  $64 = (($61) + ($63))|0;
  $65 = $64 >>> 4;
  $66 = $65 & 3855;
  $67 = $58 | $66;
  $68 = $67&65535;
  $69 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $68;
  $70 = (($15) + ($u$03))|0;
  $71 = ($16|0)==(0);
  if ($71) {
   break;
  } else {
   $count$01 = $16;$dest$02 = $69;$u$03 = $70;
  }
 }
 STACKTOP = sp;return;
}
function __ZL31inner_stretch_argb8888_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >>> 8;
 $3 = (256 - ($2))|0;
 $4 = (($info) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($info) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($info) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = HEAP32[$info>>2]|0;
 $12 = (($info) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($info) + 20|0);
 $count$01 = $9;$dest$02 = $11;$u$03 = $13;
 while(1) {
  $15 = (($count$01) + -1)|0;
  $16 = $u$03 >>> 16;
  $17 = $u$03 >>> 8;
  $18 = $17 & 255;
  $19 = (256 - ($18))|0;
  $20 = (($5) + ($16<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($16) + 1)|0;
  $23 = (($5) + ($22<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($7) + ($16<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($7) + ($22<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = $21 & 16711935;
  $30 = $24 & 16711935;
  $31 = $26 & 16711935;
  $32 = $28 & 16711935;
  $33 = $21 >>> 8;
  $34 = $33 & 16711935;
  $35 = $24 >>> 8;
  $36 = $35 & 16711935;
  $37 = $26 >>> 8;
  $38 = $37 & 16711935;
  $39 = $28 >>> 8;
  $40 = $39 & 16711935;
  $41 = Math_imul($34, $19)|0;
  $42 = Math_imul($36, $18)|0;
  $43 = (($42) + ($41))|0;
  $44 = $43 >>> 8;
  $45 = $44 & 16711935;
  $46 = Math_imul($38, $19)|0;
  $47 = Math_imul($40, $18)|0;
  $48 = (($47) + ($46))|0;
  $49 = $48 >>> 8;
  $50 = $49 & 16711935;
  $51 = Math_imul($29, $19)|0;
  $52 = Math_imul($30, $18)|0;
  $53 = (($52) + ($51))|0;
  $54 = $53 >>> 8;
  $55 = $54 & 16711935;
  $56 = Math_imul($31, $19)|0;
  $57 = Math_imul($32, $18)|0;
  $58 = (($57) + ($56))|0;
  $59 = $58 >>> 8;
  $60 = $59 & 16711935;
  $61 = Math_imul($45, $3)|0;
  $62 = Math_imul($50, $2)|0;
  $63 = (($62) + ($61))|0;
  $64 = $63 & -16711936;
  $65 = Math_imul($55, $3)|0;
  $66 = Math_imul($60, $2)|0;
  $67 = (($66) + ($65))|0;
  $68 = $67 >>> 8;
  $69 = $68 & 16711935;
  $70 = $64 | $69;
  $71 = (($dest$02) + 4|0);
  HEAP32[$dest$02>>2] = $70;
  $72 = HEAP32[$14>>2]|0;
  $73 = (($72) + ($u$03))|0;
  $74 = ($15|0)==(0);
  if ($74) {
   break;
  } else {
   $count$01 = $15;$dest$02 = $71;$u$03 = $73;
  }
 }
 STACKTOP = sp;return;
}
function __ZL26inner_stretch_1ia_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($blitter) + 64|0);
 $11 = (($blitter) + 60|0);
 $12 = (($blitter) + 40|0);
 $13 = (($blitter) + 36|0);
 $14 = (($info) + 24|0);
 $15 = (($blitter) + 68|0);
 $16 = (($blitter) + 44|0);
 $17 = (($info) + 20|0);
 $count$01 = $5;$dest$02 = $8;$u$03 = $9;
 while(1) {
  $18 = (($count$01) + -1)|0;
  $19 = $u$03 >>> 16;
  $20 = $u$03 & 65535;
  $21 = (65536 - ($20))|0;
  $22 = (($1) + ($19)|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23&255;
  $25 = HEAP32[$10>>2]|0;
  $26 = $24 >>> $25;
  $27 = HEAP32[$11>>2]|0;
  $28 = $26 << $27;
  $29 = $28 & 255;
  $30 = Math_imul($29, $21)|0;
  $31 = (($19) + 1)|0;
  $32 = (($1) + ($31)|0);
  $33 = HEAP8[$32>>0]|0;
  $34 = $33&255;
  $35 = $34 >>> $25;
  $36 = $35 << $27;
  $37 = $36 & 255;
  $38 = Math_imul($37, $20)|0;
  $39 = (($38) + ($30))|0;
  $40 = $39 >>> 16;
  $41 = (($3) + ($19)|0);
  $42 = HEAP8[$41>>0]|0;
  $43 = $42&255;
  $44 = $43 >>> $25;
  $45 = $44 << $27;
  $46 = $45 & 255;
  $47 = Math_imul($46, $21)|0;
  $48 = (($3) + ($31)|0);
  $49 = HEAP8[$48>>0]|0;
  $50 = $49&255;
  $51 = $50 >>> $25;
  $52 = $51 << $27;
  $53 = $52 & 255;
  $54 = Math_imul($53, $20)|0;
  $55 = (($54) + ($47))|0;
  $56 = $55 >>> 16;
  $57 = HEAP32[$12>>2]|0;
  $58 = $24 >>> $57;
  $59 = HEAP32[$13>>2]|0;
  $60 = $58 << $59;
  $61 = $60 & 255;
  $62 = Math_imul($61, $21)|0;
  $63 = $34 >>> $57;
  $64 = $63 << $59;
  $65 = $64 & 255;
  $66 = Math_imul($65, $20)|0;
  $67 = (($62) + ($66))|0;
  $68 = $67 >>> 16;
  $69 = $43 >>> $57;
  $70 = $69 << $59;
  $71 = $70 & 255;
  $72 = Math_imul($71, $21)|0;
  $73 = $50 >>> $57;
  $74 = $73 << $59;
  $75 = $74 & 255;
  $76 = Math_imul($75, $20)|0;
  $77 = (($72) + ($76))|0;
  $78 = $77 >>> 16;
  $79 = HEAP32[$14>>2]|0;
  $80 = (65536 - ($79))|0;
  $81 = Math_imul($40, $80)|0;
  $82 = Math_imul($56, $79)|0;
  $83 = (($82) + ($81))|0;
  $84 = $83 >>> 16;
  $85 = $84 >>> $27;
  $86 = $85 << $25;
  $87 = HEAP32[$15>>2]|0;
  $88 = $86 & $87;
  $89 = Math_imul($68, $80)|0;
  $90 = Math_imul($78, $79)|0;
  $91 = (($89) + ($90))|0;
  $92 = $91 >>> 16;
  $93 = $92 >>> $59;
  $94 = $93 << $57;
  $95 = HEAP32[$16>>2]|0;
  $96 = $94 & $95;
  $97 = $88 | $96;
  $98 = $97&255;
  $99 = (($dest$02) + 1|0);
  HEAP8[$dest$02>>0] = $98;
  $100 = HEAP32[$17>>2]|0;
  $101 = (($100) + ($u$03))|0;
  $102 = ($18|0)==(0);
  if ($102) {
   break;
  } else {
   $count$01 = $18;$dest$02 = $99;$u$03 = $101;
  }
 }
 STACKTOP = sp;return;
}
function __ZL26inner_stretch_2ia_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($blitter) + 64|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($blitter) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($blitter) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($blitter) + 36|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($info) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (65536 - ($19))|0;
 $21 = (($blitter) + 68|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($blitter) + 44|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($info) + 20|0);
 $26 = HEAP32[$25>>2]|0;
 $count$01 = $5;$dest$02 = $7;$u$03 = $9;
 while(1) {
  $27 = (($count$01) + -1)|0;
  $28 = $u$03 >>> 16;
  $29 = $u$03 & 65535;
  $30 = (65536 - ($29))|0;
  $31 = (($1) + ($28<<1)|0);
  $32 = HEAP16[$31>>1]|0;
  $33 = $32&65535;
  $34 = $33 >>> $11;
  $35 = $34 << $13;
  $36 = $35 & 255;
  $37 = Math_imul($36, $30)|0;
  $38 = (($28) + 1)|0;
  $39 = (($1) + ($38<<1)|0);
  $40 = HEAP16[$39>>1]|0;
  $41 = $40&65535;
  $42 = $41 >>> $11;
  $43 = $42 << $13;
  $44 = $43 & 255;
  $45 = Math_imul($44, $29)|0;
  $46 = (($45) + ($37))|0;
  $47 = $46 >>> 16;
  $48 = (($3) + ($28<<1)|0);
  $49 = HEAP16[$48>>1]|0;
  $50 = $49&65535;
  $51 = $50 >>> $11;
  $52 = $51 << $13;
  $53 = $52 & 255;
  $54 = Math_imul($53, $30)|0;
  $55 = (($3) + ($38<<1)|0);
  $56 = HEAP16[$55>>1]|0;
  $57 = $56&65535;
  $58 = $57 >>> $11;
  $59 = $58 << $13;
  $60 = $59 & 255;
  $61 = Math_imul($60, $29)|0;
  $62 = (($61) + ($54))|0;
  $63 = $62 >>> 16;
  $64 = $33 >>> $15;
  $65 = $64 << $17;
  $66 = $65 & 255;
  $67 = Math_imul($66, $30)|0;
  $68 = $41 >>> $15;
  $69 = $68 << $17;
  $70 = $69 & 255;
  $71 = Math_imul($70, $29)|0;
  $72 = (($67) + ($71))|0;
  $73 = $72 >>> 16;
  $74 = $50 >>> $15;
  $75 = $74 << $17;
  $76 = $75 & 255;
  $77 = Math_imul($76, $30)|0;
  $78 = $57 >>> $15;
  $79 = $78 << $17;
  $80 = $79 & 255;
  $81 = Math_imul($80, $29)|0;
  $82 = (($77) + ($81))|0;
  $83 = $82 >>> 16;
  $84 = Math_imul($47, $20)|0;
  $85 = Math_imul($63, $19)|0;
  $86 = (($85) + ($84))|0;
  $87 = $86 >>> 16;
  $88 = $87 >>> $13;
  $89 = $88 << $11;
  $90 = $89 & $22;
  $91 = Math_imul($73, $20)|0;
  $92 = Math_imul($83, $19)|0;
  $93 = (($91) + ($92))|0;
  $94 = $93 >>> 16;
  $95 = $94 >>> $17;
  $96 = $95 << $15;
  $97 = $96 & $24;
  $98 = $90 | $97;
  $99 = $98&65535;
  $100 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $99;
  $101 = (($26) + ($u$03))|0;
  $102 = ($27|0)==(0);
  if ($102) {
   break;
  } else {
   $count$01 = $27;$dest$02 = $100;$u$03 = $101;
  }
 }
 STACKTOP = sp;return;
}
function __ZL26inner_stretch_3ia_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx10 = 0, $$idx10$val = 0, $$idx3 = 0, $$idx3$val = 0, $$idx4 = 0, $$idx4$val = 0, $$idx6 = 0, $$idx6$val = 0, $$idx7 = 0, $$idx7$val = 0, $$idx9 = 0, $$idx9$val = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0;
 var $$val = 0, $$val2 = 0, $$val5 = 0, $$val8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$018 = 0, $dest$019 = 0, $u$020 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($blitter) + 64|0);
 $11 = (($blitter) + 60|0);
 $12 = (($blitter) + 40|0);
 $13 = (($blitter) + 36|0);
 $14 = (($info) + 24|0);
 $15 = (($blitter) + 68|0);
 $16 = (($blitter) + 44|0);
 $17 = (($info) + 20|0);
 $count$018 = $5;$dest$019 = $8;$u$020 = $9;
 while(1) {
  $18 = (($count$018) + -1)|0;
  $19 = $u$020 >>> 16;
  $20 = $u$020 & 65535;
  $21 = ($19*3)|0;
  $22 = (($1) + ($21)|0);
  $$val8 = HEAP8[$22>>0]|0;
  $$sum = (($21) + 1)|0;
  $$idx9 = (($1) + ($$sum)|0);
  $$idx9$val = HEAP8[$$idx9>>0]|0;
  $$sum11 = (($21) + 2)|0;
  $$idx10 = (($1) + ($$sum11)|0);
  $$idx10$val = HEAP8[$$idx10>>0]|0;
  $23 = $$val8&255;
  $24 = $$idx9$val&255;
  $25 = $24 << 8;
  $26 = $25 | $23;
  $27 = $$idx10$val&255;
  $28 = $27 << 16;
  $29 = $26 | $28;
  $30 = (($21) + 3)|0;
  $31 = (($1) + ($30)|0);
  $$val5 = HEAP8[$31>>0]|0;
  $$sum12 = (($21) + 4)|0;
  $$idx6 = (($1) + ($$sum12)|0);
  $$idx6$val = HEAP8[$$idx6>>0]|0;
  $$sum13 = (($21) + 5)|0;
  $$idx7 = (($1) + ($$sum13)|0);
  $$idx7$val = HEAP8[$$idx7>>0]|0;
  $32 = $$val5&255;
  $33 = $$idx6$val&255;
  $34 = $33 << 8;
  $35 = $34 | $32;
  $36 = $$idx7$val&255;
  $37 = $36 << 16;
  $38 = $35 | $37;
  $39 = (($3) + ($21)|0);
  $$val2 = HEAP8[$39>>0]|0;
  $$idx3 = (($3) + ($$sum)|0);
  $$idx3$val = HEAP8[$$idx3>>0]|0;
  $$idx4 = (($3) + ($$sum11)|0);
  $$idx4$val = HEAP8[$$idx4>>0]|0;
  $40 = $$val2&255;
  $41 = $$idx3$val&255;
  $42 = $41 << 8;
  $43 = $42 | $40;
  $44 = $$idx4$val&255;
  $45 = $44 << 16;
  $46 = $43 | $45;
  $47 = (($3) + ($30)|0);
  $$val = HEAP8[$47>>0]|0;
  $$idx = (($3) + ($$sum12)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$idx1 = (($3) + ($$sum13)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $48 = $$val&255;
  $49 = $$idx$val&255;
  $50 = $49 << 8;
  $51 = $50 | $48;
  $52 = $$idx1$val&255;
  $53 = $52 << 16;
  $54 = $51 | $53;
  $55 = (65536 - ($20))|0;
  $56 = HEAP32[$10>>2]|0;
  $57 = $29 >>> $56;
  $58 = HEAP32[$11>>2]|0;
  $59 = $57 << $58;
  $60 = $59 & 255;
  $61 = Math_imul($60, $55)|0;
  $62 = $38 >>> $56;
  $63 = $62 << $58;
  $64 = $63 & 255;
  $65 = Math_imul($64, $20)|0;
  $66 = (($61) + ($65))|0;
  $67 = $66 >>> 16;
  $68 = $46 >>> $56;
  $69 = $68 << $58;
  $70 = $69 & 255;
  $71 = Math_imul($70, $55)|0;
  $72 = $54 >>> $56;
  $73 = $72 << $58;
  $74 = $73 & 255;
  $75 = Math_imul($74, $20)|0;
  $76 = (($75) + ($71))|0;
  $77 = $76 >>> 16;
  $78 = HEAP32[$12>>2]|0;
  $79 = $29 >>> $78;
  $80 = HEAP32[$13>>2]|0;
  $81 = $79 << $80;
  $82 = $81 & 255;
  $83 = Math_imul($82, $55)|0;
  $84 = $38 >>> $78;
  $85 = $84 << $80;
  $86 = $85 & 255;
  $87 = Math_imul($86, $20)|0;
  $88 = (($83) + ($87))|0;
  $89 = $88 >>> 16;
  $90 = $46 >>> $78;
  $91 = $90 << $80;
  $92 = $91 & 255;
  $93 = Math_imul($92, $55)|0;
  $94 = $54 >>> $78;
  $95 = $94 << $80;
  $96 = $95 & 255;
  $97 = Math_imul($96, $20)|0;
  $98 = (($93) + ($97))|0;
  $99 = $98 >>> 16;
  $100 = HEAP32[$14>>2]|0;
  $101 = (65536 - ($100))|0;
  $102 = Math_imul($67, $101)|0;
  $103 = Math_imul($77, $100)|0;
  $104 = (($103) + ($102))|0;
  $105 = $104 >>> 16;
  $106 = $105 >>> $58;
  $107 = $106 << $56;
  $108 = HEAP32[$15>>2]|0;
  $109 = $107 & $108;
  $110 = Math_imul($89, $101)|0;
  $111 = Math_imul($99, $100)|0;
  $112 = (($110) + ($111))|0;
  $113 = $112 >>> 16;
  $114 = $113 >>> $80;
  $115 = $114 << $78;
  $116 = HEAP32[$16>>2]|0;
  $117 = $115 & $116;
  $118 = $109 | $117;
  $119 = $118&255;
  HEAP8[$dest$019>>0] = $119;
  $120 = $118 >>> 8;
  $121 = $120&255;
  $122 = (($dest$019) + 1|0);
  HEAP8[$122>>0] = $121;
  $123 = $118 >>> 16;
  $124 = $123&255;
  $125 = (($dest$019) + 2|0);
  HEAP8[$125>>0] = $124;
  $126 = (($dest$019) + 3|0);
  $127 = HEAP32[$17>>2]|0;
  $128 = (($127) + ($u$020))|0;
  $129 = ($18|0)==(0);
  if ($129) {
   break;
  } else {
   $count$018 = $18;$dest$019 = $126;$u$020 = $128;
  }
 }
 STACKTOP = sp;return;
}
function __ZL26inner_stretch_4ia_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $count$01 = 0, $dest$02 = 0;
 var $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($blitter) + 64|0);
 $11 = (($blitter) + 60|0);
 $12 = (($blitter) + 40|0);
 $13 = (($blitter) + 36|0);
 $14 = (($info) + 24|0);
 $15 = (($blitter) + 68|0);
 $16 = (($blitter) + 44|0);
 $17 = (($info) + 20|0);
 $count$01 = $5;$dest$02 = $7;$u$03 = $9;
 while(1) {
  $18 = (($count$01) + -1)|0;
  $19 = $u$03 >>> 16;
  $20 = $u$03 & 65535;
  $21 = (65536 - ($20))|0;
  $22 = (($1) + ($19<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$10>>2]|0;
  $25 = $23 >>> $24;
  $26 = HEAP32[$11>>2]|0;
  $27 = $25 << $26;
  $28 = $27 & 255;
  $29 = Math_imul($28, $21)|0;
  $30 = (($19) + 1)|0;
  $31 = (($1) + ($30<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = $32 >>> $24;
  $34 = $33 << $26;
  $35 = $34 & 255;
  $36 = Math_imul($35, $20)|0;
  $37 = (($36) + ($29))|0;
  $38 = $37 >>> 16;
  $39 = (($3) + ($19<<2)|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 >>> $24;
  $42 = $41 << $26;
  $43 = $42 & 255;
  $44 = Math_imul($43, $21)|0;
  $45 = (($3) + ($30<<2)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46 >>> $24;
  $48 = $47 << $26;
  $49 = $48 & 255;
  $50 = Math_imul($49, $20)|0;
  $51 = (($50) + ($44))|0;
  $52 = $51 >>> 16;
  $53 = HEAP32[$12>>2]|0;
  $54 = $23 >>> $53;
  $55 = HEAP32[$13>>2]|0;
  $56 = $54 << $55;
  $57 = $56 & 255;
  $58 = Math_imul($57, $21)|0;
  $59 = $32 >>> $53;
  $60 = $59 << $55;
  $61 = $60 & 255;
  $62 = Math_imul($61, $20)|0;
  $63 = (($58) + ($62))|0;
  $64 = $63 >>> 16;
  $65 = $40 >>> $53;
  $66 = $65 << $55;
  $67 = $66 & 255;
  $68 = Math_imul($67, $21)|0;
  $69 = $46 >>> $53;
  $70 = $69 << $55;
  $71 = $70 & 255;
  $72 = Math_imul($71, $20)|0;
  $73 = (($68) + ($72))|0;
  $74 = $73 >>> 16;
  $75 = HEAP32[$14>>2]|0;
  $76 = (65536 - ($75))|0;
  $77 = Math_imul($76, $38)|0;
  $78 = Math_imul($52, $75)|0;
  $79 = (($78) + ($77))|0;
  $80 = $79 >>> 16;
  $81 = $80 >>> $26;
  $82 = $81 << $24;
  $83 = HEAP32[$15>>2]|0;
  $84 = $82 & $83;
  $85 = Math_imul($64, $76)|0;
  $86 = Math_imul($74, $75)|0;
  $87 = (($85) + ($86))|0;
  $88 = $87 >>> 16;
  $89 = $88 >>> $55;
  $90 = $89 << $53;
  $91 = HEAP32[$16>>2]|0;
  $92 = $90 & $91;
  $93 = $92 | $84;
  $94 = (($dest$02) + 4|0);
  HEAP32[$dest$02>>2] = $93;
  $95 = HEAP32[$17>>2]|0;
  $96 = (($95) + ($u$03))|0;
  $97 = ($18|0)==(0);
  if ($97) {
   break;
  } else {
   $count$01 = $18;$dest$02 = $94;$u$03 = $96;
  }
 }
 STACKTOP = sp;return;
}
function __ZL28inner_stretch_1rgba_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($blitter) + 4|0);
 $11 = (($blitter) + 16|0);
 $12 = (($blitter) + 12|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 40|0);
 $16 = (($blitter) + 36|0);
 $17 = (($info) + 24|0);
 $18 = (($blitter) + 8|0);
 $19 = (($blitter) + 20|0);
 $20 = (($blitter) + 32|0);
 $21 = (($blitter) + 44|0);
 $22 = (($info) + 20|0);
 $count$01 = $5;$dest$02 = $8;$u$03 = $9;
 while(1) {
  $23 = (($count$01) + -1)|0;
  $24 = $u$03 >>> 16;
  $25 = $u$03 & 65535;
  $26 = (($1) + ($24)|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = $27&255;
  $29 = (($24) + 1)|0;
  $30 = (($1) + ($29)|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31&255;
  $33 = (($3) + ($24)|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = $34&255;
  $36 = (($3) + ($29)|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = $37&255;
  $39 = (65536 - ($25))|0;
  $40 = HEAP32[$10>>2]|0;
  $41 = $28 >>> $40;
  $42 = HEAP32[$blitter>>2]|0;
  $43 = $41 << $42;
  $44 = $43 & 255;
  $45 = Math_imul($44, $39)|0;
  $46 = $32 >>> $40;
  $47 = $46 << $42;
  $48 = $47 & 255;
  $49 = Math_imul($48, $25)|0;
  $50 = (($45) + ($49))|0;
  $51 = $50 >>> 16;
  $52 = $35 >>> $40;
  $53 = $52 << $42;
  $54 = $53 & 255;
  $55 = Math_imul($54, $39)|0;
  $56 = $38 >>> $40;
  $57 = $56 << $42;
  $58 = $57 & 255;
  $59 = Math_imul($58, $25)|0;
  $60 = (($55) + ($59))|0;
  $61 = $60 >>> 16;
  $62 = HEAP32[$11>>2]|0;
  $63 = $28 >>> $62;
  $64 = HEAP32[$12>>2]|0;
  $65 = $63 << $64;
  $66 = $65 & 255;
  $67 = Math_imul($66, $39)|0;
  $68 = $32 >>> $62;
  $69 = $68 << $64;
  $70 = $69 & 255;
  $71 = Math_imul($70, $25)|0;
  $72 = (($67) + ($71))|0;
  $73 = $72 >>> 16;
  $74 = $35 >>> $62;
  $75 = $74 << $64;
  $76 = $75 & 255;
  $77 = Math_imul($76, $39)|0;
  $78 = $38 >>> $62;
  $79 = $78 << $64;
  $80 = $79 & 255;
  $81 = Math_imul($80, $25)|0;
  $82 = (($77) + ($81))|0;
  $83 = $82 >>> 16;
  $84 = HEAP32[$13>>2]|0;
  $85 = $28 >>> $84;
  $86 = HEAP32[$14>>2]|0;
  $87 = $85 << $86;
  $88 = $87 & 255;
  $89 = Math_imul($88, $39)|0;
  $90 = $32 >>> $84;
  $91 = $90 << $86;
  $92 = $91 & 255;
  $93 = Math_imul($92, $25)|0;
  $94 = (($89) + ($93))|0;
  $95 = $94 >>> 16;
  $96 = $35 >>> $84;
  $97 = $96 << $86;
  $98 = $97 & 255;
  $99 = Math_imul($98, $39)|0;
  $100 = $38 >>> $84;
  $101 = $100 << $86;
  $102 = $101 & 255;
  $103 = Math_imul($102, $25)|0;
  $104 = (($99) + ($103))|0;
  $105 = $104 >>> 16;
  $106 = HEAP32[$15>>2]|0;
  $107 = $28 >>> $106;
  $108 = HEAP32[$16>>2]|0;
  $109 = $107 << $108;
  $110 = $109 & 255;
  $111 = Math_imul($110, $39)|0;
  $112 = $32 >>> $106;
  $113 = $112 << $108;
  $114 = $113 & 255;
  $115 = Math_imul($114, $25)|0;
  $116 = (($111) + ($115))|0;
  $117 = $116 >>> 16;
  $118 = $35 >>> $106;
  $119 = $118 << $108;
  $120 = $119 & 255;
  $121 = Math_imul($120, $39)|0;
  $122 = $38 >>> $106;
  $123 = $122 << $108;
  $124 = $123 & 255;
  $125 = Math_imul($124, $25)|0;
  $126 = (($121) + ($125))|0;
  $127 = $126 >>> 16;
  $128 = HEAP32[$17>>2]|0;
  $129 = (65536 - ($128))|0;
  $130 = Math_imul($129, $51)|0;
  $131 = Math_imul($128, $61)|0;
  $132 = (($130) + ($131))|0;
  $133 = $132 >>> 16;
  $134 = $133 >>> $42;
  $135 = $134 << $40;
  $136 = HEAP32[$18>>2]|0;
  $137 = $135 & $136;
  $138 = Math_imul($129, $73)|0;
  $139 = Math_imul($128, $83)|0;
  $140 = (($138) + ($139))|0;
  $141 = $140 >>> 16;
  $142 = $141 >>> $64;
  $143 = $142 << $62;
  $144 = HEAP32[$19>>2]|0;
  $145 = $143 & $144;
  $146 = $137 | $145;
  $147 = Math_imul($95, $129)|0;
  $148 = Math_imul($105, $128)|0;
  $149 = (($147) + ($148))|0;
  $150 = $149 >>> 16;
  $151 = $150 >>> $86;
  $152 = $151 << $84;
  $153 = HEAP32[$20>>2]|0;
  $154 = $152 & $153;
  $155 = $146 | $154;
  $156 = Math_imul($117, $129)|0;
  $157 = Math_imul($127, $128)|0;
  $158 = (($156) + ($157))|0;
  $159 = $158 >>> 16;
  $160 = $159 >>> $108;
  $161 = $160 << $106;
  $162 = HEAP32[$21>>2]|0;
  $163 = $161 & $162;
  $164 = $155 | $163;
  $165 = $164&255;
  $166 = (($dest$02) + 1|0);
  HEAP8[$dest$02>>0] = $165;
  $167 = HEAP32[$22>>2]|0;
  $168 = (($167) + ($u$03))|0;
  $169 = ($23|0)==(0);
  if ($169) {
   break;
  } else {
   $count$01 = $23;$dest$02 = $166;$u$03 = $168;
  }
 }
 STACKTOP = sp;return;
}
function __ZL28inner_stretch_2rgba_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($blitter) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$blitter>>2]|0;
 $13 = (($blitter) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($blitter) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($blitter) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($blitter) + 24|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($blitter) + 40|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($blitter) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($info) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (65536 - ($26))|0;
 $28 = (($blitter) + 8|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($blitter) + 20|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($blitter) + 32|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($blitter) + 44|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($info) + 20|0);
 $37 = HEAP32[$36>>2]|0;
 $count$01 = $5;$dest$02 = $7;$u$03 = $9;
 while(1) {
  $38 = (($count$01) + -1)|0;
  $39 = $u$03 >>> 16;
  $40 = $u$03 & 65535;
  $41 = (($1) + ($39<<1)|0);
  $42 = HEAP16[$41>>1]|0;
  $43 = $42&65535;
  $44 = (($39) + 1)|0;
  $45 = (($1) + ($44<<1)|0);
  $46 = HEAP16[$45>>1]|0;
  $47 = $46&65535;
  $48 = (($3) + ($39<<1)|0);
  $49 = HEAP16[$48>>1]|0;
  $50 = $49&65535;
  $51 = (($3) + ($44<<1)|0);
  $52 = HEAP16[$51>>1]|0;
  $53 = $52&65535;
  $54 = (65536 - ($40))|0;
  $55 = $43 >>> $11;
  $56 = $55 << $12;
  $57 = $56 & 255;
  $58 = Math_imul($57, $54)|0;
  $59 = $47 >>> $11;
  $60 = $59 << $12;
  $61 = $60 & 255;
  $62 = Math_imul($61, $40)|0;
  $63 = (($58) + ($62))|0;
  $64 = $63 >>> 16;
  $65 = $50 >>> $11;
  $66 = $65 << $12;
  $67 = $66 & 255;
  $68 = Math_imul($67, $54)|0;
  $69 = $53 >>> $11;
  $70 = $69 << $12;
  $71 = $70 & 255;
  $72 = Math_imul($71, $40)|0;
  $73 = (($68) + ($72))|0;
  $74 = $73 >>> 16;
  $75 = $43 >>> $14;
  $76 = $75 << $16;
  $77 = $76 & 255;
  $78 = Math_imul($77, $54)|0;
  $79 = $47 >>> $14;
  $80 = $79 << $16;
  $81 = $80 & 255;
  $82 = Math_imul($81, $40)|0;
  $83 = (($78) + ($82))|0;
  $84 = $83 >>> 16;
  $85 = $50 >>> $14;
  $86 = $85 << $16;
  $87 = $86 & 255;
  $88 = Math_imul($87, $54)|0;
  $89 = $53 >>> $14;
  $90 = $89 << $16;
  $91 = $90 & 255;
  $92 = Math_imul($91, $40)|0;
  $93 = (($88) + ($92))|0;
  $94 = $93 >>> 16;
  $95 = $43 >>> $18;
  $96 = $95 << $20;
  $97 = $96 & 255;
  $98 = Math_imul($97, $54)|0;
  $99 = $47 >>> $18;
  $100 = $99 << $20;
  $101 = $100 & 255;
  $102 = Math_imul($101, $40)|0;
  $103 = (($98) + ($102))|0;
  $104 = $103 >>> 16;
  $105 = $50 >>> $18;
  $106 = $105 << $20;
  $107 = $106 & 255;
  $108 = Math_imul($107, $54)|0;
  $109 = $53 >>> $18;
  $110 = $109 << $20;
  $111 = $110 & 255;
  $112 = Math_imul($111, $40)|0;
  $113 = (($108) + ($112))|0;
  $114 = $113 >>> 16;
  $115 = $43 >>> $22;
  $116 = $115 << $24;
  $117 = $116 & 255;
  $118 = Math_imul($117, $54)|0;
  $119 = $47 >>> $22;
  $120 = $119 << $24;
  $121 = $120 & 255;
  $122 = Math_imul($121, $40)|0;
  $123 = (($118) + ($122))|0;
  $124 = $123 >>> 16;
  $125 = $50 >>> $22;
  $126 = $125 << $24;
  $127 = $126 & 255;
  $128 = Math_imul($127, $54)|0;
  $129 = $53 >>> $22;
  $130 = $129 << $24;
  $131 = $130 & 255;
  $132 = Math_imul($131, $40)|0;
  $133 = (($128) + ($132))|0;
  $134 = $133 >>> 16;
  $135 = Math_imul($27, $64)|0;
  $136 = Math_imul($26, $74)|0;
  $137 = (($135) + ($136))|0;
  $138 = $137 >>> 16;
  $139 = $138 >>> $12;
  $140 = $139 << $11;
  $141 = $140 & $29;
  $142 = Math_imul($27, $84)|0;
  $143 = Math_imul($26, $94)|0;
  $144 = (($142) + ($143))|0;
  $145 = $144 >>> 16;
  $146 = $145 >>> $16;
  $147 = $146 << $14;
  $148 = $147 & $31;
  $149 = $141 | $148;
  $150 = Math_imul($104, $27)|0;
  $151 = Math_imul($114, $26)|0;
  $152 = (($150) + ($151))|0;
  $153 = $152 >>> 16;
  $154 = $153 >>> $20;
  $155 = $154 << $18;
  $156 = $155 & $33;
  $157 = $149 | $156;
  $158 = Math_imul($124, $27)|0;
  $159 = Math_imul($134, $26)|0;
  $160 = (($158) + ($159))|0;
  $161 = $160 >>> 16;
  $162 = $161 >>> $24;
  $163 = $162 << $22;
  $164 = $163 & $35;
  $165 = $157 | $164;
  $166 = $165&65535;
  $167 = (($dest$02) + 2|0);
  HEAP16[$dest$02>>1] = $166;
  $168 = (($37) + ($u$03))|0;
  $169 = ($38|0)==(0);
  if ($169) {
   break;
  } else {
   $count$01 = $38;$dest$02 = $167;$u$03 = $168;
  }
 }
 STACKTOP = sp;return;
}
function __ZL28inner_stretch_3rgba_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx10 = 0, $$idx10$val = 0, $$idx3 = 0, $$idx3$val = 0, $$idx4 = 0, $$idx4$val = 0, $$idx6 = 0, $$idx6$val = 0, $$idx7 = 0, $$idx7$val = 0, $$idx9 = 0, $$idx9$val = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0;
 var $$val = 0, $$val2 = 0, $$val5 = 0, $$val8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $count$018 = 0, $dest$019 = 0, $u$020 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (($info) + 16|0);
 $8 = HEAP32[$info>>2]|0;
 $9 = HEAP32[$7>>2]|0;
 $10 = (($blitter) + 4|0);
 $11 = (($blitter) + 16|0);
 $12 = (($blitter) + 12|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 40|0);
 $16 = (($blitter) + 36|0);
 $17 = (($info) + 24|0);
 $18 = (($blitter) + 8|0);
 $19 = (($blitter) + 20|0);
 $20 = (($blitter) + 32|0);
 $21 = (($blitter) + 44|0);
 $22 = (($info) + 20|0);
 $count$018 = $5;$dest$019 = $8;$u$020 = $9;
 while(1) {
  $23 = (($count$018) + -1)|0;
  $24 = $u$020 >>> 16;
  $25 = $u$020 & 65535;
  $26 = ($24*3)|0;
  $27 = (($1) + ($26)|0);
  $$val8 = HEAP8[$27>>0]|0;
  $$sum = (($26) + 1)|0;
  $$idx9 = (($1) + ($$sum)|0);
  $$idx9$val = HEAP8[$$idx9>>0]|0;
  $$sum11 = (($26) + 2)|0;
  $$idx10 = (($1) + ($$sum11)|0);
  $$idx10$val = HEAP8[$$idx10>>0]|0;
  $28 = $$val8&255;
  $29 = $$idx9$val&255;
  $30 = $29 << 8;
  $31 = $30 | $28;
  $32 = $$idx10$val&255;
  $33 = $32 << 16;
  $34 = $31 | $33;
  $35 = (($26) + 3)|0;
  $36 = (($1) + ($35)|0);
  $$val5 = HEAP8[$36>>0]|0;
  $$sum12 = (($26) + 4)|0;
  $$idx6 = (($1) + ($$sum12)|0);
  $$idx6$val = HEAP8[$$idx6>>0]|0;
  $$sum13 = (($26) + 5)|0;
  $$idx7 = (($1) + ($$sum13)|0);
  $$idx7$val = HEAP8[$$idx7>>0]|0;
  $37 = $$val5&255;
  $38 = $$idx6$val&255;
  $39 = $38 << 8;
  $40 = $39 | $37;
  $41 = $$idx7$val&255;
  $42 = $41 << 16;
  $43 = $40 | $42;
  $44 = (($3) + ($26)|0);
  $$val2 = HEAP8[$44>>0]|0;
  $$idx3 = (($3) + ($$sum)|0);
  $$idx3$val = HEAP8[$$idx3>>0]|0;
  $$idx4 = (($3) + ($$sum11)|0);
  $$idx4$val = HEAP8[$$idx4>>0]|0;
  $45 = $$val2&255;
  $46 = $$idx3$val&255;
  $47 = $46 << 8;
  $48 = $47 | $45;
  $49 = $$idx4$val&255;
  $50 = $49 << 16;
  $51 = $48 | $50;
  $52 = (($3) + ($35)|0);
  $$val = HEAP8[$52>>0]|0;
  $$idx = (($3) + ($$sum12)|0);
  $$idx$val = HEAP8[$$idx>>0]|0;
  $$idx1 = (($3) + ($$sum13)|0);
  $$idx1$val = HEAP8[$$idx1>>0]|0;
  $53 = $$val&255;
  $54 = $$idx$val&255;
  $55 = $54 << 8;
  $56 = $55 | $53;
  $57 = $$idx1$val&255;
  $58 = $57 << 16;
  $59 = $56 | $58;
  $60 = (65536 - ($25))|0;
  $61 = HEAP32[$10>>2]|0;
  $62 = $34 >>> $61;
  $63 = HEAP32[$blitter>>2]|0;
  $64 = $62 << $63;
  $65 = $64 & 255;
  $66 = Math_imul($65, $60)|0;
  $67 = $43 >>> $61;
  $68 = $67 << $63;
  $69 = $68 & 255;
  $70 = Math_imul($69, $25)|0;
  $71 = (($66) + ($70))|0;
  $72 = $71 >>> 16;
  $73 = $51 >>> $61;
  $74 = $73 << $63;
  $75 = $74 & 255;
  $76 = Math_imul($75, $60)|0;
  $77 = $59 >>> $61;
  $78 = $77 << $63;
  $79 = $78 & 255;
  $80 = Math_imul($79, $25)|0;
  $81 = (($80) + ($76))|0;
  $82 = $81 >>> 16;
  $83 = HEAP32[$11>>2]|0;
  $84 = $34 >>> $83;
  $85 = HEAP32[$12>>2]|0;
  $86 = $84 << $85;
  $87 = $86 & 255;
  $88 = Math_imul($87, $60)|0;
  $89 = $43 >>> $83;
  $90 = $89 << $85;
  $91 = $90 & 255;
  $92 = Math_imul($91, $25)|0;
  $93 = (($88) + ($92))|0;
  $94 = $93 >>> 16;
  $95 = $51 >>> $83;
  $96 = $95 << $85;
  $97 = $96 & 255;
  $98 = Math_imul($97, $60)|0;
  $99 = $59 >>> $83;
  $100 = $99 << $85;
  $101 = $100 & 255;
  $102 = Math_imul($101, $25)|0;
  $103 = (($98) + ($102))|0;
  $104 = $103 >>> 16;
  $105 = HEAP32[$13>>2]|0;
  $106 = $34 >>> $105;
  $107 = HEAP32[$14>>2]|0;
  $108 = $106 << $107;
  $109 = $108 & 255;
  $110 = Math_imul($109, $60)|0;
  $111 = $43 >>> $105;
  $112 = $111 << $107;
  $113 = $112 & 255;
  $114 = Math_imul($113, $25)|0;
  $115 = (($110) + ($114))|0;
  $116 = $115 >>> 16;
  $117 = $51 >>> $105;
  $118 = $117 << $107;
  $119 = $118 & 255;
  $120 = Math_imul($119, $60)|0;
  $121 = $59 >>> $105;
  $122 = $121 << $107;
  $123 = $122 & 255;
  $124 = Math_imul($123, $25)|0;
  $125 = (($120) + ($124))|0;
  $126 = $125 >>> 16;
  $127 = HEAP32[$15>>2]|0;
  $128 = $34 >>> $127;
  $129 = HEAP32[$16>>2]|0;
  $130 = $128 << $129;
  $131 = $130 & 255;
  $132 = Math_imul($131, $60)|0;
  $133 = $43 >>> $127;
  $134 = $133 << $129;
  $135 = $134 & 255;
  $136 = Math_imul($135, $25)|0;
  $137 = (($132) + ($136))|0;
  $138 = $137 >>> 16;
  $139 = $51 >>> $127;
  $140 = $139 << $129;
  $141 = $140 & 255;
  $142 = Math_imul($141, $60)|0;
  $143 = $59 >>> $127;
  $144 = $143 << $129;
  $145 = $144 & 255;
  $146 = Math_imul($145, $25)|0;
  $147 = (($142) + ($146))|0;
  $148 = $147 >>> 16;
  $149 = HEAP32[$17>>2]|0;
  $150 = (65536 - ($149))|0;
  $151 = Math_imul($150, $72)|0;
  $152 = Math_imul($149, $82)|0;
  $153 = (($151) + ($152))|0;
  $154 = $153 >>> 16;
  $155 = $154 >>> $63;
  $156 = $155 << $61;
  $157 = HEAP32[$18>>2]|0;
  $158 = $156 & $157;
  $159 = Math_imul($150, $94)|0;
  $160 = Math_imul($149, $104)|0;
  $161 = (($159) + ($160))|0;
  $162 = $161 >>> 16;
  $163 = $162 >>> $85;
  $164 = $163 << $83;
  $165 = HEAP32[$19>>2]|0;
  $166 = $164 & $165;
  $167 = $158 | $166;
  $168 = Math_imul($116, $150)|0;
  $169 = Math_imul($126, $149)|0;
  $170 = (($168) + ($169))|0;
  $171 = $170 >>> 16;
  $172 = $171 >>> $107;
  $173 = $172 << $105;
  $174 = HEAP32[$20>>2]|0;
  $175 = $173 & $174;
  $176 = $167 | $175;
  $177 = Math_imul($138, $150)|0;
  $178 = Math_imul($148, $149)|0;
  $179 = (($177) + ($178))|0;
  $180 = $179 >>> 16;
  $181 = $180 >>> $129;
  $182 = $181 << $127;
  $183 = HEAP32[$21>>2]|0;
  $184 = $182 & $183;
  $185 = $176 | $184;
  $186 = $185&255;
  HEAP8[$dest$019>>0] = $186;
  $187 = $185 >>> 8;
  $188 = $187&255;
  $189 = (($dest$019) + 1|0);
  HEAP8[$189>>0] = $188;
  $190 = $185 >>> 16;
  $191 = $190&255;
  $192 = (($dest$019) + 2|0);
  HEAP8[$192>>0] = $191;
  $193 = (($dest$019) + 3|0);
  $194 = HEAP32[$22>>2]|0;
  $195 = (($194) + ($u$020))|0;
  $196 = ($23|0)==(0);
  if ($196) {
   break;
  } else {
   $count$018 = $23;$dest$019 = $193;$u$020 = $195;
  }
 }
 STACKTOP = sp;return;
}
function __ZL28inner_stretch_4rgba_bilinearP7BlitterPK9InnerInfo($blitter,$info) {
 $blitter = $blitter|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$01 = 0, $dest$02 = 0, $u$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($info) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($info) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = HEAP32[$info>>2]|0;
 $8 = (($info) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($blitter) + 4|0);
 $11 = (($blitter) + 16|0);
 $12 = (($blitter) + 12|0);
 $13 = (($blitter) + 28|0);
 $14 = (($blitter) + 24|0);
 $15 = (($blitter) + 40|0);
 $16 = (($blitter) + 36|0);
 $17 = (($info) + 24|0);
 $18 = (($blitter) + 8|0);
 $19 = (($blitter) + 20|0);
 $20 = (($blitter) + 32|0);
 $21 = (($blitter) + 44|0);
 $22 = (($info) + 20|0);
 $count$01 = $5;$dest$02 = $7;$u$03 = $9;
 while(1) {
  $23 = (($count$01) + -1)|0;
  $24 = $u$03 >>> 16;
  $25 = $u$03 & 65535;
  $26 = (($1) + ($24<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($24) + 1)|0;
  $29 = (($1) + ($28<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($3) + ($24<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($3) + ($28<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (65536 - ($25))|0;
  $36 = HEAP32[$10>>2]|0;
  $37 = $27 >>> $36;
  $38 = HEAP32[$blitter>>2]|0;
  $39 = $37 << $38;
  $40 = $39 & 255;
  $41 = Math_imul($40, $35)|0;
  $42 = $30 >>> $36;
  $43 = $42 << $38;
  $44 = $43 & 255;
  $45 = Math_imul($44, $25)|0;
  $46 = (($41) + ($45))|0;
  $47 = $46 >>> 16;
  $48 = $32 >>> $36;
  $49 = $48 << $38;
  $50 = $49 & 255;
  $51 = Math_imul($50, $35)|0;
  $52 = $34 >>> $36;
  $53 = $52 << $38;
  $54 = $53 & 255;
  $55 = Math_imul($54, $25)|0;
  $56 = (($51) + ($55))|0;
  $57 = $56 >>> 16;
  $58 = HEAP32[$11>>2]|0;
  $59 = $27 >>> $58;
  $60 = HEAP32[$12>>2]|0;
  $61 = $59 << $60;
  $62 = $61 & 255;
  $63 = Math_imul($62, $35)|0;
  $64 = $30 >>> $58;
  $65 = $64 << $60;
  $66 = $65 & 255;
  $67 = Math_imul($66, $25)|0;
  $68 = (($63) + ($67))|0;
  $69 = $68 >>> 16;
  $70 = $32 >>> $58;
  $71 = $70 << $60;
  $72 = $71 & 255;
  $73 = Math_imul($72, $35)|0;
  $74 = $34 >>> $58;
  $75 = $74 << $60;
  $76 = $75 & 255;
  $77 = Math_imul($76, $25)|0;
  $78 = (($73) + ($77))|0;
  $79 = $78 >>> 16;
  $80 = HEAP32[$13>>2]|0;
  $81 = $27 >>> $80;
  $82 = HEAP32[$14>>2]|0;
  $83 = $81 << $82;
  $84 = $83 & 255;
  $85 = Math_imul($84, $35)|0;
  $86 = $30 >>> $80;
  $87 = $86 << $82;
  $88 = $87 & 255;
  $89 = Math_imul($88, $25)|0;
  $90 = (($85) + ($89))|0;
  $91 = $90 >>> 16;
  $92 = $32 >>> $80;
  $93 = $92 << $82;
  $94 = $93 & 255;
  $95 = Math_imul($94, $35)|0;
  $96 = $34 >>> $80;
  $97 = $96 << $82;
  $98 = $97 & 255;
  $99 = Math_imul($98, $25)|0;
  $100 = (($95) + ($99))|0;
  $101 = $100 >>> 16;
  $102 = HEAP32[$15>>2]|0;
  $103 = $27 >>> $102;
  $104 = HEAP32[$16>>2]|0;
  $105 = $103 << $104;
  $106 = $105 & 255;
  $107 = Math_imul($106, $35)|0;
  $108 = $30 >>> $102;
  $109 = $108 << $104;
  $110 = $109 & 255;
  $111 = Math_imul($110, $25)|0;
  $112 = (($107) + ($111))|0;
  $113 = $112 >>> 16;
  $114 = $32 >>> $102;
  $115 = $114 << $104;
  $116 = $115 & 255;
  $117 = Math_imul($116, $35)|0;
  $118 = $34 >>> $102;
  $119 = $118 << $104;
  $120 = $119 & 255;
  $121 = Math_imul($120, $25)|0;
  $122 = (($117) + ($121))|0;
  $123 = $122 >>> 16;
  $124 = HEAP32[$17>>2]|0;
  $125 = (65536 - ($124))|0;
  $126 = Math_imul($125, $47)|0;
  $127 = Math_imul($124, $57)|0;
  $128 = (($126) + ($127))|0;
  $129 = $128 >>> 16;
  $130 = $129 >>> $38;
  $131 = $130 << $36;
  $132 = HEAP32[$18>>2]|0;
  $133 = $131 & $132;
  $134 = Math_imul($125, $69)|0;
  $135 = Math_imul($124, $79)|0;
  $136 = (($134) + ($135))|0;
  $137 = $136 >>> 16;
  $138 = $137 >>> $60;
  $139 = $138 << $58;
  $140 = HEAP32[$19>>2]|0;
  $141 = $139 & $140;
  $142 = $133 | $141;
  $143 = Math_imul($91, $125)|0;
  $144 = Math_imul($101, $124)|0;
  $145 = (($143) + ($144))|0;
  $146 = $145 >>> 16;
  $147 = $146 >>> $82;
  $148 = $147 << $80;
  $149 = HEAP32[$20>>2]|0;
  $150 = $148 & $149;
  $151 = $142 | $150;
  $152 = Math_imul($113, $125)|0;
  $153 = Math_imul($123, $124)|0;
  $154 = (($152) + ($153))|0;
  $155 = $154 >>> 16;
  $156 = $155 >>> $104;
  $157 = $156 << $102;
  $158 = HEAP32[$21>>2]|0;
  $159 = $157 & $158;
  $160 = $151 | $159;
  $161 = (($dest$02) + 4|0);
  HEAP32[$dest$02>>2] = $160;
  $162 = HEAP32[$22>>2]|0;
  $163 = (($162) + ($u$03))|0;
  $164 = ($23|0)==(0);
  if ($164) {
   break;
  } else {
   $count$01 = $23;$dest$02 = $161;$u$03 = $163;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6prcore7Surface9BlitImageERKS0_NS0_8BlitModeE($this,$source,$mode) {
 $this = $this|0;
 $source = $source|0;
 $mode = $mode|0;
 var $$ = 0, $$0$i$i = 0, $$1 = 0, $$2 = 0, $$21 = 0, $$pre = 0, $$pre19 = 0, $$sum = 0, $$type$0 = 0, $$type$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = Math_fround(0), $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $blitterStack = 0, $d$09 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond18 = 0, $i$01$i = 0, $innerinfo = 0, $not$ = 0, $phitmp = 0, $phitmp$i = 0, $phitmp20 = 0, $s$010 = 0, $type$2 = 0, $type$2$ = 0, $umax = 0, $umax17 = 0, $v$0 = 0, $v$114 = 0, $vstep$0 = 0, $y$08 = 0;
 var $y2$015 = 0, $y5$012 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $blitterStack = sp + 28|0;
 $innerinfo = sp;
 $0 = HEAP8[1141080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $i$01$i = 0;
  while(1) {
   $2 = (Math_fround(($i$01$i|0)));
   $3 = Math_fround($2 * Math_fround(0.298999994993209838867));
   $4 = (~~(($3))&255);
   $5 = ((1138392 + ($i$01$i<<2)|0) + 2|0);
   HEAP8[$5>>0] = $4;
   $6 = Math_fround($2 * Math_fround(0.587000012397766113281));
   $7 = (~~(($6))&255);
   $8 = ((1138392 + ($i$01$i<<2)|0) + 1|0);
   HEAP8[$8>>0] = $7;
   $9 = Math_fround($2 * Math_fround(0.114000000059604644775));
   $10 = (~~(($9))&255);
   $11 = (1138392 + ($i$01$i<<2)|0);
   HEAP8[$11>>0] = $10;
   $12 = ((1138392 + ($i$01$i<<2)|0) + 3|0);
   HEAP8[$12>>0] = 0;
   $13 = (($i$01$i) + 1)|0;
   $exitcond$i = ($13|0)==(256);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $13;
   }
  }
  HEAP8[1141080>>0] = 1;
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = (($this) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($this) + 40|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 $22 = HEAP32[$source>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($source) + 4|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $27 = (($source) + 40|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = ($17|0)!=($25|0);
 $not$ = ($14|0)!=($22|0);
 $$2 = $30 | $not$;
 $31 = (($source) + 12|0);
 $32 = (($this) + 12|0);
 $33 = (($source) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($this) + 16|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 if ($37) {
  $38 = (($source) + 20|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($this) + 20|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($39|0)==($41|0);
  if ($42) {
   $43 = (($source) + 24|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($this) + 24|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($44|0)==($46|0);
   if ($47) {
    $48 = (($source) + 28|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = (($this) + 28|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = ($49|0)==($51|0);
    if ($52) {
     $53 = HEAP32[$31>>2]|0;
     $54 = HEAP32[$32>>2]|0;
     $phitmp$i = ($53|0)!=($54|0);
     $phitmp = $phitmp$i ? 2 : 0;
     $$0$i$i = $phitmp;
    } else {
     $$0$i$i = 2;
    }
   } else {
    $$0$i$i = 2;
   }
  } else {
   $$0$i$i = 2;
  }
 } else {
  $$0$i$i = 2;
 }
 if ((($mode|0) == 2)) {
  $56 = $$0$i$i | 5;
  $$type$1 = $$2 ? $56 : $$0$i$i;
  $type$2 = $$type$1;
 } else if ((($mode|0) == 1)) {
  $55 = $$2&1;
  $$type$0 = $$0$i$i | $55;
  $type$2 = $$type$0;
 } else {
  $type$2 = $$0$i$i;
 }
 $57 = ($type$2|0)==(0);
 if ($57) {
  $58 = ($22>>>0)<($14>>>0);
  $59 = $58 ? $22 : $14;
  $60 = ($25>>>0)<($17>>>0);
  $61 = $60 ? $25 : $17;
  $62 = HEAP32[$32>>2]|0;
  $63 = $62 >>> 3;
  $64 = $63 & 8191;
  $65 = Math_imul($64, $59)|0;
  $66 = ($61|0)==(0);
  if ($66) {
   STACKTOP = sp;return;
  }
  $67 = (($source) + 8|0);
  $68 = (($this) + 8|0);
  $69 = $25 ^ -1;
  $70 = $17 ^ -1;
  $71 = ($69>>>0)>($70>>>0);
  $umax = $71 ? $69 : $70;
  $72 = $umax ^ -1;
  $d$09 = $20;$s$010 = $28;$y$08 = 0;
  while(1) {
   _memcpy(($d$09|0),($s$010|0),($65|0))|0;
   $73 = HEAP32[$67>>2]|0;
   $74 = (($s$010) + ($73)|0);
   $75 = HEAP32[$68>>2]|0;
   $76 = (($d$09) + ($75)|0);
   $77 = (($y$08) + 1)|0;
   $exitcond = ($77|0)==($72|0);
   if ($exitcond) {
    break;
   } else {
    $d$09 = $76;$s$010 = $74;$y$08 = $77;
   }
  }
  STACKTOP = sp;return;
 }
 $78 = HEAP32[$32>>2]|0;
 $79 = ($78|0)>(-1);
 if (!($79)) {
  $80 = HEAP32[$31>>2]|0;
  $81 = ($80|0)>(-1);
  if (!($81)) {
   $82 = $type$2 & 2;
   $83 = ($82|0)==(0);
   $84 = $type$2 & -5;
   $type$2$ = $83 ? $type$2 : $84;
   __ZN7BlitterC2ERKN6prcore11PixelFormatES3_i($blitterStack,$32,$31,$type$2$);
   $85 = HEAP32[$19>>2]|0;
   HEAP32[$innerinfo>>2] = $85;
   $86 = (($blitterStack) + 132|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = $87 & 1;
   $89 = ($88|0)==(0);
   if ($89) {
    $163 = HEAP32[$source>>2]|0;
    $164 = HEAP32[$this>>2]|0;
    $165 = ($163>>>0)<($164>>>0);
    $166 = $165 ? $163 : $164;
    $167 = HEAP32[$24>>2]|0;
    $168 = HEAP32[$16>>2]|0;
    $169 = ($167>>>0)<($168>>>0);
    $170 = $169 ? $167 : $168;
    $171 = (($innerinfo) + 12|0);
    HEAP32[$171>>2] = $166;
    $172 = HEAP32[$27>>2]|0;
    $173 = (($innerinfo) + 4|0);
    HEAP32[$173>>2] = $172;
    $174 = ($170|0)==(0);
    if ($174) {
     STACKTOP = sp;return;
    }
    $175 = (($blitterStack) + 136|0);
    $176 = (($this) + 8|0);
    $177 = (($source) + 8|0);
    $178 = $167 ^ -1;
    $179 = $168 ^ -1;
    $180 = ($178>>>0)>($179>>>0);
    $umax17 = $180 ? $178 : $179;
    $181 = $umax17 ^ -1;
    $y5$012 = 0;
    while(1) {
     $182 = HEAP32[$175>>2]|0;
     FUNCTION_TABLE_vii[$182 & 4095]($blitterStack,$innerinfo);
     $183 = HEAP32[$176>>2]|0;
     $184 = HEAP32[$innerinfo>>2]|0;
     $185 = (($184) + ($183)|0);
     HEAP32[$innerinfo>>2] = $185;
     $186 = HEAP32[$177>>2]|0;
     $187 = HEAP32[$173>>2]|0;
     $188 = (($187) + ($186)|0);
     HEAP32[$173>>2] = $188;
     $189 = (($y5$012) + 1)|0;
     $exitcond18 = ($189|0)==($181|0);
     if ($exitcond18) {
      break;
     } else {
      $y5$012 = $189;
     }
    }
    STACKTOP = sp;return;
   }
   $90 = $87 & 4;
   $91 = ($90|0)==(0);
   do {
    if ($91) {
     $120 = HEAP32[$source>>2]|0;
     $121 = $120 << 16;
     $122 = HEAP32[$this>>2]|0;
     $123 = (($121>>>0) / ($122>>>0))&-1;
     $124 = (($innerinfo) + 20|0);
     HEAP32[$124>>2] = $123;
     $125 = $123 >>> 1;
     $126 = (($innerinfo) + 16|0);
     HEAP32[$126>>2] = $125;
     $127 = HEAP32[$24>>2]|0;
     $128 = $127 << 16;
     $129 = HEAP32[$16>>2]|0;
     $130 = (($128>>>0) / ($129>>>0))&-1;
     $131 = $130 >>> 1;
     $133 = $122;$136 = $127;$142 = $129;$v$0 = $131;$vstep$0 = $130;
    } else {
     $92 = HEAP32[$this>>2]|0;
     $93 = HEAP32[$source>>2]|0;
     $94 = ($92>>>0)<($93>>>0);
     if ($94) {
      $95 = $93 << 16;
      $96 = (($95>>>0) / ($92>>>0))&-1;
      $97 = (($innerinfo) + 20|0);
      HEAP32[$97>>2] = $96;
      $98 = $96 >>> 1;
      $99 = (($98) + -32768)|0;
      $100 = (($innerinfo) + 16|0);
      HEAP32[$100>>2] = $99;
     } else {
      $101 = (($92) + -1)|0;
      $102 = ($101|0)!=(0);
      $$ = $102 ? $101 : 1;
      $103 = $93 << 16;
      $104 = (($103) + -65536)|0;
      $105 = (($104>>>0) / ($$>>>0))&-1;
      $106 = (($innerinfo) + 20|0);
      HEAP32[$106>>2] = $105;
      $107 = (($innerinfo) + 16|0);
      HEAP32[$107>>2] = 0;
     }
     $108 = HEAP32[$16>>2]|0;
     $109 = HEAP32[$24>>2]|0;
     $110 = ($108>>>0)<($109>>>0);
     if ($110) {
      $111 = $109 << 16;
      $112 = (($111>>>0) / ($108>>>0))&-1;
      $113 = $112 >>> 1;
      $114 = (($113) + -32768)|0;
      $133 = $92;$136 = $109;$142 = $108;$v$0 = $114;$vstep$0 = $112;
      break;
     } else {
      $115 = (($108) + -1)|0;
      $116 = ($115|0)!=(0);
      $$1 = $116 ? $115 : 1;
      $117 = $109 << 16;
      $118 = (($117) + -65536)|0;
      $119 = (($118>>>0) / ($$1>>>0))&-1;
      $133 = $92;$136 = $109;$142 = $108;$v$0 = 0;$vstep$0 = $119;
      break;
     }
    }
   } while(0);
   $132 = (($innerinfo) + 12|0);
   HEAP32[$132>>2] = $133;
   $134 = HEAP32[$27>>2]|0;
   $135 = (($136) + -1)|0;
   $137 = (($source) + 8|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = Math_imul($135, $138)|0;
   $140 = (($134) + ($139)|0);
   $141 = ($142|0)==(0);
   if ($141) {
    STACKTOP = sp;return;
   }
   $143 = (($innerinfo) + 4|0);
   $144 = (($innerinfo) + 8|0);
   $145 = (($innerinfo) + 24|0);
   $146 = (($blitterStack) + 136|0);
   $147 = (($this) + 8|0);
   $150 = $138;$152 = $134;$v$114 = $v$0;$y2$015 = 1;
   while(1) {
    $148 = $v$114 >>> 16;
    $149 = Math_imul($150, $148)|0;
    $151 = (($152) + ($149)|0);
    HEAP32[$143>>2] = $151;
    $$sum = (($149) + ($150))|0;
    $153 = (($152) + ($$sum)|0);
    $154 = ($153>>>0)>($140>>>0);
    $$21 = $154 ? $151 : $153;
    HEAP32[$144>>2] = $$21;
    $155 = $v$114 & 65535;
    HEAP32[$145>>2] = $155;
    $156 = HEAP32[$146>>2]|0;
    FUNCTION_TABLE_vii[$156 & 4095]($blitterStack,$innerinfo);
    $157 = HEAP32[$147>>2]|0;
    $158 = HEAP32[$innerinfo>>2]|0;
    $159 = (($158) + ($157)|0);
    HEAP32[$innerinfo>>2] = $159;
    $160 = HEAP32[$16>>2]|0;
    $161 = ($y2$015>>>0)<($160>>>0);
    if (!($161)) {
     break;
    }
    $162 = (($v$114) + ($vstep$0))|0;
    $$pre = HEAP32[$27>>2]|0;
    $$pre19 = HEAP32[$137>>2]|0;
    $phitmp20 = (($y2$015) + 1)|0;
    $150 = $$pre19;$152 = $$pre;$v$114 = $162;$y2$015 = $phitmp20;
   }
   STACKTOP = sp;return;
  }
 }
 __ZN6prcore7Surface14BlitImageFloatERKS0_NS0_8BlitModeE($this,$source,$mode);
 STACKTOP = sp;return;
}
function __ZN6prcore7Surface10FlipImageYEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bottom$02 = 0, $func$1$ph = 0, $samples$0$ph = 0, $top$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (($3) + -1)|0;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_imul($10, $8)|0;
 $12 = (($6) + ($11)|0);
 $13 = (($this) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & 1073741824;
 $16 = ($15|0)==(0);
 do {
  if ($16) {
   $21 = $14 & 536870912;
   $22 = ($21|0)==(0);
   if (!($22)) {
    $23 = $14 >>> 3;
    $24 = $23 & 8191;
    $25 = Math_imul($24, $0)|0;
    $26 = $25 >>> 2;
    $func$1$ph = 2082;$samples$0$ph = $26;
    break;
   }
   $27 = ($14|0)<(0);
   if ($27) {
    $28 = $14 >>> 3;
    $29 = $28 & 8191;
    if ((($29|0) == 1)) {
     $func$1$ph = 2083;$samples$0$ph = $0;
     break;
    } else if ((($29|0) == 2)) {
     $func$1$ph = 2081;$samples$0$ph = $0;
     break;
    } else if ((($29|0) == 4)) {
     $func$1$ph = 2082;$samples$0$ph = $0;
     break;
    } else if ((($29|0) == 3)) {
     $func$1$ph = 2084;$samples$0$ph = $0;
     break;
    } else {
     STACKTOP = sp;return;
    }
   } else {
    $func$1$ph = 0;$samples$0$ph = 0;
   }
  } else {
   $17 = $14 >>> 3;
   $18 = $17 & 8191;
   $19 = Math_imul($18, $0)|0;
   $20 = $19 >>> 1;
   $func$1$ph = 2081;$samples$0$ph = $20;
  }
 } while(0);
 $30 = ($11|0)>(0);
 if ($30) {
  $bottom$02 = $12;$top$01 = $6;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  FUNCTION_TABLE_viii[$func$1$ph & 4095]($top$01,$bottom$02,$samples$0$ph);
  $31 = HEAP32[$9>>2]|0;
  $32 = (($top$01) + ($31)|0);
  $33 = (0 - ($31))|0;
  $34 = (($bottom$02) + ($33)|0);
  $35 = ($32>>>0)<($34>>>0);
  if ($35) {
   $bottom$02 = $34;$top$01 = $32;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZL11inner_flip2PvS_j($line0,$line1,$count) {
 $line0 = $line0|0;
 $line1 = $line1|0;
 $count = $count|0;
 var $$014$i = 0, $$023$i = 0, $$05$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $$014$i = $count;$$023$i = $line1;$$05$i = $line0;
 while(1) {
  $1 = (($$014$i) + -1)|0;
  $2 = HEAP16[$$05$i>>1]|0;
  $3 = HEAP16[$$023$i>>1]|0;
  $4 = (($$05$i) + 2|0);
  HEAP16[$$05$i>>1] = $3;
  $5 = (($$023$i) + 2|0);
  HEAP16[$$023$i>>1] = $2;
  $6 = ($1|0)==(0);
  if ($6) {
   break;
  } else {
   $$014$i = $1;$$023$i = $5;$$05$i = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZL11inner_flip4PvS_j($line0,$line1,$count) {
 $line0 = $line0|0;
 $line1 = $line1|0;
 $count = $count|0;
 var $$014$i = 0, $$023$i = 0, $$05$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $$014$i = $count;$$023$i = $line1;$$05$i = $line0;
 while(1) {
  $1 = (($$014$i) + -1)|0;
  $2 = HEAP32[$$05$i>>2]|0;
  $3 = HEAP32[$$023$i>>2]|0;
  $4 = (($$05$i) + 4|0);
  HEAP32[$$05$i>>2] = $3;
  $5 = (($$023$i) + 4|0);
  HEAP32[$$023$i>>2] = $2;
  $6 = ($1|0)==(0);
  if ($6) {
   break;
  } else {
   $$014$i = $1;$$023$i = $5;$$05$i = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZL11inner_flip1PvS_j($line0,$line1,$count) {
 $line0 = $line0|0;
 $line1 = $line1|0;
 $count = $count|0;
 var $$014$i = 0, $$023$i = 0, $$05$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $$014$i = $count;$$023$i = $line1;$$05$i = $line0;
 }
 while(1) {
  $1 = (($$014$i) + -1)|0;
  $2 = HEAP8[$$05$i>>0]|0;
  $3 = HEAP8[$$023$i>>0]|0;
  $4 = (($$05$i) + 1|0);
  HEAP8[$$05$i>>0] = $3;
  $5 = (($$023$i) + 1|0);
  HEAP8[$$023$i>>0] = $2;
  $6 = ($1|0)==(0);
  if ($6) {
   break;
  } else {
   $$014$i = $1;$$023$i = $5;$$05$i = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZL11inner_flip3PvS_j($line0,$line1,$count) {
 $line0 = $line0|0;
 $line1 = $line1|0;
 $count = $count|0;
 var $$014$i = 0, $$023$i = 0, $$05$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count*3)|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $$014$i = $0;$$023$i = $line1;$$05$i = $line0;
 }
 while(1) {
  $2 = (($$014$i) + -1)|0;
  $3 = HEAP8[$$05$i>>0]|0;
  $4 = HEAP8[$$023$i>>0]|0;
  $5 = (($$05$i) + 1|0);
  HEAP8[$$05$i>>0] = $4;
  $6 = (($$023$i) + 1|0);
  HEAP8[$$023$i>>0] = $3;
  $7 = ($2|0)==(0);
  if ($7) {
   break;
  } else {
   $$014$i = $2;$$023$i = $6;$$05$i = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6prcore7SurfaceC2Ev($this) {
 $this = $this|0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$this+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN6prcore7SurfaceC2EjjjRKNS_11PixelFormatEPv($this,$w,$h,$p,$pxf,$i) {
 $this = $this|0;
 $w = $w|0;
 $h = $h|0;
 $p = $p|0;
 $pxf = $pxf|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $w;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $h;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $p;
 $2 = HEAP32[$pxf>>2]|0;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $2;
 $4 = (($pxf) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 16|0);
 HEAP32[$6>>2] = $5;
 $7 = (($pxf) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 20|0);
 HEAP32[$9>>2] = $8;
 $10 = (($pxf) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 24|0);
 HEAP32[$12>>2] = $11;
 $13 = (($pxf) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 28|0);
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 32|0);
 $17 = (($pxf) + 20|0);
 $18 = HEAP32[$17>>2]|0;
 HEAP32[$16>>2] = $18;
 $19 = (($this) + 36|0);
 $20 = (($pxf) + 24|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$19>>2] = $21;
 $22 = (($this) + 40|0);
 HEAP32[$22>>2] = $i;
 STACKTOP = sp;return;
}
function __ZN11PlayerPrefs16StaticInitializeEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(12)|0);
 $1 = (($0) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 8|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$0>>2] = $1;
 HEAP32[1141128>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN11PlayerPrefs13StaticDestroyEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1141128>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($0,$2);
 $3 = (($0) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($0) + 4|0);
 HEAP32[$0>>2] = $4;
 HEAP32[$4>>2] = 0;
 $5 = HEAP32[1141128>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (($5) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($5,$8);
  __ZdlPv($5);
 }
 HEAP32[1141128>>2] = 0;
 $9 = HEAP8[1141104>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  HEAP8[((1141104 + 1|0))>>0] = 0;
  HEAP8[1141104>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $12 = HEAP32[((1141104 + 8|0))>>2]|0;
  HEAP8[$12>>0] = 0;
  HEAP32[((1141104 + 4|0))>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN11PlayerPrefs6GetIntERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEi($name,$def) {
 $name = $name|0;
 $def = $def|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZL18InitializeIfNeededv();
 $0 = HEAP32[1141128>>2]|0;
 $1 = (__ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE14__count_uniqueIS7_EEjRKT_($0,$name)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = $def;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueNS_4lessIS6_EENS4_INS_4pairIKS6_S7_EEEEEixERSB_($0,$name)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(254);
 if (!($5)) {
  $$0 = $def;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (($3) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZL18InitializeIfNeededv() {
 var $$0$i = 0, $$0$i$i = 0, $$0$i9$i = 0, $$01$i = 0, $$02$i = 0, $$1$i = 0, $$byval_copy8 = 0, $$off$i$i = 0, $$off$i6$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond$i = 0, $contents = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $filePath = 0, $header$i = 0, $name$i = 0, $or$cond$i = 0, $start$i = 0, $switch$i$i = 0, $switch$i7$i = 0;
 var $value$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy8 = sp + 88|0;
 $0 = sp + 60|0;
 $start$i = sp + 36|0;
 $header$i = sp;
 $name$i = sp + 40|0;
 $value$i = sp + 16|0;
 $filePath = sp + 64|0;
 $contents = sp + 76|0;
 $1 = HEAP32[1141120>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (__Znwj(32)|0);
 $4 = (($filePath) + 8|0);
 HEAP32[$4>>2] = $3;
 HEAP32[$filePath>>2] = 33;
 $5 = (($filePath) + 4|0);
 HEAP32[$5>>2] = 18;
 dest=$3+0|0; src=1141136+0|0; stop=dest+18|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $6 = (($3) + 18|0);
 HEAP8[$6>>0] = 0;
 $7 = HEAP32[1141128>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($7,$9);
 $10 = (($7) + 8|0);
 HEAP32[$10>>2] = 0;
 $11 = (($7) + 4|0);
 HEAP32[$7>>2] = $11;
 HEAP32[$11>>2] = 0;
 HEAP32[1141120>>2] = 16;
 ;HEAP32[$contents+0>>2]=0|0;HEAP32[$contents+4>>2]=0|0;HEAP32[$contents+8>>2]=0|0;
 __THREW__ = 0;
 $12 = (invoke_iii(2418,($contents|0),($filePath|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 L4: do {
  if ($14) {
   $131 = ___cxa_find_matching_catch()|0;
   $132 = tempRet0;
   $eh$lpad$body$index3Z2D = $132;$eh$lpad$body$indexZ2D = $131;
  } else {
   if ($12) {
    $15 = HEAP8[$contents>>0]|0;
    $16 = $15 & 1;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     $22 = (($contents) + 1|0);
     $23 = $15&255;
     $24 = $23 >>> 1;
     $25 = $22;$27 = $24;
    } else {
     $18 = (($contents) + 8|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($contents) + 4|0);
     $21 = HEAP32[$20>>2]|0;
     $25 = $19;$27 = $21;
    }
    HEAP32[$start$i>>2] = $25;
    $26 = (($25) + ($27)|0);
    $28 = ($27>>>0)<(16);
    if (!($28)) {
     $29 = $25;
     $30 = $29;
     $31 = HEAPU8[$30>>0]|(HEAPU8[$30+1>>0]<<8)|(HEAPU8[$30+2>>0]<<16)|(HEAPU8[$30+3>>0]<<24);
     $32 = (($29) + 4)|0;
     $33 = $32;
     $34 = HEAPU8[$33>>0]|(HEAPU8[$33+1>>0]<<8)|(HEAPU8[$33+2>>0]<<16)|(HEAPU8[$33+3>>0]<<24);
     $35 = $header$i;
     $36 = $35;
     HEAP32[$36>>2] = $31;
     $37 = (($35) + 4)|0;
     $38 = $37;
     HEAP32[$38>>2] = $34;
     $39 = (($25) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($header$i) + 8|0);
     HEAP32[$41>>2] = $40;
     $42 = (($25) + 12|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($header$i) + 12|0);
     HEAP32[$44>>2] = $43;
     $45 = (($25) + 16|0);
     HEAP32[$start$i>>2] = $45;
     $46 = (_memcmp(1141088,$header$i,8)|0);
     $47 = ($46|0)==(0);
     $48 = ($40|0)==(65536);
     $or$cond$i = $47 & $48;
     if ($or$cond$i) {
      $49 = (($value$i) + 8|0);
      $50 = (($value$i) + 16|0);
      $51 = (($name$i) + 8|0);
      $52 = (($value$i) + 12|0);
      $53 = (($name$i) + 12|0);
      $54 = (($name$i) + 16|0);
      $55 = ($27|0)>(16);
      L14: do {
       if ($55) {
        while(1) {
         __THREW__ = 0;
         invoke_viii(2085,($name$i|0),($start$i|0),($26|0));
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          label = 41;
          break;
         }
         $58 = HEAP32[$name$i>>2]|0;
         $59 = ($58|0)==(128);
         if ($59) {
          $60 = HEAP32[$start$i>>2]|0;
          $61 = ($60>>>0)<($26>>>0);
          if ($61) {
           __THREW__ = 0;
           invoke_viii(2085,($value$i|0),($start$i|0),($26|0));
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if ($63) {
            label = 15;
            break;
           }
           $64 = HEAP32[$value$i>>2]|0;
           $65 = ($64|0)==(255);
           if ($65) {
            $$02$i = 3;
           } else {
            $68 = HEAP32[1141128>>2]|0;
            __THREW__ = 0;
            $69 = (invoke_iii(2714,($68|0),($51|0))|0);
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if ($71) {
             label = 35;
             break;
            }
            $72 = $value$i;
            $73 = $72;
            $74 = HEAP32[$73>>2]|0;
            $75 = (($72) + 4)|0;
            $76 = $75;
            $77 = HEAP32[$76>>2]|0;
            $78 = $69;
            $79 = $78;
            HEAP32[$79>>2] = $74;
            $80 = (($78) + 4)|0;
            $81 = $80;
            HEAP32[$81>>2] = $77;
            $82 = (($69) + 8|0);
            __THREW__ = 0;
            (invoke_iii(2233,($82|0),($49|0))|0);
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if ($84) {
             label = 35;
             break;
            }
            $85 = HEAP32[$name$i>>2]|0;
            $$off$i$i = (($85) + -253)|0;
            $switch$i$i = ($$off$i$i>>>0)<(2);
            if ($switch$i$i) {
             $$0$i$i = 5;
            } else {
             $86 = HEAP8[$51>>0]|0;
             $87 = $86 & 1;
             $88 = ($87<<24>>24)==(0);
             if ($88) {
              $90 = $86&255;
              $91 = $90 >>> 1;
              $93 = $91;
             } else {
              $89 = HEAP32[$53>>2]|0;
              $93 = $89;
             }
             $92 = ($93>>>0)<(128);
             $94 = $92 ? 1 : 5;
             $95 = (($94) + ($93))|0;
             $$0$i$i = $95;
            }
            $96 = HEAP32[$value$i>>2]|0;
            $$off$i6$i = (($96) + -253)|0;
            $switch$i7$i = ($$off$i6$i>>>0)<(2);
            if ($switch$i7$i) {
             $$0$i9$i = 5;
            } else {
             $97 = HEAP8[$49>>0]|0;
             $98 = $97 & 1;
             $99 = ($98<<24>>24)==(0);
             if ($99) {
              $101 = $97&255;
              $102 = $101 >>> 1;
              $104 = $102;
             } else {
              $100 = HEAP32[$52>>2]|0;
              $104 = $100;
             }
             $103 = ($104>>>0)<(128);
             $105 = $103 ? 1 : 5;
             $106 = (($105) + ($104))|0;
             $$0$i9$i = $106;
            }
            $107 = (($$0$i9$i) + ($$0$i$i))|0;
            $108 = HEAP32[1141120>>2]|0;
            $109 = (($107) + ($108))|0;
            HEAP32[1141120>>2] = $109;
            $$02$i = 0;
           }
           $110 = HEAP8[$49>>0]|0;
           $111 = $110 & 1;
           $112 = ($111<<24>>24)==(0);
           if ($112) {
            $$1$i = $$02$i;
           } else {
            $113 = HEAP32[$50>>2]|0;
            __ZdlPv($113);
            $$1$i = $$02$i;
           }
          } else {
           $$1$i = 3;
          }
         } else {
          $$1$i = 3;
         }
         $114 = HEAP8[$51>>0]|0;
         $115 = $114 & 1;
         $116 = ($115<<24>>24)==(0);
         if (!($116)) {
          $117 = HEAP32[$54>>2]|0;
          __ZdlPv($117);
         }
         $cond$i = ($$1$i|0)==(3);
         if ($cond$i) {
          break L14;
         }
         $$pre$i = HEAP32[$start$i>>2]|0;
         $118 = ($$pre$i>>>0)<($26>>>0);
         if (!($118)) {
          break L14;
         }
        }
        if ((label|0) == 15) {
         $66 = ___cxa_find_matching_catch()|0;
         $67 = tempRet0;
         $$0$i = $67;$$01$i = $66;
        }
        else if ((label|0) == 35) {
         $119 = ___cxa_find_matching_catch()|0;
         $120 = tempRet0;
         $121 = HEAP8[$49>>0]|0;
         $122 = $121 & 1;
         $123 = ($122<<24>>24)==(0);
         if ($123) {
          $$0$i = $120;$$01$i = $119;
         } else {
          $124 = HEAP32[$50>>2]|0;
          __ZdlPv($124);
          $$0$i = $120;$$01$i = $119;
         }
        }
        else if ((label|0) == 41) {
         $129 = ___cxa_find_matching_catch()|0;
         $130 = tempRet0;
         $eh$lpad$body$index3Z2D = $130;$eh$lpad$body$indexZ2D = $129;
         break L4;
        }
        $125 = HEAP8[$51>>0]|0;
        $126 = $125 & 1;
        $127 = ($126<<24>>24)==(0);
        if (!($127)) {
         $128 = HEAP32[$54>>2]|0;
         __ZdlPv($128);
        }
        $eh$lpad$body$index3Z2D = $$0$i;$eh$lpad$body$indexZ2D = $$01$i;
        break L4;
       }
      } while(0);
     }
    }
   }
   $142 = HEAP8[$contents>>0]|0;
   $143 = $142 & 1;
   $144 = ($143<<24>>24)==(0);
   if (!($144)) {
    $145 = (($contents) + 8|0);
    $146 = HEAP32[$145>>2]|0;
    HEAP32[$0>>2] = 90;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($146|0),($$byval_copy8|0));
    $147 = __THREW__; __THREW__ = 0;
    $148 = $147&1;
    if ($148) {
     $149 = ___cxa_find_matching_catch()|0;
     $150 = tempRet0;
     ___cxa_call_unexpected(($149|0));
     // unreachable;
    }
   }
   $151 = HEAP8[$filePath>>0]|0;
   $152 = $151 & 1;
   $153 = ($152<<24>>24)==(0);
   if ($153) {
    STACKTOP = sp;return;
   }
   $154 = HEAP32[$4>>2]|0;
   __ZdlPv($154);
   STACKTOP = sp;return;
  }
 } while(0);
 $133 = HEAP8[$contents>>0]|0;
 $134 = $133 & 1;
 $135 = ($134<<24>>24)==(0);
 if (!($135)) {
  $136 = (($contents) + 8|0);
  $137 = HEAP32[$136>>2]|0;
  HEAP32[$0>>2] = 90;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($137|0),($$byval_copy8|0));
  $138 = __THREW__; __THREW__ = 0;
  $139 = $138&1;
  if ($139) {
   $140 = ___cxa_find_matching_catch()|0;
   $141 = tempRet0;
   ___cxa_call_unexpected(($140|0));
   // unreachable;
  }
 }
 $155 = HEAP8[$filePath>>0]|0;
 $156 = $155 & 1;
 $157 = ($156<<24>>24)==(0);
 if ($157) {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 $158 = HEAP32[$4>>2]|0;
 __ZdlPv($158);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueNS_4lessIS6_EENS4_INS_4pairIKS6_S7_EEEEEixERSB_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i$i$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (__ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueNS_4lessIS6_EENS4_INS_4pairIKS6_S7_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERSB_($this,$__parent,$__k)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $__r$0 = $1;
  $45 = (($__r$0) + 28|0);
  STACKTOP = sp;return ($45|0);
 }
 $3 = (__Znwj(48)|0);
 $4 = (($3) + 16|0);
 $5 = HEAP8[$__k>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 L4: do {
  if ($7) {
   ;HEAP32[$4+0>>2]=HEAP32[$__k+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$__k+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$__k+8>>2]|0;
  } else {
   $8 = (($__k) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($__k) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11>>>0)>(4294967279);
   do {
    if ($12) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    } else {
     $15 = ($11>>>0)<(11);
     if ($15) {
      $16 = $11 << 1;
      $17 = $16&255;
      HEAP8[$4>>0] = $17;
      $18 = (($3) + 17|0);
      $__p$0$i$i$i$i$i = $18;
     } else {
      $19 = (($11) + 16)|0;
      $20 = $19 & -16;
      __THREW__ = 0;
      $21 = (invoke_ii(2988,($20|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      $24 = (($3) + 24|0);
      HEAP32[$24>>2] = $21;
      $25 = $20 | 1;
      HEAP32[$4>>2] = $25;
      $26 = (($3) + 20|0);
      HEAP32[$26>>2] = $11;
      $__p$0$i$i$i$i$i = $21;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($9|0),($11|0))|0;
     $27 = (($__p$0$i$i$i$i$i) + ($11)|0);
     HEAP8[$27>>0] = 0;
     break L4;
    }
   } while(0);
   $28 = ___cxa_find_matching_catch()|0;
   $29 = tempRet0;
   $30 = ($3|0)==(0|0);
   if ($30) {
    ___resumeException($28|0);
    // unreachable;
   }
   __ZdlPv($3);
   ___resumeException($28|0);
   // unreachable;
  }
 } while(0);
 $31 = (($3) + 28|0);
 HEAP32[$31>>2] = 255;
 $32 = (($3) + 36|0);
 ;HEAP32[$32+0>>2]=0|0;HEAP32[$32+4>>2]=0|0;HEAP32[$32+8>>2]=0|0;
 $33 = HEAP32[$__parent>>2]|0;
 HEAP32[$3>>2] = 0;
 $34 = (($3) + 4|0);
 HEAP32[$34>>2] = 0;
 $35 = (($3) + 8|0);
 HEAP32[$35>>2] = $33;
 HEAP32[$0>>2] = $3;
 $36 = HEAP32[$this>>2]|0;
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0|0);
 if ($38) {
  $41 = $3;
 } else {
  HEAP32[$this>>2] = $37;
  $$pre$i = HEAP32[$0>>2]|0;
  $41 = $$pre$i;
 }
 $39 = (($this) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($40,$41);
 $42 = (($this) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 1)|0;
 HEAP32[$42>>2] = $44;
 $__r$0 = $3;
 $45 = (($__r$0) + 28|0);
 STACKTOP = sp;return ($45|0);
}
function __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$__nd>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$1);
 $2 = (($__nd) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE7destroyEPNS_11__tree_nodeIS9_PvEE($this,$3);
 $4 = (($__nd) + 16|0);
 $5 = (($__nd) + 36|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if (!($8)) {
  $9 = (($__nd) + 44|0);
  $10 = HEAP32[$9>>2]|0;
  __ZdlPv($10);
 }
 $11 = HEAP8[$4>>0]|0;
 $12 = $11 & 1;
 $13 = ($12<<24>>24)==(0);
 if (!($13)) {
  $14 = (($__nd) + 24|0);
  $15 = HEAP32[$14>>2]|0;
  __ZdlPv($15);
 }
 __ZdlPv($__nd);
 STACKTOP = sp;return;
}
function __ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueNS_4lessIS6_EENS4_INS_4pairIKS6_S7_EEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERSB_($this,$__parent,$__k) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__k = $__k|0;
 var $$$$i$i$i = 0, $$$$i$i$i$us = 0, $$$$i$i$i5 = 0, $$$$i$i$i5$us = 0, $$$i$i$i = 0, $$$i$i$i$us = 0, $$$i$i$i4 = 0, $$$i$i$i4$us = 0, $$0 = 0, $$lcssa = 0, $$lcssa9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $__nd$0$in = 0, $__nd$0$in$lcssa = 0, $__nd$0$in$lcssa7 = 0, $__nd$0$in$lcssa8 = 0, $__nd$0$in$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $97 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $97;
  $$0 = $97;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP8[$__k>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 $6 = $3&255;
 $7 = $6 >>> 1;
 $8 = (($__k) + 1|0);
 $9 = (($__k) + 8|0);
 $10 = (($__k) + 4|0);
 L5: do {
  if ($5) {
   $__nd$0$in$us = $1;
   while(1) {
    $11 = (($__nd$0$in$us) + 16|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = $12 & 1;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     $19 = $12&255;
     $20 = $19 >>> 1;
     $21 = (($11) + 1|0);
     $23 = $20;$25 = $21;
    } else {
     $15 = (($__nd$0$in$us) + 20|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (($__nd$0$in$us) + 24|0);
     $18 = HEAP32[$17>>2]|0;
     $23 = $16;$25 = $18;
    }
    $22 = ($23>>>0)<($7>>>0);
    $24 = $22 ? $23 : $7;
    $26 = (_memcmp($8,$25,$24)|0);
    $27 = ($26|0)==(0);
    if ($27) {
     $28 = ($7>>>0)<($23>>>0);
     $$$i$i$i4$us = $22&1;
     $$$$i$i$i5$us = $28 ? -1 : $$$i$i$i4$us;
     $30 = $$$$i$i$i5$us;
    } else {
     $30 = $26;
    }
    $29 = ($30|0)<(0);
    if ($29) {
     $50 = HEAP32[$__nd$0$in$us>>2]|0;
     $51 = ($50|0)==(0|0);
     if ($51) {
      $$lcssa9 = $__nd$0$in$us;$__nd$0$in$lcssa8 = $__nd$0$in$us;
      label = 24;
      break;
     } else {
      $__nd$0$in$us = $50;
      continue;
     }
    }
    if ($14) {
     $35 = $12&255;
     $36 = $35 >>> 1;
     $37 = (($11) + 1|0);
     $39 = $36;$41 = $37;
    } else {
     $31 = (($__nd$0$in$us) + 20|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = (($__nd$0$in$us) + 24|0);
     $34 = HEAP32[$33>>2]|0;
     $39 = $32;$41 = $34;
    }
    $38 = ($7>>>0)<($39>>>0);
    $40 = $38 ? $7 : $39;
    $42 = (_memcmp($41,$8,$40)|0);
    $43 = ($42|0)==(0);
    if ($43) {
     $44 = ($39>>>0)<($7>>>0);
     $$$i$i$i$us = $38&1;
     $$$$i$i$i$us = $44 ? -1 : $$$i$i$i$us;
     $46 = $$$$i$i$i$us;
    } else {
     $46 = $42;
    }
    $45 = ($46|0)<(0);
    if (!($45)) {
     $__nd$0$in$lcssa = $__nd$0$in$us;
     label = 33;
     break L5;
    }
    $47 = (($__nd$0$in$us) + 4|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     $$lcssa = $47;$__nd$0$in$lcssa7 = $__nd$0$in$us;
     label = 32;
     break;
    } else {
     $__nd$0$in$us = $48;
    }
   }
  } else {
   $__nd$0$in = $1;
   while(1) {
    $52 = (($__nd$0$in) + 16|0);
    $53 = HEAP32[$10>>2]|0;
    $54 = HEAP8[$52>>0]|0;
    $55 = $54 & 1;
    $56 = ($55<<24>>24)==(0);
    if ($56) {
     $61 = $54&255;
     $62 = $61 >>> 1;
     $63 = (($52) + 1|0);
     $66 = $62;$68 = $63;
    } else {
     $57 = (($__nd$0$in) + 20|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = (($__nd$0$in) + 24|0);
     $60 = HEAP32[$59>>2]|0;
     $66 = $58;$68 = $60;
    }
    $64 = HEAP32[$9>>2]|0;
    $65 = ($66>>>0)<($53>>>0);
    $67 = $65 ? $66 : $53;
    $69 = (_memcmp($64,$68,$67)|0);
    $70 = ($69|0)==(0);
    if ($70) {
     $71 = ($53>>>0)<($66>>>0);
     $$$i$i$i4 = $65&1;
     $$$$i$i$i5 = $71 ? -1 : $$$i$i$i4;
     $73 = $$$$i$i$i5;
    } else {
     $73 = $69;
    }
    $72 = ($73|0)<(0);
    if ($72) {
     $74 = HEAP32[$__nd$0$in>>2]|0;
     $75 = ($74|0)==(0|0);
     if ($75) {
      $$lcssa9 = $__nd$0$in;$__nd$0$in$lcssa8 = $__nd$0$in;
      label = 24;
      break;
     } else {
      $__nd$0$in = $74;
      continue;
     }
    }
    if ($56) {
     $80 = $54&255;
     $81 = $80 >>> 1;
     $82 = (($52) + 1|0);
     $86 = $81;$88 = $82;
    } else {
     $76 = (($__nd$0$in) + 20|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($__nd$0$in) + 24|0);
     $79 = HEAP32[$78>>2]|0;
     $86 = $77;$88 = $79;
    }
    $83 = HEAP32[$10>>2]|0;
    $84 = HEAP32[$9>>2]|0;
    $85 = ($83>>>0)<($86>>>0);
    $87 = $85 ? $83 : $86;
    $89 = (_memcmp($88,$84,$87)|0);
    $90 = ($89|0)==(0);
    if ($90) {
     $91 = ($86>>>0)<($83>>>0);
     $$$i$i$i = $85&1;
     $$$$i$i$i = $91 ? -1 : $$$i$i$i;
     $93 = $$$$i$i$i;
    } else {
     $93 = $89;
    }
    $92 = ($93|0)<(0);
    if (!($92)) {
     $__nd$0$in$lcssa = $__nd$0$in;
     label = 33;
     break L5;
    }
    $94 = (($__nd$0$in) + 4|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)==(0|0);
    if ($96) {
     $$lcssa = $94;$__nd$0$in$lcssa7 = $__nd$0$in;
     label = 32;
     break;
    } else {
     $__nd$0$in = $95;
    }
   }
  }
 } while(0);
 if ((label|0) == 24) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa8;
  $$0 = $$lcssa9;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 32) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa7;
  $$0 = $$lcssa;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNKSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE14__count_uniqueIS7_EEjRKT_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$$$i$i$i$i = 0, $$$$i$i$i$i5 = 0, $$$i$i$i$i = 0, $$$i$i$i$i4 = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__rt$0$in = 0, $__rt$0$in$in$be = 0, $__rt$0$in6 = 0, $__rt$0$in7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $__rt$0$in6 = HEAP32[$0>>2]|0;
 $1 = ($__rt$0$in6|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP8[$__k>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 $5 = $2&255;
 $6 = $5 >>> 1;
 $7 = (($__k) + 1|0);
 $8 = (($__k) + 8|0);
 $9 = (($__k) + 4|0);
 $__rt$0$in7 = $__rt$0$in6;
 while(1) {
  $10 = (($__rt$0$in7) + 16|0);
  if ($4) {
   $25 = $6;
  } else {
   $11 = HEAP32[$9>>2]|0;
   $25 = $11;
  }
  $12 = HEAP8[$10>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $17 = $12&255;
   $18 = $17 >>> 1;
   $24 = $18;
  } else {
   $15 = (($__rt$0$in7) + 20|0);
   $16 = HEAP32[$15>>2]|0;
   $24 = $16;
  }
  if ($4) {
   $27 = $7;
  } else {
   $19 = HEAP32[$8>>2]|0;
   $27 = $19;
  }
  if ($14) {
   $22 = (($10) + 1|0);
   $28 = $22;
  } else {
   $20 = (($__rt$0$in7) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   $28 = $21;
  }
  $23 = ($24>>>0)<($25>>>0);
  $26 = $23 ? $24 : $25;
  $29 = (_memcmp($27,$28,$26)|0);
  $30 = ($29|0)==(0);
  if ($30) {
   $31 = ($25>>>0)<($24>>>0);
   $$$i$i$i$i4 = $23&1;
   $$$$i$i$i$i5 = $31 ? -1 : $$$i$i$i$i4;
   $33 = $$$$i$i$i$i5;
  } else {
   $33 = $29;
  }
  $32 = ($33|0)<(0);
  if ($32) {
   $__rt$0$in$in$be = $__rt$0$in7;
  } else {
   if ($14) {
    $36 = $12&255;
    $37 = $36 >>> 1;
    $45 = $37;
   } else {
    $34 = (($__rt$0$in7) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $45 = $35;
   }
   if ($4) {
    $44 = $6;
   } else {
    $38 = HEAP32[$9>>2]|0;
    $44 = $38;
   }
   if ($14) {
    $41 = (($10) + 1|0);
    $47 = $41;
   } else {
    $39 = (($__rt$0$in7) + 24|0);
    $40 = HEAP32[$39>>2]|0;
    $47 = $40;
   }
   if ($4) {
    $48 = $7;
   } else {
    $42 = HEAP32[$8>>2]|0;
    $48 = $42;
   }
   $43 = ($44>>>0)<($45>>>0);
   $46 = $43 ? $44 : $45;
   $49 = (_memcmp($47,$48,$46)|0);
   $50 = ($49|0)==(0);
   if ($50) {
    $51 = ($45>>>0)<($44>>>0);
    $$$i$i$i$i = $43&1;
    $$$$i$i$i$i = $51 ? -1 : $$$i$i$i$i;
    $53 = $$$$i$i$i$i;
   } else {
    $53 = $49;
   }
   $52 = ($53|0)<(0);
   if (!($52)) {
    $$0 = 1;
    label = 32;
    break;
   }
   $54 = (($__rt$0$in7) + 4|0);
   $__rt$0$in$in$be = $54;
  }
  $__rt$0$in = HEAP32[$__rt$0$in$in$be>>2]|0;
  $55 = ($__rt$0$in|0)==(0|0);
  if ($55) {
   $$0 = 0;
   label = 32;
   break;
  } else {
   $__rt$0$in7 = $__rt$0$in;
  }
 }
 if ((label|0) == 32) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL11DecodeValuePPKcS0_($agg$result,$buffer,$end) {
 $agg$result = $agg$result|0;
 $buffer = $buffer|0;
 $end = $end|0;
 var $$off = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $type_or_size$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$buffer>>2]|0;
 $2 = (($1) + 1|0);
 HEAP32[$buffer>>2] = $2;
 $3 = HEAP8[$1>>0]|0;
 $4 = $3&255;
 $5 = ($2>>>0)>($end>>>0);
 if ($5) {
  HEAP32[$agg$result>>2] = 255;
  $6 = (($agg$result) + 8|0);
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
  STACKTOP = sp;return;
 }
 $$off = (($3) + 127)<<24>>24;
 $7 = ($$off&255)<(124);
 if ($7) {
  HEAP32[$agg$result>>2] = 255;
  $8 = (($agg$result) + 8|0);
  ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
  STACKTOP = sp;return;
 }
 if ((($4|0) == 254)) {
  $9 = (($1) + 5|0);
  HEAP32[$buffer>>2] = $9;
  $10 = ($9>>>0)>($end>>>0);
  if ($10) {
   HEAP32[$agg$result>>2] = 255;
   $11 = (($agg$result) + 8|0);
   ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
   STACKTOP = sp;return;
  } else {
   $12 = HEAPU8[$2>>0]|(HEAPU8[$2+1>>0]<<8)|(HEAPU8[$2+2>>0]<<16)|(HEAPU8[$2+3>>0]<<24);
   HEAP32[$agg$result>>2] = 254;
   $13 = (($agg$result) + 4|0);
   HEAP32[$13>>2] = $12;
   $14 = (($agg$result) + 8|0);
   ;HEAP32[$14+0>>2]=0|0;HEAP32[$14+4>>2]=0|0;HEAP32[$14+8>>2]=0|0;
   STACKTOP = sp;return;
  }
 } else if ((($4|0) == 253)) {
  $15 = (($1) + 5|0);
  HEAP32[$buffer>>2] = $15;
  $16 = ($15>>>0)>($end>>>0);
  if ($16) {
   HEAP32[$agg$result>>2] = 255;
   $17 = (($agg$result) + 8|0);
   ;HEAP32[$17+0>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;
   STACKTOP = sp;return;
  } else {
   HEAP8[tempDoublePtr>>0]=HEAP8[$2>>0];HEAP8[tempDoublePtr+1>>0]=HEAP8[$2+1>>0];HEAP8[tempDoublePtr+2>>0]=HEAP8[$2+2>>0];HEAP8[tempDoublePtr+3>>0]=HEAP8[$2+3>>0];$18 = Math_fround(HEAPF32[tempDoublePtr>>2]);
   HEAP32[$agg$result>>2] = 253;
   $19 = (($agg$result) + 4|0);
   HEAPF32[$19>>2] = $18;
   $20 = (($agg$result) + 8|0);
   ;HEAP32[$20+0>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;
   STACKTOP = sp;return;
  }
 } else if ((($4|0) == 128)) {
  $21 = HEAPU8[$2>>0]|(HEAPU8[$2+1>>0]<<8)|(HEAPU8[$2+2>>0]<<16)|(HEAPU8[$2+3>>0]<<24);
  $22 = (($1) + 5|0);
  HEAP32[$buffer>>2] = $22;
  $23 = ($22>>>0)>($end>>>0);
  if ($23) {
   HEAP32[$agg$result>>2] = 255;
   $24 = (($agg$result) + 8|0);
   ;HEAP32[$24+0>>2]=0|0;HEAP32[$24+4>>2]=0|0;HEAP32[$24+8>>2]=0|0;
   STACKTOP = sp;return;
  } else {
   $26 = $22;$type_or_size$0 = $21;
  }
 } else {
  $26 = $2;$type_or_size$0 = $4;
 }
 $25 = (($26) + ($type_or_size$0)|0);
 HEAP32[$buffer>>2] = $25;
 $27 = ($25>>>0)>($end>>>0);
 if ($27) {
  HEAP32[$agg$result>>2] = 255;
  $28 = (($agg$result) + 8|0);
  ;HEAP32[$28+0>>2]=0|0;HEAP32[$28+4>>2]=0|0;HEAP32[$28+8>>2]=0|0;
  STACKTOP = sp;return;
 }
 $29 = ($type_or_size$0>>>0)>(4294967279);
 if ($29) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $30 = ($type_or_size$0>>>0)<(11);
 if ($30) {
  $31 = $type_or_size$0 << 1;
  $32 = $31&255;
  HEAP8[$0>>0] = $32;
  $33 = (($0) + 1|0);
  $$pre$phiZ2D = $0;$44 = $32;$__p$0$i$i$i = $33;
 } else {
  $34 = (($type_or_size$0) + 16)|0;
  $35 = $34 & -16;
  $36 = (__Znwj($35)|0);
  $37 = (($0) + 8|0);
  HEAP32[$37>>2] = $36;
  $38 = $35 | 1;
  HEAP32[$0>>2] = $38;
  $39 = (($0) + 4|0);
  HEAP32[$39>>2] = $type_or_size$0;
  $40 = $38&255;
  $$pre$phiZ2D = $0;$44 = $40;$__p$0$i$i$i = $36;
 }
 _memcpy(($__p$0$i$i$i|0),($26|0),($type_or_size$0|0))|0;
 $41 = (($__p$0$i$i$i) + ($type_or_size$0)|0);
 HEAP8[$41>>0] = 0;
 HEAP32[$agg$result>>2] = 128;
 $42 = (($agg$result) + 8|0);
 $43 = $44 & 1;
 $45 = ($43<<24>>24)==(0);
 L37: do {
  if ($45) {
   ;HEAP32[$42+0>>2]=HEAP32[$$pre$phiZ2D+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$$pre$phiZ2D+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$$pre$phiZ2D+8>>2]|0;
  } else {
   $46 = (($0) + 8|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($0) + 4|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49>>>0)>(4294967279);
   do {
    if ($50) {
     __THREW__ = 0;
     invoke_vi(3309,0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if (!($52)) {
      // unreachable;
     }
    } else {
     $53 = ($49>>>0)<(11);
     if ($53) {
      $54 = $49 << 1;
      $55 = $54&255;
      HEAP8[$42>>0] = $55;
      $56 = (($42) + 1|0);
      $__p$0$i$i$i$i$i = $56;
     } else {
      $57 = (($49) + 16)|0;
      $58 = $57 & -16;
      __THREW__ = 0;
      $59 = (invoke_ii(2988,($58|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break;
      }
      $62 = (($agg$result) + 16|0);
      HEAP32[$62>>2] = $59;
      $63 = $58 | 1;
      HEAP32[$42>>2] = $63;
      $64 = (($agg$result) + 12|0);
      HEAP32[$64>>2] = $49;
      $__p$0$i$i$i$i$i = $59;
     }
     _memcpy(($__p$0$i$i$i$i$i|0),($47|0),($49|0))|0;
     $65 = (($__p$0$i$i$i$i$i) + ($49)|0);
     HEAP8[$65>>0] = 0;
     break L37;
    }
   } while(0);
   $70 = ___cxa_find_matching_catch()|0;
   $71 = tempRet0;
   $72 = $44 & 1;
   $73 = ($72<<24>>24)==(0);
   if ($73) {
    ___resumeException($70|0);
    // unreachable;
   }
   __ZdlPv($47);
   ___resumeException($70|0);
   // unreachable;
  }
 } while(0);
 $66 = $44 & 1;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  STACKTOP = sp;return;
 }
 $68 = (($0) + 8|0);
 $69 = HEAP32[$68>>2]|0;
 __ZdlPv($69);
 STACKTOP = sp;return;
}
function __ZN11ContextGLES6CreateEi($glesVersion) {
 $glesVersion = $glesVersion|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $attrs = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $vararg_buffer = sp;
 $attrs = sp + 4|0;
 $0 = (_JS_SystemInfo_HasWebGL()|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 _emscripten_webgl_init_context_attributes(($attrs|0));
 $2 = (($attrs) + 4|0);
 HEAP32[$2>>2] = 1;
 $3 = (($attrs) + 8|0);
 HEAP32[$3>>2] = 1;
 $4 = (__Z18GetQualitySettingsv()|0);
 $5 = (($4) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8) + (($6*96)|0)|0) + 68|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)>(0);
 $12 = $11&1;
 $13 = (($attrs) + 12|0);
 HEAP32[$13>>2] = $12;
 HEAP32[$attrs>>2] = 1;
 $14 = (_emscripten_webgl_create_context((0|0),($attrs|0))|0);
 $15 = ($14|0)<(1);
 if ($15) {
  (_puts((1141200|0))|0);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $16 = (_emscripten_webgl_make_context_current(($14|0))|0);
 $17 = ($16|0)==(0);
 if ($17) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 HEAP32[$vararg_buffer>>2] = $16;
 (_printf((1141160|0),($vararg_buffer|0))|0);
 $$1 = 0;
 STACKTOP = sp;return ($$1|0);
}
function __ZN11ContextGLES7IsValidEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN11ContextGLES7DestroyEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_emscripten_webgl_get_current_context()|0);
 (_emscripten_webgl_destroy_context(($0|0))|0);
 STACKTOP = sp;return;
}
function __ZN11ContextGLES18HandleInvalidStateEPb($new_context) {
 $new_context = $new_context|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$new_context>>0] = 0;
 STACKTOP = sp;return 1;
}
function __ZN11ContextGLES8ActivateEi($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN11ContextGLES7AcquireEi($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN11ContextGLES7ReleaseEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN11ContextGLES7PresentEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_JS_SystemInfo_HasWebGL()|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  _SDL_GL_SwapBuffers();
 }
 STACKTOP = sp;return;
}
function __ZN7Cursors9SetCursorEP9Texture2D8Vector2f10CursorMode($texture,$hotSpot,$cursorMode) {
 $texture = $texture|0;
 $hotSpot = $hotSpot|0;
 $cursorMode = $cursorMode|0;
 var $$byval_copy9 = 0, $$index = 0, $$index3 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allocPtr$0 = 0, $i$05 = 0, $image = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy9 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $image = sp + 8|0;
 $2 = $hotSpot;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = 1141240;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 HEAP32[1141232>>2] = 0;
 $12 = ($texture|0)==(0|0);
 if ($12) {
  _JS_Cursor_SetShow(1);
  STACKTOP = sp;return;
 }
 $13 = ($cursorMode|0)==(1);
 if ($13) {
  _JS_Cursor_SetShow(0);
  $14 = (($texture) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  HEAP32[1141232>>2] = $15;
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$texture>>2]|0;
 $17 = (($16) + 104|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_ii[$18 & 4095]($texture)|0);
 $20 = HEAP32[$texture>>2]|0;
 $21 = (($20) + 108|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_ii[$22 & 4095]($texture)|0);
 $24 = $19 << 2;
 $25 = Math_imul($23, $24)|0;
 $26 = (($25) + 62)|0;
 $27 = (($25) + 77)|0;
 $28 = ($27>>>0)<(2000);
 if ($28) {
  $29 = STACKTOP; STACKTOP = STACKTOP + ((((1*$27)|0)+15)&-16)|0;;
  $39 = 0;$allocPtr$0 = $29;
 } else {
  $30 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $30;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
  $31 = (invoke_iiiiiii(102,($27|0),16,($$byval_copy9|0),0,(1141248|0),43)|0);
  $32 = __THREW__; __THREW__ = 0;
  $33 = $32&1;
  if ($33) {
   $34 = ___cxa_find_matching_catch()|0;
   $35 = tempRet0;
   $$index = $34;$$index3 = $35;$101 = $0;
   ___resumeException($$index|0);
   // unreachable;
  } else {
   $39 = $31;$allocPtr$0 = $31;
  }
 }
 $43 = $allocPtr$0;
 $44 = (($43) + 15)|0;
 $45 = $44 & -16;
 $46 = $45;
 $47 = $45;
 HEAP16[$47>>1] = 0;
 $48 = (($46) + 2|0);
 HEAP16[$48>>1] = 2;
 $49 = (($46) + 4|0);
 HEAP16[$49>>1] = 1;
 $50 = (($46) + 6|0);
 $51 = $19&255;
 HEAP8[$50>>0] = $51;
 $52 = (($46) + 7|0);
 $53 = $23&255;
 HEAP8[$52>>0] = $53;
 $54 = (($46) + 8|0);
 HEAP8[$54>>0] = 0;
 $55 = (($46) + 9|0);
 HEAP8[$55>>0] = 0;
 $56 = (($46) + 10|0);
 $57 = Math_fround(HEAPF32[$hotSpot>>2]);
 $58 = (~~(($57))&65535);
 HEAP16[$56>>1] = $58;
 $59 = (($46) + 12|0);
 $60 = (($hotSpot) + 4|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = (~~(($61))&65535);
 HEAP16[$59>>1] = $62;
 $63 = (($46) + 14|0);
 $64 = (($25) + 40)|0;
 HEAP16[$63>>1]=$64&65535;HEAP16[$63+2>>1]=$64>>>16;
 $65 = (($46) + 18|0);
 HEAP16[$65>>1]=22&65535;HEAP16[$65+2>>1]=22>>>16;
 $66 = (($46) + 22|0);
 HEAP16[$66>>1]=40&65535;HEAP16[$66+2>>1]=40>>>16;
 $67 = (($46) + 26|0);
 HEAP16[$67>>1]=$19&65535;HEAP16[$67+2>>1]=$19>>>16;
 $68 = (($46) + 30|0);
 $69 = $23 << 1;
 HEAP16[$68>>1]=$69&65535;HEAP16[$68+2>>1]=$69>>>16;
 $70 = (($46) + 34|0);
 HEAP16[$70>>1] = 1;
 $71 = (($46) + 36|0);
 HEAP16[$71>>1] = 32;
 $72 = (($46) + 38|0);
 $73 = (($46) + 62|0);
 dest=$72+0|0; stop=dest+24|0; do { HEAP16[dest>>1]=0|0; dest=dest+2|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_viiiiii(125,($image|0),($19|0),($23|0),($24|0),5,($73|0));
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if (!($75)) {
  $76 = HEAP32[$texture>>2]|0;
  $77 = (($76) + 96|0);
  $78 = HEAP32[$77>>2]|0;
  __THREW__ = 0;
  (invoke_iiii($78|0,($texture|0),($image|0),0)|0);
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if (!($80)) {
   $81 = ($25|0)>(0);
   if ($81) {
    $i$05 = 0;
    while(1) {
     $82 = $i$05 | 3;
     $$sum = (($82) + 62)|0;
     $83 = (($46) + ($$sum)|0);
     $84 = HEAP8[$83>>0]|0;
     $$sum2 = (($i$05) + 62)|0;
     $85 = (($46) + ($$sum2)|0);
     $86 = HEAP8[$85>>0]|0;
     HEAP8[$83>>0] = $86;
     HEAP8[$85>>0] = $84;
     $87 = $i$05 | 2;
     $$sum3 = (($87) + 62)|0;
     $88 = (($46) + ($$sum3)|0);
     $89 = HEAP8[$88>>0]|0;
     $90 = $i$05 | 1;
     $$sum4 = (($90) + 62)|0;
     $91 = (($46) + ($$sum4)|0);
     $92 = HEAP8[$91>>0]|0;
     HEAP8[$88>>0] = $92;
     HEAP8[$91>>0] = $89;
     $93 = (($i$05) + 4)|0;
     $94 = ($93|0)<($25|0);
     if ($94) {
      $i$05 = $93;
     } else {
      break;
     }
    }
   }
   __THREW__ = 0;
   invoke_vii(3464,($46|0),($26|0));
   $95 = __THREW__; __THREW__ = 0;
   $96 = $95&1;
   if (!($96)) {
    $97 = ($39|0)==(0|0);
    if ($97) {
     STACKTOP = sp;return;
    }
    $98 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $98;
    ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($39,$$byval_copy9);
    STACKTOP = sp;return;
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $38 = ($39|0)==(0|0);
 if ($38) {
  $$index = $36;$$index3 = $37;$101 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
 $40 = HEAP32[628512>>2]|0;
 HEAP32[$0>>2] = $40;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($39|0),($$byval_copy9|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $99 = ___cxa_find_matching_catch(0|0)|0;
  $100 = tempRet0;
  ___clang_call_terminate($99);
  // unreachable;
 } else {
  $$index = $36;$$index3 = $37;$101 = $0;
  ___resumeException($$index|0);
  // unreachable;
 }
}
function __ZN7Cursors17InitializeCursorsEP9Texture2D8Vector2f($defaultCursorTexture,$defaultCursorHotSpot) {
 $defaultCursorTexture = $defaultCursorTexture|0;
 $defaultCursorHotSpot = $defaultCursorHotSpot|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $defaultCursorHotSpot;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZN7Cursors9SetCursorEP9Texture2D8Vector2f10CursorMode($defaultCursorTexture,$tmpcast$byval_copy,0);
 STACKTOP = sp;return;
}
function __ZN7Cursors17GetSoftwareCursorEv() {
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, $temp$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[1141232>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[$0>>2] = $1;
 $3 = HEAP32[560624>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  label = 10;
 } else {
  $5 = (($3) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($3) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  do {
   if ($9) {
    $10 = (($3) + 28|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($3) + 32|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + ($13<<3)|0);
    $30 = $14;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($pos$i$i$i,$3,$0);
    $15 = HEAP32[$pos$i$i$i>>2]|0;
    $16 = ($15|0)==(-1);
    $17 = (($3) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    if ($16) {
     $19 = (($3) + 32|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + ($20<<3)|0);
     $30 = $21;
     break;
    } else {
     $22 = (($18) + ($15<<3)|0);
     $30 = $22;
     break;
    }
   }
  } while(0);
  $23 = HEAP32[560624>>2]|0;
  $24 = (($23) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 32|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + ($27<<3)|0);
  $29 = ($30|0)==($28|0);
  if ($29) {
   label = 10;
  } else {
   $31 = (($30) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(0|0);
   if ($33) {
    label = 10;
   } else {
    $temp$0$i = $32;
   }
  }
 }
 if ((label|0) == 10) {
  $34 = HEAP32[1141232>>2]|0;
  $35 = (__Z31ReadObjectFromPersistentManageri($34)|0);
  $temp$0$i = $35;
 }
 $$0$i = $temp$0$i;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN7Cursors16GetCursorHotspotEv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 1141240;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $agg$result;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 STACKTOP = sp;return;
}
function _main($argc,$argv) {
 $argc = $argc|0;
 $argv = $argv|0;
 var $$0 = 0, $$0$i = 0, $$1 = 0, $$13 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i12 = 0, $phitmp$i$i = 0, $temp$0$i = 0, $tmpcast$byval_copy = 0, $url = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp + 52|0;
 $1 = sp + 40|0;
 $2 = sp + 16|0;
 $url = sp + 28|0;
 $3 = sp;
 __Z9SetupArgviPPKc($argc,$argv);
 $4 = (_SDL_Init(512)|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (_SDL_GetError()|0);
  HEAP32[$tmpcast$byval_copy>>2] = $6;
  (_printf((1141256|0),($tmpcast$byval_copy|0))|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 _emscripten_asm_const((1141288|0));
 (_SDL_InitSubSystem(512)|0);
 _SDL_StartTextInput();
 _GC_disable();
 _InitializeScriptingBackend();
 __Z17RuntimeInitializev();
 HEAP8[$1>>0] = 0;
 $7 = (($1) + 1|0);
 HEAP8[$7>>0] = 0;
 HEAP8[$2>>0] = 0;
 $8 = (($2) + 1|0);
 HEAP8[$8>>0] = 0;
 __THREW__ = 0;
 $9 = (invoke_iii(2715,($1|0),($2|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  $24 = HEAP8[$2>>0]|0;
  $25 = $24 & 1;
  $26 = ($25<<24>>24)==(0);
  if (!($26)) {
   $27 = (($2) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   __ZdlPv($28);
  }
  $29 = HEAP8[$1>>0]|0;
  $30 = $29 & 1;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $$1 = $23;$$13 = $22;
   ___resumeException($$13|0);
   // unreachable;
  }
  $32 = (($1) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  __ZdlPv($33);
  $$1 = $23;$$13 = $22;
  ___resumeException($$13|0);
  // unreachable;
 }
 $12 = HEAP8[$2>>0]|0;
 $13 = $12 & 1;
 $14 = ($13<<24>>24)==(0);
 if (!($14)) {
  $15 = (($2) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  __ZdlPv($16);
 }
 $17 = HEAP8[$1>>0]|0;
 $18 = $17 & 1;
 $19 = ($18<<24>>24)==(0);
 if (!($19)) {
  $20 = (($1) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  __ZdlPv($21);
 }
 if (!($9)) {
  _printf_console(1141608,$tmpcast$byval_copy);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = (__Z24PlayerInitEngineGraphicsb(0)|0);
 if (!($34)) {
  _printf_console(1141608,$tmpcast$byval_copy);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $35 = (__Z19GetScriptingManagerv()|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + 100|0);
 $38 = HEAP32[$37>>2]|0;
 FUNCTION_TABLE_vi[$38 & 4095]($35);
 $39 = (_JS_SystemInfo_GetDocumentURL((0|0),0)|0);
 $40 = ($39>>>0)>(4294967279);
 if ($40) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $41 = ($39>>>0)<(11);
 if ($41) {
  $42 = $39 << 1;
  $43 = $42&255;
  HEAP8[$url>>0] = $43;
  $44 = (($url) + 1|0);
  $$pre$phiZ2D = $url;$54 = $43;$__p$0$i$i$i12 = $44;
 } else {
  $45 = (($39) + 16)|0;
  $46 = $45 & -16;
  $47 = (__Znwj($46)|0);
  $48 = (($url) + 8|0);
  HEAP32[$48>>2] = $47;
  $49 = $46 | 1;
  HEAP32[$url>>2] = $49;
  $50 = (($url) + 4|0);
  HEAP32[$50>>2] = $39;
  $51 = $49&255;
  $$pre$phiZ2D = $url;$54 = $51;$__p$0$i$i$i12 = $47;
 }
 _memset(($__p$0$i$i$i12|0),0,($39|0))|0;
 $52 = (($__p$0$i$i$i12) + ($39)|0);
 HEAP8[$52>>0] = 0;
 $53 = $54 & 1;
 $55 = ($53<<24>>24)==(0);
 if ($55) {
  $58 = (($url) + 1|0);
  $65 = $58;
 } else {
  $56 = (($url) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  $65 = $57;
 }
 $59 = $54 & 1;
 $60 = ($59<<24>>24)==(0);
 if ($60) {
  $63 = $54&255;
  $64 = $63 >>> 1;
  $66 = $64;
 } else {
  $61 = (($url) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $66 = $62;
 }
 __THREW__ = 0;
 (invoke_iii(2716,($65|0),($66|0))|0);
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 L44: do {
  if (!($68)) {
   __THREW__ = 0;
   $69 = (invoke_i(127)|0);
   $70 = __THREW__; __THREW__ = 0;
   $71 = $70&1;
   if (!($71)) {
    $72 = (($69) + 220|0);
    $73 = HEAP8[$$pre$phiZ2D>>0]|0;
    $74 = $73 & 1;
    $75 = ($74<<24>>24)==(0);
    if ($75) {
     $80 = (($url) + 1|0);
     $81 = $73&255;
     $82 = $81 >>> 1;
     $91 = $82;$99 = $80;
    } else {
     $76 = (($url) + 8|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = (($url) + 4|0);
     $79 = HEAP32[$78>>2]|0;
     $91 = $79;$99 = $77;
    }
    $83 = HEAP8[$72>>0]|0;
    $84 = $83 & 1;
    $85 = ($84<<24>>24)==(0);
    if ($85) {
     $90 = 10;$93 = $83;
    } else {
     $86 = HEAP32[$72>>2]|0;
     $87 = $86 & -2;
     $phitmp$i$i = (($87) + -1)|0;
     $88 = $86&255;
     $90 = $phitmp$i$i;$93 = $88;
    }
    $89 = ($90>>>0)<($91>>>0);
    $92 = $93 & 1;
    $94 = ($92<<24>>24)==(0);
    do {
     if ($89) {
      if ($94) {
       $109 = $93&255;
       $110 = $109 >>> 1;
       $112 = $110;
      } else {
       $107 = (($69) + 224|0);
       $108 = HEAP32[$107>>2]|0;
       $112 = $108;
      }
      $111 = (($91) - ($90))|0;
      __THREW__ = 0;
      invoke_viiiiiiii(22,($72|0),($90|0),($111|0),($112|0),0,($112|0),($91|0),($99|0));
      $113 = __THREW__; __THREW__ = 0;
      $114 = $113&1;
      if ($114) {
       break L44;
      }
     } else {
      if ($94) {
       $97 = (($72) + 1|0);
       $98 = $97;
      } else {
       $95 = (($69) + 228|0);
       $96 = HEAP32[$95>>2]|0;
       $98 = $96;
      }
      _memmove(($98|0),($99|0),($91|0))|0;
      $100 = (($98) + ($91)|0);
      HEAP8[$100>>0] = 0;
      $101 = HEAP8[$72>>0]|0;
      $102 = $101 & 1;
      $103 = ($102<<24>>24)==(0);
      if ($103) {
       $105 = $91 << 1;
       $106 = $105&255;
       HEAP8[$72>>0] = $106;
       break;
      } else {
       $104 = (($69) + 224|0);
       HEAP32[$104>>2] = $91;
       break;
      }
     }
    } while(0);
    __THREW__ = 0;
    invoke_v(268);
    $115 = __THREW__; __THREW__ = 0;
    $116 = $115&1;
    if (!($116)) {
     __THREW__ = 0;
     $117 = (invoke_i(127)|0);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if (!($119)) {
      $120 = (($117) + 60|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = ($121|0)==(0);
      if ($122) {
       $$0$i = 0;
      } else {
       HEAP32[$0>>2] = $121;
       $123 = HEAP32[560624>>2]|0;
       $124 = ($123|0)==(0|0);
       do {
        if ($124) {
         label = 56;
        } else {
         $125 = (($123) + 36|0);
         $126 = HEAP32[$125>>2]|0;
         $127 = (($123) + 4|0);
         $128 = HEAP32[$127>>2]|0;
         $129 = ($126|0)==($128|0);
         do {
          if ($129) {
           $130 = (($123) + 28|0);
           $131 = HEAP32[$130>>2]|0;
           $132 = (($123) + 32|0);
           $133 = HEAP32[$132>>2]|0;
           $134 = (($131) + ($133<<3)|0);
           $150 = $134;
          } else {
           __ZNK15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS2_($tmpcast$byval_copy,$123,$0);
           $135 = HEAP32[$tmpcast$byval_copy>>2]|0;
           $136 = ($135|0)==(-1);
           $137 = (($123) + 28|0);
           $138 = HEAP32[$137>>2]|0;
           if ($136) {
            $139 = (($123) + 32|0);
            $140 = HEAP32[$139>>2]|0;
            $141 = (($138) + ($140<<3)|0);
            $150 = $141;
            break;
           } else {
            $142 = (($138) + ($135<<3)|0);
            $150 = $142;
            break;
           }
          }
         } while(0);
         $143 = HEAP32[560624>>2]|0;
         $144 = (($143) + 28|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = (($143) + 32|0);
         $147 = HEAP32[$146>>2]|0;
         $148 = (($145) + ($147<<3)|0);
         $149 = ($150|0)==($148|0);
         if ($149) {
          label = 56;
          break;
         }
         $151 = (($150) + 4|0);
         $152 = HEAP32[$151>>2]|0;
         $153 = ($152|0)==(0|0);
         if ($153) {
          label = 56;
         } else {
          $temp$0$i = $152;
         }
        }
       } while(0);
       if ((label|0) == 56) {
        __THREW__ = 0;
        $154 = (invoke_ii(3215,($121|0))|0);
        $155 = __THREW__; __THREW__ = 0;
        $156 = $155&1;
        if ($156) {
         break;
        } else {
         $temp$0$i = $154;
        }
       }
       $$0$i = $temp$0$i;
      }
      __THREW__ = 0;
      $157 = (invoke_i(127)|0);
      $158 = __THREW__; __THREW__ = 0;
      $159 = $158&1;
      if (!($159)) {
       $160 = (($157) + 64|0);
       $161 = $160;
       $162 = $161;
       $163 = HEAP32[$162>>2]|0;
       $164 = (($161) + 4)|0;
       $165 = $164;
       $166 = HEAP32[$165>>2]|0;
       $167 = $3;
       $168 = $167;
       HEAP32[$168>>2] = $163;
       $169 = (($167) + 4)|0;
       $170 = $169;
       HEAP32[$170>>2] = $166;
       __THREW__ = 0;
       ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
       invoke_vii(3465,($$0$i|0),($tmpcast$byval_copy|0));
       $171 = __THREW__; __THREW__ = 0;
       $172 = $171&1;
       if ($172) {
        break;
       }
       __THREW__ = 0;
       $173 = (invoke_i(93)|0);
       $174 = __THREW__; __THREW__ = 0;
       $175 = $174&1;
       if ($175) {
        break;
       }
       $176 = HEAP32[$173>>2]|0;
       $177 = (($176) + 16|0);
       $178 = HEAP32[$177>>2]|0;
       __THREW__ = 0;
       $179 = (invoke_i(127)|0);
       $180 = __THREW__; __THREW__ = 0;
       $181 = $180&1;
       if ($181) {
        break;
       }
       $182 = (($179) + 108|0);
       $183 = HEAP32[$182>>2]|0;
       __THREW__ = 0;
       $184 = (invoke_i(127)|0);
       $185 = __THREW__; __THREW__ = 0;
       $186 = $185&1;
       if ($186) {
        break;
       }
       $187 = (($184) + 112|0);
       $188 = HEAP32[$187>>2]|0;
       __THREW__ = 0;
       (invoke_iiiiii($178|0,($173|0),($183|0),($188|0),0,0)|0);
       $189 = __THREW__; __THREW__ = 0;
       $190 = $189&1;
       if ($190) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(2086,(269|0),0,1);
       $191 = __THREW__; __THREW__ = 0;
       $192 = $191&1;
       if ($192) {
        break;
       }
       $193 = HEAP8[$$pre$phiZ2D>>0]|0;
       $194 = $193 & 1;
       $195 = ($194<<24>>24)==(0);
       if ($195) {
        $$0 = 0;
        STACKTOP = sp;return ($$0|0);
       }
       $196 = (($url) + 8|0);
       $197 = HEAP32[$196>>2]|0;
       __ZdlPv($197);
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $198 = ___cxa_find_matching_catch()|0;
 $199 = tempRet0;
 $200 = HEAP8[$$pre$phiZ2D>>0]|0;
 $201 = $200 & 1;
 $202 = ($201<<24>>24)==(0);
 if ($202) {
  $$1 = $199;$$13 = $198;
  ___resumeException($$13|0);
  // unreachable;
 }
 $203 = (($url) + 8|0);
 $204 = HEAP32[$203>>2]|0;
 __ZdlPv($204);
 $$1 = $199;$$13 = $198;
 ___resumeException($$13|0);
 // unreachable;
 return 0|0;
}
function __ZL8mainloopv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _GC_enable();
 (_GC_collect_a_little()|0);
 _GC_disable();
 $0 = (__Z16GetScreenManagerv()|0);
 __ZN18ScreenManagerWebGL6UpdateEv($0);
 $1 = (__Z25GetShouldShowSplashScreenv()|0);
 if ($1) {
  $2 = (__Z26IsSplashScreenFadeCompletev()|0);
  if (!($2)) {
   __Z16DrawSplashScreenb(1);
   STACKTOP = sp;return;
  }
 }
 __Z11UpdateInputv();
 $3 = (__Z14GetPlayerPausev()|0);
 $4 = ($3|0)==(2);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__Z14GetPlayerPausev()|0);
 $6 = ($5|0)==(1);
 if ($6) {
  __Z14SetPlayerPause11PlayerPause(2);
 }
 __Z10PlayerLoopbbP10IHookEvent(0,1,0);
 STACKTOP = sp;return;
}
function __Z10ResetInputv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z20ResetInputAfterPausev() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z35InitEmscriptenSDLScancodeToUnitySDLv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[1146872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 HEAP8[1146872>>0] = 1;
 _memset((1141640|0),0,5228)|0;
 HEAP32[((1141640 + 52|0))>>2] = 13;
 HEAP32[((1141640 + 108|0))>>2] = 27;
 HEAP32[((1141640 + 32|0))>>2] = 8;
 HEAP32[((1141640 + 36|0))>>2] = 9;
 HEAP32[((1141640 + 128|0))>>2] = 32;
 HEAP32[((1141640 + 132|0))>>2] = 33;
 HEAP32[((1141640 + 136|0))>>2] = 34;
 HEAP32[((1141640 + 140|0))>>2] = 35;
 HEAP32[((1141640 + 144|0))>>2] = 36;
 HEAP32[((1141640 + 152|0))>>2] = 38;
 HEAP32[((1141640 + 156|0))>>2] = 39;
 HEAP32[((1141640 + 160|0))>>2] = 40;
 HEAP32[((1141640 + 164|0))>>2] = 41;
 HEAP32[((1141640 + 168|0))>>2] = 42;
 HEAP32[((1141640 + 172|0))>>2] = 43;
 HEAP32[((1141640 + 176|0))>>2] = 44;
 HEAP32[((1141640 + 180|0))>>2] = 45;
 HEAP32[((1141640 + 184|0))>>2] = 46;
 HEAP32[((1141640 + 188|0))>>2] = 47;
 HEAP32[((1141640 + 192|0))>>2] = 48;
 HEAP32[((1141640 + 196|0))>>2] = 49;
 HEAP32[((1141640 + 200|0))>>2] = 50;
 HEAP32[((1141640 + 204|0))>>2] = 51;
 HEAP32[((1141640 + 208|0))>>2] = 52;
 HEAP32[((1141640 + 212|0))>>2] = 53;
 HEAP32[((1141640 + 216|0))>>2] = 54;
 HEAP32[((1141640 + 220|0))>>2] = 55;
 HEAP32[((1141640 + 224|0))>>2] = 56;
 HEAP32[((1141640 + 228|0))>>2] = 57;
 HEAP32[((1141640 + 232|0))>>2] = 58;
 HEAP32[((1141640 + 236|0))>>2] = 59;
 HEAP32[((1141640 + 240|0))>>2] = 60;
 HEAP32[((1141640 + 244|0))>>2] = 61;
 HEAP32[((1141640 + 248|0))>>2] = 62;
 HEAP32[((1141640 + 252|0))>>2] = 63;
 HEAP32[((1141640 + 256|0))>>2] = 64;
 HEAP32[((1141640 + 364|0))>>2] = 91;
 HEAP32[((1141640 + 368|0))>>2] = 92;
 HEAP32[((1141640 + 372|0))>>2] = 93;
 HEAP32[((1141640 + 376|0))>>2] = 94;
 HEAP32[((1141640 + 380|0))>>2] = 95;
 HEAP32[((1141640 + 384|0))>>2] = 96;
 HEAP32[((1141640 + 388|0))>>2] = 97;
 HEAP32[((1141640 + 392|0))>>2] = 98;
 HEAP32[((1141640 + 396|0))>>2] = 99;
 HEAP32[((1141640 + 400|0))>>2] = 100;
 HEAP32[((1141640 + 404|0))>>2] = 101;
 HEAP32[((1141640 + 408|0))>>2] = 102;
 HEAP32[((1141640 + 412|0))>>2] = 103;
 HEAP32[((1141640 + 416|0))>>2] = 104;
 HEAP32[((1141640 + 420|0))>>2] = 105;
 HEAP32[((1141640 + 424|0))>>2] = 106;
 HEAP32[((1141640 + 428|0))>>2] = 107;
 HEAP32[((1141640 + 432|0))>>2] = 108;
 HEAP32[((1141640 + 436|0))>>2] = 109;
 HEAP32[((1141640 + 440|0))>>2] = 110;
 HEAP32[((1141640 + 444|0))>>2] = 111;
 HEAP32[((1141640 + 448|0))>>2] = 112;
 HEAP32[((1141640 + 452|0))>>2] = 113;
 HEAP32[((1141640 + 456|0))>>2] = 114;
 HEAP32[((1141640 + 460|0))>>2] = 115;
 HEAP32[((1141640 + 464|0))>>2] = 116;
 HEAP32[((1141640 + 468|0))>>2] = 117;
 HEAP32[((1141640 + 472|0))>>2] = 118;
 HEAP32[((1141640 + 476|0))>>2] = 119;
 HEAP32[((1141640 + 480|0))>>2] = 120;
 HEAP32[((1141640 + 484|0))>>2] = 121;
 HEAP32[((1141640 + 488|0))>>2] = 122;
 HEAP32[((1141640 + 4324|0))>>2] = 301;
 HEAP32[((1141640 + 4328|0))>>2] = 282;
 HEAP32[((1141640 + 4332|0))>>2] = 283;
 HEAP32[((1141640 + 4336|0))>>2] = 284;
 HEAP32[((1141640 + 4340|0))>>2] = 285;
 HEAP32[((1141640 + 4344|0))>>2] = 286;
 HEAP32[((1141640 + 4348|0))>>2] = 287;
 HEAP32[((1141640 + 4352|0))>>2] = 288;
 HEAP32[((1141640 + 4356|0))>>2] = 289;
 HEAP32[((1141640 + 4360|0))>>2] = 290;
 HEAP32[((1141640 + 4364|0))>>2] = 291;
 HEAP32[((1141640 + 4368|0))>>2] = 292;
 HEAP32[((1141640 + 4372|0))>>2] = 293;
 HEAP32[((1141640 + 4384|0))>>2] = 19;
 HEAP32[((1141640 + 4388|0))>>2] = 277;
 HEAP32[((1141640 + 4392|0))>>2] = 278;
 HEAP32[((1141640 + 4396|0))>>2] = 280;
 HEAP32[((1141640 + 508|0))>>2] = 127;
 HEAP32[((1141640 + 4404|0))>>2] = 279;
 HEAP32[((1141640 + 4408|0))>>2] = 281;
 HEAP32[((1141640 + 4412|0))>>2] = 275;
 HEAP32[((1141640 + 4416|0))>>2] = 276;
 HEAP32[((1141640 + 4420|0))>>2] = 274;
 HEAP32[((1141640 + 4424|0))>>2] = 273;
 HEAP32[((1141640 + 4432|0))>>2] = 267;
 HEAP32[((1141640 + 4436|0))>>2] = 268;
 HEAP32[((1141640 + 4440|0))>>2] = 269;
 HEAP32[((1141640 + 4444|0))>>2] = 270;
 HEAP32[((1141640 + 4448|0))>>2] = 271;
 HEAP32[((1141640 + 4492|0))>>2] = 266;
 HEAP32[((1141640 + 4504|0))>>2] = 320;
 HEAP32[((1141640 + 4508|0))>>2] = 272;
 HEAP32[((1141640 + 4512|0))>>2] = 294;
 HEAP32[((1141640 + 4516|0))>>2] = 295;
 HEAP32[((1141640 + 4520|0))>>2] = 296;
 HEAP32[((1141640 + 4564|0))>>2] = 315;
 HEAP32[((1141640 + 4568|0))>>2] = 319;
 HEAP32[((1141640 + 4584|0))>>2] = 322;
 HEAP32[((1141640 + 4712|0))>>2] = 317;
 HEAP32[((1141640 + 4720|0))>>2] = 12;
 HEAP32[((1141640 + 4992|0))>>2] = 306;
 HEAP32[((1141640 + 4996|0))>>2] = 304;
 HEAP32[((1141640 + 5000|0))>>2] = 308;
 HEAP32[((1141640 + 5004|0))>>2] = 310;
 HEAP32[((1141640 + 5008|0))>>2] = 305;
 HEAP32[((1141640 + 5012|0))>>2] = 303;
 HEAP32[((1141640 + 5016|0))>>2] = 307;
 HEAP32[((1141640 + 5020|0))>>2] = 309;
 HEAP32[((1141640 + 5124|0))>>2] = 313;
 STACKTOP = sp;return;
}
function __Z20InitGUIInputEventSDLR10InputEventRKN3SDL9SDL_EventE($ie,$event) {
 $ie = $ie|0;
 $event = $event|0;
 var $$0 = 0, $$0$i = 0, $$0$i9 = 0, $$01 = 0, $$byval_copy6 = 0, $$lcssa = 0, $$pre = 0, $$pre37 = 0, $$pre38 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0.0, $124 = Math_fround(0), $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = Math_fround(0), $181 = Math_fround(0), $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = Math_fround(0), $192 = 0, $193 = 0, $194 = 0, $195 = Math_fround(0), $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = Math_fround(0), $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = Math_fround(0), $214 = Math_fround(0), $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = Math_fround(0), $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = Math_fround(0), $255 = Math_fround(0), $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__p$0$i$i$i = 0, $i$034 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $modifiers$0$i = 0, $modifiers$0$i10 = 0, $modifiers$0$i14 = 0, $modifiers$1$i = 0, $modifiers$1$i11 = 0, $modifiers$1$i15 = 0, $modifiers$2$i = 0, $modifiers$2$i12 = 0, $modifiers$2$i16 = 0, $modifiers$3$i = 0, $modifiers$3$i13 = 0, $modifiers$3$i17 = 0, $utf16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy6 = sp + 36|0;
 $0 = sp;
 $utf16 = sp + 8|0;
 $1 = sp + 24|0;
 __ZN10InputEvent4InitEv($ie);
 $2 = HEAP32[$event>>2]|0;
 switch ($2|0) {
 case 771:  {
  HEAP32[$ie>>2] = 4;
  $221 = (__Z15GetInputManagerv()|0);
  $222 = (($221) + 56|0);
  $223 = HEAP32[$222>>2]|0;
  $224 = (($223) + 36|0);
  $225 = HEAP32[$224>>2]|0;
  $226 = (($221) + 40|0);
  $227 = HEAP32[$226>>2]|0;
  $228 = (($227) + 36|0);
  $229 = HEAP32[$228>>2]|0;
  $230 = $229 | $225;
  $231 = $230 & 98304;
  $232 = ($231|0)!=(0);
  $modifiers$0$i14 = $232&1;
  $233 = $230 & 393216;
  $234 = ($233|0)!=(0);
  $235 = $modifiers$0$i14 | 2;
  $modifiers$1$i15 = $234 ? $235 : $modifiers$0$i14;
  $236 = $230 & 1572864;
  $237 = ($236|0)!=(0);
  $238 = $modifiers$1$i15 | 4;
  $modifiers$2$i16 = $237 ? $238 : $modifiers$1$i15;
  $239 = $230 & 6291456;
  $240 = ($239|0)!=(0);
  $241 = $modifiers$2$i16 | 8;
  $modifiers$3$i17 = $240 ? $241 : $modifiers$2$i16;
  $242 = (($ie) + 24|0);
  HEAP32[$242>>2] = $modifiers$3$i17;
  $243 = (($ie) + 4|0);
  $244 = (__Z15GetInputManagerv()|0);
  $245 = (($244) + 100|0);
  $246 = Math_fround(HEAPF32[$245>>2]);
  $247 = (($244) + 104|0);
  $248 = Math_fround(HEAPF32[$247>>2]);
  $249 = (__Z16GetScreenManagerv()|0);
  $250 = HEAP32[$249>>2]|0;
  $251 = (($250) + 84|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = (FUNCTION_TABLE_ii[$252 & 4095]($249)|0);
  $254 = (Math_fround(($253|0)));
  $255 = Math_fround($254 - $248);
  $256 = (HEAPF32[tempDoublePtr>>2]=$246,HEAP32[tempDoublePtr>>2]|0);
  $257 = (HEAPF32[tempDoublePtr>>2]=$255,HEAP32[tempDoublePtr>>2]|0);
  $258 = $243;
  $259 = $258;
  HEAP32[$259>>2] = $256;
  $260 = (($258) + 4)|0;
  $261 = $260;
  HEAP32[$261>>2] = $257;
  HEAP32[$utf16>>2] = 0;
  $262 = (($utf16) + 8|0);
  HEAP32[$262>>2] = 0;
  $263 = (($utf16) + 12|0);
  HEAP32[$263>>2] = 0;
  $264 = (($utf16) + 4|0);
  HEAP32[$264>>2] = 61;
  $265 = (($event) + 8|0);
  $266 = (_strlen(($265|0))|0);
  $267 = ($266>>>0)>(4294967279);
  L3: do {
   if ($267) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $268 = __THREW__; __THREW__ = 0;
    $269 = $268&1;
    if ($269) {
     label = 38;
    } else {
     // unreachable;
    }
   } else {
    $270 = ($266>>>0)<(11);
    if ($270) {
     $271 = $266 << 1;
     $272 = $271&255;
     HEAP8[$1>>0] = $272;
     $273 = (($1) + 1|0);
     $__p$0$i$i$i = $273;
    } else {
     $274 = (($266) + 16)|0;
     $275 = $274 & -16;
     __THREW__ = 0;
     $276 = (invoke_ii(2988,($275|0))|0);
     $277 = __THREW__; __THREW__ = 0;
     $278 = $277&1;
     if ($278) {
      label = 38;
      break;
     }
     $279 = (($1) + 8|0);
     HEAP32[$279>>2] = $276;
     $280 = $275 | 1;
     HEAP32[$1>>2] = $280;
     $281 = (($1) + 4|0);
     HEAP32[$281>>2] = $266;
     $__p$0$i$i$i = $276;
    }
    _memcpy(($__p$0$i$i$i|0),($265|0),($266|0))|0;
    $282 = (($__p$0$i$i$i) + ($266)|0);
    HEAP8[$282>>0] = 0;
    __THREW__ = 0;
    (invoke_iii(2717,($1|0),($utf16|0))|0);
    $283 = __THREW__; __THREW__ = 0;
    $284 = $283&1;
    if ($284) {
     $307 = ___cxa_find_matching_catch()|0;
     $308 = tempRet0;
     $309 = HEAP8[$1>>0]|0;
     $310 = $309 & 1;
     $311 = ($310<<24>>24)==(0);
     if ($311) {
      $$0 = $308;$$01 = $307;
      break;
     }
     $312 = (($1) + 8|0);
     $313 = HEAP32[$312>>2]|0;
     __ZdlPv($313);
     $$0 = $308;$$01 = $307;
     break;
    }
    $285 = HEAP8[$1>>0]|0;
    $286 = $285 & 1;
    $287 = ($286<<24>>24)==(0);
    if (!($287)) {
     $288 = (($1) + 8|0);
     $289 = HEAP32[$288>>2]|0;
     __ZdlPv($289);
    }
    __THREW__ = 0;
    invoke_vi(3766,($ie|0));
    $290 = __THREW__; __THREW__ = 0;
    $291 = $290&1;
    if ($291) {
     label = 38;
    } else {
     $292 = HEAP32[$utf16>>2]|0;
     $293 = HEAP32[$262>>2]|0;
     $294 = ($293|0)==(0);
     L20: do {
      if ($294) {
       $$lcssa = $292;
      } else {
       $295 = (($ie) + 36|0);
       $297 = $292;$331 = $293;$i$034 = $292;
       while(1) {
        $296 = ($i$034|0)==($297|0);
        if ($296) {
         $317 = $297;$318 = $331;
        } else {
         __THREW__ = 0;
         $298 = (invoke_i(101)|0);
         $299 = __THREW__; __THREW__ = 0;
         $300 = $299&1;
         if ($300) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(3466,($298|0),($ie|0));
         $301 = __THREW__; __THREW__ = 0;
         $302 = $301&1;
         if ($302) {
          break;
         }
         $$pre37 = HEAP32[$utf16>>2]|0;
         $$pre38 = HEAP32[$262>>2]|0;
         $317 = $$pre37;$318 = $$pre38;
        }
        $314 = HEAP16[$i$034>>1]|0;
        HEAP16[$295>>1] = $314;
        $315 = (($i$034) + 2|0);
        $316 = (($317) + ($318<<1)|0);
        $319 = ($315|0)==($316|0);
        if ($319) {
         $$lcssa = $317;
         break L20;
        } else {
         $297 = $317;$331 = $318;$i$034 = $315;
        }
       }
       $303 = ___cxa_find_matching_catch()|0;
       $304 = tempRet0;
       $lpad$phi$index = $303;$lpad$phi$index2 = $304;
       label = 39;
       break L3;
      }
     } while(0);
     $320 = HEAP32[$263>>2]|0;
     $321 = ($320|0)>(-1);
     if (!($321)) {
      STACKTOP = sp;return;
     }
     $322 = HEAP32[$264>>2]|0;
     HEAP32[$0>>2] = $322;
     ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
     __Z19free_alloc_internalPv10MemLabelId($$lcssa,$$byval_copy6);
     HEAP32[$utf16>>2] = 0;
     STACKTOP = sp;return;
    }
   }
  } while(0);
  if ((label|0) == 38) {
   $305 = ___cxa_find_matching_catch()|0;
   $306 = tempRet0;
   $lpad$phi$index = $305;$lpad$phi$index2 = $306;
   label = 39;
  }
  if ((label|0) == 39) {
   $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
  }
  $323 = HEAP32[$263>>2]|0;
  $324 = ($323|0)>(-1);
  if (!($324)) {
   ___resumeException($$01|0);
   // unreachable;
  }
  $325 = HEAP32[$utf16>>2]|0;
  $326 = HEAP32[$264>>2]|0;
  HEAP32[$0>>2] = $326;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($325|0),($$byval_copy6|0));
  $327 = __THREW__; __THREW__ = 0;
  $328 = $327&1;
  if ($328) {
   $329 = ___cxa_find_matching_catch(0|0)|0;
   $330 = tempRet0;
   ___clang_call_terminate($329);
   // unreachable;
  }
  HEAP32[$utf16>>2] = 0;
  ___resumeException($$01|0);
  // unreachable;
  break;
 }
 case 1024: case 1026: case 1025:  {
  $3 = (__Z15GetInputManagerv()|0);
  $4 = (($3) + 56|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 36|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($3) + 40|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 36|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 | $7;
  $13 = $12 & 98304;
  $14 = ($13|0)!=(0);
  $modifiers$0$i = $14&1;
  $15 = $12 & 393216;
  $16 = ($15|0)!=(0);
  $17 = $modifiers$0$i | 2;
  $modifiers$1$i = $16 ? $17 : $modifiers$0$i;
  $18 = $12 & 1572864;
  $19 = ($18|0)!=(0);
  $20 = $modifiers$1$i | 4;
  $modifiers$2$i = $19 ? $20 : $modifiers$1$i;
  $21 = $12 & 6291456;
  $22 = ($21|0)!=(0);
  $23 = $modifiers$2$i | 8;
  $modifiers$3$i = $22 ? $23 : $modifiers$2$i;
  $24 = (($ie) + 24|0);
  HEAP32[$24>>2] = $modifiers$3$i;
  $25 = HEAP32[$event>>2]|0;
  $26 = ($25|0)==(1024);
  if ($26) {
   $27 = (__Z15GetInputManagerv()|0);
   $28 = (($27) + 56|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = (($27) + 40|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + 40|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 | $31;
   $37 = $36 >>> 3;
   $38 = $37 & 1;
   $39 = $38 | 2;
   HEAP32[$ie>>2] = $39;
   $40 = (($ie) + 12|0);
   $41 = (($event) + 28|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (Math_fround(($42|0)));
   $44 = (($event) + 32|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = (Math_fround(($45|0)));
   $47 = (HEAPF32[tempDoublePtr>>2]=$43,HEAP32[tempDoublePtr>>2]|0);
   $48 = (HEAPF32[tempDoublePtr>>2]=$46,HEAP32[tempDoublePtr>>2]|0);
   $49 = $40;
   $50 = $49;
   HEAP32[$50>>2] = $47;
   $51 = (($49) + 4)|0;
   $52 = $51;
   HEAP32[$52>>2] = $48;
   $53 = (($ie) + 4|0);
   $54 = (($event) + 20|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (Math_fround(($55|0)));
   $57 = (($event) + 24|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = (Math_fround(($58|0)));
   $60 = (HEAPF32[tempDoublePtr>>2]=$56,HEAP32[tempDoublePtr>>2]|0);
   $61 = (HEAPF32[tempDoublePtr>>2]=$59,HEAP32[tempDoublePtr>>2]|0);
   $62 = $53;
   $63 = $62;
   HEAP32[$63>>2] = $60;
   $64 = (($62) + 4)|0;
   $65 = $64;
   HEAP32[$65>>2] = $61;
   $66 = (__Z15GetInputManagerv()|0);
   $67 = (($66) + 56|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = (($68) + 40|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = (($66) + 40|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($72) + 40|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = $74 | $70;
   $76 = $75 & 8;
   $77 = ($76|0)==(0);
   if ($77) {
    $78 = (__Z15GetInputManagerv()|0);
    $79 = (($78) + 56|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (($80) + 40|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($78) + 40|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = (($84) + 40|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = $86 | $82;
    $88 = $87 & 16;
    $89 = ($88|0)==(0);
    if ($89) {
     $90 = (__Z15GetInputManagerv()|0);
     $91 = (($90) + 56|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = (($92) + 40|0);
     $94 = HEAP32[$93>>2]|0;
     $95 = (($90) + 40|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = (($96) + 40|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = $98 | $94;
     $100 = $99 >>> 4;
     $101 = $100 & 2;
     $$0$i = $101;
    } else {
     $$0$i = 1;
    }
   } else {
    $$0$i = 0;
   }
   $102 = (($ie) + 20|0);
   HEAP32[$102>>2] = $$0$i;
   STACKTOP = sp;return;
  }
  $103 = (($ie) + 32|0);
  HEAP32[$103>>2] = 1;
  $104 = (($event) + 16|0);
  $105 = HEAP8[$104>>0]|0;
  $106 = $105&255;
  if ((($106|0) == 3)) {
   $$0$i9 = 1;
  } else if ((($106|0) == 2)) {
   $$0$i9 = 2;
  } else if ((($106|0) == 1)) {
   $$0$i9 = 0;
  } else {
   $$0$i9 = 3;
  }
  $107 = (($ie) + 20|0);
  HEAP32[$107>>2] = $$0$i9;
  $108 = (($ie) + 4|0);
  $109 = (($event) + 20|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (Math_fround(($110|0)));
  $112 = (($event) + 24|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (Math_fround(($113|0)));
  $115 = (HEAPF32[tempDoublePtr>>2]=$111,HEAP32[tempDoublePtr>>2]|0);
  $116 = (HEAPF32[tempDoublePtr>>2]=$114,HEAP32[tempDoublePtr>>2]|0);
  $117 = $108;
  $118 = $117;
  HEAP32[$118>>2] = $115;
  $119 = (($117) + 4)|0;
  $120 = $119;
  HEAP32[$120>>2] = $116;
  $121 = HEAP32[$event>>2]|0;
  if ((($121|0) == 1025)) {
   $122 = (__Z14GetTimeManagerv()|0);
   $123 = (+__ZN11TimeManager11GetRealtimeEv($122));
   $124 = Math_fround($123);
   HEAP32[$ie>>2] = 0;
   $125 = HEAP32[$109>>2]|0;
   $126 = HEAP32[1146888>>2]|0;
   $127 = ($125|0)==($126|0);
   if ($127) {
    $128 = HEAP32[$112>>2]|0;
    $129 = HEAP32[1146896>>2]|0;
    $130 = ($128|0)==($129|0);
    if ($130) {
     $131 = Math_fround(HEAPF32[1146880>>2]);
     $132 = Math_fround($124 - $131);
     $133 = !($132 <= Math_fround(1.0));
     if ($133) {
      $136 = $125;
     } else {
      $134 = HEAP32[1146904>>2]|0;
      $135 = (($134) + 1)|0;
      HEAP32[$103>>2] = $135;
      $$pre = HEAP32[$109>>2]|0;
      $136 = $$pre;
     }
    } else {
     $136 = $125;
    }
   } else {
    $136 = $125;
   }
   HEAP32[1146888>>2] = $136;
   $137 = HEAP32[$112>>2]|0;
   HEAP32[1146896>>2] = $137;
   $138 = HEAP32[$103>>2]|0;
   HEAP32[1146904>>2] = $138;
   HEAPF32[1146880>>2] = $124;
   STACKTOP = sp;return;
  } else if ((($121|0) == 1026)) {
   HEAP32[$ie>>2] = 1;
   HEAP32[$103>>2] = 1;
   STACKTOP = sp;return;
  } else {
   STACKTOP = sp;return;
  }
  break;
 }
 case 769: case 768:  {
  $139 = ($2|0)==(768);
  $140 = $139 ? 4 : 5;
  HEAP32[$ie>>2] = $140;
  $141 = (__Z15GetInputManagerv()|0);
  $142 = (($141) + 56|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = (($143) + 36|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = (($141) + 40|0);
  $147 = HEAP32[$146>>2]|0;
  $148 = (($147) + 36|0);
  $149 = HEAP32[$148>>2]|0;
  $150 = $149 | $145;
  $151 = $150 & 98304;
  $152 = ($151|0)!=(0);
  $modifiers$0$i10 = $152&1;
  $153 = $150 & 393216;
  $154 = ($153|0)!=(0);
  $155 = $modifiers$0$i10 | 2;
  $modifiers$1$i11 = $154 ? $155 : $modifiers$0$i10;
  $156 = $150 & 1572864;
  $157 = ($156|0)!=(0);
  $158 = $modifiers$1$i11 | 4;
  $modifiers$2$i12 = $157 ? $158 : $modifiers$1$i11;
  $159 = $150 & 6291456;
  $160 = ($159|0)!=(0);
  $161 = $modifiers$2$i12 | 8;
  $modifiers$3$i13 = $160 ? $161 : $modifiers$2$i12;
  $162 = (($ie) + 24|0);
  HEAP32[$162>>2] = $modifiers$3$i13;
  $163 = (($event) + 16|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = (1141640 + ($164<<2)|0);
  $166 = HEAP32[$165>>2]|0;
  $167 = $166&65535;
  $168 = (($ie) + 38|0);
  HEAP16[$168>>1] = $167;
  $169 = (($ie) + 4|0);
  $170 = (__Z15GetInputManagerv()|0);
  $171 = (($170) + 100|0);
  $172 = Math_fround(HEAPF32[$171>>2]);
  $173 = (($170) + 104|0);
  $174 = Math_fround(HEAPF32[$173>>2]);
  $175 = (__Z16GetScreenManagerv()|0);
  $176 = HEAP32[$175>>2]|0;
  $177 = (($176) + 84|0);
  $178 = HEAP32[$177>>2]|0;
  $179 = (FUNCTION_TABLE_ii[$178 & 4095]($175)|0);
  $180 = (Math_fround(($179|0)));
  $181 = Math_fround($180 - $174);
  $182 = (HEAPF32[tempDoublePtr>>2]=$172,HEAP32[tempDoublePtr>>2]|0);
  $183 = (HEAPF32[tempDoublePtr>>2]=$181,HEAP32[tempDoublePtr>>2]|0);
  $184 = $169;
  $185 = $184;
  HEAP32[$185>>2] = $182;
  $186 = (($184) + 4)|0;
  $187 = $186;
  HEAP32[$187>>2] = $183;
  __Z16SanitizeKeyEventR10InputEvent($ie);
  STACKTOP = sp;return;
  break;
 }
 case 1027:  {
  HEAP32[$ie>>2] = 6;
  $188 = (($ie) + 12|0);
  $189 = (($event) + 16|0);
  $190 = HEAP32[$189>>2]|0;
  $191 = (Math_fround(($190|0)));
  $192 = (($event) + 20|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = (0 - ($193))|0;
  $195 = (Math_fround(($194|0)));
  $196 = (HEAPF32[tempDoublePtr>>2]=$191,HEAP32[tempDoublePtr>>2]|0);
  $197 = (HEAPF32[tempDoublePtr>>2]=$195,HEAP32[tempDoublePtr>>2]|0);
  $198 = $188;
  $199 = $198;
  HEAP32[$199>>2] = $196;
  $200 = (($198) + 4)|0;
  $201 = $200;
  HEAP32[$201>>2] = $197;
  $202 = (($ie) + 4|0);
  $203 = (__Z15GetInputManagerv()|0);
  $204 = (($203) + 100|0);
  $205 = Math_fround(HEAPF32[$204>>2]);
  $206 = (($203) + 104|0);
  $207 = Math_fround(HEAPF32[$206>>2]);
  $208 = (__Z16GetScreenManagerv()|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = (($209) + 84|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = (FUNCTION_TABLE_ii[$211 & 4095]($208)|0);
  $213 = (Math_fround(($212|0)));
  $214 = Math_fround($213 - $207);
  $215 = (HEAPF32[tempDoublePtr>>2]=$205,HEAP32[tempDoublePtr>>2]|0);
  $216 = (HEAPF32[tempDoublePtr>>2]=$214,HEAP32[tempDoublePtr>>2]|0);
  $217 = $202;
  $218 = $217;
  HEAP32[$218>>2] = $215;
  $219 = (($217) + 4)|0;
  $220 = $219;
  HEAP32[$220>>2] = $216;
  STACKTOP = sp;return;
  break;
 }
 default: {
  HEAP32[$ie>>2] = 11;
  STACKTOP = sp;return;
 }
 }
}
function __Z14SDLHandleInputRKN3SDL9SDL_EventE($event) {
 $event = $event|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = 0, $131 = Math_fround(0), $132 = 0;
 var $133 = Math_fround(0), $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = Math_fround(0), $145 = Math_fround(0), $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = Math_fround(0);
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $buttonName = 0, $sext = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $vararg_buffer = sp;
 $buttonName = sp + 20|0;
 $0 = sp + 8|0;
 $1 = (__Z15GetInputManagerv()|0);
 $2 = HEAP32[$event>>2]|0;
 L1: do {
  switch ($2|0) {
  case 1536:  {
   $48 = (($event) + 4|0);
   $49 = HEAP8[$48>>0]|0;
   $50 = $49&255;
   $51 = (($50) + 1)|0;
   $52 = (($event) + 5|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = $53&255;
   $55 = (($event) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (+($56|0));
   $58 = $57 / 32767.0;
   $59 = Math_fround($58);
   __ZN12InputManager19SetJoystickPositionEiif($1,$51,$54,$59);
   STACKTOP = sp;return;
   break;
  }
  case 1026: case 1025:  {
   $3 = (($event) + 16|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = $4&255;
   if ((($5|0) == 3)) {
    $$0$i = 324;
   } else if ((($5|0) == 1)) {
    $$0$i = 323;
   } else if ((($5|0) == 2)) {
    $$0$i = 325;
   } else {
    $$0$i = 326;
   }
   $6 = ($2|0)==(1025);
   __ZN12InputManager11SetKeyStateEib($1,$$0$i,$6);
   STACKTOP = sp;return;
   break;
  }
  case 1538:  {
   $60 = (($event) + 4|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61&255;
   $63 = (_SDL_JoystickOpen(($62|0))|0);
   $64 = (_SDL_JoystickNumAxes(($63|0))|0);
   $65 = (($event) + 5|0);
   $66 = HEAP8[$65>>0]|0;
   $67 = $66&255;
   $68 = $67 << 1;
   $69 = (($68) + ($64))|0;
   $70 = (($event) + 6|0);
   $71 = HEAP8[$70>>0]|0;
   $72 = $71&255;
   $73 = $72 & 1;
   $74 = $72 & 4;
   $75 = ($74|0)!=(0);
   $76 = $72 << 28;
   $sext = $76 >> 31;
   $77 = $71 & 2;
   $78 = ($77<<24>>24)==(0);
   $79 = HEAP8[$60>>0]|0;
   $80 = $79&255;
   $81 = (($80) + 1)|0;
   $82 = (Math_fround(($sext|0)));
   $83 = $78 ? $82 : Math_fround(1.0);
   __ZN12InputManager19SetJoystickPositionEiif($1,$81,$69,$83);
   $84 = HEAP8[$60>>0]|0;
   $85 = $84&255;
   $86 = (($85) + 1)|0;
   $87 = (($69) + 1)|0;
   $88 = (Math_fround(($73|0)));
   $89 = $75 ? Math_fround(-1.0) : $88;
   __ZN12InputManager19SetJoystickPositionEiif($1,$86,$87,$89);
   STACKTOP = sp;return;
   break;
  }
  case 1027:  {
   $130 = (($1) + 84|0);
   $131 = Math_fround(HEAPF32[$130>>2]);
   $132 = (($1) + 88|0);
   $133 = Math_fround(HEAPF32[$132>>2]);
   $134 = (($1) + 92|0);
   $135 = Math_fround(HEAPF32[$134>>2]);
   $136 = (($1) + 96|0);
   $137 = Math_fround(HEAPF32[$136>>2]);
   $138 = (($event) + 16|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = (Math_fround(($139|0)));
   $141 = Math_fround($135 - $140);
   $142 = (($event) + 20|0);
   $143 = HEAP32[$142>>2]|0;
   $144 = (Math_fround(($143|0)));
   $145 = Math_fround($137 - $144);
   HEAPF32[$130>>2] = $131;
   HEAPF32[$132>>2] = $133;
   HEAPF32[$134>>2] = $141;
   HEAPF32[$136>>2] = $145;
   break;
  }
  case 771:  {
   $146 = (($1) + 124|0);
   $147 = (($event) + 8|0);
   $148 = (_strlen(($147|0))|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($146,$147,$148)|0);
   break;
  }
  case 769: case 768:  {
   $37 = (__ZN12InputManager17GetTextFieldInputEv($1)|0);
   if ($37) {
    $38 = (__ZN12InputManager30GetEatKeyPressOnTextFieldFocusEv($1)|0);
    if ($38) {
     STACKTOP = sp;return;
    }
   }
   __Z35InitEmscriptenSDLScancodeToUnitySDLv();
   $39 = (($event) + 16|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = (1141640 + ($40<<2)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = HEAP32[$event>>2]|0;
   $44 = ($43|0)==(768);
   __ZN12InputManager11SetKeyStateEib($1,$42,$44);
   $45 = HEAP32[$39>>2]|0;
   $46 = ($45|0)==(8);
   if (!($46)) {
    STACKTOP = sp;return;
   }
   $47 = (($1) + 124|0);
   (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($47,1146912,1)|0);
   STACKTOP = sp;return;
   break;
  }
  case 1540: case 1539:  {
   $90 = (($event) + 4|0);
   $91 = HEAP8[$90>>0]|0;
   $92 = $91&255;
   $93 = (($92) + 1)|0;
   $94 = (($event) + 5|0);
   $95 = HEAP8[$94>>0]|0;
   $96 = $95&255;
   HEAP32[$vararg_buffer>>2] = $93;
   $vararg_ptr1 = (($vararg_buffer) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $96;
   (_sprintf($buttonName,1146920,$vararg_buffer)|0);
   $97 = (_strlen(($buttonName|0))|0);
   $98 = ($97>>>0)>(4294967279);
   if ($98) {
    __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
    // unreachable;
   }
   $99 = ($97>>>0)<(11);
   if ($99) {
    $100 = $97 << 1;
    $101 = $100&255;
    HEAP8[$0>>0] = $101;
    $102 = (($0) + 1|0);
    $__p$0$i$i$i = $102;
   } else {
    $103 = (($97) + 16)|0;
    $104 = $103 & -16;
    $105 = (__Znwj($104)|0);
    $106 = (($0) + 8|0);
    HEAP32[$106>>2] = $105;
    $107 = $104 | 1;
    HEAP32[$0>>2] = $107;
    $108 = (($0) + 4|0);
    HEAP32[$108>>2] = $97;
    $__p$0$i$i$i = $105;
   }
   _memcpy(($__p$0$i$i$i|0),($buttonName|0),($97|0))|0;
   $109 = (($__p$0$i$i$i) + ($97)|0);
   HEAP8[$109>>0] = 0;
   __THREW__ = 0;
   $110 = (invoke_ii(3454,($0|0))|0);
   $111 = __THREW__; __THREW__ = 0;
   $112 = $111&1;
   if (!($112)) {
    $113 = (($event) + 6|0);
    $114 = HEAP8[$113>>0]|0;
    $115 = ($114<<24>>24)!=(0);
    __THREW__ = 0;
    invoke_viii(2087,($1|0),($110|0),($115|0));
    $116 = __THREW__; __THREW__ = 0;
    $117 = $116&1;
    if (!($117)) {
     $118 = HEAP8[$0>>0]|0;
     $119 = $118 & 1;
     $120 = ($119<<24>>24)==(0);
     if ($120) {
      break L1;
     }
     $121 = (($0) + 8|0);
     $122 = HEAP32[$121>>2]|0;
     __ZdlPv($122);
     break L1;
    }
   }
   $123 = ___cxa_find_matching_catch()|0;
   $124 = tempRet0;
   $125 = HEAP8[$0>>0]|0;
   $126 = $125 & 1;
   $127 = ($126<<24>>24)==(0);
   if ($127) {
    ___resumeException($123|0);
    // unreachable;
   }
   $128 = (($0) + 8|0);
   $129 = HEAP32[$128>>2]|0;
   __ZdlPv($129);
   ___resumeException($123|0);
   // unreachable;
   break;
  }
  case 1024:  {
   $7 = (($event) + 28|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (Math_fround(($8|0)));
   $10 = (($event) + 32|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (0 - ($11))|0;
   $13 = (Math_fround(($12|0)));
   $14 = (($1) + 84|0);
   HEAPF32[$14>>2] = $9;
   $15 = (($1) + 88|0);
   HEAPF32[$15>>2] = $13;
   $16 = (($1) + 92|0);
   HEAPF32[$16>>2] = Math_fround(0.0);
   $17 = (($1) + 96|0);
   HEAPF32[$17>>2] = Math_fround(0.0);
   $18 = (($event) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (Math_fround(($19|0)));
   $21 = (__Z16GetScreenManagerv()|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 84|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (FUNCTION_TABLE_ii[$24 & 4095]($21)|0);
   $26 = (($event) + 24|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) - ($27))|0;
   $29 = (Math_fround(($28|0)));
   $30 = (($1) + 100|0);
   $31 = (HEAPF32[tempDoublePtr>>2]=$20,HEAP32[tempDoublePtr>>2]|0);
   $32 = (HEAPF32[tempDoublePtr>>2]=$29,HEAP32[tempDoublePtr>>2]|0);
   $33 = $30;
   $34 = $33;
   HEAP32[$34>>2] = $31;
   $35 = (($33) + 4)|0;
   $36 = $35;
   HEAP32[$36>>2] = $32;
   STACKTOP = sp;return;
   break;
  }
  default: {
  }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __Z11UpdateInputv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $event = 0, $ie = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $event = sp;
 $ie = sp + 48|0;
 $0 = (_SDL_NumJoysticks()|0);
 $1 = HEAP32[1146944>>2]|0;
 $2 = ($0|0)>($1|0);
 if ($2) {
  $4 = $1;
  while(1) {
   $3 = (($4) + 1)|0;
   HEAP32[1146944>>2] = $3;
   (_SDL_JoystickOpen(($4|0))|0);
   $5 = (_SDL_NumJoysticks()|0);
   $6 = HEAP32[1146944>>2]|0;
   $7 = ($5|0)>($6|0);
   if ($7) {
    $4 = $6;
   } else {
    break;
   }
  }
 }
 $8 = (_SDL_PollEvent(($event|0))|0);
 $9 = ($8|0)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($ie) + 4|0);
 $11 = (($ie) + 40|0);
 while(1) {
  __Z14SDLHandleInputRKN3SDL9SDL_EventE($event);
  HEAP32[$11>>2] = 0;
  ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
  __THREW__ = 0;
  invoke_vii(3467,($ie|0),($event|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   break;
  }
  __THREW__ = 0;
  $14 = (invoke_i(101)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   break;
  }
  __THREW__ = 0;
  invoke_vii(3466,($14|0),($ie|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   break;
  }
  __ZN10InputEventD2Ev($ie);
  $19 = (_SDL_PollEvent(($event|0))|0);
  $20 = ($19|0)==(0);
  if ($20) {
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return;
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3498,($ie|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch(0|0)|0;
  $26 = tempRet0;
  ___clang_call_terminate($25);
  // unreachable;
 } else {
  ___resumeException($21|0);
  // unreachable;
 }
}
function __ZN18ScreenManagerWebGL22SetResolutionImmediateEiibi($this,$width,$height,$fullscreen,$preferredRefreshRate) {
 $this = $this|0;
 $width = $width|0;
 $height = $height|0;
 $fullscreen = $fullscreen|0;
 $preferredRefreshRate = $preferredRefreshRate|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z18GetQualitySettingsv()|0);
 $1 = (($0) + 40|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4) + (($2*96)|0)|0) + 68|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(-1);
 $10 = ($8|0)==($6|0);
 $or$cond = $9 | $10;
 if (!($or$cond)) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1146952,0,1147032,15,512,0,0,0);
 }
 HEAP32[$7>>2] = $6;
 if ($fullscreen) {
  $11 = (($this) + 28|0);
  HEAP32[$11>>2] = $width;
  $12 = (($this) + 32|0);
  HEAP32[$12>>2] = $height;
 } else {
  _emscripten_set_canvas_size(($width|0),($height|0));
 }
 $13 = HEAP32[$this>>2]|0;
 $14 = (($13) + 92|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_ii[$15 & 4095]($this)|0);
 $17 = $16 ^ $fullscreen;
 if (!($17)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($fullscreen)) {
  (_emscripten_exit_fullscreen()|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (_JS_SystemInfo_HasFullscreen()|0);
 $19 = ($18|0)==(0);
 if ($19) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1147040,0,1147032,35,1,0,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  (_emscripten_request_fullscreen((0|0),1)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNK18ScreenManagerWebGL8GetWidthEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_emscripten_asm_const_int((1147088|0))|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK18ScreenManagerWebGL9GetHeightEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_emscripten_asm_const_int((1147128|0))|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK18ScreenManagerWebGL12IsFullScreenEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $stat = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $stat = sp;
 (_emscripten_get_fullscreen_status(($stat|0))|0);
 $0 = HEAP32[$stat>>2]|0;
 $1 = ($0|0)!=(0);
 STACKTOP = sp;return ($1|0);
}
function __Z12MouseHandleriPK20EmscriptenMouseEventPv($eventType,$mouseEvent,$userData) {
 $eventType = $eventType|0;
 $mouseEvent = $mouseEvent|0;
 $userData = $userData|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z10KeyHandleriPK23EmscriptenKeyboardEventPv($eventType,$mouseEvent,$userData) {
 $eventType = $eventType|0;
 $mouseEvent = $mouseEvent|0;
 $userData = $userData|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __Z24FullscreenChangeCallbackiPK31EmscriptenFullscreenChangeEventPv($eventType,$e,$userData) {
 $eventType = $eventType|0;
 $e = $e|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $6 = (($userData) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($userData) + 32|0);
  $9 = HEAP32[$8>>2]|0;
  _emscripten_set_canvas_size(($7|0),($9|0));
  STACKTOP = sp;return 1;
 } else {
  $2 = (($e) + 272|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($e) + 276|0);
  $5 = HEAP32[$4>>2]|0;
  _emscripten_set_canvas_size(($3|0),($5|0));
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __Z13FocusCallbackiPK20EmscriptenFocusEventPv($eventType,$e,$userData) {
 $eventType = $eventType|0;
 $e = $e|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($eventType|0)==(13);
 __Z14SetPlayerFocusb($0);
 $1 = (__Z24GetPlayerRunInBackgroundv()|0);
 if ($1) {
  STACKTOP = sp;return 1;
 }
 $2 = $0&1;
 $3 = $2 ^ 1;
 __Z14SetPlayerPause11PlayerPause($3);
 STACKTOP = sp;return 1;
}
function __ZN18ScreenManagerWebGLC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13ScreenManagerC2Ev($this);
 HEAP32[$this>>2] = ((1147168 + 8|0));
 (_emscripten_set_mouseup_callback((1147296|0),(0|0),0,(1632|0))|0);
 (_emscripten_set_keyup_callback((0|0),(0|0),0,(1633|0))|0);
 (_emscripten_set_fullscreenchange_callback((0|0),($this|0),1,(1634|0))|0);
 (_emscripten_set_focus_callback((0|0),(0|0),0,(1635|0))|0);
 (_emscripten_set_blur_callback((0|0),(0|0),0,(1635|0))|0);
 $0 = (($this) + 48|0);
 HEAP8[$0>>0] = 1;
 $1 = (($this) + 52|0);
 HEAP32[$1>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN18ScreenManagerWebGL13SetShowCursorEb($this,$show) {
 $this = $this|0;
 $show = $show|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $show&1;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 _JS_Cursor_SetShow(($show|0));
 $5 = $show&1;
 HEAP8[$0>>0] = $5;
 STACKTOP = sp;return;
}
function __ZN18ScreenManagerWebGL13SetLockCursorE14CursorLockMode($this,$lock) {
 $this = $this|0;
 $lock = $lock|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($lock|0)==(1);
 if (!($0)) {
  (_emscripten_exit_pointerlock()|0);
  STACKTOP = sp;return;
 }
 $1 = (_JS_SystemInfo_HasCursorLock()|0);
 $2 = ($1|0)==(0);
 if ($2) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1147304,0,1147032,140,1,0,0,0);
  STACKTOP = sp;return;
 } else {
  (_emscripten_request_pointerlock((0|0),1)|0);
  STACKTOP = sp;return;
 }
}
function __ZNK18ScreenManagerWebGL13GetLockCursorEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $stat = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $stat = sp;
 $0 = (_JS_SystemInfo_HasCursorLock()|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (_emscripten_get_pointerlock_status(($stat|0))|0);
 $2 = HEAP32[$stat>>2]|0;
 $3 = ($2|0)!=(0);
 $4 = $3&1;
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK18ScreenManagerWebGL20GetCurrentResolutionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($agg$result) + 4|0);
 $1 = (($agg$result) + 8|0);
 $2 = (_JS_SystemInfo_GetHeight()|0);
 HEAP32[$0>>2] = $2;
 $3 = (_JS_SystemInfo_GetWidth()|0);
 HEAP32[$agg$result>>2] = $3;
 HEAP32[$1>>2] = 60;
 STACKTOP = sp;return;
}
function __ZN18ScreenManagerWebGL6UpdateEv($this) {
 $this = $this|0;
 var $$pre = Math_fround(0), $$pre$phiZ2D = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Z16GetRenderManagerv()|0);
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($this)|0);
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 84|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_ii[$8 & 4095]($this)|0);
 $10 = (($1) + 64|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (Math_fround(($5|0)));
 $13 = $11 != $12;
 if ($13) {
  $$pre = (Math_fround(($9|0)));
  $$pre$phiZ2D = $$pre;
 } else {
  $14 = (($1) + 68|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (Math_fround(($9|0)));
  $17 = $15 != $16;
  if ($17) {
   $$pre$phiZ2D = $16;
  } else {
   STACKTOP = sp;return;
  }
 }
 HEAPF32[$0>>2] = Math_fround(0.0);
 $18 = (($0) + 8|0);
 HEAPF32[$18>>2] = $12;
 $19 = (($0) + 4|0);
 HEAPF32[$19>>2] = Math_fround(0.0);
 $20 = (($0) + 12|0);
 HEAPF32[$20>>2] = $$pre$phiZ2D;
 __ZN13RenderManager13SetWindowRectERK5RectTIfE($1,$0);
 _emscripten_set_canvas_size(($5|0),($9|0));
 STACKTOP = sp;return;
}
function __ZN18ScreenManagerWebGLD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN18ScreenManagerWebGLD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK18ScreenManagerWebGL13GetShowCursorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function _SendMessageFloat($object,$method,$value) {
 $object = $object|0;
 $method = $method|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__Z19GetScriptingManagerv()|0);
 $1 = (($0) + 208|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__Z20scripting_object_newP14ScriptingClass($2)|0);
 $4 = (($3) + 8|0);
 HEAPF32[$4>>2] = $value;
 $5 = (__Z27FindActiveTransformWithPathPKc($object)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  HEAP32[$vararg_buffer2>>2] = $object;
  _printf_console(1147424,$vararg_buffer2);
  STACKTOP = sp;return;
 }
 $7 = (($5) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (__ZN9Scripting20SendScriptingMessageERN5Unity10GameObjectEPKcP15ScriptingObject($8,$method,$3)|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer2>>2] = $object;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $method;
 _printf_console(1147360,$vararg_buffer2);
 STACKTOP = sp;return;
}
function _SendMessageString($object,$method,$value) {
 $object = $object|0;
 $method = $method|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__Z20scripting_string_newPKc($value)|0);
 $1 = (__Z27FindActiveTransformWithPathPKc($object)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$vararg_buffer2>>2] = $object;
  _printf_console(1147424,$vararg_buffer2);
  STACKTOP = sp;return;
 }
 $3 = (($1) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN9Scripting20SendScriptingMessageERN5Unity10GameObjectEPKcP15ScriptingObject($4,$method,$0)|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer2>>2] = $object;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $method;
 _printf_console(1147360,$vararg_buffer2);
 STACKTOP = sp;return;
}
function _SendMessage($object,$method) {
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer2 = sp;
 $0 = (__Z27FindActiveTransformWithPathPKc($object)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[$vararg_buffer2>>2] = $object;
  _printf_console(1147424,$vararg_buffer2);
  STACKTOP = sp;return;
 }
 $2 = (($0) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (__ZN9Scripting20SendScriptingMessageERN5Unity10GameObjectEPKcP15ScriptingObject($3,$method,0)|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer2>>2] = $object;
 $vararg_ptr1 = (($vararg_buffer2) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $method;
 _printf_console(1147360,$vararg_buffer2);
 STACKTOP = sp;return;
}
function _SetFullscreen($fullscreen) {
 $fullscreen = $fullscreen|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetScreenManagerPtrv()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (__Z16GetScreenManagerv()|0);
 $3 = ($fullscreen|0)!=(0);
 __ZN13ScreenManager24SetIsFullScreenImmediateEb($2,$3);
 STACKTOP = sp;return;
}
function __ZN10systeminfo19GetPhysicalMemoryMBEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_JS_SystemInfo_GetMemory()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN10systeminfo21GetPersistentDataPathEv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0] = 12;
 $0 = (($agg$result) + 1|0);
 ;HEAP8[$0+0>>0]=HEAP8[1147464+0>>0]|0;HEAP8[$0+1>>0]=HEAP8[1147464+1>>0]|0;HEAP8[$0+2>>0]=HEAP8[1147464+2>>0]|0;HEAP8[$0+3>>0]=HEAP8[1147464+3>>0]|0;HEAP8[$0+4>>0]=HEAP8[1147464+4>>0]|0;HEAP8[$0+5>>0]=HEAP8[1147464+5>>0]|0;
 $1 = (($agg$result) + 7|0);
 HEAP8[$1>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN10systeminfo21GetTemporaryCachePathEv($agg$result) {
 $agg$result = $agg$result|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1147472,0,1147488,87,1,0,0,0);
 HEAP8[$agg$result>>0] = 0;
 $0 = (($agg$result) + 1|0);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __Z19GetTimeSinceStartupv() {
 var $$0 = 0.0, $0 = 0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[1147496>>0]|0;
 $1 = ($0<<24>>24)==(0);
 $2 = (+_emscripten_get_now());
 if ($1) {
  HEAPF64[1147504>>3] = $2;
  HEAP8[1147496>>0] = 1;
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 } else {
  $3 = +HEAPF64[1147504>>3];
  $4 = $2 - $3;
  $5 = $4 * 0.00100000000000000002082;
  $$0 = $5;
  STACKTOP = sp;return (+$$0);
 }
 return +0;
}
function _tlsf_check_heap($tlsf) {
 $tlsf = $tlsf|0;
 var $$$i = 0, $$$status$2 = 0, $$idx = 0, $$idx$val = 0, $$in$i = 0, $$lobit = 0, $$status$2 = 0, $$status$4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $block$0$idx1$i = 0, $block$0$idx1$val$i = 0, $block$0$idx2 = 0, $block$0$idx2$val = 0, $block$017 = 0, $exitcond = 0, $exitcond24 = 0, $fl$0$i = 0, $i$023 = 0, $j$019 = 0, $not$ = 0;
 var $not$14 = 0, $not$15 = 0, $not$or$cond = 0, $not$or$cond7 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $phitmp$i$i = 0, $sext = 0, $sext10 = 0, $sext12 = 0, $sl$0$i = 0, $status$0$ph = 0, $status$022 = 0, $status$10 = 0, $status$11 = 0, $status$118 = 0, $status$2 = 0, $status$2$ = 0, $status$416 = 0;
 var $status$6 = 0, $status$6$ = 0, $status$8 = 0, $status$8$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $tlsf;
 $1 = (($0) + 3184)|0;
 $2 = ($1|0)==(0);
 L1: do {
  if ($2) {
   $status$0$ph = 0;
  } else {
   $$in$i = $1;$10 = 0;$8 = 0;
   while(1) {
    $3 = $$in$i;
    $block$0$idx1$i = (($3) + 4|0);
    $block$0$idx1$val$i = HEAP32[$block$0$idx1$i>>2]|0;
    $4 = ($block$0$idx1$val$i>>>0)<(4);
    if ($4) {
     $status$0$ph = $10;
     break L1;
    }
    $5 = (($3) + 8|0);
    $6 = $block$0$idx1$val$i >>> 1;
    $$lobit = $6 & 1;
    $7 = $block$0$idx1$val$i & 1;
    $not$ = ($8|0)!=($$lobit|0);
    $$$i = $not$ << 31 >> 31;
    $9 = (($10) + ($$$i))|0;
    $11 = (($block$0$idx1$val$i) + -4)|0;
    $12 = $11 & -4;
    $13 = $5;
    $14 = (($12) + ($13))|0;
    $15 = ($14|0)==(0);
    if ($15) {
     $status$0$ph = $9;
     break;
    } else {
     $$in$i = $14;$10 = $9;$8 = $7;
    }
   }
  }
 } while(0);
 $16 = (($tlsf) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($tlsf) + 20|0);
 $19 = (($tlsf) + 116|0);
 $i$023 = 0;$status$022 = $status$0$ph;
 while(1) {
  $20 = 1 << $i$023;
  $21 = $17 & $20;
  $22 = (($18) + ($i$023<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($21|0)!=(0);
  $25 = ($23|0)==(0);
  $26 = $25 << 31 >> 31;
  $j$019 = 0;$status$118 = $status$022;
  while(1) {
   $27 = 1 << $j$019;
   $28 = $23 & $27;
   $29 = ((($19) + ($i$023<<7)|0) + ($j$019<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($28|0)==(0);
   $or$cond = $24 | $31;
   $not$or$cond = $or$cond ^ 1;
   $32 = $not$or$cond << 31 >> 31;
   $status$2 = (($32) + ($status$118))|0;
   if ($31) {
    $not$15 = ($30|0)!=($tlsf|0);
    $33 = $not$15 << 31 >> 31;
    $status$2$ = (($status$2) + ($33))|0;
    $status$11 = $status$2$;
   } else {
    $34 = ($30|0)==($tlsf|0);
    $35 = $34 << 31 >> 31;
    $$status$2 = (($35) + ($26))|0;
    $$$status$2 = (($$status$2) + ($status$2))|0;
    if ($34) {
     $status$11 = $$$status$2;
    } else {
     $block$017 = $30;$status$416 = $$$status$2;
     while(1) {
      $block$0$idx2 = (($block$017) + 4|0);
      $block$0$idx2$val = HEAP32[$block$0$idx2>>2]|0;
      $36 = $block$0$idx2$val & 1;
      $37 = $block$0$idx2$val << 30;
      $sext10 = $37 >> 31;
      $38 = (($block$017) + 8|0);
      $39 = (($block$0$idx2$val) + -4)|0;
      $40 = $39 & -4;
      $41 = $38;
      $42 = (($40) + ($41))|0;
      $43 = $42;
      $$idx = (($43) + 4|0);
      $$idx$val = HEAP32[$$idx>>2]|0;
      $44 = $$idx$val << 31;
      $sext12 = $44 >> 31;
      $45 = $$idx$val >>> 1;
      $46 = $45 & 1;
      $47 = $block$0$idx2$val & -4;
      $not$14 = ($47>>>0)<(12);
      $48 = $not$14 << 31 >> 31;
      $49 = ($47>>>0)<(128);
      if ($49) {
       $50 = (($47|0) / 4)&-1;
       $fl$0$i = 0;$sl$0$i = $50;
      } else {
       $51 = (_llvm_ctlz_i32(($47|0))|0);
       $phitmp$i$i = (31 - ($51))|0;
       $52 = (($phitmp$i$i) + -5)|0;
       $53 = $47 >>> $52;
       $54 = $53 ^ 32;
       $55 = (($phitmp$i$i) + -6)|0;
       $fl$0$i = $55;$sl$0$i = $54;
      }
      $notlhs = ($fl$0$i|0)!=($i$023|0);
      $notrhs = ($sl$0$i|0)!=($j$019|0);
      $not$or$cond7 = $notrhs | $notlhs;
      $56 = $not$or$cond7 << 31 >> 31;
      $sext = (($status$416) + -2)|0;
      $$status$4 = (($sext) + ($36))|0;
      $status$6 = (($$status$4) + ($sext10))|0;
      $status$6$ = (($status$6) + ($48))|0;
      $status$8 = (($status$6$) + ($sext12))|0;
      $status$8$ = (($status$8) + ($46))|0;
      $status$10 = (($status$8$) + ($56))|0;
      $57 = HEAP32[$38>>2]|0;
      $58 = ($57|0)==($tlsf|0);
      if ($58) {
       $status$11 = $status$10;
       break;
      } else {
       $block$017 = $57;$status$416 = $status$10;
      }
     }
    }
   }
   $59 = (($j$019) + 1)|0;
   $exitcond = ($59|0)==(32);
   if ($exitcond) {
    break;
   } else {
    $j$019 = $59;$status$118 = $status$11;
   }
  }
  $60 = (($i$023) + 1)|0;
  $exitcond24 = ($60|0)==(24);
  if ($exitcond24) {
   break;
  } else {
   $i$023 = $60;$status$022 = $status$11;
  }
 }
 STACKTOP = sp;return ($status$11|0);
}
function _tlsf_walk_heap($pool,$walker,$user) {
 $pool = $pool|0;
 $walker = $walker|0;
 $user = $user|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$0$idx1 = 0, $block$0$idx1$val = 0, $block$idx$val$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($walker|0)!=(0|0);
 $1 = $0 ? $walker : 436;
 $2 = $pool;
 $3 = (($2) + 3184)|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $$in = $3;
 }
 while(1) {
  $5 = $$in;
  $block$0$idx1 = (($5) + 4|0);
  $block$0$idx1$val = HEAP32[$block$0$idx1>>2]|0;
  $6 = ($block$0$idx1$val>>>0)<(4);
  if ($6) {
   label = 4;
   break;
  }
  $7 = (($5) + 8|0);
  $8 = $block$0$idx1$val & -4;
  $9 = $block$0$idx1$val & 1;
  $10 = $9 ^ 1;
  FUNCTION_TABLE_viiii[$1 & 511]($7,$8,$10,$user);
  $block$idx$val$i = HEAP32[$block$0$idx1>>2]|0;
  $11 = (($block$idx$val$i) + -4)|0;
  $12 = $11 & -4;
  $13 = $7;
  $14 = (($12) + ($13))|0;
  $15 = ($14|0)==(0);
  if ($15) {
   label = 4;
   break;
  } else {
   $$in = $14;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return;
 }
}
function _default_walker($ptr,$size,$used,$user) {
 $ptr = $ptr|0;
 $size = $size|0;
 $used = $used|0;
 $user = $user|0;
 var $0 = 0, $1 = 0, $2 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = ($used|0)!=(0);
 $1 = $0 ? 1147600 : 1147608;
 $2 = (($ptr) + -8|0);
 HEAP32[$vararg_buffer>>2] = $ptr;
 $vararg_ptr1 = (($vararg_buffer) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $1;
 $vararg_ptr2 = (($vararg_buffer) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $size;
 $vararg_ptr3 = (($vararg_buffer) + 12|0);
 HEAP32[$vararg_ptr3>>2] = $2;
 (_printf((1147576|0),($vararg_buffer|0))|0);
 STACKTOP = sp;return;
}
function _tlsf_block_size($ptr) {
 $ptr = $ptr|0;
 var $$idx = 0, $$idx$val = 0, $0 = 0, $1 = 0, $size$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ptr|0)==(0|0);
 if ($0) {
  $size$0 = 0;
 } else {
  $$idx = (($ptr) + -4|0);
  $$idx$val = HEAP32[$$idx>>2]|0;
  $1 = $$idx$val & -4;
  $size$0 = $1;
 }
 STACKTOP = sp;return ($size$0|0);
}
function _tlsf_create($mem,$bytes) {
 $mem = $mem|0;
 $bytes = $bytes|0;
 var $$0 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $block$idx$val$i$i = 0, $exitcond$i = 0, $exitcond3$i = 0, $fl$0$i$i = 0, $i$02$i = 0, $j$01$i = 0, $phitmp$i$i$i = 0, $sl$0$i$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (($bytes) + -3196)|0;
 $1 = $0 & -4;
 $$off = (($1) + -12)|0;
 $2 = ($$off>>>0)>(1073741812);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 3208;
  $vararg_ptr1 = (($vararg_buffer) + 4|0);
  HEAP32[$vararg_ptr1>>2] = 1073745020;
  (_printf((1147512|0),($vararg_buffer|0))|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($mem) + 8|0);
 HEAP32[$3>>2] = $mem;
 $4 = (($mem) + 12|0);
 HEAP32[$4>>2] = $mem;
 $5 = (($mem) + 16|0);
 HEAP32[$5>>2] = 0;
 $i$02$i = 0;
 while(1) {
  $6 = ((($mem) + ($i$02$i<<2)|0) + 20|0);
  HEAP32[$6>>2] = 0;
  $j$01$i = 0;
  while(1) {
   $7 = (((($mem) + ($i$02$i<<7)|0) + ($j$01$i<<2)|0) + 116|0);
   HEAP32[$7>>2] = $mem;
   $8 = (($j$01$i) + 1)|0;
   $exitcond$i = ($8|0)==(32);
   if ($exitcond$i) {
    break;
   } else {
    $j$01$i = $8;
   }
  }
  $9 = (($i$02$i) + 1)|0;
  $exitcond3$i = ($9|0)==(24);
  if ($exitcond3$i) {
   break;
  } else {
   $i$02$i = $9;
  }
 }
 $10 = $mem;
 $11 = (($10) + 3184)|0;
 $12 = $11;
 $13 = (($12) + 4|0);
 $14 = $1 | 1;
 HEAP32[$13>>2] = $14;
 $15 = ($1>>>0)<(128);
 if ($15) {
  $16 = (($1|0) / 4)&-1;
  $fl$0$i$i = 0;$sl$0$i$i = $16;
 } else {
  $17 = (_llvm_ctlz_i32(($1|0))|0);
  $phitmp$i$i$i = (31 - ($17))|0;
  $18 = (($phitmp$i$i$i) + -5)|0;
  $19 = $1 >>> $18;
  $20 = $19 ^ 32;
  $21 = (($phitmp$i$i$i) + -6)|0;
  $fl$0$i$i = $21;$sl$0$i$i = $20;
 }
 $22 = (((($mem) + ($fl$0$i$i<<7)|0) + ($sl$0$i$i<<2)|0) + 116|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($12) + 8|0);
 HEAP32[$24>>2] = $23;
 $25 = (($12) + 12|0);
 HEAP32[$25>>2] = $mem;
 $26 = (($23) + 12|0);
 HEAP32[$26>>2] = $12;
 HEAP32[$22>>2] = $12;
 $27 = 1 << $fl$0$i$i;
 $28 = HEAP32[$5>>2]|0;
 $29 = $28 | $27;
 HEAP32[$5>>2] = $29;
 $30 = 1 << $sl$0$i$i;
 $31 = ((($mem) + ($fl$0$i$i<<2)|0) + 20|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 | $30;
 HEAP32[$31>>2] = $33;
 $block$idx$val$i$i = HEAP32[$13>>2]|0;
 $34 = (($block$idx$val$i$i) + -4)|0;
 $35 = $34 & -4;
 $36 = $24;
 $37 = (($35) + ($36))|0;
 $38 = $37;
 HEAP32[$38>>2] = $12;
 $39 = (($38) + 4|0);
 HEAP32[$39>>2] = 2;
 $$0 = $mem;
 STACKTOP = sp;return ($$0|0);
}
function _tlsf_destroy($pool) {
 $pool = $pool|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _block_locate_free($pool,$size) {
 $pool = $pool|0;
 $size = $size|0;
 var $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $block$02 = 0, $fl$0$i = 0, $fl$0$i$i = 0, $phitmp$i$i$i = 0, $sl$0$i$i = 0;
 var $sl_map$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  $block$02 = 0;
  STACKTOP = sp;return ($block$02|0);
 }
 $1 = ($size>>>0)>(31);
 if ($1) {
  $2 = (_llvm_ctlz_i32(($size|0))|0);
  $3 = (26 - ($2))|0;
  $4 = 1 << $3;
  $5 = (($size) + -1)|0;
  $6 = (($5) + ($4))|0;
  $7 = ($6>>>0)<(128);
  if ($7) {
   $$01$i = $6;
   label = 4;
  } else {
   $9 = (_llvm_ctlz_i32(($6|0))|0);
   $phitmp$i$i$i = (31 - ($9))|0;
   $10 = (($phitmp$i$i$i) + -5)|0;
   $11 = $6 >>> $10;
   $12 = $11 ^ 32;
   $13 = (($phitmp$i$i$i) + -6)|0;
   $fl$0$i$i = $13;$sl$0$i$i = $12;
  }
 } else {
  $$01$i = $size;
  label = 4;
 }
 if ((label|0) == 4) {
  $8 = (($$01$i|0) / 4)&-1;
  $fl$0$i$i = 0;$sl$0$i$i = $8;
 }
 $14 = ((($pool) + ($fl$0$i$i<<2)|0) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = -1 << $sl$0$i$i;
 $17 = $15 & $16;
 $18 = ($17|0)==(0);
 do {
  if ($18) {
   $19 = (($pool) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($fl$0$i$i) + 1)|0;
   $22 = -1 << $21;
   $23 = $20 & $22;
   $24 = ($23|0)==(0);
   if ($24) {
    $block$02 = 0;
    STACKTOP = sp;return ($block$02|0);
   } else {
    $25 = (_llvm_cttz_i32(($23|0))|0);
    $26 = ((($pool) + ($25<<2)|0) + 20|0);
    $27 = HEAP32[$26>>2]|0;
    $fl$0$i = $25;$sl_map$0$i = $27;
    break;
   }
  } else {
   $fl$0$i = $fl$0$i$i;$sl_map$0$i = $17;
  }
 } while(0);
 $28 = (_llvm_cttz_i32(($sl_map$0$i|0))|0);
 $29 = ($sl_map$0$i|0)==(0);
 $30 = $29 ? -1 : $28;
 $31 = (((($pool) + ($fl$0$i<<7)|0) + ($30<<2)|0) + 116|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $block$02 = 0;
  STACKTOP = sp;return ($block$02|0);
 }
 $34 = (($32) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($32) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 12|0);
 HEAP32[$38>>2] = $35;
 $39 = (($35) + 8|0);
 HEAP32[$39>>2] = $37;
 $40 = HEAP32[$31>>2]|0;
 $41 = ($40|0)==($32|0);
 if (!($41)) {
  $block$02 = $32;
  STACKTOP = sp;return ($block$02|0);
 }
 HEAP32[$31>>2] = $37;
 $42 = ($37|0)==($pool|0);
 if (!($42)) {
  $block$02 = $32;
  STACKTOP = sp;return ($block$02|0);
 }
 $43 = 1 << $30;
 $44 = $43 ^ -1;
 $45 = ((($pool) + ($fl$0$i<<2)|0) + 20|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 & $44;
 HEAP32[$45>>2] = $47;
 $48 = ($47|0)==(0);
 if (!($48)) {
  $block$02 = $32;
  STACKTOP = sp;return ($block$02|0);
 }
 $49 = 1 << $fl$0$i;
 $50 = $49 ^ -1;
 $51 = (($pool) + 16|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = $52 & $50;
 HEAP32[$51>>2] = $53;
 $block$02 = $32;
 STACKTOP = sp;return ($block$02|0);
}
function _block_prepare_used($pool,$block,$size) {
 $pool = $pool|0;
 $block = $block|0;
 $size = $size|0;
 var $$neg$i$i = 0, $$pre = 0, $$pre$phi3Z2D = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $block$idx$i = 0, $block$idx$val$i = 0, $block$idx$val$i$i = 0, $block$idx$val$i$i$i = 0, $block$idx$val$i$i$i$i$i = 0, $block$idx$val$i$i$pre = 0, $fl$0$i$i$i = 0, $p$0 = 0, $phitmp$i$i$i$i = 0, $sl$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($block|0)==(0|0);
 if ($0) {
  $p$0 = 0;
  STACKTOP = sp;return ($p$0|0);
 }
 $block$idx$i = (($block) + 4|0);
 $block$idx$val$i = HEAP32[$block$idx$i>>2]|0;
 $1 = $block$idx$val$i & -4;
 $2 = (($size) + 16)|0;
 $3 = ($1>>>0)<($2>>>0);
 $$pre = (($block) + 8|0);
 if ($3) {
  $$pre2 = $$pre;
  $$pre$phi3Z2D = $$pre2;$block$idx$val$i$i = $block$idx$val$i;
 } else {
  $4 = (($size) + -4)|0;
  $5 = $$pre;
  $6 = (($4) + ($5))|0;
  $7 = $6;
  $$neg$i$i = (-4 - ($size))|0;
  $8 = (($$neg$i$i) + ($1))|0;
  $9 = (($7) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 & 3;
  $12 = $11 | $8;
  HEAP32[$9>>2] = $12;
  $13 = HEAP32[$block$idx$i>>2]|0;
  $14 = $13 & 3;
  $15 = $14 | $size;
  HEAP32[$block$idx$i>>2] = $15;
  $16 = (($7) + 8|0);
  $block$idx$val$i$i$i$i$i = HEAP32[$9>>2]|0;
  $17 = (($block$idx$val$i$i$i$i$i) + -4)|0;
  $18 = $17 & -4;
  $19 = $16;
  $20 = (($18) + ($19))|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (($21) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = $23 | 2;
  HEAP32[$22>>2] = $24;
  $25 = HEAP32[$9>>2]|0;
  $26 = $25 | 1;
  HEAP32[$9>>2] = $26;
  $block$idx$val$i$i$i = HEAP32[$block$idx$i>>2]|0;
  $27 = (($block$idx$val$i$i$i) + -4)|0;
  $28 = $27 & -4;
  $29 = (($28) + ($5))|0;
  $30 = $29;
  HEAP32[$30>>2] = $block;
  $31 = $25 | 3;
  HEAP32[$9>>2] = $31;
  $32 = $25 & -4;
  $33 = ($32>>>0)<(128);
  if ($33) {
   $34 = (($32|0) / 4)&-1;
   $fl$0$i$i$i = 0;$sl$0$i$i$i = $34;
  } else {
   $35 = (_llvm_ctlz_i32(($32|0))|0);
   $phitmp$i$i$i$i = (31 - ($35))|0;
   $36 = (($phitmp$i$i$i$i) + -5)|0;
   $37 = $32 >>> $36;
   $38 = $37 ^ 32;
   $39 = (($phitmp$i$i$i$i) + -6)|0;
   $fl$0$i$i$i = $39;$sl$0$i$i$i = $38;
  }
  $40 = (((($pool) + ($fl$0$i$i$i<<7)|0) + ($sl$0$i$i$i<<2)|0) + 116|0);
  $41 = HEAP32[$40>>2]|0;
  HEAP32[$16>>2] = $41;
  $42 = (($7) + 12|0);
  HEAP32[$42>>2] = $pool;
  $43 = (($41) + 12|0);
  HEAP32[$43>>2] = $7;
  HEAP32[$40>>2] = $7;
  $44 = 1 << $fl$0$i$i$i;
  $45 = (($pool) + 16|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = $46 | $44;
  HEAP32[$45>>2] = $47;
  $48 = 1 << $sl$0$i$i$i;
  $49 = ((($pool) + ($fl$0$i$i$i<<2)|0) + 20|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 | $48;
  HEAP32[$49>>2] = $51;
  $block$idx$val$i$i$pre = HEAP32[$block$idx$i>>2]|0;
  $$pre$phi3Z2D = $5;$block$idx$val$i$i = $block$idx$val$i$i$pre;
 }
 $52 = (($block$idx$val$i$i) + -4)|0;
 $53 = $52 & -4;
 $54 = (($53) + ($$pre$phi3Z2D))|0;
 $55 = $54;
 $56 = (($55) + 4|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $57 & -3;
 HEAP32[$56>>2] = $58;
 $59 = HEAP32[$block$idx$i>>2]|0;
 $60 = $59 & -2;
 HEAP32[$block$idx$i>>2] = $60;
 $p$0 = $$pre;
 STACKTOP = sp;return ($p$0|0);
}
function _tlsf_memalign($tlsf,$align,$size) {
 $tlsf = $tlsf|0;
 $align = $align|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $adjust$0$i = 0, $adjust$0$i3 = 0, $block$0 = 0, $block$idx$i = 0, $block$idx$val$i = 0, $block$idx$val$i$i$i = 0, $block$idx$val$i$i$i$i$i = 0, $fl$0$i$i$i = 0, $gap$0 = 0, $or$cond = 0, $or$cond$i = 0;
 var $or$cond$i2 = 0, $phitmp$i$i$i$i = 0, $sl$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)!=(0);
 $1 = ($size>>>0)<(1073741824);
 $or$cond$i = $0 & $1;
 if ($or$cond$i) {
  $2 = (($size) + 3)|0;
  $3 = $2 & -4;
  $4 = ($3>>>0)>(12);
  $5 = $4 ? $3 : 12;
  $adjust$0$i = $5;
 } else {
  $adjust$0$i = 0;
 }
 $6 = (($adjust$0$i) + ($align))|0;
 $7 = (($6) + 16)|0;
 $8 = ($7|0)!=(0);
 $9 = ($7>>>0)<(1073741824);
 $or$cond$i2 = $8 & $9;
 if ($or$cond$i2) {
  $10 = (($align) + 15)|0;
  $11 = (($10) + ($6))|0;
  $12 = (0 - ($align))|0;
  $13 = $11 & $12;
  $14 = ($13>>>0)>(12);
  $15 = $14 ? $13 : 12;
  $adjust$0$i3 = $15;
 } else {
  $adjust$0$i3 = 0;
 }
 $16 = ($align>>>0)<(5);
 $17 = $16 ? $adjust$0$i : $adjust$0$i3;
 $18 = (_block_locate_free($tlsf,$17)|0);
 $19 = ($18|0)==(0|0);
 if ($19) {
  $block$0 = 0;
  $88 = (_block_prepare_used($tlsf,$block$0,$adjust$0$i)|0);
  STACKTOP = sp;return ($88|0);
 }
 $20 = (($18) + 8|0);
 $21 = $20;
 $22 = (($align) + -1)|0;
 $23 = (($21) + ($22))|0;
 $24 = (0 - ($align))|0;
 $25 = $23 & $24;
 $26 = $25;
 $27 = (($25) - ($21))|0;
 $28 = ($26|0)!=($20|0);
 $29 = ($27>>>0)<(16);
 $or$cond = $28 & $29;
 if ($or$cond) {
  $30 = (16 - ($27))|0;
  $31 = ($30>>>0)>($align>>>0);
  $32 = $31 ? $30 : $align;
  $33 = (($25) + ($22))|0;
  $34 = (($33) + ($32))|0;
  $35 = $34 & $24;
  $36 = (($35) - ($21))|0;
  $gap$0 = $36;
 } else {
  $gap$0 = $27;
 }
 $37 = ($gap$0|0)==(0);
 if ($37) {
  $block$0 = $18;
  $88 = (_block_prepare_used($tlsf,$block$0,$adjust$0$i)|0);
  STACKTOP = sp;return ($88|0);
 }
 $block$idx$i = (($18) + 4|0);
 $block$idx$val$i = HEAP32[$block$idx$i>>2]|0;
 $38 = $block$idx$val$i & -4;
 $39 = (($gap$0) + 16)|0;
 $40 = ($38>>>0)<($39>>>0);
 if ($40) {
  $block$0 = $18;
  $88 = (_block_prepare_used($tlsf,$block$0,$adjust$0$i)|0);
  STACKTOP = sp;return ($88|0);
 }
 $41 = (($gap$0) + -4)|0;
 $42 = (($21) + -8)|0;
 $43 = (($42) + ($gap$0))|0;
 $44 = $43;
 $45 = (($38) - ($gap$0))|0;
 $46 = (($44) + 4|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = $47 & 3;
 $49 = $48 | $45;
 HEAP32[$46>>2] = $49;
 $50 = HEAP32[$block$idx$i>>2]|0;
 $51 = $50 & 3;
 $52 = $51 | $41;
 HEAP32[$block$idx$i>>2] = $52;
 $53 = (($44) + 8|0);
 $block$idx$val$i$i$i$i$i = HEAP32[$46>>2]|0;
 $54 = (($block$idx$val$i$i$i$i$i) + -4)|0;
 $55 = $54 & -4;
 $56 = $53;
 $57 = (($55) + ($56))|0;
 $58 = $57;
 HEAP32[$58>>2] = $44;
 $59 = (($58) + 4|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = $60 | 2;
 HEAP32[$59>>2] = $61;
 $62 = HEAP32[$46>>2]|0;
 $63 = $62 | 3;
 HEAP32[$46>>2] = $63;
 $block$idx$val$i$i$i = HEAP32[$block$idx$i>>2]|0;
 $64 = (($block$idx$val$i$i$i) + -4)|0;
 $65 = $64 & -4;
 $66 = (($65) + ($21))|0;
 $67 = $66;
 HEAP32[$67>>2] = $18;
 $68 = $block$idx$val$i$i$i & -4;
 $69 = ($68>>>0)<(128);
 if ($69) {
  $70 = (($68|0) / 4)&-1;
  $fl$0$i$i$i = 0;$sl$0$i$i$i = $70;
 } else {
  $71 = (_llvm_ctlz_i32(($68|0))|0);
  $phitmp$i$i$i$i = (31 - ($71))|0;
  $72 = (($phitmp$i$i$i$i) + -5)|0;
  $73 = $68 >>> $72;
  $74 = $73 ^ 32;
  $75 = (($phitmp$i$i$i$i) + -6)|0;
  $fl$0$i$i$i = $75;$sl$0$i$i$i = $74;
 }
 $76 = (((($tlsf) + ($fl$0$i$i$i<<7)|0) + ($sl$0$i$i$i<<2)|0) + 116|0);
 $77 = HEAP32[$76>>2]|0;
 HEAP32[$20>>2] = $77;
 $78 = (($18) + 12|0);
 HEAP32[$78>>2] = $tlsf;
 $79 = (($77) + 12|0);
 HEAP32[$79>>2] = $18;
 HEAP32[$76>>2] = $18;
 $80 = 1 << $fl$0$i$i$i;
 $81 = (($tlsf) + 16|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = $82 | $80;
 HEAP32[$81>>2] = $83;
 $84 = 1 << $sl$0$i$i$i;
 $85 = ((($tlsf) + ($fl$0$i$i$i<<2)|0) + 20|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = $86 | $84;
 HEAP32[$85>>2] = $87;
 $block$0 = $44;
 $88 = (_block_prepare_used($tlsf,$block$0,$adjust$0$i)|0);
 STACKTOP = sp;return ($88|0);
}
function _tlsf_free($tlsf,$ptr) {
 $tlsf = $tlsf|0;
 $ptr = $ptr|0;
 var $$0$i = 0, $$idx$i = 0, $$idx$val$i = 0, $$idx1$val$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $block$idx$i$i = 0, $block$idx$i$i$i = 0, $block$idx$i$i3 = 0, $block$idx$val$i = 0, $block$idx$val$i$i = 0, $block$idx$val$i$i$i = 0, $block$idx$val$i$i4 = 0, $block$idx1$val$i = 0, $block$idx2$val$i = 0, $fl$0$i$i = 0, $fl$0$i$i$i = 0, $fl$0$i$i$i7 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i$i = 0, $phitmp$i$i$i$i5 = 0, $sl$0$i$i = 0, $sl$0$i$i$i = 0, $sl$0$i$i$i8 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($ptr|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($ptr) + -8|0);
 $block$idx$i$i$i = (($ptr) + -4|0);
 $block$idx$val$i$i$i = HEAP32[$block$idx$i$i$i>>2]|0;
 $2 = (($block$idx$val$i$i$i) + -4)|0;
 $3 = $2 & -4;
 $4 = $ptr;
 $5 = (($3) + ($4))|0;
 $6 = $5;
 HEAP32[$6>>2] = $1;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 | 2;
 HEAP32[$7>>2] = $9;
 $10 = HEAP32[$block$idx$i$i$i>>2]|0;
 $11 = $10 | 1;
 HEAP32[$block$idx$i$i$i>>2] = $11;
 $12 = $10 & 2;
 $13 = ($12|0)==(0);
 if ($13) {
  $$0$i = $1;$block$idx$val$i$i = $11;
 } else {
  $block$idx1$val$i = HEAP32[$1>>2]|0;
  $block$idx$i$i3 = (($block$idx1$val$i) + 4|0);
  $block$idx$val$i$i4 = HEAP32[$block$idx$i$i3>>2]|0;
  $14 = $block$idx$val$i$i4 & -4;
  $15 = ($14>>>0)<(128);
  if ($15) {
   $16 = (($14|0) / 4)&-1;
   $fl$0$i$i$i7 = 0;$sl$0$i$i$i8 = $16;
  } else {
   $17 = (_llvm_ctlz_i32(($14|0))|0);
   $phitmp$i$i$i$i5 = (31 - ($17))|0;
   $18 = (($phitmp$i$i$i$i5) + -5)|0;
   $19 = $14 >>> $18;
   $20 = $19 ^ 32;
   $21 = (($phitmp$i$i$i$i5) + -6)|0;
   $fl$0$i$i$i7 = $21;$sl$0$i$i$i8 = $20;
  }
  $22 = (($block$idx1$val$i) + 12|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($block$idx1$val$i) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 12|0);
  HEAP32[$26>>2] = $23;
  $27 = (($23) + 8|0);
  HEAP32[$27>>2] = $25;
  $28 = (((($tlsf) + ($fl$0$i$i$i7<<7)|0) + ($sl$0$i$i$i8<<2)|0) + 116|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==($block$idx1$val$i|0);
  if ($30) {
   HEAP32[$28>>2] = $25;
   $31 = ($25|0)==($tlsf|0);
   if ($31) {
    $32 = 1 << $sl$0$i$i$i8;
    $33 = $32 ^ -1;
    $34 = ((($tlsf) + ($fl$0$i$i$i7<<2)|0) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $35 & $33;
    HEAP32[$34>>2] = $36;
    $37 = ($36|0)==(0);
    if ($37) {
     $38 = 1 << $fl$0$i$i$i7;
     $39 = $38 ^ -1;
     $40 = (($tlsf) + 16|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = $41 & $39;
     HEAP32[$40>>2] = $42;
    }
   }
  }
  $block$idx2$val$i = HEAP32[$block$idx$i$i$i>>2]|0;
  $43 = (($block$idx2$val$i) + 4)|0;
  $44 = $43 & -4;
  $45 = HEAP32[$block$idx$i$i3>>2]|0;
  $46 = (($44) + ($45))|0;
  HEAP32[$block$idx$i$i3>>2] = $46;
  $47 = (($46) + -4)|0;
  $48 = $47 & -4;
  $49 = $24;
  $50 = (($48) + ($49))|0;
  $51 = $50;
  HEAP32[$51>>2] = $block$idx1$val$i;
  $$0$i = $block$idx1$val$i;$block$idx$val$i$i = $46;
 }
 $52 = (($$0$i) + 8|0);
 $block$idx$i$i = (($$0$i) + 4|0);
 $53 = (($block$idx$val$i$i) + -4)|0;
 $54 = $53 & -4;
 $55 = $52;
 $56 = (($54) + ($55))|0;
 $57 = $56;
 $$idx$i = (($57) + 4|0);
 $$idx$val$i = HEAP32[$$idx$i>>2]|0;
 $58 = $$idx$val$i & 1;
 $59 = ($58|0)==(0);
 if ($59) {
  $block$idx$val$i = $block$idx$val$i$i;
 } else {
  $60 = $$idx$val$i & -4;
  $61 = ($60>>>0)<(128);
  if ($61) {
   $62 = (($60|0) / 4)&-1;
   $fl$0$i$i$i = 0;$sl$0$i$i$i = $62;
  } else {
   $63 = (_llvm_ctlz_i32(($60|0))|0);
   $phitmp$i$i$i$i = (31 - ($63))|0;
   $64 = (($phitmp$i$i$i$i) + -5)|0;
   $65 = $60 >>> $64;
   $66 = $65 ^ 32;
   $67 = (($phitmp$i$i$i$i) + -6)|0;
   $fl$0$i$i$i = $67;$sl$0$i$i$i = $66;
  }
  $68 = (($57) + 12|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = (($57) + 8|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = (($71) + 12|0);
  HEAP32[$72>>2] = $69;
  $73 = (($69) + 8|0);
  HEAP32[$73>>2] = $71;
  $74 = (((($tlsf) + ($fl$0$i$i$i<<7)|0) + ($sl$0$i$i$i<<2)|0) + 116|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($75|0)==($57|0);
  if ($76) {
   HEAP32[$74>>2] = $71;
   $77 = ($71|0)==($tlsf|0);
   if ($77) {
    $78 = 1 << $sl$0$i$i$i;
    $79 = $78 ^ -1;
    $80 = ((($tlsf) + ($fl$0$i$i$i<<2)|0) + 20|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = $81 & $79;
    HEAP32[$80>>2] = $82;
    $83 = ($82|0)==(0);
    if ($83) {
     $84 = 1 << $fl$0$i$i$i;
     $85 = $84 ^ -1;
     $86 = (($tlsf) + 16|0);
     $87 = HEAP32[$86>>2]|0;
     $88 = $87 & $85;
     HEAP32[$86>>2] = $88;
    }
   }
  }
  $$idx1$val$i = HEAP32[$$idx$i>>2]|0;
  $89 = (($$idx1$val$i) + 4)|0;
  $90 = $89 & -4;
  $91 = HEAP32[$block$idx$i$i>>2]|0;
  $92 = (($90) + ($91))|0;
  HEAP32[$block$idx$i$i>>2] = $92;
  $93 = (($92) + -4)|0;
  $94 = $93 & -4;
  $95 = (($94) + ($55))|0;
  $96 = $95;
  HEAP32[$96>>2] = $$0$i;
  $block$idx$val$i = $92;
 }
 $97 = $block$idx$val$i & -4;
 $98 = ($97>>>0)<(128);
 if ($98) {
  $99 = (($97|0) / 4)&-1;
  $fl$0$i$i = 0;$sl$0$i$i = $99;
 } else {
  $100 = (_llvm_ctlz_i32(($97|0))|0);
  $phitmp$i$i$i = (31 - ($100))|0;
  $101 = (($phitmp$i$i$i) + -5)|0;
  $102 = $97 >>> $101;
  $103 = $102 ^ 32;
  $104 = (($phitmp$i$i$i) + -6)|0;
  $fl$0$i$i = $104;$sl$0$i$i = $103;
 }
 $105 = (((($tlsf) + ($fl$0$i$i<<7)|0) + ($sl$0$i$i<<2)|0) + 116|0);
 $106 = HEAP32[$105>>2]|0;
 HEAP32[$52>>2] = $106;
 $107 = (($$0$i) + 12|0);
 HEAP32[$107>>2] = $tlsf;
 $108 = (($106) + 12|0);
 HEAP32[$108>>2] = $$0$i;
 HEAP32[$105>>2] = $$0$i;
 $109 = 1 << $fl$0$i$i;
 $110 = (($tlsf) + 16|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = $111 | $109;
 HEAP32[$110>>2] = $112;
 $113 = 1 << $sl$0$i$i;
 $114 = ((($tlsf) + ($fl$0$i$i<<2)|0) + 20|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = $115 | $113;
 HEAP32[$114>>2] = $116;
 STACKTOP = sp;return;
}
function _block_trim_used($pool,$block,$size) {
 $pool = $pool|0;
 $block = $block|0;
 $size = $size|0;
 var $$idx$i = 0, $$idx$val$i = 0, $$idx1$val$i = 0, $$neg$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $block$idx = 0, $block$idx$val = 0, $block$idx$val$i = 0, $block$idx$val$i$i$i$i = 0, $fl$0$i$i = 0;
 var $fl$0$i$i$i = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i$i = 0, $sl$0$i$i = 0, $sl$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $block$idx = (($block) + 4|0);
 $block$idx$val = HEAP32[$block$idx>>2]|0;
 $0 = $block$idx$val & -4;
 $1 = (($size) + 16)|0;
 $2 = ($0>>>0)<($1>>>0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($block) + 8|0);
 $4 = (($size) + -4)|0;
 $5 = $3;
 $6 = (($4) + ($5))|0;
 $7 = $6;
 $$neg$i = (-4 - ($size))|0;
 $8 = (($$neg$i) + ($0))|0;
 $9 = (($7) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 3;
 $12 = $11 | $8;
 HEAP32[$9>>2] = $12;
 $13 = HEAP32[$block$idx>>2]|0;
 $14 = $13 & 3;
 $15 = $14 | $size;
 HEAP32[$block$idx>>2] = $15;
 $16 = (($7) + 8|0);
 $block$idx$val$i$i$i$i = HEAP32[$9>>2]|0;
 $17 = (($block$idx$val$i$i$i$i) + -4)|0;
 $18 = $17 & -4;
 $19 = $16;
 $20 = (($18) + ($19))|0;
 $21 = $20;
 HEAP32[$21>>2] = $7;
 $22 = (($21) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 | 2;
 HEAP32[$22>>2] = $24;
 $25 = HEAP32[$9>>2]|0;
 $26 = $25 & -4;
 $27 = $26 | 1;
 HEAP32[$9>>2] = $27;
 $28 = (($27) + -4)|0;
 $29 = $28 & -4;
 $30 = (($29) + ($19))|0;
 $31 = $30;
 $$idx$i = (($31) + 4|0);
 $$idx$val$i = HEAP32[$$idx$i>>2]|0;
 $32 = $$idx$val$i & 1;
 $33 = ($32|0)==(0);
 if ($33) {
  $block$idx$val$i = $27;
 } else {
  $34 = $$idx$val$i & -4;
  $35 = ($34>>>0)<(128);
  if ($35) {
   $36 = (($34|0) / 4)&-1;
   $fl$0$i$i$i = 0;$sl$0$i$i$i = $36;
  } else {
   $37 = (_llvm_ctlz_i32(($34|0))|0);
   $phitmp$i$i$i$i = (31 - ($37))|0;
   $38 = (($phitmp$i$i$i$i) + -5)|0;
   $39 = $34 >>> $38;
   $40 = $39 ^ 32;
   $41 = (($phitmp$i$i$i$i) + -6)|0;
   $fl$0$i$i$i = $41;$sl$0$i$i$i = $40;
  }
  $42 = (($31) + 12|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($31) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 12|0);
  HEAP32[$46>>2] = $43;
  $47 = (($43) + 8|0);
  HEAP32[$47>>2] = $45;
  $48 = (((($pool) + ($fl$0$i$i$i<<7)|0) + ($sl$0$i$i$i<<2)|0) + 116|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==($31|0);
  if ($50) {
   HEAP32[$48>>2] = $45;
   $51 = ($45|0)==($pool|0);
   if ($51) {
    $52 = 1 << $sl$0$i$i$i;
    $53 = $52 ^ -1;
    $54 = ((($pool) + ($fl$0$i$i$i<<2)|0) + 20|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = $55 & $53;
    HEAP32[$54>>2] = $56;
    $57 = ($56|0)==(0);
    if ($57) {
     $58 = 1 << $fl$0$i$i$i;
     $59 = $58 ^ -1;
     $60 = (($pool) + 16|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = $61 & $59;
     HEAP32[$60>>2] = $62;
    }
   }
  }
  $$idx1$val$i = HEAP32[$$idx$i>>2]|0;
  $63 = (($$idx1$val$i) + 4)|0;
  $64 = $63 & -4;
  $65 = HEAP32[$9>>2]|0;
  $66 = (($64) + ($65))|0;
  HEAP32[$9>>2] = $66;
  $67 = (($66) + -4)|0;
  $68 = $67 & -4;
  $69 = (($68) + ($19))|0;
  $70 = $69;
  HEAP32[$70>>2] = $7;
  $block$idx$val$i = $66;
 }
 $71 = $block$idx$val$i & -4;
 $72 = ($71>>>0)<(128);
 if ($72) {
  $73 = (($71|0) / 4)&-1;
  $fl$0$i$i = 0;$sl$0$i$i = $73;
 } else {
  $74 = (_llvm_ctlz_i32(($71|0))|0);
  $phitmp$i$i$i = (31 - ($74))|0;
  $75 = (($phitmp$i$i$i) + -5)|0;
  $76 = $71 >>> $75;
  $77 = $76 ^ 32;
  $78 = (($phitmp$i$i$i) + -6)|0;
  $fl$0$i$i = $78;$sl$0$i$i = $77;
 }
 $79 = (((($pool) + ($fl$0$i$i<<7)|0) + ($sl$0$i$i<<2)|0) + 116|0);
 $80 = HEAP32[$79>>2]|0;
 HEAP32[$16>>2] = $80;
 $81 = (($7) + 12|0);
 HEAP32[$81>>2] = $pool;
 $82 = (($80) + 12|0);
 HEAP32[$82>>2] = $7;
 HEAP32[$79>>2] = $7;
 $83 = 1 << $fl$0$i$i;
 $84 = (($pool) + 16|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = $85 | $83;
 HEAP32[$84>>2] = $86;
 $87 = 1 << $sl$0$i$i;
 $88 = ((($pool) + ($fl$0$i$i<<2)|0) + 20|0);
 $89 = HEAP32[$88>>2]|0;
 $90 = $89 | $87;
 HEAP32[$88>>2] = $90;
 STACKTOP = sp;return;
}
function _tlsf_realloc_align($tlsf,$ptr,$align,$size) {
 $tlsf = $tlsf|0;
 $ptr = $ptr|0;
 $align = $align|0;
 $size = $size|0;
 var $$idx = 0, $$idx$val = 0, $$idx1$val$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $9 = 0, $adjust$0$i6 = 0, $block$idx$i = 0, $block$idx$val$i = 0, $block$idx$val$i$i = 0, $fl$0$i$i$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond1 = 0, $p$0 = 0, $phitmp$i$i$i$i = 0, $sl$0$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ptr|0)!=(0|0);
 $1 = ($size|0)==(0);
 $or$cond = $0 & $1;
 if ($or$cond) {
  _tlsf_free($tlsf,$ptr);
  $p$0 = 0;
  STACKTOP = sp;return ($p$0|0);
 }
 if (!($0)) {
  $2 = (_tlsf_memalign($tlsf,$align,$size)|0);
  $p$0 = $2;
  STACKTOP = sp;return ($p$0|0);
 }
 $3 = (($ptr) + -8|0);
 $block$idx$i = (($ptr) + -4|0);
 $block$idx$val$i = HEAP32[$block$idx$i>>2]|0;
 $4 = (($block$idx$val$i) + -4)|0;
 $5 = $4 & -4;
 $6 = $ptr;
 $7 = (($5) + ($6))|0;
 $8 = $7;
 $9 = $block$idx$val$i & -4;
 $$idx = (($8) + 4|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $10 = $$idx$val & -4;
 $11 = (($9) + 4)|0;
 $12 = (($11) + ($10))|0;
 $13 = ($size|0)!=(0);
 $14 = ($size>>>0)<(1073741824);
 $or$cond$i = $13 & $14;
 if ($or$cond$i) {
  $15 = (($size) + 3)|0;
  $16 = $15 & -4;
  $17 = ($16>>>0)>(12);
  $18 = $17 ? $16 : 12;
  $19 = ($18>>>0)>($9>>>0);
  if ($19) {
   $20 = $$idx$val & 1;
   $21 = ($20|0)==(0);
   $22 = ($18>>>0)>($12>>>0);
   $or$cond1 = $21 | $22;
   if (!($or$cond1)) {
    $80 = 1;$adjust$0$i6 = $18;
    label = 8;
   }
  } else {
   $80 = 0;$adjust$0$i6 = $18;
   label = 8;
  }
 } else {
  $80 = 0;$adjust$0$i6 = 0;
  label = 8;
 }
 if ((label|0) == 8) {
  $23 = (($align) + -1)|0;
  $24 = (($23) + ($6))|0;
  $25 = (0 - ($align))|0;
  $26 = $24 & $25;
  $27 = $26;
  $28 = ($27|0)==($ptr|0);
  if ($28) {
   if ($80) {
    $33 = $$idx$val & 1;
    $34 = ($33|0)==(0);
    if ($34) {
     $block$idx$val$i$i = $block$idx$val$i;
    } else {
     $35 = ($10>>>0)<(128);
     if ($35) {
      $36 = (($10|0) / 4)&-1;
      $fl$0$i$i$i = 0;$sl$0$i$i$i = $36;
     } else {
      $37 = (_llvm_ctlz_i32(($10|0))|0);
      $phitmp$i$i$i$i = (31 - ($37))|0;
      $38 = (($phitmp$i$i$i$i) + -5)|0;
      $39 = $10 >>> $38;
      $40 = $39 ^ 32;
      $41 = (($phitmp$i$i$i$i) + -6)|0;
      $fl$0$i$i$i = $41;$sl$0$i$i$i = $40;
     }
     $42 = (($8) + 12|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($8) + 8|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = (($45) + 12|0);
     HEAP32[$46>>2] = $43;
     $47 = (($43) + 8|0);
     HEAP32[$47>>2] = $45;
     $48 = (((($tlsf) + ($fl$0$i$i$i<<7)|0) + ($sl$0$i$i$i<<2)|0) + 116|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==($8|0);
     if ($50) {
      HEAP32[$48>>2] = $45;
      $51 = ($45|0)==($tlsf|0);
      if ($51) {
       $52 = 1 << $sl$0$i$i$i;
       $53 = $52 ^ -1;
       $54 = ((($tlsf) + ($fl$0$i$i$i<<2)|0) + 20|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = $55 & $53;
       HEAP32[$54>>2] = $56;
       $57 = ($56|0)==(0);
       if ($57) {
        $58 = 1 << $fl$0$i$i$i;
        $59 = $58 ^ -1;
        $60 = (($tlsf) + 16|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = $61 & $59;
        HEAP32[$60>>2] = $62;
       }
      }
     }
     $$idx1$val$i = HEAP32[$$idx>>2]|0;
     $63 = (($$idx1$val$i) + 4)|0;
     $64 = $63 & -4;
     $65 = HEAP32[$block$idx$i>>2]|0;
     $66 = (($64) + ($65))|0;
     HEAP32[$block$idx$i>>2] = $66;
     $67 = (($66) + -4)|0;
     $68 = $67 & -4;
     $69 = (($68) + ($6))|0;
     $70 = $69;
     HEAP32[$70>>2] = $3;
     $block$idx$val$i$i = $66;
    }
    $71 = (($block$idx$val$i$i) + -4)|0;
    $72 = $71 & -4;
    $73 = (($72) + ($6))|0;
    $74 = $73;
    $75 = (($74) + 4|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = $76 & -3;
    HEAP32[$75>>2] = $77;
    $78 = HEAP32[$block$idx$i>>2]|0;
    $79 = $78 & -2;
    HEAP32[$block$idx$i>>2] = $79;
   }
   _block_trim_used($tlsf,$3,$adjust$0$i6);
   $p$0 = $ptr;
   STACKTOP = sp;return ($p$0|0);
  }
 }
 $29 = (_tlsf_memalign($tlsf,$align,$size)|0);
 $30 = ($29|0)==(0|0);
 if ($30) {
  $p$0 = 0;
  STACKTOP = sp;return ($p$0|0);
 }
 $31 = ($9>>>0)<($size>>>0);
 $32 = $31 ? $9 : $size;
 _memcpy(($29|0),($ptr|0),($32|0))|0;
 _tlsf_free($tlsf,$ptr);
 $p$0 = $29;
 STACKTOP = sp;return ($p$0|0);
}
function __Z19GetGLExtProcAddressPKc($name) {
 $name = $name|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_emscripten_GetProcAddress($name)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN4gles7InitApiE17GfxDeviceRendererP12GraphicsCaps($renderer,$caps) {
 $renderer = $renderer|0;
 $caps = $caps|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 _memset((1147664|0),0,520)|0;
 dest=1147616+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[1147664>>2] = 3767;
 $0 = (1147664 + 4|0);
 HEAP32[$0>>2] = 3468;
 $1 = (1147664 + 8|0);
 HEAP32[$1>>2] = 2088;
 $2 = (1147664 + 12|0);
 HEAP32[$2>>2] = 3469;
 $3 = (1147664 + 16|0);
 HEAP32[$3>>2] = 3470;
 $4 = (1147664 + 20|0);
 HEAP32[$4>>2] = 3471;
 $5 = (1147664 + 24|0);
 HEAP32[$5>>2] = 3472;
 $6 = (1147664 + 28|0);
 HEAP32[$6>>2] = 3473;
 $7 = (1147664 + 32|0);
 HEAP32[$7>>2] = 437;
 $8 = (1147664 + 36|0);
 HEAP32[$8>>2] = 438;
 $9 = (1147664 + 40|0);
 HEAP32[$9>>2] = 439;
 $10 = (1147664 + 44|0);
 HEAP32[$10>>2] = 3455;
 $11 = (1147664 + 48|0);
 HEAP32[$11>>2] = 3768;
 $12 = (1147664 + 52|0);
 HEAP32[$12>>2] = 1;
 $13 = (1147664 + 56|0);
 HEAP32[$13>>2] = 1;
 $14 = (1147664 + 60|0);
 HEAP32[$14>>2] = 3769;
 $15 = (1147664 + 64|0);
 HEAP32[$15>>2] = 440;
 $16 = (1147664 + 68|0);
 HEAP32[$16>>2] = 3770;
 $17 = (1147664 + 72|0);
 HEAP32[$17>>2] = 34;
 $18 = (1147664 + 76|0);
 HEAP32[$18>>2] = 14;
 $19 = (1147664 + 80|0);
 HEAP32[$19>>2] = 35;
 $20 = (1147664 + 84|0);
 HEAP32[$20>>2] = 128;
 $21 = (1147664 + 88|0);
 HEAP32[$21>>2] = 3456;
 $22 = (1147664 + 92|0);
 HEAP32[$22>>2] = 3771;
 $23 = (1147664 + 96|0);
 HEAP32[$23>>2] = 3474;
 $24 = (1147664 + 100|0);
 HEAP32[$24>>2] = 3475;
 $25 = (1147664 + 104|0);
 HEAP32[$25>>2] = 3772;
 $26 = (1147664 + 108|0);
 HEAP32[$26>>2] = 3476;
 $27 = (1147664 + 112|0);
 HEAP32[$27>>2] = 3773;
 $28 = (1147664 + 116|0);
 HEAP32[$28>>2] = 3477;
 $29 = (1147664 + 120|0);
 HEAP32[$29>>2] = 3774;
 $30 = (1147664 + 124|0);
 HEAP32[$30>>2] = 3775;
 $31 = (1147664 + 128|0);
 HEAP32[$31>>2] = 3776;
 $32 = (1147664 + 132|0);
 HEAP32[$32>>2] = 3777;
 $33 = (1147664 + 136|0);
 HEAP32[$33>>2] = 2089;
 $34 = (1147664 + 140|0);
 HEAP32[$34>>2] = 441;
 $35 = (1147664 + 144|0);
 HEAP32[$35>>2] = 3778;
 $36 = (1147664 + 148|0);
 HEAP32[$36>>2] = 3779;
 $37 = (1147664 + 152|0);
 HEAP32[$37>>2] = 270;
 $38 = (1147664 + 156|0);
 HEAP32[$38>>2] = 271;
 $39 = (1147664 + 160|0);
 HEAP32[$39>>2] = 442;
 $40 = (1147664 + 164|0);
 HEAP32[$40>>2] = 115;
 $41 = (1147664 + 168|0);
 HEAP32[$41>>2] = 3780;
 $42 = (1147664 + 172|0);
 HEAP32[$42>>2] = 3478;
 $43 = (1147664 + 176|0);
 HEAP32[$43>>2] = 3781;
 $44 = (1147664 + 180|0);
 HEAP32[$44>>2] = 3479;
 $45 = (1147664 + 184|0);
 HEAP32[$45>>2] = 3480;
 $46 = (1147664 + 188|0);
 HEAP32[$46>>2] = 3481;
 $47 = (1147664 + 192|0);
 HEAP32[$47>>2] = 73;
 $48 = (1147664 + 196|0);
 HEAP32[$48>>2] = 74;
 $49 = (1147664 + 200|0);
 HEAP32[$49>>2] = 2718;
 $50 = (1147664 + 204|0);
 HEAP32[$50>>2] = 129;
 $51 = (1147664 + 208|0);
 HEAP32[$51>>2] = 443;
 $52 = (1147664 + 212|0);
 HEAP32[$52>>2] = 3482;
 $53 = (1147664 + 216|0);
 HEAP32[$53>>2] = 2090;
 $54 = (1147664 + 220|0);
 HEAP32[$54>>2] = 444;
 $55 = (1147664 + 224|0);
 HEAP32[$55>>2] = 2091;
 $56 = (1147664 + 228|0);
 HEAP32[$56>>2] = 445;
 $57 = (1147664 + 232|0);
 HEAP32[$57>>2] = 3457;
 $58 = (1147664 + 236|0);
 HEAP32[$58>>2] = 2092;
 $59 = (1147664 + 240|0);
 HEAP32[$59>>2] = 2719;
 $60 = (1147664 + 244|0);
 HEAP32[$60>>2] = 2093;
 $61 = (1147664 + 248|0);
 HEAP32[$61>>2] = 2094;
 $62 = (1147664 + 252|0);
 HEAP32[$62>>2] = 2095;
 $63 = (1147664 + 256|0);
 HEAP32[$63>>2] = 3782;
 $64 = (1147664 + 260|0);
 HEAP32[$64>>2] = 3483;
 $65 = (1147664 + 264|0);
 HEAP32[$65>>2] = 1;
 $66 = (1147664 + 268|0);
 HEAP32[$66>>2] = 75;
 $67 = (1147664 + 272|0);
 HEAP32[$67>>2] = 446;
 $68 = (1147664 + 276|0);
 HEAP32[$68>>2] = 447;
 $69 = (1147664 + 280|0);
 HEAP32[$69>>2] = 448;
 $70 = (1147664 + 284|0);
 HEAP32[$70>>2] = 2096;
 $71 = (1147664 + 288|0);
 HEAP32[$71>>2] = 449;
 $72 = (1147664 + 292|0);
 HEAP32[$72>>2] = 3783;
 $73 = (1147664 + 296|0);
 HEAP32[$73>>2] = 2097;
 $74 = (1147664 + 300|0);
 HEAP32[$74>>2] = 450;
 $75 = (1147664 + 304|0);
 HEAP32[$75>>2] = 15;
 $76 = (1147664 + 308|0);
 HEAP32[$76>>2] = 2098;
 $77 = (1147664 + 312|0);
 HEAP32[$77>>2] = 16;
 $78 = (1147664 + 316|0);
 HEAP32[$78>>2] = 2099;
 $79 = (1147664 + 320|0);
 HEAP32[$79>>2] = 3484;
 $80 = (1147664 + 324|0);
 HEAP32[$80>>2] = 2100;
 $81 = (1147664 + 328|0);
 HEAP32[$81>>2] = 2101;
 $82 = (1147664 + 332|0);
 HEAP32[$82>>2] = 2102;
 $83 = (1147664 + 336|0);
 HEAP32[$83>>2] = 2103;
 $84 = (1147664 + 340|0);
 HEAP32[$84>>2] = 2104;
 $85 = (1147664 + 344|0);
 HEAP32[$85>>2] = 2105;
 $86 = (1147664 + 348|0);
 HEAP32[$86>>2] = 2106;
 $87 = (1147664 + 352|0);
 HEAP32[$87>>2] = 451;
 $88 = (1147664 + 356|0);
 HEAP32[$88>>2] = 452;
 $89 = (1147664 + 360|0);
 HEAP32[$89>>2] = 3784;
 $90 = (1147664 + 364|0);
 HEAP32[$90>>2] = 7;
 $91 = (1147664 + 368|0);
 HEAP32[$91>>2] = 139;
 $92 = (1147664 + 372|0);
 HEAP32[$92>>2] = 453;
 __ZN4gles8internal14InitCapsCommonE17GfxDeviceRendererP12GraphicsCaps($renderer,$caps);
 $93 = ($renderer|0)==(8);
 if (!($93)) {
  __ZN4gles8internal24InitTextureFormatSupportE17GfxDeviceRendererP12GraphicsCaps($renderer,$caps);
  __ZN4gles8internal19InitCoreApiOverrideEP12CoreFuncGLES(1147664);
  STACKTOP = sp;return;
 }
 __ZN4gles8internal12InitApiGLES2EP12GraphicsCapsP12CoreFuncGLESP11ExtFuncGLES($caps,1147664,1147616);
 __ZN4gles8internal24InitTextureFormatSupportE17GfxDeviceRendererP12GraphicsCaps($renderer,$caps);
 __ZN4gles8internal19InitCoreApiOverrideEP12CoreFuncGLES(1147664);
 STACKTOP = sp;return;
}
function __ZN4gles8internal19InitCoreApiOverrideEP12CoreFuncGLES($core) {
 $core = $core|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[1148184+0>>2]=0|0;HEAP32[1148184+4>>2]=0|0;HEAP32[1148184+8>>2]=0|0;HEAP32[1148184+12>>2]=0|0;HEAP32[1148184+16>>2]=0|0;
 $0 = HEAP32[((640792 + 280|0))>>2]|0;
 HEAP32[1148216>>2] = $0;
 $1 = ($0*24)|0;
 $2 = (_malloc($1)|0);
 HEAP32[1148208>>2] = $2;
 _memset(($2|0),0,($1|0))|0;
 $3 = (_malloc($0)|0);
 HEAP32[1148224>>2] = $3;
 _memset(($3|0),0,($0|0))|0;
 $4 = (($core) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  HEAP32[1148232>>2] = $5;
  HEAP32[$4>>2] = 3485;
 }
 $7 = (($core) + 368|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  HEAP32[1148240>>2] = $8;
  HEAP32[$7>>2] = 140;
 }
 $10 = (($core) + 96|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(0|0);
 if (!($12)) {
  HEAP32[1148248>>2] = $11;
  HEAP32[$10>>2] = 3486;
 }
 $13 = (($core) + 436|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  HEAP32[1148256>>2] = $14;
  HEAP32[$13>>2] = 3785;
 }
 $16 = (($core) + 132|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  HEAP32[1148264>>2] = $17;
  HEAP32[$16>>2] = 3786;
 }
 $19 = (($core) + 148|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  STACKTOP = sp;return;
 }
 HEAP32[1148272>>2] = $20;
 HEAP32[$19>>2] = 3787;
 STACKTOP = sp;return;
}
function __Z26GLES_InvalidateApiOverridev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[1148184+0>>2]=0|0;HEAP32[1148184+4>>2]=0|0;HEAP32[1148184+8>>2]=0|0;HEAP32[1148184+12>>2]=0|0;HEAP32[1148184+16>>2]=0|0;
 $0 = HEAP32[1148208>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[1148216>>2]|0;
  $3 = ($2*24)|0;
  _memset(($0|0),0,($3|0))|0;
 }
 $4 = HEAP32[1148224>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[1148216>>2]|0;
 _memset(($4|0),0,($6|0))|0;
 STACKTOP = sp;return;
}
function __ZL20glBindBufferOverridejj($target,$buffer) {
 $target = $target|0;
 $buffer = $buffer|0;
 var $$0$i = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($target|0) == 35345)) {
  $$0$i = 2;
 } else if ((($target|0) == 35982)) {
  $$0$i = 3;
 } else if ((($target|0) == 34963)) {
  $$0$i = 1;
 } else if ((($target|0) == 36663)) {
  $$0$i = 4;
 } else {
  $$0$i = 0;
 }
 $0 = ($buffer|0)==(0);
 $$pre = (1148184 + ($$0$i<<2)|0);
 if (!($0)) {
  $1 = HEAP32[$$pre>>2]|0;
  $2 = ($1|0)==($buffer|0);
  if ($2) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$$pre>>2] = $buffer;
 $3 = HEAP32[1148232>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($target,$buffer);
 $4 = HEAP32[1149528>>2]|0;
 $5 = (($4) + 192|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 | 7;
 HEAP32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZL29glVertexAttribPointerOverridejijhiPKv($index,$size,$type,$normalized,$stride,$pointer) {
 $index = $index|0;
 $size = $size|0;
 $type = $type|0;
 $normalized = $normalized|0;
 $stride = $stride|0;
 $pointer = $pointer|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $input = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $input = sp;
 HEAP32[$input>>2] = $pointer;
 $0 = (($input) + 4|0);
 HEAP32[$0>>2] = $stride;
 $1 = (($input) + 8|0);
 $2 = HEAP32[1148184>>2]|0;
 HEAP32[$1>>2] = $2;
 $3 = (($input) + 12|0);
 HEAP32[$3>>2] = $size;
 $4 = (($input) + 16|0);
 HEAP32[$4>>2] = $type;
 $5 = (($input) + 20|0);
 HEAP8[$5>>0] = $normalized;
 $6 = HEAP32[1148208>>2]|0;
 $7 = (($6) + (($index*24)|0)|0);
 $8 = $pointer;
 $14 = $8;$i$01$i$i = 0;
 while(1) {
  $11 = (($7) + ($i$01$i$i<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($14|0)==($12|0);
  $10 = (($i$01$i$i) + 1)|0;
  if (!($13)) {
   break;
  }
  $9 = ($10|0)<(6);
  if (!($9)) {
   label = 6;
   break;
  }
  $$phi$trans$insert = (($input) + ($10<<2)|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $14 = $$pre;$i$01$i$i = $10;
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$7+0>>2]=HEAP32[$input+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$input+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$input+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$input+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$input+16>>2]|0;HEAP32[$7+20>>2]=HEAP32[$input+20>>2]|0;
 $15 = HEAP32[1148240>>2]|0;
 FUNCTION_TABLE_viiiiii[$15 & 255]($index,$size,$type,$normalized,$stride,$pointer);
 STACKTOP = sp;return;
}
function __ZL23glDeleteBuffersOverrideiPKj($n,$buffers) {
 $n = $n|0;
 $buffers = $buffers|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond6 = 0, $i$02 = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)>(0);
 if (!($0)) {
  $11 = HEAP32[1148248>>2]|0;
  FUNCTION_TABLE_vii[$11 & 4095]($n,$buffers);
  STACKTOP = sp;return;
 }
 $1 = HEAP32[1148208>>2]|0;
 $$pre = HEAP32[1148216>>2]|0;
 $i$02 = 0;
 while(1) {
  $2 = ($$pre|0)>(0);
  if ($2) {
   $3 = (($buffers) + ($i$02<<2)|0);
   $j$01 = 0;
   while(1) {
    $4 = ((($1) + (($j$01*24)|0)|0) + 8|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = HEAP32[$3>>2]|0;
    $7 = ($5|0)==($6|0);
    if ($7) {
     $8 = (($1) + (($j$01*24)|0)|0);
     ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;HEAP32[$8+12>>2]=0|0;HEAP32[$8+16>>2]=0|0;HEAP32[$8+20>>2]=0|0;
    }
    $9 = (($j$01) + 1)|0;
    $exitcond = ($9|0)==($$pre|0);
    if ($exitcond) {
     break;
    } else {
     $j$01 = $9;
    }
   }
  }
  $10 = (($i$02) + 1)|0;
  $exitcond6 = ($10|0)==($n|0);
  if ($exitcond6) {
   break;
  } else {
   $i$02 = $10;
  }
 }
 $11 = HEAP32[1148248>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095]($n,$buffers);
 STACKTOP = sp;return;
}
function __ZL25glBindVertexArrayOverridej($array) {
 $array = $array|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[1148184+0>>2]=0|0;HEAP32[1148184+4>>2]=0|0;HEAP32[1148184+8>>2]=0|0;HEAP32[1148184+12>>2]=0|0;HEAP32[1148184+16>>2]=0|0;
 $0 = HEAP32[1148208>>2]|0;
 $1 = HEAP32[1148216>>2]|0;
 $2 = ($1*24)|0;
 _memset(($0|0),0,($2|0))|0;
 $3 = HEAP32[1148256>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($array);
 STACKTOP = sp;return;
}
function __ZL34glDisableVertexAttribArrayOverridej($index) {
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1148224>>2]|0;
 $1 = (($0) + ($index)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[1148264>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($index);
 $5 = HEAP32[1148224>>2]|0;
 $6 = (($5) + ($index)|0);
 HEAP8[$6>>0] = 0;
 STACKTOP = sp;return;
}
function __ZL33glEnableVertexAttribArrayOverridej($index) {
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1148224>>2]|0;
 $1 = (($0) + ($index)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = HEAP32[1148272>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($index);
 $5 = HEAP32[1148224>>2]|0;
 $6 = (($5) + ($index)|0);
 HEAP8[$6>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN20TextureCombinersGLES6CreateEiPKN9ShaderLab14TextureBindingE($count,$texEnvs) {
 $count = $count|0;
 $texEnvs = $texEnvs|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($count) + 3)|0;
 $2 = HEAP32[1152880>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $6 = (__Znwj10MemLabelIdbiPKci(8,$$byval_copy,0,16,1148280,14)|0);
 $7 = (($6) + 4|0);
 HEAP32[$6>>2] = $count;
 HEAP32[$7>>2] = $texEnvs;
 $$0 = $6;
 STACKTOP = sp;return ($$0|0);
}
function __ZN19ConstantBuffersGLESC2Ev($this) {
 $this = $this|0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$this+0|0; stop=dest+88|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN19ConstantBuffersGLES5ClearEv($this) {
 $this = $this|0;
 var $$lcssa = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $__new_last2$i$i$i1 = 0;
 var $i$08 = 0, $scevgep$i$i$i = 0, $scevgep$i$i$i2 = 0, $scevgep4$i$i$i = 0, $scevgep4$i$i$i6 = 0, $uglygep$i$i$i = 0, $uglygep$i$i$i4 = 0, $uglygep3$i$i$i = 0, $uglygep3$i$i$i5 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 dest=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($7|0) / 12)&-1;
 $9 = ($7|0)>(0);
 if ($9) {
  $11 = $4;$i$08 = 0;
  while(1) {
   $10 = (($11) + (($i$08*12)|0)|0);
   $12 = HEAP32[$10>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    __ZdaPv($12);
   }
   $14 = ((($11) + (($i$08*12)|0)|0) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0);
   if (!($16)) {
    $17 = $15 | -1342177280;
    $18 = $17;
    __Z34register_external_gfx_deallocationPvPKci($18,1148288,38);
    $19 = (1147664 + 96|0);
    $20 = HEAP32[$19>>2]|0;
    FUNCTION_TABLE_vii[$20 & 4095](1,$14);
   }
   $21 = (($i$08) + 1)|0;
   $22 = ($21|0)<($8|0);
   $23 = HEAP32[$3>>2]|0;
   if ($22) {
    $11 = $23;$i$08 = $21;
   } else {
    break;
   }
  }
  $$pre = HEAP32[$1>>2]|0;
  $$lcssa = $23;$25 = $$pre;
 } else {
  $$lcssa = $4;$25 = $2;
 }
 $24 = ($25|0)==($$lcssa|0);
 if (!($24)) {
  $__new_last2$i$i$i1 = $$lcssa;
  $scevgep$i$i$i2 = (($25) + -12|0);
  $26 = (0 - ($__new_last2$i$i$i1))|0;
  $uglygep$i$i$i4 = (($scevgep$i$i$i2) + ($26)|0);
  $uglygep3$i$i$i5 = $uglygep$i$i$i4;
  $27 = (($uglygep3$i$i$i5>>>0) / 12)&-1;
  $28 = $27 ^ -1;
  $scevgep4$i$i$i6 = (($25) + (($28*12)|0)|0);
  HEAP32[$1>>2] = $scevgep4$i$i$i6;
 }
 $29 = HEAP32[$this>>2]|0;
 $30 = (($this) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==($29|0);
 if ($32) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i$i = $29;
 $scevgep$i$i$i = (($31) + -4|0);
 $33 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($33)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $34 = $uglygep3$i$i$i >>> 2;
 $35 = $34 ^ -1;
 $scevgep4$i$i$i = (($31) + ($35<<2)|0);
 HEAP32[$30>>2] = $scevgep4$i$i$i;
 STACKTOP = sp;return;
}
function __ZN19ConstantBuffersGLES9SetCBInfoEii($this,$id,$size) {
 $this = $this|0;
 $id = $id|0;
 $size = $size|0;
 var $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $cb = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $cb = sp;
 $0 = $size << 16;
 $1 = $0 | $id;
 $2 = (($this) + 12|0);
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ($8|0)>(0);
 L1: do {
  if ($10) {
   $11 = HEAP32[$this>>2]|0;
   $i$01 = 0;
   while(1) {
    $14 = (($11) + ($i$01<<2)|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($1|0);
    $13 = (($i$01) + 1)|0;
    if ($16) {
     break;
    }
    $12 = ($13|0)<($9|0);
    if ($12) {
     $i$01 = $13;
    } else {
     break L1;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $17 = ($size|0)>(-1);
 $18 = $17 ? $size : -1;
 $19 = (__Znaj($18)|0);
 HEAP32[$cb>>2] = $19;
 $20 = (($cb) + 4|0);
 HEAP32[$20>>2] = 0;
 $21 = (($cb) + 8|0);
 HEAP16[$21>>1] = -1;
 $22 = (($cb) + 10|0);
 HEAP8[$22>>0] = 1;
 _memset(($19|0),0,($size|0))|0;
 $23 = (1147664 + 172|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_vii[$24 & 4095](1,$20);
 $25 = (1147664 + 12|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vii[$26 & 4095](35345,$27);
 $28 = (1147664 + 36|0);
 $29 = HEAP32[$28>>2]|0;
 FUNCTION_TABLE_viiii[$29 & 511](35345,$size,0,35048);
 $30 = HEAP32[$20>>2]|0;
 $31 = $30 | -1342177280;
 $32 = $31;
 $33 = $this;
 __Z32register_external_gfx_allocationPvjjPKci($32,$size,$33,1148288,64);
 $34 = HEAP32[$3>>2]|0;
 $35 = (($this) + 20|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($34|0)==($36|0);
 if ($37) {
  __ZNSt3__16vectorIN19ConstantBuffersGLES11ConstBufferENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($2,$cb);
 } else {
  $38 = ($34|0)==(0|0);
  if ($38) {
   $40 = 0;
  } else {
   ;HEAP32[$34+0>>2]=HEAP32[$cb+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$cb+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$cb+8>>2]|0;
   $$pre$i = HEAP32[$3>>2]|0;
   $40 = $$pre$i;
  }
  $39 = (($40) + 12|0);
  HEAP32[$3>>2] = $39;
 }
 $41 = (($this) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($this) + 8|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42|0)==($44|0);
 if (!($45)) {
  $46 = ($42|0)==(0|0);
  if (!($46)) {
   HEAP32[$42>>2] = $1;
  }
  $47 = (($42) + 4|0);
  HEAP32[$41>>2] = $47;
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$this>>2]|0;
 $49 = $42;
 $50 = $48;
 $51 = (($49) - ($50))|0;
 $52 = $51 >> 2;
 $53 = (($52) + 1)|0;
 $54 = ($53>>>0)>(1073741823);
 if ($54) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $55 = ($52>>>0)<(536870911);
 if ($55) {
  $56 = $51 >> 1;
  $57 = ($56>>>0)<($53>>>0);
  $58 = $57 ? $53 : $56;
  $59 = ($58|0)==(0);
  if ($59) {
   $$0$i3$i$i = 0;$63 = 0;
  } else {
   $$0$i2$i$i = $58;
   label = 18;
  }
 } else {
  $$0$i2$i$i = 1073741823;
  label = 18;
 }
 if ((label|0) == 18) {
  $60 = $$0$i2$i$i << 2;
  $61 = (__Znwj($60)|0);
  $$0$i3$i$i = $$0$i2$i$i;$63 = $61;
 }
 $62 = (($63) + ($52<<2)|0);
 $64 = (($63) + ($$0$i3$i$i<<2)|0);
 $65 = ($62|0)==(0|0);
 if (!($65)) {
  HEAP32[$62>>2] = $1;
 }
 $66 = (($63) + ($53<<2)|0);
 _memcpy(($63|0),($48|0),($51|0))|0;
 HEAP32[$this>>2] = $63;
 HEAP32[$41>>2] = $66;
 HEAP32[$43>>2] = $64;
 $67 = ($48|0)==(0|0);
 if ($67) {
  STACKTOP = sp;return;
 }
 __ZdlPv($48);
 STACKTOP = sp;return;
}
function __ZN19ConstantBuffersGLES13FindAndBindCBEiii($this,$id,$bind,$size) {
 $this = $this|0;
 $id = $id|0;
 $bind = $bind|0;
 $size = $size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $size << 16;
 $1 = $0 | $id;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 12)&-1;
 $10 = ($8|0)>(0);
 if (!($10)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = HEAP32[$this>>2]|0;
 $i$02 = 0;
 while(1) {
  $14 = (($11) + ($i$02<<2)|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($1|0);
  $13 = (($i$02) + 1)|0;
  if ($16) {
   break;
  }
  $12 = ($13|0)<($9|0);
  if ($12) {
   $i$02 = $13;
  } else {
   $$0 = -1;
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 $17 = ($bind|0)>(-1);
 if (!($17)) {
  $$0 = $i$02;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = $bind&65535;
 $19 = ((($5) + (($i$02*12)|0)|0) + 8|0);
 HEAP16[$19>>1] = $18;
 $$0 = $i$02;
 STACKTOP = sp;return ($$0|0);
}
function __ZN19ConstantBuffersGLES10ResetBindsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($6|0)>(0);
 if ($8) {
  $i$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $9 = ((($3) + (($i$01*12)|0)|0) + 8|0);
  HEAP16[$9>>1] = -1;
  $10 = (($i$01) + 1)|0;
  $11 = ($10|0)<($7|0);
  if ($11) {
   $i$01 = $10;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN19ConstantBuffersGLES13SetCBConstantEiiPKvi($this,$idx,$offset,$data,$size) {
 $this = $this|0;
 $idx = $idx|0;
 $offset = $offset|0;
 $data = $data|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($size|0)==(4);
 $3 = (($1) + (($idx*12)|0)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($offset)|0);
 if ($2) {
  $6 = HEAP32[$data>>2]|0;
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==($6|0);
  if ($8) {
   STACKTOP = sp;return;
  }
  HEAP32[$5>>2] = $6;
  $9 = ((($1) + (($idx*12)|0)|0) + 10|0);
  HEAP8[$9>>0] = 1;
  STACKTOP = sp;return;
 } else {
  $10 = (_memcmp($5,$data,$size)|0);
  $11 = ($10|0)==(0);
  if ($11) {
   STACKTOP = sp;return;
  }
  _memcpy(($5|0),($data|0),($size|0))|0;
  $12 = ((($1) + (($idx*12)|0)|0) + 10|0);
  HEAP8[$12>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN19ConstantBuffersGLES13UpdateBuffersEv($this) {
 $this = $this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 12)&-1;
 $8 = ($6|0)>(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $10 = $3;$i$01 = 0;
 while(1) {
  $9 = ((($10) + (($i$01*12)|0)|0) + 10|0);
  $11 = HEAP8[$9>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if (!($12)) {
   $13 = (1147664 + 12|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($10) + (($i$01*12)|0)|0) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   FUNCTION_TABLE_vii[$14 & 4095](35345,$16);
   $17 = HEAP32[$this>>2]|0;
   $18 = (($17) + ($i$01<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = $19 >>> 16;
   $21 = (1147664 + 36|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($10) + (($i$01*12)|0)|0);
   $24 = HEAP32[$23>>2]|0;
   FUNCTION_TABLE_viiii[$22 & 511](35345,$20,$24,35048);
   $25 = (1147664 + 12|0);
   $26 = HEAP32[$25>>2]|0;
   FUNCTION_TABLE_vii[$26 & 4095](35345,0);
  }
  $27 = ((($10) + (($i$01*12)|0)|0) + 8|0);
  $28 = HEAP16[$27>>1]|0;
  $29 = $28 << 16 >> 16;
  $30 = ($28<<16>>16)>(-1);
  if ($30) {
   $31 = ((($this) + ($29<<2)|0) + 24|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ((($10) + (($i$01*12)|0)|0) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($32|0)==($34|0);
   if (!($35)) {
    $36 = (1147664 + 456|0);
    $37 = HEAP32[$36>>2]|0;
    FUNCTION_TABLE_viii[$37 & 4095](35345,$29,$34);
   }
  }
  HEAP8[$9>>0] = 0;
  $38 = (($i$01) + 1)|0;
  $39 = ($38|0)<($7|0);
  if (!($39)) {
   break;
  }
  $$pre = HEAP32[$2>>2]|0;
  $10 = $$pre;$i$01 = $38;
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN19ConstantBuffersGLES11ConstBufferENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i2 = 0, $$0$i3 = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = (($5|0) / 12)&-1;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(357913941);
 if ($8) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = (($11) - ($4))|0;
 $13 = (($12|0) / 12)&-1;
 $14 = ($13>>>0)<(178956970);
 if ($14) {
  $15 = $13 << 1;
  $16 = ($15>>>0)<($7>>>0);
  $17 = $16 ? $7 : $15;
  $18 = ($17|0)==(0);
  if ($18) {
   $$0$i3 = 0;$22 = 0;
  } else {
   $$0$i2 = $17;
   label = 5;
  }
 } else {
  $$0$i2 = 357913941;
  label = 5;
 }
 if ((label|0) == 5) {
  $19 = ($$0$i2*12)|0;
  $20 = (__Znwj($19)|0);
  $$0$i3 = $$0$i2;$22 = $20;
 }
 $21 = (($22) + (($6*12)|0)|0);
 $23 = (($22) + (($$0$i3*12)|0)|0);
 $24 = ($21|0)==(0|0);
 if (!($24)) {
  ;HEAP32[$21+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$21+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$21+8>>2]=HEAP32[$__x+8>>2]|0;
 }
 $25 = (($22) + (($7*12)|0)|0);
 $26 = (($5|0) / -12)&-1;
 $$sum1 = (($26) + ($6))|0;
 $27 = (($22) + (($$sum1*12)|0)|0);
 _memcpy(($27|0),($2|0),($5|0))|0;
 HEAP32[$this>>2] = $27;
 HEAP32[$0>>2] = $25;
 HEAP32[$9>>2] = $23;
 $28 = ($2|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 __ZdlPv($2);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLESC2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN9GfxDeviceC2Ev($this);
 HEAP32[$this>>2] = ((1148296 + 8|0));
 $2 = (($this) + 6012|0);
 $3 = (($this) + 6208|0);
 __THREW__ = 0;
 invoke_vi(3788,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $$1 = $60;$$12 = $59;
 } else {
  $6 = (($this) + 7976|0);
  HEAP32[$6>>2] = 0;
  $7 = (($this) + 7984|0);
  HEAP32[$7>>2] = 0;
  $8 = (($this) + 7988|0);
  HEAP32[$8>>2] = 0;
  $9 = (($this) + 7980|0);
  HEAP32[$9>>2] = 61;
  $10 = (($this) + 8144|0);
  HEAP32[$10>>2] = 0;
  $11 = (($this) + 8148|0);
  HEAP32[$11>>2] = 0;
  $12 = (($this) + 8144|0);
  $13 = (($this) + 8140|0);
  HEAP32[$13>>2] = $12;
  $14 = (($this) + 8156|0);
  HEAP32[$14>>2] = 0;
  $15 = (($this) + 8160|0);
  HEAP32[$15>>2] = 0;
  $16 = (($this) + 8156|0);
  $17 = (($this) + 8152|0);
  HEAP32[$17>>2] = $16;
  $18 = (($this) + 8168|0);
  HEAP32[$18>>2] = 0;
  $19 = (($this) + 8172|0);
  HEAP32[$19>>2] = 0;
  $20 = (($this) + 8168|0);
  $21 = (($this) + 8164|0);
  HEAP32[$21>>2] = $20;
  $22 = (($this) + 8180|0);
  HEAP32[$22>>2] = 0;
  $23 = (($this) + 8184|0);
  HEAP32[$23>>2] = 0;
  $24 = (($this) + 8180|0);
  $25 = (($this) + 8176|0);
  HEAP32[$25>>2] = $24;
  $26 = (($this) + 8192|0);
  ;HEAP32[$26+0>>2]=0|0;HEAP32[$26+4>>2]=0|0;HEAP32[$26+8>>2]=0|0;HEAP32[$26+12>>2]=0|0;HEAP32[$26+16>>2]=0|0;HEAP32[$26+20>>2]=0|0;HEAP32[$26+24>>2]=0|0;HEAP32[$26+28>>2]=0|0;
  $27 = (($this) + 8240|0);
  $28 = (($this) + 8248|0);
  HEAP32[$28>>2] = 0;
  $29 = (($this) + 8252|0);
  HEAP32[$29>>2] = 0;
  $30 = (($this) + 8248|0);
  $31 = (($this) + 8244|0);
  HEAP32[$31>>2] = $30;
  HEAP32[$27>>2] = ((1149448 + 8|0));
  HEAP32[1149528>>2] = $2;
  $32 = (($this) + 5956|0);
  $33 = (($this) + 5960|0);
  __THREW__ = 0;
  invoke_vii(3487,($32|0),($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if (!($35)) {
   __THREW__ = 0;
   invoke_vi(3472,($this|0));
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if (!($37)) {
    HEAP16[$1>>1] = 0;
    $38 = (($1) + 2|0);
    $39 = HEAP32[1157480>>2]|0;
    $40 = $39&65535;
    HEAP16[$38>>1] = $40;
    $41 = (($this) + 8140|0);
    __THREW__ = 0;
    invoke_viii(2107,($0|0),($41|0),($1|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     $44 = HEAP32[$0>>2]|0;
     $45 = (($44) + 16|0);
     $46 = (($this) + 8188|0);
     HEAP32[$46>>2] = $45;
     __THREW__ = 0;
     invoke_vi(3789,($2|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if (!($48)) {
      $49 = HEAP32[$this>>2]|0;
      $50 = (($49) + 8|0);
      $51 = HEAP32[$50>>2]|0;
      __THREW__ = 0;
      invoke_vi($51|0,($this|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if (!($53)) {
       $54 = (($this) + 5786|0);
       HEAP8[$54>>0] = 1;
       $55 = (($this) + 5932|0);
       HEAP8[$55>>0] = 1;
       $56 = (($this) + 5933|0);
       HEAP8[$56>>0] = 0;
       $57 = (($this) + 5916|0);
       HEAPF32[$57>>2] = Math_fround(0.0);
       $58 = (($this) + 5912|0);
       HEAPF32[$58>>2] = Math_fround(0.0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
  $61 = ___cxa_find_matching_catch()|0;
  $62 = tempRet0;
  HEAP32[$27>>2] = ((1149424 + 8|0));
  $63 = (($this) + 8244|0);
  $64 = HEAP32[$28>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($63,$64);
  __THREW__ = 0;
  invoke_vi(3790,($2|0));
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if ($66) {
   $69 = ___cxa_find_matching_catch(0|0)|0;
   $70 = tempRet0;
   ___clang_call_terminate($69);
   // unreachable;
  } else {
   $$1 = $62;$$12 = $61;
  }
 }
 __THREW__ = 0;
 invoke_vi(1021,($this|0));
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $69 = ___cxa_find_matching_catch(0|0)|0;
  $70 = tempRet0;
  ___clang_call_terminate($69);
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZN26VertexDeclarationCacheGLESD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1149424 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$2);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLESD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1352,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN13GfxDeviceGLESD2Ev($this) {
 $this = $this|0;
 var $$1 = 0, $$12 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1148296 + 8|0));
 __THREW__ = 0;
 invoke_v(272);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if ($1) {
   label = 11;
  } else {
   __THREW__ = 0;
   invoke_v(273);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if ($3) {
    label = 11;
   } else {
    $4 = (($this) + 6012|0);
    $5 = (($this) + 6208|0);
    __THREW__ = 0;
    invoke_vi(3791,($5|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     label = 11;
    } else {
     __THREW__ = 0;
     invoke_vi(3792,($this|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      label = 11;
     } else {
      __THREW__ = 0;
      invoke_v(274);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       label = 11;
      } else {
       $12 = (($this) + 8240|0);
       __THREW__ = 0;
       invoke_vi(3793,($12|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        label = 11;
       } else {
        __THREW__ = 0;
        invoke_v(275);
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if ($16) {
         label = 11;
        } else {
         HEAP32[$12>>2] = ((1149424 + 8|0));
         $17 = (($this) + 8244|0);
         $18 = (($this) + 8248|0);
         $19 = HEAP32[$18>>2]|0;
         __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($17,$19);
         __THREW__ = 0;
         invoke_vi(3790,($4|0));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          $22 = ___cxa_find_matching_catch()|0;
          $23 = tempRet0;
          $$1 = $23;$$12 = $22;$$pre$phiZ2D = $this;
          break;
         } else {
          __ZN9GfxDeviceD2Ev($this);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   $26 = (($this) + 8240|0);
   HEAP32[$26>>2] = ((1149424 + 8|0));
   $27 = (($this) + 8244|0);
   $28 = (($this) + 8248|0);
   $29 = HEAP32[$28>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($27,$29);
   $30 = (($this) + 6012|0);
   __THREW__ = 0;
   invoke_vi(3790,($30|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $35 = ___cxa_find_matching_catch(0|0)|0;
    $36 = tempRet0;
    ___clang_call_terminate($35);
    // unreachable;
   } else {
    $$1 = $25;$$12 = $24;$$pre$phiZ2D = $this;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(1021,($$pre$phiZ2D|0));
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $35 = ___cxa_find_matching_catch(0|0)|0;
  $36 = tempRet0;
  ___clang_call_terminate($35);
  // unreachable;
 } else {
  ___resumeException($$12|0);
  // unreachable;
 }
}
function __ZN4gles26ClearFixedFunctionProgramsEv() {
 var $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i$i$i9 = 0, $$0$i$i$i13 = 0, $$0$i$i$i7 = 0, $$01$i$i$i = 0, $$01$i$i$i11 = 0, $$01$i$i$i5 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[1149288>>2]|0;
 $2 = ($1|0)==(((1149288 + 4|0))|0);
 if (!($2)) {
  $6 = $1;
  while(1) {
   $3 = (1147664 + 112|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($6) + 60|0);
   $7 = HEAP32[$5>>2]|0;
   FUNCTION_TABLE_vi[$4 & 4095]($7);
   $8 = (($6) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $$01$i$i$i5 = $6;
    while(1) {
     $13 = (($$01$i$i$i5) + 8|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==($$01$i$i$i5|0);
     if ($16) {
      $$0$i$i$i7 = $14;
      break;
     } else {
      $$01$i$i$i5 = $14;
     }
    }
   } else {
    $$0$i$i$i$i3 = $9;
    while(1) {
     $11 = HEAP32[$$0$i$i$i$i3>>2]|0;
     $12 = ($11|0)==(0|0);
     if ($12) {
      $$0$i$i$i7 = $$0$i$i$i$i3;
      break;
     } else {
      $$0$i$i$i$i3 = $11;
     }
    }
   }
   $17 = ($$0$i$i$i7|0)==(((1149288 + 4|0))|0);
   if ($17) {
    break;
   } else {
    $6 = $$0$i$i$i7;
   }
  }
 }
 $18 = HEAP32[1149304>>2]|0;
 $19 = ($18|0)==(((1149304 + 4|0))|0);
 if (!($19)) {
  $23 = $18;
  while(1) {
   $20 = (1147664 + 112|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($23) + 60|0);
   $24 = HEAP32[$22>>2]|0;
   FUNCTION_TABLE_vi[$21 & 4095]($24);
   $25 = (($23) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ($26|0)==(0|0);
   if ($27) {
    $$01$i$i$i11 = $23;
    while(1) {
     $30 = (($$01$i$i$i11) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = HEAP32[$31>>2]|0;
     $33 = ($32|0)==($$01$i$i$i11|0);
     if ($33) {
      $$0$i$i$i13 = $31;
      break;
     } else {
      $$01$i$i$i11 = $31;
     }
    }
   } else {
    $$0$i$i$i$i9 = $26;
    while(1) {
     $28 = HEAP32[$$0$i$i$i$i9>>2]|0;
     $29 = ($28|0)==(0|0);
     if ($29) {
      $$0$i$i$i13 = $$0$i$i$i$i9;
      break;
     } else {
      $$0$i$i$i$i9 = $28;
     }
    }
   }
   $34 = ($$0$i$i$i13|0)==(((1149304 + 4|0))|0);
   if ($34) {
    break;
   } else {
    $23 = $$0$i$i$i13;
   }
  }
 }
 $35 = HEAP32[1149272>>2]|0;
 $36 = ($35|0)==(((1149272 + 4|0))|0);
 if (!($36)) {
  $38 = $35;
  while(1) {
   $37 = (($38) + 60|0);
   $39 = HEAP32[$37>>2]|0;
   $40 = HEAP32[628280>>2]|0;
   $41 = ($39|0)==(0|0);
   if (!($41)) {
    __ZN17FfpGpuProgramGLESD2Ev($39);
   }
   HEAP32[$0>>2] = $40;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($39,$$byval_copy);
   HEAP32[$37>>2] = 0;
   $42 = (($38) + 4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($43|0)==(0|0);
   if ($44) {
    $$01$i$i$i = $38;
    while(1) {
     $47 = (($$01$i$i$i) + 8|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)==($$01$i$i$i|0);
     if ($50) {
      $$0$i$i$i = $48;
      break;
     } else {
      $$01$i$i$i = $48;
     }
    }
   } else {
    $$0$i$i$i$i = $43;
    while(1) {
     $45 = HEAP32[$$0$i$i$i$i>>2]|0;
     $46 = ($45|0)==(0|0);
     if ($46) {
      $$0$i$i$i = $$0$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i = $45;
     }
    }
   }
   $51 = ($$0$i$i$i|0)==(((1149272 + 4|0))|0);
   if ($51) {
    break;
   } else {
    $38 = $$0$i$i$i;
   }
  }
 }
 $52 = HEAP32[((1149288 + 4|0))>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_18VertexStateCompareELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(1149288,$52);
 HEAP32[((1149288 + 8|0))>>2] = 0;
 HEAP32[1149288>>2] = ((1149288 + 4|0));
 HEAP32[((1149288 + 4|0))>>2] = 0;
 $53 = HEAP32[((1149304 + 4|0))>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_20FragmentStateCompareELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE(1149304,$53);
 HEAP32[((1149304 + 8|0))>>2] = 0;
 HEAP32[1149304>>2] = ((1149304 + 4|0));
 HEAP32[((1149304 + 4|0))>>2] = 0;
 $54 = HEAP32[((1149272 + 4|0))>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEP17FfpGpuProgramGLESEENS_19__map_value_compareIS3_S6_NS2_16FullStateCompareELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE(1149272,$54);
 HEAP32[((1149272 + 8|0))>>2] = 0;
 HEAP32[1149272>>2] = ((1149272 + 4|0));
 HEAP32[((1149272 + 4|0))>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES18BeforePluginRenderEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES17AfterPluginRenderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 4095]($this);
 $3 = (($this) + 6012|0);
 __ZN4gles24InvalidatePipelineStatesER15DeviceStateGLES($3);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES15InvalidateStateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 __ZN9GfxDevice15InvalidateStateEv($this);
 $0 = (($this) + 6012|0);
 $1 = (($this) + 6204|0);
 HEAP32[$1>>2] = 7;
 __ZN4gles10InvalidateER15DeviceStateGLES($0);
 $2 = (($this) + 8237|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = (($this) + 5925|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($3<<24>>24)==($5<<24>>24);
 $7 = (1147664 + 168|0);
 $8 = HEAP32[$7>>2]|0;
 if ($6) {
  FUNCTION_TABLE_vi[$8 & 4095](2304);
 } else {
  FUNCTION_TABLE_vi[$8 & 4095](2305);
 }
 __Z26GLES_InvalidateApiOverridev();
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 $9 = (($this) + 2596|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($this) + 2600|0);
 HEAPF32[$10>>2] = Math_fround(1.0);
 $11 = (($this) + 2604|0);
 HEAPF32[$11>>2] = Math_fround(1.0);
 $12 = (($this) + 2608|0);
 HEAPF32[$12>>2] = Math_fround(1.0);
 $13 = (($this) + 2612|0);
 HEAPF32[$13>>2] = Math_fround(1.0);
 $14 = (($this) + 2616|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 $15 = (($this) + 2620|0);
 HEAPF32[$15>>2] = Math_fround(1.0);
 $16 = (($this) + 2624|0);
 HEAPF32[$16>>2] = Math_fround(1.0);
 $17 = (($this) + 2628|0);
 HEAPF32[$17>>2] = Math_fround(1.0);
 $18 = (($this) + 2632|0);
 HEAPF32[$18>>2] = Math_fround(1.0);
 $19 = (($this) + 2636|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 $20 = (($this) + 2640|0);
 HEAPF32[$20>>2] = Math_fround(1.0);
 $21 = (($this) + 2644|0);
 HEAPF32[$21>>2] = Math_fround(1.0);
 $22 = (($this) + 2648|0);
 HEAPF32[$22>>2] = Math_fround(1.0);
 $23 = (($this) + 2652|0);
 HEAPF32[$23>>2] = Math_fround(1.0);
 $24 = (($this) + 2656|0);
 HEAPF32[$24>>2] = Math_fround(1.0);
 $25 = (($this) + 2660|0);
 HEAPF32[$25>>2] = Math_fround(1.0);
 $26 = (($this) + 2664|0);
 HEAPF32[$26>>2] = Math_fround(1.0);
 $27 = (($this) + 2668|0);
 HEAPF32[$27>>2] = Math_fround(1.0);
 $28 = (($this) + 2672|0);
 HEAPF32[$28>>2] = Math_fround(1.0);
 $29 = (($this) + 2676|0);
 $30 = (($this) + 2452|0);
 dest=$29+0|0; stop=dest+48|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$30>>2] = Math_fround(1.0);
 $31 = (($this) + 2456|0);
 HEAPF32[$31>>2] = Math_fround(1.0);
 $32 = (($this) + 2460|0);
 HEAPF32[$32>>2] = Math_fround(1.0);
 $33 = (($this) + 2464|0);
 HEAPF32[$33>>2] = Math_fround(1.0);
 $34 = (($this) + 2468|0);
 $35 = (($this) + 2532|0);
 ;HEAP32[$34+0>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
 HEAPF32[$35>>2] = Math_fround(1.0);
 $36 = (($this) + 2536|0);
 HEAPF32[$36>>2] = Math_fround(1.0);
 $37 = (($this) + 2540|0);
 HEAPF32[$37>>2] = Math_fround(0.0);
 $38 = (($this) + 2544|0);
 HEAPF32[$38>>2] = Math_fround(0.0);
 $39 = (($this) + 2484|0);
 $40 = (($this) + 2548|0);
 ;HEAP32[$39+0>>2]=0|0;HEAP32[$39+4>>2]=0|0;HEAP32[$39+8>>2]=0|0;HEAP32[$39+12>>2]=0|0;
 HEAPF32[$40>>2] = Math_fround(1.0);
 $41 = (($this) + 2552|0);
 HEAPF32[$41>>2] = Math_fround(1.0);
 $42 = (($this) + 2556|0);
 HEAPF32[$42>>2] = Math_fround(0.0);
 $43 = (($this) + 2560|0);
 HEAPF32[$43>>2] = Math_fround(0.0);
 $44 = (($this) + 2500|0);
 $45 = (($this) + 2564|0);
 ;HEAP32[$44+0>>2]=0|0;HEAP32[$44+4>>2]=0|0;HEAP32[$44+8>>2]=0|0;HEAP32[$44+12>>2]=0|0;
 HEAPF32[$45>>2] = Math_fround(1.0);
 $46 = (($this) + 2568|0);
 HEAPF32[$46>>2] = Math_fround(1.0);
 $47 = (($this) + 2572|0);
 HEAPF32[$47>>2] = Math_fround(0.0);
 $48 = (($this) + 2576|0);
 HEAPF32[$48>>2] = Math_fround(0.0);
 $49 = (($this) + 2516|0);
 $50 = (($this) + 2580|0);
 ;HEAP32[$49+0>>2]=0|0;HEAP32[$49+4>>2]=0|0;HEAP32[$49+8>>2]=0|0;HEAP32[$49+12>>2]=0|0;
 HEAPF32[$50>>2] = Math_fround(1.0);
 $51 = (($this) + 2584|0);
 HEAPF32[$51>>2] = Math_fround(1.0);
 $52 = (($this) + 2588|0);
 HEAPF32[$52>>2] = Math_fround(0.0);
 $53 = (($this) + 2592|0);
 HEAPF32[$53>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES10BeginFrameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5784|0);
 HEAP8[$0>>0] = 1;
 HEAP8[((1149816 + 52|0))>>0] = 2;
 $1 = HEAP32[1149816>>2]|0;
 $2 = (($1) + 20|0);
 HEAP8[$2>>0] = 2;
 HEAP8[((1149816 + 68|0))>>0] = 2;
 $3 = HEAP32[((1149816 + 32|0))>>2]|0;
 $4 = (($3) + 20|0);
 HEAP8[$4>>0] = 2;
 __ZN4gles12SetActiveFBOERK20GfxRenderTargetSetup(1149816);
 $5 = HEAP8[((640792 + 252|0))>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES8EndFrameEv($this) {
 $this = $this|0;
 var $$phi$trans$insert = 0, $$phi$trans$insert2 = 0, $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $discardColor = 0, $exitcond$i = 0, $exitcond3$i = 0;
 var $i$01$i = 0, $i$01$us$i = 0, $invalidateCount$0$lcssa$i = 0, $invalidateCount$02$i = 0, $invalidateCount$02$us$i = 0, $invalidateCount$1$i = 0, $invalidateCount$1$us$i = 0, $invalidateTarget$i = 0, $phitmp = 0, $phitmp4 = 0, $phitmp5 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $invalidateTarget$i = sp + 8|0;
 $discardColor = sp;
 $0 = HEAP32[((1149672 + 32|0))>>2]|0;
 $1 = ($0|0)==(1150016|0);
 if ($1) {
  $2 = $discardColor;
  $3 = $2;
  HEAP32[$3>>2] = 0;
  $4 = (($2) + 4)|0;
  $5 = $4;
  HEAP32[$5>>2] = 0;
  $6 = HEAP8[((640792 + 349|0))>>0]|0;
  $7 = ($6<<24>>24)==(0);
  if (!($7)) {
   dest=$invalidateTarget$i+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $8 = HEAP32[1149888>>2]|0;
   $9 = ($8|0)==(0);
   $10 = HEAP32[((1149672 + 36|0))>>2]|0;
   $11 = ($10|0)>(0);
   L4: do {
    if ($11) {
     if ($9) {
      $31 = 1;$i$01$us$i = 1;$invalidateCount$02$us$i = 0;
      while(1) {
       if ($31) {
        $invalidateCount$1$us$i = $invalidateCount$02$us$i;
       } else {
        $12 = (($invalidateCount$02$us$i) + 1)|0;
        $13 = (($invalidateTarget$i) + ($invalidateCount$02$us$i<<2)|0);
        HEAP32[$13>>2] = 6144;
        $invalidateCount$1$us$i = $12;
       }
       $exitcond3$i = ($i$01$us$i|0)==($10|0);
       if ($exitcond3$i) {
        $invalidateCount$0$lcssa$i = $invalidateCount$1$us$i;
        break L4;
       }
       $$phi$trans$insert = (($discardColor) + ($i$01$us$i)|0);
       $$pre = HEAP8[$$phi$trans$insert>>0]|0;
       $phitmp4 = ($$pre<<24>>24)==(0);
       $phitmp5 = (($i$01$us$i) + 1)|0;
       $31 = $phitmp4;$i$01$us$i = $phitmp5;$invalidateCount$02$us$i = $invalidateCount$1$us$i;
      }
     } else {
      $32 = 1;$i$01$i = 0;$invalidateCount$02$i = 0;
      while(1) {
       if ($32) {
        $invalidateCount$1$i = $invalidateCount$02$i;
       } else {
        $14 = (($i$01$i) + 36064)|0;
        $15 = (($invalidateCount$02$i) + 1)|0;
        $16 = (($invalidateTarget$i) + ($invalidateCount$02$i<<2)|0);
        HEAP32[$16>>2] = $14;
        $invalidateCount$1$i = $15;
       }
       $17 = (($i$01$i) + 1)|0;
       $exitcond$i = ($17|0)==($10|0);
       if ($exitcond$i) {
        $invalidateCount$0$lcssa$i = $invalidateCount$1$i;
        break L4;
       }
       $$phi$trans$insert2 = (($discardColor) + ($17)|0);
       $$pre3 = HEAP8[$$phi$trans$insert2>>0]|0;
       $phitmp = ($$pre3<<24>>24)==(0);
       $32 = $phitmp;$i$01$i = $17;$invalidateCount$02$i = $invalidateCount$1$i;
      }
     }
    } else {
     $invalidateCount$0$lcssa$i = 0;
    }
   } while(0);
   $18 = $9 ? 6145 : 36096;
   $19 = (($invalidateCount$0$lcssa$i) + 1)|0;
   $20 = (($invalidateTarget$i) + ($invalidateCount$0$lcssa$i<<2)|0);
   HEAP32[$20>>2] = $18;
   $21 = $9 ? 6146 : 36128;
   $22 = (($invalidateCount$0$lcssa$i) + 2)|0;
   $23 = (($invalidateTarget$i) + ($19<<2)|0);
   HEAP32[$23>>2] = $21;
   $24 = ($22|0)==(0);
   if (!($24)) {
    $25 = (1147664 + 508|0);
    $26 = HEAP32[$25>>2]|0;
    FUNCTION_TABLE_viii[$26 & 4095](36160,$22,$invalidateTarget$i);
   }
  }
 }
 $27 = (__Z20GetBufferManagerGLESv()|0);
 __ZN17BufferManagerGLES12AdvanceFrameEv($27);
 $28 = HEAP8[((640792 + 363|0))>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  $30 = (($this) + 5784|0);
  HEAP8[$30>>0] = 0;
  STACKTOP = sp;return;
 }
 HEAP8[1149416>>0] = 0;
 $30 = (($this) + 5784|0);
 HEAP8[$30>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN4gles28InvalidateCurrentFramebufferEPbb($invalidateColor,$invalidateDepth) {
 $invalidateColor = $invalidateColor|0;
 $invalidateDepth = $invalidateDepth|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond3 = 0, $i$01 = 0, $i$01$us = 0, $invalidateCount$0$lcssa = 0, $invalidateCount$02 = 0, $invalidateCount$02$us = 0, $invalidateCount$1 = 0, $invalidateCount$1$us = 0, $invalidateCount$2 = 0, $invalidateTarget = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $invalidateTarget = sp;
 $0 = HEAP8[((640792 + 349|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 dest=$invalidateTarget+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $2 = HEAP32[1149888>>2]|0;
 $3 = ($2|0)==(0);
 $4 = HEAP32[((1149672 + 36|0))>>2]|0;
 $5 = ($4|0)>(0);
 if ($5) {
  if ($3) {
   $i$01$us = 0;$invalidateCount$02$us = 0;
   while(1) {
    $6 = (($invalidateColor) + ($i$01$us)|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     $invalidateCount$1$us = $invalidateCount$02$us;
    } else {
     $9 = (($invalidateCount$02$us) + 1)|0;
     $10 = (($invalidateTarget) + ($invalidateCount$02$us<<2)|0);
     HEAP32[$10>>2] = 6144;
     $invalidateCount$1$us = $9;
    }
    $11 = (($i$01$us) + 1)|0;
    $exitcond3 = ($11|0)==($4|0);
    if ($exitcond3) {
     $invalidateCount$0$lcssa = $invalidateCount$1$us;
     break;
    } else {
     $i$01$us = $11;$invalidateCount$02$us = $invalidateCount$1$us;
    }
   }
  } else {
   $i$01 = 0;$invalidateCount$02 = 0;
   while(1) {
    $12 = (($invalidateColor) + ($i$01)|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     $invalidateCount$1 = $invalidateCount$02;
    } else {
     $15 = (($i$01) + 36064)|0;
     $16 = (($invalidateCount$02) + 1)|0;
     $17 = (($invalidateTarget) + ($invalidateCount$02<<2)|0);
     HEAP32[$17>>2] = $15;
     $invalidateCount$1 = $16;
    }
    $18 = (($i$01) + 1)|0;
    $exitcond = ($18|0)==($4|0);
    if ($exitcond) {
     $invalidateCount$0$lcssa = $invalidateCount$1;
     break;
    } else {
     $i$01 = $18;$invalidateCount$02 = $invalidateCount$1;
    }
   }
  }
 } else {
  $invalidateCount$0$lcssa = 0;
 }
 if ($invalidateDepth) {
  $19 = $3 ? 6145 : 36096;
  $20 = (($invalidateCount$0$lcssa) + 1)|0;
  $21 = (($invalidateTarget) + ($invalidateCount$0$lcssa<<2)|0);
  HEAP32[$21>>2] = $19;
  $22 = $3 ? 6146 : 36128;
  $23 = (($invalidateCount$0$lcssa) + 2)|0;
  $24 = (($invalidateTarget) + ($20<<2)|0);
  HEAP32[$24>>2] = $22;
  $invalidateCount$2 = $23;
 } else {
  $invalidateCount$2 = $invalidateCount$0$lcssa;
 }
 $25 = ($invalidateCount$2|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (1147664 + 508|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_viii[$27 & 4095](36160,$invalidateCount$2,$invalidateTarget);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES16CreateBlendStateERK13GfxBlendState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 ;HEAP32[$1+0>>2]=HEAP32[$state+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$state+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$state+8>>2]|0;
 $2 = (($1) + 12|0);
 $3 = (($state) + 4|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (1157520 + ($5<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7&65535;
 HEAP16[$2>>1] = $8;
 $9 = (($1) + 14|0);
 $10 = (($state) + 5|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = (1157520 + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14&65535;
 HEAP16[$9>>1] = $15;
 $16 = (($1) + 16|0);
 $17 = (($state) + 6|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = (1157520 + ($19<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21&65535;
 HEAP16[$16>>1] = $22;
 $23 = (($1) + 18|0);
 $24 = (($state) + 7|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25&255;
 $27 = (1157520 + ($26<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28&65535;
 HEAP16[$23>>1] = $29;
 $30 = (($1) + 20|0);
 $31 = (($state) + 8|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = (1157568 + ($33<<2)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35&65535;
 HEAP16[$30>>1] = $36;
 $37 = (($1) + 22|0);
 $38 = (($state) + 9|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39&255;
 $41 = (1157568 + ($40<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42&65535;
 HEAP16[$37>>1] = $43;
 $44 = (($1) + 24|0);
 $45 = (($state) + 10|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46 << 24 >> 24;
 $48 = (1157480 + ($47<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49&65535;
 HEAP16[$44>>1] = $50;
 $51 = (($this) + 8164|0);
 __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$51,$1);
 $52 = HEAP32[$0>>2]|0;
 $53 = (($52) + 16|0);
 STACKTOP = sp;return ($53|0);
}
function __ZN4gles16CreateBlendStateER15DeviceStateGLESRK13GfxBlendState($state,$pipeState) {
 $state = $state|0;
 $pipeState = $pipeState|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 ;HEAP32[$1+0>>2]=HEAP32[$pipeState+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$pipeState+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$pipeState+8>>2]|0;
 $2 = (($1) + 12|0);
 $3 = (($pipeState) + 4|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (1157520 + ($5<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7&65535;
 HEAP16[$2>>1] = $8;
 $9 = (($1) + 14|0);
 $10 = (($pipeState) + 5|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = (1157520 + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14&65535;
 HEAP16[$9>>1] = $15;
 $16 = (($1) + 16|0);
 $17 = (($pipeState) + 6|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = (1157520 + ($19<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21&65535;
 HEAP16[$16>>1] = $22;
 $23 = (($1) + 18|0);
 $24 = (($pipeState) + 7|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25&255;
 $27 = (1157520 + ($26<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28&65535;
 HEAP16[$23>>1] = $29;
 $30 = (($1) + 20|0);
 $31 = (($pipeState) + 8|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = (1157568 + ($33<<2)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35&65535;
 HEAP16[$30>>1] = $36;
 $37 = (($1) + 22|0);
 $38 = (($pipeState) + 9|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39&255;
 $41 = (1157568 + ($40<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42&65535;
 HEAP16[$37>>1] = $43;
 $44 = (($1) + 24|0);
 $45 = (($pipeState) + 10|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46 << 24 >> 24;
 $48 = (1157480 + ($47<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49&65535;
 HEAP16[$44>>1] = $50;
 $51 = (($state) + 2152|0);
 __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$51,$1);
 $52 = HEAP32[$0>>2]|0;
 $53 = (($52) + 16|0);
 STACKTOP = sp;return ($53|0);
}
function __ZN13GfxDeviceGLES16CreateDepthStateERK13GfxDepthState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $sext$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAPU8[$state>>0]|(HEAPU8[$state+1>>0]<<8);
 $3 = ($2&65535) >>> 8;
 $4 = $3&65535;
 $5 = ($3 << 8)&65535;
 $6 = $2 & 255;
 $7 = $5 | $6;
 HEAP16[$1>>1] = $7;
 $8 = (($1) + 2|0);
 $sext$i = $4 << 24;
 $9 = $sext$i >> 24;
 $10 = (1157480 + ($9<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11&65535;
 HEAP16[$8>>1] = $12;
 $13 = (($this) + 8140|0);
 __ZNSt3__16__treeI20DeviceDepthStateGLES11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$13,$1);
 $14 = HEAP32[$0>>2]|0;
 $15 = (($14) + 16|0);
 STACKTOP = sp;return ($15|0);
}
function __ZN13GfxDeviceGLES18CreateStencilStateERK15GfxStencilState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 ;HEAP32[$1+0>>2]=HEAP32[$state+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$state+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$state+8>>2]|0;
 $2 = (($1) + 12|0);
 $3 = (($state) + 4|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (1157480 + ($5<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7&65535;
 HEAP16[$2>>1] = $8;
 $9 = (($1) + 14|0);
 $10 = (($state) + 5|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = (1157656 + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14&65535;
 HEAP16[$9>>1] = $15;
 $16 = (($1) + 16|0);
 $17 = (($state) + 6|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = (1157656 + ($19<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21&65535;
 HEAP16[$16>>1] = $22;
 $23 = (($1) + 18|0);
 $24 = (($state) + 7|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25&255;
 $27 = (1157656 + ($26<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28&65535;
 HEAP16[$23>>1] = $29;
 $30 = (($1) + 20|0);
 $31 = (($state) + 8|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = (1157480 + ($33<<2)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35&65535;
 HEAP16[$30>>1] = $36;
 $37 = (($1) + 22|0);
 $38 = (($state) + 9|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39&255;
 $41 = (1157656 + ($40<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42&65535;
 HEAP16[$37>>1] = $43;
 $44 = (($1) + 24|0);
 $45 = (($state) + 10|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46&255;
 $48 = (1157656 + ($47<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49&65535;
 HEAP16[$44>>1] = $50;
 $51 = (($1) + 26|0);
 $52 = (($state) + 11|0);
 $53 = HEAP8[$52>>0]|0;
 $54 = $53&255;
 $55 = (1157656 + ($54<<2)|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = $56&65535;
 HEAP16[$51>>1] = $57;
 $58 = (($this) + 8152|0);
 __ZNSt3__16__treeI22DeviceStencilStateGLES11memcmp_lessIS1_18DeviceStencilStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$58,$1);
 $59 = HEAP32[$0>>2]|0;
 $60 = (($59) + 16|0);
 STACKTOP = sp;return ($60|0);
}
function __ZN4gles18CreateStencilStateER15DeviceStateGLESRK15GfxStencilState($state,$pipeState) {
 $state = $state|0;
 $pipeState = $pipeState|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 ;HEAP32[$1+0>>2]=HEAP32[$pipeState+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$pipeState+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$pipeState+8>>2]|0;
 $2 = (($1) + 12|0);
 $3 = (($pipeState) + 4|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (1157480 + ($5<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7&65535;
 HEAP16[$2>>1] = $8;
 $9 = (($1) + 14|0);
 $10 = (($pipeState) + 5|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = (1157656 + ($12<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14&65535;
 HEAP16[$9>>1] = $15;
 $16 = (($1) + 16|0);
 $17 = (($pipeState) + 6|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = $18&255;
 $20 = (1157656 + ($19<<2)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21&65535;
 HEAP16[$16>>1] = $22;
 $23 = (($1) + 18|0);
 $24 = (($pipeState) + 7|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25&255;
 $27 = (1157656 + ($26<<2)|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28&65535;
 HEAP16[$23>>1] = $29;
 $30 = (($1) + 20|0);
 $31 = (($pipeState) + 8|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = $32&255;
 $34 = (1157480 + ($33<<2)|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = $35&65535;
 HEAP16[$30>>1] = $36;
 $37 = (($1) + 22|0);
 $38 = (($pipeState) + 9|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = $39&255;
 $41 = (1157656 + ($40<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = $42&65535;
 HEAP16[$37>>1] = $43;
 $44 = (($1) + 24|0);
 $45 = (($pipeState) + 10|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46&255;
 $48 = (1157656 + ($47<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49&65535;
 HEAP16[$44>>1] = $50;
 $51 = (($1) + 26|0);
 $52 = (($pipeState) + 11|0);
 $53 = HEAP8[$52>>0]|0;
 $54 = $53&255;
 $55 = (1157656 + ($54<<2)|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = $56&65535;
 HEAP16[$51>>1] = $57;
 $58 = (($state) + 2140|0);
 __ZNSt3__16__treeI22DeviceStencilStateGLES11memcmp_lessIS1_18DeviceStencilStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$58,$1);
 $59 = HEAP32[$0>>2]|0;
 $60 = (($59) + 16|0);
 STACKTOP = sp;return ($60|0);
}
function __ZN13GfxDeviceGLES17CreateRasterStateERK14GfxRasterState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 ;HEAP32[$1+0>>2]=HEAP32[$state+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$state+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$state+8>>2]|0;
 $2 = (($this) + 8176|0);
 __ZNSt3__16__treeI17DeviceRasterState11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$2,$1);
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 16|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN4gles17CreateRasterStateER15DeviceStateGLESRK14GfxRasterState($state,$pipeState) {
 $state = $state|0;
 $pipeState = $pipeState|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 ;HEAP32[$1+0>>2]=HEAP32[$pipeState+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$pipeState+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$pipeState+8>>2]|0;
 $2 = (($state) + 2164|0);
 __ZNSt3__16__treeI17DeviceRasterState11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$2,$1);
 $3 = HEAP32[$0>>2]|0;
 $4 = (($3) + 16|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN13GfxDeviceGLES13SetBlendStateEPK16DeviceBlendStatef($this,$state,$alphaRef) {
 $this = $this|0;
 $state = $state|0;
 $alphaRef = Math_fround($alphaRef);
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $newState$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1149744>>2]|0;
 $1 = (($0) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 64;
 $4 = ($3|0)==(0);
 $$pre = (($this) + 6012|0);
 if ($4) {
  $newState$0 = $state;
 } else {
  $5 = (__ZN4gles15UpdateColorMaskER15DeviceStateGLESPK20DeviceBlendStateGLESj($$pre,$state,0)|0);
  $newState$0 = $5;
 }
 __ZN4gles13SetBlendStateER15DeviceStateGLESPK20DeviceBlendStateGLESf($$pre,$newState$0,$alphaRef);
 STACKTOP = sp;return;
}
function __ZN4gles15UpdateColorMaskER15DeviceStateGLESPK20DeviceBlendStateGLESj($state,$blendState,$colorMask) {
 $state = $state|0;
 $blendState = $blendState|0;
 $colorMask = $colorMask|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = ($blendState|0)==(0|0);
 if ($2) {
  $3 = (($state) + 2120|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 } else {
  $6 = $blendState;
 }
 $5 = HEAP32[$6>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8&65535;
 $10 = ($9&65535) >>> 8;
 $11 = $8 >>> 16;
 $12 = $8 >>> 24;
 $13 = (($6) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14&65535;
 $16 = ($15&65535) >>> 8;
 $17 = $14 >>> 16;
 $18 = ($5|0)==($colorMask|0);
 if ($18) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = $14 >>> 24;
 $20 = $17&255;
 $21 = $16&255;
 $22 = $14&255;
 $23 = $12&255;
 $24 = $11&255;
 $25 = $10&255;
 $26 = $8&255;
 $27 = $19&255;
 HEAP32[$1>>2] = $colorMask;
 $28 = (($1) + 4|0);
 HEAP8[$28>>0] = $26;
 $29 = (($1) + 5|0);
 HEAP8[$29>>0] = $25;
 $30 = (($1) + 6|0);
 HEAP8[$30>>0] = $24;
 $31 = (($1) + 7|0);
 HEAP8[$31>>0] = $23;
 $32 = (($1) + 8|0);
 HEAP8[$32>>0] = $22;
 $33 = (($1) + 9|0);
 HEAP8[$33>>0] = $21;
 $34 = (($1) + 10|0);
 HEAP8[$34>>0] = $20;
 $35 = (($1) + 11|0);
 HEAP8[$35>>0] = $27;
 $36 = (($1) + 12|0);
 $37 = $8 & 255;
 $38 = (1157520 + ($37<<2)|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39&65535;
 HEAP16[$36>>1] = $40;
 $41 = (($1) + 14|0);
 $42 = $10&65535;
 $43 = (1157520 + ($42<<2)|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44&65535;
 HEAP16[$41>>1] = $45;
 $46 = (($1) + 16|0);
 $47 = $11 & 255;
 $48 = (1157520 + ($47<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49&65535;
 HEAP16[$46>>1] = $50;
 $51 = (($1) + 18|0);
 $52 = (1157520 + ($12<<2)|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = $53&65535;
 HEAP16[$51>>1] = $54;
 $55 = (($1) + 20|0);
 $56 = $14 & 255;
 $57 = (1157568 + ($56<<2)|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58&65535;
 HEAP16[$55>>1] = $59;
 $60 = (($1) + 22|0);
 $61 = $16&65535;
 $62 = (1157568 + ($61<<2)|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = $63&65535;
 HEAP16[$60>>1] = $64;
 $65 = (($1) + 24|0);
 $sext = $17 << 24;
 $66 = $sext >> 24;
 $67 = (1157480 + ($66<<2)|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68&65535;
 HEAP16[$65>>1] = $69;
 $70 = (($state) + 2152|0);
 __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$70,$1);
 $71 = HEAP32[$0>>2]|0;
 $72 = (($71) + 16|0);
 $$0 = $72;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles13SetBlendStateER15DeviceStateGLESPK20DeviceBlendStateGLESf($state,$newState,$alphaRef) {
 $state = $state|0;
 $newState = $newState|0;
 $alphaRef = Math_fround($alphaRef);
 var $$0 = 0, $$12 = 0, $$13 = 0, $$lobit = 0, $$lobit2 = 0, $$lobit3 = 0, $$off = 0, $$off15 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond4 = 0, $or$cond5 = 0;
 var $or$cond6 = 0, $or$cond7 = 0, $or$cond8 = 0, $or$cond9 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 57|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $$0 = $newState;
 } else {
  $4 = (($newState) + 10|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(5);
  if ($6) {
   $7 = +$alphaRef;
   $8 = !($7 <= 0.0100000000000000002082);
   if ($8) {
    $$0 = $newState;
   } else {
    $9 = (__ZN4gles15UpdateAlphaTestER15DeviceStateGLESPK20DeviceBlendStateGLES15CompareFunction($state,$newState,0)|0);
    $$0 = $9;
   }
  } else {
   $$0 = $newState;
  }
 }
 $10 = (($state) + 2120|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==($$0|0);
 do {
  if ($12) {
   $13 = (($state) + 2212|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   $15 = $14 == $alphaRef;
   if ($15) {
    STACKTOP = sp;return;
   } else {
    HEAP32[$10>>2] = $$0;
    break;
   }
  } else {
   HEAP32[$10>>2] = $$0;
   $16 = (($11) + 12|0);
   $17 = HEAP16[$16>>1]|0;
   $18 = (($11) + 14|0);
   $19 = HEAP16[$18>>1]|0;
   $20 = (($11) + 16|0);
   $21 = HEAP16[$20>>1]|0;
   $22 = (($11) + 18|0);
   $23 = HEAP16[$22>>1]|0;
   $24 = (($11) + 20|0);
   $25 = HEAP16[$24>>1]|0;
   $26 = (($11) + 22|0);
   $27 = HEAP16[$26>>1]|0;
   $28 = (($$0) + 12|0);
   $29 = HEAP16[$28>>1]|0;
   $30 = $29&65535;
   $31 = (($$0) + 14|0);
   $32 = HEAP16[$31>>1]|0;
   $33 = $32&65535;
   $34 = (($$0) + 16|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = $35&65535;
   $37 = (($$0) + 18|0);
   $38 = HEAP16[$37>>1]|0;
   $39 = $38&65535;
   $40 = (($$0) + 20|0);
   $41 = HEAP16[$40>>1]|0;
   $42 = $41&65535;
   $43 = (($$0) + 22|0);
   $44 = HEAP16[$43>>1]|0;
   $45 = $44&65535;
   $46 = HEAP32[$$0>>2]|0;
   $47 = HEAP32[$11>>2]|0;
   $48 = ($46|0)==($47|0);
   if (!($48)) {
    $49 = $46 & 1;
    $50 = (1147664 + 64|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = $46 >>> 3;
    $$lobit = $52 & 1;
    $53 = $$lobit&255;
    $54 = $46 >>> 2;
    $$lobit2 = $54 & 1;
    $55 = $$lobit2&255;
    $56 = $46 >>> 1;
    $$lobit3 = $56 & 1;
    $57 = $$lobit3&255;
    $58 = $49&255;
    FUNCTION_TABLE_viiii[$51 & 511]($53,$55,$57,$58);
   }
   $59 = ($29<<16>>16)==(1);
   $60 = ($32<<16>>16)==(0);
   $or$cond = $59 & $60;
   $61 = ($35<<16>>16)==(1);
   $or$cond4 = $or$cond & $61;
   $62 = ($38<<16>>16)==(0);
   $$12 = $or$cond4 & $62;
   $63 = ($17<<16>>16)==(1);
   $64 = ($19<<16>>16)==(0);
   $or$cond5 = $63 & $64;
   $65 = ($21<<16>>16)==(1);
   $or$cond6 = $or$cond5 & $65;
   $66 = ($23<<16>>16)==(0);
   $$13 = $or$cond6 & $66;
   $67 = $$12 ^ $$13;
   do {
    if ($67) {
     if ($$12) {
      $68 = (1147664 + 128|0);
      $69 = HEAP32[$68>>2]|0;
      FUNCTION_TABLE_vi[$69 & 4095](3042);
      break;
     } else {
      $70 = (1147664 + 144|0);
      $71 = HEAP32[$70>>2]|0;
      FUNCTION_TABLE_vi[$71 & 4095](3042);
      break;
     }
    }
   } while(0);
   $72 = ($29<<16>>16)==($17<<16>>16);
   $73 = ($32<<16>>16)==($19<<16>>16);
   $or$cond7 = $72 & $73;
   $74 = ($35<<16>>16)==($21<<16>>16);
   $or$cond8 = $or$cond7 & $74;
   $75 = ($38<<16>>16)==($23<<16>>16);
   $or$cond9 = $or$cond8 & $75;
   if (!($or$cond9)) {
    $76 = (1147664 + 32|0);
    $77 = HEAP32[$76>>2]|0;
    FUNCTION_TABLE_viiii[$77 & 511]($30,$33,$36,$39);
   }
   $78 = ($41<<16>>16)==($25<<16>>16);
   $79 = ($44<<16>>16)==($27<<16>>16);
   $or$cond10 = $78 & $79;
   if (!($or$cond10)) {
    $80 = HEAP8[((640792 + 135|0))>>0]|0;
    $81 = ($80<<24>>24)==(0);
    if ($81) {
     $$off = (($41) + 32761)<<16>>16;
     $switch = ($$off&65535)<(2);
     if ($switch) {
      break;
     }
     $$off15 = (($44) + 32761)<<16>>16;
     $82 = ($$off15&65535)>(1);
     if (!($82)) {
      break;
     }
    }
    $83 = (1147664 + 28|0);
    $84 = HEAP32[$83>>2]|0;
    FUNCTION_TABLE_vii[$84 & 4095]($42,$45);
   }
  }
 } while(0);
 $85 = (($$0) + 10|0);
 $86 = HEAP8[$85>>0]|0;
 $87 = $86 << 24 >> 24;
 $88 = HEAP32[1152880>>2]|0;
 $89 = (($88) + 85|0);
 $90 = HEAP8[$89>>0]|0;
 $91 = ($90<<24>>24)==(0);
 do {
  if (!($91)) {
   $92 = (($11) + 10|0);
   $93 = HEAP8[$92>>0]|0;
   $94 = ($86<<24>>24)==($93<<24>>24);
   if ($94) {
    $95 = (($state) + 2212|0);
    $96 = Math_fround(HEAPF32[$95>>2]);
    $97 = $96 != $alphaRef;
    if (!($97)) {
     break;
    }
   }
   $98 = ($86<<24>>24)==(0);
   if ($98) {
    $105 = (1147664 + 128|0);
    $106 = HEAP32[$105>>2]|0;
    FUNCTION_TABLE_vi[$106 & 4095](3008);
    break;
   } else {
    $99 = (1147616 + 24|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = (1157480 + ($87<<2)|0);
    $102 = HEAP32[$101>>2]|0;
    FUNCTION_TABLE_vif[$100 & 255]($102,$alphaRef);
    $103 = (1147664 + 144|0);
    $104 = HEAP32[$103>>2]|0;
    FUNCTION_TABLE_vi[$104 & 4095](3008);
    break;
   }
  }
 } while(0);
 $107 = (($state) + 2212|0);
 HEAPF32[$107>>2] = $alphaRef;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES13SetDepthStateEPK16DeviceDepthState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newState$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((1149744 + 32|0))>>2]|0;
 $1 = (($0) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 64;
 $4 = ($3|0)==(0);
 if ($4) {
  $newState$0 = $state;
 } else {
  $5 = (($this) + 8188|0);
  $6 = HEAP32[$5>>2]|0;
  $newState$0 = $6;
 }
 $7 = (($this) + 8124|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($newState$0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 HEAP32[$7>>2] = $newState$0;
 $10 = (($newState$0) + 1|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = (($8) + 1|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)==($11<<24>>24);
 do {
  if (!($14)) {
   $15 = ($11<<24>>24)==(0);
   if ($15) {
    $16 = (1147664 + 128|0);
    $17 = HEAP32[$16>>2]|0;
    FUNCTION_TABLE_vi[$17 & 4095](2929);
    break;
   }
   $18 = ($13<<24>>24)==(0);
   if ($18) {
    $19 = (1147664 + 144|0);
    $20 = HEAP32[$19>>2]|0;
    FUNCTION_TABLE_vi[$20 & 4095](2929);
   }
   $21 = (1147664 + 120|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($newState$0) + 2|0);
   $24 = HEAP16[$23>>1]|0;
   $25 = $24&65535;
   FUNCTION_TABLE_vi[$22 & 4095]($25);
  }
 } while(0);
 $26 = HEAP8[$newState$0>>0]|0;
 $27 = HEAP8[$8>>0]|0;
 $28 = ($26<<24>>24)==($27<<24>>24);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = (1147664 + 124|0);
 $30 = HEAP32[$29>>2]|0;
 FUNCTION_TABLE_vi[$30 & 4095]($26);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES14SetRasterStateEPK17DeviceRasterState($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $$phi$trans$insert = 0, $$pre = Math_fround(0), $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newState$0 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 5912|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = $3 != Math_fround(0.0);
 $$phi$trans$insert = (($this) + 5916|0);
 $$pre = Math_fround(HEAPF32[$$phi$trans$insert>>2]);
 $5 = $$pre != Math_fround(0.0);
 $or$cond = $4 | $5;
 if (!($or$cond)) {
  $newState$0 = $state;
  $23 = (($this) + 6012|0);
  __ZN4gles14SetRasterStateER15DeviceStateGLESPK17DeviceRasterState($23,$newState$0);
  STACKTOP = sp;return;
 }
 $6 = ($state|0)==(0|0);
 if ($6) {
  $7 = (($this) + 8136|0);
  $8 = HEAP32[$7>>2]|0;
  $$sink$i = $8;
 } else {
  $$sink$i = $state;
 }
 $9 = HEAP32[$$sink$i>>2]|0;
 $10 = (($$sink$i) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($$sink$i) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (Math_fround(($11|0)));
 $15 = Math_fround($3 + $14);
 $16 = (~~(($15)));
 $17 = Math_fround($$pre + $13);
 HEAP32[$1>>2] = $9;
 $18 = (($1) + 4|0);
 HEAP32[$18>>2] = $16;
 $19 = (($1) + 8|0);
 HEAPF32[$19>>2] = $17;
 $20 = (($this) + 8176|0);
 __ZNSt3__16__treeI17DeviceRasterState11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$20,$1);
 $21 = HEAP32[$0>>2]|0;
 $22 = (($21) + 16|0);
 $newState$0 = $22;
 $23 = (($this) + 6012|0);
 __ZN4gles14SetRasterStateER15DeviceStateGLESPK17DeviceRasterState($23,$newState$0);
 STACKTOP = sp;return;
}
function __ZN4gles14SetRasterStateER15DeviceStateGLESPK17DeviceRasterState($state,$newState) {
 $state = $state|0;
 $newState = $newState|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond2 = 0, $zFactor$0 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 2124|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($newState|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $newState;
 $3 = HEAP32[$newState>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($3|0)==($4|0);
 do {
  if (!($5)) {
   if ((($3|0) == 1)) {
    $8 = (1147664 + 92|0);
    $9 = HEAP32[$8>>2]|0;
    FUNCTION_TABLE_vi[$9 & 4095](1028);
    $10 = (1147664 + 144|0);
    $11 = HEAP32[$10>>2]|0;
    FUNCTION_TABLE_vi[$11 & 4095](2884);
    break;
   } else if ((($3|0) == 2)) {
    $12 = (1147664 + 92|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vi[$13 & 4095](1029);
    $14 = (1147664 + 144|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vi[$15 & 4095](2884);
    break;
   } else if ((($3|0) == 0)) {
    $6 = (1147664 + 128|0);
    $7 = HEAP32[$6>>2]|0;
    FUNCTION_TABLE_vi[$7 & 4095](2884);
    break;
   } else {
    break;
   }
  }
 } while(0);
 $16 = (($newState) + 8|0);
 $17 = Math_fround(HEAPF32[$16>>2]);
 $18 = (($newState) + 4|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (Math_fround(($19|0)));
 $21 = (($1) + 8|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = $17 != $22;
 if (!($23)) {
  $24 = (($1) + 4|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (Math_fround(($25|0)));
  $27 = $20 != $26;
  if (!($27)) {
   STACKTOP = sp;return;
  }
 }
 $28 = HEAP32[((640792 + 308|0))>>2]|0;
 $29 = ($28|0)==(2);
 if ($29) {
  $30 = HEAP8[((640792 + 333|0))>>0]|0;
  $31 = HEAP8[((640792 + 332|0))>>0]|0;
  $32 = $31 | $30;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   $zFactor$0 = $17;
  } else {
   $34 = Math_fround($17 * Math_fround(16.0));
   $zFactor$0 = $34;
  }
 } else {
  $zFactor$0 = $17;
 }
 $35 = (1147664 + 264|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_vff[$36 & 3]($zFactor$0,$20);
 $37 = $zFactor$0 != Math_fround(0.0);
 $38 = $20 != Math_fround(0.0);
 $or$cond2 = $37 | $38;
 if ($or$cond2) {
  $39 = (1147664 + 144|0);
  $40 = HEAP32[$39>>2]|0;
  FUNCTION_TABLE_vi[$40 & 4095](32823);
  STACKTOP = sp;return;
 } else {
  $41 = (1147664 + 128|0);
  $42 = HEAP32[$41>>2]|0;
  FUNCTION_TABLE_vi[$42 & 4095](32823);
  STACKTOP = sp;return;
 }
}
function __ZN13GfxDeviceGLES15SetStencilStateEPK18DeviceStencilStatei($this,$state,$stencilRef) {
 $this = $this|0;
 $state = $state|0;
 $stencilRef = $stencilRef|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6012|0);
 __ZN4gles15SetStencilStateER15DeviceStateGLESPK22DeviceStencilStateGLESi($0,$state,$stencilRef);
 STACKTOP = sp;return;
}
function __ZN4gles15SetStencilStateER15DeviceStateGLESPK22DeviceStencilStateGLESi($state,$newState,$stencilRef) {
 $state = $state|0;
 $newState = $newState|0;
 $stencilRef = $stencilRef|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 2116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($newState|0);
 if ($2) {
  $3 = (($state) + 2216|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($stencilRef|0);
  if ($5) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$0>>2] = $newState;
 $6 = HEAP8[$newState>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = (1147664 + 128|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_vi[$11 & 4095](2960);
 } else {
  $8 = (1147664 + 144|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vi[$9 & 4095](2960);
 }
 $12 = HEAP8[((640792 + 253|0))>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $51 = (1147664 + 284|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = (($newState) + 12|0);
  $54 = HEAP16[$53>>1]|0;
  $55 = $54&65535;
  $56 = (($newState) + 1|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57&255;
  FUNCTION_TABLE_viii[$52 & 4095]($55,$stencilRef,$58);
  $59 = (1147664 + 296|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($newState) + 16|0);
  $62 = HEAP16[$61>>1]|0;
  $63 = $62&65535;
  $64 = (($newState) + 18|0);
  $65 = HEAP16[$64>>1]|0;
  $66 = $65&65535;
  $67 = (($newState) + 14|0);
  $68 = HEAP16[$67>>1]|0;
  $69 = $68&65535;
  FUNCTION_TABLE_viii[$60 & 4095]($63,$66,$69);
 } else {
  $14 = (1147664 + 288|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($newState) + 12|0);
  $17 = HEAP16[$16>>1]|0;
  $18 = $17&65535;
  $19 = (($newState) + 1|0);
  $20 = HEAP8[$19>>0]|0;
  $21 = $20&255;
  FUNCTION_TABLE_viiii[$15 & 511](1028,$18,$stencilRef,$21);
  $22 = (1147664 + 300|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($newState) + 16|0);
  $25 = HEAP16[$24>>1]|0;
  $26 = $25&65535;
  $27 = (($newState) + 18|0);
  $28 = HEAP16[$27>>1]|0;
  $29 = $28&65535;
  $30 = (($newState) + 14|0);
  $31 = HEAP16[$30>>1]|0;
  $32 = $31&65535;
  FUNCTION_TABLE_viiii[$23 & 511](1028,$26,$29,$32);
  $33 = (1147664 + 288|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($newState) + 20|0);
  $36 = HEAP16[$35>>1]|0;
  $37 = $36&65535;
  $38 = HEAP8[$19>>0]|0;
  $39 = $38&255;
  FUNCTION_TABLE_viiii[$34 & 511](1029,$37,$stencilRef,$39);
  $40 = (1147664 + 300|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($newState) + 24|0);
  $43 = HEAP16[$42>>1]|0;
  $44 = $43&65535;
  $45 = (($newState) + 26|0);
  $46 = HEAP16[$45>>1]|0;
  $47 = $46&65535;
  $48 = (($newState) + 22|0);
  $49 = HEAP16[$48>>1]|0;
  $50 = $49&65535;
  FUNCTION_TABLE_viiii[$41 & 511](1029,$44,$47,$50);
 }
 $70 = (1147664 + 292|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($newState) + 2|0);
 $73 = HEAP8[$72>>0]|0;
 $74 = $73&255;
 FUNCTION_TABLE_vi[$71 & 4095]($74);
 $75 = (($state) + 2216|0);
 HEAP32[$75>>2] = $stencilRef;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES12SetSRGBWriteEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES12GetSRGBWriteEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN13GfxDeviceGLES19SetUserBackfaceModeEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5925|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $enable&1;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $enable&1;
 HEAP8[$0>>0] = $5;
 $6 = (($this) + 8237|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==($5<<24>>24);
 $9 = (1147664 + 168|0);
 $10 = HEAP32[$9>>2]|0;
 if ($8) {
  FUNCTION_TABLE_vi[$10 & 4095](2304);
  STACKTOP = sp;return;
 } else {
  FUNCTION_TABLE_vi[$10 & 4095](2305);
  STACKTOP = sp;return;
 }
}
function __ZN13GfxDeviceGLES25SetInvertProjectionMatrixEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES19SetProjectionMatrixERK10Matrix4x4f($this,$matrix) {
 $this = $this|0;
 $matrix = $matrix|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6076|0);
 __Z13CopyMatrixREFPKfPf($matrix,$0);
 $1 = (($this) + 2788|0);
 __Z13CopyMatrixREFPKfPf($matrix,$1);
 $2 = (($this) + 6204|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 | 4;
 HEAP32[$2>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES14SetWorldMatrixERK10Matrix4x4f($this,$matrix) {
 $this = $this|0;
 $matrix = $matrix|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 6012|0);
 dest=$0+0|0; src=$matrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (($this) + 6204|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 | 1;
 HEAP32[$1>>2] = $3;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES13SetViewMatrixERK10Matrix4x4f($this,$matrix) {
 $this = $this|0;
 $matrix = $matrix|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 6012|0);
 $1 = (($this) + 6204|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 | 3;
 HEAP32[$1>>2] = $3;
 $4 = (($this) + 2724|0);
 $5 = (($this) + 2788|0);
 $6 = (($this) + 2852|0);
 dest=$4+0|0; src=$matrix+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($5,$4,$6);
 dest=$0+0|0; src=616552+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZNK13GfxDeviceGLES18GetWorldViewMatrixEv($this) {
 $this = $this|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6204|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 3;
 $3 = ($2|0)==(0);
 if ($3) {
  $$pre = (($this) + 6140|0);
  $$pre$phiZ2D = $$pre;
  STACKTOP = sp;return ($$pre$phiZ2D|0);
 } else {
  $4 = (($this) + 2724|0);
  $5 = (($this) + 6012|0);
  $6 = (($this) + 6140|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($4,$5,$6);
  $7 = HEAP32[$0>>2]|0;
  $8 = $7 & -4;
  HEAP32[$0>>2] = $8;
  $$pre$phiZ2D = $6;
  STACKTOP = sp;return ($$pre$phiZ2D|0);
 }
 return 0|0;
}
function __ZNK13GfxDeviceGLES14GetWorldMatrixEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6012|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK13GfxDeviceGLES13GetViewMatrixEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 2724|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK13GfxDeviceGLES19GetProjectionMatrixEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6076|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK13GfxDeviceGLES25GetDeviceProjectionMatrixEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 120|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN13GfxDeviceGLES15SetBackfaceModeEb($this,$backface) {
 $this = $this|0;
 $backface = $backface|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8237|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $backface&1;
 $4 = ($2|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = $backface&1;
 HEAP8[$0>>0] = $5;
 $6 = (($this) + 5925|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($5<<24>>24)==($7<<24>>24);
 $9 = (1147664 + 168|0);
 $10 = HEAP32[$9>>2]|0;
 if ($8) {
  FUNCTION_TABLE_vi[$10 & 4095](2304);
  STACKTOP = sp;return;
 } else {
  FUNCTION_TABLE_vi[$10 & 4095](2305);
  STACKTOP = sp;return;
 }
}
function __ZN13GfxDeviceGLES13SetFFLightingEbb17ColorMaterialMode($this,$on,$separateSpecular,$colorMaterial) {
 $this = $this|0;
 $on = $on|0;
 $separateSpecular = $separateSpecular|0;
 $colorMaterial = $colorMaterial|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8233|0);
 $1 = $on&1;
 HEAP8[$0>>0] = $1;
 $2 = (($this) + 8234|0);
 $3 = $separateSpecular&1;
 HEAP8[$2>>0] = $3;
 $4 = $colorMaterial&255;
 $5 = (($this) + 8232|0);
 HEAP8[$5>>0] = $4;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES13SetFFMaterialERK17GfxMaterialParams($this,$params) {
 $this = $this|0;
 $params = $params|0;
 var $$op = Math_fround(0), $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = Math_fround(0), $40 = Math_fround(0), $41 = 0, $42 = Math_fround(0), $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$params>>2]);
 $1 = (($params) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($params) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($params) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 8040|0);
 HEAPF32[$7>>2] = $0;
 $8 = (($this) + 8044|0);
 HEAPF32[$8>>2] = $2;
 $9 = (($this) + 8048|0);
 HEAPF32[$9>>2] = $4;
 $10 = (($this) + 8052|0);
 HEAPF32[$10>>2] = $6;
 $11 = (($params) + 16|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($params) + 20|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($params) + 24|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($params) + 28|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = (($this) + 8056|0);
 HEAPF32[$19>>2] = $12;
 $20 = (($this) + 8060|0);
 HEAPF32[$20>>2] = $14;
 $21 = (($this) + 8064|0);
 HEAPF32[$21>>2] = $16;
 $22 = (($this) + 8068|0);
 HEAPF32[$22>>2] = $18;
 $23 = (($params) + 32|0);
 $24 = Math_fround(HEAPF32[$23>>2]);
 $25 = (($params) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = (($params) + 40|0);
 $28 = Math_fround(HEAPF32[$27>>2]);
 $29 = (($params) + 44|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = (($this) + 8072|0);
 HEAPF32[$31>>2] = $24;
 $32 = (($this) + 8076|0);
 HEAPF32[$32>>2] = $26;
 $33 = (($this) + 8080|0);
 HEAPF32[$33>>2] = $28;
 $34 = (($this) + 8084|0);
 HEAPF32[$34>>2] = $30;
 $35 = (($params) + 48|0);
 $36 = Math_fround(HEAPF32[$35>>2]);
 $37 = (($params) + 52|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = (($params) + 56|0);
 $40 = Math_fround(HEAPF32[$39>>2]);
 $41 = (($params) + 60|0);
 $42 = Math_fround(HEAPF32[$41>>2]);
 $43 = (($this) + 8088|0);
 HEAPF32[$43>>2] = $36;
 $44 = (($this) + 8092|0);
 HEAPF32[$44>>2] = $38;
 $45 = (($this) + 8096|0);
 HEAPF32[$45>>2] = $40;
 $46 = (($this) + 8100|0);
 HEAPF32[$46>>2] = $42;
 $47 = (($params) + 64|0);
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($this) + 8104|0);
 HEAPF32[$49>>2] = $48;
 HEAPF32[$10>>2] = Math_fround(1.0);
 HEAPF32[$34>>2] = Math_fround(1.0);
 HEAPF32[$46>>2] = Math_fround(1.0);
 $50 = Math_fround(HEAPF32[$47>>2]);
 $51 = $50 > Math_fround(1.0);
 $52 = $51 ? Math_fround(1.0) : $50;
 $53 = $52 < Math_fround(0.0);
 $$op = Math_fround($52 * Math_fround(128.0));
 $54 = $53 ? Math_fround(0.0) : $$op;
 HEAPF32[$49>>2] = $54;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES10SetFFColorERK10ColorRGBAf($this,$color) {
 $this = $this|0;
 $color = $color|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = Math_fround(HEAPF32[$color>>2]);
 $1 = (($color) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($color) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($color) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($this) + 8108|0);
 HEAPF32[$7>>2] = $0;
 $8 = (($this) + 8112|0);
 HEAPF32[$8>>2] = $2;
 $9 = (($this) + 8116|0);
 HEAPF32[$9>>2] = $4;
 $10 = (($this) + 8120|0);
 HEAPF32[$10>>2] = $6;
 $11 = HEAP32[$this>>2]|0;
 $12 = (($11) + 568|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$color>>2]);
 $15 = Math_fround(HEAPF32[$1>>2]);
 $16 = Math_fround(HEAPF32[$3>>2]);
 $17 = Math_fround(HEAPF32[$5>>2]);
 FUNCTION_TABLE_viffff[$13 & 15]($this,$14,$15,$16,$17);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES11SetViewportERK5RectTIiE($this,$rect) {
 $this = $this|0;
 $rect = $rect|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8192|0);
 ;HEAP32[$0+0>>2]=HEAP32[$rect+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$rect+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$rect+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$rect+12>>2]|0;
 __ZN4gles17SetActiveViewportERK5RectTIiE($rect);
 STACKTOP = sp;return;
}
function __ZNK13GfxDeviceGLES11GetViewportEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8192|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES14DisableScissorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8238|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (1147664 + 128|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095](3089);
 HEAP8[$0>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK13GfxDeviceGLES16IsScissorEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8238|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN13GfxDeviceGLES14SetScissorRectERK5RectTIiE($this,$rect) {
 $this = $this|0;
 $rect = $rect|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8238|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (1147664 + 144|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095](3089);
  HEAP8[$0>>0] = 1;
 }
 $5 = (($this) + 8208|0);
 ;HEAP32[$5+0>>2]=HEAP32[$rect+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$rect+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$rect+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$rect+12>>2]|0;
 __ZN4gles16SetActiveScissorERK5RectTIiE($rect);
 STACKTOP = sp;return;
}
function __ZNK13GfxDeviceGLES14GetScissorRectEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8208|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES22IsCombineModeSupportedEj($this,$combiner) {
 $this = $this|0;
 $combiner = $combiner|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN13GfxDeviceGLES22CreateTextureCombinersEiPKN9ShaderLab14TextureBindingEPKNS0_13PropertySheetEbb($this,$count,$texEnvs,$props,$hasVertexColorOrLighting,$usesAddSpecular) {
 $this = $this|0;
 $count = $count|0;
 $texEnvs = $texEnvs|0;
 $props = $props|0;
 $hasVertexColorOrLighting = $hasVertexColorOrLighting|0;
 $usesAddSpecular = $usesAddSpecular|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN20TextureCombinersGLES6CreateEiPKN9ShaderLab14TextureBindingE($count,$texEnvs)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13GfxDeviceGLES22DeleteTextureCombinersER12ObjectHandleI20TextureCombiners_TagPvE($this,$textureCombiners) {
 $this = $this|0;
 $textureCombiners = $textureCombiners|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$textureCombiners>>2]|0;
 $2 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[$textureCombiners>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES19SetTextureCombinersE12ObjectHandleI20TextureCombiners_TagPvEPKN9ShaderLab13PropertySheetERKNS4_17ShaderPassContextE($this,$textureCombiners,$props,$passContext) {
 $this = $this|0;
 $textureCombiners = $textureCombiners|0;
 $props = $props|0;
 $passContext = $passContext|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = Math_fround(0);
 var $44 = Math_fround(0), $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond11 = 0, $i$07 = 0, $i1$05 = 0, $texColors = 0, $texEnvData = 0;
 var $texScaleOffset = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy = sp + 196|0;
 $texEnvData = sp;
 $texScaleOffset = sp + 48|0;
 $texColors = sp + 112|0;
 $0 = sp + 176|0;
 $1 = sp + 192|0;
 $2 = HEAP32[$textureCombiners>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$texEnvData>>2] = 0;
 $4 = (($texEnvData) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($texEnvData) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($texEnvData) + 36|0);
 HEAP32[$6>>2] = 0;
 $7 = ($3|0)>(0);
 if ($7) {
  $8 = (($2) + 4|0);
  $9 = ($3|0)<(4);
  $10 = $9 ? $3 : 4;
  $i$07 = 0;
  while(1) {
   $11 = HEAP32[$8>>2]|0;
   $12 = (($11) + (($i$07*52)|0)|0);
   $13 = (__ZN9ShaderLab19GetTexEnvForBindingERKNS_14TextureBindingEPKNS_13PropertySheetERKNS_17ShaderPassContextE($12,$props,$passContext)|0);
   $14 = (($texEnvData) + (($i$07*12)|0)|0);
   __ZNK9ShaderLab6TexEnv11PrepareDataEP10TexEnvData($13,$14);
   $15 = (($13) + 44|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   $17 = (($13) + 32|0);
   $18 = Math_fround(HEAPF32[$17>>2]);
   $19 = Math_fround($16 * $18);
   $20 = (($13) + 48|0);
   $21 = Math_fround(HEAPF32[$20>>2]);
   $22 = (($13) + 36|0);
   $23 = Math_fround(HEAPF32[$22>>2]);
   $24 = Math_fround($21 * $23);
   $25 = (($13) + 52|0);
   $26 = Math_fround(HEAPF32[$25>>2]);
   $27 = (($13) + 56|0);
   $28 = Math_fround(HEAPF32[$27>>2]);
   $29 = (($texScaleOffset) + ($i$07<<4)|0);
   HEAPF32[$29>>2] = $19;
   $30 = ((($texScaleOffset) + ($i$07<<4)|0) + 4|0);
   HEAPF32[$30>>2] = $24;
   $31 = ((($texScaleOffset) + ($i$07<<4)|0) + 8|0);
   HEAPF32[$31>>2] = $26;
   $32 = ((($texScaleOffset) + ($i$07<<4)|0) + 12|0);
   HEAPF32[$32>>2] = $28;
   $33 = (($i$07) + 1)|0;
   $exitcond11 = ($33|0)==($10|0);
   if ($exitcond11) {
    break;
   } else {
    $i$07 = $33;
   }
  }
  if ($7) {
   $34 = (($2) + 4|0);
   $35 = (($0) + 4|0);
   $36 = (($0) + 8|0);
   $37 = (($0) + 12|0);
   $38 = ($3|0)<(4);
   $39 = $38 ? $3 : 4;
   $i1$05 = 0;
   while(1) {
    $40 = HEAP32[$34>>2]|0;
    $41 = ((($40) + (($i1$05*52)|0)|0) + 12|0);
    __ZNK9ShaderLab9VectorVal3GetEPKNS_13PropertySheetERKNS_17ShaderPassContextE($0,$41,$props,$passContext);
    $42 = Math_fround(HEAPF32[$0>>2]);
    $43 = Math_fround(HEAPF32[$35>>2]);
    $44 = Math_fround(HEAPF32[$36>>2]);
    $45 = Math_fround(HEAPF32[$37>>2]);
    $46 = (($texColors) + ($i1$05<<4)|0);
    HEAPF32[$46>>2] = $42;
    $47 = ((($texColors) + ($i1$05<<4)|0) + 4|0);
    HEAPF32[$47>>2] = $43;
    $48 = ((($texColors) + ($i1$05<<4)|0) + 8|0);
    HEAPF32[$48>>2] = $44;
    $49 = ((($texColors) + ($i1$05<<4)|0) + 12|0);
    HEAPF32[$49>>2] = $45;
    $50 = (($i1$05) + 1)|0;
    $exitcond = ($50|0)==($39|0);
    if ($exitcond) {
     $51 = $texColors;$52 = $texColors;
     break;
    } else {
     $i1$05 = $50;
    }
   }
  } else {
   $51 = $texColors;$52 = $texColors;
  }
 } else {
  $51 = $texColors;$52 = $texColors;
 }
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN13GfxDeviceGLES29SetTextureCombinersThreadableE12ObjectHandleI20TextureCombiners_TagPvEPK10TexEnvDataPK8Vector4fPK10ColorRGBAf($this,$$byval_copy,$texEnvData,$texScaleOffset,$51);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES29SetTextureCombinersThreadableE12ObjectHandleI20TextureCombiners_TagPvEPK10TexEnvDataPK8Vector4fPK10ColorRGBAf($this,$textureCombiners,$texEnvData,$texScaleOffsets,$texColors) {
 $this = $this|0;
 $textureCombiners = $textureCombiners|0;
 $texEnvData = $texEnvData|0;
 $texScaleOffsets = $texScaleOffsets|0;
 $texColors = $texColors|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $smax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$textureCombiners>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[((640792 + 104|0))>>2]|0;
 $4 = ($2|0)<($3|0);
 $5 = $4 ? $2 : $3;
 $6 = (($this) + 6012|0);
 $7 = (($this) + 7960|0);
 HEAP32[$7>>2] = $5;
 $8 = ($5|0)>(0);
 if (!($8)) {
  $47 = (($this) + 7968|0);
  HEAP32[$47>>2] = 0;
  __ZN4gles19ActivateTextureUnitER15DeviceStateGLESj($6,0);
  STACKTOP = sp;return;
 }
 $9 = (($1) + 4|0);
 $10 = $2 ^ -1;
 $11 = $3 ^ -1;
 $12 = ($10|0)>($11|0);
 $smax = $12 ? $10 : $11;
 $13 = $smax ^ -1;
 $i$02 = 0;
 while(1) {
  $14 = HEAP32[$9>>2]|0;
  $15 = HEAP32[$this>>2]|0;
  $16 = (($15) + 208|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($texEnvData) + (($i$02*12)|0)|0);
  $19 = HEAP32[$18>>2]|0;
  HEAP32[$0>>2] = $19;
  $20 = ((($texEnvData) + (($i$02*12)|0)|0) + 8|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = $21 & 15;
  $23 = $22&255;
  $24 = ((($texEnvData) + (($i$02*12)|0)|0) + 4|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_viiiiiif[$17 & 1]($this,2,$i$02,$i$02,$$byval_copy,$23,$25);
  $26 = (($texColors) + ($i$02<<4)|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = ((($texColors) + ($i$02<<4)|0) + 4|0);
  $29 = Math_fround(HEAPF32[$28>>2]);
  $30 = ((($texColors) + ($i$02<<4)|0) + 8|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = ((($texColors) + ($i$02<<4)|0) + 12|0);
  $33 = Math_fround(HEAPF32[$32>>2]);
  $34 = ((($this) + (($i$02*52)|0)|0) + 6296|0);
  HEAPF32[$34>>2] = $27;
  $35 = ((($this) + (($i$02*52)|0)|0) + 6300|0);
  HEAPF32[$35>>2] = $29;
  $36 = ((($this) + (($i$02*52)|0)|0) + 6304|0);
  HEAPF32[$36>>2] = $31;
  $37 = ((($this) + (($i$02*52)|0)|0) + 6308|0);
  HEAPF32[$37>>2] = $33;
  $38 = ((($this) + (($i$02*52)|0)|0) + 6312|0);
  $39 = (($texScaleOffsets) + ($i$02<<4)|0);
  ;HEAP32[$38+0>>2]=HEAP32[$39+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$39+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$39+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$39+12>>2]|0;
  $40 = ((($14) + (($i$02*52)|0)|0) + 4|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($this) + (($i$02*52)|0)|0) + 6336|0);
  HEAP32[$42>>2] = $41;
  $43 = ((($14) + (($i$02*52)|0)|0) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($this) + (($i$02*52)|0)|0) + 6340|0);
  HEAP32[$45>>2] = $44;
  $46 = (($i$02) + 1)|0;
  $exitcond = ($46|0)==($13|0);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $46;
  }
 }
 $47 = (($this) + 7968|0);
 HEAP32[$47>>2] = 0;
 __ZN4gles19ActivateTextureUnitER15DeviceStateGLESj($6,0);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES10SetTextureE10ShaderTypeii9TextureID16TextureDimensionf($this,$shaderType,$unit,$samplerUnit,$texture,$dim,$bias) {
 $this = $this|0;
 $shaderType = $shaderType|0;
 $unit = $unit|0;
 $samplerUnit = $samplerUnit|0;
 $texture = $texture|0;
 $dim = $dim|0;
 $bias = Math_fround($bias);
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 6012|0);
 $2 = HEAP32[$texture>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __ZN4gles10SetTextureER15DeviceStateGLES9TextureID16TextureDimensionj($1,$$byval_copy,$dim,$unit);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES16SetTextureParamsE9TextureID16TextureDimension17TextureFilterMode15TextureWrapModeib17TextureColorSpace($this,$texture,$texDim,$filter,$wrap,$anisoLevel,$hasMipMap,$colorSpace) {
 $this = $this|0;
 $texture = $texture|0;
 $texDim = $texDim|0;
 $filter = $filter|0;
 $wrap = $wrap|0;
 $anisoLevel = $anisoLevel|0;
 $hasMipMap = $hasMipMap|0;
 $colorSpace = $colorSpace|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $hasMipMap$not = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$texture>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 (__Z30TextureIdMapGLES_QueryOrCreate9TextureID($$byval_copy1)|0);
 $3 = (1149128 + ($texDim<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + 208|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_viiiiiif[$7 & 1]($this,2,0,0,$$byval_copy1,$texDim,Math_fround(inf));
 $8 = HEAP8[((640792 + 125|0))>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = HEAP32[((640792 + 92|0))>>2]|0;
  $11 = ($10|0)<($anisoLevel|0);
  $12 = $11 ? $10 : $anisoLevel;
  $13 = (1147664 + 308|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_viii[$14 & 4095]($4,34046,$12);
 }
 $15 = (1149152 + ($wrap<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (1147664 + 308|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_viii[$18 & 4095]($4,10242,$16);
 $19 = (1147664 + 308|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_viii[$20 & 4095]($4,10243,$16);
 $hasMipMap$not = $hasMipMap ^ 1;
 $21 = ($filter|0)==(2);
 $or$cond = $21 & $hasMipMap$not;
 $$0 = $or$cond ? 1 : $filter;
 $22 = (1147664 + 308|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($$0|0)!=(0);
 $25 = $24 ? 9729 : 9728;
 FUNCTION_TABLE_viii[$23 & 4095]($4,10240,$25);
 $26 = (1147664 + 308|0);
 $27 = HEAP32[$26>>2]|0;
 if ($hasMipMap) {
  $28 = (1149160 + ($$0<<2)|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_viii[$27 & 4095]($4,10241,$29);
  STACKTOP = sp;return;
 } else {
  FUNCTION_TABLE_viii[$27 & 4095]($4,10241,$25);
  STACKTOP = sp;return;
 }
}
function __Z30TextureIdMapGLES_QueryOrCreate9TextureID($texid) {
 $texid = $texid|0;
 var $$pre$i = 0, $$pre$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pos$i$i$i4 = sp + 48|0;
 $0 = sp + 32|0;
 $1 = sp + 16|0;
 $2 = sp;
 $3 = sp + 8|0;
 $ret = sp + 40|0;
 $4 = HEAP32[$texid>>2]|0;
 HEAP32[$3>>2] = $4;
 $5 = HEAP32[((599640 + 36|0))>>2]|0;
 $6 = HEAP32[((599640 + 4|0))>>2]|0;
 $7 = ($5|0)==($6|0);
 do {
  if ($7) {
   $8 = HEAP32[((599640 + 28|0))>>2]|0;
   $9 = HEAP32[((599640 + 32|0))>>2]|0;
   $10 = (($8) + ($9<<3)|0);
   $18 = $8;$19 = $9;$21 = $10;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i4,599640,$3);
   $11 = HEAP32[$pos$i$i$i4>>2]|0;
   $12 = ($11|0)==(-1);
   $13 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($12) {
    $14 = HEAP32[((599640 + 32|0))>>2]|0;
    $15 = (($13) + ($14<<3)|0);
    $18 = $13;$19 = $14;$21 = $15;
    break;
   } else {
    $16 = (($13) + ($11<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $18 = $13;$19 = $$pre$i;$21 = $16;
    break;
   }
  }
 } while(0);
 $17 = (($18) + ($19<<3)|0);
 $20 = ($21|0)==($17|0);
 if ($20) {
  HEAP32[$ret>>2] = 0;
 } else {
  $22 = (($21) + 4|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$ret>>2] = $23;
  $24 = ($23|0)==(0);
  if (!($24)) {
   $48 = HEAP32[$ret>>2]|0;
   STACKTOP = sp;return ($48|0);
  }
 }
 $25 = (1147664 + 188|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vii[$26 & 4095](1,$ret);
 $27 = HEAP32[$ret>>2]|0;
 HEAP32[$2>>2] = $4;
 $28 = HEAP32[((599640 + 36|0))>>2]|0;
 $29 = HEAP32[((599640 + 4|0))>>2]|0;
 $30 = ($28|0)==($29|0);
 do {
  if ($30) {
   $31 = HEAP32[((599640 + 28|0))>>2]|0;
   $32 = HEAP32[((599640 + 32|0))>>2]|0;
   $33 = (($31) + ($32<<3)|0);
   $41 = $31;$42 = $32;$44 = $33;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i4,599640,$2);
   $34 = HEAP32[$pos$i$i$i4>>2]|0;
   $35 = ($34|0)==(-1);
   $36 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($35) {
    $37 = HEAP32[((599640 + 32|0))>>2]|0;
    $38 = (($36) + ($37<<3)|0);
    $41 = $36;$42 = $37;$44 = $38;
    break;
   } else {
    $39 = (($36) + ($34<<3)|0);
    $$pre$i5 = HEAP32[((599640 + 32|0))>>2]|0;
    $41 = $36;$42 = $$pre$i5;$44 = $39;
    break;
   }
  }
 } while(0);
 $40 = (($41) + ($42<<3)|0);
 $43 = ($44|0)==($40|0);
 if ($43) {
  $46 = HEAP32[$2>>2]|0;
  HEAP32[$0>>2] = $46;
  $47 = (($0) + 4|0);
  HEAP32[$47>>2] = $27;
  __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E12resize_deltaEjj(599640,1,0);
  __ZN15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E15insert_noresizeERKS4_($1,599640,$0);
  $48 = HEAP32[$ret>>2]|0;
  STACKTOP = sp;return ($48|0);
 } else {
  $45 = (($44) + 4|0);
  HEAP32[$45>>2] = $27;
  $48 = HEAP32[$ret>>2]|0;
  STACKTOP = sp;return ($48|0);
 }
 return 0|0;
}
function __ZN13GfxDeviceGLES20SetShadersThreadableEPP10GpuProgramPPK20GpuProgramParametersPKPKh($this,$programs,$params,$paramsBuffer) {
 $this = $this|0;
 $programs = $programs|0;
 $params = $params|0;
 $paramsBuffer = $paramsBuffer|0;
 var $$byval_copy1 = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($programs) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($2) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(6);
  if ($6) {
   $7 = (($this) + 7968|0);
   HEAP32[$7>>2] = $2;
   $8 = (($params) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 7972|0);
   HEAP32[$10>>2] = $9;
   $11 = (($9) + 156|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 7976|0);
   $14 = (($this) + 7984|0);
   HEAP32[$14>>2] = $12;
   $15 = (($this) + 7988|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16 & 2147483647;
   $18 = ($17>>>0)<($12>>>0);
   do {
    if ($18) {
     $19 = ($16|0)>(-1);
     if ($19) {
      HEAP32[$15>>2] = $12;
      $20 = HEAP32[$13>>2]|0;
      $21 = (($this) + 7980|0);
      $22 = HEAP32[$21>>2]|0;
      HEAP32[$0>>2] = $22;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $23 = (__Z16realloc_internalPvji10MemLabelIdiPKci($20,$12,1,$$byval_copy1,0,1149224,370)|0);
      HEAP32[$13>>2] = $23;
      $34 = $23;
      break;
     } else {
      $24 = (($this) + 7980|0);
      $25 = HEAP32[$24>>2]|0;
      HEAP32[$0>>2] = $25;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $26 = (__Z15malloc_internaljj10MemLabelIdiPKci($12,1,$$byval_copy1,0,1149224,352)|0);
      $27 = HEAP32[$13>>2]|0;
      $28 = HEAP32[$14>>2]|0;
      _memcpy(($26|0),($27|0),($28|0))|0;
      HEAP32[$15>>2] = $12;
      HEAP32[$13>>2] = $26;
      $34 = $26;
      break;
     }
    } else {
     $$pre1 = HEAP32[$13>>2]|0;
     $34 = $$pre1;
    }
   } while(0);
   $32 = (($paramsBuffer) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   _memcpy(($34|0),($33|0),($12|0))|0;
   $$pre = HEAP32[$7>>2]|0;
   $35 = ($$pre|0)==(0|0);
   if ($35) {
    STACKTOP = sp;return;
   }
   $36 = (($this) + 7972|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = (($this) + 7976|0);
   $39 = HEAP32[$38>>2]|0;
   __ZN18GlslGpuProgramGLES19ApplyGpuProgramGLESERK20GpuProgramParametersPKh($$pre,$37,$39);
   $40 = HEAP32[$36>>2]|0;
   $41 = (($40) + 60|0);
   $42 = (($this) + 8000|0);
   HEAP32[$42>>2] = $41;
   $43 = (($40) + 72|0);
   $44 = (($this) + 5808|0);
   HEAP32[$44>>2] = $43;
   $45 = (($$pre) + 20|0);
   $46 = (($this) + 7996|0);
   HEAP32[$46>>2] = $45;
   STACKTOP = sp;return;
  }
 }
 $29 = (($this) + 7968|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 7972|0);
 HEAP32[$30>>2] = 0;
 $31 = (($this) + 7984|0);
 HEAP32[$31>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK13GfxDeviceGLES14IsShaderActiveE10ShaderType($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 7968|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN13GfxDeviceGLES17DestroySubProgramEPN9ShaderLab10SubProgramE($this,$subprogram) {
 $this = $this|0;
 $subprogram = $subprogram|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628280>>2]|0;
 $2 = ($subprogram|0)==(0|0);
 if (!($2)) {
  __ZN9ShaderLab10SubProgramD2Ev($subprogram);
 }
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($subprogram,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES13DisableLightsEi($this,$startLight) {
 $this = $this|0;
 $startLight = $startLight|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((640792 + 88|0))>>2]|0;
 $1 = ($0|0)<($startLight|0);
 $2 = $1 ? $0 : $startLight;
 $3 = (($this) + 8036|0);
 HEAP32[$3>>2] = $2;
 $4 = ($2|0)<(8);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 4|0);
 $i$05 = $2;
 while(1) {
  $6 = (($i$05) + 8)|0;
  $7 = (($5) + ($6<<4)|0);
  HEAPF32[$7>>2] = Math_fround(0.0);
  $8 = ((($5) + ($6<<4)|0) + 4|0);
  HEAPF32[$8>>2] = Math_fround(0.0);
  $9 = ((($5) + ($6<<4)|0) + 8|0);
  HEAPF32[$9>>2] = Math_fround(1.0);
  $10 = ((($5) + ($6<<4)|0) + 12|0);
  HEAPF32[$10>>2] = Math_fround(0.0);
  $11 = (($5) + ($i$05<<4)|0);
  $12 = (($i$05) + 1)|0;
  $13 = ($12|0)<(8);
  ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
  if ($13) {
   $i$05 = $12;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES8SetLightEiRK14GfxVertexLight($this,$light,$data) {
 $this = $this|0;
 $light = $light|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($data) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($this) + ($light<<2)|0) + 8004|0);
 HEAP32[$2>>2] = $1;
 __ZN9GfxDevice22SetupVertexLightParamsEiRK14GfxVertexLight($this,$light,$data);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES10SetAmbientERK10ColorRGBAf($this,$ambient) {
 $this = $this|0;
 $ambient = $ambient|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 516|0);
 ;HEAP32[$0+0>>2]=HEAP32[$ambient+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$ambient+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$ambient+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$ambient+12>>2]|0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES11EnableFFFogERK12GfxFogParams($this,$fog) {
 $this = $this|0;
 $fog = $fog|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5284|0);
 $1 = HEAP32[$fog>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = (($fog) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($fog) + 8|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($fog) + 12|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($fog) + 16|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($this) + 5288|0);
 HEAPF32[$10>>2] = $3;
 $11 = (($this) + 5292|0);
 HEAPF32[$11>>2] = $5;
 $12 = (($this) + 5296|0);
 HEAPF32[$12>>2] = $7;
 $13 = (($this) + 5300|0);
 HEAPF32[$13>>2] = $9;
 $14 = (($this) + 5304|0);
 $15 = (($fog) + 20|0);
 ;HEAP32[$14+0>>2]=HEAP32[$15+0>>2]|0;HEAP32[$14+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$14+8>>2]=HEAP32[$15+8>>2]|0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES12DisableFFFogEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 5284|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 0;
 $3 = (($this) + 5312|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES16CreateDynamicVBOEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(72)|0);
 __THREW__ = 0;
 invoke_viiiii(116,($0|0),($this|0),1,0,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZdlPv($0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN13GfxDeviceGLES24CreateRenderColorSurfaceE9TextureIDiiii16TextureDimension19RenderTextureFormatj($this,$tex,$w,$h,$samples,$depth,$dim,$format,$createFlags) {
 $this = $this|0;
 $tex = $tex|0;
 $w = $w|0;
 $h = $h|0;
 $samples = $samples|0;
 $depth = $depth|0;
 $dim = $dim|0;
 $format = $format|0;
 $createFlags = $createFlags|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $desc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $desc = sp;
 $0 = sp + 16|0;
 HEAP32[$desc>>2] = $w;
 $1 = (($desc) + 4|0);
 HEAP32[$1>>2] = $h;
 $2 = (($desc) + 8|0);
 HEAP32[$2>>2] = $samples;
 $3 = (($desc) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$tex>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__ZN4gles28CreateColorRenderSurfaceFullE19RenderTextureFormat9TextureIDj16TextureDimensionjRK17RenderSurfaceDesc($format,$$byval_copy,0,$dim,$createFlags,$desc)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN13GfxDeviceGLES24CreateRenderDepthSurfaceE9TextureIDiii16TextureDimension17DepthBufferFormatj($this,$tex,$w,$h,$samples,$dim,$format,$createFlags) {
 $this = $this|0;
 $tex = $tex|0;
 $w = $w|0;
 $h = $h|0;
 $samples = $samples|0;
 $dim = $dim|0;
 $format = $format|0;
 $createFlags = $createFlags|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $desc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $desc = sp;
 $0 = sp + 16|0;
 HEAP32[$desc>>2] = $w;
 $1 = (($desc) + 4|0);
 HEAP32[$1>>2] = $h;
 $2 = (($desc) + 8|0);
 HEAP32[$2>>2] = $samples;
 $3 = (($desc) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$tex>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (__ZN4gles28CreateDepthRenderSurfaceFullE17DepthBufferFormat9TextureIDj16TextureDimensionjRK17RenderSurfaceDesc($format,$$byval_copy,0,$dim,$createFlags,$desc)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN13GfxDeviceGLES20DestroyRenderSurfaceER12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseE($this,$rs) {
 $this = $this|0;
 $rs = $rs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$rs>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 23|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 __ZN4gles25HandleRenderSurfaceDeleteEP17RenderSurfaceBase($0);
 $5 = HEAP32[$rs>>2]|0;
 __ZN4gles20DestroyRenderSurfaceEP17RenderSurfaceGLES($5);
 HEAP32[$rs>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES16SetRenderTargetsERK20GfxRenderTargetSetup($this,$rt) {
 $this = $this|0;
 $rt = $rt|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$01$i$i$i = 0;
 while(1) {
  $2 = (($rt) + ($i$01$i$i$i<<2)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (1149744 + ($i$01$i$i$i<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)==($5|0);
  $1 = (($i$01$i$i$i) + 1)|0;
  if (!($6)) {
   break;
  }
  $0 = ($1|0)<(12);
  if ($0) {
   $i$01$i$i$i = $1;
  } else {
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return;
 }
 $7 = (__Z16GetRealGfxDevicev()|0);
 $8 = (($7) + 5544|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = (($7) + 5324|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$11>>2] = $13;
 }
 __ZN4gles12SetActiveFBOERK20GfxRenderTargetSetup($rt);
 $14 = HEAP8[((640792 + 252|0))>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  STACKTOP = sp;return;
 }
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES15DiscardContentsER12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseE($this,$rs) {
 $this = $this|0;
 $rs = $rs|0;
 var $$isCurrent$1$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $colorIndex$2 = 0, $i$0$colorIndex$0 = 0, $isCurrent$1$off0 = 0, $not$ = 0, $not$2 = 0, $not$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$rs>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 22|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $8 = HEAP32[((1149672 + 32|0))>>2]|0;
  $9 = ($0|0)==($8|0);
  $colorIndex$2 = -1;$isCurrent$1$off0 = $9;
 } else {
  $5 = HEAP32[((1149744 + 36|0))>>2]|0;
  $not$ = ($5|0)==(0);
  if ($not$) {
   $colorIndex$2 = -1;$isCurrent$1$off0 = 0;
  } else {
   $6 = HEAP32[1149672>>2]|0;
   $7 = ($0|0)==($6|0);
   $not$6 = $7 ^ 1;
   $i$0$colorIndex$0 = $not$6 << 31 >> 31;
   $colorIndex$2 = $i$0$colorIndex$0;$isCurrent$1$off0 = $7;
  }
 }
 $10 = HEAP8[((640792 + 251|0))>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = HEAP32[1152880>>2]|0;
 $13 = (($12) + 69|0);
 $14 = HEAP8[$13>>0]|0;
 $not$2 = ($14<<24>>24)!=(0);
 $$isCurrent$1$off0 = $isCurrent$1$off0 & $not$2;
 $15 = $11 ? 2 : 0;
 $16 = (($0) + 20|0);
 HEAP8[$16>>0] = $15;
 if (!($$isCurrent$1$off0)) {
  STACKTOP = sp;return;
 }
 $17 = ($colorIndex$2|0)>(-1);
 if ($17) {
  $18 = ((1149672 + ($colorIndex$2)|0) + 60|0);
  HEAP8[$18>>0] = 1;
  STACKTOP = sp;return;
 } else {
  HEAP8[((1149672 + 69|0))>>0] = 1;
  STACKTOP = sp;return;
 }
}
function __ZN13GfxDeviceGLES27GetActiveRenderColorSurfaceEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1149744 + ($index<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN13GfxDeviceGLES27GetActiveRenderDepthSurfaceEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((1149744 + 32|0))>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN13GfxDeviceGLES26GetActiveRenderTargetCountEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((1149744 + 36|0))>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN13GfxDeviceGLES19ResolveColorSurfaceE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_($this,$srcHandle,$dstHandle) {
 $this = $this|0;
 $srcHandle = $srcHandle|0;
 $dstHandle = $dstHandle|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$srcHandle>>2]|0;
 $2 = HEAP32[$dstHandle>>2]|0;
 $3 = (($1) + 22|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (($2) + 22|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   $9 = HEAP32[$2>>2]|0;
   HEAP32[$0>>2] = $9;
   $10 = HEAP32[((599640 + 36|0))>>2]|0;
   $11 = HEAP32[((599640 + 4|0))>>2]|0;
   $12 = ($10|0)==($11|0);
   do {
    if ($12) {
     $13 = HEAP32[((599640 + 28|0))>>2]|0;
     $14 = HEAP32[((599640 + 32|0))>>2]|0;
     $15 = (($13) + ($14<<3)|0);
     $23 = $13;$24 = $14;$26 = $15;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i,599640,$0);
     $16 = HEAP32[$pos$i$i$i>>2]|0;
     $17 = ($16|0)==(-1);
     $18 = HEAP32[((599640 + 28|0))>>2]|0;
     if ($17) {
      $19 = HEAP32[((599640 + 32|0))>>2]|0;
      $20 = (($18) + ($19<<3)|0);
      $23 = $18;$24 = $19;$26 = $20;
      break;
     } else {
      $21 = (($18) + ($16<<3)|0);
      $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
      $23 = $18;$24 = $$pre$i;$26 = $21;
      break;
     }
    }
   } while(0);
   $22 = (($23) + ($24<<3)|0);
   $25 = ($26|0)==($22|0);
   if (!($25)) {
    $27 = (($26) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($1) + 24|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==(0);
    $32 = ($28|0)==(0);
    $or$cond = $31 | $32;
    if (!($or$cond)) {
     __ZN4gles19ReadbackResolveMSAAEP17RenderSurfaceBaseS1_($2,$1);
     STACKTOP = sp;return;
    }
   }
   __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1149232,0,1149224,795,512,0,0,0);
   STACKTOP = sp;return;
  }
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1149176,0,1149224,787,512,0,0,0);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES23ResolveDepthIntoTextureE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_($this,$0,$depthHandle) {
 $this = $this|0;
 $0 = $0|0;
 $depthHandle = $depthHandle|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 $1 = HEAP32[$depthHandle>>2]|0;
 __ZN4gles30ReadbackDepthIntoRenderTextureEP17RenderSurfaceBase($1);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES17CaptureScreenshotEiiiiPh($this,$left,$bottom,$width,$height,$rgba32) {
 $this = $this|0;
 $left = $left|0;
 $bottom = $bottom|0;
 $width = $width|0;
 $height = $height|0;
 $rgba32 = $rgba32|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1147664 + 268|0);
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viiiiiii[$1 & 127]($left,$bottom,$width,$height,6408,5121,$rgba32);
 STACKTOP = sp;return 1;
}
function __ZN13GfxDeviceGLES13ReadbackImageER14ImageReferenceiiiiii($this,$image,$left,$bottom,$width,$height,$destX,$destY) {
 $this = $this|0;
 $image = $image|0;
 $left = $left|0;
 $bottom = $bottom|0;
 $width = $width|0;
 $height = $height|0;
 $destX = $destX|0;
 $destY = $destY|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 $0 = (__ZN4gles13ReadbackImageER14ImageReferenceiiiiii($image,$left,$bottom,$width,$height,$destX,$destY)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13GfxDeviceGLES21GrabIntoRenderTextureE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_iiii($this,$rs,$rd,$x,$y,$width,$height) {
 $this = $this|0;
 $rs = $rs|0;
 $rd = $rd|0;
 $x = $x|0;
 $y = $y|0;
 $width = $width|0;
 $height = $height|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$rs>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 23|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 $5 = HEAP32[1149744>>2]|0;
 __ZN4gles21GrabIntoRenderTextureEP17RenderSurfaceBaseS1_iiii($0,$5,$x,$y,$width,$height);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES12PresentFrameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1147664 + 64|0);
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viiii[$1 & 511](0,0,0,1);
 $2 = (1147664 + 52|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vffff[$3 & 7](Math_fround(0.0),Math_fround(0.0),Math_fround(0.0),Math_fround(1.0));
 $4 = (1147664 + 48|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095](16384);
 $6 = (1147664 + 64|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_viiii[$7 & 511](1,1,1,1);
 __ZN11ContextGLES7PresentEv();
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES22AcquireThreadOwnershipEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES22ReleaseThreadOwnershipEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES15UploadTexture2DE9TextureID16TextureDimensionPKhiii13TextureFormatij16TextureUsageMode17TextureColorSpace($this,$texture,$dimension,$srcData,$srcSize,$width,$height,$format,$mipCount,$uploadFlags,$usageMode,$colorSpace) {
 $this = $this|0;
 $texture = $texture|0;
 $dimension = $dimension|0;
 $srcData = $srcData|0;
 $srcSize = $srcSize|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $mipCount = $mipCount|0;
 $uploadFlags = $uploadFlags|0;
 $usageMode = $usageMode|0;
 $colorSpace = $colorSpace|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$texture>>2]|0;
 $3 = HEAP8[((640792 + 363|0))>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = HEAP8[1149416>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $or$cond$i = $4 & $6;
 if ($or$cond$i) {
  HEAP32[$0>>2] = $2;
  $7 = HEAP32[((599640 + 36|0))>>2]|0;
  $8 = HEAP32[((599640 + 4|0))>>2]|0;
  $9 = ($7|0)==($8|0);
  do {
   if ($9) {
    $10 = HEAP32[((599640 + 28|0))>>2]|0;
    $11 = HEAP32[((599640 + 32|0))>>2]|0;
    $12 = (($10) + ($11<<3)|0);
    $20 = $10;$21 = $11;$23 = $12;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($$byval_copy,599640,$0);
    $13 = HEAP32[$$byval_copy>>2]|0;
    $14 = ($13|0)==(-1);
    $15 = HEAP32[((599640 + 28|0))>>2]|0;
    if ($14) {
     $16 = HEAP32[((599640 + 32|0))>>2]|0;
     $17 = (($15) + ($16<<3)|0);
     $20 = $15;$21 = $16;$23 = $17;
     break;
    } else {
     $18 = (($15) + ($13<<3)|0);
     $$pre$i$i = HEAP32[((599640 + 32|0))>>2]|0;
     $20 = $15;$21 = $$pre$i$i;$23 = $18;
     break;
    }
   }
  } while(0);
  $19 = (($20) + ($21<<3)|0);
  $22 = ($23|0)==($19|0);
  if (!($22)) {
   $24 = (($23) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if (!($26)) {
    _glFinish();
    HEAP8[1149416>>0] = 1;
   }
  }
 }
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN4gles13UploadTextureE9TextureID16TextureDimension13TextureFormatPKviiiiij17TextureColorSpace($$byval_copy,2,$format,$srcData,0,$width,$height,1,$mipCount,$uploadFlags,$colorSpace);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES22UploadTextureSubData2DE9TextureIDPKhiiiiii13TextureFormat17TextureColorSpace($this,$texture,$srcData,$srcSize,$mipLevel,$x,$y,$width,$height,$format,$colorSpace) {
 $this = $this|0;
 $texture = $texture|0;
 $srcData = $srcData|0;
 $srcSize = $srcSize|0;
 $mipLevel = $mipLevel|0;
 $x = $x|0;
 $y = $y|0;
 $width = $width|0;
 $height = $height|0;
 $format = $format|0;
 $colorSpace = $colorSpace|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$texture>>2]|0;
 $3 = HEAP8[((640792 + 363|0))>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = HEAP8[1149416>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $or$cond$i = $4 & $6;
 if ($or$cond$i) {
  HEAP32[$0>>2] = $2;
  $7 = HEAP32[((599640 + 36|0))>>2]|0;
  $8 = HEAP32[((599640 + 4|0))>>2]|0;
  $9 = ($7|0)==($8|0);
  do {
   if ($9) {
    $10 = HEAP32[((599640 + 28|0))>>2]|0;
    $11 = HEAP32[((599640 + 32|0))>>2]|0;
    $12 = (($10) + ($11<<3)|0);
    $20 = $10;$21 = $11;$23 = $12;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($$byval_copy,599640,$0);
    $13 = HEAP32[$$byval_copy>>2]|0;
    $14 = ($13|0)==(-1);
    $15 = HEAP32[((599640 + 28|0))>>2]|0;
    if ($14) {
     $16 = HEAP32[((599640 + 32|0))>>2]|0;
     $17 = (($15) + ($16<<3)|0);
     $20 = $15;$21 = $16;$23 = $17;
     break;
    } else {
     $18 = (($15) + ($13<<3)|0);
     $$pre$i$i = HEAP32[((599640 + 32|0))>>2]|0;
     $20 = $15;$21 = $$pre$i$i;$23 = $18;
     break;
    }
   }
  } while(0);
  $19 = (($20) + ($21<<3)|0);
  $22 = ($23|0)==($19|0);
  if (!($22)) {
   $24 = (($23) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if (!($26)) {
    _glFinish();
    HEAP8[1149416>>0] = 1;
   }
  }
 }
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN4gles22UploadTexture2DSubDataE9TextureID13TextureFormatPKviiiii17TextureColorSpace($$byval_copy,$format,$srcData,$mipLevel,$x,$y,$width,$height,$colorSpace);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES17UploadTextureCubeE9TextureIDPKhiii13TextureFormatij17TextureColorSpace($this,$texture,$srcData,$srcSize,$faceDataSize,$size,$format,$mipCount,$uploadFlags,$colorSpace) {
 $this = $this|0;
 $texture = $texture|0;
 $srcData = $srcData|0;
 $srcSize = $srcSize|0;
 $faceDataSize = $faceDataSize|0;
 $size = $size|0;
 $format = $format|0;
 $mipCount = $mipCount|0;
 $uploadFlags = $uploadFlags|0;
 $colorSpace = $colorSpace|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$texture>>2]|0;
 $3 = HEAP8[((640792 + 363|0))>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = HEAP8[1149416>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $or$cond$i = $4 & $6;
 if ($or$cond$i) {
  HEAP32[$0>>2] = $2;
  $7 = HEAP32[((599640 + 36|0))>>2]|0;
  $8 = HEAP32[((599640 + 4|0))>>2]|0;
  $9 = ($7|0)==($8|0);
  do {
   if ($9) {
    $10 = HEAP32[((599640 + 28|0))>>2]|0;
    $11 = HEAP32[((599640 + 32|0))>>2]|0;
    $12 = (($10) + ($11<<3)|0);
    $20 = $10;$21 = $11;$23 = $12;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($$byval_copy,599640,$0);
    $13 = HEAP32[$$byval_copy>>2]|0;
    $14 = ($13|0)==(-1);
    $15 = HEAP32[((599640 + 28|0))>>2]|0;
    if ($14) {
     $16 = HEAP32[((599640 + 32|0))>>2]|0;
     $17 = (($15) + ($16<<3)|0);
     $20 = $15;$21 = $16;$23 = $17;
     break;
    } else {
     $18 = (($15) + ($13<<3)|0);
     $$pre$i$i = HEAP32[((599640 + 32|0))>>2]|0;
     $20 = $15;$21 = $$pre$i$i;$23 = $18;
     break;
    }
   }
  } while(0);
  $19 = (($20) + ($21<<3)|0);
  $22 = ($23|0)==($19|0);
  if (!($22)) {
   $24 = (($23) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if (!($26)) {
    _glFinish();
    HEAP8[1149416>>0] = 1;
   }
  }
 }
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN4gles13UploadTextureE9TextureID16TextureDimension13TextureFormatPKviiiiij17TextureColorSpace($$byval_copy,4,$format,$srcData,$faceDataSize,$size,$size,1,$mipCount,$uploadFlags,$colorSpace);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES15UploadTexture3DE9TextureIDPKhiiii13TextureFormatij($this,$texture,$srcData,$srcSize,$width,$height,$depth,$format,$mipCount,$uploadFlags) {
 $this = $this|0;
 $texture = $texture|0;
 $srcData = $srcData|0;
 $srcSize = $srcSize|0;
 $width = $width|0;
 $height = $height|0;
 $depth = $depth|0;
 $format = $format|0;
 $mipCount = $mipCount|0;
 $uploadFlags = $uploadFlags|0;
 var $$byval_copy = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$texture>>2]|0;
 $3 = HEAP8[((640792 + 363|0))>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = HEAP8[1149416>>0]|0;
 $6 = ($5<<24>>24)==(0);
 $or$cond$i = $4 & $6;
 if ($or$cond$i) {
  HEAP32[$0>>2] = $2;
  $7 = HEAP32[((599640 + 36|0))>>2]|0;
  $8 = HEAP32[((599640 + 4|0))>>2]|0;
  $9 = ($7|0)==($8|0);
  do {
   if ($9) {
    $10 = HEAP32[((599640 + 28|0))>>2]|0;
    $11 = HEAP32[((599640 + 32|0))>>2]|0;
    $12 = (($10) + ($11<<3)|0);
    $20 = $10;$21 = $11;$23 = $12;
   } else {
    __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($$byval_copy,599640,$0);
    $13 = HEAP32[$$byval_copy>>2]|0;
    $14 = ($13|0)==(-1);
    $15 = HEAP32[((599640 + 28|0))>>2]|0;
    if ($14) {
     $16 = HEAP32[((599640 + 32|0))>>2]|0;
     $17 = (($15) + ($16<<3)|0);
     $20 = $15;$21 = $16;$23 = $17;
     break;
    } else {
     $18 = (($15) + ($13<<3)|0);
     $$pre$i$i = HEAP32[((599640 + 32|0))>>2]|0;
     $20 = $15;$21 = $$pre$i$i;$23 = $18;
     break;
    }
   }
  } while(0);
  $19 = (($20) + ($21<<3)|0);
  $22 = ($23|0)==($19|0);
  if (!($22)) {
   $24 = (($23) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==(0);
   if (!($26)) {
    _glFinish();
    HEAP8[1149416>>0] = 1;
   }
  }
 }
 HEAP32[$1>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZN4gles13UploadTextureE9TextureID16TextureDimension13TextureFormatPKviiiiij17TextureColorSpace($$byval_copy,3,$format,$srcData,0,$width,$height,$depth,$mipCount,$uploadFlags,0);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES13DeleteTextureE9TextureID($this,$texture) {
 $this = $this|0;
 $texture = $texture|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $i$05 = 0, $pos$i$i$i$i = 0, $targetTex = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pos$i$i$i$i = sp + 24|0;
 $0 = sp;
 $1 = sp + 8|0;
 $targetTex = sp + 12|0;
 $temp = sp + 16|0;
 $2 = HEAP32[$texture>>2]|0;
 HEAP32[$1>>2] = $2;
 $3 = HEAP32[((599640 + 36|0))>>2]|0;
 $4 = HEAP32[((599640 + 4|0))>>2]|0;
 $5 = ($3|0)==($4|0);
 do {
  if ($5) {
   $6 = HEAP32[((599640 + 28|0))>>2]|0;
   $7 = HEAP32[((599640 + 32|0))>>2]|0;
   $8 = (($6) + ($7<<3)|0);
   $16 = $6;$17 = $7;$19 = $8;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i$i,599640,$1);
   $9 = HEAP32[$pos$i$i$i$i>>2]|0;
   $10 = ($9|0)==(-1);
   $11 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($10) {
    $12 = HEAP32[((599640 + 32|0))>>2]|0;
    $13 = (($11) + ($12<<3)|0);
    $16 = $11;$17 = $12;$19 = $13;
    break;
   } else {
    $14 = (($11) + ($9<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $16 = $11;$17 = $$pre$i;$19 = $14;
    break;
   }
  }
 } while(0);
 $15 = (($16) + ($17<<3)|0);
 $18 = ($19|0)==($15|0);
 if ($18) {
  HEAP32[$targetTex>>2] = 0;
  STACKTOP = sp;return;
 }
 $20 = (($19) + 4|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$targetTex>>2] = $21;
 $22 = ($21|0)==(0);
 if ($22) {
  STACKTOP = sp;return;
 }
 $23 = $2;
 __Z34register_external_gfx_deallocationPvPKci($23,1149224,894);
 $24 = (1147664 + 116|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095](1,$targetTex);
 $26 = HEAP8[((640792 + 371|0))>>0]|0;
 $27 = ($26<<24>>24)==(0);
 if (!($27)) {
  $28 = (1147664 + 188|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_vii[$29 & 4095](1,$temp);
 }
 $30 = HEAP32[((640792 + 104|0))>>2]|0;
 $31 = ($30|0)>(0);
 if ($31) {
  $70 = $30;$i$05 = 0;
  while(1) {
   $32 = ((($this) + (($i$05*52)|0)|0) + 6332|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP32[$targetTex>>2]|0;
   $35 = ($33|0)==($34|0);
   if ($35) {
    $36 = ((($this) + (($i$05*52)|0)|0) + 6296|0);
    __ZN4gles10InvalidateER20TextureUnitStateGLES($36);
    $$pre = HEAP32[((640792 + 104|0))>>2]|0;
    $39 = $$pre;
   } else {
    $39 = $70;
   }
   $37 = (($i$05) + 1)|0;
   $38 = ($37|0)<($39|0);
   if ($38) {
    $70 = $39;$i$05 = $37;
   } else {
    break;
   }
  }
 }
 HEAP32[$0>>2] = $2;
 $40 = HEAP32[((599640 + 36|0))>>2]|0;
 $41 = HEAP32[((599640 + 4|0))>>2]|0;
 $42 = ($40|0)==($41|0);
 do {
  if ($42) {
   $43 = HEAP32[((599640 + 28|0))>>2]|0;
   $44 = HEAP32[((599640 + 32|0))>>2]|0;
   $45 = (($43) + ($44<<3)|0);
   $53 = $43;$54 = $44;$56 = $45;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i$i,599640,$0);
   $46 = HEAP32[$pos$i$i$i$i>>2]|0;
   $47 = ($46|0)==(-1);
   $48 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($47) {
    $49 = HEAP32[((599640 + 32|0))>>2]|0;
    $50 = (($48) + ($49<<3)|0);
    $53 = $48;$54 = $49;$56 = $50;
    break;
   } else {
    $51 = (($48) + ($46<<3)|0);
    $$pre$i$i$i = HEAP32[((599640 + 32|0))>>2]|0;
    $53 = $48;$54 = $$pre$i$i$i;$56 = $51;
    break;
   }
  }
 } while(0);
 $52 = (($53) + ($54<<3)|0);
 $55 = ($56|0)==($52|0);
 if ($55) {
  STACKTOP = sp;return;
 }
 $57 = ($56|0)==(0|0);
 if (!($57)) {
  $58 = ((599640 + 12|0));
  $59 = $58;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($58) + 4)|0;
  $62 = $61;
  $63 = HEAP32[$62>>2]|0;
  $64 = $56;
  $65 = $64;
  HEAP32[$65>>2] = $60;
  $66 = (($64) + 4)|0;
  $67 = $66;
  HEAP32[$67>>2] = $63;
 }
 $68 = HEAP32[((599640 + 4|0))>>2]|0;
 $69 = (($68) + 1)|0;
 HEAP32[((599640 + 4|0))>>2] = $69;
 HEAP8[((599640 + 48|0))>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES21SetConstantBufferInfoEii($this,$id,$size) {
 $this = $this|0;
 $id = $id|0;
 $size = $size|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 6208|0);
 __ZN19ConstantBuffersGLES9SetCBInfoEii($0,$id,$size);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES23CreateGPUSkinPoseBufferEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP8[((640792 + 255|0))>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = 0;
  STACKTOP = sp;return ($7|0);
 }
 $3 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $4 = (__Znwj10MemLabelIdbiPKci(12,$$byval_copy,0,16,1149224,930)|0);
 $5 = (($4) + 4|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$4>>2] = ((1149392 + 8|0));
 $6 = (($4) + 8|0);
 HEAP32[$6>>2] = 0;
 $7 = $4;
 STACKTOP = sp;return ($7|0);
}
function __ZN13GfxDeviceGLES23DeleteGPUSkinPoseBufferEP17GPUSkinPoseBuffer($this,$poseBuffer) {
 $this = $this|0;
 $poseBuffer = $poseBuffer|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628280>>2]|0;
 $2 = ($poseBuffer|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$poseBuffer>>2]|0;
  $4 = (($3) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($poseBuffer);
 }
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($poseBuffer,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES20UpdateSkinPoseBufferEP17GPUSkinPoseBufferPK10Matrix4x4fi($this,$poseBuffer,$boneMatrices,$boneCount) {
 $this = $this|0;
 $poseBuffer = $poseBuffer|0;
 $boneMatrices = $boneMatrices|0;
 $boneCount = $boneCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN31TransformFeedbackSkinPoseBuffer6UpdateEPK10Matrix4x4fi($poseBuffer,$boneMatrices,$boneCount);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES9SkinOnGPUERK18VertexStreamSourceP12VertexBufferP17GPUSkinPoseBufferS4_iijb($this,$sourceMesh,$skinBuffer,$poseBuffer,$destBuffer,$vertexCount,$bonesPerVertex,$channelMask,$lastThisFrame) {
 $this = $this|0;
 $sourceMesh = $sourceMesh|0;
 $skinBuffer = $skinBuffer|0;
 $poseBuffer = $poseBuffer|0;
 $destBuffer = $destBuffer|0;
 $vertexCount = $vertexCount|0;
 $bonesPerVertex = $bonesPerVertex|0;
 $channelMask = $channelMask|0;
 $lastThisFrame = $lastThisFrame|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN25TransformFeedbackSkinning8SkinMeshERK18VertexStreamSourceP12VertexBufferP17GPUSkinPoseBufferS4_iijb($sourceMesh,$skinBuffer,$poseBuffer,$destBuffer,$vertexCount,$bonesPerVertex,$channelMask,$lastThisFrame);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES14GetPresentModeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN13GfxDeviceGLES12IsValidStateEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN11ContextGLES7IsValidEv()|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13GfxDeviceGLES18HandleInvalidStateEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $needReload = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $needReload = sp;
 $0 = (__ZN11ContextGLES18HandleInvalidStateEPb($needReload)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP8[$needReload>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = HEAP32[$this>>2]|0;
  $4 = (($3) + 812|0);
  $5 = HEAP32[$4>>2]|0;
  FUNCTION_TABLE_vi[$5 & 4095]($this);
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 4095]($this);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13GfxDeviceGLES15FinishRenderingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1147664 + 152|0);
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_v[$1 & 1023]();
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES15ActivateDisplayEj($this,$displayId) {
 $this = $this|0;
 $displayId = $displayId|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN11ContextGLES8ActivateEi($displayId)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN13GfxDeviceGLES16SetDisplayTargetEj($this,$displayId) {
 $this = $this|0;
 $displayId = $displayId|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN11ContextGLES7AcquireEi($displayId)|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13GfxDeviceGLES14SetTextureNameE9TextureIDPKc($this,$tex,$name) {
 $this = $this|0;
 $tex = $tex|0;
 $name = $name|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[1152880>>2]|0;
 $2 = (($1) + 67|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (1147616 + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$tex>>2]|0;
 HEAP32[$0>>2] = $7;
 $8 = HEAP32[((599640 + 36|0))>>2]|0;
 $9 = HEAP32[((599640 + 4|0))>>2]|0;
 $10 = ($8|0)==($9|0);
 do {
  if ($10) {
   $11 = HEAP32[((599640 + 28|0))>>2]|0;
   $12 = HEAP32[((599640 + 32|0))>>2]|0;
   $13 = (($11) + ($12<<3)|0);
   $21 = $11;$22 = $12;$24 = $13;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i,599640,$0);
   $14 = HEAP32[$pos$i$i$i>>2]|0;
   $15 = ($14|0)==(-1);
   $16 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($15) {
    $17 = HEAP32[((599640 + 32|0))>>2]|0;
    $18 = (($16) + ($17<<3)|0);
    $21 = $16;$22 = $17;$24 = $18;
    break;
   } else {
    $19 = (($16) + ($14<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $21 = $16;$22 = $$pre$i;$24 = $19;
    break;
   }
  }
 } while(0);
 $20 = (($21) + ($22<<3)|0);
 $23 = ($24|0)==($20|0);
 if ($23) {
  $27 = 0;
 } else {
  $25 = (($24) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26;
 }
 FUNCTION_TABLE_viiii[$6 & 511](5890,$27,0,$name);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES20SetRenderSurfaceNameEP17RenderSurfaceBasePKc($this,$rs_,$name) {
 $this = $this|0;
 $rs_ = $rs_|0;
 $name = $name|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[1152880>>2]|0;
 $2 = (($1) + 67|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($rs_) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 64;
 $8 = ($7|0)==(0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$rs_>>2]|0;
 $10 = ($9|0)==(0);
 $11 = (1147616 + 8|0);
 $12 = HEAP32[$11>>2]|0;
 if ($10) {
  $33 = (($rs_) + 24|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viiii[$12 & 511](36161,$34,0,$name);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = $9;
 $13 = HEAP32[((599640 + 36|0))>>2]|0;
 $14 = HEAP32[((599640 + 4|0))>>2]|0;
 $15 = ($13|0)==($14|0);
 do {
  if ($15) {
   $16 = HEAP32[((599640 + 28|0))>>2]|0;
   $17 = HEAP32[((599640 + 32|0))>>2]|0;
   $18 = (($16) + ($17<<3)|0);
   $26 = $16;$27 = $17;$29 = $18;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i,599640,$0);
   $19 = HEAP32[$pos$i$i$i>>2]|0;
   $20 = ($19|0)==(-1);
   $21 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($20) {
    $22 = HEAP32[((599640 + 32|0))>>2]|0;
    $23 = (($21) + ($22<<3)|0);
    $26 = $21;$27 = $22;$29 = $23;
    break;
   } else {
    $24 = (($21) + ($19<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $26 = $21;$27 = $$pre$i;$29 = $24;
    break;
   }
  }
 } while(0);
 $25 = (($26) + ($27<<3)|0);
 $28 = ($29|0)==($25|0);
 if ($28) {
  $32 = 0;
 } else {
  $30 = (($29) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $31;
 }
 FUNCTION_TABLE_viiii[$12 & 511](5890,$32,0,$name);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES19SetVertexBufferNameEP12VertexBufferPKc($this,$vb_,$name) {
 $this = $this|0;
 $vb_ = $vb_|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 67|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (1147616 + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($vb_) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511](37201,$9,0,$name);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES18SetIndexBufferNameEP11IndexBufferPKc($this,$ib_,$name) {
 $this = $this|0;
 $ib_ = $ib_|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 67|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (1147616 + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($ib_) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 511](37201,$9,0,$name);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES17SetGpuProgramNameEP10GpuProgramPKc($this,$prog_,$name) {
 $this = $this|0;
 $prog_ = $prog_|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($prog_) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[1152880>>2]|0;
 $3 = (($2) + 67|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = ($1|0)==(0);
 $or$cond = $5 | $6;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $7 = (1147616 + 8|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$8 & 511](35648,$1,0,$name);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES23GetNativeTexturePointerE9TextureID($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$id>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[((599640 + 36|0))>>2]|0;
 $3 = HEAP32[((599640 + 4|0))>>2]|0;
 $4 = ($2|0)==($3|0);
 do {
  if ($4) {
   $5 = HEAP32[((599640 + 28|0))>>2]|0;
   $6 = HEAP32[((599640 + 32|0))>>2]|0;
   $7 = (($5) + ($6<<3)|0);
   $15 = $5;$16 = $6;$18 = $7;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i,599640,$0);
   $8 = HEAP32[$pos$i$i$i>>2]|0;
   $9 = ($8|0)==(-1);
   $10 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($9) {
    $11 = HEAP32[((599640 + 32|0))>>2]|0;
    $12 = (($10) + ($11<<3)|0);
    $15 = $10;$16 = $11;$18 = $12;
    break;
   } else {
    $13 = (($10) + ($8<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $15 = $10;$16 = $$pre$i;$18 = $13;
    break;
   }
  }
 } while(0);
 $14 = (($15) + ($16<<3)|0);
 $17 = ($18|0)==($14|0);
 if ($17) {
  $21 = 0;
  STACKTOP = sp;return ($21|0);
 }
 $19 = (($18) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $phitmp = $20;
 $21 = $phitmp;
 STACKTOP = sp;return ($21|0);
}
function __ZN13GfxDeviceGLES17CreateIndexBufferEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(56,$$byval_copy,0,16,1149224,1113)|0);
 $3 = (($2) + 4|0);
 $4 = (($2) + 20|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 HEAP32[$2>>2] = ((1149368 + 8|0));
 $5 = (($2) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($2) + 32|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = (($2) + 44|0);
 HEAP32[$8>>2] = 0;
 $9 = (($2) + 36|0);
 HEAP32[$9>>2] = 61;
 $10 = (($2) + 48|0);
 HEAP8[$10>>0] = 0;
 HEAP32[$4>>2] = 0;
 $11 = (($2) + 28|0);
 HEAP32[$11>>2] = 3;
 __ZN9GfxDevice19OnCreateIndexBufferEP11IndexBuffer($this,$2);
 STACKTOP = sp;return ($2|0);
}
function __ZN13GfxDeviceGLES17UpdateIndexBufferEP11IndexBuffer13GfxBufferMode14GfxBufferLabeljPKvj($this,$indexBuf,$mode,$label,$size,$indices,$flags) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 $mode = $mode|0;
 $label = $label|0;
 $size = $size|0;
 $indices = $indices|0;
 $flags = $flags|0;
 var $$0$i$i = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($indexBuf) + 16|0);
 HEAP32[$0>>2] = $label;
 $1 = (($indexBuf) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($mode|0);
 if ($3) {
  $$pre$i = (($indexBuf) + 24|0);
  $$pre$phi$iZ2D = $$pre$i;
 } else {
  HEAP32[$1>>2] = $mode;
  if ((($mode|0) == 1)) {
   $$0$i$i = (4);
  } else if ((($mode|0) == 2)) {
   $$0$i$i = (4);
  } else if ((($mode|0) == 0)) {
   $$0$i$i = (3);
  } else {
   $$0$i$i = (4);
  }
  $4 = (($indexBuf) + 28|0);
  HEAP32[$4>>2] = $$0$i$i;
  $5 = (($indexBuf) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   __ZN14DataBufferGLES7ReleaseEv($6);
  }
  HEAP32[$5>>2] = 0;
  $$pre$phi$iZ2D = $5;
 }
 $8 = (($indexBuf) + 20|0);
 HEAP32[$8>>2] = $size;
 __ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESE12EnsureBufferEj($indexBuf,$size);
 $9 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 __ZN14DataBufferGLES6UploadEiiPKv($9,0,$size,$indices);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES17BeginWriteIndicesEP11IndexBufferjj($this,$indexBuf,$offset,$size) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 $offset = $offset|0;
 $size = $size|0;
 var $$0$i = 0, $$byval_copy1 = 0, $$c = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset$c = 0, $res$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = ($size|0)==(0);
 if ($1) {
  $2 = (($indexBuf) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  $$0$i = $3;
 } else {
  $$0$i = $size;
 }
 $4 = HEAP8[((640792 + 358|0))>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = (($indexBuf) + 48|0);
 HEAP8[$6>>0] = $4;
 if (!($5)) {
  __ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESE12EnsureBufferEj($indexBuf,$$0$i);
  $7 = (($indexBuf) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__ZN14DataBufferGLES3MapEiij($8,$offset,$$0$i,26)|0);
  $res$0$i = $9;
  STACKTOP = sp;return ($res$0$i|0);
 }
 $10 = (($indexBuf) + 32|0);
 $11 = (($indexBuf) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 8|0);
 $$c = $12;
 HEAP32[$13>>2] = $$c;
 $14 = (($10) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($12>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $$c;
    $19 = HEAP32[$10>>2]|0;
    $20 = (($10) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($19,$12,4,$$byval_copy1,0,1149224,370)|0);
    HEAP32[$10>>2] = $22;
    $29 = $22;
    break;
   } else {
    $23 = (($10) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = $24;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($12,4,$$byval_copy1,0,1149224,352)|0);
    $26 = HEAP32[$10>>2]|0;
    $27 = HEAP32[$13>>2]|0;
    _memcpy(($25|0),($26|0),($27|0))|0;
    HEAP32[$14>>2] = $$c;
    HEAP32[$10>>2] = $25;
    $29 = $25;
    break;
   }
  } else {
   $$pre = HEAP32[$10>>2]|0;
   $29 = $$pre;
  }
 } while(0);
 $28 = (($29) + ($offset)|0);
 $30 = (($indexBuf) + 52|0);
 $offset$c = $offset;
 HEAP32[$30>>2] = $offset$c;
 $res$0$i = $28;
 STACKTOP = sp;return ($res$0$i|0);
}
function __ZN13GfxDeviceGLES15EndWriteIndicesEP11IndexBufferj($this,$indexBuf,$bytesWritten) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 $bytesWritten = $bytesWritten|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESE8EndWriteEj($indexBuf,$bytesWritten);
 STACKTOP = sp;return;
}
function __ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESE8EndWriteEj($this,$bytesWritten) {
 $this = $this|0;
 $bytesWritten = $bytesWritten|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 48|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN14DataBufferGLES16FlushMappedRangeEii($5,0,$bytesWritten);
  $6 = HEAP32[$4>>2]|0;
  __ZN14DataBufferGLES5UnmapEv($6);
  HEAP8[$1>>0] = 0;
  STACKTOP = sp;return;
 }
 $7 = (($this) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($bytesWritten))|0;
 __ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESE12EnsureBufferEj($this,$9);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$7>>2]|0;
 $13 = (($this) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN14DataBufferGLES6UploadEiiPKv($11,$12,$bytesWritten,$14);
 $15 = (($this) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($this) + 44|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(-1);
 if ($20) {
  $21 = HEAP32[$13>>2]|0;
  $22 = (($this) + 36|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$0>>2] = $23;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($21,$$byval_copy);
  HEAP32[$13>>2] = 0;
 }
 $24 = (($this) + 40|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$18>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES17DeleteIndexBufferEP11IndexBuffer($this,$indexBuf) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 __ZN9GfxDevice19OnDeleteIndexBufferEP11IndexBuffer($this,$indexBuf);
 $1 = HEAP32[628280>>2]|0;
 $2 = ($indexBuf|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$indexBuf>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095]($indexBuf);
 }
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($indexBuf,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES18CreateVertexBufferEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(56,$$byval_copy,0,16,1149224,1144)|0);
 $3 = (($2) + 4|0);
 $4 = (($2) + 20|0);
 ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 HEAP32[$2>>2] = ((1149344 + 8|0));
 $5 = (($2) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($2) + 32|0);
 HEAP32[$6>>2] = 0;
 $7 = (($2) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = (($2) + 44|0);
 HEAP32[$8>>2] = 0;
 $9 = (($2) + 36|0);
 HEAP32[$9>>2] = 61;
 $10 = (($2) + 48|0);
 HEAP8[$10>>0] = 0;
 HEAP32[$4>>2] = 0;
 $11 = (($2) + 28|0);
 HEAP32[$11>>2] = 0;
 __ZN9GfxDevice20OnCreateVertexBufferEP12VertexBuffer($this,$2);
 STACKTOP = sp;return ($2|0);
}
function __ZN13GfxDeviceGLES18UpdateVertexBufferEP12VertexBuffer13GfxBufferMode14GfxBufferLabeljPKvj($this,$vertexBuf,$mode,$label,$size,$vertices,$flags) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 $mode = $mode|0;
 $label = $label|0;
 $size = $size|0;
 $vertices = $vertices|0;
 $flags = $flags|0;
 var $$0$i$i = 0, $$0$i$i$c = 0, $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($vertexBuf) + 16|0);
 HEAP32[$0>>2] = $label;
 $1 = (($vertexBuf) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($mode|0);
 if ($3) {
  $$pre$i = (($vertexBuf) + 24|0);
  $$pre$phi$iZ2D = $$pre$i;
 } else {
  HEAP32[$1>>2] = $mode;
  if ((($mode|0) == 2)) {
   $$0$i$i = 1;
  } else if ((($mode|0) == 3)) {
   $$0$i$i = 2;
  } else if ((($mode|0) == 1) | (($mode|0) == 0)) {
   $$0$i$i = $mode;
  } else {
   $$0$i$i = 1;
  }
  $4 = (($vertexBuf) + 28|0);
  $$0$i$i$c = $$0$i$i;
  HEAP32[$4>>2] = $$0$i$i$c;
  $5 = (($vertexBuf) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   __ZN14DataBufferGLES7ReleaseEv($6);
  }
  HEAP32[$5>>2] = 0;
  $$pre$phi$iZ2D = $5;
 }
 $8 = (($vertexBuf) + 20|0);
 HEAP32[$8>>2] = $size;
 __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESE12EnsureBufferEj($vertexBuf,$size);
 $9 = HEAP32[$$pre$phi$iZ2D>>2]|0;
 __ZN14DataBufferGLES6UploadEiiPKv($9,0,$size,$vertices);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES18BeginWriteVerticesEP12VertexBufferjj($this,$vertexBuf,$offset,$size) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 $offset = $offset|0;
 $size = $size|0;
 var $$0$i = 0, $$byval_copy1 = 0, $$c = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset$c = 0, $res$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = ($size|0)==(0);
 if ($1) {
  $2 = (($vertexBuf) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  $$0$i = $3;
 } else {
  $$0$i = $size;
 }
 $4 = HEAP8[((640792 + 358|0))>>0]|0;
 $5 = ($4<<24>>24)==(0);
 $6 = (($vertexBuf) + 48|0);
 HEAP8[$6>>0] = $4;
 if (!($5)) {
  __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESE12EnsureBufferEj($vertexBuf,$$0$i);
  $7 = (($vertexBuf) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (__ZN14DataBufferGLES3MapEiij($8,$offset,$$0$i,26)|0);
  $res$0$i = $9;
  STACKTOP = sp;return ($res$0$i|0);
 }
 $10 = (($vertexBuf) + 32|0);
 $11 = (($vertexBuf) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 8|0);
 $$c = $12;
 HEAP32[$13>>2] = $$c;
 $14 = (($10) + 12|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & 2147483647;
 $17 = ($16>>>0)<($12>>>0);
 do {
  if ($17) {
   $18 = ($15|0)>(-1);
   if ($18) {
    HEAP32[$14>>2] = $$c;
    $19 = HEAP32[$10>>2]|0;
    $20 = (($10) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    HEAP32[$0>>2] = $21;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $22 = (__Z16realloc_internalPvji10MemLabelIdiPKci($19,$12,4,$$byval_copy1,0,1149224,370)|0);
    HEAP32[$10>>2] = $22;
    $29 = $22;
    break;
   } else {
    $23 = (($10) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    HEAP32[$0>>2] = $24;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    $25 = (__Z15malloc_internaljj10MemLabelIdiPKci($12,4,$$byval_copy1,0,1149224,352)|0);
    $26 = HEAP32[$10>>2]|0;
    $27 = HEAP32[$13>>2]|0;
    _memcpy(($25|0),($26|0),($27|0))|0;
    HEAP32[$14>>2] = $$c;
    HEAP32[$10>>2] = $25;
    $29 = $25;
    break;
   }
  } else {
   $$pre = HEAP32[$10>>2]|0;
   $29 = $$pre;
  }
 } while(0);
 $28 = (($29) + ($offset)|0);
 $30 = (($vertexBuf) + 52|0);
 $offset$c = $offset;
 HEAP32[$30>>2] = $offset$c;
 $res$0$i = $28;
 STACKTOP = sp;return ($res$0$i|0);
}
function __ZN13GfxDeviceGLES16EndWriteVerticesEP12VertexBufferj($this,$vertexBuf,$bytesWritten) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 $bytesWritten = $bytesWritten|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESE8EndWriteEj($vertexBuf,$bytesWritten);
 STACKTOP = sp;return;
}
function __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESE8EndWriteEj($this,$bytesWritten) {
 $this = $this|0;
 $bytesWritten = $bytesWritten|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 48|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (($this) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN14DataBufferGLES16FlushMappedRangeEii($5,0,$bytesWritten);
  $6 = HEAP32[$4>>2]|0;
  __ZN14DataBufferGLES5UnmapEv($6);
  HEAP8[$1>>0] = 0;
  STACKTOP = sp;return;
 }
 $7 = (($this) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($bytesWritten))|0;
 __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESE12EnsureBufferEj($this,$9);
 $10 = (($this) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$7>>2]|0;
 $13 = (($this) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN14DataBufferGLES6UploadEiiPKv($11,$12,$bytesWritten,$14);
 $15 = (($this) + 12|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($this) + 44|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(-1);
 if ($20) {
  $21 = HEAP32[$13>>2]|0;
  $22 = (($this) + 36|0);
  $23 = HEAP32[$22>>2]|0;
  HEAP32[$0>>2] = $23;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($21,$$byval_copy);
  HEAP32[$13>>2] = 0;
 }
 $24 = (($this) + 40|0);
 HEAP32[$24>>2] = 0;
 HEAP32[$18>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES18DeleteVertexBufferEP12VertexBuffer($this,$vertexBuf) {
 $this = $this|0;
 $vertexBuf = $vertexBuf|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 __ZN9GfxDevice20OnDeleteVertexBufferEP12VertexBuffer($this,$vertexBuf);
 $1 = HEAP32[628280>>2]|0;
 $2 = ($vertexBuf|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$vertexBuf>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095]($vertexBuf);
 }
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($vertexBuf,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES20GetVertexDeclarationERK18VertexChannelsInfo($this,$declKey) {
 $this = $this|0;
 $declKey = $declKey|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8240|0);
 $1 = (__ZN22VertexDeclarationCache13GetVertexDeclERK18VertexChannelsInfo($0,$declKey)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN13GfxDeviceGLES21SetMaterialPropertiesERK21MaterialPropertyBlock($this,$block) {
 $this = $this|0;
 $block = $block|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $setValuesFunc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $setValuesFunc = sp;
 $0 = (($this) + 7996|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$setValuesFunc>>2] = $this;
 $2 = (($setValuesFunc) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 7968|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 7972|0);
 $6 = HEAP32[$5>>2]|0;
 __Z34ApplyMaterialPropertyBlockValuesESI20SetValuesFunctorGLESEvRK21MaterialPropertyBlockPK10GpuProgramPK20GpuProgramParametersRT_($block,$4,$6,$setValuesFunc);
 STACKTOP = sp;return;
}
function __Z34ApplyMaterialPropertyBlockValuesESI20SetValuesFunctorGLESEvRK21MaterialPropertyBlockPK10GpuProgramPK20GpuProgramParametersRT_($propblock,$activeProgram,$activeProgramParams,$functor) {
 $propblock = $propblock|0;
 $activeProgram = $activeProgram|0;
 $activeProgramParams = $activeProgramParams|0;
 $functor = $functor|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curProp$01 = 0, $name = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $name = sp;
 $0 = sp + 4|0;
 $1 = ($activeProgram|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[$propblock>>2]|0;
 $3 = (($propblock) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + ($4<<4)|0);
 $6 = (($propblock) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($4|0)==(0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $curProp$01 = $2;
 while(1) {
  HEAP32[$name>>2] = -1;
  $9 = HEAP32[$curProp$01>>2]|0;
  HEAP32[$name>>2] = $9;
  $10 = (($curProp$01) + 6|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  do {
   if ($12) {
    $26 = (__ZNK20GpuProgramParameters9FindParamERKN9ShaderLab16FastPropertyNameEPi($activeProgramParams,$name,0)|0);
    $27 = ($26|0)==(0|0);
    if (!($27)) {
     $28 = (($curProp$01) + 4|0);
     $29 = HEAP8[$28>>0]|0;
     $30 = (($26) + 16|0);
     $31 = HEAP8[$30>>0]|0;
     $32 = $31&255;
     $33 = ($29<<24>>24)==($31<<24>>24);
     if ($33) {
      if ((($29<<24>>24) == 4)) {
       $44 = (($curProp$01) + 12|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = (($7) + ($45<<2)|0);
       $47 = (($26) + 4|0);
       $48 = HEAP32[$47>>2]|0;
       __ZN20SetValuesFunctorGLES12SetMatrixValEiPK10Matrix4x4fi($functor,$48,$46,$32);
       break;
      } else if ((($29<<24>>24) == 1)) {
       $34 = (($curProp$01) + 12|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = (($7) + ($35<<2)|0);
       $37 = (($26) + 12|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = (($26) + 4|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = (($26) + 17|0);
       $42 = HEAP8[$41>>0]|0;
       $43 = $42&255;
       __ZN20SetValuesFunctorGLES12SetVectorValE15ShaderParamTypeiPKfi($functor,$38,$40,$36,$43);
       break;
      } else {
       break;
      }
     }
    }
   } else {
    $13 = $11&255;
    $14 = (__ZNK20GpuProgramParameters16FindTextureParamERKN9ShaderLab16FastPropertyNameE16TextureDimension($activeProgramParams,$name,$13)|0);
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     $16 = (($curProp$01) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($7) + ($17<<2)|0);
     $19 = (($14) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($14) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($14) + 12|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$18>>2]|0;
     HEAP32[$0>>2] = $25;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     __ZN20SetValuesFunctorGLES13SetTextureValE10ShaderTypeii16TextureDimension9TextureID($functor,2,$20,$22,$24,$$byval_copy);
    }
   }
  } while(0);
  $49 = (($curProp$01) + 16|0);
  $50 = ($49|0)==($5|0);
  if ($50) {
   break;
  } else {
   $curProp$01 = $49;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES14BeforeDrawCallEv($this) {
 $this = $this|0;
 var $$0$i = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$02$i = 0, $$byval_copy1 = 0, $$pre$i$i$i = 0, $$pre$i$i20$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = Math_fround(0), $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = Math_fround(0), $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = Math_fround(0), $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = Math_fround(0), $320 = 0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = Math_fround(0), $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = Math_fround(0), $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = Math_fround(0), $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = Math_fround(0), $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = Math_fround(0), $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0);
 var $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = Math_fround(0), $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = Math_fround(0), $84 = Math_fround(0), $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0);
 var $91 = Math_fround(0), $92 = Math_fround(0), $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $__parent$i$i = 0, $__r$0$i$i = 0, $__r$0$i22$i = 0, $brmerge$demorgan$i = 0, $ffstate = 0, $fshader$0$i = 0, $fshaderOK$0$in$i = 0, $i$04$i = 0, $i$04$i13 = 0, $i$04$i17 = 0, $i$04$i2 = 0;
 var $i$04$i21 = 0, $i$04$i5 = 0, $i$04$i9 = 0, $i$091 = 0, $src$i = 0, $src1$i = 0, $vprog$0$i = 0, $vprogOK$0$in$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $$byval_copy1 = sp + 344|0;
 $__parent$i$i = sp;
 $0 = sp + 64|0;
 $1 = sp + 128|0;
 $src$i = sp + 192|0;
 $src1$i = sp + 256|0;
 $2 = sp + 292|0;
 $ffstate = sp + 296|0;
 $3 = (($this) + 6012|0);
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 $4 = (($this) + 6204|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$4>>2]|0;
 $8 = $7 & 3;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (($this) + 2724|0);
  $11 = (($this) + 6140|0);
  __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($10,$3,$11);
  $12 = HEAP32[$4>>2]|0;
  $13 = $12 & -4;
  HEAP32[$4>>2] = $13;
 }
 $14 = (($this) + 8233|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if (!($16)) {
  $17 = (($this) + 8088|0);
  $18 = Math_fround(HEAPF32[$17>>2]);
  $19 = (($17) + 4|0);
  $20 = Math_fround(HEAPF32[$19>>2]);
  $21 = (($17) + 8|0);
  $22 = Math_fround(HEAPF32[$21>>2]);
  $23 = (($17) + 12|0);
  $24 = Math_fround(HEAPF32[$23>>2]);
  $25 = (($this) + 2596|0);
  HEAPF32[$25>>2] = $18;
  $26 = (($this) + 2600|0);
  HEAPF32[$26>>2] = $20;
  $27 = (($this) + 2604|0);
  HEAPF32[$27>>2] = $22;
  $28 = (($this) + 2608|0);
  HEAPF32[$28>>2] = $24;
  $29 = (($this) + 8040|0);
  $30 = Math_fround(HEAPF32[$29>>2]);
  $31 = (($29) + 4|0);
  $32 = Math_fround(HEAPF32[$31>>2]);
  $33 = (($29) + 8|0);
  $34 = Math_fround(HEAPF32[$33>>2]);
  $35 = (($29) + 12|0);
  $36 = Math_fround(HEAPF32[$35>>2]);
  $37 = (($this) + 2612|0);
  HEAPF32[$37>>2] = $30;
  $38 = (($this) + 2616|0);
  HEAPF32[$38>>2] = $32;
  $39 = (($this) + 2620|0);
  HEAPF32[$39>>2] = $34;
  $40 = (($this) + 2624|0);
  HEAPF32[$40>>2] = $36;
  $41 = (($this) + 8056|0);
  $42 = Math_fround(HEAPF32[$41>>2]);
  $43 = (($41) + 4|0);
  $44 = Math_fround(HEAPF32[$43>>2]);
  $45 = (($41) + 8|0);
  $46 = Math_fround(HEAPF32[$45>>2]);
  $47 = (($41) + 12|0);
  $48 = Math_fround(HEAPF32[$47>>2]);
  $49 = (($this) + 2628|0);
  HEAPF32[$49>>2] = $42;
  $50 = (($this) + 2632|0);
  HEAPF32[$50>>2] = $44;
  $51 = (($this) + 2636|0);
  HEAPF32[$51>>2] = $46;
  $52 = (($this) + 2640|0);
  HEAPF32[$52>>2] = $48;
  $53 = (($this) + 8072|0);
  $54 = Math_fround(HEAPF32[$53>>2]);
  $55 = (($53) + 4|0);
  $56 = Math_fround(HEAPF32[$55>>2]);
  $57 = (($53) + 8|0);
  $58 = Math_fround(HEAPF32[$57>>2]);
  $59 = (($53) + 12|0);
  $60 = Math_fround(HEAPF32[$59>>2]);
  $61 = (($this) + 2644|0);
  HEAPF32[$61>>2] = $54;
  $62 = (($this) + 2648|0);
  HEAPF32[$62>>2] = $56;
  $63 = (($this) + 2652|0);
  HEAPF32[$63>>2] = $58;
  $64 = (($this) + 2656|0);
  HEAPF32[$64>>2] = $60;
  $65 = (($this) + 8104|0);
  $66 = Math_fround(HEAPF32[$65>>2]);
  $67 = (($this) + 2660|0);
  HEAPF32[$67>>2] = $66;
  $68 = (($this) + 2664|0);
  HEAPF32[$68>>2] = $66;
  $69 = (($this) + 2668|0);
  HEAPF32[$69>>2] = $66;
  $70 = (($this) + 2672|0);
  HEAPF32[$70>>2] = $66;
 }
 $71 = (($this) + 5284|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ($72|0)>(0);
 if ($73) {
  $74 = ($72|0)==(1);
  if ($74) {
   $75 = (($this) + 5308|0);
   $76 = Math_fround(HEAPF32[$75>>2]);
   $77 = (($this) + 5304|0);
   $78 = Math_fround(HEAPF32[$77>>2]);
   $79 = Math_fround($76 - $78);
   $80 = $79 < Math_fround(0.0);
   if ($80) {
    $81 = Math_fround(-$79);
    $83 = $81;
   } else {
    $83 = $79;
   }
   $82 = $83 > Math_fround(9.99999974737875163555E-5);
   if ($82) {
    $84 = Math_fround(Math_fround(1.0) / $79);
    $92 = $84;
   } else {
    $92 = Math_fround(0.0);
   }
  } else {
   $92 = Math_fround(0.0);
  }
  $85 = (($this) + 5288|0);
  $86 = (($this) + 2692|0);
  ;HEAP32[$86+0>>2]=HEAP32[$85+0>>2]|0;HEAP32[$86+4>>2]=HEAP32[$85+4>>2]|0;HEAP32[$86+8>>2]=HEAP32[$85+8>>2]|0;HEAP32[$86+12>>2]=HEAP32[$85+12>>2]|0;
  $87 = (($this) + 5312|0);
  $88 = Math_fround(HEAPF32[$87>>2]);
  $89 = Math_fround($88 * Math_fround(1.20112240314483642578));
  $90 = Math_fround($88 * Math_fround(1.44269502162933349609));
  if ($74) {
   $91 = Math_fround(-$92);
   $93 = (($this) + 5308|0);
   $94 = Math_fround(HEAPF32[$93>>2]);
   $95 = Math_fround($92 * $94);
   $101 = $95;$99 = $91;
  } else {
   $101 = Math_fround(0.0);$99 = Math_fround(0.0);
  }
  $96 = (($this) + 2708|0);
  HEAPF32[$96>>2] = $89;
  $97 = (($this) + 2712|0);
  HEAPF32[$97>>2] = $90;
  $98 = (($this) + 2716|0);
  HEAPF32[$98>>2] = $99;
  $100 = (($this) + 2720|0);
  HEAPF32[$100>>2] = $101;
 }
 $102 = (($this) + 8224|0);
 $103 = Math_fround(HEAPF32[$102>>2]);
 $104 = (($this) + 2676|0);
 HEAPF32[$104>>2] = $103;
 $105 = (($this) + 2680|0);
 HEAPF32[$105>>2] = $103;
 $106 = (($this) + 2684|0);
 HEAPF32[$106>>2] = $103;
 $107 = (($this) + 2688|0);
 HEAPF32[$107>>2] = $103;
 $108 = (($this) + 7968|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = ($109|0)==(0|0);
 if ($110) {
  $111 = (($this) + 8108|0);
  $112 = Math_fround(HEAPF32[$111>>2]);
  $113 = (($111) + 4|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = (($111) + 8|0);
  $116 = Math_fround(HEAPF32[$115>>2]);
  $117 = (($111) + 12|0);
  $118 = Math_fround(HEAPF32[$117>>2]);
  $119 = (($this) + 2452|0);
  HEAPF32[$119>>2] = $112;
  $120 = (($this) + 2456|0);
  HEAPF32[$120>>2] = $114;
  $121 = (($this) + 2460|0);
  HEAPF32[$121>>2] = $116;
  $122 = (($this) + 2464|0);
  HEAPF32[$122>>2] = $118;
  $123 = (($this) + 7960|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ($124|0)==(0);
  if (!($125)) {
   $i$091 = 0;
   while(1) {
    $126 = (($i$091) + 154)|0;
    $127 = ((($this) + (($i$091*52)|0)|0) + 6296|0);
    $128 = (($6) + ($126<<4)|0);
    ;HEAP32[$128+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$128+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$128+8>>2]=HEAP32[$127+8>>2]|0;HEAP32[$128+12>>2]=HEAP32[$127+12>>2]|0;
    $129 = (($i$091) + 158)|0;
    $130 = ((($this) + (($i$091*52)|0)|0) + 6312|0);
    $131 = (($6) + ($129<<4)|0);
    ;HEAP32[$131+0>>2]=HEAP32[$130+0>>2]|0;HEAP32[$131+4>>2]=HEAP32[$130+4>>2]|0;HEAP32[$131+8>>2]=HEAP32[$130+8>>2]|0;HEAP32[$131+12>>2]=HEAP32[$130+12>>2]|0;
    $132 = (($i$091) + 1)|0;
    $133 = HEAP32[$123>>2]|0;
    $134 = ($132>>>0)<($133>>>0);
    if ($134) {
     $i$091 = $132;
    } else {
     break;
    }
   }
  }
  __ZN4gles15ComputeFFPStateERK15DeviceStateGLESRK12GfxFogParamsPN3ffp5StateE($3,$71,$ffstate);
  $135 = HEAP32[((1149272 + 4|0))>>2]|0;
  $136 = ($135|0)==(0|0);
  if ($136) {
   label = 25;
  } else {
   $$0$ph7$i$i$i$i = ((1149272 + 4|0));$$01$ph6$i$in$i$i$i = $135;
   L27: while(1) {
    $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
    while(1) {
     $137 = (($$013$i$in$i$i$i) + 16|0);
     $138 = (__ZNK3ffp16FullStateCompareclERKNS_5StateES3_(0,$137,$ffstate)|0);
     if (!($138)) {
      break;
     }
     $141 = (($$013$i$in$i$i$i) + 4|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ($142|0)==(0|0);
     if ($143) {
      $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
      break L27;
     } else {
      $$013$i$in$i$i$i = $142;
     }
    }
    $139 = HEAP32[$$013$i$in$i$i$i>>2]|0;
    $140 = ($139|0)==(0|0);
    if ($140) {
     $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
     break;
    } else {
     $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $139;
    }
   }
   $144 = ($$0$ph5$i$i$i$i|0)==(((1149272 + 4|0))|0);
   if ($144) {
    label = 25;
   } else {
    $145 = (($$0$ph5$i$i$i$i) + 16|0);
    $146 = (__ZNK3ffp16FullStateCompareclERKNS_5StateES3_(0,$ffstate,$145)|0);
    if ($146) {
     label = 25;
    } else {
     $147 = (($$0$ph5$i$i$i$i) + 60|0);
     $148 = HEAP32[$147>>2]|0;
     $$0$i = $148;
    }
   }
  }
  if ((label|0) == 25) {
   __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_18VertexStateCompareELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_($0,1149288,$ffstate);
   $149 = HEAP32[$0>>2]|0;
   __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_20FragmentStateCompareELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_($1,1149304,$ffstate);
   $150 = HEAP32[$1>>2]|0;
   $151 = ($149|0)==(((1149288 + 4|0))|0);
   if ($151) {
    $158 = 0;
   } else {
    $152 = (($149) + 60|0);
    $153 = HEAP32[$152>>2]|0;
    $158 = $153;
   }
   $154 = ($150|0)==(((1149304 + 4|0))|0);
   if ($154) {
    $205 = 0;
   } else {
    $155 = (($150) + 60|0);
    $156 = HEAP32[$155>>2]|0;
    $205 = $156;
   }
   $157 = ($158|0)!=(0);
   L44: do {
    if ($151) {
     $159 = (1147664 + 88|0);
     $160 = HEAP32[$159>>2]|0;
     $161 = (FUNCTION_TABLE_ii[$160 & 4095](35633)|0);
     $162 = HEAP32[((640792 + 304|0))>>2]|0;
     __ZN3ffp4gles16BuildVProgSourceERKNS_5StateEi($src$i,$ffstate,$162);
     $163 = HEAP8[$src$i>>0]|0;
     $164 = $163 & 1;
     $165 = ($164<<24>>24)==(0);
     if ($165) {
      $168 = (($src$i) + 1|0);
      $169 = $168;
     } else {
      $166 = (($src$i) + 8|0);
      $167 = HEAP32[$166>>2]|0;
      $169 = $167;
     }
     __THREW__ = 0;
     $170 = (invoke_iiii(1636,($161|0),1,($169|0))|0);
     $171 = __THREW__; __THREW__ = 0;
     $172 = $171&1;
     do {
      if (!($172)) {
       $173 = (__ZNSt3__13mapIN3ffp5StateEjNS1_18VertexStateCompareENS_9allocatorINS_4pairIKS2_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS6_(1149288,$$byval_copy1,$ffstate)|0);
       $174 = HEAP32[$173>>2]|0;
       $175 = ($174|0)==(0|0);
       if ($175) {
        __THREW__ = 0;
        $176 = (invoke_ii(2988,64)|0);
        $177 = __THREW__; __THREW__ = 0;
        $178 = $177&1;
        if ($178) {
         break;
        }
        $179 = (($176) + 16|0);
        dest=$179+0|0; src=$ffstate+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $180 = (($176) + 60|0);
        HEAP32[$180>>2] = 0;
        $181 = HEAP32[$$byval_copy1>>2]|0;
        HEAP32[$176>>2] = 0;
        $182 = (($176) + 4|0);
        HEAP32[$182>>2] = 0;
        $183 = (($176) + 8|0);
        HEAP32[$183>>2] = $181;
        HEAP32[$173>>2] = $176;
        $184 = HEAP32[1149288>>2]|0;
        $185 = HEAP32[$184>>2]|0;
        $186 = ($185|0)==(0|0);
        if ($186) {
         $188 = $176;
        } else {
         HEAP32[1149288>>2] = $185;
         $$pre$i$i20$i = HEAP32[$173>>2]|0;
         $188 = $$pre$i$i20$i;
        }
        $187 = HEAP32[((1149288 + 4|0))>>2]|0;
        __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($187,$188);
        $189 = HEAP32[((1149288 + 8|0))>>2]|0;
        $190 = (($189) + 1)|0;
        HEAP32[((1149288 + 8|0))>>2] = $190;
        $__r$0$i22$i = $176;
       } else {
        $__r$0$i22$i = $174;
       }
       $191 = (($__r$0$i22$i) + 60|0);
       HEAP32[$191>>2] = $161;
       $192 = HEAP8[$src$i>>0]|0;
       $193 = $192 & 1;
       $194 = ($193<<24>>24)==(0);
       if ($194) {
        $vprog$0$i = $161;$vprogOK$0$in$i = $170;
        break L44;
       }
       $195 = (($src$i) + 8|0);
       $196 = HEAP32[$195>>2]|0;
       __ZdlPv($196);
       $vprog$0$i = $161;$vprogOK$0$in$i = $170;
       break L44;
      }
     } while(0);
     $197 = ___cxa_find_matching_catch()|0;
     $198 = tempRet0;
     $199 = HEAP8[$src$i>>0]|0;
     $200 = $199 & 1;
     $201 = ($200<<24>>24)==(0);
     if ($201) {
      $$01$i = $198;$$02$i = $197;
      ___resumeException($$02$i|0);
      // unreachable;
     }
     $202 = (($src$i) + 8|0);
     $203 = HEAP32[$202>>2]|0;
     __ZdlPv($203);
     $$01$i = $198;$$02$i = $197;
     ___resumeException($$02$i|0);
     // unreachable;
    } else {
     $vprog$0$i = $158;$vprogOK$0$in$i = $157;
    }
   } while(0);
   $204 = ($205|0)!=(0);
   L66: do {
    if ($154) {
     $206 = (1147664 + 88|0);
     $207 = HEAP32[$206>>2]|0;
     $208 = (FUNCTION_TABLE_ii[$207 & 4095](35632)|0);
     $209 = HEAP32[((640792 + 304|0))>>2]|0;
     __ZN3ffp4gles18BuildFShaderSourceERKNS_5StateEi($src1$i,$ffstate,$209);
     $210 = HEAP8[$src1$i>>0]|0;
     $211 = $210 & 1;
     $212 = ($211<<24>>24)==(0);
     if ($212) {
      $215 = (($src1$i) + 1|0);
      $216 = $215;
     } else {
      $213 = (($src1$i) + 8|0);
      $214 = HEAP32[$213>>2]|0;
      $216 = $214;
     }
     __THREW__ = 0;
     $217 = (invoke_iiii(1636,($208|0),2,($216|0))|0);
     $218 = __THREW__; __THREW__ = 0;
     $219 = $218&1;
     do {
      if (!($219)) {
       $220 = (__ZNSt3__13mapIN3ffp5StateEjNS1_20FragmentStateCompareENS_9allocatorINS_4pairIKS2_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS6_(1149304,$__parent$i$i,$ffstate)|0);
       $221 = HEAP32[$220>>2]|0;
       $222 = ($221|0)==(0|0);
       if ($222) {
        __THREW__ = 0;
        $223 = (invoke_ii(2988,64)|0);
        $224 = __THREW__; __THREW__ = 0;
        $225 = $224&1;
        if ($225) {
         break;
        }
        $226 = (($223) + 16|0);
        dest=$226+0|0; src=$ffstate+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        $227 = (($223) + 60|0);
        HEAP32[$227>>2] = 0;
        $228 = HEAP32[$__parent$i$i>>2]|0;
        HEAP32[$223>>2] = 0;
        $229 = (($223) + 4|0);
        HEAP32[$229>>2] = 0;
        $230 = (($223) + 8|0);
        HEAP32[$230>>2] = $228;
        HEAP32[$220>>2] = $223;
        $231 = HEAP32[1149304>>2]|0;
        $232 = HEAP32[$231>>2]|0;
        $233 = ($232|0)==(0|0);
        if ($233) {
         $235 = $223;
        } else {
         HEAP32[1149304>>2] = $232;
         $$pre$i$i$i = HEAP32[$220>>2]|0;
         $235 = $$pre$i$i$i;
        }
        $234 = HEAP32[((1149304 + 4|0))>>2]|0;
        __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($234,$235);
        $236 = HEAP32[((1149304 + 8|0))>>2]|0;
        $237 = (($236) + 1)|0;
        HEAP32[((1149304 + 8|0))>>2] = $237;
        $__r$0$i$i = $223;
       } else {
        $__r$0$i$i = $221;
       }
       $238 = (($__r$0$i$i) + 60|0);
       HEAP32[$238>>2] = $208;
       $239 = HEAP8[$src1$i>>0]|0;
       $240 = $239 & 1;
       $241 = ($240<<24>>24)==(0);
       if ($241) {
        $fshader$0$i = $208;$fshaderOK$0$in$i = $217;
        break L66;
       }
       $242 = (($src1$i) + 8|0);
       $243 = HEAP32[$242>>2]|0;
       __ZdlPv($243);
       $fshader$0$i = $208;$fshaderOK$0$in$i = $217;
       break L66;
      }
     } while(0);
     $244 = ___cxa_find_matching_catch()|0;
     $245 = tempRet0;
     $246 = HEAP8[$src1$i>>0]|0;
     $247 = $246 & 1;
     $248 = ($247<<24>>24)==(0);
     if ($248) {
      $$01$i = $245;$$02$i = $244;
      ___resumeException($$02$i|0);
      // unreachable;
     }
     $249 = (($src1$i) + 8|0);
     $250 = HEAP32[$249>>2]|0;
     __ZdlPv($250);
     $$01$i = $245;$$02$i = $244;
     ___resumeException($$02$i|0);
     // unreachable;
    } else {
     $fshader$0$i = $205;$fshaderOK$0$in$i = $204;
    }
   } while(0);
   $brmerge$demorgan$i = $vprogOK$0$in$i & $fshaderOK$0$in$i;
   if ($brmerge$demorgan$i) {
    $251 = HEAP32[628280>>2]|0;
    HEAP32[$2>>2] = $251;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
    $252 = (__Znwj10MemLabelIdbiPKci(180,$$byval_copy1,0,16,1149224,1243)|0);
    __THREW__ = 0;
    invoke_viii(2108,($252|0),($vprog$0$i|0),($fshader$0$i|0));
    $253 = __THREW__; __THREW__ = 0;
    $254 = $253&1;
    if ($254) {
     $257 = ___cxa_find_matching_catch()|0;
     $258 = tempRet0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$2+0>>2]|0;
     invoke_viiiiii(97,($252|0),($$byval_copy1|0),0,16,(1149224|0),1243);
     $259 = __THREW__; __THREW__ = 0;
     $260 = $259&1;
     if ($260) {
      $261 = ___cxa_find_matching_catch(0|0)|0;
      $262 = tempRet0;
      ___clang_call_terminate($261);
      // unreachable;
     } else {
      $$01$i = $258;$$02$i = $257;
      ___resumeException($$02$i|0);
      // unreachable;
     }
    } else {
     $256 = $252;
    }
   } else {
    $256 = 0;
   }
   $255 = (__ZNSt3__13mapIN3ffp5StateEP17FfpGpuProgramGLESNS1_16FullStateCompareENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS8_(1149272,$ffstate)|0);
   HEAP32[$255>>2] = $256;
   $$0$i = $256;
  }
  $263 = ($$0$i|0)==(0|0);
  if (!($263)) {
   $264 = (($this) + 6208|0);
   __ZNK17FfpGpuProgramGLES19ApplyGpuProgramGLESERK24BuiltinShaderParamValuesR19ConstantBuffersGLES($$0$i,$6,$264);
   $265 = (($$0$i) + 88|0);
   $266 = (($this) + 5808|0);
   HEAP32[$266>>2] = $265;
   $267 = (($$0$i) + 76|0);
   $268 = (($this) + 8000|0);
   HEAP32[$268>>2] = $267;
   $269 = (($this) + 7996|0);
   HEAP32[$269>>2] = $$0$i;
  }
 }
 $270 = (($this) + 5808|0);
 $271 = HEAP32[$270>>2]|0;
 $272 = HEAP32[$271>>2]|0;
 $273 = ($272|0)>(-1);
 L98: do {
  if ($273) {
   $274 = $5 & 7;
   $275 = ($274|0)==(0);
   if (!($275)) {
    $276 = (($this) + 2788|0);
    $277 = (($this) + 6140|0);
    __Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_($276,$277,$$byval_copy1);
    $278 = HEAP32[$271>>2]|0;
    $279 = (($271) + 8|0);
    $280 = HEAP32[$279>>2]|0;
    $281 = (($this) + 8000|0);
    $282 = HEAP32[$281>>2]|0;
    $283 = (($this) + 6208|0);
    $284 = ($280|0)==(0);
    if ($284) {
     $285 = (1147664 + 356|0);
     $286 = HEAP32[$285>>2]|0;
     FUNCTION_TABLE_viiii[$286 & 511]($278,1,0,$$byval_copy1);
     break;
    }
    $287 = ($282|0)==(0|0);
    if (!($287)) {
     $288 = (($282) + 4|0);
     $289 = HEAP32[$288>>2]|0;
     $290 = HEAP32[$282>>2]|0;
     $291 = ($289|0)==($290|0);
     if (!($291)) {
      $292 = $289;
      $293 = $290;
      $294 = (($292) - ($293))|0;
      $295 = (($294|0) / 28)&-1;
      $i$04$i21 = 0;
      while(1) {
       $298 = (($290) + (($i$04$i21*28)|0)|0);
       $299 = HEAP32[$298>>2]|0;
       $300 = ((($290) + (($i$04$i21*28)|0)|0) + 20|0);
       $301 = HEAP32[$300>>2]|0;
       $302 = $301 << 16;
       $303 = $302 | $299;
       $304 = ($303|0)==($280|0);
       $297 = (($i$04$i21) + 1)|0;
       if ($304) {
        break;
       }
       $296 = ($297>>>0)<($295>>>0);
       if ($296) {
        $i$04$i21 = $297;
       } else {
        break L98;
       }
      }
      $305 = ((($290) + (($i$04$i21*28)|0)|0) + 24|0);
      $306 = HEAP32[$305>>2]|0;
      $307 = (__ZN19ConstantBuffersGLES13FindAndBindCBEiii($283,$299,$306,$301)|0);
      __ZN19ConstantBuffersGLES13SetCBConstantEiiPKvi($283,$307,$278,$$byval_copy1,64);
     }
    }
   }
  }
 } while(0);
 $308 = (($271) + 12|0);
 $309 = HEAP32[$308>>2]|0;
 $310 = ($309|0)>(-1);
 L111: do {
  if ($310) {
   $311 = $5 & 3;
   $312 = ($311|0)==(0);
   if (!($312)) {
    $313 = (($271) + 20|0);
    $314 = HEAP32[$313>>2]|0;
    $315 = (($this) + 8000|0);
    $316 = HEAP32[$315>>2]|0;
    $317 = (($this) + 6140|0);
    $318 = (($this) + 6208|0);
    $319 = ($314|0)==(0);
    if ($319) {
     $320 = (1147664 + 356|0);
     $321 = HEAP32[$320>>2]|0;
     FUNCTION_TABLE_viiii[$321 & 511]($309,1,0,$317);
     break;
    }
    $322 = ($316|0)==(0|0);
    if (!($322)) {
     $323 = (($316) + 4|0);
     $324 = HEAP32[$323>>2]|0;
     $325 = HEAP32[$316>>2]|0;
     $326 = ($324|0)==($325|0);
     if (!($326)) {
      $327 = $324;
      $328 = $325;
      $329 = (($327) - ($328))|0;
      $330 = (($329|0) / 28)&-1;
      $i$04$i17 = 0;
      while(1) {
       $333 = (($325) + (($i$04$i17*28)|0)|0);
       $334 = HEAP32[$333>>2]|0;
       $335 = ((($325) + (($i$04$i17*28)|0)|0) + 20|0);
       $336 = HEAP32[$335>>2]|0;
       $337 = $336 << 16;
       $338 = $337 | $334;
       $339 = ($338|0)==($314|0);
       $332 = (($i$04$i17) + 1)|0;
       if ($339) {
        break;
       }
       $331 = ($332>>>0)<($330>>>0);
       if ($331) {
        $i$04$i17 = $332;
       } else {
        break L111;
       }
      }
      $340 = ((($325) + (($i$04$i17*28)|0)|0) + 24|0);
      $341 = HEAP32[$340>>2]|0;
      $342 = (__ZN19ConstantBuffersGLES13FindAndBindCBEiii($318,$334,$341,$336)|0);
      __ZN19ConstantBuffersGLES13SetCBConstantEiiPKvi($318,$342,$309,$317,64);
     }
    }
   }
  }
 } while(0);
 $343 = (($271) + 48|0);
 $344 = HEAP32[$343>>2]|0;
 $345 = ($344|0)>(-1);
 L124: do {
  if ($345) {
   $346 = $5 & 3;
   $347 = ($346|0)==(0);
   if (!($347)) {
    $348 = (($this) + 6140|0);
    __Z21TransposeMatrix4x4REFPK10Matrix4x4fPS_($348,$__parent$i$i);
    $349 = HEAP32[$343>>2]|0;
    $350 = (($271) + 56|0);
    $351 = HEAP32[$350>>2]|0;
    $352 = (($this) + 8000|0);
    $353 = HEAP32[$352>>2]|0;
    $354 = (($this) + 6208|0);
    $355 = ($351|0)==(0);
    if ($355) {
     $356 = (1147664 + 356|0);
     $357 = HEAP32[$356>>2]|0;
     FUNCTION_TABLE_viiii[$357 & 511]($349,1,0,$__parent$i$i);
     break;
    }
    $358 = ($353|0)==(0|0);
    if (!($358)) {
     $359 = (($353) + 4|0);
     $360 = HEAP32[$359>>2]|0;
     $361 = HEAP32[$353>>2]|0;
     $362 = ($360|0)==($361|0);
     if (!($362)) {
      $363 = $360;
      $364 = $361;
      $365 = (($363) - ($364))|0;
      $366 = (($365|0) / 28)&-1;
      $i$04$i13 = 0;
      while(1) {
       $369 = (($361) + (($i$04$i13*28)|0)|0);
       $370 = HEAP32[$369>>2]|0;
       $371 = ((($361) + (($i$04$i13*28)|0)|0) + 20|0);
       $372 = HEAP32[$371>>2]|0;
       $373 = $372 << 16;
       $374 = $373 | $370;
       $375 = ($374|0)==($351|0);
       $368 = (($i$04$i13) + 1)|0;
       if ($375) {
        break;
       }
       $367 = ($368>>>0)<($366>>>0);
       if ($367) {
        $i$04$i13 = $368;
       } else {
        break L124;
       }
      }
      $376 = ((($361) + (($i$04$i13*28)|0)|0) + 24|0);
      $377 = HEAP32[$376>>2]|0;
      $378 = (__ZN19ConstantBuffersGLES13FindAndBindCBEiii($354,$370,$377,$372)|0);
      __ZN19ConstantBuffersGLES13SetCBConstantEiiPKvi($354,$378,$349,$__parent$i$i,64);
     }
    }
   }
  }
 } while(0);
 $379 = (($271) + 60|0);
 $380 = HEAP32[$379>>2]|0;
 $381 = ($380|0)>(-1);
 L137: do {
  if ($381) {
   $382 = $5 & 3;
   $383 = ($382|0)==(0);
   if (!($383)) {
    $384 = (($this) + 6140|0);
    (__Z25InvertMatrix4x4_General3DPKfPf($384,$0)|0);
    __Z21TransposeMatrix4x4REFPK10Matrix4x4fPS_($0,$1);
    $385 = HEAP32[$379>>2]|0;
    $386 = (($271) + 68|0);
    $387 = HEAP32[$386>>2]|0;
    $388 = (($this) + 8000|0);
    $389 = HEAP32[$388>>2]|0;
    $390 = (($this) + 6208|0);
    $391 = ($387|0)==(0);
    if ($391) {
     $392 = (1147664 + 356|0);
     $393 = HEAP32[$392>>2]|0;
     FUNCTION_TABLE_viiii[$393 & 511]($385,1,0,$1);
     break;
    }
    $394 = ($389|0)==(0|0);
    if (!($394)) {
     $395 = (($389) + 4|0);
     $396 = HEAP32[$395>>2]|0;
     $397 = HEAP32[$389>>2]|0;
     $398 = ($396|0)==($397|0);
     if (!($398)) {
      $399 = $396;
      $400 = $397;
      $401 = (($399) - ($400))|0;
      $402 = (($401|0) / 28)&-1;
      $i$04$i9 = 0;
      while(1) {
       $405 = (($397) + (($i$04$i9*28)|0)|0);
       $406 = HEAP32[$405>>2]|0;
       $407 = ((($397) + (($i$04$i9*28)|0)|0) + 20|0);
       $408 = HEAP32[$407>>2]|0;
       $409 = $408 << 16;
       $410 = $409 | $406;
       $411 = ($410|0)==($387|0);
       $404 = (($i$04$i9) + 1)|0;
       if ($411) {
        break;
       }
       $403 = ($404>>>0)<($402>>>0);
       if ($403) {
        $i$04$i9 = $404;
       } else {
        break L137;
       }
      }
      $412 = ((($397) + (($i$04$i9*28)|0)|0) + 24|0);
      $413 = HEAP32[$412>>2]|0;
      $414 = (__ZN19ConstantBuffersGLES13FindAndBindCBEiii($390,$406,$413,$408)|0);
      __ZN19ConstantBuffersGLES13SetCBConstantEiiPKvi($390,$414,$385,$1,64);
     }
    }
   }
  }
 } while(0);
 $415 = (($271) + 24|0);
 $416 = HEAP32[$415>>2]|0;
 $417 = ($416|0)>(-1);
 L150: do {
  if ($417) {
   $418 = $5 & 1;
   $419 = ($418|0)==(0);
   if (!($419)) {
    $420 = (($271) + 32|0);
    $421 = HEAP32[$420>>2]|0;
    $422 = (($this) + 8000|0);
    $423 = HEAP32[$422>>2]|0;
    $424 = (($this) + 6208|0);
    $425 = ($421|0)==(0);
    if ($425) {
     $426 = (1147664 + 356|0);
     $427 = HEAP32[$426>>2]|0;
     FUNCTION_TABLE_viiii[$427 & 511]($416,1,0,$3);
     break;
    }
    $428 = ($423|0)==(0|0);
    if (!($428)) {
     $429 = (($423) + 4|0);
     $430 = HEAP32[$429>>2]|0;
     $431 = HEAP32[$423>>2]|0;
     $432 = ($430|0)==($431|0);
     if (!($432)) {
      $433 = $430;
      $434 = $431;
      $435 = (($433) - ($434))|0;
      $436 = (($435|0) / 28)&-1;
      $i$04$i5 = 0;
      while(1) {
       $439 = (($431) + (($i$04$i5*28)|0)|0);
       $440 = HEAP32[$439>>2]|0;
       $441 = ((($431) + (($i$04$i5*28)|0)|0) + 20|0);
       $442 = HEAP32[$441>>2]|0;
       $443 = $442 << 16;
       $444 = $443 | $440;
       $445 = ($444|0)==($421|0);
       $438 = (($i$04$i5) + 1)|0;
       if ($445) {
        break;
       }
       $437 = ($438>>>0)<($436>>>0);
       if ($437) {
        $i$04$i5 = $438;
       } else {
        break L150;
       }
      }
      $446 = ((($431) + (($i$04$i5*28)|0)|0) + 24|0);
      $447 = HEAP32[$446>>2]|0;
      $448 = (__ZN19ConstantBuffersGLES13FindAndBindCBEiii($424,$440,$447,$442)|0);
      __ZN19ConstantBuffersGLES13SetCBConstantEiiPKvi($424,$448,$416,$3,64);
     }
    }
   }
  }
 } while(0);
 $449 = (($271) + 36|0);
 $450 = HEAP32[$449>>2]|0;
 $451 = ($450|0)>(-1);
 L163: do {
  if ($451) {
   $452 = $5 & 1;
   $453 = ($452|0)==(0);
   if (!($453)) {
    $454 = (($271) + 44|0);
    $455 = HEAP32[$454>>2]|0;
    (__Z25InvertMatrix4x4_General3DPKfPf($3,$src$i)|0);
    $456 = (($this) + 8000|0);
    $457 = HEAP32[$456>>2]|0;
    $458 = (($this) + 6208|0);
    $459 = ($455|0)==(0);
    if ($459) {
     $460 = (1147664 + 356|0);
     $461 = HEAP32[$460>>2]|0;
     FUNCTION_TABLE_viiii[$461 & 511]($450,1,0,$src$i);
     break;
    }
    $462 = ($457|0)==(0|0);
    if (!($462)) {
     $463 = (($457) + 4|0);
     $464 = HEAP32[$463>>2]|0;
     $465 = HEAP32[$457>>2]|0;
     $466 = ($464|0)==($465|0);
     if (!($466)) {
      $467 = $464;
      $468 = $465;
      $469 = (($467) - ($468))|0;
      $470 = (($469|0) / 28)&-1;
      $i$04$i2 = 0;
      while(1) {
       $473 = (($465) + (($i$04$i2*28)|0)|0);
       $474 = HEAP32[$473>>2]|0;
       $475 = ((($465) + (($i$04$i2*28)|0)|0) + 20|0);
       $476 = HEAP32[$475>>2]|0;
       $477 = $476 << 16;
       $478 = $477 | $474;
       $479 = ($478|0)==($455|0);
       $472 = (($i$04$i2) + 1)|0;
       if ($479) {
        break;
       }
       $471 = ($472>>>0)<($470>>>0);
       if ($471) {
        $i$04$i2 = $472;
       } else {
        break L163;
       }
      }
      $480 = ((($465) + (($i$04$i2*28)|0)|0) + 24|0);
      $481 = HEAP32[$480>>2]|0;
      $482 = (__ZN19ConstantBuffersGLES13FindAndBindCBEiii($458,$474,$481,$476)|0);
      __ZN19ConstantBuffersGLES13SetCBConstantEiiPKvi($458,$482,$450,$src$i,64);
     }
    }
   }
  }
 } while(0);
 $483 = (($271) + 72|0);
 $484 = HEAP32[$483>>2]|0;
 $485 = ($484|0)>(-1);
 if (!($485)) {
  $518 = (($this) + 6208|0);
  __ZN19ConstantBuffersGLES13UpdateBuffersEv($518);
  STACKTOP = sp;return;
 }
 $486 = $5 & 3;
 $487 = ($486|0)==(0);
 if ($487) {
  $518 = (($this) + 6208|0);
  __ZN19ConstantBuffersGLES13UpdateBuffersEv($518);
  STACKTOP = sp;return;
 }
 $488 = (($271) + 80|0);
 $489 = HEAP32[$488>>2]|0;
 $490 = (($this) + 6140|0);
 __ZN10Matrix3x3fC2ERK10Matrix4x4f($src1$i,$490);
 __ZN10Matrix3x3f15InvertTransposeEv($src1$i);
 $491 = (($this) + 8000|0);
 $492 = HEAP32[$491>>2]|0;
 $493 = (($this) + 6208|0);
 $494 = ($489|0)==(0);
 if ($494) {
  $495 = (1147664 + 352|0);
  $496 = HEAP32[$495>>2]|0;
  FUNCTION_TABLE_viiii[$496 & 511]($484,1,0,$src1$i);
  $518 = (($this) + 6208|0);
  __ZN19ConstantBuffersGLES13UpdateBuffersEv($518);
  STACKTOP = sp;return;
 }
 $497 = ($492|0)==(0|0);
 if ($497) {
  $518 = (($this) + 6208|0);
  __ZN19ConstantBuffersGLES13UpdateBuffersEv($518);
  STACKTOP = sp;return;
 }
 $498 = (($492) + 4|0);
 $499 = HEAP32[$498>>2]|0;
 $500 = HEAP32[$492>>2]|0;
 $501 = ($499|0)==($500|0);
 if ($501) {
  $518 = (($this) + 6208|0);
  __ZN19ConstantBuffersGLES13UpdateBuffersEv($518);
  STACKTOP = sp;return;
 }
 $502 = $499;
 $503 = $500;
 $504 = (($502) - ($503))|0;
 $505 = (($504|0) / 28)&-1;
 $i$04$i = 0;
 while(1) {
  $508 = (($500) + (($i$04$i*28)|0)|0);
  $509 = HEAP32[$508>>2]|0;
  $510 = ((($500) + (($i$04$i*28)|0)|0) + 20|0);
  $511 = HEAP32[$510>>2]|0;
  $512 = $511 << 16;
  $513 = $512 | $509;
  $514 = ($513|0)==($489|0);
  $507 = (($i$04$i) + 1)|0;
  if ($514) {
   break;
  }
  $506 = ($507>>>0)<($505>>>0);
  if ($506) {
   $i$04$i = $507;
  } else {
   label = 135;
   break;
  }
 }
 if ((label|0) == 135) {
  $518 = (($this) + 6208|0);
  __ZN19ConstantBuffersGLES13UpdateBuffersEv($518);
  STACKTOP = sp;return;
 }
 $515 = ((($500) + (($i$04$i*28)|0)|0) + 24|0);
 $516 = HEAP32[$515>>2]|0;
 $517 = (__ZN19ConstantBuffersGLES13FindAndBindCBEiii($493,$509,$516,$511)|0);
 __ZN19ConstantBuffersGLES13SetCBConstantEiiPKvi($493,$517,$484,$src1$i,36);
 $518 = (($this) + 6208|0);
 __ZN19ConstantBuffersGLES13UpdateBuffersEv($518);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES11DrawBuffersEP11IndexBufferPK18VertexStreamSourceiPK16DrawBuffersRangeiP17VertexDeclarationRK14ChannelAssigns($this,$indexBuf,$vertexStreams,$vertexStreamCount,$drawRanges,$drawRangeCount,$vertexDecl,$channels) {
 $this = $this|0;
 $indexBuf = $indexBuf|0;
 $vertexStreams = $vertexStreams|0;
 $vertexStreamCount = $vertexStreamCount|0;
 $drawRanges = $drawRanges|0;
 $drawRangeCount = $drawRangeCount|0;
 $vertexDecl = $vertexDecl|0;
 $channels = $channels|0;
 var $$$i = 0, $$0$i = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond4 = 0, $i$01 = 0, $r$02 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($vertexDecl|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 __Z18SetVertexStateGLESRK14ChannelAssignsP21VertexDeclarationGLESPK18VertexStreamSourcej($channels,$vertexDecl,$vertexStreams,$vertexStreamCount);
 $1 = (($channels) + 9|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(2);
 $4 = (($this) + 8235|0);
 $5 = $3&1;
 HEAP8[$4>>0] = $5;
 $6 = HEAP32[$this>>2]|0;
 $7 = (($6) + 608|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 4095]($this);
 $9 = ($drawRangeCount|0)>(0);
 L4: do {
  if ($9) {
   $10 = ($indexBuf|0)==(0|0);
   $11 = (($this) + 5544|0);
   $12 = (($this) + 5344|0);
   $13 = (($this) + 5348|0);
   $14 = (($this) + 5356|0);
   $15 = (($this) + 5352|0);
   $16 = (($indexBuf) + 24|0);
   $r$02 = 0;
   while(1) {
    $17 = (($drawRanges) + (($r$02*24)|0)|0);
    if ($10) {
     $33 = (1147664 + 136|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = HEAP32[$17>>2]|0;
     $36 = (1149320 + ($35<<2)|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ((($drawRanges) + (($r$02*24)|0)|0) + 16|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ((($drawRanges) + (($r$02*24)|0)|0) + 20|0);
     $41 = HEAP32[$40>>2]|0;
     FUNCTION_TABLE_viii[$34 & 4095]($37,$39,$41);
     $$in = $40;
    } else {
     $18 = (1147664 + 12|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = HEAP32[$16>>2]|0;
     $21 = (($20) + 4|0);
     $22 = HEAP32[$21>>2]|0;
     FUNCTION_TABLE_vii[$19 & 4095](34963,$22);
     $23 = (1147664 + 140|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$17>>2]|0;
     $26 = (1149320 + ($25<<2)|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($drawRanges) + (($r$02*24)|0)|0) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ((($drawRanges) + (($r$02*24)|0)|0) + 4|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = $31;
     FUNCTION_TABLE_viiii[$24 & 511]($27,$29,5123,$32);
     $$in = $28;
    }
    $42 = HEAP32[$$in>>2]|0;
    $43 = HEAP32[$17>>2]|0;
    switch ($43|0) {
    case 2:  {
     $46 = (($42|0) / 4)&-1;
     $$$i = $46 << 1;
     $$0$i = $$$i;
     break;
    }
    case 3:  {
     $47 = (($42|0) / 2)&-1;
     $$0$i = $47;
     break;
    }
    case 0:  {
     $44 = (($42|0) / 3)&-1;
     $$0$i = $44;
     break;
    }
    case 1:  {
     $45 = (($42) + -2)|0;
     $$0$i = $45;
     break;
    }
    case 4:  {
     $48 = (($42) + -1)|0;
     $$0$i = $48;
     break;
    }
    case 5:  {
     $$0$i = $42;
     break;
    }
    default: {
     $$0$i = 0;
    }
    }
    $49 = HEAP8[$11>>0]|0;
    $50 = ($49<<24>>24)==(0);
    if (!($50)) {
     $51 = ((($drawRanges) + (($r$02*24)|0)|0) + 20|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = HEAP32[$12>>2]|0;
     $54 = (($53) + 1)|0;
     HEAP32[$12>>2] = $54;
     $55 = HEAP32[$13>>2]|0;
     $56 = (($55) + ($$0$i))|0;
     HEAP32[$13>>2] = $56;
     $57 = HEAP32[$14>>2]|0;
     $58 = (($57) + ($52))|0;
     HEAP32[$14>>2] = $58;
     $59 = HEAP32[$15>>2]|0;
     $60 = (($59) + ($$0$i))|0;
     HEAP32[$15>>2] = $60;
    }
    $61 = (($r$02) + 1)|0;
    $exitcond4 = ($61|0)==($drawRangeCount|0);
    if ($exitcond4) {
     break L4;
    } else {
     $r$02 = $61;
    }
   }
  }
 } while(0);
 $62 = ($indexBuf|0)==(0|0);
 if (!($62)) {
  $63 = (($indexBuf) + 24|0);
  $64 = HEAP32[$63>>2]|0;
  __ZN14DataBufferGLES12RecordRenderEv($64);
 }
 $65 = ($vertexStreamCount|0)>(0);
 if ($65) {
  $i$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $66 = (($vertexStreams) + ($i$01<<3)|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  if (!($68)) {
   $69 = (($67) + 24|0);
   $70 = HEAP32[$69>>2]|0;
   __ZN14DataBufferGLES12RecordRenderEv($70);
  }
  $71 = (($i$01) + 1)|0;
  $exitcond = ($71|0)==($vertexStreamCount|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $71;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES5ClearEjRK10ColorRGBAffj($this,$clearFlags,$color,$depth,$stencil) {
 $this = $this|0;
 $clearFlags = $clearFlags|0;
 $color = $color|0;
 $depth = Math_fround($depth);
 $stencil = $stencil|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 59|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = HEAP32[1149744>>2]|0;
  $5 = HEAP32[((1149928 + 4|0))>>2]|0;
  $6 = HEAP32[((1149928 + 8|0))>>2]|0;
  $7 = $6 | $5;
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = HEAP32[((1149928 + 12|0))>>2]|0;
   $10 = (($4) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($9|0)==($11|0);
   if ($12) {
    $13 = HEAP32[((1149928 + 16|0))>>2]|0;
    $14 = (($4) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($13|0)==($15|0);
    if ($16) {
     $17 = HEAP32[((1149744 + 32|0))>>2]|0;
     $18 = (($17) + 20|0);
     HEAP8[$18>>0] = 0;
     $19 = HEAP32[1149744>>2]|0;
     $20 = (($19) + 20|0);
     HEAP8[$20>>0] = 0;
    }
   }
  }
 }
 __ZN4gles24PrepareDrawIntoActiveFBOEv();
 $21 = HEAP32[1149672>>2]|0;
 $22 = (($21) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = $23 & 64;
 $25 = ($24|0)==(0);
 if ($25) {
  $26 = $clearFlags & 1;
  $27 = ($26|0)!=(0);
  $37 = $27;
 } else {
  $37 = 0;
 }
 $28 = HEAP32[((1149672 + 32|0))>>2]|0;
 $29 = (($28) + 16|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 64;
 $32 = ($31|0)==(0);
 if (!($32)) {
  $38 = 0;$39 = 0;
  __ZN4gles23ClearCurrentFramebufferEbbbPKffi($37,$38,$39,$color,$depth,$stencil);
  STACKTOP = sp;return;
 }
 $33 = $clearFlags & 2;
 $34 = ($33|0)!=(0);
 $35 = $clearFlags & 4;
 $36 = ($35|0)!=(0);
 $38 = $34;$39 = $36;
 __ZN4gles23ClearCurrentFramebufferEbbbPKffi($37,$38,$39,$color,$depth,$stencil);
 STACKTOP = sp;return;
}
function __ZN4gles23ClearCurrentFramebufferEbbbPKffi($clearColor,$clearDepth,$clearStencil,$color,$depth,$stencil) {
 $clearColor = $clearColor|0;
 $clearDepth = $clearDepth|0;
 $clearStencil = $clearStencil|0;
 $color = $color|0;
 $depth = Math_fround($depth);
 $stencil = $stencil|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $flags$0 = 0, $flags$1 = 0, $flags$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[1149528>>2]|0;
 if ($clearColor) {
  $3 = (__ZN4gles15UpdateColorMaskER15DeviceStateGLESPK20DeviceBlendStateGLESj($2,0,15)|0);
  $4 = (($2) + 2212|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  __ZN4gles13SetBlendStateER15DeviceStateGLESPK20DeviceBlendStateGLESf($2,$3,$5);
  $6 = (1147664 + 52|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = Math_fround(HEAPF32[$color>>2]);
  $9 = (($color) + 4|0);
  $10 = Math_fround(HEAPF32[$9>>2]);
  $11 = (($color) + 8|0);
  $12 = Math_fround(HEAPF32[$11>>2]);
  $13 = (($color) + 12|0);
  $14 = Math_fround(HEAPF32[$13>>2]);
  FUNCTION_TABLE_vffff[$7 & 7]($8,$10,$12,$14);
  $flags$0 = 16384;
 } else {
  $flags$0 = 0;
 }
 if ($clearDepth) {
  $15 = (($2) + 2112|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP8[$16>>0]|0;
  $18 = $17 & 1;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $20 = (($16) + 1|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21&255;
   $23 = ($22 << 8)&65535;
   $24 = $23 | 1;
   HEAP16[$1>>1] = $24;
   $25 = (($1) + 2|0);
   $26 = $21 << 24 >> 24;
   $27 = (1157480 + ($26<<2)|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $28&65535;
   HEAP16[$25>>1] = $29;
   $30 = (($2) + 2128|0);
   __ZNSt3__16__treeI20DeviceDepthStateGLES11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$30,$1);
   $31 = HEAP32[$0>>2]|0;
   $32 = (($31) + 16|0);
   $$pre = HEAP32[$15>>2]|0;
   $33 = ($$pre|0)==($32|0);
   if (!($33)) {
    HEAP32[$15>>2] = $32;
    $34 = (($31) + 17|0);
    $35 = HEAP8[$34>>0]|0;
    $36 = (($$pre) + 1|0);
    $37 = HEAP8[$36>>0]|0;
    $38 = ($37<<24>>24)==($35<<24>>24);
    do {
     if (!($38)) {
      $39 = ($35<<24>>24)==(0);
      if ($39) {
       $40 = (1147664 + 128|0);
       $41 = HEAP32[$40>>2]|0;
       FUNCTION_TABLE_vi[$41 & 4095](2929);
       break;
      }
      $42 = ($37<<24>>24)==(0);
      if ($42) {
       $43 = (1147664 + 144|0);
       $44 = HEAP32[$43>>2]|0;
       FUNCTION_TABLE_vi[$44 & 4095](2929);
      }
      $45 = (1147664 + 120|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = (($31) + 18|0);
      $48 = HEAP16[$47>>1]|0;
      $49 = $48&65535;
      FUNCTION_TABLE_vi[$46 & 4095]($49);
     }
    } while(0);
    $50 = HEAP8[$32>>0]|0;
    $51 = HEAP8[$$pre>>0]|0;
    $52 = ($50<<24>>24)==($51<<24>>24);
    if (!($52)) {
     $53 = (1147664 + 124|0);
     $54 = HEAP32[$53>>2]|0;
     FUNCTION_TABLE_vi[$54 & 4095]($50);
    }
   }
  }
  $55 = $flags$0 | 256;
  $56 = (1147664 + 56|0);
  $57 = HEAP32[$56>>2]|0;
  FUNCTION_TABLE_vf[$57 & 3]($depth);
  $flags$1 = $55;
 } else {
  $flags$1 = $flags$0;
 }
 if (!($clearStencil)) {
  $flags$2 = $flags$1;
  $64 = (1147664 + 48|0);
  $65 = HEAP32[$64>>2]|0;
  FUNCTION_TABLE_vi[$65 & 4095]($flags$2);
  STACKTOP = sp;return;
 }
 $58 = (__ZN4gles17UpdateStencilTestER15DeviceStateGLESPK22DeviceStencilStateGLESb($2,0,1)|0);
 $59 = (($2) + 2216|0);
 $60 = HEAP32[$59>>2]|0;
 __ZN4gles15SetStencilStateER15DeviceStateGLESPK22DeviceStencilStateGLESi($2,$58,$60);
 $61 = $flags$1 | 1024;
 $62 = (1147664 + 60|0);
 $63 = HEAP32[$62>>2]|0;
 FUNCTION_TABLE_vi[$63 & 4095]($stencil);
 $flags$2 = $61;
 $64 = (1147664 + 48|0);
 $65 = HEAP32[$64>>2]|0;
 FUNCTION_TABLE_vi[$65 & 4095]($flags$2);
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES15SetSurfaceFlagsE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseEjj($this,$surf,$flags,$keepFlags) {
 $this = $this|0;
 $surf = $surf|0;
 $flags = $flags|0;
 $keepFlags = $keepFlags|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN13GfxDeviceGLES15ReloadResourcesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z20GetBufferManagerGLESv()|0);
 __ZN17BufferManagerGLES13InvalidateAllEv($0);
 __ZN25TransformFeedbackSkinning31CleanupTransformFeedbackShadersEv();
 __ZN9GfxDevice15ResetAllBuffersEv($this);
 __ZN9GfxDevice16DeleteDynamicVBOEv($this);
 (__ZN9GfxDevice13GetDynamicVBOEv($this)|0);
 __ZN9GfxDevice21CommonReloadResourcesEj(7);
 __ZN4gles26ClearFixedFunctionProgramsEv();
 __ZN4gles20HandleFBOContextLossEv();
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZNK13GfxDeviceGLES18GetDefaultRTFormatEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK13GfxDeviceGLES21GetDefaultHDRRTFormatEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN4gles15UpdateAlphaTestER15DeviceStateGLESPK20DeviceBlendStateGLES15CompareFunction($state,$blendState,$alphaTest) {
 $state = $state|0;
 $blendState = $blendState|0;
 $alphaTest = $alphaTest|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp;
 $2 = ($blendState|0)==(0|0);
 if ($2) {
  $3 = (($state) + 2120|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 } else {
  $6 = $blendState;
 }
 $5 = (($6) + 4|0);
 $7 = HEAP32[$5>>2]|0;
 $8 = $7&65535;
 $9 = ($8&65535) >>> 8;
 $10 = $7 >>> 16;
 $11 = $7 >>> 24;
 $12 = (($6) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13&65535;
 $15 = ($14&65535) >>> 8;
 $16 = $13 << 8;
 $17 = $16 >> 24;
 $18 = ($17|0)==($alphaTest|0);
 if ($18) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = $13 >>> 24;
 $20 = $15&255;
 $21 = $13&255;
 $22 = $11&255;
 $23 = $10&255;
 $24 = $9&255;
 $25 = $7&255;
 $26 = $19&255;
 $27 = HEAP32[$6>>2]|0;
 $28 = $alphaTest&255;
 HEAP32[$1>>2] = $27;
 $29 = (($1) + 4|0);
 HEAP8[$29>>0] = $25;
 $30 = (($1) + 5|0);
 HEAP8[$30>>0] = $24;
 $31 = (($1) + 6|0);
 HEAP8[$31>>0] = $23;
 $32 = (($1) + 7|0);
 HEAP8[$32>>0] = $22;
 $33 = (($1) + 8|0);
 HEAP8[$33>>0] = $21;
 $34 = (($1) + 9|0);
 HEAP8[$34>>0] = $20;
 $35 = (($1) + 10|0);
 HEAP8[$35>>0] = $28;
 $36 = (($1) + 11|0);
 HEAP8[$36>>0] = $26;
 $37 = (($1) + 12|0);
 $38 = $7 & 255;
 $39 = (1157520 + ($38<<2)|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = $40&65535;
 HEAP16[$37>>1] = $41;
 $42 = (($1) + 14|0);
 $43 = $9&65535;
 $44 = (1157520 + ($43<<2)|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45&65535;
 HEAP16[$42>>1] = $46;
 $47 = (($1) + 16|0);
 $48 = $10 & 255;
 $49 = (1157520 + ($48<<2)|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50&65535;
 HEAP16[$47>>1] = $51;
 $52 = (($1) + 18|0);
 $53 = (1157520 + ($11<<2)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54&65535;
 HEAP16[$52>>1] = $55;
 $56 = (($1) + 20|0);
 $57 = $13 & 255;
 $58 = (1157568 + ($57<<2)|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = $59&65535;
 HEAP16[$56>>1] = $60;
 $61 = (($1) + 22|0);
 $62 = $15&65535;
 $63 = (1157568 + ($62<<2)|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = $64&65535;
 HEAP16[$61>>1] = $65;
 $66 = (($1) + 24|0);
 $sext = $alphaTest << 24;
 $67 = $sext >> 24;
 $68 = (1157480 + ($67<<2)|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = $69&65535;
 HEAP16[$66>>1] = $70;
 $71 = (($state) + 2152|0);
 __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$71,$1);
 $72 = HEAP32[$0>>2]|0;
 $73 = (($72) + 16|0);
 $$0 = $73;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles17UpdateStencilTestER15DeviceStateGLESPK22DeviceStencilStateGLESb($state,$stencilState,$enable) {
 $state = $state|0;
 $stencilState = $stencilState|0;
 $enable = $enable|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $srcData$sroa$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $1 = sp + 4|0;
 $srcData$sroa$1 = sp;
 $2 = ($stencilState|0)==(0|0);
 if ($2) {
  $3 = (($state) + 2116|0);
  $4 = HEAP32[$3>>2]|0;
  $6 = $4;
 } else {
  $6 = $stencilState;
 }
 $5 = HEAP8[$6>>0]|0;
 $7 = (($6) + 1|0);
 ;HEAP8[$srcData$sroa$1+0>>0]=HEAP8[$7+0>>0]|0;HEAP8[$srcData$sroa$1+1>>0]=HEAP8[$7+1>>0]|0;HEAP8[$srcData$sroa$1+2>>0]=HEAP8[$7+2>>0]|0;
 $8 = (($6) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9&65535;
 $11 = ($10&65535) >>> 8;
 $12 = $9 >>> 16;
 $13 = $9 >>> 24;
 $14 = (($6) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15&65535;
 $17 = ($16&65535) >>> 8;
 $18 = $15 >>> 16;
 $19 = $15 >>> 24;
 $20 = $5&255;
 $21 = $enable&1;
 $22 = ($20|0)==($21|0);
 if ($22) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = $19&255;
 $24 = $18&255;
 $25 = $17&255;
 $26 = $15&255;
 $27 = $13&255;
 $28 = $12&255;
 $29 = $11&255;
 $30 = $9&255;
 $31 = $enable&1;
 HEAP8[$1>>0] = $31;
 $32 = (($1) + 1|0);
 ;HEAP8[$32+0>>0]=HEAP8[$srcData$sroa$1+0>>0]|0;HEAP8[$32+1>>0]=HEAP8[$srcData$sroa$1+1>>0]|0;HEAP8[$32+2>>0]=HEAP8[$srcData$sroa$1+2>>0]|0;
 $33 = (($1) + 4|0);
 HEAP8[$33>>0] = $30;
 $34 = (($1) + 5|0);
 HEAP8[$34>>0] = $29;
 $35 = (($1) + 6|0);
 HEAP8[$35>>0] = $28;
 $36 = (($1) + 7|0);
 HEAP8[$36>>0] = $27;
 $37 = (($1) + 8|0);
 HEAP8[$37>>0] = $26;
 $38 = (($1) + 9|0);
 HEAP8[$38>>0] = $25;
 $39 = (($1) + 10|0);
 HEAP8[$39>>0] = $24;
 $40 = (($1) + 11|0);
 HEAP8[$40>>0] = $23;
 $41 = (($1) + 12|0);
 $42 = $9 & 255;
 $43 = (1157480 + ($42<<2)|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $44&65535;
 HEAP16[$41>>1] = $45;
 $46 = (($1) + 14|0);
 $47 = $11&65535;
 $48 = (1157656 + ($47<<2)|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = $49&65535;
 HEAP16[$46>>1] = $50;
 $51 = (($1) + 16|0);
 $52 = $12 & 255;
 $53 = (1157656 + ($52<<2)|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54&65535;
 HEAP16[$51>>1] = $55;
 $56 = (($1) + 18|0);
 $57 = (1157656 + ($13<<2)|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58&65535;
 HEAP16[$56>>1] = $59;
 $60 = (($1) + 20|0);
 $61 = $15 & 255;
 $62 = (1157480 + ($61<<2)|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = $63&65535;
 HEAP16[$60>>1] = $64;
 $65 = (($1) + 22|0);
 $66 = $17&65535;
 $67 = (1157656 + ($66<<2)|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68&65535;
 HEAP16[$65>>1] = $69;
 $70 = (($1) + 24|0);
 $71 = $18 & 255;
 $72 = (1157656 + ($71<<2)|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = $73&65535;
 HEAP16[$70>>1] = $74;
 $75 = (($1) + 26|0);
 $76 = (1157656 + ($19<<2)|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = $77&65535;
 HEAP16[$75>>1] = $78;
 $79 = (($state) + 2140|0);
 __ZNSt3__16__treeI22DeviceStencilStateGLES11memcmp_lessIS1_18DeviceStencilStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($0,$79,$1);
 $80 = HEAP32[$0>>2]|0;
 $81 = (($80) + 16|0);
 $$0 = $81;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13GfxDeviceGLES12SetWireframeEb($this,$wire) {
 $this = $this|0;
 $wire = $wire|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK13GfxDeviceGLES12GetWireframeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNSt3__16__treeI17DeviceRasterState11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$20 = $13;
  } else {
   $__nd$0$in$i = $1;
   while(1) {
    $3 = (($__nd$0$in$i) + 16|0);
    $4 = (_memcmp($__v,$3,12)|0);
    $5 = ($4|0)<(0);
    if ($5) {
     $6 = HEAP32[$__nd$0$in$i>>2]|0;
     $7 = ($6|0)==(0|0);
     if ($7) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $6;
      continue;
     }
    }
    $8 = (_memcmp($3,$__v,12)|0);
    $9 = ($8|0)<(0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $30 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(28)|0);
 $17 = (($16) + 16|0);
 ;HEAP32[$17+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$__v+8>>2]|0;
 HEAP32[$16>>2] = 0;
 $18 = (($16) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $16;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $16;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$20 = $13;
  } else {
   $__nd$0$in$i = $1;
   while(1) {
    $3 = (($__nd$0$in$i) + 16|0);
    $4 = (_memcmp($__v,$3,12)|0);
    $5 = ($4|0)<(0);
    if ($5) {
     $6 = HEAP32[$__nd$0$in$i>>2]|0;
     $7 = ($6|0)==(0|0);
     if ($7) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $6;
      continue;
     }
    }
    $8 = (_memcmp($3,$__v,12)|0);
    $9 = ($8|0)<(0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $30 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(44)|0);
 $17 = (($16) + 16|0);
 ;HEAP32[$17+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$__v+16>>2]|0;HEAP32[$17+20>>2]=HEAP32[$__v+20>>2]|0;HEAP32[$17+24>>2]=HEAP32[$__v+24>>2]|0;
 HEAP32[$16>>2] = 0;
 $18 = (($16) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $16;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $16;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI22DeviceStencilStateGLES11memcmp_lessIS1_18DeviceStencilStateENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$20 = $13;
  } else {
   $__nd$0$in$i = $1;
   while(1) {
    $3 = (($__nd$0$in$i) + 16|0);
    $4 = (_memcmp($__v,$3,12)|0);
    $5 = ($4|0)<(0);
    if ($5) {
     $6 = HEAP32[$__nd$0$in$i>>2]|0;
     $7 = ($6|0)==(0|0);
     if ($7) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $6;
      continue;
     }
    }
    $8 = (_memcmp($3,$__v,12)|0);
    $9 = ($8|0)<(0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$20 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$20 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $30 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $29 = (($agg$result) + 4|0);
  HEAP8[$29>>0] = $30;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(44)|0);
 $17 = (($16) + 16|0);
 ;HEAP32[$17+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$__v+16>>2]|0;HEAP32[$17+20>>2]=HEAP32[$__v+20>>2]|0;HEAP32[$17+24>>2]=HEAP32[$__v+24>>2]|0;
 HEAP32[$16>>2] = 0;
 $18 = (($16) + 4|0);
 HEAP32[$18>>2] = 0;
 $19 = (($16) + 8|0);
 HEAP32[$19>>2] = $20;
 HEAP32[$$0$i>>2] = $16;
 $21 = HEAP32[$this>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if ($23) {
  $25 = $16;
 } else {
  HEAP32[$this>>2] = $22;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $25 = $$pre$i;
 }
 $24 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($24,$25);
 $26 = (($this) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + 1)|0;
 HEAP32[$26>>2] = $28;
 $30 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $29 = (($agg$result) + 4|0);
 HEAP8[$29>>0] = $30;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeI20DeviceDepthStateGLES11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE15__insert_uniqueERKS1_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $13 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $13;
   $$0$i = $13;$21 = $13;
  } else {
   $__nd$0$in$i = $1;
   while(1) {
    $3 = (($__nd$0$in$i) + 16|0);
    $4 = (_memcmp($__v,$3,4)|0);
    $5 = ($4|0)<(0);
    if ($5) {
     $6 = HEAP32[$__nd$0$in$i>>2]|0;
     $7 = ($6|0)==(0|0);
     if ($7) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $6;
      continue;
     }
    }
    $8 = (_memcmp($3,$__v,4)|0);
    $9 = ($8|0)<(0);
    if (!($9)) {
     label = 9;
     break;
    }
    $10 = (($__nd$0$in$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $11;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $10;$21 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$21 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $14 = HEAP32[$$0$i>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $31 = 0;$__r$0 = $14;
  HEAP32[$agg$result>>2] = $__r$0;
  $30 = (($agg$result) + 4|0);
  HEAP8[$30>>0] = $31;
  STACKTOP = sp;return;
 }
 $16 = (__Znwj(20)|0);
 $17 = (($16) + 16|0);
 $18 = HEAP32[$__v>>2]|0;
 HEAP32[$17>>2] = $18;
 HEAP32[$16>>2] = 0;
 $19 = (($16) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($16) + 8|0);
 HEAP32[$20>>2] = $21;
 HEAP32[$$0$i>>2] = $16;
 $22 = HEAP32[$this>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  $26 = $16;
 } else {
  HEAP32[$this>>2] = $23;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $26 = $$pre$i;
 }
 $25 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($25,$26);
 $27 = (($this) + 8|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[$27>>2] = $29;
 $31 = 1;$__r$0 = $16;
 HEAP32[$agg$result>>2] = $__r$0;
 $30 = (($agg$result) + 4|0);
 HEAP8[$30>>0] = $31;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEP17FfpGpuProgramGLESEENS_19__map_value_compareIS3_S6_NS2_16FullStateCompareELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEP17FfpGpuProgramGLESEENS_19__map_value_compareIS3_S6_NS2_16FullStateCompareELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEP17FfpGpuProgramGLESEENS_19__map_value_compareIS3_S6_NS2_16FullStateCompareELb1EEENS_9allocatorIS6_EEE7destroyEPNS_11__tree_nodeIS6_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_20FragmentStateCompareELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_20FragmentStateCompareELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_20FragmentStateCompareELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_18VertexStateCompareELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_18VertexStateCompareELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_18VertexStateCompareELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESE12EnsureBufferEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   label = 7;
  } else {
   $3 = (($1) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4>>>0)<($size>>>0);
   if ($5) {
    $7 = $1;
   } else {
    $6 = (__Z27BufferUpdateCausesStallGLESPK14DataBufferGLES($1)|0);
    $$pre = HEAP32[$0>>2]|0;
    if ($6) {
     $7 = $$pre;
    } else {
     $8 = ($$pre|0)==(0|0);
     if ($8) {
      label = 7;
      break;
     }
     $$pre2 = (($this) + 28|0);
     $$pre$phiZ2D = $$pre2;$15 = $$pre;
     break;
    }
   }
   __ZN14DataBufferGLES7ReleaseEv($7);
   HEAP32[$0>>2] = 0;
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $9 = (__Z20GetBufferManagerGLESv()|0);
  $10 = (($this) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__ZN17BufferManagerGLES13AcquireBufferEiN14DataBufferGLES11BufferUsageE($9,$size,$11)|0);
  HEAP32[$0>>2] = $12;
  $$pre$phiZ2D = $10;$15 = $12;
 }
 $13 = HEAP32[$$pre$phiZ2D>>2]|0;
 $14 = ($13|0)==(2);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 __ZN14DataBufferGLES13EnsureStorageEi($15,$size);
 STACKTOP = sp;return;
}
function __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESED1Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$01$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((1149344 + 8|0));
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3794,($2|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   $8 = (($this) + 44|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)>(-1);
   if (!($10)) {
    $$0$i = $7;$$01$i = $6;
    ___resumeException($$01$i|0);
    // unreachable;
   }
   $11 = (($this) + 32|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 36|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$0>>2] = $14;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($12|0),($$byval_copy1|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $28 = ___cxa_find_matching_catch(0|0)|0;
    $29 = tempRet0;
    ___clang_call_terminate($28);
    // unreachable;
   }
   HEAP32[$11>>2] = 0;
   $$0$i = $7;$$01$i = $6;
   ___resumeException($$01$i|0);
   // unreachable;
  }
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)>(-1);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = (($this) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 36|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$0>>2] = $23;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($21|0),($$byval_copy1|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $$0$i = $27;$$01$i = $26;
  ___resumeException($$01$i|0);
  // unreachable;
 } else {
  HEAP32[$20>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESED0Ev($this) {
 $this = $this|0;
 var $$0$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((1149344 + 8|0));
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3794,($3|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   $7 = ___cxa_find_matching_catch()|0;
   $8 = tempRet0;
   $9 = (($this) + 44|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)>(-1);
   if (!($11)) {
    $$0$i$i = $8;$$01$i$i = $7;
    __ZdlPv($this);
    ___resumeException($$01$i$i|0);
    // unreachable;
   }
   $12 = (($this) + 32|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($this) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$1>>2] = $15;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($13|0),($$byval_copy1|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $29 = ___cxa_find_matching_catch(0|0)|0;
    $30 = tempRet0;
    ___clang_call_terminate($29);
    // unreachable;
   } else {
    $$0$i$i = $8;$$01$i$i = $7;
    __ZdlPv($this);
    ___resumeException($$01$i$i|0);
    // unreachable;
   }
  }
 }
 $18 = (($this) + 44|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(-1);
 if (!($20)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $21 = (($this) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$0>>2] = $24;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($22|0),($$byval_copy1|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if (!($26)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $$0$i$i = $28;$$01$i$i = $27;
 __ZdlPv($this);
 ___resumeException($$01$i$i|0);
 // unreachable;
}
function __ZNK9GfxBuffer6IsLostEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN9GfxBuffer5ResetEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESE12EnsureBufferEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   label = 7;
  } else {
   $3 = (($1) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4>>>0)<($size>>>0);
   if ($5) {
    $7 = $1;
   } else {
    $6 = (__Z27BufferUpdateCausesStallGLESPK14DataBufferGLES($1)|0);
    $$pre = HEAP32[$0>>2]|0;
    if ($6) {
     $7 = $$pre;
    } else {
     $8 = ($$pre|0)==(0|0);
     if ($8) {
      label = 7;
      break;
     }
     $$pre2 = (($this) + 28|0);
     $$pre$phiZ2D = $$pre2;$15 = $$pre;
     break;
    }
   }
   __ZN14DataBufferGLES7ReleaseEv($7);
   HEAP32[$0>>2] = 0;
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $9 = (__Z20GetBufferManagerGLESv()|0);
  $10 = (($this) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__ZN17BufferManagerGLES13AcquireBufferEiN14DataBufferGLES11BufferUsageE($9,$size,$11)|0);
  HEAP32[$0>>2] = $12;
  $$pre$phiZ2D = $10;$15 = $12;
 }
 $13 = HEAP32[$$pre$phiZ2D>>2]|0;
 $14 = ($13|0)==(2);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 __ZN14DataBufferGLES13EnsureStorageEi($15,$size);
 STACKTOP = sp;return;
}
function __ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESED1Ev($this) {
 $this = $this|0;
 var $$0$i = 0, $$01$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 HEAP32[$this>>2] = ((1149368 + 8|0));
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3794,($2|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   $8 = (($this) + 44|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)>(-1);
   if (!($10)) {
    $$0$i = $7;$$01$i = $6;
    ___resumeException($$01$i|0);
    // unreachable;
   }
   $11 = (($this) + 32|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 36|0);
   $14 = HEAP32[$13>>2]|0;
   HEAP32[$0>>2] = $14;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($12|0),($$byval_copy1|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    $28 = ___cxa_find_matching_catch(0|0)|0;
    $29 = tempRet0;
    ___clang_call_terminate($28);
    // unreachable;
   }
   HEAP32[$11>>2] = 0;
   $$0$i = $7;$$01$i = $6;
   ___resumeException($$01$i|0);
   // unreachable;
  }
 }
 $17 = (($this) + 44|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)>(-1);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $20 = (($this) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($this) + 36|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$0>>2] = $23;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($21|0),($$byval_copy1|0));
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 if ($25) {
  $26 = ___cxa_find_matching_catch()|0;
  $27 = tempRet0;
  $$0$i = $27;$$01$i = $26;
  ___resumeException($$01$i|0);
  // unreachable;
 } else {
  HEAP32[$20>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESED0Ev($this) {
 $this = $this|0;
 var $$0$i$i = 0, $$01$i$i = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$this>>2] = ((1149368 + 8|0));
 $2 = (($this) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3794,($3|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   $7 = ___cxa_find_matching_catch()|0;
   $8 = tempRet0;
   $9 = (($this) + 44|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)>(-1);
   if (!($11)) {
    $$0$i$i = $8;$$01$i$i = $7;
    __ZdlPv($this);
    ___resumeException($$01$i$i|0);
    // unreachable;
   }
   $12 = (($this) + 32|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($this) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$1>>2] = $15;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   invoke_vii(2591,($13|0),($$byval_copy1|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $29 = ___cxa_find_matching_catch(0|0)|0;
    $30 = tempRet0;
    ___clang_call_terminate($29);
    // unreachable;
   } else {
    $$0$i$i = $8;$$01$i$i = $7;
    __ZdlPv($this);
    ___resumeException($$01$i$i|0);
    // unreachable;
   }
  }
 }
 $18 = (($this) + 44|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(-1);
 if (!($20)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $21 = (($this) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 HEAP32[$0>>2] = $24;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($22|0),($$byval_copy1|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if (!($26)) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $$0$i$i = $28;$$01$i$i = $27;
 __ZdlPv($this);
 ___resumeException($$01$i$i|0);
 // unreachable;
}
function __ZNSt3__13mapIN3ffp5StateEP17FfpGpuProgramGLESNS1_16FullStateCompareENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS8_($this,$__k) {
 $this = $this|0;
 $__k = $__k|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $11 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $11;
   $$0$i = $11;$19 = $11;
  } else {
   $__nd$0$in$i = $1;
   while(1) {
    $3 = (($__nd$0$in$i) + 16|0);
    $4 = (__ZNK3ffp16FullStateCompareclERKNS_5StateES3_(0,$__k,$3)|0);
    if ($4) {
     $5 = HEAP32[$__nd$0$in$i>>2]|0;
     $6 = ($5|0)==(0|0);
     if ($6) {
      label = 4;
      break;
     } else {
      $__nd$0$in$i = $5;
      continue;
     }
    }
    $7 = (__ZNK3ffp16FullStateCompareclERKNS_5StateES3_(0,$3,$__k)|0);
    if (!($7)) {
     label = 8;
     break;
    }
    $8 = (($__nd$0$in$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     label = 7;
     break;
    } else {
     $__nd$0$in$i = $9;
    }
   }
   if ((label|0) == 4) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$19 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 7) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $8;$19 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$19 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $12 = HEAP32[$$0$i>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $__r$0 = $12;
  $28 = (($__r$0) + 60|0);
  STACKTOP = sp;return ($28|0);
 }
 $14 = (__Znwj(64)|0);
 $15 = (($14) + 16|0);
 dest=$15+0|0; src=$__k+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $16 = (($14) + 60|0);
 HEAP32[$16>>2] = 0;
 HEAP32[$14>>2] = 0;
 $17 = (($14) + 4|0);
 HEAP32[$17>>2] = 0;
 $18 = (($14) + 8|0);
 HEAP32[$18>>2] = $19;
 HEAP32[$$0$i>>2] = $14;
 $20 = HEAP32[$this>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $24 = $14;
 } else {
  HEAP32[$this>>2] = $21;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $24 = $$pre$i;
 }
 $23 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($23,$24);
 $25 = (($this) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$25>>2] = $27;
 $__r$0 = $14;
 $28 = (($__r$0) + 60|0);
 STACKTOP = sp;return ($28|0);
}
function __ZNK3ffp16FullStateCompareclERKNS_5StateES3_($this,$a,$b) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var $or$cond = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($b) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 L1: do {
  if ($4) {
   $$0 = 1;
  } else {
   $5 = ($1>>>0)>($3>>>0);
   if ($5) {
    $$0 = 0;
   } else {
    $6 = (($a) + 38|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = (($b) + 38|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($7&255)<($9&255);
    if ($10) {
     $$0 = 1;
    } else {
     $11 = ($7&255)>($9&255);
     if ($11) {
      $$0 = 0;
     } else {
      $12 = (($a) + 36|0);
      $13 = HEAP8[$12>>0]|0;
      $14 = $13&255;
      $15 = (($b) + 36|0);
      $16 = HEAP8[$15>>0]|0;
      $17 = ($13&255)<($16&255);
      if ($17) {
       $$0 = 1;
      } else {
       $18 = ($13&255)>($16&255);
       if ($18) {
        $$0 = 0;
       } else {
        $19 = (($a) + 37|0);
        $20 = HEAP8[$19>>0]|0;
        $21 = (($b) + 37|0);
        $22 = HEAP8[$21>>0]|0;
        $23 = ($20&255)<($22&255);
        if ($23) {
         $$0 = 1;
        } else {
         $24 = ($20&255)>($22&255);
         if ($24) {
          $$0 = 0;
         } else {
          $25 = (($a) + 39|0);
          $26 = HEAP8[$25>>0]|0;
          $27 = (($b) + 39|0);
          $28 = HEAP8[$27>>0]|0;
          $29 = ($26<<24>>24)<($28<<24>>24);
          if ($29) {
           $$0 = 1;
          } else {
           $30 = ($26<<24>>24)>($28<<24>>24);
           if ($30) {
            $$0 = 0;
           } else {
            $31 = (($a) + 40|0);
            $32 = HEAP8[$31>>0]|0;
            $33 = (($b) + 40|0);
            $34 = HEAP8[$33>>0]|0;
            $35 = ($32<<24>>24)<($34<<24>>24);
            if ($35) {
             $$0 = 1;
            } else {
             $36 = ($32<<24>>24)>($34<<24>>24);
             if ($36) {
              $$0 = 0;
             } else {
              $37 = (($a) + 41|0);
              $38 = HEAP8[$37>>0]|0;
              $39 = (($b) + 41|0);
              $40 = HEAP8[$39>>0]|0;
              $41 = ($38&255)<($40&255);
              if ($41) {
               $$0 = 1;
              } else {
               $42 = ($38&255)>($40&255);
               $43 = ($13<<24>>24)==(0);
               $or$cond = $42 | $43;
               if ($or$cond) {
                $$0 = 0;
               } else {
                $i$01 = 0;
                while(1) {
                 $44 = (($a) + ($i$01<<2)|0);
                 $45 = HEAP32[$44>>2]|0;
                 $46 = (($b) + ($i$01<<2)|0);
                 $47 = HEAP32[$46>>2]|0;
                 $48 = ($45>>>0)<($47>>>0);
                 if ($48) {
                  $$0 = 1;
                  break L1;
                 }
                 $49 = ($45>>>0)>($47>>>0);
                 if ($49) {
                  $$0 = 0;
                  break L1;
                 }
                 $50 = ((($a) + ($i$01<<2)|0) + 16|0);
                 $51 = HEAP32[$50>>2]|0;
                 $52 = ((($b) + ($i$01<<2)|0) + 16|0);
                 $53 = HEAP32[$52>>2]|0;
                 $54 = ($51>>>0)<($53>>>0);
                 if ($54) {
                  $$0 = 1;
                  break L1;
                 }
                 $55 = ($51>>>0)<=($53>>>0);
                 $56 = (($i$01) + 1)|0;
                 $57 = ($56|0)<($14|0);
                 $or$cond2 = $55 & $57;
                 if ($or$cond2) {
                  $i$01 = $56;
                 } else {
                  $$0 = 0;
                  break;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__13mapIN3ffp5StateEjNS1_20FragmentStateCompareENS_9allocatorINS_4pairIKS2_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS6_($this,$__parent,$__k) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__k = $__k|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $__nd$0$in = 0, $i$01$i = 0, $i$01$i2 = 0, $or$cond$i = 0, $or$cond$i1 = 0, $or$cond2$i = 0, $or$cond2$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $80 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $80;
  $$0 = $80;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__k) + 38|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = (($__k) + 36|0);
 $6 = (($__k) + 39|0);
 $7 = (($__k) + 40|0);
 $__nd$0$in = $1;
 L5: while(1) {
  $8 = (($__nd$0$in) + 16|0);
  $9 = (($8) + 38|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($4&255)<($10&255);
  L7: do {
   if (!($11)) {
    $12 = ($4&255)>($10&255);
    L9: do {
     if (!($12)) {
      $13 = HEAP8[$5>>0]|0;
      $14 = $13&255;
      $15 = (($__nd$0$in) + 52|0);
      $16 = HEAP8[$15>>0]|0;
      $17 = ($13&255)<($16&255);
      if ($17) {
       break L7;
      }
      $18 = ($13&255)>($16&255);
      L12: do {
       if (!($18)) {
        $19 = HEAP8[$6>>0]|0;
        $20 = (($8) + 39|0);
        $21 = HEAP8[$20>>0]|0;
        $22 = ($19<<24>>24)<($21<<24>>24);
        if ($22) {
         break L7;
        }
        $23 = ($19<<24>>24)>($21<<24>>24);
        if (!($23)) {
         $24 = HEAP8[$7>>0]|0;
         $25 = (($__nd$0$in) + 56|0);
         $26 = HEAP8[$25>>0]|0;
         $27 = ($24<<24>>24)<($26<<24>>24);
         if ($27) {
          break L7;
         }
         $28 = ($24<<24>>24)>($26<<24>>24);
         $29 = ($13<<24>>24)==(0);
         $or$cond$i1 = $28 | $29;
         if (!($or$cond$i1)) {
          $i$01$i2 = 0;
          while(1) {
           $30 = (($__k) + ($i$01$i2<<2)|0);
           $31 = HEAP32[$30>>2]|0;
           $32 = (($8) + ($i$01$i2<<2)|0);
           $33 = HEAP32[$32>>2]|0;
           $34 = ($31>>>0)<($33>>>0);
           if ($34) {
            break L7;
           }
           $35 = ($31>>>0)>($33>>>0);
           if ($35) {
            break L12;
           }
           $36 = ((($__k) + ($i$01$i2<<2)|0) + 16|0);
           $37 = HEAP32[$36>>2]|0;
           $38 = ((($8) + ($i$01$i2<<2)|0) + 16|0);
           $39 = HEAP32[$38>>2]|0;
           $40 = ($37>>>0)<($39>>>0);
           if ($40) {
            break L7;
           }
           $41 = ($37>>>0)<=($39>>>0);
           $42 = (($i$01$i2) + 1)|0;
           $43 = ($42|0)<($14|0);
           $or$cond2$i4 = $41 & $43;
           if ($or$cond2$i4) {
            $i$01$i2 = $42;
           } else {
            break;
           }
          }
         }
        }
       }
      } while(0);
      if (!($12)) {
       $46 = (($__nd$0$in) + 52|0);
       $47 = HEAP8[$46>>0]|0;
       $48 = $47&255;
       $49 = HEAP8[$5>>0]|0;
       $50 = ($47&255)<($49&255);
       if (!($50)) {
        $51 = ($47&255)>($49&255);
        if ($51) {
         label = 30;
         break L5;
        }
        $52 = (($8) + 39|0);
        $53 = HEAP8[$52>>0]|0;
        $54 = HEAP8[$6>>0]|0;
        $55 = ($53<<24>>24)<($54<<24>>24);
        if (!($55)) {
         $56 = ($53<<24>>24)>($54<<24>>24);
         if ($56) {
          label = 30;
          break L5;
         }
         $57 = (($__nd$0$in) + 56|0);
         $58 = HEAP8[$57>>0]|0;
         $59 = HEAP8[$7>>0]|0;
         $60 = ($58<<24>>24)<($59<<24>>24);
         if (!($60)) {
          $61 = ($58<<24>>24)>($59<<24>>24);
          $62 = ($47<<24>>24)==(0);
          $or$cond$i = $61 | $62;
          if ($or$cond$i) {
           label = 30;
           break L5;
          } else {
           $i$01$i = 0;
          }
          while(1) {
           $63 = (($8) + ($i$01$i<<2)|0);
           $64 = HEAP32[$63>>2]|0;
           $65 = (($__k) + ($i$01$i<<2)|0);
           $66 = HEAP32[$65>>2]|0;
           $67 = ($64>>>0)<($66>>>0);
           if ($67) {
            break L9;
           }
           $68 = ($64>>>0)>($66>>>0);
           if ($68) {
            label = 30;
            break L5;
           }
           $69 = ((($8) + ($i$01$i<<2)|0) + 16|0);
           $70 = HEAP32[$69>>2]|0;
           $71 = ((($__k) + ($i$01$i<<2)|0) + 16|0);
           $72 = HEAP32[$71>>2]|0;
           $73 = ($70>>>0)<($72>>>0);
           if ($73) {
            break L9;
           }
           $74 = ($70>>>0)<=($72>>>0);
           $75 = (($i$01$i) + 1)|0;
           $76 = ($75|0)<($48|0);
           $or$cond2$i = $74 & $76;
           if ($or$cond2$i) {
            $i$01$i = $75;
           } else {
            label = 30;
            break L5;
           }
          }
         }
        }
       }
      }
     }
    } while(0);
    $77 = (($__nd$0$in) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ($78|0)==(0|0);
    if ($79) {
     label = 29;
     break L5;
    } else {
     $__nd$0$in = $78;
     continue L5;
    }
   }
  } while(0);
  $44 = HEAP32[$__nd$0$in>>2]|0;
  $45 = ($44|0)==(0|0);
  if ($45) {
   label = 16;
   break;
  } else {
   $__nd$0$in = $44;
  }
 }
 if ((label|0) == 16) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 29) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $77;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 30) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__13mapIN3ffp5StateEjNS1_18VertexStateCompareENS_9allocatorINS_4pairIKS2_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS6_($this,$__parent,$__k) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__k = $__k|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $68 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $68;
  $$0 = $68;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__k) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($__k) + 38|0);
 $6 = (($__k) + 36|0);
 $7 = (($__k) + 37|0);
 $8 = (($__k) + 39|0);
 $9 = (($__k) + 41|0);
 $__nd$0$in = $1;
 L5: while(1) {
  $10 = (($__nd$0$in) + 16|0);
  $11 = (($__nd$0$in) + 48|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($4>>>0)<($12>>>0);
  do {
   if (!($13)) {
    $14 = ($4>>>0)>($12>>>0);
    if (!($14)) {
     $15 = HEAP8[$5>>0]|0;
     $16 = (($10) + 38|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = ($15&255)<($17&255);
     if ($18) {
      break;
     }
     $19 = ($15&255)>($17&255);
     if (!($19)) {
      $20 = HEAP8[$6>>0]|0;
      $21 = (($__nd$0$in) + 52|0);
      $22 = HEAP8[$21>>0]|0;
      $23 = ($20&255)<($22&255);
      if ($23) {
       break;
      }
      $24 = ($20&255)>($22&255);
      if (!($24)) {
       $25 = HEAP8[$7>>0]|0;
       $26 = (($10) + 37|0);
       $27 = HEAP8[$26>>0]|0;
       $28 = ($25&255)<($27&255);
       if ($28) {
        break;
       }
       $29 = ($25&255)>($27&255);
       if (!($29)) {
        $30 = HEAP8[$8>>0]|0;
        $31 = (($10) + 39|0);
        $32 = HEAP8[$31>>0]|0;
        $33 = ($30<<24>>24)<($32<<24>>24);
        if ($33) {
         break;
        }
        $34 = ($30<<24>>24)>($32<<24>>24);
        if (!($34)) {
         $35 = HEAP8[$9>>0]|0;
         $36 = (($10) + 41|0);
         $37 = HEAP8[$36>>0]|0;
         $38 = ($35&255)<($37&255);
         if ($38) {
          break;
         }
        }
       }
      }
     }
     if (!($14)) {
      $41 = (($10) + 38|0);
      $42 = HEAP8[$41>>0]|0;
      $43 = HEAP8[$5>>0]|0;
      $44 = ($42&255)<($43&255);
      if (!($44)) {
       $45 = ($42&255)>($43&255);
       if ($45) {
        label = 28;
        break L5;
       }
       $46 = (($__nd$0$in) + 52|0);
       $47 = HEAP8[$46>>0]|0;
       $48 = HEAP8[$6>>0]|0;
       $49 = ($47&255)<($48&255);
       if (!($49)) {
        $50 = ($47&255)>($48&255);
        if ($50) {
         label = 28;
         break L5;
        }
        $51 = (($10) + 37|0);
        $52 = HEAP8[$51>>0]|0;
        $53 = HEAP8[$7>>0]|0;
        $54 = ($52&255)<($53&255);
        if (!($54)) {
         $55 = ($52&255)>($53&255);
         if ($55) {
          label = 28;
          break L5;
         }
         $56 = (($10) + 39|0);
         $57 = HEAP8[$56>>0]|0;
         $58 = HEAP8[$8>>0]|0;
         $59 = ($57<<24>>24)<($58<<24>>24);
         if (!($59)) {
          $60 = ($57<<24>>24)>($58<<24>>24);
          if ($60) {
           label = 28;
           break L5;
          }
          $61 = (($10) + 41|0);
          $62 = HEAP8[$61>>0]|0;
          $63 = HEAP8[$9>>0]|0;
          $64 = ($62&255)<($63&255);
          if (!($64)) {
           label = 28;
           break L5;
          }
         }
        }
       }
      }
     }
    }
    $65 = (($__nd$0$in) + 4|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = ($66|0)==(0|0);
    if ($67) {
     label = 27;
     break L5;
    } else {
     $__nd$0$in = $66;
     continue L5;
    }
   }
  } while(0);
  $39 = HEAP32[$__nd$0$in>>2]|0;
  $40 = ($39|0)==(0|0);
  if ($40) {
   label = 15;
   break;
  } else {
   $__nd$0$in = $39;
  }
 }
 if ((label|0) == 15) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 27) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $65;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 28) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_20FragmentStateCompareELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$ph10$i = 0, $$0$ph12$i = 0, $$01$ph11$i$in = 0, $$016$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $i$01$i$i = 0, $i$01$i$i$i = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, $or$cond2$i$i = 0, $or$cond2$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 L1: do {
  if (!($3)) {
   $4 = (($__v) + 38|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = (($__v) + 36|0);
   $7 = (($__v) + 39|0);
   $8 = (($__v) + 40|0);
   $$0$ph12$i = $2;$$01$ph11$i$in = $1;
   L3: while(1) {
    $$016$i$in = $$01$ph11$i$in;
    L5: while(1) {
     $9 = (($$016$i$in) + 54|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = ($10&255)<($5&255);
     L7: do {
      if (!($11)) {
       $12 = ($10&255)>($5&255);
       if ($12) {
        break L5;
       }
       $13 = (($$016$i$in) + 52|0);
       $14 = HEAP8[$13>>0]|0;
       $15 = $14&255;
       $16 = HEAP8[$6>>0]|0;
       $17 = ($14&255)<($16&255);
       if (!($17)) {
        $18 = ($14&255)>($16&255);
        if ($18) {
         break L5;
        }
        $19 = (($$016$i$in) + 55|0);
        $20 = HEAP8[$19>>0]|0;
        $21 = HEAP8[$7>>0]|0;
        $22 = ($20<<24>>24)<($21<<24>>24);
        if (!($22)) {
         $23 = ($20<<24>>24)>($21<<24>>24);
         if ($23) {
          break L5;
         }
         $24 = (($$016$i$in) + 56|0);
         $25 = HEAP8[$24>>0]|0;
         $26 = HEAP8[$8>>0]|0;
         $27 = ($25<<24>>24)<($26<<24>>24);
         if (!($27)) {
          $28 = ($25<<24>>24)>($26<<24>>24);
          $29 = ($14<<24>>24)==(0);
          $or$cond$i$i$i = $28 | $29;
          if ($or$cond$i$i$i) {
           break L5;
          } else {
           $i$01$i$i$i = 0;
          }
          while(1) {
           $30 = ((($$016$i$in) + ($i$01$i$i$i<<2)|0) + 16|0);
           $31 = HEAP32[$30>>2]|0;
           $32 = (($__v) + ($i$01$i$i$i<<2)|0);
           $33 = HEAP32[$32>>2]|0;
           $34 = ($31>>>0)<($33>>>0);
           if ($34) {
            break L7;
           }
           $35 = ($31>>>0)>($33>>>0);
           if ($35) {
            break L5;
           }
           $36 = ((($$016$i$in) + ($i$01$i$i$i<<2)|0) + 32|0);
           $37 = HEAP32[$36>>2]|0;
           $38 = ((($__v) + ($i$01$i$i$i<<2)|0) + 16|0);
           $39 = HEAP32[$38>>2]|0;
           $40 = ($37>>>0)<($39>>>0);
           if ($40) {
            break L7;
           }
           $41 = ($37>>>0)<=($39>>>0);
           $42 = (($i$01$i$i$i) + 1)|0;
           $43 = ($42|0)<($15|0);
           $or$cond2$i$i$i = $41 & $43;
           if ($or$cond2$i$i$i) {
            $i$01$i$i$i = $42;
           } else {
            break L5;
           }
          }
         }
        }
       }
      }
     } while(0);
     $46 = (($$016$i$in) + 4|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($47|0)==(0|0);
     if ($48) {
      $$0$ph10$i = $$0$ph12$i;
      break L3;
     } else {
      $$016$i$in = $47;
     }
    }
    $44 = HEAP32[$$016$i$in>>2]|0;
    $45 = ($44|0)==(0|0);
    if ($45) {
     $$0$ph10$i = $$016$i$in;
     break;
    } else {
     $$0$ph12$i = $$016$i$in;$$01$ph11$i$in = $44;
    }
   }
   $49 = ($$0$ph10$i|0)==($2|0);
   if (!($49)) {
    $50 = (($$0$ph10$i) + 54|0);
    $51 = HEAP8[$50>>0]|0;
    $52 = ($5&255)<($51&255);
    if (!($52)) {
     $53 = ($5&255)>($51&255);
     L25: do {
      if (!($53)) {
       $54 = HEAP8[$6>>0]|0;
       $55 = $54&255;
       $56 = (($$0$ph10$i) + 52|0);
       $57 = HEAP8[$56>>0]|0;
       $58 = ($54&255)<($57&255);
       if ($58) {
        break L1;
       }
       $59 = ($54&255)>($57&255);
       if (!($59)) {
        $60 = HEAP8[$7>>0]|0;
        $61 = (($$0$ph10$i) + 55|0);
        $62 = HEAP8[$61>>0]|0;
        $63 = ($60<<24>>24)<($62<<24>>24);
        if ($63) {
         break L1;
        }
        $64 = ($60<<24>>24)>($62<<24>>24);
        if (!($64)) {
         $65 = HEAP8[$8>>0]|0;
         $66 = (($$0$ph10$i) + 56|0);
         $67 = HEAP8[$66>>0]|0;
         $68 = ($65<<24>>24)<($67<<24>>24);
         if ($68) {
          break L1;
         }
         $69 = ($65<<24>>24)>($67<<24>>24);
         $70 = ($54<<24>>24)==(0);
         $or$cond$i$i = $69 | $70;
         if (!($or$cond$i$i)) {
          $i$01$i$i = 0;
          while(1) {
           $71 = (($__v) + ($i$01$i$i<<2)|0);
           $72 = HEAP32[$71>>2]|0;
           $73 = ((($$0$ph10$i) + ($i$01$i$i<<2)|0) + 16|0);
           $74 = HEAP32[$73>>2]|0;
           $75 = ($72>>>0)<($74>>>0);
           if ($75) {
            break L1;
           }
           $76 = ($72>>>0)>($74>>>0);
           if ($76) {
            break L25;
           }
           $77 = ((($__v) + ($i$01$i$i<<2)|0) + 16|0);
           $78 = HEAP32[$77>>2]|0;
           $79 = ((($$0$ph10$i) + ($i$01$i$i<<2)|0) + 32|0);
           $80 = HEAP32[$79>>2]|0;
           $81 = ($78>>>0)<($80>>>0);
           if ($81) {
            break L1;
           }
           $82 = ($78>>>0)<=($80>>>0);
           $83 = (($i$01$i$i) + 1)|0;
           $84 = ($83|0)<($55|0);
           $or$cond2$i$i = $82 & $84;
           if ($or$cond2$i$i) {
            $i$01$i$i = $83;
           } else {
            break;
           }
          }
         }
        }
       }
      }
     } while(0);
     HEAP32[$agg$result>>2] = $$0$ph10$i;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIN3ffp5StateEjEENS_19__map_value_compareIS3_S4_NS2_18VertexStateCompareELb1EEENS_9allocatorIS4_EEE4findIS3_EENS_15__tree_iteratorIS4_PNS_11__tree_nodeIS4_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$ph7$i = 0, $$0$ph9$i = 0, $$01$ph8$i$in = 0, $$015$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 do {
  if (!($3)) {
   $4 = (($__v) + 32|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($__v) + 38|0);
   $7 = (($__v) + 36|0);
   $8 = (($__v) + 37|0);
   $9 = (($__v) + 39|0);
   $10 = (($__v) + 41|0);
   $$0$ph9$i = $2;$$01$ph8$i$in = $1;
   L3: while(1) {
    $$015$i$in = $$01$ph8$i$in;
    while(1) {
     $11 = (($$015$i$in) + 48|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12>>>0)<($5>>>0);
     if (!($13)) {
      $14 = ($12>>>0)>($5>>>0);
      if ($14) {
       break;
      }
      $15 = (($$015$i$in) + 54|0);
      $16 = HEAP8[$15>>0]|0;
      $17 = HEAP8[$6>>0]|0;
      $18 = ($16&255)<($17&255);
      if (!($18)) {
       $19 = ($16&255)>($17&255);
       if ($19) {
        break;
       }
       $20 = (($$015$i$in) + 52|0);
       $21 = HEAP8[$20>>0]|0;
       $22 = HEAP8[$7>>0]|0;
       $23 = ($21&255)<($22&255);
       if (!($23)) {
        $24 = ($21&255)>($22&255);
        if ($24) {
         break;
        }
        $25 = (($$015$i$in) + 53|0);
        $26 = HEAP8[$25>>0]|0;
        $27 = HEAP8[$8>>0]|0;
        $28 = ($26&255)<($27&255);
        if (!($28)) {
         $29 = ($26&255)>($27&255);
         if ($29) {
          break;
         }
         $30 = (($$015$i$in) + 55|0);
         $31 = HEAP8[$30>>0]|0;
         $32 = HEAP8[$9>>0]|0;
         $33 = ($31<<24>>24)<($32<<24>>24);
         if (!($33)) {
          $34 = ($31<<24>>24)>($32<<24>>24);
          if ($34) {
           break;
          }
          $35 = (($$015$i$in) + 57|0);
          $36 = HEAP8[$35>>0]|0;
          $37 = HEAP8[$10>>0]|0;
          $38 = ($36&255)<($37&255);
          if (!($38)) {
           break;
          }
         }
        }
       }
      }
     }
     $41 = (($$015$i$in) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($42|0)==(0|0);
     if ($43) {
      $$0$ph7$i = $$0$ph9$i;
      break L3;
     } else {
      $$015$i$in = $42;
     }
    }
    $39 = HEAP32[$$015$i$in>>2]|0;
    $40 = ($39|0)==(0|0);
    if ($40) {
     $$0$ph7$i = $$015$i$in;
     break;
    } else {
     $$0$ph9$i = $$015$i$in;$$01$ph8$i$in = $39;
    }
   }
   $44 = ($$0$ph7$i|0)==($2|0);
   if (!($44)) {
    $45 = (($$0$ph7$i) + 48|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ($5>>>0)<($46>>>0);
    if (!($47)) {
     $48 = ($5>>>0)>($46>>>0);
     if (!($48)) {
      $49 = HEAP8[$6>>0]|0;
      $50 = (($$0$ph7$i) + 54|0);
      $51 = HEAP8[$50>>0]|0;
      $52 = ($49&255)<($51&255);
      if ($52) {
       break;
      }
      $53 = ($49&255)>($51&255);
      if (!($53)) {
       $54 = HEAP8[$7>>0]|0;
       $55 = (($$0$ph7$i) + 52|0);
       $56 = HEAP8[$55>>0]|0;
       $57 = ($54&255)<($56&255);
       if ($57) {
        break;
       }
       $58 = ($54&255)>($56&255);
       if (!($58)) {
        $59 = HEAP8[$8>>0]|0;
        $60 = (($$0$ph7$i) + 53|0);
        $61 = HEAP8[$60>>0]|0;
        $62 = ($59&255)<($61&255);
        if ($62) {
         break;
        }
        $63 = ($59&255)>($61&255);
        if (!($63)) {
         $64 = HEAP8[$9>>0]|0;
         $65 = (($$0$ph7$i) + 55|0);
         $66 = HEAP8[$65>>0]|0;
         $67 = ($64<<24>>24)<($66<<24>>24);
         if ($67) {
          break;
         }
         $68 = ($64<<24>>24)>($66<<24>>24);
         if (!($68)) {
          $69 = HEAP8[$10>>0]|0;
          $70 = (($$0$ph7$i) + 57|0);
          $71 = HEAP8[$70>>0]|0;
          $72 = ($69&255)<($71&255);
          if ($72) {
           break;
          }
         }
        }
       }
      }
     }
     HEAP32[$agg$result>>2] = $$0$ph7$i;
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNK17GPUSkinPoseBuffer12GetBoneCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN31TransformFeedbackSkinPoseBufferD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1149392 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_vi($5|0,($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  ___cxa_call_unexpected(($8|0));
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN31TransformFeedbackSkinPoseBufferD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1149392 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$1>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_vi($5|0,($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  ___cxa_call_unexpected(($8|0));
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN15DeviceStateGLESD2Ev($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 2164|0);
 $2 = (($this) + 2168|0);
 $3 = HEAP32[$2>>2]|0;
 __ZNSt3__16__treeI17DeviceRasterState11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($1,$3);
 $4 = (($this) + 2152|0);
 $5 = (($this) + 2156|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($4,$6);
 $7 = (($this) + 2140|0);
 $8 = (($this) + 2144|0);
 $9 = HEAP32[$8>>2]|0;
 __ZNSt3__16__treeI22DeviceStencilStateGLES11memcmp_lessIS1_18DeviceStencilStateENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($7,$9);
 $10 = (($this) + 2128|0);
 $11 = (($this) + 2132|0);
 $12 = HEAP32[$11>>2]|0;
 __ZNSt3__16__treeI20DeviceDepthStateGLES11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($10,$12);
 $13 = (($this) + 1976|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(-1);
 if (!($15)) {
  $22 = (($this) + 196|0);
  __ZN19ConstantBuffersGLESD2Ev($22);
  STACKTOP = sp;return;
 }
 $16 = (($this) + 1964|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 1968|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[$0>>2] = $19;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(2591,($17|0),($$byval_copy|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if (!($21)) {
  HEAP32[$16>>2] = 0;
  $22 = (($this) + 196|0);
  __ZN19ConstantBuffersGLESD2Ev($22);
  STACKTOP = sp;return;
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = (($this) + 196|0);
 __THREW__ = 0;
 invoke_vi(3795,($25|0));
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if ($27) {
  $28 = ___cxa_find_matching_catch(0|0)|0;
  $29 = tempRet0;
  ___clang_call_terminate($28);
  // unreachable;
 } else {
  ___resumeException($23|0);
  // unreachable;
 }
}
function __ZN19ConstantBuffersGLESD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i18 = 0;
 var $__new_last2$i$i$i$i$i2 = 0, $__new_last2$i$i$i$i$i9 = 0, $scevgep$i$i$i$i$i = 0, $scevgep$i$i$i$i$i10 = 0, $scevgep$i$i$i$i$i19 = 0, $scevgep$i$i$i$i$i3 = 0, $scevgep4$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i14 = 0, $scevgep4$i$i$i$i$i23 = 0, $scevgep4$i$i$i$i$i7 = 0, $uglygep$i$i$i$i$i = 0, $uglygep$i$i$i$i$i12 = 0, $uglygep$i$i$i$i$i21 = 0, $uglygep$i$i$i$i$i5 = 0, $uglygep3$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i13 = 0, $uglygep3$i$i$i$i$i22 = 0, $uglygep3$i$i$i$i$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(3791,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  $21 = (($this) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $24 = (($this) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)==($22|0);
   if (!($26)) {
    $__new_last2$i$i$i$i$i9 = $22;
    $scevgep$i$i$i$i$i10 = (($25) + -12|0);
    $27 = (0 - ($__new_last2$i$i$i$i$i9))|0;
    $uglygep$i$i$i$i$i12 = (($scevgep$i$i$i$i$i10) + ($27)|0);
    $uglygep3$i$i$i$i$i13 = $uglygep$i$i$i$i$i12;
    $28 = (($uglygep3$i$i$i$i$i13>>>0) / 12)&-1;
    $29 = $28 ^ -1;
    $scevgep4$i$i$i$i$i14 = (($25) + (($29*12)|0)|0);
    HEAP32[$24>>2] = $scevgep4$i$i$i$i$i14;
   }
   __ZdlPv($22);
  }
  $30 = HEAP32[$this>>2]|0;
  $31 = ($30|0)==(0|0);
  if ($31) {
   ___resumeException($19|0);
   // unreachable;
  }
  $32 = (($this) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)==($30|0);
  if (!($34)) {
   $__new_last2$i$i$i$i$i18 = $30;
   $scevgep$i$i$i$i$i19 = (($33) + -4|0);
   $35 = (0 - ($__new_last2$i$i$i$i$i18))|0;
   $uglygep$i$i$i$i$i21 = (($scevgep$i$i$i$i$i19) + ($35)|0);
   $uglygep3$i$i$i$i$i22 = $uglygep$i$i$i$i$i21;
   $36 = $uglygep3$i$i$i$i$i22 >>> 2;
   $37 = $36 ^ -1;
   $scevgep4$i$i$i$i$i23 = (($33) + ($37<<2)|0);
   HEAP32[$32>>2] = $scevgep4$i$i$i$i$i23;
  }
  __ZdlPv($30);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $2 = (($this) + 12|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = (($this) + 16|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==($3|0);
   if (!($7)) {
    $__new_last2$i$i$i$i$i = $3;
    $scevgep$i$i$i$i$i = (($6) + -12|0);
    $8 = (0 - ($__new_last2$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i = (($scevgep$i$i$i$i$i) + ($8)|0);
    $uglygep3$i$i$i$i$i = $uglygep$i$i$i$i$i;
    $9 = (($uglygep3$i$i$i$i$i>>>0) / 12)&-1;
    $10 = $9 ^ -1;
    $scevgep4$i$i$i$i$i = (($6) + (($10*12)|0)|0);
    HEAP32[$5>>2] = $scevgep4$i$i$i$i$i;
   }
   __ZdlPv($3);
  }
  $11 = HEAP32[$this>>2]|0;
  $12 = ($11|0)==(0|0);
  if ($12) {
   STACKTOP = sp;return;
  }
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==($11|0);
  if (!($15)) {
   $__new_last2$i$i$i$i$i2 = $11;
   $scevgep$i$i$i$i$i3 = (($14) + -4|0);
   $16 = (0 - ($__new_last2$i$i$i$i$i2))|0;
   $uglygep$i$i$i$i$i5 = (($scevgep$i$i$i$i$i3) + ($16)|0);
   $uglygep3$i$i$i$i$i6 = $uglygep$i$i$i$i$i5;
   $17 = $uglygep3$i$i$i$i$i6 >>> 2;
   $18 = $17 ^ -1;
   $scevgep4$i$i$i$i$i7 = (($14) + ($18<<2)|0);
   HEAP32[$13>>2] = $scevgep4$i$i$i$i$i7;
  }
  __ZdlPv($11);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeI20DeviceDepthStateGLES11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeI20DeviceDepthStateGLES11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeI20DeviceDepthStateGLES11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeI22DeviceStencilStateGLES11memcmp_lessIS1_18DeviceStencilStateENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeI22DeviceStencilStateGLES11memcmp_lessIS1_18DeviceStencilStateENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeI22DeviceStencilStateGLES11memcmp_lessIS1_18DeviceStencilStateENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeI20DeviceBlendStateGLES11memcmp_lessIS1_16DeviceBlendStateENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeI17DeviceRasterState11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeI17DeviceRasterState11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeI17DeviceRasterState11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE7destroyEPNS_11__tree_nodeIS1_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN22VertexDeclarationCacheD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1149424 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$2);
 STACKTOP = sp;return;
}
function __ZN22VertexDeclarationCacheD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1149424 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$2);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN26VertexDeclarationCacheGLESD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1149424 + 8|0));
 $0 = (($this) + 4|0);
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfoP17VertexDeclarationEENS_19__map_value_compareIS2_S5_NS_4lessIS2_EELb1EEE13stl_allocatorIS5_L18MemLabelIdentifier8ELi16EEE7destroyEPNS_11__tree_nodeIS5_PvEE($0,$2);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN26VertexDeclarationCacheGLES23CreateVertexDeclarationERK18VertexChannelsInfo($this,$key) {
 $this = $this|0;
 $key = $key|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(36,$$byval_copy,0,16,1149224,44)|0);
 HEAP32[$2>>2] = ((1149472 + 8|0));
 $3 = (($2) + 4|0);
 dest=$3+0|0; stop=dest+32|0; do { HEAP8[dest>>0]=0|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$3+0>>2]=HEAP32[$key+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$key+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$key+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$key+12>>2]|0;HEAP32[$3+16>>2]=HEAP32[$key+16>>2]|0;HEAP32[$3+20>>2]=HEAP32[$key+20>>2]|0;HEAP32[$3+24>>2]=HEAP32[$key+24>>2]|0;HEAP32[$3+28>>2]=HEAP32[$key+28>>2]|0;
 STACKTOP = sp;return ($2|0);
}
function __ZN26VertexDeclarationCacheGLES24DestroyVertexDeclarationEP17VertexDeclaration($this,$vertexDecl) {
 $this = $this|0;
 $vertexDecl = $vertexDecl|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628280>>2]|0;
 $2 = ($vertexDecl|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$vertexDecl>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_vi[$4 & 4095]($vertexDecl);
 }
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($vertexDecl,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZN21VertexDeclarationGLESD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN21VertexDeclarationGLESD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN4gles10InvalidateER20TextureUnitStateGLES($texunit) {
 $texunit = $texunit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$texunit>>2] = Math_fround(-1.0);
 $0 = (($texunit) + 4|0);
 HEAPF32[$0>>2] = Math_fround(-1.0);
 $1 = (($texunit) + 8|0);
 HEAPF32[$1>>2] = Math_fround(-1.0);
 $2 = (($texunit) + 12|0);
 HEAPF32[$2>>2] = Math_fround(-1.0);
 $3 = (($texunit) + 32|0);
 HEAPF32[$3>>2] = Math_fround(1.0E+6);
 $4 = (($texunit) + 36|0);
 HEAP32[$4>>2] = -1;
 $5 = (($texunit) + 44|0);
 HEAP32[$5>>2] = -1;
 $6 = (($texunit) + 40|0);
 HEAP32[$6>>2] = -1;
 $7 = (($texunit) + 48|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4gles14UseGLSLProgramER15DeviceStateGLESj($state,$programID) {
 $state = $state|0;
 $programID = $programID|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($state) + 1980|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($programID|0);
 if (!($2)) {
  $11 = (1147664 + 360|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vi[$12 & 4095]($programID);
  HEAP32[$0>>2] = $programID;
  $13 = (($state) + 192|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 | 7;
  HEAP32[$13>>2] = $15;
  STACKTOP = sp;return;
 }
 $3 = HEAP32[1152880>>2]|0;
 $4 = (($3) + 79|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 $7 = (1147664 + 360|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_vi[$8 & 4095](0);
 $9 = (1147664 + 360|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vi[$10 & 4095]($programID);
 STACKTOP = sp;return;
}
function __ZN4gles15ComputeFFPStateERK15DeviceStateGLESRK12GfxFogParamsPN3ffp5StateE($state,$fog,$state_ffp) {
 $state = $state|0;
 $fog = $fog|0;
 $state_ffp = $state_ffp|0;
 var $$ = 0, $$phitmp4 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $alphaTest$0 = 0, $exitcond = 0, $i$014 = 0, $i1$013 = 0, $onlyDir$0$off0$lcssa = 0, $onlyDir$0$off015 = 0, $phitmp = 0, $phitmp4 = 0, $storemerge$i10 = 0;
 var $storemerge$i12 = 0, $storemerge$i6 = 0, $storemerge$i7 = 0, $storemerge$i8 = 0, $storemerge$in$i11 = 0, $storemerge$in$i5 = 0, $storemerge$in$i9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=$state_ffp+0|0; stop=dest+44|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($state_ffp) + 38|0);
 HEAP8[$0>>0] = 0;
 $1 = (($state_ffp) + 41|0);
 HEAP8[$1>>0] = 0;
 $2 = (($state) + 2221|0);
 $3 = HEAP8[$2>>0]|0;
 HEAP8[$1>>0] = $3;
 $4 = HEAP8[$2>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $9 = 0;
 } else {
  $6 = (($state) + 2024|0);
  $7 = HEAP32[$6>>2]|0;
  $phitmp = $7&255;
  $9 = $phitmp;
 }
 $8 = (($state_ffp) + 37|0);
 HEAP8[$8>>0] = $9;
 $10 = HEAP8[$2>>0]|0;
 $11 = ($10<<24>>24)==(0);
 do {
  if ($11) {
   $43 = $3;
  } else {
   $12 = (($state) + 2024|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)>(0);
   if ($14) {
    $15 = (($state_ffp) + 32|0);
    $24 = -1;$i$014 = 0;$onlyDir$0$off015 = 1;
    while(1) {
     $16 = ((($state) + ($i$014<<2)|0) + 1992|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(1);
     $19 = $onlyDir$0$off015 & $18;
     $20 = $i$014 << 2;
     $21 = 15 << $20;
     $22 = $21 ^ -1;
     $23 = $24 & $22;
     $25 = $17 << $20;
     $26 = $23 | $25;
     $27 = (($i$014) + 1)|0;
     $exitcond = ($27|0)==($13|0);
     if ($exitcond) {
      break;
     } else {
      $24 = $26;$i$014 = $27;$onlyDir$0$off015 = $19;
     }
    }
    HEAP32[$15>>2] = $26;
    $onlyDir$0$off0$lcssa = $19;
   } else {
    $onlyDir$0$off0$lcssa = 1;
   }
   $28 = $3&255;
   $29 = $28 | 4;
   $storemerge$in$i11 = $onlyDir$0$off0$lcssa ? $29 : $28;
   $storemerge$i12 = $storemerge$in$i11&255;
   HEAP8[$1>>0] = $storemerge$i12;
   $30 = (($state) + 2222|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ($31<<24>>24)!=(0);
   $33 = $storemerge$in$i11 | 2;
   $storemerge$in$i9 = $32 ? $33 : $storemerge$in$i11;
   $storemerge$i10 = $storemerge$in$i9&255;
   HEAP8[$1>>0] = $storemerge$i10;
   $34 = (($state) + 2220|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   if ((($36|0) == 0)) {
    $43 = $storemerge$i10;
    break;
   } else if ((($36|0) == 2)) {
    $37 = $storemerge$in$i9 | 16;
    $storemerge$i8 = $37&255;
    HEAP8[$1>>0] = $storemerge$i8;
    $43 = $storemerge$i8;
    break;
   } else if ((($36|0) == 1)) {
    $38 = $storemerge$in$i9 | 32;
    $storemerge$i7 = $38&255;
    HEAP8[$1>>0] = $storemerge$i7;
    $43 = $storemerge$i7;
    break;
   } else {
    __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1149488,0,1149520,85,1,0,0,0);
    $$pre = HEAP8[$1>>0]|0;
    $43 = $$pre;
    break;
   }
  }
 } while(0);
 $39 = (($state) + 2223|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = ($40<<24>>24)==(0);
 $42 = $43&255;
 $44 = $42 & 247;
 $45 = $42 | 8;
 $storemerge$in$i5 = $41 ? $45 : $44;
 $storemerge$i6 = $storemerge$in$i5&255;
 HEAP8[$1>>0] = $storemerge$i6;
 $46 = (($state) + 1948|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ($47>>>0)>(4);
 $phitmp4 = $47&255;
 $$phitmp4 = $48 ? 4 : $phitmp4;
 $49 = (($state_ffp) + 36|0);
 HEAP8[$49>>0] = $$phitmp4;
 $50 = $$phitmp4&255;
 $51 = ($$phitmp4<<24>>24)==(0);
 if (!($51)) {
  $i1$013 = 0;
  while(1) {
   $52 = ((($state) + (($i1$013*52)|0)|0) + 332|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(4);
   $55 = 1 << $i1$013;
   $56 = $55 ^ 255;
   $57 = HEAP8[$0>>0]|0;
   $58 = $57&255;
   $59 = $58 & $56;
   $60 = $54&1;
   $61 = $60 << $i1$013;
   $62 = $59 | $61;
   $63 = $62&255;
   HEAP8[$0>>0] = $63;
   $64 = ((($state) + (($i1$013*52)|0)|0) + 324|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = (($state_ffp) + ($i1$013<<2)|0);
   HEAP32[$66>>2] = $65;
   $67 = ((($state) + (($i1$013*52)|0)|0) + 328|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ((($state_ffp) + ($i1$013<<2)|0) + 16|0);
   HEAP32[$69>>2] = $68;
   $70 = (($i1$013) + 1)|0;
   $71 = ($70|0)<($50|0);
   if ($71) {
    $i1$013 = $70;
   } else {
    break;
   }
  }
 }
 $72 = HEAP32[$fog>>2]|0;
 $73 = $72&255;
 $74 = (($state_ffp) + 39|0);
 HEAP8[$74>>0] = $73;
 $75 = HEAP32[$fog>>2]|0;
 $76 = ($75|0)==(-1);
 $$ = $76 ? 0 : $73;
 HEAP8[$74>>0] = $$;
 $77 = (($state) + 2120|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = (($78) + 10|0);
 $80 = HEAP8[$79>>0]|0;
 $81 = HEAP32[1152880>>2]|0;
 $82 = (($81) + 85|0);
 $83 = HEAP8[$82>>0]|0;
 $84 = ($83<<24>>24)==(0);
 if ($84) {
  $85 = $80 << 24 >> 24;
  if (!((($80<<24>>24) == 0) | (($80<<24>>24) == 8) | (($80<<24>>24) == -1))) {
   $alphaTest$0 = $85;
   $86 = $alphaTest$0&255;
   $87 = (($state_ffp) + 40|0);
   HEAP8[$87>>0] = $86;
   STACKTOP = sp;return;
  }
 }
 $alphaTest$0 = 0;
 $86 = $alphaTest$0&255;
 $87 = (($state_ffp) + 40|0);
 HEAP8[$87>>0] = $86;
 STACKTOP = sp;return;
}
function __ZN4gles19ActivateTextureUnitER15DeviceStateGLESj($state,$texUnit) {
 $state = $state|0;
 $texUnit = $texUnit|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1147664>>2]|0;
 $1 = (($texUnit) + 33984)|0;
 FUNCTION_TABLE_vi[$0 & 4095]($1);
 $2 = (($state) + 1952|0);
 HEAP32[$2>>2] = $texUnit;
 STACKTOP = sp;return;
}
function __ZN4gles10SetTextureER15DeviceStateGLES9TextureID16TextureDimensionj($state,$texture,$dim,$texUnit) {
 $state = $state|0;
 $texture = $texture|0;
 $dim = $dim|0;
 $texUnit = $texUnit|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $pos$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pos$i$i$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$texture>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[((599640 + 36|0))>>2]|0;
 $3 = HEAP32[((599640 + 4|0))>>2]|0;
 $4 = ($2|0)==($3|0);
 do {
  if ($4) {
   $5 = HEAP32[((599640 + 28|0))>>2]|0;
   $6 = HEAP32[((599640 + 32|0))>>2]|0;
   $7 = (($5) + ($6<<3)|0);
   $15 = $5;$16 = $6;$18 = $7;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i,599640,$0);
   $8 = HEAP32[$pos$i$i$i>>2]|0;
   $9 = ($8|0)==(-1);
   $10 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($9) {
    $11 = HEAP32[((599640 + 32|0))>>2]|0;
    $12 = (($10) + ($11<<3)|0);
    $15 = $10;$16 = $11;$18 = $12;
    break;
   } else {
    $13 = (($10) + ($8<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $15 = $10;$16 = $$pre$i;$18 = $13;
    break;
   }
  }
 } while(0);
 $14 = (($15) + ($16<<3)|0);
 $17 = ($18|0)==($14|0);
 if ($17) {
  $32 = 0;
 } else {
  $19 = (($18) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $32 = $20;
 }
 $21 = (($state) + 1952|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==($texUnit|0);
 if (!($23)) {
  $24 = HEAP32[1147664>>2]|0;
  $25 = (($texUnit) + 33984)|0;
  FUNCTION_TABLE_vi[$24 & 4095]($25);
  HEAP32[$21>>2] = $texUnit;
 }
 $26 = (($state) + 1948|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27>>>0)>($texUnit>>>0);
 if ($28) {
  $29 = ((($state) + (($texUnit*52)|0)|0) + 320|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($32|0)==($30|0);
  if ($31) {
   STACKTOP = sp;return;
  }
 } else {
  $33 = (($texUnit) + 1)|0;
  HEAP32[$26>>2] = $33;
 }
 $34 = (1147664 + 24|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (1157456 + ($dim<<2)|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$35 & 4095]($37,$32);
 $38 = ((($state) + (($texUnit*52)|0)|0) + 320|0);
 HEAP32[$38>>2] = $32;
 $39 = ((($state) + (($texUnit*52)|0)|0) + 332|0);
 HEAP32[$39>>2] = $dim;
 STACKTOP = sp;return;
}
function __ZN4gles24InvalidatePipelineStatesER15DeviceStateGLES($state) {
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 24|0;
 $1 = sp + 12|0;
 $2 = sp;
 $3 = (($state) + 2176|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($state) + 2112|0);
 HEAP32[$5>>2] = $4;
 $6 = (1147664 + 120|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vi[$7 & 4095](512);
 $8 = (1147664 + 128|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vi[$9 & 4095](2929);
 $10 = (1147664 + 124|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$11 & 4095](0);
 HEAP32[$0>>2] = 15;
 $12 = (($0) + 4|0);
 HEAP8[$12>>0] = 1;
 $13 = (($0) + 5|0);
 HEAP8[$13>>0] = 0;
 $14 = (($0) + 6|0);
 HEAP8[$14>>0] = 1;
 $15 = (($0) + 7|0);
 ;HEAP8[$15+0>>0]=0|0;HEAP8[$15+1>>0]=0|0;HEAP8[$15+2>>0]=0|0;HEAP8[$15+3>>0]=0|0;HEAP8[$15+4>>0]=0|0;
 $16 = (__ZN4gles16CreateBlendStateER15DeviceStateGLESRK13GfxBlendState($state,$0)|0);
 $17 = (($state) + 2120|0);
 HEAP32[$17>>2] = $16;
 $18 = (1147664 + 64|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_viiii[$19 & 511](1,1,1,1);
 $20 = (1147664 + 128|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_vi[$21 & 4095](3042);
 $22 = (1147664 + 32|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_viiii[$23 & 511](1,0,1,0);
 $24 = (1147664 + 28|0);
 $25 = HEAP32[$24>>2]|0;
 FUNCTION_TABLE_vii[$25 & 4095](32774,32774);
 $26 = HEAP32[1152880>>2]|0;
 $27 = (($26) + 85|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if (!($29)) {
  $30 = (1147664 + 128|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vi[$31 & 4095](3008);
 }
 HEAP8[$1>>0] = 0;
 $32 = (($1) + 1|0);
 HEAP8[$32>>0] = -1;
 $33 = (($1) + 2|0);
 HEAP8[$33>>0] = -1;
 $34 = (($1) + 4|0);
 HEAP8[$34>>0] = 8;
 $35 = (($1) + 5|0);
 HEAP8[$35>>0] = 0;
 $36 = (($1) + 6|0);
 HEAP8[$36>>0] = 0;
 $37 = (($1) + 7|0);
 HEAP8[$37>>0] = 0;
 $38 = (($1) + 8|0);
 HEAP8[$38>>0] = 8;
 $39 = (($1) + 9|0);
 HEAP8[$39>>0] = 0;
 $40 = (($1) + 10|0);
 HEAP8[$40>>0] = 0;
 $41 = (($1) + 11|0);
 HEAP8[$41>>0] = 0;
 $42 = (__ZN4gles18CreateStencilStateER15DeviceStateGLESRK15GfxStencilState($state,$1)|0);
 $43 = (($state) + 2116|0);
 HEAP32[$43>>2] = $42;
 $44 = (1147664 + 128|0);
 $45 = HEAP32[$44>>2]|0;
 FUNCTION_TABLE_vi[$45 & 4095](2960);
 $46 = (1147664 + 288|0);
 $47 = HEAP32[$46>>2]|0;
 FUNCTION_TABLE_viiii[$47 & 511](1028,519,0,255);
 $48 = (1147664 + 300|0);
 $49 = HEAP32[$48>>2]|0;
 FUNCTION_TABLE_viiii[$49 & 511](1028,7680,7680,7680);
 $50 = (1147664 + 288|0);
 $51 = HEAP32[$50>>2]|0;
 FUNCTION_TABLE_viiii[$51 & 511](1029,519,0,255);
 $52 = (1147664 + 300|0);
 $53 = HEAP32[$52>>2]|0;
 FUNCTION_TABLE_viiii[$53 & 511](1029,7680,7680,7680);
 $54 = (1147664 + 292|0);
 $55 = HEAP32[$54>>2]|0;
 FUNCTION_TABLE_vi[$55 & 4095](255);
 $56 = $2;
 $57 = $56;
 HEAP32[$57>>2] = 0;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = 0;
 HEAP32[$2>>2] = 2;
 $60 = (($2) + 4|0);
 HEAP32[$60>>2] = 0;
 $61 = (($2) + 8|0);
 HEAPF32[$61>>2] = Math_fround(0.0);
 $62 = (__ZN4gles17CreateRasterStateER15DeviceStateGLESRK14GfxRasterState($state,$2)|0);
 $63 = (($state) + 2124|0);
 HEAP32[$63>>2] = $62;
 $64 = (1147664 + 92|0);
 $65 = HEAP32[$64>>2]|0;
 FUNCTION_TABLE_vi[$65 & 4095](1029);
 $66 = (1147664 + 144|0);
 $67 = HEAP32[$66>>2]|0;
 FUNCTION_TABLE_vi[$67 & 4095](2884);
 $68 = (1147664 + 128|0);
 $69 = HEAP32[$68>>2]|0;
 FUNCTION_TABLE_vi[$69 & 4095](32823);
 $70 = (($state) + 2226|0);
 HEAP8[$70>>0] = 0;
 $71 = (1147664 + 128|0);
 $72 = HEAP32[$71>>2]|0;
 FUNCTION_TABLE_vi[$72 & 4095](3089);
 STACKTOP = sp;return;
}
function __ZN4gles10InvalidateER15DeviceStateGLES($state) {
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $i$02 = 0;
 while(1) {
  $0 = ((($state) + (($i$02*52)|0)|0) + 284|0);
  HEAPF32[$0>>2] = Math_fround(-1.0);
  $1 = ((($state) + (($i$02*52)|0)|0) + 288|0);
  HEAPF32[$1>>2] = Math_fround(-1.0);
  $2 = ((($state) + (($i$02*52)|0)|0) + 292|0);
  HEAPF32[$2>>2] = Math_fround(-1.0);
  $3 = ((($state) + (($i$02*52)|0)|0) + 296|0);
  HEAPF32[$3>>2] = Math_fround(-1.0);
  $4 = ((($state) + (($i$02*52)|0)|0) + 316|0);
  HEAPF32[$4>>2] = Math_fround(1.0E+6);
  $5 = ((($state) + (($i$02*52)|0)|0) + 320|0);
  HEAP32[$5>>2] = -1;
  $6 = ((($state) + (($i$02*52)|0)|0) + 328|0);
  HEAP32[$6>>2] = -1;
  $7 = ((($state) + (($i$02*52)|0)|0) + 324|0);
  HEAP32[$7>>2] = -1;
  $8 = ((($state) + (($i$02*52)|0)|0) + 332|0);
  HEAP32[$8>>2] = 0;
  $9 = (($i$02) + 1)|0;
  $exitcond = ($9|0)==(32);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $9;
  }
 }
 $10 = (($state) + 1948|0);
 $11 = (($state) + 1980|0);
 HEAP32[$11>>2] = 0;
 $12 = (($state) + 1972|0);
 HEAP32[$12>>2] = 0;
 $13 = (($state) + 2024|0);
 HEAP32[$13>>2] = 0;
 $14 = (($state) + 1992|0);
 ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;HEAP32[$10+12>>2]=0|0;
 HEAP32[$14>>2] = 1;
 $15 = (($state) + 1996|0);
 HEAP32[$15>>2] = 1;
 $16 = (($state) + 2000|0);
 HEAP32[$16>>2] = 1;
 $17 = (($state) + 2004|0);
 HEAP32[$17>>2] = 1;
 $18 = (($state) + 2008|0);
 HEAP32[$18>>2] = 1;
 $19 = (($state) + 2012|0);
 HEAP32[$19>>2] = 1;
 $20 = (($state) + 2016|0);
 HEAP32[$20>>2] = 1;
 $21 = (($state) + 2020|0);
 HEAP32[$21>>2] = 1;
 $22 = (($state) + 2028|0);
 HEAPF32[$22>>2] = Math_fround(-1.0);
 $23 = (($state) + 2032|0);
 HEAPF32[$23>>2] = Math_fround(-1.0);
 $24 = (($state) + 2036|0);
 HEAPF32[$24>>2] = Math_fround(-1.0);
 $25 = (($state) + 2040|0);
 HEAPF32[$25>>2] = Math_fround(-1.0);
 $26 = (($state) + 2044|0);
 HEAPF32[$26>>2] = Math_fround(-1.0);
 $27 = (($state) + 2048|0);
 HEAPF32[$27>>2] = Math_fround(-1.0);
 $28 = (($state) + 2052|0);
 HEAPF32[$28>>2] = Math_fround(-1.0);
 $29 = (($state) + 2056|0);
 HEAPF32[$29>>2] = Math_fround(-1.0);
 $30 = (($state) + 2060|0);
 HEAPF32[$30>>2] = Math_fround(-1.0);
 $31 = (($state) + 2064|0);
 HEAPF32[$31>>2] = Math_fround(-1.0);
 $32 = (($state) + 2068|0);
 HEAPF32[$32>>2] = Math_fround(-1.0);
 $33 = (($state) + 2072|0);
 HEAPF32[$33>>2] = Math_fround(-1.0);
 $34 = (($state) + 2076|0);
 HEAPF32[$34>>2] = Math_fround(-1.0);
 $35 = (($state) + 2080|0);
 HEAPF32[$35>>2] = Math_fround(-1.0);
 $36 = (($state) + 2084|0);
 HEAPF32[$36>>2] = Math_fround(-1.0);
 $37 = (($state) + 2088|0);
 HEAPF32[$37>>2] = Math_fround(-1.0);
 $38 = (($state) + 2092|0);
 HEAPF32[$38>>2] = Math_fround(-1.0);
 $39 = (($state) + 2096|0);
 HEAPF32[$39>>2] = Math_fround(-1.0);
 $40 = (($state) + 2100|0);
 HEAPF32[$40>>2] = Math_fround(-1.0);
 $41 = (($state) + 2104|0);
 HEAPF32[$41>>2] = Math_fround(-1.0);
 $42 = (($state) + 2108|0);
 HEAPF32[$42>>2] = Math_fround(-1.0);
 $43 = (($state) + 2220|0);
 HEAP8[$43>>0] = -1;
 $44 = (($state) + 2221|0);
 HEAP8[$44>>0] = 0;
 $45 = (($state) + 2222|0);
 HEAP8[$45>>0] = 0;
 $46 = (($state) + 2223|0);
 HEAP8[$46>>0] = 1;
 $47 = (($state) + 2212|0);
 HEAPF32[$47>>2] = Math_fround(-1.0);
 $48 = (($state) + 2216|0);
 HEAP32[$48>>2] = -1;
 $49 = (($state) + 2224|0);
 HEAP8[$49>>0] = -1;
 $50 = (($state) + 2225|0);
 HEAP8[$50>>0] = 0;
 __ZN4gles24InvalidatePipelineStatesER15DeviceStateGLES($state);
 STACKTOP = sp;return;
}
function __Z27BufferUpdateCausesStallGLESPK14DataBufferGLES($buffer) {
 $buffer = $buffer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$buffer>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($buffer) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($3))|0;
 $5 = ($4>>>0)<(2);
 STACKTOP = sp;return ($5|0);
}
function __ZN14DataBufferGLES7ReleaseEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __ZN17BufferManagerGLES13ReleaseBufferEP14DataBufferGLES($0,$this);
 STACKTOP = sp;return;
}
function __ZN17BufferManagerGLES13ReleaseBufferEP14DataBufferGLES($this,$buffer) {
 $this = $this|0;
 $buffer = $buffer|0;
 var $$0$i$i$i$i = 0, $$0$i2$i$i = 0, $$0$i3$i$i = 0, $$pre$i = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$buffer>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($buffer) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($3))|0;
 $5 = ($4>>>0)<(2);
 if (!($5)) {
  $6 = (($buffer) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($buffer) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $buffer;
  $11 = ((($this) + (($7*12)|0)|0) + 20|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   $22 = ((($this) + (($7*12)|0)|0) + 20|0);
   $$0$i$i$i$i = $22;$31 = $22;
  } else {
   $__nd$0$in$i$i$i$i = $12;
   while(1) {
    $14 = (($__nd$0$in$i$i$i$i) + 16|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($9|0)<($15|0);
    if ($16) {
     $17 = HEAP32[$__nd$0$in$i$i$i$i>>2]|0;
     $18 = ($17|0)==(0|0);
     if ($18) {
      $$0$i$i$i$i = $__nd$0$in$i$i$i$i;$31 = $__nd$0$in$i$i$i$i;
      break;
     } else {
      $__nd$0$in$i$i$i$i = $17;
      continue;
     }
    } else {
     $19 = (($__nd$0$in$i$i$i$i) + 4|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(0|0);
     if ($21) {
      $$0$i$i$i$i = $19;$31 = $__nd$0$in$i$i$i$i;
      break;
     } else {
      $__nd$0$in$i$i$i$i = $20;
      continue;
     }
    }
   }
  }
  $23 = (__Znwj(24)|0);
  $24 = (($23) + 16|0);
  $25 = $24;
  $26 = $25;
  HEAP32[$26>>2] = $9;
  $27 = (($25) + 4)|0;
  $28 = $27;
  HEAP32[$28>>2] = $10;
  HEAP32[$23>>2] = 0;
  $29 = (($23) + 4|0);
  HEAP32[$29>>2] = 0;
  $30 = (($23) + 8|0);
  HEAP32[$30>>2] = $31;
  HEAP32[$$0$i$i$i$i>>2] = $23;
  $32 = ((($this) + (($7*12)|0)|0) + 16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0|0);
  if ($35) {
   $37 = $23;
  } else {
   HEAP32[$32>>2] = $34;
   $$pre$i$i$i$i = HEAP32[$$0$i$i$i$i>>2]|0;
   $37 = $$pre$i$i$i$i;
  }
  $36 = HEAP32[$11>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($36,$37);
  $38 = ((($this) + (($7*12)|0)|0) + 24|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + 1)|0;
  HEAP32[$38>>2] = $40;
  STACKTOP = sp;return;
 }
 $41 = (($this) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($this) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($42|0)==($44|0);
 if (!($45)) {
  $46 = ($42|0)==(0|0);
  if ($46) {
   $48 = 0;
  } else {
   HEAP32[$42>>2] = $buffer;
   $$pre$i = HEAP32[$41>>2]|0;
   $48 = $$pre$i;
  }
  $47 = (($48) + 4|0);
  HEAP32[$41>>2] = $47;
  STACKTOP = sp;return;
 }
 $49 = (($this) + 4|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $42;
 $52 = $50;
 $53 = (($51) - ($52))|0;
 $54 = $53 >> 2;
 $55 = (($54) + 1)|0;
 $56 = ($55>>>0)>(1073741823);
 if ($56) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $57 = ($54>>>0)<(536870911);
 if ($57) {
  $58 = $53 >> 1;
  $59 = ($58>>>0)<($55>>>0);
  $60 = $59 ? $55 : $58;
  $61 = ($60|0)==(0);
  if ($61) {
   $$0$i3$i$i = 0;$65 = 0;
  } else {
   $$0$i2$i$i = $60;
   label = 18;
  }
 } else {
  $$0$i2$i$i = 1073741823;
  label = 18;
 }
 if ((label|0) == 18) {
  $62 = $$0$i2$i$i << 2;
  $63 = (__Znwj($62)|0);
  $$0$i3$i$i = $$0$i2$i$i;$65 = $63;
 }
 $64 = (($65) + ($54<<2)|0);
 $66 = (($65) + ($$0$i3$i$i<<2)|0);
 $67 = ($64|0)==(0|0);
 if (!($67)) {
  HEAP32[$64>>2] = $buffer;
 }
 $68 = (($65) + ($55<<2)|0);
 _memcpy(($65|0),($50|0),($53|0))|0;
 HEAP32[$49>>2] = $65;
 HEAP32[$41>>2] = $68;
 HEAP32[$43>>2] = $66;
 $69 = ($50|0)==(0|0);
 if ($69) {
  STACKTOP = sp;return;
 }
 __ZdlPv($50);
 STACKTOP = sp;return;
}
function __ZN14DataBufferGLES13EnsureStorageEi($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)<($size|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
 }
 $6 = (1147664 + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095]($9,$11);
 $12 = (1147664 + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$8>>2]|0;
 $15 = (($this) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_viiii[$13 & 511]($14,$size,0,$16);
 $17 = HEAP8[((640792 + 362|0))>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if (!($18)) {
  $19 = (1147664 + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_vii[$20 & 4095]($21,0);
 }
 $22 = (($this) + 8|0);
 HEAP32[$22>>2] = $size;
 $23 = HEAP32[$this>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($this) + 28|0);
 HEAP32[$25>>2] = $24;
 HEAP8[$0>>0] = 1;
 $26 = HEAP32[$10>>2]|0;
 $27 = $26 | -1073741824;
 $28 = $27;
 __Z34register_external_gfx_deallocationPvPKci($28,1149624,205);
 $29 = HEAP32[$10>>2]|0;
 $30 = $29 | -1073741824;
 $31 = $30;
 $32 = $this;
 __Z32register_external_gfx_allocationPvjjPKci($31,$size,$32,1149624,206);
 STACKTOP = sp;return;
}
function __ZN14DataBufferGLES6UploadEiiPKv($this,$offset,$size,$data) {
 $this = $this|0;
 $offset = $offset|0;
 $size = $size|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $3 = ($offset|0)==(0);
   $4 = (($this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==($size|0);
   $or$cond = $3 & $6;
   if (!($or$cond)) {
    $33 = (($this) + 8|0);
    $34 = (1147664 + 12|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = (($this) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($this) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    FUNCTION_TABLE_vii[$35 & 4095]($37,$39);
    $40 = (1147664 + 36|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = HEAP32[$36>>2]|0;
    $43 = (($this) + 20|0);
    $44 = HEAP32[$43>>2]|0;
    FUNCTION_TABLE_viiii[$41 & 511]($42,$5,0,$44);
    $45 = HEAP8[((640792 + 362|0))>>0]|0;
    $46 = ($45<<24>>24)==(0);
    if (!($46)) {
     $47 = (1147664 + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = HEAP32[$36>>2]|0;
     FUNCTION_TABLE_vii[$48 & 4095]($49,0);
    }
    HEAP32[$33>>2] = $5;
    $50 = HEAP32[$this>>2]|0;
    $51 = HEAP32[$50>>2]|0;
    $52 = (($this) + 28|0);
    HEAP32[$52>>2] = $51;
    HEAP8[$0>>0] = 1;
    $53 = HEAP32[$38>>2]|0;
    $54 = $53 | -1073741824;
    $55 = $54;
    __Z34register_external_gfx_deallocationPvPKci($55,1149624,205);
    $56 = HEAP32[$38>>2]|0;
    $57 = $56 | -1073741824;
    $58 = $57;
    $59 = $this;
    __Z32register_external_gfx_allocationPvjjPKci($58,$5,$59,1149624,206);
    break;
   }
   $7 = (1147664 + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($this) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($this) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   FUNCTION_TABLE_vii[$8 & 4095]($10,$12);
   $13 = (1147664 + 36|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = HEAP32[$9>>2]|0;
   $16 = (($this) + 20|0);
   $17 = HEAP32[$16>>2]|0;
   FUNCTION_TABLE_viiii[$14 & 511]($15,$size,$data,$17);
   $18 = HEAP8[((640792 + 362|0))>>0]|0;
   $19 = ($18<<24>>24)==(0);
   if (!($19)) {
    $20 = (1147664 + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = HEAP32[$9>>2]|0;
    FUNCTION_TABLE_vii[$21 & 4095]($22,0);
   }
   HEAP32[$4>>2] = $size;
   $23 = HEAP32[$this>>2]|0;
   $24 = HEAP32[$23>>2]|0;
   $25 = (($this) + 28|0);
   HEAP32[$25>>2] = $24;
   HEAP8[$0>>0] = 1;
   $26 = HEAP32[$11>>2]|0;
   $27 = $26 | -1073741824;
   $28 = $27;
   __Z34register_external_gfx_deallocationPvPKci($28,1149624,205);
   $29 = HEAP32[$11>>2]|0;
   $30 = $29 | -1073741824;
   $31 = $30;
   $32 = $this;
   __Z32register_external_gfx_allocationPvjjPKci($31,$size,$32,1149624,206);
   STACKTOP = sp;return;
  }
 } while(0);
 $60 = ($data|0)==(0|0);
 if (!($60)) {
  $61 = (1147664 + 12|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = (($this) + 16|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = (($this) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  FUNCTION_TABLE_vii[$62 & 4095]($64,$66);
  $67 = (1147664 + 40|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = HEAP32[$63>>2]|0;
  FUNCTION_TABLE_viiii[$68 & 511]($69,$offset,$size,$data);
  $70 = HEAP8[((640792 + 362|0))>>0]|0;
  $71 = ($70<<24>>24)==(0);
  if (!($71)) {
   $72 = (1147664 + 12|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = HEAP32[$63>>2]|0;
   FUNCTION_TABLE_vii[$73 & 4095]($74,0);
  }
 }
 $75 = HEAP32[$this>>2]|0;
 $76 = HEAP32[$75>>2]|0;
 $77 = (($this) + 32|0);
 HEAP32[$77>>2] = $76;
 STACKTOP = sp;return;
}
function __ZN14DataBufferGLES12RecordUpdateEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN14DataBufferGLES3MapEiij($this,$offset,$size,$mapBits) {
 $this = $this|0;
 $offset = $offset|0;
 $size = $size|0;
 $mapBits = $mapBits|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (1147664 + 12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($this) + 16|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($8,$10);
  $11 = (1147664 + 36|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$7>>2]|0;
  $14 = (($this) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_viiii[$12 & 511]($13,$4,0,$15);
  $16 = HEAP8[((640792 + 362|0))>>0]|0;
  $17 = ($16<<24>>24)==(0);
  if (!($17)) {
   $18 = (1147664 + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$7>>2]|0;
   FUNCTION_TABLE_vii[$19 & 4095]($20,0);
  }
  HEAP32[$3>>2] = $4;
  $21 = HEAP32[$this>>2]|0;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($this) + 28|0);
  HEAP32[$23>>2] = $22;
  HEAP8[$0>>0] = 1;
  $24 = HEAP32[$9>>2]|0;
  $25 = $24 | -1073741824;
  $26 = $25;
  __Z34register_external_gfx_deallocationPvPKci($26,1149624,205);
  $27 = HEAP32[$9>>2]|0;
  $28 = $27 | -1073741824;
  $29 = $28;
  $30 = $this;
  __Z32register_external_gfx_allocationPvjjPKci($29,$4,$30,1149624,206);
  $$pre$phi2Z2D = $9;$$pre$phiZ2D = $7;
 } else {
  $$pre = (($this) + 16|0);
  $$pre1 = (($this) + 4|0);
  $$pre$phi2Z2D = $$pre1;$$pre$phiZ2D = $$pre;
 }
 $31 = (1147664 + 12|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$$pre$phiZ2D>>2]|0;
 $34 = HEAP32[$$pre$phi2Z2D>>2]|0;
 FUNCTION_TABLE_vii[$32 & 4095]($33,$34);
 $35 = (1147664 + 428|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP32[$$pre$phiZ2D>>2]|0;
 $38 = (FUNCTION_TABLE_iiiii[$36 & 511]($37,$offset,$size,$mapBits)|0);
 $39 = HEAP8[((640792 + 362|0))>>0]|0;
 $40 = ($39<<24>>24)==(0);
 if ($40) {
  STACKTOP = sp;return ($38|0);
 }
 $41 = (1147664 + 12|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$$pre$phiZ2D>>2]|0;
 FUNCTION_TABLE_vii[$42 & 4095]($43,0);
 STACKTOP = sp;return ($38|0);
}
function __ZN14DataBufferGLES16FlushMappedRangeEii($this,$offset,$size) {
 $this = $this|0;
 $offset = $offset|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[((640792 + 358|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (1147664 + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($5,$7);
 $8 = (1147664 + 432|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viii[$9 & 4095]($10,$offset,$size);
 $11 = HEAP8[((640792 + 362|0))>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (1147664 + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($15,0);
 STACKTOP = sp;return;
}
function __ZN14DataBufferGLES5UnmapEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1147664 + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vii[$1 & 4095]($3,$5);
 $6 = (1147664 + 412|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$2>>2]|0;
 (FUNCTION_TABLE_ii[$7 & 4095]($8)|0);
 $9 = HEAP8[((640792 + 362|0))>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = (1147664 + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$2>>2]|0;
  FUNCTION_TABLE_vii[$12 & 4095]($13,0);
 }
 $14 = HEAP32[$this>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 32|0);
 HEAP32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN14DataBufferGLES12RecordRenderEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 HEAP32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __ZN17BufferManagerGLES13AcquireBufferEiN14DataBufferGLES11BufferUsageE($this,$size,$usage) {
 $this = $this|0;
 $size = $size|0;
 $usage = $usage|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i1$i = 0, $$0$ph5$i$i$i = 0, $$0$ph7$i$i$i = 0, $$01$i$i$i$i = 0, $$01$ph6$i$in$i$i = 0, $$013$i$in$i$i = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy4 = sp;
 $0 = sp + 4|0;
 $1 = ((($this) + (($usage*12)|0)|0) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($this) + (($usage*12)|0)|0) + 20|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  $$0$ph7$i$i$i = $3;$$01$ph6$i$in$i$i = $2;
  L2: while(1) {
   $$013$i$in$i$i = $$01$ph6$i$in$i$i;
   while(1) {
    $5 = (($$013$i$in$i$i) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<($size|0);
    if (!($7)) {
     break;
    }
    $10 = (($$013$i$in$i$i) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $$0$ph5$i$i$i = $$0$ph7$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i = $11;
    }
   }
   $8 = HEAP32[$$013$i$in$i$i>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $$0$ph5$i$i$i = $$013$i$in$i$i;
    break;
   } else {
    $$0$ph7$i$i$i = $$013$i$in$i$i;$$01$ph6$i$in$i$i = $8;
   }
  }
  $13 = ($$0$ph5$i$i$i|0)==($3|0);
  if (!($13)) {
   $14 = (($$0$ph5$i$i$i) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = $size << 1;
   $17 = ($15|0)<($16|0);
   if ($17) {
    $18 = (($$0$ph5$i$i$i) + 20|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($$0$ph5$i$i$i) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0|0);
    if ($22) {
     $$01$i$i$i$i = $$0$ph5$i$i$i;
     while(1) {
      $25 = (($$01$i$i$i$i) + 8|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==($$01$i$i$i$i|0);
      if ($28) {
       $$0$i$i$i$i = $26;
       break;
      } else {
       $$01$i$i$i$i = $26;
      }
     }
    } else {
     $$0$i$i$i$i$i = $21;
     while(1) {
      $23 = HEAP32[$$0$i$i$i$i$i>>2]|0;
      $24 = ($23|0)==(0|0);
      if ($24) {
       $$0$i$i$i$i = $$0$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i = $23;
      }
     }
    }
    $29 = ((($this) + (($usage*12)|0)|0) + 16|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==($$0$ph5$i$i$i|0);
    if ($31) {
     HEAP32[$29>>2] = $$0$i$i$i$i;
    }
    $32 = ((($this) + (($usage*12)|0)|0) + 24|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + -1)|0;
    HEAP32[$32>>2] = $34;
    __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($2,$$0$ph5$i$i$i);
    __ZdlPv($$0$ph5$i$i$i);
    $$0 = $19;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $35 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $35;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 $36 = (__Znwj10MemLabelIdbiPKci(40,$$byval_copy4,0,16,1149624,285)|0);
 HEAP32[$36>>2] = $this;
 $37 = (($36) + 4|0);
 HEAP32[$37>>2] = 0;
 $38 = (($36) + 8|0);
 HEAP32[$38>>2] = $size;
 $39 = (($36) + 12|0);
 HEAP32[$39>>2] = $usage;
 $40 = (($36) + 16|0);
 switch ($usage|0) {
 case 6: case 5:  {
  $$0$i$i = 35345;
  label = 20;
  break;
 }
 case 1: case 0:  {
  $$0$i$i = 34962;
  label = 20;
  break;
 }
 case 2:  {
  HEAP32[$40>>2] = 35982;
  $41 = (($36) + 20|0);
  $$0$i1$i = 35046;$47 = $41;
  label = 23;
  break;
 }
 case 4: case 3:  {
  $$0$i$i = 34963;
  label = 20;
  break;
 }
 default: {
  __THREW__ = 0;
  HEAP32[$$byval_copy4>>2] = $usage;
  invoke_vii(2587,(1149576|0),($$byval_copy4|0));
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if (!($43)) {
   $$0$i$i = 36663;
   label = 20;
  }
 }
 }
 L28: do {
  if ((label|0) == 20) {
   HEAP32[$40>>2] = $$0$i$i;
   $44 = (($36) + 20|0);
   switch ($usage|0) {
   case 6: case 4: case 1:  {
    $$0$i1$i = 35048;$47 = $44;
    label = 23;
    break L28;
    break;
   }
   case 5: case 3: case 0:  {
    $$0$i1$i = 35044;$47 = $44;
    label = 23;
    break L28;
    break;
   }
   default: {
    __THREW__ = 0;
    HEAP32[$$byval_copy4>>2] = $usage;
    invoke_vii(2587,(1149536|0),($$byval_copy4|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break L28;
    } else {
     $$0$i1$i = 35048;$47 = $44;
     label = 23;
     break L28;
    }
   }
   }
  }
 } while(0);
 if ((label|0) == 23) {
  HEAP32[$47>>2] = $$0$i1$i;
  $48 = (($36) + 24|0);
  HEAP8[$48>>0] = 0;
  $49 = (($36) + 28|0);
  HEAP32[$49>>2] = 0;
  $50 = (($36) + 32|0);
  HEAP32[$50>>2] = 0;
  $51 = (($36) + 36|0);
  HEAP32[$51>>2] = 0;
  $52 = (1147664 + 172|0);
  $53 = HEAP32[$52>>2]|0;
  __THREW__ = 0;
  invoke_vii($53|0,1,($37|0));
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if (!($55)) {
   $$0 = $36;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($36|0),($$byval_copy4|0),0,16,(1149624|0),285);
 $58 = __THREW__; __THREW__ = 0;
 $59 = $58&1;
 if ($59) {
  $60 = ___cxa_find_matching_catch(0|0)|0;
  $61 = tempRet0;
  ___clang_call_terminate($60);
  // unreachable;
 } else {
  ___resumeException($56|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN17BufferManagerGLES12AdvanceFrameEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[$this>>2] = $1;
 __ZN17BufferManagerGLES24UpdateLiveSetFromPendingEv($this);
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2>>>0) % 10)&-1;
 $4 = ($3|0)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 __ZN17BufferManagerGLES16PruneFreeBuffersEv($this);
 STACKTOP = sp;return;
}
function __ZN17BufferManagerGLES24UpdateLiveSetFromPendingEv($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$pre = 0, $$pre$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $8 = 0, $9 = 0, $__nd$0$in$i$i$i$i = 0, $__new_last2$i$i$i = 0, $bufNdx$0$ph1 = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = ($6|0)>(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = $6 >> 2;
 $76 = $8;$77 = $3;$78 = $1;$bufNdx$0$ph1 = 0;
 L4: while(1) {
  $16 = (($bufNdx$0$ph1) + 1)|0;
  $10 = $78;$12 = $77;$26 = $76;
  while(1) {
   $17 = (($12) + ($bufNdx$0$ph1<<2)|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = (($18) + 36|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) - ($22))|0;
   $24 = ($23>>>0)<(2);
   if ($24) {
    break;
   }
   $25 = ($16|0)==($26|0);
   if ($25) {
    $30 = $10;
   } else {
    $27 = (($10) + -4|0);
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$17>>2] = $28;
    HEAP32[$27>>2] = $18;
    $$pre = HEAP32[$0>>2]|0;
    $30 = $$pre;
   }
   $29 = (($30) + -4|0);
   $__new_last2$i$i$i = $29;
   $31 = (0 - ($__new_last2$i$i$i))|0;
   $uglygep$i$i$i = (($29) + ($31)|0);
   $uglygep3$i$i$i = $uglygep$i$i$i;
   $32 = $uglygep3$i$i$i >>> 2;
   $33 = $32 ^ -1;
   $scevgep4$i$i$i = (($30) + ($33<<2)|0);
   HEAP32[$0>>2] = $scevgep4$i$i$i;
   $34 = (($18) + 12|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($18) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = $18;
   $39 = ((($this) + (($35*12)|0)|0) + 20|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = ($40|0)==(0|0);
   if ($41) {
    $50 = ((($this) + (($35*12)|0)|0) + 20|0);
    $$0$i$i$i$i = $50;$59 = $50;
   } else {
    $__nd$0$in$i$i$i$i = $40;
    while(1) {
     $42 = (($__nd$0$in$i$i$i$i) + 16|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($37|0)<($43|0);
     if ($44) {
      $45 = HEAP32[$__nd$0$in$i$i$i$i>>2]|0;
      $46 = ($45|0)==(0|0);
      if ($46) {
       $$0$i$i$i$i = $__nd$0$in$i$i$i$i;$59 = $__nd$0$in$i$i$i$i;
       break;
      } else {
       $__nd$0$in$i$i$i$i = $45;
       continue;
      }
     } else {
      $47 = (($__nd$0$in$i$i$i$i) + 4|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)==(0|0);
      if ($49) {
       $$0$i$i$i$i = $47;$59 = $__nd$0$in$i$i$i$i;
       break;
      } else {
       $__nd$0$in$i$i$i$i = $48;
       continue;
      }
     }
    }
   }
   $51 = (__Znwj(24)|0);
   $52 = (($51) + 16|0);
   $53 = $52;
   $54 = $53;
   HEAP32[$54>>2] = $37;
   $55 = (($53) + 4)|0;
   $56 = $55;
   HEAP32[$56>>2] = $38;
   HEAP32[$51>>2] = 0;
   $57 = (($51) + 4|0);
   HEAP32[$57>>2] = 0;
   $58 = (($51) + 8|0);
   HEAP32[$58>>2] = $59;
   HEAP32[$$0$i$i$i$i>>2] = $51;
   $60 = ((($this) + (($35*12)|0)|0) + 16|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = HEAP32[$61>>2]|0;
   $63 = ($62|0)==(0|0);
   if ($63) {
    $65 = $51;
   } else {
    HEAP32[$60>>2] = $62;
    $$pre$i$i$i$i = HEAP32[$$0$i$i$i$i>>2]|0;
    $65 = $$pre$i$i$i$i;
   }
   $64 = HEAP32[$39>>2]|0;
   __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($64,$65);
   $66 = ((($this) + (($35*12)|0)|0) + 24|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = (($67) + 1)|0;
   HEAP32[$66>>2] = $68;
   $69 = HEAP32[$0>>2]|0;
   $70 = HEAP32[$2>>2]|0;
   $71 = $69;
   $72 = $70;
   $73 = (($71) - ($72))|0;
   $74 = $73 >> 2;
   $75 = ($bufNdx$0$ph1|0)<($74|0);
   if ($75) {
    $10 = $69;$12 = $70;$26 = $74;
   } else {
    label = 16;
    break L4;
   }
  }
  $9 = $10;
  $11 = $12;
  $13 = (($9) - ($11))|0;
  $14 = $13 >> 2;
  $15 = ($16|0)<($14|0);
  if ($15) {
   $76 = $14;$77 = $12;$78 = $10;$bufNdx$0$ph1 = $16;
  } else {
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  STACKTOP = sp;return;
 }
}
function __ZN17BufferManagerGLES16PruneFreeBuffersEv($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i15 = 0, $$0$i$i$i$i$i7 = 0, $$0$i$i$i$i11 = 0, $$0$i$i$i$i19 = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i17 = 0, $$01$i$i$i$i9 = 0, $$byval_copy = 0, $$idx$val = 0, $$idx$val$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx2 = 0, $$idx2$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0);
 var $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $usageClass$049 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $usageClass$049 = 0;
 while(1) {
  $1 = ((($this) + (($usageClass$049*12)|0)|0) + 16|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ((($this) + (($usageClass$049*12)|0)|0) + 20|0);
  $4 = ($2|0)==($3|0);
  if (!($4)) {
   $5 = ((($this) + (($usageClass$049*12)|0)|0) + 24|0);
   $6 = ((($this) + (($usageClass$049*12)|0)|0) + 20|0);
   $8 = $2;
   while(1) {
    $7 = (($8) + 20|0);
    $9 = HEAP32[$7>>2]|0;
    $$idx$val = HEAP32[$9>>2]|0;
    $$idx1 = (($9) + 8|0);
    $$idx1$val = HEAP32[$$idx1>>2]|0;
    $$idx2 = (($9) + 36|0);
    $$idx2$val = HEAP32[$$idx2>>2]|0;
    $$idx$val$idx$val = HEAP32[$$idx$val>>2]|0;
    $10 = (($$idx$val$idx$val) - ($$idx2$val))|0;
    $11 = (Math_fround(($10>>>0)));
    $12 = (Math_fround(($$idx1$val|0)));
    $13 = Math_fround($12 * Math_fround(1.66666664881631731987E-4));
    $14 = $13 < Math_fround(50.0);
    $15 = $14 ? $13 : Math_fround(50.0);
    $16 = Math_fround($11 + $15);
    $17 = !($16 >= Math_fround(59.0));
    $18 = (($8) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==(0|0);
    if ($17) {
     if ($20) {
      $$01$i$i$i$i = $8;
      while(1) {
       $48 = (($$01$i$i$i$i) + 8|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)==($$01$i$i$i$i|0);
       if ($51) {
        $$0$i$i$i$i = $49;
        break;
       } else {
        $$01$i$i$i$i = $49;
       }
      }
     } else {
      $$0$i$i$i$i$i = $19;
      while(1) {
       $46 = HEAP32[$$0$i$i$i$i$i>>2]|0;
       $47 = ($46|0)==(0|0);
       if ($47) {
        $$0$i$i$i$i = $$0$i$i$i$i$i;
        break;
       } else {
        $$0$i$i$i$i$i = $46;
       }
      }
     }
     $52 = ($$0$i$i$i$i|0)==($3|0);
     if ($52) {
      break;
     } else {
      $8 = $$0$i$i$i$i;
      continue;
     }
    }
    if ($20) {
     $$01$i$i$i$i17 = $8;
     while(1) {
      $23 = (($$01$i$i$i$i17) + 8|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25|0)==($$01$i$i$i$i17|0);
      if ($26) {
       $$0$i$i$i$i19 = $24;
       break;
      } else {
       $$01$i$i$i$i17 = $24;
      }
     }
    } else {
     $$0$i$i$i$i$i15 = $19;
     while(1) {
      $21 = HEAP32[$$0$i$i$i$i$i15>>2]|0;
      $22 = ($21|0)==(0|0);
      if ($22) {
       $$0$i$i$i$i19 = $$0$i$i$i$i$i15;
       break;
      } else {
       $$0$i$i$i$i$i15 = $21;
      }
     }
    }
    if ($20) {
     $$01$i$i$i$i9 = $8;
     while(1) {
      $29 = (($$01$i$i$i$i9) + 8|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==($$01$i$i$i$i9|0);
      if ($32) {
       $$0$i$i$i$i11 = $30;
       break;
      } else {
       $$01$i$i$i$i9 = $30;
      }
     }
    } else {
     $$0$i$i$i$i$i7 = $19;
     while(1) {
      $27 = HEAP32[$$0$i$i$i$i$i7>>2]|0;
      $28 = ($27|0)==(0|0);
      if ($28) {
       $$0$i$i$i$i11 = $$0$i$i$i$i$i7;
       break;
      } else {
       $$0$i$i$i$i$i7 = $27;
      }
     }
    }
    $33 = HEAP32[$1>>2]|0;
    $34 = ($33|0)==($8|0);
    if ($34) {
     HEAP32[$1>>2] = $$0$i$i$i$i11;
    }
    $35 = HEAP32[$5>>2]|0;
    $36 = (($35) + -1)|0;
    HEAP32[$5>>2] = $36;
    $37 = HEAP32[$6>>2]|0;
    __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($37,$8);
    __ZdlPv($8);
    $38 = HEAP32[628280>>2]|0;
    $39 = ($9|0)==(0|0);
    if (!($39)) {
     $40 = (($9) + 4|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0);
     if (!($42)) {
      $43 = (1147664 + 96|0);
      $44 = HEAP32[$43>>2]|0;
      FUNCTION_TABLE_vii[$44 & 4095](1,$40);
     }
    }
    HEAP32[$0>>2] = $38;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($9,$$byval_copy);
    $45 = ($$0$i$i$i$i19|0)==($3|0);
    if ($45) {
     break;
    } else {
     $8 = $$0$i$i$i$i19;
    }
   }
  }
  $53 = (($usageClass$049) + 1)|0;
  $exitcond = ($53|0)==(7);
  if ($exitcond) {
   break;
  } else {
   $usageClass$049 = $53;
  }
 }
 STACKTOP = sp;return;
}
function __ZN17BufferManagerGLES13InvalidateAllEv($this) {
 $this = $this|0;
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $$byval_copy1 = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $exitcond = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, $usageClass$015 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 if (!($5)) {
  $7 = $2;
  while(1) {
   $6 = HEAP32[$7>>2]|0;
   $8 = (($6) + 4|0);
   HEAP32[$8>>2] = 0;
   $9 = HEAP32[628280>>2]|0;
   HEAP32[$0>>2] = $9;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   __Z19free_alloc_internalPv10MemLabelId($6,$$byval_copy1);
   HEAP32[$7>>2] = 0;
   $10 = (($7) + 4|0);
   $11 = HEAP32[$3>>2]|0;
   $12 = ($10|0)==($11|0);
   if ($12) {
    break;
   } else {
    $7 = $10;
   }
  }
  $$pre = HEAP32[$1>>2]|0;
  $13 = ($10|0)==($$pre|0);
  if (!($13)) {
   $__new_last2$i$i$i = $$pre;
   $14 = (0 - ($__new_last2$i$i$i))|0;
   $uglygep$i$i$i = (($7) + ($14)|0);
   $uglygep3$i$i$i = $uglygep$i$i$i;
   $15 = $uglygep3$i$i$i >>> 2;
   $$sum = (0 - ($15))|0;
   $scevgep4$i$i$i = (($7) + ($$sum<<2)|0);
   HEAP32[$3>>2] = $scevgep4$i$i$i;
  }
 }
 $usageClass$015 = 0;
 while(1) {
  $16 = ((($this) + (($usageClass$015*12)|0)|0) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($this) + (($usageClass$015*12)|0)|0) + 20|0);
  $19 = ($17|0)==($18|0);
  if (!($19)) {
   $21 = $17;
   while(1) {
    $20 = (($21) + 20|0);
    $22 = HEAP32[$20>>2]|0;
    $23 = (($22) + 4|0);
    HEAP32[$23>>2] = 0;
    $24 = HEAP32[628280>>2]|0;
    HEAP32[$0>>2] = $24;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($22,$$byval_copy1);
    HEAP32[$20>>2] = 0;
    $25 = (($21) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     $$01$i$i$i$i = $21;
     while(1) {
      $30 = (($$01$i$i$i$i) + 8|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = HEAP32[$31>>2]|0;
      $33 = ($32|0)==($$01$i$i$i$i|0);
      if ($33) {
       $$0$i$i$i$i = $31;
       break;
      } else {
       $$01$i$i$i$i = $31;
      }
     }
    } else {
     $$0$i$i$i$i$i = $26;
     while(1) {
      $28 = HEAP32[$$0$i$i$i$i$i>>2]|0;
      $29 = ($28|0)==(0|0);
      if ($29) {
       $$0$i$i$i$i = $$0$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i = $28;
      }
     }
    }
    $34 = ($$0$i$i$i$i|0)==($18|0);
    if ($34) {
     break;
    } else {
     $21 = $$0$i$i$i$i;
    }
   }
  }
  $35 = ((($this) + (($usageClass$015*12)|0)|0) + 20|0);
  $36 = HEAP32[$35>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiP14DataBufferGLESEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($16,$36);
  $37 = ((($this) + (($usageClass$015*12)|0)|0) + 24|0);
  HEAP32[$37>>2] = 0;
  HEAP32[$16>>2] = $18;
  HEAP32[$18>>2] = 0;
  $38 = (($usageClass$015) + 1)|0;
  $exitcond = ($38|0)==(7);
  if ($exitcond) {
   break;
  } else {
   $usageClass$015 = $38;
  }
 }
 STACKTOP = sp;return;
}
function __Z20GetBufferManagerGLESv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[1149632>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $26 = $1;
  STACKTOP = sp;return ($26|0);
 }
 $3 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $4 = (__Znwj10MemLabelIdbiPKci(100,$$byval_copy,0,16,1149624,444)|0);
 $5 = (($4) + 20|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = (($4) + 16|0);
 HEAP32[$7>>2] = $5;
 $8 = (($4) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = (($4) + 36|0);
 HEAP32[$9>>2] = 0;
 $10 = (($4) + 28|0);
 HEAP32[$10>>2] = $8;
 $11 = (($4) + 44|0);
 HEAP32[$11>>2] = 0;
 $12 = (($4) + 48|0);
 HEAP32[$12>>2] = 0;
 $13 = (($4) + 40|0);
 HEAP32[$13>>2] = $11;
 $14 = (($4) + 56|0);
 HEAP32[$14>>2] = 0;
 $15 = (($4) + 60|0);
 HEAP32[$15>>2] = 0;
 $16 = (($4) + 52|0);
 HEAP32[$16>>2] = $14;
 $17 = (($4) + 68|0);
 HEAP32[$17>>2] = 0;
 $18 = (($4) + 72|0);
 HEAP32[$18>>2] = 0;
 $19 = (($4) + 64|0);
 HEAP32[$19>>2] = $17;
 $20 = (($4) + 80|0);
 HEAP32[$20>>2] = 0;
 $21 = (($4) + 84|0);
 HEAP32[$21>>2] = 0;
 $22 = (($4) + 76|0);
 HEAP32[$22>>2] = $20;
 $23 = (($4) + 92|0);
 HEAP32[$23>>2] = 0;
 $24 = (($4) + 96|0);
 HEAP32[$24>>2] = 0;
 $25 = (($4) + 88|0);
 HEAP32[$25>>2] = $23;
 HEAP32[1149632>>2] = $4;
 $26 = $4;
 STACKTOP = sp;return ($26|0);
}
function __ZNSt3__16__treeINS_12__value_typeIiP14DataBufferGLESEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiP14DataBufferGLESEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIiP14DataBufferGLESEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEENS_9allocatorIS4_EEE7destroyEPNS_11__tree_nodeIS4_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN17FfpGpuProgramGLESC2Ejj($this,$vertexShader,$fragmentShader) {
 $this = $this|0;
 $vertexShader = $vertexShader|0;
 $fragmentShader = $fragmentShader|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $vertexShader;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $fragmentShader;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 24|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 28|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 20|0);
 HEAP32[$6>>2] = 61;
 $7 = (($this) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = 0;
 $9 = (($this) + 44|0);
 HEAP32[$9>>2] = 0;
 $10 = (($this) + 36|0);
 HEAP32[$10>>2] = 61;
 $11 = (($this) + 48|0);
 $12 = (($this) + 68|0);
 HEAP32[$12>>2] = 0;
 $13 = (($this) + 72|0);
 HEAP32[$13>>2] = 0;
 $14 = (($this) + 64|0);
 ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;
 HEAP32[$14>>2] = 61;
 $15 = (($this) + 76|0);
 HEAP32[$15>>2] = 0;
 $16 = (($this) + 80|0);
 HEAP32[$16>>2] = 0;
 $17 = (($this) + 84|0);
 HEAP32[$17>>2] = 0;
 $18 = (($this) + 88|0);
 HEAP32[$18>>2] = -1;
 $19 = (($this) + 92|0);
 $20 = $19;
 $21 = $20;
 HEAP16[$21>>1]=0&65535;HEAP16[$21+2>>1]=0>>>16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP16[$23>>1]=0&65535;HEAP16[$23+2>>1]=0>>>16;
 $24 = (($this) + 100|0);
 HEAP32[$24>>2] = -1;
 $25 = (($this) + 104|0);
 $26 = $25;
 $27 = $26;
 HEAP16[$27>>1]=0&65535;HEAP16[$27+2>>1]=0>>>16;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP16[$29>>1]=0&65535;HEAP16[$29+2>>1]=0>>>16;
 $30 = (($this) + 112|0);
 HEAP32[$30>>2] = -1;
 $31 = (($this) + 116|0);
 $32 = $31;
 $33 = $32;
 HEAP16[$33>>1]=0&65535;HEAP16[$33+2>>1]=0>>>16;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP16[$35>>1]=0&65535;HEAP16[$35+2>>1]=0>>>16;
 $36 = (($this) + 124|0);
 HEAP32[$36>>2] = -1;
 $37 = (($this) + 128|0);
 $38 = $37;
 $39 = $38;
 HEAP16[$39>>1]=0&65535;HEAP16[$39+2>>1]=0>>>16;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP16[$41>>1]=0&65535;HEAP16[$41+2>>1]=0>>>16;
 $42 = (($this) + 136|0);
 HEAP32[$42>>2] = -1;
 $43 = (($this) + 140|0);
 $44 = $43;
 $45 = $44;
 HEAP16[$45>>1]=0&65535;HEAP16[$45+2>>1]=0>>>16;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP16[$47>>1]=0&65535;HEAP16[$47+2>>1]=0>>>16;
 $48 = (($this) + 148|0);
 HEAP32[$48>>2] = -1;
 $49 = (($this) + 152|0);
 $50 = $49;
 $51 = $50;
 HEAP16[$51>>1]=0&65535;HEAP16[$51+2>>1]=0>>>16;
 $52 = (($50) + 4)|0;
 $53 = $52;
 HEAP16[$53>>1]=0&65535;HEAP16[$53+2>>1]=0>>>16;
 $54 = (($this) + 160|0);
 HEAP32[$54>>2] = -1;
 $55 = (($this) + 164|0);
 ;HEAP16[$55+0>>1]=0|0;HEAP16[$55+2>>1]=0|0;HEAP16[$55+4>>1]=0|0;HEAP16[$55+6>>1]=0|0;HEAP16[$55+8>>1]=0|0;HEAP16[$55+10>>1]=0|0;HEAP16[$55+12>>1]=0|0;HEAP16[$55+14>>1]=0|0;
 __THREW__ = 0;
 $56 = (invoke_iiii(1637,($this|0),0,0)|0);
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if (!($58)) {
  HEAP32[$0>>2] = $56;
  $59 = HEAP32[1152880>>2]|0;
  $60 = (($59) + 67|0);
  $61 = HEAP8[$60>>0]|0;
  $62 = ($61<<24>>24)==(0);
  if ($62) {
   STACKTOP = sp;return;
  }
  $63 = (1147616 + 8|0);
  $64 = HEAP32[$63>>2]|0;
  __THREW__ = 0;
  invoke_viiii($64|0,35648,($56|0),0,(1149640|0));
  $65 = __THREW__; __THREW__ = 0;
  $66 = $65&1;
  if (!($66)) {
   STACKTOP = sp;return;
  }
 }
 $67 = ___cxa_find_matching_catch()|0;
 $68 = tempRet0;
 __THREW__ = 0;
 invoke_vi(3475,($3|0));
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $71 = ___cxa_find_matching_catch(0|0)|0;
  $72 = tempRet0;
  ___clang_call_terminate($71);
  // unreachable;
 } else {
  ___resumeException($67|0);
  // unreachable;
 }
}
function __ZN17FfpGpuProgramGLES6CreateEjj($this,$vertexShader,$fragmentShader) {
 $this = $this|0;
 $vertexShader = $vertexShader|0;
 $fragmentShader = $fragmentShader|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0;
 var $9 = 0, $exitcond = 0, $i$04 = 0, $i1$03 = 0, $i2$02 = 0, $linked = 0, $or$cond = 0, $samplerName = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $linked = sp + 16|0;
 $samplerName = sp + 4|0;
 $0 = (1147664 + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_i[$1 & 255]()|0);
 $i$04 = 0;
 while(1) {
  $3 = (1151784 + ($i$04<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[((640792 + 280|0))>>2]|0;
  $6 = ($4|0)<($5|0);
  $7 = ($4|0)>(-1);
  $or$cond = $6 & $7;
  if ($or$cond) {
   $8 = (1147664 + 8|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (1151736 + ($i$04<<2)|0);
   $11 = HEAP32[$10>>2]|0;
   FUNCTION_TABLE_viii[$9 & 4095]($2,$4,$11);
  }
  $12 = (($i$04) + 1)|0;
  $exitcond = ($12|0)==(12);
  if ($exitcond) {
   break;
  } else {
   $i$04 = $12;
  }
 }
 $13 = (1147664 + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_vii[$14 & 4095]($2,$16);
 $17 = (1147664 + 4|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 12|0);
 $20 = HEAP32[$19>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095]($2,$20);
 $21 = (1147664 + 256|0);
 $22 = HEAP32[$21>>2]|0;
 FUNCTION_TABLE_vi[$22 & 4095]($2);
 HEAP32[$linked>>2] = 0;
 $23 = (1147664 + 216|0);
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_viii[$24 & 4095]($2,35714,$linked);
 $25 = HEAP32[$linked>>2]|0;
 $26 = ($25|0)==(0);
 if ($26) {
  (__ZN18GlslGpuProgramGLES15ParseGlslErrorsEj10ShaderTypePKc($2,0,0)|0);
  $27 = (1147664 + 104|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_vi[$28 & 4095]($2);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $29 = HEAP32[1149528>>2]|0;
 __ZN4gles14UseGLSLProgramER15DeviceStateGLESj($29,$2);
 $30 = (($this) + 16|0);
 __Z18FillParamsBaseGLESjR20GpuProgramParametersP16PropertyNamesSetb($2,$30,0,0);
 $31 = (($samplerName) + 1|0);
 $32 = (($samplerName) + 8|0);
 $i1$03 = 0;
 while(1) {
  HEAP32[$vararg_buffer>>2] = $i1$03;
  __Z6FormatPKcz($samplerName,1149656,$vararg_buffer);
  $33 = (1147664 + 240|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = HEAP8[$samplerName>>0]|0;
  $36 = $35 & 1;
  $37 = ($36<<24>>24)==(0);
  $38 = HEAP32[$32>>2]|0;
  $$ = $37 ? $31 : $38;
  __THREW__ = 0;
  $39 = (invoke_iii($34|0,($2|0),($$|0))|0);
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   label = 11;
   break;
  }
  $42 = ($39|0)==(-1);
  if (!($42)) {
   $43 = (1147664 + 320|0);
   $44 = HEAP32[$43>>2]|0;
   __THREW__ = 0;
   invoke_vii($44|0,($39|0),($i1$03|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    label = 11;
    break;
   }
  }
  $53 = HEAP8[$samplerName>>0]|0;
  $54 = $53 & 1;
  $55 = ($54<<24>>24)==(0);
  if (!($55)) {
   $56 = HEAP32[$32>>2]|0;
   __ZdlPv($56);
  }
  $57 = (($i1$03) + 1)|0;
  $58 = ($57|0)<(4);
  if ($58) {
   $i1$03 = $57;
  } else {
   label = 16;
   break;
  }
 }
 if ((label|0) == 11) {
  $47 = ___cxa_find_matching_catch()|0;
  $48 = tempRet0;
  $49 = HEAP8[$samplerName>>0]|0;
  $50 = $49 & 1;
  $51 = ($50<<24>>24)==(0);
  if ($51) {
   ___resumeException($47|0);
   // unreachable;
  }
  $52 = HEAP32[$32>>2]|0;
  __ZdlPv($52);
  ___resumeException($47|0);
  // unreachable;
 }
 else if ((label|0) == 16) {
  $59 = (($this) + 80|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = (($this) + 76|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = $60;
  $64 = $62;
  $65 = (($63) - ($64))|0;
  $66 = (($65|0) / 28)&-1;
  $67 = ($65|0)>(0);
  if ($67) {
   $i2$02 = 0;
   while(1) {
    $68 = (__Z16GetRealGfxDevicev()|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($69) + 240|0);
    $71 = HEAP32[$70>>2]|0;
    $72 = HEAP32[$61>>2]|0;
    $73 = (($72) + (($i2$02*28)|0)|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ((($72) + (($i2$02*28)|0)|0) + 20|0);
    $76 = HEAP32[$75>>2]|0;
    FUNCTION_TABLE_viii[$71 & 4095]($68,$74,$76);
    $77 = (($i2$02) + 1)|0;
    $78 = ($77|0)<($66|0);
    if ($78) {
     $i2$02 = $77;
    } else {
     break;
    }
   }
  }
  __ZN16UniformCacheGLES6CreateEPK20GpuProgramParametersii($this,$30,-1,-1);
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN17FfpGpuProgramGLESD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  label = 4;
 } else {
  $3 = (1147664 + 104|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi($4|0,($1|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  __THREW__ = 0;
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = (($this) + 16|0);
   __ZN20GpuProgramParametersD2Ev($14);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $9 = (($this) + 16|0);
 __THREW__ = 0;
 invoke_vi(3475,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $15 = ___cxa_find_matching_catch(0|0)|0;
  $16 = tempRet0;
  ___clang_call_terminate($15);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZNK17FfpGpuProgramGLES19ApplyGpuProgramGLESERK24BuiltinShaderParamValuesR19ConstantBuffersGLES($this,$values,$cbs) {
 $this = $this|0;
 $values = $values|0;
 $cbs = $cbs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1149528>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN4gles14UseGLSLProgramER15DeviceStateGLESj($0,$2);
 $3 = HEAP32[1152880>>2]|0;
 $4 = (($3) + 64|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  __ZN19ConstantBuffersGLES10ResetBindsEv($cbs);
 }
 $7 = (($this) + 16|0);
 __Z19ApplyValuesBaseGLESP16UniformCacheGLESRK20GpuProgramParametersPK24BuiltinShaderParamValuesPPKh($this,$7,$values,0);
 STACKTOP = sp;return;
}
function __ZN4gles14InitBackbufferEPP17RenderSurfaceBaseS2_($outColor,$outDepth) {
 $outColor = $outColor|0;
 $outDepth = $outDepth|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__parent$i$i = 0, $__r$0$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent$i$i = sp;
 ;HEAP32[1149976+0>>2]=0|0;HEAP32[1149976+4>>2]=0|0;HEAP32[1149976+8>>2]=0|0;HEAP32[1149976+12>>2]=0|0;HEAP32[1149976+16>>2]=0|0;HEAP32[1149976+20>>2]=0|0;
 HEAP32[((1149976 + 12|0))>>2] = 1;
 HEAP8[((1149976 + 22|0))>>0] = 1;
 HEAP8[((1149976 + 23|0))>>0] = 1;
 ;HEAP32[1150016+0>>2]=0|0;HEAP32[1150016+4>>2]=0|0;HEAP32[1150016+8>>2]=0|0;HEAP32[1150016+12>>2]=0|0;HEAP32[1150016+16>>2]=0|0;HEAP32[1150016+20>>2]=0|0;
 HEAP32[((1150016 + 12|0))>>2] = 1;
 HEAP8[((1150016 + 22|0))>>0] = 0;
 HEAP8[((1150016 + 23|0))>>0] = 1;
 dest=1149816+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[1149816>>2] = 1149976;
 HEAP32[((1149816 + 32|0))>>2] = 1150016;
 HEAP32[((1149816 + 36|0))>>2] = 1;
 HEAP32[((1149816 + 40|0))>>2] = 0;
 HEAP32[((1149816 + 44|0))>>2] = -1;
 $0 = (__ZNSt3__13mapI20GfxRenderTargetSetupjNS_4lessIS1_EENS_9allocatorINS_4pairIKS1_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS6_(1150056,$__parent$i$i,1149816)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (__Znwj(92)|0);
  $4 = (($3) + 16|0);
  dest=$4+0|0; src=1149816+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $5 = (($3) + 88|0);
  HEAP32[$5>>2] = 0;
  $6 = HEAP32[$__parent$i$i>>2]|0;
  HEAP32[$3>>2] = 0;
  $7 = (($3) + 4|0);
  HEAP32[$7>>2] = 0;
  $8 = (($3) + 8|0);
  HEAP32[$8>>2] = $6;
  HEAP32[$0>>2] = $3;
  $9 = HEAP32[1150056>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $13 = $3;
  } else {
   HEAP32[1150056>>2] = $10;
   $$pre$i$i$i = HEAP32[$0>>2]|0;
   $13 = $$pre$i$i$i;
  }
  $12 = HEAP32[((1150056 + 4|0))>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($12,$13);
  $14 = HEAP32[((1150056 + 8|0))>>2]|0;
  $15 = (($14) + 1)|0;
  HEAP32[((1150056 + 8|0))>>2] = $15;
  $__r$0$i$i = $3;
 } else {
  $__r$0$i$i = $1;
 }
 $16 = (($__r$0$i$i) + 88|0);
 HEAP32[$16>>2] = 0;
 dest=1149744+0|0; src=1149816+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[1149744+68>>1]=HEAP16[1149816+68>>1]|0;
 dest=1149672+0|0; src=1149816+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[1149672+68>>1]=HEAP16[1149816+68>>1]|0;
 $17 = ($outColor|0)==(0|0);
 if (!($17)) {
  HEAP32[$outColor>>2] = 1149976;
 }
 $18 = ($outDepth|0)==(0|0);
 if ($18) {
  STACKTOP = sp;return;
 }
 HEAP32[$outDepth>>2] = 1150016;
 STACKTOP = sp;return;
}
function __ZN4gles33UpdateBackBufferFromCurrentWindowEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN4gles18FillFBOAttachmentsEP20GfxRenderTargetSetupP17RenderSurfaceBaseS3_($attach,$color,$depth) {
 $attach = $attach|0;
 $color = $color|0;
 $depth = $depth|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp;
 dest=$attach+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $2 = ($color|0)==(0|0);
 if ($2) {
  $3 = (($depth) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  HEAP32[$0>>2] = $4;
  $5 = (($0) + 4|0);
  $6 = (($depth) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$5>>2] = $7;
  $8 = (($0) + 8|0);
  $9 = (($depth) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[$8>>2] = $10;
  $11 = (($0) + 12|0);
  $12 = (($depth) + 23|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  HEAP32[$11>>2] = $14;
  $15 = (__ZN4gles18CreateDummySurfaceEbRK17RenderSurfaceDesc(1,$0)|0);
  HEAP32[$attach>>2] = $15;
  $31 = $depth;
 } else {
  HEAP32[$attach>>2] = $color;
  $16 = ($depth|0)==(0|0);
  if ($16) {
   $17 = (($color) + 4|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$1>>2] = $18;
   $19 = (($1) + 4|0);
   $20 = (($color) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   HEAP32[$19>>2] = $21;
   $22 = (($1) + 8|0);
   $23 = (($color) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$22>>2] = $24;
   $25 = (($1) + 12|0);
   $26 = (($color) + 23|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   HEAP32[$25>>2] = $28;
   $29 = (__ZN4gles18CreateDummySurfaceEbRK17RenderSurfaceDesc(0,$1)|0);
   $31 = $29;
  } else {
   $31 = $depth;
  }
 }
 $30 = (($attach) + 32|0);
 HEAP32[$30>>2] = $31;
 $32 = (($attach) + 36|0);
 HEAP32[$32>>2] = 1;
 $33 = (($attach) + 40|0);
 HEAP32[$33>>2] = 0;
 $34 = (($attach) + 44|0);
 HEAP32[$34>>2] = -1;
 STACKTOP = sp;return;
}
function __ZN4gles21GetFBOFromAttachmentsERK20GfxRenderTargetSetup($attach) {
 $attach = $attach|0;
 var $$0$i$i = 0, $$op$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i4$i$i = 0, $$pre$i6$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__r$0$i$i = 0, $colorParam$i = 0, $colorValue$i = 0, $depthParam$i = 0, $depthValue$i = 0, $exitcond$i = 0, $fb = 0, $fbi = 0, $i$010$i = 0, $i$09$i$i = 0, $mipLevel$0$i = 0, $nameCheck$i$i = 0, $nameFirst$i$i = 0, $nameInited$0$off0$lcssa$i$i = 0, $nameInited$0$off010$i$i = 0, $nameInited$1$off0$i$i = 0, $oldFbo$i = 0, $phitmp$i = 0;
 var $pos$i$i$i$i3$i$i = 0, $stencilParam$i = 0, $stencilValue$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $pos$i$i$i$i3$i$i = sp + 128|0;
 $0 = sp;
 $nameFirst$i$i = sp + 136|0;
 $nameCheck$i$i = sp + 264|0;
 $1 = sp + 80|0;
 $2 = sp + 88|0;
 $oldFbo$i = sp + 124|0;
 $colorParam$i = sp + 104|0;
 $depthParam$i = sp + 92|0;
 $stencilParam$i = sp + 108|0;
 $colorValue$i = sp + 96|0;
 $depthValue$i = sp + 100|0;
 $stencilValue$i = sp + 112|0;
 $fbi = sp + 116|0;
 $fb = sp + 120|0;
 __ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE4findIS2_EENS_15__tree_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEERKT_($fbi,1150056,$attach);
 $3 = HEAP32[$fbi>>2]|0;
 $4 = ($3|0)==(((1150056 + 4|0))|0);
 if (!($4)) {
  $233 = $3;
  $232 = (($233) + 88|0);
  $234 = HEAP32[$232>>2]|0;
  STACKTOP = sp;return ($234|0);
 }
 HEAP32[$fb>>2] = 0;
 $5 = (1147664 + 180|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_vii[$6 & 4095](1,$fb);
 $7 = HEAP32[$fb>>2]|0;
 HEAP32[$oldFbo$i>>2] = 0;
 $8 = (1147664 + 212|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095](36006,$oldFbo$i);
 $10 = (1147664 + 16|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095](36160,$7);
 $12 = (($attach) + 36|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)>(0);
 if ($14) {
  $15 = (($attach) + 40|0);
  $16 = (($attach) + 44|0);
  $i$010$i = 0;
  while(1) {
   $17 = (($i$010$i) + 36064)|0;
   $18 = (($attach) + ($i$010$i<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   HEAP32[$2>>2] = $20;
   $21 = HEAP32[((599640 + 36|0))>>2]|0;
   $22 = HEAP32[((599640 + 4|0))>>2]|0;
   $23 = ($21|0)==($22|0);
   do {
    if ($23) {
     $24 = HEAP32[((599640 + 28|0))>>2]|0;
     $25 = HEAP32[((599640 + 32|0))>>2]|0;
     $26 = (($24) + ($25<<3)|0);
     $34 = $24;$35 = $25;$37 = $26;
    } else {
     __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i$i3$i$i,599640,$2);
     $27 = HEAP32[$pos$i$i$i$i3$i$i>>2]|0;
     $28 = ($27|0)==(-1);
     $29 = HEAP32[((599640 + 28|0))>>2]|0;
     if ($28) {
      $30 = HEAP32[((599640 + 32|0))>>2]|0;
      $31 = (($29) + ($30<<3)|0);
      $34 = $29;$35 = $30;$37 = $31;
      break;
     } else {
      $32 = (($29) + ($27<<3)|0);
      $$pre$i$i = HEAP32[((599640 + 32|0))>>2]|0;
      $34 = $29;$35 = $$pre$i$i;$37 = $32;
      break;
     }
    }
   } while(0);
   $33 = (($34) + ($35<<3)|0);
   $36 = ($37|0)==($33|0);
   do {
    if ($36) {
     label = 22;
    } else {
     $38 = (($37) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0);
     if ($40) {
      label = 22;
     } else {
      $41 = (($19) + 28|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0);
      if ($43) {
       label = 22;
      } else {
       $44 = HEAP32[$15>>2]|0;
       $45 = HEAP32[1152880>>2]|0;
       $46 = (($45) + 92|0);
       $47 = HEAP8[$46>>0]|0;
       $48 = ($47<<24>>24)==(0);
       if ($48) {
        __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1150184,0,1150160,460,512,0,0,0);
        $mipLevel$0$i = 0;
       } else {
        $mipLevel$0$i = $44;
       }
       $49 = (($19) + 32|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)==(4);
       if ($51) {
        $52 = (1147664 + 164|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = HEAP32[$16>>2]|0;
        $55 = ($54|0)<(0);
        if ($55) {
         $$0$i$i = 34069;
        } else {
         $56 = ($54|0)>(5);
         $$op$i = (($54) + 34069)|0;
         $phitmp$i = $56 ? 34074 : $$op$i;
         $$0$i$i = $phitmp$i;
        }
        FUNCTION_TABLE_viiiii[$53 & 255](36160,$17,$$0$i$i,$39,$mipLevel$0$i);
        break;
       }
       $57 = (($19) + 12|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = ($58>>>0)>(1);
       if ($59) {
        $60 = HEAP32[1152880>>2]|0;
        $61 = (($60) + 90|0);
        $62 = HEAP8[$61>>0]|0;
        $63 = ($62<<24>>24)==(0);
        if (!($63)) {
         $64 = (1147616 + 16|0);
         $65 = HEAP32[$64>>2]|0;
         FUNCTION_TABLE_viiiiii[$65 & 255](36160,$17,3553,$39,$mipLevel$0$i,$58);
         break;
        }
       }
       $66 = (1147664 + 164|0);
       $67 = HEAP32[$66>>2]|0;
       FUNCTION_TABLE_viiiii[$67 & 255](36160,$17,3553,$39,$mipLevel$0$i);
      }
     }
    }
   } while(0);
   if ((label|0) == 22) {
    label = 0;
    $68 = (1147664 + 160|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($19) + 24|0);
    $71 = HEAP32[$70>>2]|0;
    FUNCTION_TABLE_viiii[$69 & 511](36160,$17,36161,$71);
   }
   $72 = (($i$010$i) + 1)|0;
   $exitcond$i = ($72|0)==($13|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$010$i = $72;
   }
  }
 }
 $73 = (($attach) + 32|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = HEAP32[$74>>2]|0;
 HEAP32[$1>>2] = $75;
 $76 = HEAP32[((599640 + 36|0))>>2]|0;
 $77 = HEAP32[((599640 + 4|0))>>2]|0;
 $78 = ($76|0)==($77|0);
 do {
  if ($78) {
   $79 = HEAP32[((599640 + 28|0))>>2]|0;
   $80 = HEAP32[((599640 + 32|0))>>2]|0;
   $81 = (($79) + ($80<<3)|0);
   $89 = $79;$90 = $80;$92 = $81;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i$i3$i$i,599640,$1);
   $82 = HEAP32[$pos$i$i$i$i3$i$i>>2]|0;
   $83 = ($82|0)==(-1);
   $84 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($83) {
    $85 = HEAP32[((599640 + 32|0))>>2]|0;
    $86 = (($84) + ($85<<3)|0);
    $89 = $84;$90 = $85;$92 = $86;
    break;
   } else {
    $87 = (($84) + ($82<<3)|0);
    $$pre$i6$i = HEAP32[((599640 + 32|0))>>2]|0;
    $89 = $84;$90 = $$pre$i6$i;$92 = $87;
    break;
   }
  }
 } while(0);
 $88 = (($89) + ($90<<3)|0);
 $91 = ($92|0)==($88|0);
 if ($91) {
  $96 = 0;
 } else {
  $93 = (($92) + 4|0);
  $94 = HEAP32[$93>>2]|0;
  $96 = $94;
 }
 $95 = ($96|0)!=(0);
 $97 = HEAP8[((640792 + 244|0))>>0]|0;
 $98 = ($97<<24>>24)==(0);
 do {
  if ($98) {
   label = 36;
  } else {
   $99 = (($74) + 28|0);
   $100 = HEAP32[$99>>2]|0;
   if ((($100|0) == 34041) | (($100|0) == 35056) | (($100|0) == 36013)) {
    if ($95) {
     $101 = (1147664 + 164|0);
     $102 = HEAP32[$101>>2]|0;
     FUNCTION_TABLE_viiiii[$102 & 255](36160,33306,3553,$96,0);
     break;
    } else {
     $103 = (1147664 + 160|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = (($74) + 24|0);
     $106 = HEAP32[$105>>2]|0;
     FUNCTION_TABLE_viiii[$104 & 511](36160,33306,36161,$106);
     break;
    }
   } else {
    label = 36;
   }
  }
 } while(0);
 do {
  if ((label|0) == 36) {
   if ($95) {
    $107 = (1147664 + 164|0);
    $108 = HEAP32[$107>>2]|0;
    FUNCTION_TABLE_viiiii[$108 & 255](36160,36096,3553,$96,0);
    $109 = (1147664 + 164|0);
    $110 = HEAP32[$109>>2]|0;
    FUNCTION_TABLE_viiiii[$110 & 255](36160,36128,3553,0,0);
    break;
   } else {
    $111 = (1147664 + 160|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = (($74) + 24|0);
    $114 = HEAP32[$113>>2]|0;
    FUNCTION_TABLE_viiii[$112 & 511](36160,36096,36161,$114);
    $115 = (1147664 + 160|0);
    $116 = HEAP32[$115>>2]|0;
    FUNCTION_TABLE_viiii[$116 & 511](36160,36128,36161,0);
    break;
   }
  }
 } while(0);
 $117 = (1147664 + 44|0);
 $118 = HEAP32[$117>>2]|0;
 $119 = (FUNCTION_TABLE_ii[$118 & 4095](36160)|0);
 $120 = ($119|0)==(36053);
 if (!($120)) {
  $121 = (1147664 + 208|0);
  $122 = HEAP32[$121>>2]|0;
  FUNCTION_TABLE_viiii[$122 & 511](36160,36064,36048,$colorParam$i);
  $123 = (1147664 + 208|0);
  $124 = HEAP32[$123>>2]|0;
  FUNCTION_TABLE_viiii[$124 & 511](36160,36096,36048,$depthParam$i);
  $125 = (1147664 + 208|0);
  $126 = HEAP32[$125>>2]|0;
  FUNCTION_TABLE_viiii[$126 & 511](36160,36128,36048,$stencilParam$i);
  $127 = (1147664 + 208|0);
  $128 = HEAP32[$127>>2]|0;
  FUNCTION_TABLE_viiii[$128 & 511](36160,36064,36049,$colorValue$i);
  $129 = (1147664 + 208|0);
  $130 = HEAP32[$129>>2]|0;
  FUNCTION_TABLE_viiii[$130 & 511](36160,36096,36049,$depthValue$i);
  $131 = (1147664 + 208|0);
  $132 = HEAP32[$131>>2]|0;
  FUNCTION_TABLE_viiii[$132 & 511](36160,36128,36049,$stencilValue$i);
 }
 $133 = HEAP32[1152880>>2]|0;
 $134 = (($133) + 67|0);
 $135 = HEAP8[$134>>0]|0;
 $136 = ($135<<24>>24)==(0);
 L61: do {
  if (!($136)) {
   $137 = HEAP32[$12>>2]|0;
   $138 = ($137|0)>(0);
   if ($138) {
    $i$09$i$i = 0;$nameInited$0$off010$i$i = 0;
    while(1) {
     $139 = (($attach) + ($i$09$i$i<<2)|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = (($140) + 16|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = $142 & 64;
     $144 = ($143|0)==(0);
     do {
      if ($144) {
       $145 = HEAP32[$140>>2]|0;
       $146 = ($145|0)==(0);
       if ($146) {
        $169 = (($140) + 24|0);
        $170 = HEAP32[$169>>2]|0;
        $171 = ($170|0)==(0);
        if (!($171)) {
         $172 = (1147616 + 12|0);
         $173 = HEAP32[$172>>2]|0;
         FUNCTION_TABLE_viiiii[$173 & 255](36161,$170,128,0,$nameCheck$i$i);
        }
       } else {
        $147 = (1147616 + 12|0);
        $148 = HEAP32[$147>>2]|0;
        HEAP32[$0>>2] = $145;
        $149 = HEAP32[((599640 + 36|0))>>2]|0;
        $150 = HEAP32[((599640 + 4|0))>>2]|0;
        $151 = ($149|0)==($150|0);
        do {
         if ($151) {
          $152 = HEAP32[((599640 + 28|0))>>2]|0;
          $153 = HEAP32[((599640 + 32|0))>>2]|0;
          $154 = (($152) + ($153<<3)|0);
          $162 = $152;$163 = $153;$165 = $154;
         } else {
          __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i$i3$i$i,599640,$0);
          $155 = HEAP32[$pos$i$i$i$i3$i$i>>2]|0;
          $156 = ($155|0)==(-1);
          $157 = HEAP32[((599640 + 28|0))>>2]|0;
          if ($156) {
           $158 = HEAP32[((599640 + 32|0))>>2]|0;
           $159 = (($157) + ($158<<3)|0);
           $162 = $157;$163 = $158;$165 = $159;
           break;
          } else {
           $160 = (($157) + ($155<<3)|0);
           $$pre$i$i$i$i = HEAP32[((599640 + 32|0))>>2]|0;
           $162 = $157;$163 = $$pre$i$i$i$i;$165 = $160;
           break;
          }
         }
        } while(0);
        $161 = (($162) + ($163<<3)|0);
        $164 = ($165|0)==($161|0);
        if ($164) {
         $168 = 0;
        } else {
         $166 = (($165) + 4|0);
         $167 = HEAP32[$166>>2]|0;
         $168 = $167;
        }
        FUNCTION_TABLE_viiiii[$148 & 255](5890,$168,128,0,$nameCheck$i$i);
       }
       if ($nameInited$0$off010$i$i) {
        $174 = (_strcmp($nameFirst$i$i,$nameCheck$i$i)|0);
        $175 = ($174|0)==(0);
        if ($175) {
         $nameInited$1$off0$i$i = 1;
         break;
        } else {
         break L61;
        }
       } else {
        dest=$nameFirst$i$i+0|0; src=$nameCheck$i$i+0|0; stop=dest+128|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
        $nameInited$1$off0$i$i = 1;
        break;
       }
      } else {
       $nameInited$1$off0$i$i = $nameInited$0$off010$i$i;
      }
     } while(0);
     $176 = (($i$09$i$i) + 1)|0;
     $177 = ($176|0)<($137|0);
     if ($177) {
      $i$09$i$i = $176;$nameInited$0$off010$i$i = $nameInited$1$off0$i$i;
     } else {
      $nameInited$0$off0$lcssa$i$i = $nameInited$1$off0$i$i;
      break;
     }
    }
   } else {
    $nameInited$0$off0$lcssa$i$i = 0;
   }
   $178 = HEAP32[$73>>2]|0;
   $179 = HEAP32[$178>>2]|0;
   $180 = ($179|0)==(0);
   if ($180) {
    $203 = (($178) + 24|0);
    $204 = HEAP32[$203>>2]|0;
    $205 = ($204|0)==(0);
    if (!($205)) {
     $206 = (1147616 + 12|0);
     $207 = HEAP32[$206>>2]|0;
     FUNCTION_TABLE_viiiii[$207 & 255](36161,$204,128,0,$nameCheck$i$i);
    }
   } else {
    $181 = (1147616 + 12|0);
    $182 = HEAP32[$181>>2]|0;
    HEAP32[$0>>2] = $179;
    $183 = HEAP32[((599640 + 36|0))>>2]|0;
    $184 = HEAP32[((599640 + 4|0))>>2]|0;
    $185 = ($183|0)==($184|0);
    do {
     if ($185) {
      $186 = HEAP32[((599640 + 28|0))>>2]|0;
      $187 = HEAP32[((599640 + 32|0))>>2]|0;
      $188 = (($186) + ($187<<3)|0);
      $196 = $186;$197 = $187;$199 = $188;
     } else {
      __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($pos$i$i$i$i3$i$i,599640,$0);
      $189 = HEAP32[$pos$i$i$i$i3$i$i>>2]|0;
      $190 = ($189|0)==(-1);
      $191 = HEAP32[((599640 + 28|0))>>2]|0;
      if ($190) {
       $192 = HEAP32[((599640 + 32|0))>>2]|0;
       $193 = (($191) + ($192<<3)|0);
       $196 = $191;$197 = $192;$199 = $193;
       break;
      } else {
       $194 = (($191) + ($189<<3)|0);
       $$pre$i$i4$i$i = HEAP32[((599640 + 32|0))>>2]|0;
       $196 = $191;$197 = $$pre$i$i4$i$i;$199 = $194;
       break;
      }
     }
    } while(0);
    $195 = (($196) + ($197<<3)|0);
    $198 = ($199|0)==($195|0);
    if ($198) {
     $202 = 0;
    } else {
     $200 = (($199) + 4|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = $201;
    }
    FUNCTION_TABLE_viiiii[$182 & 255](5890,$202,128,0,$nameCheck$i$i);
   }
   if ($nameInited$0$off0$lcssa$i$i) {
    $208 = (_strcmp($nameFirst$i$i,$nameCheck$i$i)|0);
    $209 = ($208|0)==(0);
    if (!($209)) {
     break;
    }
   }
   $210 = (1147616 + 8|0);
   $211 = HEAP32[$210>>2]|0;
   FUNCTION_TABLE_viiii[$211 & 511](36160,$7,0,$nameCheck$i$i);
  }
 } while(0);
 $212 = (1147664 + 16|0);
 $213 = HEAP32[$212>>2]|0;
 $214 = HEAP32[$oldFbo$i>>2]|0;
 FUNCTION_TABLE_vii[$213 & 4095](36160,$214);
 $215 = HEAP32[$fb>>2]|0;
 dest=$0+0|0; src=$attach+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $216 = (($0) + 72|0);
 HEAP32[$216>>2] = $215;
 $217 = (__ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESG_RKT_(1150056,$pos$i$i$i$i3$i$i,$0)|0);
 $218 = HEAP32[$217>>2]|0;
 $219 = ($218|0)==(0|0);
 if ($219) {
  $220 = (__Znwj(92)|0);
  $221 = (($220) + 16|0);
  dest=$221+0|0; src=$0+0|0; stop=dest+76|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $222 = HEAP32[$pos$i$i$i$i3$i$i>>2]|0;
  HEAP32[$220>>2] = 0;
  $223 = (($220) + 4|0);
  HEAP32[$223>>2] = 0;
  $224 = (($220) + 8|0);
  HEAP32[$224>>2] = $222;
  HEAP32[$217>>2] = $220;
  $225 = HEAP32[1150056>>2]|0;
  $226 = HEAP32[$225>>2]|0;
  $227 = ($226|0)==(0|0);
  if ($227) {
   $229 = $220;
  } else {
   HEAP32[1150056>>2] = $226;
   $$pre$i$i$i = HEAP32[$217>>2]|0;
   $229 = $$pre$i$i$i;
  }
  $228 = HEAP32[((1150056 + 4|0))>>2]|0;
  __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($228,$229);
  $230 = HEAP32[((1150056 + 8|0))>>2]|0;
  $231 = (($230) + 1)|0;
  HEAP32[((1150056 + 8|0))>>2] = $231;
  $__r$0$i$i = $220;
 } else {
  $__r$0$i$i = $218;
 }
 HEAP32[$fbi>>2] = $__r$0$i$i;
 $233 = $__r$0$i$i;
 $232 = (($233) + 88|0);
 $234 = HEAP32[$232>>2]|0;
 STACKTOP = sp;return ($234|0);
}
function __ZN4gles24PrepareDrawIntoActiveFBOEv() {
 var $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $clearColor$i = 0, $discardColor$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 24|0;
 $discardColor$i = sp + 32|0;
 $clearColor$i = sp + 8|0;
 $0 = sp;
 $1 = HEAP8[1149968>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[1149672>>2]|0;
 __ZN4gles16SetGlesFBODirectERK20GfxRenderTargetSetup(1149744);
 $4 = HEAP8[((1149672 + 52|0))>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = HEAP8[((1149672 + 68|0))>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = $6 | $4;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $10 = HEAP32[1152880>>2]|0;
  $11 = (($10) + 58|0);
  $12 = HEAP8[$11>>0]|0;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   $17 = $10;
  } else {
   $14 = $5&1;
   HEAP8[$discardColor$i>>0] = $14;
   $15 = (($discardColor$i) + 1|0);
   ;HEAP8[$15+0>>0]=0|0;HEAP8[$15+1>>0]=0|0;HEAP8[$15+2>>0]=0|0;HEAP8[$15+3>>0]=0|0;HEAP8[$15+4>>0]=0|0;HEAP8[$15+5>>0]=0|0;HEAP8[$15+6>>0]=0|0;
   __ZN4gles28InvalidateCurrentFramebufferEPbb($discardColor$i,$7);
   $$pre$i = HEAP32[1152880>>2]|0;
   $17 = $$pre$i;
  }
  $16 = (($17) + 59|0);
  $18 = HEAP8[$16>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if (!($19)) {
   ;HEAP32[$clearColor$i+0>>2]=HEAP32[1150272+0>>2]|0;HEAP32[$clearColor$i+4>>2]=HEAP32[1150272+4>>2]|0;HEAP32[$clearColor$i+8>>2]=HEAP32[1150272+8>>2]|0;HEAP32[$clearColor$i+12>>2]=HEAP32[1150272+12>>2]|0;
   __ZN4gles23ClearCurrentFramebufferEbbbPKffi($5,$7,$7,$clearColor$i,Math_fround(1.0),0);
  }
  HEAP8[((1149672 + 68|0))>>0] = 0;
  HEAP8[((1149672 + 52|0))>>0] = 0;
  $20 = HEAP32[((1149672 + 32|0))>>2]|0;
  $21 = (($20) + 20|0);
  HEAP8[$21>>0] = 0;
  $22 = HEAP32[1149672>>2]|0;
  $23 = (($22) + 20|0);
  HEAP8[$23>>0] = 0;
 }
 $24 = ($3|0)==(0|0);
 if (!($24)) {
  $25 = (($3) + 16|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26 & 130;
  $28 = ($27|0)==(130);
  if ($28) {
   $29 = (($3) + 32|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = (1157456 + ($30<<2)|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (__Z16GetRealGfxDevicev()|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($34) + 208|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = HEAP32[$3>>2]|0;
   HEAP32[$0>>2] = $37;
   $38 = HEAP32[$29>>2]|0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   FUNCTION_TABLE_viiiiiif[$36 & 1]($33,2,0,0,$$byval_copy,$38,Math_fround(inf));
   $39 = (1147664 + 176|0);
   $40 = HEAP32[$39>>2]|0;
   FUNCTION_TABLE_vi[$40 & 4095]($32);
  }
 }
 HEAP8[1149968>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN4gles12SetActiveFBOERK20GfxRenderTargetSetup($attach) {
 $attach = $attach|0;
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__r$0$i$i = 0, $discardColor$i = 0, $exitcond$i = 0, $i$01$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $discardColor$i = sp;
 $0 = HEAP8[1150168>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (1147664 + 212|0);
  $3 = HEAP32[$2>>2]|0;
  FUNCTION_TABLE_vii[$3 & 4095](36006,1150176);
  $4 = HEAP32[1150176>>2]|0;
  $5 = (__ZNSt3__13mapI20GfxRenderTargetSetupjNS_4lessIS1_EENS_9allocatorINS_4pairIKS1_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS6_(1150056,$discardColor$i,1149816)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $8 = (__Znwj(92)|0);
   $9 = (($8) + 16|0);
   dest=$9+0|0; src=1149816+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $10 = (($8) + 88|0);
   HEAP32[$10>>2] = 0;
   $11 = HEAP32[$discardColor$i>>2]|0;
   HEAP32[$8>>2] = 0;
   $12 = (($8) + 4|0);
   HEAP32[$12>>2] = 0;
   $13 = (($8) + 8|0);
   HEAP32[$13>>2] = $11;
   HEAP32[$5>>2] = $8;
   $14 = HEAP32[1150056>>2]|0;
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    $18 = $8;
   } else {
    HEAP32[1150056>>2] = $15;
    $$pre$i$i$i = HEAP32[$5>>2]|0;
    $18 = $$pre$i$i$i;
   }
   $17 = HEAP32[((1150056 + 4|0))>>2]|0;
   __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($17,$18);
   $19 = HEAP32[((1150056 + 8|0))>>2]|0;
   $20 = (($19) + 1)|0;
   HEAP32[((1150056 + 8|0))>>2] = $20;
   $__r$0$i$i = $8;
  } else {
   $__r$0$i$i = $6;
  }
  $21 = (($__r$0$i$i) + 88|0);
  HEAP32[$21>>2] = $4;
  HEAP8[1150168>>0] = 1;
 }
 $22 = $discardColor$i;
 $23 = $22;
 HEAP32[$23>>2] = 0;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = 0;
 $26 = HEAP32[((1149672 + 36|0))>>2]|0;
 $27 = ($26|0)>(0);
 if ($27) {
  $i$01$i = 0;
  while(1) {
   $28 = ((1149672 + ($i$01$i)|0) + 60|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = ($29<<24>>24)!=(0);
   $31 = (($discardColor$i) + ($i$01$i)|0);
   $32 = $30&1;
   HEAP8[$31>>0] = $32;
   $33 = (($i$01$i) + 1)|0;
   $exitcond$i = ($33|0)==($26|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $33;
   }
  }
 }
 $34 = HEAP8[((1149672 + 69|0))>>0]|0;
 $35 = ($34<<24>>24)!=(0);
 __ZN4gles28InvalidateCurrentFramebufferEPbb($discardColor$i,$35);
 dest=1149744+0|0; src=$attach+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[1149744+68>>1]=HEAP16[$attach+68>>1]|0;
 HEAP8[1149968>>0] = 0;
 HEAP32[((1149928 + 4|0))>>2] = 0;
 HEAP32[((1149928 + 20|0))>>2] = 0;
 HEAP32[((1149928 + 8|0))>>2] = 0;
 HEAP32[((1149928 + 24|0))>>2] = 0;
 $36 = HEAP32[1149744>>2]|0;
 $37 = (($36) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 HEAP32[((1149928 + 12|0))>>2] = $38;
 HEAP32[((1149928 + 28|0))>>2] = $38;
 $39 = (($36) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 HEAP32[((1149928 + 16|0))>>2] = $40;
 HEAP32[((1149928 + 32|0))>>2] = $40;
 $41 = (__ZN4gles21GetFBOFromAttachmentsERK20GfxRenderTargetSetup($attach)|0);
 HEAP32[1149928>>2] = $41;
 STACKTOP = sp;return;
}
function __ZN4gles28InvalidateCurrentFramebufferEv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $discardColor = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $discardColor = sp;
 $0 = $discardColor;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[((1149672 + 36|0))>>2]|0;
 $5 = ($4|0)>(0);
 if ($5) {
  $i$01 = 0;
  while(1) {
   $6 = ((1149672 + ($i$01)|0) + 60|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)!=(0);
   $9 = (($discardColor) + ($i$01)|0);
   $10 = $8&1;
   HEAP8[$9>>0] = $10;
   $11 = (($i$01) + 1)|0;
   $exitcond = ($11|0)==($4|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $11;
   }
  }
 }
 $12 = HEAP8[((1149672 + 69|0))>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 __ZN4gles28InvalidateCurrentFramebufferEPbb($discardColor,$13);
 STACKTOP = sp;return;
}
function __ZN4gles17SetActiveViewportERK5RectTIiE($rect) {
 $rect = $rect|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[((1149928 + 4|0))+0>>2]=HEAP32[$rect+0>>2]|0;HEAP32[((1149928 + 4|0))+4>>2]=HEAP32[$rect+4>>2]|0;HEAP32[((1149928 + 4|0))+8>>2]=HEAP32[$rect+8>>2]|0;HEAP32[((1149928 + 4|0))+12>>2]=HEAP32[$rect+12>>2]|0;
 $0 = HEAP8[1149968>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[((1149888 + 4|0))>>2]|0;
 $3 = HEAP32[((1149928 + 4|0))>>2]|0;
 $4 = ($2|0)==($3|0);
 if ($4) {
  $5 = HEAP32[((1149888 + 8|0))>>2]|0;
  $6 = HEAP32[((1149928 + 8|0))>>2]|0;
  $7 = ($5|0)==($6|0);
  if ($7) {
   $8 = HEAP32[((1149888 + 12|0))>>2]|0;
   $9 = HEAP32[((1149928 + 12|0))>>2]|0;
   $10 = ($8|0)==($9|0);
   if ($10) {
    $11 = HEAP32[((1149888 + 16|0))>>2]|0;
    $12 = HEAP32[((1149928 + 16|0))>>2]|0;
    $13 = ($11|0)==($12|0);
    if ($13) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 ;HEAP32[((1149888 + 4|0))+0>>2]=HEAP32[((1149928 + 4|0))+0>>2]|0;HEAP32[((1149888 + 4|0))+4>>2]=HEAP32[((1149928 + 4|0))+4>>2]|0;HEAP32[((1149888 + 4|0))+8>>2]=HEAP32[((1149928 + 4|0))+8>>2]|0;HEAP32[((1149888 + 4|0))+12>>2]=HEAP32[((1149928 + 4|0))+12>>2]|0;
 $14 = (1147664 + 372|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[((1149888 + 4|0))>>2]|0;
 $17 = HEAP32[((1149888 + 8|0))>>2]|0;
 $18 = HEAP32[((1149888 + 12|0))>>2]|0;
 $19 = HEAP32[((1149888 + 16|0))>>2]|0;
 FUNCTION_TABLE_viiii[$15 & 511]($16,$17,$18,$19);
 STACKTOP = sp;return;
}
function __ZN4gles16SetActiveScissorERK5RectTIiE($rect) {
 $rect = $rect|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[((1149928 + 20|0))+0>>2]=HEAP32[$rect+0>>2]|0;HEAP32[((1149928 + 20|0))+4>>2]=HEAP32[$rect+4>>2]|0;HEAP32[((1149928 + 20|0))+8>>2]=HEAP32[$rect+8>>2]|0;HEAP32[((1149928 + 20|0))+12>>2]=HEAP32[$rect+12>>2]|0;
 $0 = HEAP8[1149968>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = HEAP32[((1149888 + 20|0))>>2]|0;
 $3 = HEAP32[((1149928 + 20|0))>>2]|0;
 $4 = ($2|0)==($3|0);
 if ($4) {
  $5 = HEAP32[((1149888 + 24|0))>>2]|0;
  $6 = HEAP32[((1149928 + 24|0))>>2]|0;
  $7 = ($5|0)==($6|0);
  if ($7) {
   $8 = HEAP32[((1149888 + 28|0))>>2]|0;
   $9 = HEAP32[((1149928 + 28|0))>>2]|0;
   $10 = ($8|0)==($9|0);
   if ($10) {
    $11 = HEAP32[((1149888 + 32|0))>>2]|0;
    $12 = HEAP32[((1149928 + 32|0))>>2]|0;
    $13 = ($11|0)==($12|0);
    if ($13) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 ;HEAP32[((1149888 + 20|0))+0>>2]=HEAP32[((1149928 + 20|0))+0>>2]|0;HEAP32[((1149888 + 20|0))+4>>2]=HEAP32[((1149928 + 20|0))+4>>2]|0;HEAP32[((1149888 + 20|0))+8>>2]=HEAP32[((1149928 + 20|0))+8>>2]|0;HEAP32[((1149888 + 20|0))+12>>2]=HEAP32[((1149928 + 20|0))+12>>2]|0;
 $14 = (1147664 + 276|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[((1149888 + 20|0))>>2]|0;
 $17 = HEAP32[((1149888 + 24|0))>>2]|0;
 $18 = HEAP32[((1149888 + 28|0))>>2]|0;
 $19 = HEAP32[((1149888 + 32|0))>>2]|0;
 FUNCTION_TABLE_viiii[$15 & 511]($16,$17,$18,$19);
 STACKTOP = sp;return;
}
function __ZN4gles16SetGlesFBODirectERK20GfxRenderTargetSetup($attach) {
 $attach = $attach|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $drawBuffers = 0, $exitcond = 0, $exitcond8 = 0, $i$03 = 0, $i1$06 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $drawBuffers = sp;
 dest=1149672+0|0; src=$attach+0|0; stop=dest+68|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));HEAP16[1149672+68>>1]=HEAP16[$attach+68>>1]|0;
 $0 = HEAP32[1149928>>2]|0;
 HEAP32[1149888>>2] = $0;
 $1 = (1147664 + 16|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095](36160,$0);
 $3 = ($0|0)==(0);
 $4 = HEAP32[1152880>>2]|0;
 if ($3) {
  $5 = (($4) + 71|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(0);
  $11 = $7;
 } else {
  $11 = 0;
 }
 $8 = (($4) + 70|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 $brmerge = $10 | $11;
 if (!($brmerge)) {
  ;HEAP32[$drawBuffers+0>>2]=0|0;HEAP32[$drawBuffers+4>>2]=0|0;HEAP32[$drawBuffers+8>>2]=0|0;HEAP32[$drawBuffers+12>>2]=0|0;HEAP32[$drawBuffers+16>>2]=0|0;HEAP32[$drawBuffers+20>>2]=0|0;HEAP32[$drawBuffers+24>>2]=0|0;HEAP32[$drawBuffers+28>>2]=0|0;
  $12 = (($attach) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)>(0);
  if ($3) {
   if ($14) {
    $i$03 = 0;
    while(1) {
     $15 = (($drawBuffers) + ($i$03<<2)|0);
     HEAP32[$15>>2] = 1029;
     $16 = (($i$03) + 1)|0;
     $exitcond = ($16|0)==($13|0);
     if ($exitcond) {
      break;
     } else {
      $i$03 = $16;
     }
    }
   }
  } else {
   if ($14) {
    $i1$06 = 0;
    while(1) {
     $17 = (($attach) + ($i1$06<<2)|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + 16|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = $20 & 64;
     $22 = ($21|0)!=(0);
     $23 = (($i1$06) + 36064)|0;
     $$ = $22 ? 0 : $23;
     $24 = (($drawBuffers) + ($i1$06<<2)|0);
     HEAP32[$24>>2] = $$;
     $25 = (($i1$06) + 1)|0;
     $exitcond8 = ($25|0)==($13|0);
     if ($exitcond8) {
      break;
     } else {
      $i1$06 = $25;
     }
    }
   }
  }
  $26 = (1147664 + 416|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_vii[$27 & 4095]($13,$drawBuffers);
 }
 $28 = HEAP32[((1149888 + 4|0))>>2]|0;
 $29 = HEAP32[((1149928 + 4|0))>>2]|0;
 $30 = ($28|0)==($29|0);
 if ($30) {
  $31 = HEAP32[((1149888 + 8|0))>>2]|0;
  $32 = HEAP32[((1149928 + 8|0))>>2]|0;
  $33 = ($31|0)==($32|0);
  if ($33) {
   $34 = HEAP32[((1149888 + 12|0))>>2]|0;
   $35 = HEAP32[((1149928 + 12|0))>>2]|0;
   $36 = ($34|0)==($35|0);
   if ($36) {
    $37 = HEAP32[((1149888 + 16|0))>>2]|0;
    $38 = HEAP32[((1149928 + 16|0))>>2]|0;
    $39 = ($37|0)==($38|0);
    if (!($39)) {
     label = 14;
    }
   } else {
    label = 14;
   }
  } else {
   label = 14;
  }
 } else {
  label = 14;
 }
 if ((label|0) == 14) {
  ;HEAP32[((1149888 + 4|0))+0>>2]=HEAP32[((1149928 + 4|0))+0>>2]|0;HEAP32[((1149888 + 4|0))+4>>2]=HEAP32[((1149928 + 4|0))+4>>2]|0;HEAP32[((1149888 + 4|0))+8>>2]=HEAP32[((1149928 + 4|0))+8>>2]|0;HEAP32[((1149888 + 4|0))+12>>2]=HEAP32[((1149928 + 4|0))+12>>2]|0;
  $40 = (1147664 + 372|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = HEAP32[((1149888 + 4|0))>>2]|0;
  $43 = HEAP32[((1149888 + 8|0))>>2]|0;
  $44 = HEAP32[((1149888 + 12|0))>>2]|0;
  $45 = HEAP32[((1149888 + 16|0))>>2]|0;
  FUNCTION_TABLE_viiii[$41 & 511]($42,$43,$44,$45);
 }
 $46 = HEAP32[((1149888 + 20|0))>>2]|0;
 $47 = HEAP32[((1149928 + 20|0))>>2]|0;
 $48 = ($46|0)==($47|0);
 if ($48) {
  $49 = HEAP32[((1149888 + 24|0))>>2]|0;
  $50 = HEAP32[((1149928 + 24|0))>>2]|0;
  $51 = ($49|0)==($50|0);
  if ($51) {
   $52 = HEAP32[((1149888 + 28|0))>>2]|0;
   $53 = HEAP32[((1149928 + 28|0))>>2]|0;
   $54 = ($52|0)==($53|0);
   if ($54) {
    $55 = HEAP32[((1149888 + 32|0))>>2]|0;
    $56 = HEAP32[((1149928 + 32|0))>>2]|0;
    $57 = ($55|0)==($56|0);
    if ($57) {
     STACKTOP = sp;return;
    }
   }
  }
 }
 ;HEAP32[((1149888 + 20|0))+0>>2]=HEAP32[((1149928 + 20|0))+0>>2]|0;HEAP32[((1149888 + 20|0))+4>>2]=HEAP32[((1149928 + 20|0))+4>>2]|0;HEAP32[((1149888 + 20|0))+8>>2]=HEAP32[((1149928 + 20|0))+8>>2]|0;HEAP32[((1149888 + 20|0))+12>>2]=HEAP32[((1149928 + 20|0))+12>>2]|0;
 $58 = (1147664 + 276|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = HEAP32[((1149888 + 20|0))>>2]|0;
 $61 = HEAP32[((1149888 + 24|0))>>2]|0;
 $62 = HEAP32[((1149888 + 28|0))>>2]|0;
 $63 = HEAP32[((1149888 + 32|0))>>2]|0;
 FUNCTION_TABLE_viiii[$59 & 511]($60,$61,$62,$63);
 STACKTOP = sp;return;
}
function __ZN4gles25HandleRenderSurfaceDeleteEP17RenderSurfaceBase($rs) {
 $rs = $rs|0;
 var $$0$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i15 = 0, $$0$i$i$i$i19 = 0, $$0$i$i$i$i7 = 0, $$0$i4 = 0, $$01$i$i$i = 0, $$01$i$i$i$i = 0, $$01$i$i$i$i17 = 0, $$be$in = 0, $$lcssa29 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $curFB = 0, $exitcond = 0, $i$01$i = 0, $i$01$i2 = 0;
 var $i$01$i8 = 0, $i$030 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $curFB = sp;
 $0 = (1147664 + 212|0);
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vii[$1 & 4095](36006,$curFB);
 $2 = HEAP32[1150056>>2]|0;
 $3 = ($2|0)==(((1150056 + 4|0))|0);
 if (!($3)) {
  $5 = $2;
  while(1) {
   $4 = (($5) + 48|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = ($6|0)==($rs|0);
   $$pre = (($5) + 52|0);
   L4: do {
    if ($7) {
     label = 6;
    } else {
     $8 = HEAP32[$$pre>>2]|0;
     $9 = ($8|0)>(0);
     if ($9) {
      $i$01$i8 = 0;
      while(1) {
       $12 = ((($5) + ($i$01$i8<<2)|0) + 16|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = ($13|0)==($rs|0);
       $11 = (($i$01$i8) + 1)|0;
       if ($14) {
        label = 6;
        break L4;
       }
       $10 = ($11|0)<($8|0);
       if ($10) {
        $i$01$i8 = $11;
       } else {
        break;
       }
      }
     }
     $55 = (($5) + 4|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($56|0)==(0|0);
     if (!($57)) {
      $$0$i$i$i$i = $56;
      while(1) {
       $58 = HEAP32[$$0$i$i$i$i>>2]|0;
       $59 = ($58|0)==(0|0);
       if ($59) {
        $$be$in = $$0$i$i$i$i;
        break L4;
       } else {
        $$0$i$i$i$i = $58;
       }
      }
     }
     $$01$i$i$i = $5;
     while(1) {
      $60 = (($$01$i$i$i) + 8|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = HEAP32[$61>>2]|0;
      $63 = ($62|0)==($$01$i$i$i|0);
      if ($63) {
       $$be$in = $61;
       break;
      } else {
       $$01$i$i$i = $61;
      }
     }
    }
   } while(0);
   if ((label|0) == 6) {
    label = 0;
    $15 = (1147664 + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($5) + 88|0);
    $18 = HEAP32[$17>>2]|0;
    FUNCTION_TABLE_vii[$16 & 4095](36160,$18);
    $19 = HEAP32[$$pre>>2]|0;
    $20 = ($19|0)>(0);
    if ($20) {
     $22 = 1147664;$i$030 = 0;
     while(1) {
      $21 = (($22) + 164|0);
      $23 = HEAP32[$21>>2]|0;
      $24 = (($i$030) + 36064)|0;
      FUNCTION_TABLE_viiiii[$23 & 255](36160,$24,3553,0,0);
      $25 = (($i$030) + 1)|0;
      $exitcond = ($25|0)==($19|0);
      if ($exitcond) {
       $$lcssa29 = 1147664;
       break;
      } else {
       $22 = 1147664;$i$030 = $25;
      }
     }
    } else {
     $$lcssa29 = 1147664;
    }
    $26 = (($$lcssa29) + 160|0);
    $27 = HEAP32[$26>>2]|0;
    FUNCTION_TABLE_viiii[$27 & 511](36160,36096,36161,0);
    $28 = (1147664 + 160|0);
    $29 = HEAP32[$28>>2]|0;
    FUNCTION_TABLE_viiii[$29 & 511](36160,36128,36161,0);
    $30 = (1147664 + 16|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = HEAP32[$curFB>>2]|0;
    FUNCTION_TABLE_vii[$31 & 4095](36160,$32);
    $33 = (1147664 + 100|0);
    $34 = HEAP32[$33>>2]|0;
    FUNCTION_TABLE_vii[$34 & 4095](1,$17);
    $35 = (($5) + 4|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$01$i$i$i$i17 = $5;
     while(1) {
      $40 = (($$01$i$i$i$i17) + 8|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==($$01$i$i$i$i17|0);
      if ($43) {
       $$0$i$i$i$i19 = $41;
       break;
      } else {
       $$01$i$i$i$i17 = $41;
      }
     }
    } else {
     $$0$i$i$i$i$i15 = $36;
     while(1) {
      $38 = HEAP32[$$0$i$i$i$i$i15>>2]|0;
      $39 = ($38|0)==(0|0);
      if ($39) {
       $$0$i$i$i$i19 = $$0$i$i$i$i$i15;
       break;
      } else {
       $$0$i$i$i$i$i15 = $38;
      }
     }
    }
    if ($37) {
     $$01$i$i$i$i = $5;
     while(1) {
      $46 = (($$01$i$i$i$i) + 8|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = HEAP32[$47>>2]|0;
      $49 = ($48|0)==($$01$i$i$i$i|0);
      if ($49) {
       $$0$i$i$i$i7 = $47;
       break;
      } else {
       $$01$i$i$i$i = $47;
      }
     }
    } else {
     $$0$i$i$i$i$i = $36;
     while(1) {
      $44 = HEAP32[$$0$i$i$i$i$i>>2]|0;
      $45 = ($44|0)==(0|0);
      if ($45) {
       $$0$i$i$i$i7 = $$0$i$i$i$i$i;
       break;
      } else {
       $$0$i$i$i$i$i = $44;
      }
     }
    }
    $50 = HEAP32[1150056>>2]|0;
    $51 = ($50|0)==($5|0);
    if ($51) {
     HEAP32[1150056>>2] = $$0$i$i$i$i7;
    }
    $52 = HEAP32[((1150056 + 8|0))>>2]|0;
    $53 = (($52) + -1)|0;
    HEAP32[((1150056 + 8|0))>>2] = $53;
    $54 = HEAP32[((1150056 + 4|0))>>2]|0;
    __ZNSt3__113__tree_removeIPNS_16__tree_node_baseIPvEEEEvT_S5_($54,$5);
    __ZdlPv($5);
    $$be$in = $$0$i$i$i$i19;
   }
   $64 = ($$be$in|0)==(((1150056 + 4|0))|0);
   if ($64) {
    break;
   } else {
    $5 = $$be$in;
   }
  }
 }
 $65 = HEAP32[((1149744 + 32|0))>>2]|0;
 $66 = ($65|0)==($rs|0);
 L42: do {
  if ($66) {
   $$0$i4 = 1;
  } else {
   $67 = HEAP32[((1149744 + 36|0))>>2]|0;
   $68 = ($67|0)>(0);
   if ($68) {
    $i$01$i2 = 0;
    while(1) {
     $71 = (1149744 + ($i$01$i2<<2)|0);
     $72 = HEAP32[$71>>2]|0;
     $73 = ($72|0)==($rs|0);
     $70 = (($i$01$i2) + 1)|0;
     if ($73) {
      $$0$i4 = 1;
      break L42;
     }
     $69 = ($70|0)<($67|0);
     if ($69) {
      $i$01$i2 = $70;
     } else {
      $$0$i4 = 0;
      break;
     }
    }
   } else {
    $$0$i4 = 0;
   }
  }
 } while(0);
 $74 = HEAP32[((1149672 + 32|0))>>2]|0;
 $75 = ($74|0)==($rs|0);
 L48: do {
  if ($75) {
   $$0$i = 1;
  } else {
   $76 = HEAP32[((1149672 + 36|0))>>2]|0;
   $77 = ($76|0)>(0);
   if ($77) {
    $i$01$i = 0;
    while(1) {
     $80 = (1149672 + ($i$01$i<<2)|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = ($81|0)==($rs|0);
     $79 = (($i$01$i) + 1)|0;
     if ($82) {
      $$0$i = 1;
      break L48;
     }
     $78 = ($79|0)<($76|0);
     if ($78) {
      $i$01$i = $79;
     } else {
      $$0$i = 0;
      break;
     }
    }
   } else {
    $$0$i = 0;
   }
  }
 } while(0);
 if (!($$0$i4)) {
  if (!($$0$i)) {
   STACKTOP = sp;return;
  }
  __ZN4gles16SetGlesFBODirectERK20GfxRenderTargetSetup(1149744);
  STACKTOP = sp;return;
 }
 __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1150072,0,1150160,277,1,0,0,0);
 if ($$0$i) {
  __ZN4gles16SetGlesFBODirectERK20GfxRenderTargetSetup(1149816);
  STACKTOP = sp;return;
 } else {
  __ZN4gles12SetActiveFBOERK20GfxRenderTargetSetup(1149816);
  STACKTOP = sp;return;
 }
}
function __ZN4gles11ClearFBOMapEv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((1150056 + 4|0))>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE(1150056,$0);
 HEAP32[((1150056 + 8|0))>>2] = 0;
 HEAP32[1150056>>2] = ((1150056 + 4|0));
 HEAP32[((1150056 + 4|0))>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN4gles20HandleFBOContextLossEv() {
 var $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__parent$i$i = 0, $__r$0$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent$i$i = sp;
 $0 = HEAP32[((1150056 + 4|0))>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE(1150056,$0);
 HEAP32[((1150056 + 8|0))>>2] = 0;
 HEAP32[1150056>>2] = ((1150056 + 4|0));
 HEAP32[((1150056 + 4|0))>>2] = 0;
 HEAP8[1150168>>0] = 0;
 $1 = (1147664 + 212|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vii[$2 & 4095](36006,1150176);
 $3 = HEAP32[1150176>>2]|0;
 $4 = (__ZNSt3__13mapI20GfxRenderTargetSetupjNS_4lessIS1_EENS_9allocatorINS_4pairIKS1_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS6_(1150056,$__parent$i$i,1149816)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $__r$0$i$i = $5;
  $20 = (($__r$0$i$i) + 88|0);
  HEAP32[$20>>2] = $3;
  HEAP8[1150168>>0] = 1;
  STACKTOP = sp;return;
 }
 $7 = (__Znwj(92)|0);
 $8 = (($7) + 16|0);
 dest=$8+0|0; src=1149816+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $9 = (($7) + 88|0);
 HEAP32[$9>>2] = 0;
 $10 = HEAP32[$__parent$i$i>>2]|0;
 HEAP32[$7>>2] = 0;
 $11 = (($7) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = (($7) + 8|0);
 HEAP32[$12>>2] = $10;
 HEAP32[$4>>2] = $7;
 $13 = HEAP32[1150056>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  $17 = $7;
 } else {
  HEAP32[1150056>>2] = $14;
  $$pre$i$i$i = HEAP32[$4>>2]|0;
  $17 = $$pre$i$i$i;
 }
 $16 = HEAP32[((1150056 + 4|0))>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($16,$17);
 $18 = HEAP32[((1150056 + 8|0))>>2]|0;
 $19 = (($18) + 1)|0;
 HEAP32[((1150056 + 8|0))>>2] = $19;
 $__r$0$i$i = $7;
 $20 = (($__r$0$i$i) + 88|0);
 HEAP32[$20>>2] = $3;
 HEAP8[1150168>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE12__find_equalIS3_EERPNS_16__tree_node_baseIPvEESG_RKT_($this,$__parent,$__v) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__v = $__v|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in = 0, $i$02$i$i$i = 0, $i$02$i$i$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $64 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $64;
  $$0 = $64;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__v) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 $6 = (($__v) + 32|0);
 $7 = (($__v) + 40|0);
 $8 = (($__v) + 44|0);
 $__nd$0$in = $1;
 L5: while(1) {
  $9 = (($__nd$0$in) + 16|0);
  $10 = (($__nd$0$in) + 52|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($4|0)==($11|0);
  L7: do {
   if ($12) {
    L9: do {
     if ($5) {
      $i$02$i$i$i2 = 0;
      while(1) {
       $16 = (($__v) + ($i$02$i$i$i2<<2)|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = (($9) + ($i$02$i$i$i2<<2)|0);
       $19 = HEAP32[$18>>2]|0;
       $20 = ($17|0)==($19|0);
       $15 = (($i$02$i$i$i2) + 1)|0;
       if (!($20)) {
        break;
       }
       $14 = ($15|0)<($4|0);
       if ($14) {
        $i$02$i$i$i2 = $15;
       } else {
        label = 9;
        break L9;
       }
      }
      $21 = ($17>>>0)<($19>>>0);
      if ($21) {
       label = 14;
       break L7;
      }
     } else {
      label = 9;
     }
    } while(0);
    do {
     if ((label|0) == 9) {
      label = 0;
      $22 = HEAP32[$6>>2]|0;
      $23 = (($__nd$0$in) + 48|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($22|0)==($24|0);
      if (!($25)) {
       $26 = ($22>>>0)<($24>>>0);
       if ($26) {
        label = 14;
        break L7;
       } else {
        break;
       }
      }
      $27 = HEAP32[$7>>2]|0;
      $28 = (($__nd$0$in) + 56|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($27|0)==($29|0);
      if ($30) {
       $31 = HEAP32[$8>>2]|0;
       $32 = (($__nd$0$in) + 60|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = ($31|0)<($33|0);
       if ($34) {
        label = 14;
        break L7;
       } else {
        break;
       }
      } else {
       $35 = ($27>>>0)<($29>>>0);
       if ($35) {
        label = 14;
        break L7;
       } else {
        break;
       }
      }
     }
    } while(0);
    if ($12) {
     L24: do {
      if ($5) {
       $i$02$i$i$i = 0;
       while(1) {
        $41 = (($9) + ($i$02$i$i$i<<2)|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = (($__v) + ($i$02$i$i$i<<2)|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = ($42|0)==($44|0);
        $40 = (($i$02$i$i$i) + 1)|0;
        if (!($45)) {
         break;
        }
        $39 = ($40|0)<($4|0);
        if ($39) {
         $i$02$i$i$i = $40;
        } else {
         break L24;
        }
       }
       $46 = ($42>>>0)<($44>>>0);
       if ($46) {
        break L7;
       } else {
        label = 29;
        break L5;
       }
      }
     } while(0);
     $47 = (($__nd$0$in) + 48|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = HEAP32[$6>>2]|0;
     $50 = ($48|0)==($49|0);
     if (!($50)) {
      $51 = ($48>>>0)<($49>>>0);
      if ($51) {
       break;
      } else {
       label = 29;
       break L5;
      }
     }
     $52 = (($__nd$0$in) + 56|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = HEAP32[$7>>2]|0;
     $55 = ($53|0)==($54|0);
     if ($55) {
      $56 = (($__nd$0$in) + 60|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = HEAP32[$8>>2]|0;
      $59 = ($57|0)<($58|0);
      if ($59) {
       break;
      } else {
       label = 29;
       break L5;
      }
     } else {
      $60 = ($53>>>0)<($54>>>0);
      if ($60) {
       break;
      } else {
       label = 29;
       break L5;
      }
     }
    } else {
     label = 18;
    }
   } else {
    $13 = ($4>>>0)<($11>>>0);
    if ($13) {
     label = 14;
    } else {
     label = 18;
    }
   }
  } while(0);
  if ((label|0) == 14) {
   label = 0;
   $36 = HEAP32[$__nd$0$in>>2]|0;
   $37 = ($36|0)==(0|0);
   if ($37) {
    label = 15;
    break;
   } else {
    $__nd$0$in = $36;
    continue;
   }
  }
  else if ((label|0) == 18) {
   label = 0;
   $38 = ($11>>>0)<($4>>>0);
   if (!($38)) {
    label = 29;
    break;
   }
  }
  $61 = (($__nd$0$in) + 4|0);
  $62 = HEAP32[$61>>2]|0;
  $63 = ($62|0)==(0|0);
  if ($63) {
   label = 28;
   break;
  } else {
   $__nd$0$in = $62;
  }
 }
 if ((label|0) == 15) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__nd$0$in;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 28) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $61;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 29) {
  HEAP32[$__parent>>2] = $__nd$0$in;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE4findIS2_EENS_15__tree_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEERKT_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$ph11$i = 0, $$0$ph9$i = 0, $$01$ph10$i$in = 0, $$016$i$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$i$i$i = 0, $i$02$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = ($1|0)==(0|0);
 L1: do {
  if (!($3)) {
   $4 = (($__v) + 36|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($__v) + 32|0);
   $7 = (($__v) + 40|0);
   $8 = (($__v) + 44|0);
   $9 = ($5|0)>(0);
   $$0$ph11$i = $2;$$01$ph10$i$in = $1;
   L3: while(1) {
    $$016$i$in = $$01$ph10$i$in;
    L5: while(1) {
     $10 = (($$016$i$in) + 52|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==($5|0);
     L7: do {
      if ($12) {
       L10: do {
        if ($9) {
         $i$02$i$i$i$i = 0;
         while(1) {
          $16 = ((($$016$i$in) + ($i$02$i$i$i$i<<2)|0) + 16|0);
          $17 = HEAP32[$16>>2]|0;
          $18 = (($__v) + ($i$02$i$i$i$i<<2)|0);
          $19 = HEAP32[$18>>2]|0;
          $20 = ($17|0)==($19|0);
          $15 = (($i$02$i$i$i$i) + 1)|0;
          if (!($20)) {
           break;
          }
          $14 = ($15|0)<($5|0);
          if ($14) {
           $i$02$i$i$i$i = $15;
          } else {
           break L10;
          }
         }
         $21 = ($17>>>0)<($19>>>0);
         if ($21) {
          break L7;
         } else {
          break L5;
         }
        }
       } while(0);
       $22 = (($$016$i$in) + 48|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = HEAP32[$6>>2]|0;
       $25 = ($23|0)==($24|0);
       if (!($25)) {
        $26 = ($23>>>0)<($24>>>0);
        if ($26) {
         break;
        } else {
         break L5;
        }
       }
       $27 = (($$016$i$in) + 56|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = HEAP32[$7>>2]|0;
       $30 = ($28|0)==($29|0);
       if ($30) {
        $31 = (($$016$i$in) + 60|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = HEAP32[$8>>2]|0;
        $34 = ($32|0)<($33|0);
        if ($34) {
         break;
        } else {
         break L5;
        }
       } else {
        $35 = ($28>>>0)<($29>>>0);
        if ($35) {
         break;
        } else {
         break L5;
        }
       }
      } else {
       $13 = ($11>>>0)<($5>>>0);
       if (!($13)) {
        break L5;
       }
      }
     } while(0);
     $38 = (($$016$i$in) + 4|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      $$0$ph9$i = $$0$ph11$i;
      break L3;
     } else {
      $$016$i$in = $39;
     }
    }
    $36 = HEAP32[$$016$i$in>>2]|0;
    $37 = ($36|0)==(0|0);
    if ($37) {
     $$0$ph9$i = $$016$i$in;
     break;
    } else {
     $$0$ph11$i = $$016$i$in;$$01$ph10$i$in = $36;
    }
   }
   $41 = ($$0$ph9$i|0)==($2|0);
   if (!($41)) {
    $42 = (($$0$ph9$i) + 52|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($5|0)==($43|0);
    L26: do {
     if ($44) {
      L28: do {
       if ($9) {
        $i$02$i$i$i = 0;
        while(1) {
         $48 = (($__v) + ($i$02$i$i$i<<2)|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ((($$0$ph9$i) + ($i$02$i$i$i<<2)|0) + 16|0);
         $51 = HEAP32[$50>>2]|0;
         $52 = ($49|0)==($51|0);
         $47 = (($i$02$i$i$i) + 1)|0;
         if (!($52)) {
          break;
         }
         $46 = ($47|0)<($5|0);
         if ($46) {
          $i$02$i$i$i = $47;
         } else {
          break L28;
         }
        }
        $53 = ($49>>>0)<($51>>>0);
        if ($53) {
         break L1;
        } else {
         break L26;
        }
       }
      } while(0);
      $54 = HEAP32[$6>>2]|0;
      $55 = (($$0$ph9$i) + 48|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($54|0)==($56|0);
      if (!($57)) {
       $58 = ($54>>>0)<($56>>>0);
       if ($58) {
        break L1;
       } else {
        break;
       }
      }
      $59 = HEAP32[$7>>2]|0;
      $60 = (($$0$ph9$i) + 56|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($59|0)==($61|0);
      if ($62) {
       $63 = HEAP32[$8>>2]|0;
       $64 = (($$0$ph9$i) + 60|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = ($63|0)<($65|0);
       if ($66) {
        break L1;
       } else {
        break;
       }
      } else {
       $67 = ($59>>>0)<($61>>>0);
       if ($67) {
        break L1;
       } else {
        break;
       }
      }
     } else {
      $45 = ($5>>>0)<($43>>>0);
      if ($45) {
       break L1;
      }
     }
    } while(0);
    HEAP32[$agg$result>>2] = $$0$ph9$i;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 HEAP32[$agg$result>>2] = $2;
 STACKTOP = sp;return;
}
function __ZNSt3__13mapI20GfxRenderTargetSetupjNS_4lessIS1_EENS_9allocatorINS_4pairIKS1_jEEEEE16__find_equal_keyERPNS_16__tree_node_baseIPvEERS6_($this,$__parent,$__k) {
 $this = $this|0;
 $__parent = $__parent|0;
 $__k = $__k|0;
 var $$0 = 0, $$lcssa15 = 0, $$lcssa16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__nd$0$in = 0, $__nd$0$in$lcssa = 0, $__nd$0$in$lcssa13 = 0, $__nd$0$in$lcssa14 = 0, $__nd$0$in$us = 0, $i$02$i$i$us = 0, $i$02$i$i2$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $102 = (($this) + 4|0);
  HEAP32[$__parent>>2] = $102;
  $$0 = $102;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__k) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 $6 = (($__k) + 32|0);
 $7 = (($__k) + 40|0);
 $8 = (($__k) + 44|0);
 L5: do {
  if ($5) {
   $__nd$0$in$us = $1;
   while(1) {
    $9 = (($__nd$0$in$us) + 16|0);
    $10 = (($__nd$0$in$us) + 52|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($4|0)==($11|0);
    L32: do {
     if ($12) {
      $i$02$i$i2$us = 0;
      while(1) {
       $14 = (($__k) + ($i$02$i$i2$us<<2)|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = (($9) + ($i$02$i$i2$us<<2)|0);
       $17 = HEAP32[$16>>2]|0;
       $18 = ($15|0)==($17|0);
       $19 = (($i$02$i$i2$us) + 1)|0;
       if (!($18)) {
        label = 6;
        break;
       }
       $21 = ($19|0)<($4|0);
       if ($21) {
        $i$02$i$i2$us = $19;
       } else {
        label = 8;
        break;
       }
      }
      do {
       if ((label|0) == 6) {
        label = 0;
        $20 = ($15>>>0)<($17>>>0);
        if ($20) {
         label = 24;
         break L32;
        }
       }
       else if ((label|0) == 8) {
        label = 0;
        $22 = HEAP32[$6>>2]|0;
        $23 = (($__nd$0$in$us) + 48|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = ($22|0)==($24|0);
        if (!($25)) {
         $26 = ($22>>>0)<($24>>>0);
         if ($26) {
          label = 24;
          break L32;
         } else {
          break;
         }
        }
        $27 = HEAP32[$7>>2]|0;
        $28 = (($__nd$0$in$us) + 56|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = ($27|0)==($29|0);
        if ($30) {
         $32 = HEAP32[$8>>2]|0;
         $33 = (($__nd$0$in$us) + 60|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = ($32|0)<($34|0);
         if ($35) {
          label = 24;
          break L32;
         } else {
          break;
         }
        } else {
         $31 = ($27>>>0)<($29>>>0);
         if ($31) {
          label = 24;
          break L32;
         } else {
          break;
         }
        }
       }
      } while(0);
      if ($12) {
       $i$02$i$i$us = 0;
       while(1) {
        $37 = (($9) + ($i$02$i$i$us<<2)|0);
        $38 = HEAP32[$37>>2]|0;
        $39 = (($__k) + ($i$02$i$i$us<<2)|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = ($38|0)==($40|0);
        $42 = (($i$02$i$i$us) + 1)|0;
        if (!($41)) {
         label = 16;
         break;
        }
        $44 = ($42|0)<($4|0);
        if ($44) {
         $i$02$i$i$us = $42;
        } else {
         break;
        }
       }
       if ((label|0) == 16) {
        label = 0;
        $43 = ($38>>>0)<($40>>>0);
        if ($43) {
         break;
        } else {
         $__nd$0$in$lcssa = $__nd$0$in$us;
         label = 43;
         break L5;
        }
       }
       $45 = (($__nd$0$in$us) + 48|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = HEAP32[$6>>2]|0;
       $48 = ($46|0)==($47|0);
       if (!($48)) {
        $49 = ($46>>>0)<($47>>>0);
        if ($49) {
         break;
        } else {
         $__nd$0$in$lcssa = $__nd$0$in$us;
         label = 43;
         break L5;
        }
       }
       $50 = (($__nd$0$in$us) + 56|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = HEAP32[$7>>2]|0;
       $53 = ($51|0)==($52|0);
       if ($53) {
        $55 = (($__nd$0$in$us) + 60|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = HEAP32[$8>>2]|0;
        $58 = ($56|0)<($57|0);
        if ($58) {
         break;
        } else {
         $__nd$0$in$lcssa = $__nd$0$in$us;
         label = 43;
         break L5;
        }
       } else {
        $54 = ($51>>>0)<($52>>>0);
        if ($54) {
         break;
        } else {
         $__nd$0$in$lcssa = $__nd$0$in$us;
         label = 43;
         break L5;
        }
       }
      } else {
       label = 14;
      }
     } else {
      $13 = ($4>>>0)<($11>>>0);
      if ($13) {
       label = 24;
      } else {
       label = 14;
      }
     }
    } while(0);
    if ((label|0) == 14) {
     label = 0;
     $36 = ($11>>>0)<($4>>>0);
     if (!($36)) {
      $__nd$0$in$lcssa = $__nd$0$in$us;
      label = 43;
      break L5;
     }
    }
    else if ((label|0) == 24) {
     label = 0;
     $62 = HEAP32[$__nd$0$in$us>>2]|0;
     $63 = ($62|0)==(0|0);
     if ($63) {
      $$lcssa16 = $__nd$0$in$us;$__nd$0$in$lcssa14 = $__nd$0$in$us;
      label = 33;
      break;
     } else {
      $__nd$0$in$us = $62;
      continue;
     }
    }
    $59 = (($__nd$0$in$us) + 4|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==(0|0);
    if ($61) {
     $$lcssa15 = $59;$__nd$0$in$lcssa13 = $__nd$0$in$us;
     label = 42;
     break;
    } else {
     $__nd$0$in$us = $60;
    }
   }
  } else {
   $__nd$0$in = $1;
   while(1) {
    $64 = (($__nd$0$in) + 52|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($4|0)==($65|0);
    L8: do {
     if ($66) {
      $68 = HEAP32[$6>>2]|0;
      $69 = (($__nd$0$in) + 48|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($68|0)==($70|0);
      do {
       if ($71) {
        $73 = HEAP32[$7>>2]|0;
        $74 = (($__nd$0$in) + 56|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = ($73|0)==($75|0);
        if ($76) {
         $77 = HEAP32[$8>>2]|0;
         $78 = (($__nd$0$in) + 60|0);
         $79 = HEAP32[$78>>2]|0;
         $80 = ($77|0)<($79|0);
         if ($80) {
          label = 32;
          break L8;
         } else {
          label = 34;
          break;
         }
        } else {
         $81 = ($73>>>0)<($75>>>0);
         if ($81) {
          label = 32;
          break L8;
         } else {
          break;
         }
        }
       } else {
        $72 = ($68>>>0)<($70>>>0);
        if ($72) {
         label = 32;
         break L8;
        } else {
         label = 34;
        }
       }
      } while(0);
      if ((label|0) == 34) {
       label = 0;
       if (!($66)) {
        label = 35;
        break;
       }
      }
      $85 = (($__nd$0$in) + 48|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = HEAP32[$6>>2]|0;
      $88 = ($86|0)==($87|0);
      if (!($88)) {
       $89 = ($86>>>0)<($87>>>0);
       if ($89) {
        break;
       } else {
        $__nd$0$in$lcssa = $__nd$0$in;
        label = 43;
        break L5;
       }
      }
      $90 = (($__nd$0$in) + 56|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = HEAP32[$7>>2]|0;
      $93 = ($91|0)==($92|0);
      if ($93) {
       $94 = (($__nd$0$in) + 60|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = HEAP32[$8>>2]|0;
       $97 = ($95|0)<($96|0);
       if ($97) {
        break;
       } else {
        $__nd$0$in$lcssa = $__nd$0$in;
        label = 43;
        break L5;
       }
      } else {
       $98 = ($91>>>0)<($92>>>0);
       if ($98) {
        break;
       } else {
        $__nd$0$in$lcssa = $__nd$0$in;
        label = 43;
        break L5;
       }
      }
     } else {
      $67 = ($4>>>0)<($65>>>0);
      if ($67) {
       label = 32;
      } else {
       label = 35;
      }
     }
    } while(0);
    if ((label|0) == 32) {
     label = 0;
     $82 = HEAP32[$__nd$0$in>>2]|0;
     $83 = ($82|0)==(0|0);
     if ($83) {
      $$lcssa16 = $__nd$0$in;$__nd$0$in$lcssa14 = $__nd$0$in;
      label = 33;
      break L5;
     } else {
      $__nd$0$in = $82;
      continue;
     }
    }
    else if ((label|0) == 35) {
     label = 0;
     $84 = ($65>>>0)<($4>>>0);
     if (!($84)) {
      $__nd$0$in$lcssa = $__nd$0$in;
      label = 43;
      break L5;
     }
    }
    $99 = (($__nd$0$in) + 4|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = ($100|0)==(0|0);
    if ($101) {
     $$lcssa15 = $99;$__nd$0$in$lcssa13 = $__nd$0$in;
     label = 42;
     break;
    } else {
     $__nd$0$in = $100;
    }
   }
  }
 } while(0);
 if ((label|0) == 33) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa14;
  $$0 = $$lcssa16;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 42) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa13;
  $$0 = $$lcssa15;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 43) {
  HEAP32[$__parent>>2] = $__nd$0$in$lcssa;
  $$0 = $__parent;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeI20GfxRenderTargetSetupjEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZN18GlslGpuProgramGLESC2ERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER22CreateGpuProgramOutput($this,$source,$output) {
 $this = $this|0;
 $source = $source|0;
 $output = $output|0;
 var $$0$i = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $i$01$i = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $output$idx = 0, $output$idx$val = 0, $output$idx1 = 0, $output$idx1$val = 0, $vararg_buffer6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer6 = sp;
 __ZN10GpuProgramC2Ev($this);
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = 0;
 HEAP32[$this>>2] = ((1150288 + 8|0));
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 6;
 $2 = (($this) + 28|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 24|0);
 HEAP32[$3>>2] = 0;
 $4 = HEAP8[$source>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $9 = $4&255;
  $10 = $9 >>> 1;
  $12 = $10;
 } else {
  $7 = (($source) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $12 = $8;
 }
 $11 = ($12|0)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 8|0);
 HEAP8[$13>>0] = 1;
 __THREW__ = 0;
 $14 = (invoke_ii(3458,($output|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 L8: do {
  if ($16) {
   label = 21;
  } else {
   __THREW__ = 0;
   $17 = (invoke_iiii(1638,($this|0),($source|0),($14|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if ($19) {
    label = 21;
   } else {
    if (!($17)) {
     $output$idx = (($output) + 12|0);
     $output$idx$val = HEAP32[$output$idx>>2]|0;
     $86 = ($output$idx$val|0)==(0|0);
     do {
      if ($86) {
       $$0$i = 1151408;
      } else {
       $87 = HEAP8[$output$idx$val>>0]|0;
       $88 = $87 & 1;
       $89 = ($88<<24>>24)==(0);
       if ($89) {
        $92 = (($output$idx$val) + 1|0);
        $$0$i = $92;
        break;
       } else {
        $90 = (($output$idx$val) + 8|0);
        $91 = HEAP32[$90>>2]|0;
        $$0$i = $91;
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     HEAP32[$vararg_buffer6>>2] = $$0$i;
     invoke_vii(2587,(1150408|0),($vararg_buffer6|0));
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      label = 21;
      break;
     }
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3459,($output|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 21;
    } else {
     $23 = HEAP32[$0>>2]|0;
     $24 = (($output) + 8|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = ($23|0)==(0);
     if (!($26)) {
      $27 = HEAP32[1149528>>2]|0;
      __THREW__ = 0;
      invoke_vii(3488,($27|0),($23|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 21;
       break;
      }
      __THREW__ = 0;
      invoke_viiii(454,($23|0),($20|0),($25|0),1);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 21;
       break;
      }
      $32 = (($20) + 64|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($20) + 60|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = $33;
      $37 = $35;
      $38 = (($36) - ($37))|0;
      $39 = (($38|0) / 28)&-1;
      $40 = ($38|0)>(0);
      L26: do {
       if ($40) {
        $i$01$i = 0;
        while(1) {
         __THREW__ = 0;
         $41 = (invoke_i(130)|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break;
         }
         $44 = HEAP32[$41>>2]|0;
         $45 = (($44) + 240|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = HEAP32[$34>>2]|0;
         $48 = (($47) + (($i$01$i*28)|0)|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ((($47) + (($i$01$i*28)|0)|0) + 20|0);
         $51 = HEAP32[$50>>2]|0;
         __THREW__ = 0;
         invoke_viii($46|0,($41|0),($49|0),($51|0));
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break;
         }
         $54 = (($i$01$i) + 1)|0;
         $55 = ($54|0)<($39|0);
         if ($55) {
          $i$01$i = $54;
         } else {
          break L26;
         }
        }
        $71 = ___cxa_find_matching_catch()|0;
        $72 = tempRet0;
        $lpad$phi$index = $71;$lpad$phi$index2 = $72;
        break L8;
       }
      } while(0);
      __THREW__ = 0;
      invoke_vi(3796,($20|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 21;
       break;
      }
     }
     $58 = (($this) + 20|0);
     __THREW__ = 0;
     invoke_viiii(455,($58|0),($20|0),-1,-1);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 21;
     } else {
      $61 = (($20) + 36|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = (($20) + 32|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = $62;
      $66 = $64;
      $67 = (($65) - ($66))|0;
      $68 = $67 >> 4;
      $69 = HEAP32[((640792 + 96|0))>>2]|0;
      $70 = ($68|0)>($69|0);
      if (!($70)) {
       HEAP8[$13>>0] = 0;
       STACKTOP = sp;return;
      }
      $output$idx1 = (($output) + 12|0);
      $output$idx1$val = HEAP32[$output$idx1>>2]|0;
      $77 = ($output$idx1$val|0)==(0|0);
      do {
       if ($77) {
        $$0$i2 = 1151408;
       } else {
        $78 = HEAP8[$output$idx1$val>>0]|0;
        $79 = $78 & 1;
        $80 = ($79<<24>>24)==(0);
        if ($80) {
         $83 = (($output$idx1$val) + 1|0);
         $$0$i2 = $83;
         break;
        } else {
         $81 = (($output$idx1$val) + 8|0);
         $82 = HEAP32[$81>>2]|0;
         $$0$i2 = $82;
         break;
        }
       }
      } while(0);
      __THREW__ = 0;
      HEAP32[$vararg_buffer6>>2] = $$0$i2;
      invoke_vii(2587,(1150312|0),($vararg_buffer6|0));
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if ($85) {
       label = 21;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $73 = ___cxa_find_matching_catch()|0;
  $74 = tempRet0;
  $lpad$phi$index = $73;$lpad$phi$index2 = $74;
 }
 __THREW__ = 0;
 $75 = __THREW__; __THREW__ = 0;
 $76 = $75&1;
 if ($76) {
  $95 = ___cxa_find_matching_catch(0|0)|0;
  $96 = tempRet0;
  ___clang_call_terminate($95);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
}
function __ZN18GlslGpuProgramGLES6CreateERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER14ChannelAssigns($this,$shaderString,$channels) {
 $this = $this|0;
 $shaderString = $shaderString|0;
 $channels = $channels|0;
 var $$0 = 0, $$01 = 0, $$04 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $compileInfoLog$i = 0, $fragmentShaderSource = 0, $infoLogLength$i = 0, $remainder = 0, $vararg_buffer = 0, $vertexShaderSource = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4192|0;
 $vararg_buffer = sp;
 $compileInfoLog$i = sp + 96|0;
 $infoLogLength$i = sp + 76|0;
 $remainder = sp + 64|0;
 $vertexShaderSource = sp + 52|0;
 $0 = sp + 80|0;
 $fragmentShaderSource = sp + 16|0;
 $1 = sp + 4|0;
 $2 = sp + 28|0;
 $3 = sp + 40|0;
 $4 = (1147664 + 84|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_i[$5 & 255]()|0);
 $7 = (($this) + 16|0);
 HEAP32[$7>>2] = $6;
 $8 = (($this) + 4|0);
 HEAP32[$8>>2] = 6;
 $9 = HEAP8[$shaderString>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  ;HEAP32[$remainder+0>>2]=HEAP32[$shaderString+0>>2]|0;HEAP32[$remainder+4>>2]=HEAP32[$shaderString+4>>2]|0;HEAP32[$remainder+8>>2]=HEAP32[$shaderString+8>>2]|0;
 } else {
  $12 = (($shaderString) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($shaderString) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15>>>0)>(4294967279);
  if ($16) {
   __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
   // unreachable;
  }
  $17 = ($15>>>0)<(11);
  if ($17) {
   $18 = $15 << 1;
   $19 = $18&255;
   HEAP8[$remainder>>0] = $19;
   $20 = (($remainder) + 1|0);
   $__p$0$i$i$i = $20;
  } else {
   $21 = (($15) + 16)|0;
   $22 = $21 & -16;
   $23 = (__Znwj($22)|0);
   $24 = (($remainder) + 8|0);
   HEAP32[$24>>2] = $23;
   $25 = $22 | 1;
   HEAP32[$remainder>>2] = $25;
   $26 = (($remainder) + 4|0);
   HEAP32[$26>>2] = $15;
   $__p$0$i$i$i = $23;
  }
  _memcpy(($__p$0$i$i$i|0),($13|0),($15|0))|0;
  $27 = (($__p$0$i$i$i) + ($15)|0);
  HEAP8[$27>>0] = 0;
 }
 HEAP8[$0>>0] = 12;
 $28 = (($0) + 1|0);
 ;HEAP8[$28+0>>0]=HEAP8[1150552+0>>0]|0;HEAP8[$28+1>>0]=HEAP8[1150552+1>>0]|0;HEAP8[$28+2>>0]=HEAP8[1150552+2>>0]|0;HEAP8[$28+3>>0]=HEAP8[1150552+3>>0]|0;HEAP8[$28+4>>0]=HEAP8[1150552+4>>0]|0;HEAP8[$28+5>>0]=HEAP8[1150552+5>>0]|0;
 $29 = (($0) + 7|0);
 HEAP8[$29>>0] = 0;
 __THREW__ = 0;
 invoke_viiii(456,($vertexShaderSource|0),($0|0),($shaderString|0),($remainder|0));
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $82 = HEAP8[$0>>0]|0;
  $83 = $82 & 1;
  $84 = ($83<<24>>24)==(0);
  if ($84) {
   $$2 = $81;$$23 = $80;
  } else {
   $85 = (($0) + 8|0);
   $86 = HEAP32[$85>>2]|0;
   __ZdlPv($86);
   $$2 = $81;$$23 = $80;
  }
 } else {
  $32 = HEAP8[$0>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if (!($34)) {
   $35 = (($0) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   __ZdlPv($36);
  }
  HEAP8[$1>>0] = 16;
  $37 = (($1) + 1|0);
  $38 = $37;
  $39 = $38;
  HEAP8[$39>>0]=1195463238&255;HEAP8[$39+1>>0]=(1195463238>>8)&255;HEAP8[$39+2>>0]=(1195463238>>16)&255;HEAP8[$39+3>>0]=1195463238>>24;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP8[$41>>0]=1414415693&255;HEAP8[$41+1>>0]=(1414415693>>8)&255;HEAP8[$41+2>>0]=(1414415693>>16)&255;HEAP8[$41+3>>0]=1414415693>>24;
  $42 = (($1) + 9|0);
  HEAP8[$42>>0] = 0;
  __THREW__ = 0;
  invoke_viiii(456,($fragmentShaderSource|0),($1|0),($remainder|0),($remainder|0));
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   $87 = ___cxa_find_matching_catch()|0;
   $88 = tempRet0;
   $89 = HEAP8[$1>>0]|0;
   $90 = $89 & 1;
   $91 = ($90<<24>>24)==(0);
   if ($91) {
    $$1 = $88;$$12 = $87;
   } else {
    $92 = (($1) + 8|0);
    $93 = HEAP32[$92>>2]|0;
    __ZdlPv($93);
    $$1 = $88;$$12 = $87;
   }
  } else {
   $45 = HEAP8[$1>>0]|0;
   $46 = $45 & 1;
   $47 = ($46<<24>>24)==(0);
   if (!($47)) {
    $48 = (($1) + 8|0);
    $49 = HEAP32[$48>>2]|0;
    __ZdlPv($49);
   }
   __THREW__ = 0;
   invoke_viii(1774,($2|0),($remainder|0),($vertexShaderSource|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   do {
    if ($51) {
     label = 32;
    } else {
     __THREW__ = 0;
     (invoke_iii(2233,($vertexShaderSource|0),($2|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      $96 = ___cxa_find_matching_catch()|0;
      $97 = tempRet0;
      $98 = HEAP8[$2>>0]|0;
      $99 = $98 & 1;
      $100 = ($99<<24>>24)==(0);
      if ($100) {
       $$0 = $97;$$01 = $96;
       break;
      }
      $101 = (($2) + 8|0);
      $102 = HEAP32[$101>>2]|0;
      __ZdlPv($102);
      $$0 = $97;$$01 = $96;
      break;
     }
     $54 = HEAP8[$2>>0]|0;
     $55 = $54 & 1;
     $56 = ($55<<24>>24)==(0);
     if (!($56)) {
      $57 = (($2) + 8|0);
      $58 = HEAP32[$57>>2]|0;
      __ZdlPv($58);
     }
     __THREW__ = 0;
     invoke_viii(1774,($3|0),($remainder|0),($fragmentShaderSource|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 32;
     } else {
      __THREW__ = 0;
      (invoke_iii(2233,($fragmentShaderSource|0),($3|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       $103 = ___cxa_find_matching_catch()|0;
       $104 = tempRet0;
       $105 = HEAP8[$3>>0]|0;
       $106 = $105 & 1;
       $107 = ($106<<24>>24)==(0);
       if ($107) {
        $$0 = $104;$$01 = $103;
        break;
       }
       $108 = (($3) + 8|0);
       $109 = HEAP32[$108>>2]|0;
       __ZdlPv($109);
       $$0 = $104;$$01 = $103;
       break;
      }
      $63 = HEAP8[$3>>0]|0;
      $64 = $63 & 1;
      $65 = ($64<<24>>24)==(0);
      if (!($65)) {
       $66 = (($3) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       __ZdlPv($67);
      }
      __THREW__ = 0;
      $68 = (invoke_iiiii(297,($this|0),($vertexShaderSource|0),($fragmentShaderSource|0),($channels|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 32;
      } else {
       if ($68) {
        $$04 = 1;
       } else {
        $71 = HEAP32[$7>>2]|0;
        HEAP32[$infoLogLength$i>>2] = 0;
        $72 = (1147664 + 220|0);
        $73 = HEAP32[$72>>2]|0;
        __THREW__ = 0;
        invoke_viiii($73|0,($71|0),4096,($infoLogLength$i|0),($compileInfoLog$i|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 32;
         break;
        }
        $76 = HEAP32[$infoLogLength$i>>2]|0;
        $77 = ($76|0)>(0);
        if ($77) {
         __THREW__ = 0;
         HEAP32[$vararg_buffer>>2] = $compileInfoLog$i;
         invoke_vii(2587,(1150520|0),($vararg_buffer|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          label = 32;
          break;
         } else {
          $$04 = 0;
         }
        } else {
         $$04 = 0;
        }
       }
       $110 = HEAP8[$fragmentShaderSource>>0]|0;
       $111 = $110 & 1;
       $112 = ($111<<24>>24)==(0);
       if (!($112)) {
        $113 = (($fragmentShaderSource) + 8|0);
        $114 = HEAP32[$113>>2]|0;
        __ZdlPv($114);
       }
       $115 = HEAP8[$vertexShaderSource>>0]|0;
       $116 = $115 & 1;
       $117 = ($116<<24>>24)==(0);
       if (!($117)) {
        $118 = (($vertexShaderSource) + 8|0);
        $119 = HEAP32[$118>>2]|0;
        __ZdlPv($119);
       }
       $125 = HEAP8[$remainder>>0]|0;
       $126 = $125 & 1;
       $127 = ($126<<24>>24)==(0);
       if ($127) {
        STACKTOP = sp;return ($$04|0);
       }
       $128 = (($remainder) + 8|0);
       $129 = HEAP32[$128>>2]|0;
       __ZdlPv($129);
       STACKTOP = sp;return ($$04|0);
      }
     }
    }
   } while(0);
   if ((label|0) == 32) {
    $94 = ___cxa_find_matching_catch()|0;
    $95 = tempRet0;
    $$0 = $95;$$01 = $94;
   }
   $120 = HEAP8[$fragmentShaderSource>>0]|0;
   $121 = $120 & 1;
   $122 = ($121<<24>>24)==(0);
   if ($122) {
    $$1 = $$0;$$12 = $$01;
   } else {
    $123 = (($fragmentShaderSource) + 8|0);
    $124 = HEAP32[$123>>2]|0;
    __ZdlPv($124);
    $$1 = $$0;$$12 = $$01;
   }
  }
  $130 = HEAP8[$vertexShaderSource>>0]|0;
  $131 = $130 & 1;
  $132 = ($131<<24>>24)==(0);
  if ($132) {
   $$2 = $$1;$$23 = $$12;
  } else {
   $133 = (($vertexShaderSource) + 8|0);
   $134 = HEAP32[$133>>2]|0;
   __ZdlPv($134);
   $$2 = $$1;$$23 = $$12;
  }
 }
 $135 = HEAP8[$remainder>>0]|0;
 $136 = $135 & 1;
 $137 = ($136<<24>>24)==(0);
 if ($137) {
  ___resumeException($$23|0);
  // unreachable;
 }
 $138 = (($remainder) + 8|0);
 $139 = HEAP32[$138>>2]|0;
 __ZdlPv($139);
 ___resumeException($$23|0);
 // unreachable;
 return 0|0;
}
function __ZN18GlslGpuProgramGLESD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1150288 + 8|0));
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  label = 4;
 } else {
  $3 = (1147664 + 112|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi($4|0,($1|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   $11 = (($this) + 28|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0);
   if (!($13)) {
    $14 = (1147664 + 112|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_vi($15|0,($12|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
   }
   $18 = (($this) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0);
   if (!($20)) {
    $21 = (1147664 + 104|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    invoke_vi($22|0,($19|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
   }
   __THREW__ = 0;
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    __THREW__ = 0;
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     __ZdlPv($this);
     STACKTOP = sp;return;
    }
    $31 = ___cxa_find_matching_catch()|0;
    $32 = tempRet0;
    $eh$lpad$body$index2Z2D = $32;$eh$lpad$body$indexZ2D = $31;
    __ZdlPv($this);
    ___resumeException($eh$lpad$body$indexZ2D|0);
    // unreachable;
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $29 = ___cxa_find_matching_catch(0|0)|0;
  $30 = tempRet0;
  ___clang_call_terminate($29);
  // unreachable;
 } else {
  $eh$lpad$body$index2Z2D = $8;$eh$lpad$body$indexZ2D = $7;
  __ZdlPv($this);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
}
function __ZN18GlslGpuProgramGLESD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1150288 + 8|0));
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  label = 4;
 } else {
  $3 = (1147664 + 112|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi($4|0,($1|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   label = 4;
  }
 }
 do {
  if ((label|0) == 4) {
   $11 = (($this) + 28|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0);
   if (!($13)) {
    $14 = (1147664 + 112|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_vi($15|0,($12|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
   }
   $18 = (($this) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(0);
   if (!($20)) {
    $21 = (1147664 + 104|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    invoke_vi($22|0,($19|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
   }
   __THREW__ = 0;
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __THREW__ = 0;
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $27 = ___cxa_find_matching_catch(0|0)|0;
  $28 = tempRet0;
  ___clang_call_terminate($27);
  // unreachable;
 } else {
  ___resumeException($7|0);
  // unreachable;
 }
}
function __ZN18GlslGpuProgramGLES17CompileGlslShaderEj10ShaderTypePKc($shader,$stage,$source) {
 $shader = $shader|0;
 $stage = $stage|0;
 $source = $source|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $compileInfoLog$i = 0, $compiled = 0, $infoLogLength$i = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4112|0;
 $vararg_buffer1 = sp;
 $compileInfoLog$i = sp + 16|0;
 $infoLogLength$i = sp + 4|0;
 $0 = sp + 8|0;
 $compiled = sp + 12|0;
 HEAP32[$0>>2] = $source;
 $1 = (1147664 + 280|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$2 & 511]($shader,1,$0,0);
 $3 = (1147664 + 68|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vi[$4 & 4095]($shader);
 HEAP32[$compiled>>2] = 10;
 $5 = (1147664 + 224|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$6 & 4095]($shader,35713,$compiled);
 $7 = HEAP32[$compiled>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $20 = HEAP32[$compiled>>2]|0;
  $21 = ($20|0)!=(0);
  STACKTOP = sp;return ($21|0);
 }
 $9 = HEAP32[$0>>2]|0;
 HEAP32[$infoLogLength$i>>2] = 0;
 $10 = ($stage|0)==(0);
 if ($10) {
  $11 = (1147664 + 220|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_viiii[$12 & 511]($shader,4096,$infoLogLength$i,$compileInfoLog$i);
 } else {
  $13 = (1147664 + 228|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_viiii[$14 & 511]($shader,4096,$infoLogLength$i,$compileInfoLog$i);
 }
 $15 = HEAP32[$infoLogLength$i>>2]|0;
 $16 = ($15|0)>(0);
 if (!($16)) {
  $20 = HEAP32[$compiled>>2]|0;
  $21 = ($20|0)!=(0);
  STACKTOP = sp;return ($21|0);
 }
 $17 = ($9|0)==(0|0);
 if (!($17)) {
  $18 = ($stage|0)==(1);
  $19 = $18 ? 1150488 : 1150504;
  HEAP32[$vararg_buffer1>>2] = $19;
  _printf_console(1150456,$vararg_buffer1);
  __Z19DebugTextLineByLinePKci($9,-1);
 }
 HEAP32[$vararg_buffer1>>2] = $compileInfoLog$i;
 _printf_console(1150520,$vararg_buffer1);
 $20 = HEAP32[$compiled>>2]|0;
 $21 = ($20|0)!=(0);
 STACKTOP = sp;return ($21|0);
}
function __ZN18GlslGpuProgramGLES15ParseGlslErrorsEj10ShaderTypePKc($shader,$stage,$source) {
 $shader = $shader|0;
 $stage = $stage|0;
 $source = $source|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $compileInfoLog = 0, $hadErrors$0$off0 = 0, $infoLogLength = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4112|0;
 $vararg_buffer1 = sp;
 $compileInfoLog = sp + 8|0;
 $infoLogLength = sp + 4|0;
 HEAP32[$infoLogLength>>2] = 0;
 $0 = ($stage|0)==(0);
 if ($0) {
  $1 = (1147664 + 220|0);
  $2 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_viiii[$2 & 511]($shader,4096,$infoLogLength,$compileInfoLog);
 } else {
  $3 = (1147664 + 228|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_viiii[$4 & 511]($shader,4096,$infoLogLength,$compileInfoLog);
 }
 $5 = HEAP32[$infoLogLength>>2]|0;
 $6 = ($5|0)>(0);
 if (!($6)) {
  $hadErrors$0$off0 = 0;
  STACKTOP = sp;return ($hadErrors$0$off0|0);
 }
 $7 = ($source|0)==(0|0);
 if (!($7)) {
  $8 = ($stage|0)==(1);
  $9 = $8 ? 1150488 : 1150504;
  HEAP32[$vararg_buffer1>>2] = $9;
  _printf_console(1150456,$vararg_buffer1);
  __Z19DebugTextLineByLinePKci($source,-1);
 }
 HEAP32[$vararg_buffer1>>2] = $compileInfoLog;
 _printf_console(1150520,$vararg_buffer1);
 $hadErrors$0$off0 = 1;
 STACKTOP = sp;return ($hadErrors$0$off0|0);
}
function __ZL17ExtractDefineBockRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_PS5_($agg$result,$defineName,$str,$remainderStr) {
 $agg$result = $agg$result|0;
 $defineName = $defineName|0;
 $str = $str|0;
 $remainderStr = $remainderStr|0;
 var $$0 = 0, $$0$i$i21 = 0, $$0$i$i34 = 0, $$0$i$i67 = 0, $$01 = 0, $$01$be$i$i$i$i = 0, $$01$be$i$i$i$i15 = 0, $$01$be$i$i$i$i28 = 0, $$014$i$i$i$i = 0, $$014$i$i$i$i14 = 0, $$014$i$i$i$i27 = 0, $$1 = 0, $$12 = 0, $$sum$i$i = 0, $$sum$i$i12 = 0, $$sum$i$i25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__m1$0$i$i$i$i = 0, $__m1$0$i$i$i$i17 = 0, $__m1$0$i$i$i$i30 = 0, $__m2$0$i$i$i$i = 0, $__m2$0$i$i$i$i18 = 0, $__m2$0$i$i$i$i31 = 0, $__p$0$i$i = 0, $__p$0$i$i$i57 = 0, $beginsWith = 0, $e$0 = 0, $e$1 = 0, $e$1$in = 0, $endsWith = 0, $n$0 = 0, $n$1 = 0, $n$1$v = 0, $or$cond = 0, $or$cond$i$i = 0, $or$cond$i$i23 = 0;
 var $retVal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $beginsWith = sp + 48|0;
 $endsWith = sp;
 $retVal = sp + 12|0;
 $0 = sp + 24|0;
 $1 = sp + 36|0;
 __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($beginsWith,1150576,$defineName);
 HEAP8[$endsWith>>0] = 12;
 $2 = (($endsWith) + 1|0);
 ;HEAP8[$2+0>>0]=HEAP8[1150584+0>>0]|0;HEAP8[$2+1>>0]=HEAP8[1150584+1>>0]|0;HEAP8[$2+2>>0]=HEAP8[1150584+2>>0]|0;HEAP8[$2+3>>0]=HEAP8[1150584+3>>0]|0;HEAP8[$2+4>>0]=HEAP8[1150584+4>>0]|0;HEAP8[$2+5>>0]=HEAP8[1150584+5>>0]|0;
 $3 = (($endsWith) + 7|0);
 HEAP8[$3>>0] = 0;
 $4 = HEAP8[$beginsWith>>0]|0;
 $5 = $4 & 1;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $11 = (($beginsWith) + 1|0);
  $12 = $4&255;
  $13 = $12 >>> 1;
  $23 = $13;$31 = $11;
 } else {
  $7 = (($beginsWith) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($beginsWith) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $23 = $10;$31 = $8;
 }
 $14 = HEAP8[$str>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $19 = $14&255;
  $20 = $19 >>> 1;
  $22 = $20;
 } else {
  $17 = (($str) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  $22 = $18;
 }
 $21 = ($22>>>0)<($23>>>0);
 L9: do {
  if ($21) {
   label = 21;
  } else {
   $24 = ($23|0)==(0);
   if ($24) {
    $$0$i$i67 = 0;
   } else {
    if ($16) {
     $27 = (($str) + 1|0);
     $29 = $27;
    } else {
     $25 = (($str) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     $29 = $26;
    }
    $28 = (($29) + ($22)|0);
    $30 = (($31) + ($23)|0);
    $32 = $29;
    $33 = ($22|0)<($23|0);
    if ($33) {
     label = 21;
     break;
    }
    $34 = (1 - ($23))|0;
    $$sum$i$i = (($22) + ($34))|0;
    $35 = (($29) + ($$sum$i$i)|0);
    $36 = ($$sum$i$i|0)==(0);
    if ($36) {
     label = 21;
     break;
    }
    $37 = HEAP8[$31>>0]|0;
    $$014$i$i$i$i = $29;
    L19: while(1) {
     $38 = HEAP8[$$014$i$i$i$i>>0]|0;
     $39 = ($38<<24>>24)==($37<<24>>24);
     if ($39) {
      $__m1$0$i$i$i$i = $$014$i$i$i$i;$__m2$0$i$i$i$i = $31;
      while(1) {
       $41 = (($__m2$0$i$i$i$i) + 1|0);
       $42 = ($41|0)==($30|0);
       if ($42) {
        break L19;
       }
       $43 = (($__m1$0$i$i$i$i) + 1|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = HEAP8[$41>>0]|0;
       $46 = ($44<<24>>24)==($45<<24>>24);
       if ($46) {
        $__m1$0$i$i$i$i = $43;$__m2$0$i$i$i$i = $41;
       } else {
        break;
       }
      }
     }
     $$01$be$i$i$i$i = (($$014$i$i$i$i) + 1|0);
     $40 = ($$01$be$i$i$i$i|0)==($35|0);
     if ($40) {
      label = 21;
      break L9;
     } else {
      $$014$i$i$i$i = $$01$be$i$i$i$i;
     }
    }
    $47 = ($$014$i$i$i$i|0)==($28|0);
    if ($47) {
     label = 21;
     break;
    }
    $48 = $$014$i$i$i$i;
    $49 = (($48) - ($32))|0;
    $50 = ($49|0)==(-1);
    if ($50) {
     label = 21;
     break;
    } else {
     $$0$i$i67 = $49;
    }
   }
   if ($6) {
    $56 = $4&255;
    $57 = $56 >>> 1;
    $59 = $57;
   } else {
    $54 = (($beginsWith) + 4|0);
    $55 = HEAP32[$54>>2]|0;
    $59 = $55;
   }
   $58 = (($59) + ($$0$i$i67))|0;
   $60 = $14&255;
   $61 = $60 >>> 1;
   $62 = (($str) + 1|0);
   $63 = (($str) + 8|0);
   $64 = (($str) + 4|0);
   $65 = (($endsWith) + 8|0);
   $66 = (($endsWith) + 4|0);
   $e$0 = $58;$n$0 = 1;
   while(1) {
    if ($16) {
     $69 = $61;
    } else {
     $67 = HEAP32[$64>>2]|0;
     $69 = $67;
    }
    $68 = ($69>>>0)<($e$0>>>0);
    $70 = (($69) - ($e$0))|0;
    $71 = ($70>>>0)<(6);
    $or$cond$i$i = $68 | $71;
    L38: do {
     if ($or$cond$i$i) {
      $$0$i$i21 = -1;
     } else {
      if ($16) {
       $74 = $62;
      } else {
       $72 = HEAP32[$63>>2]|0;
       $74 = $72;
      }
      $73 = (($74) + ($e$0)|0);
      $75 = (($74) + ($69)|0);
      $76 = (($endsWith) + 7|0);
      $77 = $75;
      $78 = $73;
      $79 = (($77) - ($78))|0;
      $80 = ($79|0)<(6);
      if ($80) {
       $$0$i$i21 = -1;
      } else {
       $$sum$i$i12 = (($69) + -5)|0;
       $81 = (($74) + ($$sum$i$i12)|0);
       $82 = ($$sum$i$i12|0)==($e$0|0);
       if ($82) {
        $$0$i$i21 = -1;
       } else {
        $83 = HEAP8[$2>>0]|0;
        $$014$i$i$i$i14 = $73;
        L45: while(1) {
         $84 = HEAP8[$$014$i$i$i$i14>>0]|0;
         $85 = ($84<<24>>24)==($83<<24>>24);
         if ($85) {
          $__m1$0$i$i$i$i17 = $$014$i$i$i$i14;$__m2$0$i$i$i$i18 = $2;
          while(1) {
           $87 = (($__m2$0$i$i$i$i18) + 1|0);
           $88 = ($87|0)==($76|0);
           if ($88) {
            break L45;
           }
           $89 = (($__m1$0$i$i$i$i17) + 1|0);
           $90 = HEAP8[$89>>0]|0;
           $91 = HEAP8[$87>>0]|0;
           $92 = ($90<<24>>24)==($91<<24>>24);
           if ($92) {
            $__m1$0$i$i$i$i17 = $89;$__m2$0$i$i$i$i18 = $87;
           } else {
            break;
           }
          }
         }
         $$01$be$i$i$i$i15 = (($$014$i$i$i$i14) + 1|0);
         $86 = ($$01$be$i$i$i$i15|0)==($81|0);
         if ($86) {
          $$0$i$i21 = -1;
          break L38;
         } else {
          $$014$i$i$i$i14 = $$01$be$i$i$i$i15;
         }
        }
        $93 = ($$014$i$i$i$i14|0)==($75|0);
        if ($93) {
         $$0$i$i21 = -1;
        } else {
         $94 = $$014$i$i$i$i14;
         $95 = $74;
         $96 = (($94) - ($95))|0;
         $$0$i$i21 = $96;
        }
       }
      }
     }
    } while(0);
    if ($16) {
     $99 = $61;
    } else {
     $97 = HEAP32[$64>>2]|0;
     $99 = $97;
    }
    $98 = ($99>>>0)<($e$0>>>0);
    $100 = (($99) - ($e$0))|0;
    $101 = ($100>>>0)<(3);
    $or$cond$i$i23 = $98 | $101;
    L58: do {
     if ($or$cond$i$i23) {
      $$0$i$i34 = -1;
     } else {
      if ($16) {
       $104 = $62;
      } else {
       $102 = HEAP32[$63>>2]|0;
       $104 = $102;
      }
      $103 = (($104) + ($e$0)|0);
      $105 = (($104) + ($99)|0);
      $106 = $105;
      $107 = $103;
      $108 = (($106) - ($107))|0;
      $109 = ($108|0)<(3);
      if ($109) {
       $$0$i$i34 = -1;
      } else {
       $$sum$i$i25 = (($99) + -2)|0;
       $110 = (($104) + ($$sum$i$i25)|0);
       $111 = ($$sum$i$i25|0)==($e$0|0);
       if ($111) {
        $$0$i$i34 = -1;
       } else {
        $$014$i$i$i$i27 = $103;
        L64: while(1) {
         $112 = HEAP8[$$014$i$i$i$i27>>0]|0;
         $113 = ($112<<24>>24)==(35);
         if ($113) {
          $__m1$0$i$i$i$i30 = $$014$i$i$i$i27;$__m2$0$i$i$i$i31 = 1150600;
          while(1) {
           $115 = (($__m2$0$i$i$i$i31) + 1|0);
           $116 = ($115|0)==(((1150600 + 3|0))|0);
           if ($116) {
            break L64;
           }
           $117 = (($__m1$0$i$i$i$i30) + 1|0);
           $118 = HEAP8[$117>>0]|0;
           $119 = HEAP8[$115>>0]|0;
           $120 = ($118<<24>>24)==($119<<24>>24);
           if ($120) {
            $__m1$0$i$i$i$i30 = $117;$__m2$0$i$i$i$i31 = $115;
           } else {
            break;
           }
          }
         }
         $$01$be$i$i$i$i28 = (($$014$i$i$i$i27) + 1|0);
         $114 = ($$01$be$i$i$i$i28|0)==($110|0);
         if ($114) {
          $$0$i$i34 = -1;
          break L58;
         } else {
          $$014$i$i$i$i27 = $$01$be$i$i$i$i28;
         }
        }
        $121 = ($$014$i$i$i$i27|0)==($105|0);
        if ($121) {
         $$0$i$i34 = -1;
        } else {
         $122 = $$014$i$i$i$i27;
         $123 = $104;
         $124 = (($122) - ($123))|0;
         $$0$i$i34 = $124;
        }
       }
      }
     }
    } while(0);
    $125 = ($$0$i$i21|0)==(-1);
    if ($125) {
     label = 55;
     break;
    }
    $127 = ($$0$i$i34|0)!=(-1);
    $128 = ($$0$i$i34>>>0)<($$0$i$i21>>>0);
    $or$cond = $127 & $128;
    $e$1$in = $or$cond ? $$0$i$i34 : $$0$i$i21;
    $n$1$v = $or$cond ? 1 : -1;
    $n$1 = (($n$1$v) + ($n$0))|0;
    $e$1 = (($e$1$in) + 1)|0;
    $129 = ($n$1|0)==(0);
    if ($129) {
     break;
    } else {
     $e$0 = $e$1;$n$0 = $n$1;
    }
   }
   if ((label|0) == 55) {
    HEAP8[$agg$result>>0] = 0;
    $126 = (($agg$result) + 1|0);
    HEAP8[$126>>0] = 0;
    break;
   }
   $130 = $58 ^ -1;
   $131 = (($e$1) + ($130))|0;
   __THREW__ = 0;
   invoke_viiiii(85,($retVal|0),($str|0),($58|0),($131|0),0);
   $132 = __THREW__; __THREW__ = 0;
   $133 = $132&1;
   if ($133) {
    $52 = ___cxa_find_matching_catch()|0;
    $53 = tempRet0;
    $$1 = $52;$$12 = $53;
   } else {
    $134 = ($remainderStr|0)==(0|0);
    do {
     if ($134) {
      label = 97;
     } else {
      $135 = HEAP8[$beginsWith>>0]|0;
      $136 = $135 & 1;
      $137 = ($136<<24>>24)==(0);
      if ($137) {
       $140 = $135&255;
       $141 = $140 >>> 1;
       $143 = $141;
      } else {
       $138 = (($beginsWith) + 4|0);
       $139 = HEAP32[$138>>2]|0;
       $143 = $139;
      }
      $142 = (($58) - ($143))|0;
      $144 = HEAP8[$str>>0]|0;
      $145 = $144 & 1;
      $146 = ($145<<24>>24)==(0);
      if ($146) {
       $149 = $144&255;
       $150 = $149 >>> 1;
       $152 = $150;$169 = $62;
      } else {
       $147 = HEAP32[$64>>2]|0;
       $148 = HEAP32[$63>>2]|0;
       $152 = $147;$169 = $148;
      }
      $151 = ($152>>>0)<($142>>>0);
      $153 = $151 ? $152 : $142;
      $154 = ($153>>>0)>(4294967279);
      if ($154) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $155 = __THREW__; __THREW__ = 0;
       $156 = $155&1;
       if ($156) {
        label = 92;
        break;
       }
       // unreachable;
      }
      $157 = ($153>>>0)<(11);
      if ($157) {
       $158 = $153 << 1;
       $159 = $158&255;
       HEAP8[$0>>0] = $159;
       $160 = (($0) + 1|0);
       $__p$0$i$i = $160;
      } else {
       $161 = (($153) + 16)|0;
       $162 = $161 & -16;
       __THREW__ = 0;
       $163 = (invoke_ii(2988,($162|0))|0);
       $164 = __THREW__; __THREW__ = 0;
       $165 = $164&1;
       if ($165) {
        label = 92;
        break;
       }
       $166 = (($0) + 8|0);
       HEAP32[$166>>2] = $163;
       $167 = $162 | 1;
       HEAP32[$0>>2] = $167;
       $168 = (($0) + 4|0);
       HEAP32[$168>>2] = $153;
       $__p$0$i$i = $163;
      }
      _memcpy(($__p$0$i$i|0),($169|0),($153|0))|0;
      $170 = (($__p$0$i$i) + ($153)|0);
      HEAP8[$170>>0] = 0;
      __THREW__ = 0;
      (invoke_iii(2233,($remainderStr|0),($0|0))|0);
      $171 = __THREW__; __THREW__ = 0;
      $172 = $171&1;
      if ($172) {
       $222 = ___cxa_find_matching_catch()|0;
       $223 = tempRet0;
       $224 = HEAP8[$0>>0]|0;
       $225 = $224 & 1;
       $226 = ($225<<24>>24)==(0);
       if ($226) {
        $$0 = $222;$$01 = $223;
        break;
       }
       $227 = (($0) + 8|0);
       $228 = HEAP32[$227>>2]|0;
       __ZdlPv($228);
       $$0 = $222;$$01 = $223;
       break;
      }
      $173 = HEAP8[$0>>0]|0;
      $174 = $173 & 1;
      $175 = ($174<<24>>24)==(0);
      if (!($175)) {
       $176 = (($0) + 8|0);
       $177 = HEAP32[$176>>2]|0;
       __ZdlPv($177);
      }
      $178 = HEAP8[$endsWith>>0]|0;
      $179 = $178 & 1;
      $180 = ($179<<24>>24)==(0);
      if ($180) {
       $182 = $178&255;
       $183 = $182 >>> 1;
       $185 = $183;
      } else {
       $181 = HEAP32[$66>>2]|0;
       $185 = $181;
      }
      $184 = (($185) + ($e$1))|0;
      $186 = HEAP8[$str>>0]|0;
      $187 = $186 & 1;
      $188 = ($187<<24>>24)==(0);
      if ($188) {
       $190 = $186&255;
       $191 = $190 >>> 1;
       $193 = $191;
      } else {
       $189 = HEAP32[$64>>2]|0;
       $193 = $189;
      }
      $192 = ($184>>>0)<($193>>>0);
      if ($192) {
       if ($180) {
        $195 = $178&255;
        $196 = $195 >>> 1;
        $198 = $196;
       } else {
        $194 = HEAP32[$66>>2]|0;
        $198 = $194;
       }
       $197 = (($198) + ($e$1))|0;
       __THREW__ = 0;
       invoke_viiiii(85,($1|0),($str|0),($197|0),-1,0);
       $199 = __THREW__; __THREW__ = 0;
       $200 = $199&1;
       if ($200) {
        label = 92;
        break;
       }
       $201 = HEAP8[$1>>0]|0;
       $202 = $201 & 1;
       $203 = ($202<<24>>24)==(0);
       if ($203) {
        $208 = (($1) + 1|0);
        $209 = $201&255;
        $210 = $209 >>> 1;
        $211 = $208;$212 = $210;
       } else {
        $204 = (($1) + 8|0);
        $205 = HEAP32[$204>>2]|0;
        $206 = (($1) + 4|0);
        $207 = HEAP32[$206>>2]|0;
        $211 = $205;$212 = $207;
       }
       __THREW__ = 0;
       (invoke_iiii(1480,($remainderStr|0),($211|0),($212|0))|0);
       $213 = __THREW__; __THREW__ = 0;
       $214 = $213&1;
       if ($214) {
        $229 = ___cxa_find_matching_catch()|0;
        $230 = tempRet0;
        $231 = HEAP8[$1>>0]|0;
        $232 = $231 & 1;
        $233 = ($232<<24>>24)==(0);
        if ($233) {
         $$0 = $229;$$01 = $230;
         break;
        }
        $234 = (($1) + 8|0);
        $235 = HEAP32[$234>>2]|0;
        __ZdlPv($235);
        $$0 = $229;$$01 = $230;
        break;
       } else {
        $215 = HEAP8[$1>>0]|0;
        $216 = $215 & 1;
        $217 = ($216<<24>>24)==(0);
        if ($217) {
         label = 97;
         break;
        }
        $218 = (($1) + 8|0);
        $219 = HEAP32[$218>>2]|0;
        __ZdlPv($219);
        label = 97;
        break;
       }
      } else {
       label = 97;
      }
     }
    } while(0);
    do {
     if ((label|0) == 97) {
      $236 = HEAP8[$retVal>>0]|0;
      $237 = $236 & 1;
      $238 = ($237<<24>>24)==(0);
      if ($238) {
       ;HEAP32[$agg$result+0>>2]=HEAP32[$retVal+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$retVal+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$retVal+8>>2]|0;
       break L9;
      }
      $239 = (($retVal) + 8|0);
      $240 = HEAP32[$239>>2]|0;
      $241 = (($retVal) + 4|0);
      $242 = HEAP32[$241>>2]|0;
      $243 = ($242>>>0)>(4294967279);
      if ($243) {
       __THREW__ = 0;
       invoke_vi(3309,0);
       $244 = __THREW__; __THREW__ = 0;
       $245 = $244&1;
       if ($245) {
        label = 92;
        break;
       }
       // unreachable;
      }
      $246 = ($242>>>0)<(11);
      if ($246) {
       $247 = $242 << 1;
       $248 = $247&255;
       HEAP8[$agg$result>>0] = $248;
       $249 = (($agg$result) + 1|0);
       $__p$0$i$i$i57 = $249;
      } else {
       $250 = (($242) + 16)|0;
       $251 = $250 & -16;
       __THREW__ = 0;
       $252 = (invoke_ii(2988,($251|0))|0);
       $253 = __THREW__; __THREW__ = 0;
       $254 = $253&1;
       if ($254) {
        label = 92;
        break;
       }
       $255 = (($agg$result) + 8|0);
       HEAP32[$255>>2] = $252;
       $256 = $251 | 1;
       HEAP32[$agg$result>>2] = $256;
       $257 = (($agg$result) + 4|0);
       HEAP32[$257>>2] = $242;
       $__p$0$i$i$i57 = $252;
      }
      _memcpy(($__p$0$i$i$i57|0),($240|0),($242|0))|0;
      $258 = (($__p$0$i$i$i57) + ($242)|0);
      HEAP8[$258>>0] = 0;
      if ($238) {
       break L9;
      }
      $259 = (($retVal) + 8|0);
      $260 = HEAP32[$259>>2]|0;
      __ZdlPv($260);
      break L9;
     }
    } while(0);
    if ((label|0) == 92) {
     $220 = ___cxa_find_matching_catch()|0;
     $221 = tempRet0;
     $$0 = $220;$$01 = $221;
    }
    $261 = HEAP8[$retVal>>0]|0;
    $262 = $261 & 1;
    $263 = ($262<<24>>24)==(0);
    if ($263) {
     $$1 = $$0;$$12 = $$01;
    } else {
     $264 = (($retVal) + 8|0);
     $265 = HEAP32[$264>>2]|0;
     __ZdlPv($265);
     $$1 = $$0;$$12 = $$01;
    }
   }
   $276 = HEAP8[$endsWith>>0]|0;
   $277 = $276 & 1;
   $278 = ($277<<24>>24)==(0);
   if (!($278)) {
    $279 = HEAP32[$65>>2]|0;
    __ZdlPv($279);
   }
   $280 = HEAP8[$beginsWith>>0]|0;
   $281 = $280 & 1;
   $282 = ($281<<24>>24)==(0);
   if ($282) {
    ___resumeException($$1|0);
    // unreachable;
   }
   $283 = (($beginsWith) + 8|0);
   $284 = HEAP32[$283>>2]|0;
   __ZdlPv($284);
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 if ((label|0) == 21) {
  HEAP8[$agg$result>>0] = 0;
  $51 = (($agg$result) + 1|0);
  HEAP8[$51>>0] = 0;
 }
 $266 = HEAP8[$endsWith>>0]|0;
 $267 = $266 & 1;
 $268 = ($267<<24>>24)==(0);
 if (!($268)) {
  $269 = (($endsWith) + 8|0);
  $270 = HEAP32[$269>>2]|0;
  __ZdlPv($270);
 }
 $271 = HEAP8[$beginsWith>>0]|0;
 $272 = $271 & 1;
 $273 = ($272<<24>>24)==(0);
 if ($273) {
  STACKTOP = sp;return;
 }
 $274 = (($beginsWith) + 8|0);
 $275 = HEAP32[$274>>2]|0;
 __ZdlPv($275);
 STACKTOP = sp;return;
}
function __ZN18GlslGpuProgramGLES14CompileProgramERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_R14ChannelAssigns($this,$vprog,$fshader,$channels) {
 $this = $this|0;
 $vprog = $vprog|0;
 $fshader = $fshader|0;
 $channels = $channels|0;
 var $$$i = 0, $$0 = 0, $$0$i18 = 0, $$01 = 0, $$01$be$i$i$i$i$i = 0, $$01$be$i$i$i$i$i$i = 0, $$01$be$i$i$i$i17$i$i = 0, $$01$be$i$i$i$i30$i$i = 0, $$01$be$i$i$i$i5$i = 0, $$01$be$i$i$i$i5$i$i = 0, $$01$i = 0, $$014$i$i$i$i$i = 0, $$014$i$i$i$i$i$i = 0, $$014$i$i$i$i16$i$i = 0, $$014$i$i$i$i29$i$i = 0, $$014$i$i$i$i4$i = 0, $$014$i$i$i$i4$i$i = 0, $$02 = 0, $$1 = 0, $$1$i = 0;
 var $$12$i = 0, $$13 = 0, $$26$i = 0, $$29$i = 0, $$30$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre4$i$i = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i = 0, $$sum$i$i14$i$i = 0, $$sum$i$i2$i = 0, $$sum$i$i2$i$i = 0, $$sum$i$i27$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0;
 var $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0;
 var $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0;
 var $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0;
 var $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0;
 var $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0;
 var $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0;
 var $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__m1$0$i$i$i$i$i = 0, $__m1$0$i$i$i$i$i$i = 0, $__m1$0$i$i$i$i19$i$i = 0, $__m1$0$i$i$i$i32$i$i = 0, $__m1$0$i$i$i$i7$i = 0, $__m1$0$i$i$i$i7$i$i = 0, $__m2$0$i$i$i$i$i = 0, $__m2$0$i$i$i$i$i$i = 0, $__m2$0$i$i$i$i20$i$i = 0, $__m2$0$i$i$i$i33$i$i = 0, $__m2$0$i$i$i$i8$i = 0;
 var $__m2$0$i$i$i$i8$i$i = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i$i = 0, $binaryData$2 = 0, $binaryLength = 0, $binaryPath = 0, $compileInfoLog$i = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, $filename = 0, $infoLogLength$i = 0, $line_start$1$i$i = 0, $line_start$2$i$i = 0, $linked = 0, $linked1 = 0, $lpad$phi$i$index = 0, $lpad$phi$i$index7 = 0, $modSource$i = 0, $modSourceHeader$i = 0, $modSourceProg$i = 0;
 var $or$cond$i$i$i$i = 0, $phitmp$i$i$i$i = 0, $prec_modifier$i = 0, $result$0$off0$i = 0, $texCubeEntry$047$i$i = 0, $vararg_buffer15 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4256|0;
 $vararg_buffer15 = sp;
 $compileInfoLog$i = sp + 120|0;
 $infoLogLength$i = sp + 100|0;
 $modSourceHeader$i = sp + 88|0;
 $modSourceProg$i = sp + 76|0;
 $prec_modifier$i = sp + 64|0;
 $modSource$i = sp + 52|0;
 $0 = sp + 104|0;
 $binaryPath = sp + 32|0;
 $filename = sp + 4216|0;
 $1 = sp + 20|0;
 $2 = sp + 8|0;
 $binaryLength = sp + 4|0;
 $linked = sp + 44|0;
 $linked1 = sp + 48|0;
 ;HEAP32[$binaryPath+0>>2]=0|0;HEAP32[$binaryPath+4>>2]=0|0;HEAP32[$binaryPath+8>>2]=0|0;
 $3 = HEAP32[1152880>>2]|0;
 $4 = (($3) + 63|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 L1: do {
  if ($6) {
   label = 22;
  } else {
   dest=$filename+0|0; stop=dest+33|0; do { HEAP8[dest>>0]=49|0; dest=dest+1|0; } while ((dest|0) < (stop|0));
   $7 = HEAP32[1151424>>2]|0;
   $8 = (_strlen(($7|0))|0);
   $9 = ($8>>>0)>(4294967279);
   if ($9) {
    __THREW__ = 0;
    invoke_vi(3309,0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     label = 15;
     break;
    }
    // unreachable;
   }
   $12 = ($8>>>0)<(11);
   if ($12) {
    $13 = $8 << 1;
    $14 = $13&255;
    HEAP8[$2>>0] = $14;
    $15 = (($2) + 1|0);
    $__p$0$i$i$i = $15;
   } else {
    $16 = (($8) + 16)|0;
    $17 = $16 & -16;
    __THREW__ = 0;
    $18 = (invoke_ii(2988,($17|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 15;
     break;
    }
    $21 = (($2) + 8|0);
    HEAP32[$21>>2] = $18;
    $22 = $17 | 1;
    HEAP32[$2>>2] = $22;
    $23 = (($2) + 4|0);
    HEAP32[$23>>2] = $8;
    $__p$0$i$i$i = $18;
   }
   _memcpy(($__p$0$i$i$i|0),($7|0),($8|0))|0;
   $24 = (($__p$0$i$i$i) + ($8)|0);
   HEAP8[$24>>0] = 0;
   __THREW__ = 0;
   invoke_viii(1627,($1|0),($2|0),($filename|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   do {
    if ($26) {
     $41 = ___cxa_find_matching_catch()|0;
     $42 = tempRet0;
     $$01 = $41;$$02 = $42;
    } else {
     __THREW__ = 0;
     (invoke_iii(2233,($binaryPath|0),($1|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      $43 = ___cxa_find_matching_catch()|0;
      $44 = tempRet0;
      $45 = HEAP8[$1>>0]|0;
      $46 = $45 & 1;
      $47 = ($46<<24>>24)==(0);
      if ($47) {
       $$01 = $43;$$02 = $44;
       break;
      }
      $48 = (($1) + 8|0);
      $49 = HEAP32[$48>>2]|0;
      __ZdlPv($49);
      $$01 = $43;$$02 = $44;
      break;
     }
     $29 = HEAP8[$1>>0]|0;
     $30 = $29 & 1;
     $31 = ($30<<24>>24)==(0);
     if (!($31)) {
      $32 = (($1) + 8|0);
      $33 = HEAP32[$32>>2]|0;
      __ZdlPv($33);
     }
     $34 = HEAP8[$2>>0]|0;
     $35 = $34 & 1;
     $36 = ($35<<24>>24)==(0);
     if ($36) {
      label = 22;
      break L1;
     }
     $37 = (($2) + 8|0);
     $38 = HEAP32[$37>>2]|0;
     __ZdlPv($38);
     label = 22;
     break L1;
    }
   } while(0);
   $50 = HEAP8[$2>>0]|0;
   $51 = $50 & 1;
   $52 = ($51<<24>>24)==(0);
   if ($52) {
    $$1 = $$01;$$13 = $$02;
   } else {
    $53 = (($2) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    __ZdlPv($54);
    $$1 = $$01;$$13 = $$02;
   }
  }
 } while(0);
 L25: do {
  if ((label|0) == 22) {
   HEAP32[$binaryLength>>2] = 0;
   $55 = HEAP32[1152880>>2]|0;
   $56 = (($55) + 63|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ($57<<24>>24)==(0);
   do {
    if ($58) {
     label = 34;
    } else {
     $59 = HEAP8[$binaryPath>>0]|0;
     $60 = $59 & 1;
     $61 = ($60<<24>>24)==(0);
     if ($61) {
      $64 = (($binaryPath) + 1|0);
      $65 = $64;
     } else {
      $62 = (($binaryPath) + 8|0);
      $63 = HEAP32[$62>>2]|0;
      $65 = $63;
     }
     $66 = (_fopen(($65|0),(1150560|0))|0);
     $67 = ($66|0)==(0|0);
     if ($67) {
      label = 34;
     } else {
      (_fseek(($66|0),0,2)|0);
      $68 = (_ftell(($66|0))|0);
      (_fseek(($66|0),0,0)|0);
      $69 = (_malloc($68)|0);
      $70 = (($69) + 4|0);
      $71 = (($68) + -4)|0;
      HEAP32[$binaryLength>>2] = $71;
      (_fread(($69|0),($68|0),1,($66|0))|0);
      (_fclose(($66|0))|0);
      $72 = (($this) + 16|0);
      $73 = HEAP32[$72>>2]|0;
      __THREW__ = 0;
      $74 = (invoke_iiii(1639,($vprog|0),($channels|0),($73|0))|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 15;
       break L25;
      }
      if (!($74)) {
       _free($69);
       label = 34;
       break;
      }
      $77 = (1147664 + 504|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = HEAP32[$72>>2]|0;
      $80 = HEAP32[$69>>2]|0;
      $81 = HEAP32[$binaryLength>>2]|0;
      __THREW__ = 0;
      invoke_viiii($78|0,($79|0),($80|0),($70|0),($81|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       label = 15;
       break L25;
      }
      HEAP32[$linked>>2] = 0;
      $84 = (1147664 + 216|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = HEAP32[$72>>2]|0;
      __THREW__ = 0;
      invoke_viii($85|0,($86|0),35714,($linked|0));
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 15;
       break L25;
      }
      $89 = HEAP32[$linked>>2]|0;
      $90 = ($89|0)==(0);
      if ($90) {
       _free($69);
       label = 34;
      } else {
       $binaryData$2 = $69;
       label = 224;
      }
     }
    }
   } while(0);
   L41: do {
    if ((label|0) == 34) {
     $91 = (($this) + 16|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = (($this) + 24|0);
     $94 = HEAP32[1152880>>2]|0;
     $95 = (($94) + 12|0);
     $96 = HEAP32[$95>>2]|0;
     $97 = ($96|0)==(0);
     L43: do {
      if ($97) {
       $98 = HEAP8[$vprog>>0]|0;
       $99 = $98 & 1;
       $100 = ($99<<24>>24)==(0);
       if ($100) {
        $103 = $98&255;
        $104 = $103 >>> 1;
        $106 = $104;
       } else {
        $101 = (($vprog) + 4|0);
        $102 = HEAP32[$101>>2]|0;
        $106 = $102;
       }
       $105 = ($106>>>0)<(9);
       L49: do {
        if ($105) {
         label = 50;
        } else {
         if ($100) {
          $109 = (($vprog) + 1|0);
          $111 = $109;
         } else {
          $107 = (($vprog) + 8|0);
          $108 = HEAP32[$107>>2]|0;
          $111 = $108;
         }
         $110 = (($111) + ($106)|0);
         $112 = $111;
         $113 = ($106|0)<(9);
         if ($113) {
          label = 50;
         } else {
          $$sum$i$i$i = (($106) + -8)|0;
          $114 = (($111) + ($$sum$i$i$i)|0);
          $115 = ($$sum$i$i$i|0)==(0);
          if ($115) {
           label = 50;
          } else {
           $$014$i$i$i$i$i = $111;
           L56: while(1) {
            $116 = HEAP8[$$014$i$i$i$i$i>>0]|0;
            $117 = ($116<<24>>24)==(116);
            if ($117) {
             $__m1$0$i$i$i$i$i = $$014$i$i$i$i$i;$__m2$0$i$i$i$i$i = 1151328;
             while(1) {
              $119 = (($__m2$0$i$i$i$i$i) + 1|0);
              $120 = ($119|0)==(((1151328 + 9|0))|0);
              if ($120) {
               break L56;
              }
              $121 = (($__m1$0$i$i$i$i$i) + 1|0);
              $122 = HEAP8[$121>>0]|0;
              $123 = HEAP8[$119>>0]|0;
              $124 = ($122<<24>>24)==($123<<24>>24);
              if ($124) {
               $__m1$0$i$i$i$i$i = $121;$__m2$0$i$i$i$i$i = $119;
              } else {
               break;
              }
             }
            }
            $$01$be$i$i$i$i$i = (($$014$i$i$i$i$i) + 1|0);
            $118 = ($$01$be$i$i$i$i$i|0)==($114|0);
            if ($118) {
             label = 50;
             break L49;
            } else {
             $$014$i$i$i$i$i = $$01$be$i$i$i$i$i;
            }
           }
           $125 = ($$014$i$i$i$i$i|0)==($110|0);
           if ($125) {
            label = 50;
           } else {
            $126 = $$014$i$i$i$i$i;
            $127 = (($126) - ($112))|0;
            $128 = ($127|0)==(-1);
            if ($128) {
             label = 50;
            }
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 50) {
        if ($100) {
         $131 = $98&255;
         $132 = $131 >>> 1;
         $134 = $132;
        } else {
         $129 = (($vprog) + 4|0);
         $130 = HEAP32[$129>>2]|0;
         $134 = $130;
        }
        $133 = ($134>>>0)<(5);
        if ($133) {
         break;
        }
        if ($100) {
         $137 = (($vprog) + 1|0);
         $139 = $137;
        } else {
         $135 = (($vprog) + 8|0);
         $136 = HEAP32[$135>>2]|0;
         $139 = $136;
        }
        $138 = (($139) + ($134)|0);
        $140 = $139;
        $141 = ($134|0)<(5);
        if ($141) {
         break;
        }
        $$sum$i$i2$i = (($134) + -4)|0;
        $142 = (($139) + ($$sum$i$i2$i)|0);
        $143 = ($$sum$i$i2$i|0)==(0);
        if ($143) {
         break;
        } else {
         $$014$i$i$i$i4$i = $139;
        }
        L77: while(1) {
         $144 = HEAP8[$$014$i$i$i$i4$i>>0]|0;
         $145 = ($144<<24>>24)==(116);
         if ($145) {
          $__m1$0$i$i$i$i7$i = $$014$i$i$i$i4$i;$__m2$0$i$i$i$i8$i = 1151344;
          while(1) {
           $147 = (($__m2$0$i$i$i$i8$i) + 1|0);
           $148 = ($147|0)==(((1151344 + 5|0))|0);
           if ($148) {
            break L77;
           }
           $149 = (($__m1$0$i$i$i$i7$i) + 1|0);
           $150 = HEAP8[$149>>0]|0;
           $151 = HEAP8[$147>>0]|0;
           $152 = ($150<<24>>24)==($151<<24>>24);
           if ($152) {
            $__m1$0$i$i$i$i7$i = $149;$__m2$0$i$i$i$i8$i = $147;
           } else {
            break;
           }
          }
         }
         $$01$be$i$i$i$i5$i = (($$014$i$i$i$i4$i) + 1|0);
         $146 = ($$01$be$i$i$i$i5$i|0)==($142|0);
         if ($146) {
          break L43;
         } else {
          $$014$i$i$i$i4$i = $$01$be$i$i$i$i5$i;
         }
        }
        $153 = ($$014$i$i$i$i4$i|0)==($138|0);
        if ($153) {
         break;
        }
        $154 = $$014$i$i$i$i4$i;
        $155 = (($154) - ($140))|0;
        $156 = ($155|0)==(-1);
        if ($156) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_viiiiiiii(21,(1151352|0),0,(1150592|0),322,1,0,0,(0|0));
       $157 = __THREW__; __THREW__ = 0;
       $158 = $157&1;
       if ($158) {
        label = 15;
        break L25;
       } else {
        $$0 = 0;
        break L41;
       }
      }
     } while(0);
     $159 = (1147664 + 88|0);
     $160 = HEAP32[$159>>2]|0;
     __THREW__ = 0;
     $161 = (invoke_ii($160|0,35633)|0);
     $162 = __THREW__; __THREW__ = 0;
     $163 = $162&1;
     if ($163) {
      label = 15;
      break L25;
     }
     HEAP32[$93>>2] = $161;
     __THREW__ = 0;
     (invoke_iiii(1639,($vprog|0),($channels|0),($92|0))|0);
     $164 = __THREW__; __THREW__ = 0;
     $165 = $164&1;
     if ($165) {
      label = 15;
      break L25;
     }
     $166 = HEAP8[$vprog>>0]|0;
     $167 = $166 & 1;
     $168 = ($167<<24>>24)==(0);
     if ($168) {
      $171 = (($vprog) + 1|0);
      $173 = $171;
     } else {
      $169 = (($vprog) + 8|0);
      $170 = HEAP32[$169>>2]|0;
      $173 = $170;
     }
     $172 = HEAP32[$93>>2]|0;
     __THREW__ = 0;
     $174 = (invoke_iiii(1636,($172|0),1,($173|0))|0);
     $175 = __THREW__; __THREW__ = 0;
     $176 = $175&1;
     if ($176) {
      label = 15;
      break L25;
     }
     if ($174) {
      $177 = (($this) + 28|0);
      $178 = (1147664 + 88|0);
      $179 = HEAP32[$178>>2]|0;
      __THREW__ = 0;
      $180 = (invoke_ii($179|0,35632)|0);
      $181 = __THREW__; __THREW__ = 0;
      $182 = $181&1;
      if ($182) {
       label = 15;
       break L25;
      }
      HEAP32[$177>>2] = $180;
      ;HEAP32[$modSourceHeader$i+0>>2]=0|0;HEAP32[$modSourceHeader$i+4>>2]=0|0;HEAP32[$modSourceHeader$i+8>>2]=0|0;
      ;HEAP32[$modSourceProg$i+0>>2]=0|0;HEAP32[$modSourceProg$i+4>>2]=0|0;HEAP32[$modSourceProg$i+8>>2]=0|0;
      $183 = HEAP8[$fshader>>0]|0;
      $184 = $183 & 1;
      $185 = ($184<<24>>24)==(0);
      if ($185) {
       $188 = (($fshader) + 1|0);
       $190 = $188;
      } else {
       $186 = (($fshader) + 8|0);
       $187 = HEAP32[$186>>2]|0;
       $190 = $187;
      }
      $189 = HEAP8[$190>>0]|0;
      $191 = ($189<<24>>24)==(0);
      L101: do {
       if ($191) {
        label = 98;
       } else {
        $193 = $189;$line_start$1$i$i = $190;
        L102: while(1) {
         $192 = $193 << 24 >> 24;
         __THREW__ = 0;
         $194 = (invoke_ii(3460,($192|0))|0);
         $195 = __THREW__; __THREW__ = 0;
         $196 = $195&1;
         if ($196) {
          label = 184;
          break;
         }
         $197 = ($194|0)==(0);
         $198 = (($line_start$1$i$i) + 1|0);
         if (!($197)) {
          $$pre4$i$i = HEAP8[$198>>0]|0;
          $193 = $$pre4$i$i;$line_start$1$i$i = $198;
          continue;
         }
         $199 = HEAP8[$line_start$1$i$i>>0]|0;
         $200 = ($199<<24>>24)==(35);
         if ($200) {
          $594 = 35;$line_start$2$i$i = $line_start$1$i$i;
         } else {
          break;
         }
         while(1) {
          if ((($594<<24>>24) == 13) | (($594<<24>>24) == 10)) {
           $193 = $594;$line_start$1$i$i = $line_start$2$i$i;
           continue L102;
          }
          $201 = (($line_start$2$i$i) + 1|0);
          $$pre$i$i = HEAP8[$201>>0]|0;
          $594 = $$pre$i$i;$line_start$2$i$i = $201;
         }
        }
        if ((label|0) == 184) {
         $466 = ___cxa_find_matching_catch()|0;
         $467 = tempRet0;
         $lpad$phi$i$index = $466;$lpad$phi$i$index7 = $467;
         label = 186;
         break;
        }
        $202 = $line_start$1$i$i;
        $203 = $190;
        $204 = (($202) - ($203))|0;
        $205 = HEAP8[$modSourceHeader$i>>0]|0;
        $206 = $205 & 1;
        $207 = ($206<<24>>24)==(0);
        if ($207) {
         $212 = 10;$214 = $205;
        } else {
         $208 = HEAP32[$modSourceHeader$i>>2]|0;
         $209 = $208 & -2;
         $phitmp$i$i$i$i = (($209) + -1)|0;
         $210 = $208&255;
         $212 = $phitmp$i$i$i$i;$214 = $210;
        }
        $211 = ($212>>>0)<($204>>>0);
        $213 = $214 & 1;
        $215 = ($213<<24>>24)==(0);
        do {
         if ($211) {
          if ($215) {
           $229 = $214&255;
           $230 = $229 >>> 1;
           $232 = $230;
          } else {
           $227 = (($modSourceHeader$i) + 4|0);
           $228 = HEAP32[$227>>2]|0;
           $232 = $228;
          }
          $231 = (($204) - ($212))|0;
          __THREW__ = 0;
          invoke_viiiiiiii(29,($modSourceHeader$i|0),($212|0),($231|0),($232|0),0,($232|0),($204|0),($190|0));
          $233 = __THREW__; __THREW__ = 0;
          $234 = $233&1;
          if ($234) {
           label = 185;
           break L101;
          }
         } else {
          if ($215) {
           $218 = (($modSourceHeader$i) + 1|0);
           $219 = $218;
          } else {
           $216 = (($modSourceHeader$i) + 8|0);
           $217 = HEAP32[$216>>2]|0;
           $219 = $217;
          }
          _memmove(($219|0),($190|0),($204|0))|0;
          $220 = (($219) + ($204)|0);
          HEAP8[$220>>0] = 0;
          $221 = HEAP8[$modSourceHeader$i>>0]|0;
          $222 = $221 & 1;
          $223 = ($222<<24>>24)==(0);
          if ($223) {
           $225 = $204 << 1;
           $226 = $225&255;
           HEAP8[$modSourceHeader$i>>0] = $226;
           break;
          } else {
           $224 = (($modSourceHeader$i) + 4|0);
           HEAP32[$224>>2] = $204;
           break;
          }
         }
        } while(0);
        __THREW__ = 0;
        (invoke_iii(2392,($modSourceProg$i|0),($line_start$1$i$i|0))|0);
        $235 = __THREW__; __THREW__ = 0;
        $236 = $235&1;
        if ($236) {
         label = 185;
        } else {
         label = 98;
        }
       }
      } while(0);
      do {
       if ((label|0) == 98) {
        $237 = HEAP32[1152880>>2]|0;
        $238 = (($237) + 80|0);
        $239 = HEAP8[$238>>0]|0;
        $240 = ($239<<24>>24)!=(0);
        $241 = $240 ? 1150944 : 1150968;
        $242 = (_strlen(($241|0))|0);
        $243 = ($242>>>0)>(4294967279);
        if ($243) {
         __THREW__ = 0;
         invoke_vi(3309,0);
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if ($245) {
          label = 185;
          break;
         }
         // unreachable;
        }
        $246 = ($242>>>0)<(11);
        if ($246) {
         $247 = $242 << 1;
         $248 = $247&255;
         HEAP8[$prec_modifier$i>>0] = $248;
         $249 = (($prec_modifier$i) + 1|0);
         $__p$0$i$i$i$i = $249;
        } else {
         $250 = (($242) + 16)|0;
         $251 = $250 & -16;
         __THREW__ = 0;
         $252 = (invoke_ii(2988,($251|0))|0);
         $253 = __THREW__; __THREW__ = 0;
         $254 = $253&1;
         if ($254) {
          label = 185;
          break;
         }
         $255 = (($prec_modifier$i) + 8|0);
         HEAP32[$255>>2] = $252;
         $256 = $251 | 1;
         HEAP32[$prec_modifier$i>>2] = $256;
         $257 = (($prec_modifier$i) + 4|0);
         HEAP32[$257>>2] = $242;
         $__p$0$i$i$i$i = $252;
        }
        _memcpy(($__p$0$i$i$i$i|0),($241|0),($242|0))|0;
        $258 = (($__p$0$i$i$i$i) + ($242)|0);
        HEAP8[$258>>0] = 0;
        __THREW__ = 0;
        invoke_viii(1774,($0|0),($modSourceHeader$i|0),($prec_modifier$i|0));
        $259 = __THREW__; __THREW__ = 0;
        $260 = $259&1;
        do {
         if ($260) {
          $470 = ___cxa_find_matching_catch()|0;
          $471 = tempRet0;
          $$0$i18 = $470;$$01$i = $471;
         } else {
          __THREW__ = 0;
          invoke_viii(1774,($modSource$i|0),($0|0),($modSourceProg$i|0));
          $261 = __THREW__; __THREW__ = 0;
          $262 = $261&1;
          if ($262) {
           $472 = ___cxa_find_matching_catch()|0;
           $473 = tempRet0;
           $474 = HEAP8[$0>>0]|0;
           $475 = $474 & 1;
           $476 = ($475<<24>>24)==(0);
           if ($476) {
            $$0$i18 = $472;$$01$i = $473;
            break;
           }
           $477 = (($0) + 8|0);
           $478 = HEAP32[$477>>2]|0;
           __ZdlPv($478);
           $$0$i18 = $472;$$01$i = $473;
           break;
          }
          $263 = HEAP8[$0>>0]|0;
          $264 = $263 & 1;
          $265 = ($264<<24>>24)==(0);
          if (!($265)) {
           $266 = (($0) + 8|0);
           $267 = HEAP32[$266>>2]|0;
           __ZdlPv($267);
          }
          $268 = HEAP32[$177>>2]|0;
          $269 = HEAP8[$modSource$i>>0]|0;
          $270 = $269 & 1;
          $271 = ($270<<24>>24)==(0);
          if ($271) {
           $274 = (($modSource$i) + 1|0);
           $275 = $274;
          } else {
           $272 = (($modSource$i) + 8|0);
           $273 = HEAP32[$272>>2]|0;
           $275 = $273;
          }
          __THREW__ = 0;
          $276 = (invoke_iiii(1636,($268|0),2,($275|0))|0);
          $277 = __THREW__; __THREW__ = 0;
          $278 = $277&1;
          L156: do {
           if (!($278)) {
            do {
             if ($276) {
              $result$0$off0$i = 1;
             } else {
              $279 = HEAP32[1152880>>2]|0;
              $280 = (($279) + 81|0);
              $281 = HEAP8[$280>>0]|0;
              $282 = ($281<<24>>24)==(0);
              if ($282) {
               $result$0$off0$i = 0;
               break;
              }
              $283 = HEAP32[$177>>2]|0;
              $284 = HEAP8[$modSource$i>>0]|0;
              $285 = $284 & 1;
              $286 = ($285<<24>>24)==(0);
              if ($286) {
               $289 = $284&255;
               $290 = $289 >>> 1;
               $292 = $290;
              } else {
               $287 = (($modSource$i) + 4|0);
               $288 = HEAP32[$287>>2]|0;
               $292 = $288;
              }
              $291 = ($292>>>0)<(17);
              L165: do {
               if ($291) {
                label = 130;
               } else {
                if ($286) {
                 $295 = (($modSource$i) + 1|0);
                 $297 = $295;
                } else {
                 $293 = (($modSource$i) + 8|0);
                 $294 = HEAP32[$293>>2]|0;
                 $297 = $294;
                }
                $296 = (($297) + ($292)|0);
                $298 = $297;
                $299 = ($292|0)<(17);
                if ($299) {
                 label = 130;
                 break;
                }
                $$sum$i$i$i$i = (($292) + -16)|0;
                $300 = (($297) + ($$sum$i$i$i$i)|0);
                $301 = ($$sum$i$i$i$i|0)==(0);
                if ($301) {
                 label = 130;
                 break;
                } else {
                 $$014$i$i$i$i$i$i = $297;
                }
                L172: while(1) {
                 $302 = HEAP8[$$014$i$i$i$i$i$i>>0]|0;
                 $303 = ($302<<24>>24)==(116);
                 if ($303) {
                  $__m1$0$i$i$i$i$i$i = $$014$i$i$i$i$i$i;$__m2$0$i$i$i$i$i$i = 1151000;
                  while(1) {
                   $305 = (($__m2$0$i$i$i$i$i$i) + 1|0);
                   $306 = ($305|0)==(((1151000 + 17|0))|0);
                   if ($306) {
                    break L172;
                   }
                   $307 = (($__m1$0$i$i$i$i$i$i) + 1|0);
                   $308 = HEAP8[$307>>0]|0;
                   $309 = HEAP8[$305>>0]|0;
                   $310 = ($308<<24>>24)==($309<<24>>24);
                   if ($310) {
                    $__m1$0$i$i$i$i$i$i = $307;$__m2$0$i$i$i$i$i$i = $305;
                   } else {
                    break;
                   }
                  }
                 }
                 $$01$be$i$i$i$i$i$i = (($$014$i$i$i$i$i$i) + 1|0);
                 $304 = ($$01$be$i$i$i$i$i$i|0)==($300|0);
                 if ($304) {
                  label = 130;
                  break L165;
                 } else {
                  $$014$i$i$i$i$i$i = $$01$be$i$i$i$i$i$i;
                 }
                }
                $311 = ($$014$i$i$i$i$i$i|0)==($296|0);
                if ($311) {
                 label = 130;
                 break;
                }
                $312 = $$014$i$i$i$i$i$i;
                $313 = (($312) - ($298))|0;
                $314 = ($313|0)==(-1);
                if ($314) {
                 label = 130;
                } else {
                 label = 145;
                }
               }
              } while(0);
              L181: do {
               if ((label|0) == 130) {
                if ($286) {
                 $317 = $284&255;
                 $318 = $317 >>> 1;
                 $320 = $318;
                } else {
                 $315 = (($modSource$i) + 4|0);
                 $316 = HEAP32[$315>>2]|0;
                 $320 = $316;
                }
                $319 = ($320>>>0)<(18);
                if ($319) {
                 $457 = $284;
                 break;
                }
                if ($286) {
                 $323 = (($modSource$i) + 1|0);
                 $325 = $323;
                } else {
                 $321 = (($modSource$i) + 8|0);
                 $322 = HEAP32[$321>>2]|0;
                 $325 = $322;
                }
                $324 = (($325) + ($320)|0);
                $326 = $325;
                $327 = ($320|0)<(18);
                if ($327) {
                 $457 = $284;
                 break;
                }
                $$sum$i$i2$i$i = (($320) + -17)|0;
                $328 = (($325) + ($$sum$i$i2$i$i)|0);
                $329 = ($$sum$i$i2$i$i|0)==(0);
                if ($329) {
                 $457 = $284;
                 break;
                } else {
                 $$014$i$i$i$i4$i$i = $325;
                }
                L193: while(1) {
                 $330 = HEAP8[$$014$i$i$i$i4$i$i>>0]|0;
                 $331 = ($330<<24>>24)==(116);
                 if ($331) {
                  $__m1$0$i$i$i$i7$i$i = $$014$i$i$i$i4$i$i;$__m2$0$i$i$i$i8$i$i = 1151024;
                  while(1) {
                   $333 = (($__m2$0$i$i$i$i8$i$i) + 1|0);
                   $334 = ($333|0)==(((1151024 + 18|0))|0);
                   if ($334) {
                    break L193;
                   }
                   $335 = (($__m1$0$i$i$i$i7$i$i) + 1|0);
                   $336 = HEAP8[$335>>0]|0;
                   $337 = HEAP8[$333>>0]|0;
                   $338 = ($336<<24>>24)==($337<<24>>24);
                   if ($338) {
                    $__m1$0$i$i$i$i7$i$i = $335;$__m2$0$i$i$i$i8$i$i = $333;
                   } else {
                    break;
                   }
                  }
                 }
                 $$01$be$i$i$i$i5$i$i = (($$014$i$i$i$i4$i$i) + 1|0);
                 $332 = ($$01$be$i$i$i$i5$i$i|0)==($328|0);
                 if ($332) {
                  $457 = $284;
                  break L181;
                 } else {
                  $$014$i$i$i$i4$i$i = $$01$be$i$i$i$i5$i$i;
                 }
                }
                $339 = ($$014$i$i$i$i4$i$i|0)==($324|0);
                if ($339) {
                 $457 = $284;
                 break;
                }
                $340 = $$014$i$i$i$i4$i$i;
                $341 = (($340) - ($326))|0;
                $342 = ($341|0)==(-1);
                if ($342) {
                 $457 = $284;
                } else {
                 label = 145;
                }
               }
              } while(0);
              L202: do {
               if ((label|0) == 145) {
                __THREW__ = 0;
                invoke_vii(2587,(1151048|0),($vararg_buffer15|0));
                $343 = __THREW__; __THREW__ = 0;
                $344 = $343&1;
                if ($344) {
                 break L156;
                }
                __THREW__ = 0;
                invoke_vii(2587,(1151112|0),($vararg_buffer15|0));
                $345 = __THREW__; __THREW__ = 0;
                $346 = $345&1;
                if ($346) {
                 break L156;
                }
                __THREW__ = 0;
                invoke_vii(2587,(1151184|0),($vararg_buffer15|0));
                $347 = __THREW__; __THREW__ = 0;
                $348 = $347&1;
                if ($348) {
                 break L156;
                }
                $349 = HEAP8[$modSource$i>>0]|0;
                $350 = $349 & 1;
                $351 = ($350<<24>>24)==(0);
                if ($351) {
                 $354 = $349&255;
                 $355 = $354 >>> 1;
                 $357 = $355;
                } else {
                 $352 = (($modSource$i) + 4|0);
                 $353 = HEAP32[$352>>2]|0;
                 $357 = $353;
                }
                $356 = ($357>>>0)<(11);
                if ($356) {
                 $457 = $349;
                 break;
                }
                if ($351) {
                 $360 = (($modSource$i) + 1|0);
                 $362 = $360;
                } else {
                 $358 = (($modSource$i) + 8|0);
                 $359 = HEAP32[$358>>2]|0;
                 $362 = $359;
                }
                $361 = (($362) + ($357)|0);
                $363 = $362;
                $364 = ($357|0)<(11);
                if ($364) {
                 $457 = $349;
                 break;
                }
                $$sum$i$i14$i$i = (($357) + -10)|0;
                $365 = (($362) + ($$sum$i$i14$i$i)|0);
                $366 = ($$sum$i$i14$i$i|0)==(0);
                if ($366) {
                 $457 = $349;
                 break;
                } else {
                 $$014$i$i$i$i16$i$i = $362;
                }
                L217: while(1) {
                 $367 = HEAP8[$$014$i$i$i$i16$i$i>>0]|0;
                 $368 = ($367<<24>>24)==(116);
                 if ($368) {
                  $__m1$0$i$i$i$i19$i$i = $$014$i$i$i$i16$i$i;$__m2$0$i$i$i$i20$i$i = 1151296;
                  while(1) {
                   $370 = (($__m2$0$i$i$i$i20$i$i) + 1|0);
                   $371 = ($370|0)==(((1151296 + 11|0))|0);
                   if ($371) {
                    break L217;
                   }
                   $372 = (($__m1$0$i$i$i$i19$i$i) + 1|0);
                   $373 = HEAP8[$372>>0]|0;
                   $374 = HEAP8[$370>>0]|0;
                   $375 = ($373<<24>>24)==($374<<24>>24);
                   if ($375) {
                    $__m1$0$i$i$i$i19$i$i = $372;$__m2$0$i$i$i$i20$i$i = $370;
                   } else {
                    break;
                   }
                  }
                 }
                 $$01$be$i$i$i$i17$i$i = (($$014$i$i$i$i16$i$i) + 1|0);
                 $369 = ($$01$be$i$i$i$i17$i$i|0)==($365|0);
                 if ($369) {
                  $457 = $349;
                  break L202;
                 } else {
                  $$014$i$i$i$i16$i$i = $$01$be$i$i$i$i17$i$i;
                 }
                }
                $376 = ($$014$i$i$i$i16$i$i|0)==($361|0);
                if ($376) {
                 $457 = $349;
                 break;
                }
                $377 = $$014$i$i$i$i16$i$i;
                $378 = (($377) - ($363))|0;
                $379 = ($378|0)==(-1);
                if ($379) {
                 $457 = $349;
                 break;
                }
                $380 = (($modSource$i) + 1|0);
                $381 = (($modSource$i) + 8|0);
                $382 = (($modSource$i) + 4|0);
                $$pre$i = HEAP32[$381>>2]|0;
                $385 = $349;$387 = $$pre$i;$texCubeEntry$047$i$i = $378;
                while(1) {
                 $383 = (($texCubeEntry$047$i$i) + 11)|0;
                 $384 = $385 & 1;
                 $386 = ($384<<24>>24)==(0);
                 $$$i = $386 ? $380 : $387;
                 $388 = (($$$i) + ($383)|0);
                 $389 = (_strncmp(1151312,$388,6)|0);
                 $390 = ($389|0)==(0);
                 do {
                  if ($390) {
                   $391 = (($texCubeEntry$047$i$i) + 14)|0;
                   $392 = (($$$i) + ($391)|0);
                   HEAP8[$392>>0] = 32;
                   $393 = (($texCubeEntry$047$i$i) + 15)|0;
                   $394 = HEAP8[$modSource$i>>0]|0;
                   $395 = $394 & 1;
                   $396 = ($395<<24>>24)==(0);
                   $397 = HEAP32[$381>>2]|0;
                   $398 = $396 ? $380 : $397;
                   $399 = (($398) + ($393)|0);
                   HEAP8[$399>>0] = 32;
                   $400 = (($texCubeEntry$047$i$i) + 16)|0;
                   $401 = HEAP8[$modSource$i>>0]|0;
                   $402 = $401 & 1;
                   $403 = ($402<<24>>24)==(0);
                   $404 = HEAP32[$381>>2]|0;
                   $$26$i = $403 ? $380 : $404;
                   $405 = (($$26$i) + ($400)|0);
                   HEAP8[$405>>0] = 32;
                  } else {
                   $406 = (_strncmp(1151320,$388,7)|0);
                   $407 = ($406|0)==(0);
                   if (!($407)) {
                    break;
                   }
                   $408 = (($texCubeEntry$047$i$i) + 15)|0;
                   $409 = (($$$i) + ($408)|0);
                   HEAP8[$409>>0] = 65;
                   $410 = (($texCubeEntry$047$i$i) + 16)|0;
                   $411 = HEAP8[$modSource$i>>0]|0;
                   $412 = $411 & 1;
                   $413 = ($412<<24>>24)==(0);
                   $414 = HEAP32[$381>>2]|0;
                   $415 = $413 ? $380 : $414;
                   $416 = (($415) + ($410)|0);
                   HEAP8[$416>>0] = 82;
                   $417 = (($texCubeEntry$047$i$i) + 17)|0;
                   $418 = HEAP8[$modSource$i>>0]|0;
                   $419 = $418 & 1;
                   $420 = ($419<<24>>24)==(0);
                   $421 = HEAP32[$381>>2]|0;
                   $$29$i = $420 ? $380 : $421;
                   $422 = (($$29$i) + ($417)|0);
                   HEAP8[$422>>0] = 66;
                  }
                 } while(0);
                 $423 = HEAP8[$modSource$i>>0]|0;
                 $424 = $423 & 1;
                 $425 = ($424<<24>>24)==(0);
                 if ($425) {
                  $427 = $423&255;
                  $428 = $427 >>> 1;
                  $430 = $428;
                 } else {
                  $426 = HEAP32[$382>>2]|0;
                  $430 = $426;
                 }
                 $429 = ($430>>>0)<($383>>>0);
                 $431 = (($430) - ($383))|0;
                 $432 = ($431>>>0)<(11);
                 $or$cond$i$i$i$i = $429 | $432;
                 if ($or$cond$i$i$i$i) {
                  $457 = $423;
                  break L202;
                 }
                 $437 = HEAP32[$381>>2]|0;
                 $$30$i = $425 ? $380 : $437;
                 $438 = (($$30$i) + ($383)|0);
                 $439 = (($$30$i) + ($430)|0);
                 $440 = $439;
                 $441 = $438;
                 $442 = (($440) - ($441))|0;
                 $443 = ($442|0)<(11);
                 if ($443) {
                  $457 = $423;
                  break L202;
                 }
                 $$sum$i$i27$i$i = (($430) + -10)|0;
                 $444 = (($$30$i) + ($$sum$i$i27$i$i)|0);
                 $445 = ($$sum$i$i27$i$i|0)==($383|0);
                 if ($445) {
                  $457 = $423;
                  break L202;
                 } else {
                  $$014$i$i$i$i29$i$i = $438;
                 }
                 L240: while(1) {
                  $446 = HEAP8[$$014$i$i$i$i29$i$i>>0]|0;
                  $447 = ($446<<24>>24)==(116);
                  if ($447) {
                   $__m1$0$i$i$i$i32$i$i = $$014$i$i$i$i29$i$i;$__m2$0$i$i$i$i33$i$i = 1151296;
                   while(1) {
                    $449 = (($__m2$0$i$i$i$i33$i$i) + 1|0);
                    $450 = ($449|0)==(((1151296 + 11|0))|0);
                    if ($450) {
                     break L240;
                    }
                    $451 = (($__m1$0$i$i$i$i32$i$i) + 1|0);
                    $452 = HEAP8[$451>>0]|0;
                    $453 = HEAP8[$449>>0]|0;
                    $454 = ($452<<24>>24)==($453<<24>>24);
                    if ($454) {
                     $__m1$0$i$i$i$i32$i$i = $451;$__m2$0$i$i$i$i33$i$i = $449;
                    } else {
                     break;
                    }
                   }
                  }
                  $$01$be$i$i$i$i30$i$i = (($$014$i$i$i$i29$i$i) + 1|0);
                  $448 = ($$01$be$i$i$i$i30$i$i|0)==($444|0);
                  if ($448) {
                   $457 = $423;
                   break L202;
                  } else {
                   $$014$i$i$i$i29$i$i = $$01$be$i$i$i$i30$i$i;
                  }
                 }
                 $455 = ($$014$i$i$i$i29$i$i|0)==($439|0);
                 if ($455) {
                  $457 = $423;
                  break L202;
                 }
                 $433 = $$014$i$i$i$i29$i$i;
                 $434 = $$30$i;
                 $435 = (($433) - ($434))|0;
                 $436 = ($435|0)==(-1);
                 if ($436) {
                  $457 = $423;
                  break;
                 } else {
                  $385 = $423;$387 = $437;$texCubeEntry$047$i$i = $435;
                 }
                }
               }
              } while(0);
              $456 = $457 & 1;
              $458 = ($456<<24>>24)==(0);
              if ($458) {
               $461 = (($modSource$i) + 1|0);
               $462 = $461;
              } else {
               $459 = (($modSource$i) + 8|0);
               $460 = HEAP32[$459>>2]|0;
               $462 = $460;
              }
              __THREW__ = 0;
              $463 = (invoke_iiii(1636,($283|0),2,($462|0))|0);
              $464 = __THREW__; __THREW__ = 0;
              $465 = $464&1;
              if ($465) {
               break L156;
              } else {
               $result$0$off0$i = $463;
              }
             }
            } while(0);
            $486 = HEAP8[$modSource$i>>0]|0;
            $487 = $486 & 1;
            $488 = ($487<<24>>24)==(0);
            if (!($488)) {
             $489 = (($modSource$i) + 8|0);
             $490 = HEAP32[$489>>2]|0;
             __ZdlPv($490);
            }
            $491 = HEAP8[$prec_modifier$i>>0]|0;
            $492 = $491 & 1;
            $493 = ($492<<24>>24)==(0);
            if (!($493)) {
             $494 = (($prec_modifier$i) + 8|0);
             $495 = HEAP32[$494>>2]|0;
             __ZdlPv($495);
            }
            $496 = HEAP8[$modSourceProg$i>>0]|0;
            $497 = $496 & 1;
            $498 = ($497<<24>>24)==(0);
            if (!($498)) {
             $499 = (($modSourceProg$i) + 8|0);
             $500 = HEAP32[$499>>2]|0;
             __ZdlPv($500);
            }
            $506 = HEAP8[$modSourceHeader$i>>0]|0;
            $507 = $506 & 1;
            $508 = ($507<<24>>24)==(0);
            if (!($508)) {
             $509 = (($modSourceHeader$i) + 8|0);
             $510 = HEAP32[$509>>2]|0;
             __ZdlPv($510);
            }
            if (!($result$0$off0$i)) {
             $$0 = 0;
             break L41;
            }
            $521 = (1147664 + 4|0);
            $522 = HEAP32[$521>>2]|0;
            $523 = HEAP32[$91>>2]|0;
            $524 = HEAP32[$93>>2]|0;
            __THREW__ = 0;
            invoke_vii($522|0,($523|0),($524|0));
            $525 = __THREW__; __THREW__ = 0;
            $526 = $525&1;
            if ($526) {
             label = 15;
             break L25;
            }
            $527 = (1147664 + 4|0);
            $528 = HEAP32[$527>>2]|0;
            $529 = HEAP32[$91>>2]|0;
            $530 = HEAP32[$177>>2]|0;
            __THREW__ = 0;
            invoke_vii($528|0,($529|0),($530|0));
            $531 = __THREW__; __THREW__ = 0;
            $532 = $531&1;
            if ($532) {
             label = 15;
             break L25;
            }
            $533 = (1147664 + 256|0);
            $534 = HEAP32[$533>>2]|0;
            $535 = HEAP32[$91>>2]|0;
            __THREW__ = 0;
            invoke_vi($534|0,($535|0));
            $536 = __THREW__; __THREW__ = 0;
            $537 = $536&1;
            if ($537) {
             label = 15;
             break L25;
            }
            HEAP32[$linked1>>2] = 0;
            $538 = (1147664 + 216|0);
            $539 = HEAP32[$538>>2]|0;
            $540 = HEAP32[$91>>2]|0;
            __THREW__ = 0;
            invoke_viii($539|0,($540|0),35714,($linked1|0));
            $541 = __THREW__; __THREW__ = 0;
            $542 = $541&1;
            if ($542) {
             label = 15;
             break L25;
            }
            $543 = HEAP32[$linked1>>2]|0;
            $544 = ($543|0)==(0);
            if ($544) {
             $545 = HEAP32[$91>>2]|0;
             HEAP32[$infoLogLength$i>>2] = 0;
             $546 = (1147664 + 220|0);
             $547 = HEAP32[$546>>2]|0;
             __THREW__ = 0;
             invoke_viiii($547|0,($545|0),4096,($infoLogLength$i|0),($compileInfoLog$i|0));
             $548 = __THREW__; __THREW__ = 0;
             $549 = $548&1;
             if ($549) {
              label = 15;
              break L25;
             }
             $550 = HEAP32[$infoLogLength$i>>2]|0;
             $551 = ($550|0)>(0);
             if (!($551)) {
              $$0 = 0;
              break L41;
             }
             __THREW__ = 0;
             HEAP32[$vararg_buffer15>>2] = $compileInfoLog$i;
             invoke_vii(2587,(1150520|0),($vararg_buffer15|0));
             $552 = __THREW__; __THREW__ = 0;
             $553 = $552&1;
             if ($553) {
              label = 15;
              break L25;
             } else {
              $$0 = 0;
              break L41;
             }
            }
            $554 = HEAP32[1152880>>2]|0;
            $555 = (($554) + 63|0);
            $556 = HEAP8[$555>>0]|0;
            $557 = ($556<<24>>24)==(0);
            if ($557) {
             $$0 = 1;
             break L41;
            }
            $558 = (1147664 + 216|0);
            $559 = HEAP32[$558>>2]|0;
            $560 = HEAP32[$91>>2]|0;
            __THREW__ = 0;
            invoke_viii($559|0,($560|0),34625,($binaryLength|0));
            $561 = __THREW__; __THREW__ = 0;
            $562 = $561&1;
            if ($562) {
             label = 15;
             break L25;
            }
            $563 = HEAP32[$binaryLength>>2]|0;
            $564 = (($563) + 4)|0;
            $565 = (_malloc($564)|0);
            $566 = (($565) + 4|0);
            $567 = (1147664 + 500|0);
            $568 = HEAP32[$567>>2]|0;
            $569 = HEAP32[$91>>2]|0;
            __THREW__ = 0;
            invoke_viiiii($568|0,($569|0),($563|0),(0|0),($565|0),($566|0));
            $570 = __THREW__; __THREW__ = 0;
            $571 = $570&1;
            if ($571) {
             label = 15;
             break L25;
            }
            $572 = HEAP8[$binaryPath>>0]|0;
            $573 = $572 & 1;
            $574 = ($573<<24>>24)==(0);
            if ($574) {
             $577 = (($binaryPath) + 1|0);
             $578 = $577;
            } else {
             $575 = (($binaryPath) + 8|0);
             $576 = HEAP32[$575>>2]|0;
             $578 = $576;
            }
            $579 = (_fopen(($578|0),(1150568|0))|0);
            $580 = ($579|0)==(0|0);
            if ($580) {
             $binaryData$2 = $565;
             label = 224;
             break L41;
            }
            $581 = HEAP32[$binaryLength>>2]|0;
            $582 = (($581) + 4)|0;
            (_fwrite(($565|0),($582|0),1,($579|0))|0);
            (_fclose(($579|0))|0);
            $binaryData$2 = $565;
            label = 224;
            break L41;
           }
          } while(0);
          $479 = ___cxa_find_matching_catch()|0;
          $480 = tempRet0;
          $481 = HEAP8[$modSource$i>>0]|0;
          $482 = $481 & 1;
          $483 = ($482<<24>>24)==(0);
          if ($483) {
           $$0$i18 = $479;$$01$i = $480;
           break;
          }
          $484 = (($modSource$i) + 8|0);
          $485 = HEAP32[$484>>2]|0;
          __ZdlPv($485);
          $$0$i18 = $479;$$01$i = $480;
         }
        } while(0);
        $501 = HEAP8[$prec_modifier$i>>0]|0;
        $502 = $501 & 1;
        $503 = ($502<<24>>24)==(0);
        if ($503) {
         $$1$i = $$0$i18;$$12$i = $$01$i;
        } else {
         $504 = (($prec_modifier$i) + 8|0);
         $505 = HEAP32[$504>>2]|0;
         __ZdlPv($505);
         $$1$i = $$0$i18;$$12$i = $$01$i;
        }
       }
      } while(0);
      if ((label|0) == 185) {
       $468 = ___cxa_find_matching_catch()|0;
       $469 = tempRet0;
       $lpad$phi$i$index = $468;$lpad$phi$i$index7 = $469;
       label = 186;
      }
      if ((label|0) == 186) {
       $$1$i = $lpad$phi$i$index;$$12$i = $lpad$phi$i$index7;
      }
      $511 = HEAP8[$modSourceProg$i>>0]|0;
      $512 = $511 & 1;
      $513 = ($512<<24>>24)==(0);
      if (!($513)) {
       $514 = (($modSourceProg$i) + 8|0);
       $515 = HEAP32[$514>>2]|0;
       __ZdlPv($515);
      }
      $516 = HEAP8[$modSourceHeader$i>>0]|0;
      $517 = $516 & 1;
      $518 = ($517<<24>>24)==(0);
      if (!($518)) {
       $519 = (($modSourceHeader$i) + 8|0);
       $520 = HEAP32[$519>>2]|0;
       __ZdlPv($520);
      }
      $eh$lpad$body$index2Z2D = $$12$i;$eh$lpad$body$indexZ2D = $$1$i;
      label = 16;
      break L25;
     } else {
      $$0 = 0;
     }
    }
   } while(0);
   if ((label|0) == 224) {
    $583 = ($binaryData$2|0)==(0|0);
    if ($583) {
     $$0 = 1;
    } else {
     _free($binaryData$2);
     $$0 = 1;
    }
   }
   $584 = HEAP8[$binaryPath>>0]|0;
   $585 = $584 & 1;
   $586 = ($585<<24>>24)==(0);
   if ($586) {
    STACKTOP = sp;return ($$0|0);
   }
   $587 = (($binaryPath) + 8|0);
   $588 = HEAP32[$587>>2]|0;
   __ZdlPv($588);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 if ((label|0) == 15) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  $eh$lpad$body$index2Z2D = $40;$eh$lpad$body$indexZ2D = $39;
  label = 16;
 }
 if ((label|0) == 16) {
  $$1 = $eh$lpad$body$indexZ2D;$$13 = $eh$lpad$body$index2Z2D;
 }
 $589 = HEAP8[$binaryPath>>0]|0;
 $590 = $589 & 1;
 $591 = ($590<<24>>24)==(0);
 if ($591) {
  ___resumeException($$1|0);
  // unreachable;
 }
 $592 = (($binaryPath) + 8|0);
 $593 = HEAP32[$592>>2]|0;
 __ZdlPv($593);
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __ZL18BindVProgAttrbutesRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER14ChannelAssignsj($source,$channels,$programID) {
 $source = $source|0;
 $channels = $channels|0;
 $programID = $programID|0;
 var $$0 = 0, $$01$be$i$i$i$i = 0, $$01$be$i$i$i$i18 = 0, $$01$be$i$i$i$i6 = 0, $$014$i$i$i$i = 0, $$014$i$i$i$i17 = 0, $$014$i$i$i$i5 = 0, $$sum$i$i = 0, $$sum$i$i15 = 0, $$sum$i$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__m1$0$i$i$i$i = 0, $__m1$0$i$i$i$i20 = 0, $__m1$0$i$i$i$i8 = 0;
 var $__m2$0$i$i$i$i = 0, $__m2$0$i$i$i$i21 = 0, $__m2$0$i$i$i$i9 = 0, $__p$0$i$i$i = 0, $i$030 = 0, $j$036 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($0) + 1|0);
 $2 = (($0) + 8|0);
 $3 = (($0) + 4|0);
 $4 = (($source) + 1|0);
 $5 = (($source) + 8|0);
 $6 = (($source) + 4|0);
 $j$036 = 0;
 L1: while(1) {
  $7 = (1151736 + ($j$036<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (_strlen(($8|0))|0);
  $10 = HEAP8[$source>>0]|0;
  $11 = $10 & 1;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $14 = $10&255;
   $15 = $14 >>> 1;
   $17 = $15;
  } else {
   $13 = HEAP32[$6>>2]|0;
   $17 = $13;
  }
  $16 = ($17>>>0)<($9>>>0);
  L7: do {
   if (!($16)) {
    $18 = ($9|0)==(0);
    if (!($18)) {
     if ($12) {
      $21 = $4;
     } else {
      $19 = HEAP32[$5>>2]|0;
      $21 = $19;
     }
     $20 = (($21) + ($17)|0);
     $22 = (($8) + ($9)|0);
     $23 = $21;
     $24 = ($17|0)<($9|0);
     if ($24) {
      break;
     }
     $25 = (1 - ($9))|0;
     $$sum$i$i = (($17) + ($25))|0;
     $26 = (($21) + ($$sum$i$i)|0);
     $27 = ($$sum$i$i|0)==(0);
     if ($27) {
      break;
     }
     $28 = HEAP8[$8>>0]|0;
     $$014$i$i$i$i = $21;
     L16: while(1) {
      $29 = HEAP8[$$014$i$i$i$i>>0]|0;
      $30 = ($29<<24>>24)==($28<<24>>24);
      if ($30) {
       $__m1$0$i$i$i$i = $$014$i$i$i$i;$__m2$0$i$i$i$i = $8;
       while(1) {
        $32 = (($__m2$0$i$i$i$i) + 1|0);
        $33 = ($32|0)==($22|0);
        if ($33) {
         break L16;
        }
        $34 = (($__m1$0$i$i$i$i) + 1|0);
        $35 = HEAP8[$34>>0]|0;
        $36 = HEAP8[$32>>0]|0;
        $37 = ($35<<24>>24)==($36<<24>>24);
        if ($37) {
         $__m1$0$i$i$i$i = $34;$__m2$0$i$i$i$i = $32;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i = (($$014$i$i$i$i) + 1|0);
      $31 = ($$01$be$i$i$i$i|0)==($26|0);
      if ($31) {
       break L7;
      } else {
       $$014$i$i$i$i = $$01$be$i$i$i$i;
      }
     }
     $38 = ($$014$i$i$i$i|0)==($20|0);
     if ($38) {
      break;
     }
     $39 = $$014$i$i$i$i;
     $40 = (($39) - ($23))|0;
     $41 = ($40|0)==(-1);
     if ($41) {
      break;
     }
    }
    $42 = (1151784 + ($j$036<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[1152880>>2]|0;
    $45 = HEAP32[$44>>2]|0;
    $46 = ($43|0)<($45|0);
    if (!($46)) {
     label = 19;
     break L1;
    }
    $47 = (1147664 + 8|0);
    $48 = HEAP32[$47>>2]|0;
    FUNCTION_TABLE_viii[$48 & 4095]($programID,$43,$8);
    $49 = (1150672 + ($j$036<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (_strlen(($50|0))|0);
    $52 = ($51>>>0)>(4294967279);
    if ($52) {
     label = 21;
     break L1;
    }
    $53 = ($51>>>0)<(11);
    if ($53) {
     $54 = $51 << 1;
     $55 = $54&255;
     HEAP8[$0>>0] = $55;
     $__p$0$i$i$i = $1;
    } else {
     $56 = (($51) + 16)|0;
     $57 = $56 & -16;
     $58 = (__Znwj($57)|0);
     HEAP32[$2>>2] = $58;
     $59 = $57 | 1;
     HEAP32[$0>>2] = $59;
     HEAP32[$3>>2] = $51;
     $__p$0$i$i$i = $58;
    }
    _memcpy(($__p$0$i$i$i|0),($50|0),($51|0))|0;
    $60 = (($__p$0$i$i$i) + ($51)|0);
    HEAP8[$60>>0] = 0;
    __THREW__ = 0;
    $61 = (invoke_ii(3326,($0|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 30;
     break L1;
    }
    $64 = HEAP8[$0>>0]|0;
    $65 = $64 & 1;
    $66 = ($65<<24>>24)==(0);
    if (!($66)) {
     $67 = HEAP32[$2>>2]|0;
     __ZdlPv($67);
    }
    $68 = ($61|0)==(-1);
    if (!($68)) {
     $69 = (1150720 + ($j$036<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($channels,$61,$70);
    }
   }
  } while(0);
  $77 = (($j$036) + 1)|0;
  $78 = ($77>>>0)<(12);
  if ($78) {
   $j$036 = $77;
  } else {
   label = 33;
   break;
  }
 }
 if ((label|0) == 19) {
  __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1150608,0,1150592,364,1,0,0,0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 21) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  $73 = HEAP8[$0>>0]|0;
  $74 = $73 & 1;
  $75 = ($74<<24>>24)==(0);
  if ($75) {
   ___resumeException($71|0);
   // unreachable;
  }
  $76 = HEAP32[$2>>2]|0;
  __ZdlPv($76);
  ___resumeException($71|0);
  // unreachable;
 }
 else if ((label|0) == 33) {
  $79 = HEAP8[$source>>0]|0;
  $80 = $79 & 1;
  $81 = ($80<<24>>24)==(0);
  if ($81) {
   $83 = $79&255;
   $84 = $83 >>> 1;
   $86 = $84;
  } else {
   $82 = HEAP32[$6>>2]|0;
   $86 = $82;
  }
  $85 = ($86>>>0)<(7);
  if ($85) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($81) {
   $89 = $4;
  } else {
   $87 = HEAP32[$5>>2]|0;
   $89 = $87;
  }
  $88 = (($89) + ($86)|0);
  $90 = $89;
  $91 = ($86|0)<(7);
  if ($91) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $$sum$i$i3 = (($86) + -6)|0;
  $92 = (($89) + ($$sum$i$i3)|0);
  $93 = ($$sum$i$i3|0)==(0);
  if ($93) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$014$i$i$i$i5 = $89;
  }
  L63: while(1) {
   $94 = HEAP8[$$014$i$i$i$i5>>0]|0;
   $95 = ($94<<24>>24)==(84);
   if ($95) {
    $__m1$0$i$i$i$i8 = $$014$i$i$i$i5;$__m2$0$i$i$i$i9 = 1150768;
    while(1) {
     $97 = (($__m2$0$i$i$i$i9) + 1|0);
     $98 = ($97|0)==(((1150768 + 7|0))|0);
     if ($98) {
      break L63;
     }
     $99 = (($__m1$0$i$i$i$i8) + 1|0);
     $100 = HEAP8[$99>>0]|0;
     $101 = HEAP8[$97>>0]|0;
     $102 = ($100<<24>>24)==($101<<24>>24);
     if ($102) {
      $__m1$0$i$i$i$i8 = $99;$__m2$0$i$i$i$i9 = $97;
     } else {
      break;
     }
    }
   }
   $$01$be$i$i$i$i6 = (($$014$i$i$i$i5) + 1|0);
   $96 = ($$01$be$i$i$i$i6|0)==($92|0);
   if ($96) {
    $$0 = 1;
    label = 64;
    break;
   } else {
    $$014$i$i$i$i5 = $$01$be$i$i$i$i6;
   }
  }
  if ((label|0) == 64) {
   STACKTOP = sp;return ($$0|0);
  }
  $103 = ($$014$i$i$i$i5|0)==($88|0);
  if ($103) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $104 = $$014$i$i$i$i5;
  $105 = (($104) - ($90))|0;
  $106 = ($105|0)==(-1);
  if ($106) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $107 = (($105) + 1)|0;
  if ($81) {
   $109 = $79&255;
   $110 = $109 >>> 1;
   $112 = $110;
  } else {
   $108 = HEAP32[$6>>2]|0;
   $112 = $108;
  }
  $111 = ($112>>>0)<($107>>>0);
  $113 = (($112) - ($107))|0;
  $114 = ($113>>>0)<(7);
  $or$cond$i$i = $111 | $114;
  if ($or$cond$i$i) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  if ($81) {
   $117 = $4;
  } else {
   $115 = HEAP32[$5>>2]|0;
   $117 = $115;
  }
  $116 = (($117) + ($107)|0);
  $118 = (($117) + ($112)|0);
  $119 = $118;
  $120 = $116;
  $121 = (($119) - ($120))|0;
  $122 = ($121|0)<(7);
  if ($122) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $$sum$i$i15 = (($112) + -6)|0;
  $123 = (($117) + ($$sum$i$i15)|0);
  $124 = ($$sum$i$i15|0)==($107|0);
  if ($124) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$014$i$i$i$i17 = $116;
  }
  L94: while(1) {
   $125 = HEAP8[$$014$i$i$i$i17>>0]|0;
   $126 = ($125<<24>>24)==(84);
   if ($126) {
    $__m1$0$i$i$i$i20 = $$014$i$i$i$i17;$__m2$0$i$i$i$i21 = 1150768;
    while(1) {
     $128 = (($__m2$0$i$i$i$i21) + 1|0);
     $129 = ($128|0)==(((1150768 + 7|0))|0);
     if ($129) {
      break L94;
     }
     $130 = (($__m1$0$i$i$i$i20) + 1|0);
     $131 = HEAP8[$130>>0]|0;
     $132 = HEAP8[$128>>0]|0;
     $133 = ($131<<24>>24)==($132<<24>>24);
     if ($133) {
      $__m1$0$i$i$i$i20 = $130;$__m2$0$i$i$i$i21 = $128;
     } else {
      break;
     }
    }
   }
   $$01$be$i$i$i$i18 = (($$014$i$i$i$i17) + 1|0);
   $127 = ($$01$be$i$i$i$i18|0)==($123|0);
   if ($127) {
    $$0 = 1;
    label = 64;
    break;
   } else {
    $$014$i$i$i$i17 = $$01$be$i$i$i$i18;
   }
  }
  if ((label|0) == 64) {
   STACKTOP = sp;return ($$0|0);
  }
  $134 = ($$014$i$i$i$i17|0)==($118|0);
  if ($134) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $135 = $$014$i$i$i$i17;
  $136 = $117;
  $137 = (($135) - ($136))|0;
  $138 = ($137|0)==(-1);
  if ($138) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$030 = 6;
  }
  while(1) {
   $141 = ((($channels) + ($i$030)|0) + 8|0);
   $142 = HEAP8[$141>>0]|0;
   $143 = ($142<<24>>24)==(-1);
   $140 = (($i$030) + 1)|0;
   if ($143) {
    break;
   }
   $139 = ($140|0)<(11);
   if ($139) {
    $i$030 = $140;
   } else {
    $$0 = 1;
    label = 64;
    break;
   }
  }
  if ((label|0) == 64) {
   STACKTOP = sp;return ($$0|0);
  }
  __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($channels,7,$i$030);
  $144 = (1147664 + 8|0);
  $145 = HEAP32[$144>>2]|0;
  $146 = (($i$030) + -1)|0;
  FUNCTION_TABLE_viii[$145 & 4095]($programID,$146,1150776);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN18GlslGpuProgramGLES19ApplyGpuProgramGLESERK20GpuProgramParametersPKh($this,$params,$buffer) {
 $this = $this|0;
 $params = $params|0;
 $buffer = $buffer|0;
 var $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 HEAP32[$0>>2] = $buffer;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (__Z16GetRealGfxDevicev()|0);
 $6 = HEAP32[1149528>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 __ZN4gles14UseGLSLProgramER15DeviceStateGLESj($6,$7);
 $8 = (($this) + 20|0);
 __Z19ApplyValuesBaseGLESP16UniformCacheGLESRK20GpuProgramParametersPK24BuiltinShaderParamValuesPPKh($8,$params,0,$0);
 $9 = (($params) + 36|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($params) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($10|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 $$pre = HEAP32[$0>>2]|0;
 $18 = $12;$21 = $$pre;
 while(1) {
  $14 = HEAP32[$5>>2]|0;
  $15 = (($14) + 208|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($18) + 4|0);
  $19 = HEAP32[$17>>2]|0;
  $20 = HEAP32[$21>>2]|0;
  HEAP32[$1>>2] = $20;
  $22 = (($21) + 8|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = $23 & 15;
  $25 = $24&255;
  $26 = (($21) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  FUNCTION_TABLE_viiiiiif[$16 & 1]($5,2,$19,$19,$$byval_copy,$25,$27);
  $28 = HEAP32[$0>>2]|0;
  $29 = (($28) + 12|0);
  HEAP32[$0>>2] = $29;
  $30 = (($18) + 16|0);
  $31 = ($30|0)==($10|0);
  if ($31) {
   break;
  } else {
   $18 = $30;$21 = $29;
  }
 }
 STACKTOP = sp;return;
}
function __ZN18GlslGpuProgramGLES15ApplyGpuProgramERK20GpuProgramParametersPKh($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z28InitBinaryShadersSupportGLESv() {
 var $$ = 0, $$0 = 0, $$01 = 0, $$01$be$i$i$i$i = 0, $$01$be$i$i$i$i8 = 0, $$014$i$i$i$i = 0, $$014$i$i$i$i7 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$31 = 0, $$sum$i$i = 0, $$sum$i$i5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__m1$0$i$i$i$i = 0, $__m1$0$i$i$i$i10 = 0, $__m2$0$i$i$i$i = 0, $__m2$0$i$i$i$i11 = 0, $__p$0$i$i$i = 0, $__p$0$i$i$i22 = 0, $binFormatCount = 0, $path = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $binFormatCount = sp + 48|0;
 $path = sp;
 $0 = sp + 12|0;
 $1 = sp + 24|0;
 $2 = sp + 36|0;
 $3 = HEAP8[640792>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $7 = $3&255;
  $8 = $7 >>> 1;
  $10 = $8;
 } else {
  $6 = HEAP32[((640792 + 4|0))>>2]|0;
  $10 = $6;
 }
 $9 = ($10>>>0)<(9);
 L5: do {
  if (!($9)) {
   $11 = HEAP32[((640792 + 8|0))>>2]|0;
   $$ = $5 ? ((640792 + 1|0)) : $11;
   $12 = (($$) + ($10)|0);
   $13 = $$;
   $14 = ($10|0)<(9);
   if (!($14)) {
    $$sum$i$i = (($10) + -8)|0;
    $15 = (($$) + ($$sum$i$i)|0);
    $16 = ($$sum$i$i|0)==(0);
    if (!($16)) {
     $$014$i$i$i$i = $$;
     L8: while(1) {
      $17 = HEAP8[$$014$i$i$i$i>>0]|0;
      $18 = ($17<<24>>24)==(73);
      if ($18) {
       $__m1$0$i$i$i$i = $$014$i$i$i$i;$__m2$0$i$i$i$i = 1151432;
       while(1) {
        $20 = (($__m2$0$i$i$i$i) + 1|0);
        $21 = ($20|0)==(((1151432 + 9|0))|0);
        if ($21) {
         break L8;
        }
        $22 = (($__m1$0$i$i$i$i) + 1|0);
        $23 = HEAP8[$22>>0]|0;
        $24 = HEAP8[$20>>0]|0;
        $25 = ($23<<24>>24)==($24<<24>>24);
        if ($25) {
         $__m1$0$i$i$i$i = $22;$__m2$0$i$i$i$i = $20;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i = (($$014$i$i$i$i) + 1|0);
      $19 = ($$01$be$i$i$i$i|0)==($15|0);
      if ($19) {
       break L5;
      } else {
       $$014$i$i$i$i = $$01$be$i$i$i$i;
      }
     }
     $26 = ($$014$i$i$i$i|0)==($12|0);
     if (!($26)) {
      $27 = $$014$i$i$i$i;
      $28 = (($27) - ($13))|0;
      $29 = ($28|0)==(-1);
      if (!($29)) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 if ($5) {
  $31 = $3&255;
  $32 = $31 >>> 1;
  $34 = $32;
 } else {
  $30 = HEAP32[((640792 + 4|0))>>2]|0;
  $34 = $30;
 }
 $33 = ($34>>>0)<(6);
 L23: do {
  if (!($33)) {
   $35 = HEAP32[((640792 + 8|0))>>2]|0;
   $$31 = $5 ? ((640792 + 1|0)) : $35;
   $36 = (($$31) + ($34)|0);
   $37 = $$31;
   $38 = ($34|0)<(6);
   if (!($38)) {
    $$sum$i$i5 = (($34) + -5)|0;
    $39 = (($$31) + ($$sum$i$i5)|0);
    $40 = ($$sum$i$i5|0)==(0);
    if (!($40)) {
     $$014$i$i$i$i7 = $$31;
     L26: while(1) {
      $41 = HEAP8[$$014$i$i$i$i7>>0]|0;
      $42 = ($41<<24>>24)==(71);
      if ($42) {
       $__m1$0$i$i$i$i10 = $$014$i$i$i$i7;$__m2$0$i$i$i$i11 = 1151448;
       while(1) {
        $44 = (($__m2$0$i$i$i$i11) + 1|0);
        $45 = ($44|0)==(((1151448 + 6|0))|0);
        if ($45) {
         break L26;
        }
        $46 = (($__m1$0$i$i$i$i10) + 1|0);
        $47 = HEAP8[$46>>0]|0;
        $48 = HEAP8[$44>>0]|0;
        $49 = ($47<<24>>24)==($48<<24>>24);
        if ($49) {
         $__m1$0$i$i$i$i10 = $46;$__m2$0$i$i$i$i11 = $44;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i8 = (($$014$i$i$i$i7) + 1|0);
      $43 = ($$01$be$i$i$i$i8|0)==($39|0);
      if ($43) {
       break L23;
      } else {
       $$014$i$i$i$i7 = $$01$be$i$i$i$i8;
      }
     }
     $50 = ($$014$i$i$i$i7|0)==($36|0);
     if (!($50)) {
      $51 = $$014$i$i$i$i7;
      $52 = (($51) - ($37))|0;
      $53 = ($52|0)==(-1);
      if (!($53)) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $54 = (1147664 + 500|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==(0|0);
 if ($56) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $57 = (1147664 + 504|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$binFormatCount>>2] = 0;
 $60 = (1147664 + 212|0);
 $61 = HEAP32[$60>>2]|0;
 FUNCTION_TABLE_vii[$61 & 4095](34814,$binFormatCount);
 $62 = HEAP32[$binFormatCount>>2]|0;
 $63 = ($62|0)>(0);
 if (!($63)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __Z40GetTemporaryCachePathApplicationSpecificv($0);
 __THREW__ = 0;
 invoke_viii(1627,($path|0),($0|0),(1151456|0));
 $64 = __THREW__; __THREW__ = 0;
 $65 = $64&1;
 if ($65) {
  $73 = ___cxa_find_matching_catch()|0;
  $74 = tempRet0;
  $75 = HEAP8[$0>>0]|0;
  $76 = $75 & 1;
  $77 = ($76<<24>>24)==(0);
  if ($77) {
   $$1 = $74;$$13 = $73;
   ___resumeException($$13|0);
   // unreachable;
  }
  $78 = (($0) + 8|0);
  $79 = HEAP32[$78>>2]|0;
  __ZdlPv($79);
  $$1 = $74;$$13 = $73;
  ___resumeException($$13|0);
  // unreachable;
 }
 $66 = HEAP8[$0>>0]|0;
 $67 = $66 & 1;
 $68 = ($67<<24>>24)==(0);
 if (!($68)) {
  $69 = (($0) + 8|0);
  $70 = HEAP32[$69>>2]|0;
  __ZdlPv($70);
 }
 $71 = HEAP32[1151424>>2]|0;
 $72 = ($71|0)==(0|0);
 if (!($72)) {
  _free($71);
 }
 $82 = HEAP8[$path>>0]|0;
 $83 = $82 & 1;
 $84 = ($83<<24>>24)==(0);
 if ($84) {
  $91 = $82&255;
  $92 = $91 >>> 1;
  $93 = (($92) + 1)|0;
  $94 = (_malloc($93)|0);
  HEAP32[1151424>>2] = $94;
  $95 = (($path) + 1|0);
  $96 = $94;$97 = $95;
 } else {
  $85 = (($path) + 4|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (($86) + 1)|0;
  $88 = (_malloc($87)|0);
  HEAP32[1151424>>2] = $88;
  $89 = (($path) + 8|0);
  $90 = HEAP32[$89>>2]|0;
  $96 = $88;$97 = $90;
 }
 (_strcpy(($96|0),($97|0))|0);
 $98 = HEAP32[1151424>>2]|0;
 $99 = (_strlen(($98|0))|0);
 $100 = ($99>>>0)>(4294967279);
 L63: do {
  if ($100) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $101 = __THREW__; __THREW__ = 0;
   $102 = $101&1;
   if ($102) {
    label = 35;
   } else {
    // unreachable;
   }
  } else {
   $103 = ($99>>>0)<(11);
   if ($103) {
    $104 = $99 << 1;
    $105 = $104&255;
    HEAP8[$1>>0] = $105;
    $106 = (($1) + 1|0);
    $__p$0$i$i$i = $106;
   } else {
    $107 = (($99) + 16)|0;
    $108 = $107 & -16;
    __THREW__ = 0;
    $109 = (invoke_ii(2988,($108|0))|0);
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if ($111) {
     label = 35;
     break;
    }
    $112 = (($1) + 8|0);
    HEAP32[$112>>2] = $109;
    $113 = $108 | 1;
    HEAP32[$1>>2] = $113;
    $114 = (($1) + 4|0);
    HEAP32[$114>>2] = $99;
    $__p$0$i$i$i = $109;
   }
   _memcpy(($__p$0$i$i$i|0),($98|0),($99|0))|0;
   $115 = (($__p$0$i$i$i) + ($99)|0);
   HEAP8[$115>>0] = 0;
   __THREW__ = 0;
   $116 = (invoke_ii(3257,($1|0))|0);
   $117 = __THREW__; __THREW__ = 0;
   $118 = $117&1;
   if ($118) {
    $149 = ___cxa_find_matching_catch()|0;
    $150 = tempRet0;
    $151 = HEAP8[$1>>0]|0;
    $152 = $151 & 1;
    $153 = ($152<<24>>24)==(0);
    if ($153) {
     $$01 = $150;$$02 = $149;
     break;
    }
    $154 = (($1) + 8|0);
    $155 = HEAP32[$154>>2]|0;
    __ZdlPv($155);
    $$01 = $150;$$02 = $149;
    break;
   }
   $119 = HEAP8[$1>>0]|0;
   $120 = $119 & 1;
   $121 = ($120<<24>>24)==(0);
   if (!($121)) {
    $122 = (($1) + 8|0);
    $123 = HEAP32[$122>>2]|0;
    __ZdlPv($123);
   }
   do {
    if (!($116)) {
     $124 = HEAP32[1151424>>2]|0;
     $125 = (_strlen(($124|0))|0);
     $126 = ($125>>>0)>(4294967279);
     if ($126) {
      __THREW__ = 0;
      invoke_vi(3309,0);
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       label = 35;
       break L63;
      }
      // unreachable;
     }
     $129 = ($125>>>0)<(11);
     if ($129) {
      $130 = $125 << 1;
      $131 = $130&255;
      HEAP8[$2>>0] = $131;
      $132 = (($2) + 1|0);
      $__p$0$i$i$i22 = $132;
     } else {
      $133 = (($125) + 16)|0;
      $134 = $133 & -16;
      __THREW__ = 0;
      $135 = (invoke_ii(2988,($134|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       label = 35;
       break L63;
      }
      $138 = (($2) + 8|0);
      HEAP32[$138>>2] = $135;
      $139 = $134 | 1;
      HEAP32[$2>>2] = $139;
      $140 = (($2) + 4|0);
      HEAP32[$140>>2] = $125;
      $__p$0$i$i$i22 = $135;
     }
     _memcpy(($__p$0$i$i$i22|0),($124|0),($125|0))|0;
     $141 = (($__p$0$i$i$i22) + ($125)|0);
     HEAP8[$141>>0] = 0;
     __THREW__ = 0;
     (invoke_ii(3323,($2|0))|0);
     $142 = __THREW__; __THREW__ = 0;
     $143 = $142&1;
     if ($143) {
      $156 = ___cxa_find_matching_catch()|0;
      $157 = tempRet0;
      $158 = HEAP8[$2>>0]|0;
      $159 = $158 & 1;
      $160 = ($159<<24>>24)==(0);
      if ($160) {
       $$01 = $157;$$02 = $156;
       break L63;
      }
      $161 = (($2) + 8|0);
      $162 = HEAP32[$161>>2]|0;
      __ZdlPv($162);
      $$01 = $157;$$02 = $156;
      break L63;
     } else {
      $144 = HEAP8[$2>>0]|0;
      $145 = $144 & 1;
      $146 = ($145<<24>>24)==(0);
      if ($146) {
       break;
      }
      $147 = (($2) + 8|0);
      $148 = HEAP32[$147>>2]|0;
      __ZdlPv($148);
      break;
     }
    }
   } while(0);
   $163 = HEAP8[$path>>0]|0;
   $164 = $163 & 1;
   $165 = ($164<<24>>24)==(0);
   if ($165) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $166 = (($path) + 8|0);
   $167 = HEAP32[$166>>2]|0;
   __ZdlPv($167);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 if ((label|0) == 35) {
  $80 = ___cxa_find_matching_catch()|0;
  $81 = tempRet0;
  $$01 = $81;$$02 = $80;
 }
 $168 = HEAP8[$path>>0]|0;
 $169 = $168 & 1;
 $170 = ($169<<24>>24)==(0);
 if ($170) {
  $$1 = $$01;$$13 = $$02;
  ___resumeException($$13|0);
  // unreachable;
 }
 $171 = (($path) + 8|0);
 $172 = HEAP32[$171>>2]|0;
 __ZdlPv($172);
 $$1 = $$01;$$13 = $$02;
 ___resumeException($$13|0);
 // unreachable;
 return 0|0;
}
function __ZN20SetValuesFunctorGLES12SetVectorValE15ShaderParamTypeiPKfi($this,$type,$index,$ptr,$cols) {
 $this = $this|0;
 $type = $type|0;
 $index = $index|0;
 $ptr = $ptr|0;
 $cols = $cols|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($cols|0) == 4)) {
  $6 = (($this) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __Z14CachedUniform4P16UniformCacheGLES15ShaderParamTypeiPKf($7,$type,$index,$ptr);
  STACKTOP = sp;return;
 } else if ((($cols|0) == 1)) {
  $0 = (($this) + 4|0);
  $1 = HEAP32[$0>>2]|0;
  __Z14CachedUniform1P16UniformCacheGLES15ShaderParamTypeiPKf($1,$type,$index,$ptr);
  STACKTOP = sp;return;
 } else if ((($cols|0) == 2)) {
  $2 = (($this) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __Z14CachedUniform2P16UniformCacheGLES15ShaderParamTypeiPKf($3,$type,$index,$ptr);
  STACKTOP = sp;return;
 } else if ((($cols|0) == 3)) {
  $4 = (($this) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __Z14CachedUniform3P16UniformCacheGLES15ShaderParamTypeiPKf($5,$type,$index,$ptr);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN20SetValuesFunctorGLES12SetMatrixValEiPK10Matrix4x4fi($this,$index,$ptr,$rows) {
 $this = $this|0;
 $index = $index|0;
 $ptr = $ptr|0;
 $rows = $rows|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1147664 + 356|0);
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viiii[$1 & 511]($index,1,0,$ptr);
 STACKTOP = sp;return;
}
function __ZN20SetValuesFunctorGLES13SetTextureValE10ShaderTypeii16TextureDimension9TextureID($this,$shaderType,$index,$samplerIndex,$dim,$texID) {
 $this = $this|0;
 $shaderType = $shaderType|0;
 $index = $index|0;
 $samplerIndex = $samplerIndex|0;
 $dim = $dim|0;
 $texID = $texID|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 208|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$texID>>2]|0;
 HEAP32[$0>>2] = $5;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiiiiif[$4 & 1]($1,$shaderType,$index,$samplerIndex,$$byval_copy,$dim,Math_fround(inf));
 STACKTOP = sp;return;
}
function __GLOBAL__I_a21804() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = -1;
 __ZN9ShaderLab16FastPropertyName4InitEPKc($0,1151840);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[1151832>>2] = $1;
 STACKTOP = sp;return;
}
function __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,$type,$program,$vectorSize,$uniformNumber,$arraySize,$cbIndex,$unityName,$glName,$glNameIndexOffset,$outNames) {
 $params = $params|0;
 $type = $type|0;
 $program = $program|0;
 $vectorSize = $vectorSize|0;
 $uniformNumber = $uniformNumber|0;
 $arraySize = $arraySize|0;
 $cbIndex = $cbIndex|0;
 $unityName = $unityName|0;
 $glName = $glName|0;
 $glNameIndexOffset = $glNameIndexOffset|0;
 $outNames = $outNames|0;
 var $$1$i = 0, $$1$i$sum = 0, $$1$i1 = 0, $$sum = 0, $$sum4 = 0, $$sum6 = 0, $$sum6$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $j$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($arraySize|0)<(2);
 if ($0) {
  __ZN20GpuProgramParameters14AddVectorParamEi15ShaderParamTypeiPKciP16PropertyNamesSet($params,$uniformNumber,$type,$vectorSize,$unityName,$cbIndex,$outNames);
  STACKTOP = sp;return;
 }
 $1 = (($glName) + ($glNameIndexOffset)|0);
 $$sum = (($glNameIndexOffset) + 1)|0;
 $2 = (($glName) + ($$sum)|0);
 $$sum6 = (($glNameIndexOffset) + 2)|0;
 $3 = (($glName) + ($$sum6)|0);
 $$sum4 = (($glNameIndexOffset) + 3)|0;
 $j$07 = 0;
 while(1) {
  HEAP8[$1>>0] = 91;
  $4 = ($j$07|0)<(10);
  if ($4) {
   $5 = (($j$07) + 48)|0;
   $6 = $5&255;
   HEAP8[$2>>0] = $6;
   $$sum6$pn = $$sum6;
  } else {
   $7 = (($j$07|0) / 10)&-1;
   $8 = (($7) + 48)|0;
   $9 = $8&255;
   HEAP8[$2>>0] = $9;
   $10 = (($j$07|0) % 10)&-1;
   $11 = (($10) + 48)|0;
   $12 = $11&255;
   HEAP8[$3>>0] = $12;
   $$sum6$pn = $$sum4;
  }
  $$1$i = (($glName) + ($$sum6$pn)|0);
  $$1$i$sum = (($$sum6$pn) + 1)|0;
  $13 = (($glName) + ($$1$i$sum)|0);
  HEAP8[$$1$i>>0] = 93;
  HEAP8[$13>>0] = 0;
  $14 = (1147664 + 240|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_iii[$15 & 4095]($program,$glName)|0);
  if ($4) {
   $17 = (($j$07) + 48)|0;
   $18 = $17&255;
   HEAP8[$1>>0] = $18;
   $$1$i1 = $2;
  } else {
   $19 = (($j$07|0) / 10)&-1;
   $20 = (($19) + 48)|0;
   $21 = $20&255;
   HEAP8[$1>>0] = $21;
   $22 = (($j$07|0) % 10)&-1;
   $23 = (($22) + 48)|0;
   $24 = $23&255;
   HEAP8[$2>>0] = $24;
   $$1$i1 = $3;
  }
  HEAP8[$$1$i1>>0] = 0;
  __ZN20GpuProgramParameters14AddVectorParamEi15ShaderParamTypeiPKciP16PropertyNamesSet($params,$16,$type,$vectorSize,$glName,$cbIndex,$outNames);
  $25 = (($j$07) + 1)|0;
  $exitcond = ($25|0)==($arraySize|0);
  if ($exitcond) {
   break;
  } else {
   $j$07 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __Z23AddSizedMatrixParamGLESR20GpuProgramParametersjiiiiiPKcPciP16PropertyNamesSet($params,$program,$rows,$cols,$uniformNumber,$arraySize,$cbIndex,$unityName,$glName,$glNameIndexOffset,$outNames) {
 $params = $params|0;
 $program = $program|0;
 $rows = $rows|0;
 $cols = $cols|0;
 $uniformNumber = $uniformNumber|0;
 $arraySize = $arraySize|0;
 $cbIndex = $cbIndex|0;
 $unityName = $unityName|0;
 $glName = $glName|0;
 $glNameIndexOffset = $glNameIndexOffset|0;
 $outNames = $outNames|0;
 var $$1$i = 0, $$1$i$sum = 0, $$1$i1 = 0, $$sum = 0, $$sum4 = 0, $$sum6 = 0, $$sum6$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $j$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($arraySize|0)<(2);
 if ($0) {
  __ZN20GpuProgramParameters14AddMatrixParamEi15ShaderParamTypePKciiiP16PropertyNamesSet($params,$uniformNumber,0,$unityName,$rows,$cols,$cbIndex,$outNames);
  STACKTOP = sp;return;
 }
 $1 = (($glName) + ($glNameIndexOffset)|0);
 $$sum = (($glNameIndexOffset) + 1)|0;
 $2 = (($glName) + ($$sum)|0);
 $$sum6 = (($glNameIndexOffset) + 2)|0;
 $3 = (($glName) + ($$sum6)|0);
 $$sum4 = (($glNameIndexOffset) + 3)|0;
 $j$07 = 0;
 while(1) {
  HEAP8[$1>>0] = 91;
  $4 = ($j$07|0)<(10);
  if ($4) {
   $5 = (($j$07) + 48)|0;
   $6 = $5&255;
   HEAP8[$2>>0] = $6;
   $$sum6$pn = $$sum6;
  } else {
   $7 = (($j$07|0) / 10)&-1;
   $8 = (($7) + 48)|0;
   $9 = $8&255;
   HEAP8[$2>>0] = $9;
   $10 = (($j$07|0) % 10)&-1;
   $11 = (($10) + 48)|0;
   $12 = $11&255;
   HEAP8[$3>>0] = $12;
   $$sum6$pn = $$sum4;
  }
  $$1$i = (($glName) + ($$sum6$pn)|0);
  $$1$i$sum = (($$sum6$pn) + 1)|0;
  $13 = (($glName) + ($$1$i$sum)|0);
  HEAP8[$$1$i>>0] = 93;
  HEAP8[$13>>0] = 0;
  $14 = (1147664 + 240|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (FUNCTION_TABLE_iii[$15 & 4095]($program,$glName)|0);
  if ($4) {
   $17 = (($j$07) + 48)|0;
   $18 = $17&255;
   HEAP8[$1>>0] = $18;
   $$1$i1 = $2;
  } else {
   $19 = (($j$07|0) / 10)&-1;
   $20 = (($19) + 48)|0;
   $21 = $20&255;
   HEAP8[$1>>0] = $21;
   $22 = (($j$07|0) % 10)&-1;
   $23 = (($22) + 48)|0;
   $24 = $23&255;
   HEAP8[$2>>0] = $24;
   $$1$i1 = $3;
  }
  HEAP8[$$1$i1>>0] = 0;
  __ZN20GpuProgramParameters14AddMatrixParamEi15ShaderParamTypePKciiiP16PropertyNamesSet($params,$16,0,$glName,$rows,$cols,$cbIndex,$outNames);
  $25 = (($j$07) + 1)|0;
  $exitcond = ($25|0)==($arraySize|0);
  if ($exitcond) {
   break;
  } else {
   $j$07 = $25;
  }
 }
 STACKTOP = sp;return;
}
function __Z18FillParamsBaseGLESjR20GpuProgramParametersP16PropertyNamesSetb($program,$params,$outNames,$fillTextureParams) {
 $program = $program|0;
 $params = $params|0;
 $outNames = $outNames|0;
 $fillTextureParams = $fillTextureParams|0;
 var $$0$i = 0, $$byval_copy2 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $activeUniformBlocks = 0, $activeUniforms = 0, $arraySize = 0, $cb = 0, $cbIndex = 0, $glNameIndexOffset$0 = 0, $i$012 = 0, $i$02$i = 0, $i1 = 0, $isElemZero = 0, $name = 0, $nameLength = 0, $phitmp = 0, $phitmp15 = 0;
 var $type = 0, $uniformNumber = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1104|0;
 $$byval_copy2 = sp + 48|0;
 $0 = sp + 68|0;
 $1 = sp + 64|0;
 $name = sp + 80|0;
 $type = sp + 60|0;
 $arraySize = sp + 56|0;
 $cbIndex = sp + 52|0;
 $nameLength = sp + 44|0;
 $activeUniformBlocks = sp + 40|0;
 $cb = sp + 12|0;
 $activeUniforms = sp + 8|0;
 $i1 = sp + 4|0;
 $uniformNumber = sp;
 $isElemZero = sp + 72|0;
 HEAP32[$arraySize>>2] = 0;
 HEAP32[$cbIndex>>2] = -1;
 HEAP32[$nameLength>>2] = 0;
 $2 = HEAP32[1152880>>2]|0;
 $3 = (($2) + 64|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 L1: do {
  if (!($5)) {
   HEAP32[$activeUniformBlocks>>2] = 0;
   $6 = (1147664 + 216|0);
   $7 = HEAP32[$6>>2]|0;
   FUNCTION_TABLE_viii[$7 & 4095]($program,35382,$activeUniformBlocks);
   $8 = (($params) + 60|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($params) + 64|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==($9|0);
   L3: do {
    if (!($12)) {
     $14 = $11;
     while(1) {
      $13 = (($14) + -28|0);
      HEAP32[$10>>2] = $13;
      $15 = (($14) + -12|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)>(-1);
      if ($17) {
       $20 = (($14) + -24|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (($14) + -20|0);
       $23 = HEAP32[$22>>2]|0;
       HEAP32[$0>>2] = $23;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($21|0),($$byval_copy2|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       HEAP32[$20>>2] = 0;
       $$pre$i$i$i = HEAP32[$10>>2]|0;
       $19 = $$pre$i$i$i;
      } else {
       $19 = $13;
      }
      $18 = ($19|0)==($9|0);
      if ($18) {
       break L3;
      } else {
       $14 = $19;
      }
     }
     $26 = ___cxa_find_matching_catch()|0;
     $27 = tempRet0;
     ___cxa_call_unexpected(($26|0));
     // unreachable;
    }
   } while(0);
   $28 = HEAP32[$activeUniformBlocks>>2]|0;
   __ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE7reserveEj($8,$28);
   $29 = HEAP32[$activeUniformBlocks>>2]|0;
   $30 = ($29|0)>(0);
   if ($30) {
    $31 = (($cb) + 4|0);
    $32 = (($cb) + 12|0);
    $33 = (($cb) + 16|0);
    $34 = (($cb) + 8|0);
    $35 = (($cb) + 20|0);
    $36 = (($cb) + 24|0);
    $37 = (($params) + 68|0);
    $i$012 = 0;
    while(1) {
     $38 = (1147664 + 480|0);
     $39 = HEAP32[$38>>2]|0;
     FUNCTION_TABLE_viiiii[$39 & 255]($program,$i$012,1024,$nameLength,$name);
     $40 = (1147664 + 476|0);
     $41 = HEAP32[$40>>2]|0;
     FUNCTION_TABLE_viiii[$41 & 511]($program,$i$012,35392,$arraySize);
     HEAP32[$cb>>2] = -1;
     HEAP32[$31>>2] = 0;
     HEAP32[$32>>2] = 0;
     HEAP32[$33>>2] = 0;
     HEAP32[$34>>2] = 61;
     HEAP32[$1>>2] = -1;
     __THREW__ = 0;
     invoke_vii(2618,($1|0),($name|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     $44 = HEAP32[$1>>2]|0;
     HEAP32[$cb>>2] = $44;
     $45 = HEAP32[$arraySize>>2]|0;
     HEAP32[$35>>2] = $45;
     HEAP32[$36>>2] = $i$012;
     $46 = (1147664 + 484|0);
     $47 = HEAP32[$46>>2]|0;
     __THREW__ = 0;
     invoke_viii($47|0,($program|0),($i$012|0),($i$012|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[$10>>2]|0;
     $51 = HEAP32[$37>>2]|0;
     $52 = ($50|0)==($51|0);
     if ($52) {
      __THREW__ = 0;
      invoke_vii(3489,($8|0),($cb|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       break;
      }
      $$pre = HEAP32[$33>>2]|0;
      $phitmp15 = ($$pre|0)>(-1);
      if ($phitmp15) {
       label = 19;
      }
     } else {
      $53 = ($50|0)==(0|0);
      if ($53) {
       $73 = 0;
      } else {
       HEAP32[$50>>2] = $44;
       $54 = (($50) + 8|0);
       HEAP32[$54>>2] = 61;
       $55 = (($50) + 12|0);
       $56 = (($50) + 4|0);
       HEAP32[$56>>2] = 0;
       $57 = $55;
       $58 = $57;
       HEAP32[$58>>2] = 0;
       $59 = (($57) + 4)|0;
       $60 = $59;
       HEAP32[$60>>2] = 0;
       $61 = (($50) + 20|0);
       $62 = $35;
       $63 = $62;
       $64 = HEAP32[$63>>2]|0;
       $65 = (($62) + 4)|0;
       $66 = $65;
       $67 = HEAP32[$66>>2]|0;
       $68 = $61;
       $69 = $68;
       HEAP32[$69>>2] = $64;
       $70 = (($68) + 4)|0;
       $71 = $70;
       HEAP32[$71>>2] = $67;
       $$pre$i = HEAP32[$10>>2]|0;
       $73 = $$pre$i;
      }
      $72 = (($73) + 28|0);
      HEAP32[$10>>2] = $72;
      label = 19;
     }
     if ((label|0) == 19) {
      label = 0;
      $76 = HEAP32[$31>>2]|0;
      $77 = HEAP32[$34>>2]|0;
      HEAP32[$0>>2] = $77;
      ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
      __Z19free_alloc_internalPv10MemLabelId($76,$$byval_copy2);
      HEAP32[$31>>2] = 0;
     }
     $78 = (($i$012) + 1)|0;
     $79 = ($78|0)<($29|0);
     if ($79) {
      $i$012 = $78;
     } else {
      break L1;
     }
    }
    $80 = ___cxa_find_matching_catch()|0;
    $81 = tempRet0;
    $82 = HEAP32[$33>>2]|0;
    $83 = ($82|0)>(-1);
    if (!($83)) {
     ___resumeException($80|0);
     // unreachable;
    }
    $84 = HEAP32[$31>>2]|0;
    $85 = HEAP32[$34>>2]|0;
    HEAP32[$0>>2] = $85;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_vii(2591,($84|0),($$byval_copy2|0));
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     $199 = ___cxa_find_matching_catch(0|0)|0;
     $200 = tempRet0;
     ___clang_call_terminate($199);
     // unreachable;
    }
    HEAP32[$31>>2] = 0;
    ___resumeException($80|0);
    // unreachable;
   }
  }
 } while(0);
 $88 = (1147664 + 216|0);
 $89 = HEAP32[$88>>2]|0;
 FUNCTION_TABLE_viii[$89 & 4095]($program,35718,$activeUniforms);
 HEAP32[$i1>>2] = 0;
 $90 = HEAP32[$activeUniforms>>2]|0;
 $91 = ($90|0)>(0);
 if (!($91)) {
  STACKTOP = sp;return;
 }
 $92 = (($params) + 36|0);
 $93 = (($params) + 32|0);
 $96 = 0;
 while(1) {
  $94 = (1147664 + 196|0);
  $95 = HEAP32[$94>>2]|0;
  FUNCTION_TABLE_viiiiiii[$95 & 127]($program,$96,1024,$nameLength,$arraySize,$type,$name);
  $97 = (_strcmp($name,1152776)|0);
  $98 = ($97|0)==(0);
  L42: do {
   if (!($98)) {
    $99 = (_strcmp($name,1152800)|0);
    $100 = ($99|0)==(0);
    if (!($100)) {
     $i$02$i = 0;
     while(1) {
      $103 = (1151856 + ($i$02$i<<3)|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = (_strcmp($name,$104)|0);
      $106 = ($105|0)==(0);
      $102 = (($i$02$i) + 1)|0;
      if ($106) {
       label = 30;
       break;
      }
      $101 = ($102>>>0)<(23);
      if ($101) {
       $i$02$i = $102;
      } else {
       $$0$i = 0;
       break;
      }
     }
     if ((label|0) == 30) {
      label = 0;
      $107 = ((1151856 + ($i$02$i<<3)|0) + 4|0);
      $108 = HEAP32[$107>>2]|0;
      $$0$i = $108;
     }
     $109 = ($$0$i|0)!=(0|0);
     $110 = $109 ? $$0$i : $name;
     $111 = (_strncmp($name,1152816,3)|0);
     $112 = ($111|0)==(0);
     if (!($112)) {
      HEAP32[$uniformNumber>>2] = -1;
      HEAP32[$cbIndex>>2] = -1;
      $113 = (1147664 + 240|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = (FUNCTION_TABLE_iii[$114 & 4095]($program,$name)|0);
      HEAP32[$uniformNumber>>2] = $115;
      $116 = ($115|0)==(-1);
      if ($116) {
       $117 = (1147664 + 468|0);
       $118 = HEAP32[$117>>2]|0;
       FUNCTION_TABLE_viiiii[$118 & 255]($program,1,$i1,35387,$uniformNumber);
       $119 = (1147664 + 468|0);
       $120 = HEAP32[$119>>2]|0;
       FUNCTION_TABLE_viiiii[$120 & 255]($program,1,$i1,35386,$cbIndex);
      }
      HEAP8[$isElemZero>>0] = 0;
      $121 = HEAP32[$nameLength>>2]|0;
      $122 = HEAP32[$arraySize>>2]|0;
      $123 = (__Z22IsShaderParameterArrayPKcjiPb($name,$121,$122,$isElemZero)|0);
      if ($123) {
       $124 = HEAP32[$arraySize>>2]|0;
       $125 = ($124|0)>(99);
       if ($125) {
        __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1152824,0,1152872,196,1,0,0,0);
        HEAP32[$arraySize>>2] = 99;
       }
       $126 = HEAP8[$isElemZero>>0]|0;
       $127 = ($126<<24>>24)==(0);
       $128 = HEAP32[$nameLength>>2]|0;
       if ($127) {
        $glNameIndexOffset$0 = $128;
       } else {
        $129 = (($128) + -3)|0;
        $130 = (($name) + ($129)|0);
        HEAP8[$130>>0] = 48;
        $131 = (($128) + -2)|0;
        $132 = (($name) + ($131)|0);
        HEAP8[$132>>0] = 0;
        $glNameIndexOffset$0 = $129;
       }
      } else {
       $glNameIndexOffset$0 = 0;
      }
      $133 = HEAP32[$type>>2]|0;
      do {
       if ((($133|0) == 35664)) {
        $137 = HEAP32[$uniformNumber>>2]|0;
        $138 = HEAP32[$arraySize>>2]|0;
        $139 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,0,$program,2,$137,$138,$139,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 5126)) {
        $134 = HEAP32[$uniformNumber>>2]|0;
        $135 = HEAP32[$arraySize>>2]|0;
        $136 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,0,$program,1,$134,$135,$136,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35670)) {
        $158 = HEAP32[$uniformNumber>>2]|0;
        $159 = HEAP32[$arraySize>>2]|0;
        $160 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,2,$program,1,$158,$159,$160,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35675)) {
        $173 = HEAP32[$uniformNumber>>2]|0;
        $174 = HEAP32[$arraySize>>2]|0;
        $175 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedMatrixParamGLESR20GpuProgramParametersjiiiiiPKcPciP16PropertyNamesSet($params,$program,3,3,$173,$174,$175,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35671)) {
        $161 = HEAP32[$uniformNumber>>2]|0;
        $162 = HEAP32[$arraySize>>2]|0;
        $163 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,2,$program,2,$161,$162,$163,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35673)) {
        $167 = HEAP32[$uniformNumber>>2]|0;
        $168 = HEAP32[$arraySize>>2]|0;
        $169 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,2,$program,4,$167,$168,$169,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35665)) {
        $140 = HEAP32[$uniformNumber>>2]|0;
        $141 = HEAP32[$arraySize>>2]|0;
        $142 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,0,$program,3,$140,$141,$142,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35676)) {
        $170 = HEAP32[$uniformNumber>>2]|0;
        $171 = HEAP32[$arraySize>>2]|0;
        $172 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedMatrixParamGLESR20GpuProgramParametersjiiiiiPKcPciP16PropertyNamesSet($params,$program,4,4,$170,$171,$172,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35672)) {
        $164 = HEAP32[$uniformNumber>>2]|0;
        $165 = HEAP32[$arraySize>>2]|0;
        $166 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,2,$program,3,$164,$165,$166,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35667)) {
        $149 = HEAP32[$uniformNumber>>2]|0;
        $150 = HEAP32[$arraySize>>2]|0;
        $151 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,1,$program,2,$149,$150,$151,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35669)) {
        $155 = HEAP32[$uniformNumber>>2]|0;
        $156 = HEAP32[$arraySize>>2]|0;
        $157 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,1,$program,4,$155,$156,$157,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 5124)) {
        $146 = HEAP32[$uniformNumber>>2]|0;
        $147 = HEAP32[$arraySize>>2]|0;
        $148 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,1,$program,1,$146,$147,$148,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35666)) {
        $143 = HEAP32[$uniformNumber>>2]|0;
        $144 = HEAP32[$arraySize>>2]|0;
        $145 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,0,$program,4,$143,$144,$145,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else if ((($133|0) == 35668)) {
        $152 = HEAP32[$uniformNumber>>2]|0;
        $153 = HEAP32[$arraySize>>2]|0;
        $154 = HEAP32[$cbIndex>>2]|0;
        __Z23AddSizedVectorParamGLESR20GpuProgramParameters15ShaderParamTypejiiiiPKcPciP16PropertyNamesSet($params,1,$program,3,$152,$153,$154,$110,$name,$glNameIndexOffset$0,$outNames);
        break L42;
       } else {
        $176 = ($133|0)==(35682);
        switch ($133|0) {
        case 35678:  {
         $186 = 2;
         break;
        }
        case 35679:  {
         if (!($fillTextureParams)) {
          break L42;
         }
         $187 = HEAP32[$92>>2]|0;
         $188 = HEAP32[$93>>2]|0;
         $189 = $187;
         $190 = $188;
         $191 = (($189) - ($190))|0;
         $192 = $191 >> 4;
         $193 = (1147664 + 320|0);
         $194 = HEAP32[$193>>2]|0;
         $195 = HEAP32[$uniformNumber>>2]|0;
         FUNCTION_TABLE_vii[$194 & 4095]($195,$192);
         __ZN20GpuProgramParameters15AddTextureParamEiiPKc16TextureDimensionP16PropertyNamesSet($params,$192,-1,$110,3,$outNames);
         break L42;
         break;
        }
        case 36293: case 35682: case 35680:  {
         $phitmp = $176 ? 2 : 4;
         $186 = $phitmp;
         break;
        }
        default: {
         break L42;
        }
        }
        if (!($fillTextureParams)) {
         break L42;
        }
        $177 = HEAP32[$92>>2]|0;
        $178 = HEAP32[$93>>2]|0;
        $179 = $177;
        $180 = $178;
        $181 = (($179) - ($180))|0;
        $182 = $181 >> 4;
        $183 = (1147664 + 320|0);
        $184 = HEAP32[$183>>2]|0;
        $185 = HEAP32[$uniformNumber>>2]|0;
        FUNCTION_TABLE_vii[$184 & 4095]($185,$182);
        __ZN20GpuProgramParameters15AddTextureParamEiiPKc16TextureDimensionP16PropertyNamesSet($params,$182,-1,$110,$186,$outNames);
        break L42;
       }
      } while(0);
     }
    }
   }
  } while(0);
  $196 = HEAP32[$i1>>2]|0;
  $197 = (($196) + 1)|0;
  HEAP32[$i1>>2] = $197;
  $198 = ($197|0)<($90|0);
  if ($198) {
   $96 = $197;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE7reserveEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$byval_copy1 = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $0 = sp;
 $__v = sp + 4|0;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$this>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = (($6|0) / 28)&-1;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (($this) + 8|0);
 $10 = (($this) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11;
 $13 = (($12) - ($5))|0;
 $14 = (($13|0) / 28)&-1;
 $15 = (($__v) + 12|0);
 HEAP32[$15>>2] = 0;
 $16 = (($__v) + 16|0);
 HEAP32[$16>>2] = $9;
 $17 = ($__n|0)==(0);
 if ($17) {
  $20 = 0;
 } else {
  $18 = ($__n*28)|0;
  $19 = (__Znwj($18)|0);
  $20 = $19;
 }
 HEAP32[$__v>>2] = $20;
 $21 = (($20) + (($14*28)|0)|0);
 $22 = (($__v) + 8|0);
 HEAP32[$22>>2] = $21;
 $23 = (($__v) + 4|0);
 HEAP32[$23>>2] = $21;
 $24 = (($20) + (($__n*28)|0)|0);
 HEAP32[$15>>2] = $24;
 __THREW__ = 0;
 invoke_vii(3268,($this|0),($__v|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $47 = ___cxa_find_matching_catch()|0;
  $48 = tempRet0;
  $49 = HEAP32[$23>>2]|0;
  $50 = HEAP32[$22>>2]|0;
  $51 = ($50|0)==($49|0);
  L24: do {
   if (!($51)) {
    $53 = $50;
    while(1) {
     $52 = (($53) + -28|0);
     HEAP32[$22>>2] = $52;
     $54 = (($53) + -12|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)>(-1);
     if ($56) {
      $59 = (($53) + -24|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = (($53) + -20|0);
      $62 = HEAP32[$61>>2]|0;
      HEAP32[$0>>2] = $62;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($60|0),($$byval_copy1|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
      HEAP32[$59>>2] = 0;
      $$pre$i$i$i$i$i = HEAP32[$22>>2]|0;
      $58 = $$pre$i$i$i$i$i;
     } else {
      $58 = $52;
     }
     $57 = ($58|0)==($49|0);
     if ($57) {
      break L24;
     } else {
      $53 = $58;
     }
    }
    $65 = ___cxa_find_matching_catch()|0;
    $66 = tempRet0;
    ___cxa_call_unexpected(($65|0));
    // unreachable;
   }
  } while(0);
  $67 = HEAP32[$__v>>2]|0;
  $68 = ($67|0)==(0|0);
  if ($68) {
   ___resumeException($47|0);
   // unreachable;
  }
  __ZdlPv($67);
  ___resumeException($47|0);
  // unreachable;
 } else {
  $27 = HEAP32[$23>>2]|0;
  $28 = HEAP32[$22>>2]|0;
  $29 = ($28|0)==($27|0);
  L9: do {
   if (!($29)) {
    $31 = $28;
    while(1) {
     $30 = (($31) + -28|0);
     HEAP32[$22>>2] = $30;
     $32 = (($31) + -12|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = ($33|0)>(-1);
     if ($34) {
      $37 = (($31) + -24|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($31) + -20|0);
      $40 = HEAP32[$39>>2]|0;
      HEAP32[$0>>2] = $40;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_vii(2591,($38|0),($$byval_copy1|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      HEAP32[$37>>2] = 0;
      $$pre$i$i$i$i$i3 = HEAP32[$22>>2]|0;
      $36 = $$pre$i$i$i$i$i3;
     } else {
      $36 = $30;
     }
     $35 = ($36|0)==($27|0);
     if ($35) {
      break L9;
     } else {
      $31 = $36;
     }
    }
    $43 = ___cxa_find_matching_catch()|0;
    $44 = tempRet0;
    ___cxa_call_unexpected(($43|0));
    // unreachable;
   }
  } while(0);
  $45 = HEAP32[$__v>>2]|0;
  $46 = ($45|0)==(0|0);
  if ($46) {
   STACKTOP = sp;return;
  }
  __ZdlPv($45);
  STACKTOP = sp;return;
 }
}
function __Z19ApplyValuesBaseGLESP16UniformCacheGLESRK20GpuProgramParametersPK24BuiltinShaderParamValuesPPKh($cache,$params,$values,$buffer) {
 $cache = $cache|0;
 $params = $params|0;
 $values = $values|0;
 $buffer = $buffer|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $i$03 = 0, $i$03$us = 0, $m33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $m33 = sp;
 $0 = (__ZNK20GpuProgramParameters14GetValueParamsEv($params)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($0) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + (($3*20)|0)|0);
 $5 = ($3|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ($buffer|0)==(0|0);
 if ($6) {
  $i$03$us = $1;
  while(1) {
   $7 = (($i$03$us) + 18|0);
   $8 = HEAP8[$7>>0]|0;
   $9 = ($8<<24>>24)==(0);
   do {
    if ($9) {
     $10 = (($i$03$us) + 8|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($11|0)==(1);
     if ($12) {
      $30 = HEAP32[$i$03$us>>2]|0;
      $31 = $30 & 1073741823;
      $32 = (($values) + ($31<<4)|0);
      $33 = (($i$03$us) + 17|0);
      $34 = HEAP8[$33>>0]|0;
      $35 = $34&255;
      if ((($35|0) == 1)) {
       $48 = (($i$03$us) + 12|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = (($i$03$us) + 4|0);
       $51 = HEAP32[$50>>2]|0;
       __Z14CachedUniform1P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$49,$51,$32);
       break;
      } else if ((($35|0) == 4)) {
       $36 = (($i$03$us) + 12|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = (($i$03$us) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       __Z14CachedUniform4P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$37,$39,$32);
       break;
      } else if ((($35|0) == 3)) {
       $40 = (($i$03$us) + 12|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = (($i$03$us) + 4|0);
       $43 = HEAP32[$42>>2]|0;
       __Z14CachedUniform3P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$41,$43,$32);
       break;
      } else if ((($35|0) == 2)) {
       $44 = (($i$03$us) + 12|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = (($i$03$us) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       __Z14CachedUniform2P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$45,$47,$32);
       break;
      } else {
       break;
      }
     } else {
      label = 5;
     }
    } else {
     label = 5;
    }
   } while(0);
   do {
    if ((label|0) == 5) {
     label = 0;
     $13 = HEAP32[$i$03$us>>2]|0;
     $14 = $13 & 1073741823;
     $15 = ((($values) + ($14<<6)|0) + 2720|0);
     $16 = (($i$03$us) + 16|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = ($17<<24>>24)==(3);
     if ($18) {
      $19 = (($i$03$us) + 17|0);
      $20 = HEAP8[$19>>0]|0;
      $21 = ($20<<24>>24)==(3);
      if ($21) {
       __ZN10Matrix3x3fC2ERK10Matrix4x4f($m33,$15);
       $26 = (1147664 + 352|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = (($i$03$us) + 4|0);
       $29 = HEAP32[$28>>2]|0;
       FUNCTION_TABLE_viiii[$27 & 511]($29,1,0,$m33);
       break;
      }
     }
     $22 = (1147664 + 356|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = (($i$03$us) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     FUNCTION_TABLE_viiii[$23 & 511]($25,1,0,$15);
    }
   } while(0);
   $52 = (($i$03$us) + 20|0);
   $53 = ($52|0)==($4|0);
   if ($53) {
    break;
   } else {
    $i$03$us = $52;
   }
  }
  STACKTOP = sp;return;
 } else {
  $i$03 = $1;
  while(1) {
   $54 = (($i$03) + 18|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = ($55<<24>>24)==(0);
   do {
    if ($56) {
     $57 = (($i$03) + 8|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(1);
     if ($59) {
      $60 = HEAP32[$buffer>>2]|0;
      $61 = (($60) + 16|0);
      HEAP32[$buffer>>2] = $61;
      $62 = (($i$03) + 17|0);
      $63 = HEAP8[$62>>0]|0;
      $64 = $63&255;
      if ((($64|0) == 1)) {
       $65 = (($i$03) + 12|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = (($i$03) + 4|0);
       $68 = HEAP32[$67>>2]|0;
       __Z14CachedUniform1P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$66,$68,$60);
       break;
      } else if ((($64|0) == 2)) {
       $69 = (($i$03) + 12|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = (($i$03) + 4|0);
       $72 = HEAP32[$71>>2]|0;
       __Z14CachedUniform2P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$70,$72,$60);
       break;
      } else if ((($64|0) == 3)) {
       $73 = (($i$03) + 12|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = (($i$03) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       __Z14CachedUniform3P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$74,$76,$60);
       break;
      } else if ((($64|0) == 4)) {
       $77 = (($i$03) + 12|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = (($i$03) + 4|0);
       $80 = HEAP32[$79>>2]|0;
       __Z14CachedUniform4P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$78,$80,$60);
       break;
      } else {
       break;
      }
     } else {
      label = 22;
     }
    } else {
     label = 22;
    }
   } while(0);
   do {
    if ((label|0) == 22) {
     label = 0;
     $81 = HEAP32[$buffer>>2]|0;
     $82 = HEAP32[$81>>2]|0;
     $83 = (($81) + 4|0);
     $84 = $82 << 2;
     $$sum = (($84) + 4)|0;
     $85 = (($81) + ($$sum)|0);
     HEAP32[$buffer>>2] = $85;
     $86 = (($i$03) + 16|0);
     $87 = HEAP8[$86>>0]|0;
     $88 = ($87<<24>>24)==(3);
     if ($88) {
      $89 = (($i$03) + 17|0);
      $90 = HEAP8[$89>>0]|0;
      $91 = ($90<<24>>24)==(3);
      if ($91) {
       __ZN10Matrix3x3fC2ERK10Matrix4x4f($m33,$83);
       $92 = (1147664 + 352|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = (($i$03) + 4|0);
       $95 = HEAP32[$94>>2]|0;
       FUNCTION_TABLE_viiii[$93 & 511]($95,1,0,$m33);
       break;
      }
     }
     $96 = (1147664 + 356|0);
     $97 = HEAP32[$96>>2]|0;
     $98 = (($i$03) + 4|0);
     $99 = HEAP32[$98>>2]|0;
     FUNCTION_TABLE_viiii[$97 & 511]($99,1,0,$83);
    }
   } while(0);
   $100 = (($i$03) + 20|0);
   $101 = ($100|0)==($4|0);
   if ($101) {
    break;
   } else {
    $i$03 = $100;
   }
  }
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_($this,$__x) {
 $this = $this|0;
 $__x = $__x|0;
 var $$0$i7 = 0, $$0$i8 = 0, $$byval_copy2 = 0, $$idx$i$i$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i3 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 28|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__v = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$this>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = (($8|0) / 28)&-1;
 $10 = (($9) + 1)|0;
 $11 = ($10>>>0)>(153391689);
 if ($11) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $12 = (($this) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13;
 $15 = (($14) - ($7))|0;
 $16 = (($15|0) / 28)&-1;
 $17 = ($16>>>0)<(76695844);
 if ($17) {
  $20 = $16 << 1;
  $21 = ($20>>>0)<($10>>>0);
  $22 = $21 ? $10 : $20;
  $23 = (($__v) + 12|0);
  HEAP32[$23>>2] = 0;
  $24 = (($__v) + 16|0);
  HEAP32[$24>>2] = $2;
  $25 = ($22|0)==(0);
  if ($25) {
   $$0$i8 = 0;$28 = 0;$33 = $23;
  } else {
   $$0$i7 = $22;$111 = $23;
   label = 6;
  }
 } else {
  $18 = (($__v) + 12|0);
  HEAP32[$18>>2] = 0;
  $19 = (($__v) + 16|0);
  HEAP32[$19>>2] = $2;
  $$0$i7 = 153391689;$111 = $18;
  label = 6;
 }
 if ((label|0) == 6) {
  $26 = ($$0$i7*28)|0;
  $27 = (__Znwj($26)|0);
  $$0$i8 = $$0$i7;$28 = $27;$33 = $111;
 }
 HEAP32[$__v>>2] = $28;
 $29 = (($28) + (($9*28)|0)|0);
 $30 = (($__v) + 8|0);
 HEAP32[$30>>2] = $29;
 $31 = (($__v) + 4|0);
 HEAP32[$31>>2] = $29;
 $32 = (($28) + (($$0$i8*28)|0)|0);
 HEAP32[$33>>2] = $32;
 $34 = ($29|0)==(0|0);
 do {
  if ($34) {
   label = 12;
  } else {
   $35 = HEAP32[$__x>>2]|0;
   HEAP32[$29>>2] = $35;
   $36 = (($__x) + 8|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ((($28) + (($9*28)|0)|0) + 8|0);
   HEAP32[$38>>2] = $37;
   $39 = ((($28) + (($9*28)|0)|0) + 12|0);
   $40 = ((($28) + (($9*28)|0)|0) + 16|0);
   HEAP32[$40>>2] = 0;
   $41 = ((($28) + (($9*28)|0)|0) + 4|0);
   HEAP32[$41>>2] = 0;
   $42 = (($__x) + 4|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($__x) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   $$idx$i$i$i$i$i = ($45*20)|0;
   $46 = (($$idx$i$i$i$i$i|0) / 20)&-1;
   HEAP32[$39>>2] = $46;
   $47 = ($$idx$i$i$i$i$i|0)==(0);
   if ($47) {
    $52 = $46;$53 = 0;
   } else {
    HEAP32[$40>>2] = $46;
    HEAP32[$0>>2] = $37;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    $48 = (invoke_iiiiiiii(108,(0|0),($$idx$i$i$i$i$i|0),4,($$byval_copy2|0),0,(1152872|0),370)|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    HEAP32[$41>>2] = $48;
    $$pre$i$i$i$i = HEAP32[$39>>2]|0;
    $52 = $$pre$i$i$i$i;$53 = $48;
   }
   $51 = ($52*20)|0;
   _memcpy(($53|0),($43|0),($51|0))|0;
   $54 = ((($28) + (($9*28)|0)|0) + 20|0);
   $55 = (($__x) + 20|0);
   $56 = $55;
   $57 = $56;
   $58 = HEAP32[$57>>2]|0;
   $59 = (($56) + 4)|0;
   $60 = $59;
   $61 = HEAP32[$60>>2]|0;
   $62 = $54;
   $63 = $62;
   HEAP32[$63>>2] = $58;
   $64 = (($62) + 4)|0;
   $65 = $64;
   HEAP32[$65>>2] = $61;
   label = 12;
  }
 } while(0);
 if ((label|0) == 12) {
  $$sum = (($9) + 1)|0;
  $66 = (($28) + (($$sum*28)|0)|0);
  HEAP32[$30>>2] = $66;
  __THREW__ = 0;
  invoke_vii(3268,($this|0),($__v|0));
  $67 = __THREW__; __THREW__ = 0;
  $68 = $67&1;
  if (!($68)) {
   $69 = HEAP32[$31>>2]|0;
   $70 = HEAP32[$30>>2]|0;
   $71 = ($70|0)==($69|0);
   L19: do {
    if (!($71)) {
     $73 = $70;
     while(1) {
      $72 = (($73) + -28|0);
      HEAP32[$30>>2] = $72;
      $74 = (($73) + -12|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($75|0)>(-1);
      if ($76) {
       $79 = (($73) + -24|0);
       $80 = HEAP32[$79>>2]|0;
       $81 = (($73) + -20|0);
       $82 = HEAP32[$81>>2]|0;
       HEAP32[$0>>2] = $82;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2591,($80|0),($$byval_copy2|0));
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        break;
       }
       HEAP32[$79>>2] = 0;
       $$pre$i$i$i$i$i3 = HEAP32[$30>>2]|0;
       $78 = $$pre$i$i$i$i$i3;
      } else {
       $78 = $72;
      }
      $77 = ($78|0)==($69|0);
      if ($77) {
       break L19;
      } else {
       $73 = $78;
      }
     }
     $85 = ___cxa_find_matching_catch()|0;
     $86 = tempRet0;
     ___cxa_call_unexpected(($85|0));
     // unreachable;
    }
   } while(0);
   $87 = HEAP32[$__v>>2]|0;
   $88 = ($87|0)==(0|0);
   if ($88) {
    STACKTOP = sp;return;
   }
   __ZdlPv($87);
   STACKTOP = sp;return;
  }
 }
 $89 = ___cxa_find_matching_catch()|0;
 $90 = tempRet0;
 $91 = HEAP32[$31>>2]|0;
 $92 = HEAP32[$30>>2]|0;
 $93 = ($92|0)==($91|0);
 L34: do {
  if (!($93)) {
   $95 = $92;
   while(1) {
    $94 = (($95) + -28|0);
    HEAP32[$30>>2] = $94;
    $96 = (($95) + -12|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($97|0)>(-1);
    if ($98) {
     $101 = (($95) + -24|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = (($95) + -20|0);
     $104 = HEAP32[$103>>2]|0;
     HEAP32[$1>>2] = $104;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
     invoke_vii(2591,($102|0),($$byval_copy2|0));
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      break;
     }
     HEAP32[$101>>2] = 0;
     $$pre$i$i$i$i$i = HEAP32[$30>>2]|0;
     $100 = $$pre$i$i$i$i$i;
    } else {
     $100 = $94;
    }
    $99 = ($100|0)==($91|0);
    if ($99) {
     break L34;
    } else {
     $95 = $100;
    }
   }
   $107 = ___cxa_find_matching_catch()|0;
   $108 = tempRet0;
   ___cxa_call_unexpected(($107|0));
   // unreachable;
  }
 } while(0);
 $109 = HEAP32[$__v>>2]|0;
 $110 = ($109|0)==(0|0);
 if ($110) {
  ___resumeException($89|0);
  // unreachable;
 }
 __ZdlPv($109);
 ___resumeException($89|0);
 // unreachable;
}
function __ZN4gles8internal14InitCapsCommonE17GfxDeviceRendererP12GraphicsCaps($renderer,$caps) {
 $renderer = $renderer|0;
 $caps = $caps|0;
 var $$ = 0, $$0 = 0, $$0$i$i75 = 0, $$0$i$i87 = 0, $$01 = 0, $$01$be$i$i$i$i = 0, $$01$be$i$i$i$i45 = 0, $$01$be$i$i$i$i57 = 0, $$01$be$i$i$i$i69 = 0, $$01$be$i$i$i$i81 = 0, $$014$i$i$i$i = 0, $$014$i$i$i$i44 = 0, $$014$i$i$i$i56 = 0, $$014$i$i$i$i68 = 0, $$014$i$i$i$i80 = 0, $$1 = 0, $$12 = 0, $$122 = 0, $$byval_copy21 = 0, $$pre$i$i$i = 0;
 var $$pre$i$i$i$i$i = 0, $$pre$i$i$i$i$i94 = 0, $$pre$i$i$i95 = 0, $$sum$i$i = 0, $$sum$i$i42 = 0, $$sum$i$i54 = 0, $$sum$i$i66 = 0, $$sum$i$i78 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0;
 var $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0;
 var $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0;
 var $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__m1$0$i$i$i$i = 0, $__m1$0$i$i$i$i47 = 0, $__m1$0$i$i$i$i59 = 0, $__m1$0$i$i$i$i71 = 0, $__m1$0$i$i$i$i83 = 0, $__m2$0$i$i$i$i = 0, $__m2$0$i$i$i$i48 = 0, $__m2$0$i$i$i$i60 = 0;
 var $__m2$0$i$i$i$i72 = 0, $__m2$0$i$i$i$i84 = 0, $__p$0$i$i$i$i = 0, $__p$0$i$i$i$i14 = 0, $__p$0$i$i$i$i24 = 0, $__p$0$i$i$i$i8 = 0, $not$ = 0, $not$110 = 0, $parts = 0, $phitmp = 0, $phitmp$i$i = 0, $phitmp100 = 0, $phitmp101 = 0, $phitmp102 = 0, $phitmp103 = 0, $phitmp104 = 0, $phitmp105 = 0, $phitmp106 = 0, $phitmp107 = 0, $phitmp108 = 0;
 var $phitmp109 = 0, $phitmp3 = 0, $phitmp4 = 0, $phitmp5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy21 = sp;
 $0 = sp + 100|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 88|0;
 $4 = sp + 84|0;
 $5 = sp + 80|0;
 $6 = sp + 104|0;
 $7 = sp + 52|0;
 $8 = sp + 40|0;
 $9 = sp + 28|0;
 $10 = sp + 16|0;
 $11 = sp + 4|0;
 $parts = sp + 56|0;
 $12 = sp + 68|0;
 $13 = (($caps) + 60|0);
 HEAP32[$13>>2] = 0;
 $14 = (($caps) + 64|0);
 HEAP32[$14>>2] = 0;
 $15 = (1147664 + 232|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_ii[$16 & 4095](7937)|0);
 $18 = ($17|0)!=(0|0);
 $19 = $18 ? $17 : 1152888;
 $20 = (_strlen(($19|0))|0);
 $21 = ($20>>>0)>(2147483631);
 if ($21) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $22 = ($20>>>0)<(11);
 if ($22) {
  $23 = $20 << 1;
  $24 = $23&255;
  HEAP8[$8>>0] = $24;
  $25 = (($8) + 1|0);
  $__p$0$i$i$i$i = $25;
 } else {
  $26 = (($20) + 16)|0;
  $27 = $26 & -16;
  HEAP32[$0>>2] = 60;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
  $28 = (__Z15malloc_internaljj10MemLabelIdiPKci($27,16,$$byval_copy21,0,1154344,79)|0);
  $29 = (($8) + 8|0);
  HEAP32[$29>>2] = $28;
  $30 = $27 | 1;
  HEAP32[$8>>2] = $30;
  $31 = (($8) + 4|0);
  HEAP32[$31>>2] = $20;
  $__p$0$i$i$i$i = $28;
 }
 _memcpy(($__p$0$i$i$i$i|0),($19|0),($20|0))|0;
 $32 = (($__p$0$i$i$i$i) + ($20)|0);
 HEAP8[$32>>0] = 0;
 __THREW__ = 0;
 (invoke_iii(2720,($caps|0),($8|0))|0);
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $253 = ___cxa_find_matching_catch()|0;
  $254 = tempRet0;
  $255 = HEAP8[$8>>0]|0;
  $256 = $255 & 1;
  $257 = ($256<<24>>24)==(0);
  if ($257) {
   $$1 = $253;$$12 = $254;
   ___resumeException($$1|0);
   // unreachable;
  }
  $258 = (($8) + 8|0);
  $259 = HEAP32[$258>>2]|0;
  HEAP32[$3>>2] = 60;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$3+0>>2]|0;
  invoke_vii(2591,($259|0),($$byval_copy21|0));
  $260 = __THREW__; __THREW__ = 0;
  $261 = $260&1;
  if ($261) {
   $262 = ___cxa_find_matching_catch()|0;
   $263 = tempRet0;
   ___cxa_call_unexpected(($262|0));
   // unreachable;
  } else {
   $$1 = $253;$$12 = $254;
   ___resumeException($$1|0);
   // unreachable;
  }
 }
 $35 = HEAP8[$8>>0]|0;
 $36 = $35 & 1;
 $37 = ($36<<24>>24)==(0);
 if (!($37)) {
  $38 = (($8) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  HEAP32[$7>>2] = 60;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$7+0>>2]|0;
  invoke_vii(2591,($39|0),($$byval_copy21|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   $42 = ___cxa_find_matching_catch()|0;
   $43 = tempRet0;
   ___cxa_call_unexpected(($42|0));
   // unreachable;
  }
 }
 $44 = (1147664 + 232|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (FUNCTION_TABLE_ii[$45 & 4095](7936)|0);
 $47 = ($46|0)!=(0|0);
 $48 = $47 ? $46 : 1152888;
 $49 = (_strlen(($48|0))|0);
 $50 = ($49>>>0)>(2147483631);
 if ($50) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $51 = ($49>>>0)<(11);
 if ($51) {
  $52 = $49 << 1;
  $53 = $52&255;
  HEAP8[$9>>0] = $53;
  $54 = (($9) + 1|0);
  $__p$0$i$i$i$i8 = $54;
 } else {
  $55 = (($49) + 16)|0;
  $56 = $55 & -16;
  HEAP32[$0>>2] = 60;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
  $57 = (__Z15malloc_internaljj10MemLabelIdiPKci($56,16,$$byval_copy21,0,1154344,79)|0);
  $58 = (($9) + 8|0);
  HEAP32[$58>>2] = $57;
  $59 = $56 | 1;
  HEAP32[$9>>2] = $59;
  $60 = (($9) + 4|0);
  HEAP32[$60>>2] = $49;
  $__p$0$i$i$i$i8 = $57;
 }
 _memcpy(($__p$0$i$i$i$i8|0),($48|0),($49|0))|0;
 $61 = (($__p$0$i$i$i$i8) + ($49)|0);
 HEAP8[$61>>0] = 0;
 $62 = (($caps) + 12|0);
 __THREW__ = 0;
 (invoke_iii(2720,($62|0),($9|0))|0);
 $63 = __THREW__; __THREW__ = 0;
 $64 = $63&1;
 if ($64) {
  $264 = ___cxa_find_matching_catch()|0;
  $265 = tempRet0;
  $266 = HEAP8[$9>>0]|0;
  $267 = $266 & 1;
  $268 = ($267<<24>>24)==(0);
  if ($268) {
   $$1 = $264;$$12 = $265;
   ___resumeException($$1|0);
   // unreachable;
  }
  $269 = (($9) + 8|0);
  $270 = HEAP32[$269>>2]|0;
  HEAP32[$2>>2] = 60;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($270|0),($$byval_copy21|0));
  $271 = __THREW__; __THREW__ = 0;
  $272 = $271&1;
  if ($272) {
   $273 = ___cxa_find_matching_catch()|0;
   $274 = tempRet0;
   ___cxa_call_unexpected(($273|0));
   // unreachable;
  } else {
   $$1 = $264;$$12 = $265;
   ___resumeException($$1|0);
   // unreachable;
  }
 }
 $65 = HEAP8[$9>>0]|0;
 $66 = $65 & 1;
 $67 = ($66<<24>>24)==(0);
 if (!($67)) {
  $68 = (($9) + 8|0);
  $69 = HEAP32[$68>>2]|0;
  HEAP32[$6>>2] = 60;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$6+0>>2]|0;
  invoke_vii(2591,($69|0),($$byval_copy21|0));
  $70 = __THREW__; __THREW__ = 0;
  $71 = $70&1;
  if ($71) {
   $72 = ___cxa_find_matching_catch()|0;
   $73 = tempRet0;
   ___cxa_call_unexpected(($72|0));
   // unreachable;
  }
 }
 $74 = (1147664 + 232|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (FUNCTION_TABLE_ii[$75 & 4095](7938)|0);
 $77 = (($caps) + 24|0);
 $78 = ($76|0)!=(0|0);
 $79 = $78 ? $76 : 1152888;
 $80 = (_strlen(($79|0))|0);
 $81 = ($80>>>0)>(2147483631);
 if ($81) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $82 = ($80>>>0)<(11);
 if ($82) {
  $83 = $80 << 1;
  $84 = $83&255;
  HEAP8[$10>>0] = $84;
  $85 = (($10) + 1|0);
  $__p$0$i$i$i$i14 = $85;
 } else {
  $86 = (($80) + 16)|0;
  $87 = $86 & -16;
  HEAP32[$0>>2] = 60;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
  $88 = (__Z15malloc_internaljj10MemLabelIdiPKci($87,16,$$byval_copy21,0,1154344,79)|0);
  $89 = (($10) + 8|0);
  HEAP32[$89>>2] = $88;
  $90 = $87 | 1;
  HEAP32[$10>>2] = $90;
  $91 = (($10) + 4|0);
  HEAP32[$91>>2] = $80;
  $__p$0$i$i$i$i14 = $88;
 }
 _memcpy(($__p$0$i$i$i$i14|0),($79|0),($80|0))|0;
 $92 = (($__p$0$i$i$i$i14) + ($80)|0);
 HEAP8[$92>>0] = 0;
 __THREW__ = 0;
 (invoke_iii(2720,($77|0),($10|0))|0);
 $93 = __THREW__; __THREW__ = 0;
 $94 = $93&1;
 if ($94) {
  $275 = ___cxa_find_matching_catch()|0;
  $276 = tempRet0;
  $277 = HEAP8[$10>>0]|0;
  $278 = $277 & 1;
  $279 = ($278<<24>>24)==(0);
  if ($279) {
   $$1 = $275;$$12 = $276;
   ___resumeException($$1|0);
   // unreachable;
  }
  $280 = (($10) + 8|0);
  $281 = HEAP32[$280>>2]|0;
  HEAP32[$1>>2] = 60;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($281|0),($$byval_copy21|0));
  $282 = __THREW__; __THREW__ = 0;
  $283 = $282&1;
  if ($283) {
   $284 = ___cxa_find_matching_catch()|0;
   $285 = tempRet0;
   ___cxa_call_unexpected(($284|0));
   // unreachable;
  } else {
   $$1 = $275;$$12 = $276;
   ___resumeException($$1|0);
   // unreachable;
  }
 }
 $95 = HEAP8[$10>>0]|0;
 $96 = $95 & 1;
 $97 = ($96<<24>>24)==(0);
 if (!($97)) {
  $98 = (($10) + 8|0);
  $99 = HEAP32[$98>>2]|0;
  HEAP32[$5>>2] = 60;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$5+0>>2]|0;
  invoke_vii(2591,($99|0),($$byval_copy21|0));
  $100 = __THREW__; __THREW__ = 0;
  $101 = $100&1;
  if ($101) {
   $102 = ___cxa_find_matching_catch()|0;
   $103 = tempRet0;
   ___cxa_call_unexpected(($102|0));
   // unreachable;
  }
 }
 HEAP8[$11>>0] = 6;
 $104 = (($11) + 1|0);
 ;HEAP8[$104+0>>0]=HEAP8[1152904+0>>0]|0;HEAP8[$104+1>>0]=HEAP8[1152904+1>>0]|0;HEAP8[$104+2>>0]=HEAP8[1152904+2>>0]|0;
 $105 = (($11) + 4|0);
 HEAP8[$105>>0] = 0;
 $106 = (($caps) + 48|0);
 __THREW__ = 0;
 (invoke_iii(2720,($106|0),($11|0))|0);
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $286 = ___cxa_find_matching_catch()|0;
  $287 = tempRet0;
  $288 = HEAP8[$11>>0]|0;
  $289 = $288 & 1;
  $290 = ($289<<24>>24)==(0);
  if ($290) {
   $$1 = $286;$$12 = $287;
   ___resumeException($$1|0);
   // unreachable;
  }
  $291 = (($11) + 8|0);
  $292 = HEAP32[$291>>2]|0;
  HEAP32[$0>>2] = 60;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$0+0>>2]|0;
  invoke_vii(2591,($292|0),($$byval_copy21|0));
  $293 = __THREW__; __THREW__ = 0;
  $294 = $293&1;
  if ($294) {
   $295 = ___cxa_find_matching_catch()|0;
   $296 = tempRet0;
   ___cxa_call_unexpected(($295|0));
   // unreachable;
  } else {
   $$1 = $286;$$12 = $287;
   ___resumeException($$1|0);
   // unreachable;
  }
 }
 $109 = HEAP8[$11>>0]|0;
 $110 = $109 & 1;
 $111 = ($110<<24>>24)==(0);
 if (!($111)) {
  $112 = (($11) + 8|0);
  $113 = HEAP32[$112>>2]|0;
  HEAP32[$4>>2] = 60;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy21+0>>2]=HEAP32[$4+0>>2]|0;
  invoke_vii(2591,($113|0),($$byval_copy21|0));
  $114 = __THREW__; __THREW__ = 0;
  $115 = $114&1;
  if ($115) {
   $116 = ___cxa_find_matching_catch()|0;
   $117 = tempRet0;
   ___cxa_call_unexpected(($116|0));
   // unreachable;
  }
 }
 $118 = (($caps) + 280|0);
 $119 = (($caps) + 308|0);
 HEAP32[$119>>2] = 0;
 HEAP32[$parts>>2] = 0;
 $120 = (($parts) + 4|0);
 HEAP32[$120>>2] = 0;
 $121 = (($parts) + 8|0);
 HEAP32[$121>>2] = 0;
 $122 = HEAP8[$77>>0]|0;
 $123 = $122 & 1;
 $124 = ($123<<24>>24)==(0);
 if ($124) {
  $125 = (($77) + 1|0);
  $126 = $122&255;
  $127 = $126 >>> 1;
  $136 = $127;$148 = $125;
  label = 37;
 } else {
  $128 = (($caps) + 32|0);
  $129 = HEAP32[$128>>2]|0;
  $130 = (($caps) + 28|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ($131>>>0)>(4294967279);
  if ($132) {
   __THREW__ = 0;
   invoke_vi(3309,0);
   $133 = __THREW__; __THREW__ = 0;
   $134 = $133&1;
   if ($134) {
    label = 87;
   } else {
    // unreachable;
   }
  } else {
   $136 = $131;$148 = $129;
   label = 37;
  }
 }
 L79: do {
  if ((label|0) == 37) {
   $135 = ($136>>>0)<(11);
   if ($135) {
    $137 = $136 << 1;
    $138 = $137&255;
    HEAP8[$12>>0] = $138;
    $139 = (($12) + 1|0);
    $__p$0$i$i$i$i24 = $139;
   } else {
    $140 = (($136) + 16)|0;
    $141 = $140 & -16;
    __THREW__ = 0;
    $142 = (invoke_ii(2988,($141|0))|0);
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if ($144) {
     label = 87;
     break;
    }
    $145 = (($12) + 8|0);
    HEAP32[$145>>2] = $142;
    $146 = $141 | 1;
    HEAP32[$12>>2] = $146;
    $147 = (($12) + 4|0);
    HEAP32[$147>>2] = $136;
    $__p$0$i$i$i$i24 = $142;
   }
   _memcpy(($__p$0$i$i$i$i24|0),($148|0),($136|0))|0;
   $149 = (($__p$0$i$i$i$i24) + ($136)|0);
   HEAP8[$149>>0] = 0;
   __THREW__ = 0;
   invoke_viiii(457,($12|0),32,($parts|0),4);
   $150 = __THREW__; __THREW__ = 0;
   $151 = $150&1;
   if ($151) {
    $299 = ___cxa_find_matching_catch()|0;
    $300 = tempRet0;
    $301 = HEAP8[$12>>0]|0;
    $302 = $301 & 1;
    $303 = ($302<<24>>24)==(0);
    if ($303) {
     $$0 = $299;$$01 = $300;
     break;
    }
    $304 = (($12) + 8|0);
    $305 = HEAP32[$304>>2]|0;
    __ZdlPv($305);
    $$0 = $299;$$01 = $300;
    break;
   }
   $152 = HEAP8[$12>>0]|0;
   $153 = $152 & 1;
   $154 = ($153<<24>>24)==(0);
   if (!($154)) {
    $155 = (($12) + 8|0);
    $156 = HEAP32[$155>>2]|0;
    __ZdlPv($156);
   }
   $157 = HEAP32[$120>>2]|0;
   $158 = HEAP32[$parts>>2]|0;
   $159 = $157;
   $160 = $158;
   $161 = (($159) - ($160))|0;
   $162 = ($161|0)>(24);
   do {
    if ($162) {
     $163 = HEAP8[$158>>0]|0;
     $164 = $163 & 1;
     $165 = ($164<<24>>24)==(0);
     if ($165) {
      $170 = $163&255;
      $171 = $170 >>> 1;
      $172 = (($158) + 1|0);
      $174 = $171;$176 = $172;
     } else {
      $166 = (($158) + 4|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = (($158) + 8|0);
      $169 = HEAP32[$168>>2]|0;
      $174 = $167;$176 = $169;
     }
     $173 = ($174>>>0)>(6);
     $175 = $173 ? 6 : $174;
     $177 = (_memcmp($176,1152912,$175)|0);
     $178 = ($177|0)==(0);
     if (!($178)) {
      break;
     }
     $179 = $173 ^ 1;
     $not$ = ($174>>>0)>(5);
     $180 = $not$ & $179;
     if (!($180)) {
      break;
     }
     $181 = (($158) + 12|0);
     $182 = HEAP8[$181>>0]|0;
     $183 = $182 & 1;
     $184 = ($183<<24>>24)==(0);
     if ($184) {
      $189 = $182&255;
      $190 = $189 >>> 1;
      $191 = (($181) + 1|0);
      $193 = $190;$195 = $191;
     } else {
      $185 = (($158) + 16|0);
      $186 = HEAP32[$185>>2]|0;
      $187 = (($158) + 20|0);
      $188 = HEAP32[$187>>2]|0;
      $193 = $186;$195 = $188;
     }
     $192 = ($193>>>0)>(2);
     $194 = $192 ? 2 : $193;
     $196 = (_memcmp($195,1152920,$194)|0);
     $197 = ($196|0)==(0);
     if (!($197)) {
      break;
     }
     $198 = $192 ^ 1;
     $not$110 = ($193>>>0)>(1);
     $199 = $not$110 & $198;
     if (!($199)) {
      break;
     }
     $200 = (($158) + 24|0);
     $201 = HEAP8[$200>>0]|0;
     $202 = $201 & 1;
     $203 = ($202<<24>>24)==(0);
     if ($203) {
      $206 = (($200) + 1|0);
      $207 = $206;
     } else {
      $204 = (($158) + 32|0);
      $205 = HEAP32[$204>>2]|0;
      $207 = $205;
     }
     $208 = (_atoi($207)|0);
     HEAP32[$119>>2] = $208;
     $209 = ($161|0)>(36);
     if (!($209)) {
      break;
     }
     $210 = (($158) + 36|0);
     $211 = HEAP8[$210>>0]|0;
     $212 = $211 & 1;
     $213 = ($212<<24>>24)==(0);
     if ($213) {
      $218 = (($210) + 1|0);
      $219 = $211&255;
      $220 = $219 >>> 1;
      $229 = $220;$237 = $218;
     } else {
      $214 = (($158) + 44|0);
      $215 = HEAP32[$214>>2]|0;
      $216 = (($158) + 40|0);
      $217 = HEAP32[$216>>2]|0;
      $229 = $217;$237 = $215;
     }
     $221 = HEAP8[$106>>0]|0;
     $222 = $221 & 1;
     $223 = ($222<<24>>24)==(0);
     if ($223) {
      $228 = 10;$231 = $221;
     } else {
      $224 = HEAP32[$106>>2]|0;
      $225 = $224 & -2;
      $phitmp$i$i = (($225) + -1)|0;
      $226 = $224&255;
      $228 = $phitmp$i$i;$231 = $226;
     }
     $227 = ($228>>>0)<($229>>>0);
     $230 = $231 & 1;
     $232 = ($230<<24>>24)==(0);
     if ($227) {
      if ($232) {
       $247 = $231&255;
       $248 = $247 >>> 1;
       $250 = $248;
      } else {
       $245 = (($caps) + 52|0);
       $246 = HEAP32[$245>>2]|0;
       $250 = $246;
      }
      $249 = (($229) - ($228))|0;
      __THREW__ = 0;
      invoke_viiiiiiii(36,($106|0),($228|0),($249|0),($250|0),0,($250|0),($229|0),($237|0));
      $251 = __THREW__; __THREW__ = 0;
      $252 = $251&1;
      if ($252) {
       label = 87;
       break L79;
      } else {
       break;
      }
     }
     if ($232) {
      $235 = (($106) + 1|0);
      $236 = $235;
     } else {
      $233 = (($caps) + 56|0);
      $234 = HEAP32[$233>>2]|0;
      $236 = $234;
     }
     _memmove(($236|0),($237|0),($229|0))|0;
     $238 = (($236) + ($229)|0);
     HEAP8[$238>>0] = 0;
     $239 = HEAP8[$106>>0]|0;
     $240 = $239 & 1;
     $241 = ($240<<24>>24)==(0);
     if ($241) {
      $243 = $229 << 1;
      $244 = $243&255;
      HEAP8[$106>>0] = $244;
      break;
     } else {
      $242 = (($caps) + 52|0);
      HEAP32[$242>>2] = $229;
      break;
     }
    }
   } while(0);
   $306 = (($caps) + 36|0);
   __THREW__ = 0;
   (invoke_iii(2720,($306|0),($77|0))|0);
   $307 = __THREW__; __THREW__ = 0;
   $308 = $307&1;
   if ($308) {
    label = 87;
    break;
   }
   $309 = (1147664 + 212|0);
   $310 = HEAP32[$309>>2]|0;
   __THREW__ = 0;
   invoke_vii($310|0,34921,($118|0));
   $311 = __THREW__; __THREW__ = 0;
   $312 = $311&1;
   if ($312) {
    label = 87;
    break;
   }
   $313 = (1147664 + 212|0);
   $314 = HEAP32[$313>>2]|0;
   $315 = (($caps) + 284|0);
   __THREW__ = 0;
   invoke_vii($314|0,36348,($315|0));
   $316 = __THREW__; __THREW__ = 0;
   $317 = $316&1;
   if ($317) {
    label = 87;
    break;
   }
   $318 = (1147664 + 212|0);
   $319 = HEAP32[$318>>2]|0;
   $320 = (($caps) + 292|0);
   __THREW__ = 0;
   invoke_vii($319|0,35660,($320|0));
   $321 = __THREW__; __THREW__ = 0;
   $322 = $321&1;
   if ($322) {
    label = 87;
    break;
   }
   $323 = (1147664 + 212|0);
   $324 = HEAP32[$323>>2]|0;
   $325 = (($caps) + 108|0);
   __THREW__ = 0;
   invoke_vii($324|0,3379,($325|0));
   $326 = __THREW__; __THREW__ = 0;
   $327 = $326&1;
   if ($327) {
    label = 87;
    break;
   }
   $328 = (1147664 + 212|0);
   $329 = HEAP32[$328>>2]|0;
   $330 = (($caps) + 112|0);
   __THREW__ = 0;
   invoke_vii($329|0,34076,($330|0));
   $331 = __THREW__; __THREW__ = 0;
   $332 = $331&1;
   if ($332) {
    label = 87;
    break;
   }
   $333 = (1147664 + 212|0);
   $334 = HEAP32[$333>>2]|0;
   $335 = (($caps) + 116|0);
   __THREW__ = 0;
   invoke_vii($334|0,34024,($335|0));
   $336 = __THREW__; __THREW__ = 0;
   $337 = $336&1;
   if ($337) {
    label = 87;
    break;
   }
   $338 = (1147664 + 212|0);
   $339 = HEAP32[$338>>2]|0;
   $340 = (($caps) + 96|0);
   __THREW__ = 0;
   invoke_vii($339|0,35661,($340|0));
   $341 = __THREW__; __THREW__ = 0;
   $342 = $341&1;
   if ($342) {
    label = 87;
    break;
   }
   $343 = HEAP32[$340>>2]|0;
   $344 = ($343|0)>(32);
   $345 = $344 ? 32 : $343;
   $346 = ($345|0)<(1);
   $347 = $346 ? 1 : $345;
   HEAP32[$340>>2] = $347;
   $348 = (($caps) + 100|0);
   HEAP32[$348>>2] = $347;
   $349 = (($caps) + 104|0);
   HEAP32[$349>>2] = $347;
   $350 = (($caps) + 92|0);
   HEAP32[$350>>2] = 1;
   __THREW__ = 0;
   $351 = (invoke_ii(3461,(1152928|0))|0);
   $352 = __THREW__; __THREW__ = 0;
   $353 = $352&1;
   if ($353) {
    label = 87;
    break;
   }
   if ($351) {
    $354 = (($caps) + 125|0);
    HEAP8[$354>>0] = 1;
    label = 103;
   } else {
    __THREW__ = 0;
    $355 = (invoke_ii(3461,(1152968|0))|0);
    $356 = __THREW__; __THREW__ = 0;
    $357 = $356&1;
    if ($357) {
     label = 87;
     break;
    }
    $358 = (($caps) + 125|0);
    $359 = $355&1;
    HEAP8[$358>>0] = $359;
    if ($355) {
     label = 103;
    }
   }
   if ((label|0) == 103) {
    $360 = (1147664 + 212|0);
    $361 = HEAP32[$360>>2]|0;
    __THREW__ = 0;
    invoke_vii($361|0,34047,($350|0));
    $362 = __THREW__; __THREW__ = 0;
    $363 = $362&1;
    if ($363) {
     label = 87;
     break;
    }
   }
   $364 = (($caps) + 76|0);
   HEAP32[$364>>2] = 4;
   $365 = (($caps) + 68|0);
   HEAP32[$365>>2] = 30;
   $366 = (($caps) + 88|0);
   HEAP32[$366>>2] = 8;
   $367 = HEAP8[$caps>>0]|0;
   $368 = $367 & 1;
   $369 = ($368<<24>>24)==(0);
   if ($369) {
    $372 = $367&255;
    $373 = $372 >>> 1;
    $375 = $373;
   } else {
    $370 = (($caps) + 4|0);
    $371 = HEAP32[$370>>2]|0;
    $375 = $371;
   }
   $374 = ($375>>>0)<(7);
   L154: do {
    if ($374) {
     $398 = 0;
    } else {
     if ($369) {
      $378 = (($caps) + 1|0);
      $380 = $378;
     } else {
      $376 = (($caps) + 8|0);
      $377 = HEAP32[$376>>2]|0;
      $380 = $377;
     }
     $379 = (($380) + ($375)|0);
     $381 = $380;
     $382 = ($375|0)<(7);
     if ($382) {
      $398 = 0;
      break;
     }
     $$sum$i$i = (($375) + -6)|0;
     $383 = (($380) + ($$sum$i$i)|0);
     $384 = ($$sum$i$i|0)==(0);
     if ($384) {
      $398 = 0;
      break;
     } else {
      $$014$i$i$i$i = $380;
     }
     L161: while(1) {
      $385 = HEAP8[$$014$i$i$i$i>>0]|0;
      $386 = ($385<<24>>24)==(80);
      if ($386) {
       $__m1$0$i$i$i$i = $$014$i$i$i$i;$__m2$0$i$i$i$i = 1153008;
       while(1) {
        $388 = (($__m2$0$i$i$i$i) + 1|0);
        $389 = ($388|0)==(((1153008 + 7|0))|0);
        if ($389) {
         break L161;
        }
        $390 = (($__m1$0$i$i$i$i) + 1|0);
        $391 = HEAP8[$390>>0]|0;
        $392 = HEAP8[$388>>0]|0;
        $393 = ($391<<24>>24)==($392<<24>>24);
        if ($393) {
         $__m1$0$i$i$i$i = $390;$__m2$0$i$i$i$i = $388;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i = (($$014$i$i$i$i) + 1|0);
      $387 = ($$01$be$i$i$i$i|0)==($383|0);
      if ($387) {
       $398 = 0;
       break L154;
      } else {
       $$014$i$i$i$i = $$01$be$i$i$i$i;
      }
     }
     $394 = ($$014$i$i$i$i|0)==($379|0);
     if ($394) {
      $398 = 0;
      break;
     }
     $395 = $$014$i$i$i$i;
     $396 = (($395) - ($381))|0;
     $phitmp100 = ($396|0)!=(-1);
     $phitmp101 = $phitmp100&1;
     $398 = $phitmp101;
    }
   } while(0);
   $397 = (($caps) + 332|0);
   HEAP8[$397>>0] = $398;
   if ($369) {
    $401 = $367&255;
    $402 = $401 >>> 1;
    $404 = $402;
   } else {
    $399 = (($caps) + 4|0);
    $400 = HEAP32[$399>>2]|0;
    $404 = $400;
   }
   $403 = ($404>>>0)<(4);
   L175: do {
    if ($403) {
     $427 = 0;
    } else {
     if ($369) {
      $407 = (($caps) + 1|0);
      $409 = $407;
     } else {
      $405 = (($caps) + 8|0);
      $406 = HEAP32[$405>>2]|0;
      $409 = $406;
     }
     $408 = (($409) + ($404)|0);
     $410 = $409;
     $411 = ($404|0)<(4);
     if ($411) {
      $427 = 0;
      break;
     }
     $$sum$i$i42 = (($404) + -3)|0;
     $412 = (($409) + ($$sum$i$i42)|0);
     $413 = ($$sum$i$i42|0)==(0);
     if ($413) {
      $427 = 0;
      break;
     } else {
      $$014$i$i$i$i44 = $409;
     }
     L182: while(1) {
      $414 = HEAP8[$$014$i$i$i$i44>>0]|0;
      $415 = ($414<<24>>24)==(77);
      if ($415) {
       $__m1$0$i$i$i$i47 = $$014$i$i$i$i44;$__m2$0$i$i$i$i48 = 1153016;
       while(1) {
        $417 = (($__m2$0$i$i$i$i48) + 1|0);
        $418 = ($417|0)==(((1153016 + 4|0))|0);
        if ($418) {
         break L182;
        }
        $419 = (($__m1$0$i$i$i$i47) + 1|0);
        $420 = HEAP8[$419>>0]|0;
        $421 = HEAP8[$417>>0]|0;
        $422 = ($420<<24>>24)==($421<<24>>24);
        if ($422) {
         $__m1$0$i$i$i$i47 = $419;$__m2$0$i$i$i$i48 = $417;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i45 = (($$014$i$i$i$i44) + 1|0);
      $416 = ($$01$be$i$i$i$i45|0)==($412|0);
      if ($416) {
       $427 = 0;
       break L175;
      } else {
       $$014$i$i$i$i44 = $$01$be$i$i$i$i45;
      }
     }
     $423 = ($$014$i$i$i$i44|0)==($408|0);
     if ($423) {
      $427 = 0;
      break;
     }
     $424 = $$014$i$i$i$i44;
     $425 = (($424) - ($410))|0;
     $phitmp102 = ($425|0)!=(-1);
     $phitmp103 = $phitmp102&1;
     $427 = $phitmp103;
    }
   } while(0);
   $426 = (($caps) + 333|0);
   HEAP8[$426>>0] = $427;
   if ($369) {
    $430 = $367&255;
    $431 = $430 >>> 1;
    $433 = $431;
   } else {
    $428 = (($caps) + 4|0);
    $429 = HEAP32[$428>>2]|0;
    $433 = $429;
   }
   $432 = ($433>>>0)<(6);
   L196: do {
    if ($432) {
     $456 = 0;
    } else {
     if ($369) {
      $436 = (($caps) + 1|0);
      $438 = $436;
     } else {
      $434 = (($caps) + 8|0);
      $435 = HEAP32[$434>>2]|0;
      $438 = $435;
     }
     $437 = (($438) + ($433)|0);
     $439 = $438;
     $440 = ($433|0)<(6);
     if ($440) {
      $456 = 0;
      break;
     }
     $$sum$i$i54 = (($433) + -5)|0;
     $441 = (($438) + ($$sum$i$i54)|0);
     $442 = ($$sum$i$i54|0)==(0);
     if ($442) {
      $456 = 0;
      break;
     } else {
      $$014$i$i$i$i56 = $438;
     }
     L203: while(1) {
      $443 = HEAP8[$$014$i$i$i$i56>>0]|0;
      $444 = ($443<<24>>24)==(65);
      if ($444) {
       $__m1$0$i$i$i$i59 = $$014$i$i$i$i56;$__m2$0$i$i$i$i60 = 1153024;
       while(1) {
        $446 = (($__m2$0$i$i$i$i60) + 1|0);
        $447 = ($446|0)==(((1153024 + 6|0))|0);
        if ($447) {
         break L203;
        }
        $448 = (($__m1$0$i$i$i$i59) + 1|0);
        $449 = HEAP8[$448>>0]|0;
        $450 = HEAP8[$446>>0]|0;
        $451 = ($449<<24>>24)==($450<<24>>24);
        if ($451) {
         $__m1$0$i$i$i$i59 = $448;$__m2$0$i$i$i$i60 = $446;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i57 = (($$014$i$i$i$i56) + 1|0);
      $445 = ($$01$be$i$i$i$i57|0)==($441|0);
      if ($445) {
       $456 = 0;
       break L196;
      } else {
       $$014$i$i$i$i56 = $$01$be$i$i$i$i57;
      }
     }
     $452 = ($$014$i$i$i$i56|0)==($437|0);
     if ($452) {
      $456 = 0;
      break;
     }
     $453 = $$014$i$i$i$i56;
     $454 = (($453) - ($439))|0;
     $phitmp104 = ($454|0)!=(-1);
     $phitmp105 = $phitmp104&1;
     $456 = $phitmp105;
    }
   } while(0);
   $455 = (($caps) + 334|0);
   HEAP8[$455>>0] = $456;
   if ($369) {
    $459 = $367&255;
    $460 = $459 >>> 1;
    $462 = $460;
   } else {
    $457 = (($caps) + 4|0);
    $458 = HEAP32[$457>>2]|0;
    $462 = $458;
   }
   $461 = ($462>>>0)<(5);
   L217: do {
    if ($461) {
     $$0$i$i75 = 0;
    } else {
     if ($369) {
      $465 = (($caps) + 1|0);
      $467 = $465;
     } else {
      $463 = (($caps) + 8|0);
      $464 = HEAP32[$463>>2]|0;
      $467 = $464;
     }
     $466 = (($467) + ($462)|0);
     $468 = $467;
     $469 = ($462|0)<(5);
     if ($469) {
      $$0$i$i75 = 0;
      break;
     }
     $$sum$i$i66 = (($462) + -4)|0;
     $470 = (($467) + ($$sum$i$i66)|0);
     $471 = ($$sum$i$i66|0)==(0);
     if ($471) {
      $$0$i$i75 = 0;
      break;
     } else {
      $$014$i$i$i$i68 = $467;
     }
     L224: while(1) {
      $472 = HEAP8[$$014$i$i$i$i68>>0]|0;
      $473 = ($472<<24>>24)==(84);
      if ($473) {
       $__m1$0$i$i$i$i71 = $$014$i$i$i$i68;$__m2$0$i$i$i$i72 = 1153032;
       while(1) {
        $475 = (($__m2$0$i$i$i$i72) + 1|0);
        $476 = ($475|0)==(((1153032 + 5|0))|0);
        if ($476) {
         break L224;
        }
        $477 = (($__m1$0$i$i$i$i71) + 1|0);
        $478 = HEAP8[$477>>0]|0;
        $479 = HEAP8[$475>>0]|0;
        $480 = ($478<<24>>24)==($479<<24>>24);
        if ($480) {
         $__m1$0$i$i$i$i71 = $477;$__m2$0$i$i$i$i72 = $475;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i69 = (($$014$i$i$i$i68) + 1|0);
      $474 = ($$01$be$i$i$i$i69|0)==($470|0);
      if ($474) {
       $$0$i$i75 = 0;
       break L217;
      } else {
       $$014$i$i$i$i68 = $$01$be$i$i$i$i69;
      }
     }
     $481 = ($$014$i$i$i$i68|0)==($466|0);
     if ($481) {
      $$0$i$i75 = 0;
      break;
     }
     $482 = $$014$i$i$i$i68;
     $483 = (($482) - ($468))|0;
     $phitmp106 = ($483|0)!=(-1);
     $phitmp107 = $phitmp106&1;
     $$0$i$i75 = $phitmp107;
    }
   } while(0);
   $484 = (($caps) + 335|0);
   HEAP8[$484>>0] = $$0$i$i75;
   if ($369) {
    $487 = $367&255;
    $488 = $487 >>> 1;
    $490 = $488;
   } else {
    $485 = (($caps) + 4|0);
    $486 = HEAP32[$485>>2]|0;
    $490 = $486;
   }
   $489 = ($490>>>0)<(5);
   L238: do {
    if ($489) {
     $$0$i$i87 = 0;
    } else {
     if ($369) {
      $493 = (($caps) + 1|0);
      $495 = $493;
     } else {
      $491 = (($caps) + 8|0);
      $492 = HEAP32[$491>>2]|0;
      $495 = $492;
     }
     $494 = (($495) + ($490)|0);
     $496 = $495;
     $497 = ($490|0)<(5);
     if ($497) {
      $$0$i$i87 = 0;
      break;
     }
     $$sum$i$i78 = (($490) + -4)|0;
     $498 = (($495) + ($$sum$i$i78)|0);
     $499 = ($$sum$i$i78|0)==(0);
     if ($499) {
      $$0$i$i87 = 0;
      break;
     } else {
      $$014$i$i$i$i80 = $495;
     }
     L245: while(1) {
      $500 = HEAP8[$$014$i$i$i$i80>>0]|0;
      $501 = ($500<<24>>24)==(73);
      if ($501) {
       $__m1$0$i$i$i$i83 = $$014$i$i$i$i80;$__m2$0$i$i$i$i84 = 1153040;
       while(1) {
        $503 = (($__m2$0$i$i$i$i84) + 1|0);
        $504 = ($503|0)==(((1153040 + 5|0))|0);
        if ($504) {
         break L245;
        }
        $505 = (($__m1$0$i$i$i$i83) + 1|0);
        $506 = HEAP8[$505>>0]|0;
        $507 = HEAP8[$503>>0]|0;
        $508 = ($506<<24>>24)==($507<<24>>24);
        if ($508) {
         $__m1$0$i$i$i$i83 = $505;$__m2$0$i$i$i$i84 = $503;
        } else {
         break;
        }
       }
      }
      $$01$be$i$i$i$i81 = (($$014$i$i$i$i80) + 1|0);
      $502 = ($$01$be$i$i$i$i81|0)==($498|0);
      if ($502) {
       $$0$i$i87 = 0;
       break L238;
      } else {
       $$014$i$i$i$i80 = $$01$be$i$i$i$i81;
      }
     }
     $509 = ($$014$i$i$i$i80|0)==($494|0);
     if ($509) {
      $$0$i$i87 = 0;
      break;
     }
     $510 = $$014$i$i$i$i80;
     $511 = (($510) - ($496))|0;
     $phitmp108 = ($511|0)!=(-1);
     $phitmp109 = $phitmp108&1;
     $$0$i$i87 = $phitmp109;
    }
   } while(0);
   $512 = (($caps) + 336|0);
   HEAP8[$512>>0] = $$0$i$i87;
   $513 = ($398<<24>>24)==(0);
   $514 = $398 | $456;
   $515 = ($514<<24>>24)==(0);
   $516 = $515 ? $427 : 1;
   $517 = (($caps) + 251|0);
   HEAP8[$517>>0] = $516;
   $518 = HEAP8[((640792 + 334|0))>>0]|0;
   $519 = (($caps) + 338|0);
   HEAP8[$519>>0] = $518;
   $520 = HEAP16[((640792 + 332|0))>>1]|0;
   $521 = $520&255;
   $522 = ($521<<24>>24)==(0);
   $523 = ($520&65535) >>> 8;
   $524 = $523&255;
   $$ = $522 ? $524 : 1;
   $525 = (($caps) + 339|0);
   HEAP8[$525>>0] = $$;
   $$122 = $513 ? $456 : 1;
   $526 = (($caps) + 337|0);
   HEAP8[$526>>0] = $$122;
   __THREW__ = 0;
   $527 = (invoke_ii(3461,(1153048|0))|0);
   $528 = __THREW__; __THREW__ = 0;
   $529 = $528&1;
   if ($529) {
    label = 87;
    break;
   }
   do {
    if ($527) {
     $530 = HEAP32[1147616>>2]|0;
     $531 = ($530|0)==(0|0);
     if ($531) {
      $536 = 0;
      break;
     }
     $532 = (1147616 + 4|0);
     $533 = HEAP32[$532>>2]|0;
     $534 = ($533|0)!=(0|0);
     $phitmp = $534&1;
     $536 = $phitmp;
    } else {
     $536 = 0;
    }
   } while(0);
   $535 = (($caps) + 346|0);
   HEAP8[$535>>0] = $536;
   __THREW__ = 0;
   $537 = (invoke_ii(3461,(1153072|0))|0);
   $538 = __THREW__; __THREW__ = 0;
   $539 = $538&1;
   if ($539) {
    label = 87;
    break;
   }
   do {
    if ($537) {
     $540 = (1147616 + 8|0);
     $541 = HEAP32[$540>>2]|0;
     $542 = ($541|0)==(0|0);
     if ($542) {
      $547 = 0;
      break;
     }
     $543 = (1147616 + 12|0);
     $544 = HEAP32[$543>>2]|0;
     $545 = ($544|0)!=(0|0);
     $phitmp3 = $545&1;
     $547 = $phitmp3;
    } else {
     $547 = 0;
    }
   } while(0);
   $546 = (($caps) + 347|0);
   HEAP8[$546>>0] = $547;
   __THREW__ = 0;
   $548 = (invoke_ii(3461,(1153096|0))|0);
   $549 = __THREW__; __THREW__ = 0;
   $550 = $549&1;
   if ($550) {
    label = 87;
    break;
   }
   if ($548) {
    $551 = (1147616 + 24|0);
    $552 = HEAP32[$551>>2]|0;
    $553 = ($552|0)!=(0|0);
    $phitmp4 = $553&1;
    $555 = $phitmp4;
   } else {
    $555 = 0;
   }
   $554 = (($caps) + 365|0);
   HEAP8[$554>>0] = $555;
   __THREW__ = 0;
   $556 = (invoke_ii(3461,(1153120|0))|0);
   $557 = __THREW__; __THREW__ = 0;
   $558 = $557&1;
   if ($558) {
    label = 87;
    break;
   }
   do {
    if ($556) {
     $559 = (1147616 + 28|0);
     $560 = HEAP32[$559>>2]|0;
     $561 = ($560|0)==(0|0);
     if ($561) {
      $566 = 0;
      break;
     }
     $562 = (1147616 + 32|0);
     $563 = HEAP32[$562>>2]|0;
     $564 = ($563|0)!=(0|0);
     $phitmp5 = $564&1;
     $566 = $phitmp5;
    } else {
     $566 = 0;
    }
   } while(0);
   $565 = (($caps) + 366|0);
   HEAP8[$565>>0] = $566;
   __THREW__ = 0;
   $567 = (invoke_ii(3461,(1153136|0))|0);
   $568 = __THREW__; __THREW__ = 0;
   $569 = $568&1;
   if ($569) {
    label = 87;
    break;
   }
   $570 = (($caps) + 367|0);
   $571 = $567&1;
   HEAP8[$570>>0] = $571;
   $572 = (($caps) + 372|0);
   HEAP8[$572>>0] = 0;
   __THREW__ = 0;
   (invoke_i(131)|0);
   $573 = __THREW__; __THREW__ = 0;
   $574 = $573&1;
   if ($574) {
    label = 87;
    break;
   }
   $575 = (($caps) + 80|0);
   HEAPF32[$575>>2] = Math_fround(512.0);
   $576 = (1147664 + 232|0);
   $577 = HEAP32[$576>>2]|0;
   __THREW__ = 0;
   $578 = (invoke_ii($577|0,7939)|0);
   $579 = __THREW__; __THREW__ = 0;
   $580 = $579&1;
   if ($580) {
    label = 87;
    break;
   }
   $581 = HEAP8[$caps>>0]|0;
   $582 = $581 & 1;
   $583 = ($582<<24>>24)==(0);
   if ($583) {
    $586 = (($caps) + 1|0);
    $587 = $586;
   } else {
    $584 = (($caps) + 8|0);
    $585 = HEAP32[$584>>2]|0;
    $587 = $585;
   }
   __THREW__ = 0;
   HEAP32[$$byval_copy21>>2] = $587;
   invoke_vii(2587,(1153160|0),($$byval_copy21|0));
   $588 = __THREW__; __THREW__ = 0;
   $589 = $588&1;
   if ($589) {
    label = 87;
    break;
   }
   $590 = HEAP8[$62>>0]|0;
   $591 = $590 & 1;
   $592 = ($591<<24>>24)==(0);
   if ($592) {
    $595 = (($62) + 1|0);
    $596 = $595;
   } else {
    $593 = (($caps) + 20|0);
    $594 = HEAP32[$593>>2]|0;
    $596 = $594;
   }
   __THREW__ = 0;
   HEAP32[$$byval_copy21>>2] = $596;
   invoke_vii(2587,(1153176|0),($$byval_copy21|0));
   $597 = __THREW__; __THREW__ = 0;
   $598 = $597&1;
   if ($598) {
    label = 87;
    break;
   }
   $599 = HEAP8[$77>>0]|0;
   $600 = $599 & 1;
   $601 = ($600<<24>>24)==(0);
   if ($601) {
    $604 = (($77) + 1|0);
    $605 = $604;
   } else {
    $602 = (($caps) + 32|0);
    $603 = HEAP32[$602>>2]|0;
    $605 = $603;
   }
   __THREW__ = 0;
   HEAP32[$$byval_copy21>>2] = $605;
   invoke_vii(2587,(1153192|0),($$byval_copy21|0));
   $606 = __THREW__; __THREW__ = 0;
   $607 = $606&1;
   if ($607) {
    label = 87;
    break;
   }
   $608 = HEAP32[$119>>2]|0;
   __THREW__ = 0;
   HEAP32[$$byval_copy21>>2] = $608;
   invoke_vii(2587,(1153208|0),($$byval_copy21|0));
   $609 = __THREW__; __THREW__ = 0;
   $610 = $609&1;
   if ($610) {
    label = 87;
    break;
   }
   $611 = ($578|0)==(0|0);
   if ($611) {
    __THREW__ = 0;
    invoke_vii(2587,(1153224|0),($$byval_copy21|0));
    $614 = __THREW__; __THREW__ = 0;
    $615 = $614&1;
    if ($615) {
     label = 87;
     break;
    }
   } else {
    __THREW__ = 0;
    invoke_vii(3490,($578|0),-1);
    $612 = __THREW__; __THREW__ = 0;
    $613 = $612&1;
    if ($613) {
     label = 87;
     break;
    }
   }
   HEAP32[1152880>>2] = $118;
   $616 = HEAP32[$parts>>2]|0;
   $617 = ($616|0)==(0|0);
   if ($617) {
    STACKTOP = sp;return;
   }
   $618 = HEAP32[$120>>2]|0;
   $619 = ($618|0)==($616|0);
   if ($619) {
    $629 = $616;
   } else {
    $621 = $618;
    while(1) {
     $620 = (($621) + -12|0);
     HEAP32[$120>>2] = $620;
     $622 = HEAP8[$620>>0]|0;
     $623 = $622 & 1;
     $624 = ($623<<24>>24)==(0);
     if ($624) {
      $626 = $620;
     } else {
      $627 = (($621) + -4|0);
      $628 = HEAP32[$627>>2]|0;
      __ZdlPv($628);
      $$pre$i$i$i$i$i = HEAP32[$120>>2]|0;
      $626 = $$pre$i$i$i$i$i;
     }
     $625 = ($626|0)==($616|0);
     if ($625) {
      break;
     } else {
      $621 = $626;
     }
    }
    $$pre$i$i$i = HEAP32[$parts>>2]|0;
    $629 = $$pre$i$i$i;
   }
   __ZdlPv($629);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 87) {
  $297 = ___cxa_find_matching_catch()|0;
  $298 = tempRet0;
  $$0 = $297;$$01 = $298;
 }
 $630 = HEAP32[$parts>>2]|0;
 $631 = ($630|0)==(0|0);
 if ($631) {
  $$1 = $$0;$$12 = $$01;
  ___resumeException($$1|0);
  // unreachable;
 }
 $632 = HEAP32[$120>>2]|0;
 $633 = ($632|0)==($630|0);
 if ($633) {
  $643 = $630;
 } else {
  $635 = $632;
  while(1) {
   $634 = (($635) + -12|0);
   HEAP32[$120>>2] = $634;
   $636 = HEAP8[$634>>0]|0;
   $637 = $636 & 1;
   $638 = ($637<<24>>24)==(0);
   if ($638) {
    $640 = $634;
   } else {
    $641 = (($635) + -4|0);
    $642 = HEAP32[$641>>2]|0;
    __ZdlPv($642);
    $$pre$i$i$i$i$i94 = HEAP32[$120>>2]|0;
    $640 = $$pre$i$i$i$i$i94;
   }
   $639 = ($640|0)==($630|0);
   if ($639) {
    break;
   } else {
    $635 = $640;
   }
  }
  $$pre$i$i$i95 = HEAP32[$parts>>2]|0;
  $643 = $$pre$i$i$i95;
 }
 __ZdlPv($643);
 $$1 = $$0;$$12 = $$01;
 ___resumeException($$1|0);
 // unreachable;
}
function __ZN4gles8internal24InitTextureFormatSupportE17GfxDeviceRendererP12GraphicsCaps($renderer,$caps) {
 $renderer = $renderer|0;
 $caps = $caps|0;
 var $$off0$ = 0, $$off01 = 0, $$off042 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$demorgan = 0, $hasNativeDepth$0$off0$ph = 0, $phitmp = 0, $phitmp10 = 0, $phitmp11 = 0, $phitmp14 = 0, $phitmp15 = 0, $phitmp16 = 0, $phitmp18 = 0, $phitmp19 = 0, $phitmp2 = 0, $phitmp20 = 0, $phitmp21 = 0;
 var $phitmp21$c = 0, $phitmp22 = 0, $phitmp23 = 0, $phitmp24 = 0, $phitmp3 = 0, $phitmp4 = 0, $phitmp5 = 0, $phitmp6 = 0, $phitmp7 = 0, $phitmp74 = 0, $phitmp847 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($renderer|0)==(8);
 if ($0) {
  $1 = (__Z14QueryExtensionPKc(1153264)|0);
  $2 = (__Z14QueryExtensionPKc(1153288)|0);
  $3 = (__Z14QueryExtensionPKc(1153312)|0);
  $$off01 = $3;$$off042 = $2;$48 = $1;
 } else {
  $$off01 = 1;$$off042 = 1;$48 = 1;
 }
 $4 = (__Z14QueryExtensionPKc(1153344)|0);
 if ($4) {
  $32 = 1;
 } else {
  $5 = (__Z14QueryExtensionPKc(1153376)|0);
  if ($5) {
   $32 = 1;
  } else {
   $6 = (__Z14QueryExtensionPKc(1153408)|0);
   $32 = $6;
  }
 }
 $7 = (__Z14QueryExtensionPKc(1153448)|0);
 if ($7) {
  $35 = 1;
 } else {
  $8 = (__Z14QueryExtensionPKc(1153488)|0);
  $phitmp4 = $8&1;
  $35 = $phitmp4;
 }
 $9 = (__Z14QueryExtensionPKc(1153520)|0);
 if ($9) {
  $36 = 1;
 } else {
  $10 = (__Z14QueryExtensionPKc(1153552)|0);
  if ($10) {
   $36 = 1;
  } else {
   $11 = (__Z14QueryExtensionPKc(1153592)|0);
   $phitmp5 = $11&1;
   $36 = $phitmp5;
  }
 }
 $12 = (__Z14QueryExtensionPKc(1153624)|0);
 $13 = ($renderer|0)==(11);
 if ($13) {
  $42 = 1;
 } else {
  $14 = (__Z14QueryExtensionPKc(1153664)|0);
  if ($14) {
   $42 = 1;
  } else {
   $15 = (__Z14QueryExtensionPKc(1153704)|0);
   $phitmp6 = $15&1;
   $42 = $phitmp6;
  }
 }
 if ($32) {
  $22 = (($caps) + 151|0);
  HEAP8[$22>>0] = 1;
  $23 = (($caps) + 152|0);
  HEAP8[$23>>0] = 1;
  $29 = 1;
 } else {
  $16 = (__Z14QueryExtensionPKc(1153736)|0);
  if ($16) {
   $17 = (($caps) + 151|0);
   HEAP8[$17>>0] = 1;
  } else {
   $18 = (__Z14QueryExtensionPKc(1153768)|0);
   $phitmp = $18&1;
   $19 = (($caps) + 151|0);
   HEAP8[$19>>0] = $phitmp;
  }
  $20 = (__Z14QueryExtensionPKc(1153808)|0);
  if ($20) {
   $25 = 1;
  } else {
   $21 = (__Z14QueryExtensionPKc(1153848)|0);
   $phitmp2 = $21&1;
   $25 = $phitmp2;
  }
  $24 = (($caps) + 152|0);
  HEAP8[$24>>0] = $25;
  $26 = (__Z14QueryExtensionPKc(1153888)|0);
  if ($26) {
   $29 = 1;
  } else {
   $27 = (__Z14QueryExtensionPKc(1153928)|0);
   $phitmp3 = $27&1;
   $29 = $phitmp3;
  }
 }
 $28 = (($caps) + 153|0);
 HEAP8[$28>>0] = $29;
 $30 = (($caps) + 137|0);
 $31 = $32&1;
 HEAP8[$30>>0] = $31;
 $33 = (($caps) + 171|0);
 $34 = (($caps) + 176|0);
 _memset(($33|0),($35|0),4)|0;
 HEAP8[$34>>0] = $36;
 $37 = (($caps) + 177|0);
 HEAP8[$37>>0] = $36;
 $38 = $12&1;
 $scevgep = (($caps) + 189|0);
 _memset(($scevgep|0),($38|0),12)|0;
 $39 = $13&1;
 $40 = (($caps) + 182|0);
 $41 = (($caps) + 175|0);
 _memset(($40|0),($39|0),7)|0;
 HEAP8[$41>>0] = $42;
 $43 = (__Z14QueryExtensionPKc(1153968)|0);
 if ($43) {
  $47 = 1;
 } else {
  $44 = (__Z14QueryExtensionPKc(1154008)|0);
  if ($44) {
   $47 = 1;
  } else {
   $45 = (__Z14QueryExtensionPKc(1154040)|0);
   $phitmp7 = $45&1;
   $47 = $phitmp7;
  }
 }
 $46 = (($caps) + 155|0);
 HEAP8[$46>>0] = $47;
 $brmerge$demorgan = $48 & $$off01;
 if ($brmerge$demorgan) {
  $50 = (($caps) + 336|0);
  $51 = HEAP8[$50>>0]|0;
  $phitmp847 = $51 ^ 1;
  $52 = (($caps) + 156|0);
  HEAP8[$52>>0] = $phitmp847;
  $54 = $phitmp847;
 } else {
  $49 = (($caps) + 156|0);
  HEAP8[$49>>0] = 0;
  $54 = 0;
 }
 $53 = (($caps) + 157|0);
 HEAP8[$53>>0] = $54;
 if ($$off01) {
  $55 = (($caps) + 336|0);
  $56 = HEAP8[$55>>0]|0;
  $phitmp10 = $56 ^ 1;
  $58 = $phitmp10;
 } else {
  $58 = 0;
 }
 $57 = (($caps) + 158|0);
 HEAP8[$57>>0] = $58;
 $$off0$ = $48 & $$off042;
 $59 = (($caps) + 159|0);
 $60 = $$off0$&1;
 HEAP8[$59>>0] = $60;
 $61 = (($caps) + 160|0);
 HEAP8[$61>>0] = $60;
 $62 = (($caps) + 161|0);
 $63 = $$off042&1;
 HEAP8[$62>>0] = $63;
 $64 = (($caps) + 150|0);
 HEAP8[$64>>0] = 0;
 $65 = (($caps) + 146|0);
 HEAP8[$65>>0] = 0;
 $66 = (($caps) + 147|0);
 HEAP8[$66>>0] = 0;
 $67 = (($caps) + 149|0);
 HEAP8[$67>>0] = 0;
 $68 = (__Z14QueryExtensionPKc(1154072)|0);
 $69 = (($caps) + 341|0);
 $70 = $68&1;
 HEAP8[$69>>0] = $70;
 $71 = (__Z14QueryExtensionPKc(1154096)|0);
 $72 = (($caps) + 342|0);
 $73 = $71&1;
 HEAP8[$72>>0] = $73;
 if ($0) {
  $74 = (__Z14QueryExtensionPKc(1154120)|0);
  if ($74) {
   $hasNativeDepth$0$off0$ph = 1;
  } else {
   $75 = (__Z14QueryExtensionPKc(1154144)|0);
   if ($75) {
    $hasNativeDepth$0$off0$ph = 1;
   } else {
    $76 = (__Z14QueryExtensionPKc(1154168)|0);
    if ($76) {
     $hasNativeDepth$0$off0$ph = 1;
    } else {
     $77 = (__Z14QueryExtensionPKc(1154192)|0);
     $phitmp74 = $77&1;
     $hasNativeDepth$0$off0$ph = $phitmp74;
    }
   }
  }
  $80 = (($caps) + 247|0);
  HEAP8[$80>>0] = $hasNativeDepth$0$off0$ph;
  $81 = (__Z14QueryExtensionPKc(1154216)|0);
  $phitmp11 = $81&1;
  $82 = (($caps) + 249|0);
  HEAP8[$82>>0] = $phitmp11;
  if ($81) {
   $85 = 1;$88 = $80;$91 = $82;
  } else {
   $83 = HEAP8[$80>>0]|0;
   $85 = $83;$88 = $80;$91 = $82;
  }
 } else {
  $78 = (($caps) + 247|0);
  HEAP8[$78>>0] = 1;
  $79 = (($caps) + 249|0);
  HEAP8[$79>>0] = 1;
  $85 = 1;$88 = $78;$91 = $79;
 }
 $84 = (($caps) + 245|0);
 HEAP8[$84>>0] = $85;
 $86 = (($caps) + 201|0);
 HEAP8[$86>>0] = 1;
 $87 = HEAP8[$88>>0]|0;
 $89 = (($caps) + 202|0);
 HEAP8[$89>>0] = $87;
 $90 = HEAP8[$91>>0]|0;
 $92 = (($caps) + 204|0);
 HEAP8[$92>>0] = $90;
 $93 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(4)|0);
 $94 = (($caps) + 205|0);
 $95 = $93&1;
 HEAP8[$94>>0] = $95;
 $96 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(5)|0);
 $97 = (($caps) + 206|0);
 $98 = $96&1;
 HEAP8[$97>>0] = $98;
 $99 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(6)|0);
 $100 = (($caps) + 207|0);
 $101 = $99&1;
 HEAP8[$100>>0] = $101;
 if ($$off042) {
  (__Z14QueryExtensionPKc(1154240)|0);
  if ($48) {
   $104 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(14)|0);
   $phitmp14 = $104&1;
   $105 = (($caps) + 215|0);
   HEAP8[$105>>0] = $phitmp14;
   $106 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(12)|0);
   $phitmp15 = $106&1;
   $107 = (($caps) + 213|0);
   HEAP8[$107>>0] = $phitmp15;
  } else {
   $102 = (($caps) + 215|0);
   HEAP8[$102>>0] = 0;
   $103 = (($caps) + 213|0);
   HEAP8[$103>>0] = 0;
  }
  $110 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(11)|0);
  $phitmp16 = $110&1;
  $112 = $phitmp16;
 } else {
  $108 = (($caps) + 215|0);
  HEAP8[$108>>0] = 0;
  $109 = (($caps) + 213|0);
  HEAP8[$109>>0] = 0;
  $112 = 0;
 }
 $111 = (($caps) + 212|0);
 HEAP8[$111>>0] = $112;
 if ($$off01) {
  (__Z14QueryExtensionPKc(1154272)|0);
  if ($48) {
   $115 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(15)|0);
   $phitmp18 = $115&1;
   $116 = (($caps) + 216|0);
   HEAP8[$116>>0] = $phitmp18;
   $117 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(13)|0);
   $phitmp19 = $117&1;
   $118 = (($caps) + 214|0);
   HEAP8[$118>>0] = $phitmp19;
  } else {
   $113 = (($caps) + 216|0);
   HEAP8[$113>>0] = 0;
   $114 = (($caps) + 214|0);
   HEAP8[$114>>0] = 0;
  }
  $121 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(2)|0);
  $phitmp20 = $121&1;
  $123 = $phitmp20;
 } else {
  $119 = (($caps) + 216|0);
  HEAP8[$119>>0] = 0;
  $120 = (($caps) + 214|0);
  HEAP8[$120>>0] = 0;
  $123 = 0;
 }
 $122 = (($caps) + 203|0);
 HEAP8[$122>>0] = $123;
 if ($0) {
  $124 = (__Z14QueryExtensionPKc(1154304)|0);
  if (!($124)) {
   $129 = (($caps) + 209|0);
   HEAP8[$129>>0] = 0;
   $130 = (($caps) + 218|0);
   HEAP8[$130>>0] = 0;
   $131 = (($caps) + 219|0);
   HEAP8[$131>>0] = 0;
   $140 = 0;
   $139 = (($caps) + 220|0);
   HEAP8[$139>>0] = $140;
   $141 = (($caps) + 217|0);
   $142 = $48&1;
   HEAP8[$141>>0] = $142;
   $143 = (($caps) + 211|0);
   HEAP8[$143>>0] = 0;
   STACKTOP = sp;return;
  }
  $125 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(8)|0);
  $phitmp21 = $125&1;
  $126 = (($caps) + 209|0);
  HEAP8[$126>>0] = $phitmp21;
  if ($0) {
   $127 = (($caps) + 218|0);
   HEAP8[$127>>0] = 0;
   $128 = (($caps) + 219|0);
   HEAP8[$128>>0] = 0;
   $140 = 0;
   $139 = (($caps) + 220|0);
   HEAP8[$139>>0] = $140;
   $141 = (($caps) + 217|0);
   $142 = $48&1;
   HEAP8[$141>>0] = $142;
   $143 = (($caps) + 211|0);
   HEAP8[$143>>0] = 0;
   STACKTOP = sp;return;
  }
 } else {
  $132 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(8)|0);
  $phitmp21$c = $132&1;
  $133 = (($caps) + 209|0);
  HEAP8[$133>>0] = $phitmp21$c;
 }
 $134 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(17)|0);
 $phitmp22 = $134&1;
 $135 = (($caps) + 218|0);
 HEAP8[$135>>0] = $phitmp22;
 $136 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(18)|0);
 $phitmp23 = $136&1;
 $137 = (($caps) + 219|0);
 HEAP8[$137>>0] = $phitmp23;
 $138 = (__ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat(19)|0);
 $phitmp24 = $138&1;
 $140 = $phitmp24;
 $139 = (($caps) + 220|0);
 HEAP8[$139>>0] = $140;
 $141 = (($caps) + 217|0);
 $142 = $48&1;
 HEAP8[$141>>0] = $142;
 $143 = (($caps) + 211|0);
 HEAP8[$143>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN4gles8internalL23CheckRTFormatRenderableE19RenderTextureFormat($format) {
 $format = $format|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $color = 0;
 var $fbo = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fbo = sp + 4|0;
 $color = sp;
 HEAP32[$fbo>>2] = 0;
 $0 = (1147664 + 180|0);
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vii[$1 & 4095](1,$fbo);
 $2 = (1147664 + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$fbo>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095](36160,$4);
 $5 = (__ZN4gles18FullInternalFormatE19RenderTextureFormat($format)|0);
 $6 = (__ZN4gles24DataTypeFromFullInternalEj($5)|0);
 $7 = (__ZN4gles29TextureFormatFromFullInternalEj($5)|0);
 $8 = (__ZN4gles29BaseInternalFormatForTexImageEj($5)|0);
 HEAP32[$color>>2] = 0;
 $9 = (1147664 + 188|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$10 & 4095](1,$color);
 $11 = (1147664 + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$color>>2]|0;
 FUNCTION_TABLE_vii[$12 & 4095](3553,$13);
 $14 = (1147664 + 308|0);
 $15 = HEAP32[$14>>2]|0;
 FUNCTION_TABLE_viii[$15 & 4095](3553,10240,9728);
 $16 = (1147664 + 308|0);
 $17 = HEAP32[$16>>2]|0;
 FUNCTION_TABLE_viii[$17 & 4095](3553,10241,9728);
 $18 = (1147664 + 308|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_viii[$19 & 4095](3553,10242,33071);
 $20 = (1147664 + 308|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_viii[$21 & 4095](3553,10243,33071);
 $22 = (1147664 + 304|0);
 $23 = HEAP32[$22>>2]|0;
 FUNCTION_TABLE_viiiiiiiii[$23 & 31](3553,0,$8,16,16,0,$7,$6,0);
 $24 = (1147664 + 164|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$color>>2]|0;
 FUNCTION_TABLE_viiiii[$25 & 255](36160,36064,3553,$26,0);
 $27 = (1147664 + 44|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_ii[$28 & 4095](36160)|0);
 $30 = (1147664 + 24|0);
 $31 = HEAP32[$30>>2]|0;
 FUNCTION_TABLE_vii[$31 & 4095](3553,0);
 $32 = (1147664 + 16|0);
 $33 = HEAP32[$32>>2]|0;
 FUNCTION_TABLE_vii[$33 & 4095](36160,0);
 $34 = (1147664 + 116|0);
 $35 = HEAP32[$34>>2]|0;
 FUNCTION_TABLE_vii[$35 & 4095](1,$color);
 $36 = (1147664 + 100|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_vii[$37 & 4095](1,$fbo);
 $38 = ($29|0)==(36053);
 STACKTOP = sp;return ($38|0);
}
function __ZN4gles28CreateColorRenderSurfaceFullE19RenderTextureFormat9TextureIDj16TextureDimensionjRK17RenderSurfaceDesc($format,$tex,$rb,$dim,$flags,$desc) {
 $format = $format|0;
 $tex = $tex|0;
 $rb = $rb|0;
 $dim = $dim|0;
 $flags = $flags|0;
 $desc = $desc|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$tex>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = (__ZN4gles18FullInternalFormatE19RenderTextureFormat($format)|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (__ZN4gles25CreateUpdateRenderSurfaceEP17RenderSurfaceGLESb16TextureDimension9TextureIDjjjRK17RenderSurfaceDesc(0,1,$dim,$$byval_copy,$rb,$2,$flags,$desc)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = (($3) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 64;
 $8 = ($7|0)==(0);
 if (!($8)) {
  STACKTOP = sp;return ($3|0);
 }
 $9 = $6 & 4;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = HEAP32[1152880>>2]|0;
  $12 = (($11) + 40|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($3) + 28|0);
  HEAP32[$14>>2] = $13;
 }
 __ZN4gles8internal21InitRenderSurfaceGLESER17RenderSurfaceGLES($3);
 STACKTOP = sp;return ($3|0);
}
function __ZN4gles25CreateUpdateRenderSurfaceEP17RenderSurfaceGLESb16TextureDimension9TextureIDjjjRK17RenderSurfaceDesc($rs,$isColor,$dim,$tex,$rb,$glesFormat,$flags,$desc) {
 $rs = $rs|0;
 $isColor = $isColor|0;
 $dim = $dim|0;
 $tex = $tex|0;
 $rb = $rb|0;
 $glesFormat = $glesFormat|0;
 $flags = $flags|0;
 $desc = $desc|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = $flags & 64;
 $2 = ($1|0)==(0);
 $3 = ($rs|0)!=(0|0);
 if ($2) {
  if ($3) {
   $36 = $rs;
  } else {
   $35 = (__Znwj(36)|0);
   dest=$35+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $36 = $35;
  }
  ;HEAP32[$36+0>>2]=0|0;HEAP32[$36+4>>2]=0|0;HEAP32[$36+8>>2]=0|0;HEAP32[$36+12>>2]=0|0;HEAP32[$36+16>>2]=0|0;HEAP32[$36+20>>2]=0|0;
  $37 = (($36) + 12|0);
  HEAP32[$37>>2] = 1;
  $38 = (($36) + 22|0);
  $39 = $isColor&1;
  HEAP8[$38>>0] = $39;
  $40 = (($36) + 23|0);
  $41 = HEAP32[$desc>>2]|0;
  $42 = (($36) + 4|0);
  HEAP32[$42>>2] = $41;
  $43 = (($desc) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($36) + 8|0);
  HEAP32[$45>>2] = $44;
  $46 = (($36) + 32|0);
  HEAP32[$46>>2] = $dim;
  $47 = (($36) + 16|0);
  HEAP32[$47>>2] = $flags;
  $48 = (($desc) + 8|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = HEAP32[1152880>>2]|0;
  $51 = (($50) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ($49>>>0)>($52>>>0);
  $$ = $53 ? $52 : $49;
  HEAP32[$37>>2] = $$;
  $54 = (($desc) + 12|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)!=(0);
  $57 = $56&1;
  HEAP8[$40>>0] = $57;
  $58 = HEAP32[$tex>>2]|0;
  HEAP32[$36>>2] = $58;
  $59 = (($36) + 24|0);
  HEAP32[$59>>2] = $rb;
  $60 = (($36) + 28|0);
  HEAP32[$60>>2] = $glesFormat;
  $61 = ($58|0)!=(0);
  $62 = ($rb|0)==(0);
  $or$cond = $61 & $62;
  if (!($or$cond)) {
   $$0 = $36;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$0>>2] = $58;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  (__Z30TextureIdMapGLES_QueryOrCreate9TextureID($$byval_copy)|0);
  $$0 = $36;
  STACKTOP = sp;return ($$0|0);
 }
 if ($3) {
  $4 = HEAP32[$desc>>2]|0;
  $5 = (($desc) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($desc) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)!=(0);
  ;HEAP32[$rs+0>>2]=0|0;HEAP32[$rs+4>>2]=0|0;HEAP32[$rs+8>>2]=0|0;HEAP32[$rs+12>>2]=0|0;HEAP32[$rs+16>>2]=0|0;HEAP32[$rs+20>>2]=0|0;
  $10 = (($rs) + 12|0);
  HEAP32[$10>>2] = 1;
  $11 = (($rs) + 22|0);
  if ($isColor) {
   HEAP8[$11>>0] = 1;
   $12 = (($rs) + 23|0);
   HEAP8[$12>>0] = 0;
  } else {
   HEAP8[$11>>0] = 0;
   $13 = (($rs) + 23|0);
   HEAP8[$13>>0] = 0;
  }
  $14 = (($rs) + 4|0);
  HEAP32[$14>>2] = $4;
  $15 = (($rs) + 8|0);
  HEAP32[$15>>2] = $6;
  $16 = (($rs) + 23|0);
  $17 = $9&1;
  HEAP8[$16>>0] = $17;
  $18 = (($rs) + 16|0);
  HEAP32[$18>>2] = 64;
  $$0 = $rs;
  STACKTOP = sp;return ($$0|0);
 } else {
  $19 = (__Znwj(36)|0);
  dest=$19+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $20 = HEAP32[$desc>>2]|0;
  $21 = (($desc) + 4|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($desc) + 12|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)!=(0);
  ;HEAP32[$19+0>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;HEAP32[$19+16>>2]=0|0;HEAP32[$19+20>>2]=0|0;
  $26 = (($19) + 12|0);
  HEAP32[$26>>2] = 1;
  $27 = (($19) + 22|0);
  if ($isColor) {
   HEAP8[$27>>0] = 1;
   $28 = (($19) + 23|0);
   HEAP8[$28>>0] = 0;
  } else {
   HEAP8[$27>>0] = 0;
   $29 = (($19) + 23|0);
   HEAP8[$29>>0] = 0;
  }
  $30 = (($19) + 4|0);
  HEAP32[$30>>2] = $20;
  $31 = (($19) + 8|0);
  HEAP32[$31>>2] = $22;
  $32 = (($19) + 23|0);
  $33 = $25&1;
  HEAP8[$32>>0] = $33;
  $34 = (($19) + 16|0);
  HEAP32[$34>>2] = 64;
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN4gles8internal21InitRenderSurfaceGLESER17RenderSurfaceGLES($rs) {
 $rs = $rs|0;
 var $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = (__Z16GetRealGfxDevicev()|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 208|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$rs>>2]|0;
 HEAP32[$1>>2] = $6;
 $7 = (($rs) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 FUNCTION_TABLE_viiiiiif[$5 & 1]($2,2,0,0,$$byval_copy,$8,Math_fround(inf));
 $9 = HEAP32[$rs>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (($rs) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 & 2;
  $14 = ($13|0)!=(0);
  $15 = HEAP32[$7>>2]|0;
  $16 = (($rs) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($rs) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($rs) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  __ZN4gles24InitRenderTextureStorageE16TextureDimensionjiib($15,$17,$19,$21,$14);
  $22 = HEAP32[$7>>2]|0;
  $23 = ($22|0)==(2);
  if (!($23)) {
   STACKTOP = sp;return;
  }
  $24 = (1147664 + 308|0);
  $25 = HEAP32[$24>>2]|0;
  FUNCTION_TABLE_viii[$25 & 4095](3553,10240,9729);
  $26 = (1147664 + 308|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_viii[$27 & 4095](3553,10241,9729);
  $28 = (1147664 + 308|0);
  $29 = HEAP32[$28>>2]|0;
  FUNCTION_TABLE_viii[$29 & 4095](3553,10242,33071);
  $30 = (1147664 + 308|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_viii[$31 & 4095](3553,10243,33071);
  STACKTOP = sp;return;
 }
 HEAP32[$0>>2] = 0;
 $32 = HEAP32[((599640 + 36|0))>>2]|0;
 $33 = HEAP32[((599640 + 4|0))>>2]|0;
 $34 = ($32|0)==($33|0);
 do {
  if ($34) {
   $35 = HEAP32[((599640 + 28|0))>>2]|0;
   $36 = HEAP32[((599640 + 32|0))>>2]|0;
   $37 = (($35) + ($36<<3)|0);
   $45 = $35;$46 = $36;$48 = $37;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($$byval_copy,599640,$0);
   $38 = HEAP32[$$byval_copy>>2]|0;
   $39 = ($38|0)==(-1);
   $40 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($39) {
    $41 = HEAP32[((599640 + 32|0))>>2]|0;
    $42 = (($40) + ($41<<3)|0);
    $45 = $40;$46 = $41;$48 = $42;
    break;
   } else {
    $43 = (($40) + ($38<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $45 = $40;$46 = $$pre$i;$48 = $43;
    break;
   }
  }
 } while(0);
 $44 = (($45) + ($46<<3)|0);
 $47 = ($48|0)==($44|0);
 if ($47) {
  label = 11;
 } else {
  $49 = (($48) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($50|0)==(0);
  if ($51) {
   label = 11;
  }
 }
 if ((label|0) == 11) {
  $52 = (($rs) + 24|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0);
  if ($54) {
   $55 = (1147664 + 184|0);
   $56 = HEAP32[$55>>2]|0;
   FUNCTION_TABLE_vii[$56 & 4095](1,$52);
   $57 = (1147664 + 20|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = HEAP32[$52>>2]|0;
   FUNCTION_TABLE_vii[$58 & 4095](36161,$59);
  }
 }
 $60 = HEAP32[$7>>2]|0;
 $61 = (($rs) + 28|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($rs) + 4|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($rs) + 8|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($rs) + 12|0);
 $68 = HEAP32[$67>>2]|0;
 __ZN4gles23InitRenderBufferStorageE16TextureDimensionjiii($60,$62,$64,$66,$68);
 STACKTOP = sp;return;
}
function __ZN4gles28CreateDepthRenderSurfaceFullE17DepthBufferFormat9TextureIDj16TextureDimensionjRK17RenderSurfaceDesc($format,$tex,$rb,$dim,$flags,$desc) {
 $format = $format|0;
 $tex = $tex|0;
 $rb = $rb|0;
 $dim = $dim|0;
 $flags = $flags|0;
 $desc = $desc|0;
 var $$byval_copy = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = HEAP32[$tex>>2]|0;
 HEAP32[$1>>2] = $2;
 $3 = (__ZN4gles18FullInternalFormatE17DepthBufferFormat($format)|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 $4 = (__ZN4gles25CreateUpdateRenderSurfaceEP17RenderSurfaceGLESb16TextureDimension9TextureIDjjjRK17RenderSurfaceDesc(0,0,$dim,$$byval_copy,$rb,$3,$flags,$desc)|0);
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return ($4|0);
 }
 $6 = (($4) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 64;
 $9 = ($8|0)==(0);
 if (!($9)) {
  STACKTOP = sp;return ($4|0);
 }
 __ZN4gles8internal21InitRenderSurfaceGLESER17RenderSurfaceGLES($4);
 $10 = HEAP32[$4>>2]|0;
 HEAP32[$0>>2] = $10;
 $11 = HEAP32[((599640 + 36|0))>>2]|0;
 $12 = HEAP32[((599640 + 4|0))>>2]|0;
 $13 = ($11|0)==($12|0);
 do {
  if ($13) {
   $14 = HEAP32[((599640 + 28|0))>>2]|0;
   $15 = HEAP32[((599640 + 32|0))>>2]|0;
   $16 = (($14) + ($15<<3)|0);
   $24 = $14;$25 = $15;$27 = $16;
  } else {
   __ZNK15dense_hashtableINSt3__14pairIK9TextureIDiEES2_N12TextureIdMap20TextureIDHashFunctorEN14dense_hash_mapIS2_iS6_NS0_8equal_toIS2_EE13stl_allocatorIS4_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E13find_positionERS3_($$byval_copy,599640,$0);
   $17 = HEAP32[$$byval_copy>>2]|0;
   $18 = ($17|0)==(-1);
   $19 = HEAP32[((599640 + 28|0))>>2]|0;
   if ($18) {
    $20 = HEAP32[((599640 + 32|0))>>2]|0;
    $21 = (($19) + ($20<<3)|0);
    $24 = $19;$25 = $20;$27 = $21;
    break;
   } else {
    $22 = (($19) + ($17<<3)|0);
    $$pre$i = HEAP32[((599640 + 32|0))>>2]|0;
    $24 = $19;$25 = $$pre$i;$27 = $22;
    break;
   }
  }
 } while(0);
 $23 = (($24) + ($25<<3)|0);
 $26 = ($27|0)==($23|0);
 if ($26) {
  STACKTOP = sp;return ($4|0);
 }
 $28 = (($27) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0);
 if ($30) {
  STACKTOP = sp;return ($4|0);
 }
 $31 = HEAP32[$6>>2]|0;
 $32 = $31 & 8;
 $33 = ($32|0)==(0);
 if ($33) {
  STACKTOP = sp;return ($4|0);
 }
 $34 = (1147664 + 308|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (1157456 + ($dim<<2)|0);
 $37 = HEAP32[$36>>2]|0;
 FUNCTION_TABLE_viii[$35 & 4095]($37,34892,34894);
 $38 = (1147664 + 308|0);
 $39 = HEAP32[$38>>2]|0;
 FUNCTION_TABLE_viii[$39 & 4095]($37,34893,515);
 STACKTOP = sp;return ($4|0);
}
function __ZN4gles20DestroyRenderSurfaceEP17RenderSurfaceGLES($rs) {
 $rs = $rs|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$rs>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (__Z16GetRealGfxDevicev()|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 488|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$rs>>2]|0;
  HEAP32[$0>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_vii[$6 & 4095]($3,$$byval_copy);
 }
 $8 = (($rs) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (1147664 + 108|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_vii[$12 & 4095](1,$8);
 }
 $13 = ($rs|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return;
 }
 __ZdlPv($rs);
 STACKTOP = sp;return;
}
function __ZN4gles18CreateDummySurfaceEbRK17RenderSurfaceDesc($isColor,$desc) {
 $isColor = $isColor|0;
 $desc = $desc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (__Znwj(36)|0);
 dest=$0+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $1 = HEAP32[$desc>>2]|0;
 $2 = (($desc) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($desc) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)!=(0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;
 $7 = (($0) + 12|0);
 HEAP32[$7>>2] = 1;
 $8 = (($0) + 22|0);
 if ($isColor) {
  HEAP8[$8>>0] = 1;
  $9 = (($0) + 23|0);
  HEAP8[$9>>0] = 0;
 } else {
  HEAP8[$8>>0] = 0;
  $10 = (($0) + 23|0);
  HEAP8[$10>>0] = 0;
 }
 $11 = (($0) + 4|0);
 HEAP32[$11>>2] = $1;
 $12 = (($0) + 8|0);
 HEAP32[$12>>2] = $3;
 $13 = (($0) + 23|0);
 $14 = $6&1;
 HEAP8[$13>>0] = $14;
 $15 = (($0) + 16|0);
 HEAP32[$15>>2] = 64;
 STACKTOP = sp;return ($0|0);
}
function __ZN4gles18FullInternalFormatE19RenderTextureFormat($fmt) {
 $fmt = $fmt|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1154352 + ($fmt<<2)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = 2097290 >>> $fmt;
 $3 = $2 & 1;
 $4 = ($3|0)!=(0);
 $$ = $4 ? 32854 : $1;
 STACKTOP = sp;return ($$|0);
}
function __ZN4gles18FullInternalFormatE17DepthBufferFormat($fmt) {
 $fmt = $fmt|0;
 var $$ = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($fmt|0) == 2)) {
  $0 = HEAP8[((640792 + 244|0))>>0]|0;
  $1 = ($0<<24>>24)==(0);
  if ($1) {
   $2 = HEAP32[1152880>>2]|0;
   $3 = (($2) + 73|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $7 = $2;
    label = 5;
   } else {
    $$0 = 33190;
   }
  } else {
   $$0 = 34041;
  }
 } else if ((($fmt|0) == 0)) {
  $$0 = 0;
 } else {
  $$pre = HEAP32[1152880>>2]|0;
  $7 = $$pre;
  label = 5;
 }
 if ((label|0) == 5) {
  $6 = (($7) + 87|0);
  $8 = HEAP8[$6>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $$ = $9 ? 33189 : 36396;
  $$0 = $$;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles18FullInternalFormatE13TextureFormatb($fmt,$srgb) {
 $fmt = $fmt|0;
 $srgb = $srgb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $phitmp1 = 0, $phitmp2 = 0, $phitmp3 = 0, $phitmp4 = 0, $phitmp5 = 0;
 var $phitmp6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($fmt|0) {
  case 3:  {
   if ($srgb) {
    $10 = HEAP32[1152880>>2]|0;
    $11 = (($10) + 60|0);
    $12 = HEAP8[$11>>0]|0;
    $13 = ($12<<24>>24)==(0);
    if ($13) {
     $$0 = 32849;
    } else {
     $14 = (($10) + 44|0);
     $15 = HEAP32[$14>>2]|0;
     $$0 = $15;
    }
   } else {
    $$0 = 32849;
   }
   break;
  }
  case 17:  {
   $$0 = 34842;
   break;
  }
  case 14:  {
   $$0 = 37793;
   break;
  }
  case 20:  {
   $$0 = 34836;
   break;
  }
  case 4:  {
   if ($srgb) {
    $16 = HEAP32[1152880>>2]|0;
    $17 = (($16) + 60|0);
    $18 = HEAP8[$17>>0]|0;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     $$0 = 32856;
    } else {
     $20 = (($16) + 40|0);
     $21 = HEAP32[$20>>2]|0;
     $$0 = $21;
    }
   } else {
    $$0 = 32856;
   }
   break;
  }
  case 10:  {
   if ($srgb) {
    $22 = HEAP32[1152880>>2]|0;
    $23 = (($22) + 61|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)!=(0);
    $phitmp6 = $25 ? 35916 : 33776;
    $$0 = $phitmp6;
   } else {
    $$0 = 33776;
   }
   break;
  }
  case 16:  {
   $$0 = 33327;
   break;
  }
  case 11:  {
   if ($srgb) {
    $26 = HEAP32[1152880>>2]|0;
    $27 = (($26) + 61|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ($28<<24>>24)!=(0);
    $phitmp5 = $29 ? 35918 : 33778;
    $$0 = $phitmp5;
   } else {
    $$0 = 33778;
   }
   break;
  }
  case 9:  {
   $5 = HEAP32[1152880>>2]|0;
   $6 = (($5) + 75|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)!=(0);
   $9 = $8 ? 32837 : 6410;
   $$0 = $9;
   break;
  }
  case 15:  {
   $$0 = 33325;
   break;
  }
  case 6:  {
   $$0 = 34836;
   break;
  }
  case 7:  {
   $$0 = 36194;
   break;
  }
  case 18:  {
   $$0 = 33326;
   break;
  }
  case 1:  {
   $0 = HEAP32[1152880>>2]|0;
   $1 = (($0) + 75|0);
   $2 = HEAP8[$1>>0]|0;
   $3 = ($2<<24>>24)!=(0);
   $4 = $3 ? 32828 : 6406;
   $$0 = $4;
   break;
  }
  case 19:  {
   $$0 = 33328;
   break;
  }
  case 34:  {
   $50 = HEAP32[1152880>>2]|0;
   $51 = (($50) + 48|0);
   $52 = HEAP32[$51>>2]|0;
   $$0 = $52;
   break;
  }
  case 36:  {
   $$0 = 34798;
   break;
  }
  case 42:  {
   $$0 = 37489;
   break;
  }
  case 33:  {
   if ($srgb) {
    $46 = HEAP32[1152880>>2]|0;
    $47 = (($46) + 62|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = ($48<<24>>24)!=(0);
    $phitmp = $49 ? 35415 : 35842;
    $$0 = $phitmp;
   } else {
    $$0 = 35842;
   }
   break;
  }
  case 31:  {
   if ($srgb) {
    $38 = HEAP32[1152880>>2]|0;
    $39 = (($38) + 62|0);
    $40 = HEAP8[$39>>0]|0;
    $41 = ($40<<24>>24)!=(0);
    $phitmp2 = $41 ? 35413 : 35843;
    $$0 = $phitmp2;
   } else {
    $$0 = 35843;
   }
   break;
  }
  case 32:  {
   if ($srgb) {
    $42 = HEAP32[1152880>>2]|0;
    $43 = (($42) + 62|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = ($44<<24>>24)!=(0);
    $phitmp1 = $45 ? 35414 : 35840;
    $$0 = $phitmp1;
   } else {
    $$0 = 35840;
   }
   break;
  }
  case 35:  {
   $$0 = 35986;
   break;
  }
  case 41:  {
   $$0 = 37488;
   break;
  }
  case 30:  {
   if ($srgb) {
    $34 = HEAP32[1152880>>2]|0;
    $35 = (($34) + 62|0);
    $36 = HEAP8[$35>>0]|0;
    $37 = ($36<<24>>24)!=(0);
    $phitmp3 = $37 ? 35412 : 35841;
    $$0 = $phitmp3;
   } else {
    $$0 = 35841;
   }
   break;
  }
  case 43:  {
   $$0 = 37490;
   break;
  }
  case 44:  {
   $$0 = 37491;
   break;
  }
  case 45:  {
   $$0 = 37492;
   break;
  }
  case 46:  {
   $$0 = 37494;
   break;
  }
  case 12:  {
   if ($srgb) {
    $30 = HEAP32[1152880>>2]|0;
    $31 = (($30) + 61|0);
    $32 = HEAP8[$31>>0]|0;
    $33 = ($32<<24>>24)!=(0);
    $phitmp4 = $33 ? 35919 : 33779;
    $$0 = $phitmp4;
   } else {
    $$0 = 33779;
   }
   break;
  }
  case 55:  {
   $$0 = 37810;
   break;
  }
  case 58:  {
   $$0 = 37819;
   break;
  }
  case 51:  {
   $$0 = 37815;
   break;
  }
  case 59:  {
   $$0 = 37821;
   break;
  }
  case 47:  {
   $$0 = 37496;
   break;
  }
  case 50:  {
   $$0 = 37812;
   break;
  }
  case 52:  {
   $$0 = 37819;
   break;
  }
  case 54:  {
   $$0 = 37808;
   break;
  }
  case 56:  {
   $$0 = 37812;
   break;
  }
  case 48:  {
   $$0 = 37808;
   break;
  }
  case 53:  {
   $$0 = 37821;
   break;
  }
  case 49:  {
   $$0 = 37810;
   break;
  }
  case 13: case 2:  {
   $$0 = 32854;
   break;
  }
  case 57:  {
   $$0 = 37815;
   break;
  }
  default: {
   $$0 = 0;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles24DataTypeFromFullInternalEj($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  if ((($fmt|0) == 32854)) {
   $$0 = 32819;
  } else if ((($fmt|0) == 34842)) {
   $0 = HEAP32[1152880>>2]|0;
   $1 = (($0) + 36|0);
   $2 = HEAP32[$1>>2]|0;
   $$0 = $2;
  } else if ((($fmt|0) == 35056)) {
   $$0 = 34042;
  } else if ((($fmt|0) == 36396)) {
   $$0 = 5123;
  } else if ((($fmt|0) == 34041)) {
   $$0 = 34042;
  } else if ((($fmt|0) == 33189)) {
   $$0 = 5123;
  } else if ((($fmt|0) == 34836)) {
   $$0 = 5126;
  } else if ((($fmt|0) == 33190) | (($fmt|0) == 35906) | (($fmt|0) == 35907) | (($fmt|0) == 6410) | (($fmt|0) == 32837) | (($fmt|0) == 6406) | (($fmt|0) == 32828) | (($fmt|0) == 33321) | (($fmt|0) == 32849) | (($fmt|0) == 37793) | (($fmt|0) == 32856)) {
   $$0 = 5121;
  } else if ((($fmt|0) == 33328)) {
   $$0 = 5126;
  } else if ((($fmt|0) == 33333)) {
   $$0 = 5124;
  } else if ((($fmt|0) == 32857)) {
   $$0 = 33640;
  } else if ((($fmt|0) == 33326)) {
   $$0 = 5126;
  } else if ((($fmt|0) == 35898)) {
   $$0 = 35899;
  } else if ((($fmt|0) == 36194)) {
   $$0 = 33635;
  } else if ((($fmt|0) == 32855)) {
   $$0 = 32820;
  } else if ((($fmt|0) == 33327)) {
   $3 = HEAP32[1152880>>2]|0;
   $4 = (($3) + 36|0);
   $5 = HEAP32[$4>>2]|0;
   $$0 = $5;
  } else if ((($fmt|0) == 33325)) {
   $6 = HEAP32[1152880>>2]|0;
   $7 = (($6) + 36|0);
   $8 = HEAP32[$7>>2]|0;
   $$0 = $8;
  } else if ((($fmt|0) == 36226)) {
   $$0 = 5124;
  } else if ((($fmt|0) == 33339)) {
   $$0 = 5124;
  } else {
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles29TextureFormatFromFullInternalEj($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  if ((($fmt|0) == 35898)) {
   $$0 = 6407;
  } else if ((($fmt|0) == 36194)) {
   $$0 = 6407;
  } else if ((($fmt|0) == 32828)) {
   $$0 = 6406;
  } else if ((($fmt|0) == 34041)) {
   $$0 = $fmt;
  } else if ((($fmt|0) == 36226)) {
   $$0 = 36249;
  } else if ((($fmt|0) == 33327)) {
   $$0 = 33319;
  } else if ((($fmt|0) == 33333)) {
   $$0 = 36244;
  } else if ((($fmt|0) == 33190)) {
   $$0 = 6402;
  } else if ((($fmt|0) == 32837)) {
   $$0 = 6410;
  } else if ((($fmt|0) == 33326)) {
   $$0 = 6403;
  } else if ((($fmt|0) == 33321)) {
   $$0 = 6403;
  } else if ((($fmt|0) == 36396)) {
   $$0 = 6402;
  } else if ((($fmt|0) == 6406)) {
   $$0 = $fmt;
  } else if ((($fmt|0) == 37793)) {
   $$0 = 32993;
  } else if ((($fmt|0) == 6410)) {
   $$0 = $fmt;
  } else if ((($fmt|0) == 33328)) {
   $$0 = 33319;
  } else if ((($fmt|0) == 32849)) {
   $$0 = 6407;
  } else if ((($fmt|0) == 33339)) {
   $$0 = 33320;
  } else if ((($fmt|0) == 33325)) {
   $$0 = 6403;
  } else if ((($fmt|0) == 35056)) {
   $$0 = 34041;
  } else if ((($fmt|0) == 35906) | (($fmt|0) == 35907) | (($fmt|0) == 32857) | (($fmt|0) == 32855) | (($fmt|0) == 32854) | (($fmt|0) == 34836) | (($fmt|0) == 34842) | (($fmt|0) == 32856)) {
   $$0 = 6408;
  } else if ((($fmt|0) == 33189)) {
   $$0 = 6402;
  } else {
   $$0 = 0;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles29BaseInternalFormatForTexImageEj($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 76|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 L1: do {
  if ($3) {
   do {
    if ((($fmt|0) == 33325)) {
     $$0 = 6403;
     break L1;
    } else if ((($fmt|0) == 32837)) {
     $$0 = 6410;
     break L1;
    } else if ((($fmt|0) == 35898)) {
     $$0 = 6407;
     break L1;
    } else if ((($fmt|0) == 35056)) {
     $$0 = 34041;
     break L1;
    } else if ((($fmt|0) == 32828)) {
     $$0 = 6406;
     break L1;
    } else if ((($fmt|0) == 6406)) {
     $$0 = $fmt;
     break L1;
    } else if ((($fmt|0) == 33190)) {
     $$0 = 6402;
     break L1;
    } else if ((($fmt|0) == 36226)) {
     $$0 = 36249;
     break L1;
    } else if ((($fmt|0) == 36194)) {
     $$0 = 6407;
     break L1;
    } else if ((($fmt|0) == 33328)) {
     $$0 = 33319;
     break L1;
    } else if ((($fmt|0) == 33339)) {
     $$0 = 33320;
     break L1;
    } else if ((($fmt|0) == 37793)) {
     $$0 = 32993;
     break L1;
    } else if ((($fmt|0) == 33326)) {
     $$0 = 6403;
     break L1;
    } else if ((($fmt|0) == 33327)) {
     $$0 = 33319;
     break L1;
    } else if ((($fmt|0) == 36396)) {
     $$0 = 6402;
     break L1;
    } else if ((($fmt|0) == 33189)) {
     $$0 = 6402;
     break L1;
    } else if ((($fmt|0) == 33321)) {
     $$0 = 6403;
     break L1;
    } else if ((($fmt|0) == 6410)) {
     $$0 = $fmt;
     break L1;
    } else if ((($fmt|0) == 35906) | (($fmt|0) == 35907) | (($fmt|0) == 32857) | (($fmt|0) == 32855) | (($fmt|0) == 32854) | (($fmt|0) == 34836) | (($fmt|0) == 34842) | (($fmt|0) == 32856)) {
     $$0 = 6408;
     break L1;
    } else if ((($fmt|0) == 34041)) {
     $$0 = $fmt;
     break L1;
    } else if ((($fmt|0) == 32849)) {
     $$0 = 6407;
     break L1;
    } else if ((($fmt|0) == 33333)) {
     $$0 = 36244;
     break L1;
    } else {
     $$0 = 0;
     break L1;
    }
   } while(0);
  } else {
   $$0 = $fmt;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles18IsCompressedFormatEj($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($fmt|0) {
 case 37821: case 37819: case 37815: case 37812: case 37810: case 37808: case 37496: case 37494: case 37491: case 37490: case 37489: case 37488: case 37492: case 36196: case 34798: case 35986: case 35842: case 35840: case 35843: case 35841: case 35919: case 35918: case 35916: case 33779: case 33778: case 33776:  {
  $$0 = 1;
  break;
 }
 default: {
  $$0 = 0;
 }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles25IsTextureStorageSupportedEj($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 75|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  if ((($fmt|0) == 6406) | (($fmt|0) == 6410) | (($fmt|0) == 32828) | (($fmt|0) == 32837)) {
   $$0 = 0;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $$0 = 1;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles25UnityRTFormatFromInternalEj($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  switch ($fmt|0) {
  case 33325:  {
   $$0 = 15;
   break;
  }
  case 33327:  {
   $$0 = 13;
   break;
  }
  case 37793:  {
   $$0 = 20;
   break;
  }
  case 33321:  {
   $$0 = 16;
   break;
  }
  case 34842:  {
   $$0 = 2;
   break;
  }
  case 36194:  {
   $$0 = 4;
   break;
  }
  case 34836:  {
   $$0 = 11;
   break;
  }
  case 33328:  {
   $$0 = 12;
   break;
  }
  case 32857:  {
   $$0 = 8;
   break;
  }
  case 32855:  {
   $$0 = 6;
   break;
  }
  case 33326:  {
   $$0 = 14;
   break;
  }
  case 36226:  {
   $$0 = 17;
   break;
  }
  case 33339:  {
   $$0 = 18;
   break;
  }
  case 33333:  {
   $$0 = 19;
   break;
  }
  case 32854:  {
   $$0 = 5;
   break;
  }
  default: {
   $$0 = 0;
  }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles30UnityTextureFormatFromInternalEj($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 do {
  if ((($fmt|0) == 33328)) {
   $$0 = 19;
  } else if ((($fmt|0) == 32856)) {
   $$0 = 4;
  } else if ((($fmt|0) == 35906)) {
   $$0 = 4;
  } else if ((($fmt|0) == 37488)) {
   $$0 = 41;
  } else if ((($fmt|0) == 37494)) {
   $$0 = 46;
  } else if ((($fmt|0) == 37812)) {
   $$0 = 50;
  } else if ((($fmt|0) == 36194)) {
   $$0 = 7;
  } else if ((($fmt|0) == 35842)) {
   $$0 = 33;
  } else if ((($fmt|0) == 37489)) {
   $$0 = 42;
  } else if ((($fmt|0) == 37492)) {
   $$0 = 45;
  } else if ((($fmt|0) == 37810)) {
   $$0 = 49;
  } else if ((($fmt|0) == 6410)) {
   $$0 = 9;
  } else if ((($fmt|0) == 33327)) {
   $$0 = 16;
  } else if ((($fmt|0) == 32849)) {
   $$0 = 3;
  } else if ((($fmt|0) == 33326)) {
   $$0 = 18;
  } else if ((($fmt|0) == 35919)) {
   $$0 = 12;
  } else if ((($fmt|0) == 37490)) {
   $$0 = 43;
  } else if ((($fmt|0) == 37496)) {
   $$0 = 47;
  } else if ((($fmt|0) == 34842)) {
   $$0 = 17;
  } else if ((($fmt|0) == 35840)) {
   $$0 = 32;
  } else if ((($fmt|0) == 34798)) {
   $$0 = 36;
  } else if ((($fmt|0) == 37815)) {
   $$0 = 51;
  } else if ((($fmt|0) == 37819)) {
   $$0 = 52;
  } else if ((($fmt|0) == 35907)) {
   $$0 = 4;
  } else if ((($fmt|0) == 37491)) {
   $$0 = 44;
  } else if ((($fmt|0) == 32828)) {
   $$0 = 1;
  } else if ((($fmt|0) == 33778)) {
   $$0 = 11;
  } else if ((($fmt|0) == 36196)) {
   $$0 = 34;
  } else if ((($fmt|0) == 35986)) {
   $$0 = 35;
  } else if ((($fmt|0) == 37808)) {
   $$0 = 48;
  } else if ((($fmt|0) == 6406)) {
   $$0 = 1;
  } else if ((($fmt|0) == 33325)) {
   $$0 = 15;
  } else if ((($fmt|0) == 34836)) {
   $$0 = 20;
  } else if ((($fmt|0) == 33779)) {
   $$0 = 12;
  } else if ((($fmt|0) == 35841)) {
   $$0 = 30;
  } else if ((($fmt|0) == 35843)) {
   $$0 = 31;
  } else if ((($fmt|0) == 35916)) {
   $$0 = 10;
  } else if ((($fmt|0) == 35918)) {
   $$0 = 11;
  } else if ((($fmt|0) == 32837)) {
   $$0 = 9;
  } else if ((($fmt|0) == 37793)) {
   $$0 = 14;
  } else if ((($fmt|0) == 33776)) {
   $$0 = 10;
  } else if ((($fmt|0) == 37821)) {
   $$0 = 53;
  } else if ((($fmt|0) == 32854)) {
   $$0 = 2;
  } else {
   $$0 = 4;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles17MinTextureMipSizeE16TextureDimensionj($dim,$format) {
 $dim = $dim|0;
 $format = $format|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($format|0) {
 case 35843: case 35841:  {
  $$0 = 16;
  break;
 }
 case 37810: case 37808: case 37496: case 37494: case 37491: case 37490: case 37489: case 37488: case 37492: case 36196: case 34798: case 35986: case 37821: case 37819: case 37815: case 37812: case 35919: case 35918: case 35916: case 33779: case 33778: case 33776:  {
  $$0$i = 4;
  label = 4;
  break;
 }
 case 35842: case 35840:  {
  $0 = ($dim|0)==(2);
  $1 = $0 ? 8 : 16;
  $$0 = $1;
  break;
 }
 default: {
  $$0$i = 2;
  label = 4;
 }
 }
 if ((label|0) == 4) {
  $$0 = $$0$i;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles24ShouldDecompressOnUploadE13TextureFormat($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $format$off$i$i = 0, $format$off$i1$i = 0, $format$off$i2$i = 0, $format$off$i3$i = 0, $format$off$i4$i = 0, $format$off$i5$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond11$i = 0;
 var $or$cond13$i = 0, $or$cond7$i = 0, $or$cond9$i = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer5 = sp;
 $format$off$i$i = (($fmt) + -10)|0;
 $0 = ($format$off$i$i>>>0)<(3);
 $format$off$i5$i = (($fmt) + -30)|0;
 $1 = ($format$off$i5$i>>>0)<(4);
 $or$cond$i = $0 | $1;
 $2 = ($fmt|0)==(34);
 $or$cond7$i = $or$cond$i | $2;
 $format$off$i4$i = (($fmt) + -35)|0;
 $3 = ($format$off$i4$i>>>0)<(2);
 $or$cond9$i = $or$cond7$i | $3;
 $format$off$i3$i = (($fmt) + -41)|0;
 $4 = ($format$off$i3$i>>>0)<(4);
 $or$cond11$i = $or$cond9$i | $4;
 $format$off$i2$i = (($fmt) + -45)|0;
 $5 = ($format$off$i2$i>>>0)<(3);
 $or$cond13$i = $or$cond11$i | $5;
 $format$off$i1$i = (($fmt) + -48)|0;
 $6 = ($format$off$i1$i>>>0)<(12);
 $or$cond = $or$cond13$i | $6;
 if (!($or$cond)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ((640792 + ($fmt)|0) + 141|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if (!($9)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if ($1) {
  _printf_console(1154440,$vararg_buffer5);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($0) {
  _printf_console(1154512,$vararg_buffer5);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if ($2) {
  _printf_console(1154584,$vararg_buffer5);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($3)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 _printf_console(1154656,$vararg_buffer5);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles12UploadFormatE13TextureFormat($fmt) {
 $fmt = $fmt|0;
 var $$0 = 0, $$old = 0, $$old1 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4gles24ShouldDecompressOnUploadE13TextureFormat($fmt)|0);
 do {
  if ($0) {
   $$0 = 4;
  } else {
   if ((($fmt|0) == 14)) {
    $$old = HEAP8[((640792 + 155|0))>>0]|0;
    $$old1 = ($$old<<24>>24)==(0);
    if ($$old1) {
     $$0 = 4;
     break;
    }
   } else if ((($fmt|0) == 6)) {
    $1 = HEAP8[((640792 + 147|0))>>0]|0;
    $2 = ($1<<24>>24)==(0);
    if ($2) {
     $$0 = 4;
     break;
    }
   } else if ((($fmt|0) == 5)) {
    $$0 = 4;
    break;
   } else if ((($fmt|0) == 8)) {
    $$0 = 3;
    break;
   }
   $$0 = $fmt;
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN4gles18InitTextureStorageE16TextureDimensionjiiii($dim,$format,$w,$h,$d,$mipCount) {
 $dim = $dim|0;
 $format = $format|0;
 $w = $w|0;
 $h = $h|0;
 $d = $d|0;
 $mipCount = $mipCount|0;
 var $$neg1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $realMipCount$0 = 0, $realMipCount$1 = 0, $storageInited = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $storageInited = sp;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 74|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $realMipCount$1 = $mipCount;
  STACKTOP = sp;return ($realMipCount$1|0);
 }
 $4 = (__ZN4gles25IsTextureStorageSupportedEj($format)|0);
 if (!($4)) {
  $realMipCount$1 = $mipCount;
  STACKTOP = sp;return ($realMipCount$1|0);
 }
 HEAP32[$storageInited>>2] = 0;
 $5 = (1147664 + 236|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (1157456 + ($dim<<2)|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viii[$6 & 4095]($8,37167,$storageInited);
 $9 = HEAP32[$storageInited>>2]|0;
 $10 = ($9|0)==(1);
 if ($10) {
  $realMipCount$1 = $mipCount;
  STACKTOP = sp;return ($realMipCount$1|0);
 }
 $11 = ($mipCount|0)>(1);
 if ($11) {
  $12 = (__ZN4gles17MinTextureMipSizeE16TextureDimensionj($dim,$format)|0);
  $13 = (__Z22CalculateMipMapCount3Diii($12,$12,$d)|0);
  $14 = ($13|0)>($mipCount|0);
  if ($14) {
   $realMipCount$0 = 1;
  } else {
   $$neg1 = (($mipCount) + 1)|0;
   $15 = (($$neg1) - ($13))|0;
   $realMipCount$0 = $15;
  }
 } else {
  $realMipCount$0 = $mipCount;
 }
 $16 = ($dim|0)==(3);
 if ($16) {
  $17 = (1147664 + 516|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_viiiiii[$18 & 255](32879,$mipCount,$format,$w,$h,$d);
 } else {
  $19 = (1147664 + 512|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiiii[$20 & 255]($8,$mipCount,$format,$w,$h);
 }
 $21 = HEAP8[((640792 + 127|0))>>0]|0;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $realMipCount$1 = $realMipCount$0;
  STACKTOP = sp;return ($realMipCount$1|0);
 }
 $23 = (1147664 + 308|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($realMipCount$0) + -1)|0;
 FUNCTION_TABLE_viii[$24 & 4095]($8,33085,$25);
 $realMipCount$1 = $realMipCount$0;
 STACKTOP = sp;return ($realMipCount$1|0);
}
function __ZN4gles24InitRenderTextureStorageE16TextureDimensionjiib($dim,$format,$w,$h,$hasMips) {
 $dim = $dim|0;
 $format = $format|0;
 $w = $w|0;
 $h = $h|0;
 $hasMips = $hasMips|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($hasMips) {
  $0 = (__Z22CalculateMipMapCount3Diii($w,$h,1)|0);
  $1 = $0;
 } else {
  $1 = 1;
 }
 (__ZN4gles18InitTextureStorageE16TextureDimensionjiiii($dim,$format,$w,$h,1,$1)|0);
 $2 = HEAP32[1152880>>2]|0;
 $3 = (($2) + 74|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if (!($5)) {
  $6 = (__ZN4gles25IsTextureStorageSupportedEj($format)|0);
  if ($6) {
   STACKTOP = sp;return;
  }
 }
 $7 = (__ZN4gles24DataTypeFromFullInternalEj($format)|0);
 $8 = (__ZN4gles29TextureFormatFromFullInternalEj($format)|0);
 $9 = (__ZN4gles29BaseInternalFormatForTexImageEj($format)|0);
 $10 = ($dim|0)==(2);
 $11 = (1147664 + 304|0);
 $12 = HEAP32[$11>>2]|0;
 if ($10) {
  FUNCTION_TABLE_viiiiiiiii[$12 & 31](3553,0,$9,$w,$h,0,$8,$7,0);
 } else {
  FUNCTION_TABLE_viiiiiiiii[$12 & 31](34069,0,$9,$w,$h,0,$8,$7,0);
  $13 = (1147664 + 304|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$14 & 31](34070,0,$9,$w,$h,0,$8,$7,0);
  $15 = (1147664 + 304|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$16 & 31](34071,0,$9,$w,$h,0,$8,$7,0);
  $17 = (1147664 + 304|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$18 & 31](34072,0,$9,$w,$h,0,$8,$7,0);
  $19 = (1147664 + 304|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$20 & 31](34073,0,$9,$w,$h,0,$8,$7,0);
  $21 = (1147664 + 304|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$22 & 31](34074,0,$9,$w,$h,0,$8,$7,0);
 }
 if (!($hasMips)) {
  STACKTOP = sp;return;
 }
 $23 = (1147664 + 176|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (1157456 + ($dim<<2)|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_vi[$24 & 4095]($26);
 STACKTOP = sp;return;
}
function __ZN4gles23InitRenderBufferStorageE16TextureDimensionjiii($dim,$format,$w,$h,$samples) {
 $dim = $dim|0;
 $format = $format|0;
 $w = $w|0;
 $h = $h|0;
 $samples = $samples|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($samples|0)<(2);
 $1 = HEAP8[((640792 + 129|0))>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $or$cond = $0 | $2;
 if ($or$cond) {
  $5 = (1147664 + 272|0);
  $6 = HEAP32[$5>>2]|0;
  FUNCTION_TABLE_viiii[$6 & 511](36161,$format,$w,$h);
  STACKTOP = sp;return;
 } else {
  $3 = (1147664 + 424|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_viiiii[$4 & 255](36161,$samples,$format,$w,$h);
  STACKTOP = sp;return;
 }
}
function __ZN4gles13UploadTextureE9TextureID16TextureDimension13TextureFormatPKviiiiij17TextureColorSpace($tex,$dim,$format,$data,$faceDataSize,$w,$h,$d,$mipCount,$flags,$colorSpace) {
 $tex = $tex|0;
 $dim = $dim|0;
 $format = $format|0;
 $data = $data|0;
 $faceDataSize = $faceDataSize|0;
 $w = $w|0;
 $h = $h|0;
 $d = $d|0;
 $mipCount = $mipCount|0;
 $flags = $flags|0;
 $colorSpace = $colorSpace|0;
 var $$byval_copy5 = 0, $$pn = 0, $$pre = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $colorSpace$off = 0, $exitcond$i = 0, $exitcond$i3 = 0, $exitcond$i8 = 0, $i$015 = 0, $level$01$i = 0, $level$01$i2 = 0, $level$01$i7 = 0, $uploadedSize$0$lcssa = 0, $uploadedSize$0$lcssa$i = 0, $uploadedSize$0$lcssa$i5 = 0, $uploadedSize$016 = 0, $uploadedSize$02$i = 0, $uploadedSize$02$i1 = 0, $uploadedSize$02$i6 = 0, $uploadedSize$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $4 = HEAP32[$tex>>2]|0;
 HEAP32[$2>>2] = $4;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
 (__Z30TextureIdMapGLES_QueryOrCreate9TextureID($$byval_copy5)|0);
 $5 = HEAP32[1149528>>2]|0;
 HEAP32[$3>>2] = $4;
 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
 __ZN4gles10SetTextureER15DeviceStateGLES9TextureID16TextureDimensionj($5,$$byval_copy5,$dim,0);
 $6 = (1147664 + 260|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095](3317,1);
 $colorSpace$off = (($colorSpace) + -1)|0;
 $8 = ($colorSpace$off>>>0)<(2);
 $9 = (__ZN4gles12UploadFormatE13TextureFormat($format)|0);
 $10 = (__ZN4gles24ShouldDecompressOnUploadE13TextureFormat($format)|0);
 $11 = ($9|0)==($format|0);
 $12 = (__ZN4gles18FullInternalFormatE13TextureFormatb($9,$8)|0);
 $13 = (__ZN4gles18InitTextureStorageE16TextureDimensionjiiii($dim,$12,$w,$h,$d,$mipCount)|0);
 $14 = (1154784 + ($dim<<2)|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($dim) + -2)|0;
 $17 = ($16>>>0)<(3);
 if (!($17)) {
  $uploadedSize$0$lcssa = 0;
  $95 = $4;
  __Z34register_external_gfx_deallocationPvPKci($95,1154808,160);
  __Z32register_external_gfx_allocationPvjjPKci($95,$uploadedSize$0$lcssa,$4,1154808,161);
  STACKTOP = sp;return;
 }
 $18 = (1154760 + ($dim<<2)|0);
 $19 = ($13|0)>(0);
 $$pre = HEAP32[$18>>2]|0;
 $i$015 = 0;$uploadedSize$016 = 0;
 while(1) {
  $20 = (($$pre) + ($i$015))|0;
  $21 = (1154728 + ($20<<2)|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($i$015, $faceDataSize)|0;
  L6: do {
   if ($10) {
    $24 = (__ZN4gles18FullInternalFormatE13TextureFormatb(4,$8)|0);
    $25 = (__Z33GetMinimumTextureMipSizeForFormat13TextureFormat($format)|0);
    $26 = ($25|0)>($w|0);
    $27 = $26 ? $25 : $w;
    $28 = ($25|0)>($h|0);
    $29 = $28 ? $25 : $h;
    $30 = (__Z18CalculateImageSizeii13TextureFormat($27,$29,4)|0);
    $31 = Math_imul($30, $d)|0;
    $32 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $32;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $33 = (__Z15malloc_internaljj10MemLabelIdiPKci($31,16,$$byval_copy5,0,1154808,261)|0);
    if ($19) {
     $level$01$i = 0;$uploadedSize$02$i = 0;
     while(1) {
      $34 = $w >> $level$01$i;
      $35 = ($34|0)<(1);
      $36 = $35 ? 1 : $34;
      $37 = $h >> $level$01$i;
      $38 = ($37|0)<(1);
      $39 = $38 ? 1 : $37;
      $40 = $d >> $level$01$i;
      $41 = ($40|0)<(1);
      $42 = $41 ? 1 : $40;
      $43 = (__Z18CalculateImageSizeii13TextureFormat($36,$39,$format)|0);
      $44 = Math_imul($42, $43)|0;
      $$sum12 = (($uploadedSize$02$i) + ($23))|0;
      $45 = (($data) + ($$sum12)|0);
      $46 = ($36|0)<($25|0);
      $47 = $46 ? $25 : $36;
      $48 = ($39|0)<($25|0);
      $49 = $48 ? $25 : $39;
      (__Z29DecompressNativeTextureFormat13TextureFormatiiPKjiiPj($format,$36,$39,$45,$47,$49,$33)|0);
      __ZN4gles22UploadBytesToGLTextureE16TextureDimensionjjiiiiPKv($dim,$22,$24,$level$01$i,$36,$39,$42,$33);
      $50 = (($44) + ($uploadedSize$02$i))|0;
      $51 = (($level$01$i) + 1)|0;
      $exitcond$i = ($51|0)==($13|0);
      if ($exitcond$i) {
       $uploadedSize$0$lcssa$i = $50;
       break;
      } else {
       $level$01$i = $51;$uploadedSize$02$i = $50;
      }
     }
    } else {
     $uploadedSize$0$lcssa$i = 0;
    }
    $52 = HEAP32[628512>>2]|0;
    HEAP32[$1>>2] = $52;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($33,$$byval_copy5);
    $$pn = $uploadedSize$0$lcssa$i;
   } else {
    if ($11) {
     $78 = (__ZN4gles18FullInternalFormatE13TextureFormatb($format,$8)|0);
     if ($19) {
      $level$01$i7 = 0;$uploadedSize$02$i6 = 0;
     } else {
      $$pn = 0;
      break;
     }
     while(1) {
      $79 = $w >> $level$01$i7;
      $80 = ($79|0)<(1);
      $81 = $80 ? 1 : $79;
      $82 = $h >> $level$01$i7;
      $83 = ($82|0)<(1);
      $84 = $83 ? 1 : $82;
      $85 = $d >> $level$01$i7;
      $86 = ($85|0)<(1);
      $87 = $86 ? 1 : $85;
      $88 = (__Z18CalculateImageSizeii13TextureFormat($81,$84,$format)|0);
      $89 = Math_imul($87, $88)|0;
      $$sum11 = (($uploadedSize$02$i6) + ($23))|0;
      $90 = (($data) + ($$sum11)|0);
      __ZN4gles22UploadBytesToGLTextureE16TextureDimensionjjiiiiPKv($dim,$22,$78,$level$01$i7,$81,$84,$87,$90);
      $91 = (($89) + ($uploadedSize$02$i6))|0;
      $92 = (($level$01$i7) + 1)|0;
      $exitcond$i8 = ($92|0)==($13|0);
      if ($exitcond$i8) {
       $$pn = $91;
       break L6;
      } else {
       $level$01$i7 = $92;$uploadedSize$02$i6 = $91;
      }
     }
    }
    $53 = (__ZN4gles18FullInternalFormatE13TextureFormatb($9,$8)|0);
    $54 = (__Z33GetMinimumTextureMipSizeForFormat13TextureFormat($format)|0);
    $55 = ($54|0)>($w|0);
    $56 = $55 ? $54 : $w;
    $57 = ($54|0)>($h|0);
    $58 = $57 ? $54 : $h;
    $59 = (__Z18CalculateImageSizeii13TextureFormat($56,$58,$9)|0);
    $60 = Math_imul($59, $d)|0;
    $61 = HEAP32[628512>>2]|0;
    HEAP32[$0>>2] = $61;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
    $62 = (__Z15malloc_internaljj10MemLabelIdiPKci($60,16,$$byval_copy5,0,1154808,286)|0);
    if ($19) {
     $level$01$i2 = 0;$uploadedSize$02$i1 = 0;
     while(1) {
      $63 = $w >> $level$01$i2;
      $64 = ($63|0)<(1);
      $65 = $64 ? 1 : $63;
      $66 = $h >> $level$01$i2;
      $67 = ($66|0)<(1);
      $68 = $67 ? 1 : $66;
      $69 = $d >> $level$01$i2;
      $70 = ($69|0)<(1);
      $71 = $70 ? 1 : $69;
      $72 = (__Z18CalculateImageSizeii13TextureFormat($65,$68,$format)|0);
      $73 = Math_imul($71, $72)|0;
      $$sum = (($uploadedSize$02$i1) + ($23))|0;
      $74 = (($data) + ($$sum)|0);
      __ZN4gles8internalL27ConvertUncompressedMipLevelE13TextureFormatS1_iiiPKvPv($format,$9,$65,$68,$71,$74,$62);
      __ZN4gles22UploadBytesToGLTextureE16TextureDimensionjjiiiiPKv($dim,$22,$53,$level$01$i2,$65,$68,$71,$62);
      $75 = (($73) + ($uploadedSize$02$i1))|0;
      $76 = (($level$01$i2) + 1)|0;
      $exitcond$i3 = ($76|0)==($13|0);
      if ($exitcond$i3) {
       $uploadedSize$0$lcssa$i5 = $75;
       break;
      } else {
       $level$01$i2 = $76;$uploadedSize$02$i1 = $75;
      }
     }
    } else {
     $uploadedSize$0$lcssa$i5 = 0;
    }
    $77 = HEAP32[628512>>2]|0;
    HEAP32[$1>>2] = $77;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
    __Z19free_alloc_internalPv10MemLabelId($62,$$byval_copy5);
    $$pn = $uploadedSize$0$lcssa$i5;
   }
  } while(0);
  $uploadedSize$1 = (($$pn) + ($uploadedSize$016))|0;
  $93 = (($i$015) + 1)|0;
  $94 = ($93|0)<($15|0);
  if ($94) {
   $i$015 = $93;$uploadedSize$016 = $uploadedSize$1;
  } else {
   $uploadedSize$0$lcssa = $uploadedSize$1;
   break;
  }
 }
 $95 = $4;
 __Z34register_external_gfx_deallocationPvPKci($95,1154808,160);
 __Z32register_external_gfx_allocationPvjjPKci($95,$uploadedSize$0$lcssa,$4,1154808,161);
 STACKTOP = sp;return;
}
function __ZN4gles22UploadTexture2DSubDataE9TextureID13TextureFormatPKviiiii17TextureColorSpace($tex,$format,$data,$mipLevel,$x,$y,$w,$h,$colorSpace) {
 $tex = $tex|0;
 $format = $format|0;
 $data = $data|0;
 $mipLevel = $mipLevel|0;
 $x = $x|0;
 $y = $y|0;
 $w = $w|0;
 $h = $h|0;
 $colorSpace = $colorSpace|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $colorSpace$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 16|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = sp + 12|0;
 $colorSpace$off = (($colorSpace) + -1)|0;
 $4 = ($colorSpace$off>>>0)<(2);
 $5 = (__ZN4gles12UploadFormatE13TextureFormat($format)|0);
 $6 = ($5|0)==($format|0);
 $7 = (__ZN4gles18FullInternalFormatE13TextureFormatb($5,$4)|0);
 $8 = HEAP32[$tex>>2]|0;
 HEAP32[$2>>2] = $8;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
 (__Z30TextureIdMapGLES_QueryOrCreate9TextureID($$byval_copy3)|0);
 $9 = HEAP32[1149528>>2]|0;
 HEAP32[$3>>2] = $8;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
 __ZN4gles10SetTextureER15DeviceStateGLES9TextureID16TextureDimensionj($9,$$byval_copy3,2,0);
 $10 = (1147664 + 260|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095](3317,1);
 if ($6) {
  __ZN4gles8internalL23UploadSubImageToTextureE16TextureDimensionjjiiiiiiiPKv(2,3553,$7,$mipLevel,$x,$y,$w,$h,1,$data);
  STACKTOP = sp;return;
 } else {
  $12 = (__ZN4gles18FullInternalFormatE13TextureFormatb($5,$4)|0);
  $13 = (__Z33GetMinimumTextureMipSizeForFormat13TextureFormat($format)|0);
  $14 = ($13|0)>($w|0);
  $15 = $14 ? $13 : $w;
  $16 = ($13|0)>($h|0);
  $17 = $16 ? $13 : $h;
  $18 = (__Z18CalculateImageSizeii13TextureFormat($15,$17,$5)|0);
  $19 = HEAP32[628512>>2]|0;
  HEAP32[$0>>2] = $19;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
  $20 = (__Z15malloc_internaljj10MemLabelIdiPKci($18,16,$$byval_copy3,0,1154808,311)|0);
  __ZN4gles8internalL27ConvertUncompressedMipLevelE13TextureFormatS1_iiiPKvPv($format,$5,$w,$h,1,$data,$20);
  __ZN4gles8internalL23UploadSubImageToTextureE16TextureDimensionjjiiiiiiiPKv(2,3553,$12,$mipLevel,$x,$y,$w,$h,1,$20);
  $21 = HEAP32[628512>>2]|0;
  HEAP32[$1>>2] = $21;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  __Z19free_alloc_internalPv10MemLabelId($20,$$byval_copy3);
  STACKTOP = sp;return;
 }
}
function __ZN4gles8internalL23UploadSubImageToTextureE16TextureDimensionjjiiiiiiiPKv($dim,$target,$format,$level,$x,$y,$w,$h,$d,$data) {
 $dim = $dim|0;
 $target = $target|0;
 $format = $format|0;
 $level = $level|0;
 $x = $x|0;
 $y = $y|0;
 $w = $w|0;
 $h = $h|0;
 $d = $d|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN4gles18IsCompressedFormatEj($format)|0);
 if ($0) {
  $1 = (__ZN4gles30UnityTextureFormatFromInternalEj($format)|0);
  $2 = (__Z18CalculateImageSizeii13TextureFormat($w,$h,$1)|0);
  $3 = (1147664 + 76|0);
  $4 = HEAP32[$3>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$4 & 31]($target,$level,$x,$y,$w,$h,$format,$2,$data);
  STACKTOP = sp;return;
 }
 $5 = (__ZN4gles24DataTypeFromFullInternalEj($format)|0);
 $6 = (__ZN4gles29TextureFormatFromFullInternalEj($format)|0);
 if ((($dim|0) == 2) | (($dim|0) == 4)) {
  $7 = (1147664 + 312|0);
  $8 = HEAP32[$7>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$8 & 31]($target,$level,$x,$y,$w,$h,$6,$5,$data);
  STACKTOP = sp;return;
 } else {
  $9 = (1147664 + 388|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_viiiiiiiiiii[$10 & 3]($target,$level,$x,$y,0,$w,$h,$d,$6,$5,$data);
  STACKTOP = sp;return;
 }
}
function __ZN4gles22UploadBytesToGLTextureE16TextureDimensionjjiiiiPKv($dim,$target,$format,$level,$w,$h,$d,$data) {
 $dim = $dim|0;
 $target = $target|0;
 $format = $format|0;
 $level = $level|0;
 $w = $w|0;
 $h = $h|0;
 $d = $d|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 74|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if (!($3)) {
  $4 = (__ZN4gles25IsTextureStorageSupportedEj($format)|0);
  if ($4) {
   __ZN4gles8internalL23UploadSubImageToTextureE16TextureDimensionjjiiiiiiiPKv($dim,$target,$format,$level,0,0,$w,$h,$d,$data);
   STACKTOP = sp;return;
  }
 }
 $5 = (__ZN4gles18IsCompressedFormatEj($format)|0);
 if ($5) {
  $6 = (__ZN4gles30UnityTextureFormatFromInternalEj($format)|0);
  $7 = (__Z18CalculateImageSizeii13TextureFormat($w,$h,$6)|0);
  $8 = (1147664 + 72|0);
  $9 = HEAP32[$8>>2]|0;
  FUNCTION_TABLE_viiiiiiii[$9 & 63]($target,$level,$format,$w,$h,0,$7,$data);
  STACKTOP = sp;return;
 }
 $10 = (__ZN4gles24DataTypeFromFullInternalEj($format)|0);
 $11 = (__ZN4gles29TextureFormatFromFullInternalEj($format)|0);
 $12 = (__ZN4gles29BaseInternalFormatForTexImageEj($format)|0);
 if ((($dim|0) == 2) | (($dim|0) == 4)) {
  $13 = (1147664 + 304|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$14 & 31]($target,$level,$12,$w,$h,0,$11,$10,$data);
  STACKTOP = sp;return;
 } else {
  $15 = (1147664 + 384|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viiiiiiiiii[$16 & 15]($target,$level,$12,$w,$h,$d,0,$11,$10,$data);
  STACKTOP = sp;return;
 }
}
function __ZN4gles8internalL27ConvertUncompressedMipLevelE13TextureFormatS1_iiiPKvPv($format,$uploadFormat,$w,$h,$d,$src,$dst) {
 $format = $format|0;
 $uploadFormat = $uploadFormat|0;
 $w = $w|0;
 $h = $h|0;
 $d = $d|0;
 $src = $src|0;
 $dst = $dst|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dstImg = 0, $exitcond = 0, $i$01 = 0, $srcImg = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $srcImg = sp + 20|0;
 $dstImg = sp;
 $0 = (__Z18CalculateImageSizeii13TextureFormat($w,$h,$format)|0);
 $1 = (__Z18CalculateImageSizeii13TextureFormat($w,$h,$uploadFormat)|0);
 $2 = ($d|0)>(0);
 if ($2) {
  $i$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $3 = Math_imul($i$01, $0)|0;
  $4 = (($src) + ($3)|0);
  $5 = Math_imul($i$01, $1)|0;
  $6 = (($dst) + ($5)|0);
  $7 = (__Z29GetRowBytesFromWidthAndFormati13TextureFormat($w,$format)|0);
  __ZN14ImageReferenceC2Eiii13TextureFormatPv($srcImg,$w,$h,$7,$format,$4);
  $8 = (__Z29GetRowBytesFromWidthAndFormati13TextureFormat($w,$uploadFormat)|0);
  __ZN14ImageReferenceC2Eiii13TextureFormatPv($dstImg,$w,$h,$8,$uploadFormat,$6);
  __ZN14ImageReference9BlitImageERKS_NS_8BlitModeE($dstImg,$srcImg,0);
  $9 = (($i$01) + 1)|0;
  $exitcond = ($9|0)==($d|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZN4gles21GrabIntoRenderTextureEP17RenderSurfaceBaseS1_iiii($dst,$src,$x,$y,$width,$height) {
 $dst = $dst|0;
 $src = $src|0;
 $x = $x|0;
 $y = $y|0;
 $width = $width|0;
 $height = $height|0;
 var $$0$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $abits = 0, $bbits = 0, $cond = 0, $curFBO = 0, $gbits = 0, $interim$0 = 0, $rbits = 0, $samples$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp;
 $samples$i = sp + 36|0;
 $curFBO = sp + 32|0;
 $0 = sp + 28|0;
 $rbits = sp + 40|0;
 $gbits = sp + 8|0;
 $bbits = sp + 4|0;
 $abits = sp + 12|0;
 $1 = sp + 16|0;
 HEAP32[$curFBO>>2] = 0;
 $2 = (1147664 + 212|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095](36006,$curFBO);
 $4 = ($dst|0)==(0|0);
 L1: do {
  if ($4) {
   label = 8;
  } else {
   $5 = HEAP32[1152880>>2]|0;
   $6 = (($5) + 68|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   if ($8) {
    label = 8;
   } else {
    $9 = (($src) + 28|0);
    $10 = HEAP32[$9>>2]|0;
    switch ($10|0) {
    case 34836: case 34837: case 33328: case 33326: case 34842: case 34843: case 33327: case 33325:  {
     $$0$i$i = 1;
     break;
    }
    default: {
     $$0$i$i = 0;
    }
    }
    $11 = (($dst) + 28|0);
    $12 = HEAP32[$11>>2]|0;
    switch ($12|0) {
    case 34836: case 34837: case 33328: case 33326: case 34842: case 34843: case 33327: case 33325:  {
     if ($$0$i$i) {
      label = 8;
      break L1;
     } else {
      label = 11;
      break L1;
     }
     break;
    }
    default: {
     if ($$0$i$i) {
      label = 11;
      break L1;
     } else {
      label = 8;
      break L1;
     }
    }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $13 = (($src) + 23|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $20 = (($src) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21>>>0)>(1);
    if ($22) {
     label = 11;
     break;
    } else {
     $interim$0 = 0;
     break;
    }
   } else {
    HEAP32[$samples$i>>2] = 0;
    $16 = (1147664 + 212|0);
    $17 = HEAP32[$16>>2]|0;
    FUNCTION_TABLE_vii[$17 & 4095](32937,$samples$i);
    $18 = HEAP32[$samples$i>>2]|0;
    $19 = ($18|0)>(0);
    if ($19) {
     label = 11;
     break;
    } else {
     $interim$0 = 0;
     break;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 11) {
   $23 = HEAP32[1152880>>2]|0;
   $24 = (($23) + 89|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    $27 = (($23) + 68|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = ($28<<24>>24)==(0);
    if ($29) {
     $interim$0 = 0;
     break;
    }
   }
   $30 = $y | $x;
   $31 = ($30|0)==(0);
   if ($31) {
    $32 = (($src) + 4|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ($33|0)==($width|0);
    if ($34) {
     $35 = (($src) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==($height|0);
     if ($37) {
      __ZN4gles19ReadbackResolveMSAAEP17RenderSurfaceBaseS1_($dst,0);
      $38 = (1147664 + 16|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = HEAP32[$curFBO>>2]|0;
      FUNCTION_TABLE_vii[$39 & 4095](36160,$40);
      STACKTOP = sp;return;
     }
    }
   }
   $41 = (__ZN4gles8internalL27PrepareReadback_ResolveMSAAEP17RenderSurfaceBase($dst)|0);
   $interim$0 = $41;
  }
 } while(0);
 $42 = (__Z16GetRealGfxDevicev()|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($43) + 208|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$dst>>2]|0;
 HEAP32[$0>>2] = $46;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiiiiif[$45 & 1]($42,2,0,0,$$byval_copy,2,Math_fround(inf));
 $47 = (1147664 + 260|0);
 $48 = HEAP32[$47>>2]|0;
 FUNCTION_TABLE_vii[$48 & 4095](3317,1);
 HEAP32[$rbits>>2] = 0;
 HEAP32[$gbits>>2] = 0;
 HEAP32[$bbits>>2] = 0;
 HEAP32[$abits>>2] = 0;
 $49 = (1147664 + 212|0);
 $50 = HEAP32[$49>>2]|0;
 FUNCTION_TABLE_vii[$50 & 4095](3410,$rbits);
 $51 = (1147664 + 212|0);
 $52 = HEAP32[$51>>2]|0;
 FUNCTION_TABLE_vii[$52 & 4095](3411,$gbits);
 $53 = (1147664 + 212|0);
 $54 = HEAP32[$53>>2]|0;
 FUNCTION_TABLE_vii[$54 & 4095](3412,$bbits);
 $55 = (1147664 + 212|0);
 $56 = HEAP32[$55>>2]|0;
 FUNCTION_TABLE_vii[$56 & 4095](3413,$abits);
 $57 = HEAP32[$rbits>>2]|0;
 $58 = ($57|0)==(8);
 do {
  if ($58) {
   $59 = HEAP32[$gbits>>2]|0;
   $60 = ($59|0)==(8);
   if ($60) {
    $61 = HEAP32[$bbits>>2]|0;
    $62 = ($61|0)==(8);
    if ($62) {
     $63 = HEAP32[$abits>>2]|0;
     $64 = ($63|0)==(0);
     if ($64) {
      $65 = (($dst) + 28|0);
      $66 = HEAP32[$65>>2]|0;
      $cond = ($66|0)==(32856);
      if ($cond) {
       $88 = Math_imul($height, $width)|0;
       $89 = $88 << 2;
       $90 = ($88|0)<(0);
       $91 = $90 ? -1 : $89;
       $92 = (__Znaj($91)|0);
       $93 = (1147664 + 268|0);
       $94 = HEAP32[$93>>2]|0;
       FUNCTION_TABLE_viiiiiii[$94 & 127]($x,$y,$width,$height,6408,5121,$92);
       __ZN4gles22UploadBytesToGLTextureE16TextureDimensionjjiiiiPKv(2,3553,32856,0,$width,$height,0,$92);
       $95 = ($92|0)==(0|0);
       if ($95) {
        break;
       }
       __ZdaPv($92);
       break;
      }
      HEAP32[$$byval_copy>>2] = $66;
      __Z6FormatPKcz($1,1154816,$$byval_copy);
      $67 = HEAP8[$1>>0]|0;
      $68 = $67 & 1;
      $69 = ($68<<24>>24)==(0);
      if ($69) {
       $72 = (($1) + 1|0);
       $73 = $72;
      } else {
       $70 = (($1) + 8|0);
       $71 = HEAP32[$70>>2]|0;
       $73 = $71;
      }
      __THREW__ = 0;
      invoke_viiiiiiii(21,($73|0),0,(1154856|0),110,1,0,0,(0|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if (!($75)) {
       $76 = HEAP8[$1>>0]|0;
       $77 = $76 & 1;
       $78 = ($77<<24>>24)==(0);
       if ($78) {
        break;
       }
       $79 = (($1) + 8|0);
       $80 = HEAP32[$79>>2]|0;
       __ZdlPv($80);
       break;
      }
      $81 = ___cxa_find_matching_catch()|0;
      $82 = tempRet0;
      $83 = HEAP8[$1>>0]|0;
      $84 = $83 & 1;
      $85 = ($84<<24>>24)==(0);
      if ($85) {
       ___resumeException($81|0);
       // unreachable;
      }
      $86 = (($1) + 8|0);
      $87 = HEAP32[$86>>2]|0;
      __ZdlPv($87);
      ___resumeException($81|0);
      // unreachable;
     } else {
      label = 33;
     }
    } else {
     label = 33;
    }
   } else {
    label = 33;
   }
  } else {
   label = 33;
  }
 } while(0);
 if ((label|0) == 33) {
  $96 = (1147664 + 80|0);
  $97 = HEAP32[$96>>2]|0;
  FUNCTION_TABLE_viiiiiiii[$97 & 63](3553,0,0,0,$x,$y,$width,$height);
 }
 $98 = ($interim$0|0)==(0|0);
 if ($98) {
  STACKTOP = sp;return;
 }
 $99 = HEAP32[$curFBO>>2]|0;
 $100 = (1147664 + 16|0);
 $101 = HEAP32[$100>>2]|0;
 FUNCTION_TABLE_vii[$101 & 4095](36160,$99);
 __ZN4gles25HandleRenderSurfaceDeleteEP17RenderSurfaceBase($interim$0);
 __ZN4gles20DestroyRenderSurfaceEP17RenderSurfaceGLES($interim$0);
 STACKTOP = sp;return;
}
function __ZN4gles19ReadbackResolveMSAAEP17RenderSurfaceBaseS1_($dst,$src) {
 $dst = $dst|0;
 $src = $src|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $curFBO = 0, $discardColor = 0, $dstAttach = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $discardColor = sp;
 $curFBO = sp + 80|0;
 $dstAttach = sp + 8|0;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 89|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $4 = (($0) + 68|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   STACKTOP = sp;return;
  }
 }
 $7 = HEAP32[((1149672 + 32|0))>>2]|0;
 $8 = (($7) + 21|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = $discardColor;
  $12 = $11;
  HEAP32[$12>>2] = 0;
  $13 = (($11) + 4)|0;
  $14 = $13;
  HEAP32[$14>>2] = 0;
  __ZN4gles28InvalidateCurrentFramebufferEPbb($discardColor,1);
  $15 = HEAP32[((1149672 + 32|0))>>2]|0;
  $16 = (($15) + 21|0);
  HEAP8[$16>>0] = 0;
 }
 $17 = (1147664 + 212|0);
 $18 = HEAP32[$17>>2]|0;
 FUNCTION_TABLE_vii[$18 & 4095](36006,$curFBO);
 __ZN4gles18FillFBOAttachmentsEP20GfxRenderTargetSetupP17RenderSurfaceBaseS3_($dstAttach,$dst,0);
 $19 = (($dst) + 4|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($dst) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (1147664 + 16|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (__ZN4gles21GetFBOFromAttachmentsERK20GfxRenderTargetSetup($dstAttach)|0);
 FUNCTION_TABLE_vii[$24 & 4095](36009,$25);
 $26 = (1147664 + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$curFBO>>2]|0;
 FUNCTION_TABLE_vii[$27 & 4095](36008,$28);
 $29 = HEAP32[1152880>>2]|0;
 $30 = (($29) + 68|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = ($31<<24>>24)==(0);
 if ($32) {
  $35 = (1147616 + 20|0);
  $36 = HEAP32[$35>>2]|0;
  FUNCTION_TABLE_v[$36 & 1023]();
 } else {
  $33 = (1147664 + 420|0);
  $34 = HEAP32[$33>>2]|0;
  FUNCTION_TABLE_viiiiiiiiii[$34 & 15](0,0,$20,$22,0,0,$20,$22,16384,9728);
 }
 __ZN4gles28InvalidateCurrentFramebufferEv();
 STACKTOP = sp;return;
}
function __ZN4gles8internalL27PrepareReadback_ResolveMSAAEP17RenderSurfaceBase($dest) {
 $dest = $dest|0;
 var $$0$i$i = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $desc = 0, $interim$0 = 0, $samples$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy = sp + 32|0;
 $samples$i = sp;
 $desc = sp + 8|0;
 $0 = sp + 24|0;
 $1 = HEAP32[1149744>>2]|0;
 $2 = ($dest|0)==(0|0);
 L1: do {
  if ($2) {
   label = 8;
  } else {
   $3 = HEAP32[1152880>>2]|0;
   $4 = (($3) + 68|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    label = 8;
   } else {
    $7 = (($1) + 28|0);
    $8 = HEAP32[$7>>2]|0;
    switch ($8|0) {
    case 34836: case 34837: case 33328: case 33326: case 34842: case 34843: case 33327: case 33325:  {
     $$0$i$i = 1;
     break;
    }
    default: {
     $$0$i$i = 0;
    }
    }
    $9 = (($dest) + 28|0);
    $10 = HEAP32[$9>>2]|0;
    switch ($10|0) {
    case 34836: case 34837: case 33328: case 33326: case 34842: case 34843: case 33327: case 33325:  {
     if ($$0$i$i) {
      label = 8;
      break L1;
     } else {
      break L1;
     }
     break;
    }
    default: {
     if ($$0$i$i) {
      break L1;
     } else {
      label = 8;
      break L1;
     }
    }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $11 = (($1) + 23|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = ($12<<24>>24)==(0);
   if ($13) {
    $18 = (($1) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19>>>0)>(1);
    if ($20) {
     break;
    } else {
     $interim$0 = 0;
    }
    STACKTOP = sp;return ($interim$0|0);
   } else {
    HEAP32[$samples$i>>2] = 0;
    $14 = (1147664 + 212|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vii[$15 & 4095](32937,$samples$i);
    $16 = HEAP32[$samples$i>>2]|0;
    $17 = ($16|0)>(0);
    if ($17) {
     break;
    } else {
     $interim$0 = 0;
    }
    STACKTOP = sp;return ($interim$0|0);
   }
  }
 } while(0);
 $21 = HEAP32[1152880>>2]|0;
 $22 = (($21) + 89|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 if ($24) {
  $25 = (($21) + 68|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $interim$0 = 0;
   STACKTOP = sp;return ($interim$0|0);
  }
 }
 $28 = (($1) + 28|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (__ZN4gles25UnityRTFormatFromInternalEj($29)|0);
 $31 = (__Z16GetRealGfxDevicev()|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + 456|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (FUNCTION_TABLE_ii[$34 & 4095]($31)|0);
 $36 = (($1) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$desc>>2] = $37;
 $38 = (($desc) + 4|0);
 $39 = (($1) + 8|0);
 $40 = HEAP32[$39>>2]|0;
 HEAP32[$38>>2] = $40;
 $41 = (($desc) + 8|0);
 HEAP32[$41>>2] = 1;
 $42 = (($desc) + 12|0);
 HEAP32[$42>>2] = 0;
 HEAP32[$0>>2] = $35;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $43 = (__ZN4gles28CreateColorRenderSurfaceFullE19RenderTextureFormat9TextureIDj16TextureDimensionjRK17RenderSurfaceDesc($30,$$byval_copy,0,2,0,$desc)|0);
 __ZN4gles18FillFBOAttachmentsEP20GfxRenderTargetSetupP17RenderSurfaceBaseS3_($$byval_copy,$43,0);
 __ZN4gles19ReadbackResolveMSAAEP17RenderSurfaceBaseS1_($43,0);
 $44 = (1147664 + 16|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (__ZN4gles21GetFBOFromAttachmentsERK20GfxRenderTargetSetup($$byval_copy)|0);
 FUNCTION_TABLE_vii[$45 & 4095](36160,$46);
 $interim$0 = $43;
 STACKTOP = sp;return ($interim$0|0);
}
function __ZN4gles13ReadbackImageER14ImageReferenceiiiiii($image,$left,$bottom,$width,$height,$destX,$destY) {
 $image = $image|0;
 $left = $left|0;
 $bottom = $bottom|0;
 $width = $width|0;
 $height = $height|0;
 $destX = $destX|0;
 $destY = $destY|0;
 var $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $curFBO = 0, $dst = 0, $dstImagePtr = 0, $implReadFormat = 0;
 var $implReadType = 0, $or$cond = 0, $or$cond7 = 0, $result$0$off0 = 0, $src = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $curFBO = sp + 80|0;
 $implReadFormat = sp;
 $implReadType = sp + 4|0;
 $dstImagePtr = sp + 8|0;
 $src = sp + 40|0;
 $dst = sp + 60|0;
 HEAP32[$curFBO>>2] = 0;
 $0 = (1147664 + 212|0);
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vii[$1 & 4095](36006,$curFBO);
 $2 = (__ZN4gles8internalL27PrepareReadback_ResolveMSAAEP17RenderSurfaceBase(0)|0);
 $3 = (1147664 + 260|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095](3333,1);
 $5 = HEAP32[$image>>2]|0;
 $6 = ($5|0)==(5);
 if ($6) {
  $39 = 0;$42 = 0;
 } else {
  $7 = (__ZN4gles18FullInternalFormatE13TextureFormatb($5,0)|0);
  $8 = (__ZN4gles24DataTypeFromFullInternalEj($7)|0);
  $9 = (__ZN4gles29TextureFormatFromFullInternalEj($7)|0);
  $39 = $9;$42 = $8;
 }
 $10 = (1147664 + 212|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vii[$11 & 4095](35739,$implReadFormat);
 $12 = (1147664 + 212|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$13 & 4095](35738,$implReadType);
 HEAP32[$dstImagePtr>>2] = 0;
 $14 = (($dstImagePtr) + 4|0);
 $15 = (($image) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($image) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = Math_imul($18, $destY)|0;
 $$sum = (($19) + ($destX))|0;
 $20 = (($16) + ($$sum)|0);
 HEAP32[$14>>2] = $20;
 $21 = (($dstImagePtr) + 8|0);
 HEAP32[$21>>2] = 0;
 $22 = (($dstImagePtr) + 12|0);
 $23 = ($destX*3)|0;
 $$sum2 = (($19) + ($23))|0;
 $24 = (($16) + ($$sum2)|0);
 HEAP32[$22>>2] = $24;
 $25 = (($dstImagePtr) + 16|0);
 $26 = $destX << 2;
 $$sum3 = (($19) + ($26))|0;
 $27 = (($16) + ($$sum3)|0);
 HEAP32[$25>>2] = $27;
 $28 = (($dstImagePtr) + 20|0);
 HEAP32[$28>>2] = $27;
 $29 = (($dstImagePtr) + 24|0);
 $30 = $destX << 4;
 $$sum5 = (($19) + ($30))|0;
 $31 = (($16) + ($$sum5)|0);
 HEAP32[$29>>2] = $31;
 $32 = (($dstImagePtr) + 28|0);
 $33 = $destX << 1;
 $$sum6 = (($19) + ($33))|0;
 $34 = (($16) + ($$sum6)|0);
 HEAP32[$32>>2] = $34;
 $35 = (($dstImagePtr) + ($5<<2)|0);
 $36 = HEAP32[$35>>2]|0;
 L4: do {
  switch ($5|0) {
  case 6: case 1: case 3: case 5: case 4: case 7:  {
   $37 = HEAP32[$implReadFormat>>2]|0;
   $38 = ($39|0)==($37|0);
   $40 = HEAP32[$implReadType>>2]|0;
   $41 = ($42|0)==($40|0);
   $or$cond7 = $38 & $41;
   if ($or$cond7) {
    $43 = (($image) + 4|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ($44|0)==($width|0);
    if ($45) {
     $46 = (1147664 + 268|0);
     $47 = HEAP32[$46>>2]|0;
     FUNCTION_TABLE_viiiiiii[$47 & 127]($left,$bottom,$width,$height,$39,$42,$36);
     $result$0$off0 = 1;
     break L4;
    } else {
     $50 = $42;
    }
   } else {
    $50 = $40;
   }
   $48 = HEAP32[((640792 + 316|0))>>2]|0;
   $49 = ($50|0)==($48|0);
   $51 = ($5|0)==(6);
   $or$cond = $49 & $51;
   if ($or$cond) {
    $52 = (1147664 + 268|0);
    $53 = HEAP32[$52>>2]|0;
    FUNCTION_TABLE_viiiiiii[$53 & 127]($left,$bottom,$width,$height,$39,$42,$36);
    $result$0$off0 = 1;
    break L4;
   }
   $54 = (__ZN4gles18FullInternalFormatE13TextureFormatb(4,0)|0);
   $55 = (__ZN4gles24DataTypeFromFullInternalEj($54)|0);
   $56 = (__ZN4gles29TextureFormatFromFullInternalEj($54)|0);
   $57 = (__Z18CalculateImageSizeii13TextureFormat($width,$height,4)|0);
   $58 = ($57|0)>(-1);
   $59 = $58 ? $57 : -1;
   $60 = (__Znaj($59)|0);
   $61 = (1147664 + 268|0);
   $62 = HEAP32[$61>>2]|0;
   FUNCTION_TABLE_viiiiiii[$62 & 127]($left,$bottom,$width,$height,$56,$55,$60);
   $63 = (__Z29GetRowBytesFromWidthAndFormati13TextureFormat($width,4)|0);
   __ZN14ImageReferenceC2Eiii13TextureFormatPv($src,$width,$height,$63,4,$60);
   $64 = HEAP32[$17>>2]|0;
   $65 = HEAP32[$image>>2]|0;
   __ZN14ImageReferenceC2Eiii13TextureFormatPv($dst,$width,$height,$64,$65,$36);
   __ZN14ImageReference9BlitImageERKS_NS_8BlitModeE($dst,$src,0);
   $66 = ($60|0)==(0|0);
   if ($66) {
    $result$0$off0 = 1;
   } else {
    __ZdaPv($60);
    $result$0$off0 = 1;
   }
   break;
  }
  default: {
   $result$0$off0 = 0;
  }
  }
 } while(0);
 $67 = ($2|0)==(0|0);
 if ($67) {
  STACKTOP = sp;return ($result$0$off0|0);
 }
 $68 = HEAP32[$curFBO>>2]|0;
 $69 = (1147664 + 16|0);
 $70 = HEAP32[$69>>2]|0;
 FUNCTION_TABLE_vii[$70 & 4095](36160,$68);
 __ZN4gles25HandleRenderSurfaceDeleteEP17RenderSurfaceBase($2);
 __ZN4gles20DestroyRenderSurfaceEP17RenderSurfaceGLES($2);
 STACKTOP = sp;return ($result$0$off0|0);
}
function __ZN4gles30ReadbackDepthIntoRenderTextureEP17RenderSurfaceBase($dst) {
 $dst = $dst|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $attach = 0, $drawBuffers = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $attach = sp + 8|0;
 $drawBuffers = sp;
 $0 = HEAP32[1152880>>2]|0;
 $1 = (($0) + 68|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __ZN4gles18FillFBOAttachmentsEP20GfxRenderTargetSetupP17RenderSurfaceBaseS3_($attach,0,$dst);
 $4 = (__ZN4gles21GetFBOFromAttachmentsERK20GfxRenderTargetSetup($attach)|0);
 $5 = HEAP32[1149888>>2]|0;
 $6 = (1147664 + 16|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$7 & 4095](36008,$5);
 $8 = (1147664 + 16|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_vii[$9 & 4095](36009,$4);
 HEAP32[$drawBuffers>>2] = 0;
 $10 = (1147664 + 380|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_vi[$11 & 4095](0);
 $12 = (1147664 + 416|0);
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_vii[$13 & 4095](1,$drawBuffers);
 $14 = (($dst) + 4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($dst) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (1147664 + 420|0);
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_viiiiiiiiii[$19 & 15](0,0,$15,$17,0,0,$15,$17,256,9728);
 __ZN4gles16SetGlesFBODirectERK20GfxRenderTargetSetup(1149672);
 STACKTOP = sp;return;
}
function __ZN25TransformFeedbackSkinning31CleanupTransformFeedbackShadersEv() {
 var $$0$i$i$i$i = 0, $$0$i$i$i$i$i = 0, $$01$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1154864>>2]|0;
 $1 = ($0|0)==(((1154864 + 4|0))|0);
 if (!($1)) {
  $3 = $0;
  while(1) {
   $2 = (($3) + 24|0);
   $4 = HEAP32[$2>>2]|0;
   $5 = (($3) + 28|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4|0)==(0);
   if (!($7)) {
    $8 = (1147664 + 104|0);
    $9 = HEAP32[$8>>2]|0;
    FUNCTION_TABLE_vi[$9 & 4095]($4);
   }
   $10 = ($6|0)==(0);
   if (!($10)) {
    $11 = (1147664 + 112|0);
    $12 = HEAP32[$11>>2]|0;
    FUNCTION_TABLE_vi[$12 & 4095]($6);
   }
   $13 = (($3) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    $$01$i$i$i$i = $3;
    while(1) {
     $18 = (($$01$i$i$i$i) + 8|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==($$01$i$i$i$i|0);
     if ($21) {
      $$0$i$i$i$i = $19;
      break;
     } else {
      $$01$i$i$i$i = $19;
     }
    }
   } else {
    $$0$i$i$i$i$i = $14;
    while(1) {
     $16 = HEAP32[$$0$i$i$i$i$i>>2]|0;
     $17 = ($16|0)==(0|0);
     if ($17) {
      $$0$i$i$i$i = $$0$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i = $16;
     }
    }
   }
   $22 = ($$0$i$i$i$i|0)==(((1154864 + 4|0))|0);
   if ($22) {
    break;
   } else {
    $3 = $$0$i$i$i$i;
   }
  }
 }
 $23 = HEAP32[((1154864 + 4|0))>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIy8TFShaderEENS_19__map_value_compareIyS3_NS_4lessIyEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE(1154864,$23);
 HEAP32[((1154864 + 8|0))>>2] = 0;
 HEAP32[1154864>>2] = ((1154864 + 4|0));
 HEAP32[((1154864 + 4|0))>>2] = 0;
 $24 = HEAP32[1154880>>2]|0;
 $25 = ($24|0)==(0);
 if ($25) {
  STACKTOP = sp;return;
 }
 $26 = (1147664 + 112|0);
 $27 = HEAP32[$26>>2]|0;
 FUNCTION_TABLE_vi[$27 & 4095]($24);
 HEAP32[1154880>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN31TransformFeedbackSkinPoseBuffer6UpdateEPK10Matrix4x4fi($this,$boneMatrices,$boneCount) {
 $this = $this|0;
 $boneMatrices = $boneMatrices|0;
 $boneCount = $boneCount|0;
 var $$boneCount = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = Math_fround(0), $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = Math_fround(0), $115 = 0, $116 = 0, $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0);
 var $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = Math_fround(0), $__new_last2$i$i$i$i$i$i$i = 0, $dest$09 = 0, $exitcond = 0, $i$08 = 0, $or$cond$i2 = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $smax = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($boneCount) + 7)|0;
 $1 = $0 & -8;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 $$pre = (($this) + 8|0);
 if (!($4)) {
  $5 = HEAP32[$$pre>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = HEAP32[$5>>2]|0;
   $8 = (($7) + 24|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (FUNCTION_TABLE_iii[$9 & 4095]($5,$1)|0);
   if (!($10)) {
    $11 = HEAP32[$$pre>>2]|0;
    $12 = ($11|0)==(0|0);
    if (!($12)) {
     $13 = HEAP32[$11>>2]|0;
     $14 = (($13) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     __THREW__ = 0;
     invoke_vi($15|0,($11|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      $18 = ___cxa_find_matching_catch()|0;
      $19 = tempRet0;
      ___cxa_call_unexpected(($18|0));
      // unreachable;
     }
    }
    HEAP32[$$pre>>2] = 0;
   }
  }
 }
 HEAP32[$2>>2] = $1;
 $20 = HEAP32[$$pre>>2]|0;
 $21 = ($20|0)==(0|0);
 do {
  if ($21) {
   $22 = HEAP32[((640792 + 300|0))>>2]|0;
   $23 = (($22|0) / 4)&-1;
   $24 = (($23) + -10)|0;
   $25 = (($24|0) / 3)&-1;
   $26 = ($25>>>0)>($1>>>0);
   if ($26) {
    $27 = (__Znwj(20)|0);
    $28 = (($27) + 4|0);
    HEAP32[$28>>2] = 0;
    HEAP32[$27>>2] = ((1157392 + 8|0));
    $29 = (($27) + 8|0);
    HEAP32[$29>>2] = 0;
    $30 = (($27) + 12|0);
    HEAP32[$30>>2] = 0;
    $31 = (($27) + 16|0);
    HEAP32[$31>>2] = 0;
    HEAP32[$$pre>>2] = $27;
    $75 = $27;
    break;
   }
   $32 = HEAP8[((640792 + 345|0))>>0]|0;
   $33 = ($32<<24>>24)==(0);
   if (!($33)) {
    $34 = HEAP32[((640792 + 296|0))>>2]|0;
    $35 = (($34>>>0) / 48)&-1;
    $36 = ($35>>>0)<($1>>>0);
    if (!($36)) {
     $37 = (__Znwj(12)|0);
     $38 = (($37) + 4|0);
     HEAP32[$38>>2] = 1;
     HEAP32[$37>>2] = ((1157352 + 8|0));
     $39 = (($37) + 8|0);
     HEAP32[$39>>2] = 0;
     HEAP32[$$pre>>2] = $37;
     $75 = $37;
     break;
    }
   }
   $40 = (__Znwj(52)|0);
   $41 = (($40) + 4|0);
   HEAP32[$41>>2] = 2;
   HEAP32[$40>>2] = ((1157312 + 8|0));
   $42 = (($40) + 8|0);
   HEAP32[$42>>2] = 0;
   $43 = (($40) + 12|0);
   HEAP32[$43>>2] = 0;
   $44 = (($40) + 16|0);
   HEAP32[$44>>2] = 0;
   $45 = (($40) + 32|0);
   HEAP32[$45>>2] = 0;
   $46 = (($40) + 36|0);
   HEAP32[$46>>2] = 0;
   $47 = (1147664 + 188|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = (($40) + 20|0);
   __THREW__ = 0;
   invoke_vii($48|0,3,($49|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if (!($51)) {
    $61 = (($40) + 40|0);
    ;HEAP32[$61+0>>2]=0|0;HEAP32[$61+4>>2]=0|0;HEAP32[$61+8>>2]=0|0;
    $62 = HEAP32[$$pre>>2]|0;
    $63 = ($62|0)==($40|0);
    $64 = ($62|0)==(0|0);
    $or$cond$i2 = $63 | $64;
    if (!($or$cond$i2)) {
     $65 = HEAP32[$62>>2]|0;
     $66 = (($65) + 4|0);
     $67 = HEAP32[$66>>2]|0;
     __THREW__ = 0;
     invoke_vi($67|0,($62|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      $70 = ___cxa_find_matching_catch()|0;
      $71 = tempRet0;
      ___cxa_call_unexpected(($70|0));
      // unreachable;
     }
    }
    HEAP32[$$pre>>2] = $40;
    $75 = $40;
    break;
   }
   $52 = ___cxa_find_matching_catch()|0;
   $53 = tempRet0;
   $54 = HEAP32[$42>>2]|0;
   $55 = ($54|0)==(0|0);
   if ($55) {
    __ZdlPv($40);
    ___resumeException($52|0);
    // unreachable;
   }
   $56 = HEAP32[$43>>2]|0;
   $57 = ($56|0)==($54|0);
   if (!($57)) {
    $__new_last2$i$i$i$i$i$i$i = $54;
    $scevgep$i$i$i$i$i$i$i = (($56) + -4|0);
    $58 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
    $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($58)|0);
    $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
    $59 = $uglygep3$i$i$i$i$i$i$i >>> 2;
    $60 = $59 ^ -1;
    $scevgep4$i$i$i$i$i$i$i = (($56) + ($60<<2)|0);
    HEAP32[$43>>2] = $scevgep4$i$i$i$i$i$i$i;
   }
   __ZdlPv($54);
   __ZdlPv($40);
   ___resumeException($52|0);
   // unreachable;
  } else {
   $75 = $20;
  }
 } while(0);
 $72 = HEAP32[$2>>2]|0;
 $73 = ($72*12)|0;
 $74 = HEAP32[$75>>2]|0;
 $76 = (($74) + 8|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = (FUNCTION_TABLE_iii[$77 & 4095]($75,$73)|0);
 $79 = HEAP32[$2>>2]|0;
 $80 = ($79|0)<($boneCount|0);
 $$boneCount = $80 ? $79 : $boneCount;
 $81 = ($$boneCount|0)>(0);
 if (!($81)) {
  $123 = HEAP32[$$pre>>2]|0;
  $124 = HEAP32[$123>>2]|0;
  $125 = (($124) + 12|0);
  $126 = HEAP32[$125>>2]|0;
  FUNCTION_TABLE_vi[$126 & 4095]($123);
  STACKTOP = sp;return;
 }
 $82 = $79 ^ -1;
 $83 = $boneCount ^ -1;
 $84 = ($82|0)>($83|0);
 $smax = $84 ? $82 : $83;
 $85 = $smax ^ -1;
 $dest$09 = $78;$i$08 = 0;
 while(1) {
  $86 = (($boneMatrices) + ($i$08<<6)|0);
  $87 = Math_fround(HEAPF32[$86>>2]);
  $88 = (($dest$09) + 4|0);
  HEAPF32[$dest$09>>2] = $87;
  $89 = ((($boneMatrices) + ($i$08<<6)|0) + 16|0);
  $90 = Math_fround(HEAPF32[$89>>2]);
  $91 = (($dest$09) + 8|0);
  HEAPF32[$88>>2] = $90;
  $92 = ((($boneMatrices) + ($i$08<<6)|0) + 32|0);
  $93 = Math_fround(HEAPF32[$92>>2]);
  $94 = (($dest$09) + 12|0);
  HEAPF32[$91>>2] = $93;
  $95 = ((($boneMatrices) + ($i$08<<6)|0) + 48|0);
  $96 = Math_fround(HEAPF32[$95>>2]);
  $97 = (($dest$09) + 16|0);
  HEAPF32[$94>>2] = $96;
  $98 = ((($boneMatrices) + ($i$08<<6)|0) + 4|0);
  $99 = Math_fround(HEAPF32[$98>>2]);
  $100 = (($dest$09) + 20|0);
  HEAPF32[$97>>2] = $99;
  $101 = ((($boneMatrices) + ($i$08<<6)|0) + 20|0);
  $102 = Math_fround(HEAPF32[$101>>2]);
  $103 = (($dest$09) + 24|0);
  HEAPF32[$100>>2] = $102;
  $104 = ((($boneMatrices) + ($i$08<<6)|0) + 36|0);
  $105 = Math_fround(HEAPF32[$104>>2]);
  $106 = (($dest$09) + 28|0);
  HEAPF32[$103>>2] = $105;
  $107 = ((($boneMatrices) + ($i$08<<6)|0) + 52|0);
  $108 = Math_fround(HEAPF32[$107>>2]);
  $109 = (($dest$09) + 32|0);
  HEAPF32[$106>>2] = $108;
  $110 = ((($boneMatrices) + ($i$08<<6)|0) + 8|0);
  $111 = Math_fround(HEAPF32[$110>>2]);
  $112 = (($dest$09) + 36|0);
  HEAPF32[$109>>2] = $111;
  $113 = ((($boneMatrices) + ($i$08<<6)|0) + 24|0);
  $114 = Math_fround(HEAPF32[$113>>2]);
  $115 = (($dest$09) + 40|0);
  HEAPF32[$112>>2] = $114;
  $116 = ((($boneMatrices) + ($i$08<<6)|0) + 40|0);
  $117 = Math_fround(HEAPF32[$116>>2]);
  $118 = (($dest$09) + 44|0);
  HEAPF32[$115>>2] = $117;
  $119 = ((($boneMatrices) + ($i$08<<6)|0) + 56|0);
  $120 = Math_fround(HEAPF32[$119>>2]);
  $121 = (($dest$09) + 48|0);
  HEAPF32[$118>>2] = $120;
  $122 = (($i$08) + 1)|0;
  $exitcond = ($122|0)==($85|0);
  if ($exitcond) {
   break;
  } else {
   $dest$09 = $121;$i$08 = $122;
  }
 }
 $123 = HEAP32[$$pre>>2]|0;
 $124 = HEAP32[$123>>2]|0;
 $125 = (($124) + 12|0);
 $126 = HEAP32[$125>>2]|0;
 FUNCTION_TABLE_vi[$126 & 4095]($123);
 STACKTOP = sp;return;
}
function __ZN25TransformFeedbackSkinning8SkinMeshERK18VertexStreamSourceP12VertexBufferP17GPUSkinPoseBufferS4_iijb($sourceMesh,$skinBuffer,$poseBuffer,$destBuffer,$vertexCount,$bonesPerVertex,$channelMask,$lastThisFrame) {
 $sourceMesh = $sourceMesh|0;
 $skinBuffer = $skinBuffer|0;
 $poseBuffer = $poseBuffer|0;
 $destBuffer = $destBuffer|0;
 $vertexCount = $vertexCount|0;
 $bonesPerVertex = $bonesPerVertex|0;
 $channelMask = $channelMask|0;
 $lastThisFrame = $lastThisFrame|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i$i = 0, $$0$i$i$i$i$i$i = 0, $$0$i$i1 = 0, $$0$ph5$i$i$i$i = 0, $$0$ph7$i$i$i$i = 0, $$01$i$i = 0, $$01$i$i$i = 0, $$01$i$i$i$i$i = 0, $$01$ph6$i$in$i$i$i = 0, $$013$i$in$i$i$i = 0, $$05$i = 0, $$23$i = 0, $$27$i = 0, $$3$i = 0, $$34$i = 0, $$pre$i = 0, $$pre$i$i$i = 0, $$pre8$i = 0;
 var $$sink$i$i$i$index11 = 0, $$sink$i$index21 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $__nd$0$in$i$i$i = 0, $__p$0$i$i$i$i$i = 0, $code$i = 0, $eh$lpad$body$i$i$indexZ2D = 0, $eh$lpad$body$i$index4Z2D = 0, $eh$lpad$body$i$indexZ2D = 0, $len$i = 0, $len2$i = 0, $len4$i = 0, $meshOffset$0$i$i = 0, $shaderLen$i = 0, $shadercode$i = 0, $ss$i$i = 0, $status$i = 0, $temp$i = 0, $temp1$i = 0, $temp3$i = 0, $vararg_buffer28 = 0, $varyingCount$0$i = 0, $varyingCount$1$i = 0;
 var $varyingCount$2$i = 0, $varyings$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1808|0;
 $vararg_buffer28 = sp + 40|0;
 $ss$i$i = sp + 136|0;
 $0 = sp + 24|0;
 $1 = sp + 128|0;
 $2 = sp;
 $status$i = sp + 120|0;
 $shaderLen$i = sp + 116|0;
 $code$i = sp + 112|0;
 $temp$i = sp + 784|0;
 $len$i = sp + 92|0;
 $shadercode$i = sp + 80|0;
 $temp1$i = sp + 1296|0;
 $len2$i = sp + 76|0;
 $varyings$i = sp + 96|0;
 $temp3$i = sp + 272|0;
 $len4$i = sp + 108|0;
 $3 = HEAP32[$poseBuffer>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($poseBuffer)|0);
 $6 = (($poseBuffer) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $bonesPerVertex << 16;
 $11 = (_i64Add(($10|0),0,($channelMask|0),0)|0);
 $12 = tempRet0;
 $13 = $9 << 19;
 $14 = ($13|0)<(0);
 $15 = $14 << 31 >> 31;
 $16 = $5 << 25;
 $17 = (_i64Add(($11|0),($12|0),($16|0),0)|0);
 $18 = tempRet0;
 $19 = (_i64Add(($17|0),($18|0),($13|0),($15|0))|0);
 $20 = tempRet0;
 $21 = HEAP32[((1154864 + 4|0))>>2]|0;
 $22 = ($21|0)==(0|0);
 if ($22) {
  label = 9;
 } else {
  $$0$ph7$i$i$i$i = ((1154864 + 4|0));$$01$ph6$i$in$i$i$i = $21;
  L2: while(1) {
   $$013$i$in$i$i$i = $$01$ph6$i$in$i$i$i;
   while(1) {
    $23 = (($$013$i$in$i$i$i) + 16|0);
    $24 = $23;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + 4)|0;
    $28 = $27;
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29>>>0)<($20>>>0);
    $31 = ($29|0)==($20|0);
    $32 = ($26>>>0)<($19>>>0);
    $33 = $31 & $32;
    $34 = $30 | $33;
    if (!($34)) {
     break;
    }
    $37 = (($$013$i$in$i$i$i) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)==(0|0);
    if ($39) {
     $$0$ph5$i$i$i$i = $$0$ph7$i$i$i$i;
     break L2;
    } else {
     $$013$i$in$i$i$i = $38;
    }
   }
   $35 = HEAP32[$$013$i$in$i$i$i>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    $$0$ph5$i$i$i$i = $$013$i$in$i$i$i;
    break;
   } else {
    $$0$ph7$i$i$i$i = $$013$i$in$i$i$i;$$01$ph6$i$in$i$i$i = $35;
   }
  }
  $40 = ($$0$ph5$i$i$i$i|0)==(((1154864 + 4|0))|0);
  if ($40) {
   label = 9;
  } else {
   $41 = (($$0$ph5$i$i$i$i) + 16|0);
   $42 = $41;
   $43 = $42;
   $44 = HEAP32[$43>>2]|0;
   $45 = (($42) + 4)|0;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = ($20>>>0)<($47>>>0);
   $49 = ($20|0)==($47|0);
   $50 = ($19>>>0)<($44>>>0);
   $51 = $49 & $50;
   $52 = $48 | $51;
   if ($52) {
    label = 9;
   } else {
    $53 = (($$0$ph5$i$i$i$i) + 24|0);
    $$27$i = $53;
   }
  }
 }
 L11: do {
  if ((label|0) == 9) {
   HEAP32[$status$i>>2] = 0;
   HEAP32[$shaderLen$i>>2] = 0;
   $54 = HEAP32[1154880>>2]|0;
   $55 = ($54|0)==(0);
   if ($55) {
    $56 = (1147664 + 88|0);
    $57 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    $58 = (invoke_ii($57|0,35632)|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 17;
    } else {
     HEAP32[1154880>>2] = $58;
     HEAP32[$shaderLen$i>>2] = 111;
     HEAP32[$code$i>>2] = 1154904;
     $61 = (1147664 + 280|0);
     $62 = HEAP32[$61>>2]|0;
     __THREW__ = 0;
     invoke_viiii($62|0,($58|0),1,($code$i|0),($shaderLen$i|0));
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      label = 17;
     } else {
      $65 = (1147664 + 68|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = HEAP32[1154880>>2]|0;
      __THREW__ = 0;
      invoke_vi($66|0,($67|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 17;
      } else {
       $70 = (1147664 + 224|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = HEAP32[1154880>>2]|0;
       __THREW__ = 0;
       invoke_viii($71|0,($72|0),35713,($status$i|0));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 17;
       } else {
        $75 = HEAP32[$status$i>>2]|0;
        $76 = ($75|0)==(1);
        if ($76) {
         label = 19;
        } else {
         _memset(($temp$i|0),0,512)|0;
         HEAP32[$len$i>>2] = 512;
         $77 = (1147664 + 228|0);
         $78 = HEAP32[$77>>2]|0;
         $79 = HEAP32[1154880>>2]|0;
         __THREW__ = 0;
         invoke_viiii($78|0,($79|0),512,($len$i|0),($temp$i|0));
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if ($81) {
          label = 17;
         } else {
          __THREW__ = 0;
          HEAP32[$vararg_buffer28>>2] = $temp$i;
          invoke_vii(2587,(1155016|0),($vararg_buffer28|0));
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if ($83) {
           label = 17;
          } else {
           $$27$i = 0;
           break;
          }
         }
        }
       }
      }
     }
    }
   } else {
    label = 19;
   }
   L21: do {
    if ((label|0) == 19) {
     $86 = (1147664 + 84|0);
     $87 = HEAP32[$86>>2]|0;
     __THREW__ = 0;
     $88 = (invoke_i($87|0)|0);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 17;
     } else {
      $91 = (1147664 + 88|0);
      $92 = HEAP32[$91>>2]|0;
      __THREW__ = 0;
      $93 = (invoke_ii($92|0,35633)|0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       label = 17;
      } else {
       $96 = (($ss$i$i) + 56|0);
       $97 = (($ss$i$i) + 4|0);
       HEAP32[$ss$i$i>>2] = ((390272 + 12|0));
       $98 = (($ss$i$i) + 56|0);
       HEAP32[$98>>2] = ((390272 + 32|0));
       $99 = (($ss$i$i) + 56|0);
       __THREW__ = 0;
       invoke_vii(2480,($99|0),($97|0));
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       do {
        if ($101) {
         $131 = ___cxa_find_matching_catch()|0;
         $132 = tempRet0;
         $$01$i$i$i = $131;$$sink$i$i$i$index11 = $132;
        } else {
         $102 = (($ss$i$i) + 128|0);
         HEAP32[$102>>2] = 0;
         $103 = (($ss$i$i) + 132|0);
         HEAP32[$103>>2] = -1;
         HEAP32[$ss$i$i>>2] = ((390232 + 12|0));
         HEAP32[$96>>2] = ((390232 + 32|0));
         HEAP32[$97>>2] = ((3090568 + 8|0));
         $104 = (($ss$i$i) + 8|0);
         __ZNSt3__16localeC2Ev($104);
         $105 = (($ss$i$i) + 12|0);
         ;HEAP32[$105+0>>2]=0|0;HEAP32[$105+4>>2]=0|0;HEAP32[$105+8>>2]=0|0;HEAP32[$105+12>>2]=0|0;HEAP32[$105+16>>2]=0|0;HEAP32[$105+20>>2]=0|0;
         HEAP32[$97>>2] = ((225848 + 8|0));
         $106 = (($ss$i$i) + 36|0);
         $107 = (($ss$i$i) + 52|0);
         ;HEAP32[$106+0>>2]=0|0;HEAP32[$106+4>>2]=0|0;HEAP32[$106+8>>2]=0|0;HEAP32[$106+12>>2]=0|0;
         HEAP32[$107>>2] = 16;
         ;HEAP32[$vararg_buffer28+0>>2]=0|0;HEAP32[$vararg_buffer28+4>>2]=0|0;HEAP32[$vararg_buffer28+8>>2]=0|0;
         __THREW__ = 0;
         invoke_vii(2481,($97|0),($vararg_buffer28|0));
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          $115 = ___cxa_find_matching_catch()|0;
          $116 = tempRet0;
          $117 = HEAP8[$vararg_buffer28>>0]|0;
          $118 = $117 & 1;
          $119 = ($118<<24>>24)==(0);
          if (!($119)) {
           $120 = (($vararg_buffer28) + 8|0);
           $121 = HEAP32[$120>>2]|0;
           __ZdlPv($121);
          }
          $122 = HEAP8[$106>>0]|0;
          $123 = $122 & 1;
          $124 = ($123<<24>>24)==(0);
          if (!($124)) {
           $125 = (($ss$i$i) + 44|0);
           $126 = HEAP32[$125>>2]|0;
           __ZdlPv($126);
          }
          HEAP32[$97>>2] = ((3090568 + 8|0));
          __THREW__ = 0;
          invoke_vi(3299,($104|0));
          $127 = __THREW__; __THREW__ = 0;
          $128 = $127&1;
          if ($128) {
           $129 = ___cxa_find_matching_catch(0|0)|0;
           $130 = tempRet0;
           ___clang_call_terminate($129);
           // unreachable;
          } else {
           $$01$i$i$i = $115;$$sink$i$i$i$index11 = $116;
           break;
          }
         }
         $110 = HEAP8[$vararg_buffer28>>0]|0;
         $111 = $110 & 1;
         $112 = ($111<<24>>24)==(0);
         if (!($112)) {
          $113 = (($vararg_buffer28) + 8|0);
          $114 = HEAP32[$113>>2]|0;
          __ZdlPv($114);
         }
         __THREW__ = 0;
         $137 = (invoke_iii(2239,($ss$i$i|0),(1155304|0))|0);
         $138 = __THREW__; __THREW__ = 0;
         $139 = $138&1;
         do {
          if ($139) {
           label = 45;
          } else {
           __THREW__ = 0;
           $140 = (invoke_iii(2721,($137|0),($5|0))|0);
           $141 = __THREW__; __THREW__ = 0;
           $142 = $141&1;
           if ($142) {
            label = 45;
           } else {
            __THREW__ = 0;
            $143 = (invoke_iii(2239,($140|0),(1155352|0))|0);
            $144 = __THREW__; __THREW__ = 0;
            $145 = $144&1;
            if ($145) {
             label = 45;
            } else {
             __THREW__ = 0;
             $146 = (invoke_iii(2240,($143|0),0)|0);
             $147 = __THREW__; __THREW__ = 0;
             $148 = $147&1;
             if ($148) {
              label = 45;
             } else {
              __THREW__ = 0;
              (invoke_iii(2239,($146|0),(1155504|0))|0);
              $149 = __THREW__; __THREW__ = 0;
              $150 = $149&1;
              if ($150) {
               label = 45;
              } else {
               $151 = $channelMask & 1;
               $152 = ($151|0)!=(0);
               if ($152) {
                __THREW__ = 0;
                $153 = (invoke_iii(2239,($ss$i$i|0),(1155528|0))|0);
                $154 = __THREW__; __THREW__ = 0;
                $155 = $154&1;
                if ($155) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $156 = (invoke_iii(2240,($153|0),2)|0);
                $157 = __THREW__; __THREW__ = 0;
                $158 = $157&1;
                if ($158) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($156|0),(1155552|0))|0);
                $159 = __THREW__; __THREW__ = 0;
                $160 = $159&1;
                if ($160) {
                 label = 45;
                 break;
                }
               }
               $163 = $channelMask & 7;
               $164 = ($163|0)!=(0);
               if ($164) {
                __THREW__ = 0;
                $165 = (invoke_iii(2239,($ss$i$i|0),(1155528|0))|0);
                $166 = __THREW__; __THREW__ = 0;
                $167 = $166&1;
                if ($167) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $168 = (invoke_iii(2240,($165|0),3)|0);
                $169 = __THREW__; __THREW__ = 0;
                $170 = $169&1;
                if ($170) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($168|0),(1155576|0))|0);
                $171 = __THREW__; __THREW__ = 0;
                $172 = $171&1;
                if ($172) {
                 label = 45;
                 break;
                }
               }
               if ((($bonesPerVertex|0) == 2)) {
                __THREW__ = 0;
                $181 = (invoke_iii(2239,($ss$i$i|0),(1155528|0))|0);
                $182 = __THREW__; __THREW__ = 0;
                $183 = $182&1;
                if ($183) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $184 = (invoke_iii(2240,($181|0),4)|0);
                $185 = __THREW__; __THREW__ = 0;
                $186 = $185&1;
                if ($186) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($184|0),(1155632|0))|0);
                $187 = __THREW__; __THREW__ = 0;
                $188 = $187&1;
                if ($188) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $189 = (invoke_iii(2239,($ss$i$i|0),(1155528|0))|0);
                $190 = __THREW__; __THREW__ = 0;
                $191 = $190&1;
                if ($191) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $192 = (invoke_iii(2240,($189|0),5)|0);
                $193 = __THREW__; __THREW__ = 0;
                $194 = $193&1;
                if ($194) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($192|0),(1155664|0))|0);
                $195 = __THREW__; __THREW__ = 0;
                $196 = $195&1;
                if ($196) {
                 label = 45;
                 break;
                }
               } else if ((($bonesPerVertex|0) == 4)) {
                __THREW__ = 0;
                $197 = (invoke_iii(2239,($ss$i$i|0),(1155528|0))|0);
                $198 = __THREW__; __THREW__ = 0;
                $199 = $198&1;
                if ($199) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $200 = (invoke_iii(2240,($197|0),4)|0);
                $201 = __THREW__; __THREW__ = 0;
                $202 = $201&1;
                if ($202) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($200|0),(1155696|0))|0);
                $203 = __THREW__; __THREW__ = 0;
                $204 = $203&1;
                if ($204) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $205 = (invoke_iii(2239,($ss$i$i|0),(1155528|0))|0);
                $206 = __THREW__; __THREW__ = 0;
                $207 = $206&1;
                if ($207) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $208 = (invoke_iii(2240,($205|0),5)|0);
                $209 = __THREW__; __THREW__ = 0;
                $210 = $209&1;
                if ($210) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($208|0),(1155728|0))|0);
                $211 = __THREW__; __THREW__ = 0;
                $212 = $211&1;
                if ($212) {
                 label = 45;
                 break;
                }
               } else {
                __THREW__ = 0;
                $173 = (invoke_iii(2239,($ss$i$i|0),(1155528|0))|0);
                $174 = __THREW__; __THREW__ = 0;
                $175 = $174&1;
                if ($175) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                $176 = (invoke_iii(2240,($173|0),4)|0);
                $177 = __THREW__; __THREW__ = 0;
                $178 = $177&1;
                if ($178) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($176|0),(1155600|0))|0);
                $179 = __THREW__; __THREW__ = 0;
                $180 = $179&1;
                if ($180) {
                 label = 45;
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_iii(2239,($ss$i$i|0),(1155760|0))|0);
               $213 = __THREW__; __THREW__ = 0;
               $214 = $213&1;
               if ($214) {
                label = 45;
               } else {
                if ($152) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1155784|0))|0);
                 $215 = __THREW__; __THREW__ = 0;
                 $216 = $215&1;
                 if ($216) {
                  label = 45;
                  break;
                 }
                }
                if ($164) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1155808|0))|0);
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  label = 45;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_iii(2239,($ss$i$i|0),(1155832|0))|0);
                $219 = __THREW__; __THREW__ = 0;
                $220 = $219&1;
                if ($220) {
                 label = 45;
                 break;
                }
                if ((($9|0) == 0)) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1155840|0))|0);
                 $221 = __THREW__; __THREW__ = 0;
                 $222 = $221&1;
                 if ($222) {
                  label = 45;
                  break;
                 }
                } else if ((($9|0) == 1)) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1155880|0))|0);
                 $223 = __THREW__; __THREW__ = 0;
                 $224 = $223&1;
                 if ($224) {
                  label = 45;
                  break;
                 }
                } else {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1155944|0))|0);
                 $225 = __THREW__; __THREW__ = 0;
                 $226 = $225&1;
                 if ($226) {
                  label = 45;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_iii(2239,($ss$i$i|0),(1155976|0))|0);
                $227 = __THREW__; __THREW__ = 0;
                $228 = $227&1;
                if ($228) {
                 label = 45;
                 break;
                }
                if ((($9|0) == 0)) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156008|0))|0);
                 $229 = __THREW__; __THREW__ = 0;
                 $230 = $229&1;
                 if ($230) {
                  label = 45;
                  break;
                 }
                } else if ((($9|0) == 1)) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156088|0))|0);
                 $231 = __THREW__; __THREW__ = 0;
                 $232 = $231&1;
                 if ($232) {
                  label = 45;
                  break;
                 }
                } else {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156192|0))|0);
                 $233 = __THREW__; __THREW__ = 0;
                 $234 = $233&1;
                 if ($234) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156200|0))|0);
                 $235 = __THREW__; __THREW__ = 0;
                 $236 = $235&1;
                 if ($236) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156288|0))|0);
                 $237 = __THREW__; __THREW__ = 0;
                 $238 = $237&1;
                 if ($238) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156376|0))|0);
                 $239 = __THREW__; __THREW__ = 0;
                 $240 = $239&1;
                 if ($240) {
                  label = 45;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_iii(2239,($ss$i$i|0),(1156464|0))|0);
                $241 = __THREW__; __THREW__ = 0;
                $242 = $241&1;
                if ($242) {
                 label = 45;
                 break;
                }
                if ((($bonesPerVertex|0) == 2)) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156608|0))|0);
                 $245 = __THREW__; __THREW__ = 0;
                 $246 = $245&1;
                 if ($246) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156688|0))|0);
                 $247 = __THREW__; __THREW__ = 0;
                 $248 = $247&1;
                 if ($248) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156720|0))|0);
                 $249 = __THREW__; __THREW__ = 0;
                 $250 = $249&1;
                 if ($250) {
                  label = 45;
                  break;
                 }
                } else if ((($bonesPerVertex|0) == 4)) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156608|0))|0);
                 $251 = __THREW__; __THREW__ = 0;
                 $252 = $251&1;
                 if ($252) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156688|0))|0);
                 $253 = __THREW__; __THREW__ = 0;
                 $254 = $253&1;
                 if ($254) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156720|0))|0);
                 $255 = __THREW__; __THREW__ = 0;
                 $256 = $255&1;
                 if ($256) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156800|0))|0);
                 $257 = __THREW__; __THREW__ = 0;
                 $258 = $257&1;
                 if ($258) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156832|0))|0);
                 $259 = __THREW__; __THREW__ = 0;
                 $260 = $259&1;
                 if ($260) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156912|0))|0);
                 $261 = __THREW__; __THREW__ = 0;
                 $262 = $261&1;
                 if ($262) {
                  label = 45;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156944|0))|0);
                 $263 = __THREW__; __THREW__ = 0;
                 $264 = $263&1;
                 if ($264) {
                  label = 45;
                  break;
                 }
                } else {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1156552|0))|0);
                 $243 = __THREW__; __THREW__ = 0;
                 $244 = $243&1;
                 if ($244) {
                  label = 45;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_iii(2239,($ss$i$i|0),(1157024|0))|0);
                $265 = __THREW__; __THREW__ = 0;
                $266 = $265&1;
                if ($266) {
                 label = 45;
                 break;
                }
                if ($152) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1157112|0))|0);
                 $267 = __THREW__; __THREW__ = 0;
                 $268 = $267&1;
                 if ($268) {
                  label = 45;
                  break;
                 }
                }
                if ($164) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($ss$i$i|0),(1157200|0))|0);
                 $269 = __THREW__; __THREW__ = 0;
                 $270 = $269&1;
                 if ($270) {
                  label = 45;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_iii(2239,($ss$i$i|0),(1157304|0))|0);
                $271 = __THREW__; __THREW__ = 0;
                $272 = $271&1;
                if ($272) {
                 label = 45;
                 break;
                }
                __THREW__ = 0;
                invoke_vii(2482,($0|0),($97|0));
                $273 = __THREW__; __THREW__ = 0;
                $274 = $273&1;
                if ($274) {
                 label = 45;
                 break;
                }
                $275 = HEAP8[$0>>0]|0;
                $276 = $275 & 1;
                $277 = ($276<<24>>24)==(0);
                if ($277) {
                 $280 = (($0) + 1|0);
                 $281 = $280;
                } else {
                 $278 = (($0) + 8|0);
                 $279 = HEAP32[$278>>2]|0;
                 $281 = $279;
                }
                $282 = (_strlen(($281|0))|0);
                $283 = ($282>>>0)>(4294967279);
                do {
                 if ($283) {
                  __THREW__ = 0;
                  invoke_vi(3309,0);
                  $284 = __THREW__; __THREW__ = 0;
                  $285 = $284&1;
                  if ($285) {
                   break;
                  }
                  // unreachable;
                 } else {
                  $286 = ($282>>>0)<(11);
                  if ($286) {
                   $287 = $282 << 1;
                   $288 = $287&255;
                   HEAP8[$shadercode$i>>0] = $288;
                   $289 = (($shadercode$i) + 1|0);
                   $__p$0$i$i$i$i$i = $289;
                  } else {
                   $290 = (($282) + 16)|0;
                   $291 = $290 & -16;
                   __THREW__ = 0;
                   $292 = (invoke_ii(2988,($291|0))|0);
                   $293 = __THREW__; __THREW__ = 0;
                   $294 = $293&1;
                   if ($294) {
                    break;
                   }
                   $295 = (($shadercode$i) + 8|0);
                   HEAP32[$295>>2] = $292;
                   $296 = $291 | 1;
                   HEAP32[$shadercode$i>>2] = $296;
                   $297 = (($shadercode$i) + 4|0);
                   HEAP32[$297>>2] = $282;
                   $__p$0$i$i$i$i$i = $292;
                  }
                  _memcpy(($__p$0$i$i$i$i$i|0),($281|0),($282|0))|0;
                  $298 = (($__p$0$i$i$i$i$i) + ($282)|0);
                  HEAP8[$298>>0] = 0;
                  if (!($277)) {
                   $299 = (($0) + 8|0);
                   $300 = HEAP32[$299>>2]|0;
                   __ZdlPv($300);
                  }
                  HEAP32[$ss$i$i>>2] = ((390232 + 12|0));
                  HEAP32[$98>>2] = ((390232 + 32|0));
                  $305 = (($ss$i$i) + 4|0);
                  HEAP32[$305>>2] = ((225848 + 8|0));
                  $306 = HEAP8[$106>>0]|0;
                  $307 = $306 & 1;
                  $308 = ($307<<24>>24)==(0);
                  if (!($308)) {
                   $309 = (($ss$i$i) + 44|0);
                   $310 = HEAP32[$309>>2]|0;
                   __ZdlPv($310);
                  }
                  HEAP32[$305>>2] = ((3090568 + 8|0));
                  __THREW__ = 0;
                  invoke_vi(3299,($104|0));
                  $311 = __THREW__; __THREW__ = 0;
                  $312 = $311&1;
                  if ($312) {
                   $313 = ___cxa_find_matching_catch()|0;
                   $314 = tempRet0;
                   __THREW__ = 0;
                   invoke_vi(3217,($99|0));
                   $315 = __THREW__; __THREW__ = 0;
                   $316 = $315&1;
                   if (!($316)) {
                    $eh$lpad$body$i$index4Z2D = $314;$eh$lpad$body$i$indexZ2D = $313;
                    break L21;
                   }
                   $317 = ___cxa_find_matching_catch(0|0)|0;
                   $318 = tempRet0;
                   ___clang_call_terminate($317);
                   // unreachable;
                  }
                  __THREW__ = 0;
                  invoke_vi(3217,($99|0));
                  $319 = __THREW__; __THREW__ = 0;
                  $320 = $319&1;
                  if ($320) {
                   label = 17;
                   break L21;
                  }
                  $339 = HEAP8[$shadercode$i>>0]|0;
                  $340 = $339 & 1;
                  $341 = ($340<<24>>24)==(0);
                  if ($341) {
                   $346 = $339&255;
                   $347 = $346 >>> 1;
                   HEAP32[$shaderLen$i>>2] = $347;
                   $348 = (($shadercode$i) + 1|0);
                   $349 = $348;
                  } else {
                   $342 = (($shadercode$i) + 4|0);
                   $343 = HEAP32[$342>>2]|0;
                   HEAP32[$shaderLen$i>>2] = $343;
                   $344 = (($shadercode$i) + 8|0);
                   $345 = HEAP32[$344>>2]|0;
                   $349 = $345;
                  }
                  HEAP32[$code$i>>2] = $349;
                  $350 = (1147664 + 280|0);
                  $351 = HEAP32[$350>>2]|0;
                  __THREW__ = 0;
                  invoke_viiii($351|0,($93|0),1,($code$i|0),($shaderLen$i|0));
                  $352 = __THREW__; __THREW__ = 0;
                  $353 = $352&1;
                  L148: do {
                   if ($353) {
                    label = 142;
                   } else {
                    $354 = (1147664 + 68|0);
                    $355 = HEAP32[$354>>2]|0;
                    __THREW__ = 0;
                    invoke_vi($355|0,($93|0));
                    $356 = __THREW__; __THREW__ = 0;
                    $357 = $356&1;
                    if ($357) {
                     label = 142;
                     break;
                    }
                    $358 = (1147664 + 224|0);
                    $359 = HEAP32[$358>>2]|0;
                    __THREW__ = 0;
                    invoke_viii($359|0,($93|0),35713,($status$i|0));
                    $360 = __THREW__; __THREW__ = 0;
                    $361 = $360&1;
                    if ($361) {
                     label = 142;
                     break;
                    }
                    $362 = HEAP32[$status$i>>2]|0;
                    $363 = ($362|0)==(1);
                    do {
                     if ($363) {
                      $372 = (1147664 + 4|0);
                      $373 = HEAP32[$372>>2]|0;
                      __THREW__ = 0;
                      invoke_vii($373|0,($88|0),($93|0));
                      $374 = __THREW__; __THREW__ = 0;
                      $375 = $374&1;
                      if ($375) {
                       label = 142;
                       break L148;
                      }
                      $376 = (1147664 + 4|0);
                      $377 = HEAP32[$376>>2]|0;
                      $378 = HEAP32[1154880>>2]|0;
                      __THREW__ = 0;
                      invoke_vii($377|0,($88|0),($378|0));
                      $379 = __THREW__; __THREW__ = 0;
                      $380 = $379&1;
                      if ($380) {
                       label = 142;
                       break L148;
                      }
                      ;HEAP32[$varyings$i+0>>2]=0|0;HEAP32[$varyings$i+4>>2]=0|0;HEAP32[$varyings$i+8>>2]=0|0;
                      $381 = ($151|0)==(0);
                      if ($381) {
                       $varyingCount$0$i = 0;
                      } else {
                       HEAP32[$varyings$i>>2] = 1155176;
                       $varyingCount$0$i = 1;
                      }
                      $382 = $channelMask & 2;
                      $383 = ($382|0)==(0);
                      if ($383) {
                       $varyingCount$1$i = $varyingCount$0$i;
                      } else {
                       $384 = (($varyingCount$0$i) + 1)|0;
                       $385 = (($varyings$i) + ($varyingCount$0$i<<2)|0);
                       HEAP32[$385>>2] = 1155184;
                       $varyingCount$1$i = $384;
                      }
                      $386 = $channelMask & 128;
                      $387 = ($386|0)==(0);
                      if ($387) {
                       $varyingCount$2$i = $varyingCount$1$i;
                      } else {
                       $388 = (($varyingCount$1$i) + 1)|0;
                       $389 = (($varyings$i) + ($varyingCount$1$i<<2)|0);
                       HEAP32[$389>>2] = 1155200;
                       $varyingCount$2$i = $388;
                      }
                      $390 = (1147664 + 460|0);
                      $391 = HEAP32[$390>>2]|0;
                      __THREW__ = 0;
                      invoke_viiii($391|0,($88|0),($varyingCount$2$i|0),($varyings$i|0),35980);
                      $392 = __THREW__; __THREW__ = 0;
                      $393 = $392&1;
                      if ($393) {
                       label = 142;
                       break L148;
                      }
                      $394 = (1147664 + 256|0);
                      $395 = HEAP32[$394>>2]|0;
                      __THREW__ = 0;
                      invoke_vi($395|0,($88|0));
                      $396 = __THREW__; __THREW__ = 0;
                      $397 = $396&1;
                      if ($397) {
                       label = 142;
                       break L148;
                      }
                      $398 = (1147664 + 216|0);
                      $399 = HEAP32[$398>>2]|0;
                      __THREW__ = 0;
                      invoke_viii($399|0,($88|0),35714,($status$i|0));
                      $400 = __THREW__; __THREW__ = 0;
                      $401 = $400&1;
                      if ($401) {
                       label = 142;
                       break L148;
                      }
                      $402 = HEAP32[$status$i>>2]|0;
                      $403 = ($402|0)==(1);
                      if (!($403)) {
                       _memset(($temp3$i|0),0,512)|0;
                       HEAP32[$len4$i>>2] = 512;
                       $404 = (1147664 + 220|0);
                       $405 = HEAP32[$404>>2]|0;
                       __THREW__ = 0;
                       invoke_viiii($405|0,($88|0),512,($len4$i|0),($temp3$i|0));
                       $406 = __THREW__; __THREW__ = 0;
                       $407 = $406&1;
                       if ($407) {
                        label = 142;
                        break L148;
                       }
                       __THREW__ = 0;
                       HEAP32[$vararg_buffer28>>2] = $temp3$i;
                       invoke_vii(2587,(1155216|0),($vararg_buffer28|0));
                       $408 = __THREW__; __THREW__ = 0;
                       $409 = $408&1;
                       if ($409) {
                        label = 142;
                        break L148;
                       } else {
                        $$05$i = 0;
                        break;
                       }
                      }
                      if ((($9|0) == 2)) {
                       $415 = (1147664 + 240|0);
                       $416 = HEAP32[$415>>2]|0;
                       __THREW__ = 0;
                       $417 = (invoke_iii($416|0,($88|0),(1155280|0))|0);
                       $418 = __THREW__; __THREW__ = 0;
                       $419 = $418&1;
                       if ($419) {
                        label = 142;
                        break L148;
                       }
                       $420 = HEAP32[1149528>>2]|0;
                       __THREW__ = 0;
                       invoke_vii(3488,($420|0),($88|0));
                       $421 = __THREW__; __THREW__ = 0;
                       $422 = $421&1;
                       if ($422) {
                        label = 142;
                        break L148;
                       }
                       $423 = (1147664 + 320|0);
                       $424 = HEAP32[$423>>2]|0;
                       __THREW__ = 0;
                       invoke_vii($424|0,($417|0),0);
                       $425 = __THREW__; __THREW__ = 0;
                       $426 = $425&1;
                       if ($426) {
                        label = 142;
                        break L148;
                       } else {
                        $443 = $417;
                       }
                      } else if ((($9|0) == 1)) {
                       $427 = (1147664 + 472|0);
                       $428 = HEAP32[$427>>2]|0;
                       __THREW__ = 0;
                       $429 = (invoke_iii($428|0,($88|0),(1155288|0))|0);
                       $430 = __THREW__; __THREW__ = 0;
                       $431 = $430&1;
                       if ($431) {
                        label = 142;
                        break L148;
                       }
                       $432 = (1147664 + 484|0);
                       $433 = HEAP32[$432>>2]|0;
                       __THREW__ = 0;
                       invoke_viii($433|0,($88|0),($429|0),0);
                       $434 = __THREW__; __THREW__ = 0;
                       $435 = $434&1;
                       if ($435) {
                        label = 142;
                        break L148;
                       } else {
                        $443 = $429;
                       }
                      } else {
                       $410 = (1147664 + 240|0);
                       $411 = HEAP32[$410>>2]|0;
                       __THREW__ = 0;
                       $412 = (invoke_iii($411|0,($88|0),(1155280|0))|0);
                       $413 = __THREW__; __THREW__ = 0;
                       $414 = $413&1;
                       if ($414) {
                        label = 142;
                        break L148;
                       } else {
                        $443 = $412;
                       }
                      }
                      $436 = $2;
                      $437 = $436;
                      HEAP32[$437>>2] = $19;
                      $438 = (($436) + 4)|0;
                      $439 = $438;
                      HEAP32[$439>>2] = $20;
                      $440 = (($2) + 8|0);
                      HEAP32[$440>>2] = $88;
                      $441 = (($2) + 12|0);
                      HEAP32[$441>>2] = $93;
                      $442 = (($2) + 16|0);
                      HEAP32[$442>>2] = $443;
                      __THREW__ = 0;
                      invoke_viii(2109,($1|0),(1154864|0),($2|0));
                      $444 = __THREW__; __THREW__ = 0;
                      $445 = $444&1;
                      if ($445) {
                       $448 = ___cxa_find_matching_catch()|0;
                       $449 = tempRet0;
                       $$23$i = $448;$$sink$i$index21 = $449;
                       break L148;
                      } else {
                       $446 = HEAP32[$1>>2]|0;
                       $447 = (($446) + 24|0);
                       $$05$i = $447;
                       break;
                      }
                     } else {
                      _memset(($temp1$i|0),0,512)|0;
                      HEAP32[$len2$i>>2] = 512;
                      $364 = (1147664 + 228|0);
                      $365 = HEAP32[$364>>2]|0;
                      __THREW__ = 0;
                      invoke_viiii($365|0,($93|0),512,($len2$i|0),($temp1$i|0));
                      $366 = __THREW__; __THREW__ = 0;
                      $367 = $366&1;
                      if ($367) {
                       label = 142;
                       break L148;
                      }
                      __THREW__ = 0;
                      HEAP32[$vararg_buffer28>>2] = $temp1$i;
                      invoke_vii(2587,(1155096|0),($vararg_buffer28|0));
                      $368 = __THREW__; __THREW__ = 0;
                      $369 = $368&1;
                      if ($369) {
                       label = 142;
                       break L148;
                      } else {
                       $$05$i = 0;
                      }
                     }
                    } while(0);
                    $450 = HEAP8[$shadercode$i>>0]|0;
                    $451 = $450 & 1;
                    $452 = ($451<<24>>24)==(0);
                    if ($452) {
                     $$27$i = $$05$i;
                     break L11;
                    }
                    $453 = (($shadercode$i) + 8|0);
                    $454 = HEAP32[$453>>2]|0;
                    __ZdlPv($454);
                    $$27$i = $$05$i;
                    break L11;
                   }
                  } while(0);
                  if ((label|0) == 142) {
                   $370 = ___cxa_find_matching_catch()|0;
                   $371 = tempRet0;
                   $$23$i = $370;$$sink$i$index21 = $371;
                  }
                  $455 = HEAP8[$shadercode$i>>0]|0;
                  $456 = $455 & 1;
                  $457 = ($456<<24>>24)==(0);
                  if ($457) {
                   $$3$i = $$sink$i$index21;$$34$i = $$23$i;
                   ___resumeException($$34$i|0);
                   // unreachable;
                  }
                  $458 = (($shadercode$i) + 8|0);
                  $459 = HEAP32[$458>>2]|0;
                  __ZdlPv($459);
                  $$3$i = $$sink$i$index21;$$34$i = $$23$i;
                  ___resumeException($$34$i|0);
                  // unreachable;
                 }
                } while(0);
                $301 = ___cxa_find_matching_catch()|0;
                $302 = tempRet0;
                if ($277) {
                 $$0$i$i1 = $301;$$01$i$i = $302;
                 break;
                }
                $303 = (($0) + 8|0);
                $304 = HEAP32[$303>>2]|0;
                __ZdlPv($304);
                $$0$i$i1 = $301;$$01$i$i = $302;
               }
              }
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 45) {
          $161 = ___cxa_find_matching_catch()|0;
          $162 = tempRet0;
          $$0$i$i1 = $161;$$01$i$i = $162;
         }
         HEAP32[$ss$i$i>>2] = ((390232 + 12|0));
         HEAP32[$98>>2] = ((390232 + 32|0));
         $321 = (($ss$i$i) + 4|0);
         HEAP32[$321>>2] = ((225848 + 8|0));
         $322 = HEAP8[$106>>0]|0;
         $323 = $322 & 1;
         $324 = ($323<<24>>24)==(0);
         if (!($324)) {
          $325 = (($ss$i$i) + 44|0);
          $326 = HEAP32[$325>>2]|0;
          __ZdlPv($326);
         }
         HEAP32[$321>>2] = ((3090568 + 8|0));
         __THREW__ = 0;
         invoke_vi(3299,($104|0));
         $327 = __THREW__; __THREW__ = 0;
         $328 = $327&1;
         if ($328) {
          $331 = ___cxa_find_matching_catch(0|0)|0;
          $332 = tempRet0;
          __THREW__ = 0;
          invoke_vi(3217,($99|0));
          $333 = __THREW__; __THREW__ = 0;
          $334 = $333&1;
          if ($334) {
           $335 = ___cxa_find_matching_catch(0|0)|0;
           $336 = tempRet0;
           ___clang_call_terminate($335);
           // unreachable;
          } else {
           $eh$lpad$body$i$i$indexZ2D = $331;
           ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
           // unreachable;
          }
         }
         __THREW__ = 0;
         invoke_vi(3217,($99|0));
         $329 = __THREW__; __THREW__ = 0;
         $330 = $329&1;
         if (!($330)) {
          $eh$lpad$body$i$index4Z2D = $$01$i$i;$eh$lpad$body$i$indexZ2D = $$0$i$i1;
          break L21;
         }
         $337 = ___cxa_find_matching_catch(0|0)|0;
         $338 = tempRet0;
         $eh$lpad$body$i$i$indexZ2D = $337;
         ___clang_call_terminate($eh$lpad$body$i$i$indexZ2D);
         // unreachable;
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3217,($96|0));
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       if ($134) {
        $135 = ___cxa_find_matching_catch(0|0)|0;
        $136 = tempRet0;
        ___clang_call_terminate($135);
        // unreachable;
       } else {
        $eh$lpad$body$i$index4Z2D = $$sink$i$i$i$index11;$eh$lpad$body$i$indexZ2D = $$01$i$i$i;
        break;
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 17) {
    $84 = ___cxa_find_matching_catch()|0;
    $85 = tempRet0;
    $eh$lpad$body$i$index4Z2D = $85;$eh$lpad$body$i$indexZ2D = $84;
   }
   $$3$i = $eh$lpad$body$i$index4Z2D;$$34$i = $eh$lpad$body$i$indexZ2D;
   ___resumeException($$34$i|0);
   // unreachable;
  }
 } while(0);
 $460 = $sourceMesh;
 $461 = $460;
 $462 = HEAP32[$461>>2]|0;
 $463 = (($460) + 4)|0;
 $464 = $463;
 $465 = HEAP32[$464>>2]|0;
 $466 = HEAP32[$$27$i>>2]|0;
 $467 = HEAP32[((1154888 + 4|0))>>2]|0;
 $468 = ($467|0)==(0|0);
 if ($468) {
  $$0$i$i$i = ((1154888 + 4|0));$493 = ((1154888 + 4|0));
 } else {
  $__nd$0$in$i$i$i = $467;
  while(1) {
   $469 = (($__nd$0$in$i$i$i) + 16|0);
   $470 = HEAP32[$469>>2]|0;
   $471 = ($466>>>0)<($470>>>0);
   if ($471) {
    $472 = HEAP32[$__nd$0$in$i$i$i>>2]|0;
    $473 = ($472|0)==(0|0);
    if ($473) {
     $$0$i$i$i = $__nd$0$in$i$i$i;$493 = $__nd$0$in$i$i$i;
     break;
    } else {
     $__nd$0$in$i$i$i = $472;
     continue;
    }
   } else {
    $474 = (($__nd$0$in$i$i$i) + 4|0);
    $475 = HEAP32[$474>>2]|0;
    $476 = ($475|0)==(0|0);
    if ($476) {
     $$0$i$i$i = $474;$493 = $__nd$0$in$i$i$i;
     break;
    } else {
     $__nd$0$in$i$i$i = $475;
     continue;
    }
   }
  }
 }
 $477 = (__Znwj(56)|0);
 $478 = (($477) + 16|0);
 HEAP32[$478>>2] = $466;
 $479 = (($477) + 20|0);
 $480 = $479;
 $481 = $480;
 HEAP32[$481>>2] = $462;
 $482 = (($480) + 4)|0;
 $483 = $482;
 HEAP32[$483>>2] = $465;
 $484 = (($477) + 28|0);
 HEAP32[$484>>2] = $$27$i;
 $485 = (($477) + 32|0);
 HEAP32[$485>>2] = $destBuffer;
 $486 = (($477) + 36|0);
 HEAP32[$486>>2] = $poseBuffer;
 $487 = (($477) + 40|0);
 HEAP32[$487>>2] = $skinBuffer;
 $488 = (($477) + 44|0);
 HEAP32[$488>>2] = $vertexCount;
 $489 = (($477) + 48|0);
 HEAP32[$489>>2] = $bonesPerVertex;
 $490 = (($477) + 52|0);
 HEAP32[$490>>2] = $channelMask;
 HEAP32[$477>>2] = 0;
 $491 = (($477) + 4|0);
 HEAP32[$491>>2] = 0;
 $492 = (($477) + 8|0);
 HEAP32[$492>>2] = $493;
 HEAP32[$$0$i$i$i>>2] = $477;
 $494 = HEAP32[1154888>>2]|0;
 $495 = HEAP32[$494>>2]|0;
 $496 = ($495|0)==(0|0);
 if ($496) {
  $498 = $477;
 } else {
  HEAP32[1154888>>2] = $495;
  $$pre$i$i$i = HEAP32[$$0$i$i$i>>2]|0;
  $498 = $$pre$i$i$i;
 }
 $497 = HEAP32[((1154888 + 4|0))>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($497,$498);
 $499 = HEAP32[((1154888 + 8|0))>>2]|0;
 $500 = (($499) + 1)|0;
 HEAP32[((1154888 + 8|0))>>2] = $500;
 if (!($lastThisFrame)) {
  STACKTOP = sp;return;
 }
 $501 = (1147664 + 144|0);
 $502 = HEAP32[$501>>2]|0;
 FUNCTION_TABLE_vi[$502 & 4095](35977);
 $503 = HEAP32[1154888>>2]|0;
 $504 = ($503|0)==(((1154888 + 4|0))|0);
 if (!($504)) {
  $505 = (($0) + 8|0);
  $506 = (($0) + 12|0);
  $507 = (($ss$i$i) + 4|0);
  $508 = (($ss$i$i) + 5|0);
  $509 = (($ss$i$i) + 6|0);
  $510 = (($ss$i$i) + 7|0);
  $511 = (($ss$i$i) + 20|0);
  $512 = (($ss$i$i) + 21|0);
  $513 = (($ss$i$i) + 22|0);
  $514 = (($ss$i$i) + 23|0);
  $515 = (($ss$i$i) + 24|0);
  $516 = (($ss$i$i) + 25|0);
  $517 = (($ss$i$i) + 26|0);
  $518 = (($ss$i$i) + 27|0);
  $519 = (($ss$i$i) + 32|0);
  $520 = (($ss$i$i) + 33|0);
  $521 = (($ss$i$i) + 34|0);
  $522 = (($ss$i$i) + 35|0);
  $523 = (($ss$i$i) + 8|0);
  $524 = (($ss$i$i) + 9|0);
  $525 = (($ss$i$i) + 10|0);
  $526 = (($ss$i$i) + 11|0);
  $528 = $503;
  while(1) {
   $527 = (($528) + 20|0);
   $529 = (($528) + 32|0);
   $530 = HEAP32[$529>>2]|0;
   $531 = (($530) + 20|0);
   $532 = HEAP32[$531>>2]|0;
   __ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESE12EnsureBufferEj($530,$532);
   $533 = (($530) + 24|0);
   $534 = HEAP32[$533>>2]|0;
   $535 = (($534) + 4|0);
   $536 = HEAP32[$535>>2]|0;
   $537 = (1147664 + 456|0);
   $538 = HEAP32[$537>>2]|0;
   FUNCTION_TABLE_viii[$538 & 4095](35982,0,$536);
   $539 = HEAP32[1149528>>2]|0;
   $540 = (($528) + 28|0);
   $541 = HEAP32[$540>>2]|0;
   $542 = HEAP32[$541>>2]|0;
   __ZN4gles14UseGLSLProgramER15DeviceStateGLESj($539,$542);
   $543 = (($528) + 36|0);
   $544 = HEAP32[$543>>2]|0;
   $545 = (($544) + 8|0);
   $546 = HEAP32[$545>>2]|0;
   $547 = HEAP32[$546>>2]|0;
   $548 = (($547) + 16|0);
   $549 = HEAP32[$548>>2]|0;
   $550 = HEAP32[$540>>2]|0;
   $551 = (($550) + 8|0);
   $552 = HEAP32[$551>>2]|0;
   FUNCTION_TABLE_vii[$549 & 4095]($546,$552);
   __ZN14ChannelAssignsC2Ev($vararg_buffer28);
   __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($vararg_buffer28,0,0);
   $553 = (($528) + 52|0);
   $554 = HEAP32[$553>>2]|0;
   $555 = $554 & 2;
   $556 = ($555|0)==(0);
   if ($556) {
    $558 = $554;
   } else {
    __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($vararg_buffer28,1,2);
    $$pre$i = HEAP32[$553>>2]|0;
    $558 = $$pre$i;
   }
   $557 = $558 & 128;
   $559 = ($557|0)==(0);
   if (!($559)) {
    __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($vararg_buffer28,7,4);
   }
   __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($vararg_buffer28,4,5);
   $560 = (($528) + 48|0);
   $561 = HEAP32[$560>>2]|0;
   $562 = ($561|0)>(1);
   if ($562) {
    __ZN14ChannelAssigns4BindE13ShaderChannel15VertexComponent($vararg_buffer28,5,6);
   }
   HEAP32[$ss$i$i>>2] = ((1149472 + 8|0));
   ;HEAP32[$507+0>>2]=0|0;HEAP32[$507+4>>2]=0|0;HEAP32[$507+8>>2]=0|0;HEAP32[$507+12>>2]=0|0;HEAP32[$507+16>>2]=0|0;HEAP32[$507+20>>2]=0|0;HEAP32[$507+24>>2]=0|0;HEAP32[$507+28>>2]=0|0;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
   $563 = $527;
   $564 = $563;
   $565 = HEAP32[$564>>2]|0;
   $566 = (($563) + 4)|0;
   $567 = $566;
   $568 = HEAP32[$567>>2]|0;
   $569 = $0;
   $570 = $569;
   HEAP32[$570>>2] = $565;
   $571 = (($569) + 4)|0;
   $572 = $571;
   HEAP32[$572>>2] = $568;
   $573 = (($528) + 40|0);
   $574 = HEAP32[$573>>2]|0;
   HEAP32[$505>>2] = $574;
   $575 = HEAP32[$560>>2]|0;
   if ((($575|0) == 4)) {
    $$0$i$i = 32;
   } else if ((($575|0) == 1)) {
    $$0$i$i = 4;
   } else if ((($575|0) == 2)) {
    $$0$i$i = 16;
   } else {
    $$0$i$i = 1;
   }
   HEAP32[$506>>2] = $$0$i$i;
   HEAP8[$507>>0] = 0;
   HEAP8[$508>>0] = 0;
   HEAP8[$509>>0] = 0;
   HEAP8[$510>>0] = 3;
   $576 = HEAP32[$553>>2]|0;
   $577 = $576 & 2;
   $578 = ($577|0)==(0);
   if ($578) {
    $580 = $576;$meshOffset$0$i$i = 12;
   } else {
    HEAP8[$523>>0] = 0;
    HEAP8[$524>>0] = 12;
    HEAP8[$525>>0] = 0;
    HEAP8[$526>>0] = 3;
    $$pre8$i = HEAP32[$553>>2]|0;
    $580 = $$pre8$i;$meshOffset$0$i$i = 24;
   }
   $579 = $580 & 128;
   $581 = ($579|0)==(0);
   if (!($581)) {
    HEAP8[$519>>0] = 0;
    HEAP8[$520>>0] = $meshOffset$0$i$i;
    HEAP8[$521>>0] = 0;
    HEAP8[$522>>0] = 4;
   }
   $582 = HEAP32[$560>>2]|0;
   if ((($582|0) == 4)) {
    HEAP8[$511>>0] = 1;
    HEAP8[$512>>0] = 16;
    HEAP8[$513>>0] = 4;
    HEAP8[$514>>0] = 4;
    HEAP8[$515>>0] = 1;
    HEAP8[$516>>0] = 0;
    HEAP8[$517>>0] = 0;
    HEAP8[$518>>0] = 4;
   } else if ((($582|0) == 1)) {
    HEAP8[$511>>0] = 1;
    HEAP8[$512>>0] = 0;
    HEAP8[$513>>0] = 4;
    HEAP8[$514>>0] = 1;
   } else if ((($582|0) == 2)) {
    HEAP8[$511>>0] = 1;
    HEAP8[$512>>0] = 8;
    HEAP8[$513>>0] = 4;
    HEAP8[$514>>0] = 2;
    HEAP8[$515>>0] = 1;
    HEAP8[$516>>0] = 0;
    HEAP8[$517>>0] = 0;
    HEAP8[$518>>0] = 2;
   }
   __Z18SetVertexStateGLESRK14ChannelAssignsP21VertexDeclarationGLESPK18VertexStreamSourcej($vararg_buffer28,$ss$i$i,$0,2);
   $583 = (1147664 + 448|0);
   $584 = HEAP32[$583>>2]|0;
   FUNCTION_TABLE_vi[$584 & 4095](0);
   $585 = (1147664 + 136|0);
   $586 = HEAP32[$585>>2]|0;
   $587 = (($528) + 44|0);
   $588 = HEAP32[$587>>2]|0;
   FUNCTION_TABLE_viii[$586 & 4095](0,0,$588);
   $589 = (1147664 + 452|0);
   $590 = HEAP32[$589>>2]|0;
   FUNCTION_TABLE_v[$590 & 1023]();
   $591 = HEAP32[$543>>2]|0;
   $592 = (($591) + 8|0);
   $593 = HEAP32[$592>>2]|0;
   $594 = HEAP32[$593>>2]|0;
   $595 = (($594) + 20|0);
   $596 = HEAP32[$595>>2]|0;
   FUNCTION_TABLE_vi[$596 & 4095]($593);
   __ZN14DataBufferGLES12RecordUpdateEv($534);
   $597 = (($528) + 4|0);
   $598 = HEAP32[$597>>2]|0;
   $599 = ($598|0)==(0|0);
   if ($599) {
    $$01$i$i$i$i$i = $528;
    while(1) {
     $602 = (($$01$i$i$i$i$i) + 8|0);
     $603 = HEAP32[$602>>2]|0;
     $604 = HEAP32[$603>>2]|0;
     $605 = ($604|0)==($$01$i$i$i$i$i|0);
     if ($605) {
      $$0$i$i$i$i$i = $603;
      break;
     } else {
      $$01$i$i$i$i$i = $603;
     }
    }
   } else {
    $$0$i$i$i$i$i$i = $598;
    while(1) {
     $600 = HEAP32[$$0$i$i$i$i$i$i>>2]|0;
     $601 = ($600|0)==(0|0);
     if ($601) {
      $$0$i$i$i$i$i = $$0$i$i$i$i$i$i;
      break;
     } else {
      $$0$i$i$i$i$i$i = $600;
     }
    }
   }
   $606 = ($$0$i$i$i$i$i|0)==(((1154888 + 4|0))|0);
   if ($606) {
    break;
   } else {
    $528 = $$0$i$i$i$i$i;
   }
  }
 }
 $607 = HEAP32[((1154888 + 4|0))>>2]|0;
 __ZNSt3__16__treeINS_12__value_typeIj25DeferredSkinningOperationEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE(1154888,$607);
 HEAP32[((1154888 + 8|0))>>2] = 0;
 HEAP32[1154888>>2] = ((1154888 + 4|0));
 HEAP32[((1154888 + 4|0))>>2] = 0;
 $608 = (1147664 + 128|0);
 $609 = HEAP32[$608>>2]|0;
 FUNCTION_TABLE_vi[$609 & 4095](35977);
 $610 = (1147664 + 456|0);
 $611 = HEAP32[$610>>2]|0;
 FUNCTION_TABLE_viii[$611 & 4095](35345,0,0);
 $612 = (1147664 + 436|0);
 $613 = HEAP32[$612>>2]|0;
 FUNCTION_TABLE_vi[$613 & 4095](0);
 $614 = (1147664 + 456|0);
 $615 = HEAP32[$614>>2]|0;
 FUNCTION_TABLE_viii[$615 & 4095](35982,0,0);
 $616 = (1147664 + 488|0);
 $617 = HEAP32[$616>>2]|0;
 FUNCTION_TABLE_vii[$617 & 4095](36386,0);
 STACKTOP = sp;return;
}
function __ZNSt3__16__treeINS_12__value_typeIy8TFShaderEENS_19__map_value_compareIyS3_NS_4lessIyEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIy8TFShaderEENS_19__map_value_compareIyS3_NS_4lessIyEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIy8TFShaderEENS_19__map_value_compareIyS3_NS_4lessIyEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIj25DeferredSkinningOperationEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$__nd) {
 $this = $this|0;
 $__nd = $__nd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__nd|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 } else {
  $1 = HEAP32[$__nd>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIj25DeferredSkinningOperationEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$1);
  $2 = (($__nd) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZNSt3__16__treeINS_12__value_typeIj25DeferredSkinningOperationEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE7destroyEPNS_11__tree_nodeIS3_PvEE($this,$3);
  __ZdlPv($__nd);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16__treeINS_12__value_typeIy8TFShaderEENS_19__map_value_compareIyS3_NS_4lessIyEELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_($agg$result,$this,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__v = $__v|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nd$0$in$i = 0, $__parent = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__parent = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $31 = (($this) + 4|0);
   HEAP32[$__parent>>2] = $31;
   $$0$i = $31;$38 = $31;
  } else {
   $3 = $__v;
   $4 = $3;
   $5 = HEAP32[$4>>2]|0;
   $6 = (($3) + 4)|0;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $__nd$0$in$i = $1;
   while(1) {
    $9 = (($__nd$0$in$i) + 16|0);
    $10 = $9;
    $11 = $10;
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + 4)|0;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($8>>>0)<($15>>>0);
    $17 = ($8|0)==($15|0);
    $18 = ($5>>>0)<($12>>>0);
    $19 = $17 & $18;
    $20 = $16 | $19;
    if ($20) {
     $21 = HEAP32[$__nd$0$in$i>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      label = 5;
      break;
     } else {
      $__nd$0$in$i = $21;
      continue;
     }
    }
    $23 = ($15>>>0)<($8>>>0);
    $24 = ($15|0)==($8|0);
    $25 = ($12>>>0)<($5>>>0);
    $26 = $24 & $25;
    $27 = $23 | $26;
    if (!($27)) {
     label = 9;
     break;
    }
    $28 = (($__nd$0$in$i) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==(0|0);
    if ($30) {
     label = 8;
     break;
    } else {
     $__nd$0$in$i = $29;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__nd$0$in$i;$38 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 8) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $28;$38 = $__nd$0$in$i;
    break;
   }
   else if ((label|0) == 9) {
    HEAP32[$__parent>>2] = $__nd$0$in$i;
    $$0$i = $__parent;$38 = $__nd$0$in$i;
    break;
   }
  }
 } while(0);
 $32 = HEAP32[$$0$i>>2]|0;
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $48 = 0;$__r$0 = $32;
  HEAP32[$agg$result>>2] = $__r$0;
  $47 = (($agg$result) + 4|0);
  HEAP8[$47>>0] = $48;
  STACKTOP = sp;return;
 }
 $34 = (__Znwj(40)|0);
 $35 = (($34) + 16|0);
 ;HEAP32[$35+0>>2]=HEAP32[$__v+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$__v+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$__v+8>>2]|0;HEAP32[$35+12>>2]=HEAP32[$__v+12>>2]|0;HEAP32[$35+16>>2]=HEAP32[$__v+16>>2]|0;HEAP32[$35+20>>2]=HEAP32[$__v+20>>2]|0;
 HEAP32[$34>>2] = 0;
 $36 = (($34) + 4|0);
 HEAP32[$36>>2] = 0;
 $37 = (($34) + 8|0);
 HEAP32[$37>>2] = $38;
 HEAP32[$$0$i>>2] = $34;
 $39 = HEAP32[$this>>2]|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if ($41) {
  $43 = $34;
 } else {
  HEAP32[$this>>2] = $40;
  $$pre$i = HEAP32[$$0$i>>2]|0;
  $43 = $$pre$i;
 }
 $42 = HEAP32[$0>>2]|0;
 __ZNSt3__127__tree_balance_after_insertIPNS_16__tree_node_baseIPvEEEEvT_S5_($42,$43);
 $44 = (($this) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($45) + 1)|0;
 HEAP32[$44>>2] = $46;
 $48 = 1;$__r$0 = $34;
 HEAP32[$agg$result>>2] = $__r$0;
 $47 = (($agg$result) + 4|0);
 HEAP8[$47>>0] = $48;
 STACKTOP = sp;return;
}
function __ZN15TextureTFMethodD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3$i = 0, $scevgep4$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5$i = 0, $uglygep3$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1157312 + 8|0));
 $0 = (1147664 + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 20|0);
 __THREW__ = 0;
 invoke_vii($1|0,3,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $16 = (($this) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   ___resumeException($14|0);
   // unreachable;
  }
  $19 = (($this) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==($17|0);
  if (!($21)) {
   $__new_last2$i$i$i$i$i2$i = $17;
   $scevgep$i$i$i$i$i3$i = (($20) + -4|0);
   $22 = (0 - ($__new_last2$i$i$i$i$i2$i))|0;
   $uglygep$i$i$i$i$i5$i = (($scevgep$i$i$i$i$i3$i) + ($22)|0);
   $uglygep3$i$i$i$i$i6$i = $uglygep$i$i$i$i$i5$i;
   $23 = $uglygep3$i$i$i$i$i6$i >>> 2;
   $24 = $23 ^ -1;
   $scevgep4$i$i$i$i$i7$i = (($20) + ($24<<2)|0);
   HEAP32[$19>>2] = $scevgep4$i$i$i$i$i7$i;
  }
  __ZdlPv($17);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   STACKTOP = sp;return;
  }
  $8 = (($this) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($6|0);
  if (!($10)) {
   $__new_last2$i$i$i$i$i$i = $6;
   $scevgep$i$i$i$i$i$i = (($9) + -4|0);
   $11 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($11)|0);
   $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
   $12 = $uglygep3$i$i$i$i$i$i >>> 2;
   $13 = $12 ^ -1;
   $scevgep4$i$i$i$i$i$i = (($9) + ($13<<2)|0);
   HEAP32[$8>>2] = $scevgep4$i$i$i$i$i$i;
  }
  __ZdlPv($6);
  STACKTOP = sp;return;
 }
}
function __ZN15TextureTFMethodD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i2$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i3$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i7$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i5$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i6$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1157312 + 8|0));
 $0 = (1147664 + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 20|0);
 __THREW__ = 0;
 invoke_vii($1|0,3,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $16 = (($this) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   __ZdlPv($this);
   ___resumeException($14|0);
   // unreachable;
  }
  $19 = (($this) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==($17|0);
  if (!($21)) {
   $__new_last2$i$i$i$i$i2$i$i = $17;
   $scevgep$i$i$i$i$i3$i$i = (($20) + -4|0);
   $22 = (0 - ($__new_last2$i$i$i$i$i2$i$i))|0;
   $uglygep$i$i$i$i$i5$i$i = (($scevgep$i$i$i$i$i3$i$i) + ($22)|0);
   $uglygep3$i$i$i$i$i6$i$i = $uglygep$i$i$i$i$i5$i$i;
   $23 = $uglygep3$i$i$i$i$i6$i$i >>> 2;
   $24 = $23 ^ -1;
   $scevgep4$i$i$i$i$i7$i$i = (($20) + ($24<<2)|0);
   HEAP32[$19>>2] = $scevgep4$i$i$i$i$i7$i$i;
  }
  __ZdlPv($17);
  __ZdlPv($this);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   __ZdlPv($this);
   STACKTOP = sp;return;
  }
  $8 = (($this) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==($6|0);
  if (!($10)) {
   $__new_last2$i$i$i$i$i$i$i = $6;
   $scevgep$i$i$i$i$i$i$i = (($9) + -4|0);
   $11 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
   $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($11)|0);
   $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
   $12 = $uglygep3$i$i$i$i$i$i$i >>> 2;
   $13 = $12 ^ -1;
   $scevgep4$i$i$i$i$i$i$i = (($9) + ($13<<2)|0);
   HEAP32[$8>>2] = $scevgep4$i$i$i$i$i$i$i;
  }
  __ZdlPv($6);
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN15TextureTFMethod13MapBoneBufferEj($this,$sizeInFloats) {
 $this = $this|0;
 $sizeInFloats = $sizeInFloats|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($sizeInFloats>>>0) / 12)&-1;
 $1 = (($this) + 36|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 8|0);
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = $4;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = ($9>>>0)<($sizeInFloats>>>0);
 if (!($10)) {
  $12 = $5;
  STACKTOP = sp;return ($12|0);
 }
 $11 = (($sizeInFloats) - ($9))|0;
 __ZNSt3__16vectorIfNS_9allocatorIfEEE8__appendEj($2,$11);
 $$pre = HEAP32[$2>>2]|0;
 $12 = $$pre;
 STACKTOP = sp;return ($12|0);
}
function __ZN15TextureTFMethod15UnmapBoneBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($this) + ($3<<2)|0) + 40|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5>>>0)<($1>>>0);
 $7 = (1147664 + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($this) + ($3<<2)|0) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vii[$8 & 4095](3553,$10);
 if ($6) {
  $11 = (1147664 + 308|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_viii[$12 & 4095](3553,10241,9728);
  $13 = (1147664 + 308|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_viii[$14 & 4095](3553,10240,9728);
  $15 = (1147664 + 308|0);
  $16 = HEAP32[$15>>2]|0;
  FUNCTION_TABLE_viii[$16 & 4095](3553,10242,33071);
  $17 = (1147664 + 308|0);
  $18 = HEAP32[$17>>2]|0;
  FUNCTION_TABLE_viii[$18 & 4095](3553,10243,33071);
  $19 = (1147664 + 308|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viii[$20 & 4095](3553,33084,0);
  $21 = (1147664 + 308|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_viii[$22 & 4095](3553,33085,0);
  $23 = (1147664 + 304|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = (($this) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$24 & 31](3553,0,34836,3,$1,0,6408,5126,$26);
  $31 = HEAP32[$2>>2]|0;
  $32 = ((($this) + ($31<<2)|0) + 40|0);
  HEAP32[$32>>2] = $1;
  STACKTOP = sp;return;
 } else {
  $27 = (1147664 + 312|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($this) + 8|0);
  $30 = HEAP32[$29>>2]|0;
  FUNCTION_TABLE_viiiiiiiii[$28 & 31](3553,0,0,0,3,$1,6408,5126,$30);
  $31 = HEAP32[$2>>2]|0;
  $32 = ((($this) + ($31<<2)|0) + 40|0);
  HEAP32[$32>>2] = $1;
  STACKTOP = sp;return;
 }
}
function __ZN15TextureTFMethod16BindForRenderingEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP32[1149528>>2]|0;
 __ZN4gles19ActivateTextureUnitER15DeviceStateGLESj($1,0);
 $2 = (1147664 + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($this) + ($5<<2)|0) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095](3553,$7);
 STACKTOP = sp;return;
}
function __ZN15TextureTFMethod13DoneRenderingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1147664 + 24|0);
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vii[$1 & 4095](3553,0);
 $2 = (($this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 1)|0;
 $5 = (($4|0) % 3)&-1;
 HEAP32[$2>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN15TextureTFMethod20IsBoneCountSupportedEi($this,$boneCount) {
 $this = $this|0;
 $boneCount = $boneCount|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((640792 + 108|0))>>2]|0;
 $1 = ($0>>>0)>=($boneCount>>>0);
 STACKTOP = sp;return ($1|0);
}
function __ZN21UniformBufferTFMethodD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1157352 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN14DataBufferGLES7ReleaseEv($1);
 STACKTOP = sp;return;
}
function __ZN21UniformBufferTFMethodD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1157352 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3794,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZdlPv($this);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN21UniformBufferTFMethod13MapBoneBufferEj($this,$sizeInFloats) {
 $this = $this|0;
 $sizeInFloats = $sizeInFloats|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (__Z27BufferUpdateCausesStallGLESPK14DataBufferGLES($1)|0);
  if ($3) {
   $4 = HEAP32[$0>>2]|0;
   __ZN14DataBufferGLES7ReleaseEv($4);
   HEAP32[$0>>2] = 0;
  }
 }
 $5 = (__Z20GetBufferManagerGLESv()|0);
 $6 = $sizeInFloats << 2;
 $7 = (__ZN17BufferManagerGLES13AcquireBufferEiN14DataBufferGLES11BufferUsageE($5,$6,6)|0);
 HEAP32[$0>>2] = $7;
 $8 = (__ZN14DataBufferGLES3MapEiij($7,0,$6,10)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN21UniformBufferTFMethod15UnmapBoneBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN14DataBufferGLES5UnmapEv($1);
 $2 = HEAP32[$0>>2]|0;
 __ZN14DataBufferGLES12RecordUpdateEv($2);
 STACKTOP = sp;return;
}
function __ZN21UniformBufferTFMethod16BindForRenderingEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (1147664 + 456|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($2) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_viii[$5 & 4095](35345,0,$7);
 STACKTOP = sp;return;
}
function __ZN21UniformBufferTFMethod13DoneRenderingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN14DataBufferGLES12RecordRenderEv($1);
 STACKTOP = sp;return;
}
function __ZN21UniformBufferTFMethod20IsBoneCountSupportedEi($this,$boneCount) {
 $this = $this|0;
 $boneCount = $boneCount|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[((640792 + 345|0))>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $2 = HEAP32[((640792 + 296|0))>>2]|0;
 $3 = (($2>>>0) / 48)&-1;
 $4 = ($3>>>0)>=($boneCount>>>0);
 $$0$i = $4;
 STACKTOP = sp;return ($$0$i|0);
}
function __ZN15UniformTFMethodD1Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__new_last2$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1157392 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if (!($5)) {
  $__new_last2$i$i$i$i$i$i = $1;
  $scevgep$i$i$i$i$i$i = (($4) + -4|0);
  $6 = (0 - ($__new_last2$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i) + ($6)|0);
  $uglygep3$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i;
  $7 = $uglygep3$i$i$i$i$i$i >>> 2;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i$i$i$i = (($4) + ($8<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i;
 }
 __ZdlPv($1);
 STACKTOP = sp;return;
}
function __ZN15UniformTFMethodD0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1157392 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==($1|0);
 if (!($5)) {
  $__new_last2$i$i$i$i$i$i$i = $1;
  $scevgep$i$i$i$i$i$i$i = (($4) + -4|0);
  $6 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
  $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($6)|0);
  $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
  $7 = $uglygep3$i$i$i$i$i$i$i >>> 2;
  $8 = $7 ^ -1;
  $scevgep4$i$i$i$i$i$i$i = (($4) + ($8<<2)|0);
  HEAP32[$3>>2] = $scevgep4$i$i$i$i$i$i$i;
 }
 __ZdlPv($1);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN15UniformTFMethod13MapBoneBufferEj($this,$sizeInFloats) {
 $this = $this|0;
 $sizeInFloats = $sizeInFloats|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0;
 var $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7|0)==($sizeInFloats|0);
 if ($8) {
  $17 = $3;
  STACKTOP = sp;return ($17|0);
 }
 $9 = ($7>>>0)<($sizeInFloats>>>0);
 if ($9) {
  $10 = (($sizeInFloats) - ($7))|0;
  __ZNSt3__16vectorIfNS_9allocatorIfEEE8__appendEj($0,$10);
  $$pre = HEAP32[$0>>2]|0;
  $17 = $$pre;
  STACKTOP = sp;return ($17|0);
 }
 $11 = ($7>>>0)>($sizeInFloats>>>0);
 if (!($11)) {
  $17 = $3;
  STACKTOP = sp;return ($17|0);
 }
 $12 = (($3) + ($sizeInFloats<<2)|0);
 $13 = ($2|0)==($12|0);
 if ($13) {
  $17 = $3;
  STACKTOP = sp;return ($17|0);
 }
 $__new_last2$i$i$i = $12;
 $scevgep$i$i$i = (($2) + -4|0);
 $14 = (0 - ($__new_last2$i$i$i))|0;
 $uglygep$i$i$i = (($scevgep$i$i$i) + ($14)|0);
 $uglygep3$i$i$i = $uglygep$i$i$i;
 $15 = $uglygep3$i$i$i >>> 2;
 $16 = $15 ^ -1;
 $scevgep4$i$i$i = (($2) + ($16<<2)|0);
 HEAP32[$1>>2] = $scevgep4$i$i$i;
 $17 = $3;
 STACKTOP = sp;return ($17|0);
}
function __ZN15UniformTFMethod15UnmapBoneBufferEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15UniformTFMethod16BindForRenderingEj($this,$location) {
 $this = $this|0;
 $location = $location|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1147664 + 344|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = $9 >>> 2;
 FUNCTION_TABLE_viii[$1 & 4095]($location,$10,$5);
 STACKTOP = sp;return;
}
function __ZN15UniformTFMethod13DoneRenderingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15UniformTFMethod20IsBoneCountSupportedEi($this,$boneCount) {
 $this = $this|0;
 $boneCount = $boneCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((640792 + 300|0))>>2]|0;
 $1 = (($0|0) / 4)&-1;
 $2 = (($1) + -10)|0;
 $3 = (($2|0) / 3)&-1;
 $4 = ($3>>>0)>($boneCount>>>0);
 STACKTOP = sp;return ($4|0);
}
function __ZN16UniformCacheGLES6CreateEPK20GpuProgramParametersii($this,$params,$fogParamsIndex,$fogColorIndex) {
 $this = $this|0;
 $params = $params|0;
 $fogParamsIndex = $fogParamsIndex|0;
 $fogColorIndex = $fogColorIndex|0;
 var $$byval_copy = 0, $$lastUsedUniform$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fogParamsIndex$lastUsedUniform$0 = 0, $lastUsedUniform$0$lcssa = 0, $lastUsedUniform$02 = 0, $lastUsedUniform$1 = 0, $lastUsedUniform$3 = 0;
 var $paramI$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (__ZNK20GpuProgramParameters14GetValueParamsEv($params)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK20GpuProgramParameters14GetValueParamsEv($params)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($3) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + (($6*20)|0)|0);
 $8 = ($2|0)==($7|0);
 if ($8) {
  $lastUsedUniform$0$lcssa = -1;
 } else {
  $lastUsedUniform$02 = -1;$paramI$01 = $2;
  while(1) {
   $9 = (($paramI$01) + 16|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)==(1);
   if ($11) {
    $12 = (($paramI$01) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(1);
    if ($14) {
     $15 = (($paramI$01) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($16|0)>($lastUsedUniform$02|0);
     $$lastUsedUniform$0 = $17 ? $16 : $lastUsedUniform$02;
     $lastUsedUniform$1 = $$lastUsedUniform$0;
    } else {
     $lastUsedUniform$1 = $lastUsedUniform$02;
    }
   } else {
    $lastUsedUniform$1 = $lastUsedUniform$02;
   }
   $18 = (($paramI$01) + 20|0);
   $19 = ($18|0)==($7|0);
   if ($19) {
    $lastUsedUniform$0$lcssa = $lastUsedUniform$1;
    break;
   } else {
    $lastUsedUniform$02 = $lastUsedUniform$1;$paramI$01 = $18;
   }
  }
 }
 $20 = ($lastUsedUniform$0$lcssa|0)<($fogParamsIndex|0);
 $fogParamsIndex$lastUsedUniform$0 = $20 ? $fogParamsIndex : $lastUsedUniform$0$lcssa;
 $21 = ($fogParamsIndex$lastUsedUniform$0|0)<($fogColorIndex|0);
 $lastUsedUniform$3 = $21 ? $fogColorIndex : $fogParamsIndex$lastUsedUniform$0;
 $22 = HEAP32[1157440>>2]|0;
 $23 = (($lastUsedUniform$3) + 1)|0;
 $24 = ($22>>>0)<($23>>>0);
 if ($24) {
  $25 = $23 << 1;
  HEAP32[1157440>>2] = $25;
  $28 = $25;
 } else {
  $28 = $22;
 }
 $26 = HEAP32[1157432>>2]|0;
 $27 = $28 << 4;
 $29 = HEAP32[628272>>2]|0;
 HEAP32[$0>>2] = $29;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $30 = (__Z16realloc_internalPvji10MemLabelIdiPKci($26,$27,16,$$byval_copy,0,1157448,40)|0);
 HEAP32[1157432>>2] = $30;
 $31 = HEAP32[1157440>>2]|0;
 $32 = $31 << 4;
 _memset(($30|0),-1,($32|0))|0;
 STACKTOP = sp;return;
}
function __ZN16UniformCacheGLES7DestroyEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z14CachedUniform1P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$type,$index,$val) {
 $cache = $cache|0;
 $type = $type|0;
 $index = $index|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $ival = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ival = sp;
 $0 = HEAP32[1157432>>2]|0;
 $1 = $index << 2;
 $2 = (($0) + ($1<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$val>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($0) + ($1<<2)|0);
 $7 = Math_fround(HEAPF32[$val>>2]);
 HEAPF32[$6>>2] = $7;
 $8 = ($type|0)==(0);
 if ($8) {
  $9 = (1147664 + 316|0);
  $10 = HEAP32[$9>>2]|0;
  FUNCTION_TABLE_viii[$10 & 4095]($index,1,$val);
  STACKTOP = sp;return;
 } else {
  $11 = Math_fround(HEAPF32[$val>>2]);
  $12 = (~~(($11)));
  HEAP32[$ival>>2] = $12;
  $13 = (($ival) + 4|0);
  $14 = (($val) + 4|0);
  $15 = Math_fround(HEAPF32[$14>>2]);
  $16 = (~~(($15)));
  HEAP32[$13>>2] = $16;
  $17 = (($ival) + 8|0);
  $18 = (($val) + 8|0);
  $19 = Math_fround(HEAPF32[$18>>2]);
  $20 = (~~(($19)));
  HEAP32[$17>>2] = $20;
  $21 = (($ival) + 12|0);
  $22 = (($val) + 12|0);
  $23 = Math_fround(HEAPF32[$22>>2]);
  $24 = (~~(($23)));
  HEAP32[$21>>2] = $24;
  $25 = (1147664 + 324|0);
  $26 = HEAP32[$25>>2]|0;
  FUNCTION_TABLE_viii[$26 & 4095]($index,1,$ival);
  STACKTOP = sp;return;
 }
}
function __Z14CachedUniform2P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$type,$index,$val) {
 $cache = $cache|0;
 $type = $type|0;
 $index = $index|0;
 $val = $val|0;
 var $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$01$i$i = 0, $ival = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ival = sp;
 $0 = HEAP32[1157432>>2]|0;
 $1 = $index << 2;
 $2 = (($0) + ($1<<2)|0);
 $i$01$i$i = 0;
 while(1) {
  $$sum$i = (($i$01$i$i) + ($1))|0;
  $5 = (($0) + ($$sum$i<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($val) + ($i$01$i$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  $4 = (($i$01$i$i) + 1)|0;
  if (!($9)) {
   break;
  }
  $3 = ($4|0)<(2);
  if ($3) {
   $i$01$i$i = $4;
  } else {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return;
 }
 $10 = $val;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $2;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = ($type|0)==(0);
 if ($20) {
  $21 = (1147664 + 328|0);
  $22 = HEAP32[$21>>2]|0;
  FUNCTION_TABLE_viii[$22 & 4095]($index,1,$val);
  STACKTOP = sp;return;
 } else {
  $23 = Math_fround(HEAPF32[$val>>2]);
  $24 = (~~(($23)));
  HEAP32[$ival>>2] = $24;
  $25 = (($ival) + 4|0);
  $26 = (($val) + 4|0);
  $27 = Math_fround(HEAPF32[$26>>2]);
  $28 = (~~(($27)));
  HEAP32[$25>>2] = $28;
  $29 = (($ival) + 8|0);
  $30 = (($val) + 8|0);
  $31 = Math_fround(HEAPF32[$30>>2]);
  $32 = (~~(($31)));
  HEAP32[$29>>2] = $32;
  $33 = (($ival) + 12|0);
  $34 = (($val) + 12|0);
  $35 = Math_fround(HEAPF32[$34>>2]);
  $36 = (~~(($35)));
  HEAP32[$33>>2] = $36;
  $37 = (1147664 + 332|0);
  $38 = HEAP32[$37>>2]|0;
  FUNCTION_TABLE_viii[$38 & 4095]($index,1,$ival);
  STACKTOP = sp;return;
 }
}
function __Z14CachedUniform3P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$type,$index,$val) {
 $cache = $cache|0;
 $type = $type|0;
 $index = $index|0;
 $val = $val|0;
 var $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $ival = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ival = sp;
 $0 = HEAP32[1157432>>2]|0;
 $1 = $index << 2;
 $2 = (($0) + ($1<<2)|0);
 $i$01$i$i = 0;
 while(1) {
  $$sum$i = (($i$01$i$i) + ($1))|0;
  $5 = (($0) + ($$sum$i<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($val) + ($i$01$i$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  $4 = (($i$01$i$i) + 1)|0;
  if (!($9)) {
   break;
  }
  $3 = ($4|0)<(3);
  if ($3) {
   $i$01$i$i = $4;
  } else {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$2+0>>2]=HEAP32[$val+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$val+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$val+8>>2]|0;
 $10 = ($type|0)==(0);
 if ($10) {
  $11 = (1147664 + 336|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_viii[$12 & 4095]($index,1,$val);
  STACKTOP = sp;return;
 } else {
  $13 = Math_fround(HEAPF32[$val>>2]);
  $14 = (~~(($13)));
  HEAP32[$ival>>2] = $14;
  $15 = (($ival) + 4|0);
  $16 = (($val) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (~~(($17)));
  HEAP32[$15>>2] = $18;
  $19 = (($ival) + 8|0);
  $20 = (($val) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (~~(($21)));
  HEAP32[$19>>2] = $22;
  $23 = (($ival) + 12|0);
  $24 = (($val) + 12|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (~~(($25)));
  HEAP32[$23>>2] = $26;
  $27 = (1147664 + 340|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$28 & 4095]($index,1,$ival);
  STACKTOP = sp;return;
 }
}
function __Z14CachedUniform4P16UniformCacheGLES15ShaderParamTypeiPKf($cache,$type,$index,$val) {
 $cache = $cache|0;
 $type = $type|0;
 $index = $index|0;
 $val = $val|0;
 var $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $ival = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ival = sp;
 $0 = HEAP32[1157432>>2]|0;
 $1 = $index << 2;
 $2 = (($0) + ($1<<2)|0);
 $i$01$i$i = 0;
 while(1) {
  $$sum$i = (($i$01$i$i) + ($1))|0;
  $5 = (($0) + ($$sum$i<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($val) + ($i$01$i$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)==($8|0);
  $4 = (($i$01$i$i) + 1)|0;
  if (!($9)) {
   break;
  }
  $3 = ($4|0)<(4);
  if ($3) {
   $i$01$i$i = $4;
  } else {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return;
 }
 ;HEAP32[$2+0>>2]=HEAP32[$val+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$val+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$val+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$val+12>>2]|0;
 $10 = ($type|0)==(0);
 if ($10) {
  $11 = (1147664 + 344|0);
  $12 = HEAP32[$11>>2]|0;
  FUNCTION_TABLE_viii[$12 & 4095]($index,1,$val);
  STACKTOP = sp;return;
 } else {
  $13 = Math_fround(HEAPF32[$val>>2]);
  $14 = (~~(($13)));
  HEAP32[$ival>>2] = $14;
  $15 = (($ival) + 4|0);
  $16 = (($val) + 4|0);
  $17 = Math_fround(HEAPF32[$16>>2]);
  $18 = (~~(($17)));
  HEAP32[$15>>2] = $18;
  $19 = (($ival) + 8|0);
  $20 = (($val) + 8|0);
  $21 = Math_fround(HEAPF32[$20>>2]);
  $22 = (~~(($21)));
  HEAP32[$19>>2] = $22;
  $23 = (($ival) + 12|0);
  $24 = (($val) + 12|0);
  $25 = Math_fround(HEAPF32[$24>>2]);
  $26 = (~~(($25)));
  HEAP32[$23>>2] = $26;
  $27 = (1147664 + 348|0);
  $28 = HEAP32[$27>>2]|0;
  FUNCTION_TABLE_viii[$28 & 4095]($index,1,$ival);
  STACKTOP = sp;return;
 }
}
function __Z18SetVertexStateGLESRK14ChannelAssignsP21VertexDeclarationGLESPK18VertexStreamSourcej($channels,$decl,$vertexStreams,$vertexStreamCount) {
 $channels = $channels|0;
 $decl = $decl|0;
 $vertexStreams = $vertexStreams|0;
 $vertexStreamCount = $vertexStreamCount|0;
 var $$ = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $attribIndex$0$i = 0, $i$01 = 0, $k$05 = 0, $normalize$0$i = 0, $vararg_buffer1 = 0, $vboBound$04 = 0, $vboBound$1 = 0, $vboBound$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 $0 = HEAP32[$channels>>2]|0;
 $1 = HEAP32[((640792 + 280|0))>>2]|0;
 $2 = ($1|0)>(1);
 if ($2) {
  $k$05 = 1;
  while(1) {
   $3 = (1147664 + 132|0);
   $4 = HEAP32[$3>>2]|0;
   FUNCTION_TABLE_vi[$4 & 4095]($k$05);
   $5 = (($k$05) + 1)|0;
   $6 = HEAP32[((640792 + 280|0))>>2]|0;
   $7 = ($5|0)<($6|0);
   if ($7) {
    $k$05 = $5;
   } else {
    $i$01 = 0;$vboBound$04 = -1;
    break;
   }
  }
 } else {
  $i$01 = 0;$vboBound$04 = -1;
 }
 L4: while(1) {
  $8 = $0 >>> $i$01;
  $9 = ($8|0)==(0);
  if ($9) {
   label = 28;
   break;
  }
  $10 = 1 << $i$01;
  $11 = $10 & $0;
  $12 = ($11|0)==(0);
  L7: do {
   if ($12) {
    $vboBound$2 = $vboBound$04;
   } else {
    $13 = ((($channels) + ($i$01)|0) + 8|0);
    $14 = HEAP8[$13>>0]|0;
    $15 = $14 << 24 >> 24;
    $16 = ((($decl) + ($15<<2)|0) + 7|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     $vboBound$2 = $vboBound$04;
    } else {
     $19 = ((($decl) + ($15<<2)|0) + 6|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = ($20<<24>>24)==(2);
     $22 = $17&255;
     $$ = $21 ? 4 : $22;
     $23 = $20&255;
     switch ($23|0) {
     case 4:  {
      $$0$i = 5125;
      break;
     }
     case 2:  {
      $$0$i = 5121;
      break;
     }
     case 0:  {
      $$0$i = 5126;
      break;
     }
     case 3:  {
      $$0$i = 5120;
      break;
     }
     case 1:  {
      $24 = HEAP32[1152880>>2]|0;
      $25 = (($24) + 36|0);
      $26 = HEAP32[$25>>2]|0;
      $$0$i = $26;
      break;
     }
     default: {
      __Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE(1157776,0,1157800,37,1,0,0,0);
      $$0$i = 0;
     }
     }
     $27 = ((($decl) + ($15<<2)|0) + 5|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = ((($decl) + ($15<<2)|0) + 4|0);
     $30 = HEAP8[$29>>0]|0;
     $31 = $30&255;
     $32 = ($31>>>0)>($vertexStreamCount>>>0);
     if ($32) {
      $vboBound$2 = $vboBound$04;
     } else {
      $33 = (($vertexStreams) + ($31<<3)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==(0|0);
      if ($35) {
       $vboBound$2 = $vboBound$04;
      } else {
       $36 = (($34) + 24|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = (($37) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = ($39|0)==($vboBound$04|0);
       if ($40) {
        $vboBound$1 = $vboBound$04;
       } else {
        $41 = (1147664 + 12|0);
        $42 = HEAP32[$41>>2]|0;
        FUNCTION_TABLE_vii[$42 & 4095](34962,$39);
        $43 = HEAP32[$36>>2]|0;
        $44 = (($43) + 4|0);
        $45 = HEAP32[$44>>2]|0;
        $vboBound$1 = $45;
       }
       $46 = ((($vertexStreams) + ($31<<3)|0) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = $28&255;
       $49 = $48;
       switch ($i$01|0) {
       case 1:  {
        $attribIndex$0$i = 1;$normalize$0$i = 1;
        break;
       }
       case 27: case 26: case 25: case 24: case 23: case 22: case 21: case 20: case 19: case 18: case 17: case 16: case 15: case 14: case 13: case 12:  {
        $52 = (($i$01) + -12)|0;
        $attribIndex$0$i = $52;$normalize$0$i = 1;
        break;
       }
       case 0:  {
        $attribIndex$0$i = $i$01;$normalize$0$i = 0;
        break;
       }
       case 2:  {
        $attribIndex$0$i = $i$01;$normalize$0$i = 0;
        break;
       }
       case 11: case 10: case 9: case 8: case 7: case 6: case 5: case 4:  {
        $50 = (($i$01) + -1)|0;
        $attribIndex$0$i = $50;$normalize$0$i = 0;
        break;
       }
       case 3:  {
        _printf_console(1157688,$vararg_buffer1);
        $51 = (($i$01) + 1)|0;
        $i$01 = $51;$vboBound$04 = $vboBound$1;
        continue L4;
        break;
       }
       default: {
        $vboBound$2 = $vboBound$1;
        break L7;
       }
       }
       $53 = HEAP32[((640792 + 280|0))>>2]|0;
       $54 = ($attribIndex$0$i>>>0)<($53>>>0);
       if (!($54)) {
        _printf_console(1157728,$vararg_buffer1);
        $vboBound$2 = $vboBound$1;
        break;
       }
       $55 = (1147664 + 148|0);
       $56 = HEAP32[$55>>2]|0;
       FUNCTION_TABLE_vi[$56 & 4095]($attribIndex$0$i);
       $57 = ($$0$i|0)==(5125);
       if ($57) {
        $58 = (1147664 + 464|0);
        $59 = HEAP32[$58>>2]|0;
        FUNCTION_TABLE_viiiii[$59 & 255]($attribIndex$0$i,$$,5125,$47,$49);
        $vboBound$2 = $vboBound$1;
        break;
       } else {
        $60 = (1147664 + 368|0);
        $61 = HEAP32[$60>>2]|0;
        FUNCTION_TABLE_viiiiii[$61 & 255]($attribIndex$0$i,$$,$$0$i,$normalize$0$i,$47,$49);
        $vboBound$2 = $vboBound$1;
        break;
       }
      }
     }
    }
   }
  } while(0);
  $62 = (($i$01) + 1)|0;
  $63 = ($62|0)<(28);
  if ($63) {
   $i$01 = $62;$vboBound$04 = $vboBound$2;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 28) {
  STACKTOP = sp;return;
 }
}
function __ZN4gles8internal12InitApiGLES2EP12GraphicsCapsP12CoreFuncGLESP11ExtFuncGLES($caps,$core,$ext) {
 $caps = $caps|0;
 $core = $core|0;
 $ext = $ext|0;
 var $$ = 0, $$$i = 0, $$0$i = 0, $$str18$$str19$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$i = 0, $or$cond$i = 0, $or$cond1$i = 0, $phitmp = 0, $phitmp1 = 0, $phitmp2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z19GetGLExtProcAddressPKc(1158488)|0);
 $1 = (($core) + 416|0);
 HEAP32[$1>>2] = $0;
 $2 = (($caps) + 369|0);
 $3 = (($caps) + 370|0);
 $4 = (($caps) + 312|0);
 $5 = (__Z14QueryExtensionPKc(1158128)|0);
 $6 = (__Z14QueryExtensionPKc(1158168)|0);
 $7 = (__Z14QueryExtensionPKc(1158208)|0);
 do {
  if ($5) {
   $8 = (__Z19GetGLExtProcAddressPKc(1158248)|0);
   $9 = (($core) + 424|0);
   HEAP32[$9>>2] = $8;
   $10 = (__Z19GetGLExtProcAddressPKc(1158288)|0);
   $11 = (($ext) + 20|0);
   HEAP32[$11>>2] = $10;
   $12 = HEAP32[$9>>2]|0;
   $13 = ($12|0)==(0|0);
   $14 = ($10|0)==(0|0);
   $or$cond$i = $13 | $14;
   if ($or$cond$i) {
    HEAP32[$9>>2] = 0;
    HEAP32[$11>>2] = 0;
    break;
   } else {
    HEAP8[$2>>0] = 1;
    HEAP32[$4>>2] = 36183;
    break;
   }
  }
 } while(0);
 $brmerge$i = $6 | $7;
 do {
  if ($brmerge$i) {
   $$str18$$str19$i = $6 ? 1158328 : 1158368;
   $15 = $6 ? 1158408 : 1158448;
   $16 = (__Z19GetGLExtProcAddressPKc($$str18$$str19$i)|0);
   $17 = (($core) + 424|0);
   HEAP32[$17>>2] = $16;
   $18 = (__Z19GetGLExtProcAddressPKc($15)|0);
   $19 = (($ext) + 16|0);
   HEAP32[$19>>2] = $18;
   $20 = HEAP32[$17>>2]|0;
   $21 = ($20|0)==(0|0);
   $22 = ($18|0)==(0|0);
   $or$cond1$i = $21 | $22;
   if ($or$cond1$i) {
    HEAP32[$17>>2] = 0;
    HEAP32[$19>>2] = 0;
    break;
   } else {
    $23 = $6 ? 37173 : 36183;
    HEAP8[$3>>0] = 1;
    HEAP32[$4>>2] = $23;
    break;
   }
  }
 } while(0);
 $24 = HEAP8[$3>>0]|0;
 $25 = (($caps) + 130|0);
 HEAP8[$25>>0] = $24;
 $26 = HEAP8[$2>>0]|0;
 $27 = ($26<<24>>24)==(0);
 $$ = $27 ? $24 : 1;
 $28 = (($caps) + 129|0);
 HEAP8[$28>>0] = $$;
 $29 = (__Z14QueryExtensionPKc(1157808)|0);
 $30 = (($caps) + 225|0);
 $31 = $29&1;
 HEAP8[$30>>0] = $31;
 $32 = HEAP8[$28>>0]|0;
 $33 = ($32<<24>>24)==(0);
 if (!($33)) {
  $34 = (1147664 + 212|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = HEAP32[$4>>2]|0;
  $37 = (($caps) + 288|0);
  FUNCTION_TABLE_vii[$35 & 4095]($36,$37);
 }
 $38 = (($caps) + 316|0);
 HEAP32[$38>>2] = 36193;
 $39 = (($caps) + 328|0);
 HEAP32[$39>>2] = 36196;
 $40 = (__Z14QueryExtensionPKc(1157832)|0);
 $41 = (($caps) + 340|0);
 $42 = $40&1;
 HEAP8[$41>>0] = $42;
 $43 = (($caps) + 320|0);
 HEAP32[$43>>2] = 35906;
 $44 = (($caps) + 324|0);
 HEAP32[$44>>2] = 35904;
 $45 = (__Z14QueryExtensionPKc(1157848)|0);
 if ($45) {
  $46 = (__Z28InitBinaryShadersSupportGLESv()|0);
  $phitmp = $46&1;
  $48 = $phitmp;
 } else {
  $48 = 0;
 }
 $47 = (($caps) + 343|0);
 HEAP8[$47>>0] = $48;
 $49 = (($caps) + 344|0);
 HEAP8[$49>>0] = 0;
 $50 = (($caps) + 345|0);
 HEAP8[$50>>0] = 0;
 $51 = (__Z14QueryExtensionPKc(1157880)|0);
 $52 = (($caps) + 349|0);
 $53 = $51&1;
 HEAP8[$52>>0] = $53;
 $54 = (__Z14QueryExtensionPKc(1157912)|0);
 $55 = (($caps) + 348|0);
 $56 = $54&1;
 HEAP8[$55>>0] = $56;
 $57 = (($caps) + 351|0);
 HEAP8[$57>>0] = 0;
 $58 = (__Z14QueryExtensionPKc(1157936)|0);
 if ($58) {
  $61 = 1;
 } else {
  $59 = (__Z14QueryExtensionPKc(1157960)|0);
  $phitmp1 = $59&1;
  $61 = $phitmp1;
 }
 $60 = (($caps) + 350|0);
 HEAP8[$60>>0] = $61;
 $62 = (__Z14QueryExtensionPKc(1157984)|0);
 $63 = (($caps) + 352|0);
 $64 = $62&1;
 HEAP8[$63>>0] = $64;
 $65 = (__Z14QueryExtensionPKc(1158008)|0);
 $66 = (($caps) + 353|0);
 $67 = $65&1;
 HEAP8[$66>>0] = $67;
 $68 = (__Z14QueryExtensionPKc(1158024)|0);
 if ($68) {
  $69 = (($caps) + 371|0);
  $70 = HEAP8[$69>>0]|0;
  $phitmp2 = $70 ^ 1;
  $72 = $phitmp2;
 } else {
  $72 = 0;
 }
 $71 = (($caps) + 354|0);
 HEAP8[$71>>0] = $72;
 $73 = $72 & 1;
 $74 = (($caps) + 355|0);
 HEAP8[$74>>0] = $73;
 $75 = (($caps) + 356|0);
 HEAP8[$75>>0] = 0;
 $76 = (__Z14QueryExtensionPKc(1158048)|0);
 $77 = (($caps) + 357|0);
 $78 = $76&1;
 HEAP8[$77>>0] = $78;
 $79 = (__Z14QueryExtensionPKc(1158072)|0);
 $80 = (($caps) + 358|0);
 $81 = $79&1;
 HEAP8[$80>>0] = $81;
 $82 = HEAP8[$60>>0]|0;
 $83 = ($82<<24>>24)==(0);
 if ($83) {
  label = 20;
 } else {
  $84 = (__Z14QueryExtensionPKc(1158096)|0);
  if ($84) {
   $85 = (($caps) + 120|0);
   HEAP32[$85>>2] = 1;
   $90 = $85;
   label = 21;
  } else {
   label = 20;
  }
 }
 if ((label|0) == 20) {
  $86 = (__Z14QueryExtensionPKc(1157960)|0);
  $87 = (($caps) + 120|0);
  HEAP32[$87>>2] = 1;
  if ($86) {
   $90 = $87;
   label = 21;
  }
 }
 if ((label|0) == 21) {
  $88 = (1147664 + 212|0);
  $89 = HEAP32[$88>>2]|0;
  FUNCTION_TABLE_vii[$89 & 4095](36063,$90);
  $91 = HEAP32[$90>>2]|0;
  $92 = ($91|0)<(1);
  if ($92) {
   $$0$i = 1;
  } else {
   $93 = ($91|0)>(8);
   $$$i = $93 ? 8 : $91;
   $$0$i = $$$i;
  }
  HEAP32[$90>>2] = $$0$i;
 }
 $94 = (($caps) + 335|0);
 $95 = HEAP8[$94>>0]|0;
 $96 = ($95<<24>>24)==(0);
 if (!($96)) {
  $100 = 1;
  $99 = (($caps) + 360|0);
  HEAP8[$99>>0] = $100;
  STACKTOP = sp;return;
 }
 $97 = (($caps) + 334|0);
 $98 = HEAP8[$97>>0]|0;
 $100 = $98;
 $99 = (($caps) + 360|0);
 HEAP8[$99>>0] = $100;
 STACKTOP = sp;return;
}
function __ZN12GraphicsCaps10InitGLES20Ev($this) {
 $this = $this|0;
 var $$pr$pre = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $phitmp2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 304|0);
 HEAP32[$0>>2] = 200;
 $1 = (($this) + 296|0);
 HEAP32[$1>>2] = 0;
 $2 = (1147664 + 212|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 300|0);
 FUNCTION_TABLE_vii[$3 & 4095](36347,$4);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 << 2;
 HEAP32[$4>>2] = $6;
 $7 = (__Z14QueryExtensionPKc(1158504)|0);
 $8 = (($this) + 126|0);
 $9 = $7&1;
 HEAP8[$8>>0] = $9;
 $10 = (__Z14QueryExtensionPKc(1158528)|0);
 $11 = (($this) + 127|0);
 $12 = $10&1;
 HEAP8[$11>>0] = $12;
 $13 = (($this) + 132|0);
 HEAP8[$13>>0] = 1;
 $14 = (($this) + 133|0);
 HEAP8[$14>>0] = 1;
 $15 = (($this) + 134|0);
 HEAP8[$15>>0] = 1;
 $16 = (__Z14QueryExtensionPKc(1158560)|0);
 $17 = (($this) + 135|0);
 $18 = $16&1;
 HEAP8[$17>>0] = $18;
 $19 = (($this) + 140|0);
 HEAP8[$19>>0] = 1;
 $20 = (($this) + 228|0);
 HEAP32[$20>>2] = 1;
 $21 = (__Z14QueryExtensionPKc(1158584)|0);
 if ($21) {
  label = 4;
 } else {
  $22 = (__Z14QueryExtensionPKc(1158608)|0);
  if ($22) {
   label = 4;
  } else {
   $$pre = HEAP32[$20>>2]|0;
   $24 = $$pre;
  }
 }
 if ((label|0) == 4) {
  HEAP32[$20>>2] = 2;
  $24 = 2;
 }
 $23 = (($this) + 232|0);
 HEAP32[$23>>2] = $24;
 $25 = (($this) + 241|0);
 HEAP8[$25>>0] = 1;
 $26 = (($this) + 250|0);
 HEAP8[$26>>0] = 0;
 $27 = (($this) + 254|0);
 HEAP8[$27>>0] = 0;
 $28 = (($this) + 242|0);
 HEAP8[$28>>0] = 1;
 (__Z14QueryExtensionPKc(1158640)|0);
 $29 = (($this) + 246|0);
 HEAP8[$29>>0] = 1;
 $30 = (($this) + 253|0);
 HEAP8[$30>>0] = 1;
 $31 = (($this) + 244|0);
 HEAP8[$31>>0] = 1;
 $32 = (($this) + 334|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = ($33<<24>>24)==(0);
 do {
  if ($34) {
   label = 9;
  } else {
   $35 = (__Z14QueryExtensionPKc(1158672)|0);
   if ($35) {
    $$pr$pre = HEAP8[$29>>0]|0;
    $phitmp2 = ($$pr$pre<<24>>24)==(0);
    if ($phitmp2) {
     $39 = 0;
     break;
    } else {
     label = 9;
     break;
    }
   } else {
    HEAP8[$29>>0] = 0;
    $39 = 0;
    break;
   }
  }
 } while(0);
 if ((label|0) == 9) {
  $36 = (($this) + 247|0);
  $37 = HEAP8[$36>>0]|0;
  $39 = $37;
 }
 $38 = (($this) + 248|0);
 HEAP8[$38>>0] = $39;
 $40 = (__Z14QueryExtensionPKc(1158704)|0);
 $41 = (($this) + 256|0);
 $42 = $40&1;
 HEAP8[$41>>0] = $42;
 $43 = (($this) + 257|0);
 HEAP8[$43>>0] = 1;
 $44 = (($this) + 258|0);
 HEAP8[$44>>0] = 0;
 $45 = (($this) + 223|0);
 HEAP8[$45>>0] = 1;
 $46 = (__Z14QueryExtensionPKc(1158736)|0);
 $47 = (($this) + 237|0);
 $48 = $46&1;
 HEAP8[$47>>0] = $48;
 if (!($46)) {
  $50 = 0;
  HEAP8[$47>>0] = $50;
  $51 = (($this) + 272|0);
  HEAP8[$51>>0] = 0;
  $52 = (__Z14QueryExtensionPKc(1158776)|0);
  $53 = (($this) + 364|0);
  $54 = $52&1;
  HEAP8[$53>>0] = $54;
  HEAP8[((640792 + 139|0))>>0] = 0;
  STACKTOP = sp;return;
 }
 $49 = (__Z14QueryExtensionPKc(1158752)|0);
 $phitmp = $49&1;
 $50 = $phitmp;
 HEAP8[$47>>0] = $50;
 $51 = (($this) + 272|0);
 HEAP8[$51>>0] = 0;
 $52 = (__Z14QueryExtensionPKc(1158776)|0);
 $53 = (($this) + 364|0);
 $54 = $52&1;
 HEAP8[$53>>0] = $54;
 HEAP8[((640792 + 139|0))>>0] = 0;
 STACKTOP = sp;return;
}
function __Z21CreateGLES20GfxDevicev() {
 var $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy6 = sp;
 $0 = sp + 4|0;
 (__ZN11ContextGLES6CreateEi(2)|0);
 __ZN4gles7InitApiE17GfxDeviceRendererP12GraphicsCaps(8,640792);
 __ZN12GraphicsCaps10InitGLES20Ev(640792);
 $1 = HEAP32[628280>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(8256,$$byval_copy6,1,16,1158816,169)|0);
 __THREW__ = 0;
 invoke_vi(3797,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $eh$lpad$body$index2Z2D = $15;$eh$lpad$body$indexZ2D = $14;
 } else {
  HEAP32[$2>>2] = ((1158824 + 8|0));
  __THREW__ = 0;
  invoke_vii(2587,(1159656|0),($$byval_copy6|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $13 = (($2) + 5928|0);
   HEAP32[$13>>2] = 8;
   STACKTOP = sp;return ($2|0);
  }
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __THREW__ = 0;
  invoke_vi(1352,($2|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   $11 = ___cxa_find_matching_catch(0|0)|0;
   $12 = tempRet0;
   ___clang_call_terminate($11);
   // unreachable;
  } else {
   $eh$lpad$body$index2Z2D = $8;$eh$lpad$body$indexZ2D = $7;
  }
 }
 __THREW__ = 0;
 ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(97,($2|0),($$byval_copy6|0),1,16,(1158816|0),169);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch(0|0)|0;
  $19 = tempRet0;
  ___clang_call_terminate($18);
  // unreachable;
 } else {
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN15GfxDeviceGLES20D1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13GfxDeviceGLESD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN15GfxDeviceGLES20D0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 invoke_vi(1352,($this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZdlPv($this);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZdlPv($this);
  STACKTOP = sp;return;
 }
}
function __ZN3ffp4gles16BuildVProgSourceERKNS_5StateEi($agg$result,$state,$glslVer) {
 $agg$result = $agg$result|0;
 $state = $state|0;
 $glslVer = $glslVer|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$01$i = 0, $$sink$i$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $eh$lpad$body$indexZ2D = 0, $i$022 = 0, $i1$014 = 0, $i3$010 = 0, $lpad$phi$index = 0, $lpad$phi$index10 = 0, $q$018 = 0, $src = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 148|0;
 $src = sp;
 $1 = sp + 136|0;
 $2 = (($src) + 56|0);
 $3 = (($src) + 4|0);
 HEAP32[$src>>2] = ((390272 + 12|0));
 $4 = (($src) + 56|0);
 HEAP32[$4>>2] = ((390272 + 32|0));
 $5 = (($src) + 56|0);
 __THREW__ = 0;
 invoke_vii(2480,($5|0),($3|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if ($7) {
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   $$01$i = $37;$$sink$i$index2 = $38;
  } else {
   $8 = (($src) + 128|0);
   HEAP32[$8>>2] = 0;
   $9 = (($src) + 132|0);
   HEAP32[$9>>2] = -1;
   HEAP32[$src>>2] = ((390232 + 12|0));
   HEAP32[$2>>2] = ((390232 + 32|0));
   HEAP32[$3>>2] = ((3090568 + 8|0));
   $10 = (($src) + 8|0);
   __ZNSt3__16localeC2Ev($10);
   $11 = (($src) + 12|0);
   ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;
   HEAP32[$3>>2] = ((225848 + 8|0));
   $12 = (($src) + 36|0);
   $13 = (($src) + 52|0);
   ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
   HEAP32[$13>>2] = 16;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(2481,($3|0),($0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $21 = ___cxa_find_matching_catch()|0;
    $22 = tempRet0;
    $23 = HEAP8[$0>>0]|0;
    $24 = $23 & 1;
    $25 = ($24<<24>>24)==(0);
    if (!($25)) {
     $26 = (($0) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     __ZdlPv($27);
    }
    $28 = HEAP8[$12>>0]|0;
    $29 = $28 & 1;
    $30 = ($29<<24>>24)==(0);
    if (!($30)) {
     $31 = (($src) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __ZdlPv($32);
    }
    HEAP32[$3>>2] = ((3090568 + 8|0));
    __THREW__ = 0;
    invoke_vi(3299,($10|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch(0|0)|0;
     $36 = tempRet0;
     ___clang_call_terminate($35);
     // unreachable;
    } else {
     $$01$i = $21;$$sink$i$index2 = $22;
     break;
    }
   }
   $16 = HEAP8[$0>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if (!($18)) {
    $19 = (($0) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    __ZdlPv($20);
   }
   $43 = (($state) + 41|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = $44 & 1;
   $46 = ($45<<24>>24)==(0);
   if ($46) {
    $744 = 0;
   } else {
    $47 = (($state) + 37|0);
    $48 = HEAP8[$47>>0]|0;
    $49 = ($48<<24>>24)==(0);
    if ($49) {
     $744 = 0;
    } else {
     $50 = $44 & 4;
     $51 = ($50<<24>>24)==(0);
     $744 = $51;
    }
   }
   $52 = ($glslVer|0)>(299);
   if ($52) {
    __THREW__ = 0;
    $53 = (invoke_iii(2239,($src|0),(1159696|0))|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 27;
    } else {
     __THREW__ = 0;
     $56 = (invoke_iii(2240,($53|0),($glslVer|0))|0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      label = 27;
     } else {
      __THREW__ = 0;
      (invoke_iii(2239,($56|0),(1159712|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 27;
      } else {
       label = 29;
      }
     }
    }
   } else {
    label = 29;
   }
   L26: do {
    if ((label|0) == 29) {
     $71 = $52 ? 1159720 : 1159728;
     $72 = $52 ? 1159744 : 1159752;
     $73 = HEAP32[1152880>>2]|0;
     $74 = (($73) + 65|0);
     $75 = HEAP8[$74>>0]|0;
     $76 = ($75<<24>>24)!=(0);
     $77 = $76 ? 1159768 : 1159776;
     if ($76) {
      __THREW__ = 0;
      $78 = (invoke_iii(2239,($src|0),(1159776|0))|0);
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       label = 27;
       break;
      }
      __THREW__ = 0;
      $81 = (invoke_ii(3309,(1151832|0))|0);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       label = 27;
       break;
      }
      __THREW__ = 0;
      $84 = (invoke_iii(2239,($78|0),($81|0))|0);
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if ($86) {
       label = 27;
       break;
      }
      __THREW__ = 0;
      (invoke_iii(2239,($84|0),(1159792|0))|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 27;
       break;
      }
     }
     __THREW__ = 0;
     $89 = (invoke_iii(2239,($src|0),(1159800|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 27;
     } else {
      __THREW__ = 0;
      $92 = (invoke_iii(2239,($89|0),($77|0))|0);
      $93 = __THREW__; __THREW__ = 0;
      $94 = $93&1;
      if ($94) {
       label = 27;
      } else {
       __THREW__ = 0;
       $95 = (invoke_iii(2239,($92|0),(1159808|0))|0);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if ($97) {
        label = 27;
       } else {
        __THREW__ = 0;
        $98 = (invoke_ii(3462,0)|0);
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 27;
        } else {
         __THREW__ = 0;
         $101 = (invoke_iii(2239,($95|0),($98|0))|0);
         $102 = __THREW__; __THREW__ = 0;
         $103 = $102&1;
         if ($103) {
          label = 27;
         } else {
          __THREW__ = 0;
          (invoke_iii(2239,($101|0),(1159824|0))|0);
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 27;
          } else {
           if ($744) {
            __THREW__ = 0;
            $106 = (invoke_iii(2239,($src|0),(1159800|0))|0);
            $107 = __THREW__; __THREW__ = 0;
            $108 = $107&1;
            if ($108) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            $109 = (invoke_iii(2239,($106|0),($77|0))|0);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if ($111) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            $112 = (invoke_iii(2239,($109|0),(1159808|0))|0);
            $113 = __THREW__; __THREW__ = 0;
            $114 = $113&1;
            if ($114) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            $115 = (invoke_ii(3462,1)|0);
            $116 = __THREW__; __THREW__ = 0;
            $117 = $116&1;
            if ($117) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            $118 = (invoke_iii(2239,($112|0),($115|0))|0);
            $119 = __THREW__; __THREW__ = 0;
            $120 = $119&1;
            if ($120) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            (invoke_iii(2239,($118|0),(1159824|0))|0);
            $121 = __THREW__; __THREW__ = 0;
            $122 = $121&1;
            if ($122) {
             label = 27;
             break;
            }
           }
           $123 = HEAP32[1152880>>2]|0;
           $124 = (($123) + 65|0);
           $125 = HEAP8[$124>>0]|0;
           $126 = ($125<<24>>24)==(0);
           if (!($126)) {
            __THREW__ = 0;
            (invoke_iii(2239,($src|0),(1159832|0))|0);
            $127 = __THREW__; __THREW__ = 0;
            $128 = $127&1;
            if ($128) {
             label = 27;
             break;
            }
           }
           __THREW__ = 0;
           $129 = (invoke_iii(2239,($src|0),($71|0))|0);
           $130 = __THREW__; __THREW__ = 0;
           $131 = $130&1;
           if ($131) {
            label = 27;
           } else {
            __THREW__ = 0;
            (invoke_iii(2239,($129|0),(1159840|0))|0);
            $132 = __THREW__; __THREW__ = 0;
            $133 = $132&1;
            if ($133) {
             label = 27;
            } else {
             __THREW__ = 0;
             $134 = (invoke_iii(2239,($src|0),($71|0))|0);
             $135 = __THREW__; __THREW__ = 0;
             $136 = $135&1;
             if ($136) {
              label = 27;
             } else {
              __THREW__ = 0;
              (invoke_iii(2239,($134|0),(1159872|0))|0);
              $137 = __THREW__; __THREW__ = 0;
              $138 = $137&1;
              if ($138) {
               label = 27;
              } else {
               $139 = HEAP8[$43>>0]|0;
               $140 = $139 & 8;
               $141 = ($140<<24>>24)==(0);
               if ($141) {
                __THREW__ = 0;
                $144 = (invoke_iii(2239,($src|0),($71|0))|0);
                $145 = __THREW__; __THREW__ = 0;
                $146 = $145&1;
                if ($146) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($144|0),(1159944|0))|0);
                $147 = __THREW__; __THREW__ = 0;
                $148 = $147&1;
                if ($148) {
                 label = 27;
                 break;
                }
               } else {
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1159904|0))|0);
                $142 = __THREW__; __THREW__ = 0;
                $143 = $142&1;
                if ($143) {
                 label = 27;
                 break;
                }
               }
               __THREW__ = 0;
               $149 = (invoke_iii(2239,($src|0),($72|0))|0);
               $150 = __THREW__; __THREW__ = 0;
               $151 = $150&1;
               if ($151) {
                label = 27;
                break;
               }
               __THREW__ = 0;
               (invoke_iii(2239,($149|0),(1159968|0))|0);
               $152 = __THREW__; __THREW__ = 0;
               $153 = $152&1;
               if ($153) {
                label = 27;
                break;
               }
               $154 = (($state) + 39|0);
               $155 = HEAP8[$154>>0]|0;
               $156 = ($155<<24>>24)>(0);
               if ($156) {
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1159992|0))|0);
                $157 = __THREW__; __THREW__ = 0;
                $158 = $157&1;
                if ($158) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1160032|0))|0);
                $159 = __THREW__; __THREW__ = 0;
                $160 = $159&1;
                if ($160) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                $161 = (invoke_iii(2239,($src|0),($72|0))|0);
                $162 = __THREW__; __THREW__ = 0;
                $163 = $162&1;
                if ($163) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($161|0),(1160072|0))|0);
                $164 = __THREW__; __THREW__ = 0;
                $165 = $164&1;
                if ($165) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                $166 = (invoke_iii(2239,($src|0),($72|0))|0);
                $167 = __THREW__; __THREW__ = 0;
                $168 = $167&1;
                if ($168) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($166|0),(1160104|0))|0);
                $169 = __THREW__; __THREW__ = 0;
                $170 = $169&1;
                if ($170) {
                 label = 27;
                 break;
                }
               }
               $171 = (($state) + 36|0);
               $172 = HEAP8[$171>>0]|0;
               $173 = $172&255;
               $174 = ($172<<24>>24)==(0);
               L70: do {
                if (!($174)) {
                 $175 = (($state) + 38|0);
                 $i$022 = 0;
                 while(1) {
                  __THREW__ = 0;
                  $176 = (invoke_iii(2239,($src|0),($71|0))|0);
                  $177 = __THREW__; __THREW__ = 0;
                  $178 = $177&1;
                  if ($178) {
                   break;
                  }
                  __THREW__ = 0;
                  $179 = (invoke_iii(2239,($176|0),(1160128|0))|0);
                  $180 = __THREW__; __THREW__ = 0;
                  $181 = $180&1;
                  if ($181) {
                   break;
                  }
                  __THREW__ = 0;
                  $182 = (invoke_iii(2240,($179|0),($i$022|0))|0);
                  $183 = __THREW__; __THREW__ = 0;
                  $184 = $183&1;
                  if ($184) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($182|0),(1159824|0))|0);
                  $185 = __THREW__; __THREW__ = 0;
                  $186 = $185&1;
                  if ($186) {
                   break;
                  }
                  __THREW__ = 0;
                  $187 = (invoke_iii(2239,($src|0),(1160160|0))|0);
                  $188 = __THREW__; __THREW__ = 0;
                  $189 = $188&1;
                  if ($189) {
                   break;
                  }
                  __THREW__ = 0;
                  $190 = (invoke_iii(2240,($187|0),($i$022|0))|0);
                  $191 = __THREW__; __THREW__ = 0;
                  $192 = $191&1;
                  if ($192) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($190|0),(1159824|0))|0);
                  $193 = __THREW__; __THREW__ = 0;
                  $194 = $193&1;
                  if ($194) {
                   break;
                  }
                  $195 = HEAP8[$175>>0]|0;
                  $196 = $195&255;
                  $197 = 1 << $i$022;
                  $198 = $196 & $197;
                  $199 = ($198|0)==(0);
                  if ($199) {
                   __THREW__ = 0;
                   $211 = (invoke_iii(2239,($src|0),($72|0))|0);
                   $212 = __THREW__; __THREW__ = 0;
                   $213 = $212&1;
                   if ($213) {
                    break;
                   }
                   __THREW__ = 0;
                   $214 = (invoke_iii(2239,($211|0),(1160224|0))|0);
                   $215 = __THREW__; __THREW__ = 0;
                   $216 = $215&1;
                   if ($216) {
                    break;
                   }
                   __THREW__ = 0;
                   $217 = (invoke_iii(2240,($214|0),($i$022|0))|0);
                   $218 = __THREW__; __THREW__ = 0;
                   $219 = $218&1;
                   if ($219) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($217|0),(1159824|0))|0);
                   $220 = __THREW__; __THREW__ = 0;
                   $221 = $220&1;
                   if ($221) {
                    break;
                   }
                  } else {
                   __THREW__ = 0;
                   $200 = (invoke_iii(2239,($src|0),($72|0))|0);
                   $201 = __THREW__; __THREW__ = 0;
                   $202 = $201&1;
                   if ($202) {
                    break;
                   }
                   __THREW__ = 0;
                   $203 = (invoke_iii(2239,($200|0),(1160200|0))|0);
                   $204 = __THREW__; __THREW__ = 0;
                   $205 = $204&1;
                   if ($205) {
                    break;
                   }
                   __THREW__ = 0;
                   $206 = (invoke_iii(2240,($203|0),($i$022|0))|0);
                   $207 = __THREW__; __THREW__ = 0;
                   $208 = $207&1;
                   if ($208) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($206|0),(1159824|0))|0);
                   $209 = __THREW__; __THREW__ = 0;
                   $210 = $209&1;
                   if ($210) {
                    break;
                   }
                  }
                  $222 = (($i$022) + 1)|0;
                  $223 = ($222|0)<($173|0);
                  if ($223) {
                   $i$022 = $222;
                  } else {
                   break L70;
                  }
                 }
                 $67 = ___cxa_find_matching_catch()|0;
                 $68 = tempRet0;
                 $lpad$phi$index = $67;$lpad$phi$index10 = $68;
                 label = 28;
                 break L26;
                }
               } while(0);
               $224 = HEAP8[$43>>0]|0;
               $225 = $224 & 16;
               $226 = ($225<<24>>24)!=(0);
               $227 = $226 ? 1160248 : 1160264;
               $228 = $226 ? 1160248 : 1160296;
               $229 = $224 & 32;
               $230 = ($229<<24>>24)!=(0);
               $231 = $230 ? 1160248 : 1160328;
               $232 = $224 & 1;
               $233 = ($232<<24>>24)==(0);
               do {
                if (!($233)) {
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160360|0))|0);
                 $234 = __THREW__; __THREW__ = 0;
                 $235 = $234&1;
                 if ($235) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160392|0))|0);
                 $236 = __THREW__; __THREW__ = 0;
                 $237 = $236&1;
                 if ($237) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1159832|0))|0);
                 $238 = __THREW__; __THREW__ = 0;
                 $239 = $238&1;
                 if ($239) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160416|0))|0);
                 $240 = __THREW__; __THREW__ = 0;
                 $241 = $240&1;
                 if ($241) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160448|0))|0);
                 $242 = __THREW__; __THREW__ = 0;
                 $243 = $242&1;
                 if ($243) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160392|0))|0);
                 $244 = __THREW__; __THREW__ = 0;
                 $245 = $244&1;
                 if ($245) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160472|0))|0);
                 $246 = __THREW__; __THREW__ = 0;
                 $247 = $246&1;
                 if ($247) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160496|0))|0);
                 $248 = __THREW__; __THREW__ = 0;
                 $249 = $248&1;
                 if ($249) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160520|0))|0);
                 $250 = __THREW__; __THREW__ = 0;
                 $251 = $250&1;
                 if ($251) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1159832|0))|0);
                 $252 = __THREW__; __THREW__ = 0;
                 $253 = $252&1;
                 if ($253) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160544|0))|0);
                 $254 = __THREW__; __THREW__ = 0;
                 $255 = $254&1;
                 if ($255) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160592|0))|0);
                 $256 = __THREW__; __THREW__ = 0;
                 $257 = $256&1;
                 if ($257) {
                  label = 27;
                  break L26;
                 }
                 $258 = (($state) + 37|0);
                 $259 = HEAP8[$258>>0]|0;
                 $260 = ($259<<24>>24)==(0);
                 if ($260) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160640|0))|0);
                 $261 = __THREW__; __THREW__ = 0;
                 $262 = $261&1;
                 if ($262) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160472|0))|0);
                 $263 = __THREW__; __THREW__ = 0;
                 $264 = $263&1;
                 if ($264) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160672|0))|0);
                 $265 = __THREW__; __THREW__ = 0;
                 $266 = $265&1;
                 if ($266) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160696|0))|0);
                 $267 = __THREW__; __THREW__ = 0;
                 $268 = $267&1;
                 if ($268) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160728|0))|0);
                 $269 = __THREW__; __THREW__ = 0;
                 $270 = $269&1;
                 if ($270) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1159832|0))|0);
                 $271 = __THREW__; __THREW__ = 0;
                 $272 = $271&1;
                 if ($272) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 $273 = (invoke_iii(2239,($src|0),(1160752|0))|0);
                 $274 = __THREW__; __THREW__ = 0;
                 $275 = $274&1;
                 if ($275) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 $276 = (invoke_ii(3463,32)|0);
                 $277 = __THREW__; __THREW__ = 0;
                 $278 = $277&1;
                 if ($278) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 $279 = (invoke_iii(2239,($273|0),($276|0))|0);
                 $280 = __THREW__; __THREW__ = 0;
                 $281 = $280&1;
                 if ($281) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($279|0),(1159824|0))|0);
                 $282 = __THREW__; __THREW__ = 0;
                 $283 = $282&1;
                 if ($283) {
                  label = 27;
                  break L26;
                 } else {
                  $q$018 = 0;
                 }
                 while(1) {
                  __THREW__ = 0;
                  $284 = (invoke_iii(2239,($src|0),(1160752|0))|0);
                  $285 = __THREW__; __THREW__ = 0;
                  $286 = $285&1;
                  if ($286) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $287 = (invoke_ii(3463,($q$018|0))|0);
                  $288 = __THREW__; __THREW__ = 0;
                  $289 = $288&1;
                  if ($289) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $290 = (invoke_iii(2239,($284|0),($287|0))|0);
                  $291 = __THREW__; __THREW__ = 0;
                  $292 = $291&1;
                  if ($292) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($290|0),(1159824|0))|0);
                  $293 = __THREW__; __THREW__ = 0;
                  $294 = $293&1;
                  if ($294) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $295 = (invoke_iii(2239,($src|0),(1160752|0))|0);
                  $296 = __THREW__; __THREW__ = 0;
                  $297 = $296&1;
                  if ($297) {
                   label = 25;
                   break;
                  }
                  $298 = (($q$018) + 8)|0;
                  __THREW__ = 0;
                  $299 = (invoke_ii(3463,($298|0))|0);
                  $300 = __THREW__; __THREW__ = 0;
                  $301 = $300&1;
                  if ($301) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $302 = (invoke_iii(2239,($295|0),($299|0))|0);
                  $303 = __THREW__; __THREW__ = 0;
                  $304 = $303&1;
                  if ($304) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($302|0),(1159824|0))|0);
                  $305 = __THREW__; __THREW__ = 0;
                  $306 = $305&1;
                  if ($306) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $307 = (invoke_iii(2239,($src|0),(1160752|0))|0);
                  $308 = __THREW__; __THREW__ = 0;
                  $309 = $308&1;
                  if ($309) {
                   label = 25;
                   break;
                  }
                  $310 = (($q$018) + 16)|0;
                  __THREW__ = 0;
                  $311 = (invoke_ii(3463,($310|0))|0);
                  $312 = __THREW__; __THREW__ = 0;
                  $313 = $312&1;
                  if ($313) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $314 = (invoke_iii(2239,($307|0),($311|0))|0);
                  $315 = __THREW__; __THREW__ = 0;
                  $316 = $315&1;
                  if ($316) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($314|0),(1159824|0))|0);
                  $317 = __THREW__; __THREW__ = 0;
                  $318 = $317&1;
                  if ($318) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $319 = (invoke_iii(2239,($src|0),(1160752|0))|0);
                  $320 = __THREW__; __THREW__ = 0;
                  $321 = $320&1;
                  if ($321) {
                   label = 25;
                   break;
                  }
                  $322 = (($q$018) + 24)|0;
                  __THREW__ = 0;
                  $323 = (invoke_ii(3463,($322|0))|0);
                  $324 = __THREW__; __THREW__ = 0;
                  $325 = $324&1;
                  if ($325) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $326 = (invoke_iii(2239,($319|0),($323|0))|0);
                  $327 = __THREW__; __THREW__ = 0;
                  $328 = $327&1;
                  if ($328) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($326|0),(1159824|0))|0);
                  $329 = __THREW__; __THREW__ = 0;
                  $330 = $329&1;
                  if ($330) {
                   label = 25;
                   break;
                  }
                  $331 = (($q$018) + 1)|0;
                  $332 = ($331|0)<(8);
                  if ($332) {
                   $q$018 = $331;
                  } else {
                   break;
                  }
                 }
                 if ((label|0) == 25) {
                  $65 = ___cxa_find_matching_catch()|0;
                  $66 = tempRet0;
                  $lpad$phi$index = $65;$lpad$phi$index10 = $66;
                  label = 28;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160768|0))|0);
                 $333 = __THREW__; __THREW__ = 0;
                 $334 = $333&1;
                 if ($334) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160808|0))|0);
                 $335 = __THREW__; __THREW__ = 0;
                 $336 = $335&1;
                 if ($336) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160848|0))|0);
                 $337 = __THREW__; __THREW__ = 0;
                 $338 = $337&1;
                 if ($338) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160856|0))|0);
                 $339 = __THREW__; __THREW__ = 0;
                 $340 = $339&1;
                 if ($340) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160912|0))|0);
                 $341 = __THREW__; __THREW__ = 0;
                 $342 = $341&1;
                 if ($342) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160920|0))|0);
                 $343 = __THREW__; __THREW__ = 0;
                 $344 = $343&1;
                 if ($344) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160848|0))|0);
                 $345 = __THREW__; __THREW__ = 0;
                 $346 = $345&1;
                 if ($346) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161024|0))|0);
                 $347 = __THREW__; __THREW__ = 0;
                 $348 = $347&1;
                 if ($348) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 $349 = (invoke_iii(2239,($src|0),(1161088|0))|0);
                 $350 = __THREW__; __THREW__ = 0;
                 $351 = $350&1;
                 if ($351) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 $352 = (invoke_iii(2239,($349|0),($228|0))|0);
                 $353 = __THREW__; __THREW__ = 0;
                 $354 = $353&1;
                 if ($354) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($352|0),(1161120|0))|0);
                 $355 = __THREW__; __THREW__ = 0;
                 $356 = $355&1;
                 if ($356) {
                  label = 27;
                  break L26;
                 }
                 $357 = HEAP8[$43>>0]|0;
                 $358 = $357 & 2;
                 $359 = ($358<<24>>24)==(0);
                 if (!($359)) {
                  __THREW__ = 0;
                  (invoke_iii(2239,($src|0),(1161152|0))|0);
                  $360 = __THREW__; __THREW__ = 0;
                  $361 = $360&1;
                  if ($361) {
                   label = 27;
                   break L26;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($src|0),(1161176|0))|0);
                  $362 = __THREW__; __THREW__ = 0;
                  $363 = $362&1;
                  if ($363) {
                   label = 27;
                   break L26;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($src|0),(1161184|0))|0);
                  $364 = __THREW__; __THREW__ = 0;
                  $365 = $364&1;
                  if ($365) {
                   label = 27;
                   break L26;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($src|0),(1161248|0))|0);
                  $366 = __THREW__; __THREW__ = 0;
                  $367 = $366&1;
                  if ($367) {
                   label = 27;
                   break L26;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($src|0),(1161296|0))|0);
                  $368 = __THREW__; __THREW__ = 0;
                  $369 = $368&1;
                  if ($369) {
                   label = 27;
                   break L26;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2239,($src|0),(1161416|0))|0);
                  $370 = __THREW__; __THREW__ = 0;
                  $371 = $370&1;
                  if ($371) {
                   label = 27;
                   break L26;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161424|0))|0);
                 $372 = __THREW__; __THREW__ = 0;
                 $373 = $372&1;
                 if ($373) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160912|0))|0);
                 $374 = __THREW__; __THREW__ = 0;
                 $375 = $374&1;
                 if ($375) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161448|0))|0);
                 $376 = __THREW__; __THREW__ = 0;
                 $377 = $376&1;
                 if ($377) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160848|0))|0);
                 $378 = __THREW__; __THREW__ = 0;
                 $379 = $378&1;
                 if ($379) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161536|0))|0);
                 $380 = __THREW__; __THREW__ = 0;
                 $381 = $380&1;
                 if ($381) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161584|0))|0);
                 $382 = __THREW__; __THREW__ = 0;
                 $383 = $382&1;
                 if ($383) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160912|0))|0);
                 $384 = __THREW__; __THREW__ = 0;
                 $385 = $384&1;
                 if ($385) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161680|0))|0);
                 $386 = __THREW__; __THREW__ = 0;
                 $387 = $386&1;
                 if ($387) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160848|0))|0);
                 $388 = __THREW__; __THREW__ = 0;
                 $389 = $388&1;
                 if ($389) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161792|0))|0);
                 $390 = __THREW__; __THREW__ = 0;
                 $391 = $390&1;
                 if ($391) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161856|0))|0);
                 $392 = __THREW__; __THREW__ = 0;
                 $393 = $392&1;
                 if ($393) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161912|0))|0);
                 $394 = __THREW__; __THREW__ = 0;
                 $395 = $394&1;
                 if ($395) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161968|0))|0);
                 $396 = __THREW__; __THREW__ = 0;
                 $397 = $396&1;
                 if ($397) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1162016|0))|0);
                 $398 = __THREW__; __THREW__ = 0;
                 $399 = $398&1;
                 if ($399) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160912|0))|0);
                 $400 = __THREW__; __THREW__ = 0;
                 $401 = $400&1;
                 if ($401) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1162112|0))|0);
                 $402 = __THREW__; __THREW__ = 0;
                 $403 = $402&1;
                 if ($403) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160848|0))|0);
                 $404 = __THREW__; __THREW__ = 0;
                 $405 = $404&1;
                 if ($405) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161792|0))|0);
                 $406 = __THREW__; __THREW__ = 0;
                 $407 = $406&1;
                 if ($407) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161856|0))|0);
                 $408 = __THREW__; __THREW__ = 0;
                 $409 = $408&1;
                 if ($409) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161912|0))|0);
                 $410 = __THREW__; __THREW__ = 0;
                 $411 = $410&1;
                 if ($411) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1161968|0))|0);
                 $412 = __THREW__; __THREW__ = 0;
                 $413 = $412&1;
                 if ($413) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1162224|0))|0);
                 $414 = __THREW__; __THREW__ = 0;
                 $415 = $414&1;
                 if ($415) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1162296|0))|0);
                 $416 = __THREW__; __THREW__ = 0;
                 $417 = $416&1;
                 if ($417) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1162360|0))|0);
                 $418 = __THREW__; __THREW__ = 0;
                 $419 = $418&1;
                 if ($419) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1162408|0))|0);
                 $420 = __THREW__; __THREW__ = 0;
                 $421 = $420&1;
                 if ($421) {
                  label = 27;
                  break L26;
                 }
                 __THREW__ = 0;
                 (invoke_iii(2239,($src|0),(1160912|0))|0);
                 $422 = __THREW__; __THREW__ = 0;
                 $423 = $422&1;
                 if ($423) {
                  label = 27;
                  break L26;
                 }
                }
               } while(0);
               __THREW__ = 0;
               (invoke_iii(2239,($src|0),(1162520|0))|0);
               $424 = __THREW__; __THREW__ = 0;
               $425 = $424&1;
               if ($425) {
                label = 27;
                break;
               }
               __THREW__ = 0;
               (invoke_iii(2239,($src|0),(1160848|0))|0);
               $426 = __THREW__; __THREW__ = 0;
               $427 = $426&1;
               if ($427) {
                label = 27;
                break;
               }
               __THREW__ = 0;
               $428 = (invoke_iii(2239,($src|0),(1162536|0))|0);
               $429 = __THREW__; __THREW__ = 0;
               $430 = $429&1;
               if ($430) {
                label = 27;
                break;
               }
               __THREW__ = 0;
               $431 = (invoke_ii(3462,0)|0);
               $432 = __THREW__; __THREW__ = 0;
               $433 = $432&1;
               if ($433) {
                label = 27;
                break;
               }
               __THREW__ = 0;
               $434 = (invoke_iii(2239,($428|0),($431|0))|0);
               $435 = __THREW__; __THREW__ = 0;
               $436 = $435&1;
               if ($436) {
                label = 27;
                break;
               }
               __THREW__ = 0;
               (invoke_iii(2239,($434|0),(1162560|0))|0);
               $437 = __THREW__; __THREW__ = 0;
               $438 = $437&1;
               if ($438) {
                label = 27;
                break;
               }
               __THREW__ = 0;
               (invoke_iii(2239,($src|0),(1162584|0))|0);
               $439 = __THREW__; __THREW__ = 0;
               $440 = $439&1;
               if ($440) {
                label = 27;
                break;
               }
               $441 = HEAP8[$43>>0]|0;
               $442 = $441 & 8;
               $443 = ($442<<24>>24)==(0);
               if ($443) {
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1162656|0))|0);
                $446 = __THREW__; __THREW__ = 0;
                $447 = $446&1;
                if ($447) {
                 label = 27;
                 break;
                }
               } else {
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1162616|0))|0);
                $444 = __THREW__; __THREW__ = 0;
                $445 = $444&1;
                if ($445) {
                 label = 27;
                 break;
                }
               }
               if ($744) {
                __THREW__ = 0;
                $448 = (invoke_iii(2239,($src|0),(1162696|0))|0);
                $449 = __THREW__; __THREW__ = 0;
                $450 = $449&1;
                if ($450) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                $451 = (invoke_ii(3462,1)|0);
                $452 = __THREW__; __THREW__ = 0;
                $453 = $452&1;
                if ($453) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                $454 = (invoke_iii(2239,($448|0),($451|0))|0);
                $455 = __THREW__; __THREW__ = 0;
                $456 = $455&1;
                if ($456) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($454|0),(1162560|0))|0);
                $457 = __THREW__; __THREW__ = 0;
                $458 = $457&1;
                if ($458) {
                 label = 27;
                 break;
                }
               }
               $459 = HEAP8[$171>>0]|0;
               $460 = $459&255;
               $461 = ($459<<24>>24)==(0);
               L200: do {
                if (!($461)) {
                 $462 = (($state) + 38|0);
                 $i1$014 = 0;
                 while(1) {
                  $463 = HEAP8[$462>>0]|0;
                  $464 = $463&255;
                  $465 = 1 << $i1$014;
                  $466 = $464 & $465;
                  $467 = ($466|0)==(0);
                  if ($467) {
                   __THREW__ = 0;
                   $482 = (invoke_iii(2239,($src|0),(1162728|0))|0);
                   $483 = __THREW__; __THREW__ = 0;
                   $484 = $483&1;
                   if ($484) {
                    break;
                   }
                   __THREW__ = 0;
                   $485 = (invoke_iii(2240,($482|0),($i1$014|0))|0);
                   $486 = __THREW__; __THREW__ = 0;
                   $487 = $486&1;
                   if ($487) {
                    break;
                   }
                   __THREW__ = 0;
                   $488 = (invoke_iii(2239,($485|0),(1162744|0))|0);
                   $489 = __THREW__; __THREW__ = 0;
                   $490 = $489&1;
                   if ($490) {
                    break;
                   }
                   __THREW__ = 0;
                   $491 = (invoke_iii(2240,($488|0),($i1$014|0))|0);
                   $492 = __THREW__; __THREW__ = 0;
                   $493 = $492&1;
                   if ($493) {
                    break;
                   }
                   __THREW__ = 0;
                   $494 = (invoke_iii(2239,($491|0),(1162776|0))|0);
                   $495 = __THREW__; __THREW__ = 0;
                   $496 = $495&1;
                   if ($496) {
                    break;
                   }
                   __THREW__ = 0;
                   $497 = (invoke_iii(2240,($494|0),($i1$014|0))|0);
                   $498 = __THREW__; __THREW__ = 0;
                   $499 = $498&1;
                   if ($499) {
                    break;
                   }
                   __THREW__ = 0;
                   $500 = (invoke_iii(2239,($497|0),(1162800|0))|0);
                   $501 = __THREW__; __THREW__ = 0;
                   $502 = $501&1;
                   if ($502) {
                    break;
                   }
                   __THREW__ = 0;
                   $503 = (invoke_iii(2240,($500|0),($i1$014|0))|0);
                   $504 = __THREW__; __THREW__ = 0;
                   $505 = $504&1;
                   if ($505) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($503|0),(1162824|0))|0);
                   $506 = __THREW__; __THREW__ = 0;
                   $507 = $506&1;
                   if ($507) {
                    break;
                   }
                  } else {
                   __THREW__ = 0;
                   $468 = (invoke_iii(2239,($src|0),(1162728|0))|0);
                   $469 = __THREW__; __THREW__ = 0;
                   $470 = $469&1;
                   if ($470) {
                    break;
                   }
                   __THREW__ = 0;
                   $471 = (invoke_iii(2240,($468|0),($i1$014|0))|0);
                   $472 = __THREW__; __THREW__ = 0;
                   $473 = $472&1;
                   if ($473) {
                    break;
                   }
                   __THREW__ = 0;
                   $474 = (invoke_iii(2239,($471|0),(1162744|0))|0);
                   $475 = __THREW__; __THREW__ = 0;
                   $476 = $475&1;
                   if ($476) {
                    break;
                   }
                   __THREW__ = 0;
                   $477 = (invoke_iii(2240,($474|0),($i1$014|0))|0);
                   $478 = __THREW__; __THREW__ = 0;
                   $479 = $478&1;
                   if ($479) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($477|0),(1162768|0))|0);
                   $480 = __THREW__; __THREW__ = 0;
                   $481 = $480&1;
                   if ($481) {
                    break;
                   }
                  }
                  $508 = (($i1$014) + 1)|0;
                  $509 = ($508|0)<($460|0);
                  if ($509) {
                   $i1$014 = $508;
                  } else {
                   break L200;
                  }
                 }
                 $63 = ___cxa_find_matching_catch()|0;
                 $64 = tempRet0;
                 $lpad$phi$index = $63;$lpad$phi$index10 = $64;
                 label = 28;
                 break L26;
                }
               } while(0);
               $510 = HEAP8[$154>>0]|0;
               $511 = $510 << 24 >> 24;
               if ((($511|0) == 3)) {
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1163176|0))|0);
                $522 = __THREW__; __THREW__ = 0;
                $523 = $522&1;
                if ($523) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1163240|0))|0);
                $524 = __THREW__; __THREW__ = 0;
                $525 = $524&1;
                if ($525) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1163088|0))|0);
                $526 = __THREW__; __THREW__ = 0;
                $527 = $526&1;
                if ($527) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1162952|0))|0);
                $528 = __THREW__; __THREW__ = 0;
                $529 = $528&1;
                if ($529) {
                 label = 27;
                 break;
                }
               } else if ((($511|0) == 1)) {
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1162832|0))|0);
                $512 = __THREW__; __THREW__ = 0;
                $513 = $512&1;
                if ($513) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1162952|0))|0);
                $514 = __THREW__; __THREW__ = 0;
                $515 = $514&1;
                if ($515) {
                 label = 27;
                 break;
                }
               } else if ((($511|0) == 2)) {
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1163024|0))|0);
                $516 = __THREW__; __THREW__ = 0;
                $517 = $516&1;
                if ($517) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1163088|0))|0);
                $518 = __THREW__; __THREW__ = 0;
                $519 = $518&1;
                if ($519) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1162952|0))|0);
                $520 = __THREW__; __THREW__ = 0;
                $521 = $520&1;
                if ($521) {
                 label = 27;
                 break;
                }
               }
               $530 = HEAP8[$43>>0]|0;
               $531 = $530 & 1;
               $532 = ($531<<24>>24)==(0);
               if ($532) {
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1163824|0))|0);
                $676 = __THREW__; __THREW__ = 0;
                $677 = $676&1;
                if ($677) {
                 label = 27;
                 break;
                }
               } else {
                __THREW__ = 0;
                $533 = (invoke_iii(2239,($src|0),(1163280|0))|0);
                $534 = __THREW__; __THREW__ = 0;
                $535 = $534&1;
                if ($535) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                $536 = (invoke_iii(2239,($533|0),($231|0))|0);
                $537 = __THREW__; __THREW__ = 0;
                $538 = $537&1;
                if ($538) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                $539 = (invoke_iii(2239,($536|0),(1163312|0))|0);
                $540 = __THREW__; __THREW__ = 0;
                $541 = $540&1;
                if ($541) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                $542 = (invoke_iii(2239,($539|0),($227|0))|0);
                $543 = __THREW__; __THREW__ = 0;
                $544 = $543&1;
                if ($544) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($542|0),(1163320|0))|0);
                $545 = __THREW__; __THREW__ = 0;
                $546 = $545&1;
                if ($546) {
                 label = 27;
                 break;
                }
                $547 = (($state) + 37|0);
                $548 = HEAP8[$547>>0]|0;
                $549 = ($548<<24>>24)==(0);
                L240: do {
                 if (!($549)) {
                  __THREW__ = 0;
                  (invoke_iii(2239,($src|0),(1163360|0))|0);
                  $550 = __THREW__; __THREW__ = 0;
                  $551 = $550&1;
                  if ($551) {
                   label = 27;
                   break L26;
                  }
                  $552 = HEAP8[$547>>0]|0;
                  $553 = ($552&255)<(8);
                  $554 = $552&255;
                  $$ = $553 ? $554 : 8;
                  $555 = ($$|0)==(0);
                  if ($555) {
                   break;
                  }
                  $556 = (($state) + 32|0);
                  $i3$010 = 0;
                  while(1) {
                   __THREW__ = 0;
                   $557 = (invoke_iii(2239,($src|0),(1163432|0))|0);
                   $558 = __THREW__; __THREW__ = 0;
                   $559 = $558&1;
                   if ($559) {
                    break;
                   }
                   __THREW__ = 0;
                   $560 = (invoke_iii(2240,($557|0),($i3$010|0))|0);
                   $561 = __THREW__; __THREW__ = 0;
                   $562 = $561&1;
                   if ($562) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($560|0),(1159824|0))|0);
                   $563 = __THREW__; __THREW__ = 0;
                   $564 = $563&1;
                   if ($564) {
                    break;
                   }
                   __THREW__ = 0;
                   $565 = (invoke_iii(2239,($src|0),(1163464|0))|0);
                   $566 = __THREW__; __THREW__ = 0;
                   $567 = $566&1;
                   if ($567) {
                    break;
                   }
                   __THREW__ = 0;
                   $568 = (invoke_iii(2240,($565|0),($i3$010|0))|0);
                   $569 = __THREW__; __THREW__ = 0;
                   $570 = $569&1;
                   if ($570) {
                    break;
                   }
                   __THREW__ = 0;
                   $571 = (invoke_iii(2239,($568|0),(1163480|0))|0);
                   $572 = __THREW__; __THREW__ = 0;
                   $573 = $572&1;
                   if ($573) {
                    break;
                   }
                   __THREW__ = 0;
                   $574 = (invoke_ii(3463,($i3$010|0))|0);
                   $575 = __THREW__; __THREW__ = 0;
                   $576 = $575&1;
                   if ($576) {
                    break;
                   }
                   __THREW__ = 0;
                   $577 = (invoke_iii(2239,($571|0),($574|0))|0);
                   $578 = __THREW__; __THREW__ = 0;
                   $579 = $578&1;
                   if ($579) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($577|0),(1159824|0))|0);
                   $580 = __THREW__; __THREW__ = 0;
                   $581 = $580&1;
                   if ($581) {
                    break;
                   }
                   __THREW__ = 0;
                   $582 = (invoke_iii(2239,($src|0),(1163464|0))|0);
                   $583 = __THREW__; __THREW__ = 0;
                   $584 = $583&1;
                   if ($584) {
                    break;
                   }
                   __THREW__ = 0;
                   $585 = (invoke_iii(2240,($582|0),($i3$010|0))|0);
                   $586 = __THREW__; __THREW__ = 0;
                   $587 = $586&1;
                   if ($587) {
                    break;
                   }
                   __THREW__ = 0;
                   $588 = (invoke_iii(2239,($585|0),(1163496|0))|0);
                   $589 = __THREW__; __THREW__ = 0;
                   $590 = $589&1;
                   if ($590) {
                    break;
                   }
                   $591 = (($i3$010) + 8)|0;
                   __THREW__ = 0;
                   $592 = (invoke_ii(3463,($591|0))|0);
                   $593 = __THREW__; __THREW__ = 0;
                   $594 = $593&1;
                   if ($594) {
                    break;
                   }
                   __THREW__ = 0;
                   $595 = (invoke_iii(2239,($588|0),($592|0))|0);
                   $596 = __THREW__; __THREW__ = 0;
                   $597 = $596&1;
                   if ($597) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($595|0),(1159824|0))|0);
                   $598 = __THREW__; __THREW__ = 0;
                   $599 = $598&1;
                   if ($599) {
                    break;
                   }
                   __THREW__ = 0;
                   $600 = (invoke_iii(2239,($src|0),(1163464|0))|0);
                   $601 = __THREW__; __THREW__ = 0;
                   $602 = $601&1;
                   if ($602) {
                    break;
                   }
                   __THREW__ = 0;
                   $603 = (invoke_iii(2240,($600|0),($i3$010|0))|0);
                   $604 = __THREW__; __THREW__ = 0;
                   $605 = $604&1;
                   if ($605) {
                    break;
                   }
                   __THREW__ = 0;
                   $606 = (invoke_iii(2239,($603|0),(1163512|0))|0);
                   $607 = __THREW__; __THREW__ = 0;
                   $608 = $607&1;
                   if ($608) {
                    break;
                   }
                   $609 = (($i3$010) + 16)|0;
                   __THREW__ = 0;
                   $610 = (invoke_ii(3463,($609|0))|0);
                   $611 = __THREW__; __THREW__ = 0;
                   $612 = $611&1;
                   if ($612) {
                    break;
                   }
                   __THREW__ = 0;
                   $613 = (invoke_iii(2239,($606|0),($610|0))|0);
                   $614 = __THREW__; __THREW__ = 0;
                   $615 = $614&1;
                   if ($615) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($613|0),(1162768|0))|0);
                   $616 = __THREW__; __THREW__ = 0;
                   $617 = $616&1;
                   if ($617) {
                    break;
                   }
                   __THREW__ = 0;
                   $618 = (invoke_iii(2239,($src|0),(1163464|0))|0);
                   $619 = __THREW__; __THREW__ = 0;
                   $620 = $619&1;
                   if ($620) {
                    break;
                   }
                   __THREW__ = 0;
                   $621 = (invoke_iii(2240,($618|0),($i3$010|0))|0);
                   $622 = __THREW__; __THREW__ = 0;
                   $623 = $622&1;
                   if ($623) {
                    break;
                   }
                   __THREW__ = 0;
                   $624 = (invoke_iii(2239,($621|0),(1163536|0))|0);
                   $625 = __THREW__; __THREW__ = 0;
                   $626 = $625&1;
                   if ($626) {
                    break;
                   }
                   $627 = (($i3$010) + 24)|0;
                   __THREW__ = 0;
                   $628 = (invoke_ii(3463,($627|0))|0);
                   $629 = __THREW__; __THREW__ = 0;
                   $630 = $629&1;
                   if ($630) {
                    break;
                   }
                   __THREW__ = 0;
                   $631 = (invoke_iii(2239,($624|0),($628|0))|0);
                   $632 = __THREW__; __THREW__ = 0;
                   $633 = $632&1;
                   if ($633) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(2239,($631|0),(1159824|0))|0);
                   $634 = __THREW__; __THREW__ = 0;
                   $635 = $634&1;
                   if ($635) {
                    break;
                   }
                   $636 = HEAP32[$556>>2]|0;
                   $637 = $i3$010 << 2;
                   $638 = $636 >>> $637;
                   $639 = $638 & 15;
                   if ((($639|0) == 1)) {
                    __THREW__ = 0;
                    $640 = (invoke_iii(2239,($src|0),(1163552|0))|0);
                    $641 = __THREW__; __THREW__ = 0;
                    $642 = $641&1;
                    if ($642) {
                     break;
                    }
                    __THREW__ = 0;
                    $643 = (invoke_iii(2240,($640|0),($i3$010|0))|0);
                    $644 = __THREW__; __THREW__ = 0;
                    $645 = $644&1;
                    if ($645) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_iii(2239,($643|0),(1163592|0))|0);
                    $646 = __THREW__; __THREW__ = 0;
                    $647 = $646&1;
                    if ($647) {
                     break;
                    }
                   } else if ((($639|0) == 0)) {
                    __THREW__ = 0;
                    $648 = (invoke_iii(2239,($src|0),(1163624|0))|0);
                    $649 = __THREW__; __THREW__ = 0;
                    $650 = $649&1;
                    if ($650) {
                     break;
                    }
                    __THREW__ = 0;
                    $651 = (invoke_iii(2240,($648|0),($i3$010|0))|0);
                    $652 = __THREW__; __THREW__ = 0;
                    $653 = $652&1;
                    if ($653) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_iii(2239,($651|0),(1163664|0))|0);
                    $654 = __THREW__; __THREW__ = 0;
                    $655 = $654&1;
                    if ($655) {
                     break;
                    }
                   } else {
                    __THREW__ = 0;
                    $656 = (invoke_iii(2239,($src|0),(1163712|0))|0);
                    $657 = __THREW__; __THREW__ = 0;
                    $658 = $657&1;
                    if ($658) {
                     break;
                    }
                    __THREW__ = 0;
                    $659 = (invoke_iii(2240,($656|0),($i3$010|0))|0);
                    $660 = __THREW__; __THREW__ = 0;
                    $661 = $660&1;
                    if ($661) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_iii(2239,($659|0),(1163664|0))|0);
                    $662 = __THREW__; __THREW__ = 0;
                    $663 = $662&1;
                    if ($663) {
                     break;
                    }
                   }
                   $664 = (($i3$010) + 1)|0;
                   $665 = ($664|0)<($$|0);
                   if ($665) {
                    $i3$010 = $664;
                   } else {
                    break L240;
                   }
                  }
                  $61 = ___cxa_find_matching_catch()|0;
                  $62 = tempRet0;
                  $lpad$phi$index = $61;$lpad$phi$index10 = $62;
                  label = 28;
                  break L26;
                 }
                } while(0);
                __THREW__ = 0;
                $666 = (invoke_iii(2239,($src|0),(1163752|0))|0);
                $667 = __THREW__; __THREW__ = 0;
                $668 = $667&1;
                if ($668) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                $669 = (invoke_iii(2239,($666|0),($228|0))|0);
                $670 = __THREW__; __THREW__ = 0;
                $671 = $670&1;
                if ($671) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($669|0),(1163776|0))|0);
                $672 = __THREW__; __THREW__ = 0;
                $673 = $672&1;
                if ($673) {
                 label = 27;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(2239,($src|0),(1163784|0))|0);
                $674 = __THREW__; __THREW__ = 0;
                $675 = $674&1;
                if ($675) {
                 label = 27;
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_iii(2239,($src|0),(1160912|0))|0);
               $678 = __THREW__; __THREW__ = 0;
               $679 = $678&1;
               if ($679) {
                label = 27;
                break;
               }
               __THREW__ = 0;
               invoke_vii(2482,($1|0),($3|0));
               $680 = __THREW__; __THREW__ = 0;
               $681 = $680&1;
               if ($681) {
                label = 27;
                break;
               }
               $682 = HEAP8[$1>>0]|0;
               $683 = $682 & 1;
               $684 = ($683<<24>>24)==(0);
               if ($684) {
                $687 = (($1) + 1|0);
                $688 = $687;
               } else {
                $685 = (($1) + 8|0);
                $686 = HEAP32[$685>>2]|0;
                $688 = $686;
               }
               $689 = (_strlen(($688|0))|0);
               $690 = ($689>>>0)>(4294967279);
               do {
                if ($690) {
                 __THREW__ = 0;
                 invoke_vi(3309,0);
                 $691 = __THREW__; __THREW__ = 0;
                 $692 = $691&1;
                 if ($692) {
                  break;
                 }
                 // unreachable;
                } else {
                 $693 = ($689>>>0)<(11);
                 if ($693) {
                  $694 = $689 << 1;
                  $695 = $694&255;
                  HEAP8[$agg$result>>0] = $695;
                  $696 = (($agg$result) + 1|0);
                  $__p$0$i$i$i = $696;
                 } else {
                  $697 = (($689) + 16)|0;
                  $698 = $697 & -16;
                  __THREW__ = 0;
                  $699 = (invoke_ii(2988,($698|0))|0);
                  $700 = __THREW__; __THREW__ = 0;
                  $701 = $700&1;
                  if ($701) {
                   break;
                  }
                  $702 = (($agg$result) + 8|0);
                  HEAP32[$702>>2] = $699;
                  $703 = $698 | 1;
                  HEAP32[$agg$result>>2] = $703;
                  $704 = (($agg$result) + 4|0);
                  HEAP32[$704>>2] = $689;
                  $__p$0$i$i$i = $699;
                 }
                 _memcpy(($__p$0$i$i$i|0),($688|0),($689|0))|0;
                 $705 = (($__p$0$i$i$i) + ($689)|0);
                 HEAP8[$705>>0] = 0;
                 if (!($684)) {
                  $706 = (($1) + 8|0);
                  $707 = HEAP32[$706>>2]|0;
                  __ZdlPv($707);
                 }
                 HEAP32[$src>>2] = ((390232 + 12|0));
                 HEAP32[$4>>2] = ((390232 + 32|0));
                 $708 = (($src) + 4|0);
                 HEAP32[$708>>2] = ((225848 + 8|0));
                 $709 = HEAP8[$12>>0]|0;
                 $710 = $709 & 1;
                 $711 = ($710<<24>>24)==(0);
                 if (!($711)) {
                  $712 = (($src) + 44|0);
                  $713 = HEAP32[$712>>2]|0;
                  __ZdlPv($713);
                 }
                 HEAP32[$708>>2] = ((3090568 + 8|0));
                 __THREW__ = 0;
                 invoke_vi(3299,($10|0));
                 $714 = __THREW__; __THREW__ = 0;
                 $715 = $714&1;
                 if (!($715)) {
                  __ZNSt3__18ios_baseD2Ev($5);
                  STACKTOP = sp;return;
                 }
                 $716 = ___cxa_find_matching_catch()|0;
                 $717 = tempRet0;
                 __THREW__ = 0;
                 invoke_vi(3217,($5|0));
                 $718 = __THREW__; __THREW__ = 0;
                 $719 = $718&1;
                 if ($719) {
                  $720 = ___cxa_find_matching_catch(0|0)|0;
                  $721 = tempRet0;
                  ___clang_call_terminate($720);
                  // unreachable;
                 } else {
                  ___resumeException($716|0);
                  // unreachable;
                 }
                }
               } while(0);
               $722 = ___cxa_find_matching_catch()|0;
               $723 = tempRet0;
               if ($684) {
                $$0 = $722;$$01 = $723;
                break;
               }
               $724 = (($1) + 8|0);
               $725 = HEAP32[$724>>2]|0;
               __ZdlPv($725);
               $$0 = $722;$$01 = $723;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 27) {
    $69 = ___cxa_find_matching_catch()|0;
    $70 = tempRet0;
    $lpad$phi$index = $69;$lpad$phi$index10 = $70;
    label = 28;
   }
   if ((label|0) == 28) {
    $$0 = $lpad$phi$index;$$01 = $lpad$phi$index10;
   }
   HEAP32[$src>>2] = ((390232 + 12|0));
   HEAP32[$4>>2] = ((390232 + 32|0));
   $726 = (($src) + 4|0);
   HEAP32[$726>>2] = ((225848 + 8|0));
   $727 = HEAP8[$12>>0]|0;
   $728 = $727 & 1;
   $729 = ($728<<24>>24)==(0);
   if (!($729)) {
    $730 = (($src) + 44|0);
    $731 = HEAP32[$730>>2]|0;
    __ZdlPv($731);
   }
   HEAP32[$726>>2] = ((3090568 + 8|0));
   __THREW__ = 0;
   invoke_vi(3299,($10|0));
   $732 = __THREW__; __THREW__ = 0;
   $733 = $732&1;
   if ($733) {
    $736 = ___cxa_find_matching_catch(0|0)|0;
    $737 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3217,($5|0));
    $738 = __THREW__; __THREW__ = 0;
    $739 = $738&1;
    if ($739) {
     $740 = ___cxa_find_matching_catch(0|0)|0;
     $741 = tempRet0;
     ___clang_call_terminate($740);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $736;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_vi(3217,($5|0));
   $734 = __THREW__; __THREW__ = 0;
   $735 = $734&1;
   if (!($735)) {
    ___resumeException($$0|0);
    // unreachable;
   }
   $742 = ___cxa_find_matching_catch(0|0)|0;
   $743 = tempRet0;
   $eh$lpad$body$indexZ2D = $742;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3217,($2|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 } else {
  ___resumeException($$01$i|0);
  // unreachable;
 }
}
function __ZN3ffp4gles18BuildFShaderSourceERKNS_5StateEi($agg$result,$state,$glslVer) {
 $agg$result = $agg$result|0;
 $state = $state|0;
 $glslVer = $glslVer|0;
 var $$0 = 0, $$01 = 0, $$01$i = 0, $$sink$i$index2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__p$0$i$i$i = 0, $eh$lpad$body$indexZ2D = 0, $i$030 = 0, $i1$027 = 0, $i1$027$us = 0, $lpad$phi$index = 0, $lpad$phi$index9 = 0;
 var $src = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $0 = sp + 148|0;
 $src = sp;
 $1 = sp + 136|0;
 $2 = (($src) + 56|0);
 $3 = (($src) + 4|0);
 HEAP32[$src>>2] = ((390272 + 12|0));
 $4 = (($src) + 56|0);
 HEAP32[$4>>2] = ((390272 + 32|0));
 $5 = (($src) + 56|0);
 __THREW__ = 0;
 invoke_vii(2480,($5|0),($3|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if ($7) {
   $37 = ___cxa_find_matching_catch()|0;
   $38 = tempRet0;
   $$01$i = $37;$$sink$i$index2 = $38;
  } else {
   $8 = (($src) + 128|0);
   HEAP32[$8>>2] = 0;
   $9 = (($src) + 132|0);
   HEAP32[$9>>2] = -1;
   HEAP32[$src>>2] = ((390232 + 12|0));
   HEAP32[$2>>2] = ((390232 + 32|0));
   HEAP32[$3>>2] = ((3090568 + 8|0));
   $10 = (($src) + 8|0);
   __ZNSt3__16localeC2Ev($10);
   $11 = (($src) + 12|0);
   ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;HEAP32[$11+12>>2]=0|0;HEAP32[$11+16>>2]=0|0;HEAP32[$11+20>>2]=0|0;
   HEAP32[$3>>2] = ((225848 + 8|0));
   $12 = (($src) + 36|0);
   $13 = (($src) + 52|0);
   ;HEAP32[$12+0>>2]=0|0;HEAP32[$12+4>>2]=0|0;HEAP32[$12+8>>2]=0|0;HEAP32[$12+12>>2]=0|0;
   HEAP32[$13>>2] = 16;
   ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(2481,($3|0),($0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    $21 = ___cxa_find_matching_catch()|0;
    $22 = tempRet0;
    $23 = HEAP8[$0>>0]|0;
    $24 = $23 & 1;
    $25 = ($24<<24>>24)==(0);
    if (!($25)) {
     $26 = (($0) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     __ZdlPv($27);
    }
    $28 = HEAP8[$12>>0]|0;
    $29 = $28 & 1;
    $30 = ($29<<24>>24)==(0);
    if (!($30)) {
     $31 = (($src) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __ZdlPv($32);
    }
    HEAP32[$3>>2] = ((3090568 + 8|0));
    __THREW__ = 0;
    invoke_vi(3299,($10|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $35 = ___cxa_find_matching_catch(0|0)|0;
     $36 = tempRet0;
     ___clang_call_terminate($35);
     // unreachable;
    } else {
     $$01$i = $21;$$sink$i$index2 = $22;
     break;
    }
   }
   $16 = HEAP8[$0>>0]|0;
   $17 = $16 & 1;
   $18 = ($17<<24>>24)==(0);
   if (!($18)) {
    $19 = (($0) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    __ZdlPv($20);
   }
   $43 = (($state) + 40|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($glslVer|0)>(299);
   if ($45) {
    __THREW__ = 0;
    $46 = (invoke_iii(2239,($src|0),(1159696|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 22;
    } else {
     __THREW__ = 0;
     $49 = (invoke_iii(2240,($46|0),($glslVer|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 22;
     } else {
      __THREW__ = 0;
      (invoke_iii(2239,($49|0),(1159712|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 22;
      } else {
       label = 24;
      }
     }
    }
   } else {
    label = 24;
   }
   L23: do {
    if ((label|0) == 24) {
     $60 = ($glslVer|0)<(300);
     $61 = $60 ? 1163856 : 1163872;
     $62 = $45 ? 1159720 : 1159752;
     __THREW__ = 0;
     $63 = (invoke_iii(2239,($src|0),($62|0))|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      label = 22;
     } else {
      __THREW__ = 0;
      (invoke_iii(2239,($63|0),(1159968|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 22;
      } else {
       if (!((($44<<24>>24) == 0) | (($44<<24>>24) == 8))) {
        __THREW__ = 0;
        (invoke_iii(2239,($src|0),(1163888|0))|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         label = 22;
         break;
        }
       }
       $70 = (($state) + 39|0);
       $71 = HEAP8[$70>>0]|0;
       $72 = ($71<<24>>24)>(0);
       if ($72) {
        __THREW__ = 0;
        $73 = (invoke_iii(2239,($src|0),($62|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 22;
         break;
        }
        __THREW__ = 0;
        (invoke_iii(2239,($73|0),(1160072|0))|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 22;
         break;
        }
        __THREW__ = 0;
        $78 = (invoke_iii(2239,($src|0),($62|0))|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         label = 22;
         break;
        }
        __THREW__ = 0;
        (invoke_iii(2239,($78|0),(1160104|0))|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 22;
         break;
        }
       }
       $83 = (($state) + 36|0);
       $84 = HEAP8[$83>>0]|0;
       $85 = $84&255;
       $86 = ($84<<24>>24)==(0);
       L36: do {
        if (!($86)) {
         $87 = (($state) + 38|0);
         $i$030 = 0;
         while(1) {
          $88 = HEAP8[$87>>0]|0;
          $89 = $88&255;
          $90 = 1 << $i$030;
          $91 = $89 & $90;
          $92 = ($91|0)==(0);
          if ($92) {
           __THREW__ = 0;
           $112 = (invoke_iii(2239,($src|0),($62|0))|0);
           $113 = __THREW__; __THREW__ = 0;
           $114 = $113&1;
           if ($114) {
            break;
           }
           __THREW__ = 0;
           $115 = (invoke_iii(2239,($112|0),(1160224|0))|0);
           $116 = __THREW__; __THREW__ = 0;
           $117 = $116&1;
           if ($117) {
            break;
           }
           __THREW__ = 0;
           $118 = (invoke_iii(2240,($115|0),($i$030|0))|0);
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if ($120) {
            break;
           }
           __THREW__ = 0;
           (invoke_iii(2239,($118|0),(1159824|0))|0);
           $121 = __THREW__; __THREW__ = 0;
           $122 = $121&1;
           if ($122) {
            break;
           }
           __THREW__ = 0;
           $123 = (invoke_iii(2239,($src|0),(1163968|0))|0);
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            break;
           }
           __THREW__ = 0;
           $126 = (invoke_iii(2240,($123|0),($i$030|0))|0);
           $127 = __THREW__; __THREW__ = 0;
           $128 = $127&1;
           if ($128) {
            break;
           }
           __THREW__ = 0;
           (invoke_iii(2239,($126|0),(1159824|0))|0);
           $129 = __THREW__; __THREW__ = 0;
           $130 = $129&1;
           if ($130) {
            break;
           }
          } else {
           __THREW__ = 0;
           $93 = (invoke_iii(2239,($src|0),($62|0))|0);
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if ($95) {
            break;
           }
           __THREW__ = 0;
           $96 = (invoke_iii(2239,($93|0),(1160200|0))|0);
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if ($98) {
            break;
           }
           __THREW__ = 0;
           $99 = (invoke_iii(2240,($96|0),($i$030|0))|0);
           $100 = __THREW__; __THREW__ = 0;
           $101 = $100&1;
           if ($101) {
            break;
           }
           __THREW__ = 0;
           (invoke_iii(2239,($99|0),(1159824|0))|0);
           $102 = __THREW__; __THREW__ = 0;
           $103 = $102&1;
           if ($103) {
            break;
           }
           __THREW__ = 0;
           $104 = (invoke_iii(2239,($src|0),(1163936|0))|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            break;
           }
           __THREW__ = 0;
           $107 = (invoke_iii(2240,($104|0),($i$030|0))|0);
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            break;
           }
           __THREW__ = 0;
           (invoke_iii(2239,($107|0),(1159824|0))|0);
           $110 = __THREW__; __THREW__ = 0;
           $111 = $110&1;
           if ($111) {
            break;
           }
          }
          __THREW__ = 0;
          $131 = (invoke_iii(2239,($src|0),(1164000|0))|0);
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           break;
          }
          __THREW__ = 0;
          $134 = (invoke_iii(2240,($131|0),($i$030|0))|0);
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           break;
          }
          __THREW__ = 0;
          (invoke_iii(2239,($134|0),(1159824|0))|0);
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if ($138) {
           break;
          }
          $139 = (($i$030) + 1)|0;
          $140 = ($139|0)<($85|0);
          if ($140) {
           $i$030 = $139;
          } else {
           break L36;
          }
         }
         $56 = ___cxa_find_matching_catch()|0;
         $57 = tempRet0;
         $lpad$phi$index = $56;$lpad$phi$index9 = $57;
         label = 23;
         break L23;
        }
       } while(0);
       if (!($60)) {
        __THREW__ = 0;
        (invoke_iii(2239,($src|0),(1164040|0))|0);
        $141 = __THREW__; __THREW__ = 0;
        $142 = $141&1;
        if ($142) {
         label = 22;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1162520|0))|0);
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        label = 22;
       } else {
        __THREW__ = 0;
        (invoke_iii(2239,($src|0),(1160848|0))|0);
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         label = 22;
        } else {
         __THREW__ = 0;
         (invoke_iii(2239,($src|0),(1164072|0))|0);
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          label = 22;
         } else {
          $149 = HEAP8[$83>>0]|0;
          $150 = $149&255;
          $151 = ($149<<24>>24)==(0);
          L67: do {
           if (!($151)) {
            $152 = (($state) + 38|0);
            if ($45) {
             $i1$027$us = 0;
             while(1) {
              $153 = (($state) + ($i1$027$us<<2)|0);
              $154 = HEAP32[$153>>2]|0;
              $155 = ((($state) + ($i1$027$us<<2)|0) + 16|0);
              $156 = HEAP32[$155>>2]|0;
              __THREW__ = 0;
              $157 = (invoke_iii(2239,($src|0),(1164344|0))|0);
              $158 = __THREW__; __THREW__ = 0;
              $159 = $158&1;
              if ($159) {
               break;
              }
              __THREW__ = 0;
              $160 = (invoke_iii(2240,($157|0),($i1$027$us|0))|0);
              $161 = __THREW__; __THREW__ = 0;
              $162 = $161&1;
              if ($162) {
               break;
              }
              __THREW__ = 0;
              (invoke_iii(2239,($160|0),(1164376|0))|0);
              $163 = __THREW__; __THREW__ = 0;
              $164 = $163&1;
              if ($164) {
               break;
              }
              __THREW__ = 0;
              $165 = (invoke_iii(2239,($src|0),(1164424|0))|0);
              $166 = __THREW__; __THREW__ = 0;
              $167 = $166&1;
              if ($167) {
               break;
              }
              __THREW__ = 0;
              $168 = (invoke_iii(2239,($165|0),(1164384|0))|0);
              $169 = __THREW__; __THREW__ = 0;
              $170 = $169&1;
              if ($170) {
               break;
              }
              __THREW__ = 0;
              $171 = (invoke_iii(2239,($168|0),(1164456|0))|0);
              $172 = __THREW__; __THREW__ = 0;
              $173 = $172&1;
              if ($173) {
               break;
              }
              __THREW__ = 0;
              $174 = (invoke_iii(2240,($171|0),($i1$027$us|0))|0);
              $175 = __THREW__; __THREW__ = 0;
              $176 = $175&1;
              if ($176) {
               break;
              }
              __THREW__ = 0;
              $177 = (invoke_iii(2239,($174|0),(1164472|0))|0);
              $178 = __THREW__; __THREW__ = 0;
              $179 = $178&1;
              if ($179) {
               break;
              }
              __THREW__ = 0;
              $180 = (invoke_iii(2240,($177|0),($i1$027$us|0))|0);
              $181 = __THREW__; __THREW__ = 0;
              $182 = $181&1;
              if ($182) {
               break;
              }
              __THREW__ = 0;
              (invoke_iii(2239,($180|0),(1164488|0))|0);
              $183 = __THREW__; __THREW__ = 0;
              $184 = $183&1;
              if ($184) {
               break;
              }
              __THREW__ = 0;
              $185 = (invoke_iii(2239,($src|0),(1164496|0))|0);
              $186 = __THREW__; __THREW__ = 0;
              $187 = $186&1;
              if ($187) {
               break;
              }
              $188 = ($i1$027$us|0)>(0);
              $189 = $188 ? 1164528 : 1164536;
              __THREW__ = 0;
              $190 = (invoke_iii(2239,($185|0),($189|0))|0);
              $191 = __THREW__; __THREW__ = 0;
              $192 = $191&1;
              if ($192) {
               break;
              }
              __THREW__ = 0;
              (invoke_iii(2239,($190|0),(1159824|0))|0);
              $193 = __THREW__; __THREW__ = 0;
              $194 = $193&1;
              if ($194) {
               break;
              }
              $195 = ($154|0)==($156|0);
              if ($195) {
               __THREW__ = 0;
               invoke_viiii(458,($src|0),($i1$027$us|0),($154|0),0);
               $200 = __THREW__; __THREW__ = 0;
               $201 = $200&1;
               if ($201) {
                break;
               }
              } else {
               __THREW__ = 0;
               invoke_viiii(458,($src|0),($i1$027$us|0),($154|0),1);
               $196 = __THREW__; __THREW__ = 0;
               $197 = $196&1;
               if ($197) {
                break;
               }
               __THREW__ = 0;
               invoke_viiii(458,($src|0),($i1$027$us|0),($156|0),2);
               $198 = __THREW__; __THREW__ = 0;
               $199 = $198&1;
               if ($199) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_iii(2239,($src|0),(1161416|0))|0);
              $202 = __THREW__; __THREW__ = 0;
              $203 = $202&1;
              if ($203) {
               break;
              }
              $204 = (($i1$027$us) + 1)|0;
              $205 = ($204|0)<($150|0);
              if ($205) {
               $i1$027$us = $204;
              } else {
               break L67;
              }
             }
             $206 = ___cxa_find_matching_catch()|0;
             $207 = tempRet0;
             $lpad$phi$index = $206;$lpad$phi$index9 = $207;
             label = 23;
             break L23;
            } else {
             $i1$027 = 0;
             while(1) {
              $208 = HEAP8[$152>>0]|0;
              $209 = $208&255;
              $210 = 1 << $i1$027;
              $211 = $209 & $210;
              $212 = ($211|0)!=(0);
              $213 = (($state) + ($i1$027<<2)|0);
              $214 = HEAP32[$213>>2]|0;
              $215 = ((($state) + ($i1$027<<2)|0) + 16|0);
              $216 = HEAP32[$215>>2]|0;
              __THREW__ = 0;
              $217 = (invoke_iii(2239,($src|0),(1164344|0))|0);
              $218 = __THREW__; __THREW__ = 0;
              $219 = $218&1;
              if ($219) {
               break;
              }
              __THREW__ = 0;
              $220 = (invoke_iii(2240,($217|0),($i1$027|0))|0);
              $221 = __THREW__; __THREW__ = 0;
              $222 = $221&1;
              if ($222) {
               break;
              }
              __THREW__ = 0;
              (invoke_iii(2239,($220|0),(1164376|0))|0);
              $223 = __THREW__; __THREW__ = 0;
              $224 = $223&1;
              if ($224) {
               break;
              }
              __THREW__ = 0;
              $225 = (invoke_iii(2239,($src|0),(1164424|0))|0);
              $226 = __THREW__; __THREW__ = 0;
              $227 = $226&1;
              if ($227) {
               break;
              }
              $228 = $212 ? 1164392 : 1164408;
              __THREW__ = 0;
              $229 = (invoke_iii(2239,($225|0),($228|0))|0);
              $230 = __THREW__; __THREW__ = 0;
              $231 = $230&1;
              if ($231) {
               break;
              }
              __THREW__ = 0;
              $232 = (invoke_iii(2239,($229|0),(1164456|0))|0);
              $233 = __THREW__; __THREW__ = 0;
              $234 = $233&1;
              if ($234) {
               break;
              }
              __THREW__ = 0;
              $235 = (invoke_iii(2240,($232|0),($i1$027|0))|0);
              $236 = __THREW__; __THREW__ = 0;
              $237 = $236&1;
              if ($237) {
               break;
              }
              __THREW__ = 0;
              $238 = (invoke_iii(2239,($235|0),(1164472|0))|0);
              $239 = __THREW__; __THREW__ = 0;
              $240 = $239&1;
              if ($240) {
               break;
              }
              __THREW__ = 0;
              $241 = (invoke_iii(2240,($238|0),($i1$027|0))|0);
              $242 = __THREW__; __THREW__ = 0;
              $243 = $242&1;
              if ($243) {
               break;
              }
              __THREW__ = 0;
              (invoke_iii(2239,($241|0),(1164488|0))|0);
              $244 = __THREW__; __THREW__ = 0;
              $245 = $244&1;
              if ($245) {
               break;
              }
              __THREW__ = 0;
              $246 = (invoke_iii(2239,($src|0),(1164496|0))|0);
              $247 = __THREW__; __THREW__ = 0;
              $248 = $247&1;
              if ($248) {
               break;
              }
              $249 = ($i1$027|0)>(0);
              $250 = $249 ? 1164528 : 1164536;
              __THREW__ = 0;
              $251 = (invoke_iii(2239,($246|0),($250|0))|0);
              $252 = __THREW__; __THREW__ = 0;
              $253 = $252&1;
              if ($253) {
               break;
              }
              __THREW__ = 0;
              (invoke_iii(2239,($251|0),(1159824|0))|0);
              $254 = __THREW__; __THREW__ = 0;
              $255 = $254&1;
              if ($255) {
               break;
              }
              $256 = ($214|0)==($216|0);
              if ($256) {
               __THREW__ = 0;
               invoke_viiii(458,($src|0),($i1$027|0),($214|0),0);
               $257 = __THREW__; __THREW__ = 0;
               $258 = $257&1;
               if ($258) {
                break;
               }
              } else {
               __THREW__ = 0;
               invoke_viiii(458,($src|0),($i1$027|0),($214|0),1);
               $259 = __THREW__; __THREW__ = 0;
               $260 = $259&1;
               if ($260) {
                break;
               }
               __THREW__ = 0;
               invoke_viiii(458,($src|0),($i1$027|0),($216|0),2);
               $261 = __THREW__; __THREW__ = 0;
               $262 = $261&1;
               if ($262) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_iii(2239,($src|0),(1161416|0))|0);
              $263 = __THREW__; __THREW__ = 0;
              $264 = $263&1;
              if ($264) {
               break;
              }
              $265 = (($i1$027) + 1)|0;
              $266 = ($265|0)<($150|0);
              if ($266) {
               $i1$027 = $265;
              } else {
               break L67;
              }
             }
             $54 = ___cxa_find_matching_catch()|0;
             $55 = tempRet0;
             $lpad$phi$index = $54;$lpad$phi$index9 = $55;
             label = 23;
             break L23;
            }
           }
          } while(0);
          $267 = HEAP8[$70>>0]|0;
          $268 = ($267<<24>>24)>(0);
          if ($268) {
           __THREW__ = 0;
           $269 = (invoke_iii(2239,($src|0),(1159800|0))|0);
           $270 = __THREW__; __THREW__ = 0;
           $271 = $270&1;
           if ($271) {
            label = 22;
            break;
           }
           __THREW__ = 0;
           $272 = (invoke_iii(2239,($269|0),($61|0))|0);
           $273 = __THREW__; __THREW__ = 0;
           $274 = $273&1;
           if ($274) {
            label = 22;
            break;
           }
           __THREW__ = 0;
           (invoke_iii(2239,($272|0),(1164104|0))|0);
           $275 = __THREW__; __THREW__ = 0;
           $276 = $275&1;
           if ($276) {
            label = 22;
            break;
           }
          } else {
           __THREW__ = 0;
           $277 = (invoke_iii(2239,($src|0),(1159800|0))|0);
           $278 = __THREW__; __THREW__ = 0;
           $279 = $278&1;
           if ($279) {
            label = 22;
            break;
           }
           __THREW__ = 0;
           $280 = (invoke_iii(2239,($277|0),($61|0))|0);
           $281 = __THREW__; __THREW__ = 0;
           $282 = $281&1;
           if ($282) {
            label = 22;
            break;
           }
           __THREW__ = 0;
           (invoke_iii(2239,($280|0),(1164152|0))|0);
           $283 = __THREW__; __THREW__ = 0;
           $284 = $283&1;
           if ($284) {
            label = 22;
            break;
           }
          }
          do {
           if (!((($44<<24>>24) == 0) | (($44<<24>>24) == 8))) {
            $285 = HEAP8[$43>>0]|0;
            $286 = ($285<<24>>24)==(1);
            if ($286) {
             __THREW__ = 0;
             (invoke_iii(2239,($src|0),(1164168|0))|0);
             $287 = __THREW__; __THREW__ = 0;
             $288 = $287&1;
             if ($288) {
              label = 22;
              break L23;
             } else {
              break;
             }
            }
            __THREW__ = 0;
            $289 = (invoke_iii(2239,($src|0),(1164288|0))|0);
            $290 = __THREW__; __THREW__ = 0;
            $291 = $290&1;
            if ($291) {
             label = 22;
             break L23;
            }
            $292 = HEAP8[$43>>0]|0;
            $293 = $292 << 24 >> 24;
            $294 = (1164192 + ($293<<2)|0);
            $295 = HEAP32[$294>>2]|0;
            __THREW__ = 0;
            $296 = (invoke_iii(2239,($289|0),($295|0))|0);
            $297 = __THREW__; __THREW__ = 0;
            $298 = $297&1;
            if ($298) {
             label = 22;
             break L23;
            }
            __THREW__ = 0;
            (invoke_iii(2239,($296|0),(1164312|0))|0);
            $299 = __THREW__; __THREW__ = 0;
            $300 = $299&1;
            if ($300) {
             label = 22;
             break L23;
            }
            __THREW__ = 0;
            (invoke_iii(2239,($src|0),(1164168|0))|0);
            $301 = __THREW__; __THREW__ = 0;
            $302 = $301&1;
            if ($302) {
             label = 22;
             break L23;
            }
           }
          } while(0);
          __THREW__ = 0;
          (invoke_iii(2239,($src|0),(1160912|0))|0);
          $303 = __THREW__; __THREW__ = 0;
          $304 = $303&1;
          if ($304) {
           label = 22;
          } else {
           __THREW__ = 0;
           invoke_vii(2482,($1|0),($3|0));
           $305 = __THREW__; __THREW__ = 0;
           $306 = $305&1;
           if ($306) {
            label = 22;
           } else {
            $307 = HEAP8[$1>>0]|0;
            $308 = $307 & 1;
            $309 = ($308<<24>>24)==(0);
            if ($309) {
             $312 = (($1) + 1|0);
             $313 = $312;
            } else {
             $310 = (($1) + 8|0);
             $311 = HEAP32[$310>>2]|0;
             $313 = $311;
            }
            $314 = (_strlen(($313|0))|0);
            $315 = ($314>>>0)>(4294967279);
            do {
             if ($315) {
              __THREW__ = 0;
              invoke_vi(3309,0);
              $316 = __THREW__; __THREW__ = 0;
              $317 = $316&1;
              if ($317) {
               break;
              }
              // unreachable;
             } else {
              $318 = ($314>>>0)<(11);
              if ($318) {
               $319 = $314 << 1;
               $320 = $319&255;
               HEAP8[$agg$result>>0] = $320;
               $321 = (($agg$result) + 1|0);
               $__p$0$i$i$i = $321;
              } else {
               $322 = (($314) + 16)|0;
               $323 = $322 & -16;
               __THREW__ = 0;
               $324 = (invoke_ii(2988,($323|0))|0);
               $325 = __THREW__; __THREW__ = 0;
               $326 = $325&1;
               if ($326) {
                break;
               }
               $327 = (($agg$result) + 8|0);
               HEAP32[$327>>2] = $324;
               $328 = $323 | 1;
               HEAP32[$agg$result>>2] = $328;
               $329 = (($agg$result) + 4|0);
               HEAP32[$329>>2] = $314;
               $__p$0$i$i$i = $324;
              }
              _memcpy(($__p$0$i$i$i|0),($313|0),($314|0))|0;
              $330 = (($__p$0$i$i$i) + ($314)|0);
              HEAP8[$330>>0] = 0;
              if (!($309)) {
               $331 = (($1) + 8|0);
               $332 = HEAP32[$331>>2]|0;
               __ZdlPv($332);
              }
              HEAP32[$src>>2] = ((390232 + 12|0));
              HEAP32[$4>>2] = ((390232 + 32|0));
              $333 = (($src) + 4|0);
              HEAP32[$333>>2] = ((225848 + 8|0));
              $334 = HEAP8[$12>>0]|0;
              $335 = $334 & 1;
              $336 = ($335<<24>>24)==(0);
              if (!($336)) {
               $337 = (($src) + 44|0);
               $338 = HEAP32[$337>>2]|0;
               __ZdlPv($338);
              }
              HEAP32[$333>>2] = ((3090568 + 8|0));
              __THREW__ = 0;
              invoke_vi(3299,($10|0));
              $339 = __THREW__; __THREW__ = 0;
              $340 = $339&1;
              if (!($340)) {
               __ZNSt3__18ios_baseD2Ev($5);
               STACKTOP = sp;return;
              }
              $341 = ___cxa_find_matching_catch()|0;
              $342 = tempRet0;
              __THREW__ = 0;
              invoke_vi(3217,($5|0));
              $343 = __THREW__; __THREW__ = 0;
              $344 = $343&1;
              if ($344) {
               $345 = ___cxa_find_matching_catch(0|0)|0;
               $346 = tempRet0;
               ___clang_call_terminate($345);
               // unreachable;
              } else {
               ___resumeException($341|0);
               // unreachable;
              }
             }
            } while(0);
            $347 = ___cxa_find_matching_catch()|0;
            $348 = tempRet0;
            if ($309) {
             $$0 = $347;$$01 = $348;
             break;
            }
            $349 = (($1) + 8|0);
            $350 = HEAP32[$349>>2]|0;
            __ZdlPv($350);
            $$0 = $347;$$01 = $348;
           }
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 22) {
    $58 = ___cxa_find_matching_catch()|0;
    $59 = tempRet0;
    $lpad$phi$index = $58;$lpad$phi$index9 = $59;
    label = 23;
   }
   if ((label|0) == 23) {
    $$0 = $lpad$phi$index;$$01 = $lpad$phi$index9;
   }
   HEAP32[$src>>2] = ((390232 + 12|0));
   HEAP32[$4>>2] = ((390232 + 32|0));
   $351 = (($src) + 4|0);
   HEAP32[$351>>2] = ((225848 + 8|0));
   $352 = HEAP8[$12>>0]|0;
   $353 = $352 & 1;
   $354 = ($353<<24>>24)==(0);
   if (!($354)) {
    $355 = (($src) + 44|0);
    $356 = HEAP32[$355>>2]|0;
    __ZdlPv($356);
   }
   HEAP32[$351>>2] = ((3090568 + 8|0));
   __THREW__ = 0;
   invoke_vi(3299,($10|0));
   $357 = __THREW__; __THREW__ = 0;
   $358 = $357&1;
   if ($358) {
    $361 = ___cxa_find_matching_catch(0|0)|0;
    $362 = tempRet0;
    __THREW__ = 0;
    invoke_vi(3217,($5|0));
    $363 = __THREW__; __THREW__ = 0;
    $364 = $363&1;
    if ($364) {
     $365 = ___cxa_find_matching_catch(0|0)|0;
     $366 = tempRet0;
     ___clang_call_terminate($365);
     // unreachable;
    } else {
     $eh$lpad$body$indexZ2D = $361;
     ___clang_call_terminate($eh$lpad$body$indexZ2D);
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_vi(3217,($5|0));
   $359 = __THREW__; __THREW__ = 0;
   $360 = $359&1;
   if (!($360)) {
    ___resumeException($$0|0);
    // unreachable;
   }
   $367 = ___cxa_find_matching_catch(0|0)|0;
   $368 = tempRet0;
   $eh$lpad$body$indexZ2D = $367;
   ___clang_call_terminate($eh$lpad$body$indexZ2D);
   // unreachable;
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi(3217,($2|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if ($40) {
  $41 = ___cxa_find_matching_catch(0|0)|0;
  $42 = tempRet0;
  ___clang_call_terminate($41);
  // unreachable;
 } else {
  ___resumeException($$01$i|0);
  // unreachable;
 }
}
function __ZL22AddTextureCombinerBodyRNSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEEijN8combiner8ChannelsE($src,$unitNdx,$combinerDesc,$channels) {
 $src = $src|0;
 $unitNdx = $unitNdx|0;
 $combinerDesc = $combinerDesc|0;
 $channels = $channels|0;
 var $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $channelMask = 0, $channelTypes = 0;
 var $op = 0, $operands = 0, $scale = 0, $sources = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $vararg_buffer = sp;
 $channelTypes = sp + 84|0;
 $channelMask = sp + 4|0;
 $sources = sp + 40|0;
 $operands = sp + 52|0;
 $op = sp + 64|0;
 $scale = sp + 68|0;
 $0 = sp + 72|0;
 HEAP8[$channelTypes>>0] = 8;
 $1 = (($channelTypes) + 1|0);
 HEAP8[$1>>0]=878929270&255;HEAP8[$1+1>>0]=(878929270>>8)&255;HEAP8[$1+2>>0]=(878929270>>16)&255;HEAP8[$1+3>>0]=878929270>>24;
 $2 = (($channelTypes) + 5|0);
 HEAP8[$2>>0] = 0;
 $3 = (($channelTypes) + 12|0);
 HEAP8[$3>>0] = 8;
 $4 = (($3) + 1|0);
 HEAP8[$4>>0]=862152054&255;HEAP8[$4+1>>0]=(862152054>>8)&255;HEAP8[$4+2>>0]=(862152054>>16)&255;HEAP8[$4+3>>0]=862152054>>24;
 $5 = (($3) + 5|0);
 HEAP8[$5>>0] = 0;
 $6 = (($channelTypes) + 24|0);
 HEAP8[$6>>0] = 10;
 $7 = (($6) + 1|0);
 ;HEAP8[$7+0>>0]=HEAP8[1164544+0>>0]|0;HEAP8[$7+1>>0]=HEAP8[1164544+1>>0]|0;HEAP8[$7+2>>0]=HEAP8[1164544+2>>0]|0;HEAP8[$7+3>>0]=HEAP8[1164544+3>>0]|0;HEAP8[$7+4>>0]=HEAP8[1164544+4>>0]|0;
 $8 = (($6) + 6|0);
 HEAP8[$8>>0] = 0;
 HEAP8[$channelMask>>0] = 0;
 $9 = (($channelMask) + 1|0);
 HEAP8[$9>>0] = 0;
 $10 = (($channelMask) + 12|0);
 HEAP8[$10>>0] = 8;
 $11 = (($10) + 1|0);
 HEAP8[$11>>0]=1650946606&255;HEAP8[$11+1>>0]=(1650946606>>8)&255;HEAP8[$11+2>>0]=(1650946606>>16)&255;HEAP8[$11+3>>0]=1650946606>>24;
 $12 = (($10) + 5|0);
 HEAP8[$12>>0] = 0;
 $13 = (($channelMask) + 24|0);
 HEAP8[$13>>0] = 4;
 $14 = (($13) + 1|0);
 HEAP8[$14>>0]=24878&255;HEAP8[$14+1>>0]=24878>>8;
 $15 = (($13) + 3|0);
 HEAP8[$15>>0] = 0;
 __THREW__ = 0;
 invoke_viiiii(117,($combinerDesc|0),($op|0),($sources|0),($operands|0),($scale|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 L1: do {
  if ($17) {
   label = 6;
  } else {
   __THREW__ = 0;
   $18 = (invoke_iii(2239,($src|0),(1164568|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 6;
   } else {
    $21 = (($channelMask) + (($channels*12)|0)|0);
    __THREW__ = 0;
    $22 = (invoke_iii(2341,($18|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 6;
    } else {
     __THREW__ = 0;
     (invoke_iii(2239,($22|0),(1164584|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 6;
     } else {
      $27 = HEAP32[$op>>2]|0;
      switch ($27|0) {
      case 2:  {
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164600|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        label = 6;
        break L1;
       }
       $48 = HEAP32[$operands>>2]|0;
       $49 = HEAP32[$sources>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($48|0),($49|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164608|0))|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        label = 6;
        break L1;
       }
       $54 = (($operands) + 4|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = (($sources) + 4|0);
       $57 = HEAP32[$56>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($55|0),($57|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164616|0))|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 6;
        break L1;
       }
       break;
      }
      case 5:  {
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164632|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 6;
        break L1;
       }
       $80 = (($operands) + 4|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = (($sources) + 4|0);
       $83 = HEAP32[$82>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($81|0),($83|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164640|0))|0);
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        label = 6;
        break L1;
       }
       $88 = HEAP32[$operands>>2]|0;
       $89 = HEAP32[$sources>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($88|0),($89|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164640|0))|0);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        label = 6;
        break L1;
       }
       $94 = (($operands) + 8|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = (($sources) + 8|0);
       $97 = HEAP32[$96>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),2,($95|0),($97|0));
       $98 = __THREW__; __THREW__ = 0;
       $99 = $98&1;
       if ($99) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164616|0))|0);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        label = 6;
        break L1;
       }
       break;
      }
      case 4:  {
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164600|0))|0);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        label = 6;
        break L1;
       }
       $64 = HEAP32[$operands>>2]|0;
       $65 = HEAP32[$sources>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($64|0),($65|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164624|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        label = 6;
        break L1;
       }
       $70 = (($operands) + 4|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = (($sources) + 4|0);
       $73 = HEAP32[$72>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($71|0),($73|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164616|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        label = 6;
        break L1;
       }
       break;
      }
      case 1:  {
       $34 = HEAP32[$operands>>2]|0;
       $35 = HEAP32[$sources>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($34|0),($35|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164592|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        label = 6;
        break L1;
       }
       $40 = (($operands) + 4|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = (($sources) + 4|0);
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($41|0),($43|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 6;
        break L1;
       }
       break;
      }
      case 0:  {
       $30 = HEAP32[$operands>>2]|0;
       $31 = HEAP32[$sources>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($30|0),($31|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        label = 6;
        break L1;
       }
       break;
      }
      case 8:  {
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164600|0))|0);
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if ($103) {
        label = 6;
        break L1;
       }
       $104 = HEAP32[$operands>>2]|0;
       $105 = HEAP32[$sources>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($104|0),($105|0));
       $106 = __THREW__; __THREW__ = 0;
       $107 = $106&1;
       if ($107) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164592|0))|0);
       $108 = __THREW__; __THREW__ = 0;
       $109 = $108&1;
       if ($109) {
        label = 6;
        break L1;
       }
       $110 = (($operands) + 8|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = (($sources) + 8|0);
       $113 = HEAP32[$112>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($111|0),($113|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164608|0))|0);
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 6;
        break L1;
       }
       $118 = (($operands) + 4|0);
       $119 = HEAP32[$118>>2]|0;
       $120 = (($sources) + 4|0);
       $121 = HEAP32[$120>>2]|0;
       __THREW__ = 0;
       invoke_viiiii(118,($src|0),($unitNdx|0),($channels|0),($119|0),($121|0));
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if ($123) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($src|0),(1164616|0))|0);
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       if ($125) {
        label = 6;
        break L1;
       }
       break;
      }
      default: {
       __THREW__ = 0;
       HEAP32[$vararg_buffer>>2] = $27;
       invoke_viii(1617,($0|0),(1164648|0),($vararg_buffer|0));
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if ($127) {
        label = 6;
        break L1;
       }
       $128 = HEAP8[$0>>0]|0;
       $129 = $128 & 1;
       $130 = ($129<<24>>24)==(0);
       if ($130) {
        $133 = (($0) + 1|0);
        $134 = $133;
       } else {
        $131 = (($0) + 8|0);
        $132 = HEAP32[$131>>2]|0;
        $134 = $132;
       }
       __THREW__ = 0;
       invoke_viiiiiiii(21,($134|0),0,(1164232|0),484,1,0,0,(0|0));
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if ($136) {
        $148 = ___cxa_find_matching_catch()|0;
        $149 = tempRet0;
        $150 = HEAP8[$0>>0]|0;
        $151 = $150 & 1;
        $152 = ($151<<24>>24)==(0);
        if ($152) {
         $$01 = $149;$$02 = $148;
         break L1;
        }
        $153 = (($0) + 8|0);
        $154 = HEAP32[$153>>2]|0;
        __ZdlPv($154);
        $$01 = $149;$$02 = $148;
        break L1;
       }
       $137 = HEAP8[$0>>0]|0;
       $138 = $137 & 1;
       $139 = ($138<<24>>24)==(0);
       if (!($139)) {
        $140 = (($0) + 8|0);
        $141 = HEAP32[$140>>2]|0;
        __ZdlPv($141);
       }
       $142 = (($channelTypes) + (($channels*12)|0)|0);
       __THREW__ = 0;
       $143 = (invoke_iii(2341,($src|0),($142|0))|0);
       $144 = __THREW__; __THREW__ = 0;
       $145 = $144&1;
       if ($145) {
        label = 6;
        break L1;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($143|0),(1164688|0))|0);
       $146 = __THREW__; __THREW__ = 0;
       $147 = $146&1;
       if ($147) {
        label = 6;
        break L1;
       }
      }
      }
      $155 = HEAP32[$scale>>2]|0;
      $156 = ($155|0)==(1);
      if (!($156)) {
       __THREW__ = 0;
       $157 = (invoke_iii(2239,($src|0),(1164696|0))|0);
       $158 = __THREW__; __THREW__ = 0;
       $159 = $158&1;
       if ($159) {
        label = 6;
        break;
       }
       $160 = HEAP32[$scale>>2]|0;
       __THREW__ = 0;
       $161 = (invoke_iii(2240,($157|0),($160|0))|0);
       $162 = __THREW__; __THREW__ = 0;
       $163 = $162&1;
       if ($163) {
        label = 6;
        break;
       }
       __THREW__ = 0;
       (invoke_iii(2239,($161|0),(1164712|0))|0);
       $164 = __THREW__; __THREW__ = 0;
       $165 = $164&1;
       if ($165) {
        label = 6;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_iii(2239,($src|0),(1159824|0))|0);
      $166 = __THREW__; __THREW__ = 0;
      $167 = $166&1;
      if ($167) {
       label = 6;
      } else {
       $168 = (($channelMask) + 24|0);
       $169 = HEAP8[$168>>0]|0;
       $170 = $169 & 1;
       $171 = ($170<<24>>24)==(0);
       if (!($171)) {
        $172 = (($channelMask) + 32|0);
        $173 = HEAP32[$172>>2]|0;
        __ZdlPv($173);
       }
       $174 = (($channelMask) + 12|0);
       $175 = HEAP8[$174>>0]|0;
       $176 = $175 & 1;
       $177 = ($176<<24>>24)==(0);
       if (!($177)) {
        $207 = (($channelMask) + 20|0);
        $208 = HEAP32[$207>>2]|0;
        __ZdlPv($208);
       }
       $209 = HEAP8[$channelMask>>0]|0;
       $210 = $209 & 1;
       $211 = ($210<<24>>24)==(0);
       if (!($211)) {
        $212 = (($channelMask) + 8|0);
        $213 = HEAP32[$212>>2]|0;
        __ZdlPv($213);
       }
       $214 = (($channelTypes) + 24|0);
       $215 = HEAP8[$214>>0]|0;
       $216 = $215 & 1;
       $217 = ($216<<24>>24)==(0);
       if (!($217)) {
        $178 = (($channelTypes) + 32|0);
        $179 = HEAP32[$178>>2]|0;
        __ZdlPv($179);
       }
       $180 = (($channelTypes) + 12|0);
       $181 = HEAP8[$180>>0]|0;
       $182 = $181 & 1;
       $183 = ($182<<24>>24)==(0);
       if (!($183)) {
        $200 = (($channelTypes) + 20|0);
        $201 = HEAP32[$200>>2]|0;
        __ZdlPv($201);
       }
       $202 = HEAP8[$channelTypes>>0]|0;
       $203 = $202 & 1;
       $204 = ($203<<24>>24)==(0);
       if ($204) {
        STACKTOP = sp;return;
       }
       $205 = (($channelTypes) + 8|0);
       $206 = HEAP32[$205>>2]|0;
       __ZdlPv($206);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $28 = ___cxa_find_matching_catch()|0;
  $29 = tempRet0;
  $$01 = $29;$$02 = $28;
 }
 $184 = (($channelMask) + 24|0);
 $185 = HEAP8[$184>>0]|0;
 $186 = $185 & 1;
 $187 = ($186<<24>>24)==(0);
 if (!($187)) {
  $188 = (($channelMask) + 32|0);
  $189 = HEAP32[$188>>2]|0;
  __ZdlPv($189);
 }
 $190 = (($channelMask) + 12|0);
 $191 = HEAP8[$190>>0]|0;
 $192 = $191 & 1;
 $193 = ($192<<24>>24)==(0);
 if (!($193)) {
  $225 = (($channelMask) + 20|0);
  $226 = HEAP32[$225>>2]|0;
  __ZdlPv($226);
 }
 $227 = HEAP8[$channelMask>>0]|0;
 $228 = $227 & 1;
 $229 = ($228<<24>>24)==(0);
 if (!($229)) {
  $230 = (($channelMask) + 8|0);
  $231 = HEAP32[$230>>2]|0;
  __ZdlPv($231);
 }
 $232 = (($channelTypes) + 24|0);
 $233 = HEAP8[$232>>0]|0;
 $234 = $233 & 1;
 $235 = ($234<<24>>24)==(0);
 if (!($235)) {
  $194 = (($channelTypes) + 32|0);
  $195 = HEAP32[$194>>2]|0;
  __ZdlPv($195);
 }
 $196 = (($channelTypes) + 12|0);
 $197 = HEAP8[$196>>0]|0;
 $198 = $197 & 1;
 $199 = ($198<<24>>24)==(0);
 if (!($199)) {
  $218 = (($channelTypes) + 20|0);
  $219 = HEAP32[$218>>2]|0;
  __ZdlPv($219);
 }
 $220 = HEAP8[$channelTypes>>0]|0;
 $221 = $220 & 1;
 $222 = ($221<<24>>24)==(0);
 if ($222) {
  ___resumeException($$02|0);
  // unreachable;
 }
 $223 = (($channelTypes) + 8|0);
 $224 = HEAP32[$223>>2]|0;
 __ZdlPv($224);
 ___resumeException($$02|0);
 // unreachable;
}
function __ZL16AddTexOperandSrcRNSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEEiN8combiner8ChannelsENS7_7OperandENS7_6SourceE($src,$unitNdx,$channels,$operand,$source) {
 $src = $src|0;
 $unitNdx = $unitNdx|0;
 $channels = $channels|0;
 $operand = $operand|0;
 $source = $source|0;
 var $0 = 0, $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164600)|0);
 $0 = $operand & -2;
 $1 = ($0|0)==(2);
 if ($1) {
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164720)|0);
 }
 if ((($source|0) == 0)) {
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164736)|0);
 } else if ((($source|0) == 2)) {
  $2 = (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164744)|0);
  (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEi($2,$unitNdx)|0);
 } else if ((($source|0) == 3)) {
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164536)|0);
 } else if ((($source|0) == 1)) {
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164384)|0);
 } else {
  HEAP32[$vararg_buffer>>2] = $source;
  _printf_console(1164768,$vararg_buffer);
  (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164808)|0);
 }
 (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164616)|0);
 if ((($operand|0) == 3) | (($operand|0) == 1)) {
  if ((($channels|0) == 2)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164560)|0);
   STACKTOP = sp;return;
  } else if ((($channels|0) == 0)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164832)|0);
   STACKTOP = sp;return;
  } else if ((($channels|0) == 1)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164840)|0);
   STACKTOP = sp;return;
  } else {
   STACKTOP = sp;return;
  }
 } else if ((($operand|0) == 2) | (($operand|0) == 0)) {
  if ((($channels|0) == 2)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164560)|0);
   STACKTOP = sp;return;
  } else if ((($channels|0) == 1)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164552)|0);
   STACKTOP = sp;return;
  } else if ((($channels|0) == 0)) {
   (__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc($src,1164824)|0);
   STACKTOP = sp;return;
  } else {
   STACKTOP = sp;return;
  }
 } else {
  STACKTOP = sp;return;
 }
}
function __Z23CleanupLZMASharedBufferv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628408>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId(0,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZL25InitializeUnityWebStreamsv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj(8)|0);
 $1 = (($0) + 4|0);
 HEAP32[$0>>2] = $0;
 HEAP32[$1>>2] = $0;
 HEAP32[1164848>>2] = $0;
 STACKTOP = sp;return;
}
function __ZL22CleanupUnityWebStreamsv() {
 var $$lcssa35 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $node$01$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1164848>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($0|0);
 if ($4) {
  $$lcssa35 = $3;
 } else {
  $6 = $3;
  while(1) {
   $5 = (($6) + 63|0);
   HEAP8[$5>>0] = 1;
   $7 = (($6) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==($0|0);
   if ($9) {
    break;
   } else {
    $6 = $8;
   }
  }
  $$pre = HEAP32[$2>>2]|0;
  $10 = ($$pre|0)==($0|0);
  if ($10) {
   $$lcssa35 = $0;
  } else {
   $node$01$i = $$pre;
   while(1) {
    $11 = (($node$01$i) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    HEAP32[$node$01$i>>2] = 0;
    HEAP32[$11>>2] = 0;
    $13 = ($12|0)==($0|0);
    if ($13) {
     $$lcssa35 = $0;
     break;
    } else {
     $node$01$i = $12;
    }
   }
  }
 }
 HEAP32[$2>>2] = $$lcssa35;
 HEAP32[$0>>2] = $$lcssa35;
 $14 = HEAP32[1164848>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  __ZdlPv($14);
 }
 HEAP32[1164848>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN14UnityWebStream7ReleaseEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -1)|0;
 HEAP32[$1>>2] = $3;
 $4 = ($2|0)<(2);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $13 = HEAP32[628408>>2]|0;
  $14 = ($this|0)==(0|0);
  if ($14) {
   $15 = $13;$18 = $0;
  } else {
   $16 = $0;$17 = $13;
   label = 5;
  }
 } else {
  $7 = (($this) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($5) + 4|0);
  HEAP32[$9>>2] = $8;
  $10 = HEAP32[$this>>2]|0;
  $11 = HEAP32[$7>>2]|0;
  HEAP32[$11>>2] = $10;
  HEAP32[$this>>2] = 0;
  HEAP32[$7>>2] = 0;
  $12 = HEAP32[628408>>2]|0;
  $16 = $0;$17 = $12;
  label = 5;
 }
 if ((label|0) == 5) {
  __ZN14UnityWebStreamD2Ev($this);
  $15 = $17;$18 = $16;
 }
 HEAP32[$0>>2] = $15;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($this,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZNK14UnityWebStream10IsFinishedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 66|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $12 = 1;
  STACKTOP = sp;return ($12|0);
 }
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $6 = (($this) + 65|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if ($8) {
   $12 = 0;
   STACKTOP = sp;return ($12|0);
  }
 }
 $9 = (($this) + 61|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = $11;
 STACKTOP = sp;return ($12|0);
}
function __ZN14UnityWebStreamD2Ev($this) {
 $this = $this|0;
 var $$byval_copy7 = 0, $$pre = 0, $$pre$phi30Z2D = 0, $$pre$phiZ2D = 0, $$pre28 = 0, $$pre29 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__f$01$i$i$i$i$i = 0, $__f$01$i$i$i$i$i9 = 0, $__new_last2$i$i$i$i$i$i$i = 0, $__new_last2$i$i$i$i$i$i$i14 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp = 0, $scevgep$i$i$i$i$i$i$i = 0, $scevgep$i$i$i$i$i$i$i15 = 0, $scevgep4$i$i$i$i$i$i$i = 0, $scevgep4$i$i$i$i$i$i$i19 = 0, $uglygep$i$i$i$i$i$i$i = 0, $uglygep$i$i$i$i$i$i$i17 = 0;
 var $uglygep3$i$i$i$i$i$i$i = 0, $uglygep3$i$i$i$i$i$i$i18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy7 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 63|0);
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 140|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  label = 2;
 } else {
  $13 = HEAP32[628408>>2]|0;
  $14 = HEAP32[$5>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  invoke_vi($16|0,($5|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   label = 8;
  } else {
   HEAP32[$2>>2] = $13;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(2591,($5|0),($$byval_copy7|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 8;
   } else {
    HEAP32[$4>>2] = 0;
    label = 2;
   }
  }
 }
 L5: do {
  if ((label|0) == 2) {
   $7 = (($this) + 144|0);
   $8 = (($this) + 152|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0);
   L7: do {
    if (!($10)) {
     $11 = (($this) + 148|0);
     $12 = (($this) + 8|0);
     $50 = $9;
     while(1) {
      $40 = HEAP32[$11>>2]|0;
      $41 = (($40) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (($40) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = HEAP32[$40>>2]|0;
      $46 = (($45) + 4|0);
      HEAP32[$46>>2] = $44;
      $47 = HEAP32[$40>>2]|0;
      $48 = HEAP32[$43>>2]|0;
      HEAP32[$48>>2] = $47;
      $49 = (($50) + -1)|0;
      HEAP32[$8>>2] = $49;
      __ZdlPv($40);
      $51 = HEAP32[$12>>2]|0;
      $52 = (($51) + -1)|0;
      HEAP32[$12>>2] = $52;
      $53 = HEAP32[$12>>2]|0;
      $54 = HEAP32[1164864>>2]|0;
      $55 = HEAP32[$54>>2]|0;
      $56 = ($55|0)<(4);
      if ($56) {
       $57 = (($54) + 4|0);
       HEAP32[$0>>2] = 6;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
       $58 = (invoke_iiiiiii(102,12,16,($$byval_copy7|0),0,(1164856|0),79)|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       $61 = (($58) + 8|0);
       HEAP32[$61>>2] = $42;
       $62 = HEAP32[$57>>2]|0;
       $63 = (($62) + 4|0);
       HEAP32[$63>>2] = $58;
       $64 = HEAP32[$57>>2]|0;
       HEAP32[$58>>2] = $64;
       HEAP32[$57>>2] = $58;
       $65 = (($58) + 4|0);
       HEAP32[$65>>2] = $57;
       $66 = (($54) + 12|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($67) + 1)|0;
       HEAP32[$66>>2] = $68;
       $69 = HEAP32[1164864>>2]|0;
       $70 = HEAP32[$69>>2]|0;
       $71 = (($70) + 1)|0;
       HEAP32[$69>>2] = $71;
      } else {
       $72 = HEAP32[628408>>2]|0;
       HEAP32[$1>>2] = $72;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_vii(2591,($42|0),($$byval_copy7|0));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
      }
      $75 = HEAP32[$8>>2]|0;
      $76 = ($75|0)==(0);
      if ($76) {
       break L7;
      } else {
       $50 = $75;
      }
     }
     $21 = ___cxa_find_matching_catch()|0;
     $22 = tempRet0;
     $$pre$phi30Z2D = $8;$$pre$phiZ2D = $7;$lpad$phi$index = $21;$lpad$phi$index2 = $22;
     break L5;
    }
   } while(0);
   $77 = (($this) + 156|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = ($78|0)==(0|0);
   if (!($79)) {
    __THREW__ = 0;
    invoke_vi(3798,($78|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 8;
     break;
    }
    $$pre = HEAP32[$8>>2]|0;
    $phitmp = ($$pre|0)==(0);
    if (!($phitmp)) {
     $82 = (($this) + 148|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = HEAP32[$7>>2]|0;
     $85 = (($84) + 4|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = HEAP32[$83>>2]|0;
     $88 = (($87) + 4|0);
     HEAP32[$88>>2] = $86;
     $89 = HEAP32[$83>>2]|0;
     $90 = HEAP32[$85>>2]|0;
     HEAP32[$90>>2] = $89;
     HEAP32[$8>>2] = 0;
     $91 = ($83|0)==($7|0);
     if (!($91)) {
      $__f$01$i$i$i$i$i9 = $83;
      while(1) {
       $92 = (($__f$01$i$i$i$i$i9) + 4|0);
       $93 = HEAP32[$92>>2]|0;
       __ZdlPv($__f$01$i$i$i$i$i9);
       $94 = ($93|0)==($7|0);
       if ($94) {
        break;
       } else {
        $__f$01$i$i$i$i$i9 = $93;
       }
      }
     }
    }
   }
   $95 = (($this) + 124|0);
   $96 = HEAP32[$95>>2]|0;
   $97 = ($96|0)==(0|0);
   if (!($97)) {
    $98 = (($this) + 128|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = ($99|0)==($96|0);
    if (!($100)) {
     $__new_last2$i$i$i$i$i$i$i = $96;
     $scevgep$i$i$i$i$i$i$i = (($99) + -8|0);
     $101 = (0 - ($__new_last2$i$i$i$i$i$i$i))|0;
     $uglygep$i$i$i$i$i$i$i = (($scevgep$i$i$i$i$i$i$i) + ($101)|0);
     $uglygep3$i$i$i$i$i$i$i = $uglygep$i$i$i$i$i$i$i;
     $102 = $uglygep3$i$i$i$i$i$i$i >>> 3;
     $103 = $102 ^ -1;
     $scevgep4$i$i$i$i$i$i$i = (($99) + ($103<<3)|0);
     HEAP32[$98>>2] = $scevgep4$i$i$i$i$i$i$i;
    }
    __ZdlPv($96);
   }
   $104 = (($this) + 96|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if (!($107)) {
    $108 = (($this) + 104|0);
    $109 = HEAP32[$108>>2]|0;
    __ZdlPv($109);
   }
   $110 = (($this) + 84|0);
   $111 = HEAP8[$110>>0]|0;
   $112 = $111 & 1;
   $113 = ($112<<24>>24)==(0);
   if (!($113)) {
    $114 = (($this) + 92|0);
    $115 = HEAP32[$114>>2]|0;
    __ZdlPv($115);
   }
   $116 = (($this) + 68|0);
   $117 = HEAP8[$116>>0]|0;
   $118 = $117 & 1;
   $119 = ($118<<24>>24)==(0);
   if (!($119)) {
    $120 = (($this) + 76|0);
    $121 = HEAP32[$120>>2]|0;
    __ZdlPv($121);
   }
   $122 = (($this) + 12|0);
   $123 = HEAP8[$122>>0]|0;
   $124 = $123 & 1;
   $125 = ($124<<24>>24)==(0);
   if ($125) {
    STACKTOP = sp;return;
   }
   $126 = (($this) + 20|0);
   $127 = HEAP32[$126>>2]|0;
   __ZdlPv($127);
   STACKTOP = sp;return;
  }
 } while(0);
 if ((label|0) == 8) {
  $23 = ___cxa_find_matching_catch()|0;
  $24 = tempRet0;
  $$pre28 = (($this) + 144|0);
  $$pre29 = (($this) + 152|0);
  $$pre$phi30Z2D = $$pre29;$$pre$phiZ2D = $$pre28;$lpad$phi$index = $23;$lpad$phi$index2 = $24;
 }
 $25 = HEAP32[$$pre$phi30Z2D>>2]|0;
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = (($this) + 148|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = HEAP32[$$pre$phiZ2D>>2]|0;
  $30 = (($29) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = HEAP32[$28>>2]|0;
  $33 = (($32) + 4|0);
  HEAP32[$33>>2] = $31;
  $34 = HEAP32[$28>>2]|0;
  $35 = HEAP32[$30>>2]|0;
  HEAP32[$35>>2] = $34;
  HEAP32[$$pre$phi30Z2D>>2] = 0;
  $36 = ($28|0)==($$pre$phiZ2D|0);
  if (!($36)) {
   $__f$01$i$i$i$i$i = $28;
   while(1) {
    $37 = (($__f$01$i$i$i$i$i) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    __ZdlPv($__f$01$i$i$i$i$i);
    $39 = ($38|0)==($$pre$phiZ2D|0);
    if ($39) {
     break;
    } else {
     $__f$01$i$i$i$i$i = $38;
    }
   }
  }
 }
 $128 = (($this) + 124|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ($129|0)==(0|0);
 if (!($130)) {
  $131 = (($this) + 128|0);
  $132 = HEAP32[$131>>2]|0;
  $133 = ($132|0)==($129|0);
  if (!($133)) {
   $__new_last2$i$i$i$i$i$i$i14 = $129;
   $scevgep$i$i$i$i$i$i$i15 = (($132) + -8|0);
   $134 = (0 - ($__new_last2$i$i$i$i$i$i$i14))|0;
   $uglygep$i$i$i$i$i$i$i17 = (($scevgep$i$i$i$i$i$i$i15) + ($134)|0);
   $uglygep3$i$i$i$i$i$i$i18 = $uglygep$i$i$i$i$i$i$i17;
   $135 = $uglygep3$i$i$i$i$i$i$i18 >>> 3;
   $136 = $135 ^ -1;
   $scevgep4$i$i$i$i$i$i$i19 = (($132) + ($136<<3)|0);
   HEAP32[$131>>2] = $scevgep4$i$i$i$i$i$i$i19;
  }
  __ZdlPv($129);
 }
 $137 = (($this) + 96|0);
 $138 = HEAP8[$137>>0]|0;
 $139 = $138 & 1;
 $140 = ($139<<24>>24)==(0);
 if (!($140)) {
  $141 = (($this) + 104|0);
  $142 = HEAP32[$141>>2]|0;
  __ZdlPv($142);
 }
 $143 = (($this) + 84|0);
 $144 = HEAP8[$143>>0]|0;
 $145 = $144 & 1;
 $146 = ($145<<24>>24)==(0);
 if (!($146)) {
  $147 = (($this) + 92|0);
  $148 = HEAP32[$147>>2]|0;
  __ZdlPv($148);
 }
 $149 = (($this) + 68|0);
 $150 = HEAP8[$149>>0]|0;
 $151 = $150 & 1;
 $152 = ($151<<24>>24)==(0);
 if (!($152)) {
  $153 = (($this) + 76|0);
  $154 = HEAP32[$153>>2]|0;
  __ZdlPv($154);
 }
 $155 = (($this) + 12|0);
 $156 = HEAP8[$155>>0]|0;
 $157 = $156 & 1;
 $158 = ($157<<24>>24)==(0);
 if ($158) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $159 = (($this) + 20|0);
 $160 = HEAP32[$159>>2]|0;
 __ZdlPv($160);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN14UnityWebStream24UpdateAllUnityWebStreamsEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[1164848>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($0) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($0|0);
 if ($4) {
  STACKTOP = sp;return;
 } else {
  $6 = $3;
 }
 while(1) {
  $5 = (($6) + 4|0);
  $7 = HEAP32[$5>>2]|0;
  __ZN14UnityWebStream14UpdateProgressEv($6);
  $8 = HEAP32[1164848>>2]|0;
  $9 = ($7|0)==($8|0);
  if ($9) {
   break;
  } else {
   $6 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZN14UnityWebStream14UpdateProgressEv($this) {
 $this = $this|0;
 var $$0 = 0, $$01 = 0, $$pre = 0, $$pre15 = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $assetBundleAbsolutePathPrefix = 0;
 var $bundlePath = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $streamedLevels$0$lcssa = 0, $streamedLevels$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $assetBundleAbsolutePathPrefix = sp + 12|0;
 $bundlePath = sp;
 $0 = (($this) + 66|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 128|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 124|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $7;
 $11 = $9;
 $12 = (($10) - ($11))|0;
 $13 = $12 >> 3;
 $14 = (($this) + 40|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)<($13|0);
 if ($16) {
  $20 = $9;$23 = $4;$streamedLevels$07 = $15;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $19 = ((($20) + ($streamedLevels$07<<3)|0) + 4|0);
  $21 = HEAP32[$19>>2]|0;
  $22 = HEAP32[$23>>2]|0;
  $24 = (($22) + 28|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (FUNCTION_TABLE_ii[$25 & 4095]($23)|0);
  $27 = ($26>>>0)<($21>>>0);
  $18 = (($streamedLevels$07) + 1)|0;
  if ($27) {
   $streamedLevels$0$lcssa = $streamedLevels$07;
   break;
  }
  $17 = ($18|0)<($13|0);
  if (!($17)) {
   $streamedLevels$0$lcssa = $18;
   break;
  }
  $$pre15 = HEAP32[$8>>2]|0;
  $$pre16 = HEAP32[$3>>2]|0;
  $20 = $$pre15;$23 = $$pre16;$streamedLevels$07 = $18;
 }
 $28 = HEAP32[$14>>2]|0;
 $29 = ($streamedLevels$0$lcssa|0)==($28|0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = HEAP32[$3>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($31) + 20|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 4095]($30)|0);
 $35 = ($34|0)==(0);
 do {
  if ($35) {
   label = 10;
  } else {
   $36 = HEAP32[$3>>2]|0;
   $37 = HEAP32[$36>>2]|0;
   $38 = (($37) + 20|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = (FUNCTION_TABLE_ii[$39 & 4095]($36)|0);
   $41 = ($40|0)==(2);
   if ($41) {
    label = 10;
   } else {
    $105 = HEAP32[$3>>2]|0;
    $106 = HEAP32[$105>>2]|0;
    $107 = (($106) + 20|0);
    $108 = HEAP32[$107>>2]|0;
    $109 = (FUNCTION_TABLE_ii[$108 & 4095]($105)|0);
    $110 = ($109|0)==(1);
    if (!($110)) {
     $111 = HEAP32[$3>>2]|0;
     $112 = HEAP32[$111>>2]|0;
     $113 = (($112) + 20|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (FUNCTION_TABLE_ii[$114 & 4095]($111)|0);
     $116 = ($115|0)==(3);
     if (!($116)) {
      $$pre = HEAP32[$14>>2]|0;
      $123 = $$pre;
      break;
     }
    }
    $117 = (($this) + 65|0);
    $118 = HEAP8[$117>>0]|0;
    $119 = ($118<<24>>24)==(0);
    if ($119) {
     STACKTOP = sp;return;
    } else {
     HEAP32[$14>>2] = $streamedLevels$0$lcssa;
     $123 = $streamedLevels$0$lcssa;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $42 = (($this) + 60|0);
  $43 = HEAP8[$42>>0]|0;
  $44 = ($43<<24>>24)==(0);
  L29: do {
   if (!($44)) {
    $45 = HEAP32[$3>>2]|0;
    $46 = (($45) + 8|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = (($45) + 4|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($47|0)==($49|0);
    if (!($50)) {
     $51 = (__Z20GetPersistentManagerv()|0);
     $52 = HEAP32[$3>>2]|0;
     $53 = (($52) + 4|0);
     $54 = HEAP32[$53>>2]|0;
     __Z28GetAbsoluteAssetBundlePrefixRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($assetBundleAbsolutePathPrefix,$54);
     $55 = HEAP32[$3>>2]|0;
     $56 = (($55) + 4|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = (($55) + 8|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($57|0)==($59|0);
     L32: do {
      if ($60) {
       label = 28;
      } else {
       $61 = (($bundlePath) + 8|0);
       $62 = $57;
       while(1) {
        __THREW__ = 0;
        invoke_viii(1774,($bundlePath|0),($assetBundleAbsolutePathPrefix|0),($62|0));
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 17;
         break;
        }
        __THREW__ = 0;
        $65 = (invoke_ii(3464,($bundlePath|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
        if (!($65)) {
         __THREW__ = 0;
         $78 = (invoke_iii(2722,($51|0),($bundlePath|0))|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break;
         }
         if (!($78)) {
          $81 = (($62) + 12|0);
          __THREW__ = 0;
          (invoke_iiiiiii(127,($51|0),($bundlePath|0),($81|0),256,0,-1)|0);
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if ($83) {
           break;
          }
         }
        }
        $84 = HEAP8[$bundlePath>>0]|0;
        $85 = $84 & 1;
        $86 = ($85<<24>>24)==(0);
        if (!($86)) {
         $87 = HEAP32[$61>>2]|0;
         __ZdlPv($87);
        }
        $88 = (($62) + 32|0);
        $89 = HEAP32[$3>>2]|0;
        $90 = (($89) + 8|0);
        $91 = HEAP32[$90>>2]|0;
        $92 = ($88|0)==($91|0);
        if ($92) {
         label = 28;
         break L32;
        } else {
         $62 = $88;
        }
       }
       if ((label|0) == 17) {
        $68 = ___cxa_find_matching_catch()|0;
        $69 = tempRet0;
        $lpad$phi$index = $68;$lpad$phi$index2 = $69;
        label = 19;
        break;
       }
       $72 = ___cxa_find_matching_catch()|0;
       $73 = tempRet0;
       $74 = HEAP8[$bundlePath>>0]|0;
       $75 = $74 & 1;
       $76 = ($75<<24>>24)==(0);
       if ($76) {
        $$0 = $73;$$01 = $72;
       } else {
        $77 = HEAP32[$61>>2]|0;
        __ZdlPv($77);
        $$0 = $73;$$01 = $72;
       }
      }
     } while(0);
     do {
      if ((label|0) == 28) {
       __THREW__ = 0;
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        $70 = ___cxa_find_matching_catch()|0;
        $71 = tempRet0;
        $lpad$phi$index = $70;$lpad$phi$index2 = $71;
        label = 19;
        break;
       }
       $95 = HEAP8[$assetBundleAbsolutePathPrefix>>0]|0;
       $96 = $95 & 1;
       $97 = ($96<<24>>24)==(0);
       if ($97) {
        break L29;
       }
       $98 = (($assetBundleAbsolutePathPrefix) + 8|0);
       $99 = HEAP32[$98>>2]|0;
       __ZdlPv($99);
       break L29;
      }
     } while(0);
     if ((label|0) == 19) {
      $$0 = $lpad$phi$index2;$$01 = $lpad$phi$index;
     }
     $100 = HEAP8[$assetBundleAbsolutePathPrefix>>0]|0;
     $101 = $100 & 1;
     $102 = ($101<<24>>24)==(0);
     if ($102) {
      ___resumeException($$01|0);
      // unreachable;
     }
     $103 = (($assetBundleAbsolutePathPrefix) + 8|0);
     $104 = HEAP32[$103>>2]|0;
     __ZdlPv($104);
     ___resumeException($$01|0);
     // unreachable;
    }
   }
  } while(0);
  HEAP32[$14>>2] = $streamedLevels$0$lcssa;
  $123 = $streamedLevels$0$lcssa;
 }
 $120 = (($this) + 120|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($123|0)>=($121|0);
 $124 = (($this) + 61|0);
 $125 = $122&1;
 HEAP8[$124>>0] = $125;
 $126 = ($123|0)<($13|0);
 if ($126) {
  STACKTOP = sp;return;
 }
 $127 = HEAP32[$this>>2]|0;
 $128 = ($127|0)==(0|0);
 if ($128) {
  STACKTOP = sp;return;
 }
 $129 = (($this) + 4|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = (($127) + 4|0);
 HEAP32[$131>>2] = $130;
 $132 = HEAP32[$this>>2]|0;
 $133 = HEAP32[$129>>2]|0;
 HEAP32[$133>>2] = $132;
 HEAP32[$this>>2] = 0;
 HEAP32[$129>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20CacheDownloadBuffers16StaticInitializeEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[628240>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__Znwj10MemLabelIdbiPKci(20,$$byval_copy,1,16,1164856,702)|0);
 HEAP32[$2>>2] = 0;
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = $3;
 $4 = (($2) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = (($2) + 12|0);
 HEAP32[$5>>2] = 0;
 HEAP32[1164864>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN20CacheDownloadBuffers13StaticDestroyEv() {
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[1164864>>2]|0;
 $2 = HEAP32[628240>>2]|0;
 $3 = ($1|0)==(0|0);
 if (!($3)) {
  __ZN20CacheDownloadBuffersD2Ev($1);
 }
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z19free_alloc_internalPv10MemLabelId($1,$$byval_copy);
 HEAP32[1164864>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN20CacheDownloadBuffersD2Ev($this) {
 $this = $this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__f$0$i$i$i$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy2 = sp + 12|0;
 $0 = sp;
 $1 = sp + 4|0;
 $2 = sp + 8|0;
 $3 = (($this) + 4|0);
 $4 = (($this) + 12|0);
 $5 = (($this) + 8|0);
 while(1) {
  $6 = HEAP32[$4>>2]|0;
  $7 = ($6|0)==(0);
  if ($7) {
   label = 11;
   break;
  }
  $8 = HEAP32[$5>>2]|0;
  $9 = (($8) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[628408>>2]|0;
  HEAP32[$2>>2] = $11;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  invoke_vii(2591,($10|0),($$byval_copy2|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   label = 6;
   break;
  }
  $14 = HEAP32[$5>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = HEAP32[$14>>2]|0;
  $18 = (($17) + 4|0);
  HEAP32[$18>>2] = $16;
  $19 = HEAP32[$14>>2]|0;
  $20 = HEAP32[$15>>2]|0;
  HEAP32[$20>>2] = $19;
  $21 = HEAP32[$4>>2]|0;
  $22 = (($21) + -1)|0;
  HEAP32[$4>>2] = $22;
  HEAP32[$1>>2] = 6;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  invoke_vii(2591,($14|0),($$byval_copy2|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  ___cxa_call_unexpected(($25|0));
  // unreachable;
 }
 else if ((label|0) == 6) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  $29 = HEAP32[$4>>2]|0;
  $30 = ($29|0)==(0);
  if ($30) {
   ___resumeException($27|0);
   // unreachable;
  }
  $31 = HEAP32[$5>>2]|0;
  $32 = HEAP32[$3>>2]|0;
  $33 = (($32) + 4|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = HEAP32[$31>>2]|0;
  $36 = (($35) + 4|0);
  HEAP32[$36>>2] = $34;
  $37 = HEAP32[$31>>2]|0;
  $38 = HEAP32[$33>>2]|0;
  HEAP32[$38>>2] = $37;
  HEAP32[$4>>2] = 0;
  $__f$0$i$i$i$i1 = $31;
  while(1) {
   $39 = ($__f$0$i$i$i$i1|0)==($3|0);
   if ($39) {
    label = 12;
    break;
   }
   $40 = (($__f$0$i$i$i$i1) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   HEAP32[$0>>2] = 6;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_vii(2591,($__f$0$i$i$i$i1|0),($$byval_copy2|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    label = 10;
    break;
   } else {
    $__f$0$i$i$i$i1 = $41;
   }
  }
  if ((label|0) == 10) {
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   ___cxa_call_unexpected(($44|0));
   // unreachable;
  }
  else if ((label|0) == 12) {
   ___resumeException($27|0);
   // unreachable;
  }
 }
 else if ((label|0) == 11) {
  STACKTOP = sp;return;
 }
}
function __ZL47s_AssemblyU002DCSharpU002DfirstpassRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(1165056);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a1263() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(1165152,276,0,0);
 STACKTOP = sp;return;
}
function __ZL33s_AssemblyU002DCSharpRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(1166016);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a5() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(1166104,277,0,0);
 STACKTOP = sp;return;
}
function __ZL52s_AssemblyU002DUnityScriptU002DfirstpassRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(1166544);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a9() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(1166648,278,0,0);
 STACKTOP = sp;return;
}
function __ZL22s_Boo_LangRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(1166928);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a14() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(1167008,279,0,0);
 STACKTOP = sp;return;
}
function __Z51AssemblyU002DCSharpU002Dfirstpass_MouseLook_m__ctorP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1270240);
 $0 = (($__this) + 20|0);
 HEAPF32[$0>>2] = Math_fround(15.0);
 $1 = (($__this) + 24|0);
 HEAPF32[$1>>2] = Math_fround(15.0);
 $2 = (($__this) + 28|0);
 HEAPF32[$2>>2] = Math_fround(-360.0);
 $3 = (($__this) + 32|0);
 HEAPF32[$3>>2] = Math_fround(360.0);
 $4 = (($__this) + 36|0);
 HEAPF32[$4>>2] = Math_fround(-60.0);
 $5 = (($__this) + 40|0);
 HEAPF32[$5>>2] = Math_fround(60.0);
 __THREW__ = 0;
 invoke_vi(3120,($__this|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_UpdateP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0), $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = 0;
 var $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = Math_fround(0), $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = Math_fround(0), $79 = Math_fround(0), $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = 0, $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_2 = 0, $L_23 = 0, $L_47 = 0, $L_50 = 0, $L_50$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_50$byval_copy = sp + 52|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 $L_23 = sp + 16|0;
 $L_47 = sp + 28|0;
 $L_50 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1270288);
 __THREW__ = 0;
 invoke_v(280);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 16|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == 1)) {
    __THREW__ = 0;
    $55 = (invoke_ii(2522,($__this|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = HEAP32[2993616>>2]|0;
    __THREW__ = 0;
    $59 = (Math_fround(+(invoke_fii(41,(0|0),($58|0)))));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     break;
    }
    $62 = (($__this) + 20|0);
    $63 = Math_fround(HEAPF32[$62>>2]);
    __THREW__ = 0;
    invoke_vi(3799,($55|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     break;
    }
    $66 = Math_fround($59 * $63);
    __THREW__ = 0;
    invoke_vifff(6,($55|0),0.0,(+$66),0.0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else if ((($3|0) == 0)) {
    __THREW__ = 0;
    $6 = (invoke_ii(2522,($__this|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2127,($L_2|0),($6|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = (($L_2) + 4|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    $15 = HEAP32[2993600>>2]|0;
    __THREW__ = 0;
    $16 = (Math_fround(+(invoke_fii(41,(0|0),($15|0)))));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    $19 = (($__this) + 20|0);
    $20 = Math_fround(HEAPF32[$19>>2]);
    $21 = Math_fround($16 * $20);
    $22 = Math_fround($14 + $21);
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = (($__this) + 44|0);
    $26 = Math_fround(HEAPF32[$25>>2]);
    $27 = HEAP32[2993608>>2]|0;
    __THREW__ = 0;
    $28 = (Math_fround(+(invoke_fii(41,(0|0),($27|0)))));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    $31 = (($__this) + 24|0);
    $32 = Math_fround(HEAPF32[$31>>2]);
    $33 = Math_fround($28 * $32);
    $34 = Math_fround($26 + $33);
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    HEAPF32[$25>>2] = $34;
    $37 = (($__this) + 36|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    $39 = (($__this) + 40|0);
    $40 = Math_fround(HEAPF32[$39>>2]);
    __THREW__ = 0;
    $41 = (Math_fround(+(invoke_fifff(1,(0|0),(+$34),(+$38),(+$40)))));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     break;
    }
    HEAPF32[$25>>2] = $41;
    __THREW__ = 0;
    $44 = (invoke_ii(2522,($__this|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    $47 = Math_fround(HEAPF32[$25>>2]);
    $48 = Math_fround(-$47);
    ;HEAP32[$L_23+0>>2]=0|0;HEAP32[$L_23+4>>2]=0|0;HEAP32[$L_23+8>>2]=0|0;
    __THREW__ = 0;
    invoke_vifff(4,($L_23|0),(+$48),(+$22),0.0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($44|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    __THREW__ = 0;
    ;HEAP32[$L_50$byval_copy+0>>2]=HEAP32[$L_23+0>>2]|0;HEAP32[$L_50$byval_copy+4>>2]=HEAP32[$L_23+4>>2]|0;HEAP32[$L_50$byval_copy+8>>2]=HEAP32[$L_23+8>>2]|0;
    invoke_vii(2128,($44|0),($L_50$byval_copy|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     break;
    }
    $71 = (($__this) + 44|0);
    $72 = Math_fround(HEAPF32[$71>>2]);
    $73 = HEAP32[2993624>>2]|0;
    __THREW__ = 0;
    $74 = (Math_fround(+(invoke_fii(41,(0|0),($73|0)))));
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     break;
    }
    $77 = (($__this) + 24|0);
    $78 = Math_fround(HEAPF32[$77>>2]);
    $79 = Math_fround($74 * $78);
    $80 = Math_fround($72 + $79);
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    HEAPF32[$71>>2] = $80;
    $83 = (($__this) + 36|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = (($__this) + 40|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    __THREW__ = 0;
    $87 = (Math_fround(+(invoke_fifff(1,(0|0),(+$80),(+$84),(+$86)))));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     break;
    }
    HEAPF32[$71>>2] = $87;
    __THREW__ = 0;
    $90 = (invoke_ii(2522,($__this|0))|0);
    $91 = __THREW__; __THREW__ = 0;
    $92 = $91&1;
    if ($92) {
     break;
    }
    $93 = Math_fround(HEAPF32[$71>>2]);
    $94 = Math_fround(-$93);
    __THREW__ = 0;
    $95 = (invoke_ii(2522,($__this|0))|0);
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($95|0));
    $98 = __THREW__; __THREW__ = 0;
    $99 = $98&1;
    if ($99) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(2127,($L_47|0),($95|0));
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     break;
    }
    $102 = (($L_47) + 4|0);
    $103 = Math_fround(HEAPF32[$102>>2]);
    ;HEAP32[$L_50+0>>2]=0|0;HEAP32[$L_50+4>>2]=0|0;HEAP32[$L_50+8>>2]=0|0;
    __THREW__ = 0;
    invoke_vifff(4,($L_50|0),(+$94),(+$103),0.0);
    $104 = __THREW__; __THREW__ = 0;
    $105 = $104&1;
    if ($105) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($90|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     break;
    }
    __THREW__ = 0;
    ;HEAP32[$L_50$byval_copy+0>>2]=HEAP32[$L_50+0>>2]|0;HEAP32[$L_50$byval_copy+4>>2]=HEAP32[$L_50+4>>2]|0;HEAP32[$L_50$byval_copy+8>>2]=HEAP32[$L_50+8>>2]|0;
    invoke_vii(2128,($90|0),($L_50$byval_copy|0));
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z9NullCheckPv($this_ptr) {
 $this_ptr = $this_ptr|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this_ptr|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 STACKTOP = sp;return;
}
function __Z51AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_StartP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1270336);
 __THREW__ = 0;
 $0 = (invoke_ii(3465,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(1194,(0|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   if (!($3)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   $8 = (invoke_ii(3465,($__this|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vii(2149,($8|0),1);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __ZL84UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Rigidbody_TP33UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z81UnityEngine_UnityEngine_Component_m_GetComponent_mscorlib_System_Object_T_gsharedP33UnityEngine_UnityEngine_ComponentPPv($__this,2878360)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14ActionInvoker06InvokeEPFvPvES0_PS0_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 FUNCTION_TABLE_vi[$action & 4095]($obj);
 STACKTOP = sp;return (0|0);
}
function __Z74AssemblyU002DCSharpU002Dfirstpass_MouseLook_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(1270720)|0);
 __Z48UnityEngine_UnityEngine_AddComponentMenu_m__ctorP40UnityEngine_UnityEngine_AddComponentMenuP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN16StackTraceSentryD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(4)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3800,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch(0|0)|0;
 $6 = tempRet0;
 ___clang_call_terminate($5);
 // unreachable;
}
function __ZN16StackTraceSentryC2EP10MethodInfo($this,$method) {
 $this = $this|0;
 $method = $method|0;
 var $0 = 0, $frame_info = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $frame_info = sp;
 HEAP32[$this>>2] = $method;
 HEAP32[$frame_info>>2] = $method;
 $0 = (__ZN6il2cpp2vm6Thread7CurrentEv()|0);
 __ZN6il2cpp2vm6Thread9PushFrameEP12Il2CppThreadR20Il2CppStackFrameInfo($0,$frame_info);
 STACKTOP = sp;return;
}
function __Z40AssemblyU002DCSharp_BJController_m__ctorP32AssemblyU002DCSharp_BJController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1271336);
 __THREW__ = 0;
 invoke_vi(3120,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42AssemblyU002DCSharp_BJController_m_OnStartP32AssemblyU002DCSharp_BJController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1271384);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vii(2150,($1|0),1);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($__this) + 24|0);
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($7|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vii(2101,($7|0),1);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($__this) + 20|0);
     $13 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vii(2101,($13|0),1);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = (($__this) + 28|0);
       $19 = HEAP32[$18>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($19|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        invoke_vii(2101,($19|0),1);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         $24 = (($__this) + 32|0);
         $25 = HEAP32[$24>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($25|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          invoke_vii(2101,($25|0),1);
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if (!($29)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($30|0);
 // unreachable;
}
function __Z75AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m__ctorP67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1271880);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__0P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P30AssemblyU002DCSharp_JSONObject($__this,$backgroundColor) {
 $__this = $__this|0;
 $backgroundColor = $backgroundColor|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = Math_fround(0), $114 = Math_fround(0), $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = Math_fround(0), $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = Math_fround(0), $173 = Math_fround(0), $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = Math_fround(0), $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = Math_fround(0), $295 = Math_fround(0), $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0);
 var $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = Math_fround(0), $334 = Math_fround(0), $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $L_100 = 0, $L_100$byval_copy = 0, $L_56 = 0, $L_58 = 0, $L_62 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_100$byval_copy = sp + 72|0;
 $_stackTraceSentry = sp;
 $L_56 = sp + 8|0;
 $L_58 = sp + 24|0;
 $L_62 = sp + 40|0;
 $L_100 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1271928);
 __THREW__ = 0;
 invoke_v(281);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($backgroundColor|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($backgroundColor) + 24|0);
    $5 = HEAP32[$4>>2]|0;
    __THREW__ = 0;
    $6 = (invoke_iii(634,(0|0),($5|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     if ($6) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3799,($backgroundColor|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = HEAP32[$4>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($backgroundColor|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = HEAP32[$4>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        $19 = (invoke_ii(1816,($16|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         invoke_vi(3799,($13|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          $24 = (($19) + -6)|0;
          __THREW__ = 0;
          $25 = (invoke_iiii(528,($13|0),5,($24|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           invoke_vi(3799,($backgroundColor|0));
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            $30 = HEAP32[$4>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($30|0));
            $31 = __THREW__; __THREW__ = 0;
            $32 = $31&1;
            if (!($32)) {
             $33 = HEAP32[2990632>>2]|0;
             __THREW__ = 0;
             $34 = (invoke_iii(635,($30|0),($33|0))|0);
             $35 = __THREW__; __THREW__ = 0;
             $36 = $35&1;
             if (!($36)) {
              if ($34) {
               $V_0$0 = $25;
              } else {
               __THREW__ = 0;
               invoke_vi(3799,($backgroundColor|0));
               $37 = __THREW__; __THREW__ = 0;
               $38 = $37&1;
               if ($38) {
                break;
               }
               $39 = HEAP32[$4>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($backgroundColor|0));
               $40 = __THREW__; __THREW__ = 0;
               $41 = $40&1;
               if ($41) {
                break;
               }
               $42 = HEAP32[$4>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($42|0));
               $43 = __THREW__; __THREW__ = 0;
               $44 = $43&1;
               if ($44) {
                break;
               }
               __THREW__ = 0;
               $45 = (invoke_ii(1816,($42|0))|0);
               $46 = __THREW__; __THREW__ = 0;
               $47 = $46&1;
               if ($47) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($39|0));
               $48 = __THREW__; __THREW__ = 0;
               $49 = $48&1;
               if ($49) {
                break;
               }
               $50 = (($45) + -5)|0;
               __THREW__ = 0;
               $51 = (invoke_iiii(528,($39|0),4,($50|0))|0);
               $52 = __THREW__; __THREW__ = 0;
               $53 = $52&1;
               if ($53) {
                break;
               } else {
                $V_0$0 = $51;
               }
              }
              __THREW__ = 0;
              invoke_vi(3799,($V_0$0|0));
              $54 = __THREW__; __THREW__ = 0;
              $55 = $54&1;
              if (!($55)) {
               $56 = HEAP32[2990640>>2]|0;
               $57 = HEAP32[2990648>>2]|0;
               __THREW__ = 0;
               $58 = (invoke_iiii(548,($V_0$0|0),($56|0),($57|0))|0);
               $59 = __THREW__; __THREW__ = 0;
               $60 = $59&1;
               if (!($60)) {
                __THREW__ = 0;
                (invoke_ii(2996,(1168808|0))|0);
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if (!($62)) {
                 __THREW__ = 0;
                 $63 = (invoke_iii(2723,(1168808|0),1)|0);
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if (!($65)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($63|0));
                  $66 = __THREW__; __THREW__ = 0;
                  $67 = $66&1;
                  if (!($67)) {
                   $68 = (($63) + 12|0);
                   $69 = HEAP32[$68>>2]|0;
                   $70 = ($69|0)==(0);
                   if ($70) {
                    __THREW__ = 0;
                    $71 = (invoke_i(132)|0);
                    $72 = __THREW__; __THREW__ = 0;
                    $73 = $72&1;
                    if ($73) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($71|0));
                    $74 = __THREW__; __THREW__ = 0;
                    $75 = $74&1;
                    if ($75) {
                     break;
                    }
                   }
                   $76 = (($63) + 16|0);
                   HEAP16[$76>>1] = 44;
                   __THREW__ = 0;
                   invoke_vi(3799,($58|0));
                   $77 = __THREW__; __THREW__ = 0;
                   $78 = $77&1;
                   if ($78) {
                    break;
                   }
                   __THREW__ = 0;
                   $79 = (invoke_iii(622,($58|0),($63|0))|0);
                   $80 = __THREW__; __THREW__ = 0;
                   $81 = $80&1;
                   if ($81) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($79|0));
                   $82 = __THREW__; __THREW__ = 0;
                   $83 = $82&1;
                   if ($83) {
                    break;
                   }
                   $84 = (($79) + 12|0);
                   $85 = HEAP32[$84>>2]|0;
                   $86 = ($85|0)==(4);
                   if (!($86)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($79|0));
                    $264 = __THREW__; __THREW__ = 0;
                    $265 = $264&1;
                    if ($265) {
                     break;
                    }
                    $266 = HEAP32[$84>>2]|0;
                    $267 = ($266|0)==(3);
                    if (!($267)) {
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                    $268 = (($__this) + 8|0);
                    $269 = HEAP32[$268>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($269|0));
                    $270 = __THREW__; __THREW__ = 0;
                    $271 = $270&1;
                    if ($271) {
                     break;
                    }
                    __THREW__ = 0;
                    $272 = (invoke_ii(3466,($269|0))|0);
                    $273 = __THREW__; __THREW__ = 0;
                    $274 = $273&1;
                    if ($274) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($272|0));
                    $275 = __THREW__; __THREW__ = 0;
                    $276 = $275&1;
                    if ($276) {
                     break;
                    }
                    __THREW__ = 0;
                    $277 = (invoke_ii(2543,($272|0))|0);
                    $278 = __THREW__; __THREW__ = 0;
                    $279 = $278&1;
                    if ($279) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($79|0));
                    $280 = __THREW__; __THREW__ = 0;
                    $281 = $280&1;
                    if ($281) {
                     break;
                    }
                    $282 = HEAP32[$84>>2]|0;
                    $283 = ($282|0)==(0);
                    if ($283) {
                     __THREW__ = 0;
                     $284 = (invoke_i(132)|0);
                     $285 = __THREW__; __THREW__ = 0;
                     $286 = $285&1;
                     if ($286) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($284|0));
                     $287 = __THREW__; __THREW__ = 0;
                     $288 = $287&1;
                     if ($288) {
                      break;
                     }
                    }
                    $289 = (($79) + 16|0);
                    $290 = HEAP32[$289>>2]|0;
                    __THREW__ = 0;
                    $291 = (invoke_iii(1043,(0|0),($290|0))|0);
                    $292 = __THREW__; __THREW__ = 0;
                    $293 = $292&1;
                    if ($293) {
                     break;
                    }
                    $294 = (Math_fround(($291|0)));
                    $295 = Math_fround($294 / Math_fround(255.0));
                    __THREW__ = 0;
                    invoke_vi(3799,($79|0));
                    $296 = __THREW__; __THREW__ = 0;
                    $297 = $296&1;
                    if ($297) {
                     break;
                    }
                    $298 = HEAP32[$84>>2]|0;
                    $299 = ($298>>>0)<(2);
                    if ($299) {
                     __THREW__ = 0;
                     $300 = (invoke_i(132)|0);
                     $301 = __THREW__; __THREW__ = 0;
                     $302 = $301&1;
                     if ($302) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($300|0));
                     $303 = __THREW__; __THREW__ = 0;
                     $304 = $303&1;
                     if ($304) {
                      break;
                     }
                    }
                    $305 = HEAP32[$79>>2]|0;
                    $306 = (($305) + 92|0);
                    $307 = HEAP32[$306>>2]|0;
                    $308 = (($289) + ($307)|0);
                    $309 = HEAP32[$308>>2]|0;
                    __THREW__ = 0;
                    $310 = (invoke_iii(1043,(0|0),($309|0))|0);
                    $311 = __THREW__; __THREW__ = 0;
                    $312 = $311&1;
                    if ($312) {
                     break;
                    }
                    $313 = (Math_fround(($310|0)));
                    $314 = Math_fround($313 / Math_fround(255.0));
                    __THREW__ = 0;
                    invoke_vi(3799,($79|0));
                    $315 = __THREW__; __THREW__ = 0;
                    $316 = $315&1;
                    if ($316) {
                     break;
                    }
                    $317 = HEAP32[$84>>2]|0;
                    $318 = ($317>>>0)<(3);
                    if ($318) {
                     __THREW__ = 0;
                     $319 = (invoke_i(132)|0);
                     $320 = __THREW__; __THREW__ = 0;
                     $321 = $320&1;
                     if ($321) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($319|0));
                     $322 = __THREW__; __THREW__ = 0;
                     $323 = $322&1;
                     if ($323) {
                      break;
                     }
                    }
                    $324 = HEAP32[$79>>2]|0;
                    $325 = (($324) + 92|0);
                    $326 = HEAP32[$325>>2]|0;
                    $327 = $326 << 1;
                    $328 = (($289) + ($327)|0);
                    $329 = HEAP32[$328>>2]|0;
                    __THREW__ = 0;
                    $330 = (invoke_iii(1043,(0|0),($329|0))|0);
                    $331 = __THREW__; __THREW__ = 0;
                    $332 = $331&1;
                    if ($332) {
                     break;
                    }
                    $333 = (Math_fround(($330|0)));
                    $334 = Math_fround($333 / Math_fround(255.0));
                    ;HEAP32[$L_100+0>>2]=0|0;HEAP32[$L_100+4>>2]=0|0;HEAP32[$L_100+8>>2]=0|0;HEAP32[$L_100+12>>2]=0|0;
                    __THREW__ = 0;
                    invoke_vifff(5,($L_100|0),(+$295),(+$314),(+$334));
                    $335 = __THREW__; __THREW__ = 0;
                    $336 = $335&1;
                    if ($336) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($277|0));
                    $337 = __THREW__; __THREW__ = 0;
                    $338 = $337&1;
                    if ($338) {
                     break;
                    }
                    __THREW__ = 0;
                    ;HEAP32[$L_100$byval_copy+0>>2]=HEAP32[$L_100+0>>2]|0;HEAP32[$L_100$byval_copy+4>>2]=HEAP32[$L_100+4>>2]|0;HEAP32[$L_100$byval_copy+8>>2]=HEAP32[$L_100+8>>2]|0;HEAP32[$L_100$byval_copy+12>>2]=HEAP32[$L_100+12>>2]|0;
                    invoke_vii(2097,($277|0),($L_100$byval_copy|0));
                    $339 = __THREW__; __THREW__ = 0;
                    $340 = $339&1;
                    if ($340) {
                     break;
                    }
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   $87 = (($__this) + 8|0);
                   $88 = HEAP32[$87>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($88|0));
                   $89 = __THREW__; __THREW__ = 0;
                   $90 = $89&1;
                   if ($90) {
                    break;
                   }
                   __THREW__ = 0;
                   $91 = (invoke_ii(3466,($88|0))|0);
                   $92 = __THREW__; __THREW__ = 0;
                   $93 = $92&1;
                   if ($93) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $94 = __THREW__; __THREW__ = 0;
                   $95 = $94&1;
                   if ($95) {
                    break;
                   }
                   __THREW__ = 0;
                   $96 = (invoke_ii(2543,($91|0))|0);
                   $97 = __THREW__; __THREW__ = 0;
                   $98 = $97&1;
                   if ($98) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($79|0));
                   $99 = __THREW__; __THREW__ = 0;
                   $100 = $99&1;
                   if ($100) {
                    break;
                   }
                   $101 = HEAP32[$84>>2]|0;
                   $102 = ($101|0)==(0);
                   if ($102) {
                    __THREW__ = 0;
                    $103 = (invoke_i(132)|0);
                    $104 = __THREW__; __THREW__ = 0;
                    $105 = $104&1;
                    if ($105) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($103|0));
                    $106 = __THREW__; __THREW__ = 0;
                    $107 = $106&1;
                    if ($107) {
                     break;
                    }
                   }
                   $108 = (($79) + 16|0);
                   $109 = HEAP32[$108>>2]|0;
                   __THREW__ = 0;
                   $110 = (invoke_iii(1043,(0|0),($109|0))|0);
                   $111 = __THREW__; __THREW__ = 0;
                   $112 = $111&1;
                   if ($112) {
                    break;
                   }
                   $113 = (Math_fround(($110|0)));
                   $114 = Math_fround($113 / Math_fround(255.0));
                   __THREW__ = 0;
                   invoke_vi(3799,($79|0));
                   $115 = __THREW__; __THREW__ = 0;
                   $116 = $115&1;
                   if ($116) {
                    break;
                   }
                   $117 = HEAP32[$84>>2]|0;
                   $118 = ($117>>>0)<(2);
                   if ($118) {
                    __THREW__ = 0;
                    $119 = (invoke_i(132)|0);
                    $120 = __THREW__; __THREW__ = 0;
                    $121 = $120&1;
                    if ($121) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($119|0));
                    $122 = __THREW__; __THREW__ = 0;
                    $123 = $122&1;
                    if ($123) {
                     break;
                    }
                   }
                   $124 = HEAP32[$79>>2]|0;
                   $125 = (($124) + 92|0);
                   $126 = HEAP32[$125>>2]|0;
                   $127 = (($108) + ($126)|0);
                   $128 = HEAP32[$127>>2]|0;
                   __THREW__ = 0;
                   $129 = (invoke_iii(1043,(0|0),($128|0))|0);
                   $130 = __THREW__; __THREW__ = 0;
                   $131 = $130&1;
                   if ($131) {
                    break;
                   }
                   $132 = (Math_fround(($129|0)));
                   $133 = Math_fround($132 / Math_fround(255.0));
                   __THREW__ = 0;
                   invoke_vi(3799,($79|0));
                   $134 = __THREW__; __THREW__ = 0;
                   $135 = $134&1;
                   if ($135) {
                    break;
                   }
                   $136 = HEAP32[$84>>2]|0;
                   $137 = ($136>>>0)<(3);
                   if ($137) {
                    __THREW__ = 0;
                    $138 = (invoke_i(132)|0);
                    $139 = __THREW__; __THREW__ = 0;
                    $140 = $139&1;
                    if ($140) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($138|0));
                    $141 = __THREW__; __THREW__ = 0;
                    $142 = $141&1;
                    if ($142) {
                     break;
                    }
                   }
                   $143 = HEAP32[$79>>2]|0;
                   $144 = (($143) + 92|0);
                   $145 = HEAP32[$144>>2]|0;
                   $146 = $145 << 1;
                   $147 = (($108) + ($146)|0);
                   $148 = HEAP32[$147>>2]|0;
                   __THREW__ = 0;
                   $149 = (invoke_iii(1043,(0|0),($148|0))|0);
                   $150 = __THREW__; __THREW__ = 0;
                   $151 = $150&1;
                   if ($151) {
                    break;
                   }
                   $152 = (Math_fround(($149|0)));
                   $153 = Math_fround($152 / Math_fround(255.0));
                   __THREW__ = 0;
                   invoke_vi(3799,($79|0));
                   $154 = __THREW__; __THREW__ = 0;
                   $155 = $154&1;
                   if ($155) {
                    break;
                   }
                   $156 = HEAP32[$84>>2]|0;
                   $157 = ($156>>>0)<(4);
                   if ($157) {
                    __THREW__ = 0;
                    $158 = (invoke_i(132)|0);
                    $159 = __THREW__; __THREW__ = 0;
                    $160 = $159&1;
                    if ($160) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($158|0));
                    $161 = __THREW__; __THREW__ = 0;
                    $162 = $161&1;
                    if ($162) {
                     break;
                    }
                   }
                   $163 = HEAP32[$79>>2]|0;
                   $164 = (($163) + 92|0);
                   $165 = HEAP32[$164>>2]|0;
                   $166 = ($165*3)|0;
                   $167 = (($108) + ($166)|0);
                   $168 = HEAP32[$167>>2]|0;
                   __THREW__ = 0;
                   $169 = (invoke_iii(1043,(0|0),($168|0))|0);
                   $170 = __THREW__; __THREW__ = 0;
                   $171 = $170&1;
                   if ($171) {
                    break;
                   }
                   $172 = (Math_fround(($169|0)));
                   $173 = Math_fround($172 / Math_fround(255.0));
                   ;HEAP32[$L_56+0>>2]=0|0;HEAP32[$L_56+4>>2]=0|0;HEAP32[$L_56+8>>2]=0|0;HEAP32[$L_56+12>>2]=0|0;
                   __THREW__ = 0;
                   invoke_viffff(2,($L_56|0),(+$114),(+$133),(+$153),(+$173));
                   $174 = __THREW__; __THREW__ = 0;
                   $175 = $174&1;
                   if ($175) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($96|0));
                   $176 = __THREW__; __THREW__ = 0;
                   $177 = $176&1;
                   if ($177) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_100$byval_copy+0>>2]=HEAP32[$L_56+0>>2]|0;HEAP32[$L_100$byval_copy+4>>2]=HEAP32[$L_56+4>>2]|0;HEAP32[$L_100$byval_copy+8>>2]=HEAP32[$L_56+8>>2]|0;HEAP32[$L_100$byval_copy+12>>2]=HEAP32[$L_56+12>>2]|0;
                   invoke_vii(2097,($96|0),($L_100$byval_copy|0));
                   $178 = __THREW__; __THREW__ = 0;
                   $179 = $178&1;
                   if ($179) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $180 = __THREW__; __THREW__ = 0;
                   $181 = $180&1;
                   if ($181) {
                    break;
                   }
                   __THREW__ = 0;
                   $182 = (invoke_ii(2543,($91|0))|0);
                   $183 = __THREW__; __THREW__ = 0;
                   $184 = $183&1;
                   if ($184) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($182|0));
                   $185 = __THREW__; __THREW__ = 0;
                   $186 = $185&1;
                   if ($186) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2096,($L_58|0),($182|0));
                   $187 = __THREW__; __THREW__ = 0;
                   $188 = $187&1;
                   if ($188) {
                    break;
                   }
                   $189 = (($L_58) + 12|0);
                   $190 = Math_fround(HEAPF32[$189>>2]);
                   $191 = !($190 >= Math_fround(1.0));
                   if (!($191)) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $192 = __THREW__; __THREW__ = 0;
                   $193 = $192&1;
                   if ($193) {
                    break;
                   }
                   __THREW__ = 0;
                   $194 = (invoke_ii(2543,($91|0))|0);
                   $195 = __THREW__; __THREW__ = 0;
                   $196 = $195&1;
                   if ($196) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($194|0));
                   $197 = __THREW__; __THREW__ = 0;
                   $198 = $197&1;
                   if ($198) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2096,($L_62|0),($194|0));
                   $199 = __THREW__; __THREW__ = 0;
                   $200 = $199&1;
                   if ($200) {
                    break;
                   }
                   $201 = (($L_62) + 12|0);
                   $202 = Math_fround(HEAPF32[$201>>2]);
                   $203 = $202 != Math_fround(0.0);
                   if (!($203)) {
                    $204 = (($__this) + 12|0);
                    HEAP8[$204>>0] = 1;
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $205 = __THREW__; __THREW__ = 0;
                   $206 = $205&1;
                   if ($206) {
                    break;
                   }
                   __THREW__ = 0;
                   $207 = (invoke_ii(2543,($91|0))|0);
                   $208 = __THREW__; __THREW__ = 0;
                   $209 = $208&1;
                   if ($209) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($207|0));
                   $210 = __THREW__; __THREW__ = 0;
                   $211 = $210&1;
                   if ($211) {
                    break;
                   }
                   $212 = HEAP32[2990656>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(768,($207|0),($212|0),5);
                   $213 = __THREW__; __THREW__ = 0;
                   $214 = $213&1;
                   if ($214) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $215 = __THREW__; __THREW__ = 0;
                   $216 = $215&1;
                   if ($216) {
                    break;
                   }
                   __THREW__ = 0;
                   $217 = (invoke_ii(2543,($91|0))|0);
                   $218 = __THREW__; __THREW__ = 0;
                   $219 = $218&1;
                   if ($219) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($217|0));
                   $220 = __THREW__; __THREW__ = 0;
                   $221 = $220&1;
                   if ($221) {
                    break;
                   }
                   $222 = HEAP32[2990664>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(768,($217|0),($222|0),10);
                   $223 = __THREW__; __THREW__ = 0;
                   $224 = $223&1;
                   if ($224) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $225 = __THREW__; __THREW__ = 0;
                   $226 = $225&1;
                   if ($226) {
                    break;
                   }
                   __THREW__ = 0;
                   $227 = (invoke_ii(2543,($91|0))|0);
                   $228 = __THREW__; __THREW__ = 0;
                   $229 = $228&1;
                   if ($229) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($227|0));
                   $230 = __THREW__; __THREW__ = 0;
                   $231 = $230&1;
                   if ($231) {
                    break;
                   }
                   $232 = HEAP32[2990672>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(768,($227|0),($232|0),0);
                   $233 = __THREW__; __THREW__ = 0;
                   $234 = $233&1;
                   if ($234) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $235 = __THREW__; __THREW__ = 0;
                   $236 = $235&1;
                   if ($236) {
                    break;
                   }
                   __THREW__ = 0;
                   $237 = (invoke_ii(2543,($91|0))|0);
                   $238 = __THREW__; __THREW__ = 0;
                   $239 = $238&1;
                   if ($239) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($237|0));
                   $240 = __THREW__; __THREW__ = 0;
                   $241 = $240&1;
                   if ($241) {
                    break;
                   }
                   $242 = HEAP32[2990680>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(2100,($237|0),($242|0));
                   $243 = __THREW__; __THREW__ = 0;
                   $244 = $243&1;
                   if ($244) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $245 = __THREW__; __THREW__ = 0;
                   $246 = $245&1;
                   if ($246) {
                    break;
                   }
                   __THREW__ = 0;
                   $247 = (invoke_ii(2543,($91|0))|0);
                   $248 = __THREW__; __THREW__ = 0;
                   $249 = $248&1;
                   if ($249) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($247|0));
                   $250 = __THREW__; __THREW__ = 0;
                   $251 = $250&1;
                   if ($251) {
                    break;
                   }
                   $252 = HEAP32[2990688>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(2099,($247|0),($252|0));
                   $253 = __THREW__; __THREW__ = 0;
                   $254 = $253&1;
                   if ($254) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($91|0));
                   $255 = __THREW__; __THREW__ = 0;
                   $256 = $255&1;
                   if ($256) {
                    break;
                   }
                   __THREW__ = 0;
                   $257 = (invoke_ii(2543,($91|0))|0);
                   $258 = __THREW__; __THREW__ = 0;
                   $259 = $258&1;
                   if ($259) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($257|0));
                   $260 = __THREW__; __THREW__ = 0;
                   $261 = $260&1;
                   if ($261) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2098,($257|0),3000);
                   $262 = __THREW__; __THREW__ = 0;
                   $263 = $262&1;
                   if ($263) {
                    break;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL83UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Renderer_TP33UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z81UnityEngine_UnityEngine_Component_m_GetComponent_mscorlib_System_Object_T_gsharedP33UnityEngine_UnityEngine_ComponentPPv($__this,2869520)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__1P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P30AssemblyU002DCSharp_JSONObject($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1271976);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($name|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($name) + 24|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vii(2005,($1|0),($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__2P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P22mscorlib_System_String($__this,$p0) {
 $__this = $__this|0;
 $p0 = $p0|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1272024);
 $0 = (($__this) + 12|0);
 HEAP8[$0>>0] = 1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__3P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P30AssemblyU002DCSharp_JSONObject($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1272072);
 __THREW__ = 0;
 invoke_v(282);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(2528,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(3799,($name|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($name) + 24|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = HEAP32[2990856>>2]|0;
     __THREW__ = 0;
     $14 = (invoke_iiiii(101,(0|0),($6|0),($13|0),($12|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3799,($3|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       invoke_vii(2005,($3|0),($14|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__4P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P30AssemblyU002DCSharp_JSONObject($__this,$children) {
 $__this = $__this|0;
 $children = $children|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $L_11 = 0, $L_16 = 0, $V_1 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 48|0;
 $V_1 = sp;
 $L_11 = sp + 16|0;
 $L_16 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1272120);
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 32|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if (!($6)) {
    $9 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = (($9) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($9|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = (($13) + 1)|0;
    HEAP32[$12>>2] = $16;
   }
   $17 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($17|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = (($17) + 32|0);
    HEAP8[$20>>0] = 0;
    __THREW__ = 0;
    invoke_vi(3799,($children|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = (($children) + 16|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vii(1235,($L_11|0),($24|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       ;HEAP32[$V_1+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_11+12>>2]|0;
       while(1) {
        __THREW__ = 0;
        $35 = (invoke_ii(3467,($V_1|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         label = 17;
         break;
        }
        if (!($35)) {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 114;
         break;
        }
        __THREW__ = 0;
        $32 = (invoke_ii(3468,($V_1|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         label = 17;
         break;
        }
        $29 = HEAP32[$0>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($29|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 17;
         break;
        }
        __THREW__ = 0;
        (invoke_iii(235,($29|0),($32|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         label = 17;
         break;
        }
       }
       if ((label|0) == 17) {
        $40 = ___cxa_find_matching_catch(348288|0)|0;
        $41 = tempRet0;
        $42 = (_llvm_eh_typeid_for((348288|0))|0);
        $43 = ($41|0)==($42|0);
        if (!($43)) {
         $$0 = $40;$$02 = $41;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $44 = (___cxa_begin_catch(($40|0))|0);
        $45 = HEAP32[$44>>2]|0;
        __THREW__ = 0;
        invoke_v(66);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
        $__last_unhandled_exception$0 = $45;$leaveInstructions$sroa$0$0 = 0;
       }
       ;HEAP32[$L_16+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_16+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_16+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$L_16+12>>2]=HEAP32[$V_1+12>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(1314144|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        __THREW__ = 0;
        $50 = (invoke_iii(2724,(1314144|0),($L_16|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if (!($52)) {
         __THREW__ = 0;
         invoke_vi(3799,($50|0));
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if (!($54)) {
          __THREW__ = 0;
          invoke_vii(3491,(2176768|0),($50|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if (!($56)) {
           $cond1 = ($leaveInstructions$sroa$0$0|0)==(114);
           if ($cond1) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           invoke_vi(3801,($__last_unhandled_exception$0|0));
           $57 = __THREW__; __THREW__ = 0;
           $58 = $57&1;
           if (!($58)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $$0 = $7;$$02 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z45AssemblyU002DCSharp_LevelBuilder_m_CreateNodeP32AssemblyU002DCSharp_LevelBuilderP30AssemblyU002DCSharp_JSONObject($__this,$node) {
 $__this = $__this|0;
 $node = $node|0;
 var $$0 = 0, $$byval_copy4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0;
 var $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = Math_fround(0), $224 = 0, $225 = 0, $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_6 = 0, $L_62 = 0, $L_65 = 0, $L_7 = 0;
 var $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy4 = sp + 96|0;
 $_stackTraceSentry = sp + 92|0;
 $V_0 = sp + 80|0;
 $V_1 = sp + 68|0;
 $L_6 = sp + 56|0;
 $L_7 = sp + 44|0;
 $0 = sp + 40|0;
 $1 = sp + 32|0;
 $2 = sp + 28|0;
 $3 = sp + 24|0;
 $L_62 = sp + 12|0;
 $L_65 = sp;
 $4 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1272792);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(283);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   __THREW__ = 0;
   invoke_vi(3799,($node|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = (($node) + 12|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(3);
    if (!($11)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1272512|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(1272512|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      invoke_vi(1402,($16|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $23 = (($16) + 16|0);
        HEAP32[$23>>2] = $__this;
        __THREW__ = 0;
        $24 = (invoke_iii(1190,(0|0),3)|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         __THREW__ = 0;
         invoke_vi(3799,($24|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          __THREW__ = 0;
          $29 = (invoke_ii(2524,($24|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           __THREW__ = 0;
           invoke_vi(3799,($16|0));
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $34 = (($16) + 8|0);
            HEAP32[$34>>2] = $29;
            __THREW__ = 0;
            invoke_vii(2070,($L_6|0),(0|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if (!($36)) {
             ;HEAP32[$V_0+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_6+8>>2]|0;
             __THREW__ = 0;
             invoke_vii(2070,($L_7|0),(0|0));
             $37 = __THREW__; __THREW__ = 0;
             $38 = $37&1;
             if (!($38)) {
              ;HEAP32[$V_1+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_7+8>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($16|0));
              $39 = __THREW__; __THREW__ = 0;
              $40 = $39&1;
              if (!($40)) {
               $41 = (($16) + 12|0);
               HEAP8[$41>>0] = 0;
               __THREW__ = 0;
               (invoke_ii(2996,(1168432|0))|0);
               $42 = __THREW__; __THREW__ = 0;
               $43 = $42&1;
               if (!($43)) {
                __THREW__ = 0;
                $44 = (invoke_iii(2723,(1168432|0),4)|0);
                $45 = __THREW__; __THREW__ = 0;
                $46 = $45&1;
                if (!($46)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($44|0));
                 $47 = __THREW__; __THREW__ = 0;
                 $48 = $47&1;
                 if (!($48)) {
                  $49 = (($44) + 12|0);
                  $50 = HEAP32[$49>>2]|0;
                  $51 = ($50|0)==(0);
                  if ($51) {
                   __THREW__ = 0;
                   $52 = (invoke_i(132)|0);
                   $53 = __THREW__; __THREW__ = 0;
                   $54 = $53&1;
                   if ($54) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($52|0));
                   $55 = __THREW__; __THREW__ = 0;
                   $56 = $55&1;
                   if ($56) {
                    break;
                   }
                  }
                  $57 = HEAP32[2990360>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($44|0),($57|0));
                  $58 = __THREW__; __THREW__ = 0;
                  $59 = $58&1;
                  if (!($59)) {
                   $60 = HEAP32[2990360>>2]|0;
                   $61 = (($44) + 16|0);
                   HEAP32[$61>>2] = $60;
                   __THREW__ = 0;
                   invoke_vi(3799,($44|0));
                   $62 = __THREW__; __THREW__ = 0;
                   $63 = $62&1;
                   if ($63) {
                    break;
                   }
                   $64 = HEAP32[$49>>2]|0;
                   $65 = ($64>>>0)<(2);
                   if ($65) {
                    __THREW__ = 0;
                    $66 = (invoke_i(132)|0);
                    $67 = __THREW__; __THREW__ = 0;
                    $68 = $67&1;
                    if ($68) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($66|0));
                    $69 = __THREW__; __THREW__ = 0;
                    $70 = $69&1;
                    if ($70) {
                     break;
                    }
                   }
                   $71 = HEAP32[2990368>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3492,($44|0),($71|0));
                   $72 = __THREW__; __THREW__ = 0;
                   $73 = $72&1;
                   if ($73) {
                    break;
                   }
                   $74 = HEAP32[2990368>>2]|0;
                   $75 = HEAP32[$44>>2]|0;
                   $76 = (($75) + 92|0);
                   $77 = HEAP32[$76>>2]|0;
                   $78 = (($61) + ($77)|0);
                   HEAP32[$78>>2] = $74;
                   __THREW__ = 0;
                   invoke_vi(3799,($44|0));
                   $79 = __THREW__; __THREW__ = 0;
                   $80 = $79&1;
                   if ($80) {
                    break;
                   }
                   $81 = HEAP32[$49>>2]|0;
                   $82 = ($81>>>0)<(3);
                   if ($82) {
                    __THREW__ = 0;
                    $83 = (invoke_i(132)|0);
                    $84 = __THREW__; __THREW__ = 0;
                    $85 = $84&1;
                    if ($85) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($83|0));
                    $86 = __THREW__; __THREW__ = 0;
                    $87 = $86&1;
                    if ($87) {
                     break;
                    }
                   }
                   $88 = HEAP32[2990376>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3492,($44|0),($88|0));
                   $89 = __THREW__; __THREW__ = 0;
                   $90 = $89&1;
                   if ($90) {
                    break;
                   }
                   $91 = HEAP32[2990376>>2]|0;
                   $92 = HEAP32[$44>>2]|0;
                   $93 = (($92) + 92|0);
                   $94 = HEAP32[$93>>2]|0;
                   $95 = $94 << 1;
                   $96 = (($61) + ($95)|0);
                   HEAP32[$96>>2] = $91;
                   __THREW__ = 0;
                   invoke_vi(3799,($44|0));
                   $97 = __THREW__; __THREW__ = 0;
                   $98 = $97&1;
                   if ($98) {
                    break;
                   }
                   $99 = HEAP32[$49>>2]|0;
                   $100 = ($99>>>0)<(4);
                   if ($100) {
                    __THREW__ = 0;
                    $101 = (invoke_i(132)|0);
                    $102 = __THREW__; __THREW__ = 0;
                    $103 = $102&1;
                    if ($103) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($101|0));
                    $104 = __THREW__; __THREW__ = 0;
                    $105 = $104&1;
                    if ($105) {
                     break;
                    }
                   }
                   $106 = HEAP32[2990384>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3492,($44|0),($106|0));
                   $107 = __THREW__; __THREW__ = 0;
                   $108 = $107&1;
                   if ($108) {
                    break;
                   }
                   $109 = HEAP32[2990384>>2]|0;
                   $110 = HEAP32[$44>>2]|0;
                   $111 = (($110) + 92|0);
                   $112 = HEAP32[$111>>2]|0;
                   $113 = ($112*3)|0;
                   $114 = (($61) + ($113)|0);
                   HEAP32[$114>>2] = $109;
                   __THREW__ = 0;
                   invoke_vi(3799,($node|0));
                   $115 = __THREW__; __THREW__ = 0;
                   $116 = $115&1;
                   if ($116) {
                    break;
                   }
                   __THREW__ = 0;
                   $117 = (invoke_iii(238,($node|0),($44|0))|0);
                   $118 = __THREW__; __THREW__ = 0;
                   $119 = $118&1;
                   if ($119) {
                    break;
                   }
                   if ($117) {
                    __THREW__ = 0;
                    invoke_vi(3799,($node|0));
                    $120 = __THREW__; __THREW__ = 0;
                    $121 = $120&1;
                    if ($121) {
                     break;
                    }
                    $122 = HEAP32[2990392>>2]|0;
                    __THREW__ = 0;
                    (invoke_iiiii(68,($node|0),($V_0|0),($122|0),(0|0))|0);
                    $123 = __THREW__; __THREW__ = 0;
                    $124 = $123&1;
                    if ($124) {
                     break;
                    }
                    $125 = (($V_0) + 8|0);
                    __THREW__ = 0;
                    invoke_vi(3799,($node|0));
                    $126 = __THREW__; __THREW__ = 0;
                    $127 = $126&1;
                    if ($127) {
                     break;
                    }
                    $128 = HEAP32[2990400>>2]|0;
                    __THREW__ = 0;
                    (invoke_iiiii(68,($node|0),($125|0),($128|0),(0|0))|0);
                    $129 = __THREW__; __THREW__ = 0;
                    $130 = $129&1;
                    if ($130) {
                     break;
                    }
                    $131 = (($V_0) + 4|0);
                    HEAPF32[$131>>2] = Math_fround(20.0);
                    __THREW__ = 0;
                    invoke_vi(3799,($node|0));
                    $132 = __THREW__; __THREW__ = 0;
                    $133 = $132&1;
                    if ($133) {
                     break;
                    }
                    $134 = HEAP32[2990408>>2]|0;
                    __THREW__ = 0;
                    (invoke_iiiii(68,($node|0),($V_1|0),($134|0),(0|0))|0);
                    $135 = __THREW__; __THREW__ = 0;
                    $136 = $135&1;
                    if ($136) {
                     break;
                    }
                    $137 = (($V_1) + 8|0);
                    __THREW__ = 0;
                    invoke_vi(3799,($node|0));
                    $138 = __THREW__; __THREW__ = 0;
                    $139 = $138&1;
                    if ($139) {
                     break;
                    }
                    $140 = HEAP32[2990416>>2]|0;
                    __THREW__ = 0;
                    (invoke_iiiii(68,($node|0),($137|0),($140|0),(0|0))|0);
                    $141 = __THREW__; __THREW__ = 0;
                    $142 = $141&1;
                    if ($142) {
                     break;
                    }
                    $143 = Math_fround(HEAPF32[$V_1>>2]);
                    $144 = Math_fround(HEAPF32[$V_0>>2]);
                    $145 = Math_fround($144 * Math_fround(0.5));
                    $146 = Math_fround($143 + $145);
                    HEAPF32[$V_1>>2] = $146;
                    $147 = Math_fround(HEAPF32[$137>>2]);
                    $148 = Math_fround(HEAPF32[$125>>2]);
                    $149 = Math_fround($148 * Math_fround(0.5));
                    $150 = Math_fround($147 + $149);
                    HEAPF32[$137>>2] = $150;
                    $151 = (($__this) + 28|0);
                    $152 = HEAP32[$151>>2]|0;
                    $153 = ($152*10)|0;
                    $154 = (Math_fround(($153|0)));
                    $155 = (($V_1) + 4|0);
                    HEAPF32[$155>>2] = $154;
                   } else {
                    __THREW__ = 0;
                    invoke_vi(3799,($16|0));
                    $156 = __THREW__; __THREW__ = 0;
                    $157 = $156&1;
                    if ($157) {
                     break;
                    }
                    HEAP8[$41>>0] = 1;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(1275504|0))|0);
                   $158 = __THREW__; __THREW__ = 0;
                   $159 = $158&1;
                   if ($159) {
                    break;
                   }
                   __THREW__ = 0;
                   $160 = (invoke_ii(3469,(1275504|0))|0);
                   $161 = __THREW__; __THREW__ = 0;
                   $162 = $161&1;
                   if ($162) {
                    break;
                   }
                   HEAP32[$0>>2] = 1271928;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
                   invoke_viii(257,($160|0),($16|0),($$byval_copy4|0));
                   $163 = __THREW__; __THREW__ = 0;
                   $164 = $163&1;
                   if ($164) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($node|0));
                   $165 = __THREW__; __THREW__ = 0;
                   $166 = $165&1;
                   if ($166) {
                    break;
                   }
                   $167 = HEAP32[2990424>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii(86,($node|0),($167|0),($160|0),(0|0));
                   $168 = __THREW__; __THREW__ = 0;
                   $169 = $168&1;
                   if ($169) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(1275504|0))|0);
                   $170 = __THREW__; __THREW__ = 0;
                   $171 = $170&1;
                   if ($171) {
                    break;
                   }
                   __THREW__ = 0;
                   $172 = (invoke_ii(3469,(1275504|0))|0);
                   $173 = __THREW__; __THREW__ = 0;
                   $174 = $173&1;
                   if ($174) {
                    break;
                   }
                   HEAP32[$1>>2] = 1271976;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;
                   invoke_viii(257,($172|0),($16|0),($$byval_copy4|0));
                   $175 = __THREW__; __THREW__ = 0;
                   $176 = $175&1;
                   if ($176) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(1274944|0))|0);
                   $177 = __THREW__; __THREW__ = 0;
                   $178 = $177&1;
                   if ($178) {
                    break;
                   }
                   __THREW__ = 0;
                   $179 = (invoke_ii(3469,(1274944|0))|0);
                   $180 = __THREW__; __THREW__ = 0;
                   $181 = $180&1;
                   if ($181) {
                    break;
                   }
                   HEAP32[$2>>2] = 1272024;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
                   invoke_viii(256,($179|0),($16|0),($$byval_copy4|0));
                   $182 = __THREW__; __THREW__ = 0;
                   $183 = $182&1;
                   if ($183) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($node|0));
                   $184 = __THREW__; __THREW__ = 0;
                   $185 = $184&1;
                   if ($185) {
                    break;
                   }
                   $186 = HEAP32[2990432>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii(86,($node|0),($186|0),($172|0),($179|0));
                   $187 = __THREW__; __THREW__ = 0;
                   $188 = $187&1;
                   if ($188) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(1275504|0))|0);
                   $189 = __THREW__; __THREW__ = 0;
                   $190 = $189&1;
                   if ($190) {
                    break;
                   }
                   __THREW__ = 0;
                   $191 = (invoke_ii(3469,(1275504|0))|0);
                   $192 = __THREW__; __THREW__ = 0;
                   $193 = $192&1;
                   if ($193) {
                    break;
                   }
                   HEAP32[$3>>2] = 1272072;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$3+0>>2]|0;
                   invoke_viii(257,($191|0),($16|0),($$byval_copy4|0));
                   $194 = __THREW__; __THREW__ = 0;
                   $195 = $194&1;
                   if ($195) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($node|0));
                   $196 = __THREW__; __THREW__ = 0;
                   $197 = $196&1;
                   if ($197) {
                    break;
                   }
                   $198 = HEAP32[2990440>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii(86,($node|0),($198|0),($191|0),(0|0));
                   $199 = __THREW__; __THREW__ = 0;
                   $200 = $199&1;
                   if ($200) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($16|0));
                   $201 = __THREW__; __THREW__ = 0;
                   $202 = $201&1;
                   if ($202) {
                    break;
                   }
                   $203 = HEAP32[$34>>2]|0;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$V_0+8>>2]|0;
                   invoke_viiif(2,($L_62|0),(0|0),($$byval_copy4|0),0.0299999993294477462769);
                   $204 = __THREW__; __THREW__ = 0;
                   $205 = $204&1;
                   if ($205) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($203|0));
                   $206 = __THREW__; __THREW__ = 0;
                   $207 = $206&1;
                   if ($207) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$L_62+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$L_62+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$L_62+8>>2]|0;
                   invoke_vii(2140,($203|0),($$byval_copy4|0));
                   $208 = __THREW__; __THREW__ = 0;
                   $209 = $208&1;
                   if ($209) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($16|0));
                   $210 = __THREW__; __THREW__ = 0;
                   $211 = $210&1;
                   if ($211) {
                    break;
                   }
                   $212 = HEAP32[$34>>2]|0;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$V_1+8>>2]|0;
                   invoke_viiif(2,($L_65|0),(0|0),($$byval_copy4|0),0.0299999993294477462769);
                   $213 = __THREW__; __THREW__ = 0;
                   $214 = $213&1;
                   if ($214) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($212|0));
                   $215 = __THREW__; __THREW__ = 0;
                   $216 = $215&1;
                   if ($216) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$L_65+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$L_65+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$L_65+8>>2]|0;
                   invoke_vii(2123,($212|0),($$byval_copy4|0));
                   $217 = __THREW__; __THREW__ = 0;
                   $218 = $217&1;
                   if ($218) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($16|0));
                   $219 = __THREW__; __THREW__ = 0;
                   $220 = $219&1;
                   if ($220) {
                    break;
                   }
                   $221 = HEAP8[$41>>0]|0;
                   $222 = ($221<<24>>24)==(0);
                   do {
                    if ($222) {
                     $223 = Math_fround(HEAPF32[$V_0>>2]);
                     $224 = $223 == Math_fround(0.0);
                     if ($224) {
                      label = 82;
                      break;
                     }
                     $225 = (($V_0) + 8|0);
                     $226 = Math_fround(HEAPF32[$225>>2]);
                     $227 = $226 != Math_fround(0.0);
                     if (!($227)) {
                      label = 82;
                      break;
                     }
                     $238 = (($__this) + 32|0);
                     HEAP8[$238>>0] = 1;
                    } else {
                     label = 82;
                    }
                   } while(0);
                   if ((label|0) == 82) {
                    __THREW__ = 0;
                    invoke_vi(3799,($16|0));
                    $228 = __THREW__; __THREW__ = 0;
                    $229 = $228&1;
                    if ($229) {
                     break;
                    }
                    $230 = HEAP32[$34>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($230|0));
                    $231 = __THREW__; __THREW__ = 0;
                    $232 = $231&1;
                    if ($232) {
                     break;
                    }
                    __THREW__ = 0;
                    $233 = (invoke_ii(2523,($230|0))|0);
                    $234 = __THREW__; __THREW__ = 0;
                    $235 = $234&1;
                    if ($235) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vii(2004,(0|0),($233|0));
                    $236 = __THREW__; __THREW__ = 0;
                    $237 = $236&1;
                    if ($237) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(1275504|0))|0);
                   $239 = __THREW__; __THREW__ = 0;
                   $240 = $239&1;
                   if ($240) {
                    break;
                   }
                   __THREW__ = 0;
                   $241 = (invoke_ii(3469,(1275504|0))|0);
                   $242 = __THREW__; __THREW__ = 0;
                   $243 = $242&1;
                   if ($243) {
                    break;
                   }
                   HEAP32[$4>>2] = 1272120;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
                   invoke_viii(257,($241|0),($16|0),($$byval_copy4|0));
                   $244 = __THREW__; __THREW__ = 0;
                   $245 = $244&1;
                   if ($245) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($node|0));
                   $246 = __THREW__; __THREW__ = 0;
                   $247 = $246&1;
                   if ($247) {
                    break;
                   }
                   $248 = HEAP32[2990448>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii(86,($node|0),($248|0),($241|0),(0|0));
                   $249 = __THREW__; __THREW__ = 0;
                   $250 = $249&1;
                   if ($250) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($16|0));
                   $251 = __THREW__; __THREW__ = 0;
                   $252 = $251&1;
                   if ($252) {
                    break;
                   }
                   $253 = HEAP32[$34>>2]|0;
                   $$0 = $253;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($$0|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZL95mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_MoveNextP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1314144)|0);
 $0 = HEAP32[((1314144 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN23InterfaceActionInvoker06InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($4);
 STACKTOP = sp;return;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker1I17VoidPointerTraitsE6InvokeEPFvPvS2_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$0);
 STACKTOP = sp;return (0|0);
}
function __Z98AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z40AssemblyU002DCSharp_LevelBuilder_m__ctorP32AssemblyU002DCSharp_LevelBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1272648);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3802,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = (($__this) + 20|0);
    HEAP32[$16>>2] = $15;
    __THREW__ = 0;
    invoke_vi(3120,($__this|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL11RuntimeInitP8TypeInfo($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z40AssemblyU002DCSharp_LevelBuilder_m_StartP32AssemblyU002DCSharp_LevelBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1272696);
 __THREW__ = 0;
 invoke_v(284);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1167664|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2723,(1167664|0),0)|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[2990304>>2]|0;
    __THREW__ = 0;
    invoke_viii(729,(0|0),($7|0),($4|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($__this) + 20|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = HEAP32[2990312>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiii(562,(0|0),($12|0),($11|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_iii(1204,(0|0),($13|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2810488|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        $21 = (invoke_iii(2725,($16|0),(2810488|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         __THREW__ = 0;
         invoke_vi(3799,($21|0));
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          $26 = (invoke_ii(2627,($21|0))|0);
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           __THREW__ = 0;
           invoke_vii(1183,($__this|0),($26|0));
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if (!($30)) {
            __THREW__ = 0;
            $31 = (invoke_iii(2726,($__this|0),(2868528|0))|0);
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if (!($33)) {
             __THREW__ = 0;
             $34 = (invoke_iii(1194,(0|0),($31|0))|0);
             $35 = __THREW__; __THREW__ = 0;
             $36 = $35&1;
             if (!($36)) {
              if (!($34)) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              __THREW__ = 0;
              invoke_vi(3799,($31|0));
              $39 = __THREW__; __THREW__ = 0;
              $40 = $39&1;
              if (!($40)) {
               __THREW__ = 0;
               invoke_vii(2178,($31|0),0);
               $41 = __THREW__; __THREW__ = 0;
               $42 = $41&1;
               if (!($42)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($37|0);
 // unreachable;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z45AssemblyU002DCSharp_LevelBuilder_m_RecieveDOMP32AssemblyU002DCSharp_LevelBuilderP22mscorlib_System_String($__this,$input) {
 $__this = $__this|0;
 $input = $input|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $L_11 = 0, $L_11$byval_copy = 0, $L_4 = 0, $L_7 = 0, $L_9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_11$byval_copy = sp + 52|0;
 $_stackTraceSentry = sp;
 $L_4 = sp + 4|0;
 $L_7 = sp + 16|0;
 $L_9 = sp + 28|0;
 $L_11 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1272744);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viii(258,($2|0),($input|0),0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(235,($__this|0),($2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_ii(2522,($__this|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vii(2122,($L_4|0),($7|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        $17 = Math_fround(HEAPF32[$L_4>>2]);
        __THREW__ = 0;
        $18 = (invoke_ii(2522,($__this|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         invoke_vi(3799,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          invoke_vii(2122,($L_7|0),($18|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           $25 = (($L_7) + 4|0);
           $26 = Math_fround(HEAPF32[$25>>2]);
           __THREW__ = 0;
           invoke_vi(3799,($7|0));
           $27 = __THREW__; __THREW__ = 0;
           $28 = $27&1;
           if (!($28)) {
            __THREW__ = 0;
            invoke_vii(2122,($L_9|0),($7|0));
            $29 = __THREW__; __THREW__ = 0;
            $30 = $29&1;
            if (!($30)) {
             $31 = (($L_9) + 8|0);
             $32 = Math_fround(HEAPF32[$31>>2]);
             ;HEAP32[$L_11+0>>2]=0|0;HEAP32[$L_11+4>>2]=0|0;HEAP32[$L_11+8>>2]=0|0;
             __THREW__ = 0;
             invoke_vifff(4,($L_11|0),(+$17),(+$26),(+$32));
             $33 = __THREW__; __THREW__ = 0;
             $34 = $33&1;
             if (!($34)) {
              __THREW__ = 0;
              invoke_vi(3799,($10|0));
              $35 = __THREW__; __THREW__ = 0;
              $36 = $35&1;
              if (!($36)) {
               __THREW__ = 0;
               ;HEAP32[$L_11$byval_copy+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$L_11$byval_copy+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$L_11$byval_copy+8>>2]=HEAP32[$L_11+8>>2]|0;
               invoke_vii(2123,($10|0),($L_11$byval_copy|0));
               $37 = __THREW__; __THREW__ = 0;
               $38 = $37&1;
               if (!($38)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $39 = ___cxa_find_matching_catch()|0;
 $40 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($39|0);
 // unreachable;
}
function __Z106AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringb($__this,$str,$strict) {
 $__this = $__this|0;
 $str = $str|0;
 $strict = $strict|0;
 var $$0 = 0, $$01 = 0, $$V_0$1 = 0, $$V_0$3 = 0, $$V_4$1$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$2 = 0, $V_0$3$ph = 0, $V_0$3$ph$ph = 0, $V_1$0 = 0, $V_1$0$ph = 0, $V_1$0$ph$ph = 0, $V_1$0$ph46 = 0, $V_2$135 = 0, $V_2$2$ph$ph = 0, $V_3$1$off0$ph = 0, $V_3$1$off0$ph44 = 0, $V_4$0$off0 = 0, $V_4$1$off0$not = 0, $V_4$1$off0$ph$ph = 0, $V_5$0 = 0;
 var $V_5$1$ph = 0, $V_5$1$ph$ph = 0, $V_5$1$ph88 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond10 = 0, $or$cond8 = 0, $or$cond9$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276024);
 __THREW__ = 0;
 invoke_v(285);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if ($1) {
   label = 7;
  } else {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if ($3) {
    label = 7;
   } else {
    $4 = ($str|0)==(0|0);
    if ($4) {
     $337 = (($__this) + 12|0);
     HEAP32[$337>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1281560|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 7;
    } else {
     $15 = HEAP8[((1281560 + 116|0))>>0]|0;
     $16 = ($15<<24>>24)==(0);
     if ($16) {
      __THREW__ = 0;
      (invoke_ii(2996,(1281560|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       label = 7;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1281560|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 7;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3802,(1281560|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 7;
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1281560|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 7;
     } else {
      $25 = HEAP32[((1281560 + 80|0))>>2]|0;
      $26 = (($25) + 16|0);
      $27 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($str|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 7;
      } else {
       __THREW__ = 0;
       $30 = (invoke_iii(624,($str|0),($27|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        label = 7;
       } else {
        if ($strict) {
         __THREW__ = 0;
         invoke_vi(3799,($30|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $35 = (invoke_iii(621,($30|0),0)|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          label = 7;
          break;
         }
         $38 = ($35<<16>>16)==(91);
         if (!($38)) {
          __THREW__ = 0;
          invoke_vi(3799,($30|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          $41 = (invoke_iii(621,($30|0),0)|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           label = 7;
           break;
          }
          $44 = ($41<<16>>16)==(123);
          if (!($44)) {
           $45 = (($__this) + 12|0);
           HEAP32[$45>>2] = 0;
           $46 = HEAP32[2990880>>2]|0;
           __THREW__ = 0;
           invoke_vii(2111,(0|0),($46|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if ($48) {
            label = 7;
            break;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($30|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 7;
        } else {
         __THREW__ = 0;
         $51 = (invoke_ii(1816,($30|0))|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          label = 7;
         } else {
          $54 = ($51|0)<(1);
          if ($54) {
           $336 = (($__this) + 12|0);
           HEAP32[$336>>2] = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          $55 = HEAP32[2990888>>2]|0;
          __THREW__ = 0;
          $56 = (invoke_iiiii(91,(0|0),($30|0),($55|0),1)|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if ($58) {
           label = 7;
          } else {
           $59 = ($56|0)==(0);
           if ($59) {
            $60 = (($__this) + 12|0);
            HEAP32[$60>>2] = 5;
            $61 = (($__this) + 32|0);
            HEAP8[$61>>0] = 1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $62 = HEAP32[2990896>>2]|0;
           __THREW__ = 0;
           $63 = (invoke_iiiii(91,(0|0),($30|0),($62|0),1)|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 7;
           } else {
            $66 = ($63|0)==(0);
            if ($66) {
             $67 = (($__this) + 12|0);
             HEAP32[$67>>2] = 5;
             $68 = (($__this) + 32|0);
             HEAP8[$68>>0] = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
            $69 = HEAP32[2990904>>2]|0;
            __THREW__ = 0;
            $70 = (invoke_iiiii(91,(0|0),($30|0),($69|0),1)|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 7;
            } else {
             $73 = ($70|0)==(0);
             if ($73) {
              $74 = (($__this) + 12|0);
              HEAP32[$74>>2] = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
             $75 = HEAP32[2990912>>2]|0;
             __THREW__ = 0;
             $76 = (invoke_iiii(574,(0|0),($30|0),($75|0))|0);
             $77 = __THREW__; __THREW__ = 0;
             $78 = $77&1;
             if ($78) {
              label = 7;
             } else {
              if ($76) {
               $79 = (($__this) + 12|0);
               HEAP32[$79>>2] = 2;
               $80 = (($__this) + 28|0);
               HEAPF32[$80>>2] = Math_fround(inf);
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              $81 = HEAP32[2990920>>2]|0;
              __THREW__ = 0;
              $82 = (invoke_iiii(574,(0|0),($30|0),($81|0))|0);
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if ($84) {
               label = 7;
               break;
              }
              if ($82) {
               $85 = (($__this) + 12|0);
               HEAP32[$85>>2] = 2;
               $86 = (($__this) + 28|0);
               HEAPF32[$86>>2] = Math_fround(-inf);
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              $87 = HEAP32[2990928>>2]|0;
              __THREW__ = 0;
              $88 = (invoke_iiii(574,(0|0),($30|0),($87|0))|0);
              $89 = __THREW__; __THREW__ = 0;
              $90 = $89&1;
              if ($90) {
               label = 7;
               break;
              }
              if ($88) {
               $91 = (($__this) + 12|0);
               HEAP32[$91>>2] = 2;
               $92 = (($__this) + 28|0);
               HEAPF32[$92>>2] = Math_fround(nan);
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              __THREW__ = 0;
              invoke_vi(3799,($30|0));
              $93 = __THREW__; __THREW__ = 0;
              $94 = $93&1;
              if ($94) {
               label = 7;
               break;
              }
              __THREW__ = 0;
              $95 = (invoke_iii(621,($30|0),0)|0);
              $96 = __THREW__; __THREW__ = 0;
              $97 = $96&1;
              if ($97) {
               label = 7;
               break;
              }
              $98 = ($95<<16>>16)==(34);
              if ($98) {
               $99 = (($__this) + 12|0);
               HEAP32[$99>>2] = 1;
               __THREW__ = 0;
               invoke_vi(3799,($30|0));
               $100 = __THREW__; __THREW__ = 0;
               $101 = $100&1;
               if ($101) {
                label = 7;
                break;
               }
               __THREW__ = 0;
               $102 = (invoke_ii(1816,($30|0))|0);
               $103 = __THREW__; __THREW__ = 0;
               $104 = $103&1;
               if ($104) {
                label = 7;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($30|0));
               $105 = __THREW__; __THREW__ = 0;
               $106 = $105&1;
               if ($106) {
                label = 7;
                break;
               }
               $107 = (($102) + -2)|0;
               __THREW__ = 0;
               $108 = (invoke_iiii(528,($30|0),1,($107|0))|0);
               $109 = __THREW__; __THREW__ = 0;
               $110 = $109&1;
               if ($110) {
                label = 7;
                break;
               }
               $111 = (($__this) + 24|0);
               HEAP32[$111>>2] = $108;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              __THREW__ = 0;
              $112 = (Math_fround(+(invoke_fii(30,(0|0),($30|0)))));
              $113 = __THREW__; __THREW__ = 0;
              $114 = $113&1;
              if (!($114)) {
               $115 = (($__this) + 28|0);
               HEAPF32[$115>>2] = $112;
               $116 = (($__this) + 12|0);
               HEAP32[$116>>2] = 2;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              $117 = ___cxa_find_matching_catch(348288|0)|0;
              $118 = tempRet0;
              $119 = (_llvm_eh_typeid_for((348288|0))|0);
              $120 = ($118|0)==($119|0);
              if (!($120)) {
               $$0 = $117;$$01 = $118;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($$0|0);
               // unreachable;
              }
              $121 = (___cxa_begin_catch(($117|0))|0);
              $122 = HEAP32[$121>>2]|0;
              $123 = HEAP32[$122>>2]|0;
              __THREW__ = 0;
              $124 = (invoke_iii(2727,(2603176|0),($123|0))|0);
              $125 = __THREW__; __THREW__ = 0;
              $126 = $125&1;
              do {
               if (!($126)) {
                if (!($124)) {
                 $133 = (___cxa_allocate_exception(4)|0);
                 $134 = HEAP32[$121>>2]|0;
                 HEAP32[$133>>2] = $134;
                 __THREW__ = 0;
                 invoke_viii(1567,($133|0),(348288|0),(0|0));
                 $135 = __THREW__; __THREW__ = 0;
                 $136 = $135&1;
                 if ($136) {
                  break;
                 }
                 // unreachable;
                }
                __THREW__ = 0;
                invoke_v(66);
                $127 = __THREW__; __THREW__ = 0;
                $128 = $127&1;
                if ($128) {
                 label = 7;
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3799,($30|0));
                $137 = __THREW__; __THREW__ = 0;
                $138 = $137&1;
                if ($138) {
                 label = 7;
                 break L1;
                }
                __THREW__ = 0;
                $139 = (invoke_iii(621,($30|0),0)|0);
                $140 = __THREW__; __THREW__ = 0;
                $141 = $140&1;
                if ($141) {
                 label = 7;
                 break L1;
                }
                if ((($139<<16>>16) == 91)) {
                 $159 = (($__this) + 12|0);
                 HEAP32[$159>>2] = 4;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1326240|0))|0);
                 $160 = __THREW__; __THREW__ = 0;
                 $161 = $160&1;
                 if ($161) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 $162 = (invoke_ii(3469,(1326240|0))|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3803,($162|0));
                 $165 = __THREW__; __THREW__ = 0;
                 $166 = $165&1;
                 if ($166) {
                  label = 7;
                  break L1;
                 }
                 $167 = (($__this) + 16|0);
                 HEAP32[$167>>2] = $162;
                } else if ((($139<<16>>16) == 123)) {
                 $142 = (($__this) + 12|0);
                 HEAP32[$142>>2] = 3;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1333136|0))|0);
                 $143 = __THREW__; __THREW__ = 0;
                 $144 = $143&1;
                 if ($144) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 $145 = (invoke_ii(3469,(1333136|0))|0);
                 $146 = __THREW__; __THREW__ = 0;
                 $147 = $146&1;
                 if ($147) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3803,($145|0));
                 $148 = __THREW__; __THREW__ = 0;
                 $149 = $148&1;
                 if ($149) {
                  label = 7;
                  break L1;
                 }
                 $150 = (($__this) + 20|0);
                 HEAP32[$150>>2] = $145;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1326240|0))|0);
                 $151 = __THREW__; __THREW__ = 0;
                 $152 = $151&1;
                 if ($152) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 $153 = (invoke_ii(3469,(1326240|0))|0);
                 $154 = __THREW__; __THREW__ = 0;
                 $155 = $154&1;
                 if ($155) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3803,($153|0));
                 $156 = __THREW__; __THREW__ = 0;
                 $157 = $156&1;
                 if ($157) {
                  label = 7;
                  break L1;
                 }
                 $158 = (($__this) + 16|0);
                 HEAP32[$158>>2] = $153;
                } else {
                 $168 = (($__this) + 12|0);
                 HEAP32[$168>>2] = 0;
                 $169 = HEAP32[2990936>>2]|0;
                 __THREW__ = 0;
                 $170 = (invoke_iiii(562,(0|0),($169|0),($30|0))|0);
                 $171 = __THREW__; __THREW__ = 0;
                 $172 = $171&1;
                 if ($172) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(2111,(0|0),($170|0));
                 $173 = __THREW__; __THREW__ = 0;
                 $174 = $173&1;
                 if ($174) {
                  label = 7;
                  break L1;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $175 = __THREW__; __THREW__ = 0;
                $176 = $175&1;
                if ($176) {
                 label = 7;
                 break L1;
                }
                $177 = HEAP8[((2191608 + 116|0))>>0]|0;
                $178 = ($177<<24>>24)==(0);
                if ($178) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $179 = __THREW__; __THREW__ = 0;
                 $180 = $179&1;
                 if ($180) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $181 = __THREW__; __THREW__ = 0;
                 $182 = $181&1;
                 if ($182) {
                  label = 7;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3802,(2191608|0));
                 $183 = __THREW__; __THREW__ = 0;
                 $184 = $183&1;
                 if ($184) {
                  label = 7;
                  break L1;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $185 = __THREW__; __THREW__ = 0;
                $186 = $185&1;
                if ($186) {
                 label = 7;
                 break L1;
                }
                $187 = HEAP32[((2191608 + 80|0))>>2]|0;
                $188 = HEAP32[$187>>2]|0;
                $189 = (($__this) + 12|0);
                $190 = (($__this) + 20|0);
                $191 = (($__this) + 16|0);
                $V_0$3$ph$ph = 1;$V_1$0$ph$ph = 0;$V_2$2$ph$ph = $188;$V_4$1$off0$ph$ph = 0;$V_5$1$ph$ph = 0;
                L112: while(1) {
                 $V_0$3$ph = $V_0$3$ph$ph;$V_1$0$ph = $V_1$0$ph$ph;$V_3$1$off0$ph = 0;$V_5$1$ph = $V_5$1$ph$ph;
                 L114: while(1) {
                  $221 = ($V_5$1$ph|0)==(0);
                  $V_1$0$ph46 = $V_1$0$ph;$V_3$1$off0$ph44 = $V_3$1$off0$ph;
                  while(1) {
                   $V_1$0 = $V_1$0$ph46;
                   while(1) {
                    $207 = (($V_1$0) + 1)|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($30|0));
                    $328 = __THREW__; __THREW__ = 0;
                    $329 = $328&1;
                    if ($329) {
                     label = 4;
                     break L112;
                    }
                    __THREW__ = 0;
                    $330 = (invoke_ii(1816,($30|0))|0);
                    $331 = __THREW__; __THREW__ = 0;
                    $332 = $331&1;
                    if ($332) {
                     label = 4;
                     break L112;
                    }
                    $333 = ($207|0)<($330|0);
                    if (!($333)) {
                     label = 157;
                     break L112;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(1281560|0))|0);
                    $334 = __THREW__; __THREW__ = 0;
                    $335 = $334&1;
                    if ($335) {
                     label = 4;
                     break L112;
                    }
                    $192 = HEAP8[((1281560 + 116|0))>>0]|0;
                    $193 = ($192<<24>>24)==(0);
                    if ($193) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(1281560|0))|0);
                     $194 = __THREW__; __THREW__ = 0;
                     $195 = $194&1;
                     if ($195) {
                      label = 4;
                      break L112;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(1281560|0))|0);
                     $196 = __THREW__; __THREW__ = 0;
                     $197 = $196&1;
                     if ($197) {
                      label = 4;
                      break L112;
                     }
                     __THREW__ = 0;
                     invoke_vi(3802,(1281560|0));
                     $198 = __THREW__; __THREW__ = 0;
                     $199 = $198&1;
                     if ($199) {
                      label = 4;
                      break L112;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(1281560|0))|0);
                    $200 = __THREW__; __THREW__ = 0;
                    $201 = $200&1;
                    if ($201) {
                     label = 4;
                     break L112;
                    }
                    $202 = HEAP32[((1281560 + 80|0))>>2]|0;
                    $203 = (($202) + 16|0);
                    $204 = HEAP32[$203>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($30|0));
                    $205 = __THREW__; __THREW__ = 0;
                    $206 = $205&1;
                    if ($206) {
                     label = 4;
                     break L112;
                    }
                    __THREW__ = 0;
                    $208 = (invoke_iii(621,($30|0),($207|0))|0);
                    $209 = __THREW__; __THREW__ = 0;
                    $210 = $209&1;
                    if ($210) {
                     label = 4;
                     break L112;
                    }
                    __THREW__ = 0;
                    $211 = (invoke_iiii(1444,(0|0),($204|0),($208|0))|0);
                    $212 = __THREW__; __THREW__ = 0;
                    $213 = $212&1;
                    if ($213) {
                     label = 4;
                     break L112;
                    }
                    $214 = ($211|0)<(0);
                    if ($214) {
                     break;
                    } else {
                     $V_1$0 = $207;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($30|0));
                   $215 = __THREW__; __THREW__ = 0;
                   $216 = $215&1;
                   if ($216) {
                    label = 5;
                    break L112;
                   }
                   __THREW__ = 0;
                   $217 = (invoke_iii(621,($30|0),($207|0))|0);
                   $218 = __THREW__; __THREW__ = 0;
                   $219 = $218&1;
                   if ($219) {
                    label = 5;
                    break L112;
                   }
                   $220 = ($217<<16>>16)==(34);
                   if (!($220)) {
                    if ($V_3$1$off0$ph44) {
                     $V_1$0$ph46 = $207;$V_3$1$off0$ph44 = 1;
                     continue;
                    } else {
                     $V_2$135 = $V_2$2$ph$ph;$V_5$1$ph88 = $V_5$1$ph;
                     break L114;
                    }
                   }
                   if ($V_3$1$off0$ph44) {
                    label = 98;
                    break L114;
                   }
                   if ($221) {
                    break;
                   } else {
                    $V_1$0$ph46 = $207;$V_3$1$off0$ph44 = 1;
                   }
                  }
                  $232 = HEAP32[$189>>2]|0;
                  $233 = ($232|0)==(3);
                  $$V_0$3 = $233 ? $207 : $V_0$3$ph;
                  $V_0$3$ph = $$V_0$3;$V_1$0$ph = $207;$V_3$1$off0$ph = 1;$V_5$1$ph = 0;
                 }
                 do {
                  if ((label|0) == 98) {
                   label = 0;
                   $V_4$1$off0$not = $V_4$1$off0$ph$ph ^ 1;
                   $or$cond = $221 & $V_4$1$off0$not;
                   if (!($or$cond)) {
                    $V_2$135 = $V_2$2$ph$ph;$V_5$1$ph88 = $V_5$1$ph;
                    break;
                   }
                   $222 = HEAP32[$189>>2]|0;
                   $223 = ($222|0)==(3);
                   if (!($223)) {
                    $V_2$135 = $V_2$2$ph$ph;$V_5$1$ph88 = 0;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($30|0));
                   $224 = __THREW__; __THREW__ = 0;
                   $225 = $224&1;
                   if ($225) {
                    label = 6;
                    break L112;
                   }
                   $226 = $V_0$3$ph ^ -1;
                   $227 = (($207) + ($226))|0;
                   $228 = (($V_0$3$ph) + 1)|0;
                   __THREW__ = 0;
                   $229 = (invoke_iiii(528,($30|0),($228|0),($227|0))|0);
                   $230 = __THREW__; __THREW__ = 0;
                   $231 = $230&1;
                   if ($231) {
                    label = 6;
                    break L112;
                   } else {
                    $V_2$135 = $229;$V_5$1$ph88 = 0;
                   }
                  }
                 } while(0);
                 $234 = HEAP32[$189>>2]|0;
                 $235 = ($234|0)==(3);
                 $236 = ($V_5$1$ph88|0)==(0);
                 $or$cond8 = $235 & $236;
                 if ($or$cond8) {
                  __THREW__ = 0;
                  invoke_vi(3799,($30|0));
                  $237 = __THREW__; __THREW__ = 0;
                  $238 = $237&1;
                  if ($238) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  $239 = (invoke_iii(621,($30|0),($207|0))|0);
                  $240 = __THREW__; __THREW__ = 0;
                  $241 = $240&1;
                  if ($241) {
                   label = 6;
                   break;
                  }
                  $242 = ($239<<16>>16)==(58);
                  $243 = (($V_1$0) + 2)|0;
                  $$V_4$1$off0 = $242 | $V_4$1$off0$ph$ph;
                  $$V_0$1 = $242 ? $243 : $V_0$3$ph;
                  $V_0$2 = $$V_0$1;$V_4$0$off0 = $$V_4$1$off0;
                 } else {
                  $V_0$2 = $V_0$3$ph;$V_4$0$off0 = $V_4$1$off0$ph$ph;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($30|0));
                 $244 = __THREW__; __THREW__ = 0;
                 $245 = $244&1;
                 if ($245) {
                  label = 6;
                  break;
                 }
                 __THREW__ = 0;
                 $246 = (invoke_iii(621,($30|0),($207|0))|0);
                 $247 = __THREW__; __THREW__ = 0;
                 $248 = $247&1;
                 if ($248) {
                  label = 6;
                  break;
                 }
                 $249 = ($246<<16>>16)==(91);
                 do {
                  if ($249) {
                   label = 115;
                  } else {
                   __THREW__ = 0;
                   invoke_vi(3799,($30|0));
                   $250 = __THREW__; __THREW__ = 0;
                   $251 = $250&1;
                   if ($251) {
                    label = 6;
                    break L112;
                   }
                   __THREW__ = 0;
                   $252 = (invoke_iii(621,($30|0),($207|0))|0);
                   $253 = __THREW__; __THREW__ = 0;
                   $254 = $253&1;
                   if ($254) {
                    label = 6;
                    break L112;
                   }
                   $255 = ($252<<16>>16)==(123);
                   if ($255) {
                    label = 115;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($30|0));
                   $257 = __THREW__; __THREW__ = 0;
                   $258 = $257&1;
                   if ($258) {
                    label = 6;
                    break L112;
                   }
                   __THREW__ = 0;
                   $259 = (invoke_iii(621,($30|0),($207|0))|0);
                   $260 = __THREW__; __THREW__ = 0;
                   $261 = $260&1;
                   if ($261) {
                    label = 6;
                    break L112;
                   }
                   $262 = ($259<<16>>16)==(93);
                   if (!($262)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($30|0));
                    $263 = __THREW__; __THREW__ = 0;
                    $264 = $263&1;
                    if ($264) {
                     label = 6;
                     break L112;
                    }
                    __THREW__ = 0;
                    $265 = (invoke_iii(621,($30|0),($207|0))|0);
                    $266 = __THREW__; __THREW__ = 0;
                    $267 = $266&1;
                    if ($267) {
                     label = 6;
                     break L112;
                    }
                    $268 = ($265<<16>>16)==(125);
                    if (!($268)) {
                     $V_5$0 = $V_5$1$ph88;
                     break;
                    }
                   }
                   $269 = (($V_5$1$ph88) + -1)|0;
                   $V_5$0 = $269;
                  }
                 } while(0);
                 if ((label|0) == 115) {
                  label = 0;
                  $256 = (($V_5$1$ph88) + 1)|0;
                  $V_5$0 = $256;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($30|0));
                 $270 = __THREW__; __THREW__ = 0;
                 $271 = $270&1;
                 if ($271) {
                  label = 6;
                  break;
                 }
                 __THREW__ = 0;
                 $272 = (invoke_iii(621,($30|0),($207|0))|0);
                 $273 = __THREW__; __THREW__ = 0;
                 $274 = $273&1;
                 if ($274) {
                  label = 6;
                  break;
                 }
                 $notlhs = ($272<<16>>16)!=(44);
                 $notrhs = ($V_5$0|0)!=(0);
                 $or$cond9$not = $notrhs | $notlhs;
                 $275 = ($V_5$0|0)>(-1);
                 $or$cond10 = $or$cond9$not & $275;
                 if ($or$cond10) {
                  $V_0$3$ph$ph = $V_0$2;$V_1$0$ph$ph = $207;$V_2$2$ph$ph = $V_2$135;$V_4$1$off0$ph$ph = $V_4$0$off0;$V_5$1$ph$ph = $V_5$0;
                  continue;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($30|0));
                 $276 = __THREW__; __THREW__ = 0;
                 $277 = $276&1;
                 if ($277) {
                  label = 6;
                  break;
                 }
                 $278 = (($207) - ($V_0$2))|0;
                 __THREW__ = 0;
                 $279 = (invoke_iiii(528,($30|0),($V_0$2|0),($278|0))|0);
                 $280 = __THREW__; __THREW__ = 0;
                 $281 = $280&1;
                 if ($281) {
                  label = 6;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(1281560|0))|0);
                 $282 = __THREW__; __THREW__ = 0;
                 $283 = $282&1;
                 if ($283) {
                  label = 6;
                  break;
                 }
                 $284 = HEAP8[((1281560 + 116|0))>>0]|0;
                 $285 = ($284<<24>>24)==(0);
                 if ($285) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(1281560|0))|0);
                  $286 = __THREW__; __THREW__ = 0;
                  $287 = $286&1;
                  if ($287) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(1281560|0))|0);
                  $288 = __THREW__; __THREW__ = 0;
                  $289 = $288&1;
                  if ($289) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3802,(1281560|0));
                  $290 = __THREW__; __THREW__ = 0;
                  $291 = $290&1;
                  if ($291) {
                   label = 6;
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(1281560|0))|0);
                 $292 = __THREW__; __THREW__ = 0;
                 $293 = $292&1;
                 if ($293) {
                  label = 6;
                  break;
                 }
                 $294 = HEAP32[((1281560 + 80|0))>>2]|0;
                 $295 = (($294) + 16|0);
                 $296 = HEAP32[$295>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($279|0));
                 $297 = __THREW__; __THREW__ = 0;
                 $298 = $297&1;
                 if ($298) {
                  label = 6;
                  break;
                 }
                 __THREW__ = 0;
                 $299 = (invoke_iii(624,($279|0),($296|0))|0);
                 $300 = __THREW__; __THREW__ = 0;
                 $301 = $300&1;
                 if ($301) {
                  label = 6;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($299|0));
                 $302 = __THREW__; __THREW__ = 0;
                 $303 = $302&1;
                 if ($303) {
                  label = 6;
                  break;
                 }
                 __THREW__ = 0;
                 $304 = (invoke_ii(1816,($299|0))|0);
                 $305 = __THREW__; __THREW__ = 0;
                 $306 = $305&1;
                 if ($306) {
                  label = 6;
                  break;
                 }
                 $307 = ($304|0)<(1);
                 if (!($307)) {
                  $308 = HEAP32[$189>>2]|0;
                  $309 = ($308|0)==(3);
                  if ($309) {
                   $310 = HEAP32[$190>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($310|0));
                   $311 = __THREW__; __THREW__ = 0;
                   $312 = $311&1;
                   if ($312) {
                    label = 6;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(2110,(1331280|0),($310|0),($V_2$135|0));
                   $313 = __THREW__; __THREW__ = 0;
                   $314 = $313&1;
                   if ($314) {
                    label = 6;
                    break;
                   }
                  }
                  $315 = HEAP32[$191>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1281560|0))|0);
                  $316 = __THREW__; __THREW__ = 0;
                  $317 = $316&1;
                  if ($317) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  $318 = (invoke_ii(3469,(1281560|0))|0);
                  $319 = __THREW__; __THREW__ = 0;
                  $320 = $319&1;
                  if ($320) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(258,($318|0),($299|0),0);
                  $321 = __THREW__; __THREW__ = 0;
                  $322 = $321&1;
                  if ($322) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($315|0));
                  $323 = __THREW__; __THREW__ = 0;
                  $324 = $323&1;
                  if ($324) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(2110,(1324384|0),($315|0),($318|0));
                  $325 = __THREW__; __THREW__ = 0;
                  $326 = $325&1;
                  if ($326) {
                   label = 6;
                   break;
                  }
                 }
                 $327 = (($V_1$0) + 2)|0;
                 $V_0$3$ph$ph = $327;$V_1$0$ph$ph = $207;$V_2$2$ph$ph = $V_2$135;$V_4$1$off0$ph$ph = 0;$V_5$1$ph$ph = $V_5$0;
                }
                if ((label|0) == 4) {
                 $5 = ___cxa_find_matching_catch()|0;
                 $6 = tempRet0;
                 $lpad$phi$index = $5;$lpad$phi$index4 = $6;
                 break L1;
                }
                else if ((label|0) == 5) {
                 $7 = ___cxa_find_matching_catch()|0;
                 $8 = tempRet0;
                 $lpad$phi$index = $7;$lpad$phi$index4 = $8;
                 break L1;
                }
                else if ((label|0) == 6) {
                 $9 = ___cxa_find_matching_catch()|0;
                 $10 = tempRet0;
                 $lpad$phi$index = $9;$lpad$phi$index4 = $10;
                 break L1;
                }
                else if ((label|0) == 157) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              } while(0);
              $129 = ___cxa_find_matching_catch()|0;
              $130 = tempRet0;
              __THREW__ = 0;
              invoke_v(66);
              $131 = __THREW__; __THREW__ = 0;
              $132 = $131&1;
              if ($132) {
               $338 = ___cxa_find_matching_catch(0|0)|0;
               $339 = tempRet0;
               ___clang_call_terminate($338);
               // unreachable;
              } else {
               $$0 = $129;$$01 = $130;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($$0|0);
               // unreachable;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index4 = $12;
 }
 $$0 = $lpad$phi$index;$$01 = $lpad$phi$index4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z21ArrayElementTypeCheckP21mscorlib_System_ArrayPv($array,$value) {
 $array = $array|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($value|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$array>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$value>>2]|0;
 $5 = (__ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_($3,$4)|0);
 if ($5) {
  STACKTOP = sp;return;
 } else {
  $6 = (__ZN6il2cpp2vm9Exception29GetArrayTypeMismatchExceptionEv()|0);
  __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception($6);
  // unreachable;
 }
}
function __Z42AssemblyU002DCSharp_JSONObject_m_HasFieldsP30AssemblyU002DCSharp_JSONObjectP26mscorlib_System_String_arr($__this,$names) {
 $__this = $__this|0;
 $names = $names|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278208);
 $0 = (($names) + 12|0);
 $1 = (($names) + 16|0);
 $2 = (($__this) + 20|0);
 $V_2$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($names|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   label = 5;
   break;
  }
  $27 = HEAP32[$0>>2]|0;
  $28 = ($V_2$0|0)<($27|0);
  if (!($28)) {
   $$0 = 1;
   label = 12;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($names|0));
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 5;
   break;
  }
  $3 = HEAP32[$0>>2]|0;
  $4 = ($V_2$0>>>0)<($3>>>0);
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_i(132)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 5;
    break;
   }
  }
  $12 = HEAP32[$names>>2]|0;
  $13 = (($12) + 92|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = Math_imul($14, $V_2$0)|0;
  $16 = (($1) + ($15)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($18|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $21 = (invoke_iiii(1640,(1331648|0),($18|0),($17|0))|0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 5;
   break;
  }
  $24 = (($V_2$0) + 1)|0;
  if ($21) {
   $V_2$0 = $24;
  } else {
   $$0 = 0;
   label = 12;
   break;
  }
 }
 if ((label|0) == 5) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 }
 else if ((label|0) == 12) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z165AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_SingleU0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPfP22mscorlib_System_StringP44AssemblyU002DCSharp_JSONObject_FieldNotFound($__this,$field,$name,$fail) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fail = $fail|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277776);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if ($2) {
  $3 = (($__this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iiii(1641,(1331784|0),($4|0),($name|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($7|0)<(0);
    if ($10) {
     label = 10;
    } else {
     $13 = (($__this) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iiii(1642,(1325560|0),($14|0),($7|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       invoke_vi(3799,($17|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = (($17) + 28|0);
        $23 = Math_fround(HEAPF32[$22>>2]);
        HEAPF32[$field>>2] = $23;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $24 = ($fail|0)==(0|0);
  if ($24) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($fail|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   __THREW__ = 0;
   invoke_viii(2110,(1274576|0),($fail|0),($name|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z55AssemblyU002DCSharp_JSONObject_GetFieldResponse_m__ctorP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275080);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z178AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_GetFieldResponse_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP44AssemblyU002DCSharp_JSONObject_FieldNotFound($__this,$name,$response,$fail) {
 $__this = $__this|0;
 $name = $name|0;
 $response = $response|0;
 $fail = $fail|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278112);
 $0 = ($response|0)==(0|0);
 if ($0) {
  label = 11;
 } else {
  $1 = (($__this) + 12|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(3);
  if ($3) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1641,(1331784|0),($5|0),($name|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = ($8|0)<(0);
     if ($11) {
      label = 11;
     } else {
      $14 = (($__this) + 16|0);
      $15 = HEAP32[$14>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($15|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_iiii(1642,(1325560|0),($15|0),($8|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        invoke_vi(3799,($response|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         invoke_viii(2110,(1275128|0),($response|0),($18|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  } else {
   label = 11;
  }
 }
 if ((label|0) == 11) {
  $25 = ($fail|0)==(0|0);
  if ($25) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  invoke_vi(3799,($fail|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   __THREW__ = 0;
   invoke_viii(2110,(1274576|0),($fail|0),($name|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z52AssemblyU002DCSharp_JSONObject_FieldNotFound_m__ctorP44AssemblyU002DCSharp_JSONObject_FieldNotFoundP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1274528);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I17VoidPointerTraitsS0_E6InvokeEPFPvS2_S2_ES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z53AssemblyU002DCSharp_JSONObject_AddJSONConents_m__ctorP45AssemblyU002DCSharp_JSONObject_AddJSONConentsP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1273936);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54AssemblyU002DCSharp_JSONObject_AddJSONConents_m_InvokeP45AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObject($__this,$self) {
 $__this = $__this|0;
 $self = $self|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1273984);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vii(1184,($1|0),($self|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($10|0),($self|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z59AssemblyU002DCSharp_JSONObject_AddJSONConents_m_BeginInvokeP45AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$self,$callback,$object) {
 $__this = $__this|0;
 $self = $self|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1274032);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z57AssemblyU002DCSharp_JSONObject_AddJSONConents_m_EndInvokeP45AssemblyU002DCSharp_JSONObject_AddJSONConentsP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1274080);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS3_S3_S3_P22mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z53AssemblyU002DCSharp_JSONObject_FieldNotFound_m_InvokeP44AssemblyU002DCSharp_JSONObject_FieldNotFoundP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1274576);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vii(1186,($1|0),($name|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($10|0),($name|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z58AssemblyU002DCSharp_JSONObject_FieldNotFound_m_BeginInvokeP44AssemblyU002DCSharp_JSONObject_FieldNotFoundP22mscorlib_System_StringP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$name,$callback,$object) {
 $__this = $__this|0;
 $name = $name|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1274624);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z56AssemblyU002DCSharp_JSONObject_FieldNotFound_m_EndInvokeP44AssemblyU002DCSharp_JSONObject_FieldNotFoundP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1274672);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z56AssemblyU002DCSharp_JSONObject_GetFieldResponse_m_InvokeP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP30AssemblyU002DCSharp_JSONObject($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275128);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vii(1188,($1|0),($obj|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($10|0),($obj|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z61AssemblyU002DCSharp_JSONObject_GetFieldResponse_m_BeginInvokeP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$obj,$callback,$object) {
 $__this = $__this|0;
 $obj = $obj|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275176);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z59AssemblyU002DCSharp_JSONObject_GetFieldResponse_m_EndInvokeP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275224);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z95AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_AssemblyU002DCSharp_JSONObject_TypeP30AssemblyU002DCSharp_JSONObjecti($__this,$t) {
 $__this = $__this|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275640);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   HEAP32[$2>>2] = $t;
   if ((($t|0) == 4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1326240|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(1326240|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3803,($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = (($__this) + 16|0);
    HEAP32[$12>>2] = $7;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else if ((($t|0) == 3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1326240|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    $15 = (invoke_ii(3469,(1326240|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3803,($15|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = (($__this) + 16|0);
    HEAP32[$20>>2] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(1333136|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(3469,(1333136|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3803,($23|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = (($__this) + 20|0);
    HEAP32[$28>>2] = $23;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z83AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectb($__this,$b) {
 $__this = $__this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275688);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = 5;
  $3 = (($__this) + 32|0);
  $4 = $b&1;
  HEAP8[$3>>0] = $4;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275736);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = 2;
  $3 = (($__this) + 28|0);
  HEAPF32[$3>>2] = $f;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z163AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$dic) {
 $__this = $__this|0;
 $dic = $dic|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $L_12 = 0, $L_3 = 0, $L_4 = 0;
 var $V_0 = 0, $V_1 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $_stackTraceSentry = sp + 76|0;
 $V_0 = sp;
 $V_1 = sp + 36|0;
 $L_3 = sp + 16|0;
 $L_4 = sp + 8|0;
 $L_12 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275784);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;HEAP32[$V_1+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($__this) + 12|0);
   HEAP32[$6>>2] = 3;
   __THREW__ = 0;
   (invoke_ii(2996,(1333136|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(1333136|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3803,($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 20|0);
      HEAP32[$14>>2] = $9;
      __THREW__ = 0;
      (invoke_ii(2996,(1326240|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(1326240|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vi(3803,($17|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         $22 = (($__this) + 16|0);
         HEAP32[$22>>2] = $17;
         __THREW__ = 0;
         invoke_vi(3799,($dic|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          invoke_vii(1264,($L_3|0),($dic|0));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           ;HEAP32[$V_1+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_3+12>>2]|0;HEAP32[$V_1+16>>2]=HEAP32[$L_3+16>>2]|0;
           while(1) {
            __THREW__ = 0;
            (invoke_ii(2996,(1364424|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             label = 27;
             break;
            }
            $70 = HEAP32[((1364424 + 84|0))>>2]|0;
            __THREW__ = 0;
            $71 = (invoke_iii(2728,($V_1|0),($70|0))|0);
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if ($73) {
             label = 27;
             break;
            }
            if (!($71)) {
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 140;
             break;
            }
            __THREW__ = 0;
            invoke_vii(1299,($L_4|0),($V_1|0));
            $74 = __THREW__; __THREW__ = 0;
            $75 = $74&1;
            if ($75) {
             label = 27;
             break;
            }
            $29 = $L_4;
            $30 = $29;
            $31 = HEAP32[$30>>2]|0;
            $32 = (($29) + 4)|0;
            $33 = $32;
            $34 = HEAP32[$33>>2]|0;
            $35 = $V_0;
            $36 = $35;
            HEAP32[$36>>2] = $31;
            $37 = (($35) + 4)|0;
            $38 = $37;
            HEAP32[$38>>2] = $34;
            $39 = HEAP32[$14>>2]|0;
            __THREW__ = 0;
            $40 = (invoke_ii(3470,($V_0|0))|0);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($39|0));
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            invoke_viii(2110,(1331280|0),($39|0),($40|0));
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             label = 27;
             break;
            }
            $47 = HEAP32[$22>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(1281560|0))|0);
            $48 = __THREW__; __THREW__ = 0;
            $49 = $48&1;
            if ($49) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            $50 = (invoke_ii(3469,(1281560|0))|0);
            $51 = __THREW__; __THREW__ = 0;
            $52 = $51&1;
            if ($52) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            invoke_vi(1406,($50|0));
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($50|0));
            $55 = __THREW__; __THREW__ = 0;
            $56 = $55&1;
            if ($56) {
             label = 27;
             break;
            }
            $57 = (($50) + 12|0);
            HEAP32[$57>>2] = (1);
            __THREW__ = 0;
            $58 = (invoke_ii(3471,($V_0|0))|0);
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($50|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             label = 27;
             break;
            }
            $63 = (($50) + 24|0);
            HEAP32[$63>>2] = $58;
            __THREW__ = 0;
            invoke_vi(3799,($47|0));
            $64 = __THREW__; __THREW__ = 0;
            $65 = $64&1;
            if ($65) {
             label = 27;
             break;
            }
            __THREW__ = 0;
            invoke_viii(2110,(1324384|0),($47|0),($50|0));
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 27;
             break;
            }
           }
           if ((label|0) == 27) {
            $76 = ___cxa_find_matching_catch(348288|0)|0;
            $77 = tempRet0;
            $78 = (_llvm_eh_typeid_for((348288|0))|0);
            $79 = ($77|0)==($78|0);
            if (!($79)) {
             $$0 = $76;$$02 = $77;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($$0|0);
             // unreachable;
            }
            $80 = (___cxa_begin_catch(($76|0))|0);
            $81 = HEAP32[$80>>2]|0;
            __THREW__ = 0;
            invoke_v(66);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if ($83) {
             break;
            }
            $__last_unhandled_exception$0 = $81;$leaveInstructions$sroa$0$0 = 0;
           }
           ;HEAP32[$L_12+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$L_12+12>>2]=HEAP32[$V_1+12>>2]|0;HEAP32[$L_12+16>>2]=HEAP32[$V_1+16>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(1364424|0))|0);
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if (!($85)) {
            __THREW__ = 0;
            $86 = (invoke_iii(2724,(1364424|0),($L_12|0))|0);
            $87 = __THREW__; __THREW__ = 0;
            $88 = $87&1;
            if (!($88)) {
             __THREW__ = 0;
             invoke_vi(3799,($86|0));
             $89 = __THREW__; __THREW__ = 0;
             $90 = $89&1;
             if (!($90)) {
              __THREW__ = 0;
              invoke_vii(3491,(2176768|0),($86|0));
              $91 = __THREW__; __THREW__ = 0;
              $92 = $91&1;
              if (!($92)) {
               $cond1 = ($leaveInstructions$sroa$0$0|0)==(140);
               if ($cond1) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
               __THREW__ = 0;
               invoke_vi(3801,($__last_unhandled_exception$0|0));
               $93 = __THREW__; __THREW__ = 0;
               $94 = $93&1;
               if (!($94)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $$0 = $27;$$02 = $28;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN18VirtActionInvoker1I17VoidPointerTraitsE6InvokeEP10MethodInfoPvS4_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($4,$p1);
 STACKTOP = sp;return;
}
function __Z59AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_VoidP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275976);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z171AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$dic) {
 $__this = $__this|0;
 $dic = $dic|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $L_10 = 0, $L_3 = 0, $L_4 = 0, $V_0 = 0, $V_1 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $_stackTraceSentry = sp + 76|0;
 $V_0 = sp;
 $V_1 = sp + 36|0;
 $L_3 = sp + 16|0;
 $L_4 = sp + 8|0;
 $L_10 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275832);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;HEAP32[$V_1+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($__this) + 12|0);
   HEAP32[$6>>2] = 3;
   __THREW__ = 0;
   (invoke_ii(2996,(1333136|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(1333136|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3803,($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 20|0);
      HEAP32[$14>>2] = $9;
      __THREW__ = 0;
      (invoke_ii(2996,(1326240|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(1326240|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vi(3803,($17|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         $22 = (($__this) + 16|0);
         HEAP32[$22>>2] = $17;
         __THREW__ = 0;
         invoke_vi(3799,($dic|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          invoke_vii(1305,($L_3|0),($dic|0));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           ;HEAP32[$V_1+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_3+12>>2]|0;HEAP32[$V_1+16>>2]=HEAP32[$L_3+16>>2]|0;
           while(1) {
            __THREW__ = 0;
            (invoke_ii(2996,(1383624|0))|0);
            $55 = __THREW__; __THREW__ = 0;
            $56 = $55&1;
            if ($56) {
             label = 22;
             break;
            }
            $57 = HEAP32[((1383624 + 84|0))>>2]|0;
            __THREW__ = 0;
            $58 = (invoke_iii(2728,($V_1|0),($57|0))|0);
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             label = 22;
             break;
            }
            if (!($58)) {
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 120;
             break;
            }
            __THREW__ = 0;
            invoke_vii(1317,($L_4|0),($V_1|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             label = 22;
             break;
            }
            $29 = $L_4;
            $30 = $29;
            $31 = HEAP32[$30>>2]|0;
            $32 = (($29) + 4)|0;
            $33 = $32;
            $34 = HEAP32[$33>>2]|0;
            $35 = $V_0;
            $36 = $35;
            HEAP32[$36>>2] = $31;
            $37 = (($35) + 4)|0;
            $38 = $37;
            HEAP32[$38>>2] = $34;
            $39 = HEAP32[$14>>2]|0;
            __THREW__ = 0;
            $40 = (invoke_ii(3470,($V_0|0))|0);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             label = 22;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($39|0));
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             label = 22;
             break;
            }
            __THREW__ = 0;
            invoke_viii(2110,(1331280|0),($39|0),($40|0));
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             label = 22;
             break;
            }
            $47 = HEAP32[$22>>2]|0;
            __THREW__ = 0;
            $48 = (invoke_ii(3471,($V_0|0))|0);
            $49 = __THREW__; __THREW__ = 0;
            $50 = $49&1;
            if ($50) {
             label = 22;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($47|0));
            $51 = __THREW__; __THREW__ = 0;
            $52 = $51&1;
            if ($52) {
             label = 22;
             break;
            }
            __THREW__ = 0;
            invoke_viii(2110,(1324384|0),($47|0),($48|0));
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             label = 22;
             break;
            }
           }
           if ((label|0) == 22) {
            $63 = ___cxa_find_matching_catch(348288|0)|0;
            $64 = tempRet0;
            $65 = (_llvm_eh_typeid_for((348288|0))|0);
            $66 = ($64|0)==($65|0);
            if (!($66)) {
             $$0 = $63;$$02 = $64;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($$0|0);
             // unreachable;
            }
            $67 = (___cxa_begin_catch(($63|0))|0);
            $68 = HEAP32[$67>>2]|0;
            __THREW__ = 0;
            invoke_v(66);
            $69 = __THREW__; __THREW__ = 0;
            $70 = $69&1;
            if ($70) {
             break;
            }
            $__last_unhandled_exception$0 = $68;$leaveInstructions$sroa$0$0 = 0;
           }
           ;HEAP32[$L_10+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_10+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_10+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$L_10+12>>2]=HEAP32[$V_1+12>>2]|0;HEAP32[$L_10+16>>2]=HEAP32[$V_1+16>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(1383624|0))|0);
           $71 = __THREW__; __THREW__ = 0;
           $72 = $71&1;
           if (!($72)) {
            __THREW__ = 0;
            $73 = (invoke_iii(2724,(1383624|0),($L_10|0))|0);
            $74 = __THREW__; __THREW__ = 0;
            $75 = $74&1;
            if (!($75)) {
             __THREW__ = 0;
             invoke_vi(3799,($73|0));
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if (!($77)) {
              __THREW__ = 0;
              invoke_vii(3491,(2176768|0),($73|0));
              $78 = __THREW__; __THREW__ = 0;
              $79 = $78&1;
              if (!($79)) {
               $cond1 = ($leaveInstructions$sroa$0$0|0)==(120);
               if ($cond1) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
               __THREW__ = 0;
               invoke_vi(3801,($__last_unhandled_exception$0|0));
               $80 = __THREW__; __THREW__ = 0;
               $81 = $80&1;
               if (!($81)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $$0 = $27;$$02 = $28;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z105AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObjectP45AssemblyU002DCSharp_JSONObject_AddJSONConents($__this,$content) {
 $__this = $__this|0;
 $content = $content|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275880);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($content|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   invoke_viii(2110,(1273984|0),($content|0),($__this|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z98AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_AssemblyU002DCSharp_JSONObject_arr_arrP30AssemblyU002DCSharp_JSONObjectP34AssemblyU002DCSharp_JSONObject_arr($__this,$objs) {
 $__this = $__this|0;
 $objs = $objs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1275928);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = 4;
  __THREW__ = 0;
  (invoke_ii(2996,(1326240|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(1326240|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(3493,($5|0),($objs|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($__this) + 16|0);
     HEAP32[$10>>2] = $5;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z39AssemblyU002DCSharp_JSONObject_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276072);
 __THREW__ = 0;
 (invoke_ii(2996,(1168808|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2723,(1168808|0),4)|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$0>>2] = 1276120;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viii(551,(0|0),($3|0),($$byval_copy|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1281560|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[((1281560 + 80|0))>>2]|0;
     $11 = (($10) + 16|0);
     HEAP32[$11>>2] = $3;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z48AssemblyU002DCSharp_JSONObject_m_get_isContainerP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $$off = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276144);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $$off = (($1) + -3)|0;
 $2 = ($$off>>>0)<(2);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z42AssemblyU002DCSharp_JSONObject_m_get_CountP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276192);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = -1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2729,(1325496|0),($1|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $$0 = $5;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker0I27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z38AssemblyU002DCSharp_JSONObject_m_get_fP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276240);
 $0 = (($__this) + 28|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z43AssemblyU002DCSharp_JSONObject_m_get_nullJOP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276288);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1190,($2|0),0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z40AssemblyU002DCSharp_JSONObject_m_get_objP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276336);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1190,($2|0),3);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z40AssemblyU002DCSharp_JSONObject_m_get_arrP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276384);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1190,($2|0),4);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z45AssemblyU002DCSharp_JSONObject_m_StringObjectP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276432);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1406,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($2) + 12|0);
     HEAP32[$9>>2] = (1);
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = (($2) + 24|0);
      HEAP32[$12>>2] = $val;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($2|0);
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z39AssemblyU002DCSharp_JSONObject_m_AbsorbP30AssemblyU002DCSharp_JSONObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276480);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($obj|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($obj) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vii(3494,($1|0),($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($__this) + 20|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($obj|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = (($obj) + 20|0);
     $15 = HEAP32[$14>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      invoke_vii(3494,($11|0),($15|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       invoke_vi(3799,($obj|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = (($obj) + 24|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = (($__this) + 24|0);
        HEAP32[$24>>2] = $23;
        __THREW__ = 0;
        invoke_vi(3799,($obj|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($obj) + 28|0);
         $28 = Math_fround(HEAPF32[$27>>2]);
         $29 = (($__this) + 28|0);
         HEAPF32[$29>>2] = $28;
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          $32 = (($obj) + 32|0);
          $33 = HEAP8[$32>>0]|0;
          $34 = (($__this) + 32|0);
          HEAP8[$34>>0] = $33;
          __THREW__ = 0;
          invoke_vi(3799,($obj|0));
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if (!($36)) {
           $37 = (($obj) + 12|0);
           $38 = HEAP32[$37>>2]|0;
           $39 = (($__this) + 12|0);
           HEAP32[$39>>2] = $38;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $40 = ___cxa_find_matching_catch()|0;
 $41 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($40|0);
 // unreachable;
}
function __Z45AssemblyU002DCSharp_JSONObject_m_get_IsNumberP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276528);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z43AssemblyU002DCSharp_JSONObject_m_get_IsNullP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276576);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z45AssemblyU002DCSharp_JSONObject_m_get_IsStringP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276624);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z43AssemblyU002DCSharp_JSONObject_m_get_IsBoolP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276672);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(5);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z44AssemblyU002DCSharp_JSONObject_m_get_IsArrayP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276720);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(4);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z45AssemblyU002DCSharp_JSONObject_m_get_IsObjectP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276768);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z81AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectb($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276816);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1191,($2|0),($val|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vii(1201,($__this|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z88AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277056);
 __THREW__ = 0;
 $0 = (invoke_iii(245,0,($obj|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if (!($0)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $5 = (($__this) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(4);
   if ($7) {
    $$phi$trans$insert = (($__this) + 16|0);
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $18 = $$pre;
   } else {
    HEAP32[$5>>2] = 4;
    $8 = (($__this) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     __THREW__ = 0;
     (invoke_ii(2996,(1326240|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_ii(3469,(1326240|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3803,($13|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     HEAP32[$8>>2] = $13;
     $18 = $13;
    } else {
     $18 = $9;
    }
   }
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    invoke_viii(2110,(1324384|0),($18|0),($obj|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z80AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectf($__this,$val) {
 $__this = $__this|0;
 $val = Math_fround($val);
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276864);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vif(106,($2|0),(+$val));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vii(1201,($__this|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z79AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjecti($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276912);
 $0 = (Math_fround(($val|0)));
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3469,(1281560|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vif(106,($3|0),(+$0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1201,($__this|0),($3|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z80AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String($__this,$str) {
 $__this = $__this|0;
 $str = $str|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1276960);
 __THREW__ = 0;
 $0 = (invoke_iii(236,0,($str|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vii(1201,($__this|0),($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z103AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObjectP45AssemblyU002DCSharp_JSONObject_AddJSONConents($__this,$content) {
 $__this = $__this|0;
 $content = $content|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277008);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1194,($2|0),($content|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vii(1201,($__this|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z99AssemblyU002DCSharp_JSONObject_m_op_Implicit_mscorlib_System_Boolean_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278976);
 $0 = ($o|0)!=(0|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z109AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringb($__this,$name,$val) {
 $__this = $__this|0;
 $name = $name|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277104);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1191,($2|0),($val|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_viii(263,($__this|0),($name|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z116AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringS0_($__this,$name,$obj) {
 $__this = $__this|0;
 $name = $name|0;
 $obj = $obj|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $L_8 = 0, $V_0$0 = 0;
 var $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_8 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277344);
 __THREW__ = 0;
 $0 = (invoke_iii(245,0,($obj|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   if (!($0)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $7 = (($__this) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(3);
   if ($9) {
    $$pre = (($__this) + 20|0);
    $$pre$phiZ2D = $$pre;
   } else {
    __THREW__ = 0;
    (invoke_ii(2996,(1333136|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(1333136|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3803,($12|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($__this) + 20|0);
    HEAP32[$17>>2] = $12;
    $18 = HEAP32[$7>>2]|0;
    $19 = ($18|0)==(4);
    $20 = (($__this) + 16|0);
    L11: do {
     if ($19) {
      $V_0$0 = 0;
      while(1) {
       $47 = HEAP32[$20>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($47|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
       __THREW__ = 0;
       $50 = (invoke_iii(2729,(1325496|0),($47|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break;
       }
       $53 = ($V_0$0|0)<($50|0);
       if (!($53)) {
        break L11;
       }
       $41 = HEAP32[$17>>2]|0;
       HEAP32[$L_8>>2] = $V_0$0;
       __THREW__ = 0;
       (invoke_ii(2996,(2155952|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       }
       __THREW__ = 0;
       $21 = (invoke_iii(2724,(2155952|0),($L_8|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       $26 = HEAP8[((2191608 + 116|0))>>0]|0;
       $27 = ($26<<24>>24)==(0);
       if ($27) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3802,(2191608|0));
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
       $36 = HEAP32[((2191608 + 80|0))>>2]|0;
       $37 = HEAP32[$36>>2]|0;
       __THREW__ = 0;
       $38 = (invoke_iiii(559,(0|0),($21|0),($37|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($41|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break;
       }
       __THREW__ = 0;
       invoke_viii(2110,(1331280|0),($41|0),($38|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
       $46 = (($V_0$0) + 1)|0;
       $V_0$0 = $46;
      }
      $3 = ___cxa_find_matching_catch()|0;
      $4 = tempRet0;
      $lpad$phi$index = $3;$lpad$phi$index2 = $4;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     } else {
      $56 = HEAP32[$20>>2]|0;
      $57 = ($56|0)==(0|0);
      if ($57) {
       __THREW__ = 0;
       (invoke_ii(2996,(1326240|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break L1;
       }
       __THREW__ = 0;
       $60 = (invoke_ii(3469,(1326240|0))|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3803,($60|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        break L1;
       }
       HEAP32[$20>>2] = $60;
      }
     }
    } while(0);
    HEAP32[$7>>2] = 3;
    $$pre$phiZ2D = $17;
   }
   $65 = HEAP32[$$pre$phiZ2D>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($65|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if (!($67)) {
    __THREW__ = 0;
    invoke_viii(2110,(1331280|0),($65|0),($name|0));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if (!($69)) {
     $70 = (($__this) + 16|0);
     $71 = HEAP32[$70>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($71|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if (!($73)) {
      __THREW__ = 0;
      invoke_viii(2110,(1324384|0),($71|0),($obj|0));
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if (!($75)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z108AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringf($__this,$name,$val) {
 $__this = $__this|0;
 $name = $name|0;
 $val = Math_fround($val);
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277152);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vif(106,($2|0),(+$val));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_viii(263,($__this|0),($name|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z107AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringi($__this,$name,$val) {
 $__this = $__this|0;
 $name = $name|0;
 $val = $val|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277200);
 $0 = (Math_fround(($val|0)));
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3469,(1281560|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vif(106,($3|0),(+$0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(263,($__this|0),($name|0),($3|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z131AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP45AssemblyU002DCSharp_JSONObject_AddJSONConents($__this,$name,$content) {
 $__this = $__this|0;
 $name = $name|0;
 $content = $content|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277248);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1194,($2|0),($content|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_viii(263,($__this|0),($name|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z108AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringS2_($__this,$name,$val) {
 $__this = $__this|0;
 $name = $name|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277296);
 __THREW__ = 0;
 $0 = (invoke_iii(236,0,($val|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viii(263,($__this|0),($name|0),($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z109AssemblyU002DCSharp_JSONObject_m_SetField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringb($__this,$name,$val) {
 $__this = $__this|0;
 $name = $name|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277392);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1191,($2|0),($val|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_viii(266,($__this|0),($name|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z116AssemblyU002DCSharp_JSONObject_m_SetField_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringS0_($__this,$name,$obj) {
 $__this = $__this|0;
 $name = $name|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277536);
 __THREW__ = 0;
 $0 = (invoke_iii(239,($__this|0),($name|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    $5 = (($__this) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    $7 = (invoke_iii(242,($__this|0),($name|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($6|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    (invoke_iiii(1640,(1325224|0),($6|0),($7|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = (($__this) + 20|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    (invoke_iiii(1640,(1332120|0),($15|0),($name|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_viii(263,($__this|0),($name|0),($obj|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z108AssemblyU002DCSharp_JSONObject_m_SetField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringf($__this,$name,$val) {
 $__this = $__this|0;
 $name = $name|0;
 $val = Math_fround($val);
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277440);
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vif(106,($2|0),(+$val));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_viii(266,($__this|0),($name|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z107AssemblyU002DCSharp_JSONObject_m_SetField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringi($__this,$name,$val) {
 $__this = $__this|0;
 $name = $name|0;
 $val = $val|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277488);
 $0 = (Math_fround(($val|0)));
 __THREW__ = 0;
 (invoke_ii(2996,(1281560|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3469,(1281560|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vif(106,($3|0),(+$0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(266,($__this|0),($name|0),($3|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z41AssemblyU002DCSharp_JSONObject_m_HasFieldP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278256);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if (!($2)) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__this) + 20|0);
 $V_0$0 = 0;
 while(1) {
  $14 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($14|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  $17 = (invoke_iii(2729,(1332392|0),($14|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 6;
   break;
  }
  $20 = ($V_0$0|0)<($17|0);
  if (!($20)) {
   $$0 = 0;
   label = 11;
   break;
  }
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  $5 = (invoke_iiii(1642,(1332456|0),($4|0),($V_0$0|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  $8 = (invoke_iiii(574,(0|0),($5|0),($name|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 6;
   break;
  }
  $11 = (($V_0$0) + 1)|0;
  if ($8) {
   $$0 = 1;
   label = 11;
   break;
  } else {
   $V_0$0 = $11;
  }
 }
 if ((label|0) == 6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($12|0);
  // unreachable;
 }
 else if ((label|0) == 11) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z95AssemblyU002DCSharp_JSONObject_m_get_Item_AssemblyU002DCSharp_JSONObject_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278688);
 __THREW__ = 0;
 $0 = (invoke_iii(237,($__this|0),($index|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z44AssemblyU002DCSharp_JSONObject_m_RemoveFieldP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277584);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1641,(1331784|0),($1|0),($name|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)<(0);
   if ($7) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $10 = (($__this) + 16|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_iiii(1641,(1331784|0),($12|0),($name|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_viii(2111,(1325288|0),($11|0),($15|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[$0>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($22|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        (invoke_iiii(1640,(1332120|0),($22|0),($name|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN18VirtActionInvoker1I27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($4,$p1);
 STACKTOP = sp;return;
}
function __Z145AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_BooleanU0026_ref_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectPbP22mscorlib_System_Stringb($__this,$field,$name,$fallback) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fallback = $fallback|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277632);
 __THREW__ = 0;
 $0 = (invoke_iiiii(67,($__this|0),($field|0),($name|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 }
 if ($0) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $5 = $fallback&1;
 HEAP8[$field>>0] = $5;
 $$0 = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z166AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_BooleanU0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPbP22mscorlib_System_StringP44AssemblyU002DCSharp_JSONObject_FieldNotFound($__this,$field,$name,$fail) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fail = $fail|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277680);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if ($2) {
  $3 = (($__this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iiii(1641,(1331784|0),($4|0),($name|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($7|0)<(0);
    if ($10) {
     label = 10;
    } else {
     $13 = (($__this) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iiii(1642,(1325560|0),($14|0),($7|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       invoke_vi(3799,($17|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = (($17) + 32|0);
        $23 = HEAP8[$22>>0]|0;
        HEAP8[$field>>0] = $23;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $24 = ($fail|0)==(0|0);
  if ($24) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($fail|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   __THREW__ = 0;
   invoke_viii(2110,(1274576|0),($fail|0),($name|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z143AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_SingleU0026_ref_mscorlib_System_String_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectPfP22mscorlib_System_Stringf($__this,$field,$name,$fallback) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fallback = Math_fround($fallback);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277728);
 __THREW__ = 0;
 $0 = (invoke_iiiii(68,($__this|0),($field|0),($name|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 }
 if ($0) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 HEAPF32[$field>>2] = $fallback;
 $$0 = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z141AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_Int32U0026_ref_mscorlib_System_String_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjectPiP22mscorlib_System_Stringi($__this,$field,$name,$fallback) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fallback = $fallback|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277824);
 __THREW__ = 0;
 $0 = (invoke_iiiii(70,($__this|0),($field|0),($name|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 }
 if ($0) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$field>>2] = $fallback;
 $$0 = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z164AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_Int32U0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPiP22mscorlib_System_StringP44AssemblyU002DCSharp_JSONObject_FieldNotFound($__this,$field,$name,$fail) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fail = $fail|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277872);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if ($2) {
  $3 = (($__this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iiii(1641,(1331784|0),($4|0),($name|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($7|0)<(0);
    if ($10) {
     label = 10;
    } else {
     $13 = (($__this) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iiii(1642,(1325560|0),($14|0),($7|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       invoke_vi(3799,($17|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = (($17) + 28|0);
        $23 = Math_fround(HEAPF32[$22>>2]);
        $24 = (~~(($23)));
        HEAP32[$field>>2] = $24;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $25 = ($fail|0)==(0|0);
  if ($25) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($fail|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   __THREW__ = 0;
   invoke_viii(2110,(1274576|0),($fail|0),($name|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z143AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_UInt32U0026_ref_mscorlib_System_String_mscorlib_System_UInt32P30AssemblyU002DCSharp_JSONObjectPjP22mscorlib_System_Stringj($__this,$field,$name,$fallback) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fallback = $fallback|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277920);
 __THREW__ = 0;
 $0 = (invoke_iiiii(72,($__this|0),($field|0),($name|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 }
 if ($0) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$field>>2] = $fallback;
 $$0 = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z165AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_UInt32U0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPjP22mscorlib_System_StringP44AssemblyU002DCSharp_JSONObject_FieldNotFound($__this,$field,$name,$fail) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fail = $fail|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1277968);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if ($2) {
  $3 = (($__this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iiii(1641,(1331784|0),($4|0),($name|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($7|0)<(0);
    if ($10) {
     label = 10;
    } else {
     $13 = (($__this) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iiii(1642,(1325560|0),($14|0),($7|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       invoke_vi(3799,($17|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = (($17) + 28|0);
        $23 = Math_fround(HEAPF32[$22>>2]);
        $24 = (~~(($23))>>>0);
        HEAP32[$field>>2] = $24;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $25 = ($fail|0)==(0|0);
  if ($25) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($fail|0));
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   __THREW__ = 0;
   invoke_viii(2110,(1274576|0),($fail|0),($name|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z143AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_StringU0026_ref_mscorlib_System_String_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectPP22mscorlib_System_StringS2_S2_($__this,$field,$name,$fallback) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fallback = $fallback|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278016);
 __THREW__ = 0;
 $0 = (invoke_iiiii(74,($__this|0),($field|0),($name|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 }
 if ($0) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$field>>2] = $fallback;
 $$0 = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z165AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_StringU0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPP22mscorlib_System_StringS2_P44AssemblyU002DCSharp_JSONObject_FieldNotFound($__this,$field,$name,$fail) {
 $__this = $__this|0;
 $field = $field|0;
 $name = $name|0;
 $fail = $fail|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278064);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if ($2) {
  $3 = (($__this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iiii(1641,(1331784|0),($4|0),($name|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($7|0)<(0);
    if ($10) {
     label = 10;
    } else {
     $13 = (($__this) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iiii(1642,(1325560|0),($14|0),($7|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       invoke_vi(3799,($17|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = (($17) + 24|0);
        $23 = HEAP32[$22>>2]|0;
        HEAP32[$field>>2] = $23;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } else {
  label = 10;
 }
 if ((label|0) == 10) {
  $24 = ($fail|0)==(0|0);
  if ($24) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($fail|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if (!($26)) {
   __THREW__ = 0;
   invoke_viii(2110,(1274576|0),($fail|0),($name|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z95AssemblyU002DCSharp_JSONObject_m_GetField_AssemblyU002DCSharp_JSONObject_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278160);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if (!($2)) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__this) + 20|0);
 $V_0$0 = 0;
 while(1) {
  $23 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($23|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  $26 = (invoke_iii(2729,(1332392|0),($23|0))|0);
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   label = 6;
   break;
  }
  $29 = ($V_0$0|0)<($26|0);
  if (!($29)) {
   $$0 = 0;
   label = 16;
   break;
  }
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $30 = __THREW__; __THREW__ = 0;
  $31 = $30&1;
  if ($31) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  $5 = (invoke_iiii(1642,(1332456|0),($4|0),($V_0$0|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  $8 = (invoke_iiii(574,(0|0),($5|0),($name|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 6;
   break;
  }
  $11 = (($V_0$0) + 1)|0;
  if ($8) {
   label = 9;
   break;
  } else {
   $V_0$0 = $11;
  }
 }
 if ((label|0) == 6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index2 = $13;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  $16 = (($__this) + 16|0);
  $17 = HEAP32[$16>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($17|0));
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   __THREW__ = 0;
   $20 = (invoke_iiii(1642,(1325560|0),($17|0),($V_0$0|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $$0 = $20;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $lpad$phi$index = $14;$lpad$phi$index2 = $15;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 16) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z38AssemblyU002DCSharp_JSONObject_m_ClearP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278304);
 $0 = (($__this) + 12|0);
 HEAP32[$0>>2] = 0;
 $1 = (($__this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($2|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(3495,(1324688|0),($2|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    label = 4;
   }
  }
 }
 do {
  if ((label|0) == 4) {
   $8 = (($__this) + 20|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3799,($9|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(3495,(1331584|0),($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP8[((2191608 + 116|0))>>0]|0;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3802,(2191608|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = HEAP32[((2191608 + 80|0))>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = (($__this) + 24|0);
     HEAP32[$31>>2] = $30;
     $32 = (($__this) + 28|0);
     HEAPF32[$32>>2] = Math_fround(0.0);
     $33 = (($__this) + 32|0);
     HEAP8[$33>>0] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __ZN18VirtActionInvoker06InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($4);
 STACKTOP = sp;return;
}
function __Z37AssemblyU002DCSharp_JSONObject_m_CopyP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278352);
 __THREW__ = 0;
 $0 = (invoke_iii(240,($__this|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1281560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(1281560|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(258,($5|0),($0|0),0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($5|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z85AssemblyU002DCSharp_JSONObject_m_print_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectb($__this,$pretty) {
 $__this = $__this|0;
 $pretty = $pretty|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278496);
 __THREW__ = 0;
 $0 = (invoke_iiii(141,($__this|0),0,($pretty|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z38AssemblyU002DCSharp_JSONObject_m_MergeP30AssemblyU002DCSharp_JSONObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278400);
 __THREW__ = 0;
 invoke_viii(267,0,($__this|0),($obj|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43AssemblyU002DCSharp_JSONObject_m_MergeRecurP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObjectS2_($__this,$left,$right) {
 $__this = $__this|0;
 $left = $left|0;
 $right = $right|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278448);
 __THREW__ = 0;
 invoke_v(286);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($left|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($left) + 12|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5|0)==(0);
    if ($6) {
     __THREW__ = 0;
     invoke_vi(3799,($left|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1196,($left|0),($right|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3799,($left|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[$4>>2]|0;
     $20 = ($19|0)==(3);
     if ($20) {
      __THREW__ = 0;
      invoke_vi(3799,($right|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      $23 = (($right) + 12|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24|0)==(3);
      if ($25) {
       $26 = (($right) + 16|0);
       $27 = (($right) + 20|0);
       $V_0$0 = 0;
       L14: while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($right|0));
        $94 = __THREW__; __THREW__ = 0;
        $95 = $94&1;
        if ($95) {
         break;
        }
        $96 = HEAP32[$26>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($96|0));
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if ($98) {
         break;
        }
        __THREW__ = 0;
        $99 = (invoke_iii(2729,(1325496|0),($96|0))|0);
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         break;
        }
        $102 = ($V_0$0|0)<($99|0);
        if (!($102)) {
         label = 88;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($right|0));
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         break;
        }
        $28 = HEAP32[$27>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($28|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break;
        }
        __THREW__ = 0;
        $31 = (invoke_iiii(1642,(1332456|0),($28|0),($V_0$0|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($right|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
        __THREW__ = 0;
        $36 = (invoke_iii(241,($right|0),($V_0$0|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($36|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
        __THREW__ = 0;
        $41 = (invoke_ii(721,($36|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        do {
         if ($41) {
          __THREW__ = 0;
          invoke_vi(3799,($left|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break L14;
          }
          __THREW__ = 0;
          $46 = (invoke_iii(239,($left|0),($31|0))|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           break L14;
          }
          if (!($46)) {
           __THREW__ = 0;
           invoke_vi(3799,($right|0));
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            break L14;
           }
           __THREW__ = 0;
           $63 = (invoke_iii(241,($right|0),($V_0$0|0))|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            break L14;
           }
           __THREW__ = 0;
           invoke_vi(3799,($left|0));
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            break L14;
           }
           __THREW__ = 0;
           invoke_viii(263,($left|0),($31|0),($63|0));
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            break L14;
           } else {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($left|0));
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break L14;
          }
          __THREW__ = 0;
          $51 = (invoke_iii(242,($left|0),($31|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break L14;
          }
          __THREW__ = 0;
          invoke_vi(3799,($right|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break L14;
          }
          __THREW__ = 0;
          $56 = (invoke_iii(241,($right|0),($V_0$0|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if ($58) {
           break L14;
          }
          __THREW__ = 0;
          invoke_viii(267,0,($51|0),($56|0));
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           break L14;
          }
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($left|0));
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           break L14;
          }
          __THREW__ = 0;
          $72 = (invoke_iii(239,($left|0),($31|0))|0);
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           break L14;
          }
          if ($72) {
           __THREW__ = 0;
           invoke_vi(3799,($right|0));
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if ($76) {
            break L14;
           }
           __THREW__ = 0;
           $77 = (invoke_iii(241,($right|0),($V_0$0|0))|0);
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if ($79) {
            break L14;
           }
           __THREW__ = 0;
           invoke_vi(3799,($left|0));
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if ($81) {
            break L14;
           }
           __THREW__ = 0;
           invoke_viii(266,($left|0),($31|0),($77|0));
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if ($83) {
            break L14;
           } else {
            break;
           }
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($right|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            break L14;
           }
           __THREW__ = 0;
           $86 = (invoke_iii(241,($right|0),($V_0$0|0))|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            break L14;
           }
           __THREW__ = 0;
           invoke_vi(3799,($left|0));
           $89 = __THREW__; __THREW__ = 0;
           $90 = $89&1;
           if ($90) {
            break L14;
           }
           __THREW__ = 0;
           invoke_viii(263,($left|0),($31|0),($86|0));
           $91 = __THREW__; __THREW__ = 0;
           $92 = $91&1;
           if ($92) {
            break L14;
           } else {
            break;
           }
          }
         }
        } while(0);
        $93 = (($V_0$0) + 1)|0;
        $V_0$0 = $93;
       }
       if ((label|0) == 88) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       $7 = ___cxa_find_matching_catch()|0;
       $8 = tempRet0;
       $lpad$phi$index = $7;$lpad$phi$index3 = $8;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($left|0));
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if (!($106)) {
      $107 = HEAP32[$4>>2]|0;
      $108 = ($107|0)==(4);
      if (!($108)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3799,($right|0));
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if (!($110)) {
       $111 = (($right) + 12|0);
       $112 = HEAP32[$111>>2]|0;
       $113 = ($112|0)==(4);
       if (!($113)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       invoke_vi(3799,($right|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if (!($115)) {
        __THREW__ = 0;
        $116 = (invoke_ii(722,($right|0))|0);
        $117 = __THREW__; __THREW__ = 0;
        $118 = $117&1;
        if (!($118)) {
         __THREW__ = 0;
         invoke_vi(3799,($left|0));
         $119 = __THREW__; __THREW__ = 0;
         $120 = $119&1;
         if (!($120)) {
          __THREW__ = 0;
          $121 = (invoke_ii(722,($left|0))|0);
          $122 = __THREW__; __THREW__ = 0;
          $123 = $122&1;
          if (!($123)) {
           $124 = ($116|0)>($121|0);
           if ($124) {
            $126 = HEAP32[2991248>>2]|0;
            __THREW__ = 0;
            invoke_vii(2110,(0|0),($126|0));
            $127 = __THREW__; __THREW__ = 0;
            $128 = $127&1;
            if ($128) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $125 = (($right) + 16|0);
           $V_2$0 = 0;
           L75: while(1) {
            __THREW__ = 0;
            invoke_vi(3799,($right|0));
            $178 = __THREW__; __THREW__ = 0;
            $179 = $178&1;
            if ($179) {
             break;
            }
            $180 = HEAP32[$125>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($180|0));
            $181 = __THREW__; __THREW__ = 0;
            $182 = $181&1;
            if ($182) {
             break;
            }
            __THREW__ = 0;
            $183 = (invoke_iii(2729,(1325496|0),($180|0))|0);
            $184 = __THREW__; __THREW__ = 0;
            $185 = $184&1;
            if ($185) {
             break;
            }
            $186 = ($V_2$0|0)<($183|0);
            if (!($186)) {
             label = 88;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($left|0));
            $187 = __THREW__; __THREW__ = 0;
            $188 = $187&1;
            if ($188) {
             break;
            }
            __THREW__ = 0;
            $129 = (invoke_iii(241,($left|0),($V_2$0|0))|0);
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($129|0));
            $132 = __THREW__; __THREW__ = 0;
            $133 = $132&1;
            if ($133) {
             break;
            }
            $134 = (($129) + 12|0);
            $135 = HEAP32[$134>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($right|0));
            $136 = __THREW__; __THREW__ = 0;
            $137 = $136&1;
            if ($137) {
             break;
            }
            __THREW__ = 0;
            $138 = (invoke_iii(241,($right|0),($V_2$0|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($138|0));
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             break;
            }
            $143 = (($138) + 12|0);
            $144 = HEAP32[$143>>2]|0;
            $145 = ($135|0)==($144|0);
            do {
             if ($145) {
              __THREW__ = 0;
              invoke_vi(3799,($left|0));
              $146 = __THREW__; __THREW__ = 0;
              $147 = $146&1;
              if ($147) {
               break L75;
              }
              __THREW__ = 0;
              $148 = (invoke_iii(241,($left|0),($V_2$0|0))|0);
              $149 = __THREW__; __THREW__ = 0;
              $150 = $149&1;
              if ($150) {
               break L75;
              }
              __THREW__ = 0;
              invoke_vi(3799,($148|0));
              $151 = __THREW__; __THREW__ = 0;
              $152 = $151&1;
              if ($152) {
               break L75;
              }
              __THREW__ = 0;
              $153 = (invoke_ii(721,($148|0))|0);
              $154 = __THREW__; __THREW__ = 0;
              $155 = $154&1;
              if ($155) {
               break L75;
              }
              if (!($153)) {
               __THREW__ = 0;
               invoke_vi(3799,($right|0));
               $168 = __THREW__; __THREW__ = 0;
               $169 = $168&1;
               if ($169) {
                break L75;
               }
               __THREW__ = 0;
               $170 = (invoke_iii(241,($right|0),($V_2$0|0))|0);
               $171 = __THREW__; __THREW__ = 0;
               $172 = $171&1;
               if ($172) {
                break L75;
               }
               __THREW__ = 0;
               invoke_vi(3799,($left|0));
               $173 = __THREW__; __THREW__ = 0;
               $174 = $173&1;
               if ($174) {
                break L75;
               }
               __THREW__ = 0;
               invoke_viii(268,($left|0),($V_2$0|0),($170|0));
               $175 = __THREW__; __THREW__ = 0;
               $176 = $175&1;
               if ($176) {
                break L75;
               } else {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vi(3799,($left|0));
              $156 = __THREW__; __THREW__ = 0;
              $157 = $156&1;
              if ($157) {
               break L75;
              }
              __THREW__ = 0;
              $158 = (invoke_iii(241,($left|0),($V_2$0|0))|0);
              $159 = __THREW__; __THREW__ = 0;
              $160 = $159&1;
              if ($160) {
               break L75;
              }
              __THREW__ = 0;
              invoke_vi(3799,($right|0));
              $161 = __THREW__; __THREW__ = 0;
              $162 = $161&1;
              if ($162) {
               break L75;
              }
              __THREW__ = 0;
              $163 = (invoke_iii(241,($right|0),($V_2$0|0))|0);
              $164 = __THREW__; __THREW__ = 0;
              $165 = $164&1;
              if ($165) {
               break L75;
              }
              __THREW__ = 0;
              invoke_viii(267,0,($158|0),($163|0));
              $166 = __THREW__; __THREW__ = 0;
              $167 = $166&1;
              if ($167) {
               break L75;
              }
             }
            } while(0);
            $177 = (($V_2$0) + 1)|0;
            $V_2$0 = $177;
           }
           if ((label|0) == 88) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $9 = ___cxa_find_matching_catch()|0;
           $10 = tempRet0;
           $lpad$phi$index = $9;$lpad$phi$index3 = $10;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z94AssemblyU002DCSharp_JSONObject_m_get_Item_AssemblyU002DCSharp_JSONObject_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278592);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(1325496|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)>($index|0);
   if (!($7)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $10 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    $13 = (invoke_iiii(1642,(1325560|0),($10|0),($index|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z115AssemblyU002DCSharp_JSONObject_m_set_Item_mscorlib_System_Void_mscorlib_System_Int32_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectiS0_($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278640);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(1325496|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)>($index|0);
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $10 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    invoke_viiii(459,(1325632|0),($10|0),($index|0),($value|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z107AssemblyU002DCSharp_JSONObject_m_print_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectib($__this,$depth,$pretty) {
 $__this = $__this|0;
 $depth = $depth|0;
 $pretty = $pretty|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $$not = 0, $$not74 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0);
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = Math_fround(0), $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_68 = 0, $L_79 = 0, $V_0$10 = 0, $V_0$10$ph$ph = 0, $V_0$1151 = 0, $V_0$12 = 0, $V_0$125 = 0, $V_0$13$ph = 0, $V_0$14 = 0, $V_0$15 = 0, $V_0$16 = 0;
 var $V_0$1740 = 0, $V_0$18 = 0, $V_0$2 = 0, $V_0$3 = 0, $V_0$4 = 0, $V_0$4$ph = 0, $V_0$5 = 0, $V_0$6 = 0, $V_0$717 = 0, $V_0$8 = 0, $V_0$9 = 0, $V_1$0 = 0, $V_4$024 = 0, $V_5$016 = 0, $V_7 = 0, $V_8$050 = 0, $V_9$039 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $brmerge = 0;
 var $brmerge75 = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $lpad$phi48$index = 0, $lpad$phi48$index14 = 0, $pretty$not = 0, $pretty$not73 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 56|0;
 $V_7 = sp;
 $L_17 = sp + 16|0;
 $L_68 = sp + 24|0;
 $L_79 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278544);
 ;HEAP32[$V_7+0>>2]=0|0;HEAP32[$V_7+4>>2]=0|0;HEAP32[$V_7+8>>2]=0|0;HEAP32[$V_7+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(287);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if ($1) {
   label = 7;
  } else {
   $2 = (($depth) + 1)|0;
   $3 = ($depth|0)<(1001);
   if (!($3)) {
    $14 = HEAP32[2991376>>2]|0;
    __THREW__ = 0;
    invoke_vii(2109,(0|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     label = 7;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 7;
     break;
    }
    $19 = HEAP8[((2191608 + 116|0))>>0]|0;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3802,(2191608|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 7;
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     label = 7;
     break;
    }
    $29 = HEAP32[((2191608 + 80|0))>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    $$0 = $30;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 7;
   } else {
    $33 = HEAP8[((2191608 + 116|0))>>0]|0;
    $34 = ($33<<24>>24)==(0);
    if ($34) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3802,(2191608|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 7;
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 7;
    } else {
     $43 = HEAP32[((2191608 + 80|0))>>2]|0;
     $44 = HEAP32[$43>>2]|0;
     $45 = (($__this) + 12|0);
     $46 = HEAP32[$45>>2]|0;
     switch ($46|0) {
     case 3:  {
      $79 = HEAP32[2991424>>2]|0;
      $80 = (($__this) + 16|0);
      $81 = HEAP32[$80>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($81|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       label = 7;
       break L1;
      }
      __THREW__ = 0;
      $84 = (invoke_iii(2729,(1325496|0),($81|0))|0);
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if ($86) {
       label = 7;
       break L1;
      }
      $87 = ($84|0)<(1);
      do {
       if ($87) {
        $V_0$6 = $79;
       } else {
        if ($pretty) {
         $88 = HEAP32[2991432>>2]|0;
         __THREW__ = 0;
         $89 = (invoke_iiii(562,(0|0),($79|0),($88|0))|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          label = 7;
          break L1;
         } else {
          $V_0$4$ph = $89;
         }
        } else {
         $V_0$4$ph = $79;
        }
        $92 = (($__this) + 20|0);
        $V_0$4 = $V_0$4$ph;$V_1$0 = 0;
        L31: while(1) {
         $131 = HEAP32[$80>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($131|0));
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          label = 5;
          break;
         }
         __THREW__ = 0;
         $134 = (invoke_iii(2729,(1325496|0),($131|0))|0);
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if ($136) {
          label = 5;
          break;
         }
         $137 = ($V_1$0|0)<($134|0);
         if (!($137)) {
          label = 62;
          break;
         }
         $93 = HEAP32[$92>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($93|0));
         $138 = __THREW__; __THREW__ = 0;
         $139 = $138&1;
         if ($139) {
          label = 5;
          break;
         }
         __THREW__ = 0;
         $94 = (invoke_iiii(1642,(1332456|0),($93|0),($V_1$0|0))|0);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          label = 5;
          break;
         }
         $97 = HEAP32[$80>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($97|0));
         $98 = __THREW__; __THREW__ = 0;
         $99 = $98&1;
         if ($99) {
          label = 5;
          break;
         }
         __THREW__ = 0;
         $100 = (invoke_iiii(1642,(1325560|0),($97|0),($V_1$0|0))|0);
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          label = 5;
          break;
         }
         __THREW__ = 0;
         $103 = (invoke_iii(245,0,($100|0))|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 5;
          break;
         }
         do {
          if ($103) {
           $pretty$not = $pretty ^ 1;
           $$not = ($depth|0)<(0);
           $brmerge = $$not | $pretty$not;
           if ($brmerge) {
            $V_0$2 = $V_0$4;
           } else {
            $V_0$125 = $V_0$4;$V_4$024 = 0;
            while(1) {
             $108 = HEAP32[2991440>>2]|0;
             __THREW__ = 0;
             $109 = (invoke_iiii(562,(0|0),($V_0$125|0),($108|0))|0);
             $110 = __THREW__; __THREW__ = 0;
             $111 = $110&1;
             if ($111) {
              label = 4;
              break L31;
             }
             $106 = (($V_4$024) + 1)|0;
             $107 = ($106|0)<($2|0);
             if ($107) {
              $V_0$125 = $109;$V_4$024 = $106;
             } else {
              $V_0$2 = $109;
              break;
             }
            }
           }
           $112 = HEAP32[2991448>>2]|0;
           $113 = HEAP32[2991456>>2]|0;
           __THREW__ = 0;
           $114 = (invoke_iiiiii(89,(0|0),($V_0$2|0),($112|0),($94|0),($113|0))|0);
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            label = 5;
            break L31;
           }
           __THREW__ = 0;
           invoke_vi(3799,($100|0));
           $117 = __THREW__; __THREW__ = 0;
           $118 = $117&1;
           if ($118) {
            label = 5;
            break L31;
           }
           __THREW__ = 0;
           $119 = (invoke_iiii(141,($100|0),($2|0),($pretty|0))|0);
           $120 = __THREW__; __THREW__ = 0;
           $121 = $120&1;
           if ($121) {
            label = 5;
            break L31;
           }
           $122 = HEAP32[2991464>>2]|0;
           __THREW__ = 0;
           $123 = (invoke_iiiii(101,(0|0),($114|0),($119|0),($122|0))|0);
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            label = 5;
            break L31;
           }
           if (!($pretty)) {
            $V_0$3 = $123;
            break;
           }
           $126 = HEAP32[2991472>>2]|0;
           __THREW__ = 0;
           $127 = (invoke_iiii(562,(0|0),($123|0),($126|0))|0);
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            label = 5;
            break L31;
           } else {
            $V_0$3 = $127;
           }
          } else {
           $V_0$3 = $V_0$4;
          }
         } while(0);
         $130 = (($V_1$0) + 1)|0;
         $V_0$4 = $V_0$3;$V_1$0 = $130;
        }
        if ((label|0) == 4) {
         $6 = ___cxa_find_matching_catch()|0;
         $7 = tempRet0;
         $lpad$phi$index = $6;$lpad$phi$index5 = $7;
         break L1;
        }
        else if ((label|0) == 5) {
         $8 = ___cxa_find_matching_catch()|0;
         $9 = tempRet0;
         $lpad$phi$index = $8;$lpad$phi$index5 = $9;
         break L1;
        }
        else if ((label|0) == 62) {
         if ($pretty) {
          __THREW__ = 0;
          invoke_vi(3799,($V_0$4|0));
          $140 = __THREW__; __THREW__ = 0;
          $141 = $140&1;
          if ($141) {
           label = 7;
           break L1;
          }
          __THREW__ = 0;
          $142 = (invoke_ii(1816,($V_0$4|0))|0);
          $143 = __THREW__; __THREW__ = 0;
          $144 = $143&1;
          if ($144) {
           label = 7;
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3799,($V_0$4|0));
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          if ($146) {
           label = 7;
           break L1;
          }
          $147 = (($142) + -1)|0;
          __THREW__ = 0;
          $148 = (invoke_iiii(528,($V_0$4|0),0,($147|0))|0);
          $149 = __THREW__; __THREW__ = 0;
          $150 = $149&1;
          if ($150) {
           label = 7;
           break L1;
          } else {
           $V_0$5 = $148;
          }
         } else {
          $V_0$5 = $V_0$4;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$5|0));
         $151 = __THREW__; __THREW__ = 0;
         $152 = $151&1;
         if ($152) {
          label = 7;
          break L1;
         }
         __THREW__ = 0;
         $153 = (invoke_ii(1816,($V_0$5|0))|0);
         $154 = __THREW__; __THREW__ = 0;
         $155 = $154&1;
         if ($155) {
          label = 7;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$5|0));
         $156 = __THREW__; __THREW__ = 0;
         $157 = $156&1;
         if ($157) {
          label = 7;
          break L1;
         }
         $158 = (($153) + -1)|0;
         __THREW__ = 0;
         $159 = (invoke_iiii(528,($V_0$5|0),0,($158|0))|0);
         $160 = __THREW__; __THREW__ = 0;
         $161 = $160&1;
         if ($161) {
          label = 7;
          break L1;
         } else {
          $V_0$6 = $159;
          break;
         }
        }
       }
      } while(0);
      L68: do {
       if ($pretty) {
        $162 = HEAP32[$80>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($162|0));
        $163 = __THREW__; __THREW__ = 0;
        $164 = $163&1;
        if ($164) {
         label = 7;
         break L1;
        }
        __THREW__ = 0;
        $165 = (invoke_iii(2729,(1325496|0),($162|0))|0);
        $166 = __THREW__; __THREW__ = 0;
        $167 = $166&1;
        if ($167) {
         label = 7;
         break L1;
        }
        $168 = ($165|0)<(1);
        if ($168) {
         $V_0$8 = $V_0$6;
        } else {
         $169 = HEAP32[2991480>>2]|0;
         __THREW__ = 0;
         $170 = (invoke_iiii(562,(0|0),($V_0$6|0),($169|0))|0);
         $171 = __THREW__; __THREW__ = 0;
         $172 = $171&1;
         if ($172) {
          label = 7;
          break L1;
         }
         $173 = ($depth|0)>(0);
         if ($173) {
          $V_0$717 = $170;$V_5$016 = 0;
          while(1) {
           $176 = HEAP32[2991488>>2]|0;
           __THREW__ = 0;
           $177 = (invoke_iiii(562,(0|0),($V_0$717|0),($176|0))|0);
           $178 = __THREW__; __THREW__ = 0;
           $179 = $178&1;
           if ($179) {
            break;
           }
           $174 = (($V_5$016) + 1)|0;
           $175 = ($174|0)<($depth|0);
           if ($175) {
            $V_0$717 = $177;$V_5$016 = $174;
           } else {
            $V_0$8 = $177;
            break L68;
           }
          }
          $4 = ___cxa_find_matching_catch()|0;
          $5 = tempRet0;
          $lpad$phi$index = $4;$lpad$phi$index5 = $5;
          break L1;
         } else {
          $V_0$8 = $170;
         }
        }
       } else {
        $V_0$8 = $V_0$6;
       }
      } while(0);
      $180 = HEAP32[2991496>>2]|0;
      __THREW__ = 0;
      $181 = (invoke_iiii(562,(0|0),($V_0$8|0),($180|0))|0);
      $182 = __THREW__; __THREW__ = 0;
      $183 = $182&1;
      if ($183) {
       label = 7;
       break L1;
      } else {
       $$0 = $181;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
      break;
     }
     case 2:  {
      $54 = (($__this) + 28|0);
      $55 = Math_fround(HEAPF32[$54>>2]);
      __THREW__ = 0;
      $56 = (invoke_iif(8,(0|0),(+$55))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 7;
       break L1;
      }
      if ($56) {
       $59 = HEAP32[2991400>>2]|0;
       $$0 = $59;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $60 = Math_fround(HEAPF32[$54>>2]);
      __THREW__ = 0;
      $61 = (invoke_iif(10,(0|0),(+$60))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       label = 7;
       break L1;
      }
      if ($61) {
       $64 = HEAP32[2991408>>2]|0;
       $$0 = $64;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $65 = Math_fround(HEAPF32[$54>>2]);
      __THREW__ = 0;
      $66 = (invoke_iif(9,(0|0),(+$65))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 7;
       break L1;
      }
      if ($66) {
       $69 = HEAP32[2991416>>2]|0;
       $$0 = $69;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $70 = Math_fround(HEAPF32[$54>>2]);
      HEAPF32[$L_17>>2] = $70;
      __THREW__ = 0;
      (invoke_ii(2996,(2194912|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 7;
       break L1;
      }
      __THREW__ = 0;
      $73 = (invoke_iii(2724,(2194912|0),($L_17|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 7;
       break L1;
      }
      __THREW__ = 0;
      $76 = (invoke_iiii(559,(0|0),($44|0),($73|0))|0);
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       label = 7;
       break L1;
      } else {
       $$0 = $76;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
      break;
     }
     case 1:  {
      $47 = (($__this) + 24|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = HEAP32[2991384>>2]|0;
      $50 = HEAP32[2991392>>2]|0;
      __THREW__ = 0;
      $51 = (invoke_iiiii(101,(0|0),($49|0),($48|0),($50|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 7;
       break L1;
      } else {
       $$0 = $51;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
      break;
     }
     case 4:  {
      $184 = HEAP32[2991504>>2]|0;
      $185 = (($__this) + 16|0);
      $186 = HEAP32[$185>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($186|0));
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if ($188) {
       label = 7;
       break L1;
      }
      __THREW__ = 0;
      $189 = (invoke_iii(2729,(1325496|0),($186|0))|0);
      $190 = __THREW__; __THREW__ = 0;
      $191 = $190&1;
      if ($191) {
       label = 7;
       break L1;
      }
      $192 = ($189|0)<(1);
      if ($192) {
       $V_0$16 = $184;
      } else {
       if ($pretty) {
        $193 = HEAP32[2991512>>2]|0;
        __THREW__ = 0;
        $194 = (invoke_iiii(562,(0|0),($184|0),($193|0))|0);
        $195 = __THREW__; __THREW__ = 0;
        $196 = $195&1;
        if ($196) {
         label = 7;
         break L1;
        } else {
         $V_0$9 = $194;
        }
       } else {
        $V_0$9 = $184;
       }
       $197 = HEAP32[$185>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($197|0));
       $198 = __THREW__; __THREW__ = 0;
       $199 = $198&1;
       if ($199) {
        label = 7;
        break L1;
       }
       __THREW__ = 0;
       invoke_vii(1235,($L_68|0),($197|0));
       $200 = __THREW__; __THREW__ = 0;
       $201 = $200&1;
       if ($201) {
        label = 7;
        break L1;
       }
       ;HEAP32[$V_7+0>>2]=HEAP32[$L_68+0>>2]|0;HEAP32[$V_7+4>>2]=HEAP32[$L_68+4>>2]|0;HEAP32[$V_7+8>>2]=HEAP32[$L_68+8>>2]|0;HEAP32[$V_7+12>>2]=HEAP32[$L_68+12>>2]|0;
       $V_0$13$ph = $V_0$9;
       L111: while(1) {
        while(1) {
         __THREW__ = 0;
         $237 = (invoke_ii(3467,($V_7|0))|0);
         $238 = __THREW__; __THREW__ = 0;
         $239 = $238&1;
         if ($239) {
          label = 91;
          break L111;
         }
         if (!($237)) {
          $V_0$14 = $V_0$13$ph;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 730;
          break L111;
         }
         __THREW__ = 0;
         $202 = (invoke_ii(3468,($V_7|0))|0);
         $240 = __THREW__; __THREW__ = 0;
         $241 = $240&1;
         if ($241) {
          label = 91;
          break L111;
         }
         __THREW__ = 0;
         $203 = (invoke_iii(245,0,($202|0))|0);
         $204 = __THREW__; __THREW__ = 0;
         $205 = $204&1;
         if ($205) {
          label = 91;
          break L111;
         }
         if ($203) {
          break;
         }
        }
        $pretty$not73 = $pretty ^ 1;
        $$not74 = ($depth|0)<(0);
        $brmerge75 = $$not74 | $pretty$not73;
        if ($brmerge75) {
         $V_0$12 = $V_0$13$ph;
        } else {
         $V_0$1151 = $V_0$13$ph;$V_8$050 = 0;
         while(1) {
          $220 = HEAP32[2991520>>2]|0;
          __THREW__ = 0;
          $221 = (invoke_iiii(562,(0|0),($V_0$1151|0),($220|0))|0);
          $222 = __THREW__; __THREW__ = 0;
          $223 = $222&1;
          if ($223) {
           label = 90;
           break L111;
          }
          $218 = (($V_8$050) + 1)|0;
          $219 = ($218|0)<($2|0);
          if ($219) {
           $V_0$1151 = $221;$V_8$050 = $218;
          } else {
           $V_0$12 = $221;
           break;
          }
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($202|0));
        $224 = __THREW__; __THREW__ = 0;
        $225 = $224&1;
        if ($225) {
         $V_0$10$ph$ph = $V_0$12;
         label = 92;
         break;
        }
        __THREW__ = 0;
        $226 = (invoke_iiii(141,($202|0),($2|0),($pretty|0))|0);
        $227 = __THREW__; __THREW__ = 0;
        $228 = $227&1;
        if ($228) {
         $V_0$10$ph$ph = $V_0$12;
         label = 92;
         break;
        }
        $229 = HEAP32[2991528>>2]|0;
        __THREW__ = 0;
        $230 = (invoke_iiiii(101,(0|0),($V_0$12|0),($226|0),($229|0))|0);
        $231 = __THREW__; __THREW__ = 0;
        $232 = $231&1;
        if ($232) {
         $V_0$10$ph$ph = $V_0$12;
         label = 92;
         break;
        }
        if (!($pretty)) {
         $V_0$13$ph = $230;
         continue;
        }
        $233 = HEAP32[2991536>>2]|0;
        __THREW__ = 0;
        $234 = (invoke_iiii(562,(0|0),($230|0),($233|0))|0);
        $235 = __THREW__; __THREW__ = 0;
        $236 = $235&1;
        if ($236) {
         $V_0$10$ph$ph = $230;
         label = 92;
         break;
        } else {
         $V_0$13$ph = $234;
        }
       }
       if ((label|0) == 90) {
        $206 = ___cxa_find_matching_catch(348288|0)|0;
        $207 = tempRet0;
        $V_0$10 = $V_0$1151;$lpad$phi48$index = $206;$lpad$phi48$index14 = $207;
        label = 93;
       }
       else if ((label|0) == 91) {
        $208 = ___cxa_find_matching_catch(348288|0)|0;
        $209 = tempRet0;
        $V_0$10 = $V_0$13$ph;$lpad$phi48$index = $208;$lpad$phi48$index14 = $209;
        label = 93;
       }
       else if ((label|0) == 92) {
        $210 = ___cxa_find_matching_catch(348288|0)|0;
        $211 = tempRet0;
        $V_0$10 = $V_0$10$ph$ph;$lpad$phi48$index = $210;$lpad$phi48$index14 = $211;
        label = 93;
       }
       if ((label|0) == 93) {
        $212 = (_llvm_eh_typeid_for((348288|0))|0);
        $213 = ($lpad$phi48$index14|0)==($212|0);
        if (!($213)) {
         $$02 = $lpad$phi48$index;$$03 = $lpad$phi48$index14;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$02|0);
         // unreachable;
        }
        $214 = (___cxa_begin_catch(($lpad$phi48$index|0))|0);
        $215 = HEAP32[$214>>2]|0;
        __THREW__ = 0;
        invoke_v(66);
        $216 = __THREW__; __THREW__ = 0;
        $217 = $216&1;
        if ($217) {
         label = 7;
         break L1;
        }
        $V_0$14 = $V_0$10;$__last_unhandled_exception$0 = $215;$leaveInstructions$sroa$0$0 = 0;
       }
       ;HEAP32[$L_79+0>>2]=HEAP32[$V_7+0>>2]|0;HEAP32[$L_79+4>>2]=HEAP32[$V_7+4>>2]|0;HEAP32[$L_79+8>>2]=HEAP32[$V_7+8>>2]|0;HEAP32[$L_79+12>>2]=HEAP32[$V_7+12>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(1314144|0))|0);
       $242 = __THREW__; __THREW__ = 0;
       $243 = $242&1;
       if ($243) {
        label = 7;
        break L1;
       }
       __THREW__ = 0;
       $244 = (invoke_iii(2724,(1314144|0),($L_79|0))|0);
       $245 = __THREW__; __THREW__ = 0;
       $246 = $245&1;
       if ($246) {
        label = 7;
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($244|0));
       $247 = __THREW__; __THREW__ = 0;
       $248 = $247&1;
       if ($248) {
        label = 7;
        break L1;
       }
       __THREW__ = 0;
       invoke_vii(3491,(2176768|0),($244|0));
       $249 = __THREW__; __THREW__ = 0;
       $250 = $249&1;
       if ($250) {
        label = 7;
        break L1;
       }
       $cond1 = ($leaveInstructions$sroa$0$0|0)==(730);
       if (!($cond1)) {
        __THREW__ = 0;
        invoke_vi(3801,($__last_unhandled_exception$0|0));
        $251 = __THREW__; __THREW__ = 0;
        $252 = $251&1;
        if ($252) {
         label = 7;
         break L1;
        }
        // unreachable;
       }
       if ($pretty) {
        __THREW__ = 0;
        invoke_vi(3799,($V_0$14|0));
        $253 = __THREW__; __THREW__ = 0;
        $254 = $253&1;
        if ($254) {
         label = 7;
         break L1;
        }
        __THREW__ = 0;
        $255 = (invoke_ii(1816,($V_0$14|0))|0);
        $256 = __THREW__; __THREW__ = 0;
        $257 = $256&1;
        if ($257) {
         label = 7;
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($V_0$14|0));
        $258 = __THREW__; __THREW__ = 0;
        $259 = $258&1;
        if ($259) {
         label = 7;
         break L1;
        }
        $260 = (($255) + -1)|0;
        __THREW__ = 0;
        $261 = (invoke_iiii(528,($V_0$14|0),0,($260|0))|0);
        $262 = __THREW__; __THREW__ = 0;
        $263 = $262&1;
        if ($263) {
         label = 7;
         break L1;
        } else {
         $V_0$15 = $261;
        }
       } else {
        $V_0$15 = $V_0$14;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_0$15|0));
       $264 = __THREW__; __THREW__ = 0;
       $265 = $264&1;
       if ($265) {
        label = 7;
        break L1;
       }
       __THREW__ = 0;
       $266 = (invoke_ii(1816,($V_0$15|0))|0);
       $267 = __THREW__; __THREW__ = 0;
       $268 = $267&1;
       if ($268) {
        label = 7;
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_0$15|0));
       $269 = __THREW__; __THREW__ = 0;
       $270 = $269&1;
       if ($270) {
        label = 7;
        break L1;
       }
       $271 = (($266) + -1)|0;
       __THREW__ = 0;
       $272 = (invoke_iiii(528,($V_0$15|0),0,($271|0))|0);
       $273 = __THREW__; __THREW__ = 0;
       $274 = $273&1;
       if ($274) {
        label = 7;
        break L1;
       } else {
        $V_0$16 = $272;
       }
      }
      L158: do {
       if ($pretty) {
        $275 = HEAP32[$185>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($275|0));
        $276 = __THREW__; __THREW__ = 0;
        $277 = $276&1;
        if ($277) {
         label = 7;
         break L1;
        }
        __THREW__ = 0;
        $278 = (invoke_iii(2729,(1325496|0),($275|0))|0);
        $279 = __THREW__; __THREW__ = 0;
        $280 = $279&1;
        if ($280) {
         label = 7;
         break L1;
        }
        $281 = ($278|0)<(1);
        if ($281) {
         $V_0$18 = $V_0$16;
        } else {
         $282 = HEAP32[2991544>>2]|0;
         __THREW__ = 0;
         $283 = (invoke_iiii(562,(0|0),($V_0$16|0),($282|0))|0);
         $284 = __THREW__; __THREW__ = 0;
         $285 = $284&1;
         if ($285) {
          label = 7;
          break L1;
         }
         $286 = ($depth|0)>(0);
         if ($286) {
          $V_0$1740 = $283;$V_9$039 = 0;
          while(1) {
           $289 = HEAP32[2991552>>2]|0;
           __THREW__ = 0;
           $290 = (invoke_iiii(562,(0|0),($V_0$1740|0),($289|0))|0);
           $291 = __THREW__; __THREW__ = 0;
           $292 = $291&1;
           if ($292) {
            break;
           }
           $287 = (($V_9$039) + 1)|0;
           $288 = ($287|0)<($depth|0);
           if ($288) {
            $V_0$1740 = $290;$V_9$039 = $287;
           } else {
            $V_0$18 = $290;
            break L158;
           }
          }
          $10 = ___cxa_find_matching_catch()|0;
          $11 = tempRet0;
          $lpad$phi$index = $10;$lpad$phi$index5 = $11;
          break L1;
         } else {
          $V_0$18 = $283;
         }
        }
       } else {
        $V_0$18 = $V_0$16;
       }
      } while(0);
      $293 = HEAP32[2991560>>2]|0;
      __THREW__ = 0;
      $294 = (invoke_iiii(562,(0|0),($V_0$18|0),($293|0))|0);
      $295 = __THREW__; __THREW__ = 0;
      $296 = $295&1;
      if ($296) {
       label = 7;
       break L1;
      } else {
       $$0 = $294;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
      break;
     }
     case 0:  {
      $302 = HEAP32[2991584>>2]|0;
      $$0 = $302;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
      break;
     }
     case 5:  {
      $297 = (($__this) + 32|0);
      $298 = HEAP8[$297>>0]|0;
      $299 = ($298<<24>>24)==(0);
      if ($299) {
       $301 = HEAP32[2991576>>2]|0;
       $$0 = $301;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      } else {
       $300 = HEAP32[2991568>>2]|0;
       $$0 = $300;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      break;
     }
     default: {
      $$0 = $44;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index5 = $13;
 }
 $$02 = $lpad$phi$index;$$03 = $lpad$phi$index5;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN18VirtActionInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPviS5_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z116AssemblyU002DCSharp_JSONObject_m_set_Item_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringS0_($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278736);
 __THREW__ = 0;
 invoke_viii(266,($__this|0),($index|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z64AssemblyU002DCSharp_JSONObject_m_ToString_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278784);
 __THREW__ = 0;
 $0 = (invoke_iii(240,($__this|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z88AssemblyU002DCSharp_JSONObject_m_ToString_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectb($__this,$pretty) {
 $__this = $__this|0;
 $pretty = $pretty|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278832);
 __THREW__ = 0;
 $0 = (invoke_iii(240,($__this|0),($pretty|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z45AssemblyU002DCSharp_JSONObject_m_ToDictionaryP30AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $L_15 = 0, $L_22 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_15 = sp;
 $L_22 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278880);
 __THREW__ = 0;
 invoke_v(288);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(3);
   if (!($4)) {
    $137 = HEAP32[2991720>>2]|0;
    __THREW__ = 0;
    invoke_vii(2111,(0|0),($137|0));
    $138 = __THREW__; __THREW__ = 0;
    $139 = $138&1;
    if ($139) {
     break;
    } else {
     $$0 = 0;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1339880|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(1339880|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3804,($11|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = (($__this) + 16|0);
      $17 = (($__this) + 20|0);
      $V_1$0 = 0;
      L10: while(1) {
       $128 = HEAP32[$16>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($128|0));
       $129 = __THREW__; __THREW__ = 0;
       $130 = $129&1;
       if ($130) {
        break;
       }
       __THREW__ = 0;
       $131 = (invoke_iii(2729,(1325496|0),($128|0))|0);
       $132 = __THREW__; __THREW__ = 0;
       $133 = $132&1;
       if ($133) {
        break;
       }
       $134 = ($V_1$0|0)<($131|0);
       if (!($134)) {
        $$0 = $11;
        label = 57;
        break;
       }
       $18 = HEAP32[$16>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($18|0));
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if ($136) {
        break;
       }
       __THREW__ = 0;
       $19 = (invoke_iiii(1642,(1325560|0),($18|0),($V_1$0|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($19|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       $24 = (($19) + 12|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (($25) + -1)|0;
       do {
        if ((($25|0) == 1)) {
         $30 = HEAP32[$17>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($30|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break L10;
         }
         __THREW__ = 0;
         $33 = (invoke_iiii(1642,(1332456|0),($30|0),($V_1$0|0))|0);
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          break L10;
         }
         __THREW__ = 0;
         invoke_vi(3799,($19|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break L10;
         }
         $38 = (($19) + 24|0);
         $39 = HEAP32[$38>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($11|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L10;
         }
         __THREW__ = 0;
         invoke_viiii(460,(1335872|0),($11|0),($33|0),($39|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break L10;
         }
        } else if ((($25|0) == 2)) {
         $44 = HEAP32[$17>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($44|0));
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          break L10;
         }
         __THREW__ = 0;
         $47 = (invoke_iiii(1642,(1332456|0),($44|0),($V_1$0|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          break L10;
         }
         __THREW__ = 0;
         invoke_vi(3799,($19|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          break L10;
         }
         $52 = (($19) + 28|0);
         $53 = Math_fround(HEAPF32[$52>>2]);
         HEAPF32[$L_15>>2] = $53;
         __THREW__ = 0;
         (invoke_ii(2996,(2194912|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break L10;
         }
         __THREW__ = 0;
         $56 = (invoke_iii(2724,(2194912|0),($L_15|0))|0);
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break L10;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L10;
         }
         $61 = HEAP8[((2191608 + 116|0))>>0]|0;
         $62 = ($61<<24>>24)==(0);
         if ($62) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if ($64) {
           break L10;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           break L10;
          }
          __THREW__ = 0;
          invoke_vi(3802,(2191608|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           break L10;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          break L10;
         }
         $71 = HEAP32[((2191608 + 80|0))>>2]|0;
         $72 = HEAP32[$71>>2]|0;
         __THREW__ = 0;
         $73 = (invoke_iiii(559,(0|0),($56|0),($72|0))|0);
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          break L10;
         }
         __THREW__ = 0;
         invoke_vi(3799,($11|0));
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          break L10;
         }
         __THREW__ = 0;
         invoke_viiii(460,(1335872|0),($11|0),($47|0),($73|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          break L10;
         }
        } else {
         $27 = $26 & -2;
         $or$cond$not = ($27|0)!=(2);
         $28 = ($26|0)==(4);
         $or$cond3 = $or$cond$not & $28;
         $29 = HEAP32[$17>>2]|0;
         if (!($or$cond3)) {
          __THREW__ = 0;
          invoke_vi(3799,($29|0));
          $115 = __THREW__; __THREW__ = 0;
          $116 = $115&1;
          if ($116) {
           break L10;
          }
          __THREW__ = 0;
          $117 = (invoke_iiii(1642,(1332456|0),($29|0),($V_1$0|0))|0);
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          if ($119) {
           break L10;
          }
          $120 = HEAP32[2991704>>2]|0;
          $121 = HEAP32[2991712>>2]|0;
          __THREW__ = 0;
          $122 = (invoke_iiiii(101,(0|0),($120|0),($117|0),($121|0))|0);
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if ($124) {
           break L10;
          }
          __THREW__ = 0;
          invoke_vii(2111,(0|0),($122|0));
          $125 = __THREW__; __THREW__ = 0;
          $126 = $125&1;
          if ($126) {
           break L10;
          } else {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($29|0));
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if ($81) {
          break L10;
         }
         __THREW__ = 0;
         $82 = (invoke_iiii(1642,(1332456|0),($29|0),($V_1$0|0))|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break L10;
         }
         __THREW__ = 0;
         invoke_vi(3799,($19|0));
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          break L10;
         }
         $87 = (($19) + 32|0);
         $88 = HEAP8[$87>>0]|0;
         HEAP8[$L_22>>0] = $88;
         __THREW__ = 0;
         (invoke_ii(2996,(2208584|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          break L10;
         }
         __THREW__ = 0;
         $91 = (invoke_iii(2724,(2208584|0),($L_22|0))|0);
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          break L10;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break L10;
         }
         $96 = HEAP8[((2191608 + 116|0))>>0]|0;
         $97 = ($96<<24>>24)==(0);
         if ($97) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break L10;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break L10;
          }
          __THREW__ = 0;
          invoke_vi(3802,(2191608|0));
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           break L10;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          break L10;
         }
         $106 = HEAP32[((2191608 + 80|0))>>2]|0;
         $107 = HEAP32[$106>>2]|0;
         __THREW__ = 0;
         $108 = (invoke_iiii(559,(0|0),($91|0),($107|0))|0);
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          break L10;
         }
         __THREW__ = 0;
         invoke_vi(3799,($11|0));
         $111 = __THREW__; __THREW__ = 0;
         $112 = $111&1;
         if ($112) {
          break L10;
         }
         __THREW__ = 0;
         invoke_viiii(460,(1335872|0),($11|0),($82|0),($108|0));
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          break L10;
         }
        }
       } while(0);
       $127 = (($V_1$0) + 1)|0;
       $V_1$0 = $127;
      }
      if ((label|0) == 57) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $5 = ___cxa_find_matching_catch()|0;
      $6 = tempRet0;
      $lpad$phi$index = $5;$lpad$phi$index2 = $6;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN18VirtActionInvoker2I17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS4_S4_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z107AssemblyU002DCSharp_JSONObject_m_op_Implicit_UnityEngine_UnityEngine_WWWForm_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_2 = 0, $V_1$0 = 0, $V_2$0 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1278928);
 __THREW__ = 0;
 invoke_v(289);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2814216|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2814216|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3081,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($obj) + 16|0);
     $10 = (($obj) + 12|0);
     $11 = (($obj) + 20|0);
     $V_1$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       break;
      }
      $101 = HEAP32[$9>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($101|0));
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       break;
      }
      __THREW__ = 0;
      $104 = (invoke_iii(2729,(1325496|0),($101|0))|0);
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       break;
      }
      $107 = ($V_1$0|0)<($104|0);
      if (!($107)) {
       label = 49;
       break;
      }
      HEAP32[$L_2>>2] = $V_1$0;
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       break;
      }
      __THREW__ = 0;
      $16 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP8[((2191608 + 116|0))>>0]|0;
      $22 = ($21<<24>>24)==(0);
      if ($22) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3802,(2191608|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = HEAP32[((2191608 + 80|0))>>2]|0;
      $32 = HEAP32[$31>>2]|0;
      __THREW__ = 0;
      $33 = (invoke_iiii(559,(0|0),($16|0),($32|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$10>>2]|0;
      $39 = ($38|0)==(3);
      if ($39) {
       __THREW__ = 0;
       invoke_vi(3799,($obj|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       $42 = HEAP32[$11>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       __THREW__ = 0;
       $45 = (invoke_iiii(1642,(1332456|0),($42|0),($V_1$0|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       $V_2$0 = $45;
      } else {
       $V_2$0 = $33;
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      $50 = HEAP32[$9>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($50|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      __THREW__ = 0;
      $53 = (invoke_iiii(1642,(1325560|0),($50|0),($V_1$0|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($53|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2730,(1278784|0),($53|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      $63 = HEAP32[$9>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      __THREW__ = 0;
      $66 = (invoke_iiii(1642,(1325560|0),($63|0),($V_1$0|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($66|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       break;
      }
      $71 = (($66) + 12|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = ($72|0)==(1);
      if ($73) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       $76 = HEAP8[((2191608 + 116|0))>>0]|0;
       $77 = ($76<<24>>24)==(0);
       if ($77) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3802,(2191608|0));
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       $86 = HEAP32[((2191608 + 80|0))>>2]|0;
       $87 = HEAP32[$86>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($58|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       $90 = HEAP32[2991944>>2]|0;
       __THREW__ = 0;
       $91 = (invoke_iiii(548,($58|0),($90|0),($87|0))|0);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        break;
       } else {
        $V_3$0 = $91;
       }
      } else {
       $V_3$0 = $58;
      }
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(769,($4|0),($V_2$0|0),($V_3$0|0));
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       break;
      }
      $98 = (($V_1$0) + 1)|0;
      $V_1$0 = $98;
     }
     if ((label|0) == 49) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($4|0);
     }
     $12 = ___cxa_find_matching_catch()|0;
     $13 = tempRet0;
     $lpad$phi$index = $12;$lpad$phi$index2 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker0I17VoidPointerTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN14ActionInvoker1I27mscorlib_System_Int32TraitsE6InvokeEPFvPviES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$1);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker1I29mscorlib_System_BooleanTraitsE6InvokeEPFvPvbES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 FUNCTION_TABLE_vii[$action & 4095]($obj,$2);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker1I28mscorlib_System_SingleTraitsE6InvokeEPFvPvfES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 FUNCTION_TABLE_vif[$action & 255]($obj,$1);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS3_bES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$4);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker0I29mscorlib_System_BooleanTraitsE6InvokeEPFbPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 $1 = $0&1;
 HEAP8[$ret>>0] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker0I27mscorlib_System_Int32TraitsE6InvokeEPFiPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP32[$ret>>2] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker0I28mscorlib_System_SingleTraitsE6InvokeEPFfPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = Math_fround(0), $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (Math_fround(FUNCTION_TABLE_fi[$func & 255]($obj)));
 HEAPF32[$ret>>2] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker0I17VoidPointerTraitsE6InvokeEPFPvS2_ES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits28mscorlib_System_SingleTraitsE6InvokeEPFvPvS3_fES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$2>>2]);
 FUNCTION_TABLE_viif[$action & 63]($obj,$0,$3);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS3_iES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$3);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraitsS0_E6InvokeEPFvPvS2_S2_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$2);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S0_E6InvokeEPFbPvS3_S3_bES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$6)|0);
 $8 = $7&1;
 HEAP8[$ret>>0] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_E6InvokeEPFbPvS3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 $6 = $5&1;
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_28mscorlib_System_SingleTraitsE6InvokeEPFbPvS4_S4_fES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (FUNCTION_TABLE_iiiif[$func & 1]($obj,$0,$2,$5)|0);
 $7 = $6&1;
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEPFbPvS4_S4_iES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$5)|0);
 $7 = $6&1;
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_28mscorlib_System_UInt32TraitsE6InvokeEPFbPvS4_S4_jES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$5)|0);
 $7 = $6&1;
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN14ActionInvoker3I17VoidPointerTraitsS0_S0_E6InvokeEPFvPvS2_S2_S2_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$4);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits17VoidPointerTraitsE6InvokeEPFbPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEPFPvS3_bES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_ibES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFPvS3_iES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPFvPviS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$3);
 STACKTOP = sp;return (0|0);
}
function __Z61AssemblyU002DCSharp_JSONObject_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(1281088)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z42AssemblyU002DCSharp_JSONTemplates_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1281696);
 __THREW__ = 0;
 (invoke_ii(2996,(1392728|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1392728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3805,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1283616 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z42AssemblyU002DCSharp_JSONTemplates_m_TOJSONP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $$byval_copy10 = 0, $$sum = 0, $$sum20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0;
 var $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0;
 var $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0;
 var $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0;
 var $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0;
 var $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_11$0 = 0, $V_12$0 = 0, $V_4$0 = 0, $V_5$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 20|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1281744);
 __THREW__ = 0;
 invoke_v(290);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1283616|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = HEAP8[((1283616 + 116|0))>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3802,(1283616|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[((1283616 + 80|0))>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      $28 = (invoke_iii(2731,($25|0),($obj|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       if (!($28)) {
        $640 = HEAP32[2992024>>2]|0;
        __THREW__ = 0;
        invoke_vii(2111,(0|0),($640|0));
        $641 = __THREW__; __THREW__ = 0;
        $642 = $641&1;
        if ($642) {
         break;
        }
        __THREW__ = 0;
        $643 = (invoke_ii(723,0)|0);
        $644 = __THREW__; __THREW__ = 0;
        $645 = $644&1;
        if ($645) {
         break;
        } else {
         $$0 = $643;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       $31 = (invoke_ii(724,0)|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        __THREW__ = 0;
        invoke_vi(3799,($obj|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if (!($35)) {
         __THREW__ = 0;
         $36 = (invoke_ii(1782,($obj|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if (!($38)) {
          __THREW__ = 0;
          invoke_vi(3799,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           __THREW__ = 0;
           $41 = (invoke_iii(2730,(2236144|0),($36|0))|0);
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if (!($43)) {
            $44 = (($41) + 12|0);
            $V_4$0 = 0;
            L22: while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($41|0));
             $331 = __THREW__; __THREW__ = 0;
             $332 = $331&1;
             if ($332) {
              label = 8;
              break;
             }
             $333 = HEAP32[$44>>2]|0;
             $334 = ($V_4$0|0)<($333|0);
             if (!($334)) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($41|0));
             $335 = __THREW__; __THREW__ = 0;
             $336 = $335&1;
             if ($336) {
              label = 8;
              break;
             }
             $45 = HEAP32[$44>>2]|0;
             $46 = ($V_4$0>>>0)<($45>>>0);
             if (!($46)) {
              __THREW__ = 0;
              $47 = (invoke_i(132)|0);
              $48 = __THREW__; __THREW__ = 0;
              $49 = $48&1;
              if ($49) {
               label = 8;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($47|0));
              $50 = __THREW__; __THREW__ = 0;
              $51 = $50&1;
              if ($51) {
               label = 8;
               break;
              }
             }
             $52 = HEAP32[$41>>2]|0;
             $53 = (($52) + 92|0);
             $54 = HEAP32[$53>>2]|0;
             $55 = Math_imul($54, $V_4$0)|0;
             $$sum20 = (($55) + 16)|0;
             $56 = (($41) + ($$sum20)|0);
             $57 = HEAP32[$56>>2]|0;
             __THREW__ = 0;
             $58 = (invoke_ii(723,0)|0);
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              label = 8;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($57|0));
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              label = 8;
              break;
             }
             __THREW__ = 0;
             $63 = (invoke_iiii(1643,(2406336|0),($57|0),($obj|0))|0);
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if ($65) {
              label = 8;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($63|0));
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if ($67) {
              label = 8;
              break;
             }
             __THREW__ = 0;
             $68 = (invoke_iiii(1644,(2148736|0),($63|0),(0|0))|0);
             $69 = __THREW__; __THREW__ = 0;
             $70 = $69&1;
             if ($70) {
              label = 8;
              break;
             }
             do {
              if ($68) {
               $V_5$0 = $58;
              } else {
               HEAP32[$0>>2] = 1284304;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
               $71 = (invoke_iii(772,(0|0),($$byval_copy10|0))|0);
               $72 = __THREW__; __THREW__ = 0;
               $73 = $72&1;
               if ($73) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($57|0));
               $74 = __THREW__; __THREW__ = 0;
               $75 = $74&1;
               if ($75) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $76 = (invoke_iii(2730,(2406256|0),($57|0))|0);
               $77 = __THREW__; __THREW__ = 0;
               $78 = $77&1;
               if ($78) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($76|0));
               $79 = __THREW__; __THREW__ = 0;
               $80 = $79&1;
               if ($80) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $81 = (invoke_iii(2730,(2233608|0),($76|0))|0);
               $82 = __THREW__; __THREW__ = 0;
               $83 = $82&1;
               if ($83) {
                label = 8;
                break L22;
               }
               $84 = HEAP32[2991960>>2]|0;
               __THREW__ = 0;
               $85 = (invoke_iiii(562,(0|0),($84|0),($81|0))|0);
               $86 = __THREW__; __THREW__ = 0;
               $87 = $86&1;
               if ($87) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($71|0));
               $88 = __THREW__; __THREW__ = 0;
               $89 = $88&1;
               if ($89) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $90 = (invoke_iiii(1645,(2236288|0),($71|0),($85|0))|0);
               $91 = __THREW__; __THREW__ = 0;
               $92 = $91&1;
               if ($92) {
                label = 8;
                break L22;
               }
               $93 = ($90|0)==(0|0);
               if (!($93)) {
                __THREW__ = 0;
                (invoke_ii(2996,(1167664|0))|0);
                $94 = __THREW__; __THREW__ = 0;
                $95 = $94&1;
                if ($95) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                $96 = (invoke_iii(2723,(1167664|0),1)|0);
                $97 = __THREW__; __THREW__ = 0;
                $98 = $97&1;
                if ($98) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3799,($57|0));
                $99 = __THREW__; __THREW__ = 0;
                $100 = $99&1;
                if ($100) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                $101 = (invoke_iiii(1643,(2406336|0),($57|0),($obj|0))|0);
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3799,($96|0));
                $104 = __THREW__; __THREW__ = 0;
                $105 = $104&1;
                if ($105) {
                 label = 8;
                 break L22;
                }
                $106 = (($96) + 12|0);
                $107 = HEAP32[$106>>2]|0;
                $108 = ($107|0)==(0);
                if ($108) {
                 __THREW__ = 0;
                 $109 = (invoke_i(132)|0);
                 $110 = __THREW__; __THREW__ = 0;
                 $111 = $110&1;
                 if ($111) {
                  label = 8;
                  break L22;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($109|0));
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  label = 8;
                  break L22;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($96|0),($101|0));
                $114 = __THREW__; __THREW__ = 0;
                $115 = $114&1;
                if ($115) {
                 label = 8;
                 break L22;
                }
                $116 = (($96) + 16|0);
                HEAP32[$116>>2] = $101;
                __THREW__ = 0;
                invoke_vi(3799,($90|0));
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                $119 = (invoke_iiiii(298,(2410080|0),($90|0),(0|0),($96|0))|0);
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1281560|0))|0);
                $122 = __THREW__; __THREW__ = 0;
                $123 = $122&1;
                if ($123) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                $124 = (invoke_iii(2725,($119|0),(1281560|0))|0);
                $125 = __THREW__; __THREW__ = 0;
                $126 = $125&1;
                if ($126) {
                 label = 8;
                 break L22;
                }
                $V_5$0 = $124;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($57|0));
               $127 = __THREW__; __THREW__ = 0;
               $128 = $127&1;
               if ($128) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $129 = (invoke_iii(2730,(2406256|0),($57|0))|0);
               $130 = __THREW__; __THREW__ = 0;
               $131 = $130&1;
               if ($131) {
                label = 8;
                break L22;
               }
               HEAP32[$1>>2] = 1284472;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
               $132 = (invoke_iii(772,(0|0),($$byval_copy10|0))|0);
               $133 = __THREW__; __THREW__ = 0;
               $134 = $133&1;
               if ($134) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($129|0));
               $135 = __THREW__; __THREW__ = 0;
               $136 = $135&1;
               if ($136) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $137 = (invoke_iiii(1640,(2223400|0),($129|0),($132|0))|0);
               $138 = __THREW__; __THREW__ = 0;
               $139 = $138&1;
               if ($139) {
                label = 8;
                break L22;
               }
               if (!($137)) {
                __THREW__ = 0;
                invoke_vi(3799,($57|0));
                $163 = __THREW__; __THREW__ = 0;
                $164 = $163&1;
                if ($164) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                $165 = (invoke_iiii(1643,(2406336|0),($57|0),($obj|0))|0);
                $166 = __THREW__; __THREW__ = 0;
                $167 = $166&1;
                if ($167) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3799,($165|0));
                $168 = __THREW__; __THREW__ = 0;
                $169 = $168&1;
                if ($169) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                $170 = (invoke_iii(2730,(2149112|0),($165|0))|0);
                $171 = __THREW__; __THREW__ = 0;
                $172 = $171&1;
                if ($172) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1281560|0))|0);
                $173 = __THREW__; __THREW__ = 0;
                $174 = $173&1;
                if ($174) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                $175 = (invoke_ii(3469,(1281560|0))|0);
                $176 = __THREW__; __THREW__ = 0;
                $177 = $176&1;
                if ($177) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_viii(258,($175|0),($170|0),0);
                $178 = __THREW__; __THREW__ = 0;
                $179 = $178&1;
                if ($179) {
                 label = 8;
                 break L22;
                } else {
                 $V_5$0 = $175;
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(1281560|0))|0);
               $140 = __THREW__; __THREW__ = 0;
               $141 = $140&1;
               if ($141) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $142 = (invoke_ii(3469,(1281560|0))|0);
               $143 = __THREW__; __THREW__ = 0;
               $144 = $143&1;
               if ($144) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(1406,($142|0));
               $145 = __THREW__; __THREW__ = 0;
               $146 = $145&1;
               if ($146) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($142|0));
               $147 = __THREW__; __THREW__ = 0;
               $148 = $147&1;
               if ($148) {
                label = 8;
                break L22;
               }
               $149 = (($142) + 12|0);
               HEAP32[$149>>2] = (1);
               __THREW__ = 0;
               invoke_vi(3799,($57|0));
               $150 = __THREW__; __THREW__ = 0;
               $151 = $150&1;
               if ($151) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $152 = (invoke_iiii(1643,(2406336|0),($57|0),($obj|0))|0);
               $153 = __THREW__; __THREW__ = 0;
               $154 = $153&1;
               if ($154) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($152|0));
               $155 = __THREW__; __THREW__ = 0;
               $156 = $155&1;
               if ($156) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $157 = (invoke_iii(2730,(2149112|0),($152|0))|0);
               $158 = __THREW__; __THREW__ = 0;
               $159 = $158&1;
               if ($159) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($142|0));
               $160 = __THREW__; __THREW__ = 0;
               $161 = $160&1;
               if ($161) {
                label = 8;
                break L22;
               }
               $162 = (($142) + 24|0);
               HEAP32[$162>>2] = $157;
               $V_5$0 = $142;
              }
             } while(0);
             __THREW__ = 0;
             $180 = (invoke_iii(245,0,($V_5$0|0))|0);
             $181 = __THREW__; __THREW__ = 0;
             $182 = $181&1;
             if ($182) {
              label = 8;
              break;
             }
             do {
              if ($180) {
               __THREW__ = 0;
               invoke_vi(3799,($V_5$0|0));
               $183 = __THREW__; __THREW__ = 0;
               $184 = $183&1;
               if ($184) {
                label = 8;
                break L22;
               }
               $185 = (($V_5$0) + 12|0);
               $186 = HEAP32[$185>>2]|0;
               $187 = ($186|0)==(0);
               if (!($187)) {
                __THREW__ = 0;
                invoke_vi(3799,($57|0));
                $188 = __THREW__; __THREW__ = 0;
                $189 = $188&1;
                if ($189) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                $190 = (invoke_iii(2730,(2233608|0),($57|0))|0);
                $191 = __THREW__; __THREW__ = 0;
                $192 = $191&1;
                if ($192) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3799,($31|0));
                $193 = __THREW__; __THREW__ = 0;
                $194 = $193&1;
                if ($194) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_viii(263,($31|0),($190|0),($V_5$0|0));
                $195 = __THREW__; __THREW__ = 0;
                $196 = $195&1;
                if ($196) {
                 label = 8;
                 break L22;
                } else {
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(1168432|0))|0);
               $197 = __THREW__; __THREW__ = 0;
               $198 = $197&1;
               if ($198) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $199 = (invoke_iii(2723,(1168432|0),6)|0);
               $200 = __THREW__; __THREW__ = 0;
               $201 = $200&1;
               if ($201) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($199|0));
               $202 = __THREW__; __THREW__ = 0;
               $203 = $202&1;
               if ($203) {
                label = 8;
                break L22;
               }
               $204 = (($199) + 12|0);
               $205 = HEAP32[$204>>2]|0;
               $206 = ($205|0)==(0);
               if ($206) {
                __THREW__ = 0;
                $207 = (invoke_i(132)|0);
                $208 = __THREW__; __THREW__ = 0;
                $209 = $208&1;
                if ($209) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3302,($207|0));
                $210 = __THREW__; __THREW__ = 0;
                $211 = $210&1;
                if ($211) {
                 label = 8;
                 break L22;
                }
               }
               $212 = HEAP32[2991968>>2]|0;
               __THREW__ = 0;
               invoke_vii(3492,($199|0),($212|0));
               $213 = __THREW__; __THREW__ = 0;
               $214 = $213&1;
               if ($214) {
                label = 8;
                break L22;
               }
               $215 = HEAP32[2991968>>2]|0;
               $216 = (($199) + 16|0);
               HEAP32[$216>>2] = $215;
               __THREW__ = 0;
               invoke_vi(3799,($57|0));
               $217 = __THREW__; __THREW__ = 0;
               $218 = $217&1;
               if ($218) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $219 = (invoke_iii(2730,(2233608|0),($57|0))|0);
               $220 = __THREW__; __THREW__ = 0;
               $221 = $220&1;
               if ($221) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($199|0));
               $222 = __THREW__; __THREW__ = 0;
               $223 = $222&1;
               if ($223) {
                label = 8;
                break L22;
               }
               $224 = HEAP32[$204>>2]|0;
               $225 = ($224>>>0)<(2);
               if ($225) {
                __THREW__ = 0;
                $226 = (invoke_i(132)|0);
                $227 = __THREW__; __THREW__ = 0;
                $228 = $227&1;
                if ($228) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3302,($226|0));
                $229 = __THREW__; __THREW__ = 0;
                $230 = $229&1;
                if ($230) {
                 label = 8;
                 break L22;
                }
               }
               __THREW__ = 0;
               invoke_vii(3492,($199|0),($219|0));
               $231 = __THREW__; __THREW__ = 0;
               $232 = $231&1;
               if ($232) {
                label = 8;
                break L22;
               }
               $233 = HEAP32[$199>>2]|0;
               $234 = (($233) + 92|0);
               $235 = HEAP32[$234>>2]|0;
               $236 = (($216) + ($235)|0);
               HEAP32[$236>>2] = $219;
               __THREW__ = 0;
               invoke_vi(3799,($199|0));
               $237 = __THREW__; __THREW__ = 0;
               $238 = $237&1;
               if ($238) {
                label = 8;
                break L22;
               }
               $239 = HEAP32[$204>>2]|0;
               $240 = ($239>>>0)<(3);
               if ($240) {
                __THREW__ = 0;
                $241 = (invoke_i(132)|0);
                $242 = __THREW__; __THREW__ = 0;
                $243 = $242&1;
                if ($243) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3302,($241|0));
                $244 = __THREW__; __THREW__ = 0;
                $245 = $244&1;
                if ($245) {
                 label = 8;
                 break L22;
                }
               }
               $246 = HEAP32[2991976>>2]|0;
               __THREW__ = 0;
               invoke_vii(3492,($199|0),($246|0));
               $247 = __THREW__; __THREW__ = 0;
               $248 = $247&1;
               if ($248) {
                label = 8;
                break L22;
               }
               $249 = HEAP32[2991976>>2]|0;
               $250 = HEAP32[$199>>2]|0;
               $251 = (($250) + 92|0);
               $252 = HEAP32[$251>>2]|0;
               $253 = $252 << 1;
               $254 = (($216) + ($253)|0);
               HEAP32[$254>>2] = $249;
               __THREW__ = 0;
               invoke_vi(3799,($obj|0));
               $255 = __THREW__; __THREW__ = 0;
               $256 = $255&1;
               if ($256) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $257 = (invoke_ii(1782,($obj|0))|0);
               $258 = __THREW__; __THREW__ = 0;
               $259 = $258&1;
               if ($259) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($257|0));
               $260 = __THREW__; __THREW__ = 0;
               $261 = $260&1;
               if ($261) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $262 = (invoke_iii(2730,(2233608|0),($257|0))|0);
               $263 = __THREW__; __THREW__ = 0;
               $264 = $263&1;
               if ($264) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($199|0));
               $265 = __THREW__; __THREW__ = 0;
               $266 = $265&1;
               if ($266) {
                label = 8;
                break L22;
               }
               $267 = HEAP32[$204>>2]|0;
               $268 = ($267>>>0)<(4);
               if ($268) {
                __THREW__ = 0;
                $269 = (invoke_i(132)|0);
                $270 = __THREW__; __THREW__ = 0;
                $271 = $270&1;
                if ($271) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3302,($269|0));
                $272 = __THREW__; __THREW__ = 0;
                $273 = $272&1;
                if ($273) {
                 label = 8;
                 break L22;
                }
               }
               __THREW__ = 0;
               invoke_vii(3492,($199|0),($262|0));
               $274 = __THREW__; __THREW__ = 0;
               $275 = $274&1;
               if ($275) {
                label = 8;
                break L22;
               }
               $276 = HEAP32[$199>>2]|0;
               $277 = (($276) + 92|0);
               $278 = HEAP32[$277>>2]|0;
               $279 = ($278*3)|0;
               $280 = (($216) + ($279)|0);
               HEAP32[$280>>2] = $262;
               __THREW__ = 0;
               invoke_vi(3799,($199|0));
               $281 = __THREW__; __THREW__ = 0;
               $282 = $281&1;
               if ($282) {
                label = 8;
                break L22;
               }
               $283 = HEAP32[$204>>2]|0;
               $284 = ($283>>>0)<(5);
               if ($284) {
                __THREW__ = 0;
                $285 = (invoke_i(132)|0);
                $286 = __THREW__; __THREW__ = 0;
                $287 = $286&1;
                if ($287) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3302,($285|0));
                $288 = __THREW__; __THREW__ = 0;
                $289 = $288&1;
                if ($289) {
                 label = 8;
                 break L22;
                }
               }
               $290 = HEAP32[2991984>>2]|0;
               __THREW__ = 0;
               invoke_vii(3492,($199|0),($290|0));
               $291 = __THREW__; __THREW__ = 0;
               $292 = $291&1;
               if ($292) {
                label = 8;
                break L22;
               }
               $293 = HEAP32[2991984>>2]|0;
               $294 = HEAP32[$199>>2]|0;
               $295 = (($294) + 92|0);
               $296 = HEAP32[$295>>2]|0;
               $297 = $296 << 2;
               $298 = (($216) + ($297)|0);
               HEAP32[$298>>2] = $293;
               __THREW__ = 0;
               invoke_vi(3799,($57|0));
               $299 = __THREW__; __THREW__ = 0;
               $300 = $299&1;
               if ($300) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $301 = (invoke_iii(2730,(2406256|0),($57|0))|0);
               $302 = __THREW__; __THREW__ = 0;
               $303 = $302&1;
               if ($303) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($301|0));
               $304 = __THREW__; __THREW__ = 0;
               $305 = $304&1;
               if ($305) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               $306 = (invoke_iii(2730,(2233608|0),($301|0))|0);
               $307 = __THREW__; __THREW__ = 0;
               $308 = $307&1;
               if ($308) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vi(3799,($199|0));
               $309 = __THREW__; __THREW__ = 0;
               $310 = $309&1;
               if ($310) {
                label = 8;
                break L22;
               }
               $311 = HEAP32[$204>>2]|0;
               $312 = ($311>>>0)<(6);
               if ($312) {
                __THREW__ = 0;
                $313 = (invoke_i(132)|0);
                $314 = __THREW__; __THREW__ = 0;
                $315 = $314&1;
                if ($315) {
                 label = 8;
                 break L22;
                }
                __THREW__ = 0;
                invoke_vi(3302,($313|0));
                $316 = __THREW__; __THREW__ = 0;
                $317 = $316&1;
                if ($317) {
                 label = 8;
                 break L22;
                }
               }
               __THREW__ = 0;
               invoke_vii(3492,($199|0),($306|0));
               $318 = __THREW__; __THREW__ = 0;
               $319 = $318&1;
               if ($319) {
                label = 8;
                break L22;
               }
               $320 = HEAP32[$199>>2]|0;
               $321 = (($320) + 92|0);
               $322 = HEAP32[$321>>2]|0;
               $323 = ($322*5)|0;
               $324 = (($216) + ($323)|0);
               HEAP32[$324>>2] = $306;
               __THREW__ = 0;
               $325 = (invoke_iii(639,(0|0),($199|0))|0);
               $326 = __THREW__; __THREW__ = 0;
               $327 = $326&1;
               if ($327) {
                label = 8;
                break L22;
               }
               __THREW__ = 0;
               invoke_vii(2111,(0|0),($325|0));
               $328 = __THREW__; __THREW__ = 0;
               $329 = $328&1;
               if ($329) {
                label = 8;
                break L22;
               }
              }
             } while(0);
             $330 = (($V_4$0) + 1)|0;
             $V_4$0 = $330;
            }
            if ((label|0) == 8) {
             $18 = ___cxa_find_matching_catch()|0;
             $19 = tempRet0;
             $lpad$phi$index = $18;$lpad$phi$index3 = $19;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($obj|0));
            $337 = __THREW__; __THREW__ = 0;
            $338 = $337&1;
            if (!($338)) {
             __THREW__ = 0;
             $339 = (invoke_ii(1782,($obj|0))|0);
             $340 = __THREW__; __THREW__ = 0;
             $341 = $340&1;
             if (!($341)) {
              __THREW__ = 0;
              invoke_vi(3799,($339|0));
              $342 = __THREW__; __THREW__ = 0;
              $343 = $342&1;
              if (!($343)) {
               __THREW__ = 0;
               $344 = (invoke_iii(2730,(2236528|0),($339|0))|0);
               $345 = __THREW__; __THREW__ = 0;
               $346 = $345&1;
               if (!($346)) {
                $347 = (($344) + 12|0);
                $V_11$0 = 0;
                L155: while(1) {
                 __THREW__ = 0;
                 invoke_vi(3799,($344|0));
                 $634 = __THREW__; __THREW__ = 0;
                 $635 = $634&1;
                 if ($635) {
                  break;
                 }
                 $636 = HEAP32[$347>>2]|0;
                 $637 = ($V_11$0|0)<($636|0);
                 if (!($637)) {
                  $$0 = $31;
                  label = 250;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($344|0));
                 $638 = __THREW__; __THREW__ = 0;
                 $639 = $638&1;
                 if ($639) {
                  break;
                 }
                 $348 = HEAP32[$347>>2]|0;
                 $349 = ($V_11$0>>>0)<($348>>>0);
                 if (!($349)) {
                  __THREW__ = 0;
                  $350 = (invoke_i(132)|0);
                  $351 = __THREW__; __THREW__ = 0;
                  $352 = $351&1;
                  if ($352) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($350|0));
                  $353 = __THREW__; __THREW__ = 0;
                  $354 = $353&1;
                  if ($354) {
                   break;
                  }
                 }
                 $355 = HEAP32[$344>>2]|0;
                 $356 = (($355) + 92|0);
                 $357 = HEAP32[$356>>2]|0;
                 $358 = Math_imul($357, $V_11$0)|0;
                 $$sum = (($358) + 16)|0;
                 $359 = (($344) + ($$sum)|0);
                 $360 = HEAP32[$359>>2]|0;
                 __THREW__ = 0;
                 $361 = (invoke_ii(723,0)|0);
                 $362 = __THREW__; __THREW__ = 0;
                 $363 = $362&1;
                 if ($363) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($360|0));
                 $364 = __THREW__; __THREW__ = 0;
                 $365 = $364&1;
                 if ($365) {
                  break;
                 }
                 __THREW__ = 0;
                 $366 = (invoke_iiiii(298,(2434128|0),($360|0),($obj|0),(0|0))|0);
                 $367 = __THREW__; __THREW__ = 0;
                 $368 = $367&1;
                 if ($368) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($366|0));
                 $369 = __THREW__; __THREW__ = 0;
                 $370 = $369&1;
                 if ($370) {
                  break;
                 }
                 __THREW__ = 0;
                 $371 = (invoke_iiii(1644,(2148736|0),($366|0),(0|0))|0);
                 $372 = __THREW__; __THREW__ = 0;
                 $373 = $372&1;
                 if ($373) {
                  break;
                 }
                 do {
                  if ($371) {
                   $V_12$0 = $361;
                  } else {
                   HEAP32[$2>>2] = 1284304;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
                   $374 = (invoke_iii(772,(0|0),($$byval_copy10|0))|0);
                   $375 = __THREW__; __THREW__ = 0;
                   $376 = $375&1;
                   if ($376) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($360|0));
                   $377 = __THREW__; __THREW__ = 0;
                   $378 = $377&1;
                   if ($378) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $379 = (invoke_iii(2730,(2397904|0),($360|0))|0);
                   $380 = __THREW__; __THREW__ = 0;
                   $381 = $380&1;
                   if ($381) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($379|0));
                   $382 = __THREW__; __THREW__ = 0;
                   $383 = $382&1;
                   if ($383) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $384 = (invoke_iii(2730,(2233608|0),($379|0))|0);
                   $385 = __THREW__; __THREW__ = 0;
                   $386 = $385&1;
                   if ($386) {
                    break L155;
                   }
                   $387 = HEAP32[2991992>>2]|0;
                   __THREW__ = 0;
                   $388 = (invoke_iiii(562,(0|0),($387|0),($384|0))|0);
                   $389 = __THREW__; __THREW__ = 0;
                   $390 = $389&1;
                   if ($390) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($374|0));
                   $391 = __THREW__; __THREW__ = 0;
                   $392 = $391&1;
                   if ($392) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $393 = (invoke_iiii(1645,(2236288|0),($374|0),($388|0))|0);
                   $394 = __THREW__; __THREW__ = 0;
                   $395 = $394&1;
                   if ($395) {
                    break L155;
                   }
                   $396 = ($393|0)==(0|0);
                   if (!($396)) {
                    __THREW__ = 0;
                    (invoke_ii(2996,(1167664|0))|0);
                    $397 = __THREW__; __THREW__ = 0;
                    $398 = $397&1;
                    if ($398) {
                     break L155;
                    }
                    __THREW__ = 0;
                    $399 = (invoke_iii(2723,(1167664|0),1)|0);
                    $400 = __THREW__; __THREW__ = 0;
                    $401 = $400&1;
                    if ($401) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($360|0));
                    $402 = __THREW__; __THREW__ = 0;
                    $403 = $402&1;
                    if ($403) {
                     break L155;
                    }
                    __THREW__ = 0;
                    $404 = (invoke_iiiii(298,(2434128|0),($360|0),($obj|0),(0|0))|0);
                    $405 = __THREW__; __THREW__ = 0;
                    $406 = $405&1;
                    if ($406) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($399|0));
                    $407 = __THREW__; __THREW__ = 0;
                    $408 = $407&1;
                    if ($408) {
                     break L155;
                    }
                    $409 = (($399) + 12|0);
                    $410 = HEAP32[$409>>2]|0;
                    $411 = ($410|0)==(0);
                    if ($411) {
                     __THREW__ = 0;
                     $412 = (invoke_i(132)|0);
                     $413 = __THREW__; __THREW__ = 0;
                     $414 = $413&1;
                     if ($414) {
                      break L155;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($412|0));
                     $415 = __THREW__; __THREW__ = 0;
                     $416 = $415&1;
                     if ($416) {
                      break L155;
                     }
                    }
                    __THREW__ = 0;
                    invoke_vii(3492,($399|0),($404|0));
                    $417 = __THREW__; __THREW__ = 0;
                    $418 = $417&1;
                    if ($418) {
                     break L155;
                    }
                    $419 = (($399) + 16|0);
                    HEAP32[$419>>2] = $404;
                    __THREW__ = 0;
                    invoke_vi(3799,($393|0));
                    $420 = __THREW__; __THREW__ = 0;
                    $421 = $420&1;
                    if ($421) {
                     break L155;
                    }
                    __THREW__ = 0;
                    $422 = (invoke_iiiii(298,(2410080|0),($393|0),(0|0),($399|0))|0);
                    $423 = __THREW__; __THREW__ = 0;
                    $424 = $423&1;
                    if ($424) {
                     break L155;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(1281560|0))|0);
                    $425 = __THREW__; __THREW__ = 0;
                    $426 = $425&1;
                    if ($426) {
                     break L155;
                    }
                    __THREW__ = 0;
                    $427 = (invoke_iii(2725,($422|0),(1281560|0))|0);
                    $428 = __THREW__; __THREW__ = 0;
                    $429 = $428&1;
                    if ($429) {
                     break L155;
                    }
                    $V_12$0 = $427;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($360|0));
                   $430 = __THREW__; __THREW__ = 0;
                   $431 = $430&1;
                   if ($431) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $432 = (invoke_iii(2730,(2397904|0),($360|0))|0);
                   $433 = __THREW__; __THREW__ = 0;
                   $434 = $433&1;
                   if ($434) {
                    break L155;
                   }
                   HEAP32[$3>>2] = 1284472;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
                   $435 = (invoke_iii(772,(0|0),($$byval_copy10|0))|0);
                   $436 = __THREW__; __THREW__ = 0;
                   $437 = $436&1;
                   if ($437) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($432|0));
                   $438 = __THREW__; __THREW__ = 0;
                   $439 = $438&1;
                   if ($439) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $440 = (invoke_iiii(1640,(2223400|0),($432|0),($435|0))|0);
                   $441 = __THREW__; __THREW__ = 0;
                   $442 = $441&1;
                   if ($442) {
                    break L155;
                   }
                   if (!($440)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($360|0));
                    $466 = __THREW__; __THREW__ = 0;
                    $467 = $466&1;
                    if ($467) {
                     break L155;
                    }
                    __THREW__ = 0;
                    $468 = (invoke_iiiii(298,(2434128|0),($360|0),($obj|0),(0|0))|0);
                    $469 = __THREW__; __THREW__ = 0;
                    $470 = $469&1;
                    if ($470) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($468|0));
                    $471 = __THREW__; __THREW__ = 0;
                    $472 = $471&1;
                    if ($472) {
                     break L155;
                    }
                    __THREW__ = 0;
                    $473 = (invoke_iii(2730,(2149112|0),($468|0))|0);
                    $474 = __THREW__; __THREW__ = 0;
                    $475 = $474&1;
                    if ($475) {
                     break L155;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(1281560|0))|0);
                    $476 = __THREW__; __THREW__ = 0;
                    $477 = $476&1;
                    if ($477) {
                     break L155;
                    }
                    __THREW__ = 0;
                    $478 = (invoke_ii(3469,(1281560|0))|0);
                    $479 = __THREW__; __THREW__ = 0;
                    $480 = $479&1;
                    if ($480) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_viii(258,($478|0),($473|0),0);
                    $481 = __THREW__; __THREW__ = 0;
                    $482 = $481&1;
                    if ($482) {
                     break L155;
                    } else {
                     $V_12$0 = $478;
                     break;
                    }
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(1281560|0))|0);
                   $443 = __THREW__; __THREW__ = 0;
                   $444 = $443&1;
                   if ($444) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $445 = (invoke_ii(3469,(1281560|0))|0);
                   $446 = __THREW__; __THREW__ = 0;
                   $447 = $446&1;
                   if ($447) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(1406,($445|0));
                   $448 = __THREW__; __THREW__ = 0;
                   $449 = $448&1;
                   if ($449) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($445|0));
                   $450 = __THREW__; __THREW__ = 0;
                   $451 = $450&1;
                   if ($451) {
                    break L155;
                   }
                   $452 = (($445) + 12|0);
                   HEAP32[$452>>2] = (1);
                   __THREW__ = 0;
                   invoke_vi(3799,($360|0));
                   $453 = __THREW__; __THREW__ = 0;
                   $454 = $453&1;
                   if ($454) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $455 = (invoke_iiiii(298,(2434128|0),($360|0),($obj|0),(0|0))|0);
                   $456 = __THREW__; __THREW__ = 0;
                   $457 = $456&1;
                   if ($457) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($455|0));
                   $458 = __THREW__; __THREW__ = 0;
                   $459 = $458&1;
                   if ($459) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $460 = (invoke_iii(2730,(2149112|0),($455|0))|0);
                   $461 = __THREW__; __THREW__ = 0;
                   $462 = $461&1;
                   if ($462) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($445|0));
                   $463 = __THREW__; __THREW__ = 0;
                   $464 = $463&1;
                   if ($464) {
                    break L155;
                   }
                   $465 = (($445) + 24|0);
                   HEAP32[$465>>2] = $460;
                   $V_12$0 = $445;
                  }
                 } while(0);
                 __THREW__ = 0;
                 $483 = (invoke_iii(245,0,($V_12$0|0))|0);
                 $484 = __THREW__; __THREW__ = 0;
                 $485 = $484&1;
                 if ($485) {
                  break;
                 }
                 do {
                  if ($483) {
                   __THREW__ = 0;
                   invoke_vi(3799,($V_12$0|0));
                   $486 = __THREW__; __THREW__ = 0;
                   $487 = $486&1;
                   if ($487) {
                    break L155;
                   }
                   $488 = (($V_12$0) + 12|0);
                   $489 = HEAP32[$488>>2]|0;
                   $490 = ($489|0)==(0);
                   if (!($490)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($360|0));
                    $491 = __THREW__; __THREW__ = 0;
                    $492 = $491&1;
                    if ($492) {
                     break L155;
                    }
                    __THREW__ = 0;
                    $493 = (invoke_iii(2730,(2233608|0),($360|0))|0);
                    $494 = __THREW__; __THREW__ = 0;
                    $495 = $494&1;
                    if ($495) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($31|0));
                    $496 = __THREW__; __THREW__ = 0;
                    $497 = $496&1;
                    if ($497) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_viii(263,($31|0),($493|0),($V_12$0|0));
                    $498 = __THREW__; __THREW__ = 0;
                    $499 = $498&1;
                    if ($499) {
                     break L155;
                    } else {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(1168432|0))|0);
                   $500 = __THREW__; __THREW__ = 0;
                   $501 = $500&1;
                   if ($501) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $502 = (invoke_iii(2723,(1168432|0),6)|0);
                   $503 = __THREW__; __THREW__ = 0;
                   $504 = $503&1;
                   if ($504) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($502|0));
                   $505 = __THREW__; __THREW__ = 0;
                   $506 = $505&1;
                   if ($506) {
                    break L155;
                   }
                   $507 = (($502) + 12|0);
                   $508 = HEAP32[$507>>2]|0;
                   $509 = ($508|0)==(0);
                   if ($509) {
                    __THREW__ = 0;
                    $510 = (invoke_i(132)|0);
                    $511 = __THREW__; __THREW__ = 0;
                    $512 = $511&1;
                    if ($512) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($510|0));
                    $513 = __THREW__; __THREW__ = 0;
                    $514 = $513&1;
                    if ($514) {
                     break L155;
                    }
                   }
                   $515 = HEAP32[2992000>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3492,($502|0),($515|0));
                   $516 = __THREW__; __THREW__ = 0;
                   $517 = $516&1;
                   if ($517) {
                    break L155;
                   }
                   $518 = HEAP32[2992000>>2]|0;
                   $519 = (($502) + 16|0);
                   HEAP32[$519>>2] = $518;
                   __THREW__ = 0;
                   invoke_vi(3799,($360|0));
                   $520 = __THREW__; __THREW__ = 0;
                   $521 = $520&1;
                   if ($521) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $522 = (invoke_iii(2730,(2233608|0),($360|0))|0);
                   $523 = __THREW__; __THREW__ = 0;
                   $524 = $523&1;
                   if ($524) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($502|0));
                   $525 = __THREW__; __THREW__ = 0;
                   $526 = $525&1;
                   if ($526) {
                    break L155;
                   }
                   $527 = HEAP32[$507>>2]|0;
                   $528 = ($527>>>0)<(2);
                   if ($528) {
                    __THREW__ = 0;
                    $529 = (invoke_i(132)|0);
                    $530 = __THREW__; __THREW__ = 0;
                    $531 = $530&1;
                    if ($531) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($529|0));
                    $532 = __THREW__; __THREW__ = 0;
                    $533 = $532&1;
                    if ($533) {
                     break L155;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($502|0),($522|0));
                   $534 = __THREW__; __THREW__ = 0;
                   $535 = $534&1;
                   if ($535) {
                    break L155;
                   }
                   $536 = HEAP32[$502>>2]|0;
                   $537 = (($536) + 92|0);
                   $538 = HEAP32[$537>>2]|0;
                   $539 = (($519) + ($538)|0);
                   HEAP32[$539>>2] = $522;
                   __THREW__ = 0;
                   invoke_vi(3799,($502|0));
                   $540 = __THREW__; __THREW__ = 0;
                   $541 = $540&1;
                   if ($541) {
                    break L155;
                   }
                   $542 = HEAP32[$507>>2]|0;
                   $543 = ($542>>>0)<(3);
                   if ($543) {
                    __THREW__ = 0;
                    $544 = (invoke_i(132)|0);
                    $545 = __THREW__; __THREW__ = 0;
                    $546 = $545&1;
                    if ($546) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($544|0));
                    $547 = __THREW__; __THREW__ = 0;
                    $548 = $547&1;
                    if ($548) {
                     break L155;
                    }
                   }
                   $549 = HEAP32[2992008>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3492,($502|0),($549|0));
                   $550 = __THREW__; __THREW__ = 0;
                   $551 = $550&1;
                   if ($551) {
                    break L155;
                   }
                   $552 = HEAP32[2992008>>2]|0;
                   $553 = HEAP32[$502>>2]|0;
                   $554 = (($553) + 92|0);
                   $555 = HEAP32[$554>>2]|0;
                   $556 = $555 << 1;
                   $557 = (($519) + ($556)|0);
                   HEAP32[$557>>2] = $552;
                   __THREW__ = 0;
                   invoke_vi(3799,($obj|0));
                   $558 = __THREW__; __THREW__ = 0;
                   $559 = $558&1;
                   if ($559) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $560 = (invoke_ii(1782,($obj|0))|0);
                   $561 = __THREW__; __THREW__ = 0;
                   $562 = $561&1;
                   if ($562) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($560|0));
                   $563 = __THREW__; __THREW__ = 0;
                   $564 = $563&1;
                   if ($564) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $565 = (invoke_iii(2730,(2233608|0),($560|0))|0);
                   $566 = __THREW__; __THREW__ = 0;
                   $567 = $566&1;
                   if ($567) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($502|0));
                   $568 = __THREW__; __THREW__ = 0;
                   $569 = $568&1;
                   if ($569) {
                    break L155;
                   }
                   $570 = HEAP32[$507>>2]|0;
                   $571 = ($570>>>0)<(4);
                   if ($571) {
                    __THREW__ = 0;
                    $572 = (invoke_i(132)|0);
                    $573 = __THREW__; __THREW__ = 0;
                    $574 = $573&1;
                    if ($574) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($572|0));
                    $575 = __THREW__; __THREW__ = 0;
                    $576 = $575&1;
                    if ($576) {
                     break L155;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($502|0),($565|0));
                   $577 = __THREW__; __THREW__ = 0;
                   $578 = $577&1;
                   if ($578) {
                    break L155;
                   }
                   $579 = HEAP32[$502>>2]|0;
                   $580 = (($579) + 92|0);
                   $581 = HEAP32[$580>>2]|0;
                   $582 = ($581*3)|0;
                   $583 = (($519) + ($582)|0);
                   HEAP32[$583>>2] = $565;
                   __THREW__ = 0;
                   invoke_vi(3799,($502|0));
                   $584 = __THREW__; __THREW__ = 0;
                   $585 = $584&1;
                   if ($585) {
                    break L155;
                   }
                   $586 = HEAP32[$507>>2]|0;
                   $587 = ($586>>>0)<(5);
                   if ($587) {
                    __THREW__ = 0;
                    $588 = (invoke_i(132)|0);
                    $589 = __THREW__; __THREW__ = 0;
                    $590 = $589&1;
                    if ($590) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($588|0));
                    $591 = __THREW__; __THREW__ = 0;
                    $592 = $591&1;
                    if ($592) {
                     break L155;
                    }
                   }
                   $593 = HEAP32[2992016>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3492,($502|0),($593|0));
                   $594 = __THREW__; __THREW__ = 0;
                   $595 = $594&1;
                   if ($595) {
                    break L155;
                   }
                   $596 = HEAP32[2992016>>2]|0;
                   $597 = HEAP32[$502>>2]|0;
                   $598 = (($597) + 92|0);
                   $599 = HEAP32[$598>>2]|0;
                   $600 = $599 << 2;
                   $601 = (($519) + ($600)|0);
                   HEAP32[$601>>2] = $596;
                   __THREW__ = 0;
                   invoke_vi(3799,($360|0));
                   $602 = __THREW__; __THREW__ = 0;
                   $603 = $602&1;
                   if ($603) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $604 = (invoke_iii(2730,(2397904|0),($360|0))|0);
                   $605 = __THREW__; __THREW__ = 0;
                   $606 = $605&1;
                   if ($606) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($604|0));
                   $607 = __THREW__; __THREW__ = 0;
                   $608 = $607&1;
                   if ($608) {
                    break L155;
                   }
                   __THREW__ = 0;
                   $609 = (invoke_iii(2730,(2233608|0),($604|0))|0);
                   $610 = __THREW__; __THREW__ = 0;
                   $611 = $610&1;
                   if ($611) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($502|0));
                   $612 = __THREW__; __THREW__ = 0;
                   $613 = $612&1;
                   if ($613) {
                    break L155;
                   }
                   $614 = HEAP32[$507>>2]|0;
                   $615 = ($614>>>0)<(6);
                   if ($615) {
                    __THREW__ = 0;
                    $616 = (invoke_i(132)|0);
                    $617 = __THREW__; __THREW__ = 0;
                    $618 = $617&1;
                    if ($618) {
                     break L155;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($616|0));
                    $619 = __THREW__; __THREW__ = 0;
                    $620 = $619&1;
                    if ($620) {
                     break L155;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($502|0),($609|0));
                   $621 = __THREW__; __THREW__ = 0;
                   $622 = $621&1;
                   if ($622) {
                    break L155;
                   }
                   $623 = HEAP32[$502>>2]|0;
                   $624 = (($623) + 92|0);
                   $625 = HEAP32[$624>>2]|0;
                   $626 = ($625*5)|0;
                   $627 = (($519) + ($626)|0);
                   HEAP32[$627>>2] = $609;
                   __THREW__ = 0;
                   $628 = (invoke_iii(639,(0|0),($502|0))|0);
                   $629 = __THREW__; __THREW__ = 0;
                   $630 = $629&1;
                   if ($630) {
                    break L155;
                   }
                   __THREW__ = 0;
                   invoke_vii(2111,(0|0),($628|0));
                   $631 = __THREW__; __THREW__ = 0;
                   $632 = $631&1;
                   if ($632) {
                    break L155;
                   }
                  }
                 } while(0);
                 $633 = (($V_11$0) + 1)|0;
                 $V_11$0 = $633;
                }
                if ((label|0) == 250) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                $16 = ___cxa_find_matching_catch()|0;
                $17 = tempRet0;
                $lpad$phi$index = $16;$lpad$phi$index3 = $17;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $lpad$phi$index = $20;$lpad$phi$index3 = $21;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I28mscorlib_System_ObjectTraitsS0_E6InvokeEP10MethodInfoPvP22mscorlib_System_Object($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN16VirtFuncInvoker1I17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS4_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN16VirtFuncInvoker2I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS5_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z45AssemblyU002DCSharp_JSONTemplates_m_ToVector2P22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$obj) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = Math_fround(0), $G_B6_0$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1281792);
 __THREW__ = 0;
 invoke_v(291);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($obj|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP32[2992264>>2]|0;
    __THREW__ = 0;
    $5 = (invoke_iii(242,($obj|0),($4|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_iii(245,0,($5|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      if ($8) {
       __THREW__ = 0;
       invoke_vi(3799,($obj|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2992272>>2]|0;
       __THREW__ = 0;
       $16 = (invoke_iii(242,($obj|0),($15|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       $21 = (Math_fround(+(invoke_fi(126,($16|0)))));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       } else {
        $G_B3_0$0 = $21;
       }
      } else {
       $G_B3_0$0 = Math_fround(0.0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = HEAP32[2992280>>2]|0;
       __THREW__ = 0;
       $27 = (invoke_iii(242,($obj|0),($26|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iii(245,0,($27|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         if ($30) {
          __THREW__ = 0;
          invoke_vi(3799,($obj|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          $35 = HEAP32[2992288>>2]|0;
          __THREW__ = 0;
          $36 = (invoke_iii(242,($obj|0),($35|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          __THREW__ = 0;
          $41 = (Math_fround(+(invoke_fi(126,($36|0)))));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          } else {
           $G_B6_0$0 = $41;
          }
         } else {
          $G_B6_0$0 = Math_fround(0.0);
         }
         $44 = $agg$result;
         $45 = $44;
         HEAP32[$45>>2] = 0;
         $46 = (($44) + 4)|0;
         $47 = $46;
         HEAP32[$47>>2] = 0;
         __THREW__ = 0;
         invoke_viff(15,($agg$result|0),(+$G_B3_0$0),(+$G_B6_0$0));
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if (!($49)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z47AssemblyU002DCSharp_JSONTemplates_m_FromVector2P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector2($__this,$v) {
 $__this = $__this|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1281840);
 __THREW__ = 0;
 invoke_v(292);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1281560|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(1281560|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vii(1190,($4|0),3);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = Math_fround(HEAPF32[$v>>2]);
      $10 = $9 == Math_fround(0.0);
      if (!($10)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2992320>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($15|0),(+$9));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
      }
      $18 = (($v) + 4|0);
      $19 = Math_fround(HEAPF32[$18>>2]);
      $20 = $19 == Math_fround(0.0);
      if ($20) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($4|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       $23 = HEAP32[2992328>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($23|0),(+$19));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($4|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z47AssemblyU002DCSharp_JSONTemplates_m_FromVector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($__this,$v) {
 $__this = $__this|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1281888);
 __THREW__ = 0;
 invoke_v(293);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1281560|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(1281560|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vii(1190,($4|0),3);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = Math_fround(HEAPF32[$v>>2]);
      $10 = $9 == Math_fround(0.0);
      if (!($10)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2992344>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($15|0),(+$9));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
      }
      $18 = (($v) + 4|0);
      $19 = Math_fround(HEAPF32[$18>>2]);
      $20 = $19 == Math_fround(0.0);
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       $23 = HEAP32[2992352>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($23|0),(+$19));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
      }
      $26 = (($v) + 8|0);
      $27 = Math_fround(HEAPF32[$26>>2]);
      $28 = $27 == Math_fround(0.0);
      if ($28) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($4|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = HEAP32[2992360>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($31|0),(+$27));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($4|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z45AssemblyU002DCSharp_JSONTemplates_m_ToVector3P22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$obj) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = Math_fround(0), $G_B6_0$0 = Math_fround(0), $G_B9_0$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1281936);
 __THREW__ = 0;
 invoke_v(294);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($obj|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP32[2992384>>2]|0;
    __THREW__ = 0;
    $5 = (invoke_iii(242,($obj|0),($4|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_iii(245,0,($5|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      if ($8) {
       __THREW__ = 0;
       invoke_vi(3799,($obj|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2992392>>2]|0;
       __THREW__ = 0;
       $16 = (invoke_iii(242,($obj|0),($15|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       $21 = (Math_fround(+(invoke_fi(126,($16|0)))));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       } else {
        $G_B3_0$0 = $21;
       }
      } else {
       $G_B3_0$0 = Math_fround(0.0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = HEAP32[2992400>>2]|0;
       __THREW__ = 0;
       $27 = (invoke_iii(242,($obj|0),($26|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iii(245,0,($27|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         if ($30) {
          __THREW__ = 0;
          invoke_vi(3799,($obj|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          $35 = HEAP32[2992408>>2]|0;
          __THREW__ = 0;
          $36 = (invoke_iii(242,($obj|0),($35|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          __THREW__ = 0;
          $41 = (Math_fround(+(invoke_fi(126,($36|0)))));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          } else {
           $G_B6_0$0 = $41;
          }
         } else {
          $G_B6_0$0 = Math_fround(0.0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if (!($45)) {
          $46 = HEAP32[2992416>>2]|0;
          __THREW__ = 0;
          $47 = (invoke_iii(242,($obj|0),($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if (!($49)) {
           __THREW__ = 0;
           $50 = (invoke_iii(245,0,($47|0))|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            if ($50) {
             __THREW__ = 0;
             invoke_vi(3799,($obj|0));
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if ($54) {
              break;
             }
             $55 = HEAP32[2992424>>2]|0;
             __THREW__ = 0;
             $56 = (invoke_iii(242,($obj|0),($55|0))|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($56|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
             __THREW__ = 0;
             $61 = (Math_fround(+(invoke_fi(126,($56|0)))));
             $62 = __THREW__; __THREW__ = 0;
             $63 = $62&1;
             if ($63) {
              break;
             } else {
              $G_B9_0$0 = $61;
             }
            } else {
             $G_B9_0$0 = Math_fround(0.0);
            }
            ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
            __THREW__ = 0;
            invoke_vifff(4,($agg$result|0),(+$G_B3_0$0),(+$G_B6_0$0),(+$G_B9_0$0));
            $64 = __THREW__; __THREW__ = 0;
            $65 = $64&1;
            if (!($65)) {
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z47AssemblyU002DCSharp_JSONTemplates_m_FromVector4P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4($__this,$v) {
 $__this = $__this|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1281984);
 __THREW__ = 0;
 invoke_v(295);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1281560|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(1281560|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vii(1190,($4|0),3);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = Math_fround(HEAPF32[$v>>2]);
      $10 = $9 == Math_fround(0.0);
      if (!($10)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2992440>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($15|0),(+$9));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
      }
      $18 = (($v) + 4|0);
      $19 = Math_fround(HEAPF32[$18>>2]);
      $20 = $19 == Math_fround(0.0);
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       $23 = HEAP32[2992448>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($23|0),(+$19));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
      }
      $26 = (($v) + 8|0);
      $27 = Math_fround(HEAPF32[$26>>2]);
      $28 = $27 == Math_fround(0.0);
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       $31 = HEAP32[2992456>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($31|0),(+$27));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
      }
      $34 = (($v) + 12|0);
      $35 = Math_fround(HEAPF32[$34>>2]);
      $36 = $35 == Math_fround(0.0);
      if ($36) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($4|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = HEAP32[2992464>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($39|0),(+$35));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($4|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z45AssemblyU002DCSharp_JSONTemplates_m_ToVector4P22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$obj) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $G_B12_0$0 = Math_fround(0), $G_B3_0$0 = Math_fround(0), $G_B6_0$0 = Math_fround(0), $G_B9_0$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282032);
 __THREW__ = 0;
 invoke_v(296);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($obj|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP32[2992488>>2]|0;
    __THREW__ = 0;
    $5 = (invoke_iii(242,($obj|0),($4|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_iii(245,0,($5|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      if ($8) {
       __THREW__ = 0;
       invoke_vi(3799,($obj|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2992496>>2]|0;
       __THREW__ = 0;
       $16 = (invoke_iii(242,($obj|0),($15|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       $21 = (Math_fround(+(invoke_fi(126,($16|0)))));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       } else {
        $G_B3_0$0 = $21;
       }
      } else {
       $G_B3_0$0 = Math_fround(0.0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = HEAP32[2992504>>2]|0;
       __THREW__ = 0;
       $27 = (invoke_iii(242,($obj|0),($26|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iii(245,0,($27|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         if ($30) {
          __THREW__ = 0;
          invoke_vi(3799,($obj|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          $35 = HEAP32[2992512>>2]|0;
          __THREW__ = 0;
          $36 = (invoke_iii(242,($obj|0),($35|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          __THREW__ = 0;
          $41 = (Math_fround(+(invoke_fi(126,($36|0)))));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          } else {
           $G_B6_0$0 = $41;
          }
         } else {
          $G_B6_0$0 = Math_fround(0.0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if (!($45)) {
          $46 = HEAP32[2992520>>2]|0;
          __THREW__ = 0;
          $47 = (invoke_iii(242,($obj|0),($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if (!($49)) {
           __THREW__ = 0;
           $50 = (invoke_iii(245,0,($47|0))|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            if ($50) {
             __THREW__ = 0;
             invoke_vi(3799,($obj|0));
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if ($54) {
              break;
             }
             $55 = HEAP32[2992528>>2]|0;
             __THREW__ = 0;
             $56 = (invoke_iii(242,($obj|0),($55|0))|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($56|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
             __THREW__ = 0;
             $61 = (Math_fround(+(invoke_fi(126,($56|0)))));
             $62 = __THREW__; __THREW__ = 0;
             $63 = $62&1;
             if ($63) {
              break;
             } else {
              $G_B9_0$0 = $61;
             }
            } else {
             $G_B9_0$0 = Math_fround(0.0);
            }
            __THREW__ = 0;
            invoke_vi(3799,($obj|0));
            $64 = __THREW__; __THREW__ = 0;
            $65 = $64&1;
            if (!($65)) {
             $66 = HEAP32[2992536>>2]|0;
             __THREW__ = 0;
             $67 = (invoke_iii(242,($obj|0),($66|0))|0);
             $68 = __THREW__; __THREW__ = 0;
             $69 = $68&1;
             if (!($69)) {
              __THREW__ = 0;
              $70 = (invoke_iii(245,0,($67|0))|0);
              $71 = __THREW__; __THREW__ = 0;
              $72 = $71&1;
              if (!($72)) {
               if ($70) {
                __THREW__ = 0;
                invoke_vi(3799,($obj|0));
                $73 = __THREW__; __THREW__ = 0;
                $74 = $73&1;
                if ($74) {
                 break;
                }
                $75 = HEAP32[2992544>>2]|0;
                __THREW__ = 0;
                $76 = (invoke_iii(242,($obj|0),($75|0))|0);
                $77 = __THREW__; __THREW__ = 0;
                $78 = $77&1;
                if ($78) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($76|0));
                $79 = __THREW__; __THREW__ = 0;
                $80 = $79&1;
                if ($80) {
                 break;
                }
                __THREW__ = 0;
                $81 = (Math_fround(+(invoke_fi(126,($76|0)))));
                $82 = __THREW__; __THREW__ = 0;
                $83 = $82&1;
                if ($83) {
                 break;
                } else {
                 $G_B12_0$0 = $81;
                }
               } else {
                $G_B12_0$0 = Math_fround(0.0);
               }
               ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
               __THREW__ = 0;
               invoke_viffff(5,($agg$result|0),(+$G_B3_0$0),(+$G_B6_0$0),(+$G_B9_0$0),(+$G_B12_0$0));
               $84 = __THREW__; __THREW__ = 0;
               $85 = $84&1;
               if (!($85)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z49AssemblyU002DCSharp_JSONTemplates_m_FromMatrix4x4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4($__this,$m) {
 $__this = $__this|0;
 $m = $m|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = Math_fround(0);
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = Math_fround(0), $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282080);
 __THREW__ = 0;
 invoke_v(297);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1281560|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(1281560|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vii(1190,($4|0),3);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = Math_fround(HEAPF32[$m>>2]);
      $10 = $9 == Math_fround(0.0);
      if (!($10)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2992560>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($15|0),(+$9));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
      }
      $18 = (($m) + 16|0);
      $19 = Math_fround(HEAPF32[$18>>2]);
      $20 = $19 == Math_fround(0.0);
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       $23 = HEAP32[2992568>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($23|0),(+$19));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
      }
      $26 = (($m) + 32|0);
      $27 = Math_fround(HEAPF32[$26>>2]);
      $28 = $27 == Math_fround(0.0);
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       $31 = HEAP32[2992576>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($31|0),(+$27));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
      }
      $34 = (($m) + 48|0);
      $35 = Math_fround(HEAPF32[$34>>2]);
      $36 = $35 == Math_fround(0.0);
      if (!($36)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       $39 = HEAP32[2992584>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($39|0),(+$35));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
      }
      $42 = (($m) + 4|0);
      $43 = Math_fround(HEAPF32[$42>>2]);
      $44 = $43 == Math_fround(0.0);
      if (!($44)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       $47 = HEAP32[2992592>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($47|0),(+$43));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
      }
      $50 = (($m) + 20|0);
      $51 = Math_fround(HEAPF32[$50>>2]);
      $52 = $51 == Math_fround(0.0);
      if (!($52)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       $55 = HEAP32[2992600>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($55|0),(+$51));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
      }
      $58 = (($m) + 36|0);
      $59 = Math_fround(HEAPF32[$58>>2]);
      $60 = $59 == Math_fround(0.0);
      if (!($60)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       $63 = HEAP32[2992608>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($63|0),(+$59));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break;
       }
      }
      $66 = (($m) + 52|0);
      $67 = Math_fround(HEAPF32[$66>>2]);
      $68 = $67 == Math_fround(0.0);
      if (!($68)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break;
       }
       $71 = HEAP32[2992616>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($71|0),(+$67));
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
      }
      $74 = (($m) + 8|0);
      $75 = Math_fround(HEAPF32[$74>>2]);
      $76 = $75 == Math_fround(0.0);
      if (!($76)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        break;
       }
       $79 = HEAP32[2992624>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($79|0),(+$75));
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
      }
      $82 = (($m) + 24|0);
      $83 = Math_fround(HEAPF32[$82>>2]);
      $84 = $83 == Math_fround(0.0);
      if (!($84)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       $87 = HEAP32[2992632>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($87|0),(+$83));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
      }
      $90 = (($m) + 40|0);
      $91 = Math_fround(HEAPF32[$90>>2]);
      $92 = $91 == Math_fround(0.0);
      if (!($92)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break;
       }
       $95 = HEAP32[2992640>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($95|0),(+$91));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if ($97) {
        break;
       }
      }
      $98 = (($m) + 56|0);
      $99 = Math_fround(HEAPF32[$98>>2]);
      $100 = $99 == Math_fround(0.0);
      if (!($100)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        break;
       }
       $103 = HEAP32[2992648>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($103|0),(+$99));
       $104 = __THREW__; __THREW__ = 0;
       $105 = $104&1;
       if ($105) {
        break;
       }
      }
      $106 = (($m) + 12|0);
      $107 = Math_fround(HEAPF32[$106>>2]);
      $108 = $107 == Math_fround(0.0);
      if (!($108)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $109 = __THREW__; __THREW__ = 0;
       $110 = $109&1;
       if ($110) {
        break;
       }
       $111 = HEAP32[2992656>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($111|0),(+$107));
       $112 = __THREW__; __THREW__ = 0;
       $113 = $112&1;
       if ($113) {
        break;
       }
      }
      $114 = (($m) + 28|0);
      $115 = Math_fround(HEAPF32[$114>>2]);
      $116 = $115 == Math_fround(0.0);
      if (!($116)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $117 = __THREW__; __THREW__ = 0;
       $118 = $117&1;
       if ($118) {
        break;
       }
       $119 = HEAP32[2992664>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($119|0),(+$115));
       $120 = __THREW__; __THREW__ = 0;
       $121 = $120&1;
       if ($121) {
        break;
       }
      }
      $122 = (($m) + 44|0);
      $123 = Math_fround(HEAPF32[$122>>2]);
      $124 = $123 == Math_fround(0.0);
      if (!($124)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $125 = __THREW__; __THREW__ = 0;
       $126 = $125&1;
       if ($126) {
        break;
       }
       $127 = HEAP32[2992672>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($127|0),(+$123));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        break;
       }
      }
      $130 = (($m) + 60|0);
      $131 = Math_fround(HEAPF32[$130>>2]);
      $132 = $131 == Math_fround(0.0);
      if ($132) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($4|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       break;
      }
      $135 = HEAP32[2992680>>2]|0;
      __THREW__ = 0;
      invoke_viif(16,($4|0),($135|0),(+$131));
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($4|0);
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z47AssemblyU002DCSharp_JSONTemplates_m_ToMatrix4x4P22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$obj) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = Math_fround(0), $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = Math_fround(0);
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = Math_fround(0), $21 = Math_fround(0), $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = Math_fround(0), $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = Math_fround(0), $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = Math_fround(0), $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = Math_fround(0), $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = 0, $338 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = Math_fround(0), $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = Math_fround(0), $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0;
 var dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282128);
 dest=$agg$result+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_v(298);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($obj|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP32[2992824>>2]|0;
    __THREW__ = 0;
    $5 = (invoke_iii(242,($obj|0),($4|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_iii(245,0,($5|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      if ($8) {
       __THREW__ = 0;
       invoke_vi(3799,($obj|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2992832>>2]|0;
       __THREW__ = 0;
       $16 = (invoke_iii(242,($obj|0),($15|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       $21 = (Math_fround(+(invoke_fi(126,($16|0)))));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       HEAPF32[$agg$result>>2] = $21;
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = HEAP32[2992840>>2]|0;
       __THREW__ = 0;
       $27 = (invoke_iii(242,($obj|0),($26|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iii(245,0,($27|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         if ($30) {
          __THREW__ = 0;
          invoke_vi(3799,($obj|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          $35 = HEAP32[2992848>>2]|0;
          __THREW__ = 0;
          $36 = (invoke_iii(242,($obj|0),($35|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          __THREW__ = 0;
          $41 = (Math_fround(+(invoke_fi(126,($36|0)))));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          $44 = (($agg$result) + 16|0);
          HEAPF32[$44>>2] = $41;
         }
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if (!($46)) {
          $47 = HEAP32[2992856>>2]|0;
          __THREW__ = 0;
          $48 = (invoke_iii(242,($obj|0),($47|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if (!($50)) {
           __THREW__ = 0;
           $51 = (invoke_iii(245,0,($48|0))|0);
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if (!($53)) {
            if ($51) {
             __THREW__ = 0;
             invoke_vi(3799,($obj|0));
             $54 = __THREW__; __THREW__ = 0;
             $55 = $54&1;
             if ($55) {
              break;
             }
             $56 = HEAP32[2992864>>2]|0;
             __THREW__ = 0;
             $57 = (invoke_iii(242,($obj|0),($56|0))|0);
             $58 = __THREW__; __THREW__ = 0;
             $59 = $58&1;
             if ($59) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($57|0));
             $60 = __THREW__; __THREW__ = 0;
             $61 = $60&1;
             if ($61) {
              break;
             }
             __THREW__ = 0;
             $62 = (Math_fround(+(invoke_fi(126,($57|0)))));
             $63 = __THREW__; __THREW__ = 0;
             $64 = $63&1;
             if ($64) {
              break;
             }
             $65 = (($agg$result) + 32|0);
             HEAPF32[$65>>2] = $62;
            }
            __THREW__ = 0;
            invoke_vi(3799,($obj|0));
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if (!($67)) {
             $68 = HEAP32[2992872>>2]|0;
             __THREW__ = 0;
             $69 = (invoke_iii(242,($obj|0),($68|0))|0);
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if (!($71)) {
              __THREW__ = 0;
              $72 = (invoke_iii(245,0,($69|0))|0);
              $73 = __THREW__; __THREW__ = 0;
              $74 = $73&1;
              if (!($74)) {
               if ($72) {
                __THREW__ = 0;
                invoke_vi(3799,($obj|0));
                $75 = __THREW__; __THREW__ = 0;
                $76 = $75&1;
                if ($76) {
                 break;
                }
                $77 = HEAP32[2992880>>2]|0;
                __THREW__ = 0;
                $78 = (invoke_iii(242,($obj|0),($77|0))|0);
                $79 = __THREW__; __THREW__ = 0;
                $80 = $79&1;
                if ($80) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($78|0));
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if ($82) {
                 break;
                }
                __THREW__ = 0;
                $83 = (Math_fround(+(invoke_fi(126,($78|0)))));
                $84 = __THREW__; __THREW__ = 0;
                $85 = $84&1;
                if ($85) {
                 break;
                }
                $86 = (($agg$result) + 48|0);
                HEAPF32[$86>>2] = $83;
               }
               __THREW__ = 0;
               invoke_vi(3799,($obj|0));
               $87 = __THREW__; __THREW__ = 0;
               $88 = $87&1;
               if (!($88)) {
                $89 = HEAP32[2992888>>2]|0;
                __THREW__ = 0;
                $90 = (invoke_iii(242,($obj|0),($89|0))|0);
                $91 = __THREW__; __THREW__ = 0;
                $92 = $91&1;
                if (!($92)) {
                 __THREW__ = 0;
                 $93 = (invoke_iii(245,0,($90|0))|0);
                 $94 = __THREW__; __THREW__ = 0;
                 $95 = $94&1;
                 if ($95) {
                  break;
                 }
                 if ($93) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $96 = __THREW__; __THREW__ = 0;
                  $97 = $96&1;
                  if ($97) {
                   break;
                  }
                  $98 = HEAP32[2992896>>2]|0;
                  __THREW__ = 0;
                  $99 = (invoke_iii(242,($obj|0),($98|0))|0);
                  $100 = __THREW__; __THREW__ = 0;
                  $101 = $100&1;
                  if ($101) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($99|0));
                  $102 = __THREW__; __THREW__ = 0;
                  $103 = $102&1;
                  if ($103) {
                   break;
                  }
                  __THREW__ = 0;
                  $104 = (Math_fround(+(invoke_fi(126,($99|0)))));
                  $105 = __THREW__; __THREW__ = 0;
                  $106 = $105&1;
                  if ($106) {
                   break;
                  }
                  $107 = (($agg$result) + 4|0);
                  HEAPF32[$107>>2] = $104;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $108 = __THREW__; __THREW__ = 0;
                 $109 = $108&1;
                 if ($109) {
                  break;
                 }
                 $110 = HEAP32[2992904>>2]|0;
                 __THREW__ = 0;
                 $111 = (invoke_iii(242,($obj|0),($110|0))|0);
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  break;
                 }
                 __THREW__ = 0;
                 $114 = (invoke_iii(245,0,($111|0))|0);
                 $115 = __THREW__; __THREW__ = 0;
                 $116 = $115&1;
                 if ($116) {
                  break;
                 }
                 if ($114) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $117 = __THREW__; __THREW__ = 0;
                  $118 = $117&1;
                  if ($118) {
                   break;
                  }
                  $119 = HEAP32[2992912>>2]|0;
                  __THREW__ = 0;
                  $120 = (invoke_iii(242,($obj|0),($119|0))|0);
                  $121 = __THREW__; __THREW__ = 0;
                  $122 = $121&1;
                  if ($122) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($120|0));
                  $123 = __THREW__; __THREW__ = 0;
                  $124 = $123&1;
                  if ($124) {
                   break;
                  }
                  __THREW__ = 0;
                  $125 = (Math_fround(+(invoke_fi(126,($120|0)))));
                  $126 = __THREW__; __THREW__ = 0;
                  $127 = $126&1;
                  if ($127) {
                   break;
                  }
                  $128 = (($agg$result) + 20|0);
                  HEAPF32[$128>>2] = $125;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $129 = __THREW__; __THREW__ = 0;
                 $130 = $129&1;
                 if ($130) {
                  break;
                 }
                 $131 = HEAP32[2992920>>2]|0;
                 __THREW__ = 0;
                 $132 = (invoke_iii(242,($obj|0),($131|0))|0);
                 $133 = __THREW__; __THREW__ = 0;
                 $134 = $133&1;
                 if ($134) {
                  break;
                 }
                 __THREW__ = 0;
                 $135 = (invoke_iii(245,0,($132|0))|0);
                 $136 = __THREW__; __THREW__ = 0;
                 $137 = $136&1;
                 if ($137) {
                  break;
                 }
                 if ($135) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $138 = __THREW__; __THREW__ = 0;
                  $139 = $138&1;
                  if ($139) {
                   break;
                  }
                  $140 = HEAP32[2992928>>2]|0;
                  __THREW__ = 0;
                  $141 = (invoke_iii(242,($obj|0),($140|0))|0);
                  $142 = __THREW__; __THREW__ = 0;
                  $143 = $142&1;
                  if ($143) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($141|0));
                  $144 = __THREW__; __THREW__ = 0;
                  $145 = $144&1;
                  if ($145) {
                   break;
                  }
                  __THREW__ = 0;
                  $146 = (Math_fround(+(invoke_fi(126,($141|0)))));
                  $147 = __THREW__; __THREW__ = 0;
                  $148 = $147&1;
                  if ($148) {
                   break;
                  }
                  $149 = (($agg$result) + 36|0);
                  HEAPF32[$149>>2] = $146;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $150 = __THREW__; __THREW__ = 0;
                 $151 = $150&1;
                 if ($151) {
                  break;
                 }
                 $152 = HEAP32[2992936>>2]|0;
                 __THREW__ = 0;
                 $153 = (invoke_iii(242,($obj|0),($152|0))|0);
                 $154 = __THREW__; __THREW__ = 0;
                 $155 = $154&1;
                 if ($155) {
                  break;
                 }
                 __THREW__ = 0;
                 $156 = (invoke_iii(245,0,($153|0))|0);
                 $157 = __THREW__; __THREW__ = 0;
                 $158 = $157&1;
                 if ($158) {
                  break;
                 }
                 if ($156) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $159 = __THREW__; __THREW__ = 0;
                  $160 = $159&1;
                  if ($160) {
                   break;
                  }
                  $161 = HEAP32[2992944>>2]|0;
                  __THREW__ = 0;
                  $162 = (invoke_iii(242,($obj|0),($161|0))|0);
                  $163 = __THREW__; __THREW__ = 0;
                  $164 = $163&1;
                  if ($164) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($162|0));
                  $165 = __THREW__; __THREW__ = 0;
                  $166 = $165&1;
                  if ($166) {
                   break;
                  }
                  __THREW__ = 0;
                  $167 = (Math_fround(+(invoke_fi(126,($162|0)))));
                  $168 = __THREW__; __THREW__ = 0;
                  $169 = $168&1;
                  if ($169) {
                   break;
                  }
                  $170 = (($agg$result) + 52|0);
                  HEAPF32[$170>>2] = $167;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $171 = __THREW__; __THREW__ = 0;
                 $172 = $171&1;
                 if ($172) {
                  break;
                 }
                 $173 = HEAP32[2992952>>2]|0;
                 __THREW__ = 0;
                 $174 = (invoke_iii(242,($obj|0),($173|0))|0);
                 $175 = __THREW__; __THREW__ = 0;
                 $176 = $175&1;
                 if ($176) {
                  break;
                 }
                 __THREW__ = 0;
                 $177 = (invoke_iii(245,0,($174|0))|0);
                 $178 = __THREW__; __THREW__ = 0;
                 $179 = $178&1;
                 if ($179) {
                  break;
                 }
                 if ($177) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $180 = __THREW__; __THREW__ = 0;
                  $181 = $180&1;
                  if ($181) {
                   break;
                  }
                  $182 = HEAP32[2992960>>2]|0;
                  __THREW__ = 0;
                  $183 = (invoke_iii(242,($obj|0),($182|0))|0);
                  $184 = __THREW__; __THREW__ = 0;
                  $185 = $184&1;
                  if ($185) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($183|0));
                  $186 = __THREW__; __THREW__ = 0;
                  $187 = $186&1;
                  if ($187) {
                   break;
                  }
                  __THREW__ = 0;
                  $188 = (Math_fround(+(invoke_fi(126,($183|0)))));
                  $189 = __THREW__; __THREW__ = 0;
                  $190 = $189&1;
                  if ($190) {
                   break;
                  }
                  $191 = (($agg$result) + 8|0);
                  HEAPF32[$191>>2] = $188;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $192 = __THREW__; __THREW__ = 0;
                 $193 = $192&1;
                 if ($193) {
                  break;
                 }
                 $194 = HEAP32[2992968>>2]|0;
                 __THREW__ = 0;
                 $195 = (invoke_iii(242,($obj|0),($194|0))|0);
                 $196 = __THREW__; __THREW__ = 0;
                 $197 = $196&1;
                 if ($197) {
                  break;
                 }
                 __THREW__ = 0;
                 $198 = (invoke_iii(245,0,($195|0))|0);
                 $199 = __THREW__; __THREW__ = 0;
                 $200 = $199&1;
                 if ($200) {
                  break;
                 }
                 if ($198) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $201 = __THREW__; __THREW__ = 0;
                  $202 = $201&1;
                  if ($202) {
                   break;
                  }
                  $203 = HEAP32[2992976>>2]|0;
                  __THREW__ = 0;
                  $204 = (invoke_iii(242,($obj|0),($203|0))|0);
                  $205 = __THREW__; __THREW__ = 0;
                  $206 = $205&1;
                  if ($206) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($204|0));
                  $207 = __THREW__; __THREW__ = 0;
                  $208 = $207&1;
                  if ($208) {
                   break;
                  }
                  __THREW__ = 0;
                  $209 = (Math_fround(+(invoke_fi(126,($204|0)))));
                  $210 = __THREW__; __THREW__ = 0;
                  $211 = $210&1;
                  if ($211) {
                   break;
                  }
                  $212 = (($agg$result) + 24|0);
                  HEAPF32[$212>>2] = $209;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $213 = __THREW__; __THREW__ = 0;
                 $214 = $213&1;
                 if ($214) {
                  break;
                 }
                 $215 = HEAP32[2992984>>2]|0;
                 __THREW__ = 0;
                 $216 = (invoke_iii(242,($obj|0),($215|0))|0);
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  break;
                 }
                 __THREW__ = 0;
                 $219 = (invoke_iii(245,0,($216|0))|0);
                 $220 = __THREW__; __THREW__ = 0;
                 $221 = $220&1;
                 if ($221) {
                  break;
                 }
                 if ($219) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $222 = __THREW__; __THREW__ = 0;
                  $223 = $222&1;
                  if ($223) {
                   break;
                  }
                  $224 = HEAP32[2992992>>2]|0;
                  __THREW__ = 0;
                  $225 = (invoke_iii(242,($obj|0),($224|0))|0);
                  $226 = __THREW__; __THREW__ = 0;
                  $227 = $226&1;
                  if ($227) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($225|0));
                  $228 = __THREW__; __THREW__ = 0;
                  $229 = $228&1;
                  if ($229) {
                   break;
                  }
                  __THREW__ = 0;
                  $230 = (Math_fround(+(invoke_fi(126,($225|0)))));
                  $231 = __THREW__; __THREW__ = 0;
                  $232 = $231&1;
                  if ($232) {
                   break;
                  }
                  $233 = (($agg$result) + 40|0);
                  HEAPF32[$233>>2] = $230;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $234 = __THREW__; __THREW__ = 0;
                 $235 = $234&1;
                 if ($235) {
                  break;
                 }
                 $236 = HEAP32[2993000>>2]|0;
                 __THREW__ = 0;
                 $237 = (invoke_iii(242,($obj|0),($236|0))|0);
                 $238 = __THREW__; __THREW__ = 0;
                 $239 = $238&1;
                 if ($239) {
                  break;
                 }
                 __THREW__ = 0;
                 $240 = (invoke_iii(245,0,($237|0))|0);
                 $241 = __THREW__; __THREW__ = 0;
                 $242 = $241&1;
                 if ($242) {
                  break;
                 }
                 if ($240) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $243 = __THREW__; __THREW__ = 0;
                  $244 = $243&1;
                  if ($244) {
                   break;
                  }
                  $245 = HEAP32[2993008>>2]|0;
                  __THREW__ = 0;
                  $246 = (invoke_iii(242,($obj|0),($245|0))|0);
                  $247 = __THREW__; __THREW__ = 0;
                  $248 = $247&1;
                  if ($248) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($246|0));
                  $249 = __THREW__; __THREW__ = 0;
                  $250 = $249&1;
                  if ($250) {
                   break;
                  }
                  __THREW__ = 0;
                  $251 = (Math_fround(+(invoke_fi(126,($246|0)))));
                  $252 = __THREW__; __THREW__ = 0;
                  $253 = $252&1;
                  if ($253) {
                   break;
                  }
                  $254 = (($agg$result) + 56|0);
                  HEAPF32[$254>>2] = $251;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $255 = __THREW__; __THREW__ = 0;
                 $256 = $255&1;
                 if ($256) {
                  break;
                 }
                 $257 = HEAP32[2993016>>2]|0;
                 __THREW__ = 0;
                 $258 = (invoke_iii(242,($obj|0),($257|0))|0);
                 $259 = __THREW__; __THREW__ = 0;
                 $260 = $259&1;
                 if ($260) {
                  break;
                 }
                 __THREW__ = 0;
                 $261 = (invoke_iii(245,0,($258|0))|0);
                 $262 = __THREW__; __THREW__ = 0;
                 $263 = $262&1;
                 if ($263) {
                  break;
                 }
                 if ($261) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $264 = __THREW__; __THREW__ = 0;
                  $265 = $264&1;
                  if ($265) {
                   break;
                  }
                  $266 = HEAP32[2993024>>2]|0;
                  __THREW__ = 0;
                  $267 = (invoke_iii(242,($obj|0),($266|0))|0);
                  $268 = __THREW__; __THREW__ = 0;
                  $269 = $268&1;
                  if ($269) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($267|0));
                  $270 = __THREW__; __THREW__ = 0;
                  $271 = $270&1;
                  if ($271) {
                   break;
                  }
                  __THREW__ = 0;
                  $272 = (Math_fround(+(invoke_fi(126,($267|0)))));
                  $273 = __THREW__; __THREW__ = 0;
                  $274 = $273&1;
                  if ($274) {
                   break;
                  }
                  $275 = (($agg$result) + 12|0);
                  HEAPF32[$275>>2] = $272;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $276 = __THREW__; __THREW__ = 0;
                 $277 = $276&1;
                 if ($277) {
                  break;
                 }
                 $278 = HEAP32[2993032>>2]|0;
                 __THREW__ = 0;
                 $279 = (invoke_iii(242,($obj|0),($278|0))|0);
                 $280 = __THREW__; __THREW__ = 0;
                 $281 = $280&1;
                 if ($281) {
                  break;
                 }
                 __THREW__ = 0;
                 $282 = (invoke_iii(245,0,($279|0))|0);
                 $283 = __THREW__; __THREW__ = 0;
                 $284 = $283&1;
                 if ($284) {
                  break;
                 }
                 if ($282) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $285 = __THREW__; __THREW__ = 0;
                  $286 = $285&1;
                  if ($286) {
                   break;
                  }
                  $287 = HEAP32[2993040>>2]|0;
                  __THREW__ = 0;
                  $288 = (invoke_iii(242,($obj|0),($287|0))|0);
                  $289 = __THREW__; __THREW__ = 0;
                  $290 = $289&1;
                  if ($290) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($288|0));
                  $291 = __THREW__; __THREW__ = 0;
                  $292 = $291&1;
                  if ($292) {
                   break;
                  }
                  __THREW__ = 0;
                  $293 = (Math_fround(+(invoke_fi(126,($288|0)))));
                  $294 = __THREW__; __THREW__ = 0;
                  $295 = $294&1;
                  if ($295) {
                   break;
                  }
                  $296 = (($agg$result) + 28|0);
                  HEAPF32[$296>>2] = $293;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $297 = __THREW__; __THREW__ = 0;
                 $298 = $297&1;
                 if ($298) {
                  break;
                 }
                 $299 = HEAP32[2993048>>2]|0;
                 __THREW__ = 0;
                 $300 = (invoke_iii(242,($obj|0),($299|0))|0);
                 $301 = __THREW__; __THREW__ = 0;
                 $302 = $301&1;
                 if ($302) {
                  break;
                 }
                 __THREW__ = 0;
                 $303 = (invoke_iii(245,0,($300|0))|0);
                 $304 = __THREW__; __THREW__ = 0;
                 $305 = $304&1;
                 if ($305) {
                  break;
                 }
                 if ($303) {
                  __THREW__ = 0;
                  invoke_vi(3799,($obj|0));
                  $306 = __THREW__; __THREW__ = 0;
                  $307 = $306&1;
                  if ($307) {
                   break;
                  }
                  $308 = HEAP32[2993056>>2]|0;
                  __THREW__ = 0;
                  $309 = (invoke_iii(242,($obj|0),($308|0))|0);
                  $310 = __THREW__; __THREW__ = 0;
                  $311 = $310&1;
                  if ($311) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($309|0));
                  $312 = __THREW__; __THREW__ = 0;
                  $313 = $312&1;
                  if ($313) {
                   break;
                  }
                  __THREW__ = 0;
                  $314 = (Math_fround(+(invoke_fi(126,($309|0)))));
                  $315 = __THREW__; __THREW__ = 0;
                  $316 = $315&1;
                  if ($316) {
                   break;
                  }
                  $317 = (($agg$result) + 44|0);
                  HEAPF32[$317>>2] = $314;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $318 = __THREW__; __THREW__ = 0;
                 $319 = $318&1;
                 if ($319) {
                  break;
                 }
                 $320 = HEAP32[2993064>>2]|0;
                 __THREW__ = 0;
                 $321 = (invoke_iii(242,($obj|0),($320|0))|0);
                 $322 = __THREW__; __THREW__ = 0;
                 $323 = $322&1;
                 if ($323) {
                  break;
                 }
                 __THREW__ = 0;
                 $324 = (invoke_iii(245,0,($321|0))|0);
                 $325 = __THREW__; __THREW__ = 0;
                 $326 = $325&1;
                 if ($326) {
                  break;
                 }
                 if (!($324)) {
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($obj|0));
                 $327 = __THREW__; __THREW__ = 0;
                 $328 = $327&1;
                 if ($328) {
                  break;
                 }
                 $329 = HEAP32[2993072>>2]|0;
                 __THREW__ = 0;
                 $330 = (invoke_iii(242,($obj|0),($329|0))|0);
                 $331 = __THREW__; __THREW__ = 0;
                 $332 = $331&1;
                 if ($332) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($330|0));
                 $333 = __THREW__; __THREW__ = 0;
                 $334 = $333&1;
                 if ($334) {
                  break;
                 }
                 __THREW__ = 0;
                 $335 = (Math_fround(+(invoke_fi(126,($330|0)))));
                 $336 = __THREW__; __THREW__ = 0;
                 $337 = $336&1;
                 if ($337) {
                  break;
                 }
                 $338 = (($agg$result) + 60|0);
                 HEAPF32[$338>>2] = $335;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z50AssemblyU002DCSharp_JSONTemplates_m_FromQuaternionP22mscorlib_System_Object34UnityEngine_UnityEngine_Quaternion($__this,$q) {
 $__this = $__this|0;
 $q = $q|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282176);
 __THREW__ = 0;
 invoke_v(299);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1281560|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(1281560|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vii(1190,($4|0),3);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($q) + 12|0);
      $10 = Math_fround(HEAPF32[$9>>2]);
      $11 = $10 == Math_fround(0.0);
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
       $16 = HEAP32[2993088>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($16|0),(+$10));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
      }
      $19 = Math_fround(HEAPF32[$q>>2]);
      $20 = $19 == Math_fround(0.0);
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       $23 = HEAP32[2993096>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($23|0),(+$19));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
      }
      $26 = (($q) + 4|0);
      $27 = Math_fround(HEAPF32[$26>>2]);
      $28 = $27 == Math_fround(0.0);
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       $31 = HEAP32[2993104>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($31|0),(+$27));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
      }
      $34 = (($q) + 8|0);
      $35 = Math_fround(HEAPF32[$34>>2]);
      $36 = $35 == Math_fround(0.0);
      if ($36) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($4|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = HEAP32[2993112>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($39|0),(+$35));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($4|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z48AssemblyU002DCSharp_JSONTemplates_m_ToQuaternionP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$obj) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $G_B12_0$0 = Math_fround(0), $G_B3_0$0 = Math_fround(0), $G_B6_0$0 = Math_fround(0), $G_B9_0$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282224);
 __THREW__ = 0;
 invoke_v(300);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($obj|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP32[2993128>>2]|0;
    __THREW__ = 0;
    $5 = (invoke_iii(242,($obj|0),($4|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_iii(245,0,($5|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      if ($8) {
       __THREW__ = 0;
       invoke_vi(3799,($obj|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2993136>>2]|0;
       __THREW__ = 0;
       $16 = (invoke_iii(242,($obj|0),($15|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       $21 = (Math_fround(+(invoke_fi(126,($16|0)))));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       } else {
        $G_B3_0$0 = $21;
       }
      } else {
       $G_B3_0$0 = Math_fround(0.0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = HEAP32[2993144>>2]|0;
       __THREW__ = 0;
       $27 = (invoke_iii(242,($obj|0),($26|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iii(245,0,($27|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         if ($30) {
          __THREW__ = 0;
          invoke_vi(3799,($obj|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          $35 = HEAP32[2993152>>2]|0;
          __THREW__ = 0;
          $36 = (invoke_iii(242,($obj|0),($35|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          __THREW__ = 0;
          $41 = (Math_fround(+(invoke_fi(126,($36|0)))));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          } else {
           $G_B6_0$0 = $41;
          }
         } else {
          $G_B6_0$0 = Math_fround(0.0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if (!($45)) {
          $46 = HEAP32[2993160>>2]|0;
          __THREW__ = 0;
          $47 = (invoke_iii(242,($obj|0),($46|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if (!($49)) {
           __THREW__ = 0;
           $50 = (invoke_iii(245,0,($47|0))|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            if ($50) {
             __THREW__ = 0;
             invoke_vi(3799,($obj|0));
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if ($54) {
              break;
             }
             $55 = HEAP32[2993168>>2]|0;
             __THREW__ = 0;
             $56 = (invoke_iii(242,($obj|0),($55|0))|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($56|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
             __THREW__ = 0;
             $61 = (Math_fround(+(invoke_fi(126,($56|0)))));
             $62 = __THREW__; __THREW__ = 0;
             $63 = $62&1;
             if ($63) {
              break;
             } else {
              $G_B9_0$0 = $61;
             }
            } else {
             $G_B9_0$0 = Math_fround(0.0);
            }
            __THREW__ = 0;
            invoke_vi(3799,($obj|0));
            $64 = __THREW__; __THREW__ = 0;
            $65 = $64&1;
            if (!($65)) {
             $66 = HEAP32[2993176>>2]|0;
             __THREW__ = 0;
             $67 = (invoke_iii(242,($obj|0),($66|0))|0);
             $68 = __THREW__; __THREW__ = 0;
             $69 = $68&1;
             if (!($69)) {
              __THREW__ = 0;
              $70 = (invoke_iii(245,0,($67|0))|0);
              $71 = __THREW__; __THREW__ = 0;
              $72 = $71&1;
              if (!($72)) {
               if ($70) {
                __THREW__ = 0;
                invoke_vi(3799,($obj|0));
                $73 = __THREW__; __THREW__ = 0;
                $74 = $73&1;
                if ($74) {
                 break;
                }
                $75 = HEAP32[2993184>>2]|0;
                __THREW__ = 0;
                $76 = (invoke_iii(242,($obj|0),($75|0))|0);
                $77 = __THREW__; __THREW__ = 0;
                $78 = $77&1;
                if ($78) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($76|0));
                $79 = __THREW__; __THREW__ = 0;
                $80 = $79&1;
                if ($80) {
                 break;
                }
                __THREW__ = 0;
                $81 = (Math_fround(+(invoke_fi(126,($76|0)))));
                $82 = __THREW__; __THREW__ = 0;
                $83 = $82&1;
                if ($83) {
                 break;
                } else {
                 $G_B12_0$0 = $81;
                }
               } else {
                $G_B12_0$0 = Math_fround(0.0);
               }
               ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
               __THREW__ = 0;
               invoke_viffff(3,($agg$result|0),(+$G_B3_0$0),(+$G_B6_0$0),(+$G_B9_0$0),(+$G_B12_0$0));
               $84 = __THREW__; __THREW__ = 0;
               $85 = $84&1;
               if (!($85)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z45AssemblyU002DCSharp_JSONTemplates_m_FromColorP22mscorlib_System_Object29UnityEngine_UnityEngine_Color($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282272);
 __THREW__ = 0;
 invoke_v(301);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1281560|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(1281560|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vii(1190,($4|0),3);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = Math_fround(HEAPF32[$c>>2]);
      $10 = $9 == Math_fround(0.0);
      if (!($10)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       $15 = HEAP32[2993200>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($15|0),(+$9));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
      }
      $18 = (($c) + 4|0);
      $19 = Math_fround(HEAPF32[$18>>2]);
      $20 = $19 == Math_fround(0.0);
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       $23 = HEAP32[2993208>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($23|0),(+$19));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
      }
      $26 = (($c) + 8|0);
      $27 = Math_fround(HEAPF32[$26>>2]);
      $28 = $27 == Math_fround(0.0);
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       $31 = HEAP32[2993216>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($31|0),(+$27));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
      }
      $34 = (($c) + 12|0);
      $35 = Math_fround(HEAPF32[$34>>2]);
      $36 = $35 == Math_fround(0.0);
      if ($36) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($4|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = HEAP32[2993224>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($4|0),($39|0),(+$35));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($4|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z43AssemblyU002DCSharp_JSONTemplates_m_ToColorP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$obj) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = Math_fround(0), $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_4 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282320);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 HEAP32[$V_4>>2] = 0;
 __THREW__ = 0;
 invoke_v(302);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $lpad$phi$index = $8;$lpad$phi$index2 = $9;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $2 = (($obj) + 20|0);
 $3 = (($agg$result) + 4|0);
 $4 = (($agg$result) + 8|0);
 $5 = (($agg$result) + 12|0);
 $V_1$0 = 0;
 L5: while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($obj|0));
  $136 = __THREW__; __THREW__ = 0;
  $137 = $136&1;
  if ($137) {
   break;
  }
  __THREW__ = 0;
  $138 = (invoke_ii(722,($obj|0))|0);
  $139 = __THREW__; __THREW__ = 0;
  $140 = $139&1;
  if ($140) {
   break;
  }
  $141 = ($V_1$0|0)<($138|0);
  if (!($141)) {
   label = 69;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($obj|0));
  $142 = __THREW__; __THREW__ = 0;
  $143 = $142&1;
  if ($143) {
   break;
  }
  $10 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   break;
  }
  __THREW__ = 0;
  $13 = (invoke_iiii(1642,(1332456|0),($10|0),($V_1$0|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   break;
  }
  $16 = ($13|0)==(0|0);
  do {
   if (!($16)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break L5;
    }
    $19 = HEAP8[((1283616 + 116|0))>>0]|0;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break L5;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3802,(1283616|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break L5;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break L5;
    }
    $29 = HEAP32[((1283616 + 80|0))>>2]|0;
    $30 = (($29) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     __THREW__ = 0;
     (invoke_ii(2996,(1400808|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break L5;
     }
     __THREW__ = 0;
     $35 = (invoke_ii(3469,(1400808|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vii(1329,($35|0),4);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3799,($35|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break L5;
     }
     $42 = HEAP32[2993272>>2]|0;
     __THREW__ = 0;
     invoke_viiii(461,(1397040|0),($35|0),($42|0),0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3799,($35|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L5;
     }
     $47 = HEAP32[2993280>>2]|0;
     __THREW__ = 0;
     invoke_viiii(461,(1397040|0),($35|0),($47|0),1);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3799,($35|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L5;
     }
     $52 = HEAP32[2993288>>2]|0;
     __THREW__ = 0;
     invoke_viiii(461,(1397040|0),($35|0),($52|0),2);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3799,($35|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break L5;
     }
     $57 = HEAP32[2993296>>2]|0;
     __THREW__ = 0;
     invoke_viiii(461,(1397040|0),($35|0),($57|0),3);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break L5;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break L5;
     }
     $62 = HEAP8[((1283616 + 116|0))>>0]|0;
     $63 = ($62<<24>>24)==(0);
     if ($63) {
      __THREW__ = 0;
      (invoke_ii(2996,(1283616|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break L5;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1283616|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3802,(1283616|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       break L5;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break L5;
     }
     $72 = HEAP32[((1283616 + 80|0))>>2]|0;
     $73 = (($72) + 4|0);
     HEAP32[$73>>2] = $35;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break L5;
    }
    $76 = HEAP8[((1283616 + 116|0))>>0]|0;
    $77 = ($76<<24>>24)==(0);
    if ($77) {
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      break L5;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3802,(1283616|0));
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      break L5;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break L5;
    }
    $86 = HEAP32[((1283616 + 80|0))>>2]|0;
    $87 = (($86) + 4|0);
    $88 = HEAP32[$87>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($88|0));
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     break L5;
    }
    __THREW__ = 0;
    $91 = (invoke_iiiii(299,(1398096|0),($88|0),($13|0),($V_4|0))|0);
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     break L5;
    }
    if ($91) {
     $94 = HEAP32[$V_4>>2]|0;
     if ((($94|0) == 1)) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       break L5;
      }
      __THREW__ = 0;
      $107 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3799,($107|0));
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       break L5;
      }
      __THREW__ = 0;
      $112 = (Math_fround(+(invoke_fi(126,($107|0)))));
      $113 = __THREW__; __THREW__ = 0;
      $114 = $113&1;
      if ($114) {
       break L5;
      }
      HEAPF32[$3>>2] = $112;
      break;
     } else if ((($94|0) == 0)) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       break L5;
      }
      __THREW__ = 0;
      $97 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
      $98 = __THREW__; __THREW__ = 0;
      $99 = $98&1;
      if ($99) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3799,($97|0));
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       break L5;
      }
      __THREW__ = 0;
      $102 = (Math_fround(+(invoke_fi(126,($97|0)))));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       break L5;
      }
      HEAPF32[$agg$result>>2] = $102;
      break;
     } else if ((($94|0) == 2)) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       break L5;
      }
      __THREW__ = 0;
      $117 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
      $118 = __THREW__; __THREW__ = 0;
      $119 = $118&1;
      if ($119) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3799,($117|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       break L5;
      }
      __THREW__ = 0;
      $122 = (Math_fround(+(invoke_fi(126,($117|0)))));
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       break L5;
      }
      HEAPF32[$4>>2] = $122;
      break;
     } else if ((($94|0) == 3)) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if ($126) {
       break L5;
      }
      __THREW__ = 0;
      $127 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if ($129) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3799,($127|0));
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       break L5;
      }
      __THREW__ = 0;
      $132 = (Math_fround(+(invoke_fi(126,($127|0)))));
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       break L5;
      }
      HEAPF32[$5>>2] = $132;
      break;
     } else {
      break;
     }
    }
   }
  } while(0);
  $135 = (($V_1$0) + 1)|0;
  $V_1$0 = $135;
 }
 if ((label|0) == 69) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $lpad$phi$index = $6;$lpad$phi$index2 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN18VirtActionInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS5_i($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z49AssemblyU002DCSharp_JSONTemplates_m_FromLayerMaskP22mscorlib_System_Object33UnityEngine_UnityEngine_LayerMask($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282368);
 __THREW__ = 0;
 invoke_v(303);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(724,0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(2537,($l|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[2993312>>2]|0;
     __THREW__ = 0;
     invoke_viii(260,($2|0),($10|0),($5|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($2|0);
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z47AssemblyU002DCSharp_JSONTemplates_m_ToLayerMaskP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282416);
 HEAP32[$0>>2] = 0;
 __THREW__ = 0;
 invoke_v(304);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($obj|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[2993344>>2]|0;
   __THREW__ = 0;
   $6 = (invoke_iii(242,($obj|0),($5|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(3799,($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($6) + 28|0);
     $12 = Math_fround(HEAPF32[$11>>2]);
     $13 = (~~(($12)));
     __THREW__ = 0;
     invoke_vii(2011,($0|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __ZN16StackTraceSentryD2Ev(0);
      $16 = HEAP32[$0>>2]|0;
      STACKTOP = sp;return ($16|0);
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z44AssemblyU002DCSharp_JSONTemplates_m_FromRectP22mscorlib_System_Object28UnityEngine_UnityEngine_Rect($__this,$r) {
 $__this = $__this|0;
 $r = $r|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282464);
 __THREW__ = 0;
 invoke_v(305);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(724,0)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (Math_fround(+(invoke_fi(138,($r|0)))));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = $5 == Math_fround(0.0);
     if (!($8)) {
      __THREW__ = 0;
      $11 = (Math_fround(+(invoke_fi(138,($r|0)))));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      $16 = HEAP32[2993360>>2]|0;
      __THREW__ = 0;
      invoke_viif(16,($2|0),($16|0),(+$11));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
     }
     __THREW__ = 0;
     $19 = (Math_fround(+(invoke_fi(139,($r|0)))));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = $19 == Math_fround(0.0);
      if (!($22)) {
       __THREW__ = 0;
       $23 = (Math_fround(+(invoke_fi(139,($r|0)))));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       $28 = HEAP32[2993368>>2]|0;
       __THREW__ = 0;
       invoke_viif(16,($2|0),($28|0),(+$23));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      __THREW__ = 0;
      $31 = (Math_fround(+(invoke_fi(141,($r|0)))));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       $34 = $31 == Math_fround(0.0);
       if (!($34)) {
        __THREW__ = 0;
        $35 = (Math_fround(+(invoke_fi(141,($r|0)))));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
        $40 = HEAP32[2993376>>2]|0;
        __THREW__ = 0;
        invoke_viif(16,($2|0),($40|0),(+$35));
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         break;
        }
       }
       __THREW__ = 0;
       $43 = (Math_fround(+(invoke_fi(140,($r|0)))));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        $46 = $43 == Math_fround(0.0);
        if ($46) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($2|0);
        }
        __THREW__ = 0;
        $47 = (Math_fround(+(invoke_fi(140,($r|0)))));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if (!($49)) {
         __THREW__ = 0;
         invoke_vi(3799,($2|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[2993384>>2]|0;
          __THREW__ = 0;
          invoke_viif(16,($2|0),($52|0),(+$47));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($2|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z42AssemblyU002DCSharp_JSONTemplates_m_ToRectP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$obj) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $V_1$0 = 0, $V_4 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282512);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 HEAP32[$V_4>>2] = 0;
 __THREW__ = 0;
 invoke_v(306);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  $lpad$phi$index = $5;$lpad$phi$index2 = $6;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $2 = (($obj) + 20|0);
 $V_1$0 = 0;
 L5: while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($obj|0));
  $141 = __THREW__; __THREW__ = 0;
  $142 = $141&1;
  if ($142) {
   break;
  }
  __THREW__ = 0;
  $143 = (invoke_ii(722,($obj|0))|0);
  $144 = __THREW__; __THREW__ = 0;
  $145 = $144&1;
  if ($145) {
   break;
  }
  $146 = ($V_1$0|0)<($143|0);
  if (!($146)) {
   label = 69;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($obj|0));
  $147 = __THREW__; __THREW__ = 0;
  $148 = $147&1;
  if ($148) {
   break;
  }
  $7 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($7|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   break;
  }
  __THREW__ = 0;
  $10 = (invoke_iiii(1642,(1332456|0),($7|0),($V_1$0|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   break;
  }
  $13 = ($10|0)==(0|0);
  do {
   if (!($13)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break L5;
    }
    $16 = HEAP8[((1283616 + 116|0))>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break L5;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3802,(1283616|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break L5;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break L5;
    }
    $26 = HEAP32[((1283616 + 80|0))>>2]|0;
    $27 = (($26) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     __THREW__ = 0;
     (invoke_ii(2996,(1400808|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break L5;
     }
     __THREW__ = 0;
     $32 = (invoke_ii(3469,(1400808|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vii(1329,($32|0),4);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break L5;
     }
     $39 = HEAP32[2993432>>2]|0;
     __THREW__ = 0;
     invoke_viiii(461,(1397040|0),($32|0),($39|0),0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break L5;
     }
     $44 = HEAP32[2993440>>2]|0;
     __THREW__ = 0;
     invoke_viiii(461,(1397040|0),($32|0),($44|0),1);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break L5;
     }
     $49 = HEAP32[2993448>>2]|0;
     __THREW__ = 0;
     invoke_viiii(461,(1397040|0),($32|0),($49|0),2);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break L5;
     }
     $54 = HEAP32[2993456>>2]|0;
     __THREW__ = 0;
     invoke_viiii(461,(1397040|0),($32|0),($54|0),3);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break L5;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break L5;
     }
     $59 = HEAP8[((1283616 + 116|0))>>0]|0;
     $60 = ($59<<24>>24)==(0);
     if ($60) {
      __THREW__ = 0;
      (invoke_ii(2996,(1283616|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L5;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1283616|0))|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3802,(1283616|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break L5;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break L5;
     }
     $69 = HEAP32[((1283616 + 80|0))>>2]|0;
     $70 = (($69) + 8|0);
     HEAP32[$70>>2] = $32;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     break L5;
    }
    $73 = HEAP8[((1283616 + 116|0))>>0]|0;
    $74 = ($73<<24>>24)==(0);
    if ($74) {
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      break L5;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1283616|0))|0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3802,(1283616|0));
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if ($80) {
      break L5;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1283616|0))|0);
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break L5;
    }
    $83 = HEAP32[((1283616 + 80|0))>>2]|0;
    $84 = (($83) + 8|0);
    $85 = HEAP32[$84>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($85|0));
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     break L5;
    }
    __THREW__ = 0;
    $88 = (invoke_iiiii(299,(1398096|0),($85|0),($10|0),($V_4|0))|0);
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     break L5;
    }
    if ($88) {
     $91 = HEAP32[$V_4>>2]|0;
     if ((($91|0) == 0)) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break L5;
      }
      __THREW__ = 0;
      $94 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3799,($94|0));
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       break L5;
      }
      __THREW__ = 0;
      $99 = (Math_fround(+(invoke_fi(126,($94|0)))));
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vif(114,($agg$result|0),(+$99));
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       break L5;
      } else {
       break;
      }
     } else if ((($91|0) == 1)) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       break L5;
      }
      __THREW__ = 0;
      $106 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3799,($106|0));
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       break L5;
      }
      __THREW__ = 0;
      $111 = (Math_fround(+(invoke_fi(126,($106|0)))));
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vif(115,($agg$result|0),(+$111));
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       break L5;
      } else {
       break;
      }
     } else if ((($91|0) == 2)) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       break L5;
      }
      __THREW__ = 0;
      $118 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3799,($118|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       break L5;
      }
      __THREW__ = 0;
      $123 = (Math_fround(+(invoke_fi(126,($118|0)))));
      $124 = __THREW__; __THREW__ = 0;
      $125 = $124&1;
      if ($125) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vif(117,($agg$result|0),(+$123));
      $126 = __THREW__; __THREW__ = 0;
      $127 = $126&1;
      if ($127) {
       break L5;
      } else {
       break;
      }
     } else if ((($91|0) == 3)) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if ($129) {
       break L5;
      }
      __THREW__ = 0;
      $130 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vi(3799,($130|0));
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       break L5;
      }
      __THREW__ = 0;
      $135 = (Math_fround(+(invoke_fi(126,($130|0)))));
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break L5;
      }
      __THREW__ = 0;
      invoke_vif(116,($agg$result|0),(+$135));
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       break L5;
      } else {
       break;
      }
     } else {
      break;
     }
    }
   }
  } while(0);
  $140 = (($V_1$0) + 1)|0;
  $V_1$0 = $140;
 }
 if ((label|0) == 69) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $lpad$phi$index = $3;$lpad$phi$index2 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z50AssemblyU002DCSharp_JSONTemplates_m_FromRectOffsetP22mscorlib_System_ObjectP34UnityEngine_UnityEngine_RectOffset($__this,$r) {
 $__this = $__this|0;
 $r = $r|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282560);
 __THREW__ = 0;
 invoke_v(307);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(724,0)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($r|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_ii(2586,($r|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = ($7|0)==(0);
      if (!($10)) {
       __THREW__ = 0;
       invoke_vi(3799,($r|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       $15 = (invoke_ii(2586,($r|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
       $20 = HEAP32[2993472>>2]|0;
       __THREW__ = 0;
       invoke_viii(260,($2|0),($20|0),($15|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vi(3799,($r|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       $25 = (invoke_ii(2583,($r|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        $28 = ($25|0)==(0);
        if (!($28)) {
         __THREW__ = 0;
         invoke_vi(3799,($r|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         __THREW__ = 0;
         $31 = (invoke_ii(2583,($r|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($2|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          break;
         }
         $36 = HEAP32[2993480>>2]|0;
         __THREW__ = 0;
         invoke_viii(260,($2|0),($36|0),($31|0));
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($r|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         __THREW__ = 0;
         $41 = (invoke_ii(2584,($r|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          $44 = ($41|0)==(0);
          if (!($44)) {
           __THREW__ = 0;
           invoke_vi(3799,($r|0));
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            break;
           }
           __THREW__ = 0;
           $47 = (invoke_ii(2584,($r|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($2|0));
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           if ($51) {
            break;
           }
           $52 = HEAP32[2993488>>2]|0;
           __THREW__ = 0;
           invoke_viii(260,($2|0),($52|0),($47|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if ($54) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($r|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if (!($56)) {
           __THREW__ = 0;
           $57 = (invoke_ii(2585,($r|0))|0);
           $58 = __THREW__; __THREW__ = 0;
           $59 = $58&1;
           if (!($59)) {
            $60 = ($57|0)==(0);
            if ($60) {
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($2|0);
            }
            __THREW__ = 0;
            invoke_vi(3799,($r|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if (!($62)) {
             __THREW__ = 0;
             $63 = (invoke_ii(2585,($r|0))|0);
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if (!($65)) {
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $66 = __THREW__; __THREW__ = 0;
              $67 = $66&1;
              if (!($67)) {
               $68 = HEAP32[2993496>>2]|0;
               __THREW__ = 0;
               invoke_viii(260,($2|0),($68|0),($63|0));
               $69 = __THREW__; __THREW__ = 0;
               $70 = $69&1;
               if (!($70)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($2|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z48AssemblyU002DCSharp_JSONTemplates_m_ToRectOffsetP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_4 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1282608);
 HEAP32[$V_4>>2] = 0;
 __THREW__ = 0;
 invoke_v(308);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2746216|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2746216|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(2991,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($obj) + 20|0);
     $V_1$0 = 0;
     L6: while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $156 = __THREW__; __THREW__ = 0;
      $157 = $156&1;
      if ($157) {
       break;
      }
      __THREW__ = 0;
      $158 = (invoke_ii(722,($obj|0))|0);
      $159 = __THREW__; __THREW__ = 0;
      $160 = $159&1;
      if ($160) {
       break;
      }
      $161 = ($V_1$0|0)<($158|0);
      if (!($161)) {
       label = 72;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $162 = __THREW__; __THREW__ = 0;
      $163 = $162&1;
      if ($163) {
       break;
      }
      $14 = HEAP32[$9>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($14|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_iiii(1642,(1332456|0),($14|0),($V_1$0|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      $20 = ($17|0)==(0|0);
      do {
       if (!($20)) {
        __THREW__ = 0;
        (invoke_ii(2996,(1283616|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if ($22) {
         break L6;
        }
        $23 = HEAP8[((1283616 + 116|0))>>0]|0;
        $24 = ($23<<24>>24)==(0);
        if ($24) {
         __THREW__ = 0;
         (invoke_ii(2996,(1283616|0))|0);
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if ($26) {
          break L6;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1283616|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3802,(1283616|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break L6;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1283616|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         break L6;
        }
        $33 = HEAP32[((1283616 + 80|0))>>2]|0;
        $34 = (($33) + 12|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = ($35|0)==(0|0);
        if ($36) {
         __THREW__ = 0;
         (invoke_ii(2996,(1400808|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break L6;
         }
         __THREW__ = 0;
         $39 = (invoke_ii(3469,(1400808|0))|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vii(1329,($39|0),4);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3799,($39|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L6;
         }
         $46 = HEAP32[2993560>>2]|0;
         __THREW__ = 0;
         invoke_viiii(461,(1397040|0),($39|0),($46|0),0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3799,($39|0));
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if ($50) {
          break L6;
         }
         $51 = HEAP32[2993568>>2]|0;
         __THREW__ = 0;
         invoke_viiii(461,(1397040|0),($39|0),($51|0),1);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3799,($39|0));
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break L6;
         }
         $56 = HEAP32[2993576>>2]|0;
         __THREW__ = 0;
         invoke_viiii(461,(1397040|0),($39|0),($56|0),2);
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3799,($39|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L6;
         }
         $61 = HEAP32[2993584>>2]|0;
         __THREW__ = 0;
         invoke_viiii(461,(1397040|0),($39|0),($61|0),3);
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break L6;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1283616|0))|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break L6;
         }
         $66 = HEAP8[((1283616 + 116|0))>>0]|0;
         $67 = ($66<<24>>24)==(0);
         if ($67) {
          __THREW__ = 0;
          (invoke_ii(2996,(1283616|0))|0);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if ($69) {
           break L6;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(1283616|0))|0);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           break L6;
          }
          __THREW__ = 0;
          invoke_vi(3802,(1283616|0));
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L6;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1283616|0))|0);
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          break L6;
         }
         $76 = HEAP32[((1283616 + 80|0))>>2]|0;
         $77 = (($76) + 12|0);
         HEAP32[$77>>2] = $39;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1283616|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         break L6;
        }
        $80 = HEAP8[((1283616 + 116|0))>>0]|0;
        $81 = ($80<<24>>24)==(0);
        if ($81) {
         __THREW__ = 0;
         (invoke_ii(2996,(1283616|0))|0);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          break L6;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1283616|0))|0);
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3802,(1283616|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break L6;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1283616|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         break L6;
        }
        $90 = HEAP32[((1283616 + 80|0))>>2]|0;
        $91 = (($90) + 12|0);
        $92 = HEAP32[$91>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($92|0));
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         break L6;
        }
        __THREW__ = 0;
        $95 = (invoke_iiiii(299,(1398096|0),($92|0),($17|0),($V_4|0))|0);
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         break L6;
        }
        if (!($95)) {
         break;
        }
        $98 = HEAP32[$V_4>>2]|0;
        if ((($98|0) == 2)) {
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          break L6;
         }
         __THREW__ = 0;
         $129 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
         $130 = __THREW__; __THREW__ = 0;
         $131 = $130&1;
         if ($131) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3799,($129|0));
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          break L6;
         }
         $134 = (($129) + 28|0);
         $135 = Math_fround(HEAPF32[$134>>2]);
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $136 = __THREW__; __THREW__ = 0;
         $137 = $136&1;
         if ($137) {
          break L6;
         }
         $138 = (~~(($135)));
         __THREW__ = 0;
         invoke_vii(2058,($4|0),($138|0));
         $139 = __THREW__; __THREW__ = 0;
         $140 = $139&1;
         if ($140) {
          break L6;
         } else {
          break;
         }
        } else if ((($98|0) == 3)) {
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $141 = __THREW__; __THREW__ = 0;
         $142 = $141&1;
         if ($142) {
          break L6;
         }
         __THREW__ = 0;
         $143 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if ($145) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3799,($143|0));
         $146 = __THREW__; __THREW__ = 0;
         $147 = $146&1;
         if ($147) {
          break L6;
         }
         $148 = (($143) + 28|0);
         $149 = Math_fround(HEAPF32[$148>>2]);
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          break L6;
         }
         $152 = (~~(($149)));
         __THREW__ = 0;
         invoke_vii(2059,($4|0),($152|0));
         $153 = __THREW__; __THREW__ = 0;
         $154 = $153&1;
         if ($154) {
          break L6;
         } else {
          break;
         }
        } else if ((($98|0) == 0)) {
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          break L6;
         }
         __THREW__ = 0;
         $101 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
         $102 = __THREW__; __THREW__ = 0;
         $103 = $102&1;
         if ($103) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3799,($101|0));
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          break L6;
         }
         $106 = (($101) + 28|0);
         $107 = Math_fround(HEAPF32[$106>>2]);
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          break L6;
         }
         $110 = (~~(($107)));
         __THREW__ = 0;
         invoke_vii(2060,($4|0),($110|0));
         $111 = __THREW__; __THREW__ = 0;
         $112 = $111&1;
         if ($112) {
          break L6;
         } else {
          break;
         }
        } else if ((($98|0) == 1)) {
         __THREW__ = 0;
         invoke_vi(3799,($obj|0));
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          break L6;
         }
         __THREW__ = 0;
         $115 = (invoke_iii(241,($obj|0),($V_1$0|0))|0);
         $116 = __THREW__; __THREW__ = 0;
         $117 = $116&1;
         if ($117) {
          break L6;
         }
         __THREW__ = 0;
         invoke_vi(3799,($115|0));
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          break L6;
         }
         $120 = (($115) + 28|0);
         $121 = Math_fround(HEAPF32[$120>>2]);
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          break L6;
         }
         $124 = (~~(($121)));
         __THREW__ = 0;
         invoke_vii(2057,($4|0),($124|0));
         $125 = __THREW__; __THREW__ = 0;
         $126 = $125&1;
         if ($126) {
          break L6;
         } else {
          break;
         }
        } else {
         break;
        }
       }
      } while(0);
      $155 = (($V_1$0) + 1)|0;
      $V_1$0 = $155;
     }
     if ((label|0) == 72) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($4|0);
     }
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index2 = $11;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEPFPvS3_P22mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector2Traits17VoidPointerTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector2PvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2771616,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits37UnityEngine_UnityEngine_Vector2TraitsE6InvokeEPFPvS3_31UnityEngine_UnityEngine_Vector2ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFPvS3_31UnityEngine_UnityEngine_Vector3ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector3Traits17VoidPointerTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits37UnityEngine_UnityEngine_Vector4TraitsE6InvokeEPFPvS3_31UnityEngine_UnityEngine_Vector4ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector4Traits17VoidPointerTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector4PvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2807040,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits39UnityEngine_UnityEngine_Matrix4x4TraitsE6InvokeEPFPvS3_33UnityEngine_UnityEngine_Matrix4x4ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I39UnityEngine_UnityEngine_Matrix4x4Traits17VoidPointerTraitsE6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits40UnityEngine_UnityEngine_QuaternionTraitsE6InvokeEPFPvS3_34UnityEngine_UnityEngine_QuaternionES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I40UnityEngine_UnityEngine_QuaternionTraits17VoidPointerTraitsE6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2796280,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPFPvS3_29UnityEngine_UnityEngine_ColorES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I35UnityEngine_UnityEngine_ColorTraits17VoidPointerTraitsE6InvokeEPF29UnityEngine_UnityEngine_ColorPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2793208,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits39UnityEngine_UnityEngine_LayerMaskTraitsE6InvokeEPFPvS3_33UnityEngine_UnityEngine_LayerMaskES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I39UnityEngine_UnityEngine_LayerMaskTraits17VoidPointerTraitsE6InvokeEPF33UnityEngine_UnityEngine_LayerMaskPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2714712,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits34UnityEngine_UnityEngine_RectTraitsE6InvokeEPFPvS3_28UnityEngine_UnityEngine_RectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I34UnityEngine_UnityEngine_RectTraits17VoidPointerTraitsE6InvokeEPF28UnityEngine_UnityEngine_RectPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2797856,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z93AssemblyU002DCSharp_JSONTemplates_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map0P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z93AssemblyU002DCSharp_JSONTemplates_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map1P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z93AssemblyU002DCSharp_JSONTemplates_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map2P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z66AssemblyU002DCSharp_U003CPrivateImplementationDetailsU003E_m__ctorP58AssemblyU002DCSharp_U003CPrivateImplementationDetailsU003E($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1283936);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z89AssemblyU002DCSharp_U003CPrivateImplementationDetailsU003E_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z69AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorMovement_m__ctorP61AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorMovement($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $L_13 = 0;
 var $L_22 = 0, $L_31 = 0, $L_37 = 0, $L_38 = 0, $L_44 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $_stackTraceSentry = sp + 84|0;
 $L_13 = sp;
 $L_22 = sp + 16|0;
 $L_31 = sp + 32|0;
 $L_37 = sp + 48|0;
 $L_38 = sp + 60|0;
 $L_44 = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1285952);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 8|0);
   HEAPF32[$2>>2] = Math_fround(10.0);
   $3 = (($__this) + 12|0);
   HEAPF32[$3>>2] = Math_fround(10.0);
   $4 = (($__this) + 16|0);
   HEAPF32[$4>>2] = Math_fround(10.0);
   __THREW__ = 0;
   (invoke_ii(2996,(1174960|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1174960|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_iii(2232,(1174960|0),3)|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      invoke_vi(3799,($9|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       $14 = (($9) + 12|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = ($15|0)==(0);
       if ($16) {
        __THREW__ = 0;
        $17 = (invoke_i(132)|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($17|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break;
        }
       }
       $24 = (($9) + 16|0);
       ;HEAP32[$L_13+0>>2]=0|0;HEAP32[$L_13+4>>2]=0|0;HEAP32[$L_13+8>>2]=0|0;HEAP32[$L_13+12>>2]=0|0;
       __THREW__ = 0;
       invoke_viff(16,($L_13|0),-90.0,1.0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        ;HEAP32[$24+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$24+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$24+8>>2]=HEAP32[$L_13+8>>2]|0;HEAP32[$24+12>>2]=HEAP32[$L_13+12>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($9|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         $29 = HEAP32[$14>>2]|0;
         $30 = ($29>>>0)<(2);
         if ($30) {
          __THREW__ = 0;
          $31 = (invoke_i(132)|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if ($33) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($31|0));
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if ($35) {
           break;
          }
         }
         $36 = HEAP32[$9>>2]|0;
         $37 = (($36) + 92|0);
         $38 = HEAP32[$37>>2]|0;
         ;HEAP32[$L_22+0>>2]=0|0;HEAP32[$L_22+4>>2]=0|0;HEAP32[$L_22+8>>2]=0|0;HEAP32[$L_22+12>>2]=0|0;
         __THREW__ = 0;
         invoke_viff(16,($L_22|0),0.0,1.0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if (!($40)) {
          $41 = (($24) + ($38)|0);
          ;HEAP32[$41+0>>2]=HEAP32[$L_22+0>>2]|0;HEAP32[$41+4>>2]=HEAP32[$L_22+4>>2]|0;HEAP32[$41+8>>2]=HEAP32[$L_22+8>>2]|0;HEAP32[$41+12>>2]=HEAP32[$L_22+12>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($9|0));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if (!($43)) {
           $44 = HEAP32[$14>>2]|0;
           $45 = ($44>>>0)<(3);
           if ($45) {
            __THREW__ = 0;
            $46 = (invoke_i(132)|0);
            $47 = __THREW__; __THREW__ = 0;
            $48 = $47&1;
            if ($48) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($46|0));
            $49 = __THREW__; __THREW__ = 0;
            $50 = $49&1;
            if ($50) {
             break;
            }
           }
           $51 = HEAP32[$9>>2]|0;
           $52 = (($51) + 92|0);
           $53 = HEAP32[$52>>2]|0;
           ;HEAP32[$L_31+0>>2]=0|0;HEAP32[$L_31+4>>2]=0|0;HEAP32[$L_31+8>>2]=0|0;HEAP32[$L_31+12>>2]=0|0;
           __THREW__ = 0;
           invoke_viff(16,($L_31|0),90.0,0.0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            $56 = $53 << 1;
            $57 = (($24) + ($56)|0);
            ;HEAP32[$57+0>>2]=HEAP32[$L_31+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$L_31+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$L_31+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$L_31+12>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2845784|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             __THREW__ = 0;
             $60 = (invoke_ii(3469,(2845784|0))|0);
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if (!($62)) {
              __THREW__ = 0;
              invoke_vii(2174,($60|0),($9|0));
              $63 = __THREW__; __THREW__ = 0;
              $64 = $63&1;
              if (!($64)) {
               $65 = (($__this) + 20|0);
               HEAP32[$65>>2] = $60;
               $66 = (($__this) + 24|0);
               HEAPF32[$66>>2] = Math_fround(30.0);
               $67 = (($__this) + 28|0);
               HEAPF32[$67>>2] = Math_fround(20.0);
               $68 = (($__this) + 32|0);
               HEAPF32[$68>>2] = Math_fround(10.0);
               $69 = (($__this) + 36|0);
               HEAPF32[$69>>2] = Math_fround(20.0);
               __THREW__ = 0;
               invoke_vii(2070,($L_37|0),(0|0));
               $70 = __THREW__; __THREW__ = 0;
               $71 = $70&1;
               if (!($71)) {
                $72 = (($__this) + 56|0);
                ;HEAP32[$72+0>>2]=HEAP32[$L_37+0>>2]|0;HEAP32[$72+4>>2]=HEAP32[$L_37+4>>2]|0;HEAP32[$72+8>>2]=HEAP32[$L_37+8>>2]|0;
                __THREW__ = 0;
                invoke_vii(2070,($L_38|0),(0|0));
                $73 = __THREW__; __THREW__ = 0;
                $74 = $73&1;
                if (!($74)) {
                 $75 = (($__this) + 68|0);
                 ;HEAP32[$75+0>>2]=HEAP32[$L_38+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$L_38+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$L_38+8>>2]|0;
                 ;HEAP32[$L_44+0>>2]=0|0;HEAP32[$L_44+4>>2]=0|0;HEAP32[$L_44+8>>2]=0|0;
                 __THREW__ = 0;
                 invoke_vifff(4,($L_44|0),inf,0.0,0.0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if (!($77)) {
                  $78 = (($__this) + 80|0);
                  ;HEAP32[$78+0>>2]=HEAP32[$L_44+0>>2]|0;HEAP32[$78+4>>2]=HEAP32[$L_44+4>>2]|0;HEAP32[$78+8>>2]=HEAP32[$L_44+8>>2]|0;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
}
function __Z68AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorJumping_m__ctorP60AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorJumping($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $L_6 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1287336);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 }
 $2 = (($__this) + 8|0);
 HEAP8[$2>>0] = 1;
 $3 = (($__this) + 12|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($__this) + 16|0);
 HEAPF32[$4>>2] = Math_fround(4.09999990463256835938);
 $5 = (($__this) + 24|0);
 HEAPF32[$5>>2] = Math_fround(0.5);
 $6 = (($__this) + 36|0);
 HEAPF32[$6>>2] = Math_fround(-100.0);
 __THREW__ = 0;
 invoke_vii(2073,($L_6|0),(0|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  $9 = (($__this) + 40|0);
  ;HEAP32[$9+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$L_6+8>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z75AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorMovingPlatform_m__ctorP67AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorMovingPlatform($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1288016);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP8[$2>>0] = 1;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = 2;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z68AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorSliding_m__ctorP60AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorSliding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1288784);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP8[$2>>0] = 1;
  $3 = (($__this) + 12|0);
  HEAPF32[$3>>2] = Math_fround(15.0);
  $4 = (($__this) + 16|0);
  HEAPF32[$4>>2] = Math_fround(1.0);
  $5 = (($__this) + 20|0);
  HEAPF32[$5>>2] = Math_fround(0.400000005960464477539);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z106AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024_m__ctorP98AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024P53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this,$self_) {
 $__this = $__this|0;
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1289192);
 __THREW__ = 0;
 invoke_vi(3806,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 20|0);
  HEAP32[$2>>2] = $self_;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z109AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024_m_MoveNextP98AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024($__this) {
 $__this = $__this|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B13_0$0 = 0, $L_33 = 0;
 var $L_40 = 0, $L_40$byval_copy = 0, $L_43 = 0, $L_43$byval_copy = 0, $L_44 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_43$byval_copy = sp + 56|0;
 $L_40$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_33 = sp + 16|0;
 $L_40 = sp + 20|0;
 $L_43 = sp + 32|0;
 $L_44 = sp + 44|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1289240);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 do {
  if ((($1|0) == 3)) {
   $77 = (($__this) + 20|0);
   $78 = HEAP32[$77>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($78|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if (!($80)) {
    $81 = (($78) + 52|0);
    $82 = HEAP8[$81>>0]|0;
    $83 = ($82<<24>>24)==(0);
    if ($83) {
     $$pre$phiZ2D = $77;
     label = 38;
    } else {
     $84 = (($__this) + 16|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = HEAP32[$77>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($86|0));
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if (!($88)) {
      $89 = (($86) + 44|0);
      $90 = HEAP32[$89>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($90|0));
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if (!($92)) {
       $93 = (($90) + 20|0);
       $94 = HEAP32[$93>>2]|0;
       __THREW__ = 0;
       $95 = (invoke_iiii(1318,(0|0),($85|0),($94|0))|0);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        if ($95) {
         HEAP32[$L_33>>2] = 1;
         __THREW__ = 0;
         (invoke_ii(2996,(2155952|0))|0);
         $98 = __THREW__; __THREW__ = 0;
         $99 = $98&1;
         if (!($99)) {
          __THREW__ = 0;
          $100 = (invoke_iii(2724,(2155952|0),($L_33|0))|0);
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if (!($102)) {
           __THREW__ = 0;
           $103 = (invoke_iiii(1646,($__this|0),4,($100|0))|0);
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if (!($105)) {
            $106 = $103&1;
            $G_B13_0$0 = $106;
            $135 = ($G_B13_0$0|0)!=(0);
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($135|0);
           }
          }
         }
        } else {
         $$pre$phiZ2D = $77;
         label = 38;
        }
       }
      }
     }
    }
   }
  } else if ((($1|0) == 4)) {
   $$pre = (($__this) + 20|0);
   $$pre$phiZ2D = $$pre;
   label = 38;
  } else if ((($1|0) == 2)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2715776|0))|0);
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if (!($67)) {
    __THREW__ = 0;
    $68 = (invoke_ii(3469,(2715776|0))|0);
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if (!($70)) {
     __THREW__ = 0;
     invoke_vi(2898,($68|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if (!($72)) {
      __THREW__ = 0;
      $73 = (invoke_iiii(1646,($__this|0),3,($68|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if (!($75)) {
       $76 = $73&1;
       $G_B13_0$0 = $76;
       $135 = ($G_B13_0$0|0)!=(0);
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($135|0);
      }
     }
    }
   }
  } else if ((($1|0) == 1)) {
   $G_B13_0$0 = 0;
   $135 = ($G_B13_0$0|0)!=(0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($135|0);
  } else {
   $2 = (($__this) + 20|0);
   $3 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($3) + 44|0);
    $7 = HEAP32[$6>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($7) + 8|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      label = 46;
     } else {
      $15 = HEAP32[$2>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($15|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = (($15) + 44|0);
       $19 = HEAP32[$18>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($19|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = (($19) + 12|0);
        $23 = HEAP32[$22>>2]|0;
        $24 = ($23|0)==(1);
        if (!($24)) {
         $25 = HEAP32[$2>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($25|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         $28 = (($25) + 44|0);
         $29 = HEAP32[$28>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($29|0));
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          break;
         }
         $32 = (($29) + 12|0);
         $33 = HEAP32[$32>>2]|0;
         $34 = ($33|0)==(2);
         if (!($34)) {
          label = 46;
          break;
         }
        }
        $35 = HEAP32[$2>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($35|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         $38 = (($35) + 44|0);
         $39 = HEAP32[$38>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($39|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = (($39) + 156|0);
          $43 = HEAP8[$42>>0]|0;
          $44 = ($43<<24>>24)==(0);
          if ($44) {
           $$pre$phiZ2D = $2;
           label = 38;
          } else {
           $45 = HEAP32[$2>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($45|0));
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            $48 = (($45) + 44|0);
            $49 = HEAP32[$48>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($49|0));
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if (!($51)) {
             $52 = (($49) + 20|0);
             $53 = HEAP32[$52>>2]|0;
             $54 = (($__this) + 16|0);
             HEAP32[$54>>2] = $53;
             __THREW__ = 0;
             (invoke_ii(2996,(2715776|0))|0);
             $55 = __THREW__; __THREW__ = 0;
             $56 = $55&1;
             if (!($56)) {
              __THREW__ = 0;
              $57 = (invoke_ii(3469,(2715776|0))|0);
              $58 = __THREW__; __THREW__ = 0;
              $59 = $58&1;
              if (!($59)) {
               __THREW__ = 0;
               invoke_vi(2898,($57|0));
               $60 = __THREW__; __THREW__ = 0;
               $61 = $60&1;
               if (!($61)) {
                __THREW__ = 0;
                $62 = (invoke_iiii(1646,($__this|0),2,($57|0))|0);
                $63 = __THREW__; __THREW__ = 0;
                $64 = $63&1;
                if (!($64)) {
                 $65 = $62&1;
                 $G_B13_0$0 = $65;
                 $135 = ($G_B13_0$0|0)!=(0);
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($135|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 38) {
  $107 = HEAP32[$$pre$phiZ2D>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($107|0));
  $108 = __THREW__; __THREW__ = 0;
  $109 = $108&1;
  if (!($109)) {
   $110 = (($107) + 36|0);
   $111 = HEAP32[$110>>2]|0;
   $112 = HEAP32[$$pre$phiZ2D>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($112|0));
   $113 = __THREW__; __THREW__ = 0;
   $114 = $113&1;
   if (!($114)) {
    $115 = (($112) + 36|0);
    $116 = HEAP32[$115>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($116|0));
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if (!($118)) {
     $119 = (($116) + 44|0);
     ;HEAP32[$L_40+0>>2]=HEAP32[$119+0>>2]|0;HEAP32[$L_40+4>>2]=HEAP32[$119+4>>2]|0;HEAP32[$L_40+8>>2]=HEAP32[$119+8>>2]|0;
     $120 = HEAP32[$$pre$phiZ2D>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($120|0));
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if (!($122)) {
      $123 = (($120) + 44|0);
      $124 = HEAP32[$123>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($124|0));
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if (!($126)) {
       $127 = (($124) + 144|0);
       ;HEAP32[$L_43+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$L_43+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$L_43+8>>2]=HEAP32[$127+8>>2]|0;
       __THREW__ = 0;
       ;HEAP32[$L_40$byval_copy+0>>2]=HEAP32[$L_40+0>>2]|0;HEAP32[$L_40$byval_copy+4>>2]=HEAP32[$L_40+4>>2]|0;HEAP32[$L_40$byval_copy+8>>2]=HEAP32[$L_40+8>>2]|0;
       ;HEAP32[$L_43$byval_copy+0>>2]=HEAP32[$L_43+0>>2]|0;HEAP32[$L_43$byval_copy+4>>2]=HEAP32[$L_43+4>>2]|0;HEAP32[$L_43$byval_copy+8>>2]=HEAP32[$L_43+8>>2]|0;
       invoke_viiii(223,($L_44|0),(0|0),($L_40$byval_copy|0),($L_43$byval_copy|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if (!($129)) {
        __THREW__ = 0;
        invoke_vi(3799,($111|0));
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if (!($131)) {
         $132 = (($111) + 44|0);
         ;HEAP32[$132+0>>2]=HEAP32[$L_44+0>>2]|0;HEAP32[$132+4>>2]=HEAP32[$L_44+4>>2]|0;HEAP32[$132+8>>2]=HEAP32[$L_44+8>>2]|0;
         label = 46;
        }
       }
      }
     }
    }
   }
  }
 }
 if ((label|0) == 46) {
  __THREW__ = 0;
  (invoke_iii(2732,($__this|0),1)|0);
  $133 = __THREW__; __THREW__ = 0;
  $134 = $133&1;
  if (!($134)) {
   $G_B13_0$0 = 0;
   $135 = ($G_B13_0$0|0)!=(0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($135|0);
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z129AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z100AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_m__ctorP92AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243P53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this,$self_) {
 $__this = $__this|0;
 $self_ = $self_|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1289688);
 __THREW__ = 0;
 invoke_vi(3807,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $self_;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z108AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_m_GetEnumeratorP92AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1289736);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1289552|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_ii(3469,(1289552|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_vii(1204,($4|0),($1|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z123AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z61AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m__ctorP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $L_8 = 0, $L_9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 36|0;
 $L_2 = sp;
 $L_8 = sp + 12|0;
 $L_9 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290136);
 __THREW__ = 0;
 invoke_vi(3120,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 16|0);
  HEAP8[$2>>0] = 1;
  $3 = (($__this) + 17|0);
  HEAP8[$3>>0] = 1;
  __THREW__ = 0;
  invoke_vii(2070,($L_2|0),(0|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($__this) + 20|0);
   ;HEAP32[$6+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$L_2+8>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1286672|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(1286672|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(1416,($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 36|0);
      HEAP32[$14>>2] = $9;
      __THREW__ = 0;
      (invoke_ii(2996,(1287880|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(1287880|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vi(1417,($17|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         $22 = (($__this) + 40|0);
         HEAP32[$22>>2] = $17;
         __THREW__ = 0;
         (invoke_ii(2996,(1288648|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          $25 = (invoke_ii(3469,(1288648|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           invoke_vi(1418,($25|0));
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            $30 = (($__this) + 44|0);
            HEAP32[$30>>2] = $25;
            __THREW__ = 0;
            (invoke_ii(2996,(1289056|0))|0);
            $31 = __THREW__; __THREW__ = 0;
            $32 = $31&1;
            if (!($32)) {
             __THREW__ = 0;
             $33 = (invoke_ii(3469,(1289056|0))|0);
             $34 = __THREW__; __THREW__ = 0;
             $35 = $34&1;
             if (!($35)) {
              __THREW__ = 0;
              invoke_vi(1419,($33|0));
              $36 = __THREW__; __THREW__ = 0;
              $37 = $36&1;
              if (!($37)) {
               $38 = (($__this) + 48|0);
               HEAP32[$38>>2] = $33;
               $39 = (($__this) + 52|0);
               HEAP8[$39>>0] = 1;
               __THREW__ = 0;
               invoke_vii(2070,($L_8|0),(0|0));
               $40 = __THREW__; __THREW__ = 0;
               $41 = $40&1;
               if (!($41)) {
                $42 = (($__this) + 56|0);
                ;HEAP32[$42+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$L_8+8>>2]|0;
                __THREW__ = 0;
                invoke_vii(2070,($L_9|0),(0|0));
                $43 = __THREW__; __THREW__ = 0;
                $44 = $43&1;
                if (!($44)) {
                 $45 = (($__this) + 68|0);
                 ;HEAP32[$45+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$L_9+8>>2]|0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $46 = ___cxa_find_matching_catch()|0;
 $47 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($46|0);
 // unreachable;
}
function __Z61AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_AwakeP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290184);
 HEAP32[$0>>2] = 1299968;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(1189,($__this|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2839072|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2733,($4|0),(2839072|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($__this) + 84|0);
     HEAP32[$12>>2] = $9;
     __THREW__ = 0;
     $13 = (invoke_ii(2522,($__this|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = (($__this) + 80|0);
      HEAP32[$16>>2] = $13;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo620($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z70AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_UpdateFunctionP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = Math_fround(0);
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = Math_fround(0), $130 = Math_fround(0), $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = Math_fround(0), $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = Math_fround(0), $150 = 0;
 var $151 = 0, $152 = Math_fround(0), $153 = 0, $154 = Math_fround(0), $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = Math_fround(0), $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = Math_fround(0), $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = Math_fround(0), $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = Math_fround(0), $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = 0;
 var $26 = Math_fround(0), $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = Math_fround(0), $288 = 0, $289 = Math_fround(0), $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = Math_fround(0), $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = Math_fround(0), $310 = 0, $311 = 0, $312 = Math_fround(0);
 var $313 = Math_fround(0), $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = Math_fround(0), $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = Math_fround(0), $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0), $426 = 0, $427 = 0, $428 = 0, $429 = Math_fround(0), $43 = 0, $430 = 0, $431 = 0, $432 = Math_fround(0), $433 = Math_fround(0), $434 = 0, $435 = 0, $436 = 0, $437 = Math_fround(0), $438 = 0, $439 = 0;
 var $44 = 0, $440 = Math_fround(0), $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_10 = 0, $L_101 = 0, $L_102 = 0, $L_112 = 0, $L_118 = 0, $L_12 = 0;
 var $L_122 = 0, $L_123 = 0, $L_124 = 0, $L_13 = 0, $L_14 = 0, $L_154 = 0, $L_157 = 0, $L_159 = 0, $L_160 = 0, $L_164 = 0, $L_165 = 0, $L_166 = 0, $L_167 = 0, $L_179 = 0, $L_180 = 0, $L_182 = 0, $L_192 = 0, $L_193 = 0, $L_198 = 0, $L_199 = 0;
 var $L_2 = 0, $L_20 = 0, $L_202 = 0, $L_206 = 0, $L_207 = 0, $L_207$byval_copy = 0, $L_209 = 0, $L_209$byval_copy = 0, $L_210 = 0, $L_22 = 0, $L_23 = 0, $L_26 = 0, $L_27 = 0, $L_28 = 0, $L_3 = 0, $L_38 = 0, $L_4 = 0, $L_40 = 0, $L_47 = 0, $L_51 = 0;
 var $L_52 = 0, $L_53 = 0, $L_55 = 0, $L_61 = 0, $L_86 = 0, $L_89 = 0, $L_9 = 0, $L_90 = 0, $L_92 = 0, $V_1 = 0, $V_10 = 0, $V_13 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $V_6 = 0, $V_7$sroa$0$0 = Math_fround(0), $V_7$sroa$1$0 = Math_fround(0), $V_7$sroa$2$0 = Math_fround(0), $V_9 = 0;
 var $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 960|0;
 $L_209$byval_copy = sp + 888|0;
 $L_207$byval_copy = sp + 872|0;
 $_stackTraceSentry = sp + 864|0;
 $V_1 = sp + 852|0;
 $V_2 = sp + 840|0;
 $V_3 = sp + 824|0;
 $V_4 = sp + 808|0;
 $V_6 = sp + 796|0;
 $V_9 = sp + 784|0;
 $V_10 = sp + 772|0;
 $V_13 = sp + 760|0;
 $L_2 = sp + 748|0;
 $0 = sp + 736|0;
 $L_3 = sp + 724|0;
 $1 = sp + 712|0;
 $L_4 = sp + 700|0;
 $L_9 = sp + 688|0;
 $L_10 = sp + 676|0;
 $L_12 = sp + 664|0;
 $L_13 = sp + 652|0;
 $L_14 = sp + 640|0;
 $L_20 = sp + 624|0;
 $L_22 = sp + 608|0;
 $L_23 = sp + 592|0;
 $L_26 = sp + 576|0;
 $2 = sp + 560|0;
 $L_27 = sp + 544|0;
 $L_28 = sp + 528|0;
 $L_38 = sp + 516|0;
 $L_40 = sp + 504|0;
 $3 = sp + 492|0;
 $L_47 = sp + 480|0;
 $L_51 = sp + 468|0;
 $L_52 = sp + 456|0;
 $L_53 = sp + 444|0;
 $4 = sp + 432|0;
 $L_55 = sp + 180|0;
 $5 = sp + 168|0;
 $L_61 = sp + 156|0;
 $L_86 = sp + 144|0;
 $L_89 = sp + 132|0;
 $L_90 = sp + 120|0;
 $L_92 = sp + 108|0;
 $L_101 = sp + 96|0;
 $L_102 = sp + 84|0;
 $L_112 = sp + 60|0;
 $L_118 = sp + 48|0;
 $L_122 = sp + 36|0;
 $L_123 = sp + 24|0;
 $L_124 = sp + 12|0;
 $L_154 = sp;
 $L_157 = sp + 72|0;
 $L_159 = sp + 192|0;
 $L_160 = sp + 204|0;
 $L_164 = sp + 216|0;
 $L_165 = sp + 228|0;
 $L_166 = sp + 240|0;
 $L_167 = sp + 252|0;
 $L_179 = sp + 264|0;
 $L_180 = sp + 276|0;
 $L_182 = sp + 288|0;
 $L_192 = sp + 300|0;
 $L_193 = sp + 312|0;
 $L_198 = sp + 324|0;
 $L_199 = sp + 336|0;
 $L_202 = sp + 352|0;
 $L_206 = sp + 368|0;
 $L_207 = sp + 384|0;
 $L_209 = sp + 400|0;
 $L_210 = sp + 416|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290232);
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;HEAP32[$V_3+12>>2]=0|0;
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;HEAP32[$V_4+12>>2]=0|0;
 ;HEAP32[$V_6+0>>2]=0|0;HEAP32[$V_6+4>>2]=0|0;HEAP32[$V_6+8>>2]=0|0;
 ;HEAP32[$V_9+0>>2]=0|0;HEAP32[$V_9+4>>2]=0|0;HEAP32[$V_9+8>>2]=0|0;
 ;HEAP32[$V_10+0>>2]=0|0;HEAP32[$V_10+4>>2]=0|0;HEAP32[$V_10+8>>2]=0|0;
 ;HEAP32[$V_13+0>>2]=0|0;HEAP32[$V_13+4>>2]=0|0;HEAP32[$V_13+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(309);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if (!($7)) {
   $8 = (($__this) + 36|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($9) + 44|0);
    $13 = Math_fround(HEAPF32[$12>>2]);
    $14 = (($9) + 48|0);
    $15 = Math_fround(HEAPF32[$14>>2]);
    $16 = (($9) + 52|0);
    $17 = Math_fround(HEAPF32[$16>>2]);
    HEAPF32[$0>>2] = $13;
    $18 = (($0) + 4|0);
    HEAPF32[$18>>2] = $15;
    $19 = (($0) + 8|0);
    HEAPF32[$19>>2] = $17;
    __THREW__ = 0;
    ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
    invoke_viii(277,($L_2|0),($__this|0),($L_209$byval_copy|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = Math_fround(HEAPF32[$L_2>>2]);
     $23 = (($L_2) + 4|0);
     $24 = Math_fround(HEAPF32[$23>>2]);
     $25 = (($L_2) + 8|0);
     $26 = Math_fround(HEAPF32[$25>>2]);
     HEAPF32[$1>>2] = $22;
     $27 = (($1) + 4|0);
     HEAPF32[$27>>2] = $24;
     $28 = (($1) + 8|0);
     HEAPF32[$28>>2] = $26;
     __THREW__ = 0;
     ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;
     invoke_viii(278,($L_3|0),($__this|0),($L_209$byval_copy|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      $31 = Math_fround(HEAPF32[$L_3>>2]);
      $32 = (($L_3) + 4|0);
      $33 = Math_fround(HEAPF32[$32>>2]);
      $34 = (($L_3) + 8|0);
      $35 = Math_fround(HEAPF32[$34>>2]);
      __THREW__ = 0;
      invoke_vii(2070,($L_4|0),(0|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       ;HEAP32[$V_1+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_4+8>>2]|0;
       __THREW__ = 0;
       $38 = (invoke_ii(739,($__this|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if (!($40)) {
        do {
         if ($38) {
          $43 = (($__this) + 44|0);
          $44 = HEAP32[$43>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($44|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           break L1;
          }
          $47 = (($44) + 20|0);
          $48 = HEAP32[$47>>2]|0;
          $49 = HEAP32[$43>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($49|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           break L1;
          }
          $52 = (($49) + 24|0);
          ;HEAP32[$L_9+0>>2]=HEAP32[$52+0>>2]|0;HEAP32[$L_9+4>>2]=HEAP32[$52+4>>2]|0;HEAP32[$L_9+8>>2]=HEAP32[$52+8>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($48|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break L1;
          }
          __THREW__ = 0;
          ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_9+8>>2]|0;
          invoke_viii(780,($L_10|0),($48|0),($L_209$byval_copy|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           break L1;
          }
          ;HEAP32[$V_2+0>>2]=HEAP32[$L_10+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_10+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_10+8>>2]|0;
          $57 = HEAP32[$43>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($57|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if ($59) {
           break L1;
          }
          $60 = (($57) + 36|0);
          ;HEAP32[$L_12+0>>2]=HEAP32[$60+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$60+8>>2]|0;
          __THREW__ = 0;
          ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$V_2+8>>2]|0;
          ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;
          invoke_viiii(223,($L_13|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           break L1;
          }
          ;HEAP32[$V_1+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_13+8>>2]|0;
          __THREW__ = 0;
          invoke_vii(2070,($L_14|0),(0|0));
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if ($64) {
           break L1;
          }
          __THREW__ = 0;
          ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;
          ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_14+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_14+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_14+8>>2]|0;
          $65 = (invoke_iiii(1353,(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0))|0);
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           break L1;
          }
          if ($65) {
           $68 = (($__this) + 84|0);
           $69 = HEAP32[$68>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($69|0));
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            break L1;
           }
           __THREW__ = 0;
           ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;
           (invoke_iii(1237,($69|0),($L_209$byval_copy|0))|0);
           $72 = __THREW__; __THREW__ = 0;
           $73 = $72&1;
           if ($73) {
            break L1;
           }
          }
          $74 = HEAP32[$43>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($74|0));
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           break L1;
          }
          $77 = (($74) + 20|0);
          $78 = HEAP32[$77>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($78|0));
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vii(2133,($L_20|0),($78|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           break L1;
          }
          $83 = HEAP32[$43>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($83|0));
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if ($85) {
           break L1;
          }
          $86 = (($83) + 48|0);
          ;HEAP32[$L_22+0>>2]=HEAP32[$86+0>>2]|0;HEAP32[$L_22+4>>2]=HEAP32[$86+4>>2]|0;HEAP32[$L_22+8>>2]=HEAP32[$86+8>>2]|0;HEAP32[$L_22+12>>2]=HEAP32[$86+12>>2]|0;
          __THREW__ = 0;
          ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$L_20+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$L_20+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$L_20+8>>2]|0;HEAP32[$L_207$byval_copy+12>>2]=HEAP32[$L_20+12>>2]|0;
          ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_22+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_22+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_22+8>>2]|0;HEAP32[$L_209$byval_copy+12>>2]=HEAP32[$L_22+12>>2]|0;
          invoke_viiii(228,($L_23|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           break L1;
          }
          ;HEAP32[$V_3+0>>2]=HEAP32[$L_23+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_23+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_23+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[$L_23+12>>2]|0;
          $89 = HEAP32[$43>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($89|0));
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           break L1;
          }
          $92 = (($89) + 64|0);
          _memmove(($2|0),($92|0),16)|0;
          __THREW__ = 0;
          ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$L_209$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;
          invoke_viii(743,($L_26|0),(0|0),($L_209$byval_copy|0));
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           break L1;
          }
          __THREW__ = 0;
          ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$V_3+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$V_3+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$V_3+8>>2]|0;HEAP32[$L_207$byval_copy+12>>2]=HEAP32[$V_3+12>>2]|0;
          ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_26+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_26+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_26+8>>2]|0;HEAP32[$L_209$byval_copy+12>>2]=HEAP32[$L_26+12>>2]|0;
          invoke_viiii(228,($L_27|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
          $95 = __THREW__; __THREW__ = 0;
          $96 = $95&1;
          if ($96) {
           break L1;
          }
          ;HEAP32[$V_4+0>>2]=HEAP32[$L_27+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_27+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_27+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[$L_27+12>>2]|0;
          __THREW__ = 0;
          invoke_vii(2077,($L_28|0),($V_4|0));
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           break L1;
          }
          $99 = (($L_28) + 4|0);
          $100 = Math_fround(HEAPF32[$99>>2]);
          $101 = $100 == Math_fround(0.0);
          if ($101) {
           break;
          }
          $102 = (($__this) + 80|0);
          $103 = HEAP32[$102>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($103|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vifff(6,($103|0),0.0,(+$100),0.0);
          $106 = __THREW__; __THREW__ = 0;
          $107 = $106&1;
          if ($107) {
           break L1;
          }
         }
        } while(0);
        $108 = (($__this) + 80|0);
        $109 = HEAP32[$108>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($109|0));
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if (!($111)) {
         __THREW__ = 0;
         invoke_vii(2122,($L_38|0),($109|0));
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if (!($113)) {
          ;HEAP32[$V_6+0>>2]=HEAP32[$L_38+0>>2]|0;HEAP32[$V_6+4>>2]=HEAP32[$L_38+4>>2]|0;HEAP32[$V_6+8>>2]=HEAP32[$L_38+8>>2]|0;
          __THREW__ = 0;
          $114 = (Math_fround(+(invoke_fi(149,(0|0)))));
          $115 = __THREW__; __THREW__ = 0;
          $116 = $115&1;
          if (!($116)) {
           HEAPF32[$3>>2] = $31;
           $117 = (($3) + 4|0);
           HEAPF32[$117>>2] = $33;
           $118 = (($3) + 8|0);
           HEAPF32[$118>>2] = $35;
           __THREW__ = 0;
           ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
           invoke_viiif(2,($L_40|0),(0|0),($L_209$byval_copy|0),(+$114));
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if (!($120)) {
            $121 = Math_fround(HEAPF32[$L_40>>2]);
            $122 = (($L_40) + 4|0);
            $123 = Math_fround(HEAPF32[$122>>2]);
            $124 = (($L_40) + 8|0);
            $125 = Math_fround(HEAPF32[$124>>2]);
            $126 = (($__this) + 84|0);
            $127 = HEAP32[$126>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($127|0));
            $128 = __THREW__; __THREW__ = 0;
            $129 = $128&1;
            if (!($129)) {
             __THREW__ = 0;
             $130 = (Math_fround(+(invoke_fi(158,($127|0)))));
             $131 = __THREW__; __THREW__ = 0;
             $132 = $131&1;
             if (!($132)) {
              ;HEAP32[$L_47+0>>2]=0|0;HEAP32[$L_47+4>>2]=0|0;HEAP32[$L_47+8>>2]=0|0;
              __THREW__ = 0;
              invoke_vifff(4,($L_47|0),(+$121),0.0,(+$125));
              $133 = __THREW__; __THREW__ = 0;
              $134 = $133&1;
              if (!($134)) {
               ;HEAP32[$V_13+0>>2]=HEAP32[$L_47+0>>2]|0;HEAP32[$V_13+4>>2]=HEAP32[$L_47+4>>2]|0;HEAP32[$V_13+8>>2]=HEAP32[$L_47+8>>2]|0;
               __THREW__ = 0;
               $135 = (Math_fround(+(invoke_fi(136,($V_13|0)))));
               $136 = __THREW__; __THREW__ = 0;
               $137 = $136&1;
               if (!($137)) {
                __THREW__ = 0;
                $138 = (Math_fround(+(invoke_fiff(4,(0|0),(+$130),(+$135)))));
                $139 = __THREW__; __THREW__ = 0;
                $140 = $139&1;
                if (!($140)) {
                 $141 = (($__this) + 52|0);
                 $142 = HEAP8[$141>>0]|0;
                 $143 = ($142<<24>>24)==(0);
                 if ($143) {
                  $V_7$sroa$0$0 = $121;$V_7$sroa$1$0 = $123;$V_7$sroa$2$0 = $125;
                 } else {
                  __THREW__ = 0;
                  invoke_vii(2073,($L_51|0),(0|0));
                  $144 = __THREW__; __THREW__ = 0;
                  $145 = $144&1;
                  if ($145) {
                   break;
                  }
                  __THREW__ = 0;
                  ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_51+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_51+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_51+8>>2]|0;
                  invoke_viifi(3,($L_52|0),(0|0),(+$138),($L_209$byval_copy|0));
                  $146 = __THREW__; __THREW__ = 0;
                  $147 = $146&1;
                  if ($147) {
                   break;
                  }
                  HEAPF32[$4>>2] = $121;
                  $148 = (($4) + 4|0);
                  HEAPF32[$148>>2] = $123;
                  $149 = (($4) + 8|0);
                  HEAPF32[$149>>2] = $125;
                  __THREW__ = 0;
                  ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$4+8>>2]|0;
                  ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_52+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_52+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_52+8>>2]|0;
                  invoke_viiii(223,($L_53|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
                  $150 = __THREW__; __THREW__ = 0;
                  $151 = $150&1;
                  if ($151) {
                   break;
                  }
                  $152 = Math_fround(HEAPF32[$L_53>>2]);
                  $153 = (($L_53) + 4|0);
                  $154 = Math_fround(HEAPF32[$153>>2]);
                  $155 = (($L_53) + 8|0);
                  $156 = Math_fround(HEAPF32[$155>>2]);
                  $V_7$sroa$0$0 = $152;$V_7$sroa$1$0 = $154;$V_7$sroa$2$0 = $156;
                 }
                 $157 = (($__this) + 44|0);
                 $158 = HEAP32[$157>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($158|0));
                 $159 = __THREW__; __THREW__ = 0;
                 $160 = $159&1;
                 if (!($160)) {
                  $161 = (($158) + 16|0);
                  HEAP32[$161>>2] = 0;
                  __THREW__ = 0;
                  invoke_vii(2070,($L_55|0),(0|0));
                  $162 = __THREW__; __THREW__ = 0;
                  $163 = $162&1;
                  if (!($163)) {
                   $164 = (($__this) + 56|0);
                   ;HEAP32[$164+0>>2]=HEAP32[$L_55+0>>2]|0;HEAP32[$164+4>>2]=HEAP32[$L_55+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$L_55+8>>2]|0;
                   $165 = HEAP32[$8>>2]|0;
                   $166 = HEAP32[$126>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($166|0));
                   $167 = __THREW__; __THREW__ = 0;
                   $168 = $167&1;
                   if ($168) {
                    break;
                   }
                   HEAPF32[$5>>2] = $V_7$sroa$0$0;
                   $169 = (($5) + 4|0);
                   HEAPF32[$169>>2] = $V_7$sroa$1$0;
                   $170 = (($5) + 8|0);
                   HEAPF32[$170>>2] = $V_7$sroa$2$0;
                   __THREW__ = 0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$5+8>>2]|0;
                   $171 = (invoke_iii(1237,($166|0),($L_209$byval_copy|0))|0);
                   $172 = __THREW__; __THREW__ = 0;
                   $173 = $172&1;
                   if ($173) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($165|0));
                   $174 = __THREW__; __THREW__ = 0;
                   $175 = $174&1;
                   if ($175) {
                    break;
                   }
                   $176 = (($165) + 40|0);
                   HEAP32[$176>>2] = $171;
                   $177 = HEAP32[$8>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($177|0));
                   $178 = __THREW__; __THREW__ = 0;
                   $179 = $178&1;
                   if ($179) {
                    break;
                   }
                   $180 = (($177) + 68|0);
                   ;HEAP32[$L_61+0>>2]=HEAP32[$180+0>>2]|0;HEAP32[$L_61+4>>2]=HEAP32[$180+4>>2]|0;HEAP32[$L_61+8>>2]=HEAP32[$180+8>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($177|0));
                   $181 = __THREW__; __THREW__ = 0;
                   $182 = $181&1;
                   if ($182) {
                    break;
                   }
                   $183 = (($177) + 80|0);
                   ;HEAP32[$183+0>>2]=HEAP32[$L_61+0>>2]|0;HEAP32[$183+4>>2]=HEAP32[$L_61+4>>2]|0;HEAP32[$183+8>>2]=HEAP32[$L_61+8>>2]|0;
                   $184 = (($__this) + 68|0);
                   ;HEAP32[$184+0>>2]=HEAP32[$164+0>>2]|0;HEAP32[$184+4>>2]=HEAP32[$164+4>>2]|0;HEAP32[$184+8>>2]=HEAP32[$164+8>>2]|0;
                   $185 = HEAP32[$157>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($185|0));
                   $186 = __THREW__; __THREW__ = 0;
                   $187 = $186&1;
                   if ($187) {
                    break;
                   }
                   $188 = (($185) + 8|0);
                   $189 = HEAP8[$188>>0]|0;
                   $190 = ($189<<24>>24)==(0);
                   do {
                    if (!($190)) {
                     $191 = HEAP32[$157>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($191|0));
                     $192 = __THREW__; __THREW__ = 0;
                     $193 = $192&1;
                     if ($193) {
                      break L1;
                     }
                     $194 = (($191) + 20|0);
                     $195 = HEAP32[$194>>2]|0;
                     $196 = HEAP32[$157>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($196|0));
                     $197 = __THREW__; __THREW__ = 0;
                     $198 = $197&1;
                     if ($198) {
                      break L1;
                     }
                     $199 = (($196) + 16|0);
                     $200 = HEAP32[$199>>2]|0;
                     __THREW__ = 0;
                     $201 = (invoke_iiii(1319,(0|0),($195|0),($200|0))|0);
                     $202 = __THREW__; __THREW__ = 0;
                     $203 = $202&1;
                     if ($203) {
                      break L1;
                     }
                     if (!($201)) {
                      break;
                     }
                     $204 = HEAP32[$157>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($204|0));
                     $205 = __THREW__; __THREW__ = 0;
                     $206 = $205&1;
                     if ($206) {
                      break L1;
                     }
                     $207 = (($204) + 16|0);
                     $208 = HEAP32[$207>>2]|0;
                     __THREW__ = 0;
                     $209 = (invoke_iiii(1319,(0|0),($208|0),(0|0))|0);
                     $210 = __THREW__; __THREW__ = 0;
                     $211 = $210&1;
                     if ($211) {
                      break L1;
                     }
                     if (!($209)) {
                      break;
                     }
                     $212 = HEAP32[$157>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($212|0));
                     $213 = __THREW__; __THREW__ = 0;
                     $214 = $213&1;
                     if ($214) {
                      break L1;
                     }
                     $215 = (($212) + 16|0);
                     $216 = HEAP32[$215>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($212|0));
                     $217 = __THREW__; __THREW__ = 0;
                     $218 = $217&1;
                     if ($218) {
                      break L1;
                     }
                     $219 = (($212) + 20|0);
                     HEAP32[$219>>2] = $216;
                     $220 = HEAP32[$157>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($220|0));
                     $221 = __THREW__; __THREW__ = 0;
                     $222 = $221&1;
                     if ($222) {
                      break L1;
                     }
                     $223 = (($220) + 16|0);
                     $224 = HEAP32[$223>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($224|0));
                     $225 = __THREW__; __THREW__ = 0;
                     $226 = $225&1;
                     if ($226) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vii(2142,($L_209$byval_copy|0),($224|0));
                     $227 = __THREW__; __THREW__ = 0;
                     $228 = $227&1;
                     if ($228) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($220|0));
                     $229 = __THREW__; __THREW__ = 0;
                     $230 = $229&1;
                     if ($230) {
                      break L1;
                     }
                     $231 = (($220) + 80|0);
                     dest=$231+0|0; src=$L_209$byval_copy+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
                     $232 = HEAP32[$157>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($232|0));
                     $233 = __THREW__; __THREW__ = 0;
                     $234 = $233&1;
                     if ($234) {
                      break L1;
                     }
                     $235 = (($232) + 156|0);
                     HEAP8[$235>>0] = 1;
                    }
                   } while(0);
                   ;HEAP32[$L_86+0>>2]=0|0;HEAP32[$L_86+4>>2]=0|0;HEAP32[$L_86+8>>2]=0|0;
                   __THREW__ = 0;
                   invoke_vifff(4,($L_86|0),(+$31),0.0,(+$35));
                   $236 = __THREW__; __THREW__ = 0;
                   $237 = $236&1;
                   if ($237) {
                    break;
                   }
                   ;HEAP32[$V_9+0>>2]=HEAP32[$L_86+0>>2]|0;HEAP32[$V_9+4>>2]=HEAP32[$L_86+4>>2]|0;HEAP32[$V_9+8>>2]=HEAP32[$L_86+8>>2]|0;
                   $238 = HEAP32[$8>>2]|0;
                   $239 = HEAP32[$108>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($239|0));
                   $240 = __THREW__; __THREW__ = 0;
                   $241 = $240&1;
                   if ($241) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2122,($L_89|0),($239|0));
                   $242 = __THREW__; __THREW__ = 0;
                   $243 = $242&1;
                   if ($243) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$L_89+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$L_89+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$L_89+8>>2]|0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$V_6+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$V_6+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$V_6+8>>2]|0;
                   invoke_viiii(223,($L_90|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
                   $244 = __THREW__; __THREW__ = 0;
                   $245 = $244&1;
                   if ($245) {
                    break;
                   }
                   __THREW__ = 0;
                   $246 = (Math_fround(+(invoke_fi(149,(0|0)))));
                   $247 = __THREW__; __THREW__ = 0;
                   $248 = $247&1;
                   if ($248) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_90+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_90+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_90+8>>2]|0;
                   invoke_viiif(3,($L_92|0),(0|0),($L_209$byval_copy|0),(+$246));
                   $249 = __THREW__; __THREW__ = 0;
                   $250 = $249&1;
                   if ($250) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($238|0));
                   $251 = __THREW__; __THREW__ = 0;
                   $252 = $251&1;
                   if ($252) {
                    break;
                   }
                   $253 = (($238) + 44|0);
                   ;HEAP32[$253+0>>2]=HEAP32[$L_92+0>>2]|0;HEAP32[$253+4>>2]=HEAP32[$L_92+4>>2]|0;HEAP32[$253+8>>2]=HEAP32[$L_92+8>>2]|0;
                   $254 = HEAP32[$8>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($254|0));
                   $255 = __THREW__; __THREW__ = 0;
                   $256 = $255&1;
                   if ($256) {
                    break;
                   }
                   $257 = (($254) + 44|0);
                   $258 = Math_fround(HEAPF32[$257>>2]);
                   $259 = HEAP32[$8>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($259|0));
                   $260 = __THREW__; __THREW__ = 0;
                   $261 = $260&1;
                   if ($261) {
                    break;
                   }
                   $262 = (($259) + 52|0);
                   $263 = Math_fround(HEAPF32[$262>>2]);
                   ;HEAP32[$L_101+0>>2]=0|0;HEAP32[$L_101+4>>2]=0|0;HEAP32[$L_101+8>>2]=0|0;
                   __THREW__ = 0;
                   invoke_vifff(4,($L_101|0),(+$258),0.0,(+$263));
                   $264 = __THREW__; __THREW__ = 0;
                   $265 = $264&1;
                   if ($265) {
                    break;
                   }
                   ;HEAP32[$V_10+0>>2]=HEAP32[$L_101+0>>2]|0;HEAP32[$V_10+4>>2]=HEAP32[$L_101+4>>2]|0;HEAP32[$V_10+8>>2]=HEAP32[$L_101+8>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(2070,($L_102|0),(0|0));
                   $266 = __THREW__; __THREW__ = 0;
                   $267 = $266&1;
                   if ($267) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$V_9+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$V_9+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$V_9+8>>2]|0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_102+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_102+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_102+8>>2]|0;
                   $268 = (invoke_iiii(1351,(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0))|0);
                   $269 = __THREW__; __THREW__ = 0;
                   $270 = $269&1;
                   if ($270) {
                    break;
                   }
                   if ($268) {
                    $271 = HEAP32[$8>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($271|0));
                    $272 = __THREW__; __THREW__ = 0;
                    $273 = $272&1;
                    if ($273) {
                     break;
                    }
                    $274 = (($271) + 44|0);
                    $275 = (($271) + 48|0);
                    $276 = Math_fround(HEAPF32[$275>>2]);
                    ;HEAP32[$L_112+0>>2]=0|0;HEAP32[$L_112+4>>2]=0|0;HEAP32[$L_112+8>>2]=0|0;
                    __THREW__ = 0;
                    invoke_vifff(4,($L_112|0),0.0,(+$276),0.0);
                    $277 = __THREW__; __THREW__ = 0;
                    $278 = $277&1;
                    if ($278) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($271|0));
                    $279 = __THREW__; __THREW__ = 0;
                    $280 = $279&1;
                    if ($280) {
                     break;
                    }
                    ;HEAP32[$274+0>>2]=HEAP32[$L_112+0>>2]|0;HEAP32[$274+4>>2]=HEAP32[$L_112+4>>2]|0;HEAP32[$274+8>>2]=HEAP32[$L_112+8>>2]|0;
                   } else {
                    __THREW__ = 0;
                    ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$V_10+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$V_10+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$V_10+8>>2]|0;
                    ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$V_9+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$V_9+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$V_9+8>>2]|0;
                    $281 = (Math_fround(+(invoke_fiii(8,(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0)))));
                    $282 = __THREW__; __THREW__ = 0;
                    $283 = $282&1;
                    if ($283) {
                     break;
                    }
                    __THREW__ = 0;
                    $284 = (Math_fround(+(invoke_fi(137,($V_9|0)))));
                    $285 = __THREW__; __THREW__ = 0;
                    $286 = $285&1;
                    if ($286) {
                     break;
                    }
                    $287 = Math_fround($281 / $284);
                    $288 = HEAP32[$8>>2]|0;
                    __THREW__ = 0;
                    $289 = (Math_fround(+(invoke_fif(12,(0|0),(+$287)))));
                    $290 = __THREW__; __THREW__ = 0;
                    $291 = $290&1;
                    if ($291) {
                     break;
                    }
                    __THREW__ = 0;
                    ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$V_9+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$V_9+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$V_9+8>>2]|0;
                    invoke_viiif(2,($L_118|0),(0|0),($L_209$byval_copy|0),(+$289));
                    $292 = __THREW__; __THREW__ = 0;
                    $293 = $292&1;
                    if ($293) {
                     break;
                    }
                    $294 = HEAP32[$8>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($294|0));
                    $295 = __THREW__; __THREW__ = 0;
                    $296 = $295&1;
                    if ($296) {
                     break;
                    }
                    $297 = (($294) + 48|0);
                    $298 = Math_fround(HEAPF32[$297>>2]);
                    __THREW__ = 0;
                    invoke_vii(2073,($L_122|0),(0|0));
                    $299 = __THREW__; __THREW__ = 0;
                    $300 = $299&1;
                    if ($300) {
                     break;
                    }
                    __THREW__ = 0;
                    ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_122+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_122+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_122+8>>2]|0;
                    invoke_viifi(3,($L_123|0),(0|0),(+$298),($L_209$byval_copy|0));
                    $301 = __THREW__; __THREW__ = 0;
                    $302 = $301&1;
                    if ($302) {
                     break;
                    }
                    __THREW__ = 0;
                    ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$L_118+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$L_118+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$L_118+8>>2]|0;
                    ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_123+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_123+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_123+8>>2]|0;
                    invoke_viiii(222,($L_124|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
                    $303 = __THREW__; __THREW__ = 0;
                    $304 = $303&1;
                    if ($304) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($288|0));
                    $305 = __THREW__; __THREW__ = 0;
                    $306 = $305&1;
                    if ($306) {
                     break;
                    }
                    $307 = (($288) + 44|0);
                    ;HEAP32[$307+0>>2]=HEAP32[$L_124+0>>2]|0;HEAP32[$307+4>>2]=HEAP32[$L_124+4>>2]|0;HEAP32[$307+8>>2]=HEAP32[$L_124+8>>2]|0;
                   }
                   $308 = HEAP32[$8>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($308|0));
                   $309 = __THREW__; __THREW__ = 0;
                   $310 = $309&1;
                   if ($310) {
                    break;
                   }
                   $311 = (($308) + 48|0);
                   $312 = Math_fround(HEAPF32[$311>>2]);
                   $313 = Math_fround($33 + Math_fround(-0.00100000004749745130539));
                   $314 = !($312 >= $313);
                   do {
                    if ($314) {
                     $315 = HEAP32[$8>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($315|0));
                     $316 = __THREW__; __THREW__ = 0;
                     $317 = $316&1;
                     if ($317) {
                      break L1;
                     }
                     $318 = (($315) + 48|0);
                     $319 = Math_fround(HEAPF32[$318>>2]);
                     $320 = !($319 >= Math_fround(0.0));
                     if ($320) {
                      $321 = HEAP32[$8>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($321|0));
                      $322 = __THREW__; __THREW__ = 0;
                      $323 = $322&1;
                      if ($323) {
                       break L1;
                      }
                      $324 = (($321) + 48|0);
                      HEAPF32[$324>>2] = $33;
                      break;
                     } else {
                      $325 = (($__this) + 40|0);
                      $326 = HEAP32[$325>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($326|0));
                      $327 = __THREW__; __THREW__ = 0;
                      $328 = $327&1;
                      if ($328) {
                       break L1;
                      }
                      $329 = (($326) + 29|0);
                      HEAP8[$329>>0] = 0;
                      break;
                     }
                    }
                   } while(0);
                   $330 = HEAP8[$141>>0]|0;
                   $331 = ($330<<24>>24)==(0);
                   do {
                    if ($331) {
                     label = 130;
                    } else {
                     __THREW__ = 0;
                     $332 = (invoke_ii(740,($__this|0))|0);
                     $333 = __THREW__; __THREW__ = 0;
                     $334 = $333&1;
                     if ($334) {
                      break L1;
                     }
                     if ($332) {
                      $$pr = HEAP8[$141>>0]|0;
                      $391 = ($$pr<<24>>24)==(0);
                      if ($391) {
                       label = 130;
                       break;
                      } else {
                       break;
                      }
                     }
                     HEAP8[$141>>0] = 0;
                     $335 = HEAP32[$157>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($335|0));
                     $336 = __THREW__; __THREW__ = 0;
                     $337 = $336&1;
                     if ($337) {
                      break L1;
                     }
                     $338 = (($335) + 8|0);
                     $339 = HEAP8[$338>>0]|0;
                     $340 = ($339<<24>>24)==(0);
                     do {
                      if (!($340)) {
                       $341 = HEAP32[$157>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($341|0));
                       $342 = __THREW__; __THREW__ = 0;
                       $343 = $342&1;
                       if ($343) {
                        break L1;
                       }
                       $344 = (($341) + 12|0);
                       $345 = HEAP32[$344>>2]|0;
                       $346 = ($345|0)==(1);
                       if (!($346)) {
                        $347 = HEAP32[$157>>2]|0;
                        __THREW__ = 0;
                        invoke_vi(3799,($347|0));
                        $348 = __THREW__; __THREW__ = 0;
                        $349 = $348&1;
                        if ($349) {
                         break L1;
                        }
                        $350 = (($347) + 12|0);
                        $351 = HEAP32[$350>>2]|0;
                        $352 = ($351|0)==(2);
                        if (!($352)) {
                         break;
                        }
                       }
                       $353 = HEAP32[$8>>2]|0;
                       $354 = HEAP32[$157>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($354|0));
                       $355 = __THREW__; __THREW__ = 0;
                       $356 = $355&1;
                       if ($356) {
                        break L1;
                       }
                       $357 = (($354) + 144|0);
                       ;HEAP32[$L_154+0>>2]=HEAP32[$357+0>>2]|0;HEAP32[$L_154+4>>2]=HEAP32[$357+4>>2]|0;HEAP32[$L_154+8>>2]=HEAP32[$357+8>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($353|0));
                       $358 = __THREW__; __THREW__ = 0;
                       $359 = $358&1;
                       if ($359) {
                        break L1;
                       }
                       $360 = (($353) + 56|0);
                       ;HEAP32[$360+0>>2]=HEAP32[$L_154+0>>2]|0;HEAP32[$360+4>>2]=HEAP32[$L_154+4>>2]|0;HEAP32[$360+8>>2]=HEAP32[$L_154+8>>2]|0;
                       $361 = HEAP32[$8>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($361|0));
                       $362 = __THREW__; __THREW__ = 0;
                       $363 = $362&1;
                       if ($363) {
                        break L1;
                       }
                       $364 = (($361) + 44|0);
                       ;HEAP32[$L_157+0>>2]=HEAP32[$364+0>>2]|0;HEAP32[$L_157+4>>2]=HEAP32[$364+4>>2]|0;HEAP32[$L_157+8>>2]=HEAP32[$364+8>>2]|0;
                       $365 = HEAP32[$157>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($365|0));
                       $366 = __THREW__; __THREW__ = 0;
                       $367 = $366&1;
                       if ($367) {
                        break L1;
                       }
                       $368 = (($365) + 144|0);
                       ;HEAP32[$L_159+0>>2]=HEAP32[$368+0>>2]|0;HEAP32[$L_159+4>>2]=HEAP32[$368+4>>2]|0;HEAP32[$L_159+8>>2]=HEAP32[$368+8>>2]|0;
                       __THREW__ = 0;
                       ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$L_157+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$L_157+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$L_157+8>>2]|0;
                       ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_159+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_159+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_159+8>>2]|0;
                       invoke_viiii(222,($L_160|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
                       $369 = __THREW__; __THREW__ = 0;
                       $370 = $369&1;
                       if ($370) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($361|0));
                       $371 = __THREW__; __THREW__ = 0;
                       $372 = $371&1;
                       if ($372) {
                        break L1;
                       }
                       ;HEAP32[$364+0>>2]=HEAP32[$L_160+0>>2]|0;HEAP32[$364+4>>2]=HEAP32[$L_160+4>>2]|0;HEAP32[$364+8>>2]=HEAP32[$L_160+8>>2]|0;
                      }
                     } while(0);
                     $373 = HEAP32[2993672>>2]|0;
                     __THREW__ = 0;
                     invoke_viii(730,($__this|0),($373|0),1);
                     $374 = __THREW__; __THREW__ = 0;
                     $375 = $374&1;
                     if ($375) {
                      break L1;
                     }
                     $376 = HEAP32[$108>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($376|0));
                     $377 = __THREW__; __THREW__ = 0;
                     $378 = $377&1;
                     if ($378) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vii(2122,($L_164|0),($376|0));
                     $379 = __THREW__; __THREW__ = 0;
                     $380 = $379&1;
                     if ($380) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vii(2073,($L_165|0),(0|0));
                     $381 = __THREW__; __THREW__ = 0;
                     $382 = $381&1;
                     if ($382) {
                      break L1;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_165+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_165+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_165+8>>2]|0;
                     invoke_viifi(3,($L_166|0),(0|0),(+$138),($L_209$byval_copy|0));
                     $383 = __THREW__; __THREW__ = 0;
                     $384 = $383&1;
                     if ($384) {
                      break L1;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$L_164+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$L_164+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$L_164+8>>2]|0;
                     ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_166+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_166+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_166+8>>2]|0;
                     invoke_viiii(222,($L_167|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
                     $385 = __THREW__; __THREW__ = 0;
                     $386 = $385&1;
                     if ($386) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($376|0));
                     $387 = __THREW__; __THREW__ = 0;
                     $388 = $387&1;
                     if ($388) {
                      break L1;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_167+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_167+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_167+8>>2]|0;
                     invoke_vii(2123,($376|0),($L_209$byval_copy|0));
                     $389 = __THREW__; __THREW__ = 0;
                     $390 = $389&1;
                     if ($390) {
                      break L1;
                     }
                    }
                   } while(0);
                   do {
                    if ((label|0) == 130) {
                     __THREW__ = 0;
                     $392 = (invoke_ii(740,($__this|0))|0);
                     $393 = __THREW__; __THREW__ = 0;
                     $394 = $393&1;
                     if ($394) {
                      break L1;
                     }
                     if (!($392)) {
                      break;
                     }
                     HEAP8[$141>>0] = 1;
                     $395 = (($__this) + 40|0);
                     $396 = HEAP32[$395>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($396|0));
                     $397 = __THREW__; __THREW__ = 0;
                     $398 = $397&1;
                     if ($398) {
                      break L1;
                     }
                     $399 = (($396) + 28|0);
                     HEAP8[$399>>0] = 0;
                     __THREW__ = 0;
                     $400 = (invoke_ii(738,($__this|0))|0);
                     $401 = __THREW__; __THREW__ = 0;
                     $402 = $401&1;
                     if ($402) {
                      break L1;
                     }
                     __THREW__ = 0;
                     (invoke_iii(1230,($__this|0),($400|0))|0);
                     $403 = __THREW__; __THREW__ = 0;
                     $404 = $403&1;
                     if ($404) {
                      break L1;
                     }
                     $405 = HEAP32[2993680>>2]|0;
                     __THREW__ = 0;
                     invoke_viii(730,($__this|0),($405|0),1);
                     $406 = __THREW__; __THREW__ = 0;
                     $407 = $406&1;
                     if ($407) {
                      break L1;
                     }
                    }
                   } while(0);
                   __THREW__ = 0;
                   $408 = (invoke_ii(739,($__this|0))|0);
                   $409 = __THREW__; __THREW__ = 0;
                   $410 = $409&1;
                   if ($410) {
                    break;
                   }
                   if (!($408)) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   $411 = HEAP32[$157>>2]|0;
                   $412 = HEAP32[$108>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($412|0));
                   $413 = __THREW__; __THREW__ = 0;
                   $414 = $413&1;
                   if ($414) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2122,($L_179|0),($412|0));
                   $415 = __THREW__; __THREW__ = 0;
                   $416 = $415&1;
                   if ($416) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2073,($L_180|0),(0|0));
                   $417 = __THREW__; __THREW__ = 0;
                   $418 = $417&1;
                   if ($418) {
                    break;
                   }
                   $419 = HEAP32[$126>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($419|0));
                   $420 = __THREW__; __THREW__ = 0;
                   $421 = $420&1;
                   if ($421) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2159,($L_182|0),($419|0));
                   $422 = __THREW__; __THREW__ = 0;
                   $423 = $422&1;
                   if ($423) {
                    break;
                   }
                   $424 = (($L_182) + 4|0);
                   $425 = Math_fround(HEAPF32[$424>>2]);
                   $426 = HEAP32[$126>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($426|0));
                   $427 = __THREW__; __THREW__ = 0;
                   $428 = $427&1;
                   if ($428) {
                    break;
                   }
                   __THREW__ = 0;
                   $429 = (Math_fround(+(invoke_fi(156,($426|0)))));
                   $430 = __THREW__; __THREW__ = 0;
                   $431 = $430&1;
                   if ($431) {
                    break;
                   }
                   $432 = Math_fround($429 * Math_fround(0.5));
                   $433 = Math_fround($425 - $432);
                   $434 = HEAP32[$126>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($434|0));
                   $435 = __THREW__; __THREW__ = 0;
                   $436 = $435&1;
                   if ($436) {
                    break;
                   }
                   __THREW__ = 0;
                   $437 = (Math_fround(+(invoke_fi(155,($434|0)))));
                   $438 = __THREW__; __THREW__ = 0;
                   $439 = $438&1;
                   if ($439) {
                    break;
                   }
                   $440 = Math_fround($433 + $437);
                   __THREW__ = 0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_180+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_180+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_180+8>>2]|0;
                   invoke_viiif(2,($L_192|0),(0|0),($L_209$byval_copy|0),(+$440));
                   $441 = __THREW__; __THREW__ = 0;
                   $442 = $441&1;
                   if ($442) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$L_179+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$L_179+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$L_179+8>>2]|0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_192+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_192+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_192+8>>2]|0;
                   invoke_viiii(222,($L_193|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
                   $443 = __THREW__; __THREW__ = 0;
                   $444 = $443&1;
                   if ($444) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($411|0));
                   $445 = __THREW__; __THREW__ = 0;
                   $446 = $445&1;
                   if ($446) {
                    break;
                   }
                   $447 = (($411) + 36|0);
                   ;HEAP32[$447+0>>2]=HEAP32[$L_193+0>>2]|0;HEAP32[$447+4>>2]=HEAP32[$L_193+4>>2]|0;HEAP32[$447+8>>2]=HEAP32[$L_193+8>>2]|0;
                   $448 = HEAP32[$157>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($448|0));
                   $449 = __THREW__; __THREW__ = 0;
                   $450 = $449&1;
                   if ($450) {
                    break;
                   }
                   $451 = (($448) + 20|0);
                   $452 = HEAP32[$451>>2]|0;
                   $453 = HEAP32[$157>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($453|0));
                   $454 = __THREW__; __THREW__ = 0;
                   $455 = $454&1;
                   if ($455) {
                    break;
                   }
                   $456 = (($453) + 36|0);
                   ;HEAP32[$L_198+0>>2]=HEAP32[$456+0>>2]|0;HEAP32[$L_198+4>>2]=HEAP32[$456+4>>2]|0;HEAP32[$L_198+8>>2]=HEAP32[$456+8>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($452|0));
                   $457 = __THREW__; __THREW__ = 0;
                   $458 = $457&1;
                   if ($458) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_198+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_198+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_198+8>>2]|0;
                   invoke_viii(781,($L_199|0),($452|0),($L_209$byval_copy|0));
                   $459 = __THREW__; __THREW__ = 0;
                   $460 = $459&1;
                   if ($460) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($448|0));
                   $461 = __THREW__; __THREW__ = 0;
                   $462 = $461&1;
                   if ($462) {
                    break;
                   }
                   $463 = (($448) + 24|0);
                   ;HEAP32[$463+0>>2]=HEAP32[$L_199+0>>2]|0;HEAP32[$463+4>>2]=HEAP32[$L_199+4>>2]|0;HEAP32[$463+8>>2]=HEAP32[$L_199+8>>2]|0;
                   $464 = HEAP32[$157>>2]|0;
                   $465 = HEAP32[$108>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($465|0));
                   $466 = __THREW__; __THREW__ = 0;
                   $467 = $466&1;
                   if ($467) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2133,($L_202|0),($465|0));
                   $468 = __THREW__; __THREW__ = 0;
                   $469 = $468&1;
                   if ($469) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($464|0));
                   $470 = __THREW__; __THREW__ = 0;
                   $471 = $470&1;
                   if ($471) {
                    break;
                   }
                   $472 = (($464) + 64|0);
                   ;HEAP32[$472+0>>2]=HEAP32[$L_202+0>>2]|0;HEAP32[$472+4>>2]=HEAP32[$L_202+4>>2]|0;HEAP32[$472+8>>2]=HEAP32[$L_202+8>>2]|0;HEAP32[$472+12>>2]=HEAP32[$L_202+12>>2]|0;
                   $473 = HEAP32[$157>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($473|0));
                   $474 = __THREW__; __THREW__ = 0;
                   $475 = $474&1;
                   if ($475) {
                    break;
                   }
                   $476 = (($473) + 20|0);
                   $477 = HEAP32[$476>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($477|0));
                   $478 = __THREW__; __THREW__ = 0;
                   $479 = $478&1;
                   if ($479) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vii(2133,($L_206|0),($477|0));
                   $480 = __THREW__; __THREW__ = 0;
                   $481 = $480&1;
                   if ($481) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_206+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_206+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_206+8>>2]|0;HEAP32[$L_209$byval_copy+12>>2]=HEAP32[$L_206+12>>2]|0;
                   invoke_viii(743,($L_207|0),(0|0),($L_209$byval_copy|0));
                   $482 = __THREW__; __THREW__ = 0;
                   $483 = $482&1;
                   if ($483) {
                    break;
                   }
                   $484 = HEAP32[$157>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($484|0));
                   $485 = __THREW__; __THREW__ = 0;
                   $486 = $485&1;
                   if ($486) {
                    break;
                   }
                   $487 = (($484) + 64|0);
                   ;HEAP32[$L_209+0>>2]=HEAP32[$487+0>>2]|0;HEAP32[$L_209+4>>2]=HEAP32[$487+4>>2]|0;HEAP32[$L_209+8>>2]=HEAP32[$487+8>>2]|0;HEAP32[$L_209+12>>2]=HEAP32[$487+12>>2]|0;
                   __THREW__ = 0;
                   ;HEAP32[$L_207$byval_copy+0>>2]=HEAP32[$L_207+0>>2]|0;HEAP32[$L_207$byval_copy+4>>2]=HEAP32[$L_207+4>>2]|0;HEAP32[$L_207$byval_copy+8>>2]=HEAP32[$L_207+8>>2]|0;HEAP32[$L_207$byval_copy+12>>2]=HEAP32[$L_207+12>>2]|0;
                   ;HEAP32[$L_209$byval_copy+0>>2]=HEAP32[$L_209+0>>2]|0;HEAP32[$L_209$byval_copy+4>>2]=HEAP32[$L_209+4>>2]|0;HEAP32[$L_209$byval_copy+8>>2]=HEAP32[$L_209+8>>2]|0;HEAP32[$L_209$byval_copy+12>>2]=HEAP32[$L_209+12>>2]|0;
                   invoke_viiii(228,($L_210|0),(0|0),($L_207$byval_copy|0),($L_209$byval_copy|0));
                   $488 = __THREW__; __THREW__ = 0;
                   $489 = $488&1;
                   if ($489) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($473|0));
                   $490 = __THREW__; __THREW__ = 0;
                   $491 = $490&1;
                   if ($491) {
                    break;
                   }
                   $492 = (($473) + 48|0);
                   ;HEAP32[$492+0>>2]=HEAP32[$L_210+0>>2]|0;HEAP32[$492+4>>2]=HEAP32[$L_210+4>>2]|0;HEAP32[$492+8>>2]=HEAP32[$L_210+8>>2]|0;HEAP32[$492+12>>2]=HEAP32[$L_210+12>>2]|0;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($41|0);
 // unreachable;
}
function __Z80AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_ApplyInputVelocityChangeP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$velocity) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $velocity = $velocity|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = Math_fround(0), $11 = 0, $110 = 0, $111 = Math_fround(0), $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = Math_fround(0), $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = Math_fround(0), $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $131 = 0;
 var $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = Math_fround(0), $138 = 0, $139 = 0, $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = Math_fround(0);
 var $64 = 0, $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = Math_fround(0), $8 = 0, $80 = 0, $81 = 0;
 var $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_1 = 0;
 var $L_10 = 0, $L_11 = 0, $L_13 = 0, $L_16 = 0, $L_17 = 0, $L_19 = 0, $L_22 = 0, $L_23 = 0, $L_26 = 0, $L_27 = 0, $L_34 = 0, $L_35 = 0, $L_40 = 0, $L_47 = 0, $L_50 = 0, $L_51 = 0, $L_54 = 0, $V_0$sroa$0$0 = Math_fround(0), $V_0$sroa$0$1 = Math_fround(0), $V_0$sroa$0$2 = Math_fround(0);
 var $V_0$sroa$1$0 = Math_fround(0), $V_0$sroa$1$1 = Math_fround(0), $V_0$sroa$1$2 = Math_fround(0), $V_0$sroa$2$0 = Math_fround(0), $V_0$sroa$2$1 = Math_fround(0), $V_0$sroa$2$2 = Math_fround(0), $V_1 = 0, $V_3 = 0, $V_3$byval_copy = 0, $V_4 = 0, $_stackTraceSentry = 0, $phitmp = 0, $phitmp2 = 0, $velocity$byval_copy10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $V_3$byval_copy = sp + 340|0;
 $velocity$byval_copy10 = sp + 328|0;
 $_stackTraceSentry = sp + 324|0;
 $V_1 = sp + 312|0;
 $V_3 = sp + 300|0;
 $V_4 = sp + 288|0;
 $L_1 = sp + 276|0;
 $L_10 = sp + 264|0;
 $L_11 = sp + 252|0;
 $L_13 = sp + 240|0;
 $0 = sp + 228|0;
 $L_16 = sp + 216|0;
 $L_17 = sp + 204|0;
 $1 = sp + 192|0;
 $L_19 = sp + 180|0;
 $L_22 = sp + 168|0;
 $L_23 = sp + 60|0;
 $L_26 = sp;
 $2 = sp + 12|0;
 $L_27 = sp + 24|0;
 $L_34 = sp + 36|0;
 $L_35 = sp + 48|0;
 $3 = sp + 72|0;
 $L_40 = sp + 84|0;
 $4 = sp + 96|0;
 $L_47 = sp + 108|0;
 $5 = sp + 120|0;
 $L_50 = sp + 132|0;
 $L_51 = sp + 144|0;
 $L_54 = sp + 156|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290376);
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;
 $6 = (($__this) + 16|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  __THREW__ = 0;
  invoke_vii(2070,($L_1|0),(0|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = (($__this) + 20|0);
   ;HEAP32[$11+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$L_1+8>>2]|0;
   label = 4;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $12 = (($__this) + 52|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    label = 21;
   } else {
    __THREW__ = 0;
    $17 = (invoke_iii(2734,(1290424|0),($__this|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    if ($17) {
     $20 = (($__this) + 56|0);
     $21 = Math_fround(HEAPF32[$20>>2]);
     $22 = (($__this) + 64|0);
     $23 = Math_fround(HEAPF32[$22>>2]);
     ;HEAP32[$L_10+0>>2]=0|0;HEAP32[$L_10+4>>2]=0|0;HEAP32[$L_10+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vifff(4,($L_10|0),(+$21),0.0,(+$23));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     ;HEAP32[$V_4+0>>2]=HEAP32[$L_10+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_10+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_10+8>>2]|0;
     __THREW__ = 0;
     invoke_vii(2069,($L_11|0),($V_4|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     $28 = Math_fround(HEAPF32[$L_11>>2]);
     $29 = (($L_11) + 4|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     $31 = (($L_11) + 8|0);
     $32 = Math_fround(HEAPF32[$31>>2]);
     $33 = (($__this) + 20|0);
     HEAPF32[$0>>2] = $28;
     $34 = (($0) + 4|0);
     HEAPF32[$34>>2] = $30;
     $35 = (($0) + 8|0);
     HEAPF32[$35>>2] = $32;
     __THREW__ = 0;
     ;HEAP32[$velocity$byval_copy10+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$velocity$byval_copy10+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$velocity$byval_copy10+8>>2]=HEAP32[$33+8>>2]|0;
     ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
     invoke_viiii(219,($L_13|0),(0|0),($velocity$byval_copy10|0),($V_3$byval_copy|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     ;HEAP32[$V_1+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_13+8>>2]|0;
     $38 = (($__this) + 48|0);
     $39 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($39|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     $42 = (($39) + 20|0);
     $43 = Math_fround(HEAPF32[$42>>2]);
     __THREW__ = 0;
     ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;
     invoke_viiif(2,($L_16|0),(0|0),($V_3$byval_copy|0),(+$43));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     HEAPF32[$1>>2] = $28;
     $46 = (($1) + 4|0);
     HEAPF32[$46>>2] = $30;
     $47 = (($1) + 8|0);
     HEAPF32[$47>>2] = $32;
     __THREW__ = 0;
     ;HEAP32[$velocity$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$velocity$byval_copy10+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$velocity$byval_copy10+8>>2]=HEAP32[$1+8>>2]|0;
     ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$L_16+8>>2]|0;
     invoke_viiii(222,($L_17|0),(0|0),($velocity$byval_copy10|0),($V_3$byval_copy|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     __THREW__ = 0;
     ;HEAP32[$velocity$byval_copy10+0>>2]=HEAP32[$33+0>>2]|0;HEAP32[$velocity$byval_copy10+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$velocity$byval_copy10+8>>2]=HEAP32[$33+8>>2]|0;
     ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;
     invoke_viiii(223,($L_19|0),(0|0),($velocity$byval_copy10|0),($V_3$byval_copy|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($52|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     $55 = (($52) + 16|0);
     $56 = Math_fround(HEAPF32[$55>>2]);
     __THREW__ = 0;
     ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$L_19+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$L_19+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$L_19+8>>2]|0;
     invoke_viiif(2,($L_22|0),(0|0),($V_3$byval_copy|0),(+$56));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     __THREW__ = 0;
     ;HEAP32[$velocity$byval_copy10+0>>2]=HEAP32[$L_17+0>>2]|0;HEAP32[$velocity$byval_copy10+4>>2]=HEAP32[$L_17+4>>2]|0;HEAP32[$velocity$byval_copy10+8>>2]=HEAP32[$L_17+8>>2]|0;
     ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$L_22+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$L_22+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$L_22+8>>2]|0;
     invoke_viiii(222,($L_23|0),(0|0),($velocity$byval_copy10|0),($V_3$byval_copy|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     $61 = Math_fround(HEAPF32[$L_23>>2]);
     $62 = (($L_23) + 4|0);
     $63 = Math_fround(HEAPF32[$62>>2]);
     $64 = (($L_23) + 8|0);
     $65 = Math_fround(HEAPF32[$64>>2]);
     $66 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($66|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     $69 = (($66) + 12|0);
     $70 = Math_fround(HEAPF32[$69>>2]);
     HEAPF32[$2>>2] = $61;
     $71 = (($2) + 4|0);
     HEAPF32[$71>>2] = $63;
     $72 = (($2) + 8|0);
     HEAPF32[$72>>2] = $65;
     __THREW__ = 0;
     ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;
     invoke_viiif(2,($L_26|0),(0|0),($V_3$byval_copy|0),(+$70));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      break;
     }
     $75 = Math_fround(HEAPF32[$L_26>>2]);
     $76 = (($L_26) + 4|0);
     $77 = Math_fround(HEAPF32[$76>>2]);
     $78 = (($L_26) + 8|0);
     $79 = Math_fround(HEAPF32[$78>>2]);
     $V_0$sroa$0$0 = $75;$V_0$sroa$1$0 = $77;$V_0$sroa$2$0 = $79;
    } else {
     label = 21;
    }
   }
   if ((label|0) == 21) {
    __THREW__ = 0;
    invoke_vii(1207,($L_27|0),($__this|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     break;
    }
    $82 = Math_fround(HEAPF32[$L_27>>2]);
    $83 = (($L_27) + 4|0);
    $84 = Math_fround(HEAPF32[$83>>2]);
    $85 = (($L_27) + 8|0);
    $86 = Math_fround(HEAPF32[$85>>2]);
    $V_0$sroa$0$0 = $82;$V_0$sroa$1$0 = $84;$V_0$sroa$2$0 = $86;
   }
   $87 = (($__this) + 44|0);
   $88 = HEAP32[$87>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($88|0));
   $89 = __THREW__; __THREW__ = 0;
   $90 = $89&1;
   if (!($90)) {
    $91 = (($88) + 8|0);
    $92 = HEAP8[$91>>0]|0;
    $93 = ($92<<24>>24)==(0);
    if ($93) {
     $V_0$sroa$0$1 = $V_0$sroa$0$0;$V_0$sroa$1$1 = $V_0$sroa$1$0;$V_0$sroa$2$1 = $V_0$sroa$2$0;
    } else {
     $94 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($94|0));
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      break;
     }
     $97 = (($94) + 12|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = ($98|0)==(2);
     if ($99) {
      $100 = (($__this) + 36|0);
      $101 = HEAP32[$100>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($101|0));
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       break;
      }
      $104 = (($101) + 56|0);
      ;HEAP32[$L_34+0>>2]=HEAP32[$104+0>>2]|0;HEAP32[$L_34+4>>2]=HEAP32[$104+4>>2]|0;HEAP32[$L_34+8>>2]=HEAP32[$104+8>>2]|0;
      HEAPF32[$3>>2] = $V_0$sroa$0$0;
      $105 = (($3) + 4|0);
      HEAPF32[$105>>2] = $V_0$sroa$1$0;
      $106 = (($3) + 8|0);
      HEAPF32[$106>>2] = $V_0$sroa$2$0;
      __THREW__ = 0;
      ;HEAP32[$velocity$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$velocity$byval_copy10+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$velocity$byval_copy10+8>>2]=HEAP32[$3+8>>2]|0;
      ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$L_34+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$L_34+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$L_34+8>>2]|0;
      invoke_viiii(222,($L_35|0),(0|0),($velocity$byval_copy10|0),($V_3$byval_copy|0));
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       break;
      }
      $109 = Math_fround(HEAPF32[$L_35>>2]);
      $110 = (($L_35) + 8|0);
      $111 = Math_fround(HEAPF32[$110>>2]);
      $V_0$sroa$0$1 = $109;$V_0$sroa$1$1 = Math_fround(0.0);$V_0$sroa$2$1 = $111;
     } else {
      $V_0$sroa$0$1 = $V_0$sroa$0$0;$V_0$sroa$1$1 = $V_0$sroa$1$0;$V_0$sroa$2$1 = $V_0$sroa$2$0;
     }
    }
    $112 = HEAP8[$12>>0]|0;
    $113 = ($112<<24>>24)==(0);
    if ($113) {
     $124 = (($velocity) + 4|0);
     HEAPF32[$124>>2] = Math_fround(0.0);
     $125 = 0;$V_0$sroa$0$2 = $V_0$sroa$0$1;$V_0$sroa$1$2 = $V_0$sroa$1$1;$V_0$sroa$2$2 = $V_0$sroa$2$1;
    } else {
     $114 = (($__this) + 56|0);
     HEAPF32[$4>>2] = $V_0$sroa$0$1;
     $115 = (($4) + 4|0);
     HEAPF32[$115>>2] = $V_0$sroa$1$1;
     $116 = (($4) + 8|0);
     HEAPF32[$116>>2] = $V_0$sroa$2$1;
     __THREW__ = 0;
     ;HEAP32[$velocity$byval_copy10+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$velocity$byval_copy10+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$velocity$byval_copy10+8>>2]=HEAP32[$4+8>>2]|0;
     ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$114+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$114+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$114+8>>2]|0;
     invoke_viiii(87,($L_40|0),0,($velocity$byval_copy10|0),($V_3$byval_copy|0));
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      break;
     }
     $119 = Math_fround(HEAPF32[$L_40>>2]);
     $120 = (($L_40) + 4|0);
     $121 = Math_fround(HEAPF32[$120>>2]);
     $122 = (($L_40) + 8|0);
     $123 = Math_fround(HEAPF32[$122>>2]);
     $$pre = HEAP8[$12>>0]|0;
     $phitmp = ($$pre<<24>>24)!=(0);
     $125 = $phitmp;$V_0$sroa$0$2 = $119;$V_0$sroa$1$2 = $121;$V_0$sroa$2$2 = $123;
    }
    __THREW__ = 0;
    $126 = (Math_fround(+(invoke_fiii(15,(1290472|0),($__this|0),($125|0)))));
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if (!($128)) {
     __THREW__ = 0;
     $129 = (Math_fround(+(invoke_fi(149,(0|0)))));
     $130 = __THREW__; __THREW__ = 0;
     $131 = $130&1;
     if (!($131)) {
      $132 = Math_fround($126 * $129);
      HEAPF32[$5>>2] = $V_0$sroa$0$2;
      $133 = (($5) + 4|0);
      HEAPF32[$133>>2] = $V_0$sroa$1$2;
      $134 = (($5) + 8|0);
      HEAPF32[$134>>2] = $V_0$sroa$2$2;
      __THREW__ = 0;
      ;HEAP32[$velocity$byval_copy10+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$velocity$byval_copy10+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$velocity$byval_copy10+8>>2]=HEAP32[$5+8>>2]|0;
      ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$velocity+8>>2]|0;
      invoke_viiii(223,($L_47|0),(0|0),($velocity$byval_copy10|0),($V_3$byval_copy|0));
      $135 = __THREW__; __THREW__ = 0;
      $136 = $135&1;
      if (!($136)) {
       ;HEAP32[$V_3+0>>2]=HEAP32[$L_47+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_47+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_47+8>>2]|0;
       __THREW__ = 0;
       $137 = (Math_fround(+(invoke_fi(137,($V_3|0)))));
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if (!($139)) {
        $140 = Math_fround($132 * $132);
        $141 = !($137 <= $140);
        if ($141) {
         __THREW__ = 0;
         invoke_vii(2069,($L_50|0),($V_3|0));
         $142 = __THREW__; __THREW__ = 0;
         $143 = $142&1;
         if ($143) {
          break;
         }
         __THREW__ = 0;
         ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$L_50+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$L_50+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$L_50+8>>2]|0;
         invoke_viiif(2,($L_51|0),(0|0),($V_3$byval_copy|0),(+$132));
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if ($145) {
          break;
         }
         ;HEAP32[$V_3+0>>2]=HEAP32[$L_51+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_51+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_51+8>>2]|0;
        }
        $146 = HEAP8[$12>>0]|0;
        $147 = ($146<<24>>24)==(0);
        if ($147) {
         $148 = HEAP8[$6>>0]|0;
         $149 = ($148<<24>>24)==(0);
         if ($149) {
          ;HEAP32[$agg$result+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$velocity+8>>2]|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
        __THREW__ = 0;
        ;HEAP32[$velocity$byval_copy10+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$velocity$byval_copy10+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$velocity$byval_copy10+8>>2]=HEAP32[$velocity+8>>2]|0;
        ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$V_3+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$V_3+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$V_3+8>>2]|0;
        invoke_viiii(222,($L_54|0),(0|0),($velocity$byval_copy10|0),($V_3$byval_copy|0));
        $150 = __THREW__; __THREW__ = 0;
        $151 = $150&1;
        if (!($151)) {
         ;HEAP32[$velocity+0>>2]=HEAP32[$L_54+0>>2]|0;HEAP32[$velocity+4>>2]=HEAP32[$L_54+4>>2]|0;HEAP32[$velocity+8>>2]=HEAP32[$L_54+8>>2]|0;
         $$pre1 = HEAP8[$12>>0]|0;
         $phitmp2 = ($$pre1<<24>>24)==(0);
         if ($phitmp2) {
          ;HEAP32[$agg$result+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$velocity+8>>2]|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         $152 = (($velocity) + 4|0);
         $153 = Math_fround(HEAPF32[$152>>2]);
         __THREW__ = 0;
         $154 = (Math_fround(+(invoke_fiff(3,(0|0),(+$153),0.0))));
         $155 = __THREW__; __THREW__ = 0;
         $156 = $155&1;
         if (!($156)) {
          HEAPF32[$152>>2] = $154;
          ;HEAP32[$agg$result+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$velocity+8>>2]|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z78AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_ApplyGravityAndJumpingP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$velocity) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $velocity = $velocity|0;
 var $$pre = 0, $$pre1 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = Math_fround(0), $133 = Math_fround(0), $134 = Math_fround(0), $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = Math_fround(0), $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0);
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = Math_fround(0), $219 = Math_fround(0), $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = Math_fround(0), $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0);
 var $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = 0, $L_100 = 0, $L_111 = 0, $L_113 = 0, $L_113$byval_copy = 0, $L_114 = 0, $L_48 = 0, $L_51 = 0, $L_53 = 0, $L_54 = 0, $L_81 = 0, $L_82 = 0;
 var $L_85 = 0, $L_87 = 0, $L_88 = 0, $L_91 = 0, $L_95 = 0, $L_99 = 0, $_stackTraceSentry = 0, $velocity$byval_copy2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $L_113$byval_copy = sp + 208|0;
 $velocity$byval_copy2 = sp + 196|0;
 $_stackTraceSentry = sp + 192|0;
 $L_48 = sp + 180|0;
 $L_51 = sp + 168|0;
 $L_53 = sp + 156|0;
 $L_54 = sp + 144|0;
 $L_81 = sp + 132|0;
 $L_82 = sp + 120|0;
 $L_85 = sp + 108|0;
 $L_87 = sp + 36|0;
 $L_88 = sp;
 $L_91 = sp + 12|0;
 $L_95 = sp + 24|0;
 $L_99 = sp + 48|0;
 $L_100 = sp + 60|0;
 $L_111 = sp + 72|0;
 $L_113 = sp + 84|0;
 $L_114 = sp + 96|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290520);
 __THREW__ = 0;
 invoke_v(310);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = (($__this) + 32|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    label = 5;
   } else {
    $7 = (($__this) + 16|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     label = 5;
    } else {
     label = 8;
    }
   }
   if ((label|0) == 5) {
    $10 = (($__this) + 40|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = (($11) + 29|0);
    HEAP8[$14>>0] = 0;
    $15 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($15) + 36|0);
    HEAPF32[$18>>2] = Math_fround(-100.0);
    $$pre = HEAP8[$2>>0]|0;
    $19 = ($$pre<<24>>24)==(0);
    if (!($19)) {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    $20 = (($__this) + 40|0);
    $21 = HEAP32[$20>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = (($21) + 36|0);
    $25 = Math_fround(HEAPF32[$24>>2]);
    $26 = !($25 >= Math_fround(0.0));
    if ($26) {
     $27 = (($__this) + 16|0);
     $28 = HEAP8[$27>>0]|0;
     $29 = ($28<<24>>24)==(0);
     if (!($29)) {
      $30 = HEAP32[$20>>2]|0;
      __THREW__ = 0;
      $31 = (Math_fround(+(invoke_fi(148,(0|0)))));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($30|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      $36 = (($30) + 36|0);
      HEAPF32[$36>>2] = $31;
     }
    }
   }
   $37 = (($__this) + 52|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = ($38<<24>>24)==(0);
   if ($39) {
    $56 = (($__this) + 36|0);
    $57 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($57|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     break;
    }
    $60 = (($57) + 48|0);
    $61 = Math_fround(HEAPF32[$60>>2]);
    $62 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($62|0));
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     break;
    }
    $65 = (($62) + 32|0);
    $66 = Math_fround(HEAPF32[$65>>2]);
    __THREW__ = 0;
    $67 = (Math_fround(+(invoke_fi(149,(0|0)))));
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     break;
    }
    $70 = Math_fround($66 * $67);
    $71 = Math_fround($61 - $70);
    $72 = (($velocity) + 4|0);
    HEAPF32[$72>>2] = $71;
    $73 = (($__this) + 40|0);
    $74 = HEAP32[$73>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($74|0));
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     break;
    }
    $77 = (($74) + 28|0);
    $78 = HEAP8[$77>>0]|0;
    $79 = ($78<<24>>24)==(0);
    if ($79) {
     $134 = $71;
    } else {
     $80 = HEAP32[$73>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($80|0));
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if ($82) {
      break;
     }
     $83 = (($80) + 29|0);
     $84 = HEAP8[$83>>0]|0;
     $85 = ($84<<24>>24)==(0);
     if ($85) {
      $134 = $71;
     } else {
      __THREW__ = 0;
      $86 = (Math_fround(+(invoke_fi(148,(0|0)))));
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       break;
      }
      $89 = HEAP32[$73>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($89|0));
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      $92 = (($89) + 32|0);
      $93 = Math_fround(HEAPF32[$92>>2]);
      $94 = HEAP32[$73>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($94|0));
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       break;
      }
      $97 = (($94) + 16|0);
      $98 = Math_fround(HEAPF32[$97>>2]);
      $99 = HEAP32[$73>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($99|0));
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       break;
      }
      $102 = (($99) + 12|0);
      $103 = Math_fround(HEAPF32[$102>>2]);
      __THREW__ = 0;
      $104 = (Math_fround(+(invoke_fiif(1,(1290568|0),($__this|0),(+$103)))));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       break;
      }
      $107 = Math_fround($98 / $104);
      $108 = Math_fround($93 + $107);
      $109 = !($86 >= $108);
      if ($109) {
       $110 = HEAP32[$73>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($110|0));
       $111 = __THREW__; __THREW__ = 0;
       $112 = $111&1;
       if ($112) {
        break;
       }
       $113 = (($110) + 40|0);
       ;HEAP32[$L_48+0>>2]=HEAP32[$113+0>>2]|0;HEAP32[$L_48+4>>2]=HEAP32[$113+4>>2]|0;HEAP32[$L_48+8>>2]=HEAP32[$113+8>>2]|0;
       $114 = HEAP32[$56>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($114|0));
       $115 = __THREW__; __THREW__ = 0;
       $116 = $115&1;
       if ($116) {
        break;
       }
       $117 = (($114) + 32|0);
       $118 = Math_fround(HEAPF32[$117>>2]);
       __THREW__ = 0;
       ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_48+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_48+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_48+8>>2]|0;
       invoke_viiif(2,($L_51|0),(0|0),($L_113$byval_copy|0),(+$118));
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        break;
       }
       __THREW__ = 0;
       $121 = (Math_fround(+(invoke_fi(149,(0|0)))));
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if ($123) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_51+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_51+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_51+8>>2]|0;
       invoke_viiif(2,($L_53|0),(0|0),($L_113$byval_copy|0),(+$121));
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       if ($125) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$velocity$byval_copy2+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$velocity$byval_copy2+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$velocity$byval_copy2+8>>2]=HEAP32[$velocity+8>>2]|0;
       ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_53+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_53+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_53+8>>2]|0;
       invoke_viiii(222,($L_54|0),(0|0),($velocity$byval_copy2|0),($L_113$byval_copy|0));
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if ($127) {
        break;
       }
       ;HEAP32[$velocity+0>>2]=HEAP32[$L_54+0>>2]|0;HEAP32[$velocity+4>>2]=HEAP32[$L_54+4>>2]|0;HEAP32[$velocity+8>>2]=HEAP32[$L_54+8>>2]|0;
       $$pre1 = Math_fround(HEAPF32[$72>>2]);
       $134 = $$pre1;
      } else {
       $134 = $71;
      }
     }
    }
    $128 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($128|0));
    $129 = __THREW__; __THREW__ = 0;
    $130 = $129&1;
    if ($130) {
     break;
    }
    $131 = (($128) + 36|0);
    $132 = Math_fround(HEAPF32[$131>>2]);
    $133 = Math_fround(-$132);
    __THREW__ = 0;
    $135 = (Math_fround(+(invoke_fiff(4,(0|0),(+$134),(+$133)))));
    $136 = __THREW__; __THREW__ = 0;
    $137 = $136&1;
    if ($137) {
     break;
    }
    HEAPF32[$72>>2] = $135;
   } else {
    $40 = (($velocity) + 4|0);
    $41 = Math_fround(HEAPF32[$40>>2]);
    __THREW__ = 0;
    $42 = (Math_fround(+(invoke_fiff(3,(0|0),0.0,(+$41)))));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    $45 = (($__this) + 36|0);
    $46 = HEAP32[$45>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($46|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    $49 = (($46) + 32|0);
    $50 = Math_fround(HEAPF32[$49>>2]);
    __THREW__ = 0;
    $51 = (Math_fround(+(invoke_fi(149,(0|0)))));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    $54 = Math_fround($50 * $51);
    $55 = Math_fround($42 - $54);
    HEAPF32[$40>>2] = $55;
   }
   $138 = HEAP8[$37>>0]|0;
   $139 = ($138<<24>>24)==(0);
   if ($139) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$velocity+8>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $140 = (($__this) + 40|0);
   $141 = HEAP32[$140>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($141|0));
   $142 = __THREW__; __THREW__ = 0;
   $143 = $142&1;
   if (!($143)) {
    $144 = (($141) + 8|0);
    $145 = HEAP8[$144>>0]|0;
    $146 = ($145<<24>>24)==(0);
    if (!($146)) {
     $147 = (($__this) + 16|0);
     $148 = HEAP8[$147>>0]|0;
     $149 = ($148<<24>>24)==(0);
     if (!($149)) {
      __THREW__ = 0;
      $150 = (Math_fround(+(invoke_fi(148,(0|0)))));
      $151 = __THREW__; __THREW__ = 0;
      $152 = $151&1;
      if ($152) {
       break;
      }
      $153 = HEAP32[$140>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($153|0));
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       break;
      }
      $156 = (($153) + 36|0);
      $157 = Math_fround(HEAPF32[$156>>2]);
      $158 = Math_fround($150 - $157);
      $159 = !($158 >= Math_fround(0.20000000298023223877));
      if ($159) {
       HEAP8[$37>>0] = 0;
       $160 = HEAP32[$140>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($160|0));
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       if ($162) {
        break;
       }
       $163 = (($160) + 28|0);
       HEAP8[$163>>0] = 1;
       $164 = HEAP32[$140>>2]|0;
       __THREW__ = 0;
       $165 = (Math_fround(+(invoke_fi(148,(0|0)))));
       $166 = __THREW__; __THREW__ = 0;
       $167 = $166&1;
       if ($167) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($164|0));
       $168 = __THREW__; __THREW__ = 0;
       $169 = $168&1;
       if ($169) {
        break;
       }
       $170 = (($164) + 32|0);
       HEAPF32[$170>>2] = $165;
       $171 = HEAP32[$140>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($171|0));
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       if ($173) {
        break;
       }
       $174 = (($171) + 36|0);
       HEAPF32[$174>>2] = Math_fround(-100.0);
       $175 = HEAP32[$140>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($175|0));
       $176 = __THREW__; __THREW__ = 0;
       $177 = $176&1;
       if ($177) {
        break;
       }
       $178 = (($175) + 29|0);
       HEAP8[$178>>0] = 1;
       __THREW__ = 0;
       $179 = (invoke_iii(2734,(1290424|0),($__this|0))|0);
       $180 = __THREW__; __THREW__ = 0;
       $181 = $180&1;
       if ($181) {
        break;
       }
       $182 = HEAP32[$140>>2]|0;
       if ($179) {
        __THREW__ = 0;
        invoke_vii(2073,($L_81|0),(0|0));
        $183 = __THREW__; __THREW__ = 0;
        $184 = $183&1;
        if ($184) {
         break;
        }
        $185 = (($__this) + 56|0);
        ;HEAP32[$L_82+0>>2]=HEAP32[$185+0>>2]|0;HEAP32[$L_82+4>>2]=HEAP32[$185+4>>2]|0;HEAP32[$L_82+8>>2]=HEAP32[$185+8>>2]|0;
        $186 = HEAP32[$140>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($186|0));
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         break;
        }
        $189 = (($186) + 24|0);
        $190 = Math_fround(HEAPF32[$189>>2]);
        __THREW__ = 0;
        ;HEAP32[$velocity$byval_copy2+0>>2]=HEAP32[$L_81+0>>2]|0;HEAP32[$velocity$byval_copy2+4>>2]=HEAP32[$L_81+4>>2]|0;HEAP32[$velocity$byval_copy2+8>>2]=HEAP32[$L_81+8>>2]|0;
        ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_82+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_82+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_82+8>>2]|0;
        invoke_viiiif(2,($L_85|0),(0|0),($velocity$byval_copy2|0),($L_113$byval_copy|0),(+$190));
        $191 = __THREW__; __THREW__ = 0;
        $192 = $191&1;
        if ($192) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($182|0));
        $193 = __THREW__; __THREW__ = 0;
        $194 = $193&1;
        if ($194) {
         break;
        }
        $195 = (($182) + 40|0);
        ;HEAP32[$195+0>>2]=HEAP32[$L_85+0>>2]|0;HEAP32[$195+4>>2]=HEAP32[$L_85+4>>2]|0;HEAP32[$195+8>>2]=HEAP32[$L_85+8>>2]|0;
       } else {
        __THREW__ = 0;
        invoke_vii(2073,($L_87|0),(0|0));
        $196 = __THREW__; __THREW__ = 0;
        $197 = $196&1;
        if ($197) {
         break;
        }
        $198 = (($__this) + 56|0);
        ;HEAP32[$L_88+0>>2]=HEAP32[$198+0>>2]|0;HEAP32[$L_88+4>>2]=HEAP32[$198+4>>2]|0;HEAP32[$L_88+8>>2]=HEAP32[$198+8>>2]|0;
        $199 = HEAP32[$140>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($199|0));
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         break;
        }
        $202 = (($199) + 20|0);
        $203 = Math_fround(HEAPF32[$202>>2]);
        __THREW__ = 0;
        ;HEAP32[$velocity$byval_copy2+0>>2]=HEAP32[$L_87+0>>2]|0;HEAP32[$velocity$byval_copy2+4>>2]=HEAP32[$L_87+4>>2]|0;HEAP32[$velocity$byval_copy2+8>>2]=HEAP32[$L_87+8>>2]|0;
        ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_88+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_88+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_88+8>>2]|0;
        invoke_viiiif(2,($L_91|0),(0|0),($velocity$byval_copy2|0),($L_113$byval_copy|0),(+$203));
        $204 = __THREW__; __THREW__ = 0;
        $205 = $204&1;
        if ($205) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($182|0));
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         break;
        }
        $208 = (($182) + 40|0);
        ;HEAP32[$208+0>>2]=HEAP32[$L_91+0>>2]|0;HEAP32[$208+4>>2]=HEAP32[$L_91+4>>2]|0;HEAP32[$208+8>>2]=HEAP32[$L_91+8>>2]|0;
       }
       $209 = (($velocity) + 4|0);
       HEAPF32[$209>>2] = Math_fround(0.0);
       $210 = HEAP32[$140>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($210|0));
       $211 = __THREW__; __THREW__ = 0;
       $212 = $211&1;
       if ($212) {
        break;
       }
       $213 = (($210) + 40|0);
       ;HEAP32[$L_95+0>>2]=HEAP32[$213+0>>2]|0;HEAP32[$L_95+4>>2]=HEAP32[$213+4>>2]|0;HEAP32[$L_95+8>>2]=HEAP32[$213+8>>2]|0;
       $214 = HEAP32[$140>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($214|0));
       $215 = __THREW__; __THREW__ = 0;
       $216 = $215&1;
       if ($216) {
        break;
       }
       $217 = (($214) + 12|0);
       $218 = Math_fround(HEAPF32[$217>>2]);
       __THREW__ = 0;
       $219 = (Math_fround(+(invoke_fiif(1,(1290568|0),($__this|0),(+$218)))));
       $220 = __THREW__; __THREW__ = 0;
       $221 = $220&1;
       if ($221) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_95+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_95+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_95+8>>2]|0;
       invoke_viiif(2,($L_99|0),(0|0),($L_113$byval_copy|0),(+$219));
       $222 = __THREW__; __THREW__ = 0;
       $223 = $222&1;
       if ($223) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$velocity$byval_copy2+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$velocity$byval_copy2+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$velocity$byval_copy2+8>>2]=HEAP32[$velocity+8>>2]|0;
       ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_99+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_99+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_99+8>>2]|0;
       invoke_viiii(222,($L_100|0),(0|0),($velocity$byval_copy2|0),($L_113$byval_copy|0));
       $224 = __THREW__; __THREW__ = 0;
       $225 = $224&1;
       if ($225) {
        break;
       }
       ;HEAP32[$velocity+0>>2]=HEAP32[$L_100+0>>2]|0;HEAP32[$velocity+4>>2]=HEAP32[$L_100+4>>2]|0;HEAP32[$velocity+8>>2]=HEAP32[$L_100+8>>2]|0;
       $226 = (($__this) + 44|0);
       $227 = HEAP32[$226>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($227|0));
       $228 = __THREW__; __THREW__ = 0;
       $229 = $228&1;
       if ($229) {
        break;
       }
       $230 = (($227) + 8|0);
       $231 = HEAP8[$230>>0]|0;
       $232 = ($231<<24>>24)==(0);
       do {
        if (!($232)) {
         $233 = HEAP32[$226>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($233|0));
         $234 = __THREW__; __THREW__ = 0;
         $235 = $234&1;
         if ($235) {
          break L1;
         }
         $236 = (($233) + 12|0);
         $237 = HEAP32[$236>>2]|0;
         $238 = ($237|0)==(1);
         if (!($238)) {
          $239 = HEAP32[$226>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($239|0));
          $240 = __THREW__; __THREW__ = 0;
          $241 = $240&1;
          if ($241) {
           break L1;
          }
          $242 = (($239) + 12|0);
          $243 = HEAP32[$242>>2]|0;
          $244 = ($243|0)==(2);
          if (!($244)) {
           break;
          }
         }
         $245 = (($__this) + 36|0);
         $246 = HEAP32[$245>>2]|0;
         $247 = HEAP32[$226>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($247|0));
         $248 = __THREW__; __THREW__ = 0;
         $249 = $248&1;
         if ($249) {
          break L1;
         }
         $250 = (($247) + 144|0);
         ;HEAP32[$L_111+0>>2]=HEAP32[$250+0>>2]|0;HEAP32[$L_111+4>>2]=HEAP32[$250+4>>2]|0;HEAP32[$L_111+8>>2]=HEAP32[$250+8>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($246|0));
         $251 = __THREW__; __THREW__ = 0;
         $252 = $251&1;
         if ($252) {
          break L1;
         }
         $253 = (($246) + 56|0);
         ;HEAP32[$253+0>>2]=HEAP32[$L_111+0>>2]|0;HEAP32[$253+4>>2]=HEAP32[$L_111+4>>2]|0;HEAP32[$253+8>>2]=HEAP32[$L_111+8>>2]|0;
         $254 = HEAP32[$226>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($254|0));
         $255 = __THREW__; __THREW__ = 0;
         $256 = $255&1;
         if ($256) {
          break L1;
         }
         $257 = (($254) + 144|0);
         ;HEAP32[$L_113+0>>2]=HEAP32[$257+0>>2]|0;HEAP32[$L_113+4>>2]=HEAP32[$257+4>>2]|0;HEAP32[$L_113+8>>2]=HEAP32[$257+8>>2]|0;
         __THREW__ = 0;
         ;HEAP32[$velocity$byval_copy2+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$velocity$byval_copy2+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$velocity$byval_copy2+8>>2]=HEAP32[$velocity+8>>2]|0;
         ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_113+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_113+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_113+8>>2]|0;
         invoke_viiii(222,($L_114|0),(0|0),($velocity$byval_copy2|0),($L_113$byval_copy|0));
         $258 = __THREW__; __THREW__ = 0;
         $259 = $258&1;
         if ($259) {
          break L1;
         }
         ;HEAP32[$velocity+0>>2]=HEAP32[$L_114+0>>2]|0;HEAP32[$velocity+4>>2]=HEAP32[$L_114+4>>2]|0;HEAP32[$velocity+8>>2]=HEAP32[$L_114+8>>2]|0;
        }
       } while(0);
       $260 = HEAP32[2993728>>2]|0;
       __THREW__ = 0;
       invoke_viii(730,($__this|0),($260|0),1);
       $261 = __THREW__; __THREW__ = 0;
       $262 = $261&1;
       if ($262) {
        break;
       }
       ;HEAP32[$agg$result+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$velocity+8>>2]|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
    $263 = HEAP32[$140>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($263|0));
    $264 = __THREW__; __THREW__ = 0;
    $265 = $264&1;
    if (!($265)) {
     $266 = (($263) + 29|0);
     HEAP8[$266>>0] = 0;
     ;HEAP32[$agg$result+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$velocity+8>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z72AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_MoveWithPlatformP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290712);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 8|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $G_B5_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B5_0$0|0);
   }
   $9 = (($__this) + 52|0);
   $10 = HEAP8[$9>>0]|0;
   $11 = ($10<<24>>24)==(0);
   if ($11) {
    $13 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = (($13) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(3);
    $19 = $18&1;
    $G_B3_0$0 = $19;
   } else {
    $12 = $10&255;
    $G_B3_0$0 = $12;
   }
   $20 = ($G_B3_0$0|0)==(0);
   if ($20) {
    $G_B5_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B5_0$0|0);
   }
   $21 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($21|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = (($21) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(1319,(0|0),($25|0),(0|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $G_B5_0$0 = $26;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B5_0$0|0);
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z70AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsGroundedTestP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290904);
 $0 = (($__this) + 60|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = $1 > Math_fround(0.00999999977648258209228);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z83AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_SubtractNewPlatformVelocityP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290664);
 __THREW__ = 0;
 (invoke_ii(2996,(1290000|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1290000|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1205,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_iii(2730,(1289736|0),($2|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($9|0);
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z67AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_FixedUpdateP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $L_12 = 0, $L_15 = 0, $L_15$byval_copy = 0, $L_20 = 0, $L_21 = 0, $L_21$byval_copy = 0, $L_23 = 0, $L_31 = 0, $V_1 = 0, $_stackTraceSentry = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $L_21$byval_copy = sp + 232|0;
 $L_15$byval_copy = sp + 220|0;
 $_stackTraceSentry = sp + 216|0;
 $V_1 = sp + 152|0;
 $L_12 = sp + 88|0;
 $L_15 = sp + 72|0;
 $0 = sp + 60|0;
 $L_20 = sp + 36|0;
 $1 = sp + 24|0;
 $L_21 = sp + 12|0;
 $L_23 = sp;
 $L_31 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290280);
 dest=$V_1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $2 = (($__this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   $6 = (($3) + 8|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($7<<24>>24)==(0);
   do {
    if (!($8)) {
     $11 = HEAP32[$2>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break L1;
     }
     $14 = (($11) + 20|0);
     $15 = HEAP32[$14>>2]|0;
     __THREW__ = 0;
     $16 = (invoke_iiii(1319,(0|0),($15|0),(0|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break L1;
     }
     $19 = HEAP32[$2>>2]|0;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vii(2070,($L_31|0),(0|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($19|0));
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       break L1;
      }
      $83 = (($19) + 144|0);
      ;HEAP32[$83+0>>2]=HEAP32[$L_31+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$L_31+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$L_31+8>>2]|0;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($19|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break L1;
     }
     $22 = (($19) + 156|0);
     $23 = HEAP8[$22>>0]|0;
     $24 = ($23<<24>>24)==(0);
     if ($24) {
      $25 = HEAP32[$2>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($25|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break L1;
      }
      $28 = HEAP32[$2>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($28|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break L1;
      }
      $31 = (($28) + 20|0);
      $32 = HEAP32[$31>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($32|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vii(2142,($L_12|0),($32|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break L1;
      }
      dest=$V_1+0|0; src=$L_12+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $37 = HEAP32[$2>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break L1;
      }
      $40 = (($37) + 24|0);
      _memmove(($0|0),($40|0),12)|0;
      __THREW__ = 0;
      ;HEAP32[$L_21$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_21$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_21$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
      invoke_viii(758,($L_15|0),($V_1|0),($L_21$byval_copy|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break L1;
      }
      $43 = HEAP32[$2>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($43|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break L1;
      }
      $46 = HEAP32[$2>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($46|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break L1;
      }
      $49 = (($43) + 80|0);
      $50 = (($46) + 24|0);
      _memmove(($1|0),($50|0),12)|0;
      __THREW__ = 0;
      ;HEAP32[$L_21$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$L_21$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$L_21$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;
      invoke_viii(758,($L_20|0),($49|0),($L_21$byval_copy|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break L1;
      }
      __THREW__ = 0;
      ;HEAP32[$L_15$byval_copy+0>>2]=HEAP32[$L_15+0>>2]|0;HEAP32[$L_15$byval_copy+4>>2]=HEAP32[$L_15+4>>2]|0;HEAP32[$L_15$byval_copy+8>>2]=HEAP32[$L_15+8>>2]|0;
      ;HEAP32[$L_21$byval_copy+0>>2]=HEAP32[$L_20+0>>2]|0;HEAP32[$L_21$byval_copy+4>>2]=HEAP32[$L_20+4>>2]|0;HEAP32[$L_21$byval_copy+8>>2]=HEAP32[$L_20+8>>2]|0;
      invoke_viiii(223,($L_21|0),(0|0),($L_15$byval_copy|0),($L_21$byval_copy|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break L1;
      }
      __THREW__ = 0;
      $55 = (Math_fround(+(invoke_fi(149,(0|0)))));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break L1;
      }
      __THREW__ = 0;
      ;HEAP32[$L_21$byval_copy+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$L_21$byval_copy+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$L_21$byval_copy+8>>2]=HEAP32[$L_21+8>>2]|0;
      invoke_viiif(3,($L_23|0),(0|0),($L_21$byval_copy|0),(+$55));
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($28|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break L1;
      }
      $62 = (($28) + 144|0);
      ;HEAP32[$62+0>>2]=HEAP32[$L_23+0>>2]|0;HEAP32[$62+4>>2]=HEAP32[$L_23+4>>2]|0;HEAP32[$62+8>>2]=HEAP32[$L_23+8>>2]|0;
     }
     $63 = HEAP32[$2>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($63|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break L1;
     }
     $66 = (($63) + 20|0);
     $67 = HEAP32[$66>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($67|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(2142,($L_21$byval_copy|0),($67|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3799,($63|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      break L1;
     }
     $74 = (($63) + 80|0);
     dest=$74+0|0; src=$L_21$byval_copy+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $75 = HEAP32[$2>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($75|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break L1;
     }
     $78 = (($75) + 156|0);
     HEAP8[$78>>0] = 0;
    }
   } while(0);
   $84 = (($__this) + 17|0);
   $85 = HEAP8[$84>>0]|0;
   $86 = ($85<<24>>24)==(0);
   if ($86) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(1424,($__this|0));
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if (!($88)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z62AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_UpdateP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290328);
 $0 = (($__this) + 17|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(1424,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker0I29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z84AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_GetDesiredHorizontalVelocityP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $L_1 = 0, $L_17 = 0, $L_17$byval_copy = 0, $L_2 = 0, $L_7 = 0, $V_0 = 0, $V_1$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_17$byval_copy = sp + 64|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 $L_1 = sp + 16|0;
 $L_2 = sp + 28|0;
 $L_7 = sp + 40|0;
 $L_17 = sp + 52|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290760);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 $0 = (($__this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 20|0);
 ;HEAP32[$L_1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$2+8>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$L_17$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_17$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_17$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   invoke_viii(779,($L_2|0),($1|0),($L_17$byval_copy|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    ;HEAP32[$V_0+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_2+8>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$L_17$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_17$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_17$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;
    $7 = (Math_fround(+(invoke_fiii(16,(1290808|0),($__this|0),($L_17$byval_copy|0)))));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($__this) + 52|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      $V_1$0 = $7;
     } else {
      $15 = (($__this) + 36|0);
      $16 = HEAP32[$15>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($16|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      $19 = (($16) + 44|0);
      __THREW__ = 0;
      invoke_vii(2069,($L_7|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      $22 = (($L_7) + 4|0);
      $23 = Math_fround(HEAPF32[$22>>2]);
      $24 = (Math_fround(+(Math_asin((+$23)))));
      $25 = Math_fround($24 * Math_fround(57.295780181884765625));
      $26 = HEAP32[$15>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = (($26) + 20|0);
      $30 = HEAP32[$29>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($30|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      $33 = (Math_fround(+(invoke_fif(13,($30|0),(+$25)))));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      $36 = Math_fround($7 * $33);
      $V_1$0 = $36;
     }
     $37 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$L_17$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_17$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_17$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
     invoke_viiif(2,($L_17|0),(0|0),($L_17$byval_copy|0),(+$V_1$0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       __THREW__ = 0;
       ;HEAP32[$L_17$byval_copy+0>>2]=HEAP32[$L_17+0>>2]|0;HEAP32[$L_17$byval_copy+4>>2]=HEAP32[$L_17+4>>2]|0;HEAP32[$L_17$byval_copy+8>>2]=HEAP32[$L_17+8>>2]|0;
       invoke_viii(778,($agg$result|0),($37|0),($L_17$byval_copy|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if (!($43)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z84AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_AdjustGroundVelocityToNormalP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$hVelocity,$groundNormal) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $hVelocity = $hVelocity|0;
 $groundNormal = $groundNormal|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $L_0 = 0, $L_1 = 0, $L_1$byval_copy = 0, $L_2 = 0, $L_3 = 0;
 var $L_3$byval_copy = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_3$byval_copy = sp + 76|0;
 $L_1$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $V_1 = sp + 16|0;
 $L_0 = sp + 28|0;
 $L_1 = sp + 40|0;
 $L_2 = sp + 52|0;
 $L_3 = sp + 64|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290856);
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2073,($L_0|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
  ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$hVelocity+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$hVelocity+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$hVelocity+8>>2]|0;
  invoke_viiii(218,($L_1|0),(0|0),($L_1$byval_copy|0),($L_3$byval_copy|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$groundNormal+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$groundNormal+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$groundNormal+8>>2]|0;
   invoke_viiii(218,($L_2|0),(0|0),($L_1$byval_copy|0),($L_3$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    ;HEAP32[$V_1+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_2+8>>2]|0;
    __THREW__ = 0;
    invoke_vii(2069,($L_3|0),($V_1|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (Math_fround(+(invoke_fi(136,($hVelocity|0)))));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;
      invoke_viiif(2,($agg$result|0),(0|0),($L_3$byval_copy|0),(+$8));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __ZN16VirtFuncInvoker1I28mscorlib_System_SingleTraits29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fii[$3 & 63]($4,$p1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN16VirtFuncInvoker1I28mscorlib_System_SingleTraitsS0_E6InvokeEP10MethodInfoPvf($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = Math_fround($p1);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fif[$3 & 31]($4,$p1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __Z79AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_OnControllerColliderHitP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP45UnityEngine_UnityEngine_ControllerColliderHit($__this,$hit) {
 $__this = $__this|0;
 $hit = $hit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0;
 var $L_0 = 0, $L_12 = 0, $L_14 = 0, $L_15 = 0, $L_18 = 0, $L_18$byval_copy = 0, $L_19 = 0, $L_19$byval_copy = 0, $L_21 = 0, $L_27 = 0, $L_29 = 0, $L_4 = 0, $L_8 = 0, $V_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $L_19$byval_copy = sp + 160|0;
 $L_18$byval_copy = sp + 148|0;
 $_stackTraceSentry = sp + 144|0;
 $V_3 = sp + 132|0;
 $L_0 = sp + 120|0;
 $L_4 = sp + 108|0;
 $L_8 = sp + 96|0;
 $L_12 = sp + 84|0;
 $L_14 = sp + 60|0;
 $L_15 = sp + 48|0;
 $L_18 = sp + 36|0;
 $L_19 = sp + 24|0;
 $L_21 = sp + 12|0;
 $L_27 = sp;
 $L_29 = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290616);
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(3799,($hit|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(2154,($L_0|0),($hit|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($L_0) + 4|0);
    $5 = Math_fround(HEAPF32[$4>>2]);
    $6 = !($5 <= Math_fround(0.0));
    if (!($6)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3799,($hit|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vii(2154,($L_4|0),($hit|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = (($L_4) + 4|0);
      $14 = Math_fround(HEAPF32[$13>>2]);
      $15 = (($__this) + 56|0);
      $16 = (($__this) + 60|0);
      $17 = Math_fround(HEAPF32[$16>>2]);
      $18 = !($14 <= $17);
      if (!($18)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3799,($hit|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       invoke_vii(2155,($L_8|0),($hit|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $23 = (($L_8) + 4|0);
        $24 = Math_fround(HEAPF32[$23>>2]);
        $25 = !($24 >= Math_fround(0.0));
        if (!($25)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        invoke_vi(3799,($hit|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         __THREW__ = 0;
         invoke_vii(2153,($L_12|0),($hit|0));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          $30 = (($__this) + 36|0);
          $31 = HEAP32[$30>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($31|0));
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           $34 = (($31) + 80|0);
           ;HEAP32[$L_14+0>>2]=HEAP32[$34+0>>2]|0;HEAP32[$L_14+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$L_14+8>>2]=HEAP32[$34+8>>2]|0;
           __THREW__ = 0;
           ;HEAP32[$L_18$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_18$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_18$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;
           ;HEAP32[$L_19$byval_copy+0>>2]=HEAP32[$L_14+0>>2]|0;HEAP32[$L_19$byval_copy+4>>2]=HEAP32[$L_14+4>>2]|0;HEAP32[$L_19$byval_copy+8>>2]=HEAP32[$L_14+8>>2]|0;
           invoke_viiii(223,($L_15|0),(0|0),($L_18$byval_copy|0),($L_19$byval_copy|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if (!($36)) {
            ;HEAP32[$V_3+0>>2]=HEAP32[$L_15+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_15+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_15+8>>2]|0;
            __THREW__ = 0;
            $37 = (Math_fround(+(invoke_fi(137,($V_3|0)))));
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if (!($39)) {
             $40 = $37 > Math_fround(0.00100000004749745130539);
             if ($40) {
              label = 20;
             } else {
              $41 = (($__this) + 68|0);
              ;HEAP32[$L_18+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$L_18+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$L_18+8>>2]=HEAP32[$41+8>>2]|0;
              __THREW__ = 0;
              invoke_vii(2070,($L_19|0),(0|0));
              $42 = __THREW__; __THREW__ = 0;
              $43 = $42&1;
              if ($43) {
               break;
              }
              __THREW__ = 0;
              ;HEAP32[$L_18$byval_copy+0>>2]=HEAP32[$L_18+0>>2]|0;HEAP32[$L_18$byval_copy+4>>2]=HEAP32[$L_18+4>>2]|0;HEAP32[$L_18$byval_copy+8>>2]=HEAP32[$L_18+8>>2]|0;
              ;HEAP32[$L_19$byval_copy+0>>2]=HEAP32[$L_19+0>>2]|0;HEAP32[$L_19$byval_copy+4>>2]=HEAP32[$L_19+4>>2]|0;HEAP32[$L_19$byval_copy+8>>2]=HEAP32[$L_19+8>>2]|0;
              $44 = (invoke_iiii(1351,(0|0),($L_18$byval_copy|0),($L_19$byval_copy|0))|0);
              $45 = __THREW__; __THREW__ = 0;
              $46 = $45&1;
              if ($46) {
               break;
              }
              if ($44) {
               label = 20;
              } else {
               ;HEAP32[$15+0>>2]=HEAP32[$41+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$41+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$41+8>>2]|0;
              }
             }
             if ((label|0) == 20) {
              __THREW__ = 0;
              invoke_vi(3799,($hit|0));
              $47 = __THREW__; __THREW__ = 0;
              $48 = $47&1;
              if ($48) {
               break;
              }
              __THREW__ = 0;
              invoke_vii(2154,($L_21|0),($hit|0));
              $49 = __THREW__; __THREW__ = 0;
              $50 = $49&1;
              if ($50) {
               break;
              }
              ;HEAP32[$15+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$L_21+8>>2]|0;
             }
             $51 = (($__this) + 44|0);
             $52 = HEAP32[$51>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($hit|0));
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if (!($54)) {
              __THREW__ = 0;
              $55 = (invoke_ii(2642,($hit|0))|0);
              $56 = __THREW__; __THREW__ = 0;
              $57 = $56&1;
              if (!($57)) {
               __THREW__ = 0;
               invoke_vi(3799,($55|0));
               $58 = __THREW__; __THREW__ = 0;
               $59 = $58&1;
               if (!($59)) {
                __THREW__ = 0;
                $60 = (invoke_ii(2522,($55|0))|0);
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if (!($62)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($52|0));
                 $63 = __THREW__; __THREW__ = 0;
                 $64 = $63&1;
                 if ($64) {
                  break;
                 }
                 $65 = (($52) + 16|0);
                 HEAP32[$65>>2] = $60;
                 $66 = HEAP32[$30>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($hit|0));
                 $67 = __THREW__; __THREW__ = 0;
                 $68 = $67&1;
                 if ($68) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vii(2153,($L_27|0),($hit|0));
                 $69 = __THREW__; __THREW__ = 0;
                 $70 = $69&1;
                 if ($70) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($66|0));
                 $71 = __THREW__; __THREW__ = 0;
                 $72 = $71&1;
                 if ($72) {
                  break;
                 }
                 $73 = (($66) + 68|0);
                 ;HEAP32[$73+0>>2]=HEAP32[$L_27+0>>2]|0;HEAP32[$73+4>>2]=HEAP32[$L_27+4>>2]|0;HEAP32[$73+8>>2]=HEAP32[$L_27+8>>2]|0;
                 $74 = HEAP32[$30>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(2070,($L_29|0),(0|0));
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if ($76) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($74|0));
                 $77 = __THREW__; __THREW__ = 0;
                 $78 = $77&1;
                 if ($78) {
                  break;
                 }
                 $79 = (($74) + 56|0);
                 ;HEAP32[$79+0>>2]=HEAP32[$L_29+0>>2]|0;HEAP32[$79+4>>2]=HEAP32[$L_29+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$L_29+8>>2]|0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __ZN16VirtFuncInvoker1I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEP10MethodInfoPv31UnityEngine_UnityEngine_Vector3($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $data = 0, $p1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p1$byval_copy = sp + 8|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 ;HEAP32[$p1$byval_copy+0>>2]=HEAP32[$p1+0>>2]|0;HEAP32[$p1$byval_copy+4>>2]=HEAP32[$p1+4>>2]|0;HEAP32[$p1$byval_copy+8>>2]=HEAP32[$p1+8>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fii[$3 & 63]($4,$p1$byval_copy)));
 STACKTOP = sp;return (Math_fround($5));
}
function __Z74AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_GetMaxAccelerationP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorb($__this,$grounded) {
 $__this = $__this|0;
 $grounded = $grounded|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = Math_fround(0), $G_B3_0$0$in = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290472);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 if ($grounded) {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   label = 4;
  } else {
   $4 = (($1) + 24|0);
   $G_B3_0$0$in = $4;
   label = 7;
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   label = 4;
  } else {
   $9 = (($1) + 28|0);
   $G_B3_0$0$in = $9;
   label = 7;
  }
 }
 if ((label|0) == 4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 else if ((label|0) == 7) {
  $G_B3_0$0 = Math_fround(HEAPF32[$G_B3_0$0$in>>2]);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($G_B3_0$0));
 }
 return Math_fround(0);
}
function __Z82AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_CalculateJumpVerticalSpeedP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorf($__this,$targetJumpHeight) {
 $__this = $__this|0;
 $targetJumpHeight = Math_fround($targetJumpHeight);
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290568);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $4 = Math_fround($targetJumpHeight * Math_fround(2.0));
  $5 = (($1) + 32|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = Math_fround($4 * $6);
  $8 = (Math_fround(Math_sqrt((Math_fround($7)))));
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($8));
 }
 return Math_fround(0);
}
function __Z65AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsJumpingP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290952);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $4 = (($1) + 28|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z65AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsSlidingP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B2_0$0$off0 = 0, $G_B4_0$0$in = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1291000);
 $0 = (($__this) + 52|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $G_B4_0$0$in = 0;
 } else {
  $3 = (($__this) + 48|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  }
  $7 = (($4) + 8|0);
  $8 = HEAP8[$7>>0]|0;
  $G_B2_0$0$off0 = ($8<<24>>24)==(0);
  if ($G_B2_0$0$off0) {
   $G_B4_0$0$in = 0;
  } else {
   __THREW__ = 0;
   $11 = (invoke_iii(2734,(1290424|0),($__this|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($9|0);
    // unreachable;
   } else {
    $G_B4_0$0$in = $11;
   }
  }
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B4_0$0$in|0);
}
function __Z73AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsTouchingCeilingP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1291048);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $4 = (($1) + 40|0);
  $5 = HEAP32[$4>>2]|0;
  $$lobit = $5 & 2;
  $6 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z66AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsGroundedP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1291096);
 $0 = (($__this) + 52|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z64AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_TooSteepP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290424);
 $0 = (($__this) + 60|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($__this) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($12|0);
  // unreachable;
 }
 __THREW__ = 0;
 $6 = (Math_fround(+(invoke_fi(157,($3|0)))));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $9 = Math_fround($6 * Math_fround(0.0174532923847436904907));
  $10 = (Math_fround(+(Math_cos((+$9)))));
  $11 = !($1 > $10);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z68AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_GetDirectionP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1291144);
 $0 = (($__this) + 20|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z71AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_SetControllableP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorb($__this,$controllable) {
 $__this = $__this|0;
 $controllable = $controllable|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1291192);
 $0 = (($__this) + 16|0);
 $1 = $controllable&1;
 HEAP8[$0>>0] = $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z75AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_MaxSpeedInDirectionP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3($__this,$desiredMovementDirection) {
 $__this = $__this|0;
 $desiredMovementDirection = $desiredMovementDirection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = Math_fround(0);
 var $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $G_B5_0$0 = Math_fround(0), $G_B5_0$0$in = 0, $G_B6_0$0 = Math_fround(0), $L_0 = 0, $L_0$byval_copy = 0, $L_19 = 0, $L_20 = 0, $L_26 = 0, $V_3 = 0, $V_4 = 0, $_stackTraceSentry = 0, $desiredMovementDirection$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $L_0$byval_copy = sp + 88|0;
 $desiredMovementDirection$byval_copy = sp + 76|0;
 $_stackTraceSentry = sp + 72|0;
 $V_3 = sp + 60|0;
 $V_4 = sp + 48|0;
 $L_0 = sp + 24|0;
 $L_19 = sp + 12|0;
 $L_20 = sp;
 $L_26 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1290808);
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2070,($L_0|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   ;HEAP32[$desiredMovementDirection$byval_copy+0>>2]=HEAP32[$desiredMovementDirection+0>>2]|0;HEAP32[$desiredMovementDirection$byval_copy+4>>2]=HEAP32[$desiredMovementDirection+4>>2]|0;HEAP32[$desiredMovementDirection$byval_copy+8>>2]=HEAP32[$desiredMovementDirection+8>>2]|0;
   ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
   $2 = (invoke_iiii(1351,(0|0),($desiredMovementDirection$byval_copy|0),($L_0$byval_copy|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if ($2) {
     $G_B6_0$0 = Math_fround(0.0);
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return (Math_fround($G_B6_0$0));
    }
    $7 = (($desiredMovementDirection) + 8|0);
    $8 = Math_fround(HEAPF32[$7>>2]);
    $9 = !($8 <= Math_fround(0.0));
    $10 = (($__this) + 36|0);
    $11 = HEAP32[$10>>2]|0;
    if ($9) {
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = (($11) + 8|0);
     $G_B5_0$0$in = $14;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     $17 = (($11) + 16|0);
     $G_B5_0$0$in = $17;
    }
    $G_B5_0$0 = Math_fround(HEAPF32[$G_B5_0$0$in>>2]);
    $18 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = (($18) + 12|0);
     $22 = Math_fround(HEAPF32[$21>>2]);
     $23 = Math_fround($G_B5_0$0 / $22);
     $24 = Math_fround(HEAPF32[$desiredMovementDirection>>2]);
     $25 = Math_fround($8 / $23);
     ;HEAP32[$L_19+0>>2]=0|0;HEAP32[$L_19+4>>2]=0|0;HEAP32[$L_19+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vifff(4,($L_19|0),(+$24),0.0,(+$25));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      ;HEAP32[$V_3+0>>2]=HEAP32[$L_19+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_19+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_19+8>>2]|0;
      __THREW__ = 0;
      invoke_vii(2069,($L_20|0),($V_3|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       $30 = Math_fround(HEAPF32[$L_20>>2]);
       $31 = (($L_20) + 8|0);
       $32 = Math_fround(HEAPF32[$31>>2]);
       $33 = Math_fround($23 * $32);
       ;HEAP32[$L_26+0>>2]=0|0;HEAP32[$L_26+4>>2]=0|0;HEAP32[$L_26+8>>2]=0|0;
       __THREW__ = 0;
       invoke_vifff(4,($L_26|0),(+$30),0.0,(+$33));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        ;HEAP32[$V_4+0>>2]=HEAP32[$L_26+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_26+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_26+8>>2]|0;
        __THREW__ = 0;
        $36 = (Math_fround(+(invoke_fi(136,($V_4|0)))));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = HEAP32[$10>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($39|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = (($39) + 12|0);
          $43 = Math_fround(HEAPF32[$42>>2]);
          $44 = Math_fround($36 * $43);
          $G_B6_0$0 = $44;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return (Math_fround($G_B6_0$0));
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z67AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_SetVelocityP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3($__this,$velocity) {
 $__this = $__this|0;
 $velocity = $velocity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1291240);
 __THREW__ = 0;
 invoke_v(311);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 52|0);
  HEAP8[$2>>0] = 0;
  $3 = (($__this) + 36|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($4) + 44|0);
   ;HEAP32[$7+0>>2]=HEAP32[$velocity+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$velocity+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$velocity+8>>2]|0;
   $8 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   invoke_vii(2070,($L_3|0),(0|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = (($8) + 56|0);
     ;HEAP32[$13+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$L_3+8>>2]|0;
     $14 = HEAP32[2993760>>2]|0;
     __THREW__ = 0;
     invoke_vii(2002,($__this|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z60AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_MainP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1291288);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector3TraitsS0_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 12|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker0I37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3TraitsS0_S0_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS2_S2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 36|0;
 $$byval_copy = sp;
 $ret = sp + 12|0;
 $0 = sp + 24|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits29mscorlib_System_BooleanTraitsE6InvokeEPFfPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$2)));
 HEAPF32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraitsS0_E6InvokeEPFfPvfES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = Math_fround(0), $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (Math_fround(FUNCTION_TABLE_fif[$func & 31]($obj,$1)));
 HEAPF32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFfPv31UnityEngine_UnityEngine_Vector3ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 $1 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$tmpcast$byval_copy)));
 HEAPF32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN14ActionInvoker1I37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFvPv31UnityEngine_UnityEngine_Vector3ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z84AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(1292480)|0);
 __Z48UnityEngine_UnityEngine_AddComponentMenu_m__ctorP40UnityEngine_UnityEngine_AddComponentMenuP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717112)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2839072)|0);
 $8 = HEAP32[((2839072 + 48|0))>>2]|0;
 $9 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($8)|0);
 __Z48UnityEngine_UnityEngine_RequireComponent_m__ctorP40UnityEngine_UnityEngine_RequireComponentP20mscorlib_System_Type($7,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $7;
 STACKTOP = sp;return;
}
function __Z65AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m__ctorP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1292928);
 __THREW__ = 0;
 invoke_vi(3120,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z65AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_AwakeP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1292976);
 HEAP32[$0>>2] = 1300304;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(1189,($__this|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1292792|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2733,($4|0),(1292792|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($__this) + 16|0);
     HEAP32[$12>>2] = $9;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z66AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_UpdateP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0;
 var $27 = Math_fround(0), $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $L_13 = 0, $L_16 = 0, $L_16$byval_copy = 0, $L_17 = 0, $L_4 = 0, $L_5 = 0, $L_8 = 0;
 var $V_0 = 0, $V_0$byval_copy3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $V_0$byval_copy3 = sp + 112|0;
 $L_16$byval_copy = sp + 96|0;
 $_stackTraceSentry = sp + 88|0;
 $V_0 = sp + 76|0;
 $L_4 = sp + 64|0;
 $L_5 = sp + 52|0;
 $L_8 = sp + 28|0;
 $L_13 = sp + 16|0;
 $L_16 = sp;
 $L_17 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1293024);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(312);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[2993816>>2]|0;
   __THREW__ = 0;
   $3 = (Math_fround(+(invoke_fii(41,(0|0),($2|0)))));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = HEAP32[2993824>>2]|0;
    __THREW__ = 0;
    $7 = (Math_fround(+(invoke_fii(41,(0|0),($6|0)))));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vifff(4,($L_4|0),(+$3),0.0,(+$7));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      ;HEAP32[$V_0+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_4+8>>2]|0;
      __THREW__ = 0;
      invoke_vii(2070,($L_5|0),(0|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
       ;HEAP32[$V_0$byval_copy3+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$V_0$byval_copy3+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$V_0$byval_copy3+8>>2]=HEAP32[$L_5+8>>2]|0;
       $14 = (invoke_iiii(1353,(0|0),($L_16$byval_copy|0),($V_0$byval_copy3|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        if ($14) {
         __THREW__ = 0;
         $19 = (Math_fround(+(invoke_fi(136,($V_0|0)))));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          break;
         }
         __THREW__ = 0;
         ;HEAP32[$V_0$byval_copy3+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$V_0$byval_copy3+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$V_0$byval_copy3+8>>2]=HEAP32[$V_0+8>>2]|0;
         invoke_viiif(3,($L_8|0),(0|0),($V_0$byval_copy3|0),(+$19));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if ($23) {
          break;
         }
         ;HEAP32[$V_0+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_8+8>>2]|0;
         __THREW__ = 0;
         $24 = (Math_fround(+(invoke_fiff(3,(0|0),1.0,(+$19)))));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if ($26) {
          break;
         }
         $27 = Math_fround($24 * $24);
         __THREW__ = 0;
         ;HEAP32[$V_0$byval_copy3+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$V_0$byval_copy3+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$V_0$byval_copy3+8>>2]=HEAP32[$V_0+8>>2]|0;
         invoke_viiif(2,($L_13|0),(0|0),($V_0$byval_copy3|0),(+$27));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          break;
         }
         ;HEAP32[$V_0+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_13+8>>2]|0;
        }
        $30 = (($__this) + 16|0);
        $31 = HEAP32[$30>>2]|0;
        __THREW__ = 0;
        $32 = (invoke_ii(2522,($__this|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         __THREW__ = 0;
         invoke_vi(3799,($32|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          __THREW__ = 0;
          invoke_vii(2133,($L_16|0),($32|0));
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if (!($38)) {
           __THREW__ = 0;
           ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_16+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_16+12>>2]|0;
           ;HEAP32[$V_0$byval_copy3+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$V_0$byval_copy3+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$V_0$byval_copy3+8>>2]=HEAP32[$V_0+8>>2]|0;
           invoke_viiii(229,($L_17|0),(0|0),($L_16$byval_copy|0),($V_0$byval_copy3|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            __THREW__ = 0;
            invoke_vi(3799,($31|0));
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if (!($42)) {
             $43 = (($31) + 20|0);
             ;HEAP32[$43+0>>2]=HEAP32[$L_17+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$L_17+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$L_17+8>>2]|0;
             $44 = HEAP32[$30>>2]|0;
             $45 = HEAP32[2993832>>2]|0;
             __THREW__ = 0;
             $46 = (invoke_iii(1232,(0|0),($45|0))|0);
             $47 = __THREW__; __THREW__ = 0;
             $48 = $47&1;
             if (!($48)) {
              __THREW__ = 0;
              invoke_vi(3799,($44|0));
              $49 = __THREW__; __THREW__ = 0;
              $50 = $49&1;
              if (!($50)) {
               $51 = (($44) + 32|0);
               $52 = $46&1;
               HEAP8[$51>>0] = $52;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z64AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_MainP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1293072);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z88AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717112)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1292792)|0);
 $5 = HEAP32[((1292792 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z48UnityEngine_UnityEngine_RequireComponent_m__ctorP40UnityEngine_UnityEngine_RequireComponentP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717488)|0);
 $9 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(1293152)|0);
 __Z48UnityEngine_UnityEngine_AddComponentMenu_m__ctorP40UnityEngine_UnityEngine_AddComponentMenuP22mscorlib_System_String($8,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $8;
 STACKTOP = sp;return;
}
function __Z70AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m__ctorP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1293424);
 __THREW__ = 0;
 invoke_vi(3120,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 16|0);
  HEAP8[$2>>0] = 1;
  $3 = (($__this) + 20|0);
  HEAPF32[$3>>2] = Math_fround(360.0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z70AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_AwakeP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1293472);
 HEAP32[$0>>2] = 1300304;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(1189,($__this|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1292792|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2733,($4|0),(1292792|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($__this) + 24|0);
     HEAP32[$12>>2] = $9;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z71AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_UpdateP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = Math_fround(0), $103 = Math_fround(0), $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = Math_fround(0), $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_13 = 0, $L_16 = 0, $L_17 = 0, $L_20 = 0, $L_21 = 0, $L_23 = 0, $L_24 = 0, $L_25 = 0, $L_33 = 0, $L_37 = 0, $L_39 = 0, $L_4 = 0;
 var $L_40 = 0, $L_43 = 0, $L_44 = 0, $L_44$byval_copy = 0, $L_5 = 0, $L_8 = 0, $V_0 = 0, $V_3 = 0, $V_3$byval_copy = 0, $_stackTraceSentry = 0, $data$i = 0, $data$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 368|0;
 $L_44$byval_copy = sp + 344|0;
 $V_3$byval_copy = sp + 328|0;
 $data$i9 = sp + 320|0;
 $0 = sp + 32|0;
 $1 = sp + 48|0;
 $data$i = sp + 312|0;
 $2 = sp + 16|0;
 $3 = sp;
 $_stackTraceSentry = sp + 308|0;
 $V_0 = sp + 296|0;
 $V_3 = sp + 284|0;
 $L_4 = sp + 272|0;
 $L_5 = sp + 260|0;
 $L_8 = sp + 248|0;
 $L_13 = sp + 128|0;
 $L_16 = sp + 144|0;
 $L_17 = sp + 160|0;
 $L_20 = sp + 172|0;
 $L_21 = sp + 104|0;
 $L_23 = sp + 72|0;
 $L_24 = sp + 88|0;
 $L_25 = sp + 116|0;
 $L_33 = sp + 60|0;
 $L_37 = sp + 184|0;
 $L_39 = sp + 196|0;
 $L_40 = sp + 208|0;
 $L_43 = sp + 220|0;
 $L_44 = sp + 232|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1293520);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(313);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = HEAP32[2993896>>2]|0;
   __THREW__ = 0;
   $7 = (Math_fround(+(invoke_fii(41,(0|0),($6|0)))));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[2993904>>2]|0;
    __THREW__ = 0;
    $11 = (Math_fround(+(invoke_fii(41,(0|0),($10|0)))));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vifff(4,($L_4|0),(+$7),(+$11),0.0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      ;HEAP32[$V_0+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_4+8>>2]|0;
      __THREW__ = 0;
      invoke_vii(2070,($L_5|0),(0|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
       ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;
       $18 = (invoke_iiii(1353,(0|0),($V_3$byval_copy|0),($L_44$byval_copy|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        if ($18) {
         __THREW__ = 0;
         $23 = (Math_fround(+(invoke_fi(136,($V_0|0)))));
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          break;
         }
         __THREW__ = 0;
         ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
         invoke_viiif(3,($L_8|0),(0|0),($L_44$byval_copy|0),(+$23));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         ;HEAP32[$V_0+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_8+8>>2]|0;
         __THREW__ = 0;
         $28 = (Math_fround(+(invoke_fiff(3,(0|0),1.0,(+$23)))));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         $31 = Math_fround($28 * $28);
         __THREW__ = 0;
         ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
         invoke_viiif(2,($L_13|0),(0|0),($L_44$byval_copy|0),(+$31));
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         }
         ;HEAP32[$V_0+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_13+8>>2]|0;
        }
        __THREW__ = 0;
        $34 = (invoke_ii(2633,(0|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         __THREW__ = 0;
         invoke_vi(3799,($34|0));
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if (!($38)) {
          __THREW__ = 0;
          $39 = (invoke_ii(2522,($34|0))|0);
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if (!($41)) {
           __THREW__ = 0;
           invoke_vi(3799,($39|0));
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if (!($43)) {
            __THREW__ = 0;
            invoke_vii(2133,($L_16|0),($39|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             __THREW__ = 0;
             ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$L_16+8>>2]|0;HEAP32[$V_3$byval_copy+12>>2]=HEAP32[$L_16+12>>2]|0;
             ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
             invoke_viiii(229,($L_17|0),(0|0),($V_3$byval_copy|0),($L_44$byval_copy|0));
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if (!($47)) {
              ;HEAP32[$V_0+0>>2]=HEAP32[$L_17+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_17+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_17+8>>2]|0;
              __THREW__ = 0;
              $48 = (invoke_ii(2633,(0|0))|0);
              $49 = __THREW__; __THREW__ = 0;
              $50 = $49&1;
              if (!($50)) {
               __THREW__ = 0;
               invoke_vi(3799,($48|0));
               $51 = __THREW__; __THREW__ = 0;
               $52 = $51&1;
               if (!($52)) {
                __THREW__ = 0;
                $53 = (invoke_ii(2522,($48|0))|0);
                $54 = __THREW__; __THREW__ = 0;
                $55 = $54&1;
                if (!($55)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($53|0));
                 $56 = __THREW__; __THREW__ = 0;
                 $57 = $56&1;
                 if (!($57)) {
                  __THREW__ = 0;
                  invoke_vii(2130,($L_20|0),($53|0));
                  $58 = __THREW__; __THREW__ = 0;
                  $59 = $58&1;
                  if (!($59)) {
                   __THREW__ = 0;
                   ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$L_20+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$L_20+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$L_20+8>>2]|0;
                   invoke_viii(739,($L_21|0),(0|0),($L_44$byval_copy|0));
                   $60 = __THREW__; __THREW__ = 0;
                   $61 = $60&1;
                   if (!($61)) {
                    __THREW__ = 0;
                    $62 = (invoke_ii(2522,($__this|0))|0);
                    $63 = __THREW__; __THREW__ = 0;
                    $64 = $63&1;
                    if ($64) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($62|0));
                    $65 = __THREW__; __THREW__ = 0;
                    $66 = $65&1;
                    if ($66) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vii(2129,($L_23|0),($62|0));
                    $67 = __THREW__; __THREW__ = 0;
                    $68 = $67&1;
                    if ($68) {
                     break;
                    }
                    __THREW__ = 0;
                    ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$L_21+8>>2]|0;
                    ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$L_23+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$L_23+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$L_23+8>>2]|0;
                    invoke_viiii(224,($L_24|0),(0|0),($V_3$byval_copy|0),($L_44$byval_copy|0));
                    $69 = __THREW__; __THREW__ = 0;
                    $70 = $69&1;
                    if ($70) {
                     break;
                    }
                    __THREW__ = 0;
                    ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$L_24+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$L_24+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$L_24+8>>2]|0;HEAP32[$V_3$byval_copy+12>>2]=HEAP32[$L_24+12>>2]|0;
                    ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
                    invoke_viiii(229,($L_25|0),(0|0),($V_3$byval_copy|0),($L_44$byval_copy|0));
                    $71 = __THREW__; __THREW__ = 0;
                    $72 = $71&1;
                    if ($72) {
                     break;
                    }
                    ;HEAP32[$V_0+0>>2]=HEAP32[$L_25+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_25+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_25+8>>2]|0;
                    $73 = (($__this) + 24|0);
                    $74 = HEAP32[$73>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($74|0));
                    $75 = __THREW__; __THREW__ = 0;
                    $76 = $75&1;
                    if ($76) {
                     break;
                    }
                    $77 = (($74) + 20|0);
                    ;HEAP32[$77+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$77+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$77+8>>2]=HEAP32[$V_0+8>>2]|0;
                    $78 = HEAP32[$73>>2]|0;
                    $79 = HEAP32[2993912>>2]|0;
                    __THREW__ = 0;
                    $80 = (invoke_iii(1232,(0|0),($79|0))|0);
                    $81 = __THREW__; __THREW__ = 0;
                    $82 = $81&1;
                    if ($82) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($78|0));
                    $83 = __THREW__; __THREW__ = 0;
                    $84 = $83&1;
                    if ($84) {
                     break;
                    }
                    $85 = (($78) + 32|0);
                    $86 = $80&1;
                    HEAP8[$85>>0] = $86;
                    $87 = (($__this) + 16|0);
                    $88 = HEAP8[$87>>0]|0;
                    $89 = ($88<<24>>24)==(0);
                    if ($89) {
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                    __THREW__ = 0;
                    $90 = (Math_fround(+(invoke_fi(137,($V_0|0)))));
                    $91 = __THREW__; __THREW__ = 0;
                    $92 = $91&1;
                    if ($92) {
                     break;
                    }
                    $93 = !($90 <= Math_fround(0.00999999977648258209228));
                    if (!($93)) {
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                    __THREW__ = 0;
                    $94 = (invoke_ii(2522,($__this|0))|0);
                    $95 = __THREW__; __THREW__ = 0;
                    $96 = $95&1;
                    if ($96) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($94|0));
                    $97 = __THREW__; __THREW__ = 0;
                    $98 = $97&1;
                    if ($98) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vii(2130,($L_33|0),($94|0));
                    $99 = __THREW__; __THREW__ = 0;
                    $100 = $99&1;
                    if ($100) {
                     break;
                    }
                    $101 = (($__this) + 20|0);
                    $102 = Math_fround(HEAPF32[$101>>2]);
                    __THREW__ = 0;
                    $103 = (Math_fround(+(invoke_fi(149,(0|0)))));
                    $104 = __THREW__; __THREW__ = 0;
                    $105 = $104&1;
                    if ($105) {
                     break;
                    }
                    ;HEAP32[$3+0>>2]=HEAP32[$L_33+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$L_33+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$L_33+8>>2]|0;
                    ;HEAP32[$2+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$V_0+8>>2]|0;
                    __THREW__ = 0;
                    invoke_viii(2112,($data$i|0),(1293568|0),($__this|0));
                    $106 = __THREW__; __THREW__ = 0;
                    $107 = $106&1;
                    if ($107) {
                     break;
                    }
                    $108 = Math_fround($102 * $103);
                    $109 = (($data$i) + 4|0);
                    $110 = HEAP32[$109>>2]|0;
                    $111 = (($110) + 4|0);
                    $112 = HEAP32[$111>>2]|0;
                    $113 = HEAP32[$data$i>>2]|0;
                    __THREW__ = 0;
                    ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
                    ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;
                    invoke_viiiif($112|0,($L_37|0),($113|0),($V_3$byval_copy|0),($L_44$byval_copy|0),(+$108));
                    $114 = __THREW__; __THREW__ = 0;
                    $115 = $114&1;
                    if ($115) {
                     break;
                    }
                    ;HEAP32[$V_3+0>>2]=HEAP32[$L_37+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_37+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_37+8>>2]|0;
                    __THREW__ = 0;
                    $116 = (invoke_ii(2522,($__this|0))|0);
                    $117 = __THREW__; __THREW__ = 0;
                    $118 = $117&1;
                    if ($118) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($116|0));
                    $119 = __THREW__; __THREW__ = 0;
                    $120 = $119&1;
                    if ($120) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vii(2129,($L_39|0),($116|0));
                    $121 = __THREW__; __THREW__ = 0;
                    $122 = $121&1;
                    if ($122) {
                     break;
                    }
                    ;HEAP32[$1+0>>2]=HEAP32[$V_3+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$V_3+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$V_3+8>>2]|0;
                    ;HEAP32[$0+0>>2]=HEAP32[$L_39+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$L_39+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$L_39+8>>2]|0;
                    __THREW__ = 0;
                    invoke_viii(2112,($data$i9|0),(1293616|0),($__this|0));
                    $123 = __THREW__; __THREW__ = 0;
                    $124 = $123&1;
                    if ($124) {
                     break;
                    }
                    $125 = (($data$i9) + 4|0);
                    $126 = HEAP32[$125>>2]|0;
                    $127 = (($126) + 4|0);
                    $128 = HEAP32[$127>>2]|0;
                    $129 = HEAP32[$data$i9>>2]|0;
                    __THREW__ = 0;
                    ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;
                    ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
                    invoke_viiii($128|0,($L_40|0),($129|0),($V_3$byval_copy|0),($L_44$byval_copy|0));
                    $130 = __THREW__; __THREW__ = 0;
                    $131 = $130&1;
                    if ($131) {
                     break;
                    }
                    ;HEAP32[$V_3+0>>2]=HEAP32[$L_40+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_40+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_40+8>>2]|0;
                    __THREW__ = 0;
                    $132 = (invoke_ii(2522,($__this|0))|0);
                    $133 = __THREW__; __THREW__ = 0;
                    $134 = $133&1;
                    if ($134) {
                     break;
                    }
                    __THREW__ = 0;
                    $135 = (invoke_ii(2522,($__this|0))|0);
                    $136 = __THREW__; __THREW__ = 0;
                    $137 = $136&1;
                    if ($137) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($135|0));
                    $138 = __THREW__; __THREW__ = 0;
                    $139 = $138&1;
                    if ($139) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vii(2129,($L_43|0),($135|0));
                    $140 = __THREW__; __THREW__ = 0;
                    $141 = $140&1;
                    if ($141) {
                     break;
                    }
                    __THREW__ = 0;
                    ;HEAP32[$V_3$byval_copy+0>>2]=HEAP32[$V_3+0>>2]|0;HEAP32[$V_3$byval_copy+4>>2]=HEAP32[$V_3+4>>2]|0;HEAP32[$V_3$byval_copy+8>>2]=HEAP32[$V_3+8>>2]|0;
                    ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$L_43+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$L_43+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$L_43+8>>2]|0;
                    invoke_viiii(226,($L_44|0),(0|0),($V_3$byval_copy|0),($L_44$byval_copy|0));
                    $142 = __THREW__; __THREW__ = 0;
                    $143 = $142&1;
                    if ($143) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($132|0));
                    $144 = __THREW__; __THREW__ = 0;
                    $145 = $144&1;
                    if ($145) {
                     break;
                    }
                    __THREW__ = 0;
                    ;HEAP32[$L_44$byval_copy+0>>2]=HEAP32[$L_44+0>>2]|0;HEAP32[$L_44$byval_copy+4>>2]=HEAP32[$L_44+4>>2]|0;HEAP32[$L_44$byval_copy+8>>2]=HEAP32[$L_44+8>>2]|0;HEAP32[$L_44$byval_copy+12>>2]=HEAP32[$L_44+12>>2]|0;
                    invoke_vii(2134,($132|0),($L_44$byval_copy|0));
                    $146 = __THREW__; __THREW__ = 0;
                    $147 = $146&1;
                    if ($147) {
                     break;
                    }
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z81AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_ProjectOntoPlaneP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$v,$normal) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $v = $v|0;
 $normal = $normal|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $L_0$byval_copy = 0, $_stackTraceSentry = 0, $v$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $L_0$byval_copy = sp + 28|0;
 $v$byval_copy1 = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1293616);
 __THREW__ = 0;
 ;HEAP32[$v$byval_copy1+0>>2]=HEAP32[$v+0>>2]|0;HEAP32[$v$byval_copy1+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$v$byval_copy1+8>>2]=HEAP32[$v+8>>2]|0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$normal+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$normal+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$normal+8>>2]|0;
 invoke_viiii(219,($L_0|0),(0|0),($v$byval_copy1|0),($L_0$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$v$byval_copy1+0>>2]=HEAP32[$v+0>>2]|0;HEAP32[$v$byval_copy1+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$v$byval_copy1+8>>2]=HEAP32[$v+8>>2]|0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
 invoke_viiii(223,($agg$result|0),(0|0),($v$byval_copy1|0),($L_0$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z78AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_ConstantSlerpP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController31UnityEngine_UnityEngine_Vector3S1_f($agg$result,$__this,$from,$to,$angle) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $from = $from|0;
 $to = $to|0;
 $angle = Math_fround($angle);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $from$byval_copy1 = 0, $to$byval_copy2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $to$byval_copy2 = sp + 16|0;
 $from$byval_copy1 = sp;
 $_stackTraceSentry = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1293568);
 __THREW__ = 0;
 ;HEAP32[$from$byval_copy1+0>>2]=HEAP32[$from+0>>2]|0;HEAP32[$from$byval_copy1+4>>2]=HEAP32[$from+4>>2]|0;HEAP32[$from$byval_copy1+8>>2]=HEAP32[$from+8>>2]|0;
 ;HEAP32[$to$byval_copy2+0>>2]=HEAP32[$to+0>>2]|0;HEAP32[$to$byval_copy2+4>>2]=HEAP32[$to+4>>2]|0;HEAP32[$to$byval_copy2+8>>2]=HEAP32[$to+8>>2]|0;
 $0 = (Math_fround(+(invoke_fiii(9,(0|0),($from$byval_copy1|0),($to$byval_copy2|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 $3 = Math_fround($angle / $0);
 __THREW__ = 0;
 $4 = (Math_fround(+(invoke_fiff(3,(0|0),1.0,(+$3)))));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$from$byval_copy1+0>>2]=HEAP32[$from+0>>2]|0;HEAP32[$from$byval_copy1+4>>2]=HEAP32[$from+4>>2]|0;HEAP32[$from$byval_copy1+8>>2]=HEAP32[$from+8>>2]|0;
 ;HEAP32[$to$byval_copy2+0>>2]=HEAP32[$to+0>>2]|0;HEAP32[$to$byval_copy2+4>>2]=HEAP32[$to+4>>2]|0;HEAP32[$to$byval_copy2+8>>2]=HEAP32[$to+8>>2]|0;
 invoke_viiiif(2,($agg$result|0),(0|0),($from$byval_copy1|0),($to$byval_copy2|0),(+$4));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z69AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_MainP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1293664);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker3I37UnityEngine_UnityEngine_Vector3TraitsS0_S0_28mscorlib_System_SingleTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS3_S3_fES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 12|0;
 $0 = sp + 24|0;
 $1 = sp + 36|0;
 $2 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$4+8>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;
 FUNCTION_TABLE_viiiif[$func & 3]($ret,$obj,$$byval_copy,$$byval_copy1,$7);
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z93AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717112)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1292792)|0);
 $5 = HEAP32[((1292792 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z48UnityEngine_UnityEngine_RequireComponent_m__ctorP40UnityEngine_UnityEngine_RequireComponentP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717488)|0);
 $9 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(1293928)|0);
 __Z48UnityEngine_UnityEngine_AddComponentMenu_m__ctorP40UnityEngine_UnityEngine_AddComponentMenuP22mscorlib_System_String($8,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $8;
 STACKTOP = sp;return;
}
function __Z64AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m__ctorP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $L_10 = 0, $L_9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_9 = sp;
 $L_10 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294232);
 __THREW__ = 0;
 invoke_vi(3120,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($18|0);
  // unreachable;
 }
 $2 = (($__this) + 24|0);
 HEAPF32[$2>>2] = Math_fround(7.0);
 $3 = (($__this) + 28|0);
 HEAPF32[$3>>2] = Math_fround(3.0);
 $4 = (($__this) + 32|0);
 HEAPF32[$4>>2] = Math_fround(0.300000011920928955078);
 $5 = (($__this) + 36|0);
 HEAPF32[$5>>2] = Math_fround(15.0);
 $6 = (($__this) + 40|0);
 HEAPF32[$6>>2] = Math_fround(0.300000011920928955078);
 $7 = (($__this) + 44|0);
 HEAPF32[$7>>2] = Math_fround(0.20000000298023223877);
 $8 = (($__this) + 48|0);
 HEAPF32[$8>>2] = Math_fround(720.0);
 $9 = (($__this) + 52|0);
 HEAPF32[$9>>2] = Math_fround(0.75);
 $10 = (($__this) + 56|0);
 HEAPF32[$10>>2] = Math_fround(0.20000000298023223877);
 __THREW__ = 0;
 invoke_vii(2070,($L_9|0),(0|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($18|0);
  // unreachable;
 }
 $13 = (($__this) + 60|0);
 ;HEAP32[$13+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$L_9+8>>2]|0;
 __THREW__ = 0;
 invoke_vii(2070,($L_10|0),(0|0));
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($18|0);
  // unreachable;
 } else {
  $16 = (($__this) + 72|0);
  ;HEAP32[$16+0>>2]=HEAP32[$L_10+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$L_10+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$L_10+8>>2]|0;
  $17 = (($__this) + 100|0);
  HEAPF32[$17>>2] = Math_fround(1.0E+5);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z64AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_AwakeP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$phi7Z2D = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $L_21 = 0, $L_22 = 0, $L_22$byval_copy = 0, $L_24 = 0, $L_25 = 0, $L_28 = 0, $L_29 = 0, $L_32 = 0;
 var $V_1 = 0, $V_2 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $tmpcast$byval_copy = sp + 184|0;
 $L_22$byval_copy = sp + 172|0;
 $_stackTraceSentry = sp + 168|0;
 $V_1 = sp + 144|0;
 $V_2 = sp + 120|0;
 $0 = sp + 112|0;
 $L_21 = sp + 88|0;
 $L_22 = sp + 64|0;
 $L_24 = sp + 52|0;
 $L_25 = sp + 40|0;
 $L_28 = sp + 16|0;
 $L_29 = sp;
 $L_32 = sp + 76|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294280);
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;HEAP32[$V_1+16>>2]=0|0;HEAP32[$V_1+20>>2]=0|0;
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;HEAP32[$V_2+16>>2]=0|0;HEAP32[$V_2+20>>2]=0|0;
 __THREW__ = 0;
 invoke_v(314);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = (($__this) + 16|0);
   $4 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   $5 = (invoke_iii(1194,(0|0),($4|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    if (!($5)) {
     __THREW__ = 0;
     $10 = (invoke_ii(2633,(0|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_iii(1194,(0|0),($10|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     if ($13) {
      __THREW__ = 0;
      $16 = (invoke_ii(2633,(0|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($16|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      __THREW__ = 0;
      $21 = (invoke_ii(2522,($16|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      HEAP32[$3>>2] = $21;
     }
    }
    $24 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    $25 = (invoke_iii(1194,(0|0),($24|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     if (!($25)) {
      $28 = HEAP32[2993928>>2]|0;
      __THREW__ = 0;
      invoke_vii(2109,(0|0),($28|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(2101,($__this|0),0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
     }
     __THREW__ = 0;
     $33 = (invoke_ii(2522,($__this|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      $36 = (($__this) + 20|0);
      HEAP32[$36>>2] = $33;
      __THREW__ = 0;
      $37 = (invoke_iii(1194,(0|0),($33|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       if ($37) {
        $40 = HEAP32[$36>>2]|0;
        HEAP32[$0>>2] = 1299880;
        __THREW__ = 0;
        ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        $41 = (invoke_iii(772,(0|0),($tmpcast$byval_copy|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($40|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
        __THREW__ = 0;
        $46 = (invoke_iii(1189,($40|0),($41|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1299736|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        $51 = (invoke_iii(2733,($46|0),(1299736|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        $54 = (($__this) + 96|0);
        HEAP32[$54>>2] = $51;
        $55 = $51;
       } else {
        $$phi$trans$insert = (($__this) + 96|0);
        $$pre = HEAP32[$$phi$trans$insert>>2]|0;
        $55 = $$pre;
       }
       __THREW__ = 0;
       $56 = (invoke_iii(1194,(0|0),($55|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if (!($58)) {
        if ($56) {
         $59 = HEAP32[$36>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($59|0));
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          break;
         }
         __THREW__ = 0;
         $62 = (invoke_iii(2726,($59|0),(2882544|0))|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2839072|0))|0);
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          break;
         }
         __THREW__ = 0;
         $67 = (invoke_iii(2733,($62|0),(2839072|0))|0);
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($67|0));
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(2152,($L_21|0),($67|0));
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          break;
         }
         ;HEAP32[$V_1+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_21+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_21+12>>2]|0;HEAP32[$V_1+16>>2]=HEAP32[$L_21+16>>2]|0;HEAP32[$V_1+20>>2]=HEAP32[$L_21+20>>2]|0;
         __THREW__ = 0;
         invoke_vii(2082,($L_22|0),($V_1|0));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          break;
         }
         $76 = HEAP32[$36>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($76|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(2122,($L_24|0),($76|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break;
         }
         __THREW__ = 0;
         ;HEAP32[$L_22$byval_copy+0>>2]=HEAP32[$L_22+0>>2]|0;HEAP32[$L_22$byval_copy+4>>2]=HEAP32[$L_22+4>>2]|0;HEAP32[$L_22$byval_copy+8>>2]=HEAP32[$L_22+8>>2]|0;
         ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$L_24+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$L_24+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$L_24+8>>2]|0;
         invoke_viiii(223,($L_25|0),(0|0),($L_22$byval_copy|0),($tmpcast$byval_copy|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          break;
         }
         $83 = (($__this) + 72|0);
         ;HEAP32[$83+0>>2]=HEAP32[$L_25+0>>2]|0;HEAP32[$83+4>>2]=HEAP32[$L_25+4>>2]|0;HEAP32[$83+8>>2]=HEAP32[$L_25+8>>2]|0;
         $84 = (($__this) + 60|0);
         ;HEAP32[$84+0>>2]=HEAP32[$L_25+0>>2]|0;HEAP32[$84+4>>2]=HEAP32[$L_25+4>>2]|0;HEAP32[$84+8>>2]=HEAP32[$L_25+8>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($67|0));
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(2152,($L_28|0),($67|0));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          break;
         }
         ;HEAP32[$V_2+0>>2]=HEAP32[$L_28+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_28+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_28+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_28+12>>2]|0;HEAP32[$V_2+16>>2]=HEAP32[$L_28+16>>2]|0;HEAP32[$V_2+20>>2]=HEAP32[$L_28+20>>2]|0;
         __THREW__ = 0;
         invoke_vii(2090,($L_29|0),($V_2|0));
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          break;
         }
         $91 = (($L_29) + 4|0);
         $92 = Math_fround(HEAPF32[$91>>2]);
         $93 = HEAP32[$36>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($93|0));
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(2122,($L_32|0),($93|0));
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          break;
         }
         $98 = (($L_32) + 4|0);
         $99 = Math_fround(HEAPF32[$98>>2]);
         $100 = Math_fround($92 - $99);
         $101 = (($__this) + 64|0);
         HEAPF32[$101>>2] = $100;
         $$pre$phi7Z2D = $83;
        } else {
         $102 = HEAP32[2993936>>2]|0;
         __THREW__ = 0;
         invoke_vii(2109,(0|0),($102|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          break;
         }
         $$pre5 = (($__this) + 72|0);
         $$pre$phi7Z2D = $$pre5;
        }
        $105 = HEAP32[$36>>2]|0;
        __THREW__ = 0;
        ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$$pre$phi7Z2D+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$$pre$phi7Z2D+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$$pre$phi7Z2D+8>>2]|0;
        invoke_viiii(462,(1294328|0),($__this|0),($105|0),($tmpcast$byval_copy|0));
        $106 = __THREW__; __THREW__ = 0;
        $107 = $106&1;
        if (!($107)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __ZN18VirtActionInvoker2I17VoidPointerTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEP10MethodInfoPvS5_31UnityEngine_UnityEngine_Vector3($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, $p2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p2$byval_copy = sp + 8|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 ;HEAP32[$p2$byval_copy+0>>2]=HEAP32[$p2+0>>2]|0;HEAP32[$p2$byval_copy+4>>2]=HEAP32[$p2+4>>2]|0;HEAP32[$p2$byval_copy+8>>2]=HEAP32[$p2+8>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2$byval_copy);
 STACKTOP = sp;return;
}
function __Z73AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_DebugDrawStuffP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_1$byval_copy = 0;
 var $L_3 = 0, $L_5 = 0, $L_5$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_5$byval_copy = sp + 52|0;
 $L_1$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_1 = sp + 16|0;
 $L_3 = sp + 28|0;
 $L_5 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294376);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vii(2122,($L_1|0),($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($6|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vii(2122,($L_3|0),($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($__this) + 60|0);
     __THREW__ = 0;
     ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;
     ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$11+8>>2]|0;
     invoke_viiii(222,($L_5|0),(0|0),($L_1$byval_copy|0),($L_5$byval_copy|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
      ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;
      invoke_viii(773,(0|0),($L_1$byval_copy|0),($L_5$byval_copy|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z72AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_AngleDistanceP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraff($__this,$a,$b) {
 $__this = $__this|0;
 $a = Math_fround($a);
 $b = Math_fround($b);
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294424);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fiff(5,(0|0),(+$a),360.0))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fiff(5,(0|0),(+$b),360.0))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = Math_fround($3 - $0);
   $7 = (Math_fround(Math_abs((Math_fround($6)))));
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($7));
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return Math_fround(0);
}
function __Z64AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_ApplyP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($__this,$dummyTarget,$dummyCenter) {
 $__this = $__this|0;
 $dummyTarget = $dummyTarget|0;
 $dummyCenter = $dummyCenter|0;
 var $$byval_copy4 = 0, $$byval_copy5 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = Math_fround(0), $104 = Math_fround(0), $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = Math_fround(0), $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = Math_fround(0), $25 = 0;
 var $26 = Math_fround(0), $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = Math_fround(0), $63 = 0, $64 = Math_fround(0), $65 = Math_fround(0), $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = Math_fround(0), $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = Math_fround(0), $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $L_11 = 0, $L_14 = 0, $L_3 = 0, $L_5 = 0, $L_58 = 0, $L_68 = 0, $L_7 = 0, $L_72 = 0, $L_73 = 0, $L_74 = 0, $L_76 = 0, $L_77 = 0, $L_81 = 0, $L_9 = 0, $V_1 = 0, $V_3$0 = Math_fround(0), $V_4$0 = Math_fround(0), $V_4$1 = Math_fround(0), $V_7 = 0;
 var $_stackTraceSentry = 0, $data$i = 0, $or$cond = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy5 = sp + 288|0;
 $$byval_copy4 = sp + 272|0;
 $data$i = sp + 264|0;
 $0 = sp;
 $1 = sp + 16|0;
 $_stackTraceSentry = sp + 260|0;
 $V_1 = sp + 248|0;
 $V_7 = sp + 232|0;
 $L_3 = sp + 216|0;
 $L_5 = sp + 204|0;
 $L_7 = sp + 192|0;
 $L_9 = sp + 180|0;
 $L_11 = sp + 96|0;
 $L_14 = sp + 108|0;
 $L_58 = sp + 84|0;
 $L_68 = sp + 56|0;
 $2 = sp + 28|0;
 $L_72 = sp + 40|0;
 $L_73 = sp + 72|0;
 $L_74 = sp + 120|0;
 $L_76 = sp + 132|0;
 $L_77 = sp + 144|0;
 $L_81 = sp + 156|0;
 $3 = sp + 168|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294472);
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;
 ;HEAP32[$V_7+0>>2]=0|0;HEAP32[$V_7+4>>2]=0|0;HEAP32[$V_7+8>>2]=0|0;HEAP32[$V_7+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(315);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   $6 = (($__this) + 96|0);
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   $8 = (invoke_iii(1194,(0|0),($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $13 = (($__this) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     invoke_vii(2122,($L_3|0),($14|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = (($__this) + 72|0);
      __THREW__ = 0;
      ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$L_3+8>>2]|0;
      ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$19+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$19+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$19+8>>2]|0;
      invoke_viiii(222,($L_5|0),(0|0),($$byval_copy4|0),($$byval_copy5|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = Math_fround(HEAPF32[$L_5>>2]);
       $23 = (($L_5) + 4|0);
       $24 = Math_fround(HEAPF32[$23>>2]);
       $25 = (($L_5) + 8|0);
       $26 = Math_fround(HEAPF32[$25>>2]);
       $27 = HEAP32[$13>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($27|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vii(2122,($L_7|0),($27|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = (($__this) + 60|0);
         __THREW__ = 0;
         ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$L_7+8>>2]|0;
         ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$32+8>>2]|0;
         invoke_viiii(222,($L_9|0),(0|0),($$byval_copy4|0),($$byval_copy5|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          ;HEAP32[$V_1+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_9+8>>2]|0;
          $35 = HEAP32[$13>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($35|0));
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if (!($37)) {
           __THREW__ = 0;
           invoke_vii(2124,($L_11|0),($35|0));
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if (!($39)) {
            $40 = (($L_11) + 4|0);
            $41 = Math_fround(HEAPF32[$40>>2]);
            $42 = (($__this) + 16|0);
            $43 = HEAP32[$42>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($43|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             __THREW__ = 0;
             invoke_vii(2124,($L_14|0),($43|0));
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if (!($47)) {
              $48 = (($L_14) + 4|0);
              $49 = Math_fround(HEAPF32[$48>>2]);
              $50 = HEAP32[2994240>>2]|0;
              __THREW__ = 0;
              $51 = (invoke_iii(1232,(0|0),($50|0))|0);
              $52 = __THREW__; __THREW__ = 0;
              $53 = $52&1;
              if (!($53)) {
               $54 = (($__this) + 92|0);
               if ($51) {
                HEAP8[$54>>0] = 1;
                label = 19;
               } else {
                $$pre = HEAP8[$54>>0]|0;
                $phitmp = ($$pre<<24>>24)==(0);
                if ($phitmp) {
                 $68 = HEAP32[$6>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($68|0));
                 $69 = __THREW__; __THREW__ = 0;
                 $70 = $69&1;
                 if ($70) {
                  break;
                 }
                 __THREW__ = 0;
                 $71 = (Math_fround(+(invoke_fii(57,(1294520|0),($68|0)))));
                 $72 = __THREW__; __THREW__ = 0;
                 $73 = $72&1;
                 if ($73) {
                  break;
                 }
                 $74 = (($__this) + 56|0);
                 $75 = Math_fround(HEAPF32[$74>>2]);
                 $76 = !($71 >= $75);
                 $V_4$0 = $76 ? $49 : $41;
                 __THREW__ = 0;
                 $77 = (Math_fround(+(invoke_fiiff(1,(1294424|0),($__this|0),(+$49),(+$V_4$0)))));
                 $78 = __THREW__; __THREW__ = 0;
                 $79 = $78&1;
                 if ($79) {
                  break;
                 }
                 $80 = !($77 <= Math_fround(160.0));
                 do {
                  if ($80) {
                   $81 = HEAP32[$6>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($81|0));
                   $82 = __THREW__; __THREW__ = 0;
                   $83 = $82&1;
                   if ($83) {
                    break L1;
                   }
                   __THREW__ = 0;
                   $84 = (invoke_iii(2734,(1294568|0),($81|0))|0);
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break L1;
                   }
                   if (!($84)) {
                    $V_4$1 = $V_4$0;
                    break;
                   }
                   $87 = Math_fround($V_4$0 + Math_fround(180.0));
                   $V_4$1 = $87;
                  } else {
                   $V_4$1 = $V_4$0;
                  }
                 } while(0);
                 $88 = (($__this) + 88|0);
                 $89 = (($__this) + 32|0);
                 $90 = Math_fround(HEAPF32[$89>>2]);
                 $91 = (($__this) + 36|0);
                 $92 = Math_fround(HEAPF32[$91>>2]);
                 __THREW__ = 0;
                 $93 = (Math_fround(+(invoke_fiffiff(1,(0|0),(+$49),(+$V_4$1),($88|0),(+$90),(+$92)))));
                 $94 = __THREW__; __THREW__ = 0;
                 $95 = $94&1;
                 if ($95) {
                  break;
                 } else {
                  $V_3$0 = $93;
                 }
                } else {
                 label = 19;
                }
               }
               if ((label|0) == 19) {
                $55 = (($__this) + 92|0);
                __THREW__ = 0;
                $56 = (Math_fround(+(invoke_fiiff(1,(1294424|0),($__this|0),(+$49),(+$41)))));
                $57 = __THREW__; __THREW__ = 0;
                $58 = $57&1;
                if ($58) {
                 break;
                }
                $59 = !($56 >= Math_fround(3.0));
                if ($59) {
                 HEAP8[$55>>0] = 0;
                }
                $60 = (($__this) + 88|0);
                $61 = (($__this) + 44|0);
                $62 = Math_fround(HEAPF32[$61>>2]);
                $63 = (($__this) + 48|0);
                $64 = Math_fround(HEAPF32[$63>>2]);
                __THREW__ = 0;
                $65 = (Math_fround(+(invoke_fiffiff(1,(0|0),(+$49),(+$41),($60|0),(+$62),(+$64)))));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if ($67) {
                 break;
                } else {
                 $V_3$0 = $65;
                }
               }
               $96 = HEAP32[$6>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($96|0));
               $97 = __THREW__; __THREW__ = 0;
               $98 = $97&1;
               if (!($98)) {
                __THREW__ = 0;
                $99 = (invoke_iii(2734,(1294616|0),($96|0))|0);
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if (!($101)) {
                 $102 = (($__this) + 28|0);
                 $103 = Math_fround(HEAPF32[$102>>2]);
                 $104 = Math_fround($24 + $103);
                 $105 = (($__this) + 100|0);
                 do {
                  if ($99) {
                   $106 = Math_fround(HEAPF32[$105>>2]);
                   $107 = $104 < $106;
                   $108 = Math_fround($104 - $106);
                   $109 = !($108 <= Math_fround(5.0));
                   $or$cond = $107 | $109;
                   if (!($or$cond)) {
                    break;
                   }
                   HEAPF32[$105>>2] = $104;
                  } else {
                   HEAPF32[$105>>2] = $104;
                  }
                 } while(0);
                 $110 = HEAP32[$42>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($110|0));
                 $111 = __THREW__; __THREW__ = 0;
                 $112 = $111&1;
                 if (!($112)) {
                  __THREW__ = 0;
                  invoke_vii(2122,($L_58|0),($110|0));
                  $113 = __THREW__; __THREW__ = 0;
                  $114 = $113&1;
                  if ($114) {
                   break;
                  }
                  $115 = (($L_58) + 4|0);
                  $116 = Math_fround(HEAPF32[$115>>2]);
                  $117 = Math_fround(HEAPF32[$105>>2]);
                  $118 = (($__this) + 84|0);
                  $119 = (($__this) + 40|0);
                  $120 = Math_fround(HEAPF32[$119>>2]);
                  __THREW__ = 0;
                  $121 = (Math_fround(+(invoke_fiffif(1,(0|0),(+$116),(+$117),($118|0),(+$120)))));
                  $122 = __THREW__; __THREW__ = 0;
                  $123 = $122&1;
                  if ($123) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viifff(2,($L_68|0),(0|0),0.0,(+$V_3$0),0.0);
                  $124 = __THREW__; __THREW__ = 0;
                  $125 = $124&1;
                  if ($125) {
                   break;
                  }
                  ;HEAP32[$V_7+0>>2]=HEAP32[$L_68+0>>2]|0;HEAP32[$V_7+4>>2]=HEAP32[$L_68+4>>2]|0;HEAP32[$V_7+8>>2]=HEAP32[$L_68+8>>2]|0;HEAP32[$V_7+12>>2]=HEAP32[$L_68+12>>2]|0;
                  $126 = HEAP32[$42>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($126|0));
                  $127 = __THREW__; __THREW__ = 0;
                  $128 = $127&1;
                  if ($128) {
                   break;
                  }
                  HEAPF32[$2>>2] = $22;
                  $129 = (($2) + 4|0);
                  HEAPF32[$129>>2] = $24;
                  $130 = (($2) + 8|0);
                  HEAPF32[$130>>2] = $26;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$2+8>>2]|0;
                  invoke_vii(2123,($126|0),($$byval_copy5|0));
                  $131 = __THREW__; __THREW__ = 0;
                  $132 = $131&1;
                  if ($132) {
                   break;
                  }
                  $133 = HEAP32[$42>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($133|0));
                  $134 = __THREW__; __THREW__ = 0;
                  $135 = $134&1;
                  if ($135) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(2122,($L_72|0),($133|0));
                  $136 = __THREW__; __THREW__ = 0;
                  $137 = $136&1;
                  if ($137) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(2072,($L_73|0),(0|0));
                  $138 = __THREW__; __THREW__ = 0;
                  $139 = $138&1;
                  if ($139) {
                   break;
                  }
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$V_7+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$V_7+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$V_7+8>>2]|0;HEAP32[$$byval_copy4+12>>2]=HEAP32[$V_7+12>>2]|0;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$L_73+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$L_73+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$L_73+8>>2]|0;
                  invoke_viiii(229,($L_74|0),(0|0),($$byval_copy4|0),($$byval_copy5|0));
                  $140 = __THREW__; __THREW__ = 0;
                  $141 = $140&1;
                  if ($141) {
                   break;
                  }
                  $142 = (($__this) + 24|0);
                  $143 = Math_fround(HEAPF32[$142>>2]);
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$L_74+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$L_74+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$L_74+8>>2]|0;
                  invoke_viiif(2,($L_76|0),(0|0),($$byval_copy5|0),(+$143));
                  $144 = __THREW__; __THREW__ = 0;
                  $145 = $144&1;
                  if ($145) {
                   break;
                  }
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$L_72+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$L_72+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$L_72+8>>2]|0;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$L_76+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$L_76+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$L_76+8>>2]|0;
                  invoke_viiii(222,($L_77|0),(0|0),($$byval_copy4|0),($$byval_copy5|0));
                  $146 = __THREW__; __THREW__ = 0;
                  $147 = $146&1;
                  if ($147) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($133|0));
                  $148 = __THREW__; __THREW__ = 0;
                  $149 = $148&1;
                  if ($149) {
                   break;
                  }
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$L_77+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$L_77+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$L_77+8>>2]|0;
                  invoke_vii(2123,($133|0),($$byval_copy5|0));
                  $150 = __THREW__; __THREW__ = 0;
                  $151 = $150&1;
                  if ($151) {
                   break;
                  }
                  $152 = HEAP32[$42>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($152|0));
                  $153 = __THREW__; __THREW__ = 0;
                  $154 = $153&1;
                  if ($154) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(2122,($L_81|0),($152|0));
                  $155 = __THREW__; __THREW__ = 0;
                  $156 = $155&1;
                  if ($156) {
                   break;
                  }
                  $157 = Math_fround(HEAPF32[$L_81>>2]);
                  $158 = (($L_81) + 8|0);
                  $159 = Math_fround(HEAPF32[$158>>2]);
                  $160 = HEAP32[$42>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($160|0));
                  $161 = __THREW__; __THREW__ = 0;
                  $162 = $161&1;
                  if ($162) {
                   break;
                  }
                  HEAPF32[$3>>2] = $157;
                  $163 = (($3) + 4|0);
                  HEAPF32[$163>>2] = $121;
                  $164 = (($3) + 8|0);
                  HEAPF32[$164>>2] = $159;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$3+8>>2]|0;
                  invoke_vii(2123,($160|0),($$byval_copy5|0));
                  $165 = __THREW__; __THREW__ = 0;
                  $166 = $165&1;
                  if ($166) {
                   break;
                  }
                  ;HEAP32[$0+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$V_1+8>>2]|0;
                  HEAPF32[$1>>2] = $22;
                  $167 = (($1) + 4|0);
                  HEAPF32[$167>>2] = $24;
                  $168 = (($1) + 8|0);
                  HEAPF32[$168>>2] = $26;
                  __THREW__ = 0;
                  invoke_viii(2112,($data$i|0),(1294664|0),($__this|0));
                  $169 = __THREW__; __THREW__ = 0;
                  $170 = $169&1;
                  if ($170) {
                   break;
                  }
                  $171 = (($data$i) + 4|0);
                  $172 = HEAP32[$171>>2]|0;
                  $173 = (($172) + 4|0);
                  $174 = HEAP32[$173>>2]|0;
                  $175 = HEAP32[$data$i>>2]|0;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy4+8>>2]=HEAP32[$1+8>>2]|0;
                  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy5+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy5+8>>2]=HEAP32[$0+8>>2]|0;
                  invoke_viii($174|0,($175|0),($$byval_copy4|0),($$byval_copy5|0));
                  $176 = __THREW__; __THREW__ = 0;
                  $177 = $176&1;
                  if ($177) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __ZN16VirtFuncInvoker2I28mscorlib_System_SingleTraitsS0_S0_E6InvokeEP10MethodInfoPvff($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = Math_fround($p1);
 $p2 = Math_fround($p2);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fiff[$3 & 15]($4,$p1,$p2)));
 STACKTOP = sp;return (Math_fround($5));
}
function __ZN16VirtFuncInvoker0I28mscorlib_System_SingleTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fi[$3 & 255]($4)));
 STACKTOP = sp;return (Math_fround($5));
}
function __Z69AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_LateUpdateP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $L_1$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294712);
 __THREW__ = 0;
 $0 = (invoke_ii(2522,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vii(2070,($L_1|0),(0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   invoke_viiii(462,(1294472|0),($__this|0),($0|0),($L_1$byval_copy|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z62AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_CutP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($__this,$dummyTarget,$dummyCenter) {
 $__this = $__this|0;
 $dummyTarget = $dummyTarget|0;
 $dummyCenter = $dummyCenter|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_9 = 0, $L_9$byval_copy = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $L_9$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_9 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294328);
 $0 = (($__this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($__this) + 48|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($__this) + 44|0);
 $5 = Math_fround(HEAPF32[$4>>2]);
 HEAPF32[$2>>2] = Math_fround(1.0E+4);
 HEAPF32[$4>>2] = Math_fround(0.00100000004749745130539);
 HEAPF32[$0>>2] = Math_fround(0.00100000004749745130539);
 $6 = (($__this) + 92|0);
 HEAP8[$6>>0] = 1;
 __THREW__ = 0;
 $7 = (invoke_ii(2522,($__this|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  invoke_vii(2070,($L_9|0),(0|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   ;HEAP32[$L_9$byval_copy+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$L_9$byval_copy+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$L_9$byval_copy+8>>2]=HEAP32[$L_9+8>>2]|0;
   invoke_viiii(462,(1294472|0),($__this|0),($7|0),($L_9$byval_copy|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    HEAPF32[$0>>2] = $1;
    HEAPF32[$2>>2] = $3;
    HEAPF32[$4>>2] = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z72AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_SetUpRotationP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera31UnityEngine_UnityEngine_Vector3S1_($__this,$centerPos,$headPos) {
 $__this = $__this|0;
 $centerPos = $centerPos|0;
 $headPos = $headPos|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = Math_fround(0), $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = Math_fround(0), $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = Math_fround(0), $79 = 0, $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = Math_fround(0), $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $L_1 = 0, $L_11 = 0, $L_12 = 0, $L_14 = 0, $L_15 = 0, $L_17 = 0, $L_18 = 0, $L_2 = 0, $L_25 = 0, $L_26 = 0, $L_33 = 0, $L_34 = 0, $L_36 = 0, $L_38 = 0, $L_39 = 0;
 var $L_40 = 0, $L_55 = 0, $L_55$byval_copy = 0, $L_61 = 0, $L_62 = 0, $L_62$byval_copy = 0, $L_7 = 0, $L_8 = 0, $L_9 = 0, $V_2 = 0, $V_4 = 0, $V_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $L_62$byval_copy = sp + 416|0;
 $L_55$byval_copy = sp + 400|0;
 $_stackTraceSentry = sp + 392|0;
 $V_2 = sp + 376|0;
 $V_4 = sp + 352|0;
 $V_5 = sp + 328|0;
 $L_1 = sp + 312|0;
 $L_2 = sp + 300|0;
 $L_7 = sp + 288|0;
 $L_8 = sp + 272|0;
 $L_9 = sp + 256|0;
 $L_11 = sp + 244|0;
 $L_12 = sp + 232|0;
 $L_14 = sp + 220|0;
 $L_15 = sp + 208|0;
 $L_17 = sp + 96|0;
 $L_18 = sp;
 $L_25 = sp + 16|0;
 $L_26 = sp + 32|0;
 $L_33 = sp + 56|0;
 $L_34 = sp + 72|0;
 $L_36 = sp + 112|0;
 $L_38 = sp + 124|0;
 $L_39 = sp + 136|0;
 $L_40 = sp + 148|0;
 $L_55 = sp + 160|0;
 $L_61 = sp + 176|0;
 $L_62 = sp + 192|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294664);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;HEAP32[$V_4+12>>2]=0|0;HEAP32[$V_4+16>>2]=0|0;HEAP32[$V_4+20>>2]=0|0;
 ;HEAP32[$V_5+0>>2]=0|0;HEAP32[$V_5+4>>2]=0|0;HEAP32[$V_5+8>>2]=0|0;HEAP32[$V_5+12>>2]=0|0;HEAP32[$V_5+16>>2]=0|0;HEAP32[$V_5+20>>2]=0|0;
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   invoke_vii(2122,($L_1|0),($1|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    ;HEAP32[$L_55$byval_copy+0>>2]=HEAP32[$centerPos+0>>2]|0;HEAP32[$L_55$byval_copy+4>>2]=HEAP32[$centerPos+4>>2]|0;HEAP32[$L_55$byval_copy+8>>2]=HEAP32[$centerPos+8>>2]|0;
    ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
    invoke_viiii(223,($L_2|0),(0|0),($L_55$byval_copy|0),($L_62$byval_copy|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = Math_fround(HEAPF32[$L_2>>2]);
     $9 = (($L_2) + 8|0);
     $10 = Math_fround(HEAPF32[$9>>2]);
     ;HEAP32[$L_7+0>>2]=0|0;HEAP32[$L_7+4>>2]=0|0;HEAP32[$L_7+8>>2]=0|0;
     __THREW__ = 0;
     invoke_vifff(4,($L_7|0),(+$8),0.0,(+$10));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_7+8>>2]|0;
      invoke_viii(742,($L_8|0),(0|0),($L_62$byval_copy|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       ;HEAP32[$V_2+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_8+12>>2]|0;
       __THREW__ = 0;
       invoke_vii(2071,($L_9|0),(0|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        $17 = (($__this) + 24|0);
        $18 = Math_fround(HEAPF32[$17>>2]);
        __THREW__ = 0;
        ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_9+8>>2]|0;
        invoke_viiif(2,($L_11|0),(0|0),($L_62$byval_copy|0),(+$18));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         invoke_vii(2074,($L_12|0),(0|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          $23 = (($__this) + 28|0);
          $24 = Math_fround(HEAPF32[$23>>2]);
          __THREW__ = 0;
          ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;
          invoke_viiif(2,($L_14|0),(0|0),($L_62$byval_copy|0),(+$24));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           __THREW__ = 0;
           ;HEAP32[$L_55$byval_copy+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$L_55$byval_copy+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$L_55$byval_copy+8>>2]=HEAP32[$L_11+8>>2]|0;
           ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_14+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_14+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_14+8>>2]|0;
           invoke_viiii(222,($L_15|0),(0|0),($L_55$byval_copy|0),($L_62$byval_copy|0));
           $27 = __THREW__; __THREW__ = 0;
           $28 = $27&1;
           if (!($28)) {
            $29 = HEAP32[$0>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_15+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_15+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_15+8>>2]|0;
            invoke_viii(742,($L_17|0),(0|0),($L_62$byval_copy|0));
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if (!($31)) {
             __THREW__ = 0;
             ;HEAP32[$L_55$byval_copy+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_55$byval_copy+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_55$byval_copy+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$L_55$byval_copy+12>>2]=HEAP32[$V_2+12>>2]|0;
             ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_17+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_17+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_17+8>>2]|0;HEAP32[$L_62$byval_copy+12>>2]=HEAP32[$L_17+12>>2]|0;
             invoke_viiii(228,($L_18|0),(0|0),($L_55$byval_copy|0),($L_62$byval_copy|0));
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if (!($33)) {
              __THREW__ = 0;
              invoke_vi(3799,($29|0));
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               __THREW__ = 0;
               ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_18+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_18+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_18+8>>2]|0;HEAP32[$L_62$byval_copy+12>>2]=HEAP32[$L_18+12>>2]|0;
               invoke_vii(2134,($29|0),($L_62$byval_copy|0));
               $36 = __THREW__; __THREW__ = 0;
               $37 = $36&1;
               if (!($37)) {
                $38 = HEAP32[$0>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($38|0));
                $39 = __THREW__; __THREW__ = 0;
                $40 = $39&1;
                if (!($40)) {
                 __THREW__ = 0;
                 $41 = (invoke_ii(3472,($38|0))|0);
                 $42 = __THREW__; __THREW__ = 0;
                 $43 = $42&1;
                 if (!($43)) {
                  ;HEAP32[$L_25+0>>2]=0|0;HEAP32[$L_25+4>>2]=0|0;HEAP32[$L_25+8>>2]=0|0;
                  __THREW__ = 0;
                  invoke_vifff(4,($L_25|0),0.5,0.5,1.0);
                  $44 = __THREW__; __THREW__ = 0;
                  $45 = $44&1;
                  if (!($45)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($41|0));
                   $46 = __THREW__; __THREW__ = 0;
                   $47 = $46&1;
                   if (!($47)) {
                    __THREW__ = 0;
                    ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_25+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_25+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_25+8>>2]|0;
                    invoke_viii(771,($L_26|0),($41|0),($L_62$byval_copy|0));
                    $48 = __THREW__; __THREW__ = 0;
                    $49 = $48&1;
                    if (!($49)) {
                     ;HEAP32[$V_4+0>>2]=HEAP32[$L_26+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_26+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_26+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[$L_26+12>>2]|0;HEAP32[$V_4+16>>2]=HEAP32[$L_26+16>>2]|0;HEAP32[$V_4+20>>2]=HEAP32[$L_26+20>>2]|0;
                     $50 = HEAP32[$0>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($50|0));
                     $51 = __THREW__; __THREW__ = 0;
                     $52 = $51&1;
                     if ($52) {
                      break;
                     }
                     __THREW__ = 0;
                     $53 = (invoke_ii(3472,($50|0))|0);
                     $54 = __THREW__; __THREW__ = 0;
                     $55 = $54&1;
                     if ($55) {
                      break;
                     }
                     $56 = (($__this) + 52|0);
                     $57 = Math_fround(HEAPF32[$56>>2]);
                     ;HEAP32[$L_33+0>>2]=0|0;HEAP32[$L_33+4>>2]=0|0;HEAP32[$L_33+8>>2]=0|0;
                     __THREW__ = 0;
                     invoke_vifff(4,($L_33|0),0.5,(+$57),1.0);
                     $58 = __THREW__; __THREW__ = 0;
                     $59 = $58&1;
                     if ($59) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($53|0));
                     $60 = __THREW__; __THREW__ = 0;
                     $61 = $60&1;
                     if ($61) {
                      break;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_33+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_33+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_33+8>>2]|0;
                     invoke_viii(771,($L_34|0),($53|0),($L_62$byval_copy|0));
                     $62 = __THREW__; __THREW__ = 0;
                     $63 = $62&1;
                     if ($63) {
                      break;
                     }
                     ;HEAP32[$V_5+0>>2]=HEAP32[$L_34+0>>2]|0;HEAP32[$V_5+4>>2]=HEAP32[$L_34+4>>2]|0;HEAP32[$V_5+8>>2]=HEAP32[$L_34+8>>2]|0;HEAP32[$V_5+12>>2]=HEAP32[$L_34+12>>2]|0;HEAP32[$V_5+16>>2]=HEAP32[$L_34+16>>2]|0;HEAP32[$V_5+20>>2]=HEAP32[$L_34+20>>2]|0;
                     $64 = Math_fround(HEAPF32[$17>>2]);
                     __THREW__ = 0;
                     invoke_viif(26,($L_36|0),($V_4|0),(+$64));
                     $65 = __THREW__; __THREW__ = 0;
                     $66 = $65&1;
                     if ($66) {
                      break;
                     }
                     $67 = (($L_36) + 4|0);
                     $68 = Math_fround(HEAPF32[$67>>2]);
                     $69 = Math_fround(HEAPF32[$17>>2]);
                     __THREW__ = 0;
                     invoke_viif(26,($L_38|0),($V_5|0),(+$69));
                     $70 = __THREW__; __THREW__ = 0;
                     $71 = $70&1;
                     if ($71) {
                      break;
                     }
                     $72 = (($L_38) + 4|0);
                     $73 = Math_fround(HEAPF32[$72>>2]);
                     __THREW__ = 0;
                     invoke_vii(2095,($L_39|0),($V_4|0));
                     $74 = __THREW__; __THREW__ = 0;
                     $75 = $74&1;
                     if ($75) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(2095,($L_40|0),($V_5|0));
                     $76 = __THREW__; __THREW__ = 0;
                     $77 = $76&1;
                     if ($77) {
                      break;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_55$byval_copy+0>>2]=HEAP32[$L_39+0>>2]|0;HEAP32[$L_55$byval_copy+4>>2]=HEAP32[$L_39+4>>2]|0;HEAP32[$L_55$byval_copy+8>>2]=HEAP32[$L_39+8>>2]|0;
                     ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_40+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_40+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_40+8>>2]|0;
                     $78 = (Math_fround(+(invoke_fiii(9,(0|0),($L_55$byval_copy|0),($L_62$byval_copy|0)))));
                     $79 = __THREW__; __THREW__ = 0;
                     $80 = $79&1;
                     if ($80) {
                      break;
                     }
                     $81 = Math_fround($68 - $73);
                     $82 = Math_fround($78 / $81);
                     $83 = (($centerPos) + 4|0);
                     $84 = Math_fround(HEAPF32[$83>>2]);
                     $85 = Math_fround($68 - $84);
                     $86 = Math_fround($82 * $85);
                     $87 = !($86 >= $78);
                     if ($87) {
                      __ZN16StackTraceSentryD2Ev(0);
                      STACKTOP = sp;return;
                     }
                     $90 = Math_fround($86 - $78);
                     $91 = HEAP32[$0>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($91|0));
                     $92 = __THREW__; __THREW__ = 0;
                     $93 = $92&1;
                     if ($93) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(2133,($L_55|0),($91|0));
                     $94 = __THREW__; __THREW__ = 0;
                     $95 = $94&1;
                     if ($95) {
                      break;
                     }
                     $96 = Math_fround(-$90);
                     __THREW__ = 0;
                     invoke_viifff(2,($L_61|0),(0|0),(+$96),0.0,0.0);
                     $97 = __THREW__; __THREW__ = 0;
                     $98 = $97&1;
                     if ($98) {
                      break;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_55$byval_copy+0>>2]=HEAP32[$L_55+0>>2]|0;HEAP32[$L_55$byval_copy+4>>2]=HEAP32[$L_55+4>>2]|0;HEAP32[$L_55$byval_copy+8>>2]=HEAP32[$L_55+8>>2]|0;HEAP32[$L_55$byval_copy+12>>2]=HEAP32[$L_55+12>>2]|0;
                     ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_61+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_61+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_61+8>>2]|0;HEAP32[$L_62$byval_copy+12>>2]=HEAP32[$L_61+12>>2]|0;
                     invoke_viiii(228,($L_62|0),(0|0),($L_55$byval_copy|0),($L_62$byval_copy|0));
                     $99 = __THREW__; __THREW__ = 0;
                     $100 = $99&1;
                     if ($100) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($91|0));
                     $101 = __THREW__; __THREW__ = 0;
                     $102 = $101&1;
                     if ($102) {
                      break;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_62$byval_copy+0>>2]=HEAP32[$L_62+0>>2]|0;HEAP32[$L_62$byval_copy+4>>2]=HEAP32[$L_62+4>>2]|0;HEAP32[$L_62$byval_copy+8>>2]=HEAP32[$L_62+8>>2]|0;HEAP32[$L_62$byval_copy+12>>2]=HEAP32[$L_62+12>>2]|0;
                     invoke_vii(2134,($91|0),($L_62$byval_copy|0));
                     $103 = __THREW__; __THREW__ = 0;
                     $104 = $103&1;
                     if ($104) {
                      break;
                     }
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $88 = ___cxa_find_matching_catch()|0;
 $89 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($88|0);
 // unreachable;
}
function __ZL81UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Camera_TP33UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z81UnityEngine_UnityEngine_Component_m_GetComponent_mscorlib_System_Object_T_gsharedP33UnityEngine_UnityEngine_ComponentPPv($__this,2882552)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z74AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_GetCenterOffsetP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294760);
 $0 = (($__this) + 72|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z63AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_MainP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294808);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I28mscorlib_System_SingleTraitsS0_S0_E6InvokeEPFfPvffES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (Math_fround(FUNCTION_TABLE_fiff[$func & 15]($obj,$1,$4)));
 HEAPF32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFvPvS3_31UnityEngine_UnityEngine_Vector3ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I37UnityEngine_UnityEngine_Vector3TraitsS0_E6InvokeEPFvPv31UnityEngine_UnityEngine_Vector3S3_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 24|0;
 $$byval_copy = sp;
 $0 = sp + 12|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$$byval_copy,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z68AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m__ctorP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_18 = 0, $L_21 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_18 = sp;
 $L_21 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1296640);
 __THREW__ = 0;
 invoke_vi(3120,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($29|0);
  // unreachable;
 }
 $2 = (($__this) + 32|0);
 HEAPF32[$2>>2] = Math_fround(0.75);
 $3 = (($__this) + 36|0);
 HEAPF32[$3>>2] = Math_fround(1.0);
 $4 = (($__this) + 40|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($__this) + 44|0);
 HEAPF32[$5>>2] = Math_fround(1.14999997615814208984);
 $6 = (($__this) + 48|0);
 HEAPF32[$6>>2] = Math_fround(1.0);
 $7 = (($__this) + 60|0);
 HEAPF32[$7>>2] = Math_fround(2.0);
 $8 = (($__this) + 64|0);
 HEAPF32[$8>>2] = Math_fround(4.0);
 $9 = (($__this) + 68|0);
 HEAPF32[$9>>2] = Math_fround(6.0);
 $10 = (($__this) + 72|0);
 HEAPF32[$10>>2] = Math_fround(3.0);
 $11 = (($__this) + 76|0);
 HEAPF32[$11>>2] = Math_fround(0.5);
 $12 = (($__this) + 80|0);
 HEAPF32[$12>>2] = Math_fround(20.0);
 $13 = (($__this) + 84|0);
 HEAPF32[$13>>2] = Math_fround(10.0);
 $14 = (($__this) + 88|0);
 HEAPF32[$14>>2] = Math_fround(500.0);
 $15 = (($__this) + 92|0);
 HEAPF32[$15>>2] = Math_fround(3.0);
 $16 = (($__this) + 96|0);
 HEAP8[$16>>0] = 1;
 $17 = (($__this) + 100|0);
 HEAPF32[$17>>2] = Math_fround(0.0500000007450580596924);
 $18 = (($__this) + 104|0);
 HEAPF32[$18>>2] = Math_fround(0.150000005960464477539);
 $19 = (($__this) + 108|0);
 HEAPF32[$19>>2] = Math_fround(0.25);
 __THREW__ = 0;
 invoke_vii(2070,($L_18|0),(0|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($29|0);
  // unreachable;
 }
 $22 = (($__this) + 116|0);
 ;HEAP32[$22+0>>2]=HEAP32[$L_18+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$L_18+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$L_18+8>>2]|0;
 $23 = (($__this) + 148|0);
 HEAPF32[$23>>2] = Math_fround(-10.0);
 $24 = (($__this) + 152|0);
 HEAPF32[$24>>2] = Math_fround(-1.0);
 __THREW__ = 0;
 invoke_vii(2070,($L_21|0),(0|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $29 = ___cxa_find_matching_catch()|0;
  $30 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($29|0);
  // unreachable;
 } else {
  $27 = (($__this) + 160|0);
  ;HEAP32[$27+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$27+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$27+8>>2]=HEAP32[$L_21+8>>2]|0;
  $28 = (($__this) + 176|0);
  HEAP8[$28>>0] = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z68AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_AwakeP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 $L_2 = sp + 16|0;
 $0 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1296688);
 __THREW__ = 0;
 invoke_v(316);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2522,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vii(2071,($L_1|0),(0|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
      invoke_viii(778,($L_2|0),($3|0),($$byval_copy|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($__this) + 116|0);
       ;HEAP32[$12+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$L_2+8>>2]|0;
       HEAP32[$0>>2] = 1299976;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       $13 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        $16 = (invoke_iii(1189,($__this|0),($13|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2846960|0))|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if (!($20)) {
          __THREW__ = 0;
          $21 = (invoke_iii(2733,($16|0),(2846960|0))|0);
          $22 = __THREW__; __THREW__ = 0;
          $23 = $22&1;
          if (!($23)) {
           $24 = (($__this) + 52|0);
           HEAP32[$24>>2] = $21;
           __THREW__ = 0;
           $25 = (invoke_iii(1194,(0|0),($21|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            if (!($25)) {
             $30 = HEAP32[2994272>>2]|0;
             __THREW__ = 0;
             invoke_vii(2109,(0|0),($30|0));
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if ($32) {
              break;
             }
            }
            $33 = (($__this) + 16|0);
            $34 = HEAP32[$33>>2]|0;
            __THREW__ = 0;
            $35 = (invoke_iii(1194,(0|0),($34|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if (!($37)) {
             if (!($35)) {
              HEAP32[$24>>2] = 0;
              $38 = HEAP32[2994280>>2]|0;
              __THREW__ = 0;
              invoke_vii(2109,(0|0),($38|0));
              $39 = __THREW__; __THREW__ = 0;
              $40 = $39&1;
              if ($40) {
               break;
              }
             }
             $41 = (($__this) + 20|0);
             $42 = HEAP32[$41>>2]|0;
             __THREW__ = 0;
             $43 = (invoke_iii(1194,(0|0),($42|0))|0);
             $44 = __THREW__; __THREW__ = 0;
             $45 = $44&1;
             if (!($45)) {
              if (!($43)) {
               HEAP32[$24>>2] = 0;
               $46 = HEAP32[2994288>>2]|0;
               __THREW__ = 0;
               invoke_vii(2109,(0|0),($46|0));
               $47 = __THREW__; __THREW__ = 0;
               $48 = $47&1;
               if ($48) {
                break;
               }
              }
              $49 = (($__this) + 24|0);
              $50 = HEAP32[$49>>2]|0;
              __THREW__ = 0;
              $51 = (invoke_iii(1194,(0|0),($50|0))|0);
              $52 = __THREW__; __THREW__ = 0;
              $53 = $52&1;
              if (!($53)) {
               if (!($51)) {
                HEAP32[$24>>2] = 0;
                $54 = HEAP32[2994296>>2]|0;
                __THREW__ = 0;
                invoke_vii(2109,(0|0),($54|0));
                $55 = __THREW__; __THREW__ = 0;
                $56 = $55&1;
                if ($56) {
                 break;
                }
               }
               $57 = (($__this) + 28|0);
               $58 = HEAP32[$57>>2]|0;
               __THREW__ = 0;
               $59 = (invoke_iii(1194,(0|0),($58|0))|0);
               $60 = __THREW__; __THREW__ = 0;
               $61 = $60&1;
               if (!($61)) {
                if ($59) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                $62 = (($__this) + 96|0);
                $63 = HEAP8[$62>>0]|0;
                $64 = ($63<<24>>24)==(0);
                if ($64) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                HEAP32[$24>>2] = 0;
                $65 = HEAP32[2994304>>2]|0;
                __THREW__ = 0;
                invoke_vii(2109,(0|0),($65|0));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if ($67) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
}
function __Z94AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_UpdateSmoothedMovementDirectionP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $$ = Math_fround(0), $$2 = 0, $$not = 0, $$pn = Math_fround(0), $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = Math_fround(0), $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = Math_fround(0), $113 = Math_fround(0), $114 = 0, $115 = Math_fround(0), $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = Math_fround(0), $123 = Math_fround(0), $124 = 0, $125 = 0, $126 = 0, $127 = Math_fround(0), $128 = Math_fround(0), $129 = 0;
 var $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = Math_fround(0), $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0, $27 = 0;
 var $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0), $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = Math_fround(0), $57 = 0, $58 = 0, $59 = Math_fround(0), $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = Math_fround(0), $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0);
 var $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = Math_fround(0), $97 = 0, $98 = 0, $99 = 0, $L_13 = 0;
 var $L_28 = 0, $L_29 = 0, $L_3 = 0, $L_30 = 0, $L_37 = 0, $L_4 = 0, $L_43 = 0, $L_44 = 0, $L_52 = 0, $L_54 = 0, $L_7 = 0, $L_90 = 0, $L_90$byval_copy = 0, $L_91 = 0, $L_93 = 0, $L_95 = 0, $L_95$byval_copy = 0, $L_96 = 0, $V_2 = 0, $V_3 = 0;
 var $V_7 = 0, $V_9$0 = Math_fround(0), $_stackTraceSentry = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $L_95$byval_copy = sp + 256|0;
 $L_90$byval_copy = sp + 244|0;
 $_stackTraceSentry = sp + 240|0;
 $V_2 = sp + 228|0;
 $V_3 = sp + 216|0;
 $V_7 = sp + 204|0;
 $L_3 = sp + 192|0;
 $L_4 = sp + 180|0;
 $L_7 = sp + 168|0;
 $L_13 = sp + 156|0;
 $L_28 = sp + 144|0;
 $L_29 = sp + 132|0;
 $L_30 = sp + 48|0;
 $L_37 = sp;
 $L_43 = sp + 12|0;
 $L_44 = sp + 24|0;
 $L_52 = sp + 36|0;
 $L_54 = sp + 60|0;
 $L_90 = sp + 72|0;
 $L_91 = sp + 84|0;
 $L_93 = sp + 96|0;
 $L_95 = sp + 108|0;
 $L_96 = sp + 120|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1296736);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;
 ;HEAP32[$V_7+0>>2]=0|0;HEAP32[$V_7+4>>2]=0|0;HEAP32[$V_7+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(317);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(2633,(0|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_ii(2522,($2|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2734,(1296784|0),($__this|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vii(2071,($L_3|0),(0|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        __THREW__ = 0;
        invoke_vi(3799,($7|0));
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         __THREW__ = 0;
         ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;
         invoke_viii(778,($L_4|0),($7|0),($L_95$byval_copy|0));
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if (!($18)) {
          ;HEAP32[$V_2+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_4+8>>2]|0;
          $19 = (($V_2) + 4|0);
          HEAPF32[$19>>2] = Math_fround(0.0);
          __THREW__ = 0;
          invoke_vii(2069,($L_7|0),($V_2|0));
          $20 = __THREW__; __THREW__ = 0;
          $21 = $20&1;
          if (!($21)) {
           ;HEAP32[$V_2+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_7+8>>2]|0;
           $22 = (($V_2) + 8|0);
           $23 = Math_fround(HEAPF32[$22>>2]);
           $24 = Math_fround(HEAPF32[$V_2>>2]);
           $25 = Math_fround(-$24);
           ;HEAP32[$L_13+0>>2]=0|0;HEAP32[$L_13+4>>2]=0|0;HEAP32[$L_13+8>>2]=0|0;
           __THREW__ = 0;
           invoke_vifff(4,($L_13|0),(+$23),0.0,(+$25));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            ;HEAP32[$V_3+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_13+8>>2]|0;
            $28 = HEAP32[2994976>>2]|0;
            __THREW__ = 0;
            $29 = (Math_fround(+(invoke_fii(42,(0|0),($28|0)))));
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if (!($31)) {
             $32 = HEAP32[2994984>>2]|0;
             __THREW__ = 0;
             $33 = (Math_fround(+(invoke_fii(42,(0|0),($32|0)))));
             $34 = __THREW__; __THREW__ = 0;
             $35 = $34&1;
             if (!($35)) {
              $36 = !($29 >= Math_fround(-0.20000000298023223877));
              $37 = (($__this) + 142|0);
              $$2 = $36&1;
              HEAP8[$37>>0] = $$2;
              $38 = (($__this) + 143|0);
              $39 = HEAP8[$38>>0]|0;
              $40 = (Math_fround(Math_abs((Math_fround($33)))));
              $41 = $40 > Math_fround(0.100000001490116119385);
              if ($41) {
               $$sink = 1;
              } else {
               $44 = (Math_fround(Math_abs((Math_fround($29)))));
               $45 = $44 > Math_fround(0.100000001490116119385);
               $phitmp = $45&1;
               $$sink = $phitmp;
              }
              __THREW__ = 0;
              invoke_vi(3799,($__this|0));
              $46 = __THREW__; __THREW__ = 0;
              $47 = $46&1;
              if (!($47)) {
               HEAP8[$38>>0] = $$sink;
               __THREW__ = 0;
               ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$V_3+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$V_3+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$V_3+8>>2]|0;
               invoke_viifi(3,($L_28|0),(0|0),(+$33),($L_95$byval_copy|0));
               $48 = __THREW__; __THREW__ = 0;
               $49 = $48&1;
               if (!($49)) {
                __THREW__ = 0;
                ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$V_2+8>>2]|0;
                invoke_viifi(3,($L_29|0),(0|0),(+$29),($L_95$byval_copy|0));
                $50 = __THREW__; __THREW__ = 0;
                $51 = $50&1;
                if (!($51)) {
                 __THREW__ = 0;
                 ;HEAP32[$L_90$byval_copy+0>>2]=HEAP32[$L_28+0>>2]|0;HEAP32[$L_90$byval_copy+4>>2]=HEAP32[$L_28+4>>2]|0;HEAP32[$L_90$byval_copy+8>>2]=HEAP32[$L_28+8>>2]|0;
                 ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$L_29+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$L_29+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$L_29+8>>2]|0;
                 invoke_viiii(222,($L_30|0),(0|0),($L_90$byval_copy|0),($L_95$byval_copy|0));
                 $52 = __THREW__; __THREW__ = 0;
                 $53 = $52&1;
                 if (!($53)) {
                  ;HEAP32[$V_7+0>>2]=HEAP32[$L_30+0>>2]|0;HEAP32[$V_7+4>>2]=HEAP32[$L_30+4>>2]|0;HEAP32[$V_7+8>>2]=HEAP32[$L_30+8>>2]|0;
                  if (!($10)) {
                   $134 = (($__this) + 140|0);
                   $135 = HEAP8[$134>>0]|0;
                   $136 = ($135<<24>>24)==(0);
                   if (!($136)) {
                    $137 = (($__this) + 112|0);
                    HEAPF32[$137>>2] = Math_fround(0.0);
                   }
                   $138 = HEAP8[$38>>0]|0;
                   $139 = ($138<<24>>24)==(0);
                   if ($139) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   $140 = (($__this) + 160|0);
                   ;HEAP32[$L_90+0>>2]=HEAP32[$140+0>>2]|0;HEAP32[$L_90+4>>2]=HEAP32[$140+4>>2]|0;HEAP32[$L_90+8>>2]=HEAP32[$140+8>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(2069,($L_91|0),($V_7|0));
                   $141 = __THREW__; __THREW__ = 0;
                   $142 = $141&1;
                   if ($142) {
                    break;
                   }
                   __THREW__ = 0;
                   $143 = (Math_fround(+(invoke_fi(149,(0|0)))));
                   $144 = __THREW__; __THREW__ = 0;
                   $145 = $144&1;
                   if ($145) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$L_91+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$L_91+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$L_91+8>>2]|0;
                   invoke_viiif(2,($L_93|0),(0|0),($L_95$byval_copy|0),(+$143));
                   $146 = __THREW__; __THREW__ = 0;
                   $147 = $146&1;
                   if ($147) {
                    break;
                   }
                   $148 = (($__this) + 72|0);
                   $149 = Math_fround(HEAPF32[$148>>2]);
                   __THREW__ = 0;
                   ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$L_93+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$L_93+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$L_93+8>>2]|0;
                   invoke_viiif(2,($L_95|0),(0|0),($L_95$byval_copy|0),(+$149));
                   $150 = __THREW__; __THREW__ = 0;
                   $151 = $150&1;
                   if ($151) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_90$byval_copy+0>>2]=HEAP32[$L_90+0>>2]|0;HEAP32[$L_90$byval_copy+4>>2]=HEAP32[$L_90+4>>2]|0;HEAP32[$L_90$byval_copy+8>>2]=HEAP32[$L_90+8>>2]|0;
                   ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$L_95+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$L_95+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$L_95+8>>2]|0;
                   invoke_viiii(222,($L_96|0),(0|0),($L_90$byval_copy|0),($L_95$byval_copy|0));
                   $152 = __THREW__; __THREW__ = 0;
                   $153 = $152&1;
                   if ($153) {
                    break;
                   }
                   ;HEAP32[$140+0>>2]=HEAP32[$L_96+0>>2]|0;HEAP32[$140+4>>2]=HEAP32[$L_96+4>>2]|0;HEAP32[$140+8>>2]=HEAP32[$L_96+8>>2]|0;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                  $54 = (($__this) + 112|0);
                  $55 = Math_fround(HEAPF32[$54>>2]);
                  __THREW__ = 0;
                  $56 = (Math_fround(+(invoke_fi(149,(0|0)))));
                  $57 = __THREW__; __THREW__ = 0;
                  $58 = $57&1;
                  if (!($58)) {
                   $59 = Math_fround($55 + $56);
                   $60 = HEAP8[$38>>0]|0;
                   $61 = ($60<<24>>24)==($39<<24>>24);
                   $$ = $61 ? $59 : Math_fround(0.0);
                   HEAPF32[$54>>2] = $$;
                   __THREW__ = 0;
                   invoke_vii(2070,($L_37|0),(0|0));
                   $62 = __THREW__; __THREW__ = 0;
                   $63 = $62&1;
                   if ($63) {
                    break;
                   }
                   __THREW__ = 0;
                   ;HEAP32[$L_90$byval_copy+0>>2]=HEAP32[$V_7+0>>2]|0;HEAP32[$L_90$byval_copy+4>>2]=HEAP32[$V_7+4>>2]|0;HEAP32[$L_90$byval_copy+8>>2]=HEAP32[$V_7+8>>2]|0;
                   ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$L_37+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$L_37+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$L_37+8>>2]|0;
                   $64 = (invoke_iiii(1353,(0|0),($L_90$byval_copy|0),($L_95$byval_copy|0))|0);
                   $65 = __THREW__; __THREW__ = 0;
                   $66 = $65&1;
                   if ($66) {
                    break;
                   }
                   do {
                    if ($64) {
                     $67 = (($__this) + 132|0);
                     $68 = Math_fround(HEAPF32[$67>>2]);
                     $69 = (($__this) + 60|0);
                     $70 = Math_fround(HEAPF32[$69>>2]);
                     $71 = Math_fround($70 * Math_fround(0.899999976158142089843));
                     $$not = !($68 >= $71);
                     if ($$not) {
                      __THREW__ = 0;
                      invoke_vii(2069,($L_43|0),($V_7|0));
                      $72 = __THREW__; __THREW__ = 0;
                      $73 = $72&1;
                      if ($73) {
                       break L1;
                      }
                      $74 = (($__this) + 116|0);
                      ;HEAP32[$74+0>>2]=HEAP32[$L_43+0>>2]|0;HEAP32[$74+4>>2]=HEAP32[$L_43+4>>2]|0;HEAP32[$74+8>>2]=HEAP32[$L_43+8>>2]|0;
                      break;
                     }
                     $75 = (($__this) + 116|0);
                     ;HEAP32[$L_44+0>>2]=HEAP32[$75+0>>2]|0;HEAP32[$L_44+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$L_44+8>>2]=HEAP32[$75+8>>2]|0;
                     $76 = (($__this) + 88|0);
                     $77 = Math_fround(HEAPF32[$76>>2]);
                     __THREW__ = 0;
                     $78 = (Math_fround(+(invoke_fi(149,(0|0)))));
                     $79 = __THREW__; __THREW__ = 0;
                     $80 = $79&1;
                     if ($80) {
                      break L1;
                     }
                     $81 = Math_fround($77 * Math_fround(0.0174532923847436904907));
                     $82 = Math_fround($81 * $78);
                     __THREW__ = 0;
                     ;HEAP32[$L_90$byval_copy+0>>2]=HEAP32[$L_44+0>>2]|0;HEAP32[$L_90$byval_copy+4>>2]=HEAP32[$L_44+4>>2]|0;HEAP32[$L_90$byval_copy+8>>2]=HEAP32[$L_44+8>>2]|0;
                     ;HEAP32[$L_95$byval_copy+0>>2]=HEAP32[$V_7+0>>2]|0;HEAP32[$L_95$byval_copy+4>>2]=HEAP32[$V_7+4>>2]|0;HEAP32[$L_95$byval_copy+8>>2]=HEAP32[$V_7+8>>2]|0;
                     invoke_viiiiff(1,($L_52|0),(0|0),($L_90$byval_copy|0),($L_95$byval_copy|0),(+$82),1000.0);
                     $83 = __THREW__; __THREW__ = 0;
                     $84 = $83&1;
                     if ($84) {
                      break L1;
                     }
                     ;HEAP32[$75+0>>2]=HEAP32[$L_52+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$L_52+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$L_52+8>>2]|0;
                     __THREW__ = 0;
                     invoke_vii(2069,($L_54|0),($75|0));
                     $85 = __THREW__; __THREW__ = 0;
                     $86 = $85&1;
                     if ($86) {
                      break L1;
                     }
                     ;HEAP32[$75+0>>2]=HEAP32[$L_54+0>>2]|0;HEAP32[$75+4>>2]=HEAP32[$L_54+4>>2]|0;HEAP32[$75+8>>2]=HEAP32[$L_54+8>>2]|0;
                    }
                   } while(0);
                   $87 = (($__this) + 84|0);
                   $88 = Math_fround(HEAPF32[$87>>2]);
                   __THREW__ = 0;
                   $89 = (Math_fround(+(invoke_fi(149,(0|0)))));
                   $90 = __THREW__; __THREW__ = 0;
                   $91 = $90&1;
                   if ($91) {
                    break;
                   }
                   $92 = Math_fround($88 * $89);
                   __THREW__ = 0;
                   $93 = (Math_fround(+(invoke_fi(136,($V_7|0)))));
                   $94 = __THREW__; __THREW__ = 0;
                   $95 = $94&1;
                   if ($95) {
                    break;
                   }
                   __THREW__ = 0;
                   $96 = (Math_fround(+(invoke_fiff(3,(0|0),(+$93),1.0))));
                   $97 = __THREW__; __THREW__ = 0;
                   $98 = $97&1;
                   if ($98) {
                    break;
                   }
                   $99 = (($__this) + 56|0);
                   HEAP32[$99>>2] = 0;
                   __THREW__ = 0;
                   $100 = (invoke_iii(1234,(0|0),304)|0);
                   $101 = __THREW__; __THREW__ = 0;
                   $102 = $101&1;
                   if ($102) {
                    break;
                   }
                   do {
                    if ($100) {
                     label = 39;
                    } else {
                     __THREW__ = 0;
                     $103 = (invoke_iii(1234,(0|0),303)|0);
                     $104 = __THREW__; __THREW__ = 0;
                     $105 = $104&1;
                     if ($105) {
                      break L1;
                     }
                     if ($103) {
                      label = 39;
                      break;
                     }
                     __THREW__ = 0;
                     $108 = (Math_fround(+(invoke_fi(148,(0|0)))));
                     $109 = __THREW__; __THREW__ = 0;
                     $110 = $109&1;
                     if ($110) {
                      break L1;
                     }
                     $111 = (($__this) + 92|0);
                     $112 = Math_fround(HEAPF32[$111>>2]);
                     $113 = Math_fround($108 - $112);
                     $114 = (($__this) + 144|0);
                     $115 = Math_fround(HEAPF32[$114>>2]);
                     $116 = !($113 <= $115);
                     if ($116) {
                      $117 = (($__this) + 64|0);
                      $118 = Math_fround(HEAPF32[$117>>2]);
                      HEAP32[$99>>2] = 2;
                      $$pn = $118;
                      break;
                     } else {
                      $119 = (($__this) + 60|0);
                      $120 = Math_fround(HEAPF32[$119>>2]);
                      HEAP32[$99>>2] = 1;
                      $$pn = $120;
                      break;
                     }
                    }
                   } while(0);
                   if ((label|0) == 39) {
                    $106 = (($__this) + 68|0);
                    $107 = Math_fround(HEAPF32[$106>>2]);
                    HEAP32[$99>>2] = 3;
                    $$pn = $107;
                   }
                   $V_9$0 = Math_fround($96 * $$pn);
                   $121 = (($__this) + 132|0);
                   $122 = Math_fround(HEAPF32[$121>>2]);
                   __THREW__ = 0;
                   $123 = (Math_fround(+(invoke_fifff(2,(0|0),(+$122),(+$V_9$0),(+$92)))));
                   $124 = __THREW__; __THREW__ = 0;
                   $125 = $124&1;
                   if ($125) {
                    break;
                   }
                   HEAPF32[$121>>2] = $123;
                   $126 = (($__this) + 60|0);
                   $127 = Math_fround(HEAPF32[$126>>2]);
                   $128 = Math_fround($127 * Math_fround(0.300000011920928955078));
                   $129 = !($123 >= $128);
                   if (!($129)) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   __THREW__ = 0;
                   $130 = (Math_fround(+(invoke_fi(148,(0|0)))));
                   $131 = __THREW__; __THREW__ = 0;
                   $132 = $131&1;
                   if ($132) {
                    break;
                   }
                   $133 = (($__this) + 144|0);
                   HEAPF32[$133>>2] = $130;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($42|0);
 // unreachable;
}
function __Z75AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_ApplyJumpingP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = Math_fround(0), $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1296832);
 __THREW__ = 0;
 invoke_v(318);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 152|0);
  $3 = Math_fround(HEAPF32[$2>>2]);
  $4 = (($__this) + 100|0);
  $5 = Math_fround(HEAPF32[$4>>2]);
  __THREW__ = 0;
  $6 = (Math_fround(+(invoke_fi(148,(0|0)))));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = Math_fround($3 + $5);
   $10 = !($9 <= $6);
   if ($10) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   $13 = (invoke_iii(2734,(1296784|0),($__this|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    if (!($13)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $16 = (($__this) + 96|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $19 = (Math_fround(+(invoke_fi(148,(0|0)))));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 148|0);
     $23 = Math_fround(HEAPF32[$22>>2]);
     $24 = (($__this) + 104|0);
     $25 = Math_fround(HEAPF32[$24>>2]);
     $26 = Math_fround($23 + $25);
     $27 = !($19 >= $26);
     if (!($27)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $28 = (($__this) + 76|0);
     $29 = Math_fround(HEAPF32[$28>>2]);
     __THREW__ = 0;
     $30 = (Math_fround(+(invoke_fiif(1,(1296880|0),($__this|0),(+$29)))));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $33 = (($__this) + 128|0);
      HEAPF32[$33>>2] = $30;
      $34 = HEAP32[2995000>>2]|0;
      __THREW__ = 0;
      invoke_viii(730,($__this|0),($34|0),1);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z75AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_ApplyGravityP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = 0, $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1296928);
 __THREW__ = 0;
 invoke_v(319);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 176|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $7 = HEAP32[2995032>>2]|0;
   __THREW__ = 0;
   (invoke_iii(1232,(0|0),($7|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($__this) + 140|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = ($11<<24>>24)==(0);
    if (!($12)) {
     $13 = (($__this) + 141|0);
     $14 = HEAP8[$13>>0]|0;
     $15 = ($14<<24>>24)==(0);
     if ($15) {
      $16 = (($__this) + 128|0);
      $17 = Math_fround(HEAPF32[$16>>2]);
      $18 = $17 > Math_fround(0.0);
      if (!($18)) {
       HEAP8[$13>>0] = 1;
       $19 = HEAP32[2995040>>2]|0;
       __THREW__ = 0;
       invoke_viii(730,($__this|0),($19|0),1);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
      }
     }
    }
    __THREW__ = 0;
    $22 = (invoke_iii(2734,(1296784|0),($__this|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = (($__this) + 128|0);
     if ($22) {
      HEAPF32[$25>>2] = Math_fround(0.0);
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $26 = Math_fround(HEAPF32[$25>>2]);
     $27 = (($__this) + 80|0);
     $28 = Math_fround(HEAPF32[$27>>2]);
     __THREW__ = 0;
     $29 = (Math_fround(+(invoke_fi(149,(0|0)))));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      $32 = Math_fround($28 * $29);
      $33 = Math_fround($26 - $32);
      HEAPF32[$25>>2] = $33;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z89AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_CalculateJumpVerticalSpeedP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerf($__this,$targetJumpHeight) {
 $__this = $__this|0;
 $targetJumpHeight = Math_fround($targetJumpHeight);
 var $0 = Math_fround(0), $1 = 0, $2 = Math_fround(0), $3 = Math_fround(0), $4 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1296880);
 $0 = Math_fround($targetJumpHeight * Math_fround(2.0));
 $1 = (($__this) + 80|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = Math_fround($0 * $2);
 $4 = (Math_fround(Math_sqrt((Math_fround($3)))));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($4));
}
function __Z70AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_DidJumpP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $L_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $L_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1296976);
 $0 = (($__this) + 140|0);
 HEAP8[$0>>0] = 1;
 $1 = (($__this) + 141|0);
 HEAP8[$1>>0] = 0;
 __THREW__ = 0;
 $2 = (Math_fround(+(invoke_fi(148,(0|0)))));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($__this) + 152|0);
  HEAPF32[$5>>2] = $2;
  __THREW__ = 0;
  $6 = (invoke_ii(2522,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vi(3799,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vii(2122,($L_4|0),($6|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = (($L_4) + 4|0);
     $14 = Math_fround(HEAPF32[$13>>2]);
     $15 = (($__this) + 156|0);
     HEAPF32[$15>>2] = $14;
     $16 = (($__this) + 148|0);
     HEAPF32[$16>>2] = Math_fround(-10.0);
     $17 = (($__this) + 56|0);
     HEAP32[$17>>2] = 4;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z69AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_UpdateP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0, $130 = 0, $131 = Math_fround(0), $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = Math_fround(0), $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = Math_fround(0), $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = Math_fround(0), $204 = Math_fround(0), $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = Math_fround(0), $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = Math_fround(0), $244 = Math_fround(0), $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = Math_fround(0);
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = Math_fround(0), $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = Math_fround(0), $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = Math_fround(0), $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = Math_fround(0), $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = Math_fround(0);
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $L_107 = 0, $L_11 = 0, $L_113 = 0, $L_113$byval_copy = 0, $L_116 = 0, $L_12 = 0, $L_12$byval_copy = 0, $L_14 = 0, $L_16 = 0, $L_5 = 0, $L_53 = 0, $L_65 = 0, $L_80 = 0, $L_95 = 0, $V_0 = 0, $V_2 = 0, $V_3 = 0;
 var $V_4 = 0, $V_5 = 0, $V_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $L_113$byval_copy = sp + 248|0;
 $L_12$byval_copy = sp + 236|0;
 $_stackTraceSentry = sp + 232|0;
 $V_0 = sp + 220|0;
 $V_2 = sp + 208|0;
 $V_3 = sp + 196|0;
 $V_4 = sp + 184|0;
 $V_5 = sp + 172|0;
 $V_6 = sp + 160|0;
 $L_5 = sp + 148|0;
 $L_11 = sp + 136|0;
 $L_12 = sp + 124|0;
 $L_14 = sp + 28|0;
 $L_16 = sp;
 $0 = sp + 12|0;
 $L_53 = sp + 16|0;
 $L_65 = sp + 40|0;
 $L_80 = sp + 52|0;
 $L_95 = sp + 64|0;
 $L_107 = sp + 80|0;
 $L_113 = sp + 96|0;
 $L_116 = sp + 112|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297024);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;
 ;HEAP32[$V_5+0>>2]=0|0;HEAP32[$V_5+4>>2]=0|0;HEAP32[$V_5+8>>2]=0|0;
 ;HEAP32[$V_6+0>>2]=0|0;HEAP32[$V_6+4>>2]=0|0;HEAP32[$V_6+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(320);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = (($__this) + 176|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    __THREW__ = 0;
    invoke_vi(3123,(0|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   $10 = HEAP32[2995088>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iii(1233,(0|0),($10|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    if ($11) {
     __THREW__ = 0;
     $14 = (Math_fround(+(invoke_fi(148,(0|0)))));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     $17 = (($__this) + 148|0);
     HEAPF32[$17>>2] = $14;
    }
    __THREW__ = 0;
    invoke_vii(3495,(1296736|0),($__this|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(3495,(1296928|0),($__this|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vii(3495,(1296832|0),($__this|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       $24 = (($__this) + 116|0);
       $25 = (($__this) + 132|0);
       $26 = Math_fround(HEAPF32[$25>>2]);
       __THREW__ = 0;
       ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$24+8>>2]|0;
       invoke_viiif(2,($L_5|0),(0|0),($L_113$byval_copy|0),(+$26));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $29 = (($__this) + 128|0);
        $30 = Math_fround(HEAPF32[$29>>2]);
        ;HEAP32[$L_11+0>>2]=0|0;HEAP32[$L_11+4>>2]=0|0;HEAP32[$L_11+8>>2]=0|0;
        __THREW__ = 0;
        invoke_vifff(4,($L_11|0),0.0,(+$30),0.0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         __THREW__ = 0;
         ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;
         ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_11+8>>2]|0;
         invoke_viiii(222,($L_12|0),(0|0),($L_12$byval_copy|0),($L_113$byval_copy|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          $35 = (($__this) + 160|0);
          __THREW__ = 0;
          ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;
          ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$35+8>>2]|0;
          invoke_viiii(222,($L_14|0),(0|0),($L_12$byval_copy|0),($L_113$byval_copy|0));
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if (!($37)) {
           ;HEAP32[$V_0+0>>2]=HEAP32[$L_14+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_14+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_14+8>>2]|0;
           __THREW__ = 0;
           $38 = (Math_fround(+(invoke_fi(149,(0|0)))));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            __THREW__ = 0;
            ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
            invoke_viiif(2,($L_16|0),(0|0),($L_113$byval_copy|0),(+$38));
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if (!($42)) {
             ;HEAP32[$V_0+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_16+8>>2]|0;
             HEAP32[$0>>2] = 1299968;
             __THREW__ = 0;
             ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
             $43 = (invoke_iii(772,(0|0),($L_113$byval_copy|0))|0);
             $44 = __THREW__; __THREW__ = 0;
             $45 = $44&1;
             if (!($45)) {
              __THREW__ = 0;
              $46 = (invoke_iii(1189,($__this|0),($43|0))|0);
              $47 = __THREW__; __THREW__ = 0;
              $48 = $47&1;
              if (!($48)) {
               __THREW__ = 0;
               (invoke_ii(2996,(2839072|0))|0);
               $49 = __THREW__; __THREW__ = 0;
               $50 = $49&1;
               if (!($50)) {
                __THREW__ = 0;
                $51 = (invoke_iii(2733,($46|0),(2839072|0))|0);
                $52 = __THREW__; __THREW__ = 0;
                $53 = $52&1;
                if (!($53)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($51|0));
                 $54 = __THREW__; __THREW__ = 0;
                 $55 = $54&1;
                 if (!($55)) {
                  __THREW__ = 0;
                  ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
                  $56 = (invoke_iii(1237,($51|0),($L_113$byval_copy|0))|0);
                  $57 = __THREW__; __THREW__ = 0;
                  $58 = $57&1;
                  if (!($58)) {
                   $59 = (($__this) + 136|0);
                   HEAP32[$59>>2] = $56;
                   $60 = (($__this) + 52|0);
                   $61 = HEAP32[$60>>2]|0;
                   __THREW__ = 0;
                   $62 = (invoke_iii(1194,(0|0),($61|0))|0);
                   $63 = __THREW__; __THREW__ = 0;
                   $64 = $63&1;
                   if ($64) {
                    break;
                   }
                   do {
                    if ($62) {
                     $65 = (($__this) + 56|0);
                     $66 = HEAP32[$65>>2]|0;
                     $67 = ($66|0)==(4);
                     if ($67) {
                      $68 = (($__this) + 141|0);
                      $69 = HEAP8[$68>>0]|0;
                      $70 = ($69<<24>>24)==(0);
                      $71 = HEAP32[$60>>2]|0;
                      $72 = (($__this) + 28|0);
                      $73 = HEAP32[$72>>2]|0;
                      if ($70) {
                       __THREW__ = 0;
                       invoke_vi(3799,($73|0));
                       $74 = __THREW__; __THREW__ = 0;
                       $75 = $74&1;
                       if ($75) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $76 = (invoke_ii(2528,($73|0))|0);
                       $77 = __THREW__; __THREW__ = 0;
                       $78 = $77&1;
                       if ($78) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($71|0));
                       $79 = __THREW__; __THREW__ = 0;
                       $80 = $79&1;
                       if ($80) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $81 = (invoke_iii(1238,($71|0),($76|0))|0);
                       $82 = __THREW__; __THREW__ = 0;
                       $83 = $82&1;
                       if ($83) {
                        break L1;
                       }
                       $84 = (($__this) + 44|0);
                       $85 = Math_fround(HEAPF32[$84>>2]);
                       __THREW__ = 0;
                       invoke_vi(3799,($81|0));
                       $86 = __THREW__; __THREW__ = 0;
                       $87 = $86&1;
                       if ($87) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vif(126,($81|0),(+$85));
                       $88 = __THREW__; __THREW__ = 0;
                       $89 = $88&1;
                       if ($89) {
                        break L1;
                       }
                       $90 = HEAP32[$60>>2]|0;
                       $91 = HEAP32[$72>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($91|0));
                       $92 = __THREW__; __THREW__ = 0;
                       $93 = $92&1;
                       if ($93) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $94 = (invoke_ii(2528,($91|0))|0);
                       $95 = __THREW__; __THREW__ = 0;
                       $96 = $95&1;
                       if ($96) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($90|0));
                       $97 = __THREW__; __THREW__ = 0;
                       $98 = $97&1;
                       if ($98) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $99 = (invoke_iii(1238,($90|0),($94|0))|0);
                       $100 = __THREW__; __THREW__ = 0;
                       $101 = $100&1;
                       if ($101) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($99|0));
                       $102 = __THREW__; __THREW__ = 0;
                       $103 = $102&1;
                       if ($103) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vii(2177,($99|0),8);
                       $104 = __THREW__; __THREW__ = 0;
                       $105 = $104&1;
                       if ($105) {
                        break L1;
                       }
                       $106 = HEAP32[$60>>2]|0;
                       $107 = HEAP32[$72>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($107|0));
                       $108 = __THREW__; __THREW__ = 0;
                       $109 = $108&1;
                       if ($109) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $110 = (invoke_ii(2528,($107|0))|0);
                       $111 = __THREW__; __THREW__ = 0;
                       $112 = $111&1;
                       if ($112) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($106|0));
                       $113 = __THREW__; __THREW__ = 0;
                       $114 = $113&1;
                       if ($114) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vii(2176,($106|0),($110|0));
                       $115 = __THREW__; __THREW__ = 0;
                       $116 = $115&1;
                       if ($116) {
                        break L1;
                       } else {
                        break;
                       }
                      } else {
                       __THREW__ = 0;
                       invoke_vi(3799,($73|0));
                       $117 = __THREW__; __THREW__ = 0;
                       $118 = $117&1;
                       if ($118) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $119 = (invoke_ii(2528,($73|0))|0);
                       $120 = __THREW__; __THREW__ = 0;
                       $121 = $120&1;
                       if ($121) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($71|0));
                       $122 = __THREW__; __THREW__ = 0;
                       $123 = $122&1;
                       if ($123) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $124 = (invoke_iii(1238,($71|0),($119|0))|0);
                       $125 = __THREW__; __THREW__ = 0;
                       $126 = $125&1;
                       if ($126) {
                        break L1;
                       }
                       $127 = (($__this) + 48|0);
                       $128 = Math_fround(HEAPF32[$127>>2]);
                       __THREW__ = 0;
                       invoke_vi(3799,($124|0));
                       $129 = __THREW__; __THREW__ = 0;
                       $130 = $129&1;
                       if ($130) {
                        break L1;
                       }
                       $131 = Math_fround(-$128);
                       __THREW__ = 0;
                       invoke_vif(126,($124|0),(+$131));
                       $132 = __THREW__; __THREW__ = 0;
                       $133 = $132&1;
                       if ($133) {
                        break L1;
                       }
                       $134 = HEAP32[$60>>2]|0;
                       $135 = HEAP32[$72>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($135|0));
                       $136 = __THREW__; __THREW__ = 0;
                       $137 = $136&1;
                       if ($137) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $138 = (invoke_ii(2528,($135|0))|0);
                       $139 = __THREW__; __THREW__ = 0;
                       $140 = $139&1;
                       if ($140) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($134|0));
                       $141 = __THREW__; __THREW__ = 0;
                       $142 = $141&1;
                       if ($142) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $143 = (invoke_iii(1238,($134|0),($138|0))|0);
                       $144 = __THREW__; __THREW__ = 0;
                       $145 = $144&1;
                       if ($145) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($143|0));
                       $146 = __THREW__; __THREW__ = 0;
                       $147 = $146&1;
                       if ($147) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vii(2177,($143|0),8);
                       $148 = __THREW__; __THREW__ = 0;
                       $149 = $148&1;
                       if ($149) {
                        break L1;
                       }
                       $150 = HEAP32[$60>>2]|0;
                       $151 = HEAP32[$72>>2]|0;
                       __THREW__ = 0;
                       invoke_vi(3799,($151|0));
                       $152 = __THREW__; __THREW__ = 0;
                       $153 = $152&1;
                       if ($153) {
                        break L1;
                       }
                       __THREW__ = 0;
                       $154 = (invoke_ii(2528,($151|0))|0);
                       $155 = __THREW__; __THREW__ = 0;
                       $156 = $155&1;
                       if ($156) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($150|0));
                       $157 = __THREW__; __THREW__ = 0;
                       $158 = $157&1;
                       if ($158) {
                        break L1;
                       }
                       __THREW__ = 0;
                       invoke_vii(2176,($150|0),($154|0));
                       $159 = __THREW__; __THREW__ = 0;
                       $160 = $159&1;
                       if ($160) {
                        break L1;
                       } else {
                        break;
                       }
                      }
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($51|0));
                     $161 = __THREW__; __THREW__ = 0;
                     $162 = $161&1;
                     if ($162) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vii(2157,($L_53|0),($51|0));
                     $163 = __THREW__; __THREW__ = 0;
                     $164 = $163&1;
                     if ($164) {
                      break L1;
                     }
                     ;HEAP32[$V_3+0>>2]=HEAP32[$L_53+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_53+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_53+8>>2]|0;
                     __THREW__ = 0;
                     $165 = (Math_fround(+(invoke_fi(137,($V_3|0)))));
                     $166 = __THREW__; __THREW__ = 0;
                     $167 = $166&1;
                     if ($167) {
                      break L1;
                     }
                     $168 = !($165 >= Math_fround(0.100000001490116119385));
                     if ($168) {
                      $169 = HEAP32[$60>>2]|0;
                      $170 = (($__this) + 16|0);
                      $171 = HEAP32[$170>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($171|0));
                      $172 = __THREW__; __THREW__ = 0;
                      $173 = $172&1;
                      if ($173) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $174 = (invoke_ii(2528,($171|0))|0);
                      $175 = __THREW__; __THREW__ = 0;
                      $176 = $175&1;
                      if ($176) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($169|0));
                      $177 = __THREW__; __THREW__ = 0;
                      $178 = $177&1;
                      if ($178) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vii(2176,($169|0),($174|0));
                      $179 = __THREW__; __THREW__ = 0;
                      $180 = $179&1;
                      if ($180) {
                       break L1;
                      } else {
                       break;
                      }
                     }
                     $181 = HEAP32[$65>>2]|0;
                     if ((($181|0) == 2)) {
                      $222 = HEAP32[$60>>2]|0;
                      $223 = (($__this) + 20|0);
                      $224 = HEAP32[$223>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($224|0));
                      $225 = __THREW__; __THREW__ = 0;
                      $226 = $225&1;
                      if ($226) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $227 = (invoke_ii(2528,($224|0))|0);
                      $228 = __THREW__; __THREW__ = 0;
                      $229 = $228&1;
                      if ($229) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($222|0));
                      $230 = __THREW__; __THREW__ = 0;
                      $231 = $230&1;
                      if ($231) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $232 = (invoke_iii(1238,($222|0),($227|0))|0);
                      $233 = __THREW__; __THREW__ = 0;
                      $234 = $233&1;
                      if ($234) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($51|0));
                      $235 = __THREW__; __THREW__ = 0;
                      $236 = $235&1;
                      if ($236) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vii(2157,($L_80|0),($51|0));
                      $237 = __THREW__; __THREW__ = 0;
                      $238 = $237&1;
                      if ($238) {
                       break L1;
                      }
                      ;HEAP32[$V_5+0>>2]=HEAP32[$L_80+0>>2]|0;HEAP32[$V_5+4>>2]=HEAP32[$L_80+4>>2]|0;HEAP32[$V_5+8>>2]=HEAP32[$L_80+8>>2]|0;
                      __THREW__ = 0;
                      $239 = (Math_fround(+(invoke_fi(136,($V_5|0)))));
                      $240 = __THREW__; __THREW__ = 0;
                      $241 = $240&1;
                      if ($241) {
                       break L1;
                      }
                      $242 = (($__this) + 36|0);
                      $243 = Math_fround(HEAPF32[$242>>2]);
                      __THREW__ = 0;
                      $244 = (Math_fround(+(invoke_fifff(1,(0|0),(+$239),0.0,(+$243)))));
                      $245 = __THREW__; __THREW__ = 0;
                      $246 = $245&1;
                      if ($246) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($232|0));
                      $247 = __THREW__; __THREW__ = 0;
                      $248 = $247&1;
                      if ($248) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vif(126,($232|0),(+$244));
                      $249 = __THREW__; __THREW__ = 0;
                      $250 = $249&1;
                      if ($250) {
                       break L1;
                      }
                      $251 = HEAP32[$60>>2]|0;
                      $252 = HEAP32[$223>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($252|0));
                      $253 = __THREW__; __THREW__ = 0;
                      $254 = $253&1;
                      if ($254) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $255 = (invoke_ii(2528,($252|0))|0);
                      $256 = __THREW__; __THREW__ = 0;
                      $257 = $256&1;
                      if ($257) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($251|0));
                      $258 = __THREW__; __THREW__ = 0;
                      $259 = $258&1;
                      if ($259) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vii(2176,($251|0),($255|0));
                      $260 = __THREW__; __THREW__ = 0;
                      $261 = $260&1;
                      if ($261) {
                       break L1;
                      } else {
                       break;
                      }
                     } else if ((($181|0) == 3)) {
                      $182 = HEAP32[$60>>2]|0;
                      $183 = (($__this) + 24|0);
                      $184 = HEAP32[$183>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($184|0));
                      $185 = __THREW__; __THREW__ = 0;
                      $186 = $185&1;
                      if ($186) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $187 = (invoke_ii(2528,($184|0))|0);
                      $188 = __THREW__; __THREW__ = 0;
                      $189 = $188&1;
                      if ($189) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($182|0));
                      $190 = __THREW__; __THREW__ = 0;
                      $191 = $190&1;
                      if ($191) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $192 = (invoke_iii(1238,($182|0),($187|0))|0);
                      $193 = __THREW__; __THREW__ = 0;
                      $194 = $193&1;
                      if ($194) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($51|0));
                      $195 = __THREW__; __THREW__ = 0;
                      $196 = $195&1;
                      if ($196) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vii(2157,($L_65|0),($51|0));
                      $197 = __THREW__; __THREW__ = 0;
                      $198 = $197&1;
                      if ($198) {
                       break L1;
                      }
                      ;HEAP32[$V_4+0>>2]=HEAP32[$L_65+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_65+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_65+8>>2]|0;
                      __THREW__ = 0;
                      $199 = (Math_fround(+(invoke_fi(136,($V_4|0)))));
                      $200 = __THREW__; __THREW__ = 0;
                      $201 = $200&1;
                      if ($201) {
                       break L1;
                      }
                      $202 = (($__this) + 40|0);
                      $203 = Math_fround(HEAPF32[$202>>2]);
                      __THREW__ = 0;
                      $204 = (Math_fround(+(invoke_fifff(1,(0|0),(+$199),0.0,(+$203)))));
                      $205 = __THREW__; __THREW__ = 0;
                      $206 = $205&1;
                      if ($206) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($192|0));
                      $207 = __THREW__; __THREW__ = 0;
                      $208 = $207&1;
                      if ($208) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vif(126,($192|0),(+$204));
                      $209 = __THREW__; __THREW__ = 0;
                      $210 = $209&1;
                      if ($210) {
                       break L1;
                      }
                      $211 = HEAP32[$60>>2]|0;
                      $212 = HEAP32[$183>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($212|0));
                      $213 = __THREW__; __THREW__ = 0;
                      $214 = $213&1;
                      if ($214) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $215 = (invoke_ii(2528,($212|0))|0);
                      $216 = __THREW__; __THREW__ = 0;
                      $217 = $216&1;
                      if ($217) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($211|0));
                      $218 = __THREW__; __THREW__ = 0;
                      $219 = $218&1;
                      if ($219) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vii(2176,($211|0),($215|0));
                      $220 = __THREW__; __THREW__ = 0;
                      $221 = $220&1;
                      if ($221) {
                       break L1;
                      } else {
                       break;
                      }
                     } else if ((($181|0) == 1)) {
                      $262 = HEAP32[$60>>2]|0;
                      $263 = (($__this) + 20|0);
                      $264 = HEAP32[$263>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($264|0));
                      $265 = __THREW__; __THREW__ = 0;
                      $266 = $265&1;
                      if ($266) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $267 = (invoke_ii(2528,($264|0))|0);
                      $268 = __THREW__; __THREW__ = 0;
                      $269 = $268&1;
                      if ($269) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($262|0));
                      $270 = __THREW__; __THREW__ = 0;
                      $271 = $270&1;
                      if ($271) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $272 = (invoke_iii(1238,($262|0),($267|0))|0);
                      $273 = __THREW__; __THREW__ = 0;
                      $274 = $273&1;
                      if ($274) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($51|0));
                      $275 = __THREW__; __THREW__ = 0;
                      $276 = $275&1;
                      if ($276) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vii(2157,($L_95|0),($51|0));
                      $277 = __THREW__; __THREW__ = 0;
                      $278 = $277&1;
                      if ($278) {
                       break L1;
                      }
                      ;HEAP32[$V_6+0>>2]=HEAP32[$L_95+0>>2]|0;HEAP32[$V_6+4>>2]=HEAP32[$L_95+4>>2]|0;HEAP32[$V_6+8>>2]=HEAP32[$L_95+8>>2]|0;
                      __THREW__ = 0;
                      $279 = (Math_fround(+(invoke_fi(136,($V_6|0)))));
                      $280 = __THREW__; __THREW__ = 0;
                      $281 = $280&1;
                      if ($281) {
                       break L1;
                      }
                      $282 = (($__this) + 32|0);
                      $283 = Math_fround(HEAPF32[$282>>2]);
                      __THREW__ = 0;
                      $284 = (Math_fround(+(invoke_fifff(1,(0|0),(+$279),0.0,(+$283)))));
                      $285 = __THREW__; __THREW__ = 0;
                      $286 = $285&1;
                      if ($286) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($272|0));
                      $287 = __THREW__; __THREW__ = 0;
                      $288 = $287&1;
                      if ($288) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vif(126,($272|0),(+$284));
                      $289 = __THREW__; __THREW__ = 0;
                      $290 = $289&1;
                      if ($290) {
                       break L1;
                      }
                      $291 = HEAP32[$60>>2]|0;
                      $292 = HEAP32[$263>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($292|0));
                      $293 = __THREW__; __THREW__ = 0;
                      $294 = $293&1;
                      if ($294) {
                       break L1;
                      }
                      __THREW__ = 0;
                      $295 = (invoke_ii(2528,($292|0))|0);
                      $296 = __THREW__; __THREW__ = 0;
                      $297 = $296&1;
                      if ($297) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($291|0));
                      $298 = __THREW__; __THREW__ = 0;
                      $299 = $298&1;
                      if ($299) {
                       break L1;
                      }
                      __THREW__ = 0;
                      invoke_vii(2176,($291|0),($295|0));
                      $300 = __THREW__; __THREW__ = 0;
                      $301 = $300&1;
                      if ($301) {
                       break L1;
                      } else {
                       break;
                      }
                     } else {
                      break;
                     }
                    }
                   } while(0);
                   __THREW__ = 0;
                   $302 = (invoke_iii(2734,(1296784|0),($__this|0))|0);
                   $303 = __THREW__; __THREW__ = 0;
                   $304 = $303&1;
                   if ($304) {
                    break;
                   }
                   do {
                    if ($302) {
                     __THREW__ = 0;
                     $305 = (invoke_ii(2522,($__this|0))|0);
                     $306 = __THREW__; __THREW__ = 0;
                     $307 = $306&1;
                     if ($307) {
                      break L1;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$24+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$24+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$24+8>>2]|0;
                     invoke_viii(742,($L_107|0),(0|0),($L_113$byval_copy|0));
                     $308 = __THREW__; __THREW__ = 0;
                     $309 = $308&1;
                     if ($309) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($305|0));
                     $310 = __THREW__; __THREW__ = 0;
                     $311 = $310&1;
                     if ($311) {
                      break L1;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_107+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_107+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_107+8>>2]|0;HEAP32[$L_113$byval_copy+12>>2]=HEAP32[$L_107+12>>2]|0;
                     invoke_vii(2134,($305|0),($L_113$byval_copy|0));
                     $312 = __THREW__; __THREW__ = 0;
                     $313 = $312&1;
                     if ($313) {
                      break L1;
                     }
                    } else {
                     ;HEAP32[$V_2+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$V_0+8>>2]|0;
                     $314 = (($V_2) + 4|0);
                     HEAPF32[$314>>2] = Math_fround(0.0);
                     __THREW__ = 0;
                     $315 = (Math_fround(+(invoke_fi(137,($V_2|0)))));
                     $316 = __THREW__; __THREW__ = 0;
                     $317 = $316&1;
                     if ($317) {
                      break L1;
                     }
                     $318 = !($315 <= Math_fround(0.00100000004749745130539));
                     if (!($318)) {
                      break;
                     }
                     __THREW__ = 0;
                     $319 = (invoke_ii(2522,($__this|0))|0);
                     $320 = __THREW__; __THREW__ = 0;
                     $321 = $320&1;
                     if ($321) {
                      break L1;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$V_2+8>>2]|0;
                     invoke_viii(742,($L_113|0),(0|0),($L_113$byval_copy|0));
                     $322 = __THREW__; __THREW__ = 0;
                     $323 = $322&1;
                     if ($323) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($319|0));
                     $324 = __THREW__; __THREW__ = 0;
                     $325 = $324&1;
                     if ($325) {
                      break L1;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_113$byval_copy+0>>2]=HEAP32[$L_113+0>>2]|0;HEAP32[$L_113$byval_copy+4>>2]=HEAP32[$L_113+4>>2]|0;HEAP32[$L_113$byval_copy+8>>2]=HEAP32[$L_113+8>>2]|0;HEAP32[$L_113$byval_copy+12>>2]=HEAP32[$L_113+12>>2]|0;
                     invoke_vii(2134,($319|0),($L_113$byval_copy|0));
                     $326 = __THREW__; __THREW__ = 0;
                     $327 = $326&1;
                     if ($327) {
                      break L1;
                     }
                    }
                   } while(0);
                   __THREW__ = 0;
                   $328 = (invoke_iii(2734,(1296784|0),($__this|0))|0);
                   $329 = __THREW__; __THREW__ = 0;
                   $330 = $329&1;
                   if ($330) {
                    break;
                   }
                   if (!($328)) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   __THREW__ = 0;
                   $331 = (Math_fround(+(invoke_fi(148,(0|0)))));
                   $332 = __THREW__; __THREW__ = 0;
                   $333 = $332&1;
                   if ($333) {
                    break;
                   }
                   $334 = (($__this) + 172|0);
                   HEAPF32[$334>>2] = $331;
                   __THREW__ = 0;
                   invoke_vii(2070,($L_116|0),(0|0));
                   $335 = __THREW__; __THREW__ = 0;
                   $336 = $335&1;
                   if ($336) {
                    break;
                   }
                   ;HEAP32[$35+0>>2]=HEAP32[$L_116+0>>2]|0;HEAP32[$35+4>>2]=HEAP32[$L_116+4>>2]|0;HEAP32[$35+8>>2]=HEAP32[$L_116+8>>2]|0;
                   $337 = (($__this) + 140|0);
                   $338 = HEAP8[$337>>0]|0;
                   $339 = ($338<<24>>24)==(0);
                   if ($339) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   HEAP8[$337>>0] = 0;
                   $340 = HEAP32[2995096>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(730,($__this|0),($340|0),1);
                   $341 = __THREW__; __THREW__ = 0;
                   $342 = $341&1;
                   if ($342) {
                    break;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z86AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_OnControllerColliderHitP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP45UnityEngine_UnityEngine_ControllerColliderHit($__this,$hit) {
 $__this = $__this|0;
 $hit = $hit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297072);
 __THREW__ = 0;
 invoke_vi(3799,($hit|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2155,($L_0|0),($hit|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z71AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_GetSpeedP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297120);
 $0 = (($__this) + 132|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z72AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsJumpingP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294616);
 $0 = (($__this) + 140|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z73AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsGroundedP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1296784);
 $0 = (($__this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $$lobit = $1 & 4;
 $2 = ($$lobit|0)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z75AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_GetDirectionP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297168);
 $0 = (($__this) + 116|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z80AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsMovingBackwardsP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294568);
 $0 = (($__this) + 142|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z81AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_GetLockCameraTimerP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1294520);
 $0 = (($__this) + 112|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z71AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsMovingP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297216);
 __THREW__ = 0;
 invoke_v(321);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[2995128>>2]|0;
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fii(42,(0|0),($2|0)))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[2995136>>2]|0;
   __THREW__ = 0;
   $7 = (Math_fround(+(invoke_fii(42,(0|0),($6|0)))));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (Math_fround(Math_abs((Math_fround($3)))));
    $11 = (Math_fround(Math_abs((Math_fround($7)))));
    $12 = Math_fround($10 + $11);
    $13 = $12 > Math_fround(0.5);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($13|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z81AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_HasJumpReachedApexP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297264);
 $0 = (($__this) + 141|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z84AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsGroundedWithTimeoutP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297312);
 $0 = (($__this) + 172|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($__this) + 108|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 __THREW__ = 0;
 $4 = (Math_fround(+(invoke_fi(148,(0|0)))));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $7 = Math_fround($1 + $3);
  $8 = $7 > $4;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z68AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_ResetP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297360);
 __THREW__ = 0;
 invoke_v(322);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(2523,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[2995152>>2]|0;
    __THREW__ = 0;
    invoke_vii(2003,($2|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z67AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_MainP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1297408);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z91AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717112)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2839072)|0);
 $5 = HEAP32[((2839072 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z48UnityEngine_UnityEngine_RequireComponent_m__ctorP40UnityEngine_UnityEngine_RequireComponentP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJControllerP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1302928)|0);
 $0 = HEAP32[((1302928 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker0I28mscorlib_System_ObjectTraitsE6InvokeEPFP22mscorlib_System_ObjectPvES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1302928)|0);
 $0 = HEAP32[((1302928 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1303072);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1303120);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 $3 = (invoke_ii($2|0,($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1303168);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1303216);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1303264);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    $37 = (($rgctx) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (($38) + 4|0);
    $40 = HEAP32[$39>>2]|0;
    __THREW__ = 0;
    $41 = (invoke_iii($40|0,($26|0),($36|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($41|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1050($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1303552)|0);
 $0 = HEAP32[((1303552 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1303552)|0);
 $0 = HEAP32[((1303552 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1307416)|0);
 $0 = HEAP32[((1307416 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1307416)|0);
 $0 = HEAP32[((1307416 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_StringP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1309680)|0);
 $0 = HEAP32[((1309680 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1309680)|0);
 $0 = HEAP32[((1309680 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m__ctorP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CharP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1311464);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m_System_Collections_IEnumerator_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1311512);
 __THREW__ = 0;
 $0 = (invoke_ii(765,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP16[$L_1>>1] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2180696|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2180696|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1311656);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1261,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m_DisposeP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1311560);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m_MoveNextP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1311608);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I26mscorlib_System_CharTraitsE6InvokeEPFtPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP16[$ret>>1] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m__ctorP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObjectP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1314144)|0);
 $0 = HEAP32[((1314144 + 84|0))>>2]|0;
 $1 = (__Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL94mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_DisposeP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_VerifyStateP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1314144)|0);
 $0 = HEAP32[((1314144 + 84|0))>>2]|0;
 __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_MoveNextP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject1051($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1314144)|0);
 $0 = HEAP32[((1314144 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_get_CurrentP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1314288);
 HEAP32[$__this>>2] = $l;
 __THREW__ = 0;
 invoke_vi(3799,($l|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($l) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1314336);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($2|0,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($__this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>(0);
  if ($7) {
   $19 = (($__this) + 12|0);
   $20 = HEAP32[$19>>2]|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($20|0);
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2607872|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_ii(3469,(2607872|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    invoke_vi(2734,($12|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(3808,($12|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      // unreachable;
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1314384);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1314432);
 __THREW__ = 0;
 invoke_v(324);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if (!($3)) {
    $30 = (($__this) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($2) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($31|0)==($35|0);
    if ($36) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3469,(2607872|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    $42 = HEAP32[3021520>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($39|0),($42|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($39|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    // unreachable;
   }
   ;HEAP32[$L_1+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$__this+12>>2]|0;
   $6 = (($rgctx) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   $8 = (invoke_iii(2724,($7|0),($L_1|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_ii(1782,($8|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3799,($13|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_iii(2730,(2150320|0),($13|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2634432|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         $23 = (invoke_ii(3469,(2634432|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          invoke_vii(1970,($23|0),($18|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           invoke_vi(3808,($23|0));
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1314480);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($2|0,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = (($__this) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)>(-1);
   if (!($7)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $10 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = (($10) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($6|0)<($14|0);
    if (!($15)) {
     HEAP32[$5>>2] = -1;
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $16 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($16) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = HEAP32[$5>>2]|0;
     $22 = (($21) + 1)|0;
     HEAP32[$5>>2] = $22;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $25 = ($21|0)<(0);
      if ($25) {
       label = 10;
      } else {
       $26 = (($20) + 12|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($21>>>0)<($27>>>0);
       if (!($28)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $29 = (invoke_i(132)|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($29|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
      }
      $34 = HEAP32[$20>>2]|0;
      $35 = (($20) + 16|0);
      $36 = (($34) + 92|0);
      $37 = HEAP32[$36>>2]|0;
      $38 = Math_imul($37, $21)|0;
      $39 = (($35) + ($38)|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($__this) + 12|0);
      HEAP32[$41>>2] = $40;
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1314528);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctorP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1314880)|0);
 $0 = HEAP32[((1314880 + 84|0))>>2]|0;
 $1 = (__Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_DisposeP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyStateP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1314880)|0);
 $0 = HEAP32[((1314880 + 84|0))>>2]|0;
 __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNextP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1314880)|0);
 $0 = HEAP32[((1314880 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_CurrentP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315024);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$__this>>2]|0;
  $3 = (($2) + 84|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 116|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   $16 = $5;
   $15 = (($16) + 80|0);
   $17 = HEAP32[$15>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = (($__this) + 8|0);
   HEAP32[$19>>2] = $18;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,($5|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   invoke_vi(3809,($5|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $$pre = HEAP32[$__this>>2]|0;
    $$phi$trans$insert = (($$pre) + 84|0);
    $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
    $$pre2 = HEAP32[$$pre1>>2]|0;
    $16 = $$pre2;
    $15 = (($16) + 80|0);
    $17 = HEAP32[$15>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__this) + 8|0);
    HEAP32[$19>>2] = $18;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __ZL11RuntimeInitP8TypeInfo1058($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315072);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = (($2) + 84|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   invoke_vii($8|0,($__this|0),($collection|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP32[$__this>>2]|0;
    $12 = (($11) + 84|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 8|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii(2735,($collection|0),($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = ($16|0)==(0|0);
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3799,($16|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = HEAP32[$__this>>2]|0;
      $50 = (($49) + 84|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = (($51) + 16|0);
      $53 = HEAP32[$52>>2]|0;
      __THREW__ = 0;
      $54 = (invoke_iii(2736,($53|0),($16|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break;
      }
      $57 = HEAP32[$__this>>2]|0;
      $58 = (($57) + 84|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = (($59) + 20|0);
      $61 = HEAP32[$60>>2]|0;
      __THREW__ = 0;
      $62 = (invoke_iii(2737,($61|0),($54|0))|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
      $65 = (($__this) + 8|0);
      HEAP32[$65>>2] = $62;
      $66 = HEAP32[$__this>>2]|0;
      $67 = (($66) + 84|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (($68) + 24|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = (($70) + 4|0);
      $72 = HEAP32[$71>>2]|0;
      __THREW__ = 0;
      invoke_vii($72|0,($__this|0),($16|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $22 = HEAP32[$__this>>2]|0;
     $23 = (($22) + 84|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = HEAP32[$24>>2]|0;
     $26 = (($25) + 116|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = ($27<<24>>24)==(0);
     if ($28) {
      __THREW__ = 0;
      (invoke_ii(2996,($25|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3809,($25|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      $$pre = HEAP32[$__this>>2]|0;
      $$phi$trans$insert = (($$pre) + 84|0);
      $$pre1 = HEAP32[$$phi$trans$insert>>2]|0;
      $$pre2 = HEAP32[$$pre1>>2]|0;
      $34 = $$pre;$36 = $$pre2;
     } else {
      $34 = $22;$36 = $25;
     }
     $33 = (($34) + 84|0);
     $35 = (($36) + 80|0);
     $37 = HEAP32[$35>>2]|0;
     $38 = HEAP32[$37>>2]|0;
     $39 = (($__this) + 8|0);
     HEAP32[$39>>2] = $38;
     $40 = HEAP32[$33>>2]|0;
     $41 = (($40) + 12|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($42) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     __THREW__ = 0;
     invoke_vii($44|0,($__this|0),($collection|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker0I27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZL10SZArrayNewP8TypeInfoj1061($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315120);
 __THREW__ = 0;
 invoke_v(325);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($capacity|0)>(-1);
    if ($4) {
     $17 = HEAP32[$__this>>2]|0;
     $18 = (($17) + 84|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($19) + 20|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     $22 = (invoke_iii(2737,($21|0),($capacity|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     $25 = (($__this) + 8|0);
     HEAP32[$25>>2] = $22;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2561352|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[3021392>>2]|0;
      __THREW__ = 0;
      invoke_vii(1926,($9|0),($12|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3808,($9|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315168);
 $0 = (($rgctx) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iii(2737,($1|0),0)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $5 = HEAP32[$rgctx>>2]|0;
  $6 = (($5) + 80|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$7>>2] = $2;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp;
 $L_1 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315216);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii($6|0,($L_0|0),($__this|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;
 $9 = HEAP32[$__this>>2]|0;
 $10 = (($9) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 32|0);
 $13 = HEAP32[$12>>2]|0;
 __THREW__ = 0;
 $14 = (invoke_iii(2724,($13|0),($L_1|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($14|0);
 }
 return 0|0;
}
function __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315264);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(55,(0|0),($1|0),0,($_____array|0),($arrayIndex|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315312);
 __THREW__ = 0;
 invoke_v(326);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = (($2) + 84|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 36|0);
   $6 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(2738,($item|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[$__this>>2]|0;
    $11 = (($10) + 84|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 40|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_viii(2113,($14|0),($__this|0),($7|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = (($__this) + 12|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + -1)|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($19|0);
    }
   }
   $22 = ___cxa_find_matching_catch(348288|0)|0;
   $23 = tempRet0;
   $24 = (_llvm_eh_typeid_for((348288|0))|0);
   $25 = ($23|0)==($24|0);
   if (!($25)) {
    $$02 = $22;$$03 = $23;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
   $26 = (___cxa_begin_catch(($22|0))|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   __THREW__ = 0;
   $29 = (invoke_iii(2727,(2623248|0),($28|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   do {
    if (!($31)) {
     if (!($29)) {
      $36 = HEAP32[$26>>2]|0;
      $37 = HEAP32[$36>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_iii(2727,(2607384|0),($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      if (!($38)) {
       $41 = (___cxa_allocate_exception(4)|0);
       $42 = HEAP32[$26>>2]|0;
       HEAP32[$41>>2] = $42;
       __THREW__ = 0;
       invoke_viii(1567,($41|0),(348288|0),(0|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_v(66);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break L1;
     }
     __THREW__ = 0;
     $49 = (invoke_ii(3469,(2560072|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     }
     $52 = HEAP32[3021408>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($49|0),($52|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3808,($49|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $57 = ___cxa_find_matching_catch(0|0)|0;
    $58 = tempRet0;
    ___clang_call_terminate($57);
    // unreachable;
   } else {
    $$02 = $32;$$03 = $33;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $$02 = $20;$$03 = $21;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo1062($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN18VirtActionInvoker1I28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($4,$p1);
 STACKTOP = sp;return;
}
function __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315360);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iii(2738,($item|0),($4|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $8 = HEAP32[$__this>>2]|0;
  $9 = (($8) + 84|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 44|0);
  $12 = HEAP32[$11>>2]|0;
  __THREW__ = 0;
  $13 = (invoke_iiii(1644,($12|0),($__this|0),($5|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $$0 = $13;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $16 = ___cxa_find_matching_catch(348288|0)|0;
 $17 = tempRet0;
 $18 = (_llvm_eh_typeid_for((348288|0))|0);
 $19 = ($17|0)==($18|0);
 if (!($19)) {
  $$02 = $17;$$03 = $16;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 $20 = (___cxa_begin_catch(($16|0))|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 __THREW__ = 0;
 $23 = (invoke_iii(2727,(2623248|0),($22|0))|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if (!($25)) {
   if (!($23)) {
    $30 = HEAP32[$20>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii(2727,(2607384|0),($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    if (!($32)) {
     $35 = (___cxa_allocate_exception(4)|0);
     $36 = HEAP32[$20>>2]|0;
     HEAP32[$35>>2] = $36;
     __THREW__ = 0;
     invoke_viii(1567,($35|0),(348288|0),(0|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $41 = ___cxa_find_matching_catch()|0;
   $42 = tempRet0;
   $$02 = $42;$$03 = $41;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $43 = ___cxa_find_matching_catch(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  $$02 = $27;$$03 = $26;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315408);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iii(2738,($item|0),($4|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $8 = HEAP32[$__this>>2]|0;
  $9 = (($8) + 84|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 48|0);
  $12 = HEAP32[$11>>2]|0;
  __THREW__ = 0;
  $13 = (invoke_iiii(1647,($12|0),($__this|0),($5|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $$0 = $13;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $16 = ___cxa_find_matching_catch(348288|0)|0;
 $17 = tempRet0;
 $18 = (_llvm_eh_typeid_for((348288|0))|0);
 $19 = ($17|0)==($18|0);
 if (!($19)) {
  $$02 = $17;$$03 = $16;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 $20 = (___cxa_begin_catch(($16|0))|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 __THREW__ = 0;
 $23 = (invoke_iii(2727,(2623248|0),($22|0))|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if (!($25)) {
   if (!($23)) {
    $30 = HEAP32[$20>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii(2727,(2607384|0),($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    if (!($32)) {
     $35 = (___cxa_allocate_exception(4)|0);
     $36 = HEAP32[$20>>2]|0;
     HEAP32[$35>>2] = $36;
     __THREW__ = 0;
     invoke_viii(1567,($35|0),(348288|0),(0|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $$0 = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $41 = ___cxa_find_matching_catch()|0;
   $42 = tempRet0;
   $$02 = $42;$$03 = $41;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $43 = ___cxa_find_matching_catch(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  $$02 = $27;$$03 = $26;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315456);
 __THREW__ = 0;
 invoke_v(327);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = (($2) + 84|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 52|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   invoke_vii($8|0,($__this|0),($index|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP32[$__this>>2]|0;
    $12 = (($11) + 84|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 36|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii(2738,($item|0),($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[$__this>>2]|0;
     $20 = (($19) + 84|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($21) + 56|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_viiii(463,($23|0),($__this|0),($index|0),($16|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
    $28 = ___cxa_find_matching_catch(348288|0)|0;
    $29 = tempRet0;
    $30 = (_llvm_eh_typeid_for((348288|0))|0);
    $31 = ($29|0)==($30|0);
    if (!($31)) {
     $$0 = $28;$$02 = $29;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
    $32 = (___cxa_begin_catch(($28|0))|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    __THREW__ = 0;
    $35 = (invoke_iii(2727,(2623248|0),($34|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    do {
     if (!($37)) {
      if (!($35)) {
       $42 = HEAP32[$32>>2]|0;
       $43 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       $44 = (invoke_iii(2727,(2607384|0),($43|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       if (!($44)) {
        $47 = (___cxa_allocate_exception(4)|0);
        $48 = HEAP32[$32>>2]|0;
        HEAP32[$47>>2] = $48;
        __THREW__ = 0;
        invoke_viii(1567,($47|0),(348288|0),(0|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break L1;
      }
      __THREW__ = 0;
      $55 = (invoke_ii(3469,(2560072|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break L1;
      }
      $58 = HEAP32[3021432>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($55|0),($58|0));
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3808,($55|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L1;
      }
      // unreachable;
     }
    } while(0);
    $38 = ___cxa_find_matching_catch()|0;
    $39 = tempRet0;
    __THREW__ = 0;
    invoke_v(66);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     $63 = ___cxa_find_matching_catch(0|0)|0;
     $64 = tempRet0;
     ___clang_call_terminate($63);
     // unreachable;
    } else {
     $$0 = $38;$$02 = $39;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 $$0 = $26;$$02 = $27;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN18VirtActionInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPviP22mscorlib_System_Object($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315504);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iii(2738,($item|0),($4|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $8 = HEAP32[$__this>>2]|0;
  $9 = (($8) + 84|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 60|0);
  $12 = HEAP32[$11>>2]|0;
  __THREW__ = 0;
  (invoke_iiii(1644,($12|0),($__this|0),($5|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $15 = ___cxa_find_matching_catch(348288|0)|0;
 $16 = tempRet0;
 $17 = (_llvm_eh_typeid_for((348288|0))|0);
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $$01 = $15;$$02 = $16;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$01|0);
  // unreachable;
 }
 $19 = (___cxa_begin_catch(($15|0))|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 __THREW__ = 0;
 $22 = (invoke_iii(2727,(2623248|0),($21|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 do {
  if (!($24)) {
   if (!($22)) {
    $29 = HEAP32[$19>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iii(2727,(2607384|0),($30|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    if (!($31)) {
     $34 = (___cxa_allocate_exception(4)|0);
     $35 = HEAP32[$19>>2]|0;
     HEAP32[$34>>2] = $35;
     __THREW__ = 0;
     invoke_viii(1567,($34|0),(348288|0),(0|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $$01 = $40;$$02 = $41;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  $$01 = $25;$$02 = $26;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315552);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315600);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315648);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iiii(1648,($4|0),($__this|0),($index|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker1I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315696);
 __THREW__ = 0;
 invoke_v(328);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = (($2) + 84|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 36|0);
   $6 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(2738,($value|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[$__this>>2]|0;
    $11 = (($10) + 84|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + 68|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_viiii(463,($14|0),($__this|0),($index|0),($7|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   $19 = ___cxa_find_matching_catch(348288|0)|0;
   $20 = tempRet0;
   $21 = (_llvm_eh_typeid_for((348288|0))|0);
   $22 = ($20|0)==($21|0);
   if (!($22)) {
    $$0 = $19;$$02 = $20;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $23 = (___cxa_begin_catch(($19|0))|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   $26 = (invoke_iii(2727,(2623248|0),($25|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   do {
    if (!($28)) {
     if (!($26)) {
      $33 = HEAP32[$23>>2]|0;
      $34 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      $35 = (invoke_iii(2727,(2607384|0),($34|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      if (!($35)) {
       $38 = (___cxa_allocate_exception(4)|0);
       $39 = HEAP32[$23>>2]|0;
       HEAP32[$38>>2] = $39;
       __THREW__ = 0;
       invoke_viii(1567,($38|0),(348288|0),(0|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_v(66);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break L1;
     }
     __THREW__ = 0;
     $46 = (invoke_ii(3469,(2560072|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break L1;
     }
     $49 = HEAP32[3021344>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($46|0),($49|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3808,($46|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $29 = ___cxa_find_matching_catch()|0;
   $30 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $54 = ___cxa_find_matching_catch(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   } else {
    $$0 = $29;$$02 = $30;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $$0 = $17;$$02 = $18;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315744);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($3) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($1|0)==($7|0);
   if ($8) {
    $11 = HEAP32[$__this>>2]|0;
    $12 = (($11) + 84|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = (($13) + 72|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = (($15) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_vii($17|0,($__this|0),1);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
   }
   $20 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $23 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = (($23) + 1)|0;
     HEAP32[$0>>2] = $26;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = ($23|0)<(0);
      if ($29) {
       label = 10;
      } else {
       $30 = (($20) + 12|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($23>>>0)<($31>>>0);
       if (!($32)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $33 = (invoke_i(132)|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($33|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
      }
      $38 = HEAP32[$20>>2]|0;
      $39 = (($20) + 16|0);
      $40 = (($38) + 92|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = Math_imul($41, $23)|0;
      $43 = (($39) + ($42)|0);
      HEAP32[$43>>2] = $item;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       $46 = (($__this) + 16|0);
       $47 = HEAP32[$46>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        $50 = (($47) + 1)|0;
        HEAP32[$46>>2] = $50;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315792);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($newCount))|0;
 $3 = (($__this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = (($4) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($2|0)>($8|0);
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  $12 = HEAP32[$__this>>2]|0;
  $13 = (($12) + 84|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + 76|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 4|0);
  $18 = HEAP32[$17>>2]|0;
  __THREW__ = 0;
  $19 = (invoke_ii($18|0,($__this|0))|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   $22 = $19 << 1;
   __THREW__ = 0;
   $23 = (invoke_iiii(1197,(0|0),($22|0),4)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    __THREW__ = 0;
    $26 = (invoke_iiii(1197,(0|0),($23|0),($2|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = HEAP32[$__this>>2]|0;
     $30 = (($29) + 84|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = (($31) + 80|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($33) + 4|0);
     $35 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     invoke_vii($35|0,($__this|0),($26|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315840);
 __THREW__ = 0;
 invoke_vi(3799,($collection|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$__this>>2]|0;
  $3 = (($2) + 84|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  $7 = (invoke_iii(2736,($6|0),($collection|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = ($7|0)==(0);
   if ($10) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $13 = HEAP32[$__this>>2]|0;
   $14 = (($13) + 84|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + 72|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   __THREW__ = 0;
   invoke_vii($19|0,($__this|0),($7|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = (($__this) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($__this) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($collection|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = HEAP32[$__this>>2]|0;
     $29 = (($28) + 84|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($30) + 84|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_viiii(464,($32|0),($collection|0),($23|0),($25|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       $37 = HEAP32[$24>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        $40 = (($37) + ($7))|0;
        HEAP32[$24>>2] = $40;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __ZN23InterfaceActionInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS5_i($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var $$0 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond2 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315888);
 __THREW__ = 0;
 invoke_vi(3799,($enumerable|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = (($2) + 84|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 88|0);
   $6 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(2739,($6|0),($enumerable|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($7|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 11;
      break;
     }
     __THREW__ = 0;
     $29 = (invoke_iii(2741,(2176240|0),($7|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 11;
      break;
     }
     if (!($29)) {
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 44;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($7|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      label = 11;
      break;
     }
     $12 = HEAP32[$__this>>2]|0;
     $13 = (($12) + 84|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($14) + 92|0);
     $16 = HEAP32[$15>>2]|0;
     __THREW__ = 0;
     $17 = (invoke_iii(2740,($16|0),($7|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      label = 11;
      break;
     }
     $20 = HEAP32[$__this>>2]|0;
     $21 = (($20) + 84|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($22) + 40|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_viii(2113,($24|0),($__this|0),($17|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 11;
      break;
     }
    }
    if ((label|0) == 11) {
     $34 = ___cxa_find_matching_catch(348288|0)|0;
     $35 = tempRet0;
     $36 = (_llvm_eh_typeid_for((348288|0))|0);
     $37 = ($35|0)==($36|0);
     if (!($37)) {
      $$0 = $34;$$03 = $35;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$0|0);
      // unreachable;
     }
     $38 = (___cxa_begin_catch(($34|0))|0);
     $39 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     invoke_v(66);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     $__last_unhandled_exception$0 = $39;$leaveInstructions$sroa$0$0 = 0;
    }
    $42 = ($7|0)==(0|0);
    if ($42) {
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(44);
     if ($cond1) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3808,($__last_unhandled_exception$0|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(3799,($7|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     __THREW__ = 0;
     invoke_vii(3491,(2176768|0),($7|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if (!($48)) {
      $cond2 = ($leaveInstructions$sroa$0$0|0)==(44);
      if ($cond2) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3808,($__last_unhandled_exception$0|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if (!($50)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker0I17VoidPointerTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN21InterfaceFuncInvoker0I28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN21InterfaceFuncInvoker0I29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315936);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii($6|0,($__this|0),($collection|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   $9 = HEAP32[$__this>>2]|0;
   $10 = (($9) + 84|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($11) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   __THREW__ = 0;
   $14 = (invoke_iii(2735,($collection|0),($13|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = ($14|0)==(0|0);
    $18 = HEAP32[$__this>>2]|0;
    $19 = (($18) + 84|0);
    $20 = HEAP32[$19>>2]|0;
    if ($17) {
     $29 = (($20) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = (($30) + 4|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii($32|0,($__this|0),($collection|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
    } else {
     $23 = (($20) + 24|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($24) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     __THREW__ = 0;
     invoke_vii($26|0,($__this|0),($14|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $37 = (($__this) + 16|0);
     $38 = HEAP32[$37>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = (($38) + 1)|0;
      HEAP32[$37>>2] = $41;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1315984);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($1|0),0,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($__this) + 12|0);
   HEAP32[$8>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($__this) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = (($12) + 1)|0;
     HEAP32[$11>>2] = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316032);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$__this>>2]|0;
 $5 = (($4) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 96|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiiiii($10|0,(0|0),($1|0),($item|0),0,($3|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $14 = ($11|0)!=(-1);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($14|0);
 }
 return 0|0;
}
function __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316080);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(55,(0|0),($1|0),0,($_____array|0),($arrayIndex|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GetEnumeratorP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316128);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3496,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316176);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$__this>>2]|0;
 $5 = (($4) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 96|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiiiii($10|0,(0|0),($1|0),($item|0),0,($3|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $start$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316224);
 $0 = ($delta|0)>(-1);
 $1 = $0 ? 0 : $delta;
 $start$ = (($start) - ($1))|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($start$|0)<($3|0);
 if ($4) {
  $5 = (($__this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($start$) + ($delta))|0;
  $8 = (($3) - ($start$))|0;
  __THREW__ = 0;
  invoke_viiiiii(55,(0|0),($6|0),($start$|0),($6|0),($7|0),($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP32[$2>>2]|0;
   $14 = (($13) + ($delta))|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    HEAP32[$2>>2] = $14;
    if ($0) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (0 - ($delta))|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($20|0),($14|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316272);
 __THREW__ = 0;
 invoke_v(329);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($index|0)<(0);
  if (!($2)) {
   $5 = (($__this) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)<($index|0);
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_ii(3469,(2561352|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[3021448>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_vi(3808,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316320);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii($6|0,($__this|0),($index|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   $9 = (($__this) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($__this) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = (($12) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($10|0)==($16|0);
    if ($17) {
     $20 = HEAP32[$__this>>2]|0;
     $21 = (($20) + 84|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($22) + 72|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($24) + 4|0);
     $26 = HEAP32[$25>>2]|0;
     __THREW__ = 0;
     invoke_vii($26|0,($__this|0),1);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
    }
    $29 = HEAP32[$__this>>2]|0;
    $30 = (($29) + 84|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + 104|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    __THREW__ = 0;
    invoke_viii($35|0,($__this|0),($index|0),1);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     $38 = HEAP32[$11>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($38|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = ($index|0)<(0);
      if ($41) {
       label = 10;
      } else {
       $42 = (($38) + 12|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = ($43>>>0)>($index>>>0);
       if (!($44)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $45 = (invoke_i(132)|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($45|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
      }
      $50 = HEAP32[$38>>2]|0;
      $51 = (($38) + 16|0);
      $52 = (($50) + 92|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = Math_imul($53, $index)|0;
      $55 = (($51) + ($54)|0);
      HEAP32[$55>>2] = $item;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if (!($57)) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$58>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if (!($61)) {
        $62 = (($59) + 1)|0;
        HEAP32[$58>>2] = $62;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316368);
 __THREW__ = 0;
 invoke_v(330);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($collection|0)==(0|0);
  if (!($2)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3021464>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3808,($7|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316416);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iiii(1647,($4|0),($__this|0),($item|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 $8 = ($5|0)==(-1);
 if ($8) {
  $18 = $8 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($18|0);
 }
 $11 = HEAP32[$__this>>2]|0;
 $12 = (($11) + 84|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 108|0);
 $15 = HEAP32[$14>>2]|0;
 __THREW__ = 0;
 invoke_viii(2111,($15|0),($__this|0),($5|0));
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $18 = $8 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($18|0);
 }
 return 0|0;
}
function __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316464);
 __THREW__ = 0;
 invoke_v(331);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($index|0)<(0);
   if (!($2)) {
    $5 = (($__this) + 12|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)>($index|0);
    if ($7) {
     $18 = HEAP32[$__this>>2]|0;
     $19 = (($18) + 84|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (($20) + 104|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($22) + 4|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_viii($24|0,($__this|0),($index|0),-1);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = (($__this) + 8|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = HEAP32[$5>>2]|0;
     __THREW__ = 0;
     invoke_viiii(138,(0|0),($28|0),($29|0),1);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $34 = (($__this) + 16|0);
     $35 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     $38 = (($35) + 1)|0;
     HEAP32[$34>>2] = $38;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3021504>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3808,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316512);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$__this>>2]|0;
 $3 = (($2) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_iii(2737,($6|0),($1|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 }
 $10 = (($__this) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_viiii(140,(0|0),($11|0),($7|0),($12|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($7|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316560);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316608);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>($value|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2561352|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2587,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3808,($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 } else {
  $14 = (($__this) + 8|0);
  $15 = HEAP32[$__this>>2]|0;
  $16 = (($15) + 84|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + 112|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($19) + 4|0);
  $21 = HEAP32[$20>>2]|0;
  __THREW__ = 0;
  invoke_viii($21|0,(0|0),($14|0),($value|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if (!($23)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316656);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316704);
 __THREW__ = 0;
 invoke_v(332);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>($index|0);
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2561352|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021360>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = ($index|0)<(0);
    if (!($21)) {
     $22 = (($18) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23>>>0)>($index>>>0);
     if ($24) {
      $30 = HEAP32[$18>>2]|0;
      $31 = (($18) + 16|0);
      $32 = (($30) + 92|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = Math_imul($33, $index)|0;
      $35 = (($31) + ($34)|0);
      $36 = HEAP32[$35>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($36|0);
     }
    }
    __THREW__ = 0;
    $25 = (invoke_i(132)|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __THREW__ = 0;
     invoke_vi(3302,($25|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[$18>>2]|0;
      $31 = (($18) + 16|0);
      $32 = (($30) + 92|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = Math_imul($33, $index)|0;
      $35 = (($31) + ($34)|0);
      $36 = HEAP32[$35>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($36|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1316752);
 __THREW__ = 0;
 invoke_v(333);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = (($2) + 84|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 52|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($6) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   invoke_vii($8|0,($__this|0),($index|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($__this) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($index|0);
    if ($13) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     $18 = (invoke_ii(3469,(2561352|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     $21 = HEAP32[3021376>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($18|0),($21|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3808,($18|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     // unreachable;
    }
    $26 = (($__this) + 8|0);
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($index|0)<(0);
     if (!($30)) {
      $31 = (($27) + 12|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($32>>>0)>($index>>>0);
      if ($33) {
       $39 = HEAP32[$27>>2]|0;
       $40 = (($27) + 16|0);
       $41 = (($39) + 92|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = Math_imul($42, $index)|0;
       $44 = (($40) + ($43)|0);
       HEAP32[$44>>2] = $value;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
     __THREW__ = 0;
     $34 = (invoke_i(132)|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      __THREW__ = 0;
      invoke_vi(3302,($34|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = HEAP32[$27>>2]|0;
       $40 = (($27) + 16|0);
       $41 = (($39) + 92|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = Math_imul($42, $index)|0;
       $44 = (($40) + ($43)|0);
       HEAP32[$44>>2] = $value;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __ZL94mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_VoidP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL146mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1318616)|0);
 $0 = HEAP32[((1318616 + 84|0))>>2]|0;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv(0,$0);
 STACKTOP = sp;return;
}
function __ZL131mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyToP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_AddP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEPFiPvP22mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_ContainsP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsE6InvokeEPFbPvP22mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL100mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOfP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_InsertP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEPFvPviP22mscorlib_System_ObjectES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$3);
 STACKTOP = sp;return (0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_RemoveP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker1I28mscorlib_System_ObjectTraitsE6InvokeEPFvPvP22mscorlib_System_ObjectES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$0);
 STACKTOP = sp;return (0|0);
}
function __ZL132mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 0;
}
function __ZL111mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRootP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEPFP22mscorlib_System_ObjectPviES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL71mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeededP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollectionP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerableP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRangeP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ClearP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ContainsP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyToP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I82mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectTraitsE6InvokeEPF76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1314880,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOfP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ShiftP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32TraitsS0_E6InvokeEPFvPviiES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$4);
 STACKTOP = sp;return (0|0);
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndexP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_InsertP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollectionP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object(0,$collection);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAtP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArrayP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_CapacityP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_CapacityP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value);
 STACKTOP = sp;return;
}
function __ZL77mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_CountP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1318760);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1318808);
 $0 = (($rgctx) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_ii(3469,($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 }
 $5 = (($rgctx) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_vi($8|0,($2|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $11 = (($rgctx) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 80|0);
  $14 = HEAP32[$13>>2]|0;
  HEAP32[$14>>2] = $2;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1318856);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iii(2738,($obj|0),($4|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 }
 $8 = HEAP32[$__this>>2]|0;
 $9 = (($8) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 $13 = (invoke_iiii(1647,($12|0),($__this|0),($5|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($13|0);
 }
 return 0|0;
}
function __Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1318904);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iii(2738,($x|0),($4|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  $8 = HEAP32[$__this>>2]|0;
  $9 = (($8) + 84|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  __THREW__ = 0;
  $13 = (invoke_iii(2738,($y|0),($12|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $16 = HEAP32[$__this>>2]|0;
   $17 = (($16) + 84|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (($18) + 32|0);
   $20 = HEAP32[$19>>2]|0;
   __THREW__ = 0;
   $21 = (invoke_iiiii(300,($20|0),($__this|0),($5|0),($13|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($24|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1318952);
 $0 = (($rgctx) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 116|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 do {
  if ($4) {
   __THREW__ = 0;
   (invoke_ii(2996,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if ($6) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($9|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3809,($1|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($9|0);
    // unreachable;
   } else {
    $$pre = HEAP32[$0>>2]|0;
    $12 = $$pre;
    break;
   }
  } else {
   $12 = $1;
  }
 } while(0);
 $11 = (($12) + 80|0);
 $13 = HEAP32[$11>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($14|0);
}
function __ZL85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctorP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1319584)|0);
 $0 = HEAP32[((1319584 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv(0,$0);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCodeP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL123mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_EqualsP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFbPvP22mscorlib_System_ObjectS5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 $4 = $3&1;
 HEAP8[$ret>>0] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZL91mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1319584)|0);
 $0 = HEAP32[((1319584 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv(0,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m__ctorP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m_System_Collections_IEnumerator_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1321040)|0);
 $0 = HEAP32[((1321040 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m_DisposeP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m_MoveNextP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1321040)|0);
 $0 = HEAP32[((1321040 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1322584);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vi($6|0,($__this|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1322632);
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($obj|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2729,(2148880|0),($obj|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $$0 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1322680);
 $0 = ($x|0)==(0|0);
 if ($0) {
  $1 = ($y|0)==(0|0);
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($x|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1644,(2148736|0),($x|0),($y|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $$0 = $4;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZL101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctorP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCodeP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object(0,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_EqualsP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_(0,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z89mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_GetEnumeratorP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1323320);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3496,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL102mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_VoidP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL154mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1326240)|0);
 $0 = HEAP32[((1326240 + 84|0))>>2]|0;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv(0,$0);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_CopyToP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_AddP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_ContainsP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_IndexOfP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_InsertP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_RemoveP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL140mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 0;
}
function __ZL119mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_get_SyncRootP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_get_ItemP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_set_ItemP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_AddP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_GrowIfNeededP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_AddCollectionP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_AddEnumerableP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_AddRangeP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_ClearP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_ContainsP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL82mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_CopyToP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP34AssemblyU002DCSharp_JSONObject_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I90mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPF84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1314144,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL83mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_IndexOfP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPFiPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZL81mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_ShiftP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_CheckIndexP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_InsertP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectiP30AssemblyU002DCSharp_JSONObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_CheckCollectionP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object(0,$collection);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_RemoveP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_RemoveAtP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_ToArrayP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_get_CapacityP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_set_CapacityP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_get_CountP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_get_ItemP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_set_ItemP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectiP30AssemblyU002DCSharp_JSONObject($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1327720)|0);
 $0 = HEAP32[((1327720 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1327720)|0);
 $0 = HEAP32[((1327720 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m__ctorP85mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1329048)|0);
 $0 = HEAP32[((1329048 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv(0,$0);
 STACKTOP = sp;return;
}
function __ZL136mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IEqualityComparer_GetHashCodeP85mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL131mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IEqualityComparer_EqualsP85mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1329048)|0);
 $0 = HEAP32[((1329048 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv(0,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObject_m__ctorP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObject_m_GetHashCodeP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object(0,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObject_m_EqualsP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_(0,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_E6InvokeEPFbPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 $4 = $3&1;
 HEAP8[$ret>>0] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_GetEnumeratorP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1330216);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3496,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL84mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m__ctorP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_StringP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m__ctor_mscorlib_System_VoidP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL146mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1333136)|0);
 $0 = HEAP32[((1333136 + 84|0))>>2]|0;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv(0,$0);
 STACKTOP = sp;return;
}
function __ZL131mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_ICollection_CopyToP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_AddP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_ContainsP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_IndexOfP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_InsertP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_RemoveP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 0;
}
function __ZL111mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_ICollection_get_SyncRootP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_get_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_set_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL71mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_AddP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_GrowIfNeededP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_AddCollectionP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_AddEnumerableP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_AddRangeP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_ClearP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_ContainsP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_CopyToP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP26mscorlib_System_String_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I82mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_StringTraitsE6InvokeEPF76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_StringPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1333872,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_IndexOfP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_ShiftP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_CheckIndexP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_InsertP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringiP22mscorlib_System_String($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_CheckCollectionP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object(0,$collection);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_RemoveP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_RemoveAtP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_ToArrayP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_get_CapacityP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_set_CapacityP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value);
 STACKTOP = sp;return;
}
function __ZL77mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_get_CountP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_get_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_set_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringiP22mscorlib_System_String($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1333872)|0);
 $0 = HEAP32[((1333872 + 84|0))>>2]|0;
 $1 = (__Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_DisposeP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_VerifyStateP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1333872)|0);
 $0 = HEAP32[((1333872 + 84|0))>>2]|0;
 __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_MoveNextP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1333872)|0);
 $0 = HEAP32[((1333872 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_get_CurrentP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m__ctorP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1334656)|0);
 $0 = HEAP32[((1334656 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv(0,$0);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m_System_Collections_IEqualityComparer_GetHashCodeP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_StringP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL123mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m_System_Collections_IEqualityComparer_EqualsP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_StringP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL91mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1334656)|0);
 $0 = HEAP32[((1334656 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv(0,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_String_m__ctorP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_String_m_GetHashCodeP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_StringP22mscorlib_System_String($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object(0,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_String_m_EqualsP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_StringP22mscorlib_System_StringS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_(0,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z222mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1335824);
 __THREW__ = 0;
 $0 = (invoke_ii(3470,($keyValuePair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3471,($keyValuePair|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viiii(460,(1335872|0),($__this|0),($0|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __ZL115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_KeyP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_ValueP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z227mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1335920);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(291,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ContainsKeyValuePairP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$pair) {
 $__this = $__this|0;
 $pair = $pair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1336112);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(3470,($pair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiii(299,(1336160|0),($__this|0),($0|0),($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   if (!($3)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_ii(801,(0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3471,($pair|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP32[$V_0>>2]|0;
      __THREW__ = 0;
      $17 = (invoke_iiiii(299,(1334360|0),($8|0),($11|0),($16|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z225mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1335968);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(291,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  if (!($11)) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $16 = (invoke_ii(3470,($keyValuePair|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iiii(1640,(1336016|0),($__this|0),($16|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_make_pairP22mscorlib_System_ObjectP22mscorlib_System_StringS2_($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1336064);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(327,($agg$result|0),($key|0),($value|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1360328)|0);
 $0 = HEAP32[((1360328 + 84|0))>>2]|0;
 __Z121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_PPv($__this,$key,$value,$0);
 STACKTOP = sp;return;
}
function __Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1336208);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3497,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctor_mscorlib_System_VoidP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL193mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z201mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKey_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$comparer);
 STACKTOP = sp;return;
}
function __ZL154mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Stringi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z162mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_ICollection_get_SyncRootP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnly_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 0;
}
function __ZN14ActionInvoker1I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPFvPv105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPFbPv105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZL225mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_StringU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL143mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_ICollection_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z151mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z240mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL150mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IDictionary_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z158mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionary_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CountP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_set_ItemP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Item_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_InitP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringiP22mscorlib_System_Object($__this,$capacity,$hcp) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $hcp = $hcp|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Init_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$hcp);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_InitArraysP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Stringi($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitArrays_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$size);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_CopyToCheckP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToCheck_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraits17VoidPointerTraitsS1_E6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringPvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1360328,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_pick_valueP22mscorlib_System_ObjectP22mscorlib_System_StringS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_pick_value_gsharedP22mscorlib_System_ObjectS0_S0_(0,0,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraitsS0_S0_E6InvokeEPFPvS2_S2_S2_ES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_StringU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ResizeP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Resize_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_AddP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Add_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ClearP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Clear_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ContainsValueP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_GetObjectDataP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetObjectData_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker2I17VoidPointerTraits60mscorlib_System_Runtime_Serialization_StreamingContextTraitsE6InvokeEPFvPvS3_54mscorlib_System_Runtime_Serialization_StreamingContextES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_RemoveP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Remove_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$key)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_TryGetValueP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringPS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_TryGetValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectPS2_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_ValuesP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Values_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker0I120mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPF114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1364424,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP22mscorlib_System_StringS2_($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1339880)|0);
 __Z134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_U003CCopyToU003Em__0_gsharedP22mscorlib_System_ObjectS0_S0_PPv($agg$result,0,$key,$value,0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraitsS1_E6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2307216,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340024);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$__this>>2]|0;
  $3 = (($2) + 84|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_viii($7|0,($__this|0),10,(0|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z201mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKey_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340072);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$__this>>2]|0;
  $3 = (($2) + 84|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_viii($7|0,($__this|0),10,($comparer|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z162mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340120);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$__this>>2]|0;
  $3 = (($2) + 84|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_viii($7|0,($__this|0),($capacity|0),(0|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340168);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnly_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340216);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z222mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340264);
 __THREW__ = 0;
 $0 = (invoke_ii(3470,($keyValuePair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3471,($keyValuePair|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viiii(465,(1340312|0),($__this|0),($0|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __ZL115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_KeyP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_ValueP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN18VirtActionInvoker2I28mscorlib_System_ObjectTraitsS0_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS6_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z227mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340360);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(297,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsKeyValuePairP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$pair) {
 $__this = $__this|0;
 $pair = $pair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341368);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(3470,($pair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiii(301,(1341272|0),($__this|0),($0|0),($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   if (!($3)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_ii(778,(0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3471,($pair|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP32[$V_0>>2]|0;
      __THREW__ = 0;
      $17 = (invoke_iiiii(300,(1319296|0),($8|0),($11|0),($16|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340408);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_viii($6|0,($__this|0),($_____array|0),($index|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z225mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340456);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(297,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  if (!($11)) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $16 = (invoke_ii(3470,($keyValuePair|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iiii(1644,(1340504|0),($__this|0),($16|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z151mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy1 = 0, $$phi$trans$insert = 0, $$phi$trans$insert4 = 0, $$phi$trans$insert6 = 0, $$phi$trans$insert9 = 0, $$pre = 0, $$pre11 = 0, $$pre3 = 0, $$pre5 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340552);
 $2 = HEAP32[$__this>>2]|0;
 $3 = (($2) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_iii(2735,($_____array|0),($6|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if (!($9)) {
   $10 = ($7|0)==(0|0);
   $11 = HEAP32[$__this>>2]|0;
   $12 = (($11) + 84|0);
   $13 = HEAP32[$12>>2]|0;
   if (!($10)) {
    $16 = (($13) + 20|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 4|0);
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    invoke_viii($19|0,($__this|0),($7|0),($index|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $22 = (($13) + 32|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = (($23) + 4|0);
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   invoke_viii($25|0,($__this|0),($_____array|0),($index|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1171160|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     __THREW__ = 0;
     $30 = (invoke_iii(2735,($_____array|0),(1171160|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $33 = ($30|0)==(0|0);
      $34 = HEAP32[$__this>>2]|0;
      $35 = (($34) + 84|0);
      $36 = HEAP32[$35>>2]|0;
      if ($33) {
       $80 = (($36) + 56|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = (($36) + 60|0);
       $83 = HEAP32[$82>>2]|0;
       __THREW__ = 0;
       $84 = (invoke_ii(3469,($83|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       $87 = HEAP32[$__this>>2]|0;
       $88 = (($87) + 84|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = (($89) + 64|0);
       $91 = HEAP32[$90>>2]|0;
       $92 = (($91) + 4|0);
       $93 = HEAP32[$92>>2]|0;
       HEAP32[$1>>2] = $81;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_viii($93|0,($84|0),(0|0),($$byval_copy1|0));
       $94 = __THREW__; __THREW__ = 0;
       $95 = $94&1;
       if ($95) {
        break;
       }
       $96 = HEAP32[$__this>>2]|0;
       $97 = (($96) + 84|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = (($98) + 68|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = (($100) + 4|0);
       $102 = HEAP32[$101>>2]|0;
       __THREW__ = 0;
       invoke_viiii($102|0,($__this|0),($_____array|0),($index|0),($84|0));
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $37 = (($36) + 36|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($38) + 80|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + 16|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0|0);
      if ($43) {
       $44 = (($36) + 40|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = (($36) + 44|0);
       $47 = HEAP32[$46>>2]|0;
       __THREW__ = 0;
       $48 = (invoke_ii(3469,($47|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
       $51 = HEAP32[$__this>>2]|0;
       $52 = (($51) + 84|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (($53) + 48|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = (($55) + 4|0);
       $57 = HEAP32[$56>>2]|0;
       HEAP32[$0>>2] = $45;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_viii($57|0,($48|0),(0|0),($$byval_copy1|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
       $60 = HEAP32[$__this>>2]|0;
       $61 = (($60) + 84|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($62) + 36|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = (($64) + 80|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = (($66) + 16|0);
       HEAP32[$67>>2] = $48;
       $$pre = HEAP32[$__this>>2]|0;
       $$phi$trans$insert = (($$pre) + 84|0);
       $$pre3 = HEAP32[$$phi$trans$insert>>2]|0;
       $$phi$trans$insert4 = (($$pre3) + 36|0);
       $$pre5 = HEAP32[$$phi$trans$insert4>>2]|0;
       $$phi$trans$insert6 = (($$pre5) + 80|0);
       $$pre8 = HEAP32[$$phi$trans$insert6>>2]|0;
       $$phi$trans$insert9 = (($$pre8) + 16|0);
       $$pre11 = HEAP32[$$phi$trans$insert9>>2]|0;
       $77 = $$pre11;
      } else {
       $77 = $42;
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if (!($69)) {
       $70 = HEAP32[$__this>>2]|0;
       $71 = (($70) + 84|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = (($72) + 52|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = (($74) + 4|0);
       $76 = HEAP32[$75>>2]|0;
       __THREW__ = 0;
       invoke_viiii($76|0,($__this|0),($30|0),($index|0),($77|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if (!($79)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z240mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340600);
 ;HEAP32[$L_0+0>>2]=0|0;HEAP32[$L_0+4>>2]=0|0;HEAP32[$L_0+8>>2]=0|0;HEAP32[$L_0+12>>2]=0|0;HEAP32[$L_0+16>>2]=0|0;
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 76|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii($6|0,($L_0|0),($__this|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
 $9 = HEAP32[$__this>>2]|0;
 $10 = (($9) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 __THREW__ = 0;
 $14 = (invoke_iii(2724,($13|0),($L_1|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($14|0);
 }
 return 0|0;
}
function __Z158mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionary_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340648);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 80|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_ii(3469,($4|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 $8 = HEAP32[$__this>>2]|0;
 $9 = (($8) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 84|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __THREW__ = 0;
 invoke_vii($14|0,($5|0),($__this|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340696);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Item_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $V_1$0 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_2$2 = 0, $V_2$3 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $V_3$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340744);
 __THREW__ = 0;
 invoke_v(334);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3020568>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[$__this>>2]|0;
    $22 = (($21) + 84|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + 92|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(1649,($25|0),($18|0),($key|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = $26 | -2147483648;
     $30 = $26 & 2147483647;
     $31 = (($__this) + 8|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $35 = (($32) + 12|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($30|0) % ($36|0))&-1;
      $38 = HEAP32[$31>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($38|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = (($38) + 12|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($37>>>0)<($42>>>0);
       if (!($43)) {
        __THREW__ = 0;
        $44 = (invoke_i(132)|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($44|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
       }
       $49 = HEAP32[$38>>2]|0;
       $50 = (($38) + 16|0);
       $51 = (($49) + 92|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = Math_imul($52, $37)|0;
       $54 = (($50) + ($53)|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = (($55) + -1)|0;
       $57 = ($55|0)==(0);
       L18: do {
        if ($57) {
         $V_2$1 = $56;$V_3$1 = -1;
         label = 40;
        } else {
         $58 = (($__this) + 12|0);
         $59 = (($__this) + 16|0);
         $V_2$0 = $56;$V_3$0 = -1;
         while(1) {
          $60 = HEAP32[$58>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($60|0));
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           break;
          }
          $63 = ($V_2$0|0)<(0);
          if ($63) {
           label = 23;
          } else {
           $64 = (($60) + 12|0);
           $65 = HEAP32[$64>>2]|0;
           $66 = ($V_2$0>>>0)<($65>>>0);
           if (!($66)) {
            label = 23;
           }
          }
          if ((label|0) == 23) {
           label = 0;
           __THREW__ = 0;
           $67 = (invoke_i(132)|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($67|0));
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            break;
           }
          }
          $72 = HEAP32[$60>>2]|0;
          $73 = (($60) + 16|0);
          $74 = (($72) + 92|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = Math_imul($75, $V_2$0)|0;
          $77 = (($73) + ($76)|0);
          $78 = HEAP32[$77>>2]|0;
          $79 = ($78|0)==($29|0);
          if ($79) {
           $80 = HEAP32[$17>>2]|0;
           $81 = HEAP32[$59>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($81|0));
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if ($83) {
            break;
           }
           if ($63) {
            label = 29;
           } else {
            $84 = (($81) + 12|0);
            $85 = HEAP32[$84>>2]|0;
            $86 = ($V_2$0>>>0)<($85>>>0);
            if (!($86)) {
             label = 29;
            }
           }
           if ((label|0) == 29) {
            label = 0;
            __THREW__ = 0;
            $87 = (invoke_i(132)|0);
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if ($89) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($87|0));
            $90 = __THREW__; __THREW__ = 0;
            $91 = $90&1;
            if ($91) {
             break;
            }
           }
           $92 = HEAP32[$81>>2]|0;
           $93 = (($81) + 16|0);
           $94 = (($92) + 92|0);
           $95 = HEAP32[$94>>2]|0;
           $96 = Math_imul($95, $V_2$0)|0;
           $97 = (($93) + ($96)|0);
           $98 = HEAP32[$97>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($80|0));
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            break;
           }
           $101 = HEAP32[$__this>>2]|0;
           $102 = (($101) + 84|0);
           $103 = HEAP32[$102>>2]|0;
           $104 = (($103) + 96|0);
           $105 = HEAP32[$104>>2]|0;
           __THREW__ = 0;
           $106 = (invoke_iiiii(302,($105|0),($80|0),($98|0),($key|0))|0);
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if ($108) {
            break;
           }
           if ($106) {
            $V_2$1 = $V_2$0;$V_3$1 = $V_3$0;
            label = 40;
            break L18;
           }
          }
          $109 = HEAP32[$58>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($109|0));
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           break;
          }
          if ($63) {
           label = 37;
          } else {
           $112 = (($109) + 12|0);
           $113 = HEAP32[$112>>2]|0;
           $114 = ($V_2$0>>>0)<($113>>>0);
           if (!($114)) {
            label = 37;
           }
          }
          if ((label|0) == 37) {
           label = 0;
           __THREW__ = 0;
           $115 = (invoke_i(132)|0);
           $116 = __THREW__; __THREW__ = 0;
           $117 = $116&1;
           if ($117) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($115|0));
           $118 = __THREW__; __THREW__ = 0;
           $119 = $118&1;
           if ($119) {
            break;
           }
          }
          $120 = HEAP32[$109>>2]|0;
          $121 = (($109) + 16|0);
          $122 = (($120) + 92|0);
          $123 = HEAP32[$122>>2]|0;
          $124 = Math_imul($123, $V_2$0)|0;
          $$sum = (($124) + 4)|0;
          $125 = (($121) + ($$sum)|0);
          $126 = HEAP32[$125>>2]|0;
          $127 = ($126|0)==(-1);
          if ($127) {
           label = 41;
           break L18;
          } else {
           $V_3$0$phi = $V_2$0;$V_2$0 = $126;$V_3$0 = $V_3$0$phi;
          }
         }
         $3 = ___cxa_find_matching_catch()|0;
         $4 = tempRet0;
         $lpad$phi$index = $3;$lpad$phi$index2 = $4;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
       } while(0);
       if ((label|0) == 40) {
        $128 = ($V_2$1|0)==(-1);
        if ($128) {
         label = 41;
        } else {
         $274 = ($V_3$1|0)==(-1);
         if ($274) {
          $V_2$3 = $V_2$1;
         } else {
          $275 = (($__this) + 12|0);
          $276 = HEAP32[$275>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($276|0));
          $277 = __THREW__; __THREW__ = 0;
          $278 = $277&1;
          if ($278) {
           break;
          }
          $279 = ($V_3$1|0)<(0);
          if ($279) {
           label = 85;
          } else {
           $280 = (($276) + 12|0);
           $281 = HEAP32[$280>>2]|0;
           $282 = ($V_3$1>>>0)<($281>>>0);
           if (!($282)) {
            label = 85;
           }
          }
          if ((label|0) == 85) {
           __THREW__ = 0;
           $283 = (invoke_i(132)|0);
           $284 = __THREW__; __THREW__ = 0;
           $285 = $284&1;
           if ($285) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($283|0));
           $286 = __THREW__; __THREW__ = 0;
           $287 = $286&1;
           if ($287) {
            break;
           }
          }
          $288 = HEAP32[$276>>2]|0;
          $289 = (($276) + 16|0);
          $290 = (($288) + 92|0);
          $291 = HEAP32[$290>>2]|0;
          $292 = Math_imul($291, $V_3$1)|0;
          $293 = HEAP32[$275>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($293|0));
          $294 = __THREW__; __THREW__ = 0;
          $295 = $294&1;
          if ($295) {
           break;
          }
          $296 = ($V_2$1|0)<(0);
          if ($296) {
           label = 90;
          } else {
           $297 = (($293) + 12|0);
           $298 = HEAP32[$297>>2]|0;
           $299 = ($V_2$1>>>0)<($298>>>0);
           if (!($299)) {
            label = 90;
           }
          }
          if ((label|0) == 90) {
           __THREW__ = 0;
           $300 = (invoke_i(132)|0);
           $301 = __THREW__; __THREW__ = 0;
           $302 = $301&1;
           if ($302) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($300|0));
           $303 = __THREW__; __THREW__ = 0;
           $304 = $303&1;
           if ($304) {
            break;
           }
          }
          $305 = HEAP32[$293>>2]|0;
          $306 = (($293) + 16|0);
          $307 = (($305) + 92|0);
          $308 = HEAP32[$307>>2]|0;
          $309 = Math_imul($308, $V_2$1)|0;
          $$sum3 = (($309) + 4)|0;
          $310 = (($306) + ($$sum3)|0);
          $311 = HEAP32[$310>>2]|0;
          $$sum4 = (($292) + 4)|0;
          $312 = (($289) + ($$sum4)|0);
          HEAP32[$312>>2] = $311;
          $313 = HEAP32[$275>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($313|0));
          $314 = __THREW__; __THREW__ = 0;
          $315 = $314&1;
          if ($315) {
           break;
          }
          if ($296) {
           label = 95;
          } else {
           $316 = (($313) + 12|0);
           $317 = HEAP32[$316>>2]|0;
           $318 = ($V_2$1>>>0)<($317>>>0);
           if (!($318)) {
            label = 95;
           }
          }
          if ((label|0) == 95) {
           __THREW__ = 0;
           $319 = (invoke_i(132)|0);
           $320 = __THREW__; __THREW__ = 0;
           $321 = $320&1;
           if ($321) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($319|0));
           $322 = __THREW__; __THREW__ = 0;
           $323 = $322&1;
           if ($323) {
            break;
           }
          }
          $324 = HEAP32[$313>>2]|0;
          $325 = (($313) + 16|0);
          $326 = (($324) + 92|0);
          $327 = HEAP32[$326>>2]|0;
          $328 = Math_imul($327, $V_2$1)|0;
          $329 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($329|0));
          $330 = __THREW__; __THREW__ = 0;
          $331 = $330&1;
          if ($331) {
           break;
          }
          $332 = (($329) + 12|0);
          $333 = HEAP32[$332>>2]|0;
          $334 = ($37>>>0)<($333>>>0);
          if (!($334)) {
           __THREW__ = 0;
           $335 = (invoke_i(132)|0);
           $336 = __THREW__; __THREW__ = 0;
           $337 = $336&1;
           if ($337) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($335|0));
           $338 = __THREW__; __THREW__ = 0;
           $339 = $338&1;
           if ($339) {
            break;
           }
          }
          $340 = HEAP32[$329>>2]|0;
          $341 = (($329) + 16|0);
          $342 = (($340) + 92|0);
          $343 = HEAP32[$342>>2]|0;
          $344 = Math_imul($343, $37)|0;
          $345 = (($341) + ($344)|0);
          $346 = HEAP32[$345>>2]|0;
          $347 = (($346) + -1)|0;
          $$sum5 = (($328) + 4)|0;
          $348 = (($325) + ($$sum5)|0);
          HEAP32[$348>>2] = $347;
          $349 = HEAP32[$31>>2]|0;
          $350 = (($V_2$1) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($349|0));
          $351 = __THREW__; __THREW__ = 0;
          $352 = $351&1;
          if ($352) {
           break;
          }
          $353 = (($349) + 12|0);
          $354 = HEAP32[$353>>2]|0;
          $355 = ($37>>>0)<($354>>>0);
          if (!($355)) {
           __THREW__ = 0;
           $356 = (invoke_i(132)|0);
           $357 = __THREW__; __THREW__ = 0;
           $358 = $357&1;
           if ($358) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($356|0));
           $359 = __THREW__; __THREW__ = 0;
           $360 = $359&1;
           if ($360) {
            break;
           }
          }
          $361 = HEAP32[$349>>2]|0;
          $362 = (($349) + 16|0);
          $363 = (($361) + 92|0);
          $364 = HEAP32[$363>>2]|0;
          $365 = Math_imul($364, $37)|0;
          $366 = (($362) + ($365)|0);
          HEAP32[$366>>2] = $350;
          $V_2$3 = $V_2$1;
         }
        }
       }
       if ((label|0) == 41) {
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         break;
        }
        $131 = (($__this) + 32|0);
        $132 = HEAP32[$131>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         break;
        }
        $135 = (($132) + 1)|0;
        HEAP32[$131>>2] = $135;
        $136 = (($__this) + 36|0);
        $137 = HEAP32[$136>>2]|0;
        $138 = ($132|0)<($137|0);
        if ($138) {
         $V_1$0 = $37;
        } else {
         $139 = HEAP32[$__this>>2]|0;
         $140 = (($139) + 84|0);
         $141 = HEAP32[$140>>2]|0;
         $142 = (($141) + 100|0);
         $143 = HEAP32[$142>>2]|0;
         $144 = (($143) + 4|0);
         $145 = HEAP32[$144>>2]|0;
         __THREW__ = 0;
         invoke_vi($145|0,($__this|0));
         $146 = __THREW__; __THREW__ = 0;
         $147 = $146&1;
         if ($147) {
          break;
         }
         $148 = HEAP32[$31>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($148|0));
         $149 = __THREW__; __THREW__ = 0;
         $150 = $149&1;
         if ($150) {
          break;
         }
         $151 = (($148) + 12|0);
         $152 = HEAP32[$151>>2]|0;
         $153 = (($30|0) % ($152|0))&-1;
         $V_1$0 = $153;
        }
        $154 = (($__this) + 28|0);
        $155 = HEAP32[$154>>2]|0;
        $156 = ($155|0)==(-1);
        if ($156) {
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $157 = __THREW__; __THREW__ = 0;
         $158 = $157&1;
         if ($158) {
          break;
         }
         $159 = (($__this) + 24|0);
         $160 = HEAP32[$159>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $161 = __THREW__; __THREW__ = 0;
         $162 = $161&1;
         if ($162) {
          break;
         }
         $163 = (($160) + 1)|0;
         HEAP32[$159>>2] = $163;
         $$pre = (($__this) + 12|0);
         $$pre$phiZ2D = $$pre;$V_2$2 = $160;
        } else {
         $164 = (($__this) + 12|0);
         $165 = HEAP32[$164>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($165|0));
         $166 = __THREW__; __THREW__ = 0;
         $167 = $166&1;
         if ($167) {
          break;
         }
         $168 = ($155|0)<(0);
         if ($168) {
          label = 54;
         } else {
          $169 = (($165) + 12|0);
          $170 = HEAP32[$169>>2]|0;
          $171 = ($155>>>0)<($170>>>0);
          if (!($171)) {
           label = 54;
          }
         }
         if ((label|0) == 54) {
          __THREW__ = 0;
          $172 = (invoke_i(132)|0);
          $173 = __THREW__; __THREW__ = 0;
          $174 = $173&1;
          if ($174) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($172|0));
          $175 = __THREW__; __THREW__ = 0;
          $176 = $175&1;
          if ($176) {
           break;
          }
         }
         $177 = HEAP32[$165>>2]|0;
         $178 = (($165) + 16|0);
         $179 = (($177) + 92|0);
         $180 = HEAP32[$179>>2]|0;
         $181 = Math_imul($180, $155)|0;
         $$sum1 = (($181) + 4)|0;
         $182 = (($178) + ($$sum1)|0);
         $183 = HEAP32[$182>>2]|0;
         HEAP32[$154>>2] = $183;
         $$pre$phiZ2D = $164;$V_2$2 = $155;
        }
        $184 = HEAP32[$$pre$phiZ2D>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($184|0));
        $185 = __THREW__; __THREW__ = 0;
        $186 = $185&1;
        if ($186) {
         break;
        }
        $187 = ($V_2$2|0)<(0);
        if ($187) {
         label = 60;
        } else {
         $188 = (($184) + 12|0);
         $189 = HEAP32[$188>>2]|0;
         $190 = ($V_2$2>>>0)<($189>>>0);
         if (!($190)) {
          label = 60;
         }
        }
        if ((label|0) == 60) {
         __THREW__ = 0;
         $191 = (invoke_i(132)|0);
         $192 = __THREW__; __THREW__ = 0;
         $193 = $192&1;
         if ($193) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($191|0));
         $194 = __THREW__; __THREW__ = 0;
         $195 = $194&1;
         if ($195) {
          break;
         }
        }
        $196 = HEAP32[$184>>2]|0;
        $197 = (($184) + 16|0);
        $198 = (($196) + 92|0);
        $199 = HEAP32[$198>>2]|0;
        $200 = Math_imul($199, $V_2$2)|0;
        $201 = HEAP32[$31>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($201|0));
        $202 = __THREW__; __THREW__ = 0;
        $203 = $202&1;
        if ($203) {
         break;
        }
        $204 = (($201) + 12|0);
        $205 = HEAP32[$204>>2]|0;
        $206 = ($V_1$0>>>0)<($205>>>0);
        if (!($206)) {
         __THREW__ = 0;
         $207 = (invoke_i(132)|0);
         $208 = __THREW__; __THREW__ = 0;
         $209 = $208&1;
         if ($209) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($207|0));
         $210 = __THREW__; __THREW__ = 0;
         $211 = $210&1;
         if ($211) {
          break;
         }
        }
        $212 = HEAP32[$201>>2]|0;
        $213 = (($201) + 16|0);
        $214 = (($212) + 92|0);
        $215 = HEAP32[$214>>2]|0;
        $216 = Math_imul($215, $V_1$0)|0;
        $217 = (($213) + ($216)|0);
        $218 = HEAP32[$217>>2]|0;
        $219 = (($218) + -1)|0;
        $$sum2 = (($200) + 4)|0;
        $220 = (($197) + ($$sum2)|0);
        HEAP32[$220>>2] = $219;
        $221 = HEAP32[$31>>2]|0;
        $222 = (($V_2$2) + 1)|0;
        __THREW__ = 0;
        invoke_vi(3799,($221|0));
        $223 = __THREW__; __THREW__ = 0;
        $224 = $223&1;
        if ($224) {
         break;
        }
        $225 = (($221) + 12|0);
        $226 = HEAP32[$225>>2]|0;
        $227 = ($V_1$0>>>0)<($226>>>0);
        if (!($227)) {
         __THREW__ = 0;
         $228 = (invoke_i(132)|0);
         $229 = __THREW__; __THREW__ = 0;
         $230 = $229&1;
         if ($230) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($228|0));
         $231 = __THREW__; __THREW__ = 0;
         $232 = $231&1;
         if ($232) {
          break;
         }
        }
        $233 = HEAP32[$221>>2]|0;
        $234 = (($221) + 16|0);
        $235 = (($233) + 92|0);
        $236 = HEAP32[$235>>2]|0;
        $237 = Math_imul($236, $V_1$0)|0;
        $238 = (($234) + ($237)|0);
        HEAP32[$238>>2] = $222;
        $239 = HEAP32[$$pre$phiZ2D>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($239|0));
        $240 = __THREW__; __THREW__ = 0;
        $241 = $240&1;
        if ($241) {
         break;
        }
        if ($187) {
         label = 73;
        } else {
         $242 = (($239) + 12|0);
         $243 = HEAP32[$242>>2]|0;
         $244 = ($V_2$2>>>0)<($243>>>0);
         if (!($244)) {
          label = 73;
         }
        }
        if ((label|0) == 73) {
         __THREW__ = 0;
         $245 = (invoke_i(132)|0);
         $246 = __THREW__; __THREW__ = 0;
         $247 = $246&1;
         if ($247) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($245|0));
         $248 = __THREW__; __THREW__ = 0;
         $249 = $248&1;
         if ($249) {
          break;
         }
        }
        $250 = HEAP32[$239>>2]|0;
        $251 = (($239) + 16|0);
        $252 = (($250) + 92|0);
        $253 = HEAP32[$252>>2]|0;
        $254 = Math_imul($253, $V_2$2)|0;
        $255 = (($251) + ($254)|0);
        HEAP32[$255>>2] = $29;
        $256 = (($__this) + 16|0);
        $257 = HEAP32[$256>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($257|0));
        $258 = __THREW__; __THREW__ = 0;
        $259 = $258&1;
        if ($259) {
         break;
        }
        if ($187) {
         label = 78;
        } else {
         $260 = (($257) + 12|0);
         $261 = HEAP32[$260>>2]|0;
         $262 = ($V_2$2>>>0)<($261>>>0);
         if (!($262)) {
          label = 78;
         }
        }
        if ((label|0) == 78) {
         __THREW__ = 0;
         $263 = (invoke_i(132)|0);
         $264 = __THREW__; __THREW__ = 0;
         $265 = $264&1;
         if ($265) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($263|0));
         $266 = __THREW__; __THREW__ = 0;
         $267 = $266&1;
         if ($267) {
          break;
         }
        }
        $268 = HEAP32[$257>>2]|0;
        $269 = (($257) + 16|0);
        $270 = (($268) + 92|0);
        $271 = HEAP32[$270>>2]|0;
        $272 = Math_imul($271, $V_2$2)|0;
        $273 = (($269) + ($272)|0);
        HEAP32[$273>>2] = $key;
        $V_2$3 = $V_2$2;
       }
       $367 = (($__this) + 20|0);
       $368 = HEAP32[$367>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($368|0));
       $369 = __THREW__; __THREW__ = 0;
       $370 = $369&1;
       if (!($370)) {
        $371 = ($V_2$3|0)<(0);
        if ($371) {
         label = 109;
        } else {
         $372 = (($368) + 12|0);
         $373 = HEAP32[$372>>2]|0;
         $374 = ($V_2$3>>>0)<($373>>>0);
         if (!($374)) {
          label = 109;
         }
        }
        if ((label|0) == 109) {
         __THREW__ = 0;
         $375 = (invoke_i(132)|0);
         $376 = __THREW__; __THREW__ = 0;
         $377 = $376&1;
         if ($377) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($375|0));
         $378 = __THREW__; __THREW__ = 0;
         $379 = $378&1;
         if ($379) {
          break;
         }
        }
        $380 = HEAP32[$368>>2]|0;
        $381 = (($368) + 16|0);
        $382 = (($380) + 92|0);
        $383 = HEAP32[$382>>2]|0;
        $384 = Math_imul($383, $V_2$3)|0;
        $385 = (($381) + ($384)|0);
        HEAP32[$385>>2] = $value;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $386 = __THREW__; __THREW__ = 0;
        $387 = $386&1;
        if (!($387)) {
         $388 = (($__this) + 48|0);
         $389 = HEAP32[$388>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $390 = __THREW__; __THREW__ = 0;
         $391 = $390&1;
         if (!($391)) {
          $392 = (($389) + 1)|0;
          HEAP32[$388>>2] = $392;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN21InterfaceFuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Init_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$hcp) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $hcp = $hcp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340792);
 __THREW__ = 0;
 invoke_v(335);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($capacity|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020592>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($hcp|0)==(0|0);
   if ($15) {
    $16 = HEAP32[$__this>>2]|0;
    $17 = (($16) + 84|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 104|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    $23 = (invoke_ii($22|0,(0|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    $G_B5_0$0 = $23;
   } else {
    $G_B5_0$0 = $hcp;
   }
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = (($__this) + 40|0);
    HEAP32[$28>>2] = $G_B5_0$0;
    $29 = ($capacity|0)==(0);
    $30 = (Math_fround(($capacity|0)));
    $31 = $29 ? Math_fround(10.0) : $30;
    $32 = Math_fround($31 / Math_fround(0.899999976158142089843));
    $33 = (~~(($32)));
    $34 = (($33) + 1)|0;
    $35 = HEAP32[$__this>>2]|0;
    $36 = (($35) + 84|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + 108|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    __THREW__ = 0;
    invoke_vii($41|0,($__this|0),($34|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     $44 = (($__this) + 48|0);
     HEAP32[$44>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitArrays_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340840);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2737,(1170368|0),($size|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $2;
   __THREW__ = 0;
   (invoke_ii(2996,(1170744|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2737,(1170744|0),($size|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($__this) + 12|0);
     HEAP32[$11>>2] = $8;
     $12 = (($__this) + 28|0);
     HEAP32[$12>>2] = -1;
     $13 = HEAP32[$__this>>2]|0;
     $14 = (($13) + 84|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($15) + 112|0);
     $17 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     $18 = (invoke_iii(2737,($17|0),($size|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($__this) + 16|0);
      HEAP32[$21>>2] = $18;
      $22 = HEAP32[$__this>>2]|0;
      $23 = (($22) + 84|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($24) + 116|0);
      $26 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $27 = (invoke_iii(2737,($26|0),($size|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       $30 = (($__this) + 20|0);
       HEAP32[$30>>2] = $27;
       $31 = (($__this) + 24|0);
       HEAP32[$31>>2] = 0;
       $32 = HEAP32[$5>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        $35 = (($32) + 12|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = (Math_fround(($36|0)));
        $38 = Math_fround($37 * Math_fround(0.899999976158142089843));
        $39 = (~~(($38)));
        $40 = (($__this) + 36|0);
        HEAP32[$40>>2] = $39;
        $41 = ($39|0)==(0);
        if (!($41)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        $44 = HEAP32[$5>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = (($44) + 12|0);
         $48 = HEAP32[$47>>2]|0;
         $49 = ($48|0)<(1);
         if ($49) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         HEAP32[$40>>2] = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($42|0);
 // unreachable;
}
function __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToCheck_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340888);
 __THREW__ = 0;
 invoke_v(336);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020608>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)>(-1);
   if (!($15)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3020616>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_ii(1857,($_____array|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $31 = ($28|0)<($index|0);
     if ($31) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2560072|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = HEAP32[3020624>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($34|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3808,($34|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      $44 = (invoke_ii(1857,($_____array|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       $47 = HEAP32[$__this>>2]|0;
       $48 = (($47) + 84|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = (($49) + 120|0);
       $51 = HEAP32[$50>>2]|0;
       __THREW__ = 0;
       $52 = (invoke_iii(2729,($51|0),($__this|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if (!($54)) {
        $55 = (($44) - ($index))|0;
        $56 = ($55|0)<($52|0);
        if (!($56)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if (!($58)) {
         __THREW__ = 0;
         $59 = (invoke_ii(3469,(2560072|0))|0);
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if (!($61)) {
          $62 = HEAP32[3020632>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($59|0),($62|0));
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if (!($64)) {
           __THREW__ = 0;
           invoke_vi(3808,($59|0));
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if (!($66)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_make_pairP22mscorlib_System_ObjectS0_S0_($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340936);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(319,($agg$result|0),($key|0),($value|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1344808)|0);
 $0 = HEAP32[((1344808 + 84|0))>>2]|0;
 __Z121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_PPv($__this,$key,$value,$0);
 STACKTOP = sp;return;
}
function __Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_pick_value_gsharedP22mscorlib_System_ObjectS0_S0_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340984);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($value|0);
}
function __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341032);
 $1 = HEAP32[$__this>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_viii($7|0,($__this|0),($_____array|0),($index|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $10 = HEAP32[$__this>>2]|0;
  $11 = (($10) + 84|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 56|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 60|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_ii(3469,($16|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $20 = HEAP32[$__this>>2]|0;
   $21 = (($20) + 84|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 64|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (($24) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   HEAP32[$0>>2] = $14;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viii($26|0,($17|0),(0|0),($$byval_copy|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[$__this>>2]|0;
    $30 = (($29) + 84|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = (($31) + 132|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = (($33) + 4|0);
    $35 = HEAP32[$34>>2]|0;
    __THREW__ = 0;
    invoke_viiii($35|0,($__this|0),($_____array|0),($index|0),($17|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($38|0);
 // unreachable;
}
function __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Resize_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = Math_fround(0), $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $V_4$03 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341080);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5 << 1;
   $7 = $6 | 1;
   __THREW__ = 0;
   $8 = (invoke_iii(835,(0|0),($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1170368|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_iii(2737,(1170368|0),($8|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(1170744|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_iii(2737,(1170744|0),($8|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $21 = (($18) + 16|0);
        $22 = (($__this) + 40|0);
        $23 = (($__this) + 16|0);
        $24 = (($13) + 12|0);
        $25 = (($13) + 16|0);
        $26 = (($__this) + 12|0);
        $27 = (($18) + 12|0);
        $V_3$0 = 0;
        L8: while(1) {
         $164 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($164|0));
         $165 = __THREW__; __THREW__ = 0;
         $166 = $165&1;
         if ($166) {
          label = 9;
          break;
         }
         $167 = (($164) + 12|0);
         $168 = HEAP32[$167>>2]|0;
         $169 = ($V_3$0|0)<($168|0);
         if (!($169)) {
          label = 52;
          break;
         }
         $35 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($35|0));
         $170 = __THREW__; __THREW__ = 0;
         $171 = $170&1;
         if ($171) {
          label = 9;
          break;
         }
         $34 = (($35) + 12|0);
         $36 = HEAP32[$34>>2]|0;
         $37 = ($V_3$0>>>0)<($36>>>0);
         if (!($37)) {
          __THREW__ = 0;
          $38 = (invoke_i(132)|0);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           label = 9;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($38|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           label = 9;
           break;
          }
         }
         $43 = HEAP32[$35>>2]|0;
         $44 = (($35) + 16|0);
         $45 = (($43) + 92|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = Math_imul($46, $V_3$0)|0;
         $48 = (($44) + ($47)|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ($49|0)==(0);
         if (!($50)) {
          $51 = (($49) + -1)|0;
          $V_4$03 = $51;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($18|0));
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 8;
            break L8;
           }
           $52 = ($V_4$03|0)<(0);
           if ($52) {
            label = 19;
           } else {
            $53 = HEAP32[$27>>2]|0;
            $54 = ($V_4$03>>>0)<($53>>>0);
            if (!($54)) {
             label = 19;
            }
           }
           if ((label|0) == 19) {
            label = 0;
            __THREW__ = 0;
            $55 = (invoke_i(132)|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($55|0));
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             label = 8;
             break L8;
            }
           }
           $60 = HEAP32[$18>>2]|0;
           $61 = (($60) + 92|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = Math_imul($62, $V_4$03)|0;
           $64 = (($21) + ($63)|0);
           $65 = HEAP32[$22>>2]|0;
           $66 = HEAP32[$23>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($66|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 24;
           } else {
            $69 = (($66) + 12|0);
            $70 = HEAP32[$69>>2]|0;
            $71 = ($V_4$03>>>0)<($70>>>0);
            if (!($71)) {
             label = 24;
            }
           }
           if ((label|0) == 24) {
            label = 0;
            __THREW__ = 0;
            $72 = (invoke_i(132)|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($72|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 8;
             break L8;
            }
           }
           $77 = HEAP32[$66>>2]|0;
           $78 = (($66) + 16|0);
           $79 = (($77) + 92|0);
           $80 = HEAP32[$79>>2]|0;
           $81 = Math_imul($80, $V_4$03)|0;
           $82 = (($78) + ($81)|0);
           $83 = HEAP32[$82>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($65|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            label = 8;
            break L8;
           }
           $86 = HEAP32[$__this>>2]|0;
           $87 = (($86) + 84|0);
           $88 = HEAP32[$87>>2]|0;
           $89 = (($88) + 92|0);
           $90 = HEAP32[$89>>2]|0;
           __THREW__ = 0;
           $91 = (invoke_iiii(1649,($90|0),($65|0),($83|0))|0);
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            label = 8;
            break L8;
           }
           $94 = $91 | -2147483648;
           HEAP32[$64>>2] = $94;
           $95 = $91 & 2147483647;
           $96 = (($95|0) % ($8|0))&-1;
           __THREW__ = 0;
           invoke_vi(3799,($18|0));
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if ($98) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 31;
           } else {
            $99 = HEAP32[$27>>2]|0;
            $100 = ($V_4$03>>>0)<($99>>>0);
            if (!($100)) {
             label = 31;
            }
           }
           if ((label|0) == 31) {
            label = 0;
            __THREW__ = 0;
            $101 = (invoke_i(132)|0);
            $102 = __THREW__; __THREW__ = 0;
            $103 = $102&1;
            if ($103) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($101|0));
            $104 = __THREW__; __THREW__ = 0;
            $105 = $104&1;
            if ($105) {
             label = 8;
             break L8;
            }
           }
           $106 = HEAP32[$18>>2]|0;
           $107 = (($106) + 92|0);
           $108 = HEAP32[$107>>2]|0;
           $109 = Math_imul($108, $V_4$03)|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $110 = __THREW__; __THREW__ = 0;
           $111 = $110&1;
           if ($111) {
            label = 8;
            break L8;
           }
           $112 = HEAP32[$24>>2]|0;
           $113 = ($96>>>0)<($112>>>0);
           if (!($113)) {
            __THREW__ = 0;
            $114 = (invoke_i(132)|0);
            $115 = __THREW__; __THREW__ = 0;
            $116 = $115&1;
            if ($116) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($114|0));
            $117 = __THREW__; __THREW__ = 0;
            $118 = $117&1;
            if ($118) {
             label = 8;
             break L8;
            }
           }
           $119 = HEAP32[$13>>2]|0;
           $120 = (($119) + 92|0);
           $121 = HEAP32[$120>>2]|0;
           $122 = Math_imul($121, $96)|0;
           $123 = (($25) + ($122)|0);
           $124 = HEAP32[$123>>2]|0;
           $125 = (($124) + -1)|0;
           $$sum = (($109) + 4)|0;
           $126 = (($21) + ($$sum)|0);
           HEAP32[$126>>2] = $125;
           $127 = (($V_4$03) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            label = 8;
            break L8;
           }
           $130 = HEAP32[$24>>2]|0;
           $131 = ($96>>>0)<($130>>>0);
           if (!($131)) {
            __THREW__ = 0;
            $132 = (invoke_i(132)|0);
            $133 = __THREW__; __THREW__ = 0;
            $134 = $133&1;
            if ($134) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($132|0));
            $135 = __THREW__; __THREW__ = 0;
            $136 = $135&1;
            if ($136) {
             label = 8;
             break L8;
            }
           }
           $137 = HEAP32[$13>>2]|0;
           $138 = (($137) + 92|0);
           $139 = HEAP32[$138>>2]|0;
           $140 = Math_imul($139, $96)|0;
           $141 = (($25) + ($140)|0);
           HEAP32[$141>>2] = $127;
           $142 = HEAP32[$26>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($142|0));
           $143 = __THREW__; __THREW__ = 0;
           $144 = $143&1;
           if ($144) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 44;
           } else {
            $145 = (($142) + 12|0);
            $146 = HEAP32[$145>>2]|0;
            $147 = ($V_4$03>>>0)<($146>>>0);
            if (!($147)) {
             label = 44;
            }
           }
           if ((label|0) == 44) {
            label = 0;
            __THREW__ = 0;
            $148 = (invoke_i(132)|0);
            $149 = __THREW__; __THREW__ = 0;
            $150 = $149&1;
            if ($150) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($148|0));
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            if ($152) {
             label = 8;
             break L8;
            }
           }
           $153 = HEAP32[$142>>2]|0;
           $154 = (($142) + 16|0);
           $155 = (($153) + 92|0);
           $156 = HEAP32[$155>>2]|0;
           $157 = Math_imul($156, $V_4$03)|0;
           $$sum2 = (($157) + 4)|0;
           $158 = (($154) + ($$sum2)|0);
           $159 = HEAP32[$158>>2]|0;
           $160 = ($159|0)==(-1);
           if ($160) {
            break;
           } else {
            $V_4$03 = $159;
           }
          }
         }
         $163 = (($V_3$0) + 1)|0;
         $V_3$0 = $163;
        }
        if ((label|0) == 8) {
         $28 = ___cxa_find_matching_catch()|0;
         $29 = tempRet0;
         $lpad$phi$index = $28;$lpad$phi$index3 = $29;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 9) {
         $30 = ___cxa_find_matching_catch()|0;
         $31 = tempRet0;
         $lpad$phi$index = $30;$lpad$phi$index3 = $31;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 52) {
         HEAP32[$0>>2] = $13;
         HEAP32[$26>>2] = $18;
         $172 = HEAP32[$__this>>2]|0;
         $173 = (($172) + 84|0);
         $174 = HEAP32[$173>>2]|0;
         $175 = (($174) + 112|0);
         $176 = HEAP32[$175>>2]|0;
         __THREW__ = 0;
         $177 = (invoke_iii(2737,($176|0),($8|0))|0);
         $178 = __THREW__; __THREW__ = 0;
         $179 = $178&1;
         if ($179) {
          break;
         }
         $180 = HEAP32[$__this>>2]|0;
         $181 = (($180) + 84|0);
         $182 = HEAP32[$181>>2]|0;
         $183 = (($182) + 116|0);
         $184 = HEAP32[$183>>2]|0;
         __THREW__ = 0;
         $185 = (invoke_iii(2737,($184|0),($8|0))|0);
         $186 = __THREW__; __THREW__ = 0;
         $187 = $186&1;
         if ($187) {
          break;
         }
         $188 = HEAP32[$23>>2]|0;
         $189 = (($__this) + 24|0);
         $190 = HEAP32[$189>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($188|0),0,($177|0),0,($190|0));
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          break;
         }
         $193 = (($__this) + 20|0);
         $194 = HEAP32[$193>>2]|0;
         $195 = HEAP32[$189>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($194|0),0,($185|0),0,($195|0));
         $196 = __THREW__; __THREW__ = 0;
         $197 = $196&1;
         if ($197) {
          break;
         }
         HEAP32[$23>>2] = $177;
         HEAP32[$193>>2] = $185;
         $198 = (Math_fround(($8|0)));
         $199 = Math_fround($198 * Math_fround(0.899999976158142089843));
         $200 = (~~(($199)));
         $201 = (($__this) + 36|0);
         HEAP32[$201>>2] = $200;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 $lpad$phi$index = $32;$lpad$phi$index3 = $33;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Add_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2$05 = 0, $V_2$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340312);
 __THREW__ = 0;
 invoke_v(337);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3020792>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[$__this>>2]|0;
    $22 = (($21) + 84|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + 92|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(1649,($25|0),($18|0),($key|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = $26 | -2147483648;
     $30 = $26 & 2147483647;
     $31 = (($__this) + 8|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $35 = (($32) + 12|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($30|0) % ($36|0))&-1;
      $38 = HEAP32[$31>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($38|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = (($38) + 12|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($37>>>0)<($42>>>0);
       if (!($43)) {
        __THREW__ = 0;
        $44 = (invoke_i(132)|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($44|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
       }
       $49 = HEAP32[$38>>2]|0;
       $50 = (($38) + 16|0);
       $51 = (($49) + 92|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = Math_imul($52, $37)|0;
       $54 = (($50) + ($53)|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = ($55|0)==(0);
       L18: do {
        if (!($56)) {
         $57 = (($55) + -1)|0;
         $58 = (($__this) + 12|0);
         $59 = (($__this) + 16|0);
         $V_2$05 = $57;
         while(1) {
          $62 = HEAP32[$58>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($62|0));
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           label = 3;
           break;
          }
          $60 = ($V_2$05|0)<(0);
          if ($60) {
           label = 22;
          } else {
           $61 = (($62) + 12|0);
           $63 = HEAP32[$61>>2]|0;
           $64 = ($V_2$05>>>0)<($63>>>0);
           if (!($64)) {
            label = 22;
           }
          }
          if ((label|0) == 22) {
           label = 0;
           __THREW__ = 0;
           $65 = (invoke_i(132)|0);
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($65|0));
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            label = 3;
            break;
           }
          }
          $70 = HEAP32[$62>>2]|0;
          $71 = (($62) + 16|0);
          $72 = (($70) + 92|0);
          $73 = HEAP32[$72>>2]|0;
          $74 = Math_imul($73, $V_2$05)|0;
          $75 = (($71) + ($74)|0);
          $76 = HEAP32[$75>>2]|0;
          $77 = ($76|0)==($29|0);
          if ($77) {
           $78 = HEAP32[$17>>2]|0;
           $79 = HEAP32[$59>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($79|0));
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if ($81) {
            label = 3;
            break;
           }
           if ($60) {
            label = 28;
           } else {
            $82 = (($79) + 12|0);
            $83 = HEAP32[$82>>2]|0;
            $84 = ($V_2$05>>>0)<($83>>>0);
            if (!($84)) {
             label = 28;
            }
           }
           if ((label|0) == 28) {
            label = 0;
            __THREW__ = 0;
            $85 = (invoke_i(132)|0);
            $86 = __THREW__; __THREW__ = 0;
            $87 = $86&1;
            if ($87) {
             label = 3;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($85|0));
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if ($89) {
             label = 3;
             break;
            }
           }
           $90 = HEAP32[$79>>2]|0;
           $91 = (($79) + 16|0);
           $92 = (($90) + 92|0);
           $93 = HEAP32[$92>>2]|0;
           $94 = Math_imul($93, $V_2$05)|0;
           $95 = (($91) + ($94)|0);
           $96 = HEAP32[$95>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($78|0));
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if ($98) {
            label = 3;
            break;
           }
           $99 = HEAP32[$__this>>2]|0;
           $100 = (($99) + 84|0);
           $101 = HEAP32[$100>>2]|0;
           $102 = (($101) + 96|0);
           $103 = HEAP32[$102>>2]|0;
           __THREW__ = 0;
           $104 = (invoke_iiiii(302,($103|0),($78|0),($96|0),($key|0))|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            label = 3;
            break;
           }
           if ($104) {
            break;
           }
          }
          $117 = HEAP32[$58>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($117|0));
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          if ($119) {
           label = 3;
           break;
          }
          if ($60) {
           label = 41;
          } else {
           $120 = (($117) + 12|0);
           $121 = HEAP32[$120>>2]|0;
           $122 = ($V_2$05>>>0)<($121>>>0);
           if (!($122)) {
            label = 41;
           }
          }
          if ((label|0) == 41) {
           label = 0;
           __THREW__ = 0;
           $123 = (invoke_i(132)|0);
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($123|0));
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            label = 3;
            break;
           }
          }
          $128 = HEAP32[$117>>2]|0;
          $129 = (($117) + 16|0);
          $130 = (($128) + 92|0);
          $131 = HEAP32[$130>>2]|0;
          $132 = Math_imul($131, $V_2$05)|0;
          $$sum = (($132) + 4)|0;
          $133 = (($129) + ($$sum)|0);
          $134 = HEAP32[$133>>2]|0;
          $135 = ($134|0)==(-1);
          if ($135) {
           break L18;
          } else {
           $V_2$05 = $134;
          }
         }
         if ((label|0) == 3) {
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index2 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          break L1;
         }
         __THREW__ = 0;
         $109 = (invoke_ii(3469,(2560072|0))|0);
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         if ($111) {
          break L1;
         }
         $112 = HEAP32[3020800>>2]|0;
         __THREW__ = 0;
         invoke_vii(1924,($109|0),($112|0));
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3808,($109|0));
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break L1;
         }
         // unreachable;
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if (!($139)) {
        $140 = (($__this) + 32|0);
        $141 = HEAP32[$140>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $142 = __THREW__; __THREW__ = 0;
        $143 = $142&1;
        if (!($143)) {
         $144 = (($141) + 1)|0;
         HEAP32[$140>>2] = $144;
         $145 = (($__this) + 36|0);
         $146 = HEAP32[$145>>2]|0;
         $147 = ($141|0)<($146|0);
         if ($147) {
          $V_1$0 = $37;
         } else {
          $148 = HEAP32[$__this>>2]|0;
          $149 = (($148) + 84|0);
          $150 = HEAP32[$149>>2]|0;
          $151 = (($150) + 100|0);
          $152 = HEAP32[$151>>2]|0;
          $153 = (($152) + 4|0);
          $154 = HEAP32[$153>>2]|0;
          __THREW__ = 0;
          invoke_vi($154|0,($__this|0));
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           break;
          }
          $157 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($157|0));
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           break;
          }
          $160 = (($157) + 12|0);
          $161 = HEAP32[$160>>2]|0;
          $162 = (($30|0) % ($161|0))&-1;
          $V_1$0 = $162;
         }
         $163 = (($__this) + 28|0);
         $164 = HEAP32[$163>>2]|0;
         $165 = ($164|0)==(-1);
         if ($165) {
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $166 = __THREW__; __THREW__ = 0;
          $167 = $166&1;
          if ($167) {
           break;
          }
          $168 = (($__this) + 24|0);
          $169 = HEAP32[$168>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $170 = __THREW__; __THREW__ = 0;
          $171 = $170&1;
          if ($171) {
           break;
          }
          $172 = (($169) + 1)|0;
          HEAP32[$168>>2] = $172;
          $$pre = (($__this) + 12|0);
          $$pre$phiZ2D = $$pre;$V_2$1 = $169;
         } else {
          $173 = (($__this) + 12|0);
          $174 = HEAP32[$173>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($174|0));
          $175 = __THREW__; __THREW__ = 0;
          $176 = $175&1;
          if ($176) {
           break;
          }
          $177 = ($164|0)<(0);
          if ($177) {
           label = 58;
          } else {
           $178 = (($174) + 12|0);
           $179 = HEAP32[$178>>2]|0;
           $180 = ($164>>>0)<($179>>>0);
           if (!($180)) {
            label = 58;
           }
          }
          if ((label|0) == 58) {
           __THREW__ = 0;
           $181 = (invoke_i(132)|0);
           $182 = __THREW__; __THREW__ = 0;
           $183 = $182&1;
           if ($183) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($181|0));
           $184 = __THREW__; __THREW__ = 0;
           $185 = $184&1;
           if ($185) {
            break;
           }
          }
          $186 = HEAP32[$174>>2]|0;
          $187 = (($174) + 16|0);
          $188 = (($186) + 92|0);
          $189 = HEAP32[$188>>2]|0;
          $190 = Math_imul($189, $164)|0;
          $$sum3 = (($190) + 4)|0;
          $191 = (($187) + ($$sum3)|0);
          $192 = HEAP32[$191>>2]|0;
          HEAP32[$163>>2] = $192;
          $$pre$phiZ2D = $173;$V_2$1 = $164;
         }
         $193 = HEAP32[$$pre$phiZ2D>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($193|0));
         $194 = __THREW__; __THREW__ = 0;
         $195 = $194&1;
         if (!($195)) {
          $196 = ($V_2$1|0)<(0);
          if ($196) {
           label = 64;
          } else {
           $197 = (($193) + 12|0);
           $198 = HEAP32[$197>>2]|0;
           $199 = ($V_2$1>>>0)<($198>>>0);
           if (!($199)) {
            label = 64;
           }
          }
          if ((label|0) == 64) {
           __THREW__ = 0;
           $200 = (invoke_i(132)|0);
           $201 = __THREW__; __THREW__ = 0;
           $202 = $201&1;
           if ($202) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($200|0));
           $203 = __THREW__; __THREW__ = 0;
           $204 = $203&1;
           if ($204) {
            break;
           }
          }
          $205 = HEAP32[$193>>2]|0;
          $206 = (($193) + 16|0);
          $207 = (($205) + 92|0);
          $208 = HEAP32[$207>>2]|0;
          $209 = Math_imul($208, $V_2$1)|0;
          $210 = (($206) + ($209)|0);
          HEAP32[$210>>2] = $29;
          $211 = HEAP32[$$pre$phiZ2D>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($211|0));
          $212 = __THREW__; __THREW__ = 0;
          $213 = $212&1;
          if (!($213)) {
           if ($196) {
            label = 69;
           } else {
            $214 = (($211) + 12|0);
            $215 = HEAP32[$214>>2]|0;
            $216 = ($V_2$1>>>0)<($215>>>0);
            if (!($216)) {
             label = 69;
            }
           }
           if ((label|0) == 69) {
            __THREW__ = 0;
            $217 = (invoke_i(132)|0);
            $218 = __THREW__; __THREW__ = 0;
            $219 = $218&1;
            if ($219) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($217|0));
            $220 = __THREW__; __THREW__ = 0;
            $221 = $220&1;
            if ($221) {
             break;
            }
           }
           $222 = HEAP32[$211>>2]|0;
           $223 = (($211) + 16|0);
           $224 = (($222) + 92|0);
           $225 = HEAP32[$224>>2]|0;
           $226 = Math_imul($225, $V_2$1)|0;
           $227 = HEAP32[$31>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($227|0));
           $228 = __THREW__; __THREW__ = 0;
           $229 = $228&1;
           if (!($229)) {
            $230 = (($227) + 12|0);
            $231 = HEAP32[$230>>2]|0;
            $232 = ($V_1$0>>>0)<($231>>>0);
            if (!($232)) {
             __THREW__ = 0;
             $233 = (invoke_i(132)|0);
             $234 = __THREW__; __THREW__ = 0;
             $235 = $234&1;
             if ($235) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($233|0));
             $236 = __THREW__; __THREW__ = 0;
             $237 = $236&1;
             if ($237) {
              break;
             }
            }
            $238 = HEAP32[$227>>2]|0;
            $239 = (($227) + 16|0);
            $240 = (($238) + 92|0);
            $241 = HEAP32[$240>>2]|0;
            $242 = Math_imul($241, $V_1$0)|0;
            $243 = (($239) + ($242)|0);
            $244 = HEAP32[$243>>2]|0;
            $245 = (($244) + -1)|0;
            $$sum4 = (($226) + 4)|0;
            $246 = (($223) + ($$sum4)|0);
            HEAP32[$246>>2] = $245;
            $247 = HEAP32[$31>>2]|0;
            $248 = (($V_2$1) + 1)|0;
            __THREW__ = 0;
            invoke_vi(3799,($247|0));
            $249 = __THREW__; __THREW__ = 0;
            $250 = $249&1;
            if (!($250)) {
             $251 = (($247) + 12|0);
             $252 = HEAP32[$251>>2]|0;
             $253 = ($V_1$0>>>0)<($252>>>0);
             if (!($253)) {
              __THREW__ = 0;
              $254 = (invoke_i(132)|0);
              $255 = __THREW__; __THREW__ = 0;
              $256 = $255&1;
              if ($256) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($254|0));
              $257 = __THREW__; __THREW__ = 0;
              $258 = $257&1;
              if ($258) {
               break;
              }
             }
             $259 = HEAP32[$247>>2]|0;
             $260 = (($247) + 16|0);
             $261 = (($259) + 92|0);
             $262 = HEAP32[$261>>2]|0;
             $263 = Math_imul($262, $V_1$0)|0;
             $264 = (($260) + ($263)|0);
             HEAP32[$264>>2] = $248;
             $265 = (($__this) + 16|0);
             $266 = HEAP32[$265>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($266|0));
             $267 = __THREW__; __THREW__ = 0;
             $268 = $267&1;
             if ($268) {
              break;
             }
             if ($196) {
              label = 82;
             } else {
              $269 = (($266) + 12|0);
              $270 = HEAP32[$269>>2]|0;
              $271 = ($V_2$1>>>0)<($270>>>0);
              if (!($271)) {
               label = 82;
              }
             }
             if ((label|0) == 82) {
              __THREW__ = 0;
              $272 = (invoke_i(132)|0);
              $273 = __THREW__; __THREW__ = 0;
              $274 = $273&1;
              if ($274) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($272|0));
              $275 = __THREW__; __THREW__ = 0;
              $276 = $275&1;
              if ($276) {
               break;
              }
             }
             $277 = HEAP32[$266>>2]|0;
             $278 = (($266) + 16|0);
             $279 = (($277) + 92|0);
             $280 = HEAP32[$279>>2]|0;
             $281 = Math_imul($280, $V_2$1)|0;
             $282 = (($278) + ($281)|0);
             HEAP32[$282>>2] = $key;
             $283 = (($__this) + 20|0);
             $284 = HEAP32[$283>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($284|0));
             $285 = __THREW__; __THREW__ = 0;
             $286 = $285&1;
             if ($286) {
              break;
             }
             if ($196) {
              label = 87;
             } else {
              $287 = (($284) + 12|0);
              $288 = HEAP32[$287>>2]|0;
              $289 = ($V_2$1>>>0)<($288>>>0);
              if (!($289)) {
               label = 87;
              }
             }
             if ((label|0) == 87) {
              __THREW__ = 0;
              $290 = (invoke_i(132)|0);
              $291 = __THREW__; __THREW__ = 0;
              $292 = $291&1;
              if ($292) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($290|0));
              $293 = __THREW__; __THREW__ = 0;
              $294 = $293&1;
              if ($294) {
               break;
              }
             }
             $295 = HEAP32[$284>>2]|0;
             $296 = (($284) + 16|0);
             $297 = (($295) + 92|0);
             $298 = HEAP32[$297>>2]|0;
             $299 = Math_imul($298, $V_2$1)|0;
             $300 = (($296) + ($299)|0);
             HEAP32[$300>>2] = $value;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $301 = __THREW__; __THREW__ = 0;
             $302 = $301&1;
             if ($302) {
              break;
             }
             $303 = (($__this) + 48|0);
             $304 = HEAP32[$303>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $305 = __THREW__; __THREW__ = 0;
             $306 = $305&1;
             if ($306) {
              break;
             }
             $307 = (($304) + 1)|0;
             HEAP32[$303>>2] = $307;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Clear_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341128);
 $0 = (($__this) + 32|0);
 HEAP32[$0>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($2) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($2|0),0,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = (($__this) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = (($10) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($10|0),0,($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = (($__this) + 20|0);
     $18 = HEAP32[$17>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($18) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      __THREW__ = 0;
      invoke_viiii(138,(0|0),($18|0),0,($22|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = (($__this) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $29 = (($26) + 12|0);
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        invoke_viiii(138,(0|0),($26|0),0,($30|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $33 = (($__this) + 28|0);
         HEAP32[$33>>2] = -1;
         $34 = (($__this) + 24|0);
         HEAP32[$34>>2] = 0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          $37 = (($__this) + 48|0);
          $38 = HEAP32[$37>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = (($38) + 1)|0;
           HEAP32[$37>>2] = $41;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($42|0);
 // unreachable;
}
function __Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_1$0 = 0, $V_2$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341176);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 136|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_ii($6|0,(0|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  $lpad$phi$index = $17;$lpad$phi$index3 = $18;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $10 = (($__this) + 8|0);
 $11 = (($__this) + 20|0);
 $12 = (($__this) + 12|0);
 $V_1$0 = 0;
 L5: while(1) {
  $86 = HEAP32[$10>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($86|0));
  $87 = __THREW__; __THREW__ = 0;
  $88 = $87&1;
  if ($88) {
   label = 4;
   break;
  }
  $89 = (($86) + 12|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($V_1$0|0)<($90|0);
  if (!($91)) {
   $$0 = 0;
   label = 30;
   break;
  }
  $20 = HEAP32[$10>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($20|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 4;
   break;
  }
  $19 = (($20) + 12|0);
  $21 = HEAP32[$19>>2]|0;
  $22 = ($V_1$0>>>0)<($21>>>0);
  if (!($22)) {
   __THREW__ = 0;
   $23 = (invoke_i(132)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 4;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($23|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 4;
    break;
   }
  }
  $28 = HEAP32[$20>>2]|0;
  $29 = (($20) + 16|0);
  $30 = (($28) + 92|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = Math_imul($31, $V_1$0)|0;
  $33 = (($29) + ($32)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($34|0)==(0);
  if (!($35)) {
   $36 = (($34) + -1)|0;
   $V_2$02 = $36;
   while(1) {
    $39 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($39|0));
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if ($84) {
     label = 3;
     break L5;
    }
    $37 = ($V_2$02|0)<(0);
    if ($37) {
     label = 14;
    } else {
     $38 = (($39) + 12|0);
     $40 = HEAP32[$38>>2]|0;
     $41 = ($V_2$02>>>0)<($40>>>0);
     if (!($41)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     __THREW__ = 0;
     $42 = (invoke_i(132)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 3;
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3302,($42|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 3;
      break L5;
     }
    }
    $47 = HEAP32[$39>>2]|0;
    $48 = (($39) + 16|0);
    $49 = (($47) + 92|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = Math_imul($50, $V_2$02)|0;
    $52 = (($48) + ($51)|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($7|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 3;
     break L5;
    }
    $56 = HEAP32[$__this>>2]|0;
    $57 = (($56) + 84|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = (($58) + 140|0);
    $60 = HEAP32[$59>>2]|0;
    __THREW__ = 0;
    $61 = (invoke_iiiii(302,($60|0),($7|0),($53|0),($value|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 3;
     break L5;
    }
    if ($61) {
     $$0 = 1;
     label = 30;
     break L5;
    }
    $64 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($64|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     label = 3;
     break L5;
    }
    if ($37) {
     label = 22;
    } else {
     $67 = (($64) + 12|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ($V_2$02>>>0)<($68>>>0);
     if (!($69)) {
      label = 22;
     }
    }
    if ((label|0) == 22) {
     label = 0;
     __THREW__ = 0;
     $70 = (invoke_i(132)|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      label = 3;
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3302,($70|0));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      label = 3;
      break L5;
     }
    }
    $75 = HEAP32[$64>>2]|0;
    $76 = (($64) + 16|0);
    $77 = (($75) + 92|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = Math_imul($78, $V_2$02)|0;
    $$sum = (($79) + 4)|0;
    $80 = (($76) + ($$sum)|0);
    $81 = HEAP32[$80>>2]|0;
    $82 = ($81|0)==(-1);
    if ($82) {
     break;
    } else {
     $V_2$02 = $81;
    }
   }
  }
  $85 = (($V_1$0) + 1)|0;
  $V_1$0 = $85;
 }
 if ((label|0) == 3) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index3 = $14;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 4) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $lpad$phi$index = $15;$lpad$phi$index3 = $16;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetObjectData_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341224);
 __THREW__ = 0;
 invoke_v(338);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020944>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 48|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3020952>>2]|0;
    __THREW__ = 0;
    invoke_viii(618,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 40|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[3020960>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($26|0),($23|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = (($__this) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)<(1);
       if ($31) {
        $V_0$0 = 0;
       } else {
        $32 = HEAP32[$__this>>2]|0;
        $33 = (($32) + 84|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = (($34) + 144|0);
        $36 = HEAP32[$35>>2]|0;
        __THREW__ = 0;
        $37 = (invoke_iii(2737,($36|0),($30|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
        $40 = HEAP32[$__this>>2]|0;
        $41 = (($40) + 84|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = (($42) + 20|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = (($44) + 4|0);
        $46 = HEAP32[$45>>2]|0;
        __THREW__ = 0;
        invoke_viii($46|0,($__this|0),($37|0),0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        } else {
         $V_0$0 = $37;
        }
       }
       $49 = (($__this) + 8|0);
       $50 = HEAP32[$49>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($50|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if (!($52)) {
        $53 = (($50) + 12|0);
        $54 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if (!($56)) {
         $57 = HEAP32[3020968>>2]|0;
         __THREW__ = 0;
         invoke_viii(618,($info|0),($57|0),($54|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          invoke_vi(3799,($info|0));
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if (!($61)) {
           $62 = HEAP32[3020976>>2]|0;
           __THREW__ = 0;
           invoke_viii(621,($info|0),($62|0),($V_0$0|0));
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if (!($64)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Remove_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $$0 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1340504);
 __THREW__ = 0;
 invoke_v(339);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021072>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[$__this>>2]|0;
    $22 = (($21) + 84|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + 92|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(1649,($25|0),($18|0),($key|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = $26 | -2147483648;
     $30 = (($__this) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($31|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      $34 = $26 & 2147483647;
      $35 = (($31) + 12|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($34|0) % ($36|0))&-1;
      $38 = HEAP32[$30>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($38|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = (($38) + 12|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($37>>>0)<($42>>>0);
       if (!($43)) {
        __THREW__ = 0;
        $44 = (invoke_i(132)|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($44|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
       }
       $49 = HEAP32[$38>>2]|0;
       $50 = (($38) + 16|0);
       $51 = (($49) + 92|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = Math_imul($52, $37)|0;
       $54 = (($50) + ($53)|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = ($55|0)==(0);
       if ($56) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $57 = (($55) + -1)|0;
       $58 = (($__this) + 12|0);
       $59 = (($__this) + 16|0);
       $V_2$0 = $57;$V_3$0 = -1;
       while(1) {
        $60 = HEAP32[$58>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($60|0));
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 3;
         break;
        }
        $63 = ($V_2$0|0)<(0);
        if ($63) {
         label = 23;
        } else {
         $64 = (($60) + 12|0);
         $65 = HEAP32[$64>>2]|0;
         $66 = ($V_2$0>>>0)<($65>>>0);
         if (!($66)) {
          label = 23;
         }
        }
        if ((label|0) == 23) {
         label = 0;
         __THREW__ = 0;
         $67 = (invoke_i(132)|0);
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($67|0));
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          label = 3;
          break;
         }
        }
        $72 = HEAP32[$60>>2]|0;
        $73 = (($60) + 16|0);
        $74 = (($72) + 92|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = Math_imul($75, $V_2$0)|0;
        $77 = (($73) + ($76)|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = ($78|0)==($29|0);
        if ($79) {
         $80 = HEAP32[$17>>2]|0;
         $81 = HEAP32[$59>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($81|0));
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          label = 3;
          break;
         }
         if ($63) {
          label = 29;
         } else {
          $84 = (($81) + 12|0);
          $85 = HEAP32[$84>>2]|0;
          $86 = ($V_2$0>>>0)<($85>>>0);
          if (!($86)) {
           label = 29;
          }
         }
         if ((label|0) == 29) {
          label = 0;
          __THREW__ = 0;
          $87 = (invoke_i(132)|0);
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($87|0));
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           label = 3;
           break;
          }
         }
         $92 = HEAP32[$81>>2]|0;
         $93 = (($81) + 16|0);
         $94 = (($92) + 92|0);
         $95 = HEAP32[$94>>2]|0;
         $96 = Math_imul($95, $V_2$0)|0;
         $97 = (($93) + ($96)|0);
         $98 = HEAP32[$97>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($80|0));
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          label = 3;
          break;
         }
         $101 = HEAP32[$__this>>2]|0;
         $102 = (($101) + 84|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = (($103) + 96|0);
         $105 = HEAP32[$104>>2]|0;
         __THREW__ = 0;
         $106 = (invoke_iiiii(302,($105|0),($80|0),($98|0),($key|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          label = 3;
          break;
         }
         if ($106) {
          label = 40;
          break;
         }
        }
        $109 = HEAP32[$58>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($109|0));
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         label = 3;
         break;
        }
        if ($63) {
         label = 37;
        } else {
         $112 = (($109) + 12|0);
         $113 = HEAP32[$112>>2]|0;
         $114 = ($V_2$0>>>0)<($113>>>0);
         if (!($114)) {
          label = 37;
         }
        }
        if ((label|0) == 37) {
         label = 0;
         __THREW__ = 0;
         $115 = (invoke_i(132)|0);
         $116 = __THREW__; __THREW__ = 0;
         $117 = $116&1;
         if ($117) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($115|0));
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          label = 3;
          break;
         }
        }
        $120 = HEAP32[$109>>2]|0;
        $121 = (($109) + 16|0);
        $122 = (($120) + 92|0);
        $123 = HEAP32[$122>>2]|0;
        $124 = Math_imul($123, $V_2$0)|0;
        $$sum = (($124) + 4)|0;
        $125 = (($121) + ($$sum)|0);
        $126 = HEAP32[$125>>2]|0;
        $127 = ($126|0)==(-1);
        if ($127) {
         $$0 = 0;
         label = 88;
         break;
        } else {
         $V_3$0$phi = $V_2$0;$V_2$0 = $126;$V_3$0 = $V_3$0$phi;
        }
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 40) {
        $128 = ($V_2$0|0)==(-1);
        if ($128) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         break;
        }
        $131 = (($__this) + 32|0);
        $132 = HEAP32[$131>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         break;
        }
        $135 = (($132) + -1)|0;
        HEAP32[$131>>2] = $135;
        $136 = ($V_3$0|0)==(-1);
        if ($136) {
         $137 = HEAP32[$30>>2]|0;
         $138 = HEAP32[$58>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($138|0));
         $139 = __THREW__; __THREW__ = 0;
         $140 = $139&1;
         if ($140) {
          break;
         }
         if ($63) {
          label = 47;
         } else {
          $141 = (($138) + 12|0);
          $142 = HEAP32[$141>>2]|0;
          $143 = ($V_2$0>>>0)<($142>>>0);
          if (!($143)) {
           label = 47;
          }
         }
         if ((label|0) == 47) {
          __THREW__ = 0;
          $144 = (invoke_i(132)|0);
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          if ($146) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($144|0));
          $147 = __THREW__; __THREW__ = 0;
          $148 = $147&1;
          if ($148) {
           break;
          }
         }
         $149 = HEAP32[$138>>2]|0;
         $150 = (($138) + 16|0);
         $151 = (($149) + 92|0);
         $152 = HEAP32[$151>>2]|0;
         $153 = Math_imul($152, $V_2$0)|0;
         $$sum5 = (($153) + 4)|0;
         $154 = (($150) + ($$sum5)|0);
         $155 = HEAP32[$154>>2]|0;
         $156 = (($155) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($137|0));
         $157 = __THREW__; __THREW__ = 0;
         $158 = $157&1;
         if ($158) {
          break;
         }
         $159 = (($137) + 12|0);
         $160 = HEAP32[$159>>2]|0;
         $161 = ($37>>>0)<($160>>>0);
         if (!($161)) {
          __THREW__ = 0;
          $162 = (invoke_i(132)|0);
          $163 = __THREW__; __THREW__ = 0;
          $164 = $163&1;
          if ($164) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($162|0));
          $165 = __THREW__; __THREW__ = 0;
          $166 = $165&1;
          if ($166) {
           break;
          }
         }
         $167 = HEAP32[$137>>2]|0;
         $168 = (($137) + 16|0);
         $169 = (($167) + 92|0);
         $170 = HEAP32[$169>>2]|0;
         $171 = Math_imul($170, $37)|0;
         $172 = (($168) + ($171)|0);
         HEAP32[$172>>2] = $156;
        } else {
         $173 = HEAP32[$58>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($173|0));
         $174 = __THREW__; __THREW__ = 0;
         $175 = $174&1;
         if ($175) {
          break;
         }
         $176 = ($V_3$0|0)<(0);
         if ($176) {
          label = 57;
         } else {
          $177 = (($173) + 12|0);
          $178 = HEAP32[$177>>2]|0;
          $179 = ($V_3$0>>>0)<($178>>>0);
          if (!($179)) {
           label = 57;
          }
         }
         if ((label|0) == 57) {
          __THREW__ = 0;
          $180 = (invoke_i(132)|0);
          $181 = __THREW__; __THREW__ = 0;
          $182 = $181&1;
          if ($182) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($180|0));
          $183 = __THREW__; __THREW__ = 0;
          $184 = $183&1;
          if ($184) {
           break;
          }
         }
         $185 = HEAP32[$173>>2]|0;
         $186 = (($173) + 16|0);
         $187 = (($185) + 92|0);
         $188 = HEAP32[$187>>2]|0;
         $189 = Math_imul($188, $V_3$0)|0;
         $190 = HEAP32[$58>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($190|0));
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          break;
         }
         if ($63) {
          label = 62;
         } else {
          $193 = (($190) + 12|0);
          $194 = HEAP32[$193>>2]|0;
          $195 = ($V_2$0>>>0)<($194>>>0);
          if (!($195)) {
           label = 62;
          }
         }
         if ((label|0) == 62) {
          __THREW__ = 0;
          $196 = (invoke_i(132)|0);
          $197 = __THREW__; __THREW__ = 0;
          $198 = $197&1;
          if ($198) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($196|0));
          $199 = __THREW__; __THREW__ = 0;
          $200 = $199&1;
          if ($200) {
           break;
          }
         }
         $201 = HEAP32[$190>>2]|0;
         $202 = (($190) + 16|0);
         $203 = (($201) + 92|0);
         $204 = HEAP32[$203>>2]|0;
         $205 = Math_imul($204, $V_2$0)|0;
         $$sum2 = (($205) + 4)|0;
         $206 = (($202) + ($$sum2)|0);
         $207 = HEAP32[$206>>2]|0;
         $$sum3 = (($189) + 4)|0;
         $208 = (($186) + ($$sum3)|0);
         HEAP32[$208>>2] = $207;
        }
        $209 = HEAP32[$58>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($209|0));
        $210 = __THREW__; __THREW__ = 0;
        $211 = $210&1;
        if ($211) {
         break;
        }
        if ($63) {
         label = 68;
        } else {
         $212 = (($209) + 12|0);
         $213 = HEAP32[$212>>2]|0;
         $214 = ($V_2$0>>>0)<($213>>>0);
         if (!($214)) {
          label = 68;
         }
        }
        if ((label|0) == 68) {
         __THREW__ = 0;
         $215 = (invoke_i(132)|0);
         $216 = __THREW__; __THREW__ = 0;
         $217 = $216&1;
         if ($217) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($215|0));
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if ($219) {
          break;
         }
        }
        $220 = HEAP32[$209>>2]|0;
        $221 = (($209) + 16|0);
        $222 = (($220) + 92|0);
        $223 = HEAP32[$222>>2]|0;
        $224 = Math_imul($223, $V_2$0)|0;
        $225 = (($__this) + 28|0);
        $226 = HEAP32[$225>>2]|0;
        $$sum4 = (($224) + 4)|0;
        $227 = (($221) + ($$sum4)|0);
        HEAP32[$227>>2] = $226;
        HEAP32[$225>>2] = $V_2$0;
        $228 = HEAP32[$58>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($228|0));
        $229 = __THREW__; __THREW__ = 0;
        $230 = $229&1;
        if ($230) {
         break;
        }
        if ($63) {
         label = 73;
        } else {
         $231 = (($228) + 12|0);
         $232 = HEAP32[$231>>2]|0;
         $233 = ($V_2$0>>>0)<($232>>>0);
         if (!($233)) {
          label = 73;
         }
        }
        if ((label|0) == 73) {
         __THREW__ = 0;
         $234 = (invoke_i(132)|0);
         $235 = __THREW__; __THREW__ = 0;
         $236 = $235&1;
         if ($236) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($234|0));
         $237 = __THREW__; __THREW__ = 0;
         $238 = $237&1;
         if ($238) {
          break;
         }
        }
        $239 = HEAP32[$228>>2]|0;
        $240 = (($228) + 16|0);
        $241 = (($239) + 92|0);
        $242 = HEAP32[$241>>2]|0;
        $243 = Math_imul($242, $V_2$0)|0;
        $244 = (($240) + ($243)|0);
        HEAP32[$244>>2] = 0;
        $245 = HEAP32[$59>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($245|0));
        $246 = __THREW__; __THREW__ = 0;
        $247 = $246&1;
        if ($247) {
         break;
        }
        if ($63) {
         label = 78;
        } else {
         $248 = (($245) + 12|0);
         $249 = HEAP32[$248>>2]|0;
         $250 = ($V_2$0>>>0)<($249>>>0);
         if (!($250)) {
          label = 78;
         }
        }
        if ((label|0) == 78) {
         __THREW__ = 0;
         $251 = (invoke_i(132)|0);
         $252 = __THREW__; __THREW__ = 0;
         $253 = $252&1;
         if ($253) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($251|0));
         $254 = __THREW__; __THREW__ = 0;
         $255 = $254&1;
         if ($255) {
          break;
         }
        }
        $256 = HEAP32[$245>>2]|0;
        $257 = (($245) + 16|0);
        $258 = (($256) + 92|0);
        $259 = HEAP32[$258>>2]|0;
        $260 = Math_imul($259, $V_2$0)|0;
        $261 = (($257) + ($260)|0);
        HEAP32[$261>>2] = 0;
        $262 = (($__this) + 20|0);
        $263 = HEAP32[$262>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($263|0));
        $264 = __THREW__; __THREW__ = 0;
        $265 = $264&1;
        if ($265) {
         break;
        }
        if ($63) {
         label = 83;
        } else {
         $266 = (($263) + 12|0);
         $267 = HEAP32[$266>>2]|0;
         $268 = ($V_2$0>>>0)<($267>>>0);
         if (!($268)) {
          label = 83;
         }
        }
        if ((label|0) == 83) {
         __THREW__ = 0;
         $269 = (invoke_i(132)|0);
         $270 = __THREW__; __THREW__ = 0;
         $271 = $270&1;
         if ($271) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($269|0));
         $272 = __THREW__; __THREW__ = 0;
         $273 = $272&1;
         if ($273) {
          break;
         }
        }
        $274 = HEAP32[$263>>2]|0;
        $275 = (($263) + 16|0);
        $276 = (($274) + 92|0);
        $277 = HEAP32[$276>>2]|0;
        $278 = Math_imul($277, $V_2$0)|0;
        $279 = (($275) + ($278)|0);
        HEAP32[$279>>2] = 0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $280 = __THREW__; __THREW__ = 0;
        $281 = $280&1;
        if ($281) {
         break;
        }
        $282 = (($__this) + 48|0);
        $283 = HEAP32[$282>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $284 = __THREW__; __THREW__ = 0;
        $285 = $284&1;
        if ($285) {
         break;
        }
        $286 = (($283) + 1)|0;
        HEAP32[$282>>2] = $286;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 88) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_TryGetValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectPS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$04 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341272);
 __THREW__ = 0;
 invoke_v(340);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021088>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[$__this>>2]|0;
    $22 = (($21) + 84|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + 92|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(1649,($25|0),($18|0),($key|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = $26 | -2147483648;
     $30 = (($__this) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($31|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      $34 = $26 & 2147483647;
      $35 = (($31) + 12|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($34|0) % ($36|0))&-1;
      __THREW__ = 0;
      invoke_vi(3799,($31|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $40 = HEAP32[$35>>2]|0;
       $41 = ($37>>>0)<($40>>>0);
       if (!($41)) {
        __THREW__ = 0;
        $42 = (invoke_i(132)|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($42|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
       }
       $47 = HEAP32[$31>>2]|0;
       $48 = (($31) + 16|0);
       $49 = (($47) + 92|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = Math_imul($50, $37)|0;
       $52 = (($48) + ($51)|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = ($53|0)==(0);
       if ($54) {
        $$0 = 0;$storemerge = 0;
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $55 = (($53) + -1)|0;
       $56 = (($__this) + 12|0);
       $57 = (($__this) + 16|0);
       $V_1$04 = $55;
       while(1) {
        $60 = HEAP32[$56>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($60|0));
        $143 = __THREW__; __THREW__ = 0;
        $144 = $143&1;
        if ($144) {
         label = 3;
         break;
        }
        $58 = ($V_1$04|0)<(0);
        if ($58) {
         label = 22;
        } else {
         $59 = (($60) + 12|0);
         $61 = HEAP32[$59>>2]|0;
         $62 = ($V_1$04>>>0)<($61>>>0);
         if (!($62)) {
          label = 22;
         }
        }
        if ((label|0) == 22) {
         label = 0;
         __THREW__ = 0;
         $63 = (invoke_i(132)|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($63|0));
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          label = 3;
          break;
         }
        }
        $68 = HEAP32[$60>>2]|0;
        $69 = (($60) + 16|0);
        $70 = (($68) + 92|0);
        $71 = HEAP32[$70>>2]|0;
        $72 = Math_imul($71, $V_1$04)|0;
        $73 = (($69) + ($72)|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ($74|0)==($29|0);
        if ($75) {
         $76 = HEAP32[$17>>2]|0;
         $77 = HEAP32[$57>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($77|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          label = 3;
          break;
         }
         if ($58) {
          label = 28;
         } else {
          $80 = (($77) + 12|0);
          $81 = HEAP32[$80>>2]|0;
          $82 = ($V_1$04>>>0)<($81>>>0);
          if (!($82)) {
           label = 28;
          }
         }
         if ((label|0) == 28) {
          label = 0;
          __THREW__ = 0;
          $83 = (invoke_i(132)|0);
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if ($85) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($83|0));
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 3;
           break;
          }
         }
         $88 = HEAP32[$77>>2]|0;
         $89 = (($77) + 16|0);
         $90 = (($88) + 92|0);
         $91 = HEAP32[$90>>2]|0;
         $92 = Math_imul($91, $V_1$04)|0;
         $93 = (($89) + ($92)|0);
         $94 = HEAP32[$93>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($76|0));
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          label = 3;
          break;
         }
         $97 = HEAP32[$__this>>2]|0;
         $98 = (($97) + 84|0);
         $99 = HEAP32[$98>>2]|0;
         $100 = (($99) + 96|0);
         $101 = HEAP32[$100>>2]|0;
         __THREW__ = 0;
         $102 = (invoke_iiiii(302,($101|0),($76|0),($94|0),($key|0))|0);
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          label = 3;
          break;
         }
         if ($102) {
          label = 33;
          break;
         }
        }
        $124 = HEAP32[$56>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($124|0));
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         label = 3;
         break;
        }
        if ($58) {
         label = 42;
        } else {
         $127 = (($124) + 12|0);
         $128 = HEAP32[$127>>2]|0;
         $129 = ($V_1$04>>>0)<($128>>>0);
         if (!($129)) {
          label = 42;
         }
        }
        if ((label|0) == 42) {
         label = 0;
         __THREW__ = 0;
         $130 = (invoke_i(132)|0);
         $131 = __THREW__; __THREW__ = 0;
         $132 = $131&1;
         if ($132) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($130|0));
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          label = 3;
          break;
         }
        }
        $135 = HEAP32[$124>>2]|0;
        $136 = (($124) + 16|0);
        $137 = (($135) + 92|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = Math_imul($138, $V_1$04)|0;
        $$sum = (($139) + 4)|0;
        $140 = (($136) + ($$sum)|0);
        $141 = HEAP32[$140>>2]|0;
        $142 = ($141|0)==(-1);
        if ($142) {
         $$0 = 0;$storemerge = 0;
         label = 46;
         break;
        } else {
         $V_1$04 = $141;
        }
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 33) {
        $105 = (($__this) + 20|0);
        $106 = HEAP32[$105>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($106|0));
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         break;
        }
        if ($58) {
         label = 36;
        } else {
         $109 = (($106) + 12|0);
         $110 = HEAP32[$109>>2]|0;
         $111 = ($V_1$04>>>0)<($110>>>0);
         if (!($111)) {
          label = 36;
         }
        }
        if ((label|0) == 36) {
         __THREW__ = 0;
         $112 = (invoke_i(132)|0);
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($112|0));
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break;
         }
        }
        $117 = HEAP32[$106>>2]|0;
        $118 = (($106) + 16|0);
        $119 = (($117) + 92|0);
        $120 = HEAP32[$119>>2]|0;
        $121 = Math_imul($120, $V_1$04)|0;
        $122 = (($118) + ($121)|0);
        $123 = HEAP32[$122>>2]|0;
        $$0 = 1;$storemerge = $123;
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 46) {
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Values_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341320);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_ii(3469,($4|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 $8 = HEAP32[$__this>>2]|0;
 $9 = (($8) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 152|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 __THREW__ = 0;
 invoke_vii($14|0,($5|0),($__this|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS6_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341416);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3497,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary);
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_U003CCopyToU003Em__0_gsharedP22mscorlib_System_ObjectS0_S0_PPv($agg$result,$__this,$key,$value,$rgctx) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1341464);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(571,($agg$result|0),($key|0),($value|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_VoidP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL193mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z201mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKey_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$comparer);
 STACKTOP = sp;return;
}
function __ZL154mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z162mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRootP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnly_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 0;
}
function __ZN14ActionInvoker1I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPFvPv105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPFbPv105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZL225mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL143mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z151mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z240mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL150mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionary_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z158mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionary_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CountP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_ItemP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Item_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker2I28mscorlib_System_ObjectTraitsS0_E6InvokeEPFvPvP22mscorlib_System_ObjectS4_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$2);
 STACKTOP = sp;return (0|0);
}
function __ZL110mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$hcp) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $hcp = $hcp|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Init_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$hcp);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitArraysP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitArrays_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$size);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToCheckP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToCheck_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvP22mscorlib_System_ObjectS6_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1344808,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_pick_valueP22mscorlib_System_ObjectS0_S0_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_pick_value_gsharedP22mscorlib_System_ObjectS0_S0_(0,0,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEPFP22mscorlib_System_ObjectPvS3_S3_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ResizeP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Resize_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_AddP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Add_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ClearP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Clear_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsValueP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetObjectDataP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetObjectData_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_RemoveP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Remove_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$key)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_TryGetValueP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectPS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_TryGetValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectPS2_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFbPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 $4 = $3&1;
 HEAP8[$ret>>0] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_ValuesP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Values_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker0I120mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPF114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1353952,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectS0_S0_($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1342952)|0);
 __Z134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_U003CCopyToU003Em__0_gsharedP22mscorlib_System_ObjectS0_S0_PPv($agg$result,0,$key,$value,0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvP22mscorlib_System_ObjectS6_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2307216,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_PPv($__this,$key,$value,$rgctx) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1344192);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vii($2|0,($__this|0),($key|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($rgctx) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($__this|0),($value|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1344240);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1344288);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1344336);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1344384);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z124mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ToString_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $G_B3_0$0 = 0, $G_B6_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1344432);
 __THREW__ = 0;
 invoke_v(341);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1168432|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2737,(1168432|0),5)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $19 = HEAP32[3021312>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($4|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[3021312>>2]|0;
       $23 = (($4) + 16|0);
       HEAP32[$23>>2] = $22;
       $24 = (($rgctx) + 8|0);
       $25 = HEAP32[$24>>2]|0;
       $26 = (($25) + 4|0);
       $27 = HEAP32[$26>>2]|0;
       __THREW__ = 0;
       $28 = (invoke_ii($27|0,($__this|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = ($28|0)==(0|0);
        if ($31) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         }
         $45 = HEAP8[((2191608 + 116|0))>>0]|0;
         $46 = ($45<<24>>24)==(0);
         if ($46) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3809,(2191608|0));
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          break;
         }
         $55 = HEAP32[((2191608 + 80|0))>>2]|0;
         $56 = HEAP32[$55>>2]|0;
         $G_B3_0$0 = $56;
        } else {
         $34 = HEAP32[$24>>2]|0;
         $35 = (($34) + 4|0);
         $36 = HEAP32[$35>>2]|0;
         __THREW__ = 0;
         $37 = (invoke_ii($36|0,($__this|0))|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($37|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break;
         }
         __THREW__ = 0;
         $42 = (invoke_iii(2730,(2149112|0),($37|0))|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          break;
         }
         $G_B3_0$0 = $42;
        }
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if (!($58)) {
         $59 = HEAP32[$9>>2]|0;
         $60 = ($59>>>0)<(2);
         if ($60) {
          __THREW__ = 0;
          $61 = (invoke_i(132)|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($61|0));
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($4|0),($G_B3_0$0|0));
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if (!($67)) {
          $68 = HEAP32[$4>>2]|0;
          $69 = (($68) + 92|0);
          $70 = HEAP32[$69>>2]|0;
          $71 = (($23) + ($70)|0);
          HEAP32[$71>>2] = $G_B3_0$0;
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if (!($73)) {
           $74 = HEAP32[$9>>2]|0;
           $75 = ($74>>>0)<(3);
           if ($75) {
            __THREW__ = 0;
            $76 = (invoke_i(132)|0);
            $77 = __THREW__; __THREW__ = 0;
            $78 = $77&1;
            if ($78) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($76|0));
            $79 = __THREW__; __THREW__ = 0;
            $80 = $79&1;
            if ($80) {
             break;
            }
           }
           $81 = HEAP32[3021320>>2]|0;
           __THREW__ = 0;
           invoke_vii(3492,($4|0),($81|0));
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if (!($83)) {
            $84 = HEAP32[3021320>>2]|0;
            $85 = HEAP32[$4>>2]|0;
            $86 = (($85) + 92|0);
            $87 = HEAP32[$86>>2]|0;
            $88 = $87 << 1;
            $89 = (($23) + ($88)|0);
            HEAP32[$89>>2] = $84;
            $90 = (($rgctx) + 16|0);
            $91 = HEAP32[$90>>2]|0;
            $92 = (($91) + 4|0);
            $93 = HEAP32[$92>>2]|0;
            __THREW__ = 0;
            $94 = (invoke_ii($93|0,($__this|0))|0);
            $95 = __THREW__; __THREW__ = 0;
            $96 = $95&1;
            if (!($96)) {
             $97 = ($94|0)==(0|0);
             if ($97) {
              __THREW__ = 0;
              (invoke_ii(2996,(2191608|0))|0);
              $98 = __THREW__; __THREW__ = 0;
              $99 = $98&1;
              if ($99) {
               break;
              }
              $111 = HEAP8[((2191608 + 116|0))>>0]|0;
              $112 = ($111<<24>>24)==(0);
              if ($112) {
               __THREW__ = 0;
               (invoke_ii(2996,(2191608|0))|0);
               $113 = __THREW__; __THREW__ = 0;
               $114 = $113&1;
               if ($114) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2191608|0))|0);
               $115 = __THREW__; __THREW__ = 0;
               $116 = $115&1;
               if ($116) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3809,(2191608|0));
               $117 = __THREW__; __THREW__ = 0;
               $118 = $117&1;
               if ($118) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2191608|0))|0);
              $119 = __THREW__; __THREW__ = 0;
              $120 = $119&1;
              if ($120) {
               break;
              }
              $121 = HEAP32[((2191608 + 80|0))>>2]|0;
              $122 = HEAP32[$121>>2]|0;
              $G_B6_0$0 = $122;
             } else {
              $100 = HEAP32[$90>>2]|0;
              $101 = (($100) + 4|0);
              $102 = HEAP32[$101>>2]|0;
              __THREW__ = 0;
              $103 = (invoke_ii($102|0,($__this|0))|0);
              $104 = __THREW__; __THREW__ = 0;
              $105 = $104&1;
              if ($105) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($103|0));
              $106 = __THREW__; __THREW__ = 0;
              $107 = $106&1;
              if ($107) {
               break;
              }
              __THREW__ = 0;
              $108 = (invoke_iii(2730,(2149112|0),($103|0))|0);
              $109 = __THREW__; __THREW__ = 0;
              $110 = $109&1;
              if ($110) {
               break;
              }
              $G_B6_0$0 = $108;
             }
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $123 = __THREW__; __THREW__ = 0;
             $124 = $123&1;
             if (!($124)) {
              $125 = HEAP32[$9>>2]|0;
              $126 = ($125>>>0)<(4);
              if ($126) {
               __THREW__ = 0;
               $127 = (invoke_i(132)|0);
               $128 = __THREW__; __THREW__ = 0;
               $129 = $128&1;
               if ($129) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($127|0));
               $130 = __THREW__; __THREW__ = 0;
               $131 = $130&1;
               if ($131) {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vii(3492,($4|0),($G_B6_0$0|0));
              $132 = __THREW__; __THREW__ = 0;
              $133 = $132&1;
              if (!($133)) {
               $134 = HEAP32[$4>>2]|0;
               $135 = (($134) + 92|0);
               $136 = HEAP32[$135>>2]|0;
               $137 = ($136*3)|0;
               $138 = (($23) + ($137)|0);
               HEAP32[$138>>2] = $G_B6_0$0;
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $139 = __THREW__; __THREW__ = 0;
               $140 = $139&1;
               if ($140) {
                break;
               }
               $141 = HEAP32[$9>>2]|0;
               $142 = ($141>>>0)<(5);
               if ($142) {
                __THREW__ = 0;
                $143 = (invoke_i(132)|0);
                $144 = __THREW__; __THREW__ = 0;
                $145 = $144&1;
                if ($145) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($143|0));
                $146 = __THREW__; __THREW__ = 0;
                $147 = $146&1;
                if ($147) {
                 break;
                }
               }
               $148 = HEAP32[3021328>>2]|0;
               __THREW__ = 0;
               invoke_vii(3492,($4|0),($148|0));
               $149 = __THREW__; __THREW__ = 0;
               $150 = $149&1;
               if ($150) {
                break;
               }
               $151 = HEAP32[3021328>>2]|0;
               $152 = HEAP32[$4>>2]|0;
               $153 = (($152) + 92|0);
               $154 = HEAP32[$153>>2]|0;
               $155 = $154 << 2;
               $156 = (($23) + ($155)|0);
               HEAP32[$156>>2] = $151;
               __THREW__ = 0;
               $157 = (invoke_iii(639,(0|0),($4|0))|0);
               $158 = __THREW__; __THREW__ = 0;
               $159 = $158&1;
               if ($159) {
                break;
               }
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($157|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __ZL115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_KeyP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_ValueP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ToStringP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1344808)|0);
 $0 = HEAP32[((1344808 + 84|0))>>2]|0;
 $1 = (__Z124mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ToString_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1344952);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z193mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1345000);
 __THREW__ = 0;
 invoke_vii(1276,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(1344808|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(1344808|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z162mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1345144);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(810,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_DisposeP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1345048);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z159mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNextP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1345096);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1344808,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z72mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m__ctorP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32P21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1346624);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m_System_Collections_IEnumerator_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1346672);
 __THREW__ = 0;
 $0 = (invoke_ii(821,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2155952|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2155952|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1346816);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1276,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m_DisposeP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1346720);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m_MoveNextP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1346768);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1348888);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z128mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1348936);
 __THREW__ = 0;
 invoke_vii(1279,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2288504|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2288504|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1349080);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(817,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1348984);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1349032);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I46mscorlib_System_Collections_Generic_LinkTraitsE6InvokeEPF40mscorlib_System_Collections_Generic_LinkPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2288504,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1350912);
 __THREW__ = 0;
 invoke_v(342);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1924,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = ($dictionary|0)==(0|0);
   if (!($4)) {
    $17 = (($__this) + 8|0);
    HEAP32[$17>>2] = $dictionary;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[3021160>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3808,($9|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Add_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1350960);
 __THREW__ = 0;
 invoke_v(343);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3808,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Clear_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351008);
 __THREW__ = 0;
 invoke_v(344);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021280>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3808,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Contains_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351056);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 }
 $4 = HEAP32[$__this>>2]|0;
 $5 = (($4) + 84|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 __THREW__ = 0;
 $10 = (invoke_iii($9|0,($1|0),($item|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __Z191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Remove_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351104);
 __THREW__ = 0;
 invoke_v(345);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021296>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3808,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z198mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumerator_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351152);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii($6|0,($L_0|0),($__this|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
 $9 = HEAP32[$__this>>2]|0;
 $10 = (($9) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 __THREW__ = 0;
 $14 = (invoke_iii(2724,($13|0),($L_1|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($14|0);
 }
 return 0|0;
}
function __Z167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351200);
 $1 = HEAP32[$__this>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iii(2735,($_____array|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   $9 = ($6|0)==(0|0);
   if (!($9)) {
    $12 = HEAP32[$__this>>2]|0;
    $13 = (($12) + 84|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($14) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_viiii(461,($16|0),($__this|0),($6|0),($index|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $19 = (($__this) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($20|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 84|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 20|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 4|0);
    $29 = HEAP32[$28>>2]|0;
    __THREW__ = 0;
    invoke_viii($29|0,($20|0),($_____array|0),($index|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = HEAP32[$19>>2]|0;
     $33 = HEAP32[$__this>>2]|0;
     $34 = (($33) + 84|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($35) + 24|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = (($35) + 28|0);
     $39 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     $40 = (invoke_ii(3469,($39|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      $43 = HEAP32[$__this>>2]|0;
      $44 = (($43) + 84|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = (($45) + 32|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = (($47) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      HEAP32[$0>>2] = $37;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_viii($49|0,($40|0),(0|0),($$byval_copy|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if (!($51)) {
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if (!($53)) {
        $54 = HEAP32[$__this>>2]|0;
        $55 = (($54) + 84|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = (($56) + 36|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = (($58) + 4|0);
        $60 = HEAP32[$59>>2]|0;
        __THREW__ = 0;
        invoke_viiii($60|0,($32|0),($_____array|0),($index|0),($40|0));
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if (!($62)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z199mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnly_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351248);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351296);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2740,(2231320|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351344);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = HEAP32[$__this>>2]|0;
  $6 = (($5) + 84|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  __THREW__ = 0;
  invoke_viii($11|0,($2|0),($_____array|0),($index|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = HEAP32[$1>>2]|0;
   $15 = HEAP32[$__this>>2]|0;
   $16 = (($15) + 84|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($17) + 24|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_ii(3469,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP32[$__this>>2]|0;
    $26 = (($25) + 84|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (($27) + 32|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = (($29) + 4|0);
    $31 = HEAP32[$30>>2]|0;
    HEAP32[$0>>2] = $19;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viii($31|0,($22|0),(0|0),($$byval_copy|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      $36 = HEAP32[$__this>>2]|0;
      $37 = (($36) + 84|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($38) + 40|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + 4|0);
      $42 = HEAP32[$41>>2]|0;
      __THREW__ = 0;
      invoke_viiii($42|0,($14|0),($_____array|0),($index|0),($22|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $45 = ___cxa_find_matching_catch()|0;
 $46 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($45|0);
 // unreachable;
}
function __Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetEnumeratorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351392);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1283,($agg$result|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1352912)|0);
 $0 = HEAP32[((1352912 + 84|0))>>2]|0;
 __Z146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$host,$0);
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1351440);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = HEAP32[$__this>>2]|0;
  $5 = (($4) + 84|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  __THREW__ = 0;
  $9 = (invoke_iii(2729,($8|0),($1|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($9|0);
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZL127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary);
 STACKTOP = sp;return;
}
function __ZL180mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Add_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL182mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Clear_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object(0);
 // unreachable;
}
function __ZL185mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Contains_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Remove_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z198mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumerator_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyToP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z199mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnly_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 1;
}
function __ZL165mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRootP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL128mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPF130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1352912,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL131mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CountP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$host,$rgctx) {
 $__this = $__this|0;
 $host = $host|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1352440);
 __THREW__ = 0;
 invoke_vi(3799,($host|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 $2 = HEAP32[$rgctx>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vii($4|0,($L_0|0),($host|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  ;HEAP32[$__this+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$__this+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$__this+16>>2]=HEAP32[$L_0+16>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1352488);
 $0 = (($rgctx) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 $4 = (invoke_ii($3|0,($__this|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1352536);
 $0 = (($rgctx) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi($3|0,($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1352584);
 $0 = (($rgctx) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 $4 = (invoke_ii($3|0,($__this|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z152mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1352632);
 $0 = (($__this) + 12|0);
 $1 = (($rgctx) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_ii($4|0,($0|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __ZL175mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1352912)|0);
 $0 = HEAP32[((1352912 + 84|0))>>2]|0;
 $1 = (__Z183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_DisposeP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1352912)|0);
 $0 = HEAP32[((1352912 + 84|0))>>2]|0;
 __Z148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL141mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNextP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1352912)|0);
 $0 = HEAP32[((1352912 + 84|0))>>2]|0;
 $1 = (__Z149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL144mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1352912)|0);
 $0 = HEAP32[((1352912 + 84|0))>>2]|0;
 $1 = (__Z152mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353056);
 HEAP32[$__this>>2] = $dictionary;
 __THREW__ = 0;
 invoke_vi(3799,($dictionary|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($dictionary) + 48|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353104);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($2|0,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($21|0);
  // unreachable;
 }
 $5 = (($__this) + 12|0);
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $L_1;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($rgctx) + 4|0);
 $17 = HEAP32[$16>>2]|0;
 __THREW__ = 0;
 $18 = (invoke_iii(2724,($17|0),($L_1|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($21|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($18|0);
 }
 return 0|0;
}
function __Z175mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionaryEnumerator_get_Entry_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($agg$result,$__this,$rgctx) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353152);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($2|0,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($__this) + 12|0);
  $6 = (($rgctx) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  __THREW__ = 0;
  $10 = (invoke_ii($9|0,($5|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = (($rgctx) + 16|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 4|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   $17 = (invoke_ii($16|0,($5|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = $agg$result;
    $21 = $20;
    HEAP32[$21>>2] = 0;
    $22 = (($20) + 4)|0;
    $23 = $22;
    HEAP32[$23>>2] = 0;
    __THREW__ = 0;
    invoke_viii(571,($agg$result|0),($10|0),($17|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($26|0);
 // unreachable;
}
function __Z133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_22 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_22 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353200);
 $0 = (($rgctx) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi($3|0,($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($__this) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)>(-1);
   if (!($8)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $107 = $7;
   while(1) {
    $101 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($101|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 4;
     break;
    }
    $104 = (($101) + 24|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = ($107|0)<($105|0);
    if (!($106)) {
     label = 31;
     break;
    }
    $19 = HEAP32[$6>>2]|0;
    $108 = (($19) + 1)|0;
    HEAP32[$6>>2] = $108;
    $14 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($14|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 4;
     break;
    }
    $13 = (($14) + 12|0);
    $15 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 4;
     break;
    }
    $18 = ($19|0)<(0);
    if ($18) {
     label = 10;
    } else {
     $20 = (($15) + 12|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($19>>>0)<($21>>>0);
     if (!($22)) {
      label = 10;
     }
    }
    if ((label|0) == 10) {
     label = 0;
     __THREW__ = 0;
     $23 = (invoke_i(132)|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($23|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 4;
      break;
     }
    }
    $28 = HEAP32[$15>>2]|0;
    $29 = (($15) + 16|0);
    $30 = (($28) + 92|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = Math_imul($31, $19)|0;
    $33 = (($29) + ($32)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)<(0);
    if ($35) {
     label = 14;
     break;
    }
    $$pre = HEAP32[$6>>2]|0;
    $107 = $$pre;
   }
   if ((label|0) == 4) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    $lpad$phi$index = $9;$lpad$phi$index2 = $10;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 14) {
    $36 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    $39 = (($36) + 16|0);
    $40 = HEAP32[$39>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($40|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    if ($18) {
     label = 18;
    } else {
     $43 = (($40) + 12|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($19>>>0)<($44>>>0);
     if (!($45)) {
      label = 18;
     }
    }
    if ((label|0) == 18) {
     __THREW__ = 0;
     $46 = (invoke_i(132)|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($46|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
    }
    $51 = HEAP32[$40>>2]|0;
    $52 = (($40) + 16|0);
    $53 = (($51) + 92|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = Math_imul($54, $19)|0;
    $56 = (($52) + ($55)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($58|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    $61 = (($58) + 20|0);
    $62 = HEAP32[$61>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($62|0));
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     break;
    }
    if ($18) {
     label = 24;
    } else {
     $65 = (($62) + 12|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = ($19>>>0)<($66>>>0);
     if (!($67)) {
      label = 24;
     }
    }
    if ((label|0) == 24) {
     __THREW__ = 0;
     $68 = (invoke_i(132)|0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($68|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      break;
     }
    }
    $73 = HEAP32[$62>>2]|0;
    $74 = (($62) + 16|0);
    $75 = (($73) + 92|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = Math_imul($76, $19)|0;
    $78 = (($74) + ($77)|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = $L_22;
    $81 = $80;
    HEAP32[$81>>2] = 0;
    $82 = (($80) + 4)|0;
    $83 = $82;
    HEAP32[$83>>2] = 0;
    $84 = (($rgctx) + 28|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = (($85) + 4|0);
    $87 = HEAP32[$86>>2]|0;
    __THREW__ = 0;
    invoke_viii($87|0,($L_22|0),($57|0),($79|0));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     break;
    }
    $90 = (($__this) + 12|0);
    $91 = $L_22;
    $92 = $91;
    $93 = HEAP32[$92>>2]|0;
    $94 = (($91) + 4)|0;
    $95 = $94;
    $96 = HEAP32[$95>>2]|0;
    $97 = $90;
    $98 = $97;
    HEAP32[$98>>2] = $93;
    $99 = (($97) + 4)|0;
    $100 = $99;
    HEAP32[$100>>2] = $96;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 31) {
    HEAP32[$6>>2] = -1;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353248);
 $0 = (($__this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z141mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentValue_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353296);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($2|0,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 }
 $5 = (($__this) + 12|0);
 $6 = (($rgctx) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 __THREW__ = 0;
 $10 = (invoke_ii($9|0,($5|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __Z136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyState_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353344);
 __THREW__ = 0;
 invoke_v(346);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2634432|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2634432|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1970,($8|0),(0|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($8|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($2) + 48|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if ($21) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     $24 = (invoke_ii(3469,(2607872|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[3021104>>2]|0;
      __THREW__ = 0;
      invoke_vii(1947,($24|0),($27|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vi(3808,($24|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyCurrent_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353392);
 __THREW__ = 0;
 invoke_v(347);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($rgctx) + 24|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  invoke_vi($5|0,($__this|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($__this) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)>(0);
   if ($10) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_ii(3469,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[3021144>>2]|0;
     __THREW__ = 0;
     invoke_vii(1947,($15|0),($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3808,($15|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1353440);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZL159mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1353952)|0);
 $0 = HEAP32[((1353952 + 84|0))>>2]|0;
 $1 = (__Z167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionaryEnumerator_get_EntryP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1353952)|0);
 $0 = HEAP32[((1353952 + 84|0))>>2]|0;
 __Z175mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionaryEnumerator_get_Entry_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($agg$result,$__this,$0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I49mscorlib_System_Collections_DictionaryEntryTraitsE6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2307216,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNextP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1353952)|0);
 $0 = HEAP32[((1353952 + 84|0))>>2]|0;
 $1 = (__Z133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentValueP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1353952)|0);
 $0 = HEAP32[((1353952 + 84|0))>>2]|0;
 $1 = (__Z141mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentValue_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyStateP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyState_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyCurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1353952)|0);
 $0 = HEAP32[((1353952 + 84|0))>>2]|0;
 __Z138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyCurrent_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_DisposeP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __Z163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1354096);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z164mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Invoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1354144);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_iiii(1650,($1|0),($key|0),($value|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiii($8|0,($10|0),($key|0),($value|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __ZL156mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z164mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Invoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z169mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1354192);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1354240);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __ZL155mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$method>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZL161mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z169mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_(0,0,0,0,0)|0);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_S0_S1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS5_S3_S5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZL159mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object(0,0)|0);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFP22mscorlib_System_ObjectPvS5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1354728);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z177mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_ObjectS2_($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1354776);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(93,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z182mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1354824);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z180mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1354872);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraitsE6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2307216,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m__ctorP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1355544);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1355592);
 __THREW__ = 0;
 invoke_vii(1288,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2307216|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2307216|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1355736);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(821,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m_DisposeP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1355640);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m_MoveNextP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1355688);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z238mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1357568);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z239mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1357616);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(94,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z244mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1357664);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z242mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1357712);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1344808,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z134mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1358144);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($host|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[$__this>>2]|0;
   $5 = (($4) + 84|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vii($9|0,($L_0|0),($host|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($__this) + 8|0);
    ;HEAP32[$12+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$12+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$12+16>>2]=HEAP32[$L_0+16>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z137mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1358192);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$__this>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 $8 = (invoke_ii($7|0,($0|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z138mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Entry_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1358240);
 $0 = (($__this) + 8|0);
 ;HEAP32[$L_1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$0+16>>2]|0;
 $1 = HEAP32[$__this>>2]|0;
 $2 = (($1) + 84|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iii(2724,($5|0),($L_1|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __THREW__ = 0;
  invoke_vi(3799,($6|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   invoke_viii(2114,($agg$result|0),(2311136|0),($6|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker0I49mscorlib_System_Collections_DictionaryEntryTraitsE6InvokeEP10MethodInfoPv($agg$result,$method,$obj) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($agg$result,$4);
 STACKTOP = sp;return;
}
function __Z140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1358288);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viii(2115,($L_0|0),($4|0),($__this|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = $L_0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = $L_1;
  $14 = $13;
  HEAP32[$14>>2] = $9;
  $15 = (($13) + 4)|0;
  $16 = $15;
  HEAP32[$16>>2] = $12;
  __THREW__ = 0;
  (invoke_ii(2996,(2307216|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iii(2724,(2307216|0),($L_1|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker0I49mscorlib_System_Collections_DictionaryEntryTraitsE6InvokeEP10MethodInfoPv($agg$result,$method,$obj) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($agg$result,$4);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z134mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$host);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNextP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z137mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL130mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_EntryP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z138mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Entry_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_set_KeyP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_set_ValueP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ToStringP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1360328)|0);
 $0 = HEAP32[((1360328 + 84|0))>>2]|0;
 $1 = (__Z124mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ToString_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1360472);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z193mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1360520);
 __THREW__ = 0;
 invoke_vii(1294,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(1360328|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(1360328|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z162mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1360664);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3808,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(825,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_DisposeP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1360568);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z159mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_MoveNextP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1360616);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1360328,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_GetEnumeratorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1361888);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1298,($agg$result|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1363488)|0);
 $0 = HEAP32[((1363488 + 84|0))>>2]|0;
 __Z146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$host,$0);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary);
 STACKTOP = sp;return;
}
function __ZL180mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Add_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL182mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Clear_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object(0);
 // unreachable;
}
function __ZL185mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Contains_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Remove_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z198mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumerator_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_ICollection_CopyToP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z199mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnly_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 1;
}
function __ZL165mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_ICollection_get_SyncRootP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL128mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_CopyToP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP26mscorlib_System_String_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPF130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1363488,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL131mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CountP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL175mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1363488)|0);
 $0 = HEAP32[((1363488 + 84|0))>>2]|0;
 $1 = (__Z183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_DisposeP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1363488)|0);
 $0 = HEAP32[((1363488 + 84|0))>>2]|0;
 __Z148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL141mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_MoveNextP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1363488)|0);
 $0 = HEAP32[((1363488 + 84|0))>>2]|0;
 $1 = (__Z149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL144mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1363488)|0);
 $0 = HEAP32[((1363488 + 84|0))>>2]|0;
 $1 = (__Z152mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1363632);
 $0 = (($__this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZL159mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1364424)|0);
 $0 = HEAP32[((1364424 + 84|0))>>2]|0;
 $1 = (__Z167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IDictionaryEnumerator_get_EntryP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1364424)|0);
 $0 = HEAP32[((1364424 + 84|0))>>2]|0;
 __Z175mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionaryEnumerator_get_Entry_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($agg$result,$__this,$0);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_MoveNextP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1364424)|0);
 $0 = HEAP32[((1364424 + 84|0))>>2]|0;
 $1 = (__Z133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentValueP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1364424)|0);
 $0 = HEAP32[((1364424 + 84|0))>>2]|0;
 $1 = (__Z141mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentValue_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_VerifyStateP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyState_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_VerifyCurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1364424)|0);
 $0 = HEAP32[((1364424 + 84|0))>>2]|0;
 __Z138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyCurrent_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_DisposeP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL155mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$method>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZL156mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String_m_InvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z164mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Invoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL161mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String_m_BeginInvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_P29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z169mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_(0,0,0,0,0)|0);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS3_S3_S3_S3_P22mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZL159mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String_m_EndInvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object(0,0)|0);
 STACKTOP = sp;return (0|0);
}
function __Z176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1365144);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z177mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringS2_($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1365192);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(95,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z182mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringS2_P29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1365240);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z180mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1365288);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z238mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1365720);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z239mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_InvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1365768);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(96,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z244mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_BeginInvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_P29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1365816);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z242mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_EndInvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1365864);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraits17VoidPointerTraitsE6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1360328,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z134mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$host);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_MoveNextP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z137mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL130mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_EntryP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z138mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Entry_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z230mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1366832);
 __THREW__ = 0;
 $0 = (invoke_ii(3470,($keyValuePair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3471,($keyValuePair|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viiii(460,(1366880|0),($__this|0),($0|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z235mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1366928);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(307,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ContainsKeyValuePairP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$pair) {
 $__this = $__this|0;
 $pair = $pair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1367120);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(3470,($pair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiii(299,(1367168|0),($__this|0),($0|0),($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   if (!($3)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_ii(791,(0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3471,($pair|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP32[$V_0>>2]|0;
      __THREW__ = 0;
      $17 = (invoke_iiiii(299,(1328752|0),($8|0),($11|0),($16|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1366976);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(307,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  if (!($11)) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $16 = (invoke_ii(3470,($keyValuePair|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iiii(1640,(1367024|0),($__this|0),($16|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_make_pairP22mscorlib_System_ObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1367072);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 (invoke_ii(2996,(1378648|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = HEAP32[((1378648 + 84|0))>>2]|0;
  __THREW__ = 0;
  invoke_viiii(466,($agg$result|0),($key|0),($value|0),($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_GetEnumeratorP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1367216);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3497,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_VoidP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL201mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z201mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKey_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$comparer);
 STACKTOP = sp;return;
}
function __ZL162mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjecti($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z162mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_get_SyncRootP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnly_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 0;
}
function __ZN14ActionInvoker1I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPFvPv113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPFbPv113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZL233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP92mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CJSONObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL151mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_CopyToP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z151mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL240mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z240mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL158mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IDictionary_GetEnumeratorP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z158mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionary_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CountP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_set_ItemP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Item_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_InitP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectiP22mscorlib_System_Object($__this,$capacity,$hcp) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $hcp = $hcp|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Init_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$hcp);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_InitArraysP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjecti($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitArrays_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$size);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_CopyToCheckP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToCheck_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraits17VoidPointerTraitsS1_E6InvokeEPF113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1378648,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_pick_valueP22mscorlib_System_ObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_pick_value_gsharedP22mscorlib_System_ObjectS0_S0_(0,0,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_CopyToP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP92mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CJSONObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ResizeP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Resize_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_AddP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Add_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ClearP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Clear_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ContainsValueP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_GetObjectDataP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetObjectData_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_RemoveP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Remove_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$key)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_TryGetValueP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringPP30AssemblyU002DCSharp_JSONObject($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_TryGetValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectPS2_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_ValuesP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Values_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker0I128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPF122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1383624,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1369760)|0);
 __Z134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_U003CCopyToU003Em__0_gsharedP22mscorlib_System_ObjectS0_S0_PPv($agg$result,0,$key,$value,0);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1378648)|0);
 $0 = HEAP32[((1378648 + 84|0))>>2]|0;
 __Z121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_PPv($__this,$key,$value,$0);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_KeyP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_set_KeyP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_ValueP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_set_ValueP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ToStringP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1378648)|0);
 $0 = HEAP32[((1378648 + 84|0))>>2]|0;
 $1 = (__Z124mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ToString_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z164mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1378792);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z201mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1378840);
 __THREW__ = 0;
 invoke_vii(1312,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(1378648|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(1378648|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z170mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1378984);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(829,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z166mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_DisposeP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1378888);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z167mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_MoveNextP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1378936);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1501($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPF113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1378648,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z143mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_GetEnumeratorP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1380424);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1316,($agg$result|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1382552)|0);
 $0 = HEAP32[((1382552 + 84|0))>>2]|0;
 __Z146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$host,$0);
 STACKTOP = sp;return;
}
function __ZL135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary);
 STACKTOP = sp;return;
}
function __ZL188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Add_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Clear_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Contains_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Remove_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL198mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z198mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumerator_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_CopyToP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL199mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z199mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnly_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_get_SyncRootP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_CopyToP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP34AssemblyU002DCSharp_JSONObject_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I144mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPF138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1382552,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CountP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1382552)|0);
 $0 = HEAP32[((1382552 + 84|0))>>2]|0;
 $1 = (__Z183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_DisposeP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1382552)|0);
 $0 = HEAP32[((1382552 + 84|0))>>2]|0;
 __Z148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_MoveNextP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1382552)|0);
 $0 = HEAP32[((1382552 + 84|0))>>2]|0;
 $1 = (__Z149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL152mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1382552)|0);
 $0 = HEAP32[((1382552 + 84|0))>>2]|0;
 $1 = (__Z152mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1382696);
 $0 = (($__this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary);
 STACKTOP = sp;return;
}
function __ZL167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1383624)|0);
 $0 = HEAP32[((1383624 + 84|0))>>2]|0;
 $1 = (__Z167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL175mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IDictionaryEnumerator_get_EntryP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1383624)|0);
 $0 = HEAP32[((1383624 + 84|0))>>2]|0;
 __Z175mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionaryEnumerator_get_Entry_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($agg$result,$__this,$0);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_MoveNextP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1383624)|0);
 $0 = HEAP32[((1383624 + 84|0))>>2]|0;
 $1 = (__Z133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL141mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentValueP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1383624)|0);
 $0 = HEAP32[((1383624 + 84|0))>>2]|0;
 $1 = (__Z141mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentValue_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_VerifyStateP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyState_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_VerifyCurrentP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1383624)|0);
 $0 = HEAP32[((1383624 + 84|0))>>2]|0;
 __Z138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyCurrent_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_DisposeP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL171mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$method>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZL172mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject_m_InvokeP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z164mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Invoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL177mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject_m_BeginInvokeP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z169mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_($__this,$key,$value,$callback,$object)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL175mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject_m_EndInvokeP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$result)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z184mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1384400);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z185mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1384448);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(99,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z190mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1384496);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z188mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1384544);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z254mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1384976);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z255mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_InvokeP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1385024);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(100,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z260mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_BeginInvokeP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1385072);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z258mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_EndInvokeP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1385120);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraits17VoidPointerTraitsE6InvokeEPF113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1378648,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL134mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z134mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$host);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_MoveNextP126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z137mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL138mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_EntryP126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z138mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Entry_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this);
 STACKTOP = sp;return;
}
function __ZL140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentP126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z83mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m__ctorP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1386120);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1386168);
 __THREW__ = 0;
 (invoke_ii(2996,(1388040|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1388040|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1517,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1386952|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1386952 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z99mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Char_m__ctorP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Char($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1387688);
 __THREW__ = 0;
 invoke_vi(1515,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z126mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m_System_Collections_IEqualityComparer_GetHashCodeP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_CharP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1386216);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2742,($obj|0),(2180696|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP16[$2>>1]|0;
   __THREW__ = 0;
   $6 = (invoke_iiii(1651,(1386264|0),($__this|0),($5|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsE6InvokeEP10MethodInfoPvt($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z121mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m_System_Collections_IEqualityComparer_EqualsP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_CharP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1386312);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2742,($x|0),(2180696|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP16[$2>>1]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2742,($y|0),(2180696|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP16[$8>>1]|0;
     __THREW__ = 0;
     $12 = (invoke_iiiii(303,(1386360|0),($__this|0),($5|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($12|0);
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS1_E6InvokeEP10MethodInfoPvtt($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z89mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1386408);
 __THREW__ = 0;
 (invoke_ii(2996,(1386952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1386952 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1386952|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1386952|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3811,(1386952|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1386952|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1386952 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZL11RuntimeInitP8TypeInfo1504($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Char_m_GetHashCodeP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Chart($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 6|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 HEAP16[$0>>1] = $obj;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1387736);
 $1 = HEAP16[$0>>1]|0;
 HEAP16[$L_0>>1] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2724,(2180696|0),($L_0|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)==(0|0);
   if ($7) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(2724,(2180696|0),($0|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3799,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_iii(2724,(2180696|0),($0|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        $22 = (invoke_iii(2729,(2148880|0),($19|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         $$0 = $22;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Char_m_EqualsP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Chartt($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_5 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 10|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $L_2 = sp + 6|0;
 $L_5 = sp + 8|0;
 HEAP16[$0>>1] = $x;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1387784);
 $1 = HEAP16[$0>>1]|0;
 HEAP16[$L_0>>1] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2180696|0),($L_0|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if ($7) {
     HEAP16[$L_2>>1] = $y;
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(2724,(2180696|0),($L_2|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = ($12|0)==(0|0);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    HEAP16[$L_5>>1] = $y;
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     $18 = (invoke_iii(2724,(2180696|0),($L_5|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       $23 = (invoke_iii(2724,(2180696|0),($0|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        invoke_vi(3799,($23|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2180696|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          __THREW__ = 0;
          $30 = (invoke_iii(2724,(2180696|0),($0|0))|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           $33 = (invoke_iiii(1644,(2148736|0),($30|0),($18|0))|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $$0 = $33;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsE6InvokeEPFiPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS1_E6InvokeEPFbPvttES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 $6 = $5&1;
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m__ctorP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1388424);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z123mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m_System_Collections_IEnumerator_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1388472);
 __THREW__ = 0;
 $0 = (invoke_ii(881,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(1273800|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(1273800|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1388616);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1292,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m_DisposeP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1388520);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m_MoveNextP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1388568);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z87System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m__ctor_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390512);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$__this>>2]|0;
  $3 = (($2) + 84|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_viii($7|0,($__this|0),10,(0|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z145System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp;
 $L_1 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390560);
 ;HEAP32[$L_0+0>>2]=0|0;HEAP32[$L_0+4>>2]=0|0;HEAP32[$L_0+8>>2]=0|0;HEAP32[$L_0+12>>2]=0|0;
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vii($6|0,($L_0|0),($__this|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;
 $9 = HEAP32[$__this>>2]|0;
 $10 = (($9) + 84|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 __THREW__ = 0;
 $14 = (invoke_iii(2724,($13|0),($L_1|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($14|0);
 }
 return 0|0;
}
function __Z146System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390608);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z138System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_CopyTo_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390656);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_viiii(461,($4|0),($__this|0),($_____array|0),($index|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z135System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_Add_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390704);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 (invoke_iii($6|0,($__this|0),($item|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z91System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_get_Count_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390752);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z86System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Init_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$comparer) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B4_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390800);
 __THREW__ = 0;
 invoke_v(348);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($capacity|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3002200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($comparer|0)==(0|0);
   if ($15) {
    $16 = HEAP32[$__this>>2]|0;
    $17 = (($16) + 84|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 20|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    $23 = (invoke_ii($22|0,(0|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    $G_B4_0$0 = $23;
   } else {
    $G_B4_0$0 = $comparer;
   }
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = (($__this) + 36|0);
    HEAP32[$28>>2] = $G_B4_0$0;
    $29 = ($capacity|0)==(0);
    $30 = (Math_fround(($capacity|0)));
    $31 = $29 ? Math_fround(10.0) : $30;
    $32 = Math_fround($31 / Math_fround(0.899999976158142089843));
    $33 = (~~(($32)));
    $34 = (($33) + 1)|0;
    $35 = HEAP32[$__this>>2]|0;
    $36 = (($35) + 84|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($39) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    __THREW__ = 0;
    invoke_vii($41|0,($__this|0),($34|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     $44 = (($__this) + 40|0);
     HEAP32[$44>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z92System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_InitArrays_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Objecti($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390848);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2743,(1170368|0),($size|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $2;
   $6 = HEAP32[$__this>>2]|0;
   $7 = (($6) + 84|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + 28|0);
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iii(2743,($10|0),($size|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = (($__this) + 12|0);
    HEAP32[$14>>2] = $11;
    $15 = (($__this) + 24|0);
    HEAP32[$15>>2] = -1;
    $16 = HEAP32[$__this>>2]|0;
    $17 = (($16) + 84|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 32|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    $21 = (invoke_iii(2743,($20|0),($size|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = (($__this) + 16|0);
     HEAP32[$24>>2] = $21;
     $25 = (($__this) + 20|0);
     HEAP32[$25>>2] = 0;
     $26 = HEAP32[$5>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = (($26) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (Math_fround(($30|0)));
      $32 = Math_fround($31 * Math_fround(0.899999976158142089843));
      $33 = (~~(($32)));
      $34 = (($__this) + 32|0);
      HEAP32[$34>>2] = $33;
      $35 = ($33|0)==(0);
      if (!($35)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $38 = HEAP32[$5>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($38|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = (($38) + 12|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42|0)<(1);
       if ($43) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       HEAP32[$34>>2] = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($36|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj1507($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z97System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_SlotsContainsAt_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectiiP22mscorlib_System_Object($__this,$index,$hash,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $hash = $hash|0;
 $item = $item|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390896);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($index|0)<(0);
   if ($4) {
    label = 4;
   } else {
    $5 = (($1) + 12|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6>>>0)>($index>>>0);
    if (!($7)) {
     label = 4;
    }
   }
   if ((label|0) == 4) {
    __THREW__ = 0;
    $8 = (invoke_i(132)|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
   }
   $17 = HEAP32[$1>>2]|0;
   $18 = (($1) + 16|0);
   $19 = (($17) + 92|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = Math_imul($20, $index)|0;
   $22 = (($18) + ($21)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0);
   if ($24) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $25 = (($23) + -1)|0;
   $26 = (($__this) + 12|0);
   $27 = ($hash|0)==(-2147483648);
   $28 = ($item|0)==(0|0);
   $29 = (($__this) + 16|0);
   $30 = (($__this) + 36|0);
   $V_0$01 = $25;
   L12: while(1) {
    $33 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($33|0));
    $118 = __THREW__; __THREW__ = 0;
    $119 = $118&1;
    if ($119) {
     label = 6;
     break;
    }
    $31 = ($V_0$01|0)<(0);
    if ($31) {
     label = 13;
    } else {
     $32 = (($33) + 12|0);
     $34 = HEAP32[$32>>2]|0;
     $35 = ($V_0$01>>>0)<($34>>>0);
     if (!($35)) {
      label = 13;
     }
    }
    if ((label|0) == 13) {
     label = 0;
     __THREW__ = 0;
     $36 = (invoke_i(132)|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 6;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($36|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 6;
      break;
     }
    }
    $41 = HEAP32[$33>>2]|0;
    $42 = (($33) + 16|0);
    $43 = (($41) + 92|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = Math_imul($44, $V_0$01)|0;
    $46 = (($42) + ($45)|0);
    $47 = HEAP32[$46>>2]|0;
    $$sum = (($45) + 4)|0;
    $48 = (($42) + ($$sum)|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($47|0)==($hash|0);
    L21: do {
     if ($50) {
      do {
       if ($27) {
        $52 = HEAP32[$29>>2]|0;
        if ($28) {
         __THREW__ = 0;
         invoke_vi(3799,($52|0));
         $71 = __THREW__; __THREW__ = 0;
         $72 = $71&1;
         if ($72) {
          label = 6;
          break L12;
         }
         if ($31) {
          label = 28;
         } else {
          $73 = (($52) + 12|0);
          $74 = HEAP32[$73>>2]|0;
          $75 = ($V_0$01>>>0)<($74>>>0);
          if (!($75)) {
           label = 28;
          }
         }
         if ((label|0) == 28) {
          label = 0;
          __THREW__ = 0;
          $76 = (invoke_i(132)|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           label = 6;
           break L12;
          }
          __THREW__ = 0;
          invoke_vi(3302,($76|0));
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 6;
           break L12;
          }
         }
         $81 = HEAP32[$52>>2]|0;
         $82 = (($52) + 16|0);
         $83 = (($81) + 92|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = Math_imul($84, $V_0$01)|0;
         $86 = (($82) + ($85)|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = ($87|0)==(0|0);
         if ($88) {
          $$0 = 1;
          label = 40;
          break L12;
         } else {
          break L21;
         }
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($52|0));
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          label = 6;
          break L12;
         }
         if ($31) {
          label = 22;
         } else {
          $55 = (($52) + 12|0);
          $56 = HEAP32[$55>>2]|0;
          $57 = ($V_0$01>>>0)<($56>>>0);
          if (!($57)) {
           label = 22;
          }
         }
         if ((label|0) == 22) {
          label = 0;
          __THREW__ = 0;
          $58 = (invoke_i(132)|0);
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           label = 6;
           break L12;
          }
          __THREW__ = 0;
          invoke_vi(3302,($58|0));
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           label = 6;
           break L12;
          }
         }
         $63 = HEAP32[$52>>2]|0;
         $64 = (($52) + 16|0);
         $65 = (($63) + 92|0);
         $66 = HEAP32[$65>>2]|0;
         $67 = Math_imul($66, $V_0$01)|0;
         $68 = (($64) + ($67)|0);
         $69 = HEAP32[$68>>2]|0;
         $70 = ($69|0)==(0|0);
         if ($70) {
          break L21;
         } else {
          break;
         }
        }
       }
      } while(0);
      $89 = HEAP32[$30>>2]|0;
      $90 = HEAP32[$29>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($90|0));
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       label = 6;
       break L12;
      }
      if ($31) {
       label = 34;
      } else {
       $93 = (($90) + 12|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = ($V_0$01>>>0)<($94>>>0);
       if (!($95)) {
        label = 34;
       }
      }
      if ((label|0) == 34) {
       label = 0;
       __THREW__ = 0;
       $96 = (invoke_i(132)|0);
       $97 = __THREW__; __THREW__ = 0;
       $98 = $97&1;
       if ($98) {
        label = 6;
        break L12;
       }
       __THREW__ = 0;
       invoke_vi(3302,($96|0));
       $99 = __THREW__; __THREW__ = 0;
       $100 = $99&1;
       if ($100) {
        label = 6;
        break L12;
       }
      }
      $101 = HEAP32[$90>>2]|0;
      $102 = (($90) + 16|0);
      $103 = (($101) + 92|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = Math_imul($104, $V_0$01)|0;
      $106 = (($102) + ($105)|0);
      $107 = HEAP32[$106>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($89|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       label = 6;
       break L12;
      }
      $110 = HEAP32[$__this>>2]|0;
      $111 = (($110) + 84|0);
      $112 = HEAP32[$111>>2]|0;
      $113 = (($112) + 40|0);
      $114 = HEAP32[$113>>2]|0;
      __THREW__ = 0;
      $115 = (invoke_iiiii(302,($114|0),($89|0),($item|0),($107|0))|0);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       label = 6;
       break L12;
      }
      if ($115) {
       $$0 = 1;
       label = 40;
       break L12;
      }
     }
    } while(0);
    $51 = ($49|0)==(-1);
    if ($51) {
     $$0 = 0;
     label = 40;
     break;
    } else {
     $V_0$01 = $49;
    }
   }
   if ((label|0) == 6) {
    $13 = ___cxa_find_matching_catch()|0;
    $14 = tempRet0;
    $lpad$phi$index = $13;$lpad$phi$index2 = $14;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 40) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index2 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z141System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_CopyTo_mscorlib_System_Void_T_arr_arr_mscorlib_System_Int32_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390944);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$__this>>2]|0;
 $3 = (($2) + 84|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_viiii($8|0,($__this|0),($_____array|0),($index|0),($1|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z163System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_CopyTo_mscorlib_System_Void_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arrii($__this,$_____array,$index,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $count = $count|0;
 var $$0 = 0, $$110 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$08 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond7 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1390992);
 __THREW__ = 0;
 invoke_v(349);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3002232>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($index|0)>(-1);
   if (!($17)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2561352|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3002240>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($20|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($20|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    $30 = (($_____array) + 12|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)<($index|0);
    if ($32) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     $35 = (invoke_ii(3469,(2560072|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     $38 = HEAP32[3002248>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($35|0),($38|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3810,($35|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if (!($44)) {
     $45 = HEAP32[$30>>2]|0;
     $46 = (($45) - ($index))|0;
     $47 = ($46|0)<($count|0);
     if ($47) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      __THREW__ = 0;
      $56 = (invoke_ii(3469,(2560072|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = HEAP32[3002256>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($56|0),($59|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3810,($56|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
      // unreachable;
     }
     $48 = (($__this) + 20|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49|0)>(0);
     $51 = ($count|0)>(0);
     $or$cond7 = $50 & $51;
     if (!($or$cond7)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $52 = (($__this) + 16|0);
     $53 = (($_____array) + 16|0);
     $$110 = $index;$V_0$08 = 0;
     while(1) {
      $103 = HEAP32[$__this>>2]|0;
      $104 = (($103) + 84|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = (($105) + 48|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = (($107) + 4|0);
      $109 = HEAP32[$108>>2]|0;
      __THREW__ = 0;
      $65 = (invoke_iii($109|0,($__this|0),($V_0$08|0))|0);
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       break;
      }
      $64 = ($65|0)==(0);
      if ($64) {
       $$0 = $$110;
      } else {
       $66 = (($$110) + 1)|0;
       $67 = HEAP32[$52>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($67|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       $70 = (($67) + 12|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = ($V_0$08>>>0)<($71>>>0);
       if (!($72)) {
        __THREW__ = 0;
        $73 = (invoke_i(132)|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($73|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         break;
        }
       }
       $78 = HEAP32[$67>>2]|0;
       $79 = (($67) + 16|0);
       $80 = (($78) + 92|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = Math_imul($81, $V_0$08)|0;
       $83 = (($79) + ($82)|0);
       $84 = HEAP32[$83>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       $87 = ($$110|0)<(0);
       if ($87) {
        label = 41;
       } else {
        $88 = HEAP32[$30>>2]|0;
        $89 = ($$110>>>0)<($88>>>0);
        if (!($89)) {
         label = 41;
        }
       }
       if ((label|0) == 41) {
        label = 0;
        __THREW__ = 0;
        $90 = (invoke_i(132)|0);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($90|0));
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         break;
        }
       }
       $95 = HEAP32[$_____array>>2]|0;
       $96 = (($95) + 92|0);
       $97 = HEAP32[$96>>2]|0;
       $98 = Math_imul($97, $$110)|0;
       $99 = (($53) + ($98)|0);
       HEAP32[$99>>2] = $84;
       $$0 = $66;
      }
      $100 = (($V_0$08) + 1)|0;
      $101 = HEAP32[$48>>2]|0;
      $102 = ($100|0)<($101|0);
      if ($102) {
       $$110 = $$0;$V_0$08 = $100;
      } else {
       label = 46;
       break;
      }
     }
     if ((label|0) == 46) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $3 = ___cxa_find_matching_catch()|0;
     $4 = tempRet0;
     $lpad$phi$index = $3;$lpad$phi$index2 = $4;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z88System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Resize_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = Math_fround(0), $193 = Math_fround(0), $194 = 0, $195 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $V_4$02 = 0;
 var $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1391040);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5 << 1;
   $7 = $6 | 1;
   $8 = HEAP32[$__this>>2]|0;
   $9 = (($8) + 84|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + 52|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + 4|0);
   $14 = HEAP32[$13>>2]|0;
   __THREW__ = 0;
   $15 = (invoke_iii($14|0,(0|0),($7|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1170368|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2743,(1170368|0),($15|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = HEAP32[$__this>>2]|0;
      $24 = (($23) + 84|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = (($25) + 28|0);
      $27 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      $28 = (invoke_iii(2743,($27|0),($15|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = (($28) + 16|0);
       $32 = (($__this) + 16|0);
       $33 = (($20) + 12|0);
       $34 = (($20) + 16|0);
       $35 = (($__this) + 12|0);
       $36 = (($28) + 12|0);
       $V_3$0 = 0;
       L7: while(1) {
        $171 = HEAP32[$0>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($171|0));
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         label = 8;
         break;
        }
        $174 = (($171) + 12|0);
        $175 = HEAP32[$174>>2]|0;
        $176 = ($V_3$0|0)<($175|0);
        if (!($176)) {
         label = 50;
         break;
        }
        $44 = HEAP32[$0>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $177 = __THREW__; __THREW__ = 0;
        $178 = $177&1;
        if ($178) {
         label = 8;
         break;
        }
        $43 = (($44) + 12|0);
        $45 = HEAP32[$43>>2]|0;
        $46 = ($V_3$0>>>0)<($45>>>0);
        if (!($46)) {
         __THREW__ = 0;
         $47 = (invoke_i(132)|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          label = 8;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($47|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          label = 8;
          break;
         }
        }
        $52 = HEAP32[$44>>2]|0;
        $53 = (($44) + 16|0);
        $54 = (($52) + 92|0);
        $55 = HEAP32[$54>>2]|0;
        $56 = Math_imul($55, $V_3$0)|0;
        $57 = (($53) + ($56)|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = ($58|0)==(0);
        if (!($59)) {
         $60 = (($58) + -1)|0;
         $V_4$02 = $60;
         while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($28|0));
          $168 = __THREW__; __THREW__ = 0;
          $169 = $168&1;
          if ($169) {
           label = 7;
           break L7;
          }
          $61 = ($V_4$02|0)<(0);
          if ($61) {
           label = 18;
          } else {
           $62 = HEAP32[$36>>2]|0;
           $63 = ($V_4$02>>>0)<($62>>>0);
           if (!($63)) {
            label = 18;
           }
          }
          if ((label|0) == 18) {
           label = 0;
           __THREW__ = 0;
           $64 = (invoke_i(132)|0);
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if ($66) {
            label = 7;
            break L7;
           }
           __THREW__ = 0;
           invoke_vi(3302,($64|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 7;
            break L7;
           }
          }
          $69 = HEAP32[$28>>2]|0;
          $70 = (($69) + 92|0);
          $71 = HEAP32[$70>>2]|0;
          $72 = Math_imul($71, $V_4$02)|0;
          $73 = (($31) + ($72)|0);
          $74 = HEAP32[$32>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($74|0));
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 7;
           break L7;
          }
          if ($61) {
           label = 23;
          } else {
           $77 = (($74) + 12|0);
           $78 = HEAP32[$77>>2]|0;
           $79 = ($V_4$02>>>0)<($78>>>0);
           if (!($79)) {
            label = 23;
           }
          }
          if ((label|0) == 23) {
           label = 0;
           __THREW__ = 0;
           $80 = (invoke_i(132)|0);
           $81 = __THREW__; __THREW__ = 0;
           $82 = $81&1;
           if ($82) {
            label = 7;
            break L7;
           }
           __THREW__ = 0;
           invoke_vi(3302,($80|0));
           $83 = __THREW__; __THREW__ = 0;
           $84 = $83&1;
           if ($84) {
            label = 7;
            break L7;
           }
          }
          $85 = HEAP32[$74>>2]|0;
          $86 = (($74) + 16|0);
          $87 = (($85) + 92|0);
          $88 = HEAP32[$87>>2]|0;
          $89 = Math_imul($88, $V_4$02)|0;
          $90 = (($86) + ($89)|0);
          $91 = HEAP32[$90>>2]|0;
          $92 = HEAP32[$__this>>2]|0;
          $93 = (($92) + 84|0);
          $94 = HEAP32[$93>>2]|0;
          $95 = (($94) + 56|0);
          $96 = HEAP32[$95>>2]|0;
          $97 = (($96) + 4|0);
          $98 = HEAP32[$97>>2]|0;
          __THREW__ = 0;
          $99 = (invoke_iii($98|0,($__this|0),($91|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           label = 7;
           break L7;
          }
          HEAP32[$73>>2] = $99;
          $102 = $99 & 2147483647;
          $103 = (($102|0) % ($15|0))&-1;
          __THREW__ = 0;
          invoke_vi(3799,($28|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 7;
           break L7;
          }
          if ($61) {
           label = 29;
          } else {
           $106 = HEAP32[$36>>2]|0;
           $107 = ($V_4$02>>>0)<($106>>>0);
           if (!($107)) {
            label = 29;
           }
          }
          if ((label|0) == 29) {
           label = 0;
           __THREW__ = 0;
           $108 = (invoke_i(132)|0);
           $109 = __THREW__; __THREW__ = 0;
           $110 = $109&1;
           if ($110) {
            label = 7;
            break L7;
           }
           __THREW__ = 0;
           invoke_vi(3302,($108|0));
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            label = 7;
            break L7;
           }
          }
          $113 = HEAP32[$28>>2]|0;
          $114 = (($113) + 92|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = Math_imul($115, $V_4$02)|0;
          __THREW__ = 0;
          invoke_vi(3799,($20|0));
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           label = 7;
           break L7;
          }
          $119 = HEAP32[$33>>2]|0;
          $120 = ($103>>>0)<($119>>>0);
          if (!($120)) {
           __THREW__ = 0;
           $121 = (invoke_i(132)|0);
           $122 = __THREW__; __THREW__ = 0;
           $123 = $122&1;
           if ($123) {
            label = 7;
            break L7;
           }
           __THREW__ = 0;
           invoke_vi(3302,($121|0));
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            label = 7;
            break L7;
           }
          }
          $126 = HEAP32[$20>>2]|0;
          $127 = (($126) + 92|0);
          $128 = HEAP32[$127>>2]|0;
          $129 = Math_imul($128, $103)|0;
          $130 = (($34) + ($129)|0);
          $131 = HEAP32[$130>>2]|0;
          $132 = (($131) + -1)|0;
          $$sum = (($116) + 4)|0;
          $133 = (($31) + ($$sum)|0);
          HEAP32[$133>>2] = $132;
          $134 = (($V_4$02) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($20|0));
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           label = 7;
           break L7;
          }
          $137 = HEAP32[$33>>2]|0;
          $138 = ($103>>>0)<($137>>>0);
          if (!($138)) {
           __THREW__ = 0;
           $139 = (invoke_i(132)|0);
           $140 = __THREW__; __THREW__ = 0;
           $141 = $140&1;
           if ($141) {
            label = 7;
            break L7;
           }
           __THREW__ = 0;
           invoke_vi(3302,($139|0));
           $142 = __THREW__; __THREW__ = 0;
           $143 = $142&1;
           if ($143) {
            label = 7;
            break L7;
           }
          }
          $144 = HEAP32[$20>>2]|0;
          $145 = (($144) + 92|0);
          $146 = HEAP32[$145>>2]|0;
          $147 = Math_imul($146, $103)|0;
          $148 = (($34) + ($147)|0);
          HEAP32[$148>>2] = $134;
          $149 = HEAP32[$35>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($149|0));
          $150 = __THREW__; __THREW__ = 0;
          $151 = $150&1;
          if ($151) {
           label = 7;
           break L7;
          }
          if ($61) {
           label = 42;
          } else {
           $152 = (($149) + 12|0);
           $153 = HEAP32[$152>>2]|0;
           $154 = ($V_4$02>>>0)<($153>>>0);
           if (!($154)) {
            label = 42;
           }
          }
          if ((label|0) == 42) {
           label = 0;
           __THREW__ = 0;
           $155 = (invoke_i(132)|0);
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            label = 7;
            break L7;
           }
           __THREW__ = 0;
           invoke_vi(3302,($155|0));
           $158 = __THREW__; __THREW__ = 0;
           $159 = $158&1;
           if ($159) {
            label = 7;
            break L7;
           }
          }
          $160 = HEAP32[$149>>2]|0;
          $161 = (($149) + 16|0);
          $162 = (($160) + 92|0);
          $163 = HEAP32[$162>>2]|0;
          $164 = Math_imul($163, $V_4$02)|0;
          $$sum1 = (($164) + 4)|0;
          $165 = (($161) + ($$sum1)|0);
          $166 = HEAP32[$165>>2]|0;
          $167 = ($166|0)==(-1);
          if ($167) {
           break;
          } else {
           $V_4$02 = $166;
          }
         }
        }
        $170 = (($V_3$0) + 1)|0;
        $V_3$0 = $170;
       }
       if ((label|0) == 7) {
        $37 = ___cxa_find_matching_catch()|0;
        $38 = tempRet0;
        $lpad$phi$index = $37;$lpad$phi$index3 = $38;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 8) {
        $39 = ___cxa_find_matching_catch()|0;
        $40 = tempRet0;
        $lpad$phi$index = $39;$lpad$phi$index3 = $40;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 50) {
        HEAP32[$0>>2] = $20;
        HEAP32[$35>>2] = $28;
        $179 = HEAP32[$__this>>2]|0;
        $180 = (($179) + 84|0);
        $181 = HEAP32[$180>>2]|0;
        $182 = (($181) + 32|0);
        $183 = HEAP32[$182>>2]|0;
        __THREW__ = 0;
        $184 = (invoke_iii(2743,($183|0),($15|0))|0);
        $185 = __THREW__; __THREW__ = 0;
        $186 = $185&1;
        if ($186) {
         break;
        }
        $187 = HEAP32[$32>>2]|0;
        $188 = (($__this) + 20|0);
        $189 = HEAP32[$188>>2]|0;
        __THREW__ = 0;
        invoke_viiiiii(55,(0|0),($187|0),0,($184|0),0,($189|0));
        $190 = __THREW__; __THREW__ = 0;
        $191 = $190&1;
        if ($191) {
         break;
        }
        HEAP32[$32>>2] = $184;
        $192 = (Math_fround(($15|0)));
        $193 = Math_fround($192 * Math_fround(0.899999976158142089843));
        $194 = (~~(($193)));
        $195 = (($__this) + 32|0);
        HEAP32[$195>>2] = $194;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 $lpad$phi$index = $41;$lpad$phi$index3 = $42;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z97System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetLinkHashCode_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1391088);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($index|0)<(0);
   if ($4) {
    label = 4;
   } else {
    $5 = (($1) + 12|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6>>>0)>($index>>>0);
    if (!($7)) {
     label = 4;
    }
   }
   if ((label|0) == 4) {
    __THREW__ = 0;
    $8 = (invoke_i(132)|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
   }
   $15 = HEAP32[$1>>2]|0;
   $16 = (($1) + 16|0);
   $17 = (($15) + 92|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = Math_imul($18, $index)|0;
   $20 = (($16) + ($19)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = $21 & -2147483648;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($22|0);
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z97System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetItemHashCode_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1391136);
 $0 = ($item|0)==(0|0);
 if ($0) {
  $$0 = -2147483648;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($__this) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 }
 $5 = HEAP32[$__this>>2]|0;
 $6 = (($5) + 84|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 60|0);
 $9 = HEAP32[$8>>2]|0;
 __THREW__ = 0;
 $10 = (invoke_iiii(1649,($9|0),($2|0),($item|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 }
 $13 = $10 | -2147483648;
 $$0 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z85System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Add_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1391184);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_iii($6|0,($__this|0),($item|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if (!($9)) {
   $10 = $7 & 2147483647;
   $11 = (($__this) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = (($12) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($10|0) % ($16|0))&-1;
    $18 = HEAP32[$__this>>2]|0;
    $19 = (($18) + 84|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 64|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    __THREW__ = 0;
    $25 = (invoke_iiiii($24|0,($__this|0),($17|0),($7|0),($item|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     if ($25) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      $32 = (($__this) + 28|0);
      $33 = HEAP32[$32>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = (($33) + 1)|0;
       HEAP32[$32>>2] = $36;
       $37 = (($__this) + 32|0);
       $38 = HEAP32[$37>>2]|0;
       $39 = ($33|0)<($38|0);
       if ($39) {
        $V_1$0 = $17;
       } else {
        $40 = HEAP32[$__this>>2]|0;
        $41 = (($40) + 84|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = (($42) + 68|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = (($44) + 4|0);
        $46 = HEAP32[$45>>2]|0;
        __THREW__ = 0;
        invoke_vi($46|0,($__this|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        $49 = HEAP32[$11>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($49|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        $52 = (($49) + 12|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = (($10|0) % ($53|0))&-1;
        $V_1$0 = $54;
       }
       $55 = (($__this) + 24|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = ($56|0)==(-1);
       if ($57) {
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
        $60 = (($__this) + 20|0);
        $61 = HEAP32[$60>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = (($61) + 1)|0;
        HEAP32[$60>>2] = $64;
        $$pre = (($__this) + 12|0);
        $$pre$phiZ2D = $$pre;$V_2$0 = $61;
       } else {
        $65 = (($__this) + 12|0);
        $66 = HEAP32[$65>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($66|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        $69 = ($56|0)<(0);
        if ($69) {
         label = 19;
        } else {
         $70 = (($66) + 12|0);
         $71 = HEAP32[$70>>2]|0;
         $72 = ($56>>>0)<($71>>>0);
         if (!($72)) {
          label = 19;
         }
        }
        if ((label|0) == 19) {
         __THREW__ = 0;
         $73 = (invoke_i(132)|0);
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($73|0));
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          break;
         }
        }
        $78 = HEAP32[$66>>2]|0;
        $79 = (($66) + 16|0);
        $80 = (($78) + 92|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = Math_imul($81, $56)|0;
        $$sum = (($82) + 4)|0;
        $83 = (($79) + ($$sum)|0);
        $84 = HEAP32[$83>>2]|0;
        HEAP32[$55>>2] = $84;
        $$pre$phiZ2D = $65;$V_2$0 = $56;
       }
       $85 = HEAP32[$$pre$phiZ2D>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($85|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if (!($87)) {
        $88 = ($V_2$0|0)<(0);
        if ($88) {
         label = 25;
        } else {
         $89 = (($85) + 12|0);
         $90 = HEAP32[$89>>2]|0;
         $91 = ($V_2$0>>>0)<($90>>>0);
         if (!($91)) {
          label = 25;
         }
        }
        if ((label|0) == 25) {
         __THREW__ = 0;
         $92 = (invoke_i(132)|0);
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($92|0));
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          break;
         }
        }
        $97 = HEAP32[$85>>2]|0;
        $98 = (($85) + 16|0);
        $99 = (($97) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_2$0)|0;
        $102 = (($98) + ($101)|0);
        HEAP32[$102>>2] = $7;
        $103 = HEAP32[$$pre$phiZ2D>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($103|0));
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if (!($105)) {
         if ($88) {
          label = 30;
         } else {
          $106 = (($103) + 12|0);
          $107 = HEAP32[$106>>2]|0;
          $108 = ($V_2$0>>>0)<($107>>>0);
          if (!($108)) {
           label = 30;
          }
         }
         if ((label|0) == 30) {
          __THREW__ = 0;
          $109 = (invoke_i(132)|0);
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($109|0));
          $112 = __THREW__; __THREW__ = 0;
          $113 = $112&1;
          if ($113) {
           break;
          }
         }
         $114 = HEAP32[$103>>2]|0;
         $115 = (($103) + 16|0);
         $116 = (($114) + 92|0);
         $117 = HEAP32[$116>>2]|0;
         $118 = Math_imul($117, $V_2$0)|0;
         $119 = HEAP32[$11>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($119|0));
         $120 = __THREW__; __THREW__ = 0;
         $121 = $120&1;
         if (!($121)) {
          $122 = (($119) + 12|0);
          $123 = HEAP32[$122>>2]|0;
          $124 = ($V_1$0>>>0)<($123>>>0);
          if (!($124)) {
           __THREW__ = 0;
           $125 = (invoke_i(132)|0);
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($125|0));
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            break;
           }
          }
          $130 = HEAP32[$119>>2]|0;
          $131 = (($119) + 16|0);
          $132 = (($130) + 92|0);
          $133 = HEAP32[$132>>2]|0;
          $134 = Math_imul($133, $V_1$0)|0;
          $135 = (($131) + ($134)|0);
          $136 = HEAP32[$135>>2]|0;
          $137 = (($136) + -1)|0;
          $$sum1 = (($118) + 4)|0;
          $138 = (($115) + ($$sum1)|0);
          HEAP32[$138>>2] = $137;
          $139 = HEAP32[$11>>2]|0;
          $140 = (($V_2$0) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($139|0));
          $141 = __THREW__; __THREW__ = 0;
          $142 = $141&1;
          if (!($142)) {
           $143 = (($139) + 12|0);
           $144 = HEAP32[$143>>2]|0;
           $145 = ($V_1$0>>>0)<($144>>>0);
           if (!($145)) {
            __THREW__ = 0;
            $146 = (invoke_i(132)|0);
            $147 = __THREW__; __THREW__ = 0;
            $148 = $147&1;
            if ($148) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($146|0));
            $149 = __THREW__; __THREW__ = 0;
            $150 = $149&1;
            if ($150) {
             break;
            }
           }
           $151 = HEAP32[$139>>2]|0;
           $152 = (($139) + 16|0);
           $153 = (($151) + 92|0);
           $154 = HEAP32[$153>>2]|0;
           $155 = Math_imul($154, $V_1$0)|0;
           $156 = (($152) + ($155)|0);
           HEAP32[$156>>2] = $140;
           $157 = (($__this) + 16|0);
           $158 = HEAP32[$157>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($158|0));
           $159 = __THREW__; __THREW__ = 0;
           $160 = $159&1;
           if (!($160)) {
            if ($88) {
             label = 43;
            } else {
             $161 = (($158) + 12|0);
             $162 = HEAP32[$161>>2]|0;
             $163 = ($V_2$0>>>0)<($162>>>0);
             if (!($163)) {
              label = 43;
             }
            }
            if ((label|0) == 43) {
             __THREW__ = 0;
             $164 = (invoke_i(132)|0);
             $165 = __THREW__; __THREW__ = 0;
             $166 = $165&1;
             if ($166) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($164|0));
             $167 = __THREW__; __THREW__ = 0;
             $168 = $167&1;
             if ($168) {
              break;
             }
            }
            $169 = HEAP32[$158>>2]|0;
            $170 = (($158) + 16|0);
            $171 = (($169) + 92|0);
            $172 = HEAP32[$171>>2]|0;
            $173 = Math_imul($172, $V_2$0)|0;
            $174 = (($170) + ($173)|0);
            HEAP32[$174>>2] = $item;
            __THREW__ = 0;
            invoke_vi(3799,($__this|0));
            $175 = __THREW__; __THREW__ = 0;
            $176 = $175&1;
            if (!($176)) {
             $177 = (($__this) + 40|0);
             $178 = HEAP32[$177>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $179 = __THREW__; __THREW__ = 0;
             $180 = $179&1;
             if ($180) {
              break;
             }
             $181 = (($178) + 1)|0;
             HEAP32[$177>>2] = $181;
             $$0 = 1;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
 return 0|0;
}
function __Z87System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Clear_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1391232);
 $0 = (($__this) + 28|0);
 HEAP32[$0>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($2) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($2|0),0,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = (($__this) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = (($10) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($10|0),0,($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = (($__this) + 12|0);
     $18 = HEAP32[$17>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($18) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      __THREW__ = 0;
      invoke_viiii(138,(0|0),($18|0),0,($22|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = (($__this) + 24|0);
       HEAP32[$25>>2] = -1;
       $26 = (($__this) + 20|0);
       HEAP32[$26>>2] = 0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $29 = (($__this) + 40|0);
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $33 = (($30) + 1)|0;
         HEAP32[$29>>2] = $33;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($34|0);
 // unreachable;
}
function __Z90System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Contains_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1391280);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_iii($6|0,($__this|0),($item|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  $10 = (($__this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($11|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = $7 & 2147483647;
   $15 = (($11) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14|0) % ($16|0))&-1;
   $18 = HEAP32[$__this>>2]|0;
   $19 = (($18) + 84|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + 64|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   __THREW__ = 0;
   $25 = (invoke_iiiii($24|0,($__this|0),($17|0),($7|0),($item|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($25|0);
   }
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
 return 0|0;
}
function __Z88System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Remove_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$sum = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1391328);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 $7 = (invoke_iii($6|0,($__this|0),($item|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if (!($9)) {
   $10 = (($__this) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($11|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = $7 & 2147483647;
    $15 = (($11) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($14|0) % ($16|0))&-1;
    $18 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = (($18) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($17>>>0)<($22>>>0);
     if (!($23)) {
      __THREW__ = 0;
      $24 = (invoke_i(132)|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($24|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
     }
     $33 = HEAP32[$18>>2]|0;
     $34 = (($18) + 16|0);
     $35 = (($33) + 92|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = Math_imul($36, $17)|0;
     $38 = (($34) + ($37)|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0);
     if ($40) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $41 = (($39) + -1)|0;
     $42 = (($__this) + 12|0);
     $43 = ($7|0)==(-2147483648);
     $44 = ($item|0)==(0|0);
     $45 = (($__this) + 16|0);
     $46 = (($__this) + 36|0);
     $V_2$0 = $41;$V_3$0 = -1;
     L12: while(1) {
      $47 = HEAP32[$42>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 7;
       break;
      }
      $50 = ($V_2$0|0)<(0);
      if ($50) {
       label = 15;
      } else {
       $51 = (($47) + 12|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($V_2$0>>>0)<($52>>>0);
       if (!($53)) {
        label = 15;
       }
      }
      if ((label|0) == 15) {
       label = 0;
       __THREW__ = 0;
       $54 = (invoke_i(132)|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($54|0));
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 7;
        break;
       }
      }
      $59 = HEAP32[$47>>2]|0;
      $60 = (($47) + 16|0);
      $61 = (($59) + 92|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = Math_imul($62, $V_2$0)|0;
      $64 = (($60) + ($63)|0);
      $65 = HEAP32[$64>>2]|0;
      $$sum = (($63) + 4)|0;
      $66 = (($60) + ($$sum)|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($65|0)==($7|0);
      L21: do {
       if ($68) {
        do {
         if ($43) {
          $69 = HEAP32[$45>>2]|0;
          if ($44) {
           __THREW__ = 0;
           invoke_vi(3799,($69|0));
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            label = 7;
            break L12;
           }
           if ($50) {
            label = 29;
           } else {
            $90 = (($69) + 12|0);
            $91 = HEAP32[$90>>2]|0;
            $92 = ($V_2$0>>>0)<($91>>>0);
            if (!($92)) {
             label = 29;
            }
           }
           if ((label|0) == 29) {
            label = 0;
            __THREW__ = 0;
            $93 = (invoke_i(132)|0);
            $94 = __THREW__; __THREW__ = 0;
            $95 = $94&1;
            if ($95) {
             label = 7;
             break L12;
            }
            __THREW__ = 0;
            invoke_vi(3302,($93|0));
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             label = 7;
             break L12;
            }
           }
           $98 = HEAP32[$69>>2]|0;
           $99 = (($69) + 16|0);
           $100 = (($98) + 92|0);
           $101 = HEAP32[$100>>2]|0;
           $102 = Math_imul($101, $V_2$0)|0;
           $103 = (($99) + ($102)|0);
           $104 = HEAP32[$103>>2]|0;
           $105 = ($104|0)==(0|0);
           if ($105) {
            label = 41;
            break L12;
           } else {
            break L21;
           }
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($69|0));
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            label = 7;
            break L12;
           }
           if ($50) {
            label = 23;
           } else {
            $72 = (($69) + 12|0);
            $73 = HEAP32[$72>>2]|0;
            $74 = ($V_2$0>>>0)<($73>>>0);
            if (!($74)) {
             label = 23;
            }
           }
           if ((label|0) == 23) {
            label = 0;
            __THREW__ = 0;
            $75 = (invoke_i(132)|0);
            $76 = __THREW__; __THREW__ = 0;
            $77 = $76&1;
            if ($77) {
             label = 7;
             break L12;
            }
            __THREW__ = 0;
            invoke_vi(3302,($75|0));
            $78 = __THREW__; __THREW__ = 0;
            $79 = $78&1;
            if ($79) {
             label = 7;
             break L12;
            }
           }
           $80 = HEAP32[$69>>2]|0;
           $81 = (($69) + 16|0);
           $82 = (($80) + 92|0);
           $83 = HEAP32[$82>>2]|0;
           $84 = Math_imul($83, $V_2$0)|0;
           $85 = (($81) + ($84)|0);
           $86 = HEAP32[$85>>2]|0;
           $87 = ($86|0)==(0|0);
           if ($87) {
            break L21;
           } else {
            break;
           }
          }
         }
        } while(0);
        $106 = HEAP32[$46>>2]|0;
        $107 = HEAP32[$45>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($107|0));
        $108 = __THREW__; __THREW__ = 0;
        $109 = $108&1;
        if ($109) {
         label = 7;
         break L12;
        }
        if ($50) {
         label = 35;
        } else {
         $110 = (($107) + 12|0);
         $111 = HEAP32[$110>>2]|0;
         $112 = ($V_2$0>>>0)<($111>>>0);
         if (!($112)) {
          label = 35;
         }
        }
        if ((label|0) == 35) {
         label = 0;
         __THREW__ = 0;
         $113 = (invoke_i(132)|0);
         $114 = __THREW__; __THREW__ = 0;
         $115 = $114&1;
         if ($115) {
          label = 7;
          break L12;
         }
         __THREW__ = 0;
         invoke_vi(3302,($113|0));
         $116 = __THREW__; __THREW__ = 0;
         $117 = $116&1;
         if ($117) {
          label = 7;
          break L12;
         }
        }
        $118 = HEAP32[$107>>2]|0;
        $119 = (($107) + 16|0);
        $120 = (($118) + 92|0);
        $121 = HEAP32[$120>>2]|0;
        $122 = Math_imul($121, $V_2$0)|0;
        $123 = (($119) + ($122)|0);
        $124 = HEAP32[$123>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($106|0));
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         label = 7;
         break L12;
        }
        $127 = HEAP32[$__this>>2]|0;
        $128 = (($127) + 84|0);
        $129 = HEAP32[$128>>2]|0;
        $130 = (($129) + 40|0);
        $131 = HEAP32[$130>>2]|0;
        __THREW__ = 0;
        $132 = (invoke_iiiii(302,($131|0),($106|0),($124|0),($item|0))|0);
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         label = 7;
         break L12;
        }
        if ($132) {
         label = 41;
         break L12;
        }
       }
      } while(0);
      $135 = ($67|0)==(-1);
      if ($135) {
       $$0 = 0;
       label = 84;
       break;
      } else {
       $V_3$0$phi = $V_2$0;$V_2$0 = $67;$V_3$0 = $V_3$0$phi;
      }
     }
     if ((label|0) == 7) {
      $29 = ___cxa_find_matching_catch()|0;
      $30 = tempRet0;
      $lpad$phi$index = $29;$lpad$phi$index2 = $30;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 41) {
      $136 = ($V_2$0|0)==(-1);
      if ($136) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break;
      }
      $139 = (($__this) + 28|0);
      $140 = HEAP32[$139>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $141 = __THREW__; __THREW__ = 0;
      $142 = $141&1;
      if ($142) {
       break;
      }
      $143 = (($140) + -1)|0;
      HEAP32[$139>>2] = $143;
      $144 = ($V_3$0|0)==(-1);
      if ($144) {
       $145 = HEAP32[$10>>2]|0;
       $146 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($146|0));
       $147 = __THREW__; __THREW__ = 0;
       $148 = $147&1;
       if ($148) {
        break;
       }
       if ($50) {
        label = 48;
       } else {
        $149 = (($146) + 12|0);
        $150 = HEAP32[$149>>2]|0;
        $151 = ($V_2$0>>>0)<($150>>>0);
        if (!($151)) {
         label = 48;
        }
       }
       if ((label|0) == 48) {
        __THREW__ = 0;
        $152 = (invoke_i(132)|0);
        $153 = __THREW__; __THREW__ = 0;
        $154 = $153&1;
        if ($154) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($152|0));
        $155 = __THREW__; __THREW__ = 0;
        $156 = $155&1;
        if ($156) {
         break;
        }
       }
       $157 = HEAP32[$146>>2]|0;
       $158 = (($146) + 16|0);
       $159 = (($157) + 92|0);
       $160 = HEAP32[$159>>2]|0;
       $161 = Math_imul($160, $V_2$0)|0;
       $$sum6 = (($161) + 4)|0;
       $162 = (($158) + ($$sum6)|0);
       $163 = HEAP32[$162>>2]|0;
       $164 = (($163) + 1)|0;
       __THREW__ = 0;
       invoke_vi(3799,($145|0));
       $165 = __THREW__; __THREW__ = 0;
       $166 = $165&1;
       if ($166) {
        break;
       }
       $167 = (($145) + 12|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = ($17>>>0)<($168>>>0);
       if (!($169)) {
        __THREW__ = 0;
        $170 = (invoke_i(132)|0);
        $171 = __THREW__; __THREW__ = 0;
        $172 = $171&1;
        if ($172) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($170|0));
        $173 = __THREW__; __THREW__ = 0;
        $174 = $173&1;
        if ($174) {
         break;
        }
       }
       $175 = HEAP32[$145>>2]|0;
       $176 = (($145) + 16|0);
       $177 = (($175) + 92|0);
       $178 = HEAP32[$177>>2]|0;
       $179 = Math_imul($178, $17)|0;
       $180 = (($176) + ($179)|0);
       HEAP32[$180>>2] = $164;
      } else {
       $181 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($181|0));
       $182 = __THREW__; __THREW__ = 0;
       $183 = $182&1;
       if ($183) {
        break;
       }
       $184 = ($V_3$0|0)<(0);
       if ($184) {
        label = 58;
       } else {
        $185 = (($181) + 12|0);
        $186 = HEAP32[$185>>2]|0;
        $187 = ($V_3$0>>>0)<($186>>>0);
        if (!($187)) {
         label = 58;
        }
       }
       if ((label|0) == 58) {
        __THREW__ = 0;
        $188 = (invoke_i(132)|0);
        $189 = __THREW__; __THREW__ = 0;
        $190 = $189&1;
        if ($190) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($188|0));
        $191 = __THREW__; __THREW__ = 0;
        $192 = $191&1;
        if ($192) {
         break;
        }
       }
       $193 = HEAP32[$181>>2]|0;
       $194 = (($181) + 16|0);
       $195 = (($193) + 92|0);
       $196 = HEAP32[$195>>2]|0;
       $197 = Math_imul($196, $V_3$0)|0;
       $198 = HEAP32[$42>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($198|0));
       $199 = __THREW__; __THREW__ = 0;
       $200 = $199&1;
       if ($200) {
        break;
       }
       if ($50) {
        label = 63;
       } else {
        $201 = (($198) + 12|0);
        $202 = HEAP32[$201>>2]|0;
        $203 = ($V_2$0>>>0)<($202>>>0);
        if (!($203)) {
         label = 63;
        }
       }
       if ((label|0) == 63) {
        __THREW__ = 0;
        $204 = (invoke_i(132)|0);
        $205 = __THREW__; __THREW__ = 0;
        $206 = $205&1;
        if ($206) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($204|0));
        $207 = __THREW__; __THREW__ = 0;
        $208 = $207&1;
        if ($208) {
         break;
        }
       }
       $209 = HEAP32[$198>>2]|0;
       $210 = (($198) + 16|0);
       $211 = (($209) + 92|0);
       $212 = HEAP32[$211>>2]|0;
       $213 = Math_imul($212, $V_2$0)|0;
       $$sum3 = (($213) + 4)|0;
       $214 = (($210) + ($$sum3)|0);
       $215 = HEAP32[$214>>2]|0;
       $$sum4 = (($197) + 4)|0;
       $216 = (($194) + ($$sum4)|0);
       HEAP32[$216>>2] = $215;
      }
      $217 = HEAP32[$42>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($217|0));
      $218 = __THREW__; __THREW__ = 0;
      $219 = $218&1;
      if ($219) {
       break;
      }
      if ($50) {
       label = 69;
      } else {
       $220 = (($217) + 12|0);
       $221 = HEAP32[$220>>2]|0;
       $222 = ($V_2$0>>>0)<($221>>>0);
       if (!($222)) {
        label = 69;
       }
      }
      if ((label|0) == 69) {
       __THREW__ = 0;
       $223 = (invoke_i(132)|0);
       $224 = __THREW__; __THREW__ = 0;
       $225 = $224&1;
       if ($225) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($223|0));
       $226 = __THREW__; __THREW__ = 0;
       $227 = $226&1;
       if ($227) {
        break;
       }
      }
      $228 = HEAP32[$217>>2]|0;
      $229 = (($217) + 16|0);
      $230 = (($228) + 92|0);
      $231 = HEAP32[$230>>2]|0;
      $232 = Math_imul($231, $V_2$0)|0;
      $233 = (($__this) + 24|0);
      $234 = HEAP32[$233>>2]|0;
      $$sum5 = (($232) + 4)|0;
      $235 = (($229) + ($$sum5)|0);
      HEAP32[$235>>2] = $234;
      HEAP32[$233>>2] = $V_2$0;
      $236 = HEAP32[$42>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($236|0));
      $237 = __THREW__; __THREW__ = 0;
      $238 = $237&1;
      if ($238) {
       break;
      }
      if ($50) {
       label = 74;
      } else {
       $239 = (($236) + 12|0);
       $240 = HEAP32[$239>>2]|0;
       $241 = ($V_2$0>>>0)<($240>>>0);
       if (!($241)) {
        label = 74;
       }
      }
      if ((label|0) == 74) {
       __THREW__ = 0;
       $242 = (invoke_i(132)|0);
       $243 = __THREW__; __THREW__ = 0;
       $244 = $243&1;
       if ($244) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($242|0));
       $245 = __THREW__; __THREW__ = 0;
       $246 = $245&1;
       if ($246) {
        break;
       }
      }
      $247 = HEAP32[$236>>2]|0;
      $248 = (($236) + 16|0);
      $249 = (($247) + 92|0);
      $250 = HEAP32[$249>>2]|0;
      $251 = Math_imul($250, $V_2$0)|0;
      $252 = (($248) + ($251)|0);
      HEAP32[$252>>2] = 0;
      $253 = HEAP32[$45>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($253|0));
      $254 = __THREW__; __THREW__ = 0;
      $255 = $254&1;
      if ($255) {
       break;
      }
      if ($50) {
       label = 79;
      } else {
       $256 = (($253) + 12|0);
       $257 = HEAP32[$256>>2]|0;
       $258 = ($V_2$0>>>0)<($257>>>0);
       if (!($258)) {
        label = 79;
       }
      }
      if ((label|0) == 79) {
       __THREW__ = 0;
       $259 = (invoke_i(132)|0);
       $260 = __THREW__; __THREW__ = 0;
       $261 = $260&1;
       if ($261) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($259|0));
       $262 = __THREW__; __THREW__ = 0;
       $263 = $262&1;
       if ($263) {
        break;
       }
      }
      $264 = HEAP32[$253>>2]|0;
      $265 = (($253) + 16|0);
      $266 = (($264) + 92|0);
      $267 = HEAP32[$266>>2]|0;
      $268 = Math_imul($267, $V_2$0)|0;
      $269 = (($265) + ($268)|0);
      HEAP32[$269>>2] = 0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $270 = __THREW__; __THREW__ = 0;
      $271 = $270&1;
      if ($271) {
       break;
      }
      $272 = (($__this) + 40|0);
      $273 = HEAP32[$272>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $274 = __THREW__; __THREW__ = 0;
      $275 = $274&1;
      if ($275) {
       break;
      }
      $276 = (($273) + 1)|0;
      HEAP32[$272>>2] = $276;
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 84) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $lpad$phi$index = $31;$lpad$phi$index2 = $32;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z95System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetObjectData_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1391376);
 __THREW__ = 0;
 (invoke_ii(2996,(2622368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2754,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3810,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __ZL79System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m__ctorP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z87System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m__ctor_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL137System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z145System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL138System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z146System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object(0)|0);
 STACKTOP = sp;return 0;
}
function __ZL130System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_CopyToP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z138System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_CopyTo_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL127System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_AddP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z135System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_Add_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL83System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_get_CountP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z91System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_get_Count_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_InitP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$comparer) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $comparer = $comparer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Init_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$comparer);
 STACKTOP = sp;return;
}
function __ZL84System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_InitArraysP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Objecti($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_InitArrays_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Objecti($__this,$size);
 STACKTOP = sp;return;
}
function __ZL89System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_SlotsContainsAtP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectiiP22mscorlib_System_Object($__this,$index,$hash,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $hash = $hash|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z97System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_SlotsContainsAt_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectiiP22mscorlib_System_Object($__this,$index,$hash,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS1_28mscorlib_System_ObjectTraitsE6InvokeEPFbPviiP22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$4,$6)|0);
 $8 = $7&1;
 HEAP8[$ret>>0] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZL133System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_CopyTo_mscorlib_System_Void_T_arr_arr_mscorlib_System_Int32P71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z141System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_CopyTo_mscorlib_System_Void_T_arr_arr_mscorlib_System_Int32_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL155System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_CopyTo_mscorlib_System_Void_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arrii($__this,$_____array,$index,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $count = $count|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z163System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_CopyTo_mscorlib_System_Void_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arrii($__this,$_____array,$index,$count);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFvPvS3_iiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$3,$6);
 STACKTOP = sp;return (0|0);
}
function __ZL80System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_ResizeP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Resize_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL89System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetLinkHashCodeP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Objecti($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z97System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetLinkHashCode_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32TraitsS0_E6InvokeEPFiPviES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL89System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetItemHashCodeP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z97System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetItemHashCode_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_AddP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Add_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_ClearP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z87System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Clear_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL82System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_ContainsP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Contains_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_RemoveP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Remove_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetObjectDataP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __Z95System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetObjectData_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext(0,0,$tmpcast$byval_copy);
 // unreachable;
}
function __Z127mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m__ctorP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1393400);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z164mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1393448);
 __THREW__ = 0;
 invoke_vii(1326,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(1393256|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(1393256|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z133mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m_get_CurrentP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1393592);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(836,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z129mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m_DisposeP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1393496);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m_MoveNextP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1393544);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I82System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectTraitsE6InvokeEPF76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1393256,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z98System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_ObjectP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this,$hashset) {
 $__this = $__this|0;
 $hashset = $hashset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1395424);
 HEAP32[$__this>>2] = $hashset;
 __THREW__ = 0;
 invoke_vi(3799,($hashset|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($hashset) + 40|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z135System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1395472);
 __THREW__ = 0;
 invoke_v(350);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$rgctx>>2]|0;
  $3 = (($2) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi($4|0,($__this|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)>(0);
   if ($9) {
    $22 = (($__this) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($23|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2607872|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3002512>>2]|0;
     __THREW__ = 0;
     invoke_vii(1947,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3810,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z101System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1395520);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($2|0,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = (($__this) + 4|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)>(-1);
   if (!($7)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = (($rgctx) + 8|0);
   $52 = $6;
   while(1) {
    $46 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($46|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 4;
     break;
    }
    $49 = (($46) + 20|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = ($52|0)<($50|0);
    if (!($51)) {
     label = 20;
     break;
    }
    $17 = HEAP32[$5>>2]|0;
    $53 = (($17) + 1)|0;
    HEAP32[$5>>2] = $53;
    $16 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($16|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 4;
     break;
    }
    $13 = HEAP32[$8>>2]|0;
    $14 = (($13) + 4|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $18 = (invoke_iii($15|0,($16|0),($17|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 4;
     break;
    }
    $21 = ($18|0)==(0);
    if (!($21)) {
     label = 10;
     break;
    }
    $$pre = HEAP32[$5>>2]|0;
    $52 = $$pre;
   }
   if ((label|0) == 4) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    $lpad$phi$index = $9;$lpad$phi$index2 = $10;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 10) {
    $22 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = (($22) + 16|0);
    $26 = HEAP32[$25>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = ($17|0)<(0);
    if ($29) {
     label = 14;
    } else {
     $30 = (($26) + 12|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($17>>>0)<($31>>>0);
     if (!($32)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     __THREW__ = 0;
     $33 = (invoke_i(132)|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($33|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
    }
    $38 = HEAP32[$26>>2]|0;
    $39 = (($26) + 16|0);
    $40 = (($38) + 92|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = Math_imul($41, $17)|0;
    $43 = (($39) + ($42)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = (($__this) + 12|0);
    HEAP32[$45>>2] = $44;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 20) {
    HEAP32[$5>>2] = -1;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z104System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1395568);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z100System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1395616);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z103System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_CheckState_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1395664);
 __THREW__ = 0;
 invoke_v(351);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2634432|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2634432|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1970,($8|0),(0|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($2) + 40|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if ($21) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     $24 = (invoke_ii(3469,(2607872|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[3002568>>2]|0;
      __THREW__ = 0;
      invoke_vii(1947,($24|0),($27|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vi(3810,($24|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __ZL90System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m__ctorP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_ObjectP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this,$hashset) {
 $__this = $__this|0;
 $hashset = $hashset|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z98System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_ObjectP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object($__this,$hashset);
 STACKTOP = sp;return;
}
function __ZL127System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1396040)|0);
 $0 = HEAP32[((1396040 + 84|0))>>2]|0;
 $1 = (__Z135System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_MoveNextP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1396040)|0);
 $0 = HEAP32[((1396040 + 84|0))>>2]|0;
 $1 = (__Z101System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_get_CurrentP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_DisposeP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z100System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL95System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_CheckStateP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z103System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_CheckState_gsharedP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __Z100System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396184);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2743,(1170368|0),34)|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$0>>2] = 2674768;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viii(551,(0|0),($3|0),($$byval_copy|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = HEAP32[$rgctx>>2]|0;
    $9 = (($8) + 80|0);
    $10 = HEAP32[$9>>2]|0;
    HEAP32[$10>>2] = $3;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z103System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_TestPrime_gsharedP22mscorlib_System_Objecti($__this,$x) {
 $__this = $__this|0;
 $x = $x|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396232);
 $0 = $x & 1;
 $1 = ($0|0)==(0);
 L1: do {
  if ($1) {
   $10 = ($x|0)==(2);
   $$0 = $10;
  } else {
   $2 = (+($x|0));
   $3 = (+Math_sqrt((+$2)));
   $4 = (~~(($3)));
   $5 = ($4|0)>(3);
   if ($5) {
    $V_1$01 = 3;
    while(1) {
     $8 = (($x|0) % ($V_1$01|0))&-1;
     $9 = ($8|0)==(0);
     $7 = (($V_1$01) + 2)|0;
     if ($9) {
      $$0 = 0;
      break L1;
     }
     $6 = ($7|0)<($4|0);
     if ($6) {
      $V_1$01 = $7;
     } else {
      $$0 = 1;
      break;
     }
    }
   } else {
    $$0 = 1;
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z103System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_CalcPrime_gsharedP22mscorlib_System_ObjectiPPv($__this,$x,$rgctx) {
 $__this = $__this|0;
 $x = $x|0;
 $rgctx = $rgctx|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396280);
 $0 = $x & -2;
 $1 = (($0) + -1)|0;
 $2 = ($1|0)==(2147483647);
 L1: do {
  if ($2) {
   $$0 = $x;
  } else {
   $3 = (($rgctx) + 4|0);
   $V_0$01 = $1;
   while(1) {
    $8 = HEAP32[$3>>2]|0;
    $9 = (($8) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    $11 = (invoke_iii($10|0,(0|0),($V_0$01|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $4 = (($V_0$01) + 2)|0;
    if ($11) {
     $$0 = $V_0$01;
     break L1;
    }
    $7 = ($4|0)==(2147483647);
    if ($7) {
     $$0 = $x;
     break L1;
    } else {
     $V_0$01 = $4;
    }
   }
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z101System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_ToPrime_gsharedP22mscorlib_System_ObjectiPPv($__this,$x,$rgctx) {
 $__this = $__this|0;
 $x = $x|0;
 $rgctx = $rgctx|0;
 var $$0 = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396328);
 $V_0$0 = 0;
 while(1) {
  $61 = HEAP32[$rgctx>>2]|0;
  $62 = (($61) + 116|0);
  $63 = HEAP8[$62>>0]|0;
  $64 = ($63<<24>>24)==(0);
  if ($64) {
   __THREW__ = 0;
   (invoke_ii(2996,($61|0))|0);
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if ($66) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3811,($61|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 5;
    break;
   }
   $$pre = HEAP32[$rgctx>>2]|0;
   $70 = $$pre;
  } else {
   $70 = $61;
  }
  $69 = (($70) + 80|0);
  $71 = HEAP32[$69>>2]|0;
  $72 = HEAP32[$71>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($72|0));
  $73 = __THREW__; __THREW__ = 0;
  $74 = $73&1;
  if ($74) {
   label = 5;
   break;
  }
  $75 = (($72) + 12|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($V_0$0|0)<($76|0);
  if (!($77)) {
   label = 29;
   break;
  }
  $0 = HEAP32[$rgctx>>2]|0;
  $78 = (($0) + 116|0);
  $79 = HEAP8[$78>>0]|0;
  $80 = ($79<<24>>24)==(0);
  if ($80) {
   __THREW__ = 0;
   (invoke_ii(2996,($0|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if ($2) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3811,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    label = 5;
    break;
   }
   $$pre7 = HEAP32[$rgctx>>2]|0;
   $10 = $$pre7;
  } else {
   $10 = $0;
  }
  $9 = (($10) + 80|0);
  $11 = HEAP32[$9>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   label = 5;
   break;
  }
  $15 = (($12) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ($V_0$0>>>0)<($16>>>0);
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_i(132)|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($18|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if ($22) {
    label = 5;
    break;
   }
  }
  $23 = HEAP32[$12>>2]|0;
  $24 = (($12) + 16|0);
  $25 = (($23) + 92|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = Math_imul($26, $V_0$0)|0;
  $28 = (($24) + ($27)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)<($x|0);
  $31 = (($V_0$0) + 1)|0;
  if ($30) {
   $V_0$0 = $31;
  } else {
   label = 13;
   break;
  }
 }
 do {
  if ((label|0) == 5) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   $lpad$phi$index = $5;$lpad$phi$index2 = $6;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  else if ((label|0) == 13) {
   $32 = HEAP32[$rgctx>>2]|0;
   $33 = (($32) + 116|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    __THREW__ = 0;
    (invoke_ii(2996,($32|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3811,($32|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    $$pre8 = HEAP32[$rgctx>>2]|0;
    $41 = $$pre8;
   } else {
    $41 = $32;
   }
   $40 = (($41) + 80|0);
   $42 = HEAP32[$40>>2]|0;
   $43 = HEAP32[$42>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($43|0));
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    $46 = (($43) + 12|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($V_0$0>>>0)<($47>>>0);
    if (!($48)) {
     __THREW__ = 0;
     $49 = (invoke_i(132)|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($49|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
    }
    $54 = HEAP32[$43>>2]|0;
    $55 = (($43) + 16|0);
    $56 = (($54) + 92|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = Math_imul($57, $V_0$0)|0;
    $59 = (($55) + ($58)|0);
    $60 = HEAP32[$59>>2]|0;
    $$0 = $60;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
  else if ((label|0) == 29) {
   $81 = (($rgctx) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($82) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   __THREW__ = 0;
   $85 = (invoke_iii($84|0,(0|0),($x|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if (!($87)) {
    $$0 = $85;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL92System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1396608)|0);
 $0 = HEAP32[((1396608 + 84|0))>>2]|0;
 __Z100System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv(0,$0);
 STACKTOP = sp;return;
}
function __ZL95System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_TestPrimeP22mscorlib_System_Objecti($__this,$x) {
 $__this = $__this|0;
 $x = $x|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z103System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_TestPrime_gsharedP22mscorlib_System_Objecti(0,$x)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsE6InvokeEPFbPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZL95System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_CalcPrimeP22mscorlib_System_Objecti($__this,$x) {
 $__this = $__this|0;
 $x = $x|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1396608)|0);
 $0 = HEAP32[((1396608 + 84|0))>>2]|0;
 $1 = (__Z103System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_CalcPrime_gsharedP22mscorlib_System_ObjectiPPv(0,$x,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_ToPrimeP22mscorlib_System_Objecti($__this,$x) {
 $__this = $__this|0;
 $x = $x|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1396608)|0);
 $0 = HEAP32[((1396608 + 84|0))>>2]|0;
 $1 = (__Z101System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_ToPrime_gsharedP22mscorlib_System_ObjectiPPv(0,$x,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z131mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctor_mscorlib_System_VoidP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396752);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(359,($__this|0),10,(0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z109mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_InitP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32iP22mscorlib_System_Object($__this,$capacity,$hcp) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $hcp = $hcp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397616);
 __THREW__ = 0;
 invoke_v(335);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($capacity|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020592>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($hcp|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(1334656|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = HEAP32[((1334656 + 84|0))>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iii(2744,(0|0),($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $G_B5_0$0 = $19;
   } else {
    $G_B5_0$0 = $hcp;
   }
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = (($__this) + 40|0);
    HEAP32[$24>>2] = $G_B5_0$0;
    $25 = ($capacity|0)==(0);
    $26 = (Math_fround(($capacity|0)));
    $27 = $25 ? Math_fround(10.0) : $26;
    $28 = Math_fround($27 / Math_fround(0.899999976158142089843));
    $29 = (~~(($28)));
    $30 = (($29) + 1)|0;
    __THREW__ = 0;
    invoke_vii(1331,($__this|0),($30|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = (($__this) + 48|0);
     HEAP32[$33>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z192mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396800);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(359,($__this|0),10,($comparer|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z153mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32i($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396848);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(359,($__this|0),($capacity|0),(0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z148mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_ICollection_get_SyncRootP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396896);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396944);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z221mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1396992);
 __THREW__ = 0;
 $0 = (invoke_ii(896,($keyValuePair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(897,($keyValuePair|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viiii(461,(1397040|0),($__this|0),($0|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z114mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_KeyP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402096);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z116mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_ValueP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402192);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z226mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397088);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(326,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ContainsKeyValuePairP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$pair) {
 $__this = $__this|0;
 $pair = $pair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1398192);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(896,($pair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiii(299,(1398096|0),($__this|0),($0|0),($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   if (!($3)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_ii(913,0)|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(897,($pair|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP32[$V_0>>2]|0;
      __THREW__ = 0;
      $17 = (invoke_iiiii(304,(1398240|0),($8|0),($11|0),($16|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z224mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P94mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_Int32U003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397136);
 __THREW__ = 0;
 invoke_viii(361,($__this|0),($_____array|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_CopyToP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P94mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_Int32U003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397808);
 __THREW__ = 0;
 invoke_viii(360,($__this|0),($_____array|0),($index|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1408392|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(1408392|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    HEAP32[$0>>2] = 1397376;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viii(369,($5|0),(0|0),($$byval_copy|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_viiii(279,($__this|0),($_____array|0),($index|0),($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z224mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397184);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(326,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  if (!($11)) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $16 = (invoke_ii(896,($keyValuePair|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iiii(1640,(1397232|0),($__this|0),($16|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z142mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_ICollection_CopyToP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397280);
 __THREW__ = 0;
 (invoke_ii(2996,(1173000|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($_____array|0),(1173000|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if (!($7)) {
     __THREW__ = 0;
     invoke_viii(361,($__this|0),($4|0),($index|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_viii(360,($__this|0),($_____array|0),($index|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     (invoke_ii(2996,(1171160|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_iii(2735,($_____array|0),(1171160|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = ($16|0)==(0|0);
       if ($19) {
        __THREW__ = 0;
        (invoke_ii(2996,(1408392|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_ii(3469,(1408392|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        HEAP32[$1>>2] = 1397376;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_viii(369,($48|0),(0|0),($$byval_copy1|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
        __THREW__ = 0;
        invoke_viiii(277,($__this|0),($_____array|0),($index|0),($48|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1400808|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = HEAP32[((1400808 + 80|0))>>2]|0;
        $23 = (($22) + 16|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = ($24|0)==(0|0);
        if ($25) {
         __THREW__ = 0;
         (invoke_ii(2996,(1407816|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         __THREW__ = 0;
         $28 = (invoke_ii(3469,(1407816|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         HEAP32[$0>>2] = 1397328;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_viii(367,($28|0),(0|0),($$byval_copy1|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1400808|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         $35 = HEAP32[((1400808 + 80|0))>>2]|0;
         $36 = (($35) + 16|0);
         HEAP32[$36>>2] = $28;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1400808|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = HEAP32[((1400808 + 80|0))>>2]|0;
         $40 = (($39) + 16|0);
         $41 = HEAP32[$40>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          __THREW__ = 0;
          invoke_viiii(276,($__this|0),($16|0),($index|0),($41|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if (!($45)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_CopyToCheckP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397712);
 __THREW__ = 0;
 invoke_v(336);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020608>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)>(-1);
   if (!($15)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3020616>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_ii(1857,($_____array|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $31 = ($28|0)<($index|0);
     if ($31) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2560072|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = HEAP32[3020624>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($34|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3810,($34|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      $44 = (invoke_ii(1857,($_____array|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       __THREW__ = 0;
       $47 = (invoke_iii(2729,(1397520|0),($__this|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        $50 = (($44) - ($index))|0;
        $51 = ($50|0)<($47|0);
        if (!($51)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if (!($53)) {
         __THREW__ = 0;
         $54 = (invoke_ii(3469,(2560072|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          $57 = HEAP32[3020632>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($54|0),($57|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           __THREW__ = 0;
           invoke_vi(3810,($54|0));
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if (!($61)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z175mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1407384);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z236mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1407960);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z231mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397424);
 ;HEAP32[$L_0+0>>2]=0|0;HEAP32[$L_0+4>>2]=0|0;HEAP32[$L_0+8>>2]=0|0;HEAP32[$L_0+12>>2]=0|0;HEAP32[$L_0+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1341,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1406664|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1406664|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1405872);
 HEAP32[$__this>>2] = $dictionary;
 __THREW__ = 0;
 invoke_vi(3799,($dictionary|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($dictionary) + 48|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IDictionary_GetEnumeratorP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397472);
 __THREW__ = 0;
 (invoke_ii(2996,(1408928|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1408928|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1344,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP117mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1408536);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($host|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   invoke_vii(1332,($L_0|0),($host|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($__this) + 8|0);
    ;HEAP32[$6+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$L_0+16>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z114mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CountP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397520);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_set_ItemP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_2$2 = 0, $V_2$3 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $V_3$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397568);
 __THREW__ = 0;
 invoke_v(334);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3020568>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iiii(1652,(1334888|0),($18|0),($key|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = $21 | -2147483648;
     $25 = $21 & 2147483647;
     $26 = (($__this) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($27|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = (($27) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($25|0) % ($31|0))&-1;
      $33 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = (($33) + 12|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($32>>>0)<($37>>>0);
       if (!($38)) {
        __THREW__ = 0;
        $39 = (invoke_i(132)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($39|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
       }
       $44 = HEAP32[$33>>2]|0;
       $45 = (($33) + 16|0);
       $46 = (($44) + 92|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = Math_imul($47, $32)|0;
       $49 = (($45) + ($48)|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = (($50) + -1)|0;
       $52 = ($50|0)==(0);
       L18: do {
        if ($52) {
         $V_2$1 = $51;$V_3$1 = -1;
         label = 40;
        } else {
         $53 = (($__this) + 12|0);
         $54 = (($__this) + 16|0);
         $V_2$0 = $51;$V_3$0 = -1;
         while(1) {
          $55 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($55|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          $58 = ($V_2$0|0)<(0);
          if ($58) {
           label = 23;
          } else {
           $59 = (($55) + 12|0);
           $60 = HEAP32[$59>>2]|0;
           $61 = ($V_2$0>>>0)<($60>>>0);
           if (!($61)) {
            label = 23;
           }
          }
          if ((label|0) == 23) {
           label = 0;
           __THREW__ = 0;
           $62 = (invoke_i(132)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($62|0));
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if ($66) {
            break;
           }
          }
          $67 = HEAP32[$55>>2]|0;
          $68 = (($55) + 16|0);
          $69 = (($67) + 92|0);
          $70 = HEAP32[$69>>2]|0;
          $71 = Math_imul($70, $V_2$0)|0;
          $72 = (($68) + ($71)|0);
          $73 = HEAP32[$72>>2]|0;
          $74 = ($73|0)==($24|0);
          if ($74) {
           $75 = HEAP32[$17>>2]|0;
           $76 = HEAP32[$54>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($76|0));
           $77 = __THREW__; __THREW__ = 0;
           $78 = $77&1;
           if ($78) {
            break;
           }
           if ($58) {
            label = 29;
           } else {
            $79 = (($76) + 12|0);
            $80 = HEAP32[$79>>2]|0;
            $81 = ($V_2$0>>>0)<($80>>>0);
            if (!($81)) {
             label = 29;
            }
           }
           if ((label|0) == 29) {
            label = 0;
            __THREW__ = 0;
            $82 = (invoke_i(132)|0);
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if ($84) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($82|0));
            $85 = __THREW__; __THREW__ = 0;
            $86 = $85&1;
            if ($86) {
             break;
            }
           }
           $87 = HEAP32[$76>>2]|0;
           $88 = (($76) + 16|0);
           $89 = (($87) + 92|0);
           $90 = HEAP32[$89>>2]|0;
           $91 = Math_imul($90, $V_2$0)|0;
           $92 = (($88) + ($91)|0);
           $93 = HEAP32[$92>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($75|0));
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if ($95) {
            break;
           }
           __THREW__ = 0;
           $96 = (invoke_iiiii(305,(1334824|0),($75|0),($93|0),($key|0))|0);
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if ($98) {
            break;
           }
           if ($96) {
            $V_2$1 = $V_2$0;$V_3$1 = $V_3$0;
            label = 40;
            break L18;
           }
          }
          $99 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($99|0));
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          if ($58) {
           label = 37;
          } else {
           $102 = (($99) + 12|0);
           $103 = HEAP32[$102>>2]|0;
           $104 = ($V_2$0>>>0)<($103>>>0);
           if (!($104)) {
            label = 37;
           }
          }
          if ((label|0) == 37) {
           label = 0;
           __THREW__ = 0;
           $105 = (invoke_i(132)|0);
           $106 = __THREW__; __THREW__ = 0;
           $107 = $106&1;
           if ($107) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($105|0));
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            break;
           }
          }
          $110 = HEAP32[$99>>2]|0;
          $111 = (($99) + 16|0);
          $112 = (($110) + 92|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = Math_imul($113, $V_2$0)|0;
          $$sum = (($114) + 4)|0;
          $115 = (($111) + ($$sum)|0);
          $116 = HEAP32[$115>>2]|0;
          $117 = ($116|0)==(-1);
          if ($117) {
           label = 41;
           break L18;
          } else {
           $V_3$0$phi = $V_2$0;$V_2$0 = $116;$V_3$0 = $V_3$0$phi;
          }
         }
         $3 = ___cxa_find_matching_catch()|0;
         $4 = tempRet0;
         $lpad$phi$index = $3;$lpad$phi$index2 = $4;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
       } while(0);
       if ((label|0) == 40) {
        $118 = ($V_2$1|0)==(-1);
        if ($118) {
         label = 41;
        } else {
         $257 = ($V_3$1|0)==(-1);
         if ($257) {
          $V_2$3 = $V_2$1;
         } else {
          $258 = (($__this) + 12|0);
          $259 = HEAP32[$258>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($259|0));
          $260 = __THREW__; __THREW__ = 0;
          $261 = $260&1;
          if ($261) {
           break;
          }
          $262 = ($V_3$1|0)<(0);
          if ($262) {
           label = 85;
          } else {
           $263 = (($259) + 12|0);
           $264 = HEAP32[$263>>2]|0;
           $265 = ($V_3$1>>>0)<($264>>>0);
           if (!($265)) {
            label = 85;
           }
          }
          if ((label|0) == 85) {
           __THREW__ = 0;
           $266 = (invoke_i(132)|0);
           $267 = __THREW__; __THREW__ = 0;
           $268 = $267&1;
           if ($268) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($266|0));
           $269 = __THREW__; __THREW__ = 0;
           $270 = $269&1;
           if ($270) {
            break;
           }
          }
          $271 = HEAP32[$259>>2]|0;
          $272 = (($259) + 16|0);
          $273 = (($271) + 92|0);
          $274 = HEAP32[$273>>2]|0;
          $275 = Math_imul($274, $V_3$1)|0;
          $276 = HEAP32[$258>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($276|0));
          $277 = __THREW__; __THREW__ = 0;
          $278 = $277&1;
          if ($278) {
           break;
          }
          $279 = ($V_2$1|0)<(0);
          if ($279) {
           label = 90;
          } else {
           $280 = (($276) + 12|0);
           $281 = HEAP32[$280>>2]|0;
           $282 = ($V_2$1>>>0)<($281>>>0);
           if (!($282)) {
            label = 90;
           }
          }
          if ((label|0) == 90) {
           __THREW__ = 0;
           $283 = (invoke_i(132)|0);
           $284 = __THREW__; __THREW__ = 0;
           $285 = $284&1;
           if ($285) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($283|0));
           $286 = __THREW__; __THREW__ = 0;
           $287 = $286&1;
           if ($287) {
            break;
           }
          }
          $288 = HEAP32[$276>>2]|0;
          $289 = (($276) + 16|0);
          $290 = (($288) + 92|0);
          $291 = HEAP32[$290>>2]|0;
          $292 = Math_imul($291, $V_2$1)|0;
          $$sum3 = (($292) + 4)|0;
          $293 = (($289) + ($$sum3)|0);
          $294 = HEAP32[$293>>2]|0;
          $$sum4 = (($275) + 4)|0;
          $295 = (($272) + ($$sum4)|0);
          HEAP32[$295>>2] = $294;
          $296 = HEAP32[$258>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($296|0));
          $297 = __THREW__; __THREW__ = 0;
          $298 = $297&1;
          if ($298) {
           break;
          }
          if ($279) {
           label = 95;
          } else {
           $299 = (($296) + 12|0);
           $300 = HEAP32[$299>>2]|0;
           $301 = ($V_2$1>>>0)<($300>>>0);
           if (!($301)) {
            label = 95;
           }
          }
          if ((label|0) == 95) {
           __THREW__ = 0;
           $302 = (invoke_i(132)|0);
           $303 = __THREW__; __THREW__ = 0;
           $304 = $303&1;
           if ($304) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($302|0));
           $305 = __THREW__; __THREW__ = 0;
           $306 = $305&1;
           if ($306) {
            break;
           }
          }
          $307 = HEAP32[$296>>2]|0;
          $308 = (($296) + 16|0);
          $309 = (($307) + 92|0);
          $310 = HEAP32[$309>>2]|0;
          $311 = Math_imul($310, $V_2$1)|0;
          $312 = HEAP32[$26>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($312|0));
          $313 = __THREW__; __THREW__ = 0;
          $314 = $313&1;
          if ($314) {
           break;
          }
          $315 = (($312) + 12|0);
          $316 = HEAP32[$315>>2]|0;
          $317 = ($32>>>0)<($316>>>0);
          if (!($317)) {
           __THREW__ = 0;
           $318 = (invoke_i(132)|0);
           $319 = __THREW__; __THREW__ = 0;
           $320 = $319&1;
           if ($320) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($318|0));
           $321 = __THREW__; __THREW__ = 0;
           $322 = $321&1;
           if ($322) {
            break;
           }
          }
          $323 = HEAP32[$312>>2]|0;
          $324 = (($312) + 16|0);
          $325 = (($323) + 92|0);
          $326 = HEAP32[$325>>2]|0;
          $327 = Math_imul($326, $32)|0;
          $328 = (($324) + ($327)|0);
          $329 = HEAP32[$328>>2]|0;
          $330 = (($329) + -1)|0;
          $$sum5 = (($311) + 4)|0;
          $331 = (($308) + ($$sum5)|0);
          HEAP32[$331>>2] = $330;
          $332 = HEAP32[$26>>2]|0;
          $333 = (($V_2$1) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($332|0));
          $334 = __THREW__; __THREW__ = 0;
          $335 = $334&1;
          if ($335) {
           break;
          }
          $336 = (($332) + 12|0);
          $337 = HEAP32[$336>>2]|0;
          $338 = ($32>>>0)<($337>>>0);
          if (!($338)) {
           __THREW__ = 0;
           $339 = (invoke_i(132)|0);
           $340 = __THREW__; __THREW__ = 0;
           $341 = $340&1;
           if ($341) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($339|0));
           $342 = __THREW__; __THREW__ = 0;
           $343 = $342&1;
           if ($343) {
            break;
           }
          }
          $344 = HEAP32[$332>>2]|0;
          $345 = (($332) + 16|0);
          $346 = (($344) + 92|0);
          $347 = HEAP32[$346>>2]|0;
          $348 = Math_imul($347, $32)|0;
          $349 = (($345) + ($348)|0);
          HEAP32[$349>>2] = $333;
          $V_2$3 = $V_2$1;
         }
        }
       }
       if ((label|0) == 41) {
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         break;
        }
        $121 = (($__this) + 32|0);
        $122 = HEAP32[$121>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if ($124) {
         break;
        }
        $125 = (($122) + 1)|0;
        HEAP32[$121>>2] = $125;
        $126 = (($__this) + 36|0);
        $127 = HEAP32[$126>>2]|0;
        $128 = ($122|0)<($127|0);
        if ($128) {
         $V_1$0 = $32;
        } else {
         __THREW__ = 0;
         invoke_vi(1527,($__this|0));
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          break;
         }
         $131 = HEAP32[$26>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($131|0));
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          break;
         }
         $134 = (($131) + 12|0);
         $135 = HEAP32[$134>>2]|0;
         $136 = (($25|0) % ($135|0))&-1;
         $V_1$0 = $136;
        }
        $137 = (($__this) + 28|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = ($138|0)==(-1);
        if ($139) {
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $140 = __THREW__; __THREW__ = 0;
         $141 = $140&1;
         if ($141) {
          break;
         }
         $142 = (($__this) + 24|0);
         $143 = HEAP32[$142>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if ($145) {
          break;
         }
         $146 = (($143) + 1)|0;
         HEAP32[$142>>2] = $146;
         $$pre = (($__this) + 12|0);
         $$pre$phiZ2D = $$pre;$V_2$2 = $143;
        } else {
         $147 = (($__this) + 12|0);
         $148 = HEAP32[$147>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($148|0));
         $149 = __THREW__; __THREW__ = 0;
         $150 = $149&1;
         if ($150) {
          break;
         }
         $151 = ($138|0)<(0);
         if ($151) {
          label = 54;
         } else {
          $152 = (($148) + 12|0);
          $153 = HEAP32[$152>>2]|0;
          $154 = ($138>>>0)<($153>>>0);
          if (!($154)) {
           label = 54;
          }
         }
         if ((label|0) == 54) {
          __THREW__ = 0;
          $155 = (invoke_i(132)|0);
          $156 = __THREW__; __THREW__ = 0;
          $157 = $156&1;
          if ($157) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($155|0));
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           break;
          }
         }
         $160 = HEAP32[$148>>2]|0;
         $161 = (($148) + 16|0);
         $162 = (($160) + 92|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = Math_imul($163, $138)|0;
         $$sum1 = (($164) + 4)|0;
         $165 = (($161) + ($$sum1)|0);
         $166 = HEAP32[$165>>2]|0;
         HEAP32[$137>>2] = $166;
         $$pre$phiZ2D = $147;$V_2$2 = $138;
        }
        $167 = HEAP32[$$pre$phiZ2D>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($167|0));
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         break;
        }
        $170 = ($V_2$2|0)<(0);
        if ($170) {
         label = 60;
        } else {
         $171 = (($167) + 12|0);
         $172 = HEAP32[$171>>2]|0;
         $173 = ($V_2$2>>>0)<($172>>>0);
         if (!($173)) {
          label = 60;
         }
        }
        if ((label|0) == 60) {
         __THREW__ = 0;
         $174 = (invoke_i(132)|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($174|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          break;
         }
        }
        $179 = HEAP32[$167>>2]|0;
        $180 = (($167) + 16|0);
        $181 = (($179) + 92|0);
        $182 = HEAP32[$181>>2]|0;
        $183 = Math_imul($182, $V_2$2)|0;
        $184 = HEAP32[$26>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($184|0));
        $185 = __THREW__; __THREW__ = 0;
        $186 = $185&1;
        if ($186) {
         break;
        }
        $187 = (($184) + 12|0);
        $188 = HEAP32[$187>>2]|0;
        $189 = ($V_1$0>>>0)<($188>>>0);
        if (!($189)) {
         __THREW__ = 0;
         $190 = (invoke_i(132)|0);
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($190|0));
         $193 = __THREW__; __THREW__ = 0;
         $194 = $193&1;
         if ($194) {
          break;
         }
        }
        $195 = HEAP32[$184>>2]|0;
        $196 = (($184) + 16|0);
        $197 = (($195) + 92|0);
        $198 = HEAP32[$197>>2]|0;
        $199 = Math_imul($198, $V_1$0)|0;
        $200 = (($196) + ($199)|0);
        $201 = HEAP32[$200>>2]|0;
        $202 = (($201) + -1)|0;
        $$sum2 = (($183) + 4)|0;
        $203 = (($180) + ($$sum2)|0);
        HEAP32[$203>>2] = $202;
        $204 = HEAP32[$26>>2]|0;
        $205 = (($V_2$2) + 1)|0;
        __THREW__ = 0;
        invoke_vi(3799,($204|0));
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         break;
        }
        $208 = (($204) + 12|0);
        $209 = HEAP32[$208>>2]|0;
        $210 = ($V_1$0>>>0)<($209>>>0);
        if (!($210)) {
         __THREW__ = 0;
         $211 = (invoke_i(132)|0);
         $212 = __THREW__; __THREW__ = 0;
         $213 = $212&1;
         if ($213) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($211|0));
         $214 = __THREW__; __THREW__ = 0;
         $215 = $214&1;
         if ($215) {
          break;
         }
        }
        $216 = HEAP32[$204>>2]|0;
        $217 = (($204) + 16|0);
        $218 = (($216) + 92|0);
        $219 = HEAP32[$218>>2]|0;
        $220 = Math_imul($219, $V_1$0)|0;
        $221 = (($217) + ($220)|0);
        HEAP32[$221>>2] = $205;
        $222 = HEAP32[$$pre$phiZ2D>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($222|0));
        $223 = __THREW__; __THREW__ = 0;
        $224 = $223&1;
        if ($224) {
         break;
        }
        if ($170) {
         label = 73;
        } else {
         $225 = (($222) + 12|0);
         $226 = HEAP32[$225>>2]|0;
         $227 = ($V_2$2>>>0)<($226>>>0);
         if (!($227)) {
          label = 73;
         }
        }
        if ((label|0) == 73) {
         __THREW__ = 0;
         $228 = (invoke_i(132)|0);
         $229 = __THREW__; __THREW__ = 0;
         $230 = $229&1;
         if ($230) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($228|0));
         $231 = __THREW__; __THREW__ = 0;
         $232 = $231&1;
         if ($232) {
          break;
         }
        }
        $233 = HEAP32[$222>>2]|0;
        $234 = (($222) + 16|0);
        $235 = (($233) + 92|0);
        $236 = HEAP32[$235>>2]|0;
        $237 = Math_imul($236, $V_2$2)|0;
        $238 = (($234) + ($237)|0);
        HEAP32[$238>>2] = $24;
        $239 = (($__this) + 16|0);
        $240 = HEAP32[$239>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($240|0));
        $241 = __THREW__; __THREW__ = 0;
        $242 = $241&1;
        if ($242) {
         break;
        }
        if ($170) {
         label = 78;
        } else {
         $243 = (($240) + 12|0);
         $244 = HEAP32[$243>>2]|0;
         $245 = ($V_2$2>>>0)<($244>>>0);
         if (!($245)) {
          label = 78;
         }
        }
        if ((label|0) == 78) {
         __THREW__ = 0;
         $246 = (invoke_i(132)|0);
         $247 = __THREW__; __THREW__ = 0;
         $248 = $247&1;
         if ($248) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($246|0));
         $249 = __THREW__; __THREW__ = 0;
         $250 = $249&1;
         if ($250) {
          break;
         }
        }
        $251 = HEAP32[$240>>2]|0;
        $252 = (($240) + 16|0);
        $253 = (($251) + 92|0);
        $254 = HEAP32[$253>>2]|0;
        $255 = Math_imul($254, $V_2$2)|0;
        $256 = (($252) + ($255)|0);
        HEAP32[$256>>2] = $key;
        $V_2$3 = $V_2$2;
       }
       $350 = (($__this) + 20|0);
       $351 = HEAP32[$350>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($351|0));
       $352 = __THREW__; __THREW__ = 0;
       $353 = $352&1;
       if (!($353)) {
        $354 = ($V_2$3|0)<(0);
        if ($354) {
         label = 109;
        } else {
         $355 = (($351) + 12|0);
         $356 = HEAP32[$355>>2]|0;
         $357 = ($V_2$3>>>0)<($356>>>0);
         if (!($357)) {
          label = 109;
         }
        }
        if ((label|0) == 109) {
         __THREW__ = 0;
         $358 = (invoke_i(132)|0);
         $359 = __THREW__; __THREW__ = 0;
         $360 = $359&1;
         if ($360) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($358|0));
         $361 = __THREW__; __THREW__ = 0;
         $362 = $361&1;
         if ($362) {
          break;
         }
        }
        $363 = HEAP32[$351>>2]|0;
        $364 = (($351) + 16|0);
        $365 = (($363) + 92|0);
        $366 = HEAP32[$365>>2]|0;
        $367 = Math_imul($366, $V_2$3)|0;
        $368 = (($364) + ($367)|0);
        HEAP32[$368>>2] = $value;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $369 = __THREW__; __THREW__ = 0;
        $370 = $369&1;
        if (!($370)) {
         $371 = (($__this) + 48|0);
         $372 = HEAP32[$371>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $373 = __THREW__; __THREW__ = 0;
         $374 = $373&1;
         if (!($374)) {
          $375 = (($372) + 1)|0;
          HEAP32[$371>>2] = $375;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN21InterfaceFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ResizeP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $$sum = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $V_4$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397856);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5 << 1;
   $7 = $6 | 1;
   __THREW__ = 0;
   $8 = (invoke_iii(835,(0|0),($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1170368|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_iii(2743,(1170368|0),($8|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(1170744|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_iii(2743,(1170744|0),($8|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $21 = (($18) + 16|0);
        $22 = (($__this) + 40|0);
        $23 = (($__this) + 16|0);
        $24 = (($13) + 12|0);
        $25 = (($13) + 16|0);
        $26 = (($__this) + 12|0);
        $27 = (($18) + 12|0);
        $V_3$0 = 0;
        L8: while(1) {
         $159 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($159|0));
         $160 = __THREW__; __THREW__ = 0;
         $161 = $160&1;
         if ($161) {
          label = 9;
          break;
         }
         $162 = (($159) + 12|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = ($V_3$0|0)<($163|0);
         if (!($164)) {
          label = 52;
          break;
         }
         $35 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($35|0));
         $165 = __THREW__; __THREW__ = 0;
         $166 = $165&1;
         if ($166) {
          label = 9;
          break;
         }
         $34 = (($35) + 12|0);
         $36 = HEAP32[$34>>2]|0;
         $37 = ($V_3$0>>>0)<($36>>>0);
         if (!($37)) {
          __THREW__ = 0;
          $38 = (invoke_i(132)|0);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           label = 9;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($38|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           label = 9;
           break;
          }
         }
         $43 = HEAP32[$35>>2]|0;
         $44 = (($35) + 16|0);
         $45 = (($43) + 92|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = Math_imul($46, $V_3$0)|0;
         $48 = (($44) + ($47)|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ($49|0)==(0);
         if (!($50)) {
          $51 = (($49) + -1)|0;
          $V_4$05 = $51;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($18|0));
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            label = 8;
            break L8;
           }
           $52 = ($V_4$05|0)<(0);
           if ($52) {
            label = 19;
           } else {
            $53 = HEAP32[$27>>2]|0;
            $54 = ($V_4$05>>>0)<($53>>>0);
            if (!($54)) {
             label = 19;
            }
           }
           if ((label|0) == 19) {
            label = 0;
            __THREW__ = 0;
            $55 = (invoke_i(132)|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($55|0));
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             label = 8;
             break L8;
            }
           }
           $60 = HEAP32[$18>>2]|0;
           $61 = (($60) + 92|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = Math_imul($62, $V_4$05)|0;
           $64 = (($21) + ($63)|0);
           $65 = HEAP32[$22>>2]|0;
           $66 = HEAP32[$23>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($66|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 24;
           } else {
            $69 = (($66) + 12|0);
            $70 = HEAP32[$69>>2]|0;
            $71 = ($V_4$05>>>0)<($70>>>0);
            if (!($71)) {
             label = 24;
            }
           }
           if ((label|0) == 24) {
            label = 0;
            __THREW__ = 0;
            $72 = (invoke_i(132)|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($72|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 8;
             break L8;
            }
           }
           $77 = HEAP32[$66>>2]|0;
           $78 = (($66) + 16|0);
           $79 = (($77) + 92|0);
           $80 = HEAP32[$79>>2]|0;
           $81 = Math_imul($80, $V_4$05)|0;
           $82 = (($78) + ($81)|0);
           $83 = HEAP32[$82>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($65|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            label = 8;
            break L8;
           }
           __THREW__ = 0;
           $86 = (invoke_iiii(1652,(1334888|0),($65|0),($83|0))|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            label = 8;
            break L8;
           }
           $89 = $86 | -2147483648;
           HEAP32[$64>>2] = $89;
           $90 = $86 & 2147483647;
           $91 = (($90|0) % ($8|0))&-1;
           __THREW__ = 0;
           invoke_vi(3799,($18|0));
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 31;
           } else {
            $94 = HEAP32[$27>>2]|0;
            $95 = ($V_4$05>>>0)<($94>>>0);
            if (!($95)) {
             label = 31;
            }
           }
           if ((label|0) == 31) {
            label = 0;
            __THREW__ = 0;
            $96 = (invoke_i(132)|0);
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($96|0));
            $99 = __THREW__; __THREW__ = 0;
            $100 = $99&1;
            if ($100) {
             label = 8;
             break L8;
            }
           }
           $101 = HEAP32[$18>>2]|0;
           $102 = (($101) + 92|0);
           $103 = HEAP32[$102>>2]|0;
           $104 = Math_imul($103, $V_4$05)|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            label = 8;
            break L8;
           }
           $107 = HEAP32[$24>>2]|0;
           $108 = ($91>>>0)<($107>>>0);
           if (!($108)) {
            __THREW__ = 0;
            $109 = (invoke_i(132)|0);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if ($111) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($109|0));
            $112 = __THREW__; __THREW__ = 0;
            $113 = $112&1;
            if ($113) {
             label = 8;
             break L8;
            }
           }
           $114 = HEAP32[$13>>2]|0;
           $115 = (($114) + 92|0);
           $116 = HEAP32[$115>>2]|0;
           $117 = Math_imul($116, $91)|0;
           $118 = (($25) + ($117)|0);
           $119 = HEAP32[$118>>2]|0;
           $120 = (($119) + -1)|0;
           $$sum = (($104) + 4)|0;
           $121 = (($21) + ($$sum)|0);
           HEAP32[$121>>2] = $120;
           $122 = (($V_4$05) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $123 = __THREW__; __THREW__ = 0;
           $124 = $123&1;
           if ($124) {
            label = 8;
            break L8;
           }
           $125 = HEAP32[$24>>2]|0;
           $126 = ($91>>>0)<($125>>>0);
           if (!($126)) {
            __THREW__ = 0;
            $127 = (invoke_i(132)|0);
            $128 = __THREW__; __THREW__ = 0;
            $129 = $128&1;
            if ($129) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($127|0));
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             label = 8;
             break L8;
            }
           }
           $132 = HEAP32[$13>>2]|0;
           $133 = (($132) + 92|0);
           $134 = HEAP32[$133>>2]|0;
           $135 = Math_imul($134, $91)|0;
           $136 = (($25) + ($135)|0);
           HEAP32[$136>>2] = $122;
           $137 = HEAP32[$26>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($137|0));
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 44;
           } else {
            $140 = (($137) + 12|0);
            $141 = HEAP32[$140>>2]|0;
            $142 = ($V_4$05>>>0)<($141>>>0);
            if (!($142)) {
             label = 44;
            }
           }
           if ((label|0) == 44) {
            label = 0;
            __THREW__ = 0;
            $143 = (invoke_i(132)|0);
            $144 = __THREW__; __THREW__ = 0;
            $145 = $144&1;
            if ($145) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($143|0));
            $146 = __THREW__; __THREW__ = 0;
            $147 = $146&1;
            if ($147) {
             label = 8;
             break L8;
            }
           }
           $148 = HEAP32[$137>>2]|0;
           $149 = (($137) + 16|0);
           $150 = (($148) + 92|0);
           $151 = HEAP32[$150>>2]|0;
           $152 = Math_imul($151, $V_4$05)|0;
           $$sum4 = (($152) + 4)|0;
           $153 = (($149) + ($$sum4)|0);
           $154 = HEAP32[$153>>2]|0;
           $155 = ($154|0)==(-1);
           if ($155) {
            break;
           } else {
            $V_4$05 = $154;
           }
          }
         }
         $158 = (($V_3$0) + 1)|0;
         $V_3$0 = $158;
        }
        if ((label|0) == 8) {
         $28 = ___cxa_find_matching_catch()|0;
         $29 = tempRet0;
         $lpad$phi$index = $28;$lpad$phi$index3 = $29;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 9) {
         $30 = ___cxa_find_matching_catch()|0;
         $31 = tempRet0;
         $lpad$phi$index = $30;$lpad$phi$index3 = $31;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 52) {
         HEAP32[$0>>2] = $13;
         HEAP32[$26>>2] = $18;
         __THREW__ = 0;
         (invoke_ii(2996,(1168432|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          break;
         }
         __THREW__ = 0;
         $169 = (invoke_iii(2743,(1168432|0),($8|0))|0);
         $170 = __THREW__; __THREW__ = 0;
         $171 = $170&1;
         if ($171) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1170368|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          break;
         }
         __THREW__ = 0;
         $174 = (invoke_iii(2743,(1170368|0),($8|0))|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          break;
         }
         $177 = HEAP32[$23>>2]|0;
         $178 = (($__this) + 24|0);
         $179 = HEAP32[$178>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($177|0),0,($169|0),0,($179|0));
         $180 = __THREW__; __THREW__ = 0;
         $181 = $180&1;
         if ($181) {
          break;
         }
         $182 = (($__this) + 20|0);
         $183 = HEAP32[$182>>2]|0;
         $184 = HEAP32[$178>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($183|0),0,($174|0),0,($184|0));
         $185 = __THREW__; __THREW__ = 0;
         $186 = $185&1;
         if ($186) {
          break;
         }
         HEAP32[$23>>2] = $169;
         HEAP32[$182>>2] = $174;
         $187 = (Math_fround(($8|0)));
         $188 = Math_fround($187 * Math_fround(0.899999976158142089843));
         $189 = (~~(($188)));
         $190 = (($__this) + 36|0);
         HEAP32[$190>>2] = $189;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 $lpad$phi$index = $32;$lpad$phi$index3 = $33;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_InitArraysP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32i($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397664);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2743,(1170368|0),($size|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $2;
   __THREW__ = 0;
   (invoke_ii(2996,(1170744|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2743,(1170744|0),($size|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($__this) + 12|0);
     HEAP32[$11>>2] = $8;
     $12 = (($__this) + 28|0);
     HEAP32[$12>>2] = -1;
     __THREW__ = 0;
     (invoke_ii(2996,(1168432|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_iii(2743,(1168432|0),($size|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = (($__this) + 16|0);
       HEAP32[$18>>2] = $15;
       __THREW__ = 0;
       (invoke_ii(2996,(1170368|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        $21 = (invoke_iii(2743,(1170368|0),($size|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         $24 = (($__this) + 20|0);
         HEAP32[$24>>2] = $21;
         $25 = (($__this) + 24|0);
         HEAP32[$25>>2] = 0;
         $26 = HEAP32[$5>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($26|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($26) + 12|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = (Math_fround(($30|0)));
          $32 = Math_fround($31 * Math_fround(0.899999976158142089843));
          $33 = (~~(($32)));
          $34 = (($__this) + 36|0);
          HEAP32[$34>>2] = $33;
          $35 = ($33|0)==(0);
          if (!($35)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          $38 = HEAP32[$5>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($38|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = (($38) + 12|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = ($42|0)<(1);
           if ($43) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           HEAP32[$34>>2] = 1;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($36|0);
 // unreachable;
}
function __Z114mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_make_pairP22mscorlib_System_ObjectP22mscorlib_System_Stringi($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397376);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(363,($agg$result|0),($key|0),($value|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z112mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402048);
 __THREW__ = 0;
 invoke_vii(1333,($__this|0),($key|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1334,($__this|0),($value|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_pick_valueP22mscorlib_System_ObjectP22mscorlib_System_Stringi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397760);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($value|0);
}
function __Z108mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_AddP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2$05 = 0, $V_2$1 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397040);
 __THREW__ = 0;
 invoke_v(337);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3020792>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iiii(1652,(1334888|0),($18|0),($key|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = $21 | -2147483648;
     $25 = $21 & 2147483647;
     $26 = (($__this) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($27|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = (($27) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($25|0) % ($31|0))&-1;
      $33 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = (($33) + 12|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($32>>>0)<($37>>>0);
       if (!($38)) {
        __THREW__ = 0;
        $39 = (invoke_i(132)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($39|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
       }
       $44 = HEAP32[$33>>2]|0;
       $45 = (($33) + 16|0);
       $46 = (($44) + 92|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = Math_imul($47, $32)|0;
       $49 = (($45) + ($48)|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)==(0);
       L18: do {
        if (!($51)) {
         $52 = (($50) + -1)|0;
         $53 = (($__this) + 12|0);
         $54 = (($__this) + 16|0);
         $V_2$05 = $52;
         while(1) {
          $57 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($57|0));
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           label = 3;
           break;
          }
          $55 = ($V_2$05|0)<(0);
          if ($55) {
           label = 22;
          } else {
           $56 = (($57) + 12|0);
           $58 = HEAP32[$56>>2]|0;
           $59 = ($V_2$05>>>0)<($58>>>0);
           if (!($59)) {
            label = 22;
           }
          }
          if ((label|0) == 22) {
           label = 0;
           __THREW__ = 0;
           $60 = (invoke_i(132)|0);
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($60|0));
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            label = 3;
            break;
           }
          }
          $65 = HEAP32[$57>>2]|0;
          $66 = (($57) + 16|0);
          $67 = (($65) + 92|0);
          $68 = HEAP32[$67>>2]|0;
          $69 = Math_imul($68, $V_2$05)|0;
          $70 = (($66) + ($69)|0);
          $71 = HEAP32[$70>>2]|0;
          $72 = ($71|0)==($24|0);
          if ($72) {
           $73 = HEAP32[$17>>2]|0;
           $74 = HEAP32[$54>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($74|0));
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if ($76) {
            label = 3;
            break;
           }
           if ($55) {
            label = 28;
           } else {
            $77 = (($74) + 12|0);
            $78 = HEAP32[$77>>2]|0;
            $79 = ($V_2$05>>>0)<($78>>>0);
            if (!($79)) {
             label = 28;
            }
           }
           if ((label|0) == 28) {
            label = 0;
            __THREW__ = 0;
            $80 = (invoke_i(132)|0);
            $81 = __THREW__; __THREW__ = 0;
            $82 = $81&1;
            if ($82) {
             label = 3;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($80|0));
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if ($84) {
             label = 3;
             break;
            }
           }
           $85 = HEAP32[$74>>2]|0;
           $86 = (($74) + 16|0);
           $87 = (($85) + 92|0);
           $88 = HEAP32[$87>>2]|0;
           $89 = Math_imul($88, $V_2$05)|0;
           $90 = (($86) + ($89)|0);
           $91 = HEAP32[$90>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($73|0));
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           $94 = (invoke_iiiii(305,(1334824|0),($73|0),($91|0),($key|0))|0);
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if ($96) {
            label = 3;
            break;
           }
           if ($94) {
            break;
           }
          }
          $107 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($107|0));
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           label = 3;
           break;
          }
          if ($55) {
           label = 41;
          } else {
           $110 = (($107) + 12|0);
           $111 = HEAP32[$110>>2]|0;
           $112 = ($V_2$05>>>0)<($111>>>0);
           if (!($112)) {
            label = 41;
           }
          }
          if ((label|0) == 41) {
           label = 0;
           __THREW__ = 0;
           $113 = (invoke_i(132)|0);
           $114 = __THREW__; __THREW__ = 0;
           $115 = $114&1;
           if ($115) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($113|0));
           $116 = __THREW__; __THREW__ = 0;
           $117 = $116&1;
           if ($117) {
            label = 3;
            break;
           }
          }
          $118 = HEAP32[$107>>2]|0;
          $119 = (($107) + 16|0);
          $120 = (($118) + 92|0);
          $121 = HEAP32[$120>>2]|0;
          $122 = Math_imul($121, $V_2$05)|0;
          $$sum = (($122) + 4)|0;
          $123 = (($119) + ($$sum)|0);
          $124 = HEAP32[$123>>2]|0;
          $125 = ($124|0)==(-1);
          if ($125) {
           break L18;
          } else {
           $V_2$05 = $124;
          }
         }
         if ((label|0) == 3) {
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index2 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          break L1;
         }
         __THREW__ = 0;
         $99 = (invoke_ii(3469,(2560072|0))|0);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          break L1;
         }
         $102 = HEAP32[3020800>>2]|0;
         __THREW__ = 0;
         invoke_vii(1924,($99|0),($102|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3810,($99|0));
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          break L1;
         }
         // unreachable;
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if (!($129)) {
        $130 = (($__this) + 32|0);
        $131 = HEAP32[$130>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if (!($133)) {
         $134 = (($131) + 1)|0;
         HEAP32[$130>>2] = $134;
         $135 = (($__this) + 36|0);
         $136 = HEAP32[$135>>2]|0;
         $137 = ($131|0)<($136|0);
         if ($137) {
          $V_1$0 = $32;
         } else {
          __THREW__ = 0;
          invoke_vi(1527,($__this|0));
          $138 = __THREW__; __THREW__ = 0;
          $139 = $138&1;
          if ($139) {
           break;
          }
          $140 = HEAP32[$26>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($140|0));
          $141 = __THREW__; __THREW__ = 0;
          $142 = $141&1;
          if ($142) {
           break;
          }
          $143 = (($140) + 12|0);
          $144 = HEAP32[$143>>2]|0;
          $145 = (($25|0) % ($144|0))&-1;
          $V_1$0 = $145;
         }
         $146 = (($__this) + 28|0);
         $147 = HEAP32[$146>>2]|0;
         $148 = ($147|0)==(-1);
         if ($148) {
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $149 = __THREW__; __THREW__ = 0;
          $150 = $149&1;
          if ($150) {
           break;
          }
          $151 = (($__this) + 24|0);
          $152 = HEAP32[$151>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           break;
          }
          $155 = (($152) + 1)|0;
          HEAP32[$151>>2] = $155;
          $$pre = (($__this) + 12|0);
          $$pre$phiZ2D = $$pre;$V_2$1 = $152;
         } else {
          $156 = (($__this) + 12|0);
          $157 = HEAP32[$156>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($157|0));
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           break;
          }
          $160 = ($147|0)<(0);
          if ($160) {
           label = 58;
          } else {
           $161 = (($157) + 12|0);
           $162 = HEAP32[$161>>2]|0;
           $163 = ($147>>>0)<($162>>>0);
           if (!($163)) {
            label = 58;
           }
          }
          if ((label|0) == 58) {
           __THREW__ = 0;
           $164 = (invoke_i(132)|0);
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($164|0));
           $167 = __THREW__; __THREW__ = 0;
           $168 = $167&1;
           if ($168) {
            break;
           }
          }
          $169 = HEAP32[$157>>2]|0;
          $170 = (($157) + 16|0);
          $171 = (($169) + 92|0);
          $172 = HEAP32[$171>>2]|0;
          $173 = Math_imul($172, $147)|0;
          $$sum3 = (($173) + 4)|0;
          $174 = (($170) + ($$sum3)|0);
          $175 = HEAP32[$174>>2]|0;
          HEAP32[$146>>2] = $175;
          $$pre$phiZ2D = $156;$V_2$1 = $147;
         }
         $176 = HEAP32[$$pre$phiZ2D>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($176|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if (!($178)) {
          $179 = ($V_2$1|0)<(0);
          if ($179) {
           label = 64;
          } else {
           $180 = (($176) + 12|0);
           $181 = HEAP32[$180>>2]|0;
           $182 = ($V_2$1>>>0)<($181>>>0);
           if (!($182)) {
            label = 64;
           }
          }
          if ((label|0) == 64) {
           __THREW__ = 0;
           $183 = (invoke_i(132)|0);
           $184 = __THREW__; __THREW__ = 0;
           $185 = $184&1;
           if ($185) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($183|0));
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if ($187) {
            break;
           }
          }
          $188 = HEAP32[$176>>2]|0;
          $189 = (($176) + 16|0);
          $190 = (($188) + 92|0);
          $191 = HEAP32[$190>>2]|0;
          $192 = Math_imul($191, $V_2$1)|0;
          $193 = (($189) + ($192)|0);
          HEAP32[$193>>2] = $24;
          $194 = HEAP32[$$pre$phiZ2D>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($194|0));
          $195 = __THREW__; __THREW__ = 0;
          $196 = $195&1;
          if (!($196)) {
           if ($179) {
            label = 69;
           } else {
            $197 = (($194) + 12|0);
            $198 = HEAP32[$197>>2]|0;
            $199 = ($V_2$1>>>0)<($198>>>0);
            if (!($199)) {
             label = 69;
            }
           }
           if ((label|0) == 69) {
            __THREW__ = 0;
            $200 = (invoke_i(132)|0);
            $201 = __THREW__; __THREW__ = 0;
            $202 = $201&1;
            if ($202) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($200|0));
            $203 = __THREW__; __THREW__ = 0;
            $204 = $203&1;
            if ($204) {
             break;
            }
           }
           $205 = HEAP32[$194>>2]|0;
           $206 = (($194) + 16|0);
           $207 = (($205) + 92|0);
           $208 = HEAP32[$207>>2]|0;
           $209 = Math_imul($208, $V_2$1)|0;
           $210 = HEAP32[$26>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($210|0));
           $211 = __THREW__; __THREW__ = 0;
           $212 = $211&1;
           if (!($212)) {
            $213 = (($210) + 12|0);
            $214 = HEAP32[$213>>2]|0;
            $215 = ($V_1$0>>>0)<($214>>>0);
            if (!($215)) {
             __THREW__ = 0;
             $216 = (invoke_i(132)|0);
             $217 = __THREW__; __THREW__ = 0;
             $218 = $217&1;
             if ($218) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($216|0));
             $219 = __THREW__; __THREW__ = 0;
             $220 = $219&1;
             if ($220) {
              break;
             }
            }
            $221 = HEAP32[$210>>2]|0;
            $222 = (($210) + 16|0);
            $223 = (($221) + 92|0);
            $224 = HEAP32[$223>>2]|0;
            $225 = Math_imul($224, $V_1$0)|0;
            $226 = (($222) + ($225)|0);
            $227 = HEAP32[$226>>2]|0;
            $228 = (($227) + -1)|0;
            $$sum4 = (($209) + 4)|0;
            $229 = (($206) + ($$sum4)|0);
            HEAP32[$229>>2] = $228;
            $230 = HEAP32[$26>>2]|0;
            $231 = (($V_2$1) + 1)|0;
            __THREW__ = 0;
            invoke_vi(3799,($230|0));
            $232 = __THREW__; __THREW__ = 0;
            $233 = $232&1;
            if (!($233)) {
             $234 = (($230) + 12|0);
             $235 = HEAP32[$234>>2]|0;
             $236 = ($V_1$0>>>0)<($235>>>0);
             if (!($236)) {
              __THREW__ = 0;
              $237 = (invoke_i(132)|0);
              $238 = __THREW__; __THREW__ = 0;
              $239 = $238&1;
              if ($239) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($237|0));
              $240 = __THREW__; __THREW__ = 0;
              $241 = $240&1;
              if ($241) {
               break;
              }
             }
             $242 = HEAP32[$230>>2]|0;
             $243 = (($230) + 16|0);
             $244 = (($242) + 92|0);
             $245 = HEAP32[$244>>2]|0;
             $246 = Math_imul($245, $V_1$0)|0;
             $247 = (($243) + ($246)|0);
             HEAP32[$247>>2] = $231;
             $248 = (($__this) + 16|0);
             $249 = HEAP32[$248>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($249|0));
             $250 = __THREW__; __THREW__ = 0;
             $251 = $250&1;
             if ($251) {
              break;
             }
             if ($179) {
              label = 82;
             } else {
              $252 = (($249) + 12|0);
              $253 = HEAP32[$252>>2]|0;
              $254 = ($V_2$1>>>0)<($253>>>0);
              if (!($254)) {
               label = 82;
              }
             }
             if ((label|0) == 82) {
              __THREW__ = 0;
              $255 = (invoke_i(132)|0);
              $256 = __THREW__; __THREW__ = 0;
              $257 = $256&1;
              if ($257) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($255|0));
              $258 = __THREW__; __THREW__ = 0;
              $259 = $258&1;
              if ($259) {
               break;
              }
             }
             $260 = HEAP32[$249>>2]|0;
             $261 = (($249) + 16|0);
             $262 = (($260) + 92|0);
             $263 = HEAP32[$262>>2]|0;
             $264 = Math_imul($263, $V_2$1)|0;
             $265 = (($261) + ($264)|0);
             HEAP32[$265>>2] = $key;
             $266 = (($__this) + 20|0);
             $267 = HEAP32[$266>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($267|0));
             $268 = __THREW__; __THREW__ = 0;
             $269 = $268&1;
             if ($269) {
              break;
             }
             if ($179) {
              label = 87;
             } else {
              $270 = (($267) + 12|0);
              $271 = HEAP32[$270>>2]|0;
              $272 = ($V_2$1>>>0)<($271>>>0);
              if (!($272)) {
               label = 87;
              }
             }
             if ((label|0) == 87) {
              __THREW__ = 0;
              $273 = (invoke_i(132)|0);
              $274 = __THREW__; __THREW__ = 0;
              $275 = $274&1;
              if ($275) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($273|0));
              $276 = __THREW__; __THREW__ = 0;
              $277 = $276&1;
              if ($277) {
               break;
              }
             }
             $278 = HEAP32[$267>>2]|0;
             $279 = (($267) + 16|0);
             $280 = (($278) + 92|0);
             $281 = HEAP32[$280>>2]|0;
             $282 = Math_imul($281, $V_2$1)|0;
             $283 = (($279) + ($282)|0);
             HEAP32[$283>>2] = $value;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $284 = __THREW__; __THREW__ = 0;
             $285 = $284&1;
             if ($285) {
              break;
             }
             $286 = (($__this) + 48|0);
             $287 = HEAP32[$286>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $288 = __THREW__; __THREW__ = 0;
             $289 = $288&1;
             if ($289) {
              break;
             }
             $290 = (($287) + 1)|0;
             HEAP32[$286>>2] = $290;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z110mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ClearP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397904);
 $0 = (($__this) + 32|0);
 HEAP32[$0>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($2) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($2|0),0,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = (($__this) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = (($10) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($10|0),0,($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = (($__this) + 20|0);
     $18 = HEAP32[$17>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($18) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      __THREW__ = 0;
      invoke_viiii(138,(0|0),($18|0),0,($22|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = (($__this) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $29 = (($26) + 12|0);
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        invoke_viiii(138,(0|0),($26|0),0,($30|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $33 = (($__this) + 28|0);
         HEAP32[$33>>2] = -1;
         $34 = (($__this) + 24|0);
         HEAP32[$34>>2] = 0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          $37 = (($__this) + 48|0);
          $38 = HEAP32[$37>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = (($38) + 1)|0;
           HEAP32[$37>>2] = $41;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($42|0);
 // unreachable;
}
function __Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ContainsValueP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32i($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $V_1$0 = 0, $V_2$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397952);
 __THREW__ = 0;
 $0 = (invoke_ii(913,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index3 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $3 = (($__this) + 8|0);
 $4 = (($__this) + 20|0);
 $5 = (($__this) + 12|0);
 $V_1$0 = 0;
 L5: while(1) {
  $74 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($74|0));
  $75 = __THREW__; __THREW__ = 0;
  $76 = $75&1;
  if ($76) {
   label = 4;
   break;
  }
  $77 = (($74) + 12|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($V_1$0|0)<($78|0);
  if (!($79)) {
   $$0 = 0;
   label = 30;
   break;
  }
  $13 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($13|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   label = 4;
   break;
  }
  $12 = (($13) + 12|0);
  $14 = HEAP32[$12>>2]|0;
  $15 = ($V_1$0>>>0)<($14>>>0);
  if (!($15)) {
   __THREW__ = 0;
   $16 = (invoke_i(132)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 4;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($16|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 4;
    break;
   }
  }
  $21 = HEAP32[$13>>2]|0;
  $22 = (($13) + 16|0);
  $23 = (($21) + 92|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = Math_imul($24, $V_1$0)|0;
  $26 = (($22) + ($25)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0);
  if (!($28)) {
   $29 = (($27) + -1)|0;
   $V_2$02 = $29;
   while(1) {
    $32 = HEAP32[$4>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     label = 3;
     break L5;
    }
    $30 = ($V_2$02|0)<(0);
    if ($30) {
     label = 14;
    } else {
     $31 = (($32) + 12|0);
     $33 = HEAP32[$31>>2]|0;
     $34 = ($V_2$02>>>0)<($33>>>0);
     if (!($34)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     __THREW__ = 0;
     $35 = (invoke_i(132)|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 3;
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3302,($35|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 3;
      break L5;
     }
    }
    $40 = HEAP32[$32>>2]|0;
    $41 = (($32) + 16|0);
    $42 = (($40) + 92|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = Math_imul($43, $V_2$02)|0;
    $45 = (($41) + ($44)|0);
    $46 = HEAP32[$45>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 3;
     break L5;
    }
    __THREW__ = 0;
    $49 = (invoke_iiiii(306,(1398000|0),($0|0),($46|0),($value|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 3;
     break L5;
    }
    if ($49) {
     $$0 = 1;
     label = 30;
     break L5;
    }
    $52 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($52|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 3;
     break L5;
    }
    if ($30) {
     label = 22;
    } else {
     $55 = (($52) + 12|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($V_2$02>>>0)<($56>>>0);
     if (!($57)) {
      label = 22;
     }
    }
    if ((label|0) == 22) {
     label = 0;
     __THREW__ = 0;
     $58 = (invoke_i(132)|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 3;
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3302,($58|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 3;
      break L5;
     }
    }
    $63 = HEAP32[$52>>2]|0;
    $64 = (($52) + 16|0);
    $65 = (($63) + 92|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = Math_imul($66, $V_2$02)|0;
    $$sum = (($67) + 4)|0;
    $68 = (($64) + ($$sum)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(-1);
    if ($70) {
     break;
    } else {
     $V_2$02 = $69;
    }
   }
  }
  $73 = (($V_1$0) + 1)|0;
  $V_1$0 = $73;
 }
 if ((label|0) == 3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $lpad$phi$index = $6;$lpad$phi$index3 = $7;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 4) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $lpad$phi$index = $8;$lpad$phi$index3 = $9;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z90mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1409576);
 __THREW__ = 0;
 (invoke_ii(2996,(1409928|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1409928 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1409928|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1409928|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3811,(1409928|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1409928|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1409928 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS1_E6InvokeEP10MethodInfoPvii($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_GetObjectDataP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1398048);
 __THREW__ = 0;
 invoke_v(338);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020944>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 48|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3020952>>2]|0;
    __THREW__ = 0;
    invoke_viii(618,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 40|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[3020960>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($26|0),($23|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = (($__this) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)<(1);
       if ($31) {
        $V_0$0 = 0;
       } else {
        __THREW__ = 0;
        (invoke_ii(2996,(1173000|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2743,(1173000|0),($30|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(361,($__this|0),($34|0),0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        } else {
         $V_0$0 = $34;
        }
       }
       $39 = (($__this) + 8|0);
       $40 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($40|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        $43 = (($40) + 12|0);
        $44 = HEAP32[$43>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = HEAP32[3020968>>2]|0;
         __THREW__ = 0;
         invoke_viii(618,($info|0),($47|0),($44|0));
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if (!($49)) {
          __THREW__ = 0;
          invoke_vi(3799,($info|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if (!($51)) {
           $52 = HEAP32[3020976>>2]|0;
           __THREW__ = 0;
           invoke_viii(621,($info|0),($52|0),($V_0$0|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if (!($54)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_RemoveP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_String($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $$0 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397232);
 __THREW__ = 0;
 invoke_v(339);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021072>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iiii(1652,(1334888|0),($18|0),($key|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = $21 | -2147483648;
     $25 = (($__this) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = $21 & 2147483647;
      $30 = (($26) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($29|0) % ($31|0))&-1;
      $33 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = (($33) + 12|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($32>>>0)<($37>>>0);
       if (!($38)) {
        __THREW__ = 0;
        $39 = (invoke_i(132)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($39|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
       }
       $44 = HEAP32[$33>>2]|0;
       $45 = (($33) + 16|0);
       $46 = (($44) + 92|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = Math_imul($47, $32)|0;
       $49 = (($45) + ($48)|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)==(0);
       if ($51) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $52 = (($50) + -1)|0;
       $53 = (($__this) + 12|0);
       $54 = (($__this) + 16|0);
       $V_2$0 = $52;$V_3$0 = -1;
       while(1) {
        $55 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 3;
         break;
        }
        $58 = ($V_2$0|0)<(0);
        if ($58) {
         label = 23;
        } else {
         $59 = (($55) + 12|0);
         $60 = HEAP32[$59>>2]|0;
         $61 = ($V_2$0>>>0)<($60>>>0);
         if (!($61)) {
          label = 23;
         }
        }
        if ((label|0) == 23) {
         label = 0;
         __THREW__ = 0;
         $62 = (invoke_i(132)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($62|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          label = 3;
          break;
         }
        }
        $67 = HEAP32[$55>>2]|0;
        $68 = (($55) + 16|0);
        $69 = (($67) + 92|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = Math_imul($70, $V_2$0)|0;
        $72 = (($68) + ($71)|0);
        $73 = HEAP32[$72>>2]|0;
        $74 = ($73|0)==($24|0);
        if ($74) {
         $75 = HEAP32[$17>>2]|0;
         $76 = HEAP32[$54>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($76|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          label = 3;
          break;
         }
         if ($58) {
          label = 29;
         } else {
          $79 = (($76) + 12|0);
          $80 = HEAP32[$79>>2]|0;
          $81 = ($V_2$0>>>0)<($80>>>0);
          if (!($81)) {
           label = 29;
          }
         }
         if ((label|0) == 29) {
          label = 0;
          __THREW__ = 0;
          $82 = (invoke_i(132)|0);
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($82|0));
          $85 = __THREW__; __THREW__ = 0;
          $86 = $85&1;
          if ($86) {
           label = 3;
           break;
          }
         }
         $87 = HEAP32[$76>>2]|0;
         $88 = (($76) + 16|0);
         $89 = (($87) + 92|0);
         $90 = HEAP32[$89>>2]|0;
         $91 = Math_imul($90, $V_2$0)|0;
         $92 = (($88) + ($91)|0);
         $93 = HEAP32[$92>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($75|0));
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $96 = (invoke_iiiii(305,(1334824|0),($75|0),($93|0),($key|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          label = 3;
          break;
         }
         if ($96) {
          label = 40;
          break;
         }
        }
        $99 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($99|0));
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         label = 3;
         break;
        }
        if ($58) {
         label = 37;
        } else {
         $102 = (($99) + 12|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = ($V_2$0>>>0)<($103>>>0);
         if (!($104)) {
          label = 37;
         }
        }
        if ((label|0) == 37) {
         label = 0;
         __THREW__ = 0;
         $105 = (invoke_i(132)|0);
         $106 = __THREW__; __THREW__ = 0;
         $107 = $106&1;
         if ($107) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($105|0));
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          label = 3;
          break;
         }
        }
        $110 = HEAP32[$99>>2]|0;
        $111 = (($99) + 16|0);
        $112 = (($110) + 92|0);
        $113 = HEAP32[$112>>2]|0;
        $114 = Math_imul($113, $V_2$0)|0;
        $$sum = (($114) + 4)|0;
        $115 = (($111) + ($$sum)|0);
        $116 = HEAP32[$115>>2]|0;
        $117 = ($116|0)==(-1);
        if ($117) {
         $$0 = 0;
         label = 88;
         break;
        } else {
         $V_3$0$phi = $V_2$0;$V_2$0 = $116;$V_3$0 = $V_3$0$phi;
        }
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 40) {
        $118 = ($V_2$0|0)==(-1);
        if ($118) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         break;
        }
        $121 = (($__this) + 32|0);
        $122 = HEAP32[$121>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if ($124) {
         break;
        }
        $125 = (($122) + -1)|0;
        HEAP32[$121>>2] = $125;
        $126 = ($V_3$0|0)==(-1);
        if ($126) {
         $127 = HEAP32[$25>>2]|0;
         $128 = HEAP32[$53>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($128|0));
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          break;
         }
         if ($58) {
          label = 47;
         } else {
          $131 = (($128) + 12|0);
          $132 = HEAP32[$131>>2]|0;
          $133 = ($V_2$0>>>0)<($132>>>0);
          if (!($133)) {
           label = 47;
          }
         }
         if ((label|0) == 47) {
          __THREW__ = 0;
          $134 = (invoke_i(132)|0);
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($134|0));
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if ($138) {
           break;
          }
         }
         $139 = HEAP32[$128>>2]|0;
         $140 = (($128) + 16|0);
         $141 = (($139) + 92|0);
         $142 = HEAP32[$141>>2]|0;
         $143 = Math_imul($142, $V_2$0)|0;
         $$sum5 = (($143) + 4)|0;
         $144 = (($140) + ($$sum5)|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = (($145) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($127|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          break;
         }
         $149 = (($127) + 12|0);
         $150 = HEAP32[$149>>2]|0;
         $151 = ($32>>>0)<($150>>>0);
         if (!($151)) {
          __THREW__ = 0;
          $152 = (invoke_i(132)|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($152|0));
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           break;
          }
         }
         $157 = HEAP32[$127>>2]|0;
         $158 = (($127) + 16|0);
         $159 = (($157) + 92|0);
         $160 = HEAP32[$159>>2]|0;
         $161 = Math_imul($160, $32)|0;
         $162 = (($158) + ($161)|0);
         HEAP32[$162>>2] = $146;
        } else {
         $163 = HEAP32[$53>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($163|0));
         $164 = __THREW__; __THREW__ = 0;
         $165 = $164&1;
         if ($165) {
          break;
         }
         $166 = ($V_3$0|0)<(0);
         if ($166) {
          label = 57;
         } else {
          $167 = (($163) + 12|0);
          $168 = HEAP32[$167>>2]|0;
          $169 = ($V_3$0>>>0)<($168>>>0);
          if (!($169)) {
           label = 57;
          }
         }
         if ((label|0) == 57) {
          __THREW__ = 0;
          $170 = (invoke_i(132)|0);
          $171 = __THREW__; __THREW__ = 0;
          $172 = $171&1;
          if ($172) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($170|0));
          $173 = __THREW__; __THREW__ = 0;
          $174 = $173&1;
          if ($174) {
           break;
          }
         }
         $175 = HEAP32[$163>>2]|0;
         $176 = (($163) + 16|0);
         $177 = (($175) + 92|0);
         $178 = HEAP32[$177>>2]|0;
         $179 = Math_imul($178, $V_3$0)|0;
         $180 = HEAP32[$53>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($180|0));
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if ($182) {
          break;
         }
         if ($58) {
          label = 62;
         } else {
          $183 = (($180) + 12|0);
          $184 = HEAP32[$183>>2]|0;
          $185 = ($V_2$0>>>0)<($184>>>0);
          if (!($185)) {
           label = 62;
          }
         }
         if ((label|0) == 62) {
          __THREW__ = 0;
          $186 = (invoke_i(132)|0);
          $187 = __THREW__; __THREW__ = 0;
          $188 = $187&1;
          if ($188) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($186|0));
          $189 = __THREW__; __THREW__ = 0;
          $190 = $189&1;
          if ($190) {
           break;
          }
         }
         $191 = HEAP32[$180>>2]|0;
         $192 = (($180) + 16|0);
         $193 = (($191) + 92|0);
         $194 = HEAP32[$193>>2]|0;
         $195 = Math_imul($194, $V_2$0)|0;
         $$sum2 = (($195) + 4)|0;
         $196 = (($192) + ($$sum2)|0);
         $197 = HEAP32[$196>>2]|0;
         $$sum3 = (($179) + 4)|0;
         $198 = (($176) + ($$sum3)|0);
         HEAP32[$198>>2] = $197;
        }
        $199 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($199|0));
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         break;
        }
        if ($58) {
         label = 68;
        } else {
         $202 = (($199) + 12|0);
         $203 = HEAP32[$202>>2]|0;
         $204 = ($V_2$0>>>0)<($203>>>0);
         if (!($204)) {
          label = 68;
         }
        }
        if ((label|0) == 68) {
         __THREW__ = 0;
         $205 = (invoke_i(132)|0);
         $206 = __THREW__; __THREW__ = 0;
         $207 = $206&1;
         if ($207) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($205|0));
         $208 = __THREW__; __THREW__ = 0;
         $209 = $208&1;
         if ($209) {
          break;
         }
        }
        $210 = HEAP32[$199>>2]|0;
        $211 = (($199) + 16|0);
        $212 = (($210) + 92|0);
        $213 = HEAP32[$212>>2]|0;
        $214 = Math_imul($213, $V_2$0)|0;
        $215 = (($__this) + 28|0);
        $216 = HEAP32[$215>>2]|0;
        $$sum4 = (($214) + 4)|0;
        $217 = (($211) + ($$sum4)|0);
        HEAP32[$217>>2] = $216;
        HEAP32[$215>>2] = $V_2$0;
        $218 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($218|0));
        $219 = __THREW__; __THREW__ = 0;
        $220 = $219&1;
        if ($220) {
         break;
        }
        if ($58) {
         label = 73;
        } else {
         $221 = (($218) + 12|0);
         $222 = HEAP32[$221>>2]|0;
         $223 = ($V_2$0>>>0)<($222>>>0);
         if (!($223)) {
          label = 73;
         }
        }
        if ((label|0) == 73) {
         __THREW__ = 0;
         $224 = (invoke_i(132)|0);
         $225 = __THREW__; __THREW__ = 0;
         $226 = $225&1;
         if ($226) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($224|0));
         $227 = __THREW__; __THREW__ = 0;
         $228 = $227&1;
         if ($228) {
          break;
         }
        }
        $229 = HEAP32[$218>>2]|0;
        $230 = (($218) + 16|0);
        $231 = (($229) + 92|0);
        $232 = HEAP32[$231>>2]|0;
        $233 = Math_imul($232, $V_2$0)|0;
        $234 = (($230) + ($233)|0);
        HEAP32[$234>>2] = 0;
        $235 = HEAP32[$54>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($235|0));
        $236 = __THREW__; __THREW__ = 0;
        $237 = $236&1;
        if ($237) {
         break;
        }
        if ($58) {
         label = 78;
        } else {
         $238 = (($235) + 12|0);
         $239 = HEAP32[$238>>2]|0;
         $240 = ($V_2$0>>>0)<($239>>>0);
         if (!($240)) {
          label = 78;
         }
        }
        if ((label|0) == 78) {
         __THREW__ = 0;
         $241 = (invoke_i(132)|0);
         $242 = __THREW__; __THREW__ = 0;
         $243 = $242&1;
         if ($243) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($241|0));
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if ($245) {
          break;
         }
        }
        $246 = HEAP32[$235>>2]|0;
        $247 = (($235) + 16|0);
        $248 = (($246) + 92|0);
        $249 = HEAP32[$248>>2]|0;
        $250 = Math_imul($249, $V_2$0)|0;
        $251 = (($247) + ($250)|0);
        HEAP32[$251>>2] = 0;
        $252 = (($__this) + 20|0);
        $253 = HEAP32[$252>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($253|0));
        $254 = __THREW__; __THREW__ = 0;
        $255 = $254&1;
        if ($255) {
         break;
        }
        if ($58) {
         label = 83;
        } else {
         $256 = (($253) + 12|0);
         $257 = HEAP32[$256>>2]|0;
         $258 = ($V_2$0>>>0)<($257>>>0);
         if (!($258)) {
          label = 83;
         }
        }
        if ((label|0) == 83) {
         __THREW__ = 0;
         $259 = (invoke_i(132)|0);
         $260 = __THREW__; __THREW__ = 0;
         $261 = $260&1;
         if ($261) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($259|0));
         $262 = __THREW__; __THREW__ = 0;
         $263 = $262&1;
         if ($263) {
          break;
         }
        }
        $264 = HEAP32[$253>>2]|0;
        $265 = (($253) + 16|0);
        $266 = (($264) + 92|0);
        $267 = HEAP32[$266>>2]|0;
        $268 = Math_imul($267, $V_2$0)|0;
        $269 = (($265) + ($268)|0);
        HEAP32[$269>>2] = 0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $270 = __THREW__; __THREW__ = 0;
        $271 = $270&1;
        if ($271) {
         break;
        }
        $272 = (($__this) + 48|0);
        $273 = HEAP32[$272>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $274 = __THREW__; __THREW__ = 0;
        $275 = $274&1;
        if ($275) {
         break;
        }
        $276 = (($273) + 1)|0;
        HEAP32[$272>>2] = $276;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 88) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_TryGetValueP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_StringPi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$04 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1398096);
 __THREW__ = 0;
 invoke_v(340);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021088>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iiii(1652,(1334888|0),($18|0),($key|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = $21 | -2147483648;
     $25 = (($__this) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = $21 & 2147483647;
      $30 = (($26) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($29|0) % ($31|0))&-1;
      __THREW__ = 0;
      invoke_vi(3799,($26|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       $35 = HEAP32[$30>>2]|0;
       $36 = ($32>>>0)<($35>>>0);
       if (!($36)) {
        __THREW__ = 0;
        $37 = (invoke_i(132)|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($37|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
       }
       $42 = HEAP32[$26>>2]|0;
       $43 = (($26) + 16|0);
       $44 = (($42) + 92|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = Math_imul($45, $32)|0;
       $47 = (($43) + ($46)|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ($48|0)==(0);
       if ($49) {
        $$0 = 0;$storemerge = 0;
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $50 = (($48) + -1)|0;
       $51 = (($__this) + 12|0);
       $52 = (($__this) + 16|0);
       $V_1$04 = $50;
       while(1) {
        $55 = HEAP32[$51>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         label = 3;
         break;
        }
        $53 = ($V_1$04|0)<(0);
        if ($53) {
         label = 22;
        } else {
         $54 = (($55) + 12|0);
         $56 = HEAP32[$54>>2]|0;
         $57 = ($V_1$04>>>0)<($56>>>0);
         if (!($57)) {
          label = 22;
         }
        }
        if ((label|0) == 22) {
         label = 0;
         __THREW__ = 0;
         $58 = (invoke_i(132)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($58|0));
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          label = 3;
          break;
         }
        }
        $63 = HEAP32[$55>>2]|0;
        $64 = (($55) + 16|0);
        $65 = (($63) + 92|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = Math_imul($66, $V_1$04)|0;
        $68 = (($64) + ($67)|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = ($69|0)==($24|0);
        if ($70) {
         $71 = HEAP32[$17>>2]|0;
         $72 = HEAP32[$52>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($72|0));
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          label = 3;
          break;
         }
         if ($53) {
          label = 28;
         } else {
          $75 = (($72) + 12|0);
          $76 = HEAP32[$75>>2]|0;
          $77 = ($V_1$04>>>0)<($76>>>0);
          if (!($77)) {
           label = 28;
          }
         }
         if ((label|0) == 28) {
          label = 0;
          __THREW__ = 0;
          $78 = (invoke_i(132)|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($78|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           label = 3;
           break;
          }
         }
         $83 = HEAP32[$72>>2]|0;
         $84 = (($72) + 16|0);
         $85 = (($83) + 92|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = Math_imul($86, $V_1$04)|0;
         $88 = (($84) + ($87)|0);
         $89 = HEAP32[$88>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($71|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $92 = (invoke_iiiii(305,(1334824|0),($71|0),($89|0),($key|0))|0);
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          label = 3;
          break;
         }
         if ($92) {
          label = 33;
          break;
         }
        }
        $114 = HEAP32[$51>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($114|0));
        $115 = __THREW__; __THREW__ = 0;
        $116 = $115&1;
        if ($116) {
         label = 3;
         break;
        }
        if ($53) {
         label = 42;
        } else {
         $117 = (($114) + 12|0);
         $118 = HEAP32[$117>>2]|0;
         $119 = ($V_1$04>>>0)<($118>>>0);
         if (!($119)) {
          label = 42;
         }
        }
        if ((label|0) == 42) {
         label = 0;
         __THREW__ = 0;
         $120 = (invoke_i(132)|0);
         $121 = __THREW__; __THREW__ = 0;
         $122 = $121&1;
         if ($122) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($120|0));
         $123 = __THREW__; __THREW__ = 0;
         $124 = $123&1;
         if ($124) {
          label = 3;
          break;
         }
        }
        $125 = HEAP32[$114>>2]|0;
        $126 = (($114) + 16|0);
        $127 = (($125) + 92|0);
        $128 = HEAP32[$127>>2]|0;
        $129 = Math_imul($128, $V_1$04)|0;
        $$sum = (($129) + 4)|0;
        $130 = (($126) + ($$sum)|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = ($131|0)==(-1);
        if ($132) {
         $$0 = 0;$storemerge = 0;
         label = 46;
         break;
        } else {
         $V_1$04 = $131;
        }
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 33) {
        $95 = (($__this) + 20|0);
        $96 = HEAP32[$95>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($96|0));
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if ($98) {
         break;
        }
        if ($53) {
         label = 36;
        } else {
         $99 = (($96) + 12|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = ($V_1$04>>>0)<($100>>>0);
         if (!($101)) {
          label = 36;
         }
        }
        if ((label|0) == 36) {
         __THREW__ = 0;
         $102 = (invoke_i(132)|0);
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($102|0));
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          break;
         }
        }
        $107 = HEAP32[$96>>2]|0;
        $108 = (($96) + 16|0);
        $109 = (($107) + 92|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = Math_imul($110, $V_1$04)|0;
        $112 = (($108) + ($111)|0);
        $113 = HEAP32[$112>>2]|0;
        $$0 = 1;$storemerge = $113;
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 46) {
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_ValuesP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1398144);
 __THREW__ = 0;
 (invoke_ii(2996,(1405128|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1405128|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1337,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z126mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404128);
 __THREW__ = 0;
 invoke_v(342);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1924,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = ($dictionary|0)==(0|0);
   if (!($4)) {
    $17 = (($__this) + 8|0);
    HEAP32[$17>>2] = $dictionary;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[3021160>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3810,($9|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS1_E6InvokeEP10MethodInfoPvii($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_GetEnumeratorP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1398288);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1341,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP22mscorlib_System_Stringi($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1397328);
 HEAP32[$L_2>>2] = $value;
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $agg$result;
   $6 = $5;
   HEAP32[$6>>2] = 0;
   $7 = (($5) + 4)|0;
   $8 = $7;
   HEAP32[$8>>2] = 0;
   __THREW__ = 0;
   invoke_viii(571,($agg$result|0),($key|0),($2|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __ZN14ActionInvoker1I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPFvPv104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPFbPv104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker2I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32Traits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPF104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvS5_iES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$3);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1402568,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_E6InvokeEPFiPvS3_iES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$3)|0);
 HEAP32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker0I119mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPF113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1406664,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvS5_iES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$3);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2307216,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z114mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_set_KeyP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402144);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z116mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_set_ValueP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32i($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402240);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ToStringP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $G_B3_0$0 = 0, $G_B6_0$0 = 0, $L_21 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_1 = sp;
 $L_21 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402288);
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 invoke_v(341);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1168432|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2743,(1168432|0),5)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $19 = HEAP32[3021312>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($4|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[3021312>>2]|0;
       $23 = (($4) + 16|0);
       HEAP32[$23>>2] = $22;
       __THREW__ = 0;
       $24 = (invoke_ii(896,($__this|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        $27 = ($24|0)==(0|0);
        if ($27) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          break;
         }
         $38 = HEAP8[((2191608 + 116|0))>>0]|0;
         $39 = ($38<<24>>24)==(0);
         if ($39) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3811,(2191608|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          break;
         }
         $48 = HEAP32[((2191608 + 80|0))>>2]|0;
         $49 = HEAP32[$48>>2]|0;
         $G_B3_0$0 = $49;
        } else {
         __THREW__ = 0;
         $30 = (invoke_ii(896,($__this|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($30|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         __THREW__ = 0;
         $35 = (invoke_iii(2730,(2149112|0),($30|0))|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break;
         }
         $G_B3_0$0 = $35;
        }
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if (!($51)) {
         $52 = HEAP32[$9>>2]|0;
         $53 = ($52>>>0)<(2);
         if ($53) {
          __THREW__ = 0;
          $54 = (invoke_i(132)|0);
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($54|0));
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if ($58) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($4|0),($G_B3_0$0|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if (!($60)) {
          $61 = HEAP32[$4>>2]|0;
          $62 = (($61) + 92|0);
          $63 = HEAP32[$62>>2]|0;
          $64 = (($23) + ($63)|0);
          HEAP32[$64>>2] = $G_B3_0$0;
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if (!($66)) {
           $67 = HEAP32[$9>>2]|0;
           $68 = ($67>>>0)<(3);
           if ($68) {
            __THREW__ = 0;
            $69 = (invoke_i(132)|0);
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if ($71) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($69|0));
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if ($73) {
             break;
            }
           }
           $74 = HEAP32[3021320>>2]|0;
           __THREW__ = 0;
           invoke_vii(3492,($4|0),($74|0));
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if (!($76)) {
            $77 = HEAP32[3021320>>2]|0;
            $78 = HEAP32[$4>>2]|0;
            $79 = (($78) + 92|0);
            $80 = HEAP32[$79>>2]|0;
            $81 = $80 << 1;
            $82 = (($23) + ($81)|0);
            HEAP32[$82>>2] = $77;
            __THREW__ = 0;
            $83 = (invoke_ii(897,($__this|0))|0);
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if (!($85)) {
             HEAP32[$L_21>>2] = $83;
             __THREW__ = 0;
             (invoke_ii(2996,(2155952|0))|0);
             $86 = __THREW__; __THREW__ = 0;
             $87 = $86&1;
             if (!($87)) {
              __THREW__ = 0;
              $88 = (invoke_iii(2724,(2155952|0),($L_21|0))|0);
              $89 = __THREW__; __THREW__ = 0;
              $90 = $89&1;
              if (!($90)) {
               $91 = ($88|0)==(0|0);
               if ($91) {
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 break;
                }
                $112 = HEAP8[((2191608 + 116|0))>>0]|0;
                $113 = ($112<<24>>24)==(0);
                if ($113) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $114 = __THREW__; __THREW__ = 0;
                 $115 = $114&1;
                 if ($115) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3811,(2191608|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 break;
                }
                $122 = HEAP32[((2191608 + 80|0))>>2]|0;
                $123 = HEAP32[$122>>2]|0;
                $G_B6_0$0 = $123;
               } else {
                __THREW__ = 0;
                $94 = (invoke_ii(897,($__this|0))|0);
                $95 = __THREW__; __THREW__ = 0;
                $96 = $95&1;
                if ($96) {
                 break;
                }
                HEAP32[$V_1>>2] = $94;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $97 = __THREW__; __THREW__ = 0;
                $98 = $97&1;
                if ($98) {
                 break;
                }
                __THREW__ = 0;
                $99 = (invoke_iii(2724,(2155952|0),($V_1|0))|0);
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if ($101) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($99|0));
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $104 = __THREW__; __THREW__ = 0;
                $105 = $104&1;
                if ($105) {
                 break;
                }
                __THREW__ = 0;
                $106 = (invoke_iii(2724,(2155952|0),($V_1|0))|0);
                $107 = __THREW__; __THREW__ = 0;
                $108 = $107&1;
                if ($108) {
                 break;
                }
                __THREW__ = 0;
                $109 = (invoke_iii(2730,(2149112|0),($106|0))|0);
                $110 = __THREW__; __THREW__ = 0;
                $111 = $110&1;
                if ($111) {
                 break;
                }
                $G_B6_0$0 = $109;
               }
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $124 = __THREW__; __THREW__ = 0;
               $125 = $124&1;
               if (!($125)) {
                $126 = HEAP32[$9>>2]|0;
                $127 = ($126>>>0)<(4);
                if ($127) {
                 __THREW__ = 0;
                 $128 = (invoke_i(132)|0);
                 $129 = __THREW__; __THREW__ = 0;
                 $130 = $129&1;
                 if ($130) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($128|0));
                 $131 = __THREW__; __THREW__ = 0;
                 $132 = $131&1;
                 if ($132) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($G_B6_0$0|0));
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 break;
                }
                $135 = HEAP32[$4>>2]|0;
                $136 = (($135) + 92|0);
                $137 = HEAP32[$136>>2]|0;
                $138 = ($137*3)|0;
                $139 = (($23) + ($138)|0);
                HEAP32[$139>>2] = $G_B6_0$0;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $140 = __THREW__; __THREW__ = 0;
                $141 = $140&1;
                if ($141) {
                 break;
                }
                $142 = HEAP32[$9>>2]|0;
                $143 = ($142>>>0)<(5);
                if ($143) {
                 __THREW__ = 0;
                 $144 = (invoke_i(132)|0);
                 $145 = __THREW__; __THREW__ = 0;
                 $146 = $145&1;
                 if ($146) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($144|0));
                 $147 = __THREW__; __THREW__ = 0;
                 $148 = $147&1;
                 if ($148) {
                  break;
                 }
                }
                $149 = HEAP32[3021328>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($149|0));
                $150 = __THREW__; __THREW__ = 0;
                $151 = $150&1;
                if ($151) {
                 break;
                }
                $152 = HEAP32[3021328>>2]|0;
                $153 = HEAP32[$4>>2]|0;
                $154 = (($153) + 92|0);
                $155 = HEAP32[$154>>2]|0;
                $156 = $155 << 2;
                $157 = (($23) + ($156)|0);
                HEAP32[$157>>2] = $152;
                __THREW__ = 0;
                $158 = (invoke_iii(639,(0|0),($4|0))|0);
                $159 = __THREW__; __THREW__ = 0;
                $160 = $159&1;
                if ($160) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($158|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402712);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z192mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IEnumerator_get_CurrentP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402760);
 __THREW__ = 0;
 invoke_vii(1336,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(1402568|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(1402568|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z161mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402904);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(840,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z157mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_DisposeP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402808);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_MoveNextP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1402856);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPF104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1402568,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z179mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32i($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404176);
 __THREW__ = 0;
 invoke_v(343);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3810,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z181mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404224);
 __THREW__ = 0;
 invoke_v(344);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021280>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3810,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z184mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32i($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404272);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(325,($1|0),($item|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z182mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32i($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404320);
 __THREW__ = 0;
 invoke_v(345);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021296>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3810,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z189mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404368);
 __THREW__ = 0;
 invoke_vii(1339,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1405728|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1405728|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z134mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_GetEnumeratorP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404608);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1340,($agg$result|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z158mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_ICollection_CopyToP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404416);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2735,($_____array|0),(1170368|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if (!($6)) {
     __THREW__ = 0;
     invoke_viiii(461,(1404464|0),($__this|0),($3|0),($index|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $11 = (($__this) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_viii(360,($12|0),($_____array|0),($index|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $17 = HEAP32[$11>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(1407240|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(1407240|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        HEAP32[$0>>2] = 1397760;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_viii(366,($20|0),(0|0),($$byval_copy|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3799,($17|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          __THREW__ = 0;
          invoke_viiii(273,($17|0),($_____array|0),($index|0),($20|0));
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z153mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32_m__ctorP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32P22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406808);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404512);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z164mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_ICollection_get_SyncRootP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404560);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2740,(2231320|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_CopyToP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32P25mscorlib_System_Int32_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404464);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viii(360,($2|0),($_____array|0),($index|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = HEAP32[$1>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1407240|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(1407240|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     HEAP32[$0>>2] = 1397760;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_viii(366,($10|0),(0|0),($$byval_copy|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_viiii(275,($7|0),($_____array|0),($index|0),($10|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
}
function __Z137mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1405272);
 __THREW__ = 0;
 invoke_vi(3799,($host|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(1332,($L_0|0),($host|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  ;HEAP32[$__this+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$__this+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$__this+16>>2]=HEAP32[$L_0+16>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CountP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1404656);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(1397520|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker0I135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPF129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1405728,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z174mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IEnumerator_get_CurrentP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1405320);
 __THREW__ = 0;
 $0 = (invoke_ii(910,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_2>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2155952|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentValueP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406112);
 __THREW__ = 0;
 invoke_vi(1533,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  __THREW__ = 0;
  $3 = (invoke_ii(897,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_DisposeP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1405368);
 __THREW__ = 0;
 invoke_vi(1534,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z123mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_DisposeP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406256);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_MoveNextP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1405416);
 __THREW__ = 0;
 $0 = (invoke_ii(909,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_MoveNextP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_22 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_22 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406016);
 __THREW__ = 0;
 invoke_vi(1532,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $99 = $3;
   while(1) {
    $93 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($93|0));
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 4;
     break;
    }
    $96 = (($93) + 24|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($99|0)<($97|0);
    if (!($98)) {
     label = 31;
     break;
    }
    $15 = HEAP32[$2>>2]|0;
    $100 = (($15) + 1)|0;
    HEAP32[$2>>2] = $100;
    $10 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($10|0));
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     label = 4;
     break;
    }
    $9 = (($10) + 12|0);
    $11 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 4;
     break;
    }
    $14 = ($15|0)<(0);
    if ($14) {
     label = 10;
    } else {
     $16 = (($11) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($15>>>0)<($17>>>0);
     if (!($18)) {
      label = 10;
     }
    }
    if ((label|0) == 10) {
     label = 0;
     __THREW__ = 0;
     $19 = (invoke_i(132)|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 4;
      break;
     }
    }
    $24 = HEAP32[$11>>2]|0;
    $25 = (($11) + 16|0);
    $26 = (($24) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $15)|0;
    $29 = (($25) + ($28)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)<(0);
    if ($31) {
     label = 14;
     break;
    }
    $$pre = HEAP32[$2>>2]|0;
    $99 = $$pre;
   }
   if ((label|0) == 4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    $lpad$phi$index = $5;$lpad$phi$index2 = $6;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 14) {
    $32 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($32) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    if ($14) {
     label = 18;
    } else {
     $39 = (($36) + 12|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($15>>>0)<($40>>>0);
     if (!($41)) {
      label = 18;
     }
    }
    if ((label|0) == 18) {
     __THREW__ = 0;
     $42 = (invoke_i(132)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($42|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
    }
    $47 = HEAP32[$36>>2]|0;
    $48 = (($36) + 16|0);
    $49 = (($47) + 92|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = Math_imul($50, $15)|0;
    $52 = (($48) + ($51)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($54|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     break;
    }
    $57 = (($54) + 20|0);
    $58 = HEAP32[$57>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($58|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    if ($14) {
     label = 24;
    } else {
     $61 = (($58) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($15>>>0)<($62>>>0);
     if (!($63)) {
      label = 24;
     }
    }
    if ((label|0) == 24) {
     __THREW__ = 0;
     $64 = (invoke_i(132)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($64|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
    }
    $69 = HEAP32[$58>>2]|0;
    $70 = (($58) + 16|0);
    $71 = (($69) + 92|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = Math_imul($72, $15)|0;
    $74 = (($70) + ($73)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $L_22;
    $77 = $76;
    HEAP32[$77>>2] = 0;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = 0;
    __THREW__ = 0;
    invoke_viii(363,($L_22|0),($53|0),($75|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     break;
    }
    $82 = (($__this) + 12|0);
    $83 = $L_22;
    $84 = $83;
    $85 = HEAP32[$84>>2]|0;
    $86 = (($83) + 4)|0;
    $87 = $86;
    $88 = HEAP32[$87>>2]|0;
    $89 = $82;
    $90 = $89;
    HEAP32[$90>>2] = $85;
    $91 = (($89) + 4)|0;
    $92 = $91;
    HEAP32[$92>>2] = $88;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 31) {
    HEAP32[$2>>2] = -1;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z143mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1405464);
 $0 = (($__this) + 12|0);
 __THREW__ = 0;
 $1 = (invoke_ii(897,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z158mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IEnumerator_get_CurrentP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1405920);
 __THREW__ = 0;
 invoke_vi(1533,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  $3 = $2;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $L_1;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  __THREW__ = 0;
  (invoke_ii(2996,(1402568|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   $15 = (invoke_iii(2724,(1402568|0),($L_1|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z129mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_VerifyCurrentP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406208);
 __THREW__ = 0;
 invoke_v(347);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1532,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = (($__this) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)>(0);
   if ($6) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2607872|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[3021144>>2]|0;
     __THREW__ = 0;
     invoke_vii(1947,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3810,($11|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z166mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IDictionaryEnumerator_get_EntryP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_6 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1405968);
 __THREW__ = 0;
 invoke_vi(1533,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  __THREW__ = 0;
  $3 = (invoke_ii(896,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(897,($2|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    HEAP32[$L_6>>2] = $6;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iii(2724,(2155952|0),($L_6|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = $agg$result;
      $15 = $14;
      HEAP32[$15>>2] = 0;
      $16 = (($14) + 4)|0;
      $17 = $16;
      HEAP32[$17>>2] = 0;
      __THREW__ = 0;
      invoke_viii(571,($agg$result|0),($3|0),($11|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
}
function __Z127mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_VerifyStateP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406160);
 __THREW__ = 0;
 invoke_v(346);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2634432|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2634432|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1970,($8|0),(0|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($2) + 48|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if ($21) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     $24 = (invoke_ii(3469,(2607872|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[3021104>>2]|0;
      __THREW__ = 0;
      invoke_vii(1947,($24|0),($27|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vi(3810,($24|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z127mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406064);
 $0 = (($__this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z154mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32_m_InvokeP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406856);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_iiii(255,($1|0),($key|0),($value|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiii($8|0,($10|0),($key|0),($value|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z159mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32_m_BeginInvokeP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32P22mscorlib_System_StringiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406904);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z157mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32_m_EndInvokeP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32P22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1406952);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_S4_iS4_P22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$3,$5,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Stringi($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1407432);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(104,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z181mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1407480);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z179mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1407528);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z237mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_InvokeP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1408008);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(105,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z242mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_BeginInvokeP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_StringiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1408056);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z240mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_EndInvokeP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1408104);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPF104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1402568,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_MoveNextP117mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1408584);
 $0 = (($__this) + 8|0);
 __THREW__ = 0;
 $1 = (invoke_ii(909,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z129mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_EntryP117mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1408632);
 $0 = (($__this) + 8|0);
 ;HEAP32[$L_1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$0+16>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1406664|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2724,(1406664|0),($L_1|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(2114,($agg$result|0),(2311136|0),($3|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z131mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentP117mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1408680);
 __THREW__ = 0;
 invoke_viii(2115,($L_0|0),(1408632|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2307216|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2307216|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m__ctorP76mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1409336);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1409384);
 __THREW__ = 0;
 (invoke_ii(2996,(1410640|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1410640|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1537,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1409928|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1409928 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32_m__ctorP92mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1410304);
 __THREW__ = 0;
 invoke_vi(1535,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z127mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m_System_Collections_IEqualityComparer_GetHashCodeP76mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32P22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1409432);
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2742,($obj|0),(2155952|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   $6 = (invoke_iiii(1653,(1409480|0),($__this|0),($5|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I27mscorlib_System_Int32TraitsS0_E6InvokeEP10MethodInfoPvi($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z122mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m_System_Collections_IEqualityComparer_EqualsP76mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32P22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1409528);
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2742,($x|0),(2155952|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2742,($y|0),(2155952|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[$8>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iiiii(304,(1398240|0),($__this|0),($5|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($12|0);
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32_m_GetHashCodeP92mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32i($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 HEAP32[$0>>2] = $obj;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1410352);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$L_0>>2] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2724,(2155952|0),($L_0|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)==(0|0);
   if ($7) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(2724,(2155952|0),($0|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3799,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_iii(2724,(2155952|0),($0|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        $22 = (invoke_iii(2729,(2148880|0),($19|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         $$0 = $22;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32_m_EqualsP92mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32ii($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_5 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $L_2 = sp + 8|0;
 $L_5 = sp + 12|0;
 HEAP32[$0>>2] = $x;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1410400);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$L_0>>2] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2155952|0),($L_0|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if ($7) {
     HEAP32[$L_2>>2] = $y;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = ($12|0)==(0|0);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    HEAP32[$L_5>>2] = $y;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     $18 = (invoke_iii(2724,(2155952|0),($L_5|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       $23 = (invoke_iii(2724,(2155952|0),($0|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        invoke_vi(3799,($23|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2155952|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          __THREW__ = 0;
          $30 = (invoke_iii(2724,(2155952|0),($0|0))|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           $33 = (invoke_iiii(1644,(2148736|0),($30|0),($18|0))|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $$0 = $33;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFbPviiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 $6 = $5&1;
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m__ctorP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m_System_Collections_IEnumerator_get_CurrentP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1411504)|0);
 $0 = HEAP32[((1411504 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m_DisposeP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m_MoveNextP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m_get_CurrentP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1411504)|0);
 $0 = HEAP32[((1411504 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1413768)|0);
 $0 = HEAP32[((1413768 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1413768)|0);
 $0 = HEAP32[((1413768 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m__ctorP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL131mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1416032)|0);
 $0 = HEAP32[((1416032 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_DisposeP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_MoveNextP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1416032)|0);
 $0 = HEAP32[((1416032 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z107mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1417816);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z144mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1417864);
 __THREW__ = 0;
 $0 = (invoke_ii(925,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(1270104|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(1270104|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1418008);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1314,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1417912);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1417960);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1420080);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp;
 $L_1 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1420128);
 __THREW__ = 0;
 invoke_vii(1351,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2844928|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2844928|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1420272);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(856,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1420176);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1420224);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I38UnityEngine_UnityEngine_KeyframeTraitsE6InvokeEPF32UnityEngine_UnityEngine_KeyframePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2844928,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z112mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m__ctorP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1422344);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z149mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m_System_Collections_IEnumerator_get_CurrentP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1422392);
 __THREW__ = 0;
 $0 = (invoke_ii(930,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(1287200|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(1287200|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z118mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m_get_CurrentP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1422536);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3810,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1321,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z114mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m_DisposeP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1422440);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z115mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m_MoveNextP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1422488);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL141mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1425088)|0);
 $0 = HEAP32[((1425088 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1425088)|0);
 $0 = HEAP32[((1425088 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m__ctorP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL131mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1427352)|0);
 $0 = HEAP32[((1427352 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m_DisposeP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m_MoveNextP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1427352)|0);
 $0 = HEAP32[((1427352 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z75Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m__ctor_gsharedP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1428896);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z78Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m_ToString_gsharedP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1428944);
 __THREW__ = 0;
 invoke_v(352);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = HEAP32[$__this>>2]|0;
  $4 = (($3) + 84|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  HEAP32[$0>>2] = $6;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $7 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = HEAP32[3002152>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iiii(552,(0|0),($10|0),($7|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($11|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __ZL67Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m__ctorP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z75Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m__ctor_gsharedP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL70Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m_ToStringP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m_ToString_gsharedP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z85Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1429344);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z122Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1429392);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z91Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1429440);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z87Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1429488);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z85Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_Reset_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1429536);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3810,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z85Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_Yield_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$state,$value) {
 $__this = $__this|0;
 $state = $state|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1429584);
 $0 = (($__this) + 12|0);
 HEAP32[$0>>2] = $state;
 $1 = (($__this) + 8|0);
 HEAP32[$1>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z92Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_YieldDefault_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Objecti($__this,$state) {
 $__this = $__this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1429632);
 $0 = (($__this) + 12|0);
 HEAP32[$0>>2] = $state;
 $1 = (($__this) + 8|0);
 HEAP32[$1>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __ZL77Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m__ctorP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL114Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z122Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL83Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_get_CurrentP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z91Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_DisposeP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z87Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object(0);
 STACKTOP = sp;return;
}
function __ZL77Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_ResetP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_Reset_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object(0);
 // unreachable;
}
function __ZL77Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_YieldP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$state,$value) {
 $__this = $__this|0;
 $state = $state|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z85Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_Yield_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$state,$value)|0);
 STACKTOP = sp;return 1;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEPFbPviP22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$3)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZL84Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_YieldDefaultP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Objecti($__this,$state) {
 $__this = $__this|0;
 $state = $state|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z92Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_YieldDefault_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Objecti($__this,$state)|0);
 STACKTOP = sp;return 1;
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m__ctorP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL145mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_System_Collections_IEnumerator_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1430960)|0);
 $0 = HEAP32[((1430960 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_DisposeP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_MoveNextP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1430960)|0);
 $0 = HEAP32[((1430960 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL150mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1433224)|0);
 $0 = HEAP32[((1433224 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1433224)|0);
 $0 = HEAP32[((1433224 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m__ctorP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1441976);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z157mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m_System_Collections_IEnumerator_get_CurrentP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1442024);
 __THREW__ = 0;
 $0 = (invoke_ii(948,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2317000|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2317000|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m_get_CurrentP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1442168);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1850,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m_DisposeP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1442072);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z123mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m_MoveNextP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1442120);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1676($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL135mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1444848)|0);
 $0 = HEAP32[((1444848 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1444848)|0);
 $0 = HEAP32[((1444848 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1446632);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z150mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1446680);
 __THREW__ = 0;
 $0 = (invoke_ii(954,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2317584|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2317584|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1446824);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1858,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1446728);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1446776);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1449376)|0);
 $0 = HEAP32[((1449376 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1449376)|0);
 $0 = HEAP32[((1449376 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1451640)|0);
 $0 = HEAP32[((1451640 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1451640)|0);
 $0 = HEAP32[((1451640 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL142mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1453904)|0);
 $0 = HEAP32[((1453904 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1453904)|0);
 $0 = HEAP32[((1453904 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1456168)|0);
 $0 = HEAP32[((1456168 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1456168)|0);
 $0 = HEAP32[((1456168 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1457952);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1458000);
 __THREW__ = 0;
 $0 = (invoke_ii(969,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2329520|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2329520|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1458144);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1878,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1458048);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1458096);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CalendarP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1460696)|0);
 $0 = HEAP32[((1460696 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1460696)|0);
 $0 = HEAP32[((1460696 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1462480);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1462528);
 __THREW__ = 0;
 $0 = (invoke_ii(975,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2334344|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2334344|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1462672);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1886,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1462576);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1462624);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1464744);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1464792);
 __THREW__ = 0;
 $0 = (invoke_ii(978,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2341504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2341504|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1464936);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1890,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1464840);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1464888);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1467008);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1467056);
 __THREW__ = 0;
 $0 = (invoke_ii(981,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2343728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2343728|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1467200);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1894,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1467104);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1467152);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1469272);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1469320);
 __THREW__ = 0;
 $0 = (invoke_ii(984,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2349736|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2349736|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1469464);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1898,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1469368);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1469416);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1471536);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1471584);
 __THREW__ = 0;
 $0 = (invoke_ii(987,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2352928|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2352928|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1471728);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3812,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1902,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1471632);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1471680);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m__ctorP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL136mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m_System_Collections_IEnumerator_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1474280)|0);
 $0 = HEAP32[((1474280 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m_DisposeP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m_MoveNextP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1474280)|0);
 $0 = HEAP32[((1474280 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1476544)|0);
 $0 = HEAP32[((1476544 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1476544)|0);
 $0 = HEAP32[((1476544 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1478808)|0);
 $0 = HEAP32[((1478808 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1478808)|0);
 $0 = HEAP32[((1478808 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m__ctorP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL138mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m_System_Collections_IEnumerator_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1481072)|0);
 $0 = HEAP32[((1481072 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m_DisposeP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m_MoveNextP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1481072)|0);
 $0 = HEAP32[((1481072 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL135mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1483336)|0);
 $0 = HEAP32[((1483336 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1483336)|0);
 $0 = HEAP32[((1483336 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1485600)|0);
 $0 = HEAP32[((1485600 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1485600)|0);
 $0 = HEAP32[((1485600 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1493832)|0);
 $0 = HEAP32[((1493832 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1493832)|0);
 $0 = HEAP32[((1493832 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1496096)|0);
 $0 = HEAP32[((1496096 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1496096)|0);
 $0 = HEAP32[((1496096 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m__ctorP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL145mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m_System_Collections_IEnumerator_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1498360)|0);
 $0 = HEAP32[((1498360 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m_DisposeP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m_MoveNextP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1498360)|0);
 $0 = HEAP32[((1498360 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1500624)|0);
 $0 = HEAP32[((1500624 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1500624)|0);
 $0 = HEAP32[((1500624 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1502888)|0);
 $0 = HEAP32[((1502888 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1502888)|0);
 $0 = HEAP32[((1502888 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1505152)|0);
 $0 = HEAP32[((1505152 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1505152)|0);
 $0 = HEAP32[((1505152 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m__ctorP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL143mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m_System_Collections_IEnumerator_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1507416)|0);
 $0 = HEAP32[((1507416 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m_DisposeP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m_MoveNextP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1507416)|0);
 $0 = HEAP32[((1507416 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m__ctorP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL143mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m_System_Collections_IEnumerator_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1509680)|0);
 $0 = HEAP32[((1509680 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m_DisposeP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m_MoveNextP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1509680)|0);
 $0 = HEAP32[((1509680 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m__ctorP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL152mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m_System_Collections_IEnumerator_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1511944)|0);
 $0 = HEAP32[((1511944 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m_DisposeP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m_MoveNextP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1511944)|0);
 $0 = HEAP32[((1511944 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1514208)|0);
 $0 = HEAP32[((1514208 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1514208)|0);
 $0 = HEAP32[((1514208 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1516472)|0);
 $0 = HEAP32[((1516472 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1516472)|0);
 $0 = HEAP32[((1516472 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1518256);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1518304);
 __THREW__ = 0;
 $0 = (invoke_ii(1041,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2395880|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2395880|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1518448);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1974,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1518352);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1518400);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1833($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1521000)|0);
 $0 = HEAP32[((1521000 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1521000)|0);
 $0 = HEAP32[((1521000 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1523264)|0);
 $0 = HEAP32[((1523264 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1523264)|0);
 $0 = HEAP32[((1523264 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1525528)|0);
 $0 = HEAP32[((1525528 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1525528)|0);
 $0 = HEAP32[((1525528 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1527312);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1527360);
 __THREW__ = 0;
 $0 = (invoke_ii(1053,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2401632|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2401632|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1527504);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1990,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1527408);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1527456);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1529576);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1529624);
 __THREW__ = 0;
 $0 = (invoke_ii(1056,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2402200|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2402200|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1529768);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1994,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1529672);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1529720);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1531840);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1531888);
 __THREW__ = 0;
 $0 = (invoke_ii(1059,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2403584|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2403584|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1532032);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1998,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1531936);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1531984);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1534104);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1534152);
 __THREW__ = 0;
 $0 = (invoke_ii(1062,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2405320|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2405320|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1534296);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2002,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1534200);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1534248);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1536368);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1536416);
 __THREW__ = 0;
 $0 = (invoke_ii(1065,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2408328|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2408328|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1536560);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3813,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2006,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1536464);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1536512);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m__ctorP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1544456);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1544504);
 __THREW__ = 0;
 $0 = (invoke_ii(1068,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2409648|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2409648|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1544648);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2010,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m_DisposeP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1544552);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m_MoveNextP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1544600);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1990($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1546848);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1546896);
 __THREW__ = 0;
 $0 = (invoke_ii(1071,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2413280|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2413280|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1547040);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2014,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1546944);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1546992);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1549112);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1549160);
 __THREW__ = 0;
 $0 = (invoke_ii(1074,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2428456|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2428456|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1549304);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2018,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1549208);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1549256);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m__ctorP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1551376);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m_System_Collections_IEnumerator_get_CurrentP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1551424);
 __THREW__ = 0;
 $0 = (invoke_ii(1077,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2431504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2431504|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m_get_CurrentP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1551568);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2022,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m_DisposeP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1551472);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m_MoveNextP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1551520);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1553640);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1553688);
 __THREW__ = 0;
 $0 = (invoke_ii(1080,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2433944|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2433944|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1553832);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2026,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1553736);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1553784);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m__ctorP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1555904);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z129mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m_System_Collections_IEnumerator_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1555952);
 __THREW__ = 0;
 $0 = (invoke_ii(1083,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2438136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2438136|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1556096);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2030,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m_DisposeP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1556000);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m_MoveNextP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1556048);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1558648)|0);
 $0 = HEAP32[((1558648 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1558648)|0);
 $0 = HEAP32[((1558648 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1560912)|0);
 $0 = HEAP32[((1560912 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1560912)|0);
 $0 = HEAP32[((1560912 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1562696);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z151mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1562744);
 __THREW__ = 0;
 $0 = (invoke_ii(1092,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2439288|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2439288|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1562888);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2042,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1562792);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1562840);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL123mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m__ctorP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL160mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m_System_Collections_IEnumerator_get_CurrentP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1565440)|0);
 $0 = HEAP32[((1565440 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m_DisposeP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m_MoveNextP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL129mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m_get_CurrentP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1565440)|0);
 $0 = HEAP32[((1565440 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m__ctorP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m_System_Collections_IEnumerator_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1567704)|0);
 $0 = HEAP32[((1567704 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m_DisposeP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m_MoveNextP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1567704)|0);
 $0 = HEAP32[((1567704 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1569488);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1569536);
 __THREW__ = 0;
 $0 = (invoke_ii(1101,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2440608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2440608|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1569680);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2054,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1569584);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1569632);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m__ctorP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL152mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m_System_Collections_IEnumerator_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1572232)|0);
 $0 = HEAP32[((1572232 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m_DisposeP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m_MoveNextP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1572232)|0);
 $0 = HEAP32[((1572232 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m__ctorP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1574016);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m_System_Collections_IEnumerator_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1574064);
 __THREW__ = 0;
 $0 = (invoke_ii(1107,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2441352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2441352|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1574208);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2062,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m_DisposeP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1574112);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m_MoveNextP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1574160);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1576280);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1576328);
 __THREW__ = 0;
 $0 = (invoke_ii(1110,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2441904|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2441904|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1576472);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2066,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1576376);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1576424);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL161mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m_System_Collections_IEnumerator_get_CurrentP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1579024)|0);
 $0 = HEAP32[((1579024 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m_DisposeP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m_MoveNextP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m_get_CurrentP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1579024)|0);
 $0 = HEAP32[((1579024 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL151mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1581288)|0);
 $0 = HEAP32[((1581288 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1581288)|0);
 $0 = HEAP32[((1581288 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1583072);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1583120);
 __THREW__ = 0;
 $0 = (invoke_ii(1119,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2443656|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2443656|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1583264);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2078,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1583168);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1583216);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m_System_Collections_IEnumerator_get_CurrentP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1585816)|0);
 $0 = HEAP32[((1585816 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m_DisposeP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m_MoveNextP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m_get_CurrentP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1585816)|0);
 $0 = HEAP32[((1585816 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1587600);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1587648);
 __THREW__ = 0;
 $0 = (invoke_ii(1125,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2444504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2444504|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1587792);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3814,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2086,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1587696);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1587744);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL150mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1596296)|0);
 $0 = HEAP32[((1596296 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1596296)|0);
 $0 = HEAP32[((1596296 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m__ctorP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m_System_Collections_IEnumerator_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1598560)|0);
 $0 = HEAP32[((1598560 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m_DisposeP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m_MoveNextP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1598560)|0);
 $0 = HEAP32[((1598560 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m_System_Collections_IEnumerator_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1600824)|0);
 $0 = HEAP32[((1600824 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m_DisposeP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m_MoveNextP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1600824)|0);
 $0 = HEAP32[((1600824 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL151mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1603088)|0);
 $0 = HEAP32[((1603088 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1603088)|0);
 $0 = HEAP32[((1603088 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1604872);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1604920);
 __THREW__ = 0;
 $0 = (invoke_ii(1140,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2449232|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2449232|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1605064);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2106,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1604968);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1605016);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2147($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1607616)|0);
 $0 = HEAP32[((1607616 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1607616)|0);
 $0 = HEAP32[((1607616 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1609880)|0);
 $0 = HEAP32[((1609880 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1609880)|0);
 $0 = HEAP32[((1609880 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1611664);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z142mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1611712);
 __THREW__ = 0;
 $0 = (invoke_ii(1149,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP8[$L_1>>0] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2473464|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2473464|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1611856);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2118,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1611760);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1611808);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I26mscorlib_System_ByteTraitsE6InvokeEPFhPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP8[$ret>>0] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m__ctorP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL143mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_System_Collections_IEnumerator_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1614408)|0);
 $0 = HEAP32[((1614408 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_DisposeP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_MoveNextP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1614408)|0);
 $0 = HEAP32[((1614408 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1616672)|0);
 $0 = HEAP32[((1616672 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1616672)|0);
 $0 = HEAP32[((1616672 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1618456);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1618504);
 __THREW__ = 0;
 $0 = (invoke_ii(1158,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2493760|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2493760|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1618648);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2130,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1618552);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1618600);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m__ctorP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1620720);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z159mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m_System_Collections_IEnumerator_get_CurrentP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1620768);
 __THREW__ = 0;
 $0 = (invoke_ii(1161,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2494928|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2494928|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z128mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m_get_CurrentP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1620912);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2134,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m_DisposeP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1620816);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m_MoveNextP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1620864);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m__ctorP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1622984);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m_System_Collections_IEnumerator_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1623032);
 __THREW__ = 0;
 $0 = (invoke_ii(1164,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2495424|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2495424|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1623176);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2138,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m_DisposeP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1623080);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m_MoveNextP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1623128);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m__ctorP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1625248);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z152mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m_System_Collections_IEnumerator_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1625296);
 __THREW__ = 0;
 $0 = (invoke_ii(1167,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2495840|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2495840|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1625440);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2142,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m_DisposeP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1625344);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m_MoveNextP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1625392);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m__ctorP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1627512);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m_System_Collections_IEnumerator_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1627560);
 __THREW__ = 0;
 $0 = (invoke_ii(1170,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2500216|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2500216|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1627704);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2146,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m_DisposeP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1627608);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m_MoveNextP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1627656);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m__ctorP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1629776);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z138mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m_System_Collections_IEnumerator_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1629824);
 __THREW__ = 0;
 $0 = (invoke_ii(1173,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2508592|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2508592|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1629968);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2150,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m_DisposeP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1629872);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m_MoveNextP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1629920);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL142mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1632520)|0);
 $0 = HEAP32[((1632520 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1632520)|0);
 $0 = HEAP32[((1632520 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL151mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1634784)|0);
 $0 = HEAP32[((1634784 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1634784)|0);
 $0 = HEAP32[((1634784 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m__ctorP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL138mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m_System_Collections_IEnumerator_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1637048)|0);
 $0 = HEAP32[((1637048 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m_DisposeP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m_MoveNextP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1637048)|0);
 $0 = HEAP32[((1637048 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1638832);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1638880);
 __THREW__ = 0;
 $0 = (invoke_ii(1185,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2552656|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2552656|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1639024);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3815,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2166,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1638928);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1638976);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargetsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1646920);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1646968);
 __THREW__ = 0;
 $0 = (invoke_ii(1188,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2563424|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2563424|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1647112);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2170,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1647016);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1647064);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2282($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTime_m__ctorP78mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1649600);
 __THREW__ = 0;
 invoke_vi(1634,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z79mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime_m__ctorP71mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1650032);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z88mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTime_m_CompareP78mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTime24mscorlib_System_DateTimeS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_6 = 0, $_stackTraceSentry = 0, $data$i = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp + 64|0;
 $data$i = sp + 88|0;
 $0 = sp + 16|0;
 $_stackTraceSentry = sp + 80|0;
 $L_0 = sp + 48|0;
 $L_2 = sp + 32|0;
 $L_6 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1649648);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2724,(2592096|0),($L_0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if ($6) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2724,(2592096|0),($L_2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $not$ = ($11|0)!=(0|0);
     $$ = $not$ << 31 >> 31;
     $$0 = $$;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    ;HEAP32[$L_6+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$y+12>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2592096|0),($L_6|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = ($16|0)==(0|0);
      if ($19) {
       $$0 = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       $22 = (invoke_iii(2724,(2592096|0),($x|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        invoke_vi(3799,($22|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          __THREW__ = 0;
          $29 = (invoke_iii(2724,(2592096|0),($x|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;
           __THREW__ = 0;
           invoke_viii(2116,($data$i|0),(1649104|0),($29|0));
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $34 = (($data$i) + 4|0);
            $35 = HEAP32[$34>>2]|0;
            $36 = (($35) + 4|0);
            $37 = HEAP32[$36>>2]|0;
            $38 = HEAP32[$data$i>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
            $39 = (invoke_iii($37|0,($38|0),($$byval_copy|0))|0);
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if (!($41)) {
             $$0 = $39;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits30mscorlib_System_DateTimeTraitsS1_E6InvokeEPFiPv24mscorlib_System_DateTimeS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 32|0;
 $$byval_copy = sp;
 $ret = sp + 48|0;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z80mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1650080);
 __THREW__ = 0;
 (invoke_ii(2996,(1651288|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1651288|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1636,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1650608|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1650608 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTime_m__ctorP87mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1651008);
 __THREW__ = 0;
 invoke_vi(1634,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z110mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime_m_System_Collections_IComparer_CompareP71mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_6 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp + 80|0;
 $$byval_copy = sp;
 $data$i = sp + 104|0;
 $0 = sp + 32|0;
 $1 = sp + 48|0;
 $_stackTraceSentry = sp + 96|0;
 $L_6 = sp + 64|0;
 $2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1650128);
 $3 = ($x|0)==(0|0);
 $4 = ($y|0)!=(0|0);
 if ($3) {
  $$ = $4 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($4)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iii(2735,($x|0),(2592096|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($7|0)==(0|0);
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_iii(2735,($y|0),(2592096|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     $18 = ($15|0)==(0|0);
     if (!($18)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      __THREW__ = 0;
      $21 = (invoke_iii(2745,($x|0),(2592096|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      ;HEAP32[$L_6+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$21+12>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2745,($y|0),(2592096|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      ;HEAP32[$2+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$26+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$L_6+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$L_6+12>>2]|0;
      ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;
      __THREW__ = 0;
      invoke_viii(2112,($data$i|0),(1650176|0),($__this|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = (($data$i) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($32) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;
      $36 = (invoke_iiii($34|0,($35|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      } else {
       $$0 = $36;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     __THREW__ = 0;
     $41 = (invoke_ii(3469,(2560072|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      invoke_vi(2583,($41|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       __THREW__ = 0;
       invoke_vi(3816,($41|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo2283($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z85mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1650224);
 __THREW__ = 0;
 (invoke_ii(2996,(1650608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1650608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1650608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1650608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3817,(1650608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1650608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1650608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZL11RuntimeInitP8TypeInfo2284($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFiPvP22mscorlib_System_ObjectS5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z97mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTime_m_CompareP87mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTime24mscorlib_System_DateTimeS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $L_0 = 0;
 var $L_12 = 0, $L_16 = 0, $L_19 = 0, $L_2 = 0, $L_22 = 0, $L_6 = 0, $L_9 = 0, $_stackTraceSentry = 0, $data$i = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy = sp + 144|0;
 $data$i = sp + 160|0;
 $0 = sp + 128|0;
 $_stackTraceSentry = sp + 168|0;
 $L_0 = sp + 112|0;
 $L_2 = sp + 96|0;
 $L_6 = sp + 80|0;
 $L_9 = sp + 48|0;
 $L_12 = sp + 32|0;
 $L_16 = sp + 16|0;
 $L_19 = sp;
 $L_22 = sp + 64|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1651056);
 __THREW__ = 0;
 invoke_v(353);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2724,(2592096|0),($L_0|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = ($5|0)==(0|0);
     if ($8) {
      ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      $13 = (invoke_iii(2724,(2592096|0),($L_2|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      $not$ = ($13|0)!=(0|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     ;HEAP32[$L_6+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$y+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (invoke_iii(2724,(2592096|0),($L_6|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = ($18|0)==(0|0);
       if ($21) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       ;HEAP32[$L_9+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_9+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_9+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_9+12>>2]=HEAP32[$x+12>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        $24 = (invoke_iii(2724,(2592096|0),($L_9|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         __THREW__ = 0;
         (invoke_ii(2996,(1649200|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          __THREW__ = 0;
          $29 = (invoke_iii(2735,($24|0),(1649200|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           $32 = ($29|0)==(0|0);
           if (!($32)) {
            ;HEAP32[$L_12+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_12+12>>2]=HEAP32[$x+12>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $33 = __THREW__; __THREW__ = 0;
            $34 = $33&1;
            if ($34) {
             break;
            }
            __THREW__ = 0;
            $35 = (invoke_iii(2724,(2592096|0),($L_12|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if ($37) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(1649200|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            __THREW__ = 0;
            $40 = (invoke_iii(2746,($35|0),(1649200|0))|0);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($40|0));
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;
            __THREW__ = 0;
            invoke_viii(2116,($data$i|0),(1649104|0),($40|0));
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             break;
            }
            $47 = (($data$i) + 4|0);
            $48 = HEAP32[$47>>2]|0;
            $49 = (($48) + 4|0);
            $50 = HEAP32[$49>>2]|0;
            $51 = HEAP32[$data$i>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
            $52 = (invoke_iii($50|0,($51|0),($$byval_copy|0))|0);
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             break;
            } else {
             $$0 = $52;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           ;HEAP32[$L_16+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_16+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_16+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_16+12>>2]=HEAP32[$x+12>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if (!($56)) {
            __THREW__ = 0;
            $57 = (invoke_iii(2724,(2592096|0),($L_16|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2157896|0))|0);
             $60 = __THREW__; __THREW__ = 0;
             $61 = $60&1;
             if (!($61)) {
              __THREW__ = 0;
              $62 = (invoke_iii(2735,($57|0),(2157896|0))|0);
              $63 = __THREW__; __THREW__ = 0;
              $64 = $63&1;
              if (!($64)) {
               $65 = ($62|0)==(0|0);
               if ($65) {
                __THREW__ = 0;
                (invoke_ii(2996,(2560072|0))|0);
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 break;
                }
                __THREW__ = 0;
                $88 = (invoke_ii(3469,(2560072|0))|0);
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if ($90) {
                 break;
                }
                $91 = HEAP32[3020480>>2]|0;
                __THREW__ = 0;
                invoke_vii(1924,($88|0),($91|0));
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3816,($88|0));
                $94 = __THREW__; __THREW__ = 0;
                $95 = $94&1;
                if ($95) {
                 break;
                }
                // unreachable;
               }
               ;HEAP32[$L_19+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_19+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_19+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_19+12>>2]=HEAP32[$x+12>>2]|0;
               __THREW__ = 0;
               (invoke_ii(2996,(2592096|0))|0);
               $66 = __THREW__; __THREW__ = 0;
               $67 = $66&1;
               if (!($67)) {
                __THREW__ = 0;
                $68 = (invoke_iii(2724,(2592096|0),($L_19|0))|0);
                $69 = __THREW__; __THREW__ = 0;
                $70 = $69&1;
                if (!($70)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2157896|0))|0);
                 $71 = __THREW__; __THREW__ = 0;
                 $72 = $71&1;
                 if ($72) {
                  break;
                 }
                 __THREW__ = 0;
                 $73 = (invoke_iii(2746,($68|0),(2157896|0))|0);
                 $74 = __THREW__; __THREW__ = 0;
                 $75 = $74&1;
                 if ($75) {
                  break;
                 }
                 ;HEAP32[$L_22+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_22+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_22+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_22+12>>2]=HEAP32[$y+12>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 }
                 __THREW__ = 0;
                 $78 = (invoke_iii(2724,(2592096|0),($L_22|0))|0);
                 $79 = __THREW__; __THREW__ = 0;
                 $80 = $79&1;
                 if ($80) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($73|0));
                 $81 = __THREW__; __THREW__ = 0;
                 $82 = $81&1;
                 if ($82) {
                  break;
                 }
                 __THREW__ = 0;
                 $83 = (invoke_iiii(1649,(2157808|0),($73|0),($78|0))|0);
                 $84 = __THREW__; __THREW__ = 0;
                 $85 = $84&1;
                 if ($85) {
                  break;
                 } else {
                  $$0 = $83;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo2285($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z94mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime_m__ctorP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1651432);
 __THREW__ = 0;
 invoke_vi(1638,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z87mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m__ctorP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1651968);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z100mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime_m_GetHashCodeP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime24mscorlib_System_DateTime($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1651480);
 ;HEAP32[$L_0+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$obj+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2592096|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2592096|0),($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(2592096|0),($obj|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2148880|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $$0 = $20;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime_m_EqualsP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime24mscorlib_System_DateTimeS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_2 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy = sp + 48|0;
 $data$i = sp + 72|0;
 $0 = sp + 16|0;
 $_stackTraceSentry = sp + 64|0;
 $L_0 = sp + 32|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1651528);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2724,(2592096|0),($L_0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if ($6) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2724,(2592096|0),($L_2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = ($11|0)==(0|0);
     $$0 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_iii(2724,(2592096|0),($x|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3799,($17|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        $24 = (invoke_iii(2724,(2592096|0),($x|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;
         __THREW__ = 0;
         invoke_viii(2116,($data$i|0),(1649368|0),($24|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($data$i) + 4|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = (($30) + 4|0);
          $32 = HEAP32[$31>>2]|0;
          $33 = HEAP32[$data$i>>2]|0;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
          $34 = (invoke_iii($32|0,($33|0),($$byval_copy|0))|0);
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if (!($36)) {
           $$0 = $34;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits30mscorlib_System_DateTimeTraitsE6InvokeEPFiPv24mscorlib_System_DateTimeES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_DateTimeTraitsS1_E6InvokeEPFbPv24mscorlib_System_DateTimeS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 32|0;
 $$byval_copy = sp;
 $ret = sp + 48|0;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z88mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1652016);
 __THREW__ = 0;
 (invoke_ii(2996,(1653552|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1653552|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1640,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1652736|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1652736 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime_m__ctorP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1653216);
 __THREW__ = 0;
 invoke_vi(1638,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z130mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m_System_Collections_IEqualityComparer_GetHashCodeP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $data$i = sp + 40|0;
 $0 = sp;
 $_stackTraceSentry = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1652064);
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2745,($obj|0),(2592096|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   _memmove(($0|0),($3|0),16)|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(1652112|0),($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
    $13 = (invoke_iii($11|0,($12|0),($$byval_copy|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($13|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m_System_Collections_IEqualityComparer_EqualsP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp + 80|0;
 $$byval_copy = sp;
 $data$i = sp + 104|0;
 $0 = sp + 32|0;
 $1 = sp + 48|0;
 $_stackTraceSentry = sp + 96|0;
 $L_1 = sp + 64|0;
 $2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1652160);
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2745,($x|0),(2592096|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   ;HEAP32[$L_1+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$5+12>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2745,($y|0),(2592096|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     ;HEAP32[$2+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$10+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$L_1+12>>2]|0;
     ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;
     __THREW__ = 0;
     invoke_viii(2112,($data$i|0),(1652208|0),($__this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = (($data$i) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($16) + 4|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;
      $20 = (invoke_iiii($18|0,($19|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($20|0);
      }
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1652256);
 __THREW__ = 0;
 (invoke_ii(2996,(1652736|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1652736 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1652736|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1652736|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3817,(1652736|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1652736|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1652736 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime_m_GetHashCodeP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime24mscorlib_System_DateTime($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1653264);
 ;HEAP32[$L_0+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$obj+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2592096|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2592096|0),($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(2592096|0),($obj|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2148880|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $$0 = $20;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime_m_EqualsP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime24mscorlib_System_DateTimeS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 48|0;
 $L_0 = sp;
 $L_2 = sp + 16|0;
 $L_5 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1653312);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2724,(2592096|0),($L_0|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2724,(2592096|0),($L_2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = ($10|0)==(0|0);
     $$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    ;HEAP32[$L_5+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_5+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_5+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_5+12>>2]=HEAP32[$y+12>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2592096|0),($L_5|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_iii(2724,(2592096|0),($x|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_iii(2724,(2592096|0),($x|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           __THREW__ = 0;
           $31 = (invoke_iiii(1644,(2148736|0),($28|0),($16|0))|0);
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $$0 = $31;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_WhichP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1653936);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1653984);
 __THREW__ = 0;
 $0 = (invoke_ii(1193,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2584336|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2584336|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1654128);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2174,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1654032);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1654080);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m__ctorP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKindP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1656200);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m_System_Collections_IEnumerator_get_CurrentP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1656248);
 __THREW__ = 0;
 $0 = (invoke_ii(1196,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2592568|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2592568|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m_get_CurrentP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1656392);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2178,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m_DisposeP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1656296);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m_MoveNextP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1656344);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z92mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTimeOffset_m__ctorP84mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1658688);
 __THREW__ = 0;
 invoke_vi(1644,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z85mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset_m__ctorP77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1659088);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z94mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTimeOffset_m_CompareP84mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffsetS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_6 = 0, $_stackTraceSentry = 0, $data$i = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 96|0;
 $data$i = sp + 128|0;
 $0 = sp + 24|0;
 $_stackTraceSentry = sp + 120|0;
 $L_0 = sp + 72|0;
 $L_2 = sp + 48|0;
 $L_6 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1658736);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;HEAP32[$L_0+16>>2]=HEAP32[$x+16>>2]|0;HEAP32[$L_0+20>>2]=HEAP32[$x+20>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2724,(2594096|0),($L_0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if ($6) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$L_2+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$L_2+20>>2]=HEAP32[$y+20>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2594096|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2724,(2594096|0),($L_2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $not$ = ($11|0)!=(0|0);
     $$ = $not$ << 31 >> 31;
     $$0 = $$;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    ;HEAP32[$L_6+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$L_6+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$L_6+20>>2]=HEAP32[$y+20>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2594096|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2594096|0),($L_6|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = ($16|0)==(0|0);
      if ($19) {
       $$0 = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2594096|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       $22 = (invoke_iii(2724,(2594096|0),($x|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        invoke_vi(3799,($22|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2594096|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          __THREW__ = 0;
          $29 = (invoke_iii(2724,(2594096|0),($x|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$y+20>>2]|0;
           __THREW__ = 0;
           invoke_viii(2116,($data$i|0),(1658240|0),($29|0));
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $34 = (($data$i) + 4|0);
            $35 = HEAP32[$34>>2]|0;
            $36 = (($35) + 4|0);
            $37 = HEAP32[$36>>2]|0;
            $38 = HEAP32[$data$i>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
            $39 = (invoke_iii($37|0,($38|0),($$byval_copy|0))|0);
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if (!($41)) {
             $$0 = $39;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits36mscorlib_System_DateTimeOffsetTraitsS1_E6InvokeEPFiPv30mscorlib_System_DateTimeOffsetS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 72|0;
 $0 = sp + 24|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$3+20>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z86mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1659136);
 __THREW__ = 0;
 (invoke_ii(2996,(1660216|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1660216|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1646,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1659568|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1659568 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z101mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m__ctorP93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1659952);
 __THREW__ = 0;
 invoke_vi(1644,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z116mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset_m_System_Collections_IComparer_CompareP77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffsetP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_6 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy1 = sp + 120|0;
 $$byval_copy = sp;
 $data$i = sp + 152|0;
 $0 = sp + 48|0;
 $1 = sp + 72|0;
 $_stackTraceSentry = sp + 144|0;
 $L_6 = sp + 96|0;
 $2 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1659184);
 $3 = ($x|0)==(0|0);
 $4 = ($y|0)!=(0|0);
 if ($3) {
  $$ = $4 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($4)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iii(2735,($x|0),(2594096|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($7|0)==(0|0);
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2594096|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_iii(2735,($y|0),(2594096|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     $18 = ($15|0)==(0|0);
     if (!($18)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2594096|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      __THREW__ = 0;
      $21 = (invoke_iii(2745,($x|0),(2594096|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      ;HEAP32[$L_6+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$21+12>>2]|0;HEAP32[$L_6+16>>2]=HEAP32[$21+16>>2]|0;HEAP32[$L_6+20>>2]=HEAP32[$21+20>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2594096|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2745,($y|0),(2594096|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      ;HEAP32[$2+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$26+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$26+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$26+20>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$L_6+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$L_6+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$L_6+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$L_6+20>>2]|0;
      ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$2+20>>2]|0;
      __THREW__ = 0;
      invoke_viii(2112,($data$i|0),(1659232|0),($__this|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = (($data$i) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($32) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$1+20>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy1+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy1+20>>2]=HEAP32[$0+20>>2]|0;
      $36 = (invoke_iiii($34|0,($35|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      } else {
       $$0 = $36;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     __THREW__ = 0;
     $41 = (invoke_ii(3469,(2560072|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      invoke_vi(2583,($41|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       __THREW__ = 0;
       invoke_vi(3816,($41|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1659280);
 __THREW__ = 0;
 (invoke_ii(2996,(1659568|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1659568 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1659568|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1659568|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3817,(1659568|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1659568|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1659568 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m_CompareP93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffsetS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $L_0 = 0;
 var $L_12 = 0, $L_16 = 0, $L_19 = 0, $L_2 = 0, $L_22 = 0, $L_6 = 0, $L_9 = 0, $_stackTraceSentry = 0, $data$i = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $$byval_copy = sp + 216|0;
 $data$i = sp + 240|0;
 $0 = sp + 192|0;
 $_stackTraceSentry = sp + 248|0;
 $L_0 = sp + 168|0;
 $L_2 = sp + 144|0;
 $L_6 = sp + 120|0;
 $L_9 = sp + 72|0;
 $L_12 = sp + 48|0;
 $L_16 = sp + 24|0;
 $L_19 = sp;
 $L_22 = sp + 96|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1660000);
 __THREW__ = 0;
 invoke_v(353);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;HEAP32[$L_0+16>>2]=HEAP32[$x+16>>2]|0;HEAP32[$L_0+20>>2]=HEAP32[$x+20>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2594096|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2724,(2594096|0),($L_0|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = ($5|0)==(0|0);
     if ($8) {
      ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$L_2+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$L_2+20>>2]=HEAP32[$y+20>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2594096|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      $13 = (invoke_iii(2724,(2594096|0),($L_2|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      $not$ = ($13|0)!=(0|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     ;HEAP32[$L_6+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$L_6+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$L_6+20>>2]=HEAP32[$y+20>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2594096|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (invoke_iii(2724,(2594096|0),($L_6|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = ($18|0)==(0|0);
       if ($21) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       ;HEAP32[$L_9+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_9+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_9+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_9+12>>2]=HEAP32[$x+12>>2]|0;HEAP32[$L_9+16>>2]=HEAP32[$x+16>>2]|0;HEAP32[$L_9+20>>2]=HEAP32[$x+20>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2594096|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        $24 = (invoke_iii(2724,(2594096|0),($L_9|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         __THREW__ = 0;
         (invoke_ii(2996,(1658312|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          __THREW__ = 0;
          $29 = (invoke_iii(2735,($24|0),(1658312|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           $32 = ($29|0)==(0|0);
           if (!($32)) {
            ;HEAP32[$L_12+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_12+12>>2]=HEAP32[$x+12>>2]|0;HEAP32[$L_12+16>>2]=HEAP32[$x+16>>2]|0;HEAP32[$L_12+20>>2]=HEAP32[$x+20>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2594096|0))|0);
            $33 = __THREW__; __THREW__ = 0;
            $34 = $33&1;
            if ($34) {
             break;
            }
            __THREW__ = 0;
            $35 = (invoke_iii(2724,(2594096|0),($L_12|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if ($37) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(1658312|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            __THREW__ = 0;
            $40 = (invoke_iii(2746,($35|0),(1658312|0))|0);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($40|0));
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$y+20>>2]|0;
            __THREW__ = 0;
            invoke_viii(2116,($data$i|0),(1658240|0),($40|0));
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             break;
            }
            $47 = (($data$i) + 4|0);
            $48 = HEAP32[$47>>2]|0;
            $49 = (($48) + 4|0);
            $50 = HEAP32[$49>>2]|0;
            $51 = HEAP32[$data$i>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
            $52 = (invoke_iii($50|0,($51|0),($$byval_copy|0))|0);
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             break;
            } else {
             $$0 = $52;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           ;HEAP32[$L_16+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_16+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_16+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_16+12>>2]=HEAP32[$x+12>>2]|0;HEAP32[$L_16+16>>2]=HEAP32[$x+16>>2]|0;HEAP32[$L_16+20>>2]=HEAP32[$x+20>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2594096|0))|0);
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if (!($56)) {
            __THREW__ = 0;
            $57 = (invoke_iii(2724,(2594096|0),($L_16|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2157896|0))|0);
             $60 = __THREW__; __THREW__ = 0;
             $61 = $60&1;
             if (!($61)) {
              __THREW__ = 0;
              $62 = (invoke_iii(2735,($57|0),(2157896|0))|0);
              $63 = __THREW__; __THREW__ = 0;
              $64 = $63&1;
              if (!($64)) {
               $65 = ($62|0)==(0|0);
               if ($65) {
                __THREW__ = 0;
                (invoke_ii(2996,(2560072|0))|0);
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 break;
                }
                __THREW__ = 0;
                $88 = (invoke_ii(3469,(2560072|0))|0);
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if ($90) {
                 break;
                }
                $91 = HEAP32[3020480>>2]|0;
                __THREW__ = 0;
                invoke_vii(1924,($88|0),($91|0));
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3816,($88|0));
                $94 = __THREW__; __THREW__ = 0;
                $95 = $94&1;
                if ($95) {
                 break;
                }
                // unreachable;
               }
               ;HEAP32[$L_19+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_19+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_19+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_19+12>>2]=HEAP32[$x+12>>2]|0;HEAP32[$L_19+16>>2]=HEAP32[$x+16>>2]|0;HEAP32[$L_19+20>>2]=HEAP32[$x+20>>2]|0;
               __THREW__ = 0;
               (invoke_ii(2996,(2594096|0))|0);
               $66 = __THREW__; __THREW__ = 0;
               $67 = $66&1;
               if (!($67)) {
                __THREW__ = 0;
                $68 = (invoke_iii(2724,(2594096|0),($L_19|0))|0);
                $69 = __THREW__; __THREW__ = 0;
                $70 = $69&1;
                if (!($70)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2157896|0))|0);
                 $71 = __THREW__; __THREW__ = 0;
                 $72 = $71&1;
                 if ($72) {
                  break;
                 }
                 __THREW__ = 0;
                 $73 = (invoke_iii(2746,($68|0),(2157896|0))|0);
                 $74 = __THREW__; __THREW__ = 0;
                 $75 = $74&1;
                 if ($75) {
                  break;
                 }
                 ;HEAP32[$L_22+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_22+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_22+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_22+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$L_22+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$L_22+20>>2]=HEAP32[$y+20>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2594096|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 }
                 __THREW__ = 0;
                 $78 = (invoke_iii(2724,(2594096|0),($L_22|0))|0);
                 $79 = __THREW__; __THREW__ = 0;
                 $80 = $79&1;
                 if ($80) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($73|0));
                 $81 = __THREW__; __THREW__ = 0;
                 $82 = $81&1;
                 if ($82) {
                  break;
                 }
                 __THREW__ = 0;
                 $83 = (invoke_iiii(1649,(2157808|0),($73|0),($78|0))|0);
                 $84 = __THREW__; __THREW__ = 0;
                 $85 = $84&1;
                 if ($85) {
                  break;
                 } else {
                  $$0 = $83;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset_m__ctorP92mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1660360);
 __THREW__ = 0;
 invoke_vi(1648,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m__ctorP85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1660848);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z106mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset_m_GetHashCodeP92mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffset($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1660408);
 ;HEAP32[$L_0+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$obj+12>>2]|0;HEAP32[$L_0+16>>2]=HEAP32[$obj+16>>2]|0;HEAP32[$L_0+20>>2]=HEAP32[$obj+20>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2594096|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2594096|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2594096|0),($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2594096|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(2594096|0),($obj|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2148880|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $$0 = $20;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset_m_EqualsP92mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffsetS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_2 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy = sp + 72|0;
 $data$i = sp + 104|0;
 $0 = sp + 24|0;
 $_stackTraceSentry = sp + 96|0;
 $L_0 = sp + 48|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1660456);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;HEAP32[$L_0+16>>2]=HEAP32[$x+16>>2]|0;HEAP32[$L_0+20>>2]=HEAP32[$x+20>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2724,(2594096|0),($L_0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if ($6) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$L_2+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$L_2+20>>2]=HEAP32[$y+20>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2594096|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2724,(2594096|0),($L_2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = ($11|0)==(0|0);
     $$0 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2594096|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_iii(2724,(2594096|0),($x|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3799,($17|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2594096|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        $24 = (invoke_iii(2724,(2594096|0),($x|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$y+20>>2]|0;
         __THREW__ = 0;
         invoke_viii(2116,($data$i|0),(1658472|0),($24|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($data$i) + 4|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = (($30) + 4|0);
          $32 = HEAP32[$31>>2]|0;
          $33 = HEAP32[$data$i>>2]|0;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
          $34 = (invoke_iii($32|0,($33|0),($$byval_copy|0))|0);
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if (!($36)) {
           $$0 = $34;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits36mscorlib_System_DateTimeOffsetTraitsE6InvokeEPFiPv30mscorlib_System_DateTimeOffsetES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 24|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits36mscorlib_System_DateTimeOffsetTraitsS1_E6InvokeEPFbPv30mscorlib_System_DateTimeOffsetS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 72|0;
 $0 = sp + 24|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$3+20>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1660896);
 __THREW__ = 0;
 (invoke_ii(2996,(1662280|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1662280|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1650,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1661488|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1661488 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m__ctorP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1661944);
 __THREW__ = 0;
 invoke_vi(1648,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m_System_Collections_IEqualityComparer_GetHashCodeP85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffsetP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 24|0;
 $data$i = sp + 56|0;
 $0 = sp;
 $_stackTraceSentry = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1660944);
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2745,($obj|0),(2594096|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   _memmove(($0|0),($3|0),24)|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(1660992|0),($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
    $13 = (invoke_iii($11|0,($12|0),($$byval_copy|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($13|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m_System_Collections_IEqualityComparer_EqualsP85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffsetP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $$byval_copy1 = sp + 120|0;
 $$byval_copy = sp;
 $data$i = sp + 152|0;
 $0 = sp + 48|0;
 $1 = sp + 72|0;
 $_stackTraceSentry = sp + 144|0;
 $L_1 = sp + 96|0;
 $2 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1661040);
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2745,($x|0),(2594096|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   ;HEAP32[$L_1+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$L_1+20>>2]=HEAP32[$5+20>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2594096|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2745,($y|0),(2594096|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     ;HEAP32[$2+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$2+16>>2]=HEAP32[$10+16>>2]|0;HEAP32[$2+20>>2]=HEAP32[$10+20>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$L_1+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$L_1+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$L_1+20>>2]|0;
     ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$2+20>>2]|0;
     __THREW__ = 0;
     invoke_viii(2112,($data$i|0),(1661088|0),($__this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = (($data$i) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($16) + 4|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$1+20>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy1+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy1+20>>2]=HEAP32[$0+20>>2]|0;
      $20 = (invoke_iiii($18|0,($19|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($20|0);
      }
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1661136);
 __THREW__ = 0;
 (invoke_ii(2996,(1661488|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1661488 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1661488|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1661488|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3817,(1661488|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1661488|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1661488 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m_GetHashCodeP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffset($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1661992);
 ;HEAP32[$L_0+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$obj+12>>2]|0;HEAP32[$L_0+16>>2]=HEAP32[$obj+16>>2]|0;HEAP32[$L_0+20>>2]=HEAP32[$obj+20>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2594096|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2594096|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2594096|0),($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2594096|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(2594096|0),($obj|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2148880|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $$0 = $20;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m_EqualsP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffsetS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $_stackTraceSentry = sp + 72|0;
 $L_0 = sp;
 $L_2 = sp + 24|0;
 $L_5 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1662040);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;HEAP32[$L_0+16>>2]=HEAP32[$x+16>>2]|0;HEAP32[$L_0+20>>2]=HEAP32[$x+20>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2724,(2594096|0),($L_0|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$L_2+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$L_2+20>>2]=HEAP32[$y+20>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2594096|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2724,(2594096|0),($L_2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = ($10|0)==(0|0);
     $$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    ;HEAP32[$L_5+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_5+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_5+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_5+12>>2]=HEAP32[$y+12>>2]|0;HEAP32[$L_5+16>>2]=HEAP32[$y+16>>2]|0;HEAP32[$L_5+20>>2]=HEAP32[$y+20>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2594096|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2594096|0),($L_5|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2594096|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_iii(2724,(2594096|0),($x|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2594096|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_iii(2724,(2594096|0),($x|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           __THREW__ = 0;
           $31 = (invoke_iiii(1644,(2148736|0),($28|0),($16|0))|0);
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $$0 = $31;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m__ctorP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan24mscorlib_System_TimeSpan($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1662424);
 $0 = (($__this) + 8|0);
 HEAP8[$0>>0] = 1;
 $1 = $value;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $__this;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z66mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_get_HasValueP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1662472);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z63mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_get_ValueP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1662520);
 __THREW__ = 0;
 invoke_v(354);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   $17 = $__this;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = (($17) + 4)|0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $22;
   STACKTOP = sp;return ($19|0);
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2607872|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_ii(3469,(2607872|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[3018864>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3816,($9|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      // unreachable;
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanP22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1662568);
 $1 = ($other|0)==(0|0);
 if ($1) {
  $2 = (($__this) + 8|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  $$0 = $4;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(1663064|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  $7 = (invoke_iii(2735,($other|0),(1663064|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = ($7|0)==(0|0);
   if ($10) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1663064|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_iii(2745,($other|0),(1663064|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     _memmove(($0|0),($15|0),16)|0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
     $18 = (invoke_iii(340,($__this|0),($$byval_copy|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $$0 = $18;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_Equals_mscorlib_System_Boolean_mscorlib_System_Nullable_1_TP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanS_($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_7 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_7 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1662616);
 $0 = (($other) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($1<<24>>24)==($3<<24>>24);
 if (!($4)) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($1<<24>>24)==(0);
 if ($5) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $6 = $__this;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $L_7;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if (!($17)) {
  __THREW__ = 0;
  $18 = (invoke_iii(2724,(2652728|0),($L_7|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    $23 = (invoke_iii(2724,(2652728|0),($other|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __THREW__ = 0;
     invoke_vi(3799,($23|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       $30 = (invoke_iii(2724,(2652728|0),($other|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        __THREW__ = 0;
        $33 = (invoke_iiii(1644,(2150048|0),($30|0),($18|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if (!($35)) {
         $$0 = $33;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($36|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_GetHashCodeP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1662664);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2724,(2652728|0),($__this|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2652728|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_iii(2724,(2652728|0),($__this|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_iii(2729,(2150224|0),($12|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $$0 = $15;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_ToStringP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1662712);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP8[((2191608 + 116|0))>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3817,(2191608|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = HEAP32[((2191608 + 80|0))>>2]|0;
     $33 = HEAP32[$32>>2]|0;
     $$0 = $33;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2724,(2652728|0),($__this|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       $12 = (invoke_iii(2724,(2652728|0),($__this|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        __THREW__ = 0;
        $15 = (invoke_iii(2730,(2150272|0),($12|0))|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if (!($17)) {
         $$0 = $15;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker1I30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPv24mscorlib_System_TimeSpanES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker0I30mscorlib_System_TimeSpanTraitsE6InvokeEPF24mscorlib_System_TimeSpanPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 $1 = tempRet0;
 $2 = $ret;
 $3 = $2;
 HEAP32[$3>>2] = $0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = $1;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2652728,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits57mscorlib_System_Nullable_1_mscorlib_System_TimeSpanTraitsE6InvokeEPFbPv51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m__ctorP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeekP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1663448);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m_System_Collections_IEnumerator_get_CurrentP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1663496);
 __THREW__ = 0;
 $0 = (invoke_ii(1205,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2595696|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2595696|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m_get_CurrentP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1663640);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2182,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m_DisposeP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1663544);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m_MoveNextP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1663592);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1667152)|0);
 $0 = HEAP32[((1667152 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1667152)|0);
 $0 = HEAP32[((1667152 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z82mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_Guid_m__ctorP74mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_Guid($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1669160);
 __THREW__ = 0;
 invoke_vi(1654,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z75mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid_m__ctorP67mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1669560);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_Guid_m_CompareP74mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_Guid20mscorlib_System_GuidS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_6 = 0, $_stackTraceSentry = 0, $data$i = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp + 80|0;
 $data$i = sp + 16|0;
 $0 = sp;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp + 32|0;
 $L_2 = sp + 48|0;
 $L_6 = sp + 64|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1669208);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2724,(2605992|0),($L_0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if ($6) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2605992|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2724,(2605992|0),($L_2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $not$ = ($11|0)!=(0|0);
     $$ = $not$ << 31 >> 31;
     $$0 = $$;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    ;HEAP32[$L_6+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$y+12>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2605992|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2605992|0),($L_6|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = ($16|0)==(0|0);
      if ($19) {
       $$0 = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       $22 = (invoke_iii(2724,(2605992|0),($x|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        invoke_vi(3799,($22|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2605992|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          __THREW__ = 0;
          $29 = (invoke_iii(2724,(2605992|0),($x|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;
           __THREW__ = 0;
           invoke_viii(2116,($data$i|0),(1668712|0),($29|0));
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $34 = (($data$i) + 4|0);
            $35 = HEAP32[$34>>2]|0;
            $36 = (($35) + 4|0);
            $37 = HEAP32[$36>>2]|0;
            $38 = HEAP32[$data$i>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
            $39 = (invoke_iii($37|0,($38|0),($$byval_copy|0))|0);
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if (!($41)) {
             $$0 = $39;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_GuidTraitsS1_E6InvokeEPFiPv20mscorlib_System_GuidS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 40|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 24|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z76mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1669608);
 __THREW__ = 0;
 (invoke_ii(2996,(1670688|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1670688|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1656,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1670040|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1670040 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z91mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Guid_m__ctorP83mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Guid($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1670424);
 __THREW__ = 0;
 invoke_vi(1654,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z106mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid_m_System_Collections_IComparer_CompareP67mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_GuidP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_6 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp + 96|0;
 $$byval_copy = sp + 40|0;
 $data$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 16|0;
 $_stackTraceSentry = sp + 56|0;
 $L_6 = sp + 64|0;
 $2 = sp + 80|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1669656);
 $3 = ($x|0)==(0|0);
 $4 = ($y|0)!=(0|0);
 if ($3) {
  $$ = $4 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($4)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iii(2735,($x|0),(2605992|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($7|0)==(0|0);
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2605992|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_iii(2735,($y|0),(2605992|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     $18 = ($15|0)==(0|0);
     if (!($18)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      __THREW__ = 0;
      $21 = (invoke_iii(2745,($x|0),(2605992|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      ;HEAP32[$L_6+0>>2]=HEAP32[$21+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$21+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$21+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$21+12>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2745,($y|0),(2605992|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      ;HEAP32[$2+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$26+12>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$L_6+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$L_6+12>>2]|0;
      ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;
      __THREW__ = 0;
      invoke_viii(2112,($data$i|0),(1669704|0),($__this|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = (($data$i) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($32) + 4|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;
      $36 = (invoke_iiii($34|0,($35|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      } else {
       $$0 = $36;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     __THREW__ = 0;
     $41 = (invoke_ii(3469,(2560072|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      invoke_vi(2583,($41|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       __THREW__ = 0;
       invoke_vi(3816,($41|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1669752);
 __THREW__ = 0;
 (invoke_ii(2996,(1670040|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1670040 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1670040|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1670040|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3817,(1670040|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1670040|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1670040 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Guid_m_CompareP83mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Guid20mscorlib_System_GuidS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $L_0 = 0;
 var $L_12 = 0, $L_16 = 0, $L_19 = 0, $L_2 = 0, $L_22 = 0, $L_6 = 0, $L_9 = 0, $_stackTraceSentry = 0, $data$i = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy = sp + 160|0;
 $data$i = sp + 152|0;
 $0 = sp;
 $_stackTraceSentry = sp + 144|0;
 $L_0 = sp + 128|0;
 $L_2 = sp + 112|0;
 $L_6 = sp + 96|0;
 $L_9 = sp + 64|0;
 $L_12 = sp + 48|0;
 $L_16 = sp + 32|0;
 $L_19 = sp + 16|0;
 $L_22 = sp + 80|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1670472);
 __THREW__ = 0;
 invoke_v(353);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2605992|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2724,(2605992|0),($L_0|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = ($5|0)==(0|0);
     if ($8) {
      ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      $13 = (invoke_iii(2724,(2605992|0),($L_2|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      $not$ = ($13|0)!=(0|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     ;HEAP32[$L_6+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$y+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2605992|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (invoke_iii(2724,(2605992|0),($L_6|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = ($18|0)==(0|0);
       if ($21) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       ;HEAP32[$L_9+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_9+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_9+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_9+12>>2]=HEAP32[$x+12>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2605992|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        $24 = (invoke_iii(2724,(2605992|0),($L_9|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         __THREW__ = 0;
         (invoke_ii(2996,(1668784|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          __THREW__ = 0;
          $29 = (invoke_iii(2735,($24|0),(1668784|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           $32 = ($29|0)==(0|0);
           if (!($32)) {
            ;HEAP32[$L_12+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_12+12>>2]=HEAP32[$x+12>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2605992|0))|0);
            $33 = __THREW__; __THREW__ = 0;
            $34 = $33&1;
            if ($34) {
             break;
            }
            __THREW__ = 0;
            $35 = (invoke_iii(2724,(2605992|0),($L_12|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if ($37) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(1668784|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            __THREW__ = 0;
            $40 = (invoke_iii(2746,($35|0),(1668784|0))|0);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($40|0));
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;
            __THREW__ = 0;
            invoke_viii(2116,($data$i|0),(1668712|0),($40|0));
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             break;
            }
            $47 = (($data$i) + 4|0);
            $48 = HEAP32[$47>>2]|0;
            $49 = (($48) + 4|0);
            $50 = HEAP32[$49>>2]|0;
            $51 = HEAP32[$data$i>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
            $52 = (invoke_iii($50|0,($51|0),($$byval_copy|0))|0);
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             break;
            } else {
             $$0 = $52;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           ;HEAP32[$L_16+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_16+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_16+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_16+12>>2]=HEAP32[$x+12>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2605992|0))|0);
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if (!($56)) {
            __THREW__ = 0;
            $57 = (invoke_iii(2724,(2605992|0),($L_16|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2157896|0))|0);
             $60 = __THREW__; __THREW__ = 0;
             $61 = $60&1;
             if (!($61)) {
              __THREW__ = 0;
              $62 = (invoke_iii(2735,($57|0),(2157896|0))|0);
              $63 = __THREW__; __THREW__ = 0;
              $64 = $63&1;
              if (!($64)) {
               $65 = ($62|0)==(0|0);
               if ($65) {
                __THREW__ = 0;
                (invoke_ii(2996,(2560072|0))|0);
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 break;
                }
                __THREW__ = 0;
                $88 = (invoke_ii(3469,(2560072|0))|0);
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if ($90) {
                 break;
                }
                $91 = HEAP32[3020480>>2]|0;
                __THREW__ = 0;
                invoke_vii(1924,($88|0),($91|0));
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3816,($88|0));
                $94 = __THREW__; __THREW__ = 0;
                $95 = $94&1;
                if ($95) {
                 break;
                }
                // unreachable;
               }
               ;HEAP32[$L_19+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_19+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_19+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_19+12>>2]=HEAP32[$x+12>>2]|0;
               __THREW__ = 0;
               (invoke_ii(2996,(2605992|0))|0);
               $66 = __THREW__; __THREW__ = 0;
               $67 = $66&1;
               if (!($67)) {
                __THREW__ = 0;
                $68 = (invoke_iii(2724,(2605992|0),($L_19|0))|0);
                $69 = __THREW__; __THREW__ = 0;
                $70 = $69&1;
                if (!($70)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2157896|0))|0);
                 $71 = __THREW__; __THREW__ = 0;
                 $72 = $71&1;
                 if ($72) {
                  break;
                 }
                 __THREW__ = 0;
                 $73 = (invoke_iii(2746,($68|0),(2157896|0))|0);
                 $74 = __THREW__; __THREW__ = 0;
                 $75 = $74&1;
                 if ($75) {
                  break;
                 }
                 ;HEAP32[$L_22+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_22+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_22+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_22+12>>2]=HEAP32[$y+12>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2605992|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 }
                 __THREW__ = 0;
                 $78 = (invoke_iii(2724,(2605992|0),($L_22|0))|0);
                 $79 = __THREW__; __THREW__ = 0;
                 $80 = $79&1;
                 if ($80) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($73|0));
                 $81 = __THREW__; __THREW__ = 0;
                 $82 = $81&1;
                 if ($82) {
                  break;
                 }
                 __THREW__ = 0;
                 $83 = (invoke_iiii(1649,(2157808|0),($73|0),($78|0))|0);
                 $84 = __THREW__; __THREW__ = 0;
                 $85 = $84&1;
                 if ($85) {
                  break;
                 } else {
                  $$0 = $83;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid_m__ctorP82mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1670832);
 __THREW__ = 0;
 invoke_vi(1658,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m__ctorP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1671320);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z96mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid_m_GetHashCodeP82mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid20mscorlib_System_Guid($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1670880);
 ;HEAP32[$L_0+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$obj+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2605992|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2605992|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2605992|0),($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(2605992|0),($obj|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2148880|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $$0 = $20;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid_m_EqualsP82mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid20mscorlib_System_GuidS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_2 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy = sp + 64|0;
 $data$i = sp + 16|0;
 $0 = sp;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp + 32|0;
 $L_2 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1670928);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2724,(2605992|0),($L_0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if ($6) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2605992|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2724,(2605992|0),($L_2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = ($11|0)==(0|0);
     $$0 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2605992|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_iii(2724,(2605992|0),($x|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3799,($17|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2605992|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        $24 = (invoke_iii(2724,(2605992|0),($x|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         ;HEAP32[$0+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$y+12>>2]|0;
         __THREW__ = 0;
         invoke_viii(2116,($data$i|0),(1668944|0),($24|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($data$i) + 4|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = (($30) + 4|0);
          $32 = HEAP32[$31>>2]|0;
          $33 = HEAP32[$data$i>>2]|0;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
          $34 = (invoke_iii($32|0,($33|0),($$byval_copy|0))|0);
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if (!($36)) {
           $$0 = $34;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_GuidTraitsE6InvokeEPFiPv20mscorlib_System_GuidES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_GuidTraitsS1_E6InvokeEPFbPv20mscorlib_System_GuidS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 32|0;
 $$byval_copy = sp;
 $ret = sp + 48|0;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z84mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1671368);
 __THREW__ = 0;
 (invoke_ii(2996,(1672752|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1672752|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1660,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1671960|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1671960 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z99mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid_m__ctorP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1672416);
 __THREW__ = 0;
 invoke_vi(1658,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z126mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m_System_Collections_IEqualityComparer_GetHashCodeP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_GuidP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $data$i = sp + 16|0;
 $0 = sp;
 $_stackTraceSentry = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1671416);
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2745,($obj|0),(2605992|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   _memmove(($0|0),($3|0),16)|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(1671464|0),($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
    $13 = (invoke_iii($11|0,($12|0),($$byval_copy|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($13|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m_System_Collections_IEqualityComparer_EqualsP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_GuidP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy1 = sp + 96|0;
 $$byval_copy = sp + 40|0;
 $data$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 16|0;
 $_stackTraceSentry = sp + 56|0;
 $L_1 = sp + 64|0;
 $2 = sp + 80|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1671512);
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2745,($x|0),(2605992|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   ;HEAP32[$L_1+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$5+12>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2605992|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2745,($y|0),(2605992|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     ;HEAP32[$2+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$10+12>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$L_1+12>>2]|0;
     ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;
     __THREW__ = 0;
     invoke_viii(2112,($data$i|0),(1671560|0),($__this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = (($data$i) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($16) + 4|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;
      $20 = (invoke_iiii($18|0,($19|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($20|0);
      }
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1671608);
 __THREW__ = 0;
 (invoke_ii(2996,(1671960|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1671960 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1671960|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1671960|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3817,(1671960|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1671960|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1671960 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid_m_GetHashCodeP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid20mscorlib_System_Guid($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1672464);
 ;HEAP32[$L_0+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$obj+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$obj+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2605992|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2605992|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2605992|0),($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(2605992|0),($obj|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2148880|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $$0 = $20;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid_m_EqualsP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid20mscorlib_System_GuidS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 48|0;
 $L_0 = sp;
 $L_2 = sp + 16|0;
 $L_5 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1672512);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$x+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2724,(2605992|0),($L_0|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$y+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2605992|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2724,(2605992|0),($L_2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = ($10|0)==(0|0);
     $$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    ;HEAP32[$L_5+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_5+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_5+8>>2]=HEAP32[$y+8>>2]|0;HEAP32[$L_5+12>>2]=HEAP32[$y+12>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2605992|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2605992|0),($L_5|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_iii(2724,(2605992|0),($x|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2605992|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_iii(2724,(2605992|0),($x|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           __THREW__ = 0;
           $31 = (invoke_iiii(1644,(2148736|0),($28|0),($16|0))|0);
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $$0 = $31;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimizationP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1673136);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1673184);
 __THREW__ = 0;
 $0 = (invoke_ii(1213,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2608552|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2608552|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1673328);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2190,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1673232);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1673280);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m__ctorP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m_System_Collections_IEnumerator_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1675880)|0);
 $0 = HEAP32[((1675880 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m_DisposeP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m_MoveNextP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1675880)|0);
 $0 = HEAP32[((1675880 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1678144)|0);
 $0 = HEAP32[((1678144 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1678144)|0);
 $0 = HEAP32[((1678144 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m__ctorP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformIDP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1679928);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m_System_Collections_IEnumerator_get_CurrentP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1679976);
 __THREW__ = 0;
 $0 = (invoke_ii(1222,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2636520|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2636520|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m_get_CurrentP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1680120);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3816,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2202,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m_DisposeP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1680024);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m_MoveNextP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1680072);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1683152)|0);
 $0 = HEAP32[((1683152 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1683152)|0);
 $0 = HEAP32[((1683152 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z86mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_TimeSpan_m__ctorP78mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1685160);
 __THREW__ = 0;
 invoke_vi(1667,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z79mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan_m__ctorP71mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1685560);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z88mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_TimeSpan_m_CompareP78mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_TimeSpan24mscorlib_System_TimeSpanS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_6 = 0, $_stackTraceSentry = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp + 8|0;
 $L_2 = sp + 16|0;
 $L_6 = sp + 24|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1685208);
 $1 = $x;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $L_0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if (!($12)) {
   __THREW__ = 0;
   $13 = (invoke_iii(2724,(2652728|0),($L_0|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = ($13|0)==(0|0);
    $17 = $y;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($17) + 4)|0;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    if ($16) {
     $25 = $L_2;
     $26 = $25;
     HEAP32[$26>>2] = $19;
     $27 = (($25) + 4)|0;
     $28 = $27;
     HEAP32[$28>>2] = $22;
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     __THREW__ = 0;
     $31 = (invoke_iii(2724,(2652728|0),($L_2|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $not$ = ($31|0)!=(0|0);
     $$ = $not$ << 31 >> 31;
     $$0 = $$;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $34 = $L_6;
    $35 = $34;
    HEAP32[$35>>2] = $19;
    $36 = (($34) + 4)|0;
    $37 = $36;
    HEAP32[$37>>2] = $22;
    __THREW__ = 0;
    (invoke_ii(2996,(2652728|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     __THREW__ = 0;
     $40 = (invoke_iii(2724,(2652728|0),($L_6|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      $43 = ($40|0)==(0|0);
      if ($43) {
       $$0 = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       __THREW__ = 0;
       $46 = (invoke_iii(2724,(2652728|0),($x|0))|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if (!($48)) {
        __THREW__ = 0;
        invoke_vi(3799,($46|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if (!($50)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2652728|0))|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if (!($52)) {
          __THREW__ = 0;
          $53 = (invoke_iii(2724,(2652728|0),($x|0))|0);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if (!($55)) {
           $56 = $0;
           $57 = $56;
           HEAP32[$57>>2] = $19;
           $58 = (($56) + 4)|0;
           $59 = $58;
           HEAP32[$59>>2] = $22;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
           $60 = (invoke_iiii(1654,(1684712|0),($53|0),($$byval_copy|0))|0);
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if (!($62)) {
            $$0 = $60;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsE6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpan($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $data = sp + 16|0;
 $0 = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$data>>2]|0;
 $6 = $p1;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $16 = (FUNCTION_TABLE_iii[$4 & 4095]($5,$$byval_copy)|0);
 STACKTOP = sp;return ($16|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsS1_E6InvokeEPFiPv24mscorlib_System_TimeSpanS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $ret = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$args>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($args) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $25 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$$byval_copy1)|0);
 HEAP32[$ret>>2] = $25;
 $26 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($26|0);
}
function __Z80mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1685608);
 __THREW__ = 0;
 (invoke_ii(2996,(1686688|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1686688|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1669,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1686040|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1686040 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_TimeSpan_m__ctorP87mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1686424);
 __THREW__ = 0;
 invoke_vi(1667,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z110mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan_m_System_Collections_IComparer_CompareP71mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpanP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1685656);
 $2 = ($x|0)==(0|0);
 $3 = ($y|0)!=(0|0);
 if ($2) {
  $$ = $3 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($3)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2735,($x|0),(2652728|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)==(0|0);
    if (!($9)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     $14 = (invoke_iii(2735,($y|0),(2652728|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     $17 = ($14|0)==(0|0);
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      $20 = (invoke_iii(2745,($x|0),(2652728|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      $23 = $20;
      $24 = $23;
      $25 = HEAP32[$24>>2]|0;
      $26 = (($23) + 4)|0;
      $27 = $26;
      $28 = HEAP32[$27>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      $31 = (invoke_iii(2745,($y|0),(2652728|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      $34 = $31;
      $35 = $34;
      $36 = HEAP32[$35>>2]|0;
      $37 = (($34) + 4)|0;
      $38 = $37;
      $39 = HEAP32[$38>>2]|0;
      $40 = $0;
      $41 = $40;
      HEAP32[$41>>2] = $25;
      $42 = (($40) + 4)|0;
      $43 = $42;
      HEAP32[$43>>2] = $28;
      $44 = $1;
      $45 = $44;
      HEAP32[$45>>2] = $36;
      $46 = (($44) + 4)|0;
      $47 = $46;
      HEAP32[$47>>2] = $39;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
      $48 = (invoke_iiiii(307,(1685704|0),($__this|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      } else {
       $$0 = $48;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if (!($52)) {
     __THREW__ = 0;
     $53 = (invoke_ii(3469,(2560072|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if (!($55)) {
      __THREW__ = 0;
      invoke_vi(2583,($53|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if (!($57)) {
       __THREW__ = 0;
       invoke_vi(3816,($53|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if (!($59)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsS1_E6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpanS6_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $data = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$data>>2]|0;
 $7 = $p1;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $0;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = $p2;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $1;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $27 = (FUNCTION_TABLE_iiii[$5 & 2047]($6,$$byval_copy,$$byval_copy1)|0);
 STACKTOP = sp;return ($27|0);
}
function __Z85mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1685752);
 __THREW__ = 0;
 (invoke_ii(2996,(1686040|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1686040 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1686040|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1686040|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3817,(1686040|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1686040|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1686040 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_TimeSpan_m_CompareP87mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_TimeSpan24mscorlib_System_TimeSpanS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_0 = 0, $L_12 = 0, $L_16 = 0, $L_19 = 0, $L_2 = 0, $L_22 = 0, $L_6 = 0, $L_9 = 0, $_stackTraceSentry = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp + 72|0;
 $_stackTraceSentry = sp + 80|0;
 $L_0 = sp + 64|0;
 $L_2 = sp + 56|0;
 $L_6 = sp + 48|0;
 $L_9 = sp + 40|0;
 $L_12 = sp + 24|0;
 $0 = sp + 16|0;
 $L_16 = sp + 8|0;
 $L_19 = sp;
 $L_22 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1686472);
 __THREW__ = 0;
 invoke_v(353);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = $x;
   $4 = $3;
   $5 = HEAP32[$4>>2]|0;
   $6 = (($3) + 4)|0;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = $L_0;
   $10 = $9;
   HEAP32[$10>>2] = $5;
   $11 = (($9) + 4)|0;
   $12 = $11;
   HEAP32[$12>>2] = $8;
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_iii(2724,(2652728|0),($L_0|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = ($15|0)==(0|0);
     $19 = $y;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + 4)|0;
     $23 = $22;
     $24 = HEAP32[$23>>2]|0;
     if ($18) {
      $27 = $L_2;
      $28 = $27;
      HEAP32[$28>>2] = $21;
      $29 = (($27) + 4)|0;
      $30 = $29;
      HEAP32[$30>>2] = $24;
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      $33 = (invoke_iii(2724,(2652728|0),($L_2|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      $not$ = ($33|0)!=(0|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $36 = $L_6;
     $37 = $36;
     HEAP32[$37>>2] = $21;
     $38 = (($36) + 4)|0;
     $39 = $38;
     HEAP32[$39>>2] = $24;
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if (!($41)) {
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2652728|0),($L_6|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       $45 = ($42|0)==(0|0);
       if ($45) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $46 = $L_9;
       $47 = $46;
       HEAP32[$47>>2] = $5;
       $48 = (($46) + 4)|0;
       $49 = $48;
       HEAP32[$49>>2] = $8;
       __THREW__ = 0;
       (invoke_ii(2996,(2652728|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if (!($51)) {
        __THREW__ = 0;
        $52 = (invoke_iii(2724,(2652728|0),($L_9|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if (!($54)) {
         __THREW__ = 0;
         (invoke_ii(2996,(1684784|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          __THREW__ = 0;
          $57 = (invoke_iii(2735,($52|0),(1684784|0))|0);
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           $60 = ($57|0)==(0|0);
           if (!($60)) {
            $61 = $L_12;
            $62 = $61;
            HEAP32[$62>>2] = $5;
            $63 = (($61) + 4)|0;
            $64 = $63;
            HEAP32[$64>>2] = $8;
            __THREW__ = 0;
            (invoke_ii(2996,(2652728|0))|0);
            $65 = __THREW__; __THREW__ = 0;
            $66 = $65&1;
            if ($66) {
             break;
            }
            __THREW__ = 0;
            $67 = (invoke_iii(2724,(2652728|0),($L_12|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(1684784|0))|0);
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if ($71) {
             break;
            }
            __THREW__ = 0;
            $72 = (invoke_iii(2746,($67|0),(1684784|0))|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($72|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            $77 = $0;
            $78 = $77;
            HEAP32[$78>>2] = $21;
            $79 = (($77) + 4)|0;
            $80 = $79;
            HEAP32[$80>>2] = $24;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
            $81 = (invoke_iiii(1654,(1684712|0),($72|0),($$byval_copy|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if ($83) {
             break;
            } else {
             $$0 = $81;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           $84 = $L_16;
           $85 = $84;
           HEAP32[$85>>2] = $5;
           $86 = (($84) + 4)|0;
           $87 = $86;
           HEAP32[$87>>2] = $8;
           __THREW__ = 0;
           (invoke_ii(2996,(2652728|0))|0);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if (!($89)) {
            __THREW__ = 0;
            $90 = (invoke_iii(2724,(2652728|0),($L_16|0))|0);
            $91 = __THREW__; __THREW__ = 0;
            $92 = $91&1;
            if (!($92)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2157896|0))|0);
             $93 = __THREW__; __THREW__ = 0;
             $94 = $93&1;
             if (!($94)) {
              __THREW__ = 0;
              $95 = (invoke_iii(2735,($90|0),(2157896|0))|0);
              $96 = __THREW__; __THREW__ = 0;
              $97 = $96&1;
              if (!($97)) {
               $98 = ($95|0)==(0|0);
               if ($98) {
                __THREW__ = 0;
                (invoke_ii(2996,(2560072|0))|0);
                $127 = __THREW__; __THREW__ = 0;
                $128 = $127&1;
                if ($128) {
                 break;
                }
                __THREW__ = 0;
                $129 = (invoke_ii(3469,(2560072|0))|0);
                $130 = __THREW__; __THREW__ = 0;
                $131 = $130&1;
                if ($131) {
                 break;
                }
                $132 = HEAP32[3020480>>2]|0;
                __THREW__ = 0;
                invoke_vii(1924,($129|0),($132|0));
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3816,($129|0));
                $135 = __THREW__; __THREW__ = 0;
                $136 = $135&1;
                if ($136) {
                 break;
                }
                // unreachable;
               }
               $99 = $L_19;
               $100 = $99;
               HEAP32[$100>>2] = $5;
               $101 = (($99) + 4)|0;
               $102 = $101;
               HEAP32[$102>>2] = $8;
               __THREW__ = 0;
               (invoke_ii(2996,(2652728|0))|0);
               $103 = __THREW__; __THREW__ = 0;
               $104 = $103&1;
               if (!($104)) {
                __THREW__ = 0;
                $105 = (invoke_iii(2724,(2652728|0),($L_19|0))|0);
                $106 = __THREW__; __THREW__ = 0;
                $107 = $106&1;
                if (!($107)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2157896|0))|0);
                 $108 = __THREW__; __THREW__ = 0;
                 $109 = $108&1;
                 if ($109) {
                  break;
                 }
                 __THREW__ = 0;
                 $110 = (invoke_iii(2746,($105|0),(2157896|0))|0);
                 $111 = __THREW__; __THREW__ = 0;
                 $112 = $111&1;
                 if ($112) {
                  break;
                 }
                 $113 = $L_22;
                 $114 = $113;
                 HEAP32[$114>>2] = $21;
                 $115 = (($113) + 4)|0;
                 $116 = $115;
                 HEAP32[$116>>2] = $24;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2652728|0))|0);
                 $117 = __THREW__; __THREW__ = 0;
                 $118 = $117&1;
                 if ($118) {
                  break;
                 }
                 __THREW__ = 0;
                 $119 = (invoke_iii(2724,(2652728|0),($L_22|0))|0);
                 $120 = __THREW__; __THREW__ = 0;
                 $121 = $120&1;
                 if ($121) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($110|0));
                 $122 = __THREW__; __THREW__ = 0;
                 $123 = $122&1;
                 if ($123) {
                  break;
                 }
                 __THREW__ = 0;
                 $124 = (invoke_iiii(1649,(2157808|0),($110|0),($119|0))|0);
                 $125 = __THREW__; __THREW__ = 0;
                 $126 = $125&1;
                 if ($126) {
                  break;
                 } else {
                  $$0 = $124;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($25|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan_m__ctorP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1686832);
 __THREW__ = 0;
 invoke_vi(1671,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z87mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m__ctorP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1687320);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z100mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan_m_GetHashCodeP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan24mscorlib_System_TimeSpan($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1686880);
 $0 = $obj;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $L_0;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  $12 = (invoke_iii(2724,(2652728|0),($L_0|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = ($12|0)==(0|0);
   if ($15) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_iii(2724,(2652728|0),($obj|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2652728|0),($obj|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iii(2729,(2148880|0),($27|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $$0 = $30;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan_m_EqualsP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan24mscorlib_System_TimeSpanS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 24|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp + 8|0;
 $L_2 = sp + 16|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1686928);
 $1 = $x;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $L_0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if (!($12)) {
   __THREW__ = 0;
   $13 = (invoke_iii(2724,(2652728|0),($L_0|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = ($13|0)==(0|0);
    if ($16) {
     $19 = $y;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + 4)|0;
     $23 = $22;
     $24 = HEAP32[$23>>2]|0;
     $25 = $L_2;
     $26 = $25;
     HEAP32[$26>>2] = $21;
     $27 = (($25) + 4)|0;
     $28 = $27;
     HEAP32[$28>>2] = $24;
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     __THREW__ = 0;
     $31 = (invoke_iii(2724,(2652728|0),($L_2|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $34 = ($31|0)==(0|0);
     $$0 = $34;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2652728|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __THREW__ = 0;
     $37 = (invoke_iii(2724,(2652728|0),($x|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2652728|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if (!($43)) {
        __THREW__ = 0;
        $44 = (invoke_iii(2724,(2652728|0),($x|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = $y;
         $48 = $47;
         $49 = HEAP32[$48>>2]|0;
         $50 = (($47) + 4)|0;
         $51 = $50;
         $52 = HEAP32[$51>>2]|0;
         $53 = $0;
         $54 = $53;
         HEAP32[$54>>2] = $49;
         $55 = (($53) + 4)|0;
         $56 = $55;
         HEAP32[$56>>2] = $52;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
         $57 = (invoke_iiii(1655,(1684944|0),($44|0),($$byval_copy|0))|0);
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          $$0 = $57;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsE6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpan($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $data = sp + 16|0;
 $0 = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$data>>2]|0;
 $6 = $p1;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $16 = (FUNCTION_TABLE_iii[$4 & 4095]($5,$$byval_copy)|0);
 STACKTOP = sp;return ($16|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsE6InvokeEPFiPv24mscorlib_System_TimeSpanES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 HEAP32[$ret>>2] = $12;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsS1_E6InvokeEPFbPv24mscorlib_System_TimeSpanS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $ret = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$args>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($args) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $25 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$$byval_copy1)|0);
 $26 = $25&1;
 HEAP8[$ret>>0] = $26;
 $27 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($27|0);
}
function __Z88mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1687368);
 __THREW__ = 0;
 (invoke_ii(2996,(1688752|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1688752|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1673,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1687960|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1687960 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan_m__ctorP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1688416);
 __THREW__ = 0;
 invoke_vi(1671,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z130mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m_System_Collections_IEqualityComparer_GetHashCodeP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpanP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp + 16|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1687416);
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2745,($obj|0),(2652728|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $0;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   $16 = (invoke_iiii(1656,(1687464|0),($__this|0),($$byval_copy|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsE6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpan($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $data = sp + 16|0;
 $0 = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$data>>2]|0;
 $6 = $p1;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $16 = (FUNCTION_TABLE_iii[$4 & 4095]($5,$$byval_copy)|0);
 STACKTOP = sp;return ($16|0);
}
function __Z125mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m_System_Collections_IEqualityComparer_EqualsP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpanP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1687512);
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2745,($x|0),(2652728|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = $4;
   $8 = $7;
   $9 = HEAP32[$8>>2]|0;
   $10 = (($7) + 4)|0;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_iii(2745,($y|0),(2652728|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = $15;
     $19 = $18;
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + 4)|0;
     $22 = $21;
     $23 = HEAP32[$22>>2]|0;
     $24 = $0;
     $25 = $24;
     HEAP32[$25>>2] = $9;
     $26 = (($24) + 4)|0;
     $27 = $26;
     HEAP32[$27>>2] = $12;
     $28 = $1;
     $29 = $28;
     HEAP32[$29>>2] = $20;
     $30 = (($28) + 4)|0;
     $31 = $30;
     HEAP32[$31>>2] = $23;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
     $32 = (invoke_iiiii(308,(1687560|0),($__this|0),($$byval_copy|0),($$byval_copy1|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($32|0);
     }
    }
   }
  }
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($35|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsS1_E6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpanS6_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $data = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$data>>2]|0;
 $7 = $p1;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $0;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = $p2;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $1;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $27 = (FUNCTION_TABLE_iiii[$5 & 2047]($6,$$byval_copy,$$byval_copy1)|0);
 STACKTOP = sp;return ($27|0);
}
function __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1687608);
 __THREW__ = 0;
 (invoke_ii(2996,(1687960|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1687960 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1687960|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1687960|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3817,(1687960|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1687960|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1687960 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan_m_GetHashCodeP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan24mscorlib_System_TimeSpan($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1688464);
 $0 = $obj;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $L_0;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  $12 = (invoke_iii(2724,(2652728|0),($L_0|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = ($12|0)==(0|0);
   if ($15) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_iii(2724,(2652728|0),($obj|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2652728|0),($obj|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iii(2729,(2148880|0),($27|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $$0 = $30;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan_m_EqualsP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan24mscorlib_System_TimeSpanS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_2 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp;
 $L_2 = sp + 8|0;
 $L_5 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1688512);
 $0 = $x;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $L_0;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 do {
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_iii(2724,(2652728|0),($L_0|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = ($12|0)==(0|0);
    $16 = $y;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 4)|0;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    if ($15) {
     $24 = $L_2;
     $25 = $24;
     HEAP32[$25>>2] = $18;
     $26 = (($24) + 4)|0;
     $27 = $26;
     HEAP32[$27>>2] = $21;
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     $30 = (invoke_iii(2724,(2652728|0),($L_2|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     $33 = ($30|0)==(0|0);
     $$0 = $33;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $34 = $L_5;
    $35 = $34;
    HEAP32[$35>>2] = $18;
    $36 = (($34) + 4)|0;
    $37 = $36;
    HEAP32[$37>>2] = $21;
    __THREW__ = 0;
    (invoke_ii(2996,(2652728|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     __THREW__ = 0;
     $40 = (invoke_iii(2724,(2652728|0),($L_5|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       __THREW__ = 0;
       $45 = (invoke_iii(2724,(2652728|0),($x|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        __THREW__ = 0;
        invoke_vi(3799,($45|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if (!($49)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2652728|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          __THREW__ = 0;
          $52 = (invoke_iii(2724,(2652728|0),($x|0))|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           __THREW__ = 0;
           $55 = (invoke_iiii(1644,(2148736|0),($52|0),($40|0))|0);
           $56 = __THREW__; __THREW__ = 0;
           $57 = $56&1;
           if (!($57)) {
            $$0 = $55;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m__ctorP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCodeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1693736);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m_System_Collections_IEnumerator_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1693784);
 __THREW__ = 0;
 $0 = (invoke_ii(1230,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2656168|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2656168|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1693928);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3818,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3818,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(2210,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m_DisposeP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1693832);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m_MoveNextP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1693880);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2334($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL144mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1698856)|0);
 $0 = HEAP32[((1698856 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1698856)|0);
 $0 = HEAP32[((1698856 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m__ctorP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL148mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_System_Collections_IEnumerator_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1701216)|0);
 $0 = HEAP32[((1701216 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_DisposeP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_MoveNextP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1701216)|0);
 $0 = HEAP32[((1701216 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1703000);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z141mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1703048);
 __THREW__ = 0;
 $0 = (invoke_ii(1239,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(1296504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(1296504|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1703192);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1349,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1703096);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z107mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1703144);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2608($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1705744)|0);
 $0 = HEAP32[((1705744 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1705744)|0);
 $0 = HEAP32[((1705744 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1708008)|0);
 $0 = HEAP32[((1708008 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1708008)|0);
 $0 = HEAP32[((1708008 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1710272)|0);
 $0 = HEAP32[((1710272 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1710272)|0);
 $0 = HEAP32[((1710272 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m__ctorP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m_System_Collections_IEnumerator_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1712536)|0);
 $0 = HEAP32[((1712536 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m_DisposeP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m_MoveNextP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1712536)|0);
 $0 = HEAP32[((1712536 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1714800)|0);
 $0 = HEAP32[((1714800 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1714800)|0);
 $0 = HEAP32[((1714800 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z78System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_GetEnumeratorP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1716344);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3498,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL81System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m__ctorP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_TypeP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type($__this,$t) {
 $__this = $__this|0;
 $t = $t|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this,$t);
 STACKTOP = sp;return;
}
function __ZL70System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m__ctorP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z80System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m__ctor_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL108System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_System_Collections_ICollection_get_SyncRootP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z118System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_System_Collections_ICollection_CopyToP62System_System_Collections_Generic_Stack_1_mscorlib_System_TypeP21mscorlib_System_Arrayi($__this,$dest,$idx) {
 $__this = $__this|0;
 $dest = $dest|0;
 $idx = $idx|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z112System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$dest,$idx);
 STACKTOP = sp;return;
}
function __ZL128System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z138System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL68System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_PopP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_Pop_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL69System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_PushP62System_System_Collections_Generic_Stack_1_mscorlib_System_TypeP20mscorlib_System_Type($__this,$t) {
 $__this = $__this|0;
 $t = $t|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_Push_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$t);
 STACKTOP = sp;return;
}
function __ZL74System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_get_CountP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_get_Count_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker0I79System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_TypeTraitsE6InvokeEPF73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_TypePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1719368,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z80System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m__ctor_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1717376);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z118System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1717424);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z112System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$dest,$idx) {
 $__this = $__this|0;
 $dest = $dest|0;
 $idx = $idx|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1717472);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viiii(461,(2225864|0),($1|0),($dest|0),($idx|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   invoke_viiii(141,(0|0),($dest|0),($idx|0),($8|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch(348288|0)|0;
 $12 = tempRet0;
 $13 = (_llvm_eh_typeid_for((348288|0))|0);
 $14 = ($12|0)==($13|0);
 if (!($14)) {
  $$0 = $11;$$01 = $12;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$0|0);
  // unreachable;
 }
 $15 = (___cxa_begin_catch(($11|0))|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 __THREW__ = 0;
 $18 = (invoke_iii(2727,(2562152|0),($17|0))|0);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 do {
  if (!($20)) {
   if (!($18)) {
    $27 = (___cxa_allocate_exception(4)|0);
    $28 = HEAP32[$15>>2]|0;
    HEAP32[$27>>2] = $28;
    __THREW__ = 0;
    invoke_viii(1567,($27|0),(348288|0),(0|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_v(66);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     __THREW__ = 0;
     $35 = (invoke_ii(3469,(2560072|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      invoke_vi(2583,($35|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       __THREW__ = 0;
       invoke_vi(3819,($35|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        // unreachable;
       }
      }
     }
    }
   }
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   $$0 = $31;$$01 = $32;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$0|0);
   // unreachable;
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  $$0 = $23;$$01 = $24;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$0|0);
  // unreachable;
 }
}
function __Z138System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp;
 $L_1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1717520);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($0) + 84|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_vii($5|0,($L_0|0),($__this|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 }
 ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;
 $8 = HEAP32[$__this>>2]|0;
 $9 = (($8) + 84|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 __THREW__ = 0;
 $13 = (invoke_iii(2724,($12|0),($L_1|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($13|0);
 }
 return 0|0;
}
function __Z78System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_Pop_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1717568);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_ii(3469,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(2734,($5|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3819,($5|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       // unreachable;
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = (($__this) + 16|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = (($17) + 1)|0;
     HEAP32[$16>>2] = $20;
     $21 = (($__this) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $25 = HEAP32[$0>>2]|0;
      $26 = (($25) + -1)|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       HEAP32[$0>>2] = $26;
       __THREW__ = 0;
       invoke_vi(3799,($22|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = ($25|0)<(1);
        if ($31) {
         label = 15;
        } else {
         $32 = (($22) + 12|0);
         $33 = HEAP32[$32>>2]|0;
         $34 = ($26>>>0)<($33>>>0);
         if (!($34)) {
          label = 15;
         }
        }
        if ((label|0) == 15) {
         __THREW__ = 0;
         $35 = (invoke_i(132)|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($35|0));
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          break;
         }
        }
        $40 = HEAP32[$22>>2]|0;
        $41 = (($22) + 16|0);
        $42 = (($40) + 92|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = Math_imul($43, $26)|0;
        $45 = (($41) + ($44)|0);
        $46 = HEAP32[$45>>2]|0;
        $47 = HEAP32[$21>>2]|0;
        $48 = HEAP32[$0>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($47|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if (!($50)) {
         $51 = ($48|0)<(0);
         if (!($51)) {
          $52 = (($47) + 12|0);
          $53 = HEAP32[$52>>2]|0;
          $54 = ($48>>>0)<($53>>>0);
          if ($54) {
           $60 = HEAP32[$47>>2]|0;
           $61 = (($47) + 16|0);
           $62 = (($60) + 92|0);
           $63 = HEAP32[$62>>2]|0;
           $64 = Math_imul($63, $48)|0;
           $65 = (($61) + ($64)|0);
           HEAP32[$65>>2] = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($46|0);
          }
         }
         __THREW__ = 0;
         $55 = (invoke_i(132)|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if (!($57)) {
          __THREW__ = 0;
          invoke_vi(3302,($55|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           $60 = HEAP32[$47>>2]|0;
           $61 = (($47) + 16|0);
           $62 = (($60) + 92|0);
           $63 = HEAP32[$62>>2]|0;
           $64 = Math_imul($63, $48)|0;
           $65 = (($61) + ($64)|0);
           HEAP32[$65>>2] = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($46|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z79System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_Push_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$t) {
 $__this = $__this|0;
 $t = $t|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1717616);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 $$pre = (($__this) + 12|0);
 if ($2) {
  label = 5;
 } else {
  $3 = HEAP32[$$pre>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($1) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($3|0)==($7|0);
   if ($8) {
    label = 5;
   } else {
    label = 6;
   }
  }
 }
 if ((label|0) == 5) {
  $11 = HEAP32[$$pre>>2]|0;
  $12 = ($11|0)==(0);
  $13 = $11 << 1;
  $G_B5_0$0 = $12 ? 16 : $13;
  $14 = HEAP32[$__this>>2]|0;
  $15 = (($14) + 84|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  __THREW__ = 0;
  invoke_viii($20|0,(0|0),($0|0),($G_B5_0$0|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   label = 6;
  }
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   $25 = (($__this) + 16|0);
   $26 = HEAP32[$25>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = (($26) + 1)|0;
    HEAP32[$25>>2] = $29;
    $30 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = (($__this) + 12|0);
     $34 = HEAP32[$33>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      $37 = (($34) + 1)|0;
      HEAP32[$33>>2] = $37;
      __THREW__ = 0;
      invoke_vi(3799,($30|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $40 = ($34|0)<(0);
       if (!($40)) {
        $41 = (($30) + 12|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = ($34>>>0)<($42>>>0);
        if ($43) {
         $49 = HEAP32[$30>>2]|0;
         $50 = (($30) + 16|0);
         $51 = (($49) + 92|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = Math_imul($52, $34)|0;
         $54 = (($50) + ($53)|0);
         HEAP32[$54>>2] = $t;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
       __THREW__ = 0;
       $44 = (invoke_i(132)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3302,($44|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         $49 = HEAP32[$30>>2]|0;
         $50 = (($30) + 16|0);
         $51 = (($49) + 92|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = Math_imul($52, $34)|0;
         $54 = (($50) + ($53)|0);
         HEAP32[$54>>2] = $t;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z84System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_get_Count_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1717664);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z80System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_GetEnumeratorP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1717712);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3498,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL83System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m__ctorP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this,$t) {
 $__this = $__this|0;
 $t = $t|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this,$t);
 STACKTOP = sp;return;
}
function __ZL72System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m__ctorP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z80System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m__ctor_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL110System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRootP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z118System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyToP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$dest,$idx) {
 $__this = $__this|0;
 $dest = $dest|0;
 $idx = $idx|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z112System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$dest,$idx);
 STACKTOP = sp;return;
}
function __ZL130System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z138System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL70System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_PopP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_Pop_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL71System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_PushP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$t) {
 $__this = $__this|0;
 $t = $t|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_Push_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$t);
 STACKTOP = sp;return;
}
function __ZL76System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_get_CountP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_get_Count_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker0I81System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectTraitsE6InvokeEPF75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1718728,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z91System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object($__this,$t) {
 $__this = $__this|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1718208);
 HEAP32[$__this>>2] = $t;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __THREW__ = 0;
 invoke_vi(3799,($t|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $3 = (($t) + 16|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($__this) + 8|0);
  HEAP32[$5>>2] = $4;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z128System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectPPv($__this,$rgctx) {
 $__this = $__this|0;
 $rgctx = $rgctx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1718256);
 $0 = HEAP32[$rgctx>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 $3 = (invoke_ii($2|0,($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z93System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1718304);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z94System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B7_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1718352);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = (($2) + 16|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($1|0)==($6|0);
   if (!($7)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(2607872|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2734,($12|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($12|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = (($__this) + 4|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(-2);
   if ($21) {
    $22 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = (($22) + 12|0);
    $26 = HEAP32[$25>>2]|0;
    HEAP32[$19>>2] = $26;
    $28 = $26;
   } else {
    $28 = $20;
   }
   $27 = ($28|0)==(-1);
   if ($27) {
    $G_B7_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B7_0$0|0);
   }
   $29 = (($28) + -1)|0;
   HEAP32[$19>>2] = $29;
   $30 = ($28|0)!=(0);
   $G_B7_0$0 = $30;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B7_0$0|0);
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z97System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1718400);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(-1);
 if ($2) {
  $14 = HEAP32[$__this>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($14|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $17 = (($14) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = ($19|0)<(0);
    if (!($22)) {
     $23 = (($18) + 12|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($19>>>0)<($24>>>0);
     if ($25) {
      $31 = HEAP32[$18>>2]|0;
      $32 = (($18) + 16|0);
      $33 = (($31) + 92|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = Math_imul($34, $19)|0;
      $36 = (($32) + ($35)|0);
      $37 = HEAP32[$36>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($37|0);
     }
    }
    __THREW__ = 0;
    $26 = (invoke_i(132)|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     __THREW__ = 0;
     invoke_vi(3302,($26|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      $31 = HEAP32[$18>>2]|0;
      $32 = (($18) + 16|0);
      $33 = (($31) + 92|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = Math_imul($34, $19)|0;
      $36 = (($32) + ($35)|0);
      $37 = HEAP32[$36>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($37|0);
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2607872|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2607872|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2734,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3819,($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZL120System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1718728)|0);
 $0 = HEAP32[((1718728 + 84|0))>>2]|0;
 $1 = (__Z128System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_DisposeP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_MoveNextP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z94System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_get_CurrentP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z97System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL118System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m_System_Collections_IEnumerator_get_CurrentP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1719368)|0);
 $0 = HEAP32[((1719368 + 84|0))>>2]|0;
 $1 = (__Z128System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m_DisposeP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m_MoveNextP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z94System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m_get_CurrentP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z97System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1720232)|0);
 $0 = HEAP32[((1720232 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1720232)|0);
 $0 = HEAP32[((1720232 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_GetEnumeratorP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1721776);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3496,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL82mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m__ctorP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_TypeP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m__ctor_mscorlib_System_VoidP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL144mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL72mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1725200)|0);
 $0 = HEAP32[((1725200 + 84|0))>>2]|0;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_ICollection_CopyToP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_AddP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_ContainsP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_IndexOfP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_InsertP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_RemoveP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_ICollection_get_SyncRootP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_get_ItemP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_set_ItemP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL69mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_AddP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP20mscorlib_System_Type($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_GrowIfNeededP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_AddCollectionP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_AddEnumerableP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_AddRangeP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL71mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_ClearP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_ContainsP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP20mscorlib_System_Type($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL72mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_CopyToP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP24mscorlib_System_Type_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I80mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_TypeTraitsE6InvokeEPF74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_TypePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1725984,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_IndexOfP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP20mscorlib_System_Type($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL71mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_ShiftP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typeii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_CheckIndexP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL72mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_InsertP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeiP20mscorlib_System_Type($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_CheckCollectionP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL72mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_RemoveP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP20mscorlib_System_Type($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_RemoveAtP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_ToArrayP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_get_CapacityP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_set_CapacityP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value);
 STACKTOP = sp;return;
}
function __ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_get_CountP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_get_ItemP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_set_ItemP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeiP20mscorlib_System_Type($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1725984)|0);
 $0 = HEAP32[((1725984 + 84|0))>>2]|0;
 $1 = (__Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_DisposeP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_VerifyStateP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1725984)|0);
 $0 = HEAP32[((1725984 + 84|0))>>2]|0;
 __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_MoveNextP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1725984)|0);
 $0 = HEAP32[((1725984 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_get_CurrentP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL83mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m__ctorP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1726952)|0);
 $0 = HEAP32[((1726952 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m_System_Collections_IEqualityComparer_GetHashCodeP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TypeP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL121mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m_System_Collections_IEqualityComparer_EqualsP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TypeP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1726952)|0);
 $0 = HEAP32[((1726952 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Type_m__ctorP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Type_m_GetHashCodeP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TypeP20mscorlib_System_Type($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Type_m_EqualsP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TypeP20mscorlib_System_TypeS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1728424);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1728472);
 __THREW__ = 0;
 $0 = (invoke_ii(1284,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2433320|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2433320|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1728616);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1377,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1728520);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1728568);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I50mscorlib_System_Reflection_ParameterModifierTraitsE6InvokeEPF44mscorlib_System_Reflection_ParameterModifierPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP32[$ret>>2] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2433320,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m__ctorP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m_System_Collections_IEnumerator_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1731168)|0);
 $0 = HEAP32[((1731168 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m_DisposeP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m_MoveNextP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1731168)|0);
 $0 = HEAP32[((1731168 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m__ctorP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL136mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m_System_Collections_IEnumerator_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1733432)|0);
 $0 = HEAP32[((1733432 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m_DisposeP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m_MoveNextP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1733432)|0);
 $0 = HEAP32[((1733432 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1735696)|0);
 $0 = HEAP32[((1735696 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1735696)|0);
 $0 = HEAP32[((1735696 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1737480);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1737528);
 __THREW__ = 0;
 invoke_vii(1483,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2682160|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2682160|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1737672);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(915,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1737576);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1737624);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I53UnityEngine_UnityEngine_SendMouseEvents_HitInfoTraitsE6InvokeEPF47UnityEngine_UnityEngine_SendMouseEvents_HitInfoPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2682160,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1740224)|0);
 $0 = HEAP32[((1740224 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1740224)|0);
 $0 = HEAP32[((1740224 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1742488)|0);
 $0 = HEAP32[((1742488 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1742488)|0);
 $0 = HEAP32[((1742488 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1744752)|0);
 $0 = HEAP32[((1744752 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1744752)|0);
 $0 = HEAP32[((1744752 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z162mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctor_mscorlib_System_VoidP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746296);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(384,($__this|0),10,(0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z140mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_InitP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpiP22mscorlib_System_Object($__this,$capacity,$hcp) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $hcp = $hcp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747160);
 __THREW__ = 0;
 invoke_v(335);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($capacity|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020592>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($hcp|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(1771832|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = HEAP32[((1771832 + 84|0))>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iii(2744,(0|0),($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $G_B5_0$0 = $19;
   } else {
    $G_B5_0$0 = $hcp;
   }
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = (($__this) + 40|0);
    HEAP32[$24>>2] = $G_B5_0$0;
    $25 = ($capacity|0)==(0);
    $26 = (Math_fround(($capacity|0)));
    $27 = $25 ? Math_fround(10.0) : $26;
    $28 = Math_fround($27 / Math_fround(0.899999976158142089843));
    $29 = (~~(($28)));
    $30 = (($29) + 1)|0;
    __THREW__ = 0;
    invoke_vii(1490,($__this|0),($30|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = (($__this) + 48|0);
     HEAP32[$33>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z223mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746344);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(384,($__this|0),10,($comparer|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z184mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746392);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(384,($__this|0),($capacity|0),(0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z179mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_ICollection_get_SyncRootP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746440);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z263mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746488);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z252mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746536);
 __THREW__ = 0;
 $0 = (invoke_ii(1311,($keyValuePair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(1312,($keyValuePair|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viiii(461,(1746584|0),($__this|0),($0|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z257mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746632);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(361,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z156mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ContainsKeyValuePairP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$pair) {
 $__this = $__this|0;
 $pair = $pair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747688);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(1311,($pair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiii(299,(1747592|0),($__this|0),($0|0),($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   if (!($3)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_ii(1335,(0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(1312,($pair|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP32[$V_0>>2]|0;
      __THREW__ = 0;
      $17 = (invoke_iiiii(304,(1773280|0),($8|0),($11|0),($16|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z255mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP119mscorlib_System_Collections_Generic_KeyValuePair_2U003CUnityEngine_EventU002CUnityEngine_TextEditor_TextEditOpU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746680);
 __THREW__ = 0;
 invoke_viii(386,($__this|0),($_____array|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z142mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_CopyToP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP119mscorlib_System_Collections_Generic_KeyValuePair_2U003CUnityEngine_EventU002CUnityEngine_TextEditor_TextEditOpU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747352);
 __THREW__ = 0;
 invoke_viii(385,($__this|0),($_____array|0),($index|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1770312|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(1770312|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    HEAP32[$0>>2] = 1746920;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viii(394,($5|0),(0|0),($$byval_copy|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_viiii(287,($__this|0),($_____array|0),($index|0),($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z255mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746728);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(361,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  if (!($11)) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $16 = (invoke_ii(1311,($keyValuePair|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iiii(1640,(1746776|0),($__this|0),($16|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z173mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_ICollection_CopyToP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746824);
 __THREW__ = 0;
 (invoke_ii(2996,(1183944|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($_____array|0),(1183944|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if (!($7)) {
     __THREW__ = 0;
     invoke_viii(386,($__this|0),($4|0),($index|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_viii(385,($__this|0),($_____array|0),($index|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     (invoke_ii(2996,(1171160|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_iii(2735,($_____array|0),(1171160|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = ($16|0)==(0|0);
       if ($19) {
        __THREW__ = 0;
        (invoke_ii(2996,(1770312|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_ii(3469,(1770312|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        HEAP32[$1>>2] = 1746920;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_viii(394,($48|0),(0|0),($$byval_copy1|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
        __THREW__ = 0;
        invoke_viiii(285,($__this|0),($_____array|0),($index|0),($48|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1750352|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = HEAP32[((1750352 + 80|0))>>2]|0;
        $23 = (($22) + 16|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = ($24|0)==(0|0);
        if ($25) {
         __THREW__ = 0;
         (invoke_ii(2996,(1769736|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         __THREW__ = 0;
         $28 = (invoke_ii(3469,(1769736|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         HEAP32[$0>>2] = 1746872;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_viii(392,($28|0),(0|0),($$byval_copy1|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1750352|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         $35 = HEAP32[((1750352 + 80|0))>>2]|0;
         $36 = (($35) + 16|0);
         HEAP32[$36>>2] = $28;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1750352|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = HEAP32[((1750352 + 80|0))>>2]|0;
         $40 = (($39) + 16|0);
         $41 = HEAP32[$40>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          __THREW__ = 0;
          invoke_viiii(284,($__this|0),($16|0),($index|0),($41|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if (!($45)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z147mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_CopyToCheckP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747256);
 __THREW__ = 0;
 invoke_v(336);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020608>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)>(-1);
   if (!($15)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3020616>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_ii(1857,($_____array|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $31 = ($28|0)<($index|0);
     if ($31) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2560072|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = HEAP32[3020624>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($34|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3819,($34|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      $44 = (invoke_ii(1857,($_____array|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       __THREW__ = 0;
       $47 = (invoke_iii(2729,(1747064|0),($__this|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        $50 = (($44) - ($index))|0;
        $51 = ($50|0)<($47|0);
        if (!($51)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if (!($53)) {
         __THREW__ = 0;
         $54 = (invoke_ii(3469,(2560072|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          $57 = HEAP32[3020632>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($54|0),($57|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           __THREW__ = 0;
           invoke_vi(3819,($54|0));
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if (!($61)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z262mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746968);
 ;HEAP32[$L_0+0>>2]=0|0;HEAP32[$L_0+4>>2]=0|0;HEAP32[$L_0+8>>2]=0|0;HEAP32[$L_0+12>>2]=0|0;HEAP32[$L_0+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1502,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1768528|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1768528|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z180mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IDictionary_GetEnumeratorP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747016);
 __THREW__ = 0;
 (invoke_ii(2996,(1770880|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1770880|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1505,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z145mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CountP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747064);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z144mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_set_ItemP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_2$2 = 0, $V_2$3 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $V_3$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747112);
 __THREW__ = 0;
 invoke_v(334);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3020568>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iiii(1652,(1760456|0),($18|0),($key|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = $21 | -2147483648;
     $25 = $21 & 2147483647;
     $26 = (($__this) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($27|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = (($27) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($25|0) % ($31|0))&-1;
      $33 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = (($33) + 12|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($32>>>0)<($37>>>0);
       if (!($38)) {
        __THREW__ = 0;
        $39 = (invoke_i(132)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($39|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
       }
       $44 = HEAP32[$33>>2]|0;
       $45 = (($33) + 16|0);
       $46 = (($44) + 92|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = Math_imul($47, $32)|0;
       $49 = (($45) + ($48)|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = (($50) + -1)|0;
       $52 = ($50|0)==(0);
       L18: do {
        if ($52) {
         $V_2$1 = $51;$V_3$1 = -1;
         label = 40;
        } else {
         $53 = (($__this) + 12|0);
         $54 = (($__this) + 16|0);
         $V_2$0 = $51;$V_3$0 = -1;
         while(1) {
          $55 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($55|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          $58 = ($V_2$0|0)<(0);
          if ($58) {
           label = 23;
          } else {
           $59 = (($55) + 12|0);
           $60 = HEAP32[$59>>2]|0;
           $61 = ($V_2$0>>>0)<($60>>>0);
           if (!($61)) {
            label = 23;
           }
          }
          if ((label|0) == 23) {
           label = 0;
           __THREW__ = 0;
           $62 = (invoke_i(132)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($62|0));
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if ($66) {
            break;
           }
          }
          $67 = HEAP32[$55>>2]|0;
          $68 = (($55) + 16|0);
          $69 = (($67) + 92|0);
          $70 = HEAP32[$69>>2]|0;
          $71 = Math_imul($70, $V_2$0)|0;
          $72 = (($68) + ($71)|0);
          $73 = HEAP32[$72>>2]|0;
          $74 = ($73|0)==($24|0);
          if ($74) {
           $75 = HEAP32[$17>>2]|0;
           $76 = HEAP32[$54>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($76|0));
           $77 = __THREW__; __THREW__ = 0;
           $78 = $77&1;
           if ($78) {
            break;
           }
           if ($58) {
            label = 29;
           } else {
            $79 = (($76) + 12|0);
            $80 = HEAP32[$79>>2]|0;
            $81 = ($V_2$0>>>0)<($80>>>0);
            if (!($81)) {
             label = 29;
            }
           }
           if ((label|0) == 29) {
            label = 0;
            __THREW__ = 0;
            $82 = (invoke_i(132)|0);
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if ($84) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($82|0));
            $85 = __THREW__; __THREW__ = 0;
            $86 = $85&1;
            if ($86) {
             break;
            }
           }
           $87 = HEAP32[$76>>2]|0;
           $88 = (($76) + 16|0);
           $89 = (($87) + 92|0);
           $90 = HEAP32[$89>>2]|0;
           $91 = Math_imul($90, $V_2$0)|0;
           $92 = (($88) + ($91)|0);
           $93 = HEAP32[$92>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($75|0));
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if ($95) {
            break;
           }
           __THREW__ = 0;
           $96 = (invoke_iiiii(305,(1760376|0),($75|0),($93|0),($key|0))|0);
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if ($98) {
            break;
           }
           if ($96) {
            $V_2$1 = $V_2$0;$V_3$1 = $V_3$0;
            label = 40;
            break L18;
           }
          }
          $99 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($99|0));
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          if ($58) {
           label = 37;
          } else {
           $102 = (($99) + 12|0);
           $103 = HEAP32[$102>>2]|0;
           $104 = ($V_2$0>>>0)<($103>>>0);
           if (!($104)) {
            label = 37;
           }
          }
          if ((label|0) == 37) {
           label = 0;
           __THREW__ = 0;
           $105 = (invoke_i(132)|0);
           $106 = __THREW__; __THREW__ = 0;
           $107 = $106&1;
           if ($107) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($105|0));
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            break;
           }
          }
          $110 = HEAP32[$99>>2]|0;
          $111 = (($99) + 16|0);
          $112 = (($110) + 92|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = Math_imul($113, $V_2$0)|0;
          $$sum = (($114) + 4)|0;
          $115 = (($111) + ($$sum)|0);
          $116 = HEAP32[$115>>2]|0;
          $117 = ($116|0)==(-1);
          if ($117) {
           label = 41;
           break L18;
          } else {
           $V_3$0$phi = $V_2$0;$V_2$0 = $116;$V_3$0 = $V_3$0$phi;
          }
         }
         $3 = ___cxa_find_matching_catch()|0;
         $4 = tempRet0;
         $lpad$phi$index = $3;$lpad$phi$index2 = $4;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
       } while(0);
       if ((label|0) == 40) {
        $118 = ($V_2$1|0)==(-1);
        if ($118) {
         label = 41;
        } else {
         $257 = ($V_3$1|0)==(-1);
         if ($257) {
          $V_2$3 = $V_2$1;
         } else {
          $258 = (($__this) + 12|0);
          $259 = HEAP32[$258>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($259|0));
          $260 = __THREW__; __THREW__ = 0;
          $261 = $260&1;
          if ($261) {
           break;
          }
          $262 = ($V_3$1|0)<(0);
          if ($262) {
           label = 85;
          } else {
           $263 = (($259) + 12|0);
           $264 = HEAP32[$263>>2]|0;
           $265 = ($V_3$1>>>0)<($264>>>0);
           if (!($265)) {
            label = 85;
           }
          }
          if ((label|0) == 85) {
           __THREW__ = 0;
           $266 = (invoke_i(132)|0);
           $267 = __THREW__; __THREW__ = 0;
           $268 = $267&1;
           if ($268) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($266|0));
           $269 = __THREW__; __THREW__ = 0;
           $270 = $269&1;
           if ($270) {
            break;
           }
          }
          $271 = HEAP32[$259>>2]|0;
          $272 = (($259) + 16|0);
          $273 = (($271) + 92|0);
          $274 = HEAP32[$273>>2]|0;
          $275 = Math_imul($274, $V_3$1)|0;
          $276 = HEAP32[$258>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($276|0));
          $277 = __THREW__; __THREW__ = 0;
          $278 = $277&1;
          if ($278) {
           break;
          }
          $279 = ($V_2$1|0)<(0);
          if ($279) {
           label = 90;
          } else {
           $280 = (($276) + 12|0);
           $281 = HEAP32[$280>>2]|0;
           $282 = ($V_2$1>>>0)<($281>>>0);
           if (!($282)) {
            label = 90;
           }
          }
          if ((label|0) == 90) {
           __THREW__ = 0;
           $283 = (invoke_i(132)|0);
           $284 = __THREW__; __THREW__ = 0;
           $285 = $284&1;
           if ($285) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($283|0));
           $286 = __THREW__; __THREW__ = 0;
           $287 = $286&1;
           if ($287) {
            break;
           }
          }
          $288 = HEAP32[$276>>2]|0;
          $289 = (($276) + 16|0);
          $290 = (($288) + 92|0);
          $291 = HEAP32[$290>>2]|0;
          $292 = Math_imul($291, $V_2$1)|0;
          $$sum3 = (($292) + 4)|0;
          $293 = (($289) + ($$sum3)|0);
          $294 = HEAP32[$293>>2]|0;
          $$sum4 = (($275) + 4)|0;
          $295 = (($272) + ($$sum4)|0);
          HEAP32[$295>>2] = $294;
          $296 = HEAP32[$258>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($296|0));
          $297 = __THREW__; __THREW__ = 0;
          $298 = $297&1;
          if ($298) {
           break;
          }
          if ($279) {
           label = 95;
          } else {
           $299 = (($296) + 12|0);
           $300 = HEAP32[$299>>2]|0;
           $301 = ($V_2$1>>>0)<($300>>>0);
           if (!($301)) {
            label = 95;
           }
          }
          if ((label|0) == 95) {
           __THREW__ = 0;
           $302 = (invoke_i(132)|0);
           $303 = __THREW__; __THREW__ = 0;
           $304 = $303&1;
           if ($304) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($302|0));
           $305 = __THREW__; __THREW__ = 0;
           $306 = $305&1;
           if ($306) {
            break;
           }
          }
          $307 = HEAP32[$296>>2]|0;
          $308 = (($296) + 16|0);
          $309 = (($307) + 92|0);
          $310 = HEAP32[$309>>2]|0;
          $311 = Math_imul($310, $V_2$1)|0;
          $312 = HEAP32[$26>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($312|0));
          $313 = __THREW__; __THREW__ = 0;
          $314 = $313&1;
          if ($314) {
           break;
          }
          $315 = (($312) + 12|0);
          $316 = HEAP32[$315>>2]|0;
          $317 = ($32>>>0)<($316>>>0);
          if (!($317)) {
           __THREW__ = 0;
           $318 = (invoke_i(132)|0);
           $319 = __THREW__; __THREW__ = 0;
           $320 = $319&1;
           if ($320) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($318|0));
           $321 = __THREW__; __THREW__ = 0;
           $322 = $321&1;
           if ($322) {
            break;
           }
          }
          $323 = HEAP32[$312>>2]|0;
          $324 = (($312) + 16|0);
          $325 = (($323) + 92|0);
          $326 = HEAP32[$325>>2]|0;
          $327 = Math_imul($326, $32)|0;
          $328 = (($324) + ($327)|0);
          $329 = HEAP32[$328>>2]|0;
          $330 = (($329) + -1)|0;
          $$sum5 = (($311) + 4)|0;
          $331 = (($308) + ($$sum5)|0);
          HEAP32[$331>>2] = $330;
          $332 = HEAP32[$26>>2]|0;
          $333 = (($V_2$1) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($332|0));
          $334 = __THREW__; __THREW__ = 0;
          $335 = $334&1;
          if ($335) {
           break;
          }
          $336 = (($332) + 12|0);
          $337 = HEAP32[$336>>2]|0;
          $338 = ($32>>>0)<($337>>>0);
          if (!($338)) {
           __THREW__ = 0;
           $339 = (invoke_i(132)|0);
           $340 = __THREW__; __THREW__ = 0;
           $341 = $340&1;
           if ($341) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($339|0));
           $342 = __THREW__; __THREW__ = 0;
           $343 = $342&1;
           if ($343) {
            break;
           }
          }
          $344 = HEAP32[$332>>2]|0;
          $345 = (($332) + 16|0);
          $346 = (($344) + 92|0);
          $347 = HEAP32[$346>>2]|0;
          $348 = Math_imul($347, $32)|0;
          $349 = (($345) + ($348)|0);
          HEAP32[$349>>2] = $333;
          $V_2$3 = $V_2$1;
         }
        }
       }
       if ((label|0) == 41) {
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         break;
        }
        $121 = (($__this) + 32|0);
        $122 = HEAP32[$121>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if ($124) {
         break;
        }
        $125 = (($122) + 1)|0;
        HEAP32[$121>>2] = $125;
        $126 = (($__this) + 36|0);
        $127 = HEAP32[$126>>2]|0;
        $128 = ($122|0)<($127|0);
        if ($128) {
         $V_1$0 = $32;
        } else {
         __THREW__ = 0;
         invoke_vi(1705,($__this|0));
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          break;
         }
         $131 = HEAP32[$26>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($131|0));
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          break;
         }
         $134 = (($131) + 12|0);
         $135 = HEAP32[$134>>2]|0;
         $136 = (($25|0) % ($135|0))&-1;
         $V_1$0 = $136;
        }
        $137 = (($__this) + 28|0);
        $138 = HEAP32[$137>>2]|0;
        $139 = ($138|0)==(-1);
        if ($139) {
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $140 = __THREW__; __THREW__ = 0;
         $141 = $140&1;
         if ($141) {
          break;
         }
         $142 = (($__this) + 24|0);
         $143 = HEAP32[$142>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if ($145) {
          break;
         }
         $146 = (($143) + 1)|0;
         HEAP32[$142>>2] = $146;
         $$pre = (($__this) + 12|0);
         $$pre$phiZ2D = $$pre;$V_2$2 = $143;
        } else {
         $147 = (($__this) + 12|0);
         $148 = HEAP32[$147>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($148|0));
         $149 = __THREW__; __THREW__ = 0;
         $150 = $149&1;
         if ($150) {
          break;
         }
         $151 = ($138|0)<(0);
         if ($151) {
          label = 54;
         } else {
          $152 = (($148) + 12|0);
          $153 = HEAP32[$152>>2]|0;
          $154 = ($138>>>0)<($153>>>0);
          if (!($154)) {
           label = 54;
          }
         }
         if ((label|0) == 54) {
          __THREW__ = 0;
          $155 = (invoke_i(132)|0);
          $156 = __THREW__; __THREW__ = 0;
          $157 = $156&1;
          if ($157) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($155|0));
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           break;
          }
         }
         $160 = HEAP32[$148>>2]|0;
         $161 = (($148) + 16|0);
         $162 = (($160) + 92|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = Math_imul($163, $138)|0;
         $$sum1 = (($164) + 4)|0;
         $165 = (($161) + ($$sum1)|0);
         $166 = HEAP32[$165>>2]|0;
         HEAP32[$137>>2] = $166;
         $$pre$phiZ2D = $147;$V_2$2 = $138;
        }
        $167 = HEAP32[$$pre$phiZ2D>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($167|0));
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         break;
        }
        $170 = ($V_2$2|0)<(0);
        if ($170) {
         label = 60;
        } else {
         $171 = (($167) + 12|0);
         $172 = HEAP32[$171>>2]|0;
         $173 = ($V_2$2>>>0)<($172>>>0);
         if (!($173)) {
          label = 60;
         }
        }
        if ((label|0) == 60) {
         __THREW__ = 0;
         $174 = (invoke_i(132)|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($174|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          break;
         }
        }
        $179 = HEAP32[$167>>2]|0;
        $180 = (($167) + 16|0);
        $181 = (($179) + 92|0);
        $182 = HEAP32[$181>>2]|0;
        $183 = Math_imul($182, $V_2$2)|0;
        $184 = HEAP32[$26>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($184|0));
        $185 = __THREW__; __THREW__ = 0;
        $186 = $185&1;
        if ($186) {
         break;
        }
        $187 = (($184) + 12|0);
        $188 = HEAP32[$187>>2]|0;
        $189 = ($V_1$0>>>0)<($188>>>0);
        if (!($189)) {
         __THREW__ = 0;
         $190 = (invoke_i(132)|0);
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($190|0));
         $193 = __THREW__; __THREW__ = 0;
         $194 = $193&1;
         if ($194) {
          break;
         }
        }
        $195 = HEAP32[$184>>2]|0;
        $196 = (($184) + 16|0);
        $197 = (($195) + 92|0);
        $198 = HEAP32[$197>>2]|0;
        $199 = Math_imul($198, $V_1$0)|0;
        $200 = (($196) + ($199)|0);
        $201 = HEAP32[$200>>2]|0;
        $202 = (($201) + -1)|0;
        $$sum2 = (($183) + 4)|0;
        $203 = (($180) + ($$sum2)|0);
        HEAP32[$203>>2] = $202;
        $204 = HEAP32[$26>>2]|0;
        $205 = (($V_2$2) + 1)|0;
        __THREW__ = 0;
        invoke_vi(3799,($204|0));
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         break;
        }
        $208 = (($204) + 12|0);
        $209 = HEAP32[$208>>2]|0;
        $210 = ($V_1$0>>>0)<($209>>>0);
        if (!($210)) {
         __THREW__ = 0;
         $211 = (invoke_i(132)|0);
         $212 = __THREW__; __THREW__ = 0;
         $213 = $212&1;
         if ($213) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($211|0));
         $214 = __THREW__; __THREW__ = 0;
         $215 = $214&1;
         if ($215) {
          break;
         }
        }
        $216 = HEAP32[$204>>2]|0;
        $217 = (($204) + 16|0);
        $218 = (($216) + 92|0);
        $219 = HEAP32[$218>>2]|0;
        $220 = Math_imul($219, $V_1$0)|0;
        $221 = (($217) + ($220)|0);
        HEAP32[$221>>2] = $205;
        $222 = HEAP32[$$pre$phiZ2D>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($222|0));
        $223 = __THREW__; __THREW__ = 0;
        $224 = $223&1;
        if ($224) {
         break;
        }
        if ($170) {
         label = 73;
        } else {
         $225 = (($222) + 12|0);
         $226 = HEAP32[$225>>2]|0;
         $227 = ($V_2$2>>>0)<($226>>>0);
         if (!($227)) {
          label = 73;
         }
        }
        if ((label|0) == 73) {
         __THREW__ = 0;
         $228 = (invoke_i(132)|0);
         $229 = __THREW__; __THREW__ = 0;
         $230 = $229&1;
         if ($230) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($228|0));
         $231 = __THREW__; __THREW__ = 0;
         $232 = $231&1;
         if ($232) {
          break;
         }
        }
        $233 = HEAP32[$222>>2]|0;
        $234 = (($222) + 16|0);
        $235 = (($233) + 92|0);
        $236 = HEAP32[$235>>2]|0;
        $237 = Math_imul($236, $V_2$2)|0;
        $238 = (($234) + ($237)|0);
        HEAP32[$238>>2] = $24;
        $239 = (($__this) + 16|0);
        $240 = HEAP32[$239>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($240|0));
        $241 = __THREW__; __THREW__ = 0;
        $242 = $241&1;
        if ($242) {
         break;
        }
        if ($170) {
         label = 78;
        } else {
         $243 = (($240) + 12|0);
         $244 = HEAP32[$243>>2]|0;
         $245 = ($V_2$2>>>0)<($244>>>0);
         if (!($245)) {
          label = 78;
         }
        }
        if ((label|0) == 78) {
         __THREW__ = 0;
         $246 = (invoke_i(132)|0);
         $247 = __THREW__; __THREW__ = 0;
         $248 = $247&1;
         if ($248) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($246|0));
         $249 = __THREW__; __THREW__ = 0;
         $250 = $249&1;
         if ($250) {
          break;
         }
        }
        $251 = HEAP32[$240>>2]|0;
        $252 = (($240) + 16|0);
        $253 = (($251) + 92|0);
        $254 = HEAP32[$253>>2]|0;
        $255 = Math_imul($254, $V_2$2)|0;
        $256 = (($252) + ($255)|0);
        HEAP32[$256>>2] = $key;
        $V_2$3 = $V_2$2;
       }
       $350 = (($__this) + 20|0);
       $351 = HEAP32[$350>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($351|0));
       $352 = __THREW__; __THREW__ = 0;
       $353 = $352&1;
       if (!($353)) {
        $354 = ($V_2$3|0)<(0);
        if ($354) {
         label = 109;
        } else {
         $355 = (($351) + 12|0);
         $356 = HEAP32[$355>>2]|0;
         $357 = ($V_2$3>>>0)<($356>>>0);
         if (!($357)) {
          label = 109;
         }
        }
        if ((label|0) == 109) {
         __THREW__ = 0;
         $358 = (invoke_i(132)|0);
         $359 = __THREW__; __THREW__ = 0;
         $360 = $359&1;
         if ($360) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($358|0));
         $361 = __THREW__; __THREW__ = 0;
         $362 = $361&1;
         if ($362) {
          break;
         }
        }
        $363 = HEAP32[$351>>2]|0;
        $364 = (($351) + 16|0);
        $365 = (($363) + 92|0);
        $366 = HEAP32[$365>>2]|0;
        $367 = Math_imul($366, $V_2$3)|0;
        $368 = (($364) + ($367)|0);
        HEAP32[$368>>2] = $value;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $369 = __THREW__; __THREW__ = 0;
        $370 = $369&1;
        if (!($370)) {
         $371 = (($__this) + 48|0);
         $372 = HEAP32[$371>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $373 = __THREW__; __THREW__ = 0;
         $374 = $373&1;
         if (!($374)) {
          $375 = (($372) + 1)|0;
          HEAP32[$371>>2] = $375;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z142mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ResizeP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $$sum = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $V_4$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747400);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5 << 1;
   $7 = $6 | 1;
   __THREW__ = 0;
   $8 = (invoke_iii(835,(0|0),($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1170368|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_iii(2747,(1170368|0),($8|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(1170744|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_iii(2747,(1170744|0),($8|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $21 = (($18) + 16|0);
        $22 = (($__this) + 40|0);
        $23 = (($__this) + 16|0);
        $24 = (($13) + 12|0);
        $25 = (($13) + 16|0);
        $26 = (($__this) + 12|0);
        $27 = (($18) + 12|0);
        $V_3$0 = 0;
        L8: while(1) {
         $159 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($159|0));
         $160 = __THREW__; __THREW__ = 0;
         $161 = $160&1;
         if ($161) {
          label = 9;
          break;
         }
         $162 = (($159) + 12|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = ($V_3$0|0)<($163|0);
         if (!($164)) {
          label = 52;
          break;
         }
         $35 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($35|0));
         $165 = __THREW__; __THREW__ = 0;
         $166 = $165&1;
         if ($166) {
          label = 9;
          break;
         }
         $34 = (($35) + 12|0);
         $36 = HEAP32[$34>>2]|0;
         $37 = ($V_3$0>>>0)<($36>>>0);
         if (!($37)) {
          __THREW__ = 0;
          $38 = (invoke_i(132)|0);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           label = 9;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($38|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           label = 9;
           break;
          }
         }
         $43 = HEAP32[$35>>2]|0;
         $44 = (($35) + 16|0);
         $45 = (($43) + 92|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = Math_imul($46, $V_3$0)|0;
         $48 = (($44) + ($47)|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ($49|0)==(0);
         if (!($50)) {
          $51 = (($49) + -1)|0;
          $V_4$05 = $51;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($18|0));
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            label = 8;
            break L8;
           }
           $52 = ($V_4$05|0)<(0);
           if ($52) {
            label = 19;
           } else {
            $53 = HEAP32[$27>>2]|0;
            $54 = ($V_4$05>>>0)<($53>>>0);
            if (!($54)) {
             label = 19;
            }
           }
           if ((label|0) == 19) {
            label = 0;
            __THREW__ = 0;
            $55 = (invoke_i(132)|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($55|0));
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             label = 8;
             break L8;
            }
           }
           $60 = HEAP32[$18>>2]|0;
           $61 = (($60) + 92|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = Math_imul($62, $V_4$05)|0;
           $64 = (($21) + ($63)|0);
           $65 = HEAP32[$22>>2]|0;
           $66 = HEAP32[$23>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($66|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 24;
           } else {
            $69 = (($66) + 12|0);
            $70 = HEAP32[$69>>2]|0;
            $71 = ($V_4$05>>>0)<($70>>>0);
            if (!($71)) {
             label = 24;
            }
           }
           if ((label|0) == 24) {
            label = 0;
            __THREW__ = 0;
            $72 = (invoke_i(132)|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($72|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 8;
             break L8;
            }
           }
           $77 = HEAP32[$66>>2]|0;
           $78 = (($66) + 16|0);
           $79 = (($77) + 92|0);
           $80 = HEAP32[$79>>2]|0;
           $81 = Math_imul($80, $V_4$05)|0;
           $82 = (($78) + ($81)|0);
           $83 = HEAP32[$82>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($65|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            label = 8;
            break L8;
           }
           __THREW__ = 0;
           $86 = (invoke_iiii(1652,(1760456|0),($65|0),($83|0))|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            label = 8;
            break L8;
           }
           $89 = $86 | -2147483648;
           HEAP32[$64>>2] = $89;
           $90 = $86 & 2147483647;
           $91 = (($90|0) % ($8|0))&-1;
           __THREW__ = 0;
           invoke_vi(3799,($18|0));
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 31;
           } else {
            $94 = HEAP32[$27>>2]|0;
            $95 = ($V_4$05>>>0)<($94>>>0);
            if (!($95)) {
             label = 31;
            }
           }
           if ((label|0) == 31) {
            label = 0;
            __THREW__ = 0;
            $96 = (invoke_i(132)|0);
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($96|0));
            $99 = __THREW__; __THREW__ = 0;
            $100 = $99&1;
            if ($100) {
             label = 8;
             break L8;
            }
           }
           $101 = HEAP32[$18>>2]|0;
           $102 = (($101) + 92|0);
           $103 = HEAP32[$102>>2]|0;
           $104 = Math_imul($103, $V_4$05)|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            label = 8;
            break L8;
           }
           $107 = HEAP32[$24>>2]|0;
           $108 = ($91>>>0)<($107>>>0);
           if (!($108)) {
            __THREW__ = 0;
            $109 = (invoke_i(132)|0);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if ($111) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($109|0));
            $112 = __THREW__; __THREW__ = 0;
            $113 = $112&1;
            if ($113) {
             label = 8;
             break L8;
            }
           }
           $114 = HEAP32[$13>>2]|0;
           $115 = (($114) + 92|0);
           $116 = HEAP32[$115>>2]|0;
           $117 = Math_imul($116, $91)|0;
           $118 = (($25) + ($117)|0);
           $119 = HEAP32[$118>>2]|0;
           $120 = (($119) + -1)|0;
           $$sum = (($104) + 4)|0;
           $121 = (($21) + ($$sum)|0);
           HEAP32[$121>>2] = $120;
           $122 = (($V_4$05) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $123 = __THREW__; __THREW__ = 0;
           $124 = $123&1;
           if ($124) {
            label = 8;
            break L8;
           }
           $125 = HEAP32[$24>>2]|0;
           $126 = ($91>>>0)<($125>>>0);
           if (!($126)) {
            __THREW__ = 0;
            $127 = (invoke_i(132)|0);
            $128 = __THREW__; __THREW__ = 0;
            $129 = $128&1;
            if ($129) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($127|0));
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             label = 8;
             break L8;
            }
           }
           $132 = HEAP32[$13>>2]|0;
           $133 = (($132) + 92|0);
           $134 = HEAP32[$133>>2]|0;
           $135 = Math_imul($134, $91)|0;
           $136 = (($25) + ($135)|0);
           HEAP32[$136>>2] = $122;
           $137 = HEAP32[$26>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($137|0));
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 44;
           } else {
            $140 = (($137) + 12|0);
            $141 = HEAP32[$140>>2]|0;
            $142 = ($V_4$05>>>0)<($141>>>0);
            if (!($142)) {
             label = 44;
            }
           }
           if ((label|0) == 44) {
            label = 0;
            __THREW__ = 0;
            $143 = (invoke_i(132)|0);
            $144 = __THREW__; __THREW__ = 0;
            $145 = $144&1;
            if ($145) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($143|0));
            $146 = __THREW__; __THREW__ = 0;
            $147 = $146&1;
            if ($147) {
             label = 8;
             break L8;
            }
           }
           $148 = HEAP32[$137>>2]|0;
           $149 = (($137) + 16|0);
           $150 = (($148) + 92|0);
           $151 = HEAP32[$150>>2]|0;
           $152 = Math_imul($151, $V_4$05)|0;
           $$sum4 = (($152) + 4)|0;
           $153 = (($149) + ($$sum4)|0);
           $154 = HEAP32[$153>>2]|0;
           $155 = ($154|0)==(-1);
           if ($155) {
            break;
           } else {
            $V_4$05 = $154;
           }
          }
         }
         $158 = (($V_3$0) + 1)|0;
         $V_3$0 = $158;
        }
        if ((label|0) == 8) {
         $28 = ___cxa_find_matching_catch()|0;
         $29 = tempRet0;
         $lpad$phi$index = $28;$lpad$phi$index3 = $29;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 9) {
         $30 = ___cxa_find_matching_catch()|0;
         $31 = tempRet0;
         $lpad$phi$index = $30;$lpad$phi$index3 = $31;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 52) {
         HEAP32[$0>>2] = $13;
         HEAP32[$26>>2] = $18;
         __THREW__ = 0;
         (invoke_ii(2996,(1184320|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          break;
         }
         __THREW__ = 0;
         $169 = (invoke_iii(2747,(1184320|0),($8|0))|0);
         $170 = __THREW__; __THREW__ = 0;
         $171 = $170&1;
         if ($171) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1184704|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          break;
         }
         __THREW__ = 0;
         $174 = (invoke_iii(2747,(1184704|0),($8|0))|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          break;
         }
         $177 = HEAP32[$23>>2]|0;
         $178 = (($__this) + 24|0);
         $179 = HEAP32[$178>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($177|0),0,($169|0),0,($179|0));
         $180 = __THREW__; __THREW__ = 0;
         $181 = $180&1;
         if ($181) {
          break;
         }
         $182 = (($__this) + 20|0);
         $183 = HEAP32[$182>>2]|0;
         $184 = HEAP32[$178>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($183|0),0,($174|0),0,($184|0));
         $185 = __THREW__; __THREW__ = 0;
         $186 = $185&1;
         if ($186) {
          break;
         }
         HEAP32[$23>>2] = $169;
         HEAP32[$182>>2] = $174;
         $187 = (Math_fround(($8|0)));
         $188 = Math_fround($187 * Math_fround(0.899999976158142089843));
         $189 = (~~(($188)));
         $190 = (($__this) + 36|0);
         HEAP32[$190>>2] = $189;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 $lpad$phi$index = $32;$lpad$phi$index3 = $33;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z146mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_InitArraysP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747208);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2747,(1170368|0),($size|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $2;
   __THREW__ = 0;
   (invoke_ii(2996,(1170744|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2747,(1170744|0),($size|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($__this) + 12|0);
     HEAP32[$11>>2] = $8;
     $12 = (($__this) + 28|0);
     HEAP32[$12>>2] = -1;
     __THREW__ = 0;
     (invoke_ii(2996,(1184320|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_iii(2747,(1184320|0),($size|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = (($__this) + 16|0);
       HEAP32[$18>>2] = $15;
       __THREW__ = 0;
       (invoke_ii(2996,(1184704|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        $21 = (invoke_iii(2747,(1184704|0),($size|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         $24 = (($__this) + 20|0);
         HEAP32[$24>>2] = $21;
         $25 = (($__this) + 24|0);
         HEAP32[$25>>2] = 0;
         $26 = HEAP32[$5>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($26|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($26) + 12|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = (Math_fround(($30|0)));
          $32 = Math_fround($31 * Math_fround(0.899999976158142089843));
          $33 = (~~(($32)));
          $34 = (($__this) + 36|0);
          HEAP32[$34>>2] = $33;
          $35 = ($33|0)==(0);
          if (!($35)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          $38 = HEAP32[$5>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($38|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = (($38) + 12|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = ($42|0)<(1);
           if ($43) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           HEAP32[$34>>2] = 1;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($36|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj2609($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z145mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_make_pairP22mscorlib_System_ObjectP29UnityEngine_UnityEngine_Eventi($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746920);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(388,($agg$result|0),($key|0),($value|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z146mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_pick_valueP22mscorlib_System_ObjectP29UnityEngine_UnityEngine_Eventi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747304);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($value|0);
}
function __Z139mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_AddP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2$05 = 0, $V_2$1 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746584);
 __THREW__ = 0;
 invoke_v(337);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3020792>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iiii(1652,(1760456|0),($18|0),($key|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = $21 | -2147483648;
     $25 = $21 & 2147483647;
     $26 = (($__this) + 8|0);
     $27 = HEAP32[$26>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($27|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = (($27) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($25|0) % ($31|0))&-1;
      $33 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = (($33) + 12|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($32>>>0)<($37>>>0);
       if (!($38)) {
        __THREW__ = 0;
        $39 = (invoke_i(132)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($39|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
       }
       $44 = HEAP32[$33>>2]|0;
       $45 = (($33) + 16|0);
       $46 = (($44) + 92|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = Math_imul($47, $32)|0;
       $49 = (($45) + ($48)|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)==(0);
       L18: do {
        if (!($51)) {
         $52 = (($50) + -1)|0;
         $53 = (($__this) + 12|0);
         $54 = (($__this) + 16|0);
         $V_2$05 = $52;
         while(1) {
          $57 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($57|0));
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           label = 3;
           break;
          }
          $55 = ($V_2$05|0)<(0);
          if ($55) {
           label = 22;
          } else {
           $56 = (($57) + 12|0);
           $58 = HEAP32[$56>>2]|0;
           $59 = ($V_2$05>>>0)<($58>>>0);
           if (!($59)) {
            label = 22;
           }
          }
          if ((label|0) == 22) {
           label = 0;
           __THREW__ = 0;
           $60 = (invoke_i(132)|0);
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($60|0));
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            label = 3;
            break;
           }
          }
          $65 = HEAP32[$57>>2]|0;
          $66 = (($57) + 16|0);
          $67 = (($65) + 92|0);
          $68 = HEAP32[$67>>2]|0;
          $69 = Math_imul($68, $V_2$05)|0;
          $70 = (($66) + ($69)|0);
          $71 = HEAP32[$70>>2]|0;
          $72 = ($71|0)==($24|0);
          if ($72) {
           $73 = HEAP32[$17>>2]|0;
           $74 = HEAP32[$54>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($74|0));
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if ($76) {
            label = 3;
            break;
           }
           if ($55) {
            label = 28;
           } else {
            $77 = (($74) + 12|0);
            $78 = HEAP32[$77>>2]|0;
            $79 = ($V_2$05>>>0)<($78>>>0);
            if (!($79)) {
             label = 28;
            }
           }
           if ((label|0) == 28) {
            label = 0;
            __THREW__ = 0;
            $80 = (invoke_i(132)|0);
            $81 = __THREW__; __THREW__ = 0;
            $82 = $81&1;
            if ($82) {
             label = 3;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($80|0));
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if ($84) {
             label = 3;
             break;
            }
           }
           $85 = HEAP32[$74>>2]|0;
           $86 = (($74) + 16|0);
           $87 = (($85) + 92|0);
           $88 = HEAP32[$87>>2]|0;
           $89 = Math_imul($88, $V_2$05)|0;
           $90 = (($86) + ($89)|0);
           $91 = HEAP32[$90>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($73|0));
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           $94 = (invoke_iiiii(305,(1760376|0),($73|0),($91|0),($key|0))|0);
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if ($96) {
            label = 3;
            break;
           }
           if ($94) {
            break;
           }
          }
          $107 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($107|0));
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           label = 3;
           break;
          }
          if ($55) {
           label = 41;
          } else {
           $110 = (($107) + 12|0);
           $111 = HEAP32[$110>>2]|0;
           $112 = ($V_2$05>>>0)<($111>>>0);
           if (!($112)) {
            label = 41;
           }
          }
          if ((label|0) == 41) {
           label = 0;
           __THREW__ = 0;
           $113 = (invoke_i(132)|0);
           $114 = __THREW__; __THREW__ = 0;
           $115 = $114&1;
           if ($115) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($113|0));
           $116 = __THREW__; __THREW__ = 0;
           $117 = $116&1;
           if ($117) {
            label = 3;
            break;
           }
          }
          $118 = HEAP32[$107>>2]|0;
          $119 = (($107) + 16|0);
          $120 = (($118) + 92|0);
          $121 = HEAP32[$120>>2]|0;
          $122 = Math_imul($121, $V_2$05)|0;
          $$sum = (($122) + 4)|0;
          $123 = (($119) + ($$sum)|0);
          $124 = HEAP32[$123>>2]|0;
          $125 = ($124|0)==(-1);
          if ($125) {
           break L18;
          } else {
           $V_2$05 = $124;
          }
         }
         if ((label|0) == 3) {
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index2 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          break L1;
         }
         __THREW__ = 0;
         $99 = (invoke_ii(3469,(2560072|0))|0);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          break L1;
         }
         $102 = HEAP32[3020800>>2]|0;
         __THREW__ = 0;
         invoke_vii(1924,($99|0),($102|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3819,($99|0));
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          break L1;
         }
         // unreachable;
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if (!($129)) {
        $130 = (($__this) + 32|0);
        $131 = HEAP32[$130>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if (!($133)) {
         $134 = (($131) + 1)|0;
         HEAP32[$130>>2] = $134;
         $135 = (($__this) + 36|0);
         $136 = HEAP32[$135>>2]|0;
         $137 = ($131|0)<($136|0);
         if ($137) {
          $V_1$0 = $32;
         } else {
          __THREW__ = 0;
          invoke_vi(1705,($__this|0));
          $138 = __THREW__; __THREW__ = 0;
          $139 = $138&1;
          if ($139) {
           break;
          }
          $140 = HEAP32[$26>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($140|0));
          $141 = __THREW__; __THREW__ = 0;
          $142 = $141&1;
          if ($142) {
           break;
          }
          $143 = (($140) + 12|0);
          $144 = HEAP32[$143>>2]|0;
          $145 = (($25|0) % ($144|0))&-1;
          $V_1$0 = $145;
         }
         $146 = (($__this) + 28|0);
         $147 = HEAP32[$146>>2]|0;
         $148 = ($147|0)==(-1);
         if ($148) {
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $149 = __THREW__; __THREW__ = 0;
          $150 = $149&1;
          if ($150) {
           break;
          }
          $151 = (($__this) + 24|0);
          $152 = HEAP32[$151>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           break;
          }
          $155 = (($152) + 1)|0;
          HEAP32[$151>>2] = $155;
          $$pre = (($__this) + 12|0);
          $$pre$phiZ2D = $$pre;$V_2$1 = $152;
         } else {
          $156 = (($__this) + 12|0);
          $157 = HEAP32[$156>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($157|0));
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           break;
          }
          $160 = ($147|0)<(0);
          if ($160) {
           label = 58;
          } else {
           $161 = (($157) + 12|0);
           $162 = HEAP32[$161>>2]|0;
           $163 = ($147>>>0)<($162>>>0);
           if (!($163)) {
            label = 58;
           }
          }
          if ((label|0) == 58) {
           __THREW__ = 0;
           $164 = (invoke_i(132)|0);
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($164|0));
           $167 = __THREW__; __THREW__ = 0;
           $168 = $167&1;
           if ($168) {
            break;
           }
          }
          $169 = HEAP32[$157>>2]|0;
          $170 = (($157) + 16|0);
          $171 = (($169) + 92|0);
          $172 = HEAP32[$171>>2]|0;
          $173 = Math_imul($172, $147)|0;
          $$sum3 = (($173) + 4)|0;
          $174 = (($170) + ($$sum3)|0);
          $175 = HEAP32[$174>>2]|0;
          HEAP32[$146>>2] = $175;
          $$pre$phiZ2D = $156;$V_2$1 = $147;
         }
         $176 = HEAP32[$$pre$phiZ2D>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($176|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if (!($178)) {
          $179 = ($V_2$1|0)<(0);
          if ($179) {
           label = 64;
          } else {
           $180 = (($176) + 12|0);
           $181 = HEAP32[$180>>2]|0;
           $182 = ($V_2$1>>>0)<($181>>>0);
           if (!($182)) {
            label = 64;
           }
          }
          if ((label|0) == 64) {
           __THREW__ = 0;
           $183 = (invoke_i(132)|0);
           $184 = __THREW__; __THREW__ = 0;
           $185 = $184&1;
           if ($185) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($183|0));
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if ($187) {
            break;
           }
          }
          $188 = HEAP32[$176>>2]|0;
          $189 = (($176) + 16|0);
          $190 = (($188) + 92|0);
          $191 = HEAP32[$190>>2]|0;
          $192 = Math_imul($191, $V_2$1)|0;
          $193 = (($189) + ($192)|0);
          HEAP32[$193>>2] = $24;
          $194 = HEAP32[$$pre$phiZ2D>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($194|0));
          $195 = __THREW__; __THREW__ = 0;
          $196 = $195&1;
          if (!($196)) {
           if ($179) {
            label = 69;
           } else {
            $197 = (($194) + 12|0);
            $198 = HEAP32[$197>>2]|0;
            $199 = ($V_2$1>>>0)<($198>>>0);
            if (!($199)) {
             label = 69;
            }
           }
           if ((label|0) == 69) {
            __THREW__ = 0;
            $200 = (invoke_i(132)|0);
            $201 = __THREW__; __THREW__ = 0;
            $202 = $201&1;
            if ($202) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($200|0));
            $203 = __THREW__; __THREW__ = 0;
            $204 = $203&1;
            if ($204) {
             break;
            }
           }
           $205 = HEAP32[$194>>2]|0;
           $206 = (($194) + 16|0);
           $207 = (($205) + 92|0);
           $208 = HEAP32[$207>>2]|0;
           $209 = Math_imul($208, $V_2$1)|0;
           $210 = HEAP32[$26>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($210|0));
           $211 = __THREW__; __THREW__ = 0;
           $212 = $211&1;
           if (!($212)) {
            $213 = (($210) + 12|0);
            $214 = HEAP32[$213>>2]|0;
            $215 = ($V_1$0>>>0)<($214>>>0);
            if (!($215)) {
             __THREW__ = 0;
             $216 = (invoke_i(132)|0);
             $217 = __THREW__; __THREW__ = 0;
             $218 = $217&1;
             if ($218) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($216|0));
             $219 = __THREW__; __THREW__ = 0;
             $220 = $219&1;
             if ($220) {
              break;
             }
            }
            $221 = HEAP32[$210>>2]|0;
            $222 = (($210) + 16|0);
            $223 = (($221) + 92|0);
            $224 = HEAP32[$223>>2]|0;
            $225 = Math_imul($224, $V_1$0)|0;
            $226 = (($222) + ($225)|0);
            $227 = HEAP32[$226>>2]|0;
            $228 = (($227) + -1)|0;
            $$sum4 = (($209) + 4)|0;
            $229 = (($206) + ($$sum4)|0);
            HEAP32[$229>>2] = $228;
            $230 = HEAP32[$26>>2]|0;
            $231 = (($V_2$1) + 1)|0;
            __THREW__ = 0;
            invoke_vi(3799,($230|0));
            $232 = __THREW__; __THREW__ = 0;
            $233 = $232&1;
            if (!($233)) {
             $234 = (($230) + 12|0);
             $235 = HEAP32[$234>>2]|0;
             $236 = ($V_1$0>>>0)<($235>>>0);
             if (!($236)) {
              __THREW__ = 0;
              $237 = (invoke_i(132)|0);
              $238 = __THREW__; __THREW__ = 0;
              $239 = $238&1;
              if ($239) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($237|0));
              $240 = __THREW__; __THREW__ = 0;
              $241 = $240&1;
              if ($241) {
               break;
              }
             }
             $242 = HEAP32[$230>>2]|0;
             $243 = (($230) + 16|0);
             $244 = (($242) + 92|0);
             $245 = HEAP32[$244>>2]|0;
             $246 = Math_imul($245, $V_1$0)|0;
             $247 = (($243) + ($246)|0);
             HEAP32[$247>>2] = $231;
             $248 = (($__this) + 16|0);
             $249 = HEAP32[$248>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($249|0));
             $250 = __THREW__; __THREW__ = 0;
             $251 = $250&1;
             if ($251) {
              break;
             }
             if ($179) {
              label = 82;
             } else {
              $252 = (($249) + 12|0);
              $253 = HEAP32[$252>>2]|0;
              $254 = ($V_2$1>>>0)<($253>>>0);
              if (!($254)) {
               label = 82;
              }
             }
             if ((label|0) == 82) {
              __THREW__ = 0;
              $255 = (invoke_i(132)|0);
              $256 = __THREW__; __THREW__ = 0;
              $257 = $256&1;
              if ($257) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($255|0));
              $258 = __THREW__; __THREW__ = 0;
              $259 = $258&1;
              if ($259) {
               break;
              }
             }
             $260 = HEAP32[$249>>2]|0;
             $261 = (($249) + 16|0);
             $262 = (($260) + 92|0);
             $263 = HEAP32[$262>>2]|0;
             $264 = Math_imul($263, $V_2$1)|0;
             $265 = (($261) + ($264)|0);
             HEAP32[$265>>2] = $key;
             $266 = (($__this) + 20|0);
             $267 = HEAP32[$266>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($267|0));
             $268 = __THREW__; __THREW__ = 0;
             $269 = $268&1;
             if ($269) {
              break;
             }
             if ($179) {
              label = 87;
             } else {
              $270 = (($267) + 12|0);
              $271 = HEAP32[$270>>2]|0;
              $272 = ($V_2$1>>>0)<($271>>>0);
              if (!($272)) {
               label = 87;
              }
             }
             if ((label|0) == 87) {
              __THREW__ = 0;
              $273 = (invoke_i(132)|0);
              $274 = __THREW__; __THREW__ = 0;
              $275 = $274&1;
              if ($275) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($273|0));
              $276 = __THREW__; __THREW__ = 0;
              $277 = $276&1;
              if ($277) {
               break;
              }
             }
             $278 = HEAP32[$267>>2]|0;
             $279 = (($267) + 16|0);
             $280 = (($278) + 92|0);
             $281 = HEAP32[$280>>2]|0;
             $282 = Math_imul($281, $V_2$1)|0;
             $283 = (($279) + ($282)|0);
             HEAP32[$283>>2] = $value;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $284 = __THREW__; __THREW__ = 0;
             $285 = $284&1;
             if ($285) {
              break;
             }
             $286 = (($__this) + 48|0);
             $287 = HEAP32[$286>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $288 = __THREW__; __THREW__ = 0;
             $289 = $288&1;
             if ($289) {
              break;
             }
             $290 = (($287) + 1)|0;
             HEAP32[$286>>2] = $290;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z141mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ClearP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747448);
 $0 = (($__this) + 32|0);
 HEAP32[$0>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($2) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($2|0),0,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = (($__this) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = (($10) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($10|0),0,($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = (($__this) + 20|0);
     $18 = HEAP32[$17>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($18) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      __THREW__ = 0;
      invoke_viiii(138,(0|0),($18|0),0,($22|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = (($__this) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $29 = (($26) + 12|0);
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        invoke_viiii(138,(0|0),($26|0),0,($30|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $33 = (($__this) + 28|0);
         HEAP32[$33>>2] = -1;
         $34 = (($__this) + 24|0);
         HEAP32[$34>>2] = 0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          $37 = (($__this) + 48|0);
          $38 = HEAP32[$37>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = (($38) + 1)|0;
           HEAP32[$37>>2] = $41;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($42|0);
 // unreachable;
}
function __Z149mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ContainsValueP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $V_1$0 = 0, $V_2$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747496);
 __THREW__ = 0;
 $0 = (invoke_ii(1335,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index3 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $3 = (($__this) + 8|0);
 $4 = (($__this) + 20|0);
 $5 = (($__this) + 12|0);
 $V_1$0 = 0;
 L5: while(1) {
  $74 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($74|0));
  $75 = __THREW__; __THREW__ = 0;
  $76 = $75&1;
  if ($76) {
   label = 4;
   break;
  }
  $77 = (($74) + 12|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($V_1$0|0)<($78|0);
  if (!($79)) {
   $$0 = 0;
   label = 30;
   break;
  }
  $13 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($13|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   label = 4;
   break;
  }
  $12 = (($13) + 12|0);
  $14 = HEAP32[$12>>2]|0;
  $15 = ($V_1$0>>>0)<($14>>>0);
  if (!($15)) {
   __THREW__ = 0;
   $16 = (invoke_i(132)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 4;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($16|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 4;
    break;
   }
  }
  $21 = HEAP32[$13>>2]|0;
  $22 = (($13) + 16|0);
  $23 = (($21) + 92|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = Math_imul($24, $V_1$0)|0;
  $26 = (($22) + ($25)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0);
  if (!($28)) {
   $29 = (($27) + -1)|0;
   $V_2$02 = $29;
   while(1) {
    $32 = HEAP32[$4>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     label = 3;
     break L5;
    }
    $30 = ($V_2$02|0)<(0);
    if ($30) {
     label = 14;
    } else {
     $31 = (($32) + 12|0);
     $33 = HEAP32[$31>>2]|0;
     $34 = ($V_2$02>>>0)<($33>>>0);
     if (!($34)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     __THREW__ = 0;
     $35 = (invoke_i(132)|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 3;
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3302,($35|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 3;
      break L5;
     }
    }
    $40 = HEAP32[$32>>2]|0;
    $41 = (($32) + 16|0);
    $42 = (($40) + 92|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = Math_imul($43, $V_2$02)|0;
    $45 = (($41) + ($44)|0);
    $46 = HEAP32[$45>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 3;
     break L5;
    }
    __THREW__ = 0;
    $49 = (invoke_iiiii(306,(1772752|0),($0|0),($46|0),($value|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 3;
     break L5;
    }
    if ($49) {
     $$0 = 1;
     label = 30;
     break L5;
    }
    $52 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($52|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 3;
     break L5;
    }
    if ($30) {
     label = 22;
    } else {
     $55 = (($52) + 12|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($V_2$02>>>0)<($56>>>0);
     if (!($57)) {
      label = 22;
     }
    }
    if ((label|0) == 22) {
     label = 0;
     __THREW__ = 0;
     $58 = (invoke_i(132)|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 3;
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3302,($58|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 3;
      break L5;
     }
    }
    $63 = HEAP32[$52>>2]|0;
    $64 = (($52) + 16|0);
    $65 = (($63) + 92|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = Math_imul($66, $V_2$02)|0;
    $$sum = (($67) + 4)|0;
    $68 = (($64) + ($$sum)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(-1);
    if ($70) {
     break;
    } else {
     $V_2$02 = $69;
    }
   }
  }
  $73 = (($V_1$0) + 1)|0;
  $V_1$0 = $73;
 }
 if ((label|0) == 3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $lpad$phi$index = $6;$lpad$phi$index3 = $7;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 4) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $lpad$phi$index = $8;$lpad$phi$index3 = $9;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z149mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_GetObjectDataP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747544);
 __THREW__ = 0;
 invoke_v(338);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020944>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 48|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3020952>>2]|0;
    __THREW__ = 0;
    invoke_viii(618,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 40|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[3020960>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($26|0),($23|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = (($__this) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)<(1);
       if ($31) {
        $V_0$0 = 0;
       } else {
        __THREW__ = 0;
        (invoke_ii(2996,(1183944|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2747,(1183944|0),($30|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(386,($__this|0),($34|0),0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        } else {
         $V_0$0 = $34;
        }
       }
       $39 = (($__this) + 8|0);
       $40 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($40|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        $43 = (($40) + 12|0);
        $44 = HEAP32[$43>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = HEAP32[3020968>>2]|0;
         __THREW__ = 0;
         invoke_viii(618,($info|0),($47|0),($44|0));
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if (!($49)) {
          __THREW__ = 0;
          invoke_vi(3799,($info|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if (!($51)) {
           $52 = HEAP32[3020976>>2]|0;
           __THREW__ = 0;
           invoke_viii(621,($info|0),($52|0),($V_0$0|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if (!($54)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z142mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_RemoveP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Event($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $$0 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746776);
 __THREW__ = 0;
 invoke_v(339);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021072>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iiii(1652,(1760456|0),($18|0),($key|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = $21 | -2147483648;
     $25 = (($__this) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = $21 & 2147483647;
      $30 = (($26) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($29|0) % ($31|0))&-1;
      $33 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = (($33) + 12|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = ($32>>>0)<($37>>>0);
       if (!($38)) {
        __THREW__ = 0;
        $39 = (invoke_i(132)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($39|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
       }
       $44 = HEAP32[$33>>2]|0;
       $45 = (($33) + 16|0);
       $46 = (($44) + 92|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = Math_imul($47, $32)|0;
       $49 = (($45) + ($48)|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = ($50|0)==(0);
       if ($51) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $52 = (($50) + -1)|0;
       $53 = (($__this) + 12|0);
       $54 = (($__this) + 16|0);
       $V_2$0 = $52;$V_3$0 = -1;
       while(1) {
        $55 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 3;
         break;
        }
        $58 = ($V_2$0|0)<(0);
        if ($58) {
         label = 23;
        } else {
         $59 = (($55) + 12|0);
         $60 = HEAP32[$59>>2]|0;
         $61 = ($V_2$0>>>0)<($60>>>0);
         if (!($61)) {
          label = 23;
         }
        }
        if ((label|0) == 23) {
         label = 0;
         __THREW__ = 0;
         $62 = (invoke_i(132)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($62|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          label = 3;
          break;
         }
        }
        $67 = HEAP32[$55>>2]|0;
        $68 = (($55) + 16|0);
        $69 = (($67) + 92|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = Math_imul($70, $V_2$0)|0;
        $72 = (($68) + ($71)|0);
        $73 = HEAP32[$72>>2]|0;
        $74 = ($73|0)==($24|0);
        if ($74) {
         $75 = HEAP32[$17>>2]|0;
         $76 = HEAP32[$54>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($76|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          label = 3;
          break;
         }
         if ($58) {
          label = 29;
         } else {
          $79 = (($76) + 12|0);
          $80 = HEAP32[$79>>2]|0;
          $81 = ($V_2$0>>>0)<($80>>>0);
          if (!($81)) {
           label = 29;
          }
         }
         if ((label|0) == 29) {
          label = 0;
          __THREW__ = 0;
          $82 = (invoke_i(132)|0);
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($82|0));
          $85 = __THREW__; __THREW__ = 0;
          $86 = $85&1;
          if ($86) {
           label = 3;
           break;
          }
         }
         $87 = HEAP32[$76>>2]|0;
         $88 = (($76) + 16|0);
         $89 = (($87) + 92|0);
         $90 = HEAP32[$89>>2]|0;
         $91 = Math_imul($90, $V_2$0)|0;
         $92 = (($88) + ($91)|0);
         $93 = HEAP32[$92>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($75|0));
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $96 = (invoke_iiiii(305,(1760376|0),($75|0),($93|0),($key|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          label = 3;
          break;
         }
         if ($96) {
          label = 40;
          break;
         }
        }
        $99 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($99|0));
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         label = 3;
         break;
        }
        if ($58) {
         label = 37;
        } else {
         $102 = (($99) + 12|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = ($V_2$0>>>0)<($103>>>0);
         if (!($104)) {
          label = 37;
         }
        }
        if ((label|0) == 37) {
         label = 0;
         __THREW__ = 0;
         $105 = (invoke_i(132)|0);
         $106 = __THREW__; __THREW__ = 0;
         $107 = $106&1;
         if ($107) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($105|0));
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          label = 3;
          break;
         }
        }
        $110 = HEAP32[$99>>2]|0;
        $111 = (($99) + 16|0);
        $112 = (($110) + 92|0);
        $113 = HEAP32[$112>>2]|0;
        $114 = Math_imul($113, $V_2$0)|0;
        $$sum = (($114) + 4)|0;
        $115 = (($111) + ($$sum)|0);
        $116 = HEAP32[$115>>2]|0;
        $117 = ($116|0)==(-1);
        if ($117) {
         $$0 = 0;
         label = 88;
         break;
        } else {
         $V_3$0$phi = $V_2$0;$V_2$0 = $116;$V_3$0 = $V_3$0$phi;
        }
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 40) {
        $118 = ($V_2$0|0)==(-1);
        if ($118) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         break;
        }
        $121 = (($__this) + 32|0);
        $122 = HEAP32[$121>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $123 = __THREW__; __THREW__ = 0;
        $124 = $123&1;
        if ($124) {
         break;
        }
        $125 = (($122) + -1)|0;
        HEAP32[$121>>2] = $125;
        $126 = ($V_3$0|0)==(-1);
        if ($126) {
         $127 = HEAP32[$25>>2]|0;
         $128 = HEAP32[$53>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($128|0));
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          break;
         }
         if ($58) {
          label = 47;
         } else {
          $131 = (($128) + 12|0);
          $132 = HEAP32[$131>>2]|0;
          $133 = ($V_2$0>>>0)<($132>>>0);
          if (!($133)) {
           label = 47;
          }
         }
         if ((label|0) == 47) {
          __THREW__ = 0;
          $134 = (invoke_i(132)|0);
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($134|0));
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if ($138) {
           break;
          }
         }
         $139 = HEAP32[$128>>2]|0;
         $140 = (($128) + 16|0);
         $141 = (($139) + 92|0);
         $142 = HEAP32[$141>>2]|0;
         $143 = Math_imul($142, $V_2$0)|0;
         $$sum5 = (($143) + 4)|0;
         $144 = (($140) + ($$sum5)|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = (($145) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($127|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          break;
         }
         $149 = (($127) + 12|0);
         $150 = HEAP32[$149>>2]|0;
         $151 = ($32>>>0)<($150>>>0);
         if (!($151)) {
          __THREW__ = 0;
          $152 = (invoke_i(132)|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($152|0));
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           break;
          }
         }
         $157 = HEAP32[$127>>2]|0;
         $158 = (($127) + 16|0);
         $159 = (($157) + 92|0);
         $160 = HEAP32[$159>>2]|0;
         $161 = Math_imul($160, $32)|0;
         $162 = (($158) + ($161)|0);
         HEAP32[$162>>2] = $146;
        } else {
         $163 = HEAP32[$53>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($163|0));
         $164 = __THREW__; __THREW__ = 0;
         $165 = $164&1;
         if ($165) {
          break;
         }
         $166 = ($V_3$0|0)<(0);
         if ($166) {
          label = 57;
         } else {
          $167 = (($163) + 12|0);
          $168 = HEAP32[$167>>2]|0;
          $169 = ($V_3$0>>>0)<($168>>>0);
          if (!($169)) {
           label = 57;
          }
         }
         if ((label|0) == 57) {
          __THREW__ = 0;
          $170 = (invoke_i(132)|0);
          $171 = __THREW__; __THREW__ = 0;
          $172 = $171&1;
          if ($172) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($170|0));
          $173 = __THREW__; __THREW__ = 0;
          $174 = $173&1;
          if ($174) {
           break;
          }
         }
         $175 = HEAP32[$163>>2]|0;
         $176 = (($163) + 16|0);
         $177 = (($175) + 92|0);
         $178 = HEAP32[$177>>2]|0;
         $179 = Math_imul($178, $V_3$0)|0;
         $180 = HEAP32[$53>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($180|0));
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if ($182) {
          break;
         }
         if ($58) {
          label = 62;
         } else {
          $183 = (($180) + 12|0);
          $184 = HEAP32[$183>>2]|0;
          $185 = ($V_2$0>>>0)<($184>>>0);
          if (!($185)) {
           label = 62;
          }
         }
         if ((label|0) == 62) {
          __THREW__ = 0;
          $186 = (invoke_i(132)|0);
          $187 = __THREW__; __THREW__ = 0;
          $188 = $187&1;
          if ($188) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($186|0));
          $189 = __THREW__; __THREW__ = 0;
          $190 = $189&1;
          if ($190) {
           break;
          }
         }
         $191 = HEAP32[$180>>2]|0;
         $192 = (($180) + 16|0);
         $193 = (($191) + 92|0);
         $194 = HEAP32[$193>>2]|0;
         $195 = Math_imul($194, $V_2$0)|0;
         $$sum2 = (($195) + 4)|0;
         $196 = (($192) + ($$sum2)|0);
         $197 = HEAP32[$196>>2]|0;
         $$sum3 = (($179) + 4)|0;
         $198 = (($176) + ($$sum3)|0);
         HEAP32[$198>>2] = $197;
        }
        $199 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($199|0));
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         break;
        }
        if ($58) {
         label = 68;
        } else {
         $202 = (($199) + 12|0);
         $203 = HEAP32[$202>>2]|0;
         $204 = ($V_2$0>>>0)<($203>>>0);
         if (!($204)) {
          label = 68;
         }
        }
        if ((label|0) == 68) {
         __THREW__ = 0;
         $205 = (invoke_i(132)|0);
         $206 = __THREW__; __THREW__ = 0;
         $207 = $206&1;
         if ($207) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($205|0));
         $208 = __THREW__; __THREW__ = 0;
         $209 = $208&1;
         if ($209) {
          break;
         }
        }
        $210 = HEAP32[$199>>2]|0;
        $211 = (($199) + 16|0);
        $212 = (($210) + 92|0);
        $213 = HEAP32[$212>>2]|0;
        $214 = Math_imul($213, $V_2$0)|0;
        $215 = (($__this) + 28|0);
        $216 = HEAP32[$215>>2]|0;
        $$sum4 = (($214) + 4)|0;
        $217 = (($211) + ($$sum4)|0);
        HEAP32[$217>>2] = $216;
        HEAP32[$215>>2] = $V_2$0;
        $218 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($218|0));
        $219 = __THREW__; __THREW__ = 0;
        $220 = $219&1;
        if ($220) {
         break;
        }
        if ($58) {
         label = 73;
        } else {
         $221 = (($218) + 12|0);
         $222 = HEAP32[$221>>2]|0;
         $223 = ($V_2$0>>>0)<($222>>>0);
         if (!($223)) {
          label = 73;
         }
        }
        if ((label|0) == 73) {
         __THREW__ = 0;
         $224 = (invoke_i(132)|0);
         $225 = __THREW__; __THREW__ = 0;
         $226 = $225&1;
         if ($226) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($224|0));
         $227 = __THREW__; __THREW__ = 0;
         $228 = $227&1;
         if ($228) {
          break;
         }
        }
        $229 = HEAP32[$218>>2]|0;
        $230 = (($218) + 16|0);
        $231 = (($229) + 92|0);
        $232 = HEAP32[$231>>2]|0;
        $233 = Math_imul($232, $V_2$0)|0;
        $234 = (($230) + ($233)|0);
        HEAP32[$234>>2] = 0;
        $235 = HEAP32[$54>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($235|0));
        $236 = __THREW__; __THREW__ = 0;
        $237 = $236&1;
        if ($237) {
         break;
        }
        if ($58) {
         label = 78;
        } else {
         $238 = (($235) + 12|0);
         $239 = HEAP32[$238>>2]|0;
         $240 = ($V_2$0>>>0)<($239>>>0);
         if (!($240)) {
          label = 78;
         }
        }
        if ((label|0) == 78) {
         __THREW__ = 0;
         $241 = (invoke_i(132)|0);
         $242 = __THREW__; __THREW__ = 0;
         $243 = $242&1;
         if ($243) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($241|0));
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if ($245) {
          break;
         }
        }
        $246 = HEAP32[$235>>2]|0;
        $247 = (($235) + 16|0);
        $248 = (($246) + 92|0);
        $249 = HEAP32[$248>>2]|0;
        $250 = Math_imul($249, $V_2$0)|0;
        $251 = (($247) + ($250)|0);
        HEAP32[$251>>2] = 0;
        $252 = (($__this) + 20|0);
        $253 = HEAP32[$252>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($253|0));
        $254 = __THREW__; __THREW__ = 0;
        $255 = $254&1;
        if ($255) {
         break;
        }
        if ($58) {
         label = 83;
        } else {
         $256 = (($253) + 12|0);
         $257 = HEAP32[$256>>2]|0;
         $258 = ($V_2$0>>>0)<($257>>>0);
         if (!($258)) {
          label = 83;
         }
        }
        if ((label|0) == 83) {
         __THREW__ = 0;
         $259 = (invoke_i(132)|0);
         $260 = __THREW__; __THREW__ = 0;
         $261 = $260&1;
         if ($261) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($259|0));
         $262 = __THREW__; __THREW__ = 0;
         $263 = $262&1;
         if ($263) {
          break;
         }
        }
        $264 = HEAP32[$253>>2]|0;
        $265 = (($253) + 16|0);
        $266 = (($264) + 92|0);
        $267 = HEAP32[$266>>2]|0;
        $268 = Math_imul($267, $V_2$0)|0;
        $269 = (($265) + ($268)|0);
        HEAP32[$269>>2] = 0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $270 = __THREW__; __THREW__ = 0;
        $271 = $270&1;
        if ($271) {
         break;
        }
        $272 = (($__this) + 48|0);
        $273 = HEAP32[$272>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $274 = __THREW__; __THREW__ = 0;
        $275 = $274&1;
        if ($275) {
         break;
        }
        $276 = (($273) + 1)|0;
        HEAP32[$272>>2] = $276;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 88) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z147mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_TryGetValueP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_EventPi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$04 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747592);
 __THREW__ = 0;
 invoke_v(340);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021088>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3819,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 40|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iiii(1652,(1760456|0),($18|0),($key|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = $21 | -2147483648;
     $25 = (($__this) + 8|0);
     $26 = HEAP32[$25>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = $21 & 2147483647;
      $30 = (($26) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = (($29|0) % ($31|0))&-1;
      __THREW__ = 0;
      invoke_vi(3799,($26|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       $35 = HEAP32[$30>>2]|0;
       $36 = ($32>>>0)<($35>>>0);
       if (!($36)) {
        __THREW__ = 0;
        $37 = (invoke_i(132)|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($37|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
       }
       $42 = HEAP32[$26>>2]|0;
       $43 = (($26) + 16|0);
       $44 = (($42) + 92|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = Math_imul($45, $32)|0;
       $47 = (($43) + ($46)|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ($48|0)==(0);
       if ($49) {
        $$0 = 0;$storemerge = 0;
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $50 = (($48) + -1)|0;
       $51 = (($__this) + 12|0);
       $52 = (($__this) + 16|0);
       $V_1$04 = $50;
       while(1) {
        $55 = HEAP32[$51>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         label = 3;
         break;
        }
        $53 = ($V_1$04|0)<(0);
        if ($53) {
         label = 22;
        } else {
         $54 = (($55) + 12|0);
         $56 = HEAP32[$54>>2]|0;
         $57 = ($V_1$04>>>0)<($56>>>0);
         if (!($57)) {
          label = 22;
         }
        }
        if ((label|0) == 22) {
         label = 0;
         __THREW__ = 0;
         $58 = (invoke_i(132)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($58|0));
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          label = 3;
          break;
         }
        }
        $63 = HEAP32[$55>>2]|0;
        $64 = (($55) + 16|0);
        $65 = (($63) + 92|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = Math_imul($66, $V_1$04)|0;
        $68 = (($64) + ($67)|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = ($69|0)==($24|0);
        if ($70) {
         $71 = HEAP32[$17>>2]|0;
         $72 = HEAP32[$52>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($72|0));
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          label = 3;
          break;
         }
         if ($53) {
          label = 28;
         } else {
          $75 = (($72) + 12|0);
          $76 = HEAP32[$75>>2]|0;
          $77 = ($V_1$04>>>0)<($76>>>0);
          if (!($77)) {
           label = 28;
          }
         }
         if ((label|0) == 28) {
          label = 0;
          __THREW__ = 0;
          $78 = (invoke_i(132)|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($78|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           label = 3;
           break;
          }
         }
         $83 = HEAP32[$72>>2]|0;
         $84 = (($72) + 16|0);
         $85 = (($83) + 92|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = Math_imul($86, $V_1$04)|0;
         $88 = (($84) + ($87)|0);
         $89 = HEAP32[$88>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($71|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $92 = (invoke_iiiii(305,(1760376|0),($71|0),($89|0),($key|0))|0);
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          label = 3;
          break;
         }
         if ($92) {
          label = 33;
          break;
         }
        }
        $114 = HEAP32[$51>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($114|0));
        $115 = __THREW__; __THREW__ = 0;
        $116 = $115&1;
        if ($116) {
         label = 3;
         break;
        }
        if ($53) {
         label = 42;
        } else {
         $117 = (($114) + 12|0);
         $118 = HEAP32[$117>>2]|0;
         $119 = ($V_1$04>>>0)<($118>>>0);
         if (!($119)) {
          label = 42;
         }
        }
        if ((label|0) == 42) {
         label = 0;
         __THREW__ = 0;
         $120 = (invoke_i(132)|0);
         $121 = __THREW__; __THREW__ = 0;
         $122 = $121&1;
         if ($122) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($120|0));
         $123 = __THREW__; __THREW__ = 0;
         $124 = $123&1;
         if ($124) {
          label = 3;
          break;
         }
        }
        $125 = HEAP32[$114>>2]|0;
        $126 = (($114) + 16|0);
        $127 = (($125) + 92|0);
        $128 = HEAP32[$127>>2]|0;
        $129 = Math_imul($128, $V_1$04)|0;
        $$sum = (($129) + 4)|0;
        $130 = (($126) + ($$sum)|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = ($131|0)==(-1);
        if ($132) {
         $$0 = 0;$storemerge = 0;
         label = 46;
         break;
        } else {
         $V_1$04 = $131;
        }
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 33) {
        $95 = (($__this) + 20|0);
        $96 = HEAP32[$95>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($96|0));
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if ($98) {
         break;
        }
        if ($53) {
         label = 36;
        } else {
         $99 = (($96) + 12|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = ($V_1$04>>>0)<($100>>>0);
         if (!($101)) {
          label = 36;
         }
        }
        if ((label|0) == 36) {
         __THREW__ = 0;
         $102 = (invoke_i(132)|0);
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($102|0));
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          break;
         }
        }
        $107 = HEAP32[$96>>2]|0;
        $108 = (($96) + 16|0);
        $109 = (($107) + 92|0);
        $110 = HEAP32[$109>>2]|0;
        $111 = Math_imul($110, $V_1$04)|0;
        $112 = (($108) + ($111)|0);
        $113 = HEAP32[$112>>2]|0;
        $$0 = 1;$storemerge = $113;
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 46) {
        HEAP32[$value>>2] = $storemerge;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z146mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_ValuesP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747640);
 __THREW__ = 0;
 (invoke_ii(2996,(1766824|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1766824|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1498,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z149mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_GetEnumeratorP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1747736);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1502,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z156mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP29UnityEngine_UnityEngine_Eventi($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1746872);
 HEAP32[$L_2>>2] = $value;
 __THREW__ = 0;
 (invoke_ii(2996,(2689136|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2689136|0),($L_2|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $agg$result;
   $6 = $5;
   HEAP32[$6>>2] = 0;
   $7 = (($5) + 4)|0;
   $8 = $7;
   HEAP32[$8>>2] = 0;
   __THREW__ = 0;
   invoke_viii(571,($agg$result|0),($key|0),($2|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __ZN14ActionInvoker1I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPFvPv135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPFbPv135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker2I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPF135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvS5_iES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$3);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1758568,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker0I150mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPF144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1768528,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z143mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1757944);
 __THREW__ = 0;
 invoke_vii(1492,($__this|0),($key|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1493,($__this|0),($value|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z145mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_set_KeyP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Event($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758040);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z147mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_set_ValueP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758136);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z145mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_KeyP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1757992);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z147mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_ValueP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758088);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z146mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ToStringP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $G_B3_0$0 = 0, $G_B6_0$0 = 0, $L_21 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_1 = sp;
 $L_21 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758184);
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 invoke_v(341);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1168432|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2748,(1168432|0),5)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $19 = HEAP32[3021312>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($4|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[3021312>>2]|0;
       $23 = (($4) + 16|0);
       HEAP32[$23>>2] = $22;
       __THREW__ = 0;
       $24 = (invoke_ii(1311,($__this|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        $27 = ($24|0)==(0|0);
        if ($27) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          break;
         }
         $38 = HEAP8[((2191608 + 116|0))>>0]|0;
         $39 = ($38<<24>>24)==(0);
         if ($39) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3820,(2191608|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          break;
         }
         $48 = HEAP32[((2191608 + 80|0))>>2]|0;
         $49 = HEAP32[$48>>2]|0;
         $G_B3_0$0 = $49;
        } else {
         __THREW__ = 0;
         $30 = (invoke_ii(1311,($__this|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($30|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         __THREW__ = 0;
         $35 = (invoke_iii(2730,(2149112|0),($30|0))|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break;
         }
         $G_B3_0$0 = $35;
        }
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if (!($51)) {
         $52 = HEAP32[$9>>2]|0;
         $53 = ($52>>>0)<(2);
         if ($53) {
          __THREW__ = 0;
          $54 = (invoke_i(132)|0);
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($54|0));
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if ($58) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($4|0),($G_B3_0$0|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if (!($60)) {
          $61 = HEAP32[$4>>2]|0;
          $62 = (($61) + 92|0);
          $63 = HEAP32[$62>>2]|0;
          $64 = (($23) + ($63)|0);
          HEAP32[$64>>2] = $G_B3_0$0;
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if (!($66)) {
           $67 = HEAP32[$9>>2]|0;
           $68 = ($67>>>0)<(3);
           if ($68) {
            __THREW__ = 0;
            $69 = (invoke_i(132)|0);
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if ($71) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($69|0));
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if ($73) {
             break;
            }
           }
           $74 = HEAP32[3021320>>2]|0;
           __THREW__ = 0;
           invoke_vii(3492,($4|0),($74|0));
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if (!($76)) {
            $77 = HEAP32[3021320>>2]|0;
            $78 = HEAP32[$4>>2]|0;
            $79 = (($78) + 92|0);
            $80 = HEAP32[$79>>2]|0;
            $81 = $80 << 1;
            $82 = (($23) + ($81)|0);
            HEAP32[$82>>2] = $77;
            __THREW__ = 0;
            $83 = (invoke_ii(1312,($__this|0))|0);
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if (!($85)) {
             HEAP32[$L_21>>2] = $83;
             __THREW__ = 0;
             (invoke_ii(2996,(2689136|0))|0);
             $86 = __THREW__; __THREW__ = 0;
             $87 = $86&1;
             if (!($87)) {
              __THREW__ = 0;
              $88 = (invoke_iii(2724,(2689136|0),($L_21|0))|0);
              $89 = __THREW__; __THREW__ = 0;
              $90 = $89&1;
              if (!($90)) {
               $91 = ($88|0)==(0|0);
               if ($91) {
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 break;
                }
                $112 = HEAP8[((2191608 + 116|0))>>0]|0;
                $113 = ($112<<24>>24)==(0);
                if ($113) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $114 = __THREW__; __THREW__ = 0;
                 $115 = $114&1;
                 if ($115) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3820,(2191608|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 break;
                }
                $122 = HEAP32[((2191608 + 80|0))>>2]|0;
                $123 = HEAP32[$122>>2]|0;
                $G_B6_0$0 = $123;
               } else {
                __THREW__ = 0;
                $94 = (invoke_ii(1312,($__this|0))|0);
                $95 = __THREW__; __THREW__ = 0;
                $96 = $95&1;
                if ($96) {
                 break;
                }
                HEAP32[$V_1>>2] = $94;
                __THREW__ = 0;
                (invoke_ii(2996,(2689136|0))|0);
                $97 = __THREW__; __THREW__ = 0;
                $98 = $97&1;
                if ($98) {
                 break;
                }
                __THREW__ = 0;
                $99 = (invoke_iii(2724,(2689136|0),($V_1|0))|0);
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if ($101) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($99|0));
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2689136|0))|0);
                $104 = __THREW__; __THREW__ = 0;
                $105 = $104&1;
                if ($105) {
                 break;
                }
                __THREW__ = 0;
                $106 = (invoke_iii(2724,(2689136|0),($V_1|0))|0);
                $107 = __THREW__; __THREW__ = 0;
                $108 = $107&1;
                if ($108) {
                 break;
                }
                __THREW__ = 0;
                $109 = (invoke_iii(2730,(2149112|0),($106|0))|0);
                $110 = __THREW__; __THREW__ = 0;
                $111 = $110&1;
                if ($111) {
                 break;
                }
                $G_B6_0$0 = $109;
               }
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $124 = __THREW__; __THREW__ = 0;
               $125 = $124&1;
               if (!($125)) {
                $126 = HEAP32[$9>>2]|0;
                $127 = ($126>>>0)<(4);
                if ($127) {
                 __THREW__ = 0;
                 $128 = (invoke_i(132)|0);
                 $129 = __THREW__; __THREW__ = 0;
                 $130 = $129&1;
                 if ($130) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($128|0));
                 $131 = __THREW__; __THREW__ = 0;
                 $132 = $131&1;
                 if ($132) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($G_B6_0$0|0));
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 break;
                }
                $135 = HEAP32[$4>>2]|0;
                $136 = (($135) + 92|0);
                $137 = HEAP32[$136>>2]|0;
                $138 = ($137*3)|0;
                $139 = (($23) + ($138)|0);
                HEAP32[$139>>2] = $G_B6_0$0;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $140 = __THREW__; __THREW__ = 0;
                $141 = $140&1;
                if ($141) {
                 break;
                }
                $142 = HEAP32[$9>>2]|0;
                $143 = ($142>>>0)<(5);
                if ($143) {
                 __THREW__ = 0;
                 $144 = (invoke_i(132)|0);
                 $145 = __THREW__; __THREW__ = 0;
                 $146 = $145&1;
                 if ($146) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($144|0));
                 $147 = __THREW__; __THREW__ = 0;
                 $148 = $147&1;
                 if ($148) {
                  break;
                 }
                }
                $149 = HEAP32[3021328>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($149|0));
                $150 = __THREW__; __THREW__ = 0;
                $151 = $150&1;
                if ($151) {
                 break;
                }
                $152 = HEAP32[3021328>>2]|0;
                $153 = HEAP32[$4>>2]|0;
                $154 = (($153) + 92|0);
                $155 = HEAP32[$154>>2]|0;
                $156 = $155 << 2;
                $157 = (($23) + ($156)|0);
                HEAP32[$157>>2] = $152;
                __THREW__ = 0;
                $158 = (invoke_iii(639,(0|0),($4|0))|0);
                $159 = __THREW__; __THREW__ = 0;
                $160 = $159&1;
                if ($160) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($158|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __ZL10SZArrayNewP8TypeInfoj2873($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL11RuntimeInitP8TypeInfo2874($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z186mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758712);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z223mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEnumerator_get_CurrentP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758760);
 __THREW__ = 0;
 invoke_vii(1495,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(1758568|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(1758568|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z192mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758904);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(928,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z188mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_DisposeP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758808);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z189mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1758856);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2875($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPF135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1758568,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m__ctorP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m_System_Collections_IEnumerator_get_CurrentP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1761424)|0);
 $0 = HEAP32[((1761424 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m_DisposeP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m_MoveNextP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m_get_CurrentP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1761424)|0);
 $0 = HEAP32[((1761424 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1763328);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1763376);
 __THREW__ = 0;
 $0 = (invoke_ii(1321,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2689136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2689136|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1763520);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1415,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1763424);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1763472);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z157mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765352);
 __THREW__ = 0;
 invoke_v(342);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1924,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = ($dictionary|0)==(0|0);
   if (!($4)) {
    $17 = (($__this) + 8|0);
    HEAP32[$17>>2] = $dictionary;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[3021160>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3821,($9|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z210mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765400);
 __THREW__ = 0;
 invoke_v(343);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3821,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z212mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765448);
 __THREW__ = 0;
 invoke_v(344);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021280>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3821,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z215mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765496);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(360,($1|0),($item|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z213mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765544);
 __THREW__ = 0;
 invoke_v(345);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021296>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3821,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z220mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765592);
 __THREW__ = 0;
 invoke_vii(1500,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1767456|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1767456|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z165mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_GetEnumeratorP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765832);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1501,($agg$result|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z189mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_ICollection_CopyToP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765640);
 __THREW__ = 0;
 (invoke_ii(2996,(1184704|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2735,($_____array|0),(1184704|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if (!($6)) {
     __THREW__ = 0;
     invoke_viiii(461,(1765688|0),($__this|0),($3|0),($index|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $11 = (($__this) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_viii(385,($12|0),($_____array|0),($index|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $17 = HEAP32[$11>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(1769160|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(1769160|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        HEAP32[$0>>2] = 1747304;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_viii(391,($20|0),(0|0),($$byval_copy|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3799,($17|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          __THREW__ = 0;
          invoke_viiii(281,($17|0),($_____array|0),($index|0),($20|0));
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z208mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1768672);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z221mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765736);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z195mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_ICollection_get_SyncRootP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765784);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2740,(2231320|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z158mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_CopyToP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP49UnityEngine_UnityEngine_TextEditor_TextEditOp_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765688);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viii(385,($2|0),($_____array|0),($index|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = HEAP32[$1>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1769160|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(1769160|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     HEAP32[$0>>2] = 1747304;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_viii(391,($10|0),(0|0),($$byval_copy|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_viiii(283,($7|0),($_____array|0),($index|0),($10|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
}
function __Z168mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1766968);
 __THREW__ = 0;
 invoke_vi(3799,($host|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(1491,($L_0|0),($host|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  ;HEAP32[$__this+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$__this+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$__this+16>>2]=HEAP32[$L_0+16>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z161mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CountP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1765880);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(1747064|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker0I166mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPF160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1767456,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z205mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEnumerator_get_CurrentP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767016);
 __THREW__ = 0;
 $0 = (invoke_ii(1331,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_2>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2689136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2689136|0),($L_2|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z163mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentValueP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767840);
 __THREW__ = 0;
 invoke_vi(1713,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  __THREW__ = 0;
  $3 = (invoke_ii(1312,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z170mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_DisposeP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767064);
 __THREW__ = 0;
 invoke_vi(1714,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z154mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_DisposeP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767984);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z171mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767112);
 __THREW__ = 0;
 $0 = (invoke_ii(1330,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z155mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_22 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_22 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767744);
 __THREW__ = 0;
 invoke_vi(1712,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $99 = $3;
   while(1) {
    $93 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($93|0));
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 4;
     break;
    }
    $96 = (($93) + 24|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($99|0)<($97|0);
    if (!($98)) {
     label = 31;
     break;
    }
    $15 = HEAP32[$2>>2]|0;
    $100 = (($15) + 1)|0;
    HEAP32[$2>>2] = $100;
    $10 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($10|0));
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     label = 4;
     break;
    }
    $9 = (($10) + 12|0);
    $11 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 4;
     break;
    }
    $14 = ($15|0)<(0);
    if ($14) {
     label = 10;
    } else {
     $16 = (($11) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($15>>>0)<($17>>>0);
     if (!($18)) {
      label = 10;
     }
    }
    if ((label|0) == 10) {
     label = 0;
     __THREW__ = 0;
     $19 = (invoke_i(132)|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 4;
      break;
     }
    }
    $24 = HEAP32[$11>>2]|0;
    $25 = (($11) + 16|0);
    $26 = (($24) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $15)|0;
    $29 = (($25) + ($28)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)<(0);
    if ($31) {
     label = 14;
     break;
    }
    $$pre = HEAP32[$2>>2]|0;
    $99 = $$pre;
   }
   if ((label|0) == 4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    $lpad$phi$index = $5;$lpad$phi$index2 = $6;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 14) {
    $32 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($32) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    if ($14) {
     label = 18;
    } else {
     $39 = (($36) + 12|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($15>>>0)<($40>>>0);
     if (!($41)) {
      label = 18;
     }
    }
    if ((label|0) == 18) {
     __THREW__ = 0;
     $42 = (invoke_i(132)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($42|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
    }
    $47 = HEAP32[$36>>2]|0;
    $48 = (($36) + 16|0);
    $49 = (($47) + 92|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = Math_imul($50, $15)|0;
    $52 = (($48) + ($51)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($54|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     break;
    }
    $57 = (($54) + 20|0);
    $58 = HEAP32[$57>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($58|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    if ($14) {
     label = 24;
    } else {
     $61 = (($58) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($15>>>0)<($62>>>0);
     if (!($63)) {
      label = 24;
     }
    }
    if ((label|0) == 24) {
     __THREW__ = 0;
     $64 = (invoke_i(132)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($64|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
    }
    $69 = HEAP32[$58>>2]|0;
    $70 = (($58) + 16|0);
    $71 = (($69) + 92|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = Math_imul($72, $15)|0;
    $74 = (($70) + ($73)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $L_22;
    $77 = $76;
    HEAP32[$77>>2] = 0;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = 0;
    __THREW__ = 0;
    invoke_viii(388,($L_22|0),($53|0),($75|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     break;
    }
    $82 = (($__this) + 12|0);
    $83 = $L_22;
    $84 = $83;
    $85 = HEAP32[$84>>2]|0;
    $86 = (($83) + 4)|0;
    $87 = $86;
    $88 = HEAP32[$87>>2]|0;
    $89 = $82;
    $90 = $89;
    HEAP32[$90>>2] = $85;
    $91 = (($89) + 4)|0;
    $92 = $91;
    HEAP32[$92>>2] = $88;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 31) {
    HEAP32[$2>>2] = -1;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z174mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767160);
 $0 = (($__this) + 12|0);
 __THREW__ = 0;
 $1 = (invoke_ii(1312,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z152mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767600);
 HEAP32[$__this>>2] = $dictionary;
 __THREW__ = 0;
 invoke_vi(3799,($dictionary|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($dictionary) + 48|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z189mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEnumerator_get_CurrentP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767648);
 __THREW__ = 0;
 invoke_vi(1713,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  $3 = $2;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $L_1;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  __THREW__ = 0;
  (invoke_ii(2996,(1758568|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   $15 = (invoke_iii(2724,(1758568|0),($L_1|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z160mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_VerifyCurrentP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767936);
 __THREW__ = 0;
 invoke_v(347);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1712,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = (($__this) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)>(0);
   if ($6) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2607872|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[3021144>>2]|0;
     __THREW__ = 0;
     invoke_vii(1947,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3821,($11|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z197mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IDictionaryEnumerator_get_EntryP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_6 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767696);
 __THREW__ = 0;
 invoke_vi(1713,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  __THREW__ = 0;
  $3 = (invoke_ii(1311,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1312,($2|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    HEAP32[$L_6>>2] = $6;
    __THREW__ = 0;
    (invoke_ii(2996,(2689136|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iii(2724,(2689136|0),($L_6|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = $agg$result;
      $15 = $14;
      HEAP32[$15>>2] = 0;
      $16 = (($14) + 4)|0;
      $17 = $16;
      HEAP32[$17>>2] = 0;
      __THREW__ = 0;
      invoke_viii(571,($agg$result|0),($3|0),($11|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
}
function __Z158mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_VerifyStateP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767888);
 __THREW__ = 0;
 invoke_v(346);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2634432|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2634432|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1970,($8|0),(0|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($8|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($2) + 48|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if ($21) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     $24 = (invoke_ii(3469,(2607872|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[3021104>>2]|0;
      __THREW__ = 0;
      invoke_vii(1947,($24|0),($27|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vi(3821,($24|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z158mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1767792);
 $0 = (($__this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z209mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_InvokeP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1768720);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_iiii(320,($1|0),($key|0),($value|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiii($8|0,($10|0),($key|0),($value|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z214mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_BeginInvokeP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_EventiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1768768);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z212mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_EndInvokeP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1768816);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1769304);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z207mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntryP29UnityEngine_UnityEngine_Eventi($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1769352);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(108,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z212mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntryP29UnityEngine_UnityEngine_EventiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1769400);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z210mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1769448);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z298mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1769880);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z299mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_InvokeP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1769928);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(109,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z304mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_BeginInvokeP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_EventiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1769976);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z302mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_EndInvokeP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1770024);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraits17VoidPointerTraitsE6InvokeEPF135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1758568,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z156mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP148mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1770456);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($host|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   invoke_vii(1491,($L_0|0),($host|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($__this) + 8|0);
    ;HEAP32[$6+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$L_0+16>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z159mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP148mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1770504);
 $0 = (($__this) + 8|0);
 __THREW__ = 0;
 $1 = (invoke_ii(1330,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z160mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_EntryP148mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1770552);
 $0 = (($__this) + 8|0);
 ;HEAP32[$L_1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$0+16>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1768528|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2724,(1768528|0),($L_1|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(2114,($agg$result|0),(2311136|0),($3|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z162mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP148mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1770600);
 __THREW__ = 0;
 invoke_viii(2115,($L_0|0),(1770552|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2307216|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2307216|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __ZL92mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m__ctorP84mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1771832)|0);
 $0 = HEAP32[((1771832 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL135mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m_System_Collections_IEqualityComparer_GetHashCodeP84mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_EventP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL130mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m_System_Collections_IEqualityComparer_EqualsP84mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_EventP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1771832)|0);
 $0 = HEAP32[((1771832 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Event_m__ctorP100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Event_m_GetHashCodeP100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_EventP29UnityEngine_UnityEngine_Event($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Event_m_EqualsP100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_EventP29UnityEngine_UnityEngine_EventS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z108mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1773040);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1773088);
 __THREW__ = 0;
 (invoke_ii(2996,(1774392|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1774392|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1720,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1773680|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1773680 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z124mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOp($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1774056);
 __THREW__ = 0;
 invoke_vi(1718,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z151mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEqualityComparer_GetHashCodeP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1773136);
 __THREW__ = 0;
 (invoke_ii(2996,(2689136|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2749,($obj|0),(2689136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   $6 = (invoke_iiii(1653,(1773184|0),($__this|0),($5|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo2886($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z146mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEqualityComparer_EqualsP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1773232);
 __THREW__ = 0;
 (invoke_ii(2996,(2689136|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2749,($x|0),(2689136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2689136|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2749,($y|0),(2689136|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[$8>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iiiii(304,(1773280|0),($__this|0),($5|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($12|0);
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z114mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1773328);
 __THREW__ = 0;
 (invoke_ii(2996,(1773680|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1773680 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1773680|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1773680|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3820,(1773680|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1773680|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1773680 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z130mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_GetHashCodeP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOpi($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 HEAP32[$0>>2] = $obj;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1774104);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$L_0>>2] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2689136|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2724,(2689136|0),($L_0|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)==(0|0);
   if ($7) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2689136|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(2724,(2689136|0),($0|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3799,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2689136|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_iii(2724,(2689136|0),($0|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        $22 = (invoke_iii(2729,(2148880|0),($19|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         $$0 = $22;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_EqualsP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOpii($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_5 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $L_2 = sp + 8|0;
 $L_5 = sp + 12|0;
 HEAP32[$0>>2] = $x;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1774152);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$L_0>>2] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2689136|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2689136|0),($L_0|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if ($7) {
     HEAP32[$L_2>>2] = $y;
     __THREW__ = 0;
     (invoke_ii(2996,(2689136|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(2724,(2689136|0),($L_2|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = ($12|0)==(0|0);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    HEAP32[$L_5>>2] = $y;
    __THREW__ = 0;
    (invoke_ii(2996,(2689136|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     $18 = (invoke_iii(2724,(2689136|0),($L_5|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2689136|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       $23 = (invoke_iii(2724,(2689136|0),($0|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        invoke_vi(3799,($23|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2689136|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          __THREW__ = 0;
          $30 = (invoke_iii(2724,(2689136|0),($0|0))|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           $33 = (invoke_iiii(1644,(2148736|0),($30|0),($18|0))|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $$0 = $33;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1774776);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1774824);
 __THREW__ = 0;
 $0 = (invoke_ii(1338,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP8[$L_1>>0] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2686296|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2686296|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1774968);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1419,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1774872);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1774920);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1778440);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $_stackTraceSentry = sp + 120|0;
 $L_0 = sp;
 $L_1 = sp + 60|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1778488);
 __THREW__ = 0;
 invoke_vii(1509,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  dest=$L_1+0|0; src=$L_0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  __THREW__ = 0;
  (invoke_ii(2996,(2859256|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2859256|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1778632);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(941,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1778536);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1778584);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPF32UnityEngine_UnityEngine_UIVertexPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2859256,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m__ctor_mscorlib_System_VoidP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779064);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1782560|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((1782560 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(1782560|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1782560|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3820,(1782560|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1782560|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((1782560 + 80|0))>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     $18 = (($__this) + 8|0);
     HEAP32[$18>>2] = $17;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z156mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779112);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1520,0,($collection|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1777832|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     $6 = (invoke_iii(2735,($collection|0),(1777832|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = ($6|0)==(0|0);
      if (!($9)) {
       __THREW__ = 0;
       invoke_vi(3799,($6|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       __THREW__ = 0;
       $31 = (invoke_iii(2736,(1777344|0),($6|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1185480|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
       __THREW__ = 0;
       $36 = (invoke_iii(2748,(1185480|0),($31|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       $39 = (($__this) + 8|0);
       HEAP32[$39>>2] = $36;
       __THREW__ = 0;
       invoke_vii(1515,($__this|0),($6|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1782560|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       $14 = HEAP8[((1782560 + 116|0))>>0]|0;
       $15 = ($14<<24>>24)==(0);
       if ($15) {
        __THREW__ = 0;
        (invoke_ii(2996,(1782560|0))|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1782560|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3820,(1782560|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1782560|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = HEAP32[((1782560 + 80|0))>>2]|0;
        $25 = HEAP32[$24>>2]|0;
        $26 = (($__this) + 8|0);
        HEAP32[$26>>2] = $25;
        __THREW__ = 0;
        invoke_vii(1516,($__this|0),($collection|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_CheckCollectionP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780552);
 __THREW__ = 0;
 invoke_v(330);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($collection|0)==(0|0);
  if (!($2)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3021464>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3821,($7|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_AddEnumerableP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var $$0 = 0, $$03 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond2 = 0, $data$i = 0, $leaveInstructions$sroa$0$0 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $$byval_copy = sp + 136|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 $L_1 = sp + 76|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780216);
 __THREW__ = 0;
 invoke_vi(3799,($enumerable|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2739,(1777976|0),($enumerable|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($data$i) + 4|0);
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $21 = (invoke_iii(2741,(2176240|0),($3|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 12;
      break;
     }
     if (!($21)) {
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 44;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     invoke_viii(2117,($L_1|0),(1778200|0),($3|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      label = 12;
      break;
     }
     dest=$0+0|0; src=$L_1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     __THREW__ = 0;
     invoke_viii(2112,($data$i|0),(1779400|0),($__this|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 12;
      break;
     }
     $13 = HEAP32[$6>>2]|0;
     $14 = (($13) + 4|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = HEAP32[$data$i>>2]|0;
     __THREW__ = 0;
     dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     invoke_vii($15|0,($16|0),($$byval_copy|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 12;
      break;
     }
    }
    if ((label|0) == 12) {
     $26 = ___cxa_find_matching_catch(348288|0)|0;
     $27 = tempRet0;
     $28 = (_llvm_eh_typeid_for((348288|0))|0);
     $29 = ($27|0)==($28|0);
     if (!($29)) {
      $$0 = $26;$$03 = $27;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$0|0);
      // unreachable;
     }
     $30 = (___cxa_begin_catch(($26|0))|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     invoke_v(66);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $__last_unhandled_exception$0 = $31;$leaveInstructions$sroa$0$0 = 0;
    }
    $34 = ($3|0)==(0|0);
    if ($34) {
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(44);
     if ($cond1) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3821,($__last_unhandled_exception$0|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     __THREW__ = 0;
     invoke_vii(3491,(2176768|0),($3|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $cond2 = ($leaveInstructions$sroa$0$0|0)==(44);
      if ($cond2) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3821,($__last_unhandled_exception$0|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $$0 = $7;$$03 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_AddCollectionP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780168);
 __THREW__ = 0;
 invoke_vi(3799,($collection|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2736,(1777344|0),($collection|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vii(1514,($__this|0),($2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($__this) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($__this) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($collection|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_viiii(464,(1777640|0),($collection|0),($11|0),($13|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = HEAP32[$12>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $23 = (($20) + ($2))|0;
        HEAP32[$12>>2] = $23;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z126mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779160);
 __THREW__ = 0;
 invoke_v(325);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($capacity|0)>(-1);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(1185480|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_iii(2748,(1185480|0),($capacity|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = (($__this) + 8|0);
     HEAP32[$22>>2] = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2561352|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[3021392>>2]|0;
      __THREW__ = 0;
      invoke_vii(1926,($9|0),($12|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3821,($9|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z84mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779208);
 __THREW__ = 0;
 (invoke_ii(2996,(1185480|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2748,(1185480|0),0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1782560|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[((1782560 + 80|0))>>2]|0;
    HEAP32[$7>>2] = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z141mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $_stackTraceSentry = sp + 144|0;
 $L_0 = sp;
 $L_1 = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779256);
 __THREW__ = 0;
 invoke_vii(1518,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  dest=$L_1+0|0; src=$L_0+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  __THREW__ = 0;
  (invoke_ii(2996,(1783312|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1783312|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_GetEnumeratorP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780408);
 dest=$agg$result+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vii(1523,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z115mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_ICollection_CopyToP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779304);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(55,(0|0),($1|0),0,($_____array|0),($arrayIndex|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_AddP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$02 = 0, $$03 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, $data$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 76|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779352);
 __THREW__ = 0;
 invoke_v(326);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2859256|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2749,($item|0),(2859256|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     _memmove(($0|0),($5|0),60)|0;
     __THREW__ = 0;
     invoke_viii(2112,($data$i|0),(1779400|0),($__this|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = (($data$i) + 4|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (($11) + 4|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      invoke_vii($13|0,($14|0),($$byval_copy|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = (($__this) + 12|0);
       $18 = HEAP32[$17>>2]|0;
       $19 = (($18) + -1)|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($19|0);
      }
     }
    }
   }
   $22 = ___cxa_find_matching_catch(348288|0)|0;
   $23 = tempRet0;
   $24 = (_llvm_eh_typeid_for((348288|0))|0);
   $25 = ($23|0)==($24|0);
   if (!($25)) {
    $$02 = $22;$$03 = $23;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
   $26 = (___cxa_begin_catch(($22|0))|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   __THREW__ = 0;
   $29 = (invoke_iii(2727,(2623248|0),($28|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   do {
    if (!($31)) {
     if (!($29)) {
      $36 = HEAP32[$26>>2]|0;
      $37 = HEAP32[$36>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_iii(2727,(2607384|0),($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      if (!($38)) {
       $41 = (___cxa_allocate_exception(4)|0);
       $42 = HEAP32[$26>>2]|0;
       HEAP32[$41>>2] = $42;
       __THREW__ = 0;
       invoke_viii(1567,($41|0),(348288|0),(0|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_v(66);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break L1;
     }
     __THREW__ = 0;
     $49 = (invoke_ii(3469,(2560072|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     }
     $52 = HEAP32[3021408>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($49|0),($52|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3821,($49|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $57 = ___cxa_find_matching_catch(0|0)|0;
    $58 = tempRet0;
    ___clang_call_terminate($57);
    // unreachable;
   } else {
    $$02 = $32;$$03 = $33;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $$02 = $20;$$03 = $21;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_ContainsP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $data$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 76|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779448);
 __THREW__ = 0;
 (invoke_ii(2996,(2859256|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2749,($item|0),(2859256|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   _memmove(($0|0),($3|0),60)|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(1779496|0),($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $13 = (invoke_iii($11|0,($12|0),($$byval_copy|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch(348288|0)|0;
 $17 = tempRet0;
 $18 = (_llvm_eh_typeid_for((348288|0))|0);
 $19 = ($17|0)==($18|0);
 if (!($19)) {
  $$02 = $17;$$03 = $16;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 $20 = (___cxa_begin_catch(($16|0))|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 __THREW__ = 0;
 $23 = (invoke_iii(2727,(2623248|0),($22|0))|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if (!($25)) {
   if (!($23)) {
    $30 = HEAP32[$20>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii(2727,(2607384|0),($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    if (!($32)) {
     $35 = (___cxa_allocate_exception(4)|0);
     $36 = HEAP32[$20>>2]|0;
     HEAP32[$35>>2] = $36;
     __THREW__ = 0;
     invoke_viii(1567,($35|0),(348288|0),(0|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $41 = ___cxa_find_matching_catch()|0;
   $42 = tempRet0;
   $$02 = $42;$$03 = $41;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $43 = ___cxa_find_matching_catch(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  $$02 = $27;$$03 = $26;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __Z110mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_IndexOfP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $data$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 76|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779544);
 __THREW__ = 0;
 (invoke_ii(2996,(2859256|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2749,($item|0),(2859256|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   _memmove(($0|0),($3|0),60)|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(1779592|0),($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $13 = (invoke_iii($11|0,($12|0),($$byval_copy|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch(348288|0)|0;
 $17 = tempRet0;
 $18 = (_llvm_eh_typeid_for((348288|0))|0);
 $19 = ($17|0)==($18|0);
 if (!($19)) {
  $$02 = $17;$$03 = $16;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 $20 = (___cxa_begin_catch(($16|0))|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 __THREW__ = 0;
 $23 = (invoke_iii(2727,(2623248|0),($22|0))|0);
 $24 = __THREW__; __THREW__ = 0;
 $25 = $24&1;
 do {
  if (!($25)) {
   if (!($23)) {
    $30 = HEAP32[$20>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii(2727,(2607384|0),($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    if (!($32)) {
     $35 = (___cxa_allocate_exception(4)|0);
     $36 = HEAP32[$20>>2]|0;
     HEAP32[$35>>2] = $36;
     __THREW__ = 0;
     invoke_viii(1567,($35|0),(348288|0),(0|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $$0 = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $41 = ___cxa_find_matching_catch()|0;
   $42 = tempRet0;
   $$02 = $42;$$03 = $41;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $43 = ___cxa_find_matching_catch(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  $$02 = $27;$$03 = $26;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __Z109mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_InsertP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $data$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 76|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779640);
 __THREW__ = 0;
 invoke_v(327);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vii(1519,($__this|0),($index|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2859256|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(2749,($item|0),(2859256|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      _memmove(($0|0),($7|0),60)|0;
      __THREW__ = 0;
      invoke_viii(2112,($data$i|0),(1779688|0),($__this|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($data$i) + 4|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = (($13) + 4|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = HEAP32[$data$i>>2]|0;
       __THREW__ = 0;
       dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       invoke_viii($15|0,($16|0),($index|0),($$byval_copy|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
    $21 = ___cxa_find_matching_catch(348288|0)|0;
    $22 = tempRet0;
    $23 = (_llvm_eh_typeid_for((348288|0))|0);
    $24 = ($22|0)==($23|0);
    if (!($24)) {
     $$0 = $21;$$01 = $22;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
    $25 = (___cxa_begin_catch(($21|0))|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    $28 = (invoke_iii(2727,(2623248|0),($27|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    do {
     if (!($30)) {
      if (!($28)) {
       $35 = HEAP32[$25>>2]|0;
       $36 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       $37 = (invoke_iii(2727,(2607384|0),($36|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
       if (!($37)) {
        $40 = (___cxa_allocate_exception(4)|0);
        $41 = HEAP32[$25>>2]|0;
        HEAP32[$40>>2] = $41;
        __THREW__ = 0;
        invoke_viii(1567,($40|0),(348288|0),(0|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_v(66);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break L1;
      }
      __THREW__ = 0;
      $48 = (invoke_ii(3469,(2560072|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break L1;
      }
      $51 = HEAP32[3021432>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($48|0),($51|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3821,($48|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break L1;
      }
      // unreachable;
     }
    } while(0);
    $31 = ___cxa_find_matching_catch()|0;
    $32 = tempRet0;
    __THREW__ = 0;
    invoke_v(66);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     $56 = ___cxa_find_matching_catch(0|0)|0;
     $57 = tempRet0;
     ___clang_call_terminate($56);
     // unreachable;
    } else {
     $$0 = $31;$$01 = $32;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $$0 = $19;$$01 = $20;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_CheckIndexP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780504);
 __THREW__ = 0;
 invoke_v(329);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($index|0)<(0);
  if (!($2)) {
   $5 = (($__this) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)<($index|0);
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_ii(3469,(2561352|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[3021448>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_vi(3821,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z109mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_RemoveP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$01 = 0, $$02 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $data$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 76|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779736);
 __THREW__ = 0;
 (invoke_ii(2996,(2859256|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2749,($item|0),(2859256|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   _memmove(($0|0),($3|0),60)|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(1779784|0),($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    (invoke_iii($11|0,($12|0),($$byval_copy|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch(348288|0)|0;
 $16 = tempRet0;
 $17 = (_llvm_eh_typeid_for((348288|0))|0);
 $18 = ($16|0)==($17|0);
 if (!($18)) {
  $$01 = $15;$$02 = $16;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$01|0);
  // unreachable;
 }
 $19 = (___cxa_begin_catch(($15|0))|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 __THREW__ = 0;
 $22 = (invoke_iii(2727,(2623248|0),($21|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 do {
  if (!($24)) {
   if (!($22)) {
    $29 = HEAP32[$19>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iii(2727,(2607384|0),($30|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    if (!($31)) {
     $34 = (___cxa_allocate_exception(4)|0);
     $35 = HEAP32[$19>>2]|0;
     HEAP32[$34>>2] = $35;
     __THREW__ = 0;
     invoke_viii(1567,($34|0),(348288|0),(0|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   $$01 = $40;$$02 = $41;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 if ($28) {
  $42 = ___cxa_find_matching_catch(0|0)|0;
  $43 = tempRet0;
  ___clang_call_terminate($42);
  // unreachable;
 } else {
  $$01 = $25;$$02 = $26;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __Z142mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779832);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z121mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_ICollection_get_SyncRootP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779880);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_get_ItemP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $_stackTraceSentry = sp + 120|0;
 $L_0 = sp;
 $L_1 = sp + 60|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779928);
 __THREW__ = 0;
 invoke_viiii(467,($L_0|0),(1779976|0),($__this|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  dest=$L_1+0|0; src=$L_0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  __THREW__ = 0;
  (invoke_ii(2996,(2859256|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2859256|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I38UnityEngine_UnityEngine_UIVertexTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi($agg$result,$method,$obj,$p1) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($agg$result,$4,$p1);
 STACKTOP = sp;return;
}
function __Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_set_ItemP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $data$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 76|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780024);
 __THREW__ = 0;
 invoke_v(328);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2859256|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2749,($value|0),(2859256|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     _memmove(($0|0),($5|0),60)|0;
     __THREW__ = 0;
     invoke_viii(2112,($data$i|0),(1780072|0),($__this|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = (($data$i) + 4|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = (($11) + 4|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      invoke_viii($13|0,($14|0),($index|0),($$byval_copy|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
   $19 = ___cxa_find_matching_catch(348288|0)|0;
   $20 = tempRet0;
   $21 = (_llvm_eh_typeid_for((348288|0))|0);
   $22 = ($20|0)==($21|0);
   if (!($22)) {
    $$0 = $19;$$01 = $20;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $23 = (___cxa_begin_catch(($19|0))|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = HEAP32[$24>>2]|0;
   __THREW__ = 0;
   $26 = (invoke_iii(2727,(2623248|0),($25|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   do {
    if (!($28)) {
     if (!($26)) {
      $33 = HEAP32[$23>>2]|0;
      $34 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      $35 = (invoke_iii(2727,(2607384|0),($34|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      if (!($35)) {
       $38 = (___cxa_allocate_exception(4)|0);
       $39 = HEAP32[$23>>2]|0;
       HEAP32[$38>>2] = $39;
       __THREW__ = 0;
       invoke_viii(1567,($38|0),(348288|0),(0|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_v(66);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break L1;
     }
     __THREW__ = 0;
     $46 = (invoke_ii(3469,(2560072|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break L1;
     }
     $49 = HEAP32[3021344>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($46|0),($49|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3821,($46|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $29 = ___cxa_find_matching_catch()|0;
   $30 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $54 = ___cxa_find_matching_catch(0|0)|0;
    $55 = tempRet0;
    ___clang_call_terminate($54);
    // unreachable;
   } else {
    $$0 = $29;$$01 = $30;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $$0 = $17;$$01 = $18;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_AddP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779400);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($3) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($1|0)==($7|0);
   if ($8) {
    __THREW__ = 0;
    invoke_vii(1514,($__this|0),1);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
   }
   $13 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($16) + 1)|0;
     HEAP32[$0>>2] = $19;
     __THREW__ = 0;
     invoke_vi(3799,($13|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = ($16|0)<(0);
      if ($22) {
       label = 10;
      } else {
       $23 = (($13) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($16>>>0)<($24>>>0);
       if (!($25)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $26 = (invoke_i(132)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[$13>>2]|0;
      $32 = (($13) + 16|0);
      $33 = (($31) + 92|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = Math_imul($34, $16)|0;
      $36 = (($32) + ($35)|0);
      dest=$36+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = (($__this) + 16|0);
       $40 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        $43 = (($40) + 1)|0;
        HEAP32[$39>>2] = $43;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_GrowIfNeededP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780120);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($newCount))|0;
 $3 = (($__this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = (($4) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($2|0)>($8|0);
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  $12 = (invoke_ii(1345,($__this|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = $12 << 1;
   __THREW__ = 0;
   $16 = (invoke_iiii(1197,(0|0),($15|0),4)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_iiii(1197,(0|0),($16|0),($2|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vii(1522,($__this|0),($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_get_CapacityP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780696);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_set_CapacityP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780744);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>($value|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2561352|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2587,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3821,($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 } else {
  $14 = (($__this) + 8|0);
  __THREW__ = 0;
  invoke_viii(945,(0|0),($14|0),($value|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker0I38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEP10MethodInfoPv($agg$result,$method,$obj) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($agg$result,$4);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_AddRangeP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780264);
 __THREW__ = 0;
 invoke_vii(1520,0,($collection|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1777832|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2735,($collection|0),(1777832|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      __THREW__ = 0;
      invoke_vii(1516,($__this|0),($collection|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
     } else {
      __THREW__ = 0;
      invoke_vii(1515,($__this|0),($4|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = (($__this) + 16|0);
      $17 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = (($17) + 1)|0;
       HEAP32[$16>>2] = $20;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z83mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_ClearP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780312);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($1|0),0,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($__this) + 12|0);
   HEAP32[$8>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($__this) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = (($12) + 1)|0;
     HEAP32[$11>>2] = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_ContainsP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $item$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $item$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779496);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 dest=$item$byval_copy+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = (invoke_iiiiii(147,(0|0),($1|0),($item$byval_copy|0),0,($3|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $7 = ($4|0)!=(-1);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($7|0);
 }
 return 0|0;
}
function __Z84mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_CopyToP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP36UnityEngine_UnityEngine_UIVertex_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780360);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(55,(0|0),($1|0),0,($_____array|0),($arrayIndex|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m__ctorP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertexP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1782704);
 HEAP32[$__this>>2] = $l;
 __THREW__ = 0;
 invoke_vi(3799,($l|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($l) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_IndexOfP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, $item$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $item$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779592);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 dest=$item$byval_copy+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = (invoke_iiiiii(147,(0|0),($1|0),($item$byval_copy|0),0,($3|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z83mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_ShiftP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $start$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780456);
 $0 = ($delta|0)>(-1);
 $1 = $0 ? 0 : $delta;
 $start$ = (($start) - ($1))|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($start$|0)<($3|0);
 if ($4) {
  $5 = (($__this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($start$) + ($delta))|0;
  $8 = (($3) - ($start$))|0;
  __THREW__ = 0;
  invoke_viiiiii(55,(0|0),($6|0),($start$|0),($6|0),($7|0),($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP32[$2>>2]|0;
   $14 = (($13) + ($delta))|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    HEAP32[$2>>2] = $14;
    if ($0) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (0 - ($delta))|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($20|0),($14|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z84mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_InsertP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi32UnityEngine_UnityEngine_UIVertex($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779688);
 __THREW__ = 0;
 invoke_vii(1519,($__this|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($__this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($5) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($3|0)==($9|0);
    if ($10) {
     __THREW__ = 0;
     invoke_vii(1514,($__this|0),1);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_viii(403,($__this|0),($index|0),1);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[$4>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = ($index|0)<(0);
      if ($20) {
       label = 10;
      } else {
       $21 = (($17) + 12|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($22>>>0)>($index>>>0);
       if (!($23)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $24 = (invoke_i(132)|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($24|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
      }
      $29 = HEAP32[$17>>2]|0;
      $30 = (($17) + 16|0);
      $31 = (($29) + 92|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = Math_imul($32, $index)|0;
      $34 = (($30) + ($33)|0);
      dest=$34+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       $37 = (($__this) + 16|0);
       $38 = HEAP32[$37>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if (!($40)) {
        $41 = (($38) + 1)|0;
        HEAP32[$37>>2] = $41;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z84mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_RemoveP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $data$i = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 76|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779784);
 dest=$0+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_viii(2112,($data$i|0),(1779592|0),($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($data$i) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($4) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$data$i>>2]|0;
  __THREW__ = 0;
  dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $8 = (invoke_iii($6|0,($7|0),($$byval_copy|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = ($8|0)==(-1);
   if ($11) {
    $16 = $11 ^ 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
   __THREW__ = 0;
   invoke_viii(2111,(1780600|0),($__this|0),($8|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = $11 ^ 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_RemoveAtP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780600);
 __THREW__ = 0;
 invoke_v(331);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($index|0)<(0);
   if (!($2)) {
    $5 = (($__this) + 12|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)>($index|0);
    if ($7) {
     __THREW__ = 0;
     invoke_viii(403,($__this|0),($index|0),-1);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = (($__this) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$5>>2]|0;
     __THREW__ = 0;
     invoke_viiii(138,(0|0),($21|0),($22|0),1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = (($__this) + 16|0);
     $28 = HEAP32[$27>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     $31 = (($28) + 1)|0;
     HEAP32[$27>>2] = $31;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3021504>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3821,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_ToArrayP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780648);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1185480|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2748,(1185480|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_viiii(140,(0|0),($8|0),($4|0),($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_get_CountP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780792);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_get_ItemP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1779976);
 __THREW__ = 0;
 invoke_v(332);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>($index|0);
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2561352|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021360>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = ($index|0)<(0);
    if ($21) {
     label = 12;
    } else {
     $22 = (($18) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23>>>0)>($index>>>0);
     if (!($24)) {
      label = 12;
     }
    }
    if ((label|0) == 12) {
     __THREW__ = 0;
     $25 = (invoke_i(132)|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($25|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    $30 = HEAP32[$18>>2]|0;
    $31 = (($18) + 16|0);
    $32 = (($30) + 92|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = Math_imul($33, $index)|0;
    $35 = (($31) + ($34)|0);
    dest=$agg$result+0|0; src=$35+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_set_ItemP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi32UnityEngine_UnityEngine_UIVertex($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1780072);
 __THREW__ = 0;
 invoke_v(333);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1519,($__this|0),($index|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($__this) + 12|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5|0)==($index|0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3021376>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3821,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = ($index|0)<(0);
     if ($23) {
      label = 13;
     } else {
      $24 = (($20) + 12|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25>>>0)>($index>>>0);
      if (!($26)) {
       label = 13;
      }
     }
     if ((label|0) == 13) {
      __THREW__ = 0;
      $27 = (invoke_i(132)|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($27|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
     }
     $32 = HEAP32[$20>>2]|0;
     $33 = (($20) + 16|0);
     $34 = (($32) + 92|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = Math_imul($35, $index)|0;
     $37 = (($33) + ($36)|0);
     dest=$37+0|0; src=$value+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __ZN14ActionInvoker1I38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPFvPv32UnityEngine_UnityEngine_UIVertexES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPFbPv32UnityEngine_UnityEngine_UIVertexES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 60|0;
 $0 = HEAP32[$args>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker0I92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPF86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertexPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1783312,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPFiPv32UnityEngine_UnityEngine_UIVertexES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 4|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPFvPvi32UnityEngine_UnityEngine_UIVertexES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$3+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I38UnityEngine_UnityEngine_UIVertexTraits27mscorlib_System_Int32TraitsE6InvokeEPF32UnityEngine_UnityEngine_UIVertexPviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2859256,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z131mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_4 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 60|0;
 $L_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1782752);
 __THREW__ = 0;
 invoke_vi(1727,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(0);
   if ($4) {
    $16 = (($__this) + 12|0);
    dest=$L_4+0|0; src=$16+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    __THREW__ = 0;
    (invoke_ii(2996,(2859256|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_iii(2724,(2859256|0),($L_4|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2607872|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(2734,($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3821,($9|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_VerifyStateP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $_stackTraceSentry = sp + 72|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1782848);
 __THREW__ = 0;
 invoke_v(324);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if (!($3)) {
    $30 = (($__this) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($2) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($31|0)==($35|0);
    if ($36) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3469,(2607872|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    $42 = HEAP32[3021520>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($39|0),($42|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($39|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    // unreachable;
   }
   dest=$L_1+0|0; src=$__this+0|0; stop=dest+72|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   __THREW__ = 0;
   (invoke_ii(2996,(1783312|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2724,(1783312|0),($L_1|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(1782,($8|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(3799,($13|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        $18 = (invoke_iii(2730,(2150320|0),($13|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2634432|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          $23 = (invoke_ii(3469,(2634432|0))|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           __THREW__ = 0;
           invoke_vii(1970,($23|0),($18|0));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            invoke_vi(3821,($23|0));
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             // unreachable;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z96mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_DisposeP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1782800);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z97mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_MoveNextP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1782896);
 __THREW__ = 0;
 invoke_vi(1727,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $7 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($7|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($7) + 12|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($3|0)<($11|0);
    if (!($12)) {
     HEAP32[$2>>2] = -1;
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $13 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = (($13) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = HEAP32[$2>>2]|0;
     $19 = (($18) + 1)|0;
     HEAP32[$2>>2] = $19;
     __THREW__ = 0;
     invoke_vi(3799,($17|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = ($18|0)<(0);
      if ($22) {
       label = 10;
      } else {
       $23 = (($17) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($18>>>0)<($24>>>0);
       if (!($25)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $26 = (invoke_i(132)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[$17>>2]|0;
      $32 = (($17) + 16|0);
      $33 = (($31) + 92|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = Math_imul($34, $18)|0;
      $36 = (($32) + ($35)|0);
      $37 = (($__this) + 12|0);
      _memmove(($37|0),($36|0),60)|0;
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_get_CurrentP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1782944);
 $0 = (($__this) + 12|0);
 dest=$agg$result+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z95mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m__ctorP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1783456);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z96mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1783504);
 __THREW__ = 0;
 (invoke_ii(2996,(1785120|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1785120|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1730,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1784096|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1784096 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z111mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex_m__ctorP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1784784);
 __THREW__ = 0;
 invoke_vi(1728,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z138mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IEqualityComparer_GetHashCodeP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $data$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 76|0;
 $data$i = sp + 64|0;
 $0 = sp;
 $_stackTraceSentry = sp + 72|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1783552);
 __THREW__ = 0;
 (invoke_ii(2996,(2859256|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2749,($obj|0),(2859256|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   _memmove(($0|0),($3|0),60)|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(1783600|0),($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $13 = (invoke_iii($11|0,($12|0),($$byval_copy|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($13|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z133mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IEqualityComparer_EqualsP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, $data$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $$byval_copy1 = sp + 320|0;
 $$byval_copy = sp + 136|0;
 $data$i = sp + 128|0;
 $0 = sp;
 $1 = sp + 64|0;
 $_stackTraceSentry = sp + 196|0;
 $L_1 = sp + 200|0;
 $2 = sp + 260|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1783648);
 __THREW__ = 0;
 (invoke_ii(2996,(2859256|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2749,($x|0),(2859256|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   dest=$L_1+0|0; src=$5+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   __THREW__ = 0;
   (invoke_ii(2996,(2859256|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2749,($y|0),(2859256|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     dest=$2+0|0; src=$10+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     dest=$1+0|0; src=$L_1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     dest=$0+0|0; src=$2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     __THREW__ = 0;
     invoke_viii(2112,($data$i|0),(1783696|0),($__this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = (($data$i) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($16) + 4|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      dest=$$byval_copy+0|0; src=$1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      dest=$$byval_copy1+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $20 = (invoke_iiii($18|0,($19|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($20|0);
      }
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1783744);
 __THREW__ = 0;
 (invoke_ii(2996,(1784096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1784096 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1784096|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1784096|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3820,(1784096|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1784096|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1784096 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex_m_GetHashCodeP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 60|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1784832);
 dest=$L_0+0|0; src=$obj+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 (invoke_ii(2996,(2859256|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2859256|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2859256|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2859256|0),($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2859256|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(2859256|0),($obj|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2148880|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $$0 = $20;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z112mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex_m_EqualsP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertexS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_5 = 0, $_stackTraceSentry = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $_stackTraceSentry = sp + 180|0;
 $L_0 = sp;
 $L_2 = sp + 60|0;
 $L_5 = sp + 120|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1784880);
 dest=$L_0+0|0; src=$x+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 (invoke_ii(2996,(2859256|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2724,(2859256|0),($L_0|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     dest=$L_2+0|0; src=$y+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     __THREW__ = 0;
     (invoke_ii(2996,(2859256|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2724,(2859256|0),($L_2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = ($10|0)==(0|0);
     $$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    dest=$L_5+0|0; src=$y+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    __THREW__ = 0;
    (invoke_ii(2996,(2859256|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2859256|0),($L_5|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2859256|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_iii(2724,(2859256|0),($x|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2859256|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_iii(2724,(2859256|0),($x|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           __THREW__ = 0;
           $31 = (invoke_iiii(1644,(2148736|0),($28|0),($16|0))|0);
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $$0 = $31;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits38UnityEngine_UnityEngine_UIVertexTraitsS1_E6InvokeEPFbPv32UnityEngine_UnityEngine_UIVertexS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $tmpcast$byval_copy = sp + 120|0;
 $$byval_copy = sp;
 $ret = sp + 180|0;
 $0 = sp + 60|0;
 $1 = HEAP32[$args>>2]|0;
 dest=$0+0|0; src=$1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$tmpcast$byval_copy+0|0; src=$3+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1786904);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp;
 $L_1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1786952);
 __THREW__ = 0;
 invoke_vii(1526,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2857568|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2857568|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787096);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(946,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787000);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787048);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPF34UnityEngine_UnityEngine_UICharInfoPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2857568,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m__ctor_mscorlib_System_VoidP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787528);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1790448|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((1790448 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(1790448|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1790448|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3820,(1790448|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1790448|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((1790448 + 80|0))>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     $18 = (($__this) + 8|0);
     HEAP32[$18>>2] = $17;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z158mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787576);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1537,0,($collection|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1786296|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     $6 = (invoke_iii(2735,($collection|0),(1786296|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = ($6|0)==(0|0);
      if (!($9)) {
       __THREW__ = 0;
       invoke_vi(3799,($6|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       __THREW__ = 0;
       $31 = (invoke_iii(2736,(1785808|0),($6|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1185864|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
       __THREW__ = 0;
       $36 = (invoke_iii(2748,(1185864|0),($31|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       $39 = (($__this) + 8|0);
       HEAP32[$39>>2] = $36;
       __THREW__ = 0;
       invoke_vii(1532,($__this|0),($6|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1790448|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       $14 = HEAP8[((1790448 + 116|0))>>0]|0;
       $15 = ($14<<24>>24)==(0);
       if ($15) {
        __THREW__ = 0;
        (invoke_ii(2996,(1790448|0))|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1790448|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3820,(1790448|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1790448|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = HEAP32[((1790448 + 80|0))>>2]|0;
        $25 = HEAP32[$24>>2]|0;
        $26 = (($__this) + 8|0);
        HEAP32[$26>>2] = $25;
        __THREW__ = 0;
        invoke_vii(1533,($__this|0),($collection|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z95mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_CheckCollectionP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1789016);
 __THREW__ = 0;
 invoke_v(330);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($collection|0)==(0|0);
  if (!($2)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3021464>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3821,($7|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_AddEnumerableP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var $$0 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_1$byval_copy = 0, $__last_unhandled_exception$0 = 0;
 var $_stackTraceSentry = 0, $cond1 = 0, $cond2 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $L_1$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788680);
 __THREW__ = 0;
 invoke_vi(3799,($enumerable|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2739,(1786440|0),($enumerable|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 11;
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_iii(2741,(2176240|0),($2|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      label = 11;
      break;
     }
     if (!($13)) {
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 44;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 11;
      break;
     }
     __THREW__ = 0;
     invoke_viii(2118,($L_1|0),(1786664|0),($2|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      label = 11;
      break;
     }
     __THREW__ = 0;
     ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
     invoke_viii(2119,(1787864|0),($__this|0),($L_1$byval_copy|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      label = 11;
      break;
     }
    }
    if ((label|0) == 11) {
     $18 = ___cxa_find_matching_catch(348288|0)|0;
     $19 = tempRet0;
     $20 = (_llvm_eh_typeid_for((348288|0))|0);
     $21 = ($19|0)==($20|0);
     if (!($21)) {
      $$0 = $18;$$03 = $19;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$0|0);
      // unreachable;
     }
     $22 = (___cxa_begin_catch(($18|0))|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_v(66);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     $__last_unhandled_exception$0 = $23;$leaveInstructions$sroa$0$0 = 0;
    }
    $26 = ($2|0)==(0|0);
    if ($26) {
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(44);
     if ($cond1) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3821,($__last_unhandled_exception$0|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __THREW__ = 0;
     invoke_vii(3491,(2176768|0),($2|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $cond2 = ($leaveInstructions$sroa$0$0|0)==(44);
      if ($cond2) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3821,($__last_unhandled_exception$0|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $$0 = $5;$$03 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_AddCollectionP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788632);
 __THREW__ = 0;
 invoke_vi(3799,($collection|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2736,(1785808|0),($collection|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vii(1531,($__this|0),($2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($__this) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($__this) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($collection|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_viiii(464,(1786104|0),($collection|0),($11|0),($13|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = HEAP32[$12>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $23 = (($20) + ($2))|0;
        HEAP32[$12>>2] = $23;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z128mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787624);
 __THREW__ = 0;
 invoke_v(325);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($capacity|0)>(-1);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(1185864|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_iii(2748,(1185864|0),($capacity|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = (($__this) + 8|0);
     HEAP32[$22>>2] = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2561352|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[3021392>>2]|0;
      __THREW__ = 0;
      invoke_vii(1926,($9|0),($12|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3821,($9|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787672);
 __THREW__ = 0;
 (invoke_ii(2996,(1185864|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2748,(1185864|0),0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1790448|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[((1790448 + 80|0))>>2]|0;
    HEAP32[$7>>2] = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z143mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 48|0;
 $L_0 = sp;
 $L_1 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787720);
 __THREW__ = 0;
 invoke_vii(1535,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;HEAP32[$L_1+20>>2]=HEAP32[$L_0+20>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1791184|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1791184|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_GetEnumeratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788872);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1540,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_ICollection_CopyToP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787768);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(55,(0|0),($1|0),0,($_____array|0),($arrayIndex|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z108mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_AddP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787816);
 __THREW__ = 0;
 invoke_v(326);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2857568|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2749,($item|0),(2857568|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$4+8>>2]|0;
     invoke_viii(2119,(1787864|0),($__this|0),($tmpcast$byval_copy|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($__this) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = (($10) + -1)|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($11|0);
     }
    }
   }
   $14 = ___cxa_find_matching_catch(348288|0)|0;
   $15 = tempRet0;
   $16 = (_llvm_eh_typeid_for((348288|0))|0);
   $17 = ($15|0)==($16|0);
   if (!($17)) {
    $$02 = $14;$$03 = $15;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
   $18 = (___cxa_begin_catch(($14|0))|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   __THREW__ = 0;
   $21 = (invoke_iii(2727,(2623248|0),($20|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   do {
    if (!($23)) {
     if (!($21)) {
      $28 = HEAP32[$18>>2]|0;
      $29 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iii(2727,(2607384|0),($29|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      if (!($30)) {
       $33 = (___cxa_allocate_exception(4)|0);
       $34 = HEAP32[$18>>2]|0;
       HEAP32[$33>>2] = $34;
       __THREW__ = 0;
       invoke_viii(1567,($33|0),(348288|0),(0|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_v(66);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break L1;
     }
     __THREW__ = 0;
     $41 = (invoke_ii(3469,(2560072|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break L1;
     }
     $44 = HEAP32[3021408>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($41|0),($44|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3821,($41|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $24 = ___cxa_find_matching_catch()|0;
   $25 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    $49 = ___cxa_find_matching_catch(0|0)|0;
    $50 = tempRet0;
    ___clang_call_terminate($49);
    // unreachable;
   } else {
    $$02 = $24;$$03 = $25;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $$02 = $12;$$03 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN18VirtActionInvoker1I40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UICharInfo($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, $p1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p1$byval_copy = sp + 8|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 ;HEAP32[$p1$byval_copy+0>>2]=HEAP32[$p1+0>>2]|0;HEAP32[$p1$byval_copy+4>>2]=HEAP32[$p1+4>>2]|0;HEAP32[$p1$byval_copy+8>>2]=HEAP32[$p1+8>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($4,$p1$byval_copy);
 STACKTOP = sp;return;
}
function __Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_ContainsP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787912);
 __THREW__ = 0;
 (invoke_ii(2996,(2857568|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2749,($item|0),(2857568|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;
   $5 = (invoke_iiii(1657,(1787960|0),($__this|0),($tmpcast$byval_copy|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $$0 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch(348288|0)|0;
 $9 = tempRet0;
 $10 = (_llvm_eh_typeid_for((348288|0))|0);
 $11 = ($9|0)==($10|0);
 if (!($11)) {
  $$02 = $9;$$03 = $8;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 $12 = (___cxa_begin_catch(($8|0))|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 __THREW__ = 0;
 $15 = (invoke_iii(2727,(2623248|0),($14|0))|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if (!($17)) {
   if (!($15)) {
    $22 = HEAP32[$12>>2]|0;
    $23 = HEAP32[$22>>2]|0;
    __THREW__ = 0;
    $24 = (invoke_iii(2727,(2607384|0),($23|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    if (!($24)) {
     $27 = (___cxa_allocate_exception(4)|0);
     $28 = HEAP32[$12>>2]|0;
     HEAP32[$27>>2] = $28;
     __THREW__ = 0;
     invoke_viii(1567,($27|0),(348288|0),(0|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $33 = ___cxa_find_matching_catch()|0;
   $34 = tempRet0;
   $$02 = $34;$$03 = $33;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $35 = ___cxa_find_matching_catch(0|0)|0;
  $36 = tempRet0;
  ___clang_call_terminate($35);
  // unreachable;
 } else {
  $$02 = $19;$$03 = $18;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UICharInfo($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, $p1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p1$byval_copy = sp + 8|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 ;HEAP32[$p1$byval_copy+0>>2]=HEAP32[$p1+0>>2]|0;HEAP32[$p1$byval_copy+4>>2]=HEAP32[$p1+4>>2]|0;HEAP32[$p1$byval_copy+8>>2]=HEAP32[$p1+8>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1$byval_copy)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z112mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_IndexOfP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788008);
 __THREW__ = 0;
 (invoke_ii(2996,(2857568|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2749,($item|0),(2857568|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;
   $5 = (invoke_iiii(1658,(1788056|0),($__this|0),($tmpcast$byval_copy|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $$0 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch(348288|0)|0;
 $9 = tempRet0;
 $10 = (_llvm_eh_typeid_for((348288|0))|0);
 $11 = ($9|0)==($10|0);
 if (!($11)) {
  $$02 = $9;$$03 = $8;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 $12 = (___cxa_begin_catch(($8|0))|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 __THREW__ = 0;
 $15 = (invoke_iii(2727,(2623248|0),($14|0))|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 do {
  if (!($17)) {
   if (!($15)) {
    $22 = HEAP32[$12>>2]|0;
    $23 = HEAP32[$22>>2]|0;
    __THREW__ = 0;
    $24 = (invoke_iii(2727,(2607384|0),($23|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    if (!($24)) {
     $27 = (___cxa_allocate_exception(4)|0);
     $28 = HEAP32[$12>>2]|0;
     HEAP32[$27>>2] = $28;
     __THREW__ = 0;
     invoke_viii(1567,($27|0),(348288|0),(0|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    $$0 = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $33 = ___cxa_find_matching_catch()|0;
   $34 = tempRet0;
   $$02 = $34;$$03 = $33;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $35 = ___cxa_find_matching_catch(0|0)|0;
  $36 = tempRet0;
  ___clang_call_terminate($35);
  // unreachable;
 } else {
  $$02 = $19;$$03 = $18;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UICharInfo($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, $p1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p1$byval_copy = sp + 8|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 ;HEAP32[$p1$byval_copy+0>>2]=HEAP32[$p1+0>>2]|0;HEAP32[$p1$byval_copy+4>>2]=HEAP32[$p1+4>>2]|0;HEAP32[$p1$byval_copy+8>>2]=HEAP32[$p1+8>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1$byval_copy)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_InsertP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788104);
 __THREW__ = 0;
 invoke_v(327);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1536,($__this|0),($index|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2857568|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     $6 = (invoke_iii(2749,($item|0),(2857568|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$6+8>>2]|0;
      invoke_viiii(468,(1788152|0),($__this|0),($index|0),($tmpcast$byval_copy|0));
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if (!($10)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$0 = $13;$$02 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_iii(2727,(2623248|0),($19|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    do {
     if (!($22)) {
      if (!($20)) {
       $27 = HEAP32[$17>>2]|0;
       $28 = HEAP32[$27>>2]|0;
       __THREW__ = 0;
       $29 = (invoke_iii(2727,(2607384|0),($28|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       if (!($29)) {
        $32 = (___cxa_allocate_exception(4)|0);
        $33 = HEAP32[$17>>2]|0;
        HEAP32[$32>>2] = $33;
        __THREW__ = 0;
        invoke_viii(1567,($32|0),(348288|0),(0|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_v(66);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break L1;
      }
      __THREW__ = 0;
      $40 = (invoke_ii(3469,(2560072|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break L1;
      }
      $43 = HEAP32[3021432>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($40|0),($43|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3821,($40|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break L1;
      }
      // unreachable;
     }
    } while(0);
    $23 = ___cxa_find_matching_catch()|0;
    $24 = tempRet0;
    __THREW__ = 0;
    invoke_v(66);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     $48 = ___cxa_find_matching_catch(0|0)|0;
     $49 = tempRet0;
     ___clang_call_terminate($48);
     // unreachable;
    } else {
     $$0 = $23;$$02 = $24;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$0 = $11;$$02 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_CheckIndexP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788968);
 __THREW__ = 0;
 invoke_v(329);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($index|0)<(0);
  if (!($2)) {
   $5 = (($__this) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)<($index|0);
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_ii(3469,(2561352|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[3021448>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_vi(3821,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __ZN18VirtActionInvoker2I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPvi34UnityEngine_UnityEngine_UICharInfo($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, $p2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p2$byval_copy = sp + 8|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 ;HEAP32[$p2$byval_copy+0>>2]=HEAP32[$p2+0>>2]|0;HEAP32[$p2$byval_copy+4>>2]=HEAP32[$p2+4>>2]|0;HEAP32[$p2$byval_copy+8>>2]=HEAP32[$p2+8>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2$byval_copy);
 STACKTOP = sp;return;
}
function __Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_RemoveP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788200);
 __THREW__ = 0;
 (invoke_ii(2996,(2857568|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2749,($item|0),(2857568|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;
   (invoke_iiii(1657,(1788248|0),($__this|0),($tmpcast$byval_copy|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $7 = ___cxa_find_matching_catch(348288|0)|0;
 $8 = tempRet0;
 $9 = (_llvm_eh_typeid_for((348288|0))|0);
 $10 = ($8|0)==($9|0);
 if (!($10)) {
  $$01 = $7;$$02 = $8;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$01|0);
  // unreachable;
 }
 $11 = (___cxa_begin_catch(($7|0))|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 __THREW__ = 0;
 $14 = (invoke_iii(2727,(2623248|0),($13|0))|0);
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 do {
  if (!($16)) {
   if (!($14)) {
    $21 = HEAP32[$11>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    $23 = (invoke_iii(2727,(2607384|0),($22|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    if (!($23)) {
     $26 = (___cxa_allocate_exception(4)|0);
     $27 = HEAP32[$11>>2]|0;
     HEAP32[$26>>2] = $27;
     __THREW__ = 0;
     invoke_viii(1567,($26|0),(348288|0),(0|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   $$01 = $32;$$02 = $33;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $34 = ___cxa_find_matching_catch(0|0)|0;
  $35 = tempRet0;
  ___clang_call_terminate($34);
  // unreachable;
 } else {
  $$01 = $17;$$02 = $18;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __Z144mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788296);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z123mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_ICollection_get_SyncRootP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788344);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_get_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp;
 $L_1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788392);
 __THREW__ = 0;
 invoke_viiii(469,($L_0|0),(1788440|0),($__this|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2857568|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2857568|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I40UnityEngine_UnityEngine_UICharInfoTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi($agg$result,$method,$obj,$p1) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($agg$result,$4,$p1);
 STACKTOP = sp;return;
}
function __Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_set_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788488);
 __THREW__ = 0;
 invoke_v(328);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2857568|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2749,($value|0),(2857568|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$4+8>>2]|0;
     invoke_viiii(468,(1788536|0),($__this|0),($index|0),($tmpcast$byval_copy|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
   $11 = ___cxa_find_matching_catch(348288|0)|0;
   $12 = tempRet0;
   $13 = (_llvm_eh_typeid_for((348288|0))|0);
   $14 = ($12|0)==($13|0);
   if (!($14)) {
    $$0 = $11;$$02 = $12;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $15 = (___cxa_begin_catch(($11|0))|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   __THREW__ = 0;
   $18 = (invoke_iii(2727,(2623248|0),($17|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   do {
    if (!($20)) {
     if (!($18)) {
      $25 = HEAP32[$15>>2]|0;
      $26 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      $27 = (invoke_iii(2727,(2607384|0),($26|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      if (!($27)) {
       $30 = (___cxa_allocate_exception(4)|0);
       $31 = HEAP32[$15>>2]|0;
       HEAP32[$30>>2] = $31;
       __THREW__ = 0;
       invoke_viii(1567,($30|0),(348288|0),(0|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_v(66);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break L1;
     }
     __THREW__ = 0;
     $38 = (invoke_ii(3469,(2560072|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break L1;
     }
     $41 = HEAP32[3021344>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($38|0),($41|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3821,($38|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $21 = ___cxa_find_matching_catch()|0;
   $22 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    $46 = ___cxa_find_matching_catch(0|0)|0;
    $47 = tempRet0;
    ___clang_call_terminate($46);
    // unreachable;
   } else {
    $$0 = $21;$$02 = $22;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $$0 = $9;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z83mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_AddP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787864);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($3) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($1|0)==($7|0);
   if ($8) {
    __THREW__ = 0;
    invoke_vii(1531,($__this|0),1);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
   }
   $13 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($16) + 1)|0;
     HEAP32[$0>>2] = $19;
     __THREW__ = 0;
     invoke_vi(3799,($13|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = ($16|0)<(0);
      if ($22) {
       label = 10;
      } else {
       $23 = (($13) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($16>>>0)<($24>>>0);
       if (!($25)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $26 = (invoke_i(132)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[$13>>2]|0;
      $32 = (($13) + 16|0);
      $33 = (($31) + 92|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = Math_imul($34, $16)|0;
      $36 = (($32) + ($35)|0);
      ;HEAP32[$36+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$36+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$item+8>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = (($__this) + 16|0);
       $40 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        $43 = (($40) + 1)|0;
        HEAP32[$39>>2] = $43;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_GrowIfNeededP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788584);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($newCount))|0;
 $3 = (($__this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = (($4) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($2|0)>($8|0);
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  $12 = (invoke_ii(1356,($__this|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = $12 << 1;
   __THREW__ = 0;
   $16 = (invoke_iiii(1197,(0|0),($15|0),4)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_iiii(1197,(0|0),($16|0),($2|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vii(1539,($__this|0),($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_get_CapacityP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1789160);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_set_CapacityP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1789208);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>($value|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2561352|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2587,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3821,($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 } else {
  $14 = (($__this) + 8|0);
  __THREW__ = 0;
  invoke_viii(950,(0|0),($14|0),($value|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker0I40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPv($agg$result,$method,$obj) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($agg$result,$4);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_AddRangeP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788728);
 __THREW__ = 0;
 invoke_vii(1537,0,($collection|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1786296|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2735,($collection|0),(1786296|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      __THREW__ = 0;
      invoke_vii(1533,($__this|0),($collection|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
     } else {
      __THREW__ = 0;
      invoke_vii(1532,($__this|0),($4|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = (($__this) + 16|0);
      $17 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = (($17) + 1)|0;
       HEAP32[$16>>2] = $20;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_ClearP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788776);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($1|0),0,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($__this) + 12|0);
   HEAP32[$8>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($__this) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = (($12) + 1)|0;
     HEAP32[$11>>2] = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_ContainsP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $item$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $item$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1787960);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 ;HEAP32[$item$byval_copy+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$item$byval_copy+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$item$byval_copy+8>>2]=HEAP32[$item+8>>2]|0;
 $4 = (invoke_iiiiii(148,(0|0),($1|0),($item$byval_copy|0),0,($3|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $7 = ($4|0)!=(-1);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($7|0);
 }
 return 0|0;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_CopyToP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP38UnityEngine_UnityEngine_UICharInfo_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788824);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(55,(0|0),($1|0),0,($_____array|0),($arrayIndex|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z96mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m__ctorP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfoP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1790592);
 HEAP32[$__this>>2] = $l;
 __THREW__ = 0;
 invoke_vi(3799,($l|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($l) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_IndexOfP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, $item$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $item$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788056);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 ;HEAP32[$item$byval_copy+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$item$byval_copy+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$item$byval_copy+8>>2]=HEAP32[$item+8>>2]|0;
 $4 = (invoke_iiiiii(148,(0|0),($1|0),($item$byval_copy|0),0,($3|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_ShiftP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $start$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788920);
 $0 = ($delta|0)>(-1);
 $1 = $0 ? 0 : $delta;
 $start$ = (($start) - ($1))|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($start$|0)<($3|0);
 if ($4) {
  $5 = (($__this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($start$) + ($delta))|0;
  $8 = (($3) - ($start$))|0;
  __THREW__ = 0;
  invoke_viiiiii(55,(0|0),($6|0),($start$|0),($6|0),($7|0),($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP32[$2>>2]|0;
   $14 = (($13) + ($delta))|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    HEAP32[$2>>2] = $14;
    if ($0) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (0 - ($delta))|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($20|0),($14|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_InsertP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi34UnityEngine_UnityEngine_UICharInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788152);
 __THREW__ = 0;
 invoke_vii(1536,($__this|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($__this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($5) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($3|0)==($9|0);
    if ($10) {
     __THREW__ = 0;
     invoke_vii(1531,($__this|0),1);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_viii(411,($__this|0),($index|0),1);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[$4>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = ($index|0)<(0);
      if ($20) {
       label = 10;
      } else {
       $21 = (($17) + 12|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($22>>>0)>($index>>>0);
       if (!($23)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $24 = (invoke_i(132)|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($24|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
      }
      $29 = HEAP32[$17>>2]|0;
      $30 = (($17) + 16|0);
      $31 = (($29) + 92|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = Math_imul($32, $index)|0;
      $34 = (($30) + ($33)|0);
      ;HEAP32[$34+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$34+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$34+8>>2]=HEAP32[$item+8>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       $37 = (($__this) + 16|0);
       $38 = HEAP32[$37>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if (!($40)) {
        $41 = (($38) + 1)|0;
        HEAP32[$37>>2] = $41;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_RemoveP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, $item$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $item$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788248);
 __THREW__ = 0;
 ;HEAP32[$item$byval_copy+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$item$byval_copy+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$item$byval_copy+8>>2]=HEAP32[$item+8>>2]|0;
 $0 = (invoke_iiii(1658,(1788056|0),($__this|0),($item$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 $3 = ($0|0)==(-1);
 if ($3) {
  $8 = $3 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 __THREW__ = 0;
 invoke_viii(2111,(1789064|0),($__this|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $8 = $3 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_RemoveAtP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1789064);
 __THREW__ = 0;
 invoke_v(331);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($index|0)<(0);
   if (!($2)) {
    $5 = (($__this) + 12|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)>($index|0);
    if ($7) {
     __THREW__ = 0;
     invoke_viii(411,($__this|0),($index|0),-1);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = (($__this) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$5>>2]|0;
     __THREW__ = 0;
     invoke_viiii(138,(0|0),($21|0),($22|0),1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = (($__this) + 16|0);
     $28 = HEAP32[$27>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     $31 = (($28) + 1)|0;
     HEAP32[$27>>2] = $31;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3021504>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3821,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_ToArrayP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1789112);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1185864|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2748,(1185864|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_viiii(140,(0|0),($8|0),($4|0),($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_get_CountP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1789256);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_get_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788440);
 __THREW__ = 0;
 invoke_v(332);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>($index|0);
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2561352|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021360>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = ($index|0)<(0);
    if ($21) {
     label = 12;
    } else {
     $22 = (($18) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23>>>0)>($index>>>0);
     if (!($24)) {
      label = 12;
     }
    }
    if ((label|0) == 12) {
     __THREW__ = 0;
     $25 = (invoke_i(132)|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($25|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    $30 = HEAP32[$18>>2]|0;
    $31 = (($18) + 16|0);
    $32 = (($30) + 92|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = Math_imul($33, $index)|0;
    $35 = (($31) + ($34)|0);
    ;HEAP32[$agg$result+0>>2]=HEAP32[$35+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$35+8>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_set_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi34UnityEngine_UnityEngine_UICharInfo($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1788536);
 __THREW__ = 0;
 invoke_v(333);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1536,($__this|0),($index|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($__this) + 12|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5|0)==($index|0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3021376>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3821,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = ($index|0)<(0);
     if ($23) {
      label = 13;
     } else {
      $24 = (($20) + 12|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25>>>0)>($index>>>0);
      if (!($26)) {
       label = 13;
      }
     }
     if ((label|0) == 13) {
      __THREW__ = 0;
      $27 = (invoke_i(132)|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($27|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
     }
     $32 = HEAP32[$20>>2]|0;
     $33 = (($20) + 16|0);
     $34 = (($32) + 92|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = Math_imul($35, $index)|0;
     $37 = (($33) + ($36)|0);
     ;HEAP32[$37+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$value+8>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __ZN14ActionInvoker1I40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPFvPv34UnityEngine_UnityEngine_UICharInfoES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPFbPv34UnityEngine_UnityEngine_UICharInfoES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 12|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker0I94mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPF88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfoPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1791184,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPFiPv34UnityEngine_UnityEngine_UICharInfoES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPFvPvi34UnityEngine_UnityEngine_UICharInfoES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I40UnityEngine_UnityEngine_UICharInfoTraits27mscorlib_System_Int32TraitsE6InvokeEPF34UnityEngine_UnityEngine_UICharInfoPviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2857568,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z133mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $L_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1790640);
 __THREW__ = 0;
 invoke_vi(1736,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(0);
   if ($4) {
    $16 = (($__this) + 12|0);
    ;HEAP32[$L_4+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$L_4+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$L_4+8>>2]=HEAP32[$16+8>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2857568|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_iii(2724,(2857568|0),($L_4|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2607872|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(2734,($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3821,($9|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_VerifyStateP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1790736);
 __THREW__ = 0;
 invoke_v(324);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if (!($3)) {
    $30 = (($__this) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($2) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($31|0)==($35|0);
    if ($36) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3469,(2607872|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    $42 = HEAP32[3021520>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($39|0),($42|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($39|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    // unreachable;
   }
   ;HEAP32[$L_1+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$__this+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$__this+16>>2]|0;HEAP32[$L_1+20>>2]=HEAP32[$__this+20>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1791184|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2724,(1791184|0),($L_1|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(1782,($8|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(3799,($13|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        $18 = (invoke_iii(2730,(2150320|0),($13|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2634432|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          $23 = (invoke_ii(3469,(2634432|0))|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           __THREW__ = 0;
           invoke_vii(1970,($23|0),($18|0));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            invoke_vi(3821,($23|0));
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             // unreachable;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_DisposeP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1790688);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_MoveNextP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1790784);
 __THREW__ = 0;
 invoke_vi(1736,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $7 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($7|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($7) + 12|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($3|0)<($11|0);
    if (!($12)) {
     HEAP32[$2>>2] = -1;
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $13 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = (($13) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = HEAP32[$2>>2]|0;
     $19 = (($18) + 1)|0;
     HEAP32[$2>>2] = $19;
     __THREW__ = 0;
     invoke_vi(3799,($17|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = ($18|0)<(0);
      if ($22) {
       label = 10;
      } else {
       $23 = (($17) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($18>>>0)<($24>>>0);
       if (!($25)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $26 = (invoke_i(132)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[$17>>2]|0;
      $32 = (($17) + 16|0);
      $33 = (($31) + 92|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = Math_imul($34, $18)|0;
      $36 = (($32) + ($35)|0);
      $37 = (($__this) + 12|0);
      _memmove(($37|0),($36|0),12)|0;
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_get_CurrentP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1790832);
 $0 = (($__this) + 12|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z97mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m__ctorP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1791328);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z98mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1791376);
 __THREW__ = 0;
 (invoke_ii(2996,(1792992|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1792992|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1739,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1791968|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1791968 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z113mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo_m__ctorP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1792656);
 __THREW__ = 0;
 invoke_vi(1737,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z140mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IEqualityComparer_GetHashCodeP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1791424);
 __THREW__ = 0;
 (invoke_ii(2996,(2857568|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2749,($obj|0),(2857568|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;
   $5 = (invoke_iiii(1658,(1791472|0),($__this|0),($tmpcast$byval_copy|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z135mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IEqualityComparer_EqualsP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy1 = sp + 80|0;
 $$byval_copy = sp + 40|0;
 $data$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 16|0;
 $_stackTraceSentry = sp + 52|0;
 $L_1 = sp + 56|0;
 $2 = sp + 68|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1791520);
 __THREW__ = 0;
 (invoke_ii(2996,(2857568|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2749,($x|0),(2857568|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   ;HEAP32[$L_1+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$5+8>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2857568|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2749,($y|0),(2857568|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     ;HEAP32[$2+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$10+8>>2]|0;
     ;HEAP32[$1+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$L_1+8>>2]|0;
     ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;
     __THREW__ = 0;
     invoke_viii(2112,($data$i|0),(1791568|0),($__this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = (($data$i) + 4|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = (($16) + 4|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = HEAP32[$data$i>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;
      $20 = (invoke_iiii($18|0,($19|0),($$byval_copy|0),($$byval_copy1|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($20|0);
      }
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1791616);
 __THREW__ = 0;
 (invoke_ii(2996,(1791968|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1791968 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1791968|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1791968|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3820,(1791968|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1791968|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1791968 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo_m_GetHashCodeP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1792704);
 ;HEAP32[$L_0+0>>2]=HEAP32[$obj+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$obj+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$obj+8>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2857568|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2857568|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2857568|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2857568|0),($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2857568|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(2857568|0),($obj|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2148880|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $$0 = $20;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z114mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo_m_EqualsP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfoS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 36|0;
 $L_0 = sp;
 $L_2 = sp + 12|0;
 $L_5 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1792752);
 ;HEAP32[$L_0+0>>2]=HEAP32[$x+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$x+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$x+8>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2857568|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2724,(2857568|0),($L_0|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$y+8>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2857568|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2724,(2857568|0),($L_2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = ($10|0)==(0|0);
     $$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    ;HEAP32[$L_5+0>>2]=HEAP32[$y+0>>2]|0;HEAP32[$L_5+4>>2]=HEAP32[$y+4>>2]|0;HEAP32[$L_5+8>>2]=HEAP32[$y+8>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2857568|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2857568|0),($L_5|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2857568|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_iii(2724,(2857568|0),($x|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2857568|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_iii(2724,(2857568|0),($x|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           __THREW__ = 0;
           $31 = (invoke_iiii(1644,(2148736|0),($28|0),($16|0))|0);
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            $$0 = $31;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UICharInfoTraitsS1_E6InvokeEPFbPv34UnityEngine_UnityEngine_UICharInfoS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 24|0;
 $$byval_copy = sp;
 $ret = sp + 36|0;
 $0 = sp + 12|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1794776);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1794824);
 __THREW__ = 0;
 invoke_vii(1543,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2857840|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2857840|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1794968);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(951,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1794872);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1794920);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPF34UnityEngine_UnityEngine_UILineInfoPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2857840,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m__ctor_mscorlib_System_VoidP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795400);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1798320|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((1798320 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(1798320|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1798320|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3820,(1798320|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1798320|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((1798320 + 80|0))>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     $18 = (($__this) + 8|0);
     HEAP32[$18>>2] = $17;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z158mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795448);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1554,0,($collection|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1794168|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     $6 = (invoke_iii(2735,($collection|0),(1794168|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = ($6|0)==(0|0);
      if (!($9)) {
       __THREW__ = 0;
       invoke_vi(3799,($6|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       __THREW__ = 0;
       $31 = (invoke_iii(2736,(1793680|0),($6|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1186248|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
       __THREW__ = 0;
       $36 = (invoke_iii(2748,(1186248|0),($31|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       $39 = (($__this) + 8|0);
       HEAP32[$39>>2] = $36;
       __THREW__ = 0;
       invoke_vii(1549,($__this|0),($6|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1798320|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       $14 = HEAP8[((1798320 + 116|0))>>0]|0;
       $15 = ($14<<24>>24)==(0);
       if ($15) {
        __THREW__ = 0;
        (invoke_ii(2996,(1798320|0))|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1798320|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3820,(1798320|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1798320|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = HEAP32[((1798320 + 80|0))>>2]|0;
        $25 = HEAP32[$24>>2]|0;
        $26 = (($__this) + 8|0);
        HEAP32[$26>>2] = $25;
        __THREW__ = 0;
        invoke_vii(1550,($__this|0),($collection|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z95mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_CheckCollectionP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796888);
 __THREW__ = 0;
 invoke_v(330);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($collection|0)==(0|0);
  if (!($2)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3021464>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3821,($7|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_AddEnumerableP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var $$0 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond2 = 0, $leaveInstructions$sroa$0$0 = 0, $tmpcast4$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast4$byval_copy = sp + 24|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 $0 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796552);
 __THREW__ = 0;
 invoke_vi(3799,($enumerable|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2739,(1794312|0),($enumerable|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 11;
      break;
     }
     __THREW__ = 0;
     $24 = (invoke_iii(2741,(2176240|0),($3|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 11;
      break;
     }
     if (!($24)) {
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 44;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 11;
      break;
     }
     __THREW__ = 0;
     invoke_viii(2120,($L_1|0),(1794536|0),($3|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      label = 11;
      break;
     }
     $10 = $L_1;
     $11 = $10;
     $12 = HEAP32[$11>>2]|0;
     $13 = (($10) + 4)|0;
     $14 = $13;
     $15 = HEAP32[$14>>2]|0;
     $16 = $0;
     $17 = $16;
     HEAP32[$17>>2] = $12;
     $18 = (($16) + 4)|0;
     $19 = $18;
     HEAP32[$19>>2] = $15;
     __THREW__ = 0;
     ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     invoke_viii(2121,(1795736|0),($__this|0),($tmpcast4$byval_copy|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      label = 11;
      break;
     }
    }
    if ((label|0) == 11) {
     $29 = ___cxa_find_matching_catch(348288|0)|0;
     $30 = tempRet0;
     $31 = (_llvm_eh_typeid_for((348288|0))|0);
     $32 = ($30|0)==($31|0);
     if (!($32)) {
      $$0 = $29;$$03 = $30;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$0|0);
      // unreachable;
     }
     $33 = (___cxa_begin_catch(($29|0))|0);
     $34 = HEAP32[$33>>2]|0;
     __THREW__ = 0;
     invoke_v(66);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     $__last_unhandled_exception$0 = $34;$leaveInstructions$sroa$0$0 = 0;
    }
    $37 = ($3|0)==(0|0);
    if ($37) {
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(44);
     if ($cond1) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3821,($__last_unhandled_exception$0|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if (!($41)) {
     __THREW__ = 0;
     invoke_vii(3491,(2176768|0),($3|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      $cond2 = ($leaveInstructions$sroa$0$0|0)==(44);
      if ($cond2) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3821,($__last_unhandled_exception$0|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $$0 = $6;$$03 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_AddCollectionP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796504);
 __THREW__ = 0;
 invoke_vi(3799,($collection|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2736,(1793680|0),($collection|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vii(1548,($__this|0),($2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($__this) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($__this) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($collection|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_viiii(464,(1793976|0),($collection|0),($11|0),($13|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = HEAP32[$12>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $23 = (($20) + ($2))|0;
        HEAP32[$12>>2] = $23;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z128mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795496);
 __THREW__ = 0;
 invoke_v(325);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($capacity|0)>(-1);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(1186248|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_iii(2748,(1186248|0),($capacity|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = (($__this) + 8|0);
     HEAP32[$22>>2] = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2561352|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[3021392>>2]|0;
      __THREW__ = 0;
      invoke_vii(1926,($9|0),($12|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3821,($9|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795544);
 __THREW__ = 0;
 (invoke_ii(2996,(1186248|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2748,(1186248|0),0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1798320|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[((1798320 + 80|0))>>2]|0;
    HEAP32[$7>>2] = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z143mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795592);
 __THREW__ = 0;
 invoke_vii(1552,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1799056|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1799056|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_GetEnumeratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796744);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1557,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_ICollection_CopyToP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795640);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(55,(0|0),($1|0),0,($_____array|0),($arrayIndex|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z108mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_AddP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795688);
 __THREW__ = 0;
 invoke_v(326);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2857840|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2749,($item|0),(2857840|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = $5;
     $9 = $8;
     $10 = HEAP32[$9>>2]|0;
     $11 = (($8) + 4)|0;
     $12 = $11;
     $13 = HEAP32[$12>>2]|0;
     $14 = $0;
     $15 = $14;
     HEAP32[$15>>2] = $10;
     $16 = (($14) + 4)|0;
     $17 = $16;
     HEAP32[$17>>2] = $13;
     __THREW__ = 0;
     ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     invoke_viii(2121,(1795736|0),($__this|0),($tmpcast$byval_copy|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = (($__this) + 12|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($21) + -1)|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($22|0);
     }
    }
   }
   $25 = ___cxa_find_matching_catch(348288|0)|0;
   $26 = tempRet0;
   $27 = (_llvm_eh_typeid_for((348288|0))|0);
   $28 = ($26|0)==($27|0);
   if (!($28)) {
    $$02 = $25;$$03 = $26;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
   $29 = (___cxa_begin_catch(($25|0))|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$30>>2]|0;
   __THREW__ = 0;
   $32 = (invoke_iii(2727,(2623248|0),($31|0))|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   do {
    if (!($34)) {
     if (!($32)) {
      $39 = HEAP32[$29>>2]|0;
      $40 = HEAP32[$39>>2]|0;
      __THREW__ = 0;
      $41 = (invoke_iii(2727,(2607384|0),($40|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      }
      if (!($41)) {
       $44 = (___cxa_allocate_exception(4)|0);
       $45 = HEAP32[$29>>2]|0;
       HEAP32[$44>>2] = $45;
       __THREW__ = 0;
       invoke_viii(1567,($44|0),(348288|0),(0|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_v(66);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     }
     __THREW__ = 0;
     $52 = (invoke_ii(3469,(2560072|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break L1;
     }
     $55 = HEAP32[3021408>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($52|0),($55|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3821,($52|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $35 = ___cxa_find_matching_catch()|0;
   $36 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    $60 = ___cxa_find_matching_catch(0|0)|0;
    $61 = tempRet0;
    ___clang_call_terminate($60);
    // unreachable;
   } else {
    $$02 = $35;$$03 = $36;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $$02 = $23;$$03 = $24;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN18VirtActionInvoker1I40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UILineInfo($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $data = sp + 8|0;
 $0 = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$data>>2]|0;
 $6 = $p1;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($5,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_ContainsP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795784);
 __THREW__ = 0;
 (invoke_ii(2996,(2857840|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2749,($item|0),(2857840|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $0;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   $16 = (invoke_iiii(1659,(1795832|0),($__this|0),($tmpcast$byval_copy|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $$0 = $16;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $19 = ___cxa_find_matching_catch(348288|0)|0;
 $20 = tempRet0;
 $21 = (_llvm_eh_typeid_for((348288|0))|0);
 $22 = ($20|0)==($21|0);
 if (!($22)) {
  $$02 = $20;$$03 = $19;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 $23 = (___cxa_begin_catch(($19|0))|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 __THREW__ = 0;
 $26 = (invoke_iii(2727,(2623248|0),($25|0))|0);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 do {
  if (!($28)) {
   if (!($26)) {
    $33 = HEAP32[$23>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    __THREW__ = 0;
    $35 = (invoke_iii(2727,(2607384|0),($34|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    if (!($35)) {
     $38 = (___cxa_allocate_exception(4)|0);
     $39 = HEAP32[$23>>2]|0;
     HEAP32[$38>>2] = $39;
     __THREW__ = 0;
     invoke_viii(1567,($38|0),(348288|0),(0|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   $$02 = $45;$$03 = $44;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $46 = ___cxa_find_matching_catch(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 } else {
  $$02 = $30;$$03 = $29;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UILineInfo($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $tmpcast$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $data = sp + 8|0;
 $0 = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$data>>2]|0;
 $6 = $p1;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $16 = (FUNCTION_TABLE_iii[$4 & 4095]($5,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($16|0);
}
function __Z112mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_IndexOfP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795880);
 __THREW__ = 0;
 (invoke_ii(2996,(2857840|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2749,($item|0),(2857840|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $0;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   $16 = (invoke_iiii(1660,(1795928|0),($__this|0),($tmpcast$byval_copy|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $$0 = $16;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $19 = ___cxa_find_matching_catch(348288|0)|0;
 $20 = tempRet0;
 $21 = (_llvm_eh_typeid_for((348288|0))|0);
 $22 = ($20|0)==($21|0);
 if (!($22)) {
  $$02 = $20;$$03 = $19;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 $23 = (___cxa_begin_catch(($19|0))|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 __THREW__ = 0;
 $26 = (invoke_iii(2727,(2623248|0),($25|0))|0);
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 do {
  if (!($28)) {
   if (!($26)) {
    $33 = HEAP32[$23>>2]|0;
    $34 = HEAP32[$33>>2]|0;
    __THREW__ = 0;
    $35 = (invoke_iii(2727,(2607384|0),($34|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    if (!($35)) {
     $38 = (___cxa_allocate_exception(4)|0);
     $39 = HEAP32[$23>>2]|0;
     HEAP32[$38>>2] = $39;
     __THREW__ = 0;
     invoke_viii(1567,($38|0),(348288|0),(0|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    $$0 = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $44 = ___cxa_find_matching_catch()|0;
   $45 = tempRet0;
   $$02 = $45;$$03 = $44;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$03|0);
   // unreachable;
  }
 } while(0);
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $46 = ___cxa_find_matching_catch(0|0)|0;
  $47 = tempRet0;
  ___clang_call_terminate($46);
  // unreachable;
 } else {
  $$02 = $30;$$03 = $29;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$03|0);
  // unreachable;
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UILineInfo($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $tmpcast$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $data = sp + 8|0;
 $0 = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$data>>2]|0;
 $6 = $p1;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $16 = (FUNCTION_TABLE_iii[$4 & 4095]($5,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($16|0);
}
function __Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_InsertP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795976);
 __THREW__ = 0;
 invoke_v(327);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vii(1553,($__this|0),($index|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2857840|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(2749,($item|0),(2857840|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = $7;
      $11 = $10;
      $12 = HEAP32[$11>>2]|0;
      $13 = (($10) + 4)|0;
      $14 = $13;
      $15 = HEAP32[$14>>2]|0;
      $16 = $0;
      $17 = $16;
      HEAP32[$17>>2] = $12;
      $18 = (($16) + 4)|0;
      $19 = $18;
      HEAP32[$19>>2] = $15;
      __THREW__ = 0;
      ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
      invoke_viiii(470,(1796024|0),($__this|0),($index|0),($tmpcast$byval_copy|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
    $24 = ___cxa_find_matching_catch(348288|0)|0;
    $25 = tempRet0;
    $26 = (_llvm_eh_typeid_for((348288|0))|0);
    $27 = ($25|0)==($26|0);
    if (!($27)) {
     $$0 = $24;$$02 = $25;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
    $28 = (___cxa_begin_catch(($24|0))|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iii(2727,(2623248|0),($30|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    do {
     if (!($33)) {
      if (!($31)) {
       $38 = HEAP32[$28>>2]|0;
       $39 = HEAP32[$38>>2]|0;
       __THREW__ = 0;
       $40 = (invoke_iii(2727,(2607384|0),($39|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
       if (!($40)) {
        $43 = (___cxa_allocate_exception(4)|0);
        $44 = HEAP32[$28>>2]|0;
        HEAP32[$43>>2] = $44;
        __THREW__ = 0;
        invoke_viii(1567,($43|0),(348288|0),(0|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_v(66);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break L1;
      }
      __THREW__ = 0;
      $51 = (invoke_ii(3469,(2560072|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break L1;
      }
      $54 = HEAP32[3021432>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($51|0),($54|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3821,($51|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break L1;
      }
      // unreachable;
     }
    } while(0);
    $34 = ___cxa_find_matching_catch()|0;
    $35 = tempRet0;
    __THREW__ = 0;
    invoke_v(66);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $59 = ___cxa_find_matching_catch(0|0)|0;
     $60 = tempRet0;
     ___clang_call_terminate($59);
     // unreachable;
    } else {
     $$0 = $34;$$02 = $35;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $$0 = $22;$$02 = $23;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_CheckIndexP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796840);
 __THREW__ = 0;
 invoke_v(329);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($index|0)<(0);
  if (!($2)) {
   $5 = (($__this) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)<($index|0);
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_ii(3469,(2561352|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP32[3021448>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_vi(3821,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __ZN18VirtActionInvoker2I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPvi34UnityEngine_UnityEngine_UILineInfo($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $data = sp + 8|0;
 $0 = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $1 = (($data) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$data>>2]|0;
 $6 = $p2;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$4 & 4095]($5,$p1,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_RemoveP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796072);
 __THREW__ = 0;
 (invoke_ii(2996,(2857840|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2749,($item|0),(2857840|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $0;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   (invoke_iiii(1659,(1796120|0),($__this|0),($tmpcast$byval_copy|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $18 = ___cxa_find_matching_catch(348288|0)|0;
 $19 = tempRet0;
 $20 = (_llvm_eh_typeid_for((348288|0))|0);
 $21 = ($19|0)==($20|0);
 if (!($21)) {
  $$01 = $18;$$02 = $19;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$01|0);
  // unreachable;
 }
 $22 = (___cxa_begin_catch(($18|0))|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 __THREW__ = 0;
 $25 = (invoke_iii(2727,(2623248|0),($24|0))|0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 do {
  if (!($27)) {
   if (!($25)) {
    $32 = HEAP32[$22>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_iii(2727,(2607384|0),($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    if (!($34)) {
     $37 = (___cxa_allocate_exception(4)|0);
     $38 = HEAP32[$22>>2]|0;
     HEAP32[$37>>2] = $38;
     __THREW__ = 0;
     invoke_viii(1567,($37|0),(348288|0),(0|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   invoke_v(66);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if (!($42)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $43 = ___cxa_find_matching_catch()|0;
   $44 = tempRet0;
   $$01 = $43;$$02 = $44;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $45 = ___cxa_find_matching_catch(0|0)|0;
  $46 = tempRet0;
  ___clang_call_terminate($45);
  // unreachable;
 } else {
  $$01 = $28;$$02 = $29;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($$01|0);
  // unreachable;
 }
}
function __Z144mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796168);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z123mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_ICollection_get_SyncRootP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796216);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_get_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796264);
 __THREW__ = 0;
 invoke_viiii(471,($L_0|0),(1796312|0),($__this|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2857840|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2857840|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I40UnityEngine_UnityEngine_UILineInfoTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi($agg$result,$method,$obj,$p1) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($agg$result,$4,$p1);
 STACKTOP = sp;return;
}
function __Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_set_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796360);
 __THREW__ = 0;
 invoke_v(328);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2857840|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2749,($value|0),(2857840|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = $5;
     $9 = $8;
     $10 = HEAP32[$9>>2]|0;
     $11 = (($8) + 4)|0;
     $12 = $11;
     $13 = HEAP32[$12>>2]|0;
     $14 = $0;
     $15 = $14;
     HEAP32[$15>>2] = $10;
     $16 = (($14) + 4)|0;
     $17 = $16;
     HEAP32[$17>>2] = $13;
     __THREW__ = 0;
     ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     invoke_viiii(470,(1796408|0),($__this|0),($index|0),($tmpcast$byval_copy|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
   $22 = ___cxa_find_matching_catch(348288|0)|0;
   $23 = tempRet0;
   $24 = (_llvm_eh_typeid_for((348288|0))|0);
   $25 = ($23|0)==($24|0);
   if (!($25)) {
    $$0 = $22;$$02 = $23;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $26 = (___cxa_begin_catch(($22|0))|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   __THREW__ = 0;
   $29 = (invoke_iii(2727,(2623248|0),($28|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   do {
    if (!($31)) {
     if (!($29)) {
      $36 = HEAP32[$26>>2]|0;
      $37 = HEAP32[$36>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_iii(2727,(2607384|0),($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      if (!($38)) {
       $41 = (___cxa_allocate_exception(4)|0);
       $42 = HEAP32[$26>>2]|0;
       HEAP32[$41>>2] = $42;
       __THREW__ = 0;
       invoke_viii(1567,($41|0),(348288|0),(0|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_v(66);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break L1;
     }
     __THREW__ = 0;
     $49 = (invoke_ii(3469,(2560072|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     }
     $52 = HEAP32[3021344>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($49|0),($52|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3821,($49|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $57 = ___cxa_find_matching_catch(0|0)|0;
    $58 = tempRet0;
    ___clang_call_terminate($57);
    // unreachable;
   } else {
    $$0 = $32;$$02 = $33;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $$0 = $20;$$02 = $21;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z83mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_AddP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795736);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($3) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($1|0)==($7|0);
   if ($8) {
    __THREW__ = 0;
    invoke_vii(1548,($__this|0),1);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
   }
   $13 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($16) + 1)|0;
     HEAP32[$0>>2] = $19;
     __THREW__ = 0;
     invoke_vi(3799,($13|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = ($16|0)<(0);
      if ($22) {
       label = 10;
      } else {
       $23 = (($13) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($16>>>0)<($24>>>0);
       if (!($25)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $26 = (invoke_i(132)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[$13>>2]|0;
      $32 = (($13) + 16|0);
      $33 = (($31) + 92|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = Math_imul($34, $16)|0;
      $36 = (($32) + ($35)|0);
      $37 = $item;
      $38 = $37;
      $39 = HEAP32[$38>>2]|0;
      $40 = (($37) + 4)|0;
      $41 = $40;
      $42 = HEAP32[$41>>2]|0;
      $43 = $36;
      $44 = $43;
      HEAP32[$44>>2] = $39;
      $45 = (($43) + 4)|0;
      $46 = $45;
      HEAP32[$46>>2] = $42;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if (!($48)) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$49>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if (!($52)) {
        $53 = (($50) + 1)|0;
        HEAP32[$49>>2] = $53;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_GrowIfNeededP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796456);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($newCount))|0;
 $3 = (($__this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  $7 = (($4) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($2|0)>($8|0);
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  $12 = (invoke_ii(1367,($__this|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = $12 << 1;
   __THREW__ = 0;
   $16 = (invoke_iiii(1197,(0|0),($15|0),4)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_iiii(1197,(0|0),($16|0),($2|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vii(1556,($__this|0),($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_get_CapacityP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1797032);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_set_CapacityP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1797080);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>($value|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2561352|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2587,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3821,($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 } else {
  $14 = (($__this) + 8|0);
  __THREW__ = 0;
  invoke_viii(955,(0|0),($14|0),($value|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker0I40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPv($agg$result,$method,$obj) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($agg$result,$4);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_AddRangeP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796600);
 __THREW__ = 0;
 invoke_vii(1554,0,($collection|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1794168|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2735,($collection|0),(1794168|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      __THREW__ = 0;
      invoke_vii(1550,($__this|0),($collection|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
     } else {
      __THREW__ = 0;
      invoke_vii(1549,($__this|0),($4|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = (($__this) + 16|0);
      $17 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = (($17) + 1)|0;
       HEAP32[$16>>2] = $20;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_ClearP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796648);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($1|0),0,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($__this) + 12|0);
   HEAP32[$8>>2] = 0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($__this) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = (($12) + 1)|0;
     HEAP32[$11>>2] = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_ContainsP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795832);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $item;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $15 = (invoke_iiiiii(149,(0|0),($2|0),($tmpcast$byval_copy|0),0,($4|0))|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $18 = ($15|0)!=(-1);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($18|0);
 }
 return 0|0;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_CopyToP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP38UnityEngine_UnityEngine_UILineInfo_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796696);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(55,(0|0),($1|0),0,($_____array|0),($arrayIndex|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z96mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m__ctorP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfoP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1798464);
 HEAP32[$__this>>2] = $l;
 __THREW__ = 0;
 invoke_vi(3799,($l|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($l) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_IndexOfP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1795928);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $item;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $15 = (invoke_iiiiii(149,(0|0),($2|0),($tmpcast$byval_copy|0),0,($4|0))|0);
 $16 = __THREW__; __THREW__ = 0;
 $17 = $16&1;
 if ($17) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($18|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($15|0);
 }
 return 0|0;
}
function __Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_ShiftP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $start$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796792);
 $0 = ($delta|0)>(-1);
 $1 = $0 ? 0 : $delta;
 $start$ = (($start) - ($1))|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($start$|0)<($3|0);
 if ($4) {
  $5 = (($__this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($start$) + ($delta))|0;
  $8 = (($3) - ($start$))|0;
  __THREW__ = 0;
  invoke_viiiiii(55,(0|0),($6|0),($start$|0),($6|0),($7|0),($8|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP32[$2>>2]|0;
   $14 = (($13) + ($delta))|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    HEAP32[$2>>2] = $14;
    if ($0) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (0 - ($delta))|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($20|0),($14|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_InsertP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi34UnityEngine_UnityEngine_UILineInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796024);
 __THREW__ = 0;
 invoke_vii(1553,($__this|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($__this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($5) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($3|0)==($9|0);
    if ($10) {
     __THREW__ = 0;
     invoke_vii(1548,($__this|0),1);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_viii(419,($__this|0),($index|0),1);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[$4>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = ($index|0)<(0);
      if ($20) {
       label = 10;
      } else {
       $21 = (($17) + 12|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = ($22>>>0)>($index>>>0);
       if (!($23)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $24 = (invoke_i(132)|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($24|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
      }
      $29 = HEAP32[$17>>2]|0;
      $30 = (($17) + 16|0);
      $31 = (($29) + 92|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = Math_imul($32, $index)|0;
      $34 = (($30) + ($33)|0);
      $35 = $item;
      $36 = $35;
      $37 = HEAP32[$36>>2]|0;
      $38 = (($35) + 4)|0;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = $34;
      $42 = $41;
      HEAP32[$42>>2] = $37;
      $43 = (($41) + 4)|0;
      $44 = $43;
      HEAP32[$44>>2] = $40;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       $47 = (($__this) + 16|0);
       $48 = HEAP32[$47>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if (!($50)) {
        $51 = (($48) + 1)|0;
        HEAP32[$47>>2] = $51;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_RemoveP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796120);
 $1 = $item;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iiii(1660,(1795928|0),($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 }
 $14 = ($11|0)==(-1);
 if ($14) {
  $19 = $14 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($19|0);
 }
 __THREW__ = 0;
 invoke_viii(2111,(1796936|0),($__this|0),($11|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 if ($18) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $19 = $14 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($19|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_RemoveAtP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796936);
 __THREW__ = 0;
 invoke_v(331);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($index|0)<(0);
   if (!($2)) {
    $5 = (($__this) + 12|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)>($index|0);
    if ($7) {
     __THREW__ = 0;
     invoke_viii(419,($__this|0),($index|0),-1);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = (($__this) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = HEAP32[$5>>2]|0;
     __THREW__ = 0;
     invoke_viiii(138,(0|0),($21|0),($22|0),1);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = (($__this) + 16|0);
     $28 = HEAP32[$27>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     $31 = (($28) + 1)|0;
     HEAP32[$27>>2] = $31;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3021504>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3821,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_ToArrayP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796984);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1186248|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2748,(1186248|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_viiii(140,(0|0),($8|0),($4|0),($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_get_CountP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1797128);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_get_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796312);
 __THREW__ = 0;
 invoke_v(332);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>($index|0);
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2561352|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3021360>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = (($__this) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = ($index|0)<(0);
    if ($21) {
     label = 12;
    } else {
     $22 = (($18) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($23>>>0)>($index>>>0);
     if (!($24)) {
      label = 12;
     }
    }
    if ((label|0) == 12) {
     __THREW__ = 0;
     $25 = (invoke_i(132)|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($25|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    $30 = HEAP32[$18>>2]|0;
    $31 = (($18) + 16|0);
    $32 = (($30) + 92|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = Math_imul($33, $index)|0;
    $35 = (($31) + ($34)|0);
    $36 = $35;
    $37 = $36;
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 4)|0;
    $40 = $39;
    $41 = HEAP32[$40>>2]|0;
    $42 = $agg$result;
    $43 = $42;
    HEAP32[$43>>2] = $38;
    $44 = (($42) + 4)|0;
    $45 = $44;
    HEAP32[$45>>2] = $41;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_set_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi34UnityEngine_UnityEngine_UILineInfo($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1796408);
 __THREW__ = 0;
 invoke_v(333);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1553,($__this|0),($index|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($__this) + 12|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($5|0)==($index|0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3021376>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3821,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = ($index|0)<(0);
     if ($23) {
      label = 13;
     } else {
      $24 = (($20) + 12|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = ($25>>>0)>($index>>>0);
      if (!($26)) {
       label = 13;
      }
     }
     if ((label|0) == 13) {
      __THREW__ = 0;
      $27 = (invoke_i(132)|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($27|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
     }
     $32 = HEAP32[$20>>2]|0;
     $33 = (($20) + 16|0);
     $34 = (($32) + 92|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = Math_imul($35, $index)|0;
     $37 = (($33) + ($36)|0);
     $38 = $value;
     $39 = $38;
     $40 = HEAP32[$39>>2]|0;
     $41 = (($38) + 4)|0;
     $42 = $41;
     $43 = HEAP32[$42>>2]|0;
     $44 = $37;
     $45 = $44;
     HEAP32[$45>>2] = $40;
     $46 = (($44) + 4)|0;
     $47 = $46;
     HEAP32[$47>>2] = $43;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __ZN14ActionInvoker1I40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPFvPv34UnityEngine_UnityEngine_UILineInfoES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPFbPv34UnityEngine_UnityEngine_UILineInfoES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker0I94mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPF88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfoPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1799056,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPFiPv34UnityEngine_UnityEngine_UILineInfoES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $12;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPFvPvi34UnityEngine_UnityEngine_UILineInfoES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$2,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I40UnityEngine_UnityEngine_UILineInfoTraits27mscorlib_System_Int32TraitsE6InvokeEPF34UnityEngine_UnityEngine_UILineInfoPviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2857840,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z133mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1798512);
 __THREW__ = 0;
 invoke_vi(1745,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(0);
   if ($4) {
    $16 = (($__this) + 12|0);
    $17 = $16;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($17) + 4)|0;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = $L_4;
    $24 = $23;
    HEAP32[$24>>2] = $19;
    $25 = (($23) + 4)|0;
    $26 = $25;
    HEAP32[$26>>2] = $22;
    __THREW__ = 0;
    (invoke_ii(2996,(2857840|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_iii(2724,(2857840|0),($L_4|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($29|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2607872|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(2734,($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3821,($9|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_VerifyStateP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1798608);
 __THREW__ = 0;
 invoke_v(324);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if (!($3)) {
    $30 = (($__this) + 8|0);
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($2) + 16|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($31|0)==($35|0);
    if ($36) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3469,(2607872|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    $42 = HEAP32[3021520>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($39|0),($42|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3821,($39|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    // unreachable;
   }
   ;HEAP32[$L_1+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$__this+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$__this+16>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1799056|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2724,(1799056|0),($L_1|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(1782,($8|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(3799,($13|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        $18 = (invoke_iii(2730,(2150320|0),($13|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2634432|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          $23 = (invoke_ii(3469,(2634432|0))|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           __THREW__ = 0;
           invoke_vii(1970,($23|0),($18|0));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            invoke_vi(3821,($23|0));
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             // unreachable;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_DisposeP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1798560);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_MoveNextP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1798656);
 __THREW__ = 0;
 invoke_vi(1745,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $7 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($7|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($7) + 12|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($3|0)<($11|0);
    if (!($12)) {
     HEAP32[$2>>2] = -1;
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $13 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = (($13) + 8|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = HEAP32[$2>>2]|0;
     $19 = (($18) + 1)|0;
     HEAP32[$2>>2] = $19;
     __THREW__ = 0;
     invoke_vi(3799,($17|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = ($18|0)<(0);
      if ($22) {
       label = 10;
      } else {
       $23 = (($17) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($18>>>0)<($24>>>0);
       if (!($25)) {
        label = 10;
       }
      }
      if ((label|0) == 10) {
       __THREW__ = 0;
       $26 = (invoke_i(132)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[$17>>2]|0;
      $32 = (($17) + 16|0);
      $33 = (($31) + 92|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = Math_imul($34, $18)|0;
      $36 = (($32) + ($35)|0);
      $37 = $36;
      $38 = $37;
      $39 = HEAP32[$38>>2]|0;
      $40 = (($37) + 4)|0;
      $41 = $40;
      $42 = HEAP32[$41>>2]|0;
      $43 = (($__this) + 12|0);
      $44 = $43;
      $45 = $44;
      HEAP32[$45>>2] = $39;
      $46 = (($44) + 4)|0;
      $47 = $46;
      HEAP32[$47>>2] = $42;
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_get_CurrentP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1798704);
 $0 = (($__this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z97mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m__ctorP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1799200);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z98mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1799248);
 __THREW__ = 0;
 (invoke_ii(2996,(1800864|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1800864|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1748,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1799840|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((1799840 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z113mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo_m__ctorP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1800528);
 __THREW__ = 0;
 invoke_vi(1746,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z140mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IEqualityComparer_GetHashCodeP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1799296);
 __THREW__ = 0;
 (invoke_ii(2996,(2857840|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2749,($obj|0),(2857840|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $0;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   $16 = (invoke_iiii(1660,(1799344|0),($__this|0),($tmpcast$byval_copy|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
 return 0|0;
}
function __Z135mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IEqualityComparer_EqualsP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$byval_copy = sp + 32|0;
 $tmpcast$byval_copy = sp + 24|0;
 $_stackTraceSentry = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1799392);
 __THREW__ = 0;
 (invoke_ii(2996,(2857840|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2749,($x|0),(2857840|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = $4;
   $8 = $7;
   $9 = HEAP32[$8>>2]|0;
   $10 = (($7) + 4)|0;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2857840|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_iii(2749,($y|0),(2857840|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = $15;
     $19 = $18;
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + 4)|0;
     $22 = $21;
     $23 = HEAP32[$22>>2]|0;
     $24 = $0;
     $25 = $24;
     HEAP32[$25>>2] = $9;
     $26 = (($24) + 4)|0;
     $27 = $26;
     HEAP32[$27>>2] = $12;
     $28 = $1;
     $29 = $28;
     HEAP32[$29>>2] = $20;
     $30 = (($28) + 4)|0;
     $31 = $30;
     HEAP32[$31>>2] = $23;
     __THREW__ = 0;
     ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
     $32 = (invoke_iiiii(309,(1799440|0),($__this|0),($tmpcast$byval_copy|0),($tmpcast1$byval_copy|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($32|0);
     }
    }
   }
  }
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($35|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UILineInfoTraitsS1_E6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UILineInfoS6_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$byval_copy = sp + 32|0;
 $tmpcast$byval_copy = sp + 24|0;
 $data = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$data>>2]|0;
 $7 = $p1;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $0;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = $p2;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $1;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $27 = (FUNCTION_TABLE_iiii[$5 & 2047]($6,$tmpcast$byval_copy,$tmpcast1$byval_copy)|0);
 STACKTOP = sp;return ($27|0);
}
function __Z103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1799488);
 __THREW__ = 0;
 (invoke_ii(2996,(1799840|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((1799840 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(1799840|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1799840|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3820,(1799840|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1799840|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((1799840 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo_m_GetHashCodeP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1800576);
 $0 = $obj;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $L_0;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 __THREW__ = 0;
 (invoke_ii(2996,(2857840|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __THREW__ = 0;
  $12 = (invoke_iii(2724,(2857840|0),($L_0|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = ($12|0)==(0|0);
   if ($15) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2857840|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_iii(2724,(2857840|0),($obj|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2857840|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2857840|0),($obj|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iii(2729,(2148880|0),($27|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $$0 = $30;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z114mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo_m_EqualsP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfoS1_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_2 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_0 = sp;
 $L_2 = sp + 8|0;
 $L_5 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1800624);
 $0 = $x;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $L_0;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 __THREW__ = 0;
 (invoke_ii(2996,(2857840|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 do {
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_iii(2724,(2857840|0),($L_0|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = ($12|0)==(0|0);
    $16 = $y;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 4)|0;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    if ($15) {
     $24 = $L_2;
     $25 = $24;
     HEAP32[$25>>2] = $18;
     $26 = (($24) + 4)|0;
     $27 = $26;
     HEAP32[$27>>2] = $21;
     __THREW__ = 0;
     (invoke_ii(2996,(2857840|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     $30 = (invoke_iii(2724,(2857840|0),($L_2|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     $33 = ($30|0)==(0|0);
     $$0 = $33;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $34 = $L_5;
    $35 = $34;
    HEAP32[$35>>2] = $18;
    $36 = (($34) + 4)|0;
    $37 = $36;
    HEAP32[$37>>2] = $21;
    __THREW__ = 0;
    (invoke_ii(2996,(2857840|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     __THREW__ = 0;
     $40 = (invoke_iii(2724,(2857840|0),($L_5|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2857840|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       __THREW__ = 0;
       $45 = (invoke_iii(2724,(2857840|0),($x|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        __THREW__ = 0;
        invoke_vi(3799,($45|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if (!($49)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2857840|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          __THREW__ = 0;
          $52 = (invoke_iii(2724,(2857840|0),($x|0))|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           __THREW__ = 0;
           $55 = (invoke_iiii(1644,(2148736|0),($52|0),($40|0))|0);
           $56 = __THREW__; __THREW__ = 0;
           $57 = $56&1;
           if (!($57)) {
            $$0 = $55;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UILineInfoTraitsS1_E6InvokeEPFbPv34UnityEngine_UnityEngine_UILineInfoS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$byval_copy = sp + 24|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$args>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($args) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $25 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$tmpcast$byval_copy,$tmpcast1$byval_copy)|0);
 $26 = $25&1;
 HEAP8[$ret>>0] = $26;
 $27 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($27|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ComponentP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1801728)|0);
 $0 = HEAP32[((1801728 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1801728)|0);
 $0 = HEAP32[((1801728 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1803992)|0);
 $0 = HEAP32[((1803992 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1803992)|0);
 $0 = HEAP32[((1803992 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1806256)|0);
 $0 = HEAP32[((1806256 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1806256)|0);
 $0 = HEAP32[((1806256 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_GetEnumeratorP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1807800);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3496,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL107mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m__ctorP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCallP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctor_mscorlib_System_VoidP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL169mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1810720)|0);
 $0 = HEAP32[((1810720 + 84|0))>>2]|0;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL154mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL128mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_ICollection_CopyToP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_AddP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL124mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_ContainsP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL123mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_IndexOfP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL122mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_InsertP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalliP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_RemoveP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL155mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL134mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_ICollection_get_SyncRootP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL124mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_get_ItemP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL124mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_set_ItemP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalliP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_AddP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_GrowIfNeededP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_AddCollectionP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_AddEnumerableP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_AddRangeP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_ClearP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_ContainsP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_CopyToP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP49UnityEngine_UnityEngine_Events_PersistentCall_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I105mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCallTraitsE6InvokeEPF99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCallPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1813720,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_IndexOfP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_ShiftP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_CheckIndexP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_InsertP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalliP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_CheckCollectionP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_RemoveP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_RemoveAtP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_ToArrayP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_CapacityP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_set_CapacityP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_CountP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_ItemP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_set_ItemP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalliP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1812440)|0);
 $0 = HEAP32[((1812440 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1812440)|0);
 $0 = HEAP32[((1812440 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL144mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1813720)|0);
 $0 = HEAP32[((1813720 + 84|0))>>2]|0;
 $1 = (__Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_DisposeP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_VerifyStateP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1813720)|0);
 $0 = HEAP32[((1813720 + 84|0))>>2]|0;
 __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_MoveNextP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1813720)|0);
 $0 = HEAP32[((1813720 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_get_CurrentP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctorP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1814504)|0);
 $0 = HEAP32[((1814504 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL151mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IEqualityComparer_GetHashCodeP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL146mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IEqualityComparer_EqualsP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1814504)|0);
 $0 = HEAP32[((1814504 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL124mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCall_m__ctorP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCall_m_GetHashCodeP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCall_m_EqualsP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCallS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z107mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_GetEnumeratorP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1815672);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3496,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL120mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctor_mscorlib_System_VoidP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL172mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL142mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1818592)|0);
 $0 = HEAP32[((1818592 + 84|0))>>2]|0;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL157mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL131mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_ICollection_CopyToP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_AddP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_ContainsP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL126mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_IndexOfP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_InsertP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalliP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_RemoveP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL158mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL137mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_ICollection_get_SyncRootP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_get_ItemP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_set_ItemP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalliP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_AddP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_GrowIfNeededP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_AddCollectionP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_AddEnumerableP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_AddRangeP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_ClearP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_ContainsP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_CopyToP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I108mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCallTraitsE6InvokeEPF102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCallPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1828080,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_IndexOfP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_ShiftP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_CheckIndexP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_InsertP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalliP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_CheckCollectionP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_RemoveP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_RemoveAtP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_ToArrayP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_CapacityP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_set_CapacityP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_CountP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_ItemP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_set_ItemP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalliP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctorP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL136mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IEnumerator_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1820312)|0);
 $0 = HEAP32[((1820312 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_DisposeP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_MoveNextP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1820312)|0);
 $0 = HEAP32[((1820312 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctorP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCallP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l);
 STACKTOP = sp;return;
}
function __ZL147mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1828080)|0);
 $0 = HEAP32[((1828080 + 84|0))>>2]|0;
 $1 = (__Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_DisposeP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_VerifyStateP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1828080)|0);
 $0 = HEAP32[((1828080 + 84|0))>>2]|0;
 __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_MoveNextP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1828080)|0);
 $0 = HEAP32[((1828080 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_CurrentP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctorP103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1829088)|0);
 $0 = HEAP32[((1829088 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL154mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IEqualityComparer_GetHashCodeP103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL149mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IEqualityComparer_EqualsP103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1829088)|0);
 $0 = HEAP32[((1829088 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL127mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctorP119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCall($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_GetHashCodeP119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL128mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_EqualsP119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCallS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL135mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1831096)|0);
 $0 = HEAP32[((1831096 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1831096)|0);
 $0 = HEAP32[((1831096 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL142mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1833560)|0);
 $0 = HEAP32[((1833560 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1833560)|0);
 $0 = HEAP32[((1833560 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL145mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m_System_Collections_IEnumerator_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1835824)|0);
 $0 = HEAP32[((1835824 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m_DisposeP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m_MoveNextP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1835824)|0);
 $0 = HEAP32[((1835824 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL142mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1838088)|0);
 $0 = HEAP32[((1838088 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1838088)|0);
 $0 = HEAP32[((1838088 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m__ctorP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1839872);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z138mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m_System_Collections_IEnumerator_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1839920);
 __THREW__ = 0;
 $0 = (invoke_ii(1421,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2709456|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2709456|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1840064);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1468,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m_DisposeP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1839968);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z104mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m_MoveNextP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1840016);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3068($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL146mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1842616)|0);
 $0 = HEAP32[((1842616 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1842616)|0);
 $0 = HEAP32[((1842616 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m__ctorP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m_System_Collections_IEnumerator_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1844880)|0);
 $0 = HEAP32[((1844880 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m_DisposeP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m_MoveNextP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1844880)|0);
 $0 = HEAP32[((1844880 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1846664);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1846712);
 __THREW__ = 0;
 $0 = (invoke_ii(1430,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2712816|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2712816|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1846856);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1480,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1846760);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1846808);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1848928);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z125mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1848976);
 __THREW__ = 0;
 $0 = (invoke_ii(1433,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2713392|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2713392|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1849120);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1484,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1849024);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1849072);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m__ctorP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1851192);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z117mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m_System_Collections_IEnumerator_get_CurrentP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1851240);
 __THREW__ = 0;
 $0 = (invoke_ii(1436,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2713792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2713792|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m_get_CurrentP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1851384);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1488,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m_DisposeP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1851288);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m_MoveNextP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1851336);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1853456);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1853504);
 __THREW__ = 0;
 $0 = (invoke_ii(1439,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2715240|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2715240|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1853648);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1492,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1853552);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1853600);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1856200)|0);
 $0 = HEAP32[((1856200 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1856200)|0);
 $0 = HEAP32[((1856200 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1858464)|0);
 $0 = HEAP32[((1858464 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1858464)|0);
 $0 = HEAP32[((1858464 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1860248);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1860296);
 __THREW__ = 0;
 $0 = (invoke_ii(1448,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2719592|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2719592|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1860440);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3822,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1504,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1860344);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1860392);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RendererP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1862992)|0);
 $0 = HEAP32[((1862992 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1862992)|0);
 $0 = HEAP32[((1862992 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1865256)|0);
 $0 = HEAP32[((1865256 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1865256)|0);
 $0 = HEAP32[((1865256 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextureP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1867520)|0);
 $0 = HEAP32[((1867520 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1867520)|0);
 $0 = HEAP32[((1867520 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1869784)|0);
 $0 = HEAP32[((1869784 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1869784)|0);
 $0 = HEAP32[((1869784 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1872048)|0);
 $0 = HEAP32[((1872048 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1872048)|0);
 $0 = HEAP32[((1872048 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1880040)|0);
 $0 = HEAP32[((1880040 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1880040)|0);
 $0 = HEAP32[((1880040 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1882504)|0);
 $0 = HEAP32[((1882504 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1882504)|0);
 $0 = HEAP32[((1882504 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z161mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctor_mscorlib_System_VoidP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884048);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(438,($__this|0),10,(0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z139mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_InitP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP22mscorlib_System_Object($__this,$capacity,$hcp) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $hcp = $hcp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884912);
 __THREW__ = 0;
 invoke_v(335);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($capacity|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020592>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($hcp|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    $16 = (invoke_ii(913,(0|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    $G_B5_0$0 = $16;
   } else {
    $G_B5_0$0 = $hcp;
   }
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = (($__this) + 40|0);
    HEAP32[$21>>2] = $G_B5_0$0;
    $22 = ($capacity|0)==(0);
    $23 = (Math_fround(($capacity|0)));
    $24 = $22 ? Math_fround(10.0) : $23;
    $25 = Math_fround($24 / Math_fround(0.899999976158142089843));
    $26 = (~~(($25)));
    $27 = (($26) + 1)|0;
    __THREW__ = 0;
    invoke_vii(1616,($__this|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = (($__this) + 48|0);
     HEAP32[$30>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z222mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884096);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(438,($__this|0),10,($comparer|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z183mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachei($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884144);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(438,($__this|0),($capacity|0),(0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z178mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_ICollection_get_SyncRootP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884192);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z262mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884240);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z251mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884288);
 __THREW__ = 0;
 $0 = (invoke_ii(1476,($keyValuePair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(1477,($keyValuePair|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viiii(459,(1884336|0),($__this|0),($0|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z144mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_KeyP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1889576);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z146mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_ValueP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1889672);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z256mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884384);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(420,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z155mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ContainsKeyValuePairP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$pair) {
 $__this = $__this|0;
 $pair = $pair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885488);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(1476,($pair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiii(310,(1885392|0),($__this|0),($0|0),($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   if (!($3)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_ii(1496,(0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(1477,($pair|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP32[$V_0>>2]|0;
      __THREW__ = 0;
      $17 = (invoke_iiiii(299,(1885536|0),($8|0),($11|0),($16|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z254mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP121mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_Int32U002CUnityEngine_GUILayoutUtility_LayoutCacheU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884432);
 __THREW__ = 0;
 invoke_viii(440,($__this|0),($_____array|0),($index|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z141mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_CopyToP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP121mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_Int32U002CUnityEngine_GUILayoutUtility_LayoutCacheU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885104);
 __THREW__ = 0;
 invoke_viii(439,($__this|0),($_____array|0),($index|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1898856|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(1898856|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    HEAP32[$0>>2] = 1884672;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viii(448,($5|0),(0|0),($$byval_copy|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_viiii(299,($__this|0),($_____array|0),($index|0),($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z254mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884480);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(420,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  if (!($11)) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $16 = (invoke_ii(1476,($keyValuePair|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iiii(1661,(1884528|0),($__this|0),($16|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z172mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_ICollection_CopyToP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884576);
 __THREW__ = 0;
 (invoke_ii(2996,(1196792|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($_____array|0),(1196792|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if (!($7)) {
     __THREW__ = 0;
     invoke_viii(440,($__this|0),($4|0),($index|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_viii(439,($__this|0),($_____array|0),($index|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     (invoke_ii(2996,(1171160|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_iii(2735,($_____array|0),(1171160|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = ($16|0)==(0|0);
       if ($19) {
        __THREW__ = 0;
        (invoke_ii(2996,(1898856|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_ii(3469,(1898856|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        HEAP32[$1>>2] = 1884672;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
        invoke_viii(448,($48|0),(0|0),($$byval_copy1|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
        __THREW__ = 0;
        invoke_viiii(297,($__this|0),($_____array|0),($index|0),($48|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1888288|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = HEAP32[((1888288 + 80|0))>>2]|0;
        $23 = (($22) + 16|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = ($24|0)==(0|0);
        if ($25) {
         __THREW__ = 0;
         (invoke_ii(2996,(1898280|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         __THREW__ = 0;
         $28 = (invoke_ii(3469,(1898280|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         HEAP32[$0>>2] = 1884624;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
         invoke_viii(446,($28|0),(0|0),($$byval_copy1|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1888288|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         $35 = HEAP32[((1888288 + 80|0))>>2]|0;
         $36 = (($35) + 16|0);
         HEAP32[$36>>2] = $28;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1888288|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = HEAP32[((1888288 + 80|0))>>2]|0;
         $40 = (($39) + 16|0);
         $41 = HEAP32[$40>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          __THREW__ = 0;
          invoke_viiii(296,($__this|0),($16|0),($index|0),($41|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if (!($45)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z146mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_CopyToCheckP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885008);
 __THREW__ = 0;
 invoke_v(336);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020608>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)>(-1);
   if (!($15)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3020616>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_ii(1857,($_____array|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $31 = ($28|0)<($index|0);
     if ($31) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2560072|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = HEAP32[3020624>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($34|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3823,($34|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      $44 = (invoke_ii(1857,($_____array|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       __THREW__ = 0;
       $47 = (invoke_iii(2729,(1884816|0),($__this|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        $50 = (($44) - ($index))|0;
        $51 = ($50|0)<($47|0);
        if (!($51)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if (!($53)) {
         __THREW__ = 0;
         $54 = (invoke_ii(3469,(2560072|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          $57 = HEAP32[3020632>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($54|0),($57|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           __THREW__ = 0;
           invoke_vi(3823,($54|0));
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if (!($61)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z205mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1897848);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z296mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1898424);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z261mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884720);
 ;HEAP32[$L_0+0>>2]=0|0;HEAP32[$L_0+4>>2]=0|0;HEAP32[$L_0+8>>2]=0|0;HEAP32[$L_0+12>>2]=0|0;HEAP32[$L_0+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1627,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1897072|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1897072|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z151mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896144);
 HEAP32[$__this>>2] = $dictionary;
 __THREW__ = 0;
 invoke_vi(3799,($dictionary|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($dictionary) + 48|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z179mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IDictionary_GetEnumeratorP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884768);
 __THREW__ = 0;
 (invoke_ii(2996,(1899424|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1899424|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1630,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z155mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP147mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1899000);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($host|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   invoke_vii(1617,($L_0|0),($host|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($__this) + 8|0);
    ;HEAP32[$6+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$L_0+16>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z144mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CountP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884816);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z143mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_set_ItemP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_0 = 0, $V_1$0 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_2$2 = 0, $V_2$3 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $V_3$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884864);
 __THREW__ = 0;
 invoke_v(334);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   HEAP32[$L_0>>2] = $key;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2724,(2155952|0),($L_0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560584|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      $14 = (invoke_ii(3469,(2560584|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      $17 = HEAP32[3020568>>2]|0;
      __THREW__ = 0;
      invoke_vii(1925,($14|0),($17|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3823,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      // unreachable;
     }
     $22 = (($__this) + 40|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      $26 = (invoke_iiii(1662,(1409112|0),($23|0),($key|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = $26 | -2147483648;
       $30 = $26 & 2147483647;
       $31 = (($__this) + 8|0);
       $32 = HEAP32[$31>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        $35 = (($32) + 12|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = (($30|0) % ($36|0))&-1;
        $38 = HEAP32[$31>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($38|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = (($38) + 12|0);
         $42 = HEAP32[$41>>2]|0;
         $43 = ($37>>>0)<($42>>>0);
         if (!($43)) {
          __THREW__ = 0;
          $44 = (invoke_i(132)|0);
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($44|0));
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           break;
          }
         }
         $49 = HEAP32[$38>>2]|0;
         $50 = (($38) + 16|0);
         $51 = (($49) + 92|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = Math_imul($52, $37)|0;
         $54 = (($50) + ($53)|0);
         $55 = HEAP32[$54>>2]|0;
         $56 = (($55) + -1)|0;
         $57 = ($55|0)==(0);
         L20: do {
          if ($57) {
           $V_2$1 = $56;$V_3$1 = -1;
           label = 42;
          } else {
           $58 = (($__this) + 12|0);
           $59 = (($__this) + 16|0);
           $V_2$0 = $56;$V_3$0 = -1;
           while(1) {
            $60 = HEAP32[$58>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($60|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             break;
            }
            $63 = ($V_2$0|0)<(0);
            if ($63) {
             label = 25;
            } else {
             $64 = (($60) + 12|0);
             $65 = HEAP32[$64>>2]|0;
             $66 = ($V_2$0>>>0)<($65>>>0);
             if (!($66)) {
              label = 25;
             }
            }
            if ((label|0) == 25) {
             label = 0;
             __THREW__ = 0;
             $67 = (invoke_i(132)|0);
             $68 = __THREW__; __THREW__ = 0;
             $69 = $68&1;
             if ($69) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($67|0));
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if ($71) {
              break;
             }
            }
            $72 = HEAP32[$60>>2]|0;
            $73 = (($60) + 16|0);
            $74 = (($72) + 92|0);
            $75 = HEAP32[$74>>2]|0;
            $76 = Math_imul($75, $V_2$0)|0;
            $77 = (($73) + ($76)|0);
            $78 = HEAP32[$77>>2]|0;
            $79 = ($78|0)==($29|0);
            if ($79) {
             $80 = HEAP32[$22>>2]|0;
             $81 = HEAP32[$59>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($81|0));
             $82 = __THREW__; __THREW__ = 0;
             $83 = $82&1;
             if ($83) {
              break;
             }
             if ($63) {
              label = 31;
             } else {
              $84 = (($81) + 12|0);
              $85 = HEAP32[$84>>2]|0;
              $86 = ($V_2$0>>>0)<($85>>>0);
              if (!($86)) {
               label = 31;
              }
             }
             if ((label|0) == 31) {
              label = 0;
              __THREW__ = 0;
              $87 = (invoke_i(132)|0);
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if ($89) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($87|0));
              $90 = __THREW__; __THREW__ = 0;
              $91 = $90&1;
              if ($91) {
               break;
              }
             }
             $92 = HEAP32[$81>>2]|0;
             $93 = (($81) + 16|0);
             $94 = (($92) + 92|0);
             $95 = HEAP32[$94>>2]|0;
             $96 = Math_imul($95, $V_2$0)|0;
             $97 = (($93) + ($96)|0);
             $98 = HEAP32[$97>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($80|0));
             $99 = __THREW__; __THREW__ = 0;
             $100 = $99&1;
             if ($100) {
              break;
             }
             __THREW__ = 0;
             $101 = (invoke_iiiii(306,(1398000|0),($80|0),($98|0),($key|0))|0);
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             if ($103) {
              break;
             }
             if ($101) {
              $V_2$1 = $V_2$0;$V_3$1 = $V_3$0;
              label = 42;
              break L20;
             }
            }
            $104 = HEAP32[$58>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($104|0));
            $105 = __THREW__; __THREW__ = 0;
            $106 = $105&1;
            if ($106) {
             break;
            }
            if ($63) {
             label = 39;
            } else {
             $107 = (($104) + 12|0);
             $108 = HEAP32[$107>>2]|0;
             $109 = ($V_2$0>>>0)<($108>>>0);
             if (!($109)) {
              label = 39;
             }
            }
            if ((label|0) == 39) {
             label = 0;
             __THREW__ = 0;
             $110 = (invoke_i(132)|0);
             $111 = __THREW__; __THREW__ = 0;
             $112 = $111&1;
             if ($112) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($110|0));
             $113 = __THREW__; __THREW__ = 0;
             $114 = $113&1;
             if ($114) {
              break;
             }
            }
            $115 = HEAP32[$104>>2]|0;
            $116 = (($104) + 16|0);
            $117 = (($115) + 92|0);
            $118 = HEAP32[$117>>2]|0;
            $119 = Math_imul($118, $V_2$0)|0;
            $$sum = (($119) + 4)|0;
            $120 = (($116) + ($$sum)|0);
            $121 = HEAP32[$120>>2]|0;
            $122 = ($121|0)==(-1);
            if ($122) {
             label = 43;
             break L20;
            } else {
             $V_3$0$phi = $V_2$0;$V_2$0 = $121;$V_3$0 = $V_3$0$phi;
            }
           }
           $8 = ___cxa_find_matching_catch()|0;
           $9 = tempRet0;
           $lpad$phi$index = $8;$lpad$phi$index2 = $9;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
         } while(0);
         if ((label|0) == 42) {
          $123 = ($V_2$1|0)==(-1);
          if ($123) {
           label = 43;
          } else {
           $262 = ($V_3$1|0)==(-1);
           if ($262) {
            $V_2$3 = $V_2$1;
           } else {
            $263 = (($__this) + 12|0);
            $264 = HEAP32[$263>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($264|0));
            $265 = __THREW__; __THREW__ = 0;
            $266 = $265&1;
            if ($266) {
             break;
            }
            $267 = ($V_3$1|0)<(0);
            if ($267) {
             label = 87;
            } else {
             $268 = (($264) + 12|0);
             $269 = HEAP32[$268>>2]|0;
             $270 = ($V_3$1>>>0)<($269>>>0);
             if (!($270)) {
              label = 87;
             }
            }
            if ((label|0) == 87) {
             __THREW__ = 0;
             $271 = (invoke_i(132)|0);
             $272 = __THREW__; __THREW__ = 0;
             $273 = $272&1;
             if ($273) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($271|0));
             $274 = __THREW__; __THREW__ = 0;
             $275 = $274&1;
             if ($275) {
              break;
             }
            }
            $276 = HEAP32[$264>>2]|0;
            $277 = (($264) + 16|0);
            $278 = (($276) + 92|0);
            $279 = HEAP32[$278>>2]|0;
            $280 = Math_imul($279, $V_3$1)|0;
            $281 = HEAP32[$263>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($281|0));
            $282 = __THREW__; __THREW__ = 0;
            $283 = $282&1;
            if ($283) {
             break;
            }
            $284 = ($V_2$1|0)<(0);
            if ($284) {
             label = 92;
            } else {
             $285 = (($281) + 12|0);
             $286 = HEAP32[$285>>2]|0;
             $287 = ($V_2$1>>>0)<($286>>>0);
             if (!($287)) {
              label = 92;
             }
            }
            if ((label|0) == 92) {
             __THREW__ = 0;
             $288 = (invoke_i(132)|0);
             $289 = __THREW__; __THREW__ = 0;
             $290 = $289&1;
             if ($290) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($288|0));
             $291 = __THREW__; __THREW__ = 0;
             $292 = $291&1;
             if ($292) {
              break;
             }
            }
            $293 = HEAP32[$281>>2]|0;
            $294 = (($281) + 16|0);
            $295 = (($293) + 92|0);
            $296 = HEAP32[$295>>2]|0;
            $297 = Math_imul($296, $V_2$1)|0;
            $$sum4 = (($297) + 4)|0;
            $298 = (($294) + ($$sum4)|0);
            $299 = HEAP32[$298>>2]|0;
            $$sum5 = (($280) + 4)|0;
            $300 = (($277) + ($$sum5)|0);
            HEAP32[$300>>2] = $299;
            $301 = HEAP32[$263>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($301|0));
            $302 = __THREW__; __THREW__ = 0;
            $303 = $302&1;
            if ($303) {
             break;
            }
            if ($284) {
             label = 97;
            } else {
             $304 = (($301) + 12|0);
             $305 = HEAP32[$304>>2]|0;
             $306 = ($V_2$1>>>0)<($305>>>0);
             if (!($306)) {
              label = 97;
             }
            }
            if ((label|0) == 97) {
             __THREW__ = 0;
             $307 = (invoke_i(132)|0);
             $308 = __THREW__; __THREW__ = 0;
             $309 = $308&1;
             if ($309) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($307|0));
             $310 = __THREW__; __THREW__ = 0;
             $311 = $310&1;
             if ($311) {
              break;
             }
            }
            $312 = HEAP32[$301>>2]|0;
            $313 = (($301) + 16|0);
            $314 = (($312) + 92|0);
            $315 = HEAP32[$314>>2]|0;
            $316 = Math_imul($315, $V_2$1)|0;
            $317 = HEAP32[$31>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($317|0));
            $318 = __THREW__; __THREW__ = 0;
            $319 = $318&1;
            if ($319) {
             break;
            }
            $320 = (($317) + 12|0);
            $321 = HEAP32[$320>>2]|0;
            $322 = ($37>>>0)<($321>>>0);
            if (!($322)) {
             __THREW__ = 0;
             $323 = (invoke_i(132)|0);
             $324 = __THREW__; __THREW__ = 0;
             $325 = $324&1;
             if ($325) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($323|0));
             $326 = __THREW__; __THREW__ = 0;
             $327 = $326&1;
             if ($327) {
              break;
             }
            }
            $328 = HEAP32[$317>>2]|0;
            $329 = (($317) + 16|0);
            $330 = (($328) + 92|0);
            $331 = HEAP32[$330>>2]|0;
            $332 = Math_imul($331, $37)|0;
            $333 = (($329) + ($332)|0);
            $334 = HEAP32[$333>>2]|0;
            $335 = (($334) + -1)|0;
            $$sum6 = (($316) + 4)|0;
            $336 = (($313) + ($$sum6)|0);
            HEAP32[$336>>2] = $335;
            $337 = HEAP32[$31>>2]|0;
            $338 = (($V_2$1) + 1)|0;
            __THREW__ = 0;
            invoke_vi(3799,($337|0));
            $339 = __THREW__; __THREW__ = 0;
            $340 = $339&1;
            if ($340) {
             break;
            }
            $341 = (($337) + 12|0);
            $342 = HEAP32[$341>>2]|0;
            $343 = ($37>>>0)<($342>>>0);
            if (!($343)) {
             __THREW__ = 0;
             $344 = (invoke_i(132)|0);
             $345 = __THREW__; __THREW__ = 0;
             $346 = $345&1;
             if ($346) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($344|0));
             $347 = __THREW__; __THREW__ = 0;
             $348 = $347&1;
             if ($348) {
              break;
             }
            }
            $349 = HEAP32[$337>>2]|0;
            $350 = (($337) + 16|0);
            $351 = (($349) + 92|0);
            $352 = HEAP32[$351>>2]|0;
            $353 = Math_imul($352, $37)|0;
            $354 = (($350) + ($353)|0);
            HEAP32[$354>>2] = $338;
            $V_2$3 = $V_2$1;
           }
          }
         }
         if ((label|0) == 43) {
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $124 = __THREW__; __THREW__ = 0;
          $125 = $124&1;
          if ($125) {
           break;
          }
          $126 = (($__this) + 32|0);
          $127 = HEAP32[$126>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           break;
          }
          $130 = (($127) + 1)|0;
          HEAP32[$126>>2] = $130;
          $131 = (($__this) + 36|0);
          $132 = HEAP32[$131>>2]|0;
          $133 = ($127|0)<($132|0);
          if ($133) {
           $V_1$0 = $37;
          } else {
           __THREW__ = 0;
           invoke_vi(1792,($__this|0));
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if ($135) {
            break;
           }
           $136 = HEAP32[$31>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($136|0));
           $137 = __THREW__; __THREW__ = 0;
           $138 = $137&1;
           if ($138) {
            break;
           }
           $139 = (($136) + 12|0);
           $140 = HEAP32[$139>>2]|0;
           $141 = (($30|0) % ($140|0))&-1;
           $V_1$0 = $141;
          }
          $142 = (($__this) + 28|0);
          $143 = HEAP32[$142>>2]|0;
          $144 = ($143|0)==(-1);
          if ($144) {
           __THREW__ = 0;
           invoke_vi(3799,($__this|0));
           $145 = __THREW__; __THREW__ = 0;
           $146 = $145&1;
           if ($146) {
            break;
           }
           $147 = (($__this) + 24|0);
           $148 = HEAP32[$147>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($__this|0));
           $149 = __THREW__; __THREW__ = 0;
           $150 = $149&1;
           if ($150) {
            break;
           }
           $151 = (($148) + 1)|0;
           HEAP32[$147>>2] = $151;
           $$pre = (($__this) + 12|0);
           $$pre$phiZ2D = $$pre;$V_2$2 = $148;
          } else {
           $152 = (($__this) + 12|0);
           $153 = HEAP32[$152>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($153|0));
           $154 = __THREW__; __THREW__ = 0;
           $155 = $154&1;
           if ($155) {
            break;
           }
           $156 = ($143|0)<(0);
           if ($156) {
            label = 56;
           } else {
            $157 = (($153) + 12|0);
            $158 = HEAP32[$157>>2]|0;
            $159 = ($143>>>0)<($158>>>0);
            if (!($159)) {
             label = 56;
            }
           }
           if ((label|0) == 56) {
            __THREW__ = 0;
            $160 = (invoke_i(132)|0);
            $161 = __THREW__; __THREW__ = 0;
            $162 = $161&1;
            if ($162) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($160|0));
            $163 = __THREW__; __THREW__ = 0;
            $164 = $163&1;
            if ($164) {
             break;
            }
           }
           $165 = HEAP32[$153>>2]|0;
           $166 = (($153) + 16|0);
           $167 = (($165) + 92|0);
           $168 = HEAP32[$167>>2]|0;
           $169 = Math_imul($168, $143)|0;
           $$sum2 = (($169) + 4)|0;
           $170 = (($166) + ($$sum2)|0);
           $171 = HEAP32[$170>>2]|0;
           HEAP32[$142>>2] = $171;
           $$pre$phiZ2D = $152;$V_2$2 = $143;
          }
          $172 = HEAP32[$$pre$phiZ2D>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($172|0));
          $173 = __THREW__; __THREW__ = 0;
          $174 = $173&1;
          if ($174) {
           break;
          }
          $175 = ($V_2$2|0)<(0);
          if ($175) {
           label = 62;
          } else {
           $176 = (($172) + 12|0);
           $177 = HEAP32[$176>>2]|0;
           $178 = ($V_2$2>>>0)<($177>>>0);
           if (!($178)) {
            label = 62;
           }
          }
          if ((label|0) == 62) {
           __THREW__ = 0;
           $179 = (invoke_i(132)|0);
           $180 = __THREW__; __THREW__ = 0;
           $181 = $180&1;
           if ($181) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($179|0));
           $182 = __THREW__; __THREW__ = 0;
           $183 = $182&1;
           if ($183) {
            break;
           }
          }
          $184 = HEAP32[$172>>2]|0;
          $185 = (($172) + 16|0);
          $186 = (($184) + 92|0);
          $187 = HEAP32[$186>>2]|0;
          $188 = Math_imul($187, $V_2$2)|0;
          $189 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($189|0));
          $190 = __THREW__; __THREW__ = 0;
          $191 = $190&1;
          if ($191) {
           break;
          }
          $192 = (($189) + 12|0);
          $193 = HEAP32[$192>>2]|0;
          $194 = ($V_1$0>>>0)<($193>>>0);
          if (!($194)) {
           __THREW__ = 0;
           $195 = (invoke_i(132)|0);
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($195|0));
           $198 = __THREW__; __THREW__ = 0;
           $199 = $198&1;
           if ($199) {
            break;
           }
          }
          $200 = HEAP32[$189>>2]|0;
          $201 = (($189) + 16|0);
          $202 = (($200) + 92|0);
          $203 = HEAP32[$202>>2]|0;
          $204 = Math_imul($203, $V_1$0)|0;
          $205 = (($201) + ($204)|0);
          $206 = HEAP32[$205>>2]|0;
          $207 = (($206) + -1)|0;
          $$sum3 = (($188) + 4)|0;
          $208 = (($185) + ($$sum3)|0);
          HEAP32[$208>>2] = $207;
          $209 = HEAP32[$31>>2]|0;
          $210 = (($V_2$2) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($209|0));
          $211 = __THREW__; __THREW__ = 0;
          $212 = $211&1;
          if ($212) {
           break;
          }
          $213 = (($209) + 12|0);
          $214 = HEAP32[$213>>2]|0;
          $215 = ($V_1$0>>>0)<($214>>>0);
          if (!($215)) {
           __THREW__ = 0;
           $216 = (invoke_i(132)|0);
           $217 = __THREW__; __THREW__ = 0;
           $218 = $217&1;
           if ($218) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($216|0));
           $219 = __THREW__; __THREW__ = 0;
           $220 = $219&1;
           if ($220) {
            break;
           }
          }
          $221 = HEAP32[$209>>2]|0;
          $222 = (($209) + 16|0);
          $223 = (($221) + 92|0);
          $224 = HEAP32[$223>>2]|0;
          $225 = Math_imul($224, $V_1$0)|0;
          $226 = (($222) + ($225)|0);
          HEAP32[$226>>2] = $210;
          $227 = HEAP32[$$pre$phiZ2D>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($227|0));
          $228 = __THREW__; __THREW__ = 0;
          $229 = $228&1;
          if ($229) {
           break;
          }
          if ($175) {
           label = 75;
          } else {
           $230 = (($227) + 12|0);
           $231 = HEAP32[$230>>2]|0;
           $232 = ($V_2$2>>>0)<($231>>>0);
           if (!($232)) {
            label = 75;
           }
          }
          if ((label|0) == 75) {
           __THREW__ = 0;
           $233 = (invoke_i(132)|0);
           $234 = __THREW__; __THREW__ = 0;
           $235 = $234&1;
           if ($235) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($233|0));
           $236 = __THREW__; __THREW__ = 0;
           $237 = $236&1;
           if ($237) {
            break;
           }
          }
          $238 = HEAP32[$227>>2]|0;
          $239 = (($227) + 16|0);
          $240 = (($238) + 92|0);
          $241 = HEAP32[$240>>2]|0;
          $242 = Math_imul($241, $V_2$2)|0;
          $243 = (($239) + ($242)|0);
          HEAP32[$243>>2] = $29;
          $244 = (($__this) + 16|0);
          $245 = HEAP32[$244>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($245|0));
          $246 = __THREW__; __THREW__ = 0;
          $247 = $246&1;
          if ($247) {
           break;
          }
          if ($175) {
           label = 80;
          } else {
           $248 = (($245) + 12|0);
           $249 = HEAP32[$248>>2]|0;
           $250 = ($V_2$2>>>0)<($249>>>0);
           if (!($250)) {
            label = 80;
           }
          }
          if ((label|0) == 80) {
           __THREW__ = 0;
           $251 = (invoke_i(132)|0);
           $252 = __THREW__; __THREW__ = 0;
           $253 = $252&1;
           if ($253) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($251|0));
           $254 = __THREW__; __THREW__ = 0;
           $255 = $254&1;
           if ($255) {
            break;
           }
          }
          $256 = HEAP32[$245>>2]|0;
          $257 = (($245) + 16|0);
          $258 = (($256) + 92|0);
          $259 = HEAP32[$258>>2]|0;
          $260 = Math_imul($259, $V_2$2)|0;
          $261 = (($257) + ($260)|0);
          HEAP32[$261>>2] = $key;
          $V_2$3 = $V_2$2;
         }
         $355 = (($__this) + 20|0);
         $356 = HEAP32[$355>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($356|0));
         $357 = __THREW__; __THREW__ = 0;
         $358 = $357&1;
         if (!($358)) {
          $359 = ($V_2$3|0)<(0);
          if ($359) {
           label = 111;
          } else {
           $360 = (($356) + 12|0);
           $361 = HEAP32[$360>>2]|0;
           $362 = ($V_2$3>>>0)<($361>>>0);
           if (!($362)) {
            label = 111;
           }
          }
          if ((label|0) == 111) {
           __THREW__ = 0;
           $363 = (invoke_i(132)|0);
           $364 = __THREW__; __THREW__ = 0;
           $365 = $364&1;
           if ($365) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($363|0));
           $366 = __THREW__; __THREW__ = 0;
           $367 = $366&1;
           if ($367) {
            break;
           }
          }
          $368 = HEAP32[$356>>2]|0;
          $369 = (($356) + 16|0);
          $370 = (($368) + 92|0);
          $371 = HEAP32[$370>>2]|0;
          $372 = Math_imul($371, $V_2$3)|0;
          $373 = (($369) + ($372)|0);
          HEAP32[$373>>2] = $value;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $374 = __THREW__; __THREW__ = 0;
          $375 = $374&1;
          if (!($375)) {
           $376 = (($__this) + 48|0);
           $377 = HEAP32[$376>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($__this|0));
           $378 = __THREW__; __THREW__ = 0;
           $379 = $378&1;
           if (!($379)) {
            $380 = (($377) + 1)|0;
            HEAP32[$376>>2] = $380;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3328($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32TraitsS0_E6InvokeEP10MethodInfoPvi($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z141mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ResizeP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $$sum = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = Math_fround(0), $188 = Math_fround(0), $189 = 0, $19 = 0, $190 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $V_4$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885152);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5 << 1;
   $7 = $6 | 1;
   __THREW__ = 0;
   $8 = (invoke_iii(835,(0|0),($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1170368|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_iii(2750,(1170368|0),($8|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(1170744|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_iii(2750,(1170744|0),($8|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $21 = (($18) + 16|0);
        $22 = (($__this) + 40|0);
        $23 = (($__this) + 16|0);
        $24 = (($13) + 12|0);
        $25 = (($13) + 16|0);
        $26 = (($__this) + 12|0);
        $27 = (($18) + 12|0);
        $V_3$0 = 0;
        L8: while(1) {
         $159 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($159|0));
         $160 = __THREW__; __THREW__ = 0;
         $161 = $160&1;
         if ($161) {
          label = 9;
          break;
         }
         $162 = (($159) + 12|0);
         $163 = HEAP32[$162>>2]|0;
         $164 = ($V_3$0|0)<($163|0);
         if (!($164)) {
          label = 52;
          break;
         }
         $35 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($35|0));
         $165 = __THREW__; __THREW__ = 0;
         $166 = $165&1;
         if ($166) {
          label = 9;
          break;
         }
         $34 = (($35) + 12|0);
         $36 = HEAP32[$34>>2]|0;
         $37 = ($V_3$0>>>0)<($36>>>0);
         if (!($37)) {
          __THREW__ = 0;
          $38 = (invoke_i(132)|0);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           label = 9;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($38|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           label = 9;
           break;
          }
         }
         $43 = HEAP32[$35>>2]|0;
         $44 = (($35) + 16|0);
         $45 = (($43) + 92|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = Math_imul($46, $V_3$0)|0;
         $48 = (($44) + ($47)|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ($49|0)==(0);
         if (!($50)) {
          $51 = (($49) + -1)|0;
          $V_4$05 = $51;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($18|0));
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            label = 8;
            break L8;
           }
           $52 = ($V_4$05|0)<(0);
           if ($52) {
            label = 19;
           } else {
            $53 = HEAP32[$27>>2]|0;
            $54 = ($V_4$05>>>0)<($53>>>0);
            if (!($54)) {
             label = 19;
            }
           }
           if ((label|0) == 19) {
            label = 0;
            __THREW__ = 0;
            $55 = (invoke_i(132)|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($55|0));
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             label = 8;
             break L8;
            }
           }
           $60 = HEAP32[$18>>2]|0;
           $61 = (($60) + 92|0);
           $62 = HEAP32[$61>>2]|0;
           $63 = Math_imul($62, $V_4$05)|0;
           $64 = (($21) + ($63)|0);
           $65 = HEAP32[$22>>2]|0;
           $66 = HEAP32[$23>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($66|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 24;
           } else {
            $69 = (($66) + 12|0);
            $70 = HEAP32[$69>>2]|0;
            $71 = ($V_4$05>>>0)<($70>>>0);
            if (!($71)) {
             label = 24;
            }
           }
           if ((label|0) == 24) {
            label = 0;
            __THREW__ = 0;
            $72 = (invoke_i(132)|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($72|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 8;
             break L8;
            }
           }
           $77 = HEAP32[$66>>2]|0;
           $78 = (($66) + 16|0);
           $79 = (($77) + 92|0);
           $80 = HEAP32[$79>>2]|0;
           $81 = Math_imul($80, $V_4$05)|0;
           $82 = (($78) + ($81)|0);
           $83 = HEAP32[$82>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($65|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            label = 8;
            break L8;
           }
           __THREW__ = 0;
           $86 = (invoke_iiii(1662,(1409112|0),($65|0),($83|0))|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            label = 8;
            break L8;
           }
           $89 = $86 | -2147483648;
           HEAP32[$64>>2] = $89;
           $90 = $86 & 2147483647;
           $91 = (($90|0) % ($8|0))&-1;
           __THREW__ = 0;
           invoke_vi(3799,($18|0));
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 31;
           } else {
            $94 = HEAP32[$27>>2]|0;
            $95 = ($V_4$05>>>0)<($94>>>0);
            if (!($95)) {
             label = 31;
            }
           }
           if ((label|0) == 31) {
            label = 0;
            __THREW__ = 0;
            $96 = (invoke_i(132)|0);
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($96|0));
            $99 = __THREW__; __THREW__ = 0;
            $100 = $99&1;
            if ($100) {
             label = 8;
             break L8;
            }
           }
           $101 = HEAP32[$18>>2]|0;
           $102 = (($101) + 92|0);
           $103 = HEAP32[$102>>2]|0;
           $104 = Math_imul($103, $V_4$05)|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            label = 8;
            break L8;
           }
           $107 = HEAP32[$24>>2]|0;
           $108 = ($91>>>0)<($107>>>0);
           if (!($108)) {
            __THREW__ = 0;
            $109 = (invoke_i(132)|0);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if ($111) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($109|0));
            $112 = __THREW__; __THREW__ = 0;
            $113 = $112&1;
            if ($113) {
             label = 8;
             break L8;
            }
           }
           $114 = HEAP32[$13>>2]|0;
           $115 = (($114) + 92|0);
           $116 = HEAP32[$115>>2]|0;
           $117 = Math_imul($116, $91)|0;
           $118 = (($25) + ($117)|0);
           $119 = HEAP32[$118>>2]|0;
           $120 = (($119) + -1)|0;
           $$sum = (($104) + 4)|0;
           $121 = (($21) + ($$sum)|0);
           HEAP32[$121>>2] = $120;
           $122 = (($V_4$05) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $123 = __THREW__; __THREW__ = 0;
           $124 = $123&1;
           if ($124) {
            label = 8;
            break L8;
           }
           $125 = HEAP32[$24>>2]|0;
           $126 = ($91>>>0)<($125>>>0);
           if (!($126)) {
            __THREW__ = 0;
            $127 = (invoke_i(132)|0);
            $128 = __THREW__; __THREW__ = 0;
            $129 = $128&1;
            if ($129) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($127|0));
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             label = 8;
             break L8;
            }
           }
           $132 = HEAP32[$13>>2]|0;
           $133 = (($132) + 92|0);
           $134 = HEAP32[$133>>2]|0;
           $135 = Math_imul($134, $91)|0;
           $136 = (($25) + ($135)|0);
           HEAP32[$136>>2] = $122;
           $137 = HEAP32[$26>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($137|0));
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            label = 8;
            break L8;
           }
           if ($52) {
            label = 44;
           } else {
            $140 = (($137) + 12|0);
            $141 = HEAP32[$140>>2]|0;
            $142 = ($V_4$05>>>0)<($141>>>0);
            if (!($142)) {
             label = 44;
            }
           }
           if ((label|0) == 44) {
            label = 0;
            __THREW__ = 0;
            $143 = (invoke_i(132)|0);
            $144 = __THREW__; __THREW__ = 0;
            $145 = $144&1;
            if ($145) {
             label = 8;
             break L8;
            }
            __THREW__ = 0;
            invoke_vi(3302,($143|0));
            $146 = __THREW__; __THREW__ = 0;
            $147 = $146&1;
            if ($147) {
             label = 8;
             break L8;
            }
           }
           $148 = HEAP32[$137>>2]|0;
           $149 = (($137) + 16|0);
           $150 = (($148) + 92|0);
           $151 = HEAP32[$150>>2]|0;
           $152 = Math_imul($151, $V_4$05)|0;
           $$sum4 = (($152) + 4)|0;
           $153 = (($149) + ($$sum4)|0);
           $154 = HEAP32[$153>>2]|0;
           $155 = ($154|0)==(-1);
           if ($155) {
            break;
           } else {
            $V_4$05 = $154;
           }
          }
         }
         $158 = (($V_3$0) + 1)|0;
         $V_3$0 = $158;
        }
        if ((label|0) == 8) {
         $28 = ___cxa_find_matching_catch()|0;
         $29 = tempRet0;
         $lpad$phi$index = $28;$lpad$phi$index3 = $29;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 9) {
         $30 = ___cxa_find_matching_catch()|0;
         $31 = tempRet0;
         $lpad$phi$index = $30;$lpad$phi$index3 = $31;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 52) {
         HEAP32[$0>>2] = $13;
         HEAP32[$26>>2] = $18;
         __THREW__ = 0;
         (invoke_ii(2996,(1170368|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          break;
         }
         __THREW__ = 0;
         $169 = (invoke_iii(2750,(1170368|0),($8|0))|0);
         $170 = __THREW__; __THREW__ = 0;
         $171 = $170&1;
         if ($171) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1197176|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         if ($173) {
          break;
         }
         __THREW__ = 0;
         $174 = (invoke_iii(2750,(1197176|0),($8|0))|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          break;
         }
         $177 = HEAP32[$23>>2]|0;
         $178 = (($__this) + 24|0);
         $179 = HEAP32[$178>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($177|0),0,($169|0),0,($179|0));
         $180 = __THREW__; __THREW__ = 0;
         $181 = $180&1;
         if ($181) {
          break;
         }
         $182 = (($__this) + 20|0);
         $183 = HEAP32[$182>>2]|0;
         $184 = HEAP32[$178>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($183|0),0,($174|0),0,($184|0));
         $185 = __THREW__; __THREW__ = 0;
         $186 = $185&1;
         if ($186) {
          break;
         }
         HEAP32[$23>>2] = $169;
         HEAP32[$182>>2] = $174;
         $187 = (Math_fround(($8|0)));
         $188 = Math_fround($187 * Math_fround(0.899999976158142089843));
         $189 = (~~(($188)));
         $190 = (($__this) + 36|0);
         HEAP32[$190>>2] = $189;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 $lpad$phi$index = $32;$lpad$phi$index3 = $33;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z145mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_InitArraysP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachei($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884960);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2750,(1170368|0),($size|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $2;
   __THREW__ = 0;
   (invoke_ii(2996,(1170744|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2750,(1170744|0),($size|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($__this) + 12|0);
     HEAP32[$11>>2] = $8;
     $12 = (($__this) + 28|0);
     HEAP32[$12>>2] = -1;
     __THREW__ = 0;
     (invoke_ii(2996,(1170368|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_iii(2750,(1170368|0),($size|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = (($__this) + 16|0);
       HEAP32[$18>>2] = $15;
       __THREW__ = 0;
       (invoke_ii(2996,(1197176|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        $21 = (invoke_iii(2750,(1197176|0),($size|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         $24 = (($__this) + 20|0);
         HEAP32[$24>>2] = $21;
         $25 = (($__this) + 24|0);
         HEAP32[$25>>2] = 0;
         $26 = HEAP32[$5>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($26|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($26) + 12|0);
          $30 = HEAP32[$29>>2]|0;
          $31 = (Math_fround(($30|0)));
          $32 = Math_fround($31 * Math_fround(0.899999976158142089843));
          $33 = (~~(($32)));
          $34 = (($__this) + 36|0);
          HEAP32[$34>>2] = $33;
          $35 = ($33|0)==(0);
          if (!($35)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          $38 = HEAP32[$5>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($38|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = (($38) + 12|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = ($42|0)<(1);
           if ($43) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           HEAP32[$34>>2] = 1;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($36|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj3329($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z144mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_make_pairP22mscorlib_System_ObjectiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884672);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(442,($agg$result|0),($key|0),($value|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z142mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1889528);
 __THREW__ = 0;
 invoke_vii(1618,($__this|0),($key|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1619,($__this|0),($value|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z145mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_pick_valueP22mscorlib_System_ObjectiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885056);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($value|0);
}
function __Z138mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_AddP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $L_0 = 0, $V_1$0 = 0, $V_2$06 = 0, $V_2$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884336);
 __THREW__ = 0;
 invoke_v(337);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   HEAP32[$L_0>>2] = $key;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2724,(2155952|0),($L_0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560584|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      $14 = (invoke_ii(3469,(2560584|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      $17 = HEAP32[3020792>>2]|0;
      __THREW__ = 0;
      invoke_vii(1925,($14|0),($17|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3823,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      // unreachable;
     }
     $22 = (($__this) + 40|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      $26 = (invoke_iiii(1662,(1409112|0),($23|0),($key|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = $26 | -2147483648;
       $30 = $26 & 2147483647;
       $31 = (($__this) + 8|0);
       $32 = HEAP32[$31>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        $35 = (($32) + 12|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = (($30|0) % ($36|0))&-1;
        $38 = HEAP32[$31>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($38|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = (($38) + 12|0);
         $42 = HEAP32[$41>>2]|0;
         $43 = ($37>>>0)<($42>>>0);
         if (!($43)) {
          __THREW__ = 0;
          $44 = (invoke_i(132)|0);
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($44|0));
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           break;
          }
         }
         $49 = HEAP32[$38>>2]|0;
         $50 = (($38) + 16|0);
         $51 = (($49) + 92|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = Math_imul($52, $37)|0;
         $54 = (($50) + ($53)|0);
         $55 = HEAP32[$54>>2]|0;
         $56 = ($55|0)==(0);
         L20: do {
          if (!($56)) {
           $57 = (($55) + -1)|0;
           $58 = (($__this) + 12|0);
           $59 = (($__this) + 16|0);
           $V_2$06 = $57;
           while(1) {
            $62 = HEAP32[$58>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($62|0));
            $131 = __THREW__; __THREW__ = 0;
            $132 = $131&1;
            if ($132) {
             label = 5;
             break;
            }
            $60 = ($V_2$06|0)<(0);
            if ($60) {
             label = 24;
            } else {
             $61 = (($62) + 12|0);
             $63 = HEAP32[$61>>2]|0;
             $64 = ($V_2$06>>>0)<($63>>>0);
             if (!($64)) {
              label = 24;
             }
            }
            if ((label|0) == 24) {
             label = 0;
             __THREW__ = 0;
             $65 = (invoke_i(132)|0);
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if ($67) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($65|0));
             $68 = __THREW__; __THREW__ = 0;
             $69 = $68&1;
             if ($69) {
              label = 5;
              break;
             }
            }
            $70 = HEAP32[$62>>2]|0;
            $71 = (($62) + 16|0);
            $72 = (($70) + 92|0);
            $73 = HEAP32[$72>>2]|0;
            $74 = Math_imul($73, $V_2$06)|0;
            $75 = (($71) + ($74)|0);
            $76 = HEAP32[$75>>2]|0;
            $77 = ($76|0)==($29|0);
            if ($77) {
             $78 = HEAP32[$22>>2]|0;
             $79 = HEAP32[$59>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($79|0));
             $80 = __THREW__; __THREW__ = 0;
             $81 = $80&1;
             if ($81) {
              label = 5;
              break;
             }
             if ($60) {
              label = 30;
             } else {
              $82 = (($79) + 12|0);
              $83 = HEAP32[$82>>2]|0;
              $84 = ($V_2$06>>>0)<($83>>>0);
              if (!($84)) {
               label = 30;
              }
             }
             if ((label|0) == 30) {
              label = 0;
              __THREW__ = 0;
              $85 = (invoke_i(132)|0);
              $86 = __THREW__; __THREW__ = 0;
              $87 = $86&1;
              if ($87) {
               label = 5;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($85|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if ($89) {
               label = 5;
               break;
              }
             }
             $90 = HEAP32[$79>>2]|0;
             $91 = (($79) + 16|0);
             $92 = (($90) + 92|0);
             $93 = HEAP32[$92>>2]|0;
             $94 = Math_imul($93, $V_2$06)|0;
             $95 = (($91) + ($94)|0);
             $96 = HEAP32[$95>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($78|0));
             $97 = __THREW__; __THREW__ = 0;
             $98 = $97&1;
             if ($98) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             $99 = (invoke_iiiii(306,(1398000|0),($78|0),($96|0),($key|0))|0);
             $100 = __THREW__; __THREW__ = 0;
             $101 = $100&1;
             if ($101) {
              label = 5;
              break;
             }
             if ($99) {
              break;
             }
            }
            $112 = HEAP32[$58>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($112|0));
            $113 = __THREW__; __THREW__ = 0;
            $114 = $113&1;
            if ($114) {
             label = 5;
             break;
            }
            if ($60) {
             label = 43;
            } else {
             $115 = (($112) + 12|0);
             $116 = HEAP32[$115>>2]|0;
             $117 = ($V_2$06>>>0)<($116>>>0);
             if (!($117)) {
              label = 43;
             }
            }
            if ((label|0) == 43) {
             label = 0;
             __THREW__ = 0;
             $118 = (invoke_i(132)|0);
             $119 = __THREW__; __THREW__ = 0;
             $120 = $119&1;
             if ($120) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($118|0));
             $121 = __THREW__; __THREW__ = 0;
             $122 = $121&1;
             if ($122) {
              label = 5;
              break;
             }
            }
            $123 = HEAP32[$112>>2]|0;
            $124 = (($112) + 16|0);
            $125 = (($123) + 92|0);
            $126 = HEAP32[$125>>2]|0;
            $127 = Math_imul($126, $V_2$06)|0;
            $$sum = (($127) + 4)|0;
            $128 = (($124) + ($$sum)|0);
            $129 = HEAP32[$128>>2]|0;
            $130 = ($129|0)==(-1);
            if ($130) {
             break L20;
            } else {
             $V_2$06 = $129;
            }
           }
           if ((label|0) == 5) {
            $8 = ___cxa_find_matching_catch()|0;
            $9 = tempRet0;
            $lpad$phi$index = $8;$lpad$phi$index2 = $9;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $102 = __THREW__; __THREW__ = 0;
           $103 = $102&1;
           if ($103) {
            break L1;
           }
           __THREW__ = 0;
           $104 = (invoke_ii(3469,(2560072|0))|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            break L1;
           }
           $107 = HEAP32[3020800>>2]|0;
           __THREW__ = 0;
           invoke_vii(1924,($104|0),($107|0));
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3823,($104|0));
           $110 = __THREW__; __THREW__ = 0;
           $111 = $110&1;
           if ($111) {
            break L1;
           }
           // unreachable;
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if (!($134)) {
          $135 = (($__this) + 32|0);
          $136 = HEAP32[$135>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if (!($138)) {
           $139 = (($136) + 1)|0;
           HEAP32[$135>>2] = $139;
           $140 = (($__this) + 36|0);
           $141 = HEAP32[$140>>2]|0;
           $142 = ($136|0)<($141|0);
           if ($142) {
            $V_1$0 = $37;
           } else {
            __THREW__ = 0;
            invoke_vi(1792,($__this|0));
            $143 = __THREW__; __THREW__ = 0;
            $144 = $143&1;
            if ($144) {
             break;
            }
            $145 = HEAP32[$31>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($145|0));
            $146 = __THREW__; __THREW__ = 0;
            $147 = $146&1;
            if ($147) {
             break;
            }
            $148 = (($145) + 12|0);
            $149 = HEAP32[$148>>2]|0;
            $150 = (($30|0) % ($149|0))&-1;
            $V_1$0 = $150;
           }
           $151 = (($__this) + 28|0);
           $152 = HEAP32[$151>>2]|0;
           $153 = ($152|0)==(-1);
           if ($153) {
            __THREW__ = 0;
            invoke_vi(3799,($__this|0));
            $154 = __THREW__; __THREW__ = 0;
            $155 = $154&1;
            if ($155) {
             break;
            }
            $156 = (($__this) + 24|0);
            $157 = HEAP32[$156>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($__this|0));
            $158 = __THREW__; __THREW__ = 0;
            $159 = $158&1;
            if ($159) {
             break;
            }
            $160 = (($157) + 1)|0;
            HEAP32[$156>>2] = $160;
            $$pre = (($__this) + 12|0);
            $$pre$phiZ2D = $$pre;$V_2$1 = $157;
           } else {
            $161 = (($__this) + 12|0);
            $162 = HEAP32[$161>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($162|0));
            $163 = __THREW__; __THREW__ = 0;
            $164 = $163&1;
            if ($164) {
             break;
            }
            $165 = ($152|0)<(0);
            if ($165) {
             label = 60;
            } else {
             $166 = (($162) + 12|0);
             $167 = HEAP32[$166>>2]|0;
             $168 = ($152>>>0)<($167>>>0);
             if (!($168)) {
              label = 60;
             }
            }
            if ((label|0) == 60) {
             __THREW__ = 0;
             $169 = (invoke_i(132)|0);
             $170 = __THREW__; __THREW__ = 0;
             $171 = $170&1;
             if ($171) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($169|0));
             $172 = __THREW__; __THREW__ = 0;
             $173 = $172&1;
             if ($173) {
              break;
             }
            }
            $174 = HEAP32[$162>>2]|0;
            $175 = (($162) + 16|0);
            $176 = (($174) + 92|0);
            $177 = HEAP32[$176>>2]|0;
            $178 = Math_imul($177, $152)|0;
            $$sum4 = (($178) + 4)|0;
            $179 = (($175) + ($$sum4)|0);
            $180 = HEAP32[$179>>2]|0;
            HEAP32[$151>>2] = $180;
            $$pre$phiZ2D = $161;$V_2$1 = $152;
           }
           $181 = HEAP32[$$pre$phiZ2D>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($181|0));
           $182 = __THREW__; __THREW__ = 0;
           $183 = $182&1;
           if (!($183)) {
            $184 = ($V_2$1|0)<(0);
            if ($184) {
             label = 66;
            } else {
             $185 = (($181) + 12|0);
             $186 = HEAP32[$185>>2]|0;
             $187 = ($V_2$1>>>0)<($186>>>0);
             if (!($187)) {
              label = 66;
             }
            }
            if ((label|0) == 66) {
             __THREW__ = 0;
             $188 = (invoke_i(132)|0);
             $189 = __THREW__; __THREW__ = 0;
             $190 = $189&1;
             if ($190) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($188|0));
             $191 = __THREW__; __THREW__ = 0;
             $192 = $191&1;
             if ($192) {
              break;
             }
            }
            $193 = HEAP32[$181>>2]|0;
            $194 = (($181) + 16|0);
            $195 = (($193) + 92|0);
            $196 = HEAP32[$195>>2]|0;
            $197 = Math_imul($196, $V_2$1)|0;
            $198 = (($194) + ($197)|0);
            HEAP32[$198>>2] = $29;
            $199 = HEAP32[$$pre$phiZ2D>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($199|0));
            $200 = __THREW__; __THREW__ = 0;
            $201 = $200&1;
            if (!($201)) {
             if ($184) {
              label = 71;
             } else {
              $202 = (($199) + 12|0);
              $203 = HEAP32[$202>>2]|0;
              $204 = ($V_2$1>>>0)<($203>>>0);
              if (!($204)) {
               label = 71;
              }
             }
             if ((label|0) == 71) {
              __THREW__ = 0;
              $205 = (invoke_i(132)|0);
              $206 = __THREW__; __THREW__ = 0;
              $207 = $206&1;
              if ($207) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($205|0));
              $208 = __THREW__; __THREW__ = 0;
              $209 = $208&1;
              if ($209) {
               break;
              }
             }
             $210 = HEAP32[$199>>2]|0;
             $211 = (($199) + 16|0);
             $212 = (($210) + 92|0);
             $213 = HEAP32[$212>>2]|0;
             $214 = Math_imul($213, $V_2$1)|0;
             $215 = HEAP32[$31>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($215|0));
             $216 = __THREW__; __THREW__ = 0;
             $217 = $216&1;
             if (!($217)) {
              $218 = (($215) + 12|0);
              $219 = HEAP32[$218>>2]|0;
              $220 = ($V_1$0>>>0)<($219>>>0);
              if (!($220)) {
               __THREW__ = 0;
               $221 = (invoke_i(132)|0);
               $222 = __THREW__; __THREW__ = 0;
               $223 = $222&1;
               if ($223) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($221|0));
               $224 = __THREW__; __THREW__ = 0;
               $225 = $224&1;
               if ($225) {
                break;
               }
              }
              $226 = HEAP32[$215>>2]|0;
              $227 = (($215) + 16|0);
              $228 = (($226) + 92|0);
              $229 = HEAP32[$228>>2]|0;
              $230 = Math_imul($229, $V_1$0)|0;
              $231 = (($227) + ($230)|0);
              $232 = HEAP32[$231>>2]|0;
              $233 = (($232) + -1)|0;
              $$sum5 = (($214) + 4)|0;
              $234 = (($211) + ($$sum5)|0);
              HEAP32[$234>>2] = $233;
              $235 = HEAP32[$31>>2]|0;
              $236 = (($V_2$1) + 1)|0;
              __THREW__ = 0;
              invoke_vi(3799,($235|0));
              $237 = __THREW__; __THREW__ = 0;
              $238 = $237&1;
              if ($238) {
               break;
              }
              $239 = (($235) + 12|0);
              $240 = HEAP32[$239>>2]|0;
              $241 = ($V_1$0>>>0)<($240>>>0);
              if (!($241)) {
               __THREW__ = 0;
               $242 = (invoke_i(132)|0);
               $243 = __THREW__; __THREW__ = 0;
               $244 = $243&1;
               if ($244) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($242|0));
               $245 = __THREW__; __THREW__ = 0;
               $246 = $245&1;
               if ($246) {
                break;
               }
              }
              $247 = HEAP32[$235>>2]|0;
              $248 = (($235) + 16|0);
              $249 = (($247) + 92|0);
              $250 = HEAP32[$249>>2]|0;
              $251 = Math_imul($250, $V_1$0)|0;
              $252 = (($248) + ($251)|0);
              HEAP32[$252>>2] = $236;
              $253 = (($__this) + 16|0);
              $254 = HEAP32[$253>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($254|0));
              $255 = __THREW__; __THREW__ = 0;
              $256 = $255&1;
              if ($256) {
               break;
              }
              if ($184) {
               label = 84;
              } else {
               $257 = (($254) + 12|0);
               $258 = HEAP32[$257>>2]|0;
               $259 = ($V_2$1>>>0)<($258>>>0);
               if (!($259)) {
                label = 84;
               }
              }
              if ((label|0) == 84) {
               __THREW__ = 0;
               $260 = (invoke_i(132)|0);
               $261 = __THREW__; __THREW__ = 0;
               $262 = $261&1;
               if ($262) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($260|0));
               $263 = __THREW__; __THREW__ = 0;
               $264 = $263&1;
               if ($264) {
                break;
               }
              }
              $265 = HEAP32[$254>>2]|0;
              $266 = (($254) + 16|0);
              $267 = (($265) + 92|0);
              $268 = HEAP32[$267>>2]|0;
              $269 = Math_imul($268, $V_2$1)|0;
              $270 = (($266) + ($269)|0);
              HEAP32[$270>>2] = $key;
              $271 = (($__this) + 20|0);
              $272 = HEAP32[$271>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($272|0));
              $273 = __THREW__; __THREW__ = 0;
              $274 = $273&1;
              if ($274) {
               break;
              }
              if ($184) {
               label = 89;
              } else {
               $275 = (($272) + 12|0);
               $276 = HEAP32[$275>>2]|0;
               $277 = ($V_2$1>>>0)<($276>>>0);
               if (!($277)) {
                label = 89;
               }
              }
              if ((label|0) == 89) {
               __THREW__ = 0;
               $278 = (invoke_i(132)|0);
               $279 = __THREW__; __THREW__ = 0;
               $280 = $279&1;
               if ($280) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($278|0));
               $281 = __THREW__; __THREW__ = 0;
               $282 = $281&1;
               if ($282) {
                break;
               }
              }
              $283 = HEAP32[$272>>2]|0;
              $284 = (($272) + 16|0);
              $285 = (($283) + 92|0);
              $286 = HEAP32[$285>>2]|0;
              $287 = Math_imul($286, $V_2$1)|0;
              $288 = (($284) + ($287)|0);
              HEAP32[$288>>2] = $value;
              __THREW__ = 0;
              invoke_vi(3799,($__this|0));
              $289 = __THREW__; __THREW__ = 0;
              $290 = $289&1;
              if ($290) {
               break;
              }
              $291 = (($__this) + 48|0);
              $292 = HEAP32[$291>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($__this|0));
              $293 = __THREW__; __THREW__ = 0;
              $294 = $293&1;
              if ($294) {
               break;
              }
              $295 = (($292) + 1)|0;
              HEAP32[$291>>2] = $295;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ClearP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885200);
 $0 = (($__this) + 32|0);
 HEAP32[$0>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($2) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  invoke_viiii(138,(0|0),($2|0),0,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = (($__this) + 16|0);
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = (($10) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($10|0),0,($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = (($__this) + 20|0);
     $18 = HEAP32[$17>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($18) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      __THREW__ = 0;
      invoke_viiii(138,(0|0),($18|0),0,($22|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = (($__this) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $29 = (($26) + 12|0);
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        invoke_viiii(138,(0|0),($26|0),0,($30|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $33 = (($__this) + 28|0);
         HEAP32[$33>>2] = -1;
         $34 = (($__this) + 24|0);
         HEAP32[$34>>2] = 0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          $37 = (($__this) + 48|0);
          $38 = HEAP32[$37>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = (($38) + 1)|0;
           HEAP32[$37>>2] = $41;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($42|0);
 // unreachable;
}
function __Z148mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ContainsValueP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $V_1$0 = 0, $V_2$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885248);
 __THREW__ = 0;
 $0 = (invoke_ii(1496,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index3 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $3 = (($__this) + 8|0);
 $4 = (($__this) + 20|0);
 $5 = (($__this) + 12|0);
 $V_1$0 = 0;
 L5: while(1) {
  $74 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($74|0));
  $75 = __THREW__; __THREW__ = 0;
  $76 = $75&1;
  if ($76) {
   label = 4;
   break;
  }
  $77 = (($74) + 12|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ($V_1$0|0)<($78|0);
  if (!($79)) {
   $$0 = 0;
   label = 30;
   break;
  }
  $13 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($13|0));
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   label = 4;
   break;
  }
  $12 = (($13) + 12|0);
  $14 = HEAP32[$12>>2]|0;
  $15 = ($V_1$0>>>0)<($14>>>0);
  if (!($15)) {
   __THREW__ = 0;
   $16 = (invoke_i(132)|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 4;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($16|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 4;
    break;
   }
  }
  $21 = HEAP32[$13>>2]|0;
  $22 = (($13) + 16|0);
  $23 = (($21) + 92|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = Math_imul($24, $V_1$0)|0;
  $26 = (($22) + ($25)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0);
  if (!($28)) {
   $29 = (($27) + -1)|0;
   $V_2$02 = $29;
   while(1) {
    $32 = HEAP32[$4>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     label = 3;
     break L5;
    }
    $30 = ($V_2$02|0)<(0);
    if ($30) {
     label = 14;
    } else {
     $31 = (($32) + 12|0);
     $33 = HEAP32[$31>>2]|0;
     $34 = ($V_2$02>>>0)<($33>>>0);
     if (!($34)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     __THREW__ = 0;
     $35 = (invoke_i(132)|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 3;
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3302,($35|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      label = 3;
      break L5;
     }
    }
    $40 = HEAP32[$32>>2]|0;
    $41 = (($32) + 16|0);
    $42 = (($40) + 92|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = Math_imul($43, $V_2$02)|0;
    $45 = (($41) + ($44)|0);
    $46 = HEAP32[$45>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 3;
     break L5;
    }
    __THREW__ = 0;
    $49 = (invoke_iiiii(305,(1885296|0),($0|0),($46|0),($value|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 3;
     break L5;
    }
    if ($49) {
     $$0 = 1;
     label = 30;
     break L5;
    }
    $52 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($52|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 3;
     break L5;
    }
    if ($30) {
     label = 22;
    } else {
     $55 = (($52) + 12|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($V_2$02>>>0)<($56>>>0);
     if (!($57)) {
      label = 22;
     }
    }
    if ((label|0) == 22) {
     label = 0;
     __THREW__ = 0;
     $58 = (invoke_i(132)|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 3;
      break L5;
     }
     __THREW__ = 0;
     invoke_vi(3302,($58|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 3;
      break L5;
     }
    }
    $63 = HEAP32[$52>>2]|0;
    $64 = (($52) + 16|0);
    $65 = (($63) + 92|0);
    $66 = HEAP32[$65>>2]|0;
    $67 = Math_imul($66, $V_2$02)|0;
    $$sum = (($67) + 4)|0;
    $68 = (($64) + ($$sum)|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = ($69|0)==(-1);
    if ($70) {
     break;
    } else {
     $V_2$02 = $69;
    }
   }
  }
  $73 = (($V_1$0) + 1)|0;
  $V_1$0 = $73;
 }
 if ((label|0) == 3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $lpad$phi$index = $6;$lpad$phi$index3 = $7;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 4) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $lpad$phi$index = $8;$lpad$phi$index3 = $9;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZL121mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1900640)|0);
 $0 = HEAP32[((1900640 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z148mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_GetObjectDataP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885344);
 __THREW__ = 0;
 invoke_v(338);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020944>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 48|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3020952>>2]|0;
    __THREW__ = 0;
    invoke_viii(618,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 40|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[3020960>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($26|0),($23|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = (($__this) + 32|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)<(1);
       if ($31) {
        $V_0$0 = 0;
       } else {
        __THREW__ = 0;
        (invoke_ii(2996,(1196792|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2750,(1196792|0),($30|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break;
        }
        __THREW__ = 0;
        invoke_viii(440,($__this|0),($34|0),0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        } else {
         $V_0$0 = $34;
        }
       }
       $39 = (($__this) + 8|0);
       $40 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($40|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        $43 = (($40) + 12|0);
        $44 = HEAP32[$43>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = HEAP32[3020968>>2]|0;
         __THREW__ = 0;
         invoke_viii(618,($info|0),($47|0),($44|0));
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if (!($49)) {
          __THREW__ = 0;
          invoke_vi(3799,($info|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if (!($51)) {
           $52 = HEAP32[3020976>>2]|0;
           __THREW__ = 0;
           invoke_viii(621,($info|0),($52|0),($V_0$0|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if (!($54)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z141mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_RemoveP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachei($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $$0 = 0, $$sum = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_0 = 0, $V_2$0 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884528);
 __THREW__ = 0;
 invoke_v(339);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   HEAP32[$L_0>>2] = $key;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2724,(2155952|0),($L_0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560584|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      $14 = (invoke_ii(3469,(2560584|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      $17 = HEAP32[3021072>>2]|0;
      __THREW__ = 0;
      invoke_vii(1925,($14|0),($17|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3823,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      // unreachable;
     }
     $22 = (($__this) + 40|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      $26 = (invoke_iiii(1662,(1409112|0),($23|0),($key|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = $26 | -2147483648;
       $30 = (($__this) + 8|0);
       $31 = HEAP32[$30>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($31|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        $34 = $26 & 2147483647;
        $35 = (($31) + 12|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = (($34|0) % ($36|0))&-1;
        $38 = HEAP32[$30>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($38|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = (($38) + 12|0);
         $42 = HEAP32[$41>>2]|0;
         $43 = ($37>>>0)<($42>>>0);
         if (!($43)) {
          __THREW__ = 0;
          $44 = (invoke_i(132)|0);
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($44|0));
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           break;
          }
         }
         $49 = HEAP32[$38>>2]|0;
         $50 = (($38) + 16|0);
         $51 = (($49) + 92|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = Math_imul($52, $37)|0;
         $54 = (($50) + ($53)|0);
         $55 = HEAP32[$54>>2]|0;
         $56 = ($55|0)==(0);
         if ($56) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $57 = (($55) + -1)|0;
         $58 = (($__this) + 12|0);
         $59 = (($__this) + 16|0);
         $V_2$0 = $57;$V_3$0 = -1;
         while(1) {
          $60 = HEAP32[$58>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($60|0));
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           label = 5;
           break;
          }
          $63 = ($V_2$0|0)<(0);
          if ($63) {
           label = 25;
          } else {
           $64 = (($60) + 12|0);
           $65 = HEAP32[$64>>2]|0;
           $66 = ($V_2$0>>>0)<($65>>>0);
           if (!($66)) {
            label = 25;
           }
          }
          if ((label|0) == 25) {
           label = 0;
           __THREW__ = 0;
           $67 = (invoke_i(132)|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($67|0));
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            label = 5;
            break;
           }
          }
          $72 = HEAP32[$60>>2]|0;
          $73 = (($60) + 16|0);
          $74 = (($72) + 92|0);
          $75 = HEAP32[$74>>2]|0;
          $76 = Math_imul($75, $V_2$0)|0;
          $77 = (($73) + ($76)|0);
          $78 = HEAP32[$77>>2]|0;
          $79 = ($78|0)==($29|0);
          if ($79) {
           $80 = HEAP32[$22>>2]|0;
           $81 = HEAP32[$59>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($81|0));
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if ($83) {
            label = 5;
            break;
           }
           if ($63) {
            label = 31;
           } else {
            $84 = (($81) + 12|0);
            $85 = HEAP32[$84>>2]|0;
            $86 = ($V_2$0>>>0)<($85>>>0);
            if (!($86)) {
             label = 31;
            }
           }
           if ((label|0) == 31) {
            label = 0;
            __THREW__ = 0;
            $87 = (invoke_i(132)|0);
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if ($89) {
             label = 5;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($87|0));
            $90 = __THREW__; __THREW__ = 0;
            $91 = $90&1;
            if ($91) {
             label = 5;
             break;
            }
           }
           $92 = HEAP32[$81>>2]|0;
           $93 = (($81) + 16|0);
           $94 = (($92) + 92|0);
           $95 = HEAP32[$94>>2]|0;
           $96 = Math_imul($95, $V_2$0)|0;
           $97 = (($93) + ($96)|0);
           $98 = HEAP32[$97>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($80|0));
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           $101 = (invoke_iiiii(306,(1398000|0),($80|0),($98|0),($key|0))|0);
           $102 = __THREW__; __THREW__ = 0;
           $103 = $102&1;
           if ($103) {
            label = 5;
            break;
           }
           if ($101) {
            label = 42;
            break;
           }
          }
          $104 = HEAP32[$58>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($104|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           label = 5;
           break;
          }
          if ($63) {
           label = 39;
          } else {
           $107 = (($104) + 12|0);
           $108 = HEAP32[$107>>2]|0;
           $109 = ($V_2$0>>>0)<($108>>>0);
           if (!($109)) {
            label = 39;
           }
          }
          if ((label|0) == 39) {
           label = 0;
           __THREW__ = 0;
           $110 = (invoke_i(132)|0);
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($110|0));
           $113 = __THREW__; __THREW__ = 0;
           $114 = $113&1;
           if ($114) {
            label = 5;
            break;
           }
          }
          $115 = HEAP32[$104>>2]|0;
          $116 = (($104) + 16|0);
          $117 = (($115) + 92|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = Math_imul($118, $V_2$0)|0;
          $$sum = (($119) + 4)|0;
          $120 = (($116) + ($$sum)|0);
          $121 = HEAP32[$120>>2]|0;
          $122 = ($121|0)==(-1);
          if ($122) {
           $$0 = 0;
           label = 90;
           break;
          } else {
           $V_3$0$phi = $V_2$0;$V_2$0 = $121;$V_3$0 = $V_3$0$phi;
          }
         }
         if ((label|0) == 5) {
          $8 = ___cxa_find_matching_catch()|0;
          $9 = tempRet0;
          $lpad$phi$index = $8;$lpad$phi$index2 = $9;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 42) {
          $123 = ($V_2$0|0)==(-1);
          if ($123) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $124 = __THREW__; __THREW__ = 0;
          $125 = $124&1;
          if ($125) {
           break;
          }
          $126 = (($__this) + 32|0);
          $127 = HEAP32[$126>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           break;
          }
          $130 = (($127) + -1)|0;
          HEAP32[$126>>2] = $130;
          $131 = ($V_3$0|0)==(-1);
          if ($131) {
           $132 = HEAP32[$30>>2]|0;
           $133 = HEAP32[$58>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($133|0));
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if ($135) {
            break;
           }
           if ($63) {
            label = 49;
           } else {
            $136 = (($133) + 12|0);
            $137 = HEAP32[$136>>2]|0;
            $138 = ($V_2$0>>>0)<($137>>>0);
            if (!($138)) {
             label = 49;
            }
           }
           if ((label|0) == 49) {
            __THREW__ = 0;
            $139 = (invoke_i(132)|0);
            $140 = __THREW__; __THREW__ = 0;
            $141 = $140&1;
            if ($141) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($139|0));
            $142 = __THREW__; __THREW__ = 0;
            $143 = $142&1;
            if ($143) {
             break;
            }
           }
           $144 = HEAP32[$133>>2]|0;
           $145 = (($133) + 16|0);
           $146 = (($144) + 92|0);
           $147 = HEAP32[$146>>2]|0;
           $148 = Math_imul($147, $V_2$0)|0;
           $$sum6 = (($148) + 4)|0;
           $149 = (($145) + ($$sum6)|0);
           $150 = HEAP32[$149>>2]|0;
           $151 = (($150) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($132|0));
           $152 = __THREW__; __THREW__ = 0;
           $153 = $152&1;
           if ($153) {
            break;
           }
           $154 = (($132) + 12|0);
           $155 = HEAP32[$154>>2]|0;
           $156 = ($37>>>0)<($155>>>0);
           if (!($156)) {
            __THREW__ = 0;
            $157 = (invoke_i(132)|0);
            $158 = __THREW__; __THREW__ = 0;
            $159 = $158&1;
            if ($159) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($157|0));
            $160 = __THREW__; __THREW__ = 0;
            $161 = $160&1;
            if ($161) {
             break;
            }
           }
           $162 = HEAP32[$132>>2]|0;
           $163 = (($132) + 16|0);
           $164 = (($162) + 92|0);
           $165 = HEAP32[$164>>2]|0;
           $166 = Math_imul($165, $37)|0;
           $167 = (($163) + ($166)|0);
           HEAP32[$167>>2] = $151;
          } else {
           $168 = HEAP32[$58>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($168|0));
           $169 = __THREW__; __THREW__ = 0;
           $170 = $169&1;
           if ($170) {
            break;
           }
           $171 = ($V_3$0|0)<(0);
           if ($171) {
            label = 59;
           } else {
            $172 = (($168) + 12|0);
            $173 = HEAP32[$172>>2]|0;
            $174 = ($V_3$0>>>0)<($173>>>0);
            if (!($174)) {
             label = 59;
            }
           }
           if ((label|0) == 59) {
            __THREW__ = 0;
            $175 = (invoke_i(132)|0);
            $176 = __THREW__; __THREW__ = 0;
            $177 = $176&1;
            if ($177) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($175|0));
            $178 = __THREW__; __THREW__ = 0;
            $179 = $178&1;
            if ($179) {
             break;
            }
           }
           $180 = HEAP32[$168>>2]|0;
           $181 = (($168) + 16|0);
           $182 = (($180) + 92|0);
           $183 = HEAP32[$182>>2]|0;
           $184 = Math_imul($183, $V_3$0)|0;
           $185 = HEAP32[$58>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($185|0));
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if ($187) {
            break;
           }
           if ($63) {
            label = 64;
           } else {
            $188 = (($185) + 12|0);
            $189 = HEAP32[$188>>2]|0;
            $190 = ($V_2$0>>>0)<($189>>>0);
            if (!($190)) {
             label = 64;
            }
           }
           if ((label|0) == 64) {
            __THREW__ = 0;
            $191 = (invoke_i(132)|0);
            $192 = __THREW__; __THREW__ = 0;
            $193 = $192&1;
            if ($193) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($191|0));
            $194 = __THREW__; __THREW__ = 0;
            $195 = $194&1;
            if ($195) {
             break;
            }
           }
           $196 = HEAP32[$185>>2]|0;
           $197 = (($185) + 16|0);
           $198 = (($196) + 92|0);
           $199 = HEAP32[$198>>2]|0;
           $200 = Math_imul($199, $V_2$0)|0;
           $$sum3 = (($200) + 4)|0;
           $201 = (($197) + ($$sum3)|0);
           $202 = HEAP32[$201>>2]|0;
           $$sum4 = (($184) + 4)|0;
           $203 = (($181) + ($$sum4)|0);
           HEAP32[$203>>2] = $202;
          }
          $204 = HEAP32[$58>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($204|0));
          $205 = __THREW__; __THREW__ = 0;
          $206 = $205&1;
          if ($206) {
           break;
          }
          if ($63) {
           label = 70;
          } else {
           $207 = (($204) + 12|0);
           $208 = HEAP32[$207>>2]|0;
           $209 = ($V_2$0>>>0)<($208>>>0);
           if (!($209)) {
            label = 70;
           }
          }
          if ((label|0) == 70) {
           __THREW__ = 0;
           $210 = (invoke_i(132)|0);
           $211 = __THREW__; __THREW__ = 0;
           $212 = $211&1;
           if ($212) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($210|0));
           $213 = __THREW__; __THREW__ = 0;
           $214 = $213&1;
           if ($214) {
            break;
           }
          }
          $215 = HEAP32[$204>>2]|0;
          $216 = (($204) + 16|0);
          $217 = (($215) + 92|0);
          $218 = HEAP32[$217>>2]|0;
          $219 = Math_imul($218, $V_2$0)|0;
          $220 = (($__this) + 28|0);
          $221 = HEAP32[$220>>2]|0;
          $$sum5 = (($219) + 4)|0;
          $222 = (($216) + ($$sum5)|0);
          HEAP32[$222>>2] = $221;
          HEAP32[$220>>2] = $V_2$0;
          $223 = HEAP32[$58>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($223|0));
          $224 = __THREW__; __THREW__ = 0;
          $225 = $224&1;
          if ($225) {
           break;
          }
          if ($63) {
           label = 75;
          } else {
           $226 = (($223) + 12|0);
           $227 = HEAP32[$226>>2]|0;
           $228 = ($V_2$0>>>0)<($227>>>0);
           if (!($228)) {
            label = 75;
           }
          }
          if ((label|0) == 75) {
           __THREW__ = 0;
           $229 = (invoke_i(132)|0);
           $230 = __THREW__; __THREW__ = 0;
           $231 = $230&1;
           if ($231) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($229|0));
           $232 = __THREW__; __THREW__ = 0;
           $233 = $232&1;
           if ($233) {
            break;
           }
          }
          $234 = HEAP32[$223>>2]|0;
          $235 = (($223) + 16|0);
          $236 = (($234) + 92|0);
          $237 = HEAP32[$236>>2]|0;
          $238 = Math_imul($237, $V_2$0)|0;
          $239 = (($235) + ($238)|0);
          HEAP32[$239>>2] = 0;
          $240 = HEAP32[$59>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($240|0));
          $241 = __THREW__; __THREW__ = 0;
          $242 = $241&1;
          if ($242) {
           break;
          }
          if ($63) {
           label = 80;
          } else {
           $243 = (($240) + 12|0);
           $244 = HEAP32[$243>>2]|0;
           $245 = ($V_2$0>>>0)<($244>>>0);
           if (!($245)) {
            label = 80;
           }
          }
          if ((label|0) == 80) {
           __THREW__ = 0;
           $246 = (invoke_i(132)|0);
           $247 = __THREW__; __THREW__ = 0;
           $248 = $247&1;
           if ($248) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($246|0));
           $249 = __THREW__; __THREW__ = 0;
           $250 = $249&1;
           if ($250) {
            break;
           }
          }
          $251 = HEAP32[$240>>2]|0;
          $252 = (($240) + 16|0);
          $253 = (($251) + 92|0);
          $254 = HEAP32[$253>>2]|0;
          $255 = Math_imul($254, $V_2$0)|0;
          $256 = (($252) + ($255)|0);
          HEAP32[$256>>2] = 0;
          $257 = (($__this) + 20|0);
          $258 = HEAP32[$257>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($258|0));
          $259 = __THREW__; __THREW__ = 0;
          $260 = $259&1;
          if ($260) {
           break;
          }
          if ($63) {
           label = 85;
          } else {
           $261 = (($258) + 12|0);
           $262 = HEAP32[$261>>2]|0;
           $263 = ($V_2$0>>>0)<($262>>>0);
           if (!($263)) {
            label = 85;
           }
          }
          if ((label|0) == 85) {
           __THREW__ = 0;
           $264 = (invoke_i(132)|0);
           $265 = __THREW__; __THREW__ = 0;
           $266 = $265&1;
           if ($266) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($264|0));
           $267 = __THREW__; __THREW__ = 0;
           $268 = $267&1;
           if ($268) {
            break;
           }
          }
          $269 = HEAP32[$258>>2]|0;
          $270 = (($258) + 16|0);
          $271 = (($269) + 92|0);
          $272 = HEAP32[$271>>2]|0;
          $273 = Math_imul($272, $V_2$0)|0;
          $274 = (($270) + ($273)|0);
          HEAP32[$274>>2] = 0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $275 = __THREW__; __THREW__ = 0;
          $276 = $275&1;
          if ($276) {
           break;
          }
          $277 = (($__this) + 48|0);
          $278 = HEAP32[$277>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $279 = __THREW__; __THREW__ = 0;
          $280 = $279&1;
          if ($280) {
           break;
          }
          $281 = (($278) + 1)|0;
          HEAP32[$277>>2] = $281;
          $$0 = 1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         else if ((label|0) == 90) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z146mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_TryGetValueP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiPP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $L_0 = 0, $V_1$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885392);
 __THREW__ = 0;
 invoke_v(340);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   HEAP32[$L_0>>2] = $key;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2724,(2155952|0),($L_0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560584|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      $14 = (invoke_ii(3469,(2560584|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      $17 = HEAP32[3021088>>2]|0;
      __THREW__ = 0;
      invoke_vii(1925,($14|0),($17|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3823,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      // unreachable;
     }
     $22 = (($__this) + 40|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      $26 = (invoke_iiii(1662,(1409112|0),($23|0),($key|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = $26 | -2147483648;
       $30 = (($__this) + 8|0);
       $31 = HEAP32[$30>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($31|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        $34 = $26 & 2147483647;
        $35 = (($31) + 12|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = (($34|0) % ($36|0))&-1;
        __THREW__ = 0;
        invoke_vi(3799,($31|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         $40 = HEAP32[$35>>2]|0;
         $41 = ($37>>>0)<($40>>>0);
         if (!($41)) {
          __THREW__ = 0;
          $42 = (invoke_i(132)|0);
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($42|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           break;
          }
         }
         $47 = HEAP32[$31>>2]|0;
         $48 = (($31) + 16|0);
         $49 = (($47) + 92|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = Math_imul($50, $37)|0;
         $52 = (($48) + ($51)|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = ($53|0)==(0);
         if ($54) {
          $$0 = 0;$storemerge = 0;
          HEAP32[$value>>2] = $storemerge;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $55 = (($53) + -1)|0;
         $56 = (($__this) + 12|0);
         $57 = (($__this) + 16|0);
         $V_1$05 = $55;
         while(1) {
          $60 = HEAP32[$56>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($60|0));
          $138 = __THREW__; __THREW__ = 0;
          $139 = $138&1;
          if ($139) {
           label = 5;
           break;
          }
          $58 = ($V_1$05|0)<(0);
          if ($58) {
           label = 24;
          } else {
           $59 = (($60) + 12|0);
           $61 = HEAP32[$59>>2]|0;
           $62 = ($V_1$05>>>0)<($61>>>0);
           if (!($62)) {
            label = 24;
           }
          }
          if ((label|0) == 24) {
           label = 0;
           __THREW__ = 0;
           $63 = (invoke_i(132)|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($63|0));
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            label = 5;
            break;
           }
          }
          $68 = HEAP32[$60>>2]|0;
          $69 = (($60) + 16|0);
          $70 = (($68) + 92|0);
          $71 = HEAP32[$70>>2]|0;
          $72 = Math_imul($71, $V_1$05)|0;
          $73 = (($69) + ($72)|0);
          $74 = HEAP32[$73>>2]|0;
          $75 = ($74|0)==($29|0);
          if ($75) {
           $76 = HEAP32[$22>>2]|0;
           $77 = HEAP32[$57>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($77|0));
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if ($79) {
            label = 5;
            break;
           }
           if ($58) {
            label = 30;
           } else {
            $80 = (($77) + 12|0);
            $81 = HEAP32[$80>>2]|0;
            $82 = ($V_1$05>>>0)<($81>>>0);
            if (!($82)) {
             label = 30;
            }
           }
           if ((label|0) == 30) {
            label = 0;
            __THREW__ = 0;
            $83 = (invoke_i(132)|0);
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if ($85) {
             label = 5;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($83|0));
            $86 = __THREW__; __THREW__ = 0;
            $87 = $86&1;
            if ($87) {
             label = 5;
             break;
            }
           }
           $88 = HEAP32[$77>>2]|0;
           $89 = (($77) + 16|0);
           $90 = (($88) + 92|0);
           $91 = HEAP32[$90>>2]|0;
           $92 = Math_imul($91, $V_1$05)|0;
           $93 = (($89) + ($92)|0);
           $94 = HEAP32[$93>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($76|0));
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if ($96) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           $97 = (invoke_iiiii(306,(1398000|0),($76|0),($94|0),($key|0))|0);
           $98 = __THREW__; __THREW__ = 0;
           $99 = $98&1;
           if ($99) {
            label = 5;
            break;
           }
           if ($97) {
            label = 35;
            break;
           }
          }
          $119 = HEAP32[$56>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($119|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 5;
           break;
          }
          if ($58) {
           label = 44;
          } else {
           $122 = (($119) + 12|0);
           $123 = HEAP32[$122>>2]|0;
           $124 = ($V_1$05>>>0)<($123>>>0);
           if (!($124)) {
            label = 44;
           }
          }
          if ((label|0) == 44) {
           label = 0;
           __THREW__ = 0;
           $125 = (invoke_i(132)|0);
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($125|0));
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            label = 5;
            break;
           }
          }
          $130 = HEAP32[$119>>2]|0;
          $131 = (($119) + 16|0);
          $132 = (($130) + 92|0);
          $133 = HEAP32[$132>>2]|0;
          $134 = Math_imul($133, $V_1$05)|0;
          $$sum = (($134) + 4)|0;
          $135 = (($131) + ($$sum)|0);
          $136 = HEAP32[$135>>2]|0;
          $137 = ($136|0)==(-1);
          if ($137) {
           $$0 = 0;$storemerge = 0;
           label = 48;
           break;
          } else {
           $V_1$05 = $136;
          }
         }
         if ((label|0) == 5) {
          $8 = ___cxa_find_matching_catch()|0;
          $9 = tempRet0;
          $lpad$phi$index = $8;$lpad$phi$index2 = $9;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 35) {
          $100 = (($__this) + 20|0);
          $101 = HEAP32[$100>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($101|0));
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           break;
          }
          if ($58) {
           label = 38;
          } else {
           $104 = (($101) + 12|0);
           $105 = HEAP32[$104>>2]|0;
           $106 = ($V_1$05>>>0)<($105>>>0);
           if (!($106)) {
            label = 38;
           }
          }
          if ((label|0) == 38) {
           __THREW__ = 0;
           $107 = (invoke_i(132)|0);
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($107|0));
           $110 = __THREW__; __THREW__ = 0;
           $111 = $110&1;
           if ($111) {
            break;
           }
          }
          $112 = HEAP32[$101>>2]|0;
          $113 = (($101) + 16|0);
          $114 = (($112) + 92|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = Math_imul($115, $V_1$05)|0;
          $117 = (($113) + ($116)|0);
          $118 = HEAP32[$117>>2]|0;
          $$0 = 1;$storemerge = $118;
          HEAP32[$value>>2] = $storemerge;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         else if ((label|0) == 48) {
          HEAP32[$value>>2] = $storemerge;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z145mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_ValuesP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885440);
 __THREW__ = 0;
 (invoke_ii(2996,(1895368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1895368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1623,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z156mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1893984);
 __THREW__ = 0;
 invoke_v(342);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1924,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = ($dictionary|0)==(0|0);
   if (!($4)) {
    $17 = (($__this) + 8|0);
    HEAP32[$17>>2] = $dictionary;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[3021160>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3823,($9|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPviS6_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z148mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_GetEnumeratorP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1885584);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1627,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z155mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1884624);
 HEAP32[$L_0>>2] = $key;
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2155952|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $agg$result;
   $6 = $5;
   HEAP32[$6>>2] = 0;
   $7 = (($5) + 4)|0;
   $8 = $7;
   HEAP32[$8>>2] = 0;
   __THREW__ = 0;
   invoke_viii(571,($agg$result|0),($2|0),($value|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __ZN14ActionInvoker1I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPFvPv134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPFbPv134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker2I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPF134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePviS5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$1,$3);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1890144,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_E6InvokeEPFPvS3_iS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPFbPviS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$3)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker0I149mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPF143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1897072,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPviS5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$1,$3);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2307216,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z144mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_set_KeyP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachei($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1889624);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z146mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_set_ValueP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1889720);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z145mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ToStringP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $G_B3_0$0 = 0, $G_B6_0$0 = 0, $L_9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $L_9 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1889768);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(341);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1168432|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2750,(1168432|0),5)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $19 = HEAP32[3021312>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($4|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[3021312>>2]|0;
       $23 = (($4) + 16|0);
       HEAP32[$23>>2] = $22;
       __THREW__ = 0;
       $24 = (invoke_ii(1476,($__this|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        HEAP32[$L_9>>2] = $24;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __THREW__ = 0;
         $29 = (invoke_iii(2724,(2155952|0),($L_9|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          $32 = ($29|0)==(0|0);
          if ($32) {
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if ($34) {
            break;
           }
           $53 = HEAP8[((2191608 + 116|0))>>0]|0;
           $54 = ($53<<24>>24)==(0);
           if ($54) {
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $55 = __THREW__; __THREW__ = 0;
            $56 = $55&1;
            if ($56) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if ($58) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3824,(2191608|0));
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            break;
           }
           $63 = HEAP32[((2191608 + 80|0))>>2]|0;
           $64 = HEAP32[$63>>2]|0;
           $G_B3_0$0 = $64;
          } else {
           __THREW__ = 0;
           $35 = (invoke_ii(1476,($__this|0))|0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break;
           }
           HEAP32[$V_0>>2] = $35;
           __THREW__ = 0;
           (invoke_ii(2996,(2155952|0))|0);
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if ($39) {
            break;
           }
           __THREW__ = 0;
           $40 = (invoke_iii(2724,(2155952|0),($V_0|0))|0);
           $41 = __THREW__; __THREW__ = 0;
           $42 = $41&1;
           if ($42) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($40|0));
           $43 = __THREW__; __THREW__ = 0;
           $44 = $43&1;
           if ($44) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2155952|0))|0);
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            break;
           }
           __THREW__ = 0;
           $47 = (invoke_iii(2724,(2155952|0),($V_0|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break;
           }
           __THREW__ = 0;
           $50 = (invoke_iii(2730,(2149112|0),($47|0))|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if ($52) {
            break;
           }
           $G_B3_0$0 = $50;
          }
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if (!($66)) {
           $67 = HEAP32[$9>>2]|0;
           $68 = ($67>>>0)<(2);
           if ($68) {
            __THREW__ = 0;
            $69 = (invoke_i(132)|0);
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if ($71) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($69|0));
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if ($73) {
             break;
            }
           }
           __THREW__ = 0;
           invoke_vii(3492,($4|0),($G_B3_0$0|0));
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if (!($75)) {
            $76 = HEAP32[$4>>2]|0;
            $77 = (($76) + 92|0);
            $78 = HEAP32[$77>>2]|0;
            $79 = (($23) + ($78)|0);
            HEAP32[$79>>2] = $G_B3_0$0;
            __THREW__ = 0;
            invoke_vi(3799,($4|0));
            $80 = __THREW__; __THREW__ = 0;
            $81 = $80&1;
            if (!($81)) {
             $82 = HEAP32[$9>>2]|0;
             $83 = ($82>>>0)<(3);
             if ($83) {
              __THREW__ = 0;
              $84 = (invoke_i(132)|0);
              $85 = __THREW__; __THREW__ = 0;
              $86 = $85&1;
              if ($86) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($84|0));
              $87 = __THREW__; __THREW__ = 0;
              $88 = $87&1;
              if ($88) {
               break;
              }
             }
             $89 = HEAP32[3021320>>2]|0;
             __THREW__ = 0;
             invoke_vii(3492,($4|0),($89|0));
             $90 = __THREW__; __THREW__ = 0;
             $91 = $90&1;
             if (!($91)) {
              $92 = HEAP32[3021320>>2]|0;
              $93 = HEAP32[$4>>2]|0;
              $94 = (($93) + 92|0);
              $95 = HEAP32[$94>>2]|0;
              $96 = $95 << 1;
              $97 = (($23) + ($96)|0);
              HEAP32[$97>>2] = $92;
              __THREW__ = 0;
              $98 = (invoke_ii(1477,($__this|0))|0);
              $99 = __THREW__; __THREW__ = 0;
              $100 = $99&1;
              if (!($100)) {
               $101 = ($98|0)==(0|0);
               if ($101) {
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 break;
                }
                $112 = HEAP8[((2191608 + 116|0))>>0]|0;
                $113 = ($112<<24>>24)==(0);
                if ($113) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $114 = __THREW__; __THREW__ = 0;
                 $115 = $114&1;
                 if ($115) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3824,(2191608|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 break;
                }
                $122 = HEAP32[((2191608 + 80|0))>>2]|0;
                $123 = HEAP32[$122>>2]|0;
                $G_B6_0$0 = $123;
               } else {
                __THREW__ = 0;
                $104 = (invoke_ii(1477,($__this|0))|0);
                $105 = __THREW__; __THREW__ = 0;
                $106 = $105&1;
                if ($106) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($104|0));
                $107 = __THREW__; __THREW__ = 0;
                $108 = $107&1;
                if ($108) {
                 break;
                }
                __THREW__ = 0;
                $109 = (invoke_iii(2730,(2149112|0),($104|0))|0);
                $110 = __THREW__; __THREW__ = 0;
                $111 = $110&1;
                if ($111) {
                 break;
                }
                $G_B6_0$0 = $109;
               }
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $124 = __THREW__; __THREW__ = 0;
               $125 = $124&1;
               if (!($125)) {
                $126 = HEAP32[$9>>2]|0;
                $127 = ($126>>>0)<(4);
                if ($127) {
                 __THREW__ = 0;
                 $128 = (invoke_i(132)|0);
                 $129 = __THREW__; __THREW__ = 0;
                 $130 = $129&1;
                 if ($130) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($128|0));
                 $131 = __THREW__; __THREW__ = 0;
                 $132 = $131&1;
                 if ($132) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($G_B6_0$0|0));
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 break;
                }
                $135 = HEAP32[$4>>2]|0;
                $136 = (($135) + 92|0);
                $137 = HEAP32[$136>>2]|0;
                $138 = ($137*3)|0;
                $139 = (($23) + ($138)|0);
                HEAP32[$139>>2] = $G_B6_0$0;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $140 = __THREW__; __THREW__ = 0;
                $141 = $140&1;
                if ($141) {
                 break;
                }
                $142 = HEAP32[$9>>2]|0;
                $143 = ($142>>>0)<(5);
                if ($143) {
                 __THREW__ = 0;
                 $144 = (invoke_i(132)|0);
                 $145 = __THREW__; __THREW__ = 0;
                 $146 = $145&1;
                 if ($146) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($144|0));
                 $147 = __THREW__; __THREW__ = 0;
                 $148 = $147&1;
                 if ($148) {
                  break;
                 }
                }
                $149 = HEAP32[3021328>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($149|0));
                $150 = __THREW__; __THREW__ = 0;
                $151 = $150&1;
                if ($151) {
                 break;
                }
                $152 = HEAP32[3021328>>2]|0;
                $153 = HEAP32[$4>>2]|0;
                $154 = (($153) + 92|0);
                $155 = HEAP32[$154>>2]|0;
                $156 = $155 << 2;
                $157 = (($23) + ($156)|0);
                HEAP32[$157>>2] = $152;
                __THREW__ = 0;
                $158 = (invoke_iii(639,(0|0),($4|0))|0);
                $159 = __THREW__; __THREW__ = 0;
                $160 = $159&1;
                if ($160) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($158|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __ZL11RuntimeInitP8TypeInfo3330($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z185mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1890288);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z222mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEnumerator_get_CurrentP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1890336);
 __THREW__ = 0;
 invoke_vii(1621,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(1890144|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(1890144|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z191mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1890480);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(1036,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z187mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_DisposeP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1890384);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z188mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1890432);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPF134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1890144,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL140mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1892440)|0);
 $0 = HEAP32[((1892440 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1892440)|0);
 $0 = HEAP32[((1892440 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z209mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894032);
 __THREW__ = 0;
 invoke_v(343);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3823,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z211mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894080);
 __THREW__ = 0;
 invoke_v(344);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021280>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3823,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z214mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894128);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(419,($1|0),($item|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z212mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894176);
 __THREW__ = 0;
 invoke_v(345);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3021296>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3823,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z219mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894224);
 __THREW__ = 0;
 invoke_vii(1625,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1896000|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(1896000|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z164mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_GetEnumeratorP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894464);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1626,($agg$result|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_ICollection_CopyToP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894272);
 __THREW__ = 0;
 (invoke_ii(2996,(1197176|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2735,($_____array|0),(1197176|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if (!($6)) {
     __THREW__ = 0;
     invoke_viiii(461,(1894320|0),($__this|0),($3|0),($index|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $11 = (($__this) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_viii(439,($12|0),($_____array|0),($index|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $17 = HEAP32[$11>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(1897704|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(1897704|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        HEAP32[$0>>2] = 1885056;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_viii(445,($20|0),(0|0),($$byval_copy|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3799,($17|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          __THREW__ = 0;
          invoke_viiii(293,($17|0),($_____array|0),($index|0),($20|0));
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z214mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1897216);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z220mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894368);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z194mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_ICollection_get_SyncRootP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894416);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2740,(2231320|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z157mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_CopyToP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP56UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894320);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viii(439,($2|0),($_____array|0),($index|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = HEAP32[$1>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1897704|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(1897704|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     HEAP32[$0>>2] = 1885056;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_viii(445,($10|0),(0|0),($$byval_copy|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_viiii(295,($7|0),($_____array|0),($index|0),($10|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
}
function __Z167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1895512);
 __THREW__ = 0;
 invoke_vi(3799,($host|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(1617,($L_0|0),($host|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  ;HEAP32[$__this+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$__this+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$__this+16>>2]=HEAP32[$L_0+16>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CountP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1894512);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(1884816|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker0I165mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPF159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1896000,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z204mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEnumerator_get_CurrentP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1895560);
 __THREW__ = 0;
 $0 = (invoke_ii(1493,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z162mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentValueP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896384);
 __THREW__ = 0;
 invoke_vi(1799,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  __THREW__ = 0;
  $3 = (invoke_ii(1477,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z169mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_DisposeP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1895608);
 __THREW__ = 0;
 invoke_vi(1800,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z153mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_DisposeP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896528);
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z170mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1895656);
 __THREW__ = 0;
 $0 = (invoke_ii(1492,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z154mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_22 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_22 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896288);
 __THREW__ = 0;
 invoke_vi(1798,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $99 = $3;
   while(1) {
    $93 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($93|0));
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 4;
     break;
    }
    $96 = (($93) + 24|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($99|0)<($97|0);
    if (!($98)) {
     label = 31;
     break;
    }
    $15 = HEAP32[$2>>2]|0;
    $100 = (($15) + 1)|0;
    HEAP32[$2>>2] = $100;
    $10 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($10|0));
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     label = 4;
     break;
    }
    $9 = (($10) + 12|0);
    $11 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 4;
     break;
    }
    $14 = ($15|0)<(0);
    if ($14) {
     label = 10;
    } else {
     $16 = (($11) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($15>>>0)<($17>>>0);
     if (!($18)) {
      label = 10;
     }
    }
    if ((label|0) == 10) {
     label = 0;
     __THREW__ = 0;
     $19 = (invoke_i(132)|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 4;
      break;
     }
    }
    $24 = HEAP32[$11>>2]|0;
    $25 = (($11) + 16|0);
    $26 = (($24) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $15)|0;
    $29 = (($25) + ($28)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)<(0);
    if ($31) {
     label = 14;
     break;
    }
    $$pre = HEAP32[$2>>2]|0;
    $99 = $$pre;
   }
   if ((label|0) == 4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    $lpad$phi$index = $5;$lpad$phi$index2 = $6;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 14) {
    $32 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($32) + 16|0);
    $36 = HEAP32[$35>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    if ($14) {
     label = 18;
    } else {
     $39 = (($36) + 12|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($15>>>0)<($40>>>0);
     if (!($41)) {
      label = 18;
     }
    }
    if ((label|0) == 18) {
     __THREW__ = 0;
     $42 = (invoke_i(132)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($42|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
    }
    $47 = HEAP32[$36>>2]|0;
    $48 = (($36) + 16|0);
    $49 = (($47) + 92|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = Math_imul($50, $15)|0;
    $52 = (($48) + ($51)|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($54|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     break;
    }
    $57 = (($54) + 20|0);
    $58 = HEAP32[$57>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($58|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    if ($14) {
     label = 24;
    } else {
     $61 = (($58) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = ($15>>>0)<($62>>>0);
     if (!($63)) {
      label = 24;
     }
    }
    if ((label|0) == 24) {
     __THREW__ = 0;
     $64 = (invoke_i(132)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($64|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
    }
    $69 = HEAP32[$58>>2]|0;
    $70 = (($58) + 16|0);
    $71 = (($69) + 92|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = Math_imul($72, $15)|0;
    $74 = (($70) + ($73)|0);
    $75 = HEAP32[$74>>2]|0;
    $76 = $L_22;
    $77 = $76;
    HEAP32[$77>>2] = 0;
    $78 = (($76) + 4)|0;
    $79 = $78;
    HEAP32[$79>>2] = 0;
    __THREW__ = 0;
    invoke_viii(442,($L_22|0),($53|0),($75|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     break;
    }
    $82 = (($__this) + 12|0);
    $83 = $L_22;
    $84 = $83;
    $85 = HEAP32[$84>>2]|0;
    $86 = (($83) + 4)|0;
    $87 = $86;
    $88 = HEAP32[$87>>2]|0;
    $89 = $82;
    $90 = $89;
    HEAP32[$90>>2] = $85;
    $91 = (($89) + 4)|0;
    $92 = $91;
    HEAP32[$92>>2] = $88;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 31) {
    HEAP32[$2>>2] = -1;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1895704);
 $0 = (($__this) + 12|0);
 __THREW__ = 0;
 $1 = (invoke_ii(1477,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z188mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEnumerator_get_CurrentP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896192);
 __THREW__ = 0;
 invoke_vi(1799,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  $3 = $2;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $L_1;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  __THREW__ = 0;
  (invoke_ii(2996,(1890144|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   $15 = (invoke_iii(2724,(1890144|0),($L_1|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z159mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_VerifyCurrentP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896480);
 __THREW__ = 0;
 invoke_v(347);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1798,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = (($__this) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)>(0);
   if ($6) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2607872|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[3021144>>2]|0;
     __THREW__ = 0;
     invoke_vii(1947,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3823,($11|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z196mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IDictionaryEnumerator_get_EntryP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896240);
 __THREW__ = 0;
 invoke_vi(1799,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  __THREW__ = 0;
  $3 = (invoke_ii(1476,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$L_2>>2] = $3;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_ii(1477,($2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = $agg$result;
      $15 = $14;
      HEAP32[$15>>2] = 0;
      $16 = (($14) + 4)|0;
      $17 = $16;
      HEAP32[$17>>2] = 0;
      __THREW__ = 0;
      invoke_viii(571,($agg$result|0),($8|0),($11|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
}
function __Z157mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_VerifyStateP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896432);
 __THREW__ = 0;
 invoke_v(346);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$__this>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2634432|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2634432|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1970,($8|0),(0|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($8|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($2) + 48|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($__this) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if ($21) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     $24 = (invoke_ii(3469,(2607872|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[3021104>>2]|0;
      __THREW__ = 0;
      invoke_vii(1947,($24|0),($27|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vi(3823,($24|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z157mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1896336);
 $0 = (($__this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z215mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_InvokeP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1897264);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_iiii(373,($1|0),($key|0),($value|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiii($8|0,($10|0),($key|0),($value|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z220mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_BeginInvokeP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1897312);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z218mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_EndInvokeP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1897360);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_iS4_S4_P22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$1,$3,$5,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntryiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1897896);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(112,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z211mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntryiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1897944);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z209mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1897992);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z297mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_InvokeP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1898472);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(113,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z302mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_BeginInvokeP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1898520);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z300mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_EndInvokeP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1898568);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraits17VoidPointerTraitsE6InvokeEPF134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1890144,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z158mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP147mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1899048);
 $0 = (($__this) + 8|0);
 __THREW__ = 0;
 $1 = (invoke_ii(1492,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z159mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_EntryP147mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1899096);
 $0 = (($__this) + 8|0);
 ;HEAP32[$L_1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$0+16>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1897072|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2724,(1897072|0),($L_1|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(2114,($agg$result|0),(2311136|0),($3|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z161mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP147mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1899144);
 __THREW__ = 0;
 invoke_viii(2115,($L_0|0),(1899096|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2307216|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2307216|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __ZL115mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP107mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1900640)|0);
 $0 = HEAP32[((1900640 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL158mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEqualityComparer_GetHashCodeP107mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL153mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEqualityComparer_EqualsP107mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL131mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP123mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_GetHashCodeP123mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL132mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_EqualsP123mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntryP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1902144)|0);
 $0 = HEAP32[((1902144 + 84|0))>>2]|0;
 $1 = (__Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_DisposeP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_VerifyStateP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1902144)|0);
 $0 = HEAP32[((1902144 + 84|0))>>2]|0;
 __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_MoveNextP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1902144)|0);
 $0 = HEAP32[((1902144 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_get_CurrentP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_GetEnumeratorP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1902528);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3496,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL110mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctor_mscorlib_System_VoidP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL162mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1906024)|0);
 $0 = HEAP32[((1906024 + 84|0))>>2]|0;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL147mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL121mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_ICollection_CopyToP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_AddP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_ContainsP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL116mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_IndexOfP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_InsertP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_RemoveP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL148mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_ICollection_get_SyncRootP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_get_ItemP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_set_ItemP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_AddP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_GrowIfNeededP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_AddCollectionP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_AddEnumerableP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_AddRangeP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_ClearP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_ContainsP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_CopyToP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP42UnityEngine_UnityEngine_GUILayoutEntry_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I98mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntryTraitsE6InvokeEPF92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntryPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1902144,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_IndexOfP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_ShiftP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_CheckIndexP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_InsertP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryiP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_CheckCollectionP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_RemoveP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_RemoveAtP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_ToArrayP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_CapacityP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_set_CapacityP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_CountP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_ItemP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_set_ItemP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryiP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1907504)|0);
 $0 = HEAP32[((1907504 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1907504)|0);
 $0 = HEAP32[((1907504 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP93mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1908832)|0);
 $0 = HEAP32[((1908832 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL144mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IEqualityComparer_GetHashCodeP93mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL139mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IEqualityComparer_EqualsP93mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1908832)|0);
 $0 = HEAP32[((1908832 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntry_m_GetHashCodeP109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL118mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntry_m_EqualsP109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntryS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1910240);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1910288);
 __THREW__ = 0;
 $0 = (invoke_ii(1512,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2733216|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2733216|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1910432);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1547,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1910336);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1910384);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1912984)|0);
 $0 = HEAP32[((1912984 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1912984)|0);
 $0 = HEAP32[((1912984 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1915248)|0);
 $0 = HEAP32[((1915248 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1915248)|0);
 $0 = HEAP32[((1915248 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1916792);
 __THREW__ = 0;
 $0 = (invoke_ii(3470,($keyValuePair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3471,($keyValuePair|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viiii(460,(1916840|0),($__this|0),($0|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __ZL125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_KeyP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_ValueP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z237mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1916888);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(439,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z136mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ContainsKeyValuePairP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$pair) {
 $__this = $__this|0;
 $pair = $pair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1917080);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(3470,($pair|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiii(299,(1917128|0),($__this|0),($0|0),($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   if (!($3)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_ii(1542,(0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3471,($pair|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP32[$V_0>>2]|0;
      __THREW__ = 0;
      $17 = (invoke_iiiii(299,(1917176|0),($8|0),($11|0),($16|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z235mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$keyValuePair) {
 $__this = $__this|0;
 $keyValuePair = $keyValuePair|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1916936);
 $1 = $keyValuePair;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(439,($__this|0),($tmpcast$byval_copy|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if (!($13)) {
  if (!($11)) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $16 = (invoke_ii(3470,($keyValuePair|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iiii(1640,(1916984|0),($__this|0),($16|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_make_pairP22mscorlib_System_ObjectP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1917032);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(465,($agg$result|0),($key|0),($value|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1921528)|0);
 $0 = HEAP32[((1921528 + 84|0))>>2]|0;
 __Z121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_PPv($__this,$key,$value,$0);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1928936)|0);
 $0 = HEAP32[((1928936 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z129mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_GetEnumeratorP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1917224);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3497,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary);
 STACKTOP = sp;return;
}
function __ZL142mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctor_mscorlib_System_VoidP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL203mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z201mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKey_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$comparer);
 STACKTOP = sp;return;
}
function __ZL164mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylei($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z162mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL159mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_ICollection_get_SyncRootP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL243mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnly_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14ActionInvoker1I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPFvPv115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPFbPv115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZL235mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP102mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CUnityEngine_GUIStyleU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL153mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_ICollection_CopyToP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z151mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL242mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z240mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL160mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IDictionary_GetEnumeratorP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z158mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionary_GetEnumerator_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CountP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_set_ItemP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Item_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_InitP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleiP22mscorlib_System_Object($__this,$capacity,$hcp) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $hcp = $hcp|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Init_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$capacity,$hcp);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_InitArraysP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylei($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitArrays_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti($__this,$size);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_CopyToCheckP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToCheck_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraits17VoidPointerTraitsS1_E6InvokeEPF115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1921528,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_pick_valueP22mscorlib_System_ObjectP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_pick_value_gsharedP22mscorlib_System_ObjectS0_S0_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_CopyToP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP102mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CUnityEngine_GUIStyleU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ResizeP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Resize_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_AddP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Add_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ClearP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Clear_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ContainsValueP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL129mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_GetObjectDataP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetObjectData_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$tmpcast$byval_copy);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_RemoveP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_String($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Remove_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$key)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_TryGetValueP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringPP32UnityEngine_UnityEngine_GUIStyle($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_TryGetValue_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectPS2_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_ValuesP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Values_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker0I130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPF124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1925624,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL136mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1919768)|0);
 $0 = HEAP32[((1919768 + 84|0))>>2]|0;
 __Z134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_U003CCopyToU003Em__0_gsharedP22mscorlib_System_ObjectS0_S0_PPv($agg$result,$__this,$key,$value,$0);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_set_KeyP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_set_ValueP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$value);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ToStringP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1921528)|0);
 $0 = HEAP32[((1921528 + 84|0))>>2]|0;
 $1 = (__Z124mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ToString_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z166mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1921672);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z203mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEnumerator_get_CurrentP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1921720);
 __THREW__ = 0;
 invoke_vii(1658,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(1921528|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(1921528|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z172mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1921864);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(1056,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z168mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_DisposeP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1921768);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z169mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_MoveNextP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1921816);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPF115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1921528,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z145mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_GetEnumeratorP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1923088);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1662,($agg$result|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1924688)|0);
 $0 = HEAP32[((1924688 + 84|0))>>2]|0;
 __Z146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$host,$0);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$dictionary) {
 $__this = $__this|0;
 $dictionary = $dictionary|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$dictionary);
 STACKTOP = sp;return;
}
function __ZL190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Add_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL192mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Clear_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL195mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Contains_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_Remove_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL200mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z198mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumerator_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL169mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_ICollection_CopyToP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL201mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z199mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnly_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL175mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_ICollection_get_SyncRootP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_CopyToP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP36UnityEngine_UnityEngine_GUIStyle_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyTo_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPF140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1924688,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL141mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CountP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Count_gsharedP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL185mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEnumerator_get_CurrentP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1924688)|0);
 $0 = HEAP32[((1924688 + 84|0))>>2]|0;
 $1 = (__Z183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL150mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_DisposeP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1924688)|0);
 $0 = HEAP32[((1924688 + 84|0))>>2]|0;
 __Z148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL151mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_MoveNextP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1924688)|0);
 $0 = HEAP32[((1924688 + 84|0))>>2]|0;
 $1 = (__Z149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL154mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1924688)|0);
 $0 = HEAP32[((1924688 + 84|0))>>2]|0;
 $1 = (__Z152mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1924832);
 $0 = (($__this) + 12|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZL169mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEnumerator_get_CurrentP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1925624)|0);
 $0 = HEAP32[((1925624 + 84|0))>>2]|0;
 $1 = (__Z167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL177mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IDictionaryEnumerator_get_EntryP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1925624)|0);
 $0 = HEAP32[((1925624 + 84|0))>>2]|0;
 __Z175mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionaryEnumerator_get_Entry_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($agg$result,$__this,$0);
 STACKTOP = sp;return;
}
function __ZL135mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_MoveNextP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1925624)|0);
 $0 = HEAP32[((1925624 + 84|0))>>2]|0;
 $1 = (__Z133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentValueP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1925624)|0);
 $0 = HEAP32[((1925624 + 84|0))>>2]|0;
 $1 = (__Z141mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentValue_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_VerifyStateP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyState_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL140mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_VerifyCurrentP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1925624)|0);
 $0 = HEAP32[((1925624 + 84|0))>>2]|0;
 __Z138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyCurrent_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL134mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_DisposeP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Dispose_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL175mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$method>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 __Z163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$$byval_copy);
 STACKTOP = sp;return;
}
function __ZL176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle_m_InvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z164mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Invoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$key,$value)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL181mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle_m_BeginInvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyleP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z169mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_($__this,$key,$value,$callback,$object)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL179mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle_m_EndInvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object($__this,$result)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z186mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1926344);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z187mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1926392);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(116,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z192mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyleP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1926440);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z190mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1926488);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z258mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1926920);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z259mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_InvokeP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle($agg$result,$__this,$key,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1926968);
 $1 = (($__this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(117,($0|0),($2|0),($key|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 }
 $8 = (($__this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($__this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 __THREW__ = 0;
 invoke_viiii($9|0,($agg$result|0),($11|0),($key|0),($value|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z264mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_BeginInvokeP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyleP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$key,$value,$callback,$object) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1927016);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z262mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_EndInvokeP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object($agg$result,$__this,$result) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1927064);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker1I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraits17VoidPointerTraitsE6InvokeEPF115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1921528,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL136mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$host) {
 $__this = $__this|0;
 $host = $host|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z134mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$host);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_MoveNextP128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z137mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_EntryP128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z138mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Entry_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($agg$result,$__this);
 STACKTOP = sp;return;
}
function __ZL142mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Current_gsharedP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m__ctorP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1928936)|0);
 $0 = HEAP32[((1928936 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL138mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEqualityComparer_GetHashCodeP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL133mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEqualityComparer_EqualsP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyle_m__ctorP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyle_m_GetHashCodeP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyle_m_EqualsP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyleS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1930032);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1930080);
 __THREW__ = 0;
 $0 = (invoke_ii(1545,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2746712|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2746712|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1930224);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1562,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1930128);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1930176);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1932296);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1932344);
 __THREW__ = 0;
 $0 = (invoke_ii(1548,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2768456|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2768456|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1932488);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1566,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1932392);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1932440);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1934560);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1934608);
 __THREW__ = 0;
 $0 = (invoke_ii(1551,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2770104|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2770104|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1934752);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1570,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1934656);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1934704);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1936824);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z126mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1936872);
 __THREW__ = 0;
 $0 = (invoke_ii(1554,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2770760|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2770760|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1937016);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3823,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1574,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1936920);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1936968);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1946208)|0);
 $0 = HEAP32[((1946208 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1946208)|0);
 $0 = HEAP32[((1946208 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1948720)|0);
 $0 = HEAP32[((1948720 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1948720)|0);
 $0 = HEAP32[((1948720 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1950984)|0);
 $0 = HEAP32[((1950984 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1950984)|0);
 $0 = HEAP32[((1950984 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ShaderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1953248)|0);
 $0 = HEAP32[((1953248 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1953248)|0);
 $0 = HEAP32[((1953248 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MaterialP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1955512)|0);
 $0 = HEAP32[((1955512 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1955512)|0);
 $0 = HEAP32[((1955512 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_GetEnumeratorP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1957056);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(3496,($agg$result|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL86mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m__ctorP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arrP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this,$l) {
 $__this = $__this|0;
 $l = $l|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this,$l);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m__ctor_mscorlib_System_VoidP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL148mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z124mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$capacity);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1960648)|0);
 $0 = HEAP32[((1960648 + 84|0))>>2]|0;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z139mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumerator_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_ICollection_CopyToP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_AddP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z104mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_ContainsP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_IndexOfP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z108mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_InsertP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arriP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_RemoveP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL134mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z140mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnly_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_ICollection_get_SyncRootP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z119mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRoot_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_get_ItemP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_set_ItemP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arriP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_AddP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Add_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_GrowIfNeededP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri($__this,$newCount) {
 $__this = $__this|0;
 $newCount = $newCount|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeeded_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$newCount);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_AddCollectionP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_AddEnumerableP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$enumerable) {
 $__this = $__this|0;
 $enumerable = $enumerable|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z89mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerable_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$enumerable);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_AddRangeP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_ClearP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Clear_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_ContainsP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Contains_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_CopyToP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP34mscorlib_System_ByteU005BU005D_arri($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyTo_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri($__this,$_____array,$arrayIndex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I84mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arrTraitsE6InvokeEPF78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arrPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(1963712,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_IndexOfP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOf_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_ShiftP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrii($__this,$start,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $delta = $delta|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Shift_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii($__this,$start,$delta);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_CheckIndexP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z86mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndex_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_InsertP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arriP24mscorlib_System_Byte_arr($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Insert_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_CheckCollectionP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$collection) {
 $__this = $__this|0;
 $collection = $collection|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z91mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollection_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$collection);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_RemoveP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_Remove_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_RemoveAtP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAt_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index);
 STACKTOP = sp;return;
}
function __ZL77mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_ToArrayP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_get_CapacityP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_set_CapacityP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Capacity_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$value);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_get_CountP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Count_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_get_ItemP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_set_ItemP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arriP24mscorlib_System_Byte_arr($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_Item_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object($__this,$index,$value);
 STACKTOP = sp;return;
}
function __ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m__ctorP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arrP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m_System_Collections_IEnumerator_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1962368)|0);
 $0 = HEAP32[((1962368 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m_DisposeP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m_MoveNextP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1962368)|0);
 $0 = HEAP32[((1962368 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL123mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_System_Collections_IEnumerator_get_CurrentP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1963712)|0);
 $0 = HEAP32[((1963712 + 84|0))>>2]|0;
 $1 = (__Z129mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_DisposeP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z94mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_Dispose_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_VerifyStateP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1963712)|0);
 $0 = HEAP32[((1963712 + 84|0))>>2]|0;
 __Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyState_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_MoveNextP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1963712)|0);
 $0 = HEAP32[((1963712 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_get_CurrentP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m__ctorP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctor_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1964680)|0);
 $0 = HEAP32[((1964680 + 84|0))>>2]|0;
 __Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctor_gsharedP22mscorlib_System_ObjectPPv($__this,$0);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m_System_Collections_IEqualityComparer_GetHashCodeP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arrP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCode_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m_System_Collections_IEqualityComparer_EqualsP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arrP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_Equals_gsharedP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1964680)|0);
 $0 = HEAP32[((1964680 + 84|0))>>2]|0;
 $1 = (__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arr_m__ctorP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arr($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctor_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arr_m_GetHashCodeP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCode_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object($__this,$obj)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arr_m_EqualsP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arrS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_Equals_gsharedP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_($__this,$x,$y)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m__ctorP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ByteP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1966152);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m_System_Collections_IEnumerator_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1966200);
 __THREW__ = 0;
 $0 = (invoke_ii(1585,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP8[$L_1>>0] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2169424|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2169424|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1966344);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1602,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m_DisposeP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1966248);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m_MoveNextP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1966296);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3541($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1968896)|0);
 $0 = HEAP32[((1968896 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1968896)|0);
 $0 = HEAP32[((1968896 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisplayP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1971160)|0);
 $0 = HEAP32[((1971160 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1971160)|0);
 $0 = HEAP32[((1971160 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtrP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1972944);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1972992);
 __THREW__ = 0;
 $0 = (invoke_ii(1594,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2210080|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2210080|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1973136);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1614,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1973040);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1973088);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I28mscorlib_System_IntPtrTraitsE6InvokeEPF22mscorlib_System_IntPtrPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP32[$ret>>2] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2210080,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TransformP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1975688)|0);
 $0 = HEAP32[((1975688 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1975688)|0);
 $0 = HEAP32[((1975688 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MotionP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1977952)|0);
 $0 = HEAP32[((1977952 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1977952)|0);
 $0 = HEAP32[((1977952 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1980216)|0);
 $0 = HEAP32[((1980216 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1980216)|0);
 $0 = HEAP32[((1980216 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ColliderP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1982480)|0);
 $0 = HEAP32[((1982480 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1982480)|0);
 $0 = HEAP32[((1982480 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1984264);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z126mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1984312);
 __THREW__ = 0;
 $0 = (invoke_ii(1609,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2836688|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2836688|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1984456);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1634,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1984360);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1984408);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1987008)|0);
 $0 = HEAP32[((1987008 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1987008)|0);
 $0 = HEAP32[((1987008 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SingleP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1988792);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1988840);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fi(129,($__this|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAPF32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2194912|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2194912|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1988984);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (Math_fround(+(invoke_fii(43,($26|0),($36|0)))));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return (Math_fround($37));
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return Math_fround(0);
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1988888);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1988936);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1991056);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1991104);
 __THREW__ = 0;
 $0 = (invoke_ii(1617,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2841288|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2841288|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1991248);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1642,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1991152);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1991200);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1993320);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1993368);
 __THREW__ = 0;
 $0 = (invoke_ii(1620,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2841760|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2841760|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1993512);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3825,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1646,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1993416);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,1993464);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2002120)|0);
 $0 = HEAP32[((2002120 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2002120)|0);
 $0 = HEAP32[((2002120 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2004104);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2004152);
 __THREW__ = 0;
 $0 = (invoke_ii(1626,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2846200|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2846200|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2004296);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1654,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2004200);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2004248);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3698($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2006848)|0);
 $0 = HEAP32[((2006848 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2006848)|0);
 $0 = HEAP32[((2006848 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TerrainP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2009112)|0);
 $0 = HEAP32[((2009112 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2009112)|0);
 $0 = HEAP32[((2009112 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2010896);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2010944);
 __THREW__ = 0;
 $0 = (invoke_ii(1635,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2853288|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2853288|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2011088);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1666,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2010992);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2011040);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2013160);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2013208);
 __THREW__ = 0;
 $0 = (invoke_ii(1638,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2853712|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2853712|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2013352);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1670,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2013256);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2013304);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2015424);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2015472);
 __THREW__ = 0;
 $0 = (invoke_ii(1641,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2854128|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2854128|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2015616);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1674,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2015520);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2015568);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL79mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m__ctorP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m_System_Collections_IEnumerator_get_CurrentP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2018168)|0);
 $0 = HEAP32[((2018168 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m_DisposeP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m_MoveNextP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m_get_CurrentP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2018168)|0);
 $0 = HEAP32[((2018168 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CanvasP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2020432)|0);
 $0 = HEAP32[((2020432 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2020432)|0);
 $0 = HEAP32[((2020432 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL150mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2022696)|0);
 $0 = HEAP32[((2022696 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2022696)|0);
 $0 = HEAP32[((2022696 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m__ctorP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m_System_Collections_IEnumerator_get_CurrentP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2024960)|0);
 $0 = HEAP32[((2024960 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m_DisposeP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m_MoveNextP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m_get_CurrentP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2024960)|0);
 $0 = HEAP32[((2024960 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m__ctorP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m_System_Collections_IEnumerator_get_CurrentP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2027224)|0);
 $0 = HEAP32[((2027224 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m_DisposeP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m_MoveNextP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m_get_CurrentP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2027224)|0);
 $0 = HEAP32[((2027224 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2029760)|0);
 $0 = HEAP32[((2029760 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2029760)|0);
 $0 = HEAP32[((2029760 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2032024)|0);
 $0 = HEAP32[((2032024 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2032024)|0);
 $0 = HEAP32[((2032024 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2034288)|0);
 $0 = HEAP32[((2034288 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2034288)|0);
 $0 = HEAP32[((2034288 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z72mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m__ctorP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64P21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2036072);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m_System_Collections_IEnumerator_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2036120);
 __THREW__ = 0;
 $0 = (invoke_ii(1668,($__this|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = $L_1;
  $5 = $4;
  HEAP32[$5>>2] = $0;
  $6 = (($4) + 4)|0;
  $7 = $6;
  HEAP32[$7>>2] = $1;
  __THREW__ = 0;
  (invoke_ii(2996,(2162248|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_iii(2724,(2162248|0),($L_1|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($10|0);
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2036264);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1710,($26|0),($36|0))|0);
    $38 = tempRet0;
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $38;
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m_DisposeP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2036168);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m_MoveNextP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2036216);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I27mscorlib_System_Int64TraitsE6InvokeEPFxPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 $1 = tempRet0;
 $2 = $ret;
 $3 = $2;
 HEAP32[$3>>2] = $0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = $1;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32P21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2038824);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2038872);
 __THREW__ = 0;
 $0 = (invoke_ii(1671,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2164560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2164560|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2039016);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1711,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2038920);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2038968);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I28mscorlib_System_UInt32TraitsE6InvokeEPFjPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP32[$ret>>2] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2042032)|0);
 $0 = HEAP32[((2042032 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2042032)|0);
 $0 = HEAP32[((2042032 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64P21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2043816);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2043864);
 __THREW__ = 0;
 $0 = (invoke_ii(1677,($__this|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = $L_1;
  $5 = $4;
  HEAP32[$5>>2] = $0;
  $6 = (($4) + 4)|0;
  $7 = $6;
  HEAP32[$7>>2] = $1;
  __THREW__ = 0;
  (invoke_ii(2996,(2167208|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_iii(2724,(2167208|0),($L_1|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($10|0);
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2044008);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3826,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1719,($26|0),($36|0))|0);
    $38 = tempRet0;
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $38;
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2043912);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2043960);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I28mscorlib_System_UInt64TraitsE6InvokeEPFyPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 $1 = tempRet0;
 $2 = $ret;
 $3 = $2;
 HEAP32[$3>>2] = $0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = $1;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z72mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m__ctorP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByteP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2052536);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m_System_Collections_IEnumerator_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2052584);
 __THREW__ = 0;
 $0 = (invoke_ii(1680,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP8[$L_1>>0] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2171616|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2171616|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2052728);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1720,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m_DisposeP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2052632);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m_MoveNextP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2052680);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3830($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I27mscorlib_System_SByteTraitsE6InvokeEPFaPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP8[$ret>>0] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z72mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m__ctorP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16P21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2055592);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m_System_Collections_IEnumerator_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2055640);
 __THREW__ = 0;
 $0 = (invoke_ii(1683,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP16[$L_1>>1] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2173776|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2173776|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2055784);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1724,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m_DisposeP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2055688);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m_MoveNextP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2055736);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I27mscorlib_System_Int16TraitsE6InvokeEPFsPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP16[$ret>>1] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16P21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2058320);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2058368);
 __THREW__ = 0;
 $0 = (invoke_ii(1686,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP16[$L_1>>1] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2176024|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2176024|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2058512);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1728,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2058416);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2058464);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I28mscorlib_System_UInt16TraitsE6InvokeEPFtPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP16[$ret>>1] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DoubleP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2062208);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double($__this) {
 $__this = $__this|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2062256);
 __THREW__ = 0;
 $0 = (+invoke_di(1,($__this|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAPF64[$L_1>>3] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2198192|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2198192|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2062400);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (+invoke_dii(28,($26|0),($36|0)));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return (+$37);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return +0;
}
function __Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2062304);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2062352);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I28mscorlib_System_DoubleTraitsE6InvokeEPFdPvES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0.0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (+FUNCTION_TABLE_di[$func & 15]($obj));
 HEAPF64[$ret>>3] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m__ctorP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_BooleanP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2065400);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m_System_Collections_IEnumerator_get_CurrentP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2065448);
 __THREW__ = 0;
 $0 = (invoke_ii(1691,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $0&1;
  HEAP8[$L_1>>0] = $3;
  __THREW__ = 0;
  (invoke_ii(2996,(2208584|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2724,(2208584|0),($L_1|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m_get_CurrentP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2065592);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1732,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m_DisposeP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2065496);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m_MoveNextP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2065544);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m__ctorP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtrP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2068128);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m_System_Collections_IEnumerator_get_CurrentP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2068176);
 __THREW__ = 0;
 $0 = (invoke_ii(1694,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2212032|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2212032|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m_get_CurrentP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2068320);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3827,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1736,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m_DisposeP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2068224);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m_MoveNextP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2068272);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I29mscorlib_System_UIntPtrTraitsE6InvokeEPF23mscorlib_System_UIntPtrPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP32[$ret>>2] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2212032,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m__ctorP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DelegateP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m_System_Collections_IEnumerator_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2070872)|0);
 $0 = HEAP32[((2070872 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m_DisposeP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m_MoveNextP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2070872)|0);
 $0 = HEAP32[((2070872 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32_m__ctorP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2072680);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z78mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2072728);
 __THREW__ = 0;
 (invoke_ii(2996,(2073680|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2073680|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1887,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2073256|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2073256 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt32_m__ctorP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2073400);
 __THREW__ = 0;
 invoke_vi(1885,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z108mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32_m_System_Collections_IComparer_CompareP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32P22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2072776);
 $0 = ($x|0)==(0|0);
 $1 = ($y|0)!=(0|0);
 if ($0) {
  $$ = $1 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($1)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2164560|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($x|0),(2164560|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if (!($7)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2164560|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(2735,($y|0),(2164560|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = ($12|0)==(0|0);
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      $18 = (invoke_iii(2751,($x|0),(2164560|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP32[$18>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      $24 = (invoke_iii(2751,($y|0),(2164560|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      $27 = HEAP32[$24>>2]|0;
      __THREW__ = 0;
      $28 = (invoke_iiiii(311,(2072824|0),($__this|0),($21|0),($27|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      } else {
       $$0 = $28;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     __THREW__ = 0;
     $33 = (invoke_ii(3469,(2560072|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(2583,($33|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       __THREW__ = 0;
       invoke_vi(3827,($33|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo3831($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsS1_E6InvokeEP10MethodInfoPvjj($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z83mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2072872);
 __THREW__ = 0;
 (invoke_ii(2996,(2073256|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2073256 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2073256|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2073256|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3828,(2073256|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2073256|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2073256 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZL11RuntimeInitP8TypeInfo3832($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt32_m_CompareP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt32jj($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $L_0 = 0, $L_12 = 0, $L_16 = 0, $L_19 = 0, $L_2 = 0, $L_22 = 0, $L_6 = 0, $L_9 = 0, $_stackTraceSentry = 0, $not$ = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp + 28|0;
 $L_2 = sp + 24|0;
 $L_6 = sp + 20|0;
 $L_9 = sp + 16|0;
 $L_12 = sp + 8|0;
 $L_16 = sp + 4|0;
 $L_19 = sp;
 $L_22 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2073448);
 __THREW__ = 0;
 invoke_v(353);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   HEAP32[$L_0>>2] = $x;
   __THREW__ = 0;
   (invoke_ii(2996,(2164560|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2724,(2164560|0),($L_0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      HEAP32[$L_2>>2] = $y;
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break;
      }
      __THREW__ = 0;
      $12 = (invoke_iii(2724,(2164560|0),($L_2|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      $not$ = ($12|0)!=(0|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$L_6>>2] = $y;
     __THREW__ = 0;
     (invoke_ii(2996,(2164560|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iii(2724,(2164560|0),($L_6|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = ($17|0)==(0|0);
       if ($20) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       HEAP32[$L_9>>2] = $x;
       __THREW__ = 0;
       (invoke_ii(2996,(2164560|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        $23 = (invoke_iii(2724,(2164560|0),($L_9|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2040936|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_iii(2735,($23|0),(2040936|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           $31 = ($28|0)==(0|0);
           if (!($31)) {
            HEAP32[$L_12>>2] = $x;
            __THREW__ = 0;
            (invoke_ii(2996,(2164560|0))|0);
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if ($33) {
             break;
            }
            __THREW__ = 0;
            $34 = (invoke_iii(2724,(2164560|0),($L_12|0))|0);
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2040936|0))|0);
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if ($38) {
             break;
            }
            __THREW__ = 0;
            $39 = (invoke_iii(2752,($34|0),(2040936|0))|0);
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($39|0));
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if ($43) {
             break;
            }
            __THREW__ = 0;
            $44 = (invoke_iiii(1663,(2040864|0),($39|0),($y|0))|0);
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             break;
            } else {
             $$0 = $44;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           HEAP32[$L_16>>2] = $x;
           __THREW__ = 0;
           (invoke_ii(2996,(2164560|0))|0);
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if (!($48)) {
            __THREW__ = 0;
            $49 = (invoke_iii(2724,(2164560|0),($L_16|0))|0);
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if (!($51)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2157896|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2735,($49|0),(2157896|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               $57 = ($54|0)==(0|0);
               if ($57) {
                __THREW__ = 0;
                (invoke_ii(2996,(2560072|0))|0);
                $78 = __THREW__; __THREW__ = 0;
                $79 = $78&1;
                if ($79) {
                 break;
                }
                __THREW__ = 0;
                $80 = (invoke_ii(3469,(2560072|0))|0);
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if ($82) {
                 break;
                }
                $83 = HEAP32[3020480>>2]|0;
                __THREW__ = 0;
                invoke_vii(1924,($80|0),($83|0));
                $84 = __THREW__; __THREW__ = 0;
                $85 = $84&1;
                if ($85) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3827,($80|0));
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 break;
                }
                // unreachable;
               }
               HEAP32[$L_19>>2] = $x;
               __THREW__ = 0;
               (invoke_ii(2996,(2164560|0))|0);
               $58 = __THREW__; __THREW__ = 0;
               $59 = $58&1;
               if (!($59)) {
                __THREW__ = 0;
                $60 = (invoke_iii(2724,(2164560|0),($L_19|0))|0);
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if (!($62)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2157896|0))|0);
                 $63 = __THREW__; __THREW__ = 0;
                 $64 = $63&1;
                 if ($64) {
                  break;
                 }
                 __THREW__ = 0;
                 $65 = (invoke_iii(2752,($60|0),(2157896|0))|0);
                 $66 = __THREW__; __THREW__ = 0;
                 $67 = $66&1;
                 if ($67) {
                  break;
                 }
                 HEAP32[$L_22>>2] = $y;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2164560|0))|0);
                 $68 = __THREW__; __THREW__ = 0;
                 $69 = $68&1;
                 if ($69) {
                  break;
                 }
                 __THREW__ = 0;
                 $70 = (invoke_iii(2724,(2164560|0),($L_22|0))|0);
                 $71 = __THREW__; __THREW__ = 0;
                 $72 = $71&1;
                 if ($72) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($65|0));
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if ($74) {
                  break;
                 }
                 __THREW__ = 0;
                 $75 = (invoke_iiii(1649,(2157808|0),($65|0),($70|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 } else {
                  $$0 = $75;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo3833($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsE6InvokeEP10MethodInfoPvj($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsS1_E6InvokeEPFiPvjjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16_m__ctorP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2074064);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z78mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2074112);
 __THREW__ = 0;
 (invoke_ii(2996,(2074952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2074952|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1890,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2074544|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2074544 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt16_m__ctorP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt16($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2074688);
 __THREW__ = 0;
 invoke_vi(1888,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z108mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16_m_System_Collections_IComparer_CompareP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16P22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2074160);
 $0 = ($x|0)==(0|0);
 $1 = ($y|0)!=(0|0);
 if ($0) {
  $$ = $1 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($1)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2176024|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($x|0),(2176024|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if (!($7)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2176024|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(2735,($y|0),(2176024|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = ($12|0)==(0|0);
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      $18 = (invoke_iii(2751,($x|0),(2176024|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP16[$18>>1]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      $24 = (invoke_iii(2751,($y|0),(2176024|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      $27 = HEAP16[$24>>1]|0;
      __THREW__ = 0;
      $28 = (invoke_iiiii(312,(2074208|0),($__this|0),($21|0),($27|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      } else {
       $$0 = $28;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     __THREW__ = 0;
     $33 = (invoke_ii(3469,(2560072|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(2583,($33|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       __THREW__ = 0;
       invoke_vi(3827,($33|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsS1_E6InvokeEP10MethodInfoPvtt($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z83mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2074256);
 __THREW__ = 0;
 (invoke_ii(2996,(2074544|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2074544 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2074544|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2074544|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3828,(2074544|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2074544|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2074544 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt16_m_CompareP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt16tt($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $L_0 = 0, $L_12 = 0, $L_16 = 0, $L_19 = 0, $L_2 = 0, $L_22 = 0, $L_6 = 0, $L_9 = 0, $_stackTraceSentry = 0, $not$ = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 16|0;
 $L_2 = sp + 14|0;
 $L_6 = sp + 12|0;
 $L_9 = sp + 18|0;
 $L_12 = sp + 6|0;
 $L_16 = sp + 4|0;
 $L_19 = sp + 8|0;
 $L_22 = sp + 10|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2074736);
 __THREW__ = 0;
 invoke_v(353);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   HEAP16[$L_0>>1] = $x;
   __THREW__ = 0;
   (invoke_ii(2996,(2176024|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2724,(2176024|0),($L_0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      HEAP16[$L_2>>1] = $y;
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break;
      }
      __THREW__ = 0;
      $12 = (invoke_iii(2724,(2176024|0),($L_2|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      $not$ = ($12|0)!=(0|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     HEAP16[$L_6>>1] = $y;
     __THREW__ = 0;
     (invoke_ii(2996,(2176024|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iii(2724,(2176024|0),($L_6|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = ($17|0)==(0|0);
       if ($20) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       HEAP16[$L_9>>1] = $x;
       __THREW__ = 0;
       (invoke_ii(2996,(2176024|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        $23 = (invoke_iii(2724,(2176024|0),($L_9|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2060432|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_iii(2735,($23|0),(2060432|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           $31 = ($28|0)==(0|0);
           if (!($31)) {
            HEAP16[$L_12>>1] = $x;
            __THREW__ = 0;
            (invoke_ii(2996,(2176024|0))|0);
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if ($33) {
             break;
            }
            __THREW__ = 0;
            $34 = (invoke_iii(2724,(2176024|0),($L_12|0))|0);
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2060432|0))|0);
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if ($38) {
             break;
            }
            __THREW__ = 0;
            $39 = (invoke_iii(2752,($34|0),(2060432|0))|0);
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($39|0));
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if ($43) {
             break;
            }
            __THREW__ = 0;
            $44 = (invoke_iiii(1664,(2060360|0),($39|0),($y|0))|0);
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             break;
            } else {
             $$0 = $44;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           HEAP16[$L_16>>1] = $x;
           __THREW__ = 0;
           (invoke_ii(2996,(2176024|0))|0);
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if (!($48)) {
            __THREW__ = 0;
            $49 = (invoke_iii(2724,(2176024|0),($L_16|0))|0);
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if (!($51)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2157896|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2735,($49|0),(2157896|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               $57 = ($54|0)==(0|0);
               if ($57) {
                __THREW__ = 0;
                (invoke_ii(2996,(2560072|0))|0);
                $78 = __THREW__; __THREW__ = 0;
                $79 = $78&1;
                if ($79) {
                 break;
                }
                __THREW__ = 0;
                $80 = (invoke_ii(3469,(2560072|0))|0);
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if ($82) {
                 break;
                }
                $83 = HEAP32[3020480>>2]|0;
                __THREW__ = 0;
                invoke_vii(1924,($80|0),($83|0));
                $84 = __THREW__; __THREW__ = 0;
                $85 = $84&1;
                if ($85) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3827,($80|0));
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 break;
                }
                // unreachable;
               }
               HEAP16[$L_19>>1] = $x;
               __THREW__ = 0;
               (invoke_ii(2996,(2176024|0))|0);
               $58 = __THREW__; __THREW__ = 0;
               $59 = $58&1;
               if (!($59)) {
                __THREW__ = 0;
                $60 = (invoke_iii(2724,(2176024|0),($L_19|0))|0);
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if (!($62)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2157896|0))|0);
                 $63 = __THREW__; __THREW__ = 0;
                 $64 = $63&1;
                 if ($64) {
                  break;
                 }
                 __THREW__ = 0;
                 $65 = (invoke_iii(2752,($60|0),(2157896|0))|0);
                 $66 = __THREW__; __THREW__ = 0;
                 $67 = $66&1;
                 if ($67) {
                  break;
                 }
                 HEAP16[$L_22>>1] = $y;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2176024|0))|0);
                 $68 = __THREW__; __THREW__ = 0;
                 $69 = $68&1;
                 if ($69) {
                  break;
                 }
                 __THREW__ = 0;
                 $70 = (invoke_iii(2724,(2176024|0),($L_22|0))|0);
                 $71 = __THREW__; __THREW__ = 0;
                 $72 = $71&1;
                 if ($72) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($65|0));
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if ($74) {
                  break;
                 }
                 __THREW__ = 0;
                 $75 = (invoke_iiii(1649,(2157808|0),($65|0),($70|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 } else {
                  $$0 = $75;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsE6InvokeEP10MethodInfoPvt($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsS1_E6InvokeEPFiPvttES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z75mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte_m__ctorP67mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2075336);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z76mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2075384);
 __THREW__ = 0;
 (invoke_ii(2996,(2076224|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2076224|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1893,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2075816|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2075816 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z91mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Byte_m__ctorP83mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Byte($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2075960);
 __THREW__ = 0;
 invoke_vi(1891,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z106mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte_m_System_Collections_IComparer_CompareP67mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_ByteP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2075432);
 $0 = ($x|0)==(0|0);
 $1 = ($y|0)!=(0|0);
 if ($0) {
  $$ = $1 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($1)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2169424|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($x|0),(2169424|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if (!($7)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2169424|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(2735,($y|0),(2169424|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = ($12|0)==(0|0);
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      $18 = (invoke_iii(2751,($x|0),(2169424|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP8[$18>>0]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      $24 = (invoke_iii(2751,($y|0),(2169424|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      $27 = HEAP8[$24>>0]|0;
      __THREW__ = 0;
      $28 = (invoke_iiiii(313,(2075480|0),($__this|0),($21|0),($27|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      } else {
       $$0 = $28;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     __THREW__ = 0;
     $33 = (invoke_ii(3469,(2560072|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(2583,($33|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       __THREW__ = 0;
       invoke_vi(3827,($33|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsS1_E6InvokeEP10MethodInfoPvhh($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z81mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2075528);
 __THREW__ = 0;
 (invoke_ii(2996,(2075816|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2075816 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2075816|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2075816|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3828,(2075816|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2075816|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2075816 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Byte_m_CompareP83mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Bytehh($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $L_0 = 0, $L_12 = 0, $L_16 = 0, $L_19 = 0, $L_2 = 0, $L_22 = 0, $L_6 = 0, $L_9 = 0, $_stackTraceSentry = 0, $not$ = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 10|0;
 $L_2 = sp + 9|0;
 $L_6 = sp + 8|0;
 $L_9 = sp + 11|0;
 $L_12 = sp + 5|0;
 $L_16 = sp + 4|0;
 $L_19 = sp + 6|0;
 $L_22 = sp + 7|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2076008);
 __THREW__ = 0;
 invoke_v(353);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   HEAP8[$L_0>>0] = $x;
   __THREW__ = 0;
   (invoke_ii(2996,(2169424|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2724,(2169424|0),($L_0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($4|0)==(0|0);
     if ($7) {
      HEAP8[$L_2>>0] = $y;
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break;
      }
      __THREW__ = 0;
      $12 = (invoke_iii(2724,(2169424|0),($L_2|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      $not$ = ($12|0)!=(0|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     HEAP8[$L_6>>0] = $y;
     __THREW__ = 0;
     (invoke_ii(2996,(2169424|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iii(2724,(2169424|0),($L_6|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = ($17|0)==(0|0);
       if ($20) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       HEAP8[$L_9>>0] = $x;
       __THREW__ = 0;
       (invoke_ii(2996,(2169424|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        $23 = (invoke_iii(2724,(2169424|0),($L_9|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2051856|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_iii(2735,($23|0),(2051856|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           $31 = ($28|0)==(0|0);
           if (!($31)) {
            HEAP8[$L_12>>0] = $x;
            __THREW__ = 0;
            (invoke_ii(2996,(2169424|0))|0);
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if ($33) {
             break;
            }
            __THREW__ = 0;
            $34 = (invoke_iii(2724,(2169424|0),($L_12|0))|0);
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2051856|0))|0);
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if ($38) {
             break;
            }
            __THREW__ = 0;
            $39 = (invoke_iii(2752,($34|0),(2051856|0))|0);
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($39|0));
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if ($43) {
             break;
            }
            __THREW__ = 0;
            $44 = (invoke_iiii(1665,(2051784|0),($39|0),($y|0))|0);
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             break;
            } else {
             $$0 = $44;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           HEAP8[$L_16>>0] = $x;
           __THREW__ = 0;
           (invoke_ii(2996,(2169424|0))|0);
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if (!($48)) {
            __THREW__ = 0;
            $49 = (invoke_iii(2724,(2169424|0),($L_16|0))|0);
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if (!($51)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2157896|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2735,($49|0),(2157896|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               $57 = ($54|0)==(0|0);
               if ($57) {
                __THREW__ = 0;
                (invoke_ii(2996,(2560072|0))|0);
                $78 = __THREW__; __THREW__ = 0;
                $79 = $78&1;
                if ($79) {
                 break;
                }
                __THREW__ = 0;
                $80 = (invoke_ii(3469,(2560072|0))|0);
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if ($82) {
                 break;
                }
                $83 = HEAP32[3020480>>2]|0;
                __THREW__ = 0;
                invoke_vii(1924,($80|0),($83|0));
                $84 = __THREW__; __THREW__ = 0;
                $85 = $84&1;
                if ($85) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3827,($80|0));
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 break;
                }
                // unreachable;
               }
               HEAP8[$L_19>>0] = $x;
               __THREW__ = 0;
               (invoke_ii(2996,(2169424|0))|0);
               $58 = __THREW__; __THREW__ = 0;
               $59 = $58&1;
               if (!($59)) {
                __THREW__ = 0;
                $60 = (invoke_iii(2724,(2169424|0),($L_19|0))|0);
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if (!($62)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2157896|0))|0);
                 $63 = __THREW__; __THREW__ = 0;
                 $64 = $63&1;
                 if ($64) {
                  break;
                 }
                 __THREW__ = 0;
                 $65 = (invoke_iii(2752,($60|0),(2157896|0))|0);
                 $66 = __THREW__; __THREW__ = 0;
                 $67 = $66&1;
                 if ($67) {
                  break;
                 }
                 HEAP8[$L_22>>0] = $y;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2169424|0))|0);
                 $68 = __THREW__; __THREW__ = 0;
                 $69 = $68&1;
                 if ($69) {
                  break;
                 }
                 __THREW__ = 0;
                 $70 = (invoke_iii(2724,(2169424|0),($L_22|0))|0);
                 $71 = __THREW__; __THREW__ = 0;
                 $72 = $71&1;
                 if ($72) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($65|0));
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if ($74) {
                  break;
                 }
                 __THREW__ = 0;
                 $75 = (invoke_iiii(1649,(2157808|0),($65|0),($70|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 } else {
                  $$0 = $75;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsE6InvokeEP10MethodInfoPvh($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsS1_E6InvokeEPFiPvhhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64_m__ctorP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2076608);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z78mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2076656);
 __THREW__ = 0;
 (invoke_ii(2996,(2077496|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2077496|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1896,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2077088|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2077088 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt64_m__ctorP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt64($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2077232);
 __THREW__ = 0;
 invoke_vi(1894,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z108mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64_m_System_Collections_IComparer_CompareP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64P22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2076704);
 $0 = ($x|0)==(0|0);
 $1 = ($y|0)!=(0|0);
 if ($0) {
  $$ = $1 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($1)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2167208|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($x|0),(2167208|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if (!($7)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2167208|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(2735,($y|0),(2167208|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = ($12|0)==(0|0);
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      $18 = (invoke_iii(2751,($x|0),(2167208|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = $18;
      $22 = $21;
      $23 = HEAP32[$22>>2]|0;
      $24 = (($21) + 4)|0;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2751,($y|0),(2167208|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = $29;
      $33 = $32;
      $34 = HEAP32[$33>>2]|0;
      $35 = (($32) + 4)|0;
      $36 = $35;
      $37 = HEAP32[$36>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_iiiiiii(128,(2076752|0),($__this|0),($23|0),($26|0),($34|0),($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      } else {
       $$0 = $38;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     __THREW__ = 0;
     $43 = (invoke_ii(3469,(2560072|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      __THREW__ = 0;
      invoke_vi(2583,($43|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       invoke_vi(3827,($43|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsS1_E6InvokeEP10MethodInfoPvyy($method,$obj,$0,$1,$2,$3) {
 $method = $method|0;
 $obj = $obj|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $4 = (($data) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$data>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$7 & 255]($8,$0,$1,$2,$3)|0);
 STACKTOP = sp;return ($9|0);
}
function __Z83mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2076800);
 __THREW__ = 0;
 (invoke_ii(2996,(2077088|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2077088 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2077088|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2077088|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3828,(2077088|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2077088|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2077088 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt64_m_CompareP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt64yy($__this,$0,$1,$2,$3) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $L_0 = 0, $L_12 = 0, $L_16 = 0, $L_19 = 0, $L_2 = 0, $L_22 = 0, $L_6 = 0, $L_9 = 0, $_stackTraceSentry = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $_stackTraceSentry = sp + 64|0;
 $L_0 = sp + 56|0;
 $L_2 = sp + 48|0;
 $L_6 = sp + 40|0;
 $L_9 = sp + 32|0;
 $L_12 = sp + 16|0;
 $L_16 = sp + 8|0;
 $L_19 = sp;
 $L_22 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2077280);
 __THREW__ = 0;
 invoke_v(353);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = $L_0;
   $7 = $6;
   HEAP32[$7>>2] = $0;
   $8 = (($6) + 4)|0;
   $9 = $8;
   HEAP32[$9>>2] = $1;
   __THREW__ = 0;
   (invoke_ii(2996,(2167208|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(2724,(2167208|0),($L_0|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = ($12|0)==(0|0);
     if ($15) {
      $18 = $L_2;
      $19 = $18;
      HEAP32[$19>>2] = $2;
      $20 = (($18) + 4)|0;
      $21 = $20;
      HEAP32[$21>>2] = $3;
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      $24 = (invoke_iii(2724,(2167208|0),($L_2|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      $not$ = ($24|0)!=(0|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = $L_6;
     $28 = $27;
     HEAP32[$28>>2] = $2;
     $29 = (($27) + 4)|0;
     $30 = $29;
     HEAP32[$30>>2] = $3;
     __THREW__ = 0;
     (invoke_ii(2996,(2167208|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      $33 = (invoke_iii(2724,(2167208|0),($L_6|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = ($33|0)==(0|0);
       if ($36) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $37 = $L_9;
       $38 = $37;
       HEAP32[$38>>2] = $0;
       $39 = (($37) + 4)|0;
       $40 = $39;
       HEAP32[$40>>2] = $1;
       __THREW__ = 0;
       (invoke_ii(2996,(2167208|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(2724,(2167208|0),($L_9|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2051368|0))|0);
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if (!($47)) {
          __THREW__ = 0;
          $48 = (invoke_iii(2735,($43|0),(2051368|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if (!($50)) {
           $51 = ($48|0)==(0|0);
           if (!($51)) {
            $52 = $L_12;
            $53 = $52;
            HEAP32[$53>>2] = $0;
            $54 = (($52) + 4)|0;
            $55 = $54;
            HEAP32[$55>>2] = $1;
            __THREW__ = 0;
            (invoke_ii(2996,(2167208|0))|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             break;
            }
            __THREW__ = 0;
            $58 = (invoke_iii(2724,(2167208|0),($L_12|0))|0);
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2051368|0))|0);
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             break;
            }
            __THREW__ = 0;
            $63 = (invoke_iii(2752,($58|0),(2051368|0))|0);
            $64 = __THREW__; __THREW__ = 0;
            $65 = $64&1;
            if ($65) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($63|0));
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            $68 = (invoke_iiiii(314,(2051272|0),($63|0),($2|0),($3|0))|0);
            $69 = __THREW__; __THREW__ = 0;
            $70 = $69&1;
            if ($70) {
             break;
            } else {
             $$0 = $68;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           $71 = $L_16;
           $72 = $71;
           HEAP32[$72>>2] = $0;
           $73 = (($71) + 4)|0;
           $74 = $73;
           HEAP32[$74>>2] = $1;
           __THREW__ = 0;
           (invoke_ii(2996,(2167208|0))|0);
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if (!($76)) {
            __THREW__ = 0;
            $77 = (invoke_iii(2724,(2167208|0),($L_16|0))|0);
            $78 = __THREW__; __THREW__ = 0;
            $79 = $78&1;
            if (!($79)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2157896|0))|0);
             $80 = __THREW__; __THREW__ = 0;
             $81 = $80&1;
             if (!($81)) {
              __THREW__ = 0;
              $82 = (invoke_iii(2735,($77|0),(2157896|0))|0);
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if (!($84)) {
               $85 = ($82|0)==(0|0);
               if ($85) {
                __THREW__ = 0;
                (invoke_ii(2996,(2560072|0))|0);
                $114 = __THREW__; __THREW__ = 0;
                $115 = $114&1;
                if ($115) {
                 break;
                }
                __THREW__ = 0;
                $116 = (invoke_ii(3469,(2560072|0))|0);
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 break;
                }
                $119 = HEAP32[3020480>>2]|0;
                __THREW__ = 0;
                invoke_vii(1924,($116|0),($119|0));
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3827,($116|0));
                $122 = __THREW__; __THREW__ = 0;
                $123 = $122&1;
                if ($123) {
                 break;
                }
                // unreachable;
               }
               $86 = $L_19;
               $87 = $86;
               HEAP32[$87>>2] = $0;
               $88 = (($86) + 4)|0;
               $89 = $88;
               HEAP32[$89>>2] = $1;
               __THREW__ = 0;
               (invoke_ii(2996,(2167208|0))|0);
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                __THREW__ = 0;
                $92 = (invoke_iii(2724,(2167208|0),($L_19|0))|0);
                $93 = __THREW__; __THREW__ = 0;
                $94 = $93&1;
                if (!($94)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2157896|0))|0);
                 $95 = __THREW__; __THREW__ = 0;
                 $96 = $95&1;
                 if ($96) {
                  break;
                 }
                 __THREW__ = 0;
                 $97 = (invoke_iii(2752,($92|0),(2157896|0))|0);
                 $98 = __THREW__; __THREW__ = 0;
                 $99 = $98&1;
                 if ($99) {
                  break;
                 }
                 $100 = $L_22;
                 $101 = $100;
                 HEAP32[$101>>2] = $2;
                 $102 = (($100) + 4)|0;
                 $103 = $102;
                 HEAP32[$103>>2] = $3;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2167208|0))|0);
                 $104 = __THREW__; __THREW__ = 0;
                 $105 = $104&1;
                 if ($105) {
                  break;
                 }
                 __THREW__ = 0;
                 $106 = (invoke_iii(2724,(2167208|0),($L_22|0))|0);
                 $107 = __THREW__; __THREW__ = 0;
                 $108 = $107&1;
                 if ($108) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($97|0));
                 $109 = __THREW__; __THREW__ = 0;
                 $110 = $109&1;
                 if ($110) {
                  break;
                 }
                 __THREW__ = 0;
                 $111 = (invoke_iiii(1649,(2157808|0),($97|0),($106|0))|0);
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  break;
                 } else {
                  $$0 = $111;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsE6InvokeEP10MethodInfoPvy($method,$obj,$0,$1) {
 $method = $method|0;
 $obj = $obj|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $2 = (($data) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$data>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$5 & 2047]($6,$0,$1)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsS1_E6InvokeEPFiPvyyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$3,$6,$11,$14)|0);
 HEAP32[$ret>>2] = $15;
 $16 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($16|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2078360)|0);
 $0 = HEAP32[((2078360 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2078360)|0);
 $0 = HEAP32[((2078360 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2080624)|0);
 $0 = HEAP32[((2080624 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2080624)|0);
 $0 = HEAP32[((2080624 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m__ctorP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m_System_Collections_IEnumerator_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2082888)|0);
 $0 = HEAP32[((2082888 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m_DisposeP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m_MoveNextP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2082888)|0);
 $0 = HEAP32[((2082888 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2085152)|0);
 $0 = HEAP32[((2085152 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2085152)|0);
 $0 = HEAP32[((2085152 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2087416)|0);
 $0 = HEAP32[((2087416 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2087416)|0);
 $0 = HEAP32[((2087416 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2089680)|0);
 $0 = HEAP32[((2089680 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2089680)|0);
 $0 = HEAP32[((2089680 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2091944)|0);
 $0 = HEAP32[((2091944 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2091944)|0);
 $0 = HEAP32[((2091944 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2099320)|0);
 $0 = HEAP32[((2099320 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2099320)|0);
 $0 = HEAP32[((2099320 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2101584)|0);
 $0 = HEAP32[((2101584 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2101584)|0);
 $0 = HEAP32[((2101584 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2103848)|0);
 $0 = HEAP32[((2103848 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2103848)|0);
 $0 = HEAP32[((2103848 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m__ctorP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL145mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m_System_Collections_IEnumerator_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2106112)|0);
 $0 = HEAP32[((2106112 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m_DisposeP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m_MoveNextP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2106112)|0);
 $0 = HEAP32[((2106112 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m_System_Collections_IEnumerator_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2108376)|0);
 $0 = HEAP32[((2108376 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m_DisposeP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m_MoveNextP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2108376)|0);
 $0 = HEAP32[((2108376 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m__ctorP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m_System_Collections_IEnumerator_get_CurrentP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2110640)|0);
 $0 = HEAP32[((2110640 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m_DisposeP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m_MoveNextP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m_get_CurrentP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2110640)|0);
 $0 = HEAP32[((2110640 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m__ctorP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_System_Collections_IEnumerator_get_CurrentP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2112904)|0);
 $0 = HEAP32[((2112904 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL123mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_DisposeP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_MoveNextP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_get_CurrentP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2112904)|0);
 $0 = HEAP32[((2112904 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2115168)|0);
 $0 = HEAP32[((2115168 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2115168)|0);
 $0 = HEAP32[((2115168 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2117432)|0);
 $0 = HEAP32[((2117432 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2117432)|0);
 $0 = HEAP32[((2117432 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL153mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m_System_Collections_IEnumerator_get_CurrentP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2119696)|0);
 $0 = HEAP32[((2119696 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m_DisposeP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m_MoveNextP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m_get_CurrentP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2119696)|0);
 $0 = HEAP32[((2119696 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m__ctorP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m_System_Collections_IEnumerator_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2121960)|0);
 $0 = HEAP32[((2121960 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m_DisposeP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m_MoveNextP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2121960)|0);
 $0 = HEAP32[((2121960 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttributeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2124224)|0);
 $0 = HEAP32[((2124224 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2124224)|0);
 $0 = HEAP32[((2124224 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2126008);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z151mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_0 = sp;
 $L_1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2126056);
 __THREW__ = 0;
 invoke_vii(1751,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$L_1+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$L_0+12>>2]|0;HEAP32[$L_1+16>>2]=HEAP32[$L_0+16>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2258184|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2258184|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2126200);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(1259,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2126104);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2126152);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3992($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker0I69mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeTraitsE6InvokeEPF63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2258184,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2128752)|0);
 $0 = HEAP32[((2128752 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2128752)|0);
 $0 = HEAP32[((2128752 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL135mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2131016)|0);
 $0 = HEAP32[((2131016 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2131016)|0);
 $0 = HEAP32[((2131016 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2133280)|0);
 $0 = HEAP32[((2133280 + 84|0))>>2]|0;
 $1 = (__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map($__this) {
 $__this = $__this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_Dispose_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map($__this) {
 $__this = $__this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNext_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object($__this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2133280)|0);
 $0 = HEAP32[((2133280 + 84|0))>>2]|0;
 $1 = (__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_Current_gsharedP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2135064);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z151mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2135112);
 __THREW__ = 0;
 $0 = (invoke_ii(1772,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2273368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2273368|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2135256);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1835,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2135160);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2135208);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2137328);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2137376);
 __THREW__ = 0;
 invoke_vii(1757,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = $L_0;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $L_1;
  $9 = $8;
  HEAP32[$9>>2] = $4;
  $10 = (($8) + 4)|0;
  $11 = $10;
  HEAP32[$11>>2] = $7;
  __THREW__ = 0;
  (invoke_ii(2996,(2307464|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_iii(2724,(2307464|0),($L_1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2137520);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    invoke_viii(1275,($agg$result|0),($26|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2137424);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2137472);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __ZN12FuncInvoker0I48mscorlib_System_Collections_Hashtable_SlotTraitsE6InvokeEPF42mscorlib_System_Collections_Hashtable_SlotPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2307464,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2139592);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2139640);
 __THREW__ = 0;
 $0 = (invoke_ii(1777,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2308264|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2308264|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2139784);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1842,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2139688);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2139736);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2141856);
 HEAP32[$__this>>2] = $_____array;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z150mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2141904);
 __THREW__ = 0;
 $0 = (invoke_ii(1780,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$L_1>>2] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2316496|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2316496|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2142048);
 __THREW__ = 0;
 invoke_v(323);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   if ((($3|0) == -2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2607872|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3016344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   } else if ((($3|0) == -1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2607872|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3016352>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3829,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   } else {
    $26 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($26|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($29) + -1)|0;
    $36 = (($35) - ($32))|0;
    __THREW__ = 0;
    $37 = (invoke_iii(1846,($26|0),($36|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($37|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2141952);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = -2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2142000);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-2);
 do {
  if ($2) {
   $3 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   }
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    HEAP32[$0>>2] = $6;
    $10 = $6;
    break;
   }
  } else {
   $10 = $1;
  }
 } while(0);
 $9 = ($10|0)==(-1);
 if ($9) {
  $G_B5_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B5_0$0|0);
 }
 $13 = (($10) + -1)|0;
 HEAP32[$0>>2] = $13;
 $14 = ($10|0)!=(0);
 $G_B5_0$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z124mscorlib_U003CModuleU003E_m_UnsupportedMember_String_mscorlib_System_String_mscorlib_System_Exception_mscorlib_System_StringP22mscorlib_System_ObjectP25mscorlib_System_ExceptionP22mscorlib_System_String($__this,$self,$signature) {
 $__this = $__this|0;
 $self = $self|0;
 $signature = $signature|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148024);
 __THREW__ = 0;
 (invoke_ii(2996,(2611912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2611912|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1950,($2|0),($signature|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception4477($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z139mscorlib_U003CModuleU003E_m_UnsupportedMember_String_mscorlib_System_String_mscorlib_System_Security_SecurityElement_mscorlib_System_StringP22mscorlib_System_ObjectP40mscorlib_System_Security_SecurityElementP22mscorlib_System_String($__this,$self,$signature) {
 $__this = $__this|0;
 $self = $self|0;
 $signature = $signature|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148072);
 __THREW__ = 0;
 (invoke_ii(2996,(2611912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2611912|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1950,($2|0),($signature|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z138mscorlib_U003CModuleU003E_m_UnsupportedMember_String_mscorlib_System_String_mscorlib_System_Reflection_AssemblyName_mscorlib_System_StringP22mscorlib_System_ObjectP39mscorlib_System_Reflection_AssemblyNameP22mscorlib_System_String($__this,$self,$signature) {
 $__this = $__this|0;
 $self = $self|0;
 $signature = $signature|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148120);
 __THREW__ = 0;
 (invoke_ii(2996,(2611912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2611912|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1950,($2|0),($signature|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_U003CModuleU003E_m_UnsupportedMember_ObjectP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringP26mscorlib_System_Object_arrS4_($__this,$objectType,$url,$activationAttributes,$signature) {
 $__this = $__this|0;
 $objectType = $objectType|0;
 $url = $url|0;
 $activationAttributes = $activationAttributes|0;
 $signature = $signature|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148168);
 __THREW__ = 0;
 (invoke_ii(2996,(2611912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2611912|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1950,($2|0),($signature|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_U003CModuleU003E_m_UnsupportedMember_ByteU005BU005DP22mscorlib_System_ObjectP36mscorlib_System_Security_Policy_HashP22mscorlib_System_String($__this,$self,$signature) {
 $__this = $__this|0;
 $self = $self|0;
 $signature = $signature|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148216);
 __THREW__ = 0;
 (invoke_ii(2996,(2611912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2611912|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1950,($2|0),($signature|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker4I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_S1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S5_S5_S5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z30mscorlib_System_Object_m__ctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148688);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z78mscorlib_System_Object_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148736);
 $0 = ($__this|0)==($obj|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z101mscorlib_System_Object_m_Equals_mscorlib_System_Boolean_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_S0_($__this,$objA,$objB) {
 $__this = $__this|0;
 $objA = $objA|0;
 $objB = $objB|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148784);
 $0 = ($objA|0)==($objB|0);
 do {
  if ($0) {
   $$0 = 1;
  } else {
   $1 = ($objA|0)==(0|0);
   $2 = ($objB|0)==(0|0);
   $or$cond = $1 | $2;
   if ($or$cond) {
    $$0 = 0;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($objA|0));
    $3 = __THREW__; __THREW__ = 0;
    $4 = $3&1;
    if (!($4)) {
     __THREW__ = 0;
     $5 = (invoke_iiii(1644,(2148736|0),($objA|0),($objB|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      $$0 = $5;
      break;
     }
    }
    $8 = ___cxa_find_matching_catch()|0;
    $9 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($8|0);
    // unreachable;
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z33mscorlib_System_Object_m_FinalizeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148832);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z36mscorlib_System_Object_m_GetHashCodeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148880);
 __THREW__ = 0;
 $0 = (invoke_iii(457,0,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z44mscorlib_System_Object_m_InternalGetHashCodeP22mscorlib_System_ObjectS0_($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2149256);
 $0 = HEAP32[2149304>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2149312|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2149304>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($o|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Object_m_GetTypeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2148928);
 $0 = HEAP32[2148976>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2148984|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2148976>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Object_m_MemberwiseCloneP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2149016);
 $0 = HEAP32[2149064>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2149072|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2149064>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z33mscorlib_System_Object_m_ToStringP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2149112);
 __THREW__ = 0;
 $0 = (invoke_ii(1782,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2149160|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Object_m_ReferenceEqualsP22mscorlib_System_ObjectS0_S0_($__this,$objA,$objB) {
 $__this = $__this|0;
 $objA = $objA|0;
 $objB = $objB|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2149208);
 $0 = ($objA|0)==($objB|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z53mscorlib_System_Object_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($6,2);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($__this,$visibility) {
 $__this = $__this|0;
 $visibility = $visibility|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2159424);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  $3 = $visibility&1;
  HEAP8[$2>>0] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Object_CustomAttributesCacheGenerator_mscorlib_System_Object_m__ctorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Object_CustomAttributesCacheGenerator_mscorlib_System_Object_m_FinalizeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z94mscorlib_System_Object_CustomAttributesCacheGenerator_mscorlib_System_Object_m_ReferenceEqualsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z42mscorlib_System_ValueType_m_InternalEqualsP22mscorlib_System_ObjectS0_S0_PP26mscorlib_System_Object_arr($__this,$o1,$o2,$fields) {
 $__this = $__this|0;
 $o1 = $o1|0;
 $o2 = $o2|0;
 $fields = $fields|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2149864);
 $0 = HEAP32[2149912>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2149920|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2149912>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($o1|0),($o2|0),($fields|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_ValueType_m_DefaultEqualsP22mscorlib_System_ObjectS0_S0_($__this,$o1,$o2) {
 $__this = $__this|0;
 $o1 = $o1|0;
 $o2 = $o2|0;
 var $$0 = 0, $$pre = 0, $$pre$pre = 0, $$pre4 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150000);
 HEAP32[$V_0>>2] = 0;
 $0 = ($o2|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiiii(76,0,($o1|0),($o2|0),($V_0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $lpad$phi$index = $8;$lpad$phi$index2 = $9;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $4 = HEAP32[$V_0>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 } else {
  $55 = $4;$V_2$0 = 0;
 }
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($55|0));
  $56 = __THREW__; __THREW__ = 0;
  $57 = $56&1;
  if ($57) {
   label = 4;
   break;
  }
  $58 = HEAP32[$V_0>>2]|0;
  $59 = (($58) + 12|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ($V_2$0|0)<($60|0);
  if (!($61)) {
   $$0 = 1;
   label = 26;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($58|0));
  $62 = __THREW__; __THREW__ = 0;
  $63 = $62&1;
  if ($63) {
   label = 4;
   break;
  }
  $10 = HEAP32[$V_0>>2]|0;
  $11 = (($10) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($V_2$0>>>0)<($12>>>0);
  if ($13) {
   $20 = $10;
  } else {
   __THREW__ = 0;
   $14 = (invoke_i(132)|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 4;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($14|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 4;
    break;
   }
   $$pre4 = HEAP32[$V_0>>2]|0;
   $20 = $$pre4;
  }
  $19 = HEAP32[$20>>2]|0;
  $21 = (($20) + 16|0);
  $22 = (($19) + 92|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = Math_imul($23, $V_2$0)|0;
  $25 = (($21) + ($24)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $V_2$0 | 1;
  __THREW__ = 0;
  invoke_vi(3799,($20|0));
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if ($29) {
   label = 4;
   break;
  }
  $30 = HEAP32[$V_0>>2]|0;
  $31 = (($30) + 12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($27>>>0)<($32>>>0);
  if ($33) {
   $40 = $30;
  } else {
   __THREW__ = 0;
   $34 = (invoke_i(132)|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    label = 4;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($34|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 4;
    break;
   }
   $$pre5 = HEAP32[$V_0>>2]|0;
   $40 = $$pre5;
  }
  $39 = HEAP32[$40>>2]|0;
  $41 = (($40) + 16|0);
  $42 = (($39) + 92|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = Math_imul($43, $27)|0;
  $45 = (($41) + ($44)|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ($26|0)==(0|0);
  if ($47) {
   $48 = ($46|0)==(0|0);
   if ($48) {
    $$pre = $40;
   } else {
    $$0 = 0;
    label = 26;
    break;
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($26|0));
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    label = 4;
    break;
   }
   __THREW__ = 0;
   $51 = (invoke_iiii(1644,(2148736|0),($26|0),($46|0))|0);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    label = 4;
    break;
   }
   if (!($51)) {
    $$0 = 0;
    label = 26;
    break;
   }
   $$pre$pre = HEAP32[$V_0>>2]|0;
   $$pre = $$pre$pre;
  }
  $54 = (($V_2$0) + 2)|0;
  $55 = $$pre;$V_2$0 = $54;
 }
 if ((label|0) == 4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $lpad$phi$index = $6;$lpad$phi$index2 = $7;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 26) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z34mscorlib_System_ValueType_m_EqualsP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150048);
 __THREW__ = 0;
 $0 = (invoke_iiii(426,0,($__this|0),($obj|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z47mscorlib_System_ValueType_m_InternalGetHashCodeP22mscorlib_System_ObjectS0_PP26mscorlib_System_Object_arr($__this,$o,$fields) {
 $__this = $__this|0;
 $o = $o|0;
 $fields = $fields|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150096);
 $0 = HEAP32[2150144>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2150152|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2150144>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($o|0),($fields|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_ValueType_m_GetHashCodeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$pre = 0, $$pre$pre = 0, $$pre6 = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_1$2 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150224);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiii(427,0,($__this|0),($V_0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  $lpad$phi$index = $7;$lpad$phi$index2 = $8;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $3 = HEAP32[$V_0>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $V_1$2 = $0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_1$2|0);
 } else {
  $53 = $3;$V_1$1 = $0;$V_2$0 = 0;
 }
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($53|0));
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if ($55) {
   break;
  }
  $56 = HEAP32[$V_0>>2]|0;
  $57 = (($56) + 12|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($V_2$0|0)<($58|0);
  if (!($59)) {
   $V_1$2 = $V_1$1;
   label = 23;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($56|0));
  $60 = __THREW__; __THREW__ = 0;
  $61 = $60&1;
  if ($61) {
   break;
  }
  $9 = HEAP32[$V_0>>2]|0;
  $10 = (($9) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($V_2$0>>>0)<($11>>>0);
  if ($12) {
   $19 = $9;
  } else {
   __THREW__ = 0;
   $13 = (invoke_i(132)|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($13|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    break;
   }
   $$pre6 = HEAP32[$V_0>>2]|0;
   $19 = $$pre6;
  }
  $18 = HEAP32[$19>>2]|0;
  $20 = (($19) + 16|0);
  $21 = (($18) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_2$0)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   $$pre = $19;$V_1$0 = $V_1$1;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($19|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    break;
   }
   $29 = HEAP32[$V_0>>2]|0;
   $30 = (($29) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = ($V_2$0>>>0)<($31>>>0);
   if ($32) {
    $39 = $29;
   } else {
    __THREW__ = 0;
    $33 = (invoke_i(132)|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($33|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    $$pre7 = HEAP32[$V_0>>2]|0;
    $39 = $$pre7;
   }
   $38 = HEAP32[$39>>2]|0;
   $40 = (($39) + 16|0);
   $41 = (($38) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_2$0)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($45|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    break;
   }
   __THREW__ = 0;
   $48 = (invoke_iii(2729,(2148880|0),($45|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    break;
   }
   $51 = $48 ^ $V_1$1;
   $$pre$pre = HEAP32[$V_0>>2]|0;
   $$pre = $$pre$pre;$V_1$0 = $51;
  }
  $52 = (($V_2$0) + 1)|0;
  $53 = $$pre;$V_1$1 = $V_1$0;$V_2$0 = $52;
 }
 if ((label|0) == 23) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_1$2|0);
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_ValueType_m_ToStringP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150272);
 __THREW__ = 0;
 $0 = (invoke_ii(1782,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2150320|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsS1_17VoidPointerTraitsE6InvokeEPFbPvP22mscorlib_System_ObjectS6_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 $6 = $5&1;
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFiPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z56mscorlib_System_ValueType_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z33mscorlib_System_Attribute_m__ctorP25mscorlib_System_Attribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150728);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z131mscorlib_System_Attribute_m_GetCustomAttribute_mscorlib_System_Attribute_mscorlib_System_Reflection_MemberInfo_mscorlib_System_TypeP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoP20mscorlib_System_Type($__this,$element,$attributeType) {
 $__this = $__this|0;
 $element = $element|0;
 $attributeType = $attributeType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150776);
 __THREW__ = 0;
 $0 = (invoke_iiiii(77,0,($element|0),($attributeType|0),1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z155mscorlib_System_Attribute_m_GetCustomAttribute_mscorlib_System_Attribute_mscorlib_System_Reflection_MemberInfo_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoP20mscorlib_System_Typeb($__this,$element,$attributeType,$inherit) {
 $__this = $__this|0;
 $element = $element|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150824);
 __THREW__ = 0;
 invoke_viii(720,(0|0),($element|0),($attributeType|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iiiii(186,(0|0),($element|0),($attributeType|0),($inherit|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($2|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Attribute_m_GetHashCodeP25mscorlib_System_Attribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150872);
 __THREW__ = 0;
 $0 = (invoke_ii(1781,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z123mscorlib_System_Attribute_m_IsDefined_mscorlib_System_Boolean_mscorlib_System_Reflection_ParameterInfo_mscorlib_System_TypeP22mscorlib_System_ObjectP40mscorlib_System_Reflection_ParameterInfoP20mscorlib_System_Type($__this,$element,$attributeType) {
 $__this = $__this|0;
 $element = $element|0;
 $attributeType = $attributeType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150920);
 __THREW__ = 0;
 $0 = (invoke_iiiii(79,0,($element|0),($attributeType|0),1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z147mscorlib_System_Attribute_m_IsDefined_mscorlib_System_Boolean_mscorlib_System_Reflection_ParameterInfo_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectP40mscorlib_System_Reflection_ParameterInfoP20mscorlib_System_Typeb($__this,$element,$attributeType,$inherit) {
 $__this = $__this|0;
 $element = $element|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2151160);
 __THREW__ = 0;
 invoke_viii(720,(0|0),($element|0),($attributeType|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($element|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iiiii(315,(2432168|0),($element|0),($attributeType|0),($inherit|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if ($4) {
     $$0 = 1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($element|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iii(2730,(2432072|0),($element|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      $14 = (invoke_iiiii(78,0,($11|0),($attributeType|0),($inherit|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $$0 = $14;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Attribute_m_IsDefined_mscorlib_System_Boolean_mscorlib_System_Reflection_MemberInfo_mscorlib_System_TypeP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoP20mscorlib_System_Type($__this,$element,$attributeType) {
 $__this = $__this|0;
 $element = $element|0;
 $attributeType = $attributeType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2150968);
 __THREW__ = 0;
 $0 = (invoke_iiiii(78,0,($element|0),($attributeType|0),1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z144mscorlib_System_Attribute_m_IsDefined_mscorlib_System_Boolean_mscorlib_System_Reflection_MemberInfo_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoP20mscorlib_System_Typeb($__this,$element,$attributeType,$inherit) {
 $__this = $__this|0;
 $element = $element|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2151016);
 __THREW__ = 0;
 invoke_v(355);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_viii(720,(0|0),($element|0),($attributeType|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    invoke_vi(3799,($element|0));
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     $6 = (invoke_iii(2729,(2151064|0),($element|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      switch ($6|0) {
      case 16:  {
       __THREW__ = 0;
       $24 = (invoke_iiiii(188,(0|0),($element|0),($attributeType|0),($inherit|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break L1;
       } else {
        $$0 = $24;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
       break;
      }
      case 128: case 32: case 8: case 4: case 2: case 1:  {
       __THREW__ = 0;
       invoke_vi(3799,($element|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break L1;
       }
       __THREW__ = 0;
       $29 = (invoke_iiiii(315,(2151112|0),($element|0),($attributeType|0),($inherit|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break L1;
       } else {
        $$0 = $29;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
       break;
      }
      default: {
       $11 = HEAP32[3002696>>2]|0;
       __THREW__ = 0;
       $12 = (invoke_iii(783,0,($11|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2622808|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break L1;
       }
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(2622808|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vii(1954,($17|0),($12|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3830,($17|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break L1;
       }
       // unreachable;
      }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_Locale_m_GetText_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$msg) {
 $__this = $__this|0;
 $msg = $msg|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2256504);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($msg|0);
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS5_b($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z34mscorlib_System_Attribute_m_EqualsP25mscorlib_System_AttributeP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2151208);
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2151624|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2735,($obj|0),(2151624|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $9 = (invoke_iiii(426,0,($__this|0),($obj|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS3_S3_S3_bES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z56mscorlib_System_Attribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2151872)|0);
 $7 = HEAP32[((2151872 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($11,32767);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($14,0);
 $15 = HEAP32[$3>>2]|0;
 $16 = (($15) + 12|0);
 HEAP32[$16>>2] = $14;
 STACKTOP = sp;return;
}
function __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($__this,$validOn) {
 $__this = $__this|0;
 $validOn = $validOn|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2158664);
 $0 = (($__this) + 13|0);
 HEAP8[$0>>0] = 1;
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($__this) + 8|0);
  HEAP32[$3>>2] = $validOn;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Runtime_InteropServices__Attribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2151624)|0);
 $5 = HEAP32[((2151624 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($8,1);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($14,1);
 $15 = HEAP32[$3>>2]|0;
 $16 = (($15) + 12|0);
 HEAP32[$16>>2] = $14;
 $17 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $18 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2151760)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($17,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $17;
 STACKTOP = sp;return;
}
function __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($__this,$isCompliant) {
 $__this = $__this|0;
 $isCompliant = $isCompliant|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2164696);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  $3 = $isCompliant&1;
  HEAP8[$2>>0] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($__this,$guid) {
 $__this = $__this|0;
 $guid = $guid|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2249784);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $guid;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_Int32_m_System_IConvertible_ToBooleanPiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152008);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1009,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Int32_m_System_IConvertible_ToBytePiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152056);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1017,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Int32_m_System_IConvertible_ToCharPiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152104);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1023,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Int32_m_System_IConvertible_ToDateTimePiP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152152);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 invoke_viii(647,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_Int32_m_System_IConvertible_ToDecimalPiP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152200);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 invoke_viii(653,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52mscorlib_System_Int32_m_System_IConvertible_ToDoublePiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152248);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (+invoke_dii(21,(0|0),($0|0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$1);
 }
 return +0;
}
function __Z51mscorlib_System_Int32_m_System_IConvertible_ToInt16PiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152296);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1032,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Int32_m_System_IConvertible_ToInt32PiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152344);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z51mscorlib_System_Int32_m_System_IConvertible_ToInt64PiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152392);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1050,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Int32_m_System_IConvertible_ToSBytePiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152440);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1060,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int32_m_System_IConvertible_ToSinglePiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152488);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fii(27,(0|0),($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($1));
 }
 return Math_fround(0);
}
function __Z50mscorlib_System_Int32_m_System_IConvertible_ToTypePiP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152536);
 __THREW__ = 0;
 invoke_v(356);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = HEAP32[$__this>>2]|0;
    HEAP32[$L_2>>2] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3002856>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Int32_m_System_IConvertible_ToUInt16PiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152584);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1068,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int32_m_System_IConvertible_ToUInt32PiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152632);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1076,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int32_m_System_IConvertible_ToUInt64PiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152680);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1084,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Int32_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPiP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152728);
 __THREW__ = 0;
 invoke_v(357);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2155952|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3002896>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2155952|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP32[$26>>2]|0;
      $30 = HEAP32[$__this>>2]|0;
      $31 = ($30|0)==($29|0);
      if ($31) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $32 = ($30|0)>($29|0);
      $$ = $32 ? 1 : -1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo4482($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z77mscorlib_System_Int32_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPiP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152776);
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2155952|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2155952|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[$10>>2]|0;
     $14 = HEAP32[$__this>>2]|0;
     $15 = ($13|0)==($14|0);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_Int32_m_GetHashCodePi($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152824);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z77mscorlib_System_Int32_m_CompareTo_mscorlib_System_Int32_mscorlib_System_Int32Pii($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152872);
 $0 = HEAP32[$__this>>2]|0;
 $1 = ($0|0)==($value|0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = ($0|0)>($value|0);
  $$ = $2 ? 1 : -1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z76mscorlib_System_Int32_m_Equals_mscorlib_System_Boolean_mscorlib_System_Int32Pii($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152920);
 $0 = HEAP32[$__this>>2]|0;
 $1 = ($0|0)==($obj|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z49mscorlib_System_Int32_m_ProcessTrailingWhitespaceP22mscorlib_System_ObjectbP22mscorlib_System_StringiPP25mscorlib_System_Exception($__this,$tryParse,$s,$position,$exc) {
 $__this = $__this|0;
 $tryParse = $tryParse|0;
 $s = $s|0;
 $position = $position|0;
 $exc = $exc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2152968);
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1816,($s|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($position|0);
    if ($5) {
     $V_1$02 = $position;
    } else {
     $$0 = 1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($s|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(621,($s|0),($V_1$02|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 4;
      break;
     }
     $13 = ($10<<16>>16)==(0);
     if (!($13)) {
      __THREW__ = 0;
      $14 = (invoke_iii(604,0,($10|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       label = 4;
       break;
      }
      if (!($14)) {
       label = 11;
       break;
      }
     }
     $20 = (($V_1$02) + 1)|0;
     $21 = ($20|0)<($2|0);
     if ($21) {
      $V_1$02 = $20;
     } else {
      $$0 = 1;
      label = 16;
      break;
     }
    }
    if ((label|0) == 4) {
     $6 = ___cxa_find_matching_catch()|0;
     $7 = tempRet0;
     $lpad$phi$index = $6;$lpad$phi$index2 = $7;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 11) {
     if ($tryParse) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $17 = (invoke_ii(1790,0)|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     HEAP32[$exc>>2] = $17;
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    else if ((label|0) == 16) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_String_m_get_LengthP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185304);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z34mscorlib_System_String_m_get_CharsP22mscorlib_System_Stringi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182232);
 $0 = ($index|0)<(0);
 if (!($0)) {
  $1 = (($__this) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)>($index|0);
  if ($3) {
   $15 = (($__this) + 12|0);
   $16 = (($15) + ($index<<1)|0);
   $17 = HEAP16[$16>>1]|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($17|0);
  }
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2606944|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(3469,(2606944|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vi(2730,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3830,($6|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     // unreachable;
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_Char_m_IsWhiteSpaceP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $c$off = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178824);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2180696 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2180696|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2180696 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $c&65535;
    $18 = (($16) + ($17)|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19&255)>(10);
    if (!($20)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $21 = ($19&255)>(13);
    if (!($21)) {
     $$0 = 1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $c$off = (($c) + -9)<<16>>16;
    $22 = ($c$off&65535)<(5);
    $23 = ($c<<16>>16)==(133);
    $or$cond1 = $22 | $23;
    $24 = ($c<<16>>16)==(8287);
    $$ = $or$cond1 | $24;
    $$0 = $$;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_Int32_m_GetFormatExceptionP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153448);
 __THREW__ = 0;
 invoke_v(358);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2603176|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2603176|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3003368>>2]|0;
    __THREW__ = 0;
    invoke_vii(1940,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($4|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z166mscorlib_System_Int32_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Boolean_mscorlib_System_Int32U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringbPiPP25mscorlib_System_Exception($__this,$s,$tryParse,$result,$exc) {
 $__this = $__this|0;
 $s = $s|0;
 $tryParse = $tryParse|0;
 $result = $result|0;
 $exc = $exc|0;
 var $$0 = 0, $$V_0$1 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$226 = 0, $V_2$0$lcssa = 0, $V_2$033 = 0, $V_2$1 = 0, $V_2$2$ph = 0, $V_2$225 = 0, $V_3$0$ph = 0;
 var $V_4$0$off0 = 0, $V_4$1$off024 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153016);
 __THREW__ = 0;
 invoke_v(359);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   HEAP32[$result>>2] = 0;
   HEAP32[$exc>>2] = 0;
   $2 = ($s|0)==(0|0);
   if ($2) {
    if ($tryParse) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3002968>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    HEAP32[$exc>>2] = $11;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(1816,($s|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = ($19|0)>(0);
     L15: do {
      if ($22) {
       $V_2$033 = 0;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($s|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         break;
        }
        __THREW__ = 0;
        $23 = (invoke_iii(621,($s|0),($V_2$033|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         break;
        }
        __THREW__ = 0;
        $26 = (invoke_iii(604,0,($23|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
        $29 = (($V_2$033) + 1)|0;
        if (!($26)) {
         $V_2$0$lcssa = $V_2$033;
         break L15;
        }
        $30 = ($29|0)<($19|0);
        if ($30) {
         $V_2$033 = $29;
        } else {
         $V_2$0$lcssa = $29;
         break L15;
        }
       }
       $5 = ___cxa_find_matching_catch()|0;
       $6 = tempRet0;
       $lpad$phi$index = $5;$lpad$phi$index3 = $6;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      } else {
       $V_2$0$lcssa = 0;
      }
     } while(0);
     $33 = ($V_2$0$lcssa|0)==($19|0);
     if ($33) {
      if ($tryParse) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      $34 = (invoke_ii(1790,0)|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      HEAP32[$exc>>2] = $34;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($s|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      __THREW__ = 0;
      $39 = (invoke_iii(621,($s|0),($V_2$0$lcssa|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       if ((($39<<16>>16) == 43)) {
        $42 = (($V_2$0$lcssa) + 1)|0;
        $V_2$2$ph = $42;$V_3$0$ph = 1;
       } else if ((($39<<16>>16) == 45)) {
        $43 = (($V_2$0$lcssa) + 1)|0;
        $V_2$2$ph = $43;$V_3$0$ph = -1;
       } else {
        $V_2$2$ph = $V_2$0$lcssa;$V_3$0$ph = 1;
       }
       $44 = ($V_2$2$ph|0)<($19|0);
       L39: do {
        if ($44) {
         $V_0$226 = 0;$V_2$225 = $V_2$2$ph;$V_4$1$off024 = 0;
         L40: while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($s|0));
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          $45 = (invoke_iii(621,($s|0),($V_2$225|0))|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           label = 3;
           break;
          }
          $48 = ($45<<16>>16)==(0);
          do {
           if ($48) {
            $V_0$1 = $V_0$226;$V_2$1 = $19;$V_4$0$off0 = $V_4$1$off024;
           } else {
            $$off = (($45) + -48)<<16>>16;
            $49 = ($$off&65535)>(9);
            if ($49) {
             __THREW__ = 0;
             $68 = (invoke_iiiiii(83,0,($tryParse|0),($s|0),($V_2$225|0),($exc|0))|0);
             $69 = __THREW__; __THREW__ = 0;
             $70 = $69&1;
             if ($70) {
              label = 3;
              break L40;
             }
             if ($68) {
              $V_0$1 = $V_0$226;$V_2$1 = $V_2$225;$V_4$0$off0 = $V_4$1$off024;
              break;
             } else {
              $$0 = 0;
              label = 55;
              break L40;
             }
            }
            $50 = $45&65535;
            $51 = (($50) + 208)|0;
            $52 = ($V_0$226|0)<(214748365);
            if (!($52)) {
             break L40;
            }
            $53 = ($V_0$226|0)==(214748364);
            if ($53) {
             label = 35;
             break L40;
            }
            $65 = ($V_0$226*10)|0;
            $66 = $51 & 255;
            $67 = (($66) + ($65))|0;
            $V_0$1 = $67;$V_2$1 = $V_2$225;$V_4$0$off0 = 1;
           }
          } while(0);
          $71 = (($V_2$1) + 1)|0;
          $72 = ($71|0)<($19|0);
          if ($72) {
           $V_0$226 = $V_0$1;$V_2$225 = $71;$V_4$1$off024 = $V_4$0$off0;
          } else {
           label = 45;
           break;
          }
         }
         do {
          if ((label|0) == 3) {
           $3 = ___cxa_find_matching_catch()|0;
           $4 = tempRet0;
           $lpad$phi$index = $3;$lpad$phi$index3 = $4;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 35) {
           $54 = $51 & 255;
           $55 = ($54>>>0)<(8);
           if (!($55)) {
            $56 = ($V_3$0$ph|0)!=(1);
            $57 = ($54>>>0)<(9);
            $or$cond6 = $56 & $57;
            if (!($or$cond6)) {
             break;
            }
           }
           $58 = ($V_3$0$ph|0)==(-1);
           $59 = (($54) + 2147483640)|0;
           $60 = (-2147483640 - ($54))|0;
           $V_0$0 = $58 ? $60 : $59;
           $61 = (($V_2$225) + 1)|0;
           __THREW__ = 0;
           $62 = (invoke_iiiiii(83,0,($tryParse|0),($s|0),($61|0),($exc|0))|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            break L1;
           }
           if ($62) {
            HEAP32[$result>>2] = $V_0$0;
            $$0 = 1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
          else if ((label|0) == 45) {
           if (!($V_4$0$off0)) {
            break L39;
           }
           $78 = ($V_3$0$ph|0)==(-1);
           $79 = (0 - ($V_0$1))|0;
           $$V_0$1 = $78 ? $79 : $V_0$1;
           HEAP32[$result>>2] = $$V_0$1;
           $$0 = 1;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          else if ((label|0) == 55) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         } while(0);
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2635888|0))|0);
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if ($81) {
          break L1;
         }
         __THREW__ = 0;
         $82 = (invoke_ii(3469,(2635888|0))|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break L1;
         }
         $85 = HEAP32[3002976>>2]|0;
         __THREW__ = 0;
         invoke_vii(1971,($82|0),($85|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break L1;
         }
         HEAP32[$exc>>2] = $82;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       if ($tryParse) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       $75 = (invoke_ii(1790,0)|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if (!($77)) {
        HEAP32[$exc>>2] = $75;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Int32_m_Parse_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153064);
 __THREW__ = 0;
 $0 = (invoke_iiiii(82,0,($s|0),7,($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z149mscorlib_System_Int32_m_Parse_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153592);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(65,0,($s|0),($style|0),($provider|0),0,($V_1|0),($V_0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 }
 if ($0) {
  $8 = HEAP32[$V_1>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 $5 = HEAP32[$V_0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3830,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  // unreachable;
 }
 return 0|0;
}
function __Z34mscorlib_System_Int32_m_CheckStyleP22mscorlib_System_ObjectibPP25mscorlib_System_Exception($__this,$style,$tryParse,$exc) {
 $__this = $__this|0;
 $style = $style|0;
 $tryParse = $tryParse|0;
 $exc = $exc|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$1 = 0, $_stackTraceSentry = 0, $brmerge = 0, $brmerge2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153112);
 __THREW__ = 0;
 invoke_v(360);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $style & 512;
   $3 = ($2|0)==(0);
   if ($3) {
    $20 = ($style|0)<(512);
    $brmerge2 = $20 | $tryParse;
    if ($brmerge2) {
     $$0 = $20;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(3469,(2560072|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    $26 = HEAP32[3003048>>2]|0;
    __THREW__ = 0;
    invoke_vii(1924,($23|0),($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    HEAP32[$exc>>2] = $23;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    $6 = $style & 1;
    $7 = $6 | 512;
    $$ = $7 ^ $style;
    $8 = $style & 2;
    $9 = ($8|0)==(0);
    $10 = $$ ^ 2;
    $V_0$1 = $9 ? $$ : $10;
    $11 = ($V_0$1|0)==(0);
    $brmerge = $11 | $tryParse;
    if ($brmerge) {
     $$0 = $11;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2560072|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = HEAP32[3003040>>2]|0;
    __THREW__ = 0;
    invoke_vii(1924,($14|0),($17|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    HEAP32[$exc>>2] = $14;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Int32_m_JumpOverWhiteP22mscorlib_System_ObjectPiP22mscorlib_System_StringbbPP25mscorlib_System_Exception($__this,$pos,$s,$reportError,$tryParse,$exc) {
 $__this = $__this|0;
 $pos = $pos|0;
 $s = $s|0;
 $reportError = $reportError|0;
 $tryParse = $tryParse|0;
 $exc = $exc|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $brmerge = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153160);
 $$pre = HEAP32[$pos>>2]|0;
 $6 = $$pre;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($s|0));
  $0 = __THREW__; __THREW__ = 0;
  $1 = $0&1;
  if ($1) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($s|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   label = 5;
   break;
  }
  $5 = ($6|0)<($2|0);
  if (!($5)) {
   break;
  }
  $11 = HEAP32[$pos>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($s|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $14 = (invoke_iii(621,($s|0),($11|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $17 = (invoke_iii(604,0,($14|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 5;
   break;
  }
  if (!($17)) {
   break;
  }
  $20 = HEAP32[$pos>>2]|0;
  $21 = (($20) + 1)|0;
  HEAP32[$pos>>2] = $21;
  $6 = $21;
 }
 if ((label|0) == 5) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  $lpad$phi$index = $7;$lpad$phi$index2 = $8;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 if (!($reportError)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $22 = HEAP32[$pos>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if (!($24)) {
  __THREW__ = 0;
  $25 = (invoke_ii(1816,($s|0))|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if (!($27)) {
   $28 = ($22|0)<($25|0);
   $brmerge = $28 | $tryParse;
   if ($brmerge) {
    $$0 = $28;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $29 = (invoke_ii(1790,0)|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    HEAP32[$exc>>2] = $29;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Int32_m_FindSignP22mscorlib_System_ObjectPiP22mscorlib_System_StringP46mscorlib_System_Globalization_NumberFormatInfoPbS6_($__this,$pos,$s,$nfi,$foundSign,$negative) {
 $__this = $__this|0;
 $pos = $pos|0;
 $s = $s|0;
 $nfi = $nfi|0;
 $foundSign = $foundSign|0;
 $negative = $negative|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153208);
 $0 = HEAP32[$pos>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($nfi|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2029,($nfi|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1816,($3|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = (($8) + ($0))|0;
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       $14 = (invoke_ii(1816,($s|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        $17 = ($11|0)>($14|0);
        if ($17) {
         $$pre = HEAP32[$pos>>2]|0;
         $66 = $$pre;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          break;
         }
         __THREW__ = 0;
         $22 = (invoke_ii(2029,($nfi|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if ($24) {
          break;
         }
         $25 = HEAP32[$pos>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         __THREW__ = 0;
         $28 = (invoke_ii(2029,($nfi|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($28|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         $33 = (invoke_ii(1816,($28|0))|0);
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break;
         }
         __THREW__ = 0;
         $38 = (invoke_iiiii(95,($s|0),($22|0),($25|0),($33|0))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break;
         }
         $41 = HEAP32[$pos>>2]|0;
         $42 = ($38|0)==($41|0);
         if ($42) {
          HEAP8[$negative>>0] = 1;
          HEAP8[$foundSign>>0] = 1;
          $43 = HEAP32[$pos>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          }
          __THREW__ = 0;
          $46 = (invoke_ii(2029,($nfi|0))|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($46|0));
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
          __THREW__ = 0;
          $51 = (invoke_ii(1816,($46|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break;
          }
          $54 = (($51) + ($43))|0;
          HEAP32[$pos>>2] = $54;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         } else {
          $66 = $41;
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($nfi|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if (!($56)) {
         __THREW__ = 0;
         $57 = (invoke_ii(2044,($nfi|0))|0);
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          invoke_vi(3799,($57|0));
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if (!($61)) {
           __THREW__ = 0;
           $62 = (invoke_ii(1816,($57|0))|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if (!($64)) {
            $65 = (($62) + ($66))|0;
            __THREW__ = 0;
            invoke_vi(3799,($s|0));
            $67 = __THREW__; __THREW__ = 0;
            $68 = $67&1;
            if (!($68)) {
             __THREW__ = 0;
             $69 = (invoke_ii(1816,($s|0))|0);
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if (!($71)) {
              $72 = ($65|0)<($69|0);
              if (!($72)) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $73 = __THREW__; __THREW__ = 0;
              $74 = $73&1;
              if (!($74)) {
               __THREW__ = 0;
               $75 = (invoke_ii(2044,($nfi|0))|0);
               $76 = __THREW__; __THREW__ = 0;
               $77 = $76&1;
               if (!($77)) {
                $78 = HEAP32[$pos>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $79 = __THREW__; __THREW__ = 0;
                $80 = $79&1;
                if (!($80)) {
                 __THREW__ = 0;
                 $81 = (invoke_ii(2044,($nfi|0))|0);
                 $82 = __THREW__; __THREW__ = 0;
                 $83 = $82&1;
                 if (!($83)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($81|0));
                  $84 = __THREW__; __THREW__ = 0;
                  $85 = $84&1;
                  if (!($85)) {
                   __THREW__ = 0;
                   $86 = (invoke_ii(1816,($81|0))|0);
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($s|0));
                   $89 = __THREW__; __THREW__ = 0;
                   $90 = $89&1;
                   if ($90) {
                    break;
                   }
                   __THREW__ = 0;
                   $91 = (invoke_iiiii(95,($s|0),($75|0),($78|0),($86|0))|0);
                   $92 = __THREW__; __THREW__ = 0;
                   $93 = $92&1;
                   if ($93) {
                    break;
                   }
                   $94 = HEAP32[$pos>>2]|0;
                   $95 = ($91|0)==($94|0);
                   if (!($95)) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   HEAP8[$negative>>0] = 0;
                   $96 = HEAP32[$pos>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($nfi|0));
                   $97 = __THREW__; __THREW__ = 0;
                   $98 = $97&1;
                   if ($98) {
                    break;
                   }
                   __THREW__ = 0;
                   $99 = (invoke_ii(2044,($nfi|0))|0);
                   $100 = __THREW__; __THREW__ = 0;
                   $101 = $100&1;
                   if ($101) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($99|0));
                   $102 = __THREW__; __THREW__ = 0;
                   $103 = $102&1;
                   if ($103) {
                    break;
                   }
                   __THREW__ = 0;
                   $104 = (invoke_ii(1816,($99|0))|0);
                   $105 = __THREW__; __THREW__ = 0;
                   $106 = $105&1;
                   if ($106) {
                    break;
                   }
                   $107 = (($104) + ($96))|0;
                   HEAP32[$pos>>2] = $107;
                   HEAP8[$foundSign>>0] = 1;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z121mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringS0_ii($__this,$value,$startIndex,$count) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $$old = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183816);
 __THREW__ = 0;
 invoke_v(361);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($startIndex|0)<(0);
   if (!($15)) {
    $16 = (($__this) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)<($startIndex|0);
    if (!($18)) {
     $30 = ($count|0)<(0);
     if (!($30)) {
      $31 = (($17) - ($count))|0;
      $32 = ($31|0)<($startIndex|0);
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3799,($value|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
       $46 = (($value) + 8|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0);
       if ($48) {
        $$0 = $startIndex;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $49 = ($startIndex|0)==(0);
       if ($49) {
        $50 = HEAP32[$16>>2]|0;
        $51 = ($50|0)==(0);
        $52 = ($count|0)==(0);
        $or$cond = $51 | $52;
        if ($or$cond) {
         $$0 = -1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } else {
        $$old = ($count|0)==(0);
        if ($$old) {
         $$0 = -1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       __THREW__ = 0;
       $53 = (invoke_ii(1982,(0|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($53|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       __THREW__ = 0;
       $58 = (invoke_iii(2730,(2304464|0),($53|0))|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($58|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       __THREW__ = 0;
       $63 = (invoke_iiiiiii(129,(2326464|0),($58|0),($__this|0),($value|0),($startIndex|0),($count|0))|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break;
       } else {
        $$0 = $63;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     $35 = (invoke_ii(3469,(2561352|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     $38 = HEAP32[3006368>>2]|0;
     $39 = HEAP32[3006376>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($35|0),($38|0),($39|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($35|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2561352|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[3006352>>2]|0;
     $25 = HEAP32[3006360>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($21|0),($24|0),($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      invoke_vi(3830,($21|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_Int32_m_FindCurrencyP22mscorlib_System_ObjectPiP22mscorlib_System_StringP46mscorlib_System_Globalization_NumberFormatInfoPb($__this,$pos,$s,$nfi,$foundCurrency) {
 $__this = $__this|0;
 $pos = $pos|0;
 $s = $s|0;
 $nfi = $nfi|0;
 $foundCurrency = $foundCurrency|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153256);
 $0 = HEAP32[$pos>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($nfi|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2024,($nfi|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1816,($3|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = (($8) + ($0))|0;
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       $14 = (invoke_ii(1816,($s|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        $17 = ($11|0)>($14|0);
        if ($17) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        $20 = HEAP32[$pos>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($nfi|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         $23 = (invoke_ii(2024,($nfi|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          invoke_vi(3799,($23|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           $28 = (invoke_ii(1816,($23|0))|0);
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if (!($30)) {
            __THREW__ = 0;
            invoke_vi(3799,($s|0));
            $31 = __THREW__; __THREW__ = 0;
            $32 = $31&1;
            if (!($32)) {
             __THREW__ = 0;
             $33 = (invoke_iiii(528,($s|0),($20|0),($28|0))|0);
             $34 = __THREW__; __THREW__ = 0;
             $35 = $34&1;
             if (!($35)) {
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $36 = __THREW__; __THREW__ = 0;
              $37 = $36&1;
              if (!($37)) {
               __THREW__ = 0;
               $38 = (invoke_ii(2024,($nfi|0))|0);
               $39 = __THREW__; __THREW__ = 0;
               $40 = $39&1;
               if (!($40)) {
                __THREW__ = 0;
                $41 = (invoke_iiii(574,0,($33|0),($38|0))|0);
                $42 = __THREW__; __THREW__ = 0;
                $43 = $42&1;
                if (!($43)) {
                 if (!($41)) {
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                 HEAP8[$foundCurrency>>0] = 1;
                 $44 = HEAP32[$pos>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($nfi|0));
                 $45 = __THREW__; __THREW__ = 0;
                 $46 = $45&1;
                 if (!($46)) {
                  __THREW__ = 0;
                  $47 = (invoke_ii(2024,($nfi|0))|0);
                  $48 = __THREW__; __THREW__ = 0;
                  $49 = $48&1;
                  if (!($49)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($47|0));
                   $50 = __THREW__; __THREW__ = 0;
                   $51 = $50&1;
                   if ($51) {
                    break;
                   }
                   __THREW__ = 0;
                   $52 = (invoke_ii(1816,($47|0))|0);
                   $53 = __THREW__; __THREW__ = 0;
                   $54 = $53&1;
                   if ($54) {
                    break;
                   }
                   $55 = (($52) + ($44))|0;
                   HEAP32[$pos>>2] = $55;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z101mscorlib_System_String_m_Substring_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Stringii($__this,$startIndex,$length) {
 $__this = $__this|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182520);
 __THREW__ = 0;
 invoke_v(362);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($length|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3005944>>2]|0;
    $11 = HEAP32[3005952>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($7|0),($10|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = ($startIndex|0)>(-1);
   if (!($16)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3005960>>2]|0;
    $23 = HEAP32[3005968>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($19|0),($22|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($19|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   $28 = (($__this) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)<($startIndex|0);
   if ($30) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __THREW__ = 0;
    $33 = (invoke_ii(3469,(2561352|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = HEAP32[3005976>>2]|0;
    $37 = HEAP32[3005984>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($33|0),($36|0),($37|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($33|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    // unreachable;
   }
   $42 = (($29) - ($length))|0;
   $43 = ($42|0)<($startIndex|0);
   if (!($43)) {
    $55 = ($startIndex|0)==(0);
    $56 = ($29|0)==($length|0);
    $or$cond = $55 & $56;
    if ($or$cond) {
     $$0 = $__this;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $57 = (invoke_iiii(529,($__this|0),($startIndex|0),($length|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     break;
    } else {
     $$0 = $57;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    __THREW__ = 0;
    $46 = (invoke_ii(3469,(2561352|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if (!($48)) {
     $49 = HEAP32[3005992>>2]|0;
     $50 = HEAP32[3006000>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($46|0),($49|0),($50|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if (!($52)) {
      __THREW__ = 0;
      invoke_vi(3830,($46|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if (!($54)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_String_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186648);
 __THREW__ = 0;
 $0 = (invoke_iiii(522,0,($a|0),($b|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z36mscorlib_System_Int32_m_FindExponentP22mscorlib_System_ObjectPiP22mscorlib_System_StringS1_bPP25mscorlib_System_Exception($__this,$pos,$s,$exponent,$tryParse,$exc) {
 $__this = $__this|0;
 $pos = $pos|0;
 $s = $s|0;
 $exponent = $exponent|0;
 $tryParse = $tryParse|0;
 $exc = $exc|0;
 var $$0 = 0, $$mask = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B11_0$0 = 0, $G_B17_0$0 = 0, $G_B23_0$0 = 0, $G_B29_0$0 = 0, $G_B6_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153304);
 __THREW__ = 0;
 invoke_v(363);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   HEAP32[$exponent>>2] = 0;
   __THREW__ = 0;
   (invoke_ii(2996,(1168808|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2754,(1168808|0),2)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $21 = (($4) + 16|0);
      HEAP16[$21>>1] = 101;
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       $24 = HEAP32[$9>>2]|0;
       $25 = ($24>>>0)<(2);
       if ($25) {
        __THREW__ = 0;
        $26 = (invoke_i(132)|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($26|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break;
        }
       }
       $31 = HEAP32[$4>>2]|0;
       $32 = (($31) + 92|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = (($21) + ($33)|0);
       HEAP16[$34>>1] = 69;
       $35 = HEAP32[$pos>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __THREW__ = 0;
        $38 = (invoke_iiii(538,($s|0),($4|0),($35|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($38|0)>(-1);
         if (!($41)) {
          HEAP32[$exc>>2] = 0;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $42 = (($38) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if (!($44)) {
          __THREW__ = 0;
          $45 = (invoke_ii(1816,($s|0))|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if (!($47)) {
           $48 = ($42|0)==($45|0);
           if ($48) {
            if ($tryParse) {
             $G_B6_0$0 = 0;
            } else {
             __THREW__ = 0;
             $49 = (invoke_ii(1790,0)|0);
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             } else {
              $G_B6_0$0 = $49;
             }
            }
            HEAP32[$exc>>2] = $G_B6_0$0;
            $$0 = 1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if (!($53)) {
            __THREW__ = 0;
            $54 = (invoke_iii(621,($s|0),($42|0))|0);
            $55 = __THREW__; __THREW__ = 0;
            $56 = $55&1;
            if (!($56)) {
             $57 = ($54<<16>>16)==(45);
             if ($57) {
              if ($tryParse) {
               $G_B11_0$0 = 0;
              } else {
               __THREW__ = 0;
               (invoke_ii(2996,(2635888|0))|0);
               $58 = __THREW__; __THREW__ = 0;
               $59 = $58&1;
               if ($59) {
                break;
               }
               __THREW__ = 0;
               $60 = (invoke_ii(3469,(2635888|0))|0);
               $61 = __THREW__; __THREW__ = 0;
               $62 = $61&1;
               if ($62) {
                break;
               }
               $63 = HEAP32[3003280>>2]|0;
               __THREW__ = 0;
               invoke_vii(1971,($60|0),($63|0));
               $64 = __THREW__; __THREW__ = 0;
               $65 = $64&1;
               if ($65) {
                break;
               } else {
                $G_B11_0$0 = $60;
               }
              }
              HEAP32[$exc>>2] = $G_B11_0$0;
              $$0 = 1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             invoke_vi(3799,($s|0));
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if (!($67)) {
              __THREW__ = 0;
              $68 = (invoke_iii(621,($s|0),($42|0))|0);
              $69 = __THREW__; __THREW__ = 0;
              $70 = $69&1;
              if (!($70)) {
               $71 = ($68<<16>>16)==(43);
               do {
                if ($71) {
                 $72 = (($38) + 2)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($s|0));
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if ($74) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $75 = (invoke_ii(1816,($s|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break L1;
                 }
                 $78 = ($72|0)==($75|0);
                 if (!($78)) {
                  $91 = 0;$92 = 0;$V_1$0 = $72;
                  break;
                 }
                 if ($tryParse) {
                  $G_B17_0$0 = 0;
                 } else {
                  __THREW__ = 0;
                  $79 = (invoke_ii(1790,0)|0);
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break L1;
                  } else {
                   $G_B17_0$0 = $79;
                  }
                 }
                 HEAP32[$exc>>2] = $G_B17_0$0;
                 $$0 = 1;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                } else {
                 $91 = 0;$92 = 0;$V_1$0 = $42;
                }
               } while(0);
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($s|0));
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                $122 = (invoke_ii(1816,($s|0))|0);
                $123 = __THREW__; __THREW__ = 0;
                $124 = $123&1;
                if ($124) {
                 label = 8;
                 break;
                }
                $125 = ($V_1$0|0)<($122|0);
                if (!($125)) {
                 label = 60;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($s|0));
                $126 = __THREW__; __THREW__ = 0;
                $127 = $126&1;
                if ($127) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                $82 = (invoke_iii(621,($s|0),($V_1$0|0))|0);
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if ($84) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                $85 = (invoke_iii(600,0,($82|0))|0);
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 label = 8;
                 break;
                }
                if (!($85)) {
                 label = 45;
                 break;
                }
                $93 = (___muldi3(($91|0),($92|0),10,0)|0);
                $94 = tempRet0;
                __THREW__ = 0;
                invoke_vi(3799,($s|0));
                $95 = __THREW__; __THREW__ = 0;
                $96 = $95&1;
                if ($96) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                $97 = (invoke_iii(621,($s|0),($V_1$0|0))|0);
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 label = 8;
                 break;
                }
                $100 = $97&65535;
                $101 = (($100) + 65488)|0;
                $$mask = $101 & 65535;
                $102 = (_i64Subtract(($93|0),($94|0),($$mask|0),0)|0);
                $103 = tempRet0;
                $104 = (_i64Add(($102|0),($103|0),-2147483648,0)|0);
                $105 = tempRet0;
                $106 = ($105>>>0)<(1);
                $107 = ($105|0)==(1);
                $108 = ($104>>>0)<(0);
                $109 = $107 & $108;
                $110 = $106 | $109;
                $111 = (($V_1$0) + 1)|0;
                if ($110) {
                 $91 = $102;$92 = $103;$V_1$0 = $111;
                } else {
                 label = 51;
                 break;
                }
               }
               if ((label|0) == 8) {
                $17 = ___cxa_find_matching_catch()|0;
                $18 = tempRet0;
                $lpad$phi$index = $17;$lpad$phi$index2 = $18;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               else if ((label|0) == 45) {
                if ($tryParse) {
                 $G_B23_0$0 = 0;
                } else {
                 __THREW__ = 0;
                 $88 = (invoke_ii(1790,0)|0);
                 $89 = __THREW__; __THREW__ = 0;
                 $90 = $89&1;
                 if ($90) {
                  break;
                 } else {
                  $G_B23_0$0 = $88;
                 }
                }
                HEAP32[$exc>>2] = $G_B23_0$0;
                $$0 = 1;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               else if ((label|0) == 51) {
                if ($tryParse) {
                 $G_B29_0$0 = 0;
                } else {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2635888|0))|0);
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  break;
                 }
                 __THREW__ = 0;
                 $114 = (invoke_ii(3469,(2635888|0))|0);
                 $115 = __THREW__; __THREW__ = 0;
                 $116 = $115&1;
                 if ($116) {
                  break;
                 }
                 $117 = HEAP32[3003288>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(1971,($114|0),($117|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 } else {
                  $G_B29_0$0 = $114;
                 }
                }
                HEAP32[$exc>>2] = $G_B29_0$0;
                $$0 = 1;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               else if ((label|0) == 60) {
                $128 = (_i64Subtract(0,0,($91|0),($92|0))|0);
                $129 = tempRet0;
                HEAP32[$exc>>2] = 0;
                HEAP32[$exponent>>2] = $128;
                HEAP32[$pos>>2] = $V_1$0;
                $$0 = 1;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $lpad$phi$index = $19;$lpad$phi$index2 = $20;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL10SZArrayNewP8TypeInfoj4491($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z108mscorlib_System_String_m_IndexOfAny_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32P22mscorlib_System_StringP24mscorlib_System_Char_arri($__this,$anyOf,$startIndex) {
 $__this = $__this|0;
 $anyOf = $anyOf|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183432);
 $0 = ($anyOf|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(3469,(2560584|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(2585,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      __THREW__ = 0;
      invoke_vi(3830,($3|0));
      $8 = __THREW__; __THREW__ = 0;
      $9 = $8&1;
      if (!($9)) {
       // unreachable;
      }
     }
    }
   }
  } else {
   $12 = ($startIndex|0)<(0);
   if (!($12)) {
    $13 = (($__this) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)<($startIndex|0);
    if (!($15)) {
     $25 = (($14) - ($startIndex))|0;
     __THREW__ = 0;
     $26 = (invoke_iiiii(92,($__this|0),($anyOf|0),($startIndex|0),($25|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($26|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     invoke_vi(2587,($18|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      invoke_vi(3830,($18|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z30mscorlib_System_Char_m_IsDigitP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178632);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2180696 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2180696|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2180696 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $c&65535;
    $18 = (($16) + ($17)|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19<<24>>24)==(8);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z33mscorlib_System_Int32_m_FindOtherP22mscorlib_System_ObjectPiP22mscorlib_System_StringS3_($__this,$pos,$s,$other) {
 $__this = $__this|0;
 $pos = $pos|0;
 $s = $s|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153352);
 $0 = HEAP32[$pos>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($other|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(1816,($other|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($3) + ($0))|0;
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(1816,($s|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = ($6|0)>($9|0);
     if ($12) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $15 = HEAP32[$pos>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($other|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (invoke_ii(1816,($other|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        $23 = (invoke_iiii(528,($s|0),($15|0),($18|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         $26 = (invoke_iiii(574,0,($23|0),($other|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          if (!($26)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          $29 = HEAP32[$pos>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($other|0));
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           __THREW__ = 0;
           $32 = (invoke_ii(1816,($other|0))|0);
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if (!($34)) {
            $35 = (($32) + ($29))|0;
            HEAP32[$pos>>2] = $35;
            $$0 = 1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Int32_m_ValidDigitP22mscorlib_System_Objecttb($__this,$e,$allowHex) {
 $__this = $__this|0;
 $e = $e|0;
 $allowHex = $allowHex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $e$off = 0, $e$off2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153400);
 if ($allowHex) {
  __THREW__ = 0;
  $0 = (invoke_iii(600,0,($e|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if ($2) {
   label = 4;
  } else {
   $e$off = (($e) + -65)<<16>>16;
   $3 = ($e$off&65535)<(6);
   $or$cond = $0 | $3;
   if ($or$cond) {
    $$0 = 1;
    label = 7;
   } else {
    $e$off2 = (($e) + -97)<<16>>16;
    $6 = ($e$off2&65535)<(6);
    $$0 = $6;
    label = 7;
   }
  }
 } else {
  __THREW__ = 0;
  $7 = (invoke_iii(600,0,($e|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   label = 4;
  } else {
   $$0 = $7;
   label = 7;
  }
 }
 if ((label|0) == 4) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 else if ((label|0) == 7) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z241mscorlib_System_Int32_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_Int32U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPiPP25mscorlib_System_Exception($__this,$s,$style,$fp,$tryParse,$result,$exc) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $fp = $fp|0;
 $tryParse = $tryParse|0;
 $result = $result|0;
 $exc = $exc|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy = 0, $$lobit = 0, $$lobit10 = 0, $$lobit11 = 0, $$lobit4 = 0, $$lobit5 = 0, $$lobit6 = 0, $$lobit7 = 0, $$lobit8 = 0, $$lobit9 = 0, $$not = 0, $$not25 = 0, $$not26 = 0, $$not28 = 0, $$not31 = 0, $$not32 = 0, $$not34 = 0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0.0, $414 = 0.0, $415 = 0.0, $416 = 0.0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$1 = 0, $V_12 = 0, $V_13$0$off0 = 0, $V_14 = 0, $V_15 = 0, $V_16 = 0, $V_17$0 = 0;
 var $V_17$1 = 0, $V_17$2 = 0, $V_17$3 = 0, $V_17$4 = 0, $V_18$0 = 0, $V_18$1 = 0, $V_18$2 = 0, $V_19$0$off0 = 0, $V_19$1$off0 = 0, $V_20$0 = 0, $V_22 = 0, $_stackTraceSentry = 0, $brmerge = 0, $brmerge27 = 0, $brmerge29 = 0, $brmerge30 = 0, $brmerge33 = 0, $brmerge35 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $lpad$phi50$index = 0, $lpad$phi50$index7 = 0, $or$cond = 0, $or$cond36 = 0, $or$cond54 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $V_12 = sp + 4|0;
 $V_14 = sp + 22|0;
 $V_15 = sp + 21|0;
 $V_16 = sp + 20|0;
 $V_22 = sp + 12|0;
 $0 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153496);
 HEAP32[$V_12>>2] = 0;
 HEAP8[$V_14>>0] = 0;
 HEAP8[$V_15>>0] = 0;
 HEAP8[$V_16>>0] = 0;
 HEAP32[$V_22>>2] = 0;
 __THREW__ = 0;
 invoke_v(364);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 4;
  } else {
   HEAP32[$result>>2] = 0;
   HEAP32[$exc>>2] = 0;
   $3 = ($s|0)==(0|0);
   if ($3) {
    if ($tryParse) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    invoke_vi(2585,($10|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 4;
     break;
    }
    HEAP32[$exc>>2] = $10;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 4;
   } else {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($s|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 4;
    } else {
     $20 = ($17|0)==(0);
     if ($20) {
      if ($tryParse) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      $21 = (invoke_ii(1790,0)|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 4;
       break;
      }
      HEAP32[$exc>>2] = $21;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $24 = ($fp|0)==(0|0);
     if ($24) {
      label = 24;
     } else {
      HEAP32[$0>>2] = 2271128;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $25 = (invoke_iii(772,0,($$byval_copy|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($fp|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $30 = (invoke_iiii(1666,(2606440|0),($fp|0),($25|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2348608|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_iii(2755,($30|0),(2348608|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 4;
       break;
      }
      $38 = ($35|0)==(0|0);
      if ($38) {
       label = 24;
      } else {
       $V_0$1 = $35;
      }
     }
     if ((label|0) == 24) {
      __THREW__ = 0;
      $39 = (invoke_ii(2405,(0|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(1178,(0|0),($39|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($42|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2730,(2330184|0),($42|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      $V_0$1 = $47;
     }
     __THREW__ = 0;
     $50 = (invoke_iiiii(80,0,($style|0),($tryParse|0),($exc|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 4;
     } else {
      if (!($50)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $$lobit = $style >>> 8;
      $$lobit4 = $style & 512;
      $53 = ($$lobit4|0)!=(0);
      $$lobit5 = $style & 64;
      $54 = ($$lobit5|0)==(0);
      $$lobit6 = $style & 32;
      $55 = ($$lobit6|0)==(0);
      $$lobit7 = $style & 16;
      $56 = ($$lobit7|0)==(0);
      $$lobit8 = $style & 8;
      $57 = ($$lobit8|0)!=(0);
      $$lobit9 = $style & 4;
      $58 = ($$lobit9|0)!=(0);
      $$lobit10 = $style >>> 1;
      $59 = $style & 1;
      $60 = ($59|0)!=(0);
      $$lobit11 = $style & 128;
      $61 = ($$lobit11|0)==(0);
      HEAP32[$V_12>>2] = 0;
      if ($60) {
       __THREW__ = 0;
       $62 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),1,($tryParse|0),($exc|0))|0);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 4;
        break;
       }
       if (!($62)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      HEAP8[$V_14>>0] = 0;
      HEAP8[$V_15>>0] = 0;
      HEAP8[$V_16>>0] = 0;
      do {
       if ($56) {
        $132 = 0;$V_13$0$off0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($s|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break L1;
        }
        $67 = HEAP32[$V_12>>2]|0;
        __THREW__ = 0;
        $68 = (invoke_iii(621,($s|0),($67|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 4;
         break L1;
        }
        $71 = ($68<<16>>16)==(40);
        if ($71) {
         HEAP8[$V_15>>0] = 1;
         HEAP8[$V_14>>0] = 1;
         $72 = HEAP32[$V_12>>2]|0;
         $73 = (($72) + 1)|0;
         HEAP32[$V_12>>2] = $73;
         if ($60) {
          __THREW__ = 0;
          $74 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),1,($tryParse|0),($exc|0))|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 4;
           break L1;
          }
          if ($74) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $79 = (invoke_ii(2029,($V_0$1|0))|0);
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if ($81) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($79|0));
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $84 = (invoke_ii(1816,($79|0))|0);
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          label = 4;
          break L1;
         }
         $89 = HEAP32[$V_12>>2]|0;
         __THREW__ = 0;
         $90 = (invoke_iiii(528,($s|0),($89|0),($84|0))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $95 = (invoke_ii(2029,($V_0$1|0))|0);
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $98 = (invoke_iiii(574,0,($90|0),($95|0))|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          label = 4;
          break L1;
         }
         if ($98) {
          if ($tryParse) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $101 = (invoke_ii(1790,0)|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           label = 4;
           break L1;
          }
          HEAP32[$exc>>2] = $101;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $106 = (invoke_ii(2044,($V_0$1|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($106|0));
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $111 = (invoke_ii(1816,($106|0))|0);
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if ($113) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $114 = __THREW__; __THREW__ = 0;
         $115 = $114&1;
         if ($115) {
          label = 4;
          break L1;
         }
         $116 = HEAP32[$V_12>>2]|0;
         __THREW__ = 0;
         $117 = (invoke_iiii(528,($s|0),($116|0),($111|0))|0);
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $120 = __THREW__; __THREW__ = 0;
         $121 = $120&1;
         if ($121) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $122 = (invoke_ii(2044,($V_0$1|0))|0);
         $123 = __THREW__; __THREW__ = 0;
         $124 = $123&1;
         if ($124) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $125 = (invoke_iiii(574,0,($117|0),($122|0))|0);
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if ($127) {
          label = 4;
          break L1;
         }
         if (!($125)) {
          $132 = 1;$V_13$0$off0 = 1;
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $128 = (invoke_ii(1790,0)|0);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $128;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         $132 = 0;$V_13$0$off0 = 0;
        }
       }
      } while(0);
      do {
       if ($58) {
        $131 = ($132<<24>>24)==(0);
        if ($131) {
         __THREW__ = 0;
         invoke_viiiiii(50,0,($V_12|0),($s|0),($V_0$1|0),($V_15|0),($V_14|0));
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          label = 4;
          break L1;
         }
         $135 = HEAP8[$V_15>>0]|0;
         $136 = ($135<<24>>24)==(0);
         if ($136) {
          $152 = 0;$160 = 0;
         } else {
          if ($60) {
           __THREW__ = 0;
           $137 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),1,($tryParse|0),($exc|0))|0);
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            label = 4;
            break L1;
           }
           if (!($137)) {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
          $140 = $$lobit & 1;
          $141 = ($140|0)==(0);
          if ($141) {
           $152 = 0;$160 = $135;
          } else {
           __THREW__ = 0;
           invoke_viiiii(45,0,($V_12|0),($s|0),($V_0$1|0),($V_16|0));
           $142 = __THREW__; __THREW__ = 0;
           $143 = $142&1;
           if ($143) {
            label = 4;
            break L1;
           }
           $144 = HEAP8[$V_16>>0]|0;
           $145 = ($144<<24>>24)==(0);
           $$not = $60 ^ 1;
           $brmerge = $145 | $$not;
           if ($brmerge) {
            $152 = $144;$160 = $135;
           } else {
            __THREW__ = 0;
            $146 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $147 = __THREW__; __THREW__ = 0;
            $148 = $147&1;
            if ($148) {
             label = 4;
             break L1;
            }
            if ($146) {
             $152 = $144;$160 = $135;
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        } else {
         $152 = 0;$160 = 1;
        }
       } else {
        $152 = 0;$160 = $132;
       }
      } while(0);
      $149 = $$lobit & 1;
      $150 = ($149|0)!=(0);
      $151 = ($152<<24>>24)==(0);
      $or$cond = $150 & $151;
      do {
       if ($or$cond) {
        __THREW__ = 0;
        invoke_viiiii(45,0,($V_12|0),($s|0),($V_0$1|0),($V_16|0));
        $153 = __THREW__; __THREW__ = 0;
        $154 = $153&1;
        if ($154) {
         label = 4;
         break L1;
        }
        $155 = HEAP8[$V_16>>0]|0;
        $156 = ($155<<24>>24)==(0);
        if ($156) {
         $317 = $160;$430 = 0;
        } else {
         if ($60) {
          __THREW__ = 0;
          $157 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),1,($tryParse|0),($exc|0))|0);
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           label = 4;
           break L1;
          }
          if (!($157)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         $$not25 = ($160<<24>>24)!=(0);
         $$not26 = $58 ^ 1;
         $brmerge27 = $$not25 | $$not26;
         if ($brmerge27) {
          $317 = $160;$430 = $155;
         } else {
          __THREW__ = 0;
          invoke_viiiiii(50,0,($V_12|0),($s|0),($V_0$1|0),($V_15|0),($V_14|0));
          $161 = __THREW__; __THREW__ = 0;
          $162 = $161&1;
          if ($162) {
           label = 4;
           break L1;
          }
          $163 = HEAP8[$V_15>>0]|0;
          $164 = ($163<<24>>24)==(0);
          $$not28 = $60 ^ 1;
          $brmerge29 = $164 | $$not28;
          if ($brmerge29) {
           $317 = $163;$430 = $155;
          } else {
           __THREW__ = 0;
           $165 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),1,($tryParse|0),($exc|0))|0);
           $166 = __THREW__; __THREW__ = 0;
           $167 = $166&1;
           if ($167) {
            label = 4;
            break L1;
           }
           if ($165) {
            $317 = $163;$430 = $155;
            break;
           } else {
            $$0 = 0;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       } else {
        $317 = $160;$430 = $152;
       }
      } while(0);
      HEAP32[$V_22>>2] = 0;
      $V_17$0 = 0;$V_18$0 = 0;$V_19$0$off0 = 0;
      L120: while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $168 = __THREW__; __THREW__ = 0;
       $169 = $168&1;
       if ($169) {
        label = 3;
        break;
       }
       $170 = HEAP32[$V_12>>2]|0;
       __THREW__ = 0;
       $171 = (invoke_iii(621,($s|0),($170|0))|0);
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       if ($173) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $174 = (invoke_iiii(456,0,($171|0),($53|0))|0);
       $175 = __THREW__; __THREW__ = 0;
       $176 = $175&1;
       if ($176) {
        label = 3;
        break;
       }
       do {
        if ($174) {
         $193 = (($V_18$0) + 1)|0;
         if (!($53)) {
          if ($V_19$0$off0) {
           $236 = HEAP32[$V_12>>2]|0;
           $237 = (($236) + 1)|0;
           HEAP32[$V_12>>2] = $237;
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $238 = __THREW__; __THREW__ = 0;
           $239 = $238&1;
           if ($239) {
            label = 3;
            break L120;
           }
           __THREW__ = 0;
           $240 = (invoke_iii(621,($s|0),($236|0))|0);
           $241 = __THREW__; __THREW__ = 0;
           $242 = $241&1;
           if ($242) {
            label = 3;
            break L120;
           }
           $243 = ($240<<16>>16)==(48);
           if ($243) {
            $V_17$1 = $V_17$0;$V_18$1 = $193;$V_19$1$off0 = 1;
            break;
           } else {
            label = 127;
            break L120;
           }
          }
          $252 = ($V_17$0*10)|0;
          $253 = HEAP32[$V_12>>2]|0;
          $254 = ($253|0)==(2147483647);
          if ($254) {
           label = 133;
           break L120;
          }
          $274 = (($253) + 1)|0;
          HEAP32[$V_12>>2] = $274;
          __THREW__ = 0;
          invoke_vi(3799,($s|0));
          $275 = __THREW__; __THREW__ = 0;
          $276 = $275&1;
          if ($276) {
           label = 136;
           break L120;
          }
          __THREW__ = 0;
          $277 = (invoke_iii(621,($s|0),($253|0))|0);
          $278 = __THREW__; __THREW__ = 0;
          $279 = $278&1;
          if ($279) {
           label = 136;
           break L120;
          }
          $280 = $277&65535;
          $281 = (($280) + 65488)|0;
          $282 = $281 & 65535;
          $283 = (($252) - ($282))|0;
          $V_17$1 = $283;$V_18$1 = $193;$V_19$1$off0 = 0;
          break;
         }
         $194 = HEAP32[$V_12>>2]|0;
         $195 = (($194) + 1)|0;
         HEAP32[$V_12>>2] = $195;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $196 = __THREW__; __THREW__ = 0;
         $197 = $196&1;
         if ($197) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $198 = (invoke_iii(621,($s|0),($194|0))|0);
         $199 = __THREW__; __THREW__ = 0;
         $200 = $199&1;
         if ($200) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $201 = (invoke_iii(600,0,($198|0))|0);
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          label = 3;
          break L120;
         }
         do {
          if ($201) {
           $204 = $198&65535;
           $205 = (($204) + 65488)|0;
           $206 = $205 & 65535;
           $V_20$0 = $206;
          } else {
           __THREW__ = 0;
           $207 = (invoke_iii(602,0,($198|0))|0);
           $208 = __THREW__; __THREW__ = 0;
           $209 = $208&1;
           if ($209) {
            label = 3;
            break L120;
           }
           $210 = $198&65535;
           if ($207) {
            $211 = (($210) + 65439)|0;
            $212 = $211 & 65535;
            $213 = (($212) + 10)|0;
            $V_20$0 = $213;
            break;
           } else {
            $214 = (($210) + 65471)|0;
            $215 = $214 & 65535;
            $216 = (($215) + 10)|0;
            $V_20$0 = $216;
            break;
           }
          }
         } while(0);
         if ($tryParse) {
          $217 = ($V_17$0>>>0)>(268435455);
          if ($217) {
           $$0 = 0;
           label = 226;
           break L120;
          }
          $218 = $V_17$0 << 4;
          $219 = (($V_20$0) + ($218))|0;
          $V_17$1 = $219;$V_18$1 = $193;$V_19$1$off0 = $V_19$0$off0;
          break;
         } else {
          $220 = $V_17$0 << 4;
          $221 = ($220|0)<(0);
          $222 = $221 << 31 >> 31;
          $223 = (_i64Add(($V_20$0|0),0,($220|0),($222|0))|0);
          $224 = tempRet0;
          $225 = ($224|0)>(0);
          $226 = ($224|0)==(0);
          $227 = ($223>>>0)>(2147483647);
          $228 = $226 & $227;
          $229 = $225 | $228;
          if ($229) {
           label = 119;
           break L120;
          }
          $235 = (($V_20$0) + ($220))|0;
          $V_17$1 = $235;$V_18$1 = $193;$V_19$1$off0 = $V_19$0$off0;
          break;
         }
        } else {
         if (!($54)) {
          __THREW__ = 0;
          invoke_vi(3799,($V_0$1|0));
          $177 = __THREW__; __THREW__ = 0;
          $178 = $177&1;
          if ($178) {
           label = 3;
           break L120;
          }
          __THREW__ = 0;
          $179 = (invoke_ii(2032,($V_0$1|0))|0);
          $180 = __THREW__; __THREW__ = 0;
          $181 = $180&1;
          if ($181) {
           label = 3;
           break L120;
          }
          __THREW__ = 0;
          $182 = (invoke_iiiii(81,0,($V_12|0),($s|0),($179|0))|0);
          $183 = __THREW__; __THREW__ = 0;
          $184 = $183&1;
          if ($184) {
           label = 3;
           break L120;
          }
          if ($182) {
           $V_17$1 = $V_17$0;$V_18$1 = $V_18$0;$V_19$1$off0 = $V_19$0$off0;
           break;
          }
         }
         $brmerge30 = $V_19$0$off0 | $55;
         if ($brmerge30) {
          $V_17$2 = $V_17$0;$V_18$2 = $V_18$0;
          label = 155;
          break L120;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $185 = __THREW__; __THREW__ = 0;
         $186 = $185&1;
         if ($186) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $187 = (invoke_ii(2031,($V_0$1|0))|0);
         $188 = __THREW__; __THREW__ = 0;
         $189 = $188&1;
         if ($189) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $190 = (invoke_iiiii(81,0,($V_12|0),($s|0),($187|0))|0);
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          label = 3;
          break L120;
         }
         if ($190) {
          $V_17$1 = $V_17$0;$V_18$1 = $V_18$0;$V_19$1$off0 = 1;
         } else {
          $V_17$2 = $V_17$0;$V_18$2 = $V_18$0;
          label = 155;
          break L120;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $300 = __THREW__; __THREW__ = 0;
       $301 = $300&1;
       if ($301) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $302 = (invoke_ii(1816,($s|0))|0);
       $303 = __THREW__; __THREW__ = 0;
       $304 = $303&1;
       if ($304) {
        label = 3;
        break;
       }
       $305 = HEAP32[$V_12>>2]|0;
       $306 = ($305|0)<($302|0);
       if ($306) {
        $V_17$0 = $V_17$1;$V_18$0 = $V_18$1;$V_19$0$off0 = $V_19$1$off0;
       } else {
        $V_17$2 = $V_17$1;$V_18$2 = $V_18$1;
        label = 155;
        break;
       }
      }
      if ((label|0) == 3) {
       $4 = ___cxa_find_matching_catch()|0;
       $5 = tempRet0;
       $lpad$phi$index = $4;$lpad$phi$index2 = $5;
       break;
      }
      else if ((label|0) == 119) {
       __THREW__ = 0;
       $230 = (invoke_i(133)|0);
       $231 = __THREW__; __THREW__ = 0;
       $232 = $231&1;
       if ($232) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3830,($230|0));
       $233 = __THREW__; __THREW__ = 0;
       $234 = $233&1;
       if ($234) {
        label = 4;
        break;
       }
       // unreachable;
      }
      else if ((label|0) == 127) {
       if ($tryParse) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2635888|0))|0);
       $244 = __THREW__; __THREW__ = 0;
       $245 = $244&1;
       if ($245) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $246 = (invoke_ii(3469,(2635888|0))|0);
       $247 = __THREW__; __THREW__ = 0;
       $248 = $247&1;
       if ($248) {
        label = 4;
        break;
       }
       $249 = HEAP32[3003472>>2]|0;
       __THREW__ = 0;
       invoke_vii(1971,($246|0),($249|0));
       $250 = __THREW__; __THREW__ = 0;
       $251 = $250&1;
       if ($251) {
        label = 4;
        break;
       }
       HEAP32[$exc>>2] = $246;
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      else if ((label|0) == 133) {
       __THREW__ = 0;
       $255 = (invoke_i(133)|0);
       $256 = __THREW__; __THREW__ = 0;
       $257 = $256&1;
       if (!($257)) {
        __THREW__ = 0;
        invoke_vi(3830,($255|0));
        $258 = __THREW__; __THREW__ = 0;
        $259 = $258&1;
        if (!($259)) {
         // unreachable;
        }
       }
       $262 = ___cxa_find_matching_catch(348288|0)|0;
       $263 = tempRet0;
       $lpad$phi50$index = $262;$lpad$phi50$index7 = $263;
      }
      else if ((label|0) == 136) {
       $260 = ___cxa_find_matching_catch(348288|0)|0;
       $261 = tempRet0;
       $lpad$phi50$index = $260;$lpad$phi50$index7 = $261;
      }
      else if ((label|0) == 155) {
       $307 = ($V_18$2|0)==(0);
       if ($307) {
        if ($tryParse) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        $308 = (invoke_ii(1790,0)|0);
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        if ($310) {
         label = 4;
         break;
        }
        HEAP32[$exc>>2] = $308;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       if (!($61)) {
        __THREW__ = 0;
        $311 = (invoke_iiiiiii(51,0,($V_12|0),($s|0),($V_22|0),($tryParse|0),($exc|0))|0);
        $312 = __THREW__; __THREW__ = 0;
        $313 = $312&1;
        if ($313) {
         label = 4;
         break;
        }
        if ($311) {
         $314 = HEAP32[$exc>>2]|0;
         $315 = ($314|0)==(0|0);
         if (!($315)) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
       $316 = ($317<<24>>24)==(0);
       $or$cond54 = $57 & $316;
       do {
        if ($or$cond54) {
         __THREW__ = 0;
         invoke_viiiiii(50,0,($V_12|0),($s|0),($V_0$1|0),($V_15|0),($V_14|0));
         $318 = __THREW__; __THREW__ = 0;
         $319 = $318&1;
         if ($319) {
          label = 4;
          break L1;
         }
         $320 = HEAP8[$V_15>>0]|0;
         $321 = ($320<<24>>24)==(0);
         if ($321) {
          $431 = 0;
          label = 172;
         } else {
          $322 = $$lobit10 & 1;
          $323 = ($322|0)==(0);
          do {
           if (!($323)) {
            __THREW__ = 0;
            $324 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $325 = __THREW__; __THREW__ = 0;
            $326 = $325&1;
            if ($326) {
             label = 4;
             break L1;
            }
            if ($324) {
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          } while(0);
          if (!($150)) {
           break;
          }
          __THREW__ = 0;
          invoke_viiiii(45,0,($V_12|0),($s|0),($V_0$1|0),($V_16|0));
          $327 = __THREW__; __THREW__ = 0;
          $328 = $327&1;
          if ($328) {
           label = 4;
           break L1;
          }
          $$pre = HEAP8[$V_16>>0]|0;
          $330 = $$pre;$340 = $320;
          label = 173;
         }
        } else {
         $431 = $317;
         label = 172;
        }
       } while(0);
       if ((label|0) == 172) {
        if ($150) {
         $330 = $430;$340 = $431;
         label = 173;
        }
       }
       do {
        if ((label|0) == 173) {
         $329 = ($330<<24>>24)==(0);
         if ($329) {
          __THREW__ = 0;
          invoke_viiiii(45,0,($V_12|0),($s|0),($V_0$1|0),($V_16|0));
          $331 = __THREW__; __THREW__ = 0;
          $332 = $331&1;
          if ($332) {
           label = 4;
           break L1;
          }
          $333 = HEAP8[$V_16>>0]|0;
          $334 = ($333<<24>>24)==(0);
          if ($334) {
           break;
          }
          $335 = $$lobit10 & 1;
          $336 = ($335|0)==(0);
          do {
           if (!($336)) {
            __THREW__ = 0;
            $337 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $338 = __THREW__; __THREW__ = 0;
            $339 = $338&1;
            if ($339) {
             label = 4;
             break L1;
            }
            if ($337) {
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          } while(0);
          $$not31 = ($340<<24>>24)!=(0);
          $$not32 = $57 ^ 1;
          $brmerge33 = $$not31 | $$not32;
          if ($brmerge33) {
           break;
          }
          __THREW__ = 0;
          invoke_viiiiii(50,0,($V_12|0),($s|0),($V_0$1|0),($V_15|0),($V_14|0));
          $341 = __THREW__; __THREW__ = 0;
          $342 = $341&1;
          if ($342) {
           label = 4;
           break L1;
          }
         }
        }
       } while(0);
       $343 = $$lobit10 & 1;
       $344 = ($343|0)!=(0);
       do {
        if ($344) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $345 = __THREW__; __THREW__ = 0;
         $346 = $345&1;
         if ($346) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $347 = (invoke_ii(1816,($s|0))|0);
         $348 = __THREW__; __THREW__ = 0;
         $349 = $348&1;
         if ($349) {
          label = 4;
          break L1;
         }
         $350 = HEAP32[$V_12>>2]|0;
         $351 = ($350|0)<($347|0);
         if (!($351)) {
          break;
         }
         __THREW__ = 0;
         $352 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),0,($tryParse|0),($exc|0))|0);
         $353 = __THREW__; __THREW__ = 0;
         $354 = $353&1;
         if ($354) {
          label = 4;
          break L1;
         }
         if ($352) {
          break;
         } else {
          $$0 = 0;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       L235: do {
        if ($V_13$0$off0) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $355 = __THREW__; __THREW__ = 0;
         $356 = $355&1;
         if ($356) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $357 = (invoke_ii(1816,($s|0))|0);
         $358 = __THREW__; __THREW__ = 0;
         $359 = $358&1;
         if ($359) {
          label = 4;
          break L1;
         }
         $360 = HEAP32[$V_12>>2]|0;
         $361 = ($360|0)<($357|0);
         do {
          if ($361) {
           $362 = (($360) + 1)|0;
           HEAP32[$V_12>>2] = $362;
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $363 = __THREW__; __THREW__ = 0;
           $364 = $363&1;
           if ($364) {
            label = 4;
            break L1;
           }
           __THREW__ = 0;
           $365 = (invoke_iii(621,($s|0),($360|0))|0);
           $366 = __THREW__; __THREW__ = 0;
           $367 = $366&1;
           if ($367) {
            label = 4;
            break L1;
           }
           $368 = ($365<<16>>16)==(41);
           if (!($368)) {
            break;
           }
           if (!($344)) {
            break L235;
           }
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $372 = __THREW__; __THREW__ = 0;
           $373 = $372&1;
           if ($373) {
            label = 4;
            break L1;
           }
           __THREW__ = 0;
           $374 = (invoke_ii(1816,($s|0))|0);
           $375 = __THREW__; __THREW__ = 0;
           $376 = $375&1;
           if ($376) {
            label = 4;
            break L1;
           }
           $377 = HEAP32[$V_12>>2]|0;
           $378 = ($377|0)<($374|0);
           if (!($378)) {
            break L235;
           }
           __THREW__ = 0;
           $379 = (invoke_iiiiiii(50,0,($V_12|0),($s|0),0,($tryParse|0),($exc|0))|0);
           $380 = __THREW__; __THREW__ = 0;
           $381 = $380&1;
           if ($381) {
            label = 4;
            break L1;
           }
           if ($379) {
            break L235;
           } else {
            $$0 = 0;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         } while(0);
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $369 = (invoke_ii(1790,0)|0);
         $370 = __THREW__; __THREW__ = 0;
         $371 = $370&1;
         if ($371) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $369;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $382 = __THREW__; __THREW__ = 0;
       $383 = $382&1;
       if ($383) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $384 = (invoke_ii(1816,($s|0))|0);
       $385 = __THREW__; __THREW__ = 0;
       $386 = $385&1;
       if ($386) {
        label = 4;
        break;
       }
       $387 = HEAP32[$V_12>>2]|0;
       $388 = ($387|0)<($384|0);
       do {
        if ($388) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $389 = __THREW__; __THREW__ = 0;
         $390 = $389&1;
         if ($390) {
          label = 4;
          break L1;
         }
         $391 = HEAP32[$V_12>>2]|0;
         __THREW__ = 0;
         $392 = (invoke_iii(621,($s|0),($391|0))|0);
         $393 = __THREW__; __THREW__ = 0;
         $394 = $393&1;
         if ($394) {
          label = 4;
          break L1;
         }
         $395 = ($392<<16>>16)==(0);
         if ($395) {
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $396 = (invoke_ii(1790,0)|0);
         $397 = __THREW__; __THREW__ = 0;
         $398 = $397&1;
         if ($398) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $396;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       $399 = HEAP8[$V_14>>0]|0;
       $$not34 = ($399<<24>>24)!=(0);
       $brmerge35 = $$not34 | $53;
       do {
        if ($brmerge35) {
         $V_17$3 = $V_17$2;
        } else {
         if (!($tryParse)) {
          $410 = (0 - ($V_17$2))|0;
          $V_17$3 = $410;
          break;
         }
         $400 = ($V_17$2|0)<(0);
         $401 = $400 << 31 >> 31;
         $402 = (_i64Subtract(-2147483648,0,($V_17$2|0),($401|0))|0);
         $403 = tempRet0;
         $404 = ($403>>>0)<(1);
         $405 = ($403|0)==(1);
         $406 = ($402>>>0)<(0);
         $407 = $405 & $406;
         $408 = $404 | $407;
         if ($408) {
          $409 = (0 - ($V_17$2))|0;
          $V_17$3 = $409;
          break;
         } else {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       } while(0);
       $411 = HEAP32[$V_22>>2]|0;
       $412 = ($411|0)<(1);
       do {
        if ($412) {
         $V_17$4 = $V_17$3;
        } else {
         $413 = (+($411|0));
         $414 = (+Math_pow(10.0,(+$413)));
         $415 = (+($V_17$3|0));
         $416 = $415 * $414;
         $417 = $416 < -2147483648.0;
         $418 = !($416 <= 2147483647.0);
         $or$cond36 = $417 | $418;
         if (!($or$cond36)) {
          $427 = (~~(($416)));
          $V_17$4 = $427;
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2635888|0))|0);
         $419 = __THREW__; __THREW__ = 0;
         $420 = $419&1;
         if ($420) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $421 = (invoke_ii(3469,(2635888|0))|0);
         $422 = __THREW__; __THREW__ = 0;
         $423 = $422&1;
         if ($423) {
          label = 4;
          break L1;
         }
         $424 = HEAP32[3003488>>2]|0;
         __THREW__ = 0;
         invoke_vii(1971,($421|0),($424|0));
         $425 = __THREW__; __THREW__ = 0;
         $426 = $425&1;
         if ($426) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $421;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       HEAP32[$result>>2] = $V_17$4;
       $$0 = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      else if ((label|0) == 226) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $264 = (_llvm_eh_typeid_for((348288|0))|0);
      $265 = ($lpad$phi50$index7|0)==($264|0);
      if (!($265)) {
       $$01 = $lpad$phi50$index;$$02 = $lpad$phi50$index7;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$01|0);
       // unreachable;
      }
      $266 = (___cxa_begin_catch(($lpad$phi50$index|0))|0);
      $267 = HEAP32[$266>>2]|0;
      $268 = HEAP32[$267>>2]|0;
      __THREW__ = 0;
      $269 = (invoke_iii(2727,(2635888|0),($268|0))|0);
      $270 = __THREW__; __THREW__ = 0;
      $271 = $270&1;
      do {
       if (!($271)) {
        if (!($269)) {
         $288 = (___cxa_allocate_exception(4)|0);
         $289 = HEAP32[$266>>2]|0;
         HEAP32[$288>>2] = $289;
         __THREW__ = 0;
         invoke_viii(1567,($288|0),(348288|0),(0|0));
         $290 = __THREW__; __THREW__ = 0;
         $291 = $290&1;
         if ($291) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        invoke_v(66);
        $272 = __THREW__; __THREW__ = 0;
        $273 = $272&1;
        if ($273) {
         label = 4;
         break L1;
        }
        if ($tryParse) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2635888|0))|0);
        $292 = __THREW__; __THREW__ = 0;
        $293 = $292&1;
        if ($293) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        $294 = (invoke_ii(3469,(2635888|0))|0);
        $295 = __THREW__; __THREW__ = 0;
        $296 = $295&1;
        if ($296) {
         label = 4;
         break L1;
        }
        $297 = HEAP32[3003480>>2]|0;
        __THREW__ = 0;
        invoke_vii(1971,($294|0),($297|0));
        $298 = __THREW__; __THREW__ = 0;
        $299 = $298&1;
        if ($299) {
         label = 4;
         break L1;
        }
        HEAP32[$exc>>2] = $294;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $284 = ___cxa_find_matching_catch()|0;
      $285 = tempRet0;
      __THREW__ = 0;
      invoke_v(66);
      $286 = __THREW__; __THREW__ = 0;
      $287 = $286&1;
      if ($287) {
       $428 = ___cxa_find_matching_catch(0|0)|0;
       $429 = tempRet0;
       ___clang_call_terminate($428);
       // unreachable;
      } else {
       $$01 = $284;$$02 = $285;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$01|0);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $lpad$phi$index = $6;$lpad$phi$index2 = $7;
 }
 $$01 = $lpad$phi$index;$$02 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Type_m_GetTypeFromHandleP22mscorlib_System_Object33mscorlib_System_RuntimeTypeHandle($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235600);
 __THREW__ = 0;
 $3 = (invoke_ii(1914,($handle|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2210080|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = HEAP32[((2210080 + 80|0))>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $3;
   HEAP32[$1>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   $10 = (invoke_iiii(643,0,($$byval_copy|0),($$byval_copy2|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    if ($10) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $15 = (invoke_ii(1914,($handle|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     HEAP32[$2>>2] = $15;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     $18 = (invoke_iii(768,0,($$byval_copy2|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $$0 = $18;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo4494($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z30mscorlib_System_Char_m_IsLowerP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178728);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2180696 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2180696|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2180696 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $c&65535;
    $18 = (($16) + ($17)|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19<<24>>24)==(1);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Int32_m_Parse_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153544);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiiiii(84,0,($s|0),0,($V_1|0),($V_0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  if ($0) {
   $8 = HEAP32[$V_1>>2]|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
  $5 = HEAP32[$V_0>>2]|0;
  __THREW__ = 0;
  invoke_vi(3830,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   // unreachable;
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Int32_m_ToString_mscorlib_System_StringPi($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153640);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iiii(1233,(0|0),($0|0),(0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z87mscorlib_System_Int32_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPiP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153688);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iiii(1233,(0|0),($0|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Int32_m_ToString_mscorlib_System_String_mscorlib_System_StringPiP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153736);
 __THREW__ = 0;
 $0 = (invoke_iiii(460,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z110mscorlib_System_Int32_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPiP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2153784);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iiiii(194,(0|0),($format|0),($0|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits17VoidPointerTraitsE6InvokeEPFhPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP8[$ret>>0] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits17VoidPointerTraitsE6InvokeEPFtPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP16[$ret>>1] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits17VoidPointerTraitsE6InvokeEPF24mscorlib_System_DateTimePvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits17VoidPointerTraitsE6InvokeEPF23mscorlib_System_DecimalPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits17VoidPointerTraitsE6InvokeEPFdPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$0));
 HEAPF64[$ret>>3] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits17VoidPointerTraitsE6InvokeEPFsPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP16[$ret>>1] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits17VoidPointerTraitsE6InvokeEPFxPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 $2 = tempRet0;
 $3 = $ret;
 $4 = $3;
 HEAP32[$4>>2] = $1;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits17VoidPointerTraitsE6InvokeEPFaPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP8[$ret>>0] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits17VoidPointerTraitsE6InvokeEPFfPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$0)));
 HEAPF32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits17VoidPointerTraitsE6InvokeEPFtPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP16[$ret>>1] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits17VoidPointerTraitsE6InvokeEPFjPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits17VoidPointerTraitsE6InvokeEPFyPvS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 $2 = tempRet0;
 $3 = $ret;
 $4 = $3;
 HEAP32[$4>>2] = $1;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker4I29mscorlib_System_BooleanTraitsS0_17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFbPvbS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$2,$4,$7,$9)|0);
 $11 = $10&1;
 HEAP8[$ret>>0] = $11;
 $12 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN12FuncInvoker4I29mscorlib_System_BooleanTraits17VoidPointerTraitsS0_S1_S1_E6InvokeEPFbPvS3_bS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$4,$6,$8)|0);
 $10 = $9&1;
 HEAP8[$ret>>0] = $10;
 $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_E6InvokeEPFiPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS0_17VoidPointerTraitsE6InvokeEPFbPvibS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$5,$7)|0);
 $9 = $8&1;
 HEAP8[$ret>>0] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S0_S0_S1_E6InvokeEPFbPvS3_S3_bbS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$2,$6,$10,$12)|0);
 $14 = $13&1;
 HEAP8[$ret>>0] = $14;
 $15 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($15|0);
}
function __ZN14ActionInvoker5I17VoidPointerTraitsS0_S0_S0_S0_E6InvokeEPFvPvS2_S2_S2_S2_S2_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$2,$4,$6,$8);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I17VoidPointerTraitsS0_S0_S0_E6InvokeEPFvPvS2_S2_S2_S2_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$2,$4,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_S0_S1_E6InvokeEPFbPvS3_S3_S3_bS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$2,$4,$8,$10)|0);
 $12 = $11&1;
 HEAP8[$ret>>0] = $12;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS0_E6InvokeEPFbPvtbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$5)|0);
 $7 = $6&1;
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker6I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_S1_E6InvokeEPFbPvS4_iS4_bS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$5,$9,$11,$13)|0);
 $15 = $14&1;
 HEAP8[$ret>>0] = $15;
 $16 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($16|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_E6InvokeEPFiPvS3_iS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 HEAP32[$ret>>2] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z52mscorlib_System_Int32_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_IFormattable_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_IConvertible_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_IComparable_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z45mscorlib_System_SerializableAttribute_m__ctorP37mscorlib_System_SerializableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2158392);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z68mscorlib_System_SerializableAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,4124);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2158856);
 $0 = (($__this) + 13|0);
 $1 = $value&1;
 HEAP8[$0>>0] = $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2158760);
 $0 = (($__this) + 12|0);
 $1 = $value&1;
 HEAP8[$0>>0] = $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_AttributeUsageAttribute_m_get_AllowMultipleP39mscorlib_System_AttributeUsageAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2158712);
 $0 = (($__this) + 12|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z55mscorlib_System_AttributeUsageAttribute_m_get_InheritedP39mscorlib_System_AttributeUsageAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2158808);
 $0 = (($__this) + 13|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z70mscorlib_System_AttributeUsageAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,4);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,5597);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_Int64_m_System_IConvertible_ToBooleanPxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160104);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(968,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Int64_m_System_IConvertible_ToBytePxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160152);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(976,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Int64_m_System_IConvertible_ToCharPxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160200);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(988,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Int64_m_System_IConvertible_ToDateTimePxP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160248);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viiii(178,($agg$result|0),(0|0),($2|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_Int64_m_System_IConvertible_ToDecimalPxP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160296);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viiii(181,($agg$result|0),(0|0),($2|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52mscorlib_System_Int64_m_System_IConvertible_ToDoublePxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160344);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (+invoke_diii(2,(0|0),($2|0),($5|0)));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$6);
 }
 return +0;
}
function __Z51mscorlib_System_Int64_m_System_IConvertible_ToInt16PxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160392);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1031,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Int64_m_System_IConvertible_ToInt32PxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160440);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1042,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Int64_m_System_IConvertible_ToInt64PxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160488);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1050,(0|0),($2|0),($5|0))|0);
 $7 = tempRet0;
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Int64_m_System_IConvertible_ToSBytePxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160536);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1068,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int64_m_System_IConvertible_ToSinglePxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160584);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (Math_fround(+(invoke_fiii(2,(0|0),($2|0),($5|0)))));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($6));
 }
 return Math_fround(0);
}
function __Z50mscorlib_System_Int64_m_System_IConvertible_ToTypePxP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160632);
 __THREW__ = 0;
 invoke_v(365);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = $__this;
    $16 = $15;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + 4)|0;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = $L_2;
    $22 = $21;
    HEAP32[$22>>2] = $17;
    $23 = (($21) + 4)|0;
    $24 = $23;
    HEAP32[$24>>2] = $20;
    __THREW__ = 0;
    (invoke_ii(2996,(2162248|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __THREW__ = 0;
    $27 = (invoke_iii(2724,(2162248|0),($L_2|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    $30 = (invoke_iiiiii(126,(0|0),($27|0),($targetType|0),($provider|0),0)|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($30|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3003504>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Int64_m_System_IConvertible_ToUInt16PxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160680);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1094,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int64_m_System_IConvertible_ToUInt32PxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160728);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1110,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int64_m_System_IConvertible_ToUInt64PxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160776);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1126,(0|0),($2|0),($5|0))|0);
 $7 = tempRet0;
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Int64_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPxP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160824);
 __THREW__ = 0;
 invoke_v(366);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2162248|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2162248|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3003520>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2162248|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2162248|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = $26;
      $30 = $29;
      $31 = HEAP32[$30>>2]|0;
      $32 = (($29) + 4)|0;
      $33 = $32;
      $34 = HEAP32[$33>>2]|0;
      $35 = $__this;
      $36 = $35;
      $37 = HEAP32[$36>>2]|0;
      $38 = (($35) + 4)|0;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = ($37|0)==($31|0);
      $42 = ($40|0)==($34|0);
      $43 = $41 & $42;
      if ($43) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $44 = ($40|0)<($34|0);
      $45 = ($40|0)==($34|0);
      $46 = ($37>>>0)<($31>>>0);
      $47 = $45 & $46;
      $48 = $44 | $47;
      $$ = $48 ? -1 : 1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Int64_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPxP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160872);
 __THREW__ = 0;
 (invoke_ii(2996,(2162248|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2162248|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2162248|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2162248|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = $10;
     $14 = $13;
     $15 = HEAP32[$14>>2]|0;
     $16 = (($13) + 4)|0;
     $17 = $16;
     $18 = HEAP32[$17>>2]|0;
     $19 = $__this;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + 4)|0;
     $23 = $22;
     $24 = HEAP32[$23>>2]|0;
     $25 = ($15|0)==($21|0);
     $26 = ($18|0)==($24|0);
     $27 = $25 & $26;
     $$0 = $27;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_Int64_m_GetHashCodePx($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160920);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 ^ $2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($6|0);
}
function __Z77mscorlib_System_Int64_m_CompareTo_mscorlib_System_Int32_mscorlib_System_Int64Pxx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2160968);
 $2 = $__this;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = ($4|0)==($0|0);
 $9 = ($7|0)==($1|0);
 $10 = $8 & $9;
 if ($10) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ($7|0)>($1|0);
 $12 = ($7|0)==($1|0);
 $13 = ($4>>>0)>($0>>>0);
 $14 = $12 & $13;
 $15 = $11 | $14;
 $$ = $15 ? 1 : -1;
 $$0 = $$;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z76mscorlib_System_Int64_m_Equals_mscorlib_System_Boolean_mscorlib_System_Int64Pxx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2161016);
 $2 = $__this;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = ($4|0)==($0|0);
 $9 = ($7|0)==($1|0);
 $10 = $8 & $9;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($10|0);
}
function __Z106mscorlib_System_Int64_m_Parse_mscorlib_System_Int64_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2161064);
 __THREW__ = 0;
 $0 = (invoke_iiiii(83,0,($s|0),7,($provider|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z149mscorlib_System_Int64_m_Parse_mscorlib_System_Int64_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $V_0 = sp + 8|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2161160);
 HEAP32[$V_0>>2] = 0;
 $0 = $V_1;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 $4 = (invoke_iiiiiiii(66,0,($s|0),($style|0),($provider|0),0,($V_1|0),($V_0|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 if ($4) {
  $12 = $V_1;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $17;
  STACKTOP = sp;return ($14|0);
 }
 $9 = HEAP32[$V_0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3830,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  // unreachable;
 }
 return 0|0;
}
function __Z241mscorlib_System_Int64_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_Int64U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPxPP25mscorlib_System_Exception($__this,$s,$style,$fp,$tryParse,$result,$exc) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $fp = $fp|0;
 $tryParse = $tryParse|0;
 $result = $result|0;
 $exc = $exc|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $$byval_copy = 0, $$lobit = 0, $$lobit10 = 0, $$lobit11 = 0, $$lobit5 = 0, $$lobit6 = 0, $$lobit7 = 0, $$lobit8 = 0, $$lobit9 = 0, $$mask = 0, $$not = 0, $$not24 = 0, $$not25 = 0, $$not27 = 0, $$not30 = 0, $$not31 = 0, $$not33 = 0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_226 = 0, $L_235 = 0, $V_0$1 = 0, $V_11 = 0, $V_12$0$off0 = 0, $V_13 = 0, $V_14 = 0, $V_15 = 0, $V_17$0 = 0, $V_17$1 = 0;
 var $V_17$2 = 0, $V_18$0$off0 = 0, $V_18$1$off0 = 0, $V_19$0 = 0, $_stackTraceSentry = 0, $brmerge = 0, $brmerge26 = 0, $brmerge28 = 0, $brmerge29 = 0, $brmerge32 = 0, $brmerge34 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi64$index = 0, $lpad$phi64$index7 = 0, $or$cond = 0, $or$cond66 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 12|0;
 $_stackTraceSentry = sp + 20|0;
 $V_11 = sp + 16|0;
 $V_13 = sp + 26|0;
 $V_14 = sp + 25|0;
 $V_15 = sp + 24|0;
 $0 = sp + 4|0;
 $L_226 = sp;
 $L_235 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2161112);
 HEAP32[$V_11>>2] = 0;
 HEAP8[$V_13>>0] = 0;
 HEAP8[$V_14>>0] = 0;
 HEAP8[$V_15>>0] = 0;
 __THREW__ = 0;
 invoke_v(367);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 4;
  } else {
   $3 = $result;
   $4 = $3;
   HEAP32[$4>>2] = 0;
   $5 = (($3) + 4)|0;
   $6 = $5;
   HEAP32[$6>>2] = 0;
   HEAP32[$exc>>2] = 0;
   $7 = ($s|0)==(0|0);
   if ($7) {
    if ($tryParse) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2560584|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     label = 4;
     break;
    }
    $17 = HEAP32[3003592>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($14|0),($17|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 4;
     break;
    }
    HEAP32[$exc>>2] = $14;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    label = 4;
   } else {
    __THREW__ = 0;
    $22 = (invoke_ii(1816,($s|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 4;
    } else {
     $25 = ($22|0)==(0);
     if ($25) {
      if ($tryParse) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2603176|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_ii(3469,(2603176|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = HEAP32[3003600>>2]|0;
      __THREW__ = 0;
      invoke_vii(1940,($28|0),($31|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 4;
       break;
      }
      HEAP32[$exc>>2] = $28;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $34 = ($fp|0)==(0|0);
     if ($34) {
      label = 26;
     } else {
      HEAP32[$0>>2] = 2271128;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $35 = (invoke_iii(772,0,($$byval_copy|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($fp|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $40 = (invoke_iiii(1666,(2606440|0),($fp|0),($35|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2348608|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $45 = (invoke_iii(2755,($40|0),(2348608|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 4;
       break;
      }
      $48 = ($45|0)==(0|0);
      if ($48) {
       label = 26;
      } else {
       $V_0$1 = $45;
      }
     }
     if ((label|0) == 26) {
      __THREW__ = 0;
      $49 = (invoke_ii(2405,(0|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $52 = (invoke_iii(1178,(0|0),($49|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($52|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iii(2730,(2330184|0),($52|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $V_0$1 = $57;
     }
     __THREW__ = 0;
     $60 = (invoke_iiiii(80,0,($style|0),($tryParse|0),($exc|0))|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      label = 4;
     } else {
      if (!($60)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $$lobit = $style >>> 8;
      $$lobit5 = $style & 512;
      $63 = ($$lobit5|0)!=(0);
      $$lobit6 = $style & 64;
      $64 = ($$lobit6|0)==(0);
      $$lobit7 = $style & 32;
      $65 = ($$lobit7|0)==(0);
      $$lobit8 = $style & 16;
      $66 = ($$lobit8|0)==(0);
      $$lobit9 = $style & 8;
      $67 = ($$lobit9|0)!=(0);
      $$lobit10 = $style & 4;
      $68 = ($$lobit10|0)!=(0);
      $$lobit11 = $style >>> 1;
      $69 = $style & 1;
      $70 = ($69|0)!=(0);
      HEAP32[$V_11>>2] = 0;
      if ($70) {
       __THREW__ = 0;
       $71 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        label = 4;
        break;
       }
       if (!($71)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      HEAP8[$V_13>>0] = 0;
      HEAP8[$V_14>>0] = 0;
      HEAP8[$V_15>>0] = 0;
      do {
       if ($66) {
        $151 = 0;$V_12$0$off0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($s|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 4;
         break L1;
        }
        $76 = HEAP32[$V_11>>2]|0;
        __THREW__ = 0;
        $77 = (invoke_iii(621,($s|0),($76|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break L1;
        }
        $80 = ($77<<16>>16)==(40);
        if ($80) {
         HEAP8[$V_14>>0] = 1;
         HEAP8[$V_13>>0] = 1;
         $81 = HEAP32[$V_11>>2]|0;
         $82 = (($81) + 1)|0;
         HEAP32[$V_11>>2] = $82;
         if ($70) {
          __THREW__ = 0;
          $83 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if ($85) {
           label = 4;
           break L1;
          }
          if (!($83)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $88 = (invoke_ii(2029,($V_0$1|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($88|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $93 = (invoke_ii(1816,($88|0))|0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          label = 4;
          break L1;
         }
         $98 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $99 = (invoke_iiii(528,($s|0),($98|0),($93|0))|0);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $102 = __THREW__; __THREW__ = 0;
         $103 = $102&1;
         if ($103) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $104 = (invoke_ii(2029,($V_0$1|0))|0);
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $107 = (invoke_iiii(574,0,($99|0),($104|0))|0);
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          label = 4;
          break L1;
         }
         if ($107) {
          if ($tryParse) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2603176|0))|0);
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           label = 4;
           break L1;
          }
          __THREW__ = 0;
          $112 = (invoke_ii(3469,(2603176|0))|0);
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           label = 4;
           break L1;
          }
          $115 = HEAP32[3003608>>2]|0;
          __THREW__ = 0;
          invoke_vii(1940,($112|0),($115|0));
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           label = 4;
           break L1;
          }
          HEAP32[$exc>>2] = $112;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $120 = (invoke_ii(2044,($V_0$1|0))|0);
         $121 = __THREW__; __THREW__ = 0;
         $122 = $121&1;
         if ($122) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($120|0));
         $123 = __THREW__; __THREW__ = 0;
         $124 = $123&1;
         if ($124) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $125 = (invoke_ii(1816,($120|0))|0);
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if ($127) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $128 = __THREW__; __THREW__ = 0;
         $129 = $128&1;
         if ($129) {
          label = 4;
          break L1;
         }
         $130 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $131 = (invoke_iiii(528,($s|0),($130|0),($125|0))|0);
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $136 = (invoke_ii(2044,($V_0$1|0))|0);
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if ($138) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $139 = (invoke_iiii(574,0,($131|0),($136|0))|0);
         $140 = __THREW__; __THREW__ = 0;
         $141 = $140&1;
         if ($141) {
          label = 4;
          break L1;
         }
         if (!($139)) {
          $151 = 1;$V_12$0$off0 = 1;
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2603176|0))|0);
         $142 = __THREW__; __THREW__ = 0;
         $143 = $142&1;
         if ($143) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $144 = (invoke_ii(3469,(2603176|0))|0);
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         if ($146) {
          label = 4;
          break L1;
         }
         $147 = HEAP32[3003616>>2]|0;
         __THREW__ = 0;
         invoke_vii(1940,($144|0),($147|0));
         $148 = __THREW__; __THREW__ = 0;
         $149 = $148&1;
         if ($149) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $144;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         $151 = 0;$V_12$0$off0 = 0;
        }
       }
      } while(0);
      do {
       if ($68) {
        $150 = ($151<<24>>24)==(0);
        if ($150) {
         __THREW__ = 0;
         invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
         $152 = __THREW__; __THREW__ = 0;
         $153 = $152&1;
         if ($153) {
          label = 4;
          break L1;
         }
         $154 = HEAP8[$V_14>>0]|0;
         $155 = ($154<<24>>24)==(0);
         if ($155) {
          $171 = 0;$179 = 0;
         } else {
          if ($70) {
           __THREW__ = 0;
           $156 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
           $157 = __THREW__; __THREW__ = 0;
           $158 = $157&1;
           if ($158) {
            label = 4;
            break L1;
           }
           if (!($156)) {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
          $159 = $$lobit & 1;
          $160 = ($159|0)==(0);
          if ($160) {
           $171 = 0;$179 = $154;
          } else {
           __THREW__ = 0;
           invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 4;
            break L1;
           }
           $163 = HEAP8[$V_15>>0]|0;
           $164 = ($163<<24>>24)==(0);
           $$not = $70 ^ 1;
           $brmerge = $164 | $$not;
           if ($brmerge) {
            $171 = $163;$179 = $154;
           } else {
            __THREW__ = 0;
            $165 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $166 = __THREW__; __THREW__ = 0;
            $167 = $166&1;
            if ($167) {
             label = 4;
             break L1;
            }
            if ($165) {
             $171 = $163;$179 = $154;
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        } else {
         $171 = 0;$179 = 1;
        }
       } else {
        $171 = 0;$179 = $151;
       }
      } while(0);
      $168 = $$lobit & 1;
      $169 = ($168|0)!=(0);
      $170 = ($171<<24>>24)==(0);
      $or$cond = $169 & $170;
      do {
       if ($or$cond) {
        __THREW__ = 0;
        invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         label = 4;
         break L1;
        }
        $174 = HEAP8[$V_15>>0]|0;
        $175 = ($174<<24>>24)==(0);
        if ($175) {
         $342 = $179;$565 = 0;
        } else {
         if ($70) {
          __THREW__ = 0;
          $176 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
          $177 = __THREW__; __THREW__ = 0;
          $178 = $177&1;
          if ($178) {
           label = 4;
           break L1;
          }
          if (!($176)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         $$not24 = ($179<<24>>24)!=(0);
         $$not25 = $68 ^ 1;
         $brmerge26 = $$not24 | $$not25;
         if ($brmerge26) {
          $342 = $179;$565 = $174;
         } else {
          __THREW__ = 0;
          invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
          $180 = __THREW__; __THREW__ = 0;
          $181 = $180&1;
          if ($181) {
           label = 4;
           break L1;
          }
          $182 = HEAP8[$V_14>>0]|0;
          $183 = ($182<<24>>24)==(0);
          $$not27 = $70 ^ 1;
          $brmerge28 = $183 | $$not27;
          if ($brmerge28) {
           $342 = $182;$565 = $174;
          } else {
           __THREW__ = 0;
           $184 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
           $185 = __THREW__; __THREW__ = 0;
           $186 = $185&1;
           if ($186) {
            label = 4;
            break L1;
           }
           if ($184) {
            $342 = $182;$565 = $174;
            break;
           } else {
            $$0 = 0;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       } else {
        $342 = $179;$565 = $171;
       }
      } while(0);
      $254 = 0;$255 = 0;$V_17$0 = 0;$V_18$0$off0 = 0;
      L126: while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $187 = __THREW__; __THREW__ = 0;
       $188 = $187&1;
       if ($188) {
        label = 3;
        break;
       }
       $189 = HEAP32[$V_11>>2]|0;
       __THREW__ = 0;
       $190 = (invoke_iii(621,($s|0),($189|0))|0);
       $191 = __THREW__; __THREW__ = 0;
       $192 = $191&1;
       if ($192) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $193 = (invoke_iiii(456,0,($190|0),($63|0))|0);
       $194 = __THREW__; __THREW__ = 0;
       $195 = $194&1;
       if ($195) {
        label = 3;
        break;
       }
       do {
        if ($193) {
         $228 = (($V_17$0) + 1)|0;
         if (!($63)) {
          if ($V_18$0$off0) {
           $260 = HEAP32[$V_11>>2]|0;
           $261 = (($260) + 1)|0;
           HEAP32[$V_11>>2] = $261;
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $262 = __THREW__; __THREW__ = 0;
           $263 = $262&1;
           if ($263) {
            label = 3;
            break L126;
           }
           __THREW__ = 0;
           $264 = (invoke_iii(621,($s|0),($260|0))|0);
           $265 = __THREW__; __THREW__ = 0;
           $266 = $265&1;
           if ($266) {
            label = 3;
            break L126;
           }
           $267 = ($264<<16>>16)==(48);
           if ($267) {
            $566 = $254;$567 = $255;$V_17$1 = $228;$V_18$1$off0 = 1;
            break;
           } else {
            label = 134;
            break L126;
           }
          }
          $276 = (___muldi3(($254|0),($255|0),10,0)|0);
          $277 = tempRet0;
          $278 = HEAP32[$V_11>>2]|0;
          $279 = ($278|0)==(2147483647);
          if ($279) {
           label = 140;
           break L126;
          }
          $299 = (($278) + 1)|0;
          HEAP32[$V_11>>2] = $299;
          __THREW__ = 0;
          invoke_vi(3799,($s|0));
          $300 = __THREW__; __THREW__ = 0;
          $301 = $300&1;
          if ($301) {
           label = 143;
           break L126;
          }
          __THREW__ = 0;
          $302 = (invoke_iii(621,($s|0),($278|0))|0);
          $303 = __THREW__; __THREW__ = 0;
          $304 = $303&1;
          if ($304) {
           label = 143;
           break L126;
          }
          $305 = $302&65535;
          $306 = (($305) + 65488)|0;
          $$mask = $306 & 65535;
          $307 = (_i64Subtract(($276|0),($277|0),($$mask|0),0)|0);
          $308 = tempRet0;
          $566 = $307;$567 = $308;$V_17$1 = $228;$V_18$1$off0 = 0;
          break;
         }
         $229 = HEAP32[$V_11>>2]|0;
         $230 = (($229) + 1)|0;
         HEAP32[$V_11>>2] = $230;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $231 = __THREW__; __THREW__ = 0;
         $232 = $231&1;
         if ($232) {
          label = 3;
          break L126;
         }
         __THREW__ = 0;
         $233 = (invoke_iii(621,($s|0),($229|0))|0);
         $234 = __THREW__; __THREW__ = 0;
         $235 = $234&1;
         if ($235) {
          label = 3;
          break L126;
         }
         __THREW__ = 0;
         $236 = (invoke_iii(600,0,($233|0))|0);
         $237 = __THREW__; __THREW__ = 0;
         $238 = $237&1;
         if ($238) {
          label = 3;
          break L126;
         }
         do {
          if ($236) {
           $239 = $233&65535;
           $240 = (($239) + 65488)|0;
           $241 = $240 & 65535;
           $V_19$0 = $241;
          } else {
           __THREW__ = 0;
           $242 = (invoke_iii(602,0,($233|0))|0);
           $243 = __THREW__; __THREW__ = 0;
           $244 = $243&1;
           if ($244) {
            label = 3;
            break L126;
           }
           $245 = $233&65535;
           if ($242) {
            $246 = (($245) + 65439)|0;
            $247 = $246 & 65535;
            $248 = (($247) + 10)|0;
            $V_19$0 = $248;
            break;
           } else {
            $249 = (($245) + 65471)|0;
            $250 = $249 & 65535;
            $251 = (($250) + 10)|0;
            $V_19$0 = $251;
            break;
           }
          }
         } while(0);
         $252 = ($V_19$0|0)<(0);
         $253 = $252 << 31 >> 31;
         $256 = (_bitshift64Shl(($254|0),($255|0),4)|0);
         $257 = tempRet0;
         $258 = (_i64Add(($V_19$0|0),($253|0),($256|0),($257|0))|0);
         $259 = tempRet0;
         $566 = $258;$567 = $259;$V_17$1 = $228;$V_18$1$off0 = $V_18$0$off0;
        } else {
         if (!($64)) {
          __THREW__ = 0;
          invoke_vi(3799,($V_0$1|0));
          $196 = __THREW__; __THREW__ = 0;
          $197 = $196&1;
          if ($197) {
           label = 3;
           break L126;
          }
          __THREW__ = 0;
          $198 = (invoke_ii(2032,($V_0$1|0))|0);
          $199 = __THREW__; __THREW__ = 0;
          $200 = $199&1;
          if ($200) {
           label = 3;
           break L126;
          }
          __THREW__ = 0;
          $201 = (invoke_iiiii(81,0,($V_11|0),($s|0),($198|0))|0);
          $202 = __THREW__; __THREW__ = 0;
          $203 = $202&1;
          if ($203) {
           label = 3;
           break L126;
          }
          if ($201) {
           $566 = $254;$567 = $255;$V_17$1 = $V_17$0;$V_18$1$off0 = $V_18$0$off0;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($V_0$1|0));
          $204 = __THREW__; __THREW__ = 0;
          $205 = $204&1;
          if ($205) {
           label = 3;
           break L126;
          }
          __THREW__ = 0;
          $206 = (invoke_ii(2020,($V_0$1|0))|0);
          $207 = __THREW__; __THREW__ = 0;
          $208 = $207&1;
          if ($208) {
           label = 3;
           break L126;
          }
          __THREW__ = 0;
          $209 = (invoke_iiiii(81,0,($V_11|0),($s|0),($206|0))|0);
          $210 = __THREW__; __THREW__ = 0;
          $211 = $210&1;
          if ($211) {
           label = 3;
           break L126;
          }
          if ($209) {
           $566 = $254;$567 = $255;$V_17$1 = $V_17$0;$V_18$1$off0 = $V_18$0$off0;
           break;
          }
         }
         $brmerge29 = $V_18$0$off0 | $65;
         if ($brmerge29) {
          $553 = $254;$554 = $255;$V_17$2 = $V_17$0;
          label = 162;
          break L126;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $212 = __THREW__; __THREW__ = 0;
         $213 = $212&1;
         if ($213) {
          label = 3;
          break L126;
         }
         __THREW__ = 0;
         $214 = (invoke_ii(2031,($V_0$1|0))|0);
         $215 = __THREW__; __THREW__ = 0;
         $216 = $215&1;
         if ($216) {
          label = 3;
          break L126;
         }
         __THREW__ = 0;
         $217 = (invoke_iiiii(81,0,($V_11|0),($s|0),($214|0))|0);
         $218 = __THREW__; __THREW__ = 0;
         $219 = $218&1;
         if ($219) {
          label = 3;
          break L126;
         }
         if ($217) {
          $566 = $254;$567 = $255;$V_17$1 = $V_17$0;$V_18$1$off0 = 1;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $220 = __THREW__; __THREW__ = 0;
         $221 = $220&1;
         if ($221) {
          label = 3;
          break L126;
         }
         __THREW__ = 0;
         $222 = (invoke_ii(2019,($V_0$1|0))|0);
         $223 = __THREW__; __THREW__ = 0;
         $224 = $223&1;
         if ($224) {
          label = 3;
          break L126;
         }
         __THREW__ = 0;
         $225 = (invoke_iiiii(81,0,($V_11|0),($s|0),($222|0))|0);
         $226 = __THREW__; __THREW__ = 0;
         $227 = $226&1;
         if ($227) {
          label = 3;
          break L126;
         }
         if ($225) {
          $566 = $254;$567 = $255;$V_17$1 = $V_17$0;$V_18$1$off0 = 1;
         } else {
          $553 = $254;$554 = $255;$V_17$2 = $V_17$0;
          label = 162;
          break L126;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $325 = __THREW__; __THREW__ = 0;
       $326 = $325&1;
       if ($326) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $327 = (invoke_ii(1816,($s|0))|0);
       $328 = __THREW__; __THREW__ = 0;
       $329 = $328&1;
       if ($329) {
        label = 3;
        break;
       }
       $330 = HEAP32[$V_11>>2]|0;
       $331 = ($330|0)<($327|0);
       if ($331) {
        $254 = $566;$255 = $567;$V_17$0 = $V_17$1;$V_18$0$off0 = $V_18$1$off0;
       } else {
        $553 = $566;$554 = $567;$V_17$2 = $V_17$1;
        label = 162;
        break;
       }
      }
      if ((label|0) == 3) {
       $8 = ___cxa_find_matching_catch()|0;
       $9 = tempRet0;
       $lpad$phi$index = $8;$lpad$phi$index2 = $9;
       break;
      }
      else if ((label|0) == 134) {
       if ($tryParse) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2635888|0))|0);
       $268 = __THREW__; __THREW__ = 0;
       $269 = $268&1;
       if ($269) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $270 = (invoke_ii(3469,(2635888|0))|0);
       $271 = __THREW__; __THREW__ = 0;
       $272 = $271&1;
       if ($272) {
        label = 4;
        break;
       }
       $273 = HEAP32[3003624>>2]|0;
       __THREW__ = 0;
       invoke_vii(1971,($270|0),($273|0));
       $274 = __THREW__; __THREW__ = 0;
       $275 = $274&1;
       if ($275) {
        label = 4;
        break;
       }
       HEAP32[$exc>>2] = $270;
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      else if ((label|0) == 140) {
       __THREW__ = 0;
       $280 = (invoke_i(133)|0);
       $281 = __THREW__; __THREW__ = 0;
       $282 = $281&1;
       if (!($282)) {
        __THREW__ = 0;
        invoke_vi(3830,($280|0));
        $283 = __THREW__; __THREW__ = 0;
        $284 = $283&1;
        if (!($284)) {
         // unreachable;
        }
       }
       $287 = ___cxa_find_matching_catch(348288|0)|0;
       $288 = tempRet0;
       $lpad$phi64$index = $287;$lpad$phi64$index7 = $288;
      }
      else if ((label|0) == 143) {
       $285 = ___cxa_find_matching_catch(348288|0)|0;
       $286 = tempRet0;
       $lpad$phi64$index = $285;$lpad$phi64$index7 = $286;
      }
      else if ((label|0) == 162) {
       $332 = ($V_17$2|0)==(0);
       if ($332) {
        if ($tryParse) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2603176|0))|0);
        $333 = __THREW__; __THREW__ = 0;
        $334 = $333&1;
        if ($334) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $335 = (invoke_ii(3469,(2603176|0))|0);
        $336 = __THREW__; __THREW__ = 0;
        $337 = $336&1;
        if ($337) {
         label = 4;
         break;
        }
        $338 = HEAP32[3003640>>2]|0;
        __THREW__ = 0;
        invoke_vii(1940,($335|0),($338|0));
        $339 = __THREW__; __THREW__ = 0;
        $340 = $339&1;
        if ($340) {
         label = 4;
         break;
        }
        HEAP32[$exc>>2] = $335;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $341 = ($342<<24>>24)==(0);
       $or$cond66 = $67 & $341;
       do {
        if ($or$cond66) {
         __THREW__ = 0;
         invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
         $343 = __THREW__; __THREW__ = 0;
         $344 = $343&1;
         if ($344) {
          label = 4;
          break L1;
         }
         $345 = HEAP8[$V_14>>0]|0;
         $346 = ($345<<24>>24)==(0);
         if ($346) {
          $568 = 0;
          label = 177;
         } else {
          $347 = $$lobit11 & 1;
          $348 = ($347|0)==(0);
          do {
           if (!($348)) {
            __THREW__ = 0;
            $349 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $350 = __THREW__; __THREW__ = 0;
            $351 = $350&1;
            if ($351) {
             label = 4;
             break L1;
            }
            if ($349) {
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          } while(0);
          if (!($169)) {
           break;
          }
          __THREW__ = 0;
          invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
          $352 = __THREW__; __THREW__ = 0;
          $353 = $352&1;
          if ($353) {
           label = 4;
           break L1;
          }
          $$pre = HEAP8[$V_15>>0]|0;
          $355 = $$pre;$396 = $345;
          label = 178;
         }
        } else {
         $568 = $342;
         label = 177;
        }
       } while(0);
       if ((label|0) == 177) {
        if ($169) {
         $355 = $565;$396 = $568;
         label = 178;
        }
       }
       do {
        if ((label|0) == 178) {
         $354 = ($355<<24>>24)==(0);
         if ($354) {
          __THREW__ = 0;
          invoke_vi(3799,($V_0$1|0));
          $356 = __THREW__; __THREW__ = 0;
          $357 = $356&1;
          if ($357) {
           label = 4;
           break L1;
          }
          __THREW__ = 0;
          $358 = (invoke_ii(2023,($V_0$1|0))|0);
          $359 = __THREW__; __THREW__ = 0;
          $360 = $359&1;
          if ($360) {
           label = 4;
           break L1;
          }
          $361 = ($358|0)==(3);
          do {
           if ($361) {
            $362 = HEAP32[$V_11>>2]|0;
            $363 = (($362) + 1)|0;
            HEAP32[$V_11>>2] = $363;
            __THREW__ = 0;
            invoke_vi(3799,($s|0));
            $364 = __THREW__; __THREW__ = 0;
            $365 = $364&1;
            if ($365) {
             label = 4;
             break L1;
            }
            __THREW__ = 0;
            $366 = (invoke_iii(621,($s|0),($362|0))|0);
            $367 = __THREW__; __THREW__ = 0;
            $368 = $367&1;
            if ($368) {
             label = 4;
             break L1;
            }
            $369 = ($366<<16>>16)==(32);
            if ($369) {
             break;
            }
            if ($tryParse) {
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2603176|0))|0);
            $370 = __THREW__; __THREW__ = 0;
            $371 = $370&1;
            if ($371) {
             label = 4;
             break L1;
            }
            __THREW__ = 0;
            $372 = (invoke_ii(3469,(2603176|0))|0);
            $373 = __THREW__; __THREW__ = 0;
            $374 = $373&1;
            if ($374) {
             label = 4;
             break L1;
            }
            $375 = HEAP32[3003648>>2]|0;
            __THREW__ = 0;
            invoke_vii(1940,($372|0),($375|0));
            $376 = __THREW__; __THREW__ = 0;
            $377 = $376&1;
            if ($377) {
             label = 4;
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3830,($372|0));
            $378 = __THREW__; __THREW__ = 0;
            $379 = $378&1;
            if ($379) {
             label = 4;
             break L1;
            }
            // unreachable;
           }
          } while(0);
          __THREW__ = 0;
          invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
          $380 = __THREW__; __THREW__ = 0;
          $381 = $380&1;
          if ($381) {
           label = 4;
           break L1;
          }
          $382 = HEAP8[$V_15>>0]|0;
          $383 = ($382<<24>>24)==(0);
          if ($383) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($s|0));
          $384 = __THREW__; __THREW__ = 0;
          $385 = $384&1;
          if ($385) {
           label = 4;
           break L1;
          }
          __THREW__ = 0;
          $386 = (invoke_ii(1816,($s|0))|0);
          $387 = __THREW__; __THREW__ = 0;
          $388 = $387&1;
          if ($388) {
           label = 4;
           break L1;
          }
          $389 = HEAP32[$V_11>>2]|0;
          $390 = ($389|0)<($386|0);
          if (!($390)) {
           break;
          }
          $391 = $$lobit11 & 1;
          $392 = ($391|0)==(0);
          do {
           if (!($392)) {
            __THREW__ = 0;
            $393 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $394 = __THREW__; __THREW__ = 0;
            $395 = $394&1;
            if ($395) {
             label = 4;
             break L1;
            }
            if ($393) {
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          } while(0);
          $$not30 = ($396<<24>>24)!=(0);
          $$not31 = $67 ^ 1;
          $brmerge32 = $$not30 | $$not31;
          if ($brmerge32) {
           break;
          }
          __THREW__ = 0;
          invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
          $397 = __THREW__; __THREW__ = 0;
          $398 = $397&1;
          if ($398) {
           label = 4;
           break L1;
          }
         }
        }
       } while(0);
       $399 = $$lobit11 & 1;
       $400 = ($399|0)!=(0);
       do {
        if ($400) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $401 = __THREW__; __THREW__ = 0;
         $402 = $401&1;
         if ($402) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $403 = (invoke_ii(1816,($s|0))|0);
         $404 = __THREW__; __THREW__ = 0;
         $405 = $404&1;
         if ($405) {
          label = 4;
          break L1;
         }
         $406 = HEAP32[$V_11>>2]|0;
         $407 = ($406|0)<($403|0);
         if (!($407)) {
          break;
         }
         __THREW__ = 0;
         $408 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),0,($tryParse|0),($exc|0))|0);
         $409 = __THREW__; __THREW__ = 0;
         $410 = $409&1;
         if ($410) {
          label = 4;
          break L1;
         }
         if ($408) {
          break;
         } else {
          $$0 = 0;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       L255: do {
        if ($V_12$0$off0) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $411 = __THREW__; __THREW__ = 0;
         $412 = $411&1;
         if ($412) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $413 = (invoke_ii(1816,($s|0))|0);
         $414 = __THREW__; __THREW__ = 0;
         $415 = $414&1;
         if ($415) {
          label = 4;
          break L1;
         }
         $416 = HEAP32[$V_11>>2]|0;
         $417 = ($416|0)<($413|0);
         do {
          if ($417) {
           $418 = (($416) + 1)|0;
           HEAP32[$V_11>>2] = $418;
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $419 = __THREW__; __THREW__ = 0;
           $420 = $419&1;
           if ($420) {
            label = 4;
            break L1;
           }
           __THREW__ = 0;
           $421 = (invoke_iii(621,($s|0),($416|0))|0);
           $422 = __THREW__; __THREW__ = 0;
           $423 = $422&1;
           if ($423) {
            label = 4;
            break L1;
           }
           $424 = ($421<<16>>16)==(41);
           if (!($424)) {
            break;
           }
           if (!($400)) {
            break L255;
           }
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $433 = __THREW__; __THREW__ = 0;
           $434 = $433&1;
           if ($434) {
            label = 4;
            break L1;
           }
           __THREW__ = 0;
           $435 = (invoke_ii(1816,($s|0))|0);
           $436 = __THREW__; __THREW__ = 0;
           $437 = $436&1;
           if ($437) {
            label = 4;
            break L1;
           }
           $438 = HEAP32[$V_11>>2]|0;
           $439 = ($438|0)<($435|0);
           if (!($439)) {
            break L255;
           }
           __THREW__ = 0;
           $440 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),0,($tryParse|0),($exc|0))|0);
           $441 = __THREW__; __THREW__ = 0;
           $442 = $441&1;
           if ($442) {
            label = 4;
            break L1;
           }
           if ($440) {
            break L255;
           } else {
            $$0 = 0;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         } while(0);
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2603176|0))|0);
         $425 = __THREW__; __THREW__ = 0;
         $426 = $425&1;
         if ($426) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $427 = (invoke_ii(3469,(2603176|0))|0);
         $428 = __THREW__; __THREW__ = 0;
         $429 = $428&1;
         if ($429) {
          label = 4;
          break L1;
         }
         $430 = HEAP32[3003656>>2]|0;
         __THREW__ = 0;
         invoke_vii(1940,($427|0),($430|0));
         $431 = __THREW__; __THREW__ = 0;
         $432 = $431&1;
         if ($432) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $427;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $443 = __THREW__; __THREW__ = 0;
       $444 = $443&1;
       if ($444) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $445 = (invoke_ii(1816,($s|0))|0);
       $446 = __THREW__; __THREW__ = 0;
       $447 = $446&1;
       if ($447) {
        label = 4;
        break;
       }
       $448 = HEAP32[$V_11>>2]|0;
       $449 = ($448|0)<($445|0);
       do {
        if ($449) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $450 = __THREW__; __THREW__ = 0;
         $451 = $450&1;
         if ($451) {
          label = 4;
          break L1;
         }
         $452 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $453 = (invoke_iii(621,($s|0),($452|0))|0);
         $454 = __THREW__; __THREW__ = 0;
         $455 = $454&1;
         if ($455) {
          label = 4;
          break L1;
         }
         $456 = ($453<<16>>16)==(0);
         if ($456) {
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1167664|0))|0);
         $457 = __THREW__; __THREW__ = 0;
         $458 = $457&1;
         if ($458) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $459 = (invoke_iii(2754,(1167664|0),4)|0);
         $460 = __THREW__; __THREW__ = 0;
         $461 = $460&1;
         if ($461) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($459|0));
         $462 = __THREW__; __THREW__ = 0;
         $463 = $462&1;
         if ($463) {
          label = 4;
          break L1;
         }
         $464 = (($459) + 12|0);
         $465 = HEAP32[$464>>2]|0;
         $466 = ($465|0)==(0);
         if ($466) {
          __THREW__ = 0;
          $467 = (invoke_i(132)|0);
          $468 = __THREW__; __THREW__ = 0;
          $469 = $468&1;
          if ($469) {
           label = 4;
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($467|0));
          $470 = __THREW__; __THREW__ = 0;
          $471 = $470&1;
          if ($471) {
           label = 4;
           break L1;
          }
         }
         $472 = HEAP32[3003664>>2]|0;
         __THREW__ = 0;
         invoke_vii(3492,($459|0),($472|0));
         $473 = __THREW__; __THREW__ = 0;
         $474 = $473&1;
         if ($474) {
          label = 4;
          break L1;
         }
         $475 = HEAP32[3003664>>2]|0;
         $476 = (($459) + 16|0);
         HEAP32[$476>>2] = $475;
         $477 = HEAP32[$V_11>>2]|0;
         HEAP32[$L_226>>2] = $477;
         __THREW__ = 0;
         (invoke_ii(2996,(2155952|0))|0);
         $478 = __THREW__; __THREW__ = 0;
         $479 = $478&1;
         if ($479) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $480 = (invoke_iii(2724,(2155952|0),($L_226|0))|0);
         $481 = __THREW__; __THREW__ = 0;
         $482 = $481&1;
         if ($482) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($459|0));
         $483 = __THREW__; __THREW__ = 0;
         $484 = $483&1;
         if ($484) {
          label = 4;
          break L1;
         }
         $485 = HEAP32[$464>>2]|0;
         $486 = ($485>>>0)<(2);
         if ($486) {
          __THREW__ = 0;
          $487 = (invoke_i(132)|0);
          $488 = __THREW__; __THREW__ = 0;
          $489 = $488&1;
          if ($489) {
           label = 4;
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($487|0));
          $490 = __THREW__; __THREW__ = 0;
          $491 = $490&1;
          if ($491) {
           label = 4;
           break L1;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($459|0),($480|0));
         $492 = __THREW__; __THREW__ = 0;
         $493 = $492&1;
         if ($493) {
          label = 4;
          break L1;
         }
         $494 = HEAP32[$459>>2]|0;
         $495 = (($494) + 92|0);
         $496 = HEAP32[$495>>2]|0;
         $497 = (($476) + ($496)|0);
         HEAP32[$497>>2] = $480;
         __THREW__ = 0;
         invoke_vi(3799,($459|0));
         $498 = __THREW__; __THREW__ = 0;
         $499 = $498&1;
         if ($499) {
          label = 4;
          break L1;
         }
         $500 = HEAP32[$464>>2]|0;
         $501 = ($500>>>0)<(3);
         if ($501) {
          __THREW__ = 0;
          $502 = (invoke_i(132)|0);
          $503 = __THREW__; __THREW__ = 0;
          $504 = $503&1;
          if ($504) {
           label = 4;
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($502|0));
          $505 = __THREW__; __THREW__ = 0;
          $506 = $505&1;
          if ($506) {
           label = 4;
           break L1;
          }
         }
         $507 = HEAP32[3003672>>2]|0;
         __THREW__ = 0;
         invoke_vii(3492,($459|0),($507|0));
         $508 = __THREW__; __THREW__ = 0;
         $509 = $508&1;
         if ($509) {
          label = 4;
          break L1;
         }
         $510 = HEAP32[3003672>>2]|0;
         $511 = HEAP32[$459>>2]|0;
         $512 = (($511) + 92|0);
         $513 = HEAP32[$512>>2]|0;
         $514 = $513 << 1;
         $515 = (($476) + ($514)|0);
         HEAP32[$515>>2] = $510;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $516 = __THREW__; __THREW__ = 0;
         $517 = $516&1;
         if ($517) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $518 = (invoke_ii(1816,($s|0))|0);
         $519 = __THREW__; __THREW__ = 0;
         $520 = $519&1;
         if ($520) {
          label = 4;
          break L1;
         }
         HEAP32[$L_235>>2] = $518;
         __THREW__ = 0;
         (invoke_ii(2996,(2155952|0))|0);
         $521 = __THREW__; __THREW__ = 0;
         $522 = $521&1;
         if ($522) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $523 = (invoke_iii(2724,(2155952|0),($L_235|0))|0);
         $524 = __THREW__; __THREW__ = 0;
         $525 = $524&1;
         if ($525) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($459|0));
         $526 = __THREW__; __THREW__ = 0;
         $527 = $526&1;
         if ($527) {
          label = 4;
          break L1;
         }
         $528 = HEAP32[$464>>2]|0;
         $529 = ($528>>>0)<(4);
         if ($529) {
          __THREW__ = 0;
          $530 = (invoke_i(132)|0);
          $531 = __THREW__; __THREW__ = 0;
          $532 = $531&1;
          if ($532) {
           label = 4;
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($530|0));
          $533 = __THREW__; __THREW__ = 0;
          $534 = $533&1;
          if ($534) {
           label = 4;
           break L1;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($459|0),($523|0));
         $535 = __THREW__; __THREW__ = 0;
         $536 = $535&1;
         if ($536) {
          label = 4;
          break L1;
         }
         $537 = HEAP32[$459>>2]|0;
         $538 = (($537) + 92|0);
         $539 = HEAP32[$538>>2]|0;
         $540 = ($539*3)|0;
         $541 = (($476) + ($540)|0);
         HEAP32[$541>>2] = $523;
         __THREW__ = 0;
         $542 = (invoke_iii(638,0,($459|0))|0);
         $543 = __THREW__; __THREW__ = 0;
         $544 = $543&1;
         if ($544) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2603176|0))|0);
         $545 = __THREW__; __THREW__ = 0;
         $546 = $545&1;
         if ($546) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $547 = (invoke_ii(3469,(2603176|0))|0);
         $548 = __THREW__; __THREW__ = 0;
         $549 = $548&1;
         if ($549) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vii(1940,($547|0),($542|0));
         $550 = __THREW__; __THREW__ = 0;
         $551 = $550&1;
         if ($551) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $547;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       $552 = HEAP8[$V_13>>0]|0;
       $$not33 = ($552<<24>>24)!=(0);
       $brmerge34 = $$not33 | $63;
       if ($brmerge34) {
        $559 = $553;$562 = $554;
       } else {
        $555 = (_i64Subtract(0,0,($553|0),($554|0))|0);
        $556 = tempRet0;
        $559 = $555;$562 = 0;
       }
       $557 = $result;
       $558 = $557;
       HEAP32[$558>>2] = $559;
       $560 = (($557) + 4)|0;
       $561 = $560;
       HEAP32[$561>>2] = $562;
       $$0 = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $289 = (_llvm_eh_typeid_for((348288|0))|0);
      $290 = ($lpad$phi64$index7|0)==($289|0);
      if (!($290)) {
       $$02 = $lpad$phi64$index;$$03 = $lpad$phi64$index7;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $291 = (___cxa_begin_catch(($lpad$phi64$index|0))|0);
      $292 = HEAP32[$291>>2]|0;
      $293 = HEAP32[$292>>2]|0;
      __THREW__ = 0;
      $294 = (invoke_iii(2727,(2635888|0),($293|0))|0);
      $295 = __THREW__; __THREW__ = 0;
      $296 = $295&1;
      do {
       if (!($296)) {
        if (!($294)) {
         $313 = (___cxa_allocate_exception(4)|0);
         $314 = HEAP32[$291>>2]|0;
         HEAP32[$313>>2] = $314;
         __THREW__ = 0;
         invoke_viii(1567,($313|0),(348288|0),(0|0));
         $315 = __THREW__; __THREW__ = 0;
         $316 = $315&1;
         if ($316) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        invoke_v(66);
        $297 = __THREW__; __THREW__ = 0;
        $298 = $297&1;
        if ($298) {
         label = 4;
         break L1;
        }
        if ($tryParse) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2635888|0))|0);
        $317 = __THREW__; __THREW__ = 0;
        $318 = $317&1;
        if ($318) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        $319 = (invoke_ii(3469,(2635888|0))|0);
        $320 = __THREW__; __THREW__ = 0;
        $321 = $320&1;
        if ($321) {
         label = 4;
         break L1;
        }
        $322 = HEAP32[3003632>>2]|0;
        __THREW__ = 0;
        invoke_vii(1971,($319|0),($322|0));
        $323 = __THREW__; __THREW__ = 0;
        $324 = $323&1;
        if ($324) {
         label = 4;
         break L1;
        }
        HEAP32[$exc>>2] = $319;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $309 = ___cxa_find_matching_catch()|0;
      $310 = tempRet0;
      __THREW__ = 0;
      invoke_v(66);
      $311 = __THREW__; __THREW__ = 0;
      $312 = $311&1;
      if ($312) {
       $563 = ___cxa_find_matching_catch(0|0)|0;
       $564 = tempRet0;
       ___clang_call_terminate($563);
       // unreachable;
      } else {
       $$02 = $309;$$03 = $310;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 }
 $$02 = $lpad$phi$index;$$03 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP26mscorlib_System_Object_arr($__this,$args) {
 $__this = $__this|0;
 $args = $args|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_2$1$lcssa = 0, $V_2$19 = 0, $V_3$07 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185112);
 __THREW__ = 0;
 invoke_v(368);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($args|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3007448>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($args|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = (($args) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0);
    if ($21) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     $24 = HEAP8[((2191608 + 116|0))>>0]|0;
     $25 = ($24<<24>>24)==(0);
     if ($25) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2191608|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $34 = HEAP32[((2191608 + 80|0))>>2]|0;
     $35 = HEAP32[$34>>2]|0;
     $$0 = $35;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1168432|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     $38 = (invoke_iii(2754,(1168432|0),($20|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = ($20|0)>(0);
      L24: do {
       if ($41) {
        $42 = (($args) + 16|0);
        $43 = (($38) + 16|0);
        $44 = (($38) + 12|0);
        $V_2$19 = 0;$V_3$07 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($args|0));
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          break;
         }
         $45 = HEAP32[$19>>2]|0;
         $46 = ($V_3$07>>>0)<($45>>>0);
         if (!($46)) {
          __THREW__ = 0;
          $47 = (invoke_i(132)|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($47|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           break;
          }
         }
         $52 = HEAP32[$args>>2]|0;
         $53 = (($52) + 92|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = Math_imul($54, $V_3$07)|0;
         $56 = (($42) + ($55)|0);
         $57 = HEAP32[$56>>2]|0;
         $58 = ($57|0)==(0|0);
         if ($58) {
          $V_2$0 = $V_2$19;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($args|0));
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           break;
          }
          $61 = HEAP32[$19>>2]|0;
          $62 = ($V_3$07>>>0)<($61>>>0);
          if (!($62)) {
           __THREW__ = 0;
           $63 = (invoke_i(132)|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($63|0));
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            break;
           }
          }
          $68 = HEAP32[$args>>2]|0;
          $69 = (($68) + 92|0);
          $70 = HEAP32[$69>>2]|0;
          $71 = Math_imul($70, $V_3$07)|0;
          $72 = (($42) + ($71)|0);
          $73 = HEAP32[$72>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($73|0));
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           break;
          }
          __THREW__ = 0;
          $76 = (invoke_iii(2730,(2149112|0),($73|0))|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($38|0));
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           break;
          }
          $81 = HEAP32[$44>>2]|0;
          $82 = ($V_3$07>>>0)<($81>>>0);
          if (!($82)) {
           __THREW__ = 0;
           $83 = (invoke_i(132)|0);
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($83|0));
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if ($87) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($38|0),($76|0));
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           break;
          }
          $90 = HEAP32[$38>>2]|0;
          $91 = (($90) + 92|0);
          $92 = HEAP32[$91>>2]|0;
          $93 = Math_imul($92, $V_3$07)|0;
          $94 = (($43) + ($93)|0);
          HEAP32[$94>>2] = $76;
          __THREW__ = 0;
          invoke_vi(3799,($38|0));
          $95 = __THREW__; __THREW__ = 0;
          $96 = $95&1;
          if ($96) {
           break;
          }
          $97 = HEAP32[$44>>2]|0;
          $98 = ($V_3$07>>>0)<($97>>>0);
          if (!($98)) {
           __THREW__ = 0;
           $99 = (invoke_i(132)|0);
           $100 = __THREW__; __THREW__ = 0;
           $101 = $100&1;
           if ($101) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($99|0));
           $102 = __THREW__; __THREW__ = 0;
           $103 = $102&1;
           if ($103) {
            break;
           }
          }
          $104 = HEAP32[$38>>2]|0;
          $105 = (($104) + 92|0);
          $106 = HEAP32[$105>>2]|0;
          $107 = Math_imul($106, $V_3$07)|0;
          $108 = (($43) + ($107)|0);
          $109 = HEAP32[$108>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($109|0));
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           break;
          }
          $112 = (($109) + 8|0);
          $113 = HEAP32[$112>>2]|0;
          $114 = (($113) + ($V_2$19))|0;
          $V_2$0 = $114;
         }
         $115 = (($V_3$07) + 1)|0;
         $116 = ($115|0)<($20|0);
         if ($116) {
          $V_2$19 = $V_2$0;$V_3$07 = $115;
         } else {
          $V_2$1$lcssa = $V_2$0;
          break L24;
         }
        }
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       } else {
        $V_2$1$lcssa = 0;
       }
      } while(0);
      __THREW__ = 0;
      $119 = (invoke_iiii(563,0,($38|0),($V_2$1$lcssa|0))|0);
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if (!($121)) {
       $$0 = $119;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Int64_m_ToString_mscorlib_System_StringPx($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2161208);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiiii(197,(0|0),($2|0),($5|0),(0|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z87mscorlib_System_Int64_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPxP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2161256);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiiii(197,(0|0),($2|0),($5|0),($provider|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Int64_m_ToString_mscorlib_System_String_mscorlib_System_StringPxP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2161304);
 __THREW__ = 0;
 $0 = (invoke_iiii(469,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z110mscorlib_System_Int64_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPxP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2161352);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiiiii(134,(0|0),($format|0),($2|0),($5|0),($provider|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits27mscorlib_System_Int64TraitsE6InvokeEPFiPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_Int64TraitsE6InvokeEPFbPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 $8 = $7&1;
 HEAP8[$ret>>0] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int64Traits17VoidPointerTraitsS1_E6InvokeEPFxPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 $4 = tempRet0;
 $5 = $ret;
 $6 = $5;
 HEAP32[$6>>2] = $3;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $4;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int64Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFxPvS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 $7 = tempRet0;
 $8 = $ret;
 $9 = $8;
 HEAP32[$9>>2] = $6;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($12|0);
}
function __Z52mscorlib_System_Int64_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_UInt32_m_System_IConvertible_ToBooleanPjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162384);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1012,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_UInt32_m_System_IConvertible_ToBytePjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162432);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1020,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_UInt32_m_System_IConvertible_ToCharPjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162480);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1026,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_UInt32_m_System_IConvertible_ToDateTimePjP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162528);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 invoke_viii(650,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_UInt32_m_System_IConvertible_ToDecimalPjP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162576);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 invoke_viii(656,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_UInt32_m_System_IConvertible_ToDoublePjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162624);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (+invoke_dii(24,(0|0),($0|0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$1);
 }
 return +0;
}
function __Z52mscorlib_System_UInt32_m_System_IConvertible_ToInt16PjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162672);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1035,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt32_m_System_IConvertible_ToInt32PjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162720);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1044,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt32_m_System_IConvertible_ToInt64PjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162768);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1053,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt32_m_System_IConvertible_ToSBytePjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162816);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1062,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_UInt32_m_System_IConvertible_ToSinglePjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162864);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fii(31,(0|0),($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($1));
 }
 return Math_fround(0);
}
function __Z51mscorlib_System_UInt32_m_System_IConvertible_ToTypePjP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162912);
 __THREW__ = 0;
 invoke_v(369);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = HEAP32[$__this>>2]|0;
    HEAP32[$L_2>>2] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2164560|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2164560|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3004680>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_UInt32_m_System_IConvertible_ToUInt16PjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2162960);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1071,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_UInt32_m_System_IConvertible_ToUInt32PjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163008);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z53mscorlib_System_UInt32_m_System_IConvertible_ToUInt64PjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163056);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1087,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_UInt32_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPjP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163104);
 __THREW__ = 0;
 invoke_v(370);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2164560|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2164560|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3004696>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2164560|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP32[$26>>2]|0;
      $30 = HEAP32[$__this>>2]|0;
      $31 = ($30|0)==($29|0);
      if ($31) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $32 = ($30>>>0)<($29>>>0);
      $$ = $32 ? -1 : 1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_UInt32_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPjP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163152);
 __THREW__ = 0;
 (invoke_ii(2996,(2164560|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2164560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2164560|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2164560|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[$10>>2]|0;
     $14 = HEAP32[$__this>>2]|0;
     $15 = ($13|0)==($14|0);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_UInt32_m_GetHashCodePj($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163200);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z79mscorlib_System_UInt32_m_CompareTo_mscorlib_System_Int32_mscorlib_System_UInt32Pjj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163248);
 $0 = HEAP32[$__this>>2]|0;
 $1 = ($0|0)==($value|0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = ($0>>>0)>($value>>>0);
  $$ = $2 ? 1 : -1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z78mscorlib_System_UInt32_m_Equals_mscorlib_System_Boolean_mscorlib_System_UInt32Pjj($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163296);
 $0 = HEAP32[$__this>>2]|0;
 $1 = ($0|0)==($obj|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z243mscorlib_System_UInt32_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_UInt32U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPjPP25mscorlib_System_Exception($__this,$s,$style,$provider,$tryParse,$result,$exc) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 $tryParse = $tryParse|0;
 $result = $result|0;
 $exc = $exc|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy = 0, $$lobit = 0, $$lobit10 = 0, $$lobit4 = 0, $$lobit5 = 0, $$lobit6 = 0, $$lobit7 = 0, $$lobit8 = 0, $$lobit9 = 0, $$not = 0, $$not24 = 0, $$not25 = 0, $$not27 = 0, $$not30 = 0, $$not31 = 0, $$pre = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$1 = 0, $V_11 = 0, $V_12$0$off0 = 0, $V_13 = 0, $V_14 = 0, $V_15 = 0, $V_16$0 = 0, $V_16$1 = 0, $V_16$2 = 0, $V_17$0 = 0, $V_17$1 = 0;
 var $V_17$2 = 0, $V_18$0$off0 = 0, $V_18$1$off0 = 0, $V_19$0 = 0, $_stackTraceSentry = 0, $brmerge = 0, $brmerge26 = 0, $brmerge28 = 0, $brmerge29 = 0, $brmerge32 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi47$index = 0, $lpad$phi47$index7 = 0, $or$cond = 0, $or$cond49 = 0, $or$cond50 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 12|0;
 $_stackTraceSentry = sp;
 $V_11 = sp + 4|0;
 $V_13 = sp + 18|0;
 $V_14 = sp + 17|0;
 $V_15 = sp + 16|0;
 $0 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163344);
 HEAP32[$V_11>>2] = 0;
 HEAP8[$V_13>>0] = 0;
 HEAP8[$V_14>>0] = 0;
 HEAP8[$V_15>>0] = 0;
 __THREW__ = 0;
 invoke_v(371);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 4;
  } else {
   HEAP32[$result>>2] = 0;
   HEAP32[$exc>>2] = 0;
   $3 = ($s|0)==(0|0);
   if ($3) {
    if ($tryParse) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     label = 4;
     break;
    }
    $13 = HEAP32[3004776>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     label = 4;
     break;
    }
    HEAP32[$exc>>2] = $10;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    label = 4;
   } else {
    __THREW__ = 0;
    $18 = (invoke_ii(1816,($s|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 4;
    } else {
     $21 = ($18|0)==(0);
     if ($21) {
      if ($tryParse) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      $22 = (invoke_ii(1790,0)|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       label = 4;
       break;
      }
      HEAP32[$exc>>2] = $22;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $25 = ($provider|0)==(0|0);
     if ($25) {
      label = 24;
     } else {
      HEAP32[$0>>2] = 2271128;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $26 = (invoke_iii(772,0,($$byval_copy|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($provider|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $31 = (invoke_iiii(1666,(2606440|0),($provider|0),($26|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2348608|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2755,($31|0),(2348608|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 4;
       break;
      }
      $39 = ($36|0)==(0|0);
      if ($39) {
       label = 24;
      } else {
       $V_0$1 = $36;
      }
     }
     if ((label|0) == 24) {
      __THREW__ = 0;
      $40 = (invoke_ii(2405,(0|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $43 = (invoke_iii(1178,(0|0),($40|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($43|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2730,(2330184|0),($43|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 4;
       break;
      }
      $V_0$1 = $48;
     }
     __THREW__ = 0;
     $51 = (invoke_iiiii(80,0,($style|0),($tryParse|0),($exc|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      label = 4;
     } else {
      if (!($51)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $$lobit = $style >>> 8;
      $$lobit4 = $style & 512;
      $54 = ($$lobit4|0)!=(0);
      $$lobit5 = $style & 64;
      $55 = ($$lobit5|0)==(0);
      $$lobit6 = $style & 32;
      $56 = ($$lobit6|0)==(0);
      $$lobit7 = $style & 16;
      $57 = ($$lobit7|0)==(0);
      $$lobit8 = $style & 8;
      $58 = ($$lobit8|0)!=(0);
      $$lobit9 = $style & 4;
      $59 = ($$lobit9|0)!=(0);
      $$lobit10 = $style >>> 1;
      $60 = $style & 1;
      $61 = ($60|0)!=(0);
      HEAP32[$V_11>>2] = 0;
      if ($61) {
       __THREW__ = 0;
       $62 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 4;
        break;
       }
       if (!($62)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      HEAP8[$V_13>>0] = 0;
      HEAP8[$V_14>>0] = 0;
      HEAP8[$V_15>>0] = 0;
      do {
       if ($57) {
        $132 = 0;$V_12$0$off0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($s|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break L1;
        }
        $67 = HEAP32[$V_11>>2]|0;
        __THREW__ = 0;
        $68 = (invoke_iii(621,($s|0),($67|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 4;
         break L1;
        }
        $71 = ($68<<16>>16)==(40);
        if ($71) {
         HEAP8[$V_14>>0] = 1;
         HEAP8[$V_13>>0] = 1;
         $72 = HEAP32[$V_11>>2]|0;
         $73 = (($72) + 1)|0;
         HEAP32[$V_11>>2] = $73;
         if ($61) {
          __THREW__ = 0;
          $74 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 4;
           break L1;
          }
          if (!($74)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $79 = (invoke_ii(2029,($V_0$1|0))|0);
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if ($81) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($79|0));
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $84 = (invoke_ii(1816,($79|0))|0);
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          label = 4;
          break L1;
         }
         $89 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $90 = (invoke_iiii(528,($s|0),($89|0),($84|0))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $95 = (invoke_ii(2029,($V_0$1|0))|0);
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $98 = (invoke_iiii(574,0,($90|0),($95|0))|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          label = 4;
          break L1;
         }
         if ($98) {
          if ($tryParse) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $101 = (invoke_ii(1790,0)|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           label = 4;
           break L1;
          }
          HEAP32[$exc>>2] = $101;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $106 = (invoke_ii(2044,($V_0$1|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($106|0));
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $111 = (invoke_ii(1816,($106|0))|0);
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if ($113) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $114 = __THREW__; __THREW__ = 0;
         $115 = $114&1;
         if ($115) {
          label = 4;
          break L1;
         }
         $116 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $117 = (invoke_iiii(528,($s|0),($116|0),($111|0))|0);
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $120 = __THREW__; __THREW__ = 0;
         $121 = $120&1;
         if ($121) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $122 = (invoke_ii(2044,($V_0$1|0))|0);
         $123 = __THREW__; __THREW__ = 0;
         $124 = $123&1;
         if ($124) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $125 = (invoke_iiii(574,0,($117|0),($122|0))|0);
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if ($127) {
          label = 4;
          break L1;
         }
         if (!($125)) {
          $132 = 1;$V_12$0$off0 = 1;
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $128 = (invoke_ii(1790,0)|0);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $128;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         $132 = 0;$V_12$0$off0 = 0;
        }
       }
      } while(0);
      do {
       if ($59) {
        $131 = ($132<<24>>24)==(0);
        if ($131) {
         __THREW__ = 0;
         invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          label = 4;
          break L1;
         }
         $135 = HEAP8[$V_14>>0]|0;
         $136 = ($135<<24>>24)==(0);
         if ($136) {
          $152 = 0;$160 = 0;
         } else {
          if ($61) {
           __THREW__ = 0;
           $137 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            label = 4;
            break L1;
           }
           if (!($137)) {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
          $140 = $$lobit & 1;
          $141 = ($140|0)==(0);
          if ($141) {
           $152 = 0;$160 = $135;
          } else {
           __THREW__ = 0;
           invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
           $142 = __THREW__; __THREW__ = 0;
           $143 = $142&1;
           if ($143) {
            label = 4;
            break L1;
           }
           $144 = HEAP8[$V_15>>0]|0;
           $145 = ($144<<24>>24)==(0);
           $$not = $61 ^ 1;
           $brmerge = $145 | $$not;
           if ($brmerge) {
            $152 = $144;$160 = $135;
           } else {
            __THREW__ = 0;
            $146 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $147 = __THREW__; __THREW__ = 0;
            $148 = $147&1;
            if ($148) {
             label = 4;
             break L1;
            }
            if ($146) {
             $152 = $144;$160 = $135;
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        } else {
         $152 = 0;$160 = 1;
        }
       } else {
        $152 = 0;$160 = $132;
       }
      } while(0);
      $149 = $$lobit & 1;
      $150 = ($149|0)!=(0);
      $151 = ($152<<24>>24)==(0);
      $or$cond49 = $150 & $151;
      do {
       if ($or$cond49) {
        __THREW__ = 0;
        invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
        $153 = __THREW__; __THREW__ = 0;
        $154 = $153&1;
        if ($154) {
         label = 4;
         break L1;
        }
        $155 = HEAP8[$V_15>>0]|0;
        $156 = ($155<<24>>24)==(0);
        if ($156) {
         $330 = $160;$428 = 0;
        } else {
         if ($61) {
          __THREW__ = 0;
          $157 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           label = 4;
           break L1;
          }
          if (!($157)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         $$not24 = ($160<<24>>24)!=(0);
         $$not25 = $59 ^ 1;
         $brmerge26 = $$not24 | $$not25;
         if ($brmerge26) {
          $330 = $160;$428 = $155;
         } else {
          __THREW__ = 0;
          invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
          $161 = __THREW__; __THREW__ = 0;
          $162 = $161&1;
          if ($162) {
           label = 4;
           break L1;
          }
          $163 = HEAP8[$V_14>>0]|0;
          $164 = ($163<<24>>24)==(0);
          $$not27 = $61 ^ 1;
          $brmerge28 = $164 | $$not27;
          if ($brmerge28) {
           $330 = $163;$428 = $155;
          } else {
           __THREW__ = 0;
           $165 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
           $166 = __THREW__; __THREW__ = 0;
           $167 = $166&1;
           if ($167) {
            label = 4;
            break L1;
           }
           if ($165) {
            $330 = $163;$428 = $155;
            break;
           } else {
            $$0 = 0;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       } else {
        $330 = $160;$428 = $152;
       }
      } while(0);
      $V_16$0 = 0;$V_17$0 = 0;$V_18$0$off0 = 0;
      L120: while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $168 = __THREW__; __THREW__ = 0;
       $169 = $168&1;
       if ($169) {
        label = 3;
        break;
       }
       $170 = HEAP32[$V_11>>2]|0;
       __THREW__ = 0;
       $171 = (invoke_iii(621,($s|0),($170|0))|0);
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       if ($173) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $174 = (invoke_iiii(456,0,($171|0),($54|0))|0);
       $175 = __THREW__; __THREW__ = 0;
       $176 = $175&1;
       if ($176) {
        label = 3;
        break;
       }
       do {
        if ($174) {
         $193 = (($V_17$0) + 1)|0;
         if (!($54)) {
          if ($V_18$0$off0) {
           $234 = HEAP32[$V_11>>2]|0;
           $235 = (($234) + 1)|0;
           HEAP32[$V_11>>2] = $235;
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $236 = __THREW__; __THREW__ = 0;
           $237 = $236&1;
           if ($237) {
            label = 3;
            break L120;
           }
           __THREW__ = 0;
           $238 = (invoke_iii(621,($s|0),($234|0))|0);
           $239 = __THREW__; __THREW__ = 0;
           $240 = $239&1;
           if ($240) {
            label = 3;
            break L120;
           }
           $241 = ($238<<16>>16)==(48);
           if ($241) {
            $V_16$1 = $V_16$0;$V_17$1 = $193;$V_18$1$off0 = 1;
            break;
           } else {
            label = 126;
            break L120;
           }
          }
          $253 = ($V_16$0*10)|0;
          $254 = HEAP32[$V_11>>2]|0;
          $255 = ($254|0)==(2147483647);
          if ($255) {
           label = 133;
           break L120;
          }
          $275 = (($254) + 1)|0;
          HEAP32[$V_11>>2] = $275;
          __THREW__ = 0;
          invoke_vi(3799,($s|0));
          $276 = __THREW__; __THREW__ = 0;
          $277 = $276&1;
          if ($277) {
           label = 136;
           break L120;
          }
          __THREW__ = 0;
          $278 = (invoke_iii(621,($s|0),($254|0))|0);
          $279 = __THREW__; __THREW__ = 0;
          $280 = $279&1;
          if ($280) {
           label = 136;
           break L120;
          }
          $281 = $278&65535;
          $282 = (($281) + 65488)|0;
          $283 = $282 & 65535;
          $284 = ($253|0)<(0);
          $285 = $284 << 31 >> 31;
          $286 = (_i64Add(($283|0),0,($253|0),($285|0))|0);
          $287 = tempRet0;
          $288 = ($287|0)>(0);
          $289 = ($287|0)==(0);
          $290 = ($286>>>0)>(2147483647);
          $291 = $289 & $290;
          $292 = $288 | $291;
          if ($292) {
           label = 145;
           break L120;
          }
          $298 = (($283) + ($253))|0;
          $V_16$1 = $298;$V_17$1 = $193;$V_18$1$off0 = 0;
          break;
         }
         $194 = HEAP32[$V_11>>2]|0;
         $195 = (($194) + 1)|0;
         HEAP32[$V_11>>2] = $195;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $196 = __THREW__; __THREW__ = 0;
         $197 = $196&1;
         if ($197) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $198 = (invoke_iii(621,($s|0),($194|0))|0);
         $199 = __THREW__; __THREW__ = 0;
         $200 = $199&1;
         if ($200) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $201 = (invoke_iii(600,0,($198|0))|0);
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          label = 3;
          break L120;
         }
         do {
          if ($201) {
           $204 = $198&65535;
           $205 = (($204) + 65488)|0;
           $206 = $205 & 65535;
           $V_19$0 = $206;
          } else {
           __THREW__ = 0;
           $207 = (invoke_iii(602,0,($198|0))|0);
           $208 = __THREW__; __THREW__ = 0;
           $209 = $208&1;
           if ($209) {
            label = 3;
            break L120;
           }
           $210 = $198&65535;
           if ($207) {
            $211 = (($210) + 65439)|0;
            $212 = $211 & 65535;
            $213 = (($212) + 10)|0;
            $V_19$0 = $213;
            break;
           } else {
            $214 = (($210) + 65471)|0;
            $215 = $214 & 65535;
            $216 = (($215) + 10)|0;
            $V_19$0 = $216;
            break;
           }
          }
         } while(0);
         $217 = $V_16$0 << 4;
         if ($tryParse) {
          $218 = (($V_19$0) + ($217))|0;
          $V_16$1 = $218;$V_17$1 = $193;$V_18$1$off0 = $V_18$0$off0;
          break;
         }
         $219 = ($217|0)<(0);
         $220 = $219 << 31 >> 31;
         $221 = (_i64Add(($V_19$0|0),0,($217|0),($220|0))|0);
         $222 = tempRet0;
         $223 = ($222|0)>(0);
         $224 = ($222|0)==(0);
         $225 = ($221>>>0)>(2147483647);
         $226 = $224 & $225;
         $227 = $223 | $226;
         if ($227) {
          label = 118;
          break L120;
         }
         $233 = (($V_19$0) + ($217))|0;
         $V_16$1 = $233;$V_17$1 = $193;$V_18$1$off0 = $V_18$0$off0;
        } else {
         if (!($55)) {
          __THREW__ = 0;
          invoke_vi(3799,($V_0$1|0));
          $177 = __THREW__; __THREW__ = 0;
          $178 = $177&1;
          if ($178) {
           label = 3;
           break L120;
          }
          __THREW__ = 0;
          $179 = (invoke_ii(2032,($V_0$1|0))|0);
          $180 = __THREW__; __THREW__ = 0;
          $181 = $180&1;
          if ($181) {
           label = 3;
           break L120;
          }
          __THREW__ = 0;
          $182 = (invoke_iiiii(81,0,($V_11|0),($s|0),($179|0))|0);
          $183 = __THREW__; __THREW__ = 0;
          $184 = $183&1;
          if ($184) {
           label = 3;
           break L120;
          }
          if ($182) {
           $V_16$1 = $V_16$0;$V_17$1 = $V_17$0;$V_18$1$off0 = $V_18$0$off0;
           break;
          }
         }
         $brmerge29 = $V_18$0$off0 | $56;
         if ($brmerge29) {
          $V_16$2 = $V_16$0;$V_17$2 = $V_17$0;
          label = 160;
          break L120;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $185 = __THREW__; __THREW__ = 0;
         $186 = $185&1;
         if ($186) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $187 = (invoke_ii(2031,($V_0$1|0))|0);
         $188 = __THREW__; __THREW__ = 0;
         $189 = $188&1;
         if ($189) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $190 = (invoke_iiiii(81,0,($V_11|0),($s|0),($187|0))|0);
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          label = 3;
          break L120;
         }
         if ($190) {
          $V_16$1 = $V_16$0;$V_17$1 = $V_17$0;$V_18$1$off0 = 1;
         } else {
          $V_16$2 = $V_16$0;$V_17$2 = $V_17$0;
          label = 160;
          break L120;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $318 = __THREW__; __THREW__ = 0;
       $319 = $318&1;
       if ($319) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $320 = (invoke_ii(1816,($s|0))|0);
       $321 = __THREW__; __THREW__ = 0;
       $322 = $321&1;
       if ($322) {
        label = 3;
        break;
       }
       $323 = HEAP32[$V_11>>2]|0;
       $324 = ($323|0)<($320|0);
       if ($324) {
        $V_16$0 = $V_16$1;$V_17$0 = $V_17$1;$V_18$0$off0 = $V_18$1$off0;
       } else {
        $V_16$2 = $V_16$1;$V_17$2 = $V_17$1;
        label = 160;
        break;
       }
      }
      if ((label|0) == 3) {
       $4 = ___cxa_find_matching_catch()|0;
       $5 = tempRet0;
       $lpad$phi$index = $4;$lpad$phi$index2 = $5;
       break;
      }
      else if ((label|0) == 118) {
       __THREW__ = 0;
       $228 = (invoke_i(133)|0);
       $229 = __THREW__; __THREW__ = 0;
       $230 = $229&1;
       if ($230) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3830,($228|0));
       $231 = __THREW__; __THREW__ = 0;
       $232 = $231&1;
       if ($232) {
        label = 4;
        break;
       }
       // unreachable;
      }
      else if ((label|0) == 126) {
       if ($tryParse) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $242 = HEAP32[3004784>>2]|0;
       __THREW__ = 0;
       $243 = (invoke_iii(783,0,($242|0))|0);
       $244 = __THREW__; __THREW__ = 0;
       $245 = $244&1;
       if ($245) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2635888|0))|0);
       $246 = __THREW__; __THREW__ = 0;
       $247 = $246&1;
       if ($247) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $248 = (invoke_ii(3469,(2635888|0))|0);
       $249 = __THREW__; __THREW__ = 0;
       $250 = $249&1;
       if ($250) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vii(1971,($248|0),($243|0));
       $251 = __THREW__; __THREW__ = 0;
       $252 = $251&1;
       if ($252) {
        label = 4;
        break;
       }
       HEAP32[$exc>>2] = $248;
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      else if ((label|0) == 133) {
       __THREW__ = 0;
       $256 = (invoke_i(133)|0);
       $257 = __THREW__; __THREW__ = 0;
       $258 = $257&1;
       if ($258) {
        label = 137;
       } else {
        __THREW__ = 0;
        invoke_vi(3830,($256|0));
        $259 = __THREW__; __THREW__ = 0;
        $260 = $259&1;
        if ($260) {
         label = 137;
        } else {
         // unreachable;
        }
       }
      }
      else if ((label|0) == 136) {
       $261 = ___cxa_find_matching_catch(348288|0)|0;
       $262 = tempRet0;
       $lpad$phi47$index = $261;$lpad$phi47$index7 = $262;
      }
      else if ((label|0) == 145) {
       __THREW__ = 0;
       $293 = (invoke_i(133)|0);
       $294 = __THREW__; __THREW__ = 0;
       $295 = $294&1;
       if ($295) {
        label = 137;
       } else {
        __THREW__ = 0;
        invoke_vi(3830,($293|0));
        $296 = __THREW__; __THREW__ = 0;
        $297 = $296&1;
        if ($297) {
         label = 137;
        } else {
         // unreachable;
        }
       }
      }
      else if ((label|0) == 160) {
       $325 = ($V_17$2|0)==(0);
       if ($325) {
        if ($tryParse) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        $326 = (invoke_ii(1790,0)|0);
        $327 = __THREW__; __THREW__ = 0;
        $328 = $327&1;
        if ($328) {
         label = 4;
         break;
        }
        HEAP32[$exc>>2] = $326;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $329 = ($330<<24>>24)==(0);
       $or$cond50 = $58 & $329;
       do {
        if ($or$cond50) {
         __THREW__ = 0;
         invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
         $331 = __THREW__; __THREW__ = 0;
         $332 = $331&1;
         if ($332) {
          label = 4;
          break L1;
         }
         $333 = HEAP8[$V_14>>0]|0;
         $334 = ($333<<24>>24)==(0);
         if ($334) {
          $429 = 0;
          label = 173;
         } else {
          $335 = $$lobit10 & 1;
          $336 = ($335|0)==(0);
          do {
           if (!($336)) {
            __THREW__ = 0;
            $337 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $338 = __THREW__; __THREW__ = 0;
            $339 = $338&1;
            if ($339) {
             label = 4;
             break L1;
            }
            if ($337) {
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          } while(0);
          if (!($150)) {
           break;
          }
          __THREW__ = 0;
          invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
          $340 = __THREW__; __THREW__ = 0;
          $341 = $340&1;
          if ($341) {
           label = 4;
           break L1;
          }
          $$pre = HEAP8[$V_15>>0]|0;
          $343 = $$pre;$353 = $333;
          label = 174;
         }
        } else {
         $429 = $330;
         label = 173;
        }
       } while(0);
       if ((label|0) == 173) {
        if ($150) {
         $343 = $428;$353 = $429;
         label = 174;
        }
       }
       do {
        if ((label|0) == 174) {
         $342 = ($343<<24>>24)==(0);
         if ($342) {
          __THREW__ = 0;
          invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
          $344 = __THREW__; __THREW__ = 0;
          $345 = $344&1;
          if ($345) {
           label = 4;
           break L1;
          }
          $346 = HEAP8[$V_15>>0]|0;
          $347 = ($346<<24>>24)==(0);
          if (!($347)) {
           $348 = $$lobit10 & 1;
           $349 = ($348|0)==(0);
           do {
            if (!($349)) {
             __THREW__ = 0;
             $350 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
             $351 = __THREW__; __THREW__ = 0;
             $352 = $351&1;
             if ($352) {
              label = 4;
              break L1;
             }
             if ($350) {
              break;
             } else {
              $$0 = 0;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           } while(0);
           $$not30 = ($353<<24>>24)!=(0);
           $$not31 = $58 ^ 1;
           $brmerge32 = $$not30 | $$not31;
           if ($brmerge32) {
            break;
           }
           __THREW__ = 0;
           invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
           $354 = __THREW__; __THREW__ = 0;
           $355 = $354&1;
           if ($355) {
            label = 4;
            break L1;
           }
          }
         }
        }
       } while(0);
       $356 = $$lobit10 & 1;
       $357 = ($356|0)!=(0);
       do {
        if ($357) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $358 = __THREW__; __THREW__ = 0;
         $359 = $358&1;
         if ($359) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $360 = (invoke_ii(1816,($s|0))|0);
         $361 = __THREW__; __THREW__ = 0;
         $362 = $361&1;
         if ($362) {
          label = 4;
          break L1;
         }
         $363 = HEAP32[$V_11>>2]|0;
         $364 = ($363|0)<($360|0);
         if (!($364)) {
          break;
         }
         __THREW__ = 0;
         $365 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),0,($tryParse|0),($exc|0))|0);
         $366 = __THREW__; __THREW__ = 0;
         $367 = $366&1;
         if ($367) {
          label = 4;
          break L1;
         }
         if ($365) {
          break;
         } else {
          $$0 = 0;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       L228: do {
        if ($V_12$0$off0) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $368 = __THREW__; __THREW__ = 0;
         $369 = $368&1;
         if ($369) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $370 = (invoke_ii(1816,($s|0))|0);
         $371 = __THREW__; __THREW__ = 0;
         $372 = $371&1;
         if ($372) {
          label = 4;
          break L1;
         }
         $373 = HEAP32[$V_11>>2]|0;
         $374 = ($373|0)<($370|0);
         do {
          if ($374) {
           $375 = (($373) + 1)|0;
           HEAP32[$V_11>>2] = $375;
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $376 = __THREW__; __THREW__ = 0;
           $377 = $376&1;
           if ($377) {
            label = 4;
            break L1;
           }
           __THREW__ = 0;
           $378 = (invoke_iii(621,($s|0),($373|0))|0);
           $379 = __THREW__; __THREW__ = 0;
           $380 = $379&1;
           if ($380) {
            label = 4;
            break L1;
           }
           $381 = ($378<<16>>16)==(41);
           if (!($381)) {
            break;
           }
           if (!($357)) {
            break L228;
           }
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $385 = __THREW__; __THREW__ = 0;
           $386 = $385&1;
           if ($386) {
            label = 4;
            break L1;
           }
           __THREW__ = 0;
           $387 = (invoke_ii(1816,($s|0))|0);
           $388 = __THREW__; __THREW__ = 0;
           $389 = $388&1;
           if ($389) {
            label = 4;
            break L1;
           }
           $390 = HEAP32[$V_11>>2]|0;
           $391 = ($390|0)<($387|0);
           if (!($391)) {
            break L228;
           }
           __THREW__ = 0;
           $392 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),0,($tryParse|0),($exc|0))|0);
           $393 = __THREW__; __THREW__ = 0;
           $394 = $393&1;
           if ($394) {
            label = 4;
            break L1;
           }
           if ($392) {
            break L228;
           } else {
            $$0 = 0;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         } while(0);
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $382 = (invoke_ii(1790,0)|0);
         $383 = __THREW__; __THREW__ = 0;
         $384 = $383&1;
         if ($384) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $382;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $395 = __THREW__; __THREW__ = 0;
       $396 = $395&1;
       if ($396) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $397 = (invoke_ii(1816,($s|0))|0);
       $398 = __THREW__; __THREW__ = 0;
       $399 = $398&1;
       if ($399) {
        label = 4;
        break;
       }
       $400 = HEAP32[$V_11>>2]|0;
       $401 = ($400|0)<($397|0);
       do {
        if ($401) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $402 = __THREW__; __THREW__ = 0;
         $403 = $402&1;
         if ($403) {
          label = 4;
          break L1;
         }
         $404 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $405 = (invoke_iii(621,($s|0),($404|0))|0);
         $406 = __THREW__; __THREW__ = 0;
         $407 = $406&1;
         if ($407) {
          label = 4;
          break L1;
         }
         $408 = ($405<<16>>16)==(0);
         if ($408) {
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $409 = (invoke_ii(1790,0)|0);
         $410 = __THREW__; __THREW__ = 0;
         $411 = $410&1;
         if ($411) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $409;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       $412 = HEAP8[$V_13>>0]|0;
       $413 = ($412<<24>>24)==(0);
       $414 = ($V_16$2|0)==(0);
       $or$cond = $413 | $414;
       if ($or$cond) {
        HEAP32[$result>>2] = $V_16$2;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       if ($tryParse) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $415 = HEAP32[3004800>>2]|0;
       __THREW__ = 0;
       $416 = (invoke_iii(783,0,($415|0))|0);
       $417 = __THREW__; __THREW__ = 0;
       $418 = $417&1;
       if ($418) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2635888|0))|0);
       $419 = __THREW__; __THREW__ = 0;
       $420 = $419&1;
       if ($420) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $421 = (invoke_ii(3469,(2635888|0))|0);
       $422 = __THREW__; __THREW__ = 0;
       $423 = $422&1;
       if ($423) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vii(1971,($421|0),($416|0));
       $424 = __THREW__; __THREW__ = 0;
       $425 = $424&1;
       if ($425) {
        label = 4;
        break;
       }
       HEAP32[$exc>>2] = $421;
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      if ((label|0) == 137) {
       $263 = ___cxa_find_matching_catch(348288|0)|0;
       $264 = tempRet0;
       $lpad$phi47$index = $263;$lpad$phi47$index7 = $264;
      }
      $265 = (_llvm_eh_typeid_for((348288|0))|0);
      $266 = ($lpad$phi47$index7|0)==($265|0);
      if (!($266)) {
       $$01 = $lpad$phi47$index;$$02 = $lpad$phi47$index7;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$01|0);
       // unreachable;
      }
      $267 = (___cxa_begin_catch(($lpad$phi47$index|0))|0);
      $268 = HEAP32[$267>>2]|0;
      $269 = HEAP32[$268>>2]|0;
      __THREW__ = 0;
      $270 = (invoke_iii(2727,(2635888|0),($269|0))|0);
      $271 = __THREW__; __THREW__ = 0;
      $272 = $271&1;
      do {
       if (!($272)) {
        if (!($270)) {
         $303 = (___cxa_allocate_exception(4)|0);
         $304 = HEAP32[$267>>2]|0;
         HEAP32[$303>>2] = $304;
         __THREW__ = 0;
         invoke_viii(1567,($303|0),(348288|0),(0|0));
         $305 = __THREW__; __THREW__ = 0;
         $306 = $305&1;
         if ($306) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        invoke_v(66);
        $273 = __THREW__; __THREW__ = 0;
        $274 = $273&1;
        if ($274) {
         label = 4;
         break L1;
        }
        if ($tryParse) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $307 = HEAP32[3004792>>2]|0;
        __THREW__ = 0;
        $308 = (invoke_iii(783,0,($307|0))|0);
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        if ($310) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2635888|0))|0);
        $311 = __THREW__; __THREW__ = 0;
        $312 = $311&1;
        if ($312) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        $313 = (invoke_ii(3469,(2635888|0))|0);
        $314 = __THREW__; __THREW__ = 0;
        $315 = $314&1;
        if ($315) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        invoke_vii(1971,($313|0),($308|0));
        $316 = __THREW__; __THREW__ = 0;
        $317 = $316&1;
        if ($317) {
         label = 4;
         break L1;
        }
        HEAP32[$exc>>2] = $313;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $299 = ___cxa_find_matching_catch()|0;
      $300 = tempRet0;
      __THREW__ = 0;
      invoke_v(66);
      $301 = __THREW__; __THREW__ = 0;
      $302 = $301&1;
      if ($302) {
       $426 = ___cxa_find_matching_catch(0|0)|0;
       $427 = tempRet0;
       ___clang_call_terminate($426);
       // unreachable;
      } else {
       $$01 = $299;$$02 = $300;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$01|0);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $lpad$phi$index = $6;$lpad$phi$index2 = $7;
 }
 $$01 = $lpad$phi$index;$$02 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z151mscorlib_System_UInt32_m_Parse_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163392);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(67,0,($s|0),($style|0),($provider|0),0,($V_1|0),($V_0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 }
 if ($0) {
  $8 = HEAP32[$V_1>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 $5 = HEAP32[$V_0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3830,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  // unreachable;
 }
 return 0|0;
}
function __Z108mscorlib_System_UInt32_m_Parse_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163440);
 __THREW__ = 0;
 $0 = (invoke_iiiii(84,0,($s|0),7,($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z56mscorlib_System_UInt32_m_ToString_mscorlib_System_StringPj($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163488);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iiii(1231,(0|0),($0|0),(0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_UInt32_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPjP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163536);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iiii(1231,(0|0),($0|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_UInt32_m_ToString_mscorlib_System_String_mscorlib_System_StringPjP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163584);
 __THREW__ = 0;
 $0 = (invoke_iiii(476,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z111mscorlib_System_UInt32_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPjP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2163632);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iiiii(193,(0|0),($format|0),($0|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsE6InvokeEPFiPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_UInt32TraitsE6InvokeEPFbPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I28mscorlib_System_UInt32Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFjPvS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 HEAP32[$ret>>2] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_UInt32Traits17VoidPointerTraitsS1_E6InvokeEPFjPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z53mscorlib_System_UInt32_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z205mscorlib_System_UInt32_CustomAttributesCacheGenerator_mscorlib_System_UInt32_m_Parse_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z162mscorlib_System_UInt32_CustomAttributesCacheGenerator_mscorlib_System_UInt32_m_Parse_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_CLSCompliantAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,32767);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_UInt64_m_System_IConvertible_ToBooleanPyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165032);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(970,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_UInt64_m_System_IConvertible_ToBytePyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165080);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(982,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_UInt64_m_System_IConvertible_ToCharPyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165128);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(996,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_UInt64_m_System_IConvertible_ToDateTimePyP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165176);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viiii(180,($agg$result|0),(0|0),($2|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_UInt64_m_System_IConvertible_ToDecimalPyP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165224);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_viiii(183,($agg$result|0),(0|0),($2|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_UInt64_m_System_IConvertible_ToDoublePyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165272);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (+invoke_diii(4,(0|0),($2|0),($5|0)));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$6);
 }
 return +0;
}
function __Z52mscorlib_System_UInt64_m_System_IConvertible_ToInt16PyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165320);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1037,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt64_m_System_IConvertible_ToInt32PyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165368);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1044,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt64_m_System_IConvertible_ToInt64PyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165416);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1056,(0|0),($2|0),($5|0))|0);
 $7 = tempRet0;
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt64_m_System_IConvertible_ToSBytePyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165464);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1073,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_UInt64_m_System_IConvertible_ToSinglePyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165512);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (Math_fround(+(invoke_fiii(4,(0|0),($2|0),($5|0)))));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($6));
 }
 return Math_fround(0);
}
function __Z51mscorlib_System_UInt64_m_System_IConvertible_ToTypePyP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165560);
 __THREW__ = 0;
 invoke_v(372);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = $__this;
    $16 = $15;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + 4)|0;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = $L_2;
    $22 = $21;
    HEAP32[$22>>2] = $17;
    $23 = (($21) + 4)|0;
    $24 = $23;
    HEAP32[$24>>2] = $20;
    __THREW__ = 0;
    (invoke_ii(2996,(2167208|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __THREW__ = 0;
    $27 = (invoke_iii(2724,(2167208|0),($L_2|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    $30 = (invoke_iiiiii(126,(0|0),($27|0),($targetType|0),($provider|0),0)|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($30|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3004848>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_UInt64_m_System_IConvertible_ToUInt16PyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165608);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1100,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_UInt64_m_System_IConvertible_ToUInt32PyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165656);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiii(1115,(0|0),($2|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_UInt64_m_System_IConvertible_ToUInt64PyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165704);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $5;
 STACKTOP = sp;return ($2|0);
}
function __Z79mscorlib_System_UInt64_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPyP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165752);
 __THREW__ = 0;
 invoke_v(373);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2167208|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2167208|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3004864>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2167208|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = $26;
      $30 = $29;
      $31 = HEAP32[$30>>2]|0;
      $32 = (($29) + 4)|0;
      $33 = $32;
      $34 = HEAP32[$33>>2]|0;
      $35 = $__this;
      $36 = $35;
      $37 = HEAP32[$36>>2]|0;
      $38 = (($35) + 4)|0;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = ($37|0)==($31|0);
      $42 = ($40|0)==($34|0);
      $43 = $41 & $42;
      if ($43) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $44 = ($40>>>0)<($34>>>0);
      $45 = ($40|0)==($34|0);
      $46 = ($37>>>0)<($31>>>0);
      $47 = $45 & $46;
      $48 = $44 | $47;
      $$ = $48 ? -1 : 1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_UInt64_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPyP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165800);
 __THREW__ = 0;
 (invoke_ii(2996,(2167208|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2167208|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2167208|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2167208|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = $10;
     $14 = $13;
     $15 = HEAP32[$14>>2]|0;
     $16 = (($13) + 4)|0;
     $17 = $16;
     $18 = HEAP32[$17>>2]|0;
     $19 = $__this;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + 4)|0;
     $23 = $22;
     $24 = HEAP32[$23>>2]|0;
     $25 = ($15|0)==($21|0);
     $26 = ($18|0)==($24|0);
     $27 = $25 & $26;
     $$0 = $27;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_UInt64_m_GetHashCodePy($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165848);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 ^ $2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($6|0);
}
function __Z79mscorlib_System_UInt64_m_CompareTo_mscorlib_System_Int32_mscorlib_System_UInt64Pyy($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165896);
 $2 = $__this;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = ($4|0)==($0|0);
 $9 = ($7|0)==($1|0);
 $10 = $8 & $9;
 if ($10) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ($7>>>0)>($1>>>0);
 $12 = ($7|0)==($1|0);
 $13 = ($4>>>0)>($0>>>0);
 $14 = $12 & $13;
 $15 = $11 | $14;
 $$ = $15 ? 1 : -1;
 $$0 = $$;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z78mscorlib_System_UInt64_m_Equals_mscorlib_System_Boolean_mscorlib_System_UInt64Pyy($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165944);
 $2 = $__this;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = ($4|0)==($0|0);
 $9 = ($7|0)==($1|0);
 $10 = $8 & $9;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($10|0);
}
function __Z108mscorlib_System_UInt64_m_Parse_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2165992);
 __THREW__ = 0;
 $0 = (invoke_iiiii(85,0,($s|0),7,($provider|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z151mscorlib_System_UInt64_m_Parse_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $V_0 = sp + 8|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2166088);
 HEAP32[$V_0>>2] = 0;
 $0 = $V_1;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 $4 = (invoke_iiiiiiii(68,0,($s|0),($style|0),($provider|0),0,($V_1|0),($V_0|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 if ($4) {
  $12 = $V_1;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $17;
  STACKTOP = sp;return ($14|0);
 }
 $9 = HEAP32[$V_0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3830,($9|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  // unreachable;
 }
 return 0|0;
}
function __Z243mscorlib_System_UInt64_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_UInt64U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPyPP25mscorlib_System_Exception($__this,$s,$style,$provider,$tryParse,$result,$exc) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 $tryParse = $tryParse|0;
 $result = $result|0;
 $exc = $exc|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy = 0, $$lobit = 0, $$lobit10 = 0, $$lobit4 = 0, $$lobit5 = 0, $$lobit6 = 0, $$lobit7 = 0, $$lobit8 = 0, $$lobit9 = 0, $$mask = 0, $$mask23 = 0, $$not = 0, $$not26 = 0, $$not27 = 0, $$not29 = 0, $$not32 = 0, $$not33 = 0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$1 = 0, $V_11 = 0, $V_12$0$off0 = 0, $V_13 = 0, $V_14 = 0, $V_15 = 0;
 var $V_17$0 = 0, $V_17$1 = 0, $V_17$2 = 0, $V_18$0$off0 = 0, $V_18$1$off0 = 0, $V_19$0$in = 0, $_stackTraceSentry = 0, $brmerge = 0, $brmerge28 = 0, $brmerge30 = 0, $brmerge31 = 0, $brmerge34 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $lpad$phi48$index = 0, $lpad$phi48$index7 = 0, $or$cond = 0, $or$cond35 = 0, $or$cond51 = 0, $or$cond52 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 12|0;
 $_stackTraceSentry = sp;
 $V_11 = sp + 4|0;
 $V_13 = sp + 18|0;
 $V_14 = sp + 17|0;
 $V_15 = sp + 16|0;
 $0 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2166040);
 HEAP32[$V_11>>2] = 0;
 HEAP8[$V_13>>0] = 0;
 HEAP8[$V_14>>0] = 0;
 HEAP8[$V_15>>0] = 0;
 __THREW__ = 0;
 invoke_v(374);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 4;
  } else {
   $3 = $result;
   $4 = $3;
   HEAP32[$4>>2] = 0;
   $5 = (($3) + 4)|0;
   $6 = $5;
   HEAP32[$6>>2] = 0;
   HEAP32[$exc>>2] = 0;
   $7 = ($s|0)==(0|0);
   if ($7) {
    if ($tryParse) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2560584|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     label = 4;
     break;
    }
    $17 = HEAP32[3004944>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($14|0),($17|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 4;
     break;
    }
    HEAP32[$exc>>2] = $14;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    label = 4;
   } else {
    __THREW__ = 0;
    $22 = (invoke_ii(1816,($s|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 4;
    } else {
     $25 = ($22|0)==(0);
     if ($25) {
      if ($tryParse) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      $26 = (invoke_ii(1790,0)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 4;
       break;
      }
      HEAP32[$exc>>2] = $26;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $29 = ($provider|0)==(0|0);
     if ($29) {
      label = 24;
     } else {
      HEAP32[$0>>2] = 2271128;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $30 = (invoke_iii(772,0,($$byval_copy|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($provider|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_iiii(1666,(2606440|0),($provider|0),($30|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2348608|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $40 = (invoke_iii(2755,($35|0),(2348608|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 4;
       break;
      }
      $43 = ($40|0)==(0|0);
      if ($43) {
       label = 24;
      } else {
       $V_0$1 = $40;
      }
     }
     if ((label|0) == 24) {
      __THREW__ = 0;
      $44 = (invoke_ii(2405,(0|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(1178,(0|0),($44|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $52 = (invoke_iii(2730,(2330184|0),($47|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 4;
       break;
      }
      $V_0$1 = $52;
     }
     __THREW__ = 0;
     $55 = (invoke_iiiii(80,0,($style|0),($tryParse|0),($exc|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      label = 4;
     } else {
      if (!($55)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $$lobit = $style >>> 8;
      $$lobit4 = $style & 512;
      $58 = ($$lobit4|0)!=(0);
      $$lobit5 = $style & 64;
      $59 = ($$lobit5|0)==(0);
      $$lobit6 = $style & 32;
      $60 = ($$lobit6|0)==(0);
      $$lobit7 = $style & 16;
      $61 = ($$lobit7|0)==(0);
      $$lobit8 = $style & 8;
      $62 = ($$lobit8|0)!=(0);
      $$lobit9 = $style & 4;
      $63 = ($$lobit9|0)!=(0);
      $$lobit10 = $style >>> 1;
      $64 = $style & 1;
      $65 = ($64|0)!=(0);
      HEAP32[$V_11>>2] = 0;
      if ($65) {
       __THREW__ = 0;
       $66 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        label = 4;
        break;
       }
       if (!($66)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      HEAP8[$V_13>>0] = 0;
      HEAP8[$V_14>>0] = 0;
      HEAP8[$V_15>>0] = 0;
      do {
       if ($61) {
        $136 = 0;$V_12$0$off0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($s|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 4;
         break L1;
        }
        $71 = HEAP32[$V_11>>2]|0;
        __THREW__ = 0;
        $72 = (invoke_iii(621,($s|0),($71|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break L1;
        }
        $75 = ($72<<16>>16)==(40);
        if ($75) {
         HEAP8[$V_14>>0] = 1;
         HEAP8[$V_13>>0] = 1;
         $76 = HEAP32[$V_11>>2]|0;
         $77 = (($76) + 1)|0;
         HEAP32[$V_11>>2] = $77;
         if ($65) {
          __THREW__ = 0;
          $78 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 4;
           break L1;
          }
          if (!($78)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $83 = (invoke_ii(2029,($V_0$1|0))|0);
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($83|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $88 = (invoke_ii(1816,($83|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 4;
          break L1;
         }
         $93 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $94 = (invoke_iiii(528,($s|0),($93|0),($88|0))|0);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $99 = (invoke_ii(2029,($V_0$1|0))|0);
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $102 = (invoke_iiii(574,0,($94|0),($99|0))|0);
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          label = 4;
          break L1;
         }
         if ($102) {
          if ($tryParse) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $105 = (invoke_ii(1790,0)|0);
          $106 = __THREW__; __THREW__ = 0;
          $107 = $106&1;
          if ($107) {
           label = 4;
           break L1;
          }
          HEAP32[$exc>>2] = $105;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $110 = (invoke_ii(2044,($V_0$1|0))|0);
         $111 = __THREW__; __THREW__ = 0;
         $112 = $111&1;
         if ($112) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($110|0));
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $115 = (invoke_ii(1816,($110|0))|0);
         $116 = __THREW__; __THREW__ = 0;
         $117 = $116&1;
         if ($117) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          label = 4;
          break L1;
         }
         $120 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $121 = (invoke_iiii(528,($s|0),($120|0),($115|0))|0);
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $124 = __THREW__; __THREW__ = 0;
         $125 = $124&1;
         if ($125) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $126 = (invoke_ii(2044,($V_0$1|0))|0);
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $129 = (invoke_iiii(574,0,($121|0),($126|0))|0);
         $130 = __THREW__; __THREW__ = 0;
         $131 = $130&1;
         if ($131) {
          label = 4;
          break L1;
         }
         if (!($129)) {
          $136 = 1;$V_12$0$off0 = 1;
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $132 = (invoke_ii(1790,0)|0);
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $132;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         $136 = 0;$V_12$0$off0 = 0;
        }
       }
      } while(0);
      do {
       if ($63) {
        $135 = ($136<<24>>24)==(0);
        if ($135) {
         __THREW__ = 0;
         invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if ($138) {
          label = 4;
          break L1;
         }
         $139 = HEAP8[$V_14>>0]|0;
         $140 = ($139<<24>>24)==(0);
         if ($140) {
          $156 = 0;$164 = 0;
         } else {
          if ($65) {
           __THREW__ = 0;
           $141 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
           $142 = __THREW__; __THREW__ = 0;
           $143 = $142&1;
           if ($143) {
            label = 4;
            break L1;
           }
           if (!($141)) {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
          $144 = $$lobit & 1;
          $145 = ($144|0)==(0);
          if ($145) {
           $156 = 0;$164 = $139;
          } else {
           __THREW__ = 0;
           invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
           $146 = __THREW__; __THREW__ = 0;
           $147 = $146&1;
           if ($147) {
            label = 4;
            break L1;
           }
           $148 = HEAP8[$V_15>>0]|0;
           $149 = ($148<<24>>24)==(0);
           $$not = $65 ^ 1;
           $brmerge = $149 | $$not;
           if ($brmerge) {
            $156 = $148;$164 = $139;
           } else {
            __THREW__ = 0;
            $150 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            if ($152) {
             label = 4;
             break L1;
            }
            if ($150) {
             $156 = $148;$164 = $139;
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        } else {
         $156 = 0;$164 = 1;
        }
       } else {
        $156 = 0;$164 = $136;
       }
      } while(0);
      $153 = $$lobit & 1;
      $154 = ($153|0)!=(0);
      $155 = ($156<<24>>24)==(0);
      $or$cond51 = $154 & $155;
      do {
       if ($or$cond51) {
        __THREW__ = 0;
        invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         label = 4;
         break L1;
        }
        $159 = HEAP8[$V_15>>0]|0;
        $160 = ($159<<24>>24)==(0);
        if ($160) {
         $323 = $164;$429 = 0;
        } else {
         if ($65) {
          __THREW__ = 0;
          $161 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
          $162 = __THREW__; __THREW__ = 0;
          $163 = $162&1;
          if ($163) {
           label = 4;
           break L1;
          }
          if (!($161)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         $$not26 = ($164<<24>>24)!=(0);
         $$not27 = $63 ^ 1;
         $brmerge28 = $$not26 | $$not27;
         if ($brmerge28) {
          $323 = $164;$429 = $159;
         } else {
          __THREW__ = 0;
          invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
          $165 = __THREW__; __THREW__ = 0;
          $166 = $165&1;
          if ($166) {
           label = 4;
           break L1;
          }
          $167 = HEAP8[$V_14>>0]|0;
          $168 = ($167<<24>>24)==(0);
          $$not29 = $65 ^ 1;
          $brmerge30 = $168 | $$not29;
          if ($brmerge30) {
           $323 = $167;$429 = $159;
          } else {
           __THREW__ = 0;
           $169 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
           $170 = __THREW__; __THREW__ = 0;
           $171 = $170&1;
           if ($171) {
            label = 4;
            break L1;
           }
           if ($169) {
            $323 = $167;$429 = $159;
            break;
           } else {
            $$0 = 0;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       } else {
        $323 = $164;$429 = $156;
       }
      } while(0);
      $221 = 0;$224 = 0;$V_17$0 = 0;$V_18$0$off0 = 0;
      L120: while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       if ($173) {
        label = 3;
        break;
       }
       $174 = HEAP32[$V_11>>2]|0;
       __THREW__ = 0;
       $175 = (invoke_iii(621,($s|0),($174|0))|0);
       $176 = __THREW__; __THREW__ = 0;
       $177 = $176&1;
       if ($177) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $178 = (invoke_iiii(456,0,($175|0),($58|0))|0);
       $179 = __THREW__; __THREW__ = 0;
       $180 = $179&1;
       if ($180) {
        label = 3;
        break;
       }
       do {
        if ($178) {
         $197 = (($V_17$0) + 1)|0;
         if (!($58)) {
          if ($V_18$0$off0) {
           $240 = HEAP32[$V_11>>2]|0;
           $241 = (($240) + 1)|0;
           HEAP32[$V_11>>2] = $241;
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $242 = __THREW__; __THREW__ = 0;
           $243 = $242&1;
           if ($243) {
            label = 3;
            break L120;
           }
           __THREW__ = 0;
           $244 = (invoke_iii(621,($s|0),($240|0))|0);
           $245 = __THREW__; __THREW__ = 0;
           $246 = $245&1;
           if ($246) {
            label = 3;
            break L120;
           }
           $247 = ($244<<16>>16)==(48);
           if ($247) {
            $430 = $224;$431 = $221;$V_17$1 = $197;$V_18$1$off0 = 1;
            break;
           } else {
            label = 122;
            break L120;
           }
          }
          $259 = (___muldi3(($224|0),($221|0),10,0)|0);
          $260 = tempRet0;
          $261 = HEAP32[$V_11>>2]|0;
          $262 = ($261|0)==(2147483647);
          if ($262) {
           label = 129;
           break L120;
          }
          $282 = (($261) + 1)|0;
          HEAP32[$V_11>>2] = $282;
          __THREW__ = 0;
          invoke_vi(3799,($s|0));
          $283 = __THREW__; __THREW__ = 0;
          $284 = $283&1;
          if ($284) {
           label = 132;
           break L120;
          }
          __THREW__ = 0;
          $285 = (invoke_iii(621,($s|0),($261|0))|0);
          $286 = __THREW__; __THREW__ = 0;
          $287 = $286&1;
          if ($287) {
           label = 132;
           break L120;
          }
          $288 = $285&65535;
          $289 = (($288) + 65488)|0;
          $$mask = $289 & 65535;
          $290 = (_i64Add(($$mask|0),0,($259|0),($260|0))|0);
          $291 = tempRet0;
          $430 = $290;$431 = $291;$V_17$1 = $197;$V_18$1$off0 = 0;
          break;
         }
         $198 = HEAP32[$V_11>>2]|0;
         $199 = (($198) + 1)|0;
         HEAP32[$V_11>>2] = $199;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $200 = __THREW__; __THREW__ = 0;
         $201 = $200&1;
         if ($201) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $202 = (invoke_iii(621,($s|0),($198|0))|0);
         $203 = __THREW__; __THREW__ = 0;
         $204 = $203&1;
         if ($204) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $205 = (invoke_iii(600,0,($202|0))|0);
         $206 = __THREW__; __THREW__ = 0;
         $207 = $206&1;
         if ($207) {
          label = 3;
          break L120;
         }
         do {
          if ($205) {
           $208 = $202&65535;
           $209 = (($208) + 65488)|0;
           $$mask23 = $209 & 65535;
           $V_19$0$in = $$mask23;
          } else {
           __THREW__ = 0;
           $210 = (invoke_iii(602,0,($202|0))|0);
           $211 = __THREW__; __THREW__ = 0;
           $212 = $211&1;
           if ($212) {
            label = 3;
            break L120;
           }
           $213 = $202&65535;
           if ($210) {
            $214 = (($213) + 65439)|0;
            $215 = $214 & 65535;
            $216 = (($215) + 10)|0;
            $V_19$0$in = $216;
            break;
           } else {
            $217 = (($213) + 65471)|0;
            $218 = $217 & 65535;
            $219 = (($218) + 10)|0;
            $V_19$0$in = $219;
            break;
           }
          }
         } while(0);
         if ($tryParse) {
          $220 = ($221>>>0)<(0);
          $222 = ($221|0)==(0);
          $223 = ($224>>>0)<(65536);
          $225 = $222 & $223;
          $226 = $220 | $225;
          $227 = (_bitshift64Shl(($224|0),($221|0),4)|0);
          $228 = tempRet0;
          $229 = (_i64Add(($V_19$0$in|0),0,($227|0),($228|0))|0);
          $230 = tempRet0;
          $231 = ($230>>>0)>(0);
          $232 = ($230|0)==(0);
          $233 = ($229>>>0)>(15);
          $234 = $232 & $233;
          $235 = $231 | $234;
          $or$cond = $226 | $235;
          if ($or$cond) {
           $430 = $229;$431 = $230;$V_17$1 = $197;$V_18$1$off0 = $V_18$0$off0;
           break;
          } else {
           $$0 = 0;
           label = 213;
           break L120;
          }
         } else {
          $236 = (_bitshift64Shl(($224|0),($221|0),4)|0);
          $237 = tempRet0;
          $238 = (_i64Add(($V_19$0$in|0),0,($236|0),($237|0))|0);
          $239 = tempRet0;
          $430 = $238;$431 = $239;$V_17$1 = $197;$V_18$1$off0 = $V_18$0$off0;
          break;
         }
        } else {
         if (!($59)) {
          __THREW__ = 0;
          invoke_vi(3799,($V_0$1|0));
          $181 = __THREW__; __THREW__ = 0;
          $182 = $181&1;
          if ($182) {
           label = 3;
           break L120;
          }
          __THREW__ = 0;
          $183 = (invoke_ii(2032,($V_0$1|0))|0);
          $184 = __THREW__; __THREW__ = 0;
          $185 = $184&1;
          if ($185) {
           label = 3;
           break L120;
          }
          __THREW__ = 0;
          $186 = (invoke_iiiii(81,0,($V_11|0),($s|0),($183|0))|0);
          $187 = __THREW__; __THREW__ = 0;
          $188 = $187&1;
          if ($188) {
           label = 3;
           break L120;
          }
          if ($186) {
           $430 = $224;$431 = $221;$V_17$1 = $V_17$0;$V_18$1$off0 = $V_18$0$off0;
           break;
          }
         }
         $brmerge31 = $V_18$0$off0 | $60;
         if ($brmerge31) {
          $408 = $224;$410 = $221;$V_17$2 = $V_17$0;
          label = 152;
          break L120;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$1|0));
         $189 = __THREW__; __THREW__ = 0;
         $190 = $189&1;
         if ($190) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $191 = (invoke_ii(2031,($V_0$1|0))|0);
         $192 = __THREW__; __THREW__ = 0;
         $193 = $192&1;
         if ($193) {
          label = 3;
          break L120;
         }
         __THREW__ = 0;
         $194 = (invoke_iiiii(81,0,($V_11|0),($s|0),($191|0))|0);
         $195 = __THREW__; __THREW__ = 0;
         $196 = $195&1;
         if ($196) {
          label = 3;
          break L120;
         }
         if ($194) {
          $430 = $224;$431 = $221;$V_17$1 = $V_17$0;$V_18$1$off0 = 1;
         } else {
          $408 = $224;$410 = $221;$V_17$2 = $V_17$0;
          label = 152;
          break L120;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $311 = __THREW__; __THREW__ = 0;
       $312 = $311&1;
       if ($312) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $313 = (invoke_ii(1816,($s|0))|0);
       $314 = __THREW__; __THREW__ = 0;
       $315 = $314&1;
       if ($315) {
        label = 3;
        break;
       }
       $316 = HEAP32[$V_11>>2]|0;
       $317 = ($316|0)<($313|0);
       if ($317) {
        $221 = $431;$224 = $430;$V_17$0 = $V_17$1;$V_18$0$off0 = $V_18$1$off0;
       } else {
        $408 = $430;$410 = $431;$V_17$2 = $V_17$1;
        label = 152;
        break;
       }
      }
      if ((label|0) == 3) {
       $8 = ___cxa_find_matching_catch()|0;
       $9 = tempRet0;
       $lpad$phi$index = $8;$lpad$phi$index2 = $9;
       break;
      }
      else if ((label|0) == 122) {
       if ($tryParse) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $248 = HEAP32[3004952>>2]|0;
       __THREW__ = 0;
       $249 = (invoke_iii(783,0,($248|0))|0);
       $250 = __THREW__; __THREW__ = 0;
       $251 = $250&1;
       if ($251) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2635888|0))|0);
       $252 = __THREW__; __THREW__ = 0;
       $253 = $252&1;
       if ($253) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $254 = (invoke_ii(3469,(2635888|0))|0);
       $255 = __THREW__; __THREW__ = 0;
       $256 = $255&1;
       if ($256) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vii(1971,($254|0),($249|0));
       $257 = __THREW__; __THREW__ = 0;
       $258 = $257&1;
       if ($258) {
        label = 4;
        break;
       }
       HEAP32[$exc>>2] = $254;
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      else if ((label|0) == 129) {
       __THREW__ = 0;
       $263 = (invoke_i(133)|0);
       $264 = __THREW__; __THREW__ = 0;
       $265 = $264&1;
       if (!($265)) {
        __THREW__ = 0;
        invoke_vi(3830,($263|0));
        $266 = __THREW__; __THREW__ = 0;
        $267 = $266&1;
        if (!($267)) {
         // unreachable;
        }
       }
       $270 = ___cxa_find_matching_catch(348288|0)|0;
       $271 = tempRet0;
       $lpad$phi48$index = $270;$lpad$phi48$index7 = $271;
      }
      else if ((label|0) == 132) {
       $268 = ___cxa_find_matching_catch(348288|0)|0;
       $269 = tempRet0;
       $lpad$phi48$index = $268;$lpad$phi48$index7 = $269;
      }
      else if ((label|0) == 152) {
       $318 = ($V_17$2|0)==(0);
       if ($318) {
        if ($tryParse) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        $319 = (invoke_ii(1790,0)|0);
        $320 = __THREW__; __THREW__ = 0;
        $321 = $320&1;
        if ($321) {
         label = 4;
         break;
        }
        HEAP32[$exc>>2] = $319;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $322 = ($323<<24>>24)==(0);
       $or$cond52 = $62 & $322;
       do {
        if ($or$cond52) {
         __THREW__ = 0;
         invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
         $324 = __THREW__; __THREW__ = 0;
         $325 = $324&1;
         if ($325) {
          label = 4;
          break L1;
         }
         $326 = HEAP8[$V_14>>0]|0;
         $327 = ($326<<24>>24)==(0);
         if ($327) {
          $432 = 0;
          label = 165;
         } else {
          $328 = $$lobit10 & 1;
          $329 = ($328|0)==(0);
          do {
           if (!($329)) {
            __THREW__ = 0;
            $330 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
            $331 = __THREW__; __THREW__ = 0;
            $332 = $331&1;
            if ($332) {
             label = 4;
             break L1;
            }
            if ($330) {
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          } while(0);
          if (!($154)) {
           break;
          }
          __THREW__ = 0;
          invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
          $333 = __THREW__; __THREW__ = 0;
          $334 = $333&1;
          if ($334) {
           label = 4;
           break L1;
          }
          $$pre = HEAP8[$V_15>>0]|0;
          $336 = $$pre;$346 = $326;
          label = 166;
         }
        } else {
         $432 = $323;
         label = 165;
        }
       } while(0);
       if ((label|0) == 165) {
        if ($154) {
         $336 = $429;$346 = $432;
         label = 166;
        }
       }
       do {
        if ((label|0) == 166) {
         $335 = ($336<<24>>24)==(0);
         if ($335) {
          __THREW__ = 0;
          invoke_viiiii(45,0,($V_11|0),($s|0),($V_0$1|0),($V_15|0));
          $337 = __THREW__; __THREW__ = 0;
          $338 = $337&1;
          if ($338) {
           label = 4;
           break L1;
          }
          $339 = HEAP8[$V_15>>0]|0;
          $340 = ($339<<24>>24)==(0);
          if (!($340)) {
           $341 = $$lobit10 & 1;
           $342 = ($341|0)==(0);
           do {
            if (!($342)) {
             __THREW__ = 0;
             $343 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),1,($tryParse|0),($exc|0))|0);
             $344 = __THREW__; __THREW__ = 0;
             $345 = $344&1;
             if ($345) {
              label = 4;
              break L1;
             }
             if ($343) {
              break;
             } else {
              $$0 = 0;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           } while(0);
           $$not32 = ($346<<24>>24)!=(0);
           $$not33 = $62 ^ 1;
           $brmerge34 = $$not32 | $$not33;
           if ($brmerge34) {
            break;
           }
           __THREW__ = 0;
           invoke_viiiiii(50,0,($V_11|0),($s|0),($V_0$1|0),($V_14|0),($V_13|0));
           $347 = __THREW__; __THREW__ = 0;
           $348 = $347&1;
           if ($348) {
            label = 4;
            break L1;
           }
          }
         }
        }
       } while(0);
       $349 = $$lobit10 & 1;
       $350 = ($349|0)!=(0);
       do {
        if ($350) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $351 = __THREW__; __THREW__ = 0;
         $352 = $351&1;
         if ($352) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $353 = (invoke_ii(1816,($s|0))|0);
         $354 = __THREW__; __THREW__ = 0;
         $355 = $354&1;
         if ($355) {
          label = 4;
          break L1;
         }
         $356 = HEAP32[$V_11>>2]|0;
         $357 = ($356|0)<($353|0);
         if (!($357)) {
          break;
         }
         __THREW__ = 0;
         $358 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),0,($tryParse|0),($exc|0))|0);
         $359 = __THREW__; __THREW__ = 0;
         $360 = $359&1;
         if ($360) {
          label = 4;
          break L1;
         }
         if ($358) {
          break;
         } else {
          $$0 = 0;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       L225: do {
        if ($V_12$0$off0) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $361 = __THREW__; __THREW__ = 0;
         $362 = $361&1;
         if ($362) {
          label = 4;
          break L1;
         }
         __THREW__ = 0;
         $363 = (invoke_ii(1816,($s|0))|0);
         $364 = __THREW__; __THREW__ = 0;
         $365 = $364&1;
         if ($365) {
          label = 4;
          break L1;
         }
         $366 = HEAP32[$V_11>>2]|0;
         $367 = ($366|0)<($363|0);
         do {
          if ($367) {
           $368 = (($366) + 1)|0;
           HEAP32[$V_11>>2] = $368;
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $369 = __THREW__; __THREW__ = 0;
           $370 = $369&1;
           if ($370) {
            label = 4;
            break L1;
           }
           __THREW__ = 0;
           $371 = (invoke_iii(621,($s|0),($366|0))|0);
           $372 = __THREW__; __THREW__ = 0;
           $373 = $372&1;
           if ($373) {
            label = 4;
            break L1;
           }
           $374 = ($371<<16>>16)==(41);
           if (!($374)) {
            break;
           }
           if (!($350)) {
            break L225;
           }
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $378 = __THREW__; __THREW__ = 0;
           $379 = $378&1;
           if ($379) {
            label = 4;
            break L1;
           }
           __THREW__ = 0;
           $380 = (invoke_ii(1816,($s|0))|0);
           $381 = __THREW__; __THREW__ = 0;
           $382 = $381&1;
           if ($382) {
            label = 4;
            break L1;
           }
           $383 = HEAP32[$V_11>>2]|0;
           $384 = ($383|0)<($380|0);
           if (!($384)) {
            break L225;
           }
           __THREW__ = 0;
           $385 = (invoke_iiiiiii(50,0,($V_11|0),($s|0),0,($tryParse|0),($exc|0))|0);
           $386 = __THREW__; __THREW__ = 0;
           $387 = $386&1;
           if ($387) {
            label = 4;
            break L1;
           }
           if ($385) {
            break L225;
           } else {
            $$0 = 0;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         } while(0);
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $375 = (invoke_ii(1790,0)|0);
         $376 = __THREW__; __THREW__ = 0;
         $377 = $376&1;
         if ($377) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $375;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $388 = __THREW__; __THREW__ = 0;
       $389 = $388&1;
       if ($389) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $390 = (invoke_ii(1816,($s|0))|0);
       $391 = __THREW__; __THREW__ = 0;
       $392 = $391&1;
       if ($392) {
        label = 4;
        break;
       }
       $393 = HEAP32[$V_11>>2]|0;
       $394 = ($393|0)<($390|0);
       do {
        if ($394) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $395 = __THREW__; __THREW__ = 0;
         $396 = $395&1;
         if ($396) {
          label = 4;
          break L1;
         }
         $397 = HEAP32[$V_11>>2]|0;
         __THREW__ = 0;
         $398 = (invoke_iii(621,($s|0),($397|0))|0);
         $399 = __THREW__; __THREW__ = 0;
         $400 = $399&1;
         if ($400) {
          label = 4;
          break L1;
         }
         $401 = ($398<<16>>16)==(0);
         if ($401) {
          break;
         }
         if ($tryParse) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $402 = (invoke_ii(1790,0)|0);
         $403 = __THREW__; __THREW__ = 0;
         $404 = $403&1;
         if ($404) {
          label = 4;
          break L1;
         }
         HEAP32[$exc>>2] = $402;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } while(0);
       $405 = HEAP8[$V_13>>0]|0;
       $406 = ($405<<24>>24)==(0);
       $407 = ($408|0)==(0);
       $409 = ($410|0)==(0);
       $411 = $407 & $409;
       $or$cond35 = $406 | $411;
       if ($or$cond35) {
        $423 = $result;
        $424 = $423;
        HEAP32[$424>>2] = $408;
        $425 = (($423) + 4)|0;
        $426 = $425;
        HEAP32[$426>>2] = $410;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       if ($tryParse) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $412 = HEAP32[3004968>>2]|0;
       __THREW__ = 0;
       $413 = (invoke_iii(783,0,($412|0))|0);
       $414 = __THREW__; __THREW__ = 0;
       $415 = $414&1;
       if ($415) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2635888|0))|0);
       $416 = __THREW__; __THREW__ = 0;
       $417 = $416&1;
       if ($417) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       $418 = (invoke_ii(3469,(2635888|0))|0);
       $419 = __THREW__; __THREW__ = 0;
       $420 = $419&1;
       if ($420) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vii(1971,($418|0),($413|0));
       $421 = __THREW__; __THREW__ = 0;
       $422 = $421&1;
       if ($422) {
        label = 4;
        break;
       }
       HEAP32[$exc>>2] = $418;
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      else if ((label|0) == 213) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $272 = (_llvm_eh_typeid_for((348288|0))|0);
      $273 = ($lpad$phi48$index7|0)==($272|0);
      if (!($273)) {
       $$01 = $lpad$phi48$index;$$02 = $lpad$phi48$index7;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$01|0);
       // unreachable;
      }
      $274 = (___cxa_begin_catch(($lpad$phi48$index|0))|0);
      $275 = HEAP32[$274>>2]|0;
      $276 = HEAP32[$275>>2]|0;
      __THREW__ = 0;
      $277 = (invoke_iii(2727,(2635888|0),($276|0))|0);
      $278 = __THREW__; __THREW__ = 0;
      $279 = $278&1;
      do {
       if (!($279)) {
        if (!($277)) {
         $296 = (___cxa_allocate_exception(4)|0);
         $297 = HEAP32[$274>>2]|0;
         HEAP32[$296>>2] = $297;
         __THREW__ = 0;
         invoke_viii(1567,($296|0),(348288|0),(0|0));
         $298 = __THREW__; __THREW__ = 0;
         $299 = $298&1;
         if ($299) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        invoke_v(66);
        $280 = __THREW__; __THREW__ = 0;
        $281 = $280&1;
        if ($281) {
         label = 4;
         break L1;
        }
        if ($tryParse) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $300 = HEAP32[3004960>>2]|0;
        __THREW__ = 0;
        $301 = (invoke_iii(783,0,($300|0))|0);
        $302 = __THREW__; __THREW__ = 0;
        $303 = $302&1;
        if ($303) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2635888|0))|0);
        $304 = __THREW__; __THREW__ = 0;
        $305 = $304&1;
        if ($305) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        $306 = (invoke_ii(3469,(2635888|0))|0);
        $307 = __THREW__; __THREW__ = 0;
        $308 = $307&1;
        if ($308) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        invoke_vii(1971,($306|0),($301|0));
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        if ($310) {
         label = 4;
         break L1;
        }
        HEAP32[$exc>>2] = $306;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $292 = ___cxa_find_matching_catch()|0;
      $293 = tempRet0;
      __THREW__ = 0;
      invoke_v(66);
      $294 = __THREW__; __THREW__ = 0;
      $295 = $294&1;
      if ($295) {
       $427 = ___cxa_find_matching_catch(0|0)|0;
       $428 = tempRet0;
       ___clang_call_terminate($427);
       // unreachable;
      } else {
       $$01 = $292;$$02 = $293;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$01|0);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 }
 $$01 = $lpad$phi$index;$$02 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_UInt64_m_ToString_mscorlib_System_StringPy($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2166136);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiiii(196,(0|0),($2|0),($5|0),(0|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_UInt64_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPyP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2166184);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiiii(196,(0|0),($2|0),($5|0),($provider|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_UInt64_m_ToString_mscorlib_System_String_mscorlib_System_StringPyP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2166232);
 __THREW__ = 0;
 $0 = (invoke_iiii(485,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z111mscorlib_System_UInt64_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPyP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2166280);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iiiiii(133,(0|0),($format|0),($2|0),($5|0),($provider|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsE6InvokeEPFiPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_UInt64TraitsE6InvokeEPFbPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 $8 = $7&1;
 HEAP8[$ret>>0] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_UInt64Traits17VoidPointerTraitsS1_E6InvokeEPFyPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 $4 = tempRet0;
 $5 = $ret;
 $6 = $5;
 HEAP32[$6>>2] = $3;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $4;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker3I28mscorlib_System_UInt64Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFyPvS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 $7 = tempRet0;
 $8 = $ret;
 $9 = $8;
 HEAP32[$9>>2] = $6;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($12|0);
}
function __Z53mscorlib_System_UInt64_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z162mscorlib_System_UInt64_CustomAttributesCacheGenerator_mscorlib_System_UInt64_m_Parse_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z205mscorlib_System_UInt64_CustomAttributesCacheGenerator_mscorlib_System_UInt64_m_Parse_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z49mscorlib_System_Byte_m_System_IConvertible_ToTypePhP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167344);
 __THREW__ = 0;
 invoke_v(375);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = HEAP8[$__this>>0]|0;
    HEAP8[$L_2>>0] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2169424|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2169424|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3004984>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Byte_m_System_IConvertible_ToBooleanPhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167392);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1007,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z49mscorlib_System_Byte_m_System_IConvertible_ToBytePhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167440);
 $0 = HEAP8[$__this>>0]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z49mscorlib_System_Byte_m_System_IConvertible_ToCharPhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167488);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1022,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Byte_m_System_IConvertible_ToDateTimePhP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167536);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z52mscorlib_System_Byte_m_System_IConvertible_ToDecimalPhP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167584);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 invoke_viii(652,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z51mscorlib_System_Byte_m_System_IConvertible_ToDoublePhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167632);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (+invoke_dii(19,(0|0),($0|0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$1);
 }
 return +0;
}
function __Z50mscorlib_System_Byte_m_System_IConvertible_ToInt16PhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167680);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1029,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Byte_m_System_IConvertible_ToInt32PhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167728);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1038,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Byte_m_System_IConvertible_ToInt64PhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167776);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1047,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Byte_m_System_IConvertible_ToSBytePhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167824);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1057,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Byte_m_System_IConvertible_ToSinglePhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167872);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fii(25,(0|0),($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($1));
 }
 return Math_fround(0);
}
function __Z51mscorlib_System_Byte_m_System_IConvertible_ToUInt16PhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167920);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1065,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Byte_m_System_IConvertible_ToUInt32PhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2167968);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1073,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Byte_m_System_IConvertible_ToUInt64PhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168016);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1081,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z77mscorlib_System_Byte_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPhP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168064);
 __THREW__ = 0;
 invoke_v(376);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2169424|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2169424|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3005000>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2169424|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP8[$26>>0]|0;
      $30 = HEAP8[$__this>>0]|0;
      $31 = ($30<<24>>24)==($29<<24>>24);
      if ($31) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $32 = ($30&255)>($29&255);
      $$ = $32 ? 1 : -1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Byte_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPhP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168112);
 __THREW__ = 0;
 (invoke_ii(2996,(2169424|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2169424|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2169424|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2169424|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP8[$10>>0]|0;
     $14 = HEAP8[$__this>>0]|0;
     $15 = ($13<<24>>24)==($14<<24>>24);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Byte_m_GetHashCodePh($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168160);
 $0 = HEAP8[$__this>>0]|0;
 $1 = $0&255;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z75mscorlib_System_Byte_m_CompareTo_mscorlib_System_Int32_mscorlib_System_BytePhh($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168208);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)==($value<<24>>24);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = ($0&255)>($value&255);
  $$ = $2 ? 1 : -1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z74mscorlib_System_Byte_m_Equals_mscorlib_System_Boolean_mscorlib_System_BytePhh($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168256);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)==($obj<<24>>24);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z104mscorlib_System_Byte_m_Parse_mscorlib_System_Byte_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168304);
 __THREW__ = 0;
 $0 = (invoke_iiiii(86,0,($s|0),7,($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z147mscorlib_System_Byte_m_Parse_mscorlib_System_Byte_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168352);
 __THREW__ = 0;
 invoke_v(377);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iiiii(84,0,($s|0),($style|0),($provider|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2>>>0)<(256);
   if ($5) {
    $21 = $2&255;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   $8 = HEAP32[3005072>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_iii(783,0,($8|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_ii(3469,(2635888|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vii(1971,($14|0),($9|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       invoke_vi(3830,($14|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Byte_m_ToString_mscorlib_System_StringPh($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168400);
 $0 = HEAP8[$__this>>0]|0;
 $1 = $0&255;
 __THREW__ = 0;
 $2 = (invoke_iiii(1233,(0|0),($1|0),(0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z77mscorlib_System_Byte_m_ToString_mscorlib_System_String_mscorlib_System_StringPhP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168448);
 __THREW__ = 0;
 $0 = (invoke_iiii(492,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z109mscorlib_System_Byte_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPhP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168544);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iiiii(190,(0|0),($format|0),($0|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z86mscorlib_System_Byte_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPhP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2168496);
 $0 = HEAP8[$__this>>0]|0;
 $1 = $0&255;
 __THREW__ = 0;
 $2 = (invoke_iiii(1233,(0|0),($1|0),($provider|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsE6InvokeEPFiPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits26mscorlib_System_ByteTraitsE6InvokeEPFbPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I26mscorlib_System_ByteTraits17VoidPointerTraitsS1_E6InvokeEPFhPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I26mscorlib_System_ByteTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFhPvS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z51mscorlib_System_Byte_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_SByte_m_System_IConvertible_ToBooleanPaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169560);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1010,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_SByte_m_System_IConvertible_ToBytePaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169608);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1018,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_SByte_m_System_IConvertible_ToCharPaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169656);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1024,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_SByte_m_System_IConvertible_ToDateTimePaP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169704);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 invoke_viii(648,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_SByte_m_System_IConvertible_ToDecimalPaP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169752);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 invoke_viii(654,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52mscorlib_System_SByte_m_System_IConvertible_ToDoublePaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169800);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (+invoke_dii(22,(0|0),($0|0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$1);
 }
 return +0;
}
function __Z51mscorlib_System_SByte_m_System_IConvertible_ToInt16PaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169848);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1033,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_SByte_m_System_IConvertible_ToInt32PaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169896);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1041,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_SByte_m_System_IConvertible_ToInt64PaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169944);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1051,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_SByte_m_System_IConvertible_ToSBytePaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2169992);
 $0 = HEAP8[$__this>>0]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z52mscorlib_System_SByte_m_System_IConvertible_ToSinglePaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170040);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fii(28,(0|0),($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($1));
 }
 return Math_fround(0);
}
function __Z50mscorlib_System_SByte_m_System_IConvertible_ToTypePaP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170088);
 __THREW__ = 0;
 invoke_v(378);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = HEAP8[$__this>>0]|0;
    HEAP8[$L_2>>0] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2171616|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2171616|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3005120>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_SByte_m_System_IConvertible_ToUInt16PaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170136);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1069,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_SByte_m_System_IConvertible_ToUInt32PaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170184);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1077,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_SByte_m_System_IConvertible_ToUInt64PaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170232);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1085,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_SByte_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPaP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170280);
 __THREW__ = 0;
 invoke_v(379);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($obj|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2171616|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($obj|0),(2171616|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3005136>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2171616|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($obj|0),(2171616|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP8[$26>>0]|0;
      $30 = HEAP8[$__this>>0]|0;
      $31 = ($30<<24>>24)==($29<<24>>24);
      if ($31) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $32 = ($30<<24>>24)>($29<<24>>24);
      $$ = $32 ? 1 : -1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_SByte_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPaP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170328);
 __THREW__ = 0;
 (invoke_ii(2996,(2171616|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2171616|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2171616|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2171616|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP8[$10>>0]|0;
     $14 = HEAP8[$__this>>0]|0;
     $15 = ($13<<24>>24)==($14<<24>>24);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_SByte_m_GetHashCodePa($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170376);
 $0 = HEAP8[$__this>>0]|0;
 $1 = $0 << 24 >> 24;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z77mscorlib_System_SByte_m_CompareTo_mscorlib_System_Int32_mscorlib_System_SBytePaa($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170424);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)==($value<<24>>24);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = ($0<<24>>24)>($value<<24>>24);
  $$ = $2 ? 1 : -1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z76mscorlib_System_SByte_m_Equals_mscorlib_System_Boolean_mscorlib_System_SBytePaa($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170472);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)==($obj<<24>>24);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z106mscorlib_System_SByte_m_Parse_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170520);
 __THREW__ = 0;
 $0 = (invoke_iiiii(87,0,($s|0),7,($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z149mscorlib_System_SByte_m_Parse_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170568);
 __THREW__ = 0;
 invoke_v(380);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iiiii(82,0,($s|0),($style|0),($provider|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $$off = (($2) + 128)|0;
   $5 = ($$off>>>0)<(256);
   if ($5) {
    $21 = $2&255;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   $8 = HEAP32[3005208>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_iii(783,0,($8|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_ii(3469,(2635888|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vii(1971,($14|0),($9|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       invoke_vi(3830,($14|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_SByte_m_ToString_mscorlib_System_StringPa($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170616);
 $0 = HEAP8[$__this>>0]|0;
 $1 = $0 << 24 >> 24;
 __THREW__ = 0;
 $2 = (invoke_iiii(1233,(0|0),($1|0),(0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z87mscorlib_System_SByte_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPaP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170664);
 $0 = HEAP8[$__this>>0]|0;
 $1 = $0 << 24 >> 24;
 __THREW__ = 0;
 $2 = (invoke_iiii(1233,(0|0),($1|0),($provider|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_SByte_m_ToString_mscorlib_System_String_mscorlib_System_StringPaP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170712);
 __THREW__ = 0;
 $0 = (invoke_iiii(499,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z110mscorlib_System_SByte_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPaP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2170760);
 $0 = HEAP8[$__this>>0]|0;
 __THREW__ = 0;
 $1 = (invoke_iiiii(189,(0|0),($format|0),($0|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits27mscorlib_System_SByteTraitsE6InvokeEPFiPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_SByteTraitsE6InvokeEPFbPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_SByteTraits17VoidPointerTraitsS1_E6InvokeEPFaPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_SByteTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFaPvS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z52mscorlib_System_SByte_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z159mscorlib_System_SByte_CustomAttributesCacheGenerator_mscorlib_System_SByte_m_Parse_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z202mscorlib_System_SByte_CustomAttributesCacheGenerator_mscorlib_System_SByte_m_Parse_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_Int16_m_System_IConvertible_ToBooleanPsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2171752);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1011,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Int16_m_System_IConvertible_ToBytePsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2171800);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1019,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Int16_m_System_IConvertible_ToCharPsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2171848);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1025,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Int16_m_System_IConvertible_ToDateTimePsP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2171896);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 invoke_viii(646,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_Int16_m_System_IConvertible_ToDecimalPsP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2171944);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 invoke_viii(655,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52mscorlib_System_Int16_m_System_IConvertible_ToDoublePsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2171992);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (+invoke_dii(23,(0|0),($0|0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$1);
 }
 return +0;
}
function __Z51mscorlib_System_Int16_m_System_IConvertible_ToInt16PsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172040);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1034,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Int16_m_System_IConvertible_ToInt32PsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172088);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1042,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Int16_m_System_IConvertible_ToInt64PsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172136);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1052,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Int16_m_System_IConvertible_ToSBytePsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172184);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1061,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int16_m_System_IConvertible_ToSinglePsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172232);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fii(29,(0|0),($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($1));
 }
 return Math_fround(0);
}
function __Z50mscorlib_System_Int16_m_System_IConvertible_ToTypePsP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172280);
 __THREW__ = 0;
 invoke_v(381);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = HEAP16[$__this>>1]|0;
    HEAP16[$L_2>>1] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2173776|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2173776|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3005224>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Int16_m_System_IConvertible_ToUInt16PsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172328);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1070,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int16_m_System_IConvertible_ToUInt32PsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172376);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1078,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Int16_m_System_IConvertible_ToUInt64PsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172424);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1086,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Int16_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPsP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172472);
 __THREW__ = 0;
 invoke_v(382);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2173776|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2173776|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3005240>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2173776|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2173776|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP16[$26>>1]|0;
      $30 = HEAP16[$__this>>1]|0;
      $31 = ($30<<16>>16)==($29<<16>>16);
      if ($31) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $32 = ($30<<16>>16)>($29<<16>>16);
      $$ = $32 ? 1 : -1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Int16_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPsP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172520);
 __THREW__ = 0;
 (invoke_ii(2996,(2173776|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2173776|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2173776|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2173776|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP16[$10>>1]|0;
     $14 = HEAP16[$__this>>1]|0;
     $15 = ($13<<16>>16)==($14<<16>>16);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_Int16_m_GetHashCodePs($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172568);
 $0 = HEAP16[$__this>>1]|0;
 $1 = $0 << 16 >> 16;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z77mscorlib_System_Int16_m_CompareTo_mscorlib_System_Int32_mscorlib_System_Int16Pss($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172616);
 $0 = HEAP16[$__this>>1]|0;
 $1 = ($0<<16>>16)==($value<<16>>16);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = ($0<<16>>16)>($value<<16>>16);
  $$ = $2 ? 1 : -1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z76mscorlib_System_Int16_m_Equals_mscorlib_System_Boolean_mscorlib_System_Int16Pss($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172664);
 $0 = HEAP16[$__this>>1]|0;
 $1 = ($0<<16>>16)==($obj<<16>>16);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z106mscorlib_System_Int16_m_Parse_mscorlib_System_Int16_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172712);
 __THREW__ = 0;
 $0 = (invoke_iiiii(88,0,($s|0),7,($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z149mscorlib_System_Int16_m_Parse_mscorlib_System_Int16_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172760);
 __THREW__ = 0;
 invoke_v(383);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iiiii(82,0,($s|0),($style|0),($provider|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $$off = (($2) + 32768)|0;
   $5 = ($$off>>>0)<(65536);
   if ($5) {
    $18 = $2&65535;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2635888|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3005312>>2]|0;
     __THREW__ = 0;
     invoke_vii(1971,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3830,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Int16_m_ToString_mscorlib_System_StringPs($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172808);
 $0 = HEAP16[$__this>>1]|0;
 $1 = $0 << 16 >> 16;
 __THREW__ = 0;
 $2 = (invoke_iiii(1233,(0|0),($1|0),(0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z87mscorlib_System_Int16_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPsP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172856);
 $0 = HEAP16[$__this>>1]|0;
 $1 = $0 << 16 >> 16;
 __THREW__ = 0;
 $2 = (invoke_iiii(1233,(0|0),($1|0),($provider|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Int16_m_ToString_mscorlib_System_String_mscorlib_System_StringPsP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172904);
 __THREW__ = 0;
 $0 = (invoke_iiii(506,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z110mscorlib_System_Int16_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPsP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2172952);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iiiii(192,(0|0),($format|0),($0|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits27mscorlib_System_Int16TraitsE6InvokeEPFiPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_Int16TraitsE6InvokeEPFbPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int16Traits17VoidPointerTraitsS1_E6InvokeEPFsPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP16[$ret>>1] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int16Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFsPvS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 HEAP16[$ret>>1] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z52mscorlib_System_Int16_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_UInt16_m_System_IConvertible_ToBooleanPtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2173912);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1013,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_UInt16_m_System_IConvertible_ToBytePtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2173960);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1021,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_UInt16_m_System_IConvertible_ToCharPtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174008);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1027,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_UInt16_m_System_IConvertible_ToDateTimePtP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174056);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 invoke_viii(649,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_UInt16_m_System_IConvertible_ToDecimalPtP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174104);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 invoke_viii(657,($agg$result|0),(0|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_UInt16_m_System_IConvertible_ToDoublePtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174152);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (+invoke_dii(25,(0|0),($0|0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$1);
 }
 return +0;
}
function __Z52mscorlib_System_UInt16_m_System_IConvertible_ToInt16PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174200);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1036,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt16_m_System_IConvertible_ToInt32PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174248);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1045,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt16_m_System_IConvertible_ToInt64PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174296);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1054,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_UInt16_m_System_IConvertible_ToSBytePtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174344);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1063,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_UInt16_m_System_IConvertible_ToSinglePtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174392);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fii(32,(0|0),($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($1));
 }
 return Math_fround(0);
}
function __Z51mscorlib_System_UInt16_m_System_IConvertible_ToTypePtP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174440);
 __THREW__ = 0;
 invoke_v(384);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = HEAP16[$__this>>1]|0;
    HEAP16[$L_2>>1] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2176024|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2176024|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3005328>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_UInt16_m_System_IConvertible_ToUInt16PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174488);
 $0 = HEAP16[$__this>>1]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z53mscorlib_System_UInt16_m_System_IConvertible_ToUInt32PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174536);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1079,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_UInt16_m_System_IConvertible_ToUInt64PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174584);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1088,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_UInt16_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPtP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174632);
 __THREW__ = 0;
 invoke_v(385);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2176024|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2176024|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if (!($10)) {
      $24 = HEAP16[$__this>>1]|0;
      $25 = $24&65535;
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iii(2753,($value|0),(2176024|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = HEAP16[$28>>1]|0;
      $32 = $31&65535;
      $33 = (($25) - ($32))|0;
      $$0 = $33;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $11 = HEAP32[3005344>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,0,($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(2560072|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vii(1924,($17|0),($12|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         invoke_vi(3830,($17|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_UInt16_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPtP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174680);
 __THREW__ = 0;
 (invoke_ii(2996,(2176024|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2176024|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2176024|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2176024|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP16[$10>>1]|0;
     $14 = HEAP16[$__this>>1]|0;
     $15 = ($13<<16>>16)==($14<<16>>16);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_UInt16_m_GetHashCodePt($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174728);
 $0 = HEAP16[$__this>>1]|0;
 $1 = $0&65535;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z79mscorlib_System_UInt16_m_CompareTo_mscorlib_System_Int32_mscorlib_System_UInt16Ptt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174776);
 $0 = HEAP16[$__this>>1]|0;
 $1 = $0&65535;
 $2 = $value&65535;
 $3 = (($1) - ($2))|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($3|0);
}
function __Z78mscorlib_System_UInt16_m_Equals_mscorlib_System_Boolean_mscorlib_System_UInt16Ptt($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174824);
 $0 = HEAP16[$__this>>1]|0;
 $1 = ($0<<16>>16)==($obj<<16>>16);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z108mscorlib_System_UInt16_m_Parse_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174872);
 __THREW__ = 0;
 $0 = (invoke_iiiii(89,0,($s|0),7,($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z151mscorlib_System_UInt16_m_Parse_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174920);
 __THREW__ = 0;
 invoke_v(386);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iiiii(84,0,($s|0),($style|0),($provider|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2>>>0)<(65536);
   if ($5) {
    $21 = $2&65535;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   $8 = HEAP32[3005424>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_iii(783,0,($8|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_ii(3469,(2635888|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vii(1971,($14|0),($9|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       invoke_vi(3830,($14|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_UInt16_m_ToString_mscorlib_System_StringPt($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2174968);
 $0 = HEAP16[$__this>>1]|0;
 $1 = $0&65535;
 __THREW__ = 0;
 $2 = (invoke_iiii(1233,(0|0),($1|0),(0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_UInt16_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2175016);
 $0 = HEAP16[$__this>>1]|0;
 $1 = $0&65535;
 __THREW__ = 0;
 $2 = (invoke_iiii(1233,(0|0),($1|0),($provider|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_UInt16_m_ToString_mscorlib_System_String_mscorlib_System_StringPtP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2175064);
 __THREW__ = 0;
 $0 = (invoke_iiii(513,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z111mscorlib_System_UInt16_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPtP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2175112);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iiiii(191,(0|0),($format|0),($0|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsE6InvokeEPFiPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_UInt16TraitsE6InvokeEPFbPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_UInt16Traits17VoidPointerTraitsS1_E6InvokeEPFtPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP16[$ret>>1] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I28mscorlib_System_UInt16Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFtPvS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 HEAP16[$ret>>1] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z53mscorlib_System_UInt16_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z162mscorlib_System_UInt16_CustomAttributesCacheGenerator_mscorlib_System_UInt16_m_Parse_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z205mscorlib_System_UInt16_CustomAttributesCacheGenerator_mscorlib_System_UInt16_m_Parse_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Collections_IEnumerator_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2176288)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Collections_IEnumerable_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2176544)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_IDisposable_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z29mscorlib_System_Char_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177376);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2180696 + 80|0))>>2]|0;
  $3 = (($2) + 4|0);
  __THREW__ = 0;
  (invoke_ii(2996,(2180696|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[((2180696 + 80|0))>>2]|0;
   $7 = (($6) + 8|0);
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[((2180696 + 80|0))>>2]|0;
    $11 = (($10) + 12|0);
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[((2180696 + 80|0))>>2]|0;
     $15 = (($14) + 16|0);
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      $18 = HEAP32[((2180696 + 80|0))>>2]|0;
      $19 = (($18) + 20|0);
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[((2180696 + 80|0))>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2180696|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $25 = (($22) + 24|0);
        $26 = HEAP32[((2180696 + 80|0))>>2]|0;
        $27 = (($26) + 28|0);
        __THREW__ = 0;
        invoke_viiiiiiii(11,0,($3|0),($7|0),($11|0),($15|0),($19|0),($25|0),($27|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if (!($29)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($30|0);
 // unreachable;
}
function __Z43mscorlib_System_Char_m_GetDataTablePointersP22mscorlib_System_ObjectPPhS2_PPdPPtS6_S6_S6_($__this,$category_data,$numeric_data,$numeric_data_values,$to_lower_data_low,$to_lower_data_high,$to_upper_data_low,$to_upper_data_high) {
 $__this = $__this|0;
 $category_data = $category_data|0;
 $numeric_data = $numeric_data|0;
 $numeric_data_values = $numeric_data_values|0;
 $to_lower_data_low = $to_lower_data_low|0;
 $to_lower_data_high = $to_lower_data_high|0;
 $to_upper_data_low = $to_upper_data_low|0;
 $to_upper_data_high = $to_upper_data_high|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178144);
 $0 = HEAP32[2178192>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   __THREW__ = 0;
   $2 = (invoke_ii(3473,(2178200|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($5|0);
    // unreachable;
   } else {
    HEAP32[2178192>>2] = $2;
    $7 = $2;
    break;
   }
  } else {
   $7 = $0;
  }
 } while(0);
 __THREW__ = 0;
 invoke_viiiiiii($7|0,($category_data|0),($numeric_data|0),($numeric_data_values|0),($to_lower_data_low|0),($to_lower_data_high|0),($to_upper_data_low|0),($to_upper_data_high|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z49mscorlib_System_Char_m_System_IConvertible_ToTypePtP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177424);
 __THREW__ = 0;
 invoke_v(387);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = HEAP16[$__this>>1]|0;
    HEAP16[$L_2>>1] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2180696|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3005440>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Char_m_System_IConvertible_ToBooleanPtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177472);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Char_m_System_IConvertible_ToBytePtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177520);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1015,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z49mscorlib_System_Char_m_System_IConvertible_ToCharPtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177568);
 $0 = HEAP16[$__this>>1]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z53mscorlib_System_Char_m_System_IConvertible_ToDateTimePtP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177616);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z52mscorlib_System_Char_m_System_IConvertible_ToDecimalPtP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177664);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z51mscorlib_System_Char_m_System_IConvertible_ToDoublePtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177712);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return +0;
}
function __Z50mscorlib_System_Char_m_System_IConvertible_ToInt16PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177760);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1030,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Char_m_System_IConvertible_ToInt32PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177808);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1039,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Char_m_System_IConvertible_ToInt64PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177856);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1048,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Char_m_System_IConvertible_ToSBytePtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177904);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1058,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Char_m_System_IConvertible_ToSinglePtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2177952);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return Math_fround(0);
}
function __Z51mscorlib_System_Char_m_System_IConvertible_ToUInt16PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178000);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1066,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Char_m_System_IConvertible_ToUInt32PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178048);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1074,(0|0),($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Char_m_System_IConvertible_ToUInt64PtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178096);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 $1 = (invoke_iii(1082,(0|0),($0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z77mscorlib_System_Char_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPtP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178344);
 __THREW__ = 0;
 invoke_v(388);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2180696|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3005456>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2180696|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP16[$26>>1]|0;
      $30 = HEAP16[$__this>>1]|0;
      $31 = ($30<<16>>16)==($29<<16>>16);
      if ($31) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $32 = ($30&65535)>($29&65535);
      $$ = $32 ? 1 : -1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Char_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPtP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178392);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2180696|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2180696|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP16[$10>>1]|0;
     $14 = HEAP16[$__this>>1]|0;
     $15 = ($13<<16>>16)==($14<<16>>16);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Char_m_CompareTo_mscorlib_System_Int32_mscorlib_System_CharPtt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178440);
 $0 = HEAP16[$__this>>1]|0;
 $1 = ($0<<16>>16)==($value<<16>>16);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = ($0&65535)>($value&65535);
  $$ = $2 ? 1 : -1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z74mscorlib_System_Char_m_Equals_mscorlib_System_Boolean_mscorlib_System_CharPtt($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178488);
 $0 = HEAP16[$__this>>1]|0;
 $1 = ($0<<16>>16)==($obj<<16>>16);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z34mscorlib_System_Char_m_GetHashCodePt($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178536);
 $0 = HEAP16[$__this>>1]|0;
 $1 = $0&65535;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z41mscorlib_System_Char_m_GetUnicodeCategoryP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178584);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2180696 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2180696|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2180696 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $c&65535;
    $18 = (($16) + ($17)|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = $19&255;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZL11RuntimeInitP8TypeInfo4495($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z31mscorlib_System_Char_m_IsLetterP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178680);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2180696 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2180696|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2180696 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $c&65535;
    $18 = (($16) + ($17)|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19&255)<(5);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Char_m_IsSurrogateP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178776);
 __THREW__ = 0;
 (invoke_ii(2996,(2180696|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2180696 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2180696|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2180696 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = $c&65535;
    $18 = (($16) + ($17)|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = ($19<<24>>24)==(16);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z28mscorlib_System_Char_m_ParseP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178872);
 __THREW__ = 0;
 invoke_v(389);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3005528>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($s|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(1);
     if ($20) {
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(621,($s|0),0)|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($36|0);
     }
     $21 = HEAP32[3005536>>2]|0;
     __THREW__ = 0;
     $22 = (invoke_iii(783,0,($21|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2603176|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_ii(3469,(2603176|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vii(1940,($27|0),($22|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         __THREW__ = 0;
         invoke_vi(3830,($27|0));
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if (!($33)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Char_m_ToLowerInvariantP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178920);
 $0 = $c&65535;
 $1 = ($c&65535)>(9423);
 do {
  if ($1) {
   $21 = ($c&65535)<(65313);
   if ($21) {
    $$0 = $c;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = HEAP8[((2180696 + 116|0))>>0]|0;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2180696|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     $34 = HEAP32[((2180696 + 80|0))>>2]|0;
     $35 = (($34) + 20|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = $0 << 1;
     $38 = (($37) + 446)|0;
     $39 = $38 & 131070;
     $40 = (($36) + ($39)|0);
     $41 = HEAP16[$40>>1]|0;
     $$0 = $41;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2180696 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2180696|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2180696 + 80|0))>>2]|0;
     $17 = (($16) + 16|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + ($0<<1)|0);
     $20 = HEAP16[$19>>1]|0;
     $$0 = $20;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z30mscorlib_System_Char_m_ToLowerP22mscorlib_System_ObjecttP41mscorlib_System_Globalization_CultureInfo($__this,$c,$culture) {
 $__this = $__this|0;
 $c = $c|0;
 $culture = $culture|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2178968);
 __THREW__ = 0;
 invoke_v(390);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($culture|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3005624>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($culture|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(2729,(2273552|0),($culture|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(127);
     if ($20) {
      __THREW__ = 0;
      $21 = (invoke_iii(606,0,($c|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      } else {
       $$0 = $21;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($culture|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      $26 = (invoke_iii(2730,(2273600|0),($culture|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        $31 = (invoke_iiii(1667,(2274320|0),($26|0),($c|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         $$0 = $31;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I26mscorlib_System_CharTraitsS0_E6InvokeEP10MethodInfoPvt($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z39mscorlib_System_Char_m_ToUpperInvariantP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2179016);
 $0 = $c&65535;
 $1 = ($c&65535)>(9449);
 do {
  if ($1) {
   $21 = ($c&65535)<(65313);
   if ($21) {
    $$0 = $c;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = HEAP8[((2180696 + 116|0))>>0]|0;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2180696|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     $34 = HEAP32[((2180696 + 80|0))>>2]|0;
     $35 = (($34) + 28|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = $0 << 1;
     $38 = (($37) + 446)|0;
     $39 = $38 & 131070;
     $40 = (($36) + ($39)|0);
     $41 = HEAP16[$40>>1]|0;
     $$0 = $41;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2180696|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2180696 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2180696|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2180696|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2180696 + 80|0))>>2]|0;
     $17 = (($16) + 24|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($18) + ($0<<1)|0);
     $20 = HEAP16[$19>>1]|0;
     $$0 = $20;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Char_m_ToString_mscorlib_System_StringPt($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2179064);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(3469,(2191608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiii(570,0,($0|0),1)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_Char_mscorlib_System_Int32P22mscorlib_System_Stringti($__this,$c,$count) {
 $__this = $__this|0;
 $c = $c|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$05 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185976);
 __THREW__ = 0;
 invoke_v(391);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($count|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3008472>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($count|0)==(0);
   if (!($15)) {
    __THREW__ = 0;
    $30 = (invoke_iii(643,0,($count|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __THREW__ = 0;
    $33 = (invoke_ii(1919,0)|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = $30;
    $37 = (($33) + ($36))|0;
    $38 = $37;
    $39 = $count << 1;
    $40 = $37;
    $41 = (($40) + ($39)|0);
    $42 = ($38>>>0)<($41>>>0);
    if ($42) {
     $V_2$05 = $38;
    } else {
     $$0 = $30;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    while(1) {
     HEAP16[$V_2$05>>1] = $c;
     $43 = (($V_2$05) + 2|0);
     $44 = ($43>>>0)<($41>>>0);
     if ($44) {
      $V_2$05 = $43;
     } else {
      $$0 = $30;
      break;
     }
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP8[((2191608 + 116|0))>>0]|0;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = HEAP32[((2191608 + 80|0))>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $$0 = $29;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Char_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPtP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2179112);
 $0 = HEAP16[$__this>>1]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(3469,(2191608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiii(570,0,($0|0),1)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker7I17VoidPointerTraitsS0_S0_S0_S0_S0_S0_E6InvokeEPFvPvS2_S2_S2_S2_S2_S2_S2_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$action & 63]($obj,$0,$2,$4,$6,$8,$10,$12);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsE6InvokeEPFbPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraitsS0_E6InvokeEPFtPvtES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I26mscorlib_System_CharTraitsS0_17VoidPointerTraitsE6InvokeEPFtPvtS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$3)|0);
 HEAP16[$ret>>1] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z51mscorlib_System_Char_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z125mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringPtii($__this,$value,$startIndex,$length) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2180832);
 $0 = HEAP32[2180880>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2180888|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2180880>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiii($7|0,($__this|0),($value|0),($startIndex|0),($length|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z124mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringP24mscorlib_System_Char_arrii($__this,$value,$startIndex,$length) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2180952);
 $0 = HEAP32[2181000>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2181008|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2181000>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiii($7|0,($__this|0),($value|0),($startIndex|0),($length|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z80mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181072);
 $0 = HEAP32[2181120>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2181128|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2181120>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z94mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Char_mscorlib_System_Int32P22mscorlib_System_Stringti($__this,$c,$count) {
 $__this = $__this|0;
 $c = $c|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181168);
 $0 = HEAP32[2181216>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2181224|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2181216>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($__this|0),($c|0),($count|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z31mscorlib_System_String_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181272);
 __THREW__ = 0;
 invoke_v(392);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = HEAP32[3005656>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2191608|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[((2191608 + 80|0))>>2]|0;
   HEAP32[$6>>2] = $3;
   __THREW__ = 0;
   (invoke_ii(2996,(1168808|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2754,(1168808|0),27)|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     HEAP32[$0>>2] = 2666928;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_viii(551,0,($9|0),($$byval_copy|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = HEAP32[((2191608 + 80|0))>>2]|0;
       $17 = (($16) + 4|0);
       HEAP32[$17>>2] = $9;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z151mscorlib_System_Runtime_CompilerServices_RuntimeHelpers_m_InitializeArray_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_RuntimeFieldHandleP22mscorlib_System_ObjectP21mscorlib_System_Array34mscorlib_System_RuntimeFieldHandle($__this,$_____array,$fldHandle) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $fldHandle = $fldHandle|0;
 var $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2256032);
 $3 = ($_____array|0)==(0|0);
 if ($3) {
  label = 7;
 } else {
  __THREW__ = 0;
  $4 = (invoke_ii(1912,($fldHandle|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2210080|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[((2210080 + 80|0))>>2]|0;
    $10 = HEAP32[$9>>2]|0;
    HEAP32[$0>>2] = $4;
    HEAP32[$1>>2] = $10;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    $11 = (invoke_iiii(643,0,($$byval_copy|0),($$byval_copy2|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     if ($11) {
      label = 7;
     } else {
      __THREW__ = 0;
      $25 = (invoke_ii(1912,($fldHandle|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       HEAP32[$2>>2] = $25;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
       invoke_viii(550,0,($_____array|0),($$byval_copy2|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 if ((label|0) == 7) {
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_ii(3469,(2560584|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    invoke_vi(2585,($18|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     invoke_vi(3830,($18|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z54mscorlib_System_String_m_System_IConvertible_ToBooleanP22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181320);
 __THREW__ = 0;
 $0 = (invoke_iiii(969,(0|0),($__this|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_String_m_System_IConvertible_ToByteP22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181368);
 __THREW__ = 0;
 $0 = (invoke_iiii(980,(0|0),($__this|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_String_m_System_IConvertible_ToCharP22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181416);
 __THREW__ = 0;
 $0 = (invoke_iiii(993,(0|0),($__this|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_String_m_System_IConvertible_ToDateTimeP22mscorlib_System_StringP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181464);
 __THREW__ = 0;
 invoke_viiii(177,($agg$result|0),(0|0),($__this|0),($provider|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_String_m_System_IConvertible_ToDecimalP22mscorlib_System_StringP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181512);
 __THREW__ = 0;
 invoke_viiii(182,($agg$result|0),(0|0),($__this|0),($provider|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_String_m_System_IConvertible_ToDoubleP22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181560);
 __THREW__ = 0;
 $0 = (+invoke_diii(3,(0|0),($__this|0),($provider|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$0);
 }
 return +0;
}
function __Z52mscorlib_System_String_m_System_IConvertible_ToInt16P22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181608);
 __THREW__ = 0;
 $0 = (invoke_iiii(1035,(0|0),($__this|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_String_m_System_IConvertible_ToInt32P22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181656);
 __THREW__ = 0;
 $0 = (invoke_iiii(1043,(0|0),($__this|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_String_m_System_IConvertible_ToInt64P22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181704);
 __THREW__ = 0;
 $0 = (invoke_iiii(1054,(0|0),($__this|0),($provider|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_String_m_System_IConvertible_ToSByteP22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181752);
 __THREW__ = 0;
 $0 = (invoke_iiii(1071,(0|0),($__this|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_String_m_System_IConvertible_ToSingleP22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181800);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fiii(3,(0|0),($__this|0),($provider|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($0));
 }
 return Math_fround(0);
}
function __Z51mscorlib_System_String_m_System_IConvertible_ToTypeP22mscorlib_System_StringP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181848);
 __THREW__ = 0;
 invoke_v(393);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iiiiii(126,(0|0),($__this|0),($targetType|0),($provider|0),0)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3005672>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_String_m_System_IConvertible_ToUInt16P22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181896);
 __THREW__ = 0;
 $0 = (invoke_iiii(1098,(0|0),($__this|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_String_m_System_IConvertible_ToUInt32P22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181944);
 __THREW__ = 0;
 $0 = (invoke_iiii(1114,(0|0),($__this|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_String_m_System_IConvertible_ToUInt64P22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2181992);
 __THREW__ = 0;
 $0 = (invoke_iiii(1130,(0|0),($__this|0),($provider|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z91mscorlib_System_String_m_System_Collections_Generic_IEnumerableU003CcharU003E_GetEnumeratorP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182040);
 __THREW__ = 0;
 (invoke_ii(2996,(2565912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2565912|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1929,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$lcssa = 0, $V_0$06 = 0, $V_0$1 = 0, $V_0$2 = 0, $V_3$0$lcssa = 0, $V_3$05 = 0, $V_3$1 = 0, $V_3$2 = 0, $V_4$0$lcssa = 0, $V_4$04 = 0, $V_4$1 = 0, $V_4$2 = 0, $_stackTraceSentry = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182088);
 $0 = ($a|0)==($b|0);
 L1: do {
  if ($0) {
   $$0 = 1;
  } else {
   $1 = ($a|0)==(0|0);
   $2 = ($b|0)==(0|0);
   $or$cond = $1 | $2;
   if ($or$cond) {
    $$0 = 0;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($a|0));
    $3 = __THREW__; __THREW__ = 0;
    $4 = $3&1;
    if ($4) {
     $12 = ___cxa_find_matching_catch()|0;
     $13 = tempRet0;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($12|0);
     // unreachable;
    }
    $5 = (($a) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($b|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     $12 = ___cxa_find_matching_catch()|0;
     $13 = tempRet0;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($12|0);
     // unreachable;
    }
    $9 = (($b) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($6|0)==($10|0);
    if ($11) {
     __THREW__ = 0;
     invoke_vi(3799,($a|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      $12 = ___cxa_find_matching_catch()|0;
      $13 = tempRet0;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($12|0);
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($b|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      $12 = ___cxa_find_matching_catch()|0;
      $13 = tempRet0;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($12|0);
      // unreachable;
     }
     $18 = (($a) + 12|0);
     $19 = (($b) + 12|0);
     $20 = ($6|0)>(7);
     if ($20) {
      $V_0$06 = $6;$V_3$05 = $18;$V_4$04 = $19;
      while(1) {
       $40 = HEAP32[$V_3$05>>2]|0;
       $41 = HEAP32[$V_4$04>>2]|0;
       $42 = ($40|0)==($41|0);
       if (!($42)) {
        $$0 = 0;
        break L1;
       }
       $21 = (($V_3$05) + 4|0);
       $22 = HEAP32[$21>>2]|0;
       $23 = (($V_4$04) + 4|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = ($22|0)==($24|0);
       if (!($25)) {
        $$0 = 0;
        break L1;
       }
       $26 = (($V_3$05) + 8|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = (($V_4$04) + 8|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($27|0)==($29|0);
       if (!($30)) {
        $$0 = 0;
        break L1;
       }
       $31 = (($V_3$05) + 12|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = (($V_4$04) + 12|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ($32|0)==($34|0);
       if (!($35)) {
        $$0 = 0;
        break L1;
       }
       $36 = (($V_3$05) + 16|0);
       $37 = (($V_4$04) + 16|0);
       $38 = (($V_0$06) + -8)|0;
       $39 = ($38|0)>(7);
       if ($39) {
        $V_0$06 = $38;$V_3$05 = $36;$V_4$04 = $37;
       } else {
        $V_0$0$lcssa = $38;$V_3$0$lcssa = $36;$V_4$0$lcssa = $37;
        break;
       }
      }
     } else {
      $V_0$0$lcssa = $6;$V_3$0$lcssa = $18;$V_4$0$lcssa = $19;
     }
     $43 = ($V_0$0$lcssa|0)<(4);
     if ($43) {
      $V_0$1 = $V_0$0$lcssa;$V_3$1 = $V_3$0$lcssa;$V_4$1 = $V_4$0$lcssa;
     } else {
      $44 = HEAP32[$V_3$0$lcssa>>2]|0;
      $45 = HEAP32[$V_4$0$lcssa>>2]|0;
      $46 = ($44|0)==($45|0);
      if (!($46)) {
       $$0 = 0;
       break;
      }
      $47 = (($V_3$0$lcssa) + 4|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = (($V_4$0$lcssa) + 4|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = ($48|0)==($50|0);
      if (!($51)) {
       $$0 = 0;
       break;
      }
      $52 = (($V_3$0$lcssa) + 8|0);
      $53 = (($V_4$0$lcssa) + 8|0);
      $54 = (($V_0$0$lcssa) + -4)|0;
      $V_0$1 = $54;$V_3$1 = $52;$V_4$1 = $53;
     }
     $55 = ($V_0$1|0)<(2);
     if ($55) {
      $V_0$2 = $V_0$1;$V_3$2 = $V_3$1;$V_4$2 = $V_4$1;
     } else {
      $56 = HEAP32[$V_3$1>>2]|0;
      $57 = HEAP32[$V_4$1>>2]|0;
      $58 = ($56|0)==($57|0);
      if (!($58)) {
       $$0 = 0;
       break;
      }
      $59 = (($V_3$1) + 4|0);
      $60 = (($V_4$1) + 4|0);
      $61 = (($V_0$1) + -2)|0;
      $V_0$2 = $61;$V_3$2 = $59;$V_4$2 = $60;
     }
     $62 = ($V_0$2|0)==(0);
     if ($62) {
      $$0 = 1;
     } else {
      $63 = HEAP16[$V_3$2>>1]|0;
      $64 = HEAP16[$V_4$2>>1]|0;
      $65 = ($63<<16>>16)==($64<<16>>16);
      $$0 = $65;
     }
    } else {
     $$0 = 0;
    }
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z78mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP22mscorlib_System_StringP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182136);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2191608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiii(522,0,($__this|0),($2|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_StringP22mscorlib_System_StringS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182184);
 __THREW__ = 0;
 $0 = (invoke_iiii(522,0,($__this|0),($value|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z65mscorlib_System_String_m_ToCharArray_mscorlib_System_Char_arr_arrP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182280);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiii(524,($__this|0),0,($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z109mscorlib_System_String_m_ToCharArray_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Stringii($__this,$startIndex,$length) {
 $__this = $__this|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $G_B10_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182328);
 __THREW__ = 0;
 invoke_v(394);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($startIndex|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3005696>>2]|0;
    $11 = HEAP32[3005704>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($7|0),($10|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = ($length|0)>(-1);
   if (!($16)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3005712>>2]|0;
    $23 = HEAP32[3005720>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($19|0),($22|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($19|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   $28 = (($__this) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) - ($length))|0;
   $31 = ($30|0)<($startIndex|0);
   if ($31) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    __THREW__ = 0;
    $34 = (invoke_ii(3469,(2561352|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = HEAP32[3005728>>2]|0;
    $38 = HEAP32[3005736>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($34|0),($37|0),($38|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($34|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1168808|0))|0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    __THREW__ = 0;
    $45 = (invoke_iii(2754,(1168808|0),($length|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if (!($47)) {
     $48 = ($45|0)==(0|0);
     if ($48) {
      $G_B10_0$0 = 0;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($45|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = (($45) + 12|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = ($52|0)==(0);
      if ($53) {
       $G_B10_0$0 = 0;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($45|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       }
       $56 = HEAP32[$51>>2]|0;
       $57 = ($56|0)==(0);
       if ($57) {
        __THREW__ = 0;
        $58 = (invoke_i(132)|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($58|0));
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         break;
        }
       }
       $63 = (($45) + 16|0);
       $G_B10_0$0 = $63;
      }
     }
     __THREW__ = 0;
     $64 = (invoke_ii(1919,0)|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if (!($66)) {
      $67 = $__this;
      $68 = (($64) + ($67))|0;
      $69 = $startIndex << 1;
      $70 = $68;
      $71 = (($70) + ($69)|0);
      __THREW__ = 0;
      invoke_viiii(124,0,($G_B10_0$0|0),($71|0),($length|0));
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if (!($73)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($45|0);
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Runtime_CompilerServices_RuntimeHelpers_m_get_OffsetToStringDataP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2256080);
 $0 = HEAP32[2256128>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2256136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2256128>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z136mscorlib_System_String_m_CharCopy_mscorlib_System_Void_mscorlib_System_CharU002A_ptr_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P22mscorlib_System_ObjectPtS1_i($__this,$dest,$src,$count) {
 $__this = $__this|0;
 $dest = $dest|0;
 $src = $src|0;
 $count = $count|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$12 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186216);
 $0 = $dest;
 $1 = $src;
 $2 = $1 | $0;
 $3 = $2 & 3;
 $4 = ($3|0)==(0);
 if ($4) {
  $$1 = $dest;$$12 = $src;$$14 = $count;
 } else {
  $5 = $0 & 2;
  $6 = ($5|0)==(0);
  if ($6) {
   $$0 = $dest;$$01 = $src;$$03 = $count;
  } else {
   $7 = $1 & 2;
   $8 = ($7|0)==(0);
   $9 = ($count|0)<(1);
   $or$cond = $8 | $9;
   if ($or$cond) {
    $$0 = $dest;$$01 = $src;$$03 = $count;
   } else {
    $10 = HEAP16[$src>>1]|0;
    HEAP16[$dest>>1] = $10;
    $11 = (($dest) + 2|0);
    $12 = (($src) + 2|0);
    $13 = (($count) + -1)|0;
    $$0 = $11;$$01 = $12;$$03 = $13;
   }
  }
  $14 = $$0;
  $15 = $$01;
  $16 = $14 | $15;
  $17 = $16 & 2;
  $18 = ($17|0)==(0);
  if ($18) {
   $$1 = $$0;$$12 = $$01;$$14 = $$03;
  } else {
   $19 = $$03 << 1;
   __THREW__ = 0;
   invoke_viiii(121,0,($$0|0),($$01|0),($19|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    $22 = ___cxa_find_matching_catch()|0;
    $23 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($22|0);
    // unreachable;
   } else {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $24 = $$14 << 1;
 __THREW__ = 0;
 invoke_viiii(120,0,($$1|0),($$12|0),($24|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($22|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z90mscorlib_System_String_m_Split_mscorlib_System_String_arr_arr_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr($__this,$separator) {
 $__this = $__this|0;
 $separator = $separator|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182376);
 __THREW__ = 0;
 $0 = (invoke_iiii(526,($__this|0),($separator|0),2147483647)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z112mscorlib_System_String_m_Split_mscorlib_System_String_arr_arr_mscorlib_System_Char_arr_arr_mscorlib_System_Int32P22mscorlib_System_StringP24mscorlib_System_Char_arri($__this,$separator,$count) {
 $__this = $__this|0;
 $separator = $separator|0;
 $count = $count|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182424);
 __THREW__ = 0;
 invoke_v(395);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($separator|0)==(0|0);
   if ($2) {
    label = 6;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($separator|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    $7 = (($separator) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0);
    if ($9) {
     label = 6;
    } else {
     $$01 = $separator;
    }
   }
   if ((label|0) == 6) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP8[((2191608 + 116|0))>>0]|0;
    $13 = ($12<<24>>24)==(0);
    if ($13) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[((2191608 + 80|0))>>2]|0;
    $23 = (($22) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    $$01 = $24;
   }
   $25 = ($count|0)>(-1);
   if (!($25)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    $28 = (invoke_ii(3469,(2561352|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    $31 = HEAP32[3005896>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($28|0),($31|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($28|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    // unreachable;
   }
   if ((($count|0) == 1)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1168432|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_iii(2754,(1168432|0),1)|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($43|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    $48 = (($43) + 12|0);
    $49 = HEAP32[$48>>2]|0;
    $50 = ($49|0)==(0);
    if ($50) {
     __THREW__ = 0;
     $51 = (invoke_i(132)|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($51|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($43|0),($__this|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = (($43) + 16|0);
    HEAP32[$58>>2] = $__this;
    $$0 = $43;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else if ((($count|0) == 0)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1168432|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    __THREW__ = 0;
    $38 = (invoke_iii(2754,(1168432|0),0)|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    $$0 = $38;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    __THREW__ = 0;
    $59 = (invoke_iiiii(105,($__this|0),($$01|0),($count|0),0)|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     break;
    } else {
     $$0 = $59;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_String_m_InternalSplitP22mscorlib_System_StringP24mscorlib_System_Char_arrii($__this,$separator,$count,$options) {
 $__this = $__this|0;
 $separator = $separator|0;
 $count = $count|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186408);
 $0 = HEAP32[2186456>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2186464|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2186456>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiii($7|0,($__this|0),($separator|0),($count|0),($options|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_String_m_Substring_mscorlib_System_String_mscorlib_System_Int32P22mscorlib_System_Stringi($__this,$startIndex) {
 $__this = $__this|0;
 $startIndex = $startIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182472);
 __THREW__ = 0;
 invoke_v(396);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($startIndex|0)==(0);
   if ($2) {
    $$0 = $__this;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $5 = ($startIndex|0)<(0);
   if (!($5)) {
    $6 = (($__this) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)<($startIndex|0);
    if (!($8)) {
     $19 = (($7) - ($startIndex))|0;
     __THREW__ = 0;
     $20 = (invoke_iiii(529,($__this|0),($startIndex|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     } else {
      $$0 = $20;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2561352|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[3005928>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3830,($11|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_String_m_SubstringUncheckedP22mscorlib_System_Stringii($__this,$startIndex,$length) {
 $__this = $__this|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182568);
 $0 = ($length|0)==(0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = HEAP8[((2191608 + 116|0))>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $5 = __THREW__; __THREW__ = 0;
     $6 = $5&1;
     if ($6) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[((2191608 + 80|0))>>2]|0;
     $16 = HEAP32[$15>>2]|0;
     $$0 = $16;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   $17 = (invoke_iii(643,0,($length|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_ii(1919,0)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     $23 = (invoke_ii(1919,0)|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = $17;
      $27 = (($20) + ($26))|0;
      $28 = $__this;
      $29 = $27;
      $30 = (($23) + ($28))|0;
      $31 = $startIndex << 1;
      $32 = $30;
      $33 = (($32) + ($31)|0);
      __THREW__ = 0;
      invoke_viiii(124,0,($29|0),($33|0),($length|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_String_m_InternalAllocateStrP22mscorlib_System_Objecti($__this,$length) {
 $__this = $__this|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186536);
 $0 = HEAP32[2186584>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2186592|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2186584>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($length|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_String_m_Trim_mscorlib_System_StringP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182616);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2191608 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2191608 + 80|0))>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $$0 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   $19 = (invoke_iiiii(90,($__this|0),0,($1|0),1)|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP32[$0>>2]|0;
    $23 = ($19|0)==($22|0);
    if (!($23)) {
     $38 = (($22) + -1)|0;
     __THREW__ = 0;
     $39 = (invoke_iiiii(90,($__this|0),($38|0),($19|0),-1)|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     $42 = (($39) - ($19))|0;
     $43 = (($42) + 1)|0;
     $44 = HEAP32[$0>>2]|0;
     $45 = ($43|0)==($44|0);
     if ($45) {
      $$0 = $__this;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $46 = (invoke_iiii(529,($__this|0),($19|0),($43|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     } else {
      $$0 = $46;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = HEAP8[((2191608 + 116|0))>>0]|0;
     $27 = ($26<<24>>24)==(0);
     if ($27) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2191608|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      $36 = HEAP32[((2191608 + 80|0))>>2]|0;
      $37 = HEAP32[$36>>2]|0;
      $$0 = $37;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_String_m_FindNotWhiteSpaceP22mscorlib_System_Stringiii($__this,$pos,$target,$change) {
 $__this = $__this|0;
 $pos = $pos|0;
 $target = $target|0;
 $change = $change|0;
 var $$01$lcssa = 0, $$016 = 0, $$off = 0, $$off3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182808);
 $0 = ($pos|0)==($target|0);
 L1: do {
  if ($0) {
   $$01$lcssa = $pos;
  } else {
   $$016 = $pos;
   while(1) {
    __THREW__ = 0;
    $2 = (invoke_iii(621,($__this|0),($$016|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $1 = ($2&65535)>(132);
    if ($1) {
     if (!((($2<<16>>16) == 8287) | (($2<<16>>16) == 8239) | (($2<<16>>16) == 8233) | (($2<<16>>16) == 8232) | (($2<<16>>16) == 5760) | (($2<<16>>16) == 133) | (($2<<16>>16) == 12288) | (($2<<16>>16) == -257) | (($2<<16>>16) == 160))) {
      $$off3 = (($2) + -8192)<<16>>16;
      $7 = ($$off3&65535)<(12);
      if (!($7)) {
       $$01$lcssa = $$016;
       break L1;
      }
     }
    } else {
     $5 = ($2<<16>>16)==(32);
     $$off = (($2) + -9)<<16>>16;
     $6 = ($$off&65535)<(5);
     $or$cond = $5 | $6;
     if (!($or$cond)) {
      $$01$lcssa = $$016;
      break L1;
     }
    }
    $8 = (($$016) + ($change))|0;
    $9 = ($8|0)==($target|0);
    if ($9) {
     $$01$lcssa = $target;
     break L1;
    } else {
     $$016 = $8;
    }
   }
   $3 = ___cxa_find_matching_catch()|0;
   $4 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($3|0);
   // unreachable;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$01$lcssa|0);
}
function __Z81mscorlib_System_String_m_Trim_mscorlib_System_String_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr($__this,$trimChars) {
 $__this = $__this|0;
 $trimChars = $trimChars|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182664);
 $0 = ($trimChars|0)==(0|0);
 do {
  if ($0) {
   label = 5;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($trimChars|0));
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = (($trimChars) + 12|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($4|0)==(0);
    if ($5) {
     label = 5;
    } else {
     $11 = (($__this) + 8|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0);
     if ($13) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      $16 = HEAP8[((2191608 + 116|0))>>0]|0;
      $17 = ($16<<24>>24)==(0);
      if ($17) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3831,(2191608|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = HEAP32[((2191608 + 80|0))>>2]|0;
      $27 = HEAP32[$26>>2]|0;
      $$0 = $27;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $28 = (invoke_iiiiii(85,($__this|0),0,($12|0),1,($trimChars|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      $31 = HEAP32[$11>>2]|0;
      $32 = ($28|0)==($31|0);
      if (!($32)) {
       $47 = (($31) + -1)|0;
       __THREW__ = 0;
       $48 = (invoke_iiiiii(85,($__this|0),($47|0),($28|0),-1,($trimChars|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
       $51 = (($48) - ($28))|0;
       $52 = (($51) + 1)|0;
       $53 = HEAP32[$11>>2]|0;
       $54 = ($52|0)==($53|0);
       if ($54) {
        $$0 = $__this;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       $55 = (invoke_iiii(529,($__this|0),($28|0),($52|0))|0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       } else {
        $$0 = $55;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       $35 = HEAP8[((2191608 + 116|0))>>0]|0;
       $36 = ($35<<24>>24)==(0);
       if ($36) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3831,(2191608|0));
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if (!($44)) {
        $45 = HEAP32[((2191608 + 80|0))>>2]|0;
        $46 = HEAP32[$45>>2]|0;
        $$0 = $46;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii(1812,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $$0 = $8;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_String_m_FindNotInTableP22mscorlib_System_StringiiiP24mscorlib_System_Char_arr($__this,$pos,$target,$change,$table) {
 $__this = $__this|0;
 $pos = $pos|0;
 $target = $target|0;
 $change = $change|0;
 $table = $table|0;
 var $$01$lcssa = 0, $$019 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B4_0$0 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182856);
 $0 = ($table|0)==(0|0);
 do {
  if ($0) {
   $G_B4_0$0 = 0;
   label = 13;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($table|0));
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = (($table) + 12|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($4|0)==(0);
    if ($5) {
     $G_B4_0$0 = 0;
     label = 13;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($table|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = HEAP32[$3>>2]|0;
      $15 = ($14|0)==(0);
      if ($15) {
       __THREW__ = 0;
       $16 = (invoke_i(132)|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($16|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
      }
      $21 = (($table) + 16|0);
      $G_B4_0$0 = $21;
      label = 13;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  __THREW__ = 0;
  $22 = (invoke_ii(1919,0)|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   $25 = ($pos|0)==($target|0);
   if ($25) {
    $$01$lcssa = $pos;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$01$lcssa|0);
   }
   $26 = $__this;
   $27 = (($22) + ($26))|0;
   $28 = $27;
   $29 = (($table) + 12|0);
   $$019 = $pos;
   L16: while(1) {
    $46 = $$019 << 1;
    $47 = (($28) + ($46)|0);
    $38 = HEAP16[$47>>1]|0;
    $V_3$0 = 0;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($table|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 4;
      break L16;
     }
     $32 = HEAP32[$29>>2]|0;
     $33 = ($V_3$0|0)<($32|0);
     if (!($33)) {
      break;
     }
     $34 = $V_3$0 << 1;
     $35 = (($G_B4_0$0) + ($34)|0);
     $36 = HEAP16[$35>>1]|0;
     $37 = ($38<<16>>16)==($36<<16>>16);
     $39 = (($V_3$0) + 1)|0;
     if ($37) {
      break;
     } else {
      $V_3$0 = $39;
     }
    }
    __THREW__ = 0;
    invoke_vi(3799,($table|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 5;
     break;
    }
    $42 = HEAP32[$29>>2]|0;
    $43 = ($V_3$0|0)==($42|0);
    $44 = (($$019) + ($change))|0;
    if ($43) {
     $$01$lcssa = $$019;
     label = 23;
     break;
    }
    $45 = ($44|0)==($target|0);
    if ($45) {
     $$01$lcssa = $target;
     label = 23;
     break;
    } else {
     $$019 = $44;
    }
   }
   if ((label|0) == 4) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    $lpad$phi$index = $6;$lpad$phi$index3 = $7;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 5) {
    $8 = ___cxa_find_matching_catch()|0;
    $9 = tempRet0;
    $lpad$phi$index = $8;$lpad$phi$index3 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 23) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$01$lcssa|0);
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index3 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_String_m_TrimStartP22mscorlib_System_StringP24mscorlib_System_Char_arr($__this,$trimChars) {
 $__this = $__this|0;
 $trimChars = $trimChars|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182712);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2191608 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2191608 + 80|0))>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $$0 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   $19 = ($trimChars|0)==(0|0);
   if ($19) {
    $25 = $1;
    label = 13;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($trimChars|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (($trimChars) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0);
    $$pre = HEAP32[$0>>2]|0;
    if ($24) {
     $25 = $$pre;
     label = 13;
    } else {
     __THREW__ = 0;
     $29 = (invoke_iiiiii(85,($__this|0),0,($$pre|0),1,($trimChars|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     } else {
      $V_0$0 = $29;
     }
    }
   }
   if ((label|0) == 13) {
    __THREW__ = 0;
    $26 = (invoke_iiiii(90,($__this|0),0,($25|0),1)|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    } else {
     $V_0$0 = $26;
    }
   }
   $32 = ($V_0$0|0)==(0);
   if ($32) {
    $$0 = $__this;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $33 = HEAP32[$0>>2]|0;
   $34 = (($33) - ($V_0$0))|0;
   __THREW__ = 0;
   $35 = (invoke_iiii(529,($__this|0),($V_0$0|0),($34|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if (!($37)) {
    $$0 = $35;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_String_m_TrimEndP22mscorlib_System_StringP24mscorlib_System_Char_arr($__this,$trimChars) {
 $__this = $__this|0;
 $trimChars = $trimChars|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182760);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2191608 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2191608 + 80|0))>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $$0 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   $19 = ($trimChars|0)==(0|0);
   if ($19) {
    $26 = $1;
    label = 13;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($trimChars|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (($trimChars) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0);
    $$pre = HEAP32[$0>>2]|0;
    if ($24) {
     $26 = $$pre;
     label = 13;
    } else {
     $30 = (($$pre) + -1)|0;
     __THREW__ = 0;
     $31 = (invoke_iiiiii(85,($__this|0),($30|0),-1,-1,($trimChars|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     } else {
      $V_0$0 = $31;
     }
    }
   }
   if ((label|0) == 13) {
    $25 = (($26) + -1)|0;
    __THREW__ = 0;
    $27 = (invoke_iiiii(90,($__this|0),($25|0),-1,-1)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    } else {
     $V_0$0 = $27;
    }
   }
   $34 = (($V_0$0) + 1)|0;
   $35 = HEAP32[$0>>2]|0;
   $36 = ($34|0)==($35|0);
   if ($36) {
    $$0 = $__this;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $37 = (invoke_iiii(529,($__this|0),0,($34|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    $$0 = $37;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_String_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_($__this,$strA,$strB) {
 $__this = $__this|0;
 $strA = $strA|0;
 $strB = $strB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182904);
 __THREW__ = 0;
 $0 = (invoke_ii(1982,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2304464|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiiiii(231,(2304512|0),($5|0),($strA|0),($strB|0),0)|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($10|0);
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_E6InvokeEP10MethodInfoPvS5_S5_i($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z124mscorlib_System_String_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_BooleanP22mscorlib_System_ObjectP22mscorlib_System_StringS2_b($__this,$strA,$strB,$ignoreCase) {
 $__this = $__this|0;
 $strA = $strA|0;
 $strB = $strB|0;
 $ignoreCase = $ignoreCase|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2182952);
 __THREW__ = 0;
 $0 = (invoke_ii(1982,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2304464|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $$ = $ignoreCase&1;
     __THREW__ = 0;
     $12 = (invoke_iiiiii(231,(2304512|0),($5|0),($strA|0),($strB|0),($$|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($12|0);
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z166mscorlib_System_String_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Boolean_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_ObjectP22mscorlib_System_StringS2_bP41mscorlib_System_Globalization_CultureInfo($__this,$strA,$strB,$ignoreCase,$culture) {
 $__this = $__this|0;
 $strA = $strA|0;
 $strB = $strB|0;
 $ignoreCase = $ignoreCase|0;
 $culture = $culture|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183000);
 __THREW__ = 0;
 invoke_v(397);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($culture|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006192>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($culture|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_iii(2730,(2304464|0),($culture|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($17|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $$ = $ignoreCase&1;
    __THREW__ = 0;
    $22 = (invoke_iiiiii(231,(2304512|0),($17|0),($strA|0),($strB|0),($$|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($22|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z232mscorlib_System_String_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_ObjectP22mscorlib_System_StringiS2_iibP41mscorlib_System_Globalization_CultureInfo($__this,$strA,$indexA,$strB,$indexB,$length,$ignoreCase,$culture) {
 $__this = $__this|0;
 $strA = $strA|0;
 $indexA = $indexA|0;
 $strB = $strB|0;
 $indexB = $indexB|0;
 $length = $length|0;
 $ignoreCase = $ignoreCase|0;
 $culture = $culture|0;
 var $$ = 0, $$0 = 0, $$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $V_1$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond1 = 0, $or$cond1$not = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183048);
 __THREW__ = 0;
 invoke_v(398);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($culture|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006208>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($strA|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($strA|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)<($indexA|0);
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3799,($strB|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_ii(1816,($strB|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = ($23|0)<($indexB|0);
      $27 = ($indexA|0)<(0);
      $or$cond = $26 | $27;
      $28 = ($indexB|0)<(0);
      $or$cond1 = $or$cond | $28;
      $or$cond1$not = $or$cond1 ^ 1;
      $29 = ($length|0)>(-1);
      $or$cond2 = $29 & $or$cond1$not;
      if ($or$cond2) {
       $39 = ($length|0)==(0);
       if ($39) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $40 = ($strA|0)==(0|0);
       $41 = ($strB|0)!=(0|0);
       if ($40) {
        $$ = $41 << 31 >> 31;
        $$0 = $$;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       if (!($41)) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $$3 = $ignoreCase&1;
       __THREW__ = 0;
       invoke_vi(3799,($strA|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break;
       }
       __THREW__ = 0;
       $44 = (invoke_ii(1816,($strA|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       $47 = (($44) - ($indexA))|0;
       $48 = ($47|0)<($length|0);
       if ($48) {
        __THREW__ = 0;
        invoke_vi(3799,($strA|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        $51 = (invoke_ii(1816,($strA|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        $54 = (($51) - ($indexA))|0;
        $V_1$0 = $54;
       } else {
        $V_1$0 = $length;
       }
       __THREW__ = 0;
       invoke_vi(3799,($strB|0));
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
       __THREW__ = 0;
       $57 = (invoke_ii(1816,($strB|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
       $60 = (($57) - ($indexB))|0;
       $61 = ($60|0)<($length|0);
       if ($61) {
        __THREW__ = 0;
        invoke_vi(3799,($strB|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_ii(1816,($strB|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         break;
        }
        $67 = (($64) - ($indexB))|0;
        $V_2$0 = $67;
       } else {
        $V_2$0 = $length;
       }
       __THREW__ = 0;
       invoke_vi(3799,($culture|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       __THREW__ = 0;
       $70 = (invoke_iii(2730,(2304464|0),($culture|0))|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($70|0));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       __THREW__ = 0;
       $75 = (invoke_iiiiiiiiii(14,(2326272|0),($70|0),($strA|0),($indexA|0),($V_1$0|0),($strB|0),($indexB|0),($V_2$0|0),($$3|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       } else {
        $$0 = $75;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      __THREW__ = 0;
      $32 = (invoke_ii(3469,(2561352|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       invoke_vi(2587,($32|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        __THREW__ = 0;
        invoke_vi(3830,($32|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_S0_E6InvokeEP10MethodInfoPvS5_iiS5_iii($method,$obj,$p1,$p2,$p3,$p4,$p5,$p6,$p7) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 $p6 = $p6|0;
 $p7 = $p7|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiiiii[$3 & 63]($4,$p1,$p2,$p3,$p4,$p5,$p6,$p7)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z79mscorlib_System_String_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP22mscorlib_System_StringP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183096);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2735,($value|0),(2191608|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_iii(2755,($value|0),(2191608|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     $23 = (invoke_iiii(532,0,($__this|0),($20|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     } else {
      $$0 = $23;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2560072|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(2583,($11|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(3830,($11|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_String_m_CompareTo_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_StringS0_($__this,$strB) {
 $__this = $__this|0;
 $strB = $strB|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183144);
 $0 = ($strB|0)==(0|0);
 if ($0) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(532,0,($__this|0),($strB|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z39mscorlib_System_String_m_CompareOrdinalP22mscorlib_System_ObjectP22mscorlib_System_StringiS2_ii($__this,$strA,$indexA,$strB,$indexB,$length) {
 $__this = $__this|0;
 $strA = $strA|0;
 $indexA = $indexA|0;
 $strB = $strB|0;
 $indexB = $indexB|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond1 = 0, $or$cond1$not = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183192);
 __THREW__ = 0;
 invoke_vi(3799,($strA|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1816,($strA|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<($indexA|0);
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(3799,($strB|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(1816,($strB|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = ($10|0)<($indexB|0);
     $14 = ($indexA|0)<(0);
     $or$cond = $13 | $14;
     $15 = ($indexB|0)<(0);
     $or$cond1 = $or$cond | $15;
     $or$cond1$not = $or$cond1 ^ 1;
     $16 = ($length|0)>(-1);
     $or$cond2 = $16 & $or$cond1$not;
     if ($or$cond2) {
      __THREW__ = 0;
      $26 = (invoke_iiiiiiii(69,0,($strA|0),($indexA|0),($length|0),($strB|0),($indexB|0),($length|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($26|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     $19 = (invoke_ii(3469,(2561352|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(2587,($19|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vi(3830,($19|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_String_m_CompareOrdinalUncheckedP22mscorlib_System_ObjectP22mscorlib_System_StringiiS2_ii($__this,$strA,$indexA,$lenA,$strB,$indexB,$lenB) {
 $__this = $__this|0;
 $strA = $strA|0;
 $indexA = $indexA|0;
 $lenA = $lenA|0;
 $strB = $strB|0;
 $indexB = $indexB|0;
 $lenB = $lenB|0;
 var $$ = 0, $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_4$0$in3 = 0, $V_6$0$in2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183240);
 $0 = ($strA|0)==(0|0);
 $1 = ($strB|0)!=(0|0);
 if ($0) {
  $$ = $1 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($1)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($strA|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(1816,($strA|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($4) - ($indexA))|0;
    __THREW__ = 0;
    $8 = (invoke_iiii(1198,(0|0),($lenA|0),($7|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3799,($strB|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(1816,($strB|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = (($13) - ($indexB))|0;
       __THREW__ = 0;
       $17 = (invoke_iiii(1198,(0|0),($lenB|0),($16|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $20 = ($8|0)==($17|0);
        if ($20) {
         __THREW__ = 0;
         $23 = (invoke_iiii(424,0,($strA|0),($strB|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          break;
         }
         if ($23) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        __THREW__ = 0;
        $26 = (invoke_ii(1919,0)|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __THREW__ = 0;
         $29 = (invoke_ii(1919,0)|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          $32 = $strA;
          $33 = (($26) + ($32))|0;
          $34 = $indexA << 1;
          $35 = $33;
          __THREW__ = 0;
          $36 = (invoke_iiii(1198,(0|0),($8|0),($17|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if (!($38)) {
           $39 = $36 << 1;
           $$sum = (($39) + ($34))|0;
           $40 = (($35) + ($$sum)|0);
           $41 = ($34|0)<($$sum|0);
           L23: do {
            if ($41) {
             $42 = $strB;
             $43 = (($29) + ($42))|0;
             $44 = $43;
             $45 = $indexB << 1;
             $46 = (($35) + ($34)|0);
             $47 = (($44) + ($45)|0);
             $V_4$0$in3 = $46;$V_6$0$in2 = $47;
             while(1) {
              $49 = HEAP16[$V_4$0$in3>>1]|0;
              $51 = HEAP16[$V_6$0$in2>>1]|0;
              $56 = ($49<<16>>16)==($51<<16>>16);
              if (!($56)) {
               break;
              }
              $53 = (($V_4$0$in3) + 2|0);
              $54 = (($V_6$0$in2) + 2|0);
              $55 = ($53>>>0)<($40>>>0);
              if ($55) {
               $V_4$0$in3 = $53;$V_6$0$in2 = $54;
              } else {
               break L23;
              }
             }
             $48 = $49&65535;
             $50 = $51&65535;
             $52 = (($48) - ($50))|0;
             $$0 = $52;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           } while(0);
           $57 = (($8) - ($17))|0;
           $$0 = $57;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_String_m_CompareOrdinalCaseInsensitiveUncheckedP22mscorlib_System_ObjectP22mscorlib_System_StringiiS2_ii($__this,$strA,$indexA,$lenA,$strB,$indexB,$lenB) {
 $__this = $__this|0;
 $strA = $strA|0;
 $indexA = $indexA|0;
 $lenA = $lenA|0;
 $strB = $strB|0;
 $indexB = $indexB|0;
 $lenB = $lenB|0;
 var $$ = 0, $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $V_4$0$in4 = 0, $V_6$0$in3 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183288);
 $0 = ($strA|0)==(0|0);
 $1 = ($strB|0)!=(0|0);
 if ($0) {
  $$ = $1 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($1)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($strA|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(1816,($strA|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($4) - ($indexA))|0;
    __THREW__ = 0;
    $8 = (invoke_iiii(1198,(0|0),($lenA|0),($7|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3799,($strB|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(1816,($strB|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = (($13) - ($indexB))|0;
       __THREW__ = 0;
       $17 = (invoke_iiii(1198,(0|0),($lenB|0),($16|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $20 = ($8|0)==($17|0);
        if ($20) {
         __THREW__ = 0;
         $25 = (invoke_iiii(424,0,($strA|0),($strB|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         if ($25) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        __THREW__ = 0;
        $28 = (invoke_ii(1919,0)|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         __THREW__ = 0;
         $31 = (invoke_ii(1919,0)|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if (!($33)) {
          $34 = $strA;
          $35 = (($28) + ($34))|0;
          $36 = $indexA << 1;
          $37 = $35;
          __THREW__ = 0;
          $38 = (invoke_iiii(1198,(0|0),($8|0),($17|0))|0);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = $38 << 1;
           $$sum = (($41) + ($36))|0;
           $42 = (($37) + ($$sum)|0);
           $43 = ($36|0)<($$sum|0);
           L23: do {
            if ($43) {
             $44 = $strB;
             $45 = (($31) + ($44))|0;
             $46 = $45;
             $47 = $indexB << 1;
             $48 = (($46) + ($47)|0);
             $49 = (($37) + ($36)|0);
             $V_4$0$in4 = $49;$V_6$0$in3 = $48;
             while(1) {
              $50 = HEAP16[$V_4$0$in4>>1]|0;
              $66 = HEAP16[$V_6$0$in3>>1]|0;
              $67 = ($50<<16>>16)==($66<<16>>16);
              if (!($67)) {
               __THREW__ = 0;
               $51 = (invoke_iii(607,0,($50|0))|0);
               $52 = __THREW__; __THREW__ = 0;
               $53 = $52&1;
               if ($53) {
                label = 11;
                break;
               }
               $54 = HEAP16[$V_6$0$in3>>1]|0;
               __THREW__ = 0;
               $55 = (invoke_iii(607,0,($54|0))|0);
               $56 = __THREW__; __THREW__ = 0;
               $57 = $56&1;
               if ($57) {
                label = 11;
                break;
               }
               $58 = ($51<<16>>16)==($55<<16>>16);
               if (!($58)) {
                label = 24;
                break;
               }
              }
              $63 = (($V_4$0$in4) + 2|0);
              $64 = (($V_6$0$in3) + 2|0);
              $65 = ($63>>>0)<($42>>>0);
              if ($65) {
               $V_4$0$in4 = $63;$V_6$0$in3 = $64;
              } else {
               break L23;
              }
             }
             if ((label|0) == 11) {
              $21 = ___cxa_find_matching_catch()|0;
              $22 = tempRet0;
              $lpad$phi$index = $21;$lpad$phi$index2 = $22;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
             else if ((label|0) == 24) {
              $59 = $51&65535;
              $60 = $55&65535;
              $61 = (($59) - ($60))|0;
              $62 = $61 & 65535;
              $$0 = $62;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           } while(0);
           $68 = (($8) - ($17))|0;
           $$0 = $68;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $lpad$phi$index = $23;$lpad$phi$index2 = $24;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z33mscorlib_System_String_m_EndsWithP22mscorlib_System_StringS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183336);
 __THREW__ = 0;
 invoke_v(399);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006224>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1982,(0|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3799,($15|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2730,(2304464|0),($15|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      invoke_vi(3799,($20|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       $25 = (invoke_iiiiii(232,(2326704|0),($20|0),($__this|0),($value|0),0)|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($25|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_S6_i($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z86mscorlib_System_String_m_IndexOfAny_mscorlib_System_Int32_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr($__this,$anyOf) {
 $__this = $__this|0;
 $anyOf = $anyOf|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183384);
 $0 = ($anyOf|0)==(0|0);
 if ($0) {
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(3469,(2560584|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(2585,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3830,($3|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      // unreachable;
     }
    }
   }
  }
 } else {
  $12 = (($__this) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   $$0 = -1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $15 = (invoke_iiiii(92,($__this|0),($anyOf|0),0,($13|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $$0 = $15;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_String_m_IndexOfAnyUncheckedP22mscorlib_System_StringP24mscorlib_System_Char_arrii($__this,$anyOf,$startIndex,$count) {
 $__this = $__this|0;
 $anyOf = $anyOf|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $$V_2$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $G_B8_0$0 = 0, $V_1$0 = 0;
 var $V_1$0$ph = 0, $V_2$0$ph = 0, $V_4$0 = 0, $V_4$0$ph = 0, $V_4$1 = 0, $V_6$0$be = 0, $V_6$03 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183480);
 __THREW__ = 0;
 invoke_vi(3799,($anyOf|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($anyOf) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0);
   if ($4) {
    $$0 = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($anyOf|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[$2>>2]|0;
    $10 = ($9|0)==(1);
    if ($10) {
     __THREW__ = 0;
     invoke_vi(3799,($anyOf|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[$2>>2]|0;
     $14 = ($13|0)==(0);
     if ($14) {
      __THREW__ = 0;
      $15 = (invoke_i(132)|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($15|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
     }
     $20 = (($anyOf) + 16|0);
     $21 = HEAP16[$20>>1]|0;
     __THREW__ = 0;
     $22 = (invoke_iiiii(94,($__this|0),($21|0),($startIndex|0),($count|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     } else {
      $$0 = $22;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $25 = ($anyOf|0)==(0|0);
    if ($25) {
     $G_B8_0$0 = 0;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($anyOf|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     $28 = HEAP32[$2>>2]|0;
     $29 = ($28|0)==(0);
     if ($29) {
      $G_B8_0$0 = 0;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($anyOf|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = HEAP32[$2>>2]|0;
      $33 = ($32|0)==(0);
      if ($33) {
       __THREW__ = 0;
       $34 = (invoke_i(132)|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($34|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
      }
      $39 = (($anyOf) + 16|0);
      $G_B8_0$0 = $39;
     }
    }
    $40 = HEAP16[$G_B8_0$0>>1]|0;
    $41 = $40&65535;
    __THREW__ = 0;
    invoke_vi(3799,($anyOf|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     $44 = HEAP32[$2>>2]|0;
     $45 = (($G_B8_0$0) + ($44<<1)|0);
     $V_1$0$ph = $41;$V_2$0$ph = $41;$V_4$0$ph = $G_B8_0$0;
     L27: while(1) {
      $V_1$0 = $V_1$0$ph;$V_4$0 = $V_4$0$ph;
      while(1) {
       $48 = (($V_4$0) + 2|0);
       $49 = ($48|0)==($45|0);
       if ($49) {
        break L27;
       }
       $50 = HEAP16[$48>>1]|0;
       $47 = $50&65535;
       $51 = ($47>>>0)>($V_1$0>>>0);
       if ($51) {
        $V_1$0 = $47;$V_4$0 = $48;
       } else {
        break;
       }
      }
      $46 = ($47>>>0)<($V_2$0$ph>>>0);
      $$V_2$0 = $46 ? $47 : $V_2$0$ph;
      $V_1$0$ph = $V_1$0;$V_2$0$ph = $$V_2$0;$V_4$0$ph = $48;
     }
     $52 = (($__this) + 12|0);
     $$sum = (($count) + ($startIndex))|0;
     $53 = (($52) + ($$sum<<1)|0);
     $54 = ($count|0)==(0);
     if ($54) {
      $$0 = -1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $55 = (($52) + ($startIndex<<1)|0);
     $V_6$03 = $55;
     L37: while(1) {
      $59 = HEAP16[$V_6$03>>1]|0;
      $72 = $59&65535;
      $73 = ($72>>>0)>($V_1$0>>>0);
      $74 = ($72>>>0)<($V_2$0$ph>>>0);
      $or$cond = $73 | $74;
      L39: do {
       if (!($or$cond)) {
        $57 = HEAP16[$G_B8_0$0>>1]|0;
        $58 = ($59<<16>>16)==($57<<16>>16);
        if ($58) {
         label = 29;
         break L37;
        } else {
         $V_4$1 = $G_B8_0$0;
        }
        while(1) {
         $68 = (($V_4$1) + 2|0);
         $69 = ($68|0)==($45|0);
         if ($69) {
          break L39;
         }
         $70 = HEAP16[$68>>1]|0;
         $71 = ($59<<16>>16)==($70<<16>>16);
         if ($71) {
          label = 30;
          break L37;
         } else {
          $V_4$1 = $68;
         }
        }
       }
      } while(0);
      $V_6$0$be = (($V_6$03) + 2|0);
      $56 = ($V_6$0$be|0)==($53|0);
      if ($56) {
       $$0 = -1;
       label = 34;
       break;
      } else {
       $V_6$03 = $V_6$0$be;
      }
     }
     if ((label|0) == 29) {
      $60 = $V_6$03;
      $61 = $52;
      $62 = (($60) - ($61))|0;
      $63 = (($62|0) / 2)&-1;
      $$0 = $63;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 30) {
      $64 = $V_6$03;
      $65 = $52;
      $66 = (($64) - ($65))|0;
      $67 = (($66|0) / 2)&-1;
      $$0 = $67;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 34) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_String_m_IndexOfUncheckedP22mscorlib_System_Stringtii($__this,$value,$startIndex,$count) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $9 = 0, $V_2$0$lcssa = 0, $V_2$011 = 0, $V_2$12 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183672);
 $0 = (($__this) + 12|0);
 $1 = (($0) + ($startIndex<<1)|0);
 $2 = $count << 1;
 $3 = $2 & -16;
 $4 = (($1) + ($3)|0);
 $5 = ($1|0)==($4|0);
 L1: do {
  if ($5) {
   $V_2$0$lcssa = $1;
   label = 19;
  } else {
   $V_2$011 = $1;
   while(1) {
    $68 = HEAP16[$V_2$011>>1]|0;
    $69 = ($68<<16>>16)==($value<<16>>16);
    if ($69) {
     label = 2;
     break;
    }
    $10 = (($V_2$011) + 2|0);
    $11 = HEAP16[$10>>1]|0;
    $12 = ($11<<16>>16)==($value<<16>>16);
    if ($12) {
     label = 4;
     break;
    }
    $18 = (($V_2$011) + 4|0);
    $19 = HEAP16[$18>>1]|0;
    $20 = ($19<<16>>16)==($value<<16>>16);
    if ($20) {
     label = 6;
     break;
    }
    $26 = (($V_2$011) + 6|0);
    $27 = HEAP16[$26>>1]|0;
    $28 = ($27<<16>>16)==($value<<16>>16);
    if ($28) {
     label = 8;
     break;
    }
    $34 = (($V_2$011) + 8|0);
    $35 = HEAP16[$34>>1]|0;
    $36 = ($35<<16>>16)==($value<<16>>16);
    if ($36) {
     label = 10;
     break;
    }
    $42 = (($V_2$011) + 10|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = ($43<<16>>16)==($value<<16>>16);
    if ($44) {
     label = 12;
     break;
    }
    $50 = (($V_2$011) + 12|0);
    $51 = HEAP16[$50>>1]|0;
    $52 = ($51<<16>>16)==($value<<16>>16);
    if ($52) {
     label = 14;
     break;
    }
    $58 = (($V_2$011) + 14|0);
    $59 = HEAP16[$58>>1]|0;
    $60 = ($59<<16>>16)==($value<<16>>16);
    $61 = (($V_2$011) + 16|0);
    if ($60) {
     label = 16;
     break;
    }
    $67 = ($61|0)==($4|0);
    if ($67) {
     $V_2$0$lcssa = $4;
     label = 19;
     break L1;
    } else {
     $V_2$011 = $61;
    }
   }
   if ((label|0) == 2) {
    $6 = $V_2$011;
    $7 = $0;
    $8 = (($6) - ($7))|0;
    $9 = (($8|0) / 2)&-1;
    $$0 = $9;
    break;
   }
   else if ((label|0) == 4) {
    $13 = $V_2$011;
    $14 = $0;
    $15 = (($13) - ($14))|0;
    $16 = (($15|0) / 2)&-1;
    $17 = (($16) + 1)|0;
    $$0 = $17;
    break;
   }
   else if ((label|0) == 6) {
    $21 = $V_2$011;
    $22 = $0;
    $23 = (($21) - ($22))|0;
    $24 = (($23|0) / 2)&-1;
    $25 = (($24) + 2)|0;
    $$0 = $25;
    break;
   }
   else if ((label|0) == 8) {
    $29 = $V_2$011;
    $30 = $0;
    $31 = (($29) - ($30))|0;
    $32 = (($31|0) / 2)&-1;
    $33 = (($32) + 3)|0;
    $$0 = $33;
    break;
   }
   else if ((label|0) == 10) {
    $37 = $V_2$011;
    $38 = $0;
    $39 = (($37) - ($38))|0;
    $40 = (($39|0) / 2)&-1;
    $41 = (($40) + 4)|0;
    $$0 = $41;
    break;
   }
   else if ((label|0) == 12) {
    $45 = $V_2$011;
    $46 = $0;
    $47 = (($45) - ($46))|0;
    $48 = (($47|0) / 2)&-1;
    $49 = (($48) + 5)|0;
    $$0 = $49;
    break;
   }
   else if ((label|0) == 14) {
    $53 = $V_2$011;
    $54 = $0;
    $55 = (($53) - ($54))|0;
    $56 = (($55|0) / 2)&-1;
    $57 = (($56) + 6)|0;
    $$0 = $57;
    break;
   }
   else if ((label|0) == 16) {
    $62 = $V_2$011;
    $63 = $0;
    $64 = (($62) - ($63))|0;
    $65 = (($64|0) / 2)&-1;
    $66 = (($65) + 7)|0;
    $$0 = $66;
    break;
   }
  }
 } while(0);
 L21: do {
  if ((label|0) == 19) {
   $$sum = (($count) + ($startIndex))|0;
   $70 = (($0) + ($$sum<<1)|0);
   $71 = ($V_2$0$lcssa|0)==($70|0);
   if ($71) {
    $$0 = -1;
   } else {
    $V_2$12 = $V_2$0$lcssa;
    while(1) {
     $78 = HEAP16[$V_2$12>>1]|0;
     $79 = ($78<<16>>16)==($value<<16>>16);
     $77 = (($V_2$12) + 2|0);
     if ($79) {
      break;
     }
     $76 = ($77|0)==($70|0);
     if ($76) {
      $$0 = -1;
      break L21;
     } else {
      $V_2$12 = $77;
     }
    }
    $72 = $V_2$12;
    $73 = $0;
    $74 = (($72) - ($73))|0;
    $75 = (($74|0) / 2)&-1;
    $$0 = $75;
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z48mscorlib_System_String_m_IndexOfOrdinalUncheckedP22mscorlib_System_StringS0_ii($__this,$value,$startIndex,$count) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_3$0$in7 = 0;
 var $V_5$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183528);
 __THREW__ = 0;
 invoke_vi(3799,($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1816,($value|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($count|0);
    if ($5) {
     $$0 = -1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $8 = ($2|0)>(1);
    if (!($8)) {
     $9 = ($2|0)==(1);
     if (!($9)) {
      $$0 = $startIndex;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(621,($value|0),0)|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_iiiii(94,($__this|0),($12|0),($startIndex|0),($count|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     } else {
      $$0 = $15;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $18 = (invoke_ii(1919,0)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = $__this;
     $22 = (($18) + ($21))|0;
     __THREW__ = 0;
     $23 = (invoke_ii(1919,0)|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = $value;
      $27 = (($23) + ($26))|0;
      $28 = $startIndex << 1;
      $29 = $22;
      $30 = (($29) + ($28)|0);
      $31 = $count << 1;
      $$sum = (($31) + ($28))|0;
      $32 = (($29) + ($$sum)|0);
      $33 = $2 << 1;
      $34 = $32;
      $35 = (($34) - ($33))|0;
      $36 = $35;
      $37 = (($36) + 2|0);
      $38 = ($30|0)==($37|0);
      if ($38) {
       $$0 = -1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $39 = $27;
      $40 = HEAP16[$39>>1]|0;
      $41 = $27;
      $V_3$0$in7 = $30;
      L21: while(1) {
       $55 = HEAP16[$V_3$0$in7>>1]|0;
       $56 = ($55<<16>>16)==($40<<16>>16);
       L23: do {
        if ($56) {
         $V_5$01 = 1;
         while(1) {
          $44 = $V_5$01 << 1;
          $45 = (($V_3$0$in7) + ($44)|0);
          $46 = HEAP16[$45>>1]|0;
          $47 = (($41) + ($44)|0);
          $48 = HEAP16[$47>>1]|0;
          $49 = ($46<<16>>16)==($48<<16>>16);
          $43 = (($V_5$01) + 1)|0;
          if (!($49)) {
           break L23;
          }
          $42 = ($43|0)<($2|0);
          if ($42) {
           $V_5$01 = $43;
          } else {
           break L21;
          }
         }
        }
       } while(0);
       $53 = (($V_3$0$in7) + 2|0);
       $54 = ($V_3$0$in7|0)==($36|0);
       if ($54) {
        $$0 = -1;
        label = 19;
        break;
       } else {
        $V_3$0$in7 = $53;
       }
      }
      if ((label|0) == 19) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $50 = $V_3$0$in7;
      $51 = (($50) - ($22))|0;
      $52 = (($51|0) / 2)&-1;
      $$0 = $52;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_CharP22mscorlib_System_Stringt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183576);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = -1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $3 = (invoke_iiiii(94,($__this|0),($value|0),0,($1|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $$0 = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z97mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Char_mscorlib_System_Int32P22mscorlib_System_Stringti($__this,$value,$startIndex) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond3 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183624);
 __THREW__ = 0;
 invoke_v(400);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($startIndex|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006240>>2]|0;
    $11 = HEAP32[3006248>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($7|0),($10|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = (($__this) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)<($startIndex|0);
   if (!($18)) {
    $30 = $17 | $startIndex;
    $31 = ($30|0)==(0);
    $32 = ($17|0)==($startIndex|0);
    $or$cond3 = $31 | $32;
    if ($or$cond3) {
     $$0 = -1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $33 = (($17) - ($startIndex))|0;
    __THREW__ = 0;
    $34 = (invoke_iiiii(94,($__this|0),($value|0),($startIndex|0),($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    } else {
     $$0 = $34;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2561352|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[3006256>>2]|0;
     $25 = HEAP32[3006264>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($21|0),($24|0),($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      invoke_vi(3830,($21|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_StringS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183720);
 __THREW__ = 0;
 invoke_v(401);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($value|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = (($value) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0);
    if ($19) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $20 = (($__this) + 8|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==(0);
    if ($22) {
     $$0 = -1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1982,(0|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __THREW__ = 0;
     invoke_vi(3799,($23|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      $28 = (invoke_iii(2730,(2304464|0),($23|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = HEAP32[$20>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($28|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        __THREW__ = 0;
        $34 = (invoke_iiiiiiii(117,(2326512|0),($28|0),($__this|0),($value|0),0,($31|0),1073741824)|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         $$0 = $34;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S0_E6InvokeEP10MethodInfoPvS5_S5_iii($method,$obj,$p1,$p2,$p3,$p4,$p5) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4,$p5)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z99mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32P22mscorlib_System_StringS0_i($__this,$value,$startIndex) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183768);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($startIndex))|0;
 __THREW__ = 0;
 $3 = (invoke_iiiii(95,($__this|0),($value|0),($startIndex|0),($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_E6InvokeEP10MethodInfoPvS5_S5_ii($method,$obj,$p1,$p2,$p3,$p4) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z81mscorlib_System_String_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_StringS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183864);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  __THREW__ = 0;
  $3 = (invoke_iiiii(96,($__this|0),($value|0),0,0)|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $$0 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $8 = (($1) + -1)|0;
  __THREW__ = 0;
  $9 = (invoke_iiiii(96,($__this|0),($value|0),($8|0),($1|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $$0 = $9;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_String_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringS0_ii($__this,$value,$startIndex,$count) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $$old = 0, $$old$old = 0, $$startIndex = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond8 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183912);
 __THREW__ = 0;
 invoke_v(402);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006632>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($startIndex|0)<(-1);
   if (!($15)) {
    __THREW__ = 0;
    $16 = (invoke_ii(1816,($__this|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    $19 = ($16|0)<($startIndex|0);
    if (!($19)) {
     $31 = ($count|0)<(0);
     if (!($31)) {
      __THREW__ = 0;
      $32 = (invoke_ii(1816,($__this|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = ($32|0)<($count|0);
      if (!($35)) {
       $47 = (($startIndex) - ($count))|0;
       $48 = ($47|0)>(-2);
       if (!($48)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        $51 = (invoke_ii(3469,(2561352|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        $54 = HEAP32[3006672>>2]|0;
        __THREW__ = 0;
        invoke_vii(1926,($51|0),($54|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3830,($51|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break;
        }
        // unreachable;
       }
       __THREW__ = 0;
       invoke_vi(3799,($value|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       __THREW__ = 0;
       $61 = (invoke_ii(1816,($value|0))|0);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        break;
       }
       $64 = ($61|0)==(0);
       if ($64) {
        $$0 = $startIndex;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $65 = ($startIndex|0)==(0);
       $66 = (($__this) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = ($67|0)==(0);
       do {
        if ($65) {
         $$old = ($count|0)==(0);
         $or$cond8 = $68 | $$old;
         if ($or$cond8) {
          $$0 = -1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        } else {
         if (!($68)) {
          $$old$old = ($count|0)==(0);
          if ($$old$old) {
           $$0 = -1;
          } else {
           break;
          }
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($value|0));
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          break L1;
         }
         $71 = (($value) + 8|0);
         $72 = HEAP32[$71>>2]|0;
         $73 = ($72|0)>(0);
         $74 = ($count|0)==(0);
         $or$cond = $73 | $74;
         if ($or$cond) {
          $$0 = -1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       } while(0);
       __THREW__ = 0;
       $75 = (invoke_ii(1816,($__this|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
       $78 = ($75|0)==($startIndex|0);
       $79 = $78 << 31 >> 31;
       $$startIndex = (($79) + ($startIndex))|0;
       __THREW__ = 0;
       $80 = (invoke_ii(1982,(0|0))|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($80|0));
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        break;
       }
       __THREW__ = 0;
       $85 = (invoke_iii(2730,(2304464|0),($80|0))|0);
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($85|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       __THREW__ = 0;
       $90 = (invoke_iiiiiii(129,(2326752|0),($85|0),($__this|0),($value|0),($$startIndex|0),($count|0))|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        break;
       } else {
        $$0 = $90;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     __THREW__ = 0;
     $38 = (invoke_ii(3469,(2561352|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     $41 = HEAP32[3006656>>2]|0;
     $42 = HEAP32[3006664>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($38|0),($41|0),($42|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($38|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2561352|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = HEAP32[3006640>>2]|0;
     $26 = HEAP32[3006648>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($22|0),($25|0),($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __THREW__ = 0;
      invoke_vi(3830,($22|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_String_m_IsNullOrEmptyP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2183960);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $G_B3_0$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($value|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(1816,($value|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0);
   $G_B3_0$0 = $6;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B3_0$0|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z33mscorlib_System_String_m_PadRightP22mscorlib_System_Stringit($__this,$totalWidth,$paddingChar) {
 $__this = $__this|0;
 $totalWidth = $totalWidth|0;
 $paddingChar = $paddingChar|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $V_3$0$in5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184008);
 __THREW__ = 0;
 invoke_v(403);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($totalWidth|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006784>>2]|0;
    $11 = HEAP32[3006792>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($7|0),($10|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = (($__this) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)>($totalWidth|0);
   if ($18) {
    $$0 = $__this;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $19 = ($totalWidth|0)==(0);
   if ($19) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP8[((2191608 + 116|0))>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[((2191608 + 80|0))>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $$0 = $33;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $34 = (invoke_iii(643,0,($totalWidth|0))|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_ii(1919,0)|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     $40 = $34;
     $41 = (($37) + ($40))|0;
     __THREW__ = 0;
     $42 = (invoke_ii(1919,0)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      $45 = $41;
      $46 = $__this;
      $47 = (($42) + ($46))|0;
      $48 = $47;
      $49 = HEAP32[$16>>2]|0;
      __THREW__ = 0;
      invoke_viiii(124,0,($45|0),($48|0),($49|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if (!($51)) {
       $52 = HEAP32[$16>>2]|0;
       $53 = $52 << 1;
       $54 = $41;
       $55 = $totalWidth << 1;
       $56 = (($54) + ($55)|0);
       $57 = ($53|0)==($55|0);
       if ($57) {
        $$0 = $34;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $58 = (($54) + ($53)|0);
       $V_3$0$in5 = $58;
       while(1) {
        $59 = (($V_3$0$in5) + 2|0);
        HEAP16[$V_3$0$in5>>1] = $paddingChar;
        $60 = ($59|0)==($56|0);
        if ($60) {
         $$0 = $34;
         break;
        } else {
         $V_3$0$in5 = $59;
        }
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_String_m_StartsWithP22mscorlib_System_StringS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184056);
 __THREW__ = 0;
 invoke_v(404);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006832>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1982,(0|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3799,($15|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2730,(2304464|0),($15|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      invoke_vi(3799,($20|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       $25 = (invoke_iiiiii(232,(2326656|0),($20|0),($__this|0),($value|0),0)|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($25|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_String_m_Replace_mscorlib_System_String_mscorlib_System_Char_mscorlib_System_CharP22mscorlib_System_Stringtt($__this,$oldChar,$newChar) {
 $__this = $__this|0;
 $oldChar = $oldChar|0;
 $newChar = $newChar|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_5$0$in2 = 0, $V_6$01 = 0, $_stackTraceSentry = 0, $or$cond = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184104);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = ($oldChar<<16>>16)==($newChar<<16>>16);
 $or$cond = $2 | $3;
 if ($or$cond) {
  $$0 = $__this;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $4 = (invoke_iiiii(94,($__this|0),($oldChar|0),0,($1|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   $7 = ($4|0)==(-1);
   if ($7) {
    $$0 = $__this;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $10 = ($4|0)>(3);
   $$ = $10 ? $4 : 0;
   $11 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   $12 = (invoke_iii(643,0,($11|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_ii(1919,0)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = $12;
     $19 = (($15) + ($18))|0;
     $20 = (($__this) + 12|0);
     $21 = ($$|0)==(0);
     if (!($21)) {
      $22 = $19;
      __THREW__ = 0;
      invoke_viiii(124,0,($22|0),($20|0),($$|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
     }
     $25 = HEAP32[$0>>2]|0;
     $26 = $25 << 1;
     $27 = $19;
     $28 = (($27) + ($26)|0);
     $29 = $$ << 1;
     $30 = ($29|0)==($26|0);
     if ($30) {
      $$0 = $12;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($27) + ($29)|0);
     $32 = (($20) + ($$<<1)|0);
     $V_5$0$in2 = $31;$V_6$01 = $32;
     while(1) {
      $33 = HEAP16[$V_6$01>>1]|0;
      $34 = ($33<<16>>16)==($oldChar<<16>>16);
      $storemerge = $34 ? $newChar : $33;
      HEAP16[$V_5$0$in2>>1] = $storemerge;
      $35 = (($V_6$01) + 2|0);
      $36 = (($V_5$0$in2) + 2|0);
      $37 = ($36|0)==($28|0);
      if ($37) {
       $$0 = $12;
       break;
      } else {
       $V_5$0$in2 = $36;$V_6$01 = $35;
      }
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_String_m_Replace_mscorlib_System_String_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_StringS0_S0_($__this,$oldValue,$newValue) {
 $__this = $__this|0;
 $oldValue = $oldValue|0;
 $newValue = $newValue|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184152);
 __THREW__ = 0;
 invoke_v(405);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($oldValue|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006848>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($oldValue|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($oldValue|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(2560072|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = HEAP32[3006856>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($23|0),($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($23|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     $31 = (invoke_ii(1816,($__this|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      $34 = ($31|0)==(0);
      if ($34) {
       $$0 = $__this;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $35 = ($newValue|0)==(0|0);
      if ($35) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
       $38 = HEAP8[((2191608 + 116|0))>>0]|0;
       $39 = ($38<<24>>24)==(0);
       if ($39) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3831,(2191608|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       $48 = HEAP32[((2191608 + 80|0))>>2]|0;
       $49 = HEAP32[$48>>2]|0;
       $$01 = $49;
      } else {
       $$01 = $newValue;
      }
      __THREW__ = 0;
      $50 = (invoke_iiii(549,($__this|0),($oldValue|0),($$01|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if (!($52)) {
       $$0 = $50;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_String_m_ReplaceUncheckedP22mscorlib_System_StringS0_S0_($__this,$oldValue,$newValue) {
 $__this = $__this|0;
 $oldValue = $oldValue|0;
 $newValue = $newValue|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_10$0$lcssa = 0, $V_10$04 = 0, $V_12$03 = 0, $V_4$013 = 0, $V_5$0$lcssa = 0, $V_5$012 = 0, $V_9$0$lcssa = 0, $V_9$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184200);
 __THREW__ = 0;
 invoke_vi(3799,($oldValue|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($oldValue) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($__this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3|0)>($5|0);
   if ($6) {
    $$0 = $__this;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($oldValue|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[$2>>2]|0;
    $16 = ($15|0)==(1);
    if ($16) {
     __THREW__ = 0;
     invoke_vi(3799,($newValue|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     $19 = (($newValue) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(1);
     if ($21) {
      __THREW__ = 0;
      invoke_vi(3799,($oldValue|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      $24 = (invoke_iii(621,($oldValue|0),0)|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($newValue|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(621,($newValue|0),0)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iiii(546,($__this|0),($24|0),($29|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      } else {
       $$0 = $32;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    $35 = STACKTOP; STACKTOP = STACKTOP + 800|0;;
    __THREW__ = 0;
    $36 = (invoke_ii(1919,0)|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     $39 = $__this;
     $40 = (($36) + ($39))|0;
     __THREW__ = 0;
     $41 = (invoke_ii(1919,0)|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      $44 = $newValue;
      $45 = (($41) + ($44))|0;
      $46 = $45;
      $47 = HEAP32[$4>>2]|0;
      $48 = ($47|0)>(0);
      if ($48) {
       $65 = $47;$V_4$013 = 0;$V_5$012 = 0;
      } else {
       $$0 = $__this;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      while(1) {
       $64 = (($65) - ($V_4$013))|0;
       __THREW__ = 0;
       $50 = (invoke_iiiii(93,($__this|0),($oldValue|0),($V_4$013|0),($64|0))|0);
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        label = 4;
        break;
       }
       $49 = ($50|0)>(-1);
       if (!($49)) {
        $V_5$0$lcssa = $V_5$012;
        label = 25;
        break;
       }
       $51 = ($V_5$012|0)>(199);
       if ($51) {
        label = 22;
        break;
       }
       $52 = $V_5$012 << 2;
       $53 = (($35) + ($52)|0);
       HEAP32[$53>>2] = $50;
       __THREW__ = 0;
       invoke_vi(3799,($oldValue|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 4;
        break;
       }
       $59 = (($V_5$012) + 1)|0;
       $60 = HEAP32[$2>>2]|0;
       $61 = (($60) + ($50))|0;
       $62 = HEAP32[$4>>2]|0;
       $63 = ($61|0)<($62|0);
       if ($63) {
        $65 = $62;$V_4$013 = $61;$V_5$012 = $59;
       } else {
        $V_5$0$lcssa = $59;
        label = 25;
        break;
       }
      }
      if ((label|0) == 4) {
       $9 = ___cxa_find_matching_catch()|0;
       $10 = tempRet0;
       $lpad$phi$index = $9;$lpad$phi$index3 = $10;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 22) {
       __THREW__ = 0;
       $56 = (invoke_iiiii(97,($__this|0),($oldValue|0),($newValue|0),200)|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        break;
       } else {
        $$0 = $56;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      else if ((label|0) == 25) {
       $68 = ($V_5$0$lcssa|0)==(0);
       if ($68) {
        $$0 = $__this;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $69 = HEAP32[$4>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($newValue|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break;
       }
       $72 = (($newValue) + 8|0);
       $73 = HEAP32[$72>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($oldValue|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       $76 = HEAP32[$2>>2]|0;
       $77 = (($73) - ($76))|0;
       $78 = Math_imul($77, $V_5$0$lcssa)|0;
       $79 = (($78) + ($69))|0;
       __THREW__ = 0;
       $80 = (invoke_iii(643,0,($79|0))|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        break;
       }
       __THREW__ = 0;
       $83 = (invoke_ii(1919,0)|0);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       $86 = $80;
       $87 = (($83) + ($86))|0;
       $88 = ($V_5$0$lcssa|0)>(0);
       $89 = $87;
       $90 = $40;
       do {
        if ($88) {
         $V_10$04 = 0;$V_12$03 = 0;$V_9$05 = 0;
         while(1) {
          $111 = $V_12$03 << 2;
          $112 = (($35) + ($111)|0);
          $97 = HEAP32[$112>>2]|0;
          $92 = (($97) - ($V_10$04))|0;
          $113 = $V_9$05 << 1;
          $114 = (($89) + ($113)|0);
          $115 = $V_10$04 << 1;
          $116 = (($90) + ($115)|0);
          __THREW__ = 0;
          invoke_viiii(124,0,($114|0),($116|0),($92|0));
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           break;
          }
          $91 = (($92) + ($V_9$05))|0;
          __THREW__ = 0;
          invoke_vi(3799,($oldValue|0));
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           break;
          }
          $95 = HEAP32[$2>>2]|0;
          $96 = (($95) + ($97))|0;
          __THREW__ = 0;
          invoke_vi(3799,($newValue|0));
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break;
          }
          $100 = $91 << 1;
          $101 = (($89) + ($100)|0);
          $102 = HEAP32[$72>>2]|0;
          __THREW__ = 0;
          invoke_viiii(124,0,($101|0),($46|0),($102|0));
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($newValue|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break;
          }
          $107 = HEAP32[$72>>2]|0;
          $108 = (($107) + ($91))|0;
          $109 = (($V_12$03) + 1)|0;
          $110 = ($109|0)<($V_5$0$lcssa|0);
          if ($110) {
           $V_10$04 = $96;$V_12$03 = $109;$V_9$05 = $108;
          } else {
           label = 37;
           break;
          }
         }
         if ((label|0) == 37) {
          $phitmp = $108 << 1;
          $V_10$0$lcssa = $96;$V_9$0$lcssa = $phitmp;
          break;
         }
         $7 = ___cxa_find_matching_catch()|0;
         $8 = tempRet0;
         $lpad$phi$index = $7;$lpad$phi$index3 = $8;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        } else {
         $V_10$0$lcssa = 0;$V_9$0$lcssa = 0;
        }
       } while(0);
       $119 = (($89) + ($V_9$0$lcssa)|0);
       $120 = $V_10$0$lcssa << 1;
       $121 = (($90) + ($120)|0);
       $122 = HEAP32[$4>>2]|0;
       $123 = (($122) - ($V_10$0$lcssa))|0;
       __THREW__ = 0;
       invoke_viiii(124,0,($119|0),($121|0),($123|0));
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       if ($125) {
        break;
       } else {
        $$0 = $80;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_String_m_ReplaceFallbackP22mscorlib_System_StringS0_S0_i($__this,$oldValue,$newValue,$testedCount) {
 $__this = $__this|0;
 $oldValue = $oldValue|0;
 $newValue = $newValue|0;
 $testedCount = $testedCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$04 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184248);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($newValue|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if (!($3)) {
   $4 = (($newValue) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($oldValue|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($oldValue) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($5) - ($9))|0;
    $11 = Math_imul($10, $testedCount)|0;
    $12 = (($11) + ($1))|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2537888|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     $15 = (invoke_ii(3469,(2537888|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      invoke_vii(1910,($15|0),($12|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = HEAP32[$0>>2]|0;
       $21 = ($20|0)>(0);
       L7: do {
        if ($21) {
         $58 = $20;$V_2$04 = 0;
         while(1) {
          $57 = (($58) - ($V_2$04))|0;
          __THREW__ = 0;
          $27 = (invoke_iiiii(93,($__this|0),($oldValue|0),($V_2$04|0),($57|0))|0);
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           label = 7;
           break;
          }
          $26 = ($27|0)>(-1);
          if (!($26)) {
           break;
          }
          $37 = (($27) - ($V_2$04))|0;
          __THREW__ = 0;
          $38 = (invoke_iiii(529,($__this|0),($V_2$04|0),($37|0))|0);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($15|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          (invoke_iii(989,($15|0),($38|0))|0);
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($15|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          (invoke_iii(989,($15|0),($newValue|0))|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($oldValue|0));
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          $51 = (invoke_ii(1816,($oldValue|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           label = 7;
           break;
          }
          $54 = (($51) + ($27))|0;
          $55 = HEAP32[$0>>2]|0;
          $56 = ($54|0)<($55|0);
          if ($56) {
           $58 = $55;$V_2$04 = $54;
          } else {
           break L7;
          }
         }
         if ((label|0) == 7) {
          $22 = ___cxa_find_matching_catch()|0;
          $23 = tempRet0;
          $lpad$phi$index = $22;$lpad$phi$index2 = $23;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         $28 = HEAP32[$0>>2]|0;
         $29 = (($28) - ($V_2$04))|0;
         __THREW__ = 0;
         $30 = (invoke_iiii(529,($__this|0),($V_2$04|0),($29|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($15|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_iii(989,($15|0),($30|0))|0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          break L1;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($15|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if (!($62)) {
        __THREW__ = 0;
        $63 = (invoke_iii(2730,(2535432|0),($15|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if (!($65)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($63|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $lpad$phi$index = $24;$lpad$phi$index2 = $25;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z31mscorlib_System_String_m_RemoveP22mscorlib_System_Stringii($__this,$startIndex,$count) {
 $__this = $__this|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184296);
 __THREW__ = 0;
 invoke_v(406);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($startIndex|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3006952>>2]|0;
    $11 = HEAP32[3006960>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($7|0),($10|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = ($count|0)>(-1);
   if (!($16)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3006968>>2]|0;
    $23 = HEAP32[3006976>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($19|0),($22|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($19|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   $28 = (($__this) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) - ($count))|0;
   $31 = ($30|0)<($startIndex|0);
   if ($31) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    __THREW__ = 0;
    $34 = (invoke_ii(3469,(2561352|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = HEAP32[3006984>>2]|0;
    $38 = HEAP32[3006992>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($34|0),($37|0),($38|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($34|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $43 = (invoke_iii(643,0,($30|0))|0);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if (!($45)) {
    __THREW__ = 0;
    $46 = (invoke_ii(1919,0)|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if (!($48)) {
     $49 = $43;
     $50 = (($46) + ($49))|0;
     __THREW__ = 0;
     $51 = (invoke_ii(1919,0)|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      $54 = $50;
      $55 = $__this;
      $56 = (($51) + ($55))|0;
      $57 = $56;
      __THREW__ = 0;
      invoke_viiii(124,0,($54|0),($57|0),($startIndex|0));
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       $60 = (($count) + ($startIndex))|0;
       $61 = $startIndex << 1;
       $62 = $50;
       $63 = (($62) + ($61)|0);
       $64 = $60 << 1;
       $65 = $56;
       $66 = (($65) + ($64)|0);
       $67 = HEAP32[$28>>2]|0;
       $68 = (($67) - ($60))|0;
       __THREW__ = 0;
       invoke_viiii(124,0,($63|0),($66|0),($68|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if (!($70)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($43|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_String_m_ToLower_mscorlib_System_StringP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184344);
 __THREW__ = 0;
 $0 = (invoke_ii(1982,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(636,($__this|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_String_m_ToLower_mscorlib_System_String_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_StringP41mscorlib_System_Globalization_CultureInfo($__this,$culture) {
 $__this = $__this|0;
 $culture = $culture|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184392);
 __THREW__ = 0;
 invoke_v(407);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($culture|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3007072>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($culture|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(2729,(2273552|0),($culture|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(127);
     if ($20) {
      __THREW__ = 0;
      $21 = (invoke_ii(1814,($__this|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      } else {
       $$0 = $21;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($culture|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      $26 = (invoke_iii(2730,(2273600|0),($culture|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        $31 = (invoke_iiii(1645,(2305328|0),($26|0),($__this|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         $$0 = $31;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_String_m_ToLowerInvariantP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $V_3$07 = 0, $V_4$06 = 0, $V_5$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184440);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2191608 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[((2191608 + 80|0))>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     $$0 = $20;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   $21 = (invoke_iii(643,0,($1|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    $24 = (invoke_ii(1919,0)|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = HEAP32[$0>>2]|0;
     $28 = ($27|0)>(0);
     if (!($28)) {
      $$0 = $21;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $29 = $21;
     $30 = (($24) + ($29))|0;
     $31 = $30;
     $32 = (($__this) + 12|0);
     $V_3$07 = $31;$V_4$06 = $32;$V_5$05 = 0;
     while(1) {
      $39 = HEAP16[$V_4$06>>1]|0;
      __THREW__ = 0;
      $33 = (invoke_iii(606,0,($39|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      HEAP16[$V_3$07>>1] = $33;
      $34 = (($V_4$06) + 2|0);
      $35 = (($V_3$07) + 2|0);
      $36 = (($V_5$05) + 1)|0;
      $37 = HEAP32[$0>>2]|0;
      $38 = ($36|0)<($37|0);
      if ($38) {
       $V_3$07 = $35;$V_4$06 = $34;$V_5$05 = $36;
      } else {
       $$0 = $21;
       label = 18;
       break;
      }
     }
     if ((label|0) == 18) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $13 = ___cxa_find_matching_catch()|0;
     $14 = tempRet0;
     $lpad$phi$index = $13;$lpad$phi$index2 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index2 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_String_m_ToString_mscorlib_System_StringP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184488);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z88mscorlib_System_String_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_StringP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184536);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z100mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_String_mscorlib_System_ObjectP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$format,$arg0) {
 $__this = $__this|0;
 $format = $format|0;
 $arg0 = $arg0|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184584);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1167664|0),1)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($2|0),($arg0|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = (($2) + 16|0);
      HEAP32[$19>>2] = $arg0;
      __THREW__ = 0;
      $20 = (invoke_iiiii(99,0,(0|0),($format|0),($2|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($20|0);
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z140mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_IFormatProvider_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectS0_P22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$provider,$format,$args) {
 $__this = $__this|0;
 $provider = $provider|0;
 $format = $format|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184776);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(88,0,(0|0),($provider|0),($format|0),($args|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2535432|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z123mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectP22mscorlib_System_StringS0_S0_($__this,$format,$arg0,$arg1) {
 $__this = $__this|0;
 $format = $format|0;
 $arg0 = $arg0|0;
 $arg1 = $arg1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184632);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1167664|0),2)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($2|0),($arg0|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = (($2) + 16|0);
      HEAP32[$19>>2] = $arg0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[$7>>2]|0;
       $23 = ($22>>>0)<(2);
       if ($23) {
        __THREW__ = 0;
        $24 = (invoke_i(132)|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($24|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($2|0),($arg1|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = HEAP32[$2>>2]|0;
        $32 = (($31) + 92|0);
        $33 = HEAP32[$32>>2]|0;
        $34 = (($19) + ($33)|0);
        HEAP32[$34>>2] = $arg1;
        __THREW__ = 0;
        $35 = (invoke_iiiii(99,0,(0|0),($format|0),($2|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($35|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z146mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectP22mscorlib_System_StringS0_S0_S0_($__this,$format,$arg0,$arg1,$arg2) {
 $__this = $__this|0;
 $format = $format|0;
 $arg0 = $arg0|0;
 $arg1 = $arg1|0;
 $arg2 = $arg2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184680);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1167664|0),3)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($2|0),($arg0|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = (($2) + 16|0);
      HEAP32[$19>>2] = $arg0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[$7>>2]|0;
       $23 = ($22>>>0)<(2);
       if ($23) {
        __THREW__ = 0;
        $24 = (invoke_i(132)|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($24|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($2|0),($arg1|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = HEAP32[$2>>2]|0;
        $32 = (($31) + 92|0);
        $33 = HEAP32[$32>>2]|0;
        $34 = (($19) + ($33)|0);
        HEAP32[$34>>2] = $arg1;
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         $37 = HEAP32[$7>>2]|0;
         $38 = ($37>>>0)<(3);
         if ($38) {
          __THREW__ = 0;
          $39 = (invoke_i(132)|0);
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($39|0));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($2|0),($arg2|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if (!($45)) {
          $46 = HEAP32[$2>>2]|0;
          $47 = (($46) + 92|0);
          $48 = HEAP32[$47>>2]|0;
          $49 = $48 << 1;
          $50 = (($19) + ($49)|0);
          HEAP32[$50>>2] = $arg2;
          __THREW__ = 0;
          $51 = (invoke_iiiii(99,0,(0|0),($format|0),($2|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($51|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$format,$args) {
 $__this = $__this|0;
 $format = $format|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184728);
 __THREW__ = 0;
 $0 = (invoke_iiiii(99,0,(0|0),($format|0),($args|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z37mscorlib_System_String_m_FormatHelperP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderS0_P22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$result,$provider,$format,$args) {
 $__this = $__this|0;
 $result = $result|0;
 $provider = $provider|0;
 $format = $format|0;
 $args = $args|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_1$0 = 0, $V_11$0 = 0, $V_12$0 = 0, $V_3 = 0, $V_4$0$ph = 0, $V_6 = 0, $V_7 = 0, $V_8 = 0, $V_9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $_stackTraceSentry = sp;
 $V_3 = sp + 4|0;
 $V_6 = sp + 8|0;
 $V_7 = sp + 12|0;
 $V_8 = sp + 28|0;
 $V_9 = sp + 20|0;
 $0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184824);
 HEAP32[$V_3>>2] = 0;
 HEAP32[$V_6>>2] = 0;
 HEAP32[$V_7>>2] = 0;
 HEAP8[$V_8>>0] = 0;
 HEAP32[$V_9>>2] = 0;
 __THREW__ = 0;
 invoke_v(408);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = ($format|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2560584|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = HEAP32[3007088>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($14|0),($17|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($14|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    // unreachable;
   }
   $22 = ($args|0)==(0|0);
   if ($22) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    $25 = (invoke_ii(3469,(2560584|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = HEAP32[3007096>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($25|0),($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($25|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    // unreachable;
   }
   $33 = ($result|0)==(0|0);
   $34 = (($args) + 12|0);
   $35 = (($args) + 16|0);
   do {
    if ($33) {
     $V_0$0 = 0;$V_1$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($args|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 5;
       break;
      }
      $63 = HEAP32[$34>>2]|0;
      $64 = ($V_0$0|0)<($63|0);
      if (!($64)) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($args|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       label = 5;
       break;
      }
      $36 = HEAP32[$34>>2]|0;
      $37 = ($V_0$0>>>0)<($36>>>0);
      if (!($37)) {
       __THREW__ = 0;
       $38 = (invoke_i(132)|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        label = 5;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($38|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 5;
        break;
       }
      }
      $43 = HEAP32[$args>>2]|0;
      $44 = (($43) + 92|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = Math_imul($45, $V_0$0)|0;
      $47 = (($35) + ($46)|0);
      $48 = HEAP32[$47>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      $51 = (invoke_iii(2735,($48|0),(2191608|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 5;
       break;
      }
      $54 = ($51|0)==(0|0);
      if ($54) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($51|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 5;
       break;
      }
      $57 = (($51) + 8|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (($58) + ($V_1$0))|0;
      $60 = (($V_0$0) + 1)|0;
      $V_0$0 = $60;$V_1$0 = $59;
     }
     if ((label|0) == 5) {
      $8 = ___cxa_find_matching_catch()|0;
      $9 = tempRet0;
      $lpad$phi$index = $8;$lpad$phi$index4 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($args|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break L1;
     }
     $69 = HEAP32[$34>>2]|0;
     $70 = ($V_0$0|0)==($69|0);
     if (!($70)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2537888|0))|0);
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if ($84) {
       break L1;
      }
      __THREW__ = 0;
      $85 = (invoke_ii(3469,(2537888|0))|0);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(2525,($85|0));
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break L1;
      } else {
       $$0 = $85;
       break;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($format|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      break L1;
     }
     $73 = (($format) + 8|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = (($74) + ($V_1$0))|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2537888|0))|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break L1;
     }
     __THREW__ = 0;
     $78 = (invoke_ii(3469,(2537888|0))|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if ($80) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1910,($78|0),($75|0));
     $81 = __THREW__; __THREW__ = 0;
     $82 = $81&1;
     if ($82) {
      break L1;
     } else {
      $$0 = $78;
     }
    } else {
     $$0 = $result;
    }
   } while(0);
   HEAP32[$V_3>>2] = 0;
   $90 = (($format) + 8|0);
   $91 = ($provider|0)==(0|0);
   $280 = 0;$V_4$0$ph = 0;
   L45: while(1) {
    $92 = $280;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($format|0));
     $260 = __THREW__; __THREW__ = 0;
     $261 = $260&1;
     if ($261) {
      label = 3;
      break L45;
     }
     $262 = HEAP32[$90>>2]|0;
     $263 = ($92|0)<($262|0);
     if (!($263)) {
      label = 124;
      break L45;
     }
     $100 = (($92) + 1)|0;
     HEAP32[$V_3>>2] = $100;
     __THREW__ = 0;
     invoke_vi(3799,($format|0));
     $264 = __THREW__; __THREW__ = 0;
     $265 = $264&1;
     if ($265) {
      label = 3;
      break L45;
     }
     __THREW__ = 0;
     $93 = (invoke_iii(621,($format|0),($92|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      label = 3;
      break L45;
     }
     if ((($93<<16>>16) == 123)) {
      break;
     } else if ((($93<<16>>16) == 125)) {
      label = 108;
      break;
     } else {
      $92 = $100;
     }
    }
    if ((label|0) == 108) {
     label = 0;
     __THREW__ = 0;
     invoke_vi(3799,($format|0));
     $233 = __THREW__; __THREW__ = 0;
     $234 = $233&1;
     if ($234) {
      label = 3;
      break;
     }
     $235 = HEAP32[$90>>2]|0;
     $236 = ($100|0)<($235|0);
     if (!($236)) {
      label = 116;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($format|0));
     $237 = __THREW__; __THREW__ = 0;
     $238 = $237&1;
     if ($238) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     $239 = (invoke_iii(621,($format|0),($100|0))|0);
     $240 = __THREW__; __THREW__ = 0;
     $241 = $240&1;
     if ($241) {
      label = 3;
      break;
     }
     $242 = ($239<<16>>16)==(125);
     if (!($242)) {
      label = 116;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($$0|0));
     $243 = __THREW__; __THREW__ = 0;
     $244 = $243&1;
     if ($244) {
      label = 4;
      break;
     }
     $245 = $V_4$0$ph ^ -1;
     $246 = (($100) + ($245))|0;
     __THREW__ = 0;
     (invoke_iiiii(161,($$0|0),($format|0),($V_4$0$ph|0),($246|0))|0);
     $247 = __THREW__; __THREW__ = 0;
     $248 = $247&1;
     if ($248) {
      label = 4;
      break;
     }
     $249 = (($92) + 2)|0;
     HEAP32[$V_3>>2] = $249;
     $280 = $249;$V_4$0$ph = $100;
     continue;
    }
    __THREW__ = 0;
    invoke_vi(3799,($$0|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 4;
     break;
    }
    $98 = $V_4$0$ph ^ -1;
    $99 = (($100) + ($98))|0;
    __THREW__ = 0;
    (invoke_iiiii(161,($$0|0),($format|0),($V_4$0$ph|0),($99|0))|0);
    $101 = __THREW__; __THREW__ = 0;
    $102 = $101&1;
    if ($102) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($format|0));
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if ($104) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $105 = (invoke_iii(621,($format|0),($100|0))|0);
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     label = 4;
     break;
    }
    $108 = ($105<<16>>16)==(123);
    if ($108) {
     $109 = (($92) + 2)|0;
     HEAP32[$V_3>>2] = $109;
     $280 = $109;$V_4$0$ph = $100;
     continue;
    }
    __THREW__ = 0;
    invoke_viiiiiii(15,0,($format|0),($V_3|0),($V_6|0),($V_7|0),($V_8|0),($V_9|0));
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if ($111) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($args|0));
    $112 = __THREW__; __THREW__ = 0;
    $113 = $112&1;
    if ($113) {
     label = 4;
     break;
    }
    $114 = HEAP32[$34>>2]|0;
    $115 = HEAP32[$V_6>>2]|0;
    $116 = ($115|0)<($114|0);
    if (!($116)) {
     label = 53;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($args|0));
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     label = 4;
     break;
    }
    $129 = ($115|0)<(0);
    if ($129) {
     label = 61;
    } else {
     $130 = HEAP32[$34>>2]|0;
     $131 = ($115>>>0)<($130>>>0);
     if (!($131)) {
      label = 61;
     }
    }
    if ((label|0) == 61) {
     label = 0;
     __THREW__ = 0;
     $132 = (invoke_i(132)|0);
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if ($134) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($132|0));
     $135 = __THREW__; __THREW__ = 0;
     $136 = $135&1;
     if ($136) {
      label = 4;
      break;
     }
    }
    $137 = HEAP32[$args>>2]|0;
    $138 = (($137) + 92|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = Math_imul($139, $115)|0;
    $141 = (($35) + ($140)|0);
    $142 = HEAP32[$141>>2]|0;
    if ($91) {
     $V_12$0 = 0;
    } else {
     HEAP32[$0>>2] = 2271728;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $143 = (invoke_iii(772,0,($$byval_copy|0))|0);
     $144 = __THREW__; __THREW__ = 0;
     $145 = $144&1;
     if ($145) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($provider|0));
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $148 = (invoke_iiii(1666,(2606440|0),($provider|0),($143|0))|0);
     $149 = __THREW__; __THREW__ = 0;
     $150 = $149&1;
     if ($150) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2606272|0))|0);
     $151 = __THREW__; __THREW__ = 0;
     $152 = $151&1;
     if ($152) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $153 = (invoke_iii(2735,($148|0),(2606272|0))|0);
     $154 = __THREW__; __THREW__ = 0;
     $155 = $154&1;
     if ($155) {
      label = 4;
      break;
     }
     $V_12$0 = $153;
    }
    $156 = ($142|0)==(0|0);
    do {
     if ($156) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $157 = __THREW__; __THREW__ = 0;
      $158 = $157&1;
      if ($158) {
       label = 4;
       break L45;
      }
      $159 = HEAP8[((2191608 + 116|0))>>0]|0;
      $160 = ($159<<24>>24)==(0);
      if ($160) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       if ($162) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $163 = __THREW__; __THREW__ = 0;
       $164 = $163&1;
       if ($164) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       invoke_vi(3831,(2191608|0));
       $165 = __THREW__; __THREW__ = 0;
       $166 = $165&1;
       if ($166) {
        label = 4;
        break L45;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $167 = __THREW__; __THREW__ = 0;
      $168 = $167&1;
      if ($168) {
       label = 4;
       break L45;
      }
      $169 = HEAP32[((2191608 + 80|0))>>2]|0;
      $170 = HEAP32[$169>>2]|0;
      $V_11$0 = $170;
     } else {
      $171 = ($V_12$0|0)==(0|0);
      if (!($171)) {
       __THREW__ = 0;
       invoke_vi(3799,($V_12$0|0));
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       if ($173) {
        label = 4;
        break L45;
       }
       $174 = HEAP32[$V_9>>2]|0;
       __THREW__ = 0;
       $175 = (invoke_iiiiii(233,(2606176|0),($V_12$0|0),($174|0),($142|0),($provider|0))|0);
       $176 = __THREW__; __THREW__ = 0;
       $177 = $176&1;
       if ($177) {
        label = 4;
        break L45;
       }
       $V_11$0 = $175;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2156200|0))|0);
      $178 = __THREW__; __THREW__ = 0;
      $179 = $178&1;
      if ($179) {
       label = 4;
       break L45;
      }
      __THREW__ = 0;
      $180 = (invoke_iii(2735,($142|0),(2156200|0))|0);
      $181 = __THREW__; __THREW__ = 0;
      $182 = $181&1;
      if ($182) {
       label = 4;
       break L45;
      }
      $183 = ($180|0)==(0|0);
      if ($183) {
       __THREW__ = 0;
       invoke_vi(3799,($142|0));
       $195 = __THREW__; __THREW__ = 0;
       $196 = $195&1;
       if ($196) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       $197 = (invoke_iii(2730,(2149112|0),($142|0))|0);
       $198 = __THREW__; __THREW__ = 0;
       $199 = $198&1;
       if ($199) {
        label = 4;
        break L45;
       }
       $V_11$0 = $197;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2156200|0))|0);
      $184 = __THREW__; __THREW__ = 0;
      $185 = $184&1;
      if ($185) {
       label = 4;
       break L45;
      }
      __THREW__ = 0;
      $186 = (invoke_iii(2755,($142|0),(2156200|0))|0);
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if ($188) {
       label = 4;
       break L45;
      }
      __THREW__ = 0;
      invoke_vi(3799,($186|0));
      $189 = __THREW__; __THREW__ = 0;
      $190 = $189&1;
      if ($190) {
       label = 4;
       break L45;
      }
      $191 = HEAP32[$V_9>>2]|0;
      __THREW__ = 0;
      $192 = (invoke_iiiii(316,(2156112|0),($186|0),($191|0),($provider|0))|0);
      $193 = __THREW__; __THREW__ = 0;
      $194 = $193&1;
      if ($194) {
       label = 4;
       break L45;
      }
      $V_11$0 = $192;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vi(3799,($V_11$0|0));
    $200 = __THREW__; __THREW__ = 0;
    $201 = $200&1;
    if ($201) {
     label = 4;
     break;
    }
    $202 = (($V_11$0) + 8|0);
    $203 = HEAP32[$202>>2]|0;
    $204 = HEAP32[$V_7>>2]|0;
    $205 = ($204|0)>($203|0);
    do {
     if ($205) {
      __THREW__ = 0;
      invoke_vi(3799,($V_11$0|0));
      $206 = __THREW__; __THREW__ = 0;
      $207 = $206&1;
      if ($207) {
       label = 4;
       break L45;
      }
      $208 = HEAP32[$202>>2]|0;
      $209 = (($204) - ($208))|0;
      $210 = HEAP8[$V_8>>0]|0;
      $211 = ($210<<24>>24)==(0);
      if ($211) {
       __THREW__ = 0;
       invoke_vi(3799,($$0|0));
       $220 = __THREW__; __THREW__ = 0;
       $221 = $220&1;
       if ($221) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       (invoke_iiii(932,($$0|0),32,($209|0))|0);
       $222 = __THREW__; __THREW__ = 0;
       $223 = $222&1;
       if ($223) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       invoke_vi(3799,($$0|0));
       $224 = __THREW__; __THREW__ = 0;
       $225 = $224&1;
       if ($225) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       (invoke_iii(989,($$0|0),($V_11$0|0))|0);
       $226 = __THREW__; __THREW__ = 0;
       $227 = $226&1;
       if ($227) {
        label = 4;
        break L45;
       } else {
        break;
       }
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($$0|0));
       $212 = __THREW__; __THREW__ = 0;
       $213 = $212&1;
       if ($213) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       (invoke_iii(989,($$0|0),($V_11$0|0))|0);
       $214 = __THREW__; __THREW__ = 0;
       $215 = $214&1;
       if ($215) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       invoke_vi(3799,($$0|0));
       $216 = __THREW__; __THREW__ = 0;
       $217 = $216&1;
       if ($217) {
        label = 4;
        break L45;
       }
       __THREW__ = 0;
       (invoke_iiii(932,($$0|0),32,($209|0))|0);
       $218 = __THREW__; __THREW__ = 0;
       $219 = $218&1;
       if ($219) {
        label = 4;
        break L45;
       } else {
        break;
       }
      }
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($$0|0));
      $228 = __THREW__; __THREW__ = 0;
      $229 = $228&1;
      if ($229) {
       label = 4;
       break L45;
      }
      __THREW__ = 0;
      (invoke_iii(989,($$0|0),($V_11$0|0))|0);
      $230 = __THREW__; __THREW__ = 0;
      $231 = $230&1;
      if ($231) {
       label = 4;
       break L45;
      }
     }
    } while(0);
    $232 = HEAP32[$V_3>>2]|0;
    $280 = $232;$V_4$0$ph = $232;
   }
   if ((label|0) == 3) {
    $4 = ___cxa_find_matching_catch()|0;
    $5 = tempRet0;
    $lpad$phi$index = $4;$lpad$phi$index4 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 4) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    $lpad$phi$index = $6;$lpad$phi$index4 = $7;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 53) {
    __THREW__ = 0;
    (invoke_ii(2996,(2603176|0))|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     break;
    }
    __THREW__ = 0;
    $119 = (invoke_ii(3469,(2603176|0))|0);
    $120 = __THREW__; __THREW__ = 0;
    $121 = $120&1;
    if ($121) {
     break;
    }
    $122 = HEAP32[3007104>>2]|0;
    __THREW__ = 0;
    invoke_vii(1940,($119|0),($122|0));
    $123 = __THREW__; __THREW__ = 0;
    $124 = $123&1;
    if ($124) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($119|0));
    $125 = __THREW__; __THREW__ = 0;
    $126 = $125&1;
    if ($126) {
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 116) {
    __THREW__ = 0;
    (invoke_ii(2996,(2603176|0))|0);
    $250 = __THREW__; __THREW__ = 0;
    $251 = $250&1;
    if ($251) {
     break;
    }
    __THREW__ = 0;
    $252 = (invoke_ii(3469,(2603176|0))|0);
    $253 = __THREW__; __THREW__ = 0;
    $254 = $253&1;
    if ($254) {
     break;
    }
    $255 = HEAP32[3007112>>2]|0;
    __THREW__ = 0;
    invoke_vii(1940,($252|0),($255|0));
    $256 = __THREW__; __THREW__ = 0;
    $257 = $256&1;
    if ($257) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($252|0));
    $258 = __THREW__; __THREW__ = 0;
    $259 = $258&1;
    if ($259) {
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 124) {
    __THREW__ = 0;
    invoke_vi(3799,($format|0));
    $266 = __THREW__; __THREW__ = 0;
    $267 = $266&1;
    if ($267) {
     break;
    }
    $268 = HEAP32[$90>>2]|0;
    $269 = ($V_4$0$ph|0)<($268|0);
    if (!($269)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($format|0));
    $270 = __THREW__; __THREW__ = 0;
    $271 = $270&1;
    if ($271) {
     break;
    }
    __THREW__ = 0;
    $272 = (invoke_ii(1816,($format|0))|0);
    $273 = __THREW__; __THREW__ = 0;
    $274 = $273&1;
    if ($274) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($$0|0));
    $275 = __THREW__; __THREW__ = 0;
    $276 = $275&1;
    if ($276) {
     break;
    }
    $277 = (($272) - ($V_4$0$ph))|0;
    __THREW__ = 0;
    (invoke_iiiii(161,($$0|0),($format|0),($V_4$0$ph|0),($277|0))|0);
    $278 = __THREW__; __THREW__ = 0;
    $279 = $278&1;
    if ($279) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index4 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_String_m_ParseFormatSpecifierP22mscorlib_System_ObjectP22mscorlib_System_StringPiS3_S3_PbPS2_($__this,$str,$ptr,$n,$width,$left_align,$format) {
 $__this = $__this|0;
 $str = $str|0;
 $ptr = $ptr|0;
 $n = $n|0;
 $width = $width|0;
 $left_align = $left_align|0;
 $format = $format|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $storemerge = 0, $storemerge$in = 0, $storemerge2 = 0, $storemerge3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185352);
 __THREW__ = 0;
 invoke_v(409);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iiii(566,0,($str|0),($ptr|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   do {
    if ($4) {
     label = 7;
    } else {
     HEAP32[$n>>2] = $2;
     $5 = ($2|0)>(-1);
     if (!($5)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2603176|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       label = 7;
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_ii(3469,(2603176|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 7;
       break;
      }
      $29 = HEAP32[3007672>>2]|0;
      __THREW__ = 0;
      invoke_vii(1940,($26|0),($29|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 7;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($26|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 7;
       break;
      }
      // unreachable;
     }
     $34 = HEAP32[$ptr>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($str|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 7;
     } else {
      __THREW__ = 0;
      $37 = (invoke_iii(621,($str|0),($34|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 7;
      } else {
       $40 = ($37<<16>>16)==(44);
       if ($40) {
        $41 = HEAP32[$ptr>>2]|0;
        $storemerge$in = $41;
        while(1) {
         $storemerge = (($storemerge$in) + 1)|0;
         HEAP32[$ptr>>2] = $storemerge;
         __THREW__ = 0;
         invoke_vi(3799,($str|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 6;
          break;
         }
         __THREW__ = 0;
         $44 = (invoke_iii(621,($str|0),($storemerge|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 6;
          break;
         }
         __THREW__ = 0;
         $47 = (invoke_iii(604,0,($44|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          label = 6;
          break;
         }
         $50 = HEAP32[$ptr>>2]|0;
         if ($47) {
          $storemerge$in = $50;
         } else {
          break;
         }
        }
        if ((label|0) == 6) {
         $10 = ___cxa_find_matching_catch(348288|0)|0;
         $11 = tempRet0;
         $lpad$phi$index = $10;$lpad$phi$index3 = $11;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($str|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 7;
         break;
        }
        __THREW__ = 0;
        $53 = (invoke_iiii(528,($str|0),($50|0),0)|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 7;
         break;
        }
        HEAP32[$format>>2] = $53;
        $56 = HEAP32[$ptr>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($str|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 7;
         break;
        }
        __THREW__ = 0;
        $59 = (invoke_iii(621,($str|0),($56|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 7;
         break;
        }
        $62 = ($59<<16>>16)==(45);
        $63 = $62&1;
        HEAP8[$left_align>>0] = $63;
        if ($62) {
         $64 = HEAP32[$ptr>>2]|0;
         $65 = (($64) + 1)|0;
         HEAP32[$ptr>>2] = $65;
        }
        __THREW__ = 0;
        $66 = (invoke_iiii(566,0,($str|0),($ptr|0))|0);
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         label = 7;
         break;
        }
        HEAP32[$width>>2] = $66;
        $69 = ($66|0)>(-1);
        if (!($69)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2603176|0))|0);
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $72 = (invoke_ii(3469,(2603176|0))|0);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          label = 7;
          break;
         }
         $75 = HEAP32[3007680>>2]|0;
         __THREW__ = 0;
         invoke_vii(1940,($72|0),($75|0));
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3830,($72|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          label = 7;
          break;
         }
         // unreachable;
        }
       } else {
        HEAP32[$width>>2] = 0;
        HEAP8[$left_align>>0] = 0;
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 7;
         break;
        }
        $82 = HEAP8[((2191608 + 116|0))>>0]|0;
        $83 = ($82<<24>>24)==(0);
        if ($83) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3831,(2191608|0));
         $88 = __THREW__; __THREW__ = 0;
         $89 = $88&1;
         if ($89) {
          label = 7;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         label = 7;
         break;
        }
        $92 = HEAP32[((2191608 + 80|0))>>2]|0;
        $93 = HEAP32[$92>>2]|0;
        HEAP32[$format>>2] = $93;
       }
       $94 = HEAP32[$ptr>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($str|0));
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        label = 7;
       } else {
        __THREW__ = 0;
        $97 = (invoke_iii(621,($str|0),($94|0))|0);
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         label = 7;
        } else {
         $100 = ($97<<16>>16)==(58);
         if ($100) {
          $101 = HEAP32[$ptr>>2]|0;
          $102 = (($101) + 1)|0;
          $storemerge2 = $102;
          while(1) {
           HEAP32[$ptr>>2] = $storemerge2;
           __THREW__ = 0;
           invoke_vi(3799,($str|0));
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           $105 = (invoke_iii(621,($str|0),($storemerge2|0))|0);
           $106 = __THREW__; __THREW__ = 0;
           $107 = $106&1;
           if ($107) {
            label = 5;
            break;
           }
           $108 = ($105<<16>>16)==(125);
           if ($108) {
            break;
           }
           $109 = HEAP32[$ptr>>2]|0;
           $110 = (($109) + 1)|0;
           $storemerge2 = $110;
          }
          if ((label|0) == 5) {
           $8 = ___cxa_find_matching_catch(348288|0)|0;
           $9 = tempRet0;
           $lpad$phi$index = $8;$lpad$phi$index3 = $9;
           break;
          }
          $111 = HEAP32[$format>>2]|0;
          $112 = HEAP32[$ptr>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($str|0));
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           label = 7;
           break;
          }
          $115 = (($112) - ($102))|0;
          __THREW__ = 0;
          $116 = (invoke_iiii(528,($str|0),($102|0),($115|0))|0);
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          $119 = (invoke_iiii(562,0,($111|0),($116|0))|0);
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 7;
           break;
          } else {
           $storemerge3 = $119;
          }
         } else {
          $storemerge3 = 0;
         }
         HEAP32[$format>>2] = $storemerge3;
         $122 = HEAP32[$ptr>>2]|0;
         $123 = (($122) + 1)|0;
         HEAP32[$ptr>>2] = $123;
         __THREW__ = 0;
         invoke_vi(3799,($str|0));
         $124 = __THREW__; __THREW__ = 0;
         $125 = $124&1;
         if ($125) {
          label = 7;
         } else {
          __THREW__ = 0;
          $126 = (invoke_iii(621,($str|0),($122|0))|0);
          $127 = __THREW__; __THREW__ = 0;
          $128 = $127&1;
          if ($128) {
           label = 7;
          } else {
           $129 = ($126<<16>>16)==(125);
           if ($129) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2603176|0))|0);
           $130 = __THREW__; __THREW__ = 0;
           $131 = $130&1;
           if ($131) {
            label = 7;
           } else {
            __THREW__ = 0;
            $132 = (invoke_ii(3469,(2603176|0))|0);
            $133 = __THREW__; __THREW__ = 0;
            $134 = $133&1;
            if ($134) {
             label = 7;
            } else {
             $135 = HEAP32[3007688>>2]|0;
             __THREW__ = 0;
             invoke_vii(1940,($132|0),($135|0));
             $136 = __THREW__; __THREW__ = 0;
             $137 = $136&1;
             if ($137) {
              label = 7;
             } else {
              __THREW__ = 0;
              invoke_vi(3830,($132|0));
              $138 = __THREW__; __THREW__ = 0;
              $139 = $138&1;
              if ($139) {
               label = 7;
              } else {
               // unreachable;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 7) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $lpad$phi$index = $12;$lpad$phi$index3 = $13;
   }
   $14 = (_llvm_eh_typeid_for((348288|0))|0);
   $15 = ($lpad$phi$index3|0)==($14|0);
   if (!($15)) {
    $$0 = $lpad$phi$index;$$01 = $lpad$phi$index3;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $16 = (___cxa_begin_catch(($lpad$phi$index|0))|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   $19 = (invoke_iii(2727,(2606944|0),($18|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   do {
    if (!($21)) {
     if (!($19)) {
      $144 = (___cxa_allocate_exception(4)|0);
      $145 = HEAP32[$16>>2]|0;
      HEAP32[$144>>2] = $145;
      __THREW__ = 0;
      invoke_viii(1567,($144|0),(348288|0),(0|0));
      $146 = __THREW__; __THREW__ = 0;
      $147 = $146&1;
      if ($147) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_v(66);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2603176|0))|0);
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     if ($149) {
      break L1;
     }
     __THREW__ = 0;
     $150 = (invoke_ii(3469,(2603176|0))|0);
     $151 = __THREW__; __THREW__ = 0;
     $152 = $151&1;
     if ($152) {
      break L1;
     }
     $153 = HEAP32[3007696>>2]|0;
     __THREW__ = 0;
     invoke_vii(1940,($150|0),($153|0));
     $154 = __THREW__; __THREW__ = 0;
     $155 = $154&1;
     if ($155) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3830,($150|0));
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if ($157) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $140 = ___cxa_find_matching_catch()|0;
   $141 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $142 = __THREW__; __THREW__ = 0;
   $143 = $142&1;
   if ($143) {
    $158 = ___cxa_find_matching_catch(0|0)|0;
    $159 = tempRet0;
    ___clang_call_terminate($158);
    // unreachable;
   } else {
    $$0 = $140;$$01 = $141;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $$0 = $6;$$01 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS0_E6InvokeEP10MethodInfoPvS5_P22mscorlib_System_ObjectS5_($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN21InterfaceFuncInvoker2I17VoidPointerTraitsS0_S0_E6InvokeEP10MethodInfoPvS4_S4_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z100mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_S0_($__this,$arg0,$arg1) {
 $__this = $__this|0;
 $arg0 = $arg0|0;
 $arg1 = $arg1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $G_B6_0$0 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184872);
 $0 = ($arg0|0)==(0|0);
 if ($0) {
  $G_B3_0$0 = 0;
  label = 6;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($arg0|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2730,(2149112|0),($arg0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $G_B3_0$0 = $3;
    label = 6;
   }
  }
 }
 do {
  if ((label|0) == 6) {
   $8 = ($arg1|0)==(0|0);
   if ($8) {
    $G_B6_0$0 = 0;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($arg1|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_iii(2730,(2149112|0),($arg1|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $G_B6_0$0 = $11;
   }
   __THREW__ = 0;
   $14 = (invoke_iiii(562,0,($G_B3_0$0|0),($G_B6_0$0|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_($__this,$str0,$str1) {
 $__this = $__this|0;
 $str0 = $str0|0;
 $str1 = $str1|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184968);
 $0 = ($str0|0)==(0|0);
 do {
  if ($0) {
   label = 6;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($str0|0));
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(1816,($str0|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     $6 = ($3|0)==(0);
     if ($6) {
      label = 6;
     } else {
      $30 = ($str1|0)==(0|0);
      if ($30) {
       $$0 = $str0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($str1|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       $33 = (invoke_ii(1816,($str1|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $36 = ($33|0)==(0);
        if ($36) {
         $$0 = $str0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($str0|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = (($str0) + 8|0);
         $40 = HEAP32[$39>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($str1|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = (($str1) + 8|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = (($44) + ($40))|0;
          __THREW__ = 0;
          $46 = (invoke_iii(643,0,($45|0))|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if (!($48)) {
           $49 = $46;
           __THREW__ = 0;
           $50 = (invoke_ii(1919,0)|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            $53 = (($50) + ($49))|0;
            $54 = $53;
            __THREW__ = 0;
            $55 = (invoke_ii(1919,0)|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if (!($57)) {
             __THREW__ = 0;
             invoke_vi(3799,($str0|0));
             $58 = __THREW__; __THREW__ = 0;
             $59 = $58&1;
             if (!($59)) {
              $60 = $str0;
              $61 = (($55) + ($60))|0;
              $62 = $61;
              $63 = HEAP32[$39>>2]|0;
              __THREW__ = 0;
              invoke_viiii(124,0,($54|0),($62|0),($63|0));
              $64 = __THREW__; __THREW__ = 0;
              $65 = $64&1;
              if (!($65)) {
               __THREW__ = 0;
               $66 = (invoke_ii(1919,0)|0);
               $67 = __THREW__; __THREW__ = 0;
               $68 = $67&1;
               if (!($68)) {
                $69 = (($66) + ($49))|0;
                __THREW__ = 0;
                $70 = (invoke_ii(1919,0)|0);
                $71 = __THREW__; __THREW__ = 0;
                $72 = $71&1;
                if (!($72)) {
                 $73 = $str1;
                 $74 = (($70) + ($73))|0;
                 $75 = $74;
                 __THREW__ = 0;
                 invoke_vi(3799,($str0|0));
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if (!($77)) {
                  __THREW__ = 0;
                  $78 = (invoke_ii(1816,($str0|0))|0);
                  $79 = __THREW__; __THREW__ = 0;
                  $80 = $79&1;
                  if (!($80)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($str1|0));
                   $81 = __THREW__; __THREW__ = 0;
                   $82 = $81&1;
                   if ($82) {
                    break;
                   }
                   $83 = $69;
                   $84 = $78 << 1;
                   $85 = (($83) + ($84)|0);
                   $86 = HEAP32[$43>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii(124,0,($85|0),($75|0),($86|0));
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   } else {
                    $$0 = $46;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($$0|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 6) {
   $9 = ($str1|0)==(0|0);
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(3799,($str1|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(1816,($str1|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    $15 = ($12|0)==(0);
    if (!($15)) {
     $$0 = $str1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP8[((2191608 + 116|0))>>0]|0;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = HEAP32[((2191608 + 80|0))>>2]|0;
     $29 = HEAP32[$28>>2]|0;
     $$0 = $29;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z123mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_S0_S0_($__this,$arg0,$arg1,$arg2) {
 $__this = $__this|0;
 $arg0 = $arg0|0;
 $arg1 = $arg1|0;
 $arg2 = $arg2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_1$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2184920);
 $0 = ($arg0|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = HEAP8[((2191608 + 116|0))>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $5 = __THREW__; __THREW__ = 0;
     $6 = $5&1;
     if ($6) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[((2191608 + 80|0))>>2]|0;
     $16 = HEAP32[$15>>2]|0;
     $V_0$0 = $16;
     label = 13;
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($arg0|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_iii(2730,(2149112|0),($arg0|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $V_0$0 = $19;
     label = 13;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 13) {
   $22 = ($arg1|0)==(0|0);
   if ($22) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP8[((2191608 + 116|0))>>0]|0;
    $26 = ($25<<24>>24)==(0);
    if ($26) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = HEAP32[((2191608 + 80|0))>>2]|0;
    $36 = HEAP32[$35>>2]|0;
    $V_1$0 = $36;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($arg1|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_iii(2730,(2149112|0),($arg1|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    $V_1$0 = $39;
   }
   $42 = ($arg2|0)==(0|0);
   if ($42) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    $45 = HEAP8[((2191608 + 116|0))>>0]|0;
    $46 = ($45<<24>>24)==(0);
    if ($46) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    $55 = HEAP32[((2191608 + 80|0))>>2]|0;
    $56 = HEAP32[$55>>2]|0;
    $V_2$0 = $56;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($arg2|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     break;
    }
    __THREW__ = 0;
    $59 = (invoke_iii(2730,(2149112|0),($arg2|0))|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     break;
    }
    $V_2$0 = $59;
   }
   __THREW__ = 0;
   $62 = (invoke_iiiii(101,0,($V_0$0|0),($V_1$0|0),($V_2$0|0))|0);
   $63 = __THREW__; __THREW__ = 0;
   $64 = $63&1;
   if (!($64)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($62|0);
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z123mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_String_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_S2_($__this,$str0,$str1,$str2) {
 $__this = $__this|0;
 $str0 = $str0|0;
 $str1 = $str1|0;
 $str2 = $str2|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $tmp = 0, $tmp19 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185016);
 $0 = ($str0|0)==(0|0);
 do {
  if ($0) {
   label = 6;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($str0|0));
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(1816,($str0|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     $6 = ($3|0)==(0);
     if ($6) {
      label = 6;
     } else {
      $58 = ($str1|0)==(0|0);
      if (!($58)) {
       __THREW__ = 0;
       invoke_vi(3799,($str1|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       __THREW__ = 0;
       $61 = (invoke_ii(1816,($str1|0))|0);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        break;
       }
       $64 = ($61|0)==(0);
       if (!($64)) {
        $86 = ($str2|0)==(0|0);
        if (!($86)) {
         __THREW__ = 0;
         invoke_vi(3799,($str2|0));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          break;
         }
         __THREW__ = 0;
         $89 = (invoke_ii(1816,($str2|0))|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break;
         }
         $92 = ($89|0)==(0);
         if (!($92)) {
          $$01 = $str0;$$02 = $str1;$$03 = $str2;
          label = 58;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         break;
        }
        $95 = HEAP8[((2191608 + 116|0))>>0]|0;
        $96 = ($95<<24>>24)==(0);
        if ($96) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3831,(2191608|0));
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         break;
        }
        $105 = HEAP32[((2191608 + 80|0))>>2]|0;
        $106 = HEAP32[$105>>2]|0;
        $$01 = $str0;$$02 = $str1;$$03 = $106;
        label = 58;
        break;
       }
      }
      $65 = ($str2|0)==(0|0);
      if ($65) {
       $$0 = $str0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($str2|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if (!($67)) {
       __THREW__ = 0;
       $68 = (invoke_ii(1816,($str2|0))|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if (!($70)) {
        $71 = ($68|0)==(0);
        if ($71) {
         $$0 = $str0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if (!($73)) {
         $74 = HEAP8[((2191608 + 116|0))>>0]|0;
         $75 = ($74<<24>>24)==(0);
         if ($75) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3831,(2191608|0));
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          if ($81) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if (!($83)) {
          $84 = HEAP32[((2191608 + 80|0))>>2]|0;
          $85 = HEAP32[$84>>2]|0;
          $$01 = $str0;$$02 = $85;$$03 = $str2;
          label = 58;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 6) {
   $9 = ($str1|0)==(0|0);
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(3799,($str1|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(1816,($str1|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    $15 = ($12|0)==(0);
    if (!($15)) {
     $37 = ($str2|0)==(0|0);
     if ($37) {
      $$0 = $str1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($str2|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     __THREW__ = 0;
     $40 = (invoke_ii(1816,($str2|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     $43 = ($40|0)==(0);
     if ($43) {
      $$0 = $str1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     $46 = HEAP8[((2191608 + 116|0))>>0]|0;
     $47 = ($46<<24>>24)==(0);
     if ($47) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2191608|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     $56 = HEAP32[((2191608 + 80|0))>>2]|0;
     $57 = HEAP32[$56>>2]|0;
     $$01 = $57;$$02 = $str1;$$03 = $str2;
     label = 58;
     break;
    }
   }
   $16 = ($str2|0)==(0|0);
   if (!($16)) {
    __THREW__ = 0;
    invoke_vi(3799,($str2|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(1816,($str2|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = ($19|0)==(0);
    if (!($22)) {
     $$0 = $str2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = HEAP8[((2191608 + 116|0))>>0]|0;
    $26 = ($25<<24>>24)==(0);
    if ($26) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = HEAP32[((2191608 + 80|0))>>2]|0;
     $36 = HEAP32[$35>>2]|0;
     $$0 = $36;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 58) {
   __THREW__ = 0;
   invoke_vi(3799,($$01|0));
   $107 = __THREW__; __THREW__ = 0;
   $108 = $107&1;
   if (!($108)) {
    $109 = (($$01) + 8|0);
    $110 = HEAP32[$109>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($$02|0));
    $111 = __THREW__; __THREW__ = 0;
    $112 = $111&1;
    if (!($112)) {
     $113 = (($$02) + 8|0);
     $114 = HEAP32[$113>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($$03|0));
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     if (!($116)) {
      $117 = (($114) + ($110))|0;
      $118 = (($$03) + 8|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = (($117) + ($119))|0;
      __THREW__ = 0;
      $121 = (invoke_iii(643,0,($120|0))|0);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if (!($123)) {
       __THREW__ = 0;
       invoke_vi(3799,($$01|0));
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       if (!($125)) {
        __THREW__ = 0;
        $126 = (invoke_ii(1816,($$01|0))|0);
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if (!($128)) {
         $129 = ($126|0)==(0);
         if (!($129)) {
          __THREW__ = 0;
          $130 = (invoke_ii(1919,0)|0);
          $131 = __THREW__; __THREW__ = 0;
          $132 = $131&1;
          if ($132) {
           break;
          }
          $133 = $121;
          $134 = (($130) + ($133))|0;
          $135 = $134;
          __THREW__ = 0;
          $136 = (invoke_ii(1919,0)|0);
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if ($138) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($$01|0));
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           break;
          }
          $141 = $$01;
          $142 = (($136) + ($141))|0;
          $143 = $142;
          $144 = HEAP32[$109>>2]|0;
          __THREW__ = 0;
          invoke_viiii(124,0,($135|0),($143|0),($144|0));
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          if ($146) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($$02|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if (!($148)) {
          __THREW__ = 0;
          $149 = (invoke_ii(1816,($$02|0))|0);
          $150 = __THREW__; __THREW__ = 0;
          $151 = $150&1;
          if (!($151)) {
           $152 = ($149|0)==(0);
           if (!($152)) {
            __THREW__ = 0;
            $153 = (invoke_ii(1919,0)|0);
            $154 = __THREW__; __THREW__ = 0;
            $155 = $154&1;
            if ($155) {
             break;
            }
            $156 = $121;
            $157 = (($153) + ($156))|0;
            __THREW__ = 0;
            $158 = (invoke_ii(1919,0)|0);
            $159 = __THREW__; __THREW__ = 0;
            $160 = $159&1;
            if ($160) {
             break;
            }
            $161 = $$02;
            $162 = (($158) + ($161))|0;
            $163 = $162;
            __THREW__ = 0;
            invoke_vi(3799,($$01|0));
            $164 = __THREW__; __THREW__ = 0;
            $165 = $164&1;
            if ($165) {
             break;
            }
            __THREW__ = 0;
            $166 = (invoke_ii(1816,($$01|0))|0);
            $167 = __THREW__; __THREW__ = 0;
            $168 = $167&1;
            if ($168) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($$02|0));
            $169 = __THREW__; __THREW__ = 0;
            $170 = $169&1;
            if ($170) {
             break;
            }
            $171 = $157;
            $172 = $166 << 1;
            $173 = (($171) + ($172)|0);
            $174 = HEAP32[$113>>2]|0;
            __THREW__ = 0;
            invoke_viiii(124,0,($173|0),($163|0),($174|0));
            $175 = __THREW__; __THREW__ = 0;
            $176 = $175&1;
            if ($176) {
             break;
            }
           }
           __THREW__ = 0;
           invoke_vi(3799,($$03|0));
           $177 = __THREW__; __THREW__ = 0;
           $178 = $177&1;
           if (!($178)) {
            __THREW__ = 0;
            $179 = (invoke_ii(1816,($$03|0))|0);
            $180 = __THREW__; __THREW__ = 0;
            $181 = $180&1;
            if (!($181)) {
             $182 = ($179|0)==(0);
             if ($182) {
              $$0 = $121;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             $183 = (invoke_ii(1919,0)|0);
             $184 = __THREW__; __THREW__ = 0;
             $185 = $184&1;
             if (!($185)) {
              $186 = $121;
              $187 = (($183) + ($186))|0;
              __THREW__ = 0;
              $188 = (invoke_ii(1919,0)|0);
              $189 = __THREW__; __THREW__ = 0;
              $190 = $189&1;
              if (!($190)) {
               $191 = $$03;
               $192 = (($188) + ($191))|0;
               $193 = $192;
               __THREW__ = 0;
               invoke_vi(3799,($$01|0));
               $194 = __THREW__; __THREW__ = 0;
               $195 = $194&1;
               if (!($195)) {
                __THREW__ = 0;
                $196 = (invoke_ii(1816,($$01|0))|0);
                $197 = __THREW__; __THREW__ = 0;
                $198 = $197&1;
                if (!($198)) {
                 $199 = $187;
                 __THREW__ = 0;
                 invoke_vi(3799,($$02|0));
                 $200 = __THREW__; __THREW__ = 0;
                 $201 = $200&1;
                 if (!($201)) {
                  __THREW__ = 0;
                  $202 = (invoke_ii(1816,($$02|0))|0);
                  $203 = __THREW__; __THREW__ = 0;
                  $204 = $203&1;
                  if ($204) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($$03|0));
                  $205 = __THREW__; __THREW__ = 0;
                  $206 = $205&1;
                  if ($206) {
                   break;
                  }
                  $tmp = (($202) + ($196))|0;
                  $tmp19 = $tmp << 1;
                  $207 = (($199) + ($tmp19)|0);
                  $208 = HEAP32[$118>>2]|0;
                  __THREW__ = 0;
                  invoke_viiii(124,0,($207|0),($193|0),($208|0));
                  $209 = __THREW__; __THREW__ = 0;
                  $210 = $209&1;
                  if ($210) {
                   break;
                  } else {
                   $$0 = $121;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z146mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_String_mscorlib_System_String_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_S2_S2_($__this,$str0,$str1,$str2,$str3) {
 $__this = $__this|0;
 $str0 = $str0|0;
 $str1 = $str1|0;
 $str2 = $str2|0;
 $str3 = $str3|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $$04 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond7 = 0, $or$cond8 = 0, $tmp = 0, $tmp28 = 0, $tmp29 = 0, $tmp30 = 0, $tmp31 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185064);
 $0 = ($str0|0)!=(0|0);
 $$not = $0 ^ 1;
 $1 = ($str1|0)==(0|0);
 $or$cond = $1 & $$not;
 $2 = ($str2|0)==(0|0);
 $or$cond7 = $or$cond & $2;
 $3 = ($str3|0)==(0|0);
 $or$cond8 = $or$cond7 & $3;
 do {
  if ($or$cond8) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = HEAP8[((2191608 + 116|0))>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if ($7) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[((2191608 + 80|0))>>2]|0;
     $19 = HEAP32[$18>>2]|0;
     $$0 = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   if ($0) {
    $$01 = $str0;
   } else {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP8[((2191608 + 116|0))>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[((2191608 + 80|0))>>2]|0;
    $33 = HEAP32[$32>>2]|0;
    $$01 = $33;
   }
   if ($1) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = HEAP8[((2191608 + 116|0))>>0]|0;
    $37 = ($36<<24>>24)==(0);
    if ($37) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    $46 = HEAP32[((2191608 + 80|0))>>2]|0;
    $47 = HEAP32[$46>>2]|0;
    $$02 = $47;
   } else {
    $$02 = $str1;
   }
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    $50 = HEAP8[((2191608 + 116|0))>>0]|0;
    $51 = ($50<<24>>24)==(0);
    if ($51) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     break;
    }
    $60 = HEAP32[((2191608 + 80|0))>>2]|0;
    $61 = HEAP32[$60>>2]|0;
    $$03 = $61;
   } else {
    $$03 = $str2;
   }
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    $64 = HEAP8[((2191608 + 116|0))>>0]|0;
    $65 = ($64<<24>>24)==(0);
    if ($65) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     break;
    }
    $74 = HEAP32[((2191608 + 80|0))>>2]|0;
    $75 = HEAP32[$74>>2]|0;
    $$04 = $75;
   } else {
    $$04 = $str3;
   }
   __THREW__ = 0;
   invoke_vi(3799,($$01|0));
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if (!($77)) {
    $78 = (($$01) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($$02|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if (!($81)) {
     $82 = (($$02) + 8|0);
     $83 = HEAP32[$82>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($$03|0));
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if (!($85)) {
      $86 = (($$03) + 8|0);
      $87 = HEAP32[$86>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($$04|0));
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if (!($89)) {
       $90 = (($83) + ($79))|0;
       $91 = (($90) + ($87))|0;
       $92 = (($$04) + 8|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = (($91) + ($93))|0;
       __THREW__ = 0;
       $95 = (invoke_iii(643,0,($94|0))|0);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        __THREW__ = 0;
        invoke_vi(3799,($$01|0));
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if (!($99)) {
         __THREW__ = 0;
         $100 = (invoke_ii(1816,($$01|0))|0);
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if (!($102)) {
          $103 = ($100|0)==(0);
          if (!($103)) {
           __THREW__ = 0;
           $104 = (invoke_ii(1919,0)|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            break;
           }
           $107 = $95;
           $108 = (($104) + ($107))|0;
           $109 = $108;
           __THREW__ = 0;
           $110 = (invoke_ii(1919,0)|0);
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $113 = __THREW__; __THREW__ = 0;
           $114 = $113&1;
           if ($114) {
            break;
           }
           $115 = $$01;
           $116 = (($110) + ($115))|0;
           $117 = $116;
           $118 = HEAP32[$78>>2]|0;
           __THREW__ = 0;
           invoke_viiii(124,0,($109|0),($117|0),($118|0));
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if ($120) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($$02|0));
          $121 = __THREW__; __THREW__ = 0;
          $122 = $121&1;
          if (!($122)) {
           __THREW__ = 0;
           $123 = (invoke_ii(1816,($$02|0))|0);
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if (!($125)) {
            $126 = ($123|0)==(0);
            if (!($126)) {
             __THREW__ = 0;
             $127 = (invoke_ii(1919,0)|0);
             $128 = __THREW__; __THREW__ = 0;
             $129 = $128&1;
             if ($129) {
              break;
             }
             $130 = $95;
             $131 = (($127) + ($130))|0;
             __THREW__ = 0;
             $132 = (invoke_ii(1919,0)|0);
             $133 = __THREW__; __THREW__ = 0;
             $134 = $133&1;
             if ($134) {
              break;
             }
             $135 = $$02;
             $136 = (($132) + ($135))|0;
             $137 = $136;
             __THREW__ = 0;
             invoke_vi(3799,($$01|0));
             $138 = __THREW__; __THREW__ = 0;
             $139 = $138&1;
             if ($139) {
              break;
             }
             __THREW__ = 0;
             $140 = (invoke_ii(1816,($$01|0))|0);
             $141 = __THREW__; __THREW__ = 0;
             $142 = $141&1;
             if ($142) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($$02|0));
             $143 = __THREW__; __THREW__ = 0;
             $144 = $143&1;
             if ($144) {
              break;
             }
             $145 = $131;
             $146 = $140 << 1;
             $147 = (($145) + ($146)|0);
             $148 = HEAP32[$82>>2]|0;
             __THREW__ = 0;
             invoke_viiii(124,0,($147|0),($137|0),($148|0));
             $149 = __THREW__; __THREW__ = 0;
             $150 = $149&1;
             if ($150) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vi(3799,($$03|0));
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            if (!($152)) {
             __THREW__ = 0;
             $153 = (invoke_ii(1816,($$03|0))|0);
             $154 = __THREW__; __THREW__ = 0;
             $155 = $154&1;
             if (!($155)) {
              $156 = ($153|0)==(0);
              if (!($156)) {
               __THREW__ = 0;
               $157 = (invoke_ii(1919,0)|0);
               $158 = __THREW__; __THREW__ = 0;
               $159 = $158&1;
               if ($159) {
                break;
               }
               $160 = $95;
               $161 = (($157) + ($160))|0;
               __THREW__ = 0;
               $162 = (invoke_ii(1919,0)|0);
               $163 = __THREW__; __THREW__ = 0;
               $164 = $163&1;
               if ($164) {
                break;
               }
               $165 = $$03;
               $166 = (($162) + ($165))|0;
               $167 = $166;
               __THREW__ = 0;
               invoke_vi(3799,($$01|0));
               $168 = __THREW__; __THREW__ = 0;
               $169 = $168&1;
               if ($169) {
                break;
               }
               __THREW__ = 0;
               $170 = (invoke_ii(1816,($$01|0))|0);
               $171 = __THREW__; __THREW__ = 0;
               $172 = $171&1;
               if ($172) {
                break;
               }
               $173 = $161;
               __THREW__ = 0;
               invoke_vi(3799,($$02|0));
               $174 = __THREW__; __THREW__ = 0;
               $175 = $174&1;
               if ($175) {
                break;
               }
               __THREW__ = 0;
               $176 = (invoke_ii(1816,($$02|0))|0);
               $177 = __THREW__; __THREW__ = 0;
               $178 = $177&1;
               if ($178) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($$03|0));
               $179 = __THREW__; __THREW__ = 0;
               $180 = $179&1;
               if ($180) {
                break;
               }
               $tmp = (($176) + ($170))|0;
               $tmp28 = $tmp << 1;
               $181 = (($173) + ($tmp28)|0);
               $182 = HEAP32[$86>>2]|0;
               __THREW__ = 0;
               invoke_viiii(124,0,($181|0),($167|0),($182|0));
               $183 = __THREW__; __THREW__ = 0;
               $184 = $183&1;
               if ($184) {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vi(3799,($$04|0));
              $185 = __THREW__; __THREW__ = 0;
              $186 = $185&1;
              if ($186) {
               break;
              }
              __THREW__ = 0;
              $187 = (invoke_ii(1816,($$04|0))|0);
              $188 = __THREW__; __THREW__ = 0;
              $189 = $188&1;
              if ($189) {
               break;
              }
              $190 = ($187|0)==(0);
              if ($190) {
               $$0 = $95;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
              __THREW__ = 0;
              $191 = (invoke_ii(1919,0)|0);
              $192 = __THREW__; __THREW__ = 0;
              $193 = $192&1;
              if ($193) {
               break;
              }
              $194 = $95;
              $195 = (($191) + ($194))|0;
              __THREW__ = 0;
              $196 = (invoke_ii(1919,0)|0);
              $197 = __THREW__; __THREW__ = 0;
              $198 = $197&1;
              if ($198) {
               break;
              }
              $199 = $$04;
              $200 = (($196) + ($199))|0;
              $201 = $200;
              __THREW__ = 0;
              invoke_vi(3799,($$01|0));
              $202 = __THREW__; __THREW__ = 0;
              $203 = $202&1;
              if ($203) {
               break;
              }
              __THREW__ = 0;
              $204 = (invoke_ii(1816,($$01|0))|0);
              $205 = __THREW__; __THREW__ = 0;
              $206 = $205&1;
              if ($206) {
               break;
              }
              $207 = $195;
              __THREW__ = 0;
              invoke_vi(3799,($$02|0));
              $208 = __THREW__; __THREW__ = 0;
              $209 = $208&1;
              if ($209) {
               break;
              }
              __THREW__ = 0;
              $210 = (invoke_ii(1816,($$02|0))|0);
              $211 = __THREW__; __THREW__ = 0;
              $212 = $211&1;
              if ($212) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($$03|0));
              $213 = __THREW__; __THREW__ = 0;
              $214 = $213&1;
              if ($214) {
               break;
              }
              __THREW__ = 0;
              $215 = (invoke_ii(1816,($$03|0))|0);
              $216 = __THREW__; __THREW__ = 0;
              $217 = $216&1;
              if ($217) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($$04|0));
              $218 = __THREW__; __THREW__ = 0;
              $219 = $218&1;
              if ($219) {
               break;
              }
              $tmp29 = (($210) + ($204))|0;
              $tmp30 = (($tmp29) + ($215))|0;
              $tmp31 = $tmp30 << 1;
              $220 = (($207) + ($tmp31)|0);
              $221 = HEAP32[$92>>2]|0;
              __THREW__ = 0;
              invoke_viiii(124,0,($220|0),($201|0),($221|0));
              $222 = __THREW__; __THREW__ = 0;
              $223 = $222&1;
              if ($223) {
               break;
              } else {
               $$0 = $95;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_String_m_ConcatInternalP22mscorlib_System_ObjectP26mscorlib_System_String_arri($__this,$values,$length) {
 $__this = $__this|0;
 $values = $values|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185208);
 $0 = ($length|0)==(0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = HEAP8[((2191608 + 116|0))>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $5 = __THREW__; __THREW__ = 0;
     $6 = $5&1;
     if ($6) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2191608 + 80|0))>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $$0 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   $19 = (invoke_iii(643,0,($length|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    $22 = (invoke_ii(1919,0)|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = $19;
     $26 = (($22) + ($25))|0;
     $27 = (($values) + 12|0);
     $28 = (($values) + 16|0);
     $29 = $26;
     $V_2$1 = 0;$V_3$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($values|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
      $67 = HEAP32[$27>>2]|0;
      $68 = ($V_3$0|0)<($67|0);
      if (!($68)) {
       $$0 = $19;
       label = 29;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($values|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       break;
      }
      $30 = HEAP32[$27>>2]|0;
      $31 = ($V_3$0>>>0)<($30>>>0);
      if (!($31)) {
       __THREW__ = 0;
       $32 = (invoke_i(132)|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($32|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
      }
      $37 = HEAP32[$values>>2]|0;
      $38 = (($37) + 92|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = Math_imul($39, $V_3$0)|0;
      $41 = (($28) + ($40)|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0|0);
      if ($43) {
       $V_2$0 = $V_2$1;
      } else {
       __THREW__ = 0;
       $44 = (invoke_ii(1919,0)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
       $49 = $V_2$1 << 1;
       $50 = $42;
       $51 = (($29) + ($49)|0);
       $52 = (($44) + ($50))|0;
       $53 = $52;
       $54 = (($42) + 8|0);
       $55 = HEAP32[$54>>2]|0;
       __THREW__ = 0;
       invoke_viiii(124,0,($51|0),($53|0),($55|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
       __THREW__ = 0;
       $60 = (invoke_ii(1816,($42|0))|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       $63 = (($60) + ($V_2$1))|0;
       $V_2$0 = $63;
      }
      $64 = (($V_3$0) + 1)|0;
      $V_2$1 = $V_2$0;$V_3$0 = $64;
     }
     if ((label|0) == 29) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index2 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $lpad$phi$index = $13;$lpad$phi$index2 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_String_arr_arrP22mscorlib_System_ObjectP26mscorlib_System_String_arr($__this,$values) {
 $__this = $__this|0;
 $values = $values|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185160);
 __THREW__ = 0;
 invoke_v(410);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($values|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3007464>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $3 = (($values) + 12|0);
   $4 = (($values) + 16|0);
   $V_0$1 = 0;$V_1$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($values|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 4;
     break;
    }
    $41 = HEAP32[$3>>2]|0;
    $42 = ($V_1$0|0)<($41|0);
    if (!($42)) {
     label = 22;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($values|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     label = 4;
     break;
    }
    $19 = HEAP32[$3>>2]|0;
    $20 = ($V_1$0>>>0)<($19>>>0);
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_i(132)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($21|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 4;
      break;
     }
    }
    $26 = HEAP32[$values>>2]|0;
    $27 = (($26) + 92|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = Math_imul($28, $V_1$0)|0;
    $30 = (($4) + ($29)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    if ($32) {
     $V_0$0 = $V_0$1;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($31|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      label = 4;
      break;
     }
     $35 = (($31) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + ($V_0$1))|0;
     $V_0$0 = $37;
    }
    $38 = (($V_1$0) + 1)|0;
    $V_0$1 = $V_0$0;$V_1$0 = $38;
   }
   if ((label|0) == 4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    $lpad$phi$index = $5;$lpad$phi$index2 = $6;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 22) {
    __THREW__ = 0;
    $45 = (invoke_iiii(563,0,($values|0),($V_0$1|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($45|0);
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z31mscorlib_System_String_m_InsertP22mscorlib_System_StringiS0_($__this,$startIndex,$value) {
 $__this = $__this|0;
 $startIndex = $startIndex|0;
 $value = $value|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185256);
 __THREW__ = 0;
 invoke_v(411);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3007496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($startIndex|0)<(0);
   if (!($15)) {
    $16 = (($__this) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)<($startIndex|0);
    if (!($18)) {
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     $32 = (invoke_ii(1816,($value|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     $35 = ($32|0)==(0);
     if ($35) {
      $$0 = $__this;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $36 = (invoke_ii(1816,($__this|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     $39 = ($36|0)==(0);
     if ($39) {
      $$0 = $value;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $40 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     $43 = (($value) + 8|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + ($40))|0;
     __THREW__ = 0;
     $46 = (invoke_iii(643,0,($45|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     __THREW__ = 0;
     $49 = (invoke_ii(1919,0)|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = $46;
     $53 = (($49) + ($52))|0;
     $54 = $53;
     __THREW__ = 0;
     $55 = (invoke_ii(1919,0)|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     $58 = $__this;
     $59 = (($55) + ($58))|0;
     __THREW__ = 0;
     $60 = (invoke_ii(1919,0)|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      break;
     }
     $63 = $59;
     $64 = $value;
     $65 = (($60) + ($64))|0;
     $66 = $65;
     __THREW__ = 0;
     invoke_viiii(124,0,($54|0),($63|0),($startIndex|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     $69 = $startIndex << 1;
     $70 = $53;
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      break;
     }
     $73 = (($70) + ($69)|0);
     $74 = HEAP32[$43>>2]|0;
     __THREW__ = 0;
     invoke_viiii(124,0,($73|0),($66|0),($74|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      break;
     }
     $79 = HEAP32[$43>>2]|0;
     $80 = $79 << 1;
     $$sum = (($80) + ($69))|0;
     $81 = (($70) + ($$sum)|0);
     $82 = $59;
     $83 = (($82) + ($69)|0);
     $84 = HEAP32[$16>>2]|0;
     $85 = (($84) - ($startIndex))|0;
     __THREW__ = 0;
     invoke_viiii(124,0,($81|0),($83|0),($85|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      break;
     } else {
      $$0 = $46;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2561352|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[3007504>>2]|0;
     $25 = HEAP32[3007512>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($21|0),($24|0),($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      invoke_vi(3830,($21|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_String_m_ParseDecimalP22mscorlib_System_ObjectP22mscorlib_System_StringPi($__this,$str,$ptr) {
 $__this = $__this|0;
 $str = $str|0;
 $ptr = $ptr|0;
 var $$0 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_1$0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185400);
 $0 = HEAP32[$ptr>>2]|0;
 $V_0$0 = $0;$V_1$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($str|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if ($2) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $3 = (invoke_iii(621,($str|0),($V_0$0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   label = 5;
   break;
  }
  $$off = (($3) + -48)<<16>>16;
  $6 = ($$off&65535)<(10);
  if (!($6)) {
   label = 7;
   break;
  }
  $9 = $3&65535;
  $10 = ($V_1$0*10)|0;
  $11 = (($10) + -48)|0;
  $12 = (($11) + ($9))|0;
  $13 = (($V_0$0) + 1)|0;
  $V_0$0 = $13;$V_1$0 = $12;
 }
 if ((label|0) == 5) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 else if ((label|0) == 7) {
  $14 = HEAP32[$ptr>>2]|0;
  $15 = ($V_0$0|0)==($14|0);
  if ($15) {
   $$0 = -1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$ptr>>2] = $V_0$0;
  $$0 = $V_1$0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z40mscorlib_System_String_m_InternalSetCharP22mscorlib_System_Stringit($__this,$idx,$val) {
 $__this = $__this|0;
 $idx = $idx|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185448);
 __THREW__ = 0;
 invoke_v(412);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($idx|0);
   if ($5) {
    $18 = (($__this) + 12|0);
    $19 = (($18) + ($idx<<1)|0);
    HEAP16[$19>>1] = $val;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3007712>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3830,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z42mscorlib_System_String_m_InternalSetLengthP22mscorlib_System_Stringi($__this,$newLength) {
 $__this = $__this|0;
 $newLength = $newLength|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185496);
 __THREW__ = 0;
 invoke_v(413);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)<($newLength|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2561352|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3007736>>2]|0;
    $13 = HEAP32[3007744>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($9|0),($12|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($9|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   } else {
    $18 = (($__this) + 12|0);
    $19 = (($18) + ($3<<1)|0);
    $20 = ($3|0)>($newLength|0);
    if (!($20)) {
     HEAP32[$2>>2] = $newLength;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $21 = (($18) + ($newLength<<1)|0);
    $V_1$01 = $21;
    while(1) {
     HEAP16[$V_1$01>>1] = 0;
     $22 = (($V_1$01) + 2|0);
     $23 = ($22>>>0)<($19>>>0);
     if ($23) {
      $V_1$01 = $22;
     } else {
      break;
     }
    }
    HEAP32[$2>>2] = $newLength;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z36mscorlib_System_String_m_GetHashCodeP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0$lcssa = 0, $V_1$02 = 0, $V_3$0$lcssa = 0, $V_3$01 = 0, $V_3$1 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185544);
 __THREW__ = 0;
 $0 = (invoke_ii(1919,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 }
 $3 = $__this;
 $4 = (($0) + ($3))|0;
 $5 = $4;
 $6 = (($__this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 << 1;
 $9 = $4;
 $10 = (($9) + ($8)|0);
 $11 = $10;
 $12 = (($11) + -2)|0;
 $13 = $12;
 $14 = ($5>>>0)<($13>>>0);
 if ($14) {
  $V_1$02 = $5;$V_3$01 = 0;
  while(1) {
   $17 = ($V_3$01*31)|0;
   $18 = HEAP16[$V_1$02>>1]|0;
   $19 = $18&65535;
   $20 = (($19) + ($17))|0;
   $21 = ($20*31)|0;
   $22 = (($V_1$02) + 2|0);
   $23 = HEAP16[$22>>1]|0;
   $24 = $23&65535;
   $25 = (($21) + ($24))|0;
   $26 = (($V_1$02) + 4|0);
   $27 = ($26>>>0)<($13>>>0);
   if ($27) {
    $V_1$02 = $26;$V_3$01 = $25;
   } else {
    $V_1$0$lcssa = $26;$V_3$0$lcssa = $25;
    break;
   }
  }
 } else {
  $V_1$0$lcssa = $5;$V_3$0$lcssa = 0;
 }
 $28 = $12;
 $29 = (($28) + 2|0);
 $30 = ($V_1$0$lcssa>>>0)<($29>>>0);
 if (!($30)) {
  $V_3$1 = $V_3$0$lcssa;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_3$1|0);
 }
 $31 = ($V_3$0$lcssa*31)|0;
 $32 = HEAP16[$V_1$0$lcssa>>1]|0;
 $33 = $32&65535;
 $34 = (($33) + ($31))|0;
 $V_3$1 = $34;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($V_3$1|0);
}
function __Z51mscorlib_System_String_m_GetCaseInsensitiveHashCodeP22mscorlib_System_String($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0$lcssa = 0, $V_1$04 = 0, $V_3$0$lcssa = 0, $V_3$03 = 0, $V_3$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185592);
 __THREW__ = 0;
 $0 = (invoke_ii(1919,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $__this;
  $4 = (($0) + ($3))|0;
  $5 = $4;
  $6 = (($__this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 << 1;
  $9 = $4;
  $10 = (($9) + ($8)|0);
  $11 = $10;
  $12 = (($11) + -2)|0;
  $13 = $12;
  $14 = ($5>>>0)<($13>>>0);
  L3: do {
   if ($14) {
    $V_1$04 = $5;$V_3$03 = 0;
    while(1) {
     $33 = HEAP16[$V_1$04>>1]|0;
     __THREW__ = 0;
     $25 = (invoke_iii(607,0,($33|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $19 = (($V_1$04) + 2|0);
     $20 = HEAP16[$19>>1]|0;
     __THREW__ = 0;
     $21 = (invoke_iii(607,0,($20|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     $24 = $25&65535;
     $26 = ($V_3$03*31)|0;
     $27 = (($24) + ($26))|0;
     $28 = ($27*31)|0;
     $29 = $21&65535;
     $30 = (($29) + ($28))|0;
     $31 = (($V_1$04) + 4|0);
     $32 = ($31>>>0)<($13>>>0);
     if ($32) {
      $V_1$04 = $31;$V_3$03 = $30;
     } else {
      $V_1$0$lcssa = $31;$V_3$0$lcssa = $30;
      break L3;
     }
    }
    $15 = ___cxa_find_matching_catch()|0;
    $16 = tempRet0;
    $lpad$phi$index = $15;$lpad$phi$index2 = $16;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   } else {
    $V_1$0$lcssa = $5;$V_3$0$lcssa = 0;
   }
  } while(0);
  $36 = $12;
  $37 = (($36) + 2|0);
  $38 = ($V_1$0$lcssa>>>0)<($37>>>0);
  if (!($38)) {
   $V_3$1 = $V_3$0$lcssa;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($V_3$1|0);
  }
  $39 = HEAP16[$V_1$0$lcssa>>1]|0;
  __THREW__ = 0;
  $40 = (invoke_iii(607,0,($39|0))|0);
  $41 = __THREW__; __THREW__ = 0;
  $42 = $41&1;
  if (!($42)) {
   $43 = ($V_3$0$lcssa*31)|0;
   $44 = $40&65535;
   $45 = (($44) + ($43))|0;
   $V_3$1 = $45;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($V_3$1|0);
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $lpad$phi$index = $17;$lpad$phi$index2 = $18;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_SByteU002A_ptrP22mscorlib_System_StringPa($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$05 = 0, $V_1$0$lcssa = 0, $V_1$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185640);
 __THREW__ = 0;
 invoke_v(414);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if (!($2)) {
    $3 = HEAP8[$value>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     $V_1$0$lcssa = 0;
    } else {
     $V_0$05 = $value;$V_1$04 = 0;
     while(1) {
      $21 = (($V_0$05) + 1|0);
      $22 = (($V_1$04) + 1)|0;
      $23 = HEAP8[$21>>0]|0;
      $24 = ($23<<24>>24)==(0);
      if ($24) {
       $V_1$0$lcssa = $22;
       break;
      } else {
       $V_0$05 = $21;$V_1$04 = $22;
      }
     }
    }
    __THREW__ = 0;
    $25 = (invoke_iiiiii(90,0,($value|0),0,($V_1$0$lcssa|0),(0|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    } else {
     $$0 = $25;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP8[((2191608 + 116|0))>>0]|0;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[((2191608 + 80|0))>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     $$0 = $20;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z165mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_SByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Text_EncodingP22mscorlib_System_StringPaiiP29mscorlib_System_Text_Encoding($__this,$value,$startIndex,$length,$enc) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 $enc = $enc|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $$04 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B17_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185736);
 __THREW__ = 0;
 invoke_v(415);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($length|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3007968>>2]|0;
    $11 = HEAP32[3007976>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($7|0),($10|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = ($startIndex|0)>(-1);
   if (!($16)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3007984>>2]|0;
    $23 = HEAP32[3007992>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($19|0),($22|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($19|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   $28 = (($value) + ($startIndex)|0);
   $29 = ($enc|0)==(0|0);
   do {
    if ($29) {
     $30 = ($value|0)==(0|0);
     if ($30) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560584|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break L1;
      }
      __THREW__ = 0;
      $33 = (invoke_ii(3469,(2560584|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L1;
      }
      $36 = HEAP32[3008016>>2]|0;
      __THREW__ = 0;
      invoke_vii(1925,($33|0),($36|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3830,($33|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break L1;
      }
      // unreachable;
     }
     $41 = ($length|0)==(0);
     if (!($41)) {
      __THREW__ = 0;
      $56 = (invoke_ii(2387,(0|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break L1;
      } else {
       $$01 = $56;
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break L1;
     }
     $44 = HEAP8[((2191608 + 116|0))>>0]|0;
     $45 = ($44<<24>>24)==(0);
     if ($45) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2191608|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break L1;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break L1;
     }
     $54 = HEAP32[((2191608 + 80|0))>>2]|0;
     $55 = HEAP32[$54>>2]|0;
     $$0 = $55;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     $$01 = $enc;
    }
   } while(0);
   __THREW__ = 0;
   (invoke_ii(2996,(1203320|0))|0);
   $59 = __THREW__; __THREW__ = 0;
   $60 = $59&1;
   if (!($60)) {
    __THREW__ = 0;
    $61 = (invoke_iii(2754,(1203320|0),($length|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if (!($63)) {
     $64 = ($length|0)==(0);
     if (!($64)) {
      $65 = ($61|0)==(0|0);
      if ($65) {
       $G_B17_0$0 = 0;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($61|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        break;
       }
       $68 = (($61) + 12|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ($69|0)==(0);
       if ($70) {
        $G_B17_0$0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($61|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         break;
        }
        $73 = HEAP32[$68>>2]|0;
        $74 = ($73|0)==(0);
        if ($74) {
         __THREW__ = 0;
         $75 = (invoke_i(132)|0);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($75|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          break;
         }
        }
        $80 = (($61) + 16|0);
        $G_B17_0$0 = $80;
       }
      }
      __THREW__ = 0;
      invoke_viiii(123,0,($G_B17_0$0|0),($28|0),($length|0));
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       $83 = ___cxa_find_matching_catch(348288|0)|0;
       $84 = tempRet0;
       $85 = (_llvm_eh_typeid_for((348288|0))|0);
       $86 = ($84|0)==($85|0);
       if (!($86)) {
        $$02 = $83;$$03 = $84;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$02|0);
        // unreachable;
       }
       $87 = (___cxa_begin_catch(($83|0))|0);
       $88 = HEAP32[$87>>2]|0;
       $89 = HEAP32[$88>>2]|0;
       __THREW__ = 0;
       $90 = (invoke_iii(2727,(2623248|0),($89|0))|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       do {
        if (!($92)) {
         if ($90) {
          $$04 = 18;
         } else {
          $97 = HEAP32[$87>>2]|0;
          $98 = HEAP32[$97>>2]|0;
          __THREW__ = 0;
          $99 = (invoke_iii(2727,(2553648|0),($98|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          if ($99) {
           $$04 = 19;
          } else {
           $102 = (___cxa_allocate_exception(4)|0);
           $103 = HEAP32[$87>>2]|0;
           HEAP32[$102>>2] = $103;
           __THREW__ = 0;
           invoke_viii(1567,($102|0),(348288|0),(0|0));
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            break;
           }
           // unreachable;
          }
         }
         __THREW__ = 0;
         invoke_v(66);
         $106 = __THREW__; __THREW__ = 0;
         $107 = $106&1;
         if ($107) {
          break L1;
         }
         if ((($$04|0) == 19)) {
          if (!($29)) {
           __THREW__ = 0;
           invoke_vi(3830,($88|0));
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if ($120) {
            break L1;
           }
           // unreachable;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2561352|0))|0);
          $121 = __THREW__; __THREW__ = 0;
          $122 = $121&1;
          if ($122) {
           break L1;
          }
          __THREW__ = 0;
          $123 = (invoke_ii(3469,(2561352|0))|0);
          $124 = __THREW__; __THREW__ = 0;
          $125 = $124&1;
          if ($125) {
           break L1;
          }
          $126 = HEAP32[3008040>>2]|0;
          $127 = HEAP32[3008048>>2]|0;
          __THREW__ = 0;
          invoke_viii(644,($123|0),($126|0),($127|0));
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3830,($123|0));
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           break L1;
          }
          // unreachable;
         } else if ((($$04|0) == 18)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2561352|0))|0);
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           break L1;
          }
          __THREW__ = 0;
          $110 = (invoke_ii(3469,(2561352|0))|0);
          $111 = __THREW__; __THREW__ = 0;
          $112 = $111&1;
          if ($112) {
           break L1;
          }
          $113 = HEAP32[3008024>>2]|0;
          $114 = HEAP32[3008032>>2]|0;
          __THREW__ = 0;
          invoke_viii(644,($110|0),($113|0),($114|0));
          $115 = __THREW__; __THREW__ = 0;
          $116 = $115&1;
          if ($116) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3830,($110|0));
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           break L1;
          }
          // unreachable;
         } else {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       } while(0);
       $93 = ___cxa_find_matching_catch()|0;
       $94 = tempRet0;
       __THREW__ = 0;
       invoke_v(66);
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        $137 = ___cxa_find_matching_catch(0|0)|0;
        $138 = tempRet0;
        ___clang_call_terminate($137);
        // unreachable;
       } else {
        $$02 = $93;$$03 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$02|0);
        // unreachable;
       }
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($$01|0));
     $132 = __THREW__; __THREW__ = 0;
     $133 = $132&1;
     if (!($133)) {
      __THREW__ = 0;
      $134 = (invoke_iiii(1645,(2530592|0),($$01|0),($61|0))|0);
      $135 = __THREW__; __THREW__ = 0;
      $136 = $135&1;
      if (!($136)) {
       $$0 = $134;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$02 = $3;$$03 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z135mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_SByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringPaii($__this,$value,$startIndex,$length) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185688);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(90,0,($value|0),($startIndex|0),($length|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z31mscorlib_System_String_m_memcpyP22mscorlib_System_ObjectPhS1_i($__this,$dest,$src,$size) {
 $__this = $__this|0;
 $dest = $dest|0;
 $src = $src|0;
 $size = $size|0;
 var $$0 = 0, $$01 = 0, $$04 = 0, $$1 = 0, $$12 = 0, $$15 = 0, $$2 = 0, $$23 = 0, $$26 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186168);
 $0 = $dest;
 $1 = $src;
 $2 = $1 | $0;
 $3 = $2 & 3;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $$2 = $dest;$$23 = $src;$$26 = $size;
   label = 13;
  } else {
   $5 = $0 & 1;
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = $dest;$$01 = $src;$$04 = $size;
   } else {
    $7 = $1 & 1;
    $8 = ($7|0)==(0);
    $9 = ($size|0)<(1);
    $or$cond = $8 | $9;
    if ($or$cond) {
     $$0 = $dest;$$01 = $src;$$04 = $size;
    } else {
     $10 = HEAP8[$src>>0]|0;
     HEAP8[$dest>>0] = $10;
     $11 = (($dest) + 1|0);
     $12 = (($src) + 1|0);
     $13 = (($size) + -1)|0;
     $$0 = $11;$$01 = $12;$$04 = $13;
    }
   }
   $14 = $$0;
   $15 = $14 & 2;
   $16 = ($15|0)==(0);
   if ($16) {
    $$1 = $$0;$$12 = $$01;$$15 = $$04;
   } else {
    $17 = $$01;
    $18 = $17 & 2;
    $19 = ($18|0)==(0);
    $20 = ($$04|0)<(2);
    $or$cond7 = $19 | $20;
    if ($or$cond7) {
     $$1 = $$0;$$12 = $$01;$$15 = $$04;
    } else {
     $21 = HEAP16[$$01>>1]|0;
     HEAP16[$$0>>1] = $21;
     $22 = (($$0) + 2|0);
     $23 = (($$01) + 2|0);
     $24 = (($$04) + -2)|0;
     $$1 = $22;$$12 = $23;$$15 = $24;
    }
   }
   $25 = $$1;
   $26 = $$12;
   $27 = $25 | $26;
   $28 = $27 & 1;
   $29 = ($28|0)==(0);
   if (!($29)) {
    __THREW__ = 0;
    invoke_viiii(122,0,($$1|0),($$12|0),($$15|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $34 = $27 & 2;
   $35 = ($34|0)==(0);
   if ($35) {
    $$2 = $$1;$$23 = $$12;$$26 = $$15;
    label = 13;
   } else {
    __THREW__ = 0;
    invoke_viiii(121,0,($$1|0),($$12|0),($$15|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  __THREW__ = 0;
  invoke_viiii(120,0,($$2|0),($$23|0),($$26|0));
  $38 = __THREW__; __THREW__ = 0;
  $39 = $38&1;
  if (!($39)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($32|0);
 // unreachable;
}
function __Z90mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_CharU002A_ptrP22mscorlib_System_StringPt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$05 = 0, $V_1$0$lcssa = 0, $V_1$04 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185784);
 $0 = ($value|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2191608 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2191608 + 80|0))>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $$0 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   $1 = HEAP16[$value>>1]|0;
   $2 = ($1<<16>>16)==(0);
   if ($2) {
    $V_1$0$lcssa = 0;
   } else {
    $V_0$05 = $value;$V_1$04 = 0;
    while(1) {
     $19 = (($V_1$04) + 1)|0;
     $20 = (($V_0$05) + 2|0);
     $21 = HEAP16[$20>>1]|0;
     $22 = ($21<<16>>16)==(0);
     if ($22) {
      $V_1$0$lcssa = $19;
      break;
     } else {
      $V_0$05 = $20;$V_1$04 = $19;
     }
    }
   }
   __THREW__ = 0;
   $23 = (invoke_iii(643,0,($V_1$0$lcssa|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = ($V_1$0$lcssa|0)==(0);
    if ($26) {
     $$0 = $23;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1919,0)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = $23;
     $31 = (($27) + ($30))|0;
     $32 = $31;
     __THREW__ = 0;
     invoke_viiii(124,0,($32|0),($value|0),($V_1$0$lcssa|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $$0 = $23;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z134mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringPtii($__this,$value,$startIndex,$length) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185832);
 __THREW__ = 0;
 invoke_v(416);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($length|0)==(0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    $7 = HEAP8[((2191608 + 116|0))>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = HEAP32[((2191608 + 80|0))>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $$0 = $18;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $19 = ($value|0)==(0|0);
   if ($19) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3008248>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($startIndex|0)>(-1);
   if (!($30)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __THREW__ = 0;
    $33 = (invoke_ii(3469,(2561352|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = HEAP32[3008256>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($33|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($33|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    // unreachable;
   }
   $41 = ($length|0)>(-1);
   if ($41) {
    __THREW__ = 0;
    $52 = (invoke_iii(643,0,($length|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    __THREW__ = 0;
    $55 = (invoke_ii(1919,0)|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = $52;
    $59 = (($55) + ($58))|0;
    $60 = $59;
    $61 = (($value) + ($startIndex<<1)|0);
    __THREW__ = 0;
    invoke_viiii(124,0,($60|0),($61|0),($length|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    } else {
     $$0 = $52;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if (!($43)) {
    __THREW__ = 0;
    $44 = (invoke_ii(3469,(2561352|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     $47 = HEAP32[3008264>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($44|0),($47|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if (!($49)) {
      __THREW__ = 0;
      invoke_vi(3830,($44|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if (!($51)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z133mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringP24mscorlib_System_Char_arrii($__this,$val,$startIndex,$length) {
 $__this = $__this|0;
 $val = $val|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $G_B14_0$0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185880);
 __THREW__ = 0;
 invoke_v(417);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($val|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3008280>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($startIndex|0)>(-1);
   if (!($15)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3008288>>2]|0;
    $22 = HEAP32[3008296>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($18|0),($21|0),($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($18|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    // unreachable;
   }
   $27 = ($length|0)>(-1);
   if (!($27)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    $30 = (invoke_ii(3469,(2561352|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    $33 = HEAP32[3008304>>2]|0;
    $34 = HEAP32[3008312>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($30|0),($33|0),($34|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($30|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($val|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if (!($40)) {
    $41 = (($val) + 12|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) - ($length))|0;
    $44 = ($43|0)<($startIndex|0);
    if ($44) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3008320>>2]|0;
     $51 = HEAP32[3008328>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($51|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($47|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     // unreachable;
    }
    $56 = ($length|0)==(0);
    if ($56) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     $59 = HEAP8[((2191608 + 116|0))>>0]|0;
     $60 = ($59<<24>>24)==(0);
     if ($60) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2191608|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     $69 = HEAP32[((2191608 + 80|0))>>2]|0;
     $70 = HEAP32[$69>>2]|0;
     $$0 = $70;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $71 = (invoke_iii(643,0,($length|0))|0);
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if (!($73)) {
     __THREW__ = 0;
     $74 = (invoke_ii(1919,0)|0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if (!($76)) {
      $77 = $71;
      $78 = (($74) + ($77))|0;
      $79 = $78;
      __THREW__ = 0;
      invoke_vi(3799,($val|0));
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if (!($81)) {
       $82 = HEAP32[$41>>2]|0;
       $83 = ($82|0)==(0);
       if ($83) {
        $G_B14_0$0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($val|0));
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         break;
        }
        $86 = HEAP32[$41>>2]|0;
        $87 = ($86|0)==(0);
        if ($87) {
         __THREW__ = 0;
         $88 = (invoke_i(132)|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($88|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break;
         }
        }
        $93 = (($val) + 16|0);
        $G_B14_0$0 = $93;
       }
       $94 = $startIndex << 1;
       $95 = (($G_B14_0$0) + ($94)|0);
       __THREW__ = 0;
       invoke_viiii(124,0,($79|0),($95|0),($length|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B8_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2185928);
 $0 = ($val|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = HEAP8[((2191608 + 116|0))>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $5 = __THREW__; __THREW__ = 0;
     $6 = $5&1;
     if ($6) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[((2191608 + 80|0))>>2]|0;
     $16 = HEAP32[$15>>2]|0;
     $$0 = $16;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($val|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = (($val) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0);
    if ($21) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     $24 = HEAP8[((2191608 + 116|0))>>0]|0;
     $25 = ($24<<24>>24)==(0);
     if ($25) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2191608|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $34 = HEAP32[((2191608 + 80|0))>>2]|0;
     $35 = HEAP32[$34>>2]|0;
     $$0 = $35;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($val|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     $38 = HEAP32[$19>>2]|0;
     __THREW__ = 0;
     $39 = (invoke_iii(643,0,($38|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if (!($41)) {
      __THREW__ = 0;
      $42 = (invoke_ii(1919,0)|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       $45 = $39;
       $46 = (($42) + ($45))|0;
       $47 = $46;
       __THREW__ = 0;
       invoke_vi(3799,($val|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        $50 = HEAP32[$19>>2]|0;
        $51 = ($50|0)==(0);
        if ($51) {
         $G_B8_0$0 = 0;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($val|0));
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break;
         }
         $54 = HEAP32[$19>>2]|0;
         $55 = ($54|0)==(0);
         if ($55) {
          __THREW__ = 0;
          $56 = (invoke_i(132)|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if ($58) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($56|0));
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           break;
          }
         }
         $61 = (($val) + 16|0);
         $G_B8_0$0 = $61;
        }
        __THREW__ = 0;
        invoke_vi(3799,($val|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if (!($63)) {
         $64 = HEAP32[$19>>2]|0;
         __THREW__ = 0;
         invoke_viiii(124,0,($47|0),($G_B8_0$0|0),($64|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if (!($66)) {
          $$0 = $39;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_String_m_memcpy4P22mscorlib_System_ObjectPhS1_i($__this,$dest,$src,$size) {
 $__this = $__this|0;
 $dest = $dest|0;
 $src = $src|0;
 $size = $size|0;
 var $$0$lcssa = 0, $$01$lcssa = 0, $$0118 = 0, $$019 = 0, $$04$lcssa = 0, $$0417 = 0, $$1$lcssa = 0, $$113 = 0, $$12$lcssa = 0, $$1212 = 0, $$15$lcssa = 0, $$1511 = 0, $$238 = 0, $$267 = 0, $$29 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $scevgep = 0, $scevgep27 = 0, $scevgep30 = 0, $scevgep31 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186024);
 $0 = ($size|0)>(15);
 if ($0) {
  $1 = (($size) + -16)|0;
  $2 = $1 & -16;
  $3 = (($2) + 16)|0;
  $scevgep30 = (($src) + ($3)|0);
  $$0118 = $src;$$019 = $dest;$$0417 = $size;
  while(1) {
   $9 = HEAP32[$$0118>>2]|0;
   HEAP32[$$019>>2] = $9;
   $10 = (($$019) + 4|0);
   $11 = (($$0118) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$10>>2] = $12;
   $13 = (($$019) + 8|0);
   $14 = (($$0118) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   HEAP32[$13>>2] = $15;
   $16 = (($$019) + 12|0);
   $17 = (($$0118) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   HEAP32[$16>>2] = $18;
   $19 = (($$019) + 16|0);
   $20 = (($$0118) + 16|0);
   $21 = (($$0417) + -16)|0;
   $22 = ($21|0)>(15);
   if ($22) {
    $$0118 = $20;$$019 = $19;$$0417 = $21;
   } else {
    break;
   }
  }
  $4 = (($1) - ($2))|0;
  $scevgep31 = (($dest) + ($3)|0);
  $$0$lcssa = $scevgep31;$$01$lcssa = $scevgep30;$$04$lcssa = $4;
 } else {
  $$0$lcssa = $dest;$$01$lcssa = $src;$$04$lcssa = $size;
 }
 $5 = ($$04$lcssa|0)>(3);
 if ($5) {
  $6 = (($$04$lcssa) + -4)|0;
  $7 = $6 & -4;
  $8 = (($7) + 4)|0;
  $scevgep = (($$01$lcssa) + ($8)|0);
  $$113 = $$0$lcssa;$$1212 = $$01$lcssa;$$1511 = $$04$lcssa;
  while(1) {
   $25 = HEAP32[$$1212>>2]|0;
   HEAP32[$$113>>2] = $25;
   $26 = (($$113) + 4|0);
   $27 = (($$1212) + 4|0);
   $28 = (($$1511) + -4)|0;
   $29 = ($28|0)>(3);
   if ($29) {
    $$113 = $26;$$1212 = $27;$$1511 = $28;
   } else {
    break;
   }
  }
  $23 = (($6) - ($7))|0;
  $scevgep27 = (($$0$lcssa) + ($8)|0);
  $$1$lcssa = $scevgep27;$$12$lcssa = $scevgep;$$15$lcssa = $23;
 } else {
  $$1$lcssa = $$0$lcssa;$$12$lcssa = $$01$lcssa;$$15$lcssa = $$04$lcssa;
 }
 $24 = ($$15$lcssa|0)>(0);
 if ($24) {
  $$238 = $$12$lcssa;$$267 = $$15$lcssa;$$29 = $$1$lcssa;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 while(1) {
  $30 = HEAP8[$$238>>0]|0;
  HEAP8[$$29>>0] = $30;
  $31 = (($$29) + 1|0);
  $32 = (($$238) + 1|0);
  $33 = (($$267) + -1)|0;
  $34 = ($33|0)>(0);
  if ($34) {
   $$238 = $32;$$267 = $33;$$29 = $31;
  } else {
   break;
  }
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z32mscorlib_System_String_m_memcpy2P22mscorlib_System_ObjectPhS1_i($__this,$dest,$src,$size) {
 $__this = $__this|0;
 $dest = $dest|0;
 $src = $src|0;
 $size = $size|0;
 var $$0$lcssa = 0, $$01$lcssa = 0, $$0111 = 0, $$012 = 0, $$03$lcssa = 0, $$0310 = 0, $$1$lcssa = 0, $$12$lcssa = 0, $$126 = 0, $$14$lcssa = 0, $$145 = 0, $$17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $scevgep = 0, $scevgep20 = 0, $scevgep23 = 0, $scevgep24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186072);
 $0 = ($size|0)>(7);
 if ($0) {
  $1 = (($size) + -8)|0;
  $2 = $1 & -8;
  $3 = (($2) + 8)|0;
  $scevgep23 = (($src) + ($3)|0);
  $$0111 = $src;$$012 = $dest;$$0310 = $size;
  while(1) {
   $9 = HEAP16[$$0111>>1]|0;
   HEAP16[$$012>>1] = $9;
   $10 = (($$012) + 2|0);
   $11 = (($$0111) + 2|0);
   $12 = HEAP16[$11>>1]|0;
   HEAP16[$10>>1] = $12;
   $13 = (($$012) + 4|0);
   $14 = (($$0111) + 4|0);
   $15 = HEAP16[$14>>1]|0;
   HEAP16[$13>>1] = $15;
   $16 = (($$012) + 6|0);
   $17 = (($$0111) + 6|0);
   $18 = HEAP16[$17>>1]|0;
   HEAP16[$16>>1] = $18;
   $19 = (($$012) + 8|0);
   $20 = (($$0111) + 8|0);
   $21 = (($$0310) + -8)|0;
   $22 = ($21|0)>(7);
   if ($22) {
    $$0111 = $20;$$012 = $19;$$0310 = $21;
   } else {
    break;
   }
  }
  $4 = (($1) - ($2))|0;
  $scevgep24 = (($dest) + ($3)|0);
  $$0$lcssa = $scevgep24;$$01$lcssa = $scevgep23;$$03$lcssa = $4;
 } else {
  $$0$lcssa = $dest;$$01$lcssa = $src;$$03$lcssa = $size;
 }
 $5 = ($$03$lcssa|0)>(1);
 if ($5) {
  $6 = (($$03$lcssa) + -2)|0;
  $7 = $6 & -2;
  $8 = (($7) + 2)|0;
  $scevgep = (($$01$lcssa) + ($8)|0);
  $$126 = $$01$lcssa;$$145 = $$03$lcssa;$$17 = $$0$lcssa;
  while(1) {
   $23 = HEAP16[$$126>>1]|0;
   HEAP16[$$17>>1] = $23;
   $24 = (($$17) + 2|0);
   $25 = (($$126) + 2|0);
   $26 = (($$145) + -2)|0;
   $27 = ($26|0)>(1);
   if ($27) {
    $$126 = $25;$$145 = $26;$$17 = $24;
   } else {
    break;
   }
  }
  $28 = (($6) - ($7))|0;
  $scevgep20 = (($$0$lcssa) + ($8)|0);
  $$1$lcssa = $scevgep20;$$12$lcssa = $scevgep;$$14$lcssa = $28;
 } else {
  $$1$lcssa = $$0$lcssa;$$12$lcssa = $$01$lcssa;$$14$lcssa = $$03$lcssa;
 }
 $29 = ($$14$lcssa|0)<(1);
 if ($29) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $30 = HEAP8[$$12$lcssa>>0]|0;
 HEAP8[$$1$lcssa>>0] = $30;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z32mscorlib_System_String_m_memcpy1P22mscorlib_System_ObjectPhS1_i($__this,$dest,$src,$size) {
 $__this = $__this|0;
 $dest = $dest|0;
 $src = $src|0;
 $size = $size|0;
 var $$0$lcssa = 0, $$01$lcssa = 0, $$0111 = 0, $$012 = 0, $$03$lcssa = 0, $$0310 = 0, $$1$lcssa = 0, $$12$lcssa = 0, $$126 = 0, $$14$lcssa = 0, $$145 = 0, $$17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $scevgep = 0;
 var $scevgep20 = 0, $scevgep23 = 0, $scevgep24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186120);
 $0 = ($size|0)>(7);
 if ($0) {
  $1 = (($size) + -8)|0;
  $2 = $1 & -8;
  $3 = (($2) + 8)|0;
  $scevgep23 = (($src) + ($3)|0);
  $$0111 = $src;$$012 = $dest;$$0310 = $size;
  while(1) {
   $9 = HEAP8[$$0111>>0]|0;
   HEAP8[$$012>>0] = $9;
   $10 = (($$012) + 1|0);
   $11 = (($$0111) + 1|0);
   $12 = HEAP8[$11>>0]|0;
   HEAP8[$10>>0] = $12;
   $13 = (($$012) + 2|0);
   $14 = (($$0111) + 2|0);
   $15 = HEAP8[$14>>0]|0;
   HEAP8[$13>>0] = $15;
   $16 = (($$012) + 3|0);
   $17 = (($$0111) + 3|0);
   $18 = HEAP8[$17>>0]|0;
   HEAP8[$16>>0] = $18;
   $19 = (($$012) + 4|0);
   $20 = (($$0111) + 4|0);
   $21 = HEAP8[$20>>0]|0;
   HEAP8[$19>>0] = $21;
   $22 = (($$012) + 5|0);
   $23 = (($$0111) + 5|0);
   $24 = HEAP8[$23>>0]|0;
   HEAP8[$22>>0] = $24;
   $25 = (($$012) + 6|0);
   $26 = (($$0111) + 6|0);
   $27 = HEAP8[$26>>0]|0;
   HEAP8[$25>>0] = $27;
   $28 = (($$012) + 7|0);
   $29 = (($$0111) + 7|0);
   $30 = HEAP8[$29>>0]|0;
   HEAP8[$28>>0] = $30;
   $31 = (($$012) + 8|0);
   $32 = (($$0111) + 8|0);
   $33 = (($$0310) + -8)|0;
   $34 = ($33|0)>(7);
   if ($34) {
    $$0111 = $32;$$012 = $31;$$0310 = $33;
   } else {
    break;
   }
  }
  $4 = (($1) - ($2))|0;
  $scevgep24 = (($dest) + ($3)|0);
  $$0$lcssa = $scevgep24;$$01$lcssa = $scevgep23;$$03$lcssa = $4;
 } else {
  $$0$lcssa = $dest;$$01$lcssa = $src;$$03$lcssa = $size;
 }
 $5 = ($$03$lcssa|0)>(1);
 if ($5) {
  $6 = (($$03$lcssa) + -2)|0;
  $7 = $6 & -2;
  $8 = (($7) + 2)|0;
  $scevgep = (($$01$lcssa) + ($8)|0);
  $$126 = $$01$lcssa;$$145 = $$03$lcssa;$$17 = $$0$lcssa;
  while(1) {
   $35 = HEAP8[$$126>>0]|0;
   HEAP8[$$17>>0] = $35;
   $36 = (($$17) + 1|0);
   $37 = (($$126) + 1|0);
   $38 = HEAP8[$37>>0]|0;
   HEAP8[$36>>0] = $38;
   $39 = (($$17) + 2|0);
   $40 = (($$126) + 2|0);
   $41 = (($$145) + -2)|0;
   $42 = ($41|0)>(1);
   if ($42) {
    $$126 = $40;$$145 = $41;$$17 = $39;
   } else {
    break;
   }
  }
  $43 = (($6) - ($7))|0;
  $scevgep20 = (($$0$lcssa) + ($8)|0);
  $$1$lcssa = $scevgep20;$$12$lcssa = $scevgep;$$14$lcssa = $43;
 } else {
  $$1$lcssa = $$0$lcssa;$$12$lcssa = $$01$lcssa;$$14$lcssa = $$03$lcssa;
 }
 $44 = ($$14$lcssa|0)<(1);
 if ($44) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $45 = HEAP8[$$12$lcssa>>0]|0;
 HEAP8[$$1$lcssa>>0] = $45;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z143mscorlib_System_String_m_CharCopyReverse_mscorlib_System_Void_mscorlib_System_CharU002A_ptr_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P22mscorlib_System_ObjectPtS1_i($__this,$dest,$src,$count) {
 $__this = $__this|0;
 $dest = $dest|0;
 $src = $src|0;
 $count = $count|0;
 var $$013 = 0, $$04 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186264);
 $0 = ($count|0)>(0);
 if (!($0)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $1 = (($src) + ($count<<1)|0);
 $2 = (($dest) + ($count<<1)|0);
 $$013 = $1;$$04 = $2;$V_0$02 = $count;
 while(1) {
  $3 = $$04;
  $4 = (($3) + -2)|0;
  $5 = $4;
  $6 = $$013;
  $7 = (($6) + -2)|0;
  $8 = $7;
  $9 = HEAP16[$8>>1]|0;
  HEAP16[$5>>1] = $9;
  $10 = (($V_0$02) + -1)|0;
  $11 = ($10|0)>(0);
  if ($11) {
   $$013 = $8;$$04 = $5;$V_0$02 = $10;
  } else {
   break;
  }
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z166mscorlib_System_String_m_CharCopy_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP22mscorlib_System_StringiS2_ii($__this,$target,$targetIndex,$source,$sourceIndex,$count) {
 $__this = $__this|0;
 $target = $target|0;
 $targetIndex = $targetIndex|0;
 $source = $source|0;
 $sourceIndex = $sourceIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186312);
 __THREW__ = 0;
 $0 = (invoke_ii(1919,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(1919,0)|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $target;
   $7 = (($0) + ($6))|0;
   $8 = $source;
   $9 = (($3) + ($8))|0;
   $10 = $targetIndex << 1;
   $11 = $7;
   $12 = (($11) + ($10)|0);
   $13 = $sourceIndex << 1;
   $14 = $9;
   $15 = (($14) + ($13)|0);
   __THREW__ = 0;
   invoke_viiii(124,0,($12|0),($15|0),($count|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z173mscorlib_System_String_m_CharCopyReverse_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP22mscorlib_System_StringiS2_ii($__this,$target,$targetIndex,$source,$sourceIndex,$count) {
 $__this = $__this|0;
 $target = $target|0;
 $targetIndex = $targetIndex|0;
 $source = $source|0;
 $sourceIndex = $sourceIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186360);
 __THREW__ = 0;
 $0 = (invoke_ii(1919,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(1919,0)|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $target;
   $7 = (($0) + ($6))|0;
   $8 = $source;
   $9 = (($3) + ($8))|0;
   $10 = $targetIndex << 1;
   $11 = $7;
   $12 = (($11) + ($10)|0);
   $13 = $sourceIndex << 1;
   $14 = $9;
   $15 = (($14) + ($13)|0);
   __THREW__ = 0;
   invoke_viiii(125,0,($12|0),($15|0),($count|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z108mscorlib_System_String_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2186696);
 __THREW__ = 0;
 $0 = (invoke_iiii(522,0,($a|0),($b|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = $0 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker2I26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvtiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$4);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEPFtPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFPvS3_iiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEPFPvS3_S3_iES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEPFiPviiiES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$4,$7)|0);
 HEAP32[$ret>>2] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32TraitsS0_S0_S0_17VoidPointerTraitsE6InvokeEPFiPviiiS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$1,$4,$7,$9)|0);
 HEAP32[$ret>>2] = $10;
 $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_S4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS4_S4_bS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$6,$8)|0);
 HEAP32[$ret>>2] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_S0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS4_iS4_iibS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)!=(0);
 $16 = (($args) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$3,$5,$8,$11,$15,$17)|0);
 HEAP32[$ret>>2] = $18;
 $19 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($19|0);
}
function __ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_S0_E6InvokeEPFiPvS3_iS3_iiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$5,$8,$11)|0);
 HEAP32[$ret>>2] = $12;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_E6InvokeEPFiPvS3_iiS3_iiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$6,$8,$11,$14)|0);
 HEAP32[$ret>>2] = $15;
 $16 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($16|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_E6InvokeEPFiPvS3_iiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsS0_E6InvokeEPFiPvtiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsS0_S0_E6InvokeEPFiPvtiiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$4,$7)|0);
 HEAP32[$ret>>2] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsE6InvokeEPFPvS4_itES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits26mscorlib_System_CharTraitsS1_E6InvokeEPFPvS3_ttES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_S0_27mscorlib_System_Int32TraitsE6InvokeEPFPvS3_S3_S3_iES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS1_E6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectS5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS1_S1_E6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectS5_S5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_S0_S0_E6InvokeEPFPvS2_S2_S2_S2_ES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_S0_S0_E6InvokeEPFPvS2_S2_S2_S2_S2_ES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_S1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS5_S5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN14ActionInvoker6I17VoidPointerTraitsS0_S0_S0_S0_S0_E6InvokeEPFvPvS2_S2_S2_S2_S2_S2_ES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viiiiiii[$action & 127]($obj,$0,$2,$4,$6,$8,$10);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsE6InvokeEPFvPvitES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$4);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_E6InvokeEPFPvS3_S3_iiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_S0_E6InvokeEPFPvS3_S3_iiS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$3,$6,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEPFPvS4_tiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN14ActionInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvS3_S3_iES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$5);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_S1_E6InvokeEPFvPvS3_iS3_iiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$3,$5,$8,$11);
 STACKTOP = sp;return (0|0);
}
function __Z53mscorlib_System_String_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2190872)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($__this,$memberName) {
 $__this = $__this|0;
 $memberName = $memberName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2252112);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $memberName;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z179mscorlib_System_String_CustomAttributesCacheGenerator_mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_String_CustomAttributesCacheGenerator_mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_String_CustomAttributesCacheGenerator_mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_StringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_String_CustomAttributesCacheGenerator_mscorlib_System_String_m_GetHashCodeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z57mscorlib_System_ICloneable_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_Single_m_System_IConvertible_ToBooleanPfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192272);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(12,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Single_m_System_IConvertible_ToBytePfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192320);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(13,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Single_m_System_IConvertible_ToCharPfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192368);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(14,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_Single_m_System_IConvertible_ToDateTimePfP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192416);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 invoke_viif(21,($agg$result|0),(0|0),(+$0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_Single_m_System_IConvertible_ToDecimalPfP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192464);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 invoke_viif(22,($agg$result|0),(0|0),(+$0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_Single_m_System_IConvertible_ToDoublePfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192512);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (+invoke_dif(1,(0|0),(+$0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$1);
 }
 return +0;
}
function __Z52mscorlib_System_Single_m_System_IConvertible_ToInt16PfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192560);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(15,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Single_m_System_IConvertible_ToInt32PfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192608);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(16,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Single_m_System_IConvertible_ToInt64PfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192656);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(17,(0|0),(+$0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Single_m_System_IConvertible_ToSBytePfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192704);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(18,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Single_m_System_IConvertible_ToSinglePfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192752);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fif(3,(0|0),(+$0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($1));
 }
 return Math_fround(0);
}
function __Z51mscorlib_System_Single_m_System_IConvertible_ToTypePfP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192800);
 __THREW__ = 0;
 invoke_v(418);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = Math_fround(HEAPF32[$__this>>2]);
    HEAPF32[$L_2>>2] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2194912|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2194912|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3008488>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_Single_m_System_IConvertible_ToUInt16PfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192848);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(19,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Single_m_System_IConvertible_ToUInt32PfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192896);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(20,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Single_m_System_IConvertible_ToUInt64PfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192944);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(21,(0|0),(+$0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_Single_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPfP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2192992);
 __THREW__ = 0;
 invoke_v(419);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2194912|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2194912|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3008504>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2194912|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2194912|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = Math_fround(HEAPF32[$26>>2]);
       $30 = Math_fround(HEAPF32[$__this>>2]);
       __THREW__ = 0;
       $31 = (invoke_iif(11,0,(+$30))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        if ($31) {
         __THREW__ = 0;
         $34 = (invoke_iif(11,0,(+$29))|0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          break;
         }
         if ($34) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        $37 = Math_fround(HEAPF32[$__this>>2]);
        __THREW__ = 0;
        $38 = (invoke_iif(10,0,(+$37))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         if ($38) {
          __THREW__ = 0;
          $41 = (invoke_iif(10,0,(+$29))|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          if ($41) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         __THREW__ = 0;
         $44 = (invoke_iif(9,0,(+$29))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if (!($46)) {
          $47 = Math_fround(HEAPF32[$__this>>2]);
          if ($44) {
           __THREW__ = 0;
           $48 = (invoke_iif(9,0,(+$47))|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            break;
           }
           $51 = $48&1;
           $$ = $51 ^ 1;
           $$0 = $$;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $52 = (invoke_iif(9,0,(+$47))|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           if ($52) {
            __THREW__ = 0;
            $55 = (invoke_iif(9,0,(+$29))|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             break;
            }
            $not$ = $55 ^ 1;
            $$1 = $not$ << 31 >> 31;
            $$0 = $$1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           $58 = Math_fround(HEAPF32[$__this>>2]);
           $59 = $58 != $29;
           if (!($59)) {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           $60 = !($58 <= $29);
           $$2 = $60 ? 1 : -1;
           $$0 = $$2;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Single_m_IsPositiveInfinityP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0, $1 = 0, $2 = 0, $G_B6_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193376);
 $0 = !($f <= Math_fround(0.0));
 if ($0) {
  $1 = $f == Math_fround(-inf);
  if ($1) {
   $G_B6_0$0 = 1;
  } else {
   $2 = $f == Math_fround(inf);
   $G_B6_0$0 = $2;
  }
 } else {
  $G_B6_0$0 = 0;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B6_0$0|0);
}
function __Z43mscorlib_System_Single_m_IsNegativeInfinityP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0, $1 = 0, $2 = 0, $G_B6_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193328);
 $0 = !($f >= Math_fround(0.0));
 if ($0) {
  $1 = $f == Math_fround(-inf);
  if ($1) {
   $G_B6_0$0 = 1;
  } else {
   $2 = $f == Math_fround(inf);
   $G_B6_0$0 = $2;
  }
 } else {
  $G_B6_0$0 = 0;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B6_0$0|0);
}
function __Z30mscorlib_System_Single_m_IsNaNP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193280);
 $0 = ($f != $f) | (Math_fround(0.0) != Math_fround(0.0));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z78mscorlib_System_Single_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPfP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193040);
 __THREW__ = 0;
 (invoke_ii(2996,(2194912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($obj|0),(2194912|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2194912|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2753,($obj|0),(2194912|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = Math_fround(HEAPF32[$10>>2]);
      __THREW__ = 0;
      $14 = (invoke_iif(9,0,(+$13))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = Math_fround(HEAPF32[$__this>>2]);
       if ($14) {
        __THREW__ = 0;
        $18 = (invoke_iif(9,0,(+$17))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         break;
        } else {
         $$0 = $18;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       } else {
        $21 = $13 == $17;
        $$0 = $21;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Single_m_CompareTo_mscorlib_System_Int32_mscorlib_System_SinglePff($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, $not$ = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193088);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iif(11,0,(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if (!($3)) {
   if ($1) {
    __THREW__ = 0;
    $6 = (invoke_iif(11,0,(+$value))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    if ($6) {
     $$0 = 0;
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
   do {
    if ((label|0) == 6) {
     $9 = Math_fround(HEAPF32[$__this>>2]);
     __THREW__ = 0;
     $10 = (invoke_iif(10,0,(+$9))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break L1;
     }
     if ($10) {
      __THREW__ = 0;
      $13 = (invoke_iif(10,0,(+$value))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break L1;
      }
      if ($13) {
       $$0 = 0;
       break;
      }
     }
     __THREW__ = 0;
     $16 = (invoke_iif(9,0,(+$value))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break L1;
     }
     $19 = Math_fround(HEAPF32[$__this>>2]);
     if ($16) {
      __THREW__ = 0;
      $20 = (invoke_iif(9,0,(+$19))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break L1;
      }
      $23 = $20&1;
      $$ = $23 ^ 1;
      $$0 = $$;
      break;
     }
     __THREW__ = 0;
     $24 = (invoke_iif(9,0,(+$19))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break L1;
     }
     if ($24) {
      __THREW__ = 0;
      $27 = (invoke_iif(9,0,(+$value))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break L1;
      }
      $not$ = $27 ^ 1;
      $$1 = $not$ << 31 >> 31;
      $$0 = $$1;
      break;
     } else {
      $30 = Math_fround(HEAPF32[$__this>>2]);
      $31 = $30 != $value;
      if (!($31)) {
       $$0 = 0;
       break;
      }
      $32 = !($30 <= $value);
      $$2 = $32 ? 1 : -1;
      $$0 = $$2;
      break;
     }
    }
   } while(0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Single_m_Equals_mscorlib_System_Boolean_mscorlib_System_SinglePff($__this,$obj) {
 $__this = $__this|0;
 $obj = Math_fround($obj);
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193136);
 __THREW__ = 0;
 $0 = (invoke_iif(9,0,(+$obj))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = Math_fround(HEAPF32[$__this>>2]);
   if ($0) {
    __THREW__ = 0;
    $6 = (invoke_iif(9,0,(+$3))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    } else {
     $$0 = $6;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    $9 = $3 == $obj;
    $$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_Single_m_GetHashCodePf($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193184);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 $1 = (HEAPF32[tempDoublePtr>>2]=$0,HEAP32[tempDoublePtr>>2]|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z35mscorlib_System_Single_m_IsInfinityP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0, $1 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193232);
 $0 = $f == Math_fround(inf);
 if ($0) {
  $G_B3_0$0 = 1;
 } else {
  $1 = $f == Math_fround(-inf);
  $G_B3_0$0 = $1;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B3_0$0|0);
}
function __Z76mscorlib_System_Single_m_Parse_mscorlib_System_Single_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193424);
 __THREW__ = 0;
 $0 = (+invoke_diiii(1,0,($s|0),231,(0|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $0 + -3.40282346638528859812E+38;
  $4 = !($3 <= 3.61471124579617763624E+29);
  if (!($4)) {
   $19 = Math_fround($0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($19));
  }
  __THREW__ = 0;
  $7 = (invoke_iid(6,0,(+$0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   if ($7) {
    $19 = Math_fround($0);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return (Math_fround($19));
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(2635888|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(2770,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3830,($12|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z151mscorlib_System_Double_m_Parse_mscorlib_System_Double_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$s,$style,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $V_0 = sp + 8|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196248);
 HEAP32[$V_0>>2] = 0;
 HEAPF64[$V_1>>3] = 0.0;
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(71,0,($s|0),($style|0),($provider|0),0,($V_1|0),($V_0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 }
 if ($0) {
  $8 = +HEAPF64[$V_1>>3];
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$8);
 }
 $5 = HEAP32[$V_0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3830,($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  // unreachable;
 }
 return +0;
}
function __Z43mscorlib_System_Double_m_IsPositiveInfinityP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $1 = 0, $2 = 0, $G_B6_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196152);
 $0 = !($d <= 0.0);
 if ($0) {
  $1 = $d == -inf;
  if ($1) {
   $G_B6_0$0 = 1;
  } else {
   $2 = $d == inf;
   $G_B6_0$0 = $2;
  }
 } else {
  $G_B6_0$0 = 0;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B6_0$0|0);
}
function __Z108mscorlib_System_Single_m_Parse_mscorlib_System_Single_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193472);
 __THREW__ = 0;
 $0 = (+invoke_diiii(1,0,($s|0),231,($provider|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $0 + -3.40282346638528859812E+38;
  $4 = !($3 <= 3.61471124579617763624E+29);
  if (!($4)) {
   $19 = Math_fround($0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($19));
  }
  __THREW__ = 0;
  $7 = (invoke_iid(6,0,(+$0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   if ($7) {
    $19 = Math_fround($0);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return (Math_fround($19));
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(2635888|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(2770,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3830,($12|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z56mscorlib_System_Single_m_ToString_mscorlib_System_StringPf($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193520);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iifi(4,(0|0),(+$0),(0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_Single_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPfP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193568);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iifi(4,(0|0),(+$0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_Single_m_ToString_mscorlib_System_String_mscorlib_System_StringPfP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193616);
 __THREW__ = 0;
 $0 = (invoke_iiii(580,($__this|0),($format|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z111mscorlib_System_Single_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPfP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2193664);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __THREW__ = 0;
 $1 = (invoke_iiifi(1,(0|0),($format|0),(+$0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsE6InvokeEPFiPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_SingleTraitsE6InvokeEPFbPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_SingleTraits17VoidPointerTraitsS1_E6InvokeEPFfPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$0,$2)));
 HEAPF32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z53mscorlib_System_Single_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Single_CustomAttributesCacheGenerator_mscorlib_System_Single_m_IsNaNP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z51mscorlib_System_Double_m_System_IConvertible_ToTypePdP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195048);
 __THREW__ = 0;
 invoke_v(420);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = +HEAPF64[$__this>>3];
    HEAPF64[$L_2>>3] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2198192|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2724,(2198192|0),($L_2|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iiiiii(126,(0|0),($18|0),($targetType|0),($provider|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3008584>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Double_m_System_IConvertible_ToBooleanPdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195096);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(9,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Double_m_System_IConvertible_ToBytePdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195144);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(10,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Double_m_System_IConvertible_ToCharPdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195192);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Double_m_System_IConvertible_ToDateTimePdP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195240);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z54mscorlib_System_Double_m_System_IConvertible_ToDecimalPdP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195288);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 invoke_viid(2,($agg$result|0),(0|0),(+$0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53mscorlib_System_Double_m_System_IConvertible_ToDoublePdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195336);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (+invoke_did(1,(0|0),(+$0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$1);
 }
 return +0;
}
function __Z52mscorlib_System_Double_m_System_IConvertible_ToInt16PdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195384);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(11,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Double_m_System_IConvertible_ToInt32PdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195432);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(12,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Double_m_System_IConvertible_ToInt64PdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195480);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(13,(0|0),(+$0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Double_m_System_IConvertible_ToSBytePdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195528);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(14,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Double_m_System_IConvertible_ToSinglePdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195576);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fid(1,(0|0),(+$0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($1));
 }
 return Math_fround(0);
}
function __Z53mscorlib_System_Double_m_System_IConvertible_ToUInt16PdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195624);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(15,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Double_m_System_IConvertible_ToUInt32PdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195672);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(16,(0|0),(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Double_m_System_IConvertible_ToUInt64PdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195720);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(17,(0|0),(+$0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $2;
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_Double_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPdP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195768);
 __THREW__ = 0;
 invoke_v(421);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2198192|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2198192|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3008600>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2198192|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2198192|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = +HEAPF64[$26>>3];
       $30 = +HEAPF64[$__this>>3];
       __THREW__ = 0;
       $31 = (invoke_iid(6,0,(+$30))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        if ($31) {
         __THREW__ = 0;
         $34 = (invoke_iid(6,0,(+$29))|0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          break;
         }
         if ($34) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        $37 = +HEAPF64[$__this>>3];
        __THREW__ = 0;
        $38 = (invoke_iid(5,0,(+$37))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         if ($38) {
          __THREW__ = 0;
          $41 = (invoke_iid(5,0,(+$29))|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          if ($41) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         __THREW__ = 0;
         $44 = (invoke_iid(4,0,(+$29))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if (!($46)) {
          $47 = +HEAPF64[$__this>>3];
          if ($44) {
           __THREW__ = 0;
           $48 = (invoke_iid(4,0,(+$47))|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            break;
           }
           $51 = $48&1;
           $$ = $51 ^ 1;
           $$0 = $$;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $52 = (invoke_iid(4,0,(+$47))|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           if ($52) {
            __THREW__ = 0;
            $55 = (invoke_iid(4,0,(+$29))|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             break;
            }
            $not$ = $55 ^ 1;
            $$1 = $not$ << 31 >> 31;
            $$0 = $$1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           $58 = +HEAPF64[$__this>>3];
           $59 = !($58 <= $29);
           if ($59) {
            $$0 = 1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           $60 = !($58 >= $29);
           $$2 = $60 << 31 >> 31;
           $$0 = $$2;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Double_m_IsNegativeInfinityP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $1 = 0, $2 = 0, $G_B6_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196104);
 $0 = !($d >= 0.0);
 if ($0) {
  $1 = $d == -inf;
  if ($1) {
   $G_B6_0$0 = 1;
  } else {
   $2 = $d == inf;
   $G_B6_0$0 = $2;
  }
 } else {
  $G_B6_0$0 = 0;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B6_0$0|0);
}
function __Z30mscorlib_System_Double_m_IsNaNP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196056);
 $0 = ($d != $d) | (0.0 != 0.0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z78mscorlib_System_Double_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPdP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195816);
 __THREW__ = 0;
 (invoke_ii(2996,(2198192|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($obj|0),(2198192|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2198192|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2753,($obj|0),(2198192|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = +HEAPF64[$10>>3];
      __THREW__ = 0;
      $14 = (invoke_iid(4,0,(+$13))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = +HEAPF64[$__this>>3];
       if ($14) {
        __THREW__ = 0;
        $18 = (invoke_iid(4,0,(+$17))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         break;
        } else {
         $$0 = $18;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       } else {
        $21 = $13 == $17;
        $$0 = $21;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Double_m_CompareTo_mscorlib_System_Int32_mscorlib_System_DoublePdd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $_stackTraceSentry = 0, $not$ = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195864);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iid(6,0,(+$0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if (!($3)) {
   if ($1) {
    __THREW__ = 0;
    $6 = (invoke_iid(6,0,(+$value))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    if ($6) {
     $$0 = 0;
    } else {
     label = 6;
    }
   } else {
    label = 6;
   }
   do {
    if ((label|0) == 6) {
     $9 = +HEAPF64[$__this>>3];
     __THREW__ = 0;
     $10 = (invoke_iid(5,0,(+$9))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break L1;
     }
     if ($10) {
      __THREW__ = 0;
      $13 = (invoke_iid(5,0,(+$value))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break L1;
      }
      if ($13) {
       $$0 = 0;
       break;
      }
     }
     __THREW__ = 0;
     $16 = (invoke_iid(4,0,(+$value))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break L1;
     }
     $19 = +HEAPF64[$__this>>3];
     if ($16) {
      __THREW__ = 0;
      $20 = (invoke_iid(4,0,(+$19))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break L1;
      }
      $23 = $20&1;
      $$ = $23 ^ 1;
      $$0 = $$;
      break;
     }
     __THREW__ = 0;
     $24 = (invoke_iid(4,0,(+$19))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break L1;
     }
     if ($24) {
      __THREW__ = 0;
      $27 = (invoke_iid(4,0,(+$value))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break L1;
      }
      $not$ = $27 ^ 1;
      $$1 = $not$ << 31 >> 31;
      $$0 = $$1;
      break;
     } else {
      $30 = +HEAPF64[$__this>>3];
      $31 = !($30 <= $value);
      if ($31) {
       $$0 = 1;
       break;
      }
      $32 = !($30 >= $value);
      $$2 = $32 << 31 >> 31;
      $$0 = $$2;
      break;
     }
    }
   } while(0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Double_m_Equals_mscorlib_System_Boolean_mscorlib_System_DoublePdd($__this,$obj) {
 $__this = $__this|0;
 $obj = +$obj;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195912);
 __THREW__ = 0;
 $0 = (invoke_iid(4,0,(+$obj))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = +HEAPF64[$__this>>3];
   if ($0) {
    __THREW__ = 0;
    $6 = (invoke_iid(4,0,(+$3))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    } else {
     $$0 = $6;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    $9 = $3 == $obj;
    $$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_Double_m_GetHashCodePd($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2195960);
 __THREW__ = 0;
 $0 = (invoke_ii(1794,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z35mscorlib_System_Double_m_IsInfinityP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $1 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196008);
 $0 = $d == inf;
 if ($0) {
  $G_B3_0$0 = 1;
 } else {
  $1 = $d == -inf;
  $G_B3_0$0 = $1;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B3_0$0|0);
}
function __Z108mscorlib_System_Double_m_Parse_mscorlib_System_Double_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$s,$provider) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196200);
 __THREW__ = 0;
 $0 = (+invoke_diiii(1,0,($s|0),231,($provider|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$0);
 }
 return +0;
}
function __Z243mscorlib_System_Double_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_DoubleU0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPdPP25mscorlib_System_Exception($__this,$s,$style,$provider,$tryParse,$result,$exc) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 $tryParse = $tryParse|0;
 $result = $result|0;
 $exc = $exc|0;
 var $$0 = 0, $$lobit = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0.0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0.0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_153 = 0, $L_168 = 0, $L_180 = 0, $L_213 = 0, $L_225 = 0, $V_10$1 = 0, $V_10$4 = 0, $V_10$551 = 0;
 var $V_11$0 = 0, $V_12$0 = 0, $V_13$0 = 0, $V_14$0 = 0, $V_15$0 = 0, $V_16$0 = 0, $V_20 = 0, $V_3$1 = 0, $V_3$256 = 0, $V_3$3 = 0, $V_4$0$lcssa = 0, $V_4$068 = 0, $V_4$1 = 0, $V_4$3 = 0, $V_4$452 = 0, $V_8$0 = 0, $V_8$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 8|0;
 $V_20 = sp;
 $L_153 = sp + 20|0;
 $L_168 = sp + 12|0;
 $L_180 = sp + 14|0;
 $L_213 = sp + 16|0;
 $L_225 = sp + 18|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196296);
 HEAPF64[$V_20>>3] = 0.0;
 __THREW__ = 0;
 invoke_v(422);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   HEAPF64[$result>>3] = 0.0;
   HEAP32[$exc>>2] = 0;
   $2 = ($s|0)==(0|0);
   if ($2) {
    if ($tryParse) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2560584|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[3008672>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($13|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    HEAP32[$exc>>2] = $13;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_ii(1816,($s|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = ($21|0)==(0);
     if ($24) {
      if ($tryParse) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2603176|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_ii(3469,(2603176|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(2723,($27|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      HEAP32[$exc>>2] = $27;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $32 = $style & 512;
     $33 = ($32|0)==(0);
     if (!($33)) {
      __THREW__ = 0;
      (invoke_ii(2996,(1167664|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2754,(1167664|0),1)|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($36|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      $41 = (($36) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(0);
      if ($43) {
       __THREW__ = 0;
       $44 = (invoke_i(132)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($44|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
      }
      $49 = HEAP32[3008688>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($36|0),($49|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
      $52 = HEAP32[3008688>>2]|0;
      $53 = (($36) + 16|0);
      HEAP32[$53>>2] = $52;
      $54 = HEAP32[3008680>>2]|0;
      __THREW__ = 0;
      $55 = (invoke_iiii(728,0,($54|0),($36|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      __THREW__ = 0;
      $60 = (invoke_ii(3469,(2560072|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($60|0),($55|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($60|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
      // unreachable;
     }
     $67 = ($style|0)<(512);
     if (!($67)) {
      if ($tryParse) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_ii(3469,(2560072|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(2583,($70|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       break;
      }
      HEAP32[$exc>>2] = $70;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $75 = (invoke_iii(867,(0|0),($provider|0))|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if (!($77)) {
      $78 = ($75|0)==(0|0);
      if ($78) {
       __THREW__ = 0;
       (invoke_ii(2996,(2246120|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        break;
       }
       __THREW__ = 0;
       $81 = (invoke_ii(3469,(2246120|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       $84 = HEAP32[3008696>>2]|0;
       __THREW__ = 0;
       invoke_vii(1781,($81|0),($84|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3830,($81|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        break;
       }
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      if (!($90)) {
       __THREW__ = 0;
       $91 = (invoke_ii(1816,($s|0))|0);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if (!($93)) {
        $94 = $style & 1;
        $95 = ($94|0)==(0);
        $$lobit = $style & 2;
        $96 = ($$lobit|0)!=(0);
        if ($95) {
         $V_4$1 = 0;
        } else {
         $97 = ($91|0)>(0);
         L63: do {
          if ($97) {
           $V_4$068 = 0;
           while(1) {
            __THREW__ = 0;
            invoke_vi(3799,($s|0));
            $100 = __THREW__; __THREW__ = 0;
            $101 = $100&1;
            if ($101) {
             break;
            }
            __THREW__ = 0;
            $102 = (invoke_iii(621,($s|0),($V_4$068|0))|0);
            $103 = __THREW__; __THREW__ = 0;
            $104 = $103&1;
            if ($104) {
             break;
            }
            __THREW__ = 0;
            $105 = (invoke_iii(604,0,($102|0))|0);
            $106 = __THREW__; __THREW__ = 0;
            $107 = $106&1;
            if ($107) {
             break;
            }
            $99 = (($V_4$068) + 1)|0;
            if (!($105)) {
             $V_4$0$lcssa = $V_4$068;
             break L63;
            }
            $98 = ($99|0)<($91|0);
            if ($98) {
             $V_4$068 = $99;
            } else {
             $V_4$0$lcssa = $99;
             break L63;
            }
           }
           $7 = ___cxa_find_matching_catch()|0;
           $8 = tempRet0;
           $lpad$phi$index = $7;$lpad$phi$index4 = $8;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          } else {
           $V_4$0$lcssa = 0;
          }
         } while(0);
         $108 = ($V_4$0$lcssa|0)==($91|0);
         if ($108) {
          if ($tryParse) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $109 = (invoke_ii(1790,0)|0);
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           break;
          }
          HEAP32[$exc>>2] = $109;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         } else {
          $V_4$1 = $V_4$0$lcssa;
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($s|0));
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if (!($113)) {
         __THREW__ = 0;
         $114 = (invoke_ii(1816,($s|0))|0);
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if (!($116)) {
          $117 = (($114) + -1)|0;
          L82: do {
           if ($96) {
            $V_8$0 = $117;
            while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($s|0));
             $118 = __THREW__; __THREW__ = 0;
             $119 = $118&1;
             if ($119) {
              break;
             }
             __THREW__ = 0;
             $120 = (invoke_iii(621,($s|0),($V_8$0|0))|0);
             $121 = __THREW__; __THREW__ = 0;
             $122 = $121&1;
             if ($122) {
              break;
             }
             __THREW__ = 0;
             $123 = (invoke_iii(604,0,($120|0))|0);
             $124 = __THREW__; __THREW__ = 0;
             $125 = $124&1;
             if ($125) {
              break;
             }
             $126 = (($V_8$0) + -1)|0;
             if ($123) {
              $V_8$0 = $126;
             } else {
              $V_8$1 = $V_8$0;
              break L82;
             }
            }
            $5 = ___cxa_find_matching_catch()|0;
            $6 = tempRet0;
            $lpad$phi$index = $5;$lpad$phi$index4 = $6;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           } else {
            $V_8$1 = $117;
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3799,($75|0));
          $127 = __THREW__; __THREW__ = 0;
          $128 = $127&1;
          if (!($128)) {
           __THREW__ = 0;
           $129 = (invoke_ii(2027,($75|0))|0);
           $130 = __THREW__; __THREW__ = 0;
           $131 = $130&1;
           if (!($131)) {
            __THREW__ = 0;
            $132 = (invoke_iiiiii(91,0,($129|0),($s|0),($V_4$1|0),($V_8$1|0))|0);
            $133 = __THREW__; __THREW__ = 0;
            $134 = $133&1;
            if (!($134)) {
             if ($132) {
              HEAPF64[$result>>3] = nan;
              $$0 = 1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             invoke_vi(3799,($75|0));
             $135 = __THREW__; __THREW__ = 0;
             $136 = $135&1;
             if ($136) {
              break;
             }
             __THREW__ = 0;
             $137 = (invoke_ii(2043,($75|0))|0);
             $138 = __THREW__; __THREW__ = 0;
             $139 = $138&1;
             if ($139) {
              break;
             }
             __THREW__ = 0;
             $140 = (invoke_iiiiii(91,0,($137|0),($s|0),($V_4$1|0),($V_8$1|0))|0);
             $141 = __THREW__; __THREW__ = 0;
             $142 = $141&1;
             if ($142) {
              break;
             }
             if ($140) {
              HEAPF64[$result>>3] = inf;
              $$0 = 1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             invoke_vi(3799,($75|0));
             $143 = __THREW__; __THREW__ = 0;
             $144 = $143&1;
             if ($144) {
              break;
             }
             __THREW__ = 0;
             $145 = (invoke_ii(2028,($75|0))|0);
             $146 = __THREW__; __THREW__ = 0;
             $147 = $146&1;
             if ($147) {
              break;
             }
             __THREW__ = 0;
             $148 = (invoke_iiiiii(91,0,($145|0),($s|0),($V_4$1|0),($V_8$1|0))|0);
             $149 = __THREW__; __THREW__ = 0;
             $150 = $149&1;
             if ($150) {
              break;
             }
             if ($148) {
              HEAPF64[$result>>3] = -inf;
              $$0 = 1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             (invoke_ii(2996,(1203320|0))|0);
             $151 = __THREW__; __THREW__ = 0;
             $152 = $151&1;
             if ($152) {
              break;
             }
             $153 = (($91) + 1)|0;
             __THREW__ = 0;
             $154 = (invoke_iii(2754,(1203320|0),($153|0))|0);
             $155 = __THREW__; __THREW__ = 0;
             $156 = $155&1;
             if ($156) {
              break;
             }
             $157 = $style & 32;
             $158 = ($157|0)==(0);
             if ($158) {
              $V_11$0 = 0;$V_14$0 = 0;
             } else {
              __THREW__ = 0;
              invoke_vi(3799,($75|0));
              $159 = __THREW__; __THREW__ = 0;
              $160 = $159&1;
              if ($160) {
               break;
              }
              __THREW__ = 0;
              $161 = (invoke_ii(2031,($75|0))|0);
              $162 = __THREW__; __THREW__ = 0;
              $163 = $162&1;
              if ($163) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($161|0));
              $164 = __THREW__; __THREW__ = 0;
              $165 = $164&1;
              if ($165) {
               break;
              }
              __THREW__ = 0;
              $166 = (invoke_ii(1816,($161|0))|0);
              $167 = __THREW__; __THREW__ = 0;
              $168 = $167&1;
              if ($168) {
               break;
              } else {
               $V_11$0 = $161;$V_14$0 = $166;
              }
             }
             $169 = $style & 64;
             $170 = ($169|0)==(0);
             if ($170) {
              $V_12$0 = 0;$V_15$0 = 0;
             } else {
              __THREW__ = 0;
              invoke_vi(3799,($75|0));
              $171 = __THREW__; __THREW__ = 0;
              $172 = $171&1;
              if ($172) {
               break;
              }
              __THREW__ = 0;
              $173 = (invoke_ii(2032,($75|0))|0);
              $174 = __THREW__; __THREW__ = 0;
              $175 = $174&1;
              if ($175) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($173|0));
              $176 = __THREW__; __THREW__ = 0;
              $177 = $176&1;
              if ($177) {
               break;
              }
              __THREW__ = 0;
              $178 = (invoke_ii(1816,($173|0))|0);
              $179 = __THREW__; __THREW__ = 0;
              $180 = $179&1;
              if ($180) {
               break;
              } else {
               $V_12$0 = $173;$V_15$0 = $178;
              }
             }
             $181 = $style & 256;
             $182 = ($181|0)==(0);
             if ($182) {
              $V_13$0 = 0;$V_16$0 = 0;
             } else {
              __THREW__ = 0;
              invoke_vi(3799,($75|0));
              $183 = __THREW__; __THREW__ = 0;
              $184 = $183&1;
              if ($184) {
               break;
              }
              __THREW__ = 0;
              $185 = (invoke_ii(2024,($75|0))|0);
              $186 = __THREW__; __THREW__ = 0;
              $187 = $186&1;
              if ($187) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($185|0));
              $188 = __THREW__; __THREW__ = 0;
              $189 = $188&1;
              if ($189) {
               break;
              }
              __THREW__ = 0;
              $190 = (invoke_ii(1816,($185|0))|0);
              $191 = __THREW__; __THREW__ = 0;
              $192 = $191&1;
              if ($192) {
               break;
              } else {
               $V_13$0 = $185;$V_16$0 = $190;
              }
             }
             __THREW__ = 0;
             invoke_vi(3799,($75|0));
             $193 = __THREW__; __THREW__ = 0;
             $194 = $193&1;
             if ($194) {
              break;
             }
             __THREW__ = 0;
             $195 = (invoke_ii(2044,($75|0))|0);
             $196 = __THREW__; __THREW__ = 0;
             $197 = $196&1;
             if ($197) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($75|0));
             $198 = __THREW__; __THREW__ = 0;
             $199 = $198&1;
             if ($199) {
              break;
             }
             __THREW__ = 0;
             $200 = (invoke_ii(2029,($75|0))|0);
             $201 = __THREW__; __THREW__ = 0;
             $202 = $201&1;
             if ($202) {
              break;
             }
             $203 = ($V_4$1|0)<($91|0);
             L136: do {
              if ($203) {
               $204 = $style & 4;
               $205 = ($204|0)==(0);
               $206 = (($154) + 16|0);
               $207 = (($154) + 12|0);
               $208 = ($V_14$0|0)<(1);
               $209 = ($V_15$0|0)<(1);
               $210 = ($V_16$0|0)<(1);
               $211 = (($V_16$0) + -1)|0;
               $212 = (($V_15$0) + -1)|0;
               $213 = (($V_14$0) + -1)|0;
               $214 = $style & 128;
               $215 = ($214|0)==(0);
               $V_10$551 = 1;$V_3$256 = 0;$V_4$452 = $V_4$1;
               L139: while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($s|0));
                $598 = __THREW__; __THREW__ = 0;
                $599 = $598&1;
                if ($599) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                $216 = (invoke_iii(621,($s|0),($V_4$452|0))|0);
                $217 = __THREW__; __THREW__ = 0;
                $218 = $217&1;
                if ($218) {
                 label = 3;
                 break;
                }
                $219 = ($216<<16>>16)==(0);
                L143: do {
                 if ($219) {
                  $V_10$4 = $V_10$551;$V_3$1 = $V_3$256;$V_4$3 = $91;
                 } else {
                  L145: do {
                   switch ($V_10$551|0) {
                   case 1:  {
                    if ($205) {
                     label = 140;
                     break L145;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($195|0));
                    $220 = __THREW__; __THREW__ = 0;
                    $221 = $220&1;
                    if ($221) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    $222 = (invoke_iii(621,($195|0),0)|0);
                    $223 = __THREW__; __THREW__ = 0;
                    $224 = $223&1;
                    if ($224) {
                     label = 3;
                     break L139;
                    }
                    $225 = ($216<<16>>16)==($222<<16>>16);
                    do {
                     if ($225) {
                      __THREW__ = 0;
                      invoke_vi(3799,($195|0));
                      $226 = __THREW__; __THREW__ = 0;
                      $227 = $226&1;
                      if ($227) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $228 = (invoke_ii(1816,($195|0))|0);
                      $229 = __THREW__; __THREW__ = 0;
                      $230 = $229&1;
                      if ($230) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($s|0));
                      $231 = __THREW__; __THREW__ = 0;
                      $232 = $231&1;
                      if ($232) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $233 = (invoke_iiii(528,($s|0),($V_4$452|0),($228|0))|0);
                      $234 = __THREW__; __THREW__ = 0;
                      $235 = $234&1;
                      if ($235) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $236 = (invoke_iiii(574,0,($233|0),($195|0))|0);
                      $237 = __THREW__; __THREW__ = 0;
                      $238 = $237&1;
                      if ($238) {
                       label = 3;
                       break L139;
                      }
                      if (!($236)) {
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($195|0));
                      $239 = __THREW__; __THREW__ = 0;
                      $240 = $239&1;
                      if ($240) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $241 = (invoke_ii(1816,($195|0))|0);
                      $242 = __THREW__; __THREW__ = 0;
                      $243 = $242&1;
                      if ($243) {
                       label = 3;
                       break L139;
                      }
                      $244 = (($V_4$452) + -1)|0;
                      $245 = (($244) + ($241))|0;
                      $V_10$4 = 2;$V_3$1 = $V_3$256;$V_4$3 = $245;
                      break L143;
                     }
                    } while(0);
                    __THREW__ = 0;
                    invoke_vi(3799,($200|0));
                    $246 = __THREW__; __THREW__ = 0;
                    $247 = $246&1;
                    if ($247) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    $248 = (invoke_iii(621,($200|0),0)|0);
                    $249 = __THREW__; __THREW__ = 0;
                    $250 = $249&1;
                    if ($250) {
                     label = 3;
                     break L139;
                    }
                    $251 = ($216<<16>>16)==($248<<16>>16);
                    if (!($251)) {
                     label = 140;
                     break L145;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($200|0));
                    $252 = __THREW__; __THREW__ = 0;
                    $253 = $252&1;
                    if ($253) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    $254 = (invoke_ii(1816,($200|0))|0);
                    $255 = __THREW__; __THREW__ = 0;
                    $256 = $255&1;
                    if ($256) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($s|0));
                    $257 = __THREW__; __THREW__ = 0;
                    $258 = $257&1;
                    if ($258) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    $259 = (invoke_iiii(528,($s|0),($V_4$452|0),($254|0))|0);
                    $260 = __THREW__; __THREW__ = 0;
                    $261 = $260&1;
                    if ($261) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    $262 = (invoke_iiii(574,0,($259|0),($200|0))|0);
                    $263 = __THREW__; __THREW__ = 0;
                    $264 = $263&1;
                    if ($264) {
                     label = 3;
                     break L139;
                    }
                    if (!($262)) {
                     label = 140;
                     break L145;
                    }
                    $265 = (($V_3$256) + 1)|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($154|0));
                    $266 = __THREW__; __THREW__ = 0;
                    $267 = $266&1;
                    if ($267) {
                     label = 3;
                     break L139;
                    }
                    $268 = ($V_3$256|0)<(0);
                    if ($268) {
                     label = 135;
                    } else {
                     $269 = HEAP32[$207>>2]|0;
                     $270 = ($V_3$256>>>0)<($269>>>0);
                     if (!($270)) {
                      label = 135;
                     }
                    }
                    if ((label|0) == 135) {
                     label = 0;
                     __THREW__ = 0;
                     $271 = (invoke_i(132)|0);
                     $272 = __THREW__; __THREW__ = 0;
                     $273 = $272&1;
                     if ($273) {
                      label = 3;
                      break L139;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($271|0));
                     $274 = __THREW__; __THREW__ = 0;
                     $275 = $274&1;
                     if ($275) {
                      label = 3;
                      break L139;
                     }
                    }
                    $276 = HEAP32[$154>>2]|0;
                    $277 = (($276) + 92|0);
                    $278 = HEAP32[$277>>2]|0;
                    $279 = Math_imul($278, $V_3$256)|0;
                    $280 = (($206) + ($279)|0);
                    HEAP8[$280>>0] = 45;
                    __THREW__ = 0;
                    invoke_vi(3799,($200|0));
                    $281 = __THREW__; __THREW__ = 0;
                    $282 = $281&1;
                    if ($282) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    $283 = (invoke_ii(1816,($200|0))|0);
                    $284 = __THREW__; __THREW__ = 0;
                    $285 = $284&1;
                    if ($285) {
                     label = 3;
                     break L139;
                    }
                    $286 = (($V_4$452) + -1)|0;
                    $287 = (($286) + ($283))|0;
                    $V_10$4 = 2;$V_3$1 = $265;$V_4$3 = $287;
                    break L143;
                    break;
                   }
                   case 2:  {
                    label = 140;
                    break;
                   }
                   case 3:  {
                    $V_10$1 = 3;
                    label = 189;
                    break;
                   }
                   case 4:  {
                    __THREW__ = 0;
                    $456 = (invoke_iii(600,0,($216|0))|0);
                    $457 = __THREW__; __THREW__ = 0;
                    $458 = $457&1;
                    if ($458) {
                     label = 3;
                     break L139;
                    }
                    if ($456) {
                     label = 264;
                     break L145;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($195|0));
                    $459 = __THREW__; __THREW__ = 0;
                    $460 = $459&1;
                    if ($460) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    $461 = (invoke_iii(621,($195|0),0)|0);
                    $462 = __THREW__; __THREW__ = 0;
                    $463 = $462&1;
                    if ($463) {
                     label = 3;
                     break L139;
                    }
                    $464 = ($216<<16>>16)==($461<<16>>16);
                    do {
                     if ($464) {
                      __THREW__ = 0;
                      invoke_vi(3799,($195|0));
                      $465 = __THREW__; __THREW__ = 0;
                      $466 = $465&1;
                      if ($466) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $467 = (invoke_ii(1816,($195|0))|0);
                      $468 = __THREW__; __THREW__ = 0;
                      $469 = $468&1;
                      if ($469) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($s|0));
                      $470 = __THREW__; __THREW__ = 0;
                      $471 = $470&1;
                      if ($471) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $472 = (invoke_iiii(528,($s|0),($V_4$452|0),($467|0))|0);
                      $473 = __THREW__; __THREW__ = 0;
                      $474 = $473&1;
                      if ($474) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $475 = (invoke_iiii(574,0,($472|0),($195|0))|0);
                      $476 = __THREW__; __THREW__ = 0;
                      $477 = $476&1;
                      if ($477) {
                       label = 3;
                       break L139;
                      }
                      if (!($475)) {
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($195|0));
                      $478 = __THREW__; __THREW__ = 0;
                      $479 = $478&1;
                      if ($479) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $480 = (invoke_ii(1816,($195|0))|0);
                      $481 = __THREW__; __THREW__ = 0;
                      $482 = $481&1;
                      if ($482) {
                       label = 3;
                       break L139;
                      }
                      $483 = (($V_4$452) + -1)|0;
                      $484 = (($483) + ($480))|0;
                      $V_10$4 = 2;$V_3$1 = $V_3$256;$V_4$3 = $484;
                      break L143;
                     }
                    } while(0);
                    __THREW__ = 0;
                    invoke_vi(3799,($200|0));
                    $485 = __THREW__; __THREW__ = 0;
                    $486 = $485&1;
                    if ($486) {
                     label = 3;
                     break L139;
                    }
                    __THREW__ = 0;
                    $487 = (invoke_iii(621,($200|0),0)|0);
                    $488 = __THREW__; __THREW__ = 0;
                    $489 = $488&1;
                    if ($489) {
                     label = 3;
                     break L139;
                    }
                    $490 = ($216<<16>>16)==($487<<16>>16);
                    do {
                     if ($490) {
                      __THREW__ = 0;
                      invoke_vi(3799,($200|0));
                      $491 = __THREW__; __THREW__ = 0;
                      $492 = $491&1;
                      if ($492) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $493 = (invoke_ii(1816,($200|0))|0);
                      $494 = __THREW__; __THREW__ = 0;
                      $495 = $494&1;
                      if ($495) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($s|0));
                      $496 = __THREW__; __THREW__ = 0;
                      $497 = $496&1;
                      if ($497) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $498 = (invoke_iiii(528,($s|0),($V_4$452|0),($493|0))|0);
                      $499 = __THREW__; __THREW__ = 0;
                      $500 = $499&1;
                      if ($500) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $501 = (invoke_iiii(574,0,($498|0),($200|0))|0);
                      $502 = __THREW__; __THREW__ = 0;
                      $503 = $502&1;
                      if ($503) {
                       label = 3;
                       break L139;
                      }
                      if (!($501)) {
                       break;
                      }
                      $504 = (($V_3$256) + 1)|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($154|0));
                      $505 = __THREW__; __THREW__ = 0;
                      $506 = $505&1;
                      if ($506) {
                       label = 3;
                       break L139;
                      }
                      $507 = ($V_3$256|0)<(0);
                      if ($507) {
                       label = 249;
                      } else {
                       $508 = HEAP32[$207>>2]|0;
                       $509 = ($V_3$256>>>0)<($508>>>0);
                       if (!($509)) {
                        label = 249;
                       }
                      }
                      if ((label|0) == 249) {
                       label = 0;
                       __THREW__ = 0;
                       $510 = (invoke_i(132)|0);
                       $511 = __THREW__; __THREW__ = 0;
                       $512 = $511&1;
                       if ($512) {
                        label = 3;
                        break L139;
                       }
                       __THREW__ = 0;
                       invoke_vi(3302,($510|0));
                       $513 = __THREW__; __THREW__ = 0;
                       $514 = $513&1;
                       if ($514) {
                        label = 3;
                        break L139;
                       }
                      }
                      $515 = HEAP32[$154>>2]|0;
                      $516 = (($515) + 92|0);
                      $517 = HEAP32[$516>>2]|0;
                      $518 = Math_imul($517, $V_3$256)|0;
                      $519 = (($206) + ($518)|0);
                      HEAP8[$519>>0] = 45;
                      __THREW__ = 0;
                      invoke_vi(3799,($200|0));
                      $520 = __THREW__; __THREW__ = 0;
                      $521 = $520&1;
                      if ($521) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $522 = (invoke_ii(1816,($200|0))|0);
                      $523 = __THREW__; __THREW__ = 0;
                      $524 = $523&1;
                      if ($524) {
                       label = 3;
                       break L139;
                      }
                      $525 = (($V_4$452) + -1)|0;
                      $526 = (($525) + ($522))|0;
                      $V_10$4 = 2;$V_3$1 = $504;$V_4$3 = $526;
                      break L143;
                     }
                    } while(0);
                    __THREW__ = 0;
                    $527 = (invoke_iii(604,0,($216|0))|0);
                    $528 = __THREW__; __THREW__ = 0;
                    $529 = $528&1;
                    if ($529) {
                     label = 3;
                     break L139;
                    }
                    if (!($527)) {
                     label = 256;
                     break L139;
                    }
                    break;
                   }
                   case 5:  {
                    label = 264;
                    break;
                   }
                   case 6:  {
                    break;
                   }
                   case 7:  {
                    $$pre$phiZ2D = $154;$V_3$3 = $V_3$256;
                    break L136;
                    break;
                   }
                   default: {
                    $V_10$4 = $V_10$551;$V_3$1 = $V_3$256;$V_4$3 = $V_4$452;
                    break L143;
                   }
                   }
                  } while(0);
                  do {
                   if ((label|0) == 140) {
                    label = 0;
                    __THREW__ = 0;
                    $288 = (invoke_iii(600,0,($216|0))|0);
                    $289 = __THREW__; __THREW__ = 0;
                    $290 = $289&1;
                    if ($290) {
                     label = 3;
                     break L139;
                    }
                    if ($288) {
                     $291 = (($V_3$256) + 1)|0;
                     $292 = $216&255;
                     __THREW__ = 0;
                     invoke_vi(3799,($154|0));
                     $293 = __THREW__; __THREW__ = 0;
                     $294 = $293&1;
                     if ($294) {
                      label = 3;
                      break L139;
                     }
                     $295 = ($V_3$256|0)<(0);
                     if ($295) {
                      label = 145;
                     } else {
                      $296 = HEAP32[$207>>2]|0;
                      $297 = ($V_3$256>>>0)<($296>>>0);
                      if (!($297)) {
                       label = 145;
                      }
                     }
                     if ((label|0) == 145) {
                      label = 0;
                      __THREW__ = 0;
                      $298 = (invoke_i(132)|0);
                      $299 = __THREW__; __THREW__ = 0;
                      $300 = $299&1;
                      if ($300) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      invoke_vi(3302,($298|0));
                      $301 = __THREW__; __THREW__ = 0;
                      $302 = $301&1;
                      if ($302) {
                       label = 3;
                       break L139;
                      }
                     }
                     $303 = HEAP32[$154>>2]|0;
                     $304 = (($303) + 92|0);
                     $305 = HEAP32[$304>>2]|0;
                     $306 = Math_imul($305, $V_3$256)|0;
                     $307 = (($206) + ($306)|0);
                     HEAP8[$307>>0] = $292;
                     $V_10$4 = 2;$V_3$1 = $291;$V_4$3 = $V_4$452;
                     break L143;
                    }
                    if ((($216<<16>>16) == 69) | (($216<<16>>16) == 101)) {
                     $V_10$1 = 2;
                     label = 189;
                     break;
                    }
                    do {
                     if (!($208)) {
                      __THREW__ = 0;
                      invoke_vi(3799,($V_11$0|0));
                      $308 = __THREW__; __THREW__ = 0;
                      $309 = $308&1;
                      if ($309) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $310 = (invoke_iii(621,($V_11$0|0),0)|0);
                      $311 = __THREW__; __THREW__ = 0;
                      $312 = $311&1;
                      if ($312) {
                       label = 3;
                       break L139;
                      }
                      $313 = ($310<<16>>16)==($216<<16>>16);
                      if (!($313)) {
                       break;
                      }
                      __THREW__ = 0;
                      $314 = (invoke_iiiiiii(52,0,($s|0),($V_4$452|0),($V_11$0|0),0,($V_14$0|0))|0);
                      $315 = __THREW__; __THREW__ = 0;
                      $316 = $315&1;
                      if ($316) {
                       label = 3;
                       break L139;
                      }
                      $317 = ($314|0)==(0);
                      if (!($317)) {
                       break;
                      }
                      $318 = (($V_3$256) + 1)|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($154|0));
                      $319 = __THREW__; __THREW__ = 0;
                      $320 = $319&1;
                      if ($320) {
                       label = 3;
                       break L139;
                      }
                      $321 = ($V_3$256|0)<(0);
                      if ($321) {
                       label = 158;
                      } else {
                       $322 = HEAP32[$207>>2]|0;
                       $323 = ($V_3$256>>>0)<($322>>>0);
                       if (!($323)) {
                        label = 158;
                       }
                      }
                      if ((label|0) == 158) {
                       label = 0;
                       __THREW__ = 0;
                       $324 = (invoke_i(132)|0);
                       $325 = __THREW__; __THREW__ = 0;
                       $326 = $325&1;
                       if ($326) {
                        label = 3;
                        break L139;
                       }
                       __THREW__ = 0;
                       invoke_vi(3302,($324|0));
                       $327 = __THREW__; __THREW__ = 0;
                       $328 = $327&1;
                       if ($328) {
                        label = 3;
                        break L139;
                       }
                      }
                      $329 = HEAP32[$154>>2]|0;
                      $330 = (($329) + 92|0);
                      $331 = HEAP32[$330>>2]|0;
                      $332 = Math_imul($331, $V_3$256)|0;
                      $333 = (($206) + ($332)|0);
                      HEAP8[$333>>0] = 46;
                      $334 = (($213) + ($V_4$452))|0;
                      $V_10$4 = 3;$V_3$1 = $318;$V_4$3 = $334;
                      break L143;
                     }
                    } while(0);
                    do {
                     if (!($209)) {
                      __THREW__ = 0;
                      invoke_vi(3799,($V_12$0|0));
                      $335 = __THREW__; __THREW__ = 0;
                      $336 = $335&1;
                      if ($336) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $337 = (invoke_iii(621,($V_12$0|0),0)|0);
                      $338 = __THREW__; __THREW__ = 0;
                      $339 = $338&1;
                      if ($339) {
                       label = 3;
                       break L139;
                      }
                      $340 = ($337<<16>>16)==($216<<16>>16);
                      if (!($340)) {
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($s|0));
                      $341 = __THREW__; __THREW__ = 0;
                      $342 = $341&1;
                      if ($342) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $343 = (invoke_iiii(528,($s|0),($V_4$452|0),($V_15$0|0))|0);
                      $344 = __THREW__; __THREW__ = 0;
                      $345 = $344&1;
                      if ($345) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $346 = (invoke_iiii(574,0,($343|0),($V_12$0|0))|0);
                      $347 = __THREW__; __THREW__ = 0;
                      $348 = $347&1;
                      if ($348) {
                       label = 3;
                       break L139;
                      }
                      if (!($346)) {
                       break;
                      }
                      $349 = (($212) + ($V_4$452))|0;
                      $V_10$4 = 2;$V_3$1 = $V_3$256;$V_4$3 = $349;
                      break L143;
                     }
                    } while(0);
                    do {
                     if (!($210)) {
                      __THREW__ = 0;
                      invoke_vi(3799,($V_13$0|0));
                      $350 = __THREW__; __THREW__ = 0;
                      $351 = $350&1;
                      if ($351) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $352 = (invoke_iii(621,($V_13$0|0),0)|0);
                      $353 = __THREW__; __THREW__ = 0;
                      $354 = $353&1;
                      if ($354) {
                       label = 3;
                       break L139;
                      }
                      $355 = ($352<<16>>16)==($216<<16>>16);
                      if (!($355)) {
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($s|0));
                      $356 = __THREW__; __THREW__ = 0;
                      $357 = $356&1;
                      if ($357) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $358 = (invoke_iiii(528,($s|0),($V_4$452|0),($V_16$0|0))|0);
                      $359 = __THREW__; __THREW__ = 0;
                      $360 = $359&1;
                      if ($360) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      $361 = (invoke_iiii(574,0,($358|0),($V_13$0|0))|0);
                      $362 = __THREW__; __THREW__ = 0;
                      $363 = $362&1;
                      if ($363) {
                       label = 3;
                       break L139;
                      }
                      if (!($361)) {
                       break;
                      }
                      $364 = (($211) + ($V_4$452))|0;
                      $V_10$4 = 2;$V_3$1 = $V_3$256;$V_4$3 = $364;
                      break L143;
                     }
                    } while(0);
                    __THREW__ = 0;
                    $365 = (invoke_iii(604,0,($216|0))|0);
                    $366 = __THREW__; __THREW__ = 0;
                    $367 = $366&1;
                    if ($367) {
                     label = 3;
                     break L139;
                    }
                    if (!($365)) {
                     label = 181;
                     break L139;
                    }
                   }
                   else if ((label|0) == 264) {
                    label = 0;
                    __THREW__ = 0;
                    $546 = (invoke_iii(600,0,($216|0))|0);
                    $547 = __THREW__; __THREW__ = 0;
                    $548 = $547&1;
                    if ($548) {
                     label = 3;
                     break L139;
                    }
                    if (!($546)) {
                     __THREW__ = 0;
                     $566 = (invoke_iii(604,0,($216|0))|0);
                     $567 = __THREW__; __THREW__ = 0;
                     $568 = $567&1;
                     if ($568) {
                      label = 3;
                      break L139;
                     }
                     if ($566) {
                      break;
                     } else {
                      label = 274;
                      break L139;
                     }
                    }
                    $549 = (($V_3$256) + 1)|0;
                    $550 = $216&255;
                    __THREW__ = 0;
                    invoke_vi(3799,($154|0));
                    $551 = __THREW__; __THREW__ = 0;
                    $552 = $551&1;
                    if ($552) {
                     label = 3;
                     break L139;
                    }
                    $553 = ($V_3$256|0)<(0);
                    if ($553) {
                     label = 269;
                    } else {
                     $554 = HEAP32[$207>>2]|0;
                     $555 = ($V_3$256>>>0)<($554>>>0);
                     if (!($555)) {
                      label = 269;
                     }
                    }
                    if ((label|0) == 269) {
                     label = 0;
                     __THREW__ = 0;
                     $556 = (invoke_i(132)|0);
                     $557 = __THREW__; __THREW__ = 0;
                     $558 = $557&1;
                     if ($558) {
                      label = 3;
                      break L139;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($556|0));
                     $559 = __THREW__; __THREW__ = 0;
                     $560 = $559&1;
                     if ($560) {
                      label = 3;
                      break L139;
                     }
                    }
                    $561 = HEAP32[$154>>2]|0;
                    $562 = (($561) + 92|0);
                    $563 = HEAP32[$562>>2]|0;
                    $564 = Math_imul($563, $V_3$256)|0;
                    $565 = (($206) + ($564)|0);
                    HEAP8[$565>>0] = $550;
                    $V_10$4 = 5;$V_3$1 = $549;$V_4$3 = $V_4$452;
                    break L143;
                   }
                  } while(0);
                  do {
                   if ((label|0) == 189) {
                    label = 0;
                    __THREW__ = 0;
                    $384 = (invoke_iii(600,0,($216|0))|0);
                    $385 = __THREW__; __THREW__ = 0;
                    $386 = $385&1;
                    if ($386) {
                     label = 3;
                     break L139;
                    }
                    if ($384) {
                     $387 = (($V_3$256) + 1)|0;
                     $388 = $216&255;
                     __THREW__ = 0;
                     invoke_vi(3799,($154|0));
                     $389 = __THREW__; __THREW__ = 0;
                     $390 = $389&1;
                     if ($390) {
                      label = 3;
                      break L139;
                     }
                     $391 = ($V_3$256|0)<(0);
                     if ($391) {
                      label = 194;
                     } else {
                      $392 = HEAP32[$207>>2]|0;
                      $393 = ($V_3$256>>>0)<($392>>>0);
                      if (!($393)) {
                       label = 194;
                      }
                     }
                     if ((label|0) == 194) {
                      label = 0;
                      __THREW__ = 0;
                      $394 = (invoke_i(132)|0);
                      $395 = __THREW__; __THREW__ = 0;
                      $396 = $395&1;
                      if ($396) {
                       label = 3;
                       break L139;
                      }
                      __THREW__ = 0;
                      invoke_vi(3302,($394|0));
                      $397 = __THREW__; __THREW__ = 0;
                      $398 = $397&1;
                      if ($398) {
                       label = 3;
                       break L139;
                      }
                     }
                     $399 = HEAP32[$154>>2]|0;
                     $400 = (($399) + 92|0);
                     $401 = HEAP32[$400>>2]|0;
                     $402 = Math_imul($401, $V_3$256)|0;
                     $403 = (($206) + ($402)|0);
                     HEAP8[$403>>0] = $388;
                     $V_10$4 = $V_10$1;$V_3$1 = $387;$V_4$3 = $V_4$452;
                     break L143;
                    }
                    if (!((($216<<16>>16) == 69) | (($216<<16>>16) == 101))) {
                     __THREW__ = 0;
                     $437 = (invoke_iii(604,0,($216|0))|0);
                     $438 = __THREW__; __THREW__ = 0;
                     $439 = $438&1;
                     if ($439) {
                      label = 3;
                      break L139;
                     }
                     if ($437) {
                      break;
                     } else {
                      label = 215;
                      break L139;
                     }
                    }
                    if ($215) {
                     label = 199;
                     break L139;
                    }
                    $420 = (($V_3$256) + 1)|0;
                    $421 = $216&255;
                    __THREW__ = 0;
                    invoke_vi(3799,($154|0));
                    $422 = __THREW__; __THREW__ = 0;
                    $423 = $422&1;
                    if ($423) {
                     label = 3;
                     break L139;
                    }
                    $424 = ($V_3$256|0)<(0);
                    if ($424) {
                     label = 210;
                    } else {
                     $425 = HEAP32[$207>>2]|0;
                     $426 = ($V_3$256>>>0)<($425>>>0);
                     if (!($426)) {
                      label = 210;
                     }
                    }
                    if ((label|0) == 210) {
                     label = 0;
                     __THREW__ = 0;
                     $427 = (invoke_i(132)|0);
                     $428 = __THREW__; __THREW__ = 0;
                     $429 = $428&1;
                     if ($429) {
                      label = 3;
                      break L139;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($427|0));
                     $430 = __THREW__; __THREW__ = 0;
                     $431 = $430&1;
                     if ($431) {
                      label = 3;
                      break L139;
                     }
                    }
                    $432 = HEAP32[$154>>2]|0;
                    $433 = (($432) + 92|0);
                    $434 = HEAP32[$433>>2]|0;
                    $435 = Math_imul($434, $V_3$256)|0;
                    $436 = (($206) + ($435)|0);
                    HEAP8[$436>>0] = $421;
                    $V_10$4 = 4;$V_3$1 = $420;$V_4$3 = $V_4$452;
                    break L143;
                   }
                  } while(0);
                  if (!($96)) {
                   label = 285;
                   break L139;
                  }
                  __THREW__ = 0;
                  $585 = (invoke_iii(604,0,($216|0))|0);
                  $586 = __THREW__; __THREW__ = 0;
                  $587 = $586&1;
                  if ($587) {
                   label = 3;
                   break L139;
                  }
                  if ($585) {
                   $V_10$4 = 6;$V_3$1 = $V_3$256;$V_4$3 = $V_4$452;
                  } else {
                   label = 285;
                   break L139;
                  }
                 }
                } while(0);
                $596 = (($V_4$3) + 1)|0;
                $597 = ($596|0)<($91|0);
                if ($597) {
                 $V_10$551 = $V_10$4;$V_3$256 = $V_3$1;$V_4$452 = $596;
                } else {
                 $$pre$phiZ2D = $154;$V_3$3 = $V_3$1;
                 break L136;
                }
               }
               if ((label|0) == 3) {
                $3 = ___cxa_find_matching_catch()|0;
                $4 = tempRet0;
                $lpad$phi$index = $3;$lpad$phi$index4 = $4;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               else if ((label|0) == 181) {
                if ($tryParse) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                HEAP16[$L_153>>1] = $216;
                __THREW__ = 0;
                (invoke_ii(2996,(2180696|0))|0);
                $368 = __THREW__; __THREW__ = 0;
                $369 = $368&1;
                if ($369) {
                 break L1;
                }
                __THREW__ = 0;
                $370 = (invoke_iii(2724,(2180696|0),($L_153|0))|0);
                $371 = __THREW__; __THREW__ = 0;
                $372 = $371&1;
                if ($372) {
                 break L1;
                }
                $373 = HEAP32[3008704>>2]|0;
                __THREW__ = 0;
                $374 = (invoke_iiii(559,0,($373|0),($370|0))|0);
                $375 = __THREW__; __THREW__ = 0;
                $376 = $375&1;
                if ($376) {
                 break L1;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $377 = __THREW__; __THREW__ = 0;
                $378 = $377&1;
                if ($378) {
                 break L1;
                }
                __THREW__ = 0;
                $379 = (invoke_ii(3469,(2603176|0))|0);
                $380 = __THREW__; __THREW__ = 0;
                $381 = $380&1;
                if ($381) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vii(1940,($379|0),($374|0));
                $382 = __THREW__; __THREW__ = 0;
                $383 = $382&1;
                if ($383) {
                 break L1;
                }
                HEAP32[$exc>>2] = $379;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               else if ((label|0) == 199) {
                if ($tryParse) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                HEAP16[$L_168>>1] = $216;
                __THREW__ = 0;
                (invoke_ii(2996,(2180696|0))|0);
                $404 = __THREW__; __THREW__ = 0;
                $405 = $404&1;
                if ($405) {
                 break L1;
                }
                __THREW__ = 0;
                $406 = (invoke_iii(2724,(2180696|0),($L_168|0))|0);
                $407 = __THREW__; __THREW__ = 0;
                $408 = $407&1;
                if ($408) {
                 break L1;
                }
                $409 = HEAP32[3008712>>2]|0;
                __THREW__ = 0;
                $410 = (invoke_iiii(559,0,($409|0),($406|0))|0);
                $411 = __THREW__; __THREW__ = 0;
                $412 = $411&1;
                if ($412) {
                 break L1;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $413 = __THREW__; __THREW__ = 0;
                $414 = $413&1;
                if ($414) {
                 break L1;
                }
                __THREW__ = 0;
                $415 = (invoke_ii(3469,(2603176|0))|0);
                $416 = __THREW__; __THREW__ = 0;
                $417 = $416&1;
                if ($417) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vii(1940,($415|0),($410|0));
                $418 = __THREW__; __THREW__ = 0;
                $419 = $418&1;
                if ($419) {
                 break L1;
                }
                HEAP32[$exc>>2] = $415;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               else if ((label|0) == 215) {
                if ($tryParse) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                HEAP16[$L_180>>1] = $216;
                __THREW__ = 0;
                (invoke_ii(2996,(2180696|0))|0);
                $440 = __THREW__; __THREW__ = 0;
                $441 = $440&1;
                if ($441) {
                 break L1;
                }
                __THREW__ = 0;
                $442 = (invoke_iii(2724,(2180696|0),($L_180|0))|0);
                $443 = __THREW__; __THREW__ = 0;
                $444 = $443&1;
                if ($444) {
                 break L1;
                }
                $445 = HEAP32[3008720>>2]|0;
                __THREW__ = 0;
                $446 = (invoke_iiii(559,0,($445|0),($442|0))|0);
                $447 = __THREW__; __THREW__ = 0;
                $448 = $447&1;
                if ($448) {
                 break L1;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $449 = __THREW__; __THREW__ = 0;
                $450 = $449&1;
                if ($450) {
                 break L1;
                }
                __THREW__ = 0;
                $451 = (invoke_ii(3469,(2603176|0))|0);
                $452 = __THREW__; __THREW__ = 0;
                $453 = $452&1;
                if ($453) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vii(1940,($451|0),($446|0));
                $454 = __THREW__; __THREW__ = 0;
                $455 = $454&1;
                if ($455) {
                 break L1;
                }
                HEAP32[$exc>>2] = $451;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               else if ((label|0) == 256) {
                if ($tryParse) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                HEAP16[$L_213>>1] = $216;
                __THREW__ = 0;
                (invoke_ii(2996,(2180696|0))|0);
                $530 = __THREW__; __THREW__ = 0;
                $531 = $530&1;
                if ($531) {
                 break L1;
                }
                __THREW__ = 0;
                $532 = (invoke_iii(2724,(2180696|0),($L_213|0))|0);
                $533 = __THREW__; __THREW__ = 0;
                $534 = $533&1;
                if ($534) {
                 break L1;
                }
                $535 = HEAP32[3008728>>2]|0;
                __THREW__ = 0;
                $536 = (invoke_iiii(559,0,($535|0),($532|0))|0);
                $537 = __THREW__; __THREW__ = 0;
                $538 = $537&1;
                if ($538) {
                 break L1;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $539 = __THREW__; __THREW__ = 0;
                $540 = $539&1;
                if ($540) {
                 break L1;
                }
                __THREW__ = 0;
                $541 = (invoke_ii(3469,(2603176|0))|0);
                $542 = __THREW__; __THREW__ = 0;
                $543 = $542&1;
                if ($543) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vii(1940,($541|0),($536|0));
                $544 = __THREW__; __THREW__ = 0;
                $545 = $544&1;
                if ($545) {
                 break L1;
                }
                HEAP32[$exc>>2] = $541;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               else if ((label|0) == 274) {
                if ($tryParse) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                HEAP16[$L_225>>1] = $216;
                __THREW__ = 0;
                (invoke_ii(2996,(2180696|0))|0);
                $569 = __THREW__; __THREW__ = 0;
                $570 = $569&1;
                if ($570) {
                 break L1;
                }
                __THREW__ = 0;
                $571 = (invoke_iii(2724,(2180696|0),($L_225|0))|0);
                $572 = __THREW__; __THREW__ = 0;
                $573 = $572&1;
                if ($573) {
                 break L1;
                }
                $574 = HEAP32[3008736>>2]|0;
                __THREW__ = 0;
                $575 = (invoke_iiii(559,0,($574|0),($571|0))|0);
                $576 = __THREW__; __THREW__ = 0;
                $577 = $576&1;
                if ($577) {
                 break L1;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $578 = __THREW__; __THREW__ = 0;
                $579 = $578&1;
                if ($579) {
                 break L1;
                }
                __THREW__ = 0;
                $580 = (invoke_ii(3469,(2603176|0))|0);
                $581 = __THREW__; __THREW__ = 0;
                $582 = $581&1;
                if ($582) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vii(1940,($580|0),($575|0));
                $583 = __THREW__; __THREW__ = 0;
                $584 = $583&1;
                if ($584) {
                 break L1;
                }
                HEAP32[$exc>>2] = $580;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               else if ((label|0) == 285) {
                if ($tryParse) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $588 = __THREW__; __THREW__ = 0;
                $589 = $588&1;
                if ($589) {
                 break L1;
                }
                __THREW__ = 0;
                $590 = (invoke_ii(3469,(2603176|0))|0);
                $591 = __THREW__; __THREW__ = 0;
                $592 = $591&1;
                if ($592) {
                 break L1;
                }
                $593 = HEAP32[3008744>>2]|0;
                __THREW__ = 0;
                invoke_vii(1940,($590|0),($593|0));
                $594 = __THREW__; __THREW__ = 0;
                $595 = $594&1;
                if ($595) {
                 break L1;
                }
                HEAP32[$exc>>2] = $590;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              } else {
               $$pre$phiZ2D = $154;$V_3$3 = 0;
              }
             } while(0);
             __THREW__ = 0;
             invoke_vi(3799,($$pre$phiZ2D|0));
             $600 = __THREW__; __THREW__ = 0;
             $601 = $600&1;
             if ($601) {
              break;
             }
             $602 = ($V_3$3|0)<(0);
             if ($602) {
              label = 295;
             } else {
              $603 = (($154) + 12|0);
              $604 = HEAP32[$603>>2]|0;
              $605 = ($V_3$3>>>0)<($604>>>0);
              if (!($605)) {
               label = 295;
              }
             }
             if ((label|0) == 295) {
              __THREW__ = 0;
              $606 = (invoke_i(132)|0);
              $607 = __THREW__; __THREW__ = 0;
              $608 = $607&1;
              if ($608) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($606|0));
              $609 = __THREW__; __THREW__ = 0;
              $610 = $609&1;
              if ($610) {
               break;
              }
             }
             $611 = HEAP32[$154>>2]|0;
             $612 = (($154) + 16|0);
             $613 = (($611) + 92|0);
             $614 = HEAP32[$613>>2]|0;
             $615 = Math_imul($614, $V_3$3)|0;
             $616 = (($612) + ($615)|0);
             HEAP8[$616>>0] = 0;
             __THREW__ = 0;
             invoke_vi(3799,($$pre$phiZ2D|0));
             $617 = __THREW__; __THREW__ = 0;
             $618 = $617&1;
             if ($618) {
              break;
             }
             $619 = (($154) + 12|0);
             $620 = HEAP32[$619>>2]|0;
             $621 = ($620|0)==(0);
             if ($621) {
              __THREW__ = 0;
              $622 = (invoke_i(132)|0);
              $623 = __THREW__; __THREW__ = 0;
              $624 = $623&1;
              if ($624) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($622|0));
              $625 = __THREW__; __THREW__ = 0;
              $626 = $625&1;
              if ($626) {
               break;
              }
             }
             __THREW__ = 0;
             $627 = (invoke_iiii(587,0,($612|0),($V_20|0))|0);
             $628 = __THREW__; __THREW__ = 0;
             $629 = $628&1;
             if ($629) {
              break;
             }
             if (!($627)) {
              if ($tryParse) {
               $$0 = 0;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
              __THREW__ = 0;
              $630 = (invoke_ii(1790,0)|0);
              $631 = __THREW__; __THREW__ = 0;
              $632 = $631&1;
              if ($632) {
               break;
              }
              HEAP32[$exc>>2] = $630;
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             $633 = +HEAPF64[$V_20>>3];
             __THREW__ = 0;
             $634 = (invoke_iid(6,0,(+$633))|0);
             $635 = __THREW__; __THREW__ = 0;
             $636 = $635&1;
             if ($636) {
              break;
             }
             do {
              if (!($634)) {
               $637 = +HEAPF64[$V_20>>3];
               __THREW__ = 0;
               $638 = (invoke_iid(5,0,(+$637))|0);
               $639 = __THREW__; __THREW__ = 0;
               $640 = $639&1;
               if ($640) {
                break L1;
               }
               if ($638) {
                break;
               }
               $648 = +HEAPF64[$V_20>>3];
               HEAPF64[$result>>3] = $648;
               $$0 = 1;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             } while(0);
             if ($tryParse) {
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2635888|0))|0);
             $641 = __THREW__; __THREW__ = 0;
             $642 = $641&1;
             if ($642) {
              break;
             }
             __THREW__ = 0;
             $643 = (invoke_ii(3469,(2635888|0))|0);
             $644 = __THREW__; __THREW__ = 0;
             $645 = $644&1;
             if ($645) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2770,($643|0));
             $646 = __THREW__; __THREW__ = 0;
             $647 = $646&1;
             if ($647) {
              break;
             }
             HEAP32[$exc>>2] = $643;
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index4 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_Locale_m_GetText_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$fmt,$args) {
 $__this = $__this|0;
 $fmt = $fmt|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2256552);
 __THREW__ = 0;
 $0 = (invoke_iiii(556,0,($fmt|0),($args|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z77mscorlib_System_Exception_m__ctor_mscorlib_System_Void_mscorlib_System_StringP25mscorlib_System_ExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244200);
 $0 = (($__this) + 40|0);
 HEAP32[$0>>2] = -2146233088;
 __THREW__ = 0;
 invoke_vi(1924,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($__this) + 16|0);
  HEAP32[$3>>2] = $message;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z47mscorlib_System_Double_m_TryParseStringConstantP22mscorlib_System_ObjectP22mscorlib_System_StringS2_ii($__this,$format,$s,$start,$end) {
 $__this = $__this|0;
 $format = $format|0;
 $s = $s|0;
 $start = $start|0;
 $end = $end|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196344);
 $0 = (1 - ($start))|0;
 $1 = (($0) + ($end))|0;
 __THREW__ = 0;
 invoke_vi(3799,($format|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_ii(1816,($format|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($1|0)==($4|0);
   if (!($7)) {
    $G_B3_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($format|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_ii(1816,($format|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     $15 = (invoke_iiiiiii(52,0,($format|0),0,($s|0),($start|0),($12|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      $18 = ($15|0)==(0);
      $G_B3_0$0 = $18;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B3_0$0|0);
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Double_m_ParseImplP22mscorlib_System_ObjectPhPd($__this,$byte_ptr,$value) {
 $__this = $__this|0;
 $byte_ptr = $byte_ptr|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196392);
 $0 = HEAP32[2196440>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2196448|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2196440>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($byte_ptr|0),($value|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Double_m_ToString_mscorlib_System_StringPd($__this) {
 $__this = $__this|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196504);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iidi(1,(0|0),(+$0),(0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z88mscorlib_System_Double_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPdP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196552);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iidi(1,(0|0),(+$0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z111mscorlib_System_Double_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPdP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2196600);
 $0 = +HEAPF64[$__this>>3];
 __THREW__ = 0;
 $1 = (invoke_iiidi(1,(0|0),($format|0),(+$0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_DoubleTraitsE6InvokeEPFiPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_DoubleTraitsE6InvokeEPFbPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 $3 = $2&1;
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_DoubleTraits17VoidPointerTraitsS1_E6InvokeEPFdPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (+FUNCTION_TABLE_diii[$func & 15]($obj,$0,$2));
 HEAPF64[$ret>>3] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I28mscorlib_System_DoubleTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFdPvS4_iS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (+FUNCTION_TABLE_diiii[$func & 1]($obj,$0,$3,$5));
 HEAPF64[$ret>>3] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker4I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_E6InvokeEPFbPvS4_S4_iiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$5,$8)|0);
 $10 = $9&1;
 HEAP8[$ret>>0] = $10;
 $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($11|0);
}
function __Z53mscorlib_System_Double_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Double_CustomAttributesCacheGenerator_mscorlib_System_Double_m_IsNaNP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z163mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_System_ByteP23mscorlib_System_Decimaliiibh($__this,$lo,$mid,$hi,$isNegative,$scale) {
 $__this = $__this|0;
 $lo = $lo|0;
 $mid = $mid|0;
 $hi = $hi|0;
 $isNegative = $isNegative|0;
 $scale = $scale|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198328);
 __THREW__ = 0;
 invoke_v(423);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $lo;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $mid;
  $4 = (($__this) + 4|0);
  HEAP32[$4>>2] = $hi;
  $5 = ($scale&255)<(29);
  if ($5) {
   $21 = $scale&255;
   $22 = $21 << 16;
   $23 = $22 | -2147483648;
   $$ = $isNegative ? $23 : $22;
   HEAP32[$__this>>2] = $$;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  $8 = HEAP32[3008984>>2]|0;
  __THREW__ = 0;
  $9 = (invoke_iii(783,0,($8|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($9|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      invoke_vi(3830,($14|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z74mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P23mscorlib_System_Decimali($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198376);
 $0 = (($__this) + 12|0);
 HEAP32[$0>>2] = 0;
 $1 = (($__this) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = ($value|0)>(-1);
 if ($2) {
  HEAP32[$__this>>2] = 0;
  $5 = (($__this) + 8|0);
  HEAP32[$5>>2] = $value;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 } else {
  HEAP32[$__this>>2] = -2147483648;
  $3 = (0 - ($value))|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z75mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_UInt32P23mscorlib_System_Decimalj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198424);
 $0 = (($__this) + 8|0);
 HEAP32[$0>>2] = $value;
 $1 = (($__this) + 12|0);
 HEAP32[$1>>2] = 0;
 $2 = (($__this) + 4|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$__this>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_Int64P23mscorlib_System_Decimalx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198472);
 $2 = (($__this) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ($1|0)>(-1);
 $4 = ($1|0)==(-1);
 $5 = ($0>>>0)>(4294967295);
 $6 = $4 & $5;
 $7 = $3 | $6;
 if ($7) {
  HEAP32[$__this>>2] = 0;
  $12 = (($__this) + 8|0);
  HEAP32[$12>>2] = $0;
  $13 = (($__this) + 12|0);
  HEAP32[$13>>2] = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 } else {
  HEAP32[$__this>>2] = -2147483648;
  $8 = (_i64Subtract(0,0,($0|0),($1|0))|0);
  $9 = tempRet0;
  $10 = (($__this) + 8|0);
  HEAP32[$10>>2] = $8;
  $11 = (($__this) + 12|0);
  HEAP32[$11>>2] = $9;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z75mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_UInt64P23mscorlib_System_Decimaly($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198520);
 $2 = (($__this) + 4|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$__this>>2] = 0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $0;
 $4 = (($__this) + 12|0);
 HEAP32[$4>>2] = $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_SingleP23mscorlib_System_Decimalf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $L_10 = 0, $L_18 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 24|0;
 $_stackTraceSentry = sp;
 $L_10 = sp + 4|0;
 $L_18 = sp + 8|0;
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198568);
 __THREW__ = 0;
 invoke_v(424);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = $value > Math_fround(7.92281625142643375935E+28);
   $4 = $value < Math_fround(-7.92281625142643375935E+28);
   $or$cond = $3 | $4;
   if (!($or$cond)) {
    __THREW__ = 0;
    $7 = (invoke_iif(9,0,(+$value))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    if (!($7)) {
     __THREW__ = 0;
     $10 = (invoke_iif(10,0,(+$value))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     if (!($10)) {
      __THREW__ = 0;
      $13 = (invoke_iif(11,0,(+$value))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      if (!($13)) {
       __THREW__ = 0;
       $52 = (invoke_ii(1982,(0|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       __THREW__ = 0;
       $55 = (invoke_iii(656,($0|0),($52|0))|0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       __THREW__ = 0;
       $58 = (invoke_ii(1982,(0|0))|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       __THREW__ = 0;
       invoke_viiiii(46,($L_18|0),0,($55|0),167,($58|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       $63 = HEAP32[$L_18>>2]|0;
       $64 = (($L_18) + 4|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = (($L_18) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($L_18) + 12|0);
       $69 = HEAP32[$68>>2]|0;
       HEAP32[$__this>>2] = $63;
       $70 = (($__this) + 4|0);
       HEAP32[$70>>2] = $65;
       $71 = (($__this) + 8|0);
       HEAP32[$71>>2] = $67;
       $72 = (($__this) + 12|0);
       HEAP32[$72>>2] = $69;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_iii(2754,(1167664|0),1)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     HEAPF32[$L_10>>2] = $value;
     __THREW__ = 0;
     (invoke_ii(2996,(2194912|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_iii(2724,(2194912|0),($L_10|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       invoke_vi(3799,($18|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        $28 = (($18) + 12|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = ($29|0)==(0);
        if ($30) {
         __THREW__ = 0;
         $31 = (invoke_i(132)|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($31|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($18|0),($23|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         $38 = (($18) + 16|0);
         HEAP32[$38>>2] = $23;
         $39 = HEAP32[3009064>>2]|0;
         __THREW__ = 0;
         $40 = (invoke_iiii(728,0,($39|0),($18|0))|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2635888|0))|0);
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if (!($44)) {
           __THREW__ = 0;
           $45 = (invoke_ii(3469,(2635888|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            __THREW__ = 0;
            invoke_vii(1971,($45|0),($40|0));
            $48 = __THREW__; __THREW__ = 0;
            $49 = $48&1;
            if (!($49)) {
             __THREW__ = 0;
             invoke_vi(3830,($45|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if (!($51)) {
              // unreachable;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z153mscorlib_System_Decimal_m_Parse_mscorlib_System_Decimal_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($agg$result,$__this,$s,$style,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200392);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(425);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3009792>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = $style & 512;
   $16 = ($15|0)==(0);
   if ($16) {
    __THREW__ = 0;
    (invoke_iiiiiii(53,0,($s|0),($style|0),($provider|0),($agg$result|0),1)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560072|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2560072|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = HEAP32[3009800>>2]|0;
     $23 = HEAP32[3009808>>2]|0;
     __THREW__ = 0;
     invoke_viii(641,($19|0),($22|0),($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      invoke_vi(3830,($19|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z75mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_DoubleP23mscorlib_System_Decimald($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $L_10 = 0, $L_18 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp + 32|0;
 $L_10 = sp;
 $L_18 = sp + 16|0;
 HEAPF64[$0>>3] = $value;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198616);
 __THREW__ = 0;
 invoke_v(426);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = $value > 7.92281625142643375935E+28;
   $4 = $value < -7.92281625142643375935E+28;
   $or$cond = $3 | $4;
   if (!($or$cond)) {
    __THREW__ = 0;
    $7 = (invoke_iid(4,0,(+$value))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    if (!($7)) {
     __THREW__ = 0;
     $10 = (invoke_iid(5,0,(+$value))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     if (!($10)) {
      __THREW__ = 0;
      $13 = (invoke_iid(6,0,(+$value))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      if (!($13)) {
       __THREW__ = 0;
       $52 = (invoke_ii(1982,(0|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       __THREW__ = 0;
       $55 = (invoke_iii(670,($0|0),($52|0))|0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       __THREW__ = 0;
       $58 = (invoke_ii(1982,(0|0))|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       __THREW__ = 0;
       invoke_viiiii(46,($L_18|0),0,($55|0),167,($58|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       $63 = HEAP32[$L_18>>2]|0;
       $64 = (($L_18) + 4|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = (($L_18) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($L_18) + 12|0);
       $69 = HEAP32[$68>>2]|0;
       HEAP32[$__this>>2] = $63;
       $70 = (($__this) + 4|0);
       HEAP32[$70>>2] = $65;
       $71 = (($__this) + 8|0);
       HEAP32[$71>>2] = $67;
       $72 = (($__this) + 12|0);
       HEAP32[$72>>2] = $69;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_iii(2754,(1167664|0),1)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     HEAPF64[$L_10>>3] = $value;
     __THREW__ = 0;
     (invoke_ii(2996,(2198192|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_iii(2724,(2198192|0),($L_10|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       invoke_vi(3799,($18|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        $28 = (($18) + 12|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = ($29|0)==(0);
        if ($30) {
         __THREW__ = 0;
         $31 = (invoke_i(132)|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($31|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($18|0),($23|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         $38 = (($18) + 16|0);
         HEAP32[$38>>2] = $23;
         $39 = HEAP32[3009224>>2]|0;
         __THREW__ = 0;
         $40 = (invoke_iiii(728,0,($39|0),($18|0))|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2635888|0))|0);
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if (!($44)) {
           __THREW__ = 0;
           $45 = (invoke_ii(3469,(2635888|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            __THREW__ = 0;
            invoke_vii(1971,($45|0),($40|0));
            $48 = __THREW__; __THREW__ = 0;
            $49 = $48&1;
            if (!($49)) {
             __THREW__ = 0;
             invoke_vi(3830,($45|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if (!($51)) {
              // unreachable;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z32mscorlib_System_Decimal_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_11 = 0, $L_13 = 0, $L_15 = 0, $L_21 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $_stackTraceSentry = sp + 80|0;
 $L_5 = sp;
 $L_11 = sp + 16|0;
 $L_13 = sp + 32|0;
 $L_15 = sp + 48|0;
 $L_21 = sp + 64|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198664);
 ;HEAP32[$L_5+0>>2]=0|0;HEAP32[$L_5+4>>2]=0|0;HEAP32[$L_5+8>>2]=0|0;HEAP32[$L_5+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiiii(53,($L_5|0),-1,-1,-1,1,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2206536|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[((2206536 + 80|0))>>2]|0;
   ;HEAP32[$4+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$L_5+12>>2]|0;
   ;HEAP32[$L_11+0>>2]=0|0;HEAP32[$L_11+4>>2]=0|0;HEAP32[$L_11+8>>2]=0|0;HEAP32[$L_11+12>>2]=0|0;
   __THREW__ = 0;
   invoke_viiiiii(53,($L_11|0),-1,-1,-1,0,0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2206536|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2206536 + 80|0))>>2]|0;
     $10 = (($9) + 16|0);
     ;HEAP32[$10+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$10+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$L_11+12>>2]|0;
     ;HEAP32[$L_13+0>>2]=0|0;HEAP32[$L_13+4>>2]=0|0;HEAP32[$L_13+8>>2]=0|0;HEAP32[$L_13+12>>2]=0|0;
     __THREW__ = 0;
     invoke_vii(1767,($L_13|0),-1);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2206536|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = HEAP32[((2206536 + 80|0))>>2]|0;
       $16 = (($15) + 32|0);
       ;HEAP32[$16+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$L_13+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$L_13+12>>2]|0;
       ;HEAP32[$L_15+0>>2]=0|0;HEAP32[$L_15+4>>2]=0|0;HEAP32[$L_15+8>>2]=0|0;HEAP32[$L_15+12>>2]=0|0;
       __THREW__ = 0;
       invoke_vii(1767,($L_15|0),1);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2206536|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         $21 = HEAP32[((2206536 + 80|0))>>2]|0;
         $22 = (($21) + 48|0);
         ;HEAP32[$22+0>>2]=HEAP32[$L_15+0>>2]|0;HEAP32[$22+4>>2]=HEAP32[$L_15+4>>2]|0;HEAP32[$22+8>>2]=HEAP32[$L_15+8>>2]|0;HEAP32[$22+12>>2]=HEAP32[$L_15+12>>2]|0;
         ;HEAP32[$L_21+0>>2]=0|0;HEAP32[$L_21+4>>2]=0|0;HEAP32[$L_21+8>>2]=0|0;HEAP32[$L_21+12>>2]=0|0;
         __THREW__ = 0;
         invoke_viiiiii(53,($L_21|0),-1,-1,-1,0,1);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2206536|0))|0);
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           $27 = HEAP32[((2206536 + 80|0))>>2]|0;
           $28 = (($27) + 64|0);
           ;HEAP32[$28+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$L_21+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$L_21+12>>2]|0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($29|0);
 // unreachable;
}
function __Z52mscorlib_System_Decimal_m_System_IConvertible_ToTypeP23mscorlib_System_DecimalP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198712);
 __THREW__ = 0;
 invoke_v(427);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    ;HEAP32[$L_1+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_1+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_1+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$L_1+12>>2]=HEAP32[$__this+12>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2206536|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_iii(2724,(2206536|0),($L_1|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_iiiiii(126,(0|0),($17|0),($targetType|0),($provider|0),0)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3009240>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Decimal_m_System_IConvertible_ToBooleanP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198760);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1008,(0|0),($__this$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Decimal_m_System_IConvertible_ToByteP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198808);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1016,(0|0),($__this$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Decimal_m_System_IConvertible_ToCharP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198856);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Decimal_m_System_IConvertible_ToDateTimeP23mscorlib_System_DecimalP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198904);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z55mscorlib_System_Decimal_m_System_IConvertible_ToDecimalP23mscorlib_System_DecimalP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2198952);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$__this+12>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_Decimal_m_System_IConvertible_ToDoubleP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199000);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (+invoke_dii(20,(0|0),($__this$byval_copy|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$0);
 }
 return +0;
}
function __Z53mscorlib_System_Decimal_m_System_IConvertible_ToInt16P23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199048);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1031,(0|0),($__this$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Decimal_m_System_IConvertible_ToInt32P23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199096);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1040,(0|0),($__this$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Decimal_m_System_IConvertible_ToInt64P23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199144);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1049,(0|0),($__this$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Decimal_m_System_IConvertible_ToSByteP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199192);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1059,(0|0),($__this$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Decimal_m_System_IConvertible_ToSingleP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199240);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (Math_fround(+(invoke_fii(26,(0|0),($__this$byval_copy|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($0));
 }
 return Math_fround(0);
}
function __Z54mscorlib_System_Decimal_m_System_IConvertible_ToUInt16P23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199288);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1067,(0|0),($__this$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Decimal_m_System_IConvertible_ToUInt32P23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199336);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1075,(0|0),($__this$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Decimal_m_System_IConvertible_ToUInt64P23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199384);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iii(1083,(0|0),($__this$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z33mscorlib_System_Decimal_m_GetBitsP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$d) {
 $__this = $__this|0;
 $d = $d|0;
 var $$c = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199432);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1170368|0),4)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = (($d) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($2) + 12|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = ($10|0)==(0);
     if ($11) {
      __THREW__ = 0;
      $12 = (invoke_i(132)|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($12|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
     }
     $19 = (($2) + 16|0);
     $$c = $6;
     HEAP32[$19>>2] = $$c;
     $20 = (($d) + 12|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = HEAP32[$9>>2]|0;
      $25 = ($24>>>0)<(2);
      if ($25) {
       __THREW__ = 0;
       $26 = (invoke_i(132)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[$2>>2]|0;
      $32 = (($31) + 92|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($19) + ($33)|0);
      HEAP32[$34>>2] = $21;
      $35 = (($d) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = HEAP32[$9>>2]|0;
       $40 = ($39>>>0)<(3);
       if ($40) {
        __THREW__ = 0;
        $41 = (invoke_i(132)|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($41|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
       }
       $46 = HEAP32[$2>>2]|0;
       $47 = (($46) + 92|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = $48 << 1;
       $50 = (($19) + ($49)|0);
       HEAP32[$50>>2] = $36;
       $51 = HEAP32[$d>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if (!($53)) {
        $54 = HEAP32[$9>>2]|0;
        $55 = ($54>>>0)<(4);
        if (!($55)) {
         $61 = HEAP32[$2>>2]|0;
         $62 = (($61) + 92|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = ($63*3)|0;
         $65 = (($19) + ($64)|0);
         HEAP32[$65>>2] = $51;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($2|0);
        }
        __THREW__ = 0;
        $56 = (invoke_i(132)|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if (!($58)) {
         __THREW__ = 0;
         invoke_vi(3302,($56|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if (!($60)) {
          $61 = HEAP32[$2>>2]|0;
          $62 = (($61) + 92|0);
          $63 = HEAP32[$62>>2]|0;
          $64 = ($63*3)|0;
          $65 = (($19) + ($64)|0);
          HEAP32[$65>>2] = $51;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($2|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z29mscorlib_System_Decimal_m_AddP22mscorlib_System_Object23mscorlib_System_DecimalS1_($agg$result,$__this,$d1,$d2) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199480);
 __THREW__ = 0;
 invoke_v(428);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iiii(613,0,($d1|0),($d2|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$d1+12>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $8 = HEAP32[3009256>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_iii(783,0,($8|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_ii(3469,(2635888|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vii(1971,($14|0),($9|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       invoke_vi(3830,($14|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z37mscorlib_System_Decimal_m_decimalIncrP22mscorlib_System_ObjectP23mscorlib_System_DecimalS2_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200872);
 $0 = HEAP32[2200920>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2200928|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2200920>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($d1|0),($d2|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Decimal_m_SubtractP22mscorlib_System_Object23mscorlib_System_DecimalS1_($agg$result,$__this,$d1,$d2) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_6 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199528);
 __THREW__ = 0;
 invoke_v(429);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$d2>>2]|0;
  $3 = $2 ^ -2147483648;
  HEAP32[$d2>>2] = $3;
  __THREW__ = 0;
  $4 = (invoke_iiii(613,0,($d1|0),($d2|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)==(0);
   if ($7) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$d1+12>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   HEAP32[$L_6>>2] = $4;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(2724,(2155952|0),($L_6|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[3009344>>2]|0;
     $16 = HEAP32[3009352>>2]|0;
     __THREW__ = 0;
     $17 = (invoke_iiiii(100,0,($15|0),($12|0),($16|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      $20 = (invoke_iii(783,0,($17|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2635888|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_ii(3469,(2635888|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         __THREW__ = 0;
         invoke_vii(1971,($25|0),($20|0));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          __THREW__ = 0;
          invoke_vi(3830,($25|0));
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z37mscorlib_System_Decimal_m_GetHashCodeP23mscorlib_System_Decimal($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199576);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($__this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 ^ $0;
 $4 = (($__this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3 ^ $5;
 $7 = (($__this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $6 ^ $8;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($9|0);
}
function __Z29mscorlib_System_Decimal_m_u64P22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199624);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(511,0,($value|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_iiii(611,0,($value|0),($V_0|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)==(0);
   if ($9) {
    $21 = $V_0;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + 4)|0;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $26;
    STACKTOP = sp;return ($23|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2635888|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(2770,($14|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      invoke_vi(3830,($14|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Decimal_m_decimalFloorAndTruncP22mscorlib_System_ObjectP23mscorlib_System_Decimali($__this,$val,$floorFlag) {
 $__this = $__this|0;
 $val = $val|0;
 $floorFlag = $floorFlag|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201376);
 $0 = HEAP32[2201424>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2201432|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2201424>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($val|0),($floorFlag|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z40mscorlib_System_Decimal_m_decimal2UInt64P22mscorlib_System_ObjectP23mscorlib_System_DecimalPy($__this,$val,$result) {
 $__this = $__this|0;
 $val = $val|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200632);
 $0 = HEAP32[2200680>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2200688|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2200680>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($val|0),($result|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z29mscorlib_System_Decimal_m_s64P22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199672);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(511,0,($value|0),0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_iiii(612,0,($value|0),($V_0|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)==(0);
   if ($9) {
    $21 = $V_0;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + 4)|0;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $26;
    STACKTOP = sp;return ($23|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2635888|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(2770,($14|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      invoke_vi(3830,($14|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Decimal_m_decimal2Int64P22mscorlib_System_ObjectP23mscorlib_System_DecimalPx($__this,$val,$result) {
 $__this = $__this|0;
 $val = $val|0;
 $result = $result|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200752);
 $0 = HEAP32[2200800>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2200808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2200800>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($val|0),($result|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Decimal_m_Equals_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $d1$byval_copy = 0, $d2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $d2$byval_copy = sp + 24|0;
 $d1$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199720);
 __THREW__ = 0;
 ;HEAP32[$d1$byval_copy+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$d1$byval_copy+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$d1$byval_copy+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$d1$byval_copy+12>>2]=HEAP32[$d1+12>>2]|0;
 ;HEAP32[$d2$byval_copy+0>>2]=HEAP32[$d2+0>>2]|0;HEAP32[$d2$byval_copy+4>>2]=HEAP32[$d2+4>>2]|0;HEAP32[$d2$byval_copy+8>>2]=HEAP32[$d2+8>>2]|0;HEAP32[$d2$byval_copy+12>>2]=HEAP32[$d2+12>>2]|0;
 $0 = (invoke_iiii(602,0,($d1$byval_copy|0),($d2$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0|0)==(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z33mscorlib_System_Decimal_m_CompareP22mscorlib_System_Object23mscorlib_System_DecimalS1_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200008);
 __THREW__ = 0;
 $0 = (invoke_iiii(618,0,($d1|0),($d2|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_Decimal_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__this$byval_copy = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__this$byval_copy = sp + 40|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 $0 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199768);
 __THREW__ = 0;
 (invoke_ii(2996,(2206536|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2735,($value|0),(2206536|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2206536|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_iii(2753,($value|0),(2206536|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     ;HEAP32[$0+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$11+12>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
     ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
     $14 = (invoke_iiii(599,0,($$byval_copy|0),($__this$byval_copy|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $$0 = $14;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Decimal_m_IsZeroP23mscorlib_System_Decimal($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $G_B4_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199816);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $3 = (($__this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = (($__this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0);
   $G_B4_0$0 = $8;
  } else {
   $G_B4_0$0 = 0;
  }
 } else {
  $G_B4_0$0 = 0;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B4_0$0|0);
}
function __Z31mscorlib_System_Decimal_m_FloorP22mscorlib_System_Object23mscorlib_System_Decimal($agg$result,$__this,$d) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d = $d|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199864);
 __THREW__ = 0;
 invoke_viii(511,0,($d|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$d+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$d+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$d+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$d+12>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z34mscorlib_System_Decimal_m_MultiplyP22mscorlib_System_Object23mscorlib_System_DecimalS1_($agg$result,$__this,$d1,$d2) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199912);
 __THREW__ = 0;
 $0 = (invoke_ii(1824,($d1|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if (!($0)) {
    __THREW__ = 0;
    $5 = (invoke_ii(1824,($d2|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    if (!($5)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(616,0,($d1|0),($d2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = ($10|0)==(0);
     if ($13) {
      ;HEAP32[$agg$result+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$d1+12>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2635888|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2635888|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2770,($16|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
   }
   ;HEAP32[$L_3+0>>2]=0|0;HEAP32[$L_3+4>>2]=0|0;HEAP32[$L_3+8>>2]=0|0;HEAP32[$L_3+12>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(1767,($L_3|0),0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_3+12>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z37mscorlib_System_Decimal_m_decimalMultP22mscorlib_System_ObjectP23mscorlib_System_DecimalS2_($__this,$pd1,$pd2) {
 $__this = $__this|0;
 $pd1 = $pd1|0;
 $pd2 = $pd2|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201504);
 $0 = HEAP32[2201552>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2201560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2201552>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($pd1|0),($pd2|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Decimal_m_DivideP22mscorlib_System_Object23mscorlib_System_DecimalS1_($agg$result,$__this,$d1,$d2) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_4 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_0 = sp;
 $L_4 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2199960);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 __THREW__ = 0;
 $0 = (invoke_ii(1824,($d2|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    __THREW__ = 0;
    (invoke_ii(2996,(2597304|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2597304|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2704,($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $14 = (invoke_ii(1824,($d1|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    if ($14) {
     ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;HEAP32[$L_4+12>>2]=0|0;
     __THREW__ = 0;
     invoke_vii(1767,($L_4|0),0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     ;HEAP32[$agg$result+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_4+12>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $19 = (invoke_iiiii(106,0,($V_0|0),($d1|0),($d2|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = ($19|0)==(0);
     if ($22) {
      ;HEAP32[$agg$result+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$V_0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$V_0+12>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2635888|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      $25 = (invoke_ii(3469,(2635888|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       invoke_vi(2770,($25|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3830,($25|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z36mscorlib_System_Decimal_m_decimalDivP22mscorlib_System_ObjectP23mscorlib_System_DecimalS2_S2_($__this,$pc,$pa,$pb) {
 $__this = $__this|0;
 $pc = $pc|0;
 $pa = $pa|0;
 $pb = $pb|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201624);
 $0 = HEAP32[2201672>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2201680|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2201672>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($pc|0),($pa|0),($pb|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Decimal_m_decimalCompareP22mscorlib_System_ObjectP23mscorlib_System_DecimalS2_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201760);
 $0 = HEAP32[2201808>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2201816|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2201808>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($d1|0),($d2|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Decimal_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_5 = 0, $L_5$byval_copy = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_5$byval_copy = sp + 40|0;
 $__this$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_5 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200056);
 __THREW__ = 0;
 invoke_v(430);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2206536|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2206536|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if (!($10)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2206536|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($value|0),(2206536|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      ;HEAP32[$L_5+0>>2]=HEAP32[$26+0>>2]|0;HEAP32[$L_5+4>>2]=HEAP32[$26+4>>2]|0;HEAP32[$L_5+8>>2]=HEAP32[$26+8>>2]|0;HEAP32[$L_5+12>>2]=HEAP32[$26+12>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
      ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$L_5$byval_copy+12>>2]=HEAP32[$L_5+12>>2]|0;
      $29 = (invoke_iiii(602,0,($__this$byval_copy|0),($L_5$byval_copy|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      } else {
       $$0 = $29;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $11 = HEAP32[3009456>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,0,($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(2560072|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vii(1924,($17|0),($12|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         invoke_vi(3830,($17|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Decimal_m_CompareTo_mscorlib_System_Int32_mscorlib_System_DecimalP23mscorlib_System_DecimalS_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $value$byval_copy = sp + 24|0;
 $__this$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200104);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iiii(602,0,($__this$byval_copy|0),($value$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z80mscorlib_System_Decimal_m_Equals_mscorlib_System_Boolean_mscorlib_System_DecimalP23mscorlib_System_DecimalS_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__this$byval_copy = sp + 24|0;
 $value$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200152);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iiii(599,0,($value$byval_copy|0),($__this$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z110mscorlib_System_Decimal_m_Parse_mscorlib_System_Decimal_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($agg$result,$__this,$s,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200200);
 __THREW__ = 0;
 invoke_viiiii(46,($agg$result|0),0,($s|0),111,($provider|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z36mscorlib_System_Decimal_m_ThrowAtPosP22mscorlib_System_Objecti($__this,$pos) {
 $__this = $__this|0;
 $pos = $pos|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200248);
 __THREW__ = 0;
 invoke_v(431);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3009536>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,0,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$L_1>>2] = $pos;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2724,(2155952|0),($L_1|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iiii(552,0,($3|0),($8|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2603176|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       $16 = (invoke_ii(3469,(2603176|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        invoke_vii(1940,($16|0),($11|0));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         invoke_vi(3830,($16|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
}
function __Z41mscorlib_System_Decimal_m_ThrowInvalidExpP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200296);
 __THREW__ = 0;
 invoke_v(432);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3009624>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,0,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2603176|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2603176|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vii(1940,($8|0),($3|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($8|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z37mscorlib_System_Decimal_m_stripStylesP22mscorlib_System_ObjectP22mscorlib_System_StringiP46mscorlib_System_Globalization_NumberFormatInfoPiPbS6_S5_b($__this,$s,$style,$nfi,$decPos,$isNegative,$expFlag,$exp,$throwex) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $nfi = $nfi|0;
 $decPos = $decPos|0;
 $isNegative = $isNegative|0;
 $expFlag = $expFlag|0;
 $exp = $exp|0;
 $throwex = $throwex|0;
 var $$0 = 0, $$013539 = 0, $$lcssa = 0, $$lcssa241 = 0, $$lcssa263 = 0, $$lobit = 0, $$lobit2 = 0, $$lobit3 = 0, $$lobit4 = 0, $$lobit5 = 0, $$lobit6 = 0, $$lobit7 = 0, $$not = 0, $$not18 = 0, $$not20 = 0, $$not24 = 0, $$not27 = 0, $$pn = 0, $$pn215 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B6_0$041 = 0, $G_B9_0$0 = 0, $V_0$0$off0$ph$ph110177 = 0, $V_0$0$off0$ph$ph110181 = 0;
 var $V_0$0$off0$ph$ph211 = 0, $V_0$1$off0$ph$ph140 = 0, $V_0$1$off0$ph$ph89129 = 0, $V_1$0$off0$ph$ph198 = 0, $V_1$1$off0$not = 0, $V_1$1$off0$ph$ph136 = 0, $V_1$1$off0$ph$ph139 = 0, $V_15$0$ph$ph109$be = 0, $V_15$0$ph$ph109180 = 0, $V_15$0$ph$ph209 = 0, $V_15$0$ph119 = 0, $V_15$0$ph121 = 0, $V_15$1$ph$be = 0, $V_15$1$ph$ph159 = 0, $V_15$1$ph106 = 0, $V_15$2 = 0, $V_15$3 = 0, $V_15$3$lcssa = 0, $V_15$353 = 0, $V_15$354 = 0;
 var $V_15$4$ph = 0, $V_15$4$ph47$ph138 = 0, $V_15$4$ph47$ph88$be = 0, $V_15$4$ph47$ph88128 = 0, $V_15$4$ph4796 = 0, $V_2$0$off0$ph$ph156 = 0, $V_2$0$off0$ph$ph160 = 0, $V_26$0$off0 = 0, $_stackTraceSentry = 0, $brmerge = 0, $brmerge16 = 0, $brmerge17 = 0, $brmerge19 = 0, $brmerge21 = 0, $brmerge23 = 0, $brmerge25 = 0, $brmerge28 = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0, $notlhs = 0;
 var $notlhs44 = 0, $notrhs = 0, $notrhs45 = 0, $or$cond$not = 0, $or$cond22$not = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200344);
 __THREW__ = 0;
 invoke_v(433);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   HEAP8[$isNegative>>0] = 0;
   HEAP8[$expFlag>>0] = 0;
   HEAP32[$exp>>2] = 0;
   HEAP32[$decPos>>2] = -1;
   $2 = $style & 1;
   $3 = ($2|0)==(0);
   $$lobit = $style & 2;
   $4 = ($$lobit|0)==(0);
   $$lobit2 = $style & 4;
   $5 = ($$lobit2|0)==(0);
   $$lobit3 = $style & 8;
   $6 = ($$lobit3|0)==(0);
   $$lobit4 = $style >>> 4;
   $$lobit5 = $style & 64;
   $7 = ($$lobit5|0)==(0);
   $$lobit6 = $style >>> 5;
   $$lobit7 = $style & 128;
   $8 = ($$lobit7|0)==(0);
   $9 = $style & 256;
   $10 = ($9|0)==(0);
   if ($10) {
    label = 24;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($nfi|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(2024,($nfi|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(632,($s|0),($27|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = ($32|0)<(0);
    if ($35) {
     label = 24;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($nfi|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     __THREW__ = 0;
     $38 = (invoke_ii(2024,($nfi|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($38|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     __THREW__ = 0;
     $43 = (invoke_ii(1816,($38|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($s|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     __THREW__ = 0;
     $48 = (invoke_iiii(551,($s|0),($32|0),($43|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($nfi|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     $53 = (invoke_ii(2019,($nfi|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($nfi|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      break;
     }
     __THREW__ = 0;
     $63 = (invoke_ii(2020,($nfi|0))|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     } else {
      $$013539 = $48;$G_B6_0$041 = $53;$G_B9_0$0 = $63;
     }
    }
   }
   if ((label|0) == 24) {
    __THREW__ = 0;
    invoke_vi(3799,($nfi|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    __THREW__ = 0;
    $58 = (invoke_ii(2031,($nfi|0))|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($nfi|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     break;
    }
    __THREW__ = 0;
    $68 = (invoke_ii(2032,($nfi|0))|0);
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     break;
    } else {
     $$013539 = $s;$G_B6_0$041 = $58;$G_B9_0$0 = $68;
    }
   }
   __THREW__ = 0;
   invoke_vi(3799,($$013539|0));
   $71 = __THREW__; __THREW__ = 0;
   $72 = $71&1;
   if (!($72)) {
    __THREW__ = 0;
    $73 = (invoke_ii(1816,($$013539|0))|0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if (!($75)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2537888|0))|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if (!($77)) {
      __THREW__ = 0;
      $78 = (invoke_ii(3469,(2537888|0))|0);
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if (!($80)) {
       __THREW__ = 0;
       invoke_vii(1910,($78|0),($73|0));
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if (!($82)) {
        $83 = ($73|0)>(0);
        L30: do {
         if ($83) {
          $84 = $$lobit4 & 1;
          $notlhs44 = ($84|0)==(0);
          $85 = $$lobit6 & 1;
          $86 = ($85|0)==(0);
          $V_0$0$off0$ph$ph211 = 0;$V_15$0$ph$ph209 = 0;
          L32: while(1) {
           $V_0$0$off0$ph$ph110181 = $V_0$0$off0$ph$ph211;$V_15$0$ph$ph109180 = $V_15$0$ph$ph209;
           L34: while(1) {
            $V_15$0$ph121 = $V_15$0$ph$ph109180;
            L36: while(1) {
             L38: while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($$013539|0));
              $187 = __THREW__; __THREW__ = 0;
              $188 = $187&1;
              if ($188) {
               label = 8;
               break L32;
              }
              __THREW__ = 0;
              $87 = (invoke_iii(621,($$013539|0),($V_15$0$ph121|0))|0);
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if ($89) {
               label = 8;
               break L32;
              }
              __THREW__ = 0;
              $90 = (invoke_iii(600,0,($87|0))|0);
              $91 = __THREW__; __THREW__ = 0;
              $92 = $91&1;
              if ($92) {
               label = 8;
               break L32;
              }
              if ($90) {
               $V_0$0$off0$ph$ph110177 = $V_0$0$off0$ph$ph110181;$V_1$0$off0$ph$ph198 = $V_0$0$off0$ph$ph211;$V_15$0$ph119 = $V_15$0$ph121;
               break L30;
              }
              if (!($3)) {
               __THREW__ = 0;
               $93 = (invoke_iii(604,0,($87|0))|0);
               $94 = __THREW__; __THREW__ = 0;
               $95 = $94&1;
               if ($95) {
                label = 8;
                break L32;
               }
               if ($93) {
                break;
               }
              }
              $notrhs45 = ($87<<16>>16)!=(40);
              $or$cond$not = $notrhs45 | $notlhs44;
              $brmerge = $or$cond$not | $V_0$0$off0$ph$ph110181;
              $brmerge16 = $brmerge | $V_0$0$off0$ph$ph211;
              if (!($brmerge16)) {
               break L34;
              }
              do {
               if (!($5)) {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if ($101) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                $102 = (invoke_ii(2029,($nfi|0))|0);
                $103 = __THREW__; __THREW__ = 0;
                $104 = $103&1;
                if ($104) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                invoke_vi(3799,($102|0));
                $105 = __THREW__; __THREW__ = 0;
                $106 = $105&1;
                if ($106) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                $107 = (invoke_iii(621,($102|0),0)|0);
                $108 = __THREW__; __THREW__ = 0;
                $109 = $108&1;
                if ($109) {
                 label = 8;
                 break L32;
                }
                $$not = ($87<<16>>16)!=($107<<16>>16);
                $brmerge17 = $$not | $V_0$0$off0$ph$ph110181;
                if (!($brmerge17)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($nfi|0));
                 $110 = __THREW__; __THREW__ = 0;
                 $111 = $110&1;
                 if ($111) {
                  label = 8;
                  break L32;
                 }
                 __THREW__ = 0;
                 $112 = (invoke_ii(2029,($nfi|0))|0);
                 $113 = __THREW__; __THREW__ = 0;
                 $114 = $113&1;
                 if ($114) {
                  label = 8;
                  break L32;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($112|0));
                 $115 = __THREW__; __THREW__ = 0;
                 $116 = $115&1;
                 if ($116) {
                  label = 8;
                  break L32;
                 }
                 __THREW__ = 0;
                 $117 = (invoke_ii(1816,($112|0))|0);
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  label = 8;
                  break L32;
                 }
                 $120 = ($117|0)==(1);
                 if ($120) {
                  $$lcssa263 = 1;
                  label = 64;
                  break L36;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($nfi|0));
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  label = 8;
                  break L32;
                 }
                 __THREW__ = 0;
                 $123 = (invoke_ii(2029,($nfi|0))|0);
                 $124 = __THREW__; __THREW__ = 0;
                 $125 = $124&1;
                 if ($125) {
                  label = 8;
                  break L32;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$013539|0));
                 $126 = __THREW__; __THREW__ = 0;
                 $127 = $126&1;
                 if ($127) {
                  label = 8;
                  break L32;
                 }
                 __THREW__ = 0;
                 $128 = (invoke_iiiii(95,($$013539|0),($123|0),($V_15$0$ph121|0),($117|0))|0);
                 $129 = __THREW__; __THREW__ = 0;
                 $130 = $129&1;
                 if ($130) {
                  label = 8;
                  break L32;
                 }
                 $131 = ($128|0)==($V_15$0$ph121|0);
                 if ($131) {
                  $$lcssa263 = $117;
                  label = 64;
                  break L36;
                 } else {
                  continue L38;
                 }
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $132 = __THREW__; __THREW__ = 0;
                $133 = $132&1;
                if ($133) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                $134 = (invoke_ii(2044,($nfi|0))|0);
                $135 = __THREW__; __THREW__ = 0;
                $136 = $135&1;
                if ($136) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                invoke_vi(3799,($134|0));
                $137 = __THREW__; __THREW__ = 0;
                $138 = $137&1;
                if ($138) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                $139 = (invoke_iii(621,($134|0),0)|0);
                $140 = __THREW__; __THREW__ = 0;
                $141 = $140&1;
                if ($141) {
                 label = 8;
                 break L32;
                }
                $$not18 = ($87<<16>>16)!=($139<<16>>16);
                $brmerge19 = $$not18 | $V_0$0$off0$ph$ph110181;
                if ($brmerge19) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $142 = __THREW__; __THREW__ = 0;
                $143 = $142&1;
                if ($143) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                $144 = (invoke_ii(2044,($nfi|0))|0);
                $145 = __THREW__; __THREW__ = 0;
                $146 = $145&1;
                if ($146) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                invoke_vi(3799,($144|0));
                $147 = __THREW__; __THREW__ = 0;
                $148 = $147&1;
                if ($148) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                $149 = (invoke_ii(1816,($144|0))|0);
                $150 = __THREW__; __THREW__ = 0;
                $151 = $150&1;
                if ($151) {
                 label = 8;
                 break L32;
                }
                $152 = ($149|0)==(1);
                if ($152) {
                 $$pn215 = 1;
                 break L36;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $153 = __THREW__; __THREW__ = 0;
                $154 = $153&1;
                if ($154) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                $155 = (invoke_ii(2044,($nfi|0))|0);
                $156 = __THREW__; __THREW__ = 0;
                $157 = $156&1;
                if ($157) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                invoke_vi(3799,($$013539|0));
                $158 = __THREW__; __THREW__ = 0;
                $159 = $158&1;
                if ($159) {
                 label = 8;
                 break L32;
                }
                __THREW__ = 0;
                $160 = (invoke_iiiii(95,($$013539|0),($155|0),($V_15$0$ph121|0),($149|0))|0);
                $161 = __THREW__; __THREW__ = 0;
                $162 = $161&1;
                if ($162) {
                 label = 8;
                 break L32;
                }
                $163 = ($160|0)==($V_15$0$ph121|0);
                if ($163) {
                 $$pn215 = $149;
                 break L36;
                } else {
                 continue L38;
                }
               }
              } while(0);
              if (!($86)) {
               __THREW__ = 0;
               invoke_vi(3799,($G_B6_0$041|0));
               $165 = __THREW__; __THREW__ = 0;
               $166 = $165&1;
               if ($166) {
                label = 8;
                break L32;
               }
               __THREW__ = 0;
               $167 = (invoke_iii(621,($G_B6_0$041|0),0)|0);
               $168 = __THREW__; __THREW__ = 0;
               $169 = $168&1;
               if ($169) {
                label = 8;
                break L32;
               }
               $170 = ($87<<16>>16)==($167<<16>>16);
               if ($170) {
                label = 86;
                break L32;
               }
              }
              if (!($throwex)) {
               $$0 = 0;
               label = 268;
               break L32;
              }
              __THREW__ = 0;
              invoke_vii(1769,0,($V_15$0$ph121|0));
              $185 = __THREW__; __THREW__ = 0;
              $186 = $185&1;
              if ($186) {
               label = 8;
               break L32;
              }
             }
             $96 = (($V_15$0$ph121) + 1)|0;
             $97 = ($96|0)<($73|0);
             if ($97) {
              $V_15$0$ph121 = $96;
             } else {
              $V_0$0$off0$ph$ph110177 = $V_0$0$off0$ph$ph110181;$V_1$0$off0$ph$ph198 = $V_0$0$off0$ph$ph211;$V_15$0$ph119 = $96;
              break L30;
             }
            }
            if ((label|0) == 64) {
             label = 0;
             HEAP8[$isNegative>>0] = 1;
             $$pn215 = $$lcssa263;
            }
            $V_15$0$ph$ph109$be = (($$pn215) + ($V_15$0$ph121))|0;
            $164 = ($V_15$0$ph$ph109$be|0)<($73|0);
            if ($164) {
             $V_0$0$off0$ph$ph110181 = 1;$V_15$0$ph$ph109180 = $V_15$0$ph$ph109$be;
            } else {
             $V_0$0$off0$ph$ph110177 = 1;$V_1$0$off0$ph$ph198 = $V_0$0$off0$ph$ph211;$V_15$0$ph119 = $V_15$0$ph$ph109$be;
             break L30;
            }
           }
           HEAP8[$isNegative>>0] = 1;
           $98 = (($V_15$0$ph121) + 1)|0;
           $99 = ($98|0)<($73|0);
           if ($99) {
            $V_0$0$off0$ph$ph211 = 1;$V_15$0$ph$ph209 = $98;
           } else {
            $V_0$0$off0$ph$ph110177 = 1;$V_1$0$off0$ph$ph198 = 1;$V_15$0$ph119 = $98;
            break L30;
           }
          }
          if ((label|0) == 8) {
           $21 = ___cxa_find_matching_catch()|0;
           $22 = tempRet0;
           $lpad$phi$index = $21;$lpad$phi$index7 = $22;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 86) {
           __THREW__ = 0;
           invoke_vi(3799,($G_B6_0$041|0));
           $171 = __THREW__; __THREW__ = 0;
           $172 = $171&1;
           if ($172) {
            break L1;
           }
           __THREW__ = 0;
           $173 = (invoke_ii(1816,($G_B6_0$041|0))|0);
           $174 = __THREW__; __THREW__ = 0;
           $175 = $174&1;
           if ($175) {
            break L1;
           }
           $176 = ($173|0)==(1);
           if ($176) {
            $V_0$0$off0$ph$ph110177 = $V_0$0$off0$ph$ph110181;$V_1$0$off0$ph$ph198 = $V_0$0$off0$ph$ph211;$V_15$0$ph119 = $V_15$0$ph121;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($$013539|0));
           $177 = __THREW__; __THREW__ = 0;
           $178 = $177&1;
           if ($178) {
            break L1;
           }
           __THREW__ = 0;
           $179 = (invoke_iiiii(95,($$013539|0),($G_B6_0$041|0),($V_15$0$ph121|0),($173|0))|0);
           $180 = __THREW__; __THREW__ = 0;
           $181 = $180&1;
           if ($181) {
            break L1;
           }
           $182 = ($179|0)==($V_15$0$ph121|0);
           if ($182) {
            $V_0$0$off0$ph$ph110177 = $V_0$0$off0$ph$ph110181;$V_1$0$off0$ph$ph198 = $V_0$0$off0$ph$ph211;$V_15$0$ph119 = $V_15$0$ph121;
            break;
           }
           if ($throwex) {
            __THREW__ = 0;
            invoke_vii(1769,0,($V_15$0$ph121|0));
            $183 = __THREW__; __THREW__ = 0;
            $184 = $183&1;
            if ($184) {
             break L1;
            } else {
             $V_0$0$off0$ph$ph110177 = $V_0$0$off0$ph$ph110181;$V_1$0$off0$ph$ph198 = $V_0$0$off0$ph$ph211;$V_15$0$ph119 = $V_15$0$ph121;
             break;
            }
           } else {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
          else if ((label|0) == 268) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         } else {
          $V_0$0$off0$ph$ph110177 = 0;$V_1$0$off0$ph$ph198 = 0;$V_15$0$ph119 = 0;
         }
        } while(0);
        $189 = ($V_15$0$ph119|0)==($73|0);
        if ($189) {
         if (!($throwex)) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $193 = HEAP32[3009672>>2]|0;
         __THREW__ = 0;
         $194 = (invoke_iii(783,0,($193|0))|0);
         $195 = __THREW__; __THREW__ = 0;
         $196 = $195&1;
         if ($196) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2603176|0))|0);
         $197 = __THREW__; __THREW__ = 0;
         $198 = $197&1;
         if ($198) {
          break;
         }
         __THREW__ = 0;
         $199 = (invoke_ii(3469,(2603176|0))|0);
         $200 = __THREW__; __THREW__ = 0;
         $201 = $200&1;
         if ($201) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(1940,($199|0),($194|0));
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3830,($199|0));
         $204 = __THREW__; __THREW__ = 0;
         $205 = $204&1;
         if ($205) {
          break;
         }
         // unreachable;
        }
        $190 = ($V_15$0$ph119|0)<($73|0);
        $191 = $$lobit6 & 1;
        $192 = ($191|0)==(0);
        L119: do {
         if ($190) {
          $V_15$1$ph$ph159 = $V_15$0$ph119;$V_2$0$off0$ph$ph160 = 0;
          L121: while(1) {
           $V_15$1$ph106 = $V_15$1$ph$ph159;
           L123: while(1) {
            while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($$013539|0));
             $263 = __THREW__; __THREW__ = 0;
             $264 = $263&1;
             if ($264) {
              label = 5;
              break L121;
             }
             __THREW__ = 0;
             $206 = (invoke_iii(621,($$013539|0),($V_15$1$ph106|0))|0);
             $207 = __THREW__; __THREW__ = 0;
             $208 = $207&1;
             if ($208) {
              label = 5;
              break L121;
             }
             __THREW__ = 0;
             $209 = (invoke_iii(600,0,($206|0))|0);
             $210 = __THREW__; __THREW__ = 0;
             $211 = $210&1;
             if ($211) {
              label = 5;
              break L121;
             }
             if ($209) {
              label = 110;
              break;
             }
             if (!($7)) {
              __THREW__ = 0;
              invoke_vi(3799,($G_B9_0$0|0));
              $218 = __THREW__; __THREW__ = 0;
              $219 = $218&1;
              if ($219) {
               label = 5;
               break L121;
              }
              __THREW__ = 0;
              $220 = (invoke_iii(621,($G_B9_0$0|0),0)|0);
              $221 = __THREW__; __THREW__ = 0;
              $222 = $221&1;
              if ($222) {
               label = 5;
               break L121;
              }
              $223 = ($206<<16>>16)==($220<<16>>16);
              if ($223) {
               label = 118;
               break;
              }
             }
             if ($192) {
              label = 143;
              break L121;
             }
             __THREW__ = 0;
             invoke_vi(3799,($G_B6_0$041|0));
             $239 = __THREW__; __THREW__ = 0;
             $240 = $239&1;
             if ($240) {
              label = 5;
              break L121;
             }
             __THREW__ = 0;
             $241 = (invoke_iii(621,($G_B6_0$041|0),0)|0);
             $242 = __THREW__; __THREW__ = 0;
             $243 = $242&1;
             if ($243) {
              label = 5;
              break L121;
             }
             $$not20 = ($206<<16>>16)!=($241<<16>>16);
             $brmerge21 = $$not20 | $V_2$0$off0$ph$ph160;
             if ($brmerge21) {
              label = 143;
              break L121;
             }
             __THREW__ = 0;
             invoke_vi(3799,($G_B6_0$041|0));
             $244 = __THREW__; __THREW__ = 0;
             $245 = $244&1;
             if ($245) {
              label = 5;
              break L121;
             }
             __THREW__ = 0;
             $246 = (invoke_ii(1816,($G_B6_0$041|0))|0);
             $247 = __THREW__; __THREW__ = 0;
             $248 = $247&1;
             if ($248) {
              label = 5;
              break L121;
             }
             $249 = ($246|0)==(1);
             if ($249) {
              $$lcssa241 = 1;
              break L123;
             }
             __THREW__ = 0;
             invoke_vi(3799,($$013539|0));
             $250 = __THREW__; __THREW__ = 0;
             $251 = $250&1;
             if ($251) {
              label = 5;
              break L121;
             }
             __THREW__ = 0;
             $252 = (invoke_iiiii(95,($$013539|0),($G_B6_0$041|0),($V_15$1$ph106|0),($246|0))|0);
             $253 = __THREW__; __THREW__ = 0;
             $254 = $253&1;
             if ($254) {
              label = 5;
              break L121;
             }
             $255 = ($252|0)==($V_15$1$ph106|0);
             if ($255) {
              $$lcssa241 = $246;
              break L123;
             }
            }
            if ((label|0) == 110) {
             label = 0;
             __THREW__ = 0;
             invoke_vi(3799,($78|0));
             $212 = __THREW__; __THREW__ = 0;
             $213 = $212&1;
             if ($213) {
              label = 6;
              break L121;
             }
             __THREW__ = 0;
             (invoke_iii(992,($78|0),($206|0))|0);
             $214 = __THREW__; __THREW__ = 0;
             $215 = $214&1;
             if ($215) {
              label = 6;
              break L121;
             }
             $216 = (($V_15$1$ph106) + 1)|0;
             $V_15$1$ph$be = $216;
            }
            else if ((label|0) == 118) {
             label = 0;
             __THREW__ = 0;
             invoke_vi(3799,($G_B9_0$0|0));
             $224 = __THREW__; __THREW__ = 0;
             $225 = $224&1;
             if ($225) {
              label = 6;
              break L121;
             }
             __THREW__ = 0;
             $226 = (invoke_ii(1816,($G_B9_0$0|0))|0);
             $227 = __THREW__; __THREW__ = 0;
             $228 = $227&1;
             if ($228) {
              label = 6;
              break L121;
             }
             $229 = ($226|0)==(1);
             do {
              if (!($229)) {
               __THREW__ = 0;
               invoke_vi(3799,($$013539|0));
               $230 = __THREW__; __THREW__ = 0;
               $231 = $230&1;
               if ($231) {
                label = 6;
                break L121;
               }
               __THREW__ = 0;
               $232 = (invoke_iiiii(95,($$013539|0),($G_B9_0$0|0),($V_15$1$ph106|0),($226|0))|0);
               $233 = __THREW__; __THREW__ = 0;
               $234 = $233&1;
               if ($234) {
                label = 6;
                break L121;
               }
               $235 = ($232|0)==($V_15$1$ph106|0);
               if ($235) {
                break;
               }
               if (!($throwex)) {
                $$0 = 0;
                label = 268;
                break L121;
               }
               __THREW__ = 0;
               invoke_vii(1769,0,($V_15$1$ph106|0));
               $236 = __THREW__; __THREW__ = 0;
               $237 = $236&1;
               if ($237) {
                label = 6;
                break L121;
               }
              }
             } while(0);
             $238 = (($226) + ($V_15$1$ph106))|0;
             $V_15$1$ph$be = $238;
            }
            $217 = ($V_15$1$ph$be|0)<($73|0);
            if ($217) {
             $V_15$1$ph106 = $V_15$1$ph$be;
            } else {
             $V_15$4$ph = $V_15$1$ph$be;$V_2$0$off0$ph$ph156 = $V_2$0$off0$ph$ph160;
             break L119;
            }
           }
           __THREW__ = 0;
           invoke_vi(3799,($78|0));
           $256 = __THREW__; __THREW__ = 0;
           $257 = $256&1;
           if ($257) {
            label = 7;
            break;
           }
           __THREW__ = 0;
           $258 = (invoke_ii(2398,($78|0))|0);
           $259 = __THREW__; __THREW__ = 0;
           $260 = $259&1;
           if ($260) {
            label = 7;
            break;
           }
           HEAP32[$decPos>>2] = $258;
           $261 = (($$lcssa241) + ($V_15$1$ph106))|0;
           $262 = ($261|0)<($73|0);
           if ($262) {
            $V_15$1$ph$ph159 = $261;$V_2$0$off0$ph$ph160 = 1;
           } else {
            $V_15$4$ph = $261;$V_2$0$off0$ph$ph156 = 1;
            break L119;
           }
          }
          if ((label|0) == 5) {
           $15 = ___cxa_find_matching_catch()|0;
           $16 = tempRet0;
           $lpad$phi$index = $15;$lpad$phi$index7 = $16;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 6) {
           $17 = ___cxa_find_matching_catch()|0;
           $18 = tempRet0;
           $lpad$phi$index = $17;$lpad$phi$index7 = $18;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 7) {
           $19 = ___cxa_find_matching_catch()|0;
           $20 = tempRet0;
           $lpad$phi$index = $19;$lpad$phi$index7 = $20;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 143) {
           __THREW__ = 0;
           invoke_vi(3799,($$013539|0));
           $265 = __THREW__; __THREW__ = 0;
           $266 = $265&1;
           if ($266) {
            break L1;
           }
           __THREW__ = 0;
           $267 = (invoke_iii(621,($$013539|0),($V_15$1$ph106|0))|0);
           $268 = __THREW__; __THREW__ = 0;
           $269 = $268&1;
           if ($269) {
            break L1;
           }
           if ($8) {
            $V_15$4$ph = $V_15$1$ph106;$V_2$0$off0$ph$ph156 = $V_2$0$off0$ph$ph160;
            break;
           }
           __THREW__ = 0;
           $270 = (invoke_iii(607,0,($267|0))|0);
           $271 = __THREW__; __THREW__ = 0;
           $272 = $271&1;
           if ($272) {
            break L1;
           }
           $273 = ($270<<16>>16)==(69);
           if (!($273)) {
            $V_15$4$ph = $V_15$1$ph106;$V_2$0$off0$ph$ph156 = $V_2$0$off0$ph$ph160;
            break;
           }
           HEAP8[$expFlag>>0] = 1;
           $274 = (($V_15$1$ph106) + 1)|0;
           $275 = ($274|0)<($73|0);
           do {
            if (!($275)) {
             if ($throwex) {
              __THREW__ = 0;
              invoke_vi(1975,0);
              $276 = __THREW__; __THREW__ = 0;
              $277 = $276&1;
              if ($277) {
               break L1;
              } else {
               break;
              }
             } else {
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(3799,($$013539|0));
           $278 = __THREW__; __THREW__ = 0;
           $279 = $278&1;
           if ($279) {
            break L1;
           }
           __THREW__ = 0;
           $280 = (invoke_iii(621,($$013539|0),($274|0))|0);
           $281 = __THREW__; __THREW__ = 0;
           $282 = $281&1;
           if ($282) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3799,($nfi|0));
           $283 = __THREW__; __THREW__ = 0;
           $284 = $283&1;
           if ($284) {
            break L1;
           }
           __THREW__ = 0;
           $285 = (invoke_ii(2044,($nfi|0))|0);
           $286 = __THREW__; __THREW__ = 0;
           $287 = $286&1;
           if ($287) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3799,($285|0));
           $288 = __THREW__; __THREW__ = 0;
           $289 = $288&1;
           if ($289) {
            break L1;
           }
           __THREW__ = 0;
           $290 = (invoke_iii(621,($285|0),0)|0);
           $291 = __THREW__; __THREW__ = 0;
           $292 = $291&1;
           if ($292) {
            break L1;
           }
           $293 = ($280<<16>>16)==($290<<16>>16);
           do {
            if ($293) {
             __THREW__ = 0;
             invoke_vi(3799,($nfi|0));
             $294 = __THREW__; __THREW__ = 0;
             $295 = $294&1;
             if ($295) {
              break L1;
             }
             __THREW__ = 0;
             $296 = (invoke_ii(2044,($nfi|0))|0);
             $297 = __THREW__; __THREW__ = 0;
             $298 = $297&1;
             if ($298) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3799,($296|0));
             $299 = __THREW__; __THREW__ = 0;
             $300 = $299&1;
             if ($300) {
              break L1;
             }
             __THREW__ = 0;
             $301 = (invoke_ii(1816,($296|0))|0);
             $302 = __THREW__; __THREW__ = 0;
             $303 = $302&1;
             if ($303) {
              break L1;
             }
             $304 = ($301|0)==(1);
             if (!($304)) {
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $305 = __THREW__; __THREW__ = 0;
              $306 = $305&1;
              if ($306) {
               break L1;
              }
              __THREW__ = 0;
              $307 = (invoke_ii(2044,($nfi|0))|0);
              $308 = __THREW__; __THREW__ = 0;
              $309 = $308&1;
              if ($309) {
               break L1;
              }
              __THREW__ = 0;
              invoke_vi(3799,($$013539|0));
              $310 = __THREW__; __THREW__ = 0;
              $311 = $310&1;
              if ($311) {
               break L1;
              }
              __THREW__ = 0;
              $312 = (invoke_iiiii(95,($$013539|0),($307|0),($274|0),($301|0))|0);
              $313 = __THREW__; __THREW__ = 0;
              $314 = $313&1;
              if ($314) {
               break L1;
              }
              $315 = ($312|0)==($274|0);
              if (!($315)) {
               $V_15$2 = $274;$V_26$0$off0 = 0;
               break;
              }
             }
             $316 = (($301) + ($274))|0;
             $317 = ($316|0)<($73|0);
             if ($317) {
              $V_15$2 = $316;$V_26$0$off0 = 0;
              break;
             }
             if ($throwex) {
              __THREW__ = 0;
              invoke_vi(1975,0);
              $318 = __THREW__; __THREW__ = 0;
              $319 = $318&1;
              if ($319) {
               break L1;
              } else {
               $V_15$2 = $316;$V_26$0$off0 = 0;
               break;
              }
             } else {
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($nfi|0));
             $320 = __THREW__; __THREW__ = 0;
             $321 = $320&1;
             if ($321) {
              break L1;
             }
             __THREW__ = 0;
             $322 = (invoke_ii(2029,($nfi|0))|0);
             $323 = __THREW__; __THREW__ = 0;
             $324 = $323&1;
             if ($324) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3799,($322|0));
             $325 = __THREW__; __THREW__ = 0;
             $326 = $325&1;
             if ($326) {
              break L1;
             }
             __THREW__ = 0;
             $327 = (invoke_iii(621,($322|0),0)|0);
             $328 = __THREW__; __THREW__ = 0;
             $329 = $328&1;
             if ($329) {
              break L1;
             }
             $330 = ($280<<16>>16)==($327<<16>>16);
             if (!($330)) {
              $V_15$2 = $274;$V_26$0$off0 = 0;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($nfi|0));
             $331 = __THREW__; __THREW__ = 0;
             $332 = $331&1;
             if ($332) {
              break L1;
             }
             __THREW__ = 0;
             $333 = (invoke_ii(2029,($nfi|0))|0);
             $334 = __THREW__; __THREW__ = 0;
             $335 = $334&1;
             if ($335) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3799,($333|0));
             $336 = __THREW__; __THREW__ = 0;
             $337 = $336&1;
             if ($337) {
              break L1;
             }
             __THREW__ = 0;
             $338 = (invoke_ii(1816,($333|0))|0);
             $339 = __THREW__; __THREW__ = 0;
             $340 = $339&1;
             if ($340) {
              break L1;
             }
             $341 = ($338|0)==(1);
             if (!($341)) {
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $342 = __THREW__; __THREW__ = 0;
              $343 = $342&1;
              if ($343) {
               break L1;
              }
              __THREW__ = 0;
              $344 = (invoke_ii(2029,($nfi|0))|0);
              $345 = __THREW__; __THREW__ = 0;
              $346 = $345&1;
              if ($346) {
               break L1;
              }
              __THREW__ = 0;
              invoke_vi(3799,($$013539|0));
              $347 = __THREW__; __THREW__ = 0;
              $348 = $347&1;
              if ($348) {
               break L1;
              }
              __THREW__ = 0;
              $349 = (invoke_iiiii(95,($$013539|0),($344|0),($274|0),($338|0))|0);
              $350 = __THREW__; __THREW__ = 0;
              $351 = $350&1;
              if ($351) {
               break L1;
              }
              $352 = ($349|0)==($274|0);
              if (!($352)) {
               $V_15$2 = $274;$V_26$0$off0 = 0;
               break;
              }
             }
             $353 = (($338) + ($274))|0;
             $354 = ($353|0)<($73|0);
             if ($354) {
              $V_15$2 = $353;$V_26$0$off0 = 1;
              break;
             }
             if ($throwex) {
              __THREW__ = 0;
              invoke_vi(1975,0);
              $355 = __THREW__; __THREW__ = 0;
              $356 = $355&1;
              if ($356) {
               break L1;
              } else {
               $V_15$2 = $353;$V_26$0$off0 = 1;
               break;
              }
             } else {
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(3799,($$013539|0));
           $357 = __THREW__; __THREW__ = 0;
           $358 = $357&1;
           if ($358) {
            break L1;
           }
           __THREW__ = 0;
           $359 = (invoke_iii(621,($$013539|0),($V_15$2|0))|0);
           $360 = __THREW__; __THREW__ = 0;
           $361 = $360&1;
           if ($361) {
            break L1;
           }
           __THREW__ = 0;
           $362 = (invoke_iii(600,0,($359|0))|0);
           $363 = __THREW__; __THREW__ = 0;
           $364 = $363&1;
           if ($364) {
            break L1;
           }
           do {
            if (!($362)) {
             if ($throwex) {
              __THREW__ = 0;
              invoke_vi(1975,0);
              $365 = __THREW__; __THREW__ = 0;
              $366 = $365&1;
              if ($366) {
               break L1;
              } else {
               break;
              }
             } else {
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           } while(0);
           $367 = $359&65535;
           $368 = (($367) + 65488)|0;
           $369 = $368 & 65535;
           HEAP32[$exp>>2] = $369;
           $V_15$353 = (($V_15$2) + 1)|0;
           $370 = ($V_15$353|0)<($73|0);
           L236: do {
            if ($370) {
             $V_15$354 = $V_15$353;
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($$013539|0));
              $380 = __THREW__; __THREW__ = 0;
              $381 = $380&1;
              if ($381) {
               break;
              }
              __THREW__ = 0;
              $382 = (invoke_iii(621,($$013539|0),($V_15$354|0))|0);
              $383 = __THREW__; __THREW__ = 0;
              $384 = $383&1;
              if ($384) {
               break;
              }
              __THREW__ = 0;
              $385 = (invoke_iii(600,0,($382|0))|0);
              $386 = __THREW__; __THREW__ = 0;
              $387 = $386&1;
              if ($387) {
               break;
              }
              if (!($385)) {
               $V_15$3$lcssa = $V_15$354;
               break L236;
              }
              $388 = HEAP32[$exp>>2]|0;
              $378 = ($388*10)|0;
              HEAP32[$exp>>2] = $378;
              __THREW__ = 0;
              invoke_vi(3799,($$013539|0));
              $389 = __THREW__; __THREW__ = 0;
              $390 = $389&1;
              if ($390) {
               break;
              }
              __THREW__ = 0;
              $371 = (invoke_iii(621,($$013539|0),($V_15$354|0))|0);
              $372 = __THREW__; __THREW__ = 0;
              $373 = $372&1;
              if ($373) {
               break;
              }
              $374 = $371&65535;
              $375 = (($374) + 65488)|0;
              $376 = $375 & 65535;
              $377 = (($376) + ($378))|0;
              HEAP32[$exp>>2] = $377;
              $V_15$3 = (($V_15$354) + 1)|0;
              $379 = ($V_15$3|0)<($73|0);
              if ($379) {
               $V_15$354 = $V_15$3;
              } else {
               $V_15$3$lcssa = $V_15$3;
               break L236;
              }
             }
             $13 = ___cxa_find_matching_catch()|0;
             $14 = tempRet0;
             $lpad$phi$index = $13;$lpad$phi$index7 = $14;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            } else {
             $V_15$3$lcssa = $V_15$353;
            }
           } while(0);
           if (!($V_26$0$off0)) {
            $V_15$4$ph = $V_15$3$lcssa;$V_2$0$off0$ph$ph156 = $V_2$0$off0$ph$ph160;
            break;
           }
           $391 = HEAP32[$exp>>2]|0;
           $392 = (0 - ($391))|0;
           HEAP32[$exp>>2] = $392;
           $V_15$4$ph = $V_15$3$lcssa;$V_2$0$off0$ph$ph156 = $V_2$0$off0$ph$ph160;
           break;
          }
          else if ((label|0) == 268) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         } else {
          $V_15$4$ph = $V_15$0$ph119;$V_2$0$off0$ph$ph156 = 0;
         }
        } while(0);
        $393 = ($V_15$4$ph|0)<($73|0);
        L251: do {
         if ($393) {
          $394 = $$lobit4 & 1;
          $notlhs = ($394|0)==(0);
          $V_0$1$off0$ph$ph140 = $V_0$0$off0$ph$ph110177;$V_1$1$off0$ph$ph139 = $V_1$0$off0$ph$ph198;$V_15$4$ph47$ph138 = $V_15$4$ph;
          L253: while(1) {
           $V_1$1$off0$not = $V_1$1$off0$ph$ph139 ^ 1;
           $V_0$1$off0$ph$ph89129 = $V_0$1$off0$ph$ph140;$V_15$4$ph47$ph88128 = $V_15$4$ph47$ph138;
           L255: while(1) {
            $V_15$4$ph4796 = $V_15$4$ph47$ph88128;
            L257: while(1) {
             L259: while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($$013539|0));
              $472 = __THREW__; __THREW__ = 0;
              $473 = $472&1;
              if ($473) {
               break L253;
              }
              __THREW__ = 0;
              $395 = (invoke_iii(621,($$013539|0),($V_15$4$ph4796|0))|0);
              $396 = __THREW__; __THREW__ = 0;
              $397 = $396&1;
              if ($397) {
               break L253;
              }
              if (!($4)) {
               __THREW__ = 0;
               $398 = (invoke_iii(604,0,($395|0))|0);
               $399 = __THREW__; __THREW__ = 0;
               $400 = $399&1;
               if ($400) {
                break L253;
               }
               if ($398) {
                break;
               }
              }
              $notrhs = ($395<<16>>16)!=(41);
              $or$cond22$not = $notrhs | $notlhs;
              $brmerge23 = $or$cond22$not | $V_1$1$off0$not;
              if (!($brmerge23)) {
               break L255;
              }
              do {
               if (!($6)) {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $405 = __THREW__; __THREW__ = 0;
                $406 = $405&1;
                if ($406) {
                 break L253;
                }
                __THREW__ = 0;
                $407 = (invoke_ii(2029,($nfi|0))|0);
                $408 = __THREW__; __THREW__ = 0;
                $409 = $408&1;
                if ($409) {
                 break L253;
                }
                __THREW__ = 0;
                invoke_vi(3799,($407|0));
                $410 = __THREW__; __THREW__ = 0;
                $411 = $410&1;
                if ($411) {
                 break L253;
                }
                __THREW__ = 0;
                $412 = (invoke_iii(621,($407|0),0)|0);
                $413 = __THREW__; __THREW__ = 0;
                $414 = $413&1;
                if ($414) {
                 break L253;
                }
                $$not24 = ($395<<16>>16)!=($412<<16>>16);
                $brmerge25 = $$not24 | $V_0$1$off0$ph$ph89129;
                if (!($brmerge25)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($nfi|0));
                 $415 = __THREW__; __THREW__ = 0;
                 $416 = $415&1;
                 if ($416) {
                  break L253;
                 }
                 __THREW__ = 0;
                 $417 = (invoke_ii(2029,($nfi|0))|0);
                 $418 = __THREW__; __THREW__ = 0;
                 $419 = $418&1;
                 if ($419) {
                  break L253;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($417|0));
                 $420 = __THREW__; __THREW__ = 0;
                 $421 = $420&1;
                 if ($421) {
                  break L253;
                 }
                 __THREW__ = 0;
                 $422 = (invoke_ii(1816,($417|0))|0);
                 $423 = __THREW__; __THREW__ = 0;
                 $424 = $423&1;
                 if ($424) {
                  break L253;
                 }
                 $425 = ($422|0)==(1);
                 if ($425) {
                  $$lcssa = 1;
                  label = 232;
                  break L257;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($nfi|0));
                 $426 = __THREW__; __THREW__ = 0;
                 $427 = $426&1;
                 if ($427) {
                  break L253;
                 }
                 __THREW__ = 0;
                 $428 = (invoke_ii(2029,($nfi|0))|0);
                 $429 = __THREW__; __THREW__ = 0;
                 $430 = $429&1;
                 if ($430) {
                  break L253;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$013539|0));
                 $431 = __THREW__; __THREW__ = 0;
                 $432 = $431&1;
                 if ($432) {
                  break L253;
                 }
                 __THREW__ = 0;
                 $433 = (invoke_iiiii(95,($$013539|0),($428|0),($V_15$4$ph4796|0),($422|0))|0);
                 $434 = __THREW__; __THREW__ = 0;
                 $435 = $434&1;
                 if ($435) {
                  break L253;
                 }
                 $436 = ($433|0)==($V_15$4$ph4796|0);
                 if ($436) {
                  $$lcssa = $422;
                  label = 232;
                  break L257;
                 } else {
                  continue L259;
                 }
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $437 = __THREW__; __THREW__ = 0;
                $438 = $437&1;
                if ($438) {
                 break L253;
                }
                __THREW__ = 0;
                $439 = (invoke_ii(2044,($nfi|0))|0);
                $440 = __THREW__; __THREW__ = 0;
                $441 = $440&1;
                if ($441) {
                 break L253;
                }
                __THREW__ = 0;
                invoke_vi(3799,($439|0));
                $442 = __THREW__; __THREW__ = 0;
                $443 = $442&1;
                if ($443) {
                 break L253;
                }
                __THREW__ = 0;
                $444 = (invoke_iii(621,($439|0),0)|0);
                $445 = __THREW__; __THREW__ = 0;
                $446 = $445&1;
                if ($446) {
                 break L253;
                }
                $$not27 = ($395<<16>>16)!=($444<<16>>16);
                $brmerge28 = $$not27 | $V_0$1$off0$ph$ph89129;
                if ($brmerge28) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $447 = __THREW__; __THREW__ = 0;
                $448 = $447&1;
                if ($448) {
                 break L253;
                }
                __THREW__ = 0;
                $449 = (invoke_ii(2044,($nfi|0))|0);
                $450 = __THREW__; __THREW__ = 0;
                $451 = $450&1;
                if ($451) {
                 break L253;
                }
                __THREW__ = 0;
                invoke_vi(3799,($449|0));
                $452 = __THREW__; __THREW__ = 0;
                $453 = $452&1;
                if ($453) {
                 break L253;
                }
                __THREW__ = 0;
                $454 = (invoke_ii(1816,($449|0))|0);
                $455 = __THREW__; __THREW__ = 0;
                $456 = $455&1;
                if ($456) {
                 break L253;
                }
                $457 = ($454|0)==(1);
                if ($457) {
                 $$pn = 1;
                 break L257;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $458 = __THREW__; __THREW__ = 0;
                $459 = $458&1;
                if ($459) {
                 break L253;
                }
                __THREW__ = 0;
                $460 = (invoke_ii(2044,($nfi|0))|0);
                $461 = __THREW__; __THREW__ = 0;
                $462 = $461&1;
                if ($462) {
                 break L253;
                }
                __THREW__ = 0;
                invoke_vi(3799,($$013539|0));
                $463 = __THREW__; __THREW__ = 0;
                $464 = $463&1;
                if ($464) {
                 break L253;
                }
                __THREW__ = 0;
                $465 = (invoke_iiiii(95,($$013539|0),($460|0),($V_15$4$ph4796|0),($454|0))|0);
                $466 = __THREW__; __THREW__ = 0;
                $467 = $466&1;
                if ($467) {
                 break L253;
                }
                $468 = ($465|0)==($V_15$4$ph4796|0);
                if ($468) {
                 $$pn = $454;
                 break L257;
                } else {
                 continue L259;
                }
               }
              } while(0);
              if (!($throwex)) {
               $$0 = 0;
               label = 268;
               break L253;
              }
              __THREW__ = 0;
              invoke_vii(1769,0,($V_15$4$ph4796|0));
              $470 = __THREW__; __THREW__ = 0;
              $471 = $470&1;
              if ($471) {
               break L253;
              }
             }
             $401 = (($V_15$4$ph4796) + 1)|0;
             $402 = ($401|0)<($73|0);
             if ($402) {
              $V_15$4$ph4796 = $401;
             } else {
              $V_1$1$off0$ph$ph136 = $V_1$1$off0$ph$ph139;
              label = 253;
              break L251;
             }
            }
            if ((label|0) == 232) {
             label = 0;
             HEAP8[$isNegative>>0] = 1;
             $$pn = $$lcssa;
            }
            $V_15$4$ph47$ph88$be = (($$pn) + ($V_15$4$ph4796))|0;
            $469 = ($V_15$4$ph47$ph88$be|0)<($73|0);
            if ($469) {
             $V_0$1$off0$ph$ph89129 = 1;$V_15$4$ph47$ph88128 = $V_15$4$ph47$ph88$be;
            } else {
             $V_1$1$off0$ph$ph136 = $V_1$1$off0$ph$ph139;
             label = 253;
             break L251;
            }
           }
           $403 = (($V_15$4$ph4796) + 1)|0;
           $404 = ($403|0)<($73|0);
           if ($404) {
            $V_0$1$off0$ph$ph140 = $V_0$1$off0$ph$ph89129;$V_1$1$off0$ph$ph139 = 0;$V_15$4$ph47$ph138 = $403;
           } else {
            break L251;
           }
          }
          if ((label|0) == 268) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          $11 = ___cxa_find_matching_catch()|0;
          $12 = tempRet0;
          $lpad$phi$index = $11;$lpad$phi$index7 = $12;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         } else {
          $V_1$1$off0$ph$ph136 = $V_1$0$off0$ph$ph198;
          label = 253;
         }
        } while(0);
        if ((label|0) == 253) {
         if ($V_1$1$off0$ph$ph136) {
          if (!($throwex)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          $474 = HEAP32[3009680>>2]|0;
          __THREW__ = 0;
          $475 = (invoke_iii(783,0,($474|0))|0);
          $476 = __THREW__; __THREW__ = 0;
          $477 = $476&1;
          if ($477) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2603176|0))|0);
          $478 = __THREW__; __THREW__ = 0;
          $479 = $478&1;
          if ($479) {
           break;
          }
          __THREW__ = 0;
          $480 = (invoke_ii(3469,(2603176|0))|0);
          $481 = __THREW__; __THREW__ = 0;
          $482 = $481&1;
          if ($482) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1940,($480|0),($475|0));
          $483 = __THREW__; __THREW__ = 0;
          $484 = $483&1;
          if ($484) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3830,($480|0));
          $485 = __THREW__; __THREW__ = 0;
          $486 = $485&1;
          if ($486) {
           break;
          }
          // unreachable;
         }
        }
        if (!($V_2$0$off0$ph$ph156)) {
         __THREW__ = 0;
         invoke_vi(3799,($78|0));
         $487 = __THREW__; __THREW__ = 0;
         $488 = $487&1;
         if ($488) {
          break;
         }
         __THREW__ = 0;
         $489 = (invoke_ii(2398,($78|0))|0);
         $490 = __THREW__; __THREW__ = 0;
         $491 = $490&1;
         if ($491) {
          break;
         }
         HEAP32[$decPos>>2] = $489;
        }
        __THREW__ = 0;
        invoke_vi(3799,($78|0));
        $492 = __THREW__; __THREW__ = 0;
        $493 = $492&1;
        if (!($493)) {
         __THREW__ = 0;
         $494 = (invoke_iii(2730,(2535432|0),($78|0))|0);
         $495 = __THREW__; __THREW__ = 0;
         $496 = $495&1;
         if (!($496)) {
          $$0 = $494;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $lpad$phi$index = $23;$lpad$phi$index7 = $24;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_Decimal_m_PerformParseP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_P23mscorlib_System_Decimalb($__this,$s,$style,$provider,$res,$throwex) {
 $__this = $__this|0;
 $s = $s|0;
 $style = $style|0;
 $provider = $provider|0;
 $res = $res|0;
 $throwex = $throwex|0;
 var $$ = 0, $$$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $L_3 = 0, $L_86 = 0, $L_9 = 0, $L_91 = 0, $V_1 = 0, $V_12$0$in13 = 0, $V_12$022 = 0, $V_12$022$in = 0, $V_14 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $V_6$0$lcssa = 0, $V_6$028 = 0, $V_7$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $or$cond = 0, $or$cond44 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $_stackTraceSentry = sp + 88|0;
 $V_1 = sp + 80|0;
 $V_2 = sp + 84|0;
 $V_3 = sp + 92|0;
 $V_4 = sp + 93|0;
 $V_14 = sp + 64|0;
 $L_3 = sp + 32|0;
 $L_9 = sp + 16|0;
 $L_86 = sp;
 $L_91 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200440);
 HEAP32[$V_1>>2] = 0;
 HEAP32[$V_2>>2] = 0;
 HEAP8[$V_3>>0] = 0;
 HEAP8[$V_4>>0] = 0;
 ;HEAP32[$V_14+0>>2]=0|0;HEAP32[$V_14+4>>2]=0|0;HEAP32[$V_14+8>>2]=0|0;HEAP32[$V_14+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(434);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(867,(0|0),($provider|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iiiiiiiiii(3,0,($s|0),($style|0),($2|0),($V_1|0),($V_3|0),($V_4|0),($V_2|0),($throwex|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = ($5|0)==(0|0);
     if ($8) {
      ;HEAP32[$L_3+0>>2]=0|0;HEAP32[$L_3+4>>2]=0|0;HEAP32[$L_3+8>>2]=0|0;HEAP32[$L_3+12>>2]=0|0;
      __THREW__ = 0;
      invoke_vii(1767,($L_3|0),0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      ;HEAP32[$res+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$res+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$res+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$res+12>>2]=HEAP32[$L_3+12>>2]|0;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $17 = HEAP32[$V_1>>2]|0;
     $18 = ($17|0)>(-1);
     if (!($18)) {
      if (!($throwex)) {
       ;HEAP32[$L_9+0>>2]=0|0;HEAP32[$L_9+4>>2]=0|0;HEAP32[$L_9+8>>2]=0|0;HEAP32[$L_9+12>>2]=0|0;
       __THREW__ = 0;
       invoke_vii(1767,($L_9|0),0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       ;HEAP32[$res+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$res+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$res+8>>2]=HEAP32[$L_9+8>>2]|0;HEAP32[$res+12>>2]=HEAP32[$L_9+12>>2]|0;
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $19 = HEAP32[3009944>>2]|0;
      __THREW__ = 0;
      $20 = (invoke_iii(783,0,($19|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2246120|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      $25 = (invoke_ii(3469,(2246120|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1781,($25|0),($20|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($25|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      __THREW__ = 0;
      $36 = (invoke_ii(1816,($5|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = ($17|0)>(0);
       if ($39) {
        $V_6$028 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($5|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 6;
          break;
         }
         __THREW__ = 0;
         $44 = (invoke_iii(621,($5|0),($V_6$028|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 6;
          break;
         }
         $47 = ($44<<16>>16)==(48);
         $41 = (($V_6$028) + 1)|0;
         if (!($47)) {
          $V_6$0$lcssa = $V_6$028;
          break;
         }
         $40 = ($41|0)<($17|0);
         if ($40) {
          $V_6$028 = $41;
         } else {
          $V_6$0$lcssa = $41;
          break;
         }
        }
        if ((label|0) == 6) {
         $11 = ___cxa_find_matching_catch()|0;
         $12 = tempRet0;
         $lpad$phi$index = $11;$lpad$phi$index3 = $12;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        $48 = ($V_6$0$lcssa|0)<(2);
        $49 = ($36|0)<(2);
        $or$cond = $48 | $49;
        if ($or$cond) {
         $$01 = $5;$58 = $17;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($5|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          break;
         }
         $52 = (($36) - ($V_6$0$lcssa))|0;
         __THREW__ = 0;
         $53 = (invoke_iiii(528,($5|0),($V_6$0$lcssa|0),($52|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break;
         }
         $56 = (($17) - ($V_6$0$lcssa))|0;
         HEAP32[$V_1>>2] = $56;
         $$01 = $53;$58 = $56;
        }
       } else {
        $$01 = $5;$58 = $17;
       }
       $57 = ($58|0)==(0);
       $$ = $57 ? 27 : 28;
       __THREW__ = 0;
       invoke_vi(3799,($$01|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if (!($60)) {
        __THREW__ = 0;
        $61 = (invoke_ii(1816,($$01|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if (!($63)) {
         $64 = (($$) + 1)|0;
         $65 = ($61|0)<($64|0);
         if ($65) {
          $V_7$0 = $$;
         } else {
          __THREW__ = 0;
          $66 = (invoke_ii(1982,(0|0))|0);
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           break;
          }
          $69 = HEAP32[3009952>>2]|0;
          __THREW__ = 0;
          $70 = (invoke_iiiiiiiii(9,0,($$01|0),0,($69|0),0,($64|0),0,($66|0))|0);
          $71 = __THREW__; __THREW__ = 0;
          $72 = $71&1;
          if ($72) {
           break;
          }
          $73 = ($70|0)>(0);
          $$$ = $73 ? $$ : $64;
          $V_7$0 = $$$;
         }
         $74 = ($61|0)>($V_7$0|0);
         $75 = ($58|0)<($61|0);
         $or$cond44 = $74 & $75;
         L46: do {
          if ($or$cond44) {
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $76 = __THREW__; __THREW__ = 0;
           $77 = $76&1;
           if ($77) {
            break L1;
           }
           __THREW__ = 0;
           $78 = (invoke_iii(621,($$01|0),($V_7$0|0))|0);
           $79 = __THREW__; __THREW__ = 0;
           $80 = $79&1;
           if ($80) {
            break L1;
           }
           $81 = $78&65535;
           $82 = (($81) + 65488)|0;
           $83 = $82 & 65535;
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            break L1;
           }
           __THREW__ = 0;
           $86 = (invoke_iiii(528,($$01|0),0,($V_7$0|0))|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            break L1;
           }
           $89 = ($83>>>0)<(6);
           do {
            if ($89) {
             $90 = ($83|0)==(5);
             if (!($90)) {
              $$1 = $86;$199 = $58;
              break L46;
             }
             $91 = HEAP8[$V_3>>0]|0;
             $92 = ($91<<24>>24)==(0);
             if (!($92)) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($86|0));
             $93 = __THREW__; __THREW__ = 0;
             $94 = $93&1;
             if ($94) {
              break L1;
             }
             $95 = (($V_7$0) + -1)|0;
             __THREW__ = 0;
             $96 = (invoke_iii(621,($86|0),($95|0))|0);
             $97 = __THREW__; __THREW__ = 0;
             $98 = $97&1;
             if ($98) {
              break L1;
             }
             $99 = $96 & 1;
             $100 = ($99<<16>>16)==(0);
             if ($100) {
              $$1 = $86;$199 = $58;
              break L46;
             }
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(3799,($86|0));
           $101 = __THREW__; __THREW__ = 0;
           $102 = $101&1;
           if ($102) {
            break L1;
           }
           __THREW__ = 0;
           $103 = (invoke_ii(1811,($86|0))|0);
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            break L1;
           }
           $106 = (($103) + 16|0);
           $107 = (($103) + 12|0);
           $V_12$022$in = $V_7$0;
           while(1) {
            $V_12$022 = (($V_12$022$in) + -1)|0;
            __THREW__ = 0;
            invoke_vi(3799,($103|0));
            $170 = __THREW__; __THREW__ = 0;
            $171 = $170&1;
            if ($171) {
             label = 5;
             break;
            }
            $108 = ($V_12$022$in|0)<(1);
            if ($108) {
             label = 54;
            } else {
             $109 = HEAP32[$107>>2]|0;
             $110 = ($V_12$022>>>0)<($109>>>0);
             if (!($110)) {
              label = 54;
             }
            }
            if ((label|0) == 54) {
             label = 0;
             __THREW__ = 0;
             $111 = (invoke_i(132)|0);
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if ($113) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($111|0));
             $114 = __THREW__; __THREW__ = 0;
             $115 = $114&1;
             if ($115) {
              label = 5;
              break;
             }
            }
            $116 = HEAP32[$103>>2]|0;
            $117 = (($116) + 92|0);
            $118 = HEAP32[$117>>2]|0;
            $119 = Math_imul($118, $V_12$022)|0;
            $120 = (($106) + ($119)|0);
            $121 = HEAP16[$120>>1]|0;
            $122 = $121&65535;
            __THREW__ = 0;
            invoke_vi(3799,($103|0));
            $123 = __THREW__; __THREW__ = 0;
            $124 = $123&1;
            if ($124) {
             label = 5;
             break;
            }
            if ($108) {
             label = 59;
            } else {
             $125 = HEAP32[$107>>2]|0;
             $126 = ($V_12$022>>>0)<($125>>>0);
             if (!($126)) {
              label = 59;
             }
            }
            if ((label|0) == 59) {
             label = 0;
             __THREW__ = 0;
             $127 = (invoke_i(132)|0);
             $128 = __THREW__; __THREW__ = 0;
             $129 = $128&1;
             if ($129) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($127|0));
             $130 = __THREW__; __THREW__ = 0;
             $131 = $130&1;
             if ($131) {
              label = 5;
              break;
             }
            }
            $132 = HEAP32[$103>>2]|0;
            $133 = (($132) + 92|0);
            $134 = HEAP32[$133>>2]|0;
            $135 = Math_imul($134, $V_12$022)|0;
            $136 = (($106) + ($135)|0);
            $137 = HEAP16[$136>>1]|0;
            $138 = ($137<<16>>16)==(57);
            if (!($138)) {
             label = 62;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($103|0));
            $155 = __THREW__; __THREW__ = 0;
            $156 = $155&1;
            if ($156) {
             label = 5;
             break;
            }
            if ($108) {
             label = 71;
            } else {
             $157 = HEAP32[$107>>2]|0;
             $158 = ($V_12$022>>>0)<($157>>>0);
             if (!($158)) {
              label = 71;
             }
            }
            if ((label|0) == 71) {
             label = 0;
             __THREW__ = 0;
             $159 = (invoke_i(132)|0);
             $160 = __THREW__; __THREW__ = 0;
             $161 = $160&1;
             if ($161) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($159|0));
             $162 = __THREW__; __THREW__ = 0;
             $163 = $162&1;
             if ($163) {
              label = 5;
              break;
             }
            }
            $164 = HEAP32[$103>>2]|0;
            $165 = (($164) + 92|0);
            $166 = HEAP32[$165>>2]|0;
            $167 = Math_imul($166, $V_12$022)|0;
            $168 = (($106) + ($167)|0);
            HEAP16[$168>>1] = 48;
            $169 = ($V_12$022|0)>(0);
            if ($169) {
             $V_12$022$in = $V_12$022;
            } else {
             $V_12$0$in13 = $V_12$022;
             break;
            }
           }
           if ((label|0) == 5) {
            $9 = ___cxa_find_matching_catch()|0;
            $10 = tempRet0;
            $lpad$phi$index = $9;$lpad$phi$index3 = $10;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           if ((label|0) == 62) {
            $139 = (($122) + 1)|0;
            $140 = $139&65535;
            __THREW__ = 0;
            invoke_vi(3799,($103|0));
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             break L1;
            }
            if ($108) {
             label = 65;
            } else {
             $143 = HEAP32[$107>>2]|0;
             $144 = ($V_12$022>>>0)<($143>>>0);
             if (!($144)) {
              label = 65;
             }
            }
            if ((label|0) == 65) {
             __THREW__ = 0;
             $145 = (invoke_i(132)|0);
             $146 = __THREW__; __THREW__ = 0;
             $147 = $146&1;
             if ($147) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3302,($145|0));
             $148 = __THREW__; __THREW__ = 0;
             $149 = $148&1;
             if ($149) {
              break L1;
             }
            }
            $150 = HEAP32[$103>>2]|0;
            $151 = (($150) + 92|0);
            $152 = HEAP32[$151>>2]|0;
            $153 = Math_imul($152, $V_12$022)|0;
            $154 = (($106) + ($153)|0);
            HEAP16[$154>>1] = $140;
            $V_12$0$in13 = $V_12$022$in;
           }
           $172 = ($V_12$0$in13|0)==(0);
           do {
            if ($172) {
             __THREW__ = 0;
             invoke_vi(3799,($103|0));
             $173 = __THREW__; __THREW__ = 0;
             $174 = $173&1;
             if ($174) {
              break L1;
             }
             $175 = HEAP32[$107>>2]|0;
             $176 = ($175|0)==(0);
             if ($176) {
              __THREW__ = 0;
              $177 = (invoke_i(132)|0);
              $178 = __THREW__; __THREW__ = 0;
              $179 = $178&1;
              if ($179) {
               break L1;
              }
              __THREW__ = 0;
              invoke_vi(3302,($177|0));
              $180 = __THREW__; __THREW__ = 0;
              $181 = $180&1;
              if ($181) {
               break L1;
              }
             }
             $182 = HEAP16[$106>>1]|0;
             $183 = ($182<<16>>16)==(48);
             if (!($183)) {
              break;
             }
             $184 = (($58) + 1)|0;
             HEAP32[$V_1>>2] = $184;
             $185 = HEAP32[3009960>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($185|0));
             $186 = __THREW__; __THREW__ = 0;
             $187 = $186&1;
             if ($187) {
              break L1;
             }
             $188 = HEAP32[3009960>>2]|0;
             __THREW__ = 0;
             $189 = (invoke_iiii(544,($188|0),($184|0),48)|0);
             $190 = __THREW__; __THREW__ = 0;
             $191 = $190&1;
             if ($191) {
              break L1;
             } else {
              $$1 = $189;$199 = $184;
              break L46;
             }
            }
           } while(0);
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $192 = __THREW__; __THREW__ = 0;
           $193 = $192&1;
           if ($193) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(3469,(2191608|0))|0);
           $194 = __THREW__; __THREW__ = 0;
           $195 = $194&1;
           if ($195) {
            break L1;
           }
           __THREW__ = 0;
           $196 = (invoke_iii(642,0,($103|0))|0);
           $197 = __THREW__; __THREW__ = 0;
           $198 = $197&1;
           if ($198) {
            break L1;
           } else {
            $$1 = $196;$199 = $58;
           }
          } else {
           $$1 = $$01;$199 = $58;
          }
         } while(0);
         __THREW__ = 0;
         $200 = (invoke_iiiiii(92,0,($V_14|0),($$1|0),($199|0),0)|0);
         $201 = __THREW__; __THREW__ = 0;
         $202 = $201&1;
         if (!($202)) {
          $203 = ($200|0)==(0);
          if (!($203)) {
           if (!($throwex)) {
            ;HEAP32[$L_86+0>>2]=0|0;HEAP32[$L_86+4>>2]=0|0;HEAP32[$L_86+8>>2]=0|0;HEAP32[$L_86+12>>2]=0|0;
            __THREW__ = 0;
            invoke_vii(1767,($L_86|0),0);
            $213 = __THREW__; __THREW__ = 0;
            $214 = $213&1;
            if ($214) {
             break;
            }
            ;HEAP32[$res+0>>2]=HEAP32[$L_86+0>>2]|0;HEAP32[$res+4>>2]=HEAP32[$L_86+4>>2]|0;HEAP32[$res+8>>2]=HEAP32[$L_86+8>>2]|0;HEAP32[$res+12>>2]=HEAP32[$L_86+12>>2]|0;
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2635888|0))|0);
           $204 = __THREW__; __THREW__ = 0;
           $205 = $204&1;
           if ($205) {
            break;
           }
           __THREW__ = 0;
           $206 = (invoke_ii(3469,(2635888|0))|0);
           $207 = __THREW__; __THREW__ = 0;
           $208 = $207&1;
           if ($208) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(2770,($206|0));
           $209 = __THREW__; __THREW__ = 0;
           $210 = $209&1;
           if ($210) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3830,($206|0));
           $211 = __THREW__; __THREW__ = 0;
           $212 = $211&1;
           if ($212) {
            break;
           }
           // unreachable;
          }
          $215 = HEAP8[$V_4>>0]|0;
          $216 = ($215<<24>>24)==(0);
          if (!($216)) {
           $217 = HEAP32[$V_2>>2]|0;
           __THREW__ = 0;
           $218 = (invoke_iiii(615,0,($V_14|0),($217|0))|0);
           $219 = __THREW__; __THREW__ = 0;
           $220 = $219&1;
           if ($220) {
            break;
           }
           $221 = ($218|0)==(0);
           if (!($221)) {
            if (!($throwex)) {
             ;HEAP32[$L_91+0>>2]=0|0;HEAP32[$L_91+4>>2]=0|0;HEAP32[$L_91+8>>2]=0|0;HEAP32[$L_91+12>>2]=0|0;
             __THREW__ = 0;
             invoke_vii(1767,($L_91|0),0);
             $231 = __THREW__; __THREW__ = 0;
             $232 = $231&1;
             if ($232) {
              break;
             }
             ;HEAP32[$res+0>>2]=HEAP32[$L_91+0>>2]|0;HEAP32[$res+4>>2]=HEAP32[$L_91+4>>2]|0;HEAP32[$res+8>>2]=HEAP32[$L_91+8>>2]|0;HEAP32[$res+12>>2]=HEAP32[$L_91+12>>2]|0;
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2635888|0))|0);
            $222 = __THREW__; __THREW__ = 0;
            $223 = $222&1;
            if ($223) {
             break;
            }
            __THREW__ = 0;
            $224 = (invoke_ii(3469,(2635888|0))|0);
            $225 = __THREW__; __THREW__ = 0;
            $226 = $225&1;
            if ($226) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(2770,($224|0));
            $227 = __THREW__; __THREW__ = 0;
            $228 = $227&1;
            if ($228) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3830,($224|0));
            $229 = __THREW__; __THREW__ = 0;
            $230 = $229&1;
            if ($230) {
             break;
            }
            // unreachable;
           }
          }
          $233 = HEAP8[$V_3>>0]|0;
          $234 = ($233<<24>>24)==(0);
          if (!($234)) {
           $235 = HEAP32[$V_14>>2]|0;
           $236 = $235 ^ -2147483648;
           HEAP32[$V_14>>2] = $236;
          }
          ;HEAP32[$res+0>>2]=HEAP32[$V_14+0>>2]|0;HEAP32[$res+4>>2]=HEAP32[$V_14+4>>2]|0;HEAP32[$res+8>>2]=HEAP32[$V_14+8>>2]|0;HEAP32[$res+12>>2]=HEAP32[$V_14+12>>2]|0;
          $$0 = 1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Decimal_m_string2decimalP22mscorlib_System_ObjectP23mscorlib_System_DecimalP22mscorlib_System_Stringji($__this,$val,$sDigits,$decPos,$sign) {
 $__this = $__this|0;
 $val = $val|0;
 $sDigits = $sDigits|0;
 $decPos = $decPos|0;
 $sign = $sign|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200992);
 $0 = HEAP32[2201040>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2201048|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2201040>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiii($7|0,($val|0),($sDigits|0),($decPos|0),($sign|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_Decimal_m_decimalSetExponentP22mscorlib_System_ObjectP23mscorlib_System_Decimali($__this,$val,$exp) {
 $__this = $__this|0;
 $val = $val|0;
 $exp = $exp|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201144);
 $0 = HEAP32[2201192>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2201200|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2201192>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($val|0),($exp|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z112mscorlib_System_Decimal_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP23mscorlib_System_DecimalP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200488);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 $0 = (invoke_iiiii(195,(0|0),($format|0),($__this$byval_copy|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Decimal_m_ToString_mscorlib_System_StringP23mscorlib_System_Decimal($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200536);
 __THREW__ = 0;
 invoke_v(435);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3010112>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iiii(610,($__this|0),($2|0),(0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Decimal_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP23mscorlib_System_DecimalP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2200584);
 __THREW__ = 0;
 invoke_v(436);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3010136>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iiii(610,($__this|0),($2|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Decimal_m_decimal2doubleP22mscorlib_System_ObjectP23mscorlib_System_Decimal($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201272);
 $0 = HEAP32[2201320>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2201328|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2201320>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (+invoke_di($7|0,($val|0)));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$8);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return +0;
}
function __Z86mscorlib_System_Decimal_m_op_Increment_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($agg$result,$__this,$d) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d = $d|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, $d$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_1$byval_copy = sp + 40|0;
 $d$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201880);
 ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1767,($L_1|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$d$byval_copy+0>>2]=HEAP32[$d+0>>2]|0;HEAP32[$d$byval_copy+4>>2]=HEAP32[$d+4>>2]|0;HEAP32[$d$byval_copy+8>>2]=HEAP32[$d+8>>2]|0;HEAP32[$d$byval_copy+12>>2]=HEAP32[$d+12>>2]|0;
 ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_1$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
 invoke_viiii(126,($agg$result|0),0,($d$byval_copy|0),($L_1$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z112mscorlib_System_Decimal_m_op_Subtraction_mscorlib_System_Decimal_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_($agg$result,$__this,$d1,$d2) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, $d1$byval_copy = 0, $d2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $d2$byval_copy = sp + 24|0;
 $d1$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201928);
 __THREW__ = 0;
 ;HEAP32[$d1$byval_copy+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$d1$byval_copy+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$d1$byval_copy+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$d1$byval_copy+12>>2]=HEAP32[$d1+12>>2]|0;
 ;HEAP32[$d2$byval_copy+0>>2]=HEAP32[$d2+0>>2]|0;HEAP32[$d2$byval_copy+4>>2]=HEAP32[$d2+4>>2]|0;HEAP32[$d2$byval_copy+8>>2]=HEAP32[$d2+8>>2]|0;HEAP32[$d2$byval_copy+12>>2]=HEAP32[$d2+12>>2]|0;
 invoke_viiii(127,($agg$result|0),0,($d1$byval_copy|0),($d2$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z109mscorlib_System_Decimal_m_op_Multiply_mscorlib_System_Decimal_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_($agg$result,$__this,$d1,$d2) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, $d1$byval_copy = 0, $d2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $d2$byval_copy = sp + 24|0;
 $d1$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2201976);
 __THREW__ = 0;
 ;HEAP32[$d1$byval_copy+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$d1$byval_copy+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$d1$byval_copy+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$d1$byval_copy+12>>2]=HEAP32[$d1+12>>2]|0;
 ;HEAP32[$d2$byval_copy+0>>2]=HEAP32[$d2+0>>2]|0;HEAP32[$d2$byval_copy+4>>2]=HEAP32[$d2+4>>2]|0;HEAP32[$d2$byval_copy+8>>2]=HEAP32[$d2+8>>2]|0;HEAP32[$d2$byval_copy+12>>2]=HEAP32[$d2+12>>2]|0;
 invoke_viiii(128,($agg$result|0),0,($d1$byval_copy|0),($d2$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z109mscorlib_System_Decimal_m_op_Division_mscorlib_System_Decimal_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_($agg$result,$__this,$d1,$d2) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, $d1$byval_copy = 0, $d2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $d2$byval_copy = sp + 24|0;
 $d1$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202024);
 __THREW__ = 0;
 ;HEAP32[$d1$byval_copy+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$d1$byval_copy+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$d1$byval_copy+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$d1$byval_copy+12>>2]=HEAP32[$d1+12>>2]|0;
 ;HEAP32[$d2$byval_copy+0>>2]=HEAP32[$d2+0>>2]|0;HEAP32[$d2$byval_copy+4>>2]=HEAP32[$d2+4>>2]|0;HEAP32[$d2$byval_copy+8>>2]=HEAP32[$d2+8>>2]|0;HEAP32[$d2$byval_copy+12>>2]=HEAP32[$d2+12>>2]|0;
 invoke_viiii(129,($agg$result|0),0,($d1$byval_copy|0),($d2$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Byte_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202072);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iii(682,0,($value$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)>(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)>(255);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if (!($8)) {
   $16 = $0&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($16|0);
  }
  __THREW__ = 0;
  $9 = (invoke_i(133)|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   invoke_vi(3830,($9|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    // unreachable;
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_SByte_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202120);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iii(683,0,($value$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1|0)>(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)>(127);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if (!($8)) {
   $16 = $0&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($16|0);
  }
  __THREW__ = 0;
  $9 = (invoke_i(133)|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   invoke_vi(3830,($9|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    // unreachable;
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Int16_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202168);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iii(683,0,($value$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1|0)>(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)>(32767);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if (!($8)) {
   $16 = $0&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($16|0);
  }
  __THREW__ = 0;
  $9 = (invoke_i(133)|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   invoke_vi(3830,($9|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    // unreachable;
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt16_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202216);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iii(682,0,($value$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)>(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)>(65535);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if (!($8)) {
   $16 = $0&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($16|0);
  }
  __THREW__ = 0;
  $9 = (invoke_i(133)|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   invoke_vi(3830,($9|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    // unreachable;
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Int32_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202264);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iii(683,0,($value$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1|0)>(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)>(2147483647);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if (!($8)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
  __THREW__ = 0;
  $9 = (invoke_i(133)|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   invoke_vi(3830,($9|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    // unreachable;
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt32_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202312);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iii(682,0,($value$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)>(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)>(4294967295);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if (!($8)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
  __THREW__ = 0;
  $9 = (invoke_i(133)|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   invoke_vi(3830,($9|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    // unreachable;
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Int64_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202360);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iii(683,0,($value$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt64_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202408);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iii(682,0,($value$byval_copy|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z82mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_ByteP22mscorlib_System_Objecth($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202456);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 $0 = $value&255;
 __THREW__ = 0;
 invoke_vii(1767,($agg$result|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_SByteP22mscorlib_System_Objecta($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202504);
 $0 = $value << 24 >> 24;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1767,($agg$result|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_Int16P22mscorlib_System_Objects($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202552);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 $0 = $value << 16 >> 16;
 __THREW__ = 0;
 invoke_vii(1767,($agg$result|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt16P22mscorlib_System_Objectt($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202600);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 $0 = $value&65535;
 __THREW__ = 0;
 invoke_vii(1767,($agg$result|0),($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_Int32P22mscorlib_System_Objecti($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202648);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1767,($agg$result|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt32P22mscorlib_System_Objectj($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202696);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1768,($agg$result|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_Int64P22mscorlib_System_Objectx($agg$result,$__this,$0,$1) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202744);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(506,($agg$result|0),($0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt64P22mscorlib_System_Objecty($agg$result,$__this,$0,$1) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202792);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(507,($agg$result|0),($0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Decimal_mscorlib_System_SingleP22mscorlib_System_Objectf($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202840);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vif(108,($agg$result|0),(+$value));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Decimal_mscorlib_System_DoubleP22mscorlib_System_Objectd($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202888);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vid(1,($agg$result|0),(+$value));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Single_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202936);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (+invoke_dii(15,0,($value$byval_copy|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = Math_fround($0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($3));
 }
 return Math_fround(0);
}
function __Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Double_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2202984);
 __THREW__ = 0;
 $0 = (+invoke_dii(14,0,($value|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$0);
 }
 return +0;
}
function __Z111mscorlib_System_Decimal_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $d1$byval_copy = 0, $d2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $d2$byval_copy = sp + 24|0;
 $d1$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2203032);
 __THREW__ = 0;
 ;HEAP32[$d1$byval_copy+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$d1$byval_copy+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$d1$byval_copy+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$d1$byval_copy+12>>2]=HEAP32[$d1+12>>2]|0;
 ;HEAP32[$d2$byval_copy+0>>2]=HEAP32[$d2+0>>2]|0;HEAP32[$d2$byval_copy+4>>2]=HEAP32[$d2+4>>2]|0;HEAP32[$d2$byval_copy+8>>2]=HEAP32[$d2+8>>2]|0;HEAP32[$d2$byval_copy+12>>2]=HEAP32[$d2+12>>2]|0;
 $0 = (invoke_iiii(599,0,($d1$byval_copy|0),($d2$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = $0 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z109mscorlib_System_Decimal_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, $d1$byval_copy = 0, $d2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $d2$byval_copy = sp + 24|0;
 $d1$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2203080);
 __THREW__ = 0;
 ;HEAP32[$d1$byval_copy+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$d1$byval_copy+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$d1$byval_copy+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$d1$byval_copy+12>>2]=HEAP32[$d1+12>>2]|0;
 ;HEAP32[$d2$byval_copy+0>>2]=HEAP32[$d2+0>>2]|0;HEAP32[$d2$byval_copy+4>>2]=HEAP32[$d2+4>>2]|0;HEAP32[$d2$byval_copy+8>>2]=HEAP32[$d2+8>>2]|0;HEAP32[$d2$byval_copy+12>>2]=HEAP32[$d2+12>>2]|0;
 $0 = (invoke_iiii(599,0,($d1$byval_copy|0),($d2$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z112mscorlib_System_Decimal_m_op_GreaterThan_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $d1$byval_copy = 0, $d2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $d2$byval_copy = sp + 24|0;
 $d1$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2203128);
 __THREW__ = 0;
 ;HEAP32[$d1$byval_copy+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$d1$byval_copy+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$d1$byval_copy+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$d1$byval_copy+12>>2]=HEAP32[$d1+12>>2]|0;
 ;HEAP32[$d2$byval_copy+0>>2]=HEAP32[$d2+0>>2]|0;HEAP32[$d2$byval_copy+4>>2]=HEAP32[$d2+4>>2]|0;HEAP32[$d2$byval_copy+8>>2]=HEAP32[$d2+8>>2]|0;HEAP32[$d2$byval_copy+12>>2]=HEAP32[$d2+12>>2]|0;
 $0 = (invoke_iiii(602,0,($d1$byval_copy|0),($d2$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0|0)>(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z109mscorlib_System_Decimal_m_op_LessThan_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $d1$byval_copy = 0, $d2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $d2$byval_copy = sp + 24|0;
 $d1$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2203176);
 __THREW__ = 0;
 ;HEAP32[$d1$byval_copy+0>>2]=HEAP32[$d1+0>>2]|0;HEAP32[$d1$byval_copy+4>>2]=HEAP32[$d1+4>>2]|0;HEAP32[$d1$byval_copy+8>>2]=HEAP32[$d1+8>>2]|0;HEAP32[$d1$byval_copy+12>>2]=HEAP32[$d1+12>>2]|0;
 ;HEAP32[$d2$byval_copy+0>>2]=HEAP32[$d2+0>>2]|0;HEAP32[$d2$byval_copy+4>>2]=HEAP32[$d2+4>>2]|0;HEAP32[$d2$byval_copy+8>>2]=HEAP32[$d2+8>>2]|0;HEAP32[$d2$byval_copy+12>>2]=HEAP32[$d2+12>>2]|0;
 $0 = (invoke_iiii(602,0,($d1$byval_copy|0),($d2$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0|0)<(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker5I27mscorlib_System_Int32TraitsS0_S0_29mscorlib_System_BooleanTraits26mscorlib_System_ByteTraitsE6InvokeEPFvPviiibhES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = (($args) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP8[$13>>0]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$1,$4,$7,$11,$14);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker1I28mscorlib_System_UInt32TraitsE6InvokeEPFvPvjES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$1);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker1I27mscorlib_System_Int64TraitsE6InvokeEPFvPvxES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$3,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker1I28mscorlib_System_UInt64TraitsE6InvokeEPFvPvyES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$3,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker1I28mscorlib_System_DoubleTraitsE6InvokeEPFvPvdES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 FUNCTION_TABLE_vid[$action & 3]($obj,$1);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits29mscorlib_System_DecimalTraitsE6InvokeEPFPvS3_23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_DecimalTraitsS0_S0_E6InvokeEPF23mscorlib_System_DecimalPvS2_S2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits29mscorlib_System_DecimalTraitsE6InvokeEPFyPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = tempRet0;
 $3 = $ret;
 $4 = $3;
 HEAP32[$4>>2] = $1;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits29mscorlib_System_DecimalTraitsE6InvokeEPFxPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = tempRet0;
 $3 = $ret;
 $4 = $3;
 HEAP32[$4>>2] = $1;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits29mscorlib_System_DecimalTraitsS1_E6InvokeEPFbPv23mscorlib_System_DecimalS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 32|0;
 $$byval_copy = sp;
 $ret = sp + 48|0;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraitsS0_E6InvokeEPF23mscorlib_System_DecimalPvS2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits29mscorlib_System_DecimalTraitsS1_E6InvokeEPFiPv23mscorlib_System_DecimalS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 40|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 24|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits29mscorlib_System_DecimalTraitsE6InvokeEPFiPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits29mscorlib_System_DecimalTraitsE6InvokeEPFbPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_DecimalTraits17VoidPointerTraitsS1_E6InvokeEPF23mscorlib_System_DecimalPvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker8I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_S0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_S4_iS4_S4_S4_S4_S4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (FUNCTION_TABLE_iiiiiiiiii[$func & 15]($obj,$0,$3,$5,$7,$9,$11,$13,$17)|0);
 STACKTOP = sp;return ($18|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_DecimalTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPF23mscorlib_System_DecimalPvS5_iS5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiiii[$func & 255]($ret,$obj,$0,$3,$5);
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S1_S0_E6InvokeEPFbPvS4_iS4_S4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$5,$7,$11)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_28mscorlib_System_UInt32TraitsS0_E6InvokeEPFiPvS4_S4_jiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$5,$8)|0);
 HEAP32[$ret>>2] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S1_E6InvokeEPFiPvS3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits29mscorlib_System_DecimalTraitsE6InvokeEPFhPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP8[$ret>>0] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits29mscorlib_System_DecimalTraitsE6InvokeEPFaPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP8[$ret>>0] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits29mscorlib_System_DecimalTraitsE6InvokeEPFsPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP16[$ret>>1] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits29mscorlib_System_DecimalTraitsE6InvokeEPFtPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP16[$ret>>1] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits29mscorlib_System_DecimalTraitsE6InvokeEPFjPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits26mscorlib_System_ByteTraitsE6InvokeEPF23mscorlib_System_DecimalPvhES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits27mscorlib_System_SByteTraitsE6InvokeEPF23mscorlib_System_DecimalPvaES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits27mscorlib_System_Int16TraitsE6InvokeEPF23mscorlib_System_DecimalPvsES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_UInt16TraitsE6InvokeEPF23mscorlib_System_DecimalPvtES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits27mscorlib_System_Int32TraitsE6InvokeEPF23mscorlib_System_DecimalPviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_UInt32TraitsE6InvokeEPF23mscorlib_System_DecimalPvjES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits27mscorlib_System_Int64TraitsE6InvokeEPF23mscorlib_System_DecimalPvxES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$3,$6);
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_UInt64TraitsE6InvokeEPF23mscorlib_System_DecimalPvyES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$3,$6);
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_SingleTraitsE6InvokeEPF23mscorlib_System_DecimalPvfES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 FUNCTION_TABLE_viif[$func & 63]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_DoubleTraitsE6InvokeEPF23mscorlib_System_DecimalPvdES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 FUNCTION_TABLE_viid[$func & 7]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits29mscorlib_System_DecimalTraitsE6InvokeEPFfPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$tmpcast$byval_copy)));
 HEAPF32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits29mscorlib_System_DecimalTraitsE6InvokeEPFdPv23mscorlib_System_DecimalES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$tmpcast$byval_copy));
 HEAPF64[$ret>>3] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z54mscorlib_System_Decimal_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_Decimal_CustomAttributesCacheGenerator_MinValueP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252920)|0);
 __Z73mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributehhjjj($4,0,-1,-1,-1,-1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributehhjjj($__this,$scale,$sign,$hi,$mid,$low) {
 $__this = $__this|0;
 $scale = $scale|0;
 $sign = $sign|0;
 $hi = $hi|0;
 $mid = $mid|0;
 $low = $low|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2252528);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 }
 $2 = (($__this) + 8|0);
 HEAP8[$2>>0] = $scale;
 __THREW__ = 0;
 $3 = (invoke_iii(1007,(0|0),($sign|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $6 = (($__this) + 9|0);
  $7 = $3&1;
  HEAP8[$6>>0] = $7;
  $8 = (($__this) + 12|0);
  HEAP32[$8>>2] = $hi;
  $9 = (($__this) + 16|0);
  HEAP32[$9>>2] = $mid;
  $10 = (($__this) + 20|0);
  HEAP32[$10>>2] = $low;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z63mscorlib_System_Decimal_CustomAttributesCacheGenerator_MaxValueP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252920)|0);
 __Z73mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributehhjjj($4,0,0,-1,-1,-1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_Decimal_CustomAttributesCacheGenerator_MinusOneP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252920)|0);
 __Z73mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributehhjjj($4,0,-1,0,0,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Decimal_CustomAttributesCacheGenerator_OneP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252920)|0);
 __Z73mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributehhjjj($4,0,0,0,0,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_CompareP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z138mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_SByte_mscorlib_System_DecimalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt16_mscorlib_System_DecimalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt32_mscorlib_System_DecimalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt64_mscorlib_System_DecimalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z138mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z32mscorlib_System_Boolean_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2206672);
 __THREW__ = 0;
 invoke_v(437);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3010152>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2208584|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[((2208584 + 80|0))>>2]|0;
   HEAP32[$5>>2] = $2;
   $6 = HEAP32[3010160>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2208584|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[((2208584 + 80|0))>>2]|0;
    $10 = (($9) + 4|0);
    HEAP32[$10>>2] = $6;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z52mscorlib_System_Boolean_m_System_IConvertible_ToTypePbP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2206720);
 __THREW__ = 0;
 invoke_v(438);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($targetType|0)==(0|0);
   if (!($2)) {
    $15 = HEAP8[$__this>>0]|0;
    $16 = ($15<<24>>24)!=(0);
    $17 = $16&1;
    HEAP8[$L_2>>0] = $17;
    __THREW__ = 0;
    (invoke_ii(2996,(2208584|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_iii(2724,(2208584|0),($L_2|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    $23 = (invoke_iiiiii(126,(0|0),($20|0),($targetType|0),($provider|0),0)|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($23|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3010200>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Boolean_m_System_IConvertible_ToBooleanPbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2206768);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52mscorlib_System_Boolean_m_System_IConvertible_ToBytePbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2206816);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iii(1014,(0|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Boolean_m_System_IConvertible_ToCharPbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2206864);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Boolean_m_System_IConvertible_ToDateTimePbP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2206912);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z55mscorlib_System_Boolean_m_System_IConvertible_ToDecimalPbP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2206960);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 invoke_viii(651,($agg$result|0),(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_Boolean_m_System_IConvertible_ToDoublePbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207008);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (+invoke_dii(18,(0|0),($1|0)));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$2);
 }
 return +0;
}
function __Z53mscorlib_System_Boolean_m_System_IConvertible_ToInt16PbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207056);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iii(1028,(0|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Boolean_m_System_IConvertible_ToInt32PbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207104);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iii(1037,(0|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Boolean_m_System_IConvertible_ToInt64PbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207152);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iii(1046,(0|0),($1|0))|0);
 $3 = tempRet0;
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $3;
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Boolean_m_System_IConvertible_ToSBytePbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207200);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iii(1056,(0|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Boolean_m_System_IConvertible_ToSinglePbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207248);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (Math_fround(+(invoke_fii(24,(0|0),($1|0)))));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($2));
 }
 return Math_fround(0);
}
function __Z54mscorlib_System_Boolean_m_System_IConvertible_ToUInt16PbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207296);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iii(1064,(0|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Boolean_m_System_IConvertible_ToUInt32PbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207344);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iii(1072,(0|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Boolean_m_System_IConvertible_ToUInt64PbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207392);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iii(1080,(0|0),($1|0))|0);
 $3 = tempRet0;
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $3;
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z80mscorlib_System_Boolean_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPbP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $not$ = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207440);
 __THREW__ = 0;
 invoke_v(439);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($obj|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2208584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($obj|0),(2208584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $11 = HEAP32[3010216>>2]|0;
      __THREW__ = 0;
      $12 = (invoke_iii(783,0,($11|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(3469,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($17|0),($12|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2208584|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2753,($obj|0),(2208584|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP8[$26>>0]|0;
      $30 = HEAP8[$__this>>0]|0;
      $31 = ($30<<24>>24)!=(0);
      $32 = ($29<<24>>24)==(0);
      $or$cond = $31 & $32;
      if ($or$cond) {
       $$0 = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $33 = $30 << 24 >> 24;
      $34 = $29&255;
      $not$ = ($33|0)!=($34|0);
      $$ = $not$ << 31 >> 31;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Boolean_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPbP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207488);
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2208584|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2735,($obj|0),(2208584|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2208584|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_iii(2753,($obj|0),(2208584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP8[$11>>0]|0;
     $15 = HEAP8[$__this>>0]|0;
     $16 = ($15<<24>>24)==(0);
     $17 = $16&1;
     $18 = ($14<<24>>24)!=($17<<24>>24);
     $$0 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Boolean_m_CompareTo_mscorlib_System_Int32_mscorlib_System_BooleanPbb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207536);
 $0 = HEAP8[$__this>>0]|0;
 $1 = $0 << 24 >> 24;
 $2 = $value&1;
 $3 = ($1|0)==($2|0);
 if ($3) {
  $$0 = 0;
 } else {
  $4 = ($0<<24>>24)==(0);
  $$ = $4 ? -1 : 1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z80mscorlib_System_Boolean_m_Equals_mscorlib_System_Boolean_mscorlib_System_BooleanPbb($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207584);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 $tmp = $1 ^ $obj;
 $2 = $tmp ^ 1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z37mscorlib_System_Boolean_m_GetHashCodePb($__this) {
 $__this = $__this|0;
 var $$ = 0, $0 = 0, $_stackTraceSentry = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207632);
 $0 = HEAP8[$__this>>0]|0;
 $not$ = ($0<<24>>24)!=(0);
 $$ = $not$&1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z31mscorlib_System_Boolean_m_ParseP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207680);
 __THREW__ = 0;
 invoke_v(440);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3010280>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($value|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1812,($value|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2208584|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP8[((2208584 + 116|0))>>0]|0;
      $23 = ($22<<24>>24)==(0);
      if ($23) {
       __THREW__ = 0;
       (invoke_ii(2996,(2208584|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2208584|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3831,(2208584|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2208584|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       $32 = HEAP32[((2208584 + 80|0))>>2]|0;
       $33 = (($32) + 4|0);
       $34 = HEAP32[$33>>2]|0;
       __THREW__ = 0;
       $35 = (invoke_ii(1982,(0|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __THREW__ = 0;
        $38 = (invoke_iiiiii(86,0,($17|0),($34|0),1,($35|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($38|0)==(0);
         if ($41) {
          $$0 = 1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2208584|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          $44 = HEAP8[((2208584 + 116|0))>>0]|0;
          $45 = ($44<<24>>24)==(0);
          if ($45) {
           __THREW__ = 0;
           (invoke_ii(2996,(2208584|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if ($47) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2208584|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2208584|0));
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           if ($51) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2208584|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           $54 = HEAP32[((2208584 + 80|0))>>2]|0;
           $55 = HEAP32[$54>>2]|0;
           __THREW__ = 0;
           $56 = (invoke_ii(1982,(0|0))|0);
           $57 = __THREW__; __THREW__ = 0;
           $58 = $57&1;
           if (!($58)) {
            __THREW__ = 0;
            $59 = (invoke_iiiiii(86,0,($17|0),($55|0),1,($56|0))|0);
            $60 = __THREW__; __THREW__ = 0;
            $61 = $60&1;
            if (!($61)) {
             $62 = ($59|0)==(0);
             if ($62) {
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             $63 = HEAP32[3010288>>2]|0;
             __THREW__ = 0;
             $64 = (invoke_iii(783,0,($63|0))|0);
             $65 = __THREW__; __THREW__ = 0;
             $66 = $65&1;
             if (!($66)) {
              __THREW__ = 0;
              (invoke_ii(2996,(2603176|0))|0);
              $67 = __THREW__; __THREW__ = 0;
              $68 = $67&1;
              if (!($68)) {
               __THREW__ = 0;
               $69 = (invoke_ii(3469,(2603176|0))|0);
               $70 = __THREW__; __THREW__ = 0;
               $71 = $70&1;
               if (!($71)) {
                __THREW__ = 0;
                invoke_vii(1940,($69|0),($64|0));
                $72 = __THREW__; __THREW__ = 0;
                $73 = $72&1;
                if ($73) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3830,($69|0));
                $74 = __THREW__; __THREW__ = 0;
                $75 = $74&1;
                if ($75) {
                 break;
                }
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_Boolean_m_ToString_mscorlib_System_StringPb($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $G_B3_0$0$in$in = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207728);
 $0 = HEAP8[$__this>>0]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   __THREW__ = 0;
   (invoke_ii(2996,(2208584|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP8[((2208584 + 116|0))>>0]|0;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     __THREW__ = 0;
     (invoke_ii(2996,(2208584|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2208584|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2208584|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2208584|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = HEAP32[((2208584 + 80|0))>>2]|0;
     $G_B3_0$0$in$in = $30;
     $G_B3_0$0 = HEAP32[$G_B3_0$0$in$in>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2208584|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2208584 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2208584|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2208584|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2208584|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2208584|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2208584 + 80|0))>>2]|0;
     $17 = (($16) + 4|0);
     $G_B3_0$0$in$in = $17;
     $G_B3_0$0 = HEAP32[$G_B3_0$0$in$in>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Boolean_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPbP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2207776);
 __THREW__ = 0;
 $0 = (invoke_ii(1827,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFiPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraitsS0_E6InvokeEPFbPvbES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 $4 = $3&1;
 HEAP8[$ret>>0] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z54mscorlib_System_Boolean_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73mscorlib_System_IntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P22mscorlib_System_IntPtri($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2208720);
 $0 = $value;
 HEAP32[$__this>>2] = $0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_IntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_VoidU002A_ptrP22mscorlib_System_IntPtrPv($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2208768);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_IntPtr_m_System_Runtime_Serialization_ISerializable_GetObjectDataP22mscorlib_System_IntPtrP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2208816);
 __THREW__ = 0;
 invoke_v(441);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_ii(1830,($__this|0))|0);
    $16 = tempRet0;
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3010432>>2]|0;
    __THREW__ = 0;
    invoke_viiii(169,($info|0),($21|0),($15|0),($16|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3010424>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z32mscorlib_System_IntPtr_m_ToInt64P22mscorlib_System_IntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209008);
 __THREW__ = 0;
 (invoke_ii(1828,0)|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  $4 = HEAP32[$__this>>2]|0;
  $5 = $4;
  $6 = ($5|0)<(0);
  $7 = $6 << 31 >> 31;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z33mscorlib_System_IntPtr_m_get_SizeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2208864);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 4;
}
function __Z31mscorlib_System_IntPtr_m_EqualsP22mscorlib_System_IntPtrP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2208912);
 __THREW__ = 0;
 (invoke_ii(2996,(2210080|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2210080|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2210080|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2210080|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[$10>>2]|0;
     $14 = HEAP32[$__this>>2]|0;
     $15 = ($13|0)==($14|0);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_IntPtr_m_GetHashCodeP22mscorlib_System_IntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2208960);
 $0 = HEAP32[$__this>>2]|0;
 $1 = $0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z56mscorlib_System_IntPtr_m_ToString_mscorlib_System_StringP22mscorlib_System_IntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209056);
 __THREW__ = 0;
 $0 = (invoke_iii(714,($__this|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z79mscorlib_System_IntPtr_m_ToString_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_IntPtrP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209104);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 (invoke_ii(1828,0)|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $4 = HEAP32[$__this>>2]|0;
  $5 = $4;
  HEAP32[$V_0>>2] = $5;
  __THREW__ = 0;
  $6 = (invoke_iii(476,($V_0|0),($format|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($6|0);
  }
 }
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($2|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_IntPtr_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_IntPtr_mscorlib_System_IntPtrP22mscorlib_System_Object22mscorlib_System_IntPtrS1_($__this,$value1,$value2) {
 $__this = $__this|0;
 $value1 = $value1|0;
 $value2 = $value2|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209152);
 $0 = HEAP32[$value1>>2]|0;
 $1 = HEAP32[$value2>>2]|0;
 $2 = ($0|0)==($1|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z108mscorlib_System_IntPtr_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_IntPtr_mscorlib_System_IntPtrP22mscorlib_System_Object22mscorlib_System_IntPtrS1_($__this,$value1,$value2) {
 $__this = $__this|0;
 $value1 = $value1|0;
 $value2 = $value2|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209200);
 $0 = HEAP32[$value1>>2]|0;
 $1 = HEAP32[$value2>>2]|0;
 $2 = ($0|0)!=($1|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z81mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_IntPtr_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209248);
 HEAP32[$0>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1770,($0|0),($value|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  $3 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z89mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_IntPtr_mscorlib_System_VoidU002A_ptrP22mscorlib_System_ObjectPv($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209296);
 HEAP32[$0>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1771,($0|0),($value|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  $3 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z81mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_Int32_mscorlib_System_IntPtrP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209344);
 $0 = HEAP32[$value>>2]|0;
 $1 = $0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z89mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_VoidU002A_ptr_mscorlib_System_IntPtrP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2209392);
 $0 = HEAP32[$value>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_IntPtrTraitsS1_E6InvokeEPFbPv22mscorlib_System_IntPtrS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 4|0;
 $2 = HEAP32[$args>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = (($args) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$$byval_copy1)|0);
 $8 = $7&1;
 HEAP8[$ret>>0] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32TraitsE6InvokeEPF22mscorlib_System_IntPtrPviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2210080,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_IntPtrTraits17VoidPointerTraitsE6InvokeEPF22mscorlib_System_IntPtrPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2210080,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_IntPtrTraitsE6InvokeEPFiPv22mscorlib_System_IntPtrES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits28mscorlib_System_IntPtrTraitsE6InvokeEPFPvS3_22mscorlib_System_IntPtrES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z53mscorlib_System_IntPtr_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z127mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_VoidU002A_ptrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_get_SizeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_ToInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z160mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_IntPtr_mscorlib_System_IntPtrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z162mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_IntPtr_mscorlib_System_IntPtrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_IntPtr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z143mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_IntPtr_mscorlib_System_VoidU002A_ptrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z143mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_VoidU002A_ptr_mscorlib_System_IntPtrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Runtime_Serialization_ISerializable_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_UIntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_UInt64P23mscorlib_System_UIntPtry($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210512);
 __THREW__ = 0;
 invoke_v(442);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(1);
  $5 = ($1|0)==(1);
  $6 = ($0>>>0)<(0);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $26 = $0;
   HEAP32[$__this>>2] = $26;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(1837,0)|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP32[3010456>>2]|0;
   __THREW__ = 0;
   $14 = (invoke_iii(783,0,($13|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     $19 = (invoke_ii(3469,(2635888|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vii(1971,($19|0),($14|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vi(3830,($19|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z34mscorlib_System_UIntPtr_m_get_SizeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211040);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 4;
}
function __Z75mscorlib_System_UIntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_UInt32P23mscorlib_System_UIntPtrj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210560);
 $0 = $value;
 HEAP32[$__this>>2] = $0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_UIntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_VoidU002A_ptrP23mscorlib_System_UIntPtrPv($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210608);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z32mscorlib_System_UIntPtr_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210656);
 HEAP32[$L_1>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1772,($L_1|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2212032|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[((2212032 + 80|0))>>2]|0;
   $5 = HEAP32[$L_1>>2]|0;
   HEAP32[$4>>2] = $5;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z82mscorlib_System_UIntPtr_m_System_Runtime_Serialization_ISerializable_GetObjectDataP23mscorlib_System_UIntPtrP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210704);
 __THREW__ = 0;
 invoke_v(443);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if (!($2)) {
    $15 = HEAP32[$__this>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = $15;
    $19 = ($18|0)<(0);
    $20 = $19 << 31 >> 31;
    $21 = HEAP32[3010536>>2]|0;
    __THREW__ = 0;
    invoke_viiii(170,($info|0),($21|0),($18|0),($20|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3010528>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z32mscorlib_System_UIntPtr_m_EqualsP23mscorlib_System_UIntPtrP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210752);
 __THREW__ = 0;
 (invoke_ii(2996,(2212032|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2212032|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2212032|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2753,($obj|0),(2212032|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[$10>>2]|0;
     $14 = HEAP32[$__this>>2]|0;
     $15 = ($14|0)==($13|0);
     $$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_UIntPtr_m_GetHashCodeP23mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210800);
 $0 = HEAP32[$__this>>2]|0;
 $1 = $0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z34mscorlib_System_UIntPtr_m_ToUInt32P23mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210848);
 $0 = HEAP32[$__this>>2]|0;
 $1 = $0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z34mscorlib_System_UIntPtr_m_ToUInt64P23mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210896);
 $0 = HEAP32[$__this>>2]|0;
 $1 = $0;
 $2 = ($1|0)<(0);
 $3 = $2 << 31 >> 31;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $3;
 STACKTOP = sp;return ($1|0);
}
function __Z35mscorlib_System_UIntPtr_m_ToPointerP23mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210944);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z34mscorlib_System_UIntPtr_m_ToStringP23mscorlib_System_UIntPtr($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2210992);
 $0 = HEAP32[$__this>>2]|0;
 $1 = $0;
 HEAP32[$V_0>>2] = $1;
 __THREW__ = 0;
 $2 = (invoke_ii(1797,($V_0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z109mscorlib_System_UIntPtr_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_UIntPtr_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtrS1_($__this,$value1,$value2) {
 $__this = $__this|0;
 $value1 = $value1|0;
 $value2 = $value2|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211088);
 $0 = HEAP32[$value1>>2]|0;
 $1 = HEAP32[$value2>>2]|0;
 $2 = ($0|0)==($1|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z111mscorlib_System_UIntPtr_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_UIntPtr_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtrS1_($__this,$value1,$value2) {
 $__this = $__this|0;
 $value1 = $value1|0;
 $value2 = $value2|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211136);
 $0 = HEAP32[$value1>>2]|0;
 $1 = HEAP32[$value2>>2]|0;
 $2 = ($0|0)!=($1|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z84mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UInt64_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtr($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211184);
 $0 = HEAP32[$value>>2]|0;
 $1 = $0;
 $2 = ($1|0)<(0);
 $3 = $2 << 31 >> 31;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $3;
 STACKTOP = sp;return ($1|0);
}
function __Z84mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UInt32_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtr($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211232);
 $0 = HEAP32[$value>>2]|0;
 $1 = $0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z84mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UIntPtr_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $2 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211280);
 HEAP32[$2>>2] = 0;
 __THREW__ = 0;
 invoke_viii(522,($2|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  $5 = HEAP32[$2>>2]|0;
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z91mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UIntPtr_mscorlib_System_VoidU002A_ptrP22mscorlib_System_ObjectPv($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211328);
 HEAP32[$0>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1773,($0|0),($value|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  $3 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z91mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_VoidU002A_ptr_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtr($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211376);
 __THREW__ = 0;
 $0 = (invoke_ii(1835,($value|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z84mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UIntPtr_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2211424);
 HEAP32[$0>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1772,($0|0),($value|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  $3 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits29mscorlib_System_UIntPtrTraitsS1_E6InvokeEPFbPv23mscorlib_System_UIntPtrS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 4|0;
 $2 = HEAP32[$args>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = (($args) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$$byval_copy1)|0);
 $8 = $7&1;
 HEAP8[$ret>>0] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits29mscorlib_System_UIntPtrTraitsE6InvokeEPFyPv23mscorlib_System_UIntPtrES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $ret = sp;
 $0 = sp + 8|0;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 $4 = tempRet0;
 $5 = $ret;
 $6 = $5;
 HEAP32[$6>>2] = $3;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $4;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits29mscorlib_System_UIntPtrTraitsE6InvokeEPFjPv23mscorlib_System_UIntPtrES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_UIntPtrTraits28mscorlib_System_UInt64TraitsE6InvokeEPF23mscorlib_System_UIntPtrPvyES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2212032,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_UIntPtrTraits17VoidPointerTraitsE6InvokeEPF23mscorlib_System_UIntPtrPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2212032,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits29mscorlib_System_UIntPtrTraitsE6InvokeEPFPvS3_23mscorlib_System_UIntPtrES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_UIntPtrTraits28mscorlib_System_UInt32TraitsE6InvokeEPF23mscorlib_System_UIntPtrPvjES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2212032,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z54mscorlib_System_UIntPtr_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_UIntPtr_CustomAttributesCacheGenerator_mscorlib_System_UIntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_VoidU002A_ptrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_UIntPtr_CustomAttributesCacheGenerator_mscorlib_System_UIntPtr_m_ToPointerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z146mscorlib_System_UIntPtr_CustomAttributesCacheGenerator_mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UIntPtr_mscorlib_System_VoidU002A_ptrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z146mscorlib_System_UIntPtr_CustomAttributesCacheGenerator_mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_VoidU002A_ptr_mscorlib_System_UIntPtrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z49mscorlib_System_MulticastDelegate_m_GetObjectDataP33mscorlib_System_MulticastDelegateP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212168);
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 invoke_viii(525,($__this|0),($info|0),($tmpcast$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z40mscorlib_System_Delegate_m_GetObjectDataP24mscorlib_System_DelegateP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213480);
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 invoke_viiii(194,(0|0),($__this|0),($info|0),($tmpcast$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42mscorlib_System_MulticastDelegate_m_EqualsP33mscorlib_System_MulticastDelegateP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212216);
 __THREW__ = 0;
 $0 = (invoke_iii(729,($__this|0),($obj|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if (!($0)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2213056|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($obj|0),(2213056|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if ($10) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $11 = (($__this) + 44|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      $16 = (($7) + 44|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($17|0)==(0|0);
      $$0 = $18;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($7|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($7) + 44|0);
      $22 = HEAP32[$21>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($12|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       $25 = (invoke_iiii(1644,(2212216|0),($12|0),($22|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        $$0 = $25;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z33mscorlib_System_Delegate_m_EqualsP24mscorlib_System_DelegateP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213384);
 __THREW__ = 0;
 (invoke_ii(2996,(2214560|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($obj|0),(2214560|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if ($7) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($4|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($4) + 16|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($__this) + 16|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($13|0)==($15|0);
     if (!($16)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = (($4) + 20|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = (($__this) + 20|0);
      $22 = HEAP32[$21>>2]|0;
      HEAP32[$0>>2] = $20;
      HEAP32[$1>>2] = $22;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
      $23 = (invoke_iiii(643,0,($$byval_copy|0),($$byval_copy1|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       if (!($23)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        $28 = (($4) + 40|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = ($29|0)==(0|0);
        if ($30) {
         $31 = (($__this) + 40|0);
         $32 = HEAP32[$31>>2]|0;
         $33 = ($32|0)==(0|0);
         if ($33) {
          $$0 = 1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if (!($35)) {
         $36 = HEAP32[$28>>2]|0;
         $37 = ($36|0)==(0|0);
         if ($37) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $38 = (($__this) + 40|0);
         $39 = HEAP32[$38>>2]|0;
         $40 = ($39|0)==(0|0);
         if ($40) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$28>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($43|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if (!($45)) {
           $46 = (($43) + 8|0);
           $47 = HEAP32[$46>>2]|0;
           $48 = HEAP32[$38>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($48|0));
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if (!($50)) {
            $51 = (($48) + 8|0);
            $52 = HEAP32[$51>>2]|0;
            $53 = ($47|0)==($52|0);
            if (!($53)) {
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            invoke_vi(3799,($4|0));
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if (!($55)) {
             $56 = HEAP32[$28>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($56|0));
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if (!($58)) {
              $59 = (($56) + 12|0);
              $60 = HEAP32[$59>>2]|0;
              $61 = HEAP32[$38>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($61|0));
              $62 = __THREW__; __THREW__ = 0;
              $63 = $62&1;
              if ($63) {
               break;
              }
              $64 = (($61) + 12|0);
              $65 = HEAP32[$64>>2]|0;
              __THREW__ = 0;
              $66 = (invoke_iiii(574,0,($60|0),($65|0))|0);
              $67 = __THREW__; __THREW__ = 0;
              $68 = $67&1;
              if ($68) {
               break;
              } else {
               $$0 = $66;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_MulticastDelegate_m_GetHashCodeP33mscorlib_System_MulticastDelegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212264);
 __THREW__ = 0;
 $0 = (invoke_ii(1843,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z38mscorlib_System_Delegate_m_GetHashCodeP24mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213432);
 $0 = (($__this) + 20|0);
 __THREW__ = 0;
 $1 = (invoke_ii(1829,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($__this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $G_B3_0$0 = 0;
   $14 = $G_B3_0$0 ^ $1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($14|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($5|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   $11 = (invoke_iii(2729,(2148880|0),($5|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $G_B3_0$0 = $11;
    $14 = $G_B3_0$0 ^ $1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_MulticastDelegate_m_GetInvocationListP33mscorlib_System_MulticastDelegate($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0;
 var $V_0$16 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212312);
 __THREW__ = 0;
 $1 = (invoke_iii(2756,(2212360|0),($__this|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2213056|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_iii(2755,($1|0),(2213056|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vi(3799,($6|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = (($6) + 48|0);
      HEAP32[$11>>2] = 0;
      $V_0$0 = $6;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($V_0$0|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        label = 7;
        break;
       }
       $19 = (($V_0$0) + 44|0);
       $28 = HEAP32[$19>>2]|0;
       $29 = ($28|0)==(0|0);
       if ($29) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_0$0|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 7;
        break;
       }
       $18 = HEAP32[$19>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($18|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        label = 7;
        break;
       }
       $22 = (($18) + 48|0);
       HEAP32[$22>>2] = $V_0$0;
       __THREW__ = 0;
       invoke_vi(3799,($V_0$0|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        label = 7;
        break;
       }
       $25 = HEAP32[$19>>2]|0;
       $V_0$0 = $25;
      }
      if ((label|0) == 7) {
       $14 = ___cxa_find_matching_catch()|0;
       $15 = tempRet0;
       $lpad$phi$index = $14;$lpad$phi$index3 = $15;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vi(3799,($V_0$0|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       $34 = (($V_0$0) + 48|0);
       $35 = HEAP32[$34>>2]|0;
       $36 = ($35|0)==(0|0);
       if ($36) {
        __THREW__ = 0;
        invoke_vi(3799,($V_0$0|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        }
        __THREW__ = 0;
        $39 = (invoke_iii(2756,(2212360|0),($V_0$0|0))|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2213056|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        $44 = (invoke_iii(2755,($39|0),(2213056|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        $49 = (($44) + 44|0);
        HEAP32[$49>>2] = 0;
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        $52 = (($44) + 48|0);
        HEAP32[$52>>2] = 0;
        __THREW__ = 0;
        (invoke_ii(2996,(1220056|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __THREW__ = 0;
        $55 = (invoke_iii(2754,(1220056|0),1)|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
        $60 = (($55) + 12|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = ($61|0)==(0);
        if ($62) {
         __THREW__ = 0;
         $63 = (invoke_i(132)|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($63|0));
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($55|0),($44|0));
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         break;
        }
        $70 = (($55) + 16|0);
        HEAP32[$70>>2] = $44;
        $$0 = $55;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2304136|0))|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if (!($72)) {
        __THREW__ = 0;
        $73 = (invoke_ii(3469,(2304136|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if (!($75)) {
         __THREW__ = 0;
         invoke_vi(2153,($73|0));
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if (!($77)) {
          $78 = ($V_0$0|0)==(0|0);
          L39: do {
           if (!($78)) {
            $V_0$16 = $V_0$0;
            while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($V_0$16|0));
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             if ($103) {
              break;
             }
             __THREW__ = 0;
             $79 = (invoke_iii(2756,(2212360|0),($V_0$16|0))|0);
             $80 = __THREW__; __THREW__ = 0;
             $81 = $80&1;
             if ($81) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2213056|0))|0);
             $82 = __THREW__; __THREW__ = 0;
             $83 = $82&1;
             if ($83) {
              break;
             }
             __THREW__ = 0;
             $84 = (invoke_iii(2755,($79|0),(2213056|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if ($86) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($84|0));
             $87 = __THREW__; __THREW__ = 0;
             $88 = $87&1;
             if ($88) {
              break;
             }
             $89 = (($84) + 44|0);
             HEAP32[$89>>2] = 0;
             __THREW__ = 0;
             invoke_vi(3799,($84|0));
             $90 = __THREW__; __THREW__ = 0;
             $91 = $90&1;
             if ($91) {
              break;
             }
             $92 = (($84) + 48|0);
             HEAP32[$92>>2] = 0;
             __THREW__ = 0;
             invoke_vi(3799,($73|0));
             $93 = __THREW__; __THREW__ = 0;
             $94 = $93&1;
             if ($94) {
              break;
             }
             __THREW__ = 0;
             (invoke_iiii(1647,(2297624|0),($73|0),($84|0))|0);
             $95 = __THREW__; __THREW__ = 0;
             $96 = $95&1;
             if ($96) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($V_0$16|0));
             $97 = __THREW__; __THREW__ = 0;
             $98 = $97&1;
             if ($98) {
              break;
             }
             $99 = (($V_0$16) + 48|0);
             $100 = HEAP32[$99>>2]|0;
             $101 = ($100|0)==(0|0);
             if ($101) {
              break L39;
             } else {
              $V_0$16 = $100;
             }
            }
            $12 = ___cxa_find_matching_catch()|0;
            $13 = tempRet0;
            $lpad$phi$index = $12;$lpad$phi$index3 = $13;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
          } while(0);
          HEAP32[$0>>2] = 2094448;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
          $104 = (invoke_iii(772,0,($$byval_copy|0))|0);
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if (!($106)) {
           __THREW__ = 0;
           invoke_vi(3799,($73|0));
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if (!($108)) {
            __THREW__ = 0;
            $109 = (invoke_iiii(1645,(2299256|0),($73|0),($104|0))|0);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if (!($111)) {
             __THREW__ = 0;
             (invoke_ii(2996,(1220056|0))|0);
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if (!($113)) {
              __THREW__ = 0;
              $114 = (invoke_iii(2755,($109|0),(1220056|0))|0);
              $115 = __THREW__; __THREW__ = 0;
              $116 = $115&1;
              if (!($116)) {
               $$0 = $114;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 $lpad$phi$index = $16;$lpad$phi$index3 = $17;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker0I28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z47mscorlib_System_MulticastDelegate_m_CombineImplP33mscorlib_System_MulticastDelegateP24mscorlib_System_Delegate($__this,$follow) {
 $__this = $__this|0;
 $follow = $follow|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$011 = 0, $V_1$1 = 0, $V_1$1$in = 0, $V_2$0$lcssa = 0, $V_2$010 = 0, $V_2$1 = 0, $__this$pn = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212408);
 __THREW__ = 0;
 invoke_v(444);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1782,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($follow|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_ii(1782,($follow|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = ($2|0)==($7|0);
      if (!($10)) {
       $17 = HEAP32[3010568>>2]|0;
       __THREW__ = 0;
       $18 = (invoke_iii(783,0,($17|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       __THREW__ = 0;
       $23 = (invoke_ii(3469,(2560072|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(1924,($23|0),($18|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3830,($23|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vi(3799,($follow|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       __THREW__ = 0;
       $32 = (invoke_iii(2756,(2212360|0),($follow|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2213056|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         __THREW__ = 0;
         $37 = (invoke_iii(2755,($32|0),(2213056|0))|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if (!($39)) {
          __THREW__ = 0;
          invoke_vi(3799,($37|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if (!($41)) {
           __THREW__ = 0;
           invoke_vi(2012,($37|0));
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if (!($43)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2213056|0))|0);
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             __THREW__ = 0;
             $46 = (invoke_iii(2755,($follow|0),(2213056|0))|0);
             $47 = __THREW__; __THREW__ = 0;
             $48 = $47&1;
             if (!($48)) {
              __THREW__ = 0;
              invoke_vi(3799,($46|0));
              $49 = __THREW__; __THREW__ = 0;
              $50 = $49&1;
              if (!($50)) {
               $51 = (($46) + 44|0);
               $52 = HEAP32[$51>>2]|0;
               $53 = ($52|0)==(0|0);
               L23: do {
                if ($53) {
                 $V_2$0$lcssa = $37;
                } else {
                 $V_1$011 = $52;$V_2$010 = $37;
                 while(1) {
                  __THREW__ = 0;
                  invoke_vi(3799,($V_1$011|0));
                  $73 = __THREW__; __THREW__ = 0;
                  $74 = $73&1;
                  if ($74) {
                   break;
                  }
                  __THREW__ = 0;
                  $54 = (invoke_iii(2756,(2212360|0),($V_1$011|0))|0);
                  $55 = __THREW__; __THREW__ = 0;
                  $56 = $55&1;
                  if ($56) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2213056|0))|0);
                  $57 = __THREW__; __THREW__ = 0;
                  $58 = $57&1;
                  if ($58) {
                   break;
                  }
                  __THREW__ = 0;
                  $59 = (invoke_iii(2755,($54|0),(2213056|0))|0);
                  $60 = __THREW__; __THREW__ = 0;
                  $61 = $60&1;
                  if ($61) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($V_2$010|0));
                  $62 = __THREW__; __THREW__ = 0;
                  $63 = $62&1;
                  if ($63) {
                   break;
                  }
                  $64 = (($V_2$010) + 44|0);
                  HEAP32[$64>>2] = $59;
                  __THREW__ = 0;
                  invoke_vi(3799,($V_2$010|0));
                  $65 = __THREW__; __THREW__ = 0;
                  $66 = $65&1;
                  if ($66) {
                   break;
                  }
                  $67 = HEAP32[$64>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($V_1$011|0));
                  $68 = __THREW__; __THREW__ = 0;
                  $69 = $68&1;
                  if ($69) {
                   break;
                  }
                  $70 = (($V_1$011) + 44|0);
                  $71 = HEAP32[$70>>2]|0;
                  $72 = ($71|0)==(0|0);
                  if ($72) {
                   $V_2$0$lcssa = $67;
                   break L23;
                  } else {
                   $V_1$011 = $71;$V_2$010 = $67;
                  }
                 }
                 $13 = ___cxa_find_matching_catch()|0;
                 $14 = tempRet0;
                 $lpad$phi$index = $13;$lpad$phi$index3 = $14;
                 __ZN16StackTraceSentryD2Ev(0);
                 ___resumeException($lpad$phi$index|0);
                 // unreachable;
                }
               } while(0);
               __THREW__ = 0;
               $75 = (invoke_iii(2756,(2212360|0),($__this|0))|0);
               $76 = __THREW__; __THREW__ = 0;
               $77 = $76&1;
               if (!($77)) {
                __THREW__ = 0;
                (invoke_ii(2996,(2213056|0))|0);
                $78 = __THREW__; __THREW__ = 0;
                $79 = $78&1;
                if (!($79)) {
                 __THREW__ = 0;
                 $80 = (invoke_iii(2755,($75|0),(2213056|0))|0);
                 $81 = __THREW__; __THREW__ = 0;
                 $82 = $81&1;
                 if (!($82)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($V_2$0$lcssa|0));
                  $83 = __THREW__; __THREW__ = 0;
                  $84 = $83&1;
                  if (!($84)) {
                   $85 = (($V_2$0$lcssa) + 44|0);
                   HEAP32[$85>>2] = $80;
                   __THREW__ = 0;
                   invoke_vi(3799,($V_2$0$lcssa|0));
                   $86 = __THREW__; __THREW__ = 0;
                   $87 = $86&1;
                   if ($87) {
                    break;
                   }
                   $88 = HEAP32[$85>>2]|0;
                   $V_2$1 = $88;$__this$pn = $__this;
                   while(1) {
                    $V_1$1$in = (($__this$pn) + 44|0);
                    $V_1$1 = HEAP32[$V_1$1$in>>2]|0;
                    $105 = ($V_1$1|0)==(0|0);
                    if ($105) {
                     label = 49;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($V_1$1|0));
                    $106 = __THREW__; __THREW__ = 0;
                    $107 = $106&1;
                    if ($107) {
                     break;
                    }
                    __THREW__ = 0;
                    $89 = (invoke_iii(2756,(2212360|0),($V_1$1|0))|0);
                    $90 = __THREW__; __THREW__ = 0;
                    $91 = $90&1;
                    if ($91) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2213056|0))|0);
                    $92 = __THREW__; __THREW__ = 0;
                    $93 = $92&1;
                    if ($93) {
                     break;
                    }
                    __THREW__ = 0;
                    $94 = (invoke_iii(2755,($89|0),(2213056|0))|0);
                    $95 = __THREW__; __THREW__ = 0;
                    $96 = $95&1;
                    if ($96) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($V_2$1|0));
                    $97 = __THREW__; __THREW__ = 0;
                    $98 = $97&1;
                    if ($98) {
                     break;
                    }
                    $99 = (($V_2$1) + 44|0);
                    HEAP32[$99>>2] = $94;
                    __THREW__ = 0;
                    invoke_vi(3799,($V_2$1|0));
                    $100 = __THREW__; __THREW__ = 0;
                    $101 = $100&1;
                    if ($101) {
                     break;
                    }
                    $102 = HEAP32[$99>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($V_1$1|0));
                    $103 = __THREW__; __THREW__ = 0;
                    $104 = $103&1;
                    if ($104) {
                     break;
                    } else {
                     $V_2$1 = $102;$__this$pn = $V_1$1;
                    }
                   }
                   if ((label|0) == 49) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return ($37|0);
                   }
                   $11 = ___cxa_find_matching_catch()|0;
                   $12 = tempRet0;
                   $lpad$phi$index = $11;$lpad$phi$index3 = $12;
                   __ZN16StackTraceSentryD2Ev(0);
                   ___resumeException($lpad$phi$index|0);
                   // unreachable;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_Delegate_m_SetMulticastInvokeP24mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213288);
 $0 = HEAP32[2213336>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2213344|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2213336>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z46mscorlib_System_MulticastDelegate_m_BaseEqualsP33mscorlib_System_MulticastDelegateS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212456);
 __THREW__ = 0;
 $0 = (invoke_iii(729,($__this|0),($value|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z39mscorlib_System_MulticastDelegate_m_KPMP22mscorlib_System_ObjectP33mscorlib_System_MulticastDelegateS2_PS2_($__this,$needle,$haystack,$tail) {
 $__this = $__this|0;
 $needle = $needle|0;
 $haystack = $haystack|0;
 $tail = $tail|0;
 var $$0 = 0, $$lcssa19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $G_B10_0$0 = 0, $G_B22_0$0 = 0;
 var $V_0$0$lcssa = 0, $V_0$0$ph = 0, $V_0$021 = 0, $V_0$1 = 0, $V_0$1$ph = 0, $V_1$0$ph = 0, $V_1$1 = 0, $V_1$1$ph = 0, $V_2$0$ph = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212504);
 __THREW__ = 0;
 invoke_vi(3799,($needle|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($needle) + 48|0);
   HEAP32[$2>>2] = 0;
   $V_0$0$ph = 0;$V_1$0$ph = $needle;
   L3: while(1) {
    $44 = ($V_0$0$ph|0)==(0|0);
    L5: do {
     if ($44) {
      $$lcssa19 = 0;$V_0$0$lcssa = 0;
     } else {
      $V_0$021 = $V_0$0$ph;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($V_0$021|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        label = 5;
        break L3;
       }
       __THREW__ = 0;
       $18 = (invoke_iii(727,($V_0$021|0),($V_1$0$ph|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        label = 5;
        break L3;
       }
       if ($18) {
        $$lcssa19 = 1;$V_0$0$lcssa = $V_0$021;
        break L5;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_0$021|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        label = 5;
        break L3;
       }
       $13 = (($V_0$021) + 48|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = ($14|0)==(0|0);
       if ($15) {
        $$lcssa19 = 0;$V_0$0$lcssa = 0;
        break;
       } else {
        $V_0$021 = $14;
       }
      }
     }
    } while(0);
    __THREW__ = 0;
    invoke_vi(3799,($V_1$0$ph|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     label = 6;
     break;
    }
    $25 = (($V_1$0$ph) + 44|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     $V_0$1$ph = $needle;$V_1$1$ph = $haystack;$V_2$0$ph = $haystack;
     label = 30;
     break;
    }
    if ($$lcssa19) {
     __THREW__ = 0;
     invoke_vi(3799,($V_0$0$lcssa|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 6;
      break;
     }
     $30 = (($V_0$0$lcssa) + 44|0);
     $31 = HEAP32[$30>>2]|0;
     $G_B10_0$0 = $31;
    } else {
     $G_B10_0$0 = $needle;
    }
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    $34 = (invoke_iii(727,($26|0),($G_B10_0$0|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    if (!($34)) {
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 6;
      break;
     }
     $47 = (($26) + 48|0);
     HEAP32[$47>>2] = $G_B10_0$0;
     $V_0$0$ph = $G_B10_0$0;$V_1$0$ph = $26;
     continue;
    }
    __THREW__ = 0;
    invoke_vi(3799,($G_B10_0$0|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
    $39 = (($G_B10_0$0) + 48|0);
    $40 = HEAP32[$39>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     label = 6;
     break;
    }
    $43 = (($26) + 48|0);
    HEAP32[$43>>2] = $40;
    $V_0$0$ph = $G_B10_0$0;$V_1$0$ph = $26;
   }
   if ((label|0) == 5) {
    $7 = ___cxa_find_matching_catch()|0;
    $8 = tempRet0;
    $lpad$phi$index = $7;$lpad$phi$index5 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 6) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    $lpad$phi$index = $9;$lpad$phi$index5 = $10;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 30) {
    L28: while(1) {
     label = 0;
     $V_0$1 = $V_0$1$ph;$V_1$1 = $V_1$1$ph;
     while(1) {
      $54 = ($V_0$1|0)==(0|0);
      if ($54) {
       $G_B22_0$0 = $needle;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($V_0$1|0));
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        label = 3;
        break L28;
       }
       __THREW__ = 0;
       $57 = (invoke_iii(727,($V_0$1|0),($V_1$1|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        label = 3;
        break L28;
       }
       if (!($57)) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_0$1|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        label = 3;
        break L28;
       }
       $64 = (($V_0$1) + 44|0);
       $65 = HEAP32[$64>>2]|0;
       $G_B22_0$0 = $65;
      }
      $66 = ($G_B22_0$0|0)==(0|0);
      if ($66) {
       label = 39;
       break L28;
      }
      __THREW__ = 0;
      invoke_vi(3799,($V_1$1|0));
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 3;
       break L28;
      }
      $73 = (($V_1$1) + 44|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = ($74|0)==(0|0);
      if ($75) {
       $$0 = 0;$storemerge = 0;
       label = 43;
       break L28;
      } else {
       $V_0$1 = $G_B22_0$0;$V_1$1 = $74;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($V_0$1|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 4;
      break;
     }
     $48 = (($V_0$1) + 48|0);
     $49 = HEAP32[$48>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($V_2$0$ph|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      label = 4;
      break;
     }
     $52 = (($V_2$0$ph) + 44|0);
     $53 = HEAP32[$52>>2]|0;
     $V_0$1$ph = $49;$V_1$1$ph = $V_1$1;$V_2$0$ph = $53;
     label = 30;
    }
    if ((label|0) == 3) {
     $3 = ___cxa_find_matching_catch()|0;
     $4 = tempRet0;
     $lpad$phi$index = $3;$lpad$phi$index5 = $4;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 4) {
     $5 = ___cxa_find_matching_catch()|0;
     $6 = tempRet0;
     $lpad$phi$index = $5;$lpad$phi$index5 = $6;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 39) {
     __THREW__ = 0;
     invoke_vi(3799,($V_1$1|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     $69 = (($V_1$1) + 44|0);
     $70 = HEAP32[$69>>2]|0;
     $$0 = $V_2$0$ph;$storemerge = $70;
     HEAP32[$tail>>2] = $storemerge;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    else if ((label|0) == 43) {
     HEAP32[$tail>>2] = $storemerge;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $lpad$phi$index = $11;$lpad$phi$index5 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_MulticastDelegate_m_RemoveImplP33mscorlib_System_MulticastDelegateP24mscorlib_System_Delegate($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_1 = 0, $V_2$0$lcssa = 0, $V_2$018 = 0, $V_2$1$lcssa = 0, $V_2$17 = 0, $V_3$0 = 0, $V_3$1$lcssa = 0, $V_3$117 = 0, $V_3$2 = 0, $V_3$3$lcssa = 0, $V_3$36 = 0, $V_4$016 = 0, $V_4$1 = 0, $V_4$15 = 0, $V_4$18 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212552);
 HEAP32[$V_1>>2] = 0;
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = $__this;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2213056|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2755,($value|0),(2213056|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_iiiii(107,0,($3|0),($__this|0),($V_1|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = ($6|0)==(0|0);
     if ($9) {
      $$0 = $__this;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $10 = ($6|0)==($__this|0);
     L13: do {
      if ($10) {
       $V_2$0$lcssa = 0;$V_3$1$lcssa = 0;
      } else {
       $V_2$018 = 0;$V_3$117 = 0;$V_4$016 = $__this;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($V_4$016|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break;
        }
        __THREW__ = 0;
        $17 = (invoke_iii(2756,(2212360|0),($V_4$016|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2213056|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break;
        }
        __THREW__ = 0;
        $22 = (invoke_iii(2755,($17|0),(2213056|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if ($24) {
         break;
        }
        $25 = ($V_2$018|0)==(0|0);
        if ($25) {
         $V_3$0 = $22;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($V_2$018|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         $28 = (($V_2$018) + 44|0);
         HEAP32[$28>>2] = $22;
         $V_3$0 = $V_3$117;
        }
        __THREW__ = 0;
        invoke_vi(3799,($V_4$016|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break;
        }
        $31 = (($V_4$016) + 44|0);
        $32 = HEAP32[$31>>2]|0;
        $33 = ($32|0)==($6|0);
        if ($33) {
         $V_2$0$lcssa = $22;$V_3$1$lcssa = $V_3$0;
         break L13;
        } else {
         $V_2$018 = $22;$V_3$117 = $V_3$0;$V_4$016 = $32;
        }
       }
       $13 = ___cxa_find_matching_catch()|0;
       $14 = tempRet0;
       $lpad$phi$index = $13;$lpad$phi$index3 = $14;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     } while(0);
     $V_4$15 = HEAP32[$V_1>>2]|0;
     $34 = ($V_4$15|0)==(0|0);
     L28: do {
      if ($34) {
       $V_2$1$lcssa = $V_2$0$lcssa;$V_3$3$lcssa = $V_3$1$lcssa;
      } else {
       $V_2$17 = $V_2$0$lcssa;$V_3$36 = $V_3$1$lcssa;$V_4$18 = $V_4$15;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($V_4$18|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __THREW__ = 0;
        $37 = (invoke_iii(2756,(2212360|0),($V_4$18|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2213056|0))|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        $42 = (invoke_iii(2755,($37|0),(2213056|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break;
        }
        $45 = ($V_2$17|0)==(0|0);
        if ($45) {
         $V_3$2 = $42;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($V_2$17|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          break;
         }
         $48 = (($V_2$17) + 44|0);
         HEAP32[$48>>2] = $42;
         $V_3$2 = $V_3$36;
        }
        __THREW__ = 0;
        invoke_vi(3799,($V_4$18|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        $51 = (($V_4$18) + 44|0);
        $V_4$1 = HEAP32[$51>>2]|0;
        $52 = ($V_4$1|0)==(0|0);
        if ($52) {
         $V_2$1$lcssa = $42;$V_3$3$lcssa = $V_3$2;
         break L28;
        } else {
         $V_2$17 = $42;$V_3$36 = $V_3$2;$V_4$18 = $V_4$1;
        }
       }
       $11 = ___cxa_find_matching_catch()|0;
       $12 = tempRet0;
       $lpad$phi$index = $11;$lpad$phi$index3 = $12;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     } while(0);
     $55 = ($V_2$1$lcssa|0)==(0|0);
     if (!($55)) {
      __THREW__ = 0;
      invoke_vi(3799,($V_2$1$lcssa|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = (($V_2$1$lcssa) + 44|0);
      HEAP32[$58>>2] = 0;
     }
     $$0 = $V_3$3$lcssa;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_MulticastDelegate_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z37mscorlib_System_Delegate_m_get_MethodP24mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy3 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 28|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $L_6 = sp + 16|0;
 $2 = sp + 20|0;
 $3 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213192);
 $4 = (($__this) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $$0 = $5;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($__this) + 20|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2210080|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = HEAP32[((2210080 + 80|0))>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  HEAP32[$0>>2] = $8;
  HEAP32[$1>>2] = $12;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  $13 = (invoke_iiii(645,0,($$byval_copy|0),($$byval_copy3|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   if (!($13)) {
    $$pre = HEAP32[$4>>2]|0;
    $$0 = $$pre;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $18 = HEAP32[$7>>2]|0;
   HEAP32[$L_6>>2] = 0;
   HEAP32[$2>>2] = $18;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
   invoke_vii(1973,($L_6|0),($$byval_copy3|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[$L_6>>2]|0;
    HEAP32[$3>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
    $22 = (invoke_iii(908,(0|0),($$byval_copy3|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2414216|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      $27 = (invoke_iii(2755,($22|0),(2414216|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       HEAP32[$4>>2] = $27;
       $$0 = $27;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Delegate_m_get_TargetP24mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213240);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z32mscorlib_System_Delegate_m_CloneP24mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2212360);
 __THREW__ = 0;
 $0 = (invoke_ii(1783,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z44mscorlib_System_Delegate_m_GetInvocationListP24mscorlib_System_Delegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213528);
 __THREW__ = 0;
 (invoke_ii(2996,(1220056|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1220056|0),1)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($2|0),($__this|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = (($2) + 16|0);
      HEAP32[$19>>2] = $__this;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($2|0);
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Delegate_m_CombineP22mscorlib_System_ObjectP24mscorlib_System_DelegateS2_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213576);
 __THREW__ = 0;
 invoke_v(445);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($a|0)==(0|0);
   if ($2) {
    $$0 = $b;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $5 = ($b|0)==(0|0);
   if ($5) {
    $$0 = $a;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($a|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(1782,($a|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3799,($b|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(1782,($b|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = ($8|0)==($13|0);
       if ($16) {
        __THREW__ = 0;
        invoke_vi(3799,($a|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         break;
        }
        __THREW__ = 0;
        $32 = (invoke_iiii(1645,(2213624|0),($a|0),($b|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break;
        }
        $$0 = $32;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $17 = HEAP32[3010640>>2]|0;
       __THREW__ = 0;
       $18 = (invoke_iii(783,0,($17|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         $23 = (invoke_ii(3469,(2560072|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          invoke_vii(1924,($23|0),($18|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           invoke_vi(3830,($23|0));
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_Delegate_m_CombineImplP24mscorlib_System_DelegateS0_($__this,$d) {
 $__this = $__this|0;
 $d = $d|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213624);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2621688|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     $18 = (invoke_ii(3469,(2621688|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vii(1952,($18|0),($15|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3830,($18|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z33mscorlib_System_Delegate_m_RemoveP22mscorlib_System_ObjectP24mscorlib_System_DelegateS2_($__this,$source,$value) {
 $__this = $__this|0;
 $source = $source|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213672);
 $0 = ($source|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($source|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1645,(2213720|0),($source|0),($value|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $$0 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Delegate_m_RemoveImplP24mscorlib_System_DelegateS0_($__this,$d) {
 $__this = $__this|0;
 $d = $d|0;
 var $$__this = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2213720);
 __THREW__ = 0;
 $0 = (invoke_iiii(1644,(2213384|0),($__this|0),($d|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $$__this = $0 ? 0 : $__this;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$__this|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_Delegate_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($6,2);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z29mscorlib_System_Enum_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2214696);
 __THREW__ = 0;
 (invoke_ii(2996,(1168808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1168808|0),1)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     HEAP16[$17>>1] = 44;
     __THREW__ = 0;
     (invoke_ii(2996,(2218016|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[((2218016 + 80|0))>>2]|0;
      HEAP32[$20>>2] = $2;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z52mscorlib_System_Enum_m_System_IConvertible_ToBooleanP22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2214744);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(971,(0|0),($0|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Enum_m_get_ValueP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215648);
 __THREW__ = 0;
 $0 = (invoke_ii(1846,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z49mscorlib_System_Enum_m_System_IConvertible_ToByteP22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2214792);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(985,(0|0),($0|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Enum_m_System_IConvertible_ToCharP22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2214840);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(999,(0|0),($0|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_Enum_m_System_IConvertible_ToDateTimeP22mscorlib_System_ObjectS0_($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2214888);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viiii(179,($agg$result|0),(0|0),($0|0),($provider|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z52mscorlib_System_Enum_m_System_IConvertible_ToDecimalP22mscorlib_System_ObjectS0_($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2214936);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viiii(184,($agg$result|0),(0|0),($0|0),($provider|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z51mscorlib_System_Enum_m_System_IConvertible_ToDoubleP22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2214984);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (+invoke_diii(5,(0|0),($0|0),($provider|0)));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$3);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return +0;
}
function __Z50mscorlib_System_Enum_m_System_IConvertible_ToInt16P22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215032);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1040,(0|0),($0|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Enum_m_System_IConvertible_ToInt32P22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215080);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1045,(0|0),($0|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Enum_m_System_IConvertible_ToInt64P22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215128);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1060,(0|0),($0|0),($provider|0))|0);
  $4 = tempRet0;
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $4;
   STACKTOP = sp;return ($3|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Enum_m_System_IConvertible_ToSByteP22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215176);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1076,(0|0),($0|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Enum_m_System_IConvertible_ToSingleP22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215224);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fiii(5,(0|0),($0|0),($provider|0)))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($3));
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return Math_fround(0);
}
function __Z49mscorlib_System_Enum_m_System_IConvertible_ToTypeP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215272);
 __THREW__ = 0;
 invoke_v(446);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($targetType|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3010656>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   HEAP32[$0>>2] = 1284472;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $16 = (invoke_iii(772,0,($$byval_copy|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = ($16|0)==($targetType|0);
    if ($19) {
     __THREW__ = 0;
     $20 = (invoke_iiii(1645,(2215320|0),($__this|0),($provider|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     $$0 = $20;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     __THREW__ = 0;
     $23 = (invoke_ii(1847,($__this|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     $26 = (invoke_iiiiii(126,(0|0),($23|0),($targetType|0),($provider|0),0)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     } else {
      $$0 = $26;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Enum_m_System_IConvertible_ToUInt16P22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215368);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1102,(0|0),($0|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Enum_m_System_IConvertible_ToUInt32P22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215416);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1118,(0|0),($0|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Enum_m_System_IConvertible_ToUInt64P22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215464);
 __THREW__ = 0;
 $0 = (invoke_ii(1847,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1134,(0|0),($0|0),($provider|0))|0);
  $4 = tempRet0;
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $4;
   STACKTOP = sp;return ($3|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Enum_m_GetTypeCodeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215512);
 __THREW__ = 0;
 $0 = (invoke_ii(1782,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(744,0,($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(771,0,($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Enum_m_GetUnderlyingTypeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$enumType) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215944);
 __THREW__ = 0;
 invoke_v(447);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($enumType|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3010792>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($enumType|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(2734,(2215792|0),($enumType|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     if ($17) {
      __THREW__ = 0;
      $31 = (invoke_iii(743,0,($enumType|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($31|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_ii(3469,(2560072|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = HEAP32[3010800>>2]|0;
       $26 = HEAP32[3010808>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($22|0),($25|0),($26|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        invoke_vi(3830,($22|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Type_m_GetTypeCodeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235552);
 __THREW__ = 0;
 (invoke_ii(2996,(2621328|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($type|0),(2621328|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if (!($5)) {
     __THREW__ = 0;
     $8 = (invoke_iii(770,0,($type|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     } else {
      $$0 = $8;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $11 = ($type|0)==(0|0);
    if ($11) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($type|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_iii(2730,(2223352|0),($type|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3799,($14|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_ii(1892,($14|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        if (!($19)) {
         $$0 = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        $22 = (invoke_iii(770,0,($14|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         $$0 = $22;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Enum_m_get_valueP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215560);
 $0 = HEAP32[2215608>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2215616|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2215608>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_Enum_m_FindPositionP22mscorlib_System_ObjectS0_P21mscorlib_System_Array($__this,$value,$values) {
 $__this = $__this|0;
 $value = $value|0;
 $values = $values|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_25 = 0, $L_3 = 0, $L_36 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 12|0;
 $L_3 = sp + 8|0;
 $L_14 = sp + 16|0;
 $L_25 = sp + 18|0;
 $L_36 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215696);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($values|0),(1170368|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2753,($value|0),(2155952|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[$10>>2]|0;
     HEAP32[$L_3>>2] = $13;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_iii(2724,(2155952|0),($L_3|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2600920|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     $21 = HEAP8[((2600920 + 116|0))>>0]|0;
     $22 = ($21<<24>>24)==(0);
     if ($22) {
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2600920|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2600920|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     $31 = HEAP32[((2600920 + 80|0))>>2]|0;
     $32 = (($31) + 16|0);
     $33 = HEAP32[$32>>2]|0;
     __THREW__ = 0;
     $34 = (invoke_iiiii(114,0,($2|0),($16|0),($33|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     } else {
      $$0 = $34;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1216208|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     __THREW__ = 0;
     $39 = (invoke_iii(2735,($values|0),(1216208|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if (!($41)) {
      $42 = ($39|0)==(0|0);
      if (!($42)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2164560|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       __THREW__ = 0;
       $45 = (invoke_iii(2753,($value|0),(2164560|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       $48 = HEAP32[$45>>2]|0;
       __THREW__ = 0;
       $49 = (invoke_iiii(1451,(0|0),($39|0),($48|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       } else {
        $$0 = $49;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1217736|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if (!($53)) {
       __THREW__ = 0;
       $54 = (invoke_iii(2735,($values|0),(1217736|0))|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if (!($56)) {
        $57 = ($54|0)==(0|0);
        if (!($57)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2173776|0))|0);
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          break;
         }
         __THREW__ = 0;
         $60 = (invoke_iii(2753,($value|0),(2173776|0))|0);
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          break;
         }
         $63 = HEAP16[$60>>1]|0;
         HEAP16[$L_14>>1] = $63;
         __THREW__ = 0;
         (invoke_ii(2996,(2173776|0))|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
         __THREW__ = 0;
         $66 = (invoke_iii(2724,(2173776|0),($L_14|0))|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2600920|0))|0);
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          break;
         }
         $71 = HEAP8[((2600920 + 116|0))>>0]|0;
         $72 = ($71<<24>>24)==(0);
         if ($72) {
          __THREW__ = 0;
          (invoke_ii(2996,(2600920|0))|0);
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2600920|0))|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3831,(2600920|0));
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2600920|0))|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break;
         }
         $81 = HEAP32[((2600920 + 80|0))>>2]|0;
         $82 = (($81) + 12|0);
         $83 = HEAP32[$82>>2]|0;
         __THREW__ = 0;
         $84 = (invoke_iiiii(114,0,($54|0),($66|0),($83|0))|0);
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          break;
         } else {
          $$0 = $84;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1218120|0))|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if (!($88)) {
         __THREW__ = 0;
         $89 = (invoke_iii(2735,($values|0),(1218120|0))|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if (!($91)) {
          $92 = ($89|0)==(0|0);
          if (!($92)) {
           __THREW__ = 0;
           (invoke_ii(2996,(2176024|0))|0);
           $93 = __THREW__; __THREW__ = 0;
           $94 = $93&1;
           if ($94) {
            break;
           }
           __THREW__ = 0;
           $95 = (invoke_iii(2753,($value|0),(2176024|0))|0);
           $96 = __THREW__; __THREW__ = 0;
           $97 = $96&1;
           if ($97) {
            break;
           }
           $98 = HEAP16[$95>>1]|0;
           __THREW__ = 0;
           $99 = (invoke_iiii(1452,(0|0),($89|0),($98|0))|0);
           $100 = __THREW__; __THREW__ = 0;
           $101 = $100&1;
           if ($101) {
            break;
           } else {
            $$0 = $99;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          (invoke_ii(2996,(1217360|0))|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if (!($103)) {
           __THREW__ = 0;
           $104 = (invoke_iii(2735,($values|0),(1217360|0))|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if (!($106)) {
            $107 = ($104|0)==(0|0);
            if (!($107)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2171616|0))|0);
             $108 = __THREW__; __THREW__ = 0;
             $109 = $108&1;
             if ($109) {
              break;
             }
             __THREW__ = 0;
             $110 = (invoke_iii(2753,($value|0),(2171616|0))|0);
             $111 = __THREW__; __THREW__ = 0;
             $112 = $111&1;
             if ($112) {
              break;
             }
             $113 = HEAP8[$110>>0]|0;
             HEAP8[$L_25>>0] = $113;
             __THREW__ = 0;
             (invoke_ii(2996,(2171616|0))|0);
             $114 = __THREW__; __THREW__ = 0;
             $115 = $114&1;
             if ($115) {
              break;
             }
             __THREW__ = 0;
             $116 = (invoke_iii(2724,(2171616|0),($L_25|0))|0);
             $117 = __THREW__; __THREW__ = 0;
             $118 = $117&1;
             if ($118) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $119 = __THREW__; __THREW__ = 0;
             $120 = $119&1;
             if ($120) {
              break;
             }
             $121 = HEAP8[((2600920 + 116|0))>>0]|0;
             $122 = ($121<<24>>24)==(0);
             if ($122) {
              __THREW__ = 0;
              (invoke_ii(2996,(2600920|0))|0);
              $123 = __THREW__; __THREW__ = 0;
              $124 = $123&1;
              if ($124) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2600920|0))|0);
              $125 = __THREW__; __THREW__ = 0;
              $126 = $125&1;
              if ($126) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3831,(2600920|0));
              $127 = __THREW__; __THREW__ = 0;
              $128 = $127&1;
              if ($128) {
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $129 = __THREW__; __THREW__ = 0;
             $130 = $129&1;
             if ($130) {
              break;
             }
             $131 = HEAP32[((2600920 + 80|0))>>2]|0;
             $132 = (($131) + 8|0);
             $133 = HEAP32[$132>>2]|0;
             __THREW__ = 0;
             $134 = (invoke_iiiii(114,0,($104|0),($116|0),($133|0))|0);
             $135 = __THREW__; __THREW__ = 0;
             $136 = $135&1;
             if ($136) {
              break;
             } else {
              $$0 = $134;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            (invoke_ii(2996,(1203320|0))|0);
            $137 = __THREW__; __THREW__ = 0;
            $138 = $137&1;
            if (!($138)) {
             __THREW__ = 0;
             $139 = (invoke_iii(2735,($values|0),(1203320|0))|0);
             $140 = __THREW__; __THREW__ = 0;
             $141 = $140&1;
             if (!($141)) {
              $142 = ($139|0)==(0|0);
              if (!($142)) {
               __THREW__ = 0;
               (invoke_ii(2996,(2169424|0))|0);
               $143 = __THREW__; __THREW__ = 0;
               $144 = $143&1;
               if ($144) {
                break;
               }
               __THREW__ = 0;
               $145 = (invoke_iii(2753,($value|0),(2169424|0))|0);
               $146 = __THREW__; __THREW__ = 0;
               $147 = $146&1;
               if ($147) {
                break;
               }
               $148 = HEAP8[$145>>0]|0;
               __THREW__ = 0;
               $149 = (invoke_iiii(1453,(0|0),($139|0),($148|0))|0);
               $150 = __THREW__; __THREW__ = 0;
               $151 = $150&1;
               if ($151) {
                break;
               } else {
                $$0 = $149;
               }
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
              __THREW__ = 0;
              (invoke_ii(2996,(1215824|0))|0);
              $152 = __THREW__; __THREW__ = 0;
              $153 = $152&1;
              if (!($153)) {
               __THREW__ = 0;
               $154 = (invoke_iii(2735,($values|0),(1215824|0))|0);
               $155 = __THREW__; __THREW__ = 0;
               $156 = $155&1;
               if ($156) {
                break;
               }
               $157 = ($154|0)==(0|0);
               if ($157) {
                __THREW__ = 0;
                (invoke_ii(2996,(1216984|0))|0);
                $196 = __THREW__; __THREW__ = 0;
                $197 = $196&1;
                if ($197) {
                 break;
                }
                __THREW__ = 0;
                $198 = (invoke_iii(2735,($values|0),(1216984|0))|0);
                $199 = __THREW__; __THREW__ = 0;
                $200 = $199&1;
                if ($200) {
                 break;
                }
                $201 = ($198|0)==(0|0);
                if ($201) {
                 __THREW__ = 0;
                 $216 = (invoke_iiii(692,0,($values|0),($value|0))|0);
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  break;
                 } else {
                  $$0 = $216;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2167208|0))|0);
                $202 = __THREW__; __THREW__ = 0;
                $203 = $202&1;
                if ($203) {
                 break;
                }
                __THREW__ = 0;
                $204 = (invoke_iii(2753,($value|0),(2167208|0))|0);
                $205 = __THREW__; __THREW__ = 0;
                $206 = $205&1;
                if ($206) {
                 break;
                }
                $207 = $204;
                $208 = $207;
                $209 = HEAP32[$208>>2]|0;
                $210 = (($207) + 4)|0;
                $211 = $210;
                $212 = HEAP32[$211>>2]|0;
                __THREW__ = 0;
                $213 = (invoke_iiiii(209,(0|0),($198|0),($209|0),($212|0))|0);
                $214 = __THREW__; __THREW__ = 0;
                $215 = $214&1;
                if ($215) {
                 break;
                } else {
                 $$0 = $213;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2162248|0))|0);
               $158 = __THREW__; __THREW__ = 0;
               $159 = $158&1;
               if ($159) {
                break;
               }
               __THREW__ = 0;
               $160 = (invoke_iii(2753,($value|0),(2162248|0))|0);
               $161 = __THREW__; __THREW__ = 0;
               $162 = $161&1;
               if ($162) {
                break;
               }
               $163 = $160;
               $164 = $163;
               $165 = HEAP32[$164>>2]|0;
               $166 = (($163) + 4)|0;
               $167 = $166;
               $168 = HEAP32[$167>>2]|0;
               $169 = $L_36;
               $170 = $169;
               HEAP32[$170>>2] = $165;
               $171 = (($169) + 4)|0;
               $172 = $171;
               HEAP32[$172>>2] = $168;
               __THREW__ = 0;
               (invoke_ii(2996,(2162248|0))|0);
               $173 = __THREW__; __THREW__ = 0;
               $174 = $173&1;
               if ($174) {
                break;
               }
               __THREW__ = 0;
               $175 = (invoke_iii(2724,(2162248|0),($L_36|0))|0);
               $176 = __THREW__; __THREW__ = 0;
               $177 = $176&1;
               if ($177) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2600920|0))|0);
               $178 = __THREW__; __THREW__ = 0;
               $179 = $178&1;
               if ($179) {
                break;
               }
               $180 = HEAP8[((2600920 + 116|0))>>0]|0;
               $181 = ($180<<24>>24)==(0);
               if ($181) {
                __THREW__ = 0;
                (invoke_ii(2996,(2600920|0))|0);
                $182 = __THREW__; __THREW__ = 0;
                $183 = $182&1;
                if ($183) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2600920|0))|0);
                $184 = __THREW__; __THREW__ = 0;
                $185 = $184&1;
                if ($185) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3831,(2600920|0));
                $186 = __THREW__; __THREW__ = 0;
                $187 = $186&1;
                if ($187) {
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2600920|0))|0);
               $188 = __THREW__; __THREW__ = 0;
               $189 = $188&1;
               if ($189) {
                break;
               }
               $190 = HEAP32[((2600920 + 80|0))>>2]|0;
               $191 = (($190) + 20|0);
               $192 = HEAP32[$191>>2]|0;
               __THREW__ = 0;
               $193 = (invoke_iiiii(114,0,($154|0),($175|0),($192|0))|0);
               $194 = __THREW__; __THREW__ = 0;
               $195 = $194&1;
               if ($195) {
                break;
               } else {
                $$0 = $193;
               }
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z141mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_S0_($__this,$_____array,$value,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $comparer = $comparer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223784);
 __THREW__ = 0;
 invoke_v(448);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3014360>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1859,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)<(2);
     if (!($20)) {
      $21 = HEAP32[3014368>>2]|0;
      __THREW__ = 0;
      $22 = (invoke_iii(783,0,($21|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636920|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_ii(3469,(2636920|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1972,($27|0),($22|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($27|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      __THREW__ = 0;
      $36 = (invoke_ii(1857,($_____array|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = ($36|0)==(0);
       if ($39) {
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $40 = ($comparer|0)!=(0|0);
       $41 = ($value|0)==(0|0);
       $or$cond = $40 | $41;
       if (!($or$cond)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2157896|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        $44 = (invoke_iii(2735,($value|0),(2157896|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        $47 = ($44|0)==(0|0);
        if ($47) {
         $48 = HEAP32[3014376>>2]|0;
         __THREW__ = 0;
         $49 = (invoke_iii(783,0,($48|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break;
         }
         __THREW__ = 0;
         $54 = (invoke_ii(3469,(2560072|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(1924,($54|0),($49|0));
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3830,($54|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break;
         }
         // unreachable;
        }
       }
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if (!($62)) {
        __THREW__ = 0;
        $63 = (invoke_iii(755,($_____array|0),0)|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if (!($65)) {
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if (!($67)) {
          __THREW__ = 0;
          $68 = (invoke_iii(753,($_____array|0),0)|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if (!($70)) {
           __THREW__ = 0;
           $71 = (invoke_iiiiiii(56,0,($_____array|0),($63|0),($68|0),($value|0),($comparer|0))|0);
           $72 = __THREW__; __THREW__ = 0;
           $73 = $72&1;
           if (!($73)) {
            $$0 = $71;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_($__this,$_____array,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223736);
 __THREW__ = 0;
 invoke_v(449);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3014256>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($value|0)==(0|0);
   if ($15) {
    $$0 = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_ii(1859,($_____array|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = ($18|0)<(2);
     if (!($21)) {
      $22 = HEAP32[3014264>>2]|0;
      __THREW__ = 0;
      $23 = (invoke_iii(783,0,($22|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636920|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_ii(3469,(2636920|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1972,($28|0),($23|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($28|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      __THREW__ = 0;
      $37 = (invoke_ii(1857,($_____array|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $40 = ($37|0)==(0);
       if ($40) {
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2157896|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(2735,($value|0),(2157896|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = ($43|0)==(0|0);
         if ($46) {
          $47 = HEAP32[3014272>>2]|0;
          __THREW__ = 0;
          $48 = (invoke_iii(783,0,($47|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          __THREW__ = 0;
          $53 = (invoke_ii(3469,(2560072|0))|0);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1924,($53|0),($48|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3830,($53|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if ($59) {
           break;
          }
          // unreachable;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($_____array|0));
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if ($61) {
           break;
          }
          __THREW__ = 0;
          $62 = (invoke_iii(755,($_____array|0),0)|0);
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if ($64) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($_____array|0));
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           break;
          }
          __THREW__ = 0;
          $67 = (invoke_iii(753,($_____array|0),0)|0);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if ($69) {
           break;
          }
          __THREW__ = 0;
          $70 = (invoke_iiiiiii(56,0,($_____array|0),($62|0),($67|0),($value|0),(0|0))|0);
          $71 = __THREW__; __THREW__ = 0;
          $72 = $71&1;
          if ($72) {
           break;
          } else {
           $$0 = $70;
          }
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z30mscorlib_System_Enum_m_GetNameP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_($__this,$enumType,$value) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $G_B9_0$0 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215744);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(450);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($enumType|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3010672>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($value|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3010680>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($enumType|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_iii(2734,(2215792|0),($enumType|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     if (!($28)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      $33 = (invoke_ii(3469,(2560072|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      $36 = HEAP32[3010688>>2]|0;
      $37 = HEAP32[3010696>>2]|0;
      __THREW__ = 0;
      invoke_viii(641,($33|0),($36|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($33|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     $42 = (invoke_iiii(666,0,($enumType|0),($value|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      __THREW__ = 0;
      invoke_viii(672,(0|0),($enumType|0),($V_0|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       $47 = (($V_0) + 4|0);
       $48 = HEAP32[$47>>2]|0;
       __THREW__ = 0;
       $49 = (invoke_iiii(663,0,($42|0),($48|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if (!($51)) {
        $52 = ($49|0)<(0);
        if ($52) {
         $G_B9_0$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($G_B9_0$0|0);
        }
        $53 = (($V_0) + 8|0);
        $54 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if (!($56)) {
         $57 = (($54) + 12|0);
         $58 = HEAP32[$57>>2]|0;
         $59 = ($49>>>0)<($58>>>0);
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_i(132)|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($60|0));
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if ($64) {
           break;
          }
         }
         $65 = HEAP32[$54>>2]|0;
         $66 = (($54) + 16|0);
         $67 = (($65) + 92|0);
         $68 = HEAP32[$67>>2]|0;
         $69 = Math_imul($68, $49)|0;
         $70 = (($66) + ($69)|0);
         $71 = HEAP32[$70>>2]|0;
         $G_B9_0$0 = $71;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($G_B9_0$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z31mscorlib_System_Enum_m_ToObjectP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_($__this,$enumType,$value) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216288);
 $0 = HEAP32[2216336>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2216344|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2216336>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($enumType|0),($value|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_Enum_m_get_underlying_typeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$enumType) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215840);
 $0 = HEAP32[2215888>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2215896|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2215888>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($enumType|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Enum_m_compare_value_toP22mscorlib_System_ObjectS0_($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215992);
 $0 = HEAP32[2216040>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2216048|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2216040>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($other|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Enum_m_CompareToP22mscorlib_System_ObjectS0_($__this,$target) {
 $__this = $__this|0;
 $target = $target|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216096);
 __THREW__ = 0;
 invoke_v(451);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($target|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $5 = (invoke_ii(1782,($__this|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($target|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_ii(1782,($target|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = ($10|0)==($5|0);
      if ($13) {
       __THREW__ = 0;
       $32 = (invoke_iii(745,($__this|0),($target|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       } else {
        $$0 = $32;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($target|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       $16 = (invoke_ii(1782,($target|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        $19 = HEAP32[3010824>>2]|0;
        __THREW__ = 0;
        $20 = (invoke_iiiii(98,0,($19|0),($16|0),($5|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          $25 = (invoke_ii(3469,(2560072|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           invoke_vii(1924,($25|0),($20|0));
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            __THREW__ = 0;
            invoke_vi(3830,($25|0));
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if (!($31)) {
             // unreachable;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Enum_m_ToString_mscorlib_System_StringP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216144);
 __THREW__ = 0;
 invoke_v(452);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3011024>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(747,($__this|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216240);
 __THREW__ = 0;
 invoke_v(453);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2191608 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2191608 + 80|0))>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     $18 = (invoke_iiii(574,0,($format|0),($17|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = ($format|0)==(0|0);
      $or$cond = $18 | $21;
      $22 = HEAP32[3011056>>2]|0;
      $$0 = $or$cond ? $22 : $format;
      __THREW__ = 0;
      $23 = (invoke_ii(1782,($__this|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       $26 = (invoke_ii(1847,($__this|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        $29 = (invoke_iiiii(109,0,($23|0),($26|0),($$0|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($29|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215320);
 __THREW__ = 0;
 invoke_v(454);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3011040>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iiiii(317,(2216192|0),($__this|0),($2|0),($provider|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I17VoidPointerTraitsS0_S0_E6InvokeEP10MethodInfoPvS4_S4_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z29mscorlib_System_Enum_m_FormatP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_P22mscorlib_System_String($__this,$enumType,$value,$format) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 $value = $value|0;
 $format = $format|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_4 = 0, $V_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 28|0;
 $_stackTraceSentry = sp + 16|0;
 $V_4 = sp;
 $V_5 = sp + 8|0;
 $0 = sp + 20|0;
 $1 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216680);
 $2 = $V_4;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = $V_5;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 __THREW__ = 0;
 invoke_v(455);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if (!($11)) {
   $12 = ($enumType|0)==(0|0);
   if ($12) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2560584|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = HEAP32[3011456>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($17|0),($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($17|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    // unreachable;
   }
   $25 = ($value|0)==(0|0);
   if ($25) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    $28 = (invoke_ii(3469,(2560584|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    $31 = HEAP32[3011464>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($28|0),($31|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($28|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    // unreachable;
   }
   $36 = ($format|0)==(0|0);
   if ($36) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3469,(2560584|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    $42 = HEAP32[3011472>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($39|0),($42|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($39|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($enumType|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if (!($48)) {
    __THREW__ = 0;
    $49 = (invoke_iii(2734,(2215792|0),($enumType|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if (!($51)) {
     if (!($49)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_ii(3469,(2560072|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break;
      }
      $57 = HEAP32[3011480>>2]|0;
      $58 = HEAP32[3011488>>2]|0;
      __THREW__ = 0;
      invoke_viii(641,($54|0),($57|0),($58|0));
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($54|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if (!($64)) {
      __THREW__ = 0;
      $65 = (invoke_ii(1782,($value|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if (!($67)) {
       __THREW__ = 0;
       $68 = (invoke_iii(744,0,($enumType|0))|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if (!($70)) {
        __THREW__ = 0;
        invoke_vi(3799,($65|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if (!($72)) {
         __THREW__ = 0;
         $73 = (invoke_iii(2734,(2215792|0),($65|0))|0);
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if (!($75)) {
          if ($73) {
           $76 = ($65|0)==($enumType|0);
           if (!($76)) {
            __THREW__ = 0;
            $77 = (invoke_ii(1982,(0|0))|0);
            $78 = __THREW__; __THREW__ = 0;
            $79 = $78&1;
            if ($79) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(1167664|0))|0);
            $80 = __THREW__; __THREW__ = 0;
            $81 = $80&1;
            if ($81) {
             break;
            }
            __THREW__ = 0;
            $82 = (invoke_iii(2754,(1167664|0),2)|0);
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if ($84) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($65|0));
            $85 = __THREW__; __THREW__ = 0;
            $86 = $85&1;
            if ($86) {
             break;
            }
            __THREW__ = 0;
            $87 = (invoke_iii(2730,(2150320|0),($65|0))|0);
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if ($89) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($82|0));
            $90 = __THREW__; __THREW__ = 0;
            $91 = $90&1;
            if ($91) {
             break;
            }
            $92 = (($82) + 12|0);
            $93 = HEAP32[$92>>2]|0;
            $94 = ($93|0)==(0);
            if ($94) {
             __THREW__ = 0;
             $95 = (invoke_i(132)|0);
             $96 = __THREW__; __THREW__ = 0;
             $97 = $96&1;
             if ($97) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($95|0));
             $98 = __THREW__; __THREW__ = 0;
             $99 = $98&1;
             if ($99) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($82|0),($87|0));
            $100 = __THREW__; __THREW__ = 0;
            $101 = $100&1;
            if ($101) {
             break;
            }
            $102 = (($82) + 16|0);
            HEAP32[$102>>2] = $87;
            __THREW__ = 0;
            invoke_vi(3799,($enumType|0));
            $103 = __THREW__; __THREW__ = 0;
            $104 = $103&1;
            if ($104) {
             break;
            }
            __THREW__ = 0;
            $105 = (invoke_iii(2730,(2150320|0),($enumType|0))|0);
            $106 = __THREW__; __THREW__ = 0;
            $107 = $106&1;
            if ($107) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($82|0));
            $108 = __THREW__; __THREW__ = 0;
            $109 = $108&1;
            if ($109) {
             break;
            }
            $110 = HEAP32[$92>>2]|0;
            $111 = ($110>>>0)<(2);
            if ($111) {
             __THREW__ = 0;
             $112 = (invoke_i(132)|0);
             $113 = __THREW__; __THREW__ = 0;
             $114 = $113&1;
             if ($114) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($112|0));
             $115 = __THREW__; __THREW__ = 0;
             $116 = $115&1;
             if ($116) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($82|0),($105|0));
            $117 = __THREW__; __THREW__ = 0;
            $118 = $117&1;
            if ($118) {
             break;
            }
            $119 = HEAP32[$82>>2]|0;
            $120 = (($119) + 92|0);
            $121 = HEAP32[$120>>2]|0;
            $122 = (($102) + ($121)|0);
            HEAP32[$122>>2] = $105;
            $123 = HEAP32[3011496>>2]|0;
            __THREW__ = 0;
            $124 = (invoke_iiiii(99,0,($77|0),($123|0),($82|0))|0);
            $125 = __THREW__; __THREW__ = 0;
            $126 = $125&1;
            if ($126) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2560072|0))|0);
            $127 = __THREW__; __THREW__ = 0;
            $128 = $127&1;
            if ($128) {
             break;
            }
            __THREW__ = 0;
            $129 = (invoke_ii(3469,(2560072|0))|0);
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1924,($129|0),($124|0));
            $132 = __THREW__; __THREW__ = 0;
            $133 = $132&1;
            if ($133) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3830,($129|0));
            $134 = __THREW__; __THREW__ = 0;
            $135 = $134&1;
            if ($135) {
             break;
            }
            // unreachable;
           }
          } else {
           $136 = ($65|0)==($68|0);
           if (!($136)) {
            __THREW__ = 0;
            $137 = (invoke_ii(1982,(0|0))|0);
            $138 = __THREW__; __THREW__ = 0;
            $139 = $138&1;
            if ($139) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(1167664|0))|0);
            $140 = __THREW__; __THREW__ = 0;
            $141 = $140&1;
            if ($141) {
             break;
            }
            __THREW__ = 0;
            $142 = (invoke_iii(2754,(1167664|0),2)|0);
            $143 = __THREW__; __THREW__ = 0;
            $144 = $143&1;
            if ($144) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($65|0));
            $145 = __THREW__; __THREW__ = 0;
            $146 = $145&1;
            if ($146) {
             break;
            }
            __THREW__ = 0;
            $147 = (invoke_iii(2730,(2150320|0),($65|0))|0);
            $148 = __THREW__; __THREW__ = 0;
            $149 = $148&1;
            if ($149) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($142|0));
            $150 = __THREW__; __THREW__ = 0;
            $151 = $150&1;
            if ($151) {
             break;
            }
            $152 = (($142) + 12|0);
            $153 = HEAP32[$152>>2]|0;
            $154 = ($153|0)==(0);
            if ($154) {
             __THREW__ = 0;
             $155 = (invoke_i(132)|0);
             $156 = __THREW__; __THREW__ = 0;
             $157 = $156&1;
             if ($157) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($155|0));
             $158 = __THREW__; __THREW__ = 0;
             $159 = $158&1;
             if ($159) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($142|0),($147|0));
            $160 = __THREW__; __THREW__ = 0;
            $161 = $160&1;
            if ($161) {
             break;
            }
            $162 = (($142) + 16|0);
            HEAP32[$162>>2] = $147;
            __THREW__ = 0;
            invoke_vi(3799,($68|0));
            $163 = __THREW__; __THREW__ = 0;
            $164 = $163&1;
            if ($164) {
             break;
            }
            __THREW__ = 0;
            $165 = (invoke_iii(2730,(2150320|0),($68|0))|0);
            $166 = __THREW__; __THREW__ = 0;
            $167 = $166&1;
            if ($167) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($142|0));
            $168 = __THREW__; __THREW__ = 0;
            $169 = $168&1;
            if ($169) {
             break;
            }
            $170 = HEAP32[$152>>2]|0;
            $171 = ($170>>>0)<(2);
            if ($171) {
             __THREW__ = 0;
             $172 = (invoke_i(132)|0);
             $173 = __THREW__; __THREW__ = 0;
             $174 = $173&1;
             if ($174) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($172|0));
             $175 = __THREW__; __THREW__ = 0;
             $176 = $175&1;
             if ($176) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($142|0),($165|0));
            $177 = __THREW__; __THREW__ = 0;
            $178 = $177&1;
            if ($178) {
             break;
            }
            $179 = HEAP32[$142>>2]|0;
            $180 = (($179) + 92|0);
            $181 = HEAP32[$180>>2]|0;
            $182 = (($162) + ($181)|0);
            HEAP32[$182>>2] = $165;
            $183 = HEAP32[3011504>>2]|0;
            __THREW__ = 0;
            $184 = (invoke_iiiii(99,0,($137|0),($183|0),($142|0))|0);
            $185 = __THREW__; __THREW__ = 0;
            $186 = $185&1;
            if ($186) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2560072|0))|0);
            $187 = __THREW__; __THREW__ = 0;
            $188 = $187&1;
            if ($188) {
             break;
            }
            __THREW__ = 0;
            $189 = (invoke_ii(3469,(2560072|0))|0);
            $190 = __THREW__; __THREW__ = 0;
            $191 = $190&1;
            if ($191) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1924,($189|0),($184|0));
            $192 = __THREW__; __THREW__ = 0;
            $193 = $192&1;
            if ($193) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3830,($189|0));
            $194 = __THREW__; __THREW__ = 0;
            $195 = $194&1;
            if ($195) {
             break;
            }
            // unreachable;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($format|0));
          $196 = __THREW__; __THREW__ = 0;
          $197 = $196&1;
          if (!($197)) {
           __THREW__ = 0;
           $198 = (invoke_ii(1816,($format|0))|0);
           $199 = __THREW__; __THREW__ = 0;
           $200 = $199&1;
           if (!($200)) {
            $201 = ($198|0)==(1);
            if (!($201)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2603176|0))|0);
             $202 = __THREW__; __THREW__ = 0;
             $203 = $202&1;
             if ($203) {
              break;
             }
             __THREW__ = 0;
             $204 = (invoke_ii(3469,(2603176|0))|0);
             $205 = __THREW__; __THREW__ = 0;
             $206 = $205&1;
             if ($206) {
              break;
             }
             $207 = HEAP32[3011512>>2]|0;
             __THREW__ = 0;
             invoke_vii(1940,($204|0),($207|0));
             $208 = __THREW__; __THREW__ = 0;
             $209 = $208&1;
             if ($209) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3830,($204|0));
             $210 = __THREW__; __THREW__ = 0;
             $211 = $210&1;
             if ($211) {
              break;
             }
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($format|0));
            $212 = __THREW__; __THREW__ = 0;
            $213 = $212&1;
            if (!($213)) {
             __THREW__ = 0;
             $214 = (invoke_iii(621,($format|0),0)|0);
             $215 = __THREW__; __THREW__ = 0;
             $216 = $215&1;
             if (!($216)) {
              do {
               if ((($214<<16>>16) == 103) | (($214<<16>>16) == 71)) {
                HEAP32[$0>>2] = 1691088;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
                $217 = (invoke_iii(772,0,($$byval_copy1|0))|0);
                $218 = __THREW__; __THREW__ = 0;
                $219 = $218&1;
                if ($219) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3799,($enumType|0));
                $220 = __THREW__; __THREW__ = 0;
                $221 = $220&1;
                if ($221) {
                 break L1;
                }
                __THREW__ = 0;
                $222 = (invoke_iiiii(315,(2151112|0),($enumType|0),($217|0),0)|0);
                $223 = __THREW__; __THREW__ = 0;
                $224 = $223&1;
                if ($224) {
                 break L1;
                }
                if ($222) {
                 break;
                }
                __THREW__ = 0;
                $225 = (invoke_iiii(664,0,($enumType|0),($value|0))|0);
                $226 = __THREW__; __THREW__ = 0;
                $227 = $226&1;
                if ($227) {
                 break L1;
                }
                $228 = ($225|0)==(0|0);
                if (!($228)) {
                 $$0 = $225;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                __THREW__ = 0;
                invoke_vi(3799,($value|0));
                $229 = __THREW__; __THREW__ = 0;
                $230 = $229&1;
                if ($230) {
                 break L1;
                }
                __THREW__ = 0;
                $231 = (invoke_iii(2730,(2149112|0),($value|0))|0);
                $232 = __THREW__; __THREW__ = 0;
                $233 = $232&1;
                if ($233) {
                 break L1;
                }
                $$0 = $231;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               } else if (!((($214<<16>>16) == 70) | (($214<<16>>16) == 102))) {
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $237 = __THREW__; __THREW__ = 0;
                $238 = $237&1;
                if ($238) {
                 break L1;
                }
                $239 = HEAP8[((2191608 + 116|0))>>0]|0;
                $240 = ($239<<24>>24)==(0);
                if ($240) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $241 = __THREW__; __THREW__ = 0;
                 $242 = $241&1;
                 if ($242) {
                  break L1;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $243 = __THREW__; __THREW__ = 0;
                 $244 = $243&1;
                 if ($244) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3831,(2191608|0));
                 $245 = __THREW__; __THREW__ = 0;
                 $246 = $245&1;
                 if ($246) {
                  break L1;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $247 = __THREW__; __THREW__ = 0;
                $248 = $247&1;
                if ($248) {
                 break L1;
                }
                if ((($214<<16>>16) == 120)) {
                 __THREW__ = 0;
                 $252 = (invoke_iiiii(108,0,($enumType|0),($value|0),0)|0);
                 $253 = __THREW__; __THREW__ = 0;
                 $254 = $253&1;
                 if ($254) {
                  break L1;
                 } else {
                  $$0 = $252;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                } else if ((($214<<16>>16) == 100) | (($214<<16>>16) == 68)) {
                 HEAP32[$1>>2] = 2045848;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
                 $255 = (invoke_iii(772,0,($$byval_copy1|0))|0);
                 $256 = __THREW__; __THREW__ = 0;
                 $257 = $256&1;
                 if ($257) {
                  break L1;
                 }
                 $258 = ($68|0)==($255|0);
                 if ($258) {
                  __THREW__ = 0;
                  $259 = (invoke_iii(1089,(0|0),($value|0))|0);
                  $260 = tempRet0;
                  $261 = __THREW__; __THREW__ = 0;
                  $262 = $261&1;
                  if ($262) {
                   break L1;
                  }
                  $263 = $V_4;
                  $264 = $263;
                  HEAP32[$264>>2] = $259;
                  $265 = (($263) + 4)|0;
                  $266 = $265;
                  HEAP32[$266>>2] = $260;
                  __THREW__ = 0;
                  $267 = (invoke_ii(1799,($V_4|0))|0);
                  $268 = __THREW__; __THREW__ = 0;
                  $269 = $268&1;
                  if ($269) {
                   break L1;
                  } else {
                   $$0 = $267;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 } else {
                  __THREW__ = 0;
                  $270 = (invoke_iii(1055,(0|0),($value|0))|0);
                  $271 = tempRet0;
                  $272 = __THREW__; __THREW__ = 0;
                  $273 = $272&1;
                  if ($273) {
                   break L1;
                  }
                  $274 = $V_5;
                  $275 = $274;
                  HEAP32[$275>>2] = $270;
                  $276 = (($274) + 4)|0;
                  $277 = $276;
                  HEAP32[$277>>2] = $271;
                  __THREW__ = 0;
                  $278 = (invoke_ii(1795,($V_5|0))|0);
                  $279 = __THREW__; __THREW__ = 0;
                  $280 = $279&1;
                  if ($280) {
                   break L1;
                  } else {
                   $$0 = $278;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                } else if ((($214<<16>>16) == 88)) {
                 __THREW__ = 0;
                 $249 = (invoke_iiiii(108,0,($enumType|0),($value|0),1)|0);
                 $250 = __THREW__; __THREW__ = 0;
                 $251 = $250&1;
                 if ($251) {
                  break L1;
                 } else {
                  $$0 = $249;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                } else {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2603176|0))|0);
                 $281 = __THREW__; __THREW__ = 0;
                 $282 = $281&1;
                 if ($282) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $283 = (invoke_ii(3469,(2603176|0))|0);
                 $284 = __THREW__; __THREW__ = 0;
                 $285 = $284&1;
                 if ($285) {
                  break L1;
                 }
                 $286 = HEAP32[3011520>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(1940,($283|0),($286|0));
                 $287 = __THREW__; __THREW__ = 0;
                 $288 = $287&1;
                 if ($288) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3830,($283|0));
                 $289 = __THREW__; __THREW__ = 0;
                 $290 = $289&1;
                 if ($290) {
                  break L1;
                 }
                 // unreachable;
                }
               }
              } while(0);
              __THREW__ = 0;
              $234 = (invoke_iiii(669,0,($enumType|0),($value|0))|0);
              $235 = __THREW__; __THREW__ = 0;
              $236 = $235&1;
              if (!($236)) {
               $$0 = $234;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216192);
 __THREW__ = 0;
 invoke_v(456);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2191608 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2191608 + 80|0))>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     $18 = (invoke_iiii(574,0,($format|0),($17|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = ($format|0)==(0|0);
      $or$cond = $18 | $21;
      $22 = HEAP32[3011072>>2]|0;
      $$0 = $or$cond ? $22 : $format;
      __THREW__ = 0;
      $23 = (invoke_ii(1782,($__this|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       $26 = (invoke_ii(1847,($__this|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        $29 = (invoke_iiiii(109,0,($23|0),($26|0),($$0|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($29|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z29mscorlib_System_Enum_m_EqualsP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216400);
 __THREW__ = 0;
 $0 = (invoke_iiii(426,0,($__this|0),($obj|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z35mscorlib_System_Enum_m_get_hashcodeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216448);
 $0 = HEAP32[2216496>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2216504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2216496>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Enum_m_GetHashCodeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216536);
 __THREW__ = 0;
 $0 = (invoke_ii(1850,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z40mscorlib_System_Enum_m_FormatSpecifier_XP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_b($__this,$enumType,$value,$upper) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 $value = $value|0;
 $upper = $upper|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B13_0$0 = 0, $G_B17_0$0 = 0, $G_B21_0$0 = 0, $G_B25_0$0 = 0;
 var $G_B29_0$0 = 0, $G_B33_0$0 = 0, $G_B5_0$0 = 0, $G_B9_0$0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $V_5 = 0, $V_6 = 0, $V_7 = 0, $V_8 = 0, $_stackTraceSentry = 0, $_str_i_25f$val = 0, $_str_i_260$val = 0, $_str_i_261$val = 0, $_str_i_262$val = 0, $_str_i_263$val = 0, $_str_i_264$val = 0, $_str_i_265$val = 0;
 var $_str_i_266$val = 0, $_str_i_267$val = 0, $_str_i_268$val = 0, $_str_i_269$val = 0, $_str_i_26a$val = 0, $_str_i_26b$val = 0, $_str_i_26c$val = 0, $_str_i_26d$val = 0, $_str_i_26e$val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 24|0;
 $V_1 = sp + 32|0;
 $V_2 = sp + 33|0;
 $V_3 = sp + 30|0;
 $V_4 = sp + 28|0;
 $V_5 = sp + 16|0;
 $V_6 = sp + 20|0;
 $V_7 = sp;
 $V_8 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216584);
 HEAP8[$V_1>>0] = 0;
 HEAP8[$V_2>>0] = 0;
 HEAP16[$V_3>>1] = 0;
 HEAP16[$V_4>>1] = 0;
 HEAP32[$V_5>>2] = 0;
 HEAP32[$V_6>>2] = 0;
 $0 = $V_7;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = $V_8;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 __THREW__ = 0;
 invoke_v(457);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 L1: do {
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_iii(771,0,($enumType|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    switch ($10|0) {
    case 11:  {
     __THREW__ = 0;
     (invoke_ii(2996,(2162248|0))|0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      break L1;
     }
     __THREW__ = 0;
     $71 = (invoke_iii(2753,($value|0),(2162248|0))|0);
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      break L1;
     }
     $74 = $71;
     $75 = $74;
     $76 = HEAP32[$75>>2]|0;
     $77 = (($74) + 4)|0;
     $78 = $77;
     $79 = HEAP32[$78>>2]|0;
     $80 = $V_7;
     $81 = $80;
     HEAP32[$81>>2] = $76;
     $82 = (($80) + 4)|0;
     $83 = $82;
     HEAP32[$83>>2] = $79;
     $_str_i_26b$val = HEAP32[3011184>>2]|0;
     $_str_i_26c$val = HEAP32[3011192>>2]|0;
     $G_B29_0$0 = $upper ? $_str_i_26b$val : $_str_i_26c$val;
     __THREW__ = 0;
     $84 = (invoke_iii(490,($V_7|0),($G_B29_0$0|0))|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      break L1;
     } else {
      $$0 = $84;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 12:  {
     __THREW__ = 0;
     (invoke_ii(2996,(2167208|0))|0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      break L1;
     }
     __THREW__ = 0;
     $89 = (invoke_iii(2753,($value|0),(2167208|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      break L1;
     }
     $92 = $89;
     $93 = $92;
     $94 = HEAP32[$93>>2]|0;
     $95 = (($92) + 4)|0;
     $96 = $95;
     $97 = HEAP32[$96>>2]|0;
     $98 = $V_8;
     $99 = $98;
     HEAP32[$99>>2] = $94;
     $100 = (($98) + 4)|0;
     $101 = $100;
     HEAP32[$101>>2] = $97;
     $_str_i_26d$val = HEAP32[3011200>>2]|0;
     $_str_i_26e$val = HEAP32[3011208>>2]|0;
     $G_B33_0$0 = $upper ? $_str_i_26d$val : $_str_i_26e$val;
     __THREW__ = 0;
     $102 = (invoke_iii(520,($V_8|0),($G_B33_0$0|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      break L1;
     } else {
      $$0 = $102;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 10:  {
     __THREW__ = 0;
     (invoke_ii(2996,(2164560|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break L1;
     }
     __THREW__ = 0;
     $62 = (invoke_iii(2753,($value|0),(2164560|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      break L1;
     }
     $65 = HEAP32[$62>>2]|0;
     HEAP32[$V_6>>2] = $65;
     $_str_i_269$val = HEAP32[3011168>>2]|0;
     $_str_i_26a$val = HEAP32[3011176>>2]|0;
     $G_B25_0$0 = $upper ? $_str_i_269$val : $_str_i_26a$val;
     __THREW__ = 0;
     $66 = (invoke_iii(506,($V_6|0),($G_B25_0$0|0))|0);
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break L1;
     } else {
      $$0 = $66;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 7:  {
     __THREW__ = 0;
     (invoke_ii(2996,(2173776|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break L1;
     }
     __THREW__ = 0;
     $35 = (invoke_iii(2753,($value|0),(2173776|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break L1;
     }
     $38 = HEAP16[$35>>1]|0;
     HEAP16[$V_3>>1] = $38;
     $_str_i_263$val = HEAP32[3011120>>2]|0;
     $_str_i_264$val = HEAP32[3011128>>2]|0;
     $G_B13_0$0 = $upper ? $_str_i_263$val : $_str_i_264$val;
     __THREW__ = 0;
     $39 = (invoke_iii(568,($V_3|0),($G_B13_0$0|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break L1;
     } else {
      $$0 = $39;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 5:  {
     __THREW__ = 0;
     (invoke_ii(2996,(2171616|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break L1;
     }
     __THREW__ = 0;
     $17 = (invoke_iii(2753,($value|0),(2171616|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break L1;
     }
     $20 = HEAP8[$17>>0]|0;
     HEAP8[$V_1>>0] = $20;
     $_str_i_25f$val = HEAP32[3011088>>2]|0;
     $_str_i_260$val = HEAP32[3011096>>2]|0;
     $G_B5_0$0 = $upper ? $_str_i_25f$val : $_str_i_260$val;
     __THREW__ = 0;
     $21 = (invoke_iii(552,($V_1|0),($G_B5_0$0|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break L1;
     } else {
      $$0 = $21;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 9:  {
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break L1;
     }
     __THREW__ = 0;
     $53 = (invoke_iii(2753,($value|0),(2155952|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break L1;
     }
     $56 = HEAP32[$53>>2]|0;
     HEAP32[$V_5>>2] = $56;
     $_str_i_267$val = HEAP32[3011152>>2]|0;
     $_str_i_268$val = HEAP32[3011160>>2]|0;
     $G_B21_0$0 = $upper ? $_str_i_267$val : $_str_i_268$val;
     __THREW__ = 0;
     $57 = (invoke_iii(476,($V_5|0),($G_B21_0$0|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break L1;
     } else {
      $$0 = $57;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 6:  {
     __THREW__ = 0;
     (invoke_ii(2996,(2169424|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break L1;
     }
     __THREW__ = 0;
     $26 = (invoke_iii(2753,($value|0),(2169424|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break L1;
     }
     $29 = HEAP8[$26>>0]|0;
     HEAP8[$V_2>>0] = $29;
     $_str_i_261$val = HEAP32[3011104>>2]|0;
     $_str_i_262$val = HEAP32[3011112>>2]|0;
     $G_B9_0$0 = $upper ? $_str_i_261$val : $_str_i_262$val;
     __THREW__ = 0;
     $30 = (invoke_iii(535,($V_2|0),($G_B9_0$0|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break L1;
     } else {
      $$0 = $30;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 8:  {
     __THREW__ = 0;
     (invoke_ii(2996,(2176024|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break L1;
     }
     __THREW__ = 0;
     $44 = (invoke_iii(2753,($value|0),(2176024|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L1;
     }
     $47 = HEAP16[$44>>1]|0;
     HEAP16[$V_4>>1] = $47;
     $_str_i_265$val = HEAP32[3011136>>2]|0;
     $_str_i_266$val = HEAP32[3011144>>2]|0;
     $G_B17_0$0 = $upper ? $_str_i_265$val : $_str_i_266$val;
     __THREW__ = 0;
     $48 = (invoke_iii(584,($V_4|0),($G_B17_0$0|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break L1;
     } else {
      $$0 = $48;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    default: {
     __THREW__ = 0;
     (invoke_ii(2996,(2246120|0))|0);
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      break L1;
     }
     __THREW__ = 0;
     $107 = (invoke_ii(3469,(2246120|0))|0);
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if ($109) {
      break L1;
     }
     $110 = HEAP32[3011216>>2]|0;
     __THREW__ = 0;
     invoke_vii(1781,($107|0),($110|0));
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3830,($107|0));
     $113 = __THREW__; __THREW__ = 0;
     $114 = $113&1;
     if ($114) {
      break L1;
     }
     // unreachable;
    }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Enum_m_FormatFlagsP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_($__this,$enumType,$value) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $$V_0$17 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0;
 var $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0;
 var $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0;
 var $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0;
 var $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0;
 var $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0;
 var $834 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B104_0$0 = 0, $G_B104_0$0$in = 0;
 var $G_B13_0$0 = 0, $G_B13_0$0$in = 0, $G_B26_0$0 = 0, $G_B26_0$0$in = 0, $G_B39_0$0 = 0, $G_B39_0$0$in = 0, $G_B52_0$0 = 0, $G_B52_0$0$in = 0, $G_B65_0$0 = 0, $G_B65_0$0$in = 0, $G_B78_0$0 = 0, $G_B78_0$0$in = 0, $G_B91_0$0 = 0, $G_B91_0$0$in = 0, $V_0$10$ph283 = 0, $V_0$10$ph287 = 0, $V_0$12$ph315 = 0, $V_0$12$ph319 = 0, $V_0$14$ph331 = 0, $V_0$14$ph335 = 0;
 var $V_0$16$ph347 = 0, $V_0$16$ph351 = 0, $V_0$17 = 0, $V_0$2$ph236 = 0, $V_0$2$ph240 = 0, $V_0$4$ph251 = 0, $V_0$4$ph255 = 0, $V_0$6$ph267 = 0, $V_0$6$ph271 = 0, $V_0$8$ph299 = 0, $V_0$8$ph303 = 0, $V_1 = 0, $V_11$0132272$in = 0, $V_11$0134 = 0, $V_11$0134$in = 0, $V_12$1$ph295 = 0, $V_12$1$ph302 = 0, $V_14$0169304$in = 0, $V_14$0171 = 0, $V_14$0171$in = 0;
 var $V_15$1$ph279 = 0, $V_15$1$ph286 = 0, $V_17$0151288$in = 0, $V_17$0153 = 0, $V_17$0153$in = 0, $V_18$1$ph311 = 0, $V_18$1$ph318 = 0, $V_20$0187320$in = 0, $V_20$0189 = 0, $V_20$0189$in = 0, $V_23$0205336$in = 0, $V_23$0207 = 0, $V_23$0207$in = 0, $V_26$0223352$in = 0, $V_26$0225 = 0, $V_26$0225$in = 0, $V_3$1$ph232 = 0, $V_3$1$ph239 = 0, $V_5$097241$in = 0, $V_5$099 = 0;
 var $V_5$099$in = 0, $V_6$1$ph247 = 0, $V_6$1$ph254 = 0, $V_8$0113256$in = 0, $V_8$0115 = 0, $V_8$0115$in = 0, $V_9$1$ph263 = 0, $V_9$1$ph270 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2216632);
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(458);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2191608 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2191608|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if (!($47)) {
     $48 = HEAP32[((2191608 + 80|0))>>2]|0;
     $49 = HEAP32[$48>>2]|0;
     __THREW__ = 0;
     invoke_viii(672,(0|0),($enumType|0),($V_1|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if (!($51)) {
      __THREW__ = 0;
      invoke_vi(3799,($value|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if (!($53)) {
       __THREW__ = 0;
       $54 = (invoke_iii(2730,(2149112|0),($value|0))|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if (!($56)) {
        $57 = HEAP32[3011368>>2]|0;
        __THREW__ = 0;
        $58 = (invoke_iiii(574,0,($54|0),($57|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if (!($60)) {
         if ($58) {
          __THREW__ = 0;
          $61 = (invoke_iiii(664,0,($enumType|0),($value|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           break;
          }
          $64 = ($61|0)==(0|0);
          $$ = $64 ? $54 : $61;
          $$0 = $$;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $65 = (($V_1) + 4|0);
         $66 = HEAP32[$65>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($66|0));
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if (!($68)) {
          __THREW__ = 0;
          $69 = (invoke_iii(759,($66|0),0)|0);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if (!($71)) {
           __THREW__ = 0;
           (invoke_ii(2996,(2218016|0))|0);
           $72 = __THREW__; __THREW__ = 0;
           $73 = $72&1;
           if (!($73)) {
            __THREW__ = 0;
            $74 = (invoke_iii(2755,($69|0),(2218016|0))|0);
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if (!($76)) {
             __THREW__ = 0;
             invoke_vi(3799,($74|0));
             $77 = __THREW__; __THREW__ = 0;
             $78 = $77&1;
             if (!($78)) {
              __THREW__ = 0;
              $79 = (invoke_iii(2729,(2215512|0),($74|0))|0);
              $80 = __THREW__; __THREW__ = 0;
              $81 = $80&1;
              if (!($81)) {
               L25: do {
                switch ($79|0) {
                case 12:  {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2167208|0))|0);
                 $711 = __THREW__; __THREW__ = 0;
                 $712 = $711&1;
                 if ($712) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $713 = (invoke_iii(2753,($value|0),(2167208|0))|0);
                 $714 = __THREW__; __THREW__ = 0;
                 $715 = $714&1;
                 if ($715) {
                  break L1;
                 }
                 $716 = $713;
                 $717 = $716;
                 $718 = HEAP32[$717>>2]|0;
                 $719 = (($716) + 4)|0;
                 $720 = $719;
                 $721 = HEAP32[$720>>2]|0;
                 $722 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($722|0));
                 $723 = __THREW__; __THREW__ = 0;
                 $724 = $723&1;
                 if ($724) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $725 = (invoke_ii(1857,($722|0))|0);
                 $726 = __THREW__; __THREW__ = 0;
                 $727 = $726&1;
                 if ($727) {
                  break L1;
                 }
                 $728 = ($725|0)>(0);
                 L31: do {
                  if ($728) {
                   $729 = (($V_1) + 8|0);
                   $749 = $718;$751 = $721;$V_0$16$ph351 = $49;$V_26$0223352$in = $725;
                   L33: while(1) {
                    $V_26$0225$in = $V_26$0223352$in;
                    while(1) {
                     $V_26$0225 = (($V_26$0225$in) + -1)|0;
                     $730 = HEAP32[$65>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($730|0));
                     $811 = __THREW__; __THREW__ = 0;
                     $812 = $811&1;
                     if ($812) {
                      label = 21;
                      break L33;
                     }
                     __THREW__ = 0;
                     $731 = (invoke_iii(759,($730|0),($V_26$0225|0))|0);
                     $732 = __THREW__; __THREW__ = 0;
                     $733 = $732&1;
                     if ($733) {
                      label = 21;
                      break L33;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2167208|0))|0);
                     $734 = __THREW__; __THREW__ = 0;
                     $735 = $734&1;
                     if ($735) {
                      label = 21;
                      break L33;
                     }
                     __THREW__ = 0;
                     $736 = (invoke_iii(2753,($731|0),(2167208|0))|0);
                     $737 = __THREW__; __THREW__ = 0;
                     $738 = $737&1;
                     if ($738) {
                      label = 21;
                      break L33;
                     }
                     $739 = $736;
                     $740 = $739;
                     $741 = HEAP32[$740>>2]|0;
                     $742 = (($739) + 4)|0;
                     $743 = $742;
                     $744 = HEAP32[$743>>2]|0;
                     $745 = ($741|0)==(0);
                     $746 = ($744|0)==(0);
                     $747 = $745 & $746;
                     if (!($747)) {
                      $748 = $741 & $749;
                      $750 = $744 & $751;
                      $752 = ($748|0)==($741|0);
                      $753 = ($750|0)==($744|0);
                      $754 = $752 & $753;
                      if ($754) {
                       break;
                      }
                     }
                     $755 = ($V_26$0225|0)>(0);
                     if ($755) {
                      $V_26$0225$in = $V_26$0225;
                     } else {
                      $814 = $749;$816 = $751;$V_0$16$ph347 = $V_0$16$ph351;
                      break L31;
                     }
                    }
                    $756 = HEAP32[$729>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($756|0));
                    $757 = __THREW__; __THREW__ = 0;
                    $758 = $757&1;
                    if ($758) {
                     label = 22;
                     break;
                    }
                    $759 = ($V_26$0225$in|0)<(1);
                    if ($759) {
                     label = 314;
                    } else {
                     $760 = (($756) + 12|0);
                     $761 = HEAP32[$760>>2]|0;
                     $762 = ($V_26$0225>>>0)<($761>>>0);
                     if (!($762)) {
                      label = 314;
                     }
                    }
                    if ((label|0) == 314) {
                     label = 0;
                     __THREW__ = 0;
                     $763 = (invoke_i(132)|0);
                     $764 = __THREW__; __THREW__ = 0;
                     $765 = $764&1;
                     if ($765) {
                      label = 22;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($763|0));
                     $766 = __THREW__; __THREW__ = 0;
                     $767 = $766&1;
                     if ($767) {
                      label = 22;
                      break;
                     }
                    }
                    $768 = HEAP32[$756>>2]|0;
                    $769 = (($756) + 16|0);
                    $770 = (($768) + 92|0);
                    $771 = HEAP32[$770>>2]|0;
                    $772 = Math_imul($771, $V_26$0225)|0;
                    $773 = (($769) + ($772)|0);
                    $774 = HEAP32[$773>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $775 = __THREW__; __THREW__ = 0;
                    $776 = $775&1;
                    if ($776) {
                     label = 22;
                     break;
                    }
                    $777 = HEAP8[((2191608 + 116|0))>>0]|0;
                    $778 = ($777<<24>>24)==(0);
                    if ($778) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $779 = __THREW__; __THREW__ = 0;
                     $780 = $779&1;
                     if ($780) {
                      label = 22;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $781 = __THREW__; __THREW__ = 0;
                     $782 = $781&1;
                     if ($782) {
                      label = 22;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3831,(2191608|0));
                     $783 = __THREW__; __THREW__ = 0;
                     $784 = $783&1;
                     if ($784) {
                      label = 22;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $785 = __THREW__; __THREW__ = 0;
                    $786 = $785&1;
                    if ($786) {
                     label = 22;
                     break;
                    }
                    $787 = HEAP32[((2191608 + 80|0))>>2]|0;
                    $788 = HEAP32[$787>>2]|0;
                    __THREW__ = 0;
                    $789 = (invoke_iiii(574,0,($V_0$16$ph351|0),($788|0))|0);
                    $790 = __THREW__; __THREW__ = 0;
                    $791 = $790&1;
                    if ($791) {
                     label = 22;
                     break;
                    }
                    if ($789) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $792 = __THREW__; __THREW__ = 0;
                     $793 = $792&1;
                     if ($793) {
                      label = 22;
                      break;
                     }
                     $794 = HEAP8[((2191608 + 116|0))>>0]|0;
                     $795 = ($794<<24>>24)==(0);
                     if ($795) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $796 = __THREW__; __THREW__ = 0;
                      $797 = $796&1;
                      if ($797) {
                       label = 22;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $798 = __THREW__; __THREW__ = 0;
                      $799 = $798&1;
                      if ($799) {
                       label = 22;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3831,(2191608|0));
                      $800 = __THREW__; __THREW__ = 0;
                      $801 = $800&1;
                      if ($801) {
                       label = 22;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $802 = __THREW__; __THREW__ = 0;
                     $803 = $802&1;
                     if ($803) {
                      label = 22;
                      break;
                     }
                     $804 = HEAP32[((2191608 + 80|0))>>2]|0;
                     $G_B104_0$0$in = $804;
                    } else {
                     $G_B104_0$0$in = 3011432;
                    }
                    $G_B104_0$0 = HEAP32[$G_B104_0$0$in>>2]|0;
                    __THREW__ = 0;
                    $805 = (invoke_iiiii(101,0,($774|0),($G_B104_0$0|0),($V_0$16$ph351|0))|0);
                    $806 = __THREW__; __THREW__ = 0;
                    $807 = $806&1;
                    if ($807) {
                     label = 22;
                     break;
                    }
                    $808 = (_i64Subtract(($749|0),($751|0),($741|0),($744|0))|0);
                    $809 = tempRet0;
                    $810 = ($V_26$0225|0)>(0);
                    if ($810) {
                     $749 = $808;$751 = $809;$V_0$16$ph351 = $805;$V_26$0223352$in = $V_26$0225;
                    } else {
                     $814 = $808;$816 = $809;$V_0$16$ph347 = $805;
                     break L31;
                    }
                   }
                   if ((label|0) == 21) {
                    $40 = ___cxa_find_matching_catch()|0;
                    $41 = tempRet0;
                    $lpad$phi$index = $40;$lpad$phi$index17 = $41;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   else if ((label|0) == 22) {
                    $42 = ___cxa_find_matching_catch()|0;
                    $43 = tempRet0;
                    $lpad$phi$index = $42;$lpad$phi$index17 = $43;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                  } else {
                   $814 = $718;$816 = $721;$V_0$16$ph347 = $49;
                  }
                 } while(0);
                 $813 = ($814|0)==(0);
                 $815 = ($816|0)==(0);
                 $817 = $813 & $815;
                 if ($817) {
                  $V_0$17 = $V_0$16$ph347;
                  break L25;
                 } else {
                  $$0 = $54;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                 break;
                }
                case 5:  {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2171616|0))|0);
                 $82 = __THREW__; __THREW__ = 0;
                 $83 = $82&1;
                 if ($83) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $84 = (invoke_iii(2753,($value|0),(2171616|0))|0);
                 $85 = __THREW__; __THREW__ = 0;
                 $86 = $85&1;
                 if ($86) {
                  break L1;
                 }
                 $87 = HEAP8[$84>>0]|0;
                 $88 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($88|0));
                 $89 = __THREW__; __THREW__ = 0;
                 $90 = $89&1;
                 if ($90) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $91 = (invoke_ii(1857,($88|0))|0);
                 $92 = __THREW__; __THREW__ = 0;
                 $93 = $92&1;
                 if ($93) {
                  break L1;
                 }
                 $94 = ($91|0)>(0);
                 L83: do {
                  if ($94) {
                   $95 = (($V_1) + 8|0);
                   $V_0$2$ph240 = $49;$V_3$1$ph239 = $87;$V_5$097241$in = $91;
                   L85: while(1) {
                    $164 = $V_3$1$ph239&255;
                    $V_5$099$in = $V_5$097241$in;
                    while(1) {
                     $V_5$099 = (($V_5$099$in) + -1)|0;
                     $96 = HEAP32[$65>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($96|0));
                     $167 = __THREW__; __THREW__ = 0;
                     $168 = $167&1;
                     if ($168) {
                      label = 7;
                      break L85;
                     }
                     __THREW__ = 0;
                     $97 = (invoke_iii(759,($96|0),($V_5$099|0))|0);
                     $98 = __THREW__; __THREW__ = 0;
                     $99 = $98&1;
                     if ($99) {
                      label = 7;
                      break L85;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2171616|0))|0);
                     $100 = __THREW__; __THREW__ = 0;
                     $101 = $100&1;
                     if ($101) {
                      label = 7;
                      break L85;
                     }
                     __THREW__ = 0;
                     $102 = (invoke_iii(2753,($97|0),(2171616|0))|0);
                     $103 = __THREW__; __THREW__ = 0;
                     $104 = $103&1;
                     if ($104) {
                      label = 7;
                      break L85;
                     }
                     $105 = HEAP8[$102>>0]|0;
                     $106 = ($105<<24>>24)==(0);
                     if (!($106)) {
                      $107 = $105&255;
                      $108 = $105 & $V_3$1$ph239;
                      $109 = ($108<<24>>24)==($105<<24>>24);
                      if ($109) {
                       break;
                      }
                     }
                     $110 = ($V_5$099|0)>(0);
                     if ($110) {
                      $V_5$099$in = $V_5$099;
                     } else {
                      $V_0$2$ph236 = $V_0$2$ph240;$V_3$1$ph232 = $V_3$1$ph239;
                      break L83;
                     }
                    }
                    $111 = HEAP32[$95>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($111|0));
                    $112 = __THREW__; __THREW__ = 0;
                    $113 = $112&1;
                    if ($113) {
                     label = 8;
                     break;
                    }
                    $114 = ($V_5$099$in|0)<(1);
                    if ($114) {
                     label = 55;
                    } else {
                     $115 = (($111) + 12|0);
                     $116 = HEAP32[$115>>2]|0;
                     $117 = ($V_5$099>>>0)<($116>>>0);
                     if (!($117)) {
                      label = 55;
                     }
                    }
                    if ((label|0) == 55) {
                     label = 0;
                     __THREW__ = 0;
                     $118 = (invoke_i(132)|0);
                     $119 = __THREW__; __THREW__ = 0;
                     $120 = $119&1;
                     if ($120) {
                      label = 8;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($118|0));
                     $121 = __THREW__; __THREW__ = 0;
                     $122 = $121&1;
                     if ($122) {
                      label = 8;
                      break;
                     }
                    }
                    $123 = HEAP32[$111>>2]|0;
                    $124 = (($111) + 16|0);
                    $125 = (($123) + 92|0);
                    $126 = HEAP32[$125>>2]|0;
                    $127 = Math_imul($126, $V_5$099)|0;
                    $128 = (($124) + ($127)|0);
                    $129 = HEAP32[$128>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $130 = __THREW__; __THREW__ = 0;
                    $131 = $130&1;
                    if ($131) {
                     label = 8;
                     break;
                    }
                    $132 = HEAP8[((2191608 + 116|0))>>0]|0;
                    $133 = ($132<<24>>24)==(0);
                    if ($133) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $134 = __THREW__; __THREW__ = 0;
                     $135 = $134&1;
                     if ($135) {
                      label = 8;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $136 = __THREW__; __THREW__ = 0;
                     $137 = $136&1;
                     if ($137) {
                      label = 8;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3831,(2191608|0));
                     $138 = __THREW__; __THREW__ = 0;
                     $139 = $138&1;
                     if ($139) {
                      label = 8;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $140 = __THREW__; __THREW__ = 0;
                    $141 = $140&1;
                    if ($141) {
                     label = 8;
                     break;
                    }
                    $142 = HEAP32[((2191608 + 80|0))>>2]|0;
                    $143 = HEAP32[$142>>2]|0;
                    __THREW__ = 0;
                    $144 = (invoke_iiii(574,0,($V_0$2$ph240|0),($143|0))|0);
                    $145 = __THREW__; __THREW__ = 0;
                    $146 = $145&1;
                    if ($146) {
                     label = 8;
                     break;
                    }
                    if ($144) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $147 = __THREW__; __THREW__ = 0;
                     $148 = $147&1;
                     if ($148) {
                      label = 8;
                      break;
                     }
                     $149 = HEAP8[((2191608 + 116|0))>>0]|0;
                     $150 = ($149<<24>>24)==(0);
                     if ($150) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $151 = __THREW__; __THREW__ = 0;
                      $152 = $151&1;
                      if ($152) {
                       label = 8;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $153 = __THREW__; __THREW__ = 0;
                      $154 = $153&1;
                      if ($154) {
                       label = 8;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3831,(2191608|0));
                      $155 = __THREW__; __THREW__ = 0;
                      $156 = $155&1;
                      if ($156) {
                       label = 8;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $157 = __THREW__; __THREW__ = 0;
                     $158 = $157&1;
                     if ($158) {
                      label = 8;
                      break;
                     }
                     $159 = HEAP32[((2191608 + 80|0))>>2]|0;
                     $G_B13_0$0$in = $159;
                    } else {
                     $G_B13_0$0$in = 3011376;
                    }
                    $G_B13_0$0 = HEAP32[$G_B13_0$0$in>>2]|0;
                    __THREW__ = 0;
                    $160 = (invoke_iiiii(101,0,($129|0),($G_B13_0$0|0),($V_0$2$ph240|0))|0);
                    $161 = __THREW__; __THREW__ = 0;
                    $162 = $161&1;
                    if ($162) {
                     label = 8;
                     break;
                    }
                    $163 = (($164) - ($107))|0;
                    $165 = $163&255;
                    $166 = ($V_5$099|0)>(0);
                    if ($166) {
                     $V_0$2$ph240 = $160;$V_3$1$ph239 = $165;$V_5$097241$in = $V_5$099;
                    } else {
                     $V_0$2$ph236 = $160;$V_3$1$ph232 = $165;
                     break L83;
                    }
                   }
                   if ((label|0) == 7) {
                    $12 = ___cxa_find_matching_catch()|0;
                    $13 = tempRet0;
                    $lpad$phi$index = $12;$lpad$phi$index17 = $13;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   else if ((label|0) == 8) {
                    $14 = ___cxa_find_matching_catch()|0;
                    $15 = tempRet0;
                    $lpad$phi$index = $14;$lpad$phi$index17 = $15;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                  } else {
                   $V_0$2$ph236 = $49;$V_3$1$ph232 = $87;
                  }
                 } while(0);
                 $169 = ($V_3$1$ph232<<24>>24)==(0);
                 if ($169) {
                  $V_0$17 = $V_0$2$ph236;
                  break L25;
                 } else {
                  $$0 = $54;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                 break;
                }
                case 6:  {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2169424|0))|0);
                 $170 = __THREW__; __THREW__ = 0;
                 $171 = $170&1;
                 if ($171) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $172 = (invoke_iii(2753,($value|0),(2169424|0))|0);
                 $173 = __THREW__; __THREW__ = 0;
                 $174 = $173&1;
                 if ($174) {
                  break L1;
                 }
                 $175 = HEAP8[$172>>0]|0;
                 $176 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($176|0));
                 $177 = __THREW__; __THREW__ = 0;
                 $178 = $177&1;
                 if ($178) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $179 = (invoke_ii(1857,($176|0))|0);
                 $180 = __THREW__; __THREW__ = 0;
                 $181 = $180&1;
                 if ($181) {
                  break L1;
                 }
                 $182 = ($179|0)>(0);
                 L135: do {
                  if ($182) {
                   $183 = (($V_1) + 8|0);
                   $V_0$4$ph255 = $49;$V_6$1$ph254 = $175;$V_8$0113256$in = $179;
                   L137: while(1) {
                    $252 = $V_6$1$ph254&255;
                    $V_8$0115$in = $V_8$0113256$in;
                    while(1) {
                     $V_8$0115 = (($V_8$0115$in) + -1)|0;
                     $184 = HEAP32[$65>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($184|0));
                     $255 = __THREW__; __THREW__ = 0;
                     $256 = $255&1;
                     if ($256) {
                      label = 9;
                      break L137;
                     }
                     __THREW__ = 0;
                     $185 = (invoke_iii(759,($184|0),($V_8$0115|0))|0);
                     $186 = __THREW__; __THREW__ = 0;
                     $187 = $186&1;
                     if ($187) {
                      label = 9;
                      break L137;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2169424|0))|0);
                     $188 = __THREW__; __THREW__ = 0;
                     $189 = $188&1;
                     if ($189) {
                      label = 9;
                      break L137;
                     }
                     __THREW__ = 0;
                     $190 = (invoke_iii(2753,($185|0),(2169424|0))|0);
                     $191 = __THREW__; __THREW__ = 0;
                     $192 = $191&1;
                     if ($192) {
                      label = 9;
                      break L137;
                     }
                     $193 = HEAP8[$190>>0]|0;
                     $194 = ($193<<24>>24)==(0);
                     if (!($194)) {
                      $195 = $193&255;
                      $196 = $193 & $V_6$1$ph254;
                      $197 = ($196<<24>>24)==($193<<24>>24);
                      if ($197) {
                       break;
                      }
                     }
                     $198 = ($V_8$0115|0)>(0);
                     if ($198) {
                      $V_8$0115$in = $V_8$0115;
                     } else {
                      $V_0$4$ph251 = $V_0$4$ph255;$V_6$1$ph247 = $V_6$1$ph254;
                      break L135;
                     }
                    }
                    $199 = HEAP32[$183>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($199|0));
                    $200 = __THREW__; __THREW__ = 0;
                    $201 = $200&1;
                    if ($201) {
                     label = 10;
                     break;
                    }
                    $202 = ($V_8$0115$in|0)<(1);
                    if ($202) {
                     label = 92;
                    } else {
                     $203 = (($199) + 12|0);
                     $204 = HEAP32[$203>>2]|0;
                     $205 = ($V_8$0115>>>0)<($204>>>0);
                     if (!($205)) {
                      label = 92;
                     }
                    }
                    if ((label|0) == 92) {
                     label = 0;
                     __THREW__ = 0;
                     $206 = (invoke_i(132)|0);
                     $207 = __THREW__; __THREW__ = 0;
                     $208 = $207&1;
                     if ($208) {
                      label = 10;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($206|0));
                     $209 = __THREW__; __THREW__ = 0;
                     $210 = $209&1;
                     if ($210) {
                      label = 10;
                      break;
                     }
                    }
                    $211 = HEAP32[$199>>2]|0;
                    $212 = (($199) + 16|0);
                    $213 = (($211) + 92|0);
                    $214 = HEAP32[$213>>2]|0;
                    $215 = Math_imul($214, $V_8$0115)|0;
                    $216 = (($212) + ($215)|0);
                    $217 = HEAP32[$216>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $218 = __THREW__; __THREW__ = 0;
                    $219 = $218&1;
                    if ($219) {
                     label = 10;
                     break;
                    }
                    $220 = HEAP8[((2191608 + 116|0))>>0]|0;
                    $221 = ($220<<24>>24)==(0);
                    if ($221) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $222 = __THREW__; __THREW__ = 0;
                     $223 = $222&1;
                     if ($223) {
                      label = 10;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $224 = __THREW__; __THREW__ = 0;
                     $225 = $224&1;
                     if ($225) {
                      label = 10;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3831,(2191608|0));
                     $226 = __THREW__; __THREW__ = 0;
                     $227 = $226&1;
                     if ($227) {
                      label = 10;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $228 = __THREW__; __THREW__ = 0;
                    $229 = $228&1;
                    if ($229) {
                     label = 10;
                     break;
                    }
                    $230 = HEAP32[((2191608 + 80|0))>>2]|0;
                    $231 = HEAP32[$230>>2]|0;
                    __THREW__ = 0;
                    $232 = (invoke_iiii(574,0,($V_0$4$ph255|0),($231|0))|0);
                    $233 = __THREW__; __THREW__ = 0;
                    $234 = $233&1;
                    if ($234) {
                     label = 10;
                     break;
                    }
                    if ($232) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $235 = __THREW__; __THREW__ = 0;
                     $236 = $235&1;
                     if ($236) {
                      label = 10;
                      break;
                     }
                     $237 = HEAP8[((2191608 + 116|0))>>0]|0;
                     $238 = ($237<<24>>24)==(0);
                     if ($238) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $239 = __THREW__; __THREW__ = 0;
                      $240 = $239&1;
                      if ($240) {
                       label = 10;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $241 = __THREW__; __THREW__ = 0;
                      $242 = $241&1;
                      if ($242) {
                       label = 10;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3831,(2191608|0));
                      $243 = __THREW__; __THREW__ = 0;
                      $244 = $243&1;
                      if ($244) {
                       label = 10;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $245 = __THREW__; __THREW__ = 0;
                     $246 = $245&1;
                     if ($246) {
                      label = 10;
                      break;
                     }
                     $247 = HEAP32[((2191608 + 80|0))>>2]|0;
                     $G_B26_0$0$in = $247;
                    } else {
                     $G_B26_0$0$in = 3011384;
                    }
                    $G_B26_0$0 = HEAP32[$G_B26_0$0$in>>2]|0;
                    __THREW__ = 0;
                    $248 = (invoke_iiiii(101,0,($217|0),($G_B26_0$0|0),($V_0$4$ph255|0))|0);
                    $249 = __THREW__; __THREW__ = 0;
                    $250 = $249&1;
                    if ($250) {
                     label = 10;
                     break;
                    }
                    $251 = (($252) - ($195))|0;
                    $253 = $251&255;
                    $254 = ($V_8$0115|0)>(0);
                    if ($254) {
                     $V_0$4$ph255 = $248;$V_6$1$ph254 = $253;$V_8$0113256$in = $V_8$0115;
                    } else {
                     $V_0$4$ph251 = $248;$V_6$1$ph247 = $253;
                     break L135;
                    }
                   }
                   if ((label|0) == 9) {
                    $16 = ___cxa_find_matching_catch()|0;
                    $17 = tempRet0;
                    $lpad$phi$index = $16;$lpad$phi$index17 = $17;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   else if ((label|0) == 10) {
                    $18 = ___cxa_find_matching_catch()|0;
                    $19 = tempRet0;
                    $lpad$phi$index = $18;$lpad$phi$index17 = $19;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                  } else {
                   $V_0$4$ph251 = $49;$V_6$1$ph247 = $175;
                  }
                 } while(0);
                 $257 = ($V_6$1$ph247<<24>>24)==(0);
                 if ($257) {
                  $V_0$17 = $V_0$4$ph251;
                  break L25;
                 } else {
                  $$0 = $54;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                 break;
                }
                case 7:  {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2173776|0))|0);
                 $258 = __THREW__; __THREW__ = 0;
                 $259 = $258&1;
                 if ($259) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $260 = (invoke_iii(2753,($value|0),(2173776|0))|0);
                 $261 = __THREW__; __THREW__ = 0;
                 $262 = $261&1;
                 if ($262) {
                  break L1;
                 }
                 $263 = HEAP16[$260>>1]|0;
                 $264 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($264|0));
                 $265 = __THREW__; __THREW__ = 0;
                 $266 = $265&1;
                 if ($266) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $267 = (invoke_ii(1857,($264|0))|0);
                 $268 = __THREW__; __THREW__ = 0;
                 $269 = $268&1;
                 if ($269) {
                  break L1;
                 }
                 $270 = ($267|0)>(0);
                 L187: do {
                  if ($270) {
                   $271 = (($V_1) + 8|0);
                   $V_0$6$ph271 = $49;$V_11$0132272$in = $267;$V_9$1$ph270 = $263;
                   L189: while(1) {
                    $340 = $V_9$1$ph270&65535;
                    $V_11$0134$in = $V_11$0132272$in;
                    while(1) {
                     $V_11$0134 = (($V_11$0134$in) + -1)|0;
                     $272 = HEAP32[$65>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($272|0));
                     $343 = __THREW__; __THREW__ = 0;
                     $344 = $343&1;
                     if ($344) {
                      label = 11;
                      break L189;
                     }
                     __THREW__ = 0;
                     $273 = (invoke_iii(759,($272|0),($V_11$0134|0))|0);
                     $274 = __THREW__; __THREW__ = 0;
                     $275 = $274&1;
                     if ($275) {
                      label = 11;
                      break L189;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2173776|0))|0);
                     $276 = __THREW__; __THREW__ = 0;
                     $277 = $276&1;
                     if ($277) {
                      label = 11;
                      break L189;
                     }
                     __THREW__ = 0;
                     $278 = (invoke_iii(2753,($273|0),(2173776|0))|0);
                     $279 = __THREW__; __THREW__ = 0;
                     $280 = $279&1;
                     if ($280) {
                      label = 11;
                      break L189;
                     }
                     $281 = HEAP16[$278>>1]|0;
                     $282 = ($281<<16>>16)==(0);
                     if (!($282)) {
                      $283 = $281&65535;
                      $284 = $281 & $V_9$1$ph270;
                      $285 = ($284<<16>>16)==($281<<16>>16);
                      if ($285) {
                       break;
                      }
                     }
                     $286 = ($V_11$0134|0)>(0);
                     if ($286) {
                      $V_11$0134$in = $V_11$0134;
                     } else {
                      $V_0$6$ph267 = $V_0$6$ph271;$V_9$1$ph263 = $V_9$1$ph270;
                      break L187;
                     }
                    }
                    $287 = HEAP32[$271>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($287|0));
                    $288 = __THREW__; __THREW__ = 0;
                    $289 = $288&1;
                    if ($289) {
                     label = 12;
                     break;
                    }
                    $290 = ($V_11$0134$in|0)<(1);
                    if ($290) {
                     label = 129;
                    } else {
                     $291 = (($287) + 12|0);
                     $292 = HEAP32[$291>>2]|0;
                     $293 = ($V_11$0134>>>0)<($292>>>0);
                     if (!($293)) {
                      label = 129;
                     }
                    }
                    if ((label|0) == 129) {
                     label = 0;
                     __THREW__ = 0;
                     $294 = (invoke_i(132)|0);
                     $295 = __THREW__; __THREW__ = 0;
                     $296 = $295&1;
                     if ($296) {
                      label = 12;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($294|0));
                     $297 = __THREW__; __THREW__ = 0;
                     $298 = $297&1;
                     if ($298) {
                      label = 12;
                      break;
                     }
                    }
                    $299 = HEAP32[$287>>2]|0;
                    $300 = (($287) + 16|0);
                    $301 = (($299) + 92|0);
                    $302 = HEAP32[$301>>2]|0;
                    $303 = Math_imul($302, $V_11$0134)|0;
                    $304 = (($300) + ($303)|0);
                    $305 = HEAP32[$304>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $306 = __THREW__; __THREW__ = 0;
                    $307 = $306&1;
                    if ($307) {
                     label = 12;
                     break;
                    }
                    $308 = HEAP8[((2191608 + 116|0))>>0]|0;
                    $309 = ($308<<24>>24)==(0);
                    if ($309) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $310 = __THREW__; __THREW__ = 0;
                     $311 = $310&1;
                     if ($311) {
                      label = 12;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $312 = __THREW__; __THREW__ = 0;
                     $313 = $312&1;
                     if ($313) {
                      label = 12;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3831,(2191608|0));
                     $314 = __THREW__; __THREW__ = 0;
                     $315 = $314&1;
                     if ($315) {
                      label = 12;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $316 = __THREW__; __THREW__ = 0;
                    $317 = $316&1;
                    if ($317) {
                     label = 12;
                     break;
                    }
                    $318 = HEAP32[((2191608 + 80|0))>>2]|0;
                    $319 = HEAP32[$318>>2]|0;
                    __THREW__ = 0;
                    $320 = (invoke_iiii(574,0,($V_0$6$ph271|0),($319|0))|0);
                    $321 = __THREW__; __THREW__ = 0;
                    $322 = $321&1;
                    if ($322) {
                     label = 12;
                     break;
                    }
                    if ($320) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $323 = __THREW__; __THREW__ = 0;
                     $324 = $323&1;
                     if ($324) {
                      label = 12;
                      break;
                     }
                     $325 = HEAP8[((2191608 + 116|0))>>0]|0;
                     $326 = ($325<<24>>24)==(0);
                     if ($326) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $327 = __THREW__; __THREW__ = 0;
                      $328 = $327&1;
                      if ($328) {
                       label = 12;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $329 = __THREW__; __THREW__ = 0;
                      $330 = $329&1;
                      if ($330) {
                       label = 12;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3831,(2191608|0));
                      $331 = __THREW__; __THREW__ = 0;
                      $332 = $331&1;
                      if ($332) {
                       label = 12;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $333 = __THREW__; __THREW__ = 0;
                     $334 = $333&1;
                     if ($334) {
                      label = 12;
                      break;
                     }
                     $335 = HEAP32[((2191608 + 80|0))>>2]|0;
                     $G_B39_0$0$in = $335;
                    } else {
                     $G_B39_0$0$in = 3011392;
                    }
                    $G_B39_0$0 = HEAP32[$G_B39_0$0$in>>2]|0;
                    __THREW__ = 0;
                    $336 = (invoke_iiiii(101,0,($305|0),($G_B39_0$0|0),($V_0$6$ph271|0))|0);
                    $337 = __THREW__; __THREW__ = 0;
                    $338 = $337&1;
                    if ($338) {
                     label = 12;
                     break;
                    }
                    $339 = (($340) - ($283))|0;
                    $341 = $339&65535;
                    $342 = ($V_11$0134|0)>(0);
                    if ($342) {
                     $V_0$6$ph271 = $336;$V_11$0132272$in = $V_11$0134;$V_9$1$ph270 = $341;
                    } else {
                     $V_0$6$ph267 = $336;$V_9$1$ph263 = $341;
                     break L187;
                    }
                   }
                   if ((label|0) == 11) {
                    $20 = ___cxa_find_matching_catch()|0;
                    $21 = tempRet0;
                    $lpad$phi$index = $20;$lpad$phi$index17 = $21;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   else if ((label|0) == 12) {
                    $22 = ___cxa_find_matching_catch()|0;
                    $23 = tempRet0;
                    $lpad$phi$index = $22;$lpad$phi$index17 = $23;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                  } else {
                   $V_0$6$ph267 = $49;$V_9$1$ph263 = $263;
                  }
                 } while(0);
                 $345 = ($V_9$1$ph263<<16>>16)==(0);
                 if ($345) {
                  $V_0$17 = $V_0$6$ph267;
                  break L25;
                 } else {
                  $$0 = $54;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                 break;
                }
                case 8:  {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2176024|0))|0);
                 $431 = __THREW__; __THREW__ = 0;
                 $432 = $431&1;
                 if ($432) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $433 = (invoke_iii(2753,($value|0),(2176024|0))|0);
                 $434 = __THREW__; __THREW__ = 0;
                 $435 = $434&1;
                 if ($435) {
                  break L1;
                 }
                 $436 = HEAP16[$433>>1]|0;
                 $437 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($437|0));
                 $438 = __THREW__; __THREW__ = 0;
                 $439 = $438&1;
                 if ($439) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $440 = (invoke_ii(1857,($437|0))|0);
                 $441 = __THREW__; __THREW__ = 0;
                 $442 = $441&1;
                 if ($442) {
                  break L1;
                 }
                 $443 = ($440|0)>(0);
                 L239: do {
                  if ($443) {
                   $444 = (($V_1) + 8|0);
                   $V_0$10$ph287 = $49;$V_15$1$ph286 = $436;$V_17$0151288$in = $440;
                   L241: while(1) {
                    $513 = $V_15$1$ph286&65535;
                    $V_17$0153$in = $V_17$0151288$in;
                    while(1) {
                     $V_17$0153 = (($V_17$0153$in) + -1)|0;
                     $445 = HEAP32[$65>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($445|0));
                     $516 = __THREW__; __THREW__ = 0;
                     $517 = $516&1;
                     if ($517) {
                      label = 13;
                      break L241;
                     }
                     __THREW__ = 0;
                     $446 = (invoke_iii(759,($445|0),($V_17$0153|0))|0);
                     $447 = __THREW__; __THREW__ = 0;
                     $448 = $447&1;
                     if ($448) {
                      label = 13;
                      break L241;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2176024|0))|0);
                     $449 = __THREW__; __THREW__ = 0;
                     $450 = $449&1;
                     if ($450) {
                      label = 13;
                      break L241;
                     }
                     __THREW__ = 0;
                     $451 = (invoke_iii(2753,($446|0),(2176024|0))|0);
                     $452 = __THREW__; __THREW__ = 0;
                     $453 = $452&1;
                     if ($453) {
                      label = 13;
                      break L241;
                     }
                     $454 = HEAP16[$451>>1]|0;
                     $455 = ($454<<16>>16)==(0);
                     if (!($455)) {
                      $456 = $454&65535;
                      $457 = $454 & $V_15$1$ph286;
                      $458 = ($457<<16>>16)==($454<<16>>16);
                      if ($458) {
                       break;
                      }
                     }
                     $459 = ($V_17$0153|0)>(0);
                     if ($459) {
                      $V_17$0153$in = $V_17$0153;
                     } else {
                      $V_0$10$ph283 = $V_0$10$ph287;$V_15$1$ph279 = $V_15$1$ph286;
                      break L239;
                     }
                    }
                    $460 = HEAP32[$444>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($460|0));
                    $461 = __THREW__; __THREW__ = 0;
                    $462 = $461&1;
                    if ($462) {
                     label = 14;
                     break;
                    }
                    $463 = ($V_17$0153$in|0)<(1);
                    if ($463) {
                     label = 203;
                    } else {
                     $464 = (($460) + 12|0);
                     $465 = HEAP32[$464>>2]|0;
                     $466 = ($V_17$0153>>>0)<($465>>>0);
                     if (!($466)) {
                      label = 203;
                     }
                    }
                    if ((label|0) == 203) {
                     label = 0;
                     __THREW__ = 0;
                     $467 = (invoke_i(132)|0);
                     $468 = __THREW__; __THREW__ = 0;
                     $469 = $468&1;
                     if ($469) {
                      label = 14;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($467|0));
                     $470 = __THREW__; __THREW__ = 0;
                     $471 = $470&1;
                     if ($471) {
                      label = 14;
                      break;
                     }
                    }
                    $472 = HEAP32[$460>>2]|0;
                    $473 = (($460) + 16|0);
                    $474 = (($472) + 92|0);
                    $475 = HEAP32[$474>>2]|0;
                    $476 = Math_imul($475, $V_17$0153)|0;
                    $477 = (($473) + ($476)|0);
                    $478 = HEAP32[$477>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $479 = __THREW__; __THREW__ = 0;
                    $480 = $479&1;
                    if ($480) {
                     label = 14;
                     break;
                    }
                    $481 = HEAP8[((2191608 + 116|0))>>0]|0;
                    $482 = ($481<<24>>24)==(0);
                    if ($482) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $483 = __THREW__; __THREW__ = 0;
                     $484 = $483&1;
                     if ($484) {
                      label = 14;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $485 = __THREW__; __THREW__ = 0;
                     $486 = $485&1;
                     if ($486) {
                      label = 14;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3831,(2191608|0));
                     $487 = __THREW__; __THREW__ = 0;
                     $488 = $487&1;
                     if ($488) {
                      label = 14;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $489 = __THREW__; __THREW__ = 0;
                    $490 = $489&1;
                    if ($490) {
                     label = 14;
                     break;
                    }
                    $491 = HEAP32[((2191608 + 80|0))>>2]|0;
                    $492 = HEAP32[$491>>2]|0;
                    __THREW__ = 0;
                    $493 = (invoke_iiii(574,0,($V_0$10$ph287|0),($492|0))|0);
                    $494 = __THREW__; __THREW__ = 0;
                    $495 = $494&1;
                    if ($495) {
                     label = 14;
                     break;
                    }
                    if ($493) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $496 = __THREW__; __THREW__ = 0;
                     $497 = $496&1;
                     if ($497) {
                      label = 14;
                      break;
                     }
                     $498 = HEAP8[((2191608 + 116|0))>>0]|0;
                     $499 = ($498<<24>>24)==(0);
                     if ($499) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $500 = __THREW__; __THREW__ = 0;
                      $501 = $500&1;
                      if ($501) {
                       label = 14;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $502 = __THREW__; __THREW__ = 0;
                      $503 = $502&1;
                      if ($503) {
                       label = 14;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3831,(2191608|0));
                      $504 = __THREW__; __THREW__ = 0;
                      $505 = $504&1;
                      if ($505) {
                       label = 14;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $506 = __THREW__; __THREW__ = 0;
                     $507 = $506&1;
                     if ($507) {
                      label = 14;
                      break;
                     }
                     $508 = HEAP32[((2191608 + 80|0))>>2]|0;
                     $G_B65_0$0$in = $508;
                    } else {
                     $G_B65_0$0$in = 3011408;
                    }
                    $G_B65_0$0 = HEAP32[$G_B65_0$0$in>>2]|0;
                    __THREW__ = 0;
                    $509 = (invoke_iiiii(101,0,($478|0),($G_B65_0$0|0),($V_0$10$ph287|0))|0);
                    $510 = __THREW__; __THREW__ = 0;
                    $511 = $510&1;
                    if ($511) {
                     label = 14;
                     break;
                    }
                    $512 = (($513) - ($456))|0;
                    $514 = $512&65535;
                    $515 = ($V_17$0153|0)>(0);
                    if ($515) {
                     $V_0$10$ph287 = $509;$V_15$1$ph286 = $514;$V_17$0151288$in = $V_17$0153;
                    } else {
                     $V_0$10$ph283 = $509;$V_15$1$ph279 = $514;
                     break L239;
                    }
                   }
                   if ((label|0) == 13) {
                    $24 = ___cxa_find_matching_catch()|0;
                    $25 = tempRet0;
                    $lpad$phi$index = $24;$lpad$phi$index17 = $25;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   else if ((label|0) == 14) {
                    $26 = ___cxa_find_matching_catch()|0;
                    $27 = tempRet0;
                    $lpad$phi$index = $26;$lpad$phi$index17 = $27;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                  } else {
                   $V_0$10$ph283 = $49;$V_15$1$ph279 = $436;
                  }
                 } while(0);
                 $518 = ($V_15$1$ph279<<16>>16)==(0);
                 if ($518) {
                  $V_0$17 = $V_0$10$ph283;
                  break L25;
                 } else {
                  $$0 = $54;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                 break;
                }
                case 9:  {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $346 = __THREW__; __THREW__ = 0;
                 $347 = $346&1;
                 if ($347) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $348 = (invoke_iii(2753,($value|0),(2155952|0))|0);
                 $349 = __THREW__; __THREW__ = 0;
                 $350 = $349&1;
                 if ($350) {
                  break L1;
                 }
                 $351 = HEAP32[$348>>2]|0;
                 $352 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($352|0));
                 $353 = __THREW__; __THREW__ = 0;
                 $354 = $353&1;
                 if ($354) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $355 = (invoke_ii(1857,($352|0))|0);
                 $356 = __THREW__; __THREW__ = 0;
                 $357 = $356&1;
                 if ($357) {
                  break L1;
                 }
                 $358 = ($355|0)>(0);
                 L291: do {
                  if ($358) {
                   $359 = (($V_1) + 8|0);
                   $V_0$8$ph303 = $49;$V_12$1$ph302 = $351;$V_14$0169304$in = $355;
                   L293: while(1) {
                    $V_14$0171$in = $V_14$0169304$in;
                    while(1) {
                     $V_14$0171 = (($V_14$0171$in) + -1)|0;
                     $360 = HEAP32[$65>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($360|0));
                     $428 = __THREW__; __THREW__ = 0;
                     $429 = $428&1;
                     if ($429) {
                      label = 15;
                      break L293;
                     }
                     __THREW__ = 0;
                     $361 = (invoke_iii(759,($360|0),($V_14$0171|0))|0);
                     $362 = __THREW__; __THREW__ = 0;
                     $363 = $362&1;
                     if ($363) {
                      label = 15;
                      break L293;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2155952|0))|0);
                     $364 = __THREW__; __THREW__ = 0;
                     $365 = $364&1;
                     if ($365) {
                      label = 15;
                      break L293;
                     }
                     __THREW__ = 0;
                     $366 = (invoke_iii(2753,($361|0),(2155952|0))|0);
                     $367 = __THREW__; __THREW__ = 0;
                     $368 = $367&1;
                     if ($368) {
                      label = 15;
                      break L293;
                     }
                     $369 = HEAP32[$366>>2]|0;
                     $370 = ($369|0)==(0);
                     if (!($370)) {
                      $371 = $369 & $V_12$1$ph302;
                      $372 = ($371|0)==($369|0);
                      if ($372) {
                       break;
                      }
                     }
                     $373 = ($V_14$0171|0)>(0);
                     if ($373) {
                      $V_14$0171$in = $V_14$0171;
                     } else {
                      $V_0$8$ph299 = $V_0$8$ph303;$V_12$1$ph295 = $V_12$1$ph302;
                      break L291;
                     }
                    }
                    $374 = HEAP32[$359>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($374|0));
                    $375 = __THREW__; __THREW__ = 0;
                    $376 = $375&1;
                    if ($376) {
                     label = 16;
                     break;
                    }
                    $377 = ($V_14$0171$in|0)<(1);
                    if ($377) {
                     label = 166;
                    } else {
                     $378 = (($374) + 12|0);
                     $379 = HEAP32[$378>>2]|0;
                     $380 = ($V_14$0171>>>0)<($379>>>0);
                     if (!($380)) {
                      label = 166;
                     }
                    }
                    if ((label|0) == 166) {
                     label = 0;
                     __THREW__ = 0;
                     $381 = (invoke_i(132)|0);
                     $382 = __THREW__; __THREW__ = 0;
                     $383 = $382&1;
                     if ($383) {
                      label = 16;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($381|0));
                     $384 = __THREW__; __THREW__ = 0;
                     $385 = $384&1;
                     if ($385) {
                      label = 16;
                      break;
                     }
                    }
                    $386 = HEAP32[$374>>2]|0;
                    $387 = (($374) + 16|0);
                    $388 = (($386) + 92|0);
                    $389 = HEAP32[$388>>2]|0;
                    $390 = Math_imul($389, $V_14$0171)|0;
                    $391 = (($387) + ($390)|0);
                    $392 = HEAP32[$391>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $393 = __THREW__; __THREW__ = 0;
                    $394 = $393&1;
                    if ($394) {
                     label = 16;
                     break;
                    }
                    $395 = HEAP8[((2191608 + 116|0))>>0]|0;
                    $396 = ($395<<24>>24)==(0);
                    if ($396) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $397 = __THREW__; __THREW__ = 0;
                     $398 = $397&1;
                     if ($398) {
                      label = 16;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $399 = __THREW__; __THREW__ = 0;
                     $400 = $399&1;
                     if ($400) {
                      label = 16;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3831,(2191608|0));
                     $401 = __THREW__; __THREW__ = 0;
                     $402 = $401&1;
                     if ($402) {
                      label = 16;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $403 = __THREW__; __THREW__ = 0;
                    $404 = $403&1;
                    if ($404) {
                     label = 16;
                     break;
                    }
                    $405 = HEAP32[((2191608 + 80|0))>>2]|0;
                    $406 = HEAP32[$405>>2]|0;
                    __THREW__ = 0;
                    $407 = (invoke_iiii(574,0,($V_0$8$ph303|0),($406|0))|0);
                    $408 = __THREW__; __THREW__ = 0;
                    $409 = $408&1;
                    if ($409) {
                     label = 16;
                     break;
                    }
                    if ($407) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $410 = __THREW__; __THREW__ = 0;
                     $411 = $410&1;
                     if ($411) {
                      label = 16;
                      break;
                     }
                     $412 = HEAP8[((2191608 + 116|0))>>0]|0;
                     $413 = ($412<<24>>24)==(0);
                     if ($413) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $414 = __THREW__; __THREW__ = 0;
                      $415 = $414&1;
                      if ($415) {
                       label = 16;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $416 = __THREW__; __THREW__ = 0;
                      $417 = $416&1;
                      if ($417) {
                       label = 16;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3831,(2191608|0));
                      $418 = __THREW__; __THREW__ = 0;
                      $419 = $418&1;
                      if ($419) {
                       label = 16;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $420 = __THREW__; __THREW__ = 0;
                     $421 = $420&1;
                     if ($421) {
                      label = 16;
                      break;
                     }
                     $422 = HEAP32[((2191608 + 80|0))>>2]|0;
                     $G_B52_0$0$in = $422;
                    } else {
                     $G_B52_0$0$in = 3011400;
                    }
                    $G_B52_0$0 = HEAP32[$G_B52_0$0$in>>2]|0;
                    __THREW__ = 0;
                    $423 = (invoke_iiiii(101,0,($392|0),($G_B52_0$0|0),($V_0$8$ph303|0))|0);
                    $424 = __THREW__; __THREW__ = 0;
                    $425 = $424&1;
                    if ($425) {
                     label = 16;
                     break;
                    }
                    $426 = (($V_12$1$ph302) - ($369))|0;
                    $427 = ($V_14$0171|0)>(0);
                    if ($427) {
                     $V_0$8$ph303 = $423;$V_12$1$ph302 = $426;$V_14$0169304$in = $V_14$0171;
                    } else {
                     $V_0$8$ph299 = $423;$V_12$1$ph295 = $426;
                     break L291;
                    }
                   }
                   if ((label|0) == 15) {
                    $28 = ___cxa_find_matching_catch()|0;
                    $29 = tempRet0;
                    $lpad$phi$index = $28;$lpad$phi$index17 = $29;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   else if ((label|0) == 16) {
                    $30 = ___cxa_find_matching_catch()|0;
                    $31 = tempRet0;
                    $lpad$phi$index = $30;$lpad$phi$index17 = $31;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                  } else {
                   $V_0$8$ph299 = $49;$V_12$1$ph295 = $351;
                  }
                 } while(0);
                 $430 = ($V_12$1$ph295|0)==(0);
                 if ($430) {
                  $V_0$17 = $V_0$8$ph299;
                  break L25;
                 } else {
                  $$0 = $54;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                 break;
                }
                case 10:  {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2164560|0))|0);
                 $519 = __THREW__; __THREW__ = 0;
                 $520 = $519&1;
                 if ($520) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $521 = (invoke_iii(2753,($value|0),(2164560|0))|0);
                 $522 = __THREW__; __THREW__ = 0;
                 $523 = $522&1;
                 if ($523) {
                  break L1;
                 }
                 $524 = HEAP32[$521>>2]|0;
                 $525 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($525|0));
                 $526 = __THREW__; __THREW__ = 0;
                 $527 = $526&1;
                 if ($527) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $528 = (invoke_ii(1857,($525|0))|0);
                 $529 = __THREW__; __THREW__ = 0;
                 $530 = $529&1;
                 if ($530) {
                  break L1;
                 }
                 $531 = ($528|0)>(0);
                 L343: do {
                  if ($531) {
                   $532 = (($V_1) + 8|0);
                   $V_0$12$ph319 = $49;$V_18$1$ph318 = $524;$V_20$0187320$in = $528;
                   L345: while(1) {
                    $V_20$0189$in = $V_20$0187320$in;
                    while(1) {
                     $V_20$0189 = (($V_20$0189$in) + -1)|0;
                     $533 = HEAP32[$65>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($533|0));
                     $601 = __THREW__; __THREW__ = 0;
                     $602 = $601&1;
                     if ($602) {
                      label = 17;
                      break L345;
                     }
                     __THREW__ = 0;
                     $534 = (invoke_iii(759,($533|0),($V_20$0189|0))|0);
                     $535 = __THREW__; __THREW__ = 0;
                     $536 = $535&1;
                     if ($536) {
                      label = 17;
                      break L345;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2164560|0))|0);
                     $537 = __THREW__; __THREW__ = 0;
                     $538 = $537&1;
                     if ($538) {
                      label = 17;
                      break L345;
                     }
                     __THREW__ = 0;
                     $539 = (invoke_iii(2753,($534|0),(2164560|0))|0);
                     $540 = __THREW__; __THREW__ = 0;
                     $541 = $540&1;
                     if ($541) {
                      label = 17;
                      break L345;
                     }
                     $542 = HEAP32[$539>>2]|0;
                     $543 = ($542|0)==(0);
                     if (!($543)) {
                      $544 = $542 & $V_18$1$ph318;
                      $545 = ($544|0)==($542|0);
                      if ($545) {
                       break;
                      }
                     }
                     $546 = ($V_20$0189|0)>(0);
                     if ($546) {
                      $V_20$0189$in = $V_20$0189;
                     } else {
                      $V_0$12$ph315 = $V_0$12$ph319;$V_18$1$ph311 = $V_18$1$ph318;
                      break L343;
                     }
                    }
                    $547 = HEAP32[$532>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($547|0));
                    $548 = __THREW__; __THREW__ = 0;
                    $549 = $548&1;
                    if ($549) {
                     label = 18;
                     break;
                    }
                    $550 = ($V_20$0189$in|0)<(1);
                    if ($550) {
                     label = 240;
                    } else {
                     $551 = (($547) + 12|0);
                     $552 = HEAP32[$551>>2]|0;
                     $553 = ($V_20$0189>>>0)<($552>>>0);
                     if (!($553)) {
                      label = 240;
                     }
                    }
                    if ((label|0) == 240) {
                     label = 0;
                     __THREW__ = 0;
                     $554 = (invoke_i(132)|0);
                     $555 = __THREW__; __THREW__ = 0;
                     $556 = $555&1;
                     if ($556) {
                      label = 18;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($554|0));
                     $557 = __THREW__; __THREW__ = 0;
                     $558 = $557&1;
                     if ($558) {
                      label = 18;
                      break;
                     }
                    }
                    $559 = HEAP32[$547>>2]|0;
                    $560 = (($547) + 16|0);
                    $561 = (($559) + 92|0);
                    $562 = HEAP32[$561>>2]|0;
                    $563 = Math_imul($562, $V_20$0189)|0;
                    $564 = (($560) + ($563)|0);
                    $565 = HEAP32[$564>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $566 = __THREW__; __THREW__ = 0;
                    $567 = $566&1;
                    if ($567) {
                     label = 18;
                     break;
                    }
                    $568 = HEAP8[((2191608 + 116|0))>>0]|0;
                    $569 = ($568<<24>>24)==(0);
                    if ($569) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $570 = __THREW__; __THREW__ = 0;
                     $571 = $570&1;
                     if ($571) {
                      label = 18;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $572 = __THREW__; __THREW__ = 0;
                     $573 = $572&1;
                     if ($573) {
                      label = 18;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3831,(2191608|0));
                     $574 = __THREW__; __THREW__ = 0;
                     $575 = $574&1;
                     if ($575) {
                      label = 18;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $576 = __THREW__; __THREW__ = 0;
                    $577 = $576&1;
                    if ($577) {
                     label = 18;
                     break;
                    }
                    $578 = HEAP32[((2191608 + 80|0))>>2]|0;
                    $579 = HEAP32[$578>>2]|0;
                    __THREW__ = 0;
                    $580 = (invoke_iiii(574,0,($V_0$12$ph319|0),($579|0))|0);
                    $581 = __THREW__; __THREW__ = 0;
                    $582 = $581&1;
                    if ($582) {
                     label = 18;
                     break;
                    }
                    if ($580) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $583 = __THREW__; __THREW__ = 0;
                     $584 = $583&1;
                     if ($584) {
                      label = 18;
                      break;
                     }
                     $585 = HEAP8[((2191608 + 116|0))>>0]|0;
                     $586 = ($585<<24>>24)==(0);
                     if ($586) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $587 = __THREW__; __THREW__ = 0;
                      $588 = $587&1;
                      if ($588) {
                       label = 18;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $589 = __THREW__; __THREW__ = 0;
                      $590 = $589&1;
                      if ($590) {
                       label = 18;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3831,(2191608|0));
                      $591 = __THREW__; __THREW__ = 0;
                      $592 = $591&1;
                      if ($592) {
                       label = 18;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $593 = __THREW__; __THREW__ = 0;
                     $594 = $593&1;
                     if ($594) {
                      label = 18;
                      break;
                     }
                     $595 = HEAP32[((2191608 + 80|0))>>2]|0;
                     $G_B78_0$0$in = $595;
                    } else {
                     $G_B78_0$0$in = 3011416;
                    }
                    $G_B78_0$0 = HEAP32[$G_B78_0$0$in>>2]|0;
                    __THREW__ = 0;
                    $596 = (invoke_iiiii(101,0,($565|0),($G_B78_0$0|0),($V_0$12$ph319|0))|0);
                    $597 = __THREW__; __THREW__ = 0;
                    $598 = $597&1;
                    if ($598) {
                     label = 18;
                     break;
                    }
                    $599 = (($V_18$1$ph318) - ($542))|0;
                    $600 = ($V_20$0189|0)>(0);
                    if ($600) {
                     $V_0$12$ph319 = $596;$V_18$1$ph318 = $599;$V_20$0187320$in = $V_20$0189;
                    } else {
                     $V_0$12$ph315 = $596;$V_18$1$ph311 = $599;
                     break L343;
                    }
                   }
                   if ((label|0) == 17) {
                    $32 = ___cxa_find_matching_catch()|0;
                    $33 = tempRet0;
                    $lpad$phi$index = $32;$lpad$phi$index17 = $33;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   else if ((label|0) == 18) {
                    $34 = ___cxa_find_matching_catch()|0;
                    $35 = tempRet0;
                    $lpad$phi$index = $34;$lpad$phi$index17 = $35;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                  } else {
                   $V_0$12$ph315 = $49;$V_18$1$ph311 = $524;
                  }
                 } while(0);
                 $603 = ($V_18$1$ph311|0)==(0);
                 if ($603) {
                  $V_0$17 = $V_0$12$ph315;
                  break L25;
                 } else {
                  $$0 = $54;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                 break;
                }
                case 11:  {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2162248|0))|0);
                 $604 = __THREW__; __THREW__ = 0;
                 $605 = $604&1;
                 if ($605) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $606 = (invoke_iii(2753,($value|0),(2162248|0))|0);
                 $607 = __THREW__; __THREW__ = 0;
                 $608 = $607&1;
                 if ($608) {
                  break L1;
                 }
                 $609 = $606;
                 $610 = $609;
                 $611 = HEAP32[$610>>2]|0;
                 $612 = (($609) + 4)|0;
                 $613 = $612;
                 $614 = HEAP32[$613>>2]|0;
                 $615 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($615|0));
                 $616 = __THREW__; __THREW__ = 0;
                 $617 = $616&1;
                 if ($617) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $618 = (invoke_ii(1857,($615|0))|0);
                 $619 = __THREW__; __THREW__ = 0;
                 $620 = $619&1;
                 if ($620) {
                  break L1;
                 }
                 $621 = ($618|0)>(0);
                 L395: do {
                  if ($621) {
                   $622 = (($V_1) + 8|0);
                   $642 = $611;$644 = $614;$V_0$14$ph335 = $49;$V_23$0205336$in = $618;
                   L397: while(1) {
                    $V_23$0207$in = $V_23$0205336$in;
                    while(1) {
                     $V_23$0207 = (($V_23$0207$in) + -1)|0;
                     $623 = HEAP32[$65>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($623|0));
                     $704 = __THREW__; __THREW__ = 0;
                     $705 = $704&1;
                     if ($705) {
                      label = 19;
                      break L397;
                     }
                     __THREW__ = 0;
                     $624 = (invoke_iii(759,($623|0),($V_23$0207|0))|0);
                     $625 = __THREW__; __THREW__ = 0;
                     $626 = $625&1;
                     if ($626) {
                      label = 19;
                      break L397;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2162248|0))|0);
                     $627 = __THREW__; __THREW__ = 0;
                     $628 = $627&1;
                     if ($628) {
                      label = 19;
                      break L397;
                     }
                     __THREW__ = 0;
                     $629 = (invoke_iii(2753,($624|0),(2162248|0))|0);
                     $630 = __THREW__; __THREW__ = 0;
                     $631 = $630&1;
                     if ($631) {
                      label = 19;
                      break L397;
                     }
                     $632 = $629;
                     $633 = $632;
                     $634 = HEAP32[$633>>2]|0;
                     $635 = (($632) + 4)|0;
                     $636 = $635;
                     $637 = HEAP32[$636>>2]|0;
                     $638 = ($634|0)==(0);
                     $639 = ($637|0)==(0);
                     $640 = $638 & $639;
                     if (!($640)) {
                      $641 = $634 & $642;
                      $643 = $637 & $644;
                      $645 = ($641|0)==($634|0);
                      $646 = ($643|0)==($637|0);
                      $647 = $645 & $646;
                      if ($647) {
                       break;
                      }
                     }
                     $648 = ($V_23$0207|0)>(0);
                     if ($648) {
                      $V_23$0207$in = $V_23$0207;
                     } else {
                      $707 = $642;$709 = $644;$V_0$14$ph331 = $V_0$14$ph335;
                      break L395;
                     }
                    }
                    $649 = HEAP32[$622>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($649|0));
                    $650 = __THREW__; __THREW__ = 0;
                    $651 = $650&1;
                    if ($651) {
                     label = 20;
                     break;
                    }
                    $652 = ($V_23$0207$in|0)<(1);
                    if ($652) {
                     label = 277;
                    } else {
                     $653 = (($649) + 12|0);
                     $654 = HEAP32[$653>>2]|0;
                     $655 = ($V_23$0207>>>0)<($654>>>0);
                     if (!($655)) {
                      label = 277;
                     }
                    }
                    if ((label|0) == 277) {
                     label = 0;
                     __THREW__ = 0;
                     $656 = (invoke_i(132)|0);
                     $657 = __THREW__; __THREW__ = 0;
                     $658 = $657&1;
                     if ($658) {
                      label = 20;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($656|0));
                     $659 = __THREW__; __THREW__ = 0;
                     $660 = $659&1;
                     if ($660) {
                      label = 20;
                      break;
                     }
                    }
                    $661 = HEAP32[$649>>2]|0;
                    $662 = (($649) + 16|0);
                    $663 = (($661) + 92|0);
                    $664 = HEAP32[$663>>2]|0;
                    $665 = Math_imul($664, $V_23$0207)|0;
                    $666 = (($662) + ($665)|0);
                    $667 = HEAP32[$666>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $668 = __THREW__; __THREW__ = 0;
                    $669 = $668&1;
                    if ($669) {
                     label = 20;
                     break;
                    }
                    $670 = HEAP8[((2191608 + 116|0))>>0]|0;
                    $671 = ($670<<24>>24)==(0);
                    if ($671) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $672 = __THREW__; __THREW__ = 0;
                     $673 = $672&1;
                     if ($673) {
                      label = 20;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $674 = __THREW__; __THREW__ = 0;
                     $675 = $674&1;
                     if ($675) {
                      label = 20;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3831,(2191608|0));
                     $676 = __THREW__; __THREW__ = 0;
                     $677 = $676&1;
                     if ($677) {
                      label = 20;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $678 = __THREW__; __THREW__ = 0;
                    $679 = $678&1;
                    if ($679) {
                     label = 20;
                     break;
                    }
                    $680 = HEAP32[((2191608 + 80|0))>>2]|0;
                    $681 = HEAP32[$680>>2]|0;
                    __THREW__ = 0;
                    $682 = (invoke_iiii(574,0,($V_0$14$ph335|0),($681|0))|0);
                    $683 = __THREW__; __THREW__ = 0;
                    $684 = $683&1;
                    if ($684) {
                     label = 20;
                     break;
                    }
                    if ($682) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $685 = __THREW__; __THREW__ = 0;
                     $686 = $685&1;
                     if ($686) {
                      label = 20;
                      break;
                     }
                     $687 = HEAP8[((2191608 + 116|0))>>0]|0;
                     $688 = ($687<<24>>24)==(0);
                     if ($688) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $689 = __THREW__; __THREW__ = 0;
                      $690 = $689&1;
                      if ($690) {
                       label = 20;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2191608|0))|0);
                      $691 = __THREW__; __THREW__ = 0;
                      $692 = $691&1;
                      if ($692) {
                       label = 20;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3831,(2191608|0));
                      $693 = __THREW__; __THREW__ = 0;
                      $694 = $693&1;
                      if ($694) {
                       label = 20;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2191608|0))|0);
                     $695 = __THREW__; __THREW__ = 0;
                     $696 = $695&1;
                     if ($696) {
                      label = 20;
                      break;
                     }
                     $697 = HEAP32[((2191608 + 80|0))>>2]|0;
                     $G_B91_0$0$in = $697;
                    } else {
                     $G_B91_0$0$in = 3011424;
                    }
                    $G_B91_0$0 = HEAP32[$G_B91_0$0$in>>2]|0;
                    __THREW__ = 0;
                    $698 = (invoke_iiiii(101,0,($667|0),($G_B91_0$0|0),($V_0$14$ph335|0))|0);
                    $699 = __THREW__; __THREW__ = 0;
                    $700 = $699&1;
                    if ($700) {
                     label = 20;
                     break;
                    }
                    $701 = (_i64Subtract(($642|0),($644|0),($634|0),($637|0))|0);
                    $702 = tempRet0;
                    $703 = ($V_23$0207|0)>(0);
                    if ($703) {
                     $642 = $701;$644 = $702;$V_0$14$ph335 = $698;$V_23$0205336$in = $V_23$0207;
                    } else {
                     $707 = $701;$709 = $702;$V_0$14$ph331 = $698;
                     break L395;
                    }
                   }
                   if ((label|0) == 19) {
                    $36 = ___cxa_find_matching_catch()|0;
                    $37 = tempRet0;
                    $lpad$phi$index = $36;$lpad$phi$index17 = $37;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   else if ((label|0) == 20) {
                    $38 = ___cxa_find_matching_catch()|0;
                    $39 = tempRet0;
                    $lpad$phi$index = $38;$lpad$phi$index17 = $39;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                  } else {
                   $707 = $611;$709 = $614;$V_0$14$ph331 = $49;
                  }
                 } while(0);
                 $706 = ($707|0)==(0);
                 $708 = ($709|0)==(0);
                 $710 = $706 & $708;
                 if ($710) {
                  $V_0$17 = $V_0$14$ph331;
                  break L25;
                 } else {
                  $$0 = $54;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                 break;
                }
                default: {
                 $V_0$17 = $49;
                }
                }
               } while(0);
               __THREW__ = 0;
               (invoke_ii(2996,(2191608|0))|0);
               $818 = __THREW__; __THREW__ = 0;
               $819 = $818&1;
               if (!($819)) {
                $820 = HEAP8[((2191608 + 116|0))>>0]|0;
                $821 = ($820<<24>>24)==(0);
                if ($821) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $822 = __THREW__; __THREW__ = 0;
                 $823 = $822&1;
                 if ($823) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $824 = __THREW__; __THREW__ = 0;
                 $825 = $824&1;
                 if ($825) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3831,(2191608|0));
                 $826 = __THREW__; __THREW__ = 0;
                 $827 = $826&1;
                 if ($827) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $828 = __THREW__; __THREW__ = 0;
                $829 = $828&1;
                if (!($829)) {
                 $830 = HEAP32[((2191608 + 80|0))>>2]|0;
                 $831 = HEAP32[$830>>2]|0;
                 __THREW__ = 0;
                 $832 = (invoke_iiii(574,0,($V_0$17|0),($831|0))|0);
                 $833 = __THREW__; __THREW__ = 0;
                 $834 = $833&1;
                 if (!($834)) {
                  $$V_0$17 = $832 ? $54 : $V_0$17;
                  $$0 = $$V_0$17;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $44 = ___cxa_find_matching_catch()|0;
 $45 = tempRet0;
 $lpad$phi$index = $44;$lpad$phi$index17 = $45;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222584);
 __THREW__ = 0;
 invoke_v(459);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(1);
    if (!($5)) {
     $8 = HEAP32[3012576>>2]|0;
     __THREW__ = 0;
     $9 = (invoke_iii(783,0,($8|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     $14 = (invoke_ii(3469,(2560072|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($14|0),($9|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($14|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $21 = (invoke_iii(755,($__this|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = ($21|0)>($index|0);
     if (!($24)) {
      __THREW__ = 0;
      $25 = (invoke_iii(758,($__this|0),0)|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      $28 = ($25|0)<($index|0);
      if (!($28)) {
       __THREW__ = 0;
       $42 = (invoke_iii(755,($__this|0),0)|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $45 = (($index) - ($42))|0;
       __THREW__ = 0;
       $46 = (invoke_iii(757,($__this|0),($45|0))|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($46|0);
      }
     }
     $29 = HEAP32[3012584>>2]|0;
     __THREW__ = 0;
     $30 = (invoke_iii(783,0,($29|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2606944|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       $35 = (invoke_ii(3469,(2606944|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __THREW__ = 0;
        invoke_vii(1945,($35|0),($30|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         __THREW__ = 0;
         invoke_vi(3830,($35|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Array_m_get_LengthP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221112);
 __THREW__ = 0;
 $0 = (invoke_iii(753,($__this|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  $lpad$phi$index = $5;$lpad$phi$index2 = $6;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 } else {
  $V_0$0 = $0;$V_1$0 = 1;
 }
 while(1) {
  __THREW__ = 0;
  $10 = (invoke_ii(1859,($__this|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   break;
  }
  $13 = ($V_1$0|0)<($10|0);
  if (!($13)) {
   label = 9;
   break;
  }
  __THREW__ = 0;
  $8 = (invoke_iii(753,($__this|0),($V_1$0|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   break;
  }
  $7 = Math_imul($8, $V_0$0)|0;
  $9 = (($V_1$0) + 1)|0;
  $V_0$0 = $7;$V_1$0 = $9;
 }
 if ((label|0) == 9) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_0$0|0);
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $lpad$phi$index = $3;$lpad$phi$index2 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraitsS0_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S4_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraits29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_S4_P22mscorlib_System_ObjectbES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS0_E6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z51mscorlib_System_Enum_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_GetNameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_GetUnderlyingTypeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z138mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2217640)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2248168);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $message;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z161mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2217640)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_ToObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_FormatP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46mscorlib_System_Array_SimpleEnumerator_m__ctorP38mscorlib_System_Array_SimpleEnumeratorP21mscorlib_System_Array($__this,$arrayToEnumerate) {
 $__this = $__this|0;
 $arrayToEnumerate = $arrayToEnumerate|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2218512);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $arrayToEnumerate;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = -1;
  __THREW__ = 0;
  invoke_vi(3799,($arrayToEnumerate|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1857,($arrayToEnumerate|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = (($__this) + 16|0);
    HEAP32[$9>>2] = $6;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z52mscorlib_System_Array_SimpleEnumerator_m_get_CurrentP38mscorlib_System_Array_SimpleEnumerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2218560);
 __THREW__ = 0;
 invoke_v(460);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(-1);
   if (!($4)) {
    $7 = HEAP32[3016512>>2]|0;
    __THREW__ = 0;
    $8 = (invoke_iii(783,0,($7|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2607872|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1947,($13|0),($8|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($13|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    // unreachable;
   }
   $20 = (($__this) + 16|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($3|0)<($21|0);
   if ($22) {
    $36 = (($__this) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($37|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iii(757,($37|0),($3|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($40|0);
   }
   $23 = HEAP32[3016520>>2]|0;
   __THREW__ = 0;
   $24 = (invoke_iii(783,0,($23|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     __THREW__ = 0;
     $29 = (invoke_ii(3469,(2607872|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      __THREW__ = 0;
      invoke_vii(1947,($29|0),($24|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_vi(3830,($29|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_Array_m_GetValueImplP21mscorlib_System_Arrayi($__this,$pos) {
 $__this = $__this|0;
 $pos = $pos|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221792);
 $0 = HEAP32[2221840>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2221848|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2221840>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($pos|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Array_SimpleEnumerator_m_MoveNextP38mscorlib_System_Array_SimpleEnumerator($__this) {
 $__this = $__this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2218608);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  $12 = $1;$13 = $3;
  $11 = ($12|0)<($13|0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($__this|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 }
 $7 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($__this|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 }
 $10 = (($7) + 1)|0;
 HEAP32[$0>>2] = $10;
 $$pre = HEAP32[$2>>2]|0;
 $12 = $10;$13 = $$pre;
 $11 = ($12|0)<($13|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($11|0);
}
function __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2250656);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z59mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m__ctorP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2251816);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z37mscorlib_System_Array_Swapper_m__ctorP29mscorlib_System_Array_SwapperP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2219792);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z38mscorlib_System_Array_Swapper_m_InvokeP29mscorlib_System_Array_Swapperii($__this,$i,$j) {
 $__this = $__this|0;
 $i = $i|0;
 $j = $j|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2219840);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  invoke_viii(529,($1|0),($i|0),($j|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 invoke_viii($8|0,($10|0),($i|0),($j|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43mscorlib_System_Array_Swapper_m_BeginInvokeP29mscorlib_System_Array_SwapperiiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$i,$j,$callback,$object) {
 $__this = $__this|0;
 $i = $i|0;
 $j = $j|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2219888);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z41mscorlib_System_Array_Swapper_m_EndInvokeP29mscorlib_System_Array_SwapperP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2219936);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_iiS4_P22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$1,$4,$6,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __Z29mscorlib_System_Array_m__ctorP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220392);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57mscorlib_System_Array_m_System_Collections_IList_get_ItemP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220440);
 __THREW__ = 0;
 invoke_v(461);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2606944|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2606944|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3011920>>2]|0;
     __THREW__ = 0;
     invoke_vii(1945,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(1859,($__this|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = ($18|0)<(2);
     if ($21) {
      __THREW__ = 0;
      $35 = (invoke_iii(757,($__this|0),($index|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($35|0);
     }
     $22 = HEAP32[3011928>>2]|0;
     __THREW__ = 0;
     $23 = (invoke_iii(783,0,($22|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       $28 = (invoke_ii(3469,(2560072|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        invoke_vii(1924,($28|0),($23|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         __THREW__ = 0;
         invoke_vi(3830,($28|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Array_m_get_RankP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221208);
 __THREW__ = 0;
 $0 = (invoke_ii(1860,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Array_m_System_Collections_IList_set_ItemP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220488);
 __THREW__ = 0;
 invoke_v(462);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2606944|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2606944|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012032>>2]|0;
     __THREW__ = 0;
     invoke_vii(1945,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(1859,($__this|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = ($18|0)<(2);
     if ($21) {
      __THREW__ = 0;
      invoke_viii(533,($__this|0),($value|0),($index|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $22 = HEAP32[3012040>>2]|0;
     __THREW__ = 0;
     $23 = (invoke_iii(783,0,($22|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       $28 = (invoke_ii(3469,(2560072|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        invoke_vii(1924,($28|0),($23|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         __THREW__ = 0;
         invoke_vi(3830,($28|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z36mscorlib_System_Array_m_SetValueImplP21mscorlib_System_ArrayP22mscorlib_System_Objecti($__this,$value,$pos) {
 $__this = $__this|0;
 $value = $value|0;
 $pos = $pos|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221896);
 $0 = HEAP32[2221944>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2221952|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2221944>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($__this|0),($value|0),($pos|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z52mscorlib_System_Array_m_System_Collections_IList_AddP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220536);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Array_m_System_Collections_IList_ClearP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220584);
 __THREW__ = 0;
 $0 = (invoke_iii(755,($__this|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(1857,($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viiii(138,0,($__this|0),($0|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z37mscorlib_System_Array_m_GetLowerBoundP21mscorlib_System_Arrayi($__this,$dimension) {
 $__this = $__this|0;
 $dimension = $dimension|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221480);
 $0 = HEAP32[2221528>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2221536|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2221528>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($dimension|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z29mscorlib_System_Array_m_ClearP22mscorlib_System_ObjectP21mscorlib_System_Arrayii($__this,$_____array,$index,$length) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223976);
 __THREW__ = 0;
 invoke_v(463);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3014992>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($length|0)>(-1);
   if (!($15)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2606944|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2606944|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3015000>>2]|0;
    __THREW__ = 0;
    invoke_vii(1945,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_iii(755,($_____array|0),0)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $31 = ($28|0)>($index|0);
     if ($31) {
      __THREW__ = 0;
      (invoke_ii(2996,(2606944|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2606944|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = HEAP32[3015008>>2]|0;
      __THREW__ = 0;
      invoke_vii(1945,($34|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($34|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     $42 = (($index) - ($28))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      __THREW__ = 0;
      $45 = (invoke_ii(1857,($_____array|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       $48 = (($45) - ($length))|0;
       $49 = ($42|0)>($48|0);
       if (!($49)) {
        __THREW__ = 0;
        invoke_viiii(139,0,($_____array|0),($42|0),($length|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         break;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2606944|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if (!($51)) {
        __THREW__ = 0;
        $52 = (invoke_ii(3469,(2606944|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if (!($54)) {
         $55 = HEAP32[3015016>>2]|0;
         __THREW__ = 0;
         invoke_vii(1945,($52|0),($55|0));
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if (!($57)) {
          __THREW__ = 0;
          invoke_vi(3830,($52|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z57mscorlib_System_Array_m_System_Collections_IList_ContainsP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220632);
 __THREW__ = 0;
 invoke_v(464);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012056>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,0,($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if ($26) {
      $V_1$01 = 0;
     } else {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     while(1) {
      __THREW__ = 0;
      $27 = (invoke_iii(757,($__this|0),($V_1$01|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iiii(423,0,($27|0),($value|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = (($V_1$01) + 1)|0;
      if ($28) {
       $$0 = 1;
       label = 19;
       break;
      }
      $32 = ($31|0)<($23|0);
      if ($32) {
       $V_1$01 = $31;
      } else {
       $$0 = 0;
       label = 19;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 19) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Array_m_System_Collections_IList_IndexOfP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$03 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220680);
 __THREW__ = 0;
 invoke_v(465);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012072>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,0,($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $V_1$03 = 0;
       while(1) {
        __THREW__ = 0;
        $27 = (invoke_iii(757,($__this|0),($V_1$03|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iiii(423,0,($27|0),($value|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = (($V_1$03) + 1)|0;
        if ($28) {
         break;
        }
        $36 = ($31|0)<($23|0);
        if ($36) {
         $V_1$03 = $31;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       __THREW__ = 0;
       $32 = (invoke_iii(755,($__this|0),0)|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break L1;
       }
       $35 = (($32) + ($V_1$03))|0;
       $$0 = $35;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     } while(0);
     __THREW__ = 0;
     $39 = (invoke_iii(755,($__this|0),0)|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if (!($41)) {
      $42 = (($39) + -1)|0;
      $$0 = $42;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Array_m_System_Collections_IList_InsertP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220728);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z55mscorlib_System_Array_m_System_Collections_IList_RemoveP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220776);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z57mscorlib_System_Array_m_System_Collections_IList_RemoveAtP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220824);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z64mscorlib_System_Array_m_System_Collections_ICollection_get_CountP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220872);
 __THREW__ = 0;
 $0 = (invoke_ii(1857,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z60mscorlib_System_Array_m_InternalArray__ICollection_get_CountP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220920);
 __THREW__ = 0;
 $0 = (invoke_ii(1857,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z65mscorlib_System_Array_m_InternalArray__ICollection_get_IsReadOnlyP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2220968);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z56mscorlib_System_Array_m_InternalArray__ICollection_ClearP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221016);
 __THREW__ = 0;
 invoke_v(466);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012088>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3830,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z47mscorlib_System_Array_m_InternalArray__RemoveAtP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221064);
 __THREW__ = 0;
 invoke_v(467);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012512>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3830,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z33mscorlib_System_Array_m_GetLengthP21mscorlib_System_Arrayi($__this,$dimension) {
 $__this = $__this|0;
 $dimension = $dimension|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221336);
 $0 = HEAP32[2221384>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2221392|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2221384>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($dimension|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_Array_m_get_LongLengthP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221160);
 __THREW__ = 0;
 $0 = (invoke_ii(1857,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = ($0|0)<(0);
  $4 = $3 << 31 >> 31;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $4;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z31mscorlib_System_Array_m_GetRankP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221256);
 $0 = HEAP32[2221304>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2221312|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2221304>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Array_m_GetLongLengthP21mscorlib_System_Arrayi($__this,$dimension) {
 $__this = $__this|0;
 $dimension = $dimension|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221432);
 __THREW__ = 0;
 $0 = (invoke_iii(753,($__this|0),($dimension|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = ($0|0)<(0);
  $4 = $3 << 31 >> 31;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $4;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z85mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int32_arr_arrP21mscorlib_System_ArrayP25mscorlib_System_Int32_arr($__this,$indices) {
 $__this = $__this|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221584);
 $0 = HEAP32[2221632>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2221640|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2221632>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($indices|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int32_arr_arrP21mscorlib_System_ArrayP22mscorlib_System_ObjectP25mscorlib_System_Int32_arr($__this,$value,$indices) {
 $__this = $__this|0;
 $value = $value|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2221680);
 $0 = HEAP32[2221728>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2221736|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2221728>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($__this|0),($value|0),($indices|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z32mscorlib_System_Array_m_FastCopyP22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii($__this,$source,$source_idx,$dest,$dest_idx,$length) {
 $__this = $__this|0;
 $source = $source|0;
 $source_idx = $source_idx|0;
 $dest = $dest|0;
 $dest_idx = $dest_idx|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222008);
 $0 = HEAP32[2222056>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2222064|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2222056>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiiii($7|0,($source|0),($source_idx|0),($dest|0),($dest_idx|0),($length|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_Array_m_CreateInstanceImplP22mscorlib_System_ObjectP20mscorlib_System_TypeP25mscorlib_System_Int32_arrS4_($__this,$elementType,$lengths,$bounds) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 $lengths = $lengths|0;
 $bounds = $bounds|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222160);
 $0 = HEAP32[2222208>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2222216|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2222208>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($elementType|0),($lengths|0),($bounds|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_Array_m_get_IsSynchronizedP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222296);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z36mscorlib_System_Array_m_get_SyncRootP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222344);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z39mscorlib_System_Array_m_get_IsFixedSizeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222392);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z38mscorlib_System_Array_m_get_IsReadOnlyP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222440);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z37mscorlib_System_Array_m_GetEnumeratorP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222488);
 __THREW__ = 0;
 (invoke_ii(2996,(2218920|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2218920|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1774,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Array_m_GetUpperBoundP21mscorlib_System_Arrayi($__this,$dimension) {
 $__this = $__this|0;
 $dimension = $dimension|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222536);
 __THREW__ = 0;
 $0 = (invoke_iii(755,($__this|0),($dimension|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(753,($__this|0),($dimension|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($0) + -1)|0;
   $7 = (($6) + ($3))|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($7|0);
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P21mscorlib_System_Arrayii($__this,$index1,$index2) {
 $__this = $__this|0;
 $index1 = $index1|0;
 $index2 = $index2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $index1$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222632);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1170368|0),2)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     $index1$c = $index1;
     HEAP32[$17>>2] = $index1$c;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$7>>2]|0;
      $21 = ($20>>>0)<(2);
      if ($21) {
       __THREW__ = 0;
       $22 = (invoke_i(132)|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
      }
      $27 = HEAP32[$2>>2]|0;
      $28 = (($27) + 92|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($17) + ($29)|0);
      HEAP32[$30>>2] = $index2;
      __THREW__ = 0;
      $31 = (invoke_iii(756,($__this|0),($2|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($31|0);
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P21mscorlib_System_Arrayiii($__this,$index1,$index2,$index3) {
 $__this = $__this|0;
 $index1 = $index1|0;
 $index2 = $index2|0;
 $index3 = $index3|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $index1$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222680);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1170368|0),3)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     $index1$c = $index1;
     HEAP32[$17>>2] = $index1$c;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$7>>2]|0;
      $21 = ($20>>>0)<(2);
      if ($21) {
       __THREW__ = 0;
       $22 = (invoke_i(132)|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
      }
      $27 = HEAP32[$2>>2]|0;
      $28 = (($27) + 92|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($17) + ($29)|0);
      HEAP32[$30>>2] = $index2;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $33 = HEAP32[$7>>2]|0;
       $34 = ($33>>>0)<(3);
       if ($34) {
        __THREW__ = 0;
        $35 = (invoke_i(132)|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($35|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
       }
       $40 = HEAP32[$2>>2]|0;
       $41 = (($40) + 92|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = $42 << 1;
       $44 = (($17) + ($43)|0);
       HEAP32[$44>>2] = $index3;
       __THREW__ = 0;
       $45 = (invoke_iii(756,($__this|0),($2|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($45|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64P21mscorlib_System_Arrayx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222728);
 __THREW__ = 0;
 invoke_v(468);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($1>>>0)<(0);
   $5 = ($1|0)==(0);
   $6 = ($0>>>0)<(2147483648);
   $7 = $5 & $6;
   $8 = $4 | $7;
   if ($8) {
    __THREW__ = 0;
    $25 = (invoke_iii(759,($__this|0),($0|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($25|0);
   }
   $11 = HEAP32[3012808>>2]|0;
   __THREW__ = 0;
   $12 = (invoke_iii(783,0,($11|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2561352|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[3012800>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($17|0),($20|0),($12|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3830,($17|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64P21mscorlib_System_Arrayxx($__this,$0,$1,$2,$3) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222776);
 __THREW__ = 0;
 invoke_v(469);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = ($1>>>0)<(0);
   $7 = ($1|0)==(0);
   $8 = ($0>>>0)<(2147483648);
   $9 = $7 & $8;
   $10 = $6 | $9;
   if (!($10)) {
    $13 = HEAP32[3012920>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_iii(783,0,($13|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3012912>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($19|0),($22|0),($14|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($19|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    // unreachable;
   }
   $27 = ($3>>>0)<(0);
   $28 = ($3|0)==(0);
   $29 = ($2>>>0)<(2147483648);
   $30 = $28 & $29;
   $31 = $27 | $30;
   if ($31) {
    __THREW__ = 0;
    $46 = (invoke_iiii(676,($__this|0),($0|0),($2|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($46|0);
   }
   $32 = HEAP32[3012936>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_iii(783,0,($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     $38 = (invoke_ii(3469,(2561352|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = HEAP32[3012928>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($38|0),($41|0),($33|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       __THREW__ = 0;
       invoke_vi(3830,($38|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64_mscorlib_System_Int64P21mscorlib_System_Arrayxxx($__this,$0,$1,$2,$3,$4,$5) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222824);
 __THREW__ = 0;
 invoke_v(470);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if (!($7)) {
   $8 = ($1>>>0)<(0);
   $9 = ($1|0)==(0);
   $10 = ($0>>>0)<(2147483648);
   $11 = $9 & $10;
   $12 = $8 | $11;
   if (!($12)) {
    $15 = HEAP32[3012992>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii(783,0,($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2561352|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = HEAP32[3012984>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($21|0),($24|0),($16|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($21|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    // unreachable;
   }
   $29 = ($3>>>0)<(0);
   $30 = ($3|0)==(0);
   $31 = ($2>>>0)<(2147483648);
   $32 = $30 & $31;
   $33 = $29 | $32;
   if (!($33)) {
    $34 = HEAP32[3013008>>2]|0;
    __THREW__ = 0;
    $35 = (invoke_iii(783,0,($34|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3469,(2561352|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $43 = HEAP32[3013000>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($40|0),($43|0),($35|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($40|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    // unreachable;
   }
   $48 = ($5>>>0)<(0);
   $49 = ($5|0)==(0);
   $50 = ($4>>>0)<(2147483648);
   $51 = $49 & $50;
   $52 = $48 | $51;
   if ($52) {
    __THREW__ = 0;
    $67 = (invoke_iiiii(111,($__this|0),($0|0),($2|0),($4|0))|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($67|0);
   }
   $53 = HEAP32[3013024>>2]|0;
   __THREW__ = 0;
   $54 = (invoke_iii(783,0,($53|0))|0);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if (!($56)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if (!($58)) {
     __THREW__ = 0;
     $59 = (invoke_ii(3469,(2561352|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if (!($61)) {
      $62 = HEAP32[3013016>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($59|0),($62|0),($54|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if (!($64)) {
       __THREW__ = 0;
       invoke_vi(3830,($59|0));
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if (!($66)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64P21mscorlib_System_ArrayP22mscorlib_System_Objectx($__this,$value,$0,$1) {
 $__this = $__this|0;
 $value = $value|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222872);
 __THREW__ = 0;
 invoke_v(471);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($1>>>0)<(0);
   $5 = ($1|0)==(0);
   $6 = ($0>>>0)<(2147483648);
   $7 = $5 & $6;
   $8 = $4 | $7;
   if ($8) {
    __THREW__ = 0;
    invoke_viii(534,($__this|0),($value|0),($0|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $11 = HEAP32[3013064>>2]|0;
   __THREW__ = 0;
   $12 = (invoke_iii(783,0,($11|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2561352|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[3013056>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($17|0),($20|0),($12|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3830,($17|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int32P21mscorlib_System_ArrayP22mscorlib_System_Objecti($__this,$value,$index) {
 $__this = $__this|0;
 $value = $value|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223016);
 __THREW__ = 0;
 invoke_v(472);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(1);
    if (!($5)) {
     $8 = HEAP32[3013176>>2]|0;
     __THREW__ = 0;
     $9 = (invoke_iii(783,0,($8|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     $14 = (invoke_ii(3469,(2560072|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($14|0),($9|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($14|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $21 = (invoke_iii(755,($__this|0),0)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = ($21|0)>($index|0);
     if (!($24)) {
      __THREW__ = 0;
      $25 = (invoke_iii(758,($__this|0),0)|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      $28 = ($25|0)<($index|0);
      if (!($28)) {
       __THREW__ = 0;
       $42 = (invoke_iii(755,($__this|0),0)|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $45 = (($index) - ($42))|0;
       __THREW__ = 0;
       invoke_viii(533,($__this|0),($value|0),($45|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
     $29 = HEAP32[3013184>>2]|0;
     __THREW__ = 0;
     $30 = (invoke_iii(783,0,($29|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2606944|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       $35 = (invoke_ii(3469,(2606944|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __THREW__ = 0;
        invoke_vii(1945,($35|0),($30|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         __THREW__ = 0;
         invoke_vi(3830,($35|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z120mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64P21mscorlib_System_ArrayP22mscorlib_System_Objectxx($__this,$value,$0,$1,$2,$3) {
 $__this = $__this|0;
 $value = $value|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$c = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222920);
 __THREW__ = 0;
 invoke_v(473);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = ($1>>>0)<(0);
   $7 = ($1|0)==(0);
   $8 = ($0>>>0)<(2147483648);
   $9 = $7 & $8;
   $10 = $6 | $9;
   if (!($10)) {
    $13 = HEAP32[3013088>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_iii(783,0,($13|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3013080>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($19|0),($22|0),($14|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($19|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    // unreachable;
   }
   $27 = ($3>>>0)<(0);
   $28 = ($3|0)==(0);
   $29 = ($2>>>0)<(2147483648);
   $30 = $28 & $29;
   $31 = $27 | $30;
   if (!($31)) {
    $32 = HEAP32[3013104>>2]|0;
    __THREW__ = 0;
    $33 = (invoke_iii(783,0,($32|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    __THREW__ = 0;
    $38 = (invoke_ii(3469,(2561352|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    $41 = HEAP32[3013096>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($38|0),($41|0),($33|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($38|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1170368|0))|0);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if (!($47)) {
    __THREW__ = 0;
    $48 = (invoke_iii(2754,(1170368|0),2)|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if (!($50)) {
     __THREW__ = 0;
     invoke_vi(3799,($48|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if (!($52)) {
      $53 = (($48) + 12|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($54|0)==(0);
      if ($55) {
       __THREW__ = 0;
       $56 = (invoke_i(132)|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($56|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
      }
      $61 = (($48) + 16|0);
      $$c = $0;
      HEAP32[$61>>2] = $$c;
      __THREW__ = 0;
      invoke_vi(3799,($48|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if (!($63)) {
       $64 = HEAP32[$53>>2]|0;
       $65 = ($64>>>0)<(2);
       if ($65) {
        __THREW__ = 0;
        $66 = (invoke_i(132)|0);
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($66|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
       }
       $71 = HEAP32[$48>>2]|0;
       $72 = (($71) + 92|0);
       $73 = HEAP32[$72>>2]|0;
       $74 = (($61) + ($73)|0);
       HEAP32[$74>>2] = $2;
       __THREW__ = 0;
       invoke_viii(532,($__this|0),($value|0),($48|0));
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if (!($76)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z142mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64_mscorlib_System_Int64P21mscorlib_System_ArrayP22mscorlib_System_Objectxxx($__this,$value,$0,$1,$2,$3,$4,$5) {
 $__this = $__this|0;
 $value = $value|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $$c = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2222968);
 __THREW__ = 0;
 invoke_v(474);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if (!($7)) {
   $8 = ($1>>>0)<(0);
   $9 = ($1|0)==(0);
   $10 = ($0>>>0)<(2147483648);
   $11 = $9 & $10;
   $12 = $8 | $11;
   if (!($12)) {
    $15 = HEAP32[3013128>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii(783,0,($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2561352|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = HEAP32[3013120>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($21|0),($24|0),($16|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($21|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    // unreachable;
   }
   $29 = ($3>>>0)<(0);
   $30 = ($3|0)==(0);
   $31 = ($2>>>0)<(2147483648);
   $32 = $30 & $31;
   $33 = $29 | $32;
   if (!($33)) {
    $34 = HEAP32[3013144>>2]|0;
    __THREW__ = 0;
    $35 = (invoke_iii(783,0,($34|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3469,(2561352|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $43 = HEAP32[3013136>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($40|0),($43|0),($35|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($40|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    // unreachable;
   }
   $48 = ($5>>>0)<(0);
   $49 = ($5|0)==(0);
   $50 = ($4>>>0)<(2147483648);
   $51 = $49 & $50;
   $52 = $48 | $51;
   if (!($52)) {
    $53 = HEAP32[3013160>>2]|0;
    __THREW__ = 0;
    $54 = (invoke_iii(783,0,($53|0))|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     break;
    }
    __THREW__ = 0;
    $59 = (invoke_ii(3469,(2561352|0))|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     break;
    }
    $62 = HEAP32[3013152>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($59|0),($62|0),($54|0));
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($59|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1170368|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if (!($68)) {
    __THREW__ = 0;
    $69 = (invoke_iii(2754,(1170368|0),3)|0);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if (!($71)) {
     __THREW__ = 0;
     invoke_vi(3799,($69|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if (!($73)) {
      $74 = (($69) + 12|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = ($75|0)==(0);
      if ($76) {
       __THREW__ = 0;
       $77 = (invoke_i(132)|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($77|0));
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
      }
      $82 = (($69) + 16|0);
      $$c = $0;
      HEAP32[$82>>2] = $$c;
      __THREW__ = 0;
      invoke_vi(3799,($69|0));
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if (!($84)) {
       $85 = HEAP32[$74>>2]|0;
       $86 = ($85>>>0)<(2);
       if ($86) {
        __THREW__ = 0;
        $87 = (invoke_i(132)|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($87|0));
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         break;
        }
       }
       $92 = HEAP32[$69>>2]|0;
       $93 = (($92) + 92|0);
       $94 = HEAP32[$93>>2]|0;
       $95 = (($82) + ($94)|0);
       HEAP32[$95>>2] = $2;
       __THREW__ = 0;
       invoke_vi(3799,($69|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        $98 = HEAP32[$74>>2]|0;
        $99 = ($98>>>0)<(3);
        if ($99) {
         __THREW__ = 0;
         $100 = (invoke_i(132)|0);
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($100|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          break;
         }
        }
        $105 = HEAP32[$69>>2]|0;
        $106 = (($105) + 92|0);
        $107 = HEAP32[$106>>2]|0;
        $108 = $107 << 1;
        $109 = (($82) + ($108)|0);
        HEAP32[$109>>2] = $4;
        __THREW__ = 0;
        invoke_viii(532,($__this|0),($value|0),($69|0));
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if (!($111)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z120mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P21mscorlib_System_ArrayP22mscorlib_System_Objectii($__this,$value,$index1,$index2) {
 $__this = $__this|0;
 $value = $value|0;
 $index1 = $index1|0;
 $index2 = $index2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $index1$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223064);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1170368|0),2)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     $index1$c = $index1;
     HEAP32[$17>>2] = $index1$c;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$7>>2]|0;
      $21 = ($20>>>0)<(2);
      if ($21) {
       __THREW__ = 0;
       $22 = (invoke_i(132)|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
      }
      $27 = HEAP32[$2>>2]|0;
      $28 = (($27) + 92|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($17) + ($29)|0);
      HEAP32[$30>>2] = $index2;
      __THREW__ = 0;
      invoke_viii(532,($__this|0),($value|0),($2|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z142mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P21mscorlib_System_ArrayP22mscorlib_System_Objectiii($__this,$value,$index1,$index2,$index3) {
 $__this = $__this|0;
 $value = $value|0;
 $index1 = $index1|0;
 $index2 = $index2|0;
 $index3 = $index3|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $index1$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223112);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1170368|0),3)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     $index1$c = $index1;
     HEAP32[$17>>2] = $index1$c;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$7>>2]|0;
      $21 = ($20>>>0)<(2);
      if ($21) {
       __THREW__ = 0;
       $22 = (invoke_i(132)|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
      }
      $27 = HEAP32[$2>>2]|0;
      $28 = (($27) + 92|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($17) + ($29)|0);
      HEAP32[$30>>2] = $index2;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $33 = HEAP32[$7>>2]|0;
       $34 = ($33>>>0)<(3);
       if ($34) {
        __THREW__ = 0;
        $35 = (invoke_i(132)|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($35|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
       }
       $40 = HEAP32[$2>>2]|0;
       $41 = (($40) + 92|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = $42 << 1;
       $44 = (($17) + ($43)|0);
       HEAP32[$44>>2] = $index3;
       __THREW__ = 0;
       invoke_viii(532,($__this|0),($value|0),($2|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32P22mscorlib_System_ObjectP20mscorlib_System_Typei($__this,$elementType,$length) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $length$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223160);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1170368|0),1)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     $length$c = $length;
     HEAP32[$17>>2] = $length$c;
     __THREW__ = 0;
     $18 = (invoke_iiii(690,0,($elementType|0),($2|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($18|0);
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP25mscorlib_System_Int32_arr($__this,$elementType,$lengths) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 $lengths = $lengths|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223304);
 __THREW__ = 0;
 invoke_v(475);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($elementType|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3013328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = ($lengths|0)==(0|0);
   if ($16) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3013336>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($19|0),($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($19|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($lengths|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = (($lengths) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)<(256);
    if (!($31)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2657288|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     __THREW__ = 0;
     $34 = (invoke_ii(3469,(2657288|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2791,($34|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($34|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(3799,($elementType|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     __THREW__ = 0;
     $43 = (invoke_iii(2730,(2223352|0),($elementType|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      __THREW__ = 0;
      invoke_vi(3799,($43|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       $48 = (invoke_ii(1892,($43|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if (!($50)) {
        if (!($48)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          break;
         }
         __THREW__ = 0;
         $53 = (invoke_ii(3469,(2560072|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break;
         }
         $56 = HEAP32[3013344>>2]|0;
         $57 = HEAP32[3013352>>2]|0;
         __THREW__ = 0;
         invoke_viii(641,($53|0),($56|0),($57|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3830,($53|0));
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          break;
         }
         // unreachable;
        }
        HEAP32[$0>>2] = 1271016;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        $62 = (invoke_iii(772,0,($$byval_copy|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if (!($64)) {
         __THREW__ = 0;
         invoke_vi(3799,($43|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if (!($66)) {
          __THREW__ = 0;
          $67 = (invoke_iiii(1640,(2223400|0),($43|0),($62|0))|0);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if (!($69)) {
           if ($67) {
            __THREW__ = 0;
            (invoke_ii(2996,(2622808|0))|0);
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if ($71) {
             break;
            }
            __THREW__ = 0;
            $72 = (invoke_ii(3469,(2622808|0))|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            $75 = HEAP32[3013360>>2]|0;
            __THREW__ = 0;
            invoke_vii(1954,($72|0),($75|0));
            $76 = __THREW__; __THREW__ = 0;
            $77 = $76&1;
            if ($77) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3830,($72|0));
            $78 = __THREW__; __THREW__ = 0;
            $79 = $78&1;
            if ($79) {
             break;
            }
            // unreachable;
           }
           __THREW__ = 0;
           invoke_vi(3799,($43|0));
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            $82 = (invoke_iii(2734,(2223448|0),($43|0))|0);
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if (!($84)) {
             if (!($82)) {
              __THREW__ = 0;
              $95 = (invoke_iiiii(110,0,($43|0),($lengths|0),(0|0))|0);
              $96 = __THREW__; __THREW__ = 0;
              $97 = $96&1;
              if ($97) {
               break;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($95|0);
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2622808|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              __THREW__ = 0;
              $87 = (invoke_ii(3469,(2622808|0))|0);
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               $90 = HEAP32[3013368>>2]|0;
               __THREW__ = 0;
               invoke_vii(1954,($87|0),($90|0));
               $91 = __THREW__; __THREW__ = 0;
               $92 = $91&1;
               if ($92) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3830,($87|0));
               $93 = __THREW__; __THREW__ = 0;
               $94 = $93&1;
               if ($94) {
                break;
               }
               // unreachable;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP20mscorlib_System_Typeii($__this,$elementType,$length1,$length2) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 $length1 = $length1|0;
 $length2 = $length2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $length1$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223208);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1170368|0),2)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     $length1$c = $length1;
     HEAP32[$17>>2] = $length1$c;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$7>>2]|0;
      $21 = ($20>>>0)<(2);
      if ($21) {
       __THREW__ = 0;
       $22 = (invoke_i(132)|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
      }
      $27 = HEAP32[$2>>2]|0;
      $28 = (($27) + 92|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($17) + ($29)|0);
      HEAP32[$30>>2] = $length2;
      __THREW__ = 0;
      $31 = (invoke_iiii(690,0,($elementType|0),($2|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($31|0);
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z147mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP20mscorlib_System_Typeiii($__this,$elementType,$length1,$length2,$length3) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 $length1 = $length1|0;
 $length2 = $length2|0;
 $length3 = $length3|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $length1$c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223256);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2754,(1170368|0),3)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     $length1$c = $length1;
     HEAP32[$17>>2] = $length1$c;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$7>>2]|0;
      $21 = ($20>>>0)<(2);
      if ($21) {
       __THREW__ = 0;
       $22 = (invoke_i(132)|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
      }
      $27 = HEAP32[$2>>2]|0;
      $28 = (($27) + 92|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($17) + ($29)|0);
      HEAP32[$30>>2] = $length2;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $33 = HEAP32[$7>>2]|0;
       $34 = ($33>>>0)<(3);
       if ($34) {
        __THREW__ = 0;
        $35 = (invoke_i(132)|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($35|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
       }
       $40 = HEAP32[$2>>2]|0;
       $41 = (($40) + 92|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = $42 << 1;
       $44 = (($17) + ($43)|0);
       HEAP32[$44>>2] = $length3;
       __THREW__ = 0;
       $45 = (invoke_iiii(690,0,($elementType|0),($2|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($45|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Type_m_get_IsSystemTypeP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237056);
 $2 = (($__this) + 8|0);
 __THREW__ = 0;
 $3 = (invoke_ii(1914,($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2210080|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = HEAP32[((2210080 + 80|0))>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $3;
   HEAP32[$1>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   $10 = (invoke_iiii(645,0,($$byval_copy|0),($$byval_copy1|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($10|0);
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z141mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32_arr_arr_mscorlib_System_Int32_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP25mscorlib_System_Int32_arrS4_($__this,$elementType,$lengths,$lowerBounds) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 $lengths = $lengths|0;
 $lowerBounds = $lowerBounds|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223496);
 __THREW__ = 0;
 invoke_v(476);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($elementType|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3013656>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($10|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   }
   $18 = ($lengths|0)==(0|0);
   if ($18) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2560584|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = HEAP32[3013664>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($21|0),($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($21|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    // unreachable;
   }
   $29 = ($lowerBounds|0)==(0|0);
   if ($29) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    __THREW__ = 0;
    $32 = (invoke_ii(3469,(2560584|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = HEAP32[3013672>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($32|0),($35|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($32|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($elementType|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    __THREW__ = 0;
    $42 = (invoke_iii(2730,(2223352|0),($elementType|0))|0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if (!($44)) {
     __THREW__ = 0;
     invoke_vi(3799,($42|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      __THREW__ = 0;
      $47 = (invoke_ii(1892,($42|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if (!($49)) {
       if (!($47)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        __THREW__ = 0;
        $52 = (invoke_ii(3469,(2560072|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        $55 = HEAP32[3013680>>2]|0;
        $56 = HEAP32[3013688>>2]|0;
        __THREW__ = 0;
        invoke_viii(641,($52|0),($55|0),($56|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3830,($52|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        // unreachable;
       }
       HEAP32[$0>>2] = 1271016;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       $61 = (invoke_iii(772,0,($$byval_copy|0))|0);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if (!($63)) {
        __THREW__ = 0;
        invoke_vi(3799,($42|0));
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if (!($65)) {
         __THREW__ = 0;
         $66 = (invoke_iiii(1640,(2223400|0),($42|0),($61|0))|0);
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if (!($68)) {
          if ($66) {
           __THREW__ = 0;
           (invoke_ii(2996,(2622808|0))|0);
           $69 = __THREW__; __THREW__ = 0;
           $70 = $69&1;
           if ($70) {
            break;
           }
           __THREW__ = 0;
           $71 = (invoke_ii(3469,(2622808|0))|0);
           $72 = __THREW__; __THREW__ = 0;
           $73 = $72&1;
           if ($73) {
            break;
           }
           $74 = HEAP32[3013696>>2]|0;
           __THREW__ = 0;
           invoke_vii(1954,($71|0),($74|0));
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if ($76) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3830,($71|0));
           $77 = __THREW__; __THREW__ = 0;
           $78 = $77&1;
           if ($78) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_vi(3799,($42|0));
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if (!($80)) {
           __THREW__ = 0;
           $81 = (invoke_iii(2734,(2223448|0),($42|0))|0);
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if (!($83)) {
            if ($81) {
             __THREW__ = 0;
             (invoke_ii(2996,(2622808|0))|0);
             $84 = __THREW__; __THREW__ = 0;
             $85 = $84&1;
             if ($85) {
              break;
             }
             __THREW__ = 0;
             $86 = (invoke_ii(3469,(2622808|0))|0);
             $87 = __THREW__; __THREW__ = 0;
             $88 = $87&1;
             if ($88) {
              break;
             }
             $89 = HEAP32[3013704>>2]|0;
             __THREW__ = 0;
             invoke_vii(1954,($86|0),($89|0));
             $90 = __THREW__; __THREW__ = 0;
             $91 = $90&1;
             if ($91) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3830,($86|0));
             $92 = __THREW__; __THREW__ = 0;
             $93 = $92&1;
             if ($93) {
              break;
             }
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($lengths|0));
            $94 = __THREW__; __THREW__ = 0;
            $95 = $94&1;
            if (!($95)) {
             $96 = (($lengths) + 12|0);
             $97 = HEAP32[$96>>2]|0;
             $98 = ($97|0)>(0);
             if (!($98)) {
              $99 = HEAP32[3013712>>2]|0;
              __THREW__ = 0;
              $100 = (invoke_iii(783,0,($99|0))|0);
              $101 = __THREW__; __THREW__ = 0;
              $102 = $101&1;
              if ($102) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2560072|0))|0);
              $103 = __THREW__; __THREW__ = 0;
              $104 = $103&1;
              if ($104) {
               break;
              }
              __THREW__ = 0;
              $105 = (invoke_ii(3469,(2560072|0))|0);
              $106 = __THREW__; __THREW__ = 0;
              $107 = $106&1;
              if ($107) {
               break;
              }
              __THREW__ = 0;
              invoke_vii(1924,($105|0),($100|0));
              $108 = __THREW__; __THREW__ = 0;
              $109 = $108&1;
              if ($109) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3830,($105|0));
              $110 = __THREW__; __THREW__ = 0;
              $111 = $110&1;
              if ($111) {
               break;
              }
              // unreachable;
             }
             __THREW__ = 0;
             invoke_vi(3799,($lengths|0));
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if (!($113)) {
              $114 = HEAP32[$96>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($lowerBounds|0));
              $115 = __THREW__; __THREW__ = 0;
              $116 = $115&1;
              if ($116) {
               break;
              }
              $117 = (($lowerBounds) + 12|0);
              $118 = HEAP32[$117>>2]|0;
              $119 = ($114|0)==($118|0);
              if (!($119)) {
               $122 = HEAP32[3013720>>2]|0;
               __THREW__ = 0;
               $123 = (invoke_iii(783,0,($122|0))|0);
               $124 = __THREW__; __THREW__ = 0;
               $125 = $124&1;
               if ($125) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2560072|0))|0);
               $126 = __THREW__; __THREW__ = 0;
               $127 = $126&1;
               if ($127) {
                break;
               }
               __THREW__ = 0;
               $128 = (invoke_ii(3469,(2560072|0))|0);
               $129 = __THREW__; __THREW__ = 0;
               $130 = $129&1;
               if ($130) {
                break;
               }
               __THREW__ = 0;
               invoke_vii(1924,($128|0),($123|0));
               $131 = __THREW__; __THREW__ = 0;
               $132 = $131&1;
               if ($132) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3830,($128|0));
               $133 = __THREW__; __THREW__ = 0;
               $134 = $133&1;
               if ($134) {
                break;
               }
               // unreachable;
              }
              $120 = (($lengths) + 16|0);
              $121 = (($lowerBounds) + 16|0);
              $V_0$0 = 0;
              while(1) {
               __THREW__ = 0;
               invoke_vi(3799,($lowerBounds|0));
               $219 = __THREW__; __THREW__ = 0;
               $220 = $219&1;
               if ($220) {
                label = 3;
                break;
               }
               $221 = HEAP32[$117>>2]|0;
               $222 = ($V_0$0|0)<($221|0);
               if (!($222)) {
                label = 96;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($lengths|0));
               $223 = __THREW__; __THREW__ = 0;
               $224 = $223&1;
               if ($224) {
                label = 3;
                break;
               }
               $135 = HEAP32[$96>>2]|0;
               $136 = ($V_0$0>>>0)<($135>>>0);
               if (!($136)) {
                __THREW__ = 0;
                $137 = (invoke_i(132)|0);
                $138 = __THREW__; __THREW__ = 0;
                $139 = $138&1;
                if ($139) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($137|0));
                $140 = __THREW__; __THREW__ = 0;
                $141 = $140&1;
                if ($141) {
                 label = 3;
                 break;
                }
               }
               $142 = HEAP32[$lengths>>2]|0;
               $143 = (($142) + 92|0);
               $144 = HEAP32[$143>>2]|0;
               $145 = Math_imul($144, $V_0$0)|0;
               $146 = (($120) + ($145)|0);
               $147 = HEAP32[$146>>2]|0;
               $148 = ($147|0)>(-1);
               if (!($148)) {
                label = 72;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($lowerBounds|0));
               $163 = __THREW__; __THREW__ = 0;
               $164 = $163&1;
               if ($164) {
                label = 3;
                break;
               }
               $165 = HEAP32[$117>>2]|0;
               $166 = ($V_0$0>>>0)<($165>>>0);
               if (!($166)) {
                __THREW__ = 0;
                $167 = (invoke_i(132)|0);
                $168 = __THREW__; __THREW__ = 0;
                $169 = $168&1;
                if ($169) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($167|0));
                $170 = __THREW__; __THREW__ = 0;
                $171 = $170&1;
                if ($171) {
                 label = 3;
                 break;
                }
               }
               $172 = HEAP32[$lowerBounds>>2]|0;
               $173 = (($172) + 92|0);
               $174 = HEAP32[$173>>2]|0;
               $175 = Math_imul($174, $V_0$0)|0;
               $176 = (($121) + ($175)|0);
               $177 = HEAP32[$176>>2]|0;
               $178 = ($177|0)<(0);
               $179 = $178 << 31 >> 31;
               __THREW__ = 0;
               invoke_vi(3799,($lengths|0));
               $180 = __THREW__; __THREW__ = 0;
               $181 = $180&1;
               if ($181) {
                label = 3;
                break;
               }
               $182 = HEAP32[$96>>2]|0;
               $183 = ($V_0$0>>>0)<($182>>>0);
               if (!($183)) {
                __THREW__ = 0;
                $184 = (invoke_i(132)|0);
                $185 = __THREW__; __THREW__ = 0;
                $186 = $185&1;
                if ($186) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($184|0));
                $187 = __THREW__; __THREW__ = 0;
                $188 = $187&1;
                if ($188) {
                 label = 3;
                 break;
                }
               }
               $189 = HEAP32[$lengths>>2]|0;
               $190 = (($189) + 92|0);
               $191 = HEAP32[$190>>2]|0;
               $192 = Math_imul($191, $V_0$0)|0;
               $193 = (($120) + ($192)|0);
               $194 = HEAP32[$193>>2]|0;
               $195 = ($194|0)<(0);
               $196 = $195 << 31 >> 31;
               $197 = (_i64Add(($194|0),($196|0),($177|0),($179|0))|0);
               $198 = tempRet0;
               $199 = ($198|0)<(0);
               $200 = ($198|0)==(0);
               $201 = ($197>>>0)<(2147483648);
               $202 = $200 & $201;
               $203 = $199 | $202;
               $204 = (($V_0$0) + 1)|0;
               if ($203) {
                $V_0$0 = $204;
               } else {
                label = 87;
                break;
               }
              }
              if ((label|0) == 3) {
               $4 = ___cxa_find_matching_catch()|0;
               $5 = tempRet0;
               $lpad$phi$index = $4;$lpad$phi$index2 = $5;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($lpad$phi$index|0);
               // unreachable;
              }
              else if ((label|0) == 72) {
               $149 = HEAP32[3013736>>2]|0;
               __THREW__ = 0;
               $150 = (invoke_iii(783,0,($149|0))|0);
               $151 = __THREW__; __THREW__ = 0;
               $152 = $151&1;
               if ($152) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2561352|0))|0);
               $153 = __THREW__; __THREW__ = 0;
               $154 = $153&1;
               if ($154) {
                break;
               }
               __THREW__ = 0;
               $155 = (invoke_ii(3469,(2561352|0))|0);
               $156 = __THREW__; __THREW__ = 0;
               $157 = $156&1;
               if ($157) {
                break;
               }
               $158 = HEAP32[3013728>>2]|0;
               __THREW__ = 0;
               invoke_viii(644,($155|0),($158|0),($150|0));
               $159 = __THREW__; __THREW__ = 0;
               $160 = $159&1;
               if ($160) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3830,($155|0));
               $161 = __THREW__; __THREW__ = 0;
               $162 = $161&1;
               if ($162) {
                break;
               }
               // unreachable;
              }
              else if ((label|0) == 87) {
               $205 = HEAP32[3013752>>2]|0;
               __THREW__ = 0;
               $206 = (invoke_iii(783,0,($205|0))|0);
               $207 = __THREW__; __THREW__ = 0;
               $208 = $207&1;
               if ($208) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2561352|0))|0);
               $209 = __THREW__; __THREW__ = 0;
               $210 = $209&1;
               if ($210) {
                break;
               }
               __THREW__ = 0;
               $211 = (invoke_ii(3469,(2561352|0))|0);
               $212 = __THREW__; __THREW__ = 0;
               $213 = $212&1;
               if ($213) {
                break;
               }
               $214 = HEAP32[3013744>>2]|0;
               __THREW__ = 0;
               invoke_viii(644,($211|0),($214|0),($206|0));
               $215 = __THREW__; __THREW__ = 0;
               $216 = $215&1;
               if ($216) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3830,($211|0));
               $217 = __THREW__; __THREW__ = 0;
               $218 = $217&1;
               if ($218) {
                break;
               }
               // unreachable;
              }
              else if ((label|0) == 96) {
               __THREW__ = 0;
               invoke_vi(3799,($lengths|0));
               $225 = __THREW__; __THREW__ = 0;
               $226 = $225&1;
               if ($226) {
                break;
               }
               $227 = HEAP32[$96>>2]|0;
               $228 = ($227|0)<(256);
               if ($228) {
                __THREW__ = 0;
                $238 = (invoke_iiiii(110,0,($42|0),($lengths|0),($lowerBounds|0))|0);
                $239 = __THREW__; __THREW__ = 0;
                $240 = $239&1;
                if ($240) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($238|0);
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2657288|0))|0);
               $229 = __THREW__; __THREW__ = 0;
               $230 = $229&1;
               if ($230) {
                break;
               }
               __THREW__ = 0;
               $231 = (invoke_ii(3469,(2657288|0))|0);
               $232 = __THREW__; __THREW__ = 0;
               $233 = $232&1;
               if ($233) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(2791,($231|0));
               $234 = __THREW__; __THREW__ = 0;
               $235 = $234&1;
               if ($235) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3830,($231|0));
               $236 = __THREW__; __THREW__ = 0;
               $237 = $236&1;
               if ($237) {
                break;
               }
               // unreachable;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $lpad$phi$index = $6;$lpad$phi$index2 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_Array_m_GetIntArrayP22mscorlib_System_ObjectP25mscorlib_System_Int64_arr($__this,$values) {
 $__this = $__this|0;
 $values = $values|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $V_2$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223544);
 __THREW__ = 0;
 invoke_v(477);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($values|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($values) + 12|0);
    $5 = HEAP32[$4>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(1170368|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_iii(2754,(1170368|0),($5|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = ($5|0)>(0);
      if (!($11)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($8|0);
      }
      $12 = (($values) + 16|0);
      $13 = (($8) + 16|0);
      $14 = (($8) + 12|0);
      $V_2$02 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($values|0));
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        label = 7;
        break;
       }
       $19 = HEAP32[$4>>2]|0;
       $20 = ($V_2$02>>>0)<($19>>>0);
       if (!($20)) {
        __THREW__ = 0;
        $21 = (invoke_i(132)|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         label = 7;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($21|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 7;
         break;
        }
       }
       $26 = HEAP32[$values>>2]|0;
       $27 = (($26) + 92|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = Math_imul($28, $V_2$02)|0;
       $30 = (($12) + ($29)|0);
       $31 = $30;
       $32 = $31;
       $33 = HEAP32[$32>>2]|0;
       $34 = (($31) + 4)|0;
       $35 = $34;
       $36 = HEAP32[$35>>2]|0;
       $37 = ($36>>>0)<(0);
       $38 = ($36|0)==(0);
       $39 = ($33>>>0)<(2147483648);
       $40 = $38 & $39;
       $41 = $37 | $40;
       if (!($41)) {
        label = 14;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($8|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        label = 7;
        break;
       }
       $58 = HEAP32[$14>>2]|0;
       $59 = ($V_2$02>>>0)<($58>>>0);
       if (!($59)) {
        __THREW__ = 0;
        $60 = (invoke_i(132)|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 7;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($60|0));
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 7;
         break;
        }
       }
       $65 = HEAP32[$8>>2]|0;
       $66 = (($65) + 92|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = Math_imul($67, $V_2$02)|0;
       $69 = (($13) + ($68)|0);
       HEAP32[$69>>2] = $33;
       $70 = (($V_2$02) + 1)|0;
       $71 = ($70|0)<($5|0);
       if ($71) {
        $V_2$02 = $70;
       } else {
        label = 26;
        break;
       }
      }
      if ((label|0) == 7) {
       $15 = ___cxa_find_matching_catch()|0;
       $16 = tempRet0;
       $lpad$phi$index = $15;$lpad$phi$index2 = $16;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 14) {
       $42 = HEAP32[3014080>>2]|0;
       __THREW__ = 0;
       $43 = (invoke_iii(783,0,($42|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       __THREW__ = 0;
       $48 = (invoke_ii(3469,(2561352|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
       $51 = HEAP32[3014072>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($48|0),($51|0),($43|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3830,($48|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       }
       // unreachable;
      }
      else if ((label|0) == 26) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($8|0);
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $lpad$phi$index = $17;$lpad$phi$index2 = $18;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int64_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP25mscorlib_System_Int64_arr($__this,$elementType,$lengths) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 $lengths = $lengths|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223592);
 __THREW__ = 0;
 invoke_v(478);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($lengths|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iii(761,0,($lengths|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iiii(690,0,($elementType|0),($15|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3014192>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_arr_arrP21mscorlib_System_ArrayP25mscorlib_System_Int64_arr($__this,$indices) {
 $__this = $__this|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223640);
 __THREW__ = 0;
 invoke_v(479);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($indices|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iii(761,0,($indices|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(756,($__this|0),($15|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3014208>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_arr_arrP21mscorlib_System_ArrayP22mscorlib_System_ObjectP25mscorlib_System_Int64_arr($__this,$value,$indices) {
 $__this = $__this|0;
 $value = $value|0;
 $indices = $indices|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223688);
 __THREW__ = 0;
 invoke_v(480);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($indices|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iii(761,0,($indices|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(532,($__this|0),($value|0),($15|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3014240>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z38mscorlib_System_Array_m_DoBinarySearchP22mscorlib_System_ObjectP21mscorlib_System_ArrayiiS0_S0_($__this,$_____array,$index,$length,$value,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 $value = $value|0;
 $comparer = $comparer|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0;
 var $9 = 0, $V_0$0$lcssa = 0, $V_0$0$ph19 = 0, $V_0$013 = 0, $V_1$0$ph18 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223928);
 __THREW__ = 0;
 invoke_v(481);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($comparer|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2306688|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    $7 = HEAP8[((2306688 + 116|0))>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     __THREW__ = 0;
     (invoke_ii(2996,(2306688|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2306688|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2306688|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2306688|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = HEAP32[((2306688 + 80|0))>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $$01 = $18;
   } else {
    $$01 = $comparer;
   }
   $19 = (($index) + -1)|0;
   $20 = (($19) + ($length))|0;
   $21 = ($20|0)<($index|0);
   L13: do {
    if ($21) {
     $V_0$0$lcssa = $index;
    } else {
     $V_0$0$ph19 = $index;$V_1$0$ph18 = $20;
     L15: while(1) {
      $V_0$013 = $V_0$0$ph19;
      while(1) {
       $49 = (($V_1$0$ph18) - ($V_0$013))|0;
       $50 = (($49|0) / 2)&-1;
       $22 = (($50) + ($V_0$013))|0;
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break L15;
       }
       __THREW__ = 0;
       $23 = (invoke_iii(757,($_____array|0),($22|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break L15;
       }
       __THREW__ = 0;
       invoke_vi(3799,($$01|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break L15;
       }
       __THREW__ = 0;
       $28 = (invoke_iiiii(318,(2311568|0),($$01|0),($23|0),($value|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break L15;
       }
       $31 = ($28|0)==(0);
       if ($31) {
        $$0 = $22;
        label = 35;
        break L15;
       }
       $44 = ($28|0)<(1);
       $45 = (($22) + 1)|0;
       if (!($44)) {
        break;
       }
       $48 = ($22|0)<($V_1$0$ph18|0);
       if ($48) {
        $V_0$013 = $45;
       } else {
        $V_0$0$lcssa = $45;
        break L13;
       }
      }
      $46 = (($22) + -1)|0;
      $47 = ($V_0$013|0)>($46|0);
      if ($47) {
       $V_0$0$lcssa = $V_0$013;
       break L13;
      } else {
       $V_0$0$ph19 = $V_0$013;$V_1$0$ph18 = $46;
      }
     }
     if ((label|0) == 35) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $32 = ___cxa_find_matching_catch(348288|0)|0;
     $33 = tempRet0;
     $34 = (_llvm_eh_typeid_for((348288|0))|0);
     $35 = ($33|0)==($34|0);
     if (!($35)) {
      $$02 = $32;$$03 = $33;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$02|0);
      // unreachable;
     }
     $36 = (___cxa_begin_catch(($32|0))|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = HEAP32[$37>>2]|0;
     __THREW__ = 0;
     $39 = (invoke_iii(2727,(2246120|0),($38|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     do {
      if (!($41)) {
       if (!($39)) {
        $57 = (___cxa_allocate_exception(4)|0);
        $58 = HEAP32[$36>>2]|0;
        HEAP32[$57>>2] = $58;
        __THREW__ = 0;
        invoke_viii(1567,($57|0),(348288|0),(0|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        // unreachable;
       }
       __THREW__ = 0;
       invoke_v(66);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break L1;
       }
       $61 = HEAP32[3014920>>2]|0;
       __THREW__ = 0;
       $62 = (invoke_iii(783,0,($61|0))|0);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2607872|0))|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        break L1;
       }
       __THREW__ = 0;
       $67 = (invoke_ii(3469,(2607872|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break L1;
       }
       __THREW__ = 0;
       invoke_viii(678,($67|0),($62|0),($37|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3830,($67|0));
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break L1;
       }
       // unreachable;
      }
     } while(0);
     $53 = ___cxa_find_matching_catch()|0;
     $54 = tempRet0;
     __THREW__ = 0;
     invoke_v(66);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      $75 = ___cxa_find_matching_catch(0|0)|0;
      $76 = tempRet0;
      ___clang_call_terminate($75);
      // unreachable;
     } else {
      $$02 = $53;$$03 = $54;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$02|0);
      // unreachable;
     }
    }
   } while(0);
   $74 = $V_0$0$lcssa ^ -1;
   $$0 = $74;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$02 = $3;$$03 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z147mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_ObjectP22mscorlib_System_ObjectP21mscorlib_System_ArrayiiS0_($__this,$_____array,$index,$length,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223832);
 __THREW__ = 0;
 invoke_v(482);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3014504>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1859,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)<(2);
     if (!($20)) {
      $21 = HEAP32[3014512>>2]|0;
      __THREW__ = 0;
      $22 = (invoke_iii(783,0,($21|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636920|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_ii(3469,(2636920|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1972,($27|0),($22|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($27|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      __THREW__ = 0;
      $36 = (invoke_iii(755,($_____array|0),0)|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = ($36|0)>($index|0);
       if ($39) {
        $40 = HEAP32[3014528>>2]|0;
        __THREW__ = 0;
        $41 = (invoke_iii(783,0,($40|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
        __THREW__ = 0;
        $46 = (invoke_ii(3469,(2561352|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        $49 = HEAP32[3014520>>2]|0;
        __THREW__ = 0;
        invoke_viii(644,($46|0),($49|0),($41|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3830,($46|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        // unreachable;
       }
       $54 = ($length|0)>(-1);
       if (!($54)) {
        $55 = HEAP32[3014544>>2]|0;
        __THREW__ = 0;
        $56 = (invoke_iii(783,0,($55|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_ii(3469,(2561352|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[3014536>>2]|0;
        __THREW__ = 0;
        invoke_viii(644,($61|0),($64|0),($56|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3830,($61|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        // unreachable;
       }
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if (!($70)) {
        __THREW__ = 0;
        $71 = (invoke_iii(755,($_____array|0),0)|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if (!($73)) {
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if (!($75)) {
          __THREW__ = 0;
          $76 = (invoke_iii(753,($_____array|0),0)|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if (!($78)) {
           $79 = (($71) - ($length))|0;
           $80 = (($79) + ($76))|0;
           $81 = ($80|0)<($index|0);
           if ($81) {
            $82 = HEAP32[3014552>>2]|0;
            __THREW__ = 0;
            $83 = (invoke_iii(783,0,($82|0))|0);
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if ($85) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2560072|0))|0);
            $86 = __THREW__; __THREW__ = 0;
            $87 = $86&1;
            if ($87) {
             break;
            }
            __THREW__ = 0;
            $88 = (invoke_ii(3469,(2560072|0))|0);
            $89 = __THREW__; __THREW__ = 0;
            $90 = $89&1;
            if ($90) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1924,($88|0),($83|0));
            $91 = __THREW__; __THREW__ = 0;
            $92 = $91&1;
            if ($92) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3830,($88|0));
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            // unreachable;
           }
           __THREW__ = 0;
           invoke_vi(3799,($_____array|0));
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if (!($96)) {
            __THREW__ = 0;
            $97 = (invoke_ii(1857,($_____array|0))|0);
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if (!($99)) {
             $100 = ($97|0)==(0);
             if ($100) {
              $$0 = -1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             $101 = ($value|0)==(0|0);
             do {
              if (!($101)) {
               __THREW__ = 0;
               (invoke_ii(2996,(2157896|0))|0);
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               if ($103) {
                break L1;
               }
               __THREW__ = 0;
               $104 = (invoke_iii(2735,($value|0),(2157896|0))|0);
               $105 = __THREW__; __THREW__ = 0;
               $106 = $105&1;
               if ($106) {
                break L1;
               }
               $107 = ($104|0)==(0|0);
               if (!($107)) {
                break;
               }
               $108 = HEAP32[3014560>>2]|0;
               __THREW__ = 0;
               $109 = (invoke_iii(783,0,($108|0))|0);
               $110 = __THREW__; __THREW__ = 0;
               $111 = $110&1;
               if ($111) {
                break L1;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2560072|0))|0);
               $112 = __THREW__; __THREW__ = 0;
               $113 = $112&1;
               if ($113) {
                break L1;
               }
               __THREW__ = 0;
               $114 = (invoke_ii(3469,(2560072|0))|0);
               $115 = __THREW__; __THREW__ = 0;
               $116 = $115&1;
               if ($116) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vii(1924,($114|0),($109|0));
               $117 = __THREW__; __THREW__ = 0;
               $118 = $117&1;
               if ($118) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vi(3830,($114|0));
               $119 = __THREW__; __THREW__ = 0;
               $120 = $119&1;
               if ($120) {
                break L1;
               }
               // unreachable;
              }
             } while(0);
             __THREW__ = 0;
             $121 = (invoke_iiiiiii(56,0,($_____array|0),($index|0),($length|0),($value|0),(0|0))|0);
             $122 = __THREW__; __THREW__ = 0;
             $123 = $122&1;
             if (!($123)) {
              $$0 = $121;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z185mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayiiS0_S0_($__this,$_____array,$index,$length,$value,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 $value = $value|0;
 $comparer = $comparer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223880);
 __THREW__ = 0;
 invoke_v(483);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3014848>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1859,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)<(2);
     if (!($20)) {
      $21 = HEAP32[3014856>>2]|0;
      __THREW__ = 0;
      $22 = (invoke_iii(783,0,($21|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636920|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_ii(3469,(2636920|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1972,($27|0),($22|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($27|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      __THREW__ = 0;
      $36 = (invoke_iii(755,($_____array|0),0)|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = ($36|0)>($index|0);
       if ($39) {
        $40 = HEAP32[3014872>>2]|0;
        __THREW__ = 0;
        $41 = (invoke_iii(783,0,($40|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
        __THREW__ = 0;
        $46 = (invoke_ii(3469,(2561352|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        $49 = HEAP32[3014864>>2]|0;
        __THREW__ = 0;
        invoke_viii(644,($46|0),($49|0),($41|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3830,($46|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        // unreachable;
       }
       $54 = ($length|0)>(-1);
       if (!($54)) {
        $55 = HEAP32[3014888>>2]|0;
        __THREW__ = 0;
        $56 = (invoke_iii(783,0,($55|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_ii(3469,(2561352|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[3014880>>2]|0;
        __THREW__ = 0;
        invoke_viii(644,($61|0),($64|0),($56|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3830,($61|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        // unreachable;
       }
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if (!($70)) {
        __THREW__ = 0;
        $71 = (invoke_iii(755,($_____array|0),0)|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if (!($73)) {
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if (!($75)) {
          __THREW__ = 0;
          $76 = (invoke_iii(753,($_____array|0),0)|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if (!($78)) {
           $79 = (($71) - ($length))|0;
           $80 = (($79) + ($76))|0;
           $81 = ($80|0)<($index|0);
           if ($81) {
            $82 = HEAP32[3014896>>2]|0;
            __THREW__ = 0;
            $83 = (invoke_iii(783,0,($82|0))|0);
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if ($85) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2560072|0))|0);
            $86 = __THREW__; __THREW__ = 0;
            $87 = $86&1;
            if ($87) {
             break;
            }
            __THREW__ = 0;
            $88 = (invoke_ii(3469,(2560072|0))|0);
            $89 = __THREW__; __THREW__ = 0;
            $90 = $89&1;
            if ($90) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1924,($88|0),($83|0));
            $91 = __THREW__; __THREW__ = 0;
            $92 = $91&1;
            if ($92) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3830,($88|0));
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            // unreachable;
           }
           __THREW__ = 0;
           invoke_vi(3799,($_____array|0));
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if (!($96)) {
            __THREW__ = 0;
            $97 = (invoke_ii(1857,($_____array|0))|0);
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if (!($99)) {
             $100 = ($97|0)==(0);
             if ($100) {
              $$0 = -1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             $101 = ($comparer|0)!=(0|0);
             $102 = ($value|0)==(0|0);
             $or$cond = $101 | $102;
             do {
              if (!($or$cond)) {
               __THREW__ = 0;
               (invoke_ii(2996,(2157896|0))|0);
               $103 = __THREW__; __THREW__ = 0;
               $104 = $103&1;
               if ($104) {
                break L1;
               }
               __THREW__ = 0;
               $105 = (invoke_iii(2735,($value|0),(2157896|0))|0);
               $106 = __THREW__; __THREW__ = 0;
               $107 = $106&1;
               if ($107) {
                break L1;
               }
               $108 = ($105|0)==(0|0);
               if (!($108)) {
                break;
               }
               $109 = HEAP32[3014904>>2]|0;
               __THREW__ = 0;
               $110 = (invoke_iii(783,0,($109|0))|0);
               $111 = __THREW__; __THREW__ = 0;
               $112 = $111&1;
               if ($112) {
                break L1;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2560072|0))|0);
               $113 = __THREW__; __THREW__ = 0;
               $114 = $113&1;
               if ($114) {
                break L1;
               }
               __THREW__ = 0;
               $115 = (invoke_ii(3469,(2560072|0))|0);
               $116 = __THREW__; __THREW__ = 0;
               $117 = $116&1;
               if ($117) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vii(1924,($115|0),($110|0));
               $118 = __THREW__; __THREW__ = 0;
               $119 = $118&1;
               if ($119) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vi(3830,($115|0));
               $120 = __THREW__; __THREW__ = 0;
               $121 = $120&1;
               if ($121) {
                break L1;
               }
               // unreachable;
              }
             } while(0);
             __THREW__ = 0;
             $122 = (invoke_iiiiiii(56,0,($_____array|0),($index|0),($length|0),($value|0),($comparer|0))|0);
             $123 = __THREW__; __THREW__ = 0;
             $124 = $123&1;
             if (!($124)) {
              $$0 = $122;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z37mscorlib_System_Array_m_ClearInternalP22mscorlib_System_ObjectP21mscorlib_System_Arrayii($__this,$a,$index,$count) {
 $__this = $__this|0;
 $a = $a|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224024);
 $0 = HEAP32[2224072>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2224080|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2224072>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($a|0),($index|0),($count|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z29mscorlib_System_Array_m_CloneP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224152);
 $0 = HEAP32[2224200>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2224208|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2224200>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_i($__this,$sourceArray,$destinationArray,$length) {
 $__this = $__this|0;
 $sourceArray = $sourceArray|0;
 $destinationArray = $destinationArray|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224232);
 __THREW__ = 0;
 invoke_v(484);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($sourceArray|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3015144>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($destinationArray|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3015152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($sourceArray|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_iii(755,($sourceArray|0),0)|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __THREW__ = 0;
     invoke_vi(3799,($destinationArray|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      $33 = (invoke_iii(755,($destinationArray|0),0)|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       invoke_viiiiii(55,0,($sourceArray|0),($28|0),($destinationArray|0),($33|0),($length|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z159mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii($__this,$sourceArray,$sourceIndex,$destinationArray,$destinationIndex,$length) {
 $__this = $__this|0;
 $sourceArray = $sourceArray|0;
 $sourceIndex = $sourceIndex|0;
 $destinationArray = $destinationArray|0;
 $destinationIndex = $destinationIndex|0;
 $length = $length|0;
 var $$0 = 0, $$02 = 0, $$byval_copy8 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_5$031 = 0, $V_7$0 = 0, $V_7$0$in = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224280);
 __THREW__ = 0;
 invoke_v(485);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if ($3) {
   label = 5;
  } else {
   $4 = ($sourceArray|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2560584|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     label = 5;
     break;
    }
    $16 = HEAP32[3015224>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($13|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($13|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 5;
     break;
    }
    // unreachable;
   }
   $21 = ($destinationArray|0)==(0|0);
   if ($21) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2560584|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     label = 5;
     break;
    }
    $27 = HEAP32[3015232>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($24|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($24|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     label = 5;
     break;
    }
    // unreachable;
   }
   $32 = ($length|0)>(-1);
   if (!($32)) {
    $33 = HEAP32[3015248>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_iii(783,0,($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3469,(2561352|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 5;
     break;
    }
    $42 = HEAP32[3015240>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($39|0),($42|0),($34|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($39|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     label = 5;
     break;
    }
    // unreachable;
   }
   $47 = ($sourceIndex|0)>(-1);
   if (!($47)) {
    $48 = HEAP32[3015264>>2]|0;
    __THREW__ = 0;
    $49 = (invoke_iii(783,0,($48|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    $54 = (invoke_ii(3469,(2561352|0))|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 5;
     break;
    }
    $57 = HEAP32[3015256>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($54|0),($57|0),($49|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($54|0));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     label = 5;
     break;
    }
    // unreachable;
   }
   $62 = ($destinationIndex|0)>(-1);
   if (!($62)) {
    $63 = HEAP32[3015280>>2]|0;
    __THREW__ = 0;
    $64 = (invoke_iii(783,0,($63|0))|0);
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    $69 = (invoke_ii(3469,(2561352|0))|0);
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     label = 5;
     break;
    }
    $72 = HEAP32[3015272>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($69|0),($72|0),($64|0));
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if ($74) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($69|0));
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     label = 5;
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $77 = (invoke_iiiiiii(54,0,($sourceArray|0),($sourceIndex|0),($destinationArray|0),($destinationIndex|0),($length|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 5;
   } else {
    if ($77) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3799,($sourceArray|0));
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 5;
    } else {
     __THREW__ = 0;
     $82 = (invoke_iii(755,($sourceArray|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      label = 5;
     } else {
      $85 = (($sourceIndex) - ($82))|0;
      __THREW__ = 0;
      invoke_vi(3799,($destinationArray|0));
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       label = 5;
      } else {
       __THREW__ = 0;
       $88 = (invoke_iii(755,($destinationArray|0),0)|0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        label = 5;
       } else {
        $91 = (($destinationIndex) - ($88))|0;
        __THREW__ = 0;
        invoke_vi(3799,($sourceArray|0));
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         label = 5;
        } else {
         __THREW__ = 0;
         $94 = (invoke_ii(1857,($sourceArray|0))|0);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          label = 5;
         } else {
          $97 = (($94) - ($length))|0;
          $98 = ($85|0)>($97|0);
          if ($98) {
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           $101 = (invoke_ii(3469,(2560072|0))|0);
           $102 = __THREW__; __THREW__ = 0;
           $103 = $102&1;
           if ($103) {
            label = 5;
            break;
           }
           $104 = HEAP32[3015288>>2]|0;
           __THREW__ = 0;
           invoke_vii(1924,($101|0),($104|0));
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3830,($101|0));
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if ($108) {
            label = 5;
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_vi(3799,($destinationArray|0));
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           label = 5;
          } else {
           __THREW__ = 0;
           $111 = (invoke_ii(1857,($destinationArray|0))|0);
           $112 = __THREW__; __THREW__ = 0;
           $113 = $112&1;
           if ($113) {
            label = 5;
           } else {
            $114 = (($111) - ($length))|0;
            $115 = ($91|0)>($114|0);
            if ($115) {
             $116 = HEAP32[3015296>>2]|0;
             __THREW__ = 0;
             (invoke_ii(2996,(2191608|0))|0);
             $117 = __THREW__; __THREW__ = 0;
             $118 = $117&1;
             if ($118) {
              label = 5;
              break;
             }
             $119 = HEAP8[((2191608 + 116|0))>>0]|0;
             $120 = ($119<<24>>24)==(0);
             if ($120) {
              __THREW__ = 0;
              (invoke_ii(2996,(2191608|0))|0);
              $121 = __THREW__; __THREW__ = 0;
              $122 = $121&1;
              if ($122) {
               label = 5;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2191608|0))|0);
              $123 = __THREW__; __THREW__ = 0;
              $124 = $123&1;
              if ($124) {
               label = 5;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3831,(2191608|0));
              $125 = __THREW__; __THREW__ = 0;
              $126 = $125&1;
              if ($126) {
               label = 5;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2191608|0))|0);
             $127 = __THREW__; __THREW__ = 0;
             $128 = $127&1;
             if ($128) {
              label = 5;
              break;
             }
             $129 = HEAP32[((2191608 + 80|0))>>2]|0;
             $130 = HEAP32[$129>>2]|0;
             __THREW__ = 0;
             (invoke_ii(2996,(2560072|0))|0);
             $131 = __THREW__; __THREW__ = 0;
             $132 = $131&1;
             if ($132) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             $133 = (invoke_ii(3469,(2560072|0))|0);
             $134 = __THREW__; __THREW__ = 0;
             $135 = $134&1;
             if ($135) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_viii(641,($133|0),($116|0),($130|0));
             $136 = __THREW__; __THREW__ = 0;
             $137 = $136&1;
             if ($137) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3830,($133|0));
             $138 = __THREW__; __THREW__ = 0;
             $139 = $138&1;
             if ($139) {
              label = 5;
              break;
             }
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($sourceArray|0));
            $140 = __THREW__; __THREW__ = 0;
            $141 = $140&1;
            if ($141) {
             label = 5;
            } else {
             __THREW__ = 0;
             $142 = (invoke_ii(1859,($sourceArray|0))|0);
             $143 = __THREW__; __THREW__ = 0;
             $144 = $143&1;
             if ($144) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($destinationArray|0));
             $145 = __THREW__; __THREW__ = 0;
             $146 = $145&1;
             if ($146) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             $147 = (invoke_ii(1859,($destinationArray|0))|0);
             $148 = __THREW__; __THREW__ = 0;
             $149 = $148&1;
             if ($149) {
              label = 5;
              break;
             }
             $150 = ($142|0)==($147|0);
             if (!($150)) {
              $151 = HEAP32[3015304>>2]|0;
              __THREW__ = 0;
              $152 = (invoke_iii(783,0,($151|0))|0);
              $153 = __THREW__; __THREW__ = 0;
              $154 = $153&1;
              if ($154) {
               label = 5;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2636920|0))|0);
              $155 = __THREW__; __THREW__ = 0;
              $156 = $155&1;
              if ($156) {
               label = 5;
               break;
              }
              __THREW__ = 0;
              $157 = (invoke_ii(3469,(2636920|0))|0);
              $158 = __THREW__; __THREW__ = 0;
              $159 = $158&1;
              if ($159) {
               label = 5;
               break;
              }
              __THREW__ = 0;
              invoke_vii(1972,($157|0),($152|0));
              $160 = __THREW__; __THREW__ = 0;
              $161 = $160&1;
              if ($161) {
               label = 5;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3830,($157|0));
              $162 = __THREW__; __THREW__ = 0;
              $163 = $162&1;
              if ($163) {
               label = 5;
               break;
              }
              // unreachable;
             }
             __THREW__ = 0;
             invoke_vi(3799,($sourceArray|0));
             $164 = __THREW__; __THREW__ = 0;
             $165 = $164&1;
             if ($165) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             $166 = (invoke_ii(1782,($sourceArray|0))|0);
             $167 = __THREW__; __THREW__ = 0;
             $168 = $167&1;
             if ($168) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($166|0));
             $169 = __THREW__; __THREW__ = 0;
             $170 = $169&1;
             if ($170) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             $171 = (invoke_iii(2730,(2224328|0),($166|0))|0);
             $172 = __THREW__; __THREW__ = 0;
             $173 = $172&1;
             if ($173) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($destinationArray|0));
             $174 = __THREW__; __THREW__ = 0;
             $175 = $174&1;
             if ($175) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             $176 = (invoke_ii(1782,($destinationArray|0))|0);
             $177 = __THREW__; __THREW__ = 0;
             $178 = $177&1;
             if ($178) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($176|0));
             $179 = __THREW__; __THREW__ = 0;
             $180 = $179&1;
             if ($180) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             $181 = (invoke_iii(2730,(2224328|0),($176|0))|0);
             $182 = __THREW__; __THREW__ = 0;
             $183 = $182&1;
             if ($183) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             $184 = (invoke_iiii(424,0,($sourceArray|0),($destinationArray|0))|0);
             $185 = __THREW__; __THREW__ = 0;
             $186 = $185&1;
             if ($186) {
              label = 5;
              break;
             }
             $$not = $184 ^ 1;
             $187 = ($85|0)>($91|0);
             $or$cond = $187 | $$not;
             if (!($or$cond)) {
              $V_7$0$in = $length;
              while(1) {
               $V_7$0 = (($V_7$0$in) + -1)|0;
               $337 = ($V_7$0$in|0)>(0);
               if (!($337)) {
                label = 151;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($sourceArray|0));
               $338 = __THREW__; __THREW__ = 0;
               $339 = $338&1;
               if ($339) {
                label = 4;
                break;
               }
               $265 = (($V_7$0) + ($85))|0;
               __THREW__ = 0;
               $266 = (invoke_iii(757,($sourceArray|0),($265|0))|0);
               $267 = __THREW__; __THREW__ = 0;
               $268 = $267&1;
               if ($268) {
                label = 4;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($destinationArray|0));
               $269 = __THREW__; __THREW__ = 0;
               $270 = $269&1;
               if ($270) {
                label = 123;
                break;
               }
               $271 = (($V_7$0) + ($91))|0;
               __THREW__ = 0;
               invoke_viii(533,($destinationArray|0),($266|0),($271|0));
               $272 = __THREW__; __THREW__ = 0;
               $273 = $272&1;
               if ($273) {
                label = 123;
                break;
               } else {
                $V_7$0$in = $V_7$0;
               }
              }
              if ((label|0) == 4) {
               $7 = ___cxa_find_matching_catch()|0;
               $8 = tempRet0;
               $lpad$phi$index = $7;$lpad$phi$index3 = $8;
               break;
              }
              else if ((label|0) == 123) {
               $274 = ___cxa_find_matching_catch(348288|0)|0;
               $275 = tempRet0;
               $276 = (_llvm_eh_typeid_for((348288|0))|0);
               $277 = ($275|0)==($276|0);
               if (!($277)) {
                $$0 = $274;$$02 = $275;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($$0|0);
                // unreachable;
               }
               $278 = (___cxa_begin_catch(($274|0))|0);
               $279 = HEAP32[$278>>2]|0;
               $280 = HEAP32[$279>>2]|0;
               __THREW__ = 0;
               $281 = (invoke_iii(2727,(2149728|0),($280|0))|0);
               $282 = __THREW__; __THREW__ = 0;
               $283 = $282&1;
               do {
                if (!($283)) {
                 if (!($281)) {
                  $290 = (___cxa_allocate_exception(4)|0);
                  $291 = HEAP32[$278>>2]|0;
                  HEAP32[$290>>2] = $291;
                  __THREW__ = 0;
                  invoke_viii(1567,($290|0),(348288|0),(0|0));
                  $292 = __THREW__; __THREW__ = 0;
                  $293 = $292&1;
                  if ($293) {
                   break;
                  }
                  // unreachable;
                 }
                 __THREW__ = 0;
                 invoke_v(66);
                 $284 = __THREW__; __THREW__ = 0;
                 $285 = $284&1;
                 if ($285) {
                  label = 5;
                  break L1;
                 }
                 HEAP32[$1>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
                 $294 = (invoke_iii(772,0,($$byval_copy8|0))|0);
                 $295 = __THREW__; __THREW__ = 0;
                 $296 = $295&1;
                 if ($296) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($171|0));
                 $297 = __THREW__; __THREW__ = 0;
                 $298 = $297&1;
                 if ($298) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 $299 = (invoke_iiii(1640,(2223400|0),($171|0),($294|0))|0);
                 $300 = __THREW__; __THREW__ = 0;
                 $301 = $300&1;
                 if ($301) {
                  label = 5;
                  break L1;
                 }
                 if ($299) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2607384|0))|0);
                  $302 = __THREW__; __THREW__ = 0;
                  $303 = $302&1;
                  if ($303) {
                   label = 5;
                   break L1;
                  }
                  __THREW__ = 0;
                  $304 = (invoke_ii(3469,(2607384|0))|0);
                  $305 = __THREW__; __THREW__ = 0;
                  $306 = $305&1;
                  if ($306) {
                   label = 5;
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(2732,($304|0));
                  $307 = __THREW__; __THREW__ = 0;
                  $308 = $307&1;
                  if ($308) {
                   label = 5;
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3830,($304|0));
                  $309 = __THREW__; __THREW__ = 0;
                  $310 = $309&1;
                  if ($310) {
                   label = 5;
                   break L1;
                  }
                  // unreachable;
                 }
                 $311 = HEAP32[3015320>>2]|0;
                 __THREW__ = 0;
                 $312 = (invoke_iii(783,0,($311|0))|0);
                 $313 = __THREW__; __THREW__ = 0;
                 $314 = $313&1;
                 if ($314) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($171|0));
                 $315 = __THREW__; __THREW__ = 0;
                 $316 = $315&1;
                 if ($316) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 $317 = (invoke_iii(2730,(2150320|0),($171|0))|0);
                 $318 = __THREW__; __THREW__ = 0;
                 $319 = $318&1;
                 if ($319) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($181|0));
                 $320 = __THREW__; __THREW__ = 0;
                 $321 = $320&1;
                 if ($321) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 $322 = (invoke_iii(2730,(2150320|0),($181|0))|0);
                 $323 = __THREW__; __THREW__ = 0;
                 $324 = $323&1;
                 if ($324) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 $325 = (invoke_iiiii(98,0,($312|0),($317|0),($322|0))|0);
                 $326 = __THREW__; __THREW__ = 0;
                 $327 = $326&1;
                 if ($327) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2562152|0))|0);
                 $328 = __THREW__; __THREW__ = 0;
                 $329 = $328&1;
                 if ($329) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 $330 = (invoke_ii(3469,(2562152|0))|0);
                 $331 = __THREW__; __THREW__ = 0;
                 $332 = $331&1;
                 if ($332) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(1928,($330|0),($325|0));
                 $333 = __THREW__; __THREW__ = 0;
                 $334 = $333&1;
                 if ($334) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3830,($330|0));
                 $335 = __THREW__; __THREW__ = 0;
                 $336 = $335&1;
                 if ($336) {
                  label = 5;
                  break L1;
                 }
                 // unreachable;
                }
               } while(0);
               $286 = ___cxa_find_matching_catch()|0;
               $287 = tempRet0;
               __THREW__ = 0;
               invoke_v(66);
               $288 = __THREW__; __THREW__ = 0;
               $289 = $288&1;
               if ($289) {
                $340 = ___cxa_find_matching_catch(0|0)|0;
                $341 = tempRet0;
                ___clang_call_terminate($340);
                // unreachable;
               } else {
                $$0 = $286;$$02 = $287;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($$0|0);
                // unreachable;
               }
              }
              else if ((label|0) == 151) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
             }
             $188 = ($length|0)>(0);
             if ($188) {
              $V_5$031 = 0;
             } else {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($sourceArray|0));
              $263 = __THREW__; __THREW__ = 0;
              $264 = $263&1;
              if ($264) {
               label = 3;
               break;
              }
              $189 = (($V_5$031) + ($85))|0;
              __THREW__ = 0;
              $190 = (invoke_iii(757,($sourceArray|0),($189|0))|0);
              $191 = __THREW__; __THREW__ = 0;
              $192 = $191&1;
              if ($192) {
               label = 3;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($destinationArray|0));
              $193 = __THREW__; __THREW__ = 0;
              $194 = $193&1;
              if ($194) {
               label = 92;
               break;
              }
              $195 = (($V_5$031) + ($91))|0;
              __THREW__ = 0;
              invoke_viii(533,($destinationArray|0),($190|0),($195|0));
              $196 = __THREW__; __THREW__ = 0;
              $197 = $196&1;
              if ($197) {
               label = 92;
               break;
              }
              $261 = (($V_5$031) + 1)|0;
              $262 = ($261|0)<($length|0);
              if ($262) {
               $V_5$031 = $261;
              } else {
               label = 151;
               break;
              }
             }
             if ((label|0) == 3) {
              $5 = ___cxa_find_matching_catch()|0;
              $6 = tempRet0;
              $lpad$phi$index = $5;$lpad$phi$index3 = $6;
              break;
             }
             else if ((label|0) == 92) {
              $198 = ___cxa_find_matching_catch(348288|0)|0;
              $199 = tempRet0;
              $200 = (_llvm_eh_typeid_for((348288|0))|0);
              $201 = ($199|0)==($200|0);
              if (!($201)) {
               $$0 = $198;$$02 = $199;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($$0|0);
               // unreachable;
              }
              $202 = (___cxa_begin_catch(($198|0))|0);
              $203 = HEAP32[$202>>2]|0;
              $204 = HEAP32[$203>>2]|0;
              __THREW__ = 0;
              $205 = (invoke_iii(2727,(2149728|0),($204|0))|0);
              $206 = __THREW__; __THREW__ = 0;
              $207 = $206&1;
              do {
               if (!($207)) {
                if (!($205)) {
                 $214 = (___cxa_allocate_exception(4)|0);
                 $215 = HEAP32[$202>>2]|0;
                 HEAP32[$214>>2] = $215;
                 __THREW__ = 0;
                 invoke_viii(1567,($214|0),(348288|0),(0|0));
                 $216 = __THREW__; __THREW__ = 0;
                 $217 = $216&1;
                 if ($217) {
                  break;
                 }
                 // unreachable;
                }
                __THREW__ = 0;
                invoke_v(66);
                $208 = __THREW__; __THREW__ = 0;
                $209 = $208&1;
                if ($209) {
                 label = 5;
                 break L1;
                }
                HEAP32[$0>>2] = 1284448;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
                $218 = (invoke_iii(772,0,($$byval_copy8|0))|0);
                $219 = __THREW__; __THREW__ = 0;
                $220 = $219&1;
                if ($220) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3799,($171|0));
                $221 = __THREW__; __THREW__ = 0;
                $222 = $221&1;
                if ($222) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                $223 = (invoke_iiii(1640,(2223400|0),($171|0),($218|0))|0);
                $224 = __THREW__; __THREW__ = 0;
                $225 = $224&1;
                if ($225) {
                 label = 5;
                 break L1;
                }
                if ($223) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2607384|0))|0);
                 $226 = __THREW__; __THREW__ = 0;
                 $227 = $226&1;
                 if ($227) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 $228 = (invoke_ii(3469,(2607384|0))|0);
                 $229 = __THREW__; __THREW__ = 0;
                 $230 = $229&1;
                 if ($230) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(2732,($228|0));
                 $231 = __THREW__; __THREW__ = 0;
                 $232 = $231&1;
                 if ($232) {
                  label = 5;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3830,($228|0));
                 $233 = __THREW__; __THREW__ = 0;
                 $234 = $233&1;
                 if ($234) {
                  label = 5;
                  break L1;
                 }
                 // unreachable;
                }
                $235 = HEAP32[3015312>>2]|0;
                __THREW__ = 0;
                $236 = (invoke_iii(783,0,($235|0))|0);
                $237 = __THREW__; __THREW__ = 0;
                $238 = $237&1;
                if ($238) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3799,($171|0));
                $239 = __THREW__; __THREW__ = 0;
                $240 = $239&1;
                if ($240) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                $241 = (invoke_iii(2730,(2150320|0),($171|0))|0);
                $242 = __THREW__; __THREW__ = 0;
                $243 = $242&1;
                if ($243) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3799,($181|0));
                $244 = __THREW__; __THREW__ = 0;
                $245 = $244&1;
                if ($245) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                $246 = (invoke_iii(2730,(2150320|0),($181|0))|0);
                $247 = __THREW__; __THREW__ = 0;
                $248 = $247&1;
                if ($248) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                $249 = (invoke_iiiii(98,0,($236|0),($241|0),($246|0))|0);
                $250 = __THREW__; __THREW__ = 0;
                $251 = $250&1;
                if ($251) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2562152|0))|0);
                $252 = __THREW__; __THREW__ = 0;
                $253 = $252&1;
                if ($253) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                $254 = (invoke_ii(3469,(2562152|0))|0);
                $255 = __THREW__; __THREW__ = 0;
                $256 = $255&1;
                if ($256) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                invoke_vii(1928,($254|0),($249|0));
                $257 = __THREW__; __THREW__ = 0;
                $258 = $257&1;
                if ($258) {
                 label = 5;
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3830,($254|0));
                $259 = __THREW__; __THREW__ = 0;
                $260 = $259&1;
                if ($260) {
                 label = 5;
                 break L1;
                }
                // unreachable;
               }
              } while(0);
              $210 = ___cxa_find_matching_catch()|0;
              $211 = tempRet0;
              __THREW__ = 0;
              invoke_v(66);
              $212 = __THREW__; __THREW__ = 0;
              $213 = $212&1;
              if ($213) {
               $340 = ___cxa_find_matching_catch(0|0)|0;
               $341 = tempRet0;
               ___clang_call_terminate($340);
               // unreachable;
              } else {
               $$0 = $210;$$02 = $211;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($$0|0);
               // unreachable;
              }
             }
             else if ((label|0) == 151) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $lpad$phi$index = $9;$lpad$phi$index3 = $10;
 }
 $$0 = $lpad$phi$index;$$02 = $lpad$phi$index3;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z159mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int64_mscorlib_System_Array_mscorlib_System_Int64_mscorlib_System_Int64P22mscorlib_System_ObjectP21mscorlib_System_ArrayxS2_xx($__this,$sourceArray,$0,$1,$destinationArray,$2,$3,$4,$5) {
 $__this = $__this|0;
 $sourceArray = $sourceArray|0;
 $0 = $0|0;
 $1 = $1|0;
 $destinationArray = $destinationArray|0;
 $2 = $2|0;
 $3 = $3|0;
 $4 = $4|0;
 $5 = $5|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224376);
 __THREW__ = 0;
 invoke_v(486);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if (!($7)) {
   $8 = ($sourceArray|0)==(0|0);
   if ($8) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2560584|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[3015648>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($13|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($13|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    // unreachable;
   }
   $21 = ($destinationArray|0)==(0|0);
   if ($21) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2560584|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = HEAP32[3015656>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($24|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($24|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    // unreachable;
   }
   $32 = (_i64Add(($0|0),($1|0),-2147483648,0)|0);
   $33 = tempRet0;
   $34 = ($33>>>0)<(1);
   $35 = ($33|0)==(1);
   $36 = ($32>>>0)<(0);
   $37 = $35 & $36;
   $38 = $34 | $37;
   if (!($38)) {
    $39 = HEAP32[3015672>>2]|0;
    __THREW__ = 0;
    $40 = (invoke_iii(783,0,($39|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    $45 = (invoke_ii(3469,(2561352|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    $48 = HEAP32[3015664>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($45|0),($48|0),($40|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($45|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    // unreachable;
   }
   $53 = (_i64Add(($2|0),($3|0),-2147483648,0)|0);
   $54 = tempRet0;
   $55 = ($54>>>0)<(1);
   $56 = ($54|0)==(1);
   $57 = ($53>>>0)<(0);
   $58 = $56 & $57;
   $59 = $55 | $58;
   if (!($59)) {
    $60 = HEAP32[3015688>>2]|0;
    __THREW__ = 0;
    $61 = (invoke_iii(783,0,($60|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     break;
    }
    __THREW__ = 0;
    $66 = (invoke_ii(3469,(2561352|0))|0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     break;
    }
    $69 = HEAP32[3015680>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($66|0),($69|0),($61|0));
    $70 = __THREW__; __THREW__ = 0;
    $71 = $70&1;
    if ($71) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($66|0));
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     break;
    }
    // unreachable;
   }
   $74 = ($5>>>0)<(0);
   $75 = ($5|0)==(0);
   $76 = ($4>>>0)<(2147483648);
   $77 = $75 & $76;
   $78 = $74 | $77;
   if ($78) {
    __THREW__ = 0;
    invoke_viiiiii(55,0,($sourceArray|0),($0|0),($destinationArray|0),($2|0),($4|0));
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if ($94) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $79 = HEAP32[3015704>>2]|0;
   __THREW__ = 0;
   $80 = (invoke_iii(783,0,($79|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if (!($82)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $83 = __THREW__; __THREW__ = 0;
    $84 = $83&1;
    if (!($84)) {
     __THREW__ = 0;
     $85 = (invoke_ii(3469,(2561352|0))|0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if (!($87)) {
      $88 = HEAP32[3015696>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($85|0),($88|0),($80|0));
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      if (!($90)) {
       __THREW__ = 0;
       invoke_vi(3830,($85|0));
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if (!($92)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z115mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int64P22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_x($__this,$sourceArray,$destinationArray,$0,$1) {
 $__this = $__this|0;
 $sourceArray = $sourceArray|0;
 $destinationArray = $destinationArray|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224424);
 __THREW__ = 0;
 invoke_v(487);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($1>>>0)<(0);
   $5 = ($1|0)==(0);
   $6 = ($0>>>0)<(2147483648);
   $7 = $5 & $6;
   $8 = $4 | $7;
   if ($8) {
    __THREW__ = 0;
    invoke_viiii(140,0,($sourceArray|0),($destinationArray|0),($0|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $11 = HEAP32[3015784>>2]|0;
   __THREW__ = 0;
   $12 = (invoke_iii(783,0,($11|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2561352|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[3015776>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($17|0),($20|0),($12|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3830,($17|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_($__this,$_____array,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224472);
 __THREW__ = 0;
 invoke_v(488);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(1857,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_iiiiii(97,0,($_____array|0),($value|0),0,($17|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3015800>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z142mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_ii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $V_1$08 = 0;
 var $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224568);
 __THREW__ = 0;
 invoke_v(489);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3015832>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(1859,($_____array|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = ($19|0)<(2);
     if (!($22)) {
      $23 = HEAP32[3015840>>2]|0;
      __THREW__ = 0;
      $24 = (invoke_iii(783,0,($23|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636920|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_ii(3469,(2636920|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1972,($29|0),($24|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($29|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      // unreachable;
     }
     $36 = ($count|0)<(0);
     if (!($36)) {
      __THREW__ = 0;
      invoke_vi(3799,($_____array|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      __THREW__ = 0;
      $39 = (invoke_iii(755,($_____array|0),0)|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      $42 = ($39|0)>($startIndex|0);
      if (!($42)) {
       $43 = (($startIndex) + -1)|0;
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
       __THREW__ = 0;
       $46 = (invoke_iii(758,($_____array|0),0)|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
       $49 = (($46) - ($count))|0;
       $50 = ($43|0)>($49|0);
       if (!($50)) {
        $60 = (($count) + ($startIndex))|0;
        $61 = ($count|0)>(0);
        L28: do {
         if ($61) {
          $V_1$08 = $startIndex;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($_____array|0));
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            break;
           }
           __THREW__ = 0;
           $62 = (invoke_iii(757,($_____array|0),($V_1$08|0))|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            break;
           }
           __THREW__ = 0;
           $65 = (invoke_iiii(423,0,($62|0),($value|0))|0);
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            break;
           }
           $68 = (($V_1$08) + 1)|0;
           if ($65) {
            $$0 = $V_1$08;
            label = 41;
            break;
           }
           $69 = ($68|0)<($60|0);
           if ($69) {
            $V_1$08 = $68;
           } else {
            break L28;
           }
          }
          if ((label|0) == 41) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index2 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3799,($_____array|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         break;
        }
        __THREW__ = 0;
        $74 = (invoke_iii(755,($_____array|0),0)|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         break;
        }
        $77 = (($74) + -1)|0;
        $$0 = $77;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if (!($52)) {
      __THREW__ = 0;
      $53 = (invoke_ii(3469,(2561352|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if (!($55)) {
       __THREW__ = 0;
       invoke_vi(2587,($53|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if (!($57)) {
        __THREW__ = 0;
        invoke_vi(3830,($53|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if (!($59)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_i($__this,$_____array,$value,$startIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224520);
 __THREW__ = 0;
 invoke_v(490);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(1857,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = (($17) - ($startIndex))|0;
    __THREW__ = 0;
    $21 = (invoke_iiiiii(97,0,($_____array|0),($value|0),($startIndex|0),($20|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3015816>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Array_m_InitializeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224616);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z102mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_($__this,$_____array,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224664);
 __THREW__ = 0;
 invoke_v(491);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3015856>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1857,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(0);
     if ($20) {
      __THREW__ = 0;
      invoke_vi(3799,($_____array|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_iii(755,($_____array|0),0)|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = (($23) + -1)|0;
      $$0 = $26;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($_____array|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_ii(1857,($_____array|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = (($29) + -1)|0;
      __THREW__ = 0;
      $33 = (invoke_iiiii(116,0,($_____array|0),($value|0),($32|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      } else {
       $$0 = $33;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z124mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_i($__this,$_____array,$value,$startIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224712);
 __THREW__ = 0;
 invoke_v(492);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_iii(755,($_____array|0),0)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = (($startIndex) + 1)|0;
    $21 = (($20) - ($17))|0;
    __THREW__ = 0;
    $22 = (invoke_iiiiii(98,0,($_____array|0),($value|0),($startIndex|0),($21|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($22|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3015872>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z146mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_ii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $V_1$08 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224760);
 __THREW__ = 0;
 invoke_v(493);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3015888>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(1859,($_____array|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = ($19|0)<(2);
     if (!($22)) {
      $23 = HEAP32[3015896>>2]|0;
      __THREW__ = 0;
      $24 = (invoke_iii(783,0,($23|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636920|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_ii(3469,(2636920|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1972,($29|0),($24|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($29|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_ii(1857,($_____array|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = ($43|0)==(0);
         if ($46) {
          $47 = (($38) + -1)|0;
          $$0 = $47;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $48 = ($count|0)<(0);
         $49 = ($38|0)>($startIndex|0);
         $or$cond = $48 | $49;
         if (!($or$cond)) {
          __THREW__ = 0;
          invoke_vi(3799,($_____array|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           break;
          }
          __THREW__ = 0;
          $52 = (invoke_iii(758,($_____array|0),0)|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break;
          }
          $55 = ($52|0)<($startIndex|0);
          if (!($55)) {
           $56 = (($startIndex) - ($count))|0;
           $57 = (($56) + 1)|0;
           $58 = ($57|0)<($38|0);
           if (!($58)) {
            $59 = ($count|0)<(1);
            L34: do {
             if (!($59)) {
              $V_1$08 = $startIndex;
              while(1) {
               __THREW__ = 0;
               invoke_vi(3799,($_____array|0));
               $77 = __THREW__; __THREW__ = 0;
               $78 = $77&1;
               if ($78) {
                break;
               }
               __THREW__ = 0;
               $69 = (invoke_iii(757,($_____array|0),($V_1$08|0))|0);
               $70 = __THREW__; __THREW__ = 0;
               $71 = $70&1;
               if ($71) {
                break;
               }
               __THREW__ = 0;
               $72 = (invoke_iiii(423,0,($69|0),($value|0))|0);
               $73 = __THREW__; __THREW__ = 0;
               $74 = $73&1;
               if ($74) {
                break;
               }
               if ($72) {
                $$0 = $V_1$08;
                label = 43;
                break;
               }
               $75 = (($V_1$08) + -1)|0;
               $76 = ($V_1$08|0)>($57|0);
               if ($76) {
                $V_1$08 = $75;
               } else {
                break L34;
               }
              }
              if ((label|0) == 43) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
              $3 = ___cxa_find_matching_catch()|0;
              $4 = tempRet0;
              $lpad$phi$index = $3;$lpad$phi$index2 = $4;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
            } while(0);
            $79 = (($38) + -1)|0;
            $$0 = $79;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2561352|0))|0);
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if (!($61)) {
          __THREW__ = 0;
          $62 = (invoke_ii(3469,(2561352|0))|0);
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if (!($64)) {
           __THREW__ = 0;
           invoke_vi(2587,($62|0));
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if (!($66)) {
            __THREW__ = 0;
            invoke_vi(3830,($62|0));
            $67 = __THREW__; __THREW__ = 0;
            $68 = $67&1;
            if (!($68)) {
             // unreachable;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_get_swapper_mscorlib_System_Array_Swapper_mscorlib_System_ArrayP22mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $$0 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 20|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224808);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2735,($_____array|0),(1170368|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)==(0|0);
    if (!($9)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2220256|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     $14 = (invoke_ii(3469,(2220256|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     HEAP32[$0>>2] = 2224856;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
     invoke_viii(528,($14|0),($_____array|0),($$byval_copy3|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     } else {
      $$0 = $14;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1218904|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($_____array|0),(1218904|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if (!($24)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2220256|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       $27 = (invoke_ii(3469,(2220256|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
       HEAP32[$1>>2] = 2224904;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_viii(528,($27|0),($_____array|0),($$byval_copy3|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       } else {
        $$0 = $27;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1167664|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       $34 = (invoke_iii(2735,($_____array|0),(1167664|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        $37 = ($34|0)==(0|0);
        if ($37) {
         __THREW__ = 0;
         (invoke_ii(2996,(2220256|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          break;
         }
         __THREW__ = 0;
         $47 = (invoke_ii(3469,(2220256|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          break;
         }
         HEAP32[$3>>2] = 2225000;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
         invoke_viii(528,($47|0),($_____array|0),($$byval_copy3|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          break;
         } else {
          $$0 = $47;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         (invoke_ii(2996,(2220256|0))|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          break;
         }
         __THREW__ = 0;
         $40 = (invoke_ii(3469,(2220256|0))|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break;
         }
         HEAP32[$2>>2] = 2224952;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
         invoke_viii(528,($40|0),($_____array|0),($$byval_copy3|0));
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          break;
         } else {
          $$0 = $40;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Array_m_Reverse_mscorlib_System_Void_mscorlib_System_ArrayP22mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225048);
 __THREW__ = 0;
 invoke_v(494);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3015912>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(755,($_____array|0),0)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_iii(753,($_____array|0),0)|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_viiii(141,0,($_____array|0),($17|0),($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z118mscorlib_System_Array_m_Reverse_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_Arrayii($__this,$_____array,$index,$length) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 var $$036 = 0, $$128 = 0, $$221 = 0, $$314 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0.0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0.0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$035 = 0, $V_0$127 = 0, $V_0$220 = 0, $V_0$313 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225096);
 __THREW__ = 0;
 invoke_v(495);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    $15 = (invoke_ii(3469,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = HEAP32[3015928>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($15|0),($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($15|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    $25 = (invoke_ii(1859,($_____array|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = ($25|0)<(2);
     if (!($28)) {
      $29 = HEAP32[3015936>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iii(783,0,($29|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636920|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_ii(3469,(2636920|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1972,($35|0),($30|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($35|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      $44 = (invoke_iii(755,($_____array|0),0)|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       $47 = ($44|0)<=($index|0);
       $48 = ($length|0)>(-1);
       $or$cond = $47 & $48;
       if (!($or$cond)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        $51 = (invoke_ii(3469,(2561352|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(2587,($51|0));
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3830,($51|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
        // unreachable;
       }
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if (!($59)) {
        __THREW__ = 0;
        $60 = (invoke_iii(758,($_____array|0),0)|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if (!($62)) {
         $63 = (1 - ($length))|0;
         $64 = (($63) + ($60))|0;
         $65 = ($64|0)<($index|0);
         if ($65) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           break;
          }
          __THREW__ = 0;
          $68 = (invoke_ii(3469,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(2583,($68|0));
          $71 = __THREW__; __THREW__ = 0;
          $72 = $71&1;
          if ($72) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3830,($68|0));
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           break;
          }
          // unreachable;
         }
         $75 = (($index) + -1)|0;
         $76 = (($75) + ($length))|0;
         __THREW__ = 0;
         (invoke_ii(2996,(1167664|0))|0);
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if (!($78)) {
          __THREW__ = 0;
          $79 = (invoke_iii(2735,($_____array|0),(1167664|0))|0);
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          if (!($81)) {
           $82 = ($79|0)==(0|0);
           if (!($82)) {
            $83 = ($76|0)>($index|0);
            if (!($83)) {
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
            $84 = (($79) + 16|0);
            $85 = (($79) + 12|0);
            $$036 = $index;$V_0$035 = $76;
            while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($79|0));
             $151 = __THREW__; __THREW__ = 0;
             $152 = $151&1;
             if ($152) {
              break;
             }
             $86 = ($$036|0)<(0);
             if ($86) {
              label = 46;
             } else {
              $87 = HEAP32[$85>>2]|0;
              $88 = ($$036>>>0)<($87>>>0);
              if (!($88)) {
               label = 46;
              }
             }
             if ((label|0) == 46) {
              label = 0;
              __THREW__ = 0;
              $89 = (invoke_i(132)|0);
              $90 = __THREW__; __THREW__ = 0;
              $91 = $90&1;
              if ($91) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($89|0));
              $92 = __THREW__; __THREW__ = 0;
              $93 = $92&1;
              if ($93) {
               break;
              }
             }
             $94 = HEAP32[$79>>2]|0;
             $95 = (($94) + 92|0);
             $96 = HEAP32[$95>>2]|0;
             $97 = Math_imul($96, $$036)|0;
             $98 = (($84) + ($97)|0);
             $99 = HEAP32[$98>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($79|0));
             $100 = __THREW__; __THREW__ = 0;
             $101 = $100&1;
             if ($101) {
              break;
             }
             $102 = ($V_0$035|0)<(0);
             if ($102) {
              label = 51;
             } else {
              $103 = HEAP32[$85>>2]|0;
              $104 = ($V_0$035>>>0)<($103>>>0);
              if (!($104)) {
               label = 51;
              }
             }
             if ((label|0) == 51) {
              label = 0;
              __THREW__ = 0;
              $105 = (invoke_i(132)|0);
              $106 = __THREW__; __THREW__ = 0;
              $107 = $106&1;
              if ($107) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($105|0));
              $108 = __THREW__; __THREW__ = 0;
              $109 = $108&1;
              if ($109) {
               break;
              }
             }
             $110 = HEAP32[$79>>2]|0;
             $111 = (($110) + 92|0);
             $112 = HEAP32[$111>>2]|0;
             $113 = Math_imul($112, $V_0$035)|0;
             $114 = (($84) + ($113)|0);
             $115 = HEAP32[$114>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($79|0));
             $116 = __THREW__; __THREW__ = 0;
             $117 = $116&1;
             if ($117) {
              break;
             }
             if ($86) {
              label = 56;
             } else {
              $118 = HEAP32[$85>>2]|0;
              $119 = ($$036>>>0)<($118>>>0);
              if (!($119)) {
               label = 56;
              }
             }
             if ((label|0) == 56) {
              label = 0;
              __THREW__ = 0;
              $120 = (invoke_i(132)|0);
              $121 = __THREW__; __THREW__ = 0;
              $122 = $121&1;
              if ($122) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($120|0));
              $123 = __THREW__; __THREW__ = 0;
              $124 = $123&1;
              if ($124) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($79|0),($115|0));
             $125 = __THREW__; __THREW__ = 0;
             $126 = $125&1;
             if ($126) {
              break;
             }
             $127 = HEAP32[$79>>2]|0;
             $128 = (($127) + 92|0);
             $129 = HEAP32[$128>>2]|0;
             $130 = Math_imul($129, $$036)|0;
             $131 = (($84) + ($130)|0);
             HEAP32[$131>>2] = $115;
             __THREW__ = 0;
             invoke_vi(3799,($79|0));
             $132 = __THREW__; __THREW__ = 0;
             $133 = $132&1;
             if ($133) {
              break;
             }
             if ($102) {
              label = 62;
             } else {
              $134 = HEAP32[$85>>2]|0;
              $135 = ($V_0$035>>>0)<($134>>>0);
              if (!($135)) {
               label = 62;
              }
             }
             if ((label|0) == 62) {
              label = 0;
              __THREW__ = 0;
              $136 = (invoke_i(132)|0);
              $137 = __THREW__; __THREW__ = 0;
              $138 = $137&1;
              if ($138) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($136|0));
              $139 = __THREW__; __THREW__ = 0;
              $140 = $139&1;
              if ($140) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($79|0),($99|0));
             $141 = __THREW__; __THREW__ = 0;
             $142 = $141&1;
             if ($142) {
              break;
             }
             $143 = HEAP32[$79>>2]|0;
             $144 = (($143) + 92|0);
             $145 = HEAP32[$144>>2]|0;
             $146 = Math_imul($145, $V_0$035)|0;
             $147 = (($84) + ($146)|0);
             HEAP32[$147>>2] = $99;
             $148 = (($$036) + 1)|0;
             $149 = (($V_0$035) + -1)|0;
             $150 = ($148|0)<($149|0);
             if ($150) {
              $$036 = $148;$V_0$035 = $149;
             } else {
              label = 125;
              break;
             }
            }
            if ((label|0) == 125) {
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
            $9 = ___cxa_find_matching_catch()|0;
            $10 = tempRet0;
            $lpad$phi$index = $9;$lpad$phi$index5 = $10;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1170368|0))|0);
           $153 = __THREW__; __THREW__ = 0;
           $154 = $153&1;
           if (!($154)) {
            __THREW__ = 0;
            $155 = (invoke_iii(2735,($_____array|0),(1170368|0))|0);
            $156 = __THREW__; __THREW__ = 0;
            $157 = $156&1;
            if (!($157)) {
             $158 = ($155|0)==(0|0);
             if (!($158)) {
              $159 = ($76|0)>($index|0);
              if (!($159)) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              $160 = (($155) + 16|0);
              $161 = (($155) + 12|0);
              $$128 = $index;$V_0$127 = $76;
              while(1) {
               __THREW__ = 0;
               invoke_vi(3799,($155|0));
               $223 = __THREW__; __THREW__ = 0;
               $224 = $223&1;
               if ($224) {
                break;
               }
               $162 = ($$128|0)<(0);
               if ($162) {
                label = 74;
               } else {
                $163 = HEAP32[$161>>2]|0;
                $164 = ($$128>>>0)<($163>>>0);
                if (!($164)) {
                 label = 74;
                }
               }
               if ((label|0) == 74) {
                label = 0;
                __THREW__ = 0;
                $165 = (invoke_i(132)|0);
                $166 = __THREW__; __THREW__ = 0;
                $167 = $166&1;
                if ($167) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($165|0));
                $168 = __THREW__; __THREW__ = 0;
                $169 = $168&1;
                if ($169) {
                 break;
                }
               }
               $170 = HEAP32[$155>>2]|0;
               $171 = (($170) + 92|0);
               $172 = HEAP32[$171>>2]|0;
               $173 = Math_imul($172, $$128)|0;
               $174 = (($160) + ($173)|0);
               $175 = HEAP32[$174>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($155|0));
               $176 = __THREW__; __THREW__ = 0;
               $177 = $176&1;
               if ($177) {
                break;
               }
               $178 = ($V_0$127|0)<(0);
               if ($178) {
                label = 79;
               } else {
                $179 = HEAP32[$161>>2]|0;
                $180 = ($V_0$127>>>0)<($179>>>0);
                if (!($180)) {
                 label = 79;
                }
               }
               if ((label|0) == 79) {
                label = 0;
                __THREW__ = 0;
                $181 = (invoke_i(132)|0);
                $182 = __THREW__; __THREW__ = 0;
                $183 = $182&1;
                if ($183) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($181|0));
                $184 = __THREW__; __THREW__ = 0;
                $185 = $184&1;
                if ($185) {
                 break;
                }
               }
               $186 = HEAP32[$155>>2]|0;
               $187 = (($186) + 92|0);
               $188 = HEAP32[$187>>2]|0;
               $189 = Math_imul($188, $V_0$127)|0;
               $190 = (($160) + ($189)|0);
               $191 = HEAP32[$190>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($155|0));
               $192 = __THREW__; __THREW__ = 0;
               $193 = $192&1;
               if ($193) {
                break;
               }
               if ($162) {
                label = 84;
               } else {
                $194 = HEAP32[$161>>2]|0;
                $195 = ($$128>>>0)<($194>>>0);
                if (!($195)) {
                 label = 84;
                }
               }
               if ((label|0) == 84) {
                label = 0;
                __THREW__ = 0;
                $196 = (invoke_i(132)|0);
                $197 = __THREW__; __THREW__ = 0;
                $198 = $197&1;
                if ($198) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($196|0));
                $199 = __THREW__; __THREW__ = 0;
                $200 = $199&1;
                if ($200) {
                 break;
                }
               }
               $201 = HEAP32[$155>>2]|0;
               $202 = (($201) + 92|0);
               $203 = HEAP32[$202>>2]|0;
               $204 = Math_imul($203, $$128)|0;
               $205 = (($160) + ($204)|0);
               HEAP32[$205>>2] = $191;
               __THREW__ = 0;
               invoke_vi(3799,($155|0));
               $206 = __THREW__; __THREW__ = 0;
               $207 = $206&1;
               if ($207) {
                break;
               }
               if ($178) {
                label = 89;
               } else {
                $208 = HEAP32[$161>>2]|0;
                $209 = ($V_0$127>>>0)<($208>>>0);
                if (!($209)) {
                 label = 89;
                }
               }
               if ((label|0) == 89) {
                label = 0;
                __THREW__ = 0;
                $210 = (invoke_i(132)|0);
                $211 = __THREW__; __THREW__ = 0;
                $212 = $211&1;
                if ($212) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($210|0));
                $213 = __THREW__; __THREW__ = 0;
                $214 = $213&1;
                if ($214) {
                 break;
                }
               }
               $215 = HEAP32[$155>>2]|0;
               $216 = (($215) + 92|0);
               $217 = HEAP32[$216>>2]|0;
               $218 = Math_imul($217, $V_0$127)|0;
               $219 = (($160) + ($218)|0);
               HEAP32[$219>>2] = $175;
               $220 = (($$128) + 1)|0;
               $221 = (($V_0$127) + -1)|0;
               $222 = ($220|0)<($221|0);
               if ($222) {
                $$128 = $220;$V_0$127 = $221;
               } else {
                label = 125;
                break;
               }
              }
              if ((label|0) == 125) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              $7 = ___cxa_find_matching_catch()|0;
              $8 = tempRet0;
              $lpad$phi$index = $7;$lpad$phi$index5 = $8;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(1218904|0))|0);
             $225 = __THREW__; __THREW__ = 0;
             $226 = $225&1;
             if (!($226)) {
              __THREW__ = 0;
              $227 = (invoke_iii(2735,($_____array|0),(1218904|0))|0);
              $228 = __THREW__; __THREW__ = 0;
              $229 = $228&1;
              if (!($229)) {
               $230 = ($227|0)==(0|0);
               if ($230) {
                __THREW__ = 0;
                $297 = (invoke_iii(763,0,($_____array|0))|0);
                $298 = __THREW__; __THREW__ = 0;
                $299 = $298&1;
                if ($299) {
                 break;
                }
                $300 = ($76|0)>($index|0);
                if (!($300)) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                $$314 = $index;$V_0$313 = $76;
                while(1) {
                 __THREW__ = 0;
                 invoke_vi(3799,($297|0));
                 $306 = __THREW__; __THREW__ = 0;
                 $307 = $306&1;
                 if ($307) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiii(472,(2219840|0),($297|0),($$314|0),($V_0$313|0));
                 $301 = __THREW__; __THREW__ = 0;
                 $302 = $301&1;
                 if ($302) {
                  break;
                 }
                 $303 = (($$314) + 1)|0;
                 $304 = (($V_0$313) + -1)|0;
                 $305 = ($303|0)<($304|0);
                 if ($305) {
                  $$314 = $303;$V_0$313 = $304;
                 } else {
                  label = 125;
                  break;
                 }
                }
                if ((label|0) == 125) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                $3 = ___cxa_find_matching_catch()|0;
                $4 = tempRet0;
                $lpad$phi$index = $3;$lpad$phi$index5 = $4;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               $231 = ($76|0)>($index|0);
               if (!($231)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
               $232 = (($227) + 16|0);
               $233 = (($227) + 12|0);
               $$221 = $index;$V_0$220 = $76;
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($227|0));
                $295 = __THREW__; __THREW__ = 0;
                $296 = $295&1;
                if ($296) {
                 break;
                }
                $234 = ($$221|0)<(0);
                if ($234) {
                 label = 100;
                } else {
                 $235 = HEAP32[$233>>2]|0;
                 $236 = ($$221>>>0)<($235>>>0);
                 if (!($236)) {
                  label = 100;
                 }
                }
                if ((label|0) == 100) {
                 label = 0;
                 __THREW__ = 0;
                 $237 = (invoke_i(132)|0);
                 $238 = __THREW__; __THREW__ = 0;
                 $239 = $238&1;
                 if ($239) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($237|0));
                 $240 = __THREW__; __THREW__ = 0;
                 $241 = $240&1;
                 if ($241) {
                  break;
                 }
                }
                $242 = HEAP32[$227>>2]|0;
                $243 = (($242) + 92|0);
                $244 = HEAP32[$243>>2]|0;
                $245 = Math_imul($244, $$221)|0;
                $246 = (($232) + ($245)|0);
                $247 = +HEAPF64[$246>>3];
                __THREW__ = 0;
                invoke_vi(3799,($227|0));
                $248 = __THREW__; __THREW__ = 0;
                $249 = $248&1;
                if ($249) {
                 break;
                }
                $250 = ($V_0$220|0)<(0);
                if ($250) {
                 label = 105;
                } else {
                 $251 = HEAP32[$233>>2]|0;
                 $252 = ($V_0$220>>>0)<($251>>>0);
                 if (!($252)) {
                  label = 105;
                 }
                }
                if ((label|0) == 105) {
                 label = 0;
                 __THREW__ = 0;
                 $253 = (invoke_i(132)|0);
                 $254 = __THREW__; __THREW__ = 0;
                 $255 = $254&1;
                 if ($255) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($253|0));
                 $256 = __THREW__; __THREW__ = 0;
                 $257 = $256&1;
                 if ($257) {
                  break;
                 }
                }
                $258 = HEAP32[$227>>2]|0;
                $259 = (($258) + 92|0);
                $260 = HEAP32[$259>>2]|0;
                $261 = Math_imul($260, $V_0$220)|0;
                $262 = (($232) + ($261)|0);
                $263 = +HEAPF64[$262>>3];
                __THREW__ = 0;
                invoke_vi(3799,($227|0));
                $264 = __THREW__; __THREW__ = 0;
                $265 = $264&1;
                if ($265) {
                 break;
                }
                if ($234) {
                 label = 110;
                } else {
                 $266 = HEAP32[$233>>2]|0;
                 $267 = ($$221>>>0)<($266>>>0);
                 if (!($267)) {
                  label = 110;
                 }
                }
                if ((label|0) == 110) {
                 label = 0;
                 __THREW__ = 0;
                 $268 = (invoke_i(132)|0);
                 $269 = __THREW__; __THREW__ = 0;
                 $270 = $269&1;
                 if ($270) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($268|0));
                 $271 = __THREW__; __THREW__ = 0;
                 $272 = $271&1;
                 if ($272) {
                  break;
                 }
                }
                $273 = HEAP32[$227>>2]|0;
                $274 = (($273) + 92|0);
                $275 = HEAP32[$274>>2]|0;
                $276 = Math_imul($275, $$221)|0;
                $277 = (($232) + ($276)|0);
                HEAPF64[$277>>3] = $263;
                __THREW__ = 0;
                invoke_vi(3799,($227|0));
                $278 = __THREW__; __THREW__ = 0;
                $279 = $278&1;
                if ($279) {
                 break;
                }
                if ($250) {
                 label = 115;
                } else {
                 $280 = HEAP32[$233>>2]|0;
                 $281 = ($V_0$220>>>0)<($280>>>0);
                 if (!($281)) {
                  label = 115;
                 }
                }
                if ((label|0) == 115) {
                 label = 0;
                 __THREW__ = 0;
                 $282 = (invoke_i(132)|0);
                 $283 = __THREW__; __THREW__ = 0;
                 $284 = $283&1;
                 if ($284) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($282|0));
                 $285 = __THREW__; __THREW__ = 0;
                 $286 = $285&1;
                 if ($286) {
                  break;
                 }
                }
                $287 = HEAP32[$227>>2]|0;
                $288 = (($287) + 92|0);
                $289 = HEAP32[$288>>2]|0;
                $290 = Math_imul($289, $V_0$220)|0;
                $291 = (($232) + ($290)|0);
                HEAPF64[$291>>3] = $247;
                $292 = (($$221) + 1)|0;
                $293 = (($V_0$220) + -1)|0;
                $294 = ($292|0)<($293|0);
                if ($294) {
                 $$221 = $292;$V_0$220 = $293;
                } else {
                 label = 125;
                 break;
                }
               }
               if ((label|0) == 125) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
               $5 = ___cxa_find_matching_catch()|0;
               $6 = tempRet0;
               $lpad$phi$index = $5;$lpad$phi$index5 = $6;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($lpad$phi$index|0);
               // unreachable;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $lpad$phi$index = $11;$lpad$phi$index5 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN18VirtActionInvoker2I27mscorlib_System_Int32TraitsS0_E6InvokeEP10MethodInfoPvii($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_ArrayP22mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225144);
 __THREW__ = 0;
 invoke_v(496);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3015952>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(755,($_____array|0),0)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_iii(753,($_____array|0),0)|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_viiiiii(56,0,($_____array|0),(0|0),($17|0),($22|0),(0|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z175mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_iiS0_($__this,$keys,$items,$index,$length,$comparer) {
 $__this = $__this|0;
 $keys = $keys|0;
 $items = $items|0;
 $index = $index|0;
 $length = $length|0;
 $comparer = $comparer|0;
 var $$0 = 0, $$01 = 0, $$neg25 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225480);
 __THREW__ = 0;
 invoke_v(497);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($keys|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3016024>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($keys|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1859,($keys|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)>(1);
     do {
      if (!($20)) {
       $21 = ($items|0)!=(0|0);
       if ($21) {
        __THREW__ = 0;
        invoke_vi(3799,($items|0));
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break L1;
        }
        __THREW__ = 0;
        $24 = (invoke_ii(1859,($items|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break L1;
        }
        $27 = ($24|0)<(2);
        if (!($27)) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($keys|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break L1;
        }
        __THREW__ = 0;
        $39 = (invoke_iii(755,($keys|0),0)|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($items|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break L1;
        }
        __THREW__ = 0;
        $44 = (invoke_iii(755,($items|0),0)|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break L1;
        }
        $47 = ($39|0)==($44|0);
        if (!($47)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          break L1;
         }
         __THREW__ = 0;
         $50 = (invoke_ii(3469,(2560072|0))|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(2583,($50|0));
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3830,($50|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break L1;
         }
         // unreachable;
        }
       }
       __THREW__ = 0;
       invoke_vi(3799,($keys|0));
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        break L1;
       }
       __THREW__ = 0;
       $59 = (invoke_iii(755,($keys|0),0)|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        break L1;
       }
       $62 = ($59|0)>($index|0);
       if ($62) {
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         break L1;
        }
        __THREW__ = 0;
        $65 = (invoke_ii(3469,(2561352|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break L1;
        }
        $68 = HEAP32[3016032>>2]|0;
        __THREW__ = 0;
        invoke_vii(1926,($65|0),($68|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3830,($65|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         break L1;
        }
        // unreachable;
       }
       $73 = ($length|0)>(-1);
       if (!($73)) {
        $74 = HEAP32[3016048>>2]|0;
        __THREW__ = 0;
        $75 = (invoke_iii(783,0,($74|0))|0);
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         break L1;
        }
        __THREW__ = 0;
        $80 = (invoke_ii(3469,(2561352|0))|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         break L1;
        }
        $83 = HEAP32[3016040>>2]|0;
        __THREW__ = 0;
        invoke_viii(644,($80|0),($83|0),($75|0));
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3830,($80|0));
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         break L1;
        }
        // unreachable;
       }
       __THREW__ = 0;
       invoke_vi(3799,($keys|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break L1;
       }
       __THREW__ = 0;
       $90 = (invoke_ii(1857,($keys|0))|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($keys|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break L1;
       }
       __THREW__ = 0;
       $95 = (invoke_iii(755,($keys|0),0)|0);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if ($97) {
        break L1;
       }
       $$neg25 = (($90) - ($index))|0;
       $98 = (($$neg25) - ($95))|0;
       $99 = ($98|0)<($length|0);
       do {
        if (!($99)) {
         if ($21) {
          __THREW__ = 0;
          invoke_vi(3799,($items|0));
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break L1;
          }
          __THREW__ = 0;
          $102 = (invoke_ii(1857,($items|0))|0);
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           break L1;
          }
          $105 = (($102) - ($length))|0;
          $106 = ($105|0)<($index|0);
          if ($106) {
           break;
          }
         }
         $116 = ($length|0)>(1);
         if (!($116)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         $117 = ($comparer|0)==(0|0);
         do {
          if ($117) {
           if ($21) {
            __THREW__ = 0;
            $118 = (invoke_iii(763,0,($items|0))|0);
            $119 = __THREW__; __THREW__ = 0;
            $120 = $119&1;
            if ($120) {
             break L1;
            } else {
             $V_0$0 = $118;
            }
           } else {
            $V_0$0 = 0;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1218904|0))|0);
           $121 = __THREW__; __THREW__ = 0;
           $122 = $121&1;
           if ($122) {
            break L1;
           }
           __THREW__ = 0;
           $123 = (invoke_iii(2735,($keys|0),(1218904|0))|0);
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            break L1;
           }
           $126 = ($123|0)==(0|0);
           if (!($126)) {
            __THREW__ = 0;
            (invoke_ii(2996,(1218904|0))|0);
            $127 = __THREW__; __THREW__ = 0;
            $128 = $127&1;
            if ($128) {
             break L1;
            }
            __THREW__ = 0;
            $129 = (invoke_iii(2735,($keys|0),(1218904|0))|0);
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             break L1;
            }
            __THREW__ = 0;
            invoke_viiiii(51,0,($129|0),($index|0),($length|0),($V_0$0|0));
            $132 = __THREW__; __THREW__ = 0;
            $133 = $132&1;
            if ($133) {
             break L1;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1170368|0))|0);
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if ($135) {
            break L1;
           }
           __THREW__ = 0;
           $136 = (invoke_iii(2735,($keys|0),(1170368|0))|0);
           $137 = __THREW__; __THREW__ = 0;
           $138 = $137&1;
           if ($138) {
            break L1;
           }
           $139 = ($136|0)==(0|0);
           if (!($139)) {
            __THREW__ = 0;
            (invoke_ii(2996,(1170368|0))|0);
            $140 = __THREW__; __THREW__ = 0;
            $141 = $140&1;
            if ($141) {
             break L1;
            }
            __THREW__ = 0;
            $142 = (invoke_iii(2735,($keys|0),(1170368|0))|0);
            $143 = __THREW__; __THREW__ = 0;
            $144 = $143&1;
            if ($144) {
             break L1;
            }
            __THREW__ = 0;
            invoke_viiiii(52,0,($142|0),($index|0),($length|0),($V_0$0|0));
            $145 = __THREW__; __THREW__ = 0;
            $146 = $145&1;
            if ($146) {
             break L1;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1168808|0))|0);
           $147 = __THREW__; __THREW__ = 0;
           $148 = $147&1;
           if ($148) {
            break L1;
           }
           __THREW__ = 0;
           $149 = (invoke_iii(2735,($keys|0),(1168808|0))|0);
           $150 = __THREW__; __THREW__ = 0;
           $151 = $150&1;
           if ($151) {
            break L1;
           }
           $152 = ($149|0)==(0|0);
           if ($152) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1168808|0))|0);
           $153 = __THREW__; __THREW__ = 0;
           $154 = $153&1;
           if ($154) {
            break L1;
           }
           __THREW__ = 0;
           $155 = (invoke_iii(2735,($keys|0),(1168808|0))|0);
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            break L1;
           }
           __THREW__ = 0;
           invoke_viiiii(53,0,($155|0),($index|0),($length|0),($V_0$0|0));
           $158 = __THREW__; __THREW__ = 0;
           $159 = $158&1;
           if ($159) {
            break L1;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         } while(0);
         $160 = (($index) + -1)|0;
         $161 = (($160) + ($length))|0;
         __THREW__ = 0;
         invoke_viiiiii(57,0,($keys|0),($items|0),($index|0),($161|0),($comparer|0));
         $162 = __THREW__; __THREW__ = 0;
         $163 = $162&1;
         if (!($163)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         $164 = ___cxa_find_matching_catch(348288|0)|0;
         $165 = tempRet0;
         $166 = (_llvm_eh_typeid_for((348288|0))|0);
         $167 = ($165|0)==($166|0);
         if (!($167)) {
          $$0 = $164;$$01 = $165;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($$0|0);
          // unreachable;
         }
         $168 = (___cxa_begin_catch(($164|0))|0);
         $169 = HEAP32[$168>>2]|0;
         $170 = HEAP32[$169>>2]|0;
         __THREW__ = 0;
         $171 = (invoke_iii(2727,(2246120|0),($170|0))|0);
         $172 = __THREW__; __THREW__ = 0;
         $173 = $172&1;
         do {
          if (!($173)) {
           if (!($171)) {
            $180 = (___cxa_allocate_exception(4)|0);
            $181 = HEAP32[$168>>2]|0;
            HEAP32[$180>>2] = $181;
            __THREW__ = 0;
            invoke_viii(1567,($180|0),(348288|0),(0|0));
            $182 = __THREW__; __THREW__ = 0;
            $183 = $182&1;
            if ($183) {
             break;
            }
            // unreachable;
           }
           __THREW__ = 0;
           invoke_v(66);
           $174 = __THREW__; __THREW__ = 0;
           $175 = $174&1;
           if ($175) {
            break L1;
           }
           $184 = HEAP32[3016056>>2]|0;
           __THREW__ = 0;
           $185 = (invoke_iii(783,0,($184|0))|0);
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if ($187) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2607872|0))|0);
           $188 = __THREW__; __THREW__ = 0;
           $189 = $188&1;
           if ($189) {
            break L1;
           }
           __THREW__ = 0;
           $190 = (invoke_ii(3469,(2607872|0))|0);
           $191 = __THREW__; __THREW__ = 0;
           $192 = $191&1;
           if ($192) {
            break L1;
           }
           __THREW__ = 0;
           invoke_viii(678,($190|0),($185|0),($169|0));
           $193 = __THREW__; __THREW__ = 0;
           $194 = $193&1;
           if ($194) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3830,($190|0));
           $195 = __THREW__; __THREW__ = 0;
           $196 = $195&1;
           if ($196) {
            break L1;
           }
           // unreachable;
          }
         } while(0);
         $176 = ___cxa_find_matching_catch()|0;
         $177 = tempRet0;
         __THREW__ = 0;
         invoke_v(66);
         $178 = __THREW__; __THREW__ = 0;
         $179 = $178&1;
         if ($179) {
          $197 = ___cxa_find_matching_catch(0|0)|0;
          $198 = tempRet0;
          ___clang_call_terminate($197);
          // unreachable;
         } else {
          $$0 = $176;$$01 = $177;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($$0|0);
          // unreachable;
         }
        }
       } while(0);
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        break L1;
       }
       __THREW__ = 0;
       $109 = (invoke_ii(3469,(2560072|0))|0);
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if ($111) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(2583,($109|0));
       $112 = __THREW__; __THREW__ = 0;
       $113 = $112&1;
       if ($113) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3830,($109|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        break L1;
       }
       // unreachable;
      }
     } while(0);
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      __THREW__ = 0;
      $30 = (invoke_ii(3469,(2636920|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(2773,($30|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        __THREW__ = 0;
        invoke_vi(3830,($30|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$0 = $3;$$01 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_ArrayP22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_($__this,$keys,$items) {
 $__this = $__this|0;
 $keys = $keys|0;
 $items = $items|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225192);
 __THREW__ = 0;
 invoke_v(498);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($keys|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3015968>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($keys|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(755,($keys|0),0)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3799,($keys|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_iii(753,($keys|0),0)|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_viiiiii(56,0,($keys|0),($items|0),($17|0),($22|0),(0|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_($__this,$_____array,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225240);
 __THREW__ = 0;
 invoke_v(499);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3015992>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(755,($_____array|0),0)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_iii(753,($_____array|0),0)|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_viiiiii(56,0,($_____array|0),(0|0),($17|0),($22|0),($comparer|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z115mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_Arrayii($__this,$_____array,$index,$length) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225288);
 __THREW__ = 0;
 invoke_viiiiii(56,0,($_____array|0),(0|0),($index|0),($length|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z131mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_S0_($__this,$keys,$items,$comparer) {
 $__this = $__this|0;
 $keys = $keys|0;
 $items = $items|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225336);
 __THREW__ = 0;
 invoke_v(500);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($keys|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3016008>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($keys|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(755,($keys|0),0)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3799,($keys|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_iii(753,($keys|0),0)|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_viiiiii(56,0,($keys|0),($items|0),($17|0),($22|0),($comparer|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z137mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_ii($__this,$keys,$items,$index,$length) {
 $__this = $__this|0;
 $keys = $keys|0;
 $items = $items|0;
 $index = $index|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225384);
 __THREW__ = 0;
 invoke_viiiiii(56,0,($keys|0),($items|0),($index|0),($length|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z153mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayiiS0_($__this,$_____array,$index,$length,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225432);
 __THREW__ = 0;
 invoke_viiiiii(56,0,($_____array|0),(0|0),($index|0),($length|0),($comparer|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z158mscorlib_System_Array_m_combsort_mscorlib_System_Void_mscorlib_System_Double_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Array_SwapperP22mscorlib_System_ObjectP26mscorlib_System_Double_arriiP29mscorlib_System_Array_Swapper($__this,$_____array,$start,$size,$swap_items) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $start = $start|0;
 $size = $size|0;
 $swap_items = $swap_items|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_1$0$off0 = 0, $V_1$1$off0$lcssa = 0, $V_1$1$off05 = 0, $V_3$03 = 0, $_stackTraceSentry = 0, $brmerge = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225576);
 $0 = (($size) + ($start))|0;
 $1 = (($_____array) + 16|0);
 $2 = ($swap_items|0)==(0|0);
 $3 = (($_____array) + 12|0);
 $V_0$0 = $size;
 L1: while(1) {
  __THREW__ = 0;
  $4 = (invoke_iii(764,0,($V_0$0|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   label = 5;
   break;
  }
  $7 = (($0) - ($4))|0;
  $8 = ($7|0)>($start|0);
  if ($8) {
   $V_1$1$off05 = 0;$V_3$03 = $start;
   while(1) {
    $30 = (($V_3$03) + ($4))|0;
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 4;
     break L1;
    }
    $13 = ($V_3$03|0)<(0);
    if ($13) {
     label = 9;
    } else {
     $14 = HEAP32[$3>>2]|0;
     $15 = ($V_3$03>>>0)<($14>>>0);
     if (!($15)) {
      label = 9;
     }
    }
    if ((label|0) == 9) {
     label = 0;
     __THREW__ = 0;
     $16 = (invoke_i(132)|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 4;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3302,($16|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 4;
      break L1;
     }
    }
    $21 = HEAP32[$_____array>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $V_3$03)|0;
    $25 = (($1) + ($24)|0);
    $26 = +HEAPF64[$25>>3];
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     label = 4;
     break L1;
    }
    $29 = ($30|0)<(0);
    if ($29) {
     label = 14;
    } else {
     $31 = HEAP32[$3>>2]|0;
     $32 = ($30>>>0)<($31>>>0);
     if (!($32)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     __THREW__ = 0;
     $33 = (invoke_i(132)|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 4;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3302,($33|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 4;
      break L1;
     }
    }
    $38 = HEAP32[$_____array>>2]|0;
    $39 = (($38) + 92|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = Math_imul($40, $30)|0;
    $42 = (($1) + ($41)|0);
    $43 = +HEAPF64[$42>>3];
    $44 = !($26 <= $43);
    if ($44) {
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 4;
      break L1;
     }
     if ($13) {
      label = 20;
     } else {
      $47 = HEAP32[$3>>2]|0;
      $48 = ($V_3$03>>>0)<($47>>>0);
      if (!($48)) {
       label = 20;
      }
     }
     if ((label|0) == 20) {
      label = 0;
      __THREW__ = 0;
      $49 = (invoke_i(132)|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($49|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break L1;
      }
     }
     $54 = HEAP32[$_____array>>2]|0;
     $55 = (($54) + 92|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = Math_imul($56, $V_3$03)|0;
     $58 = (($1) + ($57)|0);
     $59 = +HEAPF64[$58>>3];
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 4;
      break L1;
     }
     if ($29) {
      label = 25;
     } else {
      $62 = HEAP32[$3>>2]|0;
      $63 = ($30>>>0)<($62>>>0);
      if (!($63)) {
       label = 25;
      }
     }
     if ((label|0) == 25) {
      label = 0;
      __THREW__ = 0;
      $64 = (invoke_i(132)|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($64|0));
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 4;
       break L1;
      }
     }
     $69 = HEAP32[$_____array>>2]|0;
     $70 = (($69) + 92|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = Math_imul($71, $30)|0;
     $73 = (($1) + ($72)|0);
     $74 = +HEAPF64[$73>>3];
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      label = 4;
      break L1;
     }
     if ($13) {
      label = 30;
     } else {
      $77 = HEAP32[$3>>2]|0;
      $78 = ($V_3$03>>>0)<($77>>>0);
      if (!($78)) {
       label = 30;
      }
     }
     if ((label|0) == 30) {
      label = 0;
      __THREW__ = 0;
      $79 = (invoke_i(132)|0);
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($79|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       label = 4;
       break L1;
      }
     }
     $84 = HEAP32[$_____array>>2]|0;
     $85 = (($84) + 92|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = Math_imul($86, $V_3$03)|0;
     $88 = (($1) + ($87)|0);
     HEAPF64[$88>>3] = $74;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 4;
      break L1;
     }
     if ($29) {
      label = 35;
     } else {
      $91 = HEAP32[$3>>2]|0;
      $92 = ($30>>>0)<($91>>>0);
      if (!($92)) {
       label = 35;
      }
     }
     if ((label|0) == 35) {
      label = 0;
      __THREW__ = 0;
      $93 = (invoke_i(132)|0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($93|0));
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       label = 4;
       break L1;
      }
     }
     $98 = HEAP32[$_____array>>2]|0;
     $99 = (($98) + 92|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = Math_imul($100, $30)|0;
     $102 = (($1) + ($101)|0);
     HEAPF64[$102>>3] = $59;
     if ($2) {
      $V_1$0$off0 = 1;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($swap_items|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_viiii(472,(2219840|0),($swap_items|0),($V_3$03|0),($30|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       label = 4;
       break L1;
      } else {
       $V_1$0$off0 = 1;
      }
     }
    } else {
     $V_1$0$off0 = $V_1$1$off05;
    }
    $107 = (($V_3$03) + 1)|0;
    $108 = ($107|0)<($7|0);
    if ($108) {
     $V_1$1$off05 = $V_1$0$off0;$V_3$03 = $107;
    } else {
     $V_1$1$off0$lcssa = $V_1$0$off0;
     break;
    }
   }
  } else {
   $V_1$1$off0$lcssa = 0;
  }
  $$not = ($4|0)!=(1);
  $brmerge = $$not | $V_1$1$off0$lcssa;
  if ($brmerge) {
   $V_0$0 = $4;
  } else {
   label = 43;
   break;
  }
 }
 if ((label|0) == 4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $lpad$phi$index = $9;$lpad$phi$index2 = $10;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 43) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z157mscorlib_System_Array_m_combsort_mscorlib_System_Void_mscorlib_System_Int32_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Array_SwapperP22mscorlib_System_ObjectP25mscorlib_System_Int32_arriiP29mscorlib_System_Array_Swapper($__this,$_____array,$start,$size,$swap_items) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $start = $start|0;
 $size = $size|0;
 $swap_items = $swap_items|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_1$0$off0 = 0, $V_1$1$off0$lcssa = 0, $V_1$1$off05 = 0, $V_3$03 = 0, $_stackTraceSentry = 0, $brmerge = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225624);
 $0 = (($size) + ($start))|0;
 $1 = (($_____array) + 16|0);
 $2 = ($swap_items|0)==(0|0);
 $3 = (($_____array) + 12|0);
 $V_0$0 = $size;
 L1: while(1) {
  __THREW__ = 0;
  $4 = (invoke_iii(764,0,($V_0$0|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   label = 5;
   break;
  }
  $7 = (($0) - ($4))|0;
  $8 = ($7|0)>($start|0);
  if ($8) {
   $V_1$1$off05 = 0;$V_3$03 = $start;
   while(1) {
    $30 = (($V_3$03) + ($4))|0;
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 4;
     break L1;
    }
    $13 = ($V_3$03|0)<(0);
    if ($13) {
     label = 9;
    } else {
     $14 = HEAP32[$3>>2]|0;
     $15 = ($V_3$03>>>0)<($14>>>0);
     if (!($15)) {
      label = 9;
     }
    }
    if ((label|0) == 9) {
     label = 0;
     __THREW__ = 0;
     $16 = (invoke_i(132)|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 4;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3302,($16|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 4;
      break L1;
     }
    }
    $21 = HEAP32[$_____array>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $V_3$03)|0;
    $25 = (($1) + ($24)|0);
    $26 = HEAP32[$25>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     label = 4;
     break L1;
    }
    $29 = ($30|0)<(0);
    if ($29) {
     label = 14;
    } else {
     $31 = HEAP32[$3>>2]|0;
     $32 = ($30>>>0)<($31>>>0);
     if (!($32)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     __THREW__ = 0;
     $33 = (invoke_i(132)|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 4;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3302,($33|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 4;
      break L1;
     }
    }
    $38 = HEAP32[$_____array>>2]|0;
    $39 = (($38) + 92|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = Math_imul($40, $30)|0;
    $42 = (($1) + ($41)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($26|0)>($43|0);
    if ($44) {
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 4;
      break L1;
     }
     if ($13) {
      label = 20;
     } else {
      $47 = HEAP32[$3>>2]|0;
      $48 = ($V_3$03>>>0)<($47>>>0);
      if (!($48)) {
       label = 20;
      }
     }
     if ((label|0) == 20) {
      label = 0;
      __THREW__ = 0;
      $49 = (invoke_i(132)|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($49|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break L1;
      }
     }
     $54 = HEAP32[$_____array>>2]|0;
     $55 = (($54) + 92|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = Math_imul($56, $V_3$03)|0;
     $58 = (($1) + ($57)|0);
     $59 = HEAP32[$58>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 4;
      break L1;
     }
     if ($29) {
      label = 25;
     } else {
      $62 = HEAP32[$3>>2]|0;
      $63 = ($30>>>0)<($62>>>0);
      if (!($63)) {
       label = 25;
      }
     }
     if ((label|0) == 25) {
      label = 0;
      __THREW__ = 0;
      $64 = (invoke_i(132)|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($64|0));
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 4;
       break L1;
      }
     }
     $69 = HEAP32[$_____array>>2]|0;
     $70 = (($69) + 92|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = Math_imul($71, $30)|0;
     $73 = (($1) + ($72)|0);
     $74 = HEAP32[$73>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      label = 4;
      break L1;
     }
     if ($13) {
      label = 30;
     } else {
      $77 = HEAP32[$3>>2]|0;
      $78 = ($V_3$03>>>0)<($77>>>0);
      if (!($78)) {
       label = 30;
      }
     }
     if ((label|0) == 30) {
      label = 0;
      __THREW__ = 0;
      $79 = (invoke_i(132)|0);
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($79|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       label = 4;
       break L1;
      }
     }
     $84 = HEAP32[$_____array>>2]|0;
     $85 = (($84) + 92|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = Math_imul($86, $V_3$03)|0;
     $88 = (($1) + ($87)|0);
     HEAP32[$88>>2] = $74;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 4;
      break L1;
     }
     if ($29) {
      label = 35;
     } else {
      $91 = HEAP32[$3>>2]|0;
      $92 = ($30>>>0)<($91>>>0);
      if (!($92)) {
       label = 35;
      }
     }
     if ((label|0) == 35) {
      label = 0;
      __THREW__ = 0;
      $93 = (invoke_i(132)|0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($93|0));
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       label = 4;
       break L1;
      }
     }
     $98 = HEAP32[$_____array>>2]|0;
     $99 = (($98) + 92|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = Math_imul($100, $30)|0;
     $102 = (($1) + ($101)|0);
     HEAP32[$102>>2] = $59;
     if ($2) {
      $V_1$0$off0 = 1;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($swap_items|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_viiii(472,(2219840|0),($swap_items|0),($V_3$03|0),($30|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       label = 4;
       break L1;
      } else {
       $V_1$0$off0 = 1;
      }
     }
    } else {
     $V_1$0$off0 = $V_1$1$off05;
    }
    $107 = (($V_3$03) + 1)|0;
    $108 = ($107|0)<($7|0);
    if ($108) {
     $V_1$1$off05 = $V_1$0$off0;$V_3$03 = $107;
    } else {
     $V_1$1$off0$lcssa = $V_1$0$off0;
     break;
    }
   }
  } else {
   $V_1$1$off0$lcssa = 0;
  }
  $$not = ($4|0)!=(1);
  $brmerge = $$not | $V_1$1$off0$lcssa;
  if ($brmerge) {
   $V_0$0 = $4;
  } else {
   label = 43;
   break;
  }
 }
 if ((label|0) == 4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $lpad$phi$index = $9;$lpad$phi$index2 = $10;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 43) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z156mscorlib_System_Array_m_combsort_mscorlib_System_Void_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Array_SwapperP22mscorlib_System_ObjectP24mscorlib_System_Char_arriiP29mscorlib_System_Array_Swapper($__this,$_____array,$start,$size,$swap_items) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $start = $start|0;
 $size = $size|0;
 $swap_items = $swap_items|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_1$0$off0 = 0, $V_1$1$off0$lcssa = 0, $V_1$1$off05 = 0, $V_3$03 = 0, $_stackTraceSentry = 0, $brmerge = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225672);
 $0 = (($size) + ($start))|0;
 $1 = (($_____array) + 16|0);
 $2 = ($swap_items|0)==(0|0);
 $3 = (($_____array) + 12|0);
 $V_0$0 = $size;
 L1: while(1) {
  __THREW__ = 0;
  $4 = (invoke_iii(764,0,($V_0$0|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   label = 5;
   break;
  }
  $7 = (($0) - ($4))|0;
  $8 = ($7|0)>($start|0);
  if ($8) {
   $V_1$1$off05 = 0;$V_3$03 = $start;
   while(1) {
    $30 = (($V_3$03) + ($4))|0;
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 4;
     break L1;
    }
    $13 = ($V_3$03|0)<(0);
    if ($13) {
     label = 9;
    } else {
     $14 = HEAP32[$3>>2]|0;
     $15 = ($V_3$03>>>0)<($14>>>0);
     if (!($15)) {
      label = 9;
     }
    }
    if ((label|0) == 9) {
     label = 0;
     __THREW__ = 0;
     $16 = (invoke_i(132)|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 4;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3302,($16|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 4;
      break L1;
     }
    }
    $21 = HEAP32[$_____array>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $V_3$03)|0;
    $25 = (($1) + ($24)|0);
    $26 = HEAP16[$25>>1]|0;
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     label = 4;
     break L1;
    }
    $29 = ($30|0)<(0);
    if ($29) {
     label = 14;
    } else {
     $31 = HEAP32[$3>>2]|0;
     $32 = ($30>>>0)<($31>>>0);
     if (!($32)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     __THREW__ = 0;
     $33 = (invoke_i(132)|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 4;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3302,($33|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 4;
      break L1;
     }
    }
    $38 = HEAP32[$_____array>>2]|0;
    $39 = (($38) + 92|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = Math_imul($40, $30)|0;
    $42 = (($1) + ($41)|0);
    $43 = HEAP16[$42>>1]|0;
    $44 = ($26&65535)>($43&65535);
    if ($44) {
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 4;
      break L1;
     }
     if ($13) {
      label = 20;
     } else {
      $47 = HEAP32[$3>>2]|0;
      $48 = ($V_3$03>>>0)<($47>>>0);
      if (!($48)) {
       label = 20;
      }
     }
     if ((label|0) == 20) {
      label = 0;
      __THREW__ = 0;
      $49 = (invoke_i(132)|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($49|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break L1;
      }
     }
     $54 = HEAP32[$_____array>>2]|0;
     $55 = (($54) + 92|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = Math_imul($56, $V_3$03)|0;
     $58 = (($1) + ($57)|0);
     $59 = HEAP16[$58>>1]|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 4;
      break L1;
     }
     if ($29) {
      label = 25;
     } else {
      $62 = HEAP32[$3>>2]|0;
      $63 = ($30>>>0)<($62>>>0);
      if (!($63)) {
       label = 25;
      }
     }
     if ((label|0) == 25) {
      label = 0;
      __THREW__ = 0;
      $64 = (invoke_i(132)|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($64|0));
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 4;
       break L1;
      }
     }
     $69 = HEAP32[$_____array>>2]|0;
     $70 = (($69) + 92|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = Math_imul($71, $30)|0;
     $73 = (($1) + ($72)|0);
     $74 = HEAP16[$73>>1]|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      label = 4;
      break L1;
     }
     if ($13) {
      label = 30;
     } else {
      $77 = HEAP32[$3>>2]|0;
      $78 = ($V_3$03>>>0)<($77>>>0);
      if (!($78)) {
       label = 30;
      }
     }
     if ((label|0) == 30) {
      label = 0;
      __THREW__ = 0;
      $79 = (invoke_i(132)|0);
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($79|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       label = 4;
       break L1;
      }
     }
     $84 = HEAP32[$_____array>>2]|0;
     $85 = (($84) + 92|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = Math_imul($86, $V_3$03)|0;
     $88 = (($1) + ($87)|0);
     HEAP16[$88>>1] = $74;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      label = 4;
      break L1;
     }
     if ($29) {
      label = 35;
     } else {
      $91 = HEAP32[$3>>2]|0;
      $92 = ($30>>>0)<($91>>>0);
      if (!($92)) {
       label = 35;
      }
     }
     if ((label|0) == 35) {
      label = 0;
      __THREW__ = 0;
      $93 = (invoke_i(132)|0);
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($93|0));
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       label = 4;
       break L1;
      }
     }
     $98 = HEAP32[$_____array>>2]|0;
     $99 = (($98) + 92|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = Math_imul($100, $30)|0;
     $102 = (($1) + ($101)|0);
     HEAP16[$102>>1] = $59;
     if ($2) {
      $V_1$0$off0 = 1;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($swap_items|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_viiii(472,(2219840|0),($swap_items|0),($V_3$03|0),($30|0));
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       label = 4;
       break L1;
      } else {
       $V_1$0$off0 = 1;
      }
     }
    } else {
     $V_1$0$off0 = $V_1$1$off05;
    }
    $107 = (($V_3$03) + 1)|0;
    $108 = ($107|0)<($7|0);
    if ($108) {
     $V_1$1$off05 = $V_1$0$off0;$V_3$03 = $107;
    } else {
     $V_1$1$off0$lcssa = $V_1$0$off0;
     break;
    }
   }
  } else {
   $V_1$1$off0$lcssa = 0;
  }
  $$not = ($4|0)!=(1);
  $brmerge = $$not | $V_1$1$off0$lcssa;
  if ($brmerge) {
   $V_0$0 = $4;
  } else {
   label = 43;
   break;
  }
 }
 if ((label|0) == 4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $lpad$phi$index = $9;$lpad$phi$index2 = $10;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index2 = $12;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 43) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z176mscorlib_System_Array_m_qsort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_iiS0_($__this,$keys,$items,$low0,$high0,$comparer) {
 $__this = $__this|0;
 $keys = $keys|0;
 $items = $items|0;
 $low0 = $low0|0;
 $high0 = $high0|0;
 $comparer = $comparer|0;
 var $$lcssa = 0, $$lcssa13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$lcssa = 0, $V_0$0$ph = 0, $V_0$015 = 0, $V_1$0$ph = 0, $V_1$1$lcssa = 0, $V_1$13 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225720);
 $0 = ($low0|0)<($high0|0);
 if (!($0)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3799,($keys|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = (($high0) - ($low0))|0;
   $4 = (($3|0) / 2)&-1;
   $5 = (($4) + ($low0))|0;
   __THREW__ = 0;
   $6 = (invoke_iii(757,($keys|0),($5|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $V_0$0$ph = $low0;$V_1$0$ph = $high0;
    L6: while(1) {
     $45 = ($V_0$0$ph|0)<($high0|0);
     L8: do {
      if ($45) {
       $V_0$015 = $V_0$0$ph;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($keys|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         label = 5;
         break L6;
        }
        __THREW__ = 0;
        $22 = (invoke_iii(757,($keys|0),($V_0$015|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if ($24) {
         label = 5;
         break L6;
        }
        __THREW__ = 0;
        $25 = (invoke_iiiii(117,0,($22|0),($6|0),($comparer|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         label = 5;
         break L6;
        }
        $28 = ($25|0)<(0);
        $18 = (($V_0$015) + 1)|0;
        if (!($28)) {
         $$lcssa13 = 0;$V_0$0$lcssa = $V_0$015;
         break L8;
        }
        $17 = ($18|0)<($high0|0);
        if ($17) {
         $V_0$015 = $18;
        } else {
         $$lcssa13 = 1;$V_0$0$lcssa = $18;
         break;
        }
       }
      } else {
       $$lcssa13 = 1;$V_0$0$lcssa = $V_0$0$ph;
      }
     } while(0);
     $19 = ($V_1$0$ph|0)>($low0|0);
     L16: do {
      if ($19) {
       $V_1$13 = $V_1$0$ph;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($keys|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         label = 4;
         break L6;
        }
        __THREW__ = 0;
        $33 = (invoke_iii(757,($keys|0),($V_1$13|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         label = 4;
         break L6;
        }
        __THREW__ = 0;
        $36 = (invoke_iiiii(117,0,($6|0),($33|0),($comparer|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         label = 4;
         break L6;
        }
        $39 = ($36|0)<(0);
        $30 = (($V_1$13) + -1)|0;
        if (!($39)) {
         $$lcssa = 0;$V_1$1$lcssa = $V_1$13;
         break L16;
        }
        $29 = ($30|0)>($low0|0);
        if ($29) {
         $V_1$13 = $30;
        } else {
         $$lcssa = 1;$V_1$1$lcssa = $30;
         break;
        }
       }
      } else {
       $$lcssa = 1;$V_1$1$lcssa = $V_1$0$ph;
      }
     } while(0);
     $40 = ($V_0$0$lcssa|0)>($V_1$1$lcssa|0);
     if ($40) {
      label = 24;
      break;
     }
     __THREW__ = 0;
     invoke_viiiii(54,0,($keys|0),($items|0),($V_0$0$lcssa|0),($V_1$1$lcssa|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 6;
      break;
     }
     $43 = (($V_0$0$lcssa) + 1)|0;
     $44 = (($V_1$1$lcssa) + -1)|0;
     $V_0$0$ph = $43;$V_1$0$ph = $44;
    }
    if ((label|0) == 4) {
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index4 = $10;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 5) {
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index4 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 6) {
     $13 = ___cxa_find_matching_catch()|0;
     $14 = tempRet0;
     $lpad$phi$index = $13;$lpad$phi$index4 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 24) {
     if (!($$lcssa)) {
      __THREW__ = 0;
      invoke_viiiiii(57,0,($keys|0),($items|0),($low0|0),($V_1$1$lcssa|0),($comparer|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
     }
     if ($$lcssa13) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_viiiiii(57,0,($keys|0),($items|0),($V_0$0$lcssa|0),($high0|0),($comparer|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index4 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z35mscorlib_System_Array_m_int_swapperP21mscorlib_System_Arrayii($__this,$i,$j) {
 $__this = $__this|0;
 $i = $i|0;
 $j = $j|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224856);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($__this|0),(1170368|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($i|0)<(0);
     if ($7) {
      label = 6;
     } else {
      $8 = (($2) + 12|0);
      $9 = HEAP32[$8>>2]|0;
      $10 = ($9>>>0)>($i>>>0);
      if (!($10)) {
       label = 6;
      }
     }
     if ((label|0) == 6) {
      __THREW__ = 0;
      $11 = (invoke_i(132)|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($11|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
     $18 = HEAP32[$2>>2]|0;
     $19 = (($2) + 16|0);
     $20 = (($18) + 92|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = Math_imul($21, $i)|0;
     $23 = (($19) + ($22)|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = ($j|0)<(0);
      if ($27) {
       label = 12;
      } else {
       $28 = (($2) + 12|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29>>>0)>($j>>>0);
       if (!($30)) {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       __THREW__ = 0;
       $31 = (invoke_i(132)|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($31|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
      }
      $36 = HEAP32[$2>>2]|0;
      $37 = (($36) + 92|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = Math_imul($38, $j)|0;
      $40 = (($19) + ($39)|0);
      $41 = HEAP32[$40>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       if ($7) {
        label = 17;
       } else {
        $44 = (($2) + 12|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ($45>>>0)>($i>>>0);
        if (!($46)) {
         label = 17;
        }
       }
       if ((label|0) == 17) {
        __THREW__ = 0;
        $47 = (invoke_i(132)|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($47|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
       }
       $52 = HEAP32[$2>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $i)|0;
       $56 = (($19) + ($55)|0);
       HEAP32[$56>>2] = $41;
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if (!($58)) {
        if (!($27)) {
         $59 = (($2) + 12|0);
         $60 = HEAP32[$59>>2]|0;
         $61 = ($60>>>0)>($j>>>0);
         if ($61) {
          $67 = HEAP32[$2>>2]|0;
          $68 = (($67) + 92|0);
          $69 = HEAP32[$68>>2]|0;
          $70 = Math_imul($69, $j)|0;
          $71 = (($19) + ($70)|0);
          HEAP32[$71>>2] = $24;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
        __THREW__ = 0;
        $62 = (invoke_i(132)|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if (!($64)) {
         __THREW__ = 0;
         invoke_vi(3302,($62|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if (!($66)) {
          $67 = HEAP32[$2>>2]|0;
          $68 = (($67) + 92|0);
          $69 = HEAP32[$68>>2]|0;
          $70 = Math_imul($69, $j)|0;
          $71 = (($19) + ($70)|0);
          HEAP32[$71>>2] = $24;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z35mscorlib_System_Array_m_obj_swapperP21mscorlib_System_Arrayii($__this,$i,$j) {
 $__this = $__this|0;
 $i = $i|0;
 $j = $j|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224952);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($i|0)<(0);
     if ($7) {
      label = 6;
     } else {
      $8 = (($2) + 12|0);
      $9 = HEAP32[$8>>2]|0;
      $10 = ($9>>>0)>($i>>>0);
      if (!($10)) {
       label = 6;
      }
     }
     if ((label|0) == 6) {
      __THREW__ = 0;
      $11 = (invoke_i(132)|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($11|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
     $18 = HEAP32[$2>>2]|0;
     $19 = (($2) + 16|0);
     $20 = (($18) + 92|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = Math_imul($21, $i)|0;
     $23 = (($19) + ($22)|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = ($j|0)<(0);
      if ($27) {
       label = 12;
      } else {
       $28 = (($2) + 12|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29>>>0)>($j>>>0);
       if (!($30)) {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       __THREW__ = 0;
       $31 = (invoke_i(132)|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($31|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
      }
      $36 = HEAP32[$2>>2]|0;
      $37 = (($36) + 92|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = Math_imul($38, $j)|0;
      $40 = (($19) + ($39)|0);
      $41 = HEAP32[$40>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       if ($7) {
        label = 17;
       } else {
        $44 = (($2) + 12|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ($45>>>0)>($i>>>0);
        if (!($46)) {
         label = 17;
        }
       }
       if ((label|0) == 17) {
        __THREW__ = 0;
        $47 = (invoke_i(132)|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($47|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($2|0),($41|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if (!($53)) {
        $54 = HEAP32[$2>>2]|0;
        $55 = (($54) + 92|0);
        $56 = HEAP32[$55>>2]|0;
        $57 = Math_imul($56, $i)|0;
        $58 = (($19) + ($57)|0);
        HEAP32[$58>>2] = $41;
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if (!($60)) {
         if ($27) {
          label = 23;
         } else {
          $61 = (($2) + 12|0);
          $62 = HEAP32[$61>>2]|0;
          $63 = ($62>>>0)>($j>>>0);
          if (!($63)) {
           label = 23;
          }
         }
         if ((label|0) == 23) {
          __THREW__ = 0;
          $64 = (invoke_i(132)|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($64|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($2|0),($24|0));
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if (!($70)) {
          $71 = HEAP32[$2>>2]|0;
          $72 = (($71) + 92|0);
          $73 = HEAP32[$72>>2]|0;
          $74 = Math_imul($73, $j)|0;
          $75 = (($19) + ($74)|0);
          HEAP32[$75>>2] = $24;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z36mscorlib_System_Array_m_slow_swapperP21mscorlib_System_Arrayii($__this,$i,$j) {
 $__this = $__this|0;
 $i = $i|0;
 $j = $j|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225000);
 __THREW__ = 0;
 $0 = (invoke_iii(757,($__this|0),($i|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(759,($__this|0),($j|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viii(533,($__this|0),($3|0),($i|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(533,($__this|0),($0|0),($j|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z38mscorlib_System_Array_m_double_swapperP21mscorlib_System_Arrayii($__this,$i,$j) {
 $__this = $__this|0;
 $i = $i|0;
 $j = $j|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2224904);
 __THREW__ = 0;
 (invoke_ii(2996,(1218904|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($__this|0),(1218904|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($i|0)<(0);
     if ($7) {
      label = 6;
     } else {
      $8 = (($2) + 12|0);
      $9 = HEAP32[$8>>2]|0;
      $10 = ($9>>>0)>($i>>>0);
      if (!($10)) {
       label = 6;
      }
     }
     if ((label|0) == 6) {
      __THREW__ = 0;
      $11 = (invoke_i(132)|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($11|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
     $18 = HEAP32[$2>>2]|0;
     $19 = (($2) + 16|0);
     $20 = (($18) + 92|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = Math_imul($21, $i)|0;
     $23 = (($19) + ($22)|0);
     $24 = +HEAPF64[$23>>3];
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = ($j|0)<(0);
      if ($27) {
       label = 12;
      } else {
       $28 = (($2) + 12|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29>>>0)>($j>>>0);
       if (!($30)) {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       __THREW__ = 0;
       $31 = (invoke_i(132)|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($31|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
      }
      $36 = HEAP32[$2>>2]|0;
      $37 = (($36) + 92|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = Math_imul($38, $j)|0;
      $40 = (($19) + ($39)|0);
      $41 = +HEAPF64[$40>>3];
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       if ($7) {
        label = 17;
       } else {
        $44 = (($2) + 12|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = ($45>>>0)>($i>>>0);
        if (!($46)) {
         label = 17;
        }
       }
       if ((label|0) == 17) {
        __THREW__ = 0;
        $47 = (invoke_i(132)|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($47|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
       }
       $52 = HEAP32[$2>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $i)|0;
       $56 = (($19) + ($55)|0);
       HEAPF64[$56>>3] = $41;
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if (!($58)) {
        if (!($27)) {
         $59 = (($2) + 12|0);
         $60 = HEAP32[$59>>2]|0;
         $61 = ($60>>>0)>($j>>>0);
         if ($61) {
          $67 = HEAP32[$2>>2]|0;
          $68 = (($67) + 92|0);
          $69 = HEAP32[$68>>2]|0;
          $70 = Math_imul($69, $j)|0;
          $71 = (($19) + ($70)|0);
          HEAPF64[$71>>3] = $24;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
        __THREW__ = 0;
        $62 = (invoke_i(132)|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if (!($64)) {
         __THREW__ = 0;
         invoke_vi(3302,($62|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if (!($66)) {
          $67 = HEAP32[$2>>2]|0;
          $68 = (($67) + 92|0);
          $69 = HEAP32[$68>>2]|0;
          $70 = Math_imul($69, $j)|0;
          $71 = (($19) + ($70)|0);
          HEAPF64[$71>>3] = $24;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z31mscorlib_System_Array_m_new_gapP22mscorlib_System_Objecti($__this,$gap) {
 $__this = $__this|0;
 $gap = $gap|0;
 var $$ = 0, $$0 = 0, $$off = 0, $$off1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225528);
 $0 = ($gap*10)|0;
 $$off = (($0) + -117)|0;
 $1 = ($$off>>>0)>(12);
 $$off1 = (($0) + -130)|0;
 $2 = ($$off1>>>0)>(12);
 $or$cond = $1 & $2;
 if (!($or$cond)) {
  $$0 = 11;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($0|0) / 13)&-1;
 $4 = ($0|0)>(12);
 $$ = $4 ? $3 : 1;
 $$0 = $$;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z137mscorlib_System_Array_m_compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectS0_S0_S0_($__this,$value1,$value2,$comparer) {
 $__this = $__this|0;
 $value1 = $value1|0;
 $value2 = $value2|0;
 $comparer = $comparer|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225816);
 $0 = ($value1|0)==(0|0);
 $1 = ($value2|0)!=(0|0);
 if ($0) {
  $$ = $1 << 31 >> 31;
  $$0 = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 if (!($1)) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($comparer|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(2157896|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2755,($value1|0),(2157896|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(1649,(2157808|0),($5|0),($value2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $$0 = $10;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($comparer|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   $17 = (invoke_iiiii(318,(2311568|0),($comparer|0),($value1|0),($value2|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $$0 = $17;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z137mscorlib_System_Array_m_swap_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_ii($__this,$keys,$items,$i,$j) {
 $__this = $__this|0;
 $keys = $keys|0;
 $items = $items|0;
 $i = $i|0;
 $j = $j|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225768);
 __THREW__ = 0;
 invoke_vi(3799,($keys|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(757,($keys|0),($i|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($keys|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(759,($keys|0),($j|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3799,($keys|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      invoke_viii(533,($keys|0),($7|0),($i|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       invoke_vi(3799,($keys|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_viii(533,($keys|0),($2|0),($j|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if (!($17)) {
         $18 = ($items|0)==(0|0);
         if ($18) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         __THREW__ = 0;
         invoke_vi(3799,($items|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          $23 = (invoke_iii(757,($items|0),($i|0))|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           __THREW__ = 0;
           invoke_vi(3799,($items|0));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            $28 = (invoke_iii(757,($items|0),($j|0))|0);
            $29 = __THREW__; __THREW__ = 0;
            $30 = $29&1;
            if (!($30)) {
             __THREW__ = 0;
             invoke_vi(3799,($items|0));
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if (!($32)) {
              __THREW__ = 0;
              invoke_viii(533,($items|0),($28|0),($i|0));
              $33 = __THREW__; __THREW__ = 0;
              $34 = $33&1;
              if (!($34)) {
               __THREW__ = 0;
               invoke_vi(3799,($items|0));
               $35 = __THREW__; __THREW__ = 0;
               $36 = $35&1;
               if (!($36)) {
                __THREW__ = 0;
                invoke_viii(533,($items|0),($23|0),($j|0));
                $37 = __THREW__; __THREW__ = 0;
                $38 = $37&1;
                if (!($38)) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32P21mscorlib_System_ArrayS0_i($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225864);
 __THREW__ = 0;
 invoke_v(501);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3016136>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3016144>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,0,($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3016152>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3830,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3016160>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,0,($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3830,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,0,($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3016176>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,0,($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3016168>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3830,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int64P21mscorlib_System_ArrayS0_x($__this,$_____array,$0,$1) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225912);
 __THREW__ = 0;
 invoke_v(502);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($1>>>0)<(0);
   $5 = ($1|0)==(0);
   $6 = ($0>>>0)<(2147483648);
   $7 = $5 & $6;
   $8 = $4 | $7;
   if ($8) {
    __THREW__ = 0;
    invoke_viiii(461,(2225864|0),($__this|0),($_____array|0),($0|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $11 = HEAP32[3016200>>2]|0;
   __THREW__ = 0;
   $12 = (invoke_iii(783,0,($11|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2561352|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[3016192>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($17|0),($20|0),($12|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3830,($17|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z39mscorlib_System_Array_m_ConstrainedCopyP22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii($__this,$sourceArray,$sourceIndex,$destinationArray,$destinationIndex,$length) {
 $__this = $__this|0;
 $sourceArray = $sourceArray|0;
 $sourceIndex = $sourceIndex|0;
 $destinationArray = $destinationArray|0;
 $destinationIndex = $destinationIndex|0;
 $length = $length|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2225960);
 __THREW__ = 0;
 invoke_viiiiii(55,0,($sourceArray|0),($sourceIndex|0),($destinationArray|0),($destinationIndex|0),($length|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits27mscorlib_System_Int32TraitsE6InvokeEPFxPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN14ActionInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFvPvP22mscorlib_System_ObjectS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$2);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvP22mscorlib_System_ObjectiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$3);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S2_S2_E6InvokeEPFbPvS4_iS4_iiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$5,$8,$11)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFP22mscorlib_System_ObjectPviiES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker3I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFP22mscorlib_System_ObjectPviiiES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$4,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsE6InvokeEPFP22mscorlib_System_ObjectPvxES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsS1_E6InvokeEPFP22mscorlib_System_ObjectPvxxES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$3,$6,$11,$14)|0);
 STACKTOP = sp;return ($15|0);
}
function __ZN12FuncInvoker3I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsS1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvxxxES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$3,$6,$11,$14,$19,$22)|0);
 STACKTOP = sp;return ($23|0);
}
function __ZN14ActionInvoker2I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsE6InvokeEPFvPvP22mscorlib_System_ObjectxES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$5,$8);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsS1_E6InvokeEPFvPvP22mscorlib_System_ObjectxxES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$5,$8,$13,$16);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsS1_S1_E6InvokeEPFvPvP22mscorlib_System_ObjectxxxES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($args) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$action & 63]($obj,$0,$5,$8,$13,$16,$21,$24);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFvPvP22mscorlib_System_ObjectiiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$3,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFvPvP22mscorlib_System_ObjectiiiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$3,$6,$9);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFPvS3_S3_iiiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$3,$6,$9)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEPFiPvS4_P22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFiPvS4_P22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFiPvS4_iiP22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$3,$6,$8)|0);
 HEAP32[$ret>>2] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_28mscorlib_System_ObjectTraitsS1_E6InvokeEPFiPvS4_iiP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$6,$8,$10)|0);
 HEAP32[$ret>>2] = $11;
 $12 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN14ActionInvoker5I17VoidPointerTraits27mscorlib_System_Int64TraitsS0_S1_S1_E6InvokeEPFvPvS3_xS3_xxES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($args) + 16|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = $20;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 4)|0;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_viiiiiiiii[$action & 31]($obj,$0,$5,$8,$10,$15,$18,$23,$26);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int64TraitsE6InvokeEPFvPvS3_S3_xES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$2,$7,$10);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_E6InvokeEPFiPvS4_P22mscorlib_System_ObjectiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$5)|0);
 HEAP32[$ret>>2] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEPFiPvS4_P22mscorlib_System_ObjectiiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$5,$8)|0);
 HEAP32[$ret>>2] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN14ActionInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_E6InvokeEPFvPvS3_S3_iiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$2,$5,$8);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_E6InvokeEPFvPvS3_iiS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$3,$6,$8);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker5I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_S0_E6InvokeEPFvPvS3_S3_iiS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$2,$5,$8,$10);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS1_17VoidPointerTraitsE6InvokeEPFiPvP22mscorlib_System_ObjectS6_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits27mscorlib_System_Int64TraitsE6InvokeEPFvPvS3_xES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$5,$8);
 STACKTOP = sp;return (0|0);
}
function __Z52mscorlib_System_Array_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z109mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_System_Collections_IList_IndexOfP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_get_LengthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z91mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_get_LongLengthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_get_RankP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetLongLengthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetLowerBoundP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetUpperBoundP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z152mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z174mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z151mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z173mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z195mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z138mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_arr_arrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z159mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_arr_arrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z156mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z194mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Collections_IComparerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z200mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_ObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z238mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Collections_IComparerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_ClearP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z168mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z212mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z212mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int64_mscorlib_System_Array_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z168mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z151mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z173mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z195mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z155mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z177mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z199mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z127mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Reverse_mscorlib_System_Void_mscorlib_System_ArrayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z171mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Reverse_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z124mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_ArrayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z146mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_ArrayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z162mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Collections_IComparerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z168mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z184mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Collections_IComparerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z190mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z206mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z228mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,2,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z148mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_ConstrainedCopyP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z104mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_ArrayTraits_LongLength_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Collections_ICollection_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_Collections_IList_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2219784)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Collections_Generic_IList_1_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2219784)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z51mscorlib_System_Void_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z29mscorlib_System_Type_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233416);
 __THREW__ = 0;
 (invoke_ii(2996,(2242320|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = HEAP32[((2242320 + 80|0))>>2]|0;
   $6 = (($5) + 4|0);
   HEAP16[$6>>1] = 46;
   __THREW__ = 0;
   (invoke_ii(2996,(1169184|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2754,(1169184|0),0)|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = HEAP32[((2242320 + 80|0))>>2]|0;
      $15 = (($14) + 8|0);
      HEAP32[$15>>2] = $9;
      __THREW__ = 0;
      (invoke_ii(2996,(2660160|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_ii(3469,(2660160|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        HEAP32[$0>>2] = 2233464;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_viii(710,($18|0),(0|0),($$byval_copy2|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2242320|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          $25 = HEAP32[((2242320 + 80|0))>>2]|0;
          $26 = (($25) + 12|0);
          HEAP32[$26>>2] = $18;
          __THREW__ = 0;
          (invoke_ii(2996,(2660160|0))|0);
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           __THREW__ = 0;
           $29 = (invoke_ii(3469,(2660160|0))|0);
           $30 = __THREW__; __THREW__ = 0;
           $31 = $30&1;
           if (!($31)) {
            HEAP32[$1>>2] = 2233512;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
            invoke_viii(710,($29|0),(0|0),($$byval_copy2|0));
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if (!($33)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2242320|0))|0);
             $34 = __THREW__; __THREW__ = 0;
             $35 = $34&1;
             if (!($35)) {
              $36 = HEAP32[((2242320 + 80|0))>>2]|0;
              $37 = (($36) + 16|0);
              HEAP32[$37>>2] = $29;
              __THREW__ = 0;
              (invoke_ii(2996,(2660160|0))|0);
              $38 = __THREW__; __THREW__ = 0;
              $39 = $38&1;
              if (!($39)) {
               __THREW__ = 0;
               $40 = (invoke_ii(3469,(2660160|0))|0);
               $41 = __THREW__; __THREW__ = 0;
               $42 = $41&1;
               if (!($42)) {
                HEAP32[$2>>2] = 2233560;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
                invoke_viii(710,($40|0),(0|0),($$byval_copy2|0));
                $43 = __THREW__; __THREW__ = 0;
                $44 = $43&1;
                if (!($44)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2242320|0))|0);
                 $45 = __THREW__; __THREW__ = 0;
                 $46 = $45&1;
                 if (!($46)) {
                  $47 = HEAP32[((2242320 + 80|0))>>2]|0;
                  $48 = (($47) + 20|0);
                  HEAP32[$48>>2] = $40;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2414728|0))|0);
                  $49 = __THREW__; __THREW__ = 0;
                  $50 = $49&1;
                  if (!($50)) {
                   $51 = HEAP8[((2414728 + 116|0))>>0]|0;
                   $52 = ($51<<24>>24)==(0);
                   if ($52) {
                    __THREW__ = 0;
                    (invoke_ii(2996,(2414728|0))|0);
                    $53 = __THREW__; __THREW__ = 0;
                    $54 = $53&1;
                    if ($54) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2414728|0))|0);
                    $55 = __THREW__; __THREW__ = 0;
                    $56 = $55&1;
                    if ($56) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3831,(2414728|0));
                    $57 = __THREW__; __THREW__ = 0;
                    $58 = $57&1;
                    if ($58) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2414728|0))|0);
                   $61 = __THREW__; __THREW__ = 0;
                   $62 = $61&1;
                   if (!($62)) {
                    $63 = HEAP32[((2414728 + 80|0))>>2]|0;
                    $64 = HEAP32[$63>>2]|0;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2242320|0))|0);
                    $65 = __THREW__; __THREW__ = 0;
                    $66 = $65&1;
                    if ($66) {
                     break;
                    }
                    $67 = HEAP32[((2242320 + 80|0))>>2]|0;
                    $68 = (($67) + 24|0);
                    HEAP32[$68>>2] = $64;
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $59 = ___cxa_find_matching_catch()|0;
 $60 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($59|0);
 // unreachable;
}
function __Z38mscorlib_System_Type_m_FilterName_implP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoS0_($__this,$m,$filterCriteria) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233512);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2755,($filterCriteria|0),(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_ii(1816,($2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = ($10|0)==(0);
      if ($13) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       $16 = (invoke_ii(1816,($2|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         $21 = (($16) + -1)|0;
         __THREW__ = 0;
         $22 = (invoke_iii(621,($2|0),($21|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          $25 = ($22<<16>>16)==(42);
          if (!($25)) {
           __THREW__ = 0;
           invoke_vi(3799,($m|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            break;
           }
           __THREW__ = 0;
           $46 = (invoke_iii(2730,(2233608|0),($m|0))|0);
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if ($48) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($2|0));
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            break;
           }
           __THREW__ = 0;
           $51 = (invoke_iiii(1640,(2182184|0),($2|0),($46|0))|0);
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if ($53) {
            break;
           } else {
            $$0 = $51;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          invoke_vi(3799,($m|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           $28 = (invoke_iii(2730,(2233608|0),($m|0))|0);
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if (!($30)) {
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $31 = __THREW__; __THREW__ = 0;
            $32 = $31&1;
            if (!($32)) {
             __THREW__ = 0;
             $33 = (invoke_ii(1816,($2|0))|0);
             $34 = __THREW__; __THREW__ = 0;
             $35 = $34&1;
             if (!($35)) {
              __THREW__ = 0;
              $36 = (invoke_ii(1982,(0|0))|0);
              $37 = __THREW__; __THREW__ = 0;
              $38 = $37&1;
              if (!($38)) {
               $39 = (($33) + -1)|0;
               __THREW__ = 0;
               $40 = (invoke_iiiiiiiii(9,0,($2|0),0,($28|0),0,($39|0),0,($36|0))|0);
               $41 = __THREW__; __THREW__ = 0;
               $42 = $41&1;
               if (!($42)) {
                $43 = ($40|0)==(0);
                $$0 = $43;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Type_m_FilterNameIgnoreCase_implP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoS0_($__this,$m,$filterCriteria) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233560);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2755,($filterCriteria|0),(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_ii(1816,($2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = ($10|0)==(0);
      if ($13) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       $16 = (invoke_ii(1816,($2|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         $21 = (($16) + -1)|0;
         __THREW__ = 0;
         $22 = (invoke_iii(621,($2|0),($21|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          $25 = ($22<<16>>16)==(42);
          if (!($25)) {
           __THREW__ = 0;
           invoke_vi(3799,($m|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            break;
           }
           __THREW__ = 0;
           $46 = (invoke_iii(2730,(2233608|0),($m|0))|0);
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if ($48) {
            break;
           }
           __THREW__ = 0;
           $49 = (invoke_ii(1982,(0|0))|0);
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           if ($51) {
            break;
           }
           __THREW__ = 0;
           $52 = (invoke_iiiiii(86,0,($2|0),($46|0),1,($49|0))|0);
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if ($54) {
            break;
           }
           $55 = ($52|0)==(0);
           $$0 = $55;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          invoke_vi(3799,($m|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           $28 = (invoke_iii(2730,(2233608|0),($m|0))|0);
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if (!($30)) {
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $31 = __THREW__; __THREW__ = 0;
            $32 = $31&1;
            if (!($32)) {
             __THREW__ = 0;
             $33 = (invoke_ii(1816,($2|0))|0);
             $34 = __THREW__; __THREW__ = 0;
             $35 = $34&1;
             if (!($35)) {
              __THREW__ = 0;
              $36 = (invoke_ii(1982,(0|0))|0);
              $37 = __THREW__; __THREW__ = 0;
              $38 = $37&1;
              if (!($38)) {
               $39 = (($33) + -1)|0;
               __THREW__ = 0;
               $40 = (invoke_iiiiiiiii(9,0,($2|0),0,($28|0),0,($39|0),1,($36|0))|0);
               $41 = __THREW__; __THREW__ = 0;
               $42 = $41&1;
               if (!($42)) {
                $43 = ($40|0)==(0);
                $$0 = $43;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Type_m_FilterAttribute_implP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoS0_($__this,$m,$filterCriteria) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233464);
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2755,($filterCriteria|0),(2157656|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iiii(1652,(2156896|0),($2|0),(0|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2414216|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       $12 = (invoke_iii(2735,($m|0),(2414216|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = ($12|0)==(0|0);
        if (!($15)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2414216|0))|0);
         $18 = __THREW__; __THREW__ = 0;
         $19 = $18&1;
         if ($19) {
          break;
         }
         __THREW__ = 0;
         $20 = (invoke_iii(2755,($m|0),(2414216|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($20|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if ($24) {
          break;
         }
         __THREW__ = 0;
         $25 = (invoke_iii(2729,(2410224|0),($20|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         $28 = $25 & $7;
         $29 = ($28|0)!=(0);
         $$0 = $29;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2407016|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         __THREW__ = 0;
         $32 = (invoke_iii(2735,($m|0),(2407016|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          $35 = ($32|0)==(0|0);
          if (!($35)) {
           __THREW__ = 0;
           (invoke_ii(2996,(2407016|0))|0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break;
           }
           __THREW__ = 0;
           $38 = (invoke_iii(2755,($m|0),(2407016|0))|0);
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if ($40) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($38|0));
           $41 = __THREW__; __THREW__ = 0;
           $42 = $41&1;
           if ($42) {
            break;
           }
           __THREW__ = 0;
           $43 = (invoke_iii(2729,(2405552|0),($38|0))|0);
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            break;
           }
           $46 = $43 & $7;
           $47 = ($46|0)!=(0);
           $$0 = $47;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2434720|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if (!($49)) {
           __THREW__ = 0;
           $50 = (invoke_iii(2735,($m|0),(2434720|0))|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            $53 = ($50|0)==(0|0);
            if (!($53)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2434720|0))|0);
             $54 = __THREW__; __THREW__ = 0;
             $55 = $54&1;
             if ($55) {
              break;
             }
             __THREW__ = 0;
             $56 = (invoke_iii(2755,($m|0),(2434720|0))|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($56|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
             __THREW__ = 0;
             $61 = (invoke_iii(2729,(2434224|0),($56|0))|0);
             $62 = __THREW__; __THREW__ = 0;
             $63 = $62&1;
             if ($63) {
              break;
             }
             $64 = $61 & $7;
             $65 = ($64|0)!=(0);
             $$0 = $65;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2404168|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if (!($67)) {
             __THREW__ = 0;
             $68 = (invoke_iii(2735,($m|0),(2404168|0))|0);
             $69 = __THREW__; __THREW__ = 0;
             $70 = $69&1;
             if (!($70)) {
              $71 = ($68|0)==(0|0);
              if ($71) {
               $$0 = 0;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2404168|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if (!($73)) {
               __THREW__ = 0;
               $74 = (invoke_iii(2755,($m|0),(2404168|0))|0);
               $75 = __THREW__; __THREW__ = 0;
               $76 = $75&1;
               if (!($76)) {
                __THREW__ = 0;
                invoke_vi(3799,($74|0));
                $77 = __THREW__; __THREW__ = 0;
                $78 = $77&1;
                if (!($78)) {
                 __THREW__ = 0;
                 $79 = (invoke_iii(2729,(2403880|0),($74|0))|0);
                 $80 = __THREW__; __THREW__ = 0;
                 $81 = $80&1;
                 if ($81) {
                  break;
                 }
                 $82 = $79 & $7;
                 $83 = ($82|0)!=(0);
                 $$0 = $83;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Type_m_get_AttributesP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233656);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2233704|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z40mscorlib_System_Type_m_get_DeclaringTypeP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233752);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z41mscorlib_System_Type_m_get_HasElementTypeP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233800);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2233848|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z37mscorlib_System_Type_m_get_IsAbstractP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233896);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2233656|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 128;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z34mscorlib_System_Type_m_get_IsArrayP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2233944);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2233992|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z34mscorlib_System_Type_m_get_IsByRefP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234040);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2234088|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z34mscorlib_System_Type_m_get_IsClassP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234136);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2234184|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  if ($0) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $5 = (invoke_iii(2734,(2234232|0),($__this|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = $5 ^ 1;
   $$0 = $8;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Type_m_get_IsContextfulP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234280);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2234328|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z33mscorlib_System_Type_m_get_IsEnumP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2215792);
 HEAP32[$0>>2] = 2269384;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,0,($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1640,(2234376|0),($__this|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Type_m_get_IsExplicitLayoutP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234424);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2233656|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 24;
  $4 = ($3|0)==(16);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z38mscorlib_System_Type_m_get_IsInterfaceP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234184);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2233656|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 32;
  $4 = ($3|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z41mscorlib_System_Type_m_get_IsMarshalByRefP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234472);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2234520|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z36mscorlib_System_Type_m_get_IsPointerP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234568);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2234616|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z38mscorlib_System_Type_m_get_IsPrimitiveP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234664);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2234712|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z35mscorlib_System_Type_m_get_IsSealedP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234760);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2233656|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 256;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z38mscorlib_System_Type_m_get_IsValueTypeP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234232);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2234808|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z37mscorlib_System_Type_m_get_MemberTypeP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234856);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 32;
}
function __Z40mscorlib_System_Type_m_get_ReflectedTypeP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234904);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z37mscorlib_System_Type_m_get_TypeHandleP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234952);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z76mscorlib_System_Type_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235000);
 $0 = ($o|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2242320|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2735,($o|0),(2242320|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $9 = (invoke_iiii(1640,(2223400|0),($__this|0),($3|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Type_m_Equals_mscorlib_System_Boolean_mscorlib_System_TypeP20mscorlib_System_TypeS0_($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223400);
 $0 = ($o|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iii(2730,(2223352|0),($__this|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3799,($o|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2730,(2223352|0),($o|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(3799,($1|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iii(767,($1|0),($6|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $$0 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Type_m_EqualsInternalP20mscorlib_System_TypeS0_($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235048);
 $0 = HEAP32[2235096>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2235104|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2235096>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Type_m_internal_from_handleP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235152);
 $1 = HEAP32[2235200>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2235208|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2235200>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $10 = (invoke_ii($9|0,($$byval_copy|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __Z41mscorlib_System_Type_m_internal_from_nameP22mscorlib_System_ObjectP22mscorlib_System_Stringbb($__this,$name,$throwOnError,$ignoreCase) {
 $__this = $__this|0;
 $name = $name|0;
 $throwOnError = $throwOnError|0;
 $ignoreCase = $ignoreCase|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235264);
 $0 = HEAP32[2235312>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2235320|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2235312>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($name|0),($throwOnError|0),($ignoreCase|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z30mscorlib_System_Type_m_GetTypeP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$typeName) {
 $__this = $__this|0;
 $typeName = $typeName|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235400);
 __THREW__ = 0;
 invoke_v(503);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($typeName|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iiiii(118,0,($typeName|0),0,0)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016656>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_Type_m_GetTypeCodeInternalP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235448);
 $0 = HEAP32[2235496>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2235504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2235496>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_RuntimeTypeHandle_m_get_ValueP33mscorlib_System_RuntimeTypeHandle($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2247048);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z36mscorlib_System_Type_m_GetTypeHandleP22mscorlib_System_ObjectS0_($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235648);
 $0 = ($o|0)==(0|0);
 if ($0) {
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(3469,(2560584|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(2585,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3830,($3|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      // unreachable;
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($o|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_ii(1782,($o|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_vi(3799,($14|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     $19 = (invoke_iii(2757,(2234952|0),($14|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($19|0);
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker0I39mscorlib_System_RuntimeTypeHandleTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z41mscorlib_System_Type_m_type_is_subtype_ofP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_b($__this,$a,$b,$check_interfaces) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 $check_interfaces = $check_interfaces|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235696);
 $0 = HEAP32[2235744>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2235752|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2235744>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($a|0),($b|0),($check_interfaces|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Type_m_type_is_assignable_fromP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235824);
 $0 = HEAP32[2235872>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2235880|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2235872>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($a|0),($b|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_Type_m_IsSubclassOfP20mscorlib_System_TypeS0_($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$in = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234376);
 $0 = ($c|0)==(0|0);
 $1 = ($c|0)==($__this|0);
 $or$cond = $0 | $1;
 L1: do {
  if ($or$cond) {
   $$0 = 0;
  } else {
   __THREW__ = 0;
   $2 = (invoke_ii(1892,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   do {
    if (!($4)) {
     if ($2) {
      __THREW__ = 0;
      invoke_vi(3799,($c|0));
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      $11 = (invoke_ii(1892,($c|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       $$0 = 0;
       break L1;
      }
      __THREW__ = 0;
      $14 = (invoke_iiiii(119,0,($__this|0),($c|0),0)|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      } else {
       $$0 = $14;
       break L1;
      }
     }
     __THREW__ = 0;
     $17 = (invoke_iii(2730,(2235944|0),($__this|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $V_0$0$in = $17;
      while(1) {
       $25 = ($V_0$0$in|0)==(0|0);
       if ($25) {
        $$0 = 0;
        break L1;
       }
       $26 = ($V_0$0$in|0)==($c|0);
       if ($26) {
        $$0 = 1;
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_0$0$in|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       __THREW__ = 0;
       $22 = (invoke_iii(2730,(2235944|0),($V_0$0$in|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       } else {
        $V_0$0$in = $22;
       }
      }
      $5 = ___cxa_find_matching_catch()|0;
      $6 = tempRet0;
      $lpad$phi$index = $5;$lpad$phi$index2 = $6;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    }
   } while(0);
   $7 = ___cxa_find_matching_catch()|0;
   $8 = tempRet0;
   $lpad$phi$index = $7;$lpad$phi$index2 = $8;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z39mscorlib_System_Type_m_IsAssignableFromP20mscorlib_System_TypeS0_($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2235992);
 $0 = ($c|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(1640,(2223400|0),($__this|0),($c|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   if ($1) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2374224|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2735,($c|0),(2374224|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = ($8|0)==(0|0);
     if (!($11)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2374224|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      $14 = (invoke_iii(2755,($c|0),(2374224|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($14|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      $19 = (invoke_iii(902,($14|0),($__this|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      } else {
       $$0 = $19;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $22 = (invoke_ii(1892,($__this|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      if (!($22)) {
       __THREW__ = 0;
       $25 = (invoke_iii(2730,(2223352|0),($__this|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($25|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
       __THREW__ = 0;
       $30 = (invoke_ii(1892,($25|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
       if (!($30)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($25|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       }
       __THREW__ = 0;
       $35 = (invoke_iiii(1640,(2235992|0),($25|0),($c|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       } else {
        $$0 = $35;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($c|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       __THREW__ = 0;
       $40 = (invoke_ii(1892,($c|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        if ($40) {
         __THREW__ = 0;
         $56 = (invoke_iiii(716,0,($__this|0),($c|0))|0);
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break;
         } else {
          $$0 = $56;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($c|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if (!($44)) {
         __THREW__ = 0;
         $45 = (invoke_iii(2730,(2223352|0),($c|0))|0);
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if (!($47)) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if (!($49)) {
           __THREW__ = 0;
           $50 = (invoke_ii(1892,($45|0))|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            if (!($50)) {
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            $53 = (invoke_iiii(1640,(2235992|0),($__this|0),($45|0))|0);
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if (!($55)) {
             $$0 = $53;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Type_m_IsInstanceOfTypeP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236040);
 $0 = HEAP32[2236088>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2236096|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2236088>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($o|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Type_m_GetFields_mscorlib_System_Reflection_FieldInfo_arr_arrP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236144);
 __THREW__ = 0;
 $0 = (invoke_iiii(1642,(2236192|0),($__this|0),28)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z34mscorlib_System_Type_m_GetHashCodeP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236240);
 __THREW__ = 0;
 $1 = (invoke_iii(2730,(2223352|0),($__this|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($1|0)==(0|0);
   $5 = ($1|0)==($__this|0);
   $or$cond = $4 | $5;
   if ($or$cond) {
    $13 = (($__this) + 8|0);
    __THREW__ = 0;
    $14 = (invoke_ii(1914,($13|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    HEAP32[$0>>2] = $14;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (invoke_iii(717,0,($$byval_copy|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    } else {
     $$0 = $17;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($1|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iii(2729,(2236240|0),($1|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    } else {
     $$0 = $10;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Type_m_GetMethod_mscorlib_System_Reflection_MethodInfo_mscorlib_System_StringP20mscorlib_System_TypeP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236288);
 __THREW__ = 0;
 invoke_v(504);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iiiiiiiii(46,(2236336|0),($__this|0),($name|0),28,(0|0),3,(0|0),(0|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016688>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker6I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S1_S0_S0_E6InvokeEP10MethodInfoPvS5_iS5_iS5_S5_($method,$obj,$p1,$p2,$p3,$p4,$p5,$p6) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 $p6 = $p6|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiiii[$3 & 127]($4,$p1,$p2,$p3,$p4,$p5,$p6)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z133mscorlib_System_Type_m_GetMethod_mscorlib_System_Reflection_MethodInfo_mscorlib_System_String_mscorlib_System_Reflection_BindingFlagsP20mscorlib_System_TypeP22mscorlib_System_Stringi($__this,$name,$bindingAttr) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236384);
 __THREW__ = 0;
 invoke_v(505);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iiiiiiiii(46,(2236336|0),($__this|0),($name|0),($bindingAttr|0),(0|0),3,(0|0),(0|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016712>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z249mscorlib_System_Type_m_GetMethod_mscorlib_System_Reflection_MethodInfo_mscorlib_System_String_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236432);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiiii(46,(2236480|0),($__this|0),($name|0),($bindingAttr|0),($binder|0),3,($types|0),($modifiers|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z295mscorlib_System_Type_m_GetMethod_mscorlib_System_Reflection_MethodInfo_mscorlib_System_String_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Reflection_CallingConventions_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236480);
 __THREW__ = 0;
 invoke_v(506);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3016728>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($types|0)==(0|0);
   if ($17) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3016736>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $18 = (($types) + 12|0);
   $19 = (($types) + 16|0);
   $V_0$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($types|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 3;
     break;
    }
    $57 = HEAP32[$18>>2]|0;
    $58 = ($V_0$0|0)<($57|0);
    if (!($58)) {
     label = 30;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($types|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 3;
     break;
    }
    $30 = HEAP32[$18>>2]|0;
    $31 = ($V_0$0>>>0)<($30>>>0);
    if (!($31)) {
     __THREW__ = 0;
     $32 = (invoke_i(132)|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($32|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 3;
      break;
     }
    }
    $37 = HEAP32[$types>>2]|0;
    $38 = (($37) + 92|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = Math_imul($39, $V_0$0)|0;
    $41 = (($19) + ($40)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    $44 = (($V_0$0) + 1)|0;
    if ($43) {
     label = 22;
     break;
    } else {
     $V_0$0 = $44;
    }
   }
   if ((label|0) == 3) {
    $3 = ___cxa_find_matching_catch()|0;
    $4 = tempRet0;
    $lpad$phi$index = $3;$lpad$phi$index2 = $4;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 22) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    __THREW__ = 0;
    $47 = (invoke_ii(3469,(2560584|0))|0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    $50 = HEAP32[3016744>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($47|0),($50|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($47|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 30) {
    __THREW__ = 0;
    $61 = (invoke_iiiiiiiii(46,(2236336|0),($__this|0),($name|0),($bindingAttr|0),($binder|0),($callConvention|0),($types|0),($modifiers|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($61|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Type_m_GetProperties_mscorlib_System_Reflection_PropertyInfo_arr_arrP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236528);
 __THREW__ = 0;
 $0 = (invoke_iiii(1642,(2236576|0),($__this|0),28)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z118mscorlib_System_Type_m_GetProperty_mscorlib_System_Reflection_PropertyInfo_mscorlib_System_String_mscorlib_System_TypeP20mscorlib_System_TypeP22mscorlib_System_StringS0_($__this,$name,$returnType) {
 $__this = $__this|0;
 $name = $name|0;
 $returnType = $returnType|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236624);
 __THREW__ = 0;
 invoke_v(507);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iiiiiiiii(47,(2236672|0),($__this|0),($name|0),28,(0|0),($returnType|0),(0|0),(0|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016776>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker6I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEP10MethodInfoPvS5_iS5_S5_S5_S5_($method,$obj,$p1,$p2,$p3,$p4,$p5,$p6) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 $p6 = $p6|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiiii[$3 & 127]($4,$p1,$p2,$p3,$p4,$p5,$p6)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z147mscorlib_System_Type_m_GetProperty_mscorlib_System_Reflection_PropertyInfo_mscorlib_System_String_mscorlib_System_Type_mscorlib_System_Type_arr_arrP20mscorlib_System_TypeP22mscorlib_System_StringS0_P24mscorlib_System_Type_arr($__this,$name,$returnType,$types) {
 $__this = $__this|0;
 $name = $name|0;
 $returnType = $returnType|0;
 $types = $types|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236720);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiiii(47,(2236768|0),($__this|0),($name|0),28,(0|0),($returnType|0),($types|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z274mscorlib_System_Type_m_GetProperty_mscorlib_System_Reflection_PropertyInfo_mscorlib_System_String_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Type_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderS0_P24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$returnType,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $returnType = $returnType|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236768);
 __THREW__ = 0;
 invoke_v(508);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3016792>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($types|0)==(0|0);
   if ($17) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3016800>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $18 = (($types) + 12|0);
   $19 = (($types) + 16|0);
   $V_2$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($types|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 3;
     break;
    }
    $57 = HEAP32[$18>>2]|0;
    $58 = ($V_2$0|0)<($57|0);
    if (!($58)) {
     label = 30;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($types|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     label = 3;
     break;
    }
    $30 = HEAP32[$18>>2]|0;
    $31 = ($V_2$0>>>0)<($30>>>0);
    if (!($31)) {
     __THREW__ = 0;
     $32 = (invoke_i(132)|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($32|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 3;
      break;
     }
    }
    $37 = HEAP32[$types>>2]|0;
    $38 = (($37) + 92|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = Math_imul($39, $V_2$0)|0;
    $41 = (($19) + ($40)|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($42|0)==(0|0);
    $44 = (($V_2$0) + 1)|0;
    if ($43) {
     label = 22;
     break;
    } else {
     $V_2$0 = $44;
    }
   }
   if ((label|0) == 3) {
    $3 = ___cxa_find_matching_catch()|0;
    $4 = tempRet0;
    $lpad$phi$index = $3;$lpad$phi$index2 = $4;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 22) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    __THREW__ = 0;
    $47 = (invoke_ii(3469,(2560584|0))|0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    $50 = HEAP32[3016808>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($47|0),($50|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($47|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 30) {
    __THREW__ = 0;
    $61 = (invoke_iiiiiiiii(47,(2236672|0),($__this|0),($name|0),($bindingAttr|0),($binder|0),($returnType|0),($types|0),($modifiers|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($61|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Type_m_IsArrayImpl_mscorlib_System_Boolean_mscorlib_System_TypeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236816);
 $0 = HEAP32[2236864>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2236872|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2236864>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_Type_m_IsValueTypeImplP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234808);
 HEAP32[$0>>2] = 2269376;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(772,0,($$byval_copy2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = ($3|0)==($__this|0);
  if ($6) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$1>>2] = 2269384;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $9 = (invoke_iii(772,0,($$byval_copy2|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = ($9|0)==($__this|0);
   if ($12) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$2>>2] = 2269376;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
   $13 = (invoke_iii(772,0,($$byval_copy2|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __THREW__ = 0;
    $16 = (invoke_iiii(1640,(2234376|0),($__this|0),($13|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $$0 = $16;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Type_m_IsContextfulImplP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234328);
 HEAP32[$0>>2] = 2269368;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,0,($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iiii(1640,(2235992|0),($1|0),($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_Type_m_IsMarshalByRefImplP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2234520);
 HEAP32[$0>>2] = 2266512;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,0,($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iiii(1640,(2235992|0),($1|0),($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z236mscorlib_System_Type_m_GetConstructor_mscorlib_System_Reflection_ConstructorInfo_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeiP33mscorlib_System_Reflection_BinderP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$bindingAttr,$binder,$types,$modifiers) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236912);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(118,(2236960|0),($__this|0),($bindingAttr|0),($binder|0),3,($types|0),($modifiers|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_S0_S0_E6InvokeEP10MethodInfoPviS5_iS5_S5_($method,$obj,$p1,$p2,$p3,$p4,$p5) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4,$p5)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z282mscorlib_System_Type_m_GetConstructor_mscorlib_System_Reflection_ConstructorInfo_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Reflection_CallingConventions_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2236960);
 __THREW__ = 0;
 invoke_v(509);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($types|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3016824>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $3 = (($types) + 12|0);
   $4 = (($types) + 16|0);
   $V_2$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($types|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     label = 4;
     break;
    }
    $46 = HEAP32[$3>>2]|0;
    $47 = ($V_2$0|0)<($46|0);
    if (!($47)) {
     label = 24;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($types|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 4;
     break;
    }
    $19 = HEAP32[$3>>2]|0;
    $20 = ($V_2$0>>>0)<($19>>>0);
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_i(132)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($21|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 4;
      break;
     }
    }
    $26 = HEAP32[$types>>2]|0;
    $27 = (($26) + 92|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = Math_imul($28, $V_2$0)|0;
    $30 = (($4) + ($29)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    $33 = (($V_2$0) + 1)|0;
    if ($32) {
     label = 16;
     break;
    } else {
     $V_2$0 = $33;
    }
   }
   if ((label|0) == 4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    $lpad$phi$index = $5;$lpad$phi$index2 = $6;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 16) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    __THREW__ = 0;
    $36 = (invoke_ii(3469,(2560584|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    $39 = HEAP32[3016832>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($36|0),($39|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($36|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 24) {
    __THREW__ = 0;
    $50 = (invoke_iiiiiiii(118,(2237008|0),($__this|0),($bindingAttr|0),($binder|0),($callConvention|0),($types|0),($modifiers|0))|0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($50|0);
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z31mscorlib_System_Type_m_ToStringP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2149160);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2150320|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z42mscorlib_System_Type_m_GetGenericArgumentsP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237104);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3830,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Type_m_get_ContainsGenericParametersP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2223448);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z50mscorlib_System_Type_m_get_IsGenericTypeDefinitionP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237152);
 $0 = HEAP32[2237200>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2237208|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2237200>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Type_m_GetGenericTypeDefinition_implP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237256);
 $0 = HEAP32[2237304>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2237312|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2237304>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_Type_m_GetGenericTypeDefinitionP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237360);
 __THREW__ = 0;
 invoke_v(510);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3016848>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3830,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Type_m_get_IsGenericTypeP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237408);
 $0 = HEAP32[2237456>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2237464|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2237456>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Type_m_MakeGenericType_mscorlib_System_Type_mscorlib_System_Type_mscorlib_System_Type_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP24mscorlib_System_Type_arr($__this,$gt,$types) {
 $__this = $__this|0;
 $gt = $gt|0;
 $types = $types|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237504);
 $0 = HEAP32[2237552>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2237560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2237552>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($gt|0),($types|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Type_m_MakeGenericType_mscorlib_System_Type_mscorlib_System_Type_arr_arrP20mscorlib_System_TypeP24mscorlib_System_Type_arr($__this,$typeArguments) {
 $__this = $__this|0;
 $typeArguments = $typeArguments|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_11 = 0, $L_15 = 0, $V_1$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_11 = sp;
 $L_15 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237616);
 __THREW__ = 0;
 invoke_v(511);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2734,(2237152|0),($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if (!($2)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2607872|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2607872|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3016960>>2]|0;
     __THREW__ = 0;
     invoke_vii(1947,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    $19 = ($typeArguments|0)==(0|0);
    if ($19) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560584|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     $22 = (invoke_ii(3469,(2560584|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     $25 = HEAP32[3016968>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($22|0),($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3830,($22|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $30 = (invoke_iii(2730,(2237104|0),($__this|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     __THREW__ = 0;
     invoke_vi(3799,($30|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $35 = (($30) + 12|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($typeArguments|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = (($typeArguments) + 12|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = ($36|0)==($40|0);
       if (!($41)) {
        __THREW__ = 0;
        $42 = (invoke_iii(2730,(2237104|0),($__this|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($42|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        $47 = (($42) + 12|0);
        $48 = HEAP32[$47>>2]|0;
        HEAP32[$L_11>>2] = $48;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        $51 = (invoke_iii(2724,(2155952|0),($L_11|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($typeArguments|0));
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         break;
        }
        $56 = HEAP32[$39>>2]|0;
        HEAP32[$L_15>>2] = $56;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break;
        }
        __THREW__ = 0;
        $59 = (invoke_iii(2724,(2155952|0),($L_15|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         break;
        }
        $62 = HEAP32[3016976>>2]|0;
        __THREW__ = 0;
        $63 = (invoke_iiiii(98,0,($62|0),($51|0),($59|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
        __THREW__ = 0;
        $68 = (invoke_ii(3469,(2560072|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
        $71 = HEAP32[3016984>>2]|0;
        __THREW__ = 0;
        invoke_viii(641,($68|0),($63|0),($71|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3830,($68|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        // unreachable;
       }
       __THREW__ = 0;
       invoke_vi(3799,($typeArguments|0));
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if (!($77)) {
        $78 = HEAP32[$39>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(1169184|0))|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if (!($80)) {
         __THREW__ = 0;
         $81 = (invoke_iii(2754,(1169184|0),($78|0))|0);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if (!($83)) {
          $84 = (($typeArguments) + 16|0);
          $85 = (($81) + 16|0);
          $86 = (($81) + 12|0);
          $V_1$0 = 0;
          L39: while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($typeArguments|0));
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            label = 4;
            break;
           }
           $163 = HEAP32[$39>>2]|0;
           $164 = ($V_1$0|0)<($163|0);
           if (!($164)) {
            label = 75;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($typeArguments|0));
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            label = 4;
            break;
           }
           $87 = HEAP32[$39>>2]|0;
           $88 = ($V_1$0>>>0)<($87>>>0);
           if (!($88)) {
            __THREW__ = 0;
            $89 = (invoke_i(132)|0);
            $90 = __THREW__; __THREW__ = 0;
            $91 = $90&1;
            if ($91) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($89|0));
            $92 = __THREW__; __THREW__ = 0;
            $93 = $92&1;
            if ($93) {
             label = 4;
             break;
            }
           }
           $94 = HEAP32[$typeArguments>>2]|0;
           $95 = (($94) + 92|0);
           $96 = HEAP32[$95>>2]|0;
           $97 = Math_imul($96, $V_1$0)|0;
           $98 = (($84) + ($97)|0);
           $99 = HEAP32[$98>>2]|0;
           $100 = ($99|0)==(0|0);
           if ($100) {
            label = 43;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2360152|0))|0);
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           $113 = (invoke_iii(2735,($99|0),(2360152|0))|0);
           $114 = __THREW__; __THREW__ = 0;
           $115 = $114&1;
           if ($115) {
            label = 4;
            break;
           }
           $116 = ($113|0)==(0|0);
           do {
            if ($116) {
             __THREW__ = 0;
             (invoke_ii(2996,(2374224|0))|0);
             $117 = __THREW__; __THREW__ = 0;
             $118 = $117&1;
             if ($118) {
              label = 4;
              break L39;
             }
             __THREW__ = 0;
             $119 = (invoke_iii(2735,($99|0),(2374224|0))|0);
             $120 = __THREW__; __THREW__ = 0;
             $121 = $120&1;
             if ($121) {
              label = 4;
              break L39;
             }
             $122 = ($119|0)==(0|0);
             if (!($122)) {
              $V_2$0 = $99;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($99|0));
             $123 = __THREW__; __THREW__ = 0;
             $124 = $123&1;
             if ($124) {
              label = 4;
              break L39;
             }
             __THREW__ = 0;
             $125 = (invoke_iii(2730,(2223352|0),($99|0))|0);
             $126 = __THREW__; __THREW__ = 0;
             $127 = $126&1;
             if ($127) {
              label = 4;
              break L39;
             }
             $V_2$0 = $125;
            } else {
             $V_2$0 = $99;
            }
           } while(0);
           $128 = ($V_2$0|0)==(0|0);
           if ($128) {
            label = 61;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($V_2$0|0));
           $129 = __THREW__; __THREW__ = 0;
           $130 = $129&1;
           if ($130) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           $131 = (invoke_ii(1892,($V_2$0|0))|0);
           $132 = __THREW__; __THREW__ = 0;
           $133 = $132&1;
           if ($133) {
            label = 4;
            break;
           }
           if (!($131)) {
            label = 61;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($81|0));
           $144 = __THREW__; __THREW__ = 0;
           $145 = $144&1;
           if ($145) {
            label = 4;
            break;
           }
           $146 = HEAP32[$86>>2]|0;
           $147 = ($V_1$0>>>0)<($146>>>0);
           if (!($147)) {
            __THREW__ = 0;
            $148 = (invoke_i(132)|0);
            $149 = __THREW__; __THREW__ = 0;
            $150 = $149&1;
            if ($150) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($148|0));
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            if ($152) {
             label = 4;
             break;
            }
           }
           __THREW__ = 0;
           invoke_vii(3492,($81|0),($V_2$0|0));
           $153 = __THREW__; __THREW__ = 0;
           $154 = $153&1;
           if ($154) {
            label = 4;
            break;
           }
           $155 = HEAP32[$81>>2]|0;
           $156 = (($155) + 92|0);
           $157 = HEAP32[$156>>2]|0;
           $158 = Math_imul($157, $V_1$0)|0;
           $159 = (($85) + ($158)|0);
           HEAP32[$159>>2] = $V_2$0;
           $160 = (($V_1$0) + 1)|0;
           $V_1$0 = $160;
          }
          if ((label|0) == 4) {
           $5 = ___cxa_find_matching_catch()|0;
           $6 = tempRet0;
           $lpad$phi$index = $5;$lpad$phi$index2 = $6;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 43) {
           __THREW__ = 0;
           (invoke_ii(2996,(2560584|0))|0);
           $101 = __THREW__; __THREW__ = 0;
           $102 = $101&1;
           if ($102) {
            break;
           }
           __THREW__ = 0;
           $103 = (invoke_ii(3469,(2560584|0))|0);
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            break;
           }
           $106 = HEAP32[3016992>>2]|0;
           __THREW__ = 0;
           invoke_vii(1925,($103|0),($106|0));
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if ($108) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3830,($103|0));
           $109 = __THREW__; __THREW__ = 0;
           $110 = $109&1;
           if ($110) {
            break;
           }
           // unreachable;
          }
          else if ((label|0) == 61) {
           __THREW__ = 0;
           (invoke_ii(2996,(2560584|0))|0);
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if ($135) {
            break;
           }
           __THREW__ = 0;
           $136 = (invoke_ii(3469,(2560584|0))|0);
           $137 = __THREW__; __THREW__ = 0;
           $138 = $137&1;
           if ($138) {
            break;
           }
           $139 = HEAP32[3017000>>2]|0;
           __THREW__ = 0;
           invoke_vii(1925,($136|0),($139|0));
           $140 = __THREW__; __THREW__ = 0;
           $141 = $140&1;
           if ($141) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3830,($136|0));
           $142 = __THREW__; __THREW__ = 0;
           $143 = $142&1;
           if ($143) {
            break;
           }
           // unreachable;
          }
          else if ((label|0) == 75) {
           __THREW__ = 0;
           $167 = (invoke_iiii(724,0,($__this|0),($81|0))|0);
           $168 = __THREW__; __THREW__ = 0;
           $169 = $168&1;
           if ($169) {
            break;
           }
           $170 = ($167|0)==(0|0);
           if (!($170)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($167|0);
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2657288|0))|0);
           $171 = __THREW__; __THREW__ = 0;
           $172 = $171&1;
           if ($172) {
            break;
           }
           __THREW__ = 0;
           $173 = (invoke_ii(3469,(2657288|0))|0);
           $174 = __THREW__; __THREW__ = 0;
           $175 = $174&1;
           if ($175) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(2791,($173|0));
           $176 = __THREW__; __THREW__ = 0;
           $177 = $176&1;
           if ($177) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3830,($173|0));
           $178 = __THREW__; __THREW__ = 0;
           $179 = $178&1;
           if ($179) {
            break;
           }
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_Type_m_get_IsGenericParameterP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237664);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z35mscorlib_System_Type_m_get_IsNestedP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237712);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2233752|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0|0)!=(0|0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z48mscorlib_System_Type_m_GetPseudoCustomAttributesP20mscorlib_System_Type($__this) {
 $__this = $__this|0;
 var $$$ = 0, $$0 = 0, $$lobit = 0, $$lobit4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $V_0$2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2237760);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2233656|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2729,(2233656|0),($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $8 = $0 >>> 13;
    $$lobit = $8 & 1;
    $9 = $3 >>> 12;
    $$lobit4 = $9 & 1;
    $$$ = (($$lobit4) + ($$lobit))|0;
    $10 = ($$$|0)==(0);
    if ($10) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_iii(2754,(1167664|0),($$$|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_iii(2729,(2233656|0),($__this|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = $16 & 8192;
       $20 = ($19|0)==(0);
       if ($20) {
        $V_0$2 = 0;
       } else {
        __THREW__ = 0;
        (invoke_ii(2996,(2158528|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if ($22) {
         break;
        }
        __THREW__ = 0;
        $23 = (invoke_ii(3469,(2158528|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(1938,($23|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($13|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         break;
        }
        $30 = (($13) + 12|0);
        $31 = HEAP32[$30>>2]|0;
        $32 = ($31|0)==(0);
        if ($32) {
         __THREW__ = 0;
         $33 = (invoke_i(132)|0);
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($33|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($13|0),($23|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
        $40 = (($13) + 16|0);
        HEAP32[$40>>2] = $23;
        $V_0$2 = 1;
       }
       __THREW__ = 0;
       $41 = (invoke_iii(2729,(2233656|0),($__this|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if (!($43)) {
        $44 = $41 & 4096;
        $45 = ($44|0)==(0);
        if ($45) {
         $$0 = $13;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2250248|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if (!($47)) {
         __THREW__ = 0;
         $48 = (invoke_ii(3469,(2250248|0))|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if (!($50)) {
          __THREW__ = 0;
          invoke_vi(2105,($48|0));
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if (!($52)) {
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if (!($54)) {
            $55 = (($13) + 12|0);
            $56 = HEAP32[$55>>2]|0;
            $57 = ($V_0$2>>>0)<($56>>>0);
            if (!($57)) {
             __THREW__ = 0;
             $58 = (invoke_i(132)|0);
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($58|0));
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($13|0),($48|0));
            $63 = __THREW__; __THREW__ = 0;
            $64 = $63&1;
            if (!($64)) {
             $65 = HEAP32[$13>>2]|0;
             $66 = (($13) + 16|0);
             $67 = (($65) + 92|0);
             $68 = HEAP32[$67>>2]|0;
             $69 = (0 - ($V_0$2))|0;
             $70 = $68 & $69;
             $71 = (($66) + ($70)|0);
             HEAP32[$71>>2] = $48;
             $$0 = $13;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Runtime_InteropServices_ComImportAttribute_m__ctorP58mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2250112);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEPFbPvS4_P22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 $4 = $3&1;
 HEAP8[$ret>>0] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker0I39mscorlib_System_RuntimeTypeHandleTraitsE6InvokeEPF33mscorlib_System_RuntimeTypeHandlePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP32[$ret>>2] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2247448,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFPvS3_S3_bbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$4,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits39mscorlib_System_RuntimeTypeHandleTraitsE6InvokeEPFPvS3_33mscorlib_System_RuntimeTypeHandleES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I39mscorlib_System_RuntimeTypeHandleTraits28mscorlib_System_ObjectTraitsE6InvokeEPF33mscorlib_System_RuntimeTypeHandlePvP22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2247448,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker5I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEPFPvS3_S3_iS3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$5,$7,$9)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12FuncInvoker6I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S1_S0_S0_E6InvokeEPFPvS3_S3_iS3_iS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$5,$8,$10,$12)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker6I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEPFPvS3_S3_iS3_S3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$5,$7,$9,$11)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEPFPvS3_iS3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$1,$3,$5,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_S0_S0_E6InvokeEPFPvS3_iS3_iS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$1,$3,$6,$8,$10)|0);
 STACKTOP = sp;return ($11|0);
}
function __Z51mscorlib_System_Type_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2244016)|0);
 $5 = HEAP32[((2244016 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($8,0);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Type_CustomAttributesCacheGenerator_mscorlib_System_Type_m_IsSubclassOfP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z288mscorlib_System_Type_CustomAttributesCacheGenerator_mscorlib_System_Type_m_GetConstructor_mscorlib_System_Reflection_ConstructorInfo_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z334mscorlib_System_Type_CustomAttributesCacheGenerator_mscorlib_System_Type_m_GetConstructor_mscorlib_System_Reflection_ConstructorInfo_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Reflection_CallingConventions_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_Type_CustomAttributesCacheGenerator_mscorlib_System_Type_m_GetConstructorsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z50mscorlib_System_Reflection_MemberInfo_m_get_ModuleP37mscorlib_System_Reflection_MemberInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2242456);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2242504|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2238776|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Reflection_MemberInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2243592)|0);
 $5 = HEAP32[((2243592 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($8,0);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Reflection_ICustomAttributeProvider_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Runtime_InteropServices__MemberInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2243512)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($10,0);
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 HEAP32[$12>>2] = $10;
 $13 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($13,1);
 $14 = HEAP32[$3>>2]|0;
 $15 = (($14) + 12|0);
 HEAP32[$15>>2] = $13;
 $16 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2243032)|0);
 $17 = HEAP32[((2243032 + 48|0))>>2]|0;
 $18 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($17)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($16,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $16;
 STACKTOP = sp;return;
}
function __Z66mscorlib_System_Reflection_IReflect_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2243728)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Runtime_InteropServices__Type_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2242320)|0);
 $10 = HEAP32[((2242320 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $15 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2243944)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($14,$15);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $14;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_Exception_m__ctor_mscorlib_System_VoidP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244152);
 $0 = (($__this) + 40|0);
 HEAP32[$0>>2] = -2146233088;
 __THREW__ = 0;
 invoke_vi(1924,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z103mscorlib_System_Exception_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ExceptionP25mscorlib_System_ExceptionP22mscorlib_System_StringS0_($__this,$message,$innerException) {
 $__this = $__this|0;
 $message = $message|0;
 $innerException = $innerException|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244248);
 $0 = (($__this) + 40|0);
 HEAP32[$0>>2] = -2146233088;
 __THREW__ = 0;
 invoke_vi(1924,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $innerException;
  $4 = (($__this) + 16|0);
  HEAP32[$4>>2] = $message;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z46mscorlib_System_Exception_m_get_InnerExceptionP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244296);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z40mscorlib_System_Exception_m_get_HelpLinkP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244344);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z40mscorlib_System_Exception_m_set_HelpLinkP25mscorlib_System_ExceptionP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244392);
 $0 = (($__this) + 20|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z39mscorlib_System_Exception_m_set_HResultP25mscorlib_System_Exceptioni($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244440);
 $0 = (($__this) + 40|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z41mscorlib_System_Exception_m_get_ClassNameP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244488);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $11 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 __THREW__ = 0;
 $3 = (invoke_iii(2730,(2244536|0),($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_iii(2730,(2149160|0),($3|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    HEAP32[$0>>2] = $8;
    $11 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($11|0);
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_Exception_m_get_MessageP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244584);
 __THREW__ = 0;
 invoke_v(512);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $17 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($17|0);
  }
  $7 = HEAP32[3017424>>2]|0;
  __THREW__ = 0;
  $8 = (invoke_iii(783,0,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   $11 = (invoke_ii(1904,($__this|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_iiii(552,0,($8|0),($11|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     HEAP32[$2>>2] = $14;
     $17 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($17|0);
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_Exception_m_get_SourceP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244632);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $50 = HEAP32[$0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($50|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2322024|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2322024|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(584,($5|0),($__this|0),1);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_iii(2729,(2321312|0),($5|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = ($12|0)<(1);
       if ($15) {
        $50 = HEAP32[$0>>2]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($50|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($5|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_iiii(1642,(2321360|0),($5|0),0)|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $23 = ($5|0)==(0|0);
         if ($23) {
          $50 = HEAP32[$0>>2]|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($50|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($20|0));
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          $26 = (invoke_iii(2730,(2319784|0),($20|0))|0);
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           $29 = ($26|0)==(0|0);
           if ($29) {
            $50 = HEAP32[$0>>2]|0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($50|0);
           }
           __THREW__ = 0;
           invoke_vi(3799,($26|0));
           $30 = __THREW__; __THREW__ = 0;
           $31 = $30&1;
           if (!($31)) {
            __THREW__ = 0;
            $32 = (invoke_iii(2730,(2242504|0),($26|0))|0);
            $33 = __THREW__; __THREW__ = 0;
            $34 = $33&1;
            if (!($34)) {
             __THREW__ = 0;
             invoke_vi(3799,($32|0));
             $35 = __THREW__; __THREW__ = 0;
             $36 = $35&1;
             if (!($36)) {
              __THREW__ = 0;
              $37 = (invoke_iii(2730,(2238288|0),($32|0))|0);
              $38 = __THREW__; __THREW__ = 0;
              $39 = $38&1;
              if (!($39)) {
               __THREW__ = 0;
               invoke_vi(3799,($37|0));
               $40 = __THREW__; __THREW__ = 0;
               $41 = $40&1;
               if (!($41)) {
                __THREW__ = 0;
                $42 = (invoke_iii(2730,(2376456|0),($37|0))|0);
                $43 = __THREW__; __THREW__ = 0;
                $44 = $43&1;
                if (!($44)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($42|0));
                 $45 = __THREW__; __THREW__ = 0;
                 $46 = $45&1;
                 if ($46) {
                  break;
                 }
                 __THREW__ = 0;
                 $47 = (invoke_ii(2189,($42|0))|0);
                 $48 = __THREW__; __THREW__ = 0;
                 $49 = $48&1;
                 if ($49) {
                  break;
                 }
                 HEAP32[$0>>2] = $47;
                 $50 = HEAP32[$0>>2]|0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($50|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_Exception_m_set_SourceP25mscorlib_System_ExceptionP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244680);
 $0 = (($__this) + 44|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z42mscorlib_System_Exception_m_get_StackTraceP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_20 = 0, $L_27 = 0, $L_31 = 0, $L_36 = 0, $V_4$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_20 = sp;
 $L_27 = sp + 4|0;
 $L_31 = sp + 8|0;
 $L_36 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244728);
 __THREW__ = 0;
 invoke_v(513);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 28|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $$0 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  $9 = (($__this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if ($11) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2322024|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_ii(3469,(2322024|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_viiiii(64,($14|0),($__this|0),0,1,1);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2537888|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      $21 = (invoke_ii(3469,(2537888|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vi(2525,($21|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        $26 = (invoke_ii(2441,(0|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         $29 = HEAP32[3017520>>2]|0;
         __THREW__ = 0;
         $30 = (invoke_iii(783,0,($29|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          $33 = HEAP32[3017512>>2]|0;
          __THREW__ = 0;
          $34 = (invoke_iiiii(98,0,($33|0),($26|0),($30|0))|0);
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if (!($36)) {
           $37 = HEAP32[3017528>>2]|0;
           __THREW__ = 0;
           $38 = (invoke_iii(783,0,($37|0))|0);
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            $V_4$0 = 0;
            L19: while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($14|0));
             $153 = __THREW__; __THREW__ = 0;
             $154 = $153&1;
             if ($154) {
              label = 3;
              break;
             }
             __THREW__ = 0;
             $155 = (invoke_iii(2729,(2321312|0),($14|0))|0);
             $156 = __THREW__; __THREW__ = 0;
             $157 = $156&1;
             if ($157) {
              label = 3;
              break;
             }
             $158 = ($V_4$0|0)<($155|0);
             if (!($158)) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($14|0));
             $159 = __THREW__; __THREW__ = 0;
             $160 = $159&1;
             if ($160) {
              label = 3;
              break;
             }
             __THREW__ = 0;
             $41 = (invoke_iiii(1642,(2321360|0),($14|0),($V_4$0|0))|0);
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              label = 3;
              break;
             }
             $44 = ($V_4$0|0)==(0);
             if ($44) {
              $45 = HEAP32[3017544>>2]|0;
              __THREW__ = 0;
              $46 = (invoke_iii(783,0,($45|0))|0);
              $47 = __THREW__; __THREW__ = 0;
              $48 = $47&1;
              if ($48) {
               label = 3;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($21|0));
              $49 = __THREW__; __THREW__ = 0;
              $50 = $49&1;
              if ($50) {
               label = 3;
               break;
              }
              $51 = HEAP32[3017536>>2]|0;
              __THREW__ = 0;
              (invoke_iiii(934,($21|0),($51|0),($46|0))|0);
              $52 = __THREW__; __THREW__ = 0;
              $53 = $52&1;
              if ($53) {
               label = 3;
               break;
              }
             } else {
              __THREW__ = 0;
              invoke_vi(3799,($21|0));
              $54 = __THREW__; __THREW__ = 0;
              $55 = $54&1;
              if ($55) {
               label = 3;
               break;
              }
              __THREW__ = 0;
              (invoke_iii(989,($21|0),($34|0))|0);
              $56 = __THREW__; __THREW__ = 0;
              $57 = $56&1;
              if ($57) {
               label = 3;
               break;
              }
             }
             __THREW__ = 0;
             invoke_vi(3799,($41|0));
             $58 = __THREW__; __THREW__ = 0;
             $59 = $58&1;
             if ($59) {
              label = 3;
              break;
             }
             __THREW__ = 0;
             $60 = (invoke_iii(2730,(2319784|0),($41|0))|0);
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              label = 3;
              break;
             }
             $63 = ($60|0)==(0|0);
             do {
              if ($63) {
               __THREW__ = 0;
               invoke_vi(3799,($41|0));
               $64 = __THREW__; __THREW__ = 0;
               $65 = $64&1;
               if ($65) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               $66 = (invoke_ii(1973,($41|0))|0);
               $67 = __THREW__; __THREW__ = 0;
               $68 = $67&1;
               if ($68) {
                label = 3;
                break L19;
               }
               $69 = ($66|0)==(0|0);
               if (!($69)) {
                __THREW__ = 0;
                invoke_vi(3799,($21|0));
                $70 = __THREW__; __THREW__ = 0;
                $71 = $70&1;
                if ($71) {
                 label = 3;
                 break L19;
                }
                __THREW__ = 0;
                (invoke_iii(989,($21|0),($66|0))|0);
                $72 = __THREW__; __THREW__ = 0;
                $73 = $72&1;
                if ($73) {
                 label = 3;
                 break L19;
                } else {
                 break;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($41|0));
               $74 = __THREW__; __THREW__ = 0;
               $75 = $74&1;
               if ($75) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               $76 = (invoke_iii(2729,(2319832|0),($41|0))|0);
               $77 = __THREW__; __THREW__ = 0;
               $78 = $77&1;
               if ($78) {
                label = 3;
                break L19;
               }
               HEAP32[$L_20>>2] = $76;
               __THREW__ = 0;
               (invoke_ii(2996,(2155952|0))|0);
               $79 = __THREW__; __THREW__ = 0;
               $80 = $79&1;
               if ($80) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               $81 = (invoke_iii(2724,(2155952|0),($L_20|0))|0);
               $82 = __THREW__; __THREW__ = 0;
               $83 = $82&1;
               if ($83) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               invoke_vi(3799,($21|0));
               $84 = __THREW__; __THREW__ = 0;
               $85 = $84&1;
               if ($85) {
                label = 3;
                break L19;
               }
               $86 = HEAP32[3017552>>2]|0;
               __THREW__ = 0;
               (invoke_iiiii(163,($21|0),($86|0),($81|0),($38|0))|0);
               $87 = __THREW__; __THREW__ = 0;
               $88 = $87&1;
               if ($88) {
                label = 3;
                break L19;
               }
              } else {
               __THREW__ = 0;
               invoke_vi(3799,($41|0));
               $89 = __THREW__; __THREW__ = 0;
               $90 = $89&1;
               if ($90) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               $91 = (invoke_iii(2730,(2319784|0),($41|0))|0);
               $92 = __THREW__; __THREW__ = 0;
               $93 = $92&1;
               if ($93) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               invoke_viii(545,0,($21|0),($91|0));
               $94 = __THREW__; __THREW__ = 0;
               $95 = $94&1;
               if ($95) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               invoke_vi(3799,($41|0));
               $96 = __THREW__; __THREW__ = 0;
               $97 = $96&1;
               if ($97) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               $98 = (invoke_iii(2729,(2319736|0),($41|0))|0);
               $99 = __THREW__; __THREW__ = 0;
               $100 = $99&1;
               if ($100) {
                label = 3;
                break L19;
               }
               $101 = ($98|0)==(-1);
               if ($101) {
                __THREW__ = 0;
                invoke_vi(3799,($41|0));
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 label = 3;
                 break L19;
                }
                __THREW__ = 0;
                $104 = (invoke_iii(2729,(2319832|0),($41|0))|0);
                $105 = __THREW__; __THREW__ = 0;
                $106 = $105&1;
                if ($106) {
                 label = 3;
                 break L19;
                }
                HEAP32[$L_27>>2] = $104;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $107 = __THREW__; __THREW__ = 0;
                $108 = $107&1;
                if ($108) {
                 label = 3;
                 break L19;
                }
                __THREW__ = 0;
                $109 = (invoke_iii(2724,(2155952|0),($L_27|0))|0);
                $110 = __THREW__; __THREW__ = 0;
                $111 = $110&1;
                if ($111) {
                 label = 3;
                 break L19;
                }
                __THREW__ = 0;
                invoke_vi(3799,($21|0));
                $112 = __THREW__; __THREW__ = 0;
                $113 = $112&1;
                if ($113) {
                 label = 3;
                 break L19;
                }
                $114 = HEAP32[3017560>>2]|0;
                __THREW__ = 0;
                (invoke_iiii(934,($21|0),($114|0),($109|0))|0);
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if ($116) {
                 label = 3;
                 break L19;
                }
               } else {
                __THREW__ = 0;
                invoke_vi(3799,($41|0));
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 label = 3;
                 break L19;
                }
                __THREW__ = 0;
                $119 = (invoke_iii(2729,(2319736|0),($41|0))|0);
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 label = 3;
                 break L19;
                }
                HEAP32[$L_31>>2] = $119;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $122 = __THREW__; __THREW__ = 0;
                $123 = $122&1;
                if ($123) {
                 label = 3;
                 break L19;
                }
                __THREW__ = 0;
                $124 = (invoke_iii(2724,(2155952|0),($L_31|0))|0);
                $125 = __THREW__; __THREW__ = 0;
                $126 = $125&1;
                if ($126) {
                 label = 3;
                 break L19;
                }
                __THREW__ = 0;
                invoke_vi(3799,($21|0));
                $127 = __THREW__; __THREW__ = 0;
                $128 = $127&1;
                if ($128) {
                 label = 3;
                 break L19;
                }
                $129 = HEAP32[3017568>>2]|0;
                __THREW__ = 0;
                (invoke_iiii(934,($21|0),($129|0),($124|0))|0);
                $130 = __THREW__; __THREW__ = 0;
                $131 = $130&1;
                if ($131) {
                 label = 3;
                 break L19;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($41|0));
               $132 = __THREW__; __THREW__ = 0;
               $133 = $132&1;
               if ($133) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               $134 = (invoke_ii(1969,($41|0))|0);
               $135 = __THREW__; __THREW__ = 0;
               $136 = $135&1;
               if ($136) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               invoke_vi(3799,($41|0));
               $137 = __THREW__; __THREW__ = 0;
               $138 = $137&1;
               if ($138) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               $139 = (invoke_iii(2729,(2319592|0),($41|0))|0);
               $140 = __THREW__; __THREW__ = 0;
               $141 = $140&1;
               if ($141) {
                label = 3;
                break L19;
               }
               HEAP32[$L_36>>2] = $139;
               __THREW__ = 0;
               (invoke_ii(2996,(2155952|0))|0);
               $142 = __THREW__; __THREW__ = 0;
               $143 = $142&1;
               if ($143) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               $144 = (invoke_iii(2724,(2155952|0),($L_36|0))|0);
               $145 = __THREW__; __THREW__ = 0;
               $146 = $145&1;
               if ($146) {
                label = 3;
                break L19;
               }
               __THREW__ = 0;
               invoke_vi(3799,($21|0));
               $147 = __THREW__; __THREW__ = 0;
               $148 = $147&1;
               if ($148) {
                label = 3;
                break L19;
               }
               $149 = HEAP32[3017576>>2]|0;
               __THREW__ = 0;
               (invoke_iiiii(163,($21|0),($149|0),($134|0),($144|0))|0);
               $150 = __THREW__; __THREW__ = 0;
               $151 = $150&1;
               if ($151) {
                label = 3;
                break L19;
               }
              }
             } while(0);
             $152 = (($V_4$0) + 1)|0;
             $V_4$0 = $152;
            }
            if ((label|0) == 3) {
             $5 = ___cxa_find_matching_catch()|0;
             $6 = tempRet0;
             $lpad$phi$index = $5;$lpad$phi$index2 = $6;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($21|0));
            $161 = __THREW__; __THREW__ = 0;
            $162 = $161&1;
            if (!($162)) {
             __THREW__ = 0;
             $163 = (invoke_iii(2730,(2535432|0),($21|0))|0);
             $164 = __THREW__; __THREW__ = 0;
             $165 = $164&1;
             if (!($165)) {
              HEAP32[$2>>2] = $163;
              $$0 = $163;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Exception_m_GetFullNameForStackTraceP25mscorlib_System_ExceptionP34mscorlib_System_Text_StringBuilderP37mscorlib_System_Reflection_MethodBase($__this,$sb,$mi) {
 $__this = $__this|0;
 $sb = $sb|0;
 $mi = $mi|0;
 var $$sum = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244968);
 __THREW__ = 0;
 invoke_v(514);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($mi|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2730,(2397136|0),($mi|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($mi|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_iii(2730,(2242504|0),($mi|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($9|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        __THREW__ = 0;
        $14 = (invoke_iii(2730,(2149160|0),($9|0))|0);
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         __THREW__ = 0;
         invoke_vi(3799,($sb|0));
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if (!($18)) {
          __THREW__ = 0;
          (invoke_iii(989,($sb|0),($14|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           __THREW__ = 0;
           invoke_vi(3799,($sb|0));
           $21 = __THREW__; __THREW__ = 0;
           $22 = $21&1;
           if (!($22)) {
            $23 = HEAP32[3018384>>2]|0;
            __THREW__ = 0;
            (invoke_iii(989,($sb|0),($23|0))|0);
            $24 = __THREW__; __THREW__ = 0;
            $25 = $24&1;
            if (!($25)) {
             __THREW__ = 0;
             invoke_vi(3799,($mi|0));
             $26 = __THREW__; __THREW__ = 0;
             $27 = $26&1;
             if (!($27)) {
              __THREW__ = 0;
              $28 = (invoke_iii(2730,(2233608|0),($mi|0))|0);
              $29 = __THREW__; __THREW__ = 0;
              $30 = $29&1;
              if (!($30)) {
               __THREW__ = 0;
               invoke_vi(3799,($sb|0));
               $31 = __THREW__; __THREW__ = 0;
               $32 = $31&1;
               if (!($32)) {
                __THREW__ = 0;
                (invoke_iii(989,($sb|0),($28|0))|0);
                $33 = __THREW__; __THREW__ = 0;
                $34 = $33&1;
                if (!($34)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($mi|0));
                 $35 = __THREW__; __THREW__ = 0;
                 $36 = $35&1;
                 if (!($36)) {
                  __THREW__ = 0;
                  $37 = (invoke_iii(2734,(2410944|0),($mi|0))|0);
                  $38 = __THREW__; __THREW__ = 0;
                  $39 = $38&1;
                  if (!($39)) {
                   do {
                    if ($37) {
                     __THREW__ = 0;
                     invoke_vi(3799,($mi|0));
                     $46 = __THREW__; __THREW__ = 0;
                     $47 = $46&1;
                     if ($47) {
                      break L1;
                     }
                     __THREW__ = 0;
                     $48 = (invoke_iii(2730,(2410848|0),($mi|0))|0);
                     $49 = __THREW__; __THREW__ = 0;
                     $50 = $49&1;
                     if ($50) {
                      break L1;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($sb|0));
                     $51 = __THREW__; __THREW__ = 0;
                     $52 = $51&1;
                     if ($52) {
                      break L1;
                     }
                     $53 = HEAP32[3018392>>2]|0;
                     __THREW__ = 0;
                     (invoke_iii(989,($sb|0),($53|0))|0);
                     $54 = __THREW__; __THREW__ = 0;
                     $55 = $54&1;
                     if ($55) {
                      break L1;
                     }
                     $56 = (($48) + 12|0);
                     $V_2$0 = 0;
                     while(1) {
                      __THREW__ = 0;
                      invoke_vi(3799,($48|0));
                      $87 = __THREW__; __THREW__ = 0;
                      $88 = $87&1;
                      if ($88) {
                       label = 20;
                       break;
                      }
                      $89 = HEAP32[$56>>2]|0;
                      $90 = ($V_2$0|0)<($89|0);
                      if (!($90)) {
                       label = 42;
                       break;
                      }
                      $91 = ($V_2$0|0)<(1);
                      if (!($91)) {
                       __THREW__ = 0;
                       invoke_vi(3799,($sb|0));
                       $57 = __THREW__; __THREW__ = 0;
                       $58 = $57&1;
                       if ($58) {
                        label = 20;
                        break;
                       }
                       $59 = HEAP32[3018400>>2]|0;
                       __THREW__ = 0;
                       (invoke_iii(989,($sb|0),($59|0))|0);
                       $60 = __THREW__; __THREW__ = 0;
                       $61 = $60&1;
                       if ($61) {
                        label = 20;
                        break;
                       }
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($48|0));
                      $62 = __THREW__; __THREW__ = 0;
                      $63 = $62&1;
                      if ($63) {
                       label = 20;
                       break;
                      }
                      $64 = HEAP32[$56>>2]|0;
                      $65 = ($V_2$0>>>0)<($64>>>0);
                      if (!($65)) {
                       __THREW__ = 0;
                       $66 = (invoke_i(132)|0);
                       $67 = __THREW__; __THREW__ = 0;
                       $68 = $67&1;
                       if ($68) {
                        label = 20;
                        break;
                       }
                       __THREW__ = 0;
                       invoke_vi(3302,($66|0));
                       $69 = __THREW__; __THREW__ = 0;
                       $70 = $69&1;
                       if ($70) {
                        label = 20;
                        break;
                       }
                      }
                      $71 = HEAP32[$48>>2]|0;
                      $72 = (($71) + 92|0);
                      $73 = HEAP32[$72>>2]|0;
                      $74 = Math_imul($73, $V_2$0)|0;
                      $$sum6 = (($74) + 16)|0;
                      $75 = (($48) + ($$sum6)|0);
                      $76 = HEAP32[$75>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($76|0));
                      $77 = __THREW__; __THREW__ = 0;
                      $78 = $77&1;
                      if ($78) {
                       label = 20;
                       break;
                      }
                      __THREW__ = 0;
                      $79 = (invoke_iii(2730,(2233608|0),($76|0))|0);
                      $80 = __THREW__; __THREW__ = 0;
                      $81 = $80&1;
                      if ($81) {
                       label = 20;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($sb|0));
                      $82 = __THREW__; __THREW__ = 0;
                      $83 = $82&1;
                      if ($83) {
                       label = 20;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_iii(989,($sb|0),($79|0))|0);
                      $84 = __THREW__; __THREW__ = 0;
                      $85 = $84&1;
                      if ($85) {
                       label = 20;
                       break;
                      }
                      $86 = (($V_2$0) + 1)|0;
                      $V_2$0 = $86;
                     }
                     if ((label|0) == 20) {
                      $42 = ___cxa_find_matching_catch()|0;
                      $43 = tempRet0;
                      $lpad$phi$index = $42;$lpad$phi$index3 = $43;
                      __ZN16StackTraceSentryD2Ev(0);
                      ___resumeException($lpad$phi$index|0);
                      // unreachable;
                     }
                     else if ((label|0) == 42) {
                      __THREW__ = 0;
                      invoke_vi(3799,($sb|0));
                      $92 = __THREW__; __THREW__ = 0;
                      $93 = $92&1;
                      if ($93) {
                       break L1;
                      }
                      $94 = HEAP32[3018408>>2]|0;
                      __THREW__ = 0;
                      (invoke_iii(989,($sb|0),($94|0))|0);
                      $95 = __THREW__; __THREW__ = 0;
                      $96 = $95&1;
                      if ($96) {
                       break L1;
                      } else {
                       break;
                      }
                     }
                    }
                   } while(0);
                   __THREW__ = 0;
                   invoke_vi(3799,($sb|0));
                   $97 = __THREW__; __THREW__ = 0;
                   $98 = $97&1;
                   if (!($98)) {
                    $99 = HEAP32[3018416>>2]|0;
                    __THREW__ = 0;
                    (invoke_iii(989,($sb|0),($99|0))|0);
                    $100 = __THREW__; __THREW__ = 0;
                    $101 = $100&1;
                    if ($101) {
                     break;
                    }
                    $102 = (($4) + 12|0);
                    $V_3$0 = 0;
                    L50: while(1) {
                     __THREW__ = 0;
                     invoke_vi(3799,($4|0));
                     $229 = __THREW__; __THREW__ = 0;
                     $230 = $229&1;
                     if ($230) {
                      label = 19;
                      break;
                     }
                     $231 = HEAP32[$102>>2]|0;
                     $232 = ($V_3$0|0)<($231|0);
                     if (!($232)) {
                      break;
                     }
                     $233 = ($V_3$0|0)<(1);
                     if (!($233)) {
                      __THREW__ = 0;
                      invoke_vi(3799,($sb|0));
                      $103 = __THREW__; __THREW__ = 0;
                      $104 = $103&1;
                      if ($104) {
                       label = 19;
                       break;
                      }
                      $105 = HEAP32[3018424>>2]|0;
                      __THREW__ = 0;
                      (invoke_iii(989,($sb|0),($105|0))|0);
                      $106 = __THREW__; __THREW__ = 0;
                      $107 = $106&1;
                      if ($107) {
                       label = 19;
                       break;
                      }
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($4|0));
                     $108 = __THREW__; __THREW__ = 0;
                     $109 = $108&1;
                     if ($109) {
                      label = 19;
                      break;
                     }
                     $110 = HEAP32[$102>>2]|0;
                     $111 = ($V_3$0>>>0)<($110>>>0);
                     if (!($111)) {
                      __THREW__ = 0;
                      $112 = (invoke_i(132)|0);
                      $113 = __THREW__; __THREW__ = 0;
                      $114 = $113&1;
                      if ($114) {
                       label = 19;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3302,($112|0));
                      $115 = __THREW__; __THREW__ = 0;
                      $116 = $115&1;
                      if ($116) {
                       label = 19;
                       break;
                      }
                     }
                     $117 = HEAP32[$4>>2]|0;
                     $118 = (($117) + 92|0);
                     $119 = HEAP32[$118>>2]|0;
                     $120 = Math_imul($119, $V_3$0)|0;
                     $$sum = (($120) + 16)|0;
                     $121 = (($4) + ($$sum)|0);
                     $122 = HEAP32[$121>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($122|0));
                     $123 = __THREW__; __THREW__ = 0;
                     $124 = $123&1;
                     if ($124) {
                      label = 19;
                      break;
                     }
                     __THREW__ = 0;
                     $125 = (invoke_iii(2730,(2397472|0),($122|0))|0);
                     $126 = __THREW__; __THREW__ = 0;
                     $127 = $126&1;
                     if ($127) {
                      label = 19;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($125|0));
                     $128 = __THREW__; __THREW__ = 0;
                     $129 = $128&1;
                     if ($129) {
                      label = 19;
                      break;
                     }
                     __THREW__ = 0;
                     $130 = (invoke_iii(2734,(2234136|0),($125|0))|0);
                     $131 = __THREW__; __THREW__ = 0;
                     $132 = $131&1;
                     if ($132) {
                      label = 19;
                      break;
                     }
                     do {
                      if ($130) {
                       __THREW__ = 0;
                       invoke_vi(3799,($125|0));
                       $133 = __THREW__; __THREW__ = 0;
                       $134 = $133&1;
                       if ($134) {
                        label = 19;
                        break L50;
                       }
                       __THREW__ = 0;
                       $135 = (invoke_iii(2730,(2238840|0),($125|0))|0);
                       $136 = __THREW__; __THREW__ = 0;
                       $137 = $136&1;
                       if ($137) {
                        label = 19;
                        break L50;
                       }
                       __THREW__ = 0;
                       (invoke_ii(2996,(2191608|0))|0);
                       $138 = __THREW__; __THREW__ = 0;
                       $139 = $138&1;
                       if ($139) {
                        label = 19;
                        break L50;
                       }
                       $140 = HEAP8[((2191608 + 116|0))>>0]|0;
                       $141 = ($140<<24>>24)==(0);
                       if ($141) {
                        __THREW__ = 0;
                        (invoke_ii(2996,(2191608|0))|0);
                        $142 = __THREW__; __THREW__ = 0;
                        $143 = $142&1;
                        if ($143) {
                         label = 19;
                         break L50;
                        }
                        __THREW__ = 0;
                        (invoke_ii(2996,(2191608|0))|0);
                        $144 = __THREW__; __THREW__ = 0;
                        $145 = $144&1;
                        if ($145) {
                         label = 19;
                         break L50;
                        }
                        __THREW__ = 0;
                        invoke_vi(3831,(2191608|0));
                        $146 = __THREW__; __THREW__ = 0;
                        $147 = $146&1;
                        if ($147) {
                         label = 19;
                         break L50;
                        }
                       }
                       __THREW__ = 0;
                       (invoke_ii(2996,(2191608|0))|0);
                       $148 = __THREW__; __THREW__ = 0;
                       $149 = $148&1;
                       if ($149) {
                        label = 19;
                        break L50;
                       }
                       $150 = HEAP32[((2191608 + 80|0))>>2]|0;
                       $151 = HEAP32[$150>>2]|0;
                       __THREW__ = 0;
                       $152 = (invoke_iiii(575,0,($135|0),($151|0))|0);
                       $153 = __THREW__; __THREW__ = 0;
                       $154 = $153&1;
                       if ($154) {
                        label = 19;
                        break L50;
                       }
                       if (!($152)) {
                        break;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($125|0));
                       $155 = __THREW__; __THREW__ = 0;
                       $156 = $155&1;
                       if ($156) {
                        label = 19;
                        break L50;
                       }
                       __THREW__ = 0;
                       $157 = (invoke_iii(2730,(2238840|0),($125|0))|0);
                       $158 = __THREW__; __THREW__ = 0;
                       $159 = $158&1;
                       if ($159) {
                        label = 19;
                        break L50;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($sb|0));
                       $160 = __THREW__; __THREW__ = 0;
                       $161 = $160&1;
                       if ($161) {
                        label = 19;
                        break L50;
                       }
                       __THREW__ = 0;
                       (invoke_iii(989,($sb|0),($157|0))|0);
                       $162 = __THREW__; __THREW__ = 0;
                       $163 = $162&1;
                       if ($163) {
                        label = 19;
                        break L50;
                       }
                       __THREW__ = 0;
                       invoke_vi(3799,($sb|0));
                       $164 = __THREW__; __THREW__ = 0;
                       $165 = $164&1;
                       if ($165) {
                        label = 19;
                        break L50;
                       }
                       $166 = HEAP32[3018432>>2]|0;
                       __THREW__ = 0;
                       (invoke_iii(989,($sb|0),($166|0))|0);
                       $167 = __THREW__; __THREW__ = 0;
                       $168 = $167&1;
                       if ($168) {
                        label = 19;
                        break L50;
                       }
                      }
                     } while(0);
                     __THREW__ = 0;
                     invoke_vi(3799,($125|0));
                     $169 = __THREW__; __THREW__ = 0;
                     $170 = $169&1;
                     if ($170) {
                      label = 19;
                      break;
                     }
                     __THREW__ = 0;
                     $171 = (invoke_iii(2730,(2233608|0),($125|0))|0);
                     $172 = __THREW__; __THREW__ = 0;
                     $173 = $172&1;
                     if ($173) {
                      label = 19;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($sb|0));
                     $174 = __THREW__; __THREW__ = 0;
                     $175 = $174&1;
                     if ($175) {
                      label = 19;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_iii(989,($sb|0),($171|0))|0);
                     $176 = __THREW__; __THREW__ = 0;
                     $177 = $176&1;
                     if ($177) {
                      label = 19;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($4|0));
                     $178 = __THREW__; __THREW__ = 0;
                     $179 = $178&1;
                     if ($179) {
                      label = 19;
                      break;
                     }
                     $180 = HEAP32[$102>>2]|0;
                     $181 = ($V_3$0>>>0)<($180>>>0);
                     if (!($181)) {
                      __THREW__ = 0;
                      $182 = (invoke_i(132)|0);
                      $183 = __THREW__; __THREW__ = 0;
                      $184 = $183&1;
                      if ($184) {
                       label = 19;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3302,($182|0));
                      $185 = __THREW__; __THREW__ = 0;
                      $186 = $185&1;
                      if ($186) {
                       label = 19;
                       break;
                      }
                     }
                     $187 = HEAP32[$4>>2]|0;
                     $188 = (($187) + 92|0);
                     $189 = HEAP32[$188>>2]|0;
                     $190 = Math_imul($189, $V_3$0)|0;
                     $$sum4 = (($190) + 16)|0;
                     $191 = (($4) + ($$sum4)|0);
                     $192 = HEAP32[$191>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($192|0));
                     $193 = __THREW__; __THREW__ = 0;
                     $194 = $193&1;
                     if ($194) {
                      label = 19;
                      break;
                     }
                     __THREW__ = 0;
                     $195 = (invoke_iii(2730,(2397184|0),($192|0))|0);
                     $196 = __THREW__; __THREW__ = 0;
                     $197 = $196&1;
                     if ($197) {
                      label = 19;
                      break;
                     }
                     $198 = ($195|0)==(0|0);
                     if (!($198)) {
                      __THREW__ = 0;
                      invoke_vi(3799,($sb|0));
                      $199 = __THREW__; __THREW__ = 0;
                      $200 = $199&1;
                      if ($200) {
                       label = 19;
                       break;
                      }
                      $201 = HEAP32[3018440>>2]|0;
                      __THREW__ = 0;
                      (invoke_iii(989,($sb|0),($201|0))|0);
                      $202 = __THREW__; __THREW__ = 0;
                      $203 = $202&1;
                      if ($203) {
                       label = 19;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($4|0));
                      $204 = __THREW__; __THREW__ = 0;
                      $205 = $204&1;
                      if ($205) {
                       label = 19;
                       break;
                      }
                      $206 = HEAP32[$102>>2]|0;
                      $207 = ($V_3$0>>>0)<($206>>>0);
                      if (!($207)) {
                       __THREW__ = 0;
                       $208 = (invoke_i(132)|0);
                       $209 = __THREW__; __THREW__ = 0;
                       $210 = $209&1;
                       if ($210) {
                        label = 19;
                        break;
                       }
                       __THREW__ = 0;
                       invoke_vi(3302,($208|0));
                       $211 = __THREW__; __THREW__ = 0;
                       $212 = $211&1;
                       if ($212) {
                        label = 19;
                        break;
                       }
                      }
                      $213 = HEAP32[$4>>2]|0;
                      $214 = (($213) + 92|0);
                      $215 = HEAP32[$214>>2]|0;
                      $216 = Math_imul($215, $V_3$0)|0;
                      $$sum5 = (($216) + 16)|0;
                      $217 = (($4) + ($$sum5)|0);
                      $218 = HEAP32[$217>>2]|0;
                      __THREW__ = 0;
                      invoke_vi(3799,($218|0));
                      $219 = __THREW__; __THREW__ = 0;
                      $220 = $219&1;
                      if ($220) {
                       label = 19;
                       break;
                      }
                      __THREW__ = 0;
                      $221 = (invoke_iii(2730,(2397184|0),($218|0))|0);
                      $222 = __THREW__; __THREW__ = 0;
                      $223 = $222&1;
                      if ($223) {
                       label = 19;
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3799,($sb|0));
                      $224 = __THREW__; __THREW__ = 0;
                      $225 = $224&1;
                      if ($225) {
                       label = 19;
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_iii(989,($sb|0),($221|0))|0);
                      $226 = __THREW__; __THREW__ = 0;
                      $227 = $226&1;
                      if ($227) {
                       label = 19;
                       break;
                      }
                     }
                     $228 = (($V_3$0) + 1)|0;
                     $V_3$0 = $228;
                    }
                    if ((label|0) == 19) {
                     $40 = ___cxa_find_matching_catch()|0;
                     $41 = tempRet0;
                     $lpad$phi$index = $40;$lpad$phi$index3 = $41;
                     __ZN16StackTraceSentryD2Ev(0);
                     ___resumeException($lpad$phi$index|0);
                     // unreachable;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($sb|0));
                    $234 = __THREW__; __THREW__ = 0;
                    $235 = $234&1;
                    if ($235) {
                     break;
                    }
                    $236 = HEAP32[3018448>>2]|0;
                    __THREW__ = 0;
                    (invoke_iii(989,($sb|0),($236|0))|0);
                    $237 = __THREW__; __THREW__ = 0;
                    $238 = $237&1;
                    if ($238) {
                     break;
                    }
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $44 = ___cxa_find_matching_catch()|0;
 $45 = tempRet0;
 $lpad$phi$index = $44;$lpad$phi$index3 = $45;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z42mscorlib_System_Exception_m_get_TargetSiteP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244776);
 __THREW__ = 0;
 (invoke_ii(2996,(2322024|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2322024|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viii(584,($2|0),($__this|0),1);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_iii(2729,(2321312|0),($2|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = ($9|0)<(1);
      if ($12) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iiii(1642,(2321360|0),($2|0),0)|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vi(3799,($17|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         $22 = (invoke_iii(2730,(2319784|0),($17|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          $$0 = $22;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_Exception_m_GetBaseExceptionP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$01 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244824);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = $__this;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 } else {
  $V_0$01 = $1;
 }
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($V_0$01|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   label = 4;
   break;
  }
  __THREW__ = 0;
  $3 = (invoke_iii(2730,(2244296|0),($V_0$01|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   label = 4;
   break;
  }
  $6 = ($3|0)==(0|0);
  if ($6) {
   $$0 = $V_0$01;
   label = 9;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($V_0$01|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 4;
   break;
  }
  __THREW__ = 0;
  $11 = (invoke_iii(2730,(2244296|0),($V_0$01|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   label = 4;
   break;
  }
  $14 = ($11|0)==(0|0);
  if ($14) {
   $$0 = $__this;
   label = 9;
   break;
  } else {
   $V_0$01 = $11;
  }
 }
 if ((label|0) == 4) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z41mscorlib_System_Exception_m_GetObjectDataP25mscorlib_System_ExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244872);
 __THREW__ = 0;
 invoke_v(515);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($info|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3017776>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $16 = (invoke_ii(1904,($__this|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = HEAP32[3017784>>2]|0;
     __THREW__ = 0;
     invoke_viii(621,($info|0),($21|0),($16|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = (($__this) + 16|0);
      $25 = HEAP32[$24>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($info|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       $28 = HEAP32[3017792>>2]|0;
       __THREW__ = 0;
       invoke_viii(621,($info|0),($28|0),($25|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = (($__this) + 12|0);
        $32 = HEAP32[$31>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         $35 = HEAP32[3017800>>2]|0;
         __THREW__ = 0;
         invoke_viii(621,($info|0),($35|0),($32|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if (!($37)) {
          $38 = (($__this) + 20|0);
          $39 = HEAP32[$38>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($info|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if (!($41)) {
           $42 = HEAP32[3017808>>2]|0;
           __THREW__ = 0;
           invoke_viii(621,($info|0),($42|0),($39|0));
           $43 = __THREW__; __THREW__ = 0;
           $44 = $43&1;
           if (!($44)) {
            __THREW__ = 0;
            $45 = (invoke_iii(2730,(2244728|0),($__this|0))|0);
            $46 = __THREW__; __THREW__ = 0;
            $47 = $46&1;
            if (!($47)) {
             __THREW__ = 0;
             invoke_vi(3799,($info|0));
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if (!($49)) {
              $50 = HEAP32[3017816>>2]|0;
              __THREW__ = 0;
              invoke_viii(621,($info|0),($50|0),($45|0));
              $51 = __THREW__; __THREW__ = 0;
              $52 = $51&1;
              if (!($52)) {
               $53 = (($__this) + 32|0);
               $54 = HEAP32[$53>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($info|0));
               $55 = __THREW__; __THREW__ = 0;
               $56 = $55&1;
               if (!($56)) {
                $57 = HEAP32[3017824>>2]|0;
                __THREW__ = 0;
                invoke_viii(621,($info|0),($57|0),($54|0));
                $58 = __THREW__; __THREW__ = 0;
                $59 = $58&1;
                if (!($59)) {
                 $60 = (($__this) + 36|0);
                 $61 = HEAP32[$60>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($info|0));
                 $62 = __THREW__; __THREW__ = 0;
                 $63 = $62&1;
                 if (!($63)) {
                  $64 = HEAP32[3017832>>2]|0;
                  __THREW__ = 0;
                  invoke_viii(618,($info|0),($64|0),($61|0));
                  $65 = __THREW__; __THREW__ = 0;
                  $66 = $65&1;
                  if (!($66)) {
                   $67 = (($__this) + 40|0);
                   $68 = HEAP32[$67>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($info|0));
                   $69 = __THREW__; __THREW__ = 0;
                   $70 = $69&1;
                   if (!($70)) {
                    $71 = HEAP32[3017840>>2]|0;
                    __THREW__ = 0;
                    invoke_viii(618,($info|0),($71|0),($68|0));
                    $72 = __THREW__; __THREW__ = 0;
                    $73 = $72&1;
                    if ($73) {
                     break;
                    }
                    __THREW__ = 0;
                    $74 = (invoke_iii(2730,(2244632|0),($__this|0))|0);
                    $75 = __THREW__; __THREW__ = 0;
                    $76 = $75&1;
                    if ($76) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($info|0));
                    $77 = __THREW__; __THREW__ = 0;
                    $78 = $77&1;
                    if ($78) {
                     break;
                    }
                    $79 = HEAP32[3017848>>2]|0;
                    __THREW__ = 0;
                    invoke_viii(621,($info|0),($79|0),($74|0));
                    $80 = __THREW__; __THREW__ = 0;
                    $81 = $80&1;
                    if ($81) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($info|0));
                    $82 = __THREW__; __THREW__ = 0;
                    $83 = $82&1;
                    if ($83) {
                     break;
                    }
                    $84 = HEAP32[3017856>>2]|0;
                    __THREW__ = 0;
                    invoke_viii(621,($info|0),($84|0),(0|0));
                    $85 = __THREW__; __THREW__ = 0;
                    $86 = $85&1;
                    if ($86) {
                     break;
                    }
                    $87 = (($__this) + 48|0);
                    $88 = HEAP32[$87>>2]|0;
                    HEAP32[$0>>2] = 2267488;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
                    $89 = (invoke_iii(772,0,($$byval_copy|0))|0);
                    $90 = __THREW__; __THREW__ = 0;
                    $91 = $90&1;
                    if ($91) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($info|0));
                    $92 = __THREW__; __THREW__ = 0;
                    $93 = $92&1;
                    if ($93) {
                     break;
                    }
                    $94 = HEAP32[3017864>>2]|0;
                    __THREW__ = 0;
                    invoke_viiii(168,($info|0),($94|0),($88|0),($89|0));
                    $95 = __THREW__; __THREW__ = 0;
                    $96 = $95&1;
                    if ($96) {
                     break;
                    }
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z36mscorlib_System_Exception_m_ToStringP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244920);
 __THREW__ = 0;
 invoke_v(516);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1904,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2537888|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_ii(3469,(2537888|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vii(1911,($7|0),($2|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($7|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        $14 = HEAP32[3018152>>2]|0;
        __THREW__ = 0;
        $15 = (invoke_iii(989,($7|0),($14|0))|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if (!($17)) {
         __THREW__ = 0;
         $18 = (invoke_iii(2730,(2244584|0),($__this|0))|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if (!($20)) {
          __THREW__ = 0;
          invoke_vi(3799,($15|0));
          $21 = __THREW__; __THREW__ = 0;
          $22 = $21&1;
          if (!($22)) {
           __THREW__ = 0;
           (invoke_iii(989,($15|0),($18|0))|0);
           $23 = __THREW__; __THREW__ = 0;
           $24 = $23&1;
           if (!($24)) {
            $25 = (($__this) + 32|0);
            $26 = HEAP32[$25>>2]|0;
            $27 = ($26|0)==(0|0);
            if (!($27)) {
             __THREW__ = 0;
             invoke_vi(3799,($7|0));
             $30 = __THREW__; __THREW__ = 0;
             $31 = $30&1;
             if ($31) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii(989,($7|0),($26|0))|0);
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if ($33) {
              break;
             }
            }
            $34 = (($__this) + 12|0);
            $35 = HEAP32[$34>>2]|0;
            $36 = ($35|0)==(0|0);
            if (!($36)) {
             __THREW__ = 0;
             invoke_vi(3799,($7|0));
             $37 = __THREW__; __THREW__ = 0;
             $38 = $37&1;
             if ($38) {
              break;
             }
             $39 = HEAP32[3018160>>2]|0;
             __THREW__ = 0;
             $40 = (invoke_iii(989,($7|0),($39|0))|0);
             $41 = __THREW__; __THREW__ = 0;
             $42 = $41&1;
             if ($42) {
              break;
             }
             $43 = HEAP32[3018168>>2]|0;
             __THREW__ = 0;
             (invoke_iiii(418,0,0,($43|0))|0);
             $44 = __THREW__; __THREW__ = 0;
             $45 = $44&1;
             if ($45) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($40|0));
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if ($47) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii(989,($40|0),0)|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             $50 = (invoke_ii(2441,(0|0))|0);
             $51 = __THREW__; __THREW__ = 0;
             $52 = $51&1;
             if ($52) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($7|0));
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if ($54) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii(989,($7|0),($50|0))|0);
             $55 = __THREW__; __THREW__ = 0;
             $56 = $55&1;
             if ($56) {
              break;
             }
             $57 = HEAP32[3018176>>2]|0;
             __THREW__ = 0;
             $58 = (invoke_iii(783,0,($57|0))|0);
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($7|0));
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii(989,($7|0),($58|0))|0);
             $63 = __THREW__; __THREW__ = 0;
             $64 = $63&1;
             if ($64) {
              break;
             }
            }
            __THREW__ = 0;
            $65 = (invoke_iii(2730,(2244728|0),($__this|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if (!($67)) {
             $68 = ($65|0)==(0|0);
             if (!($68)) {
              __THREW__ = 0;
              $69 = (invoke_ii(2441,(0|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($7|0));
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               break;
              }
              __THREW__ = 0;
              $74 = (invoke_iii(989,($7|0),($69|0))|0);
              $75 = __THREW__; __THREW__ = 0;
              $76 = $75&1;
              if ($76) {
               break;
              }
              __THREW__ = 0;
              $77 = (invoke_iii(2730,(2244728|0),($__this|0))|0);
              $78 = __THREW__; __THREW__ = 0;
              $79 = $78&1;
              if ($79) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($74|0));
              $80 = __THREW__; __THREW__ = 0;
              $81 = $80&1;
              if ($81) {
               break;
              }
              __THREW__ = 0;
              (invoke_iii(989,($74|0),($77|0))|0);
              $82 = __THREW__; __THREW__ = 0;
              $83 = $82&1;
              if ($83) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vi(3799,($7|0));
             $84 = __THREW__; __THREW__ = 0;
             $85 = $84&1;
             if (!($85)) {
              __THREW__ = 0;
              $86 = (invoke_iii(2730,(2535432|0),($7|0))|0);
              $87 = __THREW__; __THREW__ = 0;
              $88 = $87&1;
              if (!($88)) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($86|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_Exception_m_GetTypeP25mscorlib_System_Exception($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2244536);
 __THREW__ = 0;
 $0 = (invoke_ii(1782,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z56mscorlib_System_Exception_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2246336)|0);
 $7 = HEAP32[((2246336 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Runtime_InteropServices__Exception_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2246256)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($10,0);
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 HEAP32[$12>>2] = $10;
 $13 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($13,0);
 $14 = HEAP32[$3>>2]|0;
 $15 = (($14) + 12|0);
 HEAP32[$15>>2] = $13;
 STACKTOP = sp;return;
}
function __Z46mscorlib_System_RuntimeFieldHandle_m_get_ValueP34mscorlib_System_RuntimeFieldHandle($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2246472);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z50mscorlib_System_RuntimeFieldHandle_m_GetObjectDataP34mscorlib_System_RuntimeFieldHandleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$byval_copy = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2246520);
 __THREW__ = 0;
 invoke_v(517);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = ($info|0)==(0|0);
   if ($6) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3018472>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2210080|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP32[((2210080 + 80|0))>>2]|0;
    $23 = HEAP32[$22>>2]|0;
    HEAP32[$0>>2] = $19;
    HEAP32[$1>>2] = $23;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    $24 = (invoke_iiii(643,0,($$byval_copy|0),($$byval_copy3|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     if ($24) {
      __THREW__ = 0;
      (invoke_ii(2996,(2497744|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_ii(3469,(2497744|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = HEAP32[3018480>>2]|0;
      __THREW__ = 0;
      invoke_vii(1896,($29|0),($32|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($29|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      // unreachable;
     }
     $37 = HEAP32[$__this>>2]|0;
     HEAP32[$2>>2] = $37;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     $38 = (invoke_iii(907,(0|0),($$byval_copy3|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2420056|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       __THREW__ = 0;
       $43 = (invoke_iii(2755,($38|0),(2420056|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        HEAP32[$3>>2] = 2267080;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
        $46 = (invoke_iii(772,0,($$byval_copy3|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         __THREW__ = 0;
         invoke_vi(3799,($info|0));
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if (!($50)) {
          $51 = HEAP32[3018488>>2]|0;
          __THREW__ = 0;
          invoke_viiii(168,($info|0),($51|0),($43|0),($46|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z43mscorlib_System_RuntimeFieldHandle_m_EqualsP34mscorlib_System_RuntimeFieldHandleP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $V_0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp + 8|0;
 $L_0 = sp + 12|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2246568);
 HEAP32[$V_0>>2] = 0;
 $2 = ($obj|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$__this>>2]|0;
 HEAP32[$L_0>>2] = $3;
 __THREW__ = 0;
 (invoke_ii(2996,(2246912|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_iii(2724,(2246912|0),($L_0|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vi(3799,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(1782,($6|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($obj|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_ii(1782,($obj|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = ($11|0)==($16|0);
       if (!($19)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $22 = HEAP32[$__this>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2246912|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_iii(2753,($obj|0),(2246912|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $28 = HEAP32[$25>>2]|0;
         HEAP32[$V_0>>2] = $28;
         __THREW__ = 0;
         $29 = (invoke_ii(1912,($V_0|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          HEAP32[$0>>2] = $22;
          HEAP32[$1>>2] = $29;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
          ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
          $32 = (invoke_iiii(643,0,($$byval_copy|0),($$byval_copy1|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           $$0 = $32;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_RuntimeFieldHandle_m_GetHashCodeP34mscorlib_System_RuntimeFieldHandle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2246616);
 __THREW__ = 0;
 $0 = (invoke_ii(1829,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z65mscorlib_System_RuntimeFieldHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2246752)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($__this,$comment) {
 $__this = $__this|0;
 $comment = $comment|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2256880);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $comment;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z109mscorlib_System_RuntimeFieldHandle_CustomAttributesCacheGenerator_mscorlib_System_RuntimeFieldHandle_m_EqualsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z49mscorlib_System_RuntimeTypeHandle_m_GetObjectDataP33mscorlib_System_RuntimeTypeHandleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $L_5 = 0, $L_8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 28|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $L_5 = sp + 16|0;
 $L_8 = sp + 20|0;
 $2 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2247096);
 __THREW__ = 0;
 invoke_v(518);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($info|0)==(0|0);
   if ($5) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3018616>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3830,($10|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   }
   $18 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2210080|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = HEAP32[((2210080 + 80|0))>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    HEAP32[$0>>2] = $18;
    HEAP32[$1>>2] = $22;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    $23 = (invoke_iiii(643,0,($$byval_copy|0),($$byval_copy2|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     if ($23) {
      __THREW__ = 0;
      (invoke_ii(2996,(2497744|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_ii(3469,(2497744|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = HEAP32[3018624>>2]|0;
      __THREW__ = 0;
      invoke_vii(1896,($28|0),($31|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3830,($28|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      // unreachable;
     }
     $36 = HEAP32[$__this>>2]|0;
     HEAP32[$L_5>>2] = $36;
     __THREW__ = 0;
     (invoke_ii(2996,(2247448|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      __THREW__ = 0;
      $39 = (invoke_iii(2724,(2247448|0),($L_5|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       __THREW__ = 0;
       $42 = (invoke_iii(773,0,($39|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if (!($44)) {
        HEAP32[$L_8>>2] = $42;
        __THREW__ = 0;
        (invoke_ii(2996,(2247448|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         __THREW__ = 0;
         $47 = (invoke_iii(2724,(2247448|0),($L_8|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if (!($49)) {
          HEAP32[$2>>2] = 1690232;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
          $50 = (invoke_iii(772,0,($$byval_copy2|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if (!($52)) {
           __THREW__ = 0;
           invoke_vi(3799,($info|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if (!($54)) {
            $55 = HEAP32[3018632>>2]|0;
            __THREW__ = 0;
            invoke_viiii(168,($info|0),($55|0),($47|0),($50|0));
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if (!($57)) {
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z42mscorlib_System_RuntimeTypeHandle_m_EqualsP33mscorlib_System_RuntimeTypeHandleP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $V_0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp + 8|0;
 $L_0 = sp + 12|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2247144);
 HEAP32[$V_0>>2] = 0;
 $2 = ($obj|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$__this>>2]|0;
 HEAP32[$L_0>>2] = $3;
 __THREW__ = 0;
 (invoke_ii(2996,(2247448|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_iii(2724,(2247448|0),($L_0|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vi(3799,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(1782,($6|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($obj|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_ii(1782,($obj|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = ($11|0)==($16|0);
       if (!($19)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $22 = HEAP32[$__this>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2247448|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_iii(2753,($obj|0),(2247448|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $28 = HEAP32[$25>>2]|0;
         HEAP32[$V_0>>2] = $28;
         __THREW__ = 0;
         $29 = (invoke_ii(1914,($V_0|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          HEAP32[$0>>2] = $22;
          HEAP32[$1>>2] = $29;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
          ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
          $32 = (invoke_iiii(643,0,($$byval_copy|0),($$byval_copy1|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           $$0 = $32;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_RuntimeTypeHandle_m_GetHashCodeP33mscorlib_System_RuntimeTypeHandle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2247192);
 __THREW__ = 0;
 $0 = (invoke_ii(1829,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z64mscorlib_System_RuntimeTypeHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2246752)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z107mscorlib_System_RuntimeTypeHandle_CustomAttributesCacheGenerator_mscorlib_System_RuntimeTypeHandle_m_EqualsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z43mscorlib_System_ParamArrayAttribute_m__ctorP35mscorlib_System_ParamArrayAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2247584);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z66mscorlib_System_ParamArrayAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,2048);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z60mscorlib_System_Runtime_InteropServices_OutAttribute_m__ctorP52mscorlib_System_Runtime_InteropServices_OutAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2247856);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_Runtime_InteropServices_OutAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,2048);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_ObsoleteAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2248120);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z109mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_Stringb($__this,$message,$error) {
 $__this = $__this|0;
 $message = $message|0;
 $error = $error|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2248216);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $message;
  $3 = (($__this) + 12|0);
  $4 = $error&1;
  HEAP8[$3>>0] = $4;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z64mscorlib_System_ObsoleteAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,6140);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_Runtime_InteropServices_DllImportAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,64);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z66mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m__ctorP58mscorlib_System_Runtime_InteropServices_MarshalAsAttributei($__this,$unmanagedType) {
 $__this = $__this|0;
 $unmanagedType = $unmanagedType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2248896);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $unmanagedType;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z89mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,10496);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z101mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_CustomAttributesCacheGenerator_MarshalTypeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z104mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_CustomAttributesCacheGenerator_MarshalTypeRefP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_Runtime_InteropServices_InAttribute_m__ctorP51mscorlib_System_Runtime_InteropServices_InAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2249520);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Runtime_InteropServices_InAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,2048);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Runtime_InteropServices_GuidAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,5149);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_Runtime_InteropServices_ComImportAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1028);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z65mscorlib_System_Runtime_InteropServices_OptionalAttribute_m__ctorP57mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2250384);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z88mscorlib_System_Runtime_InteropServices_OptionalAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,2048);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,32767);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m__ctorP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP22mscorlib_System_String($__this,$assemblyName) {
 $__this = $__this|0;
 $assemblyName = $assemblyName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2250968);
 $0 = (($__this) + 12|0);
 HEAP8[$0>>0] = 1;
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($__this) + 8|0);
  HEAP32[$3>>2] = $assemblyName;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z99mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z78mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m__ctorP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2251360);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z99mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_set_WrapNonExceptionThrowsP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2251408);
 $0 = (($__this) + 8|0);
 $1 = $value&1;
 HEAP8[$0>>0] = $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z101mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Diagnostics_DebuggerHiddenAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,224);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z66mscorlib_System_Reflection_DefaultMemberAttribute_m_get_MemberNameP49mscorlib_System_Reflection_DefaultMemberAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2252160);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z80mscorlib_System_Reflection_DefaultMemberAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1036);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker5I26mscorlib_System_ByteTraitsS0_28mscorlib_System_UInt32TraitsS1_S1_E6InvokeEPFvPvhhjjjES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$1,$4,$7,$10,$13);
 STACKTOP = sp;return (0|0);
}
function __Z96mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,2304);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z170mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m__ctorP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttributei($__this,$offset) {
 $__this = $__this|0;
 $offset = $offset|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2253056);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $offset;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z91mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,256);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_RuntimeArgumentHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z37mscorlib_System_AsyncCallback_m__ctorP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2253632);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z38mscorlib_System_AsyncCallback_m_InvokeP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$ar) {
 $__this = $__this|0;
 $ar = $ar|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2253680);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vii(1792,($1|0),($ar|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($10|0),($ar|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z43mscorlib_System_AsyncCallback_m_BeginInvokeP29mscorlib_System_AsyncCallbackP22mscorlib_System_ObjectS0_S2_($__this,$ar,$callback,$object) {
 $__this = $__this|0;
 $ar = $ar|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2253728);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z41mscorlib_System_AsyncCallback_m_EndInvokeP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2253776);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z60mscorlib_System_AsyncCallback_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_IAsyncResult_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z39mscorlib_System_TypedReference_m_EqualsP30mscorlib_System_TypedReferenceP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2254376);
 __THREW__ = 0;
 invoke_v(519);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3018664>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,0,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2622808|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2622808|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vii(1954,($8|0),($3|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($8|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_TypedReference_m_GetHashCodeP30mscorlib_System_TypedReference($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2254424);
 __THREW__ = 0;
 $3 = (invoke_ii(1914,($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2210080|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = HEAP32[((2210080 + 80|0))>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $3;
   HEAP32[$1>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
   $10 = (invoke_iiii(643,0,($$byval_copy|0),($$byval_copy2|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    if ($10) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $15 = HEAP32[$__this>>2]|0;
    HEAP32[$2>>2] = $15;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
    $16 = (invoke_iii(772,0,($$byval_copy2|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     invoke_vi(3799,($16|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      $21 = (invoke_iii(2729,(2236240|0),($16|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       $$0 = $21;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_TypedReference_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z36mscorlib_System_ArgIterator_m_EqualsP27mscorlib_System_ArgIteratorP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2254800);
 __THREW__ = 0;
 invoke_v(520);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3018776>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,0,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2622808|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2622808|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vii(1954,($8|0),($3|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3830,($8|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_ArgIterator_m_GetHashCodeP27mscorlib_System_ArgIterator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2254848);
 __THREW__ = 0;
 $0 = (invoke_ii(1829,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z65mscorlib_System_MarshalByRefObject_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Runtime_CompilerServices_RuntimeHelpers_m_InitializeArray_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_IntPtrP22mscorlib_System_ObjectP21mscorlib_System_Array22mscorlib_System_IntPtr($__this,$_____array,$fldHandle) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $fldHandle = $fldHandle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2255880);
 $1 = HEAP32[2255928>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2255936|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2255928>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$fldHandle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii($9|0,($_____array|0),($$byval_copy|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN14ActionInvoker2I17VoidPointerTraits28mscorlib_System_IntPtrTraitsE6InvokeEPFvPvS3_22mscorlib_System_IntPtrES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits40mscorlib_System_RuntimeFieldHandleTraitsE6InvokeEPFvPvS3_34mscorlib_System_RuntimeFieldHandleES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2256832);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z64mscorlib_System_MonoTODOAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,32767);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z86mscorlib_Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid_m_get_IsInvalidP70mscorlib_Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid($__this) {
 $__this = $__this|0;
 var $$byval_copy2 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $$byval_copy2 = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2257216);
 $4 = (($__this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 $6 = (invoke_iii(715,0,-1)|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  HEAP32[$0>>2] = $5;
  HEAP32[$1>>2] = $6;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
  $9 = (invoke_iiii(643,0,($$byval_copy2|0),($$byval_copy3|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   if ($9) {
    $G_B3_0$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
   $14 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   $15 = (invoke_iii(715,0,0)|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    HEAP32[$2>>2] = $14;
    HEAP32[$3>>2] = $15;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
    $18 = (invoke_iiii(643,0,($$byval_copy2|0),($$byval_copy3|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $G_B3_0$0 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_Microsoft_Win32_SafeHandles_SafeWaitHandle_m_ReleaseHandleP51mscorlib_Microsoft_Win32_SafeHandles_SafeWaitHandle($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2257568);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(1918,(0|0),($$byval_copy|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return 1;
 }
 return 0|0;
}
function __Z71mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m__ctorP63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeiii($__this,$start,$end,$indexStart) {
 $__this = $__this|0;
 $start = $start|0;
 $end = $end|0;
 $indexStart = $indexStart|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2257848);
 HEAP32[$__this>>2] = $start;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $end;
 $1 = (($end) - ($start))|0;
 $2 = (($__this) + 8|0);
 HEAP32[$2>>2] = $1;
 $3 = (($__this) + 12|0);
 HEAP32[$3>>2] = $indexStart;
 $4 = (($1) + ($indexStart))|0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $4;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker3I27mscorlib_System_Int32TraitsS0_S0_E6InvokeEPFvPviiiES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$4,$7);
 STACKTOP = sp;return (0|0);
}
function __Z60mscorlib_Mono_Globalization_Unicode_CodePointIndexer_m__ctorP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerP25mscorlib_System_Int32_arrS2_ii($__this,$starts,$ends,$defaultIndex,$defaultCP) {
 $__this = $__this|0;
 $starts = $starts|0;
 $ends = $ends|0;
 $defaultIndex = $defaultIndex|0;
 $defaultCP = $defaultCP|0;
 var $$pre = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B4_0$0 = 0, $L_20 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_20 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2258320);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 16|0);
  HEAP32[$2>>2] = $defaultIndex;
  $3 = (($__this) + 20|0);
  HEAP32[$3>>2] = $defaultCP;
  __THREW__ = 0;
  invoke_vi(3799,($starts|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($starts) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1227936|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2754,(1227936|0),($7|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = (($__this) + 8|0);
     HEAP32[$13>>2] = $10;
     $14 = (($starts) + 16|0);
     $15 = (($ends) + 16|0);
     $16 = (($ends) + 12|0);
     $111 = $10;$V_0$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($111|0));
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       label = 7;
       break;
      }
      $114 = (($111) + 12|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ($V_0$0|0)<($115|0);
      if (!($116)) {
       break;
      }
      $24 = HEAP32[$13>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($24|0));
      $118 = __THREW__; __THREW__ = 0;
      $119 = $118&1;
      if ($119) {
       label = 7;
       break;
      }
      $23 = (($24) + 12|0);
      $25 = HEAP32[$23>>2]|0;
      $26 = ($V_0$0>>>0)<($25>>>0);
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_i(132)|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($27|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 7;
        break;
       }
      }
      $32 = HEAP32[$24>>2]|0;
      $33 = (($24) + 16|0);
      $34 = (($32) + 92|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = Math_imul($35, $V_0$0)|0;
      $37 = (($33) + ($36)|0);
      __THREW__ = 0;
      invoke_vi(3799,($starts|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 7;
       break;
      }
      $40 = HEAP32[$6>>2]|0;
      $41 = ($V_0$0>>>0)<($40>>>0);
      if (!($41)) {
       __THREW__ = 0;
       $42 = (invoke_i(132)|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($42|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        label = 7;
        break;
       }
      }
      $47 = HEAP32[$starts>>2]|0;
      $48 = (($47) + 92|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = Math_imul($49, $V_0$0)|0;
      $51 = (($14) + ($50)|0);
      $52 = HEAP32[$51>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($ends|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 7;
       break;
      }
      $55 = HEAP32[$16>>2]|0;
      $56 = ($V_0$0>>>0)<($55>>>0);
      if (!($56)) {
       __THREW__ = 0;
       $57 = (invoke_i(132)|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($57|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 7;
        break;
       }
      }
      $62 = HEAP32[$ends>>2]|0;
      $63 = (($62) + 92|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = Math_imul($64, $V_0$0)|0;
      $66 = (($15) + ($65)|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($V_0$0|0)==(0);
      if ($68) {
       $G_B4_0$0 = 0;
      } else {
       $69 = HEAP32[$13>>2]|0;
       $70 = (($V_0$0) + -1)|0;
       __THREW__ = 0;
       invoke_vi(3799,($69|0));
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        label = 7;
        break;
       }
       $73 = ($V_0$0|0)<(1);
       if ($73) {
        label = 25;
       } else {
        $74 = (($69) + 12|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = ($70>>>0)<($75>>>0);
        if (!($76)) {
         label = 25;
        }
       }
       if ((label|0) == 25) {
        label = 0;
        __THREW__ = 0;
        $77 = (invoke_i(132)|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 7;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 7;
         break;
        }
       }
       $82 = HEAP32[$69>>2]|0;
       $83 = (($69) + 16|0);
       $84 = (($82) + 92|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = Math_imul($85, $70)|0;
       $$sum1 = (($86) + 12)|0;
       $87 = (($83) + ($$sum1)|0);
       $88 = HEAP32[$87>>2]|0;
       $89 = HEAP32[$13>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($89|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        label = 7;
        break;
       }
       if ($73) {
        label = 30;
       } else {
        $92 = (($89) + 12|0);
        $93 = HEAP32[$92>>2]|0;
        $94 = ($70>>>0)<($93>>>0);
        if (!($94)) {
         label = 30;
        }
       }
       if ((label|0) == 30) {
        label = 0;
        __THREW__ = 0;
        $95 = (invoke_i(132)|0);
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         label = 7;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($95|0));
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         label = 7;
         break;
        }
       }
       $100 = HEAP32[$89>>2]|0;
       $101 = (($89) + 16|0);
       $102 = (($100) + 92|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = Math_imul($103, $70)|0;
       $$sum2 = (($104) + 8)|0;
       $105 = (($101) + ($$sum2)|0);
       $106 = HEAP32[$105>>2]|0;
       $107 = (($106) + ($88))|0;
       $G_B4_0$0 = $107;
      }
      ;HEAP32[$L_20+0>>2]=0|0;HEAP32[$L_20+4>>2]=0|0;HEAP32[$L_20+8>>2]=0|0;HEAP32[$L_20+12>>2]=0|0;HEAP32[$L_20+16>>2]=0|0;
      __THREW__ = 0;
      invoke_viiii(145,($L_20|0),($52|0),($67|0),($G_B4_0$0|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       label = 7;
       break;
      }
      ;HEAP32[$37+0>>2]=HEAP32[$L_20+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$L_20+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$L_20+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$L_20+12>>2]|0;HEAP32[$37+16>>2]=HEAP32[$L_20+16>>2]|0;
      $110 = (($V_0$0) + 1)|0;
      $$pre = HEAP32[$13>>2]|0;
      $111 = $$pre;$V_0$0 = $110;
     }
     if ((label|0) == 7) {
      $19 = ___cxa_find_matching_catch()|0;
      $20 = tempRet0;
      $lpad$phi$index = $19;$lpad$phi$index3 = $20;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     $117 = (($__this) + 12|0);
     $V_1$0 = 0;
     while(1) {
      $143 = HEAP32[$13>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($143|0));
      $144 = __THREW__; __THREW__ = 0;
      $145 = $144&1;
      if ($145) {
       break;
      }
      $146 = (($143) + 12|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = ($V_1$0|0)<($147|0);
      if (!($148)) {
       label = 48;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $149 = __THREW__; __THREW__ = 0;
      $150 = $149&1;
      if ($150) {
       break;
      }
      $120 = HEAP32[$117>>2]|0;
      $121 = HEAP32[$13>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($121|0));
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       break;
      }
      $124 = (($121) + 12|0);
      $125 = HEAP32[$124>>2]|0;
      $126 = ($V_1$0>>>0)<($125>>>0);
      if (!($126)) {
       __THREW__ = 0;
       $127 = (invoke_i(132)|0);
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($127|0));
       $130 = __THREW__; __THREW__ = 0;
       $131 = $130&1;
       if ($131) {
        break;
       }
      }
      $132 = HEAP32[$121>>2]|0;
      $133 = (($121) + 16|0);
      $134 = (($132) + 92|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = Math_imul($135, $V_1$0)|0;
      $$sum = (($136) + 8)|0;
      $137 = (($133) + ($$sum)|0);
      $138 = HEAP32[$137>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $139 = __THREW__; __THREW__ = 0;
      $140 = $139&1;
      if ($140) {
       break;
      }
      $141 = (($138) + ($120))|0;
      HEAP32[$117>>2] = $141;
      $142 = (($V_1$0) + 1)|0;
      $V_1$0 = $142;
     }
     if ((label|0) == 48) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $17 = ___cxa_find_matching_catch()|0;
     $18 = tempRet0;
     $lpad$phi$index = $17;$lpad$phi$index3 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $lpad$phi$index = $21;$lpad$phi$index3 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z62mscorlib_Mono_Globalization_Unicode_CodePointIndexer_m_ToIndexP52mscorlib_Mono_Globalization_Unicode_CodePointIndexeri($__this,$cp) {
 $__this = $__this|0;
 $cp = $cp|0;
 var $$0 = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2258368);
 $0 = (($__this) + 8|0);
 $V_0$0 = 0;
 while(1) {
  $82 = HEAP32[$0>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($82|0));
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if ($84) {
   label = 5;
   break;
  }
  $85 = (($82) + 12|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($V_0$0|0)<($86|0);
  if (!($87)) {
   label = 27;
   break;
  }
  $2 = HEAP32[$0>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($2|0));
  $88 = __THREW__; __THREW__ = 0;
  $89 = $88&1;
  if ($89) {
   label = 5;
   break;
  }
  $1 = (($2) + 12|0);
  $3 = HEAP32[$1>>2]|0;
  $4 = ($V_0$0>>>0)<($3>>>0);
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_i(132)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 5;
    break;
   }
  }
  $14 = HEAP32[$2>>2]|0;
  $15 = (($2) + 16|0);
  $16 = (($14) + 92|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = Math_imul($17, $V_0$0)|0;
  $19 = (($15) + ($18)|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)>($cp|0);
  if ($21) {
   label = 9;
   break;
  }
  $24 = HEAP32[$0>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($24|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   label = 5;
   break;
  }
  $27 = (($24) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ($V_0$0>>>0)<($28>>>0);
  if (!($29)) {
   __THREW__ = 0;
   $30 = (invoke_i(132)|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($30|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 5;
    break;
   }
  }
  $35 = HEAP32[$24>>2]|0;
  $36 = (($24) + 16|0);
  $37 = (($35) + 92|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = Math_imul($38, $V_0$0)|0;
  $$sum = (($39) + 4)|0;
  $40 = (($36) + ($$sum)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)>($cp|0);
  $43 = (($V_0$0) + 1)|0;
  if ($42) {
   label = 15;
   break;
  } else {
   $V_0$0 = $43;
  }
 }
 if ((label|0) == 5) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  $22 = (($__this) + 16|0);
  $23 = HEAP32[$22>>2]|0;
  $$0 = $23;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 15) {
  $44 = HEAP32[$0>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($44|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  do {
   if (!($46)) {
    $47 = (($44) + 12|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($V_0$0>>>0)<($48>>>0);
    if (!($49)) {
     __THREW__ = 0;
     $50 = (invoke_i(132)|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($50|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
    }
    $55 = HEAP32[$44>>2]|0;
    $56 = (($44) + 16|0);
    $57 = (($55) + 92|0);
    $58 = HEAP32[$57>>2]|0;
    $59 = Math_imul($58, $V_0$0)|0;
    $60 = (($56) + ($59)|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = (($cp) - ($61))|0;
    $63 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($63|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if (!($65)) {
     $66 = (($63) + 12|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = ($V_0$0>>>0)<($67>>>0);
     if (!($68)) {
      __THREW__ = 0;
      $69 = (invoke_i(132)|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($69|0));
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       break;
      }
     }
     $74 = HEAP32[$63>>2]|0;
     $75 = (($63) + 16|0);
     $76 = (($74) + 92|0);
     $77 = HEAP32[$76>>2]|0;
     $78 = Math_imul($77, $V_0$0)|0;
     $$sum1 = (($78) + 12)|0;
     $79 = (($75) + ($$sum1)|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = (($62) + ($80))|0;
     $$0 = $81;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } while(0);
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index2 = $13;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 27) {
  $90 = (($__this) + 16|0);
  $91 = HEAP32[$90>>2]|0;
  $$0 = $91;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z57mscorlib_Mono_Globalization_Unicode_TailoringInfo_m__ctorP49mscorlib_Mono_Globalization_Unicode_TailoringInfoiiib($__this,$lcid,$tailoringIndex,$tailoringCount,$frenchSort) {
 $__this = $__this|0;
 $lcid = $lcid|0;
 $tailoringIndex = $tailoringIndex|0;
 $tailoringCount = $tailoringCount|0;
 $frenchSort = $frenchSort|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2258896);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $lcid;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $tailoringIndex;
  $4 = (($__this) + 16|0);
  HEAP32[$4>>2] = $tailoringCount;
  $5 = (($__this) + 20|0);
  $6 = $frenchSort&1;
  HEAP8[$5>>0] = $6;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN14ActionInvoker4I27mscorlib_System_Int32TraitsS0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFvPviiibES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$1,$4,$7,$11);
 STACKTOP = sp;return (0|0);
}
function __Z55mscorlib_Mono_Globalization_Unicode_Contraction_m__ctorP47mscorlib_Mono_Globalization_Unicode_ContractionP24mscorlib_System_Char_arrP22mscorlib_System_StringP24mscorlib_System_Byte_arr($__this,$source,$replacement,$sortkey) {
 $__this = $__this|0;
 $source = $source|0;
 $replacement = $replacement|0;
 $sortkey = $sortkey|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2259352);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $source;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $replacement;
  $4 = (($__this) + 16|0);
  HEAP32[$4>>2] = $sortkey;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z63mscorlib_Mono_Globalization_Unicode_ContractionComparer_m__ctorP55mscorlib_Mono_Globalization_Unicode_ContractionComparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2259744);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z64mscorlib_Mono_Globalization_Unicode_ContractionComparer_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2259792);
 __THREW__ = 0;
 (invoke_ii(2996,(2260048|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2260048|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2127,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2260048|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2260048 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z65mscorlib_Mono_Globalization_Unicode_ContractionComparer_m_CompareP55mscorlib_Mono_Globalization_Unicode_ContractionComparerP22mscorlib_System_ObjectS2_($__this,$o1,$o2) {
 $__this = $__this|0;
 $o1 = $o1|0;
 $o2 = $o2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B3_0$0 = 0, $G_B3_0$0$in = 0, $V_5$08 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2259840);
 __THREW__ = 0;
 (invoke_ii(2996,(2259608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2755,($o1|0),(2259608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2259608|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(2755,($o2|0),(2259608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($2) + 8|0);
       $13 = HEAP32[$12>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($7|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        $16 = (($7) + 8|0);
        $17 = HEAP32[$16>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($13|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         $20 = (($13) + 12|0);
         $21 = HEAP32[$20>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($17|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          $24 = (($17) + 12|0);
          $25 = HEAP32[$24>>2]|0;
          $26 = ($21|0)>($25|0);
          if ($26) {
           __THREW__ = 0;
           invoke_vi(3799,($17|0));
           $31 = __THREW__; __THREW__ = 0;
           $32 = $31&1;
           if ($32) {
            break;
           } else {
            $G_B3_0$0$in = $24;
           }
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if ($34) {
            break;
           } else {
            $G_B3_0$0$in = $20;
           }
          }
          $G_B3_0$0 = HEAP32[$G_B3_0$0$in>>2]|0;
          $35 = ($G_B3_0$0|0)>(0);
          L14: do {
           if ($35) {
            $36 = (($13) + 16|0);
            $37 = (($17) + 16|0);
            $V_5$08 = 0;
            while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($13|0));
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             if ($103) {
              label = 10;
              break;
             }
             $38 = HEAP32[$20>>2]|0;
             $39 = ($V_5$08>>>0)<($38>>>0);
             if (!($39)) {
              __THREW__ = 0;
              $40 = (invoke_i(132)|0);
              $41 = __THREW__; __THREW__ = 0;
              $42 = $41&1;
              if ($42) {
               label = 10;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($40|0));
              $43 = __THREW__; __THREW__ = 0;
              $44 = $43&1;
              if ($44) {
               label = 10;
               break;
              }
             }
             $45 = HEAP32[$13>>2]|0;
             $46 = (($45) + 92|0);
             $47 = HEAP32[$46>>2]|0;
             $48 = Math_imul($47, $V_5$08)|0;
             $49 = (($36) + ($48)|0);
             $50 = HEAP16[$49>>1]|0;
             __THREW__ = 0;
             invoke_vi(3799,($17|0));
             $51 = __THREW__; __THREW__ = 0;
             $52 = $51&1;
             if ($52) {
              label = 10;
              break;
             }
             $53 = HEAP32[$24>>2]|0;
             $54 = ($V_5$08>>>0)<($53>>>0);
             if (!($54)) {
              __THREW__ = 0;
              $55 = (invoke_i(132)|0);
              $56 = __THREW__; __THREW__ = 0;
              $57 = $56&1;
              if ($57) {
               label = 10;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($55|0));
              $58 = __THREW__; __THREW__ = 0;
              $59 = $58&1;
              if ($59) {
               label = 10;
               break;
              }
             }
             $60 = HEAP32[$17>>2]|0;
             $61 = (($60) + 92|0);
             $62 = HEAP32[$61>>2]|0;
             $63 = Math_imul($62, $V_5$08)|0;
             $64 = (($37) + ($63)|0);
             $65 = HEAP16[$64>>1]|0;
             $66 = ($50<<16>>16)==($65<<16>>16);
             $67 = (($V_5$08) + 1)|0;
             if (!($66)) {
              break;
             }
             $101 = ($67|0)<($G_B3_0$0|0);
             if ($101) {
              $V_5$08 = $67;
             } else {
              break L14;
             }
            }
            if ((label|0) == 10) {
             $27 = ___cxa_find_matching_catch()|0;
             $28 = tempRet0;
             $lpad$phi$index = $27;$lpad$phi$index2 = $28;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break L1;
            }
            $70 = HEAP32[$20>>2]|0;
            $71 = ($V_5$08>>>0)<($70>>>0);
            if (!($71)) {
             __THREW__ = 0;
             $72 = (invoke_i(132)|0);
             $73 = __THREW__; __THREW__ = 0;
             $74 = $73&1;
             if ($74) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3302,($72|0));
             $75 = __THREW__; __THREW__ = 0;
             $76 = $75&1;
             if ($76) {
              break L1;
             }
            }
            $77 = HEAP32[$13>>2]|0;
            $78 = (($77) + 92|0);
            $79 = HEAP32[$78>>2]|0;
            $80 = Math_imul($79, $V_5$08)|0;
            $81 = (($36) + ($80)|0);
            $82 = HEAP16[$81>>1]|0;
            __THREW__ = 0;
            invoke_vi(3799,($17|0));
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if ($84) {
             break L1;
            }
            $85 = HEAP32[$24>>2]|0;
            $86 = ($V_5$08>>>0)<($85>>>0);
            if (!($86)) {
             __THREW__ = 0;
             $87 = (invoke_i(132)|0);
             $88 = __THREW__; __THREW__ = 0;
             $89 = $88&1;
             if ($89) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3302,($87|0));
             $90 = __THREW__; __THREW__ = 0;
             $91 = $90&1;
             if ($91) {
              break L1;
             }
            }
            $92 = HEAP32[$17>>2]|0;
            $93 = (($92) + 92|0);
            $94 = HEAP32[$93>>2]|0;
            $95 = Math_imul($94, $V_5$08)|0;
            $96 = (($37) + ($95)|0);
            $97 = HEAP16[$96>>1]|0;
            $98 = $82&65535;
            $99 = $97&65535;
            $100 = (($98) - ($99))|0;
            $$0 = $100;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3799,($13|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if (!($105)) {
           $106 = HEAP32[$20>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($17|0));
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if (!($108)) {
            $109 = HEAP32[$24>>2]|0;
            $110 = (($106) - ($109))|0;
            $$0 = $110;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $lpad$phi$index = $29;$lpad$phi$index2 = $30;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_Mono_Globalization_Unicode_Level2Map_m__ctorP45mscorlib_Mono_Globalization_Unicode_Level2Maphh($__this,$source,$replace) {
 $__this = $__this|0;
 $source = $source|0;
 $replace = $replace|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2260184);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP8[$2>>0] = $source;
  $3 = (($__this) + 9|0);
  HEAP8[$3>>0] = $replace;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN14ActionInvoker2I26mscorlib_System_ByteTraitsS0_E6InvokeEPFvPvhhES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$4);
 STACKTOP = sp;return (0|0);
}
function __Z61mscorlib_Mono_Globalization_Unicode_Level2MapComparer_m__ctorP53mscorlib_Mono_Globalization_Unicode_Level2MapComparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2260504);
 __THREW__ = 0;
 invoke_vi(1924,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62mscorlib_Mono_Globalization_Unicode_Level2MapComparer_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2260552);
 __THREW__ = 0;
 (invoke_ii(2996,(2260792|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2260792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2129,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2260792|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2260792 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z63mscorlib_Mono_Globalization_Unicode_Level2MapComparer_m_CompareP53mscorlib_Mono_Globalization_Unicode_Level2MapComparerP22mscorlib_System_ObjectS2_($__this,$o1,$o2) {
 $__this = $__this|0;
 $o1 = $o1|0;
 $o2 = $o2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2260600);
 __THREW__ = 0;
 (invoke_ii(2996,(2260368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2755,($o1|0),(2260368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2260368|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2755,($o2|0),(2260368|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = (($2) + 8|0);
      $13 = HEAP8[$12>>0]|0;
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = (($7) + 8|0);
       $17 = HEAP8[$16>>0]|0;
       $18 = $13&255;
       $19 = $17&255;
       $20 = (($18) - ($19))|0;
       $21 = $20 & 255;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($21|0);
      }
     }
    }
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy10 = 0, $$byval_copy12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_11$019 = 0, $V_3$0$lcssa = 0, $V_3$026 = 0;
 var $V_3$120 = 0, $V_6$025 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy12 = sp + 32|0;
 $$byval_copy10 = sp + 28|0;
 $_stackTraceSentry = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2260928);
 __THREW__ = 0;
 invoke_v(521);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if (!($7)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[((2263896 + 80|0))>>2]|0;
    HEAP32[$10>>2] = 3;
    __THREW__ = 0;
    (invoke_ii(2996,(2149728|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_ii(3469,(2149728|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(1924,0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $20 = HEAP32[((2263896 + 80|0))>>2]|0;
        $21 = (($20) + 68|0);
        HEAP32[$21>>2] = $13;
        $22 = HEAP32[3018952>>2]|0;
        __THREW__ = 0;
        $23 = (invoke_iii(797,0,($22|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2210080|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          $28 = HEAP32[((2210080 + 80|0))>>2]|0;
          $29 = HEAP32[$28>>2]|0;
          HEAP32[$0>>2] = $23;
          HEAP32[$1>>2] = $29;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
          ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$1+0>>2]|0;
          $30 = (invoke_iiii(643,0,($$byval_copy10|0),($$byval_copy12|0))|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           if ($30) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           HEAP32[$2>>2] = $23;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$2+0>>2]|0;
           $39 = (invoke_iii(718,0,($$byval_copy12|0))|0);
           $40 = __THREW__; __THREW__ = 0;
           $41 = $40&1;
           if (!($41)) {
            $42 = HEAP32[3018960>>2]|0;
            __THREW__ = 0;
            $43 = (invoke_iii(797,0,($42|0))|0);
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2210080|0))|0);
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if (!($47)) {
              $48 = HEAP32[((2210080 + 80|0))>>2]|0;
              $49 = HEAP32[$48>>2]|0;
              HEAP32[$3>>2] = $43;
              HEAP32[$4>>2] = $49;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
              ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$4+0>>2]|0;
              $50 = (invoke_iiii(643,0,($$byval_copy10|0),($$byval_copy12|0))|0);
              $51 = __THREW__; __THREW__ = 0;
              $52 = $51&1;
              if (!($52)) {
               if ($50) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
               HEAP32[$5>>2] = $43;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy12+0>>2]=HEAP32[$5+0>>2]|0;
               $53 = (invoke_iii(718,0,($$byval_copy12|0))|0);
               $54 = __THREW__; __THREW__ = 0;
               $55 = $54&1;
               if (!($55)) {
                $56 = ($39|0)==(0|0);
                $57 = ($53|0)==(0|0);
                $or$cond = $56 | $57;
                if ($or$cond) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                $58 = HEAP8[$39>>0]|0;
                $59 = ($58<<24>>24)==(3);
                if (!($59)) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                $60 = HEAP8[$53>>0]|0;
                $61 = ($60<<24>>24)==(3);
                if (!($61)) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                __THREW__ = 0;
                $62 = (invoke_iiii(737,0,($39|0),1)|0);
                $63 = __THREW__; __THREW__ = 0;
                $64 = $63&1;
                if ($64) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $65 = __THREW__; __THREW__ = 0;
                $66 = $65&1;
                if ($66) {
                 break;
                }
                $67 = (($39) + 5|0);
                $68 = HEAP32[((2263896 + 80|0))>>2]|0;
                $69 = (($68) + 4|0);
                HEAP32[$69>>2] = $67;
                $70 = (($62) + 5)|0;
                __THREW__ = 0;
                $71 = (invoke_iiii(737,0,($39|0),($70|0))|0);
                $72 = __THREW__; __THREW__ = 0;
                $73 = $72&1;
                if ($73) {
                 break;
                }
                $74 = (($62) + 9)|0;
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $75 = __THREW__; __THREW__ = 0;
                $76 = $75&1;
                if ($76) {
                 break;
                }
                $77 = (($39) + ($74)|0);
                $78 = HEAP32[((2263896 + 80|0))>>2]|0;
                $79 = (($78) + 8|0);
                HEAP32[$79>>2] = $77;
                $80 = (($71) + ($74))|0;
                __THREW__ = 0;
                $81 = (invoke_iiii(737,0,($39|0),($80|0))|0);
                $82 = __THREW__; __THREW__ = 0;
                $83 = $82&1;
                if ($83) {
                 break;
                }
                $84 = (($80) + 4)|0;
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $85 = __THREW__; __THREW__ = 0;
                $86 = $85&1;
                if ($86) {
                 break;
                }
                $87 = (($39) + ($84)|0);
                $88 = HEAP32[((2263896 + 80|0))>>2]|0;
                $89 = (($88) + 12|0);
                HEAP32[$89>>2] = $87;
                $90 = (($81) + ($84))|0;
                __THREW__ = 0;
                $91 = (invoke_iiii(737,0,($39|0),($90|0))|0);
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 break;
                }
                $94 = (($90) + 4)|0;
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $95 = __THREW__; __THREW__ = 0;
                $96 = $95&1;
                if ($96) {
                 break;
                }
                $97 = (($39) + ($94)|0);
                $98 = HEAP32[((2263896 + 80|0))>>2]|0;
                $99 = (($98) + 16|0);
                HEAP32[$99>>2] = $97;
                $100 = (($91) + ($94))|0;
                __THREW__ = 0;
                (invoke_iiii(737,0,($39|0),($100|0))|0);
                $101 = __THREW__; __THREW__ = 0;
                $102 = $101&1;
                if ($102) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $103 = __THREW__; __THREW__ = 0;
                $104 = $103&1;
                if ($104) {
                 break;
                }
                $105 = (($100) + 4)|0;
                $106 = (($39) + ($105)|0);
                $107 = HEAP32[((2263896 + 80|0))>>2]|0;
                $108 = (($107) + 20|0);
                HEAP32[$108>>2] = $106;
                __THREW__ = 0;
                $109 = (invoke_iiii(737,0,($53|0),1)|0);
                $110 = __THREW__; __THREW__ = 0;
                $111 = $110&1;
                if ($111) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1228352|0))|0);
                $112 = __THREW__; __THREW__ = 0;
                $113 = $112&1;
                if ($113) {
                 break;
                }
                __THREW__ = 0;
                $114 = (invoke_iii(2754,(1228352|0),($109|0))|0);
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if ($116) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 break;
                }
                $119 = HEAP32[((2263896 + 80|0))>>2]|0;
                $120 = (($119) + 64|0);
                HEAP32[$120>>2] = $114;
                $121 = ($109|0)==(0);
                L45: do {
                 if ($121) {
                  $V_3$0$lcssa = 5;
                 } else {
                  $V_3$026 = 5;$V_6$025 = 0;
                  while(1) {
                   __THREW__ = 0;
                   $140 = (invoke_iiii(737,0,($53|0),($V_3$026|0))|0);
                   $174 = __THREW__; __THREW__ = 0;
                   $175 = $174&1;
                   if ($175) {
                    break;
                   }
                   $122 = (($V_3$026) + 4)|0;
                   __THREW__ = 0;
                   $123 = (invoke_iiii(737,0,($53|0),($122|0))|0);
                   $124 = __THREW__; __THREW__ = 0;
                   $125 = $124&1;
                   if ($125) {
                    break;
                   }
                   $126 = (($V_3$026) + 8)|0;
                   __THREW__ = 0;
                   $127 = (invoke_iiii(737,0,($53|0),($126|0))|0);
                   $128 = __THREW__; __THREW__ = 0;
                   $129 = $128&1;
                   if ($129) {
                    break;
                   }
                   $130 = (($V_3$026) + 12)|0;
                   $131 = (($V_3$026) + 13)|0;
                   $132 = (($53) + ($130)|0);
                   $133 = HEAP8[$132>>0]|0;
                   $134 = ($133<<24>>24)!=(0);
                   __THREW__ = 0;
                   (invoke_ii(2996,(2259216|0))|0);
                   $135 = __THREW__; __THREW__ = 0;
                   $136 = $135&1;
                   if ($136) {
                    break;
                   }
                   __THREW__ = 0;
                   $137 = (invoke_ii(3469,(2259216|0))|0);
                   $138 = __THREW__; __THREW__ = 0;
                   $139 = $138&1;
                   if ($139) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viiiii(56,($137|0),($140|0),($123|0),($127|0),($134|0));
                   $141 = __THREW__; __THREW__ = 0;
                   $142 = $141&1;
                   if ($142) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2263896|0))|0);
                   $143 = __THREW__; __THREW__ = 0;
                   $144 = $143&1;
                   if ($144) {
                    break;
                   }
                   $145 = HEAP32[((2263896 + 80|0))>>2]|0;
                   $146 = (($145) + 64|0);
                   $147 = HEAP32[$146>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($147|0));
                   $148 = __THREW__; __THREW__ = 0;
                   $149 = $148&1;
                   if ($149) {
                    break;
                   }
                   $150 = (($147) + 12|0);
                   $151 = HEAP32[$150>>2]|0;
                   $152 = ($V_6$025>>>0)<($151>>>0);
                   if (!($152)) {
                    __THREW__ = 0;
                    $153 = (invoke_i(132)|0);
                    $154 = __THREW__; __THREW__ = 0;
                    $155 = $154&1;
                    if ($155) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($153|0));
                    $156 = __THREW__; __THREW__ = 0;
                    $157 = $156&1;
                    if ($157) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($147|0),($137|0));
                   $158 = __THREW__; __THREW__ = 0;
                   $159 = $158&1;
                   if ($159) {
                    break;
                   }
                   $160 = HEAP32[$147>>2]|0;
                   $161 = (($147) + 16|0);
                   $162 = (($160) + 92|0);
                   $163 = HEAP32[$162>>2]|0;
                   $164 = Math_imul($163, $V_6$025)|0;
                   $165 = (($161) + ($164)|0);
                   HEAP32[$165>>2] = $137;
                   $166 = (($V_6$025) + 1)|0;
                   $167 = ($166|0)<(0);
                   $168 = $167 << 31 >> 31;
                   $169 = ($168>>>0)<(0);
                   $170 = ($168|0)==(0);
                   $171 = ($166>>>0)<($109>>>0);
                   $172 = $170 & $171;
                   $173 = $169 | $172;
                   if ($173) {
                    $V_3$026 = $131;$V_6$025 = $166;
                   } else {
                    $V_3$0$lcssa = $131;
                    break L45;
                   }
                  }
                  $35 = ___cxa_find_matching_catch()|0;
                  $36 = tempRet0;
                  $lpad$phi$index = $35;$lpad$phi$index3 = $36;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($lpad$phi$index|0);
                  // unreachable;
                 }
                } while(0);
                $176 = (($V_3$0$lcssa) + 2)|0;
                __THREW__ = 0;
                $177 = (invoke_iiii(737,0,($53|0),($176|0))|0);
                $178 = __THREW__; __THREW__ = 0;
                $179 = $178&1;
                if ($179) {
                 break;
                }
                $180 = (($V_3$0$lcssa) + 6)|0;
                __THREW__ = 0;
                (invoke_ii(2996,(1168808|0))|0);
                $181 = __THREW__; __THREW__ = 0;
                $182 = $181&1;
                if ($182) {
                 break;
                }
                __THREW__ = 0;
                $183 = (invoke_iii(2754,(1168808|0),($177|0))|0);
                $184 = __THREW__; __THREW__ = 0;
                $185 = $184&1;
                if ($185) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $186 = __THREW__; __THREW__ = 0;
                $187 = $186&1;
                if ($187) {
                 break;
                }
                $188 = HEAP32[((2263896 + 80|0))>>2]|0;
                $189 = (($188) + 60|0);
                HEAP32[$189>>2] = $183;
                $190 = ($177|0)==(0);
                L68: do {
                 if (!($190)) {
                  $V_11$019 = 0;$V_3$120 = $180;
                  while(1) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2263896|0))|0);
                   $229 = __THREW__; __THREW__ = 0;
                   $230 = $229&1;
                   if ($230) {
                    break;
                   }
                   $191 = HEAP32[((2263896 + 80|0))>>2]|0;
                   $192 = (($191) + 60|0);
                   $193 = HEAP32[$192>>2]|0;
                   $194 = (($53) + ($V_3$120)|0);
                   $195 = HEAP8[$194>>0]|0;
                   $196 = $195&255;
                   $197 = (($V_3$120) + 1)|0;
                   $198 = (($53) + ($197)|0);
                   $199 = HEAP8[$198>>0]|0;
                   $200 = $199&255;
                   $201 = $200 << 8;
                   $202 = $201 | $196;
                   $203 = $202&65535;
                   __THREW__ = 0;
                   invoke_vi(3799,($193|0));
                   $204 = __THREW__; __THREW__ = 0;
                   $205 = $204&1;
                   if ($205) {
                    break;
                   }
                   $206 = (($193) + 12|0);
                   $207 = HEAP32[$206>>2]|0;
                   $208 = ($V_11$019>>>0)<($207>>>0);
                   if (!($208)) {
                    __THREW__ = 0;
                    $209 = (invoke_i(132)|0);
                    $210 = __THREW__; __THREW__ = 0;
                    $211 = $210&1;
                    if ($211) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($209|0));
                    $212 = __THREW__; __THREW__ = 0;
                    $213 = $212&1;
                    if ($213) {
                     break;
                    }
                   }
                   $214 = HEAP32[$193>>2]|0;
                   $215 = (($193) + 16|0);
                   $216 = (($214) + 92|0);
                   $217 = HEAP32[$216>>2]|0;
                   $218 = Math_imul($217, $V_11$019)|0;
                   $219 = (($215) + ($218)|0);
                   HEAP16[$219>>1] = $203;
                   $220 = (($V_11$019) + 1)|0;
                   $221 = (($V_3$120) + 2)|0;
                   $222 = ($220|0)<(0);
                   $223 = $222 << 31 >> 31;
                   $224 = ($223>>>0)<(0);
                   $225 = ($223|0)==(0);
                   $226 = ($220>>>0)<($177>>>0);
                   $227 = $225 & $226;
                   $228 = $224 | $227;
                   if ($228) {
                    $V_11$019 = $220;$V_3$120 = $221;
                   } else {
                    break L68;
                   }
                  }
                  $33 = ___cxa_find_matching_catch()|0;
                  $34 = tempRet0;
                  $lpad$phi$index = $33;$lpad$phi$index3 = $34;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($lpad$phi$index|0);
                  // unreachable;
                 }
                } while(0);
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $231 = __THREW__; __THREW__ = 0;
                $232 = $231&1;
                if ($232) {
                 break;
                }
                $233 = HEAP32[((2263896 + 80|0))>>2]|0;
                $234 = (($233) + 72|0);
                HEAP8[$234>>0] = 1;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 $lpad$phi$index = $37;$lpad$phi$index3 = $38;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z70mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_GetResourceP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261696);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(2188,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiiii(137,($0|0),($name|0),($V_0|0),($V_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_UInt32FromBytePtrP22mscorlib_System_ObjectPhj($__this,$raw,$idx) {
 $__this = $__this|0;
 $raw = $raw|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261744);
 $0 = (($raw) + ($idx)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = (($idx) + 1)|0;
 $4 = (($raw) + ($3)|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 << 8;
 $8 = $7 | $2;
 $9 = (($idx) + 2)|0;
 $10 = (($raw) + ($9)|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 16;
 $14 = $8 | $13;
 $15 = (($idx) + 3)|0;
 $16 = (($raw) + ($15)|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 $19 = $18 << 24;
 $20 = $14 | $19;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($20|0);
}
function __Z75mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_GetTailoringInfoP22mscorlib_System_Objecti($__this,$lcid) {
 $__this = $__this|0;
 $lcid = $lcid|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2260976);
 $V_0$0 = 0;
 while(1) {
  __THREW__ = 0;
  (invoke_ii(2996,(2263896|0))|0);
  $72 = __THREW__; __THREW__ = 0;
  $73 = $72&1;
  if ($73) {
   label = 6;
   break;
  }
  $74 = HEAP8[((2263896 + 116|0))>>0]|0;
  $75 = ($74<<24>>24)==(0);
  if ($75) {
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3831,(2263896|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    label = 6;
    break;
   }
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2263896|0))|0);
  $82 = __THREW__; __THREW__ = 0;
  $83 = $82&1;
  if ($83) {
   label = 6;
   break;
  }
  $84 = HEAP32[((2263896 + 80|0))>>2]|0;
  $85 = (($84) + 64|0);
  $86 = HEAP32[$85>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($86|0));
  $87 = __THREW__; __THREW__ = 0;
  $88 = $87&1;
  if ($88) {
   label = 6;
   break;
  }
  $89 = (($86) + 12|0);
  $90 = HEAP32[$89>>2]|0;
  $91 = ($V_0$0|0)<($90|0);
  if (!($91)) {
   $$0 = 0;
   label = 36;
   break;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2263896|0))|0);
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $0 = HEAP8[((2263896 + 116|0))>>0]|0;
  $1 = ($0<<24>>24)==(0);
  if ($1) {
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if ($3) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3831,(2263896|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 6;
    break;
   }
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2263896|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   label = 6;
   break;
  }
  $14 = HEAP32[((2263896 + 80|0))>>2]|0;
  $15 = (($14) + 64|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   label = 6;
   break;
  }
  $19 = (($16) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($V_0$0>>>0)<($20>>>0);
  if (!($21)) {
   __THREW__ = 0;
   $22 = (invoke_i(132)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($22|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 6;
    break;
   }
  }
  $27 = HEAP32[$16>>2]|0;
  $28 = (($16) + 16|0);
  $29 = (($27) + 92|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = Math_imul($30, $V_0$0)|0;
  $32 = (($28) + ($31)|0);
  $33 = HEAP32[$32>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 6;
   break;
  }
  $36 = (($33) + 8|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==($lcid|0);
  $39 = (($V_0$0) + 1)|0;
  if ($38) {
   label = 16;
   break;
  } else {
   $V_0$0 = $39;
  }
 }
 if ((label|0) == 6) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $lpad$phi$index = $8;$lpad$phi$index2 = $9;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 16) {
  __THREW__ = 0;
  (invoke_ii(2996,(2263896|0))|0);
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  do {
   if (!($41)) {
    $42 = HEAP8[((2263896 + 116|0))>>0]|0;
    $43 = ($42<<24>>24)==(0);
    if ($43) {
     __THREW__ = 0;
     (invoke_ii(2996,(2263896|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2263896|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2263896|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if (!($51)) {
     $52 = HEAP32[((2263896 + 80|0))>>2]|0;
     $53 = (($52) + 64|0);
     $54 = HEAP32[$53>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($54|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      $57 = (($54) + 12|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = ($V_0$0>>>0)<($58>>>0);
      if (!($59)) {
       __THREW__ = 0;
       $60 = (invoke_i(132)|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($60|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        break;
       }
      }
      $65 = HEAP32[$54>>2]|0;
      $66 = (($54) + 16|0);
      $67 = (($65) + 92|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = Math_imul($68, $V_0$0)|0;
      $70 = (($66) + ($69)|0);
      $71 = HEAP32[$70>>2]|0;
      $$0 = $71;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  } while(0);
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 36) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z79mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_BuildTailoringTablesP22mscorlib_System_ObjectP41mscorlib_System_Globalization_CultureInfoP49mscorlib_Mono_Globalization_Unicode_TailoringInfoPP51mscorlib_Mono_Globalization_Unicode_Contraction_arrPP49mscorlib_Mono_Globalization_Unicode_Level2Map_arr($__this,$culture,$t,$contractions,$diacriticals) {
 $__this = $__this|0;
 $culture = $culture|0;
 $t = $t|0;
 $contractions = $contractions|0;
 $diacriticals = $diacriticals|0;
 var $$byval_copy10 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B4_0$0 = 0, $L_105 = 0, $L_108 = 0, $V_3$0$be = 0, $V_3$051 = 0;
 var $V_5$0 = 0, $V_5$1 = 0, $V_8$044 = 0, $V_9$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy10 = sp + 28|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $L_105 = sp + 12|0;
 $L_108 = sp + 16|0;
 $2 = sp + 20|0;
 $3 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261024);
 __THREW__ = 0;
 invoke_v(522);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2304136|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2304136|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(2153,($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2304136|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       $15 = (invoke_ii(3469,(2304136|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        invoke_vi(2153,($15|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2263896|0))|0);
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if (!($21)) {
          $22 = HEAP8[((2263896 + 116|0))>>0]|0;
          $23 = ($22<<24>>24)==(0);
          if ($23) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $24 = __THREW__; __THREW__ = 0;
           $25 = $24&1;
           if ($25) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if ($27) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if ($29) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if (!($37)) {
           $38 = HEAP32[((2263896 + 80|0))>>2]|0;
           $39 = (($38) + 60|0);
           $40 = HEAP32[$39>>2]|0;
           $41 = ($40|0)==(0|0);
           if ($41) {
            $G_B4_0$0 = 0;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if ($43) {
             break;
            }
            $44 = HEAP8[((2263896 + 116|0))>>0]|0;
            $45 = ($44<<24>>24)==(0);
            if ($45) {
             __THREW__ = 0;
             (invoke_ii(2996,(2263896|0))|0);
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if ($47) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2263896|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3831,(2263896|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $52 = __THREW__; __THREW__ = 0;
            $53 = $52&1;
            if ($53) {
             break;
            }
            $54 = HEAP32[((2263896 + 80|0))>>2]|0;
            $55 = (($54) + 60|0);
            $56 = HEAP32[$55>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($56|0));
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if ($58) {
             break;
            }
            $59 = (($56) + 12|0);
            $60 = HEAP32[$59>>2]|0;
            $61 = ($60|0)==(0);
            if ($61) {
             $G_B4_0$0 = 0;
            } else {
             __THREW__ = 0;
             (invoke_ii(2996,(2263896|0))|0);
             $62 = __THREW__; __THREW__ = 0;
             $63 = $62&1;
             if ($63) {
              break;
             }
             $64 = HEAP8[((2263896 + 116|0))>>0]|0;
             $65 = ($64<<24>>24)==(0);
             if ($65) {
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $66 = __THREW__; __THREW__ = 0;
              $67 = $66&1;
              if ($67) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $68 = __THREW__; __THREW__ = 0;
              $69 = $68&1;
              if ($69) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3831,(2263896|0));
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2263896|0))|0);
             $72 = __THREW__; __THREW__ = 0;
             $73 = $72&1;
             if ($73) {
              break;
             }
             $74 = HEAP32[((2263896 + 80|0))>>2]|0;
             $75 = (($74) + 60|0);
             $76 = HEAP32[$75>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($76|0));
             $77 = __THREW__; __THREW__ = 0;
             $78 = $77&1;
             if ($78) {
              break;
             }
             $79 = (($76) + 12|0);
             $80 = HEAP32[$79>>2]|0;
             $81 = ($80|0)==(0);
             if ($81) {
              __THREW__ = 0;
              $82 = (invoke_i(132)|0);
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if ($84) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($82|0));
              $85 = __THREW__; __THREW__ = 0;
              $86 = $85&1;
              if ($86) {
               break;
              }
             }
             $87 = (($76) + 16|0);
             $G_B4_0$0 = $87;
            }
           }
           __THREW__ = 0;
           invoke_vi(3799,($t|0));
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if (!($89)) {
            $90 = (($t) + 12|0);
            $91 = HEAP32[$90>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($t|0));
            $92 = __THREW__; __THREW__ = 0;
            $93 = $92&1;
            if (!($93)) {
             $94 = (($t) + 16|0);
             $95 = HEAP32[$94>>2]|0;
             $96 = (($95) + ($91))|0;
             $97 = ($95|0)>(0);
             L42: do {
              if ($97) {
               $V_3$051 = $91;
               L44: while(1) {
                $103 = (($V_3$051) + 1)|0;
                $247 = (($G_B4_0$0) + ($V_3$051<<1)|0);
                $248 = HEAP16[$247>>1]|0;
                $249 = $248&65535;
                $250 = (($249) + 65535)|0;
                $251 = $250 & 65535;
                if ((($251|0) == 0)) {
                 $V_5$0 = $103;
                 while(1) {
                  $98 = (($G_B4_0$0) + ($V_5$0<<1)|0);
                  $99 = HEAP16[$98>>1]|0;
                  $100 = ($99<<16>>16)==(0);
                  $101 = (($V_5$0) + 1)|0;
                  if ($100) {
                   break;
                  } else {
                   $V_5$0 = $101;
                  }
                 }
                 $102 = (($V_5$0) - ($103))|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1168808|0))|0);
                 $104 = __THREW__; __THREW__ = 0;
                 $105 = $104&1;
                 if ($105) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 $106 = (invoke_iii(2754,(1168808|0),($102|0))|0);
                 $107 = __THREW__; __THREW__ = 0;
                 $108 = $107&1;
                 if ($108) {
                  label = 14;
                  break;
                 }
                 $109 = (($G_B4_0$0) + ($103<<1)|0);
                 __THREW__ = 0;
                 $110 = (invoke_iii(716,0,($109|0))|0);
                 $111 = __THREW__; __THREW__ = 0;
                 $112 = $111&1;
                 if ($112) {
                  label = 14;
                  break;
                 }
                 HEAP32[$0>>2] = $110;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$0+0>>2]|0;
                 invoke_viiiii(69,(0|0),($$byval_copy10|0),($106|0),0,($102|0));
                 $113 = __THREW__; __THREW__ = 0;
                 $114 = $113&1;
                 if ($114) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(1203320|0))|0);
                 $115 = __THREW__; __THREW__ = 0;
                 $116 = $115&1;
                 if ($116) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 $117 = (invoke_iii(2754,(1203320|0),4)|0);
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  label = 14;
                  break;
                 }
                 $120 = (($117) + 16|0);
                 $121 = (($117) + 12|0);
                 $V_8$044 = 0;
                 while(1) {
                  $137 = (($101) + ($V_8$044))|0;
                  $138 = (($G_B4_0$0) + ($137<<1)|0);
                  $139 = HEAP16[$138>>1]|0;
                  $134 = $139&255;
                  __THREW__ = 0;
                  invoke_vi(3799,($117|0));
                  $140 = __THREW__; __THREW__ = 0;
                  $141 = $140&1;
                  if ($141) {
                   label = 13;
                   break L44;
                  }
                  $122 = HEAP32[$121>>2]|0;
                  $123 = ($V_8$044>>>0)<($122>>>0);
                  if (!($123)) {
                   __THREW__ = 0;
                   $124 = (invoke_i(132)|0);
                   $125 = __THREW__; __THREW__ = 0;
                   $126 = $125&1;
                   if ($126) {
                    label = 13;
                    break L44;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($124|0));
                   $127 = __THREW__; __THREW__ = 0;
                   $128 = $127&1;
                   if ($128) {
                    label = 13;
                    break L44;
                   }
                  }
                  $129 = HEAP32[$117>>2]|0;
                  $130 = (($129) + 92|0);
                  $131 = HEAP32[$130>>2]|0;
                  $132 = Math_imul($131, $V_8$044)|0;
                  $133 = (($120) + ($132)|0);
                  HEAP8[$133>>0] = $134;
                  $135 = (($V_8$044) + 1)|0;
                  $136 = ($135|0)<(4);
                  if ($136) {
                   $V_8$044 = $135;
                  } else {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2259608|0))|0);
                 $142 = __THREW__; __THREW__ = 0;
                 $143 = $142&1;
                 if ($143) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 $144 = (invoke_ii(3469,(2259608|0))|0);
                 $145 = __THREW__; __THREW__ = 0;
                 $146 = $145&1;
                 if ($146) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiii(146,($144|0),($106|0),(0|0),($117|0));
                 $147 = __THREW__; __THREW__ = 0;
                 $148 = $147&1;
                 if ($148) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($8|0));
                 $149 = __THREW__; __THREW__ = 0;
                 $150 = $149&1;
                 if ($150) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iiii(1647,(2297624|0),($8|0),($144|0))|0);
                 $151 = __THREW__; __THREW__ = 0;
                 $152 = $151&1;
                 if ($152) {
                  label = 14;
                  break;
                 }
                 $153 = (($V_5$0) + 6)|0;
                 $V_3$0$be = $153;
                } else if ((($251|0) == 1)) {
                 $155 = (($G_B4_0$0) + ($103<<1)|0);
                 $156 = HEAP16[$155>>1]|0;
                 $157 = $156&255;
                 $158 = $V_3$051 << 1;
                 $159 = (($158) + 4)|0;
                 $160 = (($G_B4_0$0) + ($159)|0);
                 $161 = HEAP16[$160>>1]|0;
                 $162 = $161&255;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2260368|0))|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 $165 = (invoke_ii(3469,(2260368|0))|0);
                 $166 = __THREW__; __THREW__ = 0;
                 $167 = $166&1;
                 if ($167) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(552,($165|0),($157|0),($162|0));
                 $168 = __THREW__; __THREW__ = 0;
                 $169 = $168&1;
                 if ($169) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($15|0));
                 $170 = __THREW__; __THREW__ = 0;
                 $171 = $170&1;
                 if ($171) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iiii(1647,(2297624|0),($15|0),($165|0))|0);
                 $172 = __THREW__; __THREW__ = 0;
                 $173 = $172&1;
                 if ($173) {
                  label = 14;
                  break;
                 }
                 $174 = (($V_3$051) + 3)|0;
                 $V_3$0$be = $174;
                } else if ((($251|0) == 2)) {
                 $V_5$1 = $103;
                 while(1) {
                  $175 = (($G_B4_0$0) + ($V_5$1<<1)|0);
                  $176 = HEAP16[$175>>1]|0;
                  $177 = ($176<<16>>16)==(0);
                  $178 = (($V_5$1) + 1)|0;
                  if ($177) {
                   break;
                  } else {
                   $V_5$1 = $178;
                  }
                 }
                 $179 = (($V_5$1) - ($103))|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1168808|0))|0);
                 $180 = __THREW__; __THREW__ = 0;
                 $181 = $180&1;
                 if ($181) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 $182 = (invoke_iii(2754,(1168808|0),($179|0))|0);
                 $183 = __THREW__; __THREW__ = 0;
                 $184 = $183&1;
                 if ($184) {
                  label = 14;
                  break;
                 }
                 $185 = (($G_B4_0$0) + ($103<<1)|0);
                 __THREW__ = 0;
                 $186 = (invoke_iii(716,0,($185|0))|0);
                 $187 = __THREW__; __THREW__ = 0;
                 $188 = $187&1;
                 if ($188) {
                  label = 14;
                  break;
                 }
                 HEAP32[$1>>2] = $186;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$1+0>>2]|0;
                 invoke_viiiii(69,(0|0),($$byval_copy10|0),($182|0),0,($179|0));
                 $189 = __THREW__; __THREW__ = 0;
                 $190 = $189&1;
                 if ($190) {
                  label = 14;
                  break;
                 } else {
                  $V_9$0 = $178;
                 }
                 while(1) {
                  $191 = (($G_B4_0$0) + ($V_9$0<<1)|0);
                  $192 = HEAP16[$191>>1]|0;
                  $193 = ($192<<16>>16)==(0);
                  $194 = (($V_9$0) + 1)|0;
                  if ($193) {
                   break;
                  } else {
                   $V_9$0 = $194;
                  }
                 }
                 $195 = (($V_9$0) - ($178))|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $196 = __THREW__; __THREW__ = 0;
                 $197 = $196&1;
                 if ($197) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(3469,(2191608|0))|0);
                 $198 = __THREW__; __THREW__ = 0;
                 $199 = $198&1;
                 if ($199) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 $200 = (invoke_iiiii(103,0,($G_B4_0$0|0),($178|0),($195|0))|0);
                 $201 = __THREW__; __THREW__ = 0;
                 $202 = $201&1;
                 if ($202) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2259608|0))|0);
                 $203 = __THREW__; __THREW__ = 0;
                 $204 = $203&1;
                 if ($204) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 $205 = (invoke_ii(3469,(2259608|0))|0);
                 $206 = __THREW__; __THREW__ = 0;
                 $207 = $206&1;
                 if ($207) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiii(146,($205|0),($182|0),($200|0),(0|0));
                 $208 = __THREW__; __THREW__ = 0;
                 $209 = $208&1;
                 if ($209) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($8|0));
                 $210 = __THREW__; __THREW__ = 0;
                 $211 = $210&1;
                 if ($211) {
                  label = 14;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iiii(1647,(2297624|0),($8|0),($205|0))|0);
                 $212 = __THREW__; __THREW__ = 0;
                 $213 = $212&1;
                 if ($213) {
                  label = 14;
                  break;
                 } else {
                  $V_3$0$be = $194;
                 }
                } else {
                 label = 82;
                 break;
                }
                $154 = ($V_3$0$be|0)<($96|0);
                if ($154) {
                 $V_3$051 = $V_3$0$be;
                } else {
                 break L42;
                }
               }
               if ((label|0) == 13) {
                $30 = ___cxa_find_matching_catch()|0;
                $31 = tempRet0;
                $lpad$phi$index = $30;$lpad$phi$index3 = $31;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               else if ((label|0) == 14) {
                $32 = ___cxa_find_matching_catch()|0;
                $33 = tempRet0;
                $lpad$phi$index = $32;$lpad$phi$index3 = $33;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               else if ((label|0) == 82) {
                __THREW__ = 0;
                invoke_vi(3799,($culture|0));
                $214 = __THREW__; __THREW__ = 0;
                $215 = $214&1;
                if ($215) {
                 break L1;
                }
                __THREW__ = 0;
                $216 = (invoke_iii(2729,(2273552|0),($culture|0))|0);
                $217 = __THREW__; __THREW__ = 0;
                $218 = $217&1;
                if ($218) {
                 break L1;
                }
                HEAP32[$L_105>>2] = $216;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $219 = __THREW__; __THREW__ = 0;
                $220 = $219&1;
                if ($220) {
                 break L1;
                }
                __THREW__ = 0;
                $221 = (invoke_iii(2724,(2155952|0),($L_105|0))|0);
                $222 = __THREW__; __THREW__ = 0;
                $223 = $222&1;
                if ($223) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3799,($culture|0));
                $224 = __THREW__; __THREW__ = 0;
                $225 = $224&1;
                if ($225) {
                 break L1;
                }
                __THREW__ = 0;
                $226 = (invoke_iii(2730,(2273792|0),($culture|0))|0);
                $227 = __THREW__; __THREW__ = 0;
                $228 = $227&1;
                if ($228) {
                 break L1;
                }
                HEAP32[$L_108>>2] = $V_3$051;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $229 = __THREW__; __THREW__ = 0;
                $230 = $229&1;
                if ($230) {
                 break L1;
                }
                __THREW__ = 0;
                $231 = (invoke_iii(2724,(2155952|0),($L_108|0))|0);
                $232 = __THREW__; __THREW__ = 0;
                $233 = $232&1;
                if ($233) {
                 break L1;
                }
                $234 = HEAP32[3019064>>2]|0;
                __THREW__ = 0;
                $235 = (invoke_iiiiii(87,0,($234|0),($221|0),($226|0),($231|0))|0);
                $236 = __THREW__; __THREW__ = 0;
                $237 = $236&1;
                if ($237) {
                 break L1;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2622368|0))|0);
                $238 = __THREW__; __THREW__ = 0;
                $239 = $238&1;
                if ($239) {
                 break L1;
                }
                __THREW__ = 0;
                $240 = (invoke_ii(3469,(2622368|0))|0);
                $241 = __THREW__; __THREW__ = 0;
                $242 = $241&1;
                if ($242) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vii(1953,($240|0),($235|0));
                $243 = __THREW__; __THREW__ = 0;
                $244 = $243&1;
                if ($244) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3830,($240|0));
                $245 = __THREW__; __THREW__ = 0;
                $246 = $245&1;
                if ($246) {
                 break L1;
                }
                // unreachable;
               }
              }
             } while(0);
             __THREW__ = 0;
             (invoke_ii(2996,(2260048|0))|0);
             $252 = __THREW__; __THREW__ = 0;
             $253 = $252&1;
             if (!($253)) {
              $254 = HEAP8[((2260048 + 116|0))>>0]|0;
              $255 = ($254<<24>>24)==(0);
              if ($255) {
               __THREW__ = 0;
               (invoke_ii(2996,(2260048|0))|0);
               $256 = __THREW__; __THREW__ = 0;
               $257 = $256&1;
               if ($257) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2260048|0))|0);
               $258 = __THREW__; __THREW__ = 0;
               $259 = $258&1;
               if ($259) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3831,(2260048|0));
               $260 = __THREW__; __THREW__ = 0;
               $261 = $260&1;
               if ($261) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2260048|0))|0);
              $262 = __THREW__; __THREW__ = 0;
              $263 = $262&1;
              if (!($263)) {
               $264 = HEAP32[((2260048 + 80|0))>>2]|0;
               $265 = HEAP32[$264>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($8|0));
               $266 = __THREW__; __THREW__ = 0;
               $267 = $266&1;
               if (!($267)) {
                __THREW__ = 0;
                invoke_viii(2110,(2299064|0),($8|0),($265|0));
                $268 = __THREW__; __THREW__ = 0;
                $269 = $268&1;
                if (!($269)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2260792|0))|0);
                 $270 = __THREW__; __THREW__ = 0;
                 $271 = $270&1;
                 if ($271) {
                  break;
                 }
                 $272 = HEAP8[((2260792 + 116|0))>>0]|0;
                 $273 = ($272<<24>>24)==(0);
                 if ($273) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2260792|0))|0);
                  $274 = __THREW__; __THREW__ = 0;
                  $275 = $274&1;
                  if ($275) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2260792|0))|0);
                  $276 = __THREW__; __THREW__ = 0;
                  $277 = $276&1;
                  if ($277) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2260792|0));
                  $278 = __THREW__; __THREW__ = 0;
                  $279 = $278&1;
                  if ($279) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2260792|0))|0);
                 $280 = __THREW__; __THREW__ = 0;
                 $281 = $280&1;
                 if ($281) {
                  break;
                 }
                 $282 = HEAP32[((2260792 + 80|0))>>2]|0;
                 $283 = HEAP32[$282>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($15|0));
                 $284 = __THREW__; __THREW__ = 0;
                 $285 = $284&1;
                 if ($285) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(2110,(2299064|0),($15|0),($283|0));
                 $286 = __THREW__; __THREW__ = 0;
                 $287 = $286&1;
                 if ($287) {
                  break;
                 }
                 HEAP32[$2>>2] = 2143808;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$2+0>>2]|0;
                 $288 = (invoke_iii(772,0,($$byval_copy10|0))|0);
                 $289 = __THREW__; __THREW__ = 0;
                 $290 = $289&1;
                 if ($290) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($8|0));
                 $291 = __THREW__; __THREW__ = 0;
                 $292 = $291&1;
                 if ($292) {
                  break;
                 }
                 __THREW__ = 0;
                 $293 = (invoke_iiii(1645,(2299256|0),($8|0),($288|0))|0);
                 $294 = __THREW__; __THREW__ = 0;
                 $295 = $294&1;
                 if ($295) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(1228736|0))|0);
                 $296 = __THREW__; __THREW__ = 0;
                 $297 = $296&1;
                 if ($297) {
                  break;
                 }
                 __THREW__ = 0;
                 $298 = (invoke_iii(2735,($293|0),(1228736|0))|0);
                 $299 = __THREW__; __THREW__ = 0;
                 $300 = $299&1;
                 if ($300) {
                  break;
                 }
                 HEAP32[$contractions>>2] = $298;
                 HEAP32[$3>>2] = 2143536;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy10+0>>2]=HEAP32[$3+0>>2]|0;
                 $301 = (invoke_iii(772,0,($$byval_copy10|0))|0);
                 $302 = __THREW__; __THREW__ = 0;
                 $303 = $302&1;
                 if ($303) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($15|0));
                 $304 = __THREW__; __THREW__ = 0;
                 $305 = $304&1;
                 if ($305) {
                  break;
                 }
                 __THREW__ = 0;
                 $306 = (invoke_iiii(1645,(2299256|0),($15|0),($301|0))|0);
                 $307 = __THREW__; __THREW__ = 0;
                 $308 = $307&1;
                 if ($308) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(1229120|0))|0);
                 $309 = __THREW__; __THREW__ = 0;
                 $310 = $309&1;
                 if ($310) {
                  break;
                 }
                 __THREW__ = 0;
                 $311 = (invoke_iii(2735,($306|0),(1229120|0))|0);
                 $312 = __THREW__; __THREW__ = 0;
                 $313 = $312&1;
                 if ($313) {
                  break;
                 }
                 HEAP32[$diacriticals>>2] = $311;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $34 = ___cxa_find_matching_catch()|0;
 $35 = tempRet0;
 $lpad$phi$index = $34;$lpad$phi$index3 = $35;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z75mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_SetCJKReferencesP22mscorlib_System_ObjectP22mscorlib_System_StringPP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerPPhS7_S5_S7_($__this,$name,$cjkIndexer,$catTable,$lv1Table,$lv2Indexer,$lv2Table) {
 $__this = $__this|0;
 $name = $name|0;
 $cjkIndexer = $cjkIndexer|0;
 $catTable = $catTable|0;
 $lv1Table = $lv1Table|0;
 $lv2Indexer = $lv2Indexer|0;
 $lv2Table = $lv2Table|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261072);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(523);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP8[((2263896 + 116|0))>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     __THREW__ = 0;
     (invoke_ii(2996,(2263896|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2263896|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2263896|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2263896 + 80|0))>>2]|0;
     $18 = (($17) + 76|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($19|0)==(0|0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(1400808|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(1400808|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1329,($23|0),4);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($23|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      $30 = HEAP32[3019304>>2]|0;
      __THREW__ = 0;
      invoke_viiii(461,(1397040|0),($23|0),($30|0),0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($23|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = HEAP32[3019312>>2]|0;
      __THREW__ = 0;
      invoke_viiii(461,(1397040|0),($23|0),($35|0),1);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($23|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      $40 = HEAP32[3019320>>2]|0;
      __THREW__ = 0;
      invoke_viiii(461,(1397040|0),($23|0),($40|0),2);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($23|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      $45 = HEAP32[3019328>>2]|0;
      __THREW__ = 0;
      invoke_viiii(461,(1397040|0),($23|0),($45|0),3);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2263896|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      $50 = HEAP8[((2263896 + 116|0))>>0]|0;
      $51 = ($50<<24>>24)==(0);
      if ($51) {
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3831,(2263896|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2263896|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      $60 = HEAP32[((2263896 + 80|0))>>2]|0;
      $61 = (($60) + 76|0);
      HEAP32[$61>>2] = $23;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2263896|0))|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if (!($63)) {
      $64 = HEAP8[((2263896 + 116|0))>>0]|0;
      $65 = ($64<<24>>24)==(0);
      if ($65) {
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3831,(2263896|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2263896|0))|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if (!($73)) {
       $74 = HEAP32[((2263896 + 80|0))>>2]|0;
       $75 = (($74) + 76|0);
       $76 = HEAP32[$75>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($76|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if (!($78)) {
        __THREW__ = 0;
        $79 = (invoke_iiiii(299,(1398096|0),($76|0),($name|0),($V_2|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if (!($81)) {
         if (!($79)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         $82 = HEAP32[$V_2>>2]|0;
         if ((($82|0) == 1)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           break;
          }
          $130 = HEAP8[((2263896 + 116|0))>>0]|0;
          $131 = ($130<<24>>24)==(0);
          if ($131) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $132 = __THREW__; __THREW__ = 0;
           $133 = $132&1;
           if ($133) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if ($135) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $136 = __THREW__; __THREW__ = 0;
           $137 = $136&1;
           if ($137) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $138 = __THREW__; __THREW__ = 0;
          $139 = $138&1;
          if ($139) {
           break;
          }
          $140 = HEAP32[((2263896 + 80|0))>>2]|0;
          $141 = (($140) + 28|0);
          $142 = HEAP32[$141>>2]|0;
          HEAP32[$catTable>>2] = $142;
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $143 = __THREW__; __THREW__ = 0;
          $144 = $143&1;
          if ($144) {
           break;
          }
          $145 = HEAP8[((2263896 + 116|0))>>0]|0;
          $146 = ($145<<24>>24)==(0);
          if ($146) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $147 = __THREW__; __THREW__ = 0;
           $148 = $147&1;
           if ($148) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $149 = __THREW__; __THREW__ = 0;
           $150 = $149&1;
           if ($150) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $151 = __THREW__; __THREW__ = 0;
           $152 = $151&1;
           if ($152) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           break;
          }
          $155 = HEAP32[((2263896 + 80|0))>>2]|0;
          $156 = (($155) + 44|0);
          $157 = HEAP32[$156>>2]|0;
          HEAP32[$lv1Table>>2] = $157;
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           break;
          }
          $160 = HEAP8[((2264376 + 116|0))>>0]|0;
          $161 = ($160<<24>>24)==(0);
          if ($161) {
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $162 = __THREW__; __THREW__ = 0;
           $163 = $162&1;
           if ($163) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $164 = __THREW__; __THREW__ = 0;
           $165 = $164&1;
           if ($165) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2264376|0));
           $166 = __THREW__; __THREW__ = 0;
           $167 = $166&1;
           if ($167) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $168 = __THREW__; __THREW__ = 0;
          $169 = $168&1;
          if ($169) {
           break;
          }
          $170 = HEAP32[((2264376 + 80|0))>>2]|0;
          $171 = (($170) + 24|0);
          $172 = HEAP32[$171>>2]|0;
          HEAP32[$cjkIndexer>>2] = $172;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         } else if ((($82|0) == 2)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $173 = __THREW__; __THREW__ = 0;
          $174 = $173&1;
          if ($174) {
           break;
          }
          $175 = HEAP8[((2263896 + 116|0))>>0]|0;
          $176 = ($175<<24>>24)==(0);
          if ($176) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $177 = __THREW__; __THREW__ = 0;
           $178 = $177&1;
           if ($178) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $179 = __THREW__; __THREW__ = 0;
           $180 = $179&1;
           if ($180) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $181 = __THREW__; __THREW__ = 0;
           $182 = $181&1;
           if ($182) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $183 = __THREW__; __THREW__ = 0;
          $184 = $183&1;
          if ($184) {
           break;
          }
          $185 = HEAP32[((2263896 + 80|0))>>2]|0;
          $186 = (($185) + 32|0);
          $187 = HEAP32[$186>>2]|0;
          HEAP32[$catTable>>2] = $187;
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $188 = __THREW__; __THREW__ = 0;
          $189 = $188&1;
          if ($189) {
           break;
          }
          $190 = HEAP8[((2263896 + 116|0))>>0]|0;
          $191 = ($190<<24>>24)==(0);
          if ($191) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $192 = __THREW__; __THREW__ = 0;
           $193 = $192&1;
           if ($193) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $194 = __THREW__; __THREW__ = 0;
           $195 = $194&1;
           if ($195) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $198 = __THREW__; __THREW__ = 0;
          $199 = $198&1;
          if ($199) {
           break;
          }
          $200 = HEAP32[((2263896 + 80|0))>>2]|0;
          $201 = (($200) + 48|0);
          $202 = HEAP32[$201>>2]|0;
          HEAP32[$lv1Table>>2] = $202;
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $203 = __THREW__; __THREW__ = 0;
          $204 = $203&1;
          if ($204) {
           break;
          }
          $205 = HEAP8[((2264376 + 116|0))>>0]|0;
          $206 = ($205<<24>>24)==(0);
          if ($206) {
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $207 = __THREW__; __THREW__ = 0;
           $208 = $207&1;
           if ($208) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $209 = __THREW__; __THREW__ = 0;
           $210 = $209&1;
           if ($210) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2264376|0));
           $211 = __THREW__; __THREW__ = 0;
           $212 = $211&1;
           if ($212) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $213 = __THREW__; __THREW__ = 0;
          $214 = $213&1;
          if ($214) {
           break;
          }
          $215 = HEAP32[((2264376 + 80|0))>>2]|0;
          $216 = (($215) + 24|0);
          $217 = HEAP32[$216>>2]|0;
          HEAP32[$cjkIndexer>>2] = $217;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         } else if ((($82|0) == 3)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $218 = __THREW__; __THREW__ = 0;
          $219 = $218&1;
          if ($219) {
           break;
          }
          $220 = HEAP8[((2263896 + 116|0))>>0]|0;
          $221 = ($220<<24>>24)==(0);
          if ($221) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $222 = __THREW__; __THREW__ = 0;
           $223 = $222&1;
           if ($223) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $224 = __THREW__; __THREW__ = 0;
           $225 = $224&1;
           if ($225) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $226 = __THREW__; __THREW__ = 0;
           $227 = $226&1;
           if ($227) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $228 = __THREW__; __THREW__ = 0;
          $229 = $228&1;
          if ($229) {
           break;
          }
          $230 = HEAP32[((2263896 + 80|0))>>2]|0;
          $231 = (($230) + 36|0);
          $232 = HEAP32[$231>>2]|0;
          HEAP32[$catTable>>2] = $232;
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $233 = __THREW__; __THREW__ = 0;
          $234 = $233&1;
          if ($234) {
           break;
          }
          $235 = HEAP8[((2263896 + 116|0))>>0]|0;
          $236 = ($235<<24>>24)==(0);
          if ($236) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $237 = __THREW__; __THREW__ = 0;
           $238 = $237&1;
           if ($238) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $239 = __THREW__; __THREW__ = 0;
           $240 = $239&1;
           if ($240) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $241 = __THREW__; __THREW__ = 0;
           $242 = $241&1;
           if ($242) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $243 = __THREW__; __THREW__ = 0;
          $244 = $243&1;
          if ($244) {
           break;
          }
          $245 = HEAP32[((2263896 + 80|0))>>2]|0;
          $246 = (($245) + 52|0);
          $247 = HEAP32[$246>>2]|0;
          HEAP32[$lv1Table>>2] = $247;
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $248 = __THREW__; __THREW__ = 0;
          $249 = $248&1;
          if ($249) {
           break;
          }
          $250 = HEAP8[((2263896 + 116|0))>>0]|0;
          $251 = ($250<<24>>24)==(0);
          if ($251) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $252 = __THREW__; __THREW__ = 0;
           $253 = $252&1;
           if ($253) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $254 = __THREW__; __THREW__ = 0;
           $255 = $254&1;
           if ($255) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $256 = __THREW__; __THREW__ = 0;
           $257 = $256&1;
           if ($257) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $258 = __THREW__; __THREW__ = 0;
          $259 = $258&1;
          if ($259) {
           break;
          }
          $260 = HEAP32[((2263896 + 80|0))>>2]|0;
          $261 = (($260) + 56|0);
          $262 = HEAP32[$261>>2]|0;
          HEAP32[$lv2Table>>2] = $262;
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $263 = __THREW__; __THREW__ = 0;
          $264 = $263&1;
          if ($264) {
           break;
          }
          $265 = HEAP8[((2264376 + 116|0))>>0]|0;
          $266 = ($265<<24>>24)==(0);
          if ($266) {
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $267 = __THREW__; __THREW__ = 0;
           $268 = $267&1;
           if ($268) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $269 = __THREW__; __THREW__ = 0;
           $270 = $269&1;
           if ($270) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2264376|0));
           $271 = __THREW__; __THREW__ = 0;
           $272 = $271&1;
           if ($272) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $273 = __THREW__; __THREW__ = 0;
          $274 = $273&1;
          if ($274) {
           break;
          }
          $275 = HEAP32[((2264376 + 80|0))>>2]|0;
          $276 = (($275) + 24|0);
          $277 = HEAP32[$276>>2]|0;
          HEAP32[$cjkIndexer>>2] = $277;
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $278 = __THREW__; __THREW__ = 0;
          $279 = $278&1;
          if ($279) {
           break;
          }
          $280 = HEAP8[((2264376 + 116|0))>>0]|0;
          $281 = ($280<<24>>24)==(0);
          if ($281) {
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $282 = __THREW__; __THREW__ = 0;
           $283 = $282&1;
           if ($283) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $284 = __THREW__; __THREW__ = 0;
           $285 = $284&1;
           if ($285) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2264376|0));
           $286 = __THREW__; __THREW__ = 0;
           $287 = $286&1;
           if ($287) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $288 = __THREW__; __THREW__ = 0;
          $289 = $288&1;
          if ($289) {
           break;
          }
          $290 = HEAP32[((2264376 + 80|0))>>2]|0;
          $291 = (($290) + 24|0);
          $292 = HEAP32[$291>>2]|0;
          HEAP32[$lv2Indexer>>2] = $292;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         } else if ((($82|0) == 0)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           break;
          }
          $85 = HEAP8[((2263896 + 116|0))>>0]|0;
          $86 = ($85<<24>>24)==(0);
          if ($86) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $89 = __THREW__; __THREW__ = 0;
           $90 = $89&1;
           if ($90) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $91 = __THREW__; __THREW__ = 0;
           $92 = $91&1;
           if ($92) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           break;
          }
          $95 = HEAP32[((2263896 + 80|0))>>2]|0;
          $96 = (($95) + 24|0);
          $97 = HEAP32[$96>>2]|0;
          HEAP32[$catTable>>2] = $97;
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break;
          }
          $100 = HEAP8[((2263896 + 116|0))>>0]|0;
          $101 = ($100<<24>>24)==(0);
          if ($101) {
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $102 = __THREW__; __THREW__ = 0;
           $103 = $102&1;
           if ($103) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2263896|0));
           $106 = __THREW__; __THREW__ = 0;
           $107 = $106&1;
           if ($107) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2263896|0))|0);
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           break;
          }
          $110 = HEAP32[((2263896 + 80|0))>>2]|0;
          $111 = (($110) + 40|0);
          $112 = HEAP32[$111>>2]|0;
          HEAP32[$lv1Table>>2] = $112;
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           break;
          }
          $115 = HEAP8[((2264376 + 116|0))>>0]|0;
          $116 = ($115<<24>>24)==(0);
          if ($116) {
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $117 = __THREW__; __THREW__ = 0;
           $118 = $117&1;
           if ($118) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2264376|0))|0);
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if ($120) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3831,(2264376|0));
           $121 = __THREW__; __THREW__ = 0;
           $122 = $121&1;
           if ($122) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2264376|0))|0);
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if ($124) {
           break;
          }
          $125 = HEAP32[((2264376 + 80|0))>>2]|0;
          $126 = (($125) + 20|0);
          $127 = HEAP32[$126>>2]|0;
          HEAP32[$cjkIndexer>>2] = $127;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         } else {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z67mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_CategoryP22mscorlib_System_Objecti($__this,$cp) {
 $__this = $__this|0;
 $cp = $cp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261120);
 __THREW__ = 0;
 (invoke_ii(2996,(2263896|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2263896 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2263896|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2263896 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2264376|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP8[((2264376 + 116|0))>>0]|0;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2264376|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2264376|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2264376|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2264376|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[((2264376 + 80|0))>>2]|0;
      $30 = (($29) + 4|0);
      $31 = HEAP32[$30>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($31|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       $34 = (invoke_iii(784,($31|0),($cp|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        $37 = (($16) + ($34)|0);
        $38 = HEAP8[$37>>0]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($38|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_Level1P22mscorlib_System_Objecti($__this,$cp) {
 $__this = $__this|0;
 $cp = $cp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261168);
 __THREW__ = 0;
 (invoke_ii(2996,(2263896|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2263896 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2263896|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2263896 + 80|0))>>2]|0;
    $15 = (($14) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2264376|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP8[((2264376 + 116|0))>>0]|0;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2264376|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2264376|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2264376|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2264376|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[((2264376 + 80|0))>>2]|0;
      $30 = (($29) + 8|0);
      $31 = HEAP32[$30>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($31|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       $34 = (invoke_iii(784,($31|0),($cp|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        $37 = (($16) + ($34)|0);
        $38 = HEAP8[$37>>0]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($38|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_Level2P22mscorlib_System_Objecti($__this,$cp) {
 $__this = $__this|0;
 $cp = $cp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261216);
 __THREW__ = 0;
 (invoke_ii(2996,(2263896|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2263896 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2263896|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2263896 + 80|0))>>2]|0;
    $15 = (($14) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2264376|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP8[((2264376 + 116|0))>>0]|0;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2264376|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2264376|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2264376|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2264376|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[((2264376 + 80|0))>>2]|0;
      $30 = (($29) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($31|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       $34 = (invoke_iii(784,($31|0),($cp|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        $37 = (($16) + ($34)|0);
        $38 = HEAP8[$37>>0]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($38|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_Level3P22mscorlib_System_Objecti($__this,$cp) {
 $__this = $__this|0;
 $cp = $cp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261264);
 __THREW__ = 0;
 (invoke_ii(2996,(2263896|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2263896 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2263896|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2263896 + 80|0))>>2]|0;
    $15 = (($14) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2264376|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP8[((2264376 + 116|0))>>0]|0;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2264376|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2264376|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2264376|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2264376|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[((2264376 + 80|0))>>2]|0;
      $30 = (($29) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($31|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       $34 = (invoke_iii(784,($31|0),($cp|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        $37 = (($16) + ($34)|0);
        $38 = HEAP8[$37>>0]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($38|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsIgnorableP22mscorlib_System_Objectih($__this,$cp,$flag) {
 $__this = $__this|0;
 $cp = $cp|0;
 $flag = $flag|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $cp$off = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261312);
 $0 = ($cp|0)==(0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $1 = $flag & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  label = 6;
 } else {
  $3 = $cp&65535;
  __THREW__ = 0;
  $4 = (invoke_iii(599,0,($3|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)!=(29);
   $cp$off = (($cp) + -55424)|0;
   $8 = ($cp$off>>>0)>(767);
   $or$cond = $7 & $8;
   if ($or$cond) {
    label = 6;
   } else {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 do {
  if ((label|0) == 6) {
   __THREW__ = 0;
   (invoke_ii(2996,(2264376|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP8[((2264376 + 116|0))>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     __THREW__ = 0;
     (invoke_ii(2996,(2264376|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2264376|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3831,(2264376|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2264376|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[((2264376 + 80|0))>>2]|0;
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      $27 = (invoke_iii(784,($24|0),($cp|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       $30 = ($27|0)<(0);
       if ($30) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        $33 = HEAP8[((2263896 + 116|0))>>0]|0;
        $34 = ($33<<24>>24)==(0);
        if ($34) {
         __THREW__ = 0;
         (invoke_ii(2996,(2263896|0))|0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2263896|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3831,(2263896|0));
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2263896|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if (!($42)) {
         $43 = HEAP32[((2263896 + 80|0))>>2]|0;
         $44 = (($43) + 4|0);
         $45 = HEAP32[$44>>2]|0;
         $46 = (($45) + ($27)|0);
         $47 = HEAP8[$46>>0]|0;
         $48 = $47 & $flag;
         $49 = ($48<<24>>24)!=(0);
         $$0 = $49;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsIgnorableNonSpacingP22mscorlib_System_Objecti($__this,$cp) {
 $__this = $__this|0;
 $cp = $cp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261360);
 __THREW__ = 0;
 $0 = (invoke_iiii(735,0,($cp|0),4)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z80mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_ToKanaTypeInsensitiveP22mscorlib_System_Objecti($__this,$i) {
 $__this = $__this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $G_B4_0$0 = 0, $_stackTraceSentry = 0, $i$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261408);
 $i$off = (($i) + -12353)|0;
 $0 = ($i$off>>>0)>(83);
 $1 = (($i) + 96)|0;
 $G_B4_0$0 = $0 ? $i : $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B4_0$0|0);
}
function __Z72mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_ToWidthCompatP22mscorlib_System_Objecti($__this,$i) {
 $__this = $__this|0;
 $i = $i|0;
 var $$0 = 0, $$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261456);
 $0 = ($i|0)>(8591);
 L1: do {
  if ($0) {
   $1 = ($i|0)<(65281);
   if (!($1)) {
    $2 = ($i|0)>(65374);
    if (!($2)) {
     $3 = (($i) + -65248)|0;
     $$0 = $3;
     break;
    }
    switch ($i|0) {
    case 65506:  {
     $$0 = 172;
     break L1;
     break;
    }
    case 65507:  {
     $$0 = 175;
     break L1;
     break;
    }
    case 65509:  {
     $$0 = 165;
     break L1;
     break;
    }
    case 65510:  {
     $$0 = 8361;
     break L1;
     break;
    }
    case 65505:  {
     $$0 = 163;
     break L1;
     break;
    }
    case 65508:  {
     $$0 = 166;
     break L1;
     break;
    }
    case 65504:  {
     $$0 = 162;
     break L1;
     break;
    }
    default: {
     $$0 = $i;
     break L1;
    }
    }
   }
   $4 = ($i|0)<(13055);
   if ($4) {
    $5 = ($i|0)>(8595);
    if (!($5)) {
     $6 = (($i) + 56921)|0;
     $$0 = $6;
     break;
    }
    $7 = ($i|0)>(9473);
    if ($7) {
     $8 = ($i|0)>(9675);
     if (!($8)) {
      if ((($i|0) == 9474)) {
       $$0 = 65512;
       break;
      } else if ((($i|0) == 9632)) {
       $$0 = 65517;
       break;
      } else if ((($i|0) == 9675)) {
       $$0 = 65518;
       break;
      } else {
       $$0 = $i;
       break;
      }
     }
     $9 = ($i|0)>(12287);
     if ($9) {
      $10 = ($i|0)>(12592);
      if ($10) {
       $11 = ($i|0)>(12643);
       if ($11) {
        $13 = ($i|0)==(12644);
        $$i = $13 ? 65440 : $i;
        $$0 = $$i;
        break;
       } else {
        $12 = (($i) + 52848)|0;
        $$0 = $12;
        break;
       }
      }
      if ((($i|0) == 12288)) {
       $$0 = 32;
       break;
      } else if ((($i|0) == 12290)) {
       $$0 = 65377;
       break;
      } else if ((($i|0) == 12289)) {
       $$0 = 65380;
       break;
      } else {
       if ((($i|0) == 12300)) {
        $$0 = 65378;
        break;
       } else if ((($i|0) == 12301)) {
        $$0 = 65379;
        break;
       } else if ((($i|0) == 12539)) {
        $$0 = 65381;
        break;
       } else {
        $$0 = $i;
        break;
       }
      }
     } else {
      $$0 = $i;
     }
    } else {
     $$0 = $i;
    }
   } else {
    $$0 = $i;
   }
  } else {
   $$0 = $i;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z75mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_HasSpecialWeightP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, $c$off = 0, $c$off1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261504);
 $0 = ($c&65535)>(12352);
 do {
  if ($0) {
   $c$off = (($c) + 154)<<16>>16;
   $1 = ($c$off&65535)>(55);
   if ($1) {
    $2 = ($c&65535)<(13056);
    if ($2) {
     $3 = ($c&65535)>(12444);
     if (!($3)) {
      $4 = ($c&65535)<(12441);
      $$0 = $4;
      break;
     }
     $5 = ($c&65535)>(12543);
     if ($5) {
      $c$off1 = (($c) + -13008)<<16>>16;
      $7 = ($c$off1&65535)<(47);
      $$0 = $7;
      break;
     } else {
      $6 = ($c<<16>>16)!=(12539);
      $$0 = $6;
      break;
     }
    } else {
     $$0 = 0;
    }
   } else {
    $$0 = 1;
   }
  } else {
   $$0 = 0;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z74mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsHalfWidthKanaP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $_stackTraceSentry = 0, $c$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261552);
 $c$off = (($c) + 154)<<16>>16;
 $0 = ($c$off&65535)<(56);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z69mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsHiraganaP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $_stackTraceSentry = 0, $c$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261600);
 $c$off = (($c) + -12353)<<16>>16;
 $0 = ($c$off&65535)<(84);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z80mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsJapaneseSmallLetterP22mscorlib_System_Objectt($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $c$off = 0, $c$off2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261648);
 $0 = $c&65535;
 $c$off = (($c) + 153)<<16>>16;
 $1 = ($c$off&65535)>(8);
 L1: do {
  if ($1) {
   $c$off2 = (($c) + -12353)<<16>>16;
   $2 = ($c$off2&65535)>(184);
   if (!($2)) {
    $3 = (($0) + 53183)|0;
    $4 = $3 & 65535;
    switch ($4|0) {
    case 4: case 6: case 2: case 8: case 0:  {
     $$0 = 1;
     break L1;
     break;
    }
    default: {
    }
    }
    $5 = (($0) + 53087)|0;
    $6 = $5 & 65535;
    switch ($6|0) {
    case 4: case 6: case 2: case 8: case 0:  {
     $$0 = 1;
     break L1;
     break;
    }
    default: {
    }
    }
    $7 = (($0) + 53117)|0;
    $8 = $7 & 65535;
    if ((($8|0) == 2) | (($8|0) == 4) | (($8|0) == 0)) {
     $$0 = 1;
     break;
    }
    $9 = (($0) + 53021)|0;
    $10 = $9 & 65535;
    if ((($10|0) == 2) | (($10|0) == 4) | (($10|0) == 0)) {
     $$0 = 1;
     break;
    }
    switch ($c<<16>>16) {
    case 12526: case 12483: case 12430: case 12387: case 12534: case 12533:  {
     $$0 = 1;
     break L1;
     break;
    }
    default: {
    }
    }
   }
   $$0 = 0;
  } else {
   $$0 = 1;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z66mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_FillCJKP22mscorlib_System_ObjectP22mscorlib_System_StringPP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerPPhS7_S5_S7_($__this,$culture,$cjkIndexer,$catTable,$lv1Table,$lv2Indexer,$lv2Table) {
 $__this = $__this|0;
 $culture = $culture|0;
 $cjkIndexer = $cjkIndexer|0;
 $catTable = $catTable|0;
 $lv1Table = $lv1Table|0;
 $lv2Indexer = $lv2Indexer|0;
 $lv2Table = $lv2Table|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0;
 var $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261792);
 __THREW__ = 0;
 (invoke_ii(2996,(2263896|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2263896 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3831,(2263896|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2263896|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2263896 + 80|0))>>2]|0;
    $15 = (($14) + 68|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_vii(1916,(0|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     invoke_viiiiiii(18,0,($culture|0),0,($catTable|0),($lv1Table|0),0,($lv2Table|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 11;
     } else {
      __THREW__ = 0;
      invoke_viiiiiii(16,0,($culture|0),($cjkIndexer|0),($catTable|0),($lv1Table|0),($lv2Indexer|0),($lv2Table|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 11;
      } else {
       $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 47;
      }
     }
     if ((label|0) == 11) {
      $23 = ___cxa_find_matching_catch(348288|0)|0;
      $24 = tempRet0;
      $25 = (_llvm_eh_typeid_for((348288|0))|0);
      $26 = ($24|0)==($25|0);
      if (!($26)) {
       $$0 = $24;$$02 = $23;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $27 = (___cxa_begin_catch(($23|0))|0);
      $28 = HEAP32[$27>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $__last_unhandled_exception$0 = $28;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,(0|0),($16|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $cond1 = ($leaveInstructions$sroa$0$0|0)==(47);
      if ($cond1) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3830,($__last_unhandled_exception$0|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z70mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_FillCJKCoreP22mscorlib_System_ObjectP22mscorlib_System_StringPP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerPPhS7_S5_S7_($__this,$culture,$cjkIndexer,$catTable,$lv1Table,$cjkLv2Indexer,$lv2Table) {
 $__this = $__this|0;
 $culture = $culture|0;
 $cjkIndexer = $cjkIndexer|0;
 $catTable = $catTable|0;
 $lv1Table = $lv1Table|0;
 $cjkLv2Indexer = $cjkLv2Indexer|0;
 $lv2Table = $lv2Table|0;
 var $$byval_copy3 = 0, $$byval_copy5 = 0, $$not = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_8 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond101 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp + 36|0;
 $$byval_copy3 = sp + 32|0;
 $_stackTraceSentry = sp + 28|0;
 $V_8 = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2261840);
 HEAP32[$V_8>>2] = 0;
 __THREW__ = 0;
 invoke_v(524);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_ii(2508,(0|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $$not = $8 ^ 1;
    $11 = ($culture|0)==(0|0);
    $or$cond = $11 | $$not;
    if ($or$cond) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2263896|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP8[((2263896 + 116|0))>>0]|0;
     $17 = ($16<<24>>24)==(0);
     if ($17) {
      __THREW__ = 0;
      (invoke_ii(2996,(2263896|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2263896|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3831,(2263896|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2263896|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[((2263896 + 80|0))>>2]|0;
      $27 = (($26) + 80|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($28|0)==(0|0);
      if ($29) {
       __THREW__ = 0;
       (invoke_ii(2996,(1400808|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __THREW__ = 0;
       $32 = (invoke_ii(3469,(1400808|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(1329,($32|0),4);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       $39 = HEAP32[3019392>>2]|0;
       __THREW__ = 0;
       invoke_viiii(461,(1397040|0),($32|0),($39|0),0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break;
       }
       $44 = HEAP32[3019400>>2]|0;
       __THREW__ = 0;
       invoke_viiii(461,(1397040|0),($32|0),($44|0),1);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
       $49 = HEAP32[3019408>>2]|0;
       __THREW__ = 0;
       invoke_viiii(461,(1397040|0),($32|0),($49|0),2);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break;
       }
       $54 = HEAP32[3019416>>2]|0;
       __THREW__ = 0;
       invoke_viiii(461,(1397040|0),($32|0),($54|0),3);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        break;
       }
       $59 = HEAP8[((2263896 + 116|0))>>0]|0;
       $60 = ($59<<24>>24)==(0);
       if ($60) {
        __THREW__ = 0;
        (invoke_ii(2996,(2263896|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2263896|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3831,(2263896|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        break;
       }
       $69 = HEAP32[((2263896 + 80|0))>>2]|0;
       $70 = (($69) + 80|0);
       HEAP32[$70>>2] = $32;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2263896|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if (!($72)) {
       $73 = HEAP8[((2263896 + 116|0))>>0]|0;
       $74 = ($73<<24>>24)==(0);
       if ($74) {
        __THREW__ = 0;
        (invoke_ii(2996,(2263896|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2263896|0))|0);
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3831,(2263896|0));
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2263896|0))|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if (!($82)) {
        $83 = HEAP32[((2263896 + 80|0))>>2]|0;
        $84 = (($83) + 80|0);
        $85 = HEAP32[$84>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($85|0));
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if (!($87)) {
         __THREW__ = 0;
         $88 = (invoke_iiiii(299,(1398096|0),($85|0),($culture|0),($V_8|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if (!($90)) {
          if (!($88)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          $91 = HEAP32[$V_8>>2]|0;
          if ((($91|0) == 0)) {
           $92 = HEAP32[3019424>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $93 = __THREW__; __THREW__ = 0;
           $94 = $93&1;
           if ($94) {
            break;
           }
           $95 = HEAP8[((2263896 + 116|0))>>0]|0;
           $96 = ($95<<24>>24)==(0);
           if ($96) {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $99 = __THREW__; __THREW__ = 0;
            $100 = $99&1;
            if ($100) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3831,(2263896|0));
            $101 = __THREW__; __THREW__ = 0;
            $102 = $101&1;
            if ($102) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            break;
           }
           $105 = HEAP32[((2263896 + 80|0))>>2]|0;
           $106 = (($105) + 24|0);
           $107 = HEAP32[$106>>2]|0;
           HEAP32[$catTable>>2] = $107;
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            break;
           }
           $110 = HEAP8[((2263896 + 116|0))>>0]|0;
           $111 = ($110<<24>>24)==(0);
           if ($111) {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $112 = __THREW__; __THREW__ = 0;
            $113 = $112&1;
            if ($113) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $114 = __THREW__; __THREW__ = 0;
            $115 = $114&1;
            if ($115) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3831,(2263896|0));
            $116 = __THREW__; __THREW__ = 0;
            $117 = $116&1;
            if ($117) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $118 = __THREW__; __THREW__ = 0;
           $119 = $118&1;
           if ($119) {
            break;
           }
           $120 = HEAP32[((2263896 + 80|0))>>2]|0;
           $121 = (($120) + 40|0);
           $122 = HEAP32[$121>>2]|0;
           HEAP32[$lv1Table>>2] = $122;
           $218 = $122;$V_0$0 = $92;
          } else if ((($91|0) == 2)) {
           $154 = HEAP32[3019440>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $155 = __THREW__; __THREW__ = 0;
           $156 = $155&1;
           if ($156) {
            break;
           }
           $157 = HEAP8[((2263896 + 116|0))>>0]|0;
           $158 = ($157<<24>>24)==(0);
           if ($158) {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $159 = __THREW__; __THREW__ = 0;
            $160 = $159&1;
            if ($160) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $161 = __THREW__; __THREW__ = 0;
            $162 = $161&1;
            if ($162) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3831,(2263896|0));
            $163 = __THREW__; __THREW__ = 0;
            $164 = $163&1;
            if ($164) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            break;
           }
           $167 = HEAP32[((2263896 + 80|0))>>2]|0;
           $168 = (($167) + 32|0);
           $169 = HEAP32[$168>>2]|0;
           HEAP32[$catTable>>2] = $169;
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $170 = __THREW__; __THREW__ = 0;
           $171 = $170&1;
           if ($171) {
            break;
           }
           $172 = HEAP8[((2263896 + 116|0))>>0]|0;
           $173 = ($172<<24>>24)==(0);
           if ($173) {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $174 = __THREW__; __THREW__ = 0;
            $175 = $174&1;
            if ($175) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $176 = __THREW__; __THREW__ = 0;
            $177 = $176&1;
            if ($177) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3831,(2263896|0));
            $178 = __THREW__; __THREW__ = 0;
            $179 = $178&1;
            if ($179) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $180 = __THREW__; __THREW__ = 0;
           $181 = $180&1;
           if ($181) {
            break;
           }
           $182 = HEAP32[((2263896 + 80|0))>>2]|0;
           $183 = (($182) + 48|0);
           $184 = HEAP32[$183>>2]|0;
           HEAP32[$lv1Table>>2] = $184;
           $218 = $184;$V_0$0 = $154;
          } else if ((($91|0) == 1)) {
           $123 = HEAP32[3019432>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            break;
           }
           $126 = HEAP8[((2263896 + 116|0))>>0]|0;
           $127 = ($126<<24>>24)==(0);
           if ($127) {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $128 = __THREW__; __THREW__ = 0;
            $129 = $128&1;
            if ($129) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $130 = __THREW__; __THREW__ = 0;
            $131 = $130&1;
            if ($131) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3831,(2263896|0));
            $132 = __THREW__; __THREW__ = 0;
            $133 = $132&1;
            if ($133) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if ($135) {
            break;
           }
           $136 = HEAP32[((2263896 + 80|0))>>2]|0;
           $137 = (($136) + 28|0);
           $138 = HEAP32[$137>>2]|0;
           HEAP32[$catTable>>2] = $138;
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $139 = __THREW__; __THREW__ = 0;
           $140 = $139&1;
           if ($140) {
            break;
           }
           $141 = HEAP8[((2263896 + 116|0))>>0]|0;
           $142 = ($141<<24>>24)==(0);
           if ($142) {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $143 = __THREW__; __THREW__ = 0;
            $144 = $143&1;
            if ($144) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $145 = __THREW__; __THREW__ = 0;
            $146 = $145&1;
            if ($146) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3831,(2263896|0));
            $147 = __THREW__; __THREW__ = 0;
            $148 = $147&1;
            if ($148) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $149 = __THREW__; __THREW__ = 0;
           $150 = $149&1;
           if ($150) {
            break;
           }
           $151 = HEAP32[((2263896 + 80|0))>>2]|0;
           $152 = (($151) + 44|0);
           $153 = HEAP32[$152>>2]|0;
           HEAP32[$lv1Table>>2] = $153;
           $218 = $153;$V_0$0 = $123;
          } else if ((($91|0) == 3)) {
           $185 = HEAP32[3019448>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if ($187) {
            break;
           }
           $188 = HEAP8[((2263896 + 116|0))>>0]|0;
           $189 = ($188<<24>>24)==(0);
           if ($189) {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $190 = __THREW__; __THREW__ = 0;
            $191 = $190&1;
            if ($191) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $192 = __THREW__; __THREW__ = 0;
            $193 = $192&1;
            if ($193) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3831,(2263896|0));
            $194 = __THREW__; __THREW__ = 0;
            $195 = $194&1;
            if ($195) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            break;
           }
           $198 = HEAP32[((2263896 + 80|0))>>2]|0;
           $199 = (($198) + 36|0);
           $200 = HEAP32[$199>>2]|0;
           HEAP32[$catTable>>2] = $200;
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $201 = __THREW__; __THREW__ = 0;
           $202 = $201&1;
           if ($202) {
            break;
           }
           $203 = HEAP8[((2263896 + 116|0))>>0]|0;
           $204 = ($203<<24>>24)==(0);
           if ($204) {
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $205 = __THREW__; __THREW__ = 0;
            $206 = $205&1;
            if ($206) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2263896|0))|0);
            $207 = __THREW__; __THREW__ = 0;
            $208 = $207&1;
            if ($208) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3831,(2263896|0));
            $209 = __THREW__; __THREW__ = 0;
            $210 = $209&1;
            if ($210) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2263896|0))|0);
           $211 = __THREW__; __THREW__ = 0;
           $212 = $211&1;
           if ($212) {
            break;
           }
           $213 = HEAP32[((2263896 + 80|0))>>2]|0;
           $214 = (($213) + 52|0);
           $215 = HEAP32[$214>>2]|0;
           HEAP32[$lv1Table>>2] = $215;
           $218 = $215;$V_0$0 = $185;
          } else {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          $216 = ($V_0$0|0)!=(0|0);
          $217 = ($218|0)==(0|0);
          $or$cond101 = $216 & $217;
          if (!($or$cond101)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          $219 = HEAP32[3019456>>2]|0;
          __THREW__ = 0;
          $220 = (invoke_iiii(552,0,($219|0),($V_0$0|0))|0);
          $221 = __THREW__; __THREW__ = 0;
          $222 = $221&1;
          if (!($222)) {
           __THREW__ = 0;
           $223 = (invoke_iii(797,0,($220|0))|0);
           $224 = __THREW__; __THREW__ = 0;
           $225 = $224&1;
           if (!($225)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2210080|0))|0);
            $226 = __THREW__; __THREW__ = 0;
            $227 = $226&1;
            if (!($227)) {
             $228 = HEAP32[((2210080 + 80|0))>>2]|0;
             $229 = HEAP32[$228>>2]|0;
             HEAP32[$0>>2] = $223;
             HEAP32[$1>>2] = $229;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
             ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
             $230 = (invoke_iiii(643,0,($$byval_copy3|0),($$byval_copy5|0))|0);
             $231 = __THREW__; __THREW__ = 0;
             $232 = $231&1;
             if (!($232)) {
              if ($230) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              HEAP32[$2>>2] = $223;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
              $233 = (invoke_iii(718,0,($$byval_copy5|0))|0);
              $234 = __THREW__; __THREW__ = 0;
              $235 = $234&1;
              if ($235) {
               break;
              }
              __THREW__ = 0;
              $236 = (invoke_iiii(737,0,($233|0),1)|0);
              $237 = __THREW__; __THREW__ = 0;
              $238 = $237&1;
              if ($238) {
               break;
              }
              $239 = (($233) + 5|0);
              HEAP32[$catTable>>2] = $239;
              $$sum = (($236) + 5)|0;
              $240 = (($233) + ($$sum)|0);
              HEAP32[$lv1Table>>2] = $240;
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $241 = __THREW__; __THREW__ = 0;
              $242 = $241&1;
              if ($242) {
               break;
              }
              $243 = HEAP8[((2263896 + 116|0))>>0]|0;
              $244 = ($243<<24>>24)==(0);
              if ($244) {
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $245 = __THREW__; __THREW__ = 0;
               $246 = $245&1;
               if ($246) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $247 = __THREW__; __THREW__ = 0;
               $248 = $247&1;
               if ($248) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3831,(2263896|0));
               $249 = __THREW__; __THREW__ = 0;
               $250 = $249&1;
               if ($250) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $251 = __THREW__; __THREW__ = 0;
              $252 = $251&1;
              if ($252) {
               break;
              }
              $253 = HEAP32[((2263896 + 80|0))>>2]|0;
              $254 = (($253) + 84|0);
              $255 = HEAP32[$254>>2]|0;
              $256 = ($255|0)==(0|0);
              if ($256) {
               __THREW__ = 0;
               (invoke_ii(2996,(1400808|0))|0);
               $257 = __THREW__; __THREW__ = 0;
               $258 = $257&1;
               if ($258) {
                break;
               }
               __THREW__ = 0;
               $259 = (invoke_ii(3469,(1400808|0))|0);
               $260 = __THREW__; __THREW__ = 0;
               $261 = $260&1;
               if ($261) {
                break;
               }
               __THREW__ = 0;
               invoke_vii(1329,($259|0),4);
               $262 = __THREW__; __THREW__ = 0;
               $263 = $262&1;
               if ($263) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($259|0));
               $264 = __THREW__; __THREW__ = 0;
               $265 = $264&1;
               if ($265) {
                break;
               }
               $266 = HEAP32[3019464>>2]|0;
               __THREW__ = 0;
               invoke_viiii(461,(1397040|0),($259|0),($266|0),0);
               $267 = __THREW__; __THREW__ = 0;
               $268 = $267&1;
               if ($268) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($259|0));
               $269 = __THREW__; __THREW__ = 0;
               $270 = $269&1;
               if ($270) {
                break;
               }
               $271 = HEAP32[3019472>>2]|0;
               __THREW__ = 0;
               invoke_viiii(461,(1397040|0),($259|0),($271|0),1);
               $272 = __THREW__; __THREW__ = 0;
               $273 = $272&1;
               if ($273) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($259|0));
               $274 = __THREW__; __THREW__ = 0;
               $275 = $274&1;
               if ($275) {
                break;
               }
               $276 = HEAP32[3019480>>2]|0;
               __THREW__ = 0;
               invoke_viiii(461,(1397040|0),($259|0),($276|0),2);
               $277 = __THREW__; __THREW__ = 0;
               $278 = $277&1;
               if ($278) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($259|0));
               $279 = __THREW__; __THREW__ = 0;
               $280 = $279&1;
               if ($280) {
                break;
               }
               $281 = HEAP32[3019488>>2]|0;
               __THREW__ = 0;
               invoke_viiii(461,(1397040|0),($259|0),($281|0),3);
               $282 = __THREW__; __THREW__ = 0;
               $283 = $282&1;
               if ($283) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $284 = __THREW__; __THREW__ = 0;
               $285 = $284&1;
               if ($285) {
                break;
               }
               $286 = HEAP8[((2263896 + 116|0))>>0]|0;
               $287 = ($286<<24>>24)==(0);
               if ($287) {
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $288 = __THREW__; __THREW__ = 0;
                $289 = $288&1;
                if ($289) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2263896|0))|0);
                $290 = __THREW__; __THREW__ = 0;
                $291 = $290&1;
                if ($291) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3831,(2263896|0));
                $292 = __THREW__; __THREW__ = 0;
                $293 = $292&1;
                if ($293) {
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $294 = __THREW__; __THREW__ = 0;
               $295 = $294&1;
               if ($295) {
                break;
               }
               $296 = HEAP32[((2263896 + 80|0))>>2]|0;
               $297 = (($296) + 84|0);
               HEAP32[$297>>2] = $259;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $298 = __THREW__; __THREW__ = 0;
              $299 = $298&1;
              if ($299) {
               break;
              }
              $300 = HEAP8[((2263896 + 116|0))>>0]|0;
              $301 = ($300<<24>>24)==(0);
              if ($301) {
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $302 = __THREW__; __THREW__ = 0;
               $303 = $302&1;
               if ($303) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $304 = __THREW__; __THREW__ = 0;
               $305 = $304&1;
               if ($305) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3831,(2263896|0));
               $306 = __THREW__; __THREW__ = 0;
               $307 = $306&1;
               if ($307) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $308 = __THREW__; __THREW__ = 0;
              $309 = $308&1;
              if ($309) {
               break;
              }
              $310 = HEAP32[((2263896 + 80|0))>>2]|0;
              $311 = (($310) + 84|0);
              $312 = HEAP32[$311>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($312|0));
              $313 = __THREW__; __THREW__ = 0;
              $314 = $313&1;
              if ($314) {
               break;
              }
              __THREW__ = 0;
              $315 = (invoke_iiiii(299,(1398096|0),($312|0),($culture|0),($V_8|0))|0);
              $316 = __THREW__; __THREW__ = 0;
              $317 = $316&1;
              if ($317) {
               break;
              }
              do {
               if ($315) {
                $318 = HEAP32[$V_8>>2]|0;
                if ((($318|0) == 1)) {
                 $349 = HEAP32[$catTable>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $350 = __THREW__; __THREW__ = 0;
                 $351 = $350&1;
                 if ($351) {
                  break L1;
                 }
                 $352 = HEAP8[((2263896 + 116|0))>>0]|0;
                 $353 = ($352<<24>>24)==(0);
                 if ($353) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $354 = __THREW__; __THREW__ = 0;
                  $355 = $354&1;
                  if ($355) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $356 = __THREW__; __THREW__ = 0;
                  $357 = $356&1;
                  if ($357) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2263896|0));
                  $358 = __THREW__; __THREW__ = 0;
                  $359 = $358&1;
                  if ($359) {
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $360 = __THREW__; __THREW__ = 0;
                 $361 = $360&1;
                 if ($361) {
                  break L1;
                 }
                 $362 = HEAP32[((2263896 + 80|0))>>2]|0;
                 $363 = (($362) + 28|0);
                 HEAP32[$363>>2] = $349;
                 $364 = HEAP32[$lv1Table>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $365 = __THREW__; __THREW__ = 0;
                 $366 = $365&1;
                 if ($366) {
                  break L1;
                 }
                 $367 = HEAP8[((2263896 + 116|0))>>0]|0;
                 $368 = ($367<<24>>24)==(0);
                 if ($368) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $369 = __THREW__; __THREW__ = 0;
                  $370 = $369&1;
                  if ($370) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $371 = __THREW__; __THREW__ = 0;
                  $372 = $371&1;
                  if ($372) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2263896|0));
                  $373 = __THREW__; __THREW__ = 0;
                  $374 = $373&1;
                  if ($374) {
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $375 = __THREW__; __THREW__ = 0;
                 $376 = $375&1;
                 if ($376) {
                  break L1;
                 }
                 $377 = HEAP32[((2263896 + 80|0))>>2]|0;
                 $378 = (($377) + 44|0);
                 HEAP32[$378>>2] = $364;
                 break;
                } else if ((($318|0) == 0)) {
                 $319 = HEAP32[$catTable>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $320 = __THREW__; __THREW__ = 0;
                 $321 = $320&1;
                 if ($321) {
                  break L1;
                 }
                 $322 = HEAP8[((2263896 + 116|0))>>0]|0;
                 $323 = ($322<<24>>24)==(0);
                 if ($323) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $324 = __THREW__; __THREW__ = 0;
                  $325 = $324&1;
                  if ($325) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $326 = __THREW__; __THREW__ = 0;
                  $327 = $326&1;
                  if ($327) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2263896|0));
                  $328 = __THREW__; __THREW__ = 0;
                  $329 = $328&1;
                  if ($329) {
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $330 = __THREW__; __THREW__ = 0;
                 $331 = $330&1;
                 if ($331) {
                  break L1;
                 }
                 $332 = HEAP32[((2263896 + 80|0))>>2]|0;
                 $333 = (($332) + 24|0);
                 HEAP32[$333>>2] = $319;
                 $334 = HEAP32[$lv1Table>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $335 = __THREW__; __THREW__ = 0;
                 $336 = $335&1;
                 if ($336) {
                  break L1;
                 }
                 $337 = HEAP8[((2263896 + 116|0))>>0]|0;
                 $338 = ($337<<24>>24)==(0);
                 if ($338) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $339 = __THREW__; __THREW__ = 0;
                  $340 = $339&1;
                  if ($340) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $341 = __THREW__; __THREW__ = 0;
                  $342 = $341&1;
                  if ($342) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2263896|0));
                  $343 = __THREW__; __THREW__ = 0;
                  $344 = $343&1;
                  if ($344) {
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $345 = __THREW__; __THREW__ = 0;
                 $346 = $345&1;
                 if ($346) {
                  break L1;
                 }
                 $347 = HEAP32[((2263896 + 80|0))>>2]|0;
                 $348 = (($347) + 40|0);
                 HEAP32[$348>>2] = $334;
                 break;
                } else if ((($318|0) == 2)) {
                 $379 = HEAP32[$catTable>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $380 = __THREW__; __THREW__ = 0;
                 $381 = $380&1;
                 if ($381) {
                  break L1;
                 }
                 $382 = HEAP8[((2263896 + 116|0))>>0]|0;
                 $383 = ($382<<24>>24)==(0);
                 if ($383) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $384 = __THREW__; __THREW__ = 0;
                  $385 = $384&1;
                  if ($385) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $386 = __THREW__; __THREW__ = 0;
                  $387 = $386&1;
                  if ($387) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2263896|0));
                  $388 = __THREW__; __THREW__ = 0;
                  $389 = $388&1;
                  if ($389) {
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $390 = __THREW__; __THREW__ = 0;
                 $391 = $390&1;
                 if ($391) {
                  break L1;
                 }
                 $392 = HEAP32[((2263896 + 80|0))>>2]|0;
                 $393 = (($392) + 32|0);
                 HEAP32[$393>>2] = $379;
                 $394 = HEAP32[$lv1Table>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $395 = __THREW__; __THREW__ = 0;
                 $396 = $395&1;
                 if ($396) {
                  break L1;
                 }
                 $397 = HEAP8[((2263896 + 116|0))>>0]|0;
                 $398 = ($397<<24>>24)==(0);
                 if ($398) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $399 = __THREW__; __THREW__ = 0;
                  $400 = $399&1;
                  if ($400) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $401 = __THREW__; __THREW__ = 0;
                  $402 = $401&1;
                  if ($402) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2263896|0));
                  $403 = __THREW__; __THREW__ = 0;
                  $404 = $403&1;
                  if ($404) {
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $405 = __THREW__; __THREW__ = 0;
                 $406 = $405&1;
                 if ($406) {
                  break L1;
                 }
                 $407 = HEAP32[((2263896 + 80|0))>>2]|0;
                 $408 = (($407) + 48|0);
                 HEAP32[$408>>2] = $394;
                 break;
                } else if ((($318|0) == 3)) {
                 $409 = HEAP32[$catTable>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $410 = __THREW__; __THREW__ = 0;
                 $411 = $410&1;
                 if ($411) {
                  break L1;
                 }
                 $412 = HEAP8[((2263896 + 116|0))>>0]|0;
                 $413 = ($412<<24>>24)==(0);
                 if ($413) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $414 = __THREW__; __THREW__ = 0;
                  $415 = $414&1;
                  if ($415) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $416 = __THREW__; __THREW__ = 0;
                  $417 = $416&1;
                  if ($417) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2263896|0));
                  $418 = __THREW__; __THREW__ = 0;
                  $419 = $418&1;
                  if ($419) {
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $420 = __THREW__; __THREW__ = 0;
                 $421 = $420&1;
                 if ($421) {
                  break L1;
                 }
                 $422 = HEAP32[((2263896 + 80|0))>>2]|0;
                 $423 = (($422) + 36|0);
                 HEAP32[$423>>2] = $409;
                 $424 = HEAP32[$lv1Table>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $425 = __THREW__; __THREW__ = 0;
                 $426 = $425&1;
                 if ($426) {
                  break L1;
                 }
                 $427 = HEAP8[((2263896 + 116|0))>>0]|0;
                 $428 = ($427<<24>>24)==(0);
                 if ($428) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $429 = __THREW__; __THREW__ = 0;
                  $430 = $429&1;
                  if ($430) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2263896|0))|0);
                  $431 = __THREW__; __THREW__ = 0;
                  $432 = $431&1;
                  if ($432) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3831,(2263896|0));
                  $433 = __THREW__; __THREW__ = 0;
                  $434 = $433&1;
                  if ($434) {
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2263896|0))|0);
                 $435 = __THREW__; __THREW__ = 0;
                 $436 = $435&1;
                 if ($436) {
                  break L1;
                 }
                 $437 = HEAP32[((2263896 + 80|0))>>2]|0;
                 $438 = (($437) + 52|0);
                 HEAP32[$438>>2] = $424;
                 break;
                } else {
                 break;
                }
               }
              } while(0);
              $439 = HEAP32[3019496>>2]|0;
              __THREW__ = 0;
              $440 = (invoke_iiii(575,0,($V_0$0|0),($439|0))|0);
              $441 = __THREW__; __THREW__ = 0;
              $442 = $441&1;
              if ($442) {
               break;
              }
              if ($440) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              $443 = HEAP32[3019504>>2]|0;
              __THREW__ = 0;
              $444 = (invoke_iii(797,0,($443|0))|0);
              $445 = __THREW__; __THREW__ = 0;
              $446 = $445&1;
              if ($446) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2210080|0))|0);
              $447 = __THREW__; __THREW__ = 0;
              $448 = $447&1;
              if ($448) {
               break;
              }
              $449 = HEAP32[((2210080 + 80|0))>>2]|0;
              $450 = HEAP32[$449>>2]|0;
              HEAP32[$3>>2] = $444;
              HEAP32[$4>>2] = $450;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
              ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
              $451 = (invoke_iiii(643,0,($$byval_copy3|0),($$byval_copy5|0))|0);
              $452 = __THREW__; __THREW__ = 0;
              $453 = $452&1;
              if ($453) {
               break;
              }
              if ($451) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              HEAP32[$5>>2] = $444;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
              $454 = (invoke_iii(718,0,($$byval_copy5|0))|0);
              $455 = __THREW__; __THREW__ = 0;
              $456 = $455&1;
              if ($456) {
               break;
              }
              $457 = (($454) + 5|0);
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $458 = __THREW__; __THREW__ = 0;
              $459 = $458&1;
              if ($459) {
               break;
              }
              $460 = HEAP8[((2263896 + 116|0))>>0]|0;
              $461 = ($460<<24>>24)==(0);
              if ($461) {
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $462 = __THREW__; __THREW__ = 0;
               $463 = $462&1;
               if ($463) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $464 = __THREW__; __THREW__ = 0;
               $465 = $464&1;
               if ($465) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3831,(2263896|0));
               $466 = __THREW__; __THREW__ = 0;
               $467 = $466&1;
               if ($467) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $468 = __THREW__; __THREW__ = 0;
              $469 = $468&1;
              if ($469) {
               break;
              }
              $470 = HEAP32[((2263896 + 80|0))>>2]|0;
              $471 = (($470) + 56|0);
              HEAP32[$471>>2] = $457;
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $472 = __THREW__; __THREW__ = 0;
              $473 = $472&1;
              if ($473) {
               break;
              }
              $474 = HEAP8[((2263896 + 116|0))>>0]|0;
              $475 = ($474<<24>>24)==(0);
              if ($475) {
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $476 = __THREW__; __THREW__ = 0;
               $477 = $476&1;
               if ($477) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2263896|0))|0);
               $478 = __THREW__; __THREW__ = 0;
               $479 = $478&1;
               if ($479) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3831,(2263896|0));
               $480 = __THREW__; __THREW__ = 0;
               $481 = $480&1;
               if ($481) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2263896|0))|0);
              $482 = __THREW__; __THREW__ = 0;
              $483 = $482&1;
              if ($483) {
               break;
              }
              $484 = HEAP32[((2263896 + 80|0))>>2]|0;
              $485 = (($484) + 56|0);
              $486 = HEAP32[$485>>2]|0;
              HEAP32[$lv2Table>>2] = $486;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits27mscorlib_System_Int32TraitsE6InvokeEPFhPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsE6InvokeEPFbPvihES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 $6 = $5&1;
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_UInt32Traits17VoidPointerTraitsS0_E6InvokeEPFjPvS3_jES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$3)|0);
 HEAP32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z116mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map2P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map3P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map4P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z69mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTableUtil_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2264032);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_iii(2754,(1170368|0),3)|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = (($8) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14>>>0)<(2);
     if ($15) {
      __THREW__ = 0;
      $16 = (invoke_i(132)|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($16|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
     }
     $23 = HEAP32[$8>>2]|0;
     $24 = (($8) + 16|0);
     $25 = (($23) + 92|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($24) + ($26)|0);
     HEAP32[$27>>2] = 40960;
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[$13>>2]|0;
      $31 = ($30>>>0)<(3);
      if ($31) {
       __THREW__ = 0;
       $32 = (invoke_i(132)|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($32|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
      }
      $37 = HEAP32[$8>>2]|0;
      $38 = (($37) + 92|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = $39 << 1;
      $41 = (($24) + ($40)|0);
      HEAP32[$41>>2] = 63744;
      __THREW__ = 0;
      (invoke_ii(2996,(1170368|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       __THREW__ = 0;
       $44 = (invoke_iii(2754,(1170368|0),3)|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         $49 = (($44) + 12|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = ($50|0)==(0);
         if ($51) {
          __THREW__ = 0;
          $52 = (invoke_i(132)|0);
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($52|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           break;
          }
         }
         $57 = (($44) + 16|0);
         HEAP32[$57>>2] = (13312);
         __THREW__ = 0;
         invoke_vi(3799,($44|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          $60 = HEAP32[$49>>2]|0;
          $61 = ($60>>>0)<(2);
          if ($61) {
           __THREW__ = 0;
           $62 = (invoke_i(132)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($62|0));
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if ($66) {
            break;
           }
          }
          $67 = HEAP32[$44>>2]|0;
          $68 = (($67) + 92|0);
          $69 = HEAP32[$68>>2]|0;
          $70 = (($57) + ($69)|0);
          HEAP32[$70>>2] = 42240;
          __THREW__ = 0;
          invoke_vi(3799,($44|0));
          $71 = __THREW__; __THREW__ = 0;
          $72 = $71&1;
          if (!($72)) {
           $73 = HEAP32[$49>>2]|0;
           $74 = ($73>>>0)<(3);
           if ($74) {
            __THREW__ = 0;
            $75 = (invoke_i(132)|0);
            $76 = __THREW__; __THREW__ = 0;
            $77 = $76&1;
            if ($77) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($75|0));
            $78 = __THREW__; __THREW__ = 0;
            $79 = $78&1;
            if ($79) {
             break;
            }
           }
           $80 = HEAP32[$44>>2]|0;
           $81 = (($80) + 92|0);
           $82 = HEAP32[$81>>2]|0;
           $83 = $82 << 1;
           $84 = (($57) + ($83)|0);
           HEAP32[$84>>2] = 65536;
           __THREW__ = 0;
           (invoke_ii(2996,(1170368|0))|0);
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if (!($86)) {
            __THREW__ = 0;
            $87 = (invoke_iii(2754,(1170368|0),6)|0);
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if (!($89)) {
             HEAP32[$0>>2] = 2666968;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
             invoke_viii(551,0,($87|0),($$byval_copy5|0));
             $90 = __THREW__; __THREW__ = 0;
             $91 = $90&1;
             if (!($91)) {
              __THREW__ = 0;
              (invoke_ii(2996,(1170368|0))|0);
              $92 = __THREW__; __THREW__ = 0;
              $93 = $92&1;
              if (!($93)) {
               __THREW__ = 0;
               $94 = (invoke_iii(2754,(1170368|0),6)|0);
               $95 = __THREW__; __THREW__ = 0;
               $96 = $95&1;
               if (!($96)) {
                HEAP32[$1>>2] = 2667008;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
                invoke_viii(551,0,($94|0),($$byval_copy5|0));
                $97 = __THREW__; __THREW__ = 0;
                $98 = $97&1;
                if ($98) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $99 = __THREW__; __THREW__ = 0;
                $100 = $99&1;
                if ($100) {
                 break;
                }
                __THREW__ = 0;
                $101 = (invoke_iii(2754,(1170368|0),6)|0);
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 break;
                }
                HEAP32[$2>>2] = 2667048;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
                invoke_viii(551,0,($101|0),($$byval_copy5|0));
                $104 = __THREW__; __THREW__ = 0;
                $105 = $104&1;
                if ($105) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $106 = __THREW__; __THREW__ = 0;
                $107 = $106&1;
                if ($107) {
                 break;
                }
                __THREW__ = 0;
                $108 = (invoke_iii(2754,(1170368|0),6)|0);
                $109 = __THREW__; __THREW__ = 0;
                $110 = $109&1;
                if ($110) {
                 break;
                }
                HEAP32[$3>>2] = 2667088;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
                invoke_viii(551,0,($108|0),($$byval_copy5|0));
                $111 = __THREW__; __THREW__ = 0;
                $112 = $111&1;
                if ($112) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $113 = __THREW__; __THREW__ = 0;
                $114 = $113&1;
                if ($114) {
                 break;
                }
                __THREW__ = 0;
                $115 = (invoke_iii(2754,(1170368|0),4)|0);
                $116 = __THREW__; __THREW__ = 0;
                $117 = $116&1;
                if ($117) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($115|0));
                $118 = __THREW__; __THREW__ = 0;
                $119 = $118&1;
                if ($119) {
                 break;
                }
                $120 = (($115) + 12|0);
                $121 = HEAP32[$120>>2]|0;
                $122 = ($121>>>0)<(2);
                if ($122) {
                 __THREW__ = 0;
                 $123 = (invoke_i(132)|0);
                 $124 = __THREW__; __THREW__ = 0;
                 $125 = $124&1;
                 if ($125) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($123|0));
                 $126 = __THREW__; __THREW__ = 0;
                 $127 = $126&1;
                 if ($127) {
                  break;
                 }
                }
                $128 = HEAP32[$115>>2]|0;
                $129 = (($115) + 16|0);
                $130 = (($128) + 92|0);
                $131 = HEAP32[$130>>2]|0;
                $132 = (($129) + ($131)|0);
                HEAP32[$132>>2] = 7680;
                __THREW__ = 0;
                invoke_vi(3799,($115|0));
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 break;
                }
                $135 = HEAP32[$120>>2]|0;
                $136 = ($135>>>0)<(3);
                if ($136) {
                 __THREW__ = 0;
                 $137 = (invoke_i(132)|0);
                 $138 = __THREW__; __THREW__ = 0;
                 $139 = $138&1;
                 if ($139) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($137|0));
                 $140 = __THREW__; __THREW__ = 0;
                 $141 = $140&1;
                 if ($141) {
                  break;
                 }
                }
                $142 = HEAP32[$115>>2]|0;
                $143 = (($142) + 92|0);
                $144 = HEAP32[$143>>2]|0;
                $145 = $144 << 1;
                $146 = (($129) + ($145)|0);
                HEAP32[$146>>2] = 12288;
                __THREW__ = 0;
                invoke_vi(3799,($115|0));
                $147 = __THREW__; __THREW__ = 0;
                $148 = $147&1;
                if ($148) {
                 break;
                }
                $149 = HEAP32[$120>>2]|0;
                $150 = ($149>>>0)<(4);
                if ($150) {
                 __THREW__ = 0;
                 $151 = (invoke_i(132)|0);
                 $152 = __THREW__; __THREW__ = 0;
                 $153 = $152&1;
                 if ($153) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($151|0));
                 $154 = __THREW__; __THREW__ = 0;
                 $155 = $154&1;
                 if ($155) {
                  break;
                 }
                }
                $156 = HEAP32[$115>>2]|0;
                $157 = (($156) + 92|0);
                $158 = HEAP32[$157>>2]|0;
                $159 = ($158*3)|0;
                $160 = (($129) + ($159)|0);
                HEAP32[$160>>2] = 64256;
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $161 = __THREW__; __THREW__ = 0;
                $162 = $161&1;
                if ($162) {
                 break;
                }
                __THREW__ = 0;
                $163 = (invoke_iii(2754,(1170368|0),4)|0);
                $164 = __THREW__; __THREW__ = 0;
                $165 = $164&1;
                if ($165) {
                 break;
                }
                HEAP32[$4>>2] = 2667128;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
                invoke_viii(551,0,($163|0),($$byval_copy5|0));
                $166 = __THREW__; __THREW__ = 0;
                $167 = $166&1;
                if ($167) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $168 = __THREW__; __THREW__ = 0;
                $169 = $168&1;
                if ($169) {
                 break;
                }
                __THREW__ = 0;
                $170 = (invoke_iii(2754,(1170368|0),4)|0);
                $171 = __THREW__; __THREW__ = 0;
                $172 = $171&1;
                if ($172) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($170|0));
                $173 = __THREW__; __THREW__ = 0;
                $174 = $173&1;
                if ($174) {
                 break;
                }
                $175 = (($170) + 12|0);
                $176 = HEAP32[$175>>2]|0;
                $177 = ($176>>>0)<(2);
                if ($177) {
                 __THREW__ = 0;
                 $178 = (invoke_i(132)|0);
                 $179 = __THREW__; __THREW__ = 0;
                 $180 = $179&1;
                 if ($180) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($178|0));
                 $181 = __THREW__; __THREW__ = 0;
                 $182 = $181&1;
                 if ($182) {
                  break;
                 }
                }
                $183 = HEAP32[$170>>2]|0;
                $184 = (($170) + 16|0);
                $185 = (($183) + 92|0);
                $186 = HEAP32[$185>>2]|0;
                $187 = (($184) + ($186)|0);
                HEAP32[$187>>2] = 7680;
                __THREW__ = 0;
                invoke_vi(3799,($170|0));
                $188 = __THREW__; __THREW__ = 0;
                $189 = $188&1;
                if ($189) {
                 break;
                }
                $190 = HEAP32[$175>>2]|0;
                $191 = ($190>>>0)<(3);
                if ($191) {
                 __THREW__ = 0;
                 $192 = (invoke_i(132)|0);
                 $193 = __THREW__; __THREW__ = 0;
                 $194 = $193&1;
                 if ($194) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($192|0));
                 $195 = __THREW__; __THREW__ = 0;
                 $196 = $195&1;
                 if ($196) {
                  break;
                 }
                }
                $197 = HEAP32[$170>>2]|0;
                $198 = (($197) + 92|0);
                $199 = HEAP32[$198>>2]|0;
                $200 = $199 << 1;
                $201 = (($184) + ($200)|0);
                HEAP32[$201>>2] = 12288;
                __THREW__ = 0;
                invoke_vi(3799,($170|0));
                $202 = __THREW__; __THREW__ = 0;
                $203 = $202&1;
                if ($203) {
                 break;
                }
                $204 = HEAP32[$175>>2]|0;
                $205 = ($204>>>0)<(4);
                if ($205) {
                 __THREW__ = 0;
                 $206 = (invoke_i(132)|0);
                 $207 = __THREW__; __THREW__ = 0;
                 $208 = $207&1;
                 if ($208) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($206|0));
                 $209 = __THREW__; __THREW__ = 0;
                 $210 = $209&1;
                 if ($210) {
                  break;
                 }
                }
                $211 = HEAP32[$170>>2]|0;
                $212 = (($211) + 92|0);
                $213 = HEAP32[$212>>2]|0;
                $214 = ($213*3)|0;
                $215 = (($184) + ($214)|0);
                HEAP32[$215>>2] = 64256;
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $216 = __THREW__; __THREW__ = 0;
                $217 = $216&1;
                if ($217) {
                 break;
                }
                __THREW__ = 0;
                $218 = (invoke_iii(2754,(1170368|0),4)|0);
                $219 = __THREW__; __THREW__ = 0;
                $220 = $219&1;
                if ($220) {
                 break;
                }
                HEAP32[$5>>2] = 2667168;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
                invoke_viii(551,0,($218|0),($$byval_copy5|0));
                $221 = __THREW__; __THREW__ = 0;
                $222 = $221&1;
                if ($222) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $223 = __THREW__; __THREW__ = 0;
                $224 = $223&1;
                if ($224) {
                 break;
                }
                __THREW__ = 0;
                $225 = (invoke_iii(2754,(1170368|0),3)|0);
                $226 = __THREW__; __THREW__ = 0;
                $227 = $226&1;
                if ($227) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($225|0));
                $228 = __THREW__; __THREW__ = 0;
                $229 = $228&1;
                if ($229) {
                 break;
                }
                $230 = (($225) + 12|0);
                $231 = HEAP32[$230>>2]|0;
                $232 = ($231|0)==(0);
                if ($232) {
                 __THREW__ = 0;
                 $233 = (invoke_i(132)|0);
                 $234 = __THREW__; __THREW__ = 0;
                 $235 = $234&1;
                 if ($235) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($233|0));
                 $236 = __THREW__; __THREW__ = 0;
                 $237 = $236&1;
                 if ($237) {
                  break;
                 }
                }
                $238 = (($225) + 16|0);
                HEAP32[$238>>2] = (12544);
                __THREW__ = 0;
                invoke_vi(3799,($225|0));
                $239 = __THREW__; __THREW__ = 0;
                $240 = $239&1;
                if ($240) {
                 break;
                }
                $241 = HEAP32[$230>>2]|0;
                $242 = ($241>>>0)<(2);
                if ($242) {
                 __THREW__ = 0;
                 $243 = (invoke_i(132)|0);
                 $244 = __THREW__; __THREW__ = 0;
                 $245 = $244&1;
                 if ($245) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($243|0));
                 $246 = __THREW__; __THREW__ = 0;
                 $247 = $246&1;
                 if ($247) {
                  break;
                 }
                }
                $248 = HEAP32[$225>>2]|0;
                $249 = (($248) + 92|0);
                $250 = HEAP32[$249>>2]|0;
                $251 = (($238) + ($250)|0);
                HEAP32[$251>>2] = 19968;
                __THREW__ = 0;
                invoke_vi(3799,($225|0));
                $252 = __THREW__; __THREW__ = 0;
                $253 = $252&1;
                if ($253) {
                 break;
                }
                $254 = HEAP32[$230>>2]|0;
                $255 = ($254>>>0)<(3);
                if ($255) {
                 __THREW__ = 0;
                 $256 = (invoke_i(132)|0);
                 $257 = __THREW__; __THREW__ = 0;
                 $258 = $257&1;
                 if ($258) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($256|0));
                 $259 = __THREW__; __THREW__ = 0;
                 $260 = $259&1;
                 if ($260) {
                  break;
                 }
                }
                $261 = HEAP32[$225>>2]|0;
                $262 = (($261) + 92|0);
                $263 = HEAP32[$262>>2]|0;
                $264 = $263 << 1;
                $265 = (($238) + ($264)|0);
                HEAP32[$265>>2] = 59392;
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $266 = __THREW__; __THREW__ = 0;
                $267 = $266&1;
                if ($267) {
                 break;
                }
                __THREW__ = 0;
                $268 = (invoke_iii(2754,(1170368|0),3)|0);
                $269 = __THREW__; __THREW__ = 0;
                $270 = $269&1;
                if ($270) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($268|0));
                $271 = __THREW__; __THREW__ = 0;
                $272 = $271&1;
                if ($272) {
                 break;
                }
                $273 = (($268) + 12|0);
                $274 = HEAP32[$273>>2]|0;
                $275 = ($274|0)==(0);
                if ($275) {
                 __THREW__ = 0;
                 $276 = (invoke_i(132)|0);
                 $277 = __THREW__; __THREW__ = 0;
                 $278 = $277&1;
                 if ($278) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($276|0));
                 $279 = __THREW__; __THREW__ = 0;
                 $280 = $279&1;
                 if ($280) {
                  break;
                 }
                }
                $281 = (($268) + 16|0);
                HEAP32[$281>>2] = (13312);
                __THREW__ = 0;
                invoke_vi(3799,($268|0));
                $282 = __THREW__; __THREW__ = 0;
                $283 = $282&1;
                if ($283) {
                 break;
                }
                $284 = HEAP32[$273>>2]|0;
                $285 = ($284>>>0)<(2);
                if ($285) {
                 __THREW__ = 0;
                 $286 = (invoke_i(132)|0);
                 $287 = __THREW__; __THREW__ = 0;
                 $288 = $287&1;
                 if ($288) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($286|0));
                 $289 = __THREW__; __THREW__ = 0;
                 $290 = $289&1;
                 if ($290) {
                  break;
                 }
                }
                $291 = HEAP32[$268>>2]|0;
                $292 = (($291) + 92|0);
                $293 = HEAP32[$292>>2]|0;
                $294 = (($281) + ($293)|0);
                HEAP32[$294>>2] = 40960;
                __THREW__ = 0;
                invoke_vi(3799,($268|0));
                $295 = __THREW__; __THREW__ = 0;
                $296 = $295&1;
                if ($296) {
                 break;
                }
                $297 = HEAP32[$273>>2]|0;
                $298 = ($297>>>0)<(3);
                if ($298) {
                 __THREW__ = 0;
                 $299 = (invoke_i(132)|0);
                 $300 = __THREW__; __THREW__ = 0;
                 $301 = $300&1;
                 if ($301) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($299|0));
                 $302 = __THREW__; __THREW__ = 0;
                 $303 = $302&1;
                 if ($303) {
                  break;
                 }
                }
                $304 = HEAP32[$268>>2]|0;
                $305 = (($304) + 92|0);
                $306 = HEAP32[$305>>2]|0;
                $307 = $306 << 1;
                $308 = (($281) + ($307)|0);
                HEAP32[$308>>2] = 65536;
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $309 = __THREW__; __THREW__ = 0;
                $310 = $309&1;
                if ($310) {
                 break;
                }
                __THREW__ = 0;
                $311 = (invoke_iii(2754,(1170368|0),3)|0);
                $312 = __THREW__; __THREW__ = 0;
                $313 = $312&1;
                if ($313) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($311|0));
                $314 = __THREW__; __THREW__ = 0;
                $315 = $314&1;
                if ($315) {
                 break;
                }
                $316 = (($311) + 12|0);
                $317 = HEAP32[$316>>2]|0;
                $318 = ($317|0)==(0);
                if ($318) {
                 __THREW__ = 0;
                 $319 = (invoke_i(132)|0);
                 $320 = __THREW__; __THREW__ = 0;
                 $321 = $320&1;
                 if ($321) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($319|0));
                 $322 = __THREW__; __THREW__ = 0;
                 $323 = $322&1;
                 if ($323) {
                  break;
                 }
                }
                $324 = (($311) + 16|0);
                HEAP32[$324>>2] = (12544);
                __THREW__ = 0;
                invoke_vi(3799,($311|0));
                $325 = __THREW__; __THREW__ = 0;
                $326 = $325&1;
                if ($326) {
                 break;
                }
                $327 = HEAP32[$316>>2]|0;
                $328 = ($327>>>0)<(2);
                if ($328) {
                 __THREW__ = 0;
                 $329 = (invoke_i(132)|0);
                 $330 = __THREW__; __THREW__ = 0;
                 $331 = $330&1;
                 if ($331) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($329|0));
                 $332 = __THREW__; __THREW__ = 0;
                 $333 = $332&1;
                 if ($333) {
                  break;
                 }
                }
                $334 = HEAP32[$311>>2]|0;
                $335 = (($334) + 92|0);
                $336 = HEAP32[$335>>2]|0;
                $337 = (($324) + ($336)|0);
                HEAP32[$337>>2] = 19968;
                __THREW__ = 0;
                invoke_vi(3799,($311|0));
                $338 = __THREW__; __THREW__ = 0;
                $339 = $338&1;
                if ($339) {
                 break;
                }
                $340 = HEAP32[$316>>2]|0;
                $341 = ($340>>>0)<(3);
                if ($341) {
                 __THREW__ = 0;
                 $342 = (invoke_i(132)|0);
                 $343 = __THREW__; __THREW__ = 0;
                 $344 = $343&1;
                 if ($344) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($342|0));
                 $345 = __THREW__; __THREW__ = 0;
                 $346 = $345&1;
                 if ($346) {
                  break;
                 }
                }
                $347 = HEAP32[$311>>2]|0;
                $348 = (($347) + 92|0);
                $349 = HEAP32[$348>>2]|0;
                $350 = $349 << 1;
                $351 = (($324) + ($350)|0);
                HEAP32[$351>>2] = 63744;
                __THREW__ = 0;
                (invoke_ii(2996,(1170368|0))|0);
                $352 = __THREW__; __THREW__ = 0;
                $353 = $352&1;
                if ($353) {
                 break;
                }
                __THREW__ = 0;
                $354 = (invoke_iii(2754,(1170368|0),3)|0);
                $355 = __THREW__; __THREW__ = 0;
                $356 = $355&1;
                if ($356) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($354|0));
                $357 = __THREW__; __THREW__ = 0;
                $358 = $357&1;
                if ($358) {
                 break;
                }
                $359 = (($354) + 12|0);
                $360 = HEAP32[$359>>2]|0;
                $361 = ($360|0)==(0);
                if ($361) {
                 __THREW__ = 0;
                 $362 = (invoke_i(132)|0);
                 $363 = __THREW__; __THREW__ = 0;
                 $364 = $363&1;
                 if ($364) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($362|0));
                 $365 = __THREW__; __THREW__ = 0;
                 $366 = $365&1;
                 if ($366) {
                  break;
                 }
                }
                $367 = (($354) + 16|0);
                HEAP32[$367>>2] = (13312);
                __THREW__ = 0;
                invoke_vi(3799,($354|0));
                $368 = __THREW__; __THREW__ = 0;
                $369 = $368&1;
                if ($369) {
                 break;
                }
                $370 = HEAP32[$359>>2]|0;
                $371 = ($370>>>0)<(2);
                if ($371) {
                 __THREW__ = 0;
                 $372 = (invoke_i(132)|0);
                 $373 = __THREW__; __THREW__ = 0;
                 $374 = $373&1;
                 if ($374) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($372|0));
                 $375 = __THREW__; __THREW__ = 0;
                 $376 = $375&1;
                 if ($376) {
                  break;
                 }
                }
                $377 = HEAP32[$354>>2]|0;
                $378 = (($377) + 92|0);
                $379 = HEAP32[$378>>2]|0;
                $380 = (($367) + ($379)|0);
                HEAP32[$380>>2] = 40960;
                __THREW__ = 0;
                invoke_vi(3799,($354|0));
                $381 = __THREW__; __THREW__ = 0;
                $382 = $381&1;
                if ($382) {
                 break;
                }
                $383 = HEAP32[$359>>2]|0;
                $384 = ($383>>>0)<(3);
                if ($384) {
                 __THREW__ = 0;
                 $385 = (invoke_i(132)|0);
                 $386 = __THREW__; __THREW__ = 0;
                 $387 = $386&1;
                 if ($387) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($385|0));
                 $388 = __THREW__; __THREW__ = 0;
                 $389 = $388&1;
                 if ($389) {
                  break;
                 }
                }
                $390 = HEAP32[$354>>2]|0;
                $391 = (($390) + 92|0);
                $392 = HEAP32[$391>>2]|0;
                $393 = $392 << 1;
                $394 = (($367) + ($393)|0);
                HEAP32[$394>>2] = 64256;
                __THREW__ = 0;
                (invoke_ii(2996,(2258760|0))|0);
                $395 = __THREW__; __THREW__ = 0;
                $396 = $395&1;
                if ($396) {
                 break;
                }
                __THREW__ = 0;
                $397 = (invoke_ii(3469,(2258760|0))|0);
                $398 = __THREW__; __THREW__ = 0;
                $399 = $398&1;
                if ($399) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiiii(55,($397|0),($8|0),($44|0),-1,-1);
                $400 = __THREW__; __THREW__ = 0;
                $401 = $400&1;
                if ($401) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2264376|0))|0);
                $402 = __THREW__; __THREW__ = 0;
                $403 = $402&1;
                if ($403) {
                 break;
                }
                $404 = HEAP32[((2264376 + 80|0))>>2]|0;
                HEAP32[$404>>2] = $397;
                __THREW__ = 0;
                (invoke_ii(2996,(2258760|0))|0);
                $405 = __THREW__; __THREW__ = 0;
                $406 = $405&1;
                if ($406) {
                 break;
                }
                __THREW__ = 0;
                $407 = (invoke_ii(3469,(2258760|0))|0);
                $408 = __THREW__; __THREW__ = 0;
                $409 = $408&1;
                if ($409) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiiii(55,($407|0),($87|0),($94|0),0,0);
                $410 = __THREW__; __THREW__ = 0;
                $411 = $410&1;
                if ($411) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2264376|0))|0);
                $412 = __THREW__; __THREW__ = 0;
                $413 = $412&1;
                if ($413) {
                 break;
                }
                $414 = HEAP32[((2264376 + 80|0))>>2]|0;
                $415 = (($414) + 4|0);
                HEAP32[$415>>2] = $407;
                __THREW__ = 0;
                (invoke_ii(2996,(2258760|0))|0);
                $416 = __THREW__; __THREW__ = 0;
                $417 = $416&1;
                if ($417) {
                 break;
                }
                __THREW__ = 0;
                $418 = (invoke_ii(3469,(2258760|0))|0);
                $419 = __THREW__; __THREW__ = 0;
                $420 = $419&1;
                if ($420) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiiii(55,($418|0),($101|0),($108|0),0,0);
                $421 = __THREW__; __THREW__ = 0;
                $422 = $421&1;
                if ($422) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2264376|0))|0);
                $423 = __THREW__; __THREW__ = 0;
                $424 = $423&1;
                if ($424) {
                 break;
                }
                $425 = HEAP32[((2264376 + 80|0))>>2]|0;
                $426 = (($425) + 8|0);
                HEAP32[$426>>2] = $418;
                __THREW__ = 0;
                (invoke_ii(2996,(2258760|0))|0);
                $427 = __THREW__; __THREW__ = 0;
                $428 = $427&1;
                if ($428) {
                 break;
                }
                __THREW__ = 0;
                $429 = (invoke_ii(3469,(2258760|0))|0);
                $430 = __THREW__; __THREW__ = 0;
                $431 = $430&1;
                if ($431) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiiii(55,($429|0),($115|0),($163|0),0,0);
                $432 = __THREW__; __THREW__ = 0;
                $433 = $432&1;
                if ($433) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2264376|0))|0);
                $434 = __THREW__; __THREW__ = 0;
                $435 = $434&1;
                if ($435) {
                 break;
                }
                $436 = HEAP32[((2264376 + 80|0))>>2]|0;
                $437 = (($436) + 12|0);
                HEAP32[$437>>2] = $429;
                __THREW__ = 0;
                (invoke_ii(2996,(2258760|0))|0);
                $438 = __THREW__; __THREW__ = 0;
                $439 = $438&1;
                if ($439) {
                 break;
                }
                __THREW__ = 0;
                $440 = (invoke_ii(3469,(2258760|0))|0);
                $441 = __THREW__; __THREW__ = 0;
                $442 = $441&1;
                if ($442) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiiii(55,($440|0),($170|0),($218|0),0,0);
                $443 = __THREW__; __THREW__ = 0;
                $444 = $443&1;
                if ($444) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2264376|0))|0);
                $445 = __THREW__; __THREW__ = 0;
                $446 = $445&1;
                if ($446) {
                 break;
                }
                $447 = HEAP32[((2264376 + 80|0))>>2]|0;
                $448 = (($447) + 16|0);
                HEAP32[$448>>2] = $440;
                __THREW__ = 0;
                (invoke_ii(2996,(2258760|0))|0);
                $449 = __THREW__; __THREW__ = 0;
                $450 = $449&1;
                if ($450) {
                 break;
                }
                __THREW__ = 0;
                $451 = (invoke_ii(3469,(2258760|0))|0);
                $452 = __THREW__; __THREW__ = 0;
                $453 = $452&1;
                if ($453) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiiii(55,($451|0),($225|0),($268|0),-1,-1);
                $454 = __THREW__; __THREW__ = 0;
                $455 = $454&1;
                if ($455) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2264376|0))|0);
                $456 = __THREW__; __THREW__ = 0;
                $457 = $456&1;
                if ($457) {
                 break;
                }
                $458 = HEAP32[((2264376 + 80|0))>>2]|0;
                $459 = (($458) + 20|0);
                HEAP32[$459>>2] = $451;
                __THREW__ = 0;
                (invoke_ii(2996,(2258760|0))|0);
                $460 = __THREW__; __THREW__ = 0;
                $461 = $460&1;
                if ($461) {
                 break;
                }
                __THREW__ = 0;
                $462 = (invoke_ii(3469,(2258760|0))|0);
                $463 = __THREW__; __THREW__ = 0;
                $464 = $463&1;
                if ($464) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiiii(55,($462|0),($311|0),($354|0),-1,-1);
                $465 = __THREW__; __THREW__ = 0;
                $466 = $465&1;
                if ($466) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2264376|0))|0);
                $467 = __THREW__; __THREW__ = 0;
                $468 = $467&1;
                if ($468) {
                 break;
                }
                $469 = HEAP32[((2264376 + 80|0))>>2]|0;
                $470 = (($469) + 24|0);
                HEAP32[$470>>2] = $462;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z66mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context_m__ctorP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_ContextiPhS1_S1_S1_S1_b($__this,$opt,$alwaysMatchFlags,$neverMatchFlags,$buffer1,$buffer2,$prev1,$quickCheckPossible) {
 $__this = $__this|0;
 $opt = $opt|0;
 $alwaysMatchFlags = $alwaysMatchFlags|0;
 $neverMatchFlags = $neverMatchFlags|0;
 $buffer1 = $buffer1|0;
 $buffer2 = $buffer2|0;
 $prev1 = $prev1|0;
 $quickCheckPossible = $quickCheckPossible|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2264512);
 HEAP32[$__this>>2] = $opt;
 $0 = (($__this) + 8|0);
 HEAP32[$0>>2] = $alwaysMatchFlags;
 $1 = (($__this) + 4|0);
 HEAP32[$1>>2] = $neverMatchFlags;
 $2 = (($__this) + 12|0);
 HEAP32[$2>>2] = $buffer1;
 $3 = (($__this) + 16|0);
 HEAP32[$3>>2] = $buffer2;
 $4 = (($__this) + 24|0);
 HEAP32[$4>>2] = $prev1;
 $5 = (($__this) + 20|0);
 HEAP32[$5>>2] = -1;
 $6 = (($__this) + 28|0);
 $7 = $quickCheckPossible&1;
 HEAP8[$6>>0] = $7;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S1_S1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFvPviS4_S4_S4_S4_S4_bES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)!=(0);
 FUNCTION_TABLE_viiiiiiii[$action & 63]($obj,$1,$3,$5,$7,$9,$11,$15);
 STACKTOP = sp;return (0|0);
}
function __Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_PreviousInfo_m__ctorP63mscorlib_Mono_Globalization_Unicode_SimpleCollator_PreviousInfob($__this,$dummy) {
 $__this = $__this|0;
 $dummy = $dummy|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2265176);
 HEAP32[$__this>>2] = -1;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z58mscorlib_Mono_Globalization_Unicode_SimpleCollator_m__ctorP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP41mscorlib_System_Globalization_CultureInfo($__this,$culture) {
 $__this = $__this|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$2 = 0, $V_1$0 = 0, $V_10$0 = 0;
 var $V_13$0 = 0, $V_4$0 = 0, $V_7$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273504);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($culture|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2729,(2273552|0),($culture|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($__this) + 36|0);
     HEAP32[$7>>2] = $4;
     __THREW__ = 0;
     invoke_vi(3799,($culture|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2730,(2273600|0),($culture|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       $13 = (($__this) + 8|0);
       HEAP32[$13>>2] = $10;
       $14 = (($__this) + 24|0);
       $15 = (($__this) + 16|0);
       $16 = (($__this) + 20|0);
       $17 = (($__this) + 32|0);
       $18 = (($__this) + 28|0);
       __THREW__ = 0;
       invoke_viiiiiii(19,0,($culture|0),($14|0),($15|0),($16|0),($17|0),($18|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $V_1$0 = $culture;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($V_1$0|0));
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 11;
          break;
         }
         __THREW__ = 0;
         $47 = (invoke_iii(2729,(2273552|0),($V_1$0|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          label = 11;
          break;
         }
         $50 = ($47|0)==(127);
         if ($50) {
          label = 24;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_1$0|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          label = 11;
          break;
         }
         __THREW__ = 0;
         $33 = (invoke_iii(2729,(2273552|0),($V_1$0|0))|0);
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          label = 11;
          break;
         }
         __THREW__ = 0;
         $36 = (invoke_iii(785,(0|0),($33|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          label = 11;
          break;
         }
         $39 = ($36|0)==(0|0);
         if (!($39)) {
          $V_0$2 = $36;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_1$0|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          label = 11;
          break;
         }
         __THREW__ = 0;
         $42 = (invoke_iii(2730,(2273648|0),($V_1$0|0))|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          label = 11;
          break;
         }
         $V_1$0 = $42;
        }
        if ((label|0) == 11) {
         $29 = ___cxa_find_matching_catch()|0;
         $30 = tempRet0;
         $lpad$phi$index = $29;$lpad$phi$index6 = $30;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 24) {
         __THREW__ = 0;
         $53 = (invoke_iii(785,(0|0),127)|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break;
         } else {
          $V_0$2 = $53;
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($V_0$2|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if (!($57)) {
         $58 = (($V_0$2) + 20|0);
         $59 = HEAP8[$58>>0]|0;
         $60 = (($__this) + 12|0);
         HEAP8[$60>>0] = $59;
         $61 = (($__this) + 40|0);
         $62 = (($__this) + 44|0);
         __THREW__ = 0;
         invoke_viiiii(57,(0|0),($culture|0),($V_0$2|0),($61|0),($62|0));
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if (!($64)) {
          __THREW__ = 0;
          (invoke_ii(2996,(1203320|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if (!($66)) {
           __THREW__ = 0;
           $67 = (invoke_iii(2758,(1203320|0),96)|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if (!($69)) {
            $70 = (($__this) + 48|0);
            HEAP32[$70>>2] = $67;
            $71 = HEAP32[$61>>2]|0;
            $72 = (($71) + 12|0);
            $73 = (($71) + 16|0);
            $V_4$0 = 0;
            L27: while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($71|0));
             $148 = __THREW__; __THREW__ = 0;
             $149 = $148&1;
             if ($149) {
              label = 10;
              break;
             }
             $150 = HEAP32[$72>>2]|0;
             $151 = ($V_4$0|0)<($150|0);
             if (!($151)) {
              label = 53;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($71|0));
             $152 = __THREW__; __THREW__ = 0;
             $153 = $152&1;
             if ($153) {
              label = 10;
              break;
             }
             $74 = HEAP32[$72>>2]|0;
             $75 = ($V_4$0>>>0)<($74>>>0);
             if (!($75)) {
              __THREW__ = 0;
              $76 = (invoke_i(132)|0);
              $77 = __THREW__; __THREW__ = 0;
              $78 = $77&1;
              if ($78) {
               label = 10;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($76|0));
              $79 = __THREW__; __THREW__ = 0;
              $80 = $79&1;
              if ($80) {
               label = 10;
               break;
              }
             }
             $81 = HEAP32[$71>>2]|0;
             $82 = (($81) + 92|0);
             $83 = HEAP32[$82>>2]|0;
             $84 = Math_imul($83, $V_4$0)|0;
             $85 = (($73) + ($84)|0);
             $86 = HEAP32[$85>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($86|0));
             $87 = __THREW__; __THREW__ = 0;
             $88 = $87&1;
             if ($88) {
              label = 10;
              break;
             }
             $89 = (($86) + 8|0);
             $90 = HEAP32[$89>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($90|0));
             $91 = __THREW__; __THREW__ = 0;
             $92 = $91&1;
             if ($92) {
              label = 10;
              break;
             }
             $93 = (($90) + 12|0);
             $94 = HEAP32[$93>>2]|0;
             $95 = ($94|0)<(2);
             L38: do {
              if (!($95)) {
               __THREW__ = 0;
               invoke_vi(3799,($86|0));
               $96 = __THREW__; __THREW__ = 0;
               $97 = $96&1;
               if ($97) {
                label = 10;
                break L27;
               }
               $98 = HEAP32[$89>>2]|0;
               $99 = (($98) + 12|0);
               $100 = (($98) + 16|0);
               $V_7$0 = 0;
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($98|0));
                $141 = __THREW__; __THREW__ = 0;
                $142 = $141&1;
                if ($142) {
                 label = 9;
                 break L27;
                }
                $143 = HEAP32[$99>>2]|0;
                $144 = ($V_7$0|0)<($143|0);
                if (!($144)) {
                 break L38;
                }
                __THREW__ = 0;
                invoke_vi(3799,($98|0));
                $145 = __THREW__; __THREW__ = 0;
                $146 = $145&1;
                if ($146) {
                 label = 9;
                 break L27;
                }
                $101 = HEAP32[$99>>2]|0;
                $102 = ($V_7$0>>>0)<($101>>>0);
                if (!($102)) {
                 __THREW__ = 0;
                 $103 = (invoke_i(132)|0);
                 $104 = __THREW__; __THREW__ = 0;
                 $105 = $104&1;
                 if ($105) {
                  label = 9;
                  break L27;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($103|0));
                 $106 = __THREW__; __THREW__ = 0;
                 $107 = $106&1;
                 if ($107) {
                  label = 9;
                  break L27;
                 }
                }
                $108 = HEAP32[$98>>2]|0;
                $109 = (($108) + 92|0);
                $110 = HEAP32[$109>>2]|0;
                $111 = Math_imul($110, $V_7$0)|0;
                $112 = (($100) + ($111)|0);
                $113 = HEAP16[$112>>1]|0;
                $114 = HEAP32[$70>>2]|0;
                $115 = $113&65535;
                __THREW__ = 0;
                invoke_vi(3799,($114|0));
                $116 = __THREW__; __THREW__ = 0;
                $117 = $116&1;
                if ($117) {
                 label = 9;
                 break L27;
                }
                $118 = ($113&65535) >>> 3;
                $119 = $118&65535;
                $120 = (($114) + 12|0);
                $121 = HEAP32[$120>>2]|0;
                $122 = ($119>>>0)<($121>>>0);
                if (!($122)) {
                 __THREW__ = 0;
                 $123 = (invoke_i(132)|0);
                 $124 = __THREW__; __THREW__ = 0;
                 $125 = $124&1;
                 if ($125) {
                  label = 9;
                  break L27;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($123|0));
                 $126 = __THREW__; __THREW__ = 0;
                 $127 = $126&1;
                 if ($127) {
                  label = 9;
                  break L27;
                 }
                }
                $128 = HEAP32[$114>>2]|0;
                $129 = (($114) + 16|0);
                $130 = (($128) + 92|0);
                $131 = HEAP32[$130>>2]|0;
                $132 = Math_imul($131, $119)|0;
                $133 = (($129) + ($132)|0);
                $134 = HEAP8[$133>>0]|0;
                $135 = $134&255;
                $136 = $115 & 7;
                $137 = 1 << $136;
                $138 = $135 | $137;
                $139 = $138&255;
                HEAP8[$133>>0] = $139;
                $140 = (($V_7$0) + 1)|0;
                $V_7$0 = $140;
               }
              }
             } while(0);
             $147 = (($V_4$0) + 1)|0;
             $V_4$0 = $147;
            }
            if ((label|0) == 9) {
             $25 = ___cxa_find_matching_catch()|0;
             $26 = tempRet0;
             $lpad$phi$index = $25;$lpad$phi$index6 = $26;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            else if ((label|0) == 10) {
             $27 = ___cxa_find_matching_catch()|0;
             $28 = tempRet0;
             $lpad$phi$index = $27;$lpad$phi$index6 = $28;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            else if ((label|0) == 53) {
             $154 = HEAP32[$7>>2]|0;
             $155 = ($154|0)==(127);
             if ($155) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2280704|0))|0);
             $156 = __THREW__; __THREW__ = 0;
             $157 = $156&1;
             if ($157) {
              break;
             }
             $158 = HEAP8[((2280704 + 116|0))>>0]|0;
             $159 = ($158<<24>>24)==(0);
             if ($159) {
              __THREW__ = 0;
              (invoke_ii(2996,(2280704|0))|0);
              $160 = __THREW__; __THREW__ = 0;
              $161 = $160&1;
              if ($161) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2280704|0))|0);
              $162 = __THREW__; __THREW__ = 0;
              $163 = $162&1;
              if ($163) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3832,(2280704|0));
              $164 = __THREW__; __THREW__ = 0;
              $165 = $164&1;
              if ($165) {
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2280704|0))|0);
             $166 = __THREW__; __THREW__ = 0;
             $167 = $166&1;
             if ($167) {
              break;
             }
             $168 = HEAP32[((2280704 + 80|0))>>2]|0;
             $169 = (($168) + 4|0);
             $170 = HEAP32[$169>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($170|0));
             $171 = __THREW__; __THREW__ = 0;
             $172 = $171&1;
             if ($172) {
              break;
             }
             $173 = (($170) + 40|0);
             $174 = HEAP32[$173>>2]|0;
             $175 = (($174) + 12|0);
             $176 = (($174) + 16|0);
             $V_10$0 = 0;
             L73: while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $251 = __THREW__; __THREW__ = 0;
              $252 = $251&1;
              if ($252) {
               label = 8;
               break;
              }
              $253 = HEAP32[$175>>2]|0;
              $254 = ($V_10$0|0)<($253|0);
              if (!($254)) {
               label = 85;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $255 = __THREW__; __THREW__ = 0;
              $256 = $255&1;
              if ($256) {
               label = 8;
               break;
              }
              $177 = HEAP32[$175>>2]|0;
              $178 = ($V_10$0>>>0)<($177>>>0);
              if (!($178)) {
               __THREW__ = 0;
               $179 = (invoke_i(132)|0);
               $180 = __THREW__; __THREW__ = 0;
               $181 = $180&1;
               if ($181) {
                label = 8;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($179|0));
               $182 = __THREW__; __THREW__ = 0;
               $183 = $182&1;
               if ($183) {
                label = 8;
                break;
               }
              }
              $184 = HEAP32[$174>>2]|0;
              $185 = (($184) + 92|0);
              $186 = HEAP32[$185>>2]|0;
              $187 = Math_imul($186, $V_10$0)|0;
              $188 = (($176) + ($187)|0);
              $189 = HEAP32[$188>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($189|0));
              $190 = __THREW__; __THREW__ = 0;
              $191 = $190&1;
              if ($191) {
               label = 8;
               break;
              }
              $192 = (($189) + 8|0);
              $193 = HEAP32[$192>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($193|0));
              $194 = __THREW__; __THREW__ = 0;
              $195 = $194&1;
              if ($195) {
               label = 8;
               break;
              }
              $196 = (($193) + 12|0);
              $197 = HEAP32[$196>>2]|0;
              $198 = ($197|0)<(2);
              L84: do {
               if (!($198)) {
                __THREW__ = 0;
                invoke_vi(3799,($189|0));
                $199 = __THREW__; __THREW__ = 0;
                $200 = $199&1;
                if ($200) {
                 label = 8;
                 break L73;
                }
                $201 = HEAP32[$192>>2]|0;
                $202 = (($201) + 12|0);
                $203 = (($201) + 16|0);
                $V_13$0 = 0;
                while(1) {
                 __THREW__ = 0;
                 invoke_vi(3799,($201|0));
                 $244 = __THREW__; __THREW__ = 0;
                 $245 = $244&1;
                 if ($245) {
                  label = 7;
                  break L73;
                 }
                 $246 = HEAP32[$202>>2]|0;
                 $247 = ($V_13$0|0)<($246|0);
                 if (!($247)) {
                  break L84;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($201|0));
                 $248 = __THREW__; __THREW__ = 0;
                 $249 = $248&1;
                 if ($249) {
                  label = 7;
                  break L73;
                 }
                 $204 = HEAP32[$202>>2]|0;
                 $205 = ($V_13$0>>>0)<($204>>>0);
                 if (!($205)) {
                  __THREW__ = 0;
                  $206 = (invoke_i(132)|0);
                  $207 = __THREW__; __THREW__ = 0;
                  $208 = $207&1;
                  if ($208) {
                   label = 7;
                   break L73;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($206|0));
                  $209 = __THREW__; __THREW__ = 0;
                  $210 = $209&1;
                  if ($210) {
                   label = 7;
                   break L73;
                  }
                 }
                 $211 = HEAP32[$201>>2]|0;
                 $212 = (($211) + 92|0);
                 $213 = HEAP32[$212>>2]|0;
                 $214 = Math_imul($213, $V_13$0)|0;
                 $215 = (($203) + ($214)|0);
                 $216 = HEAP16[$215>>1]|0;
                 $217 = HEAP32[$70>>2]|0;
                 $218 = $216&65535;
                 __THREW__ = 0;
                 invoke_vi(3799,($217|0));
                 $219 = __THREW__; __THREW__ = 0;
                 $220 = $219&1;
                 if ($220) {
                  label = 7;
                  break L73;
                 }
                 $221 = ($216&65535) >>> 3;
                 $222 = $221&65535;
                 $223 = (($217) + 12|0);
                 $224 = HEAP32[$223>>2]|0;
                 $225 = ($222>>>0)<($224>>>0);
                 if (!($225)) {
                  __THREW__ = 0;
                  $226 = (invoke_i(132)|0);
                  $227 = __THREW__; __THREW__ = 0;
                  $228 = $227&1;
                  if ($228) {
                   label = 7;
                   break L73;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($226|0));
                  $229 = __THREW__; __THREW__ = 0;
                  $230 = $229&1;
                  if ($230) {
                   label = 7;
                   break L73;
                  }
                 }
                 $231 = HEAP32[$217>>2]|0;
                 $232 = (($217) + 16|0);
                 $233 = (($231) + 92|0);
                 $234 = HEAP32[$233>>2]|0;
                 $235 = Math_imul($234, $222)|0;
                 $236 = (($232) + ($235)|0);
                 $237 = HEAP8[$236>>0]|0;
                 $238 = $237&255;
                 $239 = $218 & 7;
                 $240 = 1 << $239;
                 $241 = $238 | $240;
                 $242 = $241&255;
                 HEAP8[$236>>0] = $242;
                 $243 = (($V_13$0) + 1)|0;
                 $V_13$0 = $243;
                }
               }
              } while(0);
              $250 = (($V_10$0) + 1)|0;
              $V_10$0 = $250;
             }
             if ((label|0) == 7) {
              $21 = ___cxa_find_matching_catch()|0;
              $22 = tempRet0;
              $lpad$phi$index = $21;$lpad$phi$index6 = $22;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
             else if ((label|0) == 8) {
              $23 = ___cxa_find_matching_catch()|0;
              $24 = tempRet0;
              $lpad$phi$index = $23;$lpad$phi$index6 = $24;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
             else if ((label|0) == 85) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $lpad$phi$index = $31;$lpad$phi$index6 = $32;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z64mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_SetCJKTableP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP41mscorlib_System_Globalization_CultureInfoPP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerPPhS7_S5_S7_($__this,$culture,$cjkIndexer,$catTable,$lv1Table,$lv2Indexer,$lv2Table) {
 $__this = $__this|0;
 $culture = $culture|0;
 $cjkIndexer = $cjkIndexer|0;
 $catTable = $catTable|0;
 $lv1Table = $lv1Table|0;
 $lv2Indexer = $lv2Indexer|0;
 $lv2Table = $lv2Table|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273744);
 __THREW__ = 0;
 $0 = (invoke_iii(798,0,($culture|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2273792|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viiiiiii(17,(0|0),($5|0),($cjkIndexer|0),($catTable|0),($lv1Table|0),($lv2Indexer|0),($lv2Table|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj5700($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL11RuntimeInitP8TypeInfo5701($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z59mscorlib_Mono_Globalization_Unicode_SimpleCollator_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273696);
 __THREW__ = 0;
 invoke_v(525);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3019672>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(1122,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[3019680>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iiii(574,(0|0),($3|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2280704|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[((2280704 + 80|0))>>2]|0;
     $13 = $7&1;
     HEAP8[$12>>0] = $13;
     __THREW__ = 0;
     $14 = (invoke_ii(1982,0)|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2280704|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_ii(3469,(2280704|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        invoke_vii(1796,($19|0),($14|0));
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2280704|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          $26 = HEAP32[((2280704 + 80|0))>>2]|0;
          $27 = (($26) + 4|0);
          HEAP32[$27>>2] = $19;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
}
function __Z64mscorlib_System_Globalization_CultureInfo_m_get_InvariantCultureP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2329848);
 __THREW__ = 0;
 (invoke_ii(2996,(2333776|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2333776 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2333776|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2333776|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3832,(2333776|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2333776|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2333776 + 80|0))>>2]|0;
    $15 = (($14) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetNeutralCultureP22mscorlib_System_ObjectP41mscorlib_System_Globalization_CultureInfo($__this,$info) {
 $__this = $__this|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273840);
 $V_0$0 = $info;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($V_0$0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  $5 = (invoke_iii(2730,(2273648|0),($V_0$0|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 7;
   break;
  }
  $8 = ($5|0)==(0|0);
  if ($8) {
   label = 14;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($V_0$0|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  $13 = (invoke_iii(2730,(2273648|0),($V_0$0|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($13|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  $18 = (invoke_iii(2729,(2273552|0),($13|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   label = 7;
   break;
  }
  $21 = ($18|0)==(127);
  if ($21) {
   label = 14;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($V_0$0|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  $0 = (invoke_iii(2730,(2273648|0),($V_0$0|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if ($2) {
   label = 7;
   break;
  }
  $V_0$0 = $0;
 }
 if ((label|0) == 7) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_0$0|0);
 }
 return 0|0;
}
function __Z61mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CategoryP50mscorlib_Mono_Globalization_Unicode_SimpleCollatori($__this,$cp) {
 $__this = $__this|0;
 $cp = $cp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273888);
 $0 = ($cp|0)<(12288);
 do {
  if ($0) {
   label = 3;
  } else {
   $1 = (($__this) + 16|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    label = 3;
   } else {
    $9 = (($__this) + 24|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_iii(784,($10|0),($cp|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = ($13|0)>(-1);
      if ($16) {
       $20 = HEAP32[$1>>2]|0;
       $21 = (($20) + ($13)|0);
       $22 = HEAP8[$21>>0]|0;
       $$0 = $22;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      } else {
       __THREW__ = 0;
       $17 = (invoke_iii(786,(0|0),($cp|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       } else {
        $$0 = $17;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  __THREW__ = 0;
  $4 = (invoke_iii(786,(0|0),($cp|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $$0 = $4;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_Level1P50mscorlib_Mono_Globalization_Unicode_SimpleCollatori($__this,$cp) {
 $__this = $__this|0;
 $cp = $cp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273936);
 $0 = ($cp|0)<(12288);
 do {
  if ($0) {
   label = 3;
  } else {
   $1 = (($__this) + 20|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    label = 3;
   } else {
    $9 = (($__this) + 24|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_iii(784,($10|0),($cp|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = ($13|0)>(-1);
      if ($16) {
       $20 = HEAP32[$1>>2]|0;
       $21 = (($20) + ($13)|0);
       $22 = HEAP8[$21>>0]|0;
       $$0 = $22;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      } else {
       __THREW__ = 0;
       $17 = (invoke_iii(787,(0|0),($cp|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       } else {
        $$0 = $17;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  __THREW__ = 0;
  $4 = (invoke_iii(787,(0|0),($cp|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $$0 = $4;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_Level2P50mscorlib_Mono_Globalization_Unicode_SimpleCollatorii($__this,$cp,$ext) {
 $__this = $__this|0;
 $cp = $cp|0;
 $ext = $ext|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273984);
 if ((($ext|0) == 4)) {
  $$0 = 5;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 } else if ((($ext|0) == 3)) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 } else {
  $0 = ($cp|0)<(12288);
  do {
   if ($0) {
    label = 5;
   } else {
    $1 = (($__this) + 28|0);
    $2 = HEAP32[$1>>2]|0;
    $3 = ($2|0)==(0|0);
    if ($3) {
     label = 5;
    } else {
     $11 = (($__this) + 32|0);
     $12 = HEAP32[$11>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_iii(784,($12|0),($cp|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = ($15|0)>(-1);
       if ($18) {
        $19 = HEAP32[$1>>2]|0;
        $20 = (($19) + ($15)|0);
        $21 = HEAP8[$20>>0]|0;
        $22 = ($21<<24>>24)==(0);
        if (!($22)) {
         $$0 = $21;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       __THREW__ = 0;
       $23 = (invoke_iii(788,(0|0),($cp|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        $26 = (($__this) + 44|0);
        $27 = HEAP32[$26>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($27|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if (!($29)) {
         $30 = (($27) + 12|0);
         $31 = HEAP32[$30>>2]|0;
         $32 = ($31|0)==(0);
         if ($32) {
          $$0 = $23;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         } else {
          $V_2$0 = 0;
         }
         while(1) {
          $99 = HEAP32[$26>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($99|0));
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           label = 6;
           break;
          }
          $102 = (($99) + 12|0);
          $103 = HEAP32[$102>>2]|0;
          $104 = ($V_2$0|0)<($103|0);
          if (!($104)) {
           $$0 = $23;
           label = 36;
           break;
          }
          $34 = HEAP32[$26>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($34|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           label = 6;
           break;
          }
          $33 = (($34) + 12|0);
          $35 = HEAP32[$33>>2]|0;
          $36 = ($V_2$0>>>0)<($35>>>0);
          if (!($36)) {
           __THREW__ = 0;
           $37 = (invoke_i(132)|0);
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if ($39) {
            label = 6;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($37|0));
           $40 = __THREW__; __THREW__ = 0;
           $41 = $40&1;
           if ($41) {
            label = 6;
            break;
           }
          }
          $42 = HEAP32[$34>>2]|0;
          $43 = (($34) + 16|0);
          $44 = (($42) + 92|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = Math_imul($45, $V_2$0)|0;
          $47 = (($43) + ($46)|0);
          $48 = HEAP32[$47>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($48|0));
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           label = 6;
           break;
          }
          $51 = (($48) + 8|0);
          $52 = HEAP8[$51>>0]|0;
          $53 = ($52<<24>>24)==($23<<24>>24);
          $54 = HEAP32[$26>>2]|0;
          if ($53) {
           label = 21;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($54|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           label = 6;
           break;
          }
          $78 = (($54) + 12|0);
          $79 = HEAP32[$78>>2]|0;
          $80 = ($V_2$0>>>0)<($79>>>0);
          if (!($80)) {
           __THREW__ = 0;
           $81 = (invoke_i(132)|0);
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if ($83) {
            label = 6;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($81|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            label = 6;
            break;
           }
          }
          $86 = HEAP32[$54>>2]|0;
          $87 = (($54) + 16|0);
          $88 = (($86) + 92|0);
          $89 = HEAP32[$88>>2]|0;
          $90 = Math_imul($89, $V_2$0)|0;
          $91 = (($87) + ($90)|0);
          $92 = HEAP32[$91>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($92|0));
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           label = 6;
           break;
          }
          $95 = (($92) + 8|0);
          $96 = HEAP8[$95>>0]|0;
          $97 = ($96&255)>($23&255);
          $98 = (($V_2$0) + 1)|0;
          if ($97) {
           $$0 = $23;
           label = 36;
           break;
          } else {
           $V_2$0 = $98;
          }
         }
         if ((label|0) == 6) {
          $7 = ___cxa_find_matching_catch()|0;
          $8 = tempRet0;
          $lpad$phi$index = $7;$lpad$phi$index2 = $8;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 21) {
          __THREW__ = 0;
          invoke_vi(3799,($54|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           break;
          }
          $57 = (($54) + 12|0);
          $58 = HEAP32[$57>>2]|0;
          $59 = ($V_2$0>>>0)<($58>>>0);
          if (!($59)) {
           __THREW__ = 0;
           $60 = (invoke_i(132)|0);
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($60|0));
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            break;
           }
          }
          $65 = HEAP32[$54>>2]|0;
          $66 = (($54) + 16|0);
          $67 = (($65) + 92|0);
          $68 = HEAP32[$67>>2]|0;
          $69 = Math_imul($68, $V_2$0)|0;
          $70 = (($66) + ($69)|0);
          $71 = HEAP32[$70>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($71|0));
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break;
          }
          $74 = (($71) + 9|0);
          $75 = HEAP8[$74>>0]|0;
          $$0 = $75;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         else if ((label|0) == 36) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 5) {
   __THREW__ = 0;
   $4 = (invoke_iii(788,(0|0),($cp|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $$0 = $4;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $lpad$phi$index = $9;$lpad$phi$index2 = $10;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __Z63mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsHalfKanaP22mscorlib_System_Objectii($__this,$cp,$opt) {
 $__this = $__this|0;
 $cp = $cp|0;
 $opt = $opt|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274032);
 $0 = $opt & 16;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $G_B3_0$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 $2 = $cp&65535;
 __THREW__ = 0;
 $3 = (invoke_iii(794,(0|0),($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $G_B3_0$0 = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 return 0|0;
}
function __Z182mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetContraction_mscorlib_Mono_Globalization_Unicode_Contraction_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_Stringii($__this,$s,$start,$end) {
 $__this = $__this|0;
 $s = $s|0;
 $start = $start|0;
 $end = $end|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274080);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiiiii(100,0,($s|0),($start|0),($end|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if (!($5)) {
    $$0 = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = (($__this) + 36|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(127);
   if ($10) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2280704|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP8[((2280704 + 116|0))>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     __THREW__ = 0;
     (invoke_ii(2996,(2280704|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2280704|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2280704|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2280704|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[((2280704 + 80|0))>>2]|0;
     $24 = (($23) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = (($25) + 40|0);
      $29 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iiiiii(100,0,($s|0),($start|0),($end|0),($29|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $$0 = $30;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z238mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetContraction_mscorlib_Mono_Globalization_Unicode_Contraction_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_Mono_Globalization_Unicode_Contraction_arr_arrP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiP51mscorlib_Mono_Globalization_Unicode_Contraction_arr($__this,$s,$start,$end,$clist) {
 $__this = $__this|0;
 $s = $s|0;
 $start = $start|0;
 $end = $end|0;
 $clist = $clist|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $V_0$0 = 0, $V_5$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274128);
 $0 = (($clist) + 12|0);
 $1 = (($clist) + 16|0);
 $2 = (($end) - ($start))|0;
 $V_0$0 = 0;
 L1: while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($clist|0));
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if ($84) {
   label = 6;
   break;
  }
  $85 = HEAP32[$0>>2]|0;
  $86 = ($V_0$0|0)<($85|0);
  if (!($86)) {
   $$0 = 0;
   label = 34;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($clist|0));
  $87 = __THREW__; __THREW__ = 0;
  $88 = $87&1;
  if ($88) {
   label = 6;
   break;
  }
  $3 = HEAP32[$0>>2]|0;
  $4 = ($V_0$0>>>0)<($3>>>0);
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_i(132)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 6;
    break;
   }
  }
  $14 = HEAP32[$clist>>2]|0;
  $15 = (($14) + 92|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = Math_imul($16, $V_0$0)|0;
  $18 = (($1) + ($17)|0);
  $19 = HEAP32[$18>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($19|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   label = 6;
   break;
  }
  $22 = (($19) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($23|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 6;
   break;
  }
  $26 = (($23) + 12|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==(0);
  if ($28) {
   __THREW__ = 0;
   $29 = (invoke_i(132)|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($29|0));
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    label = 6;
    break;
   }
  }
  $34 = (($23) + 16|0);
  $35 = HEAP16[$34>>1]|0;
  __THREW__ = 0;
  invoke_vi(3799,($s|0));
  $36 = __THREW__; __THREW__ = 0;
  $37 = $36&1;
  if ($37) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  $38 = (invoke_iii(621,($s|0),($start|0))|0);
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if ($40) {
   label = 6;
   break;
  }
  $41 = $35&65535;
  $42 = $38&65535;
  $43 = (($41) - ($42))|0;
  $44 = ($43|0)<(1);
  if (!($44)) {
   $$0 = 0;
   label = 34;
   break;
  }
  $45 = ($43|0)>(-1);
  if ($45) {
   __THREW__ = 0;
   invoke_vi(3799,($19|0));
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    label = 6;
    break;
   }
   $48 = HEAP32[$22>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($48|0));
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if ($50) {
    label = 6;
    break;
   }
   $51 = (($48) + 12|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($2|0)<($52|0);
   if (!($53)) {
    $54 = (($48) + 16|0);
    $V_5$0 = 0;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($48|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      label = 5;
      break L1;
     }
     $78 = HEAP32[$51>>2]|0;
     $79 = ($V_5$0|0)<($78|0);
     if (!($79)) {
      $$0 = $19;
      label = 34;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3799,($s|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      label = 5;
      break L1;
     }
     $55 = (($V_5$0) + ($start))|0;
     __THREW__ = 0;
     $56 = (invoke_iii(621,($s|0),($55|0))|0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      label = 5;
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3799,($48|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      label = 5;
      break L1;
     }
     $61 = HEAP32[$51>>2]|0;
     $62 = ($V_5$0>>>0)<($61>>>0);
     if (!($62)) {
      __THREW__ = 0;
      $63 = (invoke_i(132)|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 5;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 5;
       break L1;
      }
     }
     $68 = HEAP32[$48>>2]|0;
     $69 = (($68) + 92|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = Math_imul($70, $V_5$0)|0;
     $72 = (($54) + ($71)|0);
     $73 = HEAP16[$72>>1]|0;
     $74 = ($56<<16>>16)==($73<<16>>16);
     $75 = (($V_5$0) + 1)|0;
     if ($74) {
      $V_5$0 = $75;
     } else {
      break;
     }
    }
   }
  }
  $82 = (($V_0$0) + 1)|0;
  $V_0$0 = $82;
 }
 if ((label|0) == 5) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 6) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  $lpad$phi$index = $12;$lpad$phi$index2 = $13;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 34) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z186mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetTailContraction_mscorlib_Mono_Globalization_Unicode_Contraction_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_Stringii($__this,$s,$start,$end) {
 $__this = $__this|0;
 $s = $s|0;
 $start = $start|0;
 $end = $end|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274176);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiiiii(101,0,($s|0),($start|0),($end|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if (!($5)) {
    $$0 = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = (($__this) + 36|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(127);
   if ($10) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2280704|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP8[((2280704 + 116|0))>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     __THREW__ = 0;
     (invoke_ii(2996,(2280704|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2280704|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2280704|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2280704|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[((2280704 + 80|0))>>2]|0;
     $24 = (($23) + 4|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = (($25) + 40|0);
      $29 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iiiiii(101,0,($s|0),($start|0),($end|0),($29|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $$0 = $30;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z242mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetTailContraction_mscorlib_Mono_Globalization_Unicode_Contraction_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_Mono_Globalization_Unicode_Contraction_arr_arrP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiP51mscorlib_Mono_Globalization_Unicode_Contraction_arr($__this,$s,$start,$end,$clist) {
 $__this = $__this|0;
 $s = $s|0;
 $start = $start|0;
 $end = $end|0;
 $clist = $clist|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_5 = 0, $L_7 = 0, $V_0$0 = 0, $V_4$0 = 0;
 var $V_5$0 = 0, $V_5$0$in = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_5 = sp;
 $L_7 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274224);
 __THREW__ = 0;
 invoke_v(526);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($start|0)==($end|0);
   $3 = ($end|0)<(-1);
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(1816,($s|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    $15 = ($12|0)>($start|0);
    if ($15) {
     __THREW__ = 0;
     invoke_vi(3799,($s|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     $18 = (invoke_ii(1816,($s|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     $21 = (($end) + 1)|0;
     $22 = ($18|0)>($21|0);
     if ($22) {
      $23 = (($clist) + 12|0);
      $24 = (($clist) + 16|0);
      $25 = (($start) - ($end))|0;
      $V_0$0 = 0;
      L11: while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($clist|0));
       $129 = __THREW__; __THREW__ = 0;
       $130 = $129&1;
       if ($130) {
        label = 4;
        break;
       }
       $131 = HEAP32[$23>>2]|0;
       $132 = ($V_0$0|0)<($131|0);
       if (!($132)) {
        $$0 = 0;
        label = 54;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($clist|0));
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       if ($134) {
        label = 4;
        break;
       }
       $49 = HEAP32[$23>>2]|0;
       $50 = ($V_0$0>>>0)<($49>>>0);
       if (!($50)) {
        __THREW__ = 0;
        $51 = (invoke_i(132)|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($51|0));
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 4;
         break;
        }
       }
       $56 = HEAP32[$clist>>2]|0;
       $57 = (($56) + 92|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = Math_imul($58, $V_0$0)|0;
       $60 = (($24) + ($59)|0);
       $61 = HEAP32[$60>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($61|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        label = 4;
        break;
       }
       $64 = (($61) + 8|0);
       $65 = HEAP32[$64>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($65|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        label = 4;
        break;
       }
       $68 = (($65) + 12|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ($69|0)>($25|0);
       do {
        if (!($70)) {
         __THREW__ = 0;
         invoke_vi(3799,($65|0));
         $71 = __THREW__; __THREW__ = 0;
         $72 = $71&1;
         if ($72) {
          label = 4;
          break L11;
         }
         $73 = HEAP32[$68>>2]|0;
         $74 = (($73) + -1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($65|0));
         $75 = __THREW__; __THREW__ = 0;
         $76 = $75&1;
         if ($76) {
          label = 4;
          break L11;
         }
         $77 = ($73|0)<(1);
         if ($77) {
          label = 34;
         } else {
          $78 = HEAP32[$68>>2]|0;
          $79 = ($74>>>0)<($78>>>0);
          if (!($79)) {
           label = 34;
          }
         }
         if ((label|0) == 34) {
          label = 0;
          __THREW__ = 0;
          $80 = (invoke_i(132)|0);
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           label = 4;
           break L11;
          }
          __THREW__ = 0;
          invoke_vi(3302,($80|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           label = 4;
           break L11;
          }
         }
         $85 = HEAP32[$65>>2]|0;
         $86 = (($65) + 16|0);
         $87 = (($85) + 92|0);
         $88 = HEAP32[$87>>2]|0;
         $89 = Math_imul($88, $74)|0;
         $90 = (($86) + ($89)|0);
         $91 = HEAP16[$90>>1]|0;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          label = 4;
          break L11;
         }
         __THREW__ = 0;
         $94 = (invoke_iii(621,($s|0),($start|0))|0);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          label = 4;
          break L11;
         }
         $97 = ($91<<16>>16)==($94<<16>>16);
         if (!($97)) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($65|0));
         $98 = __THREW__; __THREW__ = 0;
         $99 = $98&1;
         if ($99) {
          label = 4;
          break L11;
         }
         $100 = HEAP32[$68>>2]|0;
         $101 = (($start) - ($100))|0;
         $V_4$0 = 0;$V_5$0$in = $101;
         while(1) {
          $V_5$0 = (($V_5$0$in) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($65|0));
          $122 = __THREW__; __THREW__ = 0;
          $123 = $122&1;
          if ($123) {
           label = 3;
           break L11;
          }
          $124 = HEAP32[$68>>2]|0;
          $125 = ($V_4$0|0)<($124|0);
          if (!($125)) {
           $$0 = $61;
           label = 54;
           break L11;
          }
          __THREW__ = 0;
          invoke_vi(3799,($s|0));
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           label = 3;
           break L11;
          }
          __THREW__ = 0;
          $102 = (invoke_iii(621,($s|0),($V_5$0|0))|0);
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           label = 3;
           break L11;
          }
          __THREW__ = 0;
          invoke_vi(3799,($65|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           label = 3;
           break L11;
          }
          $107 = HEAP32[$68>>2]|0;
          $108 = ($V_4$0>>>0)<($107>>>0);
          if (!($108)) {
           __THREW__ = 0;
           $109 = (invoke_i(132)|0);
           $110 = __THREW__; __THREW__ = 0;
           $111 = $110&1;
           if ($111) {
            label = 3;
            break L11;
           }
           __THREW__ = 0;
           invoke_vi(3302,($109|0));
           $112 = __THREW__; __THREW__ = 0;
           $113 = $112&1;
           if ($113) {
            label = 3;
            break L11;
           }
          }
          $114 = HEAP32[$65>>2]|0;
          $115 = (($114) + 92|0);
          $116 = HEAP32[$115>>2]|0;
          $117 = Math_imul($116, $V_4$0)|0;
          $118 = (($86) + ($117)|0);
          $119 = HEAP16[$118>>1]|0;
          $120 = ($102<<16>>16)==($119<<16>>16);
          $121 = (($V_4$0) + 1)|0;
          if ($120) {
           $V_4$0 = $121;$V_5$0$in = $V_5$0;
          } else {
           break;
          }
         }
        }
       } while(0);
       $128 = (($V_0$0) + 1)|0;
       $V_0$0 = $128;
      }
      if ((label|0) == 3) {
       $4 = ___cxa_find_matching_catch()|0;
       $5 = tempRet0;
       $lpad$phi$index = $4;$lpad$phi$index3 = $5;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 4) {
       $6 = ___cxa_find_matching_catch()|0;
       $7 = tempRet0;
       $lpad$phi$index = $6;$lpad$phi$index3 = $7;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 54) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
   HEAP32[$L_5>>2] = $start;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_iii(2724,(2155952|0),($L_5|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     HEAP32[$L_7>>2] = $end;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      $33 = (invoke_iii(2724,(2155952|0),($L_7|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       $36 = HEAP32[3019776>>2]|0;
       __THREW__ = 0;
       $37 = (invoke_iiiiii(87,(0|0),($36|0),($28|0),($33|0),($s|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2649224|0))|0);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if (!($41)) {
         __THREW__ = 0;
         $42 = (invoke_ii(3469,(2649224|0))|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if (!($44)) {
          __THREW__ = 0;
          invoke_vii(1975,($42|0),($37|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if (!($46)) {
           __THREW__ = 0;
           invoke_vi(3833,($42|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if (!($48)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index3 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception5704($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z66mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_FilterOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorii($__this,$i,$opt) {
 $__this = $__this|0;
 $i = $i|0;
 $opt = $opt|0;
 var $$0 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $i$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274272);
 $0 = $opt & 16;
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = $i;
  label = 5;
 } else {
  __THREW__ = 0;
  $2 = (invoke_iii(792,(0|0),($i|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   $i$ = $5 ? $i : $2;
   $$0 = $i$;
   label = 5;
  }
 }
 do {
  if ((label|0) == 5) {
   $8 = $opt & 268435456;
   $9 = ($8|0)==(0);
   if ($9) {
    $$1 = $$0;
   } else {
    $10 = (($__this) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = $$0&65535;
    __THREW__ = 0;
    $15 = (invoke_iiii(1667,(2274320|0),($11|0),($14|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = $15&65535;
    $$1 = $18;
   }
   $19 = $opt & 1;
   $20 = ($19|0)==(0);
   if ($20) {
    $$2 = $$1;
   } else {
    $21 = (($__this) + 8|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = $$1&65535;
    __THREW__ = 0;
    $26 = (invoke_iiii(1667,(2274320|0),($22|0),($25|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = $26&65535;
    $$2 = $29;
   }
   $30 = $opt & 8;
   $31 = ($30|0)==(0);
   if ($31) {
    $$3 = $$2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$3|0);
   }
   __THREW__ = 0;
   $32 = (invoke_iii(791,(0|0),($$2|0))|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    $$3 = $32;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$3|0);
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetExtenderTypeP50mscorlib_Mono_Globalization_Unicode_SimpleCollatori($__this,$i) {
 $__this = $__this|0;
 $i = $i|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, $i$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274368);
 $0 = ($i|0)==(8213);
 L1: do {
  if ($0) {
   $1 = (($__this) + 36|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = ($2|0)==(16);
   $$ = $3 ? 3 : 0;
   $$0 = $$;
  } else {
   $i$off = (($i) + -12293)|0;
   $4 = ($i$off>>>0)<(53100);
   if ($4) {
    $5 = ($i|0)<(65148);
    if (!($5)) {
     if ((($i|0) == 65392)) {
      $$0 = 3;
      break;
     } else if ((($i|0) == 65149) | (($i|0) == 65148)) {
      $$0 = 1;
      break;
     } else {
      $$0 = 0;
      break;
     }
    }
    $6 = ($i|0)<(12543);
    if ($6) {
     L12: do {
      if ((($i|0) == 12542)) {
       label = 12;
      } else if ((($i|0) == 12540)) {
       $$0 = 3;
       break L1;
      } else if ((($i|0) == 12541)) {
       label = 11;
      } else {
       switch ($i|0) {
       case 12446:  {
        label = 12;
        break L12;
        break;
       }
       case 12293:  {
        $$0 = 4;
        break L1;
        break;
       }
       case 12445: case 12338: case 12337:  {
        label = 11;
        break L12;
        break;
       }
       default: {
       }
       }
       $$0 = 0;
       break L1;
      }
     } while(0);
     if ((label|0) == 11) {
      $$0 = 1;
      break;
     }
     else if ((label|0) == 12) {
      $$0 = 2;
      break;
     }
    } else {
     $$0 = 0;
    }
   } else {
    $$0 = 0;
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_ToDashTypeValueP22mscorlib_System_Objectii($__this,$ext,$opt) {
 $__this = $__this|0;
 $ext = $ext|0;
 $opt = $opt|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, $ext$off = 0, $or$cond = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274416);
 $0 = $opt & 2;
 $1 = ($0|0)!=(0);
 $2 = ($ext|0)==(0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  $$0 = 3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $ext$off = (($ext) + -1)|0;
 $or$cond$not = ($ext$off>>>0)>(1);
 $3 = ($ext|0)==(3);
 $or$cond3 = $or$cond$not & $3;
 $$ = $or$cond3 ? 5 : 4;
 $$0 = $$;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_FilterExtenderP50mscorlib_Mono_Globalization_Unicode_SimpleCollatoriii($__this,$i,$ext,$opt) {
 $__this = $__this|0;
 $i = $i|0;
 $ext = $ext|0;
 $opt = $opt|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274464);
 $0 = ($ext|0)==(3);
 L1: do {
  if ($0) {
   $1 = $i&65535;
   __THREW__ = 0;
   $2 = (invoke_iii(793,(0|0),($1|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if (!($2)) {
     $$0 = $i;
     break;
    }
    $7 = $i & 65535;
    __THREW__ = 0;
    $8 = (invoke_iiii(742,0,($7|0),($opt|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iii(795,(0|0),($1|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      $14 = (invoke_iii(800,($__this|0),($i|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = $14&255;
       $18 = $17 & 7;
       switch ($18|0) {
       case 2:  {
        if ($8) {
         $$0 = 65393;
         break L1;
        }
        $$ = $11 ? 12354 : 12450;
        $$0 = $$;
        break L1;
        break;
       }
       case 5:  {
        if ($8) {
         $$0 = 65396;
         break L1;
        }
        $$3 = $11 ? 12360 : 12456;
        $$0 = $$3;
        break L1;
        break;
       }
       case 6:  {
        if ($8) {
         $$0 = 65397;
         break L1;
        }
        $$4 = $11 ? 12362 : 12458;
        $$0 = $$4;
        break L1;
        break;
       }
       case 4:  {
        if ($8) {
         $$0 = 65395;
         break L1;
        }
        $$2 = $11 ? 12358 : 12454;
        $$0 = $$2;
        break L1;
        break;
       }
       case 3:  {
        if ($8) {
         $$0 = 65394;
         break L1;
        }
        $$1 = $11 ? 12356 : 12452;
        $$0 = $$1;
        break L1;
        break;
       }
       default: {
        $$0 = $i;
        break L1;
       }
       }
      }
     }
    }
   }
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  } else {
   $$0 = $i;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z64mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsIgnorableP22mscorlib_System_Objectii($__this,$i,$opt) {
 $__this = $__this|0;
 $i = $i|0;
 $opt = $opt|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274512);
 $0 = $opt >>> 1;
 $1 = $0 & 2;
 $2 = $opt << 1;
 $3 = $2 & 4;
 $4 = $3 | $1;
 $5 = $4 | 1;
 $6 = $5&255;
 __THREW__ = 0;
 $7 = (invoke_iiii(735,(0|0),($i|0),($6|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($7|0);
 }
 return 0|0;
}
function __Z59mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsSafeP50mscorlib_Mono_Globalization_Unicode_SimpleCollatori($__this,$i) {
 $__this = $__this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274560);
 $0 = (($i|0) / 8)&-1;
 $1 = (($__this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = (($2) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($0|0)<($6|0);
   if (!($7)) {
    $G_B3_0$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
   $10 = HEAP32[$1>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = ($i|0)<(-7);
    if ($13) {
     label = 7;
    } else {
     $14 = (($10) + 12|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($0>>>0)<($15>>>0);
     if (!($16)) {
      label = 7;
     }
    }
    if ((label|0) == 7) {
     __THREW__ = 0;
     $17 = (invoke_i(132)|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($17|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
    }
    $22 = HEAP32[$10>>2]|0;
    $23 = (($10) + 16|0);
    $24 = (($22) + 92|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = Math_imul($25, $0)|0;
    $27 = (($23) + ($26)|0);
    $28 = HEAP8[$27>>0]|0;
    $29 = (($i|0) % 8)&-1;
    $30 = $29 & 31;
    $31 = 1 << $30;
    $32 = $28&255;
    $33 = $31 & $32;
    $34 = ($33|0)==(0);
    $G_B3_0$0 = $34;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z169mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetSortKey_mscorlib_System_Globalization_SortKey_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_Stringi($__this,$s,$options) {
 $__this = $__this|0;
 $s = $s|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274608);
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($s|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiiiii(102,($__this|0),($s|0),0,($2|0),($options|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z213mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetSortKey_mscorlib_System_Globalization_SortKey_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_Stringiii($__this,$s,$start,$length,$options) {
 $__this = $__this|0;
 $s = $s|0;
 $start = $start|0;
 $length = $length|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274656);
 $0 = (($__this) + 36|0);
 __THREW__ = 0;
 (invoke_ii(2996,(2283864|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3469,(2283864|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1797,($3|0),0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = HEAP32[$0>>2]|0;
    $9 = (($__this) + 12|0);
    $10 = HEAP8[$9>>0]|0;
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = ($10<<24>>24)!=(0);
     __THREW__ = 0;
     invoke_viiiii(59,($3|0),($options|0),($8|0),($s|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = (($length) + ($start))|0;
      __THREW__ = 0;
      invoke_viiiiii(60,($__this|0),($s|0),($start|0),($16|0),($3|0),($options|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       invoke_vi(3799,($3|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        $21 = (invoke_ii(1930,($3|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($21|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($24|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m__ctorP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferi($__this,$lcid) {
 $__this = $__this|0;
 $lcid = $lcid|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2281944);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_InitializeP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferiiP22mscorlib_System_Stringb($__this,$options,$lcid,$s,$frenchSort) {
 $__this = $__this|0;
 $options = $options|0;
 $lcid = $lcid|0;
 $s = $s|0;
 $frenchSort = $frenchSort|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282040);
 $0 = (($__this) + 72|0);
 HEAP32[$0>>2] = $s;
 $1 = (($__this) + 80|0);
 HEAP32[$1>>2] = $lcid;
 $2 = (($__this) + 84|0);
 HEAP32[$2>>2] = $options;
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(1816,($s|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($__this) + 76|0);
    $9 = $options >>> 1;
    $$lobit = $9 & 1;
    $10 = $$lobit ^ 1;
    $11 = $10&255;
    HEAP8[$8>>0] = $11;
    $12 = (($__this) + 77|0);
    $13 = $frenchSort&1;
    HEAP8[$12>>0] = $13;
    $14 = (($__this) + 40|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     label = 7;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($15|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     $21 = (($15) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)<($5|0);
     if ($23) {
      label = 7;
     }
    }
    if ((label|0) == 7) {
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     $26 = $5 << 1;
     $27 = (($26) + 10)|0;
     __THREW__ = 0;
     $28 = (invoke_iii(2758,(1203320|0),($27|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     HEAP32[$14>>2] = $28;
    }
    $31 = HEAP8[$8>>0]|0;
    $32 = ($31<<24>>24)==(0);
    do {
     if (!($32)) {
      $33 = (($__this) + 44|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)==(0|0);
      if (!($35)) {
       __THREW__ = 0;
       invoke_vi(3799,($34|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break L1;
       }
       $38 = (($34) + 12|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = ($39|0)<($5|0);
       if (!($40)) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1203320|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break L1;
      }
      $43 = (($5) + 10)|0;
      __THREW__ = 0;
      $44 = (invoke_iii(2758,(1203320|0),($43|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break L1;
      }
      HEAP32[$33>>2] = $44;
     }
    } while(0);
    $47 = (($__this) + 48|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(0|0);
    if ($49) {
     label = 20;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($48|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = (($48) + 12|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)<($5|0);
     if ($54) {
      label = 20;
     }
    }
    if ((label|0) == 20) {
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     $57 = (($5) + 10)|0;
     __THREW__ = 0;
     $58 = (invoke_iii(2758,(1203320|0),($57|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     HEAP32[$47>>2] = $58;
    }
    $61 = (($__this) + 52|0);
    $62 = HEAP32[$61>>2]|0;
    $63 = ($62|0)==(0|0);
    if ($63) {
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     __THREW__ = 0;
     $66 = (invoke_iii(2758,(1203320|0),10)|0);
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     HEAP32[$61>>2] = $66;
    }
    $69 = (($__this) + 56|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($70|0)==(0|0);
    if ($71) {
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      break;
     }
     __THREW__ = 0;
     $74 = (invoke_iii(2758,(1203320|0),10)|0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      break;
     }
     HEAP32[$69>>2] = $74;
    }
    $77 = (($__this) + 60|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ($78|0)==(0|0);
    if ($79) {
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     __THREW__ = 0;
     $82 = (invoke_iii(2758,(1203320|0),10)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      break;
     }
     HEAP32[$77>>2] = $82;
    }
    $85 = (($__this) + 64|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = ($86|0)==(0|0);
    if ($87) {
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      break;
     }
     __THREW__ = 0;
     $90 = (invoke_iii(2758,(1203320|0),10)|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      break;
     }
     HEAP32[$85>>2] = $90;
    }
    $93 = (($__this) + 68|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(0|0);
    if (!($95)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1203320|0))|0);
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if (!($97)) {
     __THREW__ = 0;
     $98 = (invoke_iii(2758,(1203320|0),10)|0);
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if (!($100)) {
      HEAP32[$93>>2] = $98;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z246mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetSortKey_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferi($__this,$s,$start,$end,$buf,$opt) {
 $__this = $__this|0;
 $s = $s|0;
 $start = $start|0;
 $end = $end|0;
 $buf = $buf|0;
 $opt = $opt|0;
 var $$sink = 0, $$sink1 = 0, $$sink2 = 0, $$sink3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1 = 0, $V_2$0 = 0, $V_2$17 = 0, $V_8$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274704);
 ;HEAP32[$V_1+0>>2]=HEAP32[2275808+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2275808+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2275808+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2275808+12>>2]|0;HEAP32[$V_1+16>>2]=HEAP32[2275808+16>>2]|0;HEAP32[$V_1+20>>2]=HEAP32[2275808+20>>2]|0;HEAP32[$V_1+24>>2]=HEAP32[2275808+24>>2]|0;HEAP32[$V_1+28>>2]=HEAP32[2275808+28>>2]|0;
 $0 = sp + 36|0;
 __THREW__ = 0;
 invoke_viii(554,0,($0|0),4);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viiiiiiii(13,($V_1|0),($opt|0),(0|0),(0|0),(0|0),(0|0),($0|0),0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($start|0)<($end|0);
   if (!($5)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $6 = (($V_1) + 20|0);
   $7 = (($V_1) + 24|0);
   $V_2$17 = $start;
   L7: while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $146 = __THREW__; __THREW__ = 0;
    $147 = $146&1;
    if ($147) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    $14 = (invoke_iii(621,($s|0),($V_2$17|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     label = 6;
     break;
    }
    $17 = $14&65535;
    __THREW__ = 0;
    $18 = (invoke_iii(802,($__this|0),($17|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 6;
     break;
    }
    $21 = ($18|0)==(0);
    do {
     if ($21) {
      __THREW__ = 0;
      $50 = (invoke_iiii(746,0,($17|0),($opt|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 6;
       break L7;
      }
      if ($50) {
       $V_2$0 = $V_2$17;
      } else {
       __THREW__ = 0;
       $53 = (invoke_iiii(743,($__this|0),($17|0),($opt|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 6;
        break L7;
       }
       __THREW__ = 0;
       $56 = (invoke_iiiii(122,($__this|0),($s|0),($V_2$17|0),($end|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 6;
        break L7;
       }
       $59 = ($56|0)==(0|0);
       if ($59) {
        __THREW__ = 0;
        $139 = (invoke_iii(790,(0|0),($53|0))|0);
        $140 = __THREW__; __THREW__ = 0;
        $141 = $140&1;
        if ($141) {
         label = 6;
         break L7;
        }
        if (!($139)) {
         HEAP32[$6>>2] = $53;
        }
        __THREW__ = 0;
        invoke_viiiii(58,($__this|0),($53|0),0,($buf|0),($opt|0));
        $142 = __THREW__; __THREW__ = 0;
        $143 = $142&1;
        if ($143) {
         label = 6;
         break L7;
        } else {
         $V_2$0 = $V_2$17;
         break;
        }
       }
       __THREW__ = 0;
       invoke_vi(3799,($56|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 6;
        break L7;
       }
       $62 = (($56) + 12|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = ($63|0)==(0|0);
       if ($64) {
        $78 = HEAP32[$7>>2]|0;
        $79 = (($56) + 16|0);
        $V_8$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($56|0));
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          label = 5;
          break L7;
         }
         $102 = HEAP32[$79>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($102|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          label = 5;
          break L7;
         }
         $105 = (($102) + 12|0);
         $106 = HEAP32[$105>>2]|0;
         $107 = ($V_8$0|0)<($106|0);
         if (!($107)) {
          break;
         }
         $98 = (($78) + ($V_8$0)|0);
         __THREW__ = 0;
         invoke_vi(3799,($56|0));
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          label = 5;
          break L7;
         }
         $80 = HEAP32[$79>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($80|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          label = 5;
          break L7;
         }
         $83 = (($80) + 12|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = ($V_8$0>>>0)<($84>>>0);
         if (!($85)) {
          __THREW__ = 0;
          $86 = (invoke_i(132)|0);
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           label = 5;
           break L7;
          }
          __THREW__ = 0;
          invoke_vi(3302,($86|0));
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           label = 5;
           break L7;
          }
         }
         $91 = HEAP32[$80>>2]|0;
         $92 = (($80) + 16|0);
         $93 = (($91) + 92|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = Math_imul($94, $V_8$0)|0;
         $96 = (($92) + ($95)|0);
         $97 = HEAP8[$96>>0]|0;
         HEAP8[$98>>0] = $97;
         $99 = (($V_8$0) + 1)|0;
         $V_8$0 = $99;
        }
        $110 = HEAP8[$78>>0]|0;
        $111 = (($78) + 1|0);
        $112 = HEAP8[$111>>0]|0;
        $113 = (($78) + 2|0);
        $114 = HEAP8[$113>>0]|0;
        $115 = ($114<<24>>24)==(1);
        if ($115) {
         __THREW__ = 0;
         $116 = (invoke_iiii(740,($__this|0),($53|0),0)|0);
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          label = 6;
          break L7;
         } else {
          $$sink2 = $116;
         }
        } else {
         $$sink2 = $114;
        }
        $119 = (($78) + 3|0);
        $120 = HEAP8[$119>>0]|0;
        $121 = ($120<<24>>24)==(1);
        if ($121) {
         __THREW__ = 0;
         $122 = (invoke_iii(789,(0|0),($53|0))|0);
         $123 = __THREW__; __THREW__ = 0;
         $124 = $123&1;
         if ($124) {
          label = 6;
          break L7;
         } else {
          $$sink3 = $122;
         }
        } else {
         $$sink3 = $120;
        }
        __THREW__ = 0;
        invoke_vi(3799,($buf|0));
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         label = 6;
         break L7;
        }
        __THREW__ = 0;
        invoke_viiiii(60,($buf|0),($110|0),($112|0),($$sink2|0),($$sink3|0));
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if ($128) {
         label = 6;
         break L7;
        }
        HEAP32[$6>>2] = -1;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($56|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 6;
         break L7;
        }
        $67 = HEAP32[$62>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($56|0));
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         label = 6;
         break L7;
        }
        $70 = HEAP32[$62>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($70|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 6;
         break L7;
        }
        __THREW__ = 0;
        $73 = (invoke_ii(1816,($70|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 6;
         break L7;
        }
        __THREW__ = 0;
        invoke_viiiiii(60,($__this|0),($67|0),0,($73|0),($buf|0),($opt|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 6;
         break L7;
        }
       }
       __THREW__ = 0;
       invoke_vi(3799,($56|0));
       $129 = __THREW__; __THREW__ = 0;
       $130 = $129&1;
       if ($130) {
        label = 6;
        break L7;
       }
       $131 = (($56) + 8|0);
       $132 = HEAP32[$131>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($132|0));
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       if ($134) {
        label = 6;
        break L7;
       }
       $135 = (($132) + 12|0);
       $136 = HEAP32[$135>>2]|0;
       $137 = (($V_2$17) + -1)|0;
       $138 = (($137) + ($136))|0;
       $V_2$0 = $138;
      }
     } else {
      $22 = HEAP32[$6>>2]|0;
      __THREW__ = 0;
      $23 = (invoke_iiiii(124,($__this|0),($22|0),($18|0),($opt|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       label = 6;
       break L7;
      }
      $26 = ($23|0)<(0);
      if (!($26)) {
       __THREW__ = 0;
       invoke_viiiii(58,($__this|0),($23|0),($18|0),($buf|0),($opt|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        label = 6;
        break L7;
       } else {
        $V_2$0 = $V_2$17;
        break;
       }
      }
      $29 = HEAP32[$7>>2]|0;
      $30 = ($29|0)==(0|0);
      if ($30) {
       $V_2$0 = $V_2$17;
      } else {
       $31 = HEAP8[$29>>0]|0;
       $32 = (($29) + 1|0);
       $33 = HEAP8[$32>>0]|0;
       $34 = (($29) + 2|0);
       $35 = HEAP8[$34>>0]|0;
       $36 = ($35<<24>>24)==(1);
       if ($36) {
        __THREW__ = 0;
        $37 = (invoke_iiii(740,($__this|0),($23|0),($18|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         label = 6;
         break L7;
        } else {
         $$sink = $37;
        }
       } else {
        $$sink = $35;
       }
       $40 = (($29) + 3|0);
       $41 = HEAP8[$40>>0]|0;
       $42 = ($41<<24>>24)==(1);
       if ($42) {
        __THREW__ = 0;
        $43 = (invoke_iii(789,(0|0),($23|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         label = 6;
         break L7;
        } else {
         $$sink1 = $43;
        }
       } else {
        $$sink1 = $41;
       }
       __THREW__ = 0;
       invoke_vi(3799,($buf|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        label = 6;
        break L7;
       }
       __THREW__ = 0;
       invoke_viiiii(60,($buf|0),($31|0),($33|0),($$sink|0),($$sink1|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        label = 6;
        break L7;
       } else {
        $V_2$0 = $V_2$17;
       }
      }
     }
    } while(0);
    $144 = (($V_2$0) + 1)|0;
    $145 = ($144|0)<($end|0);
    if ($145) {
     $V_2$17 = $144;
    } else {
     label = 60;
     break;
    }
   }
   if ((label|0) == 5) {
    $8 = ___cxa_find_matching_catch()|0;
    $9 = tempRet0;
    $lpad$phi$index = $8;$lpad$phi$index3 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 6) {
    $10 = ___cxa_find_matching_catch()|0;
    $11 = tempRet0;
    $lpad$phi$index = $10;$lpad$phi$index3 = $11;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 60) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index3 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z69mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_GetResultAndResetP49mscorlib_Mono_Globalization_Unicode_SortKeyBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282328);
 __THREW__ = 0;
 $0 = (invoke_ii(1931,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(2138,($__this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_ClearBufferP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorPhi($__this,$buffer,$size) {
 $__this = $__this|0;
 $buffer = $buffer|0;
 $size = $size|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275040);
 $0 = ($size|0)>(0);
 if ($0) {
  _memset(($buffer|0),0,($size|0))|0;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_FillSortKeyRawP50mscorlib_Mono_Globalization_Unicode_SimpleCollatoriiP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferi($__this,$i,$ext,$buf,$opt) {
 $__this = $__this|0;
 $i = $i|0;
 $ext = $ext|0;
 $buf = $buf|0;
 $opt = $opt|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $9 = 0, $_stackTraceSentry = 0, $i$off = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274752);
 $i$off = (($i) + -13312)|0;
 $0 = ($i$off>>>0)>(6581);
 do {
  if ($0) {
   $13 = $i&65535;
   __THREW__ = 0;
   $14 = (invoke_iii(599,(0|0),($13|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    if ((($14|0) == 16)) {
     __THREW__ = 0;
     invoke_viii(553,0,($i|0),($buf|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    } else if ((($14|0) == 17)) {
     $17 = (($i) + -57344)|0;
     __THREW__ = 0;
     invoke_vi(3799,($buf|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = (($17|0) % 254)&-1;
     $21 = (($17|0) / 254)&-1;
     $22 = (($20) + 2)|0;
     $23 = (($21) + 229)|0;
     $24 = $22&255;
     $25 = $23&255;
     __THREW__ = 0;
     invoke_viiiii(60,($buf|0),($25|0),($24|0),0,0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    } else {
     __THREW__ = 0;
     $30 = (invoke_iiii(740,($__this|0),($i|0),($ext|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     __THREW__ = 0;
     $33 = (invoke_iii(793,(0|0),($13|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     if (!($33)) {
      __THREW__ = 0;
      $70 = (invoke_iii(799,($__this|0),($i|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iii(800,($__this|0),($i|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       break;
      }
      __THREW__ = 0;
      $76 = (invoke_iii(789,(0|0),($i|0))|0);
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($buf|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       break;
      }
      __THREW__ = 0;
      invoke_viiiii(60,($buf|0),($70|0),($73|0),($30|0),($76|0));
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     $36 = (invoke_iii(800,($__this|0),($i|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     __THREW__ = 0;
     $39 = (invoke_iii(799,($__this|0),($i|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     __THREW__ = 0;
     $42 = (invoke_iii(789,(0|0),($i|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     $45 = (invoke_iii(796,(0|0),($13|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     __THREW__ = 0;
     $48 = (invoke_iiii(745,0,($ext|0),($opt|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     __THREW__ = 0;
     $51 = (invoke_iii(795,(0|0),($13|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     $54 = $51 ^ 1;
     $55 = $i & 65535;
     __THREW__ = 0;
     $56 = (invoke_iiii(742,0,($55|0),($opt|0))|0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($buf|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     __THREW__ = 0;
     invoke_viiiiiiiii(6,($buf|0),($39|0),($36|0),($30|0),($42|0),($45|0),($48|0),($54|0),($56|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      break;
     }
     $63 = $opt & 2;
     $64 = ($63|0)==(0);
     $65 = ($ext|0)==(2);
     $or$cond1 = $64 & $65;
     if (!($or$cond1)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3799,($buf|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     __THREW__ = 0;
     invoke_viiiii(60,($buf|0),1,1,1,0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($buf|0));
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = (($i$off|0) % 254)&-1;
    $4 = (($i$off|0) / 254)&-1;
    $5 = (($3) + 2)|0;
    $6 = (($4) + 16)|0;
    $7 = $5&255;
    $8 = $6&255;
    __THREW__ = 0;
    invoke_viii(555,($buf|0),($8|0),($7|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z64mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendNormalP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhhhh($__this,$category,$lv1,$lv2,$lv3) {
 $__this = $__this|0;
 $category = $category|0;
 $lv1 = $lv1|0;
 $lv2 = $lv2|0;
 $lv3 = $lv3|0;
 var $$01 = 0, $$125 = 0, $$17 = 0, $$lv2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $_stackTraceSentry = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282184);
 $0 = ($lv2<<24>>24)==(0);
 $$lv2 = $0 ? 2 : $lv2;
 $1 = ($lv3<<24>>24)==(0);
 $$01 = $1 ? 2 : $lv3;
 $2 = ($category<<24>>24)==(6);
 do {
  if ($2) {
   $3 = (($__this) + 84|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = $4 & 536870912;
   $6 = ($5|0)==(0);
   if (!($6)) {
    $7 = (($__this) + 76|0);
    $94 = $7;
    label = 24;
    break;
   }
   __THREW__ = 0;
   invoke_viii(556,($__this|0),6,($lv1|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  } else {
   $12 = (($__this) + 76|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = ($13<<24>>24)!=(0);
   $15 = ($category<<24>>24)==(1);
   $or$cond = $14 & $15;
   if ($or$cond) {
    $16 = (($__this) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)<(1);
    if (!($18)) {
     $19 = (($__this) + 44|0);
     $20 = HEAP32[$19>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     $23 = (($__this) + 12|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (($24) + -1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     HEAP32[$23>>2] = $25;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = ($24|0)<(1);
     if ($30) {
      label = 13;
     } else {
      $31 = (($20) + 12|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($25>>>0)<($32>>>0);
      if (!($33)) {
       label = 13;
      }
     }
     if ((label|0) == 13) {
      __THREW__ = 0;
      $34 = (invoke_i(132)|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($34|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
     }
     $39 = HEAP32[$20>>2]|0;
     $40 = (($20) + 16|0);
     $41 = (($39) + 92|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = Math_imul($42, $25)|0;
     $44 = (($40) + ($43)|0);
     $45 = HEAP8[$44>>0]|0;
     $46 = $$lv2&255;
     $47 = $45&255;
     $48 = (($47) + ($46))|0;
     $49 = $48&255;
     $50 = (($__this) + 48|0);
     $51 = HEAP32[$50>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     $54 = (($__this) + 16|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = (($55) + -1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     HEAP32[$54>>2] = $56;
     __THREW__ = 0;
     invoke_vi(3799,($51|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     $61 = ($55|0)<(1);
     if ($61) {
      label = 20;
     } else {
      $62 = (($51) + 12|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($56>>>0)<($63>>>0);
      if (!($64)) {
       label = 20;
      }
     }
     if ((label|0) == 20) {
      __THREW__ = 0;
      $65 = (invoke_i(132)|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($65|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       break;
      }
     }
     $70 = HEAP32[$51>>2]|0;
     $71 = (($51) + 16|0);
     $72 = (($70) + 92|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = Math_imul($73, $56)|0;
     $75 = (($71) + ($74)|0);
     $76 = HEAP8[$75>>0]|0;
     $$125 = $76;$$17 = $49;$84 = $12;
     label = 26;
     break;
    }
   }
   if ($15) {
    $$125 = $$01;$$17 = $$lv2;$84 = $12;
    label = 26;
   } else {
    $94 = $12;
    label = 24;
   }
  }
 } while(0);
 if ((label|0) == 24) {
  $77 = (($__this) + 40|0);
  $78 = (($__this) + 8|0);
  __THREW__ = 0;
  invoke_viiii(148,0,($category|0),($77|0),($78|0));
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if (!($80)) {
   __THREW__ = 0;
   invoke_viiii(148,0,($lv1|0),($77|0),($78|0));
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if (!($82)) {
    $$125 = $$01;$$17 = $$lv2;$84 = $94;
    label = 26;
   }
  }
 }
 do {
  if ((label|0) == 26) {
   $83 = HEAP8[$84>>0]|0;
   $85 = ($83<<24>>24)==(0);
   if (!($85)) {
    $86 = (($__this) + 44|0);
    $87 = (($__this) + 12|0);
    __THREW__ = 0;
    invoke_viiii(148,0,($$17|0),($86|0),($87|0));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     break;
    }
   }
   $90 = (($__this) + 48|0);
   $91 = (($__this) + 16|0);
   __THREW__ = 0;
   invoke_viiii(148,0,($$125|0),($90|0),($91|0));
   $92 = __THREW__; __THREW__ = 0;
   $93 = $92&1;
   if (!($93)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z70mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendCJKExtensionP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhh($__this,$lv1msb,$lv1lsb) {
 $__this = $__this|0;
 $lv1msb = $lv1msb|0;
 $lv1lsb = $lv1lsb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282088);
 $0 = (($__this) + 40|0);
 $1 = (($__this) + 8|0);
 __THREW__ = 0;
 invoke_viiii(148,0,-2,($0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   invoke_viiii(148,0,-1,($0|0),($1|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_viiii(148,0,($lv1msb|0),($0|0),($1|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_viiii(148,0,($lv1lsb|0),($0|0),($1|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = (($__this) + 76|0);
      $11 = HEAP8[$10>>0]|0;
      $12 = ($11<<24>>24)==(0);
      if (!($12)) {
       $15 = (($__this) + 44|0);
       $16 = (($__this) + 12|0);
       __THREW__ = 0;
       invoke_viiii(148,0,2,($15|0),($16|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
      }
      $19 = (($__this) + 48|0);
      $20 = (($__this) + 16|0);
      __THREW__ = 0;
      invoke_viiii(148,0,2,($19|0),($20|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z76mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_FillSurrogateSortKeyRawP50mscorlib_Mono_Globalization_Unicode_SimpleCollatoriP49mscorlib_Mono_Globalization_Unicode_SortKeyBuffer($__this,$i,$buf) {
 $__this = $__this|0;
 $i = $i|0;
 $buf = $buf|0;
 var $$ = 0, $$2 = 0, $$3 = 0, $$4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0$0 = 0, $V_1$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $i$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274800);
 $0 = ($i|0)>(55359);
 if ($0) {
  $2 = ($i|0)>(55423);
  if ($2) {
   $i$off = (($i) + -56192)|0;
   $3 = ($i$off>>>0)>(127);
   $$2 = $3 ? 63 : 62;
   $$3 = $3 ? 65 : 254;
   $$4 = $3 ? 56074 : 56128;
   $V_0$0 = $$4;$V_1$0 = $$3;$V_2$0 = $$2;
  } else {
   $V_0$0 = 55360;$V_1$0 = 242;$V_2$0 = 62;
  }
 } else {
  $1 = ($i|0)==(55296);
  $$ = $1 ? 62 : 63;
  $V_0$0 = 55296;$V_1$0 = 65;$V_2$0 = $$;
 }
 $4 = (($i) - ($V_0$0))|0;
 __THREW__ = 0;
 invoke_vi(3799,($buf|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 }
 $7 = (($4|0) % 254)&-1;
 $8 = (($4|0) / 254)&-1;
 $9 = (($7) + 2)|0;
 $10 = (($8) + ($V_1$0))|0;
 $11 = $9&255;
 $12 = $10&255;
 __THREW__ = 0;
 invoke_viiiii(60,($buf|0),($12|0),($11|0),($V_2$0|0),($V_2$0|0));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendKanaP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhhhhbhbb($__this,$category,$lv1,$lv2,$lv3,$isSmallKana,$markType,$isKatakana,$isHalfWidth) {
 $__this = $__this|0;
 $category = $category|0;
 $lv1 = $lv1|0;
 $lv2 = $lv2|0;
 $lv3 = $lv3|0;
 $isSmallKana = $isSmallKana|0;
 $markType = $markType|0;
 $isKatakana = $isKatakana|0;
 $isHalfWidth = $isHalfWidth|0;
 var $$ = 0, $$1 = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282136);
 __THREW__ = 0;
 invoke_viiiii(60,($__this|0),($category|0),($lv1|0),($lv2|0),($lv3|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $$ = $isSmallKana ? -60 : -28;
   $6 = (($__this) + 20|0);
   $7 = (($__this) + 52|0);
   __THREW__ = 0;
   invoke_viiii(148,0,($$|0),($7|0),($6|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($__this) + 56|0);
    $11 = (($__this) + 24|0);
    __THREW__ = 0;
    invoke_viiii(148,0,($markType|0),($10|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $$1 = $isKatakana ? -60 : -28;
      $16 = (($__this) + 28|0);
      $17 = (($__this) + 60|0);
      __THREW__ = 0;
      invoke_viiii(148,0,($$1|0),($17|0),($16|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $$2 = $isHalfWidth ? -60 : -28;
        $22 = (($__this) + 32|0);
        $23 = (($__this) + 64|0);
        __THREW__ = 0;
        invoke_viiii(148,0,($$2|0),($23|0),($22|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareOrdinalP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_ii($__this,$s1,$idx1,$len1,$s2,$idx2,$len2) {
 $__this = $__this|0;
 $s1 = $s1|0;
 $idx1 = $idx1|0;
 $len1 = $len1|0;
 $s2 = $s2|0;
 $idx2 = $idx2|0;
 $len2 = $len2|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_11 = 0, $L_16 = 0, $L_21 = 0, $L_26 = 0, $L_32 = 0, $L_38 = 0, $V_3$020 = 0, $V_4$019 = 0, $_stackTraceSentry = 0, $len1$len2 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_11 = sp;
 $L_16 = sp + 4|0;
 $L_21 = sp + 8|0;
 $L_26 = sp + 12|0;
 $L_32 = sp + 16|0;
 $L_38 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274848);
 __THREW__ = 0;
 invoke_v(527);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($len1|0)<($len2|0);
   $len1$len2 = $2 ? $len1 : $len2;
   $3 = (($len1$len2) + ($idx1))|0;
   $4 = (($len1$len2) + ($idx2))|0;
   $5 = $idx2 | $idx1;
   $6 = ($5|0)<(0);
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($s1|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(1816,($s1|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = ($3|0)>($13|0);
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(3799,($s2|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_ii(1816,($s2|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = ($4|0)>($19|0);
     if (!($22)) {
      $23 = ($len1$len2|0)>(0);
      L11: do {
       if ($23) {
        $V_3$020 = $idx1;$V_4$019 = $idx2;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($s1|0));
         $201 = __THREW__; __THREW__ = 0;
         $202 = $201&1;
         if ($202) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $174 = (invoke_iii(621,($s1|0),($V_3$020|0))|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s2|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $179 = (invoke_iii(621,($s2|0),($V_4$019|0))|0);
         $180 = __THREW__; __THREW__ = 0;
         $181 = $180&1;
         if ($181) {
          label = 3;
          break;
         }
         $182 = ($174<<16>>16)==($179<<16>>16);
         if (!($182)) {
          break;
         }
         $197 = (($V_3$020) + 1)|0;
         $198 = (($V_4$019) + 1)|0;
         $199 = ($197|0)<($3|0);
         $200 = ($198|0)<($4|0);
         $or$cond1 = $199 & $200;
         if ($or$cond1) {
          $V_3$020 = $197;$V_4$019 = $198;
         } else {
          break L11;
         }
        }
        if ((label|0) == 3) {
         $7 = ___cxa_find_matching_catch()|0;
         $8 = tempRet0;
         $lpad$phi$index = $7;$lpad$phi$index2 = $8;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        __THREW__ = 0;
        invoke_vi(3799,($s1|0));
        $183 = __THREW__; __THREW__ = 0;
        $184 = $183&1;
        if ($184) {
         break L1;
        }
        __THREW__ = 0;
        $185 = (invoke_iii(621,($s1|0),($V_3$020|0))|0);
        $186 = __THREW__; __THREW__ = 0;
        $187 = $186&1;
        if ($187) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($s2|0));
        $188 = __THREW__; __THREW__ = 0;
        $189 = $188&1;
        if ($189) {
         break L1;
        }
        __THREW__ = 0;
        $190 = (invoke_iii(621,($s2|0),($V_4$019|0))|0);
        $191 = __THREW__; __THREW__ = 0;
        $192 = $191&1;
        if ($192) {
         break L1;
        }
        $193 = $185&65535;
        $194 = $190&65535;
        $195 = (($193) - ($194))|0;
        $196 = $195 & 65535;
        $$0 = $196;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $203 = ($len1|0)==($len2|0);
      if ($203) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $204 = ($len1$len2|0)==($len1|0);
      $$ = $204 ? -1 : 1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    __THREW__ = 0;
    $26 = (invoke_iii(2758,(1167664|0),6)|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     HEAP32[$L_11>>2] = $idx1;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      $31 = (invoke_iii(2724,(2155952|0),($L_11|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $36 = (($26) + 12|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = ($37|0)==(0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_i(132)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($39|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($26|0),($31|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($26) + 16|0);
         HEAP32[$46>>2] = $31;
         HEAP32[$L_16>>2] = $idx2;
         __THREW__ = 0;
         (invoke_ii(2996,(2155952|0))|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if (!($48)) {
          __THREW__ = 0;
          $49 = (invoke_iii(2724,(2155952|0),($L_16|0))|0);
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if (!($51)) {
           __THREW__ = 0;
           invoke_vi(3799,($26|0));
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if (!($53)) {
            $54 = HEAP32[$36>>2]|0;
            $55 = ($54>>>0)<(2);
            if ($55) {
             __THREW__ = 0;
             $56 = (invoke_i(132)|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($56|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($26|0),($49|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if (!($62)) {
             $63 = HEAP32[$26>>2]|0;
             $64 = (($63) + 92|0);
             $65 = HEAP32[$64>>2]|0;
             $66 = (($46) + ($65)|0);
             HEAP32[$66>>2] = $49;
             HEAP32[$L_21>>2] = $len1;
             __THREW__ = 0;
             (invoke_ii(2996,(2155952|0))|0);
             $67 = __THREW__; __THREW__ = 0;
             $68 = $67&1;
             if (!($68)) {
              __THREW__ = 0;
              $69 = (invoke_iii(2724,(2155952|0),($L_21|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if (!($71)) {
               __THREW__ = 0;
               invoke_vi(3799,($26|0));
               $72 = __THREW__; __THREW__ = 0;
               $73 = $72&1;
               if (!($73)) {
                $74 = HEAP32[$36>>2]|0;
                $75 = ($74>>>0)<(3);
                if ($75) {
                 __THREW__ = 0;
                 $76 = (invoke_i(132)|0);
                 $77 = __THREW__; __THREW__ = 0;
                 $78 = $77&1;
                 if ($78) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($76|0));
                 $79 = __THREW__; __THREW__ = 0;
                 $80 = $79&1;
                 if ($80) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($26|0),($69|0));
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if (!($82)) {
                 $83 = HEAP32[$26>>2]|0;
                 $84 = (($83) + 92|0);
                 $85 = HEAP32[$84>>2]|0;
                 $86 = $85 << 1;
                 $87 = (($46) + ($86)|0);
                 HEAP32[$87>>2] = $69;
                 HEAP32[$L_26>>2] = $len2;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $88 = __THREW__; __THREW__ = 0;
                 $89 = $88&1;
                 if ($89) {
                  break;
                 }
                 __THREW__ = 0;
                 $90 = (invoke_iii(2724,(2155952|0),($L_26|0))|0);
                 $91 = __THREW__; __THREW__ = 0;
                 $92 = $91&1;
                 if ($92) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($26|0));
                 $93 = __THREW__; __THREW__ = 0;
                 $94 = $93&1;
                 if ($94) {
                  break;
                 }
                 $95 = HEAP32[$36>>2]|0;
                 $96 = ($95>>>0)<(4);
                 if ($96) {
                  __THREW__ = 0;
                  $97 = (invoke_i(132)|0);
                  $98 = __THREW__; __THREW__ = 0;
                  $99 = $98&1;
                  if ($99) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($97|0));
                  $100 = __THREW__; __THREW__ = 0;
                  $101 = $100&1;
                  if ($101) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($26|0),($90|0));
                 $102 = __THREW__; __THREW__ = 0;
                 $103 = $102&1;
                 if ($103) {
                  break;
                 }
                 $104 = HEAP32[$26>>2]|0;
                 $105 = (($104) + 92|0);
                 $106 = HEAP32[$105>>2]|0;
                 $107 = ($106*3)|0;
                 $108 = (($46) + ($107)|0);
                 HEAP32[$108>>2] = $90;
                 __THREW__ = 0;
                 invoke_vi(3799,($s1|0));
                 $109 = __THREW__; __THREW__ = 0;
                 $110 = $109&1;
                 if ($110) {
                  break;
                 }
                 __THREW__ = 0;
                 $111 = (invoke_ii(1816,($s1|0))|0);
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  break;
                 }
                 HEAP32[$L_32>>2] = $111;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $114 = __THREW__; __THREW__ = 0;
                 $115 = $114&1;
                 if ($115) {
                  break;
                 }
                 __THREW__ = 0;
                 $116 = (invoke_iii(2724,(2155952|0),($L_32|0))|0);
                 $117 = __THREW__; __THREW__ = 0;
                 $118 = $117&1;
                 if ($118) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($26|0));
                 $119 = __THREW__; __THREW__ = 0;
                 $120 = $119&1;
                 if ($120) {
                  break;
                 }
                 $121 = HEAP32[$36>>2]|0;
                 $122 = ($121>>>0)<(5);
                 if ($122) {
                  __THREW__ = 0;
                  $123 = (invoke_i(132)|0);
                  $124 = __THREW__; __THREW__ = 0;
                  $125 = $124&1;
                  if ($125) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($123|0));
                  $126 = __THREW__; __THREW__ = 0;
                  $127 = $126&1;
                  if ($127) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($26|0),($116|0));
                 $128 = __THREW__; __THREW__ = 0;
                 $129 = $128&1;
                 if ($129) {
                  break;
                 }
                 $130 = HEAP32[$26>>2]|0;
                 $131 = (($130) + 92|0);
                 $132 = HEAP32[$131>>2]|0;
                 $133 = $132 << 2;
                 $134 = (($46) + ($133)|0);
                 HEAP32[$134>>2] = $116;
                 __THREW__ = 0;
                 invoke_vi(3799,($s2|0));
                 $135 = __THREW__; __THREW__ = 0;
                 $136 = $135&1;
                 if ($136) {
                  break;
                 }
                 __THREW__ = 0;
                 $137 = (invoke_ii(1816,($s2|0))|0);
                 $138 = __THREW__; __THREW__ = 0;
                 $139 = $138&1;
                 if ($139) {
                  break;
                 }
                 HEAP32[$L_38>>2] = $137;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $140 = __THREW__; __THREW__ = 0;
                 $141 = $140&1;
                 if ($141) {
                  break;
                 }
                 __THREW__ = 0;
                 $142 = (invoke_iii(2724,(2155952|0),($L_38|0))|0);
                 $143 = __THREW__; __THREW__ = 0;
                 $144 = $143&1;
                 if ($144) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($26|0));
                 $145 = __THREW__; __THREW__ = 0;
                 $146 = $145&1;
                 if ($146) {
                  break;
                 }
                 $147 = HEAP32[$36>>2]|0;
                 $148 = ($147>>>0)<(6);
                 if ($148) {
                  __THREW__ = 0;
                  $149 = (invoke_i(132)|0);
                  $150 = __THREW__; __THREW__ = 0;
                  $151 = $150&1;
                  if ($151) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($149|0));
                  $152 = __THREW__; __THREW__ = 0;
                  $153 = $152&1;
                  if ($153) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($26|0),($142|0));
                 $154 = __THREW__; __THREW__ = 0;
                 $155 = $154&1;
                 if ($155) {
                  break;
                 }
                 $156 = HEAP32[$26>>2]|0;
                 $157 = (($156) + 92|0);
                 $158 = HEAP32[$157>>2]|0;
                 $159 = ($158*5)|0;
                 $160 = (($46) + ($159)|0);
                 HEAP32[$160>>2] = $142;
                 $161 = HEAP32[3019968>>2]|0;
                 __THREW__ = 0;
                 $162 = (invoke_iiii(556,(0|0),($161|0),($26|0))|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2649224|0))|0);
                 $165 = __THREW__; __THREW__ = 0;
                 $166 = $165&1;
                 if ($166) {
                  break;
                 }
                 __THREW__ = 0;
                 $167 = (invoke_ii(3469,(2649224|0))|0);
                 $168 = __THREW__; __THREW__ = 0;
                 $169 = $168&1;
                 if ($169) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vii(1975,($167|0),($162|0));
                 $170 = __THREW__; __THREW__ = 0;
                 $171 = $170&1;
                 if ($171) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3833,($167|0));
                 $172 = __THREW__; __THREW__ = 0;
                 $173 = $172&1;
                 if ($173) {
                  break;
                 }
                 // unreachable;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareQuickP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_iiPbS3_b($__this,$s1,$idx1,$len1,$s2,$idx2,$len2,$sourceConsumed,$targetConsumed,$immediateBreakup) {
 $__this = $__this|0;
 $s1 = $s1|0;
 $idx1 = $idx1|0;
 $len1 = $len1|0;
 $s2 = $s2|0;
 $idx2 = $idx2|0;
 $len2 = $len2|0;
 $sourceConsumed = $sourceConsumed|0;
 $targetConsumed = $targetConsumed|0;
 $immediateBreakup = $immediateBreakup|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_13 = 0, $L_18 = 0, $L_23 = 0, $L_28 = 0;
 var $L_34 = 0, $L_40 = 0, $L_73 = 0, $L_78 = 0, $L_83 = 0, $L_88 = 0, $V_3$033 = 0, $V_4$032 = 0, $_stackTraceSentry = 0, $len1$len2 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_13 = sp + 36|0;
 $L_18 = sp + 32|0;
 $L_23 = sp + 28|0;
 $L_28 = sp + 24|0;
 $L_34 = sp + 20|0;
 $L_40 = sp + 12|0;
 $L_73 = sp + 8|0;
 $L_78 = sp + 4|0;
 $L_83 = sp;
 $L_88 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274896);
 __THREW__ = 0;
 invoke_v(528);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   HEAP8[$sourceConsumed>>0] = 0;
   HEAP8[$targetConsumed>>0] = 0;
   $2 = ($len1|0)<($len2|0);
   $len1$len2 = $2 ? $len1 : $len2;
   $3 = (($len1$len2) + ($idx1))|0;
   $4 = (($len1$len2) + ($idx2))|0;
   $5 = $idx2 | $idx1;
   $6 = ($5|0)<(0);
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($s1|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(1816,($s1|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = ($3|0)>($13|0);
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(3799,($s2|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_ii(1816,($s2|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = ($4|0)>($19|0);
     if (!($22)) {
      $23 = ($len1$len2|0)>(0);
      L11: do {
       if ($23) {
        $V_3$033 = $idx1;$V_4$032 = $idx2;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($s1|0));
         $386 = __THREW__; __THREW__ = 0;
         $387 = $386&1;
         if ($387) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $174 = (invoke_iii(621,($s1|0),($V_3$033|0))|0);
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s2|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $179 = (invoke_iii(621,($s2|0),($V_4$032|0))|0);
         $180 = __THREW__; __THREW__ = 0;
         $181 = $180&1;
         if ($181) {
          label = 3;
          break;
         }
         $182 = ($174<<16>>16)==($179<<16>>16);
         if (!($182)) {
          break;
         }
         $382 = (($V_3$033) + 1)|0;
         $383 = (($V_4$032) + 1)|0;
         $384 = ($382|0)<($3|0);
         $385 = ($383|0)<($4|0);
         $or$cond1 = $384 & $385;
         if ($or$cond1) {
          $V_3$033 = $382;$V_4$032 = $383;
         } else {
          break L11;
         }
        }
        if ((label|0) == 3) {
         $7 = ___cxa_find_matching_catch()|0;
         $8 = tempRet0;
         $lpad$phi$index = $7;$lpad$phi$index2 = $8;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        if ($immediateBreakup) {
         $$0 = -1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($s1|0));
        $183 = __THREW__; __THREW__ = 0;
        $184 = $183&1;
        if ($184) {
         break L1;
        }
        __THREW__ = 0;
        $185 = (invoke_iii(621,($s1|0),($V_3$033|0))|0);
        $186 = __THREW__; __THREW__ = 0;
        $187 = $186&1;
        if ($187) {
         break L1;
        }
        $188 = $185&65535;
        __THREW__ = 0;
        $189 = (invoke_iii(799,($__this|0),($188|0))|0);
        $190 = __THREW__; __THREW__ = 0;
        $191 = $190&1;
        if ($191) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($s2|0));
        $192 = __THREW__; __THREW__ = 0;
        $193 = $192&1;
        if ($193) {
         break L1;
        }
        __THREW__ = 0;
        $194 = (invoke_iii(621,($s2|0),($V_4$032|0))|0);
        $195 = __THREW__; __THREW__ = 0;
        $196 = $195&1;
        if ($196) {
         break L1;
        }
        $197 = $194&65535;
        __THREW__ = 0;
        $198 = (invoke_iii(799,($__this|0),($197|0))|0);
        $199 = __THREW__; __THREW__ = 0;
        $200 = $199&1;
        if ($200) {
         break L1;
        }
        $201 = $189&255;
        $202 = $198&255;
        $203 = (($201) - ($202))|0;
        $204 = $203 & 255;
        $205 = ($204|0)==(0);
        if (!($205)) {
         $$0 = $204;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($s1|0));
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         break L1;
        }
        __THREW__ = 0;
        $208 = (invoke_iii(621,($s1|0),($V_3$033|0))|0);
        $209 = __THREW__; __THREW__ = 0;
        $210 = $209&1;
        if ($210) {
         break L1;
        }
        $211 = $208&65535;
        __THREW__ = 0;
        $212 = (invoke_iii(800,($__this|0),($211|0))|0);
        $213 = __THREW__; __THREW__ = 0;
        $214 = $213&1;
        if ($214) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($s2|0));
        $215 = __THREW__; __THREW__ = 0;
        $216 = $215&1;
        if ($216) {
         break L1;
        }
        __THREW__ = 0;
        $217 = (invoke_iii(621,($s2|0),($V_4$032|0))|0);
        $218 = __THREW__; __THREW__ = 0;
        $219 = $218&1;
        if ($219) {
         break L1;
        }
        $220 = $217&65535;
        __THREW__ = 0;
        $221 = (invoke_iii(800,($__this|0),($220|0))|0);
        $222 = __THREW__; __THREW__ = 0;
        $223 = $222&1;
        if ($223) {
         break L1;
        }
        $224 = $212&255;
        $225 = $221&255;
        $226 = (($224) - ($225))|0;
        $227 = $226 & 255;
        $228 = ($227|0)==(0);
        if (!($228)) {
         $$0 = $227;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($s1|0));
        $229 = __THREW__; __THREW__ = 0;
        $230 = $229&1;
        if ($230) {
         break L1;
        }
        __THREW__ = 0;
        $231 = (invoke_iii(621,($s1|0),($V_3$033|0))|0);
        $232 = __THREW__; __THREW__ = 0;
        $233 = $232&1;
        if ($233) {
         break L1;
        }
        $234 = $231&65535;
        __THREW__ = 0;
        $235 = (invoke_iii(789,(0|0),($234|0))|0);
        $236 = __THREW__; __THREW__ = 0;
        $237 = $236&1;
        if ($237) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($s2|0));
        $238 = __THREW__; __THREW__ = 0;
        $239 = $238&1;
        if ($239) {
         break L1;
        }
        __THREW__ = 0;
        $240 = (invoke_iii(621,($s2|0),($V_4$032|0))|0);
        $241 = __THREW__; __THREW__ = 0;
        $242 = $241&1;
        if ($242) {
         break L1;
        }
        $243 = $240&65535;
        __THREW__ = 0;
        $244 = (invoke_iii(789,(0|0),($243|0))|0);
        $245 = __THREW__; __THREW__ = 0;
        $246 = $245&1;
        if ($246) {
         break L1;
        }
        $247 = $235&255;
        $248 = $244&255;
        $249 = (($247) - ($248))|0;
        $250 = $249 & 255;
        $251 = ($250|0)==(0);
        if (!($251)) {
         $$0 = $250;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1167664|0))|0);
        $252 = __THREW__; __THREW__ = 0;
        $253 = $252&1;
        if ($253) {
         break L1;
        }
        __THREW__ = 0;
        $254 = (invoke_iii(2758,(1167664|0),6)|0);
        $255 = __THREW__; __THREW__ = 0;
        $256 = $255&1;
        if ($256) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($254|0));
        $257 = __THREW__; __THREW__ = 0;
        $258 = $257&1;
        if ($258) {
         break L1;
        }
        $259 = (($254) + 12|0);
        $260 = HEAP32[$259>>2]|0;
        $261 = ($260|0)==(0);
        if ($261) {
         __THREW__ = 0;
         $262 = (invoke_i(132)|0);
         $263 = __THREW__; __THREW__ = 0;
         $264 = $263&1;
         if ($264) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($262|0));
         $265 = __THREW__; __THREW__ = 0;
         $266 = $265&1;
         if ($266) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($254|0),($s1|0));
        $267 = __THREW__; __THREW__ = 0;
        $268 = $267&1;
        if ($268) {
         break L1;
        }
        $269 = (($254) + 16|0);
        HEAP32[$269>>2] = $s1;
        __THREW__ = 0;
        invoke_vi(3799,($254|0));
        $270 = __THREW__; __THREW__ = 0;
        $271 = $270&1;
        if ($271) {
         break L1;
        }
        $272 = HEAP32[$259>>2]|0;
        $273 = ($272>>>0)<(2);
        if ($273) {
         __THREW__ = 0;
         $274 = (invoke_i(132)|0);
         $275 = __THREW__; __THREW__ = 0;
         $276 = $275&1;
         if ($276) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($274|0));
         $277 = __THREW__; __THREW__ = 0;
         $278 = $277&1;
         if ($278) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($254|0),($s2|0));
        $279 = __THREW__; __THREW__ = 0;
        $280 = $279&1;
        if ($280) {
         break L1;
        }
        $281 = HEAP32[$254>>2]|0;
        $282 = (($281) + 92|0);
        $283 = HEAP32[$282>>2]|0;
        $284 = (($269) + ($283)|0);
        HEAP32[$284>>2] = $s2;
        HEAP32[$L_73>>2] = $idx1;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $285 = __THREW__; __THREW__ = 0;
        $286 = $285&1;
        if ($286) {
         break L1;
        }
        __THREW__ = 0;
        $287 = (invoke_iii(2724,(2155952|0),($L_73|0))|0);
        $288 = __THREW__; __THREW__ = 0;
        $289 = $288&1;
        if ($289) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($254|0));
        $290 = __THREW__; __THREW__ = 0;
        $291 = $290&1;
        if ($291) {
         break L1;
        }
        $292 = HEAP32[$259>>2]|0;
        $293 = ($292>>>0)<(3);
        if ($293) {
         __THREW__ = 0;
         $294 = (invoke_i(132)|0);
         $295 = __THREW__; __THREW__ = 0;
         $296 = $295&1;
         if ($296) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($294|0));
         $297 = __THREW__; __THREW__ = 0;
         $298 = $297&1;
         if ($298) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($254|0),($287|0));
        $299 = __THREW__; __THREW__ = 0;
        $300 = $299&1;
        if ($300) {
         break L1;
        }
        $301 = HEAP32[$254>>2]|0;
        $302 = (($301) + 92|0);
        $303 = HEAP32[$302>>2]|0;
        $304 = $303 << 1;
        $305 = (($269) + ($304)|0);
        HEAP32[$305>>2] = $287;
        HEAP32[$L_78>>2] = $3;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $306 = __THREW__; __THREW__ = 0;
        $307 = $306&1;
        if ($307) {
         break L1;
        }
        __THREW__ = 0;
        $308 = (invoke_iii(2724,(2155952|0),($L_78|0))|0);
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        if ($310) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($254|0));
        $311 = __THREW__; __THREW__ = 0;
        $312 = $311&1;
        if ($312) {
         break L1;
        }
        $313 = HEAP32[$259>>2]|0;
        $314 = ($313>>>0)<(4);
        if ($314) {
         __THREW__ = 0;
         $315 = (invoke_i(132)|0);
         $316 = __THREW__; __THREW__ = 0;
         $317 = $316&1;
         if ($317) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($315|0));
         $318 = __THREW__; __THREW__ = 0;
         $319 = $318&1;
         if ($319) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($254|0),($308|0));
        $320 = __THREW__; __THREW__ = 0;
        $321 = $320&1;
        if ($321) {
         break L1;
        }
        $322 = HEAP32[$254>>2]|0;
        $323 = (($322) + 92|0);
        $324 = HEAP32[$323>>2]|0;
        $325 = ($324*3)|0;
        $326 = (($269) + ($325)|0);
        HEAP32[$326>>2] = $308;
        HEAP32[$L_83>>2] = $idx2;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $327 = __THREW__; __THREW__ = 0;
        $328 = $327&1;
        if ($328) {
         break L1;
        }
        __THREW__ = 0;
        $329 = (invoke_iii(2724,(2155952|0),($L_83|0))|0);
        $330 = __THREW__; __THREW__ = 0;
        $331 = $330&1;
        if ($331) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($254|0));
        $332 = __THREW__; __THREW__ = 0;
        $333 = $332&1;
        if ($333) {
         break L1;
        }
        $334 = HEAP32[$259>>2]|0;
        $335 = ($334>>>0)<(5);
        if ($335) {
         __THREW__ = 0;
         $336 = (invoke_i(132)|0);
         $337 = __THREW__; __THREW__ = 0;
         $338 = $337&1;
         if ($338) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($336|0));
         $339 = __THREW__; __THREW__ = 0;
         $340 = $339&1;
         if ($340) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($254|0),($329|0));
        $341 = __THREW__; __THREW__ = 0;
        $342 = $341&1;
        if ($342) {
         break L1;
        }
        $343 = HEAP32[$254>>2]|0;
        $344 = (($343) + 92|0);
        $345 = HEAP32[$344>>2]|0;
        $346 = $345 << 2;
        $347 = (($269) + ($346)|0);
        HEAP32[$347>>2] = $329;
        HEAP32[$L_88>>2] = $4;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $348 = __THREW__; __THREW__ = 0;
        $349 = $348&1;
        if ($349) {
         break L1;
        }
        __THREW__ = 0;
        $350 = (invoke_iii(2724,(2155952|0),($L_88|0))|0);
        $351 = __THREW__; __THREW__ = 0;
        $352 = $351&1;
        if ($352) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($254|0));
        $353 = __THREW__; __THREW__ = 0;
        $354 = $353&1;
        if ($354) {
         break L1;
        }
        $355 = HEAP32[$259>>2]|0;
        $356 = ($355>>>0)<(6);
        if ($356) {
         __THREW__ = 0;
         $357 = (invoke_i(132)|0);
         $358 = __THREW__; __THREW__ = 0;
         $359 = $358&1;
         if ($359) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($357|0));
         $360 = __THREW__; __THREW__ = 0;
         $361 = $360&1;
         if ($361) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($254|0),($350|0));
        $362 = __THREW__; __THREW__ = 0;
        $363 = $362&1;
        if ($363) {
         break L1;
        }
        $364 = HEAP32[$254>>2]|0;
        $365 = (($364) + 92|0);
        $366 = HEAP32[$365>>2]|0;
        $367 = ($366*5)|0;
        $368 = (($269) + ($367)|0);
        HEAP32[$368>>2] = $350;
        $369 = HEAP32[3020136>>2]|0;
        __THREW__ = 0;
        $370 = (invoke_iiii(556,(0|0),($369|0),($254|0))|0);
        $371 = __THREW__; __THREW__ = 0;
        $372 = $371&1;
        if ($372) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2649224|0))|0);
        $373 = __THREW__; __THREW__ = 0;
        $374 = $373&1;
        if ($374) {
         break L1;
        }
        __THREW__ = 0;
        $375 = (invoke_ii(3469,(2649224|0))|0);
        $376 = __THREW__; __THREW__ = 0;
        $377 = $376&1;
        if ($377) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vii(1975,($375|0),($370|0));
        $378 = __THREW__; __THREW__ = 0;
        $379 = $378&1;
        if ($379) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3833,($375|0));
        $380 = __THREW__; __THREW__ = 0;
        $381 = $380&1;
        if ($381) {
         break L1;
        }
        // unreachable;
       }
      } while(0);
      $388 = ($len1|0)<=($len2|0);
      $389 = $388&1;
      HEAP8[$sourceConsumed>>0] = $389;
      $390 = ($len1|0)>=($len2|0);
      $391 = $390&1;
      HEAP8[$targetConsumed>>0] = $391;
      $392 = ($len1|0)==($len2|0);
      if ($392) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $393 = ($len1$len2|0)==($len1|0);
      $$ = $393 ? -1 : 1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    __THREW__ = 0;
    $26 = (invoke_iii(2758,(1167664|0),6)|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     HEAP32[$L_13>>2] = $idx1;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      $31 = (invoke_iii(2724,(2155952|0),($L_13|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $36 = (($26) + 12|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = ($37|0)==(0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_i(132)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($39|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($26|0),($31|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($26) + 16|0);
         HEAP32[$46>>2] = $31;
         HEAP32[$L_18>>2] = $idx2;
         __THREW__ = 0;
         (invoke_ii(2996,(2155952|0))|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if (!($48)) {
          __THREW__ = 0;
          $49 = (invoke_iii(2724,(2155952|0),($L_18|0))|0);
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if (!($51)) {
           __THREW__ = 0;
           invoke_vi(3799,($26|0));
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if (!($53)) {
            $54 = HEAP32[$36>>2]|0;
            $55 = ($54>>>0)<(2);
            if ($55) {
             __THREW__ = 0;
             $56 = (invoke_i(132)|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($56|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($26|0),($49|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if (!($62)) {
             $63 = HEAP32[$26>>2]|0;
             $64 = (($63) + 92|0);
             $65 = HEAP32[$64>>2]|0;
             $66 = (($46) + ($65)|0);
             HEAP32[$66>>2] = $49;
             HEAP32[$L_23>>2] = $len1;
             __THREW__ = 0;
             (invoke_ii(2996,(2155952|0))|0);
             $67 = __THREW__; __THREW__ = 0;
             $68 = $67&1;
             if (!($68)) {
              __THREW__ = 0;
              $69 = (invoke_iii(2724,(2155952|0),($L_23|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if (!($71)) {
               __THREW__ = 0;
               invoke_vi(3799,($26|0));
               $72 = __THREW__; __THREW__ = 0;
               $73 = $72&1;
               if (!($73)) {
                $74 = HEAP32[$36>>2]|0;
                $75 = ($74>>>0)<(3);
                if ($75) {
                 __THREW__ = 0;
                 $76 = (invoke_i(132)|0);
                 $77 = __THREW__; __THREW__ = 0;
                 $78 = $77&1;
                 if ($78) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($76|0));
                 $79 = __THREW__; __THREW__ = 0;
                 $80 = $79&1;
                 if ($80) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($26|0),($69|0));
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if (!($82)) {
                 $83 = HEAP32[$26>>2]|0;
                 $84 = (($83) + 92|0);
                 $85 = HEAP32[$84>>2]|0;
                 $86 = $85 << 1;
                 $87 = (($46) + ($86)|0);
                 HEAP32[$87>>2] = $69;
                 HEAP32[$L_28>>2] = $len2;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $88 = __THREW__; __THREW__ = 0;
                 $89 = $88&1;
                 if ($89) {
                  break;
                 }
                 __THREW__ = 0;
                 $90 = (invoke_iii(2724,(2155952|0),($L_28|0))|0);
                 $91 = __THREW__; __THREW__ = 0;
                 $92 = $91&1;
                 if ($92) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($26|0));
                 $93 = __THREW__; __THREW__ = 0;
                 $94 = $93&1;
                 if ($94) {
                  break;
                 }
                 $95 = HEAP32[$36>>2]|0;
                 $96 = ($95>>>0)<(4);
                 if ($96) {
                  __THREW__ = 0;
                  $97 = (invoke_i(132)|0);
                  $98 = __THREW__; __THREW__ = 0;
                  $99 = $98&1;
                  if ($99) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($97|0));
                  $100 = __THREW__; __THREW__ = 0;
                  $101 = $100&1;
                  if ($101) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($26|0),($90|0));
                 $102 = __THREW__; __THREW__ = 0;
                 $103 = $102&1;
                 if ($103) {
                  break;
                 }
                 $104 = HEAP32[$26>>2]|0;
                 $105 = (($104) + 92|0);
                 $106 = HEAP32[$105>>2]|0;
                 $107 = ($106*3)|0;
                 $108 = (($46) + ($107)|0);
                 HEAP32[$108>>2] = $90;
                 __THREW__ = 0;
                 invoke_vi(3799,($s1|0));
                 $109 = __THREW__; __THREW__ = 0;
                 $110 = $109&1;
                 if ($110) {
                  break;
                 }
                 __THREW__ = 0;
                 $111 = (invoke_ii(1816,($s1|0))|0);
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  break;
                 }
                 HEAP32[$L_34>>2] = $111;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $114 = __THREW__; __THREW__ = 0;
                 $115 = $114&1;
                 if ($115) {
                  break;
                 }
                 __THREW__ = 0;
                 $116 = (invoke_iii(2724,(2155952|0),($L_34|0))|0);
                 $117 = __THREW__; __THREW__ = 0;
                 $118 = $117&1;
                 if ($118) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($26|0));
                 $119 = __THREW__; __THREW__ = 0;
                 $120 = $119&1;
                 if ($120) {
                  break;
                 }
                 $121 = HEAP32[$36>>2]|0;
                 $122 = ($121>>>0)<(5);
                 if ($122) {
                  __THREW__ = 0;
                  $123 = (invoke_i(132)|0);
                  $124 = __THREW__; __THREW__ = 0;
                  $125 = $124&1;
                  if ($125) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($123|0));
                  $126 = __THREW__; __THREW__ = 0;
                  $127 = $126&1;
                  if ($127) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($26|0),($116|0));
                 $128 = __THREW__; __THREW__ = 0;
                 $129 = $128&1;
                 if ($129) {
                  break;
                 }
                 $130 = HEAP32[$26>>2]|0;
                 $131 = (($130) + 92|0);
                 $132 = HEAP32[$131>>2]|0;
                 $133 = $132 << 2;
                 $134 = (($46) + ($133)|0);
                 HEAP32[$134>>2] = $116;
                 __THREW__ = 0;
                 invoke_vi(3799,($s2|0));
                 $135 = __THREW__; __THREW__ = 0;
                 $136 = $135&1;
                 if ($136) {
                  break;
                 }
                 __THREW__ = 0;
                 $137 = (invoke_ii(1816,($s2|0))|0);
                 $138 = __THREW__; __THREW__ = 0;
                 $139 = $138&1;
                 if ($139) {
                  break;
                 }
                 HEAP32[$L_40>>2] = $137;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $140 = __THREW__; __THREW__ = 0;
                 $141 = $140&1;
                 if ($141) {
                  break;
                 }
                 __THREW__ = 0;
                 $142 = (invoke_iii(2724,(2155952|0),($L_40|0))|0);
                 $143 = __THREW__; __THREW__ = 0;
                 $144 = $143&1;
                 if ($144) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($26|0));
                 $145 = __THREW__; __THREW__ = 0;
                 $146 = $145&1;
                 if ($146) {
                  break;
                 }
                 $147 = HEAP32[$36>>2]|0;
                 $148 = ($147>>>0)<(6);
                 if ($148) {
                  __THREW__ = 0;
                  $149 = (invoke_i(132)|0);
                  $150 = __THREW__; __THREW__ = 0;
                  $151 = $150&1;
                  if ($151) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($149|0));
                  $152 = __THREW__; __THREW__ = 0;
                  $153 = $152&1;
                  if ($153) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($26|0),($142|0));
                 $154 = __THREW__; __THREW__ = 0;
                 $155 = $154&1;
                 if ($155) {
                  break;
                 }
                 $156 = HEAP32[$26>>2]|0;
                 $157 = (($156) + 92|0);
                 $158 = HEAP32[$157>>2]|0;
                 $159 = ($158*5)|0;
                 $160 = (($46) + ($159)|0);
                 HEAP32[$160>>2] = $142;
                 $161 = HEAP32[3020128>>2]|0;
                 __THREW__ = 0;
                 $162 = (invoke_iiii(556,(0|0),($161|0),($26|0))|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2649224|0))|0);
                 $165 = __THREW__; __THREW__ = 0;
                 $166 = $165&1;
                 if ($166) {
                  break;
                 }
                 __THREW__ = 0;
                 $167 = (invoke_ii(3469,(2649224|0))|0);
                 $168 = __THREW__; __THREW__ = 0;
                 $169 = $168&1;
                 if ($169) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vii(1975,($167|0),($162|0));
                 $170 = __THREW__; __THREW__ = 0;
                 $171 = $170&1;
                 if ($171) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3833,($167|0));
                 $172 = __THREW__; __THREW__ = 0;
                 $173 = $172&1;
                 if ($173) {
                  break;
                 }
                 // unreachable;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareOrdinalIgnoreCaseP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_ii($__this,$s1,$idx1,$len1,$s2,$idx2,$len2) {
 $__this = $__this|0;
 $s1 = $s1|0;
 $idx1 = $idx1|0;
 $len1 = $len1|0;
 $s2 = $s2|0;
 $idx2 = $idx2|0;
 $len2 = $len2|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_11 = 0, $L_16 = 0, $L_21 = 0, $L_26 = 0, $L_32 = 0, $L_38 = 0, $V_4$024 = 0, $V_5$023 = 0, $_stackTraceSentry = 0, $len1$len2 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_11 = sp;
 $L_16 = sp + 4|0;
 $L_21 = sp + 8|0;
 $L_26 = sp + 12|0;
 $L_32 = sp + 16|0;
 $L_38 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274944);
 __THREW__ = 0;
 invoke_v(529);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($len1|0)<($len2|0);
   $len1$len2 = $2 ? $len1 : $len2;
   $3 = (($len1$len2) + ($idx1))|0;
   $4 = (($len1$len2) + ($idx2))|0;
   $5 = $idx2 | $idx1;
   $6 = ($5|0)<(0);
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($s1|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(1816,($s1|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = ($3|0)>($13|0);
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(3799,($s2|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_ii(1816,($s2|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = ($4|0)>($19|0);
     if (!($22)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2280704|0))|0);
      $173 = __THREW__; __THREW__ = 0;
      $174 = $173&1;
      if ($174) {
       break;
      }
      $175 = HEAP8[((2280704 + 116|0))>>0]|0;
      $176 = ($175<<24>>24)==(0);
      if ($176) {
       __THREW__ = 0;
       (invoke_ii(2996,(2280704|0))|0);
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2280704|0))|0);
       $179 = __THREW__; __THREW__ = 0;
       $180 = $179&1;
       if ($180) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3832,(2280704|0));
       $181 = __THREW__; __THREW__ = 0;
       $182 = $181&1;
       if ($182) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2280704|0))|0);
      $183 = __THREW__; __THREW__ = 0;
      $184 = $183&1;
      if ($184) {
       break;
      }
      $185 = HEAP32[((2280704 + 80|0))>>2]|0;
      $186 = (($185) + 4|0);
      $187 = HEAP32[$186>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($187|0));
      $188 = __THREW__; __THREW__ = 0;
      $189 = $188&1;
      if ($189) {
       break;
      }
      $190 = ($len1$len2|0)>(0);
      L19: do {
       if ($190) {
        $191 = (($187) + 8|0);
        $192 = HEAP32[$191>>2]|0;
        $V_4$024 = $idx1;$V_5$023 = $idx2;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($s1|0));
         $240 = __THREW__; __THREW__ = 0;
         $241 = $240&1;
         if ($241) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $193 = (invoke_iii(621,($s1|0),($V_4$024|0))|0);
         $194 = __THREW__; __THREW__ = 0;
         $195 = $194&1;
         if ($195) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($192|0));
         $196 = __THREW__; __THREW__ = 0;
         $197 = $196&1;
         if ($197) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $198 = (invoke_iiii(1667,(2274320|0),($192|0),($193|0))|0);
         $199 = __THREW__; __THREW__ = 0;
         $200 = $199&1;
         if ($200) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s2|0));
         $201 = __THREW__; __THREW__ = 0;
         $202 = $201&1;
         if ($202) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $203 = (invoke_iii(621,($s2|0),($V_5$023|0))|0);
         $204 = __THREW__; __THREW__ = 0;
         $205 = $204&1;
         if ($205) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($192|0));
         $206 = __THREW__; __THREW__ = 0;
         $207 = $206&1;
         if ($207) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $208 = (invoke_iiii(1667,(2274320|0),($192|0),($203|0))|0);
         $209 = __THREW__; __THREW__ = 0;
         $210 = $209&1;
         if ($210) {
          label = 3;
          break;
         }
         $211 = ($198<<16>>16)==($208<<16>>16);
         if (!($211)) {
          break;
         }
         $236 = (($V_4$024) + 1)|0;
         $237 = (($V_5$023) + 1)|0;
         $238 = ($236|0)<($3|0);
         $239 = ($237|0)<($4|0);
         $or$cond1 = $238 & $239;
         if ($or$cond1) {
          $V_4$024 = $236;$V_5$023 = $237;
         } else {
          break L19;
         }
        }
        if ((label|0) == 3) {
         $7 = ___cxa_find_matching_catch()|0;
         $8 = tempRet0;
         $lpad$phi$index = $7;$lpad$phi$index2 = $8;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        __THREW__ = 0;
        invoke_vi(3799,($s1|0));
        $212 = __THREW__; __THREW__ = 0;
        $213 = $212&1;
        if ($213) {
         break L1;
        }
        __THREW__ = 0;
        $214 = (invoke_iii(621,($s1|0),($V_4$024|0))|0);
        $215 = __THREW__; __THREW__ = 0;
        $216 = $215&1;
        if ($216) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($192|0));
        $217 = __THREW__; __THREW__ = 0;
        $218 = $217&1;
        if ($218) {
         break L1;
        }
        __THREW__ = 0;
        $219 = (invoke_iiii(1667,(2274320|0),($192|0),($214|0))|0);
        $220 = __THREW__; __THREW__ = 0;
        $221 = $220&1;
        if ($221) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($s2|0));
        $222 = __THREW__; __THREW__ = 0;
        $223 = $222&1;
        if ($223) {
         break L1;
        }
        __THREW__ = 0;
        $224 = (invoke_iii(621,($s2|0),($V_5$023|0))|0);
        $225 = __THREW__; __THREW__ = 0;
        $226 = $225&1;
        if ($226) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($192|0));
        $227 = __THREW__; __THREW__ = 0;
        $228 = $227&1;
        if ($228) {
         break L1;
        }
        __THREW__ = 0;
        $229 = (invoke_iiii(1667,(2274320|0),($192|0),($224|0))|0);
        $230 = __THREW__; __THREW__ = 0;
        $231 = $230&1;
        if ($231) {
         break L1;
        }
        $232 = $219&65535;
        $233 = $229&65535;
        $234 = (($232) - ($233))|0;
        $235 = $234 & 65535;
        $$0 = $235;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $242 = ($len1|0)==($len2|0);
      if ($242) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $243 = ($len1$len2|0)==($len1|0);
      $$ = $243 ? -1 : 1;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    $25 = (invoke_iii(2758,(1167664|0),6)|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     HEAP32[$L_11>>2] = $idx1;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      __THREW__ = 0;
      $30 = (invoke_iii(2724,(2155952|0),($L_11|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3799,($25|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        $35 = (($25) + 12|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = ($36|0)==(0);
        if ($37) {
         __THREW__ = 0;
         $38 = (invoke_i(132)|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($38|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($25|0),($30|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if (!($44)) {
         $45 = (($25) + 16|0);
         HEAP32[$45>>2] = $30;
         HEAP32[$L_16>>2] = $idx2;
         __THREW__ = 0;
         (invoke_ii(2996,(2155952|0))|0);
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if (!($47)) {
          __THREW__ = 0;
          $48 = (invoke_iii(2724,(2155952|0),($L_16|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if (!($50)) {
           __THREW__ = 0;
           invoke_vi(3799,($25|0));
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            $53 = HEAP32[$35>>2]|0;
            $54 = ($53>>>0)<(2);
            if ($54) {
             __THREW__ = 0;
             $55 = (invoke_i(132)|0);
             $56 = __THREW__; __THREW__ = 0;
             $57 = $56&1;
             if ($57) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($55|0));
             $58 = __THREW__; __THREW__ = 0;
             $59 = $58&1;
             if ($59) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($25|0),($48|0));
            $60 = __THREW__; __THREW__ = 0;
            $61 = $60&1;
            if (!($61)) {
             $62 = HEAP32[$25>>2]|0;
             $63 = (($62) + 92|0);
             $64 = HEAP32[$63>>2]|0;
             $65 = (($45) + ($64)|0);
             HEAP32[$65>>2] = $48;
             HEAP32[$L_21>>2] = $len1;
             __THREW__ = 0;
             (invoke_ii(2996,(2155952|0))|0);
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if (!($67)) {
              __THREW__ = 0;
              $68 = (invoke_iii(2724,(2155952|0),($L_21|0))|0);
              $69 = __THREW__; __THREW__ = 0;
              $70 = $69&1;
              if (!($70)) {
               __THREW__ = 0;
               invoke_vi(3799,($25|0));
               $71 = __THREW__; __THREW__ = 0;
               $72 = $71&1;
               if (!($72)) {
                $73 = HEAP32[$35>>2]|0;
                $74 = ($73>>>0)<(3);
                if ($74) {
                 __THREW__ = 0;
                 $75 = (invoke_i(132)|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($75|0));
                 $78 = __THREW__; __THREW__ = 0;
                 $79 = $78&1;
                 if ($79) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($25|0),($68|0));
                $80 = __THREW__; __THREW__ = 0;
                $81 = $80&1;
                if (!($81)) {
                 $82 = HEAP32[$25>>2]|0;
                 $83 = (($82) + 92|0);
                 $84 = HEAP32[$83>>2]|0;
                 $85 = $84 << 1;
                 $86 = (($45) + ($85)|0);
                 HEAP32[$86>>2] = $68;
                 HEAP32[$L_26>>2] = $len2;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $87 = __THREW__; __THREW__ = 0;
                 $88 = $87&1;
                 if ($88) {
                  break;
                 }
                 __THREW__ = 0;
                 $89 = (invoke_iii(2724,(2155952|0),($L_26|0))|0);
                 $90 = __THREW__; __THREW__ = 0;
                 $91 = $90&1;
                 if ($91) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($25|0));
                 $92 = __THREW__; __THREW__ = 0;
                 $93 = $92&1;
                 if ($93) {
                  break;
                 }
                 $94 = HEAP32[$35>>2]|0;
                 $95 = ($94>>>0)<(4);
                 if ($95) {
                  __THREW__ = 0;
                  $96 = (invoke_i(132)|0);
                  $97 = __THREW__; __THREW__ = 0;
                  $98 = $97&1;
                  if ($98) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($96|0));
                  $99 = __THREW__; __THREW__ = 0;
                  $100 = $99&1;
                  if ($100) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($25|0),($89|0));
                 $101 = __THREW__; __THREW__ = 0;
                 $102 = $101&1;
                 if ($102) {
                  break;
                 }
                 $103 = HEAP32[$25>>2]|0;
                 $104 = (($103) + 92|0);
                 $105 = HEAP32[$104>>2]|0;
                 $106 = ($105*3)|0;
                 $107 = (($45) + ($106)|0);
                 HEAP32[$107>>2] = $89;
                 __THREW__ = 0;
                 invoke_vi(3799,($s1|0));
                 $108 = __THREW__; __THREW__ = 0;
                 $109 = $108&1;
                 if ($109) {
                  break;
                 }
                 __THREW__ = 0;
                 $110 = (invoke_ii(1816,($s1|0))|0);
                 $111 = __THREW__; __THREW__ = 0;
                 $112 = $111&1;
                 if ($112) {
                  break;
                 }
                 HEAP32[$L_32>>2] = $110;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $113 = __THREW__; __THREW__ = 0;
                 $114 = $113&1;
                 if ($114) {
                  break;
                 }
                 __THREW__ = 0;
                 $115 = (invoke_iii(2724,(2155952|0),($L_32|0))|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($25|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                 $120 = HEAP32[$35>>2]|0;
                 $121 = ($120>>>0)<(5);
                 if ($121) {
                  __THREW__ = 0;
                  $122 = (invoke_i(132)|0);
                  $123 = __THREW__; __THREW__ = 0;
                  $124 = $123&1;
                  if ($124) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($122|0));
                  $125 = __THREW__; __THREW__ = 0;
                  $126 = $125&1;
                  if ($126) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($25|0),($115|0));
                 $127 = __THREW__; __THREW__ = 0;
                 $128 = $127&1;
                 if ($128) {
                  break;
                 }
                 $129 = HEAP32[$25>>2]|0;
                 $130 = (($129) + 92|0);
                 $131 = HEAP32[$130>>2]|0;
                 $132 = $131 << 2;
                 $133 = (($45) + ($132)|0);
                 HEAP32[$133>>2] = $115;
                 __THREW__ = 0;
                 invoke_vi(3799,($s2|0));
                 $134 = __THREW__; __THREW__ = 0;
                 $135 = $134&1;
                 if ($135) {
                  break;
                 }
                 __THREW__ = 0;
                 $136 = (invoke_ii(1816,($s2|0))|0);
                 $137 = __THREW__; __THREW__ = 0;
                 $138 = $137&1;
                 if ($138) {
                  break;
                 }
                 HEAP32[$L_38>>2] = $136;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $139 = __THREW__; __THREW__ = 0;
                 $140 = $139&1;
                 if ($140) {
                  break;
                 }
                 __THREW__ = 0;
                 $141 = (invoke_iii(2724,(2155952|0),($L_38|0))|0);
                 $142 = __THREW__; __THREW__ = 0;
                 $143 = $142&1;
                 if ($143) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($25|0));
                 $144 = __THREW__; __THREW__ = 0;
                 $145 = $144&1;
                 if ($145) {
                  break;
                 }
                 $146 = HEAP32[$35>>2]|0;
                 $147 = ($146>>>0)<(6);
                 if ($147) {
                  __THREW__ = 0;
                  $148 = (invoke_i(132)|0);
                  $149 = __THREW__; __THREW__ = 0;
                  $150 = $149&1;
                  if ($150) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($148|0));
                  $151 = __THREW__; __THREW__ = 0;
                  $152 = $151&1;
                  if ($152) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($25|0),($141|0));
                 $153 = __THREW__; __THREW__ = 0;
                 $154 = $153&1;
                 if ($154) {
                  break;
                 }
                 $155 = HEAP32[$25>>2]|0;
                 $156 = (($155) + 92|0);
                 $157 = HEAP32[$156>>2]|0;
                 $158 = ($157*5)|0;
                 $159 = (($45) + ($158)|0);
                 HEAP32[$159>>2] = $141;
                 $160 = HEAP32[3020304>>2]|0;
                 __THREW__ = 0;
                 $161 = (invoke_iiii(556,(0|0),($160|0),($25|0))|0);
                 $162 = __THREW__; __THREW__ = 0;
                 $163 = $162&1;
                 if ($163) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2649224|0))|0);
                 $164 = __THREW__; __THREW__ = 0;
                 $165 = $164&1;
                 if ($165) {
                  break;
                 }
                 __THREW__ = 0;
                 $166 = (invoke_ii(3469,(2649224|0))|0);
                 $167 = __THREW__; __THREW__ = 0;
                 $168 = $167&1;
                 if ($168) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vii(1975,($166|0),($161|0));
                 $169 = __THREW__; __THREW__ = 0;
                 $170 = $169&1;
                 if ($170) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3833,($166|0));
                 $171 = __THREW__; __THREW__ = 0;
                 $172 = $171&1;
                 if ($172) {
                  break;
                 }
                 // unreachable;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_iii($__this,$s1,$idx1,$len1,$s2,$idx2,$len2,$options) {
 $__this = $__this|0;
 $s1 = $s1|0;
 $idx1 = $idx1|0;
 $len1 = $len1|0;
 $s2 = $s2|0;
 $idx2 = $idx2|0;
 $len2 = $len2|0;
 $options = $options|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $V_3 = sp + 37|0;
 $V_4 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274992);
 ;HEAP32[$V_2+0>>2]=HEAP32[2275808+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[2275808+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[2275808+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[2275808+12>>2]|0;HEAP32[$V_2+16>>2]=HEAP32[2275808+16>>2]|0;HEAP32[$V_2+20>>2]=HEAP32[2275808+20>>2]|0;HEAP32[$V_2+24>>2]=HEAP32[2275808+24>>2]|0;HEAP32[$V_2+28>>2]=HEAP32[2275808+28>>2]|0;
 HEAP8[$V_3>>0] = 0;
 HEAP8[$V_4>>0] = 0;
 $0 = ($idx1|0)==($idx2|0);
 $1 = ($len1|0)==($len2|0);
 $or$cond = $0 & $1;
 if ($or$cond) {
  __THREW__ = 0;
  $2 = (invoke_iiii(424,(0|0),($s1|0),($s2|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   if ($2) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    label = 5;
   }
  }
 } else {
  label = 5;
 }
 do {
  if ((label|0) == 5) {
   if ((($options|0) == 268435456)) {
    __THREW__ = 0;
    $10 = (invoke_iiiiiiii(76,0,($s1|0),($idx1|0),($len1|0),($s2|0),($idx2|0),($len2|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    } else {
     $$0 = $10;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else if ((($options|0) == 1073741824)) {
    __THREW__ = 0;
    $7 = (invoke_iiiiiiii(75,0,($s1|0),($idx1|0),($len1|0),($s2|0),($idx2|0),($len2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    } else {
     $$0 = $7;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    $13 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
    $14 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
    __THREW__ = 0;
    invoke_viii(554,0,($13|0),4);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(554,0,($14|0),4);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    (invoke_iiiiiiii(77,0,0,0,0,0,0,0)|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    invoke_viiiiiiii(13,($V_2|0),($options|0),(0|0),(0|0),($13|0),($14|0),(0|0),0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    $23 = (invoke_iiiiiiiiiiiii(1,($__this|0),($s1|0),($idx1|0),($len1|0),($s2|0),($idx2|0),($len2|0),($V_3|0),($V_4|0),1,0,($V_2|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    $26 = ($23|0)==(0);
    if ($26) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $27 = $23 >> 31;
    $28 = $27 | 1;
    $$0 = $28;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_QuickCheckPossibleP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_ii($__this,$s1,$idx1,$end1,$s2,$idx2,$end2) {
 $__this = $__this|0;
 $s1 = $s1|0;
 $idx1 = $idx1|0;
 $end1 = $end1|0;
 $s2 = $s2|0;
 $idx2 = $idx2|0;
 $end2 = $end2|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275088);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareInternalP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_iiPbS3_bbP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s1,$idx1,$len1,$s2,$idx2,$len2,$targetConsumed,$sourceConsumed,$skipHeadingExtenders,$immediateBreakup,$ctx) {
 $__this = $__this|0;
 $s1 = $s1|0;
 $idx1 = $idx1|0;
 $len1 = $len1|0;
 $s2 = $s2|0;
 $idx2 = $idx2|0;
 $len2 = $len2|0;
 $targetConsumed = $targetConsumed|0;
 $sourceConsumed = $sourceConsumed|0;
 $skipHeadingExtenders = $skipHeadingExtenders|0;
 $immediateBreakup = $immediateBreakup|0;
 $ctx = $ctx|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$01$phi = 0, $$02$lcssa = 0, $$02340 = 0, $$03 = 0, $$03$phi = 0, $$04332 = 0, $$1 = 0, $$1014145 = 0, $$1071 = 0, $$11 = 0, $$1115 = 0, $$12$lcssa = 0, $$121670 = 0, $$1257 = 0, $$13 = 0, $$1317 = 0, $$13569 = 0;
 var $$13570 = 0, $$1451 = 0, $$15 = 0, $$1518 = 0, $$1518567 = 0, $$1518568 = 0, $$2 = 0, $$2$phi = 0, $$26 = 0, $$26$phi = 0, $$3$lcssa = 0, $$33 = 0, $$37$lcssa = 0, $$3782 = 0, $$394 = 0, $$4 = 0, $$4$in = 0, $$40 = 0, $$48$lcssa = 0, $$4893 = 0;
 var $$5$lcssa = 0, $$5117 = 0, $$59$lcssa = 0, $$59109 = 0, $$6 = 0, $$610124 = 0, $$7 = 0, $$711 = 0, $$8$lcssa = 0, $$812 = 0, $$8138 = 0, $$9 = 0, $$913 = 0, $$V_10$2 = 0, $$V_11$2 = 0, $$V_8$2 = 0, $$V_9$2 = 0, $$lcssa = 0, $$not = 0, $$pre$phiZ2D = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B161_0$0 = 0;
 var $G_B198_0$045 = 0, $G_B81_0$0 = 0, $G_B89_0$0 = 0, $V_1$0 = 0, $V_1$0$phi = 0, $V_10$0 = 0, $V_10$0$phi = 0, $V_10$1 = 0, $V_10$2 = 0, $V_11$0 = 0, $V_11$0$phi = 0, $V_11$1 = 0, $V_11$2 = 0, $V_12$0 = 0, $V_12$0$phi = 0, $V_12$168 = 0, $V_13$0 = 0, $V_13$0$phi = 0, $V_13$167 = 0, $V_14$0 = 0;
 var $V_14$0$phi = 0, $V_14$1 = 0, $V_15$0 = 0, $V_15$0$phi = 0, $V_15$1 = 0, $V_18$sroa$0$0 = 0, $V_18$sroa$0$0$phi = 0, $V_18$sroa$1$0 = 0, $V_18$sroa$1$0$phi = 0, $V_18$sroa$2$0 = 0, $V_18$sroa$2$0$phi = 0, $V_18$sroa$3$0 = 0, $V_18$sroa$3$0$phi = 0, $V_18$sroa$4$0 = 0, $V_18$sroa$4$0$phi = 0, $V_19$sroa$0$0 = 0, $V_19$sroa$0$0$phi = 0, $V_19$sroa$1$0 = 0, $V_19$sroa$1$0$phi = 0, $V_19$sroa$2$0 = 0;
 var $V_19$sroa$2$0$phi = 0, $V_19$sroa$3$0 = 0, $V_19$sroa$3$0$phi = 0, $V_19$sroa$4$0 = 0, $V_19$sroa$4$0$phi = 0, $V_2$0 = 0, $V_2$0$phi = 0, $V_24$0 = 0, $V_24$1 = 0, $V_25$0 = 0, $V_25$1 = 0, $V_26$0 = 0, $V_27$0 = 0, $V_28$0$off0 = 0, $V_28$1$off0 = 0, $V_29$0$off0 = 0, $V_29$1$off0 = 0, $V_3$0 = 0, $V_3$0$phi = 0, $V_32$0 = 0;
 var $V_33$0 = 0, $V_34$0 = 0, $V_35$0 = 0, $V_36$0 = 0, $V_4$0 = 0, $V_4$0$phi = 0, $V_5 = 0, $V_6$0 = 0, $V_6$0$phi = 0, $V_6$169 = 0, $V_6$2 = 0, $V_6$3$ = 0, $V_6$348 = 0, $V_7$0 = 0, $V_7$0$ = 0, $V_7$0$phi = 0, $V_8$0 = 0, $V_8$0$phi = 0, $V_8$1 = 0, $V_8$2 = 0;
 var $V_9$0 = 0, $V_9$0$phi = 0, $V_9$1 = 0, $V_9$2 = 0, $_stackTraceSentry = 0, $brmerge = 0, $lpad$phi$index = 0, $lpad$phi$index17 = 0, $or$cond = 0, $or$cond27 = 0, $or$cond28 = 0, $or$cond29 = 0, $or$cond30 = 0, $or$cond31 = 0, $or$cond32 = 0, $or$cond34 = 0, $or$cond35 = 0, $or$cond36 = 0, $or$cond3666 = 0, $or$cond37 = 0;
 var $or$cond38 = 0, $or$cond39 = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_5 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275136);
 $0 = $V_5;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = HEAP32[$ctx>>2]|0;
 $5 = (($len1) + ($idx1))|0;
 $6 = (($len2) + ($idx2))|0;
 HEAP8[$targetConsumed>>0] = 0;
 HEAP8[$sourceConsumed>>0] = 0;
 __THREW__ = 0;
 invoke_vii(1795,($V_5|0),0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   $9 = ($4|0)==(0);
   if ($9) {
    $44 = (($ctx) + 28|0);
    $45 = HEAP8[$44>>0]|0;
    $46 = ($45<<24>>24)==(0);
    if (!($46)) {
     __THREW__ = 0;
     $47 = (invoke_iiiiiiiiiii(1,($__this|0),($s1|0),($idx1|0),($len1|0),($s2|0),($idx2|0),($len2|0),($sourceConsumed|0),($targetConsumed|0),($immediateBreakup|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     } else {
      $$0 = $47;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   L8: do {
    if ($skipHeadingExtenders) {
     $50 = ($len1|0)>(0);
     L10: do {
      if ($50) {
       $$02340 = $idx1;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($s1|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        __THREW__ = 0;
        $51 = (invoke_iii(621,($s1|0),($$02340|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        $54 = $51&65535;
        __THREW__ = 0;
        $55 = (invoke_iii(802,($__this|0),($54|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
        $58 = ($55|0)==(0);
        $59 = (($$02340) + 1)|0;
        if ($58) {
         $$02$lcssa = $$02340;
         break L10;
        }
        $61 = ($59|0)<($5|0);
        if ($61) {
         $$02340 = $59;
        } else {
         $$02$lcssa = $59;
         break L10;
        }
       }
       $40 = ___cxa_find_matching_catch()|0;
       $41 = tempRet0;
       $lpad$phi$index = $40;$lpad$phi$index17 = $41;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      } else {
       $$02$lcssa = $idx1;
      }
     } while(0);
     $60 = ($len2|0)>(0);
     if ($60) {
      $$04332 = $idx2;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($s2|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       __THREW__ = 0;
       $64 = (invoke_iii(621,($s2|0),($$04332|0))|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        break;
       }
       $67 = $64&65535;
       __THREW__ = 0;
       $68 = (invoke_iii(802,($__this|0),($67|0))|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break;
       }
       $71 = ($68|0)==(0);
       $72 = (($$04332) + 1)|0;
       if ($71) {
        $$1 = $$02$lcssa;$$15 = $$04332;
        break L8;
       }
       $73 = ($72|0)<($6|0);
       if ($73) {
        $$04332 = $72;
       } else {
        $$1 = $$02$lcssa;$$15 = $72;
        break L8;
       }
      }
      $38 = ___cxa_find_matching_catch()|0;
      $39 = tempRet0;
      $lpad$phi$index = $38;$lpad$phi$index17 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     } else {
      $$1 = $$02$lcssa;$$15 = $idx2;
     }
    } else {
     $$1 = $idx1;$$15 = $idx2;
    }
   } while(0);
   $76 = (($ctx) + 20|0);
   $77 = (($ctx) + 24|0);
   $78 = (($V_5) + 4|0);
   $79 = $4 & 536870912;
   $80 = ($79|0)==(0);
   $81 = (($ctx) + 12|0);
   $82 = $4 & 2;
   $83 = ($82|0)!=(0);
   $84 = (($ctx) + 16|0);
   $85 = (($__this) + 12|0);
   $$01 = $s1;$$03 = $s2;$$2 = $$1;$$26 = $$15;$V_1$0 = $idx1;$V_10$0 = 0;$V_11$0 = 0;$V_12$0 = 0;$V_13$0 = 0;$V_14$0 = $$1;$V_15$0 = $$15;$V_18$sroa$0$0 = 0;$V_18$sroa$1$0 = 0;$V_18$sroa$2$0 = 0;$V_18$sroa$3$0 = 0;$V_18$sroa$4$0 = 0;$V_19$sroa$0$0 = 0;$V_19$sroa$1$0 = 0;$V_19$sroa$2$0 = 0;$V_19$sroa$3$0 = 0;$V_19$sroa$4$0 = 0;$V_2$0 = $idx2;$V_3$0 = $5;$V_4$0 = $6;$V_6$0 = 0;$V_7$0 = 5;$V_8$0 = -1;$V_9$0 = -1;
   L31: while(1) {
    $95 = ($$2|0)<($V_3$0|0);
    if ($95) {
     __THREW__ = 0;
     invoke_vi(3799,($$01|0));
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      label = 16;
      break;
     }
     __THREW__ = 0;
     $86 = (invoke_iii(621,($$01|0),($$2|0))|0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      label = 16;
      break;
     }
     $89 = $86&65535;
     __THREW__ = 0;
     $90 = (invoke_iiii(746,0,($89|0),($4|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 16;
      break;
     }
     if ($90) {
      $94 = (($$2) + 1)|0;
      $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_15$0$phi = $V_15$0;$V_14$0$phi = $V_14$0;$V_13$0$phi = $V_13$0;$V_12$0$phi = $V_12$0;$V_11$0$phi = $V_11$0;$V_10$0$phi = $V_10$0;$V_1$0$phi = $V_1$0;$$26$phi = $$26;$$03$phi = $$03;$$01$phi = $$01;$$2 = $94;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_15$0 = $V_15$0$phi;$V_14$0 = $V_14$0$phi;$V_13$0 = $V_13$0$phi;$V_12$0 = $V_12$0$phi;$V_11$0 = $V_11$0$phi;$V_10$0 = $V_10$0$phi;$V_1$0 = $V_1$0$phi;$$26 = $$26$phi;$$03 = $$03$phi;$$01 = $$01$phi;
      continue;
     }
    }
    $93 = ($$26|0)<($V_4$0|0);
    L40: do {
     if ($93) {
      $$3782 = $$26;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($$03|0));
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        label = 6;
        break L31;
       }
       __THREW__ = 0;
       $98 = (invoke_iii(621,($$03|0),($$3782|0))|0);
       $99 = __THREW__; __THREW__ = 0;
       $100 = $99&1;
       if ($100) {
        label = 6;
        break L31;
       }
       $101 = $98&65535;
       __THREW__ = 0;
       $102 = (invoke_iiii(746,0,($101|0),($4|0))|0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        label = 6;
        break L31;
       }
       $105 = (($$3782) + 1)|0;
       if (!($102)) {
        $$37$lcssa = $$3782;$$lcssa = 1;
        break L40;
       }
       $106 = ($105|0)<($V_4$0|0);
       if ($106) {
        $$3782 = $105;
       } else {
        $$37$lcssa = $105;$$lcssa = 0;
        break;
       }
      }
     } else {
      $$37$lcssa = $$26;$$lcssa = 0;
     }
    } while(0);
    if (!($95)) {
     $109 = ($V_18$sroa$0$0|0)==(0|0);
     if ($109) {
      label = 258;
      break;
     } else {
      $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_18$sroa$3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_15$0$phi = $V_15$0;$V_14$0$phi = $V_18$sroa$4$0;$V_13$0$phi = $V_13$0;$V_12$0$phi = $V_12$0;$V_11$0$phi = $V_11$0;$V_10$0$phi = $V_10$0;$V_1$0$phi = $V_18$sroa$2$0;$$2$phi = $V_18$sroa$1$0;$$03$phi = $$03;$$01$phi = $V_18$sroa$0$0;$$26 = $$37$lcssa;$V_18$sroa$0$0 = 0;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_15$0 = $V_15$0$phi;$V_14$0 = $V_14$0$phi;$V_13$0 = $V_13$0$phi;$V_12$0 = $V_12$0$phi;$V_11$0 = $V_11$0$phi;$V_10$0 = $V_10$0$phi;$V_1$0 = $V_1$0$phi;$$2 = $$2$phi;$$03 = $$03$phi;$$01 = $$01$phi;
      continue;
     }
    }
    if (!($$lcssa)) {
     $110 = ($V_19$sroa$0$0|0)==(0|0);
     if ($110) {
      label = 258;
      break;
     } else {
      $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_19$sroa$3$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_19$sroa$2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_15$0$phi = $V_19$sroa$4$0;$V_14$0$phi = $V_14$0;$V_13$0$phi = $V_13$0;$V_12$0$phi = $V_12$0;$V_11$0$phi = $V_11$0;$V_10$0$phi = $V_10$0;$V_1$0$phi = $V_1$0;$$26$phi = $V_19$sroa$1$0;$$2$phi = $$2;$$03$phi = $V_19$sroa$0$0;$$01$phi = $$01;$V_19$sroa$0$0 = 0;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_15$0 = $V_15$0$phi;$V_14$0 = $V_14$0$phi;$V_13$0 = $V_13$0$phi;$V_12$0 = $V_12$0$phi;$V_11$0 = $V_11$0$phi;$V_10$0 = $V_10$0$phi;$V_1$0 = $V_1$0$phi;$$26 = $$26$phi;$$2 = $$2$phi;$$03 = $$03$phi;$$01 = $$01$phi;
      continue;
     }
    }
    $111 = ($V_14$0|0)<($$2|0);
    $112 = ($V_15$0|0)<($$37$lcssa|0);
    $or$cond = $111 & $112;
    L55: do {
     if ($or$cond) {
      $113 = ($$37$lcssa|0)<($V_4$0|0);
      L57: do {
       if ($113) {
        $$394 = $$2;$$4893 = $$37$lcssa;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($$01|0));
         $114 = __THREW__; __THREW__ = 0;
         $115 = $114&1;
         if ($115) {
          label = 7;
          break L31;
         }
         __THREW__ = 0;
         $116 = (invoke_iii(621,($$01|0),($$394|0))|0);
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          label = 7;
          break L31;
         }
         __THREW__ = 0;
         invoke_vi(3799,($$03|0));
         $119 = __THREW__; __THREW__ = 0;
         $120 = $119&1;
         if ($120) {
          label = 7;
          break L31;
         }
         __THREW__ = 0;
         $121 = (invoke_iii(621,($$03|0),($$4893|0))|0);
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 7;
          break L31;
         }
         $124 = ($116<<16>>16)==($121<<16>>16);
         if (!($124)) {
          $$3$lcssa = $$394;$$48$lcssa = $$4893;
          break L57;
         }
         $125 = (($$394) + 1)|0;
         $126 = (($$4893) + 1)|0;
         $127 = ($125|0)<($V_3$0|0);
         $128 = ($126|0)<($V_4$0|0);
         $or$cond27 = $127 & $128;
         if ($or$cond27) {
          $$394 = $125;$$4893 = $126;
         } else {
          $$3$lcssa = $125;$$48$lcssa = $126;
          break;
         }
        }
       } else {
        $$3$lcssa = $$2;$$48$lcssa = $$37$lcssa;
       }
      } while(0);
      $129 = ($$3$lcssa|0)==($V_3$0|0);
      $130 = ($$48$lcssa|0)==($V_4$0|0);
      $or$cond28 = $129 | $130;
      if ($or$cond28) {
       $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_15$0$phi = $V_15$0;$V_14$0$phi = $V_14$0;$V_13$0$phi = $V_13$0;$V_12$0$phi = $V_12$0;$V_11$0$phi = $V_11$0;$V_10$0$phi = $V_10$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$3$lcssa;$$26 = $$48$lcssa;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_15$0 = $V_15$0$phi;$V_14$0 = $V_14$0$phi;$V_13$0 = $V_13$0$phi;$V_12$0 = $V_12$0$phi;$V_11$0 = $V_11$0$phi;$V_10$0 = $V_10$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
       continue L31;
      }
      $131 = (($$48$lcssa) + -1)|0;
      $$4$in = $$3$lcssa;
      while(1) {
       $$4 = (($$4$in) + -1)|0;
       $140 = ($$4|0)>($V_14$0|0);
       if (!($140)) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($$01|0));
       $141 = __THREW__; __THREW__ = 0;
       $142 = $141&1;
       if ($142) {
        label = 8;
        break L31;
       }
       __THREW__ = 0;
       $132 = (invoke_iii(621,($$01|0),($$4|0))|0);
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       if ($134) {
        label = 8;
        break L31;
       }
       $135 = $132&65535;
       __THREW__ = 0;
       $136 = (invoke_iii(799,($__this|0),($135|0))|0);
       $137 = __THREW__; __THREW__ = 0;
       $138 = $137&1;
       if ($138) {
        label = 8;
        break L31;
       }
       $139 = ($136<<24>>24)==(1);
       if ($139) {
        $$4$in = $$4;
       } else {
        break;
       }
      }
      $152 = ($131|0)>($V_15$0|0);
      L75: do {
       if ($152) {
        $$59109 = $131;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($$03|0));
         $154 = __THREW__; __THREW__ = 0;
         $155 = $154&1;
         if ($155) {
          label = 9;
          break L31;
         }
         __THREW__ = 0;
         $143 = (invoke_iii(621,($$03|0),($$59109|0))|0);
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if ($145) {
          label = 9;
          break L31;
         }
         $146 = $143&65535;
         __THREW__ = 0;
         $147 = (invoke_iii(799,($__this|0),($146|0))|0);
         $148 = __THREW__; __THREW__ = 0;
         $149 = $148&1;
         if ($149) {
          label = 9;
          break L31;
         }
         $150 = ($147<<24>>24)==(1);
         $151 = (($$59109) + -1)|0;
         if (!($150)) {
          $$59$lcssa = $$59109;
          break L75;
         }
         $153 = ($151|0)>($V_15$0|0);
         if ($153) {
          $$59109 = $151;
         } else {
          $$59$lcssa = $151;
          break;
         }
        }
       } else {
        $$59$lcssa = $131;
       }
      } while(0);
      L84: do {
       if ($140) {
        $$5117 = $$4;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($$01|0));
         $165 = __THREW__; __THREW__ = 0;
         $166 = $165&1;
         if ($166) {
          label = 10;
          break L31;
         }
         __THREW__ = 0;
         $156 = (invoke_iii(621,($$01|0),($$5117|0))|0);
         $157 = __THREW__; __THREW__ = 0;
         $158 = $157&1;
         if ($158) {
          label = 10;
          break L31;
         }
         $159 = $156&65535;
         __THREW__ = 0;
         $160 = (invoke_iii(803,($__this|0),($159|0))|0);
         $161 = __THREW__; __THREW__ = 0;
         $162 = $161&1;
         if ($162) {
          label = 10;
          break L31;
         }
         $163 = (($$5117) + -1)|0;
         if ($160) {
          $$5$lcssa = $$5117;
          break L84;
         }
         $164 = ($163|0)>($V_14$0|0);
         if ($164) {
          $$5117 = $163;
         } else {
          $$5$lcssa = $163;
          break;
         }
        }
       } else {
        $$5$lcssa = $$4;
       }
      } while(0);
      $175 = ($$59$lcssa|0)>($V_15$0|0);
      if ($175) {
       $$610124 = $$59$lcssa;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($$03|0));
        $177 = __THREW__; __THREW__ = 0;
        $178 = $177&1;
        if ($178) {
         label = 11;
         break L31;
        }
        __THREW__ = 0;
        $167 = (invoke_iii(621,($$03|0),($$610124|0))|0);
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         label = 11;
         break L31;
        }
        $170 = $167&65535;
        __THREW__ = 0;
        $171 = (invoke_iii(803,($__this|0),($170|0))|0);
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         label = 11;
         break L31;
        }
        $174 = (($$610124) + -1)|0;
        if ($171) {
         $$6 = $$5$lcssa;$$711 = $$610124;$$pre$phiZ2D = $$01;$V_14$1 = $$3$lcssa;$V_15$1 = $$48$lcssa;
         break L55;
        }
        $176 = ($174|0)>($V_15$0|0);
        if ($176) {
         $$610124 = $174;
        } else {
         $$6 = $$5$lcssa;$$711 = $174;$$pre$phiZ2D = $$01;$V_14$1 = $$3$lcssa;$V_15$1 = $$48$lcssa;
         break;
        }
       }
      } else {
       $$6 = $$5$lcssa;$$711 = $$59$lcssa;$$pre$phiZ2D = $$01;$V_14$1 = $$3$lcssa;$V_15$1 = $$48$lcssa;
      }
     } else {
      $$6 = $$2;$$711 = $$37$lcssa;$$pre$phiZ2D = $$01;$V_14$1 = $V_14$0;$V_15$1 = $V_15$0;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vi(3799,($$pre$phiZ2D|0));
    $179 = __THREW__; __THREW__ = 0;
    $180 = $179&1;
    if ($180) {
     label = 16;
     break;
    }
    __THREW__ = 0;
    $181 = (invoke_iii(621,($$01|0),($$6|0))|0);
    $182 = __THREW__; __THREW__ = 0;
    $183 = $182&1;
    if ($183) {
     label = 16;
     break;
    }
    $184 = $181&65535;
    __THREW__ = 0;
    $185 = (invoke_iiii(743,($__this|0),($184|0),($4|0))|0);
    $186 = __THREW__; __THREW__ = 0;
    $187 = $186&1;
    if ($187) {
     label = 16;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($$03|0));
    $188 = __THREW__; __THREW__ = 0;
    $189 = $188&1;
    if ($189) {
     label = 16;
     break;
    }
    __THREW__ = 0;
    $190 = (invoke_iii(621,($$03|0),($$711|0))|0);
    $191 = __THREW__; __THREW__ = 0;
    $192 = $191&1;
    if ($192) {
     label = 16;
     break;
    }
    $193 = $190&65535;
    __THREW__ = 0;
    $194 = (invoke_iiii(743,($__this|0),($193|0),($4|0))|0);
    $195 = __THREW__; __THREW__ = 0;
    $196 = $195&1;
    if ($196) {
     label = 16;
     break;
    }
    __THREW__ = 0;
    $197 = (invoke_iii(802,($__this|0),($185|0))|0);
    $198 = __THREW__; __THREW__ = 0;
    $199 = $198&1;
    if ($199) {
     label = 16;
     break;
    }
    $200 = ($197|0)!=(0);
    do {
     if ($200) {
      $201 = HEAP32[$76>>2]|0;
      $202 = ($201|0)>(-1);
      if ($202) {
       __THREW__ = 0;
       $206 = (invoke_iiiii(124,($__this|0),($201|0),($197|0),($4|0))|0);
       $207 = __THREW__; __THREW__ = 0;
       $208 = $207&1;
       if ($208) {
        label = 16;
        break L31;
       } else {
        $V_24$0 = 0;$V_26$0 = $206;
        break;
       }
      }
      $203 = HEAP32[$77>>2]|0;
      $204 = ($203|0)==(0|0);
      if (!($204)) {
       $V_24$0 = $203;$V_26$0 = $185;
       break;
      }
      $205 = (($$6) + 1)|0;
      $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_13$0$phi = $V_13$0;$V_11$0$phi = $V_11$0;$V_10$0$phi = $V_10$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $205;$$26 = $$711;$V_12$0 = $197;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_13$0 = $V_13$0$phi;$V_11$0 = $V_11$0$phi;$V_10$0 = $V_10$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
      continue L31;
     } else {
      $V_24$0 = 0;$V_26$0 = $185;
     }
    } while(0);
    __THREW__ = 0;
    $209 = (invoke_iii(802,($__this|0),($194|0))|0);
    $210 = __THREW__; __THREW__ = 0;
    $211 = $210&1;
    if ($211) {
     label = 16;
     break;
    }
    $212 = ($209|0)!=(0);
    do {
     if ($212) {
      $213 = HEAP32[$V_5>>2]|0;
      $214 = ($213|0)>(-1);
      if ($214) {
       __THREW__ = 0;
       $218 = (invoke_iiiii(124,($__this|0),($213|0),($209|0),($4|0))|0);
       $219 = __THREW__; __THREW__ = 0;
       $220 = $219&1;
       if ($220) {
        label = 16;
        break L31;
       } else {
        $V_25$0 = 0;$V_27$0 = $218;
        break;
       }
      }
      $215 = HEAP32[$78>>2]|0;
      $216 = ($215|0)==(0|0);
      if (!($216)) {
       $V_25$0 = $215;$V_27$0 = $194;
       break;
      }
      $217 = (($$711) + 1)|0;
      $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_11$0$phi = $V_11$0;$V_10$0$phi = $V_10$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$6;$$26 = $217;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_11$0 = $V_11$0$phi;$V_10$0 = $V_10$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
      continue L31;
     } else {
      $V_25$0 = 0;$V_27$0 = $194;
     }
    } while(0);
    __THREW__ = 0;
    $221 = (invoke_iii(799,($__this|0),($V_26$0|0))|0);
    $222 = __THREW__; __THREW__ = 0;
    $223 = $222&1;
    if ($223) {
     label = 16;
     break;
    }
    __THREW__ = 0;
    $224 = (invoke_iii(799,($__this|0),($V_27$0|0))|0);
    $225 = __THREW__; __THREW__ = 0;
    $226 = $225&1;
    if ($226) {
     label = 16;
     break;
    }
    $227 = ($221<<24>>24)==(6);
    if ($227) {
     $228 = ($V_7$0|0)==(5);
     $or$cond29 = $80 & $228;
     if ($or$cond29) {
      $229 = ($V_18$sroa$0$0|0)==(0|0);
      $230 = (($V_18$sroa$1$0) - ($V_18$sroa$2$0))|0;
      $231 = (($$6) - ($V_1$0))|0;
      $G_B81_0$0 = $229 ? $231 : $230;
      __THREW__ = 0;
      $232 = (invoke_iii(800,($__this|0),($V_26$0|0))|0);
      $233 = __THREW__; __THREW__ = 0;
      $234 = $233&1;
      if ($234) {
       label = 16;
       break;
      }
      __THREW__ = 0;
      $235 = (invoke_iii(789,(0|0),($V_26$0|0))|0);
      $236 = __THREW__; __THREW__ = 0;
      $237 = $236&1;
      if ($237) {
       label = 16;
       break;
      }
      $238 = $235&255;
      $239 = (($238) + 8)|0;
      $240 = $239 & 31;
      $241 = $232&255;
      $242 = $241 << $240;
      $V_10$1 = $242;$V_8$1 = $G_B81_0$0;
     } else {
      $V_10$1 = $V_10$0;$V_8$1 = $V_8$0;
     }
     HEAP32[$76>>2] = $V_26$0;
     $243 = (($$6) + 1)|0;
     $$7 = $243;$V_10$2 = $V_10$1;$V_8$2 = $V_8$1;
    } else {
     $$7 = $$6;$V_10$2 = $V_10$0;$V_8$2 = $V_8$0;
    }
    $244 = ($224<<24>>24)!=(6);
    if ($244) {
     $$812 = $$711;$V_11$2 = $V_11$0;$V_9$2 = $V_9$0;
    } else {
     $245 = ($V_7$0|0)==(5);
     $or$cond30 = $80 & $245;
     if ($or$cond30) {
      $246 = ($V_19$sroa$0$0|0)==(0|0);
      $247 = (($V_19$sroa$1$0) - ($V_19$sroa$2$0))|0;
      $248 = (($$711) - ($V_2$0))|0;
      $G_B89_0$0 = $246 ? $248 : $247;
      __THREW__ = 0;
      $249 = (invoke_iii(800,($__this|0),($V_27$0|0))|0);
      $250 = __THREW__; __THREW__ = 0;
      $251 = $250&1;
      if ($251) {
       label = 16;
       break;
      }
      __THREW__ = 0;
      $252 = (invoke_iii(789,(0|0),($V_27$0|0))|0);
      $253 = __THREW__; __THREW__ = 0;
      $254 = $253&1;
      if ($254) {
       label = 16;
       break;
      }
      $255 = $252&255;
      $256 = (($255) + 8)|0;
      $257 = $256 & 31;
      $258 = $249&255;
      $259 = $258 << $257;
      $V_11$1 = $259;$V_9$1 = $G_B89_0$0;
     } else {
      $V_11$1 = $V_11$0;$V_9$1 = $V_9$0;
     }
     HEAP32[$V_5>>2] = $V_27$0;
     $260 = (($$711) + 1)|0;
     $$812 = $260;$V_11$2 = $V_11$1;$V_9$2 = $V_9$1;
    }
    $$not = $244 ^ 1;
    $brmerge = $227 | $$not;
    if ($brmerge) {
     $261 = ($V_7$0|0)==(5);
     if (!($261)) {
      $V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$7;$$26 = $$812;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
      continue;
     }
     $262 = ($V_10$2|0)==($V_11$2|0);
     $$V_11$2 = $262 ? 0 : $V_11$2;
     $$V_10$2 = $262 ? 0 : $V_10$2;
     $$V_9$2 = $262 ? -1 : $V_9$2;
     $$V_8$2 = $262 ? -1 : $V_8$2;
     $V_7$0$ = $262 ? 5 : 4;
     $V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$7;$$26 = $$812;$V_10$0 = $$V_10$2;$V_11$0 = $$V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_7$0 = $V_7$0$;$V_8$0 = $$V_8$2;$V_9$0 = $$V_9$2;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
     continue;
    }
    if ($200) {
     $V_32$0 = 0;
    } else {
     __THREW__ = 0;
     $263 = (invoke_iiiii(122,($__this|0),($$01|0),($$7|0),($V_3$0|0))|0);
     $264 = __THREW__; __THREW__ = 0;
     $265 = $264&1;
     if ($265) {
      label = 16;
      break;
     } else {
      $V_32$0 = $263;
     }
    }
    $266 = ($V_24$0|0)==(0|0);
    do {
     if ($266) {
      $267 = ($V_32$0|0)==(0|0);
      if ($267) {
       $330 = HEAP32[$81>>2]|0;
       HEAP8[$330>>0] = $221;
       __THREW__ = 0;
       $331 = (invoke_iii(800,($__this|0),($V_26$0|0))|0);
       $332 = __THREW__; __THREW__ = 0;
       $333 = $332&1;
       if ($333) {
        label = 16;
        break L31;
       }
       $334 = (($330) + 1|0);
       HEAP8[$334>>0] = $331;
       $335 = ($V_7$0>>>0)<(2);
       $or$cond31 = $83 | $335;
       if (!($or$cond31)) {
        __THREW__ = 0;
        $336 = (invoke_iiii(740,($__this|0),($V_26$0|0),($197|0))|0);
        $337 = __THREW__; __THREW__ = 0;
        $338 = $337&1;
        if ($338) {
         label = 16;
         break L31;
        }
        $339 = (($330) + 2|0);
        HEAP8[$339>>0] = $336;
       }
       $340 = ($V_7$0>>>0)<(3);
       do {
        if ($340) {
         $V_28$0$off0 = 0;
        } else {
         __THREW__ = 0;
         $341 = (invoke_iii(789,(0|0),($V_26$0|0))|0);
         $342 = __THREW__; __THREW__ = 0;
         $343 = $342&1;
         if ($343) {
          label = 16;
          break L31;
         }
         $344 = (($330) + 3|0);
         HEAP8[$344>>0] = $341;
         $345 = ($V_7$0>>>0)<(4);
         if ($345) {
          $V_28$0$off0 = 0;
          break;
         }
         $346 = $V_26$0&65535;
         __THREW__ = 0;
         $347 = (invoke_iii(793,(0|0),($346|0))|0);
         $348 = __THREW__; __THREW__ = 0;
         $349 = $348&1;
         if ($349) {
          label = 16;
          break L31;
         } else {
          $V_28$0$off0 = $347;
         }
        }
       } while(0);
       $350 = ($221&255)<(2);
       if ($350) {
        $V_24$1 = $330;$V_28$1$off0 = $V_28$0$off0;$V_33$0 = 1;
        break;
       }
       HEAP32[$76>>2] = $V_26$0;
       $V_24$1 = $330;$V_28$1$off0 = $V_28$0$off0;$V_33$0 = 1;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($V_32$0|0));
      $268 = __THREW__; __THREW__ = 0;
      $269 = $268&1;
      if ($269) {
       label = 16;
       break L31;
      }
      $270 = (($V_32$0) + 8|0);
      $271 = HEAP32[$270>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($271|0));
      $272 = __THREW__; __THREW__ = 0;
      $273 = $272&1;
      if ($273) {
       label = 16;
       break L31;
      }
      $274 = (($271) + 12|0);
      $275 = HEAP32[$274>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($V_32$0|0));
      $276 = __THREW__; __THREW__ = 0;
      $277 = $276&1;
      if ($277) {
       label = 16;
       break L31;
      }
      $278 = (($V_32$0) + 16|0);
      $279 = HEAP32[$278>>2]|0;
      $280 = ($279|0)==(0|0);
      if ($280) {
       $312 = ($V_18$sroa$0$0|0)==(0|0);
       if (!($312)) {
        $V_24$1 = 0;$V_28$1$off0 = 0;$V_33$0 = $275;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_32$0|0));
       $313 = __THREW__; __THREW__ = 0;
       $314 = $313&1;
       if ($314) {
        label = 16;
        break L31;
       }
       $315 = HEAP32[$270>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($315|0));
       $316 = __THREW__; __THREW__ = 0;
       $317 = $316&1;
       if ($317) {
        label = 16;
        break L31;
       }
       $318 = (($315) + 12|0);
       $319 = HEAP32[$318>>2]|0;
       $320 = (($319) + ($$6))|0;
       __THREW__ = 0;
       invoke_vi(3799,($V_32$0|0));
       $321 = __THREW__; __THREW__ = 0;
       $322 = $321&1;
       if ($322) {
        label = 16;
        break L31;
       }
       $323 = (($V_32$0) + 12|0);
       $324 = HEAP32[$323>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($324|0));
       $325 = __THREW__; __THREW__ = 0;
       $326 = $325&1;
       if ($326) {
        label = 16;
        break L31;
       }
       __THREW__ = 0;
       $327 = (invoke_ii(1816,($324|0))|0);
       $328 = __THREW__; __THREW__ = 0;
       $329 = $328&1;
       if ($329) {
        label = 16;
        break L31;
       } else {
        $V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$3$0$phi = $V_3$0;$V_18$sroa$2$0$phi = $V_1$0;$V_18$sroa$0$0$phi = $$01;$$03$phi = $$03;$$01 = $324;$$2 = 0;$$26 = $$812;$V_1$0 = 0;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = 0;$V_15$0 = $V_15$1;$V_18$sroa$1$0 = $320;$V_18$sroa$4$0 = $V_14$1;$V_3$0 = $327;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$$03 = $$03$phi;
        continue L31;
       }
      }
      $281 = HEAP32[$81>>2]|0;
      $V_34$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($V_32$0|0));
       $302 = __THREW__; __THREW__ = 0;
       $303 = $302&1;
       if ($303) {
        label = 12;
        break L31;
       }
       $304 = HEAP32[$278>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($304|0));
       $305 = __THREW__; __THREW__ = 0;
       $306 = $305&1;
       if ($306) {
        label = 12;
        break L31;
       }
       $307 = (($304) + 12|0);
       $308 = HEAP32[$307>>2]|0;
       $309 = ($V_34$0|0)<($308|0);
       if (!($309)) {
        break;
       }
       $300 = (($281) + ($V_34$0)|0);
       __THREW__ = 0;
       invoke_vi(3799,($V_32$0|0));
       $310 = __THREW__; __THREW__ = 0;
       $311 = $310&1;
       if ($311) {
        label = 12;
        break L31;
       }
       $282 = HEAP32[$278>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($282|0));
       $283 = __THREW__; __THREW__ = 0;
       $284 = $283&1;
       if ($284) {
        label = 12;
        break L31;
       }
       $285 = (($282) + 12|0);
       $286 = HEAP32[$285>>2]|0;
       $287 = ($V_34$0>>>0)<($286>>>0);
       if (!($287)) {
        __THREW__ = 0;
        $288 = (invoke_i(132)|0);
        $289 = __THREW__; __THREW__ = 0;
        $290 = $289&1;
        if ($290) {
         label = 12;
         break L31;
        }
        __THREW__ = 0;
        invoke_vi(3302,($288|0));
        $291 = __THREW__; __THREW__ = 0;
        $292 = $291&1;
        if ($292) {
         label = 12;
         break L31;
        }
       }
       $293 = HEAP32[$282>>2]|0;
       $294 = (($282) + 16|0);
       $295 = (($293) + 92|0);
       $296 = HEAP32[$295>>2]|0;
       $297 = Math_imul($296, $V_34$0)|0;
       $298 = (($294) + ($297)|0);
       $299 = HEAP8[$298>>0]|0;
       HEAP8[$300>>0] = $299;
       $301 = (($V_34$0) + 1)|0;
       $V_34$0 = $301;
      }
      HEAP32[$76>>2] = -1;
      HEAP32[$77>>2] = $281;
      $V_24$1 = $281;$V_28$1$off0 = 0;$V_33$0 = $275;
     } else {
      $V_24$1 = $V_24$0;$V_28$1$off0 = 0;$V_33$0 = 1;
     }
    } while(0);
    if ($212) {
     $V_35$0 = 0;
    } else {
     __THREW__ = 0;
     $351 = (invoke_iiiii(122,($__this|0),($$03|0),($$812|0),($V_4$0|0))|0);
     $352 = __THREW__; __THREW__ = 0;
     $353 = $352&1;
     if ($353) {
      label = 16;
      break;
     } else {
      $V_35$0 = $351;
     }
    }
    $354 = ($V_25$0|0)==(0|0);
    do {
     if ($354) {
      $356 = ($V_35$0|0)==(0|0);
      if ($356) {
       $420 = HEAP32[$84>>2]|0;
       HEAP8[$420>>0] = $224;
       __THREW__ = 0;
       $421 = (invoke_iii(800,($__this|0),($V_27$0|0))|0);
       $422 = __THREW__; __THREW__ = 0;
       $423 = $422&1;
       if ($423) {
        label = 16;
        break L31;
       }
       $424 = (($420) + 1|0);
       HEAP8[$424>>0] = $421;
       $425 = ($V_7$0>>>0)<(2);
       $or$cond32 = $83 | $425;
       if (!($or$cond32)) {
        __THREW__ = 0;
        $426 = (invoke_iiii(740,($__this|0),($V_27$0|0),($209|0))|0);
        $427 = __THREW__; __THREW__ = 0;
        $428 = $427&1;
        if ($428) {
         label = 16;
         break L31;
        }
        $429 = (($420) + 2|0);
        HEAP8[$429>>0] = $426;
       }
       $430 = ($V_7$0>>>0)<(3);
       do {
        if ($430) {
         $V_29$0$off0 = 0;
        } else {
         __THREW__ = 0;
         $431 = (invoke_iii(789,(0|0),($V_27$0|0))|0);
         $432 = __THREW__; __THREW__ = 0;
         $433 = $432&1;
         if ($433) {
          label = 16;
          break L31;
         }
         $434 = (($420) + 3|0);
         HEAP8[$434>>0] = $431;
         $435 = ($V_7$0>>>0)<(4);
         if ($435) {
          $V_29$0$off0 = 0;
          break;
         }
         $436 = $V_27$0&65535;
         __THREW__ = 0;
         $437 = (invoke_iii(793,(0|0),($436|0))|0);
         $438 = __THREW__; __THREW__ = 0;
         $439 = $438&1;
         if ($439) {
          label = 16;
          break L31;
         } else {
          $V_29$0$off0 = $437;
         }
        }
       } while(0);
       $440 = ($224&255)<(2);
       if (!($440)) {
        HEAP32[$V_5>>2] = $V_27$0;
       }
       $441 = (($$812) + 1)|0;
       $$913 = $441;$V_25$1 = $420;$V_29$1$off0 = $V_29$0$off0;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($V_35$0|0));
      $357 = __THREW__; __THREW__ = 0;
      $358 = $357&1;
      if ($358) {
       label = 16;
       break L31;
      }
      $359 = (($V_35$0) + 8|0);
      $360 = HEAP32[$359>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($360|0));
      $361 = __THREW__; __THREW__ = 0;
      $362 = $361&1;
      if ($362) {
       label = 16;
       break L31;
      }
      $363 = (($360) + 12|0);
      $364 = HEAP32[$363>>2]|0;
      $365 = (($364) + ($$812))|0;
      __THREW__ = 0;
      invoke_vi(3799,($V_35$0|0));
      $366 = __THREW__; __THREW__ = 0;
      $367 = $366&1;
      if ($367) {
       label = 16;
       break L31;
      }
      $368 = (($V_35$0) + 16|0);
      $369 = HEAP32[$368>>2]|0;
      $370 = ($369|0)==(0|0);
      if ($370) {
       $402 = ($V_19$sroa$0$0|0)==(0|0);
       if (!($402)) {
        $$913 = $365;$V_25$1 = 0;$V_29$1$off0 = 0;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_35$0|0));
       $403 = __THREW__; __THREW__ = 0;
       $404 = $403&1;
       if ($404) {
        label = 16;
        break L31;
       }
       $405 = HEAP32[$359>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($405|0));
       $406 = __THREW__; __THREW__ = 0;
       $407 = $406&1;
       if ($407) {
        label = 16;
        break L31;
       }
       $408 = (($405) + 12|0);
       $409 = HEAP32[$408>>2]|0;
       $410 = (($409) + ($$711))|0;
       __THREW__ = 0;
       invoke_vi(3799,($V_35$0|0));
       $411 = __THREW__; __THREW__ = 0;
       $412 = $411&1;
       if ($412) {
        label = 16;
        break L31;
       }
       $413 = (($V_35$0) + 12|0);
       $414 = HEAP32[$413>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($414|0));
       $415 = __THREW__; __THREW__ = 0;
       $416 = $415&1;
       if ($416) {
        label = 16;
        break L31;
       }
       __THREW__ = 0;
       $417 = (invoke_ii(1816,($414|0))|0);
       $418 = __THREW__; __THREW__ = 0;
       $419 = $418&1;
       if ($419) {
        label = 16;
        break L31;
       } else {
        $V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_3$0$phi = $V_3$0;$V_19$sroa$3$0$phi = $V_4$0;$V_19$sroa$2$0$phi = $V_2$0;$V_19$sroa$0$0$phi = $$03;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$01$phi = $$01;$$03 = $414;$$2 = $$7;$$26 = 0;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = 0;$V_19$sroa$1$0 = $410;$V_19$sroa$4$0 = $V_15$1;$V_2$0 = 0;$V_4$0 = $417;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_3$0 = $V_3$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$01 = $$01$phi;
        continue L31;
       }
      }
      $371 = HEAP32[$84>>2]|0;
      $V_36$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($V_35$0|0));
       $392 = __THREW__; __THREW__ = 0;
       $393 = $392&1;
       if ($393) {
        label = 13;
        break L31;
       }
       $394 = HEAP32[$368>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($394|0));
       $395 = __THREW__; __THREW__ = 0;
       $396 = $395&1;
       if ($396) {
        label = 13;
        break L31;
       }
       $397 = (($394) + 12|0);
       $398 = HEAP32[$397>>2]|0;
       $399 = ($V_36$0|0)<($398|0);
       if (!($399)) {
        break;
       }
       $390 = (($371) + ($V_36$0)|0);
       __THREW__ = 0;
       invoke_vi(3799,($V_35$0|0));
       $400 = __THREW__; __THREW__ = 0;
       $401 = $400&1;
       if ($401) {
        label = 13;
        break L31;
       }
       $372 = HEAP32[$368>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($372|0));
       $373 = __THREW__; __THREW__ = 0;
       $374 = $373&1;
       if ($374) {
        label = 13;
        break L31;
       }
       $375 = (($372) + 12|0);
       $376 = HEAP32[$375>>2]|0;
       $377 = ($V_36$0>>>0)<($376>>>0);
       if (!($377)) {
        __THREW__ = 0;
        $378 = (invoke_i(132)|0);
        $379 = __THREW__; __THREW__ = 0;
        $380 = $379&1;
        if ($380) {
         label = 13;
         break L31;
        }
        __THREW__ = 0;
        invoke_vi(3302,($378|0));
        $381 = __THREW__; __THREW__ = 0;
        $382 = $381&1;
        if ($382) {
         label = 13;
         break L31;
        }
       }
       $383 = HEAP32[$372>>2]|0;
       $384 = (($372) + 16|0);
       $385 = (($383) + 92|0);
       $386 = HEAP32[$385>>2]|0;
       $387 = Math_imul($386, $V_36$0)|0;
       $388 = (($384) + ($387)|0);
       $389 = HEAP8[$388>>0]|0;
       HEAP8[$390>>0] = $389;
       $391 = (($V_36$0) + 1)|0;
       $V_36$0 = $391;
      }
      HEAP32[$V_5>>2] = -1;
      HEAP32[$78>>2] = $371;
      $$913 = $365;$V_25$1 = $371;$V_29$1$off0 = 0;
     } else {
      $355 = (($$812) + 1)|0;
      $$913 = $355;$V_25$1 = $V_25$0;$V_29$1$off0 = 0;
     }
    } while(0);
    $442 = (($V_33$0) + ($$7))|0;
    L234: do {
     if ($83) {
      $$1115 = $$913;$$9 = $442;
     } else {
      $443 = ($442|0)<($V_3$0|0);
      L236: do {
       if ($443) {
        $444 = (($V_24$1) + 2|0);
        $$8138 = $442;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($$pre$phiZ2D|0));
         $471 = __THREW__; __THREW__ = 0;
         $472 = $471&1;
         if ($472) {
          label = 14;
          break L31;
         }
         __THREW__ = 0;
         $445 = (invoke_iii(621,($$01|0),($$8138|0))|0);
         $446 = __THREW__; __THREW__ = 0;
         $447 = $446&1;
         if ($447) {
          label = 14;
          break L31;
         }
         $448 = $445&65535;
         __THREW__ = 0;
         $449 = (invoke_iii(799,($__this|0),($448|0))|0);
         $450 = __THREW__; __THREW__ = 0;
         $451 = $450&1;
         if ($451) {
          label = 14;
          break L31;
         }
         $452 = ($449<<24>>24)==(1);
         if (!($452)) {
          $$8$lcssa = $$8138;
          break L236;
         }
         $453 = HEAP8[$444>>0]|0;
         $454 = ($453<<24>>24)==(0);
         if ($454) {
          HEAP8[$444>>0] = 2;
          $456 = 2;
         } else {
          $456 = $453;
         }
         $455 = $456&255;
         __THREW__ = 0;
         invoke_vi(3799,($$pre$phiZ2D|0));
         $457 = __THREW__; __THREW__ = 0;
         $458 = $457&1;
         if ($458) {
          label = 14;
          break L31;
         }
         __THREW__ = 0;
         $459 = (invoke_iii(621,($$01|0),($$8138|0))|0);
         $460 = __THREW__; __THREW__ = 0;
         $461 = $460&1;
         if ($461) {
          label = 14;
          break L31;
         }
         $462 = $459&65535;
         __THREW__ = 0;
         $463 = (invoke_iiii(740,($__this|0),($462|0),0)|0);
         $464 = __THREW__; __THREW__ = 0;
         $465 = $464&1;
         if ($465) {
          label = 14;
          break L31;
         }
         $466 = $463&255;
         $467 = (($466) + ($455))|0;
         $468 = $467&255;
         HEAP8[$444>>0] = $468;
         $469 = (($$8138) + 1)|0;
         $470 = ($469|0)<($V_3$0|0);
         if ($470) {
          $$8138 = $469;
         } else {
          $$8$lcssa = $469;
          break;
         }
        }
       } else {
        $$8$lcssa = $442;
       }
      } while(0);
      $500 = ($$913|0)<($V_4$0|0);
      if (!($500)) {
       $$1115 = $$913;$$9 = $$8$lcssa;
       break;
      }
      $482 = (($V_25$1) + 2|0);
      $$1014145 = $$913;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($$03|0));
       $501 = __THREW__; __THREW__ = 0;
       $502 = $501&1;
       if ($502) {
        label = 15;
        break L31;
       }
       __THREW__ = 0;
       $473 = (invoke_iii(621,($$03|0),($$1014145|0))|0);
       $474 = __THREW__; __THREW__ = 0;
       $475 = $474&1;
       if ($475) {
        label = 15;
        break L31;
       }
       $476 = $473&65535;
       __THREW__ = 0;
       $477 = (invoke_iii(799,($__this|0),($476|0))|0);
       $478 = __THREW__; __THREW__ = 0;
       $479 = $478&1;
       if ($479) {
        label = 15;
        break L31;
       }
       $480 = ($477<<24>>24)==(1);
       if (!($480)) {
        $$1115 = $$1014145;$$9 = $$8$lcssa;
        break L234;
       }
       $481 = HEAP8[$482>>0]|0;
       $483 = ($481<<24>>24)==(0);
       if ($483) {
        HEAP8[$482>>0] = 2;
        $485 = 2;
       } else {
        $485 = $481;
       }
       $484 = $485&255;
       __THREW__ = 0;
       invoke_vi(3799,($$03|0));
       $486 = __THREW__; __THREW__ = 0;
       $487 = $486&1;
       if ($487) {
        label = 15;
        break L31;
       }
       __THREW__ = 0;
       $488 = (invoke_iii(621,($$03|0),($$1014145|0))|0);
       $489 = __THREW__; __THREW__ = 0;
       $490 = $489&1;
       if ($490) {
        label = 15;
        break L31;
       }
       $491 = $488&65535;
       __THREW__ = 0;
       $492 = (invoke_iiii(740,($__this|0),($491|0),0)|0);
       $493 = __THREW__; __THREW__ = 0;
       $494 = $493&1;
       if ($494) {
        label = 15;
        break L31;
       }
       $495 = $492&255;
       $496 = (($495) + ($484))|0;
       $497 = $496&255;
       HEAP8[$482>>0] = $497;
       $498 = (($$1014145) + 1)|0;
       $499 = ($498|0)<($V_4$0|0);
       if ($499) {
        $$1014145 = $498;
       } else {
        $$1115 = $498;$$9 = $$8$lcssa;
        break;
       }
      }
     }
    } while(0);
    $503 = HEAP8[$V_24$1>>0]|0;
    $504 = HEAP8[$V_25$1>>0]|0;
    $505 = ($503<<24>>24)==($504<<24>>24);
    if ($505) {
     $509 = (($V_24$1) + 1|0);
     $510 = HEAP8[$509>>0]|0;
     $511 = $510&255;
     $512 = (($V_25$1) + 1|0);
     $513 = HEAP8[$512>>0]|0;
     $514 = $513&255;
     $515 = (($511) - ($514))|0;
     $G_B161_0$0 = $515;
    } else {
     $506 = $503&255;
     $507 = $504&255;
     $508 = (($506) - ($507))|0;
     $G_B161_0$0 = $508;
    }
    $516 = ($G_B161_0$0|0)==(0);
    if (!($516)) {
     $$0 = $G_B161_0$0;
     label = 304;
     break;
    }
    $517 = ($V_7$0|0)==(1);
    if ($517) {
     $V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_7$0 = 1;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
     continue;
    }
    do {
     if (!($83)) {
      $518 = (($V_24$1) + 2|0);
      $519 = HEAP8[$518>>0]|0;
      $520 = $519&255;
      $521 = (($V_25$1) + 2|0);
      $522 = HEAP8[$521>>0]|0;
      $523 = $522&255;
      $524 = (($520) - ($523))|0;
      $525 = ($519<<24>>24)==($522<<24>>24);
      if ($525) {
       break;
      }
      if ($immediateBreakup) {
       $$0 = -1;
       label = 304;
       break L31;
      }
      $526 = HEAP8[$85>>0]|0;
      $527 = ($526<<24>>24)==(0);
      $$ = $527 ? 1 : 2;
      $V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_6$0 = $524;$V_7$0 = $$;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
      continue L31;
     }
    } while(0);
    $528 = ($V_7$0|0)==(2);
    if ($528) {
     $V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_7$0 = 2;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
     continue;
    }
    $529 = (($V_24$1) + 3|0);
    $530 = HEAP8[$529>>0]|0;
    $531 = (($V_25$1) + 3|0);
    $532 = HEAP8[$531>>0]|0;
    $533 = ($530<<24>>24)==($532<<24>>24);
    if (!($533)) {
     $534 = $532&255;
     $535 = $530&255;
     $536 = (($535) - ($534))|0;
     if ($immediateBreakup) {
      $$0 = -1;
      label = 304;
      break;
     } else {
      $V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_6$0 = $536;$V_7$0 = 2;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
      continue;
     }
    }
    $537 = ($V_7$0|0)==(3);
    if ($537) {
     $V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_7$0 = 3;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
     continue;
    }
    $tmp = $V_28$1$off0 ^ $V_29$1$off0;
    if ($tmp) {
     if ($immediateBreakup) {
      $$0 = -1;
      label = 304;
      break;
     }
     $$33 = $V_28$1$off0 ? 1 : -1;
     $V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_6$0 = $$33;$V_7$0 = 3;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
     continue;
    }
    if (!($V_28$1$off0)) {
     $V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
     continue;
    }
    $538 = $V_26$0&65535;
    __THREW__ = 0;
    $539 = (invoke_iii(796,(0|0),($538|0))|0);
    $540 = __THREW__; __THREW__ = 0;
    $541 = $540&1;
    if ($541) {
     label = 16;
     break;
    }
    $542 = $V_27$0&65535;
    __THREW__ = 0;
    $543 = (invoke_iii(796,(0|0),($542|0))|0);
    $544 = __THREW__; __THREW__ = 0;
    $545 = $544&1;
    if ($545) {
     label = 16;
     break;
    }
    $546 = $539 ^ 1;
    $547 = $543 ^ 1;
    __THREW__ = 0;
    $548 = (invoke_iiii(754,0,($546|0),($547|0))|0);
    $549 = __THREW__; __THREW__ = 0;
    $550 = $549&1;
    if ($550) {
     label = 16;
     break;
    }
    $551 = ($548|0)==(0);
    do {
     if ($551) {
      __THREW__ = 0;
      $552 = (invoke_iiii(745,0,($197|0),($4|0))|0);
      $553 = __THREW__; __THREW__ = 0;
      $554 = $553&1;
      if ($554) {
       label = 16;
       break L31;
      }
      __THREW__ = 0;
      $555 = (invoke_iiii(745,0,($209|0),($4|0))|0);
      $556 = __THREW__; __THREW__ = 0;
      $557 = $556&1;
      if ($557) {
       label = 16;
       break L31;
      }
      $558 = $552&255;
      $559 = $555&255;
      $560 = (($558) - ($559))|0;
      $561 = $560 & 255;
      $562 = ($561|0)==(0);
      if (!($562)) {
       $G_B198_0$045 = $561;
       break;
      }
      __THREW__ = 0;
      $563 = (invoke_iii(795,(0|0),($538|0))|0);
      $564 = __THREW__; __THREW__ = 0;
      $565 = $564&1;
      if ($565) {
       label = 16;
       break L31;
      }
      __THREW__ = 0;
      $566 = (invoke_iii(795,(0|0),($542|0))|0);
      $567 = __THREW__; __THREW__ = 0;
      $568 = $567&1;
      if ($568) {
       label = 16;
       break L31;
      }
      __THREW__ = 0;
      $569 = (invoke_iiii(754,0,($563|0),($566|0))|0);
      $570 = __THREW__; __THREW__ = 0;
      $571 = $570&1;
      if ($571) {
       label = 16;
       break L31;
      }
      $572 = ($569|0)==(0);
      if (!($572)) {
       $G_B198_0$045 = $569;
       break;
      }
      $573 = $V_26$0 & 65535;
      __THREW__ = 0;
      $574 = (invoke_iiii(742,0,($573|0),($4|0))|0);
      $575 = __THREW__; __THREW__ = 0;
      $576 = $575&1;
      if ($576) {
       label = 16;
       break L31;
      }
      $577 = $V_27$0 & 65535;
      __THREW__ = 0;
      $578 = (invoke_iiii(742,0,($577|0),($4|0))|0);
      $579 = __THREW__; __THREW__ = 0;
      $580 = $579&1;
      if ($580) {
       label = 16;
       break L31;
      }
      $581 = $574 ^ 1;
      $582 = $578 ^ 1;
      __THREW__ = 0;
      $583 = (invoke_iiii(754,0,($581|0),($582|0))|0);
      $584 = __THREW__; __THREW__ = 0;
      $585 = $584&1;
      if ($585) {
       label = 16;
       break L31;
      }
      $586 = ($583|0)==(0);
      if ($586) {
       $V_7$0$phi = $V_7$0;$V_6$0$phi = $V_6$0;$V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_7$0 = $V_7$0$phi;$V_6$0 = $V_6$0$phi;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
       continue L31;
      } else {
       $G_B198_0$045 = $583;
      }
     } else {
      $G_B198_0$045 = $548;
     }
    } while(0);
    if ($immediateBreakup) {
     $$0 = -1;
     label = 304;
     break;
    } else {
     $V_4$0$phi = $V_4$0;$V_3$0$phi = $V_3$0;$V_2$0$phi = $V_2$0;$V_19$sroa$4$0$phi = $V_19$sroa$4$0;$V_19$sroa$3$0$phi = $V_19$sroa$3$0;$V_19$sroa$2$0$phi = $V_19$sroa$2$0;$V_19$sroa$1$0$phi = $V_19$sroa$1$0;$V_19$sroa$0$0$phi = $V_19$sroa$0$0;$V_18$sroa$4$0$phi = $V_18$sroa$4$0;$V_18$sroa$3$0$phi = $V_18$sroa$3$0;$V_18$sroa$2$0$phi = $V_18$sroa$2$0;$V_18$sroa$1$0$phi = $V_18$sroa$1$0;$V_18$sroa$0$0$phi = $V_18$sroa$0$0;$V_1$0$phi = $V_1$0;$$03$phi = $$03;$$01$phi = $$01;$$2 = $$9;$$26 = $$1115;$V_10$0 = $V_10$2;$V_11$0 = $V_11$2;$V_12$0 = $197;$V_13$0 = $209;$V_14$0 = $V_14$1;$V_15$0 = $V_15$1;$V_6$0 = $G_B198_0$045;$V_7$0 = 3;$V_8$0 = $V_8$2;$V_9$0 = $V_9$2;$V_4$0 = $V_4$0$phi;$V_3$0 = $V_3$0$phi;$V_2$0 = $V_2$0$phi;$V_19$sroa$4$0 = $V_19$sroa$4$0$phi;$V_19$sroa$3$0 = $V_19$sroa$3$0$phi;$V_19$sroa$2$0 = $V_19$sroa$2$0$phi;$V_19$sroa$1$0 = $V_19$sroa$1$0$phi;$V_19$sroa$0$0 = $V_19$sroa$0$0$phi;$V_18$sroa$4$0 = $V_18$sroa$4$0$phi;$V_18$sroa$3$0 = $V_18$sroa$3$0$phi;$V_18$sroa$2$0 = $V_18$sroa$2$0$phi;$V_18$sroa$1$0 = $V_18$sroa$1$0$phi;$V_18$sroa$0$0 = $V_18$sroa$0$0$phi;$V_1$0 = $V_1$0$phi;$$03 = $$03$phi;$$01 = $$01$phi;
    }
   }
   switch (label|0) {
    case 6: {
     $16 = ___cxa_find_matching_catch()|0;
     $17 = tempRet0;
     $lpad$phi$index = $16;$lpad$phi$index17 = $17;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 7: {
     $18 = ___cxa_find_matching_catch()|0;
     $19 = tempRet0;
     $lpad$phi$index = $18;$lpad$phi$index17 = $19;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 8: {
     $20 = ___cxa_find_matching_catch()|0;
     $21 = tempRet0;
     $lpad$phi$index = $20;$lpad$phi$index17 = $21;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 9: {
     $22 = ___cxa_find_matching_catch()|0;
     $23 = tempRet0;
     $lpad$phi$index = $22;$lpad$phi$index17 = $23;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 10: {
     $24 = ___cxa_find_matching_catch()|0;
     $25 = tempRet0;
     $lpad$phi$index = $24;$lpad$phi$index17 = $25;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 11: {
     $26 = ___cxa_find_matching_catch()|0;
     $27 = tempRet0;
     $lpad$phi$index = $26;$lpad$phi$index17 = $27;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 12: {
     $28 = ___cxa_find_matching_catch()|0;
     $29 = tempRet0;
     $lpad$phi$index = $28;$lpad$phi$index17 = $29;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 13: {
     $30 = ___cxa_find_matching_catch()|0;
     $31 = tempRet0;
     $lpad$phi$index = $30;$lpad$phi$index17 = $31;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 14: {
     $32 = ___cxa_find_matching_catch()|0;
     $33 = tempRet0;
     $lpad$phi$index = $32;$lpad$phi$index17 = $33;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 15: {
     $34 = ___cxa_find_matching_catch()|0;
     $35 = tempRet0;
     $lpad$phi$index = $34;$lpad$phi$index17 = $35;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 16: {
     $36 = ___cxa_find_matching_catch()|0;
     $37 = tempRet0;
     $lpad$phi$index = $36;$lpad$phi$index17 = $37;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
     break;
    }
    case 258: {
     $587 = ($V_6$0|0)==(0);
     $or$cond34 = $83 | $587;
     $588 = ($V_7$0>>>0)<(3);
     $or$cond35 = $or$cond34 | $588;
     L304: do {
      if ($or$cond35) {
       $$11 = $$2;$$1317 = $$37$lcssa;$V_6$2 = $V_6$0;
       label = 279;
      } else {
       $589 = ($$37$lcssa|0)<($V_4$0|0);
       $or$cond3666 = $95 & $589;
       if ($or$cond3666) {
        $$1071 = $$2;$$121670 = $$37$lcssa;$V_12$168 = $V_12$0;$V_13$167 = $V_13$0;$V_6$169 = $V_6$0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($$01|0));
         $639 = __THREW__; __THREW__ = 0;
         $640 = $639&1;
         if ($640) {
          break;
         }
         __THREW__ = 0;
         $590 = (invoke_iii(621,($$01|0),($$1071|0))|0);
         $591 = __THREW__; __THREW__ = 0;
         $592 = $591&1;
         if ($592) {
          break;
         }
         $593 = $590&65535;
         __THREW__ = 0;
         $594 = (invoke_iii(790,(0|0),($593|0))|0);
         $595 = __THREW__; __THREW__ = 0;
         $596 = $595&1;
         if ($596) {
          break;
         }
         if (!($594)) {
          $$11 = $$1071;$$1317 = $$121670;$V_6$2 = $V_6$169;
          label = 279;
          break L304;
         }
         __THREW__ = 0;
         invoke_vi(3799,($$03|0));
         $597 = __THREW__; __THREW__ = 0;
         $598 = $597&1;
         if ($598) {
          break;
         }
         __THREW__ = 0;
         $599 = (invoke_iii(621,($$03|0),($$121670|0))|0);
         $600 = __THREW__; __THREW__ = 0;
         $601 = $600&1;
         if ($601) {
          break;
         }
         $602 = $599&65535;
         __THREW__ = 0;
         $603 = (invoke_iii(790,(0|0),($602|0))|0);
         $604 = __THREW__; __THREW__ = 0;
         $605 = $604&1;
         if ($605) {
          break;
         }
         if (!($603)) {
          $$11 = $$1071;$$1317 = $$121670;$V_6$2 = $V_6$169;
          label = 279;
          break L304;
         }
         __THREW__ = 0;
         invoke_vi(3799,($$01|0));
         $606 = __THREW__; __THREW__ = 0;
         $607 = $606&1;
         if ($607) {
          break;
         }
         __THREW__ = 0;
         $608 = (invoke_iii(621,($$01|0),($$1071|0))|0);
         $609 = __THREW__; __THREW__ = 0;
         $610 = $609&1;
         if ($610) {
          break;
         }
         $611 = $608&65535;
         __THREW__ = 0;
         $612 = (invoke_iiii(743,($__this|0),($611|0),($4|0))|0);
         $613 = __THREW__; __THREW__ = 0;
         $614 = $613&1;
         if ($614) {
          break;
         }
         __THREW__ = 0;
         $615 = (invoke_iiii(740,($__this|0),($612|0),($V_12$168|0))|0);
         $616 = __THREW__; __THREW__ = 0;
         $617 = $616&1;
         if ($617) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($$03|0));
         $618 = __THREW__; __THREW__ = 0;
         $619 = $618&1;
         if ($619) {
          break;
         }
         __THREW__ = 0;
         $620 = (invoke_iii(621,($$03|0),($$121670|0))|0);
         $621 = __THREW__; __THREW__ = 0;
         $622 = $621&1;
         if ($622) {
          break;
         }
         $623 = $620&65535;
         __THREW__ = 0;
         $624 = (invoke_iiii(743,($__this|0),($623|0),($4|0))|0);
         $625 = __THREW__; __THREW__ = 0;
         $626 = $625&1;
         if ($626) {
          break;
         }
         __THREW__ = 0;
         $627 = (invoke_iiii(740,($__this|0),($624|0),($V_13$167|0))|0);
         $628 = __THREW__; __THREW__ = 0;
         $629 = $628&1;
         if ($629) {
          break;
         }
         $630 = $615&255;
         $631 = $627&255;
         $632 = (($630) - ($631))|0;
         $633 = $632 & 255;
         $634 = ($633|0)==(0);
         if (!($634)) {
          $$11 = $$1071;$$1317 = $$121670;$V_6$2 = $633;
          label = 279;
          break L304;
         }
         $635 = (($$1071) + 1)|0;
         $636 = (($$121670) + 1)|0;
         $637 = ($635|0)<($V_3$0|0);
         $638 = ($636|0)<($V_4$0|0);
         $or$cond36 = $637 & $638;
         if ($or$cond36) {
          $$1071 = $635;$$121670 = $636;$V_12$168 = 0;$V_13$167 = 0;$V_6$169 = 0;
         } else {
          $$13570 = $635;$$1518568 = $636;
          label = 295;
          break L304;
         }
        }
        $14 = ___cxa_find_matching_catch()|0;
        $15 = tempRet0;
        $lpad$phi$index = $14;$lpad$phi$index17 = $15;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       } else {
        $$11 = $$2;$$1317 = $$37$lcssa;$V_6$2 = $V_6$0;
        label = 279;
       }
      }
     } while(0);
     if ((label|0) == 279) {
      $641 = ($V_7$0|0)!=(1);
      $642 = ($V_6$2|0)==(0);
      $or$cond37 = $641 | $642;
      L330: do {
       if ($or$cond37) {
        $$13 = $$11;$$1518 = $$1317;
       } else {
        $643 = ($$11|0)<($V_3$0|0);
        L332: do {
         if ($643) {
          $$1257 = $$11;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $654 = __THREW__; __THREW__ = 0;
           $655 = $654&1;
           if ($655) {
            break;
           }
           __THREW__ = 0;
           $644 = (invoke_iii(621,($$01|0),($$1257|0))|0);
           $645 = __THREW__; __THREW__ = 0;
           $646 = $645&1;
           if ($646) {
            break;
           }
           $647 = $644&65535;
           __THREW__ = 0;
           $648 = (invoke_iii(790,(0|0),($647|0))|0);
           $649 = __THREW__; __THREW__ = 0;
           $650 = $649&1;
           if ($650) {
            break;
           }
           $651 = (($$1257) + 1)|0;
           if (!($648)) {
            $$12$lcssa = $$1257;
            break L332;
           }
           $653 = ($651|0)<($V_3$0|0);
           if ($653) {
            $$1257 = $651;
           } else {
            $$12$lcssa = $651;
            break L332;
           }
          }
          $12 = ___cxa_find_matching_catch()|0;
          $13 = tempRet0;
          $lpad$phi$index = $12;$lpad$phi$index17 = $13;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         } else {
          $$12$lcssa = $$11;
         }
        } while(0);
        $652 = ($$1317|0)<($V_4$0|0);
        if ($652) {
         $$1451 = $$1317;
         while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($$03|0));
          $665 = __THREW__; __THREW__ = 0;
          $666 = $665&1;
          if ($666) {
           break;
          }
          __THREW__ = 0;
          $656 = (invoke_iii(621,($$03|0),($$1451|0))|0);
          $657 = __THREW__; __THREW__ = 0;
          $658 = $657&1;
          if ($658) {
           break;
          }
          $659 = $656&65535;
          __THREW__ = 0;
          $660 = (invoke_iii(790,(0|0),($659|0))|0);
          $661 = __THREW__; __THREW__ = 0;
          $662 = $661&1;
          if ($662) {
           break;
          }
          $663 = (($$1451) + 1)|0;
          if (!($660)) {
           $$13 = $$12$lcssa;$$1518 = $$1451;
           break L330;
          }
          $664 = ($663|0)<($V_4$0|0);
          if ($664) {
           $$1451 = $663;
          } else {
           $$13 = $$12$lcssa;$$1518 = $663;
           break L330;
          }
         }
         $10 = ___cxa_find_matching_catch()|0;
         $11 = tempRet0;
         $lpad$phi$index = $10;$lpad$phi$index17 = $11;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        } else {
         $$13 = $$12$lcssa;$$1518 = $$1317;
        }
       }
      } while(0);
      if ($642) {
       $$13570 = $$13;$$1518568 = $$1518;
       label = 295;
      } else {
       $$13569 = $$13;$$1518567 = $$1518;$V_6$348 = $V_6$2;
      }
     }
     if ((label|0) == 295) {
      $667 = ($V_8$0|0)>(-1);
      $668 = ($V_9$0|0)<(0);
      $or$cond38 = $667 | $668;
      if ($or$cond38) {
       $669 = ($V_9$0|0)>(-1);
       $670 = ($V_8$0|0)<(0);
       $or$cond39 = $669 | $670;
       if ($or$cond39) {
        $671 = (($V_8$0) - ($V_9$0))|0;
        $672 = ($V_8$0|0)==($V_9$0|0);
        $673 = (($V_10$0) - ($V_11$0))|0;
        $$40 = $672 ? $673 : $671;
        $674 = ($$40|0)==(0);
        if ($674) {
         $675 = ($$1518568|0)==($V_4$0|0);
         if ($675) {
          HEAP8[$targetConsumed>>0] = 1;
         }
         $676 = ($$13570|0)==($V_3$0|0);
         if ($676) {
          HEAP8[$sourceConsumed>>0] = 1;
          $$13569 = $$13570;$$1518567 = $$1518568;$V_6$348 = 0;
         } else {
          $$13569 = $$13570;$$1518567 = $$1518568;$V_6$348 = 0;
         }
        } else {
         $$13569 = $$13570;$$1518567 = $$1518568;$V_6$348 = $$40;
        }
       } else {
        $$13569 = $$13570;$$1518567 = $$1518568;$V_6$348 = 1;
       }
      } else {
       $$13569 = $$13570;$$1518567 = $$1518568;$V_6$348 = -1;
      }
     }
     $677 = ($$13569|0)==($V_3$0|0);
     if (!($677)) {
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $678 = ($$1518567|0)==($V_4$0|0);
     $V_6$3$ = $678 ? $V_6$348 : -1;
     $$0 = $V_6$3$;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 304: {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
   }
  }
 } while(0);
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 $lpad$phi$index = $42;$lpad$phi$index17 = $43;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareFlagPairP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorbb($__this,$b1,$b2) {
 $__this = $__this|0;
 $b1 = $b1|0;
 $b2 = $b2|0;
 var $$ = 0, $0 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275184);
 $0 = $b1 ^ $b2;
 if ($0) {
  $$ = $b1 ? 1 : -1;
  $G_B5_0$0 = $$;
 } else {
  $G_B5_0$0 = 0;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B5_0$0|0);
}
function __Z176mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsPrefix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_i($__this,$src,$target,$opt) {
 $__this = $__this|0;
 $src = $src|0;
 $target = $target|0;
 $opt = $opt|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275232);
 __THREW__ = 0;
 invoke_vi(3799,($src|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($src|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiiiiii(59,($__this|0),($src|0),($target|0),0,($2|0),($opt|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z220mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsPrefix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iii($__this,$s,$target,$start,$length,$opt) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 $opt = $opt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275280);
 ;HEAP32[$V_2+0>>2]=HEAP32[2275808+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[2275808+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[2275808+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[2275808+12>>2]|0;HEAP32[$V_2+16>>2]=HEAP32[2275808+16>>2]|0;HEAP32[$V_2+20>>2]=HEAP32[2275808+20>>2]|0;HEAP32[$V_2+24>>2]=HEAP32[2275808+24>>2]|0;HEAP32[$V_2+28>>2]=HEAP32[2275808+28>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($target|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
   $9 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
   __THREW__ = 0;
   invoke_viii(554,0,($8|0),4);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    invoke_viii(554,0,($9|0),4);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($target|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(1816,($target|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       (invoke_iiiiiiii(77,0,0,0,0,0,0,0)|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_viiiiiiii(13,($V_2|0),($opt|0),(0|0),(0|0),($8|0),($9|0),(0|0),0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         $22 = (invoke_iiiiiiii(78,($__this|0),($s|0),($target|0),($start|0),($length|0),1,($V_2|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          $$0 = $22;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z267mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsPrefix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ContextU0026_refP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iibP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$target,$start,$length,$skipHeadingExtenders,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 $skipHeadingExtenders = $skipHeadingExtenders|0;
 $ctx = $ctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 5|0;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275328);
 HEAP8[$V_0>>0] = 0;
 HEAP8[$V_1>>0] = 0;
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($target|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_iiiiiiiiiiiii(1,($__this|0),($s|0),($start|0),($length|0),($target|0),0,($2|0),($V_0|0),($V_1|0),($skipHeadingExtenders|0),1,($ctx|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP8[$V_0>>0]|0;
    $8 = ($7<<24>>24)!=(0);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($8|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z176mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsSuffix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_i($__this,$src,$target,$opt) {
 $__this = $__this|0;
 $src = $src|0;
 $target = $target|0;
 $opt = $opt|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275376);
 __THREW__ = 0;
 invoke_vi(3799,($src|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($src|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($2) + -1)|0;
   __THREW__ = 0;
   invoke_vi(3799,($src|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(1816,($src|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iiiiiii(60,($__this|0),($src|0),($target|0),($5|0),($8|0),($opt|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($11|0);
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z220mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsSuffix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iii($__this,$s,$target,$start,$length,$opt) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 $opt = $opt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275424);
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($target|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_iiiiiii(63,($__this|0),($s|0),($target|0),($start|0),($length|0),($opt|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = ($8|0)<(0);
    if ($11) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_ii(1816,($s|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $17 = (($14) - ($8))|0;
      __THREW__ = 0;
      invoke_vi(3799,($target|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(1816,($target|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        $23 = (invoke_iiiiiiiii(10,($__this|0),($s|0),($8|0),($17|0),($target|0),0,($20|0),($opt|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         $26 = ($23|0)==(0);
         $$0 = $26;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z221mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iii($__this,$s,$target,$start,$length,$opt) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 $opt = $opt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_5 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275760);
 ;HEAP32[$V_5+0>>2]=HEAP32[2275808+0>>2]|0;HEAP32[$V_5+4>>2]=HEAP32[2275808+4>>2]|0;HEAP32[$V_5+8>>2]=HEAP32[2275808+8>>2]|0;HEAP32[$V_5+12>>2]=HEAP32[2275808+12>>2]|0;HEAP32[$V_5+16>>2]=HEAP32[2275808+16>>2]|0;HEAP32[$V_5+20>>2]=HEAP32[2275808+20>>2]|0;HEAP32[$V_5+24>>2]=HEAP32[2275808+24>>2]|0;HEAP32[$V_5+28>>2]=HEAP32[2275808+28>>2]|0;
 if ((($opt|0) == 1073741824)) {
  __THREW__ = 0;
  $0 = (invoke_iiiiii(105,0,($s|0),($target|0),($start|0),($length|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   $$0 = $0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else if ((($opt|0) == 268435456)) {
  __THREW__ = 0;
  $5 = (invoke_iiiiii(106,($__this|0),($s|0),($target|0),($start|0),($length|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $$0 = $5;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $8 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  $9 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  $10 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  $11 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  $12 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  __THREW__ = 0;
  invoke_viii(554,0,($8|0),16);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   invoke_viii(554,0,($9|0),16);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_viii(554,0,($10|0),4);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     invoke_viii(554,0,($11|0),4);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_viii(554,0,($12|0),4);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_viiiiiiii(13,($V_5|0),($opt|0),($8|0),($9|0),($11|0),($12|0),(0|0),0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_iiiiiiii(80,($__this|0),($s|0),($target|0),($start|0),($length|0),($10|0),($V_5|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $$0 = $25;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_QuickIndexOfP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iiPb($__this,$s,$target,$start,$length,$testWasUnable) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 $testWasUnable = $testWasUnable|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$312 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_1$311 = 0, $V_3$010 = 0, $V_5$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275472);
 HEAP8[$testWasUnable>>0] = 1;
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($target|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($target|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_ii(1816,($target|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = ($12|0)>($length|0);
     if ($15) {
      $$0 = -1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     HEAP8[$testWasUnable>>0] = 0;
     __THREW__ = 0;
     invoke_vi(3799,($target|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (invoke_ii(1816,($target|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = (($start) + 1)|0;
       $22 = (($21) + ($length))|0;
       $23 = (($22) - ($18))|0;
       $24 = ($23|0)>($start|0);
       if (!($24)) {
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $V_0$312 = -1;$V_1$311 = -1;$V_3$010 = $start;
       L17: while(1) {
        $V_0$1 = $V_0$312;$V_1$1 = $V_1$311;$V_5$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($target|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $53 = (invoke_ii(1816,($target|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 4;
          break L17;
         }
         $56 = ($V_5$0|0)<($53|0);
         if (!($56)) {
          $$0 = $V_3$010;
          label = 34;
          break L17;
         }
         $57 = ($V_1$1|0)<($V_5$0|0);
         if ($57) {
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if ($26) {
           label = 4;
           break L17;
          }
          __THREW__ = 0;
          $27 = (invoke_iii(621,($target|0),($V_5$0|0))|0);
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if ($29) {
           label = 4;
           break L17;
          }
          $30 = ($27&65535)<(128);
          if ($30) {
           $V_1$0 = $V_5$0;
          } else {
           label = 17;
           break L17;
          }
         } else {
          $V_1$0 = $V_1$1;
         }
         $31 = (($V_5$0) + ($V_3$010))|0;
         $32 = ($V_0$1|0)<($31|0);
         if ($32) {
          __THREW__ = 0;
          invoke_vi(3799,($s|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           label = 4;
           break L17;
          }
          __THREW__ = 0;
          $35 = (invoke_iii(621,($s|0),($31|0))|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           label = 4;
           break L17;
          }
          $38 = ($35&65535)<(128);
          if ($38) {
           $V_0$0 = $31;
          } else {
           label = 22;
           break L17;
          }
         } else {
          $V_0$0 = $V_0$1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $41 = (invoke_iii(621,($s|0),($31|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         invoke_vi(3799,($target|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $46 = (invoke_iii(621,($target|0),($V_5$0|0))|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          label = 4;
          break L17;
         }
         $49 = ($41<<16>>16)==($46<<16>>16);
         $50 = (($V_5$0) + 1)|0;
         if ($49) {
          $V_0$1 = $V_0$0;$V_1$1 = $V_1$0;$V_5$0 = $50;
         } else {
          break;
         }
        }
        $58 = (($V_3$010) + 1)|0;
        $59 = ($58|0)<($23|0);
        if ($59) {
         $V_0$312 = $V_0$0;$V_1$311 = $V_1$0;$V_3$010 = $58;
        } else {
         $$0 = -1;
         label = 34;
         break;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 17) {
        HEAP8[$testWasUnable>>0] = 1;
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 22) {
        HEAP8[$testWasUnable>>0] = 1;
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 34) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z217mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iii($__this,$s,$target,$start,$length,$opt) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 $opt = $opt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_0 = sp + 36|0;
 $V_7 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275520);
 HEAP8[$V_0>>0] = 0;
 ;HEAP32[$V_7+0>>2]=HEAP32[2275808+0>>2]|0;HEAP32[$V_7+4>>2]=HEAP32[2275808+4>>2]|0;HEAP32[$V_7+8>>2]=HEAP32[2275808+8>>2]|0;HEAP32[$V_7+12>>2]=HEAP32[2275808+12>>2]|0;HEAP32[$V_7+16>>2]=HEAP32[2275808+16>>2]|0;HEAP32[$V_7+20>>2]=HEAP32[2275808+20>>2]|0;HEAP32[$V_7+24>>2]=HEAP32[2275808+24>>2]|0;HEAP32[$V_7+28>>2]=HEAP32[2275808+28>>2]|0;
 if ((($opt|0) == 0)) {
  __THREW__ = 0;
  $8 = (invoke_iiiiiii(61,0,($s|0),($target|0),($start|0),($length|0),($V_0|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = HEAP8[$V_0>>0]|0;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    $$0 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    label = 7;
   }
  }
 } else if ((($opt|0) == 268435456)) {
  __THREW__ = 0;
  $5 = (invoke_iiiiii(104,($__this|0),($s|0),($target|0),($start|0),($length|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $$0 = $5;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else if ((($opt|0) == 1073741824)) {
  __THREW__ = 0;
  $0 = (invoke_iiiiii(103,0,($s|0),($target|0),($start|0),($length|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   $$0 = $0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  label = 7;
 }
 if ((label|0) == 7) {
  $13 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  $14 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  $15 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  $16 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  $17 = STACKTOP; STACKTOP = STACKTOP + 16|0;;
  __THREW__ = 0;
  invoke_viii(554,0,($13|0),16);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   __THREW__ = 0;
   invoke_viii(554,0,($14|0),16);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    invoke_viii(554,0,($15|0),4);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     invoke_viii(554,0,($16|0),4);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      invoke_viii(554,0,($17|0),4);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       invoke_viiiiiiii(13,($V_7|0),($opt|0),($13|0),($14|0),($16|0),($17|0),(0|0),0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_iiiiiiii(79,($__this|0),($s|0),($target|0),($start|0),($length|0),($15|0),($V_7|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $$0 = $30;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOfOrdinalP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_ii($__this,$s,$target,$start,$length) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$04 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275568);
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($target|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($target|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_ii(1816,($target|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = ($12|0)>($length|0);
     if ($15) {
      $$0 = -1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($target|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (invoke_ii(1816,($target|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = (($start) + 1)|0;
       $22 = (($21) + ($length))|0;
       $23 = (($22) - ($18))|0;
       $24 = ($23|0)>($start|0);
       if (!($24)) {
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $V_1$04 = $start;
       L17: while(1) {
        $V_3$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($target|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $38 = (invoke_ii(1816,($target|0))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          label = 4;
          break L17;
         }
         $41 = ($V_3$0|0)<($38|0);
         if (!($41)) {
          $$0 = $V_1$04;
          label = 24;
          break L17;
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 4;
          break L17;
         }
         $25 = (($V_3$0) + ($V_1$04))|0;
         __THREW__ = 0;
         $26 = (invoke_iii(621,($s|0),($25|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         invoke_vi(3799,($target|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $31 = (invoke_iii(621,($target|0),($V_3$0|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          label = 4;
          break L17;
         }
         $34 = ($26<<16>>16)==($31<<16>>16);
         $35 = (($V_3$0) + 1)|0;
         if ($34) {
          $V_3$0 = $35;
         } else {
          break;
         }
        }
        $44 = (($V_1$04) + 1)|0;
        $45 = ($44|0)<($23|0);
        if ($45) {
         $V_1$04 = $44;
        } else {
         $$0 = -1;
         label = 24;
         break;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 24) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOfOrdinalIgnoreCaseP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_ii($__this,$s,$target,$start,$length) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_1$04 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275616);
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($target|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($target|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_ii(1816,($target|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = ($12|0)>($length|0);
     if ($15) {
      $$0 = -1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($target|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (invoke_ii(1816,($target|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = (($start) + 1)|0;
       $22 = (($21) + ($length))|0;
       $23 = (($22) - ($18))|0;
       $24 = ($23|0)>($start|0);
       if (!($24)) {
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $25 = (($__this) + 8|0);
       $V_1$04 = $start;
       L17: while(1) {
        $V_3$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($target|0));
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if ($50) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $51 = (invoke_ii(1816,($target|0))|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          label = 4;
          break L17;
         }
         $54 = ($V_3$0|0)<($51|0);
         if (!($54)) {
          $$0 = $V_1$04;
          label = 28;
          break L17;
         }
         $30 = HEAP32[$25>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          label = 4;
          break L17;
         }
         $26 = (($V_3$0) + ($V_1$04))|0;
         __THREW__ = 0;
         $27 = (invoke_iii(621,($s|0),($26|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         invoke_vi(3799,($30|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $33 = (invoke_iiii(1667,(2274320|0),($30|0),($27|0))|0);
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          label = 4;
          break L17;
         }
         $36 = HEAP32[$25>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($target|0));
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $39 = (invoke_iii(621,($target|0),($V_3$0|0))|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         invoke_vi(3799,($36|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 4;
          break L17;
         }
         __THREW__ = 0;
         $44 = (invoke_iiii(1667,(2274320|0),($36|0),($39|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 4;
          break L17;
         }
         $47 = ($33<<16>>16)==($44<<16>>16);
         $48 = (($V_3$0) + 1)|0;
         if ($47) {
          $V_3$0 = $48;
         } else {
          break;
         }
        }
        $57 = (($V_1$04) + 1)|0;
        $58 = ($57|0)<($23|0);
        if ($58) {
         $V_1$04 = $57;
        } else {
         $$0 = -1;
         label = 28;
         break;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 28) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z270mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ContextU0026_refP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iiPhP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$target,$start,$length,$targetSortKey,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 $targetSortKey = $targetSortKey|0;
 $ctx = $ctx|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$ph = 0, $$ph24 = 0, $$pn = 0, $$targetSortKey = 0, $$targetSortKey11$ph = 0, $$targetSortKey919$ph = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B10_0$0716$ph = 0, $G_B10_0$0720$ph = 0, $V_1$0 = 0, $V_1$1 = 0, $V_1$1$in = 0, $V_5$0$off018$ph = 0;
 var $V_5$0$off022$ph = 0, $V_7$017$ph = 0, $V_7$021$ph = 0, $V_8$0 = 0, $V_9$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275712);
 $0 = HEAP32[$ctx>>2]|0;
 $V_1$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($target|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  $21 = (invoke_ii(1816,($target|0))|0);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if ($23) {
   label = 8;
   break;
  }
  $24 = ($V_1$0|0)<($21|0);
  if (!($24)) {
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($target|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  $1 = (invoke_iii(621,($target|0),($V_1$0|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   label = 8;
   break;
  }
  $4 = $1&65535;
  __THREW__ = 0;
  $5 = (invoke_iiii(746,0,($4|0),($0|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 8;
   break;
  }
  $8 = (($V_1$0) + 1)|0;
  if ($5) {
   $V_1$0 = $8;
  } else {
   break;
  }
 }
 if ((label|0) == 8) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $lpad$phi$index = $15;$lpad$phi$index5 = $16;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $27 = __THREW__; __THREW__ = 0;
 $28 = $27&1;
 L13: do {
  if (!($28)) {
   __THREW__ = 0;
   $29 = (invoke_ii(1816,($target|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    $32 = ($V_1$0|0)==($29|0);
    if ($32) {
     $$0 = $start;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($target|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     __THREW__ = 0;
     $35 = (invoke_ii(1816,($target|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      $38 = (($35) - ($V_1$0))|0;
      __THREW__ = 0;
      $39 = (invoke_iiiii(122,($__this|0),($target|0),($V_1$0|0),($38|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       $42 = ($39|0)==(0|0);
       L22: do {
        if ($42) {
         $43 = ($targetSortKey|0)==(0|0);
         if ($43) {
          $$ph = 0;$$targetSortKey11$ph = 0;$G_B10_0$0716$ph = 0;$V_5$0$off018$ph = 1;$V_7$017$ph = -1;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           break L13;
          }
          __THREW__ = 0;
          (invoke_iii(621,($target|0),($V_1$0|0))|0);
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           break L13;
          }
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $85 = __THREW__; __THREW__ = 0;
          $86 = $85&1;
          if ($86) {
           break L13;
          }
          __THREW__ = 0;
          $87 = (invoke_iii(621,($target|0),($V_1$0|0))|0);
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           break L13;
          }
          $90 = $87&65535;
          __THREW__ = 0;
          $91 = (invoke_iiii(743,($__this|0),($90|0),($0|0))|0);
          $92 = __THREW__; __THREW__ = 0;
          $93 = $92&1;
          if ($93) {
           break L13;
          }
          __THREW__ = 0;
          $94 = (invoke_iii(799,($__this|0),($91|0))|0);
          $95 = __THREW__; __THREW__ = 0;
          $96 = $95&1;
          if ($96) {
           break L13;
          }
          HEAP8[$targetSortKey>>0] = $94;
          __THREW__ = 0;
          $97 = (invoke_iii(800,($__this|0),($91|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break L13;
          }
          $100 = (($targetSortKey) + 1|0);
          HEAP8[$100>>0] = $97;
          $101 = $0 & 2;
          $102 = ($101|0)==(0);
          if ($102) {
           __THREW__ = 0;
           $103 = (invoke_iiii(740,($__this|0),($91|0),0)|0);
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            break L13;
           }
           $106 = (($targetSortKey) + 2|0);
           HEAP8[$106>>0] = $103;
          }
          __THREW__ = 0;
          $107 = (invoke_iii(789,(0|0),($91|0))|0);
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           break L13;
          }
          $110 = (($targetSortKey) + 3|0);
          HEAP8[$110>>0] = $107;
          $111 = $91&65535;
          __THREW__ = 0;
          $112 = (invoke_iii(793,(0|0),($111|0))|0);
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           break L13;
          }
          $115 = $112 ^ 1;
          $$ph24 = 0;$$targetSortKey919$ph = $targetSortKey;$G_B10_0$0720$ph = 0;$V_5$0$off022$ph = $115;$V_7$021$ph = $91;
          label = 49;
         }
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($39|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L13;
         }
         $46 = (($39) + 12|0);
         $47 = HEAP32[$46>>2]|0;
         $48 = ($47|0)!=(0|0);
         $$targetSortKey = $48 ? 0 : $targetSortKey;
         $49 = ($$targetSortKey|0)==(0|0);
         if ($49) {
          $$ph = $48;$$targetSortKey11$ph = 0;$G_B10_0$0716$ph = $47;$V_5$0$off018$ph = 1;$V_7$017$ph = -1;
         } else {
          $50 = (($39) + 16|0);
          $V_8$0 = 0;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($39|0));
           $71 = __THREW__; __THREW__ = 0;
           $72 = $71&1;
           if ($72) {
            break;
           }
           $73 = HEAP32[$50>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($73|0));
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if ($75) {
            break;
           }
           $76 = (($73) + 12|0);
           $77 = HEAP32[$76>>2]|0;
           $78 = ($V_8$0|0)<($77|0);
           if (!($78)) {
            $$ph24 = $48;$$targetSortKey919$ph = $$targetSortKey;$G_B10_0$0720$ph = $47;$V_5$0$off022$ph = 1;$V_7$021$ph = -1;
            label = 49;
            break L22;
           }
           $69 = (($$targetSortKey) + ($V_8$0)|0);
           __THREW__ = 0;
           invoke_vi(3799,($39|0));
           $79 = __THREW__; __THREW__ = 0;
           $80 = $79&1;
           if ($80) {
            break;
           }
           $51 = HEAP32[$50>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($51|0));
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if ($53) {
            break;
           }
           $54 = (($51) + 12|0);
           $55 = HEAP32[$54>>2]|0;
           $56 = ($V_8$0>>>0)<($55>>>0);
           if (!($56)) {
            __THREW__ = 0;
            $57 = (invoke_i(132)|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($57|0));
            $60 = __THREW__; __THREW__ = 0;
            $61 = $60&1;
            if ($61) {
             break;
            }
           }
           $62 = HEAP32[$51>>2]|0;
           $63 = (($51) + 16|0);
           $64 = (($62) + 92|0);
           $65 = HEAP32[$64>>2]|0;
           $66 = Math_imul($65, $V_8$0)|0;
           $67 = (($63) + ($66)|0);
           $68 = HEAP8[$67>>0]|0;
           HEAP8[$69>>0] = $68;
           $70 = (($V_8$0) + 1)|0;
           $V_8$0 = $70;
          }
          $13 = ___cxa_find_matching_catch()|0;
          $14 = tempRet0;
          $lpad$phi$index = $13;$lpad$phi$index5 = $14;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
        }
       } while(0);
       L54: do {
        if ((label|0) == 49) {
         $116 = (($$targetSortKey919$ph) + 2|0);
         $V_1$1$in = $V_1$0;
         while(1) {
          $V_1$1 = (($V_1$1$in) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $141 = __THREW__; __THREW__ = 0;
          $142 = $141&1;
          if ($142) {
           break;
          }
          __THREW__ = 0;
          $143 = (invoke_ii(1816,($target|0))|0);
          $144 = __THREW__; __THREW__ = 0;
          $145 = $144&1;
          if ($145) {
           break;
          }
          $146 = ($V_1$1|0)<($143|0);
          if (!($146)) {
           $$ph = $$ph24;$$targetSortKey11$ph = $$targetSortKey919$ph;$G_B10_0$0716$ph = $G_B10_0$0720$ph;$V_5$0$off018$ph = $V_5$0$off022$ph;$V_7$017$ph = $V_7$021$ph;
           break L54;
          }
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $147 = __THREW__; __THREW__ = 0;
          $148 = $147&1;
          if ($148) {
           break;
          }
          __THREW__ = 0;
          $117 = (invoke_iii(621,($target|0),($V_1$1|0))|0);
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          if ($119) {
           break;
          }
          $120 = $117&65535;
          __THREW__ = 0;
          $121 = (invoke_iii(799,($__this|0),($120|0))|0);
          $122 = __THREW__; __THREW__ = 0;
          $123 = $122&1;
          if ($123) {
           break;
          }
          $124 = ($121<<24>>24)==(1);
          if (!($124)) {
           $$ph = $$ph24;$$targetSortKey11$ph = $$targetSortKey919$ph;$G_B10_0$0716$ph = $G_B10_0$0720$ph;$V_5$0$off018$ph = $V_5$0$off022$ph;$V_7$017$ph = $V_7$021$ph;
           break L54;
          }
          $125 = HEAP8[$116>>0]|0;
          $126 = ($125<<24>>24)==(0);
          if ($126) {
           HEAP8[$116>>0] = 2;
           $128 = 2;
          } else {
           $128 = $125;
          }
          $127 = $128&255;
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $129 = __THREW__; __THREW__ = 0;
          $130 = $129&1;
          if ($130) {
           break;
          }
          __THREW__ = 0;
          $131 = (invoke_iii(621,($target|0),($V_1$1|0))|0);
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           break;
          }
          $134 = $131&65535;
          __THREW__ = 0;
          $135 = (invoke_iiii(740,($__this|0),($134|0),0)|0);
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           break;
          }
          $138 = $135&255;
          $139 = (($138) + ($127))|0;
          $140 = $139&255;
          HEAP8[$116>>0] = $140;
          $V_1$1$in = $V_1$1;
         }
         $11 = ___cxa_find_matching_catch()|0;
         $12 = tempRet0;
         $lpad$phi$index = $11;$lpad$phi$index5 = $12;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
       } while(0);
       $$01 = $start;$$02 = $length;
       while(1) {
        if ($$ph) {
         __THREW__ = 0;
         $149 = (invoke_iiiiiiii(79,($__this|0),($s|0),($G_B10_0$0716$ph|0),($$01|0),($$02|0),($targetSortKey|0),($ctx|0))|0);
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          label = 5;
          break;
         } else {
          $V_9$0 = $149;
         }
        } else {
         __THREW__ = 0;
         $152 = (invoke_iiiiiiiiii(4,($__this|0),($s|0),($$01|0),($$02|0),($$targetSortKey11$ph|0),0,($V_7$017$ph|0),($V_5$0$off018$ph|0),($ctx|0))|0);
         $153 = __THREW__; __THREW__ = 0;
         $154 = $153&1;
         if ($154) {
          label = 5;
          break;
         } else {
          $V_9$0 = $152;
         }
        }
        $155 = ($V_9$0|0)>(-1);
        if (!($155)) {
         $$0 = -1;
         label = 78;
         break;
        }
        $156 = (($$01) - ($V_9$0))|0;
        $157 = (($156) + ($$02))|0;
        __THREW__ = 0;
        $158 = (invoke_iiiiiiii(78,($__this|0),($s|0),($target|0),($V_9$0|0),($157|0),0,($ctx|0))|0);
        $159 = __THREW__; __THREW__ = 0;
        $160 = $159&1;
        if ($160) {
         label = 5;
         break;
        }
        if ($158) {
         $$0 = $V_9$0;
         label = 78;
         break;
        }
        __THREW__ = 0;
        $161 = (invoke_iiiii(122,($__this|0),($s|0),($V_9$0|0),($157|0))|0);
        $162 = __THREW__; __THREW__ = 0;
        $163 = $162&1;
        if ($163) {
         label = 5;
         break;
        }
        $164 = ($161|0)==(0|0);
        if ($164) {
         $181 = (($157) + -1)|0;
         $$13 = $181;$$pn = 1;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($161|0));
         $165 = __THREW__; __THREW__ = 0;
         $166 = $165&1;
         if ($166) {
          label = 5;
          break;
         }
         $167 = (($161) + 8|0);
         $168 = HEAP32[$167>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($168|0));
         $169 = __THREW__; __THREW__ = 0;
         $170 = $169&1;
         if ($170) {
          label = 5;
          break;
         }
         $171 = (($168) + 12|0);
         $172 = HEAP32[$171>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($161|0));
         $173 = __THREW__; __THREW__ = 0;
         $174 = $173&1;
         if ($174) {
          label = 5;
          break;
         }
         $175 = HEAP32[$167>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($175|0));
         $176 = __THREW__; __THREW__ = 0;
         $177 = $176&1;
         if ($177) {
          label = 5;
          break;
         }
         $178 = (($175) + 12|0);
         $179 = HEAP32[$178>>2]|0;
         $180 = (($157) - ($179))|0;
         $$13 = $180;$$pn = $172;
        }
        $$1 = (($$pn) + ($V_9$0))|0;
        $182 = ($$13|0)>(0);
        if ($182) {
         $$01 = $$1;$$02 = $$13;
        } else {
         $$0 = -1;
         label = 78;
         break;
        }
       }
       if ((label|0) == 5) {
        $9 = ___cxa_find_matching_catch()|0;
        $10 = tempRet0;
        $lpad$phi$index = $9;$lpad$phi$index5 = $10;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 78) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $lpad$phi$index = $17;$lpad$phi$index5 = $18;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOfSortKeyP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiPhtibP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$start,$length,$sortkey,$target,$ti,$noLv4,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $start = $start|0;
 $length = $length|0;
 $sortkey = $sortkey|0;
 $target = $target|0;
 $ti = $ti|0;
 $noLv4 = $noLv4|0;
 $ctx = $ctx|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275664);
 $0 = (($length) + ($start))|0;
 HEAP32[$V_1>>2] = $start;
 $4 = $start;
 while(1) {
  $3 = ($4|0)<($0|0);
  if (!($3)) {
   $$0 = -1;
   label = 7;
   break;
  }
  __THREW__ = 0;
  $5 = (invoke_iiiiiiiii(11,($__this|0),($s|0),($V_1|0),($0|0),($ti|0),($sortkey|0),($noLv4|0),($ctx|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 4;
   break;
  }
  if ($5) {
   $$0 = $4;
   label = 7;
   break;
  }
  $$pre = HEAP32[$V_1>>2]|0;
  $4 = $$pre;
 }
 if ((label|0) == 4) {
  $1 = ___cxa_find_matching_catch()|0;
  $2 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($1|0);
  // unreachable;
 }
 else if ((label|0) == 7) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesForwardP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringPiiiPhbP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$idx,$end,$ti,$sortkey,$noLv4,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $idx = $idx|0;
 $end = $end|0;
 $ti = $ti|0;
 $sortkey = $sortkey|0;
 $noLv4 = $noLv4|0;
 $ctx = $ctx|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2 = 0, $_stackTraceSentry = 0, $notlhs = 0, $notlhs6 = 0, $notrhs = 0, $notrhs7 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2$not = 0, $or$cond3 = 0;
 var $or$cond4$not = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2276032);
 HEAP32[$V_2>>2] = 0;
 $0 = HEAP32[$idx>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(621,($s|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3&65535;
   $7 = (($ctx) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   $10 = ($3&65535)>(127);
   $or$cond = $9 | $10;
   if (!($or$cond)) {
    $13 = $6 >>> 3;
    $14 = (($8) + ($13)|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = $15&255;
    $17 = $6 & 7;
    $18 = 1 << $17;
    $19 = $16 & $18;
    $20 = ($19|0)==(0);
    if (!($20)) {
     $$0 = 1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   $21 = (($ctx) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   $or$cond1 = $23 | $10;
   if (!($or$cond1)) {
    $24 = $6 >>> 3;
    $25 = (($22) + ($24)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26&255;
    $28 = $6 & 7;
    $29 = 1 << $28;
    $30 = $27 & $29;
    $31 = ($30|0)==(0);
    if (!($31)) {
     $32 = HEAP32[$idx>>2]|0;
     $33 = (($32) + 1)|0;
     HEAP32[$idx>>2] = $33;
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   $34 = HEAP32[$idx>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_iii(621,($s|0),($34|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     $40 = $37&65535;
     __THREW__ = 0;
     $41 = (invoke_iii(802,($__this|0),($40|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      HEAP32[$V_2>>2] = 0;
      __THREW__ = 0;
      $44 = (invoke_iiiiiiiiiii(2,($__this|0),($s|0),($idx|0),($end|0),($ti|0),($sortkey|0),($noLv4|0),($41|0),($V_2|0),($ctx|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       if ($44) {
        $47 = HEAP32[$7>>2]|0;
        $48 = ($47|0)==(0|0);
        if ($48) {
         $$0 = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $49 = HEAP32[$V_2>>2]|0;
        $notlhs6 = ($49|0)!=(0|0);
        $notrhs7 = ($41|0)!=(0);
        $or$cond2$not = $notrhs7 | $notlhs6;
        $or$cond3 = $or$cond2$not | $10;
        if ($or$cond3) {
         $$0 = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $50 = $6 >>> 3;
        $51 = (($47) + ($50)|0);
        $52 = HEAP8[$51>>0]|0;
        $53 = $52&255;
        $54 = $6 & 7;
        $55 = 1 << $54;
        $56 = $53 | $55;
        $57 = $56&255;
        HEAP8[$51>>0] = $57;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       } else {
        $58 = HEAP32[$21>>2]|0;
        $59 = ($58|0)==(0|0);
        if ($59) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $60 = HEAP32[$V_2>>2]|0;
        $notlhs = ($60|0)!=(0|0);
        $notrhs = ($41|0)!=(0);
        $or$cond4$not = $notrhs | $notlhs;
        $or$cond5 = $or$cond4$not | $10;
        if ($or$cond5) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $61 = $6 >>> 3;
        $62 = (($58) + ($61)|0);
        $63 = HEAP8[$62>>0]|0;
        $64 = $63&255;
        $65 = $6 & 7;
        $66 = 1 << $65;
        $67 = $64 | $66;
        $68 = $67&255;
        HEAP8[$62>>0] = $68;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOfOrdinalP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_ii($__this,$s,$target,$start,$length) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $V_2$0$be = 0, $V_2$09 = 0, $V_5$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275840);
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($target|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(1816,($s|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(3799,($target|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      $19 = (invoke_ii(1816,($target|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = ($14|0)<($19|0);
       if ($22) {
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($target|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_ii(1816,($target|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $28 = ($25|0)>($length|0);
         if ($28) {
          $$0 = -1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($target|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          __THREW__ = 0;
          $31 = (invoke_ii(1816,($target|0))|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           $34 = (($start) + -1)|0;
           $35 = (($34) - ($length))|0;
           $36 = (($35) + ($31))|0;
           __THREW__ = 0;
           invoke_vi(3799,($target|0));
           $37 = __THREW__; __THREW__ = 0;
           $38 = $37&1;
           if (!($38)) {
            __THREW__ = 0;
            $39 = (invoke_ii(1816,($target|0))|0);
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if (!($41)) {
             __THREW__ = 0;
             invoke_vi(3799,($target|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if (!($43)) {
              $44 = (($39) + -1)|0;
              __THREW__ = 0;
              $45 = (invoke_iii(621,($target|0),($44|0))|0);
              $46 = __THREW__; __THREW__ = 0;
              $47 = $46&1;
              if (!($47)) {
               $48 = ($36|0)<($start|0);
               if ($48) {
                $V_2$09 = $start;
               } else {
                $$0 = -1;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               L27: while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($s|0));
                $82 = __THREW__; __THREW__ = 0;
                $83 = $82&1;
                if ($83) {
                 label = 5;
                 break;
                }
                __THREW__ = 0;
                $49 = (invoke_iii(621,($s|0),($V_2$09|0))|0);
                $50 = __THREW__; __THREW__ = 0;
                $51 = $50&1;
                if ($51) {
                 label = 5;
                 break;
                }
                $52 = ($49<<16>>16)==($45<<16>>16);
                L31: do {
                 if ($52) {
                  __THREW__ = 0;
                  invoke_vi(3799,($target|0));
                  $54 = __THREW__; __THREW__ = 0;
                  $55 = $54&1;
                  if ($55) {
                   label = 5;
                   break L27;
                  }
                  __THREW__ = 0;
                  $56 = (invoke_ii(1816,($target|0))|0);
                  $57 = __THREW__; __THREW__ = 0;
                  $58 = $57&1;
                  if ($58) {
                   label = 5;
                   break L27;
                  }
                  $59 = (($V_2$09) - ($56))|0;
                  $60 = (($59) + 1)|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($target|0));
                  $61 = __THREW__; __THREW__ = 0;
                  $62 = $61&1;
                  if ($62) {
                   label = 5;
                   break L27;
                  }
                  __THREW__ = 0;
                  $63 = (invoke_ii(1816,($target|0))|0);
                  $64 = __THREW__; __THREW__ = 0;
                  $65 = $64&1;
                  if ($65) {
                   label = 5;
                   break L27;
                  }
                  $66 = (($63) + -2)|0;
                  $67 = ($66|0)>(-1);
                  if ($67) {
                   $V_5$02 = $66;
                  } else {
                   $$0 = $60;
                   label = 38;
                   break L27;
                  }
                  while(1) {
                   __THREW__ = 0;
                   invoke_vi(3799,($s|0));
                   $80 = __THREW__; __THREW__ = 0;
                   $81 = $80&1;
                   if ($81) {
                    label = 4;
                    break L27;
                   }
                   $68 = (($V_5$02) + ($60))|0;
                   __THREW__ = 0;
                   $69 = (invoke_iii(621,($s|0),($68|0))|0);
                   $70 = __THREW__; __THREW__ = 0;
                   $71 = $70&1;
                   if ($71) {
                    label = 4;
                    break L27;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($target|0));
                   $72 = __THREW__; __THREW__ = 0;
                   $73 = $72&1;
                   if ($73) {
                    label = 4;
                    break L27;
                   }
                   __THREW__ = 0;
                   $74 = (invoke_iii(621,($target|0),($V_5$02|0))|0);
                   $75 = __THREW__; __THREW__ = 0;
                   $76 = $75&1;
                   if ($76) {
                    label = 4;
                    break L27;
                   }
                   $77 = ($69<<16>>16)==($74<<16>>16);
                   if (!($77)) {
                    break L31;
                   }
                   $78 = (($V_5$02) + -1)|0;
                   $79 = ($V_5$02|0)>(0);
                   if ($79) {
                    $V_5$02 = $78;
                   } else {
                    $$0 = $60;
                    label = 38;
                    break L27;
                   }
                  }
                 }
                } while(0);
                $V_2$0$be = (($V_2$09) + -1)|0;
                $53 = ($V_2$0$be|0)>($36|0);
                if ($53) {
                 $V_2$09 = $V_2$0$be;
                } else {
                 $$0 = -1;
                 label = 38;
                 break;
                }
               }
               if ((label|0) == 4) {
                $6 = ___cxa_find_matching_catch()|0;
                $7 = tempRet0;
                $lpad$phi$index = $6;$lpad$phi$index3 = $7;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               else if ((label|0) == 5) {
                $8 = ___cxa_find_matching_catch()|0;
                $9 = tempRet0;
                $lpad$phi$index = $8;$lpad$phi$index3 = $9;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               else if ((label|0) == 38) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index3 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOfOrdinalIgnoreCaseP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_ii($__this,$s,$target,$start,$length) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$0$be = 0, $V_2$09 = 0, $V_5$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275888);
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($target|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(1816,($s|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = ($14|0)<($length|0);
     if ($17) {
      $$0 = -1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($target|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      $20 = (invoke_ii(1816,($target|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       $23 = ($20|0)>($length|0);
       if ($23) {
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($target|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        $26 = (invoke_ii(1816,($target|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         $29 = (($start) + -1)|0;
         $30 = (($29) - ($length))|0;
         $31 = (($30) + ($26))|0;
         $32 = (($__this) + 8|0);
         $33 = HEAP32[$32>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($target|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if (!($35)) {
          __THREW__ = 0;
          $36 = (invoke_ii(1816,($target|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if (!($38)) {
           __THREW__ = 0;
           invoke_vi(3799,($target|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            $41 = (($36) + -1)|0;
            __THREW__ = 0;
            $42 = (invoke_iii(621,($target|0),($41|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if (!($44)) {
             __THREW__ = 0;
             invoke_vi(3799,($33|0));
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if (!($46)) {
              __THREW__ = 0;
              $47 = (invoke_iiii(1667,(2274320|0),($33|0),($42|0))|0);
              $48 = __THREW__; __THREW__ = 0;
              $49 = $48&1;
              if (!($49)) {
               $50 = ($31|0)<($start|0);
               if ($50) {
                $V_2$09 = $start;
               } else {
                $$0 = -1;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               L27: while(1) {
                $54 = HEAP32[$32>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($s|0));
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 label = 5;
                 break;
                }
                __THREW__ = 0;
                $51 = (invoke_iii(621,($s|0),($V_2$09|0))|0);
                $52 = __THREW__; __THREW__ = 0;
                $53 = $52&1;
                if ($53) {
                 label = 5;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($54|0));
                $55 = __THREW__; __THREW__ = 0;
                $56 = $55&1;
                if ($56) {
                 label = 5;
                 break;
                }
                __THREW__ = 0;
                $57 = (invoke_iiii(1667,(2274320|0),($54|0),($51|0))|0);
                $58 = __THREW__; __THREW__ = 0;
                $59 = $58&1;
                if ($59) {
                 label = 5;
                 break;
                }
                $60 = ($57<<16>>16)==($47<<16>>16);
                L33: do {
                 if ($60) {
                  __THREW__ = 0;
                  invoke_vi(3799,($target|0));
                  $62 = __THREW__; __THREW__ = 0;
                  $63 = $62&1;
                  if ($63) {
                   label = 5;
                   break L27;
                  }
                  __THREW__ = 0;
                  $64 = (invoke_ii(1816,($target|0))|0);
                  $65 = __THREW__; __THREW__ = 0;
                  $66 = $65&1;
                  if ($66) {
                   label = 5;
                   break L27;
                  }
                  $67 = (($V_2$09) - ($64))|0;
                  $68 = (($67) + 1)|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($target|0));
                  $69 = __THREW__; __THREW__ = 0;
                  $70 = $69&1;
                  if ($70) {
                   label = 5;
                   break L27;
                  }
                  __THREW__ = 0;
                  $71 = (invoke_ii(1816,($target|0))|0);
                  $72 = __THREW__; __THREW__ = 0;
                  $73 = $72&1;
                  if ($73) {
                   label = 5;
                   break L27;
                  }
                  $74 = (($71) + -2)|0;
                  $75 = ($74|0)>(-1);
                  if ($75) {
                   $V_5$02 = $74;
                  } else {
                   $$0 = $68;
                   label = 44;
                   break L27;
                  }
                  while(1) {
                   $80 = HEAP32[$32>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($s|0));
                   $100 = __THREW__; __THREW__ = 0;
                   $101 = $100&1;
                   if ($101) {
                    label = 4;
                    break L27;
                   }
                   $76 = (($V_5$02) + ($68))|0;
                   __THREW__ = 0;
                   $77 = (invoke_iii(621,($s|0),($76|0))|0);
                   $78 = __THREW__; __THREW__ = 0;
                   $79 = $78&1;
                   if ($79) {
                    label = 4;
                    break L27;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($80|0));
                   $81 = __THREW__; __THREW__ = 0;
                   $82 = $81&1;
                   if ($82) {
                    label = 4;
                    break L27;
                   }
                   __THREW__ = 0;
                   $83 = (invoke_iiii(1667,(2274320|0),($80|0),($77|0))|0);
                   $84 = __THREW__; __THREW__ = 0;
                   $85 = $84&1;
                   if ($85) {
                    label = 4;
                    break L27;
                   }
                   $86 = HEAP32[$32>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($target|0));
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    label = 4;
                    break L27;
                   }
                   __THREW__ = 0;
                   $89 = (invoke_iii(621,($target|0),($V_5$02|0))|0);
                   $90 = __THREW__; __THREW__ = 0;
                   $91 = $90&1;
                   if ($91) {
                    label = 4;
                    break L27;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($86|0));
                   $92 = __THREW__; __THREW__ = 0;
                   $93 = $92&1;
                   if ($93) {
                    label = 4;
                    break L27;
                   }
                   __THREW__ = 0;
                   $94 = (invoke_iiii(1667,(2274320|0),($86|0),($89|0))|0);
                   $95 = __THREW__; __THREW__ = 0;
                   $96 = $95&1;
                   if ($96) {
                    label = 4;
                    break L27;
                   }
                   $97 = ($83<<16>>16)==($94<<16>>16);
                   if (!($97)) {
                    break L33;
                   }
                   $98 = (($V_5$02) + -1)|0;
                   $99 = ($V_5$02|0)>(0);
                   if ($99) {
                    $V_5$02 = $98;
                   } else {
                    $$0 = $68;
                    label = 44;
                    break L27;
                   }
                  }
                 }
                } while(0);
                $V_2$0$be = (($V_2$09) + -1)|0;
                $61 = ($V_2$0$be|0)>($31|0);
                if ($61) {
                 $V_2$09 = $V_2$0$be;
                } else {
                 $$0 = -1;
                 label = 44;
                 break;
                }
               }
               if ((label|0) == 4) {
                $6 = ___cxa_find_matching_catch()|0;
                $7 = tempRet0;
                $lpad$phi$index = $6;$lpad$phi$index3 = $7;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               else if ((label|0) == 5) {
                $8 = ___cxa_find_matching_catch()|0;
                $9 = tempRet0;
                $lpad$phi$index = $8;$lpad$phi$index3 = $9;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               else if ((label|0) == 44) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index3 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z274mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ContextU0026_refP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iiPhP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$target,$start,$length,$targetSortKey,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $target = $target|0;
 $start = $start|0;
 $length = $length|0;
 $targetSortKey = $targetSortKey|0;
 $ctx = $ctx|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $$13 = 0, $$ph = 0, $$ph32 = 0, $$targetSortKey = 0, $$targetSortKey11$ph = 0, $$targetSortKey919$ph = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B10_0$0716$ph = 0, $G_B10_0$0720$ph = 0, $V_2$0 = 0, $V_2$1 = 0, $V_2$1$in = 0, $V_6$0$off018$ph = 0, $V_6$0$off022$ph = 0, $V_7$017$ph = 0, $V_7$021$ph = 0, $V_8$0 = 0, $V_9$0 = 0, $V_9$125 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275984);
 $0 = HEAP32[$ctx>>2]|0;
 $V_2$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($target|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   label = 9;
   break;
  }
  __THREW__ = 0;
  $23 = (invoke_ii(1816,($target|0))|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 9;
   break;
  }
  $26 = ($V_2$0|0)<($23|0);
  if (!($26)) {
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($target|0));
  $27 = __THREW__; __THREW__ = 0;
  $28 = $27&1;
  if ($28) {
   label = 9;
   break;
  }
  __THREW__ = 0;
  $1 = (invoke_iii(621,($target|0),($V_2$0|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if ($3) {
   label = 9;
   break;
  }
  $4 = $1&65535;
  __THREW__ = 0;
  $5 = (invoke_iiii(746,0,($4|0),($0|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 9;
   break;
  }
  $8 = (($V_2$0) + 1)|0;
  if ($5) {
   $V_2$0 = $8;
  } else {
   break;
  }
 }
 if ((label|0) == 9) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  $lpad$phi$index = $17;$lpad$phi$index6 = $18;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3799,($target|0));
 $29 = __THREW__; __THREW__ = 0;
 $30 = $29&1;
 L13: do {
  if (!($30)) {
   __THREW__ = 0;
   $31 = (invoke_ii(1816,($target|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    $34 = ($V_2$0|0)==($31|0);
    if ($34) {
     $$0 = $start;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($target|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __THREW__ = 0;
     $37 = (invoke_ii(1816,($target|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      $40 = (($37) - ($V_2$0))|0;
      __THREW__ = 0;
      $41 = (invoke_iiiii(122,($__this|0),($target|0),($V_2$0|0),($40|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       $44 = ($41|0)==(0|0);
       L22: do {
        if ($44) {
         $45 = ($targetSortKey|0)==(0|0);
         if ($45) {
          $$ph = 0;$$targetSortKey11$ph = 0;$G_B10_0$0716$ph = 0;$V_6$0$off018$ph = 1;$V_7$017$ph = -1;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           break L13;
          }
          __THREW__ = 0;
          $85 = (invoke_iii(621,($target|0),($V_2$0|0))|0);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           break L13;
          }
          $88 = $85&65535;
          __THREW__ = 0;
          $89 = (invoke_iiii(743,($__this|0),($88|0),($0|0))|0);
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           break L13;
          }
          __THREW__ = 0;
          $92 = (invoke_iii(799,($__this|0),($89|0))|0);
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           break L13;
          }
          HEAP8[$targetSortKey>>0] = $92;
          __THREW__ = 0;
          $95 = (invoke_iii(800,($__this|0),($89|0))|0);
          $96 = __THREW__; __THREW__ = 0;
          $97 = $96&1;
          if ($97) {
           break L13;
          }
          $98 = (($targetSortKey) + 1|0);
          HEAP8[$98>>0] = $95;
          $99 = $0 & 2;
          $100 = ($99|0)==(0);
          if ($100) {
           __THREW__ = 0;
           $101 = (invoke_iiii(740,($__this|0),($89|0),0)|0);
           $102 = __THREW__; __THREW__ = 0;
           $103 = $102&1;
           if ($103) {
            break L13;
           }
           $104 = (($targetSortKey) + 2|0);
           HEAP8[$104>>0] = $101;
          }
          __THREW__ = 0;
          $105 = (invoke_iii(789,(0|0),($89|0))|0);
          $106 = __THREW__; __THREW__ = 0;
          $107 = $106&1;
          if ($107) {
           break L13;
          }
          $108 = (($targetSortKey) + 3|0);
          HEAP8[$108>>0] = $105;
          $109 = $89&65535;
          __THREW__ = 0;
          $110 = (invoke_iii(793,(0|0),($109|0))|0);
          $111 = __THREW__; __THREW__ = 0;
          $112 = $111&1;
          if ($112) {
           break L13;
          }
          $113 = $110 ^ 1;
          $$ph32 = 0;$$targetSortKey919$ph = $targetSortKey;$G_B10_0$0720$ph = 0;$V_6$0$off022$ph = $113;$V_7$021$ph = $89;
          label = 48;
         }
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($41|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          break L13;
         }
         $48 = (($41) + 12|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ($49|0)!=(0|0);
         $$targetSortKey = $50 ? 0 : $targetSortKey;
         $51 = ($$targetSortKey|0)==(0|0);
         if ($51) {
          $$ph = $50;$$targetSortKey11$ph = 0;$G_B10_0$0716$ph = $49;$V_6$0$off018$ph = 1;$V_7$017$ph = -1;
         } else {
          $52 = (($41) + 16|0);
          $V_8$0 = 0;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($41|0));
           $73 = __THREW__; __THREW__ = 0;
           $74 = $73&1;
           if ($74) {
            break;
           }
           $75 = HEAP32[$52>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($75|0));
           $76 = __THREW__; __THREW__ = 0;
           $77 = $76&1;
           if ($77) {
            break;
           }
           $78 = (($75) + 12|0);
           $79 = HEAP32[$78>>2]|0;
           $80 = ($V_8$0|0)<($79|0);
           if (!($80)) {
            $$ph32 = $50;$$targetSortKey919$ph = $$targetSortKey;$G_B10_0$0720$ph = $49;$V_6$0$off022$ph = 1;$V_7$021$ph = -1;
            label = 48;
            break L22;
           }
           $71 = (($$targetSortKey) + ($V_8$0)|0);
           __THREW__ = 0;
           invoke_vi(3799,($41|0));
           $81 = __THREW__; __THREW__ = 0;
           $82 = $81&1;
           if ($82) {
            break;
           }
           $53 = HEAP32[$52>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($53|0));
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if ($55) {
            break;
           }
           $56 = (($53) + 12|0);
           $57 = HEAP32[$56>>2]|0;
           $58 = ($V_8$0>>>0)<($57>>>0);
           if (!($58)) {
            __THREW__ = 0;
            $59 = (invoke_i(132)|0);
            $60 = __THREW__; __THREW__ = 0;
            $61 = $60&1;
            if ($61) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($59|0));
            $62 = __THREW__; __THREW__ = 0;
            $63 = $62&1;
            if ($63) {
             break;
            }
           }
           $64 = HEAP32[$53>>2]|0;
           $65 = (($53) + 16|0);
           $66 = (($64) + 92|0);
           $67 = HEAP32[$66>>2]|0;
           $68 = Math_imul($67, $V_8$0)|0;
           $69 = (($65) + ($68)|0);
           $70 = HEAP8[$69>>0]|0;
           HEAP8[$71>>0] = $70;
           $72 = (($V_8$0) + 1)|0;
           $V_8$0 = $72;
          }
          $15 = ___cxa_find_matching_catch()|0;
          $16 = tempRet0;
          $lpad$phi$index = $15;$lpad$phi$index6 = $16;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
        }
       } while(0);
       L52: do {
        if ((label|0) == 48) {
         $114 = (($$targetSortKey919$ph) + 2|0);
         $V_2$1$in = $V_2$0;
         while(1) {
          $V_2$1 = (($V_2$1$in) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           break;
          }
          __THREW__ = 0;
          $141 = (invoke_ii(1816,($target|0))|0);
          $142 = __THREW__; __THREW__ = 0;
          $143 = $142&1;
          if ($143) {
           break;
          }
          $144 = ($V_2$1|0)<($141|0);
          if (!($144)) {
           $$ph = $$ph32;$$targetSortKey11$ph = $$targetSortKey919$ph;$G_B10_0$0716$ph = $G_B10_0$0720$ph;$V_6$0$off018$ph = $V_6$0$off022$ph;$V_7$017$ph = $V_7$021$ph;
           break L52;
          }
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          if ($146) {
           break;
          }
          __THREW__ = 0;
          $115 = (invoke_iii(621,($target|0),($V_2$1|0))|0);
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           break;
          }
          $118 = $115&65535;
          __THREW__ = 0;
          $119 = (invoke_iii(799,($__this|0),($118|0))|0);
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           break;
          }
          $122 = ($119<<24>>24)==(1);
          if (!($122)) {
           $$ph = $$ph32;$$targetSortKey11$ph = $$targetSortKey919$ph;$G_B10_0$0716$ph = $G_B10_0$0720$ph;$V_6$0$off018$ph = $V_6$0$off022$ph;$V_7$017$ph = $V_7$021$ph;
           break L52;
          }
          $123 = HEAP8[$114>>0]|0;
          $124 = ($123<<24>>24)==(0);
          if ($124) {
           HEAP8[$114>>0] = 2;
           $126 = 2;
          } else {
           $126 = $123;
          }
          $125 = $126&255;
          __THREW__ = 0;
          invoke_vi(3799,($target|0));
          $127 = __THREW__; __THREW__ = 0;
          $128 = $127&1;
          if ($128) {
           break;
          }
          __THREW__ = 0;
          $129 = (invoke_iii(621,($target|0),($V_2$1|0))|0);
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           break;
          }
          $132 = $129&65535;
          __THREW__ = 0;
          $133 = (invoke_iiii(740,($__this|0),($132|0),0)|0);
          $134 = __THREW__; __THREW__ = 0;
          $135 = $134&1;
          if ($135) {
           break;
          }
          $136 = $133&255;
          $137 = (($136) + ($125))|0;
          $138 = $137&255;
          HEAP8[$114>>0] = $138;
          $V_2$1$in = $V_2$1;
         }
         $13 = ___cxa_find_matching_catch()|0;
         $14 = tempRet0;
         $lpad$phi$index = $13;$lpad$phi$index6 = $14;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
       } while(0);
       $$01 = $start;$$02 = $length;
       while(1) {
        if ($$ph) {
         __THREW__ = 0;
         $147 = (invoke_iiiiiiii(80,($__this|0),($s|0),($G_B10_0$0716$ph|0),($$01|0),($$02|0),($targetSortKey|0),($ctx|0))|0);
         $148 = __THREW__; __THREW__ = 0;
         $149 = $148&1;
         if ($149) {
          label = 6;
          break;
         } else {
          $V_9$0 = $147;
         }
        } else {
         __THREW__ = 0;
         $150 = (invoke_iiiiiiiiii(5,($__this|0),($s|0),($$01|0),($start|0),($$02|0),($$targetSortKey11$ph|0),($V_7$017$ph|0),($V_6$0$off018$ph|0),($ctx|0))|0);
         $151 = __THREW__; __THREW__ = 0;
         $152 = $151&1;
         if ($152) {
          label = 6;
          break;
         } else {
          $V_9$0 = $150;
         }
        }
        $153 = ($V_9$0|0)>(-1);
        if (!($153)) {
         $$0 = -1;
         label = 84;
         break;
        }
        $154 = (($V_9$0) - ($$01))|0;
        $155 = (($154) + ($$02))|0;
        $156 = (($start) - ($V_9$0))|0;
        $157 = (($156) + 1)|0;
        __THREW__ = 0;
        $158 = (invoke_iiiiiiii(78,($__this|0),($s|0),($target|0),($V_9$0|0),($157|0),0,($ctx|0))|0);
        $159 = __THREW__; __THREW__ = 0;
        $160 = $159&1;
        if ($160) {
         label = 6;
         break;
        }
        if ($158) {
         label = 68;
         break;
        }
        __THREW__ = 0;
        $173 = (invoke_iiiii(122,($__this|0),($s|0),($V_9$0|0),($157|0))|0);
        $174 = __THREW__; __THREW__ = 0;
        $175 = $174&1;
        if ($175) {
         label = 6;
         break;
        }
        $176 = ($173|0)==(0|0);
        if ($176) {
         $194 = (($V_9$0) + -1)|0;
         $195 = (($155) + -1)|0;
         $$1 = $194;$$13 = $195;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($173|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          label = 6;
          break;
         }
         $179 = (($173) + 8|0);
         $180 = HEAP32[$179>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($180|0));
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if ($182) {
          label = 6;
          break;
         }
         $183 = (($180) + 12|0);
         $184 = HEAP32[$183>>2]|0;
         $185 = (($V_9$0) - ($184))|0;
         __THREW__ = 0;
         invoke_vi(3799,($173|0));
         $186 = __THREW__; __THREW__ = 0;
         $187 = $186&1;
         if ($187) {
          label = 6;
          break;
         }
         $188 = HEAP32[$179>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($188|0));
         $189 = __THREW__; __THREW__ = 0;
         $190 = $189&1;
         if ($190) {
          label = 6;
          break;
         }
         $191 = (($188) + 12|0);
         $192 = HEAP32[$191>>2]|0;
         $193 = (($155) - ($192))|0;
         $$1 = $185;$$13 = $193;
        }
        $196 = ($$13|0)>(0);
        if ($196) {
         $$01 = $$1;$$02 = $$13;
        } else {
         $$0 = -1;
         label = 84;
         break;
        }
       }
       if ((label|0) == 6) {
        $11 = ___cxa_find_matching_catch()|0;
        $12 = tempRet0;
        $lpad$phi$index = $11;$lpad$phi$index6 = $12;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 68) {
        $161 = ($V_9$0|0)<($start|0);
        if (!($161)) {
         $$0 = $V_9$0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $V_9$125 = $V_9$0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $171 = __THREW__; __THREW__ = 0;
         $172 = $171&1;
         if ($172) {
          label = 5;
          break;
         }
         __THREW__ = 0;
         $162 = (invoke_iii(621,($s|0),($V_9$125|0))|0);
         $163 = __THREW__; __THREW__ = 0;
         $164 = $163&1;
         if ($164) {
          label = 5;
          break;
         }
         $165 = $162&65535;
         __THREW__ = 0;
         $166 = (invoke_iiii(746,0,($165|0),($0|0))|0);
         $167 = __THREW__; __THREW__ = 0;
         $168 = $167&1;
         if ($168) {
          label = 5;
          break;
         }
         $169 = (($V_9$125) + 1)|0;
         if (!($166)) {
          $$0 = $V_9$125;
          label = 84;
          break;
         }
         $170 = ($169|0)<($start|0);
         if ($170) {
          $V_9$125 = $169;
         } else {
          $$0 = $169;
          label = 84;
          break;
         }
        }
        if ((label|0) == 5) {
         $9 = ___cxa_find_matching_catch()|0;
         $10 = tempRet0;
         $lpad$phi$index = $9;$lpad$phi$index6 = $10;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 84) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 84) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $lpad$phi$index = $19;$lpad$phi$index6 = $20;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOfSortKeyP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiiPhibP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$start,$orgStart,$length,$sortkey,$ti,$noLv4,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $start = $start|0;
 $orgStart = $orgStart|0;
 $length = $length|0;
 $sortkey = $sortkey|0;
 $ti = $ti|0;
 $noLv4 = $noLv4|0;
 $ctx = $ctx|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2275936);
 $0 = (($start) - ($length))|0;
 HEAP32[$V_1>>2] = $start;
 $4 = $start;
 while(1) {
  $3 = ($4|0)>($0|0);
  if (!($3)) {
   $$0 = -1;
   label = 7;
   break;
  }
  __THREW__ = 0;
  $5 = (invoke_iiiiiiiiii(6,($__this|0),($s|0),($V_1|0),($0|0),($orgStart|0),($ti|0),($sortkey|0),($noLv4|0),($ctx|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 4;
   break;
  }
  if ($5) {
   $$0 = $4;
   label = 7;
   break;
  }
  $$pre = HEAP32[$V_1>>2]|0;
  $4 = $$pre;
 }
 if ((label|0) == 4) {
  $1 = ___cxa_find_matching_catch()|0;
  $2 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($1|0);
  // unreachable;
 }
 else if ((label|0) == 7) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesBackwardP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringPiiiiPhbP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$idx,$end,$orgStart,$ti,$sortkey,$noLv4,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $idx = $idx|0;
 $end = $end|0;
 $orgStart = $orgStart|0;
 $ti = $ti|0;
 $sortkey = $sortkey|0;
 $noLv4 = $noLv4|0;
 $ctx = $ctx|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2 = 0, $_stackTraceSentry = 0, $notlhs = 0, $notlhs6 = 0, $notrhs = 0, $notrhs7 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2$not = 0, $or$cond3 = 0;
 var $or$cond4$not = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2276176);
 HEAP32[$V_2>>2] = 0;
 $0 = HEAP32[$idx>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(621,($s|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = $3&65535;
   $7 = (($ctx) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   $10 = ($3&65535)>(127);
   $or$cond = $9 | $10;
   if (!($or$cond)) {
    $13 = $6 >>> 3;
    $14 = (($8) + ($13)|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = $15&255;
    $17 = $6 & 7;
    $18 = 1 << $17;
    $19 = $16 & $18;
    $20 = ($19|0)==(0);
    if (!($20)) {
     $$0 = 1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   $21 = (($ctx) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   $or$cond1 = $23 | $10;
   if (!($or$cond1)) {
    $24 = $6 >>> 3;
    $25 = (($22) + ($24)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26&255;
    $28 = $6 & 7;
    $29 = 1 << $28;
    $30 = $27 & $29;
    $31 = ($30|0)==(0);
    if (!($31)) {
     $32 = HEAP32[$idx>>2]|0;
     $33 = (($32) + -1)|0;
     HEAP32[$idx>>2] = $33;
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   $34 = HEAP32[$idx>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    __THREW__ = 0;
    $37 = (invoke_iii(621,($s|0),($34|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     $40 = $37&65535;
     __THREW__ = 0;
     $41 = (invoke_iii(802,($__this|0),($40|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      HEAP32[$V_2>>2] = 0;
      __THREW__ = 0;
      $44 = (invoke_iiiiiiiiiiii(1,($__this|0),($s|0),($idx|0),($end|0),($orgStart|0),($ti|0),($sortkey|0),($noLv4|0),($41|0),($V_2|0),($ctx|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       if ($44) {
        $47 = HEAP32[$7>>2]|0;
        $48 = ($47|0)==(0|0);
        if ($48) {
         $$0 = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $49 = HEAP32[$V_2>>2]|0;
        $notlhs6 = ($49|0)!=(0|0);
        $notrhs7 = ($41|0)!=(0);
        $or$cond2$not = $notrhs7 | $notlhs6;
        $or$cond3 = $or$cond2$not | $10;
        if ($or$cond3) {
         $$0 = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $50 = $6 >>> 3;
        $51 = (($47) + ($50)|0);
        $52 = HEAP8[$51>>0]|0;
        $53 = $52&255;
        $54 = $6 & 7;
        $55 = 1 << $54;
        $56 = $53 | $55;
        $57 = $56&255;
        HEAP8[$51>>0] = $57;
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       } else {
        $58 = HEAP32[$21>>2]|0;
        $59 = ($58|0)==(0|0);
        if ($59) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $60 = HEAP32[$V_2>>2]|0;
        $notlhs = ($60|0)!=(0|0);
        $notrhs = ($41|0)!=(0);
        $or$cond4$not = $notrhs | $notlhs;
        $or$cond5 = $or$cond4$not | $10;
        if ($or$cond5) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $61 = $6 >>> 3;
        $62 = (($58) + ($61)|0);
        $63 = HEAP8[$62>>0]|0;
        $64 = $63&255;
        $65 = $6 & 7;
        $66 = 1 << $65;
        $67 = $64 | $66;
        $68 = $67&255;
        HEAP8[$62>>0] = $68;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesForwardCoreP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringPiiiPhbiPP47mscorlib_Mono_Globalization_Unicode_ContractionP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$idx,$end,$ti,$sortkey,$noLv4,$ext,$ct,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $idx = $idx|0;
 $end = $end|0;
 $ti = $ti|0;
 $sortkey = $sortkey|0;
 $noLv4 = $noLv4|0;
 $ext = $ext|0;
 $ct = $ct|0;
 $ctx = $ctx|0;
 var $$0 = 0, $$lobit = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_1$0$ph = 0, $V_3$0 = 0, $V_3$0$ph = 0, $V_3$1 = 0, $V_3$2$ph = 0, $V_5 = 0, $V_6$0$off0 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_5 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2276080);
 HEAP32[$V_5>>2] = 0;
 $0 = HEAP32[$ctx>>2]|0;
 $1 = (($ctx) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $$lobit = $0 >>> 1;
 $3 = ($ext|0)==(0);
 do {
  if ($3) {
   $4 = HEAP32[$idx>>2]|0;
   __THREW__ = 0;
   $5 = (invoke_iiiii(122,($__this|0),($s|0),($4|0),($end|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    HEAP32[$ct>>2] = $5;
    $26 = $5;$V_1$0 = $2;$V_3$0 = -1;
    label = 13;
   }
  } else {
   $14 = (($ctx) + 20|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)>(-1);
   if ($16) {
    __THREW__ = 0;
    $22 = (invoke_iiiii(124,($__this|0),($15|0),($ext|0),($0|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    } else {
     $V_1$0$ph = $2;$V_3$0$ph = $22;
    }
   } else {
    $17 = (($ctx) + 24|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $20 = HEAP32[$idx>>2]|0;
     $21 = (($20) + 1)|0;
     HEAP32[$idx>>2] = $21;
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     $V_1$0$ph = $18;$V_3$0$ph = -1;
    }
   }
   $$pr = HEAP32[$ct>>2]|0;
   $26 = $$pr;$V_1$0 = $V_1$0$ph;$V_3$0 = $V_3$0$ph;
   label = 13;
  }
 } while(0);
 L11: do {
  if ((label|0) == 13) {
   $25 = ($26|0)==(0|0);
   do {
    if ($25) {
     $73 = ($V_3$0|0)>(-1);
     if ($73) {
      $V_3$1 = $V_3$0;
     } else {
      $74 = HEAP32[$idx>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       break L11;
      }
      __THREW__ = 0;
      $77 = (invoke_iii(621,($s|0),($74|0))|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       break L11;
      }
      $80 = $77&65535;
      __THREW__ = 0;
      $81 = (invoke_iiii(743,($__this|0),($80|0),($0|0))|0);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break L11;
      } else {
       $V_3$1 = $81;
      }
     }
     $84 = HEAP32[$idx>>2]|0;
     $85 = (($84) + 1)|0;
     HEAP32[$idx>>2] = $85;
     __THREW__ = 0;
     $86 = (invoke_iii(799,($__this|0),($V_3$1|0))|0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      break L11;
     }
     HEAP8[$V_1$0>>0] = $86;
     $89 = HEAP8[$sortkey>>0]|0;
     $90 = ($89<<24>>24)==($86<<24>>24);
     if ($90) {
      __THREW__ = 0;
      $91 = (invoke_iii(800,($__this|0),($V_3$1|0))|0);
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break L11;
      }
      $94 = (($V_1$0) + 1|0);
      HEAP8[$94>>0] = $91;
      $V_6$0$off0 = 0;
     } else {
      $V_6$0$off0 = 1;
     }
     $95 = $$lobit & 1;
     $96 = ($95|0)==(0);
     if ($96) {
      $97 = (($sortkey) + 1|0);
      $98 = HEAP8[$97>>0]|0;
      $99 = (($V_1$0) + 1|0);
      $100 = HEAP8[$99>>0]|0;
      $101 = ($98<<24>>24)==($100<<24>>24);
      if ($101) {
       __THREW__ = 0;
       $102 = (invoke_iiii(740,($__this|0),($V_3$1|0),($ext|0))|0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        break L11;
       }
       $105 = (($V_1$0) + 2|0);
       HEAP8[$105>>0] = $102;
       if (!($V_6$0$off0)) {
        label = 45;
       }
      }
     } else {
      if (!($V_6$0$off0)) {
       label = 45;
      }
     }
     if ((label|0) == 45) {
      __THREW__ = 0;
      $122 = (invoke_iii(789,(0|0),($V_3$1|0))|0);
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       break L11;
      }
      $125 = (($V_1$0) + 3|0);
      HEAP8[$125>>0] = $122;
      $126 = HEAP8[$V_1$0>>0]|0;
      $127 = ($126<<24>>24)==(1);
      if ($127) {
       $V_3$2$ph = $V_3$1;
       break;
      }
      $128 = (($ctx) + 20|0);
      HEAP32[$128>>2] = $V_3$1;
      $V_3$2$ph = $V_3$1;
      break;
     }
     $106 = HEAP32[$idx>>2]|0;
     $107 = ($106|0)<($end|0);
     if (!($107)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $108 = $106;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $109 = (invoke_iii(621,($s|0),($108|0))|0);
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       label = 4;
       break;
      }
      $112 = $109&65535;
      __THREW__ = 0;
      $113 = (invoke_iii(799,($__this|0),($112|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       label = 4;
       break;
      }
      $116 = ($113<<24>>24)==(1);
      if (!($116)) {
       $$0 = 0;
       label = 63;
       break;
      }
      $117 = HEAP32[$idx>>2]|0;
      $118 = (($117) + 1)|0;
      HEAP32[$idx>>2] = $118;
      $119 = ($118|0)<($end|0);
      if ($119) {
       $108 = $118;
      } else {
       $$0 = 0;
       label = 63;
       break;
      }
     }
     if ((label|0) == 4) {
      $8 = ___cxa_find_matching_catch()|0;
      $9 = tempRet0;
      $lpad$phi$index = $8;$lpad$phi$index3 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 63) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     $27 = HEAP32[$idx>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break L11;
     }
     $30 = (($26) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($31|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break L11;
     }
     $34 = (($31) + 12|0);
     $35 = HEAP32[$34>>2]|0;
     $36 = (($35) + ($27))|0;
     HEAP32[$idx>>2] = $36;
     if (!($noLv4)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $37 = HEAP32[$ct>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($37|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break L11;
     }
     $40 = (($37) + 16|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if (!($42)) {
      $43 = HEAP8[$sortkey>>0]|0;
      HEAP8[$V_1$0>>0] = $43;
      $44 = (($V_1$0) + 1|0);
      $45 = (($sortkey) + 1|0);
      $46 = HEAP8[$45>>0]|0;
      HEAP8[$44>>0] = $46;
      $47 = (($V_1$0) + 2|0);
      $48 = (($sortkey) + 2|0);
      $49 = HEAP8[$48>>0]|0;
      HEAP8[$47>>0] = $49;
      $50 = (($V_1$0) + 3|0);
      $51 = (($sortkey) + 3|0);
      $52 = HEAP8[$51>>0]|0;
      HEAP8[$50>>0] = $52;
      $53 = (($ctx) + 20|0);
      HEAP32[$53>>2] = -1;
      $54 = (($ctx) + 24|0);
      HEAP32[$54>>2] = $V_1$0;
      $V_3$2$ph = $V_3$0;
      break;
     }
     HEAP32[$V_5>>2] = 0;
     $55 = HEAP32[$ct>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($55|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break L11;
     }
     $58 = (($55) + 12|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = HEAP32[$ct>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($60|0));
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      break L11;
     }
     $63 = (($60) + 12|0);
     $64 = HEAP32[$63>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($64|0));
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break L11;
     }
     __THREW__ = 0;
     $67 = (invoke_ii(1816,($64|0))|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break L11;
     }
     __THREW__ = 0;
     $70 = (invoke_iiiiiiiii(11,($__this|0),($59|0),($V_5|0),($67|0),($ti|0),($sortkey|0),1,($ctx|0))|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      break L11;
     } else {
      $$0 = $70;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   $129 = HEAP32[$idx>>2]|0;
   $130 = ($129|0)<($end|0);
   L65: do {
    if ($130) {
     $131 = $$lobit & 1;
     $132 = ($131|0)==(0);
     $133 = (($V_1$0) + 2|0);
     $134 = $129;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $163 = __THREW__; __THREW__ = 0;
      $164 = $163&1;
      if ($164) {
       break;
      }
      __THREW__ = 0;
      $135 = (invoke_iii(621,($s|0),($134|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break;
      }
      $138 = $135&65535;
      __THREW__ = 0;
      $139 = (invoke_iii(799,($__this|0),($138|0))|0);
      $140 = __THREW__; __THREW__ = 0;
      $141 = $140&1;
      if ($141) {
       break;
      }
      $142 = ($139<<24>>24)==(1);
      if (!($142)) {
       break L65;
      }
      if ($132) {
       $143 = HEAP8[$133>>0]|0;
       $144 = ($143<<24>>24)==(0);
       if ($144) {
        HEAP8[$133>>0] = 2;
        $146 = 2;
       } else {
        $146 = $143;
       }
       $145 = $146&255;
       $147 = HEAP32[$idx>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $148 = __THREW__; __THREW__ = 0;
       $149 = $148&1;
       if ($149) {
        break;
       }
       __THREW__ = 0;
       $150 = (invoke_iii(621,($s|0),($147|0))|0);
       $151 = __THREW__; __THREW__ = 0;
       $152 = $151&1;
       if ($152) {
        break;
       }
       $153 = $150&65535;
       __THREW__ = 0;
       $154 = (invoke_iiii(740,($__this|0),($153|0),0)|0);
       $155 = __THREW__; __THREW__ = 0;
       $156 = $155&1;
       if ($156) {
        break;
       }
       $157 = $154&255;
       $158 = (($157) + ($145))|0;
       $159 = $158&255;
       HEAP8[$133>>0] = $159;
      }
      $160 = HEAP32[$idx>>2]|0;
      $161 = (($160) + 1)|0;
      HEAP32[$idx>>2] = $161;
      $162 = ($161|0)<($end|0);
      if ($162) {
       $134 = $161;
      } else {
       break L65;
      }
     }
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index3 = $11;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   } while(0);
   __THREW__ = 0;
   $165 = (invoke_iiiiiiiii(12,0,($0|0),($V_1$0|0),($V_3$2$ph|0),($ext|0),($sortkey|0),($ti|0),($noLv4|0))|0);
   $166 = __THREW__; __THREW__ = 0;
   $167 = $166&1;
   if (!($167)) {
    $$0 = $165;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index3 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesPrimitiveP50mscorlib_Mono_Globalization_Unicode_SimpleCollatoriPhiiS1_ib($__this,$opt,$source,$si,$ext,$target,$ti,$noLv4) {
 $__this = $__this|0;
 $opt = $opt|0;
 $source = $source|0;
 $si = $si|0;
 $ext = $ext|0;
 $target = $target|0;
 $ti = $ti|0;
 $noLv4 = $noLv4|0;
 var $$0 = 0, $$lobit = 0, $$not = 0, $$not1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, $not$tmp = 0, $or$cond = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2276128);
 $$lobit = $opt & 2;
 $0 = ($$lobit|0)!=(0);
 $1 = HEAP8[$source>>0]|0;
 $2 = HEAP8[$target>>0]|0;
 $3 = ($1<<24>>24)==($2<<24>>24);
 do {
  if ($3) {
   $4 = (($source) + 1|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = (($target) + 1|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = ($5<<24>>24)==($7<<24>>24);
   if ($8) {
    if (!($0)) {
     $9 = (($source) + 2|0);
     $10 = HEAP8[$9>>0]|0;
     $11 = (($target) + 2|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($10<<24>>24)==($12<<24>>24);
     if (!($13)) {
      $$0 = 0;
      break;
     }
    }
    $14 = (($source) + 3|0);
    $15 = HEAP8[$14>>0]|0;
    $16 = (($target) + 3|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($15<<24>>24)==($17<<24>>24);
    if ($18) {
     if ($noLv4) {
      $19 = ($si|0)<(0);
      if ($19) {
       $$0 = 1;
       break;
      }
      $20 = $si&65535;
      __THREW__ = 0;
      $21 = (invoke_iii(793,(0|0),($20|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       $$not1 = $21 ^ 1;
       $$0 = $$not1;
       break;
      }
     } else {
      $$not = $0 ^ 1;
      $26 = ($ext|0)==(3);
      $or$cond = $26 & $$not;
      if ($or$cond) {
       $$0 = 0;
       break;
      }
      $27 = $si&65535;
      __THREW__ = 0;
      $28 = (invoke_iii(796,(0|0),($27|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = $ti&65535;
       __THREW__ = 0;
       $32 = (invoke_iii(796,(0|0),($31|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        $35 = $28 ^ $32;
        if ($35) {
         $$0 = 0;
         break;
        }
        __THREW__ = 0;
        $36 = (invoke_iiii(745,0,($ext|0),($opt|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         __THREW__ = 0;
         $39 = (invoke_iiii(745,0,0,($opt|0))|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = ($36<<24>>24)==($39<<24>>24);
          if (!($42)) {
           $$0 = 0;
           break;
          }
          __THREW__ = 0;
          $43 = (invoke_iii(795,(0|0),($27|0))|0);
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if (!($45)) {
           __THREW__ = 0;
           $46 = (invoke_iii(795,(0|0),($31|0))|0);
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if (!($48)) {
            $49 = $43 ^ $46;
            if ($49) {
             $$0 = 0;
             break;
            }
            $50 = $si & 65535;
            __THREW__ = 0;
            $51 = (invoke_iiii(742,0,($50|0),($opt|0))|0);
            $52 = __THREW__; __THREW__ = 0;
            $53 = $52&1;
            if (!($53)) {
             $54 = $ti & 65535;
             __THREW__ = 0;
             $55 = (invoke_iiii(742,0,($54|0),($opt|0))|0);
             $56 = __THREW__; __THREW__ = 0;
             $57 = $56&1;
             if (!($57)) {
              $tmp = $51 ^ $55;
              $not$tmp = $tmp ^ 1;
              $$0 = $not$tmp;
              break;
             }
            }
           }
          }
         }
        }
       }
      }
     }
     $24 = ___cxa_find_matching_catch()|0;
     $25 = tempRet0;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($24|0);
     // unreachable;
    } else {
     $$0 = 0;
    }
   } else {
    $$0 = 0;
   }
  } else {
   $$0 = 0;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z72mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesBackwardCoreP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringPiiiiPhbiPP47mscorlib_Mono_Globalization_Unicode_ContractionP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context($__this,$s,$idx,$end,$orgStart,$ti,$sortkey,$noLv4,$ext,$ct,$ctx) {
 $__this = $__this|0;
 $s = $s|0;
 $idx = $idx|0;
 $end = $end|0;
 $orgStart = $orgStart|0;
 $ti = $ti|0;
 $sortkey = $sortkey|0;
 $noLv4 = $noLv4|0;
 $ext = $ext|0;
 $ct = $ct|0;
 $ctx = $ctx|0;
 var $$0 = 0, $$lobit = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_11$0$off0 = 0, $V_12$0 = 0, $V_12$010 = 0, $V_12$09 = 0, $V_4$04 = 0, $V_4$1 = 0;
 var $V_4$2 = 0, $V_4$28 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2276224);
 $0 = HEAP32[$ctx>>2]|0;
 $1 = (($ctx) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $$lobit = $0 >>> 1;
 $3 = HEAP32[$idx>>2]|0;
 $4 = ($ext|0)!=(0);
 L1: do {
  if ($4) {
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   do {
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(621,($s|0),0)|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = $7&65535;
      __THREW__ = 0;
      $11 = (invoke_iiii(746,0,($10|0),($0|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       if ($11) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        $22 = (invoke_iii(621,($s|0),0)|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         $25 = $22&65535;
         __THREW__ = 0;
         $26 = (invoke_iiii(743,($__this|0),($25|0),($0|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          __THREW__ = 0;
          $29 = (invoke_iii(799,($__this|0),($26|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           $32 = ($29<<24>>24)==(1);
           if ($32) {
            __THREW__ = 0;
            (invoke_iiii(740,($__this|0),($26|0),0)|0);
            $33 = __THREW__; __THREW__ = 0;
            $34 = $33&1;
            if ($34) {
             break;
            } else {
             $$0 = 0;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           $35 = (invoke_iiiii(124,($__this|0),($26|0),($ext|0),($0|0))|0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break L1;
           }
           HEAP8[$2>>0] = $29;
           __THREW__ = 0;
           $38 = (invoke_iii(800,($__this|0),($35|0))|0);
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if ($40) {
            break L1;
           }
           $41 = (($2) + 1|0);
           HEAP8[$41>>0] = $38;
           $42 = $$lobit & 1;
           $43 = ($42|0)==(0);
           if ($43) {
            __THREW__ = 0;
            $44 = (invoke_iiii(740,($__this|0),($35|0),($ext|0))|0);
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             break L1;
            }
            $47 = (($2) + 2|0);
            HEAP8[$47>>0] = $44;
           }
           __THREW__ = 0;
           $48 = (invoke_iii(789,(0|0),($35|0))|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            break L1;
           }
           $54 = (($2) + 3|0);
           HEAP8[$54>>0] = $48;
           $55 = HEAP32[$idx>>2]|0;
           $56 = (($55) + -1)|0;
           HEAP32[$idx>>2] = $56;
           $$pr = HEAP32[$ct>>2]|0;
           $58 = $$pr;$V_4$04 = $35;
           label = 25;
           break L1;
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   $16 = ___cxa_find_matching_catch()|0;
   $17 = tempRet0;
   $lpad$phi$index = $16;$lpad$phi$index3 = $17;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  } else {
   __THREW__ = 0;
   $51 = (invoke_iiiii(123,($__this|0),($s|0),($3|0),($end|0))|0);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if (!($53)) {
    HEAP32[$ct>>2] = $51;
    $58 = $51;$V_4$04 = -1;
    label = 25;
   }
  }
 } while(0);
 L29: do {
  if ((label|0) == 25) {
   $57 = ($58|0)==(0|0);
   do {
    if ($57) {
     if ($4) {
      $V_4$28 = $V_4$04;
     } else {
      $117 = ($V_4$04|0)>(-1);
      if ($117) {
       $V_4$1 = $V_4$04;
      } else {
       $118 = HEAP32[$idx>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        break L29;
       }
       __THREW__ = 0;
       $121 = (invoke_iii(621,($s|0),($118|0))|0);
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if ($123) {
        break L29;
       }
       $124 = $121&65535;
       __THREW__ = 0;
       $125 = (invoke_iiii(743,($__this|0),($124|0),($0|0))|0);
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if ($127) {
        break L29;
       } else {
        $V_4$1 = $125;
       }
      }
      $128 = HEAP32[$idx>>2]|0;
      $129 = (($128) + -1)|0;
      HEAP32[$idx>>2] = $129;
      __THREW__ = 0;
      $130 = (invoke_iii(799,($__this|0),($V_4$1|0))|0);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       break L29;
      }
      HEAP8[$2>>0] = $130;
      $133 = HEAP8[$sortkey>>0]|0;
      $134 = ($130<<24>>24)==($133<<24>>24);
      if ($134) {
       __THREW__ = 0;
       $135 = (invoke_iii(800,($__this|0),($V_4$1|0))|0);
       $136 = __THREW__; __THREW__ = 0;
       $137 = $136&1;
       if ($137) {
        break L29;
       }
       $138 = (($2) + 1|0);
       HEAP8[$138>>0] = $135;
       $V_11$0$off0 = 0;
      } else {
       $V_11$0$off0 = 1;
      }
      $139 = $$lobit & 1;
      $140 = ($139|0)==(0);
      if ($140) {
       $141 = (($2) + 1|0);
       $142 = HEAP8[$141>>0]|0;
       $143 = (($sortkey) + 1|0);
       $144 = HEAP8[$143>>0]|0;
       $145 = ($142<<24>>24)==($144<<24>>24);
       if (!($145)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       $146 = (invoke_iiii(740,($__this|0),($V_4$1|0),0)|0);
       $147 = __THREW__; __THREW__ = 0;
       $148 = $147&1;
       if ($148) {
        break L29;
       }
       $149 = (($2) + 2|0);
       HEAP8[$149>>0] = $146;
       if ($V_11$0$off0) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } else {
       if ($V_11$0$off0) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      __THREW__ = 0;
      $150 = (invoke_iii(789,(0|0),($V_4$1|0))|0);
      $151 = __THREW__; __THREW__ = 0;
      $152 = $151&1;
      if ($152) {
       break L29;
      }
      $153 = (($2) + 3|0);
      HEAP8[$153>>0] = $150;
      $154 = HEAP8[$2>>0]|0;
      $155 = ($154<<24>>24)==(1);
      if ($155) {
       $V_4$2 = $V_4$1;
       label = 58;
      } else {
       $156 = (($ctx) + 20|0);
       HEAP32[$156>>2] = $V_4$1;
       $V_4$2 = $V_4$1;
       label = 58;
      }
     }
    } else {
     $59 = HEAP32[$idx>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($58|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break L29;
     }
     $62 = (($58) + 8|0);
     $63 = HEAP32[$62>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($63|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break L29;
     }
     $66 = (($63) + 12|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = (($59) - ($67))|0;
     HEAP32[$idx>>2] = $68;
     if (!($noLv4)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $69 = HEAP32[$ct>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($69|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break L29;
     }
     $72 = (($69) + 16|0);
     $73 = HEAP32[$72>>2]|0;
     $74 = ($73|0)==(0|0);
     if (!($74)) {
      $75 = HEAP8[$sortkey>>0]|0;
      HEAP8[$2>>0] = $75;
      $76 = (($2) + 1|0);
      $77 = (($sortkey) + 1|0);
      $78 = HEAP8[$77>>0]|0;
      HEAP8[$76>>0] = $78;
      $79 = (($2) + 2|0);
      $80 = (($sortkey) + 2|0);
      $81 = HEAP8[$80>>0]|0;
      HEAP8[$79>>0] = $81;
      $82 = (($2) + 3|0);
      $83 = (($sortkey) + 3|0);
      $84 = HEAP8[$83>>0]|0;
      HEAP8[$82>>0] = $84;
      $85 = (($ctx) + 20|0);
      HEAP32[$85>>2] = -1;
      $86 = (($ctx) + 24|0);
      HEAP32[$86>>2] = $2;
      $V_4$2 = $V_4$04;
      label = 58;
      break;
     }
     $87 = HEAP32[$ct>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($87|0));
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      break L29;
     }
     $90 = (($87) + 12|0);
     $91 = HEAP32[$90>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($91|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      break L29;
     }
     __THREW__ = 0;
     $94 = (invoke_ii(1816,($91|0))|0);
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      break L29;
     }
     $97 = (($94) + -1)|0;
     $98 = HEAP32[$ct>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($98|0));
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if ($100) {
      break L29;
     }
     $101 = (($98) + 12|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = HEAP32[$ct>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($103|0));
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      break L29;
     }
     $106 = (($103) + 12|0);
     $107 = HEAP32[$106>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($107|0));
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if ($109) {
      break L29;
     }
     __THREW__ = 0;
     $110 = (invoke_ii(1816,($107|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      break L29;
     }
     __THREW__ = 0;
     $113 = (invoke_iiiiiiiiii(5,($__this|0),($102|0),($97|0),($97|0),($110|0),($sortkey|0),($ti|0),1,($ctx|0))|0);
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if ($115) {
      break L29;
     }
     $116 = ($113|0)>(-1);
     $$0 = $116;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   L75: do {
    if ((label|0) == 58) {
     if ($4) {
      $V_4$28 = $V_4$2;
     } else {
      $V_12$09 = (($3) + 1)|0;
      $157 = ($V_12$09|0)<($orgStart|0);
      if ($157) {
       $158 = $$lobit & 1;
       $159 = ($158|0)==(0);
       $160 = (($2) + 2|0);
       $V_12$010 = $V_12$09;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($s|0));
        $186 = __THREW__; __THREW__ = 0;
        $187 = $186&1;
        if ($187) {
         break;
        }
        __THREW__ = 0;
        $161 = (invoke_iii(621,($s|0),($V_12$010|0))|0);
        $162 = __THREW__; __THREW__ = 0;
        $163 = $162&1;
        if ($163) {
         break;
        }
        $164 = $161&65535;
        __THREW__ = 0;
        $165 = (invoke_iii(799,($__this|0),($164|0))|0);
        $166 = __THREW__; __THREW__ = 0;
        $167 = $166&1;
        if ($167) {
         break;
        }
        $168 = ($165<<24>>24)==(1);
        if (!($168)) {
         $V_4$28 = $V_4$2;
         break L75;
        }
        if ($159) {
         $170 = HEAP8[$160>>0]|0;
         $171 = ($170<<24>>24)==(0);
         if ($171) {
          HEAP8[$160>>0] = 2;
          $173 = 2;
         } else {
          $173 = $170;
         }
         $172 = $173&255;
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $174 = __THREW__; __THREW__ = 0;
         $175 = $174&1;
         if ($175) {
          break;
         }
         __THREW__ = 0;
         $176 = (invoke_iii(621,($s|0),($V_12$010|0))|0);
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          break;
         }
         $179 = $176&65535;
         __THREW__ = 0;
         $180 = (invoke_iiii(740,($__this|0),($179|0),0)|0);
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if ($182) {
          break;
         }
         $183 = $180&255;
         $184 = (($183) + ($172))|0;
         $185 = $184&255;
         HEAP8[$160>>0] = $185;
        }
        $V_12$0 = (($V_12$010) + 1)|0;
        $169 = ($V_12$0|0)<($orgStart|0);
        if ($169) {
         $V_12$010 = $V_12$0;
        } else {
         $V_4$28 = $V_4$2;
         break L75;
        }
       }
       $14 = ___cxa_find_matching_catch()|0;
       $15 = tempRet0;
       $lpad$phi$index = $14;$lpad$phi$index3 = $15;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      } else {
       $V_4$28 = $V_4$2;
      }
     }
    }
   } while(0);
   __THREW__ = 0;
   $188 = (invoke_iiiiiiiii(12,0,($0|0),($2|0),($V_4$28|0),($ext|0),($sortkey|0),($ti|0),($noLv4|0))|0);
   $189 = __THREW__; __THREW__ = 0;
   $190 = $189&1;
   if (!($190)) {
    $$0 = $188;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $lpad$phi$index = $18;$lpad$phi$index3 = $19;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I26mscorlib_System_ByteTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFhPviiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32TraitsS0_S0_E6InvokeEPFiPviiES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN14ActionInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_E6InvokeEPFvPvS3_iiS3_iES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$3,$6,$8,$11);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I27mscorlib_System_Int32TraitsS0_17VoidPointerTraitsS0_E6InvokeEPFvPviiS3_iES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$1,$4,$6,$9);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker9I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_S1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iiS4_iiS4_S4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($args) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($args) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)!=(0);
 $23 = (FUNCTION_TABLE_iiiiiiiiiii[$func & 7]($obj,$0,$3,$6,$8,$11,$14,$16,$18,$22)|0);
 HEAP32[$ret>>2] = $23;
 $24 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($24|0);
}
function __ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_S0_E6InvokeEPFiPvS3_iiS3_iiiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$3,$6,$8,$11,$14,$17)|0);
 HEAP32[$ret>>2] = $18;
 $19 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($19|0);
}
function __ZN12FuncInvoker6I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS2_S1_S2_S2_E6InvokeEPFbPvS4_iiS4_iiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$6,$8,$11,$14)|0);
 $16 = $15&1;
 HEAP8[$ret>>0] = $16;
 $17 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($17|0);
}
function __ZN13FuncInvoker11I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_S1_S1_29mscorlib_System_BooleanTraitsS2_S1_E6InvokeEPFiPvS4_iiS4_iiS4_S4_bbS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($args) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($args) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)!=(0);
 $23 = (($args) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP8[$24>>0]|0;
 $26 = ($25<<24>>24)!=(0);
 $27 = (($args) + 40|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (FUNCTION_TABLE_iiiiiiiiiiiii[$func & 3]($obj,$0,$3,$6,$8,$11,$14,$16,$18,$22,$26,$28)|0);
 HEAP32[$ret>>2] = $29;
 $30 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($30|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvbbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$2,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S2_E6InvokeEPFbPvS4_S4_iiiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$2,$5,$8,$11)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker6I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S0_S1_E6InvokeEPFbPvS4_S4_iibS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)!=(0);
 $13 = (($args) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$2,$5,$8,$12,$14)|0);
 $16 = $15&1;
 HEAP8[$ret>>0] = $16;
 $17 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($17|0);
}
function __ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S1_E6InvokeEPFiPvS3_S3_iiS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$2,$5,$8,$10)|0);
 HEAP32[$ret>>2] = $11;
 $12 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S0_E6InvokeEPFiPvS3_S3_iiiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$2,$5,$8,$11)|0);
 HEAP32[$ret>>2] = $12;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_E6InvokeEPFiPvS3_S3_iiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$5,$8)|0);
 HEAP32[$ret>>2] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12FuncInvoker8I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_26mscorlib_System_CharTraitsS0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS5_iiS5_tibS5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP16[$10>>1]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)!=(0);
 $19 = (($args) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_iiiiiiiiii[$func & 15]($obj,$0,$3,$6,$8,$11,$14,$18,$20)|0);
 HEAP32[$ret>>2] = $21;
 $22 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($22|0);
}
function __ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S1_S1_E6InvokeEPFiPvS3_S3_iiS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$2,$5,$8,$10,$12)|0);
 HEAP32[$ret>>2] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker8I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S0_S1_S0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS4_iiiS4_ibS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)!=(0);
 $19 = (($args) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (FUNCTION_TABLE_iiiiiiiiii[$func & 15]($obj,$0,$3,$6,$9,$11,$14,$18,$20)|0);
 HEAP32[$ret>>2] = $21;
 $22 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($22|0);
}
function __ZN12FuncInvoker7I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S1_S0_S1_E6InvokeEPFbPvS4_S4_iiS4_bS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)!=(0);
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$2,$5,$8,$10,$14,$16)|0);
 $18 = $17&1;
 HEAP8[$ret>>0] = $18;
 $19 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($19|0);
}
function __ZN12FuncInvoker9I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S1_S0_S2_S1_S1_E6InvokeEPFbPvS4_S4_iiS4_biS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)!=(0);
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($args) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($args) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_iiiiiiiiiii[$func & 7]($obj,$0,$2,$5,$8,$10,$14,$17,$19,$21)|0);
 $23 = $22&1;
 HEAP8[$ret>>0] = $23;
 $24 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($24|0);
}
function __ZN12FuncInvoker7I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S1_S2_S1_S0_E6InvokeEPFbPviS4_iiS4_ibES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)!=(0);
 $19 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$1,$3,$6,$9,$11,$14,$18)|0);
 $20 = $19&1;
 HEAP8[$ret>>0] = $20;
 $21 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($21|0);
}
function __ZN12FuncInvoker8I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S2_S1_S0_S1_E6InvokeEPFbPvS4_S4_iiiS4_bS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (($args) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_iiiiiiiiii[$func & 15]($obj,$0,$2,$5,$8,$11,$13,$17,$19)|0);
 $21 = $20&1;
 HEAP8[$ret>>0] = $21;
 $22 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($22|0);
}
function __ZN13FuncInvoker10I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S2_S1_S0_S2_S1_S1_E6InvokeEPFbPvS4_S4_iiiS4_biS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (($args) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($args) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($args) + 36|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_iiiiiiiiiiii[$func & 7]($obj,$0,$2,$5,$8,$11,$13,$17,$20,$22,$24)|0);
 $26 = $25&1;
 HEAP8[$ret>>0] = $26;
 $27 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($27|0);
}
function __Z156mscorlib_System_Globalization_SortKey_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP37mscorlib_System_Globalization_SortKeyiP22mscorlib_System_Stringi($__this,$lcid,$source,$opt) {
 $__this = $__this|0;
 $lcid = $lcid|0;
 $source = $source|0;
 $opt = $opt|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2280840);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($__this) + 20|0);
  HEAP32[$2>>2] = $lcid;
  $3 = (($__this) + 8|0);
  HEAP32[$3>>2] = $source;
  $4 = (($__this) + 12|0);
  HEAP32[$4>>2] = $opt;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z361mscorlib_System_Globalization_SortKey_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Byte_arr_arr_mscorlib_System_Globalization_CompareOptions_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P37mscorlib_System_Globalization_SortKeyiP22mscorlib_System_StringP24mscorlib_System_Byte_arriiiiiiiii($__this,$lcid,$source,$buffer,$opt,$lv1Length,$lv2Length,$lv3Length,$kanaSmallLength,$markTypeLength,$katakanaLength,$kanaWidthLength,$identLength) {
 $__this = $__this|0;
 $lcid = $lcid|0;
 $source = $source|0;
 $buffer = $buffer|0;
 $opt = $opt|0;
 $lv1Length = $lv1Length|0;
 $lv2Length = $lv2Length|0;
 $lv3Length = $lv3Length|0;
 $kanaSmallLength = $kanaSmallLength|0;
 $markTypeLength = $markTypeLength|0;
 $katakanaLength = $katakanaLength|0;
 $kanaWidthLength = $kanaWidthLength|0;
 $identLength = $identLength|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2280888);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $2 = (($__this) + 20|0);
  HEAP32[$2>>2] = $lcid;
  $3 = (($__this) + 8|0);
  HEAP32[$3>>2] = $source;
  $4 = (($__this) + 16|0);
  HEAP32[$4>>2] = $buffer;
  $5 = (($__this) + 12|0);
  HEAP32[$5>>2] = $opt;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z47mscorlib_System_Globalization_SortKey_m_CompareP22mscorlib_System_ObjectP37mscorlib_System_Globalization_SortKeyS2_($__this,$sortkey1,$sortkey2) {
 $__this = $__this|0;
 $sortkey1 = $sortkey1|0;
 $sortkey2 = $sortkey2|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$sum = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B10_0$0 = 0, $G_B10_0$0$in = 0, $V_3$011 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2280936);
 __THREW__ = 0;
 invoke_v(530);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($sortkey1|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3020320>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($sortkey2|0)==(0|0);
   if ($17) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2560584|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3020328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($20|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($20|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $28 = (invoke_iiii(424,(0|0),($sortkey1|0),($sortkey2|0))|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    if ($28) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($sortkey1|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     __THREW__ = 0;
     $33 = (invoke_iii(2730,(2280984|0),($sortkey1|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($sortkey2|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       __THREW__ = 0;
       $38 = (invoke_iii(2730,(2280984|0),($sortkey2|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if (!($40)) {
        __THREW__ = 0;
        $41 = (invoke_iiii(424,(0|0),($33|0),($38|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if (!($43)) {
         if ($41) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($sortkey1|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if (!($45)) {
          __THREW__ = 0;
          $46 = (invoke_iii(2730,(2281032|0),($sortkey1|0))|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if (!($48)) {
           __THREW__ = 0;
           invoke_vi(3799,($sortkey2|0));
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if (!($50)) {
            __THREW__ = 0;
            $51 = (invoke_iii(2730,(2281032|0),($sortkey2|0))|0);
            $52 = __THREW__; __THREW__ = 0;
            $53 = $52&1;
            if (!($53)) {
             __THREW__ = 0;
             invoke_vi(3799,($46|0));
             $54 = __THREW__; __THREW__ = 0;
             $55 = $54&1;
             if (!($55)) {
              $56 = (($46) + 12|0);
              $57 = HEAP32[$56>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($51|0));
              $58 = __THREW__; __THREW__ = 0;
              $59 = $58&1;
              if (!($59)) {
               $60 = (($51) + 12|0);
               $61 = HEAP32[$60>>2]|0;
               $62 = ($57|0)>($61|0);
               if ($62) {
                __THREW__ = 0;
                invoke_vi(3799,($51|0));
                $63 = __THREW__; __THREW__ = 0;
                $64 = $63&1;
                if ($64) {
                 break;
                } else {
                 $G_B10_0$0$in = $60;
                }
               } else {
                __THREW__ = 0;
                invoke_vi(3799,($46|0));
                $65 = __THREW__; __THREW__ = 0;
                $66 = $65&1;
                if ($66) {
                 break;
                } else {
                 $G_B10_0$0$in = $56;
                }
               }
               $G_B10_0$0 = HEAP32[$G_B10_0$0$in>>2]|0;
               $67 = ($G_B10_0$0|0)>(0);
               L39: do {
                if ($67) {
                 $V_3$011 = 0;
                 while(1) {
                  __THREW__ = 0;
                  invoke_vi(3799,($46|0));
                  $130 = __THREW__; __THREW__ = 0;
                  $131 = $130&1;
                  if ($131) {
                   label = 3;
                   break;
                  }
                  $68 = HEAP32[$56>>2]|0;
                  $69 = ($V_3$011>>>0)<($68>>>0);
                  if (!($69)) {
                   __THREW__ = 0;
                   $70 = (invoke_i(132)|0);
                   $71 = __THREW__; __THREW__ = 0;
                   $72 = $71&1;
                   if ($72) {
                    label = 3;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($70|0));
                   $73 = __THREW__; __THREW__ = 0;
                   $74 = $73&1;
                   if ($74) {
                    label = 3;
                    break;
                   }
                  }
                  $75 = HEAP32[$46>>2]|0;
                  $76 = (($75) + 92|0);
                  $77 = HEAP32[$76>>2]|0;
                  $78 = Math_imul($77, $V_3$011)|0;
                  $$sum = (($78) + 16)|0;
                  $79 = (($46) + ($$sum)|0);
                  $80 = HEAP8[$79>>0]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($51|0));
                  $81 = __THREW__; __THREW__ = 0;
                  $82 = $81&1;
                  if ($82) {
                   label = 3;
                   break;
                  }
                  $83 = HEAP32[$60>>2]|0;
                  $84 = ($V_3$011>>>0)<($83>>>0);
                  if (!($84)) {
                   __THREW__ = 0;
                   $85 = (invoke_i(132)|0);
                   $86 = __THREW__; __THREW__ = 0;
                   $87 = $86&1;
                   if ($87) {
                    label = 3;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($85|0));
                   $88 = __THREW__; __THREW__ = 0;
                   $89 = $88&1;
                   if ($89) {
                    label = 3;
                    break;
                   }
                  }
                  $90 = HEAP32[$51>>2]|0;
                  $91 = (($90) + 92|0);
                  $92 = HEAP32[$91>>2]|0;
                  $93 = Math_imul($92, $V_3$011)|0;
                  $$sum4 = (($93) + 16)|0;
                  $94 = (($51) + ($$sum4)|0);
                  $95 = HEAP8[$94>>0]|0;
                  $96 = ($80<<24>>24)==($95<<24>>24);
                  $97 = (($V_3$011) + 1)|0;
                  if (!($96)) {
                   break;
                  }
                  $129 = ($97|0)<($G_B10_0$0|0);
                  if ($129) {
                   $V_3$011 = $97;
                  } else {
                   break L39;
                  }
                 }
                 if ((label|0) == 3) {
                  $3 = ___cxa_find_matching_catch()|0;
                  $4 = tempRet0;
                  $lpad$phi$index = $3;$lpad$phi$index2 = $4;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($lpad$phi$index|0);
                  // unreachable;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($46|0));
                 $98 = __THREW__; __THREW__ = 0;
                 $99 = $98&1;
                 if ($99) {
                  break L1;
                 }
                 $100 = HEAP32[$56>>2]|0;
                 $101 = ($V_3$011>>>0)<($100>>>0);
                 if (!($101)) {
                  __THREW__ = 0;
                  $102 = (invoke_i(132)|0);
                  $103 = __THREW__; __THREW__ = 0;
                  $104 = $103&1;
                  if ($104) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($102|0));
                  $105 = __THREW__; __THREW__ = 0;
                  $106 = $105&1;
                  if ($106) {
                   break L1;
                  }
                 }
                 $107 = HEAP32[$46>>2]|0;
                 $108 = (($107) + 92|0);
                 $109 = HEAP32[$108>>2]|0;
                 $110 = Math_imul($109, $V_3$011)|0;
                 $$sum5 = (($110) + 16)|0;
                 $111 = (($46) + ($$sum5)|0);
                 $112 = HEAP8[$111>>0]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($51|0));
                 $113 = __THREW__; __THREW__ = 0;
                 $114 = $113&1;
                 if ($114) {
                  break L1;
                 }
                 $115 = HEAP32[$60>>2]|0;
                 $116 = ($V_3$011>>>0)<($115>>>0);
                 if (!($116)) {
                  __THREW__ = 0;
                  $117 = (invoke_i(132)|0);
                  $118 = __THREW__; __THREW__ = 0;
                  $119 = $118&1;
                  if ($119) {
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($117|0));
                  $120 = __THREW__; __THREW__ = 0;
                  $121 = $120&1;
                  if ($121) {
                   break L1;
                  }
                 }
                 $122 = HEAP32[$51>>2]|0;
                 $123 = (($122) + 92|0);
                 $124 = HEAP32[$123>>2]|0;
                 $125 = Math_imul($124, $V_3$011)|0;
                 $$sum6 = (($125) + 16)|0;
                 $126 = (($51) + ($$sum6)|0);
                 $127 = HEAP8[$126>>0]|0;
                 $128 = ($112&255)<($127&255);
                 $$ = $128 ? -1 : 1;
                 $$0 = $$;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               } while(0);
               __THREW__ = 0;
               invoke_vi(3799,($46|0));
               $132 = __THREW__; __THREW__ = 0;
               $133 = $132&1;
               if ($133) {
                break;
               }
               $134 = HEAP32[$56>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($51|0));
               $135 = __THREW__; __THREW__ = 0;
               $136 = $135&1;
               if ($136) {
                break;
               }
               $137 = HEAP32[$60>>2]|0;
               $138 = ($134|0)==($137|0);
               if ($138) {
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               __THREW__ = 0;
               invoke_vi(3799,($46|0));
               $139 = __THREW__; __THREW__ = 0;
               $140 = $139&1;
               if ($140) {
                break;
               }
               $141 = HEAP32[$56>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($51|0));
               $142 = __THREW__; __THREW__ = 0;
               $143 = $142&1;
               if ($143) {
                break;
               }
               $144 = HEAP32[$60>>2]|0;
               $145 = ($141|0)<($144|0);
               $$1 = $145 ? -1 : 1;
               $$0 = $$1;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Globalization_SortKey_m_get_OriginalStringP37mscorlib_System_Globalization_SortKey($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2280984);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51mscorlib_System_Globalization_SortKey_m_get_KeyDataP37mscorlib_System_Globalization_SortKey($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2281032);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z46mscorlib_System_Globalization_SortKey_m_EqualsP37mscorlib_System_Globalization_SortKeyP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2281080);
 __THREW__ = 0;
 (invoke_ii(2996,(2281808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($value|0),(2281808|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if (!($5)) {
     $8 = (($__this) + 20|0);
     $9 = HEAP32[$8>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = (($2) + 20|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($9|0)==($13|0);
     if ($14) {
      $15 = (($__this) + 12|0);
      $16 = HEAP32[$15>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      $19 = (($2) + 12|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = ($16|0)==($20|0);
      if ($21) {
       __THREW__ = 0;
       $22 = (invoke_iiii(771,0,($__this|0),($2|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       $25 = ($22|0)==(0);
       if ($25) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Globalization_SortKey_m_GetHashCodeP37mscorlib_System_Globalization_SortKey($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2281128);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $11 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($11|0));
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = (($11) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0);
    if ($16) {
     __THREW__ = 0;
     $17 = (invoke_i(132)|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($17|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
    }
    $22 = (($11) + 16|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $V_0$0 = $24;$V_1$0 = 1;
    while(1) {
     $46 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($46|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     $49 = (($46) + 12|0);
     $50 = HEAP32[$49>>2]|0;
     $51 = ($V_1$0|0)<($50|0);
     if (!($51)) {
      $$0 = $V_0$0;
      label = 18;
      break;
     }
     $26 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     $25 = (($26) + 12|0);
     $27 = HEAP32[$25>>2]|0;
     $28 = ($V_1$0>>>0)<($27>>>0);
     if (!($28)) {
      __THREW__ = 0;
      $29 = (invoke_i(132)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($29|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
     }
     $34 = HEAP32[$26>>2]|0;
     $35 = (($26) + 16|0);
     $36 = (($34) + 92|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = Math_imul($37, $V_1$0)|0;
     $39 = (($35) + ($38)|0);
     $40 = HEAP8[$39>>0]|0;
     $41 = $V_1$0 & 3;
     $42 = $40&255;
     $43 = $42 << $41;
     $44 = $43 ^ $V_0$0;
     $45 = (($V_1$0) + 1)|0;
     $V_0$0 = $44;$V_1$0 = $45;
    }
    if ((label|0) == 18) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $7 = ___cxa_find_matching_catch()|0;
    $8 = tempRet0;
    $lpad$phi$index = $7;$lpad$phi$index2 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Globalization_SortKey_m_ToStringP37mscorlib_System_Globalization_SortKey($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_18 = 0, $L_9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_9 = sp;
 $L_18 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2281176);
 __THREW__ = 0;
 invoke_v(531);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2758,(1167664|0),6)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $19 = HEAP32[3020376>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($4|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[3020376>>2]|0;
       $23 = (($4) + 16|0);
       HEAP32[$23>>2] = $22;
       $24 = (($__this) + 20|0);
       $25 = HEAP32[$24>>2]|0;
       HEAP32[$L_9>>2] = $25;
       __THREW__ = 0;
       (invoke_ii(2996,(2155952|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2155952|0),($L_9|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          $33 = HEAP32[$9>>2]|0;
          $34 = ($33>>>0)<(2);
          if ($34) {
           __THREW__ = 0;
           $35 = (invoke_i(132)|0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($35|0));
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if ($39) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($4|0),($28|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if (!($41)) {
           $42 = HEAP32[$4>>2]|0;
           $43 = (($42) + 92|0);
           $44 = HEAP32[$43>>2]|0;
           $45 = (($23) + ($44)|0);
           HEAP32[$45>>2] = $28;
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            $48 = HEAP32[$9>>2]|0;
            $49 = ($48>>>0)<(3);
            if ($49) {
             __THREW__ = 0;
             $50 = (invoke_i(132)|0);
             $51 = __THREW__; __THREW__ = 0;
             $52 = $51&1;
             if ($52) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($50|0));
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if ($54) {
              break;
             }
            }
            $55 = HEAP32[3020384>>2]|0;
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($55|0));
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if (!($57)) {
             $58 = HEAP32[3020384>>2]|0;
             $59 = HEAP32[$4>>2]|0;
             $60 = (($59) + 92|0);
             $61 = HEAP32[$60>>2]|0;
             $62 = $61 << 1;
             $63 = (($23) + ($62)|0);
             HEAP32[$63>>2] = $58;
             $64 = (($__this) + 12|0);
             $65 = HEAP32[$64>>2]|0;
             HEAP32[$L_18>>2] = $65;
             __THREW__ = 0;
             (invoke_ii(2996,(2329520|0))|0);
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if (!($67)) {
              __THREW__ = 0;
              $68 = (invoke_iii(2724,(2329520|0),($L_18|0))|0);
              $69 = __THREW__; __THREW__ = 0;
              $70 = $69&1;
              if (!($70)) {
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $71 = __THREW__; __THREW__ = 0;
               $72 = $71&1;
               if (!($72)) {
                $73 = HEAP32[$9>>2]|0;
                $74 = ($73>>>0)<(4);
                if ($74) {
                 __THREW__ = 0;
                 $75 = (invoke_i(132)|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($75|0));
                 $78 = __THREW__; __THREW__ = 0;
                 $79 = $78&1;
                 if ($79) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($68|0));
                $80 = __THREW__; __THREW__ = 0;
                $81 = $80&1;
                if (!($81)) {
                 $82 = HEAP32[$4>>2]|0;
                 $83 = (($82) + 92|0);
                 $84 = HEAP32[$83>>2]|0;
                 $85 = ($84*3)|0;
                 $86 = (($23) + ($85)|0);
                 HEAP32[$86>>2] = $68;
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $87 = __THREW__; __THREW__ = 0;
                 $88 = $87&1;
                 if ($88) {
                  break;
                 }
                 $89 = HEAP32[$9>>2]|0;
                 $90 = ($89>>>0)<(5);
                 if ($90) {
                  __THREW__ = 0;
                  $91 = (invoke_i(132)|0);
                  $92 = __THREW__; __THREW__ = 0;
                  $93 = $92&1;
                  if ($93) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($91|0));
                  $94 = __THREW__; __THREW__ = 0;
                  $95 = $94&1;
                  if ($95) {
                   break;
                  }
                 }
                 $96 = HEAP32[3020392>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($96|0));
                 $97 = __THREW__; __THREW__ = 0;
                 $98 = $97&1;
                 if ($98) {
                  break;
                 }
                 $99 = HEAP32[3020392>>2]|0;
                 $100 = HEAP32[$4>>2]|0;
                 $101 = (($100) + 92|0);
                 $102 = HEAP32[$101>>2]|0;
                 $103 = $102 << 2;
                 $104 = (($23) + ($103)|0);
                 HEAP32[$104>>2] = $99;
                 $105 = (($__this) + 8|0);
                 $106 = HEAP32[$105>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $107 = __THREW__; __THREW__ = 0;
                 $108 = $107&1;
                 if ($108) {
                  break;
                 }
                 $109 = HEAP32[$9>>2]|0;
                 $110 = ($109>>>0)<(6);
                 if ($110) {
                  __THREW__ = 0;
                  $111 = (invoke_i(132)|0);
                  $112 = __THREW__; __THREW__ = 0;
                  $113 = $112&1;
                  if ($113) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($111|0));
                  $114 = __THREW__; __THREW__ = 0;
                  $115 = $114&1;
                  if ($115) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($106|0));
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 $118 = HEAP32[$4>>2]|0;
                 $119 = (($118) + 92|0);
                 $120 = HEAP32[$119>>2]|0;
                 $121 = ($120*5)|0;
                 $122 = (($23) + ($121)|0);
                 HEAP32[$122>>2] = $106;
                 __THREW__ = 0;
                 $123 = (invoke_iii(638,(0|0),($4|0))|0);
                 $124 = __THREW__; __THREW__ = 0;
                 $125 = $124&1;
                 if ($125) {
                  break;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($123|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_E6InvokeEPFvPviS3_iES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$3,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN15ActionInvoker12I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S0_S0_S0_S0_S0_S0_S0_E6InvokeEPFvPviS3_S3_iiiiiiiiiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($args) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($args) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($args) + 36|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($args) + 40|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($args) + 44|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 FUNCTION_TABLE_viiiiiiiiiiiii[$action & 3]($obj,$1,$3,$5,$8,$11,$14,$17,$20,$23,$26,$29,$32);
 STACKTOP = sp;return (0|0);
}
function __Z68mscorlib_System_Globalization_SortKey_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z57mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_ResetP49mscorlib_Mono_Globalization_Unicode_SortKeyBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2281992);
 $0 = (($__this) + 8|0);
 $1 = (($__this) + 78|0);
 HEAP8[$1>>0] = 0;
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;HEAP32[$0+16>>2]=0|0;HEAP32[$0+20>>2]=0|0;HEAP32[$0+24>>2]=0|0;HEAP32[$0+28>>2]=0|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z73mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendBufferPrimitiveP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhPP24mscorlib_System_Byte_arrPi($__this,$value,$buf,$bidx) {
 $__this = $__this|0;
 $value = $value|0;
 $buf = $buf|0;
 $bidx = $bidx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282280);
 $0 = HEAP32[$buf>>2]|0;
 $1 = HEAP32[$bidx>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$bidx>>2] = $2;
 __THREW__ = 0;
 invoke_vi(3799,($0|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($1|0)<(0);
   if ($5) {
    label = 4;
   } else {
    $6 = (($0) + 12|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($1>>>0)<($7>>>0);
    if (!($8)) {
     label = 4;
    }
   }
   if ((label|0) == 4) {
    __THREW__ = 0;
    $9 = (invoke_i(132)|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($9|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
   }
   $16 = HEAP32[$0>>2]|0;
   $17 = (($0) + 16|0);
   $18 = (($16) + 92|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = Math_imul($19, $1)|0;
   $21 = (($17) + ($20)|0);
   HEAP8[$21>>0] = $value;
   $22 = HEAP32[$bidx>>2]|0;
   $23 = HEAP32[$buf>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $26 = (($23) + 12|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($22|0)==($27|0);
    if (!($28)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $29 = HEAP32[$bidx>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(1203320|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = $29 << 1;
     __THREW__ = 0;
     $33 = (invoke_iii(2758,(1203320|0),($32|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      $36 = HEAP32[$buf>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($36|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       $39 = (($36) + 12|0);
       $40 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       invoke_viiii(140,(0|0),($36|0),($33|0),($40|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        HEAP32[$buf>>2] = $33;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z64mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendLevel5P49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhh($__this,$category,$lv1) {
 $__this = $__this|0;
 $category = $category|0;
 $lv1 = $lv1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282232);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 $3 = (($2|0) % 8192)&-1;
 $4 = (($3|0) / 64)&-1;
 $5 = (($4) + 128)|0;
 $6 = $5&255;
 $7 = (($__this) + 68|0);
 $8 = (($__this) + 36|0);
 __THREW__ = 0;
 invoke_viiii(148,0,($6|0),($7|0),($8|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if (!($10)) {
  $11 = (($3|0) % 64)&-1;
  $12 = $11 << 2;
  $13 = $12 | 3;
  $14 = $13&255;
  __THREW__ = 0;
  invoke_viiii(148,0,($14|0),($7|0),($8|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   invoke_viiii(148,0,($category|0),($7|0),($8|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    invoke_viiii(148,0,($lv1|0),($7|0),($8|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z61mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_GetResultP49mscorlib_Mono_Globalization_Unicode_SortKeyBuffer($__this) {
 $__this = $__this|0;
 var $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_2$0 = 0, $V_5$0 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282424);
 $0 = (($__this) + 77|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   label = 17;
  } else {
   $3 = (($__this) + 78|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $6 = (($__this) + 44|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==(0|0);
    if ($8) {
     label = 17;
    } else {
     $31 = $7;$V_0$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($31|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 7;
       break;
      }
      $34 = (($31) + 12|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($V_0$0|0)<($35|0);
      if (!($36)) {
       label = 15;
       break;
      }
      $10 = HEAP32[$6>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($10|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 7;
       break;
      }
      $9 = (($10) + 12|0);
      $11 = HEAP32[$9>>2]|0;
      $12 = ($V_0$0>>>0)<($11>>>0);
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_i(132)|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($13|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        label = 7;
        break;
       }
      }
      $22 = HEAP32[$10>>2]|0;
      $23 = (($10) + 16|0);
      $24 = (($22) + 92|0);
      $25 = HEAP32[$24>>2]|0;
      $26 = Math_imul($25, $V_0$0)|0;
      $27 = (($23) + ($26)|0);
      $28 = HEAP8[$27>>0]|0;
      $29 = ($28<<24>>24)==(0);
      if ($29) {
       label = 15;
       break;
      }
      $30 = (($V_0$0) + 1)|0;
      $$pre11 = HEAP32[$6>>2]|0;
      $31 = $$pre11;$V_0$0 = $30;
     }
     if ((label|0) == 7) {
      $18 = ___cxa_find_matching_catch()|0;
      $19 = tempRet0;
      $lpad$phi$index = $18;$lpad$phi$index2 = $19;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 15) {
      $39 = HEAP32[$6>>2]|0;
      __THREW__ = 0;
      invoke_viiii(141,(0|0),($39|0),0,($V_0$0|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      HEAP8[$3>>0] = 1;
      label = 17;
      break;
     }
    }
   } else {
    label = 17;
   }
  }
 } while(0);
 do {
  if ((label|0) == 17) {
   $42 = (($__this) + 44|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($__this) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   __THREW__ = 0;
   $46 = (invoke_iiiii(127,0,($43|0),($45|0),2)|0);
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if (!($48)) {
    HEAP32[$44>>2] = $46;
    $49 = (($__this) + 48|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($__this) + 16|0);
    $52 = HEAP32[$51>>2]|0;
    __THREW__ = 0;
    $53 = (invoke_iiiii(127,0,($50|0),($52|0),2)|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     HEAP32[$51>>2] = $53;
     $56 = (($__this) + 20|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)>(0);
     $59 = (($__this) + 52|0);
     $60 = HEAP32[$59>>2]|0;
     __THREW__ = 0;
     $61 = (invoke_iiiii(127,0,($60|0),($57|0),-28)|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if (!($63)) {
      HEAP32[$56>>2] = $61;
      $64 = (($__this) + 56|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($__this) + 24|0);
      $67 = HEAP32[$66>>2]|0;
      __THREW__ = 0;
      $68 = (invoke_iiiii(127,0,($65|0),($67|0),3)|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if (!($70)) {
       HEAP32[$66>>2] = $68;
       $71 = (($__this) + 60|0);
       $72 = HEAP32[$71>>2]|0;
       $73 = (($__this) + 28|0);
       $74 = HEAP32[$73>>2]|0;
       __THREW__ = 0;
       $75 = (invoke_iiiii(127,0,($72|0),($74|0),-28)|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if (!($77)) {
        HEAP32[$73>>2] = $75;
        $78 = (($__this) + 64|0);
        $79 = HEAP32[$78>>2]|0;
        $80 = (($__this) + 32|0);
        $81 = HEAP32[$80>>2]|0;
        __THREW__ = 0;
        $82 = (invoke_iiiii(127,0,($79|0),($81|0),-28)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if (!($84)) {
         HEAP32[$80>>2] = $82;
         $85 = (($__this) + 68|0);
         $86 = HEAP32[$85>>2]|0;
         $87 = (($__this) + 36|0);
         $88 = HEAP32[$87>>2]|0;
         __THREW__ = 0;
         $89 = (invoke_iiiii(127,0,($86|0),($88|0),2)|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if (!($91)) {
          HEAP32[$87>>2] = $89;
          $92 = (($__this) + 8|0);
          $93 = HEAP32[$92>>2]|0;
          $94 = HEAP32[$44>>2]|0;
          $95 = HEAP32[$51>>2]|0;
          $96 = (($89) + 5)|0;
          $97 = (($96) + ($93))|0;
          $98 = (($97) + ($94))|0;
          $99 = (($98) + ($95))|0;
          if ($58) {
           $100 = HEAP32[$66>>2]|0;
           $101 = HEAP32[$56>>2]|0;
           $102 = HEAP32[$73>>2]|0;
           $103 = HEAP32[$80>>2]|0;
           $104 = (($99) + 4)|0;
           $105 = (($104) + ($100))|0;
           $106 = (($105) + ($101))|0;
           $107 = (($106) + ($102))|0;
           $108 = (($107) + ($103))|0;
           $V_2$0 = $108;
          } else {
           $V_2$0 = $99;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(1203320|0))|0);
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if (!($110)) {
           __THREW__ = 0;
           $111 = (invoke_iii(2758,(1203320|0),($V_2$0|0))|0);
           $112 = __THREW__; __THREW__ = 0;
           $113 = $112&1;
           if (!($113)) {
            $114 = (($__this) + 40|0);
            $115 = HEAP32[$114>>2]|0;
            $116 = HEAP32[$92>>2]|0;
            __THREW__ = 0;
            invoke_viiii(140,(0|0),($115|0),($111|0),($116|0));
            $117 = __THREW__; __THREW__ = 0;
            $118 = $117&1;
            if (!($118)) {
             $119 = HEAP32[$92>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($111|0));
             $120 = __THREW__; __THREW__ = 0;
             $121 = $120&1;
             if (!($121)) {
              $122 = ($119|0)<(0);
              if ($122) {
               label = 32;
              } else {
               $123 = (($111) + 12|0);
               $124 = HEAP32[$123>>2]|0;
               $125 = ($119>>>0)<($124>>>0);
               if (!($125)) {
                label = 32;
               }
              }
              if ((label|0) == 32) {
               __THREW__ = 0;
               $126 = (invoke_i(132)|0);
               $127 = __THREW__; __THREW__ = 0;
               $128 = $127&1;
               if ($128) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($126|0));
               $129 = __THREW__; __THREW__ = 0;
               $130 = $129&1;
               if ($130) {
                break;
               }
              }
              $131 = HEAP32[$111>>2]|0;
              $132 = (($111) + 16|0);
              $133 = (($131) + 92|0);
              $134 = HEAP32[$133>>2]|0;
              $135 = Math_imul($134, $119)|0;
              $136 = (($132) + ($135)|0);
              HEAP8[$136>>0] = 1;
              $137 = HEAP32[$92>>2]|0;
              $138 = (($137) + 1)|0;
              $139 = HEAP32[$44>>2]|0;
              $140 = ($139|0)<(1);
              if ($140) {
               $145 = $139;
              } else {
               $141 = HEAP32[$42>>2]|0;
               __THREW__ = 0;
               invoke_viiiiii(55,(0|0),($141|0),0,($111|0),($138|0),($139|0));
               $142 = __THREW__; __THREW__ = 0;
               $143 = $142&1;
               if ($143) {
                break;
               }
               $$pre = HEAP32[$44>>2]|0;
               $145 = $$pre;
              }
              $144 = (($145) + ($138))|0;
              $146 = (($144) + 1)|0;
              __THREW__ = 0;
              invoke_vi(3799,($111|0));
              $147 = __THREW__; __THREW__ = 0;
              $148 = $147&1;
              if (!($148)) {
               $149 = ($144|0)<(0);
               if ($149) {
                label = 40;
               } else {
                $150 = (($111) + 12|0);
                $151 = HEAP32[$150>>2]|0;
                $152 = ($144>>>0)<($151>>>0);
                if (!($152)) {
                 label = 40;
                }
               }
               if ((label|0) == 40) {
                __THREW__ = 0;
                $153 = (invoke_i(132)|0);
                $154 = __THREW__; __THREW__ = 0;
                $155 = $154&1;
                if ($155) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($153|0));
                $156 = __THREW__; __THREW__ = 0;
                $157 = $156&1;
                if ($157) {
                 break;
                }
               }
               $158 = HEAP32[$111>>2]|0;
               $159 = (($158) + 92|0);
               $160 = HEAP32[$159>>2]|0;
               $161 = Math_imul($160, $144)|0;
               $162 = (($132) + ($161)|0);
               HEAP8[$162>>0] = 1;
               $163 = HEAP32[$51>>2]|0;
               $164 = ($163|0)<(1);
               if ($164) {
                $169 = $163;
               } else {
                $165 = HEAP32[$49>>2]|0;
                __THREW__ = 0;
                invoke_viiiiii(55,(0|0),($165|0),0,($111|0),($146|0),($163|0));
                $166 = __THREW__; __THREW__ = 0;
                $167 = $166&1;
                if ($167) {
                 break;
                }
                $$pre9 = HEAP32[$51>>2]|0;
                $169 = $$pre9;
               }
               $168 = (($169) + ($146))|0;
               $170 = (($168) + 1)|0;
               __THREW__ = 0;
               invoke_vi(3799,($111|0));
               $171 = __THREW__; __THREW__ = 0;
               $172 = $171&1;
               if (!($172)) {
                $173 = ($168|0)<(0);
                if ($173) {
                 label = 48;
                } else {
                 $174 = (($111) + 12|0);
                 $175 = HEAP32[$174>>2]|0;
                 $176 = ($168>>>0)<($175>>>0);
                 if (!($176)) {
                  label = 48;
                 }
                }
                if ((label|0) == 48) {
                 __THREW__ = 0;
                 $177 = (invoke_i(132)|0);
                 $178 = __THREW__; __THREW__ = 0;
                 $179 = $178&1;
                 if ($179) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($177|0));
                 $180 = __THREW__; __THREW__ = 0;
                 $181 = $180&1;
                 if ($181) {
                  break;
                 }
                }
                $182 = HEAP32[$111>>2]|0;
                $183 = (($182) + 92|0);
                $184 = HEAP32[$183>>2]|0;
                $185 = Math_imul($184, $168)|0;
                $186 = (($132) + ($185)|0);
                HEAP8[$186>>0] = 1;
                if ($58) {
                 $187 = HEAP32[$59>>2]|0;
                 $188 = HEAP32[$56>>2]|0;
                 __THREW__ = 0;
                 invoke_viiiiii(55,(0|0),($187|0),0,($111|0),($170|0),($188|0));
                 $189 = __THREW__; __THREW__ = 0;
                 $190 = $189&1;
                 if ($190) {
                  break;
                 }
                 $191 = HEAP32[$56>>2]|0;
                 $192 = (($191) + ($170))|0;
                 $193 = (($192) + 1)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($111|0));
                 $194 = __THREW__; __THREW__ = 0;
                 $195 = $194&1;
                 if ($195) {
                  break;
                 }
                 $196 = ($192|0)<(0);
                 if ($196) {
                  label = 55;
                 } else {
                  $197 = (($111) + 12|0);
                  $198 = HEAP32[$197>>2]|0;
                  $199 = ($192>>>0)<($198>>>0);
                  if (!($199)) {
                   label = 55;
                  }
                 }
                 if ((label|0) == 55) {
                  __THREW__ = 0;
                  $200 = (invoke_i(132)|0);
                  $201 = __THREW__; __THREW__ = 0;
                  $202 = $201&1;
                  if ($202) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($200|0));
                  $203 = __THREW__; __THREW__ = 0;
                  $204 = $203&1;
                  if ($204) {
                   break;
                  }
                 }
                 $205 = HEAP32[$111>>2]|0;
                 $206 = (($205) + 92|0);
                 $207 = HEAP32[$206>>2]|0;
                 $208 = Math_imul($207, $192)|0;
                 $209 = (($132) + ($208)|0);
                 HEAP8[$209>>0] = -1;
                 $210 = HEAP32[$64>>2]|0;
                 $211 = HEAP32[$66>>2]|0;
                 __THREW__ = 0;
                 invoke_viiiiii(55,(0|0),($210|0),0,($111|0),($193|0),($211|0));
                 $212 = __THREW__; __THREW__ = 0;
                 $213 = $212&1;
                 if ($213) {
                  break;
                 }
                 $214 = HEAP32[$66>>2]|0;
                 $215 = (($214) + ($193))|0;
                 $216 = (($215) + 1)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($111|0));
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  break;
                 }
                 $219 = ($215|0)<(0);
                 if ($219) {
                  label = 61;
                 } else {
                  $220 = (($111) + 12|0);
                  $221 = HEAP32[$220>>2]|0;
                  $222 = ($215>>>0)<($221>>>0);
                  if (!($222)) {
                   label = 61;
                  }
                 }
                 if ((label|0) == 61) {
                  __THREW__ = 0;
                  $223 = (invoke_i(132)|0);
                  $224 = __THREW__; __THREW__ = 0;
                  $225 = $224&1;
                  if ($225) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($223|0));
                  $226 = __THREW__; __THREW__ = 0;
                  $227 = $226&1;
                  if ($227) {
                   break;
                  }
                 }
                 $228 = HEAP32[$111>>2]|0;
                 $229 = (($228) + 92|0);
                 $230 = HEAP32[$229>>2]|0;
                 $231 = Math_imul($230, $215)|0;
                 $232 = (($132) + ($231)|0);
                 HEAP8[$232>>0] = 2;
                 $233 = HEAP32[$71>>2]|0;
                 $234 = HEAP32[$73>>2]|0;
                 __THREW__ = 0;
                 invoke_viiiiii(55,(0|0),($233|0),0,($111|0),($216|0),($234|0));
                 $235 = __THREW__; __THREW__ = 0;
                 $236 = $235&1;
                 if ($236) {
                  break;
                 }
                 $237 = HEAP32[$73>>2]|0;
                 $238 = (($237) + ($216))|0;
                 $239 = (($238) + 1)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($111|0));
                 $240 = __THREW__; __THREW__ = 0;
                 $241 = $240&1;
                 if ($241) {
                  break;
                 }
                 $242 = ($238|0)<(0);
                 if ($242) {
                  label = 67;
                 } else {
                  $243 = (($111) + 12|0);
                  $244 = HEAP32[$243>>2]|0;
                  $245 = ($238>>>0)<($244>>>0);
                  if (!($245)) {
                   label = 67;
                  }
                 }
                 if ((label|0) == 67) {
                  __THREW__ = 0;
                  $246 = (invoke_i(132)|0);
                  $247 = __THREW__; __THREW__ = 0;
                  $248 = $247&1;
                  if ($248) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($246|0));
                  $249 = __THREW__; __THREW__ = 0;
                  $250 = $249&1;
                  if ($250) {
                   break;
                  }
                 }
                 $251 = HEAP32[$111>>2]|0;
                 $252 = (($251) + 92|0);
                 $253 = HEAP32[$252>>2]|0;
                 $254 = Math_imul($253, $238)|0;
                 $255 = (($132) + ($254)|0);
                 HEAP8[$255>>0] = -1;
                 $256 = HEAP32[$78>>2]|0;
                 $257 = HEAP32[$80>>2]|0;
                 __THREW__ = 0;
                 invoke_viiiiii(55,(0|0),($256|0),0,($111|0),($239|0),($257|0));
                 $258 = __THREW__; __THREW__ = 0;
                 $259 = $258&1;
                 if ($259) {
                  break;
                 }
                 $260 = HEAP32[$80>>2]|0;
                 $261 = (($260) + ($239))|0;
                 $262 = (($261) + 1)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($111|0));
                 $263 = __THREW__; __THREW__ = 0;
                 $264 = $263&1;
                 if ($264) {
                  break;
                 }
                 $265 = ($261|0)<(0);
                 if ($265) {
                  label = 73;
                 } else {
                  $266 = (($111) + 12|0);
                  $267 = HEAP32[$266>>2]|0;
                  $268 = ($261>>>0)<($267>>>0);
                  if (!($268)) {
                   label = 73;
                  }
                 }
                 if ((label|0) == 73) {
                  __THREW__ = 0;
                  $269 = (invoke_i(132)|0);
                  $270 = __THREW__; __THREW__ = 0;
                  $271 = $270&1;
                  if ($271) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($269|0));
                  $272 = __THREW__; __THREW__ = 0;
                  $273 = $272&1;
                  if ($273) {
                   break;
                  }
                 }
                 $274 = HEAP32[$111>>2]|0;
                 $275 = (($274) + 92|0);
                 $276 = HEAP32[$275>>2]|0;
                 $277 = Math_imul($276, $261)|0;
                 $278 = (($132) + ($277)|0);
                 HEAP8[$278>>0] = -1;
                 $V_5$0 = $262;
                } else {
                 $V_5$0 = $170;
                }
                $279 = (($V_5$0) + 1)|0;
                __THREW__ = 0;
                invoke_vi(3799,($111|0));
                $280 = __THREW__; __THREW__ = 0;
                $281 = $280&1;
                if ($281) {
                 break;
                }
                $282 = ($V_5$0|0)<(0);
                if ($282) {
                 label = 79;
                } else {
                 $283 = (($111) + 12|0);
                 $284 = HEAP32[$283>>2]|0;
                 $285 = ($V_5$0>>>0)<($284>>>0);
                 if (!($285)) {
                  label = 79;
                 }
                }
                if ((label|0) == 79) {
                 __THREW__ = 0;
                 $286 = (invoke_i(132)|0);
                 $287 = __THREW__; __THREW__ = 0;
                 $288 = $287&1;
                 if ($288) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($286|0));
                 $289 = __THREW__; __THREW__ = 0;
                 $290 = $289&1;
                 if ($290) {
                  break;
                 }
                }
                $291 = HEAP32[$111>>2]|0;
                $292 = (($291) + 92|0);
                $293 = HEAP32[$292>>2]|0;
                $294 = Math_imul($293, $V_5$0)|0;
                $295 = (($132) + ($294)|0);
                HEAP8[$295>>0] = 1;
                $296 = HEAP32[$87>>2]|0;
                $297 = ($296|0)<(1);
                if ($297) {
                 $302 = $296;
                } else {
                 $298 = HEAP32[$85>>2]|0;
                 __THREW__ = 0;
                 invoke_viiiiii(55,(0|0),($298|0),0,($111|0),($279|0),($296|0));
                 $299 = __THREW__; __THREW__ = 0;
                 $300 = $299&1;
                 if ($300) {
                  break;
                 }
                 $$pre10 = HEAP32[$87>>2]|0;
                 $302 = $$pre10;
                }
                $301 = (($302) + ($279))|0;
                __THREW__ = 0;
                invoke_vi(3799,($111|0));
                $303 = __THREW__; __THREW__ = 0;
                $304 = $303&1;
                if ($304) {
                 break;
                }
                $305 = ($301|0)<(0);
                if ($305) {
                 label = 87;
                } else {
                 $306 = (($111) + 12|0);
                 $307 = HEAP32[$306>>2]|0;
                 $308 = ($301>>>0)<($307>>>0);
                 if (!($308)) {
                  label = 87;
                 }
                }
                if ((label|0) == 87) {
                 __THREW__ = 0;
                 $309 = (invoke_i(132)|0);
                 $310 = __THREW__; __THREW__ = 0;
                 $311 = $310&1;
                 if ($311) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($309|0));
                 $312 = __THREW__; __THREW__ = 0;
                 $313 = $312&1;
                 if ($313) {
                  break;
                 }
                }
                $314 = HEAP32[$111>>2]|0;
                $315 = (($314) + 92|0);
                $316 = HEAP32[$315>>2]|0;
                $317 = Math_imul($316, $301)|0;
                $318 = (($132) + ($317)|0);
                HEAP8[$318>>0] = 0;
                $319 = (($__this) + 80|0);
                $320 = HEAP32[$319>>2]|0;
                $321 = (($__this) + 72|0);
                $322 = HEAP32[$321>>2]|0;
                $323 = (($__this) + 84|0);
                $324 = HEAP32[$323>>2]|0;
                __THREW__ = 0;
                (invoke_ii(2996,(2281808|0))|0);
                $325 = __THREW__; __THREW__ = 0;
                $326 = $325&1;
                if ($326) {
                 break;
                }
                __THREW__ = 0;
                $327 = (invoke_ii(3469,(2281808|0))|0);
                $328 = __THREW__; __THREW__ = 0;
                $329 = $328&1;
                if ($329) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiiiiiiiiiiii(2,($327|0),($320|0),($322|0),($111|0),($324|0),0,0,0,0,0,0,0,0);
                $330 = __THREW__; __THREW__ = 0;
                $331 = $330&1;
                if ($331) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($327|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $lpad$phi$index = $20;$lpad$phi$index2 = $21;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_GetOptimizedLengthP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferP24mscorlib_System_Byte_arrih($__this,$data,$len,$defaultValue) {
 $__this = $__this|0;
 $data = $data|0;
 $len = $len|0;
 $defaultValue = $defaultValue|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $V_0$1$V_1$0 = 0, $V_0$1$lcssa = 0, $V_0$13 = 0, $V_1$02 = 0, $_stackTraceSentry = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2282376);
 $0 = ($len|0)>(0);
 if (!($0)) {
  $V_0$1$lcssa = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_0$1$lcssa|0);
 }
 $1 = (($data) + 16|0);
 $2 = (($data) + 12|0);
 $V_0$13 = -1;$V_1$02 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($data|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   label = 6;
   break;
  }
  $3 = HEAP32[$2>>2]|0;
  $4 = ($V_1$02>>>0)<($3>>>0);
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_i(132)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 6;
    break;
   }
  }
  $12 = HEAP32[$data>>2]|0;
  $13 = (($12) + 92|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = Math_imul($14, $V_1$02)|0;
  $16 = (($1) + ($15)|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = ($17<<24>>24)==($defaultValue<<24>>24);
  $V_0$1$V_1$0 = $18 ? $V_0$13 : $V_1$02;
  $19 = (($V_1$02) + 1)|0;
  $20 = ($19|0)<($len|0);
  if ($20) {
   $V_0$13 = $V_0$1$V_1$0;$V_1$02 = $19;
  } else {
   break;
  }
 }
 if ((label|0) == 6) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 }
 $phitmp = (($V_0$1$V_1$0) + 1)|0;
 $V_0$1$lcssa = $phitmp;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($V_0$1$lcssa|0);
}
function __ZN14ActionInvoker4I27mscorlib_System_Int32TraitsS0_17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEPFvPviiS4_bES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$1,$4,$6,$10);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker8I26mscorlib_System_ByteTraitsS0_S0_S0_29mscorlib_System_BooleanTraitsS0_S1_S1_E6InvokeEPFvPvhhhhbhbbES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP8[$6>>0]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)!=(0);
 $15 = (($args) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP8[$16>>0]|0;
 $18 = (($args) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = (($args) + 28|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)!=(0);
 FUNCTION_TABLE_viiiiiiiii[$action & 31]($obj,$1,$4,$7,$10,$14,$17,$21,$25);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I26mscorlib_System_ByteTraitsS0_S0_S0_E6InvokeEPFvPvhhhhES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP8[$6>>0]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$1,$4,$7,$10);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I26mscorlib_System_ByteTraits17VoidPointerTraitsS1_E6InvokeEPFvPvhS3_S3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$3,$5);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_26mscorlib_System_ByteTraitsE6InvokeEPFiPvS4_ihES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$5>>0]|0;
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z62mscorlib_Mono_Security_Cryptography_CryptoConvert_m_GetBytesLEP22mscorlib_System_Objecti($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284000);
 __THREW__ = 0;
 (invoke_ii(2996,(1203320|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2758,(1203320|0),4)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = $val&255;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = (($2) + 12|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ($9|0)==(0);
     if ($10) {
      __THREW__ = 0;
      $11 = (invoke_i(132)|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($11|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
     $18 = (($2) + 16|0);
     HEAP8[$18>>0] = $5;
     $19 = $val >>> 8;
     $20 = $19&255;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = HEAP32[$8>>2]|0;
      $24 = ($23>>>0)<(2);
      if ($24) {
       __THREW__ = 0;
       $25 = (invoke_i(132)|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($25|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
      }
      $30 = HEAP32[$2>>2]|0;
      $31 = (($30) + 92|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($18) + ($32)|0);
      HEAP8[$33>>0] = $20;
      $34 = $val >>> 16;
      $35 = $34&255;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       $38 = HEAP32[$8>>2]|0;
       $39 = ($38>>>0)<(3);
       if ($39) {
        __THREW__ = 0;
        $40 = (invoke_i(132)|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($40|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break;
        }
       }
       $45 = HEAP32[$2>>2]|0;
       $46 = (($45) + 92|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = $47 << 1;
       $49 = (($18) + ($48)|0);
       HEAP8[$49>>0] = $35;
       $50 = $val >>> 24;
       $51 = $50&255;
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if (!($53)) {
        $54 = HEAP32[$8>>2]|0;
        $55 = ($54>>>0)<(4);
        if (!($55)) {
         $61 = HEAP32[$2>>2]|0;
         $62 = (($61) + 92|0);
         $63 = HEAP32[$62>>2]|0;
         $64 = ($63*3)|0;
         $65 = (($18) + ($64)|0);
         HEAP8[$65>>0] = $51;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($2|0);
        }
        __THREW__ = 0;
        $56 = (invoke_i(132)|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if (!($58)) {
         __THREW__ = 0;
         invoke_vi(3302,($56|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if (!($60)) {
          $61 = HEAP32[$2>>2]|0;
          $62 = (($61) + 92|0);
          $63 = HEAP32[$62>>2]|0;
          $64 = ($63*3)|0;
          $65 = (($18) + ($64)|0);
          HEAP8[$65>>0] = $51;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($2|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z72mscorlib_Mono_Security_Cryptography_CryptoConvert_m_ToCapiPrivateKeyBlobP22mscorlib_System_ObjectP41mscorlib_System_Security_Cryptography_RSA($__this,$rsa) {
 $__this = $__this|0;
 $rsa = $rsa|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_1 = 0, $V_4$02 = 0, $V_5$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284048);
 __THREW__ = 0;
 invoke_vi(3799,($rsa|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_viiii(473,($L_1|0),(2504328|0),($rsa|0),1);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP32[$L_1>>2]|0;
    $5 = (($L_1) + 4|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($L_1) + 8|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($L_1) + 12|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($L_1) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($L_1) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($L_1) + 24|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($L_1) + 28|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($16|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = (($16) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $25 = $22 << 2;
      $26 = $22 >> 1;
      $27 = (($25) + 20)|0;
      $28 = (($27) + ($26))|0;
      __THREW__ = 0;
      $29 = (invoke_iii(2758,(1203320|0),($28|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       __THREW__ = 0;
       invoke_vi(3799,($29|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        $34 = (($29) + 12|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = ($35|0)==(0);
        if ($36) {
         __THREW__ = 0;
         $37 = (invoke_i(132)|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($37|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break;
         }
        }
        $46 = (($29) + 16|0);
        HEAP8[$46>>0] = 7;
        __THREW__ = 0;
        invoke_vi(3799,($29|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         $49 = HEAP32[$34>>2]|0;
         $50 = ($49>>>0)<(2);
         if ($50) {
          __THREW__ = 0;
          $51 = (invoke_i(132)|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($51|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
         }
         $56 = HEAP32[$29>>2]|0;
         $57 = (($56) + 92|0);
         $58 = HEAP32[$57>>2]|0;
         $59 = (($46) + ($58)|0);
         HEAP8[$59>>0] = 2;
         __THREW__ = 0;
         invoke_vi(3799,($29|0));
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if (!($61)) {
          $62 = HEAP32[$34>>2]|0;
          $63 = ($62>>>0)<(6);
          if ($63) {
           __THREW__ = 0;
           $64 = (invoke_i(132)|0);
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if ($66) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($64|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
          }
          $69 = HEAP32[$29>>2]|0;
          $70 = (($69) + 92|0);
          $71 = HEAP32[$70>>2]|0;
          $72 = ($71*5)|0;
          $73 = (($46) + ($72)|0);
          HEAP8[$73>>0] = 36;
          __THREW__ = 0;
          invoke_vi(3799,($29|0));
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if (!($75)) {
           $76 = HEAP32[$34>>2]|0;
           $77 = ($76>>>0)<(9);
           if ($77) {
            __THREW__ = 0;
            $78 = (invoke_i(132)|0);
            $79 = __THREW__; __THREW__ = 0;
            $80 = $79&1;
            if ($80) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($78|0));
            $81 = __THREW__; __THREW__ = 0;
            $82 = $81&1;
            if ($82) {
             break;
            }
           }
           $83 = HEAP32[$29>>2]|0;
           $84 = (($83) + 92|0);
           $85 = HEAP32[$84>>2]|0;
           $86 = $85 << 3;
           $87 = (($46) + ($86)|0);
           HEAP8[$87>>0] = 82;
           __THREW__ = 0;
           invoke_vi(3799,($29|0));
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if (!($89)) {
            $90 = HEAP32[$34>>2]|0;
            $91 = ($90>>>0)<(10);
            if ($91) {
             __THREW__ = 0;
             $92 = (invoke_i(132)|0);
             $93 = __THREW__; __THREW__ = 0;
             $94 = $93&1;
             if ($94) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($92|0));
             $95 = __THREW__; __THREW__ = 0;
             $96 = $95&1;
             if ($96) {
              break;
             }
            }
            $97 = HEAP32[$29>>2]|0;
            $98 = (($97) + 92|0);
            $99 = HEAP32[$98>>2]|0;
            $100 = ($99*9)|0;
            $101 = (($46) + ($100)|0);
            HEAP8[$101>>0] = 83;
            __THREW__ = 0;
            invoke_vi(3799,($29|0));
            $102 = __THREW__; __THREW__ = 0;
            $103 = $102&1;
            if (!($103)) {
             $104 = HEAP32[$34>>2]|0;
             $105 = ($104>>>0)<(11);
             if ($105) {
              __THREW__ = 0;
              $106 = (invoke_i(132)|0);
              $107 = __THREW__; __THREW__ = 0;
              $108 = $107&1;
              if ($108) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($106|0));
              $109 = __THREW__; __THREW__ = 0;
              $110 = $109&1;
              if ($110) {
               break;
              }
             }
             $111 = HEAP32[$29>>2]|0;
             $112 = (($111) + 92|0);
             $113 = HEAP32[$112>>2]|0;
             $114 = ($113*10)|0;
             $115 = (($46) + ($114)|0);
             HEAP8[$115>>0] = 65;
             __THREW__ = 0;
             invoke_vi(3799,($29|0));
             $116 = __THREW__; __THREW__ = 0;
             $117 = $116&1;
             if (!($117)) {
              $118 = HEAP32[$34>>2]|0;
              $119 = ($118>>>0)<(12);
              if ($119) {
               __THREW__ = 0;
               $120 = (invoke_i(132)|0);
               $121 = __THREW__; __THREW__ = 0;
               $122 = $121&1;
               if ($122) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($120|0));
               $123 = __THREW__; __THREW__ = 0;
               $124 = $123&1;
               if ($124) {
                break;
               }
              }
              $125 = HEAP32[$29>>2]|0;
              $126 = (($125) + 92|0);
              $127 = HEAP32[$126>>2]|0;
              $128 = ($127*11)|0;
              $129 = (($46) + ($128)|0);
              HEAP8[$129>>0] = 50;
              $130 = $22 << 3;
              __THREW__ = 0;
              $131 = (invoke_iii(805,0,($130|0))|0);
              $132 = __THREW__; __THREW__ = 0;
              $133 = $132&1;
              if ($133) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($131|0));
              $134 = __THREW__; __THREW__ = 0;
              $135 = $134&1;
              if ($135) {
               break;
              }
              $136 = (($131) + 12|0);
              $137 = HEAP32[$136>>2]|0;
              $138 = ($137|0)==(0);
              if ($138) {
               __THREW__ = 0;
               $139 = (invoke_i(132)|0);
               $140 = __THREW__; __THREW__ = 0;
               $141 = $140&1;
               if ($141) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($139|0));
               $142 = __THREW__; __THREW__ = 0;
               $143 = $142&1;
               if ($143) {
                break;
               }
              }
              $144 = (($131) + 16|0);
              $145 = HEAP8[$144>>0]|0;
              __THREW__ = 0;
              invoke_vi(3799,($29|0));
              $146 = __THREW__; __THREW__ = 0;
              $147 = $146&1;
              if ($147) {
               break;
              }
              $148 = HEAP32[$34>>2]|0;
              $149 = ($148>>>0)<(13);
              if ($149) {
               __THREW__ = 0;
               $150 = (invoke_i(132)|0);
               $151 = __THREW__; __THREW__ = 0;
               $152 = $151&1;
               if ($152) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($150|0));
               $153 = __THREW__; __THREW__ = 0;
               $154 = $153&1;
               if ($154) {
                break;
               }
              }
              $155 = HEAP32[$29>>2]|0;
              $156 = (($155) + 92|0);
              $157 = HEAP32[$156>>2]|0;
              $158 = ($157*12)|0;
              $159 = (($46) + ($158)|0);
              HEAP8[$159>>0] = $145;
              __THREW__ = 0;
              invoke_vi(3799,($131|0));
              $160 = __THREW__; __THREW__ = 0;
              $161 = $160&1;
              if ($161) {
               break;
              }
              $162 = HEAP32[$136>>2]|0;
              $163 = ($162>>>0)<(2);
              if ($163) {
               __THREW__ = 0;
               $164 = (invoke_i(132)|0);
               $165 = __THREW__; __THREW__ = 0;
               $166 = $165&1;
               if ($166) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($164|0));
               $167 = __THREW__; __THREW__ = 0;
               $168 = $167&1;
               if ($168) {
                break;
               }
              }
              $169 = HEAP32[$131>>2]|0;
              $170 = (($169) + 92|0);
              $171 = HEAP32[$170>>2]|0;
              $172 = (($144) + ($171)|0);
              $173 = HEAP8[$172>>0]|0;
              __THREW__ = 0;
              invoke_vi(3799,($29|0));
              $174 = __THREW__; __THREW__ = 0;
              $175 = $174&1;
              if ($175) {
               break;
              }
              $176 = HEAP32[$34>>2]|0;
              $177 = ($176>>>0)<(14);
              if ($177) {
               __THREW__ = 0;
               $178 = (invoke_i(132)|0);
               $179 = __THREW__; __THREW__ = 0;
               $180 = $179&1;
               if ($180) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($178|0));
               $181 = __THREW__; __THREW__ = 0;
               $182 = $181&1;
               if ($182) {
                break;
               }
              }
              $183 = HEAP32[$29>>2]|0;
              $184 = (($183) + 92|0);
              $185 = HEAP32[$184>>2]|0;
              $186 = ($185*13)|0;
              $187 = (($46) + ($186)|0);
              HEAP8[$187>>0] = $173;
              __THREW__ = 0;
              invoke_vi(3799,($131|0));
              $188 = __THREW__; __THREW__ = 0;
              $189 = $188&1;
              if ($189) {
               break;
              }
              $190 = HEAP32[$136>>2]|0;
              $191 = ($190>>>0)<(3);
              if ($191) {
               __THREW__ = 0;
               $192 = (invoke_i(132)|0);
               $193 = __THREW__; __THREW__ = 0;
               $194 = $193&1;
               if ($194) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($192|0));
               $195 = __THREW__; __THREW__ = 0;
               $196 = $195&1;
               if ($196) {
                break;
               }
              }
              $197 = HEAP32[$131>>2]|0;
              $198 = (($197) + 92|0);
              $199 = HEAP32[$198>>2]|0;
              $200 = $199 << 1;
              $201 = (($144) + ($200)|0);
              $202 = HEAP8[$201>>0]|0;
              __THREW__ = 0;
              invoke_vi(3799,($29|0));
              $203 = __THREW__; __THREW__ = 0;
              $204 = $203&1;
              if ($204) {
               break;
              }
              $205 = HEAP32[$34>>2]|0;
              $206 = ($205>>>0)<(15);
              if ($206) {
               __THREW__ = 0;
               $207 = (invoke_i(132)|0);
               $208 = __THREW__; __THREW__ = 0;
               $209 = $208&1;
               if ($209) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($207|0));
               $210 = __THREW__; __THREW__ = 0;
               $211 = $210&1;
               if ($211) {
                break;
               }
              }
              $212 = HEAP32[$29>>2]|0;
              $213 = (($212) + 92|0);
              $214 = HEAP32[$213>>2]|0;
              $215 = ($214*14)|0;
              $216 = (($46) + ($215)|0);
              HEAP8[$216>>0] = $202;
              __THREW__ = 0;
              invoke_vi(3799,($131|0));
              $217 = __THREW__; __THREW__ = 0;
              $218 = $217&1;
              if ($218) {
               break;
              }
              $219 = HEAP32[$136>>2]|0;
              $220 = ($219>>>0)<(4);
              if ($220) {
               __THREW__ = 0;
               $221 = (invoke_i(132)|0);
               $222 = __THREW__; __THREW__ = 0;
               $223 = $222&1;
               if ($223) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($221|0));
               $224 = __THREW__; __THREW__ = 0;
               $225 = $224&1;
               if ($225) {
                break;
               }
              }
              $226 = HEAP32[$131>>2]|0;
              $227 = (($226) + 92|0);
              $228 = HEAP32[$227>>2]|0;
              $229 = ($228*3)|0;
              $230 = (($144) + ($229)|0);
              $231 = HEAP8[$230>>0]|0;
              __THREW__ = 0;
              invoke_vi(3799,($29|0));
              $232 = __THREW__; __THREW__ = 0;
              $233 = $232&1;
              if ($233) {
               break;
              }
              $234 = HEAP32[$34>>2]|0;
              $235 = ($234>>>0)<(16);
              if ($235) {
               __THREW__ = 0;
               $236 = (invoke_i(132)|0);
               $237 = __THREW__; __THREW__ = 0;
               $238 = $237&1;
               if ($238) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($236|0));
               $239 = __THREW__; __THREW__ = 0;
               $240 = $239&1;
               if ($240) {
                break;
               }
              }
              $241 = HEAP32[$29>>2]|0;
              $242 = (($241) + 92|0);
              $243 = HEAP32[$242>>2]|0;
              $244 = ($243*15)|0;
              $245 = (($46) + ($244)|0);
              HEAP8[$245>>0] = $231;
              __THREW__ = 0;
              invoke_vi(3799,($18|0));
              $246 = __THREW__; __THREW__ = 0;
              $247 = $246&1;
              if ($247) {
               break;
              }
              $248 = (($18) + 12|0);
              $249 = HEAP32[$248>>2]|0;
              $250 = ($249|0)>(0);
              L84: do {
               if ($250) {
                $251 = (($18) + 16|0);
                $V_4$02 = 16;$V_5$01 = $249;
                while(1) {
                 $281 = (($V_4$02) + 1)|0;
                 $254 = (($V_5$01) + -1)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($18|0));
                 $282 = __THREW__; __THREW__ = 0;
                 $283 = $282&1;
                 if ($283) {
                  break;
                 }
                 $252 = HEAP32[$248>>2]|0;
                 $253 = ($254>>>0)<($252>>>0);
                 if (!($253)) {
                  __THREW__ = 0;
                  $255 = (invoke_i(132)|0);
                  $256 = __THREW__; __THREW__ = 0;
                  $257 = $256&1;
                  if ($257) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($255|0));
                  $258 = __THREW__; __THREW__ = 0;
                  $259 = $258&1;
                  if ($259) {
                   break;
                  }
                 }
                 $260 = HEAP32[$18>>2]|0;
                 $261 = (($260) + 92|0);
                 $262 = HEAP32[$261>>2]|0;
                 $263 = Math_imul($262, $254)|0;
                 $264 = (($251) + ($263)|0);
                 $265 = HEAP8[$264>>0]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($29|0));
                 $266 = __THREW__; __THREW__ = 0;
                 $267 = $266&1;
                 if ($267) {
                  break;
                 }
                 $268 = HEAP32[$34>>2]|0;
                 $269 = ($V_4$02>>>0)<($268>>>0);
                 if (!($269)) {
                  __THREW__ = 0;
                  $270 = (invoke_i(132)|0);
                  $271 = __THREW__; __THREW__ = 0;
                  $272 = $271&1;
                  if ($272) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($270|0));
                  $273 = __THREW__; __THREW__ = 0;
                  $274 = $273&1;
                  if ($274) {
                   break;
                  }
                 }
                 $275 = HEAP32[$29>>2]|0;
                 $276 = (($275) + 92|0);
                 $277 = HEAP32[$276>>2]|0;
                 $278 = Math_imul($277, $V_4$02)|0;
                 $279 = (($46) + ($278)|0);
                 HEAP8[$279>>0] = $265;
                 $280 = ($254|0)>(0);
                 if ($280) {
                  $V_4$02 = $281;$V_5$01 = $254;
                 } else {
                  break L84;
                 }
                }
                $42 = ___cxa_find_matching_catch()|0;
                $43 = tempRet0;
                $lpad$phi$index = $42;$lpad$phi$index2 = $43;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($16|0));
              $284 = __THREW__; __THREW__ = 0;
              $285 = $284&1;
              if ($285) {
               break;
              }
              $286 = HEAP32[$21>>2]|0;
              __THREW__ = 0;
              invoke_viiii(141,(0|0),($16|0),0,($286|0));
              $287 = __THREW__; __THREW__ = 0;
              $288 = $287&1;
              if ($288) {
               break;
              }
              __THREW__ = 0;
              invoke_viiiiii(65,(0|0),($16|0),0,($29|0),20,($286|0));
              $289 = __THREW__; __THREW__ = 0;
              $290 = $289&1;
              if ($290) {
               break;
              }
              $291 = (($286) + 20)|0;
              __THREW__ = 0;
              invoke_vi(3799,($4|0));
              $292 = __THREW__; __THREW__ = 0;
              $293 = $292&1;
              if ($293) {
               break;
              }
              $294 = (($4) + 12|0);
              $295 = HEAP32[$294>>2]|0;
              __THREW__ = 0;
              invoke_viiii(141,(0|0),($4|0),0,($295|0));
              $296 = __THREW__; __THREW__ = 0;
              $297 = $296&1;
              if ($297) {
               break;
              }
              __THREW__ = 0;
              invoke_viiiiii(65,(0|0),($4|0),0,($29|0),($291|0),($295|0));
              $298 = __THREW__; __THREW__ = 0;
              $299 = $298&1;
              if ($299) {
               break;
              }
              $300 = (($295) + ($291))|0;
              __THREW__ = 0;
              invoke_vi(3799,($6|0));
              $301 = __THREW__; __THREW__ = 0;
              $302 = $301&1;
              if ($302) {
               break;
              }
              $303 = (($6) + 12|0);
              $304 = HEAP32[$303>>2]|0;
              __THREW__ = 0;
              invoke_viiii(141,(0|0),($6|0),0,($304|0));
              $305 = __THREW__; __THREW__ = 0;
              $306 = $305&1;
              if ($306) {
               break;
              }
              __THREW__ = 0;
              invoke_viiiiii(65,(0|0),($6|0),0,($29|0),($300|0),($304|0));
              $307 = __THREW__; __THREW__ = 0;
              $308 = $307&1;
              if ($308) {
               break;
              }
              $309 = (($304) + ($300))|0;
              __THREW__ = 0;
              invoke_vi(3799,($10|0));
              $310 = __THREW__; __THREW__ = 0;
              $311 = $310&1;
              if ($311) {
               break;
              }
              $312 = (($10) + 12|0);
              $313 = HEAP32[$312>>2]|0;
              __THREW__ = 0;
              invoke_viiii(141,(0|0),($10|0),0,($313|0));
              $314 = __THREW__; __THREW__ = 0;
              $315 = $314&1;
              if ($315) {
               break;
              }
              __THREW__ = 0;
              invoke_viiiiii(65,(0|0),($10|0),0,($29|0),($309|0),($313|0));
              $316 = __THREW__; __THREW__ = 0;
              $317 = $316&1;
              if ($317) {
               break;
              }
              $318 = (($313) + ($309))|0;
              __THREW__ = 0;
              invoke_vi(3799,($12|0));
              $319 = __THREW__; __THREW__ = 0;
              $320 = $319&1;
              if ($320) {
               break;
              }
              $321 = (($12) + 12|0);
              $322 = HEAP32[$321>>2]|0;
              __THREW__ = 0;
              invoke_viiii(141,(0|0),($12|0),0,($322|0));
              $323 = __THREW__; __THREW__ = 0;
              $324 = $323&1;
              if ($324) {
               break;
              }
              __THREW__ = 0;
              invoke_viiiiii(65,(0|0),($12|0),0,($29|0),($318|0),($322|0));
              $325 = __THREW__; __THREW__ = 0;
              $326 = $325&1;
              if ($326) {
               break;
              }
              $327 = (($322) + ($318))|0;
              __THREW__ = 0;
              invoke_vi(3799,($14|0));
              $328 = __THREW__; __THREW__ = 0;
              $329 = $328&1;
              if ($329) {
               break;
              }
              $330 = (($14) + 12|0);
              $331 = HEAP32[$330>>2]|0;
              __THREW__ = 0;
              invoke_viiii(141,(0|0),($14|0),0,($331|0));
              $332 = __THREW__; __THREW__ = 0;
              $333 = $332&1;
              if ($333) {
               break;
              }
              __THREW__ = 0;
              invoke_viiiiii(65,(0|0),($14|0),0,($29|0),($327|0),($331|0));
              $334 = __THREW__; __THREW__ = 0;
              $335 = $334&1;
              if ($335) {
               break;
              }
              $336 = (($331) + ($327))|0;
              __THREW__ = 0;
              invoke_vi(3799,($8|0));
              $337 = __THREW__; __THREW__ = 0;
              $338 = $337&1;
              if ($338) {
               break;
              }
              $339 = (($8) + 12|0);
              $340 = HEAP32[$339>>2]|0;
              __THREW__ = 0;
              invoke_viiii(141,(0|0),($8|0),0,($340|0));
              $341 = __THREW__; __THREW__ = 0;
              $342 = $341&1;
              if ($342) {
               break;
              }
              __THREW__ = 0;
              invoke_viiiiii(65,(0|0),($8|0),0,($29|0),($336|0),($340|0));
              $343 = __THREW__; __THREW__ = 0;
              $344 = $343&1;
              if ($344) {
               break;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($29|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $44 = ___cxa_find_matching_catch()|0;
 $45 = tempRet0;
 $lpad$phi$index = $44;$lpad$phi$index2 = $45;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I57mscorlib_System_Security_Cryptography_RSAParametersTraits29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb($agg$result,$method,$obj,$p1) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($agg$result,$4,$p1);
 STACKTOP = sp;return;
}
function __Z71mscorlib_Mono_Security_Cryptography_CryptoConvert_m_ToCapiPublicKeyBlobP22mscorlib_System_ObjectP41mscorlib_System_Security_Cryptography_RSA($__this,$rsa) {
 $__this = $__this|0;
 $rsa = $rsa|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_1 = 0, $V_4$02 = 0, $V_5$01 = 0;
 var $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284096);
 __THREW__ = 0;
 invoke_vi(3799,($rsa|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_viiii(473,($L_1|0),(2504328|0),($rsa|0),0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($L_1) + 24|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (($L_1) + 28|0);
    $7 = HEAP32[$6>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($5) + 12|0);
     $11 = HEAP32[$10>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($11) + 20)|0;
      __THREW__ = 0;
      $15 = (invoke_iii(2758,(1203320|0),($14|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       invoke_vi(3799,($15|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $20 = (($15) + 12|0);
        $21 = HEAP32[$20>>2]|0;
        $22 = ($21|0)==(0);
        if ($22) {
         __THREW__ = 0;
         $23 = (invoke_i(132)|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($23|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
        }
        $32 = (($15) + 16|0);
        HEAP8[$32>>0] = 6;
        __THREW__ = 0;
        invoke_vi(3799,($15|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         $35 = HEAP32[$20>>2]|0;
         $36 = ($35>>>0)<(2);
         if ($36) {
          __THREW__ = 0;
          $37 = (invoke_i(132)|0);
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($37|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           break;
          }
         }
         $42 = HEAP32[$15>>2]|0;
         $43 = (($42) + 92|0);
         $44 = HEAP32[$43>>2]|0;
         $45 = (($32) + ($44)|0);
         HEAP8[$45>>0] = 2;
         __THREW__ = 0;
         invoke_vi(3799,($15|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if (!($47)) {
          $48 = HEAP32[$20>>2]|0;
          $49 = ($48>>>0)<(6);
          if ($49) {
           __THREW__ = 0;
           $50 = (invoke_i(132)|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if ($52) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($50|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if ($54) {
            break;
           }
          }
          $55 = HEAP32[$15>>2]|0;
          $56 = (($55) + 92|0);
          $57 = HEAP32[$56>>2]|0;
          $58 = ($57*5)|0;
          $59 = (($32) + ($58)|0);
          HEAP8[$59>>0] = 36;
          __THREW__ = 0;
          invoke_vi(3799,($15|0));
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if (!($61)) {
           $62 = HEAP32[$20>>2]|0;
           $63 = ($62>>>0)<(9);
           if ($63) {
            __THREW__ = 0;
            $64 = (invoke_i(132)|0);
            $65 = __THREW__; __THREW__ = 0;
            $66 = $65&1;
            if ($66) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($64|0));
            $67 = __THREW__; __THREW__ = 0;
            $68 = $67&1;
            if ($68) {
             break;
            }
           }
           $69 = HEAP32[$15>>2]|0;
           $70 = (($69) + 92|0);
           $71 = HEAP32[$70>>2]|0;
           $72 = $71 << 3;
           $73 = (($32) + ($72)|0);
           HEAP8[$73>>0] = 82;
           __THREW__ = 0;
           invoke_vi(3799,($15|0));
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if (!($75)) {
            $76 = HEAP32[$20>>2]|0;
            $77 = ($76>>>0)<(10);
            if ($77) {
             __THREW__ = 0;
             $78 = (invoke_i(132)|0);
             $79 = __THREW__; __THREW__ = 0;
             $80 = $79&1;
             if ($80) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($78|0));
             $81 = __THREW__; __THREW__ = 0;
             $82 = $81&1;
             if ($82) {
              break;
             }
            }
            $83 = HEAP32[$15>>2]|0;
            $84 = (($83) + 92|0);
            $85 = HEAP32[$84>>2]|0;
            $86 = ($85*9)|0;
            $87 = (($32) + ($86)|0);
            HEAP8[$87>>0] = 83;
            __THREW__ = 0;
            invoke_vi(3799,($15|0));
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if (!($89)) {
             $90 = HEAP32[$20>>2]|0;
             $91 = ($90>>>0)<(11);
             if ($91) {
              __THREW__ = 0;
              $92 = (invoke_i(132)|0);
              $93 = __THREW__; __THREW__ = 0;
              $94 = $93&1;
              if ($94) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($92|0));
              $95 = __THREW__; __THREW__ = 0;
              $96 = $95&1;
              if ($96) {
               break;
              }
             }
             $97 = HEAP32[$15>>2]|0;
             $98 = (($97) + 92|0);
             $99 = HEAP32[$98>>2]|0;
             $100 = ($99*10)|0;
             $101 = (($32) + ($100)|0);
             HEAP8[$101>>0] = 65;
             __THREW__ = 0;
             invoke_vi(3799,($15|0));
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             if (!($103)) {
              $104 = HEAP32[$20>>2]|0;
              $105 = ($104>>>0)<(12);
              if ($105) {
               __THREW__ = 0;
               $106 = (invoke_i(132)|0);
               $107 = __THREW__; __THREW__ = 0;
               $108 = $107&1;
               if ($108) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($106|0));
               $109 = __THREW__; __THREW__ = 0;
               $110 = $109&1;
               if ($110) {
                break;
               }
              }
              $111 = HEAP32[$15>>2]|0;
              $112 = (($111) + 92|0);
              $113 = HEAP32[$112>>2]|0;
              $114 = ($113*11)|0;
              $115 = (($32) + ($114)|0);
              HEAP8[$115>>0] = 49;
              $116 = $11 << 3;
              __THREW__ = 0;
              $117 = (invoke_iii(805,0,($116|0))|0);
              $118 = __THREW__; __THREW__ = 0;
              $119 = $118&1;
              if ($119) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($117|0));
              $120 = __THREW__; __THREW__ = 0;
              $121 = $120&1;
              if ($121) {
               break;
              }
              $122 = (($117) + 12|0);
              $123 = HEAP32[$122>>2]|0;
              $124 = ($123|0)==(0);
              if ($124) {
               __THREW__ = 0;
               $125 = (invoke_i(132)|0);
               $126 = __THREW__; __THREW__ = 0;
               $127 = $126&1;
               if ($127) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($125|0));
               $128 = __THREW__; __THREW__ = 0;
               $129 = $128&1;
               if ($129) {
                break;
               }
              }
              $130 = (($117) + 16|0);
              $131 = HEAP8[$130>>0]|0;
              __THREW__ = 0;
              invoke_vi(3799,($15|0));
              $132 = __THREW__; __THREW__ = 0;
              $133 = $132&1;
              if ($133) {
               break;
              }
              $134 = HEAP32[$20>>2]|0;
              $135 = ($134>>>0)<(13);
              if ($135) {
               __THREW__ = 0;
               $136 = (invoke_i(132)|0);
               $137 = __THREW__; __THREW__ = 0;
               $138 = $137&1;
               if ($138) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($136|0));
               $139 = __THREW__; __THREW__ = 0;
               $140 = $139&1;
               if ($140) {
                break;
               }
              }
              $141 = HEAP32[$15>>2]|0;
              $142 = (($141) + 92|0);
              $143 = HEAP32[$142>>2]|0;
              $144 = ($143*12)|0;
              $145 = (($32) + ($144)|0);
              HEAP8[$145>>0] = $131;
              __THREW__ = 0;
              invoke_vi(3799,($117|0));
              $146 = __THREW__; __THREW__ = 0;
              $147 = $146&1;
              if ($147) {
               break;
              }
              $148 = HEAP32[$122>>2]|0;
              $149 = ($148>>>0)<(2);
              if ($149) {
               __THREW__ = 0;
               $150 = (invoke_i(132)|0);
               $151 = __THREW__; __THREW__ = 0;
               $152 = $151&1;
               if ($152) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($150|0));
               $153 = __THREW__; __THREW__ = 0;
               $154 = $153&1;
               if ($154) {
                break;
               }
              }
              $155 = HEAP32[$117>>2]|0;
              $156 = (($155) + 92|0);
              $157 = HEAP32[$156>>2]|0;
              $158 = (($130) + ($157)|0);
              $159 = HEAP8[$158>>0]|0;
              __THREW__ = 0;
              invoke_vi(3799,($15|0));
              $160 = __THREW__; __THREW__ = 0;
              $161 = $160&1;
              if ($161) {
               break;
              }
              $162 = HEAP32[$20>>2]|0;
              $163 = ($162>>>0)<(14);
              if ($163) {
               __THREW__ = 0;
               $164 = (invoke_i(132)|0);
               $165 = __THREW__; __THREW__ = 0;
               $166 = $165&1;
               if ($166) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($164|0));
               $167 = __THREW__; __THREW__ = 0;
               $168 = $167&1;
               if ($168) {
                break;
               }
              }
              $169 = HEAP32[$15>>2]|0;
              $170 = (($169) + 92|0);
              $171 = HEAP32[$170>>2]|0;
              $172 = ($171*13)|0;
              $173 = (($32) + ($172)|0);
              HEAP8[$173>>0] = $159;
              __THREW__ = 0;
              invoke_vi(3799,($117|0));
              $174 = __THREW__; __THREW__ = 0;
              $175 = $174&1;
              if ($175) {
               break;
              }
              $176 = HEAP32[$122>>2]|0;
              $177 = ($176>>>0)<(3);
              if ($177) {
               __THREW__ = 0;
               $178 = (invoke_i(132)|0);
               $179 = __THREW__; __THREW__ = 0;
               $180 = $179&1;
               if ($180) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($178|0));
               $181 = __THREW__; __THREW__ = 0;
               $182 = $181&1;
               if ($182) {
                break;
               }
              }
              $183 = HEAP32[$117>>2]|0;
              $184 = (($183) + 92|0);
              $185 = HEAP32[$184>>2]|0;
              $186 = $185 << 1;
              $187 = (($130) + ($186)|0);
              $188 = HEAP8[$187>>0]|0;
              __THREW__ = 0;
              invoke_vi(3799,($15|0));
              $189 = __THREW__; __THREW__ = 0;
              $190 = $189&1;
              if ($190) {
               break;
              }
              $191 = HEAP32[$20>>2]|0;
              $192 = ($191>>>0)<(15);
              if ($192) {
               __THREW__ = 0;
               $193 = (invoke_i(132)|0);
               $194 = __THREW__; __THREW__ = 0;
               $195 = $194&1;
               if ($195) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($193|0));
               $196 = __THREW__; __THREW__ = 0;
               $197 = $196&1;
               if ($197) {
                break;
               }
              }
              $198 = HEAP32[$15>>2]|0;
              $199 = (($198) + 92|0);
              $200 = HEAP32[$199>>2]|0;
              $201 = ($200*14)|0;
              $202 = (($32) + ($201)|0);
              HEAP8[$202>>0] = $188;
              __THREW__ = 0;
              invoke_vi(3799,($117|0));
              $203 = __THREW__; __THREW__ = 0;
              $204 = $203&1;
              if ($204) {
               break;
              }
              $205 = HEAP32[$122>>2]|0;
              $206 = ($205>>>0)<(4);
              if ($206) {
               __THREW__ = 0;
               $207 = (invoke_i(132)|0);
               $208 = __THREW__; __THREW__ = 0;
               $209 = $208&1;
               if ($209) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($207|0));
               $210 = __THREW__; __THREW__ = 0;
               $211 = $210&1;
               if ($211) {
                break;
               }
              }
              $212 = HEAP32[$117>>2]|0;
              $213 = (($212) + 92|0);
              $214 = HEAP32[$213>>2]|0;
              $215 = ($214*3)|0;
              $216 = (($130) + ($215)|0);
              $217 = HEAP8[$216>>0]|0;
              __THREW__ = 0;
              invoke_vi(3799,($15|0));
              $218 = __THREW__; __THREW__ = 0;
              $219 = $218&1;
              if ($219) {
               break;
              }
              $220 = HEAP32[$20>>2]|0;
              $221 = ($220>>>0)<(16);
              if ($221) {
               __THREW__ = 0;
               $222 = (invoke_i(132)|0);
               $223 = __THREW__; __THREW__ = 0;
               $224 = $223&1;
               if ($224) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($222|0));
               $225 = __THREW__; __THREW__ = 0;
               $226 = $225&1;
               if ($226) {
                break;
               }
              }
              $227 = HEAP32[$15>>2]|0;
              $228 = (($227) + 92|0);
              $229 = HEAP32[$228>>2]|0;
              $230 = ($229*15)|0;
              $231 = (($32) + ($230)|0);
              HEAP8[$231>>0] = $217;
              __THREW__ = 0;
              invoke_vi(3799,($7|0));
              $232 = __THREW__; __THREW__ = 0;
              $233 = $232&1;
              if ($233) {
               break;
              }
              $234 = (($7) + 12|0);
              $235 = HEAP32[$234>>2]|0;
              $236 = ($235|0)>(0);
              L84: do {
               if ($236) {
                $237 = (($7) + 16|0);
                $V_4$02 = 16;$V_5$01 = $235;
                while(1) {
                 $267 = (($V_4$02) + 1)|0;
                 $240 = (($V_5$01) + -1)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($7|0));
                 $268 = __THREW__; __THREW__ = 0;
                 $269 = $268&1;
                 if ($269) {
                  break;
                 }
                 $238 = HEAP32[$234>>2]|0;
                 $239 = ($240>>>0)<($238>>>0);
                 if (!($239)) {
                  __THREW__ = 0;
                  $241 = (invoke_i(132)|0);
                  $242 = __THREW__; __THREW__ = 0;
                  $243 = $242&1;
                  if ($243) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($241|0));
                  $244 = __THREW__; __THREW__ = 0;
                  $245 = $244&1;
                  if ($245) {
                   break;
                  }
                 }
                 $246 = HEAP32[$7>>2]|0;
                 $247 = (($246) + 92|0);
                 $248 = HEAP32[$247>>2]|0;
                 $249 = Math_imul($248, $240)|0;
                 $250 = (($237) + ($249)|0);
                 $251 = HEAP8[$250>>0]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($15|0));
                 $252 = __THREW__; __THREW__ = 0;
                 $253 = $252&1;
                 if ($253) {
                  break;
                 }
                 $254 = HEAP32[$20>>2]|0;
                 $255 = ($V_4$02>>>0)<($254>>>0);
                 if (!($255)) {
                  __THREW__ = 0;
                  $256 = (invoke_i(132)|0);
                  $257 = __THREW__; __THREW__ = 0;
                  $258 = $257&1;
                  if ($258) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($256|0));
                  $259 = __THREW__; __THREW__ = 0;
                  $260 = $259&1;
                  if ($260) {
                   break;
                  }
                 }
                 $261 = HEAP32[$15>>2]|0;
                 $262 = (($261) + 92|0);
                 $263 = HEAP32[$262>>2]|0;
                 $264 = Math_imul($263, $V_4$02)|0;
                 $265 = (($32) + ($264)|0);
                 HEAP8[$265>>0] = $251;
                 $266 = ($240|0)>(0);
                 if ($266) {
                  $V_4$02 = $267;$V_5$01 = $240;
                 } else {
                  break L84;
                 }
                }
                $28 = ___cxa_find_matching_catch()|0;
                $29 = tempRet0;
                $lpad$phi$index = $28;$lpad$phi$index2 = $29;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($5|0));
              $270 = __THREW__; __THREW__ = 0;
              $271 = $270&1;
              if ($271) {
               break;
              }
              $272 = HEAP32[$10>>2]|0;
              __THREW__ = 0;
              invoke_viiii(141,(0|0),($5|0),0,($272|0));
              $273 = __THREW__; __THREW__ = 0;
              $274 = $273&1;
              if ($274) {
               break;
              }
              __THREW__ = 0;
              invoke_viiiiii(65,(0|0),($5|0),0,($15|0),20,($272|0));
              $275 = __THREW__; __THREW__ = 0;
              $276 = $275&1;
              if ($276) {
               break;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($15|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 $lpad$phi$index = $30;$lpad$phi$index2 = $31;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_Mono_Security_Cryptography_CryptoConvert_m_ToCapiKeyBlobP22mscorlib_System_ObjectP41mscorlib_System_Security_Cryptography_RSAb($__this,$rsa,$includePrivateKey) {
 $__this = $__this|0;
 $rsa = $rsa|0;
 $includePrivateKey = $includePrivateKey|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284144);
 __THREW__ = 0;
 invoke_v(532);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($rsa|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3020432>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   } else {
    if ($includePrivateKey) {
     __THREW__ = 0;
     $15 = (invoke_iii(806,0,($rsa|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     } else {
      $$0 = $15;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     __THREW__ = 0;
     $18 = (invoke_iii(807,0,($rsa|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     } else {
      $$0 = $18;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS3_S3_bES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z52mscorlib_Mono_Security_BitConverterLE_m_GetUIntBytesP22mscorlib_System_ObjectPh($__this,$bytes) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 var $$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284576);
 __THREW__ = 0;
 (invoke_ii(2996,(2564344|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2564344 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3832,(2564344|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2564344|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2564344 + 80|0))>>2]|0;
    $15 = (($14) + 1|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      break;
     }
     __THREW__ = 0;
     $84 = (invoke_iii(2758,(1203320|0),4)|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      break;
     }
     $87 = (($bytes) + 3|0);
     $88 = HEAP8[$87>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($84|0));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      break;
     }
     $91 = (($84) + 12|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = ($92|0)==(0);
     if ($93) {
      __THREW__ = 0;
      $94 = (invoke_i(132)|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($94|0));
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       break;
      }
     }
     $99 = (($84) + 16|0);
     HEAP8[$99>>0] = $88;
     $100 = (($bytes) + 2|0);
     $101 = HEAP8[$100>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($84|0));
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      break;
     }
     $104 = HEAP32[$91>>2]|0;
     $105 = ($104>>>0)<(2);
     if ($105) {
      __THREW__ = 0;
      $106 = (invoke_i(132)|0);
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($106|0));
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       break;
      }
     }
     $111 = HEAP32[$84>>2]|0;
     $112 = (($111) + 92|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = (($99) + ($113)|0);
     HEAP8[$114>>0] = $101;
     $115 = (($bytes) + 1|0);
     $116 = HEAP8[$115>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($84|0));
     $117 = __THREW__; __THREW__ = 0;
     $118 = $117&1;
     if ($118) {
      break;
     }
     $119 = HEAP32[$91>>2]|0;
     $120 = ($119>>>0)<(3);
     if ($120) {
      __THREW__ = 0;
      $121 = (invoke_i(132)|0);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($121|0));
      $124 = __THREW__; __THREW__ = 0;
      $125 = $124&1;
      if ($125) {
       break;
      }
     }
     $126 = HEAP32[$84>>2]|0;
     $127 = (($126) + 92|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = $128 << 1;
     $130 = (($99) + ($129)|0);
     HEAP8[$130>>0] = $116;
     $131 = HEAP8[$bytes>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($84|0));
     $132 = __THREW__; __THREW__ = 0;
     $133 = $132&1;
     if ($133) {
      break;
     }
     $134 = HEAP32[$91>>2]|0;
     $135 = ($134>>>0)<(4);
     if ($135) {
      __THREW__ = 0;
      $136 = (invoke_i(132)|0);
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($136|0));
      $139 = __THREW__; __THREW__ = 0;
      $140 = $139&1;
      if ($140) {
       break;
      }
     }
     $141 = HEAP32[$84>>2]|0;
     $142 = (($141) + 92|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = ($143*3)|0;
     $145 = (($99) + ($144)|0);
     HEAP8[$145>>0] = $131;
     $$0$in = $84;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0$in|0);
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(1203320|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_iii(2758,(1203320|0),4)|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     $23 = HEAP8[$bytes>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     $26 = (($20) + 12|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==(0);
     if ($28) {
      __THREW__ = 0;
      $29 = (invoke_i(132)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($29|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
     }
     $34 = (($20) + 16|0);
     HEAP8[$34>>0] = $23;
     $35 = (($bytes) + 1|0);
     $36 = HEAP8[$35>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     $39 = HEAP32[$26>>2]|0;
     $40 = ($39>>>0)<(2);
     if ($40) {
      __THREW__ = 0;
      $41 = (invoke_i(132)|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($41|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break;
      }
     }
     $46 = HEAP32[$20>>2]|0;
     $47 = (($46) + 92|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($34) + ($48)|0);
     HEAP8[$49>>0] = $36;
     $50 = (($bytes) + 2|0);
     $51 = HEAP8[$50>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     $54 = HEAP32[$26>>2]|0;
     $55 = ($54>>>0)<(3);
     if ($55) {
      __THREW__ = 0;
      $56 = (invoke_i(132)|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($56|0));
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
     }
     $61 = HEAP32[$20>>2]|0;
     $62 = (($61) + 92|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = $63 << 1;
     $65 = (($34) + ($64)|0);
     HEAP8[$65>>0] = $51;
     $66 = (($bytes) + 3|0);
     $67 = HEAP8[$66>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     $70 = HEAP32[$26>>2]|0;
     $71 = ($70>>>0)<(4);
     if ($71) {
      __THREW__ = 0;
      $72 = (invoke_i(132)|0);
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($72|0));
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       break;
      }
     }
     $77 = HEAP32[$20>>2]|0;
     $78 = (($77) + 92|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79*3)|0;
     $81 = (($34) + ($80)|0);
     HEAP8[$81>>0] = $67;
     $$0$in = $20;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0$in|0);
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_Mono_Security_BitConverterLE_m_GetBytesP22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284624);
 __THREW__ = 0;
 $1 = (invoke_iii(808,0,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __Z55mscorlib_Mono_Security_BitConverterLE_m_UShortFromBytesP22mscorlib_System_ObjectPhP24mscorlib_System_Byte_arri($__this,$dst,$src,$startIndex) {
 $__this = $__this|0;
 $dst = $dst|0;
 $src = $src|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284672);
 __THREW__ = 0;
 (invoke_ii(2996,(2564344|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2564344 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3832,(2564344|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2564344|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2564344 + 80|0))>>2]|0;
    $15 = (($14) + 1|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     $55 = (($startIndex) + 1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     $58 = ($55|0)<(0);
     if ($58) {
      label = 23;
     } else {
      $59 = (($src) + 12|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($55>>>0)<($60>>>0);
      if (!($61)) {
       label = 23;
      }
     }
     if ((label|0) == 23) {
      __THREW__ = 0;
      $62 = (invoke_i(132)|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($62|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
     $67 = HEAP32[$src>>2]|0;
     $68 = (($src) + 16|0);
     $69 = (($67) + 92|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = Math_imul($70, $55)|0;
     $72 = (($68) + ($71)|0);
     $73 = HEAP8[$72>>0]|0;
     HEAP8[$dst>>0] = $73;
     $74 = (($dst) + 1|0);
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      break;
     }
     $77 = ($startIndex|0)<(0);
     if ($77) {
      label = 28;
     } else {
      $78 = (($src) + 12|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = ($79>>>0)>($startIndex>>>0);
      if (!($80)) {
       label = 28;
      }
     }
     if ((label|0) == 28) {
      __THREW__ = 0;
      $81 = (invoke_i(132)|0);
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($81|0));
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if ($85) {
       break;
      }
     }
     $86 = HEAP32[$src>>2]|0;
     $87 = (($86) + 92|0);
     $88 = HEAP32[$87>>2]|0;
     $89 = Math_imul($88, $startIndex)|0;
     $90 = (($68) + ($89)|0);
     $91 = HEAP8[$90>>0]|0;
     HEAP8[$74>>0] = $91;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = ($startIndex|0)<(0);
     if ($20) {
      label = 12;
     } else {
      $21 = (($src) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22>>>0)>($startIndex>>>0);
      if (!($23)) {
       label = 12;
      }
     }
     if ((label|0) == 12) {
      __THREW__ = 0;
      $24 = (invoke_i(132)|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($24|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
     }
     $29 = HEAP32[$src>>2]|0;
     $30 = (($src) + 16|0);
     $31 = (($29) + 92|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = Math_imul($32, $startIndex)|0;
     $34 = (($30) + ($33)|0);
     $35 = HEAP8[$34>>0]|0;
     HEAP8[$dst>>0] = $35;
     $36 = (($dst) + 1|0);
     $37 = (($startIndex) + 1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     $40 = ($37|0)<(0);
     if ($40) {
      label = 17;
     } else {
      $41 = (($src) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($37>>>0)<($42>>>0);
      if (!($43)) {
       label = 17;
      }
     }
     if ((label|0) == 17) {
      __THREW__ = 0;
      $44 = (invoke_i(132)|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($44|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
     }
     $49 = HEAP32[$src>>2]|0;
     $50 = (($49) + 92|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = Math_imul($51, $37)|0;
     $53 = (($30) + ($52)|0);
     $54 = HEAP8[$53>>0]|0;
     HEAP8[$36>>0] = $54;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z53mscorlib_Mono_Security_BitConverterLE_m_UIntFromBytesP22mscorlib_System_ObjectPhP24mscorlib_System_Byte_arri($__this,$dst,$src,$startIndex) {
 $__this = $__this|0;
 $dst = $dst|0;
 $src = $src|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284720);
 __THREW__ = 0;
 (invoke_ii(2996,(2564344|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2564344 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3832,(2564344|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2564344|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2564344 + 80|0))>>2]|0;
    $15 = (($14) + 1|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     $93 = (($startIndex) + 3)|0;
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      break;
     }
     $96 = ($93|0)<(0);
     if ($96) {
      label = 33;
     } else {
      $97 = (($src) + 12|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = ($93>>>0)<($98>>>0);
      if (!($99)) {
       label = 33;
      }
     }
     if ((label|0) == 33) {
      __THREW__ = 0;
      $100 = (invoke_i(132)|0);
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($100|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       break;
      }
     }
     $105 = HEAP32[$src>>2]|0;
     $106 = (($src) + 16|0);
     $107 = (($105) + 92|0);
     $108 = HEAP32[$107>>2]|0;
     $109 = Math_imul($108, $93)|0;
     $110 = (($106) + ($109)|0);
     $111 = HEAP8[$110>>0]|0;
     HEAP8[$dst>>0] = $111;
     $112 = (($dst) + 1|0);
     $113 = (($startIndex) + 2)|0;
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if ($115) {
      break;
     }
     $116 = ($113|0)<(0);
     if ($116) {
      label = 38;
     } else {
      $117 = (($src) + 12|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = ($113>>>0)<($118>>>0);
      if (!($119)) {
       label = 38;
      }
     }
     if ((label|0) == 38) {
      __THREW__ = 0;
      $120 = (invoke_i(132)|0);
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($120|0));
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       break;
      }
     }
     $125 = HEAP32[$src>>2]|0;
     $126 = (($125) + 92|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = Math_imul($127, $113)|0;
     $129 = (($106) + ($128)|0);
     $130 = HEAP8[$129>>0]|0;
     HEAP8[$112>>0] = $130;
     $131 = (($dst) + 2|0);
     $132 = (($startIndex) + 1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if ($134) {
      break;
     }
     $135 = ($132|0)<(0);
     if ($135) {
      label = 43;
     } else {
      $136 = (($src) + 12|0);
      $137 = HEAP32[$136>>2]|0;
      $138 = ($132>>>0)<($137>>>0);
      if (!($138)) {
       label = 43;
      }
     }
     if ((label|0) == 43) {
      __THREW__ = 0;
      $139 = (invoke_i(132)|0);
      $140 = __THREW__; __THREW__ = 0;
      $141 = $140&1;
      if ($141) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($139|0));
      $142 = __THREW__; __THREW__ = 0;
      $143 = $142&1;
      if ($143) {
       break;
      }
     }
     $144 = HEAP32[$src>>2]|0;
     $145 = (($144) + 92|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = Math_imul($146, $132)|0;
     $148 = (($106) + ($147)|0);
     $149 = HEAP8[$148>>0]|0;
     HEAP8[$131>>0] = $149;
     $150 = (($dst) + 3|0);
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $151 = __THREW__; __THREW__ = 0;
     $152 = $151&1;
     if ($152) {
      break;
     }
     $153 = ($startIndex|0)<(0);
     if ($153) {
      label = 48;
     } else {
      $154 = (($src) + 12|0);
      $155 = HEAP32[$154>>2]|0;
      $156 = ($155>>>0)>($startIndex>>>0);
      if (!($156)) {
       label = 48;
      }
     }
     if ((label|0) == 48) {
      __THREW__ = 0;
      $157 = (invoke_i(132)|0);
      $158 = __THREW__; __THREW__ = 0;
      $159 = $158&1;
      if ($159) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($157|0));
      $160 = __THREW__; __THREW__ = 0;
      $161 = $160&1;
      if ($161) {
       break;
      }
     }
     $162 = HEAP32[$src>>2]|0;
     $163 = (($162) + 92|0);
     $164 = HEAP32[$163>>2]|0;
     $165 = Math_imul($164, $startIndex)|0;
     $166 = (($106) + ($165)|0);
     $167 = HEAP8[$166>>0]|0;
     HEAP8[$150>>0] = $167;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = ($startIndex|0)<(0);
     if ($20) {
      label = 12;
     } else {
      $21 = (($src) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($22>>>0)>($startIndex>>>0);
      if (!($23)) {
       label = 12;
      }
     }
     if ((label|0) == 12) {
      __THREW__ = 0;
      $24 = (invoke_i(132)|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($24|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
     }
     $29 = HEAP32[$src>>2]|0;
     $30 = (($src) + 16|0);
     $31 = (($29) + 92|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = Math_imul($32, $startIndex)|0;
     $34 = (($30) + ($33)|0);
     $35 = HEAP8[$34>>0]|0;
     HEAP8[$dst>>0] = $35;
     $36 = (($dst) + 1|0);
     $37 = (($startIndex) + 1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     $40 = ($37|0)<(0);
     if ($40) {
      label = 17;
     } else {
      $41 = (($src) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($37>>>0)<($42>>>0);
      if (!($43)) {
       label = 17;
      }
     }
     if ((label|0) == 17) {
      __THREW__ = 0;
      $44 = (invoke_i(132)|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($44|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
     }
     $49 = HEAP32[$src>>2]|0;
     $50 = (($49) + 92|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = Math_imul($51, $37)|0;
     $53 = (($30) + ($52)|0);
     $54 = HEAP8[$53>>0]|0;
     HEAP8[$36>>0] = $54;
     $55 = (($dst) + 2|0);
     $56 = (($startIndex) + 2)|0;
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     $59 = ($56|0)<(0);
     if ($59) {
      label = 22;
     } else {
      $60 = (($src) + 12|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($56>>>0)<($61>>>0);
      if (!($62)) {
       label = 22;
      }
     }
     if ((label|0) == 22) {
      __THREW__ = 0;
      $63 = (invoke_i(132)|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
     }
     $68 = HEAP32[$src>>2]|0;
     $69 = (($68) + 92|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = Math_imul($70, $56)|0;
     $72 = (($30) + ($71)|0);
     $73 = HEAP8[$72>>0]|0;
     HEAP8[$55>>0] = $73;
     $74 = (($dst) + 3|0);
     $75 = (($startIndex) + 3)|0;
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break;
     }
     $78 = ($75|0)<(0);
     if ($78) {
      label = 27;
     } else {
      $79 = (($src) + 12|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = ($75>>>0)<($80>>>0);
      if (!($81)) {
       label = 27;
      }
     }
     if ((label|0) == 27) {
      __THREW__ = 0;
      $82 = (invoke_i(132)|0);
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if ($84) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($82|0));
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if ($86) {
       break;
      }
     }
     $87 = HEAP32[$src>>2]|0;
     $88 = (($87) + 92|0);
     $89 = HEAP32[$88>>2]|0;
     $90 = Math_imul($89, $75)|0;
     $91 = (($30) + ($90)|0);
     $92 = HEAP8[$91>>0]|0;
     HEAP8[$74>>0] = $92;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z47mscorlib_Mono_Security_BitConverterLE_m_ToInt16P22mscorlib_System_ObjectP24mscorlib_System_Byte_arri($__this,$value,$startIndex) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284768);
 HEAP16[$V_0>>1] = 0;
 __THREW__ = 0;
 invoke_viiii(149,0,($V_0|0),($value|0),($startIndex|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP16[$V_0>>1]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z47mscorlib_Mono_Security_BitConverterLE_m_ToInt32P22mscorlib_System_ObjectP24mscorlib_System_Byte_arri($__this,$value,$startIndex) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2284816);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(150,0,($V_0|0),($value|0),($startIndex|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP32[$V_0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker2I27mscorlib_System_Int16Traits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFsPvS4_iES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$3)|0);
 HEAP16[$ret>>1] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z42mscorlib_Mono_Security_StrongName_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2285328);
 __THREW__ = 0;
 (invoke_ii(2996,(2149728|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2149728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1924,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2285928|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2285928 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __THREW__ = 0;
     (invoke_ii(2996,(2285928|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[((2285928 + 80|0))>>2]|0;
      $13 = (($12) + 4|0);
      HEAP8[$13>>0] = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z49mscorlib_Mono_Security_StrongName_m_get_PublicKeyP33mscorlib_Mono_Security_StrongName($__this) {
 $__this = $__this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2285376);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $3 = (($__this) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   $5 = (invoke_iiii(777,0,($4|0),0)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iii(2729,(2500448|0),($8|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      (invoke_ii(2996,(1203320|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = $11 >> 3;
       $17 = (($16) + 32)|0;
       __THREW__ = 0;
       $18 = (invoke_iii(2758,(1203320|0),($17|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        HEAP32[$0>>2] = $18;
        __THREW__ = 0;
        invoke_vi(3799,($5|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $23 = (($5) + 12|0);
         $24 = HEAP32[$23>>2]|0;
         $25 = ($24>>>0)<(5);
         if ($25) {
          __THREW__ = 0;
          $26 = (invoke_i(132)|0);
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if ($28) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($26|0));
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if ($30) {
           break;
          }
         }
         $33 = HEAP32[$5>>2]|0;
         $34 = (($5) + 16|0);
         $35 = (($33) + 92|0);
         $36 = HEAP32[$35>>2]|0;
         $37 = $36 << 2;
         $38 = (($34) + ($37)|0);
         $39 = HEAP8[$38>>0]|0;
         __THREW__ = 0;
         invoke_vi(3799,($18|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = (($18) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43|0)==(0);
          if ($44) {
           __THREW__ = 0;
           $45 = (invoke_i(132)|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if ($47) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($45|0));
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break;
           }
          }
          $50 = (($18) + 16|0);
          HEAP8[$50>>0] = $39;
          $51 = HEAP32[$0>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($5|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           $54 = HEAP32[$23>>2]|0;
           $55 = ($54>>>0)<(6);
           if ($55) {
            __THREW__ = 0;
            $56 = (invoke_i(132)|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if ($58) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($56|0));
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             break;
            }
           }
           $61 = HEAP32[$5>>2]|0;
           $62 = (($61) + 92|0);
           $63 = HEAP32[$62>>2]|0;
           $64 = ($63*5)|0;
           $65 = (($34) + ($64)|0);
           $66 = HEAP8[$65>>0]|0;
           __THREW__ = 0;
           invoke_vi(3799,($51|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if (!($68)) {
            $69 = (($51) + 12|0);
            $70 = HEAP32[$69>>2]|0;
            $71 = ($70>>>0)<(2);
            if ($71) {
             __THREW__ = 0;
             $72 = (invoke_i(132)|0);
             $73 = __THREW__; __THREW__ = 0;
             $74 = $73&1;
             if ($74) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($72|0));
             $75 = __THREW__; __THREW__ = 0;
             $76 = $75&1;
             if ($76) {
              break;
             }
            }
            $77 = HEAP32[$51>>2]|0;
            $78 = (($51) + 16|0);
            $79 = (($77) + 92|0);
            $80 = HEAP32[$79>>2]|0;
            $81 = (($78) + ($80)|0);
            HEAP8[$81>>0] = $66;
            $82 = HEAP32[$0>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($5|0));
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if (!($84)) {
             $85 = HEAP32[$23>>2]|0;
             $86 = ($85>>>0)<(7);
             if ($86) {
              __THREW__ = 0;
              $87 = (invoke_i(132)|0);
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if ($89) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($87|0));
              $90 = __THREW__; __THREW__ = 0;
              $91 = $90&1;
              if ($91) {
               break;
              }
             }
             $92 = HEAP32[$5>>2]|0;
             $93 = (($92) + 92|0);
             $94 = HEAP32[$93>>2]|0;
             $95 = ($94*6)|0;
             $96 = (($34) + ($95)|0);
             $97 = HEAP8[$96>>0]|0;
             __THREW__ = 0;
             invoke_vi(3799,($82|0));
             $98 = __THREW__; __THREW__ = 0;
             $99 = $98&1;
             if (!($99)) {
              $100 = (($82) + 12|0);
              $101 = HEAP32[$100>>2]|0;
              $102 = ($101>>>0)<(3);
              if ($102) {
               __THREW__ = 0;
               $103 = (invoke_i(132)|0);
               $104 = __THREW__; __THREW__ = 0;
               $105 = $104&1;
               if ($105) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($103|0));
               $106 = __THREW__; __THREW__ = 0;
               $107 = $106&1;
               if ($107) {
                break;
               }
              }
              $108 = HEAP32[$82>>2]|0;
              $109 = (($82) + 16|0);
              $110 = (($108) + 92|0);
              $111 = HEAP32[$110>>2]|0;
              $112 = $111 << 1;
              $113 = (($109) + ($112)|0);
              HEAP8[$113>>0] = $97;
              $114 = HEAP32[$0>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($5|0));
              $115 = __THREW__; __THREW__ = 0;
              $116 = $115&1;
              if (!($116)) {
               $117 = HEAP32[$23>>2]|0;
               $118 = ($117>>>0)<(8);
               if ($118) {
                __THREW__ = 0;
                $119 = (invoke_i(132)|0);
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($119|0));
                $122 = __THREW__; __THREW__ = 0;
                $123 = $122&1;
                if ($123) {
                 break;
                }
               }
               $124 = HEAP32[$5>>2]|0;
               $125 = (($124) + 92|0);
               $126 = HEAP32[$125>>2]|0;
               $127 = ($126*7)|0;
               $128 = (($34) + ($127)|0);
               $129 = HEAP8[$128>>0]|0;
               __THREW__ = 0;
               invoke_vi(3799,($114|0));
               $130 = __THREW__; __THREW__ = 0;
               $131 = $130&1;
               if ($131) {
                break;
               }
               $132 = (($114) + 12|0);
               $133 = HEAP32[$132>>2]|0;
               $134 = ($133>>>0)<(4);
               if ($134) {
                __THREW__ = 0;
                $135 = (invoke_i(132)|0);
                $136 = __THREW__; __THREW__ = 0;
                $137 = $136&1;
                if ($137) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($135|0));
                $138 = __THREW__; __THREW__ = 0;
                $139 = $138&1;
                if ($139) {
                 break;
                }
               }
               $140 = HEAP32[$114>>2]|0;
               $141 = (($114) + 16|0);
               $142 = (($140) + 92|0);
               $143 = HEAP32[$142>>2]|0;
               $144 = ($143*3)|0;
               $145 = (($141) + ($144)|0);
               HEAP8[$145>>0] = $129;
               $146 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($146|0));
               $147 = __THREW__; __THREW__ = 0;
               $148 = $147&1;
               if ($148) {
                break;
               }
               $149 = (($146) + 12|0);
               $150 = HEAP32[$149>>2]|0;
               $151 = ($150>>>0)<(5);
               if ($151) {
                __THREW__ = 0;
                $152 = (invoke_i(132)|0);
                $153 = __THREW__; __THREW__ = 0;
                $154 = $153&1;
                if ($154) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($152|0));
                $155 = __THREW__; __THREW__ = 0;
                $156 = $155&1;
                if ($156) {
                 break;
                }
               }
               $157 = HEAP32[$146>>2]|0;
               $158 = (($146) + 16|0);
               $159 = (($157) + 92|0);
               $160 = HEAP32[$159>>2]|0;
               $161 = $160 << 2;
               $162 = (($158) + ($161)|0);
               HEAP8[$162>>0] = 4;
               $163 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($163|0));
               $164 = __THREW__; __THREW__ = 0;
               $165 = $164&1;
               if ($165) {
                break;
               }
               $166 = (($163) + 12|0);
               $167 = HEAP32[$166>>2]|0;
               $168 = ($167>>>0)<(6);
               if ($168) {
                __THREW__ = 0;
                $169 = (invoke_i(132)|0);
                $170 = __THREW__; __THREW__ = 0;
                $171 = $170&1;
                if ($171) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($169|0));
                $172 = __THREW__; __THREW__ = 0;
                $173 = $172&1;
                if ($173) {
                 break;
                }
               }
               $174 = HEAP32[$163>>2]|0;
               $175 = (($163) + 16|0);
               $176 = (($174) + 92|0);
               $177 = HEAP32[$176>>2]|0;
               $178 = ($177*5)|0;
               $179 = (($175) + ($178)|0);
               HEAP8[$179>>0] = -128;
               $180 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($180|0));
               $181 = __THREW__; __THREW__ = 0;
               $182 = $181&1;
               if ($182) {
                break;
               }
               $183 = (($180) + 12|0);
               $184 = HEAP32[$183>>2]|0;
               $185 = ($184>>>0)<(7);
               if ($185) {
                __THREW__ = 0;
                $186 = (invoke_i(132)|0);
                $187 = __THREW__; __THREW__ = 0;
                $188 = $187&1;
                if ($188) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($186|0));
                $189 = __THREW__; __THREW__ = 0;
                $190 = $189&1;
                if ($190) {
                 break;
                }
               }
               $191 = HEAP32[$180>>2]|0;
               $192 = (($180) + 16|0);
               $193 = (($191) + 92|0);
               $194 = HEAP32[$193>>2]|0;
               $195 = ($194*6)|0;
               $196 = (($192) + ($195)|0);
               HEAP8[$196>>0] = 0;
               $197 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($197|0));
               $198 = __THREW__; __THREW__ = 0;
               $199 = $198&1;
               if ($199) {
                break;
               }
               $200 = (($197) + 12|0);
               $201 = HEAP32[$200>>2]|0;
               $202 = ($201>>>0)<(8);
               if ($202) {
                __THREW__ = 0;
                $203 = (invoke_i(132)|0);
                $204 = __THREW__; __THREW__ = 0;
                $205 = $204&1;
                if ($205) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($203|0));
                $206 = __THREW__; __THREW__ = 0;
                $207 = $206&1;
                if ($207) {
                 break;
                }
               }
               $208 = HEAP32[$197>>2]|0;
               $209 = (($197) + 16|0);
               $210 = (($208) + 92|0);
               $211 = HEAP32[$210>>2]|0;
               $212 = ($211*7)|0;
               $213 = (($209) + ($212)|0);
               HEAP8[$213>>0] = 0;
               $214 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($214|0));
               $215 = __THREW__; __THREW__ = 0;
               $216 = $215&1;
               if ($216) {
                break;
               }
               $217 = (($214) + 12|0);
               $218 = HEAP32[$217>>2]|0;
               $219 = (($218) + -12)|0;
               __THREW__ = 0;
               $220 = (invoke_iii(809,0,($219|0))|0);
               $221 = __THREW__; __THREW__ = 0;
               $222 = $221&1;
               if ($222) {
                break;
               }
               $223 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($220|0));
               $224 = __THREW__; __THREW__ = 0;
               $225 = $224&1;
               if ($225) {
                break;
               }
               $226 = (($220) + 12|0);
               $227 = HEAP32[$226>>2]|0;
               $228 = ($227|0)==(0);
               if ($228) {
                __THREW__ = 0;
                $229 = (invoke_i(132)|0);
                $230 = __THREW__; __THREW__ = 0;
                $231 = $230&1;
                if ($231) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($229|0));
                $232 = __THREW__; __THREW__ = 0;
                $233 = $232&1;
                if ($233) {
                 break;
                }
               }
               $234 = (($220) + 16|0);
               $235 = HEAP8[$234>>0]|0;
               __THREW__ = 0;
               invoke_vi(3799,($223|0));
               $236 = __THREW__; __THREW__ = 0;
               $237 = $236&1;
               if ($237) {
                break;
               }
               $238 = (($223) + 12|0);
               $239 = HEAP32[$238>>2]|0;
               $240 = ($239>>>0)<(9);
               if ($240) {
                __THREW__ = 0;
                $241 = (invoke_i(132)|0);
                $242 = __THREW__; __THREW__ = 0;
                $243 = $242&1;
                if ($243) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($241|0));
                $244 = __THREW__; __THREW__ = 0;
                $245 = $244&1;
                if ($245) {
                 break;
                }
               }
               $246 = HEAP32[$223>>2]|0;
               $247 = (($223) + 16|0);
               $248 = (($246) + 92|0);
               $249 = HEAP32[$248>>2]|0;
               $250 = $249 << 3;
               $251 = (($247) + ($250)|0);
               HEAP8[$251>>0] = $235;
               $252 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($220|0));
               $253 = __THREW__; __THREW__ = 0;
               $254 = $253&1;
               if ($254) {
                break;
               }
               $255 = HEAP32[$226>>2]|0;
               $256 = ($255>>>0)<(2);
               if ($256) {
                __THREW__ = 0;
                $257 = (invoke_i(132)|0);
                $258 = __THREW__; __THREW__ = 0;
                $259 = $258&1;
                if ($259) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($257|0));
                $260 = __THREW__; __THREW__ = 0;
                $261 = $260&1;
                if ($261) {
                 break;
                }
               }
               $262 = HEAP32[$220>>2]|0;
               $263 = (($262) + 92|0);
               $264 = HEAP32[$263>>2]|0;
               $265 = (($234) + ($264)|0);
               $266 = HEAP8[$265>>0]|0;
               __THREW__ = 0;
               invoke_vi(3799,($252|0));
               $267 = __THREW__; __THREW__ = 0;
               $268 = $267&1;
               if ($268) {
                break;
               }
               $269 = (($252) + 12|0);
               $270 = HEAP32[$269>>2]|0;
               $271 = ($270>>>0)<(10);
               if ($271) {
                __THREW__ = 0;
                $272 = (invoke_i(132)|0);
                $273 = __THREW__; __THREW__ = 0;
                $274 = $273&1;
                if ($274) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($272|0));
                $275 = __THREW__; __THREW__ = 0;
                $276 = $275&1;
                if ($276) {
                 break;
                }
               }
               $277 = HEAP32[$252>>2]|0;
               $278 = (($252) + 16|0);
               $279 = (($277) + 92|0);
               $280 = HEAP32[$279>>2]|0;
               $281 = ($280*9)|0;
               $282 = (($278) + ($281)|0);
               HEAP8[$282>>0] = $266;
               $283 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($220|0));
               $284 = __THREW__; __THREW__ = 0;
               $285 = $284&1;
               if ($285) {
                break;
               }
               $286 = HEAP32[$226>>2]|0;
               $287 = ($286>>>0)<(3);
               if ($287) {
                __THREW__ = 0;
                $288 = (invoke_i(132)|0);
                $289 = __THREW__; __THREW__ = 0;
                $290 = $289&1;
                if ($290) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($288|0));
                $291 = __THREW__; __THREW__ = 0;
                $292 = $291&1;
                if ($292) {
                 break;
                }
               }
               $293 = HEAP32[$220>>2]|0;
               $294 = (($293) + 92|0);
               $295 = HEAP32[$294>>2]|0;
               $296 = $295 << 1;
               $297 = (($234) + ($296)|0);
               $298 = HEAP8[$297>>0]|0;
               __THREW__ = 0;
               invoke_vi(3799,($283|0));
               $299 = __THREW__; __THREW__ = 0;
               $300 = $299&1;
               if ($300) {
                break;
               }
               $301 = (($283) + 12|0);
               $302 = HEAP32[$301>>2]|0;
               $303 = ($302>>>0)<(11);
               if ($303) {
                __THREW__ = 0;
                $304 = (invoke_i(132)|0);
                $305 = __THREW__; __THREW__ = 0;
                $306 = $305&1;
                if ($306) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($304|0));
                $307 = __THREW__; __THREW__ = 0;
                $308 = $307&1;
                if ($308) {
                 break;
                }
               }
               $309 = HEAP32[$283>>2]|0;
               $310 = (($283) + 16|0);
               $311 = (($309) + 92|0);
               $312 = HEAP32[$311>>2]|0;
               $313 = ($312*10)|0;
               $314 = (($310) + ($313)|0);
               HEAP8[$314>>0] = $298;
               $315 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($220|0));
               $316 = __THREW__; __THREW__ = 0;
               $317 = $316&1;
               if ($317) {
                break;
               }
               $318 = HEAP32[$226>>2]|0;
               $319 = ($318>>>0)<(4);
               if ($319) {
                __THREW__ = 0;
                $320 = (invoke_i(132)|0);
                $321 = __THREW__; __THREW__ = 0;
                $322 = $321&1;
                if ($322) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($320|0));
                $323 = __THREW__; __THREW__ = 0;
                $324 = $323&1;
                if ($324) {
                 break;
                }
               }
               $325 = HEAP32[$220>>2]|0;
               $326 = (($325) + 92|0);
               $327 = HEAP32[$326>>2]|0;
               $328 = ($327*3)|0;
               $329 = (($234) + ($328)|0);
               $330 = HEAP8[$329>>0]|0;
               __THREW__ = 0;
               invoke_vi(3799,($315|0));
               $331 = __THREW__; __THREW__ = 0;
               $332 = $331&1;
               if ($332) {
                break;
               }
               $333 = (($315) + 12|0);
               $334 = HEAP32[$333>>2]|0;
               $335 = ($334>>>0)<(12);
               if ($335) {
                __THREW__ = 0;
                $336 = (invoke_i(132)|0);
                $337 = __THREW__; __THREW__ = 0;
                $338 = $337&1;
                if ($338) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($336|0));
                $339 = __THREW__; __THREW__ = 0;
                $340 = $339&1;
                if ($340) {
                 break;
                }
               }
               $341 = HEAP32[$315>>2]|0;
               $342 = (($315) + 16|0);
               $343 = (($341) + 92|0);
               $344 = HEAP32[$343>>2]|0;
               $345 = ($344*11)|0;
               $346 = (($342) + ($345)|0);
               HEAP8[$346>>0] = $330;
               $347 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($347|0));
               $348 = __THREW__; __THREW__ = 0;
               $349 = $348&1;
               if ($349) {
                break;
               }
               $350 = (($347) + 12|0);
               $351 = HEAP32[$350>>2]|0;
               $352 = ($351>>>0)<(13);
               if ($352) {
                __THREW__ = 0;
                $353 = (invoke_i(132)|0);
                $354 = __THREW__; __THREW__ = 0;
                $355 = $354&1;
                if ($355) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($353|0));
                $356 = __THREW__; __THREW__ = 0;
                $357 = $356&1;
                if ($357) {
                 break;
                }
               }
               $358 = HEAP32[$347>>2]|0;
               $359 = (($347) + 16|0);
               $360 = (($358) + 92|0);
               $361 = HEAP32[$360>>2]|0;
               $362 = ($361*12)|0;
               $363 = (($359) + ($362)|0);
               HEAP8[$363>>0] = 6;
               $364 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($364|0));
               $365 = __THREW__; __THREW__ = 0;
               $366 = $365&1;
               if ($366) {
                break;
               }
               $367 = (($364) + 12|0);
               $368 = HEAP32[$367>>2]|0;
               $369 = (($368) + -13)|0;
               __THREW__ = 0;
               invoke_viiiiii(65,(0|0),($5|0),1,($364|0),13,($369|0));
               $370 = __THREW__; __THREW__ = 0;
               $371 = $370&1;
               if ($371) {
                break;
               }
               $372 = HEAP32[$0>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($372|0));
               $373 = __THREW__; __THREW__ = 0;
               $374 = $373&1;
               if ($374) {
                break;
               }
               $375 = (($372) + 12|0);
               $376 = HEAP32[$375>>2]|0;
               $377 = ($376>>>0)<(24);
               if ($377) {
                __THREW__ = 0;
                $378 = (invoke_i(132)|0);
                $379 = __THREW__; __THREW__ = 0;
                $380 = $379&1;
                if ($380) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($378|0));
                $381 = __THREW__; __THREW__ = 0;
                $382 = $381&1;
                if ($382) {
                 break;
                }
               }
               $383 = HEAP32[$372>>2]|0;
               $384 = (($372) + 16|0);
               $385 = (($383) + 92|0);
               $386 = HEAP32[$385>>2]|0;
               $387 = ($386*23)|0;
               $388 = (($384) + ($387)|0);
               HEAP8[$388>>0] = 49;
               $$pre = HEAP32[$0>>2]|0;
               $389 = $$pre;
               label = 101;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  } else {
   $389 = $1;
   label = 101;
  }
 } while(0);
 if ((label|0) == 101) {
  __THREW__ = 0;
  invoke_vi(3799,($389|0));
  $390 = __THREW__; __THREW__ = 0;
  $391 = $390&1;
  if (!($391)) {
   __THREW__ = 0;
   $392 = (invoke_iii(2756,(2224152|0),($389|0))|0);
   $393 = __THREW__; __THREW__ = 0;
   $394 = $393&1;
   if (!($394)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1203320|0))|0);
    $395 = __THREW__; __THREW__ = 0;
    $396 = $395&1;
    if (!($396)) {
     __THREW__ = 0;
     $397 = (invoke_iii(2759,($392|0),(1203320|0))|0);
     $398 = __THREW__; __THREW__ = 0;
     $399 = $398&1;
     if (!($399)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($397|0);
     }
    }
   }
  }
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($31|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo5705($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z54mscorlib_Mono_Security_StrongName_m_get_PublicKeyTokenP33mscorlib_Mono_Security_StrongName($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2285424);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  $3 = (invoke_ii(1932,($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $9 = (invoke_ii(1934,($__this|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(960,(0|0),($9|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3799,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iii(959,($12|0),($3|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       (invoke_ii(2996,(1203320|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        $22 = (invoke_iii(2758,(1203320|0),8)|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         HEAP32[$0>>2] = $22;
         __THREW__ = 0;
         invoke_vi(3799,($17|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          $27 = (($17) + 12|0);
          $28 = HEAP32[$27>>2]|0;
          $29 = (($28) + -8)|0;
          $30 = HEAP32[$0>>2]|0;
          __THREW__ = 0;
          invoke_viiiiii(65,(0|0),($17|0),($29|0),($30|0),0,8);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           $33 = HEAP32[$0>>2]|0;
           __THREW__ = 0;
           invoke_viiii(141,(0|0),($33|0),0,8);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $$pre = HEAP32[$0>>2]|0;
            $36 = $$pre;
            label = 15;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } else {
  $36 = $1;
  label = 15;
 }
 if ((label|0) == 15) {
  __THREW__ = 0;
  invoke_vi(3799,($36|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if (!($38)) {
   __THREW__ = 0;
   $39 = (invoke_iii(2756,(2224152|0),($36|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    __THREW__ = 0;
    (invoke_ii(2996,(1203320|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     __THREW__ = 0;
     $44 = (invoke_iii(2759,($39|0),(1203320|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      $$0 = $44;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_Mono_Security_StrongName_m_get_TokenAlgorithmP33mscorlib_Mono_Security_StrongName($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2285472);
 __THREW__ = 0;
 invoke_v(533);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $2 = (($__this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $8 = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 $7 = HEAP32[3020456>>2]|0;
 HEAP32[$2>>2] = $7;
 $8 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($8|0);
}
function __Z38mscorlib_Mono_Runtime_m_GetDisplayNameP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2286064);
 $0 = HEAP32[2286112>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2286120|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2286112>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2319176)|0);
 $5 = HEAP32[((2287168 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $9 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2290720)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($8,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $8;
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2318968);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($type|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2730,(2233608|0),($type|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 8|0);
    HEAP32[$7>>2] = $4;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2318192);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    $7 = HEAP8[((2191608 + 116|0))>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2191608|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = HEAP32[((2191608 + 80|0))>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $$0 = $18;
   } else {
    $$0 = $value;
   }
   $19 = (($__this) + 8|0);
   HEAP32[$19>>2] = $$0;
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP8[((2191608 + 116|0))>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2191608|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = HEAP32[((2191608 + 80|0))>>2]|0;
     $33 = HEAP32[$32>>2]|0;
     $34 = (($__this) + 12|0);
     HEAP32[$34>>2] = $33;
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      $37 = HEAP8[((2191608 + 116|0))>>0]|0;
      $38 = ($37<<24>>24)==(0);
      if ($38) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3832,(2191608|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       $47 = HEAP32[((2191608 + 80|0))>>2]|0;
       $48 = HEAP32[$47>>2]|0;
       $49 = (($__this) + 16|0);
       HEAP32[$49>>2] = $48;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z79mscorlib_System_Collections_Generic_Dictionary_2_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2291976)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $8 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2290720)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($7,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $7;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2319176)|0);
 $15 = HEAP32[((2287168 + 48|0))>>2]|0;
 $16 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($15)|0);
 __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($14,$16);
 $17 = HEAP32[$3>>2]|0;
 $18 = (($17) + 12|0);
 HEAP32[$18>>2] = $14;
 STACKTOP = sp;return;
}
function __Z106mscorlib_System_Collections_Generic_Dictionary_2_CustomAttributesCacheGenerator_U003CU003Ef__amU0024cacheBP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z151mscorlib_System_Collections_Generic_Dictionary_2_CustomAttributesCacheGenerator_mscorlib_System_Collections_Generic_Dictionary_2_m_U003CCopyToU003Em__0P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Collections_Generic_IDictionary_2_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2291976)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Collections_Generic_KeyValuePair_2_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2294872)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($4,$5);
 $6 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2294880)|0);
 __Z63mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_set_NameP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_set_NameP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2318240);
 $0 = (($__this) + 16|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z73mscorlib_System_Collections_Generic_List_1_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2291976)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $8 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2290720)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($7,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $7;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2319176)|0);
 $12 = HEAP32[((2286624 + 48|0))>>2]|0;
 $13 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($12)|0);
 __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($11,$13);
 $14 = HEAP32[$3>>2]|0;
 $15 = (($14) + 8|0);
 HEAP32[$15>>2] = $11;
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_Collections_ArrayList_SimpleEnumerator_m__ctorP54mscorlib_System_Collections_ArrayList_SimpleEnumeratorP37mscorlib_System_Collections_ArrayList($__this,$list) {
 $__this = $__this|0;
 $list = $list|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2296344);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 8|0);
   HEAP32[$2>>2] = $list;
   $3 = (($__this) + 12|0);
   HEAP32[$3>>2] = -1;
   __THREW__ = 0;
   invoke_vi(3799,($list|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($list) + 16|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($__this) + 16|0);
    HEAP32[$8>>2] = $7;
    __THREW__ = 0;
    (invoke_ii(2996,(2297008|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP8[((2297008 + 116|0))>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      __THREW__ = 0;
      (invoke_ii(2996,(2297008|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2297008|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3832,(2297008|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2297008|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = HEAP32[((2297008 + 80|0))>>2]|0;
      $24 = HEAP32[$23>>2]|0;
      $25 = (($__this) + 20|0);
      HEAP32[$25>>2] = $24;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
}
function __Z63mscorlib_System_Collections_ArrayList_SimpleEnumerator_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2296392);
 __THREW__ = 0;
 (invoke_ii(2996,(2149728|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2149728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1924,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2297008|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2297008 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z65mscorlib_System_Collections_ArrayList_SimpleEnumerator_m_MoveNextP54mscorlib_System_Collections_ArrayList_SimpleEnumerator($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2296440);
 __THREW__ = 0;
 invoke_v(534);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 16|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($__this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($5) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($3|0)==($9|0);
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2607872|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_ii(3469,(2607872|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     $18 = HEAP32[3022672>>2]|0;
     __THREW__ = 0;
     invoke_vii(1947,($15|0),($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($15|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = (($__this) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = (($26) + 1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      HEAP32[$25>>2] = $27;
      $30 = HEAP32[$4>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($30|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       $33 = (invoke_iii(2729,(2296488|0),($30|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $36 = ($27|0)<($33|0);
        if ($36) {
         $37 = HEAP32[$4>>2]|0;
         $38 = HEAP32[$25>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($37|0));
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break;
         }
         __THREW__ = 0;
         $41 = (invoke_iiii(1648,(2296536|0),($37|0),($38|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break;
         }
         $44 = (($__this) + 20|0);
         HEAP32[$44>>2] = $41;
         $$0 = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2297008|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = HEAP8[((2297008 + 116|0))>>0]|0;
         $48 = ($47<<24>>24)==(0);
         if ($48) {
          __THREW__ = 0;
          (invoke_ii(2996,(2297008|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2297008|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3832,(2297008|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2297008|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          $57 = HEAP32[((2297008 + 80|0))>>2]|0;
          $58 = HEAP32[$57>>2]|0;
          $59 = (($__this) + 20|0);
          HEAP32[$59>>2] = $58;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Collections_ArrayList_SimpleEnumerator_m_get_CurrentP54mscorlib_System_Collections_ArrayList_SimpleEnumerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2296584);
 __THREW__ = 0;
 invoke_v(535);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 20|0);
   $3 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2297008|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = HEAP8[((2297008 + 116|0))>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if ($7) {
     __THREW__ = 0;
     (invoke_ii(2996,(2297008|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2297008|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2297008|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2297008|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[((2297008 + 80|0))>>2]|0;
     $19 = HEAP32[$18>>2]|0;
     $20 = ($3|0)==($19|0);
     if (!($20)) {
      $44 = HEAP32[$2>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($44|0);
     }
     $21 = (($__this) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22|0)==(-1);
     if ($23) {
      __THREW__ = 0;
      (invoke_ii(2996,(2607872|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_ii(3469,(2607872|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP32[3022568>>2]|0;
      __THREW__ = 0;
      invoke_vii(1947,($26|0),($29|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($26|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      // unreachable;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2607872|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_ii(3469,(2607872|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = HEAP32[3022576>>2]|0;
      __THREW__ = 0;
      invoke_vii(1947,($36|0),($39|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($36|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      }
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Collections_ArrayList_ArrayListWrapper_m__ctorP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP37mscorlib_System_Collections_ArrayList($__this,$innerArrayList) {
 $__this = $__this|0;
 $innerArrayList = $innerArrayList|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297144);
 __THREW__ = 0;
 invoke_vi(2153,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 20|0);
  HEAP32[$2>>2] = $innerArrayList;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z66mscorlib_System_Collections_ArrayList_m__ctor_mscorlib_System_VoidP37mscorlib_System_Collections_ArrayList($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2302584);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2304136|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2304136 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2304136|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2304136|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2304136|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2304136|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2304136 + 80|0))>>2]|0;
     $17 = (($16) + 4|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = (($__this) + 12|0);
     HEAP32[$19>>2] = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_get_ItemP54mscorlib_System_Collections_ArrayList_ArrayListWrapperi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297192);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1648,(2296536|0),($1|0),($index|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_set_ItemP54mscorlib_System_Collections_ArrayList_ArrayListWrapperiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297240);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(463,(2297288|0),($1|0),($index|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z66mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_get_CountP54mscorlib_System_Collections_ArrayList_ArrayListWrapper($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297336);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(2296488|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_get_IsSynchronizedP54mscorlib_System_Collections_ArrayList_ArrayListWrapper($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297384);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2734,(2297432|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_get_SyncRootP54mscorlib_System_Collections_ArrayList_ArrayListWrapper($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297480);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2756,(2297528|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_AddP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297576);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1647,(2297624|0),($1|0),($value|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_ClearP54mscorlib_System_Collections_ArrayList_ArrayListWrapper($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297672);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vii(3495,(2297720|0),($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_ContainsP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297768);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1644,(2297816|0),($1|0),($value|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_ObjectP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297864);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1647,(2297912|0),($1|0),($value|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z131mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32P54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Objecti($__this,$value,$startIndex) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297960);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiii(319,(2298008|0),($1|0),($value|0),($startIndex|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS0_E6InvokeEP10MethodInfoPvP22mscorlib_System_Objecti($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z153mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Objectii($__this,$value,$startIndex,$count) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298056);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiiii(234,(2298104|0),($1|0),($value|0),($startIndex|0),($count|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker3I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEP10MethodInfoPvP22mscorlib_System_Objectii($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z63mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_InsertP54mscorlib_System_Collections_ArrayList_ArrayListWrapperiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298152);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(463,(2298200|0),($1|0),($index|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z68mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_InsertRangeP54mscorlib_System_Collections_ArrayList_ArrayListWrapperiP22mscorlib_System_Object($__this,$index,$c) {
 $__this = $__this|0;
 $index = $index|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298248);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(459,(2298296|0),($1|0),($index|0),($c|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z63mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_RemoveP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298344);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viii(2113,(2298392|0),($1|0),($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_RemoveAtP54mscorlib_System_Collections_ArrayList_ArrayListWrapperi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298440);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viii(2111,(2298488|0),($1|0),($index|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z106mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_ArrayP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298536);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viii(2110,(2298584|0),($1|0),($_____array|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z128mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32P54mscorlib_System_Collections_ArrayList_ArrayListWrapperP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298632);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiii(461,(2298680|0),($1|0),($_____array|0),($index|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z172mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P54mscorlib_System_Collections_ArrayList_ArrayListWrapperiP21mscorlib_System_Arrayii($__this,$index,$_____array,$arrayIndex,$count) {
 $__this = $__this|0;
 $index = $index|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298728);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viiiiii(141,(2298776|0),($1|0),($index|0),($_____array|0),($arrayIndex|0),($count|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __ZN18VirtActionInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_E6InvokeEP10MethodInfoPviS5_ii($method,$obj,$p1,$p2,$p3,$p4) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiiii[$3 & 255]($4,$p1,$p2,$p3,$p4);
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_GetEnumeratorP54mscorlib_System_Collections_ArrayList_ArrayListWrapper($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298824);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2298872|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_AddRangeP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298920);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viii(2110,(2298968|0),($1|0),($c|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z61mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_SortP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2299016);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_viii(2110,(2299064|0),($1|0),($comparer|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z95mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_ToArray_mscorlib_System_Object_arr_arrP54mscorlib_System_Collections_ArrayList_ArrayListWrapper($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2299112);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2299160|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_ToArray_mscorlib_System_Array_mscorlib_System_TypeP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP20mscorlib_System_Type($__this,$elementType) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2299208);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1645,(2299256|0),($1|0),($elementType|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS0_E6InvokeEPFiPvP22mscorlib_System_ObjectiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$3)|0);
 HEAP32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEPFiPvP22mscorlib_System_ObjectiiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN14ActionInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_E6InvokeEPFvPviS3_iiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$1,$3,$6,$9);
 STACKTOP = sp;return (0|0);
}
function __Z85mscorlib_System_Collections_ArrayList_ArrayListWrapper_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2291976)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m__ctorP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP37mscorlib_System_Collections_ArrayList($__this,$innerArrayList) {
 $__this = $__this|0;
 $innerArrayList = $innerArrayList|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300480);
 __THREW__ = 0;
 invoke_vii(1799,($__this|0),($innerArrayList|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($innerArrayList|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2756,(2297528|0),($innerArrayList|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 24|0);
    HEAP32[$7>>2] = $4;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_get_ItemP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300528);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiii(1648,(2296536|0),($5|0),($index|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 5;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 37;
    }
   }
   if ((label|0) == 5) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(37);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_set_ItemP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300576);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viiii(463,(2297288|0),($5|0),($index|0),($value|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 35;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(35);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z78mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_get_CountP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300624);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iii(2729,(2296488|0),($5|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 5;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 36;
    }
   }
   if ((label|0) == 5) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(36);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_get_IsSynchronizedP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300672);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z81mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_get_SyncRootP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300720);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z72mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_AddP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300768);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiii(1647,(2297624|0),($5|0),($value|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 5;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 37;
    }
   }
   if ((label|0) == 5) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(37);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_ClearP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300816);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_vii(3495,(2297720|0),($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 33;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(33);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_ContainsP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0$off0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300864);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiii(1644,(2297816|0),($5|0),($value|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 5;
    } else {
     $V_1$0$off0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 37;
    }
   }
   if ((label|0) == 5) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0$off0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(37);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0$off0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_ObjectP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300912);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiii(1647,(2297912|0),($5|0),($value|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 5;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 37;
    }
   }
   if ((label|0) == 5) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(37);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z143mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32P66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Objecti($__this,$value,$startIndex) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2300960);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiiii(319,(2298008|0),($5|0),($value|0),($startIndex|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 5;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 38;
    }
   }
   if ((label|0) == 5) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(38);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z165mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Objectii($__this,$value,$startIndex,$count) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301008);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiiiii(234,(2298104|0),($5|0),($value|0),($startIndex|0),($count|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 5;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 39;
    }
   }
   if ((label|0) == 5) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(39);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_InsertP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301056);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viiii(463,(2298200|0),($5|0),($index|0),($value|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 35;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(35);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z80mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_InsertRangeP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperiP22mscorlib_System_Object($__this,$index,$c) {
 $__this = $__this|0;
 $index = $index|0;
 $c = $c|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301104);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viiii(459,(2298296|0),($5|0),($index|0),($c|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 35;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(35);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z75mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_RemoveP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301152);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viii(2113,(2298392|0),($5|0),($value|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 34;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(34);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_RemoveAtP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301200);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viii(2111,(2298488|0),($5|0),($index|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 34;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(34);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z118mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_ArrayP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301248);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viii(2110,(2298584|0),($5|0),($_____array|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 34;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(34);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z140mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32P66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301296);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viiii(461,(2298680|0),($5|0),($_____array|0),($index|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 35;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(35);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z184mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperiP21mscorlib_System_Arrayii($__this,$index,$_____array,$arrayIndex,$count) {
 $__this = $__this|0;
 $index = $index|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 $count = $count|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301344);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viiiiii(141,(2298776|0),($5|0),($index|0),($_____array|0),($arrayIndex|0),($count|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 38;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(38);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z82mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_GetEnumeratorP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301392);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 6;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iii(2730,(2298872|0),($5|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 6;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 36;
    }
   }
   if ((label|0) == 6) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(36);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_AddRangeP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301440);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viii(2110,(2298968|0),($5|0),($c|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 34;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(34);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z73mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_SortP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301488);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 5;
   } else {
    __THREW__ = 0;
    invoke_viii(2110,(2299064|0),($5|0),($comparer|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 5;
    } else {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 34;
    }
   }
   if ((label|0) == 5) {
    $12 = ___cxa_find_matching_catch(348288|0)|0;
    $13 = tempRet0;
    $14 = (_llvm_eh_typeid_for((348288|0))|0);
    $15 = ($13|0)==($14|0);
    if (!($15)) {
     $$0 = $13;$$02 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$02|0);
     // unreachable;
    }
    $16 = (___cxa_begin_catch(($12|0))|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(34);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z107mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_ToArray_mscorlib_System_Object_arr_arrP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301536);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 6;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iii(2730,(2299160|0),($5|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 6;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 36;
    }
   }
   if ((label|0) == 6) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(36);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_ToArray_mscorlib_System_Array_mscorlib_System_TypeP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP20mscorlib_System_Type($__this,$elementType) {
 $__this = $__this|0;
 $elementType = $elementType|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2301584);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vii(1916,(0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 6;
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiii(1645,(2299256|0),($5|0),($elementType|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 6;
    } else {
     $V_1$0 = $8;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 37;
    }
   }
   if ((label|0) == 6) {
    $13 = ___cxa_find_matching_catch(348288|0)|0;
    $14 = tempRet0;
    $15 = (_llvm_eh_typeid_for((348288|0))|0);
    $16 = ($14|0)==($15|0);
    if (!($16)) {
     $$02 = $14;$$03 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $17 = (___cxa_begin_catch(($13|0))|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_v(66);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $V_1$0 = 0;$__last_unhandled_exception$0 = $18;$leaveInstructions$sroa$0$0 = 0;
   }
   __THREW__ = 0;
   invoke_vii(1917,(0|0),($1|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $cond1 = ($leaveInstructions$sroa$0$0|0)==(37);
    if ($cond1) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_1$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3833,($__last_unhandled_exception$0|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$02 = $12;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2291976)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Collections_ArrayList_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $$capacity = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2302632);
 __THREW__ = 0;
 invoke_v(536);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($capacity|0)>(-1);
    if (!($4)) {
     HEAP32[$L_1>>2] = $capacity;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     $9 = (invoke_iii(2724,(2155952|0),($L_1|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = HEAP32[3021848>>2]|0;
     $13 = HEAP32[3021856>>2]|0;
     __THREW__ = 0;
     invoke_viiii(151,0,($12|0),($9|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = ($capacity|0)==(0);
     $$capacity = $18 ? 4 : $capacity;
     __THREW__ = 0;
     $19 = (invoke_iii(2758,(1167664|0),($$capacity|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = (($__this) + 12|0);
      HEAP32[$22>>2] = $19;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z75mscorlib_System_Collections_ArrayList_m_ThrowNewArgumentOutOfRangeExceptionP22mscorlib_System_ObjectP22mscorlib_System_StringS0_S2_($__this,$name,$actual,$message) {
 $__this = $__this|0;
 $name = $name|0;
 $actual = $actual|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2302824);
 __THREW__ = 0;
 (invoke_ii(2996,(2561352|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2561352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viiii(176,($2|0),($name|0),($actual|0),($message|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3833,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z46mscorlib_System_Collections_ArrayList_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2302680);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2758,(1167664|0),0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2304136|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[((2304136 + 80|0))>>2]|0;
    $8 = (($7) + 4|0);
    HEAP32[$8>>2] = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z48mscorlib_System_Collections_ArrayList_m_get_ItemP37mscorlib_System_Collections_ArrayListi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2296536);
 __THREW__ = 0;
 invoke_v(537);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($index|0)<(0);
   if ($2) {
    label = 5;
   } else {
    $5 = (($__this) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)>($index|0);
    if (!($7)) {
     label = 5;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$L_2>>2] = $index;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3021672>>2]|0;
    $14 = HEAP32[3021680>>2]|0;
    __THREW__ = 0;
    invoke_viiii(151,0,($13|0),($10|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
   }
   $17 = (($__this) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    if (!($2)) {
     $21 = (($18) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22>>>0)>($index>>>0);
     if ($23) {
      $29 = HEAP32[$18>>2]|0;
      $30 = (($18) + 16|0);
      $31 = (($29) + 92|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = Math_imul($32, $index)|0;
      $34 = (($30) + ($33)|0);
      $35 = HEAP32[$34>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($35|0);
     }
    }
    __THREW__ = 0;
    $24 = (invoke_i(132)|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     invoke_vi(3302,($24|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[$18>>2]|0;
      $30 = (($18) + 16|0);
      $31 = (($29) + 92|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = Math_imul($32, $index)|0;
      $34 = (($30) + ($33)|0);
      $35 = HEAP32[$34>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($35|0);
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Collections_ArrayList_m_set_ItemP37mscorlib_System_Collections_ArrayListiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297288);
 __THREW__ = 0;
 invoke_v(538);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($index|0)<(0);
   if ($2) {
    label = 5;
   } else {
    $5 = (($__this) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)>($index|0);
    if (!($7)) {
     label = 5;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$L_2>>2] = $index;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3021824>>2]|0;
    $14 = HEAP32[3021832>>2]|0;
    __THREW__ = 0;
    invoke_viiii(151,0,($13|0),($10|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
   }
   $17 = (($__this) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    if ($2) {
     label = 11;
    } else {
     $21 = (($18) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = ($22>>>0)>($index>>>0);
     if (!($23)) {
      label = 11;
     }
    }
    if ((label|0) == 11) {
     __THREW__ = 0;
     $24 = (invoke_i(132)|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($24|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($18|0),($value|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $31 = HEAP32[$18>>2]|0;
     $32 = (($18) + 16|0);
     $33 = (($31) + 92|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = Math_imul($34, $index)|0;
     $36 = (($32) + ($35)|0);
     HEAP32[$36>>2] = $value;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      $39 = (($__this) + 16|0);
      $40 = HEAP32[$39>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       $43 = (($40) + 1)|0;
       HEAP32[$39>>2] = $43;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z49mscorlib_System_Collections_ArrayList_m_get_CountP37mscorlib_System_Collections_ArrayList($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2296488);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z58mscorlib_System_Collections_ArrayList_m_get_IsSynchronizedP37mscorlib_System_Collections_ArrayList($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297432);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z52mscorlib_System_Collections_ArrayList_m_get_SyncRootP37mscorlib_System_Collections_ArrayList($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297528);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z54mscorlib_System_Collections_ArrayList_m_EnsureCapacityP37mscorlib_System_Collections_ArrayListi($__this,$count) {
 $__this = $__this|0;
 $count = $count|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2302728);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)<($count|0);
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  $9 = HEAP32[$0>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = (($9) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 << 1;
   $15 = ($14|0)==(0);
   $$ = $15 ? 4 : $14;
   $V_0$0 = $$;
   while(1) {
    $16 = ($V_0$0|0)<($count|0);
    $17 = $V_0$0 << 1;
    if ($16) {
     $V_0$0 = $17;
    } else {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_iii(2758,(1167664|0),($V_0$0|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = (($23) + 12|0);
      $27 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      invoke_viiiiii(55,(0|0),($23|0),0,($20|0),0,($27|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       HEAP32[$0>>2] = $20;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z45mscorlib_System_Collections_ArrayList_m_ShiftP37mscorlib_System_Collections_ArrayListii($__this,$index,$count) {
 $__this = $__this|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_0$0$ph = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2302776);
 $0 = ($count|0)<(1);
 do {
  if ($0) {
   $48 = ($count|0)>(-1);
   if ($48) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $49 = (($index) - ($count))|0;
   $50 = (($__this) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = (($__this) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) - ($49))|0;
   __THREW__ = 0;
   invoke_viiiiii(55,(0|0),($51|0),($49|0),($51|0),($index|0),($54|0));
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if (!($56)) {
    $57 = HEAP32[$50>>2]|0;
    $58 = HEAP32[$52>>2]|0;
    $59 = (($58) + ($count))|0;
    $60 = (0 - ($count))|0;
    __THREW__ = 0;
    invoke_viiii(138,(0|0),($57|0),($59|0),($60|0));
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if (!($62)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  } else {
   $1 = (($__this) + 8|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = (($__this) + 12|0);
   $4 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($4|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($2) + ($count))|0;
    $8 = (($4) + 12|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($7|0)>($9|0);
    $11 = HEAP32[$3>>2]|0;
    if (!($10)) {
     $43 = (($count) + ($index))|0;
     $44 = HEAP32[$1>>2]|0;
     $45 = (($44) - ($index))|0;
     __THREW__ = 0;
     invoke_viiiiii(55,(0|0),($11|0),($index|0),($11|0),($43|0),($45|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = (($11) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)<(1);
     if ($18) {
      $V_0$0$ph = 1;
     } else {
      $19 = HEAP32[$3>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      $22 = (($19) + 12|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = $23 << 1;
      $V_0$0$ph = $24;
     }
     $25 = HEAP32[$1>>2]|0;
     $26 = (($25) + ($count))|0;
     $V_0$0 = $V_0$0$ph;
     while(1) {
      $27 = ($V_0$0|0)<($26|0);
      $28 = $V_0$0 << 1;
      if ($27) {
       $V_0$0 = $28;
      } else {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      $31 = (invoke_iii(2758,(1167664|0),($V_0$0|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       $34 = HEAP32[$3>>2]|0;
       __THREW__ = 0;
       invoke_viiiiii(55,(0|0),($34|0),0,($31|0),0,($index|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        $37 = HEAP32[$3>>2]|0;
        $38 = (($count) + ($index))|0;
        $39 = HEAP32[$1>>2]|0;
        $40 = (($39) - ($index))|0;
        __THREW__ = 0;
        invoke_viiiiii(55,(0|0),($37|0),($index|0),($31|0),($38|0),($40|0));
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if (!($42)) {
         HEAP32[$3>>2] = $31;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z43mscorlib_System_Collections_ArrayList_m_AddP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297624);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($__this) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5|0)>($7|0);
   if ($8) {
    $18 = $7;
   } else {
    $11 = (($7) + 1)|0;
    __THREW__ = 0;
    invoke_vii(1817,($__this|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $$pr = HEAP32[$6>>2]|0;
    $18 = $$pr;
   }
   $14 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($14|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = ($18|0)<(0);
    if ($17) {
     label = 9;
    } else {
     $19 = (($14) + 12|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($18>>>0)<($20>>>0);
     if (!($21)) {
      label = 9;
     }
    }
    if ((label|0) == 9) {
     __THREW__ = 0;
     $22 = (invoke_i(132)|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($22|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($14|0),($value|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = HEAP32[$14>>2]|0;
     $30 = (($14) + 16|0);
     $31 = (($29) + 92|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = Math_imul($32, $18)|0;
     $34 = (($30) + ($33)|0);
     HEAP32[$34>>2] = $value;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      $37 = (($__this) + 16|0);
      $38 = HEAP32[$37>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = (($38) + 1)|0;
       HEAP32[$37>>2] = $41;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if (!($43)) {
        $44 = HEAP32[$6>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = (($44) + 1)|0;
         HEAP32[$6>>2] = $47;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($44|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_Collections_ArrayList_m_ClearP37mscorlib_System_Collections_ArrayList($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297720);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiii(138,(0|0),($1|0),0,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  HEAP32[$2>>2] = 0;
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($__this) + 16|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($9) + 1)|0;
    HEAP32[$8>>2] = $12;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z48mscorlib_System_Collections_ArrayList_m_ContainsP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297816);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiiiii(234,(2298104|0),($__this|0),($item|0),0,($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = ($2|0)>(-1);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z92mscorlib_System_Collections_ArrayList_m_IndexOf_mscorlib_System_Int32_mscorlib_System_ObjectP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2297912);
 __THREW__ = 0;
 $0 = (invoke_iiiii(319,(2298008|0),($__this|0),($value|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z114mscorlib_System_Collections_ArrayList_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListP22mscorlib_System_Objecti($__this,$value,$startIndex) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298008);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($startIndex))|0;
 __THREW__ = 0;
 $3 = (invoke_iiiiii(234,(2298104|0),($__this|0),($value|0),($startIndex|0),($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z136mscorlib_System_Collections_ArrayList_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListP22mscorlib_System_Objectii($__this,$value,$startIndex,$count) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_2 = sp;
 $L_5 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298104);
 __THREW__ = 0;
 invoke_v(539);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($startIndex|0)<(0);
   if ($2) {
    label = 5;
   } else {
    $5 = (($__this) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<($startIndex|0);
    if ($7) {
     label = 5;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$L_2>>2] = $startIndex;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3021968>>2]|0;
    $14 = HEAP32[3021976>>2]|0;
    __THREW__ = 0;
    invoke_viiii(151,0,($13|0),($10|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
   }
   $17 = ($count|0)>(-1);
   if (!($17)) {
    HEAP32[$L_5>>2] = $count;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_iii(2724,(2155952|0),($L_5|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3021984>>2]|0;
    $24 = HEAP32[3021992>>2]|0;
    __THREW__ = 0;
    invoke_viiii(151,0,($23|0),($20|0),($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
   }
   $27 = (($__this) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (($28) - ($count))|0;
   $30 = ($29|0)<($startIndex|0);
   if (!($30)) {
    $42 = (($__this) + 12|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = HEAP32[((2869648 + 40|0))>>2]|0;
    __THREW__ = 0;
    $45 = (invoke_iiiiiii(130,(0|0),($43|0),($value|0),($startIndex|0),($count|0),($44|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($45|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    __THREW__ = 0;
    $33 = (invoke_ii(3469,(2561352|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if (!($35)) {
     $36 = HEAP32[3022000>>2]|0;
     $37 = HEAP32[3022008>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($33|0),($36|0),($37|0));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      __THREW__ = 0;
      invoke_vi(3833,($33|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Collections_ArrayList_m_InsertP37mscorlib_System_Collections_ArrayListiP22mscorlib_System_Object($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298200);
 __THREW__ = 0;
 invoke_v(540);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($index|0)<(0);
   if ($2) {
    label = 5;
   } else {
    $5 = (($__this) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)<($index|0);
    if ($7) {
     label = 5;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$L_2>>2] = $index;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3022240>>2]|0;
    $14 = HEAP32[3022248>>2]|0;
    __THREW__ = 0;
    invoke_viiii(151,0,($13|0),($10|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_viii(569,($__this|0),($index|0),1);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = (($__this) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     if ($2) {
      label = 12;
     } else {
      $23 = (($20) + 12|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24>>>0)>($index>>>0);
      if (!($25)) {
       label = 12;
      }
     }
     if ((label|0) == 12) {
      __THREW__ = 0;
      $26 = (invoke_i(132)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($26|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($20|0),($value|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $33 = HEAP32[$20>>2]|0;
      $34 = (($20) + 16|0);
      $35 = (($33) + 92|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = Math_imul($36, $index)|0;
      $38 = (($34) + ($37)|0);
      HEAP32[$38>>2] = $value;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = (($__this) + 8|0);
       $42 = HEAP32[$41>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if (!($44)) {
        $45 = (($42) + 1)|0;
        HEAP32[$41>>2] = $45;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if (!($47)) {
         $48 = (($__this) + 16|0);
         $49 = HEAP32[$48>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = (($49) + 1)|0;
          HEAP32[$48>>2] = $52;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z51mscorlib_System_Collections_ArrayList_m_InsertRangeP37mscorlib_System_Collections_ArrayListiP22mscorlib_System_Object($__this,$index,$c) {
 $__this = $__this|0;
 $index = $index|0;
 $c = $c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298296);
 __THREW__ = 0;
 invoke_v(541);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($c|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3022328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if ($15) {
    label = 11;
   } else {
    $16 = (($__this) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)<($index|0);
    if ($18) {
     label = 11;
    }
   }
   if ((label|0) == 11) {
    HEAP32[$L_3>>2] = $index;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iii(2724,(2155952|0),($L_3|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = HEAP32[3022336>>2]|0;
    $25 = HEAP32[3022344>>2]|0;
    __THREW__ = 0;
    invoke_viiii(151,0,($24|0),($21|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_vi(3799,($c|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    __THREW__ = 0;
    $30 = (invoke_iii(2736,(2231272|0),($c|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = (($__this) + 12|0);
     $34 = HEAP32[$33>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($34|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      $37 = (($34) + 12|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = (($__this) + 8|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + ($30))|0;
      $42 = ($38|0)<($41|0);
      if ($42) {
       __THREW__ = 0;
       invoke_vii(1817,($__this|0),($41|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $$pre = HEAP32[$39>>2]|0;
       $46 = $$pre;
      } else {
       $46 = $40;
      }
      $45 = ($46|0)>($index|0);
      if ($45) {
       $47 = HEAP32[$33>>2]|0;
       $48 = (($30) + ($index))|0;
       $49 = (($46) - ($index))|0;
       __THREW__ = 0;
       invoke_viiiiii(55,(0|0),($47|0),($index|0),($47|0),($48|0),($49|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vi(3799,($c|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if (!($53)) {
       __THREW__ = 0;
       $54 = (invoke_iii(2740,(2231320|0),($c|0))|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if (!($56)) {
        $57 = ($__this|0)==($54|0);
        $58 = HEAP32[$33>>2]|0;
        if ($57) {
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($58|0),0,($58|0),($index|0),($index|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break;
         }
         $61 = HEAP32[$33>>2]|0;
         $62 = (($30) + ($index))|0;
         $63 = $index << 1;
         $64 = HEAP32[$39>>2]|0;
         $65 = (($64) - ($index))|0;
         __THREW__ = 0;
         invoke_viiiiii(55,(0|0),($61|0),($62|0),($61|0),($63|0),($65|0));
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          break;
         }
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($c|0));
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          break;
         }
         __THREW__ = 0;
         invoke_viiii(464,(2231392|0),($c|0),($58|0),($index|0));
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if (!($73)) {
         $74 = HEAP32[$39>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($c|0));
         $75 = __THREW__; __THREW__ = 0;
         $76 = $75&1;
         if (!($76)) {
          __THREW__ = 0;
          $77 = (invoke_iii(2736,(2231272|0),($c|0))|0);
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if (!($79)) {
           __THREW__ = 0;
           invoke_vi(3799,($__this|0));
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            $82 = (($77) + ($74))|0;
            HEAP32[$39>>2] = $82;
            __THREW__ = 0;
            invoke_vi(3799,($__this|0));
            $83 = __THREW__; __THREW__ = 0;
            $84 = $83&1;
            if (!($84)) {
             $85 = (($__this) + 16|0);
             $86 = HEAP32[$85>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $87 = __THREW__; __THREW__ = 0;
             $88 = $87&1;
             if (!($88)) {
              $89 = (($86) + 1)|0;
              HEAP32[$85>>2] = $89;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z46mscorlib_System_Collections_ArrayList_m_RemoveP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298392);
 __THREW__ = 0;
 $0 = (invoke_iiii(1647,(2297912|0),($__this|0),($obj|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($0|0)<(0);
   if (!($3)) {
    __THREW__ = 0;
    invoke_viii(2111,(2298488|0),($__this|0),($0|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($__this) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = (($11) + 1)|0;
     HEAP32[$10>>2] = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z48mscorlib_System_Collections_ArrayList_m_RemoveAtP37mscorlib_System_Collections_ArrayListi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298488);
 __THREW__ = 0;
 invoke_v(542);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($index|0)<(0);
   if ($2) {
    label = 5;
   } else {
    $5 = (($__this) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)>($index|0);
    if (!($7)) {
     label = 5;
    }
   }
   if ((label|0) == 5) {
    HEAP32[$L_2>>2] = $index;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3022368>>2]|0;
    $14 = HEAP32[3022376>>2]|0;
    __THREW__ = 0;
    invoke_viiii(151,0,($13|0),($10|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_viii(569,($__this|0),($index|0),-1);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = (($__this) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $25 = (($22) + -1)|0;
      HEAP32[$21>>2] = $25;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       $28 = (($__this) + 16|0);
       $29 = HEAP32[$28>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        $32 = (($29) + 1)|0;
        HEAP32[$28>>2] = $32;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z89mscorlib_System_Collections_ArrayList_m_CopyTo_mscorlib_System_Void_mscorlib_System_ArrayP37mscorlib_System_Collections_ArrayListP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298584);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiii(140,(0|0),($1|0),($_____array|0),($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z111mscorlib_System_Collections_ArrayList_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298680);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_viiiiii(141,(2298776|0),($__this|0),0,($_____array|0),($arrayIndex|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z155mscorlib_System_Collections_ArrayList_m_CopyTo_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListiP21mscorlib_System_Arrayii($__this,$index,$_____array,$arrayIndex,$count) {
 $__this = $__this|0;
 $index = $index|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298776);
 __THREW__ = 0;
 invoke_v(543);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3022464>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1859,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(1);
     if ($20) {
      $32 = (($__this) + 12|0);
      $33 = HEAP32[$32>>2]|0;
      __THREW__ = 0;
      invoke_viiiiii(55,(0|0),($33|0),($index|0),($_____array|0),($arrayIndex|0),($count|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(2560072|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = HEAP32[3022472>>2]|0;
       $27 = HEAP32[3022480>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($23|0),($26|0),($27|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3833,($23|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z53mscorlib_System_Collections_ArrayList_m_GetEnumeratorP37mscorlib_System_Collections_ArrayList($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298872);
 __THREW__ = 0;
 (invoke_ii(2996,(2297008|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2297008|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1798,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Collections_ArrayList_m_AddRangeP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2298968);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_viiii(459,(2298296|0),($__this|0),($1|0),($c|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44mscorlib_System_Collections_ArrayList_m_SortP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object($__this,$comparer) {
 $__this = $__this|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2299064);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_viiiii(50,(0|0),($1|0),0,($3|0),($comparer|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z78mscorlib_System_Collections_ArrayList_m_ToArray_mscorlib_System_Object_arr_arrP37mscorlib_System_Collections_ArrayList($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2299160);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2758,(1167664|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_viii(2110,(2298584|0),($__this|0),($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Collections_ArrayList_m_ToArray_mscorlib_System_Array_mscorlib_System_TypeP37mscorlib_System_Collections_ArrayListP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2299256);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiii(688,(0|0),($type|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viii(2110,(2298584|0),($__this|0),($2|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($2|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Collections_ArrayList_m_SynchronizedP22mscorlib_System_ObjectP37mscorlib_System_Collections_ArrayList($__this,$list) {
 $__this = $__this|0;
 $list = $list|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2302872);
 __THREW__ = 0;
 invoke_v(544);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($list|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3022552>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($list|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(2734,(2297432|0),($list|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     if ($17) {
      $$0 = $list;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2302448|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_ii(3469,(2302448|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_vii(1810,($22|0),($list|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        $$0 = $22;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_E6InvokeEPFvPvS3_P22mscorlib_System_ObjectS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$4);
 STACKTOP = sp;return (0|0);
}
function __Z68mscorlib_System_Collections_ArrayList_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2290720)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2319176)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2305960)|0);
 $8 = HEAP32[((2305960 + 48|0))>>2]|0;
 $9 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($8)|0);
 __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($7,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $7;
 $12 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $13 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2291976)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($12,$13);
 $14 = HEAP32[$3>>2]|0;
 $15 = (($14) + 8|0);
 HEAP32[$15>>2] = $12;
 $16 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($16,1);
 $17 = HEAP32[$3>>2]|0;
 $18 = (($17) + 12|0);
 HEAP32[$18>>2] = $16;
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Collections_CaseInsensitiveComparer_m__ctor_mscorlib_System_VoidP51mscorlib_System_Collections_CaseInsensitiveComparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2304272);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1982,0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $2;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z104mscorlib_System_Collections_CaseInsensitiveComparer_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP51mscorlib_System_Collections_CaseInsensitiveComparerb($__this,$invariant) {
 $__this = $__this|0;
 $invariant = $invariant|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2304320);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z60mscorlib_System_Collections_CaseInsensitiveComparer_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2304368);
 __THREW__ = 0;
 (invoke_ii(2996,(2304904|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2304904|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2156,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2304904|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2304904 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __THREW__ = 0;
     (invoke_ii(2996,(2304904|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_ii(3469,(2304904|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vii(1818,($12|0),0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2304904|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         $19 = HEAP32[((2304904 + 80|0))>>2]|0;
         $20 = (($19) + 4|0);
         HEAP32[$20>>2] = $12;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z61mscorlib_System_Collections_CaseInsensitiveComparer_m_CompareP51mscorlib_System_Collections_CaseInsensitiveComparerP22mscorlib_System_ObjectS2_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2304416);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($a|0),(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(2735,($b|0),(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = ($2|0)==(0|0);
      $11 = ($7|0)==(0|0);
      $or$cond = $10 | $11;
      if ($or$cond) {
       __THREW__ = 0;
       (invoke_ii(2996,(2306688|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       $42 = HEAP8[((2306688 + 116|0))>>0]|0;
       $43 = ($42<<24>>24)==(0);
       if ($43) {
        __THREW__ = 0;
        (invoke_ii(2996,(2306688|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2306688|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3832,(2306688|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2306688|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       $52 = HEAP32[((2306688 + 80|0))>>2]|0;
       $53 = HEAP32[$52>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($53|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       }
       __THREW__ = 0;
       $56 = (invoke_iiiii(320,(2304560|0),($53|0),($a|0),($b|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        break;
       } else {
        $$0 = $56;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $14 = (($__this) + 8|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = ($15|0)==(0|0);
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3799,($15|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       $19 = (invoke_iii(2730,(2304464|0),($15|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($19|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       __THREW__ = 0;
       $24 = (invoke_iiiiii(231,(2304512|0),($19|0),($2|0),($7|0),1)|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       } else {
        $$0 = $24;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      $27 = (invoke_ii(1982,0)|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vi(3799,($27|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        __THREW__ = 0;
        $32 = (invoke_iii(2730,(2304464|0),($27|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         __THREW__ = 0;
         invoke_vi(3799,($32|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          __THREW__ = 0;
          $37 = (invoke_iiiiii(231,(2304512|0),($32|0),($2|0),($7|0),1)|0);
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if (!($39)) {
           $$0 = $37;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z82mscorlib_System_Collections_CaseInsensitiveComparer_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m__ctor_mscorlib_System_VoidP59mscorlib_System_Collections_CaseInsensitiveHashCodeProvider($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2305040);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1982,0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(1982,0)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(792,0,($2|0),($5|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     if ($8) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     $13 = (invoke_ii(1982,0)|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3799,($13|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_iii(2730,(2273600|0),($13|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $21 = (($__this) + 8|0);
        HEAP32[$21>>2] = $18;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z178mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m_AreEqual_mscorlib_System_Boolean_mscorlib_System_Globalization_CultureInfo_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_ObjectP41mscorlib_System_Globalization_CultureInfoS2_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2305184);
 __THREW__ = 0;
 invoke_vi(3799,($a|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2730,(2273792|0),($a|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($b|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2730,(2273792|0),($b|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(574,(0|0),($2|0),($7|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($10|0);
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z130mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m__ctor_mscorlib_System_Void_mscorlib_System_Globalization_CultureInfoP59mscorlib_System_Collections_CaseInsensitiveHashCodeProviderP41mscorlib_System_Globalization_CultureInfo($__this,$culture) {
 $__this = $__this|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2305088);
 __THREW__ = 0;
 invoke_v(545);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($culture|0)==(0|0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560584|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2560584|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = HEAP32[3022728>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($9|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(1982,0)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iiii(792,0,($culture|0),($17|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      if ($20) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3799,($culture|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       $25 = (invoke_iii(2730,(2273600|0),($culture|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        $28 = (($__this) + 8|0);
        HEAP32[$28>>2] = $25;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z68mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2305136);
 __THREW__ = 0;
 $0 = (invoke_ii(1982,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2305768|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2305768|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1819,($5|0),($0|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2305768|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[((2305768 + 80|0))>>2]|0;
      HEAP32[$12>>2] = $5;
      __THREW__ = 0;
      (invoke_ii(2996,(2149728|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       $15 = (invoke_ii(3469,(2149728|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        invoke_vi(1924,($15|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2305768|0))|0);
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if (!($21)) {
          $22 = HEAP32[((2305768 + 80|0))>>2]|0;
          $23 = (($22) + 4|0);
          HEAP32[$23>>2] = $15;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($24|0);
 // unreachable;
}
function __Z175mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m_AreEqual_mscorlib_System_Boolean_mscorlib_System_Globalization_TextInfo_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_ObjectP38mscorlib_System_Globalization_TextInfoP41mscorlib_System_Globalization_CultureInfo($__this,$info,$culture) {
 $__this = $__this|0;
 $info = $info|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2305232);
 __THREW__ = 0;
 invoke_vi(3799,($info|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(2045,($info|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($culture|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2730,(2273792|0),($culture|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(574,(0|0),($2|0),($7|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($10|0);
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Globalization_TextInfo_m_get_CultureNameP38mscorlib_System_Globalization_TextInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2350312);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $10 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 $3 = (($__this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  $7 = (invoke_iii(2730,(2273792|0),($4|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   HEAP32[$0>>2] = $7;
   $10 = $7;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($10|0);
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m_GetHashCodeP59mscorlib_System_Collections_CaseInsensitiveHashCodeProviderP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_3$0 = 0, $V_4$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2305280);
 __THREW__ = 0;
 invoke_v(546);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($obj|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3022744>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iii(2735,($obj|0),(2191608|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = ($21|0)==(0|0);
     if ($24) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_iii(2729,(2148880|0),($obj|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      } else {
       $$0 = $27;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $30 = (($__this) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     $32 = ($31|0)==(0|0);
     if (!($32)) {
      __THREW__ = 0;
      $33 = (invoke_ii(1982,0)|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iiii(793,0,($31|0),($33|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      if (!($36)) {
       $39 = HEAP32[$30>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($39|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       __THREW__ = 0;
       $42 = (invoke_iiii(1645,(2305328|0),($39|0),($21|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $V_1$0 = 0;$V_3$0 = 0;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($42|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_ii(1816,($42|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
        $57 = ($V_3$0|0)<($54|0);
        if (!($57)) {
         $$0 = $V_1$0;
         label = 39;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($42|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
        __THREW__ = 0;
        $45 = (invoke_iii(621,($42|0),($V_3$0|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
        $48 = ($V_1$0*31)|0;
        $49 = $45&65535;
        $50 = (($49) + ($48))|0;
        $51 = (($V_3$0) + 1)|0;
        $V_1$0 = $50;$V_3$0 = $51;
       }
       if ((label|0) == 39) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $5 = ___cxa_find_matching_catch()|0;
       $6 = tempRet0;
       $lpad$phi$index = $5;$lpad$phi$index3 = $6;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     }
     $V_1$1 = 0;$V_4$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($21|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       break;
      }
      __THREW__ = 0;
      $75 = (invoke_ii(1816,($21|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break;
      }
      $78 = ($V_4$0|0)<($75|0);
      if (!($78)) {
       $$0 = $V_1$1;
       label = 39;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($21|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       break;
      }
      __THREW__ = 0;
      $60 = (invoke_iii(621,($21|0),($V_4$0|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_ii(1982,0)|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      __THREW__ = 0;
      $66 = (invoke_iiii(518,(0|0),($60|0),($63|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      $69 = ($V_1$1*31)|0;
      $70 = $66&65535;
      $71 = (($70) + ($69))|0;
      $72 = (($V_4$0) + 1)|0;
      $V_1$1 = $71;$V_4$0 = $72;
     }
     if ((label|0) == 39) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $3 = ___cxa_find_matching_catch()|0;
     $4 = tempRet0;
     $lpad$phi$index = $3;$lpad$phi$index3 = $4;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2305584)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z65mscorlib_System_Collections_Comparer_m__ctor_mscorlib_System_VoidP36mscorlib_System_Collections_Comparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2306096);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z107mscorlib_System_Collections_Comparer_m__ctor_mscorlib_System_Void_mscorlib_System_Globalization_CultureInfoP36mscorlib_System_Collections_ComparerP41mscorlib_System_Globalization_CultureInfo($__this,$culture) {
 $__this = $__this|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2306144);
 __THREW__ = 0;
 invoke_v(547);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($culture|0)==(0|0);
    if (!($4)) {
     __THREW__ = 0;
     invoke_vi(3799,($culture|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_iii(2730,(2304464|0),($culture|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = (($__this) + 8|0);
     HEAP32[$22>>2] = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2560584|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[3022768>>2]|0;
      __THREW__ = 0;
      invoke_vii(1925,($9|0),($12|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3833,($9|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z45mscorlib_System_Collections_Comparer_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2306192);
 __THREW__ = 0;
 (invoke_ii(2996,(2306688|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2306688|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2162,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2306688|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2306688 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __THREW__ = 0;
     $10 = (invoke_ii(1982,0)|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2306688|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       $15 = (invoke_ii(3469,(2306688|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        invoke_vii(1820,($15|0),($10|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2306688|0))|0);
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if (!($21)) {
          $22 = HEAP32[((2306688 + 80|0))>>2]|0;
          $23 = (($22) + 4|0);
          HEAP32[$23>>2] = $15;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($24|0);
 // unreachable;
}
function __Z46mscorlib_System_Collections_Comparer_m_CompareP36mscorlib_System_Collections_ComparerP22mscorlib_System_ObjectS2_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2304560);
 __THREW__ = 0;
 invoke_v(548);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($a|0)==($b|0);
   if ($2) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $5 = ($a|0)==(0|0);
   if ($5) {
    $$0 = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $6 = ($b|0)==(0|0);
   if ($6) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $7 = (($__this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_iii(2735,($a|0),(2191608|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_iii(2735,($b|0),(2191608|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = ($12|0)==(0|0);
    $21 = ($17|0)==(0|0);
    $or$cond = $20 | $21;
    if (!($or$cond)) {
     $22 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($22|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_iiiii(321,(2306240|0),($22|0),($12|0),($17|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     } else {
      $$0 = $25;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2157896|0))|0);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    __THREW__ = 0;
    $30 = (invoke_iii(2735,($a|0),(2157896|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = ($30|0)==(0|0);
     if (!($33)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2157896|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2735,($a|0),(2157896|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($36|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      __THREW__ = 0;
      $41 = (invoke_iiii(1649,(2157808|0),($36|0),($b|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      } else {
       $$0 = $41;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2157896|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      __THREW__ = 0;
      $46 = (invoke_iii(2735,($b|0),(2157896|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if (!($48)) {
       $49 = ($46|0)==(0|0);
       if ($49) {
        $61 = HEAP32[3022784>>2]|0;
        __THREW__ = 0;
        $62 = (invoke_iii(783,(0|0),($61|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         break;
        }
        __THREW__ = 0;
        $67 = (invoke_ii(3469,(2560072|0))|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(1924,($67|0),($62|0));
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3833,($67|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         break;
        }
        // unreachable;
       } else {
        __THREW__ = 0;
        (invoke_ii(2996,(2157896|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        __THREW__ = 0;
        $52 = (invoke_iii(2735,($b|0),(2157896|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($52|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
        __THREW__ = 0;
        $57 = (invoke_iiii(1649,(2157808|0),($52|0),($a|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
        $60 = (0 - ($57))|0;
        $$0 = $60;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z52mscorlib_System_Collections_Comparer_m_GetObjectDataP36mscorlib_System_Collections_ComparerP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2306288);
 __THREW__ = 0;
 invoke_v(549);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($info|0)==(0|0);
   if (!($3)) {
    $16 = (($__this) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    HEAP32[$0>>2] = 2387432;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $18 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3022896>>2]|0;
    __THREW__ = 0;
    invoke_viiii(168,($info|0),($23|0),($17|0),($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[3022888>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($8|0),($11|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3833,($8|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z67mscorlib_System_Collections_Comparer_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z51mscorlib_System_Collections_DictionaryEntry_m__ctorP43mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2306824);
 HEAP32[$__this>>2] = $key;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_Collections_DictionaryEntry_m_get_KeyP43mscorlib_System_Collections_DictionaryEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2306872);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z55mscorlib_System_Collections_DictionaryEntry_m_get_ValueP43mscorlib_System_Collections_DictionaryEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2306920);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Collections_DictionaryEntry_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2307080)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($6,$7);
 $8 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2307096)|0);
 __Z63mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_set_NameP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_Collections_Hashtable_KeyMarker_m__ctorP47mscorlib_System_Collections_Hashtable_KeyMarker($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2307600);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56mscorlib_System_Collections_Hashtable_KeyMarker_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2307648);
 __THREW__ = 0;
 (invoke_ii(2996,(2307792|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2307792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2166,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2307792|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2307792 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z56mscorlib_System_Collections_Hashtable_Enumerator_m__ctorP48mscorlib_System_Collections_Hashtable_EnumeratorP37mscorlib_System_Collections_Hashtablei($__this,$host,$mode) {
 $__this = $__this|0;
 $host = $host|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2308400);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $host;
  __THREW__ = 0;
  invoke_vi(3799,($host|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($host) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($__this) + 12|0);
   HEAP32[$7>>2] = $6;
   __THREW__ = 0;
   invoke_vi(3799,($host|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($host) + 20|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = (($11) + 12|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($__this) + 20|0);
     HEAP32[$16>>2] = $15;
     $17 = (($__this) + 24|0);
     HEAP32[$17>>2] = $mode;
     __THREW__ = 0;
     invoke_vii(3495,(2308448|0),($__this|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
}
function __Z57mscorlib_System_Collections_Hashtable_Enumerator_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2308496);
 __THREW__ = 0;
 invoke_v(550);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3023944>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2309240|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[((2309240 + 80|0))>>2]|0;
   HEAP32[$5>>2] = $2;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z59mscorlib_System_Collections_Hashtable_Enumerator_m_FailFastP48mscorlib_System_Collections_Hashtable_Enumerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2308544);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($__this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5|0)==($7|0);
   if ($8) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2309240|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = HEAP8[((2309240 + 116|0))>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     __THREW__ = 0;
     (invoke_ii(2996,(2309240|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2309240|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2309240|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2309240|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[((2309240 + 80|0))>>2]|0;
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2607872|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      $27 = (invoke_ii(3469,(2607872|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vii(1947,($27|0),($24|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        __THREW__ = 0;
        invoke_vi(3833,($27|0));
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z56mscorlib_System_Collections_Hashtable_Enumerator_m_ResetP48mscorlib_System_Collections_Hashtable_Enumerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2308448);
 __THREW__ = 0;
 invoke_vi(2170,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($__this) + 16|0);
  HEAP32[$2>>2] = -1;
  $3 = (($__this) + 28|0);
  HEAP32[$3>>2] = 0;
  $4 = (($__this) + 32|0);
  HEAP32[$4>>2] = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z59mscorlib_System_Collections_Hashtable_Enumerator_m_MoveNextP48mscorlib_System_Collections_Hashtable_Enumerator($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2308592);
 __THREW__ = 0;
 invoke_vi(2170,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $2 = (($__this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)<($5|0);
 L5: do {
  if ($6) {
   $7 = (($__this) + 8|0);
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 4;
     break;
    }
    $56 = HEAP32[$2>>2]|0;
    $57 = (($56) + 1)|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 4;
     break;
    }
    HEAP32[$2>>2] = $57;
    $60 = HEAP32[$4>>2]|0;
    $61 = ($57|0)<($60|0);
    if (!($61)) {
     break L5;
    }
    $13 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($13|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 4;
     break;
    }
    $12 = (($13) + 20|0);
    $14 = HEAP32[$12>>2]|0;
    $15 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($14|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 4;
     break;
    }
    $18 = ($15|0)<(0);
    if ($18) {
     label = 10;
    } else {
     $19 = (($14) + 12|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($15>>>0)<($20>>>0);
     if (!($21)) {
      label = 10;
     }
    }
    if ((label|0) == 10) {
     label = 0;
     __THREW__ = 0;
     $22 = (invoke_i(132)|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($22|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 4;
      break;
     }
    }
    $27 = HEAP32[$14>>2]|0;
    $28 = (($14) + 16|0);
    $29 = (($27) + 92|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = Math_imul($30, $15)|0;
    $32 = (($28) + ($31)|0);
    $33 = HEAP32[$32>>2]|0;
    $$sum = (($31) + 4)|0;
    $34 = (($28) + ($$sum)|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($33|0)==(0|0);
    if ($36) {
     continue;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2307792|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 4;
     break;
    }
    $39 = HEAP8[((2307792 + 116|0))>>0]|0;
    $40 = ($39<<24>>24)==(0);
    if ($40) {
     __THREW__ = 0;
     (invoke_ii(2996,(2307792|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2307792|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2307792|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      label = 4;
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2307792|0))|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 4;
     break;
    }
    $49 = HEAP32[((2307792 + 80|0))>>2]|0;
    $50 = HEAP32[$49>>2]|0;
    $51 = ($33|0)==($50|0);
    if (!($51)) {
     label = 20;
     break;
    }
   }
   if ((label|0) == 4) {
    $8 = ___cxa_find_matching_catch()|0;
    $9 = tempRet0;
    $lpad$phi$index = $8;$lpad$phi$index2 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 20) {
    $52 = (($__this) + 28|0);
    HEAP32[$52>>2] = $33;
    $53 = (($__this) + 32|0);
    HEAP32[$53>>2] = $35;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $64 = (($__this) + 28|0);
 HEAP32[$64>>2] = 0;
 $65 = (($__this) + 32|0);
 HEAP32[$65>>2] = 0;
 $$0 = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z60mscorlib_System_Collections_Hashtable_Enumerator_m_get_EntryP48mscorlib_System_Collections_Hashtable_Enumerator($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2308640);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607872|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2607872|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2734,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3833,($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  invoke_vi(2170,($__this|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $16 = HEAP32[$0>>2]|0;
   $17 = (($__this) + 32|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = $agg$result;
   $20 = $19;
   HEAP32[$20>>2] = 0;
   $21 = (($19) + 4)|0;
   $22 = $21;
   HEAP32[$22>>2] = 0;
   __THREW__ = 0;
   invoke_viii(571,($agg$result|0),($16|0),($18|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z62mscorlib_System_Collections_Hashtable_Enumerator_m_get_CurrentP48mscorlib_System_Collections_Hashtable_Enumerator($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_7 = 0, $L_8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_7 = sp;
 $L_8 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2308688);
 __THREW__ = 0;
 invoke_v(551);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 28|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2607872|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2734,($9|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($9|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = (($__this) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   if ((($17|0) == 1)) {
    $18 = (($__this) + 32|0);
    $19 = HEAP32[$18>>2]|0;
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else if ((($17|0) == 0)) {
    $$0 = $3;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else if ((($17|0) == 2)) {
    $20 = (($__this) + 32|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = $L_7;
    $23 = $22;
    HEAP32[$23>>2] = 0;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP32[$25>>2] = 0;
    __THREW__ = 0;
    invoke_viii(571,($L_7|0),($3|0),($21|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = $L_7;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 4)|0;
    $32 = $31;
    $33 = HEAP32[$32>>2]|0;
    $34 = $L_8;
    $35 = $34;
    HEAP32[$35>>2] = $30;
    $36 = (($34) + 4)|0;
    $37 = $36;
    HEAP32[$37>>2] = $33;
    __THREW__ = 0;
    (invoke_ii(2996,(2307216|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_iii(2724,(2307216|0),($L_8|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $$0 = $40;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    __THREW__ = 0;
    (invoke_ii(2996,(2246120|0))|0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    $45 = (invoke_ii(3469,(2246120|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    $48 = HEAP32[3023888>>2]|0;
    __THREW__ = 0;
    invoke_vii(1781,($45|0),($48|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($45|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    // unreachable;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Collections_Hashtable_HashKeys_m_get_CountP46mscorlib_System_Collections_Hashtable_HashKeys($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2309376);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(2309424|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Collections_Hashtable_HashKeys_m_get_SyncRootP46mscorlib_System_Collections_Hashtable_HashKeys($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2309472);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2756,(2309520|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Collections_Hashtable_HashKeys_m_CopyToP46mscorlib_System_Collections_Hashtable_HashKeysP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2309568);
 __THREW__ = 0;
 invoke_v(552);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3024048>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1859,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(1);
     if (!($20)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(2560072|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = HEAP32[3024056>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($23|0),($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($23|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     }
     $31 = ($arrayIndex|0)>(-1);
     if (!($31)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2561352|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2561352|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = HEAP32[3024064>>2]|0;
      __THREW__ = 0;
      invoke_vii(1926,($34|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($34|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      $44 = (invoke_ii(1857,($_____array|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       __THREW__ = 0;
       $47 = (invoke_iii(2729,(2309376|0),($__this|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        $50 = (($44) - ($arrayIndex))|0;
        $51 = ($50|0)<($47|0);
        if (!($51)) {
         $62 = (($__this) + 8|0);
         $63 = HEAP32[$62>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($63|0));
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
         __THREW__ = 0;
         invoke_viiii(153,($63|0),($_____array|0),($arrayIndex|0),0);
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          break;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if (!($53)) {
         __THREW__ = 0;
         $54 = (invoke_ii(3469,(2560072|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          $57 = HEAP32[3024072>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($54|0),($57|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           __THREW__ = 0;
           invoke_vi(3833,($54|0));
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if (!($61)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z51mscorlib_System_Collections_Hashtable_m_CopyToArrayP37mscorlib_System_Collections_HashtableP21mscorlib_System_Arrayii($__this,$arr,$i,$mode) {
 $__this = $__this|0;
 $arr = $arr|0;
 $i = $i|0;
 $mode = $mode|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311856);
 __THREW__ = 0;
 (invoke_ii(2996,(2309240|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2309240|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viii(572,($2|0),($__this|0),($mode|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $$0 = $i;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     $21 = (invoke_iii(2741,(2176240|0),($2|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     if (!($21)) {
      label = 15;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2740,(2176176|0),($2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($arr|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = (($$0) + 1)|0;
     __THREW__ = 0;
     invoke_viii(534,($arr|0),($11|0),($$0|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     } else {
      $$0 = $16;
     }
    }
    if ((label|0) == 15) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $7 = ___cxa_find_matching_catch()|0;
    $8 = tempRet0;
    $lpad$phi$index = $7;$lpad$phi$index2 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z77mscorlib_System_Collections_Hashtable_HashKeys_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2290720)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2319176)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2305960)|0);
 $8 = HEAP32[((2305960 + 48|0))>>2]|0;
 $9 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($8)|0);
 __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($7,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $7;
 STACKTOP = sp;return;
}
function __Z60mscorlib_System_Collections_Hashtable_HashValues_m_get_CountP48mscorlib_System_Collections_Hashtable_HashValues($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2309968);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(2309424|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Collections_Hashtable_HashValues_m_get_SyncRootP48mscorlib_System_Collections_Hashtable_HashValues($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310016);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2756,(2309520|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_Collections_Hashtable_HashValues_m_CopyToP48mscorlib_System_Collections_Hashtable_HashValuesP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310064);
 __THREW__ = 0;
 invoke_v(553);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3024120>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1859,($_____array|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(1);
     if (!($20)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(2560072|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = HEAP32[3024128>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($23|0),($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($23|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     }
     $31 = ($arrayIndex|0)>(-1);
     if (!($31)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2561352|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2561352|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = HEAP32[3024136>>2]|0;
      __THREW__ = 0;
      invoke_vii(1926,($34|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($34|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      __THREW__ = 0;
      $44 = (invoke_ii(1857,($_____array|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       __THREW__ = 0;
       $47 = (invoke_iii(2729,(2309968|0),($__this|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        $50 = (($44) - ($arrayIndex))|0;
        $51 = ($50|0)<($47|0);
        if (!($51)) {
         $62 = (($__this) + 8|0);
         $63 = HEAP32[$62>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($63|0));
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
         __THREW__ = 0;
         invoke_viiii(153,($63|0),($_____array|0),($arrayIndex|0),1);
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          break;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if (!($53)) {
         __THREW__ = 0;
         $54 = (invoke_ii(3469,(2560072|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          $57 = HEAP32[3024144>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($54|0),($57|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if (!($59)) {
           __THREW__ = 0;
           invoke_vi(3833,($54|0));
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if (!($61)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z79mscorlib_System_Collections_Hashtable_HashValues_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2290720)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2319176)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2305960)|0);
 $8 = HEAP32[((2305960 + 48|0))>>2]|0;
 $9 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($8)|0);
 __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($7,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $7;
 STACKTOP = sp;return;
}
function __Z66mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_VoidP37mscorlib_System_Collections_Hashtable($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310464);
 __THREW__ = 0;
 invoke_viif(19,($__this|0),0,1.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z111mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_SingleP37mscorlib_System_Collections_Hashtableif($__this,$capacity,$loadFactor) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $loadFactor = Math_fround($loadFactor);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310560);
 __THREW__ = 0;
 invoke_viifii(2,($__this|0),($capacity|0),(+$loadFactor),(0|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z195mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Single_mscorlib_System_Collections_IHashCodeProvider_mscorlib_System_Collections_IComparerP37mscorlib_System_Collections_HashtableifP22mscorlib_System_ObjectS2_($__this,$capacity,$loadFactor,$hcp,$comparer) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 $loadFactor = Math_fround($loadFactor);
 $hcp = $hcp|0;
 $comparer = $comparer|0;
 var $$capacity = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310512);
 __THREW__ = 0;
 invoke_v(554);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($capacity|0)>(-1);
    if (!($4)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2561352|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = HEAP32[3022976>>2]|0;
     $13 = HEAP32[3022984>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($9|0),($12|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($9|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    $18 = $loadFactor < Math_fround(0.100000001490116119385);
    $19 = $loadFactor > Math_fround(1.0);
    $or$cond = $18 | $19;
    if (!($or$cond)) {
     __THREW__ = 0;
     $20 = (invoke_iif(9,(0|0),(+$loadFactor))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     if (!($20)) {
      $34 = ($capacity|0)==(0);
      $35 = $34&1;
      $$capacity = (($35) + ($capacity))|0;
      $36 = Math_fround($loadFactor * Math_fround(0.75));
      $37 = (($__this) + 16|0);
      HEAPF32[$37>>2] = $36;
      $38 = (Math_fround(($$capacity|0)));
      $39 = Math_fround($38 / $36);
      $40 = +$39;
      $41 = !($40 <= 2147483647.0);
      if ($41) {
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break;
       }
       __THREW__ = 0;
       $44 = (invoke_ii(3469,(2560072|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       $47 = HEAP32[3023008>>2]|0;
       __THREW__ = 0;
       invoke_vii(1924,($44|0),($47|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3833,($44|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       // unreachable;
      }
      $52 = (~~(($39)));
      __THREW__ = 0;
      $53 = (invoke_iii(835,0,($52|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1229880|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2758,(1229880|0),($53|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1170368|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2758,(1170368|0),($53|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(580,($__this|0),($58|0),($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1824,($__this|0),($hcp|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1823,($__this|0),($comparer|0));
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       break;
      }
      $72 = (($__this) + 8|0);
      HEAP32[$72>>2] = 0;
      $73 = (($__this) + 12|0);
      HEAP32[$73>>2] = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2561352|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = HEAP32[3022992>>2]|0;
      $29 = HEAP32[3023000>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($25|0),($28|0),($29|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       __THREW__ = 0;
       invoke_vi(3833,($25|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z47mscorlib_System_Collections_Hashtable_m_ToPrimeP22mscorlib_System_Objecti($__this,$x) {
 $__this = $__this|0;
 $x = $x|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2312000);
 $V_0$0 = 0;
 while(1) {
  __THREW__ = 0;
  (invoke_ii(2996,(2313960|0))|0);
  $68 = __THREW__; __THREW__ = 0;
  $69 = $68&1;
  if ($69) {
   label = 6;
   break;
  }
  $70 = HEAP8[((2313960 + 116|0))>>0]|0;
  $71 = ($70<<24>>24)==(0);
  if ($71) {
   __THREW__ = 0;
   (invoke_ii(2996,(2313960|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2313960|0))|0);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3832,(2313960|0));
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 6;
    break;
   }
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2313960|0))|0);
  $78 = __THREW__; __THREW__ = 0;
  $79 = $78&1;
  if ($79) {
   label = 6;
   break;
  }
  $80 = HEAP32[((2313960 + 80|0))>>2]|0;
  $81 = (($80) + 4|0);
  $82 = HEAP32[$81>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($82|0));
  $83 = __THREW__; __THREW__ = 0;
  $84 = $83&1;
  if ($84) {
   label = 6;
   break;
  }
  $85 = (($82) + 12|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = ($V_0$0|0)<($86|0);
  if (!($87)) {
   label = 35;
   break;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2313960|0))|0);
  $88 = __THREW__; __THREW__ = 0;
  $89 = $88&1;
  if ($89) {
   label = 6;
   break;
  }
  $0 = HEAP8[((2313960 + 116|0))>>0]|0;
  $1 = ($0<<24>>24)==(0);
  if ($1) {
   __THREW__ = 0;
   (invoke_ii(2996,(2313960|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if ($3) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2313960|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3832,(2313960|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if ($7) {
    label = 6;
    break;
   }
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2313960|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   label = 6;
   break;
  }
  $14 = HEAP32[((2313960 + 80|0))>>2]|0;
  $15 = (($14) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if ($18) {
   label = 6;
   break;
  }
  $19 = (($16) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($V_0$0>>>0)<($20>>>0);
  if (!($21)) {
   __THREW__ = 0;
   $22 = (invoke_i(132)|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($22|0));
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 6;
    break;
   }
  }
  $27 = HEAP32[$16>>2]|0;
  $28 = (($16) + 16|0);
  $29 = (($27) + 92|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = Math_imul($30, $V_0$0)|0;
  $32 = (($28) + ($31)|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ($33|0)<($x|0);
  $35 = (($V_0$0) + 1)|0;
  if ($34) {
   $V_0$0 = $35;
  } else {
   label = 15;
   break;
  }
 }
 do {
  if ((label|0) == 6) {
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   $lpad$phi$index = $8;$lpad$phi$index2 = $9;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  else if ((label|0) == 15) {
   __THREW__ = 0;
   (invoke_ii(2996,(2313960|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if (!($37)) {
    $38 = HEAP8[((2313960 + 116|0))>>0]|0;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     __THREW__ = 0;
     (invoke_ii(2996,(2313960|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2313960|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2313960|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2313960|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if (!($47)) {
     $48 = HEAP32[((2313960 + 80|0))>>2]|0;
     $49 = (($48) + 4|0);
     $50 = HEAP32[$49>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($50|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if (!($52)) {
      $53 = (($50) + 12|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = ($V_0$0>>>0)<($54>>>0);
      if (!($55)) {
       __THREW__ = 0;
       $56 = (invoke_i(132)|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($56|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
      }
      $61 = HEAP32[$50>>2]|0;
      $62 = (($50) + 16|0);
      $63 = (($61) + 92|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = Math_imul($64, $V_0$0)|0;
      $66 = (($62) + ($65)|0);
      $67 = HEAP32[$66>>2]|0;
      $$0 = $67;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
  else if ((label|0) == 35) {
   __THREW__ = 0;
   $90 = (invoke_iii(834,0,($x|0))|0);
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   if (!($92)) {
    $$0 = $90;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Collections_Hashtable_m_SetTableP37mscorlib_System_Collections_HashtableP46mscorlib_System_Collections_Hashtable_Slot_arrP25mscorlib_System_Int32_arr($__this,$table,$hashes) {
 $__this = $__this|0;
 $table = $table|0;
 $hashes = $hashes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311664);
 __THREW__ = 0;
 invoke_v(555);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($table|0)==(0|0);
   if (!($2)) {
    $15 = (($__this) + 20|0);
    HEAP32[$15>>2] = $table;
    $16 = (($__this) + 24|0);
    HEAP32[$16>>2] = $hashes;
    __THREW__ = 0;
    invoke_vi(2175,($__this|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3023736>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3833,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z47mscorlib_System_Collections_Hashtable_m_set_hcpP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310800);
 $0 = (($__this) + 40|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z52mscorlib_System_Collections_Hashtable_m_set_comparerP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310752);
 $0 = (($__this) + 44|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P37mscorlib_System_Collections_Hashtablei($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310608);
 __THREW__ = 0;
 invoke_viif(19,($__this|0),($capacity|0),1.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z150mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_IHashCodeProvider_mscorlib_System_Collections_IComparerP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_($__this,$hcp,$comparer) {
 $__this = $__this|0;
 $hcp = $hcp|0;
 $comparer = $comparer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310656);
 __THREW__ = 0;
 invoke_viifii(2,($__this|0),1,1.0,($hcp|0),($comparer|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z46mscorlib_System_Collections_Hashtable_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310704);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2758,(1170368|0),34)|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$0>>2] = 2667208;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viii(551,(0|0),($3|0),($$byval_copy|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2313960|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[((2313960 + 80|0))>>2]|0;
     $11 = (($10) + 4|0);
     HEAP32[$11>>2] = $3;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z49mscorlib_System_Collections_Hashtable_m_get_CountP37mscorlib_System_Collections_Hashtable($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2309424);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52mscorlib_System_Collections_Hashtable_m_get_SyncRootP37mscorlib_System_Collections_Hashtable($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2309520);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z48mscorlib_System_Collections_Hashtable_m_get_ItemP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $V_4$02 = 0, $V_6$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310848);
 __THREW__ = 0;
 invoke_v(556);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3022936>>2]|0;
    $13 = HEAP32[3022944>>2]|0;
    __THREW__ = 0;
    invoke_viii(643,($9|0),($12|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($9|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   }
   $18 = (($__this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__this) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($19|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = (($19) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(1647,(2310896|0),($__this|0),($key|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = $26 & 2147483647;
     $30 = $29 >>> 5;
     $31 = (($30) + 1)|0;
     $32 = (($25) + -1)|0;
     $33 = (($31>>>0) % ($32>>>0))&-1;
     $34 = (($33) + 1)|0;
     $35 = ($25|0)==(0);
     if ($35) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $36 = (($19) + 16|0);
     $37 = (($21) + 12|0);
     $38 = (($21) + 16|0);
     $V_4$02 = $29;$V_6$01 = $25;
     while(1) {
      $41 = (($V_4$02>>>0) % ($25>>>0))&-1;
      __THREW__ = 0;
      invoke_vi(3799,($19|0));
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       label = 3;
       break;
      }
      $39 = HEAP32[$24>>2]|0;
      $40 = ($41>>>0)<($39>>>0);
      if (!($40)) {
       __THREW__ = 0;
       $42 = (invoke_i(132)|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($42|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        label = 3;
        break;
       }
      }
      $47 = HEAP32[$19>>2]|0;
      $48 = (($47) + 92|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = Math_imul($49, $41)|0;
      $51 = (($36) + ($50)|0);
      $52 = HEAP32[$51>>2]|0;
      $$sum = (($50) + 4)|0;
      $53 = (($36) + ($$sum)|0);
      $54 = HEAP32[$53>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($21|0));
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 3;
       break;
      }
      $57 = HEAP32[$37>>2]|0;
      $58 = ($41>>>0)<($57>>>0);
      if (!($58)) {
       __THREW__ = 0;
       $59 = (invoke_i(132)|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($59|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        label = 3;
        break;
       }
      }
      $64 = HEAP32[$21>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $41)|0;
      $68 = (($38) + ($67)|0);
      $69 = HEAP32[$68>>2]|0;
      $70 = ($52|0)==(0|0);
      if ($70) {
       $$0 = 0;
       label = 30;
       break;
      }
      $71 = ($52|0)==($key|0);
      if ($71) {
       $$0 = $54;
       label = 30;
       break;
      }
      $72 = $69 & 2147483647;
      $73 = ($72|0)==($29|0);
      if ($73) {
       __THREW__ = 0;
       $74 = (invoke_iiiii(300,(2310944|0),($__this|0),($key|0),($52|0))|0);
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        label = 3;
        break;
       }
       if ($74) {
        $$0 = $54;
        label = 30;
        break;
       }
      }
      $77 = ($69|0)<(0);
      if (!($77)) {
       $$0 = 0;
       label = 30;
       break;
      }
      $78 = (($34) + ($41))|0;
      $79 = (($V_6$01) + -1)|0;
      $80 = ($79|0)==(0);
      if ($80) {
       $$0 = 0;
       label = 30;
       break;
      } else {
       $V_4$02 = $78;$V_6$01 = $79;
      }
     }
     if ((label|0) == 3) {
      $3 = ___cxa_find_matching_catch()|0;
      $4 = tempRet0;
      $lpad$phi$index = $3;$lpad$phi$index2 = $4;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 30) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Collections_Hashtable_m_set_ItemP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310992);
 __THREW__ = 0;
 invoke_viiii(152,($__this|0),($key|0),($value|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z47mscorlib_System_Collections_Hashtable_m_PutImplP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_b($__this,$key,$value,$overwrite) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 $overwrite = $overwrite|0;
 var $$V_7$0 = 0, $$V_7$1 = 0, $$sum = 0, $$sum12 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$027 = 0, $V_7$0 = 0, $V_7$126 = 0, $V_7$2 = 0, $V_8$025 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311808);
 __THREW__ = 0;
 invoke_v(557);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3023792>>2]|0;
    $13 = HEAP32[3023800>>2]|0;
    __THREW__ = 0;
    invoke_viii(643,($9|0),($12|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($9|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   }
   $18 = (($__this) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__this) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($19|0)<($21|0);
   if (!($22)) {
    __THREW__ = 0;
    invoke_vi(2176,($__this|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
   }
   $25 = (($__this) + 20|0);
   $26 = HEAP32[$25>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($26|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = (($26) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iiii(1647,(2310896|0),($__this|0),($key|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     $34 = $31 & 2147483647;
     $35 = $34 >>> 5;
     $36 = (($35) + 1)|0;
     $37 = (($30) + -1)|0;
     $38 = (($36>>>0) % ($37>>>0))&-1;
     $39 = (($38) + 1)|0;
     $40 = HEAP32[$25>>2]|0;
     $41 = (($__this) + 24|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = ($30|0)==(0);
     if ($43) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $44 = (($40) + 16|0);
     $45 = (($42) + 16|0);
     $46 = (($42) + 12|0);
     $47 = (($40) + 12|0);
     $V_2$027 = $34;$V_7$126 = -1;$V_8$025 = 0;
     while(1) {
      $49 = (($V_2$027>>>0) % ($30>>>0))&-1;
      __THREW__ = 0;
      invoke_vi(3799,($40|0));
      $178 = __THREW__; __THREW__ = 0;
      $179 = $178&1;
      if ($179) {
       label = 3;
       break;
      }
      $48 = ($49|0)<(0);
      if ($48) {
       label = 19;
      } else {
       $50 = HEAP32[$47>>2]|0;
       $51 = ($49>>>0)<($50>>>0);
       if (!($51)) {
        label = 19;
       }
      }
      if ((label|0) == 19) {
       label = 0;
       __THREW__ = 0;
       $52 = (invoke_i(132)|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($52|0));
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        label = 3;
        break;
       }
      }
      $57 = HEAP32[$40>>2]|0;
      $58 = (($57) + 92|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = Math_imul($59, $49)|0;
      $61 = (($44) + ($60)|0);
      $62 = HEAP32[$61>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($42|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       label = 3;
       break;
      }
      if ($48) {
       label = 24;
      } else {
       $65 = HEAP32[$46>>2]|0;
       $66 = ($49>>>0)<($65>>>0);
       if (!($66)) {
        label = 24;
       }
      }
      if ((label|0) == 24) {
       label = 0;
       __THREW__ = 0;
       $67 = (invoke_i(132)|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($67|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 3;
        break;
       }
      }
      $72 = HEAP32[$42>>2]|0;
      $73 = (($72) + 92|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = Math_imul($74, $49)|0;
      $76 = (($45) + ($75)|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = ($V_7$126|0)==(-1);
      if ($78) {
       __THREW__ = 0;
       (invoke_ii(2996,(2307792|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        label = 3;
        break;
       }
       $81 = HEAP8[((2307792 + 116|0))>>0]|0;
       $82 = ($81<<24>>24)==(0);
       if ($82) {
        __THREW__ = 0;
        (invoke_ii(2996,(2307792|0))|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2307792|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3832,(2307792|0));
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         label = 3;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2307792|0))|0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        label = 3;
        break;
       }
       $91 = HEAP32[((2307792 + 80|0))>>2]|0;
       $92 = HEAP32[$91>>2]|0;
       $93 = ($62|0)==($92|0);
       $94 = ($77|0)<(0);
       $or$cond = $93 & $94;
       $$V_7$1 = $or$cond ? $49 : -1;
       $V_7$0 = $$V_7$1;
      } else {
       $V_7$0 = $V_7$126;
      }
      $95 = ($62|0)==(0|0);
      if ($95) {
       label = 42;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2307792|0))|0);
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       label = 3;
       break;
      }
      $98 = HEAP8[((2307792 + 116|0))>>0]|0;
      $99 = ($98<<24>>24)==(0);
      if ($99) {
       __THREW__ = 0;
       (invoke_ii(2996,(2307792|0))|0);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2307792|0))|0);
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if ($103) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3832,(2307792|0));
       $104 = __THREW__; __THREW__ = 0;
       $105 = $104&1;
       if ($105) {
        label = 3;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2307792|0))|0);
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       label = 3;
       break;
      }
      $108 = HEAP32[((2307792 + 80|0))>>2]|0;
      $109 = HEAP32[$108>>2]|0;
      $110 = ($62|0)!=($109|0);
      $111 = ($77|0)<(0);
      $or$cond1 = $110 | $111;
      if (!($or$cond1)) {
       label = 42;
       break;
      }
      $113 = $77 & 2147483647;
      $114 = ($113|0)==($34|0);
      if ($114) {
       __THREW__ = 0;
       $115 = (invoke_iiiii(300,(2310944|0),($__this|0),($key|0),($62|0))|0);
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 3;
        break;
       }
       if ($115) {
        label = 46;
        break;
       }
      }
      $152 = ($V_7$0|0)==(-1);
      if ($152) {
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $153 = __THREW__; __THREW__ = 0;
       $154 = $153&1;
       if ($154) {
        label = 3;
        break;
       }
       if ($48) {
        label = 65;
       } else {
        $155 = HEAP32[$46>>2]|0;
        $156 = ($49>>>0)<($155>>>0);
        if (!($156)) {
         label = 65;
        }
       }
       if ((label|0) == 65) {
        label = 0;
        __THREW__ = 0;
        $157 = (invoke_i(132)|0);
        $158 = __THREW__; __THREW__ = 0;
        $159 = $158&1;
        if ($159) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($157|0));
        $160 = __THREW__; __THREW__ = 0;
        $161 = $160&1;
        if ($161) {
         label = 3;
         break;
        }
       }
       $162 = HEAP32[$42>>2]|0;
       $163 = (($162) + 92|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = Math_imul($164, $49)|0;
       $166 = (($45) + ($165)|0);
       $167 = HEAP32[$166>>2]|0;
       $168 = $167 | -2147483648;
       HEAP32[$166>>2] = $168;
      }
      $169 = (($39) + ($V_2$027))|0;
      $170 = (($V_8$025) + 1)|0;
      $171 = ($170|0)<(0);
      $172 = $171 << 31 >> 31;
      $173 = ($172>>>0)<(0);
      $174 = ($172|0)==(0);
      $175 = ($170>>>0)<($30>>>0);
      $176 = $174 & $175;
      $177 = $173 | $176;
      if ($177) {
       $V_2$027 = $169;$V_7$126 = $V_7$0;$V_8$025 = $170;
      } else {
       $V_7$2 = $V_7$0;
       break;
      }
     }
     if ((label|0) == 3) {
      $3 = ___cxa_find_matching_catch()|0;
      $4 = tempRet0;
      $lpad$phi$index = $3;$lpad$phi$index2 = $4;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 42) {
      $112 = ($V_7$0|0)==(-1);
      $$V_7$0 = $112 ? $49 : $V_7$0;
      $V_7$2 = $$V_7$0;
     }
     else if ((label|0) == 46) {
      if (!($overwrite)) {
       $139 = HEAP32[3023808>>2]|0;
       __THREW__ = 0;
       $140 = (invoke_iiii(559,(0|0),($139|0),($key|0))|0);
       $141 = __THREW__; __THREW__ = 0;
       $142 = $141&1;
       if ($142) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        break;
       }
       __THREW__ = 0;
       $145 = (invoke_ii(3469,(2560072|0))|0);
       $146 = __THREW__; __THREW__ = 0;
       $147 = $146&1;
       if ($147) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(1924,($145|0),($140|0));
       $148 = __THREW__; __THREW__ = 0;
       $149 = $148&1;
       if ($149) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3833,($145|0));
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        break;
       }
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vi(3799,($40|0));
      $118 = __THREW__; __THREW__ = 0;
      $119 = $118&1;
      if ($119) {
       break;
      }
      if ($48) {
       label = 50;
      } else {
       $120 = HEAP32[$47>>2]|0;
       $121 = ($49>>>0)<($120>>>0);
       if (!($121)) {
        label = 50;
       }
      }
      if ((label|0) == 50) {
       __THREW__ = 0;
       $122 = (invoke_i(132)|0);
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($122|0));
       $125 = __THREW__; __THREW__ = 0;
       $126 = $125&1;
       if ($126) {
        break;
       }
      }
      $127 = HEAP32[$40>>2]|0;
      $128 = (($127) + 92|0);
      $129 = HEAP32[$128>>2]|0;
      $130 = Math_imul($129, $49)|0;
      $$sum12 = (($130) + 4)|0;
      $131 = (($44) + ($$sum12)|0);
      HEAP32[$131>>2] = $value;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $132 = __THREW__; __THREW__ = 0;
      $133 = $132&1;
      if ($133) {
       break;
      }
      $134 = (($__this) + 12|0);
      $135 = HEAP32[$134>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break;
      }
      $138 = (($135) + 1)|0;
      HEAP32[$134>>2] = $138;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $180 = ($V_7$2|0)==(-1);
     if ($180) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3799,($40|0));
     $181 = __THREW__; __THREW__ = 0;
     $182 = $181&1;
     if (!($182)) {
      $183 = ($V_7$2|0)<(0);
      if ($183) {
       label = 74;
      } else {
       $184 = (($40) + 12|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = ($V_7$2>>>0)<($185>>>0);
       if (!($186)) {
        label = 74;
       }
      }
      if ((label|0) == 74) {
       __THREW__ = 0;
       $187 = (invoke_i(132)|0);
       $188 = __THREW__; __THREW__ = 0;
       $189 = $188&1;
       if ($189) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($187|0));
       $190 = __THREW__; __THREW__ = 0;
       $191 = $190&1;
       if ($191) {
        break;
       }
      }
      $192 = HEAP32[$40>>2]|0;
      $193 = (($40) + 16|0);
      $194 = (($192) + 92|0);
      $195 = HEAP32[$194>>2]|0;
      $196 = Math_imul($195, $V_7$2)|0;
      $197 = (($193) + ($196)|0);
      HEAP32[$197>>2] = $key;
      __THREW__ = 0;
      invoke_vi(3799,($40|0));
      $198 = __THREW__; __THREW__ = 0;
      $199 = $198&1;
      if (!($199)) {
       if ($183) {
        label = 79;
       } else {
        $200 = (($40) + 12|0);
        $201 = HEAP32[$200>>2]|0;
        $202 = ($V_7$2>>>0)<($201>>>0);
        if (!($202)) {
         label = 79;
        }
       }
       if ((label|0) == 79) {
        __THREW__ = 0;
        $203 = (invoke_i(132)|0);
        $204 = __THREW__; __THREW__ = 0;
        $205 = $204&1;
        if ($205) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($203|0));
        $206 = __THREW__; __THREW__ = 0;
        $207 = $206&1;
        if ($207) {
         break;
        }
       }
       $208 = HEAP32[$40>>2]|0;
       $209 = (($208) + 92|0);
       $210 = HEAP32[$209>>2]|0;
       $211 = Math_imul($210, $V_7$2)|0;
       $$sum = (($211) + 4)|0;
       $212 = (($193) + ($$sum)|0);
       HEAP32[$212>>2] = $value;
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $213 = __THREW__; __THREW__ = 0;
       $214 = $213&1;
       if (!($214)) {
        if ($183) {
         label = 84;
        } else {
         $215 = (($42) + 12|0);
         $216 = HEAP32[$215>>2]|0;
         $217 = ($V_7$2>>>0)<($216>>>0);
         if (!($217)) {
          label = 84;
         }
        }
        if ((label|0) == 84) {
         __THREW__ = 0;
         $218 = (invoke_i(132)|0);
         $219 = __THREW__; __THREW__ = 0;
         $220 = $219&1;
         if ($220) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($218|0));
         $221 = __THREW__; __THREW__ = 0;
         $222 = $221&1;
         if ($222) {
          break;
         }
        }
        $223 = HEAP32[$42>>2]|0;
        $224 = (($42) + 16|0);
        $225 = (($223) + 92|0);
        $226 = HEAP32[$225>>2]|0;
        $227 = Math_imul($226, $V_7$2)|0;
        $228 = (($224) + ($227)|0);
        $229 = HEAP32[$228>>2]|0;
        $230 = $229 | $34;
        HEAP32[$228>>2] = $230;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $231 = __THREW__; __THREW__ = 0;
        $232 = $231&1;
        if (!($232)) {
         $233 = HEAP32[$18>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $234 = __THREW__; __THREW__ = 0;
         $235 = $234&1;
         if (!($235)) {
          $236 = (($233) + 1)|0;
          HEAP32[$18>>2] = $236;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $237 = __THREW__; __THREW__ = 0;
          $238 = $237&1;
          if (!($238)) {
           $239 = (($__this) + 12|0);
           $240 = HEAP32[$239>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($__this|0));
           $241 = __THREW__; __THREW__ = 0;
           $242 = $241&1;
           if (!($242)) {
            $243 = (($240) + 1)|0;
            HEAP32[$239>>2] = $243;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z46mscorlib_System_Collections_Hashtable_m_CopyToP37mscorlib_System_Collections_HashtableP21mscorlib_System_Arrayi($__this,$_____array,$arrayIndex) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $arrayIndex = $arrayIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_15 = 0, $L_16 = 0, $V_1$0 = 0;
 var $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_15 = sp;
 $L_16 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311040);
 __THREW__ = 0;
 invoke_v(558);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3023144>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($arrayIndex|0)>(-1);
   if (!($17)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2561352|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3023152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($20|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($20|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    __THREW__ = 0;
    $30 = (invoke_ii(1859,($_____array|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = ($30|0)<(2);
     if (!($33)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_ii(3469,(2560072|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = HEAP32[3023160>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($36|0),($39|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($36|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      __THREW__ = 0;
      $46 = (invoke_ii(1857,($_____array|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if (!($48)) {
       $49 = ($46|0)<(1);
       if (!($49)) {
        __THREW__ = 0;
        invoke_vi(3799,($_____array|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        __THREW__ = 0;
        $52 = (invoke_ii(1857,($_____array|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        $55 = ($52|0)>($arrayIndex|0);
        if (!($55)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          break;
         }
         __THREW__ = 0;
         $58 = (invoke_ii(3469,(2560072|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break;
         }
         $61 = HEAP32[3023168>>2]|0;
         __THREW__ = 0;
         invoke_vii(1924,($58|0),($61|0));
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3833,($58|0));
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
         // unreachable;
        }
       }
       $66 = (($__this) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($67) + ($arrayIndex))|0;
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if (!($70)) {
        __THREW__ = 0;
        $71 = (invoke_ii(1857,($_____array|0))|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if (!($73)) {
         $74 = ($68|0)>($71|0);
         if ($74) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           break;
          }
          __THREW__ = 0;
          $77 = (invoke_ii(3469,(2560072|0))|0);
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break;
          }
          $80 = HEAP32[3023176>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($77|0),($80|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3833,($77|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         $85 = (invoke_iii(2730,(2311088|0),($__this|0))|0);
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if (!($87)) {
          $V_1$0 = $arrayIndex;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($85|0));
           $110 = __THREW__; __THREW__ = 0;
           $111 = $110&1;
           if ($111) {
            break;
           }
           __THREW__ = 0;
           $112 = (invoke_iii(2741,(2176240|0),($85|0))|0);
           $113 = __THREW__; __THREW__ = 0;
           $114 = $113&1;
           if ($114) {
            break;
           }
           if (!($112)) {
            label = 55;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($85|0));
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(2114,($L_15|0),(2311136|0),($85|0));
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            break;
           }
           $90 = $L_15;
           $91 = $90;
           $92 = HEAP32[$91>>2]|0;
           $93 = (($90) + 4)|0;
           $94 = $93;
           $95 = HEAP32[$94>>2]|0;
           $96 = $L_16;
           $97 = $96;
           HEAP32[$97>>2] = $92;
           $98 = (($96) + 4)|0;
           $99 = $98;
           HEAP32[$99>>2] = $95;
           __THREW__ = 0;
           (invoke_ii(2996,(2307216|0))|0);
           $100 = __THREW__; __THREW__ = 0;
           $101 = $100&1;
           if ($101) {
            break;
           }
           __THREW__ = 0;
           $102 = (invoke_iii(2724,(2307216|0),($L_16|0))|0);
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($_____array|0));
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            break;
           }
           $107 = (($V_1$0) + 1)|0;
           __THREW__ = 0;
           invoke_viii(534,($_____array|0),($102|0),($V_1$0|0));
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            break;
           } else {
            $V_1$0 = $107;
           }
          }
          if ((label|0) == 55) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index2 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z43mscorlib_System_Collections_Hashtable_m_AddP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_($__this,$key,$value) {
 $__this = $__this|0;
 $key = $key|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311184);
 __THREW__ = 0;
 invoke_viiii(152,($__this|0),($key|0),($value|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48mscorlib_System_Collections_Hashtable_m_ContainsP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311232);
 __THREW__ = 0;
 $0 = (invoke_iii(832,($__this|0),($key|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0|0)>(-1);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z44mscorlib_System_Collections_Hashtable_m_FindP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $V_4$02 = 0, $V_6$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311712);
 __THREW__ = 0;
 invoke_v(559);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($key|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3023768>>2]|0;
    $13 = HEAP32[3023776>>2]|0;
    __THREW__ = 0;
    invoke_viii(643,($9|0),($12|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($9|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   }
   $18 = (($__this) + 20|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__this) + 24|0);
   $21 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($19|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = (($19) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(1647,(2310896|0),($__this|0),($key|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = $26 & 2147483647;
     $30 = $29 >>> 5;
     $31 = (($30) + 1)|0;
     $32 = (($25) + -1)|0;
     $33 = (($31>>>0) % ($32>>>0))&-1;
     $34 = (($33) + 1)|0;
     $35 = ($25|0)==(0);
     if ($35) {
      $$0 = -1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $36 = (($19) + 16|0);
     $37 = (($21) + 12|0);
     $38 = (($21) + 16|0);
     $V_4$02 = $29;$V_6$01 = $25;
     while(1) {
      $41 = (($V_4$02>>>0) % ($25>>>0))&-1;
      __THREW__ = 0;
      invoke_vi(3799,($19|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       label = 3;
       break;
      }
      $39 = HEAP32[$24>>2]|0;
      $40 = ($41>>>0)<($39>>>0);
      if (!($40)) {
       __THREW__ = 0;
       $42 = (invoke_i(132)|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($42|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        label = 3;
        break;
       }
      }
      $47 = HEAP32[$19>>2]|0;
      $48 = (($47) + 92|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = Math_imul($49, $41)|0;
      $51 = (($36) + ($50)|0);
      $52 = HEAP32[$51>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($21|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 3;
       break;
      }
      $55 = HEAP32[$37>>2]|0;
      $56 = ($41>>>0)<($55>>>0);
      if (!($56)) {
       __THREW__ = 0;
       $57 = (invoke_i(132)|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($57|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        label = 3;
        break;
       }
      }
      $62 = HEAP32[$21>>2]|0;
      $63 = (($62) + 92|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = Math_imul($64, $41)|0;
      $66 = (($38) + ($65)|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($52|0)==(0|0);
      if ($68) {
       $$0 = -1;
       label = 30;
       break;
      }
      $69 = ($52|0)==($key|0);
      if ($69) {
       $$0 = $41;
       label = 30;
       break;
      }
      $70 = $67 & 2147483647;
      $71 = ($70|0)==($29|0);
      if ($71) {
       __THREW__ = 0;
       $72 = (invoke_iiiii(300,(2310944|0),($__this|0),($key|0),($52|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 3;
        break;
       }
       if ($72) {
        $$0 = $41;
        label = 30;
        break;
       }
      }
      $75 = ($67|0)<(0);
      if (!($75)) {
       $$0 = -1;
       label = 30;
       break;
      }
      $76 = (($34) + ($41))|0;
      $77 = (($V_6$01) + -1)|0;
      $78 = ($77|0)==(0);
      if ($78) {
       $$0 = -1;
       label = 30;
       break;
      } else {
       $V_4$02 = $76;$V_6$01 = $77;
      }
     }
     if ((label|0) == 3) {
      $3 = ___cxa_find_matching_catch()|0;
      $4 = tempRet0;
      $lpad$phi$index = $3;$lpad$phi$index2 = $4;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 30) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_Collections_Hashtable_m_GetEnumeratorP37mscorlib_System_Collections_Hashtable($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311088);
 __THREW__ = 0;
 (invoke_ii(2996,(2309240|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2309240|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viii(572,($2|0),($__this|0),2);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Collections_Hashtable_m_RemoveP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B4_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311280);
 __THREW__ = 0;
 $0 = (invoke_iii(832,($__this|0),($key|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($0|0)<(0);
   if ($3) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $6 = (($__this) + 20|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($__this) + 24|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($9) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($0>>>0)<($13>>>0);
    if (!($14)) {
     __THREW__ = 0;
     $15 = (invoke_i(132)|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($15|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
    }
    $20 = HEAP32[$9>>2]|0;
    $21 = (($9) + 16|0);
    $22 = (($20) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $0)|0;
    $25 = (($21) + ($24)|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = $26 & -2147483648;
    $28 = HEAP32[$8>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($28|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $31 = (($28) + 12|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = ($0>>>0)<($32>>>0);
     if (!($33)) {
      __THREW__ = 0;
      $34 = (invoke_i(132)|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($34|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
     }
     $39 = HEAP32[$28>>2]|0;
     $40 = (($28) + 16|0);
     $41 = (($39) + 92|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = Math_imul($42, $0)|0;
     $44 = (($40) + ($43)|0);
     HEAP32[$44>>2] = $27;
     __THREW__ = 0;
     invoke_vi(3799,($7|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      $47 = (($7) + 12|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = ($0>>>0)<($48>>>0);
      if (!($49)) {
       __THREW__ = 0;
       $50 = (invoke_i(132)|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($50|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
      }
      $55 = HEAP32[$7>>2]|0;
      $56 = (($7) + 16|0);
      $57 = (($55) + 92|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = Math_imul($58, $0)|0;
      $60 = (($56) + ($59)|0);
      $61 = ($27|0)==(0);
      if ($61) {
       $G_B4_0$0 = 0;
      } else {
       __THREW__ = 0;
       (invoke_ii(2996,(2307792|0))|0);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        break;
       }
       $64 = HEAP8[((2307792 + 116|0))>>0]|0;
       $65 = ($64<<24>>24)==(0);
       if ($65) {
        __THREW__ = 0;
        (invoke_ii(2996,(2307792|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2307792|0))|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3832,(2307792|0));
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2307792|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = HEAP32[((2307792 + 80|0))>>2]|0;
       $75 = HEAP32[$74>>2]|0;
       $G_B4_0$0 = $75;
      }
      HEAP32[$60>>2] = $G_B4_0$0;
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if (!($77)) {
       $78 = (($7) + 12|0);
       $79 = HEAP32[$78>>2]|0;
       $80 = ($0>>>0)<($79>>>0);
       if (!($80)) {
        __THREW__ = 0;
        $81 = (invoke_i(132)|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($81|0));
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         break;
        }
       }
       $86 = HEAP32[$7>>2]|0;
       $87 = (($86) + 92|0);
       $88 = HEAP32[$87>>2]|0;
       $89 = Math_imul($88, $0)|0;
       $$sum = (($89) + 4)|0;
       $90 = (($56) + ($$sum)|0);
       HEAP32[$90>>2] = 0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if (!($92)) {
        $93 = (($__this) + 8|0);
        $94 = HEAP32[$93>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $95 = __THREW__; __THREW__ = 0;
        $96 = $95&1;
        if (!($96)) {
         $97 = (($94) + -1)|0;
         HEAP32[$93>>2] = $97;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $98 = __THREW__; __THREW__ = 0;
         $99 = $98&1;
         if (!($99)) {
          $100 = (($__this) + 12|0);
          $101 = HEAP32[$100>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if (!($103)) {
           $104 = (($101) + 1)|0;
           HEAP32[$100>>2] = $104;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z51mscorlib_System_Collections_Hashtable_m_ContainsKeyP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311328);
 __THREW__ = 0;
 $0 = (invoke_iiii(1644,(2311232|0),($__this|0),($key|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Collections_Hashtable_m_GetObjectDataP37mscorlib_System_Collections_HashtableP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311376);
 __THREW__ = 0;
 invoke_v(560);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3023512>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 16|0);
   $16 = Math_fround(HEAPF32[$15>>2]);
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3023520>>2]|0;
    __THREW__ = 0;
    invoke_viif(20,($info|0),($19|0),(+$16));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 12|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[3023528>>2]|0;
      __THREW__ = 0;
      invoke_viii(618,($info|0),($26|0),($23|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = (($__this) + 52|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)==(0|0);
       if ($31) {
        $37 = (($__this) + 44|0);
        $38 = HEAP32[$37>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
        $41 = HEAP32[3023544>>2]|0;
        __THREW__ = 0;
        invoke_viii(621,($info|0),($41|0),($38|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        $34 = HEAP32[3023536>>2]|0;
        __THREW__ = 0;
        invoke_viii(621,($info|0),($34|0),($30|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break;
        }
       }
       $44 = (($__this) + 40|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = ($45|0)==(0|0);
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        $49 = HEAP32[3023552>>2]|0;
        __THREW__ = 0;
        invoke_viii(621,($info|0),($49|0),($45|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
       }
       $52 = (($__this) + 20|0);
       $53 = HEAP32[$52>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($53|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if (!($55)) {
        $56 = (($53) + 12|0);
        $57 = HEAP32[$56>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if (!($59)) {
         $60 = HEAP32[3023560>>2]|0;
         __THREW__ = 0;
         invoke_viii(618,($info|0),($60|0),($57|0));
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if (!($62)) {
          $63 = (($__this) + 8|0);
          $64 = HEAP32[$63>>2]|0;
          __THREW__ = 0;
          (invoke_ii(2996,(1167664|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if (!($66)) {
           __THREW__ = 0;
           $67 = (invoke_iii(2758,(1167664|0),($64|0))|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if (!($69)) {
            __THREW__ = 0;
            invoke_viiii(153,($__this|0),($67|0),0,0);
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if (!($71)) {
             $72 = HEAP32[$63>>2]|0;
             __THREW__ = 0;
             (invoke_ii(2996,(1167664|0))|0);
             $73 = __THREW__; __THREW__ = 0;
             $74 = $73&1;
             if (!($74)) {
              __THREW__ = 0;
              $75 = (invoke_iii(2758,(1167664|0),($72|0))|0);
              $76 = __THREW__; __THREW__ = 0;
              $77 = $76&1;
              if (!($77)) {
               __THREW__ = 0;
               invoke_viiii(153,($__this|0),($75|0),0,1);
               $78 = __THREW__; __THREW__ = 0;
               $79 = $78&1;
               if (!($79)) {
                __THREW__ = 0;
                invoke_vi(3799,($info|0));
                $80 = __THREW__; __THREW__ = 0;
                $81 = $80&1;
                if (!($81)) {
                 $82 = HEAP32[3023568>>2]|0;
                 __THREW__ = 0;
                 invoke_viii(621,($info|0),($82|0),($67|0));
                 $83 = __THREW__; __THREW__ = 0;
                 $84 = $83&1;
                 if (!($84)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($info|0));
                  $85 = __THREW__; __THREW__ = 0;
                  $86 = $85&1;
                  if ($86) {
                   break;
                  }
                  $87 = HEAP32[3023576>>2]|0;
                  __THREW__ = 0;
                  invoke_viii(621,($info|0),($87|0),($75|0));
                  $88 = __THREW__; __THREW__ = 0;
                  $89 = $88&1;
                  if ($89) {
                   break;
                  }
                  $90 = HEAP32[$29>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($info|0));
                  $91 = __THREW__; __THREW__ = 0;
                  $92 = $91&1;
                  if ($92) {
                   break;
                  }
                  $93 = HEAP32[3023584>>2]|0;
                  __THREW__ = 0;
                  invoke_viii(621,($info|0),($93|0),($90|0));
                  $94 = __THREW__; __THREW__ = 0;
                  $95 = $94&1;
                  if ($95) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z47mscorlib_System_Collections_Hashtable_m_GetHashP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310896);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $10 = (($__this) + 40|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    __THREW__ = 0;
    invoke_vi(3799,($key|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    $15 = (invoke_iii(2729,(2148880|0),($key|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    } else {
     $$0 = $15;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_iiii(1649,(2311472|0),($11|0),($key|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    } else {
     $$0 = $20;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($1|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iiii(1649,(2311424|0),($1|0),($key|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $$0 = $5;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Collections_Hashtable_m_KeyEqualsP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_($__this,$item,$key) {
 $__this = $__this|0;
 $item = $item|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2310944);
 __THREW__ = 0;
 (invoke_ii(2996,(2307792|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2307792 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2307792|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2307792|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3832,(2307792|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2307792|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2307792 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==($key|0);
    if ($16) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $17 = (($__this) + 52|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3799,($18|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     $22 = (invoke_iiiii(302,(2311520|0),($18|0),($item|0),($key|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     } else {
      $$0 = $22;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $25 = (($__this) + 44|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = ($26|0)==(0|0);
    if ($27) {
     __THREW__ = 0;
     invoke_vi(3799,($item|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     $30 = (invoke_iiii(1644,(2148736|0),($item|0),($key|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     } else {
      $$0 = $30;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($26|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     __THREW__ = 0;
     $35 = (invoke_iiiii(318,(2311568|0),($26|0),($item|0),($key|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      $38 = ($35|0)==(0);
      $$0 = $38;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Collections_Hashtable_m_AdjustThresholdP37mscorlib_System_Collections_Hashtable($__this) {
 $__this = $__this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311616);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (Math_fround(($5|0)));
  $7 = (($__this) + 16|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  $9 = Math_fround($6 * $8);
  $10 = (~~(($9)));
  $11 = (($__this) + 28|0);
  $12 = ($10|0)<($5|0);
  $13 = (($5) + -1)|0;
  $$ = $12 ? $10 : $13;
  HEAP32[$11>>2] = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z46mscorlib_System_Collections_Hashtable_m_RehashP37mscorlib_System_Collections_Hashtable($__this) {
 $__this = $__this|0;
 var $$pn = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_11$0 = 0, $V_6$010 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311760);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 << 1;
  $7 = $6 | 1;
  __THREW__ = 0;
  $8 = (invoke_iii(835,0,($7|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1229880|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    $13 = (invoke_iii(2758,(1229880|0),($8|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1170368|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      $19 = (invoke_iii(2758,(1170368|0),($8|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = (($__this) + 24|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = ($5|0)>(0);
       L8: do {
        if ($24) {
         $25 = (($16) + 16|0);
         $26 = (($23) + 16|0);
         $27 = (($8) + -1)|0;
         $28 = (($13) + 12|0);
         $29 = (($13) + 16|0);
         $30 = (($19) + 12|0);
         $31 = (($19) + 16|0);
         $32 = (($23) + 12|0);
         $33 = (($16) + 12|0);
         $V_6$010 = 0;
         L10: while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($16|0));
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           label = 10;
           break;
          }
          $40 = HEAP32[$33>>2]|0;
          $41 = ($V_6$010>>>0)<($40>>>0);
          if (!($41)) {
           __THREW__ = 0;
           $42 = (invoke_i(132)|0);
           $43 = __THREW__; __THREW__ = 0;
           $44 = $43&1;
           if ($44) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($42|0));
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            label = 10;
            break;
           }
          }
          $47 = HEAP32[$16>>2]|0;
          $48 = (($47) + 92|0);
          $49 = HEAP32[$48>>2]|0;
          $50 = Math_imul($49, $V_6$010)|0;
          $51 = (($25) + ($50)|0);
          $52 = HEAP32[$51>>2]|0;
          $$sum = (($50) + 4)|0;
          $53 = (($25) + ($$sum)|0);
          $54 = HEAP32[$53>>2]|0;
          $55 = ($52|0)==(0|0);
          if (!($55)) {
           __THREW__ = 0;
           invoke_vi(3799,($23|0));
           $56 = __THREW__; __THREW__ = 0;
           $57 = $56&1;
           if ($57) {
            label = 10;
            break;
           }
           $58 = HEAP32[$32>>2]|0;
           $59 = ($V_6$010>>>0)<($58>>>0);
           if (!($59)) {
            __THREW__ = 0;
            $60 = (invoke_i(132)|0);
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             label = 10;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($60|0));
            $63 = __THREW__; __THREW__ = 0;
            $64 = $63&1;
            if ($64) {
             label = 10;
             break;
            }
           }
           $65 = HEAP32[$23>>2]|0;
           $66 = (($65) + 92|0);
           $67 = HEAP32[$66>>2]|0;
           $68 = Math_imul($67, $V_6$010)|0;
           $69 = (($26) + ($68)|0);
           $70 = HEAP32[$69>>2]|0;
           $71 = $70 & 2147483647;
           $72 = $71 >>> 5;
           $73 = (($72) + 1)|0;
           $74 = (($73>>>0) % ($27>>>0))&-1;
           $75 = (($74) + 1)|0;
           $$pn = $71;
           while(1) {
            $V_11$0 = (($$pn>>>0) % ($8>>>0))&-1;
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            if ($152) {
             label = 9;
             break L10;
            }
            $76 = HEAP32[$28>>2]|0;
            $77 = ($V_11$0>>>0)<($76>>>0);
            if (!($77)) {
             __THREW__ = 0;
             $78 = (invoke_i(132)|0);
             $79 = __THREW__; __THREW__ = 0;
             $80 = $79&1;
             if ($80) {
              label = 9;
              break L10;
             }
             __THREW__ = 0;
             invoke_vi(3302,($78|0));
             $81 = __THREW__; __THREW__ = 0;
             $82 = $81&1;
             if ($82) {
              label = 9;
              break L10;
             }
            }
            $83 = HEAP32[$13>>2]|0;
            $84 = (($83) + 92|0);
            $85 = HEAP32[$84>>2]|0;
            $86 = Math_imul($85, $V_11$0)|0;
            $87 = (($29) + ($86)|0);
            $88 = HEAP32[$87>>2]|0;
            $89 = ($88|0)==(0|0);
            if ($89) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($19|0));
            $134 = __THREW__; __THREW__ = 0;
            $135 = $134&1;
            if ($135) {
             label = 9;
             break L10;
            }
            $136 = HEAP32[$30>>2]|0;
            $137 = ($V_11$0>>>0)<($136>>>0);
            if (!($137)) {
             __THREW__ = 0;
             $138 = (invoke_i(132)|0);
             $139 = __THREW__; __THREW__ = 0;
             $140 = $139&1;
             if ($140) {
              label = 9;
              break L10;
             }
             __THREW__ = 0;
             invoke_vi(3302,($138|0));
             $141 = __THREW__; __THREW__ = 0;
             $142 = $141&1;
             if ($142) {
              label = 9;
              break L10;
             }
            }
            $143 = HEAP32[$19>>2]|0;
            $144 = (($143) + 92|0);
            $145 = HEAP32[$144>>2]|0;
            $146 = Math_imul($145, $V_11$0)|0;
            $147 = (($31) + ($146)|0);
            $148 = HEAP32[$147>>2]|0;
            $149 = $148 | -2147483648;
            HEAP32[$147>>2] = $149;
            $150 = (($75) + ($$pn))|0;
            $$pn = $150;
           }
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            label = 10;
            break;
           }
           $92 = HEAP32[$28>>2]|0;
           $93 = ($V_11$0>>>0)<($92>>>0);
           if (!($93)) {
            __THREW__ = 0;
            $94 = (invoke_i(132)|0);
            $95 = __THREW__; __THREW__ = 0;
            $96 = $95&1;
            if ($96) {
             label = 10;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($94|0));
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             label = 10;
             break;
            }
           }
           $99 = HEAP32[$13>>2]|0;
           $100 = (($99) + 92|0);
           $101 = HEAP32[$100>>2]|0;
           $102 = Math_imul($101, $V_11$0)|0;
           $103 = (($29) + ($102)|0);
           HEAP32[$103>>2] = $52;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            label = 10;
            break;
           }
           $106 = HEAP32[$28>>2]|0;
           $107 = ($V_11$0>>>0)<($106>>>0);
           if (!($107)) {
            __THREW__ = 0;
            $108 = (invoke_i(132)|0);
            $109 = __THREW__; __THREW__ = 0;
            $110 = $109&1;
            if ($110) {
             label = 10;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($108|0));
            $111 = __THREW__; __THREW__ = 0;
            $112 = $111&1;
            if ($112) {
             label = 10;
             break;
            }
           }
           $113 = HEAP32[$13>>2]|0;
           $114 = (($113) + 92|0);
           $115 = HEAP32[$114>>2]|0;
           $116 = Math_imul($115, $V_11$0)|0;
           $$sum2 = (($116) + 4)|0;
           $117 = (($29) + ($$sum2)|0);
           HEAP32[$117>>2] = $54;
           __THREW__ = 0;
           invoke_vi(3799,($19|0));
           $118 = __THREW__; __THREW__ = 0;
           $119 = $118&1;
           if ($119) {
            label = 10;
            break;
           }
           $120 = HEAP32[$30>>2]|0;
           $121 = ($V_11$0>>>0)<($120>>>0);
           if (!($121)) {
            __THREW__ = 0;
            $122 = (invoke_i(132)|0);
            $123 = __THREW__; __THREW__ = 0;
            $124 = $123&1;
            if ($124) {
             label = 10;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($122|0));
            $125 = __THREW__; __THREW__ = 0;
            $126 = $125&1;
            if ($126) {
             label = 10;
             break;
            }
           }
           $127 = HEAP32[$19>>2]|0;
           $128 = (($127) + 92|0);
           $129 = HEAP32[$128>>2]|0;
           $130 = Math_imul($129, $V_11$0)|0;
           $131 = (($31) + ($130)|0);
           $132 = HEAP32[$131>>2]|0;
           $133 = $132 | $71;
           HEAP32[$131>>2] = $133;
          }
          $153 = (($V_6$010) + 1)|0;
          $154 = ($153|0)<($5|0);
          if ($154) {
           $V_6$010 = $153;
          } else {
           break L8;
          }
         }
         if ((label|0) == 9) {
          $34 = ___cxa_find_matching_catch()|0;
          $35 = tempRet0;
          $lpad$phi$index = $34;$lpad$phi$index3 = $35;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 10) {
          $36 = ___cxa_find_matching_catch()|0;
          $37 = tempRet0;
          $lpad$phi$index = $36;$lpad$phi$index3 = $37;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $157 = __THREW__; __THREW__ = 0;
       $158 = $157&1;
       if (!($158)) {
        $159 = (($__this) + 12|0);
        $160 = HEAP32[$159>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $161 = __THREW__; __THREW__ = 0;
        $162 = $161&1;
        if (!($162)) {
         $163 = (($160) + 1)|0;
         HEAP32[$159>>2] = $163;
         __THREW__ = 0;
         invoke_viii(580,($__this|0),($13|0),($19|0));
         $164 = __THREW__; __THREW__ = 0;
         $165 = $164&1;
         if (!($165)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 $lpad$phi$index = $38;$lpad$phi$index3 = $39;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z49mscorlib_System_Collections_Hashtable_m_TestPrimeP22mscorlib_System_Objecti($__this,$x) {
 $__this = $__this|0;
 $x = $x|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311904);
 $0 = $x & 1;
 $1 = ($0|0)==(0);
 L1: do {
  if ($1) {
   $10 = ($x|0)==(2);
   $$0 = $10;
  } else {
   $2 = (+($x|0));
   $3 = (+Math_sqrt((+$2)));
   $4 = (~~(($3)));
   $5 = ($4|0)>(3);
   if ($5) {
    $V_1$01 = 3;
    while(1) {
     $8 = (($x|0) % ($V_1$01|0))&-1;
     $9 = ($8|0)==(0);
     $7 = (($V_1$01) + 2)|0;
     if ($9) {
      $$0 = 0;
      break L1;
     }
     $6 = ($7|0)<($4|0);
     if ($6) {
      $V_1$01 = $7;
     } else {
      $$0 = 1;
      break;
     }
    }
   } else {
    $$0 = 1;
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z49mscorlib_System_Collections_Hashtable_m_CalcPrimeP22mscorlib_System_Objecti($__this,$x) {
 $__this = $__this|0;
 $x = $x|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2311952);
 $0 = $x & -2;
 $1 = (($0) + -1)|0;
 $2 = ($1|0)==(2147483647);
 L1: do {
  if ($2) {
   $$0 = $x;
  } else {
   $V_0$01 = $1;
   while(1) {
    __THREW__ = 0;
    $7 = (invoke_iii(833,0,($V_0$01|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $3 = (($V_0$01) + 2)|0;
    if ($7) {
     $$0 = $V_0$01;
     break L1;
    }
    $6 = ($3|0)==(2147483647);
    if ($6) {
     $$0 = $x;
     break L1;
    } else {
     $V_0$01 = $3;
    }
   }
   $4 = ___cxa_find_matching_catch()|0;
   $5 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($4|0);
   // unreachable;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN14ActionInvoker4I27mscorlib_System_Int32Traits28mscorlib_System_SingleTraits17VoidPointerTraitsS2_E6InvokeEPFvPvifS4_S4_ES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viifii[$action & 3]($obj,$1,$4,$6,$8);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsE6InvokeEPFvPvifES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 FUNCTION_TABLE_viif[$action & 63]($obj,$1,$4);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_ObjectTraitsS0_E6InvokeEPFP22mscorlib_System_ObjectPvS3_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN14ActionInvoker3I28mscorlib_System_ObjectTraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEPFvPvP22mscorlib_System_ObjectS5_bES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$6);
 STACKTOP = sp;return (0|0);
}
function __Z68mscorlib_System_Collections_Hashtable_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2290720)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $11 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2291976)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($10,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $10;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2319176)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2305960)|0);
 $15 = HEAP32[((2305960 + 48|0))>>2]|0;
 $16 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($15)|0);
 __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($14,$16);
 $17 = HEAP32[$3>>2]|0;
 $18 = (($17) + 12|0);
 HEAP32[$18>>2] = $14;
 STACKTOP = sp;return;
}
function __Z264mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Single_mscorlib_System_Collections_IHashCodeProvider_mscorlib_System_Collections_IComparerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2313336)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z219mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_IHashCodeProvider_mscorlib_System_Collections_IComparerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2313400)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_Hashtable_m_RemoveP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_HashtableTraits_comparer_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2313448)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z129mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_HashtableTraits_hcp_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2313448)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_Collections_IComparer_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Collections_IDictionary_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2291976)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Collections_IDictionaryEnumerator_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Collections_IEqualityComparer_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Collections_IHashCodeProvider_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2314984)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z41mscorlib_System_Collections_Stack_m__ctorP33mscorlib_System_Collections_Stack($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2315208);
 $0 = (($__this) + 12|0);
 HEAP32[$0>>2] = -1;
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1167664|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2758,(1167664|0),16)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($__this) + 8|0);
    HEAP32[$8>>2] = $5;
    $9 = (($__this) + 20|0);
    HEAP32[$9>>2] = 16;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z42mscorlib_System_Collections_Stack_m_ResizeP33mscorlib_System_Collections_Stacki($__this,$ncapacity) {
 $__this = $__this|0;
 $ncapacity = $ncapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2315256);
 __THREW__ = 0;
 $0 = (invoke_iiii(1197,(0|0),($ncapacity|0),16)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1167664|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2758,(1167664|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($__this) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($__this) + 16|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_viiii(140,(0|0),($9|0),($5|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = (($__this) + 20|0);
     HEAP32[$14>>2] = $0;
     HEAP32[$8>>2] = $5;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z45mscorlib_System_Collections_Stack_m_get_CountP33mscorlib_System_Collections_Stack($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2315304);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z48mscorlib_System_Collections_Stack_m_get_SyncRootP33mscorlib_System_Collections_Stack($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2315352);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z41mscorlib_System_Collections_Stack_m_ClearP33mscorlib_System_Collections_Stack($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2315400);
 __THREW__ = 0;
 invoke_vi(3799,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 24|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($3) + 1)|0;
   HEAP32[$2>>2] = $6;
   $7 = (($__this) + 16|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)>(0);
   if (!($9)) {
    HEAP32[$7>>2] = 0;
    $35 = (($__this) + 12|0);
    HEAP32[$35>>2] = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $10 = (($__this) + 8|0);
   $V_0$02 = 0;
   while(1) {
    $16 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($16|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $15 = (($16) + 12|0);
    $17 = HEAP32[$15>>2]|0;
    $18 = ($V_0$02>>>0)<($17>>>0);
    if (!($18)) {
     __THREW__ = 0;
     $19 = (invoke_i(132)|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
    }
    $24 = HEAP32[$16>>2]|0;
    $25 = (($16) + 16|0);
    $26 = (($24) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $V_0$02)|0;
    $29 = (($25) + ($28)|0);
    HEAP32[$29>>2] = 0;
    $30 = (($V_0$02) + 1)|0;
    $31 = HEAP32[$7>>2]|0;
    $32 = ($30|0)<($31|0);
    if ($32) {
     $V_0$02 = $30;
    } else {
     label = 13;
     break;
    }
   }
   if ((label|0) == 13) {
    HEAP32[$7>>2] = 0;
    $35 = (($__this) + 12|0);
    HEAP32[$35>>2] = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   $lpad$phi$index = $11;$lpad$phi$index2 = $12;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $lpad$phi$index = $13;$lpad$phi$index2 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z42mscorlib_System_Collections_Stack_m_CopyToP33mscorlib_System_Collections_StackP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $$neg = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $V_0$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2315448);
 __THREW__ = 0;
 invoke_v(561);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3024160>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($index|0)>(-1);
   if (!($17)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2561352|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3024168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($20|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($20|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    __THREW__ = 0;
    $30 = (invoke_ii(1859,($_____array|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = ($30|0)>(1);
     do {
      if (!($33)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break L1;
       }
       __THREW__ = 0;
       $36 = (invoke_ii(1857,($_____array|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break L1;
       }
       $39 = ($36|0)<(1);
       if (!($39)) {
        __THREW__ = 0;
        invoke_vi(3799,($_____array|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break L1;
        }
        __THREW__ = 0;
        $42 = (invoke_ii(1857,($_____array|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break L1;
        }
        $45 = ($42|0)>($index|0);
        if (!($45)) {
         break;
        }
       }
       $46 = (($__this) + 16|0);
       $47 = HEAP32[$46>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break L1;
       }
       __THREW__ = 0;
       $50 = (invoke_ii(1857,($_____array|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break L1;
       }
       $53 = (($50) - ($index))|0;
       $54 = ($47|0)>($53|0);
       if (!($54)) {
        $64 = (($__this) + 12|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = ($65|0)==(-1);
        if ($66) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        $67 = (($__this) + 8|0);
        $$neg = (($index) + -1)|0;
        $V_0$05 = $65;
        while(1) {
         $70 = HEAP32[$67>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($70|0));
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         $68 = ($V_0$05|0)<(0);
         if ($68) {
          label = 38;
         } else {
          $69 = (($70) + 12|0);
          $71 = HEAP32[$69>>2]|0;
          $72 = ($V_0$05>>>0)<($71>>>0);
          if (!($72)) {
           label = 38;
          }
         }
         if ((label|0) == 38) {
          label = 0;
          __THREW__ = 0;
          $73 = (invoke_i(132)|0);
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($73|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break;
          }
         }
         $78 = HEAP32[$70>>2]|0;
         $79 = (($70) + 16|0);
         $80 = (($78) + 92|0);
         $81 = HEAP32[$80>>2]|0;
         $82 = Math_imul($81, $V_0$05)|0;
         $83 = (($79) + ($82)|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = HEAP32[$46>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         }
         $88 = (($$neg) - ($V_0$05))|0;
         $89 = (($88) + ($85))|0;
         __THREW__ = 0;
         invoke_viii(534,($_____array|0),($84|0),($89|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break;
         }
         $92 = (($V_0$05) + -1)|0;
         $93 = ($V_0$05|0)==(0);
         if ($93) {
          label = 44;
          break;
         } else {
          $V_0$05 = $92;
         }
        }
        if ((label|0) == 44) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
      }
     } while(0);
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      __THREW__ = 0;
      $57 = (invoke_ii(3469,(2560072|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       __THREW__ = 0;
       invoke_vi(2583,($57|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if (!($61)) {
        __THREW__ = 0;
        invoke_vi(3833,($57|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if (!($63)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z40mscorlib_System_Collections_Stack_m_PushP33mscorlib_System_Collections_StackP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2315496);
 __THREW__ = 0;
 invoke_vi(3799,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 24|0);
   $3 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($3) + 1)|0;
    HEAP32[$2>>2] = $6;
    $7 = (($__this) + 20|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($__this) + 16|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    if ($11) {
     $14 = $8 << 1;
     __THREW__ = 0;
     invoke_vii(1826,($__this|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[$9>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = (($19) + 1)|0;
      HEAP32[$9>>2] = $22;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = (($__this) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = (($26) + 1)|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        HEAP32[$25>>2] = $27;
        $30 = (($__this) + 8|0);
        $31 = HEAP32[$30>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($31|0));
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         $34 = ($27|0)<(0);
         if ($34) {
          label = 13;
         } else {
          $35 = (($31) + 12|0);
          $36 = HEAP32[$35>>2]|0;
          $37 = ($27>>>0)<($36>>>0);
          if (!($37)) {
           label = 13;
          }
         }
         if ((label|0) == 13) {
          __THREW__ = 0;
          $38 = (invoke_i(132)|0);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($38|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($31|0),($obj|0));
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if (!($44)) {
          $45 = HEAP32[$31>>2]|0;
          $46 = (($31) + 16|0);
          $47 = (($45) + 92|0);
          $48 = HEAP32[$47>>2]|0;
          $49 = Math_imul($48, $27)|0;
          $50 = (($46) + ($49)|0);
          HEAP32[$50>>2] = $obj;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z64mscorlib_System_Collections_Stack_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2319176)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2305960)|0);
 $5 = HEAP32[((2305960 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($8,1);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318552)|0);
 $12 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2290720)|0);
 __Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String($11,$12);
 $13 = HEAP32[$3>>2]|0;
 $14 = (($13) + 8|0);
 HEAP32[$14>>2] = $11;
 STACKTOP = sp;return;
}
function __Z93mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z100mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z93mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_Diagnostics_DebuggableAttribute_m__ctorP47mscorlib_System_Diagnostics_DebuggableAttributei($__this,$modes) {
 $__this = $__this|0;
 $modes = $modes|0;
 var $$lobit = 0, $$lobit$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2317720);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = $modes;
  $3 = $modes & 1;
  $4 = (($__this) + 8|0);
  $5 = $3&255;
  HEAP8[$4>>0] = $5;
  $6 = (($__this) + 9|0);
  $$lobit = $modes >>> 8;
  $$lobit$lobit = $$lobit & 1;
  $7 = $$lobit$lobit&255;
  HEAP8[$6>>0] = $7;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z78mscorlib_System_Diagnostics_DebuggableAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,3);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Diagnostics_DebuggerDisplayAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,4509);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m__ctorP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2318688);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z87mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,108);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,13);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z46mscorlib_System_Diagnostics_StackFrame_m__ctorP38mscorlib_System_Diagnostics_StackFrameib($__this,$skipFrames,$fNeedFileInfo) {
 $__this = $__this|0;
 $skipFrames = $skipFrames|0;
 $fNeedFileInfo = $fNeedFileInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319312);
 $0 = (($__this) + 8|0);
 HEAP32[$0>>2] = -1;
 $1 = (($__this) + 12|0);
 HEAP32[$1>>2] = -1;
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 }
 $4 = (($skipFrames) + 2)|0;
 $5 = (($__this) + 16|0);
 $6 = (($__this) + 20|0);
 $7 = (($__this) + 24|0);
 $8 = (($__this) + 28|0);
 __THREW__ = 0;
 (invoke_iiiiiiiiii(7,0,($4|0),($fNeedFileInfo|0),($5|0),($0|0),($1|0),($6|0),($7|0),($8|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z55mscorlib_System_Diagnostics_StackFrame_m_get_frame_infoP22mscorlib_System_ObjectibPP37mscorlib_System_Reflection_MethodBasePiS4_PP22mscorlib_System_StringS4_S4_($__this,$skip,$needFileInfo,$method,$iloffset,$native_offset,$file,$line,$column) {
 $__this = $__this|0;
 $skip = $skip|0;
 $needFileInfo = $needFileInfo|0;
 $method = $method|0;
 $iloffset = $iloffset|0;
 $native_offset = $native_offset|0;
 $file = $file|0;
 $line = $line|0;
 $column = $column|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319360);
 $0 = HEAP32[2319408>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   __THREW__ = 0;
   $2 = (invoke_ii(3473,(2319416|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($5|0);
    // unreachable;
   } else {
    HEAP32[2319408>>2] = $2;
    $7 = $2;
    break;
   }
  } else {
   $7 = $0;
  }
 } while(0);
 __THREW__ = 0;
 $8 = (invoke_iiiiiiiii($7|0,($skip|0),($needFileInfo|0),($method|0),($iloffset|0),($native_offset|0),($file|0),($line|0),($column|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z58mscorlib_System_Diagnostics_StackFrame_m_GetFileLineNumberP38mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319592);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52mscorlib_System_Diagnostics_StackFrame_m_GetFileNameP38mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319640);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z58mscorlib_System_Diagnostics_StackFrame_m_GetSecureFileNameP38mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319688);
 __THREW__ = 0;
 invoke_v(562);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP32[3024184>>2]|0;
   $3 = (($__this) + 20|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0|0);
   if ($5) {
    $$0 = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $8 = (invoke_iii(2730,(2319640|0),($__this|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $$0 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $11 = ___cxa_find_matching_catch(348288|0)|0;
   $12 = tempRet0;
   $13 = (_llvm_eh_typeid_for((348288|0))|0);
   $14 = ($12|0)==($13|0);
   if (!($14)) {
    $$01 = $11;$$02 = $12;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$01|0);
    // unreachable;
   }
   $15 = (___cxa_begin_catch(($11|0))|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$16>>2]|0;
   __THREW__ = 0;
   $18 = (invoke_iii(2727,(2512704|0),($17|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   do {
    if (!($20)) {
     if ($18) {
      __THREW__ = 0;
      invoke_v(66);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break L1;
      } else {
       $$0 = $2;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     } else {
      $27 = (___cxa_allocate_exception(4)|0);
      $28 = HEAP32[$15>>2]|0;
      HEAP32[$27>>2] = $28;
      __THREW__ = 0;
      invoke_viii(1567,($27|0),(348288|0),(0|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     }
    }
   } while(0);
   $23 = ___cxa_find_matching_catch()|0;
   $24 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    $31 = ___cxa_find_matching_catch(0|0)|0;
    $32 = tempRet0;
    ___clang_call_terminate($31);
    // unreachable;
   } else {
    $$01 = $23;$$02 = $24;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$01|0);
    // unreachable;
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $$01 = $6;$$02 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Diagnostics_StackFrame_m_GetILOffsetP38mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319736);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z50mscorlib_System_Diagnostics_StackFrame_m_GetMethodP38mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319784);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z56mscorlib_System_Diagnostics_StackFrame_m_GetNativeOffsetP38mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319832);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z62mscorlib_System_Diagnostics_StackFrame_m_GetInternalMethodNameP38mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319880);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z49mscorlib_System_Diagnostics_StackFrame_m_ToStringP38mscorlib_System_Diagnostics_StackFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $L_22 = 0, $L_25 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_22 = sp;
 $L_25 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2319928);
 __THREW__ = 0;
 invoke_v(563);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2537888|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(2537888|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(2525,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($__this) + 16|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0|0);
      if ($11) {
       $14 = HEAP32[3024240>>2]|0;
       __THREW__ = 0;
       $15 = (invoke_iii(783,(0|0),($14|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
       __THREW__ = 0;
       (invoke_iii(989,($4|0),($15|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($10|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       __THREW__ = 0;
       $24 = (invoke_iii(2730,(2233608|0),($10|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       (invoke_iii(989,($4|0),($24|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[3024248>>2]|0;
      __THREW__ = 0;
      $32 = (invoke_iii(783,(0|0),($31|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        __THREW__ = 0;
        (invoke_iii(989,($4|0),($32|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = (($__this) + 8|0);
         $40 = HEAP32[$39>>2]|0;
         $41 = ($40|0)==(-1);
         if ($41) {
          $42 = HEAP32[3024256>>2]|0;
          __THREW__ = 0;
          $43 = (invoke_iii(783,(0|0),($42|0))|0);
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          (invoke_iii(989,($4|0),($43|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         } else {
          $50 = HEAP32[3024264>>2]|0;
          __THREW__ = 0;
          $51 = (invoke_iii(783,(0|0),($50|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          (invoke_iii(989,($4|0),($51|0))|0);
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          $58 = HEAP32[$39>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           break;
          }
          __THREW__ = 0;
          (invoke_iii(990,($4|0),($58|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           break;
          }
         }
         $63 = HEAP32[3024272>>2]|0;
         __THREW__ = 0;
         $64 = (invoke_iii(783,(0|0),($63|0))|0);
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if (!($66)) {
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if (!($68)) {
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($64|0))|0);
           $69 = __THREW__; __THREW__ = 0;
           $70 = $69&1;
           if (!($70)) {
            __THREW__ = 0;
            $71 = (invoke_ii(1969,($__this|0))|0);
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if (!($73)) {
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $74 = __THREW__; __THREW__ = 0;
             $75 = $74&1;
             if (!($75)) {
              __THREW__ = 0;
              (invoke_iii(989,($4|0),($71|0))|0);
              $76 = __THREW__; __THREW__ = 0;
              $77 = $76&1;
              if (!($77)) {
               $78 = (($__this) + 24|0);
               $79 = HEAP32[$78>>2]|0;
               HEAP32[$L_22>>2] = $79;
               __THREW__ = 0;
               (invoke_ii(2996,(2155952|0))|0);
               $80 = __THREW__; __THREW__ = 0;
               $81 = $80&1;
               if (!($81)) {
                __THREW__ = 0;
                $82 = (invoke_iii(2724,(2155952|0),($L_22|0))|0);
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if (!($84)) {
                 $85 = (($__this) + 28|0);
                 $86 = HEAP32[$85>>2]|0;
                 HEAP32[$L_25>>2] = $86;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $87 = __THREW__; __THREW__ = 0;
                 $88 = $87&1;
                 if (!($88)) {
                  __THREW__ = 0;
                  $89 = (invoke_iii(2724,(2155952|0),($L_25|0))|0);
                  $90 = __THREW__; __THREW__ = 0;
                  $91 = $90&1;
                  if (!($91)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $92 = __THREW__; __THREW__ = 0;
                   $93 = $92&1;
                   if ($93) {
                    break;
                   }
                   $94 = HEAP32[3024280>>2]|0;
                   __THREW__ = 0;
                   (invoke_iiiii(163,($4|0),($94|0),($82|0),($89|0))|0);
                   $95 = __THREW__; __THREW__ = 0;
                   $96 = $95&1;
                   if ($96) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $97 = __THREW__; __THREW__ = 0;
                   $98 = $97&1;
                   if ($98) {
                    break;
                   }
                   __THREW__ = 0;
                   $99 = (invoke_iii(2730,(2535432|0),($4|0))|0);
                   $100 = __THREW__; __THREW__ = 0;
                   $101 = $100&1;
                   if ($101) {
                    break;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($99|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvibES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$5);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker8I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS0_17VoidPointerTraitsS2_S2_S2_S2_S2_E6InvokeEPFbPvibS4_S4_S4_S4_S4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($args) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_iiiiiiiiii[$func & 15]($obj,$1,$5,$7,$9,$11,$13,$15,$17)|0);
 $19 = $18&1;
 HEAP8[$ret>>0] = $19;
 $20 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($20|0);
}
function __Z69mscorlib_System_Diagnostics_StackFrame_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2320576)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z113mscorlib_System_Diagnostics_StackTrace_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_BooleanP38mscorlib_System_Diagnostics_StackTraceib($__this,$skipFrames,$fNeedFileInfo) {
 $__this = $__this|0;
 $skipFrames = $skipFrames|0;
 $fNeedFileInfo = $fNeedFileInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2320928);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(585,($__this|0),($skipFrames|0),($fNeedFileInfo|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z52mscorlib_System_Diagnostics_StackTrace_m_init_framesP38mscorlib_System_Diagnostics_StackTraceib($__this,$skipFrames,$fNeedFileInfo) {
 $__this = $__this|0;
 $skipFrames = $skipFrames|0;
 $fNeedFileInfo = $fNeedFileInfo|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2321120);
 __THREW__ = 0;
 invoke_v(564);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($skipFrames|0)>(-1);
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3024480>>2]|0;
    $14 = HEAP32[3024488>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($10|0),($13|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($10|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2304136|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2304136|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     invoke_vi(2153,($21|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = (($skipFrames) + 2)|0;
      $$0 = $26;
      while(1) {
       __THREW__ = 0;
       (invoke_ii(2996,(2320792|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $27 = (invoke_ii(3469,(2320792|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_viii(582,($27|0),($$0|0),($fNeedFileInfo|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        label = 3;
        break;
       }
       $37 = ($27|0)==(0|0);
       if ($37) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($27|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $40 = (invoke_iii(2730,(2319784|0),($27|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 3;
        break;
       }
       $43 = ($40|0)==(0|0);
       if ($43) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($21|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       (invoke_iiii(1647,(2297624|0),($21|0),($27|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        label = 3;
        break;
       }
       $30 = (($$0) + 1)|0;
       $$0 = $30;
      }
      if ((label|0) == 3) {
       $4 = ___cxa_find_matching_catch()|0;
       $5 = tempRet0;
       $lpad$phi$index = $4;$lpad$phi$index2 = $5;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      $46 = (($__this) + 12|0);
      $47 = $fNeedFileInfo&1;
      HEAP8[$46>>0] = $47;
      HEAP32[$0>>2] = 1489264;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $48 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if (!($50)) {
       __THREW__ = 0;
       invoke_vi(3799,($21|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if (!($52)) {
        __THREW__ = 0;
        $53 = (invoke_iiii(1645,(2299256|0),($21|0),($48|0))|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if (!($55)) {
         __THREW__ = 0;
         (invoke_ii(2996,(1233464|0))|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if (!($57)) {
          __THREW__ = 0;
          $58 = (invoke_iii(2759,($53|0),(1233464|0))|0);
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if (!($60)) {
           $61 = (($__this) + 8|0);
           HEAP32[$61>>2] = $58;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $lpad$phi$index = $6;$lpad$phi$index2 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z117mscorlib_System_Diagnostics_StackTrace_m__ctor_mscorlib_System_Void_mscorlib_System_Exception_mscorlib_System_BooleanP38mscorlib_System_Diagnostics_StackTraceP25mscorlib_System_Exceptionb($__this,$e,$fNeedFileInfo) {
 $__this = $__this|0;
 $e = $e|0;
 $fNeedFileInfo = $fNeedFileInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2320976);
 __THREW__ = 0;
 invoke_viiii(154,($__this|0),($e|0),0,($fNeedFileInfo|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z139mscorlib_System_Diagnostics_StackTrace_m__ctor_mscorlib_System_Void_mscorlib_System_Exception_mscorlib_System_Int32_mscorlib_System_BooleanP38mscorlib_System_Diagnostics_StackTraceP25mscorlib_System_Exceptionib($__this,$e,$skipFrames,$fNeedFileInfo) {
 $__this = $__this|0;
 $e = $e|0;
 $skipFrames = $skipFrames|0;
 $fNeedFileInfo = $fNeedFileInfo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2321024);
 __THREW__ = 0;
 invoke_viiiii(64,($__this|0),($e|0),($skipFrames|0),($fNeedFileInfo|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z163mscorlib_System_Diagnostics_StackTrace_m__ctor_mscorlib_System_Void_mscorlib_System_Exception_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_System_BooleanP38mscorlib_System_Diagnostics_StackTraceP25mscorlib_System_Exceptionibb($__this,$e,$skipFrames,$fNeedFileInfo,$returnNativeFrames) {
 $__this = $__this|0;
 $e = $e|0;
 $skipFrames = $skipFrames|0;
 $fNeedFileInfo = $fNeedFileInfo|0;
 $returnNativeFrames = $returnNativeFrames|0;
 var $$V_0$1$off0 = 0, $$byval_copy = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$1$off0 = 0, $V_1$0 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2321072);
 __THREW__ = 0;
 invoke_v(565);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($e|0)==(0|0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560584|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     $14 = (invoke_ii(3469,(2560584|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     $17 = HEAP32[3024416>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($14|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     // unreachable;
    }
    $22 = ($skipFrames|0)>(-1);
    if (!($22)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2561352|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     $28 = HEAP32[3024424>>2]|0;
     $29 = HEAP32[3024432>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($25|0),($28|0),($29|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($25|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $34 = (invoke_iiiii(132,0,($e|0),($skipFrames|0),($fNeedFileInfo|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $37 = (($__this) + 8|0);
     HEAP32[$37>>2] = $34;
     if ($returnNativeFrames) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     } else {
      $61 = $34;$V_0$1$off0 = 0;$V_1$0 = 0;
     }
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($61|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       label = 5;
       break;
      }
      $64 = (($61) + 12|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = ($V_1$0|0)<($65|0);
      if (!($66)) {
       break;
      }
      $39 = HEAP32[$37>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($39|0));
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 5;
       break;
      }
      $38 = (($39) + 12|0);
      $40 = HEAP32[$38>>2]|0;
      $41 = ($V_1$0>>>0)<($40>>>0);
      if (!($41)) {
       __THREW__ = 0;
       $42 = (invoke_i(132)|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 5;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($42|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        label = 5;
        break;
       }
      }
      $47 = HEAP32[$39>>2]|0;
      $48 = (($39) + 16|0);
      $49 = (($47) + 92|0);
      $50 = HEAP32[$49>>2]|0;
      $51 = Math_imul($50, $V_1$0)|0;
      $52 = (($48) + ($51)|0);
      $53 = HEAP32[$52>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($53|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      $56 = (invoke_iii(2730,(2319784|0),($53|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 5;
       break;
      }
      $59 = ($56|0)==(0|0);
      $$V_0$1$off0 = $59 | $V_0$1$off0;
      $60 = (($V_1$0) + 1)|0;
      $$pre = HEAP32[$37>>2]|0;
      $61 = $$pre;$V_0$1$off0 = $$V_0$1$off0;$V_1$0 = $60;
     }
     if ((label|0) == 5) {
      $8 = ___cxa_find_matching_catch()|0;
      $9 = tempRet0;
      $lpad$phi$index = $8;$lpad$phi$index3 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     if (!($V_0$1$off0)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2304136|0))|0);
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if (!($70)) {
      __THREW__ = 0;
      $71 = (invoke_ii(3469,(2304136|0))|0);
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if (!($73)) {
       __THREW__ = 0;
       invoke_vi(2153,($71|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if (!($75)) {
        $V_3$0 = 0;
        while(1) {
         $121 = HEAP32[$37>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($121|0));
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 4;
          break;
         }
         $124 = (($121) + 12|0);
         $125 = HEAP32[$124>>2]|0;
         $126 = ($V_3$0|0)<($125|0);
         if (!($126)) {
          break;
         }
         $77 = HEAP32[$37>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($77|0));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          label = 4;
          break;
         }
         $76 = (($77) + 12|0);
         $78 = HEAP32[$76>>2]|0;
         $79 = ($V_3$0>>>0)<($78>>>0);
         if (!($79)) {
          __THREW__ = 0;
          $80 = (invoke_i(132)|0);
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           label = 4;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($80|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           label = 4;
           break;
          }
         }
         $85 = HEAP32[$77>>2]|0;
         $86 = (($77) + 16|0);
         $87 = (($85) + 92|0);
         $88 = HEAP32[$87>>2]|0;
         $89 = Math_imul($88, $V_3$0)|0;
         $90 = (($86) + ($89)|0);
         $91 = HEAP32[$90>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($91|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          label = 4;
          break;
         }
         __THREW__ = 0;
         $94 = (invoke_iii(2730,(2319784|0),($91|0))|0);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          label = 4;
          break;
         }
         $97 = ($94|0)==(0|0);
         if (!($97)) {
          $98 = HEAP32[$37>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($98|0));
          $99 = __THREW__; __THREW__ = 0;
          $100 = $99&1;
          if ($100) {
           label = 4;
           break;
          }
          $101 = (($98) + 12|0);
          $102 = HEAP32[$101>>2]|0;
          $103 = ($V_3$0>>>0)<($102>>>0);
          if (!($103)) {
           __THREW__ = 0;
           $104 = (invoke_i(132)|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($104|0));
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if ($108) {
            label = 4;
            break;
           }
          }
          $109 = HEAP32[$98>>2]|0;
          $110 = (($98) + 16|0);
          $111 = (($109) + 92|0);
          $112 = HEAP32[$111>>2]|0;
          $113 = Math_imul($112, $V_3$0)|0;
          $114 = (($110) + ($113)|0);
          $115 = HEAP32[$114>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($71|0));
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           label = 4;
           break;
          }
          __THREW__ = 0;
          (invoke_iiii(1647,(2297624|0),($71|0),($115|0))|0);
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          if ($119) {
           label = 4;
           break;
          }
         }
         $120 = (($V_3$0) + 1)|0;
         $V_3$0 = $120;
        }
        if ((label|0) == 4) {
         $6 = ___cxa_find_matching_catch()|0;
         $7 = tempRet0;
         $lpad$phi$index = $6;$lpad$phi$index3 = $7;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        HEAP32[$0>>2] = 1489264;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        $129 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if (!($131)) {
         __THREW__ = 0;
         invoke_vi(3799,($71|0));
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if (!($133)) {
          __THREW__ = 0;
          $134 = (invoke_iiii(1645,(2299256|0),($71|0),($129|0))|0);
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if (!($136)) {
           __THREW__ = 0;
           (invoke_ii(2996,(1233464|0))|0);
           $137 = __THREW__; __THREW__ = 0;
           $138 = $137&1;
           if (!($138)) {
            __THREW__ = 0;
            $139 = (invoke_iii(2759,($134|0),(1233464|0))|0);
            $140 = __THREW__; __THREW__ = 0;
            $141 = $140&1;
            if (!($141)) {
             HEAP32[$37>>2] = $139;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index3 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z50mscorlib_System_Diagnostics_StackTrace_m_get_traceP22mscorlib_System_ObjectP25mscorlib_System_Exceptionib($__this,$e,$skipFrames,$fNeedFileInfo) {
 $__this = $__this|0;
 $e = $e|0;
 $skipFrames = $skipFrames|0;
 $fNeedFileInfo = $fNeedFileInfo|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2321168);
 $0 = HEAP32[2321216>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2321224|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2321216>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($e|0),($skipFrames|0),($fNeedFileInfo|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Diagnostics_StackTrace_m_get_FrameCountP38mscorlib_System_Diagnostics_StackTrace($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2321312);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 $5 = (($1) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $G_B3_0$0 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B3_0$0|0);
}
function __Z49mscorlib_System_Diagnostics_StackTrace_m_GetFrameP38mscorlib_System_Diagnostics_StackTracei($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2321360);
 $0 = ($index|0)<(0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iii(2729,(2321312|0),($__this|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($1|0)>($index|0);
   if (!($4)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $7 = (($__this) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($8|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($8) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12>>>0)>($index>>>0);
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_i(132)|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($14|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
    }
    $19 = HEAP32[$8>>2]|0;
    $20 = (($8) + 16|0);
    $21 = (($19) + 92|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = Math_imul($22, $index)|0;
    $24 = (($20) + ($23)|0);
    $25 = HEAP32[$24>>2]|0;
    $$0 = $25;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Diagnostics_StackTrace_m_ToStringP38mscorlib_System_Diagnostics_StackTrace($__this) {
 $__this = $__this|0;
 var $$sum = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_49 = 0, $V_4$0 = 0, $V_8$0 = 0, $V_9$0$in = 0;
 var $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_49 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2321408);
 __THREW__ = 0;
 invoke_v(566);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(2441,(0|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP32[3024512>>2]|0;
    __THREW__ = 0;
    $6 = (invoke_iii(783,(0|0),($5|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[3024504>>2]|0;
     __THREW__ = 0;
     $10 = (invoke_iiiii(98,(0|0),($9|0),($2|0),($6|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = HEAP32[3024520>>2]|0;
      __THREW__ = 0;
      $14 = (invoke_iii(783,(0|0),($13|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = HEAP32[3024528>>2]|0;
       __THREW__ = 0;
       $18 = (invoke_iii(783,(0|0),($17|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2537888|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         $23 = (invoke_ii(3469,(2537888|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          invoke_vi(2525,($23|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           $28 = (($__this) + 12|0);
           $V_4$0 = 0;
           L11: while(1) {
            __THREW__ = 0;
            $243 = (invoke_iii(2729,(2321312|0),($__this|0))|0);
            $244 = __THREW__; __THREW__ = 0;
            $245 = $244&1;
            if ($245) {
             label = 12;
             break;
            }
            $246 = ($V_4$0|0)<($243|0);
            if (!($246)) {
             label = 107;
             break;
            }
            __THREW__ = 0;
            $49 = (invoke_iiii(1642,(2321360|0),($__this|0),($V_4$0|0))|0);
            $247 = __THREW__; __THREW__ = 0;
            $248 = $247&1;
            if ($248) {
             label = 12;
             break;
            }
            $35 = ($V_4$0|0)<(1);
            if ($35) {
             $40 = HEAP32[3024544>>2]|0;
             __THREW__ = 0;
             $41 = (invoke_iii(783,(0|0),($40|0))|0);
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($23|0));
             $44 = __THREW__; __THREW__ = 0;
             $45 = $44&1;
             if ($45) {
              label = 12;
              break;
             }
             $46 = HEAP32[3024536>>2]|0;
             __THREW__ = 0;
             (invoke_iiii(934,($23|0),($46|0),($41|0))|0);
             $47 = __THREW__; __THREW__ = 0;
             $48 = $47&1;
             if ($48) {
              label = 12;
              break;
             }
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($23|0));
             $36 = __THREW__; __THREW__ = 0;
             $37 = $36&1;
             if ($37) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             (invoke_iii(989,($23|0),($10|0))|0);
             $38 = __THREW__; __THREW__ = 0;
             $39 = $38&1;
             if ($39) {
              label = 12;
              break;
             }
            }
            __THREW__ = 0;
            invoke_vi(3799,($49|0));
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if ($51) {
             label = 12;
             break;
            }
            __THREW__ = 0;
            $52 = (invoke_iii(2730,(2319784|0),($49|0))|0);
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             label = 12;
             break;
            }
            $55 = ($52|0)==(0|0);
            if ($55) {
             __THREW__ = 0;
             invoke_vi(3799,($23|0));
             $213 = __THREW__; __THREW__ = 0;
             $214 = $213&1;
             if ($214) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             (invoke_iii(989,($23|0),($14|0))|0);
             $215 = __THREW__; __THREW__ = 0;
             $216 = $215&1;
             if ($216) {
              label = 12;
              break;
             }
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($52|0));
             $56 = __THREW__; __THREW__ = 0;
             $57 = $56&1;
             if ($57) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             $58 = (invoke_iii(2730,(2242504|0),($52|0))|0);
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($58|0));
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             $63 = (invoke_iii(2730,(2150320|0),($58|0))|0);
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if ($65) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($52|0));
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if ($67) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             $68 = (invoke_iii(2730,(2233608|0),($52|0))|0);
             $69 = __THREW__; __THREW__ = 0;
             $70 = $69&1;
             if ($70) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($23|0));
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if ($72) {
              label = 12;
              break;
             }
             $73 = HEAP32[3024552>>2]|0;
             __THREW__ = 0;
             (invoke_iiiii(163,($23|0),($73|0),($63|0),($68|0))|0);
             $74 = __THREW__; __THREW__ = 0;
             $75 = $74&1;
             if ($75) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($23|0));
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 12;
              break;
             }
             $78 = HEAP32[3024560>>2]|0;
             __THREW__ = 0;
             (invoke_iii(989,($23|0),($78|0))|0);
             $79 = __THREW__; __THREW__ = 0;
             $80 = $79&1;
             if ($80) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($52|0));
             $81 = __THREW__; __THREW__ = 0;
             $82 = $81&1;
             if ($82) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             $83 = (invoke_iii(2730,(2397136|0),($52|0))|0);
             $84 = __THREW__; __THREW__ = 0;
             $85 = $84&1;
             if ($85) {
              label = 12;
              break;
             }
             $86 = (($83) + 12|0);
             $V_8$0 = 0;
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($83|0));
              $203 = __THREW__; __THREW__ = 0;
              $204 = $203&1;
              if ($204) {
               label = 11;
               break L11;
              }
              $205 = HEAP32[$86>>2]|0;
              $206 = ($V_8$0|0)<($205|0);
              if (!($206)) {
               break;
              }
              $207 = ($V_8$0|0)<(1);
              if (!($207)) {
               __THREW__ = 0;
               invoke_vi(3799,($23|0));
               $87 = __THREW__; __THREW__ = 0;
               $88 = $87&1;
               if ($88) {
                label = 11;
                break L11;
               }
               $89 = HEAP32[3024568>>2]|0;
               __THREW__ = 0;
               (invoke_iii(989,($23|0),($89|0))|0);
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if ($91) {
                label = 11;
                break L11;
               }
              }
              __THREW__ = 0;
              invoke_vi(3799,($83|0));
              $92 = __THREW__; __THREW__ = 0;
              $93 = $92&1;
              if ($93) {
               label = 11;
               break L11;
              }
              $94 = HEAP32[$86>>2]|0;
              $95 = ($V_8$0>>>0)<($94>>>0);
              if (!($95)) {
               __THREW__ = 0;
               $96 = (invoke_i(132)|0);
               $97 = __THREW__; __THREW__ = 0;
               $98 = $97&1;
               if ($98) {
                label = 11;
                break L11;
               }
               __THREW__ = 0;
               invoke_vi(3302,($96|0));
               $99 = __THREW__; __THREW__ = 0;
               $100 = $99&1;
               if ($100) {
                label = 11;
                break L11;
               }
              }
              $101 = HEAP32[$83>>2]|0;
              $102 = (($101) + 92|0);
              $103 = HEAP32[$102>>2]|0;
              $104 = Math_imul($103, $V_8$0)|0;
              $$sum = (($104) + 16)|0;
              $105 = (($83) + ($$sum)|0);
              $106 = HEAP32[$105>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($106|0));
              $107 = __THREW__; __THREW__ = 0;
              $108 = $107&1;
              if ($108) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              $109 = (invoke_iii(2730,(2397472|0),($106|0))|0);
              $110 = __THREW__; __THREW__ = 0;
              $111 = $110&1;
              if ($111) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              invoke_vi(3799,($109|0));
              $112 = __THREW__; __THREW__ = 0;
              $113 = $112&1;
              if ($113) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              $114 = (invoke_iii(2734,(2234040|0),($109|0))|0);
              $115 = __THREW__; __THREW__ = 0;
              $116 = $115&1;
              if ($116) {
               label = 11;
               break L11;
              }
              if ($114) {
               __THREW__ = 0;
               invoke_vi(3799,($109|0));
               $117 = __THREW__; __THREW__ = 0;
               $118 = $117&1;
               if ($118) {
                label = 11;
                break L11;
               }
               __THREW__ = 0;
               $119 = (invoke_iii(2730,(2224328|0),($109|0))|0);
               $120 = __THREW__; __THREW__ = 0;
               $121 = $120&1;
               if ($121) {
                label = 11;
                break L11;
               } else {
                $V_9$0$in = $119;
               }
              } else {
               $V_9$0$in = $109;
              }
              __THREW__ = 0;
              invoke_vi(3799,($V_9$0$in|0));
              $122 = __THREW__; __THREW__ = 0;
              $123 = $122&1;
              if ($123) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              $124 = (invoke_iii(2734,(2234136|0),($V_9$0$in|0))|0);
              $125 = __THREW__; __THREW__ = 0;
              $126 = $125&1;
              if ($126) {
               label = 11;
               break L11;
              }
              do {
               if ($124) {
                __THREW__ = 0;
                invoke_vi(3799,($V_9$0$in|0));
                $127 = __THREW__; __THREW__ = 0;
                $128 = $127&1;
                if ($128) {
                 label = 11;
                 break L11;
                }
                __THREW__ = 0;
                $129 = (invoke_iii(2730,(2238840|0),($V_9$0$in|0))|0);
                $130 = __THREW__; __THREW__ = 0;
                $131 = $130&1;
                if ($131) {
                 label = 11;
                 break L11;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $132 = __THREW__; __THREW__ = 0;
                $133 = $132&1;
                if ($133) {
                 label = 11;
                 break L11;
                }
                $134 = HEAP8[((2191608 + 116|0))>>0]|0;
                $135 = ($134<<24>>24)==(0);
                if ($135) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $136 = __THREW__; __THREW__ = 0;
                 $137 = $136&1;
                 if ($137) {
                  label = 11;
                  break L11;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $138 = __THREW__; __THREW__ = 0;
                 $139 = $138&1;
                 if ($139) {
                  label = 11;
                  break L11;
                 }
                 __THREW__ = 0;
                 invoke_vi(3832,(2191608|0));
                 $140 = __THREW__; __THREW__ = 0;
                 $141 = $140&1;
                 if ($141) {
                  label = 11;
                  break L11;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $142 = __THREW__; __THREW__ = 0;
                $143 = $142&1;
                if ($143) {
                 label = 11;
                 break L11;
                }
                $144 = HEAP32[((2191608 + 80|0))>>2]|0;
                $145 = HEAP32[$144>>2]|0;
                __THREW__ = 0;
                $146 = (invoke_iiii(575,(0|0),($129|0),($145|0))|0);
                $147 = __THREW__; __THREW__ = 0;
                $148 = $147&1;
                if ($148) {
                 label = 11;
                 break L11;
                }
                if (!($146)) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($V_9$0$in|0));
                $149 = __THREW__; __THREW__ = 0;
                $150 = $149&1;
                if ($150) {
                 label = 11;
                 break L11;
                }
                __THREW__ = 0;
                $151 = (invoke_iii(2730,(2238840|0),($V_9$0$in|0))|0);
                $152 = __THREW__; __THREW__ = 0;
                $153 = $152&1;
                if ($153) {
                 label = 11;
                 break L11;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $154 = __THREW__; __THREW__ = 0;
                $155 = $154&1;
                if ($155) {
                 label = 11;
                 break L11;
                }
                __THREW__ = 0;
                (invoke_iii(989,($23|0),($151|0))|0);
                $156 = __THREW__; __THREW__ = 0;
                $157 = $156&1;
                if ($157) {
                 label = 11;
                 break L11;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $158 = __THREW__; __THREW__ = 0;
                $159 = $158&1;
                if ($159) {
                 label = 11;
                 break L11;
                }
                $160 = HEAP32[3024576>>2]|0;
                __THREW__ = 0;
                (invoke_iii(989,($23|0),($160|0))|0);
                $161 = __THREW__; __THREW__ = 0;
                $162 = $161&1;
                if ($162) {
                 label = 11;
                 break L11;
                }
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($V_9$0$in|0));
              $163 = __THREW__; __THREW__ = 0;
              $164 = $163&1;
              if ($164) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              $165 = (invoke_iii(2730,(2233608|0),($V_9$0$in|0))|0);
              $166 = __THREW__; __THREW__ = 0;
              $167 = $166&1;
              if ($167) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              invoke_vi(3799,($23|0));
              $168 = __THREW__; __THREW__ = 0;
              $169 = $168&1;
              if ($169) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              (invoke_iii(989,($23|0),($165|0))|0);
              $170 = __THREW__; __THREW__ = 0;
              $171 = $170&1;
              if ($171) {
               label = 11;
               break L11;
              }
              if ($114) {
               __THREW__ = 0;
               invoke_vi(3799,($23|0));
               $172 = __THREW__; __THREW__ = 0;
               $173 = $172&1;
               if ($173) {
                label = 11;
                break L11;
               }
               $174 = HEAP32[3024584>>2]|0;
               __THREW__ = 0;
               (invoke_iii(989,($23|0),($174|0))|0);
               $175 = __THREW__; __THREW__ = 0;
               $176 = $175&1;
               if ($176) {
                label = 11;
                break L11;
               }
              }
              __THREW__ = 0;
              invoke_vi(3799,($83|0));
              $177 = __THREW__; __THREW__ = 0;
              $178 = $177&1;
              if ($178) {
               label = 11;
               break L11;
              }
              $179 = HEAP32[$86>>2]|0;
              $180 = ($V_8$0>>>0)<($179>>>0);
              if (!($180)) {
               __THREW__ = 0;
               $181 = (invoke_i(132)|0);
               $182 = __THREW__; __THREW__ = 0;
               $183 = $182&1;
               if ($183) {
                label = 11;
                break L11;
               }
               __THREW__ = 0;
               invoke_vi(3302,($181|0));
               $184 = __THREW__; __THREW__ = 0;
               $185 = $184&1;
               if ($185) {
                label = 11;
                break L11;
               }
              }
              $186 = HEAP32[$83>>2]|0;
              $187 = (($186) + 92|0);
              $188 = HEAP32[$187>>2]|0;
              $189 = Math_imul($188, $V_8$0)|0;
              $$sum6 = (($189) + 16)|0;
              $190 = (($83) + ($$sum6)|0);
              $191 = HEAP32[$190>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($191|0));
              $192 = __THREW__; __THREW__ = 0;
              $193 = $192&1;
              if ($193) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              $194 = (invoke_iii(2730,(2397184|0),($191|0))|0);
              $195 = __THREW__; __THREW__ = 0;
              $196 = $195&1;
              if ($196) {
               label = 11;
               break L11;
              }
              __THREW__ = 0;
              invoke_vi(3799,($23|0));
              $197 = __THREW__; __THREW__ = 0;
              $198 = $197&1;
              if ($198) {
               label = 11;
               break L11;
              }
              $199 = HEAP32[3024592>>2]|0;
              __THREW__ = 0;
              (invoke_iiii(934,($23|0),($199|0),($194|0))|0);
              $200 = __THREW__; __THREW__ = 0;
              $201 = $200&1;
              if ($201) {
               label = 11;
               break L11;
              }
              $202 = (($V_8$0) + 1)|0;
              $V_8$0 = $202;
             }
             __THREW__ = 0;
             invoke_vi(3799,($23|0));
             $208 = __THREW__; __THREW__ = 0;
             $209 = $208&1;
             if ($209) {
              label = 12;
              break;
             }
             $210 = HEAP32[3024600>>2]|0;
             __THREW__ = 0;
             (invoke_iii(989,($23|0),($210|0))|0);
             $211 = __THREW__; __THREW__ = 0;
             $212 = $211&1;
             if ($212) {
              label = 12;
              break;
             }
            }
            $217 = HEAP8[$28>>0]|0;
            $218 = ($217<<24>>24)==(0);
            do {
             if (!($218)) {
              __THREW__ = 0;
              invoke_vi(3799,($49|0));
              $219 = __THREW__; __THREW__ = 0;
              $220 = $219&1;
              if ($220) {
               label = 12;
               break L11;
              }
              __THREW__ = 0;
              $221 = (invoke_ii(1969,($49|0))|0);
              $222 = __THREW__; __THREW__ = 0;
              $223 = $222&1;
              if ($223) {
               label = 12;
               break L11;
              }
              $224 = HEAP32[3024608>>2]|0;
              __THREW__ = 0;
              $225 = (invoke_iiii(575,(0|0),($221|0),($224|0))|0);
              $226 = __THREW__; __THREW__ = 0;
              $227 = $226&1;
              if ($227) {
               label = 12;
               break L11;
              }
              if (!($225)) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($49|0));
              $228 = __THREW__; __THREW__ = 0;
              $229 = $228&1;
              if ($229) {
               label = 12;
               break L11;
              }
              __THREW__ = 0;
              $230 = (invoke_iii(2729,(2319592|0),($49|0))|0);
              $231 = __THREW__; __THREW__ = 0;
              $232 = $231&1;
              if ($232) {
               label = 12;
               break L11;
              }
              HEAP32[$L_49>>2] = $230;
              __THREW__ = 0;
              (invoke_ii(2996,(2155952|0))|0);
              $233 = __THREW__; __THREW__ = 0;
              $234 = $233&1;
              if ($234) {
               label = 12;
               break L11;
              }
              __THREW__ = 0;
              $235 = (invoke_iii(2724,(2155952|0),($L_49|0))|0);
              $236 = __THREW__; __THREW__ = 0;
              $237 = $236&1;
              if ($237) {
               label = 12;
               break L11;
              }
              __THREW__ = 0;
              invoke_vi(3799,($23|0));
              $238 = __THREW__; __THREW__ = 0;
              $239 = $238&1;
              if ($239) {
               label = 12;
               break L11;
              }
              __THREW__ = 0;
              (invoke_iiiii(163,($23|0),($18|0),($221|0),($235|0))|0);
              $240 = __THREW__; __THREW__ = 0;
              $241 = $240&1;
              if ($241) {
               label = 12;
               break L11;
              }
             }
            } while(0);
            $242 = (($V_4$0) + 1)|0;
            $V_4$0 = $242;
           }
           if ((label|0) == 11) {
            $29 = ___cxa_find_matching_catch()|0;
            $30 = tempRet0;
            $lpad$phi$index = $29;$lpad$phi$index3 = $30;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           else if ((label|0) == 12) {
            $31 = ___cxa_find_matching_catch()|0;
            $32 = tempRet0;
            $lpad$phi$index = $31;$lpad$phi$index3 = $32;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           else if ((label|0) == 107) {
            __THREW__ = 0;
            invoke_vi(3799,($23|0));
            $249 = __THREW__; __THREW__ = 0;
            $250 = $249&1;
            if ($250) {
             break;
            }
            __THREW__ = 0;
            $251 = (invoke_iii(2730,(2535432|0),($23|0))|0);
            $252 = __THREW__; __THREW__ = 0;
            $253 = $252&1;
            if ($253) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($251|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 $lpad$phi$index = $33;$lpad$phi$index3 = $34;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker3I17VoidPointerTraits27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS4_ibES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$3,$7);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I17VoidPointerTraits27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsS2_E6InvokeEPFvPvS4_ibbES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$3,$7,$11);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_S4_ibES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z69mscorlib_System_Diagnostics_StackTrace_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2321848)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z46mscorlib_System_Globalization_Calendar_m__ctorP38mscorlib_System_Globalization_Calendar($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2322160);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = 99;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_Globalization_Calendar_m_CheckReadOnlyP38mscorlib_System_Globalization_Calendar($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2322208);
 __THREW__ = 0;
 invoke_v(567);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if ($4) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2607872|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_ii(3469,(2607872|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[3024832>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3833,($9|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      // unreachable;
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z53mscorlib_System_Globalization_Calendar_m_get_EraNamesP38mscorlib_System_Globalization_Calendar($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2322256);
 __THREW__ = 0;
 invoke_v(568);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 20|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    $9 = (($3) + 12|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    $11 = (invoke_iii(2730,(2322304|0),($__this|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = (($11) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($10|0)==($17|0);
    if ($18) {
     $29 = HEAP32[$2>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($29|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     $32 = (invoke_iii(2756,(2224152|0),($29|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1168432|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     __THREW__ = 0;
     $37 = (invoke_iii(2759,($32|0),(1168432|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($37|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2246120|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2246120|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[3024736>>2]|0;
     __THREW__ = 0;
     invoke_vii(1781,($21|0),($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      __THREW__ = 0;
      invoke_vi(3833,($21|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Globalization_Calendar_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z42mscorlib_System_Globalization_CCMath_m_divP22mscorlib_System_Objectii($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2323264);
 $0 = (+($x|0));
 $1 = (+($y|0));
 $2 = $0 / $1;
 $3 = (+Math_floor((+$2)));
 $4 = (~~(($3)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($4|0);
}
function __Z42mscorlib_System_Globalization_CCMath_m_modP22mscorlib_System_Objectii($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2323312);
 __THREW__ = 0;
 $0 = (invoke_iiii(805,0,($x|0),($y|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = Math_imul($0, $y)|0;
  $4 = (($x) - ($3))|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z46mscorlib_System_Globalization_CCMath_m_div_modP22mscorlib_System_ObjectPiii($__this,$remainder,$x,$y) {
 $__this = $__this|0;
 $remainder = $remainder|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2323360);
 __THREW__ = 0;
 $0 = (invoke_iiii(805,0,($x|0),($y|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = Math_imul($0, $y)|0;
  $4 = (($x) - ($3))|0;
  HEAP32[$remainder>>2] = $4;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Globalization_CCFixed_m_FromDateTimeP22mscorlib_System_Object24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2323704);
 __THREW__ = 0;
 $0 = (invoke_ii(2432,($time|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $4 = (___divdi3(($0|0),($1|0),711573504,201)|0);
  $5 = tempRet0;
  $6 = (($4) + 1)|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Globalization_CCFixed_m_day_of_weekP22mscorlib_System_Objecti($__this,$date) {
 $__this = $__this|0;
 $date = $date|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2323752);
 __THREW__ = 0;
 $0 = (invoke_iiii(806,0,($date|0),7)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z64mscorlib_System_Globalization_CCGregorianCalendar_m_is_leap_yearP22mscorlib_System_Objecti($__this,$year) {
 $__this = $__this|0;
 $year = $year|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324048);
 __THREW__ = 0;
 $0 = (invoke_iiii(806,0,($year|0),4)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($0|0)==(0);
   if ($3) {
    __THREW__ = 0;
    $6 = (invoke_iiii(806,0,($year|0),400)|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    if ((($6|0) == 300) | (($6|0) == 200) | (($6|0) == 100)) {
     $$0 = 0;
    } else {
     $$0 = 1;
    }
   } else {
    $$0 = 0;
   }
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Globalization_CCGregorianCalendar_m_fixed_from_dmyP22mscorlib_System_Objectiii($__this,$day,$month,$year) {
 $__this = $__this|0;
 $day = $day|0;
 $month = $month|0;
 $year = $year|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324096);
 $0 = (($year) + -1)|0;
 __THREW__ = 0;
 $1 = (invoke_iiii(805,0,($0|0),4)|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(805,0,($0|0),100)|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iiii(805,0,($0|0),400)|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = ($month*367)|0;
    $11 = (($10) + -362)|0;
    __THREW__ = 0;
    $12 = (invoke_iiii(805,0,($11|0),12)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = ($0*365)|0;
     $16 = (($1) + ($15))|0;
     $17 = (($16) - ($4))|0;
     $18 = (($17) + ($7))|0;
     $19 = (($18) + ($12))|0;
     $20 = ($month|0)<(3);
     if ($20) {
      $V_0$0 = $19;
      $27 = (($V_0$0) + ($day))|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($27|0);
     }
     __THREW__ = 0;
     $23 = (invoke_iii(839,0,($year|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $$ = $23 ? -1 : -2;
      $26 = (($$) + ($19))|0;
      $V_0$0 = $26;
      $27 = (($V_0$0) + ($day))|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($27|0);
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Globalization_CCGregorianCalendar_m_year_from_fixedP22mscorlib_System_Objecti($__this,$date) {
 $__this = $__this|0;
 $date = $date|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B4_0$0 = 0, $V_0 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324144);
 $0 = (($date) + -1)|0;
 HEAP32[$V_0>>2] = $0;
 __THREW__ = 0;
 $1 = (invoke_iiiii(133,0,($V_0|0),($0|0),146097)|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = HEAP32[$V_0>>2]|0;
  __THREW__ = 0;
  $5 = (invoke_iiiii(133,0,($V_0|0),($4|0),36524)|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = HEAP32[$V_0>>2]|0;
   __THREW__ = 0;
   $9 = (invoke_iiiii(133,0,($V_0|0),($8|0),1461)|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[$V_0>>2]|0;
    __THREW__ = 0;
    $13 = (invoke_iiii(805,0,($12|0),365)|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = ($1*400)|0;
     $17 = ($5*100)|0;
     $18 = (($17) + ($16))|0;
     $19 = $9 << 2;
     $20 = (($18) + ($19))|0;
     $21 = (($20) + ($13))|0;
     $22 = ($5|0)==(4);
     $23 = ($13|0)==(4);
     $or$cond = $22 | $23;
     $24 = $or$cond&1;
     $25 = $24 ^ 1;
     $G_B4_0$0 = (($21) + ($25))|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B4_0$0|0);
    }
   }
  }
 }
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($26|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Globalization_CCGregorianCalendar_m_my_from_fixedP22mscorlib_System_ObjectPiS1_i($__this,$month,$year,$date) {
 $__this = $__this|0;
 $month = $month|0;
 $year = $year|0;
 $date = $date|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324192);
 __THREW__ = 0;
 $0 = (invoke_iii(840,0,($date|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   HEAP32[$year>>2] = $0;
   __THREW__ = 0;
   $3 = (invoke_iiiii(134,0,1,1,($0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($date) - ($3))|0;
    $7 = HEAP32[$year>>2]|0;
    __THREW__ = 0;
    $8 = (invoke_iiiii(134,0,1,3,($7|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = ($8|0)>($date|0);
     if ($11) {
      $V_1$0 = 0;
     } else {
      $14 = HEAP32[$year>>2]|0;
      __THREW__ = 0;
      $15 = (invoke_iii(839,0,($14|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      $$ = $15 ? 1 : 2;
      $V_1$0 = $$;
     }
     $18 = (($6) + ($V_1$0))|0;
     $19 = ($18*12)|0;
     $20 = (($19) + 373)|0;
     __THREW__ = 0;
     $21 = (invoke_iiii(805,0,($20|0),367)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      HEAP32[$month>>2] = $21;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z66mscorlib_System_Globalization_CCGregorianCalendar_m_dmy_from_fixedP22mscorlib_System_ObjectPiS1_S1_i($__this,$day,$month,$year,$date) {
 $__this = $__this|0;
 $day = $day|0;
 $month = $month|0;
 $year = $year|0;
 $date = $date|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324240);
 __THREW__ = 0;
 invoke_viiii(155,0,($month|0),($year|0),($date|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$month>>2]|0;
  $3 = HEAP32[$year>>2]|0;
  __THREW__ = 0;
  $4 = (invoke_iiiii(134,0,1,($2|0),($3|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($date) + 1)|0;
   $8 = (($7) - ($4))|0;
   HEAP32[$day>>2] = $8;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z68mscorlib_System_Globalization_CCGregorianCalendar_m_month_from_fixedP22mscorlib_System_Objecti($__this,$date) {
 $__this = $__this|0;
 $date = $date|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324288);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 invoke_viiii(155,0,($V_0|0),($V_1|0),($date|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP32[$V_0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z66mscorlib_System_Globalization_CCGregorianCalendar_m_day_from_fixedP22mscorlib_System_Objecti($__this,$date) {
 $__this = $__this|0;
 $date = $date|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 $V_2 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324336);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_viiiii(65,0,($V_0|0),($V_1|0),($V_2|0),($date|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP32[$V_0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z65mscorlib_System_Globalization_CCGregorianCalendar_m_GetDayOfMonthP22mscorlib_System_Object24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $time$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324384);
 __THREW__ = 0;
 ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
 $0 = (invoke_iii(837,0,($time$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 __THREW__ = 0;
 $3 = (invoke_iii(842,0,($0|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z60mscorlib_System_Globalization_CCGregorianCalendar_m_GetMonthP22mscorlib_System_Object24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $time$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324432);
 __THREW__ = 0;
 ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
 $0 = (invoke_iii(837,0,($time$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 __THREW__ = 0;
 $3 = (invoke_iii(841,0,($0|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z59mscorlib_System_Globalization_CCGregorianCalendar_m_GetYearP22mscorlib_System_Object24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $time$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2324480);
 __THREW__ = 0;
 ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
 $0 = (invoke_iii(837,0,($time$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 __THREW__ = 0;
 $3 = (invoke_iii(840,0,($0|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker4I17VoidPointerTraitsS0_S0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvS3_S3_S3_iES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$2,$4,$7);
 STACKTOP = sp;return (0|0);
}
function __Z49mscorlib_System_Globalization_CompareInfo_m__ctorP41mscorlib_System_Globalization_CompareInfoP41mscorlib_System_Globalization_CultureInfo($__this,$ci) {
 $__this = $__this|0;
 $ci = $ci|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $L_15 = 0, $L_7 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_7 = sp;
 $L_15 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2325120);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($ci|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2729,(2273552|0),($ci|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($__this) + 8|0);
     HEAP32[$7>>2] = $4;
     __THREW__ = 0;
     $8 = (invoke_ii(1978,0)|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      if (!($8)) {
       __THREW__ = 0;
       invoke_vi(3799,($ci|0));
       $153 = __THREW__; __THREW__ = 0;
       $154 = $153&1;
       if ($154) {
        break;
       }
       __THREW__ = 0;
       $155 = (invoke_ii(1983,($ci|0))|0);
       $156 = __THREW__; __THREW__ = 0;
       $157 = $156&1;
       if ($157) {
        break;
       }
       $158 = (($__this) + 12|0);
       HEAP32[$158>>2] = $155;
       __THREW__ = 0;
       invoke_vii(1833,($__this|0),($155|0));
       $159 = __THREW__; __THREW__ = 0;
       $160 = $159&1;
       if ($160) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2328760|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = HEAP8[((2328760 + 116|0))>>0]|0;
       $16 = ($15<<24>>24)==(0);
       if ($16) {
        __THREW__ = 0;
        (invoke_ii(2996,(2328760|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if ($18) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2328760|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3832,(2328760|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if ($22) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2328760|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $25 = HEAP32[((2328760 + 80|0))>>2]|0;
        $26 = (($25) + 8|0);
        $27 = HEAP32[$26>>2]|0;
        __THREW__ = 0;
        invoke_vii(1916,(0|0),($27|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if (!($29)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2328760|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         do {
          if ($31) {
           label = 19;
          } else {
           $32 = HEAP8[((2328760 + 116|0))>>0]|0;
           $33 = ($32<<24>>24)==(0);
           if ($33) {
            __THREW__ = 0;
            (invoke_ii(2996,(2328760|0))|0);
            $34 = __THREW__; __THREW__ = 0;
            $35 = $34&1;
            if ($35) {
             label = 19;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2328760|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if ($37) {
             label = 19;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3832,(2328760|0));
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             label = 19;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2328760|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            label = 19;
           } else {
            $50 = HEAP32[((2328760 + 80|0))>>2]|0;
            $51 = (($50) + 4|0);
            $52 = HEAP32[$51>>2]|0;
            $53 = ($52|0)==(0|0);
            if ($53) {
             __THREW__ = 0;
             (invoke_ii(2996,(2313960|0))|0);
             $54 = __THREW__; __THREW__ = 0;
             $55 = $54&1;
             if ($55) {
              label = 19;
              break;
             }
             __THREW__ = 0;
             $56 = (invoke_ii(3469,(2313960|0))|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              label = 19;
              break;
             }
             __THREW__ = 0;
             invoke_vi(2173,($56|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              label = 19;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2328760|0))|0);
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              label = 19;
              break;
             }
             $63 = HEAP8[((2328760 + 116|0))>>0]|0;
             $64 = ($63<<24>>24)==(0);
             if ($64) {
              __THREW__ = 0;
              (invoke_ii(2996,(2328760|0))|0);
              $65 = __THREW__; __THREW__ = 0;
              $66 = $65&1;
              if ($66) {
               label = 19;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2328760|0))|0);
              $67 = __THREW__; __THREW__ = 0;
              $68 = $67&1;
              if ($68) {
               label = 19;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3832,(2328760|0));
              $69 = __THREW__; __THREW__ = 0;
              $70 = $69&1;
              if ($70) {
               label = 19;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2328760|0))|0);
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if ($72) {
              label = 19;
              break;
             }
             $73 = HEAP32[((2328760 + 80|0))>>2]|0;
             $74 = (($73) + 4|0);
             HEAP32[$74>>2] = $56;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2328760|0))|0);
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             label = 19;
            } else {
             $77 = HEAP8[((2328760 + 116|0))>>0]|0;
             $78 = ($77<<24>>24)==(0);
             if ($78) {
              __THREW__ = 0;
              (invoke_ii(2996,(2328760|0))|0);
              $79 = __THREW__; __THREW__ = 0;
              $80 = $79&1;
              if ($80) {
               label = 19;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2328760|0))|0);
              $81 = __THREW__; __THREW__ = 0;
              $82 = $81&1;
              if ($82) {
               label = 19;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3832,(2328760|0));
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if ($84) {
               label = 19;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2328760|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if ($86) {
              label = 19;
             } else {
              $87 = HEAP32[((2328760 + 80|0))>>2]|0;
              $88 = (($87) + 4|0);
              $89 = HEAP32[$88>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($ci|0));
              $90 = __THREW__; __THREW__ = 0;
              $91 = $90&1;
              if ($91) {
               label = 19;
              } else {
               __THREW__ = 0;
               $92 = (invoke_iii(2729,(2273552|0),($ci|0))|0);
               $93 = __THREW__; __THREW__ = 0;
               $94 = $93&1;
               if ($94) {
                label = 19;
               } else {
                HEAP32[$L_7>>2] = $92;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $95 = __THREW__; __THREW__ = 0;
                $96 = $95&1;
                if ($96) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                $97 = (invoke_iii(2724,(2155952|0),($L_7|0))|0);
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($89|0));
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if ($101) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                $102 = (invoke_iiii(1643,(2310848|0),($89|0),($97|0))|0);
                $103 = __THREW__; __THREW__ = 0;
                $104 = $103&1;
                if ($104) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2280704|0))|0);
                $105 = __THREW__; __THREW__ = 0;
                $106 = $105&1;
                if ($106) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                $107 = (invoke_iii(2759,($102|0),(2280704|0))|0);
                $108 = __THREW__; __THREW__ = 0;
                $109 = $108&1;
                if ($109) {
                 label = 19;
                 break;
                }
                $110 = (($__this) + 16|0);
                HEAP32[$110>>2] = $107;
                $111 = ($107|0)==(0|0);
                if (!($111)) {
                 $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 145;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2280704|0))|0);
                $112 = __THREW__; __THREW__ = 0;
                $113 = $112&1;
                if ($113) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                $114 = (invoke_ii(3469,(2280704|0))|0);
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if ($116) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                invoke_vii(1796,($114|0),($ci|0));
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 label = 19;
                 break;
                }
                HEAP32[$110>>2] = $114;
                __THREW__ = 0;
                (invoke_ii(2996,(2328760|0))|0);
                $119 = __THREW__; __THREW__ = 0;
                $120 = $119&1;
                if ($120) {
                 label = 19;
                 break;
                }
                $121 = HEAP8[((2328760 + 116|0))>>0]|0;
                $122 = ($121<<24>>24)==(0);
                if ($122) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2328760|0))|0);
                 $123 = __THREW__; __THREW__ = 0;
                 $124 = $123&1;
                 if ($124) {
                  label = 19;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2328760|0))|0);
                 $125 = __THREW__; __THREW__ = 0;
                 $126 = $125&1;
                 if ($126) {
                  label = 19;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3832,(2328760|0));
                 $127 = __THREW__; __THREW__ = 0;
                 $128 = $127&1;
                 if ($128) {
                  label = 19;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2328760|0))|0);
                $129 = __THREW__; __THREW__ = 0;
                $130 = $129&1;
                if ($130) {
                 label = 19;
                 break;
                }
                $131 = HEAP32[((2328760 + 80|0))>>2]|0;
                $132 = (($131) + 4|0);
                $133 = HEAP32[$132>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($ci|0));
                $134 = __THREW__; __THREW__ = 0;
                $135 = $134&1;
                if ($135) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                $136 = (invoke_iii(2729,(2273552|0),($ci|0))|0);
                $137 = __THREW__; __THREW__ = 0;
                $138 = $137&1;
                if ($138) {
                 label = 19;
                 break;
                }
                HEAP32[$L_15>>2] = $136;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $139 = __THREW__; __THREW__ = 0;
                $140 = $139&1;
                if ($140) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                $141 = (invoke_iii(2724,(2155952|0),($L_15|0))|0);
                $142 = __THREW__; __THREW__ = 0;
                $143 = $142&1;
                if ($143) {
                 label = 19;
                 break;
                }
                $144 = HEAP32[$110>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($133|0));
                $145 = __THREW__; __THREW__ = 0;
                $146 = $145&1;
                if ($146) {
                 label = 19;
                 break;
                }
                __THREW__ = 0;
                invoke_viiii(465,(2310992|0),($133|0),($141|0),($144|0));
                $147 = __THREW__; __THREW__ = 0;
                $148 = $147&1;
                if ($148) {
                 label = 19;
                } else {
                 $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 145;
                }
               }
              }
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 19) {
          $40 = ___cxa_find_matching_catch(348288|0)|0;
          $41 = tempRet0;
          $42 = (_llvm_eh_typeid_for((348288|0))|0);
          $43 = ($41|0)==($42|0);
          if (!($43)) {
           $$0 = $40;$$02 = $41;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($$0|0);
           // unreachable;
          }
          $44 = (___cxa_begin_catch(($40|0))|0);
          $45 = HEAP32[$44>>2]|0;
          __THREW__ = 0;
          invoke_v(66);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          $__last_unhandled_exception$0 = $45;$leaveInstructions$sroa$0$0 = 0;
         }
         __THREW__ = 0;
         invoke_vii(1917,(0|0),($27|0));
         $149 = __THREW__; __THREW__ = 0;
         $150 = $149&1;
         if (!($150)) {
          $cond1 = ($leaveInstructions$sroa$0$0|0)==(145);
          if ($cond1) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          __THREW__ = 0;
          invoke_vi(3833,($__last_unhandled_exception$0|0));
          $151 = __THREW__; __THREW__ = 0;
          $152 = $151&1;
          if (!($152)) {
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $$0 = $11;$$02 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z67mscorlib_System_Globalization_CompareInfo_m_get_UseManagedCollationP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2325216);
 __THREW__ = 0;
 (invoke_ii(2996,(2328760|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2328760 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2328760|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2328760|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3832,(2328760|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2328760|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2328760 + 80|0))>>2]|0;
    $15 = HEAP8[$14>>0]|0;
    $16 = ($15<<24>>24)!=(0);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Globalization_CultureInfo_m_get_IcuNameP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2329896);
 $0 = (($__this) + 112|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  __THREW__ = 0;
  invoke_vi(2211,($__this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $7 = ___cxa_find_matching_catch()|0;
   $8 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($7|0);
   // unreachable;
  }
 }
 $5 = (($__this) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($6|0);
}
function __Z65mscorlib_System_Globalization_CompareInfo_m_construct_compareinfoP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_String($__this,$locale) {
 $__this = $__this|0;
 $locale = $locale|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2325264);
 $0 = HEAP32[2325312>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2325320|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2325312>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($locale|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z50mscorlib_System_Globalization_CompareInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2325168);
 __THREW__ = 0;
 invoke_v(569);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[3024904>>2]|0;
   __THREW__ = 0;
   $3 = (invoke_iii(1122,(0|0),($2|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = HEAP32[3024912>>2]|0;
    __THREW__ = 0;
    $7 = (invoke_iiii(575,(0|0),($3|0),($6|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     if ($7) {
      __THREW__ = 0;
      $12 = (invoke_ii(2508,(0|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      $15 = $12&1;
      $G_B3_0$0 = $15;
     } else {
      $G_B3_0$0 = 0;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2328760|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      $18 = HEAP32[((2328760 + 80|0))>>2]|0;
      HEAP8[$18>>0] = $G_B3_0$0;
      __THREW__ = 0;
      (invoke_ii(2996,(2149728|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_ii(3469,(2149728|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(1924,($21|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2328760|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          $28 = HEAP32[((2328760 + 80|0))>>2]|0;
          $29 = (($28) + 8|0);
          HEAP32[$29>>2] = $21;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z66mscorlib_System_Globalization_CompareInfo_m_free_internal_collatorP41mscorlib_System_Globalization_CompareInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2325392);
 $0 = HEAP32[2325440>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2325448|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2325440>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z60mscorlib_System_Globalization_CompareInfo_m_internal_compareP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_iii($__this,$str1,$offset1,$length1,$str2,$offset2,$length2,$options) {
 $__this = $__this|0;
 $str1 = $str1|0;
 $offset1 = $offset1|0;
 $length1 = $length1|0;
 $str2 = $str2|0;
 $offset2 = $offset2|0;
 $length2 = $length2|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2325512);
 $0 = HEAP32[2325560>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   __THREW__ = 0;
   $2 = (invoke_ii(3473,(2325568|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($5|0);
    // unreachable;
   } else {
    HEAP32[2325560>>2] = $2;
    $7 = $2;
    break;
   }
  } else {
   $7 = $0;
  }
 } while(0);
 __THREW__ = 0;
 $8 = (invoke_iiiiiiiii($7|0,($__this|0),($str1|0),($offset1|0),($length1|0),($str2|0),($offset2|0),($length2|0),($options|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z58mscorlib_System_Globalization_CompareInfo_m_assign_sortkeyP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_ObjectP22mscorlib_System_Stringi($__this,$key,$source,$options) {
 $__this = $__this|0;
 $key = $key|0;
 $source = $source|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2325736);
 $0 = HEAP32[2325784>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2325792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2325784>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiii($7|0,($__this|0),($key|0),($source|0),($options|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z58mscorlib_System_Globalization_CompareInfo_m_internal_indexP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_ib($__this,$source,$sindex,$count,$value,$options,$first) {
 $__this = $__this|0;
 $source = $source|0;
 $sindex = $sindex|0;
 $count = $count|0;
 $value = $value|0;
 $options = $options|0;
 $first = $first|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2325912);
 $0 = HEAP32[2325960>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2325968|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2325960>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiiiiii($7|0,($__this|0),($source|0),($sindex|0),($count|0),($value|0),($options|0),($first|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Globalization_CompareInfo_m_FinalizeP41mscorlib_System_Globalization_CompareInfo($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326128);
 __THREW__ = 0;
 invoke_vi(2205,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 15;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(15);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3833,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z68mscorlib_System_Globalization_CompareInfo_m_internal_compare_managedP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_iii($__this,$str1,$offset1,$length1,$str2,$offset2,$length2,$options) {
 $__this = $__this|0;
 $str1 = $str1|0;
 $offset1 = $offset1|0;
 $length1 = $length1|0;
 $str2 = $str2|0;
 $offset2 = $offset2|0;
 $length2 = $length2|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326176);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiiiiiii(10,($1|0),($str1|0),($offset1|0),($length1|0),($str2|0),($offset2|0),($length2|0),($options|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Globalization_CompareInfo_m_internal_compare_switchP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_iii($__this,$str1,$offset1,$length1,$str2,$offset2,$length2,$options) {
 $__this = $__this|0;
 $str1 = $str1|0;
 $offset1 = $offset1|0;
 $length1 = $length1|0;
 $str2 = $str2|0;
 $offset2 = $offset2|0;
 $length2 = $length2|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326224);
 __THREW__ = 0;
 $0 = (invoke_ii(1978,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    __THREW__ = 0;
    $5 = (invoke_iiiiiiiii(14,($__this|0),($str1|0),($offset1|0),($length1|0),($str2|0),($offset2|0),($length2|0),($options|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    } else {
     $G_B3_0$0 = $5;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   } else {
    __THREW__ = 0;
    $8 = (invoke_iiiiiiiii(13,($__this|0),($str1|0),($offset1|0),($length1|0),($str2|0),($offset2|0),($length2|0),($options|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    } else {
     $G_B3_0$0 = $8;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Globalization_CompareInfo_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_StringP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_($__this,$string1,$string2) {
 $__this = $__this|0;
 $string1 = $string1|0;
 $string2 = $string2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2306240);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(231,(2304512|0),($__this|0),($string1|0),($string2|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z164mscorlib_System_Globalization_CompareInfo_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_i($__this,$string1,$string2,$options) {
 $__this = $__this|0;
 $string1 = $string1|0;
 $string2 = $string2|0;
 $options = $options|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2304512);
 __THREW__ = 0;
 invoke_v(570);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $options & 1879048223;
   $3 = ($2|0)==($options|0);
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560072|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3024992>>2]|0;
    __THREW__ = 0;
    invoke_vii(1924,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = ($string1|0)==(0|0);
   $17 = ($string2|0)!=(0|0);
   if ($16) {
    $$ = $17 << 31 >> 31;
    $$0 = $$;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   if (!($17)) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($string1|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_ii(1816,($string1|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = ($20|0)==(0);
     if ($23) {
      __THREW__ = 0;
      invoke_vi(3799,($string2|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_ii(1816,($string2|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = ($26|0)==(0);
      if ($29) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($string1|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      __THREW__ = 0;
      $32 = (invoke_ii(1816,($string1|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       invoke_vi(3799,($string2|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        __THREW__ = 0;
        $37 = (invoke_ii(1816,($string2|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         __THREW__ = 0;
         $40 = (invoke_iiiiiiiii(15,($__this|0),($string1|0),0,($32|0),($string2|0),0,($37|0),($options|0))|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $$0 = $40;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z252mscorlib_System_Globalization_CompareInfo_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_iii($__this,$string1,$offset1,$length1,$string2,$offset2,$length2,$options) {
 $__this = $__this|0;
 $string1 = $string1|0;
 $offset1 = $offset1|0;
 $length1 = $length1|0;
 $string2 = $string2|0;
 $offset2 = $offset2|0;
 $length2 = $length2|0;
 $options = $options|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326272);
 __THREW__ = 0;
 invoke_v(571);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $options & 1879048223;
   $3 = ($2|0)==($options|0);
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560072|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3025024>>2]|0;
    __THREW__ = 0;
    invoke_vii(1924,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   $16 = ($string1|0)==(0|0);
   $17 = ($string2|0)!=(0|0);
   if ($16) {
    $$ = $17 << 31 >> 31;
    $$0 = $$;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   if (!($17)) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($string1|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_ii(1816,($string1|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = ($20|0)==(0);
     if ($23) {
      label = 18;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($string1|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_ii(1816,($string1|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = ($26|0)==($offset1|0);
      $30 = ($length1|0)==(0);
      $or$cond = $29 | $30;
      if ($or$cond) {
       label = 18;
      }
     }
     if ((label|0) == 18) {
      __THREW__ = 0;
      invoke_vi(3799,($string2|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      $33 = (invoke_ii(1816,($string2|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      $36 = ($33|0)==(0);
      if ($36) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($string2|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      __THREW__ = 0;
      $39 = (invoke_ii(1816,($string2|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      $42 = ($39|0)==($offset2|0);
      $43 = ($length2|0)==(0);
      $or$cond1 = $42 | $43;
      if ($or$cond1) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     $44 = $length1 | $offset1;
     $45 = $44 | $offset2;
     $46 = $45 | $length2;
     $47 = ($46|0)>(-1);
     if (!($47)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2561352|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      __THREW__ = 0;
      $50 = (invoke_ii(3469,(2561352|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = HEAP32[3025032>>2]|0;
      __THREW__ = 0;
      invoke_vii(1926,($50|0),($53|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($50|0));
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($string1|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      __THREW__ = 0;
      $60 = (invoke_ii(1816,($string1|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if (!($62)) {
       $63 = ($60|0)<($offset1|0);
       if ($63) {
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         break;
        }
        __THREW__ = 0;
        $66 = (invoke_ii(3469,(2561352|0))|0);
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        $69 = HEAP32[3025040>>2]|0;
        __THREW__ = 0;
        invoke_vii(1926,($66|0),($69|0));
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3833,($66|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         break;
        }
        // unreachable;
       }
       __THREW__ = 0;
       invoke_vi(3799,($string2|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if (!($75)) {
        __THREW__ = 0;
        $76 = (invoke_ii(1816,($string2|0))|0);
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if (!($78)) {
         $79 = ($76|0)<($offset2|0);
         if ($79) {
          __THREW__ = 0;
          (invoke_ii(2996,(2561352|0))|0);
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          if ($81) {
           break;
          }
          __THREW__ = 0;
          $82 = (invoke_ii(3469,(2561352|0))|0);
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           break;
          }
          $85 = HEAP32[3025048>>2]|0;
          __THREW__ = 0;
          invoke_vii(1926,($82|0),($85|0));
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3833,($82|0));
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($string1|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if (!($91)) {
          __THREW__ = 0;
          $92 = (invoke_ii(1816,($string1|0))|0);
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if (!($94)) {
           $95 = (($92) - ($offset1))|0;
           $96 = ($95|0)<($length1|0);
           if ($96) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             break;
            }
            __THREW__ = 0;
            $99 = (invoke_ii(3469,(2561352|0))|0);
            $100 = __THREW__; __THREW__ = 0;
            $101 = $100&1;
            if ($101) {
             break;
            }
            $102 = HEAP32[3025056>>2]|0;
            __THREW__ = 0;
            invoke_vii(1926,($99|0),($102|0));
            $103 = __THREW__; __THREW__ = 0;
            $104 = $103&1;
            if ($104) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3833,($99|0));
            $105 = __THREW__; __THREW__ = 0;
            $106 = $105&1;
            if ($106) {
             break;
            }
            // unreachable;
           }
           __THREW__ = 0;
           invoke_vi(3799,($string2|0));
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if (!($108)) {
            __THREW__ = 0;
            $109 = (invoke_ii(1816,($string2|0))|0);
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if (!($111)) {
             $112 = (($109) - ($offset2))|0;
             $113 = ($112|0)<($length2|0);
             if (!($113)) {
              __THREW__ = 0;
              $124 = (invoke_iiiiiiiii(15,($__this|0),($string1|0),($offset1|0),($length1|0),($string2|0),($offset2|0),($length2|0),($options|0))|0);
              $125 = __THREW__; __THREW__ = 0;
              $126 = $125&1;
              if ($126) {
               break;
              } else {
               $$0 = $124;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2561352|0))|0);
             $114 = __THREW__; __THREW__ = 0;
             $115 = $114&1;
             if ($115) {
              break;
             }
             __THREW__ = 0;
             $116 = (invoke_ii(3469,(2561352|0))|0);
             $117 = __THREW__; __THREW__ = 0;
             $118 = $117&1;
             if ($118) {
              break;
             }
             $119 = HEAP32[3025064>>2]|0;
             __THREW__ = 0;
             invoke_vii(1926,($116|0),($119|0));
             $120 = __THREW__; __THREW__ = 0;
             $121 = $120&1;
             if ($121) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3833,($116|0));
             $122 = __THREW__; __THREW__ = 0;
             $123 = $122&1;
             if ($123) {
              break;
             }
             // unreachable;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Globalization_CompareInfo_m_EqualsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326320);
 __THREW__ = 0;
 (invoke_ii(2996,(2328760|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2328760|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($2) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($__this) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    $$0 = $14;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Globalization_CompareInfo_m_GetHashCodeP41mscorlib_System_Globalization_CompareInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326368);
 __THREW__ = 0;
 $0 = (invoke_ii(1981,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Globalization_CompareInfo_m_get_LCIDP41mscorlib_System_Globalization_CompareInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326896);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z54mscorlib_System_Globalization_CompareInfo_m_GetSortKeyP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_Stringi($__this,$source,$options) {
 $__this = $__this|0;
 $source = $source|0;
 $options = $options|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326416);
 __THREW__ = 0;
 invoke_v(572);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   if ((($options|0) == 1073741824) | (($options|0) == 268435456)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    $6 = (invoke_ii(3469,(2560072|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    $9 = HEAP32[3025752>>2]|0;
    $10 = HEAP32[3025760>>2]|0;
    __THREW__ = 0;
    invoke_viii(641,($6|0),($9|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($6|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1978,0)|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    if ($15) {
     $18 = (($__this) + 16|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($19|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     $22 = (invoke_iiii(747,($19|0),($source|0),($options|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     } else {
      $$0 = $22;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $25 = (($__this) + 8|0);
    $26 = HEAP32[$25>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2281808|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     __THREW__ = 0;
     $29 = (invoke_ii(3469,(2281808|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      __THREW__ = 0;
      invoke_viiii(147,($29|0),($26|0),($source|0),($options|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_viiii(156,($__this|0),($29|0),($source|0),($options|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $$0 = $29;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($2|0);
 // unreachable;
 return 0|0;
}
function __Z163mscorlib_System_Globalization_CompareInfo_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_ii($__this,$source,$value,$startIndex,$count) {
 $__this = $__this|0;
 $source = $source|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326464);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(117,(2326512|0),($__this|0),($source|0),($value|0),($startIndex|0),($count|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z66mscorlib_System_Globalization_CompareInfo_m_internal_index_managedP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_ib($__this,$s1,$sindex,$count,$s2,$opt,$first) {
 $__this = $__this|0;
 $s1 = $s1|0;
 $sindex = $sindex|0;
 $count = $count|0;
 $s2 = $s2|0;
 $opt = $opt|0;
 $first = $first|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326560);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 if ($first) {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iiiiiii(62,($1|0),($s1|0),($s2|0),($sindex|0),($count|0),($opt|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $G_B3_0$0 = $4;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   $11 = (invoke_iiiiiii(63,($1|0),($s1|0),($s2|0),($sindex|0),($count|0),($opt|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $G_B3_0$0 = $11;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Globalization_CompareInfo_m_internal_index_switchP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_ib($__this,$s1,$sindex,$count,$s2,$opt,$first) {
 $__this = $__this|0;
 $s1 = $s1|0;
 $sindex = $sindex|0;
 $count = $count|0;
 $s2 = $s2|0;
 $opt = $opt|0;
 $first = $first|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326608);
 __THREW__ = 0;
 $0 = (invoke_ii(1978,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    $5 = ($opt|0)==(1073741824);
    $or$cond = $5 & $first;
    if (!($or$cond)) {
     __THREW__ = 0;
     $6 = (invoke_iiiiiiii(82,($__this|0),($s1|0),($sindex|0),($count|0),($s2|0),($opt|0),($first|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     } else {
      $G_B5_0$0 = $6;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B5_0$0|0);
    }
   }
   __THREW__ = 0;
   $9 = (invoke_iiiiiiii(81,($__this|0),($s1|0),($sindex|0),($count|0),($s2|0),($opt|0),($first|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $G_B5_0$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B5_0$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z208mscorlib_System_Globalization_CompareInfo_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_iii($__this,$source,$value,$startIndex,$count,$options) {
 $__this = $__this|0;
 $source = $source|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 $options = $options|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326512);
 __THREW__ = 0;
 invoke_v(573);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($source|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3025832>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($value|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3025840>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($startIndex|0)>(-1);
   if (!($26)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(3469,(2561352|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[3025848>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($29|0),($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($29|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    // unreachable;
   }
   $37 = ($count|0)<(0);
   if (!($37)) {
    __THREW__ = 0;
    invoke_vi(3799,($source|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(1816,($source|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $43 = (($40) - ($startIndex))|0;
    $44 = ($43|0)<($count|0);
    if (!($44)) {
     $55 = $options & 1342177311;
     $56 = ($55|0)==($options|0);
     if (!($56)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      __THREW__ = 0;
      $59 = (invoke_ii(3469,(2560072|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break;
      }
      $62 = HEAP32[3025864>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($59|0),($62|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($59|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     __THREW__ = 0;
     $69 = (invoke_ii(1816,($value|0))|0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     }
     $72 = ($69|0)==(0);
     if ($72) {
      $$0 = $startIndex;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $73 = ($count|0)==(0);
     if ($73) {
      $$0 = -1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $74 = (invoke_iiiiiiii(83,($__this|0),($source|0),($startIndex|0),($count|0),($value|0),($options|0),1)|0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      break;
     } else {
      $$0 = $74;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    __THREW__ = 0;
    $47 = (invoke_ii(3469,(2561352|0))|0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if (!($49)) {
     $50 = HEAP32[3025856>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($47|0),($50|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if (!($52)) {
      __THREW__ = 0;
      invoke_vi(3833,($47|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if (!($54)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Globalization_CompareInfo_m_IsPrefixP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_i($__this,$source,$prefix,$options) {
 $__this = $__this|0;
 $source = $source|0;
 $prefix = $prefix|0;
 $options = $options|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326656);
 __THREW__ = 0;
 invoke_v(574);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($source|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3025896>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($prefix|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3025904>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $26 = (invoke_ii(1978,0)|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    if ($26) {
     $29 = (($__this) + 16|0);
     $30 = HEAP32[$29>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($30|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     __THREW__ = 0;
     $33 = (invoke_iiiii(125,($30|0),($source|0),($prefix|0),($options|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     } else {
      $$0 = $33;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($source|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     $38 = (invoke_ii(1816,($source|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      __THREW__ = 0;
      invoke_vi(3799,($prefix|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       __THREW__ = 0;
       $43 = (invoke_ii(1816,($prefix|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        $46 = ($38|0)<($43|0);
        if ($46) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($prefix|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         __THREW__ = 0;
         $49 = (invoke_ii(1816,($prefix|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          __THREW__ = 0;
          invoke_vi(3799,($prefix|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           __THREW__ = 0;
           $54 = (invoke_ii(1816,($prefix|0))|0);
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if (!($56)) {
            __THREW__ = 0;
            $57 = (invoke_iiiiiiiiii(14,(2326272|0),($__this|0),($source|0),0,($49|0),($prefix|0),0,($54|0),($options|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             $60 = ($57|0)==(0);
             $$0 = $60;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Globalization_CompareInfo_m_IsSuffixP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_i($__this,$source,$suffix,$options) {
 $__this = $__this|0;
 $source = $source|0;
 $suffix = $suffix|0;
 $options = $options|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326704);
 __THREW__ = 0;
 invoke_v(575);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($source|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3025936>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($suffix|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3025944>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $26 = (invoke_ii(1978,0)|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    if ($26) {
     $29 = (($__this) + 16|0);
     $30 = HEAP32[$29>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($30|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     __THREW__ = 0;
     $33 = (invoke_iiiii(126,($30|0),($source|0),($suffix|0),($options|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     } else {
      $$0 = $33;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($source|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     $38 = (invoke_ii(1816,($source|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      __THREW__ = 0;
      invoke_vi(3799,($suffix|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       __THREW__ = 0;
       $43 = (invoke_ii(1816,($suffix|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        $46 = ($38|0)<($43|0);
        if ($46) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($source|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         __THREW__ = 0;
         $49 = (invoke_ii(1816,($source|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          __THREW__ = 0;
          invoke_vi(3799,($suffix|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           __THREW__ = 0;
           $54 = (invoke_ii(1816,($suffix|0))|0);
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if (!($56)) {
            $57 = (($49) - ($54))|0;
            __THREW__ = 0;
            invoke_vi(3799,($suffix|0));
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             __THREW__ = 0;
             $60 = (invoke_ii(1816,($suffix|0))|0);
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if (!($62)) {
              __THREW__ = 0;
              invoke_vi(3799,($suffix|0));
              $63 = __THREW__; __THREW__ = 0;
              $64 = $63&1;
              if (!($64)) {
               __THREW__ = 0;
               $65 = (invoke_ii(1816,($suffix|0))|0);
               $66 = __THREW__; __THREW__ = 0;
               $67 = $66&1;
               if (!($67)) {
                __THREW__ = 0;
                $68 = (invoke_iiiiiiiiii(14,(2326272|0),($__this|0),($source|0),($57|0),($60|0),($suffix|0),0,($65|0),($options|0))|0);
                $69 = __THREW__; __THREW__ = 0;
                $70 = $69&1;
                if (!($70)) {
                 $71 = ($68|0)==(0);
                 $$0 = $71;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z167mscorlib_System_Globalization_CompareInfo_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_ii($__this,$source,$value,$startIndex,$count) {
 $__this = $__this|0;
 $source = $source|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326752);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(117,(2326800|0),($__this|0),($source|0),($value|0),($startIndex|0),($count|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z212mscorlib_System_Globalization_CompareInfo_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_iii($__this,$source,$value,$startIndex,$count,$options) {
 $__this = $__this|0;
 $source = $source|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 $options = $options|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326800);
 __THREW__ = 0;
 invoke_v(576);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($source|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3025976>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($value|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3025984>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($startIndex|0)>(-1);
   if (!($26)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(3469,(2561352|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[3025992>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($29|0),($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($29|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    // unreachable;
   }
   $37 = ($count|0)<(0);
   if (!($37)) {
    $38 = (($startIndex) - ($count))|0;
    $39 = ($38|0)>(-2);
    if ($39) {
     $50 = $options & 1342177311;
     $51 = ($50|0)==($options|0);
     if (!($51)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_ii(3469,(2560072|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break;
      }
      $57 = HEAP32[3026008>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($54|0),($57|0));
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($54|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break;
      }
      // unreachable;
     }
     $62 = ($count|0)==(0);
     if ($62) {
      $$0 = -1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      break;
     }
     __THREW__ = 0;
     $65 = (invoke_ii(1816,($value|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     $68 = ($65|0)==(0);
     if ($68) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $69 = (invoke_iiiiiiii(83,($__this|0),($source|0),($startIndex|0),($count|0),($value|0),($options|0),0)|0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     } else {
      $$0 = $69;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    __THREW__ = 0;
    $42 = (invoke_ii(3469,(2561352|0))|0);
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if (!($44)) {
     $45 = HEAP32[3026000>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($42|0),($45|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if (!($47)) {
      __THREW__ = 0;
      invoke_vi(3833,($42|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if (!($49)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Globalization_CompareInfo_m_ToStringP41mscorlib_System_Globalization_CompareInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2326848);
 __THREW__ = 0;
 invoke_v(577);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$L_1>>2] = $3;
  __THREW__ = 0;
  (invoke_ii(2996,(2155952|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2724,(2155952|0),($L_1|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3026024>>2]|0;
    __THREW__ = 0;
    $10 = (invoke_iiii(559,(0|0),($9|0),($6|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($10|0);
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker3I28mscorlib_System_ObjectTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvP22mscorlib_System_ObjectS4_iES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$5);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iiS4_ibES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)!=(0);
 $16 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$6,$8,$11,$15)|0);
 HEAP32[$ret>>2] = $16;
 $17 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($17|0);
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_E6InvokeEPFiPvS3_S3_iES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$5)|0);
 HEAP32[$ret>>2] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z72mscorlib_System_Globalization_CompareInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Globalization_CompareOptions_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Globalization_CultureInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P41mscorlib_System_Globalization_CultureInfoi($__this,$culture) {
 $__this = $__this|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2329656);
 __THREW__ = 0;
 invoke_viii(586,($__this|0),($culture|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z116mscorlib_System_Globalization_CultureInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_BooleanP41mscorlib_System_Globalization_CultureInfoib($__this,$culture,$useUserOverride) {
 $__this = $__this|0;
 $culture = $culture|0;
 $useUserOverride = $useUserOverride|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2329704);
 __THREW__ = 0;
 invoke_viiii(157,($__this|0),($culture|0),($useUserOverride|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z140mscorlib_System_Globalization_CultureInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_System_BooleanP41mscorlib_System_Globalization_CultureInfoibb($__this,$culture,$useUserOverride,$read_only) {
 $__this = $__this|0;
 $culture = $culture|0;
 $useUserOverride = $useUserOverride|0;
 $read_only = $read_only|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_5 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2329752);
 __THREW__ = 0;
 invoke_v(578);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($culture|0)>(-1);
    if (!($4)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2561352|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = HEAP32[3026072>>2]|0;
     $13 = HEAP32[3026080>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($9|0),($12|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($9|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    $18 = (($__this) + 112|0);
    HEAP8[$18>>0] = 1;
    $19 = (($__this) + 8|0);
    $20 = $read_only&1;
    HEAP8[$19>>0] = $20;
    $21 = (($__this) + 32|0);
    $22 = $useUserOverride&1;
    HEAP8[$21>>0] = $22;
    $23 = ($culture|0)==(127);
    if ($23) {
     __THREW__ = 0;
     invoke_vii(1835,($__this|0),($read_only|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $26 = (invoke_iii(849,($__this|0),($culture|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     if ($26) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     HEAP32[$L_5>>2] = $culture;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      $31 = (invoke_iii(2724,(2155952|0),($L_5|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       $34 = HEAP32[3026088>>2]|0;
       __THREW__ = 0;
       $35 = (invoke_iiii(552,(0|0),($34|0),($31|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         __THREW__ = 0;
         $40 = (invoke_ii(3469,(2560072|0))|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[3026096>>2]|0;
          __THREW__ = 0;
          invoke_viii(641,($40|0),($35|0),($43|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if (!($45)) {
           __THREW__ = 0;
           invoke_vi(3833,($40|0));
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z62mscorlib_System_Globalization_CultureInfo_m_ConstructInvariantP41mscorlib_System_Globalization_CultureInfob($__this,$read_only) {
 $__this = $__this|0;
 $read_only = $read_only|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330856);
 __THREW__ = 0;
 invoke_v(579);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   HEAP32[$2>>2] = 127;
   __THREW__ = 0;
   $3 = (invoke_ii(2026,0)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($__this) + 36|0);
    HEAP32[$6>>2] = $3;
    __THREW__ = 0;
    $7 = (invoke_ii(2009,0)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($__this) + 40|0);
     HEAP32[$10>>2] = $7;
     if (!($read_only)) {
      $13 = HEAP32[$6>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($13|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      __THREW__ = 0;
      $16 = (invoke_iii(2756,(2330904|0),($13|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2348608|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      __THREW__ = 0;
      $21 = (invoke_iii(2759,($16|0),(2348608|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      HEAP32[$6>>2] = $21;
      $24 = HEAP32[$10>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($24|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_iii(2756,(2330952|0),($24|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2340656|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2759,($27|0),(2340656|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      HEAP32[$10>>2] = $32;
     }
     __THREW__ = 0;
     $35 = (invoke_iii(851,($__this|0),($read_only|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      $38 = (($__this) + 44|0);
      HEAP32[$38>>2] = $35;
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP8[((2191608 + 116|0))>>0]|0;
       $42 = ($41<<24>>24)==(0);
       if ($42) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3832,(2191608|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if (!($50)) {
        $51 = HEAP32[((2191608 + 80|0))>>2]|0;
        $52 = HEAP32[$51>>2]|0;
        $53 = (($__this) + 48|0);
        HEAP32[$53>>2] = $52;
        $54 = HEAP32[3026664>>2]|0;
        $55 = (($__this) + 60|0);
        HEAP32[$55>>2] = $54;
        $56 = (($__this) + 56|0);
        HEAP32[$56>>2] = $54;
        $57 = (($__this) + 52|0);
        HEAP32[$57>>2] = $54;
        $58 = HEAP32[3026672>>2]|0;
        $59 = (($__this) + 64|0);
        HEAP32[$59>>2] = $58;
        $60 = HEAP32[3026680>>2]|0;
        $61 = (($__this) + 68|0);
        HEAP32[$61>>2] = $60;
        $62 = HEAP32[3026688>>2]|0;
        $63 = (($__this) + 72|0);
        HEAP32[$63>>2] = $62;
        $64 = HEAP32[3026696>>2]|0;
        $65 = (($__this) + 76|0);
        HEAP32[$65>>2] = $64;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z75mscorlib_System_Globalization_CultureInfo_m_ConstructInternalLocaleFromLcidP41mscorlib_System_Globalization_CultureInfoi($__this,$lcid) {
 $__this = $__this|0;
 $lcid = $lcid|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330424);
 __THREW__ = 0;
 $0 = (invoke_iii(850,($__this|0),($lcid|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Globalization_CultureInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2329800);
 __THREW__ = 0;
 invoke_v(580);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2149728|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2149728|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(1924,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2333776|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = HEAP32[((2333776 + 80|0))>>2]|0;
      $12 = (($11) + 20|0);
      HEAP32[$12>>2] = $4;
      $13 = HEAP32[3026280>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2333776|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = HEAP32[((2333776 + 80|0))>>2]|0;
       $17 = (($16) + 28|0);
       HEAP32[$17>>2] = $13;
       __THREW__ = 0;
       (invoke_ii(2996,(2333776|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_ii(3469,(2333776|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         invoke_viiii(157,($20|0),127,0,1);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2333776|0))|0);
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           $27 = HEAP32[((2333776 + 80|0))>>2]|0;
           $28 = (($27) + 16|0);
           HEAP32[$28>>2] = $20;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($29|0);
 // unreachable;
}
function __Z52mscorlib_System_Globalization_CultureInfo_m_get_LCIDP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273552);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52mscorlib_System_Globalization_CultureInfo_m_get_NameP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273792);
 $0 = (($__this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z54mscorlib_System_Globalization_CultureInfo_m_get_ParentP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273648);
 $0 = (($__this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   $3 = (($__this) + 112|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    __THREW__ = 0;
    invoke_vi(2211,($__this|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     label = 4;
    }
   } else {
    label = 4;
   }
   do {
    if ((label|0) == 4) {
     $8 = (($__this) + 16|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (($__this) + 12|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($9|0)==($11|0);
     if ($12) {
      $$0 = 0;
      break L1;
     }
     $15 = ($9|0)==(127);
     if ($15) {
      __THREW__ = 0;
      $16 = (invoke_ii(1982,0)|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      HEAP32[$0>>2] = $16;
      $$0 = $16;
      break L1;
     }
     $19 = ($11|0)==(127);
     if ($19) {
      HEAP32[$0>>2] = $__this;
      $$0 = $__this;
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2333776|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_ii(3469,(2333776|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_vii(1834,($22|0),($9|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        HEAP32[$0>>2] = $22;
        $$0 = $22;
        break L1;
       }
      }
     }
    }
   } while(0);
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($13|0);
   // unreachable;
  } else {
   $$0 = $1;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z53mscorlib_System_Globalization_CultureInfo_m_ConstructP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330376);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_iii(850,($__this|0),($1|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $4 = (($__this) + 112|0);
  HEAP8[$4>>0] = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56mscorlib_System_Globalization_CultureInfo_m_get_TextInfoP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2273600);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $32 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($32|0);
 }
 $3 = (($__this) + 112|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  __THREW__ = 0;
  invoke_vi(2211,($__this|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   label = 4;
  }
 } else {
  label = 4;
 }
 L6: do {
  if ((label|0) == 4) {
   __THREW__ = 0;
   invoke_vii(1916,(0|0),($__this|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[$0>>2]|0;
    $11 = ($10|0)==(0|0);
    do {
     if ($11) {
      $14 = (($__this) + 8|0);
      $15 = HEAP8[$14>>0]|0;
      $16 = ($15<<24>>24)!=(0);
      __THREW__ = 0;
      $17 = (invoke_iii(851,($__this|0),($16|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       HEAP32[$0>>2] = $17;
       $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 71;
       break;
      }
      $20 = ___cxa_find_matching_catch(348288|0)|0;
      $21 = tempRet0;
      $22 = (_llvm_eh_typeid_for((348288|0))|0);
      $23 = ($21|0)==($22|0);
      if (!($23)) {
       $$02 = $20;$$03 = $21;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $24 = (___cxa_begin_catch(($20|0))|0);
      $25 = HEAP32[$24>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break L6;
      }
      $__last_unhandled_exception$0 = $25;$leaveInstructions$sroa$0$0 = 0;
     } else {
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 71;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vii(1917,(0|0),($__this|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(71);
     if ($cond1) {
      $$pre = HEAP32[$0>>2]|0;
      $32 = $$pre;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($32|0);
     } else {
      __THREW__ = 0;
      invoke_vi(3833,($__last_unhandled_exception$0|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $$02 = $12;$$03 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Globalization_CultureInfo_m_CreateTextInfoP41mscorlib_System_Globalization_CultureInfob($__this,$readOnly) {
 $__this = $__this|0;
 $readOnly = $readOnly|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2331000);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2351088|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(3469,(2351088|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_viiiii(66,($6|0),($__this|0),($1|0),($3|0),($readOnly|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Globalization_CultureInfo_m_EqualsP41mscorlib_System_Globalization_CultureInfoP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2329944);
 __THREW__ = 0;
 (invoke_ii(2996,(2333776|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2333776|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($2) + 12|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($__this) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    $$0 = $14;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Globalization_CultureInfo_m_GetHashCodeP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2329992);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52mscorlib_System_Globalization_CultureInfo_m_ToStringP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330040);
 $0 = (($__this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z59mscorlib_System_Globalization_CultureInfo_m_get_CompareInfoP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0;
 var $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2304464);
 $0 = (($__this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $33 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($33|0);
 }
 $3 = (($__this) + 112|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  __THREW__ = 0;
  invoke_vi(2211,($__this|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   label = 4;
  }
 } else {
  label = 4;
 }
 L6: do {
  if ((label|0) == 4) {
   __THREW__ = 0;
   invoke_vii(1916,(0|0),($__this|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[$0>>2]|0;
    $11 = ($10|0)==(0|0);
    do {
     if ($11) {
      __THREW__ = 0;
      (invoke_ii(2996,(2328760|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       $16 = (invoke_ii(3469,(2328760|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        invoke_vii(1832,($16|0),($__this|0));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         HEAP32[$0>>2] = $16;
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 65;
         break;
        }
       }
      }
      $21 = ___cxa_find_matching_catch(348288|0)|0;
      $22 = tempRet0;
      $23 = (_llvm_eh_typeid_for((348288|0))|0);
      $24 = ($22|0)==($23|0);
      if (!($24)) {
       $$02 = $21;$$03 = $22;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $25 = (___cxa_begin_catch(($21|0))|0);
      $26 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break L6;
      }
      $__last_unhandled_exception$0 = $26;$leaveInstructions$sroa$0$0 = 0;
     } else {
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 65;
     }
    } while(0);
    __THREW__ = 0;
    invoke_vii(1917,(0|0),($__this|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(65);
     if ($cond1) {
      $$pre = HEAP32[$0>>2]|0;
      $33 = $$pre;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($33|0);
     } else {
      __THREW__ = 0;
      invoke_vi(3833,($__last_unhandled_exception$0|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $$02 = $12;$$03 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Globalization_CultureInfo_m_get_IsNeutralCultureP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330088);
 $0 = (($__this) + 112|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  __THREW__ = 0;
  invoke_vi(2211,($__this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($8|0);
   // unreachable;
  }
 }
 $5 = (($__this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(127);
 if ($7) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $10 = $6 & 65280;
 $11 = ($10|0)==(0);
 if ($11) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $12 = (($__this) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0);
 $$0 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z56mscorlib_System_Globalization_CultureInfo_m_CheckNeutralP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330136);
 __THREW__ = 0;
 invoke_v(581);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2734,(2330088|0),($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   if (!($2)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $7 = (($__this) + 48|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = HEAP32[3026352>>2]|0;
   $10 = HEAP32[3026360>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iiiii(101,(0|0),($9|0),($8|0),($10|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2622808|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2622808|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      invoke_vii(1954,($16|0),($11|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3833,($16|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z60mscorlib_System_Globalization_CultureInfo_m_get_NumberFormatP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330184);
 $0 = (($__this) + 112|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  __THREW__ = 0;
  invoke_vi(2211,($__this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 L3: do {
  if ((label|0) == 3) {
   __THREW__ = 0;
   invoke_vi(2210,($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 36|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     $40 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($40|0);
    }
    __THREW__ = 0;
    invoke_vii(1916,(0|0),($__this|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[$7>>2]|0;
     $15 = ($14|0)==(0|0);
     do {
      if ($15) {
       $16 = (($__this) + 8|0);
       $17 = HEAP8[$16>>0]|0;
       $18 = ($17<<24>>24)!=(0);
       __THREW__ = 0;
       (invoke_ii(2996,(2348608|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        $21 = (invoke_ii(3469,(2348608|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         __THREW__ = 0;
         invoke_vii(1842,($21|0),($18|0));
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          HEAP32[$7>>2] = $21;
          __THREW__ = 0;
          invoke_vi(2213,($__this|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 82;
           break;
          }
         }
        }
       }
       $28 = ___cxa_find_matching_catch(348288|0)|0;
       $29 = tempRet0;
       $30 = (_llvm_eh_typeid_for((348288|0))|0);
       $31 = ($29|0)==($30|0);
       if (!($31)) {
        $$02 = $28;$$03 = $29;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$02|0);
        // unreachable;
       }
       $32 = (___cxa_begin_catch(($28|0))|0);
       $33 = HEAP32[$32>>2]|0;
       __THREW__ = 0;
       invoke_v(66);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break L3;
       }
       $__last_unhandled_exception$0 = $33;$leaveInstructions$sroa$0$0 = 0;
      } else {
       $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 82;
      }
     } while(0);
     __THREW__ = 0;
     invoke_vii(1917,(0|0),($__this|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      $cond1 = ($leaveInstructions$sroa$0$0|0)==(82);
      if ($cond1) {
       $$pre = HEAP32[$7>>2]|0;
       $40 = $$pre;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($40|0);
      } else {
       __THREW__ = 0;
       invoke_vi(3833,($__last_unhandled_exception$0|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Globalization_NumberFormatInfo_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP46mscorlib_System_Globalization_NumberFormatInfob($__this,$read_only) {
 $__this = $__this|0;
 $read_only = $read_only|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2343912);
 __THREW__ = 0;
 invoke_viii(587,($__this|0),127,($read_only|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z67mscorlib_System_Globalization_CultureInfo_m_construct_number_formatP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330736);
 $0 = HEAP32[2330784>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2330792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2330784>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z62mscorlib_System_Globalization_CultureInfo_m_get_DateTimeFormatP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330232);
 $0 = (($__this) + 112|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  __THREW__ = 0;
  invoke_vi(2211,($__this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 3;
  }
 } else {
  label = 3;
 }
 L3: do {
  if ((label|0) == 3) {
   __THREW__ = 0;
   invoke_vi(2210,($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 40|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if (!($9)) {
     $60 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($60|0);
    }
    __THREW__ = 0;
    invoke_vii(1916,(0|0),($__this|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[$7>>2]|0;
     $15 = ($14|0)==(0|0);
     L10: do {
      if ($15) {
       $16 = (($__this) + 8|0);
       $17 = HEAP8[$16>>0]|0;
       $18 = ($17<<24>>24)!=(0);
       __THREW__ = 0;
       (invoke_ii(2996,(2340656|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       do {
        if (!($20)) {
         __THREW__ = 0;
         $21 = (invoke_ii(3469,(2340656|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          __THREW__ = 0;
          invoke_vii(1836,($21|0),($18|0));
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           HEAP32[$7>>2] = $21;
           __THREW__ = 0;
           invoke_vi(2212,($__this|0));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            $28 = (($__this) + 96|0);
            $29 = HEAP32[$28>>2]|0;
            $30 = ($29|0)==(0|0);
            if ($30) {
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 111;
             break L10;
            }
            $39 = HEAP32[$7>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($29|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if (!($41)) {
             $42 = (($29) + 12|0);
             $43 = HEAP32[$42>>2]|0;
             $44 = ($43|0)==(0);
             if ($44) {
              __THREW__ = 0;
              $45 = (invoke_i(132)|0);
              $46 = __THREW__; __THREW__ = 0;
              $47 = $46&1;
              if ($47) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($45|0));
              $48 = __THREW__; __THREW__ = 0;
              $49 = $48&1;
              if ($49) {
               break;
              }
             }
             $50 = (($29) + 16|0);
             $51 = HEAP32[$50>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($39|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              invoke_vii(1837,($39|0),($51|0));
              $54 = __THREW__; __THREW__ = 0;
              $55 = $54&1;
              if (!($55)) {
               $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 111;
               break L10;
              }
             }
            }
           }
          }
         }
        }
       } while(0);
       $31 = ___cxa_find_matching_catch(348288|0)|0;
       $32 = tempRet0;
       $33 = (_llvm_eh_typeid_for((348288|0))|0);
       $34 = ($32|0)==($33|0);
       if (!($34)) {
        $$02 = $31;$$03 = $32;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$02|0);
        // unreachable;
       }
       $35 = (___cxa_begin_catch(($31|0))|0);
       $36 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       invoke_v(66);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break L3;
       }
       $__last_unhandled_exception$0 = $36;$leaveInstructions$sroa$0$0 = 0;
      } else {
       $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 111;
      }
     } while(0);
     __THREW__ = 0;
     invoke_vii(1917,(0|0),($__this|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if (!($57)) {
      $cond1 = ($leaveInstructions$sroa$0$0|0)==(111);
      if ($cond1) {
       $$pre = HEAP32[$7>>2]|0;
       $60 = $$pre;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($60|0);
      } else {
       __THREW__ = 0;
       invoke_vi(3833,($__last_unhandled_exception$0|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Globalization_DateTimeFormatInfo_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP48mscorlib_System_Globalization_DateTimeFormatInfob($__this,$read_only) {
 $__this = $__this|0;
 $read_only = $read_only|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334480);
 __THREW__ = 0;
 invoke_v(582);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($__this) + 8|0);
    $5 = $read_only&1;
    HEAP8[$4>>0] = $5;
    $6 = HEAP32[3026944>>2]|0;
    $7 = (($__this) + 12|0);
    HEAP32[$7>>2] = $6;
    $8 = HEAP32[3026952>>2]|0;
    $9 = (($__this) + 16|0);
    HEAP32[$9>>2] = $8;
    $10 = HEAP32[3026960>>2]|0;
    $11 = (($__this) + 20|0);
    HEAP32[$11>>2] = $10;
    $12 = HEAP32[3026968>>2]|0;
    $13 = (($__this) + 24|0);
    HEAP32[$13>>2] = $12;
    $14 = HEAP32[3026976>>2]|0;
    $15 = (($__this) + 28|0);
    HEAP32[$15>>2] = $14;
    $16 = HEAP32[3026984>>2]|0;
    $17 = (($__this) + 32|0);
    HEAP32[$17>>2] = $16;
    $18 = HEAP32[3026992>>2]|0;
    $19 = (($__this) + 36|0);
    HEAP32[$19>>2] = $18;
    $20 = HEAP32[3027000>>2]|0;
    $21 = (($__this) + 40|0);
    HEAP32[$21>>2] = $20;
    $22 = HEAP32[3027008>>2]|0;
    $23 = (($__this) + 44|0);
    HEAP32[$23>>2] = $22;
    $24 = HEAP32[3027016>>2]|0;
    $25 = (($__this) + 48|0);
    HEAP32[$25>>2] = $24;
    $26 = HEAP32[3027024>>2]|0;
    $27 = (($__this) + 52|0);
    HEAP32[$27>>2] = $26;
    $28 = HEAP32[3027032>>2]|0;
    $29 = (($__this) + 56|0);
    HEAP32[$29>>2] = $28;
    $30 = HEAP32[3027040>>2]|0;
    $31 = (($__this) + 60|0);
    HEAP32[$31>>2] = $30;
    $32 = HEAP32[3027048>>2]|0;
    $33 = (($__this) + 64|0);
    HEAP32[$33>>2] = $32;
    $34 = (($__this) + 68|0);
    HEAP32[$34>>2] = 0;
    __THREW__ = 0;
    (invoke_ii(2996,(2343072|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __THREW__ = 0;
     $37 = (invoke_ii(3469,(2343072|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      __THREW__ = 0;
      invoke_vi(2225,($37|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       $42 = (($__this) + 72|0);
       HEAP32[$42>>2] = $37;
       $43 = (($__this) + 76|0);
       HEAP32[$43>>2] = 0;
       __THREW__ = 0;
       (invoke_ii(2996,(2340656|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        $46 = HEAP8[((2340656 + 116|0))>>0]|0;
        $47 = ($46<<24>>24)==(0);
        if ($47) {
         __THREW__ = 0;
         (invoke_ii(2996,(2340656|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2340656|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3832,(2340656|0));
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2340656|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if (!($57)) {
         $58 = HEAP32[((2340656 + 80|0))>>2]|0;
         $59 = (($58) + 16|0);
         $60 = HEAP32[$59>>2]|0;
         $61 = (($__this) + 80|0);
         HEAP32[$61>>2] = $60;
         __THREW__ = 0;
         (invoke_ii(2996,(2340656|0))|0);
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if (!($63)) {
          $64 = HEAP8[((2340656 + 116|0))>>0]|0;
          $65 = ($64<<24>>24)==(0);
          if ($65) {
           __THREW__ = 0;
           (invoke_ii(2996,(2340656|0))|0);
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2340656|0))|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3832,(2340656|0));
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2340656|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if (!($73)) {
           $74 = HEAP32[((2340656 + 80|0))>>2]|0;
           $75 = (($74) + 20|0);
           $76 = HEAP32[$75>>2]|0;
           $77 = (($__this) + 84|0);
           HEAP32[$77>>2] = $76;
           __THREW__ = 0;
           (invoke_ii(2996,(2340656|0))|0);
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if (!($79)) {
            $80 = HEAP8[((2340656 + 116|0))>>0]|0;
            $81 = ($80<<24>>24)==(0);
            if ($81) {
             __THREW__ = 0;
             (invoke_ii(2996,(2340656|0))|0);
             $82 = __THREW__; __THREW__ = 0;
             $83 = $82&1;
             if ($83) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2340656|0))|0);
             $84 = __THREW__; __THREW__ = 0;
             $85 = $84&1;
             if ($85) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3832,(2340656|0));
             $86 = __THREW__; __THREW__ = 0;
             $87 = $86&1;
             if ($87) {
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2340656|0))|0);
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if (!($89)) {
             $90 = HEAP32[((2340656 + 80|0))>>2]|0;
             $91 = (($90) + 24|0);
             $92 = HEAP32[$91>>2]|0;
             $93 = (($__this) + 92|0);
             HEAP32[$93>>2] = $92;
             __THREW__ = 0;
             (invoke_ii(2996,(2340656|0))|0);
             $94 = __THREW__; __THREW__ = 0;
             $95 = $94&1;
             if (!($95)) {
              $96 = HEAP8[((2340656 + 116|0))>>0]|0;
              $97 = ($96<<24>>24)==(0);
              if ($97) {
               __THREW__ = 0;
               (invoke_ii(2996,(2340656|0))|0);
               $98 = __THREW__; __THREW__ = 0;
               $99 = $98&1;
               if ($99) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2340656|0))|0);
               $100 = __THREW__; __THREW__ = 0;
               $101 = $100&1;
               if ($101) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3832,(2340656|0));
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               if ($103) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2340656|0))|0);
              $104 = __THREW__; __THREW__ = 0;
              $105 = $104&1;
              if (!($105)) {
               $106 = HEAP32[((2340656 + 80|0))>>2]|0;
               $107 = (($106) + 28|0);
               $108 = HEAP32[$107>>2]|0;
               $109 = (($__this) + 88|0);
               HEAP32[$109>>2] = $108;
               __THREW__ = 0;
               (invoke_ii(2996,(2340656|0))|0);
               $110 = __THREW__; __THREW__ = 0;
               $111 = $110&1;
               if (!($111)) {
                $112 = HEAP8[((2340656 + 116|0))>>0]|0;
                $113 = ($112<<24>>24)==(0);
                if ($113) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $114 = __THREW__; __THREW__ = 0;
                 $115 = $114&1;
                 if ($115) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3832,(2340656|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2340656|0))|0);
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 break;
                }
                $122 = HEAP32[((2340656 + 80|0))>>2]|0;
                $123 = (($122) + 24|0);
                $124 = HEAP32[$123>>2]|0;
                $125 = (($__this) + 176|0);
                HEAP32[$125>>2] = $124;
                __THREW__ = 0;
                (invoke_ii(2996,(2340656|0))|0);
                $126 = __THREW__; __THREW__ = 0;
                $127 = $126&1;
                if ($127) {
                 break;
                }
                $128 = HEAP8[((2340656 + 116|0))>>0]|0;
                $129 = ($128<<24>>24)==(0);
                if ($129) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $130 = __THREW__; __THREW__ = 0;
                 $131 = $130&1;
                 if ($131) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $132 = __THREW__; __THREW__ = 0;
                 $133 = $132&1;
                 if ($133) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3832,(2340656|0));
                 $134 = __THREW__; __THREW__ = 0;
                 $135 = $134&1;
                 if ($135) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2340656|0))|0);
                $136 = __THREW__; __THREW__ = 0;
                $137 = $136&1;
                if ($137) {
                 break;
                }
                $138 = HEAP32[((2340656 + 80|0))>>2]|0;
                $139 = (($138) + 28|0);
                $140 = HEAP32[$139>>2]|0;
                $141 = (($__this) + 172|0);
                HEAP32[$141>>2] = $140;
                __THREW__ = 0;
                (invoke_ii(2996,(2340656|0))|0);
                $142 = __THREW__; __THREW__ = 0;
                $143 = $142&1;
                if ($143) {
                 break;
                }
                $144 = HEAP8[((2340656 + 116|0))>>0]|0;
                $145 = ($144<<24>>24)==(0);
                if ($145) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $146 = __THREW__; __THREW__ = 0;
                 $147 = $146&1;
                 if ($147) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $148 = __THREW__; __THREW__ = 0;
                 $149 = $148&1;
                 if ($149) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3832,(2340656|0));
                 $150 = __THREW__; __THREW__ = 0;
                 $151 = $150&1;
                 if ($151) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2340656|0))|0);
                $152 = __THREW__; __THREW__ = 0;
                $153 = $152&1;
                if ($153) {
                 break;
                }
                $154 = HEAP32[((2340656 + 80|0))>>2]|0;
                $155 = (($154) + 32|0);
                $156 = HEAP32[$155>>2]|0;
                $157 = (($__this) + 120|0);
                HEAP32[$157>>2] = $156;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $54 = ___cxa_find_matching_catch()|0;
 $55 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($54|0);
 // unreachable;
}
function __Z69mscorlib_System_Globalization_CultureInfo_m_construct_datetime_formatP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330616);
 $0 = HEAP32[2330664>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2330672|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2330664>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z63mscorlib_System_Globalization_DateTimeFormatInfo_m_set_CalendarP48mscorlib_System_Globalization_DateTimeFormatInfoP38mscorlib_System_Globalization_Calendar($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335824);
 __THREW__ = 0;
 $0 = (invoke_ii(1992,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if (!($0)) {
    $29 = ($value|0)==(0|0);
    if (!($29)) {
     $39 = (($__this) + 72|0);
     HEAP32[$39>>2] = $value;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    __THREW__ = 0;
    $32 = (invoke_ii(3469,(2560584|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2585,($32|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($32|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2340656|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP8[((2340656 + 116|0))>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2340656|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2340656|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2340656 + 80|0))>>2]|0;
     $18 = (($17) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2607872|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_ii(3469,(2607872|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_vii(1947,($22|0),($19|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        __THREW__ = 0;
        invoke_vi(3833,($22|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z58mscorlib_System_Globalization_CultureInfo_m_get_IsReadOnlyP41mscorlib_System_Globalization_CultureInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330280);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z53mscorlib_System_Globalization_CultureInfo_m_GetFormatP41mscorlib_System_Globalization_CultureInfoP20mscorlib_System_Type($__this,$formatType) {
 $__this = $__this|0;
 $formatType = $formatType|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330328);
 HEAP32[$0>>2] = 2271128;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($2|0)==($formatType|0);
   if ($5) {
    __THREW__ = 0;
    $8 = (invoke_iii(2730,(2330184|0),($__this|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $V_0$0 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($V_0$0|0);
   }
   HEAP32[$1>>2] = 2386784;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   $11 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = ($11|0)==($formatType|0);
    if (!($14)) {
     $V_0$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_0$0|0);
    }
    __THREW__ = 0;
    $15 = (invoke_iii(2730,(2330232|0),($__this|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $V_0$0 = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_0$0|0);
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Globalization_CultureInfo_m_construct_internal_locale_from_lcidP41mscorlib_System_Globalization_CultureInfoi($__this,$lcid) {
 $__this = $__this|0;
 $lcid = $lcid|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330472);
 $0 = HEAP32[2330520>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2330528|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2330520>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($lcid|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Globalization_NumberFormatInfo_m_get_InvariantInfoP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344440);
 __THREW__ = 0;
 (invoke_ii(2996,(2348608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2348608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2228,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vii(1843,($2|0),1);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       $13 = (($2) + 8|0);
       HEAP8[$13>>0] = 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($2|0);
      }
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Globalization_DateTimeFormatInfo_m_get_InvariantInfoP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335728);
 __THREW__ = 0;
 (invoke_ii(2996,(2340656|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2340656 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2340656|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2340656|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3832,(2340656|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2340656|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2340656 + 80|0))>>2]|0;
    $15 = (($14) + 36|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2340656|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2218,($20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_iii(853,0,($20|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP8[((2340656 + 116|0))>>0]|0;
     $31 = ($30<<24>>24)==(0);
     if ($31) {
      __THREW__ = 0;
      (invoke_ii(2996,(2340656|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2340656|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3832,(2340656|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     $40 = HEAP32[((2340656 + 80|0))>>2]|0;
     $41 = (($40) + 36|0);
     HEAP32[$41>>2] = $25;
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     $44 = HEAP8[((2340656 + 116|0))>>0]|0;
     $45 = ($44<<24>>24)==(0);
     if ($45) {
      __THREW__ = 0;
      (invoke_ii(2996,(2340656|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2340656|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3832,(2340656|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     $54 = HEAP32[((2340656 + 80|0))>>2]|0;
     $55 = (($54) + 36|0);
     $56 = HEAP32[$55>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($56|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2221,($56|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2340656|0))|0);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if (!($62)) {
     $63 = HEAP8[((2340656 + 116|0))>>0]|0;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      __THREW__ = 0;
      (invoke_ii(2996,(2340656|0))|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2340656|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3832,(2340656|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if (!($72)) {
      $73 = HEAP32[((2340656 + 80|0))>>2]|0;
      $74 = (($73) + 36|0);
      $75 = HEAP32[$74>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($75|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Globalization_TextInfo_m__ctorP38mscorlib_System_Globalization_TextInfoP41mscorlib_System_Globalization_CultureInfoiPvb($__this,$ci,$lcid,$data,$read_only) {
 $__this = $__this|0;
 $ci = $ci|0;
 $lcid = $lcid|0;
 $data = $data|0;
 $read_only = $read_only|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2350240);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  $3 = $read_only&1;
  HEAP8[$2>>0] = $3;
  $4 = (($__this) + 16|0);
  HEAP32[$4>>2] = $lcid;
  $5 = (($__this) + 20|0);
  HEAP32[$5>>2] = $ci;
  $6 = ($data|0)==(0|0);
  $7 = (($__this) + 28|0);
  if ($6) {
   ;HEAP32[$7+0>>2]=HEAP32[2350288+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[2350288+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[2350288+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[2350288+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[2350288+16>>2]|0;
   $12 = (($__this) + 44|0);
   HEAP8[$12>>0] = 44;
   $V_0$0 = $ci;
  } else {
   ;HEAP32[$7+0>>2]=HEAP32[$data+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$data+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$data+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$data+12>>2]|0;HEAP32[$7+16>>2]=HEAP32[$data+16>>2]|0;
   $V_0$0 = $ci;
  }
  while(1) {
   __THREW__ = 0;
   invoke_vi(3799,($V_0$0|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    label = 3;
    break;
   }
   __THREW__ = 0;
   $18 = (invoke_iii(2730,(2273648|0),($V_0$0|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if ($20) {
    label = 3;
    break;
   }
   $21 = ($18|0)==(0|0);
   if ($21) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($V_0$0|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    label = 3;
    break;
   }
   __THREW__ = 0;
   $24 = (invoke_iii(2730,(2273648|0),($V_0$0|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if ($26) {
    label = 3;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($24|0));
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    label = 3;
    break;
   }
   __THREW__ = 0;
   $29 = (invoke_iii(2729,(2273552|0),($24|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    label = 3;
    break;
   }
   $32 = ($29|0)==(127);
   if ($32) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($V_0$0|0));
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 3;
    break;
   }
   __THREW__ = 0;
   $35 = (invoke_iii(2730,(2273648|0),($V_0$0|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if ($37) {
    label = 3;
    break;
   }
   $38 = ($35|0)==($V_0$0|0);
   if ($38) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($V_0$0|0));
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    label = 3;
    break;
   }
   __THREW__ = 0;
   $13 = (invoke_iii(2730,(2273648|0),($V_0$0|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 3;
    break;
   }
   $V_0$0 = $13;
  }
  if ((label|0) == 3) {
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   $lpad$phi$index = $8;$lpad$phi$index2 = $9;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  $41 = ($V_0$0|0)==(0|0);
  if ($41) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  invoke_vi(3799,($V_0$0|0));
  $42 = __THREW__; __THREW__ = 0;
  $43 = $42&1;
  if (!($43)) {
   __THREW__ = 0;
   $44 = (invoke_iii(2729,(2273552|0),($V_0$0|0))|0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    if (!((($44|0) == 44) | (($44|0) == 31))) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $47 = (($__this) + 24|0);
    HEAP8[$47>>0] = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN14ActionInvoker3I27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsS1_E6InvokeEPFvPvibbES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)!=(0);
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$5,$9);
 STACKTOP = sp;return (0|0);
}
function __Z72mscorlib_System_Globalization_CultureInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z102mscorlib_System_Globalization_CultureInfo_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map19P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z102mscorlib_System_Globalization_CultureInfo_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map1AP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Globalization_DateTimeFormatFlags_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Globalization_GregorianCalendar_m__ctor_mscorlib_System_VoidP47mscorlib_System_Globalization_GregorianCalendar($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342352);
 __THREW__ = 0;
 invoke_vii(1840,($__this|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z77mscorlib_System_Globalization_DateTimeFormatInfo_m__ctor_mscorlib_System_VoidP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334528);
 __THREW__ = 0;
 invoke_vii(1836,($__this|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57mscorlib_System_Globalization_DateTimeFormatInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0;
 var $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0;
 var $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0;
 var $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0;
 var $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0;
 var $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0;
 var $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0;
 var $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334576);
 __THREW__ = 0;
 invoke_v(583);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[3027480>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2340656|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP32[((2340656 + 80|0))>>2]|0;
    $6 = (($5) + 4|0);
    HEAP32[$6>>2] = $2;
    $7 = HEAP32[3027488>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2340656|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[((2340656 + 80|0))>>2]|0;
     $11 = (($10) + 8|0);
     HEAP32[$11>>2] = $7;
     $12 = HEAP32[3027496>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = HEAP32[((2340656 + 80|0))>>2]|0;
      $16 = (($15) + 12|0);
      HEAP32[$16>>2] = $12;
      __THREW__ = 0;
      (invoke_ii(2996,(1168432|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_iii(2758,(1168432|0),7)|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        invoke_vi(3799,($19|0));
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         $24 = (($19) + 12|0);
         $25 = HEAP32[$24>>2]|0;
         $26 = ($25|0)==(0);
         if ($26) {
          __THREW__ = 0;
          $27 = (invoke_i(132)|0);
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if ($29) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($27|0));
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if ($31) {
           break;
          }
         }
         $34 = HEAP32[3027504>>2]|0;
         __THREW__ = 0;
         invoke_vii(3492,($19|0),($34|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if (!($36)) {
          $37 = HEAP32[3027504>>2]|0;
          $38 = (($19) + 16|0);
          HEAP32[$38>>2] = $37;
          __THREW__ = 0;
          invoke_vi(3799,($19|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if (!($40)) {
           $41 = HEAP32[$24>>2]|0;
           $42 = ($41>>>0)<(2);
           if ($42) {
            __THREW__ = 0;
            $43 = (invoke_i(132)|0);
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if ($45) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($43|0));
            $46 = __THREW__; __THREW__ = 0;
            $47 = $46&1;
            if ($47) {
             break;
            }
           }
           $48 = HEAP32[3027512>>2]|0;
           __THREW__ = 0;
           invoke_vii(3492,($19|0),($48|0));
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if (!($50)) {
            $51 = HEAP32[3027512>>2]|0;
            $52 = HEAP32[$19>>2]|0;
            $53 = (($52) + 92|0);
            $54 = HEAP32[$53>>2]|0;
            $55 = (($38) + ($54)|0);
            HEAP32[$55>>2] = $51;
            __THREW__ = 0;
            invoke_vi(3799,($19|0));
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if (!($57)) {
             $58 = HEAP32[$24>>2]|0;
             $59 = ($58>>>0)<(3);
             if ($59) {
              __THREW__ = 0;
              $60 = (invoke_i(132)|0);
              $61 = __THREW__; __THREW__ = 0;
              $62 = $61&1;
              if ($62) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($60|0));
              $63 = __THREW__; __THREW__ = 0;
              $64 = $63&1;
              if ($64) {
               break;
              }
             }
             $65 = HEAP32[3027520>>2]|0;
             __THREW__ = 0;
             invoke_vii(3492,($19|0),($65|0));
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if (!($67)) {
              $68 = HEAP32[3027520>>2]|0;
              $69 = HEAP32[$19>>2]|0;
              $70 = (($69) + 92|0);
              $71 = HEAP32[$70>>2]|0;
              $72 = $71 << 1;
              $73 = (($38) + ($72)|0);
              HEAP32[$73>>2] = $68;
              __THREW__ = 0;
              invoke_vi(3799,($19|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if (!($75)) {
               $76 = HEAP32[$24>>2]|0;
               $77 = ($76>>>0)<(4);
               if ($77) {
                __THREW__ = 0;
                $78 = (invoke_i(132)|0);
                $79 = __THREW__; __THREW__ = 0;
                $80 = $79&1;
                if ($80) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($78|0));
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if ($82) {
                 break;
                }
               }
               $83 = HEAP32[3027528>>2]|0;
               __THREW__ = 0;
               invoke_vii(3492,($19|0),($83|0));
               $84 = __THREW__; __THREW__ = 0;
               $85 = $84&1;
               if (!($85)) {
                $86 = HEAP32[3027528>>2]|0;
                $87 = HEAP32[$19>>2]|0;
                $88 = (($87) + 92|0);
                $89 = HEAP32[$88>>2]|0;
                $90 = ($89*3)|0;
                $91 = (($38) + ($90)|0);
                HEAP32[$91>>2] = $86;
                __THREW__ = 0;
                invoke_vi(3799,($19|0));
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if (!($93)) {
                 $94 = HEAP32[$24>>2]|0;
                 $95 = ($94>>>0)<(5);
                 if ($95) {
                  __THREW__ = 0;
                  $96 = (invoke_i(132)|0);
                  $97 = __THREW__; __THREW__ = 0;
                  $98 = $97&1;
                  if ($98) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($96|0));
                  $99 = __THREW__; __THREW__ = 0;
                  $100 = $99&1;
                  if ($100) {
                   break;
                  }
                 }
                 $101 = HEAP32[3027536>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($19|0),($101|0));
                 $102 = __THREW__; __THREW__ = 0;
                 $103 = $102&1;
                 if ($103) {
                  break;
                 }
                 $104 = HEAP32[3027536>>2]|0;
                 $105 = HEAP32[$19>>2]|0;
                 $106 = (($105) + 92|0);
                 $107 = HEAP32[$106>>2]|0;
                 $108 = $107 << 2;
                 $109 = (($38) + ($108)|0);
                 HEAP32[$109>>2] = $104;
                 __THREW__ = 0;
                 invoke_vi(3799,($19|0));
                 $110 = __THREW__; __THREW__ = 0;
                 $111 = $110&1;
                 if ($111) {
                  break;
                 }
                 $112 = HEAP32[$24>>2]|0;
                 $113 = ($112>>>0)<(6);
                 if ($113) {
                  __THREW__ = 0;
                  $114 = (invoke_i(132)|0);
                  $115 = __THREW__; __THREW__ = 0;
                  $116 = $115&1;
                  if ($116) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($114|0));
                  $117 = __THREW__; __THREW__ = 0;
                  $118 = $117&1;
                  if ($118) {
                   break;
                  }
                 }
                 $119 = HEAP32[3027544>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($19|0),($119|0));
                 $120 = __THREW__; __THREW__ = 0;
                 $121 = $120&1;
                 if ($121) {
                  break;
                 }
                 $122 = HEAP32[3027544>>2]|0;
                 $123 = HEAP32[$19>>2]|0;
                 $124 = (($123) + 92|0);
                 $125 = HEAP32[$124>>2]|0;
                 $126 = ($125*5)|0;
                 $127 = (($38) + ($126)|0);
                 HEAP32[$127>>2] = $122;
                 __THREW__ = 0;
                 invoke_vi(3799,($19|0));
                 $128 = __THREW__; __THREW__ = 0;
                 $129 = $128&1;
                 if ($129) {
                  break;
                 }
                 $130 = HEAP32[$24>>2]|0;
                 $131 = ($130>>>0)<(7);
                 if ($131) {
                  __THREW__ = 0;
                  $132 = (invoke_i(132)|0);
                  $133 = __THREW__; __THREW__ = 0;
                  $134 = $133&1;
                  if ($134) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($132|0));
                  $135 = __THREW__; __THREW__ = 0;
                  $136 = $135&1;
                  if ($136) {
                   break;
                  }
                 }
                 $137 = HEAP32[3027552>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($19|0),($137|0));
                 $138 = __THREW__; __THREW__ = 0;
                 $139 = $138&1;
                 if ($139) {
                  break;
                 }
                 $140 = HEAP32[3027552>>2]|0;
                 $141 = HEAP32[$19>>2]|0;
                 $142 = (($141) + 92|0);
                 $143 = HEAP32[$142>>2]|0;
                 $144 = ($143*6)|0;
                 $145 = (($38) + ($144)|0);
                 HEAP32[$145>>2] = $140;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $146 = __THREW__; __THREW__ = 0;
                 $147 = $146&1;
                 if ($147) {
                  break;
                 }
                 $148 = HEAP32[((2340656 + 80|0))>>2]|0;
                 $149 = (($148) + 16|0);
                 HEAP32[$149>>2] = $19;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1168432|0))|0);
                 $150 = __THREW__; __THREW__ = 0;
                 $151 = $150&1;
                 if ($151) {
                  break;
                 }
                 __THREW__ = 0;
                 $152 = (invoke_iii(2758,(1168432|0),7)|0);
                 $153 = __THREW__; __THREW__ = 0;
                 $154 = $153&1;
                 if ($154) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $155 = __THREW__; __THREW__ = 0;
                 $156 = $155&1;
                 if ($156) {
                  break;
                 }
                 $157 = (($152) + 12|0);
                 $158 = HEAP32[$157>>2]|0;
                 $159 = ($158|0)==(0);
                 if ($159) {
                  __THREW__ = 0;
                  $160 = (invoke_i(132)|0);
                  $161 = __THREW__; __THREW__ = 0;
                  $162 = $161&1;
                  if ($162) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($160|0));
                  $163 = __THREW__; __THREW__ = 0;
                  $164 = $163&1;
                  if ($164) {
                   break;
                  }
                 }
                 $165 = HEAP32[3027560>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($152|0),($165|0));
                 $166 = __THREW__; __THREW__ = 0;
                 $167 = $166&1;
                 if ($167) {
                  break;
                 }
                 $168 = HEAP32[3027560>>2]|0;
                 $169 = (($152) + 16|0);
                 HEAP32[$169>>2] = $168;
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $170 = __THREW__; __THREW__ = 0;
                 $171 = $170&1;
                 if ($171) {
                  break;
                 }
                 $172 = HEAP32[$157>>2]|0;
                 $173 = ($172>>>0)<(2);
                 if ($173) {
                  __THREW__ = 0;
                  $174 = (invoke_i(132)|0);
                  $175 = __THREW__; __THREW__ = 0;
                  $176 = $175&1;
                  if ($176) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($174|0));
                  $177 = __THREW__; __THREW__ = 0;
                  $178 = $177&1;
                  if ($178) {
                   break;
                  }
                 }
                 $179 = HEAP32[3027568>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($152|0),($179|0));
                 $180 = __THREW__; __THREW__ = 0;
                 $181 = $180&1;
                 if ($181) {
                  break;
                 }
                 $182 = HEAP32[3027568>>2]|0;
                 $183 = HEAP32[$152>>2]|0;
                 $184 = (($183) + 92|0);
                 $185 = HEAP32[$184>>2]|0;
                 $186 = (($169) + ($185)|0);
                 HEAP32[$186>>2] = $182;
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $187 = __THREW__; __THREW__ = 0;
                 $188 = $187&1;
                 if ($188) {
                  break;
                 }
                 $189 = HEAP32[$157>>2]|0;
                 $190 = ($189>>>0)<(3);
                 if ($190) {
                  __THREW__ = 0;
                  $191 = (invoke_i(132)|0);
                  $192 = __THREW__; __THREW__ = 0;
                  $193 = $192&1;
                  if ($193) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($191|0));
                  $194 = __THREW__; __THREW__ = 0;
                  $195 = $194&1;
                  if ($195) {
                   break;
                  }
                 }
                 $196 = HEAP32[3027576>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($152|0),($196|0));
                 $197 = __THREW__; __THREW__ = 0;
                 $198 = $197&1;
                 if ($198) {
                  break;
                 }
                 $199 = HEAP32[3027576>>2]|0;
                 $200 = HEAP32[$152>>2]|0;
                 $201 = (($200) + 92|0);
                 $202 = HEAP32[$201>>2]|0;
                 $203 = $202 << 1;
                 $204 = (($169) + ($203)|0);
                 HEAP32[$204>>2] = $199;
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $205 = __THREW__; __THREW__ = 0;
                 $206 = $205&1;
                 if ($206) {
                  break;
                 }
                 $207 = HEAP32[$157>>2]|0;
                 $208 = ($207>>>0)<(4);
                 if ($208) {
                  __THREW__ = 0;
                  $209 = (invoke_i(132)|0);
                  $210 = __THREW__; __THREW__ = 0;
                  $211 = $210&1;
                  if ($211) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($209|0));
                  $212 = __THREW__; __THREW__ = 0;
                  $213 = $212&1;
                  if ($213) {
                   break;
                  }
                 }
                 $214 = HEAP32[3027584>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($152|0),($214|0));
                 $215 = __THREW__; __THREW__ = 0;
                 $216 = $215&1;
                 if ($216) {
                  break;
                 }
                 $217 = HEAP32[3027584>>2]|0;
                 $218 = HEAP32[$152>>2]|0;
                 $219 = (($218) + 92|0);
                 $220 = HEAP32[$219>>2]|0;
                 $221 = ($220*3)|0;
                 $222 = (($169) + ($221)|0);
                 HEAP32[$222>>2] = $217;
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $223 = __THREW__; __THREW__ = 0;
                 $224 = $223&1;
                 if ($224) {
                  break;
                 }
                 $225 = HEAP32[$157>>2]|0;
                 $226 = ($225>>>0)<(5);
                 if ($226) {
                  __THREW__ = 0;
                  $227 = (invoke_i(132)|0);
                  $228 = __THREW__; __THREW__ = 0;
                  $229 = $228&1;
                  if ($229) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($227|0));
                  $230 = __THREW__; __THREW__ = 0;
                  $231 = $230&1;
                  if ($231) {
                   break;
                  }
                 }
                 $232 = HEAP32[3027592>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($152|0),($232|0));
                 $233 = __THREW__; __THREW__ = 0;
                 $234 = $233&1;
                 if ($234) {
                  break;
                 }
                 $235 = HEAP32[3027592>>2]|0;
                 $236 = HEAP32[$152>>2]|0;
                 $237 = (($236) + 92|0);
                 $238 = HEAP32[$237>>2]|0;
                 $239 = $238 << 2;
                 $240 = (($169) + ($239)|0);
                 HEAP32[$240>>2] = $235;
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $241 = __THREW__; __THREW__ = 0;
                 $242 = $241&1;
                 if ($242) {
                  break;
                 }
                 $243 = HEAP32[$157>>2]|0;
                 $244 = ($243>>>0)<(6);
                 if ($244) {
                  __THREW__ = 0;
                  $245 = (invoke_i(132)|0);
                  $246 = __THREW__; __THREW__ = 0;
                  $247 = $246&1;
                  if ($247) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($245|0));
                  $248 = __THREW__; __THREW__ = 0;
                  $249 = $248&1;
                  if ($249) {
                   break;
                  }
                 }
                 $250 = HEAP32[3027600>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($152|0),($250|0));
                 $251 = __THREW__; __THREW__ = 0;
                 $252 = $251&1;
                 if ($252) {
                  break;
                 }
                 $253 = HEAP32[3027600>>2]|0;
                 $254 = HEAP32[$152>>2]|0;
                 $255 = (($254) + 92|0);
                 $256 = HEAP32[$255>>2]|0;
                 $257 = ($256*5)|0;
                 $258 = (($169) + ($257)|0);
                 HEAP32[$258>>2] = $253;
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $259 = __THREW__; __THREW__ = 0;
                 $260 = $259&1;
                 if ($260) {
                  break;
                 }
                 $261 = HEAP32[$157>>2]|0;
                 $262 = ($261>>>0)<(7);
                 if ($262) {
                  __THREW__ = 0;
                  $263 = (invoke_i(132)|0);
                  $264 = __THREW__; __THREW__ = 0;
                  $265 = $264&1;
                  if ($265) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($263|0));
                  $266 = __THREW__; __THREW__ = 0;
                  $267 = $266&1;
                  if ($267) {
                   break;
                  }
                 }
                 $268 = HEAP32[3027608>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($152|0),($268|0));
                 $269 = __THREW__; __THREW__ = 0;
                 $270 = $269&1;
                 if ($270) {
                  break;
                 }
                 $271 = HEAP32[3027608>>2]|0;
                 $272 = HEAP32[$152>>2]|0;
                 $273 = (($272) + 92|0);
                 $274 = HEAP32[$273>>2]|0;
                 $275 = ($274*6)|0;
                 $276 = (($169) + ($275)|0);
                 HEAP32[$276>>2] = $271;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $277 = __THREW__; __THREW__ = 0;
                 $278 = $277&1;
                 if ($278) {
                  break;
                 }
                 $279 = HEAP32[((2340656 + 80|0))>>2]|0;
                 $280 = (($279) + 20|0);
                 HEAP32[$280>>2] = $152;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1168432|0))|0);
                 $281 = __THREW__; __THREW__ = 0;
                 $282 = $281&1;
                 if ($282) {
                  break;
                 }
                 __THREW__ = 0;
                 $283 = (invoke_iii(2758,(1168432|0),13)|0);
                 $284 = __THREW__; __THREW__ = 0;
                 $285 = $284&1;
                 if ($285) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $286 = __THREW__; __THREW__ = 0;
                 $287 = $286&1;
                 if ($287) {
                  break;
                 }
                 $288 = (($283) + 12|0);
                 $289 = HEAP32[$288>>2]|0;
                 $290 = ($289|0)==(0);
                 if ($290) {
                  __THREW__ = 0;
                  $291 = (invoke_i(132)|0);
                  $292 = __THREW__; __THREW__ = 0;
                  $293 = $292&1;
                  if ($293) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($291|0));
                  $294 = __THREW__; __THREW__ = 0;
                  $295 = $294&1;
                  if ($295) {
                   break;
                  }
                 }
                 $296 = HEAP32[3027616>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($296|0));
                 $297 = __THREW__; __THREW__ = 0;
                 $298 = $297&1;
                 if ($298) {
                  break;
                 }
                 $299 = HEAP32[3027616>>2]|0;
                 $300 = (($283) + 16|0);
                 HEAP32[$300>>2] = $299;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $301 = __THREW__; __THREW__ = 0;
                 $302 = $301&1;
                 if ($302) {
                  break;
                 }
                 $303 = HEAP32[$288>>2]|0;
                 $304 = ($303>>>0)<(2);
                 if ($304) {
                  __THREW__ = 0;
                  $305 = (invoke_i(132)|0);
                  $306 = __THREW__; __THREW__ = 0;
                  $307 = $306&1;
                  if ($307) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($305|0));
                  $308 = __THREW__; __THREW__ = 0;
                  $309 = $308&1;
                  if ($309) {
                   break;
                  }
                 }
                 $310 = HEAP32[3027624>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($310|0));
                 $311 = __THREW__; __THREW__ = 0;
                 $312 = $311&1;
                 if ($312) {
                  break;
                 }
                 $313 = HEAP32[3027624>>2]|0;
                 $314 = HEAP32[$283>>2]|0;
                 $315 = (($314) + 92|0);
                 $316 = HEAP32[$315>>2]|0;
                 $317 = (($300) + ($316)|0);
                 HEAP32[$317>>2] = $313;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $318 = __THREW__; __THREW__ = 0;
                 $319 = $318&1;
                 if ($319) {
                  break;
                 }
                 $320 = HEAP32[$288>>2]|0;
                 $321 = ($320>>>0)<(3);
                 if ($321) {
                  __THREW__ = 0;
                  $322 = (invoke_i(132)|0);
                  $323 = __THREW__; __THREW__ = 0;
                  $324 = $323&1;
                  if ($324) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($322|0));
                  $325 = __THREW__; __THREW__ = 0;
                  $326 = $325&1;
                  if ($326) {
                   break;
                  }
                 }
                 $327 = HEAP32[3027632>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($327|0));
                 $328 = __THREW__; __THREW__ = 0;
                 $329 = $328&1;
                 if ($329) {
                  break;
                 }
                 $330 = HEAP32[3027632>>2]|0;
                 $331 = HEAP32[$283>>2]|0;
                 $332 = (($331) + 92|0);
                 $333 = HEAP32[$332>>2]|0;
                 $334 = $333 << 1;
                 $335 = (($300) + ($334)|0);
                 HEAP32[$335>>2] = $330;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $336 = __THREW__; __THREW__ = 0;
                 $337 = $336&1;
                 if ($337) {
                  break;
                 }
                 $338 = HEAP32[$288>>2]|0;
                 $339 = ($338>>>0)<(4);
                 if ($339) {
                  __THREW__ = 0;
                  $340 = (invoke_i(132)|0);
                  $341 = __THREW__; __THREW__ = 0;
                  $342 = $341&1;
                  if ($342) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($340|0));
                  $343 = __THREW__; __THREW__ = 0;
                  $344 = $343&1;
                  if ($344) {
                   break;
                  }
                 }
                 $345 = HEAP32[3027640>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($345|0));
                 $346 = __THREW__; __THREW__ = 0;
                 $347 = $346&1;
                 if ($347) {
                  break;
                 }
                 $348 = HEAP32[3027640>>2]|0;
                 $349 = HEAP32[$283>>2]|0;
                 $350 = (($349) + 92|0);
                 $351 = HEAP32[$350>>2]|0;
                 $352 = ($351*3)|0;
                 $353 = (($300) + ($352)|0);
                 HEAP32[$353>>2] = $348;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $354 = __THREW__; __THREW__ = 0;
                 $355 = $354&1;
                 if ($355) {
                  break;
                 }
                 $356 = HEAP32[$288>>2]|0;
                 $357 = ($356>>>0)<(5);
                 if ($357) {
                  __THREW__ = 0;
                  $358 = (invoke_i(132)|0);
                  $359 = __THREW__; __THREW__ = 0;
                  $360 = $359&1;
                  if ($360) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($358|0));
                  $361 = __THREW__; __THREW__ = 0;
                  $362 = $361&1;
                  if ($362) {
                   break;
                  }
                 }
                 $363 = HEAP32[3027648>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($363|0));
                 $364 = __THREW__; __THREW__ = 0;
                 $365 = $364&1;
                 if ($365) {
                  break;
                 }
                 $366 = HEAP32[3027648>>2]|0;
                 $367 = HEAP32[$283>>2]|0;
                 $368 = (($367) + 92|0);
                 $369 = HEAP32[$368>>2]|0;
                 $370 = $369 << 2;
                 $371 = (($300) + ($370)|0);
                 HEAP32[$371>>2] = $366;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $372 = __THREW__; __THREW__ = 0;
                 $373 = $372&1;
                 if ($373) {
                  break;
                 }
                 $374 = HEAP32[$288>>2]|0;
                 $375 = ($374>>>0)<(6);
                 if ($375) {
                  __THREW__ = 0;
                  $376 = (invoke_i(132)|0);
                  $377 = __THREW__; __THREW__ = 0;
                  $378 = $377&1;
                  if ($378) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($376|0));
                  $379 = __THREW__; __THREW__ = 0;
                  $380 = $379&1;
                  if ($380) {
                   break;
                  }
                 }
                 $381 = HEAP32[3027656>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($381|0));
                 $382 = __THREW__; __THREW__ = 0;
                 $383 = $382&1;
                 if ($383) {
                  break;
                 }
                 $384 = HEAP32[3027656>>2]|0;
                 $385 = HEAP32[$283>>2]|0;
                 $386 = (($385) + 92|0);
                 $387 = HEAP32[$386>>2]|0;
                 $388 = ($387*5)|0;
                 $389 = (($300) + ($388)|0);
                 HEAP32[$389>>2] = $384;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $390 = __THREW__; __THREW__ = 0;
                 $391 = $390&1;
                 if ($391) {
                  break;
                 }
                 $392 = HEAP32[$288>>2]|0;
                 $393 = ($392>>>0)<(7);
                 if ($393) {
                  __THREW__ = 0;
                  $394 = (invoke_i(132)|0);
                  $395 = __THREW__; __THREW__ = 0;
                  $396 = $395&1;
                  if ($396) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($394|0));
                  $397 = __THREW__; __THREW__ = 0;
                  $398 = $397&1;
                  if ($398) {
                   break;
                  }
                 }
                 $399 = HEAP32[3027664>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($399|0));
                 $400 = __THREW__; __THREW__ = 0;
                 $401 = $400&1;
                 if ($401) {
                  break;
                 }
                 $402 = HEAP32[3027664>>2]|0;
                 $403 = HEAP32[$283>>2]|0;
                 $404 = (($403) + 92|0);
                 $405 = HEAP32[$404>>2]|0;
                 $406 = ($405*6)|0;
                 $407 = (($300) + ($406)|0);
                 HEAP32[$407>>2] = $402;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $408 = __THREW__; __THREW__ = 0;
                 $409 = $408&1;
                 if ($409) {
                  break;
                 }
                 $410 = HEAP32[$288>>2]|0;
                 $411 = ($410>>>0)<(8);
                 if ($411) {
                  __THREW__ = 0;
                  $412 = (invoke_i(132)|0);
                  $413 = __THREW__; __THREW__ = 0;
                  $414 = $413&1;
                  if ($414) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($412|0));
                  $415 = __THREW__; __THREW__ = 0;
                  $416 = $415&1;
                  if ($416) {
                   break;
                  }
                 }
                 $417 = HEAP32[3027672>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($417|0));
                 $418 = __THREW__; __THREW__ = 0;
                 $419 = $418&1;
                 if ($419) {
                  break;
                 }
                 $420 = HEAP32[3027672>>2]|0;
                 $421 = HEAP32[$283>>2]|0;
                 $422 = (($421) + 92|0);
                 $423 = HEAP32[$422>>2]|0;
                 $424 = ($423*7)|0;
                 $425 = (($300) + ($424)|0);
                 HEAP32[$425>>2] = $420;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $426 = __THREW__; __THREW__ = 0;
                 $427 = $426&1;
                 if ($427) {
                  break;
                 }
                 $428 = HEAP32[$288>>2]|0;
                 $429 = ($428>>>0)<(9);
                 if ($429) {
                  __THREW__ = 0;
                  $430 = (invoke_i(132)|0);
                  $431 = __THREW__; __THREW__ = 0;
                  $432 = $431&1;
                  if ($432) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($430|0));
                  $433 = __THREW__; __THREW__ = 0;
                  $434 = $433&1;
                  if ($434) {
                   break;
                  }
                 }
                 $435 = HEAP32[3027680>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($435|0));
                 $436 = __THREW__; __THREW__ = 0;
                 $437 = $436&1;
                 if ($437) {
                  break;
                 }
                 $438 = HEAP32[3027680>>2]|0;
                 $439 = HEAP32[$283>>2]|0;
                 $440 = (($439) + 92|0);
                 $441 = HEAP32[$440>>2]|0;
                 $442 = $441 << 3;
                 $443 = (($300) + ($442)|0);
                 HEAP32[$443>>2] = $438;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $444 = __THREW__; __THREW__ = 0;
                 $445 = $444&1;
                 if ($445) {
                  break;
                 }
                 $446 = HEAP32[$288>>2]|0;
                 $447 = ($446>>>0)<(10);
                 if ($447) {
                  __THREW__ = 0;
                  $448 = (invoke_i(132)|0);
                  $449 = __THREW__; __THREW__ = 0;
                  $450 = $449&1;
                  if ($450) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($448|0));
                  $451 = __THREW__; __THREW__ = 0;
                  $452 = $451&1;
                  if ($452) {
                   break;
                  }
                 }
                 $453 = HEAP32[3027688>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($453|0));
                 $454 = __THREW__; __THREW__ = 0;
                 $455 = $454&1;
                 if ($455) {
                  break;
                 }
                 $456 = HEAP32[3027688>>2]|0;
                 $457 = HEAP32[$283>>2]|0;
                 $458 = (($457) + 92|0);
                 $459 = HEAP32[$458>>2]|0;
                 $460 = ($459*9)|0;
                 $461 = (($300) + ($460)|0);
                 HEAP32[$461>>2] = $456;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $462 = __THREW__; __THREW__ = 0;
                 $463 = $462&1;
                 if ($463) {
                  break;
                 }
                 $464 = HEAP32[$288>>2]|0;
                 $465 = ($464>>>0)<(11);
                 if ($465) {
                  __THREW__ = 0;
                  $466 = (invoke_i(132)|0);
                  $467 = __THREW__; __THREW__ = 0;
                  $468 = $467&1;
                  if ($468) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($466|0));
                  $469 = __THREW__; __THREW__ = 0;
                  $470 = $469&1;
                  if ($470) {
                   break;
                  }
                 }
                 $471 = HEAP32[3027696>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($471|0));
                 $472 = __THREW__; __THREW__ = 0;
                 $473 = $472&1;
                 if ($473) {
                  break;
                 }
                 $474 = HEAP32[3027696>>2]|0;
                 $475 = HEAP32[$283>>2]|0;
                 $476 = (($475) + 92|0);
                 $477 = HEAP32[$476>>2]|0;
                 $478 = ($477*10)|0;
                 $479 = (($300) + ($478)|0);
                 HEAP32[$479>>2] = $474;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $480 = __THREW__; __THREW__ = 0;
                 $481 = $480&1;
                 if ($481) {
                  break;
                 }
                 $482 = HEAP32[$288>>2]|0;
                 $483 = ($482>>>0)<(12);
                 if ($483) {
                  __THREW__ = 0;
                  $484 = (invoke_i(132)|0);
                  $485 = __THREW__; __THREW__ = 0;
                  $486 = $485&1;
                  if ($486) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($484|0));
                  $487 = __THREW__; __THREW__ = 0;
                  $488 = $487&1;
                  if ($488) {
                   break;
                  }
                 }
                 $489 = HEAP32[3027704>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($489|0));
                 $490 = __THREW__; __THREW__ = 0;
                 $491 = $490&1;
                 if ($491) {
                  break;
                 }
                 $492 = HEAP32[3027704>>2]|0;
                 $493 = HEAP32[$283>>2]|0;
                 $494 = (($493) + 92|0);
                 $495 = HEAP32[$494>>2]|0;
                 $496 = ($495*11)|0;
                 $497 = (($300) + ($496)|0);
                 HEAP32[$497>>2] = $492;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $498 = __THREW__; __THREW__ = 0;
                 $499 = $498&1;
                 if ($499) {
                  break;
                 }
                 $500 = HEAP8[((2191608 + 116|0))>>0]|0;
                 $501 = ($500<<24>>24)==(0);
                 if ($501) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2191608|0))|0);
                  $502 = __THREW__; __THREW__ = 0;
                  $503 = $502&1;
                  if ($503) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2191608|0))|0);
                  $504 = __THREW__; __THREW__ = 0;
                  $505 = $504&1;
                  if ($505) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3832,(2191608|0));
                  $506 = __THREW__; __THREW__ = 0;
                  $507 = $506&1;
                  if ($507) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $508 = __THREW__; __THREW__ = 0;
                 $509 = $508&1;
                 if ($509) {
                  break;
                 }
                 $510 = HEAP32[((2191608 + 80|0))>>2]|0;
                 $511 = HEAP32[$510>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($283|0));
                 $512 = __THREW__; __THREW__ = 0;
                 $513 = $512&1;
                 if ($513) {
                  break;
                 }
                 $514 = HEAP32[$288>>2]|0;
                 $515 = ($514>>>0)<(13);
                 if ($515) {
                  __THREW__ = 0;
                  $516 = (invoke_i(132)|0);
                  $517 = __THREW__; __THREW__ = 0;
                  $518 = $517&1;
                  if ($518) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($516|0));
                  $519 = __THREW__; __THREW__ = 0;
                  $520 = $519&1;
                  if ($520) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($283|0),($511|0));
                 $521 = __THREW__; __THREW__ = 0;
                 $522 = $521&1;
                 if ($522) {
                  break;
                 }
                 $523 = HEAP32[$283>>2]|0;
                 $524 = (($523) + 92|0);
                 $525 = HEAP32[$524>>2]|0;
                 $526 = ($525*12)|0;
                 $527 = (($300) + ($526)|0);
                 HEAP32[$527>>2] = $511;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $528 = __THREW__; __THREW__ = 0;
                 $529 = $528&1;
                 if ($529) {
                  break;
                 }
                 $530 = HEAP32[((2340656 + 80|0))>>2]|0;
                 $531 = (($530) + 24|0);
                 HEAP32[$531>>2] = $283;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1168432|0))|0);
                 $532 = __THREW__; __THREW__ = 0;
                 $533 = $532&1;
                 if ($533) {
                  break;
                 }
                 __THREW__ = 0;
                 $534 = (invoke_iii(2758,(1168432|0),13)|0);
                 $535 = __THREW__; __THREW__ = 0;
                 $536 = $535&1;
                 if ($536) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $537 = __THREW__; __THREW__ = 0;
                 $538 = $537&1;
                 if ($538) {
                  break;
                 }
                 $539 = (($534) + 12|0);
                 $540 = HEAP32[$539>>2]|0;
                 $541 = ($540|0)==(0);
                 if ($541) {
                  __THREW__ = 0;
                  $542 = (invoke_i(132)|0);
                  $543 = __THREW__; __THREW__ = 0;
                  $544 = $543&1;
                  if ($544) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($542|0));
                  $545 = __THREW__; __THREW__ = 0;
                  $546 = $545&1;
                  if ($546) {
                   break;
                  }
                 }
                 $547 = HEAP32[3027712>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($547|0));
                 $548 = __THREW__; __THREW__ = 0;
                 $549 = $548&1;
                 if ($549) {
                  break;
                 }
                 $550 = HEAP32[3027712>>2]|0;
                 $551 = (($534) + 16|0);
                 HEAP32[$551>>2] = $550;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $552 = __THREW__; __THREW__ = 0;
                 $553 = $552&1;
                 if ($553) {
                  break;
                 }
                 $554 = HEAP32[$539>>2]|0;
                 $555 = ($554>>>0)<(2);
                 if ($555) {
                  __THREW__ = 0;
                  $556 = (invoke_i(132)|0);
                  $557 = __THREW__; __THREW__ = 0;
                  $558 = $557&1;
                  if ($558) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($556|0));
                  $559 = __THREW__; __THREW__ = 0;
                  $560 = $559&1;
                  if ($560) {
                   break;
                  }
                 }
                 $561 = HEAP32[3027720>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($561|0));
                 $562 = __THREW__; __THREW__ = 0;
                 $563 = $562&1;
                 if ($563) {
                  break;
                 }
                 $564 = HEAP32[3027720>>2]|0;
                 $565 = HEAP32[$534>>2]|0;
                 $566 = (($565) + 92|0);
                 $567 = HEAP32[$566>>2]|0;
                 $568 = (($551) + ($567)|0);
                 HEAP32[$568>>2] = $564;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $569 = __THREW__; __THREW__ = 0;
                 $570 = $569&1;
                 if ($570) {
                  break;
                 }
                 $571 = HEAP32[$539>>2]|0;
                 $572 = ($571>>>0)<(3);
                 if ($572) {
                  __THREW__ = 0;
                  $573 = (invoke_i(132)|0);
                  $574 = __THREW__; __THREW__ = 0;
                  $575 = $574&1;
                  if ($575) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($573|0));
                  $576 = __THREW__; __THREW__ = 0;
                  $577 = $576&1;
                  if ($577) {
                   break;
                  }
                 }
                 $578 = HEAP32[3027728>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($578|0));
                 $579 = __THREW__; __THREW__ = 0;
                 $580 = $579&1;
                 if ($580) {
                  break;
                 }
                 $581 = HEAP32[3027728>>2]|0;
                 $582 = HEAP32[$534>>2]|0;
                 $583 = (($582) + 92|0);
                 $584 = HEAP32[$583>>2]|0;
                 $585 = $584 << 1;
                 $586 = (($551) + ($585)|0);
                 HEAP32[$586>>2] = $581;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $587 = __THREW__; __THREW__ = 0;
                 $588 = $587&1;
                 if ($588) {
                  break;
                 }
                 $589 = HEAP32[$539>>2]|0;
                 $590 = ($589>>>0)<(4);
                 if ($590) {
                  __THREW__ = 0;
                  $591 = (invoke_i(132)|0);
                  $592 = __THREW__; __THREW__ = 0;
                  $593 = $592&1;
                  if ($593) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($591|0));
                  $594 = __THREW__; __THREW__ = 0;
                  $595 = $594&1;
                  if ($595) {
                   break;
                  }
                 }
                 $596 = HEAP32[3027736>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($596|0));
                 $597 = __THREW__; __THREW__ = 0;
                 $598 = $597&1;
                 if ($598) {
                  break;
                 }
                 $599 = HEAP32[3027736>>2]|0;
                 $600 = HEAP32[$534>>2]|0;
                 $601 = (($600) + 92|0);
                 $602 = HEAP32[$601>>2]|0;
                 $603 = ($602*3)|0;
                 $604 = (($551) + ($603)|0);
                 HEAP32[$604>>2] = $599;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $605 = __THREW__; __THREW__ = 0;
                 $606 = $605&1;
                 if ($606) {
                  break;
                 }
                 $607 = HEAP32[$539>>2]|0;
                 $608 = ($607>>>0)<(5);
                 if ($608) {
                  __THREW__ = 0;
                  $609 = (invoke_i(132)|0);
                  $610 = __THREW__; __THREW__ = 0;
                  $611 = $610&1;
                  if ($611) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($609|0));
                  $612 = __THREW__; __THREW__ = 0;
                  $613 = $612&1;
                  if ($613) {
                   break;
                  }
                 }
                 $614 = HEAP32[3027744>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($614|0));
                 $615 = __THREW__; __THREW__ = 0;
                 $616 = $615&1;
                 if ($616) {
                  break;
                 }
                 $617 = HEAP32[3027744>>2]|0;
                 $618 = HEAP32[$534>>2]|0;
                 $619 = (($618) + 92|0);
                 $620 = HEAP32[$619>>2]|0;
                 $621 = $620 << 2;
                 $622 = (($551) + ($621)|0);
                 HEAP32[$622>>2] = $617;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $623 = __THREW__; __THREW__ = 0;
                 $624 = $623&1;
                 if ($624) {
                  break;
                 }
                 $625 = HEAP32[$539>>2]|0;
                 $626 = ($625>>>0)<(6);
                 if ($626) {
                  __THREW__ = 0;
                  $627 = (invoke_i(132)|0);
                  $628 = __THREW__; __THREW__ = 0;
                  $629 = $628&1;
                  if ($629) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($627|0));
                  $630 = __THREW__; __THREW__ = 0;
                  $631 = $630&1;
                  if ($631) {
                   break;
                  }
                 }
                 $632 = HEAP32[3027752>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($632|0));
                 $633 = __THREW__; __THREW__ = 0;
                 $634 = $633&1;
                 if ($634) {
                  break;
                 }
                 $635 = HEAP32[3027752>>2]|0;
                 $636 = HEAP32[$534>>2]|0;
                 $637 = (($636) + 92|0);
                 $638 = HEAP32[$637>>2]|0;
                 $639 = ($638*5)|0;
                 $640 = (($551) + ($639)|0);
                 HEAP32[$640>>2] = $635;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $641 = __THREW__; __THREW__ = 0;
                 $642 = $641&1;
                 if ($642) {
                  break;
                 }
                 $643 = HEAP32[$539>>2]|0;
                 $644 = ($643>>>0)<(7);
                 if ($644) {
                  __THREW__ = 0;
                  $645 = (invoke_i(132)|0);
                  $646 = __THREW__; __THREW__ = 0;
                  $647 = $646&1;
                  if ($647) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($645|0));
                  $648 = __THREW__; __THREW__ = 0;
                  $649 = $648&1;
                  if ($649) {
                   break;
                  }
                 }
                 $650 = HEAP32[3027760>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($650|0));
                 $651 = __THREW__; __THREW__ = 0;
                 $652 = $651&1;
                 if ($652) {
                  break;
                 }
                 $653 = HEAP32[3027760>>2]|0;
                 $654 = HEAP32[$534>>2]|0;
                 $655 = (($654) + 92|0);
                 $656 = HEAP32[$655>>2]|0;
                 $657 = ($656*6)|0;
                 $658 = (($551) + ($657)|0);
                 HEAP32[$658>>2] = $653;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $659 = __THREW__; __THREW__ = 0;
                 $660 = $659&1;
                 if ($660) {
                  break;
                 }
                 $661 = HEAP32[$539>>2]|0;
                 $662 = ($661>>>0)<(8);
                 if ($662) {
                  __THREW__ = 0;
                  $663 = (invoke_i(132)|0);
                  $664 = __THREW__; __THREW__ = 0;
                  $665 = $664&1;
                  if ($665) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($663|0));
                  $666 = __THREW__; __THREW__ = 0;
                  $667 = $666&1;
                  if ($667) {
                   break;
                  }
                 }
                 $668 = HEAP32[3027768>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($668|0));
                 $669 = __THREW__; __THREW__ = 0;
                 $670 = $669&1;
                 if ($670) {
                  break;
                 }
                 $671 = HEAP32[3027768>>2]|0;
                 $672 = HEAP32[$534>>2]|0;
                 $673 = (($672) + 92|0);
                 $674 = HEAP32[$673>>2]|0;
                 $675 = ($674*7)|0;
                 $676 = (($551) + ($675)|0);
                 HEAP32[$676>>2] = $671;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $677 = __THREW__; __THREW__ = 0;
                 $678 = $677&1;
                 if ($678) {
                  break;
                 }
                 $679 = HEAP32[$539>>2]|0;
                 $680 = ($679>>>0)<(9);
                 if ($680) {
                  __THREW__ = 0;
                  $681 = (invoke_i(132)|0);
                  $682 = __THREW__; __THREW__ = 0;
                  $683 = $682&1;
                  if ($683) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($681|0));
                  $684 = __THREW__; __THREW__ = 0;
                  $685 = $684&1;
                  if ($685) {
                   break;
                  }
                 }
                 $686 = HEAP32[3027776>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($686|0));
                 $687 = __THREW__; __THREW__ = 0;
                 $688 = $687&1;
                 if ($688) {
                  break;
                 }
                 $689 = HEAP32[3027776>>2]|0;
                 $690 = HEAP32[$534>>2]|0;
                 $691 = (($690) + 92|0);
                 $692 = HEAP32[$691>>2]|0;
                 $693 = $692 << 3;
                 $694 = (($551) + ($693)|0);
                 HEAP32[$694>>2] = $689;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $695 = __THREW__; __THREW__ = 0;
                 $696 = $695&1;
                 if ($696) {
                  break;
                 }
                 $697 = HEAP32[$539>>2]|0;
                 $698 = ($697>>>0)<(10);
                 if ($698) {
                  __THREW__ = 0;
                  $699 = (invoke_i(132)|0);
                  $700 = __THREW__; __THREW__ = 0;
                  $701 = $700&1;
                  if ($701) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($699|0));
                  $702 = __THREW__; __THREW__ = 0;
                  $703 = $702&1;
                  if ($703) {
                   break;
                  }
                 }
                 $704 = HEAP32[3027784>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($704|0));
                 $705 = __THREW__; __THREW__ = 0;
                 $706 = $705&1;
                 if ($706) {
                  break;
                 }
                 $707 = HEAP32[3027784>>2]|0;
                 $708 = HEAP32[$534>>2]|0;
                 $709 = (($708) + 92|0);
                 $710 = HEAP32[$709>>2]|0;
                 $711 = ($710*9)|0;
                 $712 = (($551) + ($711)|0);
                 HEAP32[$712>>2] = $707;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $713 = __THREW__; __THREW__ = 0;
                 $714 = $713&1;
                 if ($714) {
                  break;
                 }
                 $715 = HEAP32[$539>>2]|0;
                 $716 = ($715>>>0)<(11);
                 if ($716) {
                  __THREW__ = 0;
                  $717 = (invoke_i(132)|0);
                  $718 = __THREW__; __THREW__ = 0;
                  $719 = $718&1;
                  if ($719) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($717|0));
                  $720 = __THREW__; __THREW__ = 0;
                  $721 = $720&1;
                  if ($721) {
                   break;
                  }
                 }
                 $722 = HEAP32[3027792>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($722|0));
                 $723 = __THREW__; __THREW__ = 0;
                 $724 = $723&1;
                 if ($724) {
                  break;
                 }
                 $725 = HEAP32[3027792>>2]|0;
                 $726 = HEAP32[$534>>2]|0;
                 $727 = (($726) + 92|0);
                 $728 = HEAP32[$727>>2]|0;
                 $729 = ($728*10)|0;
                 $730 = (($551) + ($729)|0);
                 HEAP32[$730>>2] = $725;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $731 = __THREW__; __THREW__ = 0;
                 $732 = $731&1;
                 if ($732) {
                  break;
                 }
                 $733 = HEAP32[$539>>2]|0;
                 $734 = ($733>>>0)<(12);
                 if ($734) {
                  __THREW__ = 0;
                  $735 = (invoke_i(132)|0);
                  $736 = __THREW__; __THREW__ = 0;
                  $737 = $736&1;
                  if ($737) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($735|0));
                  $738 = __THREW__; __THREW__ = 0;
                  $739 = $738&1;
                  if ($739) {
                   break;
                  }
                 }
                 $740 = HEAP32[3027800>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($740|0));
                 $741 = __THREW__; __THREW__ = 0;
                 $742 = $741&1;
                 if ($742) {
                  break;
                 }
                 $743 = HEAP32[3027800>>2]|0;
                 $744 = HEAP32[$534>>2]|0;
                 $745 = (($744) + 92|0);
                 $746 = HEAP32[$745>>2]|0;
                 $747 = ($746*11)|0;
                 $748 = (($551) + ($747)|0);
                 HEAP32[$748>>2] = $743;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $749 = __THREW__; __THREW__ = 0;
                 $750 = $749&1;
                 if ($750) {
                  break;
                 }
                 $751 = HEAP8[((2191608 + 116|0))>>0]|0;
                 $752 = ($751<<24>>24)==(0);
                 if ($752) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2191608|0))|0);
                  $753 = __THREW__; __THREW__ = 0;
                  $754 = $753&1;
                  if ($754) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2191608|0))|0);
                  $755 = __THREW__; __THREW__ = 0;
                  $756 = $755&1;
                  if ($756) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3832,(2191608|0));
                  $757 = __THREW__; __THREW__ = 0;
                  $758 = $757&1;
                  if ($758) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $759 = __THREW__; __THREW__ = 0;
                 $760 = $759&1;
                 if ($760) {
                  break;
                 }
                 $761 = HEAP32[((2191608 + 80|0))>>2]|0;
                 $762 = HEAP32[$761>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($534|0));
                 $763 = __THREW__; __THREW__ = 0;
                 $764 = $763&1;
                 if ($764) {
                  break;
                 }
                 $765 = HEAP32[$539>>2]|0;
                 $766 = ($765>>>0)<(13);
                 if ($766) {
                  __THREW__ = 0;
                  $767 = (invoke_i(132)|0);
                  $768 = __THREW__; __THREW__ = 0;
                  $769 = $768&1;
                  if ($769) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($767|0));
                  $770 = __THREW__; __THREW__ = 0;
                  $771 = $770&1;
                  if ($771) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($534|0),($762|0));
                 $772 = __THREW__; __THREW__ = 0;
                 $773 = $772&1;
                 if ($773) {
                  break;
                 }
                 $774 = HEAP32[$534>>2]|0;
                 $775 = (($774) + 92|0);
                 $776 = HEAP32[$775>>2]|0;
                 $777 = ($776*12)|0;
                 $778 = (($551) + ($777)|0);
                 HEAP32[$778>>2] = $762;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $779 = __THREW__; __THREW__ = 0;
                 $780 = $779&1;
                 if ($780) {
                  break;
                 }
                 $781 = HEAP32[((2340656 + 80|0))>>2]|0;
                 $782 = (($781) + 28|0);
                 HEAP32[$782>>2] = $534;
                 __THREW__ = 0;
                 (invoke_ii(2996,(1168432|0))|0);
                 $783 = __THREW__; __THREW__ = 0;
                 $784 = $783&1;
                 if ($784) {
                  break;
                 }
                 __THREW__ = 0;
                 $785 = (invoke_iii(2758,(1168432|0),7)|0);
                 $786 = __THREW__; __THREW__ = 0;
                 $787 = $786&1;
                 if ($787) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($785|0));
                 $788 = __THREW__; __THREW__ = 0;
                 $789 = $788&1;
                 if ($789) {
                  break;
                 }
                 $790 = (($785) + 12|0);
                 $791 = HEAP32[$790>>2]|0;
                 $792 = ($791|0)==(0);
                 if ($792) {
                  __THREW__ = 0;
                  $793 = (invoke_i(132)|0);
                  $794 = __THREW__; __THREW__ = 0;
                  $795 = $794&1;
                  if ($795) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($793|0));
                  $796 = __THREW__; __THREW__ = 0;
                  $797 = $796&1;
                  if ($797) {
                   break;
                  }
                 }
                 $798 = HEAP32[3027808>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($785|0),($798|0));
                 $799 = __THREW__; __THREW__ = 0;
                 $800 = $799&1;
                 if ($800) {
                  break;
                 }
                 $801 = HEAP32[3027808>>2]|0;
                 $802 = (($785) + 16|0);
                 HEAP32[$802>>2] = $801;
                 __THREW__ = 0;
                 invoke_vi(3799,($785|0));
                 $803 = __THREW__; __THREW__ = 0;
                 $804 = $803&1;
                 if ($804) {
                  break;
                 }
                 $805 = HEAP32[$790>>2]|0;
                 $806 = ($805>>>0)<(2);
                 if ($806) {
                  __THREW__ = 0;
                  $807 = (invoke_i(132)|0);
                  $808 = __THREW__; __THREW__ = 0;
                  $809 = $808&1;
                  if ($809) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($807|0));
                  $810 = __THREW__; __THREW__ = 0;
                  $811 = $810&1;
                  if ($811) {
                   break;
                  }
                 }
                 $812 = HEAP32[3027816>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($785|0),($812|0));
                 $813 = __THREW__; __THREW__ = 0;
                 $814 = $813&1;
                 if ($814) {
                  break;
                 }
                 $815 = HEAP32[3027816>>2]|0;
                 $816 = HEAP32[$785>>2]|0;
                 $817 = (($816) + 92|0);
                 $818 = HEAP32[$817>>2]|0;
                 $819 = (($802) + ($818)|0);
                 HEAP32[$819>>2] = $815;
                 __THREW__ = 0;
                 invoke_vi(3799,($785|0));
                 $820 = __THREW__; __THREW__ = 0;
                 $821 = $820&1;
                 if ($821) {
                  break;
                 }
                 $822 = HEAP32[$790>>2]|0;
                 $823 = ($822>>>0)<(3);
                 if ($823) {
                  __THREW__ = 0;
                  $824 = (invoke_i(132)|0);
                  $825 = __THREW__; __THREW__ = 0;
                  $826 = $825&1;
                  if ($826) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($824|0));
                  $827 = __THREW__; __THREW__ = 0;
                  $828 = $827&1;
                  if ($828) {
                   break;
                  }
                 }
                 $829 = HEAP32[3027824>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($785|0),($829|0));
                 $830 = __THREW__; __THREW__ = 0;
                 $831 = $830&1;
                 if ($831) {
                  break;
                 }
                 $832 = HEAP32[3027824>>2]|0;
                 $833 = HEAP32[$785>>2]|0;
                 $834 = (($833) + 92|0);
                 $835 = HEAP32[$834>>2]|0;
                 $836 = $835 << 1;
                 $837 = (($802) + ($836)|0);
                 HEAP32[$837>>2] = $832;
                 __THREW__ = 0;
                 invoke_vi(3799,($785|0));
                 $838 = __THREW__; __THREW__ = 0;
                 $839 = $838&1;
                 if ($839) {
                  break;
                 }
                 $840 = HEAP32[$790>>2]|0;
                 $841 = ($840>>>0)<(4);
                 if ($841) {
                  __THREW__ = 0;
                  $842 = (invoke_i(132)|0);
                  $843 = __THREW__; __THREW__ = 0;
                  $844 = $843&1;
                  if ($844) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($842|0));
                  $845 = __THREW__; __THREW__ = 0;
                  $846 = $845&1;
                  if ($846) {
                   break;
                  }
                 }
                 $847 = HEAP32[3027832>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($785|0),($847|0));
                 $848 = __THREW__; __THREW__ = 0;
                 $849 = $848&1;
                 if ($849) {
                  break;
                 }
                 $850 = HEAP32[3027832>>2]|0;
                 $851 = HEAP32[$785>>2]|0;
                 $852 = (($851) + 92|0);
                 $853 = HEAP32[$852>>2]|0;
                 $854 = ($853*3)|0;
                 $855 = (($802) + ($854)|0);
                 HEAP32[$855>>2] = $850;
                 __THREW__ = 0;
                 invoke_vi(3799,($785|0));
                 $856 = __THREW__; __THREW__ = 0;
                 $857 = $856&1;
                 if ($857) {
                  break;
                 }
                 $858 = HEAP32[$790>>2]|0;
                 $859 = ($858>>>0)<(5);
                 if ($859) {
                  __THREW__ = 0;
                  $860 = (invoke_i(132)|0);
                  $861 = __THREW__; __THREW__ = 0;
                  $862 = $861&1;
                  if ($862) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($860|0));
                  $863 = __THREW__; __THREW__ = 0;
                  $864 = $863&1;
                  if ($864) {
                   break;
                  }
                 }
                 $865 = HEAP32[3027840>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($785|0),($865|0));
                 $866 = __THREW__; __THREW__ = 0;
                 $867 = $866&1;
                 if ($867) {
                  break;
                 }
                 $868 = HEAP32[3027840>>2]|0;
                 $869 = HEAP32[$785>>2]|0;
                 $870 = (($869) + 92|0);
                 $871 = HEAP32[$870>>2]|0;
                 $872 = $871 << 2;
                 $873 = (($802) + ($872)|0);
                 HEAP32[$873>>2] = $868;
                 __THREW__ = 0;
                 invoke_vi(3799,($785|0));
                 $874 = __THREW__; __THREW__ = 0;
                 $875 = $874&1;
                 if ($875) {
                  break;
                 }
                 $876 = HEAP32[$790>>2]|0;
                 $877 = ($876>>>0)<(6);
                 if ($877) {
                  __THREW__ = 0;
                  $878 = (invoke_i(132)|0);
                  $879 = __THREW__; __THREW__ = 0;
                  $880 = $879&1;
                  if ($880) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($878|0));
                  $881 = __THREW__; __THREW__ = 0;
                  $882 = $881&1;
                  if ($882) {
                   break;
                  }
                 }
                 $883 = HEAP32[3027848>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($785|0),($883|0));
                 $884 = __THREW__; __THREW__ = 0;
                 $885 = $884&1;
                 if ($885) {
                  break;
                 }
                 $886 = HEAP32[3027848>>2]|0;
                 $887 = HEAP32[$785>>2]|0;
                 $888 = (($887) + 92|0);
                 $889 = HEAP32[$888>>2]|0;
                 $890 = ($889*5)|0;
                 $891 = (($802) + ($890)|0);
                 HEAP32[$891>>2] = $886;
                 __THREW__ = 0;
                 invoke_vi(3799,($785|0));
                 $892 = __THREW__; __THREW__ = 0;
                 $893 = $892&1;
                 if ($893) {
                  break;
                 }
                 $894 = HEAP32[$790>>2]|0;
                 $895 = ($894>>>0)<(7);
                 if ($895) {
                  __THREW__ = 0;
                  $896 = (invoke_i(132)|0);
                  $897 = __THREW__; __THREW__ = 0;
                  $898 = $897&1;
                  if ($898) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($896|0));
                  $899 = __THREW__; __THREW__ = 0;
                  $900 = $899&1;
                  if ($900) {
                   break;
                  }
                 }
                 $901 = HEAP32[3027856>>2]|0;
                 __THREW__ = 0;
                 invoke_vii(3492,($785|0),($901|0));
                 $902 = __THREW__; __THREW__ = 0;
                 $903 = $902&1;
                 if ($903) {
                  break;
                 }
                 $904 = HEAP32[3027856>>2]|0;
                 $905 = HEAP32[$785>>2]|0;
                 $906 = (($905) + 92|0);
                 $907 = HEAP32[$906>>2]|0;
                 $908 = ($907*6)|0;
                 $909 = (($802) + ($908)|0);
                 HEAP32[$909>>2] = $904;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2340656|0))|0);
                 $910 = __THREW__; __THREW__ = 0;
                 $911 = $910&1;
                 if ($911) {
                  break;
                 }
                 $912 = HEAP32[((2340656 + 80|0))>>2]|0;
                 $913 = (($912) + 32|0);
                 HEAP32[$913>>2] = $785;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($32|0);
 // unreachable;
}
function __Z62mscorlib_System_Globalization_DateTimeFormatInfo_m_GetInstanceP22mscorlib_System_ObjectS0_($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334624);
 $1 = ($provider|0)==(0|0);
 if ($1) {
  label = 10;
 } else {
  HEAP32[$0>>2] = 2386784;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $2 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($provider|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iiii(1666,(2606440|0),($provider|0),($2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2340656|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_iii(2759,($7|0),(2340656|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = ($12|0)==(0|0);
       if ($15) {
        label = 10;
       } else {
        $$0 = $12;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 if ((label|0) == 10) {
  __THREW__ = 0;
  $18 = (invoke_ii(2008,0)|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   $$0 = $18;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Globalization_DateTimeFormatInfo_m_get_CurrentInfoP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335680);
 __THREW__ = 0;
 $0 = (invoke_ii(2405,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(1178,(0|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2730,(2330232|0),($3|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($8|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Globalization_DateTimeFormatInfo_m_get_IsReadOnlyP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334672);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z59mscorlib_System_Globalization_DateTimeFormatInfo_m_ReadOnlyP22mscorlib_System_ObjectP48mscorlib_System_Globalization_DateTimeFormatInfo($__this,$dtfi) {
 $__this = $__this|0;
 $dtfi = $dtfi|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334720);
 __THREW__ = 0;
 invoke_vi(3799,($dtfi|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2756,(2330952|0),($dtfi|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2340656|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2759,($2|0),(2340656|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3799,($7|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = (($7) + 8|0);
      HEAP8[$12>>0] = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($7|0);
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Globalization_DateTimeFormatInfo_m_CloneP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330952);
 __THREW__ = 0;
 $0 = (invoke_ii(1783,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2340656|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2759,($0|0),(2340656|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($5) + 8|0);
     HEAP8[$10>>0] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($5|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Globalization_DateTimeFormatInfo_m_GetFormatP48mscorlib_System_Globalization_DateTimeFormatInfoP20mscorlib_System_Type($__this,$formatType) {
 $__this = $__this|0;
 $formatType = $formatType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $__this$ = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334768);
 __THREW__ = 0;
 $0 = (invoke_ii(1782,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0|0)==($formatType|0);
  $__this$ = $3 ? $__this : 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($__this$|0);
 }
 return 0|0;
}
function __Z74mscorlib_System_Globalization_DateTimeFormatInfo_m_GetAbbreviatedMonthNameP48mscorlib_System_Globalization_DateTimeFormatInfoi($__this,$month) {
 $__this = $__this|0;
 $month = $month|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $month$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334816);
 $month$off = (($month) + -1)|0;
 $0 = ($month$off>>>0)<(13);
 if ($0) {
  $12 = (($__this) + 92|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($13|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $16 = ($month|0)<(1);
   if (!($16)) {
    $17 = (($13) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($month$off>>>0)<($18>>>0);
    if ($19) {
     $25 = HEAP32[$13>>2]|0;
     $26 = (($13) + 16|0);
     $27 = (($25) + 92|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = Math_imul($28, $month$off)|0;
     $30 = (($26) + ($29)|0);
     $31 = HEAP32[$30>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($31|0);
    }
   }
   __THREW__ = 0;
   $20 = (invoke_i(132)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    invoke_vi(3302,($20|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = HEAP32[$13>>2]|0;
     $26 = (($13) + 16|0);
     $27 = (($25) + 92|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = Math_imul($28, $month$off)|0;
     $30 = (($26) + ($29)|0);
     $31 = HEAP32[$30>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($31|0);
    }
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(3469,(2561352|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(2587,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3833,($3|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      // unreachable;
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Globalization_DateTimeFormatInfo_m_GetEraNameP48mscorlib_System_Globalization_DateTimeFormatInfoi($__this,$era) {
 $__this = $__this|0;
 $era = $era|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 HEAP32[$0>>2] = $era;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334864);
 __THREW__ = 0;
 invoke_v(584);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = HEAP32[$0>>2]|0;
   $4 = ($3|0)<(0);
   if (!($4)) {
    $7 = (($__this) + 72|0);
    $8 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(1977,($8|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = (($11) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[$0>>2]|0;
    $19 = ($18|0)>($17|0);
    if (!($19)) {
     $33 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     __THREW__ = 0;
     $36 = (invoke_ii(1977,($33|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     $39 = HEAP32[$0>>2]|0;
     $40 = (($39) + -1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($36|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     $43 = ($39|0)<(1);
     if (!($43)) {
      $44 = (($36) + 12|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($40>>>0)<($45>>>0);
      if ($46) {
       $52 = HEAP32[$36>>2]|0;
       $53 = (($36) + 16|0);
       $54 = (($52) + 92|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = Math_imul($55, $40)|0;
       $57 = (($53) + ($56)|0);
       $58 = HEAP32[$57>>2]|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($58|0);
      }
     }
     __THREW__ = 0;
     $47 = (invoke_i(132)|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($47|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = HEAP32[$36>>2]|0;
     $53 = (($36) + 16|0);
     $54 = (($52) + 92|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = Math_imul($55, $40)|0;
     $57 = (($53) + ($56)|0);
     $58 = HEAP32[$57>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($58|0);
    }
   }
   __THREW__ = 0;
   $20 = (invoke_ii(1791,($0|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2561352|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = HEAP32[3028544>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($25|0),($28|0),($20|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       __THREW__ = 0;
       invoke_vi(3833,($25|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Globalization_DateTimeFormatInfo_m_GetMonthNameP48mscorlib_System_Globalization_DateTimeFormatInfoi($__this,$month) {
 $__this = $__this|0;
 $month = $month|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $month$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334912);
 $month$off = (($month) + -1)|0;
 $0 = ($month$off>>>0)<(13);
 if ($0) {
  $12 = (($__this) + 88|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($13|0));
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   $16 = ($month|0)<(1);
   if (!($16)) {
    $17 = (($13) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($month$off>>>0)<($18>>>0);
    if ($19) {
     $25 = HEAP32[$13>>2]|0;
     $26 = (($13) + 16|0);
     $27 = (($25) + 92|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = Math_imul($28, $month$off)|0;
     $30 = (($26) + ($29)|0);
     $31 = HEAP32[$30>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($31|0);
    }
   }
   __THREW__ = 0;
   $20 = (invoke_i(132)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    invoke_vi(3302,($20|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = HEAP32[$13>>2]|0;
     $26 = (($13) + 16|0);
     $27 = (($25) + 92|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = Math_imul($28, $month$off)|0;
     $30 = (($26) + ($29)|0);
     $31 = HEAP32[$30>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($31|0);
    }
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(3469,(2561352|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(2587,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3833,($3|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      // unreachable;
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RawAbbreviatedDayNamesP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2334960);
 $0 = (($__this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z79mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RawAbbreviatedMonthNamesP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335008);
 $0 = (($__this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z66mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RawDayNamesP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335056);
 $0 = (($__this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RawMonthNamesP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335104);
 $0 = (($__this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67mscorlib_System_Globalization_DateTimeFormatInfo_m_get_AMDesignatorP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335152);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67mscorlib_System_Globalization_DateTimeFormatInfo_m_get_PMDesignatorP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335200);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Globalization_DateTimeFormatInfo_m_get_DateSeparatorP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335248);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Globalization_DateTimeFormatInfo_m_get_TimeSeparatorP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335296);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Globalization_DateTimeFormatInfo_m_get_LongDatePatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335344);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_get_ShortDatePatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335392);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_get_ShortTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335440);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Globalization_DateTimeFormatInfo_m_get_LongTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335488);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Globalization_DateTimeFormatInfo_m_get_MonthDayPatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335536);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_get_YearMonthPatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335584);
 $0 = (($__this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Globalization_DateTimeFormatInfo_m_get_FullDateTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335632);
 __THREW__ = 0;
 invoke_v(585);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $2 = (($__this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $$0 = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($__this) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 40|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[3026832>>2]|0;
 __THREW__ = 0;
 $12 = (invoke_iiiii(101,(0|0),($8|0),($11|0),($10|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $$0 = $12;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z72mscorlib_System_Globalization_DateTimeFormatInfo_m_FillInvariantPatternsP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2336304);
 __THREW__ = 0;
 invoke_v(586);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1168432|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2758,(1168432|0),1)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $19 = HEAP32[3028680>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($4|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[3028680>>2]|0;
       $23 = (($4) + 16|0);
       HEAP32[$23>>2] = $22;
       $24 = (($__this) + 96|0);
       HEAP32[$24>>2] = $4;
       __THREW__ = 0;
       (invoke_ii(2996,(1168432|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        __THREW__ = 0;
        $27 = (invoke_iii(2758,(1168432|0),1)|0);
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if (!($29)) {
         __THREW__ = 0;
         invoke_vi(3799,($27|0));
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          $32 = (($27) + 12|0);
          $33 = HEAP32[$32>>2]|0;
          $34 = ($33|0)==(0);
          if ($34) {
           __THREW__ = 0;
           $35 = (invoke_i(132)|0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($35|0));
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if ($39) {
            break;
           }
          }
          $40 = HEAP32[3028688>>2]|0;
          __THREW__ = 0;
          invoke_vii(3492,($27|0),($40|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if (!($42)) {
           $43 = HEAP32[3028688>>2]|0;
           $44 = (($27) + 16|0);
           HEAP32[$44>>2] = $43;
           $45 = (($__this) + 100|0);
           HEAP32[$45>>2] = $27;
           __THREW__ = 0;
           (invoke_ii(2996,(1168432|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            __THREW__ = 0;
            $48 = (invoke_iii(2758,(1168432|0),1)|0);
            $49 = __THREW__; __THREW__ = 0;
            $50 = $49&1;
            if (!($50)) {
             __THREW__ = 0;
             invoke_vi(3799,($48|0));
             $51 = __THREW__; __THREW__ = 0;
             $52 = $51&1;
             if (!($52)) {
              $53 = (($48) + 12|0);
              $54 = HEAP32[$53>>2]|0;
              $55 = ($54|0)==(0);
              if ($55) {
               __THREW__ = 0;
               $56 = (invoke_i(132)|0);
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if ($58) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($56|0));
               $59 = __THREW__; __THREW__ = 0;
               $60 = $59&1;
               if ($60) {
                break;
               }
              }
              $61 = HEAP32[3028696>>2]|0;
              __THREW__ = 0;
              invoke_vii(3492,($48|0),($61|0));
              $62 = __THREW__; __THREW__ = 0;
              $63 = $62&1;
              if (!($63)) {
               $64 = HEAP32[3028696>>2]|0;
               $65 = (($48) + 16|0);
               HEAP32[$65>>2] = $64;
               $66 = (($__this) + 108|0);
               HEAP32[$66>>2] = $48;
               __THREW__ = 0;
               (invoke_ii(2996,(1168432|0))|0);
               $67 = __THREW__; __THREW__ = 0;
               $68 = $67&1;
               if (!($68)) {
                __THREW__ = 0;
                $69 = (invoke_iii(2758,(1168432|0),4)|0);
                $70 = __THREW__; __THREW__ = 0;
                $71 = $70&1;
                if (!($71)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($69|0));
                 $72 = __THREW__; __THREW__ = 0;
                 $73 = $72&1;
                 if (!($73)) {
                  $74 = (($69) + 12|0);
                  $75 = HEAP32[$74>>2]|0;
                  $76 = ($75|0)==(0);
                  if ($76) {
                   __THREW__ = 0;
                   $77 = (invoke_i(132)|0);
                   $78 = __THREW__; __THREW__ = 0;
                   $79 = $78&1;
                   if ($79) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($77|0));
                   $80 = __THREW__; __THREW__ = 0;
                   $81 = $80&1;
                   if ($81) {
                    break;
                   }
                  }
                  $82 = HEAP32[3028704>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($69|0),($82|0));
                  $83 = __THREW__; __THREW__ = 0;
                  $84 = $83&1;
                  if ($84) {
                   break;
                  }
                  $85 = HEAP32[3028704>>2]|0;
                  $86 = (($69) + 16|0);
                  HEAP32[$86>>2] = $85;
                  __THREW__ = 0;
                  invoke_vi(3799,($69|0));
                  $87 = __THREW__; __THREW__ = 0;
                  $88 = $87&1;
                  if ($88) {
                   break;
                  }
                  $89 = HEAP32[$74>>2]|0;
                  $90 = ($89>>>0)<(2);
                  if ($90) {
                   __THREW__ = 0;
                   $91 = (invoke_i(132)|0);
                   $92 = __THREW__; __THREW__ = 0;
                   $93 = $92&1;
                   if ($93) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($91|0));
                   $94 = __THREW__; __THREW__ = 0;
                   $95 = $94&1;
                   if ($95) {
                    break;
                   }
                  }
                  $96 = HEAP32[3028712>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($69|0),($96|0));
                  $97 = __THREW__; __THREW__ = 0;
                  $98 = $97&1;
                  if ($98) {
                   break;
                  }
                  $99 = HEAP32[3028712>>2]|0;
                  $100 = HEAP32[$69>>2]|0;
                  $101 = (($100) + 92|0);
                  $102 = HEAP32[$101>>2]|0;
                  $103 = (($86) + ($102)|0);
                  HEAP32[$103>>2] = $99;
                  __THREW__ = 0;
                  invoke_vi(3799,($69|0));
                  $104 = __THREW__; __THREW__ = 0;
                  $105 = $104&1;
                  if ($105) {
                   break;
                  }
                  $106 = HEAP32[$74>>2]|0;
                  $107 = ($106>>>0)<(3);
                  if ($107) {
                   __THREW__ = 0;
                   $108 = (invoke_i(132)|0);
                   $109 = __THREW__; __THREW__ = 0;
                   $110 = $109&1;
                   if ($110) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($108|0));
                   $111 = __THREW__; __THREW__ = 0;
                   $112 = $111&1;
                   if ($112) {
                    break;
                   }
                  }
                  $113 = HEAP32[3028720>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($69|0),($113|0));
                  $114 = __THREW__; __THREW__ = 0;
                  $115 = $114&1;
                  if ($115) {
                   break;
                  }
                  $116 = HEAP32[3028720>>2]|0;
                  $117 = HEAP32[$69>>2]|0;
                  $118 = (($117) + 92|0);
                  $119 = HEAP32[$118>>2]|0;
                  $120 = $119 << 1;
                  $121 = (($86) + ($120)|0);
                  HEAP32[$121>>2] = $116;
                  __THREW__ = 0;
                  invoke_vi(3799,($69|0));
                  $122 = __THREW__; __THREW__ = 0;
                  $123 = $122&1;
                  if ($123) {
                   break;
                  }
                  $124 = HEAP32[$74>>2]|0;
                  $125 = ($124>>>0)<(4);
                  if ($125) {
                   __THREW__ = 0;
                   $126 = (invoke_i(132)|0);
                   $127 = __THREW__; __THREW__ = 0;
                   $128 = $127&1;
                   if ($128) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($126|0));
                   $129 = __THREW__; __THREW__ = 0;
                   $130 = $129&1;
                   if ($130) {
                    break;
                   }
                  }
                  $131 = HEAP32[3028728>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($69|0),($131|0));
                  $132 = __THREW__; __THREW__ = 0;
                  $133 = $132&1;
                  if ($133) {
                   break;
                  }
                  $134 = HEAP32[3028728>>2]|0;
                  $135 = HEAP32[$69>>2]|0;
                  $136 = (($135) + 92|0);
                  $137 = HEAP32[$136>>2]|0;
                  $138 = ($137*3)|0;
                  $139 = (($86) + ($138)|0);
                  HEAP32[$139>>2] = $134;
                  $140 = (($__this) + 104|0);
                  HEAP32[$140>>2] = $69;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1168432|0))|0);
                  $141 = __THREW__; __THREW__ = 0;
                  $142 = $141&1;
                  if ($142) {
                   break;
                  }
                  __THREW__ = 0;
                  $143 = (invoke_iii(2758,(1168432|0),1)|0);
                  $144 = __THREW__; __THREW__ = 0;
                  $145 = $144&1;
                  if ($145) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($143|0));
                  $146 = __THREW__; __THREW__ = 0;
                  $147 = $146&1;
                  if ($147) {
                   break;
                  }
                  $148 = (($143) + 12|0);
                  $149 = HEAP32[$148>>2]|0;
                  $150 = ($149|0)==(0);
                  if ($150) {
                   __THREW__ = 0;
                   $151 = (invoke_i(132)|0);
                   $152 = __THREW__; __THREW__ = 0;
                   $153 = $152&1;
                   if ($153) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($151|0));
                   $154 = __THREW__; __THREW__ = 0;
                   $155 = $154&1;
                   if ($155) {
                    break;
                   }
                  }
                  $156 = HEAP32[3028736>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($143|0),($156|0));
                  $157 = __THREW__; __THREW__ = 0;
                  $158 = $157&1;
                  if ($158) {
                   break;
                  }
                  $159 = HEAP32[3028736>>2]|0;
                  $160 = (($143) + 16|0);
                  HEAP32[$160>>2] = $159;
                  $161 = (($__this) + 112|0);
                  HEAP32[$161>>2] = $143;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1168432|0))|0);
                  $162 = __THREW__; __THREW__ = 0;
                  $163 = $162&1;
                  if ($163) {
                   break;
                  }
                  __THREW__ = 0;
                  $164 = (invoke_iii(2758,(1168432|0),1)|0);
                  $165 = __THREW__; __THREW__ = 0;
                  $166 = $165&1;
                  if ($166) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($164|0));
                  $167 = __THREW__; __THREW__ = 0;
                  $168 = $167&1;
                  if ($168) {
                   break;
                  }
                  $169 = (($164) + 12|0);
                  $170 = HEAP32[$169>>2]|0;
                  $171 = ($170|0)==(0);
                  if ($171) {
                   __THREW__ = 0;
                   $172 = (invoke_i(132)|0);
                   $173 = __THREW__; __THREW__ = 0;
                   $174 = $173&1;
                   if ($174) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($172|0));
                   $175 = __THREW__; __THREW__ = 0;
                   $176 = $175&1;
                   if ($176) {
                    break;
                   }
                  }
                  $177 = HEAP32[3028744>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($164|0),($177|0));
                  $178 = __THREW__; __THREW__ = 0;
                  $179 = $178&1;
                  if ($179) {
                   break;
                  }
                  $180 = HEAP32[3028744>>2]|0;
                  $181 = (($164) + 16|0);
                  HEAP32[$181>>2] = $180;
                  $182 = (($__this) + 116|0);
                  HEAP32[$182>>2] = $164;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z63mscorlib_System_Globalization_DateTimeFormatInfo_m_get_CalendarP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335776);
 $0 = (($__this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z69mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RFC1123PatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335872);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RoundtripPatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335920);
 __THREW__ = 0;
 invoke_v(587);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP32[3026848>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Globalization_DateTimeFormatInfo_m_get_SortableDateTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2335968);
 $0 = (($__this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z87mscorlib_System_Globalization_DateTimeFormatInfo_m_get_UniversalSortableDateTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2336016);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z81mscorlib_System_Globalization_DateTimeFormatInfo_m_GetAllDateTimePatternsInternalP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2336064);
 __THREW__ = 0;
 invoke_vi(2220,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 192|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z74mscorlib_System_Globalization_DateTimeFormatInfo_m_FillAllDateTimePatternsP48mscorlib_System_Globalization_DateTimeFormatInfo($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2336112);
 $1 = (($__this) + 192|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2304136|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2304136|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(2153,($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iii(858,($__this|0),100)|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3799,($6|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_viii(2110,(2298968|0),($6|0),($11|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        $18 = (invoke_iii(858,($__this|0),68)|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         invoke_vi(3799,($6|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          invoke_viii(2110,(2298968|0),($6|0),($18|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           $25 = (invoke_iii(858,($__this|0),103)|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            invoke_vi(3799,($6|0));
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             __THREW__ = 0;
             invoke_viii(2110,(2298968|0),($6|0),($25|0));
             $30 = __THREW__; __THREW__ = 0;
             $31 = $30&1;
             if (!($31)) {
              __THREW__ = 0;
              $32 = (invoke_iii(858,($__this|0),71)|0);
              $33 = __THREW__; __THREW__ = 0;
              $34 = $33&1;
              if (!($34)) {
               __THREW__ = 0;
               invoke_vi(3799,($6|0));
               $35 = __THREW__; __THREW__ = 0;
               $36 = $35&1;
               if (!($36)) {
                __THREW__ = 0;
                invoke_viii(2110,(2298968|0),($6|0),($32|0));
                $37 = __THREW__; __THREW__ = 0;
                $38 = $37&1;
                if (!($38)) {
                 __THREW__ = 0;
                 $39 = (invoke_iii(858,($__this|0),102)|0);
                 $40 = __THREW__; __THREW__ = 0;
                 $41 = $40&1;
                 if (!($41)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($6|0));
                  $42 = __THREW__; __THREW__ = 0;
                  $43 = $42&1;
                  if (!($43)) {
                   __THREW__ = 0;
                   invoke_viii(2110,(2298968|0),($6|0),($39|0));
                   $44 = __THREW__; __THREW__ = 0;
                   $45 = $44&1;
                   if (!($45)) {
                    __THREW__ = 0;
                    $46 = (invoke_iii(858,($__this|0),70)|0);
                    $47 = __THREW__; __THREW__ = 0;
                    $48 = $47&1;
                    if ($48) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $49 = __THREW__; __THREW__ = 0;
                    $50 = $49&1;
                    if ($50) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($46|0));
                    $51 = __THREW__; __THREW__ = 0;
                    $52 = $51&1;
                    if ($52) {
                     break;
                    }
                    __THREW__ = 0;
                    $53 = (invoke_iii(858,($__this|0),109)|0);
                    $54 = __THREW__; __THREW__ = 0;
                    $55 = $54&1;
                    if ($55) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $56 = __THREW__; __THREW__ = 0;
                    $57 = $56&1;
                    if ($57) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($53|0));
                    $58 = __THREW__; __THREW__ = 0;
                    $59 = $58&1;
                    if ($59) {
                     break;
                    }
                    __THREW__ = 0;
                    $60 = (invoke_iii(858,($__this|0),77)|0);
                    $61 = __THREW__; __THREW__ = 0;
                    $62 = $61&1;
                    if ($62) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $63 = __THREW__; __THREW__ = 0;
                    $64 = $63&1;
                    if ($64) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($60|0));
                    $65 = __THREW__; __THREW__ = 0;
                    $66 = $65&1;
                    if ($66) {
                     break;
                    }
                    __THREW__ = 0;
                    $67 = (invoke_iii(858,($__this|0),114)|0);
                    $68 = __THREW__; __THREW__ = 0;
                    $69 = $68&1;
                    if ($69) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $70 = __THREW__; __THREW__ = 0;
                    $71 = $70&1;
                    if ($71) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($67|0));
                    $72 = __THREW__; __THREW__ = 0;
                    $73 = $72&1;
                    if ($73) {
                     break;
                    }
                    __THREW__ = 0;
                    $74 = (invoke_iii(858,($__this|0),82)|0);
                    $75 = __THREW__; __THREW__ = 0;
                    $76 = $75&1;
                    if ($76) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $77 = __THREW__; __THREW__ = 0;
                    $78 = $77&1;
                    if ($78) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($74|0));
                    $79 = __THREW__; __THREW__ = 0;
                    $80 = $79&1;
                    if ($80) {
                     break;
                    }
                    __THREW__ = 0;
                    $81 = (invoke_iii(858,($__this|0),115)|0);
                    $82 = __THREW__; __THREW__ = 0;
                    $83 = $82&1;
                    if ($83) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $84 = __THREW__; __THREW__ = 0;
                    $85 = $84&1;
                    if ($85) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($81|0));
                    $86 = __THREW__; __THREW__ = 0;
                    $87 = $86&1;
                    if ($87) {
                     break;
                    }
                    __THREW__ = 0;
                    $88 = (invoke_iii(858,($__this|0),116)|0);
                    $89 = __THREW__; __THREW__ = 0;
                    $90 = $89&1;
                    if ($90) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $91 = __THREW__; __THREW__ = 0;
                    $92 = $91&1;
                    if ($92) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($88|0));
                    $93 = __THREW__; __THREW__ = 0;
                    $94 = $93&1;
                    if ($94) {
                     break;
                    }
                    __THREW__ = 0;
                    $95 = (invoke_iii(858,($__this|0),84)|0);
                    $96 = __THREW__; __THREW__ = 0;
                    $97 = $96&1;
                    if ($97) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $98 = __THREW__; __THREW__ = 0;
                    $99 = $98&1;
                    if ($99) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($95|0));
                    $100 = __THREW__; __THREW__ = 0;
                    $101 = $100&1;
                    if ($101) {
                     break;
                    }
                    __THREW__ = 0;
                    $102 = (invoke_iii(858,($__this|0),117)|0);
                    $103 = __THREW__; __THREW__ = 0;
                    $104 = $103&1;
                    if ($104) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $105 = __THREW__; __THREW__ = 0;
                    $106 = $105&1;
                    if ($106) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($102|0));
                    $107 = __THREW__; __THREW__ = 0;
                    $108 = $107&1;
                    if ($108) {
                     break;
                    }
                    __THREW__ = 0;
                    $109 = (invoke_iii(858,($__this|0),85)|0);
                    $110 = __THREW__; __THREW__ = 0;
                    $111 = $110&1;
                    if ($111) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $112 = __THREW__; __THREW__ = 0;
                    $113 = $112&1;
                    if ($113) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($109|0));
                    $114 = __THREW__; __THREW__ = 0;
                    $115 = $114&1;
                    if ($115) {
                     break;
                    }
                    __THREW__ = 0;
                    $116 = (invoke_iii(858,($__this|0),121)|0);
                    $117 = __THREW__; __THREW__ = 0;
                    $118 = $117&1;
                    if ($118) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $119 = __THREW__; __THREW__ = 0;
                    $120 = $119&1;
                    if ($120) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($116|0));
                    $121 = __THREW__; __THREW__ = 0;
                    $122 = $121&1;
                    if ($122) {
                     break;
                    }
                    __THREW__ = 0;
                    $123 = (invoke_iii(858,($__this|0),89)|0);
                    $124 = __THREW__; __THREW__ = 0;
                    $125 = $124&1;
                    if ($125) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $126 = __THREW__; __THREW__ = 0;
                    $127 = $126&1;
                    if ($127) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(2110,(2298968|0),($6|0),($123|0));
                    $128 = __THREW__; __THREW__ = 0;
                    $129 = $128&1;
                    if ($129) {
                     break;
                    }
                    HEAP32[$0>>2] = 1284472;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
                    $130 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
                    $131 = __THREW__; __THREW__ = 0;
                    $132 = $131&1;
                    if ($132) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($6|0));
                    $133 = __THREW__; __THREW__ = 0;
                    $134 = $133&1;
                    if ($134) {
                     break;
                    }
                    __THREW__ = 0;
                    $135 = (invoke_iiii(1645,(2299256|0),($6|0),($130|0))|0);
                    $136 = __THREW__; __THREW__ = 0;
                    $137 = $136&1;
                    if ($137) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(1168432|0))|0);
                    $138 = __THREW__; __THREW__ = 0;
                    $139 = $138&1;
                    if ($139) {
                     break;
                    }
                    __THREW__ = 0;
                    $140 = (invoke_iii(2759,($135|0),(1168432|0))|0);
                    $141 = __THREW__; __THREW__ = 0;
                    $142 = $141&1;
                    if ($142) {
                     break;
                    }
                    HEAP32[$1>>2] = $140;
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $143 = ___cxa_find_matching_catch()|0;
 $144 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($143|0);
 // unreachable;
}
function __Z76mscorlib_System_Globalization_DateTimeFormatInfo_m_GetAllRawDateTimePatternsP48mscorlib_System_Globalization_DateTimeFormatInfot($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2336160);
 __THREW__ = 0;
 invoke_v(588);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = $format&65535;
   $3 = (($2) + 65454)|0;
   $4 = $3 & 65535;
   if ((($4|0) == 2)) {
    $73 = (($__this) + 108|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($74|0)==(0|0);
    if (!($75)) {
     __THREW__ = 0;
     invoke_vi(3799,($74|0));
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break;
     }
     $78 = (($74) + 12|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)<(1);
     if (!($80)) {
      $81 = HEAP32[$73>>2]|0;
      $$0 = $81;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1168432|0))|0);
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    $84 = (invoke_iii(2758,(1168432|0),1)|0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     break;
    }
    __THREW__ = 0;
    $87 = (invoke_ii(2004,($__this|0))|0);
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($84|0));
    $90 = __THREW__; __THREW__ = 0;
    $91 = $90&1;
    if ($91) {
     break;
    }
    $92 = (($84) + 12|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ($93|0)==(0);
    if ($94) {
     __THREW__ = 0;
     $95 = (invoke_i(132)|0);
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($95|0));
     $98 = __THREW__; __THREW__ = 0;
     $99 = $98&1;
     if ($99) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($84|0),($87|0));
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     break;
    }
    $102 = (($84) + 16|0);
    HEAP32[$102>>2] = $87;
    $$0 = $84;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else if ((($4|0) == 3)) {
    label = 90;
   } else if ((($4|0) == 0)) {
    label = 146;
   } else if ((($4|0) == 7)) {
    label = 133;
   } else {
    label = 4;
   }
   L21: do {
    if ((label|0) == 4) {
     $7 = (($2) + 65422)|0;
     $8 = $7 & 65535;
     switch ($8|0) {
     case 2:  {
      $103 = (($__this) + 104|0);
      $104 = HEAP32[$103>>2]|0;
      $105 = ($104|0)==(0|0);
      if (!($105)) {
       __THREW__ = 0;
       invoke_vi(3799,($104|0));
       $106 = __THREW__; __THREW__ = 0;
       $107 = $106&1;
       if ($107) {
        break L1;
       }
       $108 = (($104) + 12|0);
       $109 = HEAP32[$108>>2]|0;
       $110 = ($109|0)<(1);
       if (!($110)) {
        $111 = HEAP32[$103>>2]|0;
        $$0 = $111;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1168432|0))|0);
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       break L1;
      }
      __THREW__ = 0;
      $114 = (invoke_iii(2758,(1168432|0),1)|0);
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       break L1;
      }
      __THREW__ = 0;
      $117 = (invoke_ii(2003,($__this|0))|0);
      $118 = __THREW__; __THREW__ = 0;
      $119 = $118&1;
      if ($119) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($114|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       break L1;
      }
      $122 = (($114) + 12|0);
      $123 = HEAP32[$122>>2]|0;
      $124 = ($123|0)==(0);
      if ($124) {
       __THREW__ = 0;
       $125 = (invoke_i(132)|0);
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if ($127) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3302,($125|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        break L1;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($114|0),($117|0));
      $130 = __THREW__; __THREW__ = 0;
      $131 = $130&1;
      if ($131) {
       break L1;
      }
      $132 = (($114) + 16|0);
      HEAP32[$132>>2] = $117;
      $$0 = $114;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
      break;
     }
     case 0:  {
      label = 146;
      break L21;
      break;
     }
     case 7:  {
      label = 133;
      break L21;
      break;
     }
     case 1:  {
      __THREW__ = 0;
      (invoke_ii(2996,(1168432|0))|0);
      $378 = __THREW__; __THREW__ = 0;
      $379 = $378&1;
      if ($379) {
       break L1;
      }
      __THREW__ = 0;
      $380 = (invoke_iii(2758,(1168432|0),1)|0);
      $381 = __THREW__; __THREW__ = 0;
      $382 = $381&1;
      if ($382) {
       break L1;
      }
      __THREW__ = 0;
      $383 = (invoke_ii(2013,($__this|0))|0);
      $384 = __THREW__; __THREW__ = 0;
      $385 = $384&1;
      if ($385) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($380|0));
      $386 = __THREW__; __THREW__ = 0;
      $387 = $386&1;
      if ($387) {
       break L1;
      }
      $388 = (($380) + 12|0);
      $389 = HEAP32[$388>>2]|0;
      $390 = ($389|0)==(0);
      if ($390) {
       __THREW__ = 0;
       $391 = (invoke_i(132)|0);
       $392 = __THREW__; __THREW__ = 0;
       $393 = $392&1;
       if ($393) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3302,($391|0));
       $394 = __THREW__; __THREW__ = 0;
       $395 = $394&1;
       if ($395) {
        break L1;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($380|0),($383|0));
      $396 = __THREW__; __THREW__ = 0;
      $397 = $396&1;
      if ($397) {
       break L1;
      }
      $398 = (($380) + 16|0);
      HEAP32[$398>>2] = $383;
      $$0 = $380;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
      break;
     }
     case 3:  {
      __THREW__ = 0;
      (invoke_ii(2996,(1168432|0))|0);
      $399 = __THREW__; __THREW__ = 0;
      $400 = $399&1;
      if ($400) {
       break L1;
      }
      __THREW__ = 0;
      $401 = (invoke_iii(2758,(1168432|0),1)|0);
      $402 = __THREW__; __THREW__ = 0;
      $403 = $402&1;
      if ($403) {
       break L1;
      }
      __THREW__ = 0;
      $404 = (invoke_ii(2014,($__this|0))|0);
      $405 = __THREW__; __THREW__ = 0;
      $406 = $405&1;
      if ($406) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($401|0));
      $407 = __THREW__; __THREW__ = 0;
      $408 = $407&1;
      if ($408) {
       break L1;
      }
      $409 = (($401) + 12|0);
      $410 = HEAP32[$409>>2]|0;
      $411 = ($410|0)==(0);
      if ($411) {
       __THREW__ = 0;
       $412 = (invoke_i(132)|0);
       $413 = __THREW__; __THREW__ = 0;
       $414 = $413&1;
       if ($414) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3302,($412|0));
       $415 = __THREW__; __THREW__ = 0;
       $416 = $415&1;
       if ($416) {
        break L1;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($401|0),($404|0));
      $417 = __THREW__; __THREW__ = 0;
      $418 = $417&1;
      if ($418) {
       break L1;
      }
      $419 = (($401) + 16|0);
      HEAP32[$419>>2] = $404;
      $$0 = $401;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
      break;
     }
     default: {
      $9 = (($2) + 65468)|0;
      $10 = $9 & 65535;
      if ((($10|0) == 0)) {
       $13 = (($__this) + 100|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = ($14|0)==(0|0);
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($14|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         break L1;
        }
        $18 = (($14) + 12|0);
        $19 = HEAP32[$18>>2]|0;
        $20 = ($19|0)<(1);
        if (!($20)) {
         $21 = HEAP32[$13>>2]|0;
         $$0 = $21;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1168432|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break L1;
       }
       __THREW__ = 0;
       $24 = (invoke_iii(2758,(1168432|0),1)|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break L1;
       }
       __THREW__ = 0;
       $27 = (invoke_ii(2001,($__this|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($24|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break L1;
       }
       $32 = (($24) + 12|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = ($33|0)==(0);
       if ($34) {
        __THREW__ = 0;
        $35 = (invoke_i(132)|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($35|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break L1;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($24|0),($27|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break L1;
       }
       $42 = (($24) + 16|0);
       HEAP32[$42>>2] = $27;
       $$0 = $24;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      } else if ((($10|0) == 3)) {
       $133 = (($__this) + 96|0);
       $134 = HEAP32[$133>>2]|0;
       $135 = (($__this) + 108|0);
       $136 = HEAP32[$135>>2]|0;
       __THREW__ = 0;
       $137 = (invoke_iiii(813,0,($134|0),($136|0))|0);
       $138 = __THREW__; __THREW__ = 0;
       $139 = $138&1;
       if ($139) {
        break L1;
       }
       $140 = ($137|0)==(0|0);
       if (!($140)) {
        __THREW__ = 0;
        invoke_vi(3799,($137|0));
        $141 = __THREW__; __THREW__ = 0;
        $142 = $141&1;
        if ($142) {
         break L1;
        }
        $143 = (($137) + 12|0);
        $144 = HEAP32[$143>>2]|0;
        $145 = ($144|0)<(1);
        if (!($145)) {
         $$0 = $137;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1168432|0))|0);
       $146 = __THREW__; __THREW__ = 0;
       $147 = $146&1;
       if ($147) {
        break L1;
       }
       __THREW__ = 0;
       $148 = (invoke_iii(2758,(1168432|0),1)|0);
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if ($150) {
        break L1;
       }
       __THREW__ = 0;
       $151 = (invoke_ii(2002,($__this|0))|0);
       $152 = __THREW__; __THREW__ = 0;
       $153 = $152&1;
       if ($153) {
        break L1;
       }
       __THREW__ = 0;
       $154 = (invoke_ii(2004,($__this|0))|0);
       $155 = __THREW__; __THREW__ = 0;
       $156 = $155&1;
       if ($156) {
        break L1;
       }
       $157 = HEAP32[3028568>>2]|0;
       __THREW__ = 0;
       $158 = (invoke_iiiii(101,(0|0),($151|0),($157|0),($154|0))|0);
       $159 = __THREW__; __THREW__ = 0;
       $160 = $159&1;
       if ($160) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($148|0));
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       if ($162) {
        break L1;
       }
       $163 = (($148) + 12|0);
       $164 = HEAP32[$163>>2]|0;
       $165 = ($164|0)==(0);
       if ($165) {
        __THREW__ = 0;
        $166 = (invoke_i(132)|0);
        $167 = __THREW__; __THREW__ = 0;
        $168 = $167&1;
        if ($168) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($166|0));
        $169 = __THREW__; __THREW__ = 0;
        $170 = $169&1;
        if ($170) {
         break L1;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($148|0),($158|0));
       $171 = __THREW__; __THREW__ = 0;
       $172 = $171&1;
       if ($172) {
        break L1;
       }
       $173 = (($148) + 16|0);
       HEAP32[$173>>2] = $158;
       $$0 = $148;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      } else if ((($10|0) == 2)) {
       label = 90;
       break L21;
      } else {
       $11 = (($2) + 65436)|0;
       $12 = $11 & 65535;
       if ((($12|0) == 0)) {
        $43 = (($__this) + 96|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = ($44|0)==(0|0);
        if (!($45)) {
         __THREW__ = 0;
         invoke_vi(3799,($44|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          break L1;
         }
         $48 = (($44) + 12|0);
         $49 = HEAP32[$48>>2]|0;
         $50 = ($49|0)<(1);
         if (!($50)) {
          $51 = HEAP32[$43>>2]|0;
          $$0 = $51;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1168432|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2758,(1168432|0),1)|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        __THREW__ = 0;
        $57 = (invoke_ii(2002,($__this|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         break L1;
        }
        $62 = (($54) + 12|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = ($63|0)==(0);
        if ($64) {
         __THREW__ = 0;
         $65 = (invoke_i(132)|0);
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($65|0));
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($54|0),($57|0));
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break L1;
        }
        $72 = (($54) + 16|0);
        HEAP32[$72>>2] = $57;
        $$0 = $54;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       } else if ((($12|0) == 3)) {
        $174 = (($__this) + 96|0);
        $175 = HEAP32[$174>>2]|0;
        $176 = (($__this) + 104|0);
        $177 = HEAP32[$176>>2]|0;
        __THREW__ = 0;
        $178 = (invoke_iiii(813,0,($175|0),($177|0))|0);
        $179 = __THREW__; __THREW__ = 0;
        $180 = $179&1;
        if ($180) {
         break L1;
        }
        $181 = ($178|0)==(0|0);
        if (!($181)) {
         __THREW__ = 0;
         invoke_vi(3799,($178|0));
         $182 = __THREW__; __THREW__ = 0;
         $183 = $182&1;
         if ($183) {
          break L1;
         }
         $184 = (($178) + 12|0);
         $185 = HEAP32[$184>>2]|0;
         $186 = ($185|0)<(1);
         if (!($186)) {
          $$0 = $178;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1168432|0))|0);
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         break L1;
        }
        __THREW__ = 0;
        $189 = (invoke_iii(2758,(1168432|0),1)|0);
        $190 = __THREW__; __THREW__ = 0;
        $191 = $190&1;
        if ($191) {
         break L1;
        }
        __THREW__ = 0;
        $192 = (invoke_ii(2002,($__this|0))|0);
        $193 = __THREW__; __THREW__ = 0;
        $194 = $193&1;
        if ($194) {
         break L1;
        }
        __THREW__ = 0;
        $195 = (invoke_ii(2003,($__this|0))|0);
        $196 = __THREW__; __THREW__ = 0;
        $197 = $196&1;
        if ($197) {
         break L1;
        }
        $198 = HEAP32[3028576>>2]|0;
        __THREW__ = 0;
        $199 = (invoke_iiiii(101,(0|0),($192|0),($198|0),($195|0))|0);
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($189|0));
        $202 = __THREW__; __THREW__ = 0;
        $203 = $202&1;
        if ($203) {
         break L1;
        }
        $204 = (($189) + 12|0);
        $205 = HEAP32[$204>>2]|0;
        $206 = ($205|0)==(0);
        if ($206) {
         __THREW__ = 0;
         $207 = (invoke_i(132)|0);
         $208 = __THREW__; __THREW__ = 0;
         $209 = $208&1;
         if ($209) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($207|0));
         $210 = __THREW__; __THREW__ = 0;
         $211 = $210&1;
         if ($211) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($189|0),($199|0));
        $212 = __THREW__; __THREW__ = 0;
        $213 = $212&1;
        if ($213) {
         break L1;
        }
        $214 = (($189) + 16|0);
        HEAP32[$214>>2] = $199;
        $$0 = $189;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       } else if ((($12|0) == 2)) {
        $256 = (($__this) + 100|0);
        $257 = HEAP32[$256>>2]|0;
        $258 = (($__this) + 104|0);
        $259 = HEAP32[$258>>2]|0;
        __THREW__ = 0;
        $260 = (invoke_iiii(813,0,($257|0),($259|0))|0);
        $261 = __THREW__; __THREW__ = 0;
        $262 = $261&1;
        if ($262) {
         break L1;
        }
        $263 = ($260|0)==(0|0);
        if (!($263)) {
         __THREW__ = 0;
         invoke_vi(3799,($260|0));
         $264 = __THREW__; __THREW__ = 0;
         $265 = $264&1;
         if ($265) {
          break L1;
         }
         $266 = (($260) + 12|0);
         $267 = HEAP32[$266>>2]|0;
         $268 = ($267|0)<(1);
         if (!($268)) {
          $$0 = $260;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1168432|0))|0);
        $269 = __THREW__; __THREW__ = 0;
        $270 = $269&1;
        if ($270) {
         break L1;
        }
        __THREW__ = 0;
        $271 = (invoke_iii(2758,(1168432|0),1)|0);
        $272 = __THREW__; __THREW__ = 0;
        $273 = $272&1;
        if ($273) {
         break L1;
        }
        __THREW__ = 0;
        $274 = (invoke_ii(2001,($__this|0))|0);
        $275 = __THREW__; __THREW__ = 0;
        $276 = $275&1;
        if ($276) {
         break L1;
        }
        __THREW__ = 0;
        $277 = (invoke_ii(2003,($__this|0))|0);
        $278 = __THREW__; __THREW__ = 0;
        $279 = $278&1;
        if ($279) {
         break L1;
        }
        $280 = HEAP32[3028592>>2]|0;
        __THREW__ = 0;
        $281 = (invoke_iiiii(101,(0|0),($274|0),($280|0),($277|0))|0);
        $282 = __THREW__; __THREW__ = 0;
        $283 = $282&1;
        if ($283) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($271|0));
        $284 = __THREW__; __THREW__ = 0;
        $285 = $284&1;
        if ($285) {
         break L1;
        }
        $286 = (($271) + 12|0);
        $287 = HEAP32[$286>>2]|0;
        $288 = ($287|0)==(0);
        if ($288) {
         __THREW__ = 0;
         $289 = (invoke_i(132)|0);
         $290 = __THREW__; __THREW__ = 0;
         $291 = $290&1;
         if ($291) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($289|0));
         $292 = __THREW__; __THREW__ = 0;
         $293 = $292&1;
         if ($293) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($271|0),($281|0));
        $294 = __THREW__; __THREW__ = 0;
        $295 = $294&1;
        if ($295) {
         break L1;
        }
        $296 = (($271) + 16|0);
        HEAP32[$296>>2] = $281;
        $$0 = $271;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       } else {
        if (!((($format<<16>>16) == 109) | (($format<<16>>16) == 77))) {
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $420 = __THREW__; __THREW__ = 0;
         $421 = $420&1;
         if ($421) {
          break L1;
         }
         __THREW__ = 0;
         $422 = (invoke_ii(3469,(2560072|0))|0);
         $423 = __THREW__; __THREW__ = 0;
         $424 = $423&1;
         if ($424) {
          break L1;
         }
         $425 = HEAP32[3028600>>2]|0;
         __THREW__ = 0;
         invoke_vii(1924,($422|0),($425|0));
         $426 = __THREW__; __THREW__ = 0;
         $427 = $426&1;
         if ($427) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3833,($422|0));
         $428 = __THREW__; __THREW__ = 0;
         $429 = $428&1;
         if ($429) {
          break L1;
         }
         // unreachable;
        }
        $297 = (($__this) + 112|0);
        $298 = HEAP32[$297>>2]|0;
        $299 = ($298|0)==(0|0);
        if (!($299)) {
         __THREW__ = 0;
         invoke_vi(3799,($298|0));
         $300 = __THREW__; __THREW__ = 0;
         $301 = $300&1;
         if ($301) {
          break L1;
         }
         $302 = (($298) + 12|0);
         $303 = HEAP32[$302>>2]|0;
         $304 = ($303|0)<(1);
         if (!($304)) {
          $305 = HEAP32[$297>>2]|0;
          $$0 = $305;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1168432|0))|0);
        $306 = __THREW__; __THREW__ = 0;
        $307 = $306&1;
        if ($307) {
         break L1;
        }
        __THREW__ = 0;
        $308 = (invoke_iii(2758,(1168432|0),1)|0);
        $309 = __THREW__; __THREW__ = 0;
        $310 = $309&1;
        if ($310) {
         break L1;
        }
        __THREW__ = 0;
        $311 = (invoke_ii(2005,($__this|0))|0);
        $312 = __THREW__; __THREW__ = 0;
        $313 = $312&1;
        if ($313) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($308|0));
        $314 = __THREW__; __THREW__ = 0;
        $315 = $314&1;
        if ($315) {
         break L1;
        }
        $316 = (($308) + 12|0);
        $317 = HEAP32[$316>>2]|0;
        $318 = ($317|0)==(0);
        if ($318) {
         __THREW__ = 0;
         $319 = (invoke_i(132)|0);
         $320 = __THREW__; __THREW__ = 0;
         $321 = $320&1;
         if ($321) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($319|0));
         $322 = __THREW__; __THREW__ = 0;
         $323 = $322&1;
         if ($323) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($308|0),($311|0));
        $324 = __THREW__; __THREW__ = 0;
        $325 = $324&1;
        if ($325) {
         break L1;
        }
        $326 = (($308) + 16|0);
        HEAP32[$326>>2] = $311;
        $$0 = $308;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
     }
    }
   } while(0);
   if ((label|0) == 90) {
    $215 = (($__this) + 100|0);
    $216 = HEAP32[$215>>2]|0;
    $217 = (($__this) + 108|0);
    $218 = HEAP32[$217>>2]|0;
    __THREW__ = 0;
    $219 = (invoke_iiii(813,0,($216|0),($218|0))|0);
    $220 = __THREW__; __THREW__ = 0;
    $221 = $220&1;
    if ($221) {
     break;
    }
    $222 = ($219|0)==(0|0);
    if (!($222)) {
     __THREW__ = 0;
     invoke_vi(3799,($219|0));
     $223 = __THREW__; __THREW__ = 0;
     $224 = $223&1;
     if ($224) {
      break;
     }
     $225 = (($219) + 12|0);
     $226 = HEAP32[$225>>2]|0;
     $227 = ($226|0)<(1);
     if (!($227)) {
      $$0 = $219;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1168432|0))|0);
    $228 = __THREW__; __THREW__ = 0;
    $229 = $228&1;
    if ($229) {
     break;
    }
    __THREW__ = 0;
    $230 = (invoke_iii(2758,(1168432|0),1)|0);
    $231 = __THREW__; __THREW__ = 0;
    $232 = $231&1;
    if ($232) {
     break;
    }
    __THREW__ = 0;
    $233 = (invoke_ii(2001,($__this|0))|0);
    $234 = __THREW__; __THREW__ = 0;
    $235 = $234&1;
    if ($235) {
     break;
    }
    __THREW__ = 0;
    $236 = (invoke_ii(2004,($__this|0))|0);
    $237 = __THREW__; __THREW__ = 0;
    $238 = $237&1;
    if ($238) {
     break;
    }
    $239 = HEAP32[3028584>>2]|0;
    __THREW__ = 0;
    $240 = (invoke_iiiii(101,(0|0),($233|0),($239|0),($236|0))|0);
    $241 = __THREW__; __THREW__ = 0;
    $242 = $241&1;
    if ($242) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($230|0));
    $243 = __THREW__; __THREW__ = 0;
    $244 = $243&1;
    if ($244) {
     break;
    }
    $245 = (($230) + 12|0);
    $246 = HEAP32[$245>>2]|0;
    $247 = ($246|0)==(0);
    if ($247) {
     __THREW__ = 0;
     $248 = (invoke_i(132)|0);
     $249 = __THREW__; __THREW__ = 0;
     $250 = $249&1;
     if ($250) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($248|0));
     $251 = __THREW__; __THREW__ = 0;
     $252 = $251&1;
     if ($252) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($230|0),($240|0));
    $253 = __THREW__; __THREW__ = 0;
    $254 = $253&1;
    if ($254) {
     break;
    }
    $255 = (($230) + 16|0);
    HEAP32[$255>>2] = $240;
    $$0 = $230;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 133) {
    $327 = (($__this) + 116|0);
    $328 = HEAP32[$327>>2]|0;
    $329 = ($328|0)==(0|0);
    if (!($329)) {
     __THREW__ = 0;
     invoke_vi(3799,($328|0));
     $330 = __THREW__; __THREW__ = 0;
     $331 = $330&1;
     if ($331) {
      break;
     }
     $332 = (($328) + 12|0);
     $333 = HEAP32[$332>>2]|0;
     $334 = ($333|0)<(1);
     if (!($334)) {
      $335 = HEAP32[$327>>2]|0;
      $$0 = $335;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1168432|0))|0);
    $336 = __THREW__; __THREW__ = 0;
    $337 = $336&1;
    if ($337) {
     break;
    }
    __THREW__ = 0;
    $338 = (invoke_iii(2758,(1168432|0),1)|0);
    $339 = __THREW__; __THREW__ = 0;
    $340 = $339&1;
    if ($340) {
     break;
    }
    __THREW__ = 0;
    $341 = (invoke_ii(2006,($__this|0))|0);
    $342 = __THREW__; __THREW__ = 0;
    $343 = $342&1;
    if ($343) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($338|0));
    $344 = __THREW__; __THREW__ = 0;
    $345 = $344&1;
    if ($345) {
     break;
    }
    $346 = (($338) + 12|0);
    $347 = HEAP32[$346>>2]|0;
    $348 = ($347|0)==(0);
    if ($348) {
     __THREW__ = 0;
     $349 = (invoke_i(132)|0);
     $350 = __THREW__; __THREW__ = 0;
     $351 = $350&1;
     if ($351) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($349|0));
     $352 = __THREW__; __THREW__ = 0;
     $353 = $352&1;
     if ($353) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($338|0),($341|0));
    $354 = __THREW__; __THREW__ = 0;
    $355 = $354&1;
    if ($355) {
     break;
    }
    $356 = (($338) + 16|0);
    HEAP32[$356>>2] = $341;
    $$0 = $338;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 146) {
    __THREW__ = 0;
    (invoke_ii(2996,(1168432|0))|0);
    $357 = __THREW__; __THREW__ = 0;
    $358 = $357&1;
    if ($358) {
     break;
    }
    __THREW__ = 0;
    $359 = (invoke_iii(2758,(1168432|0),1)|0);
    $360 = __THREW__; __THREW__ = 0;
    $361 = $360&1;
    if ($361) {
     break;
    }
    __THREW__ = 0;
    $362 = (invoke_ii(2011,($__this|0))|0);
    $363 = __THREW__; __THREW__ = 0;
    $364 = $363&1;
    if ($364) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($359|0));
    $365 = __THREW__; __THREW__ = 0;
    $366 = $365&1;
    if ($366) {
     break;
    }
    $367 = (($359) + 12|0);
    $368 = HEAP32[$367>>2]|0;
    $369 = ($368|0)==(0);
    if ($369) {
     __THREW__ = 0;
     $370 = (invoke_i(132)|0);
     $371 = __THREW__; __THREW__ = 0;
     $372 = $371&1;
     if ($372) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($370|0));
     $373 = __THREW__; __THREW__ = 0;
     $374 = $373&1;
     if ($374) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($359|0),($362|0));
    $375 = __THREW__; __THREW__ = 0;
    $376 = $375&1;
    if ($376) {
     break;
    }
    $377 = (($359) + 16|0);
    HEAP32[$377>>2] = $362;
    $$0 = $359;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_PopulateCombinedListP48mscorlib_System_Globalization_DateTimeFormatInfoP26mscorlib_System_String_arrS2_($__this,$dates,$times) {
 $__this = $__this|0;
 $dates = $dates|0;
 $times = $times|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_4$0 = 0, $V_7$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2336352);
 __THREW__ = 0;
 invoke_v(589);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($dates|0)==(0|0);
  $3 = ($times|0)==(0|0);
  $or$cond = $2 | $3;
  if ($or$cond) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($dates|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = (($dates) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($times|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = (($times) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(1168432|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = Math_imul($17, $13)|0;
     __THREW__ = 0;
     $21 = (invoke_iii(2758,(1168432|0),($20|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = (($dates) + 16|0);
      $25 = (($times) + 16|0);
      $26 = (($21) + 16|0);
      $27 = (($21) + 12|0);
      $V_1$1 = 0;$V_4$0 = 0;
      L10: while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($dates|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        label = 4;
        break;
       }
       $86 = HEAP32[$12>>2]|0;
       $87 = ($V_4$0|0)<($86|0);
       if (!($87)) {
        $$0 = $21;
        label = 34;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($dates|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        label = 4;
        break;
       }
       $28 = HEAP32[$12>>2]|0;
       $29 = ($V_4$0>>>0)<($28>>>0);
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_i(132)|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($30|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         label = 4;
         break;
        }
       }
       $35 = HEAP32[$dates>>2]|0;
       $36 = (($35) + 92|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = Math_imul($37, $V_4$0)|0;
       $39 = (($24) + ($38)|0);
       $40 = HEAP32[$39>>2]|0;
       $V_1$0 = $V_1$1;$V_7$0 = 0;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($times|0));
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         label = 3;
         break L10;
        }
        $79 = HEAP32[$16>>2]|0;
        $80 = ($V_7$0|0)<($79|0);
        if (!($80)) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($times|0));
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 3;
         break L10;
        }
        $41 = HEAP32[$16>>2]|0;
        $42 = ($V_7$0>>>0)<($41>>>0);
        if (!($42)) {
         __THREW__ = 0;
         $43 = (invoke_i(132)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          label = 3;
          break L10;
         }
         __THREW__ = 0;
         invoke_vi(3302,($43|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          label = 3;
          break L10;
         }
        }
        $48 = HEAP32[$times>>2]|0;
        $49 = (($48) + 92|0);
        $50 = HEAP32[$49>>2]|0;
        $51 = Math_imul($50, $V_7$0)|0;
        $52 = (($25) + ($51)|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = (($V_1$0) + 1)|0;
        $55 = HEAP32[3028800>>2]|0;
        __THREW__ = 0;
        $56 = (invoke_iiiii(101,(0|0),($40|0),($55|0),($53|0))|0);
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 3;
         break L10;
        }
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 3;
         break L10;
        }
        $61 = ($V_1$0|0)<(0);
        if ($61) {
         label = 23;
        } else {
         $62 = HEAP32[$27>>2]|0;
         $63 = ($V_1$0>>>0)<($62>>>0);
         if (!($63)) {
          label = 23;
         }
        }
        if ((label|0) == 23) {
         label = 0;
         __THREW__ = 0;
         $64 = (invoke_i(132)|0);
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          label = 3;
          break L10;
         }
         __THREW__ = 0;
         invoke_vi(3302,($64|0));
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          label = 3;
          break L10;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($21|0),($56|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 3;
         break L10;
        }
        $71 = HEAP32[$21>>2]|0;
        $72 = (($71) + 92|0);
        $73 = HEAP32[$72>>2]|0;
        $74 = Math_imul($73, $V_1$0)|0;
        $75 = (($26) + ($74)|0);
        HEAP32[$75>>2] = $56;
        $76 = (($V_7$0) + 1)|0;
        $V_1$0 = $54;$V_7$0 = $76;
       }
       $83 = (($V_4$0) + 1)|0;
       $V_1$1 = $V_1$0;$V_4$0 = $83;
      }
      if ((label|0) == 3) {
       $4 = ___cxa_find_matching_catch()|0;
       $5 = tempRet0;
       $lpad$phi$index = $4;$lpad$phi$index3 = $5;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 4) {
       $6 = ___cxa_find_matching_catch()|0;
       $7 = tempRet0;
       $lpad$phi$index = $6;$lpad$phi$index3 = $7;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 34) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index3 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Globalization_DateTimeFormatInfo_m_GetDayNameP48mscorlib_System_Globalization_DateTimeFormatInfoi($__this,$dayofweek) {
 $__this = $__this|0;
 $dayofweek = $dayofweek|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2336208);
 $0 = ($dayofweek|0)<(0);
 $$not = $0 ^ 1;
 $1 = ($dayofweek|0)<(7);
 $or$cond = $1 & $$not;
 if ($or$cond) {
  $13 = (($__this) + 84|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($14|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   if (!($0)) {
    $17 = (($14) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18>>>0)>($dayofweek>>>0);
    if ($19) {
     $25 = HEAP32[$14>>2]|0;
     $26 = (($14) + 16|0);
     $27 = (($25) + 92|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = Math_imul($28, $dayofweek)|0;
     $30 = (($26) + ($29)|0);
     $31 = HEAP32[$30>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($31|0);
    }
   }
   __THREW__ = 0;
   $20 = (invoke_i(132)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    invoke_vi(3302,($20|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = HEAP32[$14>>2]|0;
     $26 = (($14) + 16|0);
     $27 = (($25) + 92|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = Math_imul($28, $dayofweek)|0;
     $30 = (($26) + ($29)|0);
     $31 = HEAP32[$30>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($31|0);
    }
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2561352|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(2587,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vi(3833,($4|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      // unreachable;
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z72mscorlib_System_Globalization_DateTimeFormatInfo_m_GetAbbreviatedDayNameP48mscorlib_System_Globalization_DateTimeFormatInfoi($__this,$dayofweek) {
 $__this = $__this|0;
 $dayofweek = $dayofweek|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2336256);
 $0 = ($dayofweek|0)<(0);
 $$not = $0 ^ 1;
 $1 = ($dayofweek|0)<(7);
 $or$cond = $1 & $$not;
 if ($or$cond) {
  $13 = (($__this) + 80|0);
  $14 = HEAP32[$13>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($14|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   if (!($0)) {
    $17 = (($14) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18>>>0)>($dayofweek>>>0);
    if ($19) {
     $25 = HEAP32[$14>>2]|0;
     $26 = (($14) + 16|0);
     $27 = (($25) + 92|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = Math_imul($28, $dayofweek)|0;
     $30 = (($26) + ($29)|0);
     $31 = HEAP32[$30>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($31|0);
    }
   }
   __THREW__ = 0;
   $20 = (invoke_i(132)|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    invoke_vi(3302,($20|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = HEAP32[$14>>2]|0;
     $26 = (($14) + 16|0);
     $27 = (($25) + 92|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = Math_imul($28, $dayofweek)|0;
     $30 = (($26) + ($29)|0);
     $31 = HEAP32[$30>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($31|0);
    }
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2561352|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(2587,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vi(3833,($4|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      // unreachable;
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I17VoidPointerTraits26mscorlib_System_CharTraitsE6InvokeEPFPvS3_tES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z79mscorlib_System_Globalization_DateTimeFormatInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Globalization_DateTimeStyles_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z50mscorlib_System_Globalization_DaylightTime_m__ctorP42mscorlib_System_Globalization_DaylightTime24mscorlib_System_DateTimeS1_24mscorlib_System_TimeSpan($__this,$start,$end,$delta) {
 $__this = $__this|0;
 $start = $start|0;
 $end = $end|0;
 $delta = $delta|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2341640);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  ;HEAP32[$2+0>>2]=HEAP32[$start+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$start+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$start+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$start+12>>2]|0;
  $3 = (($__this) + 24|0);
  ;HEAP32[$3+0>>2]=HEAP32[$end+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$end+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$end+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$end+12>>2]|0;
  $4 = $delta;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($__this) + 40|0);
  $11 = $10;
  $12 = $11;
  HEAP32[$12>>2] = $6;
  $13 = (($11) + 4)|0;
  $14 = $13;
  HEAP32[$14>>2] = $9;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_Globalization_DaylightTime_m_get_StartP42mscorlib_System_Globalization_DaylightTime($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2341688);
 $0 = (($__this) + 8|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z52mscorlib_System_Globalization_DaylightTime_m_get_EndP42mscorlib_System_Globalization_DaylightTime($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2341736);
 $0 = (($__this) + 24|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_Globalization_DaylightTime_m_get_DeltaP42mscorlib_System_Globalization_DaylightTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2341784);
 $0 = (($__this) + 40|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $6;
 STACKTOP = sp;return ($3|0);
}
function __ZN14ActionInvoker3I30mscorlib_System_DateTimeTraitsS0_30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPv24mscorlib_System_DateTimeS4_24mscorlib_System_TimeSpanES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy2 = sp + 72|0;
 $$byval_copy1 = sp;
 $$byval_copy = sp + 16|0;
 $0 = sp + 32|0;
 $1 = sp + 48|0;
 $2 = sp + 64|0;
 $3 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (($args) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$5+12>>2]|0;
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $2;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$1+12>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$$byval_copy,$$byval_copy1,$$byval_copy2);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker0I30mscorlib_System_DateTimeTraitsE6InvokeEPF24mscorlib_System_DateTimePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z73mscorlib_System_Globalization_DaylightTime_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z129mscorlib_System_Globalization_GregorianCalendar_m__ctor_mscorlib_System_Void_mscorlib_System_Globalization_GregorianCalendarTypesP47mscorlib_System_Globalization_GregorianCalendari($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342256);
 __THREW__ = 0;
 invoke_v(590);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(2201,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    invoke_viii(2111,(2342304|0),($__this|0),($type|0));
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(1168432|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      __THREW__ = 0;
      $8 = (invoke_iii(2758,(1168432|0),1)|0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if (!($10)) {
       __THREW__ = 0;
       invoke_vi(3799,($8|0));
       $11 = __THREW__; __THREW__ = 0;
       $12 = $11&1;
       if (!($12)) {
        $13 = (($8) + 12|0);
        $14 = HEAP32[$13>>2]|0;
        $15 = ($14|0)==(0);
        if ($15) {
         __THREW__ = 0;
         $16 = (invoke_i(132)|0);
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if ($18) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($16|0));
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if ($20) {
          break;
         }
        }
        $23 = HEAP32[3028816>>2]|0;
        __THREW__ = 0;
        invoke_vii(3492,($8|0),($23|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         $26 = HEAP32[3028816>>2]|0;
         $27 = (($8) + 16|0);
         HEAP32[$27>>2] = $26;
         $28 = (($__this) + 16|0);
         HEAP32[$28>>2] = $8;
         __THREW__ = 0;
         (invoke_ii(2996,(1168432|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          __THREW__ = 0;
          $31 = (invoke_iii(2758,(1168432|0),1)|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           __THREW__ = 0;
           invoke_vi(3799,($31|0));
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $36 = (($31) + 12|0);
            $37 = HEAP32[$36>>2]|0;
            $38 = ($37|0)==(0);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            $44 = HEAP32[3028824>>2]|0;
            __THREW__ = 0;
            invoke_vii(3492,($31|0),($44|0));
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if (!($46)) {
             $47 = HEAP32[3028824>>2]|0;
             $48 = (($31) + 16|0);
             HEAP32[$48>>2] = $47;
             $49 = (($__this) + 20|0);
             HEAP32[$49>>2] = $31;
             $50 = (($__this) + 12|0);
             $51 = HEAP32[$50>>2]|0;
             $52 = ($51|0)==(99);
             if (!($52)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
             HEAP32[$50>>2] = 2029;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z58mscorlib_System_Globalization_GregorianCalendar_m_get_ErasP47mscorlib_System_Globalization_GregorianCalendar($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342400);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2758,(1170368|0),1)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($2) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0);
    if (!($9)) {
     $17 = (($2) + 16|0);
     HEAP32[$17>>2] = (1);
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($2|0);
    }
    __THREW__ = 0;
    $10 = (invoke_i(132)|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3302,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $17 = (($2) + 16|0);
      HEAP32[$17>>2] = (1);
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($2|0);
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Globalization_GregorianCalendar_m_set_CalendarTypeP47mscorlib_System_Globalization_GregorianCalendari($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342304);
 __THREW__ = 0;
 invoke_vi(2202,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 24|0);
  HEAP32[$2>>2] = $value;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z63mscorlib_System_Globalization_GregorianCalendar_m_GetDayOfMonthP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $time$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342448);
 __THREW__ = 0;
 ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
 $0 = (invoke_iii(843,0,($time$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z62mscorlib_System_Globalization_GregorianCalendar_m_GetDayOfWeekP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $time$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342496);
 __THREW__ = 0;
 ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
 $0 = (invoke_iii(837,0,($time$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 __THREW__ = 0;
 $3 = (invoke_iii(838,0,($0|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z56mscorlib_System_Globalization_GregorianCalendar_m_GetEraP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342544);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z58mscorlib_System_Globalization_GregorianCalendar_m_GetMonthP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $time$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342592);
 __THREW__ = 0;
 ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
 $0 = (invoke_iii(844,0,($time$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Globalization_GregorianCalendar_m_GetYearP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $time$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2342640);
 __THREW__ = 0;
 ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
 $0 = (invoke_iii(845,0,($time$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Globalization_GregorianCalendar_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2342856)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Globalization_GregorianCalendarTypes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z121mscorlib_System_Globalization_NumberFormatInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_BooleanP46mscorlib_System_Globalization_NumberFormatInfoib($__this,$lcid,$read_only) {
 $__this = $__this|0;
 $lcid = $lcid|0;
 $read_only = $read_only|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2343864);
 __THREW__ = 0;
 invoke_v(591);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[3029160>>2]|0;
   $3 = (($__this) + 24|0);
   HEAP32[$3>>2] = $2;
   $4 = HEAP32[3029168>>2]|0;
   $5 = (($__this) + 28|0);
   HEAP32[$5>>2] = $4;
   __THREW__ = 0;
   (invoke_ii(2996,(2348608|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = HEAP8[((2348608 + 116|0))>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     __THREW__ = 0;
     (invoke_ii(2996,(2348608|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2348608|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2348608|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2348608|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = HEAP32[((2348608 + 80|0))>>2]|0;
     $21 = HEAP32[$20>>2]|0;
     $22 = (($__this) + 144|0);
     HEAP32[$22>>2] = $21;
     $23 = (($__this) + 148|0);
     HEAP32[$23>>2] = 1;
     __THREW__ = 0;
     invoke_vi(1924,($__this|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = (($__this) + 8|0);
      HEAP8[$26>>0] = 0;
      $27 = (($__this) + 32|0);
      HEAP32[$27>>2] = 2;
      $28 = HEAP32[3029176>>2]|0;
      $29 = (($__this) + 36|0);
      HEAP32[$29>>2] = $28;
      $30 = HEAP32[3029184>>2]|0;
      $31 = (($__this) + 40|0);
      HEAP32[$31>>2] = $30;
      __THREW__ = 0;
      (invoke_ii(2996,(1170368|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       $34 = (invoke_iii(2758,(1170368|0),1)|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        __THREW__ = 0;
        invoke_vi(3799,($34|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = (($34) + 12|0);
         $40 = HEAP32[$39>>2]|0;
         $41 = ($40|0)==(0);
         if ($41) {
          __THREW__ = 0;
          $42 = (invoke_i(132)|0);
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($42|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           break;
          }
         }
         $47 = (($34) + 16|0);
         HEAP32[$47>>2] = (3);
         $48 = (($__this) + 44|0);
         HEAP32[$48>>2] = $34;
         $49 = (($__this) + 48|0);
         HEAP32[$49>>2] = 0;
         $50 = (($__this) + 52|0);
         HEAP32[$50>>2] = 0;
         $51 = HEAP32[3029192>>2]|0;
         $52 = (($__this) + 56|0);
         HEAP32[$52>>2] = $51;
         $53 = HEAP32[3029200>>2]|0;
         $54 = (($__this) + 60|0);
         HEAP32[$54>>2] = $53;
         $55 = HEAP32[3029208>>2]|0;
         $56 = (($__this) + 64|0);
         HEAP32[$56>>2] = $55;
         $57 = HEAP32[3029216>>2]|0;
         $58 = (($__this) + 68|0);
         HEAP32[$58>>2] = $57;
         $59 = (($__this) + 72|0);
         HEAP32[$59>>2] = 2;
         $60 = HEAP32[3029224>>2]|0;
         $61 = (($__this) + 76|0);
         HEAP32[$61>>2] = $60;
         $62 = HEAP32[3029232>>2]|0;
         $63 = (($__this) + 80|0);
         HEAP32[$63>>2] = $62;
         __THREW__ = 0;
         (invoke_ii(2996,(1170368|0))|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if (!($65)) {
          __THREW__ = 0;
          $66 = (invoke_iii(2758,(1170368|0),1)|0);
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if (!($68)) {
           __THREW__ = 0;
           invoke_vi(3799,($66|0));
           $69 = __THREW__; __THREW__ = 0;
           $70 = $69&1;
           if (!($70)) {
            $71 = (($66) + 12|0);
            $72 = HEAP32[$71>>2]|0;
            $73 = ($72|0)==(0);
            if ($73) {
             __THREW__ = 0;
             $74 = (invoke_i(132)|0);
             $75 = __THREW__; __THREW__ = 0;
             $76 = $75&1;
             if ($76) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($74|0));
             $77 = __THREW__; __THREW__ = 0;
             $78 = $77&1;
             if ($78) {
              break;
             }
            }
            $79 = (($66) + 16|0);
            HEAP32[$79>>2] = (3);
            $80 = (($__this) + 84|0);
            HEAP32[$80>>2] = $66;
            $81 = (($__this) + 88|0);
            HEAP32[$81>>2] = 1;
            $82 = (($__this) + 92|0);
            HEAP32[$82>>2] = 2;
            $83 = HEAP32[3029240>>2]|0;
            $84 = (($__this) + 96|0);
            HEAP32[$84>>2] = $83;
            $85 = HEAP32[3029248>>2]|0;
            $86 = (($__this) + 100|0);
            HEAP32[$86>>2] = $85;
            __THREW__ = 0;
            (invoke_ii(2996,(1170368|0))|0);
            $87 = __THREW__; __THREW__ = 0;
            $88 = $87&1;
            if (!($88)) {
             __THREW__ = 0;
             $89 = (invoke_iii(2758,(1170368|0),1)|0);
             $90 = __THREW__; __THREW__ = 0;
             $91 = $90&1;
             if (!($91)) {
              __THREW__ = 0;
              invoke_vi(3799,($89|0));
              $92 = __THREW__; __THREW__ = 0;
              $93 = $92&1;
              if (!($93)) {
               $94 = (($89) + 12|0);
               $95 = HEAP32[$94>>2]|0;
               $96 = ($95|0)==(0);
               if (!($96)) {
                $102 = (($89) + 16|0);
                HEAP32[$102>>2] = (3);
                $103 = (($__this) + 104|0);
                HEAP32[$103>>2] = $89;
                $104 = (($__this) + 108|0);
                HEAP32[$104>>2] = 0;
                $105 = (($__this) + 112|0);
                HEAP32[$105>>2] = 0;
                $106 = HEAP32[3029256>>2]|0;
                $107 = (($__this) + 116|0);
                HEAP32[$107>>2] = $106;
                $108 = HEAP32[3029264>>2]|0;
                $109 = (($__this) + 120|0);
                HEAP32[$109>>2] = $108;
                $110 = HEAP32[3029272>>2]|0;
                $111 = (($__this) + 124|0);
                HEAP32[$111>>2] = $110;
                $112 = HEAP32[3029280>>2]|0;
                $113 = (($__this) + 128|0);
                HEAP32[$113>>2] = $112;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
               __THREW__ = 0;
               $97 = (invoke_i(132)|0);
               $98 = __THREW__; __THREW__ = 0;
               $99 = $98&1;
               if (!($99)) {
                __THREW__ = 0;
                invoke_vi(3302,($97|0));
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if (!($101)) {
                 $102 = (($89) + 16|0);
                 HEAP32[$102>>2] = (3);
                 $103 = (($__this) + 104|0);
                 HEAP32[$103>>2] = $89;
                 $104 = (($__this) + 108|0);
                 HEAP32[$104>>2] = 0;
                 $105 = (($__this) + 112|0);
                 HEAP32[$105>>2] = 0;
                 $106 = HEAP32[3029256>>2]|0;
                 $107 = (($__this) + 116|0);
                 HEAP32[$107>>2] = $106;
                 $108 = HEAP32[3029264>>2]|0;
                 $109 = (($__this) + 120|0);
                 HEAP32[$109>>2] = $108;
                 $110 = HEAP32[3029272>>2]|0;
                 $111 = (($__this) + 124|0);
                 HEAP32[$111>>2] = $110;
                 $112 = HEAP32[3029280>>2]|0;
                 $113 = (($__this) + 128|0);
                 HEAP32[$113>>2] = $112;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z75mscorlib_System_Globalization_NumberFormatInfo_m__ctor_mscorlib_System_VoidP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2343960);
 __THREW__ = 0;
 invoke_vii(1842,($__this|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z55mscorlib_System_Globalization_NumberFormatInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344008);
 __THREW__ = 0;
 invoke_v(592);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1168432|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2758,(1168432|0),10)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $19 = HEAP32[3029376>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($4|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[3029376>>2]|0;
       $23 = (($4) + 16|0);
       HEAP32[$23>>2] = $22;
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        $26 = HEAP32[$9>>2]|0;
        $27 = ($26>>>0)<(2);
        if ($27) {
         __THREW__ = 0;
         $28 = (invoke_i(132)|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($28|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
        }
        $33 = HEAP32[3029384>>2]|0;
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($33|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if (!($35)) {
         $36 = HEAP32[3029384>>2]|0;
         $37 = HEAP32[$4>>2]|0;
         $38 = (($37) + 92|0);
         $39 = HEAP32[$38>>2]|0;
         $40 = (($23) + ($39)|0);
         HEAP32[$40>>2] = $36;
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$9>>2]|0;
          $44 = ($43>>>0)<(3);
          if ($44) {
           __THREW__ = 0;
           $45 = (invoke_i(132)|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if ($47) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($45|0));
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break;
           }
          }
          $50 = HEAP32[3029392>>2]|0;
          __THREW__ = 0;
          invoke_vii(3492,($4|0),($50|0));
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if (!($52)) {
           $53 = HEAP32[3029392>>2]|0;
           $54 = HEAP32[$4>>2]|0;
           $55 = (($54) + 92|0);
           $56 = HEAP32[$55>>2]|0;
           $57 = $56 << 1;
           $58 = (($23) + ($57)|0);
           HEAP32[$58>>2] = $53;
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $59 = __THREW__; __THREW__ = 0;
           $60 = $59&1;
           if (!($60)) {
            $61 = HEAP32[$9>>2]|0;
            $62 = ($61>>>0)<(4);
            if ($62) {
             __THREW__ = 0;
             $63 = (invoke_i(132)|0);
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if ($65) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($63|0));
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if ($67) {
              break;
             }
            }
            $68 = HEAP32[3029400>>2]|0;
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($68|0));
            $69 = __THREW__; __THREW__ = 0;
            $70 = $69&1;
            if (!($70)) {
             $71 = HEAP32[3029400>>2]|0;
             $72 = HEAP32[$4>>2]|0;
             $73 = (($72) + 92|0);
             $74 = HEAP32[$73>>2]|0;
             $75 = ($74*3)|0;
             $76 = (($23) + ($75)|0);
             HEAP32[$76>>2] = $71;
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $77 = __THREW__; __THREW__ = 0;
             $78 = $77&1;
             if (!($78)) {
              $79 = HEAP32[$9>>2]|0;
              $80 = ($79>>>0)<(5);
              if ($80) {
               __THREW__ = 0;
               $81 = (invoke_i(132)|0);
               $82 = __THREW__; __THREW__ = 0;
               $83 = $82&1;
               if ($83) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($81|0));
               $84 = __THREW__; __THREW__ = 0;
               $85 = $84&1;
               if ($85) {
                break;
               }
              }
              $86 = HEAP32[3029408>>2]|0;
              __THREW__ = 0;
              invoke_vii(3492,($4|0),($86|0));
              $87 = __THREW__; __THREW__ = 0;
              $88 = $87&1;
              if (!($88)) {
               $89 = HEAP32[3029408>>2]|0;
               $90 = HEAP32[$4>>2]|0;
               $91 = (($90) + 92|0);
               $92 = HEAP32[$91>>2]|0;
               $93 = $92 << 2;
               $94 = (($23) + ($93)|0);
               HEAP32[$94>>2] = $89;
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $95 = __THREW__; __THREW__ = 0;
               $96 = $95&1;
               if (!($96)) {
                $97 = HEAP32[$9>>2]|0;
                $98 = ($97>>>0)<(6);
                if ($98) {
                 __THREW__ = 0;
                 $99 = (invoke_i(132)|0);
                 $100 = __THREW__; __THREW__ = 0;
                 $101 = $100&1;
                 if ($101) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($99|0));
                 $102 = __THREW__; __THREW__ = 0;
                 $103 = $102&1;
                 if ($103) {
                  break;
                 }
                }
                $104 = HEAP32[3029416>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($104|0));
                $105 = __THREW__; __THREW__ = 0;
                $106 = $105&1;
                if ($106) {
                 break;
                }
                $107 = HEAP32[3029416>>2]|0;
                $108 = HEAP32[$4>>2]|0;
                $109 = (($108) + 92|0);
                $110 = HEAP32[$109>>2]|0;
                $111 = ($110*5)|0;
                $112 = (($23) + ($111)|0);
                HEAP32[$112>>2] = $107;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $113 = __THREW__; __THREW__ = 0;
                $114 = $113&1;
                if ($114) {
                 break;
                }
                $115 = HEAP32[$9>>2]|0;
                $116 = ($115>>>0)<(7);
                if ($116) {
                 __THREW__ = 0;
                 $117 = (invoke_i(132)|0);
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($117|0));
                 $120 = __THREW__; __THREW__ = 0;
                 $121 = $120&1;
                 if ($121) {
                  break;
                 }
                }
                $122 = HEAP32[3029424>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($122|0));
                $123 = __THREW__; __THREW__ = 0;
                $124 = $123&1;
                if ($124) {
                 break;
                }
                $125 = HEAP32[3029424>>2]|0;
                $126 = HEAP32[$4>>2]|0;
                $127 = (($126) + 92|0);
                $128 = HEAP32[$127>>2]|0;
                $129 = ($128*6)|0;
                $130 = (($23) + ($129)|0);
                HEAP32[$130>>2] = $125;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $131 = __THREW__; __THREW__ = 0;
                $132 = $131&1;
                if ($132) {
                 break;
                }
                $133 = HEAP32[$9>>2]|0;
                $134 = ($133>>>0)<(8);
                if ($134) {
                 __THREW__ = 0;
                 $135 = (invoke_i(132)|0);
                 $136 = __THREW__; __THREW__ = 0;
                 $137 = $136&1;
                 if ($137) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($135|0));
                 $138 = __THREW__; __THREW__ = 0;
                 $139 = $138&1;
                 if ($139) {
                  break;
                 }
                }
                $140 = HEAP32[3029432>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($140|0));
                $141 = __THREW__; __THREW__ = 0;
                $142 = $141&1;
                if ($142) {
                 break;
                }
                $143 = HEAP32[3029432>>2]|0;
                $144 = HEAP32[$4>>2]|0;
                $145 = (($144) + 92|0);
                $146 = HEAP32[$145>>2]|0;
                $147 = ($146*7)|0;
                $148 = (($23) + ($147)|0);
                HEAP32[$148>>2] = $143;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $149 = __THREW__; __THREW__ = 0;
                $150 = $149&1;
                if ($150) {
                 break;
                }
                $151 = HEAP32[$9>>2]|0;
                $152 = ($151>>>0)<(9);
                if ($152) {
                 __THREW__ = 0;
                 $153 = (invoke_i(132)|0);
                 $154 = __THREW__; __THREW__ = 0;
                 $155 = $154&1;
                 if ($155) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($153|0));
                 $156 = __THREW__; __THREW__ = 0;
                 $157 = $156&1;
                 if ($157) {
                  break;
                 }
                }
                $158 = HEAP32[3029440>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($158|0));
                $159 = __THREW__; __THREW__ = 0;
                $160 = $159&1;
                if ($160) {
                 break;
                }
                $161 = HEAP32[3029440>>2]|0;
                $162 = HEAP32[$4>>2]|0;
                $163 = (($162) + 92|0);
                $164 = HEAP32[$163>>2]|0;
                $165 = $164 << 3;
                $166 = (($23) + ($165)|0);
                HEAP32[$166>>2] = $161;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $167 = __THREW__; __THREW__ = 0;
                $168 = $167&1;
                if ($168) {
                 break;
                }
                $169 = HEAP32[$9>>2]|0;
                $170 = ($169>>>0)<(10);
                if ($170) {
                 __THREW__ = 0;
                 $171 = (invoke_i(132)|0);
                 $172 = __THREW__; __THREW__ = 0;
                 $173 = $172&1;
                 if ($173) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($171|0));
                 $174 = __THREW__; __THREW__ = 0;
                 $175 = $174&1;
                 if ($175) {
                  break;
                 }
                }
                $176 = HEAP32[3029448>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($176|0));
                $177 = __THREW__; __THREW__ = 0;
                $178 = $177&1;
                if ($178) {
                 break;
                }
                $179 = HEAP32[3029448>>2]|0;
                $180 = HEAP32[$4>>2]|0;
                $181 = (($180) + 92|0);
                $182 = HEAP32[$181>>2]|0;
                $183 = ($182*9)|0;
                $184 = (($23) + ($183)|0);
                HEAP32[$184>>2] = $179;
                __THREW__ = 0;
                (invoke_ii(2996,(2348608|0))|0);
                $185 = __THREW__; __THREW__ = 0;
                $186 = $185&1;
                if ($186) {
                 break;
                }
                $187 = HEAP32[((2348608 + 80|0))>>2]|0;
                HEAP32[$187>>2] = $4;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z74mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyDecimalDigitsP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344056);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z77mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyDecimalSeparatorP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344104);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyGroupSeparatorP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344152);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Globalization_NumberFormatInfo_m_get_RawCurrencyGroupSizesP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344200);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z76mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyNegativePatternP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344248);
 $0 = (($__this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z76mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyPositivePatternP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344296);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencySymbolP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344344);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z64mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrentInfoP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344392);
 __THREW__ = 0;
 $0 = (invoke_ii(2405,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(1178,(0|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2730,(2330184|0),($3|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = (($8) + 8|0);
      HEAP8[$13>>0] = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($8|0);
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Globalization_NumberFormatInfo_m_set_NumberNegativePatternP46mscorlib_System_Globalization_NumberFormatInfoi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344872);
 __THREW__ = 0;
 invoke_v(593);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value>>>0)<(5);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3028856>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 8|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    $28 = (($__this) + 88|0);
    HEAP32[$28>>2] = $value;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2607872|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2607872|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[3028864>>2]|0;
     __THREW__ = 0;
     invoke_vii(1947,($20|0),($23|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      invoke_vi(3833,($20|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z62mscorlib_System_Globalization_NumberFormatInfo_m_get_NaNSymbolP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344488);
 $0 = (($__this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_NegativeInfinitySymbolP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344536);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65mscorlib_System_Globalization_NumberFormatInfo_m_get_NegativeSignP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344584);
 $0 = (($__this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z72mscorlib_System_Globalization_NumberFormatInfo_m_get_NumberDecimalDigitsP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344632);
 $0 = (($__this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_NumberDecimalSeparatorP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344680);
 $0 = (($__this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z73mscorlib_System_Globalization_NumberFormatInfo_m_get_NumberGroupSeparatorP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344728);
 $0 = (($__this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z72mscorlib_System_Globalization_NumberFormatInfo_m_get_RawNumberGroupSizesP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344776);
 $0 = (($__this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Globalization_NumberFormatInfo_m_get_NumberNegativePatternP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344824);
 $0 = (($__this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z73mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentDecimalDigitsP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344920);
 $0 = (($__this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z76mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentDecimalSeparatorP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2344968);
 $0 = (($__this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentGroupSeparatorP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345016);
 $0 = (($__this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z73mscorlib_System_Globalization_NumberFormatInfo_m_get_RawPercentGroupSizesP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345064);
 $0 = (($__this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentNegativePatternP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345112);
 $0 = (($__this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentPositivePatternP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345160);
 $0 = (($__this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z66mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentSymbolP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345208);
 $0 = (($__this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67mscorlib_System_Globalization_NumberFormatInfo_m_get_PerMilleSymbolP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345256);
 $0 = (($__this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_PositiveInfinitySymbolP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345304);
 $0 = (($__this) + 124|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65mscorlib_System_Globalization_NumberFormatInfo_m_get_PositiveSignP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345352);
 $0 = (($__this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z58mscorlib_System_Globalization_NumberFormatInfo_m_GetFormatP46mscorlib_System_Globalization_NumberFormatInfoP20mscorlib_System_Type($__this,$formatType) {
 $__this = $__this|0;
 $formatType = $formatType|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $__this$ = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345400);
 HEAP32[$0>>2] = 2271128;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $4 = ($1|0)==($formatType|0);
  $__this$ = $4 ? $__this : 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($__this$|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Globalization_NumberFormatInfo_m_CloneP46mscorlib_System_Globalization_NumberFormatInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2330904);
 __THREW__ = 0;
 $0 = (invoke_ii(1783,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2348608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2759,($0|0),(2348608|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($5) + 8|0);
     HEAP8[$10>>0] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($5|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Globalization_NumberFormatInfo_m_GetInstanceP22mscorlib_System_ObjectS0_($__this,$formatProvider) {
 $__this = $__this|0;
 $formatProvider = $formatProvider|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2345448);
 $1 = ($formatProvider|0)==(0|0);
 if ($1) {
  label = 10;
 } else {
  HEAP32[$0>>2] = 2271128;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $2 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($formatProvider|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iiii(1666,(2606440|0),($formatProvider|0),($2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2348608|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_iii(2759,($7|0),(2348608|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = ($12|0)==(0|0);
       if ($15) {
        label = 10;
       } else {
        $$0 = $12;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 if ((label|0) == 10) {
  __THREW__ = 0;
  $18 = (invoke_ii(2025,0)|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   $$0 = $18;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Globalization_NumberFormatInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73mscorlib_System_Globalization_NumberStyles_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z47mscorlib_System_Globalization_TextInfo_m_EqualsP38mscorlib_System_Globalization_TextInfoP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2350360);
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2351088|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2735,($obj|0),(2351088|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($3) + 16|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($__this) + 16|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($12|0)==($14|0);
    if (!($15)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = (($3) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($__this) + 20|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($19|0)==($21|0);
     $$0 = $22;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Globalization_TextInfo_m_GetHashCodeP38mscorlib_System_Globalization_TextInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2350408);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z49mscorlib_System_Globalization_TextInfo_m_ToStringP38mscorlib_System_Globalization_TextInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2350456);
 __THREW__ = 0;
 invoke_v(594);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$L_1>>2] = $3;
  __THREW__ = 0;
  (invoke_ii(2996,(2155952|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2724,(2155952|0),($L_1|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3029528>>2]|0;
    __THREW__ = 0;
    $10 = (invoke_iiii(559,(0|0),($9|0),($6|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($10|0);
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Globalization_TextInfo_m_ToLower_mscorlib_System_Char_mscorlib_System_CharP38mscorlib_System_Globalization_TextInfot($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $c$off = 0, $c$off3 = 0, $or$cond = 0, $or$cond2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2274320);
 $0 = $c&65535;
 $1 = ($c&65535)>(63);
 $c$off = (($c) + -97)<<16>>16;
 $2 = ($c$off&65535)>(30);
 $or$cond = $1 & $2;
 L1: do {
  if ($or$cond) {
   $c$off3 = (($c) + -65)<<16>>16;
   $3 = ($c$off3&65535)>(25);
   if (!($3)) {
    $4 = (($__this) + 24|0);
    $5 = HEAP8[$4>>0]|0;
    $6 = ($5<<24>>24)!=(0);
    $7 = ($c<<16>>16)==(73);
    $or$cond2 = $6 & $7;
    if (!($or$cond2)) {
     $8 = (($0) + 32)|0;
     $9 = $8&65535;
     $$0 = $9;
     break;
    }
   }
   $10 = (($__this) + 20|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   do {
    if ($12) {
     label = 10;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_iii(2729,(2273552|0),($11|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = ($15|0)==(127);
       if ($18) {
        label = 10;
       } else {
        $24 = (($0) + 65083)|0;
        $25 = $24 & 65535;
        if ((($25|0) == 3)) {
         $$0 = 457;
         break L1;
        } else if ((($25|0) == 0)) {
         $$0 = 454;
         break L1;
        }
        $26 = (($0) + 64558)|0;
        $27 = $26 & 65535;
        if ((($27|0) == 0)) {
         $$0 = 965;
         break L1;
        } else if ((($27|0) == 1)) {
         $$0 = 973;
         break L1;
        } else if ((($27|0) == 2)) {
         $$0 = 971;
         break L1;
        } else {
         if ((($c<<16>>16) == 304)) {
          $$0 = 105;
          break L1;
         } else if ((($c<<16>>16) == 73)) {
          $28 = (($__this) + 24|0);
          $29 = HEAP8[$28>>0]|0;
          $30 = ($29<<24>>24)==(0);
          if (!($30)) {
           $$0 = 305;
           break L1;
          }
         } else if ((($c<<16>>16) == 459)) {
          $$0 = 460;
          break L1;
         } else if ((($c<<16>>16) == 498)) {
          $$0 = 499;
          break L1;
         }
         __THREW__ = 0;
         $31 = (invoke_iii(606,(0|0),($c|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         } else {
          $$0 = $31;
          break L1;
         }
        }
       }
      }
     }
    }
   } while(0);
   if ((label|0) == 10) {
    __THREW__ = 0;
    $21 = (invoke_iii(606,(0|0),($c|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $$0 = $21;
     break;
    }
   }
   $19 = ___cxa_find_matching_catch()|0;
   $20 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($19|0);
   // unreachable;
  } else {
   $$0 = $c;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z94mscorlib_System_Globalization_TextInfo_m_ToLower_mscorlib_System_String_mscorlib_System_StringP38mscorlib_System_Globalization_TextInfoP22mscorlib_System_String($__this,$str) {
 $__this = $__this|0;
 $str = $str|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $V_3$0 = 0, $V_4$0 = 0, $V_5$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2305328);
 __THREW__ = 0;
 invoke_v(595);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($str|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3029568>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($str|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(1816,($str|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = ($19|0)==(0);
     if ($22) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      $25 = HEAP8[((2191608 + 116|0))>>0]|0;
      $26 = ($25<<24>>24)==(0);
      if ($26) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3832,(2191608|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = HEAP32[((2191608 + 80|0))>>2]|0;
      $36 = HEAP32[$35>>2]|0;
      $$0 = $36;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($str|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      __THREW__ = 0;
      $39 = (invoke_ii(1816,($str|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       __THREW__ = 0;
       $42 = (invoke_iii(643,(0|0),($39|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if (!($44)) {
        __THREW__ = 0;
        $45 = (invoke_ii(1919,(0|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if (!($47)) {
         __THREW__ = 0;
         $48 = (invoke_ii(1919,(0|0))|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if (!($50)) {
          $51 = $str;
          $52 = (($45) + ($51))|0;
          $53 = $42;
          $54 = $52;
          $55 = (($48) + ($53))|0;
          $56 = $55;
          $V_3$0 = $56;$V_4$0 = $54;$V_5$0 = 0;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($str|0));
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            break;
           }
           __THREW__ = 0;
           $63 = (invoke_ii(1816,($str|0))|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            break;
           }
           $66 = ($V_5$0|0)<($63|0);
           if (!($66)) {
            $$0 = $42;
            label = 32;
            break;
           }
           $67 = HEAP16[$V_4$0>>1]|0;
           __THREW__ = 0;
           $57 = (invoke_iiii(1667,(2274320|0),($__this|0),($67|0))|0);
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            break;
           }
           HEAP16[$V_3$0>>1] = $57;
           $58 = (($V_4$0) + 2|0);
           $59 = (($V_3$0) + 2|0);
           $60 = (($V_5$0) + 1)|0;
           $V_3$0 = $59;$V_4$0 = $58;$V_5$0 = $60;
          }
          if ((label|0) == 32) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index2 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS4_iS4_bES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$3,$5,$9);
 STACKTOP = sp;return (0|0);
}
function __Z69mscorlib_System_Globalization_TextInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2350840)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Globalization_TextInfo_CustomAttributesCacheGenerator_mscorlib_System_Globalization_TextInfoTraits_CultureName_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Globalization_UnicodeCategory_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_Reflection_Emit_AssemblyBuilder_m_get_IsCompilerContextP47mscorlib_System_Reflection_Emit_AssemblyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2353064);
 $0 = (($__this) + 60|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z68mscorlib_System_Reflection_Emit_AssemblyBuilder_m_UnprotectedGetNameP47mscorlib_System_Reflection_Emit_AssemblyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2353112);
 __THREW__ = 0;
 $0 = (invoke_ii(2187,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_ii(1932,($4|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vii(1855,($0|0),($10|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $17 = HEAP32[$3>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($17|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(1933,($17|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vi(3799,($0|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vii(1856,($0|0),($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Reflection_Assembly_m_UnprotectedGetNameP35mscorlib_System_Reflection_Assembly($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2376456);
 __THREW__ = 0;
 (invoke_ii(2996,(2395256|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2395256|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2274,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_viii(588,0,($__this|0),($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($2|0);
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Reflection_Emit_AssemblyBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2449888)|0);
 $5 = HEAP32[((2449888 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($8,1);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_CallingConventionP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2353720);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_TypeBuilderP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2353768);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z81mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetMethodImplementationFlagsP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2353816);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z66mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetParametersP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2353864);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2175,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if (!($4)) {
     __THREW__ = 0;
     $9 = (invoke_ii(2063,($__this|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     if (!($9)) {
      __THREW__ = 0;
      $12 = (invoke_ii(2066,0)|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3833,($12|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    $17 = (invoke_ii(2054,($__this|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($17|0);
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Reflection_Emit_TypeBuilder_m_get_is_createdP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371512);
 $0 = (($__this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z74mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_IsCompilerContextP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354584);
 __THREW__ = 0;
 $0 = (invoke_ii(2051,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2354632|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2368480|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2759,($5|0),(2368480|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       $15 = (invoke_ii(2230,($10|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2353584|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         $20 = (invoke_iii(2759,($15|0),(2353584|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          invoke_vi(3799,($20|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           $25 = (invoke_ii(2048,($20|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($25|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Reflection_Emit_ConstructorBuilder_m_not_createdP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354728);
 __THREW__ = 0;
 invoke_v(596);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3029800>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($4|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetParametersInternalP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $G_B6_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2353912);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(1183184|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2758,(1183184|0),0)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $$0$in = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0$in|0);
   }
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $14 = (($1) + 12|0);
   $15 = HEAP32[$14>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1183184|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_iii(2758,(1183184|0),($15|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = (($__this) + 28|0);
     $22 = (($18) + 16|0);
     $23 = (($18) + 12|0);
     $V_1$0 = 0;
     while(1) {
      $85 = HEAP32[$0>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($85|0));
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       break;
      }
      $88 = (($85) + 12|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = ($V_1$0|0)<($89|0);
      if (!($90)) {
       $$0$in = $18;
       label = 32;
       break;
      }
      $25 = HEAP32[$21>>2]|0;
      $91 = ($25|0)==(0|0);
      if ($91) {
       $G_B6_0$0 = 0;
      } else {
       $24 = (($V_1$0) + 1)|0;
       __THREW__ = 0;
       invoke_vi(3799,($25|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       $28 = (($25) + 12|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($24>>>0)<($29>>>0);
       if (!($30)) {
        __THREW__ = 0;
        $31 = (invoke_i(132)|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($31|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
       }
       $36 = HEAP32[$25>>2]|0;
       $37 = (($25) + 16|0);
       $38 = (($36) + 92|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = Math_imul($39, $24)|0;
       $41 = (($37) + ($40)|0);
       $42 = HEAP32[$41>>2]|0;
       $G_B6_0$0 = $42;
      }
      $43 = HEAP32[$0>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($43|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break;
      }
      $46 = (($43) + 12|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($V_1$0>>>0)<($47>>>0);
      if (!($48)) {
       __THREW__ = 0;
       $49 = (invoke_i(132)|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($49|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break;
       }
      }
      $54 = HEAP32[$43>>2]|0;
      $55 = (($43) + 16|0);
      $56 = (($54) + 92|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = Math_imul($57, $V_1$0)|0;
      $59 = (($55) + ($58)|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = (($V_1$0) + 1)|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2433064|0))|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
      __THREW__ = 0;
      $64 = (invoke_ii(3469,(2433064|0))|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
      __THREW__ = 0;
      invoke_viiiii(67,($64|0),($G_B6_0$0|0),($60|0),($__this|0),($61|0));
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($18|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       break;
      }
      $71 = HEAP32[$23>>2]|0;
      $72 = ($V_1$0>>>0)<($71>>>0);
      if (!($72)) {
       __THREW__ = 0;
       $73 = (invoke_i(132)|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($73|0));
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($18|0),($64|0));
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       break;
      }
      $80 = HEAP32[$18>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$0)|0;
      $84 = (($22) + ($83)|0);
      HEAP32[$84>>2] = $64;
      $V_1$0 = $61;
     }
     if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0$in|0);
     }
     $8 = ___cxa_find_matching_catch()|0;
     $9 = tempRet0;
     $lpad$phi$index = $8;$lpad$phi$index2 = $9;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z252mscorlib_System_Reflection_Emit_ConstructorBuilder_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP50mscorlib_System_Reflection_Emit_ConstructorBuilderP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo($__this,$obj,$invokeAttr,$binder,$parameters,$culture) {
 $__this = $__this|0;
 $obj = $obj|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $parameters = $parameters|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2353960);
 __THREW__ = 0;
 $0 = (invoke_ii(2065,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Reflection_Emit_ConstructorBuilder_m_not_supportedP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354680);
 __THREW__ = 0;
 invoke_v(597);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3029672>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($4|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z229mscorlib_System_Reflection_Emit_ConstructorBuilder_m_Invoke_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP50mscorlib_System_Reflection_Emit_ConstructorBuilderiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo($__this,$invokeAttr,$binder,$parameters,$culture) {
 $__this = $__this|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $parameters = $parameters|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354008);
 __THREW__ = 0;
 $0 = (invoke_ii(2065,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_MethodHandleP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354056);
 __THREW__ = 0;
 $0 = (invoke_ii(2065,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_AttributesP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354104);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_ReflectedTypeP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354152);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_DeclaringTypeP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354200);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z61mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_NameP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $G_B3_0$0$in$in = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354248);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   __THREW__ = 0;
   (invoke_ii(2996,(2403064|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP8[((2403064 + 116|0))>>0]|0;
    $23 = ($22<<24>>24)==(0);
    if ($23) {
     __THREW__ = 0;
     (invoke_ii(2996,(2403064|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2403064|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2403064|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2403064|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = HEAP32[((2403064 + 80|0))>>2]|0;
     $G_B3_0$0$in$in = $32;
     $G_B3_0$0 = HEAP32[$G_B3_0$0$in$in>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2403064|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = HEAP8[((2403064 + 116|0))>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if ($7) {
     __THREW__ = 0;
     (invoke_ii(2996,(2403064|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2403064|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2403064|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2403064|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[((2403064 + 80|0))>>2]|0;
     $19 = (($18) + 4|0);
     $G_B3_0$0$in$in = $19;
     $G_B3_0$0 = HEAP32[$G_B3_0$0$in$in>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Reflection_Emit_ConstructorBuilder_m_IsDefinedP50mscorlib_System_Reflection_Emit_ConstructorBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354296);
 __THREW__ = 0;
 $0 = (invoke_ii(2065,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z127mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP50mscorlib_System_Reflection_Emit_ConstructorBuilderb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354344);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2175,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if ($4) {
     __THREW__ = 0;
     $9 = (invoke_ii(2063,($__this|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     if ($9) {
      __THREW__ = 0;
      $12 = (invoke_iiii(1202,(0|0),($__this|0),($inherit|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($12|0);
     }
    }
    __THREW__ = 0;
    $15 = (invoke_ii(2065,0)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vi(3833,($15|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z148mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP50mscorlib_System_Reflection_Emit_ConstructorBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354392);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2175,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if ($4) {
     __THREW__ = 0;
     $9 = (invoke_ii(2063,($__this|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     if ($9) {
      __THREW__ = 0;
      $12 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($12|0);
     }
    }
    __THREW__ = 0;
    $15 = (invoke_ii(2065,0)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vi(3833,($15|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_ModuleP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354440);
 __THREW__ = 0;
 $0 = (invoke_ii(1901,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Emit_ConstructorBuilder_m_ToStringP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354488);
 __THREW__ = 0;
 invoke_v(598);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 24|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2730,(2354536|0),($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3029592>>2]|0;
    $10 = HEAP32[3029600>>2]|0;
    __THREW__ = 0;
    $11 = (invoke_iiiii(101,(0|0),($9|0),($6|0),($10|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($11|0);
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker5I28mscorlib_System_ObjectTraitsS0_27mscorlib_System_Int32Traits17VoidPointerTraitsS2_S2_E6InvokeEPFP22mscorlib_System_ObjectPvS5_iS6_S6_S6_ES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$5,$7,$9)|0);
 STACKTOP = sp;return ($10|0);
}
function __ZN12FuncInvoker4I28mscorlib_System_ObjectTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS2_S2_E6InvokeEPFP22mscorlib_System_ObjectPviS6_S6_S6_ES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$1,$3,$5,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker0I41mscorlib_System_RuntimeMethodHandleTraitsE6InvokeEPF35mscorlib_System_RuntimeMethodHandlePvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = (FUNCTION_TABLE_ii[$func & 4095]($obj)|0);
 HEAP32[$ret>>2] = $0;
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2637784,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS0_E6InvokeEPFbPvS3_bES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$4)|0);
 $6 = $5&1;
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z81mscorlib_System_Reflection_Emit_ConstructorBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2450328)|0);
 $5 = HEAP32[((2450328 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($8,0);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z169mscorlib_System_Reflection_Emit_ConstructorBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_ConstructorBuilderTraits_CallingConvention_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Reflection_Emit_EnumBuilder_m_get_AssemblyP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356016);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356064|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Reflection_Emit_EnumBuilder_m_get_AssemblyQualifiedNameP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356112);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356160|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Reflection_Emit_EnumBuilder_m_get_BaseTypeP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356208);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356256|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Reflection_Emit_EnumBuilder_m_get_DeclaringTypeP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356304);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356352|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Reflection_Emit_EnumBuilder_m_get_FullNameP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356400);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356448|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Reflection_Emit_EnumBuilder_m_get_ModuleP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356496);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2354632|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_Emit_EnumBuilder_m_get_NameP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356544);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2354536|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_get_NamespaceP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356592);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356640|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Reflection_Emit_EnumBuilder_m_get_ReflectedTypeP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356688);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356736|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Reflection_Emit_EnumBuilder_m_get_TypeHandleP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356784);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2757,(2356832|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Reflection_Emit_EnumBuilder_m_get_UnderlyingSystemTypeP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356880);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67mscorlib_System_Reflection_Emit_EnumBuilder_m_GetAttributeFlagsImplP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356928);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($1) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z64mscorlib_System_Reflection_Emit_EnumBuilder_m_GetConstructorImplP43mscorlib_System_Reflection_Emit_EnumBuilderiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356976);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiiiiii(118,(2236960|0),($1|0),($bindingAttr|0),($binder|0),($callConvention|0),($types|0),($modifiers|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Emit_EnumBuilder_m_GetConstructorsP43mscorlib_System_Reflection_Emit_EnumBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357024);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1642,(2357072|0),($1|0),($bindingAttr|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Reflection_Emit_EnumBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP43mscorlib_System_Reflection_Emit_EnumBuilderb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357120);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1668,(2357168|0),($1|0),($inherit|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z141mscorlib_System_Reflection_Emit_EnumBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP43mscorlib_System_Reflection_Emit_EnumBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357216);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiii(322,(2357264|0),($1|0),($attributeType|0),($inherit|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvS5_b($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z60mscorlib_System_Reflection_Emit_EnumBuilder_m_GetElementTypeP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357312);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2357360|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_Emit_EnumBuilder_m_GetFieldP43mscorlib_System_Reflection_Emit_EnumBuilderP22mscorlib_System_Stringi($__this,$name,$bindingAttr) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357408);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiii(323,(2357456|0),($1|0),($name|0),($bindingAttr|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS5_i($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z55mscorlib_System_Reflection_Emit_EnumBuilder_m_GetFieldsP43mscorlib_System_Reflection_Emit_EnumBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357504);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1642,(2357552|0),($1|0),($bindingAttr|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_GetInterfacesP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357600);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2357648|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_GetMethodImplP43mscorlib_System_Reflection_Emit_EnumBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357696);
 $0 = ($types|0)==(0|0);
 $1 = (($__this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 if ($0) {
  __THREW__ = 0;
  invoke_vi(3799,($2|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiiii(323,(2236384|0),($2|0),($name|0),($bindingAttr|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $$0$in = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0$in|0);
   }
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($2|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_iiiiiiiii(46,(2236480|0),($2|0),($name|0),($bindingAttr|0),($binder|0),($callConvention|0),($types|0),($modifiers|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $$0$in = $12;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0$in|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Reflection_Emit_EnumBuilder_m_GetMethodsP43mscorlib_System_Reflection_Emit_EnumBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357744);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1642,(2357792|0),($1|0),($bindingAttr|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_GetPropertiesP43mscorlib_System_Reflection_Emit_EnumBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357840);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1642,(2357888|0),($1|0),($bindingAttr|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Emit_EnumBuilder_m_GetPropertyImplP43mscorlib_System_Reflection_Emit_EnumBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$returnType,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $returnType = $returnType|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357936);
 __THREW__ = 0;
 $0 = (invoke_ii(2097,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Reflection_Emit_EnumBuilder_m_CreateNotSupportedExceptionP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358464);
 __THREW__ = 0;
 invoke_v(599);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3029872>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($4|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Reflection_Emit_EnumBuilder_m_HasElementTypeImplP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357984);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2734,(2233800|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Reflection_Emit_EnumBuilder_m_InvokeMemberP43mscorlib_System_Reflection_Emit_EnumBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP22mscorlib_System_ObjectP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arr($__this,$name,$invokeAttr,$binder,$target,$args,$modifiers,$culture,$namedParameters) {
 $__this = $__this|0;
 $name = $name|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $target = $target|0;
 $args = $args|0;
 $modifiers = $modifiers|0;
 $culture = $culture|0;
 $namedParameters = $namedParameters|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358032);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiiiiiiiii(6,(2358080|0),($1|0),($name|0),($invokeAttr|0),($binder|0),($target|0),($args|0),($modifiers|0),($culture|0),($namedParameters|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker8I28mscorlib_System_ObjectTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_S1_S1_S1_E6InvokeEP10MethodInfoPvS6_iS6_P22mscorlib_System_ObjectS6_S6_S6_S6_($method,$obj,$p1,$p2,$p3,$p4,$p5,$p6,$p7,$p8) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 $p6 = $p6|0;
 $p7 = $p7|0;
 $p8 = $p8|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiiiiii[$3 & 15]($4,$p1,$p2,$p3,$p4,$p5,$p6,$p7,$p8)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z57mscorlib_System_Reflection_Emit_EnumBuilder_m_IsArrayImplP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358128);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z57mscorlib_System_Reflection_Emit_EnumBuilder_m_IsByRefImplP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358176);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_IsPointerImplP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358224);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z61mscorlib_System_Reflection_Emit_EnumBuilder_m_IsPrimitiveImplP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358272);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z61mscorlib_System_Reflection_Emit_EnumBuilder_m_IsValueTypeImplP43mscorlib_System_Reflection_Emit_EnumBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358320);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z55mscorlib_System_Reflection_Emit_EnumBuilder_m_IsDefinedP43mscorlib_System_Reflection_Emit_EnumBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358368);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiii(315,(2358416|0),($1|0),($attributeType|0),($inherit|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker8I28mscorlib_System_ObjectTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_S1_S1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvS6_iS6_S5_S6_S6_S6_S6_ES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_iiiiiiiiii[$func & 15]($obj,$0,$3,$5,$7,$9,$11,$13,$15)|0);
 STACKTOP = sp;return ($16|0);
}
function __Z74mscorlib_System_Reflection_Emit_EnumBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2450768)|0);
 $7 = HEAP32[((2450768 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Reflection_Emit_EnumBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_EnumBuilder_m_GetConstructorsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z61mscorlib_System_Reflection_Emit_FieldBuilder_m_get_AttributesP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360288);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z64mscorlib_System_Reflection_Emit_FieldBuilder_m_get_DeclaringTypeP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360336);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z60mscorlib_System_Reflection_Emit_FieldBuilder_m_get_FieldTypeP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360384);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z55mscorlib_System_Reflection_Emit_FieldBuilder_m_get_NameP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360432);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z64mscorlib_System_Reflection_Emit_FieldBuilder_m_get_ReflectedTypeP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360480);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z121mscorlib_System_Reflection_Emit_FieldBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP44mscorlib_System_Reflection_Emit_FieldBuilderb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360528);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2175,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if ($4) {
     __THREW__ = 0;
     $9 = (invoke_iiii(1202,(0|0),($__this|0),($inherit|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($9|0);
    }
    __THREW__ = 0;
    $12 = (invoke_ii(2105,0)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3833,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Reflection_Emit_FieldBuilder_m_CreateNotSupportedExceptionP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360864);
 __THREW__ = 0;
 invoke_v(600);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3029888>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($4|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z142mscorlib_System_Reflection_Emit_FieldBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP44mscorlib_System_Reflection_Emit_FieldBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360576);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2175,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if ($4) {
     __THREW__ = 0;
     $9 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($9|0);
    }
    __THREW__ = 0;
    $12 = (invoke_ii(2105,0)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3833,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Reflection_Emit_FieldBuilder_m_GetValueP44mscorlib_System_Reflection_Emit_FieldBuilderP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360624);
 __THREW__ = 0;
 $0 = (invoke_ii(2105,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Reflection_Emit_FieldBuilder_m_IsDefinedP44mscorlib_System_Reflection_Emit_FieldBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360672);
 __THREW__ = 0;
 $0 = (invoke_ii(2105,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Emit_FieldBuilder_m_GetFieldOffsetP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360720);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z55mscorlib_System_Reflection_Emit_FieldBuilder_m_SetValueP44mscorlib_System_Reflection_Emit_FieldBuilderP22mscorlib_System_ObjectS2_iP33mscorlib_System_Reflection_BinderP41mscorlib_System_Globalization_CultureInfo($__this,$obj,$val,$invokeAttr,$binder,$culture) {
 $__this = $__this|0;
 $obj = $obj|0;
 $val = $val|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360768);
 __THREW__ = 0;
 $0 = (invoke_ii(2105,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z59mscorlib_System_Reflection_Emit_FieldBuilder_m_get_UMarshalP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360816);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z57mscorlib_System_Reflection_Emit_FieldBuilder_m_get_ModuleP44mscorlib_System_Reflection_Emit_FieldBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2360912);
 __THREW__ = 0;
 $0 = (invoke_ii(1901,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker5I28mscorlib_System_ObjectTraitsS0_27mscorlib_System_Int32Traits17VoidPointerTraitsS2_E6InvokeEPFvPvP22mscorlib_System_ObjectS6_iS4_S4_ES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$2,$5,$7,$9);
 STACKTOP = sp;return (0|0);
}
function __Z75mscorlib_System_Reflection_Emit_FieldBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2451200)|0);
 $7 = HEAP32[((2451200 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsSubclassOfP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP20mscorlib_System_Type($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2361776);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2730,(2354632|0),($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2368480|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_iii(2759,($4|0),(2368480|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      invoke_vi(3799,($9|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       $14 = (($9) + 36|0);
       $15 = HEAP32[$14>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($15|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        $18 = (invoke_ii(2048,($15|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         if (!($18)) {
          __THREW__ = 0;
          $23 = (invoke_ii(2134,0)|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if ($25) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3833,($23|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if ($27) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         $28 = (invoke_iii(2730,(2361824|0),($__this|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          $31 = ($28|0)==(0|0);
          if ($31) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $32 = (invoke_iii(2730,(2361824|0),($__this|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           $35 = ($32|0)==($c|0);
           if ($35) {
            $$0 = 1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           $36 = (invoke_iii(2730,(2361824|0),($__this|0))|0);
           $37 = __THREW__; __THREW__ = 0;
           $38 = $37&1;
           if (!($38)) {
            __THREW__ = 0;
            invoke_vi(3799,($36|0));
            $39 = __THREW__; __THREW__ = 0;
            $40 = $39&1;
            if (!($40)) {
             __THREW__ = 0;
             $41 = (invoke_iiii(1640,(2234376|0),($36|0),($c|0))|0);
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if (!($43)) {
              $$0 = $41;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_not_supportedP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363792);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetAttributeFlagsImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2361872);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2354632|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2368480|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2759,($4|0),(2368480|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3799,($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($9) + 36|0);
      $15 = HEAP32[$14>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($15|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_ii(2048,($15|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        if ($18) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return 1;
        }
        __THREW__ = 0;
        $23 = (invoke_ii(2134,0)|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         invoke_vi(3833,($23|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetConstructorImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2361920);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetConstructorsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2361968);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetFieldP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_Stringi($__this,$name,$bindingAttr) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362016);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetFieldsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362064);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetInterfacesP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362112);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z72mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetMethodsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362160);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetMethodImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362208);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetPropertiesP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362256);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetPropertyImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$returnType,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $returnType = $returnType|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362304);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_HasElementTypeImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362352);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z78mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsAssignableFromP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP20mscorlib_System_Type($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362400);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsInstanceOfTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362448);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsArrayImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362496);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z73mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsByRefImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362544);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsPointerImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362592);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsPrimitiveImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362640);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsValueTypeImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362688);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2734,(2234232|0),($1|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $G_B3_0$0 = $5;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B3_0$0|0);
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_InvokeMemberP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP22mscorlib_System_ObjectP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arr($__this,$name,$invokeAttr,$binder,$target,$args,$modifiers,$culture,$namedParameters) {
 $__this = $__this|0;
 $name = $name|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $target = $target|0;
 $args = $args|0;
 $modifiers = $modifiers|0;
 $culture = $culture|0;
 $namedParameters = $namedParameters|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362736);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetElementTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362784);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_UnderlyingSystemTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362832);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_AssemblyP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362880);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356064|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_AssemblyQualifiedNameP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362928);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_BaseTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2361824);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_FullNameP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2362976);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z71mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsDefinedP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363024);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z136mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363072);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z157mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363120);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_NameP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363168);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_NamespaceP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363216);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z72mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_ModuleP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363264);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2354632|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_DeclaringTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363312);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $10 = (($__this) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $G_B3_0$0 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2730,(2363360|0),($1|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $G_B3_0$0 = $5;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B3_0$0|0);
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_ReflectedTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363408);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2363312|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z76mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_TypeHandleP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363456);
 __THREW__ = 0;
 $0 = (invoke_ii(2134,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetGenericArgumentsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363504);
 __THREW__ = 0;
 (invoke_ii(2996,(2607872|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607872|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2734,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3833,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetGenericTypeDefinitionP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363552);
 __THREW__ = 0;
 (invoke_ii(2996,(2607872|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607872|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2734,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3833,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_ContainsGenericParametersP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363600);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z84mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_IsGenericParameterP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363648);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z79mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_IsGenericTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363696);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z89mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_IsGenericTypeDefinitionP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363744);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z70mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_ToStringP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363840);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_EqualsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363888);
 __THREW__ = 0;
 $0 = (invoke_iii(766,($__this|0),($o|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z73mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetHashCodeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363936);
 __THREW__ = 0;
 $0 = (invoke_ii(1890,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_MakeGenericTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP24mscorlib_System_Type_arr($__this,$typeArguments) {
 $__this = $__this|0;
 $typeArguments = $typeArguments|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363984);
 __THREW__ = 0;
 $0 = (invoke_iii(778,($__this|0),($typeArguments|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z90mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z165mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsSubclassOfP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z168mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetConstructorsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z159mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_EqualsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z164mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetHashCodeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z168mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_MakeGenericTypeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z77mscorlib_System_Reflection_Emit_MethodBuilder_m_get_ContainsGenericParametersP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2365872);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3833,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Reflection_Emit_MethodBuilder_m_get_MethodHandleP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2365920);
 __THREW__ = 0;
 $0 = (invoke_ii(2149,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Reflection_Emit_MethodBuilder_m_NotSupportedP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366688);
 __THREW__ = 0;
 invoke_v(601);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3029976>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($4|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Reflection_Emit_MethodBuilder_m_get_ReturnTypeP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2365968);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65mscorlib_System_Reflection_Emit_MethodBuilder_m_get_ReflectedTypeP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366016);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65mscorlib_System_Reflection_Emit_MethodBuilder_m_get_DeclaringTypeP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2363360);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z56mscorlib_System_Reflection_Emit_MethodBuilder_m_get_NameP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366064);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z62mscorlib_System_Reflection_Emit_MethodBuilder_m_get_AttributesP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366112);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z69mscorlib_System_Reflection_Emit_MethodBuilder_m_get_CallingConventionP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366160);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65mscorlib_System_Reflection_Emit_MethodBuilder_m_GetBaseDefinitionP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366208);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z76mscorlib_System_Reflection_Emit_MethodBuilder_m_GetMethodImplementationFlagsP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366256);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z61mscorlib_System_Reflection_Emit_MethodBuilder_m_GetParametersP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $G_B8_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366304);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2175,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if (!($4)) {
     __THREW__ = 0;
     $11 = (invoke_ii(2149,0)|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($11|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     // unreachable;
    }
    $16 = (($__this) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($17|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = (($17) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1183184|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      $25 = (invoke_iii(2758,(1183184|0),($22|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       $28 = (($__this) + 32|0);
       $29 = (($25) + 16|0);
       $30 = (($25) + 12|0);
       $V_1$0 = 0;
       while(1) {
        $92 = HEAP32[$16>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($92|0));
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         break;
        }
        $95 = (($92) + 12|0);
        $96 = HEAP32[$95>>2]|0;
        $97 = ($V_1$0|0)<($96|0);
        if (!($97)) {
         $$0 = $25;
         label = 36;
         break;
        }
        $32 = HEAP32[$28>>2]|0;
        $98 = ($32|0)==(0|0);
        if ($98) {
         $G_B8_0$0 = 0;
        } else {
         $31 = (($V_1$0) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($32|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         $35 = (($32) + 12|0);
         $36 = HEAP32[$35>>2]|0;
         $37 = ($31>>>0)<($36>>>0);
         if (!($37)) {
          __THREW__ = 0;
          $38 = (invoke_i(132)|0);
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($38|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           break;
          }
         }
         $43 = HEAP32[$32>>2]|0;
         $44 = (($32) + 16|0);
         $45 = (($43) + 92|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = Math_imul($46, $31)|0;
         $48 = (($44) + ($47)|0);
         $49 = HEAP32[$48>>2]|0;
         $G_B8_0$0 = $49;
        }
        $50 = HEAP32[$16>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($50|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
        $53 = (($50) + 12|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = ($V_1$0>>>0)<($54>>>0);
        if (!($55)) {
         __THREW__ = 0;
         $56 = (invoke_i(132)|0);
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($56|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break;
         }
        }
        $61 = HEAP32[$50>>2]|0;
        $62 = (($50) + 16|0);
        $63 = (($61) + 92|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = Math_imul($64, $V_1$0)|0;
        $66 = (($62) + ($65)|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = (($V_1$0) + 1)|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2433064|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
        __THREW__ = 0;
        $71 = (invoke_ii(3469,(2433064|0))|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         break;
        }
        __THREW__ = 0;
        invoke_viiiii(67,($71|0),($G_B8_0$0|0),($67|0),($__this|0),($68|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($25|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         break;
        }
        $78 = HEAP32[$30>>2]|0;
        $79 = ($V_1$0>>>0)<($78>>>0);
        if (!($79)) {
         __THREW__ = 0;
         $80 = (invoke_i(132)|0);
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($80|0));
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($25|0),($71|0));
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         break;
        }
        $87 = HEAP32[$25>>2]|0;
        $88 = (($87) + 92|0);
        $89 = HEAP32[$88>>2]|0;
        $90 = Math_imul($89, $V_1$0)|0;
        $91 = (($29) + ($90)|0);
        HEAP32[$91>>2] = $71;
        $V_1$0 = $68;
       }
       if ((label|0) == 36) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $7 = ___cxa_find_matching_catch()|0;
       $8 = tempRet0;
       $lpad$phi$index = $7;$lpad$phi$index2 = $8;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_Emit_MethodBuilder_m_InvokeP45mscorlib_System_Reflection_Emit_MethodBuilderP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo($__this,$obj,$invokeAttr,$binder,$parameters,$culture) {
 $__this = $__this|0;
 $obj = $obj|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $parameters = $parameters|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366352);
 __THREW__ = 0;
 $0 = (invoke_ii(2149,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_Reflection_Emit_MethodBuilder_m_IsDefinedP45mscorlib_System_Reflection_Emit_MethodBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366400);
 __THREW__ = 0;
 $0 = (invoke_ii(2149,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z122mscorlib_System_Reflection_Emit_MethodBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP45mscorlib_System_Reflection_Emit_MethodBuilderb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366448);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2175,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if ($4) {
     __THREW__ = 0;
     $9 = (invoke_iiii(1202,(0|0),($__this|0),($inherit|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($9|0);
    }
    __THREW__ = 0;
    $12 = (invoke_ii(2149,0)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3833,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z143mscorlib_System_Reflection_Emit_MethodBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP45mscorlib_System_Reflection_Emit_MethodBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366496);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2175,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if ($4) {
     __THREW__ = 0;
     $9 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($9|0);
    }
    __THREW__ = 0;
    $12 = (invoke_ii(2149,0)|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3833,($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Reflection_Emit_MethodBuilder_m_ToStringP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366544);
 __THREW__ = 0;
 invoke_v(602);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1168432|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2758,(1168432|0),5)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($4) + 12|0);
      $10 = HEAP32[$9>>2]|0;
      $11 = ($10|0)==(0);
      if ($11) {
       __THREW__ = 0;
       $12 = (invoke_i(132)|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      $19 = HEAP32[3029904>>2]|0;
      __THREW__ = 0;
      invoke_vii(3492,($4|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[3029904>>2]|0;
       $23 = (($4) + 16|0);
       HEAP32[$23>>2] = $22;
       $24 = (($__this) + 28|0);
       $25 = HEAP32[$24>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($25|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __THREW__ = 0;
        $28 = (invoke_iii(2730,(2354536|0),($25|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          $33 = HEAP32[$9>>2]|0;
          $34 = ($33>>>0)<(2);
          if ($34) {
           __THREW__ = 0;
           $35 = (invoke_i(132)|0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($35|0));
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if ($39) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($4|0),($28|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if (!($41)) {
           $42 = HEAP32[$4>>2]|0;
           $43 = (($42) + 92|0);
           $44 = HEAP32[$43>>2]|0;
           $45 = (($23) + ($44)|0);
           HEAP32[$45>>2] = $28;
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            $48 = HEAP32[$9>>2]|0;
            $49 = ($48>>>0)<(3);
            if ($49) {
             __THREW__ = 0;
             $50 = (invoke_i(132)|0);
             $51 = __THREW__; __THREW__ = 0;
             $52 = $51&1;
             if ($52) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($50|0));
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if ($54) {
              break;
             }
            }
            $55 = HEAP32[3029912>>2]|0;
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($55|0));
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if (!($57)) {
             $58 = HEAP32[3029912>>2]|0;
             $59 = HEAP32[$4>>2]|0;
             $60 = (($59) + 92|0);
             $61 = HEAP32[$60>>2]|0;
             $62 = $61 << 1;
             $63 = (($23) + ($62)|0);
             HEAP32[$63>>2] = $58;
             $64 = (($__this) + 24|0);
             $65 = HEAP32[$64>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if (!($67)) {
              $68 = HEAP32[$9>>2]|0;
              $69 = ($68>>>0)<(4);
              if ($69) {
               __THREW__ = 0;
               $70 = (invoke_i(132)|0);
               $71 = __THREW__; __THREW__ = 0;
               $72 = $71&1;
               if ($72) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($70|0));
               $73 = __THREW__; __THREW__ = 0;
               $74 = $73&1;
               if ($74) {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vii(3492,($4|0),($65|0));
              $75 = __THREW__; __THREW__ = 0;
              $76 = $75&1;
              if (!($76)) {
               $77 = HEAP32[$4>>2]|0;
               $78 = (($77) + 92|0);
               $79 = HEAP32[$78>>2]|0;
               $80 = ($79*3)|0;
               $81 = (($23) + ($80)|0);
               HEAP32[$81>>2] = $65;
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $82 = __THREW__; __THREW__ = 0;
               $83 = $82&1;
               if (!($83)) {
                $84 = HEAP32[$9>>2]|0;
                $85 = ($84>>>0)<(5);
                if ($85) {
                 __THREW__ = 0;
                 $86 = (invoke_i(132)|0);
                 $87 = __THREW__; __THREW__ = 0;
                 $88 = $87&1;
                 if ($88) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($86|0));
                 $89 = __THREW__; __THREW__ = 0;
                 $90 = $89&1;
                 if ($90) {
                  break;
                 }
                }
                $91 = HEAP32[3029920>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($91|0));
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 break;
                }
                $94 = HEAP32[3029920>>2]|0;
                $95 = HEAP32[$4>>2]|0;
                $96 = (($95) + 92|0);
                $97 = HEAP32[$96>>2]|0;
                $98 = $97 << 2;
                $99 = (($23) + ($98)|0);
                HEAP32[$99>>2] = $94;
                __THREW__ = 0;
                $100 = (invoke_iii(639,(0|0),($4|0))|0);
                $101 = __THREW__; __THREW__ = 0;
                $102 = $101&1;
                if ($102) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($100|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_Emit_MethodBuilder_m_EqualsP45mscorlib_System_Reflection_Emit_MethodBuilderP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366592);
 __THREW__ = 0;
 $0 = (invoke_iii(456,($__this|0),($obj|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_MethodBuilder_m_GetHashCodeP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366640);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(2185544|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Reflection_Emit_MethodBuilder_m_MakeGenericMethodP45mscorlib_System_Reflection_Emit_MethodBuilderP24mscorlib_System_Type_arr($__this,$typeArguments) {
 $__this = $__this|0;
 $typeArguments = $typeArguments|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366736);
 $0 = HEAP32[2366784>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2366792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2366784>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($typeArguments|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Reflection_Emit_MethodBuilder_m_get_IsGenericMethodDefinitionP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366864);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z67mscorlib_System_Reflection_Emit_MethodBuilder_m_get_IsGenericMethodP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366912);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z67mscorlib_System_Reflection_Emit_MethodBuilder_m_GetGenericArgumentsP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2366960);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   (invoke_ii(2996,(2242320|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2242320 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2242320|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2242320|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[((2242320 + 80|0))>>2]|0;
     $20 = (($19) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     $$0 = $21;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($1|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = (($1) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(1169184|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __THREW__ = 0;
     $28 = (invoke_iii(2758,(1169184|0),($25|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      $31 = (($28) + 16|0);
      $32 = (($28) + 12|0);
      $V_1$0 = 0;
      while(1) {
       $66 = HEAP32[$0>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($66|0));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        break;
       }
       $69 = (($66) + 12|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = ($V_1$0|0)<($70|0);
       if (!($71)) {
        $$0 = $28;
        label = 28;
        break;
       }
       $34 = HEAP32[$0>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($34|0));
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $33 = (($34) + 12|0);
       $35 = HEAP32[$33>>2]|0;
       $36 = ($V_1$0>>>0)<($35>>>0);
       if (!($36)) {
        __THREW__ = 0;
        $37 = (invoke_i(132)|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($37|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
       }
       $42 = HEAP32[$34>>2]|0;
       $43 = (($34) + 16|0);
       $44 = (($42) + 92|0);
       $45 = HEAP32[$44>>2]|0;
       $46 = Math_imul($45, $V_1$0)|0;
       $47 = (($43) + ($46)|0);
       $48 = HEAP32[$47>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($28|0));
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
       $51 = HEAP32[$32>>2]|0;
       $52 = ($V_1$0>>>0)<($51>>>0);
       if (!($52)) {
        __THREW__ = 0;
        $53 = (invoke_i(132)|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($53|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($28|0),($48|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
       $60 = HEAP32[$28>>2]|0;
       $61 = (($60) + 92|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = Math_imul($62, $V_1$0)|0;
       $64 = (($31) + ($63)|0);
       HEAP32[$64>>2] = $48;
       $65 = (($V_1$0) + 1)|0;
       $V_1$0 = $65;
      }
      if ((label|0) == 28) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $13 = ___cxa_find_matching_catch()|0;
      $14 = tempRet0;
      $lpad$phi$index = $13;$lpad$phi$index2 = $14;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index2 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Reflection_Emit_MethodBuilder_m_get_ModuleP45mscorlib_System_Reflection_Emit_MethodBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2367008);
 __THREW__ = 0;
 $0 = (invoke_ii(1901,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z76mscorlib_System_Reflection_Emit_MethodBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2451848)|0);
 $5 = HEAP32[((2451848 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($8,1);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Reflection_Emit_MethodBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_MethodBuilder_m_EqualsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_Reflection_Emit_ModuleBuilder_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2368192);
 __THREW__ = 0;
 (invoke_ii(2996,(1168808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2758,(1168808|0),3)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     HEAP16[$17>>1] = 38;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[$7>>2]|0;
      $21 = ($20>>>0)<(2);
      if ($21) {
       __THREW__ = 0;
       $22 = (invoke_i(132)|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
      }
      $27 = HEAP32[$2>>2]|0;
      $28 = (($27) + 92|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($17) + ($29)|0);
      HEAP16[$30>>1] = 91;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $33 = HEAP32[$7>>2]|0;
       $34 = ($33>>>0)<(3);
       if ($34) {
        __THREW__ = 0;
        $35 = (invoke_i(132)|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($35|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
       }
       $40 = HEAP32[$2>>2]|0;
       $41 = (($40) + 92|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = $42 << 1;
       $44 = (($17) + ($43)|0);
       HEAP16[$44>>1] = 42;
       __THREW__ = 0;
       (invoke_ii(2996,(2368480|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        $47 = HEAP32[((2368480 + 80|0))>>2]|0;
        HEAP32[$47>>2] = $2;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z76mscorlib_System_Reflection_Emit_ModuleBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2452488)|0);
 $10 = HEAP32[((2452488 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 STACKTOP = sp;return;
}
function __Z65mscorlib_System_Reflection_Emit_ParameterBuilder_m_get_AttributesP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2368616);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z59mscorlib_System_Reflection_Emit_ParameterBuilder_m_get_NameP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2368664);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z63mscorlib_System_Reflection_Emit_ParameterBuilder_m_get_PositionP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2368712);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z79mscorlib_System_Reflection_Emit_ParameterBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2452712)|0);
 $5 = HEAP32[((2452712 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($8,1);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_AttributesP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369144);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_DeclaringTypeP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369192);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z58mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_NameP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369240);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z66mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_PropertyTypeP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369288);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_ReflectedTypeP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369336);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z124mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP47mscorlib_System_Reflection_Emit_PropertyBuilderb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369384);
 __THREW__ = 0;
 $0 = (invoke_ii(2164,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Reflection_Emit_PropertyBuilder_m_not_supportedP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369816);
 __THREW__ = 0;
 invoke_v(603);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3029992>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($4|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z145mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP47mscorlib_System_Reflection_Emit_PropertyBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369432);
 __THREW__ = 0;
 $0 = (invoke_ii(2164,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetGetMethodP47mscorlib_System_Reflection_Emit_PropertyBuilderb($__this,$nonPublic) {
 $__this = $__this|0;
 $nonPublic = $nonPublic|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369480);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetIndexParametersP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369528);
 __THREW__ = 0;
 $0 = (invoke_ii(2164,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetSetMethodP47mscorlib_System_Reflection_Emit_PropertyBuilderb($__this,$nonPublic) {
 $__this = $__this|0;
 $nonPublic = $nonPublic|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369576);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z135mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP47mscorlib_System_Reflection_Emit_PropertyBuilderP22mscorlib_System_ObjectP26mscorlib_System_Object_arr($__this,$obj,$index) {
 $__this = $__this|0;
 $obj = $obj|0;
 $index = $index|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369624);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z251mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP47mscorlib_System_Reflection_Emit_PropertyBuilderP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo($__this,$obj,$invokeAttr,$binder,$index,$culture) {
 $__this = $__this|0;
 $obj = $obj|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $index = $index|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369672);
 __THREW__ = 0;
 $0 = (invoke_ii(2164,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_PropertyBuilder_m_IsDefinedP47mscorlib_System_Reflection_Emit_PropertyBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369720);
 __THREW__ = 0;
 $0 = (invoke_ii(2164,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_ModuleP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2369768);
 __THREW__ = 0;
 $0 = (invoke_ii(1901,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker2I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsE6InvokeEPFP22mscorlib_System_ObjectPvS4_S5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z78mscorlib_System_Reflection_Emit_PropertyBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2453152)|0);
 $7 = HEAP32[((2453152 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_Reflection_Emit_TypeBuilder_m_GetAttributeFlagsImplP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2370744);
 $0 = (($__this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_get_AssemblyP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356064);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_ii(2230,($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Reflection_Emit_TypeBuilder_m_get_AssemblyQualifiedNameP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356160);
 __THREW__ = 0;
 invoke_v(604);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 64|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2356064|0),($__this|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_vi(3799,($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2730,(2370792|0),($4|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[3030008>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiiii(101,(0|0),($3|0),($12|0),($9|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($13|0);
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_get_BaseTypeP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356256);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z63mscorlib_System_Reflection_Emit_TypeBuilder_m_get_DeclaringTypeP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356352);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Reflection_Emit_TypeBuilder_m_get_UnderlyingSystemTypeP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2370840);
 __THREW__ = 0;
 invoke_v(605);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(2175,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if ($2) {
     $7 = (($__this) + 60|0);
     $8 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2730,(2223352|0),($8|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $$0 = $11;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $14 = (invoke_iii(2734,(2215792|0),($__this|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     if ($14) {
      __THREW__ = 0;
      $17 = (invoke_ii(2174,($__this|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      if (!($17)) {
       $20 = (($__this) + 68|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = ($21|0)==(0|0);
       if (!($22)) {
        $$0 = $21;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2607872|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       $25 = (invoke_ii(3469,(2607872|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       $28 = HEAP32[3030024>>2]|0;
       __THREW__ = 0;
       invoke_vii(1947,($25|0),($28|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3833,($25|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
       // unreachable;
      }
     }
     $$0 = $__this;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Reflection_Emit_TypeBuilder_m_get_IsCompilerContextP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371464);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($1) + 36|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_ii(2048,($5|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($8|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_get_FullNameP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356448);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z56mscorlib_System_Reflection_Emit_TypeBuilder_m_get_ModuleP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354632);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z54mscorlib_System_Reflection_Emit_TypeBuilder_m_get_NameP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2354536);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_get_NamespaceP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356640);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z63mscorlib_System_Reflection_Emit_TypeBuilder_m_get_ReflectedTypeP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356736);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z64mscorlib_System_Reflection_Emit_TypeBuilder_m_GetConstructorImplP43mscorlib_System_Reflection_Emit_TypeBuilderiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_1$2 = 0, $V_1$3 = 0, $V_4$0 = 0, $V_8$0 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2370888);
 __THREW__ = 0;
 invoke_vi(2253,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = (($__this) + 60|0);
   $4 = HEAP32[$3>>2]|0;
   HEAP32[$0>>2] = 1284448;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $5 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = ($4|0)==($5|0);
    if (!($8)) {
     $142 = HEAP32[$3>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($142|0));
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if ($144) {
      break;
     }
     __THREW__ = 0;
     $145 = (invoke_iiiiiiii(118,(2236960|0),($142|0),($bindingAttr|0),($binder|0),($callConvention|0),($types|0),($modifiers|0))|0);
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      break;
     }
     $$0 = $145;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $15 = (($__this) + 36|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $18 = (($16) + 12|0);
    $19 = (($16) + 16|0);
    $20 = ($callConvention|0)==(3);
    $V_0$1 = 0;$V_1$1 = 0;$V_4$0 = 0;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($16|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      label = 5;
      break;
     }
     $44 = HEAP32[$18>>2]|0;
     $45 = ($V_4$0|0)<($44|0);
     if (!($45)) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($16|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 5;
      break;
     }
     $21 = HEAP32[$18>>2]|0;
     $22 = ($V_4$0>>>0)<($21>>>0);
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_i(132)|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($23|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 5;
       break;
      }
     }
     $28 = HEAP32[$16>>2]|0;
     $29 = (($28) + 92|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = Math_imul($30, $V_4$0)|0;
     $32 = (($19) + ($31)|0);
     $33 = HEAP32[$32>>2]|0;
     if ($20) {
      label = 17;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2729,(2353720|0),($33|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 5;
       break;
      }
      $39 = ($36|0)==($callConvention|0);
      if ($39) {
       label = 17;
      } else {
       $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
      }
     }
     if ((label|0) == 17) {
      label = 0;
      $40 = (($V_1$1) + 1)|0;
      $V_0$0 = $33;$V_1$0 = $40;
     }
     $41 = (($V_4$0) + 1)|0;
     $V_0$1 = $V_0$0;$V_1$1 = $V_1$0;$V_4$0 = $41;
    }
    if ((label|0) == 5) {
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index3 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    $48 = ($V_1$1|0)==(0);
    if ($48) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $49 = ($types|0)==(0|0);
    if ($49) {
     $50 = ($V_1$1|0)<(2);
     if ($50) {
      $$0 = $V_0$1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2375288|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     $53 = (invoke_ii(3469,(2375288|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2261,($53|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($53|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1238976|0))|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if (!($61)) {
     __THREW__ = 0;
     $62 = (invoke_iii(2758,(1238976|0),($V_1$1|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if (!($64)) {
      $65 = ($V_1$1|0)==(1);
      L49: do {
       if ($65) {
        __THREW__ = 0;
        invoke_vi(3799,($62|0));
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break L1;
        }
        $68 = (($62) + 12|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = ($69|0)==(0);
        if ($70) {
         __THREW__ = 0;
         $71 = (invoke_i(132)|0);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($71|0));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($62|0),($V_0$1|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         break L1;
        }
        $78 = (($62) + 16|0);
        HEAP32[$78>>2] = $V_0$1;
       } else {
        $79 = HEAP32[$15>>2]|0;
        $80 = (($79) + 12|0);
        $81 = (($79) + 16|0);
        $82 = (($62) + 16|0);
        $83 = (($62) + 12|0);
        $V_1$3 = 0;$V_8$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($79|0));
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          break;
         }
         $124 = HEAP32[$80>>2]|0;
         $125 = ($V_8$0|0)<($124|0);
         if (!($125)) {
          break L49;
         }
         __THREW__ = 0;
         invoke_vi(3799,($79|0));
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if ($127) {
          break;
         }
         $84 = HEAP32[$80>>2]|0;
         $85 = ($V_8$0>>>0)<($84>>>0);
         if (!($85)) {
          __THREW__ = 0;
          $86 = (invoke_i(132)|0);
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($86|0));
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           break;
          }
         }
         $91 = HEAP32[$79>>2]|0;
         $92 = (($91) + 92|0);
         $93 = HEAP32[$92>>2]|0;
         $94 = Math_imul($93, $V_8$0)|0;
         $95 = (($81) + ($94)|0);
         $96 = HEAP32[$95>>2]|0;
         if ($20) {
          label = 48;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($96|0));
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           break;
          }
          __THREW__ = 0;
          $99 = (invoke_iii(2729,(2397712|0),($96|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          $102 = ($99|0)==($callConvention|0);
          if ($102) {
           label = 48;
          } else {
           $V_1$2 = $V_1$3;
          }
         }
         if ((label|0) == 48) {
          label = 0;
          $103 = (($V_1$3) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($62|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           break;
          }
          $106 = ($V_1$3|0)<(0);
          if ($106) {
           label = 51;
          } else {
           $107 = HEAP32[$83>>2]|0;
           $108 = ($V_1$3>>>0)<($107>>>0);
           if (!($108)) {
            label = 51;
           }
          }
          if ((label|0) == 51) {
           label = 0;
           __THREW__ = 0;
           $109 = (invoke_i(132)|0);
           $110 = __THREW__; __THREW__ = 0;
           $111 = $110&1;
           if ($111) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($109|0));
           $112 = __THREW__; __THREW__ = 0;
           $113 = $112&1;
           if ($113) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($62|0),($96|0));
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           break;
          }
          $116 = HEAP32[$62>>2]|0;
          $117 = (($116) + 92|0);
          $118 = HEAP32[$117>>2]|0;
          $119 = Math_imul($118, $V_1$3)|0;
          $120 = (($82) + ($119)|0);
          HEAP32[$120>>2] = $96;
          $V_1$2 = $103;
         }
         $121 = (($V_8$0) + 1)|0;
         $V_1$3 = $V_1$2;$V_8$0 = $121;
        }
        $9 = ___cxa_find_matching_catch()|0;
        $10 = tempRet0;
        $lpad$phi$index = $9;$lpad$phi$index3 = $10;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
      } while(0);
      $128 = ($binder|0)==(0|0);
      if ($128) {
       __THREW__ = 0;
       $129 = (invoke_ii(2196,(0|0))|0);
       $130 = __THREW__; __THREW__ = 0;
       $131 = $130&1;
       if ($131) {
        break;
       } else {
        $$01 = $129;
       }
      } else {
       $$01 = $binder;
      }
      __THREW__ = 0;
      invoke_vi(3799,($$01|0));
      $132 = __THREW__; __THREW__ = 0;
      $133 = $132&1;
      if (!($133)) {
       __THREW__ = 0;
       $134 = (invoke_iiiiiii(131,(2399880|0),($$01|0),($bindingAttr|0),($62|0),($types|0),($modifiers|0))|0);
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if (!($136)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2403064|0))|0);
        $137 = __THREW__; __THREW__ = 0;
        $138 = $137&1;
        if (!($138)) {
         __THREW__ = 0;
         $139 = (invoke_iii(2759,($134|0),(2403064|0))|0);
         $140 = __THREW__; __THREW__ = 0;
         $141 = $140&1;
         if (!($141)) {
          $$0 = $139;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_check_createdP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371608);
 __THREW__ = 0;
 $0 = (invoke_ii(2175,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  if ($0) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  $5 = (invoke_ii(2176,0)|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(3833,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    // unreachable;
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z79mscorlib_System_Reflection_AmbiguousMatchException_m__ctor_mscorlib_System_VoidP50mscorlib_System_Reflection_AmbiguousMatchException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2374992);
 __THREW__ = 0;
 invoke_v(606);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3030176>>2]|0;
  __THREW__ = 0;
  invoke_vii(1975,($__this|0),($2|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN16VirtFuncInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEP10MethodInfoPviS5_S5_S5_($method,$obj,$p1,$p2,$p3,$p4) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z55mscorlib_System_Reflection_Emit_TypeBuilder_m_IsDefinedP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358416);
 __THREW__ = 0;
 $0 = (invoke_ii(2175,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if (!($0)) {
    __THREW__ = 0;
    $5 = (invoke_ii(2174,($__this|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2622808|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2622808|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2756,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3833,($10|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   $17 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($17|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Reflection_Emit_TypeBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP43mscorlib_System_Reflection_Emit_TypeBuilderb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357168);
 __THREW__ = 0;
 invoke_vi(2253,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 60|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iiii(1668,(2242680|0),($3|0),($inherit|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z141mscorlib_System_Reflection_Emit_TypeBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357264);
 __THREW__ = 0;
 invoke_vi(2253,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 60|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iiiii(322,(2242752|0),($3|0),($attributeType|0),($inherit|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_GetConstructorsP43mscorlib_System_Reflection_Emit_TypeBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357072);
 __THREW__ = 0;
 $0 = (invoke_ii(2175,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    $5 = (($__this) + 60|0);
    $6 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($6|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_iiii(1642,(2240832|0),($6|0),($bindingAttr|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $12 = (invoke_ii(2174,($__this|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    if ($12) {
     __THREW__ = 0;
     $24 = (invoke_iii(898,($__this|0),($bindingAttr|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     } else {
      $$0 = $24;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2622808|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2622808|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(2756,($17|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       invoke_vi(3833,($17|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Reflection_Emit_TypeBuilder_m_GetConstructorsInternalP43mscorlib_System_Reflection_Emit_TypeBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $$0$in = 0, $$sink4 = 0, $$sink4$v = 0, $$sink5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $V_5$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$ = 0, $not$8 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2370936);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(1220856|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2758,(1220856|0),0)|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $$0$in = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0$in|0);
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2304136|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_ii(3469,(2304136|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_vi(2153,($14|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[$0>>2]|0;
     $20 = (($19) + 12|0);
     $21 = (($19) + 16|0);
     $V_5$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($19|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      $52 = HEAP32[$20>>2]|0;
      $53 = ($V_5$0|0)<($52|0);
      if (!($53)) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($19|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 4;
       break;
      }
      $22 = HEAP32[$20>>2]|0;
      $23 = ($V_5$0>>>0)<($22>>>0);
      if (!($23)) {
       __THREW__ = 0;
       $24 = (invoke_i(132)|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($24|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        label = 4;
        break;
       }
      }
      $29 = HEAP32[$19>>2]|0;
      $30 = (($29) + 92|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = Math_imul($31, $V_5$0)|0;
      $33 = (($21) + ($32)|0);
      $34 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($34|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $37 = (invoke_iii(2729,(2354104|0),($34|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 4;
       break;
      }
      $40 = $37 & 7;
      $41 = ($40|0)==(6);
      $$sink4$v = $41 ? 16 : 32;
      $$sink4 = $$sink4$v & $bindingAttr;
      $not$ = ($$sink4|0)==(0);
      if (!($not$)) {
       $42 = $37 >>> 2;
       $43 = $42 & 4;
       $44 = (($43) + 4)|0;
       $$sink5 = $44 & $bindingAttr;
       $not$8 = ($$sink5|0)==(0);
       if (!($not$8)) {
        __THREW__ = 0;
        invoke_vi(3799,($14|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_iiii(1647,(2297624|0),($14|0),($34|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
       }
      }
      $49 = (($V_5$0) + 1)|0;
      $V_5$0 = $49;
     }
     if ((label|0) == 4) {
      $8 = ___cxa_find_matching_catch()|0;
      $9 = tempRet0;
      $lpad$phi$index = $8;$lpad$phi$index2 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if (!($57)) {
      __THREW__ = 0;
      $58 = (invoke_iii(2729,(2296488|0),($14|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if (!($60)) {
       __THREW__ = 0;
       (invoke_ii(2996,(1220856|0))|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if (!($62)) {
        __THREW__ = 0;
        $63 = (invoke_iii(2758,(1220856|0),($58|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if (!($65)) {
         __THREW__ = 0;
         invoke_vi(3799,($14|0));
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if (!($67)) {
          __THREW__ = 0;
          invoke_viii(2110,(2298584|0),($14|0),($63|0));
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if (!($69)) {
           $$0$in = $63;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0$in|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Reflection_Emit_TypeBuilder_m_GetElementTypeP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357360);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3833,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_Emit_TypeBuilder_m_GetFieldP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_Stringi($__this,$name,$bindingAttr) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 var $$0 = 0, $$sink4 = 0, $$sink4$v = 0, $$sink5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_4$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$ = 0, $not$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357456);
 $0 = (($__this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiiii(323,(2239632|0),($1|0),($name|0),($bindingAttr|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $$0 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $12 = (($__this) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($13) + 12|0);
 $16 = (($13) + 16|0);
 $V_4$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($13|0));
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   label = 5;
   break;
  }
  $52 = HEAP32[$15>>2]|0;
  $53 = ($V_4$0|0)<($52|0);
  if (!($53)) {
   $$0 = 0;
   label = 26;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($13|0));
  $54 = __THREW__; __THREW__ = 0;
  $55 = $54&1;
  if ($55) {
   label = 5;
   break;
  }
  $17 = HEAP32[$15>>2]|0;
  $18 = ($V_4$0>>>0)<($17>>>0);
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_i(132)|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if ($21) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($19|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    label = 5;
    break;
   }
  }
  $24 = HEAP32[$13>>2]|0;
  $25 = (($24) + 92|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = Math_imul($26, $V_4$0)|0;
  $28 = (($16) + ($27)|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(0|0);
  if (!($30)) {
   __THREW__ = 0;
   invoke_vi(3799,($29|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   $33 = (invoke_iii(2730,(2233608|0),($29|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   $36 = (invoke_iiii(575,(0|0),($33|0),($name|0))|0);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 5;
    break;
   }
   if (!($36)) {
    __THREW__ = 0;
    invoke_vi(3799,($29|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    $41 = (invoke_iii(2729,(2405552|0),($29|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     label = 5;
     break;
    }
    $44 = $41 & 7;
    $45 = ($44|0)==(6);
    $$sink4$v = $45 ? 16 : 32;
    $$sink4 = $$sink4$v & $bindingAttr;
    $not$ = ($$sink4|0)==(0);
    if (!($not$)) {
     $46 = $41 >>> 2;
     $47 = $46 & 4;
     $48 = (($47) + 4)|0;
     $$sink5 = $48 & $bindingAttr;
     $not$6 = ($$sink5|0)==(0);
     if (!($not$6)) {
      $$0 = $29;
      label = 26;
      break;
     }
    }
   }
  }
  $49 = (($V_4$0) + 1)|0;
  $V_4$0 = $49;
 }
 if ((label|0) == 5) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  $lpad$phi$index = $8;$lpad$phi$index2 = $9;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 else if ((label|0) == 26) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_Reflection_Emit_TypeBuilder_m_GetFieldsP43mscorlib_System_Reflection_Emit_TypeBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $$0 = 0, $$sink4 = 0, $$sink4$v = 0, $$sink5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $8 = 0, $9 = 0, $V_5$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$ = 0, $not$8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357552);
 $0 = (($__this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $12 = (($__this) + 44|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    __THREW__ = 0;
    (invoke_ii(2996,(1173408|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_iii(2758,(1173408|0),0)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $$0 = $17;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2304136|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2304136|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     invoke_vi(2153,($22|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[$12>>2]|0;
      $28 = (($27) + 12|0);
      $29 = (($27) + 16|0);
      $V_5$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($27|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        label = 5;
        break;
       }
       $61 = HEAP32[$28>>2]|0;
       $62 = ($V_5$0|0)<($61|0);
       if (!($62)) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($27|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        label = 5;
        break;
       }
       $30 = HEAP32[$28>>2]|0;
       $31 = ($V_5$0>>>0)<($30>>>0);
       if (!($31)) {
        __THREW__ = 0;
        $32 = (invoke_i(132)|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         label = 5;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($32|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         label = 5;
         break;
        }
       }
       $37 = HEAP32[$27>>2]|0;
       $38 = (($37) + 92|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = Math_imul($39, $V_5$0)|0;
       $41 = (($29) + ($40)|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($42|0)==(0|0);
       if (!($43)) {
        __THREW__ = 0;
        invoke_vi(3799,($42|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         label = 5;
         break;
        }
        __THREW__ = 0;
        $46 = (invoke_iii(2729,(2405552|0),($42|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break;
        }
        $49 = $46 & 7;
        $50 = ($49|0)==(6);
        $$sink4$v = $50 ? 16 : 32;
        $$sink4 = $$sink4$v & $bindingAttr;
        $not$ = ($$sink4|0)==(0);
        if (!($not$)) {
         $51 = $46 >>> 2;
         $52 = $51 & 4;
         $53 = (($52) + 4)|0;
         $$sink5 = $53 & $bindingAttr;
         $not$8 = ($$sink5|0)==(0);
         if (!($not$8)) {
          __THREW__ = 0;
          invoke_vi(3799,($22|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 5;
           break;
          }
          __THREW__ = 0;
          (invoke_iiii(1647,(2297624|0),($22|0),($42|0))|0);
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           label = 5;
           break;
          }
         }
        }
       }
       $58 = (($V_5$0) + 1)|0;
       $V_5$0 = $58;
      }
      if ((label|0) == 5) {
       $8 = ___cxa_find_matching_catch()|0;
       $9 = tempRet0;
       $lpad$phi$index = $8;$lpad$phi$index2 = $9;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vi(3799,($22|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if (!($66)) {
       __THREW__ = 0;
       $67 = (invoke_iii(2729,(2296488|0),($22|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if (!($69)) {
        __THREW__ = 0;
        (invoke_ii(2996,(1173408|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if (!($71)) {
         __THREW__ = 0;
         $72 = (invoke_iii(2758,(1173408|0),($67|0))|0);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if (!($74)) {
          __THREW__ = 0;
          invoke_vi(3799,($22|0));
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if (!($76)) {
           __THREW__ = 0;
           invoke_viii(2110,(2298584|0),($22|0),($72|0));
           $77 = __THREW__; __THREW__ = 0;
           $78 = $77&1;
           if (!($78)) {
            $$0 = $72;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($1|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iiii(1642,(2236192|0),($1|0),($bindingAttr|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $$0 = $5;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_GetInterfacesP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357648);
 __THREW__ = 0;
 $0 = (invoke_ii(2175,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    $5 = (($__this) + 60|0);
    $6 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($6|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_iii(2730,(2239448|0),($6|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $12 = (($__this) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if (!($14)) {
    __THREW__ = 0;
    invoke_vi(3799,($13|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($13) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(1169184|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_iii(2758,(1169184|0),($18|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __THREW__ = 0;
    invoke_viiii(461,(2225864|0),($24|0),($21|0),0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    } else {
     $$0 = $21;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2242320|0))|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    $31 = HEAP8[((2242320 + 116|0))>>0]|0;
    $32 = ($31<<24>>24)==(0);
    if ($32) {
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3832,(2242320|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2242320|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     $41 = HEAP32[((2242320 + 80|0))>>2]|0;
     $42 = (($41) + 8|0);
     $43 = HEAP32[$42>>2]|0;
     $$0 = $43;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Reflection_Emit_TypeBuilder_m_GetMethodsByNameP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_StringibP20mscorlib_System_Type($__this,$name,$bindingAttr,$ignoreCase,$reflected_type) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $ignoreCase = $ignoreCase|0;
 $reflected_type = $reflected_type|0;
 var $$0$in = 0, $$lobit = 0, $$lobit7 = 0, $$not = 0, $$not9 = 0, $$off = 0, $$sink13 = 0, $$sink13$v = 0, $$sink14 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_11$0 = 0, $V_6$0 = 0;
 var $_stackTraceSentry = 0, $brmerge = 0, $extract$t = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $not$ = 0, $not$21 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2370984);
 $0 = $bindingAttr & 2;
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   $2 = (($__this) + 20|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    label = 51;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iiii(1642,(2240024|0),($3|0),($bindingAttr|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($7) + 12|0);
       $13 = HEAP32[$12>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2304136|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        $16 = (invoke_ii(3469,(2304136|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         __THREW__ = 0;
         invoke_vii(1816,($16|0),($13|0));
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if (!($20)) {
          $$lobit = $bindingAttr & 64;
          $$not9 = ($$lobit|0)!=(0);
          $$lobit7 = $bindingAttr & 16;
          $21 = ($$lobit7|0)==(0);
          $22 = $bindingAttr & 32;
          $extract$t = ($22|0)==(0);
          $V_6$0 = 0;
          L10: while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($7|0));
           $59 = __THREW__; __THREW__ = 0;
           $60 = $59&1;
           if ($60) {
            label = 11;
            break;
           }
           $61 = HEAP32[$12>>2]|0;
           $62 = ($V_6$0|0)<($61|0);
           if (!($62)) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($7|0));
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            label = 11;
            break;
           }
           $29 = HEAP32[$12>>2]|0;
           $30 = ($V_6$0>>>0)<($29>>>0);
           if (!($30)) {
            __THREW__ = 0;
            $31 = (invoke_i(132)|0);
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if ($33) {
             label = 11;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($31|0));
            $34 = __THREW__; __THREW__ = 0;
            $35 = $34&1;
            if ($35) {
             label = 11;
             break;
            }
           }
           $36 = HEAP32[$7>>2]|0;
           $37 = (($36) + 92|0);
           $38 = HEAP32[$37>>2]|0;
           $39 = Math_imul($38, $V_6$0)|0;
           $$sum = (($39) + 16)|0;
           $40 = (($7) + ($$sum)|0);
           $41 = HEAP32[$40>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($41|0));
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if ($43) {
            label = 11;
            break;
           }
           __THREW__ = 0;
           $44 = (invoke_iii(2729,(2410224|0),($41|0))|0);
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            label = 11;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($41|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if ($48) {
            label = 11;
            break;
           }
           __THREW__ = 0;
           $49 = (invoke_iii(2734,(2410512|0),($41|0))|0);
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           if ($51) {
            label = 11;
            break;
           }
           $$not = $49 ^ 1;
           $brmerge = $$not9 | $$not;
           L23: do {
            if ($brmerge) {
             $52 = $44 & 7;
             do {
              if ((($52|0) == 3)) {
               if ($extract$t) {
                break L23;
               }
              } else if ((($52|0) == 2)) {
               label = 25;
              } else if ((($52|0) == 1)) {
               break L23;
              } else {
               $$off = (($52) + -4)|0;
               $or$cond$not = ($$off>>>0)>(1);
               $53 = ($52|0)==(6);
               $or$cond3 = $or$cond$not & $53;
               if (!($or$cond3)) {
                label = 25;
                break;
               }
               if ($21) {
                break L23;
               }
              }
             } while(0);
             if ((label|0) == 25) {
              label = 0;
              if ($extract$t) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vi(3799,($16|0));
             $54 = __THREW__; __THREW__ = 0;
             $55 = $54&1;
             if ($55) {
              label = 11;
              break L10;
             }
             __THREW__ = 0;
             (invoke_iiii(1647,(2297624|0),($16|0),($41|0))|0);
             $56 = __THREW__; __THREW__ = 0;
             $57 = $56&1;
             if ($57) {
              label = 11;
              break L10;
             }
            }
           } while(0);
           $58 = (($V_6$0) + 1)|0;
           $V_6$0 = $58;
          }
          if ((label|0) == 11) {
           $25 = ___cxa_find_matching_catch()|0;
           $26 = tempRet0;
           $lpad$phi$index = $25;$lpad$phi$index3 = $26;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          $65 = (($__this) + 32|0);
          $66 = HEAP32[$65>>2]|0;
          $67 = ($66|0)==(0|0);
          if ($67) {
           __THREW__ = 0;
           invoke_vi(3799,($16|0));
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            break;
           }
           __THREW__ = 0;
           $70 = (invoke_iii(2729,(2296488|0),($16|0))|0);
           $71 = __THREW__; __THREW__ = 0;
           $72 = $71&1;
           if ($72) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1220464|0))|0);
           $73 = __THREW__; __THREW__ = 0;
           $74 = $73&1;
           if ($74) {
            break;
           }
           __THREW__ = 0;
           $75 = (invoke_iii(2758,(1220464|0),($70|0))|0);
           $76 = __THREW__; __THREW__ = 0;
           $77 = $76&1;
           if ($77) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($16|0));
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if ($79) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(2110,(2298584|0),($16|0),($75|0));
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if ($81) {
            break;
           } else {
            $V_0$0 = $75;
            label = 52;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($66|0));
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if (!($83)) {
           $84 = (($66) + 12|0);
           $85 = HEAP32[$84>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($16|0));
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if (!($87)) {
            __THREW__ = 0;
            $88 = (invoke_iii(2729,(2296488|0),($16|0))|0);
            $89 = __THREW__; __THREW__ = 0;
            $90 = $89&1;
            if (!($90)) {
             __THREW__ = 0;
             (invoke_ii(2996,(1220464|0))|0);
             $91 = __THREW__; __THREW__ = 0;
             $92 = $91&1;
             if (!($92)) {
              $93 = (($88) + ($85))|0;
              __THREW__ = 0;
              $94 = (invoke_iii(2758,(1220464|0),($93|0))|0);
              $95 = __THREW__; __THREW__ = 0;
              $96 = $95&1;
              if (!($96)) {
               __THREW__ = 0;
               invoke_vi(3799,($16|0));
               $97 = __THREW__; __THREW__ = 0;
               $98 = $97&1;
               if (!($98)) {
                __THREW__ = 0;
                invoke_viiii(461,(2298680|0),($16|0),($94|0),0);
                $99 = __THREW__; __THREW__ = 0;
                $100 = $99&1;
                if (!($100)) {
                 $101 = HEAP32[$65>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($16|0));
                 $102 = __THREW__; __THREW__ = 0;
                 $103 = $102&1;
                 if (!($103)) {
                  __THREW__ = 0;
                  $104 = (invoke_iii(2729,(2296488|0),($16|0))|0);
                  $105 = __THREW__; __THREW__ = 0;
                  $106 = $105&1;
                  if (!($106)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($101|0));
                   $107 = __THREW__; __THREW__ = 0;
                   $108 = $107&1;
                   if (!($108)) {
                    __THREW__ = 0;
                    invoke_viiii(461,(2225864|0),($101|0),($94|0),($104|0));
                    $109 = __THREW__; __THREW__ = 0;
                    $110 = $109&1;
                    if (!($110)) {
                     $V_0$0 = $94;
                     label = 52;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  } else {
   label = 51;
  }
 } while(0);
 if ((label|0) == 51) {
  $111 = (($__this) + 32|0);
  $112 = HEAP32[$111>>2]|0;
  $V_0$0 = $112;
  label = 52;
 }
 do {
  if ((label|0) == 52) {
   $113 = ($V_0$0|0)==(0|0);
   if ($113) {
    __THREW__ = 0;
    (invoke_ii(2996,(1220464|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    }
    __THREW__ = 0;
    $116 = (invoke_iii(2758,(1220464|0),0)|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     break;
    } else {
     $$0$in = $116;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0$in|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2304136|0))|0);
   $119 = __THREW__; __THREW__ = 0;
   $120 = $119&1;
   if (!($120)) {
    __THREW__ = 0;
    $121 = (invoke_ii(3469,(2304136|0))|0);
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if (!($123)) {
     __THREW__ = 0;
     invoke_vi(2153,($121|0));
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     if (!($125)) {
      $126 = (($V_0$0) + 12|0);
      $127 = (($V_0$0) + 16|0);
      $128 = ($name|0)==(0|0);
      $V_11$0 = 0;
      L68: while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($V_0$0|0));
       $167 = __THREW__; __THREW__ = 0;
       $168 = $167&1;
       if ($168) {
        label = 10;
        break;
       }
       $169 = HEAP32[$126>>2]|0;
       $170 = ($V_11$0|0)<($169|0);
       if (!($170)) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($V_0$0|0));
       $171 = __THREW__; __THREW__ = 0;
       $172 = $171&1;
       if ($172) {
        label = 10;
        break;
       }
       $129 = HEAP32[$126>>2]|0;
       $130 = ($V_11$0>>>0)<($129>>>0);
       if (!($130)) {
        __THREW__ = 0;
        $131 = (invoke_i(132)|0);
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if ($133) {
         label = 10;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($131|0));
        $134 = __THREW__; __THREW__ = 0;
        $135 = $134&1;
        if ($135) {
         label = 10;
         break;
        }
       }
       $136 = HEAP32[$V_0$0>>2]|0;
       $137 = (($136) + 92|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = Math_imul($138, $V_11$0)|0;
       $140 = (($127) + ($139)|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = ($141|0)==(0|0);
       do {
        if (!($142)) {
         if (!($128)) {
          __THREW__ = 0;
          invoke_vi(3799,($141|0));
          $143 = __THREW__; __THREW__ = 0;
          $144 = $143&1;
          if ($144) {
           label = 10;
           break L68;
          }
          __THREW__ = 0;
          $145 = (invoke_iii(2730,(2233608|0),($141|0))|0);
          $146 = __THREW__; __THREW__ = 0;
          $147 = $146&1;
          if ($147) {
           label = 10;
           break L68;
          }
          __THREW__ = 0;
          $148 = (invoke_iiiii(91,(0|0),($145|0),($name|0),($ignoreCase|0))|0);
          $149 = __THREW__; __THREW__ = 0;
          $150 = $149&1;
          if ($150) {
           label = 10;
           break L68;
          }
          $151 = ($148|0)==(0);
          if (!($151)) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($141|0));
         $152 = __THREW__; __THREW__ = 0;
         $153 = $152&1;
         if ($153) {
          label = 10;
          break L68;
         }
         __THREW__ = 0;
         $154 = (invoke_iii(2729,(2410224|0),($141|0))|0);
         $155 = __THREW__; __THREW__ = 0;
         $156 = $155&1;
         if ($156) {
          label = 10;
          break L68;
         }
         $157 = $154 & 7;
         $158 = ($157|0)==(6);
         $$sink13$v = $158 ? 16 : 32;
         $$sink13 = $$sink13$v & $bindingAttr;
         $not$ = ($$sink13|0)==(0);
         if (!($not$)) {
          $159 = $154 >>> 2;
          $160 = $159 & 4;
          $161 = (($160) + 4)|0;
          $$sink14 = $161 & $bindingAttr;
          $not$21 = ($$sink14|0)==(0);
          if (!($not$21)) {
           __THREW__ = 0;
           invoke_vi(3799,($121|0));
           $162 = __THREW__; __THREW__ = 0;
           $163 = $162&1;
           if ($163) {
            label = 10;
            break L68;
           }
           __THREW__ = 0;
           (invoke_iiii(1647,(2297624|0),($121|0),($141|0))|0);
           $164 = __THREW__; __THREW__ = 0;
           $165 = $164&1;
           if ($165) {
            label = 10;
            break L68;
           }
          }
         }
        }
       } while(0);
       $166 = (($V_11$0) + 1)|0;
       $V_11$0 = $166;
      }
      if ((label|0) == 10) {
       $23 = ___cxa_find_matching_catch()|0;
       $24 = tempRet0;
       $lpad$phi$index = $23;$lpad$phi$index3 = $24;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vi(3799,($121|0));
      $173 = __THREW__; __THREW__ = 0;
      $174 = $173&1;
      if (!($174)) {
       __THREW__ = 0;
       $175 = (invoke_iii(2729,(2296488|0),($121|0))|0);
       $176 = __THREW__; __THREW__ = 0;
       $177 = $176&1;
       if (!($177)) {
        __THREW__ = 0;
        (invoke_ii(2996,(1220464|0))|0);
        $178 = __THREW__; __THREW__ = 0;
        $179 = $178&1;
        if (!($179)) {
         __THREW__ = 0;
         $180 = (invoke_iii(2758,(1220464|0),($175|0))|0);
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if (!($182)) {
          __THREW__ = 0;
          invoke_vi(3799,($121|0));
          $183 = __THREW__; __THREW__ = 0;
          $184 = $183&1;
          if (!($184)) {
           __THREW__ = 0;
           invoke_viii(2110,(2298584|0),($121|0),($180|0));
           $185 = __THREW__; __THREW__ = 0;
           $186 = $185&1;
           if (!($186)) {
            $$0$in = $180;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0$in|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $lpad$phi$index = $27;$lpad$phi$index3 = $28;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Reflection_Emit_TypeBuilder_m_GetMethodsP43mscorlib_System_Reflection_Emit_TypeBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357792);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(110,($__this|0),(0|0),($bindingAttr|0),0,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_GetMethodImplP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $$0 = 0, $$01 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $G_B3_0$0 = 0, $V_11$0 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_5$0 = 0, $V_5$1 = 0, $V_5$2 = 0, $V_5$3 = 0, $V_8$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371032);
 __THREW__ = 0;
 invoke_vi(2253,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = $bindingAttr & 1;
   $3 = ($2|0)!=(0);
   __THREW__ = 0;
   $4 = (invoke_iiiiii(110,($__this|0),($name|0),($bindingAttr|0),($3|0),0)|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($types|0)!=(0|0);
    if ($7) {
     __THREW__ = 0;
     invoke_vi(3799,($types|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = (($types) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $G_B3_0$0 = $17;
    } else {
     $G_B3_0$0 = 0;
    }
    $18 = (($4) + 12|0);
    $19 = (($4) + 16|0);
    $20 = ($callConvention|0)==(3);
    $V_2$1 = 0;$V_5$1 = 0;$V_8$0 = 0;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 5;
      break;
     }
     $45 = HEAP32[$18>>2]|0;
     $46 = ($V_8$0|0)<($45|0);
     if (!($46)) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      label = 5;
      break;
     }
     $21 = HEAP32[$18>>2]|0;
     $22 = ($V_8$0>>>0)<($21>>>0);
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_i(132)|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($23|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 5;
       break;
      }
     }
     $28 = HEAP32[$4>>2]|0;
     $29 = (($28) + 92|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = Math_imul($30, $V_8$0)|0;
     $32 = (($19) + ($31)|0);
     $33 = HEAP32[$32>>2]|0;
     if ($20) {
      label = 18;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2729,(2397712|0),($33|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 5;
       break;
      }
      $39 = $36 & $callConvention;
      $40 = ($39|0)==($callConvention|0);
      if ($40) {
       label = 18;
      } else {
       $V_2$0 = $V_2$1;$V_5$0 = $V_5$1;
      }
     }
     if ((label|0) == 18) {
      label = 0;
      $41 = (($V_5$1) + 1)|0;
      $V_2$0 = $33;$V_5$0 = $41;
     }
     $42 = (($V_8$0) + 1)|0;
     $V_2$1 = $V_2$0;$V_5$1 = $V_5$0;$V_8$0 = $42;
    }
    if ((label|0) == 5) {
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index3 = $11;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    $49 = ($V_5$1|0)==(0);
    if ($49) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $50 = ($V_5$1|0)!=(1);
    $$not = $50 ^ 1;
    $51 = ($G_B3_0$0|0)==(0);
    $or$cond = $51 & $$not;
    if ($or$cond) {
     $$0 = $V_2$1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1238976|0))|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if (!($53)) {
     __THREW__ = 0;
     $54 = (invoke_iii(2758,(1238976|0),($V_5$1|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      L36: do {
       if ($50) {
        $57 = (($54) + 16|0);
        $58 = (($54) + 12|0);
        $V_11$0 = 0;$V_5$3 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $111 = __THREW__; __THREW__ = 0;
         $112 = $111&1;
         if ($112) {
          break;
         }
         $113 = HEAP32[$18>>2]|0;
         $114 = ($V_11$0|0)<($113|0);
         if (!($114)) {
          break L36;
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break;
         }
         $72 = HEAP32[$18>>2]|0;
         $73 = ($V_11$0>>>0)<($72>>>0);
         if (!($73)) {
          __THREW__ = 0;
          $74 = (invoke_i(132)|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($74|0));
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           break;
          }
         }
         $79 = HEAP32[$4>>2]|0;
         $80 = (($79) + 92|0);
         $81 = HEAP32[$80>>2]|0;
         $82 = Math_imul($81, $V_11$0)|0;
         $83 = (($19) + ($82)|0);
         $84 = HEAP32[$83>>2]|0;
         if ($20) {
          label = 42;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($84|0));
          $85 = __THREW__; __THREW__ = 0;
          $86 = $85&1;
          if ($86) {
           break;
          }
          __THREW__ = 0;
          $87 = (invoke_iii(2729,(2397712|0),($84|0))|0);
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           break;
          }
          $90 = $87 & $callConvention;
          $91 = ($90|0)==($callConvention|0);
          if ($91) {
           label = 42;
          } else {
           $V_5$2 = $V_5$3;
          }
         }
         if ((label|0) == 42) {
          label = 0;
          $92 = (($V_5$3) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($54|0));
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           break;
          }
          $95 = ($V_5$3|0)<(0);
          if ($95) {
           label = 45;
          } else {
           $96 = HEAP32[$58>>2]|0;
           $97 = ($V_5$3>>>0)<($96>>>0);
           if (!($97)) {
            label = 45;
           }
          }
          if ((label|0) == 45) {
           label = 0;
           __THREW__ = 0;
           $98 = (invoke_i(132)|0);
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($98|0));
           $101 = __THREW__; __THREW__ = 0;
           $102 = $101&1;
           if ($102) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($54|0),($84|0));
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           break;
          }
          $105 = HEAP32[$54>>2]|0;
          $106 = (($105) + 92|0);
          $107 = HEAP32[$106>>2]|0;
          $108 = Math_imul($107, $V_5$3)|0;
          $109 = (($57) + ($108)|0);
          HEAP32[$109>>2] = $84;
          $V_5$2 = $92;
         }
         $110 = (($V_11$0) + 1)|0;
         $V_11$0 = $110;$V_5$3 = $V_5$2;
        }
        $8 = ___cxa_find_matching_catch()|0;
        $9 = tempRet0;
        $lpad$phi$index = $8;$lpad$phi$index3 = $9;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break L1;
        }
        $61 = (($54) + 12|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = ($62|0)==(0);
        if ($63) {
         __THREW__ = 0;
         $64 = (invoke_i(132)|0);
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($64|0));
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          break L1;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($54|0),($V_2$1|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($54) + 16|0);
        HEAP32[$71>>2] = $V_2$1;
       }
      } while(0);
      if (!($7)) {
       __THREW__ = 0;
       $117 = (invoke_iii(905,(0|0),($54|0))|0);
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2414216|0))|0);
       $120 = __THREW__; __THREW__ = 0;
       $121 = $120&1;
       if ($121) {
        break;
       }
       __THREW__ = 0;
       $122 = (invoke_iii(2759,($117|0),(2414216|0))|0);
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        break;
       }
       $$0 = $122;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $125 = ($binder|0)==(0|0);
      if ($125) {
       __THREW__ = 0;
       $126 = (invoke_ii(2196,(0|0))|0);
       $127 = __THREW__; __THREW__ = 0;
       $128 = $127&1;
       if ($128) {
        break;
       } else {
        $$01 = $126;
       }
      } else {
       $$01 = $binder;
      }
      __THREW__ = 0;
      invoke_vi(3799,($$01|0));
      $129 = __THREW__; __THREW__ = 0;
      $130 = $129&1;
      if (!($130)) {
       __THREW__ = 0;
       $131 = (invoke_iiiiiii(131,(2399880|0),($$01|0),($bindingAttr|0),($54|0),($types|0),($modifiers|0))|0);
       $132 = __THREW__; __THREW__ = 0;
       $133 = $132&1;
       if (!($133)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2414216|0))|0);
        $134 = __THREW__; __THREW__ = 0;
        $135 = $134&1;
        if (!($135)) {
         __THREW__ = 0;
         $136 = (invoke_iii(2759,($131|0),(2414216|0))|0);
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if (!($138)) {
          $$0 = $136;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index3 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_GetPropertiesP43mscorlib_System_Reflection_Emit_TypeBuilderi($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $$0 = 0, $$sink4 = 0, $$sink4$v = 0, $$sink5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $V_3$0$in8 = 0, $V_6$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $not$ = 0, $not$9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2357888);
 __THREW__ = 0;
 $0 = (invoke_ii(2175,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    $7 = (($__this) + 60|0);
    $8 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_iiii(1642,(2236576|0),($8|0),($bindingAttr|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $$0 = $11;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $14 = (($__this) + 40|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    __THREW__ = 0;
    (invoke_ii(2996,(1173792|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_iii(2758,(1173792|0),0)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $$0 = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2304136|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2304136|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     invoke_vi(2153,($24|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[$14>>2]|0;
      $30 = (($29) + 12|0);
      $31 = (($29) + 16|0);
      $V_6$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($29|0));
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        label = 3;
        break;
       }
       $74 = HEAP32[$30>>2]|0;
       $75 = ($V_6$0|0)<($74|0);
       if (!($75)) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($29|0));
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        label = 3;
        break;
       }
       $32 = HEAP32[$30>>2]|0;
       $33 = ($V_6$0>>>0)<($32>>>0);
       if (!($33)) {
        __THREW__ = 0;
        $34 = (invoke_i(132)|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($34|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         label = 3;
         break;
        }
       }
       $39 = HEAP32[$29>>2]|0;
       $40 = (($39) + 92|0);
       $41 = HEAP32[$40>>2]|0;
       $42 = Math_imul($41, $V_6$0)|0;
       $43 = (($31) + ($42)|0);
       $44 = HEAP32[$43>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($44|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $47 = (invoke_iiii(1668,(2434288|0),($44|0),1)|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        label = 3;
        break;
       }
       $50 = ($47|0)==(0|0);
       if ($50) {
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        $53 = (invoke_iiii(1668,(2434352|0),($44|0),1)|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 3;
         break;
        }
        $56 = ($53|0)==(0|0);
        if (!($56)) {
         $V_3$0$in8 = $53;
         label = 26;
        }
       } else {
        $V_3$0$in8 = $47;
        label = 26;
       }
       if ((label|0) == 26) {
        label = 0;
        __THREW__ = 0;
        invoke_vi(3799,($V_3$0$in8|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        $59 = (invoke_iii(2729,(2410224|0),($V_3$0$in8|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 3;
         break;
        }
        $62 = $59 & 7;
        $63 = ($62|0)==(6);
        $$sink4$v = $63 ? 16 : 32;
        $$sink4 = $$sink4$v & $bindingAttr;
        $not$ = ($$sink4|0)==(0);
        if (!($not$)) {
         $64 = $59 >>> 2;
         $65 = $64 & 4;
         $66 = (($65) + 4)|0;
         $$sink5 = $66 & $bindingAttr;
         $not$9 = ($$sink5|0)==(0);
         if (!($not$9)) {
          __THREW__ = 0;
          invoke_vi(3799,($24|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          (invoke_iiii(1647,(2297624|0),($24|0),($44|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           label = 3;
           break;
          }
         }
        }
       }
       $71 = (($V_6$0) + 1)|0;
       $V_6$0 = $71;
      }
      if ((label|0) == 3) {
       $3 = ___cxa_find_matching_catch()|0;
       $4 = tempRet0;
       $lpad$phi$index = $3;$lpad$phi$index2 = $4;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vi(3799,($24|0));
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if (!($79)) {
       __THREW__ = 0;
       $80 = (invoke_iii(2729,(2296488|0),($24|0))|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if (!($82)) {
        __THREW__ = 0;
        (invoke_ii(2996,(1173792|0))|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if (!($84)) {
         __THREW__ = 0;
         $85 = (invoke_iii(2758,(1173792|0),($80|0))|0);
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if (!($87)) {
          __THREW__ = 0;
          invoke_vi(3799,($24|0));
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if (!($89)) {
           __THREW__ = 0;
           invoke_viii(2110,(2298584|0),($24|0),($85|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if (!($91)) {
            $$0 = $85;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_GetPropertyImplP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$returnType,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $returnType = $returnType|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371080);
 __THREW__ = 0;
 $0 = (invoke_ii(2176,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3833,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   // unreachable;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_not_supportedP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371560);
 __THREW__ = 0;
 invoke_v(607);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3030104>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($4|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Reflection_Emit_TypeBuilder_m_HasElementTypeImplP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371128);
 __THREW__ = 0;
 $0 = (invoke_ii(2175,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  if (!($0)) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  $5 = (($__this) + 60|0);
  $6 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_iii(2734,(2233800|0),($6|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_InvokeMemberP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP22mscorlib_System_ObjectP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arr($__this,$name,$invokeAttr,$binder,$target,$args,$modifiers,$culture,$namedParameters) {
 $__this = $__this|0;
 $name = $name|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $target = $target|0;
 $args = $args|0;
 $modifiers = $modifiers|0;
 $culture = $culture|0;
 $namedParameters = $namedParameters|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2358080);
 __THREW__ = 0;
 invoke_vi(2253,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 60|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iiiiiiiiiii(6,(2240992|0),($3|0),($name|0),($invokeAttr|0),($binder|0),($target|0),($args|0),($modifiers|0),($culture|0),($namedParameters|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_Reflection_Emit_TypeBuilder_m_IsArrayImplP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371176);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z57mscorlib_System_Reflection_Emit_TypeBuilder_m_IsByRefImplP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371224);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_IsPointerImplP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371272);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_IsPrimitiveImplP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371320);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_IsValueTypeImplP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371368);
 $1 = (($__this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = (($2) + 36|0);
   $6 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($6|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = (($6) + 48|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    $11 = (invoke_iiiii(119,(0|0),($__this|0),($10|0),0)|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     if (!($11)) {
      HEAP32[$0>>2] = 2269376;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $16 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      $19 = (invoke_iiiii(119,(0|0),($__this|0),($16|0),0)|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      if (!($19)) {
       $G_B5_0$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($G_B5_0$0|0);
      }
     }
     $22 = HEAP32[$1>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($22|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $25 = (($22) + 36|0);
      $26 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = (($26) + 48|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($__this|0)==($30|0);
       if ($31) {
        $G_B5_0$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($G_B5_0$0|0);
       }
       $32 = HEAP32[$1>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($32|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        $35 = (($32) + 36|0);
        $36 = HEAP32[$35>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($36|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         $39 = (($36) + 52|0);
         $40 = HEAP32[$39>>2]|0;
         $41 = ($__this|0)!=($40|0);
         $G_B5_0$0 = $41;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($G_B5_0$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_MakeGenericTypeP43mscorlib_System_Reflection_Emit_TypeBuilderP24mscorlib_System_Type_arr($__this,$typeArguments) {
 $__this = $__this|0;
 $typeArguments = $typeArguments|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371416);
 __THREW__ = 0;
 $0 = (invoke_iii(778,($__this|0),($typeArguments|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z60mscorlib_System_Reflection_Emit_TypeBuilder_m_get_TypeHandleP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2356832);
 __THREW__ = 0;
 invoke_vi(2253,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 60|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2757,(2234952|0),($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_Emit_TypeBuilder_m_ToStringP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371656);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2356448|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z62mscorlib_System_Reflection_Emit_TypeBuilder_m_IsAssignableFromP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Type($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371704);
 __THREW__ = 0;
 $0 = (invoke_iii(774,($__this|0),($c|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_IsSubclassOfP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Type($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371752);
 __THREW__ = 0;
 $0 = (invoke_iii(765,($__this|0),($c|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z60mscorlib_System_Reflection_Emit_TypeBuilder_m_IsAssignableToP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Type($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371800);
 $1 = ($__this|0)==($c|0);
 if ($1) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($c|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L4: do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2734,(2234184|0),($c|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 20|0);
    do {
     if ($4) {
      $12 = HEAP32[$7>>2]|0;
      $13 = ($12|0)==(0|0);
      if (!($13)) {
       __THREW__ = 0;
       $14 = (invoke_ii(2175,($__this|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break L4;
       }
       if ($14) {
        $17 = HEAP32[$7>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($c|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break L4;
        }
        __THREW__ = 0;
        $20 = (invoke_iiii(1640,(2235992|0),($c|0),($17|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if ($22) {
         break L4;
        }
        if ($20) {
         $$0 = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
      $23 = (($__this) + 28|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24|0)==(0|0);
      if ($25) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $26 = (($24) + 12|0);
      $27 = (($24) + 16|0);
      $V_2$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($24|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        label = 5;
        break;
       }
       $49 = HEAP32[$26>>2]|0;
       $50 = ($V_2$0|0)<($49|0);
       if (!($50)) {
        label = 25;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($24|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        label = 5;
        break;
       }
       $28 = HEAP32[$26>>2]|0;
       $29 = ($V_2$0>>>0)<($28>>>0);
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_i(132)|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         label = 5;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($30|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         label = 5;
         break;
        }
       }
       $35 = HEAP32[$24>>2]|0;
       $36 = (($35) + 92|0);
       $37 = HEAP32[$36>>2]|0;
       $38 = Math_imul($37, $V_2$0)|0;
       $39 = (($27) + ($38)|0);
       $40 = HEAP32[$39>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($c|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 5;
        break;
       }
       __THREW__ = 0;
       $43 = (invoke_iiii(1640,(2235992|0),($c|0),($40|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 5;
        break;
       }
       $46 = (($V_2$0) + 1)|0;
       if ($43) {
        $$0 = 1;
        label = 32;
        break;
       } else {
        $V_2$0 = $46;
       }
      }
      if ((label|0) == 5) {
       $8 = ___cxa_find_matching_catch()|0;
       $9 = tempRet0;
       $lpad$phi$index = $8;$lpad$phi$index2 = $9;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 25) {
       __THREW__ = 0;
       $53 = (invoke_ii(2175,($__this|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break L4;
       }
       if ($53) {
        break;
       } else {
        $$0 = 0;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      else if ((label|0) == 32) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    } while(0);
    $56 = HEAP32[$7>>2]|0;
    $57 = ($56|0)==(0|0);
    if ($57) {
     HEAP32[$0>>2] = 1284448;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $58 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     $61 = ($58|0)==($c|0);
     $$0 = $61;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($c|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     $64 = (invoke_iiii(1640,(2235992|0),($c|0),($56|0))|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break;
     } else {
      $$0 = $64;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Reflection_Emit_TypeBuilder_m_GetGenericArgumentsP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371848);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($1) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(1169184|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_iii(2758,(1169184|0),($6|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_viiii(461,(2225864|0),($12|0),($9|0),0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $$0 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Reflection_Emit_TypeBuilder_m_GetGenericTypeDefinitionP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371896);
 __THREW__ = 0;
 invoke_v(608);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 56|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($__this|0);
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2607872|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_ii(3469,(2607872|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[3030120>>2]|0;
    __THREW__ = 0;
    invoke_vii(1947,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3833,($9|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      // unreachable;
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Reflection_Emit_TypeBuilder_m_get_ContainsGenericParametersP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371944);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z68mscorlib_System_Reflection_Emit_TypeBuilder_m_get_IsGenericParameterP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2371992);
 $0 = HEAP32[2372040>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2372048|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2372040>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Reflection_Emit_TypeBuilder_m_get_IsGenericTypeDefinitionP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2372112);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z63mscorlib_System_Reflection_Emit_TypeBuilder_m_get_IsGenericTypeP43mscorlib_System_Reflection_Emit_TypeBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2372160);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2372112|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsS0_E6InvokeEPFPvS4_S4_ibS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)!=(0);
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$3,$7,$9)|0);
 STACKTOP = sp;return ($10|0);
}
function __Z74mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2453792)|0);
 $10 = HEAP32[((2453792 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_GetConstructorsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_MakeGenericTypeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_IsAssignableFromP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_IsSubclassOfP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_IsAssignableToP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2373472)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_Reflection_Emit_UnmanagedMarshal_m_ToMarshalAsAttributeP48mscorlib_System_Reflection_Emit_UnmanagedMarshal($__this) {
 $__this = $__this|0;
 var $$c = 0, $$c4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2374360);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2249384|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2249384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vii(1786,($4|0),($1|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($__this) + 16|0);
     $10 = HEAP32[$9>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = (($4) + 12|0);
      $$c = $10;
      HEAP32[$13>>2] = $$c;
      $14 = (($__this) + 20|0);
      $15 = HEAP32[$14>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = (($4) + 16|0);
       HEAP32[$18>>2] = $15;
       $19 = (($__this) + 24|0);
       $20 = HEAP32[$19>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $23 = (($4) + 20|0);
        HEAP32[$23>>2] = $20;
        $24 = (($__this) + 28|0);
        $25 = HEAP32[$24>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $28 = (($4) + 24|0);
         HEAP32[$28>>2] = $25;
         $29 = (($__this) + 8|0);
         $30 = HEAP32[$29>>2]|0;
         $31 = ($30|0)==(-1);
         if ($31) {
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if ($35) {
           break;
          }
          $36 = (($4) + 28|0);
          HEAP32[$36>>2] = 0;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          $39 = (($4) + 28|0);
          $$c4 = $30;
          HEAP32[$39>>2] = $$c4;
         }
         $40 = (($__this) + 32|0);
         $41 = HEAP32[$40>>2]|0;
         $42 = ($41|0)==(-1);
         if ($42) {
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           break;
          }
          $45 = (($4) + 32|0);
          HEAP16[$45>>1] = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($4|0);
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          $48 = $41&65535;
          $49 = (($4) + 32|0);
          HEAP16[$49>>1] = $48;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($4|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($32|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Reflection_Emit_UnmanagedMarshal_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2374672)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z102mscorlib_System_Reflection_AmbiguousMatchException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP50mscorlib_System_Reflection_AmbiguousMatchExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2375040);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Reflection_AmbiguousMatchException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z50mscorlib_System_Reflection_Assembly_m_get_fullnameP35mscorlib_System_Reflection_Assembly($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2375616);
 $0 = HEAP32[2375664>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2375672|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2375664>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Reflection_Assembly_m_get_FullNameP35mscorlib_System_Reflection_Assembly($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2370792);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2375720|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z47mscorlib_System_Reflection_Assembly_m_IsDefinedP35mscorlib_System_Reflection_AssemblyP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2375768);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_Assembly_m_GetCustomAttributesP35mscorlib_System_Reflection_AssemblyP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2375816);
 __THREW__ = 0;
 $0 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z65mscorlib_System_Reflection_Assembly_m_GetManifestResourceInternalP35mscorlib_System_Reflection_AssemblyP22mscorlib_System_StringPiPP33mscorlib_System_Reflection_Module($__this,$name,$size,$module) {
 $__this = $__this|0;
 $name = $name|0;
 $size = $size|0;
 $module = $module|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2375864);
 $0 = HEAP32[2375912>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2375920|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2375912>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiii($7|0,($__this|0),($name|0),($size|0),($module|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Reflection_Assembly_m_GetType_mscorlib_System_Type_mscorlib_System_StringP35mscorlib_System_Reflection_AssemblyP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2376032);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(235,(2376080|0),($__this|0),($name|0),0,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker3I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsS1_E6InvokeEP10MethodInfoPvS5_bb($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z53mscorlib_System_Reflection_Assembly_m_InternalGetTypeP35mscorlib_System_Reflection_AssemblyP33mscorlib_System_Reflection_ModuleP22mscorlib_System_Stringbb($__this,$module,$name,$throwOnError,$ignoreCase) {
 $__this = $__this|0;
 $module = $module|0;
 $name = $name|0;
 $throwOnError = $throwOnError|0;
 $ignoreCase = $ignoreCase|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2376128);
 $0 = HEAP32[2376176>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2376184|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2376176>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiiii($7|0,($__this|0),($module|0),($name|0),($throwOnError|0),($ignoreCase|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z137mscorlib_System_Reflection_Assembly_m_GetType_mscorlib_System_Type_mscorlib_System_String_mscorlib_System_Boolean_mscorlib_System_BooleanP35mscorlib_System_Reflection_AssemblyP22mscorlib_System_Stringbb($__this,$name,$throwOnError,$ignoreCase) {
 $__this = $__this|0;
 $name = $name|0;
 $throwOnError = $throwOnError|0;
 $ignoreCase = $ignoreCase|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2376080);
 __THREW__ = 0;
 invoke_v(609);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1925,($7|0),(0|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3833,($7|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($name|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __THREW__ = 0;
    $16 = (invoke_ii(1816,($name|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = ($16|0)==(0);
     if (!($19)) {
      __THREW__ = 0;
      $31 = (invoke_iiiiii(111,($__this|0),(0|0),($name|0),($throwOnError|0),($ignoreCase|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($31|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_ii(3469,(2560072|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $25 = HEAP32[3030272>>2]|0;
       $26 = HEAP32[3030280>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($22|0),($25|0),($26|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        invoke_vi(3833,($22|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Reflection_Assembly_m_FillNameP22mscorlib_System_ObjectP35mscorlib_System_Reflection_AssemblyP39mscorlib_System_Reflection_AssemblyName($__this,$ass,$aname) {
 $__this = $__this|0;
 $ass = $ass|0;
 $aname = $aname|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2376304);
 $0 = HEAP32[2376352>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2376360|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2376352>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($ass|0),($aname|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z46mscorlib_System_Reflection_Assembly_m_ToStringP35mscorlib_System_Reflection_Assembly($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2375720);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $3 = (invoke_ii(2185,($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $3;
 $$0 = $3;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z58mscorlib_System_Reflection_Assembly_m_GetExecutingAssemblyP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2376504);
 $0 = HEAP32[2376552>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2376560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2376552>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker3I28mscorlib_System_IntPtrTraits17VoidPointerTraitsS1_S1_E6InvokeEPF22mscorlib_System_IntPtrPvS4_S4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2210080,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFPvS3_S3_S3_bbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 $11 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$6,$10)|0);
 STACKTOP = sp;return ($11|0);
}
function __Z66mscorlib_System_Reflection_Assembly_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2449664)|0);
 $10 = HEAP32[((2449664 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_Reflection_AssemblyCompanyAttribute_m__ctorP51mscorlib_System_Reflection_AssemblyCompanyAttributeP22mscorlib_System_String($__this,$company) {
 $__this = $__this|0;
 $company = $company|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2377720);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $company;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Reflection_AssemblyCompanyAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z65mscorlib_System_Reflection_AssemblyConfigurationAttribute_m__ctorP57mscorlib_System_Reflection_AssemblyConfigurationAttributeP22mscorlib_System_String($__this,$configuration) {
 $__this = $__this|0;
 $configuration = $configuration|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2378048);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $configuration;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z88mscorlib_System_Reflection_AssemblyConfigurationAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z61mscorlib_System_Reflection_AssemblyCopyrightAttribute_m__ctorP53mscorlib_System_Reflection_AssemblyCopyrightAttributeP22mscorlib_System_String($__this,$copyright) {
 $__this = $__this|0;
 $copyright = $copyright|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2378376);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $copyright;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Reflection_AssemblyCopyrightAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m__ctorP56mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP22mscorlib_System_String($__this,$defaultAlias) {
 $__this = $__this|0;
 $defaultAlias = $defaultAlias|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2378704);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $defaultAlias;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z87mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z61mscorlib_System_Reflection_AssemblyDelaySignAttribute_m__ctorP53mscorlib_System_Reflection_AssemblyDelaySignAttributeb($__this,$delaySign) {
 $__this = $__this|0;
 $delaySign = $delaySign|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2379032);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  $3 = $delaySign&1;
  HEAP8[$2>>0] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Reflection_AssemblyDelaySignAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_Reflection_AssemblyDescriptionAttribute_m__ctorP55mscorlib_System_Reflection_AssemblyDescriptionAttributeP22mscorlib_System_String($__this,$description) {
 $__this = $__this|0;
 $description = $description|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2392496);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $description;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z86mscorlib_System_Reflection_AssemblyDescriptionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_Reflection_AssemblyFileVersionAttribute_m__ctorP55mscorlib_System_Reflection_AssemblyFileVersionAttributeP22mscorlib_System_String($__this,$version) {
 $__this = $__this|0;
 $version = $version|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2392864);
 __THREW__ = 0;
 invoke_v(610);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1931,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = ($version|0)==(0|0);
   if (!($4)) {
    $17 = (($__this) + 8|0);
    HEAP32[$17>>2] = $version;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[3030336>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3834,($9|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception6636($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Reflection_AssemblyFileVersionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z72mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m__ctorP64mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP22mscorlib_System_String($__this,$informationalVersion) {
 $__this = $__this|0;
 $informationalVersion = $informationalVersion|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2393192);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $informationalVersion;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z95mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_Reflection_AssemblyKeyFileAttribute_m__ctorP51mscorlib_System_Reflection_AssemblyKeyFileAttributeP22mscorlib_System_String($__this,$keyFile) {
 $__this = $__this|0;
 $keyFile = $keyFile|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2393528);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $keyFile;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Reflection_AssemblyKeyFileAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_Reflection_AssemblyKeyNameAttribute_m__ctorP51mscorlib_System_Reflection_AssemblyKeyNameAttributeP22mscorlib_System_String($__this,$keyName) {
 $__this = $__this|0;
 $keyName = $keyName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2393856);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $keyName;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Reflection_AssemblyKeyNameAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z47mscorlib_System_Reflection_AssemblyName_m__ctorP39mscorlib_System_Reflection_AssemblyName($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2394184);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 40|0);
  HEAP32[$2>>2] = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50mscorlib_System_Reflection_AssemblyName_m_get_NameP39mscorlib_System_Reflection_AssemblyName($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2394232);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z53mscorlib_System_Reflection_AssemblyName_m_get_VersionP39mscorlib_System_Reflection_AssemblyName($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2394280);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z50mscorlib_System_Reflection_AssemblyName_m_ToStringP39mscorlib_System_Reflection_AssemblyName($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2394328);
 __THREW__ = 0;
 invoke_v(611);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3030368>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iiii(420,(0|0),($__this|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if (!($6)) {
    $G_B3_0$0 = $3;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
   __THREW__ = 0;
   $9 = (invoke_ii(1784,($__this|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $G_B3_0$0 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_AssemblyName_m_SetPublicKeyP39mscorlib_System_Reflection_AssemblyNameP24mscorlib_System_Byte_arr($__this,$publicKey) {
 $__this = $__this|0;
 $publicKey = $publicKey|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2394376);
 $0 = ($publicKey|0)==(0|0);
 if ($0) {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   $3 = (($__this) + 20|0);
   $4 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = $4 ^ 1;
    HEAP32[$3>>2] = $7;
    $17 = (($__this) + 32|0);
    HEAP32[$17>>2] = $publicKey;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = (($__this) + 20|0);
   $13 = HEAP32[$12>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = $13 | 1;
    HEAP32[$12>>2] = $16;
    $17 = (($__this) + 32|0);
    HEAP32[$17>>2] = $publicKey;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z59mscorlib_System_Reflection_AssemblyName_m_SetPublicKeyTokenP39mscorlib_System_Reflection_AssemblyNameP24mscorlib_System_Byte_arr($__this,$publicKeyToken) {
 $__this = $__this|0;
 $publicKeyToken = $publicKeyToken|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2394424);
 $0 = (($__this) + 36|0);
 HEAP32[$0>>2] = $publicKeyToken;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_Reflection_AssemblyName_m_GetObjectDataP39mscorlib_System_Reflection_AssemblyNameP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $G_B5_0$0 = 0, $L_11 = 0, $L_14 = 0, $L_18 = 0, $L_21 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_11 = sp;
 $L_14 = sp + 4|0;
 $L_18 = sp + 8|0;
 $L_21 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2394472);
 __THREW__ = 0;
 invoke_v(612);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3030504>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3834,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3030512>>2]|0;
    __THREW__ = 0;
    invoke_viii(621,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 32|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[3030520>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($26|0),($23|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = (($__this) + 36|0);
       $30 = HEAP32[$29>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($info|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        $33 = HEAP32[3030528>>2]|0;
        __THREW__ = 0;
        invoke_viii(621,($info|0),($33|0),($30|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if (!($35)) {
         $36 = (($__this) + 16|0);
         $37 = HEAP32[$36>>2]|0;
         $38 = HEAP32[3030536>>2]|0;
         $39 = ($37|0)==(0|0);
         if ($39) {
          $G_B5_0$0 = -1;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($37|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           break;
          }
          __THREW__ = 0;
          $42 = (invoke_iii(2729,(2273552|0),($37|0))|0);
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           break;
          } else {
           $G_B5_0$0 = $42;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($info|0));
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if (!($46)) {
          __THREW__ = 0;
          invoke_viii(618,($info|0),($38|0),($G_B5_0$0|0));
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if (!($48)) {
           $49 = (($__this) + 12|0);
           $50 = HEAP32[$49>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($info|0));
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            $53 = HEAP32[3030544>>2]|0;
            __THREW__ = 0;
            invoke_viii(621,($info|0),($53|0),($50|0));
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if (!($55)) {
             __THREW__ = 0;
             $56 = (invoke_ii(2190,($__this|0))|0);
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if (!($58)) {
              __THREW__ = 0;
              invoke_vi(3799,($info|0));
              $59 = __THREW__; __THREW__ = 0;
              $60 = $59&1;
              if (!($60)) {
               $61 = HEAP32[3030552>>2]|0;
               __THREW__ = 0;
               invoke_viii(621,($info|0),($61|0),($56|0));
               $62 = __THREW__; __THREW__ = 0;
               $63 = $62&1;
               if (!($63)) {
                $64 = (($__this) + 24|0);
                $65 = HEAP32[$64>>2]|0;
                HEAP32[$L_11>>2] = $65;
                __THREW__ = 0;
                (invoke_ii(2996,(2316496|0))|0);
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if (!($67)) {
                 __THREW__ = 0;
                 $68 = (invoke_iii(2724,(2316496|0),($L_11|0))|0);
                 $69 = __THREW__; __THREW__ = 0;
                 $70 = $69&1;
                 if (!($70)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($info|0));
                  $71 = __THREW__; __THREW__ = 0;
                  $72 = $71&1;
                  if (!($72)) {
                   $73 = HEAP32[3030560>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(621,($info|0),($73|0),($68|0));
                   $74 = __THREW__; __THREW__ = 0;
                   $75 = $74&1;
                   if ($75) {
                    break;
                   }
                   HEAP32[$L_14>>2] = 0;
                   __THREW__ = 0;
                   (invoke_ii(2996,(2316496|0))|0);
                   $76 = __THREW__; __THREW__ = 0;
                   $77 = $76&1;
                   if ($77) {
                    break;
                   }
                   __THREW__ = 0;
                   $78 = (invoke_iii(2724,(2316496|0),($L_14|0))|0);
                   $79 = __THREW__; __THREW__ = 0;
                   $80 = $79&1;
                   if ($80) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($info|0));
                   $81 = __THREW__; __THREW__ = 0;
                   $82 = $81&1;
                   if ($82) {
                    break;
                   }
                   $83 = HEAP32[3030568>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(621,($info|0),($83|0),($78|0));
                   $84 = __THREW__; __THREW__ = 0;
                   $85 = $84&1;
                   if ($85) {
                    break;
                   }
                   $86 = (($__this) + 28|0);
                   $87 = HEAP32[$86>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($info|0));
                   $88 = __THREW__; __THREW__ = 0;
                   $89 = $88&1;
                   if ($89) {
                    break;
                   }
                   $90 = HEAP32[3030576>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(621,($info|0),($90|0),($87|0));
                   $91 = __THREW__; __THREW__ = 0;
                   $92 = $91&1;
                   if ($92) {
                    break;
                   }
                   $93 = (($__this) + 40|0);
                   $94 = HEAP32[$93>>2]|0;
                   HEAP32[$L_18>>2] = $94;
                   __THREW__ = 0;
                   (invoke_ii(2996,(2317000|0))|0);
                   $95 = __THREW__; __THREW__ = 0;
                   $96 = $95&1;
                   if ($96) {
                    break;
                   }
                   __THREW__ = 0;
                   $97 = (invoke_iii(2724,(2317000|0),($L_18|0))|0);
                   $98 = __THREW__; __THREW__ = 0;
                   $99 = $98&1;
                   if ($99) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($info|0));
                   $100 = __THREW__; __THREW__ = 0;
                   $101 = $100&1;
                   if ($101) {
                    break;
                   }
                   $102 = HEAP32[3030584>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(621,($info|0),($102|0),($97|0));
                   $103 = __THREW__; __THREW__ = 0;
                   $104 = $103&1;
                   if ($104) {
                    break;
                   }
                   $105 = (($__this) + 20|0);
                   $106 = HEAP32[$105>>2]|0;
                   HEAP32[$L_21>>2] = $106;
                   __THREW__ = 0;
                   (invoke_ii(2996,(2395880|0))|0);
                   $107 = __THREW__; __THREW__ = 0;
                   $108 = $107&1;
                   if ($108) {
                    break;
                   }
                   __THREW__ = 0;
                   $109 = (invoke_iii(2724,(2395880|0),($L_21|0))|0);
                   $110 = __THREW__; __THREW__ = 0;
                   $111 = $110&1;
                   if ($111) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($info|0));
                   $112 = __THREW__; __THREW__ = 0;
                   $113 = $112&1;
                   if ($113) {
                    break;
                   }
                   $114 = HEAP32[3030592>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(621,($info|0),($114|0),($109|0));
                   $115 = __THREW__; __THREW__ = 0;
                   $116 = $115&1;
                   if ($116) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($info|0));
                   $117 = __THREW__; __THREW__ = 0;
                   $118 = $117&1;
                   if ($118) {
                    break;
                   }
                   $119 = HEAP32[3030600>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(621,($info|0),($119|0),(0|0));
                   $120 = __THREW__; __THREW__ = 0;
                   $121 = $120&1;
                   if ($121) {
                    break;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z70mscorlib_System_Reflection_AssemblyName_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2450104)|0);
 $10 = HEAP32[((2450104 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($__this,$classInterfaceType) {
 $__this = $__this|0;
 $classInterfaceType = $classInterfaceType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2442952);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $classInterfaceType;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($__this,$defaultInterface) {
 $__this = $__this|0;
 $defaultInterface = $defaultInterface|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2443792);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $defaultInterface;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z75mscorlib_System_Reflection_AssemblyNameFlags_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_Reflection_AssemblyProductAttribute_m__ctorP51mscorlib_System_Reflection_AssemblyProductAttributeP22mscorlib_System_String($__this,$product) {
 $__this = $__this|0;
 $product = $product|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2396016);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $product;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Reflection_AssemblyProductAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z57mscorlib_System_Reflection_AssemblyTitleAttribute_m__ctorP49mscorlib_System_Reflection_AssemblyTitleAttributeP22mscorlib_System_String($__this,$title) {
 $__this = $__this|0;
 $title = $title|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2396344);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $title;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z80mscorlib_System_Reflection_AssemblyTitleAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z61mscorlib_System_Reflection_AssemblyTrademarkAttribute_m__ctorP53mscorlib_System_Reflection_AssemblyTrademarkAttributeP22mscorlib_System_String($__this,$trademark) {
 $__this = $__this|0;
 $trademark = $trademark|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2396664);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $trademark;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z84mscorlib_System_Reflection_AssemblyTrademarkAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z49mscorlib_System_Reflection_Binder_Default_m__ctorP41mscorlib_System_Reflection_Binder_Default($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2396992);
 __THREW__ = 0;
 invoke_vi(2282,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z41mscorlib_System_Reflection_Binder_m__ctorP33mscorlib_System_Reflection_Binder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2399200);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56mscorlib_System_Reflection_Binder_Default_m_BindToMethodP41mscorlib_System_Reflection_Binder_DefaultiP41mscorlib_System_Reflection_MethodBase_arrPP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arrPP22mscorlib_System_Object($__this,$bindingAttr,$match,$args,$modifiers,$culture,$names,$state) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $match = $match|0;
 $args = $args|0;
 $modifiers = $modifiers|0;
 $culture = $culture|0;
 $names = $names|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397040);
 $0 = HEAP32[$args>>2]|0;
 $1 = ($0|0)==(0|0);
 L1: do {
  if ($1) {
   __THREW__ = 0;
   (invoke_ii(2996,(2242320|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2242320 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3835,(2242320|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2242320|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[((2242320 + 80|0))>>2]|0;
     $19 = (($18) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     $V_0$0 = $20;
     label = 36;
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $23 = (($0) + 12|0);
    $24 = HEAP32[$23>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(1169184|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_iii(2760,(1169184|0),($24|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = (($27) + 16|0);
      $31 = (($27) + 12|0);
      $V_1$0 = 0;
      while(1) {
       $89 = HEAP32[$args>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($89|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        break;
       }
       $92 = (($89) + 12|0);
       $93 = HEAP32[$92>>2]|0;
       $94 = ($V_1$0|0)<($93|0);
       if (!($94)) {
        $V_0$0 = $27;
        label = 36;
        break L1;
       }
       $33 = HEAP32[$args>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($33|0));
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        break;
       }
       $32 = (($33) + 12|0);
       $34 = HEAP32[$32>>2]|0;
       $35 = ($V_1$0>>>0)<($34>>>0);
       if (!($35)) {
        __THREW__ = 0;
        $36 = (invoke_i(132)|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($36|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
       }
       $41 = HEAP32[$33>>2]|0;
       $42 = (($33) + 16|0);
       $43 = (($41) + 92|0);
       $44 = HEAP32[$43>>2]|0;
       $45 = Math_imul($44, $V_1$0)|0;
       $46 = (($42) + ($45)|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = ($47|0)==(0|0);
       if (!($48)) {
        $49 = HEAP32[$args>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($49|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        $52 = (($49) + 12|0);
        $53 = HEAP32[$52>>2]|0;
        $54 = ($V_1$0>>>0)<($53>>>0);
        if (!($54)) {
         __THREW__ = 0;
         $55 = (invoke_i(132)|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($55|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          break;
         }
        }
        $60 = HEAP32[$49>>2]|0;
        $61 = (($49) + 16|0);
        $62 = (($60) + 92|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = Math_imul($63, $V_1$0)|0;
        $65 = (($61) + ($64)|0);
        $66 = HEAP32[$65>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($66|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        __THREW__ = 0;
        $69 = (invoke_ii(1782,($66|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($27|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         break;
        }
        $74 = HEAP32[$31>>2]|0;
        $75 = ($V_1$0>>>0)<($74>>>0);
        if (!($75)) {
         __THREW__ = 0;
         $76 = (invoke_i(132)|0);
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($76|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($27|0),($69|0));
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         break;
        }
        $83 = HEAP32[$27>>2]|0;
        $84 = (($83) + 92|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = Math_imul($85, $V_1$0)|0;
        $87 = (($30) + ($86)|0);
        HEAP32[$87>>2] = $69;
       }
       $88 = (($V_1$0) + 1)|0;
       $V_1$0 = $88;
      }
      $12 = ___cxa_find_matching_catch()|0;
      $13 = tempRet0;
      $lpad$phi$index = $12;$lpad$phi$index2 = $13;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 36) {
  __THREW__ = 0;
  $97 = (invoke_iiiiiii(72,($__this|0),($bindingAttr|0),($match|0),($V_0$0|0),0,1)|0);
  $98 = __THREW__; __THREW__ = 0;
  $99 = $98&1;
  if (!($99)) {
   HEAP32[$state>>2] = 0;
   $100 = ($names|0)==(0|0);
   if ($100) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($97|0);
   }
   __THREW__ = 0;
   invoke_viiii(159,0,($names|0),($args|0),($97|0));
   $101 = __THREW__; __THREW__ = 0;
   $102 = $101&1;
   if (!($102)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($97|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL11RuntimeInitP8TypeInfo6649($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __ZL10SZArrayNewP8TypeInfoj6650($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z286mscorlib_System_Reflection_Binder_Default_m_SelectMethod_mscorlib_System_Reflection_MethodBase_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_MethodBase_arr_arr_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arr_mscorlib_System_BooleanP41mscorlib_System_Reflection_Binder_DefaultiP41mscorlib_System_Reflection_MethodBase_arrP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arrb($__this,$bindingAttr,$match,$types,$modifiers,$allowByRefMatch) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $match = $match|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 $allowByRefMatch = $allowByRefMatch|0;
 var $$0 = 0, $$byval_copy = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $V_1$0 = 0, $V_1$1 = 0, $V_1$2 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_7$0 = 0, $V_7$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397568);
 __THREW__ = 0;
 invoke_v(613);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($match|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3030968>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3834,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $4 = (($match) + 12|0);
   $5 = (($match) + 16|0);
   $6 = (($types) + 12|0);
   $7 = (($types) + 16|0);
   $V_1$0 = 0;
   L10: while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($match|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 8;
     break;
    }
    $104 = HEAP32[$4>>2]|0;
    $105 = ($V_1$0|0)<($104|0);
    if (!($105)) {
     label = 43;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($match|0));
    $106 = __THREW__; __THREW__ = 0;
    $107 = $106&1;
    if ($107) {
     label = 8;
     break;
    }
    $30 = HEAP32[$4>>2]|0;
    $31 = ($V_1$0>>>0)<($30>>>0);
    if (!($31)) {
     __THREW__ = 0;
     $32 = (invoke_i(132)|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      label = 8;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($32|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      label = 8;
      break;
     }
    }
    $37 = HEAP32[$match>>2]|0;
    $38 = (($37) + 92|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = Math_imul($39, $V_1$0)|0;
    $41 = (($5) + ($40)|0);
    $42 = HEAP32[$41>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($42|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     label = 8;
     break;
    }
    __THREW__ = 0;
    $45 = (invoke_iii(2730,(2397136|0),($42|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     label = 8;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($45|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     label = 8;
     break;
    }
    $50 = (($45) + 12|0);
    $51 = HEAP32[$50>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($types|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 8;
     break;
    }
    $54 = HEAP32[$6>>2]|0;
    $55 = ($51|0)==($54|0);
    if ($55) {
     $V_2$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($types|0));
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       label = 7;
       break L10;
      }
      $93 = HEAP32[$6>>2]|0;
      $94 = ($V_2$0|0)<($93|0);
      if (!($94)) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($types|0));
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 7;
       break L10;
      }
      $56 = HEAP32[$6>>2]|0;
      $57 = ($V_2$0>>>0)<($56>>>0);
      if (!($57)) {
       __THREW__ = 0;
       $58 = (invoke_i(132)|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        label = 7;
        break L10;
       }
       __THREW__ = 0;
       invoke_vi(3302,($58|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        label = 7;
        break L10;
       }
      }
      $63 = HEAP32[$types>>2]|0;
      $64 = (($63) + 92|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $V_2$0)|0;
      $67 = (($7) + ($66)|0);
      $68 = HEAP32[$67>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($45|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 7;
       break L10;
      }
      $71 = HEAP32[$50>>2]|0;
      $72 = ($V_2$0>>>0)<($71>>>0);
      if (!($72)) {
       __THREW__ = 0;
       $73 = (invoke_i(132)|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        label = 7;
        break L10;
       }
       __THREW__ = 0;
       invoke_vi(3302,($73|0));
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        label = 7;
        break L10;
       }
      }
      $78 = HEAP32[$45>>2]|0;
      $79 = (($78) + 92|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = Math_imul($80, $V_2$0)|0;
      $$sum3 = (($81) + 16)|0;
      $82 = (($45) + ($$sum3)|0);
      $83 = HEAP32[$82>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($83|0));
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if ($85) {
       label = 7;
       break L10;
      }
      __THREW__ = 0;
      $86 = (invoke_iii(2730,(2397472|0),($83|0))|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       label = 7;
       break L10;
      }
      $89 = ($68|0)==($86|0);
      $90 = (($V_2$0) + 1)|0;
      if ($89) {
       $V_2$0 = $90;
      } else {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($types|0));
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      label = 8;
      break;
     }
     $99 = HEAP32[$6>>2]|0;
     $100 = ($V_2$0|0)==($99|0);
     if ($100) {
      $$0 = $42;
      label = 121;
      break;
     }
    }
    $101 = (($V_1$0) + 1)|0;
    $V_1$0 = $101;
   }
   if ((label|0) == 7) {
    $14 = ___cxa_find_matching_catch()|0;
    $15 = tempRet0;
    $lpad$phi$index = $14;$lpad$phi$index6 = $15;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 8) {
    $16 = ___cxa_find_matching_catch()|0;
    $17 = tempRet0;
    $lpad$phi$index = $16;$lpad$phi$index6 = $17;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 43) {
    $V_1$1 = 0;
    L46: while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($match|0));
     $266 = __THREW__; __THREW__ = 0;
     $267 = $266&1;
     if ($267) {
      label = 6;
      break;
     }
     $268 = HEAP32[$4>>2]|0;
     $269 = ($V_1$1|0)<($268|0);
     if (!($269)) {
      label = 104;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($match|0));
     $270 = __THREW__; __THREW__ = 0;
     $271 = $270&1;
     if ($271) {
      label = 6;
      break;
     }
     $108 = HEAP32[$4>>2]|0;
     $109 = ($V_1$1>>>0)<($108>>>0);
     if (!($109)) {
      __THREW__ = 0;
      $110 = (invoke_i(132)|0);
      $111 = __THREW__; __THREW__ = 0;
      $112 = $111&1;
      if ($112) {
       label = 6;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($110|0));
      $113 = __THREW__; __THREW__ = 0;
      $114 = $113&1;
      if ($114) {
       label = 6;
       break;
      }
     }
     $115 = HEAP32[$match>>2]|0;
     $116 = (($115) + 92|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = Math_imul($117, $V_1$1)|0;
     $119 = (($5) + ($118)|0);
     $120 = HEAP32[$119>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($120|0));
     $121 = __THREW__; __THREW__ = 0;
     $122 = $121&1;
     if ($122) {
      label = 6;
      break;
     }
     __THREW__ = 0;
     $123 = (invoke_iii(2730,(2397136|0),($120|0))|0);
     $124 = __THREW__; __THREW__ = 0;
     $125 = $124&1;
     if ($125) {
      label = 6;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($123|0));
     $126 = __THREW__; __THREW__ = 0;
     $127 = $126&1;
     if ($127) {
      label = 6;
      break;
     }
     $128 = (($123) + 12|0);
     $129 = HEAP32[$128>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($types|0));
     $130 = __THREW__; __THREW__ = 0;
     $131 = $130&1;
     if ($131) {
      label = 6;
      break;
     }
     $132 = HEAP32[$6>>2]|0;
     $133 = ($129|0)>($132|0);
     do {
      if (!($133)) {
       __THREW__ = 0;
       invoke_vi(3799,($123|0));
       $134 = __THREW__; __THREW__ = 0;
       $135 = $134&1;
       if ($135) {
        label = 6;
        break L46;
       }
       $136 = HEAP32[$128>>2]|0;
       $137 = ($136|0)==(0);
       if (!($137)) {
        __THREW__ = 0;
        invoke_vi(3799,($123|0));
        $138 = __THREW__; __THREW__ = 0;
        $139 = $138&1;
        if ($139) {
         label = 6;
         break L46;
        }
        $140 = HEAP32[$128>>2]|0;
        $141 = (($140) + -1)|0;
        __THREW__ = 0;
        invoke_vi(3799,($123|0));
        $142 = __THREW__; __THREW__ = 0;
        $143 = $142&1;
        if ($143) {
         label = 6;
         break L46;
        }
        $144 = ($140|0)<(1);
        if ($144) {
         label = 59;
        } else {
         $145 = HEAP32[$128>>2]|0;
         $146 = ($141>>>0)<($145>>>0);
         if (!($146)) {
          label = 59;
         }
        }
        if ((label|0) == 59) {
         label = 0;
         __THREW__ = 0;
         $147 = (invoke_i(132)|0);
         $148 = __THREW__; __THREW__ = 0;
         $149 = $148&1;
         if ($149) {
          label = 6;
          break L46;
         }
         __THREW__ = 0;
         invoke_vi(3302,($147|0));
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          label = 6;
          break L46;
         }
        }
        $152 = HEAP32[$123>>2]|0;
        $153 = (($152) + 92|0);
        $154 = HEAP32[$153>>2]|0;
        $155 = Math_imul($154, $141)|0;
        $$sum = (($155) + 16)|0;
        $156 = (($123) + ($$sum)|0);
        $157 = HEAP32[$156>>2]|0;
        HEAP32[$0>>2] = 2093160;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        $158 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
        $159 = __THREW__; __THREW__ = 0;
        $160 = $159&1;
        if ($160) {
         label = 6;
         break L46;
        }
        __THREW__ = 0;
        $161 = (invoke_iiii(431,(0|0),($157|0),($158|0))|0);
        $162 = __THREW__; __THREW__ = 0;
        $163 = $162&1;
        if ($163) {
         label = 6;
         break L46;
        }
        if (!($161)) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($123|0));
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if ($165) {
         label = 6;
         break L46;
        }
        $166 = HEAP32[$128>>2]|0;
        $167 = (($166) + -1)|0;
        __THREW__ = 0;
        invoke_vi(3799,($123|0));
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         label = 6;
         break L46;
        }
        $170 = ($166|0)<(1);
        if ($170) {
         label = 68;
        } else {
         $171 = HEAP32[$128>>2]|0;
         $172 = ($167>>>0)<($171>>>0);
         if (!($172)) {
          label = 68;
         }
        }
        if ((label|0) == 68) {
         label = 0;
         __THREW__ = 0;
         $173 = (invoke_i(132)|0);
         $174 = __THREW__; __THREW__ = 0;
         $175 = $174&1;
         if ($175) {
          label = 6;
          break L46;
         }
         __THREW__ = 0;
         invoke_vi(3302,($173|0));
         $176 = __THREW__; __THREW__ = 0;
         $177 = $176&1;
         if ($177) {
          label = 6;
          break L46;
         }
        }
        $178 = HEAP32[$123>>2]|0;
        $179 = (($178) + 92|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = Math_imul($180, $167)|0;
        $$sum1 = (($181) + 16)|0;
        $182 = (($123) + ($$sum1)|0);
        $183 = HEAP32[$182>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($183|0));
        $184 = __THREW__; __THREW__ = 0;
        $185 = $184&1;
        if ($185) {
         label = 6;
         break L46;
        }
        __THREW__ = 0;
        $186 = (invoke_iii(2730,(2397472|0),($183|0))|0);
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         label = 6;
         break L46;
        }
        __THREW__ = 0;
        invoke_vi(3799,($186|0));
        $189 = __THREW__; __THREW__ = 0;
        $190 = $189&1;
        if ($190) {
         label = 6;
         break L46;
        }
        __THREW__ = 0;
        $191 = (invoke_iii(2730,(2224328|0),($186|0))|0);
        $192 = __THREW__; __THREW__ = 0;
        $193 = $192&1;
        if ($193) {
         label = 6;
         break L46;
        }
        $V_2$1 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($types|0));
         $255 = __THREW__; __THREW__ = 0;
         $256 = $255&1;
         if ($256) {
          label = 5;
          break L46;
         }
         $257 = HEAP32[$6>>2]|0;
         $258 = ($V_2$1|0)<($257|0);
         if (!($258)) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($123|0));
         $259 = __THREW__; __THREW__ = 0;
         $260 = $259&1;
         if ($260) {
          label = 5;
          break L46;
         }
         $194 = HEAP32[$128>>2]|0;
         $195 = (($194) + -1)|0;
         $196 = ($V_2$1|0)<($195|0);
         if ($196) {
          __THREW__ = 0;
          invoke_vi(3799,($types|0));
          $197 = __THREW__; __THREW__ = 0;
          $198 = $197&1;
          if ($198) {
           label = 5;
           break L46;
          }
          $199 = HEAP32[$6>>2]|0;
          $200 = ($V_2$1>>>0)<($199>>>0);
          if (!($200)) {
           __THREW__ = 0;
           $201 = (invoke_i(132)|0);
           $202 = __THREW__; __THREW__ = 0;
           $203 = $202&1;
           if ($203) {
            label = 5;
            break L46;
           }
           __THREW__ = 0;
           invoke_vi(3302,($201|0));
           $204 = __THREW__; __THREW__ = 0;
           $205 = $204&1;
           if ($205) {
            label = 5;
            break L46;
           }
          }
          $206 = HEAP32[$types>>2]|0;
          $207 = (($206) + 92|0);
          $208 = HEAP32[$207>>2]|0;
          $209 = Math_imul($208, $V_2$1)|0;
          $210 = (($7) + ($209)|0);
          $211 = HEAP32[$210>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($123|0));
          $212 = __THREW__; __THREW__ = 0;
          $213 = $212&1;
          if ($213) {
           label = 5;
           break L46;
          }
          $214 = HEAP32[$128>>2]|0;
          $215 = ($V_2$1>>>0)<($214>>>0);
          if (!($215)) {
           __THREW__ = 0;
           $216 = (invoke_i(132)|0);
           $217 = __THREW__; __THREW__ = 0;
           $218 = $217&1;
           if ($218) {
            label = 5;
            break L46;
           }
           __THREW__ = 0;
           invoke_vi(3302,($216|0));
           $219 = __THREW__; __THREW__ = 0;
           $220 = $219&1;
           if ($220) {
            label = 5;
            break L46;
           }
          }
          $221 = HEAP32[$123>>2]|0;
          $222 = (($221) + 92|0);
          $223 = HEAP32[$222>>2]|0;
          $224 = Math_imul($223, $V_2$1)|0;
          $$sum2 = (($224) + 16)|0;
          $225 = (($123) + ($$sum2)|0);
          $226 = HEAP32[$225>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($226|0));
          $227 = __THREW__; __THREW__ = 0;
          $228 = $227&1;
          if ($228) {
           label = 5;
           break L46;
          }
          __THREW__ = 0;
          $229 = (invoke_iii(2730,(2397472|0),($226|0))|0);
          $230 = __THREW__; __THREW__ = 0;
          $231 = $230&1;
          if ($231) {
           label = 5;
           break L46;
          }
          $232 = ($211|0)==($229|0);
          if (!($232)) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($123|0));
         $233 = __THREW__; __THREW__ = 0;
         $234 = $233&1;
         if ($234) {
          label = 5;
          break L46;
         }
         $235 = HEAP32[$128>>2]|0;
         $236 = (($235) + -1)|0;
         $237 = ($V_2$1|0)<($236|0);
         if (!($237)) {
          __THREW__ = 0;
          invoke_vi(3799,($types|0));
          $238 = __THREW__; __THREW__ = 0;
          $239 = $238&1;
          if ($239) {
           label = 5;
           break L46;
          }
          $240 = HEAP32[$6>>2]|0;
          $241 = ($V_2$1>>>0)<($240>>>0);
          if (!($241)) {
           __THREW__ = 0;
           $242 = (invoke_i(132)|0);
           $243 = __THREW__; __THREW__ = 0;
           $244 = $243&1;
           if ($244) {
            label = 5;
            break L46;
           }
           __THREW__ = 0;
           invoke_vi(3302,($242|0));
           $245 = __THREW__; __THREW__ = 0;
           $246 = $245&1;
           if ($246) {
            label = 5;
            break L46;
           }
          }
          $247 = HEAP32[$types>>2]|0;
          $248 = (($247) + 92|0);
          $249 = HEAP32[$248>>2]|0;
          $250 = Math_imul($249, $V_2$1)|0;
          $251 = (($7) + ($250)|0);
          $252 = HEAP32[$251>>2]|0;
          $253 = ($252|0)==($191|0);
          if (!($253)) {
           break;
          }
         }
         $254 = (($V_2$1) + 1)|0;
         $V_2$1 = $254;
        }
        __THREW__ = 0;
        invoke_vi(3799,($types|0));
        $261 = __THREW__; __THREW__ = 0;
        $262 = $261&1;
        if ($262) {
         label = 6;
         break L46;
        }
        $263 = HEAP32[$6>>2]|0;
        $264 = ($V_2$1|0)==($263|0);
        if ($264) {
         $$0 = $120;
         label = 121;
         break L46;
        }
       }
      }
     } while(0);
     $265 = (($V_1$1) + 1)|0;
     $V_1$1 = $265;
    }
    if ((label|0) == 5) {
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index6 = $11;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 6) {
     $12 = ___cxa_find_matching_catch()|0;
     $13 = tempRet0;
     $lpad$phi$index = $12;$lpad$phi$index6 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 104) {
     $272 = $bindingAttr & 65536;
     $273 = ($272|0)==(0);
     if ($273) {
      $V_1$2 = 0;$V_7$1 = 0;
     } else {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($match|0));
      $308 = __THREW__; __THREW__ = 0;
      $309 = $308&1;
      if ($309) {
       break;
      }
      $310 = HEAP32[$4>>2]|0;
      $311 = ($V_1$2|0)<($310|0);
      if (!($311)) {
       $$0 = $V_7$1;
       label = 121;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($match|0));
      $312 = __THREW__; __THREW__ = 0;
      $313 = $312&1;
      if ($313) {
       break;
      }
      $274 = HEAP32[$4>>2]|0;
      $275 = ($V_1$2>>>0)<($274>>>0);
      if (!($275)) {
       __THREW__ = 0;
       $276 = (invoke_i(132)|0);
       $277 = __THREW__; __THREW__ = 0;
       $278 = $277&1;
       if ($278) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($276|0));
       $279 = __THREW__; __THREW__ = 0;
       $280 = $279&1;
       if ($280) {
        break;
       }
      }
      $281 = HEAP32[$match>>2]|0;
      $282 = (($281) + 92|0);
      $283 = HEAP32[$282>>2]|0;
      $284 = Math_imul($283, $V_1$2)|0;
      $285 = (($5) + ($284)|0);
      $286 = HEAP32[$285>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($286|0));
      $287 = __THREW__; __THREW__ = 0;
      $288 = $287&1;
      if ($288) {
       break;
      }
      __THREW__ = 0;
      $289 = (invoke_iii(2730,(2397136|0),($286|0))|0);
      $290 = __THREW__; __THREW__ = 0;
      $291 = $290&1;
      if ($291) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($289|0));
      $292 = __THREW__; __THREW__ = 0;
      $293 = $292&1;
      if ($293) {
       break;
      }
      $294 = (($289) + 12|0);
      $295 = HEAP32[$294>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($types|0));
      $296 = __THREW__; __THREW__ = 0;
      $297 = $296&1;
      if ($297) {
       break;
      }
      $298 = HEAP32[$6>>2]|0;
      $299 = ($295|0)==($298|0);
      if ($299) {
       __THREW__ = 0;
       $300 = (invoke_iiiii(140,0,($types|0),($289|0),($allowByRefMatch|0))|0);
       $301 = __THREW__; __THREW__ = 0;
       $302 = $301&1;
       if ($302) {
        break;
       }
       if ($300) {
        $303 = ($V_7$1|0)==(0|0);
        if ($303) {
         $V_7$0 = $286;
        } else {
         __THREW__ = 0;
         $304 = (invoke_iiiii(141,($__this|0),($V_7$1|0),($286|0),0)|0);
         $305 = __THREW__; __THREW__ = 0;
         $306 = $305&1;
         if ($306) {
          break;
         } else {
          $V_7$0 = $304;
         }
        }
       } else {
        $V_7$0 = $V_7$1;
       }
      } else {
       $V_7$0 = $V_7$1;
      }
      $307 = (($V_1$2) + 1)|0;
      $V_1$2 = $307;$V_7$1 = $V_7$0;
     }
     if ((label|0) == 121) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $8 = ___cxa_find_matching_catch()|0;
     $9 = tempRet0;
     $lpad$phi$index = $8;$lpad$phi$index6 = $9;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 121) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   else if ((label|0) == 121) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 $lpad$phi$index = $18;$lpad$phi$index6 = $19;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Binder_Default_m_ReorderParametersP41mscorlib_System_Reflection_Binder_DefaultP26mscorlib_System_String_arrPP26mscorlib_System_Object_arrP37mscorlib_System_Reflection_MethodBase($__this,$names,$args,$selected) {
 $__this = $__this|0;
 $names = $names|0;
 $args = $args|0;
 $selected = $selected|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397088);
 $0 = HEAP32[$args>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = (($0) + 12|0);
   $4 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2760,(1167664|0),($4|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[$args>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = (($10) + 12|0);
      $14 = HEAP32[$13>>2]|0;
      __THREW__ = 0;
      invoke_viiii(140,(0|0),($10|0),($7|0),($14|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3799,($selected|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        $19 = (invoke_iii(2730,(2397136|0),($selected|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         $22 = (($names) + 12|0);
         $23 = (($19) + 12|0);
         $24 = (($names) + 16|0);
         $25 = (($7) + 16|0);
         $26 = (($7) + 12|0);
         $V_2$0 = 0;
         L9: while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($names|0));
          $111 = __THREW__; __THREW__ = 0;
          $112 = $111&1;
          if ($112) {
           label = 10;
           break;
          }
          $113 = HEAP32[$22>>2]|0;
          $114 = ($V_2$0|0)<($113|0);
          if ($114) {
           $V_3$0 = 0;
          } else {
           label = 40;
           break;
          }
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($19|0));
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            label = 9;
            break L9;
           }
           $106 = HEAP32[$23>>2]|0;
           $107 = ($V_3$0|0)<($106|0);
           if (!($107)) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($names|0));
           $108 = __THREW__; __THREW__ = 0;
           $109 = $108&1;
           if ($109) {
            label = 9;
            break L9;
           }
           $33 = HEAP32[$22>>2]|0;
           $34 = ($V_2$0>>>0)<($33>>>0);
           if (!($34)) {
            __THREW__ = 0;
            $35 = (invoke_i(132)|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if ($37) {
             label = 9;
             break L9;
            }
            __THREW__ = 0;
            invoke_vi(3302,($35|0));
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             label = 9;
             break L9;
            }
           }
           $40 = HEAP32[$names>>2]|0;
           $41 = (($40) + 92|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = Math_imul($42, $V_2$0)|0;
           $44 = (($24) + ($43)|0);
           $45 = HEAP32[$44>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($19|0));
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if ($47) {
            label = 9;
            break L9;
           }
           $48 = HEAP32[$23>>2]|0;
           $49 = ($V_3$0>>>0)<($48>>>0);
           if (!($49)) {
            __THREW__ = 0;
            $50 = (invoke_i(132)|0);
            $51 = __THREW__; __THREW__ = 0;
            $52 = $51&1;
            if ($52) {
             label = 9;
             break L9;
            }
            __THREW__ = 0;
            invoke_vi(3302,($50|0));
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             label = 9;
             break L9;
            }
           }
           $55 = HEAP32[$19>>2]|0;
           $56 = (($55) + 92|0);
           $57 = HEAP32[$56>>2]|0;
           $58 = Math_imul($57, $V_3$0)|0;
           $$sum = (($58) + 16)|0;
           $59 = (($19) + ($$sum)|0);
           $60 = HEAP32[$59>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($60|0));
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            label = 9;
            break L9;
           }
           __THREW__ = 0;
           $63 = (invoke_iii(2730,(2397184|0),($60|0))|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 9;
            break L9;
           }
           __THREW__ = 0;
           $66 = (invoke_iiii(574,(0|0),($45|0),($63|0))|0);
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            label = 9;
            break L9;
           }
           $69 = (($V_3$0) + 1)|0;
           if ($66) {
            label = 24;
            break;
           } else {
            $V_3$0 = $69;
           }
          }
          if ((label|0) == 24) {
           label = 0;
           $70 = HEAP32[$args>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($70|0));
           $71 = __THREW__; __THREW__ = 0;
           $72 = $71&1;
           if ($72) {
            label = 10;
            break;
           }
           $73 = (($70) + 12|0);
           $74 = HEAP32[$73>>2]|0;
           $75 = ($V_2$0>>>0)<($74>>>0);
           if (!($75)) {
            __THREW__ = 0;
            $76 = (invoke_i(132)|0);
            $77 = __THREW__; __THREW__ = 0;
            $78 = $77&1;
            if ($78) {
             label = 10;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($76|0));
            $79 = __THREW__; __THREW__ = 0;
            $80 = $79&1;
            if ($80) {
             label = 10;
             break;
            }
           }
           $81 = HEAP32[$70>>2]|0;
           $82 = (($70) + 16|0);
           $83 = (($81) + 92|0);
           $84 = HEAP32[$83>>2]|0;
           $85 = Math_imul($84, $V_2$0)|0;
           $86 = (($82) + ($85)|0);
           $87 = HEAP32[$86>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($7|0));
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            label = 10;
            break;
           }
           $90 = HEAP32[$26>>2]|0;
           $91 = ($V_3$0>>>0)<($90>>>0);
           if (!($91)) {
            __THREW__ = 0;
            $92 = (invoke_i(132)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             label = 10;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($92|0));
            $95 = __THREW__; __THREW__ = 0;
            $96 = $95&1;
            if ($96) {
             label = 10;
             break;
            }
           }
           __THREW__ = 0;
           invoke_vii(3492,($7|0),($87|0));
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if ($98) {
            label = 10;
            break;
           }
           $99 = HEAP32[$7>>2]|0;
           $100 = (($99) + 92|0);
           $101 = HEAP32[$100>>2]|0;
           $102 = Math_imul($101, $V_3$0)|0;
           $103 = (($25) + ($102)|0);
           HEAP32[$103>>2] = $87;
          }
          $110 = (($V_2$0) + 1)|0;
          $V_2$0 = $110;
         }
         if ((label|0) == 9) {
          $27 = ___cxa_find_matching_catch()|0;
          $28 = tempRet0;
          $lpad$phi$index = $27;$lpad$phi$index3 = $28;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 10) {
          $29 = ___cxa_find_matching_catch()|0;
          $30 = tempRet0;
          $lpad$phi$index = $29;$lpad$phi$index3 = $30;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 40) {
          $115 = HEAP32[$args>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($115|0));
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           break;
          }
          $118 = (($115) + 12|0);
          $119 = HEAP32[$118>>2]|0;
          __THREW__ = 0;
          invoke_viiii(140,(0|0),($7|0),($115|0),($119|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           break;
          }
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $lpad$phi$index = $31;$lpad$phi$index3 = $32;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z61mscorlib_System_Reflection_Binder_Default_m_IsArrayAssignableP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_($__this,$object_type,$target_type) {
 $__this = $__this|0;
 $object_type = $object_type|0;
 $target_type = $target_type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397232);
 __THREW__ = 0;
 invoke_vi(3799,($object_type|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2734,(2233944|0),($object_type|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if ($2) {
     __THREW__ = 0;
     invoke_vi(3799,($target_type|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     $9 = (invoke_iii(2734,(2233944|0),($target_type|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     if ($9) {
      __THREW__ = 0;
      invoke_vi(3799,($object_type|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      $14 = (invoke_iii(2730,(2224328|0),($object_type|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($target_type|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      $19 = (invoke_iii(2730,(2224328|0),($target_type|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      $22 = (invoke_iiii(848,0,($14|0),($19|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      } else {
       $$0 = $22;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    invoke_vi(3799,($target_type|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_iiii(1640,(2235992|0),($target_type|0),($object_type|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $$0 = $27;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_Binder_Default_m_ChangeTypeP41mscorlib_System_Reflection_Binder_DefaultP22mscorlib_System_ObjectP20mscorlib_System_TypeP41mscorlib_System_Globalization_CultureInfo($__this,$value,$type,$culture) {
 $__this = $__this|0;
 $value = $value|0;
 $type = $type|0;
 $culture = $culture|0;
 var $$0 = 0, $$01 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = Math_fround(0), $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_23 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy3 = sp + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $L_17 = sp;
 $2 = sp + 20|0;
 $L_23 = sp + 24|0;
 $3 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397280);
 $4 = ($value|0)==(0|0);
 if ($4) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($value|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 L4: do {
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(1782,($value|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(3799,($type|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_iii(2734,(2234040|0),($type|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      if ($12) {
       __THREW__ = 0;
       invoke_vi(3799,($type|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       $19 = (invoke_iii(2730,(2224328|0),($type|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       $$01 = $19;
      } else {
       $$01 = $type;
      }
      $22 = ($7|0)==($$01|0);
      if ($22) {
       $$0 = $value;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($$01|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       $25 = (invoke_iiii(1644,(2236040|0),($$01|0),($value|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        if ($25) {
         $$0 = $value;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($7|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if (!($29)) {
         __THREW__ = 0;
         $30 = (invoke_iii(2734,(2233944|0),($7|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          do {
           if ($30) {
            __THREW__ = 0;
            invoke_vi(3799,($$01|0));
            $33 = __THREW__; __THREW__ = 0;
            $34 = $33&1;
            if ($34) {
             break L4;
            }
            __THREW__ = 0;
            $35 = (invoke_iii(2734,(2233944|0),($$01|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if ($37) {
             break L4;
            }
            if ($35) {
             __THREW__ = 0;
             invoke_vi(3799,($7|0));
             $38 = __THREW__; __THREW__ = 0;
             $39 = $38&1;
             if ($39) {
              break L4;
             }
             __THREW__ = 0;
             $40 = (invoke_iii(2730,(2224328|0),($7|0))|0);
             $41 = __THREW__; __THREW__ = 0;
             $42 = $41&1;
             if ($42) {
              break L4;
             }
             __THREW__ = 0;
             invoke_vi(3799,($$01|0));
             $43 = __THREW__; __THREW__ = 0;
             $44 = $43&1;
             if ($44) {
              break L4;
             }
             __THREW__ = 0;
             $45 = (invoke_iii(2730,(2224328|0),($$01|0))|0);
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if ($47) {
              break L4;
             }
             __THREW__ = 0;
             $48 = (invoke_iiii(848,0,($40|0),($45|0))|0);
             $49 = __THREW__; __THREW__ = 0;
             $50 = $49&1;
             if ($50) {
              break L4;
             }
             if ($48) {
              $$0 = $value;
             } else {
              break;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          } while(0);
          __THREW__ = 0;
          $51 = (invoke_iiii(851,0,($7|0),($$01|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           if (!($51)) {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2734,(2215792|0),($$01|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             if ($56) {
              __THREW__ = 0;
              $59 = (invoke_iiii(666,(0|0),($$01|0),($value|0))|0);
              $60 = __THREW__; __THREW__ = 0;
              $61 = $60&1;
              if ($61) {
               break;
              } else {
               $$0 = $59;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             HEAP32[$0>>2] = 1376192;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
             $62 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
             $63 = __THREW__; __THREW__ = 0;
             $64 = $63&1;
             if (!($64)) {
              $65 = ($7|0)==($62|0);
              do {
               if ($65) {
                HEAP32[$1>>2] = 2095368;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
                $66 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
                $67 = __THREW__; __THREW__ = 0;
                $68 = $67&1;
                if ($68) {
                 break L4;
                }
                $69 = ($$01|0)==($66|0);
                if ($69) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2180696|0))|0);
                 $70 = __THREW__; __THREW__ = 0;
                 $71 = $70&1;
                 if ($71) {
                  break L4;
                 }
                 __THREW__ = 0;
                 $72 = (invoke_iii(2761,($value|0),(2180696|0))|0);
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if ($74) {
                  break L4;
                 }
                 $75 = HEAP16[$72>>1]|0;
                 $76 = (+($75&65535));
                 HEAPF64[$L_17>>3] = $76;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2198192|0))|0);
                 $77 = __THREW__; __THREW__ = 0;
                 $78 = $77&1;
                 if ($78) {
                  break L4;
                 }
                 __THREW__ = 0;
                 $79 = (invoke_iii(2724,(2198192|0),($L_17|0))|0);
                 $80 = __THREW__; __THREW__ = 0;
                 $81 = $80&1;
                 if ($81) {
                  break L4;
                 }
                 $$0 = $79;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                HEAP32[$2>>2] = 1285152;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
                $82 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if ($84) {
                 break L4;
                }
                $85 = ($$01|0)==($82|0);
                if (!($85)) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2180696|0))|0);
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 break L4;
                }
                __THREW__ = 0;
                $88 = (invoke_iii(2761,($value|0),(2180696|0))|0);
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if ($90) {
                 break L4;
                }
                $91 = HEAP16[$88>>1]|0;
                $92 = (Math_fround(($91&65535)));
                HEAPF32[$L_23>>2] = $92;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $93 = __THREW__; __THREW__ = 0;
                $94 = $93&1;
                if ($94) {
                 break L4;
                }
                __THREW__ = 0;
                $95 = (invoke_iii(2724,(2194912|0),($L_23|0))|0);
                $96 = __THREW__; __THREW__ = 0;
                $97 = $96&1;
                if ($97) {
                 break L4;
                }
                $$0 = $95;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              } while(0);
              HEAP32[$3>>2] = 1285376;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
              $98 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
              $99 = __THREW__; __THREW__ = 0;
              $100 = $99&1;
              if ($100) {
               break;
              }
              $101 = ($7|0)==($98|0);
              do {
               if ($101) {
                __THREW__ = 0;
                invoke_vi(3799,($$01|0));
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 break L4;
                }
                __THREW__ = 0;
                $104 = (invoke_iii(2734,(2234568|0),($$01|0))|0);
                $105 = __THREW__; __THREW__ = 0;
                $106 = $105&1;
                if ($106) {
                 break L4;
                }
                if ($104) {
                 $$0 = $value;
                } else {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              } while(0);
              __THREW__ = 0;
              $107 = (invoke_iiii(1136,(0|0),($value|0),($$01|0))|0);
              $108 = __THREW__; __THREW__ = 0;
              $109 = $108&1;
              if ($109) {
               break;
              } else {
               $$0 = $107;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_Binder_Default_m_check_typeP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_($__this,$from,$to) {
 $__this = $__this|0;
 $from = $from|0;
 $to = $to|0;
 var $$0 = 0, $$052 = 0, $$byval_copy18 = 0, $$off = 0, $$off53 = 0, $$off54 = 0, $$off55 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond19 = 0, $or$cond21 = 0, $or$cond23 = 0, $or$cond25 = 0, $or$cond27 = 0, $or$cond29 = 0, $switch = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy18 = sp + 80|0;
 $_stackTraceSentry = sp + 76|0;
 $0 = sp + 72|0;
 $1 = sp + 68|0;
 $2 = sp + 64|0;
 $3 = sp + 60|0;
 $4 = sp + 56|0;
 $5 = sp + 52|0;
 $6 = sp + 48|0;
 $7 = sp + 44|0;
 $8 = sp + 40|0;
 $9 = sp + 12|0;
 $10 = sp;
 $11 = sp + 4|0;
 $12 = sp + 8|0;
 $13 = sp + 16|0;
 $14 = sp + 20|0;
 $15 = sp + 24|0;
 $16 = sp + 28|0;
 $17 = sp + 32|0;
 $18 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397376);
 $19 = ($from|0)==($to|0);
 $20 = ($from|0)==(0|0);
 $or$cond = $19 | $20;
 L1: do {
  if ($or$cond) {
   $$0 = 1;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($to|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   L3: do {
    if (!($22)) {
     __THREW__ = 0;
     $23 = (invoke_iii(2734,(2234040|0),($to|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      invoke_vi(3799,($from|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       $28 = (invoke_iii(2734,(2234040|0),($from|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $tmp = $23 ^ $28;
        if ($tmp) {
         $$0 = 0;
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($to|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         __THREW__ = 0;
         $35 = (invoke_iii(2734,(2234184|0),($to|0))|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if (!($37)) {
          if ($35) {
           __THREW__ = 0;
           invoke_vi(3799,($to|0));
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if ($39) {
            break;
           }
           __THREW__ = 0;
           $40 = (invoke_iiii(1640,(2235992|0),($to|0),($from|0))|0);
           $41 = __THREW__; __THREW__ = 0;
           $42 = $41&1;
           if ($42) {
            break;
           } else {
            $$0 = $40;
            break L1;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($to|0));
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if (!($44)) {
           __THREW__ = 0;
           $45 = (invoke_iii(2734,(2215792|0),($to|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            if ($45) {
             __THREW__ = 0;
             $48 = (invoke_iii(744,(0|0),($to|0))|0);
             $49 = __THREW__; __THREW__ = 0;
             $50 = $49&1;
             if ($50) {
              break;
             }
             $51 = ($48|0)==($from|0);
             if ($51) {
              $$0 = 1;
              break L1;
             } else {
              $$052 = $48;
             }
            } else {
             $$052 = $to;
            }
            __THREW__ = 0;
            invoke_vi(3799,($$052|0));
            $52 = __THREW__; __THREW__ = 0;
            $53 = $52&1;
            if (!($53)) {
             __THREW__ = 0;
             $54 = (invoke_iii(2734,(2237408|0),($$052|0))|0);
             $55 = __THREW__; __THREW__ = 0;
             $56 = $55&1;
             if (!($56)) {
              do {
               if ($54) {
                __THREW__ = 0;
                invoke_vi(3799,($$052|0));
                $57 = __THREW__; __THREW__ = 0;
                $58 = $57&1;
                if ($58) {
                 break L3;
                }
                __THREW__ = 0;
                $59 = (invoke_iii(2730,(2237360|0),($$052|0))|0);
                $60 = __THREW__; __THREW__ = 0;
                $61 = $60&1;
                if ($61) {
                 break L3;
                }
                HEAP32[$0>>2] = 2266480;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$0+0>>2]|0;
                $62 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                $63 = __THREW__; __THREW__ = 0;
                $64 = $63&1;
                if ($64) {
                 break L3;
                }
                $65 = ($59|0)==($62|0);
                if (!($65)) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($$052|0));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if ($67) {
                 break L3;
                }
                __THREW__ = 0;
                $68 = (invoke_iii(2730,(2237104|0),($$052|0))|0);
                $69 = __THREW__; __THREW__ = 0;
                $70 = $69&1;
                if ($70) {
                 break L3;
                }
                __THREW__ = 0;
                invoke_vi(3799,($68|0));
                $71 = __THREW__; __THREW__ = 0;
                $72 = $71&1;
                if ($72) {
                 break L3;
                }
                $73 = (($68) + 12|0);
                $74 = HEAP32[$73>>2]|0;
                $75 = ($74|0)==(0);
                if ($75) {
                 __THREW__ = 0;
                 $76 = (invoke_i(132)|0);
                 $77 = __THREW__; __THREW__ = 0;
                 $78 = $77&1;
                 if ($78) {
                  break L3;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($76|0));
                 $79 = __THREW__; __THREW__ = 0;
                 $80 = $79&1;
                 if ($80) {
                  break L3;
                 }
                }
                $81 = (($68) + 16|0);
                $82 = HEAP32[$81>>2]|0;
                $83 = ($82|0)==($from|0);
                if ($83) {
                 $$0 = 1;
                 break L1;
                }
               }
              } while(0);
              __THREW__ = 0;
              $84 = (invoke_iii(771,(0|0),($from|0))|0);
              $85 = __THREW__; __THREW__ = 0;
              $86 = $85&1;
              if (!($86)) {
               __THREW__ = 0;
               $87 = (invoke_iii(771,(0|0),($$052|0))|0);
               $88 = __THREW__; __THREW__ = 0;
               $89 = $88&1;
               if (!($89)) {
                switch ($84|0) {
                case 4:  {
                 $92 = (($87) + -8)|0;
                 $93 = ($92>>>0)<(7);
                 if ($93) {
                  $$0 = 1;
                  break L1;
                 }
                 HEAP32[$1>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$1+0>>2]|0;
                 $94 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $95 = __THREW__; __THREW__ = 0;
                 $96 = $95&1;
                 if ($96) {
                  break L3;
                 }
                 $97 = ($$052|0)==($94|0);
                 $$0 = $97;
                 break L1;
                 break;
                }
                case 6:  {
                 $98 = (($87) + -4)|0;
                 $99 = ($98|0)==(0);
                 if ($99) {
                  $$0 = 1;
                  break L1;
                 }
                 $$off53 = (($87) + -5)|0;
                 $100 = ($$off53>>>0)<(2);
                 if (!($100)) {
                  $$off54 = (($87) + -7)|0;
                  $101 = ($$off54>>>0)<(2);
                  $102 = ($98|0)==(5);
                  $or$cond19 = $101 | $102;
                  $103 = ($98|0)==(6);
                  $or$cond21 = $or$cond19 | $103;
                  $104 = ($98|0)==(7);
                  $or$cond23 = $or$cond21 | $104;
                  $105 = ($98|0)==(8);
                  $or$cond25 = $or$cond23 | $105;
                  $106 = ($98|0)==(9);
                  $or$cond27 = $or$cond25 | $106;
                  $107 = ($98|0)==(10);
                  $or$cond29 = $or$cond27 | $107;
                  if ($or$cond29) {
                   $$0 = 1;
                   break L1;
                  }
                 }
                 HEAP32[$2>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$2+0>>2]|0;
                 $108 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $109 = __THREW__; __THREW__ = 0;
                 $110 = $109&1;
                 if ($110) {
                  break L3;
                 }
                 $111 = ($$052|0)==($108|0);
                 if ($111) {
                  $$0 = 1;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($from|0));
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  break L3;
                 }
                 __THREW__ = 0;
                 $114 = (invoke_iii(2734,(2215792|0),($from|0))|0);
                 $115 = __THREW__; __THREW__ = 0;
                 $116 = $115&1;
                 if ($116) {
                  break L3;
                 }
                 if (!($114)) {
                  $$0 = 0;
                  break L1;
                 }
                 HEAP32[$3>>2] = 2269384;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$3+0>>2]|0;
                 $117 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break L3;
                 }
                 $120 = ($$052|0)==($117|0);
                 $$0 = $120;
                 break L1;
                 break;
                }
                case 9:  {
                 if ((($87|0) == 11)) {
                  $$0 = 1;
                  break L1;
                 } else if (!((($87|0) == 12))) {
                  $183 = (($87) + -11)|0;
                  $184 = $183 & -2;
                  $185 = ($184|0)==(2);
                  if ($185) {
                   $$0 = 1;
                   break L1;
                  }
                 }
                 HEAP32[$12>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$12+0>>2]|0;
                 $186 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $187 = __THREW__; __THREW__ = 0;
                 $188 = $187&1;
                 if ($188) {
                  break L3;
                 }
                 $189 = ($$052|0)==($186|0);
                 if ($189) {
                  $$0 = 1;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($from|0));
                 $190 = __THREW__; __THREW__ = 0;
                 $191 = $190&1;
                 if ($191) {
                  break L3;
                 }
                 __THREW__ = 0;
                 $192 = (invoke_iii(2734,(2215792|0),($from|0))|0);
                 $193 = __THREW__; __THREW__ = 0;
                 $194 = $193&1;
                 if ($194) {
                  break L3;
                 }
                 if (!($192)) {
                  $$0 = 0;
                  break L1;
                 }
                 HEAP32[$13>>2] = 2269384;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$13+0>>2]|0;
                 $195 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $196 = __THREW__; __THREW__ = 0;
                 $197 = $196&1;
                 if ($197) {
                  break L3;
                 }
                 $198 = ($$052|0)==($195|0);
                 $$0 = $198;
                 break L1;
                 break;
                }
                case 7:  {
                 if ((($87|0) == 11) | (($87|0) == 9)) {
                  $$0 = 1;
                  break L1;
                 } else if (!((($87|0) == 12) | (($87|0) == 10))) {
                  $152 = (($87) + -9)|0;
                  $153 = $152 & -2;
                  $154 = ($153|0)==(4);
                  if ($154) {
                   $$0 = 1;
                   break L1;
                  }
                 }
                 HEAP32[$8>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$8+0>>2]|0;
                 $155 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $156 = __THREW__; __THREW__ = 0;
                 $157 = $156&1;
                 if ($157) {
                  break L3;
                 }
                 $158 = ($$052|0)==($155|0);
                 if ($158) {
                  $$0 = 1;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($from|0));
                 $159 = __THREW__; __THREW__ = 0;
                 $160 = $159&1;
                 if ($160) {
                  break L3;
                 }
                 __THREW__ = 0;
                 $161 = (invoke_iii(2734,(2215792|0),($from|0))|0);
                 $162 = __THREW__; __THREW__ = 0;
                 $163 = $162&1;
                 if ($163) {
                  break L3;
                 }
                 if (!($161)) {
                  $$0 = 0;
                  break L1;
                 }
                 HEAP32[$9>>2] = 2269384;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$9+0>>2]|0;
                 $164 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $165 = __THREW__; __THREW__ = 0;
                 $166 = $165&1;
                 if ($166) {
                  break L3;
                 }
                 $167 = ($$052|0)==($164|0);
                 $$0 = $167;
                 break L1;
                 break;
                }
                case 5:  {
                 switch ($87|0) {
                 case 12: case 10: case 8:  {
                  break;
                 }
                 case 11: case 9: case 7:  {
                  $$0 = 1;
                  break L1;
                  break;
                 }
                 default: {
                  $121 = (($87) + -7)|0;
                  $122 = $121 & -2;
                  $123 = ($122|0)==(6);
                  if ($123) {
                   $$0 = 1;
                   break L1;
                  }
                 }
                 }
                 HEAP32[$4>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$4+0>>2]|0;
                 $124 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $125 = __THREW__; __THREW__ = 0;
                 $126 = $125&1;
                 if ($126) {
                  break L3;
                 }
                 $127 = ($$052|0)==($124|0);
                 if ($127) {
                  $$0 = 1;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($from|0));
                 $128 = __THREW__; __THREW__ = 0;
                 $129 = $128&1;
                 if ($129) {
                  break L3;
                 }
                 __THREW__ = 0;
                 $130 = (invoke_iii(2734,(2215792|0),($from|0))|0);
                 $131 = __THREW__; __THREW__ = 0;
                 $132 = $131&1;
                 if ($132) {
                  break L3;
                 }
                 if (!($130)) {
                  $$0 = 0;
                  break L1;
                 }
                 HEAP32[$5>>2] = 2269384;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$5+0>>2]|0;
                 $133 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $134 = __THREW__; __THREW__ = 0;
                 $135 = $134&1;
                 if ($135) {
                  break L3;
                 }
                 $136 = ($$052|0)==($133|0);
                 $$0 = $136;
                 break L1;
                 break;
                }
                case 10:  {
                 $168 = (($87) + -11)|0;
                 $169 = ($168>>>0)<(4);
                 if ($169) {
                  $$0 = 1;
                  break L1;
                 }
                 HEAP32[$10>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$10+0>>2]|0;
                 $170 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $171 = __THREW__; __THREW__ = 0;
                 $172 = $171&1;
                 if ($172) {
                  break L3;
                 }
                 $173 = ($$052|0)==($170|0);
                 if ($173) {
                  $$0 = 1;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($from|0));
                 $174 = __THREW__; __THREW__ = 0;
                 $175 = $174&1;
                 if ($175) {
                  break L3;
                 }
                 __THREW__ = 0;
                 $176 = (invoke_iii(2734,(2215792|0),($from|0))|0);
                 $177 = __THREW__; __THREW__ = 0;
                 $178 = $177&1;
                 if ($178) {
                  break L3;
                 }
                 if (!($176)) {
                  $$0 = 0;
                  break L1;
                 }
                 HEAP32[$11>>2] = 2269384;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$11+0>>2]|0;
                 $179 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $180 = __THREW__; __THREW__ = 0;
                 $181 = $180&1;
                 if ($181) {
                  break L3;
                 }
                 $182 = ($$052|0)==($179|0);
                 $$0 = $182;
                 break L1;
                 break;
                }
                case 8:  {
                 $137 = (($87) + -9)|0;
                 $138 = ($137>>>0)<(6);
                 if ($138) {
                  $$0 = 1;
                  break L1;
                 }
                 HEAP32[$6>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$6+0>>2]|0;
                 $139 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $140 = __THREW__; __THREW__ = 0;
                 $141 = $140&1;
                 if ($141) {
                  break L3;
                 }
                 $142 = ($$052|0)==($139|0);
                 if ($142) {
                  $$0 = 1;
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($from|0));
                 $143 = __THREW__; __THREW__ = 0;
                 $144 = $143&1;
                 if ($144) {
                  break L3;
                 }
                 __THREW__ = 0;
                 $145 = (invoke_iii(2734,(2215792|0),($from|0))|0);
                 $146 = __THREW__; __THREW__ = 0;
                 $147 = $146&1;
                 if ($147) {
                  break L3;
                 }
                 if (!($145)) {
                  $$0 = 0;
                  break L1;
                 }
                 HEAP32[$7>>2] = 2269384;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$7+0>>2]|0;
                 $148 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $149 = __THREW__; __THREW__ = 0;
                 $150 = $149&1;
                 if ($150) {
                  break L3;
                 }
                 $151 = ($$052|0)==($148|0);
                 $$0 = $151;
                 break L1;
                 break;
                }
                default: {
                 $$off = (($84) + -11)|0;
                 $90 = ($$off>>>0)<(2);
                 if ($90) {
                  $$off55 = (($87) + -13)|0;
                  $switch = ($$off55>>>0)<(2);
                  if ($switch) {
                   $$0 = 1;
                   break L1;
                  }
                  HEAP32[$14>>2] = 1284448;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$14+0>>2]|0;
                  $199 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                  $200 = __THREW__; __THREW__ = 0;
                  $201 = $200&1;
                  if ($201) {
                   break L3;
                  }
                  $202 = ($$052|0)==($199|0);
                  if ($202) {
                   $$0 = 1;
                   break L1;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($from|0));
                  $203 = __THREW__; __THREW__ = 0;
                  $204 = $203&1;
                  if ($204) {
                   break L3;
                  }
                  __THREW__ = 0;
                  $205 = (invoke_iii(2734,(2215792|0),($from|0))|0);
                  $206 = __THREW__; __THREW__ = 0;
                  $207 = $206&1;
                  if ($207) {
                   break L3;
                  }
                  if (!($205)) {
                   $$0 = 0;
                   break L1;
                  }
                  HEAP32[$15>>2] = 2269384;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$15+0>>2]|0;
                  $208 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                  $209 = __THREW__; __THREW__ = 0;
                  $210 = $209&1;
                  if ($210) {
                   break L3;
                  }
                  $211 = ($$052|0)==($208|0);
                  $$0 = $211;
                  break L1;
                 }
                 $91 = ($84|0)==(13);
                 if ($91) {
                  $212 = ($87|0)==(14);
                  if ($212) {
                   $$0 = 1;
                   break L1;
                  }
                  HEAP32[$16>>2] = 1284448;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$16+0>>2]|0;
                  $213 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                  $214 = __THREW__; __THREW__ = 0;
                  $215 = $214&1;
                  if ($215) {
                   break L3;
                  }
                  $216 = ($$052|0)==($213|0);
                  $$0 = $216;
                  break L1;
                 }
                 HEAP32[$17>>2] = 1284448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$17+0>>2]|0;
                 $217 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                 $218 = __THREW__; __THREW__ = 0;
                 $219 = $218&1;
                 if ($219) {
                  break L3;
                 }
                 $220 = ($$052|0)==($217|0);
                 if ($220) {
                  __THREW__ = 0;
                  invoke_vi(3799,($from|0));
                  $221 = __THREW__; __THREW__ = 0;
                  $222 = $221&1;
                  if ($222) {
                   break L3;
                  }
                  __THREW__ = 0;
                  $223 = (invoke_iii(2734,(2234232|0),($from|0))|0);
                  $224 = __THREW__; __THREW__ = 0;
                  $225 = $224&1;
                  if ($225) {
                   break L3;
                  }
                  if ($223) {
                   $$0 = 1;
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$052|0));
                 $226 = __THREW__; __THREW__ = 0;
                 $227 = $226&1;
                 if ($227) {
                  break L3;
                 }
                 __THREW__ = 0;
                 $228 = (invoke_iii(2734,(2234568|0),($$052|0))|0);
                 $229 = __THREW__; __THREW__ = 0;
                 $230 = $229&1;
                 if ($230) {
                  break L3;
                 }
                 if ($228) {
                  HEAP32[$18>>2] = 1285376;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy18+0>>2]=HEAP32[$18+0>>2]|0;
                  $231 = (invoke_iii(772,(0|0),($$byval_copy18|0))|0);
                  $232 = __THREW__; __THREW__ = 0;
                  $233 = $232&1;
                  if ($233) {
                   break L3;
                  }
                  $234 = ($231|0)==($from|0);
                  if ($234) {
                   $$0 = 1;
                   break L1;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$052|0));
                 $235 = __THREW__; __THREW__ = 0;
                 $236 = $235&1;
                 if ($236) {
                  break L3;
                 }
                 __THREW__ = 0;
                 $237 = (invoke_iiii(1640,(2235992|0),($$052|0),($from|0))|0);
                 $238 = __THREW__; __THREW__ = 0;
                 $239 = $238&1;
                 if ($239) {
                  break L3;
                 } else {
                  $$0 = $237;
                  break L1;
                 }
                }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   $31 = ___cxa_find_matching_catch()|0;
   $32 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($31|0);
   // unreachable;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo6651($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z64mscorlib_System_Reflection_Binder_Default_m_ReorderArgumentArrayP41mscorlib_System_Reflection_Binder_DefaultPP26mscorlib_System_Object_arrP22mscorlib_System_Object($__this,$args,$state) {
 $__this = $__this|0;
 $args = $args|0;
 $state = $state|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397328);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_Reflection_Binder_Default_m_check_argumentsP22mscorlib_System_ObjectP24mscorlib_System_Type_arrP44mscorlib_System_Reflection_ParameterInfo_arrb($__this,$types,$args,$allowByRefMatch) {
 $__this = $__this|0;
 $types = $types|0;
 $args = $args|0;
 $allowByRefMatch = $allowByRefMatch|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $V_0$0 = 0, $V_1$0$off0 = 0;
 var $_stackTraceSentry = 0, $allowByRefMatch$not = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397424);
 $0 = (($types) + 12|0);
 $1 = (($types) + 16|0);
 $2 = (($args) + 16|0);
 $allowByRefMatch$not = $allowByRefMatch ^ 1;
 $3 = (($args) + 12|0);
 $V_0$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($types|0));
  $91 = __THREW__; __THREW__ = 0;
  $92 = $91&1;
  if ($92) {
   label = 5;
   break;
  }
  $93 = HEAP32[$0>>2]|0;
  $94 = ($V_0$0|0)<($93|0);
  if (!($94)) {
   $$0 = 1;
   label = 34;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($types|0));
  $95 = __THREW__; __THREW__ = 0;
  $96 = $95&1;
  if ($96) {
   label = 5;
   break;
  }
  $4 = HEAP32[$0>>2]|0;
  $5 = ($V_0$0>>>0)<($4>>>0);
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_i(132)|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 5;
    break;
   }
  }
  $13 = HEAP32[$types>>2]|0;
  $14 = (($13) + 92|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $V_0$0)|0;
  $17 = (($1) + ($16)|0);
  $18 = HEAP32[$17>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($args|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   label = 5;
   break;
  }
  $21 = HEAP32[$3>>2]|0;
  $22 = ($V_0$0>>>0)<($21>>>0);
  if (!($22)) {
   __THREW__ = 0;
   $23 = (invoke_i(132)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($23|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 5;
    break;
   }
  }
  $28 = HEAP32[$args>>2]|0;
  $29 = (($28) + 92|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = Math_imul($30, $V_0$0)|0;
  $32 = (($2) + ($31)|0);
  $33 = HEAP32[$32>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $36 = (invoke_iii(2730,(2397472|0),($33|0))|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $39 = (invoke_iiii(851,0,($18|0),($36|0))|0);
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   label = 5;
   break;
  }
  $brmerge = $39 | $allowByRefMatch$not;
  if ($brmerge) {
   $V_1$0$off0 = $39;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($args|0));
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    label = 5;
    break;
   }
   $44 = HEAP32[$3>>2]|0;
   $45 = ($V_0$0>>>0)<($44>>>0);
   if (!($45)) {
    __THREW__ = 0;
    $46 = (invoke_i(132)|0);
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($46|0));
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     label = 5;
     break;
    }
   }
   $51 = HEAP32[$args>>2]|0;
   $52 = (($51) + 92|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = Math_imul($53, $V_0$0)|0;
   $55 = (($2) + ($54)|0);
   $56 = HEAP32[$55>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($56|0));
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if ($58) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   $59 = (invoke_iii(2730,(2397472|0),($56|0))|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($59|0));
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if ($63) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   $64 = (invoke_iii(2734,(2234040|0),($59|0))|0);
   $65 = __THREW__; __THREW__ = 0;
   $66 = $65&1;
   if ($66) {
    label = 5;
    break;
   }
   if (!($64)) {
    $$0 = 0;
    label = 34;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($types|0));
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 5;
    break;
   }
   $69 = HEAP32[$0>>2]|0;
   $70 = ($V_0$0>>>0)<($69>>>0);
   if (!($70)) {
    __THREW__ = 0;
    $71 = (invoke_i(132)|0);
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     label = 5;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($71|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     label = 5;
     break;
    }
   }
   $76 = HEAP32[$types>>2]|0;
   $77 = (($76) + 92|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = Math_imul($78, $V_0$0)|0;
   $80 = (($1) + ($79)|0);
   $81 = HEAP32[$80>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($59|0));
   $82 = __THREW__; __THREW__ = 0;
   $83 = $82&1;
   if ($83) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   $84 = (invoke_iii(2730,(2224328|0),($59|0))|0);
   $85 = __THREW__; __THREW__ = 0;
   $86 = $85&1;
   if ($86) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   $87 = (invoke_iiii(851,0,($81|0),($84|0))|0);
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 5;
    break;
   } else {
    $V_1$0$off0 = $87;
   }
  }
  $90 = (($V_0$0) + 1)|0;
  if ($V_1$0$off0) {
   $V_0$0 = $90;
  } else {
   $$0 = 0;
   label = 34;
   break;
  }
 }
 if ((label|0) == 5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 }
 else if ((label|0) == 34) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z262mscorlib_System_Reflection_Binder_Default_m_SelectMethod_mscorlib_System_Reflection_MethodBase_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_MethodBase_arr_arr_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP41mscorlib_System_Reflection_Binder_DefaultiP41mscorlib_System_Reflection_MethodBase_arrP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$bindingAttr,$match,$types,$modifiers) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $match = $match|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397520);
 __THREW__ = 0;
 $0 = (invoke_iiiiiii(72,($__this|0),($bindingAttr|0),($match|0),($types|0),0,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z59mscorlib_System_Reflection_Binder_Default_m_GetBetterMethodP41mscorlib_System_Reflection_Binder_DefaultP37mscorlib_System_Reflection_MethodBaseS2_P24mscorlib_System_Type_arr($__this,$m1,$m2,$types) {
 $__this = $__this|0;
 $m1 = $m1|0;
 $m2 = $m2|0;
 $types = $types|0;
 var $$0 = 0, $$V_2$1 = 0, $$lobit = 0, $$not = 0, $$sum = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$1 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $m1$m2 = 0, $or$cond = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397616);
 __THREW__ = 0;
 invoke_vi(3799,($m1|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2734,(2397664|0),($m1|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if ($2) {
     __THREW__ = 0;
     invoke_vi(3799,($m2|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2734,(2397664|0),($m2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     if (!($11)) {
      $$0 = $m2;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    invoke_vi(3799,($m2|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(2734,(2397664|0),($m2|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      if ($16) {
       __THREW__ = 0;
       invoke_vi(3799,($m1|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       $21 = (invoke_iii(2734,(2397664|0),($m1|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       if (!($21)) {
        $$0 = $m1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      __THREW__ = 0;
      invoke_vi(3799,($m1|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       $26 = (invoke_iii(2730,(2397136|0),($m1|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        invoke_vi(3799,($m2|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         __THREW__ = 0;
         $31 = (invoke_iii(2730,(2397136|0),($m2|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if (!($33)) {
          $34 = (($26) + 12|0);
          $35 = (($31) + 12|0);
          $V_2$1 = 0;$V_3$0 = 0;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($26|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            label = 4;
            break;
           }
           $92 = HEAP32[$34>>2]|0;
           $93 = ($V_3$0|0)<($92|0);
           if (!($93)) {
            label = 43;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($26|0));
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if ($95) {
            label = 4;
            break;
           }
           $36 = HEAP32[$34>>2]|0;
           $37 = ($V_3$0>>>0)<($36>>>0);
           if (!($37)) {
            __THREW__ = 0;
            $38 = (invoke_i(132)|0);
            $39 = __THREW__; __THREW__ = 0;
            $40 = $39&1;
            if ($40) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($38|0));
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             label = 4;
             break;
            }
           }
           $43 = HEAP32[$26>>2]|0;
           $44 = (($43) + 92|0);
           $45 = HEAP32[$44>>2]|0;
           $46 = Math_imul($45, $V_3$0)|0;
           $$sum = (($46) + 16)|0;
           $47 = (($26) + ($$sum)|0);
           $48 = HEAP32[$47>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($48|0));
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           $51 = (invoke_iii(2730,(2397472|0),($48|0))|0);
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if ($53) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($31|0));
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if ($55) {
            label = 4;
            break;
           }
           $56 = HEAP32[$35>>2]|0;
           $57 = ($V_3$0>>>0)<($56>>>0);
           if (!($57)) {
            __THREW__ = 0;
            $58 = (invoke_i(132)|0);
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($58|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             label = 4;
             break;
            }
           }
           $63 = HEAP32[$31>>2]|0;
           $64 = (($63) + 92|0);
           $65 = HEAP32[$64>>2]|0;
           $66 = Math_imul($65, $V_3$0)|0;
           $$sum6 = (($66) + 16)|0;
           $67 = (($31) + ($$sum6)|0);
           $68 = HEAP32[$67>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($68|0));
           $69 = __THREW__; __THREW__ = 0;
           $70 = $69&1;
           if ($70) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           $71 = (invoke_iii(2730,(2397472|0),($68|0))|0);
           $72 = __THREW__; __THREW__ = 0;
           $73 = $72&1;
           if ($73) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           $74 = (invoke_iiii(853,($__this|0),($51|0),($71|0))|0);
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if ($76) {
            label = 4;
            break;
           }
           $77 = ($74|0)!=(0);
           $$not = $77 ^ 1;
           $78 = ($V_2$1|0)==(0);
           $or$cond = $78 | $$not;
           $79 = ($V_2$1|0)==($74|0);
           $or$cond2 = $or$cond | $79;
           if (!($or$cond2)) {
            label = 34;
            break;
           }
           $$V_2$1 = $77 ? $74 : $V_2$1;
           $89 = (($V_3$0) + 1)|0;
           $V_2$1 = $$V_2$1;$V_3$0 = $89;
          }
          if ((label|0) == 4) {
           $5 = ___cxa_find_matching_catch()|0;
           $6 = tempRet0;
           $lpad$phi$index = $5;$lpad$phi$index2 = $6;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 34) {
           __THREW__ = 0;
           (invoke_ii(2996,(2375288|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if ($81) {
            break;
           }
           __THREW__ = 0;
           $82 = (invoke_ii(3469,(2375288|0))|0);
           $83 = __THREW__; __THREW__ = 0;
           $84 = $83&1;
           if ($84) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(2261,($82|0));
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if ($86) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3834,($82|0));
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            break;
           }
           // unreachable;
          }
          else if ((label|0) == 43) {
           $96 = ($V_2$1|0)==(0);
           if (!($96)) {
            $97 = ($V_2$1|0)<(1);
            $m1$m2 = $97 ? $m1 : $m2;
            $$0 = $m1$m2;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           invoke_vi(3799,($m1|0));
           $98 = __THREW__; __THREW__ = 0;
           $99 = $98&1;
           if ($99) {
            break;
           }
           __THREW__ = 0;
           $100 = (invoke_iii(2730,(2242504|0),($m1|0))|0);
           $101 = __THREW__; __THREW__ = 0;
           $102 = $101&1;
           if ($102) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($m2|0));
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            break;
           }
           __THREW__ = 0;
           $105 = (invoke_iii(2730,(2242504|0),($m2|0))|0);
           $106 = __THREW__; __THREW__ = 0;
           $107 = $106&1;
           if ($107) {
            break;
           }
           $108 = ($100|0)==($105|0);
           do {
            if (!($108)) {
             __THREW__ = 0;
             invoke_vi(3799,($100|0));
             $109 = __THREW__; __THREW__ = 0;
             $110 = $109&1;
             if ($110) {
              break L1;
             }
             __THREW__ = 0;
             $111 = (invoke_iiii(1640,(2234376|0),($100|0),($105|0))|0);
             $112 = __THREW__; __THREW__ = 0;
             $113 = $112&1;
             if ($113) {
              break L1;
             }
             if ($111) {
              $$0 = $m1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             invoke_vi(3799,($105|0));
             $114 = __THREW__; __THREW__ = 0;
             $115 = $114&1;
             if ($115) {
              break L1;
             }
             __THREW__ = 0;
             $116 = (invoke_iiii(1640,(2234376|0),($105|0),($100|0))|0);
             $117 = __THREW__; __THREW__ = 0;
             $118 = $117&1;
             if ($118) {
              break L1;
             }
             if ($116) {
              $$0 = $m2;
             } else {
              break;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(3799,($m1|0));
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if ($120) {
            break;
           }
           __THREW__ = 0;
           $121 = (invoke_iii(2729,(2397712|0),($m1|0))|0);
           $122 = __THREW__; __THREW__ = 0;
           $123 = $122&1;
           if ($123) {
            break;
           }
           $$lobit = $121 & 2;
           $124 = ($$lobit|0)==(0);
           __THREW__ = 0;
           invoke_vi(3799,($m2|0));
           $125 = __THREW__; __THREW__ = 0;
           $126 = $125&1;
           if ($126) {
            break;
           }
           __THREW__ = 0;
           $127 = (invoke_iii(2729,(2397712|0),($m2|0))|0);
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            break;
           }
           $130 = $127 & 2;
           $131 = ($130|0)==(0);
           do {
            if ($124) {
             if ($131) {
              break;
             } else {
              $$0 = $m1;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            } else {
             if ($131) {
              $$0 = $m2;
             } else {
              break;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           } while(0);
           __THREW__ = 0;
           (invoke_ii(2996,(2375288|0))|0);
           $132 = __THREW__; __THREW__ = 0;
           $133 = $132&1;
           if ($133) {
            break;
           }
           __THREW__ = 0;
           $134 = (invoke_ii(3469,(2375288|0))|0);
           $135 = __THREW__; __THREW__ = 0;
           $136 = $135&1;
           if ($136) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(2261,($134|0));
           $137 = __THREW__; __THREW__ = 0;
           $138 = $137&1;
           if ($138) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3834,($134|0));
           $139 = __THREW__; __THREW__ = 0;
           $140 = $139&1;
           if ($140) {
            break;
           }
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Reflection_Binder_Default_m_CompareCloserTypeP41mscorlib_System_Reflection_Binder_DefaultP20mscorlib_System_TypeS2_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397760);
 $0 = ($t1|0)==($t2|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($t1|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L4: do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2734,(2237664|0),($t1|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    if ($3) {
     __THREW__ = 0;
     invoke_vi(3799,($t2|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2734,(2237664|0),($t2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     if (!($10)) {
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    invoke_vi(3799,($t1|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     $15 = (invoke_iii(2734,(2237664|0),($t1|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(3799,($t2|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
       __THREW__ = 0;
       $20 = (invoke_iii(2734,(2237664|0),($t2|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       if ($20) {
        $$0 = -1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      __THREW__ = 0;
      invoke_vi(3799,($t1|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       $25 = (invoke_iii(2734,(2233800|0),($t1|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        if ($25) {
         __THREW__ = 0;
         invoke_vi(3799,($t2|0));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          break;
         }
         __THREW__ = 0;
         $30 = (invoke_iii(2734,(2233800|0),($t2|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         if ($30) {
          __THREW__ = 0;
          invoke_vi(3799,($t1|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          __THREW__ = 0;
          $35 = (invoke_iii(2730,(2224328|0),($t1|0))|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($t2|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
          __THREW__ = 0;
          $40 = (invoke_iii(2730,(2224328|0),($t2|0))|0);
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           break;
          }
          __THREW__ = 0;
          $43 = (invoke_iiii(853,($__this|0),($35|0),($40|0))|0);
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          } else {
           $$0 = $43;
          }
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($t1|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if (!($47)) {
         __THREW__ = 0;
         $48 = (invoke_iiii(1640,(2234376|0),($t1|0),($t2|0))|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if (!($50)) {
          if ($48) {
           $$0 = -1;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          invoke_vi(3799,($t2|0));
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if (!($52)) {
           __THREW__ = 0;
           $53 = (invoke_iiii(1640,(2234376|0),($t2|0),($t1|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            if ($53) {
             $$0 = 1;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            invoke_vi(3799,($t1|0));
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if (!($57)) {
             __THREW__ = 0;
             $58 = (invoke_iii(2734,(2234184|0),($t1|0))|0);
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              do {
               if ($58) {
                __THREW__ = 0;
                invoke_vi(3799,($t2|0));
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if ($62) {
                 break L4;
                }
                __THREW__ = 0;
                $63 = (invoke_iii(2730,(2239448|0),($t2|0))|0);
                $64 = __THREW__; __THREW__ = 0;
                $65 = $64&1;
                if ($65) {
                 break L4;
                }
                __THREW__ = 0;
                $66 = (invoke_iii(2762,($63|0),($t1|0))|0);
                $67 = __THREW__; __THREW__ = 0;
                $68 = $67&1;
                if ($68) {
                 break L4;
                }
                $69 = ($66|0)<(0);
                if ($69) {
                 break;
                } else {
                 $$0 = 1;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($t2|0));
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               break;
              }
              __THREW__ = 0;
              $72 = (invoke_iii(2734,(2234184|0),($t2|0))|0);
              $73 = __THREW__; __THREW__ = 0;
              $74 = $73&1;
              if ($74) {
               break;
              }
              do {
               if ($72) {
                __THREW__ = 0;
                invoke_vi(3799,($t1|0));
                $75 = __THREW__; __THREW__ = 0;
                $76 = $75&1;
                if ($76) {
                 break L4;
                }
                __THREW__ = 0;
                $77 = (invoke_iii(2730,(2239448|0),($t1|0))|0);
                $78 = __THREW__; __THREW__ = 0;
                $79 = $78&1;
                if ($79) {
                 break L4;
                }
                __THREW__ = 0;
                $80 = (invoke_iii(2762,($77|0),($t2|0))|0);
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if ($82) {
                 break L4;
                }
                $83 = ($80|0)<(0);
                if ($83) {
                 break;
                } else {
                 $$0 = -1;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              } while(0);
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZL86mscorlib_System_Array_m_IndexOf_mscorlib_System_Type_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP24mscorlib_System_Type_arrP20mscorlib_System_Type($p0,$p1) {
 $p0 = $p0|0;
 $p1 = $p1|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z96mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_PPv(0,$p0,$p1,2963960)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z58mscorlib_System_Reflection_Binder_Default_m_SelectPropertyP41mscorlib_System_Reflection_Binder_DefaultiP43mscorlib_System_Reflection_PropertyInfo_arrP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$bindingAttr,$match,$returnType,$indexes,$modifiers) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $match = $match|0;
 $returnType = $returnType|0;
 $indexes = $indexes|0;
 $modifiers = $modifiers|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $G_B6_0$0 = 0, $V_2$1$ph36 = 0, $V_2$1$ph3664 = 0;
 var $V_2$1$ph42 = 0, $V_3$0152243$in = 0, $V_3$01524$in = 0, $V_3$016 = 0, $V_3$016$in = 0, $V_4$1$ph31 = 0, $V_4$1$ph41 = 0, $V_5$1$ph40 = 0, $V_5$1$ph423 = 0, $V_6$1$ph39 = 0, $V_9$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397808);
 __THREW__ = 0;
 invoke_v(614);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($match|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($match|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    $9 = (($match) + 12|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($10|0)==(0);
    if (!($11)) {
     $23 = ($returnType|0)==(0|0);
     $24 = ($indexes|0)==(0|0);
     if ($24) {
      $G_B6_0$0 = -1;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($indexes|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      $27 = (($indexes) + 12|0);
      $28 = HEAP32[$27>>2]|0;
      $G_B6_0$0 = $28;
     }
     __THREW__ = 0;
     invoke_vi(3799,($match|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     $31 = HEAP32[$9>>2]|0;
     $32 = ($31|0)>(0);
     if (!($32)) {
      $V_2$1$ph3664 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($V_2$1$ph3664|0);
     }
     $33 = (($match) + 16|0);
     $34 = ($G_B6_0$0|0)<(0);
     $35 = ($G_B6_0$0|0)<(1);
     $V_2$1$ph42 = 0;$V_3$0152243$in = $31;$V_4$1$ph41 = 2147483646;$V_5$1$ph40 = 2147483647;$V_6$1$ph39 = 0;
     L15: while(1) {
      $83 = ($V_2$1$ph42|0)==(0|0);
      $V_3$01524$in = $V_3$0152243$in;$V_5$1$ph423 = $V_5$1$ph40;
      L17: while(1) {
       $V_3$016$in = $V_3$01524$in;
       L19: while(1) {
        $V_3$016 = (($V_3$016$in) + -1)|0;
        __THREW__ = 0;
        invoke_vi(3799,($match|0));
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 3;
         break L15;
        }
        $36 = HEAP32[$9>>2]|0;
        $37 = ($V_3$016>>>0)<($36>>>0);
        if (!($37)) {
         __THREW__ = 0;
         $38 = (invoke_i(132)|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          label = 3;
          break L15;
         }
         __THREW__ = 0;
         invoke_vi(3302,($38|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          label = 3;
          break L15;
         }
        }
        $43 = HEAP32[$match>>2]|0;
        $44 = (($43) + 92|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = Math_imul($45, $V_3$016)|0;
        $47 = (($33) + ($46)|0);
        $48 = HEAP32[$47>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($48|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 3;
         break L15;
        }
        __THREW__ = 0;
        $51 = (invoke_iii(2730,(2397856|0),($48|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 3;
         break L15;
        }
        if ($34) {
         label = 27;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($51|0));
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 3;
          break L15;
         }
         $56 = (($51) + 12|0);
         $57 = HEAP32[$56>>2]|0;
         $58 = ($G_B6_0$0|0)==($57|0);
         if ($58) {
          label = 27;
         }
        }
        do {
         if ((label|0) == 27) {
          label = 0;
          if (!($23)) {
           __THREW__ = 0;
           invoke_vi(3799,($48|0));
           $59 = __THREW__; __THREW__ = 0;
           $60 = $59&1;
           if ($60) {
            label = 3;
            break L15;
           }
           __THREW__ = 0;
           $61 = (invoke_iii(2730,(2397904|0),($48|0))|0);
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if ($63) {
            label = 3;
            break L15;
           }
           $64 = ($61|0)==($returnType|0);
           if (!($64)) {
            break;
           }
          }
          if ($35) {
           $V_9$0 = 2147483646;
          } else {
           __THREW__ = 0;
           $65 = (invoke_iiii(855,0,($indexes|0),($51|0))|0);
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            label = 3;
            break L15;
           }
           $68 = ($65|0)==(-1);
           if ($68) {
            break;
           } else {
            $V_9$0 = $65;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($48|0));
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           label = 3;
           break L15;
          }
          __THREW__ = 0;
          $71 = (invoke_iii(2730,(2242504|0),($48|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           label = 3;
           break L15;
          }
          __THREW__ = 0;
          $74 = (invoke_iii(904,0,($71|0))|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 3;
           break L15;
          }
          if ($83) {
           break L17;
          }
          $77 = ($V_4$1$ph41|0)<($V_9$0|0);
          if ($77) {
           break;
          }
          $78 = ($V_4$1$ph41|0)==($V_9$0|0);
          if (!($78)) {
           break L17;
          }
          $79 = ($V_6$1$ph39|0)==($74|0);
          if ($79) {
           break L19;
          }
          $80 = ($V_6$1$ph39|0)>($74|0);
          if (!($80)) {
           break L17;
          }
         }
        } while(0);
        $81 = ($V_3$016|0)>(0);
        if ($81) {
         $V_3$016$in = $V_3$016;
        } else {
         $V_2$1$ph36 = $V_2$1$ph42;$V_4$1$ph31 = $V_4$1$ph41;
         label = 48;
         break L15;
        }
       }
       $84 = ($V_3$016|0)>(0);
       if ($84) {
        $V_3$01524$in = $V_3$016;$V_5$1$ph423 = $V_4$1$ph41;
       } else {
        break L15;
       }
      }
      $82 = ($V_3$016|0)>(0);
      if ($82) {
       $V_2$1$ph42 = $48;$V_3$0152243$in = $V_3$016;$V_4$1$ph41 = $V_9$0;$V_5$1$ph40 = $V_5$1$ph423;$V_6$1$ph39 = $74;
      } else {
       $V_2$1$ph36 = $48;$V_4$1$ph31 = $V_9$0;
       label = 48;
       break;
      }
     }
     if ((label|0) == 3) {
      $3 = ___cxa_find_matching_catch()|0;
      $4 = tempRet0;
      $lpad$phi$index = $3;$lpad$phi$index2 = $4;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 48) {
      $87 = ($V_5$1$ph423|0)>($V_4$1$ph31|0);
      if ($87) {
       $V_2$1$ph3664 = $V_2$1$ph36;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($V_2$1$ph3664|0);
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2375288|0))|0);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      break;
     }
     __THREW__ = 0;
     $90 = (invoke_ii(3469,(2375288|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2261,($90|0));
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3834,($90|0));
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560072|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2560072|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3030984>>2]|0;
     $18 = HEAP32[3030992>>2]|0;
     __THREW__ = 0;
     invoke_viii(641,($14|0),($17|0),($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3834,($14|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Reflection_Binder_Default_m_check_arguments_with_scoreP22mscorlib_System_ObjectP24mscorlib_System_Type_arrP44mscorlib_System_Reflection_ParameterInfo_arr($__this,$types,$args) {
 $__this = $__this|0;
 $types = $types|0;
 $args = $args|0;
 var $$0 = 0, $$V_0$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$1 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397952);
 $0 = (($types) + 12|0);
 $1 = (($types) + 16|0);
 $2 = (($args) + 16|0);
 $3 = (($args) + 12|0);
 $V_0$1 = -1;$V_1$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($types|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   label = 5;
   break;
  }
  $47 = HEAP32[$0>>2]|0;
  $48 = ($V_1$0|0)<($47|0);
  if (!($48)) {
   $$0 = $V_0$1;
   label = 18;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($types|0));
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if ($50) {
   label = 5;
   break;
  }
  $4 = HEAP32[$0>>2]|0;
  $5 = ($V_1$0>>>0)<($4>>>0);
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_i(132)|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 5;
    break;
   }
  }
  $13 = HEAP32[$types>>2]|0;
  $14 = (($13) + 92|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = Math_imul($15, $V_1$0)|0;
  $17 = (($1) + ($16)|0);
  $18 = HEAP32[$17>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($args|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   label = 5;
   break;
  }
  $21 = HEAP32[$3>>2]|0;
  $22 = ($V_1$0>>>0)<($21>>>0);
  if (!($22)) {
   __THREW__ = 0;
   $23 = (invoke_i(132)|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if ($25) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($23|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 5;
    break;
   }
  }
  $28 = HEAP32[$args>>2]|0;
  $29 = (($28) + 92|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = Math_imul($30, $V_1$0)|0;
  $32 = (($2) + ($31)|0);
  $33 = HEAP32[$32>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($33|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $36 = (invoke_iii(2730,(2397472|0),($33|0))|0);
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if ($38) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $39 = (invoke_iiii(856,0,($18|0),($36|0))|0);
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   label = 5;
   break;
  }
  $42 = ($39|0)==(-1);
  if ($42) {
   $$0 = -1;
   label = 18;
   break;
  }
  $43 = ($V_0$1|0)<($39|0);
  $$V_0$1 = $43 ? $39 : $V_0$1;
  $44 = (($V_1$0) + 1)|0;
  $V_0$1 = $$V_0$1;$V_1$0 = $44;
 }
 if ((label|0) == 5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 }
 else if ((label|0) == 18) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Reflection_Binder_m_GetDerivedLevelP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2399440);
 $V_0$0 = $type;$V_1$0 = 1;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($V_0$0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  $5 = (invoke_iii(2730,(2235944|0),($V_0$0|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 8;
   break;
  }
  $8 = ($5|0)==(0|0);
  if ($8) {
   label = 9;
   break;
  }
  $9 = (($V_1$0) + 1)|0;
  __THREW__ = 0;
  invoke_vi(3799,($V_0$0|0));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  $0 = (invoke_iii(2730,(2235944|0),($V_0$0|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if ($2) {
   label = 8;
   break;
  }
  $V_0$0 = $0;$V_1$0 = $9;
 }
 if ((label|0) == 8) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($12|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_1$0|0);
 }
 return 0|0;
}
function __Z65mscorlib_System_Reflection_Binder_Default_m_check_type_with_scoreP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_($__this,$from,$to) {
 $__this = $__this|0;
 $from = $from|0;
 $to = $to|0;
 var $$ = 0, $$0 = 0, $$53 = 0, $$54 = 0, $$55 = 0, $$byval_copy7 = 0, $$off = 0, $$off50 = 0, $$off51 = 0, $$off52 = 0, $$off56 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0;
 var $or$cond11 = 0, $or$cond17 = 0, $or$cond19 = 0, $or$cond21 = 0, $or$cond23 = 0, $or$cond25 = 0, $or$cond27 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy7 = sp + 36|0;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 28|0;
 $1 = sp + 24|0;
 $2 = sp + 20|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp + 4|0;
 $6 = sp;
 $7 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2398000);
 $8 = ($from|0)==(0|0);
 L1: do {
  if ($8) {
   __THREW__ = 0;
   invoke_vi(3799,($to|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    label = 5;
   } else {
    __THREW__ = 0;
    $11 = (invoke_iii(2734,(2234232|0),($to|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 5;
    } else {
     $$ = $11 << 31 >> 31;
     $$0 = $$;
     label = 74;
    }
   }
  } else {
   $16 = ($from|0)==($to|0);
   if ($16) {
    $$0 = 0;
    label = 74;
   } else {
    HEAP32[$0>>2] = 1284448;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$0+0>>2]|0;
    $17 = (invoke_iii(772,(0|0),($$byval_copy7|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     label = 5;
    } else {
     $20 = ($17|0)==($to|0);
     if ($20) {
      $$0 = 4;
      label = 74;
     } else {
      __THREW__ = 0;
      $21 = (invoke_iii(771,(0|0),($from|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 5;
      } else {
       __THREW__ = 0;
       $24 = (invoke_iii(771,(0|0),($to|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        label = 5;
       } else {
        switch ($21|0) {
        case 6:  {
         $36 = (($24) + -4)|0;
         $37 = ($36|0)==(0);
         if ($37) {
          $$0 = 2;
          label = 74;
          break L1;
         }
         $$off50 = (($24) + -5)|0;
         $38 = ($$off50>>>0)<(2);
         if (!($38)) {
          $$off51 = (($24) + -7)|0;
          $39 = ($$off51>>>0)<(2);
          $40 = ($36|0)==(5);
          $or$cond17 = $39 | $40;
          $41 = ($36|0)==(6);
          $or$cond19 = $or$cond17 | $41;
          $42 = ($36|0)==(7);
          $or$cond21 = $or$cond19 | $42;
          $43 = ($36|0)==(8);
          $or$cond23 = $or$cond21 | $43;
          $44 = ($36|0)==(9);
          $or$cond25 = $or$cond23 | $44;
          $45 = ($36|0)==(10);
          $or$cond27 = $or$cond25 | $45;
          if ($or$cond27) {
           $$0 = 2;
           label = 74;
           break L1;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($from|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          label = 5;
          break L1;
         }
         __THREW__ = 0;
         $48 = (invoke_iii(2734,(2215792|0),($from|0))|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if ($50) {
          label = 5;
          break L1;
         }
         if ($48) {
          HEAP32[$1>>2] = 2269384;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$1+0>>2]|0;
          $51 = (invoke_iii(772,(0|0),($$byval_copy7|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           label = 5;
           break L1;
          }
          $54 = ($51|0)==($to|0);
          if ($54) {
           $$0 = 1;
           label = 74;
           break L1;
          }
         }
         $$0 = -1;
         label = 74;
         break L1;
         break;
        }
        case 8:  {
         $67 = (($24) + -9)|0;
         $68 = ($67>>>0)<(6);
         if ($68) {
          $$0 = 2;
          label = 74;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($from|0));
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          label = 5;
          break L1;
         }
         __THREW__ = 0;
         $71 = (invoke_iii(2734,(2215792|0),($from|0))|0);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          label = 5;
          break L1;
         }
         if ($71) {
          HEAP32[$3>>2] = 2269384;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$3+0>>2]|0;
          $74 = (invoke_iii(772,(0|0),($$byval_copy7|0))|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           label = 5;
           break L1;
          }
          $77 = ($74|0)==($to|0);
          if ($77) {
           $$0 = 1;
           label = 74;
           break L1;
          }
         }
         $$0 = -1;
         label = 74;
         break L1;
         break;
        }
        case 5:  {
         switch ($24|0) {
         case 12: case 10: case 8:  {
          break;
         }
         case 11: case 9: case 7:  {
          $$0 = 2;
          label = 74;
          break L1;
          break;
         }
         default: {
          $55 = (($24) + -7)|0;
          $56 = $55 & -2;
          $57 = ($56|0)==(6);
          if ($57) {
           $$0 = 2;
           label = 74;
           break L1;
          }
         }
         }
         __THREW__ = 0;
         invoke_vi(3799,($from|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          label = 5;
          break L1;
         }
         __THREW__ = 0;
         $60 = (invoke_iii(2734,(2215792|0),($from|0))|0);
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          label = 5;
          break L1;
         }
         if ($60) {
          HEAP32[$2>>2] = 2269384;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$2+0>>2]|0;
          $63 = (invoke_iii(772,(0|0),($$byval_copy7|0))|0);
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           label = 5;
           break L1;
          }
          $66 = ($63|0)==($to|0);
          if ($66) {
           $$0 = 1;
           label = 74;
           break L1;
          }
         }
         $$0 = -1;
         label = 74;
         break L1;
         break;
        }
        case 4:  {
         $29 = (($24) + -8)|0;
         $30 = ($29|0)==(0);
         if ($30) {
          $$0 = 0;
          label = 74;
          break L1;
         }
         $$off52 = (($24) + -9)|0;
         $31 = ($$off52>>>0)<(2);
         $32 = ($29|0)==(3);
         $or$cond5 = $31 | $32;
         $33 = ($29|0)==(4);
         $or$cond7 = $or$cond5 | $33;
         $34 = ($29|0)==(5);
         $or$cond9 = $or$cond7 | $34;
         $35 = ($29|0)==(6);
         $or$cond11 = $or$cond9 | $35;
         $$53 = $or$cond11 ? 2 : -1;
         $$0 = $$53;
         label = 74;
         break L1;
         break;
        }
        case 7:  {
         if ((($24|0) == 11) | (($24|0) == 9)) {
          $$0 = 2;
          label = 74;
          break L1;
         } else if (!((($24|0) == 12) | (($24|0) == 10))) {
          $78 = (($24) + -9)|0;
          $79 = $78 & -2;
          $80 = ($79|0)==(4);
          if ($80) {
           $$0 = 2;
           label = 74;
           break L1;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($from|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          label = 5;
          break L1;
         }
         __THREW__ = 0;
         $83 = (invoke_iii(2734,(2215792|0),($from|0))|0);
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          label = 5;
          break L1;
         }
         if ($83) {
          HEAP32[$4>>2] = 2269384;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$4+0>>2]|0;
          $86 = (invoke_iii(772,(0|0),($$byval_copy7|0))|0);
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           label = 5;
           break L1;
          }
          $89 = ($86|0)==($to|0);
          if ($89) {
           $$0 = 1;
           label = 74;
           break L1;
          }
         }
         $$0 = -1;
         label = 74;
         break L1;
         break;
        }
        case 10:  {
         $90 = (($24) + -11)|0;
         $91 = ($90>>>0)<(4);
         if ($91) {
          $$0 = 2;
          label = 74;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($from|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          label = 5;
          break L1;
         }
         __THREW__ = 0;
         $94 = (invoke_iii(2734,(2215792|0),($from|0))|0);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          label = 5;
          break L1;
         }
         if ($94) {
          HEAP32[$5>>2] = 2269384;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$5+0>>2]|0;
          $97 = (invoke_iii(772,(0|0),($$byval_copy7|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           label = 5;
           break L1;
          }
          $100 = ($97|0)==($to|0);
          if ($100) {
           $$0 = 1;
           label = 74;
           break L1;
          }
         }
         $$0 = -1;
         label = 74;
         break L1;
         break;
        }
        case 9:  {
         if ((($24|0) == 11)) {
          $$0 = 2;
          label = 74;
          break L1;
         } else if (!((($24|0) == 12))) {
          $101 = (($24) + -11)|0;
          $102 = $101 & -2;
          $103 = ($102|0)==(2);
          if ($103) {
           $$0 = 2;
           label = 74;
           break L1;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($from|0));
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 5;
          break L1;
         }
         __THREW__ = 0;
         $106 = (invoke_iii(2734,(2215792|0),($from|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          label = 5;
          break L1;
         }
         if ($106) {
          HEAP32[$6>>2] = 2269384;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$6+0>>2]|0;
          $109 = (invoke_iii(772,(0|0),($$byval_copy7|0))|0);
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           label = 5;
           break L1;
          }
          $112 = ($109|0)==($to|0);
          if ($112) {
           $$0 = 1;
           label = 74;
           break L1;
          }
         }
         $$0 = -1;
         label = 74;
         break L1;
         break;
        }
        default: {
         $$off = (($21) + -11)|0;
         $27 = ($$off>>>0)<(2);
         if (!($27)) {
          $28 = ($21|0)==(13);
          if ($28) {
           $122 = ($24|0)==(14);
           $$54 = $122 ? 2 : -1;
           $$0 = $$54;
           label = 74;
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3799,($to|0));
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if ($124) {
           label = 5;
           break L1;
          }
          __THREW__ = 0;
          $125 = (invoke_iiii(1640,(2235992|0),($to|0),($from|0))|0);
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           label = 5;
           break L1;
          }
          $$55 = $125 ? 3 : -1;
          $$0 = $$55;
          label = 74;
          break L1;
         }
         $$off56 = (($24) + -13)|0;
         $switch = ($$off56>>>0)<(2);
         if ($switch) {
          $$0 = 2;
          label = 74;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($from|0));
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          label = 5;
          break L1;
         }
         __THREW__ = 0;
         $115 = (invoke_iii(2734,(2215792|0),($from|0))|0);
         $116 = __THREW__; __THREW__ = 0;
         $117 = $116&1;
         if ($117) {
          label = 5;
          break L1;
         }
         if ($115) {
          HEAP32[$7>>2] = 2269384;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy7+0>>2]=HEAP32[$7+0>>2]|0;
          $118 = (invoke_iii(772,(0|0),($$byval_copy7|0))|0);
          $119 = __THREW__; __THREW__ = 0;
          $120 = $119&1;
          if ($120) {
           label = 5;
           break L1;
          }
          $121 = ($118|0)==($to|0);
          if ($121) {
           $$0 = 1;
           label = 74;
           break L1;
          }
         }
         $$0 = -1;
         label = 74;
         break L1;
        }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 }
 else if ((label|0) == 74) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker7I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_S0_S0_S0_E6InvokeEPFPvS3_iS3_S3_S3_S3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 24|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$1,$3,$5,$7,$9,$11,$13)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker3I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsS1_E6InvokeEPFP22mscorlib_System_ObjectPvS4_S5_S5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEPFvPvS3_P22mscorlib_System_ObjectES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$2);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_iS4_S4_S4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$1,$3,$5,$7,$11)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN12FuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEPFPvS3_iS3_S3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$1,$3,$5,$7,$9)|0);
 STACKTOP = sp;return ($10|0);
}
function __Z137mscorlib_System_Reflection_Binder_Default_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Binder_Default_m_ReorderArgumentArrayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2398896)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z42mscorlib_System_Reflection_Binder_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2399248);
 __THREW__ = 0;
 (invoke_ii(2996,(2399064|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2399064|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2280,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2400328|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2400328 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z53mscorlib_System_Reflection_Binder_m_get_DefaultBinderP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2399296);
 __THREW__ = 0;
 (invoke_ii(2996,(2400328|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2400328 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2400328|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2400328|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3835,(2400328|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2400328|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2400328 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_Reflection_Binder_m_ConvertArgsP22mscorlib_System_ObjectP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP44mscorlib_System_Reflection_ParameterInfo_arrP41mscorlib_System_Globalization_CultureInfo($__this,$binder,$args,$pinfo,$culture) {
 $__this = $__this|0;
 $binder = $binder|0;
 $args = $args|0;
 $pinfo = $pinfo|0;
 $culture = $culture|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2399344);
 $0 = ($args|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   invoke_vi(3799,($pinfo|0));
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = (($pinfo) + 12|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = ($4|0)==(0);
    if ($5) {
     $$0 = 1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2436368|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2436368|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(2324,($12|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3834,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($pinfo|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = (($pinfo) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($args|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = (($args) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($22|0)==($26|0);
     if (!($27)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2436368|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_ii(3469,(2436368|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(2324,($32|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3834,($32|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      // unreachable;
     }
     $28 = (($args) + 16|0);
     $29 = (($pinfo) + 16|0);
     $V_0$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($args|0));
      $111 = __THREW__; __THREW__ = 0;
      $112 = $111&1;
      if ($112) {
       label = 4;
       break;
      }
      $113 = HEAP32[$25>>2]|0;
      $114 = ($V_0$0|0)<($113|0);
      if (!($114)) {
       $$0 = 1;
       label = 47;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($args|0));
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       label = 4;
       break;
      }
      $39 = HEAP32[$25>>2]|0;
      $40 = ($V_0$0>>>0)<($39>>>0);
      if (!($40)) {
       __THREW__ = 0;
       $41 = (invoke_i(132)|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($41|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 4;
        break;
       }
      }
      $46 = HEAP32[$args>>2]|0;
      $47 = (($46) + 92|0);
      $48 = HEAP32[$47>>2]|0;
      $49 = Math_imul($48, $V_0$0)|0;
      $50 = (($28) + ($49)|0);
      $51 = HEAP32[$50>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($pinfo|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      $54 = HEAP32[$21>>2]|0;
      $55 = ($V_0$0>>>0)<($54>>>0);
      if (!($55)) {
       __THREW__ = 0;
       $56 = (invoke_i(132)|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($56|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        label = 4;
        break;
       }
      }
      $61 = HEAP32[$pinfo>>2]|0;
      $62 = (($61) + 92|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = Math_imul($63, $V_0$0)|0;
      $65 = (($29) + ($64)|0);
      $66 = HEAP32[$65>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($66|0));
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $69 = (invoke_iii(2730,(2397472|0),($66|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($binder|0));
      $72 = __THREW__; __THREW__ = 0;
      $73 = $72&1;
      if ($73) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $74 = (invoke_iiiiii(236,(2399392|0),($binder|0),($51|0),($69|0),($culture|0))|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 4;
       break;
      }
      $77 = ($74|0)==(0|0);
      if ($77) {
       __THREW__ = 0;
       invoke_vi(3799,($args|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 4;
        break;
       }
       $80 = HEAP32[$25>>2]|0;
       $81 = ($V_0$0>>>0)<($80>>>0);
       if (!($81)) {
        __THREW__ = 0;
        $82 = (invoke_i(132)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($82|0));
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
       }
       $87 = HEAP32[$args>>2]|0;
       $88 = (($87) + 92|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = Math_imul($89, $V_0$0)|0;
       $91 = (($28) + ($90)|0);
       $92 = HEAP32[$91>>2]|0;
       $93 = ($92|0)==(0|0);
       if (!($93)) {
        $$0 = 0;
        label = 47;
        break;
       }
      }
      __THREW__ = 0;
      invoke_vi(3799,($args|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if ($95) {
       label = 4;
       break;
      }
      $96 = HEAP32[$25>>2]|0;
      $97 = ($V_0$0>>>0)<($96>>>0);
      if (!($97)) {
       __THREW__ = 0;
       $98 = (invoke_i(132)|0);
       $99 = __THREW__; __THREW__ = 0;
       $100 = $99&1;
       if ($100) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($98|0));
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        label = 4;
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($args|0),($74|0));
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       label = 4;
       break;
      }
      $105 = HEAP32[$args>>2]|0;
      $106 = (($105) + 92|0);
      $107 = HEAP32[$106>>2]|0;
      $108 = Math_imul($107, $V_0$0)|0;
      $109 = (($28) + ($108)|0);
      HEAP32[$109>>2] = $74;
      $110 = (($V_0$0) + 1)|0;
      $V_0$0 = $110;
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 47) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Reflection_TargetParameterCountException_m__ctor_mscorlib_System_VoidP56mscorlib_System_Reflection_TargetParameterCountException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2436088);
 __THREW__ = 0;
 invoke_v(615);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3033800>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1781,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __ZN16VirtFuncInvoker3I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS5_S5_($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z56mscorlib_System_Reflection_Binder_m_FindMostDerivedMatchP22mscorlib_System_ObjectP41mscorlib_System_Reflection_MethodBase_arr($__this,$match) {
 $__this = $__this|0;
 $match = $match|0;
 var $$V_0$1 = 0, $$sum = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$117 = 0, $V_1$1$lcssa = 0;
 var $V_1$115 = 0, $V_3$0$V_1$1 = 0, $V_3$014 = 0, $V_9$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2399488);
 __THREW__ = 0;
 invoke_vi(3799,($match|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = (($match) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>(0);
   L3: do {
    if ($4) {
     $5 = (($match) + 16|0);
     $V_0$117 = 0;$V_1$115 = -1;$V_3$014 = 0;
     L5: while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($match|0));
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       label = 5;
       break;
      }
      $12 = HEAP32[$2>>2]|0;
      $13 = ($V_3$014>>>0)<($12>>>0);
      if (!($13)) {
       __THREW__ = 0;
       $14 = (invoke_i(132)|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        label = 5;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($14|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        label = 5;
        break;
       }
      }
      $19 = HEAP32[$match>>2]|0;
      $20 = (($19) + 92|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = Math_imul($21, $V_3$014)|0;
      $23 = (($5) + ($22)|0);
      $24 = HEAP32[$23>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($24|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_iii(2730,(2242504|0),($24|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      $30 = (invoke_iii(904,0,($27|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 5;
       break;
      }
      $33 = ($30|0)==($V_0$117|0);
      if ($33) {
       label = 15;
       break;
      }
      $43 = ($V_1$115|0)<(0);
      L16: do {
       if (!($43)) {
        __THREW__ = 0;
        invoke_vi(3799,($24|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         label = 5;
         break L5;
        }
        __THREW__ = 0;
        $46 = (invoke_iii(2730,(2397136|0),($24|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 5;
         break L5;
        }
        __THREW__ = 0;
        invoke_vi(3799,($match|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 5;
         break L5;
        }
        $51 = HEAP32[$2>>2]|0;
        $52 = ($V_1$115>>>0)<($51>>>0);
        if (!($52)) {
         __THREW__ = 0;
         $53 = (invoke_i(132)|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 5;
          break L5;
         }
         __THREW__ = 0;
         invoke_vi(3302,($53|0));
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          label = 5;
          break L5;
         }
        }
        $58 = HEAP32[$match>>2]|0;
        $59 = (($58) + 92|0);
        $60 = HEAP32[$59>>2]|0;
        $61 = Math_imul($60, $V_1$115)|0;
        $62 = (($5) + ($61)|0);
        $63 = HEAP32[$62>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($63|0));
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 5;
         break L5;
        }
        __THREW__ = 0;
        $66 = (invoke_iii(2730,(2397136|0),($63|0))|0);
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         label = 5;
         break L5;
        }
        __THREW__ = 0;
        invoke_vi(3799,($46|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 5;
         break L5;
        }
        $71 = (($46) + 12|0);
        $72 = HEAP32[$71>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($66|0));
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 5;
         break L5;
        }
        $75 = (($66) + 12|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($72|0)==($76|0);
        if (!($77)) {
         label = 48;
         break L5;
        }
        $V_9$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($46|0));
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          label = 4;
          break L5;
         }
         $120 = HEAP32[$71>>2]|0;
         $121 = ($V_9$0|0)<($120|0);
         if (!($121)) {
          break L16;
         }
         __THREW__ = 0;
         invoke_vi(3799,($46|0));
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 4;
          break L5;
         }
         $78 = HEAP32[$71>>2]|0;
         $79 = ($V_9$0>>>0)<($78>>>0);
         if (!($79)) {
          __THREW__ = 0;
          $80 = (invoke_i(132)|0);
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           label = 4;
           break L5;
          }
          __THREW__ = 0;
          invoke_vi(3302,($80|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           label = 4;
           break L5;
          }
         }
         $85 = HEAP32[$46>>2]|0;
         $86 = (($85) + 92|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = Math_imul($87, $V_9$0)|0;
         $$sum = (($88) + 16)|0;
         $89 = (($46) + ($$sum)|0);
         $90 = HEAP32[$89>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($90|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 4;
          break L5;
         }
         __THREW__ = 0;
         $93 = (invoke_iii(2730,(2397472|0),($90|0))|0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          label = 4;
          break L5;
         }
         __THREW__ = 0;
         invoke_vi(3799,($66|0));
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          label = 4;
          break L5;
         }
         $98 = HEAP32[$75>>2]|0;
         $99 = ($V_9$0>>>0)<($98>>>0);
         if (!($99)) {
          __THREW__ = 0;
          $100 = (invoke_i(132)|0);
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if ($102) {
           label = 4;
           break L5;
          }
          __THREW__ = 0;
          invoke_vi(3302,($100|0));
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           label = 4;
           break L5;
          }
         }
         $105 = HEAP32[$66>>2]|0;
         $106 = (($105) + 92|0);
         $107 = HEAP32[$106>>2]|0;
         $108 = Math_imul($107, $V_9$0)|0;
         $$sum3 = (($108) + 16)|0;
         $109 = (($66) + ($$sum3)|0);
         $110 = HEAP32[$109>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($110|0));
         $111 = __THREW__; __THREW__ = 0;
         $112 = $111&1;
         if ($112) {
          label = 4;
          break L5;
         }
         __THREW__ = 0;
         $113 = (invoke_iii(2730,(2397472|0),($110|0))|0);
         $114 = __THREW__; __THREW__ = 0;
         $115 = $114&1;
         if ($115) {
          label = 4;
          break L5;
         }
         $116 = ($93|0)==($113|0);
         $117 = (($V_9$0) + 1)|0;
         if ($116) {
          $V_9$0 = $117;
         } else {
          label = 48;
          break L5;
         }
        }
       }
      } while(0);
      $133 = ($30|0)>($V_0$117|0);
      $V_3$0$V_1$1 = $133 ? $V_3$014 : $V_1$115;
      $$V_0$1 = $133 ? $30 : $V_0$117;
      $134 = (($V_3$014) + 1)|0;
      $135 = ($134|0)<($3|0);
      if ($135) {
       $V_0$117 = $$V_0$1;$V_1$115 = $V_3$0$V_1$1;$V_3$014 = $134;
      } else {
       $V_1$1$lcssa = $V_3$0$V_1$1;
       break L3;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index3 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 5) {
      $8 = ___cxa_find_matching_catch()|0;
      $9 = tempRet0;
      $lpad$phi$index = $8;$lpad$phi$index3 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 15) {
      __THREW__ = 0;
      (invoke_ii(2996,(2375288|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L1;
      }
      __THREW__ = 0;
      $36 = (invoke_ii(3469,(2375288|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(2261,($36|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3834,($36|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break L1;
      }
      // unreachable;
     }
     else if ((label|0) == 48) {
      __THREW__ = 0;
      (invoke_ii(2996,(2375288|0))|0);
      $124 = __THREW__; __THREW__ = 0;
      $125 = $124&1;
      if ($125) {
       break L1;
      }
      __THREW__ = 0;
      $126 = (invoke_ii(3469,(2375288|0))|0);
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(2261,($126|0));
      $129 = __THREW__; __THREW__ = 0;
      $130 = $129&1;
      if ($130) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3834,($126|0));
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       break L1;
      }
      // unreachable;
     }
    } else {
     $V_1$1$lcssa = -1;
    }
   } while(0);
   __THREW__ = 0;
   invoke_vi(3799,($match|0));
   $138 = __THREW__; __THREW__ = 0;
   $139 = $138&1;
   if (!($139)) {
    $140 = ($V_1$1$lcssa|0)<(0);
    if (!($140)) {
     $141 = HEAP32[$2>>2]|0;
     $142 = ($V_1$1$lcssa>>>0)<($141>>>0);
     if ($142) {
      $148 = HEAP32[$match>>2]|0;
      $149 = (($match) + 16|0);
      $150 = (($148) + 92|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = Math_imul($151, $V_1$1$lcssa)|0;
      $153 = (($149) + ($152)|0);
      $154 = HEAP32[$153>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($154|0);
     }
    }
    __THREW__ = 0;
    $143 = (invoke_i(132)|0);
    $144 = __THREW__; __THREW__ = 0;
    $145 = $144&1;
    if (!($145)) {
     __THREW__ = 0;
     invoke_vi(3302,($143|0));
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if (!($147)) {
      $148 = HEAP32[$match>>2]|0;
      $149 = (($match) + 16|0);
      $150 = (($148) + 92|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = Math_imul($151, $V_1$1$lcssa)|0;
      $153 = (($149) + ($152)|0);
      $154 = HEAP32[$153>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($154|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index3 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker4I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_S1_E6InvokeEPFbPvS3_S3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$6)|0);
 $8 = $7&1;
 HEAP8[$ret>>0] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __Z64mscorlib_System_Reflection_Binder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Reflection_BindingFlags_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Reflection_CallingConventions_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z51mscorlib_System_Reflection_ConstructorInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2402336);
 __THREW__ = 0;
 invoke_v(616);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3031056>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2403064|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[((2403064 + 80|0))>>2]|0;
   HEAP32[$5>>2] = $2;
   $6 = HEAP32[3031064>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2403064|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[((2403064 + 80|0))>>2]|0;
    $10 = (($9) + 4|0);
    HEAP32[$10>>2] = $6;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z59mscorlib_System_Reflection_ConstructorInfo_m_get_MemberTypeP42mscorlib_System_Reflection_ConstructorInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2402384);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z105mscorlib_System_Reflection_ConstructorInfo_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_arr_arrP42mscorlib_System_Reflection_ConstructorInfoP26mscorlib_System_Object_arr($__this,$parameters) {
 $__this = $__this|0;
 $parameters = $parameters|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2402432);
 $0 = ($parameters|0)==(0|0);
 if ($0) {
  __THREW__ = 0;
  (invoke_ii(2996,(1167664|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2760,(1167664|0),0)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $$0 = $3;
    label = 5;
   }
  }
 } else {
  $$0 = $parameters;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $6 = (invoke_iiiiiii(132,(2402480|0),($__this|0),512,(0|0),($$0|0),(0|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($6|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker4I28mscorlib_System_ObjectTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS2_S2_E6InvokeEP10MethodInfoPviS6_S6_S6_($method,$obj,$p1,$p2,$p3,$p4) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z73mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2450552)|0);
 $5 = HEAP32[((2450552 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($8,0);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGenerator_ConstructorNameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z93mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGenerator_TypeConstructorNameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z179mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_ConstructorInfo_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_arr_arrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2251976)|0);
 __Z59mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m__ctorP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318832)|0);
 __Z64mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m__ctorP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z146mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_ConstructorInfoTraits_MemberType_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73mscorlib_System_Reflection_EventAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_Reflection_EventInfo_m_get_EventHandlerTypeP36mscorlib_System_Reflection_EventInfo($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2403720);
 __THREW__ = 0;
 $0 = (invoke_iiii(1668,(2403768|0),($__this|0),1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2730,(2397136|0),($0|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = (($5) + 12|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ($11|0)<(1);
      if ($12) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($5|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = HEAP32[$10>>2]|0;
       $18 = ($17|0)==(0);
       if ($18) {
        __THREW__ = 0;
        $19 = (invoke_i(132)|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($19|0));
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break;
        }
       }
       $24 = (($5) + 16|0);
       $25 = HEAP32[$24>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($25|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __THREW__ = 0;
        $28 = (invoke_iii(2730,(2397472|0),($25|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         $$0 = $28;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_Reflection_EventInfo_m_get_MemberTypeP36mscorlib_System_Reflection_EventInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2403816);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 2;
}
function __Z67mscorlib_System_Reflection_EventInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2450984)|0);
 $7 = HEAP32[((2450984 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z73mscorlib_System_Reflection_FieldAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_Reflection_FieldInfo_m_get_MemberTypeP36mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2405456);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 4;
}
function __Z52mscorlib_System_Reflection_FieldInfo_m_get_IsLiteralP36mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2405504);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2405552|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 64;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Reflection_FieldInfo_m_get_IsStaticP36mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2405600);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2405552|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 16;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z58mscorlib_System_Reflection_FieldInfo_m_get_IsNotSerializedP36mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2405648);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2405552|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 128;
  $4 = ($3|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z114mscorlib_System_Reflection_FieldInfo_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_ObjectP36mscorlib_System_Reflection_FieldInfoP22mscorlib_System_ObjectS2_($__this,$obj,$value) {
 $__this = $__this|0;
 $obj = $obj|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2405696);
 __THREW__ = 0;
 invoke_viiiiiii(76,(2405744|0),($__this|0),($obj|0),($value|0),0,(0|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN18VirtActionInvoker5I28mscorlib_System_ObjectTraitsS0_27mscorlib_System_Int32Traits17VoidPointerTraitsS2_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS8_iS6_S6_($method,$obj,$p1,$p2,$p3,$p4,$p5) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4,$p5);
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_Reflection_FieldInfo_m_internal_from_handle_typeP22mscorlib_System_Object22mscorlib_System_IntPtrS1_($__this,$field_handle,$type_handle) {
 $__this = $__this|0;
 $field_handle = $field_handle|0;
 $type_handle = $type_handle|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2405792);
 $2 = HEAP32[2405840>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   __THREW__ = 0;
   $4 = (invoke_ii(3473,(2405848|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if ($6) {
    $7 = ___cxa_find_matching_catch()|0;
    $8 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($7|0);
    // unreachable;
   } else {
    HEAP32[2405840>>2] = $4;
    $11 = $4;
    break;
   }
  } else {
   $11 = $2;
  }
 } while(0);
 $9 = HEAP32[$field_handle>>2]|0;
 HEAP32[$0>>2] = $9;
 $10 = HEAP32[$type_handle>>2]|0;
 HEAP32[$1>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $12 = (invoke_iii($11|0,($$byval_copy|0),($$byval_copy1|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($12|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_FieldInfo_m_GetFieldFromHandleP22mscorlib_System_Object34mscorlib_System_RuntimeFieldHandle($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy2 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $$byval_copy2 = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2405936);
 __THREW__ = 0;
 invoke_v(617);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1912,($handle|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2210080|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[((2210080 + 80|0))>>2]|0;
     $12 = HEAP32[$11>>2]|0;
     HEAP32[$0>>2] = $6;
     HEAP32[$1>>2] = $12;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     $13 = (invoke_iiii(643,(0|0),($$byval_copy2|0),($$byval_copy3|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      if (!($13)) {
       __THREW__ = 0;
       $28 = (invoke_ii(1912,($handle|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2210080|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
       $33 = HEAP32[((2210080 + 80|0))>>2]|0;
       $34 = HEAP32[$33>>2]|0;
       HEAP32[$2>>2] = $28;
       HEAP32[$3>>2] = $34;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
       $35 = (invoke_iiii(858,0,($$byval_copy2|0),($$byval_copy3|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($35|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2560072|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $23 = HEAP32[3031112>>2]|0;
        __THREW__ = 0;
        invoke_vii(1924,($20|0),($23|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         invoke_vi(3834,($20|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_Reflection_FieldInfo_m_GetFieldOffsetP36mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2405984);
 __THREW__ = 0;
 invoke_v(618);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2649224|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2649224|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3031176>>2]|0;
    __THREW__ = 0;
    invoke_vii(1975,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3834,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Reflection_FieldInfo_m_GetUnmanagedMarshalP36mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2406032);
 $0 = HEAP32[2406080>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2406088|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2406080>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Reflection_FieldInfo_m_get_UMarshalP36mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2406144);
 __THREW__ = 0;
 $0 = (invoke_ii(2205,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z64mscorlib_System_Reflection_FieldInfo_m_GetPseudoCustomAttributesP36mscorlib_System_Reflection_FieldInfo($__this) {
 $__this = $__this|0;
 var $$ = 0, $$$ = 0, $$$$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$3 = 0, $V_0$4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2406192);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2405648|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $$ = $0&1;
   __THREW__ = 0;
   $3 = (invoke_iii(2730,(2242504|0),($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2734,(2234424|0),($3|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_iii(2730,(2406144|0),($__this|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = $0 ? 2 : 1;
       $$$ = $10 ? $16 : $$;
       $17 = ($13|0)!=(0|0);
       $18 = $17&1;
       $$$$ = (($18) + ($$$))|0;
       $19 = ($$$$|0)==(0);
       if ($19) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1167664|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        $22 = (invoke_iii(2760,(1167664|0),($$$$|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         $25 = (invoke_iii(2734,(2405648|0),($__this|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          if ($25) {
           __THREW__ = 0;
           (invoke_ii(2996,(2621960|0))|0);
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if ($29) {
            break;
           }
           __THREW__ = 0;
           $30 = (invoke_ii(3469,(2621960|0))|0);
           $31 = __THREW__; __THREW__ = 0;
           $32 = $31&1;
           if ($32) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(2752,($30|0));
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if ($34) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($22|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if ($36) {
            break;
           }
           $37 = (($22) + 12|0);
           $38 = HEAP32[$37>>2]|0;
           $39 = ($38|0)==(0);
           if ($39) {
            __THREW__ = 0;
            $40 = (invoke_i(132)|0);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($40|0));
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
           }
           __THREW__ = 0;
           invoke_vii(3492,($22|0),($30|0));
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            break;
           }
           $47 = (($22) + 16|0);
           HEAP32[$47>>2] = $30;
           $V_0$3 = 1;
          } else {
           $V_0$3 = 0;
          }
          __THREW__ = 0;
          $48 = (invoke_iii(2730,(2242504|0),($__this|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if (!($50)) {
           __THREW__ = 0;
           invoke_vi(3799,($48|0));
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if (!($52)) {
            __THREW__ = 0;
            $53 = (invoke_iii(2734,(2234424|0),($48|0))|0);
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if (!($55)) {
             if ($53) {
              $56 = (($V_0$3) + 1)|0;
              __THREW__ = 0;
              $57 = (invoke_iii(2729,(2405984|0),($__this|0))|0);
              $58 = __THREW__; __THREW__ = 0;
              $59 = $58&1;
              if ($59) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2253248|0))|0);
              $60 = __THREW__; __THREW__ = 0;
              $61 = $60&1;
              if ($61) {
               break;
              }
              __THREW__ = 0;
              $62 = (invoke_ii(3469,(2253248|0))|0);
              $63 = __THREW__; __THREW__ = 0;
              $64 = $63&1;
              if ($64) {
               break;
              }
              __THREW__ = 0;
              invoke_vii(1791,($62|0),($57|0));
              $65 = __THREW__; __THREW__ = 0;
              $66 = $65&1;
              if ($66) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($22|0));
              $67 = __THREW__; __THREW__ = 0;
              $68 = $67&1;
              if ($68) {
               break;
              }
              $69 = (($22) + 12|0);
              $70 = HEAP32[$69>>2]|0;
              $71 = ($V_0$3>>>0)<($70>>>0);
              if (!($71)) {
               __THREW__ = 0;
               $72 = (invoke_i(132)|0);
               $73 = __THREW__; __THREW__ = 0;
               $74 = $73&1;
               if ($74) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($72|0));
               $75 = __THREW__; __THREW__ = 0;
               $76 = $75&1;
               if ($76) {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vii(3492,($22|0),($62|0));
              $77 = __THREW__; __THREW__ = 0;
              $78 = $77&1;
              if ($78) {
               break;
              }
              $79 = HEAP32[$22>>2]|0;
              $80 = (($22) + 16|0);
              $81 = (($79) + 92|0);
              $82 = HEAP32[$81>>2]|0;
              $83 = (0 - ($V_0$3))|0;
              $84 = $82 & $83;
              $85 = (($80) + ($84)|0);
              HEAP32[$85>>2] = $62;
              $V_0$4 = $56;
             } else {
              $V_0$4 = $V_0$3;
             }
             if (!($17)) {
              $$0 = $22;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             invoke_vi(3799,($13|0));
             $86 = __THREW__; __THREW__ = 0;
             $87 = $86&1;
             if (!($87)) {
              __THREW__ = 0;
              $88 = (invoke_ii(2184,($13|0))|0);
              $89 = __THREW__; __THREW__ = 0;
              $90 = $89&1;
              if (!($90)) {
               __THREW__ = 0;
               invoke_vi(3799,($22|0));
               $91 = __THREW__; __THREW__ = 0;
               $92 = $91&1;
               if (!($92)) {
                $93 = (($22) + 12|0);
                $94 = HEAP32[$93>>2]|0;
                $95 = ($V_0$4>>>0)<($94>>>0);
                if (!($95)) {
                 __THREW__ = 0;
                 $96 = (invoke_i(132)|0);
                 $97 = __THREW__; __THREW__ = 0;
                 $98 = $97&1;
                 if ($98) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($96|0));
                 $99 = __THREW__; __THREW__ = 0;
                 $100 = $99&1;
                 if ($100) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($22|0),($88|0));
                $101 = __THREW__; __THREW__ = 0;
                $102 = $101&1;
                if ($102) {
                 break;
                }
                $103 = HEAP32[$22>>2]|0;
                $104 = (($22) + 16|0);
                $105 = (($103) + 92|0);
                $106 = HEAP32[$105>>2]|0;
                $107 = Math_imul($106, $V_0$4)|0;
                $108 = (($104) + ($107)|0);
                HEAP32[$108>>2] = $88;
                $$0 = $22;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_IntPtrTraitsS1_E6InvokeEPFPvS3_22mscorlib_System_IntPtrS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$args>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $3;
 $4 = (($args) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$1>>2] = $6;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$$byval_copy1)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits40mscorlib_System_RuntimeFieldHandleTraitsE6InvokeEPFPvS3_34mscorlib_System_RuntimeFieldHandleES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z67mscorlib_System_Reflection_FieldInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2451416)|0);
 $10 = HEAP32[((2451416 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 STACKTOP = sp;return;
}
function __Z182mscorlib_System_Reflection_FieldInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_FieldInfo_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_ObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2251976)|0);
 __Z59mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m__ctorP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318832)|0);
 __Z64mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m__ctorP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z251mscorlib_System_Reflection_MemberInfoSerializationHolder_m_Serialize_mscorlib_System_Void_mscorlib_System_Runtime_Serialization_SerializationInfo_mscorlib_System_String_mscorlib_System_Type_mscorlib_System_String_mscorlib_System_Reflection_MemberTypesP22mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_StringP20mscorlib_System_TypeS4_i($__this,$info,$name,$klass,$signature,$type) {
 $__this = $__this|0;
 $info = $info|0;
 $name = $name|0;
 $klass = $klass|0;
 $signature = $signature|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2407152);
 __THREW__ = 0;
 invoke_viiiiiii(20,0,($info|0),($name|0),($klass|0),($signature|0),($type|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z280mscorlib_System_Reflection_MemberInfoSerializationHolder_m_Serialize_mscorlib_System_Void_mscorlib_System_Runtime_Serialization_SerializationInfo_mscorlib_System_String_mscorlib_System_Type_mscorlib_System_String_mscorlib_System_Reflection_MemberTypes_mscorlib_System_Type_arr_arrP22mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_StringP20mscorlib_System_TypeS4_iP24mscorlib_System_Type_arr($__this,$info,$name,$klass,$signature,$type,$genericArguments) {
 $__this = $__this|0;
 $info = $info|0;
 $name = $name|0;
 $klass = $klass|0;
 $signature = $signature|0;
 $type = $type|0;
 $genericArguments = $genericArguments|0;
 var $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy5 = sp + 28|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 $4 = sp + 20|0;
 $5 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2407200);
 __THREW__ = 0;
 invoke_v(619);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if (!($7)) {
   HEAP32[$0>>2] = 2464176;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$0+0>>2]|0;
   $8 = (invoke_iii(772,(0|0),($$byval_copy5|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vii(1897,($info|0),($8|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3799,($klass|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2730,(2238776|0),($klass|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vi(3799,($17|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         $22 = (invoke_ii(2230,($17|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          invoke_vi(3799,($22|0));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           __THREW__ = 0;
           $27 = (invoke_iii(2730,(2370792|0),($22|0))|0);
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            HEAP32[$1>>2] = 1284472;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
            $30 = (invoke_iii(772,(0|0),($$byval_copy5|0))|0);
            $31 = __THREW__; __THREW__ = 0;
            $32 = $31&1;
            if (!($32)) {
             __THREW__ = 0;
             invoke_vi(3799,($info|0));
             $33 = __THREW__; __THREW__ = 0;
             $34 = $33&1;
             if (!($34)) {
              $35 = HEAP32[3031256>>2]|0;
              __THREW__ = 0;
              invoke_viiii(168,($info|0),($35|0),($27|0),($30|0));
              $36 = __THREW__; __THREW__ = 0;
              $37 = $36&1;
              if (!($37)) {
               __THREW__ = 0;
               invoke_vi(3799,($klass|0));
               $38 = __THREW__; __THREW__ = 0;
               $39 = $38&1;
               if (!($39)) {
                __THREW__ = 0;
                $40 = (invoke_iii(2730,(2150320|0),($klass|0))|0);
                $41 = __THREW__; __THREW__ = 0;
                $42 = $41&1;
                if (!($42)) {
                 HEAP32[$2>>2] = 1284472;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$2+0>>2]|0;
                 $43 = (invoke_iii(772,(0|0),($$byval_copy5|0))|0);
                 $44 = __THREW__; __THREW__ = 0;
                 $45 = $44&1;
                 if (!($45)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($info|0));
                  $46 = __THREW__; __THREW__ = 0;
                  $47 = $46&1;
                  if (!($47)) {
                   $48 = HEAP32[3031264>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii(168,($info|0),($48|0),($40|0),($43|0));
                   $49 = __THREW__; __THREW__ = 0;
                   $50 = $49&1;
                   if (!($50)) {
                    HEAP32[$3>>2] = 1284472;
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
                    $51 = (invoke_iii(772,(0|0),($$byval_copy5|0))|0);
                    $52 = __THREW__; __THREW__ = 0;
                    $53 = $52&1;
                    if (!($53)) {
                     __THREW__ = 0;
                     invoke_vi(3799,($info|0));
                     $54 = __THREW__; __THREW__ = 0;
                     $55 = $54&1;
                     if ($55) {
                      break;
                     }
                     $56 = HEAP32[3031272>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(168,($info|0),($56|0),($name|0),($51|0));
                     $57 = __THREW__; __THREW__ = 0;
                     $58 = $57&1;
                     if ($58) {
                      break;
                     }
                     HEAP32[$4>>2] = 1284472;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$4+0>>2]|0;
                     $59 = (invoke_iii(772,(0|0),($$byval_copy5|0))|0);
                     $60 = __THREW__; __THREW__ = 0;
                     $61 = $60&1;
                     if ($61) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($info|0));
                     $62 = __THREW__; __THREW__ = 0;
                     $63 = $62&1;
                     if ($63) {
                      break;
                     }
                     $64 = HEAP32[3031280>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(168,($info|0),($64|0),($signature|0),($59|0));
                     $65 = __THREW__; __THREW__ = 0;
                     $66 = $65&1;
                     if ($66) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($info|0));
                     $67 = __THREW__; __THREW__ = 0;
                     $68 = $67&1;
                     if ($68) {
                      break;
                     }
                     $69 = HEAP32[3031288>>2]|0;
                     __THREW__ = 0;
                     invoke_viii(618,($info|0),($69|0),($type|0));
                     $70 = __THREW__; __THREW__ = 0;
                     $71 = $70&1;
                     if ($71) {
                      break;
                     }
                     HEAP32[$5>>2] = 1207272;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
                     $72 = (invoke_iii(772,(0|0),($$byval_copy5|0))|0);
                     $73 = __THREW__; __THREW__ = 0;
                     $74 = $73&1;
                     if ($74) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($info|0));
                     $75 = __THREW__; __THREW__ = 0;
                     $76 = $75&1;
                     if ($76) {
                      break;
                     }
                     $77 = HEAP32[3031296>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(168,($info|0),($77|0),($genericArguments|0),($72|0));
                     $78 = __THREW__; __THREW__ = 0;
                     $79 = $78&1;
                     if ($79) {
                      break;
                     }
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $80 = ___cxa_find_matching_catch()|0;
 $81 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($80|0);
 // unreachable;
}
function __Z48mscorlib_System_Reflection_Module_m_get_AssemblyP33mscorlib_System_Reflection_Module($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2415008);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z72mscorlib_System_Reflection_MemberInfoSerializationHolder_m_GetObjectDataP56mscorlib_System_Reflection_MemberInfoSerializationHolderP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2407248);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3834,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __ZN14ActionInvoker5I17VoidPointerTraitsS0_S0_S0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvS3_S3_S3_S3_iES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$2,$4,$6,$9);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker6I17VoidPointerTraitsS0_S0_S0_27mscorlib_System_Int32TraitsS0_E6InvokeEPFvPvS3_S3_S3_S3_iS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 FUNCTION_TABLE_viiiiiii[$action & 127]($obj,$0,$2,$4,$6,$9,$11);
 STACKTOP = sp;return (0|0);
}
function __Z69mscorlib_System_Reflection_MemberTypes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Reflection_MethodAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z73mscorlib_System_Reflection_MethodBase_m_GetMethodFromHandleNoGenericCheckP22mscorlib_System_Object35mscorlib_System_RuntimeMethodHandle($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2409784);
 __THREW__ = 0;
 $2 = (invoke_ii(2491,($handle|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2210080|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = HEAP32[((2210080 + 80|0))>>2]|0;
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$0>>2] = $2;
   HEAP32[$1>>2] = $8;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   $9 = (invoke_iiii(864,0,($$byval_copy|0),($$byval_copy1|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($9|0);
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MethodBase_m_GetMethodFromIntPtrP22mscorlib_System_Object22mscorlib_System_IntPtrS1_($__this,$handle,$declaringType) {
 $__this = $__this|0;
 $handle = $handle|0;
 $declaringType = $declaringType|0;
 var $$byval_copy2 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $$byval_copy2 = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2409832);
 __THREW__ = 0;
 invoke_v(620);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2210080|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = HEAP32[((2210080 + 80|0))>>2]|0;
    $9 = HEAP32[$8>>2]|0;
    $10 = HEAP32[$handle>>2]|0;
    HEAP32[$0>>2] = $10;
    HEAP32[$1>>2] = $9;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    $11 = (invoke_iiii(643,(0|0),($$byval_copy2|0),($$byval_copy3|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     if ($11) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      $18 = (invoke_ii(3469,(2560072|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP32[3031440>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($18|0),($21|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3834,($18|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      // unreachable;
     }
     HEAP32[$2>>2] = $10;
     $26 = HEAP32[$declaringType>>2]|0;
     HEAP32[$3>>2] = $26;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
     $27 = (invoke_iiii(865,0,($$byval_copy2|0),($$byval_copy3|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = ($27|0)==(0|0);
      if (!($30)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($27|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       $33 = (invoke_ii(3469,(2560072|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $36 = HEAP32[3031448>>2]|0;
        __THREW__ = 0;
        invoke_vii(1924,($33|0),($36|0));
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         __THREW__ = 0;
         invoke_vi(3834,($33|0));
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if (!($40)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Reflection_MethodBase_m_GetMethodFromHandleInternalTypeP22mscorlib_System_Object22mscorlib_System_IntPtrS1_($__this,$method_handle,$type_handle) {
 $__this = $__this|0;
 $method_handle = $method_handle|0;
 $type_handle = $type_handle|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2409928);
 $2 = HEAP32[2409976>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   __THREW__ = 0;
   $4 = (invoke_ii(3473,(2409984|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if ($6) {
    $7 = ___cxa_find_matching_catch()|0;
    $8 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($7|0);
    // unreachable;
   } else {
    HEAP32[2409976>>2] = $4;
    $11 = $4;
    break;
   }
  } else {
   $11 = $2;
  }
 } while(0);
 $9 = HEAP32[$method_handle>>2]|0;
 HEAP32[$0>>2] = $9;
 $10 = HEAP32[$type_handle>>2]|0;
 HEAP32[$1>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 $12 = (invoke_iii($11|0,($$byval_copy|0),($$byval_copy1|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($12|0);
 }
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MethodBase_m_GetMethodFromHandleP22mscorlib_System_Object35mscorlib_System_RuntimeMethodHandle($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2409880);
 __THREW__ = 0;
 invoke_v(621);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2491,($handle|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2210080|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2210080 + 80|0))>>2]|0;
     $10 = HEAP32[$9>>2]|0;
     HEAP32[$0>>2] = $4;
     HEAP32[$1>>2] = $10;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
     $11 = (invoke_iiii(864,0,($$byval_copy|0),($$byval_copy1|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3799,($11|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       $16 = (invoke_iii(2730,(2242504|0),($11|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        invoke_vi(3799,($16|0));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         $21 = (invoke_iii(2734,(2237408|0),($16|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          if (!($21)) {
           __THREW__ = 0;
           invoke_vi(3799,($16|0));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if ($27) {
            break;
           }
           __THREW__ = 0;
           $28 = (invoke_iii(2734,(2237152|0),($16|0))|0);
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if ($30) {
            break;
           }
           if (!($28)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($11|0);
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           $33 = (invoke_ii(3469,(2560072|0))|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $36 = HEAP32[3031464>>2]|0;
            __THREW__ = 0;
            invoke_vii(1924,($33|0),($36|0));
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if (!($38)) {
             __THREW__ = 0;
             invoke_vi(3834,($33|0));
             $39 = __THREW__; __THREW__ = 0;
             $40 = $39&1;
             if (!($40)) {
              // unreachable;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($24|0);
 // unreachable;
 return 0|0;
}
function __Z123mscorlib_System_Reflection_MethodBase_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP37mscorlib_System_Reflection_MethodBaseP22mscorlib_System_ObjectP26mscorlib_System_Object_arr($__this,$obj,$parameters) {
 $__this = $__this|0;
 $obj = $obj|0;
 $parameters = $parameters|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410080);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(119,(2410128|0),($__this|0),($obj|0),0,(0|0),($parameters|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN16VirtFuncInvoker5I28mscorlib_System_ObjectTraitsS0_27mscorlib_System_Int32Traits17VoidPointerTraitsS2_S2_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectiS6_S6_S6_($method,$obj,$p1,$p2,$p3,$p4,$p5) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4,$p5)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z61mscorlib_System_Reflection_MethodBase_m_get_CallingConventionP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397712);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z52mscorlib_System_Reflection_MethodBase_m_get_IsPublicP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410176);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 7;
  $4 = ($3|0)==(6);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Reflection_MethodBase_m_get_IsPrivateP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410272);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 7;
  $4 = ($3|0)==(1);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Reflection_MethodBase_m_get_IsFamilyP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410320);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 7;
  $4 = ($3|0)==(4);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Reflection_MethodBase_m_get_IsAssemblyP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410368);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 7;
  $4 = ($3|0)==(3);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z63mscorlib_System_Reflection_MethodBase_m_get_IsFamilyAndAssemblyP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410416);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 7;
  $4 = ($3|0)==(2);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z62mscorlib_System_Reflection_MethodBase_m_get_IsFamilyOrAssemblyP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410464);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 7;
  $4 = ($3|0)==(5);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Reflection_MethodBase_m_get_IsStaticP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410512);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 16;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Reflection_MethodBase_m_get_IsFinalP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410560);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 32;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Reflection_MethodBase_m_get_IsVirtualP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410608);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 64;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_Reflection_MethodBase_m_get_IsHideBySigP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410656);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 128;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Reflection_MethodBase_m_get_IsAbstractP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410704);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 1024;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_MethodBase_m_get_IsSpecialNameP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410752);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 2048;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_MethodBase_m_get_IsConstructorP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410800);
 __THREW__ = 0;
 invoke_v(622);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2729,(2410224|0),($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $2 & 4096;
   $6 = ($5|0)==(0);
   if ($6) {
    $G_B3_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
   __THREW__ = 0;
   $9 = (invoke_iii(2730,(2233608|0),($__this|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = HEAP32[3031424>>2]|0;
    __THREW__ = 0;
    $13 = (invoke_iiii(574,(0|0),($9|0),($12|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $G_B3_0$0 = $13;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MethodBase_m_GetGenericArgumentsP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410848);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3834,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Reflection_MethodBase_m_get_ContainsGenericParametersP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410896);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z69mscorlib_System_Reflection_MethodBase_m_get_IsGenericMethodDefinitionP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397664);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z59mscorlib_System_Reflection_MethodBase_m_get_IsGenericMethodP37mscorlib_System_Reflection_MethodBase($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2410944);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __ZN12FuncInvoker1I17VoidPointerTraits41mscorlib_System_RuntimeMethodHandleTraitsE6InvokeEPFPvS3_35mscorlib_System_RuntimeMethodHandleES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z68mscorlib_System_Reflection_MethodBase_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2451632)|0);
 $5 = HEAP32[((2451632 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($8,0);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z192mscorlib_System_Reflection_MethodBase_CustomAttributesCacheGenerator_mscorlib_System_Reflection_MethodBase_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2251976)|0);
 __Z59mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m__ctorP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318832)|0);
 __Z64mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m__ctorP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z128mscorlib_System_Reflection_MethodBase_CustomAttributesCacheGenerator_mscorlib_System_Reflection_MethodBase_m_GetGenericArgumentsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Reflection_MethodBase_CustomAttributesCacheGenerator_mscorlib_System_Reflection_MethodBaseTraits_IsConstructor_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z78mscorlib_System_Reflection_MethodImplAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_Reflection_MethodInfo_m_get_MemberTypeP37mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2413416);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 8;
}
function __Z54mscorlib_System_Reflection_MethodInfo_m_get_ReturnTypeP37mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2413464);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z57mscorlib_System_Reflection_MethodInfo_m_MakeGenericMethodP37mscorlib_System_Reflection_MethodInfoP24mscorlib_System_Type_arr($__this,$typeArguments) {
 $__this = $__this|0;
 $typeArguments = $typeArguments|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2413512);
 __THREW__ = 0;
 $0 = (invoke_ii(1782,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2149160|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2622808|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2622808|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vii(1954,($10|0),($5|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3834,($10|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MethodInfo_m_GetGenericArgumentsP37mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2413560);
 __THREW__ = 0;
 (invoke_ii(2996,(2242320|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2242320 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2242320|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2242320|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3835,(2242320|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2242320|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2242320 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MethodInfo_m_get_IsGenericMethodP37mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2413608);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z69mscorlib_System_Reflection_MethodInfo_m_get_IsGenericMethodDefinitionP37mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2413656);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z69mscorlib_System_Reflection_MethodInfo_m_get_ContainsGenericParametersP37mscorlib_System_Reflection_MethodInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2413704);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z68mscorlib_System_Reflection_MethodInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2452064)|0);
 $7 = HEAP32[((2452064 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z128mscorlib_System_Reflection_MethodInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_MethodInfo_m_GetGenericArgumentsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z42mscorlib_System_Reflection_Missing_m__ctorP34mscorlib_System_Reflection_Missing($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2414352);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43mscorlib_System_Reflection_Missing_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2414400);
 __THREW__ = 0;
 (invoke_ii(2996,(2414728|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2414728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2307,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2414728|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2414728 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z93mscorlib_System_Reflection_Missing_m_System_Runtime_Serialization_ISerializable_GetObjectDataP34mscorlib_System_Reflection_MissingP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2414448);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z65mscorlib_System_Reflection_Missing_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z159mscorlib_System_Reflection_Missing_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Missing_m_System_Runtime_Serialization_ISerializable_GetObjectDataP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z42mscorlib_System_Reflection_Module_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2414864);
 __THREW__ = 0;
 (invoke_ii(2996,(2660744|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_ii(3469,(2660744|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   HEAP32[$0>>2] = 2414912;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viii(711,($4|0),(0|0),($$byval_copy1|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2416152|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[((2416152 + 80|0))>>2]|0;
     $12 = (($11) + 4|0);
     HEAP32[$12>>2] = $4;
     __THREW__ = 0;
     (invoke_ii(2996,(2660744|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_ii(3469,(2660744|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       HEAP32[$1>>2] = 2414960;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_viii(711,($15|0),(0|0),($$byval_copy1|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2416152|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         $22 = HEAP32[((2416152 + 80|0))>>2]|0;
         $23 = (($22) + 8|0);
         HEAP32[$23>>2] = $15;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($24|0);
 // unreachable;
}
function __Z49mscorlib_System_Reflection_Module_m_get_ScopeNameP33mscorlib_System_Reflection_Module($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2415056);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z55mscorlib_System_Reflection_Module_m_GetCustomAttributesP33mscorlib_System_Reflection_ModuleP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2415104);
 __THREW__ = 0;
 $0 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z49mscorlib_System_Reflection_Module_m_GetObjectDataP33mscorlib_System_Reflection_ModuleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2415152);
 __THREW__ = 0;
 invoke_v(623);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($info|0)==(0|0);
   if (!($3)) {
    $16 = $context;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 4)|0;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    $22 = $0;
    $23 = $22;
    HEAP32[$23>>2] = $18;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP32[$25>>2] = $21;
    __THREW__ = 0;
    ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
    invoke_viiii(205,(0|0),($__this|0),($info|0),($tmpcast$byval_copy|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[3031608>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($8|0),($11|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3834,($8|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z45mscorlib_System_Reflection_Module_m_IsDefinedP33mscorlib_System_Reflection_ModuleP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2415200);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z44mscorlib_System_Reflection_Module_m_ToStringP33mscorlib_System_Reflection_Module($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2415248);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z55mscorlib_System_Reflection_Module_m_filter_by_type_nameP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_($__this,$m,$filterCriteria) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2414912);
 __THREW__ = 0;
 invoke_v(624);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2763,($filterCriteria|0),(2191608|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = HEAP32[3031624>>2]|0;
      __THREW__ = 0;
      $10 = (invoke_iii(629,($4|0),($9|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       if (!($10)) {
        __THREW__ = 0;
        invoke_vi(3799,($m|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2730,(2233608|0),($m|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
        __THREW__ = 0;
        $41 = (invoke_iiii(574,(0|0),($38|0),($4|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        } else {
         $$0 = $41;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($m|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __THREW__ = 0;
        $17 = (invoke_iii(2730,(2233608|0),($m|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if (!($21)) {
          __THREW__ = 0;
          $22 = (invoke_ii(1816,($4|0))|0);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $25 = __THREW__; __THREW__ = 0;
           $26 = $25&1;
           if (!($26)) {
            $27 = (($22) + -1)|0;
            __THREW__ = 0;
            $28 = (invoke_iiii(528,($4|0),0,($27|0))|0);
            $29 = __THREW__; __THREW__ = 0;
            $30 = $29&1;
            if (!($30)) {
             __THREW__ = 0;
             invoke_vi(3799,($17|0));
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if (!($32)) {
              __THREW__ = 0;
              $33 = (invoke_iii(635,($17|0),($28|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               $$0 = $33;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo6662($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z67mscorlib_System_Reflection_Module_m_filter_by_type_name_ignore_caseP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_($__this,$m,$filterCriteria) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2414960);
 __THREW__ = 0;
 invoke_v(625);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2763,($filterCriteria|0),(2191608|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = HEAP32[3031648>>2]|0;
      __THREW__ = 0;
      $10 = (invoke_iii(629,($4|0),($9|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       if (!($10)) {
        __THREW__ = 0;
        invoke_vi(3799,($m|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_iii(2730,(2233608|0),($m|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        $51 = (invoke_iiiii(91,(0|0),($48|0),($4|0),1)|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        $54 = ($51|0)==(0);
        $$0 = $54;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($m|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __THREW__ = 0;
        $17 = (invoke_iii(2730,(2233608|0),($m|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         invoke_vi(3799,($17|0));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if (!($21)) {
          __THREW__ = 0;
          $22 = (invoke_ii(1813,($17|0))|0);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $25 = __THREW__; __THREW__ = 0;
           $26 = $25&1;
           if (!($26)) {
            __THREW__ = 0;
            $27 = (invoke_ii(1816,($4|0))|0);
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $30 = __THREW__; __THREW__ = 0;
             $31 = $30&1;
             if (!($31)) {
              $32 = (($27) + -1)|0;
              __THREW__ = 0;
              $33 = (invoke_iiii(528,($4|0),0,($32|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               __THREW__ = 0;
               invoke_vi(3799,($33|0));
               $36 = __THREW__; __THREW__ = 0;
               $37 = $36&1;
               if (!($37)) {
                __THREW__ = 0;
                $38 = (invoke_ii(1813,($33|0))|0);
                $39 = __THREW__; __THREW__ = 0;
                $40 = $39&1;
                if (!($40)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($22|0));
                 $41 = __THREW__; __THREW__ = 0;
                 $42 = $41&1;
                 if (!($42)) {
                  __THREW__ = 0;
                  $43 = (invoke_iii(635,($22|0),($38|0))|0);
                  $44 = __THREW__; __THREW__ = 0;
                  $45 = $44&1;
                  if (!($45)) {
                   $$0 = $43;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($$0|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Reflection_Module_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2452272)|0);
 $7 = HEAP32[((2452272 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z57mscorlib_System_Reflection_MonoEventInfo_m_get_event_infoP22mscorlib_System_ObjectP36mscorlib_System_Reflection_MonoEventP40mscorlib_System_Reflection_MonoEventInfo($__this,$ev,$info) {
 $__this = $__this|0;
 $ev = $ev|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2416288);
 $0 = HEAP32[2416336>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2416344|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2416336>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($ev|0),($info|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z55mscorlib_System_Reflection_MonoEventInfo_m_GetEventInfoP22mscorlib_System_ObjectP36mscorlib_System_Reflection_MonoEvent($agg$result,$__this,$ev) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $ev = $ev|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2416456);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;HEAP32[$agg$result+24>>2]=0|0;HEAP32[$agg$result+28>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(595,0,($ev|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN12FuncInvoker1I46mscorlib_System_Reflection_MonoEventInfoTraits17VoidPointerTraitsE6InvokeEPF40mscorlib_System_Reflection_MonoEventInfoPvS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$0);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2416968,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z53mscorlib_System_Reflection_MonoEvent_m_get_AttributesP36mscorlib_System_Reflection_MonoEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417104);
 __THREW__ = 0;
 invoke_viii(596,($L_0|0),0,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($L_0) + 24|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Reflection_MonoEvent_m_GetAddMethodP36mscorlib_System_Reflection_MonoEventb($__this,$nonPublic) {
 $__this = $__this|0;
 $nonPublic = $nonPublic|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417152);
 __THREW__ = 0;
 invoke_viii(596,($L_0|0),0,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($L_0) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   if ($nonPublic) {
    $$0 = $3;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $6 = ($3|0)==(0|0);
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_iii(2734,(2410176|0),($3|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    if ($9) {
     $$0 = $3;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Reflection_MonoEvent_m_get_DeclaringTypeP36mscorlib_System_Reflection_MonoEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417200);
 __THREW__ = 0;
 invoke_viii(596,($L_0|0),0,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP32[$L_0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z56mscorlib_System_Reflection_MonoEvent_m_get_ReflectedTypeP36mscorlib_System_Reflection_MonoEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417248);
 __THREW__ = 0;
 invoke_viii(596,($L_0|0),0,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($L_0) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z47mscorlib_System_Reflection_MonoEvent_m_get_NameP36mscorlib_System_Reflection_MonoEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417296);
 __THREW__ = 0;
 invoke_viii(596,($L_0|0),0,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($L_0) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z47mscorlib_System_Reflection_MonoEvent_m_ToStringP36mscorlib_System_Reflection_MonoEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417344);
 __THREW__ = 0;
 invoke_v(626);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2730,(2403720|0),($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2417296|0),($__this|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = HEAP32[3031664>>2]|0;
    __THREW__ = 0;
    $9 = (invoke_iiiii(100,(0|0),($2|0),($8|0),($5|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($9|0);
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Reflection_MonoEvent_m_IsDefinedP36mscorlib_System_Reflection_MonoEventP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417392);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z113mscorlib_System_Reflection_MonoEvent_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP36mscorlib_System_Reflection_MonoEventb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417440);
 __THREW__ = 0;
 $0 = (invoke_iiii(1202,(0|0),($__this|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z134mscorlib_System_Reflection_MonoEvent_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP36mscorlib_System_Reflection_MonoEventP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417488);
 __THREW__ = 0;
 $0 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Reflection_MonoEvent_m_GetObjectDataP36mscorlib_System_Reflection_MonoEventP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2417536);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2417296|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2730,(2417248|0),($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2730,(2417344|0),($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiiiii(62,0,($info|0),($0|0),($3|0),($6|0),2);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z53mscorlib_System_Reflection_MonoField_m_get_AttributesP36mscorlib_System_Reflection_MonoField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418176);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52mscorlib_System_Reflection_MonoField_m_get_FieldTypeP36mscorlib_System_Reflection_MonoField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418224);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52mscorlib_System_Reflection_MonoField_m_GetParentTypeP36mscorlib_System_Reflection_MonoFieldb($__this,$declaring) {
 $__this = $__this|0;
 $declaring = $declaring|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418272);
 $0 = HEAP32[2418320>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2418328|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2418320>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($declaring|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Reflection_MonoField_m_get_ReflectedTypeP36mscorlib_System_Reflection_MonoField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418392);
 __THREW__ = 0;
 $0 = (invoke_iii(913,($__this|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z56mscorlib_System_Reflection_MonoField_m_get_DeclaringTypeP36mscorlib_System_Reflection_MonoField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418440);
 __THREW__ = 0;
 $0 = (invoke_iii(913,($__this|0),1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z47mscorlib_System_Reflection_MonoField_m_get_NameP36mscorlib_System_Reflection_MonoField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418488);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z48mscorlib_System_Reflection_MonoField_m_IsDefinedP36mscorlib_System_Reflection_MonoFieldP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418536);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z113mscorlib_System_Reflection_MonoField_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP36mscorlib_System_Reflection_MonoFieldb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418584);
 __THREW__ = 0;
 $0 = (invoke_iiii(1202,(0|0),($__this|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z134mscorlib_System_Reflection_MonoField_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP36mscorlib_System_Reflection_MonoFieldP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418632);
 __THREW__ = 0;
 $0 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Reflection_MonoField_m_GetFieldOffsetP36mscorlib_System_Reflection_MonoField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418680);
 $0 = HEAP32[2418728>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2418736|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2418728>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Reflection_MonoField_m_GetValueInternalP36mscorlib_System_Reflection_MonoFieldP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418784);
 $0 = HEAP32[2418832>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2418840|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2418832>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($obj|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_Reflection_MonoField_m_GetValueP36mscorlib_System_Reflection_MonoFieldP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418904);
 __THREW__ = 0;
 invoke_v(627);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2734,(2405600|0),($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $$not = $2 ^ 1;
    $5 = ($obj|0)==(0|0);
    $or$cond = $5 & $$not;
    if ($or$cond) {
     __THREW__ = 0;
     (invoke_ii(2996,(2435592|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2435592|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3031680>>2]|0;
     __THREW__ = 0;
     invoke_vii(1861,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3834,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    } else {
     __THREW__ = 0;
     $18 = (invoke_iii(2734,(2405504|0),($__this|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     if (!($18)) {
      __THREW__ = 0;
      invoke_vi(2313,($__this|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
     }
     __THREW__ = 0;
     $23 = (invoke_iii(915,($__this|0),($obj|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($23|0);
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Reflection_TargetException_m__ctorP42mscorlib_System_Reflection_TargetExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2435384);
 __THREW__ = 0;
 invoke_vii(1781,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z51mscorlib_System_Reflection_MonoField_m_CheckGenericP36mscorlib_System_Reflection_MonoField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2419256);
 __THREW__ = 0;
 invoke_v(628);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2730,(2418440|0),($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2734,(2223448|0),($2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     if (!($7)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2607872|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      $14 = (invoke_ii(3469,(2607872|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = HEAP32[3032016>>2]|0;
       __THREW__ = 0;
       invoke_vii(1947,($14|0),($17|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vi(3834,($14|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z47mscorlib_System_Reflection_MonoField_m_ToStringP36mscorlib_System_Reflection_MonoField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2418952);
 __THREW__ = 0;
 invoke_v(629);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($__this) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[3031768>>2]|0;
  __THREW__ = 0;
  $7 = (invoke_iiiii(98,(0|0),($6|0),($3|0),($5|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($7|0);
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Reflection_MonoField_m_SetValueInternalP22mscorlib_System_ObjectP36mscorlib_System_Reflection_FieldInfoS0_S0_($__this,$fi,$obj,$value) {
 $__this = $__this|0;
 $fi = $fi|0;
 $obj = $obj|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2419000);
 $0 = HEAP32[2419048>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2419056|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2419048>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($fi|0),($obj|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z47mscorlib_System_Reflection_MonoField_m_SetValueP36mscorlib_System_Reflection_MonoFieldP22mscorlib_System_ObjectS2_iP33mscorlib_System_Reflection_BinderP41mscorlib_System_Globalization_CultureInfo($__this,$obj,$val,$invokeAttr,$binder,$culture) {
 $__this = $__this|0;
 $obj = $obj|0;
 $val = $val|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $culture = $culture|0;
 var $$0 = 0, $$01 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2419160);
 __THREW__ = 0;
 invoke_v(630);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2734,(2405600|0),($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $$not = $2 ^ 1;
    $5 = ($obj|0)==(0|0);
    $or$cond = $5 & $$not;
    if ($or$cond) {
     __THREW__ = 0;
     (invoke_ii(2996,(2435592|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2435592|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3031800>>2]|0;
     __THREW__ = 0;
     invoke_vii(1861,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3834,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $18 = (invoke_iii(2734,(2405504|0),($__this|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     if ($18) {
      __THREW__ = 0;
      (invoke_ii(2996,(2602480|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(2602480|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = HEAP32[3031808>>2]|0;
      __THREW__ = 0;
      invoke_vii(1939,($23|0),($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3834,($23|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     }
     $31 = ($binder|0)==(0|0);
     if ($31) {
      __THREW__ = 0;
      $32 = (invoke_ii(2196,0)|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      } else {
       $$01 = $32;
      }
     } else {
      $$01 = $binder;
     }
     __THREW__ = 0;
     invoke_vi(2313,($__this|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      $37 = ($val|0)==(0|0);
      if ($37) {
       $$0 = 0;
      } else {
       $38 = (($__this) + 20|0);
       $39 = HEAP32[$38>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($$01|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       __THREW__ = 0;
       $42 = (invoke_iiiiii(236,(2399392|0),($$01|0),($val|0),($39|0),($culture|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $45 = ($42|0)==(0|0);
       if ($45) {
        __THREW__ = 0;
        (invoke_ii(2996,(1167664|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_iii(2760,(1167664|0),4)|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($48|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
        $53 = (($48) + 12|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = ($54|0)==(0);
        if ($55) {
         __THREW__ = 0;
         $56 = (invoke_i(132)|0);
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($56|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break;
         }
        }
        $61 = HEAP32[3031816>>2]|0;
        __THREW__ = 0;
        invoke_vii(3492,($48|0),($61|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        $64 = HEAP32[3031816>>2]|0;
        $65 = (($48) + 16|0);
        HEAP32[$65>>2] = $64;
        __THREW__ = 0;
        invoke_vi(3799,($val|0));
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
        __THREW__ = 0;
        $68 = (invoke_ii(1782,($val|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($48|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         break;
        }
        $73 = HEAP32[$53>>2]|0;
        $74 = ($73>>>0)<(2);
        if ($74) {
         __THREW__ = 0;
         $75 = (invoke_i(132)|0);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($75|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($48|0),($68|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         break;
        }
        $82 = HEAP32[$48>>2]|0;
        $83 = (($82) + 92|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = (($65) + ($84)|0);
        HEAP32[$85>>2] = $68;
        __THREW__ = 0;
        invoke_vi(3799,($48|0));
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         break;
        }
        $88 = HEAP32[$53>>2]|0;
        $89 = ($88>>>0)<(3);
        if ($89) {
         __THREW__ = 0;
         $90 = (invoke_i(132)|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($90|0));
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          break;
         }
        }
        $95 = HEAP32[3031824>>2]|0;
        __THREW__ = 0;
        invoke_vii(3492,($48|0),($95|0));
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         break;
        }
        $98 = HEAP32[3031824>>2]|0;
        $99 = HEAP32[$48>>2]|0;
        $100 = (($99) + 92|0);
        $101 = HEAP32[$100>>2]|0;
        $102 = $101 << 1;
        $103 = (($65) + ($102)|0);
        HEAP32[$103>>2] = $98;
        $104 = HEAP32[$38>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($48|0));
        $105 = __THREW__; __THREW__ = 0;
        $106 = $105&1;
        if ($106) {
         break;
        }
        $107 = HEAP32[$53>>2]|0;
        $108 = ($107>>>0)<(4);
        if ($108) {
         __THREW__ = 0;
         $109 = (invoke_i(132)|0);
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         if ($111) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($109|0));
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if ($113) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($48|0),($104|0));
        $114 = __THREW__; __THREW__ = 0;
        $115 = $114&1;
        if ($115) {
         break;
        }
        $116 = HEAP32[$48>>2]|0;
        $117 = (($116) + 92|0);
        $118 = HEAP32[$117>>2]|0;
        $119 = ($118*3)|0;
        $120 = (($65) + ($119)|0);
        HEAP32[$120>>2] = $104;
        __THREW__ = 0;
        $121 = (invoke_iii(638,(0|0),($48|0))|0);
        $122 = __THREW__; __THREW__ = 0;
        $123 = $122&1;
        if ($123) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break;
        }
        __THREW__ = 0;
        $126 = (invoke_ii(3469,(2560072|0))|0);
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if ($128) {
         break;
        }
        $129 = HEAP32[3031832>>2]|0;
        __THREW__ = 0;
        invoke_viii(641,($126|0),($121|0),($129|0));
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if ($131) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3834,($126|0));
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if ($133) {
         break;
        }
        // unreachable;
       } else {
        $$0 = $42;
       }
      }
      __THREW__ = 0;
      invoke_viiii(160,0,($__this|0),($obj|0),($$0|0));
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if (!($135)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z52mscorlib_System_Reflection_MonoField_m_GetObjectDataP36mscorlib_System_Reflection_MonoFieldP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2419208);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2418488|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2730,(2418392|0),($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2730,(2418952|0),($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiiiii(62,0,($info|0),($0|0),($3|0),($6|0),4);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFvPvS3_P22mscorlib_System_ObjectS5_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$4);
 STACKTOP = sp;return (0|0);
}
function __Z64mscorlib_System_Reflection_MonoGenericMethod_m_get_ReflectedTypeP44mscorlib_System_Reflection_MonoGenericMethod($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2420192);
 $0 = HEAP32[2420240>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2420248|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2420240>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Reflection_MonoGenericCMethod_m_get_ReflectedTypeP45mscorlib_System_Reflection_MonoGenericCMethod($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2420712);
 $0 = HEAP32[2420760>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2420768|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2420760>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MonoMethodInfo_m_get_method_infoP22mscorlib_System_Object22mscorlib_System_IntPtrP41mscorlib_System_Reflection_MonoMethodInfo($__this,$handle,$info) {
 $__this = $__this|0;
 $handle = $handle|0;
 $info = $info|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421224);
 $1 = HEAP32[2421272>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2421280|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2421272>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii($9|0,($$byval_copy|0),($info|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57mscorlib_System_Reflection_MonoMethodInfo_m_GetMethodInfoP22mscorlib_System_Object22mscorlib_System_IntPtr($agg$result,$__this,$handle) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421384);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 $1 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(599,0,($$byval_copy|0),($agg$result|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z60mscorlib_System_Reflection_MonoMethodInfo_m_GetDeclaringTypeP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 28|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $0 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421432);
 $1 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(600,($L_0|0),0,($$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $4 = HEAP32[$L_0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_MonoMethodInfo_m_GetReturnTypeP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 28|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $0 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421480);
 $1 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(600,($L_0|0),0,($$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($L_0) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_MonoMethodInfo_m_GetAttributesP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 28|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $0 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421528);
 $1 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(600,($L_0|0),0,($$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($L_0) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z64mscorlib_System_Reflection_MonoMethodInfo_m_GetCallingConventionP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 28|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $0 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421576);
 $1 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(600,($L_0|0),0,($$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($L_0) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z72mscorlib_System_Reflection_MonoMethodInfo_m_GetMethodImplementationFlagsP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 28|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $0 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421624);
 $1 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(600,($L_0|0),0,($$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($L_0) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z62mscorlib_System_Reflection_MonoMethodInfo_m_get_parameter_infoP22mscorlib_System_Object22mscorlib_System_IntPtrP37mscorlib_System_Reflection_MemberInfo($__this,$handle,$member) {
 $__this = $__this|0;
 $handle = $handle|0;
 $member = $member|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421672);
 $1 = HEAP32[2421720>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2421728|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2421720>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $10 = (invoke_iii($9|0,($$byval_copy|0),($member|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __Z61mscorlib_System_Reflection_MonoMethodInfo_m_GetParametersInfoP22mscorlib_System_Object22mscorlib_System_IntPtrP37mscorlib_System_Reflection_MemberInfo($__this,$handle,$member) {
 $__this = $__this|0;
 $handle = $handle|0;
 $member = $member|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2421832);
 $1 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (invoke_iiii(879,0,($$byval_copy|0),($member|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker2I28mscorlib_System_IntPtrTraits17VoidPointerTraitsE6InvokeEPFvPv22mscorlib_System_IntPtrS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$$byval_copy,$4);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I47mscorlib_System_Reflection_MonoMethodInfoTraits28mscorlib_System_IntPtrTraitsE6InvokeEPF41mscorlib_System_Reflection_MonoMethodInfoPv22mscorlib_System_IntPtrES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $ret = sp;
 $0 = sp + 20|0;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$$byval_copy);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2422472,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_IntPtrTraitsS0_E6InvokeEPFPvS3_22mscorlib_System_IntPtrS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z48mscorlib_System_Reflection_MonoMethod_m_get_nameP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MethodBase($__this,$method) {
 $__this = $__this|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2422608);
 $0 = HEAP32[2422656>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2422664|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2422656>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($method|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MonoMethod_m_get_base_definitionP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MonoMethod($__this,$method) {
 $__this = $__this|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2422736);
 $0 = HEAP32[2422784>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2422792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2422784>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($method|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_Reflection_MonoMethod_m_GetBaseDefinitionP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2422872);
 __THREW__ = 0;
 $0 = (invoke_iii(923,0,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Reflection_MonoMethod_m_get_ReturnTypeP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2422920);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(918,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z68mscorlib_System_Reflection_MonoMethod_m_GetMethodImplementationFlagsP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2422968);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(921,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Reflection_MonoMethod_m_GetParametersP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423016);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iiii(881,0,($$byval_copy|0),($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($3) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1183184|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(2760,(1183184|0),($9|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_viiii(461,(2225864|0),($3|0),($12|0),0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($12|0);
      }
     }
    }
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_MonoMethod_m_InternalInvokeP37mscorlib_System_Reflection_MonoMethodP22mscorlib_System_ObjectP26mscorlib_System_Object_arrPP25mscorlib_System_Exception($__this,$obj,$parameters,$exc) {
 $__this = $__this|0;
 $obj = $obj|0;
 $parameters = $parameters|0;
 $exc = $exc|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423064);
 $0 = HEAP32[2423112>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2423120|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2423112>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiii($7|0,($__this|0),($obj|0),($parameters|0),($exc|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Reflection_MonoMethod_m_InvokeP37mscorlib_System_Reflection_MonoMethodP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo($__this,$obj,$invokeAttr,$binder,$parameters,$culture) {
 $__this = $__this|0;
 $obj = $obj|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $parameters = $parameters|0;
 $culture = $culture|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $$04 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $0 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423216);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(631);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 4;
  } else {
   $3 = ($binder|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    $8 = (invoke_ii(2196,0)|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     label = 4;
     break;
    } else {
     $$02 = $8;
    }
   } else {
    $$02 = $binder;
   }
   $11 = (($__this) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$0>>2] = $12;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $13 = (invoke_iiii(881,0,($$byval_copy|0),($__this|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 4;
   } else {
    $16 = ($parameters|0)==(0|0);
    if ($16) {
     __THREW__ = 0;
     invoke_vi(3799,($13|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 4;
      break;
     }
     $19 = (($13) + 12|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ($20|0)==(0);
     if (!($21)) {
      label = 14;
     }
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($parameters|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 4;
      break;
     }
     $24 = (($parameters) + 12|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($13|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 4;
      break;
     }
     $28 = (($13) + 12|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($25|0)==($29|0);
     if (!($30)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     __THREW__ = 0;
     (invoke_ii(2996,(2436368|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $33 = (invoke_ii(3469,(2436368|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 4;
      break;
     }
     $36 = HEAP32[3032256>>2]|0;
     __THREW__ = 0;
     invoke_vii(1863,($33|0),($36|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3834,($33|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 4;
      break;
     }
     // unreachable;
    }
    $41 = $invokeAttr & 65536;
    $42 = ($41|0)==(0);
    L20: do {
     if ($42) {
      __THREW__ = 0;
      $47 = (invoke_iiiiii(113,0,($$02|0),($parameters|0),($13|0),($culture|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break L1;
      }
      if (!($47)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        label = 4;
        break L1;
       }
       __THREW__ = 0;
       $52 = (invoke_ii(3469,(2560072|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 4;
        break L1;
       }
       $55 = HEAP32[3032264>>2]|0;
       __THREW__ = 0;
       invoke_vii(1924,($52|0),($55|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        label = 4;
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3834,($52|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        label = 4;
        break L1;
       }
       // unreachable;
      }
     } else {
      $43 = (($13) + 12|0);
      $44 = (($parameters) + 16|0);
      $45 = (($13) + 16|0);
      $46 = (($parameters) + 12|0);
      $V_1$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($13|0));
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if ($111) {
        label = 3;
        break;
       }
       $112 = HEAP32[$43>>2]|0;
       $113 = ($V_1$0|0)<($112|0);
       if (!($113)) {
        break L20;
       }
       __THREW__ = 0;
       invoke_vi(3799,($parameters|0));
       $114 = __THREW__; __THREW__ = 0;
       $115 = $114&1;
       if ($115) {
        label = 3;
        break;
       }
       $60 = HEAP32[$46>>2]|0;
       $61 = ($V_1$0>>>0)<($60>>>0);
       if (!($61)) {
        __THREW__ = 0;
        $62 = (invoke_i(132)|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($62|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 3;
         break;
        }
       }
       $67 = HEAP32[$parameters>>2]|0;
       $68 = (($67) + 92|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = Math_imul($69, $V_1$0)|0;
       $71 = (($44) + ($70)|0);
       $72 = HEAP32[$71>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($72|0));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $75 = (invoke_ii(1782,($72|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($13|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 3;
        break;
       }
       $80 = HEAP32[$43>>2]|0;
       $81 = ($V_1$0>>>0)<($80>>>0);
       if (!($81)) {
        __THREW__ = 0;
        $82 = (invoke_i(132)|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($82|0));
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 3;
         break;
        }
       }
       $87 = HEAP32[$13>>2]|0;
       $88 = (($87) + 92|0);
       $89 = HEAP32[$88>>2]|0;
       $90 = Math_imul($89, $V_1$0)|0;
       $91 = (($45) + ($90)|0);
       $92 = HEAP32[$91>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($92|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $95 = (invoke_iii(2730,(2397472|0),($92|0))|0);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if ($97) {
        label = 3;
        break;
       }
       $98 = ($75|0)==($95|0);
       $99 = (($V_1$0) + 1)|0;
       if ($98) {
        $V_1$0 = $99;
       } else {
        break;
       }
      }
      if ((label|0) == 3) {
       $4 = ___cxa_find_matching_catch()|0;
       $5 = tempRet0;
       $lpad$phi$index = $4;$lpad$phi$index2 = $5;
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $100 = __THREW__; __THREW__ = 0;
      $101 = $100&1;
      if ($101) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      $102 = (invoke_ii(3469,(2560072|0))|0);
      $103 = __THREW__; __THREW__ = 0;
      $104 = $103&1;
      if ($104) {
       label = 4;
       break L1;
      }
      $105 = HEAP32[3032272>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($102|0),($105|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3834,($102|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       label = 4;
       break L1;
      }
      // unreachable;
     }
    } while(0);
    __THREW__ = 0;
    $116 = (invoke_iii(2734,(2423264|0),($__this|0))|0);
    $117 = __THREW__; __THREW__ = 0;
    $118 = $117&1;
    if ($118) {
     label = 4;
    } else {
     if ($116) {
      __THREW__ = 0;
      (invoke_ii(2996,(2607872|0))|0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $121 = (invoke_ii(3469,(2607872|0))|0);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       label = 4;
       break;
      }
      $124 = HEAP32[3032280>>2]|0;
      __THREW__ = 0;
      invoke_vii(1947,($121|0),($124|0));
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if ($126) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3834,($121|0));
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       label = 4;
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     $129 = (invoke_iiiii(142,($__this|0),($obj|0),($parameters|0),($V_2|0))|0);
     $130 = __THREW__; __THREW__ = 0;
     $131 = $130&1;
     if (!($131)) {
      $132 = HEAP32[$V_2>>2]|0;
      $133 = ($132|0)==(0|0);
      if ($133) {
       $$0 = $129;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3834,($132|0));
      $177 = __THREW__; __THREW__ = 0;
      $178 = $177&1;
      if ($178) {
       label = 4;
       break;
      }
      // unreachable;
     }
     $134 = ___cxa_find_matching_catch(348288|0)|0;
     $135 = tempRet0;
     $136 = (_llvm_eh_typeid_for((348288|0))|0);
     $137 = ($135|0)==($136|0);
     if (!($137)) {
      $$03 = $134;$$04 = $135;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$03|0);
      // unreachable;
     }
     $138 = (___cxa_begin_catch(($134|0))|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = HEAP32[$139>>2]|0;
     __THREW__ = 0;
     $141 = (invoke_iii(2727,(2551840|0),($140|0))|0);
     $142 = __THREW__; __THREW__ = 0;
     $143 = $142&1;
     do {
      if (!($143)) {
       if ($141) {
        $$01 = 19;
       } else {
        $148 = HEAP32[$138>>2]|0;
        $149 = HEAP32[$148>>2]|0;
        __THREW__ = 0;
        $150 = (invoke_iii(2727,(2610792|0),($149|0))|0);
        $151 = __THREW__; __THREW__ = 0;
        $152 = $151&1;
        if ($152) {
         break;
        }
        if ($150) {
         $$01 = 20;
        } else {
         $153 = HEAP32[$138>>2]|0;
         $154 = HEAP32[$153>>2]|0;
         __THREW__ = 0;
         $155 = (invoke_iii(2727,(2246120|0),($154|0))|0);
         $156 = __THREW__; __THREW__ = 0;
         $157 = $156&1;
         if ($157) {
          break;
         }
         if ($155) {
          $$01 = 21;
         } else {
          $158 = (___cxa_allocate_exception(4)|0);
          $159 = HEAP32[$138>>2]|0;
          HEAP32[$158>>2] = $159;
          __THREW__ = 0;
          invoke_viii(1567,($158|0),(348288|0),(0|0));
          $160 = __THREW__; __THREW__ = 0;
          $161 = $160&1;
          if ($161) {
           break;
          }
          // unreachable;
         }
        }
       }
       __THREW__ = 0;
       invoke_v(66);
       $162 = __THREW__; __THREW__ = 0;
       $163 = $162&1;
       if ($163) {
        label = 4;
        break L1;
       }
       if ((($$01|0) == 19)) {
        __THREW__ = 0;
        invoke_vi(3834,($139|0));
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if ($165) {
         label = 4;
         break L1;
        }
        // unreachable;
       } else if ((($$01|0) == 20)) {
        __THREW__ = 0;
        invoke_vi(3834,($139|0));
        $166 = __THREW__; __THREW__ = 0;
        $167 = $166&1;
        if ($167) {
         label = 4;
         break L1;
        }
        // unreachable;
       } else if ((($$01|0) == 21)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2435952|0))|0);
        $168 = __THREW__; __THREW__ = 0;
        $169 = $168&1;
        if ($169) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        $170 = (invoke_ii(3469,(2435952|0))|0);
        $171 = __THREW__; __THREW__ = 0;
        $172 = $171&1;
        if ($172) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        invoke_vii(1862,($170|0),($139|0));
        $173 = __THREW__; __THREW__ = 0;
        $174 = $173&1;
        if ($174) {
         label = 4;
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3834,($170|0));
        $175 = __THREW__; __THREW__ = 0;
        $176 = $175&1;
        if ($176) {
         label = 4;
         break L1;
        }
        // unreachable;
       } else {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     $144 = ___cxa_find_matching_catch()|0;
     $145 = tempRet0;
     __THREW__ = 0;
     invoke_v(66);
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      $179 = ___cxa_find_matching_catch(0|0)|0;
      $180 = tempRet0;
      ___clang_call_terminate($179);
      // unreachable;
     } else {
      $$03 = $144;$$04 = $145;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$03|0);
      // unreachable;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  $lpad$phi$index = $6;$lpad$phi$index2 = $7;
 }
 $$03 = $lpad$phi$index;$$04 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Reflection_TargetParameterCountException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP56mscorlib_System_Reflection_TargetParameterCountExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2436136);
 __THREW__ = 0;
 invoke_vii(1781,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z60mscorlib_System_Reflection_TargetInvocationException_m__ctorP52mscorlib_System_Reflection_TargetInvocationExceptionP25mscorlib_System_Exception($__this,$inner) {
 $__this = $__this|0;
 $inner = $inner|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2435728);
 __THREW__ = 0;
 invoke_v(632);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3033664>>2]|0;
  __THREW__ = 0;
  invoke_viii(543,($__this|0),($2|0),($inner|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z56mscorlib_System_Reflection_MonoMethod_m_get_MethodHandleP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $0 = sp;
 $_stackTraceSentry = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423312);
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$1>>2] = $3;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(1973,($0|0),($$byval_copy|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  $6 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Reflection_MonoMethod_m_get_AttributesP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423360);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(919,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z61mscorlib_System_Reflection_MonoMethod_m_get_CallingConventionP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423408);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(920,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_MonoMethod_m_get_ReflectedTypeP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423456);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z57mscorlib_System_Reflection_MonoMethod_m_get_DeclaringTypeP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423504);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(917,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z48mscorlib_System_Reflection_MonoMethod_m_get_NameP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423552);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $3 = (invoke_iii(922,0,($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $$0 = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z49mscorlib_System_Reflection_MonoMethod_m_IsDefinedP37mscorlib_System_Reflection_MonoMethodP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423600);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z114mscorlib_System_Reflection_MonoMethod_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP37mscorlib_System_Reflection_MonoMethodb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423648);
 __THREW__ = 0;
 $0 = (invoke_iiii(1202,(0|0),($__this|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z135mscorlib_System_Reflection_MonoMethod_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP37mscorlib_System_Reflection_MonoMethodP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423696);
 __THREW__ = 0;
 $0 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z61mscorlib_System_Reflection_MonoMethod_m_GetDllImportAttributeP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$mhandle) {
 $__this = $__this|0;
 $mhandle = $mhandle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423744);
 $1 = HEAP32[2423792>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2423800|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2423792>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$mhandle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $10 = (invoke_ii($9|0,($$byval_copy|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __Z65mscorlib_System_Reflection_MonoMethod_m_GetPseudoCustomAttributesP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$byval_copy1 = 0, $$lobit = 0, $$lobit2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $V_0$1 = 0, $V_0$2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 $0 = sp + 24|0;
 $1 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423872);
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = $3;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii(600,($L_2|0),0,($$byval_copy1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($L_2) + 8|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($L_2) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 & 128;
   $11 = ($10|0)!=(0);
   $$lobit = $10 >>> 7;
   $12 = $7 & 8192;
   $13 = ($12|0)==(0);
   $$lobit2 = $12 >>> 13;
   $V_0$1 = (($$lobit) + ($$lobit2))|0;
   $14 = ($V_0$1|0)==(0);
   if ($14) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_iii(2760,(1167664|0),($V_0$1|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     if ($11) {
      __THREW__ = 0;
      (invoke_ii(2996,(2445816|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      $24 = (invoke_ii(3469,(2445816|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(2347,($24|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($19|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = (($19) + 12|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($32|0)==(0);
      if ($33) {
       __THREW__ = 0;
       $34 = (invoke_i(132)|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($34|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($19|0),($24|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      $41 = (($19) + 16|0);
      HEAP32[$41>>2] = $24;
      $V_0$2 = 1;
     } else {
      $V_0$2 = 0;
     }
     if ($13) {
      $$0 = $19;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $42 = HEAP32[$2>>2]|0;
     HEAP32[$1>>2] = $42;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
     $43 = (invoke_iii(925,0,($$byval_copy1|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      if ($11) {
       __THREW__ = 0;
       invoke_vi(3799,($43|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       $48 = (($43) + 8|0);
       HEAP8[$48>>0] = 1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($19|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if (!($50)) {
       $51 = (($19) + 12|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($V_0$2>>>0)<($52>>>0);
       if (!($53)) {
        __THREW__ = 0;
        $54 = (invoke_i(132)|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($19|0),($43|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if (!($60)) {
        $61 = HEAP32[$19>>2]|0;
        $62 = (($19) + 16|0);
        $63 = (($61) + 92|0);
        $64 = HEAP32[$63>>2]|0;
        $65 = (0 - ($V_0$2))|0;
        $66 = $64 & $65;
        $67 = (($62) + ($66)|0);
        HEAP32[$67>>2] = $43;
        $$0 = $19;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m__ctorP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2445680);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z59mscorlib_System_Reflection_MonoMethod_m_ShouldPrintFullNameP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B9_0$0 = 0, $_stackTraceSentry = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423920);
 __THREW__ = 0;
 invoke_vi(3799,($type|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2734,(2234136|0),($type|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   if (!($2)) {
    $G_B9_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B9_0$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($type|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2734,(2234568|0),($type|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     if (!($9)) {
      $G_B9_0$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B9_0$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($type|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      $14 = (invoke_iii(2730,(2224328|0),($type|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3799,($14|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        $19 = (invoke_iii(2734,(2234664|0),($14|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         if ($19) {
          $G_B9_0$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($G_B9_0$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($type|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          __THREW__ = 0;
          $24 = (invoke_iii(2730,(2224328|0),($type|0))|0);
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           __THREW__ = 0;
           invoke_vi(3799,($24|0));
           $27 = __THREW__; __THREW__ = 0;
           $28 = $27&1;
           if (!($28)) {
            __THREW__ = 0;
            $29 = (invoke_ii(1899,($24|0))|0);
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if (!($31)) {
             $phitmp = $29 ^ 1;
             $G_B9_0$0 = $phitmp;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($G_B9_0$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Reflection_MonoMethod_m_ToStringP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $V_5$0 = 0, $V_6$0$in = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423968);
 __THREW__ = 0;
 invoke_v(633);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2537888|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(2537888|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(2525,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_iii(2730,(2422920|0),($__this|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       $12 = (invoke_iii(926,0,($9|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        if ($12) {
         __THREW__ = 0;
         invoke_vi(3799,($9|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
         __THREW__ = 0;
         $23 = (invoke_iii(2730,(2149160|0),($9|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break;
         }
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($23|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          break;
         }
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($9|0));
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          break;
         }
         __THREW__ = 0;
         $32 = (invoke_iii(2730,(2233608|0),($9|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          break;
         }
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($32|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = HEAP32[3032640>>2]|0;
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($41|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          __THREW__ = 0;
          $44 = (invoke_iii(2730,(2423552|0),($__this|0))|0);
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if (!($46)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if (!($48)) {
            __THREW__ = 0;
            (invoke_iii(989,($4|0),($44|0))|0);
            $49 = __THREW__; __THREW__ = 0;
            $50 = $49&1;
            if (!($50)) {
             __THREW__ = 0;
             $51 = (invoke_iii(2734,(2424016|0),($__this|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              do {
               if ($51) {
                __THREW__ = 0;
                $54 = (invoke_iii(2730,(2424064|0),($__this|0))|0);
                $55 = __THREW__; __THREW__ = 0;
                $56 = $55&1;
                if ($56) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $57 = __THREW__; __THREW__ = 0;
                $58 = $57&1;
                if ($58) {
                 break L1;
                }
                $59 = HEAP32[3032648>>2]|0;
                __THREW__ = 0;
                (invoke_iii(989,($4|0),($59|0))|0);
                $60 = __THREW__; __THREW__ = 0;
                $61 = $60&1;
                if ($61) {
                 break L1;
                }
                $62 = (($54) + 12|0);
                $V_3$0 = 0;
                while(1) {
                 __THREW__ = 0;
                 invoke_vi(3799,($54|0));
                 $93 = __THREW__; __THREW__ = 0;
                 $94 = $93&1;
                 if ($94) {
                  label = 9;
                  break;
                 }
                 $95 = HEAP32[$62>>2]|0;
                 $96 = ($V_3$0|0)<($95|0);
                 if (!($96)) {
                  label = 45;
                  break;
                 }
                 $97 = ($V_3$0|0)<(1);
                 if (!($97)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $63 = __THREW__; __THREW__ = 0;
                  $64 = $63&1;
                  if ($64) {
                   label = 9;
                   break;
                  }
                  $65 = HEAP32[3032656>>2]|0;
                  __THREW__ = 0;
                  (invoke_iii(989,($4|0),($65|0))|0);
                  $66 = __THREW__; __THREW__ = 0;
                  $67 = $66&1;
                  if ($67) {
                   label = 9;
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($54|0));
                 $68 = __THREW__; __THREW__ = 0;
                 $69 = $68&1;
                 if ($69) {
                  label = 9;
                  break;
                 }
                 $70 = HEAP32[$62>>2]|0;
                 $71 = ($V_3$0>>>0)<($70>>>0);
                 if (!($71)) {
                  __THREW__ = 0;
                  $72 = (invoke_i(132)|0);
                  $73 = __THREW__; __THREW__ = 0;
                  $74 = $73&1;
                  if ($74) {
                   label = 9;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($72|0));
                  $75 = __THREW__; __THREW__ = 0;
                  $76 = $75&1;
                  if ($76) {
                   label = 9;
                   break;
                  }
                 }
                 $77 = HEAP32[$54>>2]|0;
                 $78 = (($77) + 92|0);
                 $79 = HEAP32[$78>>2]|0;
                 $80 = Math_imul($79, $V_3$0)|0;
                 $$sum1 = (($80) + 16)|0;
                 $81 = (($54) + ($$sum1)|0);
                 $82 = HEAP32[$81>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($82|0));
                 $83 = __THREW__; __THREW__ = 0;
                 $84 = $83&1;
                 if ($84) {
                  label = 9;
                  break;
                 }
                 __THREW__ = 0;
                 $85 = (invoke_iii(2730,(2233608|0),($82|0))|0);
                 $86 = __THREW__; __THREW__ = 0;
                 $87 = $86&1;
                 if ($87) {
                  label = 9;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $88 = __THREW__; __THREW__ = 0;
                 $89 = $88&1;
                 if ($89) {
                  label = 9;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(989,($4|0),($85|0))|0);
                 $90 = __THREW__; __THREW__ = 0;
                 $91 = $90&1;
                 if ($91) {
                  label = 9;
                  break;
                 }
                 $92 = (($V_3$0) + 1)|0;
                 $V_3$0 = $92;
                }
                if ((label|0) == 9) {
                 $17 = ___cxa_find_matching_catch()|0;
                 $18 = tempRet0;
                 $lpad$phi$index = $17;$lpad$phi$index3 = $18;
                 __ZN16StackTraceSentryD2Ev(0);
                 ___resumeException($lpad$phi$index|0);
                 // unreachable;
                }
                else if ((label|0) == 45) {
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $98 = __THREW__; __THREW__ = 0;
                 $99 = $98&1;
                 if ($99) {
                  break L1;
                 }
                 $100 = HEAP32[3032664>>2]|0;
                 __THREW__ = 0;
                 (invoke_iii(989,($4|0),($100|0))|0);
                 $101 = __THREW__; __THREW__ = 0;
                 $102 = $101&1;
                 if ($102) {
                  break L1;
                 } else {
                  break;
                 }
                }
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($4|0));
              $103 = __THREW__; __THREW__ = 0;
              $104 = $103&1;
              if (!($104)) {
               $105 = HEAP32[3032672>>2]|0;
               __THREW__ = 0;
               (invoke_iii(989,($4|0),($105|0))|0);
               $106 = __THREW__; __THREW__ = 0;
               $107 = $106&1;
               if (!($107)) {
                __THREW__ = 0;
                $108 = (invoke_iii(2730,(2423016|0),($__this|0))|0);
                $109 = __THREW__; __THREW__ = 0;
                $110 = $109&1;
                if (!($110)) {
                 $111 = (($108) + 12|0);
                 $V_5$0 = 0;
                 while(1) {
                  __THREW__ = 0;
                  invoke_vi(3799,($108|0));
                  $174 = __THREW__; __THREW__ = 0;
                  $175 = $174&1;
                  if ($175) {
                   label = 8;
                   break;
                  }
                  $176 = HEAP32[$111>>2]|0;
                  $177 = ($V_5$0|0)<($176|0);
                  if (!($177)) {
                   break;
                  }
                  $178 = ($V_5$0|0)<(1);
                  if (!($178)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $112 = __THREW__; __THREW__ = 0;
                   $113 = $112&1;
                   if ($113) {
                    label = 8;
                    break;
                   }
                   $114 = HEAP32[3032680>>2]|0;
                   __THREW__ = 0;
                   (invoke_iii(989,($4|0),($114|0))|0);
                   $115 = __THREW__; __THREW__ = 0;
                   $116 = $115&1;
                   if ($116) {
                    label = 8;
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($108|0));
                  $117 = __THREW__; __THREW__ = 0;
                  $118 = $117&1;
                  if ($118) {
                   label = 8;
                   break;
                  }
                  $119 = HEAP32[$111>>2]|0;
                  $120 = ($V_5$0>>>0)<($119>>>0);
                  if (!($120)) {
                   __THREW__ = 0;
                   $121 = (invoke_i(132)|0);
                   $122 = __THREW__; __THREW__ = 0;
                   $123 = $122&1;
                   if ($123) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($121|0));
                   $124 = __THREW__; __THREW__ = 0;
                   $125 = $124&1;
                   if ($125) {
                    label = 8;
                    break;
                   }
                  }
                  $126 = HEAP32[$108>>2]|0;
                  $127 = (($126) + 92|0);
                  $128 = HEAP32[$127>>2]|0;
                  $129 = Math_imul($128, $V_5$0)|0;
                  $$sum = (($129) + 16)|0;
                  $130 = (($108) + ($$sum)|0);
                  $131 = HEAP32[$130>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($131|0));
                  $132 = __THREW__; __THREW__ = 0;
                  $133 = $132&1;
                  if ($133) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  $134 = (invoke_iii(2730,(2397472|0),($131|0))|0);
                  $135 = __THREW__; __THREW__ = 0;
                  $136 = $135&1;
                  if ($136) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($134|0));
                  $137 = __THREW__; __THREW__ = 0;
                  $138 = $137&1;
                  if ($138) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  $139 = (invoke_iii(2734,(2234040|0),($134|0))|0);
                  $140 = __THREW__; __THREW__ = 0;
                  $141 = $140&1;
                  if ($141) {
                   label = 8;
                   break;
                  }
                  if ($139) {
                   __THREW__ = 0;
                   invoke_vi(3799,($134|0));
                   $142 = __THREW__; __THREW__ = 0;
                   $143 = $142&1;
                   if ($143) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   $144 = (invoke_iii(2730,(2224328|0),($134|0))|0);
                   $145 = __THREW__; __THREW__ = 0;
                   $146 = $145&1;
                   if ($146) {
                    label = 8;
                    break;
                   } else {
                    $V_6$0$in = $144;
                   }
                  } else {
                   $V_6$0$in = $134;
                  }
                  __THREW__ = 0;
                  $147 = (invoke_iii(926,0,($V_6$0$in|0))|0);
                  $148 = __THREW__; __THREW__ = 0;
                  $149 = $148&1;
                  if ($149) {
                   label = 8;
                   break;
                  }
                  if ($147) {
                   __THREW__ = 0;
                   invoke_vi(3799,($V_6$0$in|0));
                   $150 = __THREW__; __THREW__ = 0;
                   $151 = $150&1;
                   if ($151) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   $152 = (invoke_iii(2730,(2149160|0),($V_6$0$in|0))|0);
                   $153 = __THREW__; __THREW__ = 0;
                   $154 = $153&1;
                   if ($154) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $155 = __THREW__; __THREW__ = 0;
                   $156 = $155&1;
                   if ($156) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(989,($4|0),($152|0))|0);
                   $157 = __THREW__; __THREW__ = 0;
                   $158 = $157&1;
                   if ($158) {
                    label = 8;
                    break;
                   }
                  } else {
                   __THREW__ = 0;
                   invoke_vi(3799,($V_6$0$in|0));
                   $159 = __THREW__; __THREW__ = 0;
                   $160 = $159&1;
                   if ($160) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   $161 = (invoke_iii(2730,(2233608|0),($V_6$0$in|0))|0);
                   $162 = __THREW__; __THREW__ = 0;
                   $163 = $162&1;
                   if ($163) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $164 = __THREW__; __THREW__ = 0;
                   $165 = $164&1;
                   if ($165) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(989,($4|0),($161|0))|0);
                   $166 = __THREW__; __THREW__ = 0;
                   $167 = $166&1;
                   if ($167) {
                    label = 8;
                    break;
                   }
                  }
                  if ($139) {
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $168 = __THREW__; __THREW__ = 0;
                   $169 = $168&1;
                   if ($169) {
                    label = 8;
                    break;
                   }
                   $170 = HEAP32[3032688>>2]|0;
                   __THREW__ = 0;
                   (invoke_iii(989,($4|0),($170|0))|0);
                   $171 = __THREW__; __THREW__ = 0;
                   $172 = $171&1;
                   if ($172) {
                    label = 8;
                    break;
                   }
                  }
                  $173 = (($V_5$0) + 1)|0;
                  $V_5$0 = $173;
                 }
                 if ((label|0) == 8) {
                  $15 = ___cxa_find_matching_catch()|0;
                  $16 = tempRet0;
                  $lpad$phi$index = $15;$lpad$phi$index3 = $16;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($lpad$phi$index|0);
                  // unreachable;
                 }
                 __THREW__ = 0;
                 $179 = (invoke_iii(2729,(2423408|0),($__this|0))|0);
                 $180 = __THREW__; __THREW__ = 0;
                 $181 = $180&1;
                 if (!($181)) {
                  $182 = $179 & 2;
                  $183 = ($182|0)==(0);
                  if (!($183)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($108|0));
                   $184 = __THREW__; __THREW__ = 0;
                   $185 = $184&1;
                   if ($185) {
                    break;
                   }
                   $186 = HEAP32[$111>>2]|0;
                   $187 = ($186|0)<(1);
                   if (!($187)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($4|0));
                    $188 = __THREW__; __THREW__ = 0;
                    $189 = $188&1;
                    if ($189) {
                     break;
                    }
                    $190 = HEAP32[3032696>>2]|0;
                    __THREW__ = 0;
                    (invoke_iii(989,($4|0),($190|0))|0);
                    $191 = __THREW__; __THREW__ = 0;
                    $192 = $191&1;
                    if ($192) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $193 = __THREW__; __THREW__ = 0;
                   $194 = $193&1;
                   if ($194) {
                    break;
                   }
                   $195 = HEAP32[3032704>>2]|0;
                   __THREW__ = 0;
                   (invoke_iii(989,($4|0),($195|0))|0);
                   $196 = __THREW__; __THREW__ = 0;
                   $197 = $196&1;
                   if ($197) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $198 = __THREW__; __THREW__ = 0;
                  $199 = $198&1;
                  if ($199) {
                   break;
                  }
                  $200 = HEAP32[3032712>>2]|0;
                  __THREW__ = 0;
                  (invoke_iii(989,($4|0),($200|0))|0);
                  $201 = __THREW__; __THREW__ = 0;
                  $202 = $201&1;
                  if ($202) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $203 = __THREW__; __THREW__ = 0;
                  $204 = $203&1;
                  if ($204) {
                   break;
                  }
                  __THREW__ = 0;
                  $205 = (invoke_iii(2730,(2535432|0),($4|0))|0);
                  $206 = __THREW__; __THREW__ = 0;
                  $207 = $206&1;
                  if ($207) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($205|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $lpad$phi$index = $19;$lpad$phi$index3 = $20;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_Reflection_MonoMethod_m_GetObjectDataP37mscorlib_System_Reflection_MonoMethodP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $G_B4_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2424112);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2424016|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    __THREW__ = 0;
    $5 = (invoke_iii(2734,(2424160|0),($__this|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    if ($5) {
     $G_B4_0$0 = 0;
    } else {
     __THREW__ = 0;
     $8 = (invoke_iii(2730,(2424064|0),($__this|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     $G_B4_0$0 = $8;
    }
   } else {
    $G_B4_0$0 = 0;
   }
   __THREW__ = 0;
   $11 = (invoke_iii(2730,(2423552|0),($__this|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_iii(2730,(2423456|0),($__this|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_iii(2730,(2423968|0),($__this|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_viiiiiii(20,0,($info|0),($11|0),($14|0),($17|0),8,($G_B4_0$0|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z57mscorlib_System_Reflection_MonoMethod_m_MakeGenericMethodP37mscorlib_System_Reflection_MonoMethodP24mscorlib_System_Type_arr($__this,$methodInstantiation) {
 $__this = $__this|0;
 $methodInstantiation = $methodInstantiation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_12 = 0, $L_16 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_12 = sp;
 $L_16 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2424208);
 __THREW__ = 0;
 invoke_v(634);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($methodInstantiation|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3032736>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3834,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $3 = (($methodInstantiation) + 12|0);
   $4 = (($methodInstantiation) + 16|0);
   $V_2$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($methodInstantiation|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     label = 4;
     break;
    }
    $45 = HEAP32[$3>>2]|0;
    $46 = ($V_2$0|0)<($45|0);
    if (!($46)) {
     label = 24;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($methodInstantiation|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     label = 4;
     break;
    }
    $19 = HEAP32[$3>>2]|0;
    $20 = ($V_2$0>>>0)<($19>>>0);
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_i(132)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($21|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 4;
      break;
     }
    }
    $26 = HEAP32[$methodInstantiation>>2]|0;
    $27 = (($26) + 92|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = Math_imul($28, $V_2$0)|0;
    $30 = (($4) + ($29)|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31|0)==(0|0);
    $33 = (($V_2$0) + 1)|0;
    if ($32) {
     label = 16;
     break;
    } else {
     $V_2$0 = $33;
    }
   }
   if ((label|0) == 4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    $lpad$phi$index = $5;$lpad$phi$index2 = $6;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 16) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    __THREW__ = 0;
    $36 = (invoke_ii(3469,(2560584|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2585,($36|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3834,($36|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 24) {
    __THREW__ = 0;
    $49 = (invoke_iii(928,($__this|0),($methodInstantiation|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    $52 = ($49|0)==(0|0);
    if (!($52)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($49|0);
    }
    __THREW__ = 0;
    $53 = (invoke_iii(2730,(2424064|0),($__this|0))|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($53|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    $58 = (($53) + 12|0);
    $59 = HEAP32[$58>>2]|0;
    HEAP32[$L_12>>2] = $59;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     break;
    }
    __THREW__ = 0;
    $62 = (invoke_iii(2724,(2155952|0),($L_12|0))|0);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($methodInstantiation|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     break;
    }
    $67 = HEAP32[$3>>2]|0;
    HEAP32[$L_16>>2] = $67;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     break;
    }
    __THREW__ = 0;
    $70 = (invoke_iii(2724,(2155952|0),($L_16|0))|0);
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     break;
    }
    $73 = HEAP32[3032744>>2]|0;
    __THREW__ = 0;
    $74 = (invoke_iiiii(98,(0|0),($73|0),($62|0),($70|0))|0);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $77 = __THREW__; __THREW__ = 0;
    $78 = $77&1;
    if ($78) {
     break;
    }
    __THREW__ = 0;
    $79 = (invoke_ii(3469,(2560072|0))|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1924,($79|0),($74|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3834,($79|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
    // unreachable;
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Reflection_MonoMethod_m_MakeGenericMethod_implP37mscorlib_System_Reflection_MonoMethodP24mscorlib_System_Type_arr($__this,$types) {
 $__this = $__this|0;
 $types = $types|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2424256);
 $0 = HEAP32[2424304>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2424312|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2424304>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($types|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MonoMethod_m_GetGenericArgumentsP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2424064);
 $0 = HEAP32[2424384>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2424392|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2424384>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Reflection_MonoMethod_m_get_IsGenericMethodDefinitionP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2424160);
 $0 = HEAP32[2424448>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2424456|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2424448>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MonoMethod_m_get_IsGenericMethodP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2424016);
 $0 = HEAP32[2424520>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2424528|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2424520>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Reflection_MonoMethod_m_get_ContainsGenericParametersP37mscorlib_System_Reflection_MonoMethod($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2423264);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2424016|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   L3: do {
    if ($0) {
     __THREW__ = 0;
     $7 = (invoke_iii(2730,(2424064|0),($__this|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break L1;
     }
     $10 = (($7) + 12|0);
     $V_2$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = HEAP32[$10>>2]|0;
      $33 = ($V_2$0|0)<($32|0);
      if (!($33)) {
       break L3;
      }
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      $11 = HEAP32[$10>>2]|0;
      $12 = ($V_2$0>>>0)<($11>>>0);
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_i(132)|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($13|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
      }
      $18 = HEAP32[$7>>2]|0;
      $19 = (($18) + 92|0);
      $20 = HEAP32[$19>>2]|0;
      $21 = Math_imul($20, $V_2$0)|0;
      $$sum = (($21) + 16)|0;
      $22 = (($7) + ($$sum)|0);
      $23 = HEAP32[$22>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($23|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2734,(2223448|0),($23|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = (($V_2$0) + 1)|0;
      if ($26) {
       $$0 = 1;
       label = 20;
       break;
      } else {
       $V_2$0 = $29;
      }
     }
     if ((label|0) == 20) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $3 = ___cxa_find_matching_catch()|0;
     $4 = tempRet0;
     $lpad$phi$index = $3;$lpad$phi$index2 = $4;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   } while(0);
   __THREW__ = 0;
   $36 = (invoke_iii(2730,(2423504|0),($__this|0))|0);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if (!($38)) {
    __THREW__ = 0;
    invoke_vi(3799,($36|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     __THREW__ = 0;
     $41 = (invoke_iii(2734,(2223448|0),($36|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if (!($43)) {
      $$0 = $41;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Reflection_MonoCMethod_m_GetMethodImplementationFlagsP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2425656);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(921,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Reflection_MonoCMethod_m_GetParametersP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2425704);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iiii(881,0,($$byval_copy|0),($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_Reflection_MonoCMethod_m_InternalInvokeP38mscorlib_System_Reflection_MonoCMethodP22mscorlib_System_ObjectP26mscorlib_System_Object_arrPP25mscorlib_System_Exception($__this,$obj,$parameters,$exc) {
 $__this = $__this|0;
 $obj = $obj|0;
 $parameters = $parameters|0;
 $exc = $exc|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2425752);
 $0 = HEAP32[2425800>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2425808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2425800>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiii($7|0,($__this|0),($obj|0),($parameters|0),($exc|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z240mscorlib_System_Reflection_MonoCMethod_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP38mscorlib_System_Reflection_MonoCMethodP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo($__this,$obj,$invokeAttr,$binder,$parameters,$culture) {
 $__this = $__this|0;
 $obj = $obj|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $parameters = $parameters|0;
 $culture = $culture|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $$04 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2425904);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(635);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if ($1) {
   label = 4;
  } else {
   $2 = ($binder|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    $7 = (invoke_ii(2196,0)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     label = 4;
     break;
    } else {
     $$02 = $7;
    }
   } else {
    $$02 = $binder;
   }
   __THREW__ = 0;
   $10 = (invoke_iii(2730,(2425704|0),($__this|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 4;
   } else {
    $13 = ($parameters|0)==(0|0);
    if ($13) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      label = 4;
      break;
     }
     $16 = (($10) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0);
     if (!($18)) {
      label = 14;
     }
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($parameters|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 4;
      break;
     }
     $21 = (($parameters) + 12|0);
     $22 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 4;
      break;
     }
     $25 = (($10) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($22|0)==($26|0);
     if (!($27)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     __THREW__ = 0;
     (invoke_ii(2996,(2436368|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $30 = (invoke_ii(3469,(2436368|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      label = 4;
      break;
     }
     $33 = HEAP32[3032968>>2]|0;
     __THREW__ = 0;
     invoke_vii(1863,($30|0),($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3834,($30|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 4;
      break;
     }
     // unreachable;
    }
    $38 = $invokeAttr & 65536;
    $39 = ($38|0)==(0);
    L20: do {
     if ($39) {
      __THREW__ = 0;
      $43 = (invoke_iiiiii(113,0,($$02|0),($parameters|0),($10|0),($culture|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 4;
       break L1;
      }
      if (!($43)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        label = 4;
        break L1;
       }
       __THREW__ = 0;
       $48 = (invoke_ii(3469,(2560072|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        label = 4;
        break L1;
       }
       $51 = HEAP32[3032976>>2]|0;
       __THREW__ = 0;
       invoke_vii(1924,($48|0),($51|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        label = 4;
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3834,($48|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 4;
        break L1;
       }
       // unreachable;
      }
     } else {
      $40 = (($10) + 12|0);
      $41 = (($parameters) + 16|0);
      $42 = (($parameters) + 12|0);
      $V_1$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($10|0));
       $106 = __THREW__; __THREW__ = 0;
       $107 = $106&1;
       if ($107) {
        label = 3;
        break;
       }
       $108 = HEAP32[$40>>2]|0;
       $109 = ($V_1$0|0)<($108|0);
       if (!($109)) {
        break L20;
       }
       __THREW__ = 0;
       invoke_vi(3799,($parameters|0));
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if ($111) {
        label = 3;
        break;
       }
       $56 = HEAP32[$42>>2]|0;
       $57 = ($V_1$0>>>0)<($56>>>0);
       if (!($57)) {
        __THREW__ = 0;
        $58 = (invoke_i(132)|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($58|0));
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 3;
         break;
        }
       }
       $63 = HEAP32[$parameters>>2]|0;
       $64 = (($63) + 92|0);
       $65 = HEAP32[$64>>2]|0;
       $66 = Math_imul($65, $V_1$0)|0;
       $67 = (($41) + ($66)|0);
       $68 = HEAP32[$67>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($68|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $71 = (invoke_ii(1782,($68|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($10|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        label = 3;
        break;
       }
       $76 = HEAP32[$40>>2]|0;
       $77 = ($V_1$0>>>0)<($76>>>0);
       if (!($77)) {
        __THREW__ = 0;
        $78 = (invoke_i(132)|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($78|0));
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 3;
         break;
        }
       }
       $83 = HEAP32[$10>>2]|0;
       $84 = (($83) + 92|0);
       $85 = HEAP32[$84>>2]|0;
       $86 = Math_imul($85, $V_1$0)|0;
       $$sum = (($86) + 16)|0;
       $87 = (($10) + ($$sum)|0);
       $88 = HEAP32[$87>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($88|0));
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $91 = (invoke_iii(2730,(2397472|0),($88|0))|0);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        label = 3;
        break;
       }
       $94 = ($71|0)==($91|0);
       $95 = (($V_1$0) + 1)|0;
       if ($94) {
        $V_1$0 = $95;
       } else {
        break;
       }
      }
      if ((label|0) == 3) {
       $3 = ___cxa_find_matching_catch()|0;
       $4 = tempRet0;
       $lpad$phi$index = $3;$lpad$phi$index2 = $4;
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      $98 = (invoke_ii(3469,(2560072|0))|0);
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       label = 4;
       break L1;
      }
      $101 = HEAP32[3032984>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($98|0),($101|0));
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       label = 4;
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3834,($98|0));
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       label = 4;
       break L1;
      }
      // unreachable;
     }
    } while(0);
    $112 = ($obj|0)!=(0|0);
    if (!($112)) {
     __THREW__ = 0;
     $113 = (invoke_iii(2730,(2425952|0),($__this|0))|0);
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if ($115) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($113|0));
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $118 = (invoke_iii(2734,(2223448|0),($113|0))|0);
     $119 = __THREW__; __THREW__ = 0;
     $120 = $119&1;
     if ($120) {
      label = 4;
      break;
     }
     if ($118) {
      __THREW__ = 0;
      $121 = (invoke_iii(2730,(2425952|0),($__this|0))|0);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       label = 4;
       break;
      }
      $124 = HEAP32[3032992>>2]|0;
      $125 = HEAP32[3033000>>2]|0;
      __THREW__ = 0;
      $126 = (invoke_iiiii(100,(0|0),($124|0),($121|0),($125|0))|0);
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2610504|0))|0);
      $129 = __THREW__; __THREW__ = 0;
      $130 = $129&1;
      if ($130) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $131 = (invoke_ii(3469,(2610504|0))|0);
      $132 = __THREW__; __THREW__ = 0;
      $133 = $132&1;
      if ($133) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vii(1948,($131|0),($126|0));
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3834,($131|0));
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       label = 4;
       break;
      }
      // unreachable;
     }
    }
    $138 = $invokeAttr & 512;
    $139 = ($138|0)==(0);
    if (!($139)) {
     __THREW__ = 0;
     $140 = (invoke_iii(2730,(2425952|0),($__this|0))|0);
     $141 = __THREW__; __THREW__ = 0;
     $142 = $141&1;
     if ($142) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($140|0));
     $143 = __THREW__; __THREW__ = 0;
     $144 = $143&1;
     if ($144) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $145 = (invoke_iii(2734,(2233896|0),($140|0))|0);
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      label = 4;
      break;
     }
     if ($145) {
      __THREW__ = 0;
      $148 = (invoke_iii(2730,(2425952|0),($__this|0))|0);
      $149 = __THREW__; __THREW__ = 0;
      $150 = $149&1;
      if ($150) {
       label = 4;
       break;
      }
      $151 = HEAP32[3033008>>2]|0;
      __THREW__ = 0;
      $152 = (invoke_iiii(552,(0|0),($151|0),($148|0))|0);
      $153 = __THREW__; __THREW__ = 0;
      $154 = $153&1;
      if ($154) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2610504|0))|0);
      $155 = __THREW__; __THREW__ = 0;
      $156 = $155&1;
      if ($156) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $157 = (invoke_ii(3469,(2610504|0))|0);
      $158 = __THREW__; __THREW__ = 0;
      $159 = $158&1;
      if ($159) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vii(1948,($157|0),($152|0));
      $160 = __THREW__; __THREW__ = 0;
      $161 = $160&1;
      if ($161) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3834,($157|0));
      $162 = __THREW__; __THREW__ = 0;
      $163 = $162&1;
      if ($163) {
       label = 4;
       break;
      }
      // unreachable;
     }
    }
    HEAP32[$V_2>>2] = 0;
    __THREW__ = 0;
    $164 = (invoke_iiiii(143,($__this|0),($obj|0),($parameters|0),($V_2|0))|0);
    $165 = __THREW__; __THREW__ = 0;
    $166 = $165&1;
    if (!($166)) {
     $167 = HEAP32[$V_2>>2]|0;
     $168 = ($167|0)==(0|0);
     if ($168) {
      $$ = $112 ? 0 : $164;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     } else {
      __THREW__ = 0;
      invoke_vi(3834,($167|0));
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if ($206) {
       label = 4;
       break;
      }
      // unreachable;
     }
    }
    $169 = ___cxa_find_matching_catch(348288|0)|0;
    $170 = tempRet0;
    $171 = (_llvm_eh_typeid_for((348288|0))|0);
    $172 = ($170|0)==($171|0);
    if (!($172)) {
     $$03 = $169;$$04 = $170;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
    $173 = (___cxa_begin_catch(($169|0))|0);
    $174 = HEAP32[$173>>2]|0;
    $175 = HEAP32[$174>>2]|0;
    __THREW__ = 0;
    $176 = (invoke_iii(2727,(2610792|0),($175|0))|0);
    $177 = __THREW__; __THREW__ = 0;
    $178 = $177&1;
    do {
     if (!($178)) {
      if ($176) {
       $$01 = 20;
      } else {
       $183 = HEAP32[$173>>2]|0;
       $184 = HEAP32[$183>>2]|0;
       __THREW__ = 0;
       $185 = (invoke_iii(2727,(2246120|0),($184|0))|0);
       $186 = __THREW__; __THREW__ = 0;
       $187 = $186&1;
       if ($187) {
        break;
       }
       if ($185) {
        $$01 = 21;
       } else {
        $188 = (___cxa_allocate_exception(4)|0);
        $189 = HEAP32[$173>>2]|0;
        HEAP32[$188>>2] = $189;
        __THREW__ = 0;
        invoke_viii(1567,($188|0),(348288|0),(0|0));
        $190 = __THREW__; __THREW__ = 0;
        $191 = $190&1;
        if ($191) {
         break;
        }
        // unreachable;
       }
      }
      __THREW__ = 0;
      invoke_v(66);
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if ($193) {
       label = 4;
       break L1;
      }
      if ((($$01|0) == 20)) {
       __THREW__ = 0;
       invoke_vi(3834,($174|0));
       $194 = __THREW__; __THREW__ = 0;
       $195 = $194&1;
       if ($195) {
        label = 4;
        break L1;
       }
       // unreachable;
      } else if ((($$01|0) == 21)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2435952|0))|0);
       $196 = __THREW__; __THREW__ = 0;
       $197 = $196&1;
       if ($197) {
        label = 4;
        break L1;
       }
       __THREW__ = 0;
       $198 = (invoke_ii(3469,(2435952|0))|0);
       $199 = __THREW__; __THREW__ = 0;
       $200 = $199&1;
       if ($200) {
        label = 4;
        break L1;
       }
       __THREW__ = 0;
       invoke_vii(1862,($198|0),($174|0));
       $201 = __THREW__; __THREW__ = 0;
       $202 = $201&1;
       if ($202) {
        label = 4;
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3834,($198|0));
       $203 = __THREW__; __THREW__ = 0;
       $204 = $203&1;
       if ($204) {
        label = 4;
        break L1;
       }
       // unreachable;
      } else {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    } while(0);
    $179 = ___cxa_find_matching_catch()|0;
    $180 = tempRet0;
    __THREW__ = 0;
    invoke_v(66);
    $181 = __THREW__; __THREW__ = 0;
    $182 = $181&1;
    if ($182) {
     $207 = ___cxa_find_matching_catch(0|0)|0;
     $208 = tempRet0;
     ___clang_call_terminate($207);
     // unreachable;
    } else {
     $$03 = $179;$$04 = $180;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$03|0);
     // unreachable;
    }
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 }
 $$03 = $lpad$phi$index;$$04 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z217mscorlib_System_Reflection_MonoCMethod_m_Invoke_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP38mscorlib_System_Reflection_MonoCMethodiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo($__this,$invokeAttr,$binder,$parameters,$culture) {
 $__this = $__this|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $parameters = $parameters|0;
 $culture = $culture|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426000);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(119,(2425904|0),($__this|0),(0|0),($invokeAttr|0),($binder|0),($parameters|0),($culture|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_MonoCMethod_m_get_MethodHandleP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $0 = sp;
 $_stackTraceSentry = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426048);
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$0>>2] = 0;
 HEAP32[$1>>2] = $3;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 invoke_vii(1973,($0|0),($$byval_copy|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  $6 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_Reflection_MonoCMethod_m_get_AttributesP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426096);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(919,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z62mscorlib_System_Reflection_MonoCMethod_m_get_CallingConventionP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426144);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(920,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z58mscorlib_System_Reflection_MonoCMethod_m_get_ReflectedTypeP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426192);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z58mscorlib_System_Reflection_MonoCMethod_m_get_DeclaringTypeP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2425952);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(917,0,($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z49mscorlib_System_Reflection_MonoCMethod_m_get_NameP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426240);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $3 = (invoke_iii(922,0,($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $$0 = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Reflection_MonoCMethod_m_IsDefinedP38mscorlib_System_Reflection_MonoCMethodP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426288);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z115mscorlib_System_Reflection_MonoCMethod_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP38mscorlib_System_Reflection_MonoCMethodb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426336);
 __THREW__ = 0;
 $0 = (invoke_iiii(1202,(0|0),($__this|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z136mscorlib_System_Reflection_MonoCMethod_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP38mscorlib_System_Reflection_MonoCMethodP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426384);
 __THREW__ = 0;
 $0 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z49mscorlib_System_Reflection_MonoCMethod_m_ToStringP38mscorlib_System_Reflection_MonoCMethod($__this) {
 $__this = $__this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426432);
 __THREW__ = 0;
 invoke_v(636);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2537888|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(2537888|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(2525,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if (!($10)) {
       $11 = HEAP32[3033312>>2]|0;
       __THREW__ = 0;
       (invoke_iii(989,($4|0),($11|0))|0);
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        __THREW__ = 0;
        $14 = (invoke_iii(2730,(2426240|0),($__this|0))|0);
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if (!($18)) {
          __THREW__ = 0;
          (invoke_iii(989,($4|0),($14|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $21 = __THREW__; __THREW__ = 0;
           $22 = $21&1;
           if (!($22)) {
            $23 = HEAP32[3033320>>2]|0;
            __THREW__ = 0;
            (invoke_iii(989,($4|0),($23|0))|0);
            $24 = __THREW__; __THREW__ = 0;
            $25 = $24&1;
            if (!($25)) {
             __THREW__ = 0;
             $26 = (invoke_iii(2730,(2425704|0),($__this|0))|0);
             $27 = __THREW__; __THREW__ = 0;
             $28 = $27&1;
             if (!($28)) {
              $29 = (($26) + 12|0);
              $V_2$0 = 0;
              while(1) {
               __THREW__ = 0;
               invoke_vi(3799,($26|0));
               $69 = __THREW__; __THREW__ = 0;
               $70 = $69&1;
               if ($70) {
                label = 14;
                break;
               }
               $71 = HEAP32[$29>>2]|0;
               $72 = ($V_2$0|0)<($71|0);
               if (!($72)) {
                break;
               }
               $73 = ($V_2$0|0)<(1);
               if (!($73)) {
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $34 = __THREW__; __THREW__ = 0;
                $35 = $34&1;
                if ($35) {
                 label = 14;
                 break;
                }
                $36 = HEAP32[3033328>>2]|0;
                __THREW__ = 0;
                (invoke_iii(989,($4|0),($36|0))|0);
                $37 = __THREW__; __THREW__ = 0;
                $38 = $37&1;
                if ($38) {
                 label = 14;
                 break;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($26|0));
               $39 = __THREW__; __THREW__ = 0;
               $40 = $39&1;
               if ($40) {
                label = 14;
                break;
               }
               $41 = HEAP32[$29>>2]|0;
               $42 = ($V_2$0>>>0)<($41>>>0);
               if (!($42)) {
                __THREW__ = 0;
                $43 = (invoke_i(132)|0);
                $44 = __THREW__; __THREW__ = 0;
                $45 = $44&1;
                if ($45) {
                 label = 14;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($43|0));
                $46 = __THREW__; __THREW__ = 0;
                $47 = $46&1;
                if ($47) {
                 label = 14;
                 break;
                }
               }
               $48 = HEAP32[$26>>2]|0;
               $49 = (($48) + 92|0);
               $50 = HEAP32[$49>>2]|0;
               $51 = Math_imul($50, $V_2$0)|0;
               $$sum = (($51) + 16)|0;
               $52 = (($26) + ($$sum)|0);
               $53 = HEAP32[$52>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($53|0));
               $54 = __THREW__; __THREW__ = 0;
               $55 = $54&1;
               if ($55) {
                label = 14;
                break;
               }
               __THREW__ = 0;
               $56 = (invoke_iii(2730,(2397472|0),($53|0))|0);
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if ($58) {
                label = 14;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($56|0));
               $59 = __THREW__; __THREW__ = 0;
               $60 = $59&1;
               if ($60) {
                label = 14;
                break;
               }
               __THREW__ = 0;
               $61 = (invoke_iii(2730,(2233608|0),($56|0))|0);
               $62 = __THREW__; __THREW__ = 0;
               $63 = $62&1;
               if ($63) {
                label = 14;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $64 = __THREW__; __THREW__ = 0;
               $65 = $64&1;
               if ($65) {
                label = 14;
                break;
               }
               __THREW__ = 0;
               (invoke_iii(989,($4|0),($61|0))|0);
               $66 = __THREW__; __THREW__ = 0;
               $67 = $66&1;
               if ($67) {
                label = 14;
                break;
               }
               $68 = (($V_2$0) + 1)|0;
               $V_2$0 = $68;
              }
              if ((label|0) == 14) {
               $30 = ___cxa_find_matching_catch()|0;
               $31 = tempRet0;
               $lpad$phi$index = $30;$lpad$phi$index2 = $31;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($lpad$phi$index|0);
               // unreachable;
              }
              __THREW__ = 0;
              $74 = (invoke_iii(2729,(2426144|0),($__this|0))|0);
              $75 = __THREW__; __THREW__ = 0;
              $76 = $75&1;
              if (!($76)) {
               $77 = ($74|0)==(3);
               if ($77) {
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $78 = __THREW__; __THREW__ = 0;
                $79 = $78&1;
                if ($79) {
                 break;
                }
                $80 = HEAP32[3033336>>2]|0;
                __THREW__ = 0;
                (invoke_iii(989,($4|0),($80|0))|0);
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if ($82) {
                 break;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $83 = __THREW__; __THREW__ = 0;
               $84 = $83&1;
               if (!($84)) {
                $85 = HEAP32[3033344>>2]|0;
                __THREW__ = 0;
                (invoke_iii(989,($4|0),($85|0))|0);
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if (!($87)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $88 = __THREW__; __THREW__ = 0;
                 $89 = $88&1;
                 if (!($89)) {
                  __THREW__ = 0;
                  $90 = (invoke_iii(2730,(2535432|0),($4|0))|0);
                  $91 = __THREW__; __THREW__ = 0;
                  $92 = $91&1;
                  if (!($92)) {
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($90|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 $lpad$phi$index = $32;$lpad$phi$index2 = $33;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Reflection_MonoCMethod_m_GetObjectDataP38mscorlib_System_Reflection_MonoCMethodP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2426480);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2426240|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2730,(2426192|0),($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2730,(2426432|0),($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiiiii(62,0,($info|0),($0|0),($3|0),($6|0),1);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z63mscorlib_System_Reflection_MonoPropertyInfo_m_get_property_infoP22mscorlib_System_ObjectP39mscorlib_System_Reflection_MonoPropertyP43mscorlib_System_Reflection_MonoPropertyInfoi($__this,$prop,$info,$req_info) {
 $__this = $__this|0;
 $prop = $prop|0;
 $info = $info|0;
 $req_info = $req_info|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2427336);
 $0 = HEAP32[2427384>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2427392|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2427384>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($prop|0),($info|0),($req_info|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z63mscorlib_System_Reflection_PInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z61mscorlib_System_Reflection_MonoProperty_GetterAdapter_m__ctorP53mscorlib_System_Reflection_MonoProperty_GetterAdapterP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2428592);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_Reflection_MonoProperty_GetterAdapter_m_InvokeP53mscorlib_System_Reflection_MonoProperty_GetterAdapterP22mscorlib_System_Object($__this,$_this) {
 $__this = $__this|0;
 $_this = $_this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2428640);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_iii(930,($1|0),($_this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iii($8|0,($10|0),($_this|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z67mscorlib_System_Reflection_MonoProperty_GetterAdapter_m_BeginInvokeP53mscorlib_System_Reflection_MonoProperty_GetterAdapterP22mscorlib_System_ObjectP29mscorlib_System_AsyncCallbackS2_($__this,$_this,$callback,$object) {
 $__this = $__this|0;
 $_this = $_this|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2428688);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z65mscorlib_System_Reflection_MonoProperty_GetterAdapter_m_EndInvokeP53mscorlib_System_Reflection_MonoProperty_GetterAdapterP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2428736);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_S1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS3_S5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z59mscorlib_System_Reflection_MonoProperty_m_CachePropertyInfoP39mscorlib_System_Reflection_MonoPropertyi($__this,$flags) {
 $__this = $__this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429176);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & $flags;
 $3 = ($2|0)==($flags|0);
 if ($3) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $4 = (($__this) + 16|0);
 __THREW__ = 0;
 invoke_viiii(161,0,($__this|0),($4|0),($flags|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = $9 | $flags;
    HEAP32[$0>>2] = $12;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z56mscorlib_System_Reflection_MonoProperty_m_get_AttributesP39mscorlib_System_Reflection_MonoProperty($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429224);
 __THREW__ = 0;
 invoke_vii(1860,($__this|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 32|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z58mscorlib_System_Reflection_MonoProperty_m_get_PropertyTypeP39mscorlib_System_Reflection_MonoProperty($__this) {
 $__this = $__this|0;
 var $$0$in = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429272);
 __THREW__ = 0;
 invoke_vii(1860,($__this|0),6);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 24|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_iii(2730,(2413464|0),($3|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    } else {
     $$0$in = $9;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0$in|0);
   }
   $12 = (($__this) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($13|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __THREW__ = 0;
    $16 = (invoke_iii(2730,(2397136|0),($13|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     invoke_vi(3799,($16|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = (($16) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($22) + -1)|0;
      __THREW__ = 0;
      invoke_vi(3799,($16|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = ($22|0)<(1);
       if ($26) {
        label = 12;
       } else {
        $27 = HEAP32[$21>>2]|0;
        $28 = ($23>>>0)<($27>>>0);
        if (!($28)) {
         label = 12;
        }
       }
       if ((label|0) == 12) {
        __THREW__ = 0;
        $29 = (invoke_i(132)|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($29|0));
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
       }
       $34 = HEAP32[$16>>2]|0;
       $35 = (($34) + 92|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = Math_imul($36, $23)|0;
       $$sum = (($37) + 16)|0;
       $38 = (($16) + ($$sum)|0);
       $39 = HEAP32[$38>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($39|0));
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __THREW__ = 0;
        $42 = (invoke_iii(2730,(2397472|0),($39|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if (!($44)) {
         $$0$in = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0$in|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MonoProperty_m_get_ReflectedTypeP39mscorlib_System_Reflection_MonoProperty($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429320);
 __THREW__ = 0;
 invoke_vii(1860,($__this|0),8);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z59mscorlib_System_Reflection_MonoProperty_m_get_DeclaringTypeP39mscorlib_System_Reflection_MonoProperty($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429368);
 __THREW__ = 0;
 invoke_vii(1860,($__this|0),16);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_Reflection_MonoProperty_m_get_NameP39mscorlib_System_Reflection_MonoProperty($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429416);
 __THREW__ = 0;
 invoke_vii(1860,($__this|0),32);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z54mscorlib_System_Reflection_MonoProperty_m_GetGetMethodP39mscorlib_System_Reflection_MonoPropertyb($__this,$nonPublic) {
 $__this = $__this|0;
 $nonPublic = $nonPublic|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429464);
 __THREW__ = 0;
 invoke_vii(1860,($__this|0),2);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 24|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  $brmerge = $4 | $nonPublic;
  if ($brmerge) {
   $$0 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_iii(2734,(2410176|0),($3|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    if (!($9)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $$pre = HEAP32[$2>>2]|0;
    $$0 = $$pre;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Reflection_MonoProperty_m_GetIndexParametersP39mscorlib_System_Reflection_MonoProperty($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $V_0$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429512);
 __THREW__ = 0;
 invoke_vii(1860,($__this|0),6);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 24|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    $14 = (($__this) + 28|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = ($15|0)==(0|0);
    if ($16) {
     __THREW__ = 0;
     (invoke_ii(2996,(1183184|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     __THREW__ = 0;
     $40 = (invoke_iii(2760,(1183184|0),0)|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     $$0 = $40;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($15|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_iii(2730,(2397136|0),($15|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($19|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = (($19) + 12|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(1183184|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = (($25) + -1)|0;
    __THREW__ = 0;
    $29 = (invoke_iii(2760,(1183184|0),($28|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($29|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($29) + 12|0);
    $35 = HEAP32[$34>>2]|0;
    __THREW__ = 0;
    invoke_viiii(140,(0|0),($19|0),($29|0),($35|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    } else {
     $V_0$0 = $29;
    }
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_iii(2730,(2397136|0),($3|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $V_0$0 = $11;
   }
   $43 = (($V_0$0) + 12|0);
   $44 = (($V_0$0) + 16|0);
   $V_2$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($V_0$0|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    $84 = HEAP32[$43>>2]|0;
    $85 = ($V_2$0|0)<($84|0);
    if (!($85)) {
     $$0 = $V_0$0;
     label = 36;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($V_0$0|0));
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     break;
    }
    $45 = HEAP32[$43>>2]|0;
    $46 = ($V_2$0>>>0)<($45>>>0);
    if (!($46)) {
     __THREW__ = 0;
     $47 = (invoke_i(132)|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($47|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
    }
    $52 = HEAP32[$V_0$0>>2]|0;
    $53 = (($52) + 92|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = Math_imul($54, $V_2$0)|0;
    $56 = (($44) + ($55)|0);
    $57 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2433064|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     break;
    }
    __THREW__ = 0;
    $60 = (invoke_ii(3469,(2433064|0))|0);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(605,($60|0),($57|0),($__this|0));
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if ($64) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($V_0$0|0));
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     break;
    }
    $67 = HEAP32[$43>>2]|0;
    $68 = ($V_2$0>>>0)<($67>>>0);
    if (!($68)) {
     __THREW__ = 0;
     $69 = (invoke_i(132)|0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($69|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($V_0$0|0),($60|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    $76 = HEAP32[$V_0$0>>2]|0;
    $77 = (($76) + 92|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = Math_imul($78, $V_2$0)|0;
    $80 = (($44) + ($79)|0);
    HEAP32[$80>>2] = $60;
    $81 = (($V_2$0) + 1)|0;
    $V_2$0 = $81;
   }
   if ((label|0) == 36) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   $lpad$phi$index = $5;$lpad$phi$index2 = $6;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z148mscorlib_System_Reflection_ParameterInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Reflection_ParameterInfo_mscorlib_System_Reflection_MemberInfoP40mscorlib_System_Reflection_ParameterInfoS0_P37mscorlib_System_Reflection_MemberInfo($__this,$pinfo,$member) {
 $__this = $__this|0;
 $pinfo = $pinfo|0;
 $member = $member|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2431688);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($pinfo|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2730,(2397472|0),($pinfo|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 8|0);
    HEAP32[$7>>2] = $4;
    $8 = (($__this) + 16|0);
    HEAP32[$8>>2] = $member;
    __THREW__ = 0;
    invoke_vi(3799,($pinfo|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iii(2730,(2397184|0),($pinfo|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 20|0);
      HEAP32[$14>>2] = $11;
      __THREW__ = 0;
      invoke_vi(3799,($pinfo|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2729,(2431736|0),($pinfo|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $20 = (($__this) + 24|0);
        HEAP32[$20>>2] = $17;
        __THREW__ = 0;
        invoke_vi(3799,($pinfo|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         $23 = (invoke_iii(2729,(2431784|0),($pinfo|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          $26 = (($__this) + 28|0);
          HEAP32[$26>>2] = $23;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($27|0);
 // unreachable;
}
function __Z54mscorlib_System_Reflection_MonoProperty_m_GetSetMethodP39mscorlib_System_Reflection_MonoPropertyb($__this,$nonPublic) {
 $__this = $__this|0;
 $nonPublic = $nonPublic|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429560);
 __THREW__ = 0;
 invoke_vii(1860,($__this|0),4);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 28|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  $brmerge = $4 | $nonPublic;
  if ($brmerge) {
   $$0 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_iii(2734,(2410176|0),($3|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    if (!($9)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $$pre = HEAP32[$2>>2]|0;
    $$0 = $$pre;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Reflection_MonoProperty_m_IsDefinedP39mscorlib_System_Reflection_MonoPropertyP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429608);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z116mscorlib_System_Reflection_MonoProperty_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP39mscorlib_System_Reflection_MonoPropertyb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429656);
 __THREW__ = 0;
 $0 = (invoke_iiii(1202,(0|0),($__this|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z137mscorlib_System_Reflection_MonoProperty_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP39mscorlib_System_Reflection_MonoPropertyP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429704);
 __THREW__ = 0;
 $0 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z127mscorlib_System_Reflection_MonoProperty_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP39mscorlib_System_Reflection_MonoPropertyP22mscorlib_System_ObjectP26mscorlib_System_Object_arr($__this,$obj,$index) {
 $__this = $__this|0;
 $obj = $obj|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429752);
 $0 = ($index|0)==(0|0);
 if ($0) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($index|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  __THREW__ = 0;
  $5 = (invoke_iiiiiiii(119,(2429800|0),($__this|0),($obj|0),0,(0|0),($index|0),(0|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($5|0);
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z243mscorlib_System_Reflection_MonoProperty_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP39mscorlib_System_Reflection_MonoPropertyP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo($__this,$obj,$invokeAttr,$binder,$index,$culture) {
 $__this = $__this|0;
 $obj = $obj|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $index = $index|0;
 $culture = $culture|0;
 var $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429800);
 __THREW__ = 0;
 invoke_v(637);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iiii(1668,(2429464|0),($__this|0),1)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     __THREW__ = 0;
     $8 = (invoke_iii(2730,(2429416|0),($__this|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     $11 = HEAP32[3033392>>2]|0;
     $12 = HEAP32[3033400>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiiii(101,(0|0),($11|0),($8|0),($12|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     $18 = (invoke_ii(3469,(2560072|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($18|0),($13|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3834,($18|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     // unreachable;
    }
    $25 = ($index|0)==(0|0);
    if ($25) {
     label = 19;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($index|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = (($index) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==(0);
      if ($30) {
       label = 19;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        __THREW__ = 0;
        $50 = (invoke_iiiiiiii(119,(2410128|0),($2|0),($obj|0),($invokeAttr|0),($binder|0),($index|0),($culture|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if (!($52)) {
         $V_0$0 = $50;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($V_0$0|0);
        }
       }
      }
     }
    }
    if ((label|0) == 19) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      __THREW__ = 0;
      $45 = (invoke_iiiiiiii(119,(2410128|0),($2|0),($obj|0),($invokeAttr|0),($binder|0),(0|0),($culture|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       $V_0$0 = $45;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($V_0$0|0);
      }
     }
    }
    $31 = ___cxa_find_matching_catch(348288|0)|0;
    $32 = tempRet0;
    $33 = (_llvm_eh_typeid_for((348288|0))|0);
    $34 = ($32|0)==($33|0);
    if (!($34)) {
     $$01 = $31;$$02 = $32;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$01|0);
     // unreachable;
    }
    $35 = (___cxa_begin_catch(($31|0))|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = HEAP32[$36>>2]|0;
    __THREW__ = 0;
    $38 = (invoke_iii(2727,(2512704|0),($37|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    do {
     if (!($40)) {
      if (!($38)) {
       $57 = (___cxa_allocate_exception(4)|0);
       $58 = HEAP32[$35>>2]|0;
       HEAP32[$57>>2] = $58;
       __THREW__ = 0;
       invoke_viii(1567,($57|0),(348288|0),(0|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       // unreachable;
      }
      __THREW__ = 0;
      invoke_v(66);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2435952|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L1;
      }
      __THREW__ = 0;
      $63 = (invoke_ii(3469,(2435952|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vii(1862,($63|0),($36|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3834,($63|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       break L1;
      }
      // unreachable;
     }
    } while(0);
    $53 = ___cxa_find_matching_catch()|0;
    $54 = tempRet0;
    __THREW__ = 0;
    invoke_v(66);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     $70 = ___cxa_find_matching_catch(0|0)|0;
     $71 = tempRet0;
     ___clang_call_terminate($70);
     // unreachable;
    } else {
     $$01 = $53;$$02 = $54;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$01|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $$01 = $6;$$02 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Reflection_MonoProperty_m_ToStringP39mscorlib_System_Reflection_MonoProperty($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429848);
 __THREW__ = 0;
 invoke_v(638);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2730,(2429272|0),($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2730,(2149160|0),($2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2730,(2429416|0),($__this|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = HEAP32[3033480>>2]|0;
      __THREW__ = 0;
      $14 = (invoke_iiiii(101,(0|0),($7|0),($13|0),($10|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($14|0);
      }
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Reflection_MonoProperty_m_GetObjectDataP39mscorlib_System_Reflection_MonoPropertyP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2429896);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2429416|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2730,(2429320|0),($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2730,(2429848|0),($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiiiii(62,0,($info|0),($0|0),($3|0),($6|0),16);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z77mscorlib_System_Reflection_ParameterAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z199mscorlib_System_Reflection_ParameterInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Reflection_Emit_ParameterBuilder_mscorlib_System_Type_mscorlib_System_Reflection_MemberInfo_mscorlib_System_Int32P40mscorlib_System_Reflection_ParameterInfoP48mscorlib_System_Reflection_Emit_ParameterBuilderP20mscorlib_System_TypeP37mscorlib_System_Reflection_MemberInfoi($__this,$pb,$type,$member,$position) {
 $__this = $__this|0;
 $pb = $pb|0;
 $type = $type|0;
 $member = $member|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2431640);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $type;
  $3 = (($__this) + 16|0);
  HEAP32[$3>>2] = $member;
  $4 = ($pb|0)==(0|0);
  if ($4) {
   $26 = (($__this) + 20|0);
   HEAP32[$26>>2] = 0;
   $27 = (($position) + -1)|0;
   $28 = (($__this) + 24|0);
   HEAP32[$28>>2] = $27;
   $29 = (($__this) + 28|0);
   HEAP32[$29>>2] = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  invoke_vi(3799,($pb|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_iii(2730,(2368664|0),($pb|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($__this) + 20|0);
    HEAP32[$12>>2] = $9;
    __THREW__ = 0;
    invoke_vi(3799,($pb|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     $15 = (invoke_iii(2729,(2368712|0),($pb|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      $18 = (($15) + -1)|0;
      $19 = (($__this) + 24|0);
      HEAP32[$19>>2] = $18;
      __THREW__ = 0;
      invoke_vi(3799,($pb|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       $22 = (invoke_iii(2729,(2368616|0),($pb|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $25 = (($__this) + 28|0);
        HEAP32[$25>>2] = $22;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z51mscorlib_System_Reflection_ParameterInfo_m_ToStringP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $G_B10_0$0$in = 0, $L_19 = 0;
 var $V_0$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $L_19 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2431832);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $V_0$0 = $2;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($V_0$0|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  $8 = (invoke_iii(2734,(2233800|0),($V_0$0|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 8;
   break;
  }
  if (!($8)) {
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($V_0$0|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   label = 8;
   break;
  }
  __THREW__ = 0;
  $3 = (invoke_iii(2730,(2224328|0),($V_0$0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   label = 8;
   break;
  }
  $V_0$0 = $3;
 }
 if ((label|0) == 8) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index2 = $14;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3799,($V_0$0|0));
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iii(2734,(2234664|0),($V_0$0|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    if ($19) {
     label = 23;
    } else {
     $22 = HEAP32[$1>>2]|0;
     HEAP32[$0>>2] = 1271016;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $23 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     $26 = ($22|0)==($23|0);
     if ($26) {
      label = 23;
     } else {
      $27 = HEAP32[$1>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($27|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      $30 = (invoke_iii(2730,(2238840|0),($27|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      $33 = (($__this) + 16|0);
      $34 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($34|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      __THREW__ = 0;
      $37 = (invoke_iii(2730,(2242504|0),($34|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2730,(2238840|0),($37|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __THREW__ = 0;
      $45 = (invoke_iiii(574,(0|0),($30|0),($42|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $49 = HEAP32[$1>>2]|0;
      if ($45) {
       $50 = $49;
       label = 25;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($49|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       __THREW__ = 0;
       $58 = (invoke_iii(2730,(2150320|0),($49|0))|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       } else {
        $G_B10_0$0$in = $58;
       }
      }
     }
    }
    if ((label|0) == 23) {
     $48 = HEAP32[$1>>2]|0;
     $50 = $48;
     label = 25;
    }
    if ((label|0) == 25) {
     __THREW__ = 0;
     invoke_vi(3799,($50|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     $53 = (invoke_iii(2730,(2233608|0),($50|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     } else {
      $G_B10_0$0$in = $53;
     }
    }
    __THREW__ = 0;
    $61 = (invoke_ii(2285,($__this|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if (!($63)) {
     if ($61) {
      $V_2$0 = $G_B10_0$0$in;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($V_2$0|0);
     }
     HEAP16[$L_19>>1] = 32;
     __THREW__ = 0;
     (invoke_ii(2996,(2180696|0))|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if (!($65)) {
      __THREW__ = 0;
      $66 = (invoke_iii(2724,(2180696|0),($L_19|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if (!($68)) {
       __THREW__ = 0;
       $69 = (invoke_iiii(559,(0|0),($G_B10_0$0$in|0),($66|0))|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if (!($71)) {
        $72 = (($__this) + 20|0);
        $73 = HEAP32[$72>>2]|0;
        __THREW__ = 0;
        $74 = (invoke_iiii(562,(0|0),($69|0),($73|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if (!($76)) {
         $V_2$0 = $74;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($V_2$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index2 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Reflection_ParameterInfo_m_get_IsRetvalP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2432024);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2431784|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 8;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z60mscorlib_System_Reflection_ParameterInfo_m_get_ParameterTypeP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397472);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z57mscorlib_System_Reflection_ParameterInfo_m_get_AttributesP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2431784);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51mscorlib_System_Reflection_ParameterInfo_m_get_IsInP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2431880);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2431784|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & 1;
  $4 = ($3|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z57mscorlib_System_Reflection_ParameterInfo_m_get_IsOptionalP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2431928);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2431784|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 16;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Reflection_ParameterInfo_m_get_IsOutP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2431976);
 __THREW__ = 0;
 $0 = (invoke_iii(2729,(2431784|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$lobit = $0 & 2;
  $3 = ($$lobit|0)!=(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Reflection_ParameterInfo_m_get_MemberP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2432072);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51mscorlib_System_Reflection_ParameterInfo_m_get_NameP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2397184);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z55mscorlib_System_Reflection_ParameterInfo_m_get_PositionP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2431736);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z62mscorlib_System_Reflection_ParameterInfo_m_GetCustomAttributesP40mscorlib_System_Reflection_ParameterInfoP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2432120);
 __THREW__ = 0;
 $0 = (invoke_iiiii(187,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Reflection_ParameterInfo_m_IsDefinedP40mscorlib_System_Reflection_ParameterInfoP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2432168);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,(0|0),($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z68mscorlib_System_Reflection_ParameterInfo_m_GetPseudoCustomAttributesP40mscorlib_System_Reflection_ParameterInfo($__this) {
 $__this = $__this|0;
 var $$ = 0, $$$ = 0, $$$$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$3 = 0, $V_0$4 = 0, $V_0$5 = 0, $V_0$6 = 0, $_stackTraceSentry = 0, $not$ = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2432216);
 __THREW__ = 0;
 $0 = (invoke_ii(2282,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2284,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $8 = (invoke_ii(2283,($__this|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = $0 ? 2 : 1;
     $$ = $0&1;
     $$$ = $3 ? $11 : $$;
     $12 = $8&1;
     $$$$ = (($12) + ($$$))|0;
     $13 = (($__this) + 32|0);
     $14 = HEAP32[$13>>2]|0;
     $not$ = ($14|0)!=(0|0);
     $15 = $not$&1;
     $V_0$3 = (($$$$) + ($15))|0;
     $16 = ($V_0$3|0)==(0);
     if ($16) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      $19 = (invoke_iii(2760,(1167664|0),($V_0$3|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       $22 = (invoke_ii(2282,($__this|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        if ($22) {
         __THREW__ = 0;
         (invoke_ii(2996,(2249648|0))|0);
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if ($26) {
          break;
         }
         __THREW__ = 0;
         $27 = (invoke_ii(3469,(2249648|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(2102,($27|0));
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($19|0));
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         }
         $34 = (($19) + 12|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = ($35|0)==(0);
         if ($36) {
          __THREW__ = 0;
          $37 = (invoke_i(132)|0);
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($37|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($19|0),($27|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break;
         }
         $44 = (($19) + 16|0);
         HEAP32[$44>>2] = $27;
         $V_0$4 = 1;
        } else {
         $V_0$4 = 0;
        }
        __THREW__ = 0;
        $45 = (invoke_ii(2283,($__this|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if (!($47)) {
         if ($45) {
          $48 = (($V_0$4) + 1)|0;
          __THREW__ = 0;
          (invoke_ii(2996,(2250520|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
          __THREW__ = 0;
          $51 = (invoke_ii(3469,(2250520|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(2107,($51|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($19|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          $58 = (($19) + 12|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = ($V_0$4>>>0)<($59>>>0);
          if (!($60)) {
           __THREW__ = 0;
           $61 = (invoke_i(132)|0);
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if ($63) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($61|0));
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($19|0),($51|0));
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           break;
          }
          $68 = HEAP32[$19>>2]|0;
          $69 = (($19) + 16|0);
          $70 = (($68) + 92|0);
          $71 = HEAP32[$70>>2]|0;
          $72 = (0 - ($V_0$4))|0;
          $73 = $71 & $72;
          $74 = (($69) + ($73)|0);
          HEAP32[$74>>2] = $51;
          $V_0$5 = $48;
         } else {
          $V_0$5 = $V_0$4;
         }
         __THREW__ = 0;
         $75 = (invoke_ii(2284,($__this|0))|0);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if (!($77)) {
          if ($75) {
           $78 = (($V_0$5) + 1)|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2247984|0))|0);
           $79 = __THREW__; __THREW__ = 0;
           $80 = $79&1;
           if ($80) {
            break;
           }
           __THREW__ = 0;
           $81 = (invoke_ii(3469,(2247984|0))|0);
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if ($83) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(2094,($81|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($19|0));
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if ($87) {
            break;
           }
           $88 = (($19) + 12|0);
           $89 = HEAP32[$88>>2]|0;
           $90 = ($V_0$5>>>0)<($89>>>0);
           if (!($90)) {
            __THREW__ = 0;
            $91 = (invoke_i(132)|0);
            $92 = __THREW__; __THREW__ = 0;
            $93 = $92&1;
            if ($93) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($91|0));
            $94 = __THREW__; __THREW__ = 0;
            $95 = $94&1;
            if ($95) {
             break;
            }
           }
           __THREW__ = 0;
           invoke_vii(3492,($19|0),($81|0));
           $96 = __THREW__; __THREW__ = 0;
           $97 = $96&1;
           if ($97) {
            break;
           }
           $98 = HEAP32[$19>>2]|0;
           $99 = (($19) + 16|0);
           $100 = (($98) + 92|0);
           $101 = HEAP32[$100>>2]|0;
           $102 = Math_imul($101, $V_0$5)|0;
           $103 = (($99) + ($102)|0);
           HEAP32[$103>>2] = $81;
           $V_0$6 = $78;
          } else {
           $V_0$6 = $V_0$5;
          }
          $104 = HEAP32[$13>>2]|0;
          $105 = ($104|0)==(0|0);
          if ($105) {
           $$0 = $19;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          invoke_vi(3799,($104|0));
          $106 = __THREW__; __THREW__ = 0;
          $107 = $106&1;
          if (!($107)) {
           __THREW__ = 0;
           $108 = (invoke_ii(2184,($104|0))|0);
           $109 = __THREW__; __THREW__ = 0;
           $110 = $109&1;
           if (!($110)) {
            __THREW__ = 0;
            invoke_vi(3799,($19|0));
            $111 = __THREW__; __THREW__ = 0;
            $112 = $111&1;
            if (!($112)) {
             $113 = ($V_0$6|0)<(0);
             if ($113) {
              label = 47;
             } else {
              $114 = (($19) + 12|0);
              $115 = HEAP32[$114>>2]|0;
              $116 = ($V_0$6>>>0)<($115>>>0);
              if (!($116)) {
               label = 47;
              }
             }
             if ((label|0) == 47) {
              __THREW__ = 0;
              $117 = (invoke_i(132)|0);
              $118 = __THREW__; __THREW__ = 0;
              $119 = $118&1;
              if ($119) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($117|0));
              $120 = __THREW__; __THREW__ = 0;
              $121 = $120&1;
              if ($121) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($19|0),($108|0));
             $122 = __THREW__; __THREW__ = 0;
             $123 = $122&1;
             if (!($123)) {
              $124 = HEAP32[$19>>2]|0;
              $125 = (($19) + 16|0);
              $126 = (($124) + 92|0);
              $127 = HEAP32[$126>>2]|0;
              $128 = Math_imul($127, $V_0$6)|0;
              $129 = (($125) + ($128)|0);
              HEAP32[$129>>2] = $108;
              $$0 = $19;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Reflection_ParameterInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2452928)|0);
 $7 = HEAP32[((2452928 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Reflection_ParameterModifier_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2433232)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Reflection_PropertyAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z56mscorlib_System_Reflection_PropertyInfo_m_get_MemberTypeP39mscorlib_System_Reflection_PropertyInfo($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2434080);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 16;
}
function __Z127mscorlib_System_Reflection_PropertyInfo_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP39mscorlib_System_Reflection_PropertyInfoP22mscorlib_System_ObjectP26mscorlib_System_Object_arr($__this,$obj,$index) {
 $__this = $__this|0;
 $obj = $obj|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2434128);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(119,(2434176|0),($__this|0),($obj|0),0,(0|0),($index|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z70mscorlib_System_Reflection_PropertyInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2453368)|0);
 $10 = HEAP32[((2453368 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 STACKTOP = sp;return;
}
function __Z198mscorlib_System_Reflection_PropertyInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_PropertyInfo_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2318832)|0);
 __Z64mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m__ctorP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2251976)|0);
 __Z59mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m__ctorP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z103mscorlib_System_Reflection_StrongNameKeyPair_m_System_Runtime_Serialization_ISerializable_GetObjectDataP44mscorlib_System_Reflection_StrongNameKeyPairP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2434856);
 __THREW__ = 0;
 invoke_v(639);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($__this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  HEAP32[$0>>2] = 1205864;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $6 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP32[3033496>>2]|0;
    __THREW__ = 0;
    invoke_viiii(168,($info|0),($11|0),($5|0),($6|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = (($__this) + 12|0);
     $15 = HEAP32[$14>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      $18 = HEAP32[3033504>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($18|0),($15|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = (($__this) + 16|0);
       $22 = HEAP8[$21>>0]|0;
       __THREW__ = 0;
       invoke_vi(3799,($info|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $25 = ($22<<24>>24)!=(0);
        $26 = HEAP32[3033512>>2]|0;
        __THREW__ = 0;
        invoke_viii(619,($info|0),($26|0),($25|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         $29 = (($__this) + 20|0);
         $30 = HEAP32[$29>>2]|0;
         HEAP32[$1>>2] = 1205864;
         __THREW__ = 0;
         ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
         $31 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if (!($33)) {
          __THREW__ = 0;
          invoke_vi(3799,($info|0));
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           $36 = HEAP32[3033520>>2]|0;
           __THREW__ = 0;
           invoke_viiii(168,($info|0),($36|0),($30|0),($31|0));
           $37 = __THREW__; __THREW__ = 0;
           $38 = $37&1;
           if (!($38)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $39 = ___cxa_find_matching_catch()|0;
 $40 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($39|0);
 // unreachable;
}
function __Z75mscorlib_System_Reflection_StrongNameKeyPair_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73mscorlib_System_Reflection_TargetException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Reflection_TargetInvocationException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Reflection_TargetParameterCountException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z72mscorlib_System_Reflection_TypeAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m__ctorP59mscorlib_System_Resources_NeutralResourcesLanguageAttributeP22mscorlib_System_String($__this,$cultureName) {
 $__this = $__this|0;
 $cultureName = $cultureName|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2438272);
 __THREW__ = 0;
 invoke_v(640);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(1931,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = ($cultureName|0)==(0|0);
   if (!($4)) {
    $17 = (($__this) + 8|0);
    HEAP32[$17>>2] = $cultureName;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[3033920>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3834,($9|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z90mscorlib_System_Resources_NeutralResourcesLanguageAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_Resources_SatelliteContractVersionAttribute_m__ctorP59mscorlib_System_Resources_SatelliteContractVersionAttributeP22mscorlib_System_String($__this,$version) {
 $__this = $__this|0;
 $version = $version|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2438640);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2659512|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2659512|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vii(1978,($4|0),($version|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($__this) + 8|0);
     HEAP32[$9>>2] = $4;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z90mscorlib_System_Resources_SatelliteContractVersionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z94mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m__ctorP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributei($__this,$relaxations) {
 $__this = $__this|0;
 $relaxations = $relaxations|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2439424);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $relaxations;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z103mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,71);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributei($__this,$loadHintArgument) {
 $__this = $__this|0;
 $loadHintArgument = $loadHintArgument|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2439760);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $loadHintArgument;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z98mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Runtime_CompilerServices_IsVolatile_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z72mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m__ctorP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2440744);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z95mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z79mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject_m_FinalizeP68mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2442040);
 __THREW__ = 0;
 invoke_vi(1925,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z99mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z179mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject_CustomAttributesCacheGenerator_mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject_m_FinalizeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($__this,$consistencyGuarantee,$cer) {
 $__this = $__this|0;
 $consistencyGuarantee = $consistencyGuarantee|0;
 $cer = $cer|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2442328);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $consistencyGuarantee;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $cer;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z104mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1133);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Runtime_Hosting_ActivationArguments_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z94mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,5);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_Runtime_InteropServices_ClassInterfaceType_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,4);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Runtime_InteropServices_ComInterfaceType_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($__this,$interfaceType) {
 $__this = $__this|0;
 $interfaceType = $interfaceType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2444640);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $interfaceType;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z93mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,1024);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z56mscorlib_System_Runtime_InteropServices_Marshal_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2444968);
 __THREW__ = 0;
 (invoke_ii(2996,(2445544|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2445544 + 80|0))>>2]|0;
  HEAP32[$2>>2] = 2;
  __THREW__ = 0;
  $3 = (invoke_ii(2444,(0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(2489,($3|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2445544|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $15 = ($8|0)==(2);
      $$ = $15 ? 2 : 1;
      $16 = HEAP32[((2445544 + 80|0))>>2]|0;
      $17 = (($16) + 4|0);
      HEAP32[$17>>2] = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z69mscorlib_System_Runtime_InteropServices_Marshal_m_copy_from_unmanagedP22mscorlib_System_Object22mscorlib_System_IntPtriP21mscorlib_System_Arrayi($__this,$source,$startIndex,$destination,$length) {
 $__this = $__this|0;
 $source = $source|0;
 $startIndex = $startIndex|0;
 $destination = $destination|0;
 $length = $length|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2445016);
 $1 = HEAP32[2445064>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2445072|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2445064>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$source>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii($9|0,($$byval_copy|0),($startIndex|0),($destination|0),($length|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_Runtime_InteropServices_Marshal_m_CopyP22mscorlib_System_Object22mscorlib_System_IntPtrP24mscorlib_System_Char_arrii($__this,$source,$destination,$startIndex,$length) {
 $__this = $__this|0;
 $source = $source|0;
 $destination = $destination|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2445192);
 $1 = HEAP32[$source>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiii(68,0,($$byval_copy|0),($startIndex|0),($destination|0),($length|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN14ActionInvoker4I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS1_E6InvokeEPFvPv22mscorlib_System_IntPtriS4_iES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$$byval_copy,$5,$7,$10);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I28mscorlib_System_IntPtrTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS2_E6InvokeEPFvPv22mscorlib_System_IntPtrS4_iiES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$$byval_copy,$4,$7,$10);
 STACKTOP = sp;return (0|0);
}
function __Z78mscorlib_System_Runtime_InteropServices_Marshal_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2513328)|0);
 __Z71mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m__ctorP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z91mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,64);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Runtime_InteropServices_SafeHandle_m_CloseP50mscorlib_System_Runtime_InteropServices_SafeHandle($__this) {
 $__this = $__this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2445952);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  __THREW__ = 0;
  $3 = (invoke_ii(1782,($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2730,(2150320|0),($3|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2634432|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(3469,(2634432|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vii(1970,($13|0),($8|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        invoke_vi(3834,($13|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } else {
  $25 = $1;
  while(1) {
   $24 = (($25) + -1)|0;
   __THREW__ = 0;
   $26 = (invoke_iiiii(177,(0|0),($0|0),($24|0),($25|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    label = 10;
    break;
   }
   $29 = ($26|0)==($25|0);
   if ($29) {
    break;
   }
   $$pre = HEAP32[$0>>2]|0;
   $25 = $$pre;
  }
  if ((label|0) == 10) {
   $20 = ___cxa_find_matching_catch()|0;
   $21 = tempRet0;
   $lpad$phi$index = $20;$lpad$phi$index2 = $21;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  $30 = ($24|0)==(0);
  if (!($30)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  $31 = (($__this) + 20|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  $34 = (invoke_iii(2734,(2446000|0),($__this|0))|0);
  $35 = __THREW__; __THREW__ = 0;
  $36 = $35&1;
  if (!($36)) {
   if ($34) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_iii(2734,(2446048|0),($__this|0))|0);
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if (!($38)) {
    $39 = (($__this) + 12|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($__this) + 8|0);
    HEAP32[$41>>2] = $40;
    HEAP32[$0>>2] = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $lpad$phi$index = $22;$lpad$phi$index2 = $23;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z81mscorlib_System_Runtime_InteropServices_SafeHandle_m_Dispose_mscorlib_System_VoidP50mscorlib_System_Runtime_InteropServices_SafeHandle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2446096);
 __THREW__ = 0;
 invoke_viii(2122,(2446144|0),($__this|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1941,(0|0),($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __ZN18VirtActionInvoker1I29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($4,$p1);
 STACKTOP = sp;return;
}
function __Z105mscorlib_System_Runtime_InteropServices_SafeHandle_m_Dispose_mscorlib_System_Void_mscorlib_System_BooleanP50mscorlib_System_Runtime_InteropServices_SafeHandleb($__this,$disposing) {
 $__this = $__this|0;
 $disposing = $disposing|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2446144);
 if (!($disposing)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(2349,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z61mscorlib_System_Runtime_InteropServices_SafeHandle_m_FinalizeP50mscorlib_System_Runtime_InteropServices_SafeHandle($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2446192);
 $0 = (($__this) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 do {
  if ($2) {
   $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 44;
   label = 10;
  } else {
   __THREW__ = 0;
   $3 = (invoke_iii(2734,(2446000|0),($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    if ($3) {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 44;
     label = 10;
     break;
    }
    __THREW__ = 0;
    (invoke_iii(2734,(2446048|0),($__this|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = (($__this) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($__this) + 8|0);
     HEAP32[$18>>2] = $17;
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 44;
     label = 10;
     break;
    }
   }
   $6 = ___cxa_find_matching_catch(348288|0)|0;
   $7 = tempRet0;
   $8 = (_llvm_eh_typeid_for((348288|0))|0);
   $9 = ($7|0)==($8|0);
   if (!($9)) {
    $$0 = $6;$$02 = $7;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $10 = (___cxa_begin_catch(($6|0))|0);
   $11 = HEAP32[$10>>2]|0;
   __THREW__ = 0;
   invoke_v(66);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $__last_unhandled_exception$0 = $11;$leaveInstructions$sroa$0$0 = 0;
    label = 10;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  __THREW__ = 0;
  invoke_vi(2335,($__this|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   $cond = ($leaveInstructions$sroa$0$0|0)==(44);
   if ($cond) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3834,($__last_unhandled_exception$0|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    // unreachable;
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $$0 = $19;$$02 = $20;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z140mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_CloseP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z163mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_Dispose_mscorlib_System_VoidP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z187mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_Dispose_mscorlib_System_Void_mscorlib_System_BooleanP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z148mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_ReleaseHandleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z148mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_get_IsInvalidP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($__this,$importClass) {
 $__this = $__this|0;
 $importClass = $importClass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2446816);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($importClass|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2730,(2149160|0),($importClass|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 8|0);
    HEAP32[$7>>2] = $4;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z98mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1024);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeii($__this,$major,$minor) {
 $__this = $__this|0;
 $major = $major|0;
 $minor = $minor|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2447160);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $major;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $minor;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z94mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,0);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Runtime_InteropServices_UnmanagedType_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Runtime_InteropServices__Activator_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2555264)|0);
 $7 = HEAP32[((2555264 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $12 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2449368)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($11,$12);
 $13 = HEAP32[$3>>2]|0;
 $14 = (($13) + 8|0);
 HEAP32[$14>>2] = $11;
 $15 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($15,1);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $15;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($18,0);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Runtime_InteropServices__Assembly_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2377584)|0);
 $10 = HEAP32[((2377584 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($14,1);
 $15 = HEAP32[$3>>2]|0;
 $16 = (($15) + 12|0);
 HEAP32[$16>>2] = $14;
 $17 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $18 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2449584)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($17,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $17;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Runtime_InteropServices__AssemblyBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2353584)|0);
 $5 = HEAP32[((2353584 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($8,0);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $15 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2449800)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($14,$15);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $14;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Runtime_InteropServices__AssemblyName_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2395256)|0);
 $5 = HEAP32[((2395256 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($8,1);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($14,1);
 $15 = HEAP32[$3>>2]|0;
 $16 = (($15) + 12|0);
 HEAP32[$16>>2] = $14;
 $17 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $18 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2450024)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($17,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $17;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_Runtime_InteropServices__ConstructorBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2355880)|0);
 $7 = HEAP32[((2355880 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $15 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2450240)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($14,$15);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $14;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($18,0);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Runtime_InteropServices__ConstructorInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2450464)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 $10 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($10,1);
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 HEAP32[$12>>2] = $10;
 $13 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2403064)|0);
 $14 = HEAP32[((2403064 + 48|0))>>2]|0;
 $15 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($14)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($13,$15);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $13;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Runtime_InteropServices__EnumBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2360152)|0);
 $5 = HEAP32[((2360152 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($8,1);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($14,1);
 $15 = HEAP32[$3>>2]|0;
 $16 = (($15) + 12|0);
 HEAP32[$16>>2] = $14;
 $17 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $18 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2450688)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($17,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $17;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Runtime_InteropServices__EventInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2404168)|0);
 $10 = HEAP32[((2404168 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $15 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2450904)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($14,$15);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $14;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Runtime_InteropServices__FieldBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2361640)|0);
 $10 = HEAP32[((2361640 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($14,0);
 $15 = HEAP32[$3>>2]|0;
 $16 = (($15) + 12|0);
 HEAP32[$16>>2] = $14;
 $17 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $18 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2451120)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($17,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $17;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Runtime_InteropServices__FieldInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2451336)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($10,0);
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 HEAP32[$12>>2] = $10;
 $13 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($13,1);
 $14 = HEAP32[$3>>2]|0;
 $15 = (($14) + 12|0);
 HEAP32[$15>>2] = $13;
 $16 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2407016)|0);
 $17 = HEAP32[((2407016 + 48|0))>>2]|0;
 $18 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($17)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($16,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $16;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Runtime_InteropServices__MethodBase_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2412288)|0);
 $5 = HEAP32[((2412288 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $9 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2451552)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($8,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $8;
 $12 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($12,1);
 $13 = HEAP32[$3>>2]|0;
 $14 = (($13) + 8|0);
 HEAP32[$14>>2] = $12;
 $15 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($15,0);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $15;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Runtime_InteropServices__MethodBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2368056)|0);
 $5 = HEAP32[((2368056 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $9 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2451768)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($8,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $8;
 $12 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($12,1);
 $13 = HEAP32[$3>>2]|0;
 $14 = (($13) + 8|0);
 HEAP32[$14>>2] = $12;
 $15 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($15,1);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $15;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($18,0);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Runtime_InteropServices__MethodInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($9,1);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 8|0);
 HEAP32[$11>>2] = $9;
 $12 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $13 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2451984)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($12,$13);
 $14 = HEAP32[$3>>2]|0;
 $15 = (($14) + 12|0);
 HEAP32[$15>>2] = $12;
 $16 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2414216)|0);
 $17 = HEAP32[((2414216 + 48|0))>>2]|0;
 $18 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($17)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($16,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $16;
 STACKTOP = sp;return;
}
function __Z78mscorlib_System_Runtime_InteropServices__Module_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2452200)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 $10 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($10,1);
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 HEAP32[$12>>2] = $10;
 $13 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($13,1);
 $14 = HEAP32[$3>>2]|0;
 $15 = (($14) + 12|0);
 HEAP32[$15>>2] = $13;
 $16 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2416152)|0);
 $17 = HEAP32[((2416152 + 48|0))>>2]|0;
 $18 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($17)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($16,$18);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $16;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Runtime_InteropServices__ModuleBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2368480)|0);
 $10 = HEAP32[((2368480 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $15 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2452408)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($14,$15);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $14;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Runtime_InteropServices__ParameterBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2369008)|0);
 $7 = HEAP32[((2369008 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $12 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2452624)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($11,$12);
 $13 = HEAP32[$3>>2]|0;
 $14 = (($13) + 8|0);
 HEAP32[$14>>2] = $11;
 $15 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($15,0);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $15;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Runtime_InteropServices__ParameterInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2433064)|0);
 $5 = HEAP32[((2433064 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($8,1);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($11,0);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 $14 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $15 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2452848)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($14,$15);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $14;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Runtime_InteropServices__PropertyBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2370608)|0);
 $7 = HEAP32[((2370608 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $12 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2453064)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($11,$12);
 $13 = HEAP32[$3>>2]|0;
 $14 = (($13) + 8|0);
 HEAP32[$14>>2] = $11;
 $15 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($15,1);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $15;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($18,0);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z84mscorlib_System_Runtime_InteropServices__PropertyInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2434720)|0);
 $7 = HEAP32[((2434720 + 48|0))>>2]|0;
 $8 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($7)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($6,$8);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $6;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $12 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2453288)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($11,$12);
 $13 = HEAP32[$3>>2]|0;
 $14 = (($13) + 8|0);
 HEAP32[$14>>2] = $11;
 $15 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($15,1);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $15;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($18,0);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z78mscorlib_System_Runtime_InteropServices__Thread_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2453504)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2551552)|0);
 $8 = HEAP32[((2551552 + 48|0))>>2]|0;
 $9 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($8)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($7,$9);
 $10 = HEAP32[$3>>2]|0;
 $11 = (($10) + 4|0);
 HEAP32[$11>>2] = $7;
 $12 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($12,1);
 $13 = HEAP32[$3>>2]|0;
 $14 = (($13) + 8|0);
 HEAP32[$14>>2] = $12;
 $15 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($15,0);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $15;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($18,1);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Runtime_InteropServices__TypeBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2444832)|0);
 __Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2249976)|0);
 $10 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2453712)|0);
 __Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String($9,$10);
 $11 = HEAP32[$3>>2]|0;
 $12 = (($11) + 8|0);
 HEAP32[$12>>2] = $9;
 $13 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2447024)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2374224)|0);
 $14 = HEAP32[((2374224 + 48|0))>>2]|0;
 $15 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($14)|0);
 __Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type($13,$15);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 12|0);
 HEAP32[$17>>2] = $13;
 $18 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($18,0);
 $19 = HEAP32[$3>>2]|0;
 $20 = (($19) + 16|0);
 HEAP32[$20>>2] = $18;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_Runtime_Remoting_Activation_ActivationServices_m_get_ConstructionActivatorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2453928);
 __THREW__ = 0;
 (invoke_ii(2996,(2454392|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[((2454392 + 80|0))>>2]|0;
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2455040|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2455040|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2381,($9|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2454392|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[((2454392 + 80|0))>>2]|0;
    HEAP32[$16>>2] = $9;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2454392|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[((2454392 + 80|0))>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Runtime_Remoting_Activation_ConstructionLevelActivator_m__ctorP70mscorlib_System_Runtime_Remoting_Activation_ConstructionLevelActivator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2454904);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z90mscorlib_System_Runtime_Remoting_Activation_ActivationServices_m_CreateProxyFromAttributesP22mscorlib_System_ObjectP20mscorlib_System_TypeP26mscorlib_System_Object_arr($__this,$type,$activationAttributes) {
 $__this = $__this|0;
 $type = $type|0;
 $activationAttributes = $activationAttributes|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2453976);
 __THREW__ = 0;
 invoke_v(641);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($activationAttributes) + 12|0);
   $3 = (($activationAttributes) + 16|0);
   $V_0$1 = 0;$V_3$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($activationAttributes|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 3;
     break;
    }
    $56 = HEAP32[$2>>2]|0;
    $57 = ($V_3$0|0)<($56|0);
    if (!($57)) {
     label = 28;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($activationAttributes|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 3;
     break;
    }
    $8 = HEAP32[$2>>2]|0;
    $9 = ($V_3$0>>>0)<($8>>>0);
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_i(132)|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 3;
      break;
     }
    }
    $15 = HEAP32[$activationAttributes>>2]|0;
    $16 = (($15) + 92|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = Math_imul($17, $V_3$0)|0;
    $19 = (($3) + ($18)|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2472816|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 3;
     break;
    }
    __THREW__ = 0;
    $23 = (invoke_iii(2735,($20|0),(2472816|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     label = 3;
     break;
    }
    $26 = ($23|0)==(0|0);
    if ($26) {
     label = 12;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2467344|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 3;
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_iii(2735,($20|0),(2467344|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 3;
     break;
    }
    $42 = ($39|0)==(0|0);
    if ($42) {
     $V_0$0 = $V_0$1;
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(2467344|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     $45 = (invoke_iii(2763,($20|0),(2467344|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($45|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     $50 = (invoke_ii(2290,($45|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 3;
      break;
     } else {
      $V_0$0 = $50;
     }
    }
    $53 = (($V_3$0) + 1)|0;
    $V_0$1 = $V_0$0;$V_3$0 = $53;
   }
   if ((label|0) == 3) {
    $4 = ___cxa_find_matching_catch()|0;
    $5 = tempRet0;
    $lpad$phi$index = $4;$lpad$phi$index2 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 12) {
    __THREW__ = 0;
    (invoke_ii(2996,(2488992|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(3469,(2488992|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[3033968>>2]|0;
    __THREW__ = 0;
    invoke_vii(1891,($29|0),($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3834,($29|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    // unreachable;
   }
   else if ((label|0) == 28) {
    $60 = ($V_0$1|0)==(0|0);
    if (!($60)) {
     $61 = HEAP32[3033976>>2]|0;
     __THREW__ = 0;
     $62 = (invoke_iiiiii(82,(0|0),($type|0),($V_0$1|0),($activationAttributes|0),($61|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      break;
     } else {
      $$0 = $62;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $65 = (invoke_iii(950,(0|0),($type|0))|0);
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if ($67) {
     break;
    }
    $68 = ($65|0)==(0|0);
    if (!($68)) {
     __THREW__ = 0;
     $69 = (invoke_iiii(903,(0|0),($65|0),($activationAttributes|0))|0);
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     } else {
      $$0 = $69;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($type|0));
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     break;
    }
    __THREW__ = 0;
    $74 = (invoke_iii(2734,(2234280|0),($type|0))|0);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     break;
    }
    if (!($74)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $77 = (invoke_iiii(904,(0|0),($type|0),($activationAttributes|0))|0);
    $78 = __THREW__; __THREW__ = 0;
    $79 = $78&1;
    if ($79) {
     break;
    } else {
     $$0 = $77;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $lpad$phi$index = $6;$lpad$phi$index2 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Runtime_Remoting_Activation_ActivationServices_m_CreateConstructionCallP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$type,$activationUrl,$activationAttributes) {
 $__this = $__this|0;
 $type = $type|0;
 $activationUrl = $activationUrl|0;
 $activationAttributes = $activationAttributes|0;
 var $$06 = 0, $$07 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $G_B19_0$0 = 0, $V_1$0 = 0, $V_10$0 = 0, $V_3$1 = 0, $V_3$2$off0 = 0, $V_3$3$off0 = 0, $V_3$4$off0 = 0, $__last_unhandled_exception$0 = 0, $__last_unhandled_exception$1 = 0, $__last_unhandled_exception$2 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond2 = 0, $cond4 = 0, $cond5 = 0, $extract$t10 = 0, $extract$t9 = 0, $leaveInstructions$sroa$0$0 = 0;
 var $leaveInstructions$sroa$0$1 = 0, $leaveInstructions$sroa$0$2 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2454024);
 __THREW__ = 0;
 (invoke_ii(2996,(2475440|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if ($1) {
   label = 8;
  } else {
   __THREW__ = 0;
   $2 = (invoke_ii(3469,(2475440|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    label = 8;
   } else {
    __THREW__ = 0;
    invoke_vii(1879,($2|0),($type|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     label = 8;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($type|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      label = 8;
     } else {
      __THREW__ = 0;
      $9 = (invoke_iii(2734,(2234280|0),($type|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       label = 8;
      } else {
       if (!($9)) {
        __THREW__ = 0;
        $16 = (invoke_ii(2289,0)|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if ($18) {
         label = 8;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2454768|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         label = 8;
         break;
        }
        __THREW__ = 0;
        $21 = (invoke_ii(3469,(2454768|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         label = 8;
         break;
        }
        __THREW__ = 0;
        invoke_viii(609,($21|0),($activationUrl|0),($16|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 8;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         label = 8;
         break;
        }
        __THREW__ = 0;
        invoke_viii(2110,(2474456|0),($2|0),($21|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         label = 8;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 8;
         break;
        }
        __THREW__ = 0;
        invoke_vii(1880,($2|0),0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         label = 8;
         break;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($2|0);
       }
       __THREW__ = 0;
       $34 = (invoke_ii(2289,0)|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        label = 8;
       } else {
        __THREW__ = 0;
        (invoke_ii(2996,(2455368|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         label = 8;
        } else {
         __THREW__ = 0;
         $39 = (invoke_ii(3469,(2455368|0))|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          label = 8;
         } else {
          __THREW__ = 0;
          invoke_vii(1873,($39|0),($34|0));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           label = 8;
          } else {
           __THREW__ = 0;
           (invoke_ii(2996,(2304136|0))|0);
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            label = 8;
           } else {
            __THREW__ = 0;
            $46 = (invoke_ii(3469,(2304136|0))|0);
            $47 = __THREW__; __THREW__ = 0;
            $48 = $47&1;
            if ($48) {
             label = 8;
            } else {
             __THREW__ = 0;
             invoke_vi(2153,($46|0));
             $49 = __THREW__; __THREW__ = 0;
             $50 = $49&1;
             if ($50) {
              label = 8;
             } else {
              $51 = ($activationAttributes|0)==(0|0);
              if (!($51)) {
               __THREW__ = 0;
               invoke_vi(3799,($46|0));
               $52 = __THREW__; __THREW__ = 0;
               $53 = $52&1;
               if ($53) {
                label = 8;
                break;
               }
               __THREW__ = 0;
               invoke_viii(2110,(2298968|0),($46|0),($activationAttributes|0));
               $54 = __THREW__; __THREW__ = 0;
               $55 = $54&1;
               if ($55) {
                label = 8;
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2468768|0))|0);
              $56 = __THREW__; __THREW__ = 0;
              $57 = $56&1;
              if ($57) {
               label = 8;
              } else {
               $58 = HEAP8[((2468768 + 116|0))>>0]|0;
               $59 = ($58<<24>>24)==(0);
               if ($59) {
                __THREW__ = 0;
                (invoke_ii(2996,(2468768|0))|0);
                $60 = __THREW__; __THREW__ = 0;
                $61 = $60&1;
                if ($61) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2468768|0))|0);
                $62 = __THREW__; __THREW__ = 0;
                $63 = $62&1;
                if ($63) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3835,(2468768|0));
                $64 = __THREW__; __THREW__ = 0;
                $65 = $64&1;
                if ($65) {
                 label = 8;
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2468768|0))|0);
               $66 = __THREW__; __THREW__ = 0;
               $67 = $66&1;
               if ($67) {
                label = 8;
               } else {
                $68 = HEAP32[((2468768 + 80|0))>>2]|0;
                $69 = (($68) + 12|0);
                $70 = HEAP32[$69>>2]|0;
                __THREW__ = 0;
                $71 = (invoke_iiii(574,(0|0),($activationUrl|0),($70|0))|0);
                $72 = __THREW__; __THREW__ = 0;
                $73 = $72&1;
                if ($73) {
                 label = 8;
                } else {
                 $74 = $71&1;
                 __THREW__ = 0;
                 $75 = (invoke_ii(2403,(0|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  label = 8;
                 } else {
                  do {
                   if ($71) {
                    __THREW__ = 0;
                    invoke_vi(3799,($46|0));
                    $78 = __THREW__; __THREW__ = 0;
                    $79 = $78&1;
                    if ($79) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    $80 = (invoke_iii(2730,(2298872|0),($46|0))|0);
                    $81 = __THREW__; __THREW__ = 0;
                    $82 = $81&1;
                    if ($82) {
                     label = 8;
                     break L1;
                    }
                    while(1) {
                     __THREW__ = 0;
                     invoke_vi(3799,($80|0));
                     $104 = __THREW__; __THREW__ = 0;
                     $105 = $104&1;
                     if ($105) {
                      label = 46;
                      break;
                     }
                     __THREW__ = 0;
                     $106 = (invoke_iii(2741,(2176240|0),($80|0))|0);
                     $107 = __THREW__; __THREW__ = 0;
                     $108 = $107&1;
                     if ($108) {
                      label = 46;
                      break;
                     }
                     if (!($106)) {
                      $V_3$1 = $74;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 165;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($80|0));
                     $109 = __THREW__; __THREW__ = 0;
                     $110 = $109&1;
                     if ($110) {
                      label = 46;
                      break;
                     }
                     __THREW__ = 0;
                     $83 = (invoke_iii(2740,(2176176|0),($80|0))|0);
                     $84 = __THREW__; __THREW__ = 0;
                     $85 = $84&1;
                     if ($85) {
                      label = 46;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2472816|0))|0);
                     $86 = __THREW__; __THREW__ = 0;
                     $87 = $86&1;
                     if ($87) {
                      label = 46;
                      break;
                     }
                     __THREW__ = 0;
                     $88 = (invoke_iii(2763,($83|0),(2472816|0))|0);
                     $89 = __THREW__; __THREW__ = 0;
                     $90 = $89&1;
                     if ($90) {
                      label = 46;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($88|0));
                     $91 = __THREW__; __THREW__ = 0;
                     $92 = $91&1;
                     if ($92) {
                      label = 46;
                      break;
                     }
                     __THREW__ = 0;
                     $93 = (invoke_iiiii(305,(2472712|0),($88|0),($75|0),($2|0))|0);
                     $94 = __THREW__; __THREW__ = 0;
                     $95 = $94&1;
                     if ($95) {
                      label = 46;
                      break;
                     }
                     if (!($93)) {
                      $V_3$1 = 0;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 165;
                      break;
                     }
                    }
                    if ((label|0) == 46) {
                     $96 = ___cxa_find_matching_catch(348288|0)|0;
                     $97 = tempRet0;
                     $98 = (_llvm_eh_typeid_for((348288|0))|0);
                     $99 = ($97|0)==($98|0);
                     if (!($99)) {
                      $$06 = $96;$$07 = $97;
                      __ZN16StackTraceSentryD2Ev(0);
                      ___resumeException($$06|0);
                      // unreachable;
                     }
                     $100 = (___cxa_begin_catch(($96|0))|0);
                     $101 = HEAP32[$100>>2]|0;
                     __THREW__ = 0;
                     invoke_v(66);
                     $102 = __THREW__; __THREW__ = 0;
                     $103 = $102&1;
                     if ($103) {
                      label = 8;
                      break L1;
                     }
                     $V_3$1 = $74;$__last_unhandled_exception$0 = $101;$leaveInstructions$sroa$0$0 = 0;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2176856|0))|0);
                    $111 = __THREW__; __THREW__ = 0;
                    $112 = $111&1;
                    if ($112) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    $113 = (invoke_iii(2735,($80|0),(2176856|0))|0);
                    $114 = __THREW__; __THREW__ = 0;
                    $115 = $114&1;
                    if ($115) {
                     label = 8;
                     break L1;
                    }
                    $116 = ($113|0)==(0|0);
                    if ($116) {
                     $cond4 = ($leaveInstructions$sroa$0$0|0)==(165);
                     $extract$t10 = ($V_3$1<<24>>24)!=(0);
                     if ($cond4) {
                      $V_3$2$off0 = $extract$t10;$__last_unhandled_exception$1 = $__last_unhandled_exception$0;$leaveInstructions$sroa$0$1 = 165;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3834,($__last_unhandled_exception$0|0));
                     $117 = __THREW__; __THREW__ = 0;
                     $118 = $117&1;
                     if ($118) {
                      label = 8;
                      break L1;
                     }
                     // unreachable;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($113|0));
                    $119 = __THREW__; __THREW__ = 0;
                    $120 = $119&1;
                    if ($120) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    invoke_vii(3491,(2176768|0),($113|0));
                    $121 = __THREW__; __THREW__ = 0;
                    $122 = $121&1;
                    if ($122) {
                     label = 8;
                     break L1;
                    }
                    $cond5 = ($leaveInstructions$sroa$0$0|0)==(165);
                    $extract$t9 = ($V_3$1<<24>>24)!=(0);
                    if ($cond5) {
                     $V_3$2$off0 = $extract$t9;$__last_unhandled_exception$1 = $__last_unhandled_exception$0;$leaveInstructions$sroa$0$1 = 165;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3834,($__last_unhandled_exception$0|0));
                    $123 = __THREW__; __THREW__ = 0;
                    $124 = $123&1;
                    if ($124) {
                     label = 8;
                     break L1;
                    }
                    // unreachable;
                   } else {
                    $V_3$2$off0 = 0;$__last_unhandled_exception$1 = 0;$leaveInstructions$sroa$0$1 = 0;
                   }
                  } while(0);
                  __THREW__ = 0;
                  invoke_vi(3799,($type|0));
                  $125 = __THREW__; __THREW__ = 0;
                  $126 = $125&1;
                  if ($126) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  $127 = (invoke_iiii(1668,(2242680|0),($type|0),1)|0);
                  $128 = __THREW__; __THREW__ = 0;
                  $129 = $128&1;
                  if ($129) {
                   label = 8;
                   break;
                  }
                  $130 = (($127) + 12|0);
                  $V_10$0 = 0;$V_3$4$off0 = $V_3$2$off0;
                  while(1) {
                   __THREW__ = 0;
                   invoke_vi(3799,($127|0));
                   $165 = __THREW__; __THREW__ = 0;
                   $166 = $165&1;
                   if ($166) {
                    label = 7;
                    break;
                   }
                   $167 = HEAP32[$130>>2]|0;
                   $168 = ($V_10$0|0)<($167|0);
                   if (!($168)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($127|0));
                   $169 = __THREW__; __THREW__ = 0;
                   $170 = $169&1;
                   if ($170) {
                    label = 7;
                    break;
                   }
                   $131 = HEAP32[$130>>2]|0;
                   $132 = ($V_10$0>>>0)<($131>>>0);
                   if (!($132)) {
                    __THREW__ = 0;
                    $133 = (invoke_i(132)|0);
                    $134 = __THREW__; __THREW__ = 0;
                    $135 = $134&1;
                    if ($135) {
                     label = 7;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($133|0));
                    $136 = __THREW__; __THREW__ = 0;
                    $137 = $136&1;
                    if ($137) {
                     label = 7;
                     break;
                    }
                   }
                   $138 = HEAP32[$127>>2]|0;
                   $139 = (($138) + 92|0);
                   $140 = HEAP32[$139>>2]|0;
                   $141 = Math_imul($140, $V_10$0)|0;
                   $$sum = (($141) + 16)|0;
                   $142 = (($127) + ($$sum)|0);
                   $143 = HEAP32[$142>>2]|0;
                   __THREW__ = 0;
                   (invoke_ii(2996,(2472816|0))|0);
                   $144 = __THREW__; __THREW__ = 0;
                   $145 = $144&1;
                   if ($145) {
                    label = 7;
                    break;
                   }
                   __THREW__ = 0;
                   $146 = (invoke_iii(2735,($143|0),(2472816|0))|0);
                   $147 = __THREW__; __THREW__ = 0;
                   $148 = $147&1;
                   if ($148) {
                    label = 7;
                    break;
                   }
                   $149 = ($146|0)==(0|0);
                   if ($149) {
                    $V_3$3$off0 = $V_3$4$off0;
                   } else {
                    if ($V_3$4$off0) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2472816|0))|0);
                     $150 = __THREW__; __THREW__ = 0;
                     $151 = $150&1;
                     if ($151) {
                      label = 7;
                      break;
                     }
                     __THREW__ = 0;
                     $152 = (invoke_iii(2763,($143|0),(2472816|0))|0);
                     $153 = __THREW__; __THREW__ = 0;
                     $154 = $153&1;
                     if ($154) {
                      label = 7;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($152|0));
                     $155 = __THREW__; __THREW__ = 0;
                     $156 = $155&1;
                     if ($156) {
                      label = 7;
                      break;
                     }
                     __THREW__ = 0;
                     $157 = (invoke_iiiii(305,(2472712|0),($152|0),($75|0),($2|0))|0);
                     $158 = __THREW__; __THREW__ = 0;
                     $159 = $158&1;
                     if ($159) {
                      label = 7;
                      break;
                     } else {
                      $G_B19_0$0 = $157;
                     }
                    } else {
                     $G_B19_0$0 = 0;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($46|0));
                    $160 = __THREW__; __THREW__ = 0;
                    $161 = $160&1;
                    if ($161) {
                     label = 7;
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_iiii(1647,(2297624|0),($46|0),($143|0))|0);
                    $162 = __THREW__; __THREW__ = 0;
                    $163 = $162&1;
                    if ($163) {
                     label = 7;
                     break;
                    } else {
                     $V_3$3$off0 = $G_B19_0$0;
                    }
                   }
                   $164 = (($V_10$0) + 1)|0;
                   $V_10$0 = $164;$V_3$4$off0 = $V_3$3$off0;
                  }
                  if ((label|0) == 7) {
                   $12 = ___cxa_find_matching_catch()|0;
                   $13 = tempRet0;
                   $lpad$phi$index = $12;$lpad$phi$index2 = $13;
                   break;
                  }
                  do {
                   if (!($V_3$4$off0)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($46|0));
                    $171 = __THREW__; __THREW__ = 0;
                    $172 = $171&1;
                    if ($172) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    $173 = (invoke_iii(2730,(2299160|0),($46|0))|0);
                    $174 = __THREW__; __THREW__ = 0;
                    $175 = $174&1;
                    if ($175) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($2|0));
                    $176 = __THREW__; __THREW__ = 0;
                    $177 = $176&1;
                    if ($177) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    invoke_vii(1882,($2|0),($173|0));
                    $178 = __THREW__; __THREW__ = 0;
                    $179 = $178&1;
                    if ($179) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($46|0));
                    $180 = __THREW__; __THREW__ = 0;
                    $181 = $180&1;
                    if ($181) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    $182 = (invoke_iii(2730,(2298872|0),($46|0))|0);
                    $183 = __THREW__; __THREW__ = 0;
                    $184 = $183&1;
                    if ($184) {
                     label = 8;
                     break L1;
                    }
                    while(1) {
                     __THREW__ = 0;
                     invoke_vi(3799,($182|0));
                     $197 = __THREW__; __THREW__ = 0;
                     $198 = $197&1;
                     if ($198) {
                      label = 100;
                      break;
                     }
                     __THREW__ = 0;
                     $199 = (invoke_iii(2741,(2176240|0),($182|0))|0);
                     $200 = __THREW__; __THREW__ = 0;
                     $201 = $200&1;
                     if ($201) {
                      label = 100;
                      break;
                     }
                     if (!($199)) {
                      $__last_unhandled_exception$2 = $__last_unhandled_exception$1;$leaveInstructions$sroa$0$2 = 324;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($182|0));
                     $202 = __THREW__; __THREW__ = 0;
                     $203 = $202&1;
                     if ($203) {
                      label = 100;
                      break;
                     }
                     __THREW__ = 0;
                     $185 = (invoke_iii(2740,(2176176|0),($182|0))|0);
                     $186 = __THREW__; __THREW__ = 0;
                     $187 = $186&1;
                     if ($187) {
                      label = 100;
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2472816|0))|0);
                     $188 = __THREW__; __THREW__ = 0;
                     $189 = $188&1;
                     if ($189) {
                      label = 100;
                      break;
                     }
                     __THREW__ = 0;
                     $190 = (invoke_iii(2763,($185|0),(2472816|0))|0);
                     $191 = __THREW__; __THREW__ = 0;
                     $192 = $191&1;
                     if ($192) {
                      label = 100;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($190|0));
                     $193 = __THREW__; __THREW__ = 0;
                     $194 = $193&1;
                     if ($194) {
                      label = 100;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(2123,(2472640|0),($190|0),($2|0));
                     $195 = __THREW__; __THREW__ = 0;
                     $196 = $195&1;
                     if ($196) {
                      label = 100;
                      break;
                     }
                    }
                    if ((label|0) == 100) {
                     $204 = ___cxa_find_matching_catch(348288|0)|0;
                     $205 = tempRet0;
                     $206 = (_llvm_eh_typeid_for((348288|0))|0);
                     $207 = ($205|0)==($206|0);
                     if (!($207)) {
                      $$06 = $204;$$07 = $205;
                      __ZN16StackTraceSentryD2Ev(0);
                      ___resumeException($$06|0);
                      // unreachable;
                     }
                     $208 = (___cxa_begin_catch(($204|0))|0);
                     $209 = HEAP32[$208>>2]|0;
                     __THREW__ = 0;
                     invoke_v(66);
                     $210 = __THREW__; __THREW__ = 0;
                     $211 = $210&1;
                     if ($211) {
                      label = 8;
                      break L1;
                     }
                     $__last_unhandled_exception$2 = $209;$leaveInstructions$sroa$0$2 = $leaveInstructions$sroa$0$1;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2176856|0))|0);
                    $212 = __THREW__; __THREW__ = 0;
                    $213 = $212&1;
                    if ($213) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    $214 = (invoke_iii(2735,($182|0),(2176856|0))|0);
                    $215 = __THREW__; __THREW__ = 0;
                    $216 = $215&1;
                    if ($216) {
                     label = 8;
                     break L1;
                    }
                    $217 = ($214|0)==(0|0);
                    if ($217) {
                     $cond1 = ($leaveInstructions$sroa$0$2|0)==(324);
                     if ($cond1) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3834,($__last_unhandled_exception$2|0));
                     $218 = __THREW__; __THREW__ = 0;
                     $219 = $218&1;
                     if ($219) {
                      label = 8;
                      break L1;
                     }
                     // unreachable;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($214|0));
                    $220 = __THREW__; __THREW__ = 0;
                    $221 = $220&1;
                    if ($221) {
                     label = 8;
                     break L1;
                    }
                    __THREW__ = 0;
                    invoke_vii(3491,(2176768|0),($214|0));
                    $222 = __THREW__; __THREW__ = 0;
                    $223 = $222&1;
                    if ($223) {
                     label = 8;
                     break L1;
                    }
                    $cond2 = ($leaveInstructions$sroa$0$2|0)==(324);
                    if ($cond2) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3834,($__last_unhandled_exception$2|0));
                    $224 = __THREW__; __THREW__ = 0;
                    $225 = $224&1;
                    if ($225) {
                     label = 8;
                     break L1;
                    }
                    // unreachable;
                   }
                  } while(0);
                  __THREW__ = 0;
                  (invoke_ii(2996,(2468768|0))|0);
                  $226 = __THREW__; __THREW__ = 0;
                  $227 = $226&1;
                  if ($227) {
                   label = 8;
                   break;
                  }
                  $228 = HEAP8[((2468768 + 116|0))>>0]|0;
                  $229 = ($228<<24>>24)==(0);
                  if ($229) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2468768|0))|0);
                   $230 = __THREW__; __THREW__ = 0;
                   $231 = $230&1;
                   if ($231) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2468768|0))|0);
                   $232 = __THREW__; __THREW__ = 0;
                   $233 = $232&1;
                   if ($233) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3835,(2468768|0));
                   $234 = __THREW__; __THREW__ = 0;
                   $235 = $234&1;
                   if ($235) {
                    label = 8;
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2468768|0))|0);
                  $236 = __THREW__; __THREW__ = 0;
                  $237 = $236&1;
                  if ($237) {
                   label = 8;
                   break;
                  }
                  $238 = HEAP32[((2468768 + 80|0))>>2]|0;
                  $239 = (($238) + 12|0);
                  $240 = HEAP32[$239>>2]|0;
                  __THREW__ = 0;
                  $241 = (invoke_iiii(575,(0|0),($activationUrl|0),($240|0))|0);
                  $242 = __THREW__; __THREW__ = 0;
                  $243 = $242&1;
                  if ($243) {
                   label = 8;
                   break;
                  }
                  if ($241) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2454768|0))|0);
                   $244 = __THREW__; __THREW__ = 0;
                   $245 = $244&1;
                   if ($245) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   $246 = (invoke_ii(3469,(2454768|0))|0);
                   $247 = __THREW__; __THREW__ = 0;
                   $248 = $247&1;
                   if ($248) {
                    label = 8;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(609,($246|0),($activationUrl|0),($39|0));
                   $249 = __THREW__; __THREW__ = 0;
                   $250 = $249&1;
                   if ($250) {
                    label = 8;
                    break;
                   }
                   $V_1$0 = $246;
                  } else {
                   $V_1$0 = $39;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($2|0));
                  $251 = __THREW__; __THREW__ = 0;
                  $252 = $251&1;
                  if ($252) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(2110,(2474456|0),($2|0),($V_1$0|0));
                  $253 = __THREW__; __THREW__ = 0;
                  $254 = $253&1;
                  if ($254) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($2|0));
                  $255 = __THREW__; __THREW__ = 0;
                  $256 = $255&1;
                  if ($256) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(1880,($2|0),($V_3$4$off0|0));
                  $257 = __THREW__; __THREW__ = 0;
                  $258 = $257&1;
                  if ($258) {
                   label = 8;
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($2|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 }
 $$06 = $lpad$phi$index;$$07 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$06|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Runtime_Remoting_Activation_AppDomainLevelActivator_m__ctorP67mscorlib_System_Runtime_Remoting_Activation_AppDomainLevelActivatorP22mscorlib_System_StringP22mscorlib_System_Object($__this,$activationUrl,$next) {
 $__this = $__this|0;
 $activationUrl = $activationUrl|0;
 $next = $next|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2454528);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $activationUrl;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $next;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z73mscorlib_System_Runtime_Remoting_Activation_ContextLevelActivator_m__ctorP65mscorlib_System_Runtime_Remoting_Activation_ContextLevelActivatorP22mscorlib_System_Object($__this,$next) {
 $__this = $__this|0;
 $next = $next|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2455176);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $next;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN23InterfaceActionInvoker1I17VoidPointerTraitsE6InvokeEP10MethodInfoPvS4_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($4,$p1);
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Runtime_Remoting_Activation_IActivator_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Runtime_Remoting_Activation_IConstructionCallMessage_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_get_UrlValueP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2466744);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_EqualsP56mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2466792);
 __THREW__ = 0;
 (invoke_ii(2996,(2467344|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($o|0),(2467344|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2467344|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2764,($o|0),(2467344|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_ii(2290,($10|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = (($__this) + 12|0);
       $19 = HEAP32[$18>>2]|0;
       __THREW__ = 0;
       $20 = (invoke_iiii(574,(0|0),($15|0),($19|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $$0 = $20;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo7306($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z70mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_GetHashCodeP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2466840);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(2185544|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_GetPropertiesForNewContextP56mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP22mscorlib_System_Object($__this,$ctorMsg) {
 $__this = $__this|0;
 $ctorMsg = $ctorMsg|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2466888);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_IsContextOKP56mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP49mscorlib_System_Runtime_Remoting_Contexts_ContextP22mscorlib_System_Object($__this,$ctx,$msg) {
 $__this = $__this|0;
 $ctx = $ctx|0;
 $msg = $msg|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2466936);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z87mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z173mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_GetPropertiesForNewContextP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z158mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_IsContextOKP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z52mscorlib_System_Runtime_Remoting_ChannelInfo_m__ctorP44mscorlib_System_Runtime_Remoting_ChannelInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2467480);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(2292,0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $2;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z81mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m_GetCurrentChannelInfoP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$05 = 0, $$06 = 0, $$1 = 0, $$17 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__last_unhandled_exception$0 = 0;
 var $_stackTraceSentry = 0, $cond3 = 0, $cond4 = 0, $leaveInstructions$sroa$1$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2468152);
 __THREW__ = 0;
 (invoke_ii(2996,(2304136|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(3469,(2304136|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(2153,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2468768|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = HEAP8[((2468768 + 116|0))>>0]|0;
      $10 = ($9<<24>>24)==(0);
      if ($10) {
       __THREW__ = 0;
       (invoke_ii(2996,(2468768|0))|0);
       $11 = __THREW__; __THREW__ = 0;
       $12 = $11&1;
       if ($12) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2468768|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3836,(2468768|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2468768|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = HEAP32[((2468768 + 80|0))>>2]|0;
       $22 = HEAP32[$21>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($22|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_iii(2756,(2297528|0),($22|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         __THREW__ = 0;
         invoke_vii(1916,(0|0),($25|0));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2468768|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          L15: do {
           if ($31) {
            label = 19;
           } else {
            $32 = HEAP8[((2468768 + 116|0))>>0]|0;
            $33 = ($32<<24>>24)==(0);
            if ($33) {
             __THREW__ = 0;
             (invoke_ii(2996,(2468768|0))|0);
             $34 = __THREW__; __THREW__ = 0;
             $35 = $34&1;
             if ($35) {
              label = 19;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2468768|0))|0);
             $36 = __THREW__; __THREW__ = 0;
             $37 = $36&1;
             if ($37) {
              label = 19;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3836,(2468768|0));
             $38 = __THREW__; __THREW__ = 0;
             $39 = $38&1;
             if ($39) {
              label = 19;
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2468768|0))|0);
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if ($43) {
             label = 19;
            } else {
             $44 = HEAP32[((2468768 + 80|0))>>2]|0;
             $45 = HEAP32[$44>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($45|0));
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if ($47) {
              label = 19;
             } else {
              __THREW__ = 0;
              $48 = (invoke_iii(2730,(2298872|0),($45|0))|0);
              $49 = __THREW__; __THREW__ = 0;
              $50 = $49&1;
              if ($50) {
               label = 19;
              } else {
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($48|0));
                $83 = __THREW__; __THREW__ = 0;
                $84 = $83&1;
                if ($84) {
                 label = 28;
                 break;
                }
                __THREW__ = 0;
                $85 = (invoke_iii(2741,(2176240|0),($48|0))|0);
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 label = 28;
                 break;
                }
                if (!($85)) {
                 $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$1$0 = 108;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($48|0));
                $88 = __THREW__; __THREW__ = 0;
                $89 = $88&1;
                if ($89) {
                 label = 28;
                 break;
                }
                __THREW__ = 0;
                $51 = (invoke_iii(2740,(2176176|0),($48|0))|0);
                $52 = __THREW__; __THREW__ = 0;
                $53 = $52&1;
                if ($53) {
                 label = 28;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2470392|0))|0);
                $54 = __THREW__; __THREW__ = 0;
                $55 = $54&1;
                if ($55) {
                 label = 28;
                 break;
                }
                __THREW__ = 0;
                $56 = (invoke_iii(2735,($51|0),(2470392|0))|0);
                $57 = __THREW__; __THREW__ = 0;
                $58 = $57&1;
                if ($58) {
                 label = 28;
                 break;
                }
                $59 = ($56|0)==(0|0);
                if ($59) {
                 continue;
                }
                __THREW__ = 0;
                invoke_vi(3799,($56|0));
                $73 = __THREW__; __THREW__ = 0;
                $74 = $73&1;
                if ($74) {
                 label = 28;
                 break;
                }
                __THREW__ = 0;
                $75 = (invoke_iii(2740,(2468200|0),($56|0))|0);
                $76 = __THREW__; __THREW__ = 0;
                $77 = $76&1;
                if ($77) {
                 label = 28;
                 break;
                }
                $78 = ($75|0)==(0|0);
                if ($78) {
                 continue;
                }
                __THREW__ = 0;
                invoke_vi(3799,($2|0));
                $79 = __THREW__; __THREW__ = 0;
                $80 = $79&1;
                if ($80) {
                 label = 28;
                 break;
                }
                __THREW__ = 0;
                (invoke_iiii(1647,(2297624|0),($2|0),($75|0))|0);
                $81 = __THREW__; __THREW__ = 0;
                $82 = $81&1;
                if ($82) {
                 label = 28;
                 break;
                }
               }
               if ((label|0) == 28) {
                $60 = ___cxa_find_matching_catch(348288|0)|0;
                $61 = tempRet0;
                $62 = (_llvm_eh_typeid_for((348288|0))|0);
                $63 = ($61|0)==($62|0);
                if (!($63)) {
                 $$05 = $60;$$06 = $61;$$pre$phiZ2D = $62;
                 break;
                }
                $69 = (___cxa_begin_catch(($60|0))|0);
                $70 = HEAP32[$69>>2]|0;
                __THREW__ = 0;
                invoke_v(66);
                $71 = __THREW__; __THREW__ = 0;
                $72 = $71&1;
                if ($72) {
                 label = 19;
                 break;
                }
                $__last_unhandled_exception$0 = $70;$leaveInstructions$sroa$1$0 = 0;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2176856|0))|0);
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if ($91) {
                label = 19;
               } else {
                __THREW__ = 0;
                $92 = (invoke_iii(2735,($48|0),(2176856|0))|0);
                $93 = __THREW__; __THREW__ = 0;
                $94 = $93&1;
                if ($94) {
                 label = 19;
                } else {
                 $95 = ($92|0)==(0|0);
                 do {
                  if ($95) {
                   $cond3 = ($leaveInstructions$sroa$1$0|0)==(108);
                   if ($cond3) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3837,($__last_unhandled_exception$0|0));
                   $96 = __THREW__; __THREW__ = 0;
                   $97 = $96&1;
                   if ($97) {
                    label = 19;
                    break L15;
                   }
                   // unreachable;
                  } else {
                   __THREW__ = 0;
                   invoke_vi(3799,($92|0));
                   $98 = __THREW__; __THREW__ = 0;
                   $99 = $98&1;
                   if ($99) {
                    label = 19;
                    break L15;
                   }
                   __THREW__ = 0;
                   invoke_vii(3491,(2176768|0),($92|0));
                   $100 = __THREW__; __THREW__ = 0;
                   $101 = $100&1;
                   if ($101) {
                    label = 19;
                    break L15;
                   }
                   $cond4 = ($leaveInstructions$sroa$1$0|0)==(108);
                   if ($cond4) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3837,($__last_unhandled_exception$0|0));
                   $102 = __THREW__; __THREW__ = 0;
                   $103 = $102&1;
                   if ($103) {
                    label = 19;
                    break L15;
                   }
                   // unreachable;
                  }
                 } while(0);
                 __THREW__ = 0;
                 invoke_vi(3799,($2|0));
                 $108 = __THREW__; __THREW__ = 0;
                 $109 = $108&1;
                 if ($109) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $110 = (invoke_iii(2730,(2299160|0),($2|0))|0);
                 $111 = __THREW__; __THREW__ = 0;
                 $112 = $111&1;
                 if ($112) {
                  break L1;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($110|0);
                }
               }
              }
             }
            }
           }
          } while(0);
          if ((label|0) == 19) {
           $40 = ___cxa_find_matching_catch(348288|0)|0;
           $41 = tempRet0;
           $$pre = (_llvm_eh_typeid_for((348288|0))|0);
           $$05 = $40;$$06 = $41;$$pre$phiZ2D = $$pre;
          }
          $64 = ($$06|0)==($$pre$phiZ2D|0);
          if (!($64)) {
           $$1 = $$05;$$17 = $$06;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($$1|0);
           // unreachable;
          }
          $65 = (___cxa_begin_catch(($$05|0))|0);
          $66 = HEAP32[$65>>2]|0;
          __THREW__ = 0;
          invoke_v(66);
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if (!($68)) {
           __THREW__ = 0;
           invoke_vii(1917,(0|0),($25|0));
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if (!($105)) {
            __THREW__ = 0;
            invoke_vi(3837,($66|0));
            $106 = __THREW__; __THREW__ = 0;
            $107 = $106&1;
            if (!($107)) {
             // unreachable;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $$1 = $17;$$17 = $18;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2467816);
 __THREW__ = 0;
 invoke_v(642);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2304136|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(2304136|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(2153,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2468768|0))|0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if (!($10)) {
       $11 = HEAP32[((2468768 + 80|0))>>2]|0;
       HEAP32[$11>>2] = $4;
       __THREW__ = 0;
       (invoke_ii(2996,(2304136|0))|0);
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        __THREW__ = 0;
        $14 = (invoke_ii(3469,(2304136|0))|0);
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         __THREW__ = 0;
         invoke_vi(2153,($14|0));
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if (!($18)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2468768|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           $21 = HEAP32[((2468768 + 80|0))>>2]|0;
           $22 = (($21) + 4|0);
           HEAP32[$22>>2] = $14;
           __THREW__ = 0;
           (invoke_ii(2996,(2472488|0))|0);
           $23 = __THREW__; __THREW__ = 0;
           $24 = $23&1;
           if (!($24)) {
            __THREW__ = 0;
            $25 = (invoke_ii(3469,(2472488|0))|0);
            $26 = __THREW__; __THREW__ = 0;
            $27 = $26&1;
            if (!($27)) {
             __THREW__ = 0;
             invoke_vi(2401,($25|0));
             $28 = __THREW__; __THREW__ = 0;
             $29 = $28&1;
             if (!($29)) {
              __THREW__ = 0;
              (invoke_ii(2996,(2468768|0))|0);
              $30 = __THREW__; __THREW__ = 0;
              $31 = $30&1;
              if (!($31)) {
               $32 = HEAP32[((2468768 + 80|0))>>2]|0;
               $33 = (($32) + 8|0);
               HEAP32[$33>>2] = $25;
               $34 = HEAP32[3034368>>2]|0;
               __THREW__ = 0;
               (invoke_ii(2996,(2468768|0))|0);
               $35 = __THREW__; __THREW__ = 0;
               $36 = $35&1;
               if (!($36)) {
                $37 = HEAP32[((2468768 + 80|0))>>2]|0;
                $38 = (($37) + 12|0);
                HEAP32[$38>>2] = $34;
                __THREW__ = 0;
                (invoke_ii(2996,(1168432|0))|0);
                $39 = __THREW__; __THREW__ = 0;
                $40 = $39&1;
                if (!($40)) {
                 __THREW__ = 0;
                 $41 = (invoke_iii(2765,(1168432|0),2)|0);
                 $42 = __THREW__; __THREW__ = 0;
                 $43 = $42&1;
                 if (!($43)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($41|0));
                  $44 = __THREW__; __THREW__ = 0;
                  $45 = $44&1;
                  if (!($45)) {
                   $46 = (($41) + 12|0);
                   $47 = HEAP32[$46>>2]|0;
                   $48 = ($47|0)==(0);
                   if ($48) {
                    __THREW__ = 0;
                    $49 = (invoke_i(132)|0);
                    $50 = __THREW__; __THREW__ = 0;
                    $51 = $50&1;
                    if ($51) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($49|0));
                    $52 = __THREW__; __THREW__ = 0;
                    $53 = $52&1;
                    if ($53) {
                     break;
                    }
                   }
                   $56 = HEAP32[3034376>>2]|0;
                   __THREW__ = 0;
                   invoke_vii(3492,($41|0),($56|0));
                   $57 = __THREW__; __THREW__ = 0;
                   $58 = $57&1;
                   if (!($58)) {
                    $59 = HEAP32[3034376>>2]|0;
                    $60 = (($41) + 16|0);
                    HEAP32[$60>>2] = $59;
                    __THREW__ = 0;
                    invoke_vi(3799,($41|0));
                    $61 = __THREW__; __THREW__ = 0;
                    $62 = $61&1;
                    if ($62) {
                     break;
                    }
                    $63 = HEAP32[$46>>2]|0;
                    $64 = ($63>>>0)<(2);
                    if ($64) {
                     __THREW__ = 0;
                     $65 = (invoke_i(132)|0);
                     $66 = __THREW__; __THREW__ = 0;
                     $67 = $66&1;
                     if ($67) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3302,($65|0));
                     $68 = __THREW__; __THREW__ = 0;
                     $69 = $68&1;
                     if ($69) {
                      break;
                     }
                    }
                    $70 = HEAP32[3034384>>2]|0;
                    __THREW__ = 0;
                    invoke_vii(3492,($41|0),($70|0));
                    $71 = __THREW__; __THREW__ = 0;
                    $72 = $71&1;
                    if ($72) {
                     break;
                    }
                    $73 = HEAP32[3034384>>2]|0;
                    $74 = HEAP32[$41>>2]|0;
                    $75 = (($74) + 92|0);
                    $76 = HEAP32[$75>>2]|0;
                    $77 = (($60) + ($76)|0);
                    HEAP32[$77>>2] = $73;
                    __THREW__ = 0;
                    (invoke_ii(2996,(2468768|0))|0);
                    $78 = __THREW__; __THREW__ = 0;
                    $79 = $78&1;
                    if ($79) {
                     break;
                    }
                    $80 = HEAP32[((2468768 + 80|0))>>2]|0;
                    $81 = (($80) + 16|0);
                    HEAP32[$81>>2] = $41;
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $54 = ___cxa_find_matching_catch()|0;
 $55 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($54|0);
 // unreachable;
}
function __Z69mscorlib_System_Runtime_Remoting_Contexts_CrossContextChannel_m__ctorP61mscorlib_System_Runtime_Remoting_Contexts_CrossContextChannel($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2472360);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL10SZArrayNewP8TypeInfoj7307($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z147mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m_RegisterChannel_mscorlib_System_Void_mscorlib_System_Runtime_Remoting_Channels_IChannelP22mscorlib_System_ObjectS0_($__this,$chnl) {
 $__this = $__this|0;
 $chnl = $chnl|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2467864);
 __THREW__ = 0;
 invoke_viii(610,0,($chnl|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z171mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m_RegisterChannel_mscorlib_System_Void_mscorlib_System_Runtime_Remoting_Channels_IChannel_mscorlib_System_BooleanP22mscorlib_System_ObjectS0_b($__this,$chnl,$ensureSecurity) {
 $__this = $__this|0;
 $chnl = $chnl|0;
 $ensureSecurity = $ensureSecurity|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_3$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2467912);
 __THREW__ = 0;
 invoke_v(643);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($chnl|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3034600>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   do {
    if ($ensureSecurity) {
     __THREW__ = 0;
     (invoke_ii(2996,(2470784|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break L1;
     }
     __THREW__ = 0;
     $17 = (invoke_iii(2735,($chnl|0),(2470784|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break L1;
     }
     $20 = ($17|0)==(0|0);
     if (!($20)) {
      __THREW__ = 0;
      invoke_vi(3799,($17|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break L1;
      }
      __THREW__ = 0;
      invoke_viii(2124,(2468008|0),($17|0),1);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break L1;
      } else {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($chnl|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break L1;
     }
     __THREW__ = 0;
     $23 = (invoke_iii(2739,(2467960|0),($chnl|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break L1;
     }
     $26 = HEAP32[3034608>>2]|0;
     __THREW__ = 0;
     $27 = (invoke_iiii(552,(0|0),($26|0),($23|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2488992|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break L1;
     }
     __THREW__ = 0;
     $32 = (invoke_ii(3469,(2488992|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1891,($32|0),($27|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3837,($32|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   __THREW__ = 0;
   (invoke_ii(2996,(2468768|0))|0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    $45 = HEAP8[((2468768 + 116|0))>>0]|0;
    $46 = ($45<<24>>24)==(0);
    if ($46) {
     __THREW__ = 0;
     (invoke_ii(2996,(2468768|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2468768|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3836,(2468768|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2468768|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     $55 = HEAP32[((2468768 + 80|0))>>2]|0;
     $56 = HEAP32[$55>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($56|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if (!($58)) {
      __THREW__ = 0;
      $59 = (invoke_iii(2756,(2297528|0),($56|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if (!($61)) {
       __THREW__ = 0;
       invoke_vii(1916,(0|0),($59|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if (!($63)) {
        $V_2$1 = -1;$V_3$0 = 0;
        while(1) {
         __THREW__ = 0;
         (invoke_ii(2996,(2468768|0))|0);
         $163 = __THREW__; __THREW__ = 0;
         $164 = $163&1;
         if ($164) {
          label = 37;
          break;
         }
         $165 = HEAP8[((2468768 + 116|0))>>0]|0;
         $166 = ($165<<24>>24)==(0);
         if ($166) {
          __THREW__ = 0;
          (invoke_ii(2996,(2468768|0))|0);
          $167 = __THREW__; __THREW__ = 0;
          $168 = $167&1;
          if ($168) {
           label = 37;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2468768|0))|0);
          $169 = __THREW__; __THREW__ = 0;
          $170 = $169&1;
          if ($170) {
           label = 37;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3836,(2468768|0));
          $171 = __THREW__; __THREW__ = 0;
          $172 = $171&1;
          if ($172) {
           label = 37;
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2468768|0))|0);
         $173 = __THREW__; __THREW__ = 0;
         $174 = $173&1;
         if ($174) {
          label = 37;
          break;
         }
         $175 = HEAP32[((2468768 + 80|0))>>2]|0;
         $176 = HEAP32[$175>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($176|0));
         $177 = __THREW__; __THREW__ = 0;
         $178 = $177&1;
         if ($178) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         $179 = (invoke_iii(2729,(2296488|0),($176|0))|0);
         $180 = __THREW__; __THREW__ = 0;
         $181 = $180&1;
         if ($181) {
          label = 37;
          break;
         }
         $182 = ($V_3$0|0)<($179|0);
         if (!($182)) {
          label = 85;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2468768|0))|0);
         $183 = __THREW__; __THREW__ = 0;
         $184 = $183&1;
         if ($184) {
          label = 37;
          break;
         }
         $64 = HEAP8[((2468768 + 116|0))>>0]|0;
         $65 = ($64<<24>>24)==(0);
         if ($65) {
          __THREW__ = 0;
          (invoke_ii(2996,(2468768|0))|0);
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           label = 37;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2468768|0))|0);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if ($69) {
           label = 37;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3836,(2468768|0));
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           label = 37;
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2468768|0))|0);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          label = 37;
          break;
         }
         $84 = HEAP32[((2468768 + 80|0))>>2]|0;
         $85 = HEAP32[$84>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($85|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         $88 = (invoke_iiii(1648,(2296536|0),($85|0),($V_3$0|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2470168|0))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         $93 = (invoke_iii(2764,($88|0),(2470168|0))|0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($93|0));
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         $98 = (invoke_iii(2739,(2467960|0),($93|0))|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($chnl|0));
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         $103 = (invoke_iii(2739,(2467960|0),($chnl|0))|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         $106 = (invoke_iiii(574,(0|0),($98|0),($103|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          label = 37;
          break;
         }
         if ($106) {
          __THREW__ = 0;
          invoke_vi(3799,($chnl|0));
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           label = 37;
           break;
          }
          __THREW__ = 0;
          $111 = (invoke_iii(2739,(2467960|0),($chnl|0))|0);
          $112 = __THREW__; __THREW__ = 0;
          $113 = $112&1;
          if ($113) {
           label = 37;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           label = 37;
           break;
          }
          $116 = HEAP8[((2191608 + 116|0))>>0]|0;
          $117 = ($116<<24>>24)==(0);
          if ($117) {
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $118 = __THREW__; __THREW__ = 0;
           $119 = $118&1;
           if ($119) {
            label = 37;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $120 = __THREW__; __THREW__ = 0;
           $121 = $120&1;
           if ($121) {
            label = 37;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3836,(2191608|0));
           $122 = __THREW__; __THREW__ = 0;
           $123 = $122&1;
           if ($123) {
            label = 37;
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $124 = __THREW__; __THREW__ = 0;
          $125 = $124&1;
          if ($125) {
           label = 37;
           break;
          }
          $126 = HEAP32[((2191608 + 80|0))>>2]|0;
          $127 = HEAP32[$126>>2]|0;
          __THREW__ = 0;
          $128 = (invoke_iiii(575,(0|0),($111|0),($127|0))|0);
          $129 = __THREW__; __THREW__ = 0;
          $130 = $129&1;
          if ($130) {
           label = 37;
           break;
          }
          if ($128) {
           label = 62;
           break;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($93|0));
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         $152 = (invoke_iii(2736,(2468056|0),($93|0))|0);
         $153 = __THREW__; __THREW__ = 0;
         $154 = $153&1;
         if ($154) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($chnl|0));
         $155 = __THREW__; __THREW__ = 0;
         $156 = $155&1;
         if ($156) {
          label = 37;
          break;
         }
         __THREW__ = 0;
         $157 = (invoke_iii(2736,(2468056|0),($chnl|0))|0);
         $158 = __THREW__; __THREW__ = 0;
         $159 = $158&1;
         if ($159) {
          label = 37;
          break;
         }
         $160 = ($152|0)<($157|0);
         $161 = ($V_2$1|0)==(-1);
         $or$cond = $160 & $161;
         $V_2$0 = $or$cond ? $V_3$0 : $V_2$1;
         $162 = (($V_3$0) + 1)|0;
         $V_2$1 = $V_2$0;$V_3$0 = $162;
        }
        do {
         if ((label|0) == 37) {
          $72 = ___cxa_find_matching_catch(348288|0)|0;
          $73 = tempRet0;
          $lpad$phi$index = $72;$lpad$phi$index2 = $73;
          label = 39;
         }
         else if ((label|0) == 62) {
          __THREW__ = 0;
          invoke_vi(3799,($93|0));
          $131 = __THREW__; __THREW__ = 0;
          $132 = $131&1;
          if ($132) {
           label = 38;
          } else {
           __THREW__ = 0;
           $133 = (invoke_iii(2739,(2467960|0),($93|0))|0);
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if ($135) {
            label = 38;
           } else {
            $136 = HEAP32[3034616>>2]|0;
            $137 = HEAP32[3034624>>2]|0;
            __THREW__ = 0;
            $138 = (invoke_iiiii(101,(0|0),($136|0),($133|0),($137|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 38;
            } else {
             __THREW__ = 0;
             (invoke_ii(2996,(2488992|0))|0);
             $141 = __THREW__; __THREW__ = 0;
             $142 = $141&1;
             if ($142) {
              label = 38;
             } else {
              __THREW__ = 0;
              $143 = (invoke_ii(3469,(2488992|0))|0);
              $144 = __THREW__; __THREW__ = 0;
              $145 = $144&1;
              if ($145) {
               label = 38;
              } else {
               __THREW__ = 0;
               invoke_vii(1891,($143|0),($138|0));
               $146 = __THREW__; __THREW__ = 0;
               $147 = $146&1;
               if ($147) {
                label = 38;
               } else {
                __THREW__ = 0;
                invoke_vi(3837,($143|0));
                $148 = __THREW__; __THREW__ = 0;
                $149 = $148&1;
                if ($149) {
                 label = 38;
                } else {
                 // unreachable;
                }
               }
              }
             }
            }
           }
          }
         }
         else if ((label|0) == 85) {
          $185 = ($V_2$1|0)==(-1);
          if ($185) {
           __THREW__ = 0;
           (invoke_ii(2996,(2468768|0))|0);
           $204 = __THREW__; __THREW__ = 0;
           $205 = $204&1;
           if ($205) {
            label = 38;
            break;
           }
           $206 = HEAP8[((2468768 + 116|0))>>0]|0;
           $207 = ($206<<24>>24)==(0);
           if ($207) {
            __THREW__ = 0;
            (invoke_ii(2996,(2468768|0))|0);
            $208 = __THREW__; __THREW__ = 0;
            $209 = $208&1;
            if ($209) {
             label = 38;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2468768|0))|0);
            $210 = __THREW__; __THREW__ = 0;
            $211 = $210&1;
            if ($211) {
             label = 38;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3836,(2468768|0));
            $212 = __THREW__; __THREW__ = 0;
            $213 = $212&1;
            if ($213) {
             label = 38;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2468768|0))|0);
           $214 = __THREW__; __THREW__ = 0;
           $215 = $214&1;
           if ($215) {
            label = 38;
            break;
           }
           $216 = HEAP32[((2468768 + 80|0))>>2]|0;
           $217 = HEAP32[$216>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($217|0));
           $218 = __THREW__; __THREW__ = 0;
           $219 = $218&1;
           if ($219) {
            label = 38;
            break;
           }
           __THREW__ = 0;
           (invoke_iiii(1647,(2297624|0),($217|0),($chnl|0))|0);
           $220 = __THREW__; __THREW__ = 0;
           $221 = $220&1;
           if ($221) {
            label = 38;
            break;
           }
          } else {
           __THREW__ = 0;
           (invoke_ii(2996,(2468768|0))|0);
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if ($187) {
            label = 38;
            break;
           }
           $188 = HEAP8[((2468768 + 116|0))>>0]|0;
           $189 = ($188<<24>>24)==(0);
           if ($189) {
            __THREW__ = 0;
            (invoke_ii(2996,(2468768|0))|0);
            $190 = __THREW__; __THREW__ = 0;
            $191 = $190&1;
            if ($191) {
             label = 38;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2468768|0))|0);
            $192 = __THREW__; __THREW__ = 0;
            $193 = $192&1;
            if ($193) {
             label = 38;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3836,(2468768|0));
            $194 = __THREW__; __THREW__ = 0;
            $195 = $194&1;
            if ($195) {
             label = 38;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2468768|0))|0);
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            label = 38;
            break;
           }
           $198 = HEAP32[((2468768 + 80|0))>>2]|0;
           $199 = HEAP32[$198>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($199|0));
           $200 = __THREW__; __THREW__ = 0;
           $201 = $200&1;
           if ($201) {
            label = 38;
            break;
           }
           __THREW__ = 0;
           invoke_viiii(463,(2298200|0),($199|0),($V_2$1|0),($chnl|0));
           $202 = __THREW__; __THREW__ = 0;
           $203 = $202&1;
           if ($203) {
            label = 38;
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2470392|0))|0);
          $222 = __THREW__; __THREW__ = 0;
          $223 = $222&1;
          if ($223) {
           label = 38;
          } else {
           __THREW__ = 0;
           $224 = (invoke_iii(2735,($chnl|0),(2470392|0))|0);
           $225 = __THREW__; __THREW__ = 0;
           $226 = $225&1;
           if ($226) {
            label = 38;
           } else {
            $227 = ($224|0)==(0|0);
            if ($227) {
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 283;
            } else {
             __THREW__ = 0;
             (invoke_ii(2996,(2468768|0))|0);
             $228 = __THREW__; __THREW__ = 0;
             $229 = $228&1;
             if ($229) {
              label = 38;
             } else {
              $230 = HEAP8[((2468768 + 116|0))>>0]|0;
              $231 = ($230<<24>>24)==(0);
              if ($231) {
               __THREW__ = 0;
               (invoke_ii(2996,(2468768|0))|0);
               $232 = __THREW__; __THREW__ = 0;
               $233 = $232&1;
               if ($233) {
                label = 38;
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2468768|0))|0);
               $234 = __THREW__; __THREW__ = 0;
               $235 = $234&1;
               if ($235) {
                label = 38;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3836,(2468768|0));
               $236 = __THREW__; __THREW__ = 0;
               $237 = $236&1;
               if ($237) {
                label = 38;
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2468768|0))|0);
              $238 = __THREW__; __THREW__ = 0;
              $239 = $238&1;
              if ($239) {
               label = 38;
              } else {
               $240 = HEAP32[((2468768 + 80|0))>>2]|0;
               $241 = (($240) + 16|0);
               $242 = HEAP32[$241>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($chnl|0));
               $243 = __THREW__; __THREW__ = 0;
               $244 = $243&1;
               if ($244) {
                label = 38;
               } else {
                __THREW__ = 0;
                $245 = (invoke_ii(1782,($chnl|0))|0);
                $246 = __THREW__; __THREW__ = 0;
                $247 = $246&1;
                if ($247) {
                 label = 38;
                } else {
                 __THREW__ = 0;
                 invoke_vi(3799,($245|0));
                 $248 = __THREW__; __THREW__ = 0;
                 $249 = $248&1;
                 if ($249) {
                  label = 38;
                  break;
                 }
                 __THREW__ = 0;
                 $250 = (invoke_iii(2730,(2149160|0),($245|0))|0);
                 $251 = __THREW__; __THREW__ = 0;
                 $252 = $251&1;
                 if ($252) {
                  label = 38;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($242|0));
                 $253 = __THREW__; __THREW__ = 0;
                 $254 = $253&1;
                 if ($254) {
                  label = 38;
                  break;
                 }
                 __THREW__ = 0;
                 $255 = (invoke_iiii(1669,(2231960|0),($242|0),($250|0))|0);
                 $256 = __THREW__; __THREW__ = 0;
                 $257 = $256&1;
                 if ($257) {
                  label = 38;
                  break;
                 }
                 if (!($255)) {
                  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 283;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($224|0));
                 $258 = __THREW__; __THREW__ = 0;
                 $259 = $258&1;
                 if ($259) {
                  label = 38;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(2125,(2468104|0),($224|0),(0|0));
                 $260 = __THREW__; __THREW__ = 0;
                 $261 = $260&1;
                 if ($261) {
                  label = 38;
                 } else {
                  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 283;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        } while(0);
        if ((label|0) == 38) {
         $74 = ___cxa_find_matching_catch(348288|0)|0;
         $75 = tempRet0;
         $lpad$phi$index = $74;$lpad$phi$index2 = $75;
         label = 39;
        }
        if ((label|0) == 39) {
         $76 = (_llvm_eh_typeid_for((348288|0))|0);
         $77 = ($lpad$phi$index2|0)==($76|0);
         if (!($77)) {
          $$0 = $lpad$phi$index;$$02 = $lpad$phi$index2;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($$0|0);
          // unreachable;
         }
         $78 = (___cxa_begin_catch(($lpad$phi$index|0))|0);
         $79 = HEAP32[$78>>2]|0;
         __THREW__ = 0;
         invoke_v(66);
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if ($81) {
          break;
         }
         $__last_unhandled_exception$0 = $79;$leaveInstructions$sroa$0$0 = 0;
        }
        __THREW__ = 0;
        invoke_vii(1917,(0|0),($59|0));
        $262 = __THREW__; __THREW__ = 0;
        $263 = $262&1;
        if (!($263)) {
         $cond1 = ($leaveInstructions$sroa$0$0|0)==(283);
         if ($cond1) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         __THREW__ = 0;
         invoke_vi(3837,($__last_unhandled_exception$0|0));
         $264 = __THREW__; __THREW__ = 0;
         $265 = $264&1;
         if (!($265)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$0 = $3;$$02 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception7308($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Runtime_Remoting_RemotingException_m__ctorP50mscorlib_System_Runtime_Remoting_RemotingExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2488776);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN23InterfaceActionInvoker1I29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($4,$p1);
 STACKTOP = sp;return;
}
function __ZL11RuntimeInitP8TypeInfo7311($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __ZN21InterfaceFuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN23InterfaceActionInvoker1I28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_vii[$3 & 4095]($4,$p1);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Runtime_Remoting_Channels_ChannelServices_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z236mscorlib_System_Runtime_Remoting_Channels_ChannelServices_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m_RegisterChannel_mscorlib_System_Void_mscorlib_System_Runtime_Remoting_Channels_IChannelP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2468584)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainData_m__ctorP60mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainDatai($__this,$domainId) {
 $__this = $__this|0;
 $domainId = $domainId|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2468904);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$L_1>>2] = 0;
  __THREW__ = 0;
  (invoke_ii(2996,(2155952|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2724,(2155952|0),($L_1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 8|0);
    HEAP32[$7>>2] = $4;
    $8 = (($__this) + 12|0);
    HEAP32[$8>>2] = $domainId;
    __THREW__ = 0;
    $9 = (invoke_ii(2328,0)|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($__this) + 16|0);
     HEAP32[$12>>2] = $9;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z70mscorlib_System_Runtime_Remoting_RemotingConfiguration_m_get_ProcessIdP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2487736);
 __THREW__ = 0;
 (invoke_ii(2996,(2488640|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2488640 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2488640|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2488640|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2488640|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2488640|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2488640 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     $18 = (invoke_ii(2413,(0|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2488640|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     $23 = HEAP8[((2488640 + 116|0))>>0]|0;
     $24 = ($23<<24>>24)==(0);
     if ($24) {
      __THREW__ = 0;
      (invoke_ii(2996,(2488640|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2488640|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3836,(2488640|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2488640|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     $33 = HEAP32[((2488640 + 80|0))>>2]|0;
     $34 = (($33) + 8|0);
     HEAP32[$34>>2] = $18;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2488640|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $37 = HEAP8[((2488640 + 116|0))>>0]|0;
     $38 = ($37<<24>>24)==(0);
     if ($38) {
      __THREW__ = 0;
      (invoke_ii(2996,(2488640|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2488640|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3836,(2488640|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2488640|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      $47 = HEAP32[((2488640 + 80|0))>>2]|0;
      $48 = (($47) + 8|0);
      $49 = HEAP32[$48>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($49|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m__ctorP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2469296);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z72mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2469344);
 __THREW__ = 0;
 (invoke_ii(2996,(2149728|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2149728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1924,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2469968|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2469968 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z95mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_RegisterCrossAppDomainChannelP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2469392);
 __THREW__ = 0;
 (invoke_ii(2996,(2469968|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2469968 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2469968|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2469968|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2469968|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2469968|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2469968 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_vii(1916,(0|0),($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2469968|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      label = 13;
     } else {
      __THREW__ = 0;
      $20 = (invoke_ii(3469,(2469968|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 13;
      } else {
       __THREW__ = 0;
       invoke_vi(2391,($20|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        label = 13;
       } else {
        __THREW__ = 0;
        invoke_vii(1875,0,($20|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         label = 13;
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 33;
        }
       }
      }
     }
     if ((label|0) == 13) {
      $27 = ___cxa_find_matching_catch(348288|0)|0;
      $28 = tempRet0;
      $29 = (_llvm_eh_typeid_for((348288|0))|0);
      $30 = ($28|0)==($29|0);
      if (!($30)) {
       $$0 = $28;$$02 = $27;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $31 = (___cxa_begin_catch(($27|0))|0);
      $32 = HEAP32[$31>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $__last_unhandled_exception$0 = $32;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,(0|0),($15|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      $cond1 = ($leaveInstructions$sroa$0$0|0)==(33);
      if ($cond1) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3837,($__last_unhandled_exception$0|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z81mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_get_ChannelNameP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2469440);
 __THREW__ = 0;
 invoke_v(644);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP32[3034848>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z85mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_get_ChannelPriorityP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2469488);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 100;
}
function __Z81mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_get_ChannelDataP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2469536);
 __THREW__ = 0;
 $0 = (invoke_ii(2406,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2469160|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2469160|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1876,($5|0),($0|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($5|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_StartListeningP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannelP22mscorlib_System_Object($__this,$data) {
 $__this = $__this|0;
 $data = $data|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2469584);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Runtime_Remoting_Channels_IChannel_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_Runtime_Remoting_Channels_IChannelReceiver_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Runtime_Remoting_Channels_IChannelSender_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Runtime_Remoting_Contexts_Context_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2470920);
 __THREW__ = 0;
 (invoke_ii(2996,(2313960|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2313960|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2173,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2471560|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2471560 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z60mscorlib_System_Runtime_Remoting_Contexts_Context_m_FinalizeP49mscorlib_System_Runtime_Remoting_Contexts_Context($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2470968);
 __THREW__ = 0;
 invoke_vi(1925,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z70mscorlib_System_Runtime_Remoting_Contexts_Context_m_get_DefaultContextP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2471016);
 __THREW__ = 0;
 $0 = (invoke_ii(2412,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z63mscorlib_System_Runtime_Remoting_Contexts_Context_m_GetPropertyP49mscorlib_System_Runtime_Remoting_Contexts_ContextP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $__last_unhandled_exception$0 = 0;
 var $_stackTraceSentry = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2471064);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L4: do {
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2298872|0),($1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $36 = (invoke_iii(2741,(2176240|0),($5|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 12;
      break;
     }
     if (!($36)) {
      $V_2$0 = 0;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 82;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2740,(2176176|0),($5|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2473008|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_iii(2764,($10|0),(2473008|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($15|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_iii(2739,(2471112|0),($15|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $23 = (invoke_iiii(574,(0|0),($20|0),($name|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 12;
      break;
     }
     if ($23) {
      $V_2$0 = $15;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 84;
      break;
     }
    }
    if ((label|0) == 12) {
     $26 = ___cxa_find_matching_catch(348288|0)|0;
     $27 = tempRet0;
     $28 = (_llvm_eh_typeid_for((348288|0))|0);
     $29 = ($27|0)==($28|0);
     if (!($29)) {
      $$01 = $26;$$02 = $27;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$01|0);
      // unreachable;
     }
     $30 = (___cxa_begin_catch(($26|0))|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     invoke_v(66);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $V_2$0 = 0;$__last_unhandled_exception$0 = $31;$leaveInstructions$sroa$0$0 = 0;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2176856|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     __THREW__ = 0;
     $43 = (invoke_iii(2735,($5|0),(2176856|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      $46 = ($43|0)==(0|0);
      do {
       if ($46) {
        if ((($leaveInstructions$sroa$0$0|0) == 84)) {
         break;
        } else if ((($leaveInstructions$sroa$0$0|0) == 82)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3837,($__last_unhandled_exception$0|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break L4;
        }
        // unreachable;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($43|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break L4;
        }
        __THREW__ = 0;
        invoke_vii(3491,(2176768|0),($43|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break L4;
        }
        if ((($leaveInstructions$sroa$0$0|0) == 84)) {
         break;
        } else if ((($leaveInstructions$sroa$0$0|0) == 82)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3837,($__last_unhandled_exception$0|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break L4;
        }
        // unreachable;
       }
      } while(0);
      $$0 = $V_2$0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $$01 = $8;$$02 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Runtime_Remoting_Contexts_Context_m_ToStringP49mscorlib_System_Runtime_Remoting_Contexts_Context($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2471160);
 __THREW__ = 0;
 invoke_v(645);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$L_1>>2] = $3;
  __THREW__ = 0;
  (invoke_ii(2996,(2155952|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2724,(2155952|0),($L_1|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3034880>>2]|0;
    __THREW__ = 0;
    $10 = (invoke_iiii(559,(0|0),($9|0),($6|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($10|0);
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Runtime_Remoting_Contexts_Context_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z69mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_get_NameP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2471696);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_EqualsP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2471744);
 $0 = ($o|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2472224|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2735,($o|0),(2472224|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2472224|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_iii(2764,($o|0),(2472224|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = (($11) + 8|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = (($__this) + 8|0);
      $19 = HEAP32[$18>>2]|0;
      __THREW__ = 0;
      $20 = (invoke_iiii(575,(0|0),($17|0),($19|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       $not$ = $20 ^ 1;
       $$0 = $not$;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z72mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_GetHashCodeP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2471792);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(2729,(2185544|0),($1|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $$0 = $5;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_GetPropertiesForNewContextP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP22mscorlib_System_Object($__this,$ctorMsg) {
 $__this = $__this|0;
 $ctorMsg = $ctorMsg|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2471840);
 __THREW__ = 0;
 invoke_v(646);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($ctorMsg|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3034920>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($ctorMsg|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_iii(2739,(2455776|0),($ctorMsg|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($17|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    (invoke_iiii(1649,(2231832|0),($17|0),($__this|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z72mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_IsContextOKP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP49mscorlib_System_Runtime_Remoting_Contexts_ContextP22mscorlib_System_Object($__this,$ctx,$ctorMsg) {
 $__this = $__this|0;
 $ctx = $ctx|0;
 $ctorMsg = $ctorMsg|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2471888);
 __THREW__ = 0;
 invoke_v(647);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($ctorMsg|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3034952>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($ctx|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3034960>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($ctorMsg|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_iii(2739,(2455704|0),($ctorMsg|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __THREW__ = 0;
     invoke_vi(3799,($28|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      $33 = (invoke_iii(2734,(2234280|0),($28|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       if (!($33)) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $36 = (($__this) + 8|0);
       $37 = HEAP32[$36>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($ctx|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        __THREW__ = 0;
        $40 = (invoke_iiii(1645,(2471064|0),($ctx|0),($37|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if (!($42)) {
         $43 = ($40|0)==(0|0);
         if ($43) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $44 = ($__this|0)==($40|0);
         $$0 = $44;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,4);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z90mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_Runtime_Remoting_Contexts_IContextProperty_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m__ctorP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfoP37mscorlib_System_Reflection_MethodBaseh($__this,$method,$type) {
 $__this = $__this|0;
 $method = $method|0;
 $type = $type|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2473600);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 16|0);
  HEAP32[$2>>2] = $method;
  __THREW__ = 0;
  invoke_vi(3799,($method|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2397136|0),($method|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($5) + 12|0);
     $11 = HEAP32[$10>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1170368|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      $14 = (invoke_iii(2765,(1170368|0),($11|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = (($__this) + 8|0);
       HEAP32[$17>>2] = $14;
       $18 = (($__this) + 12|0);
       HEAP32[$18>>2] = 0;
       $19 = ($type<<24>>24)==(0);
       if ($19) {
        $V_1$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($5|0));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          break;
         }
         $76 = HEAP32[$10>>2]|0;
         $77 = ($V_1$0|0)<($76|0);
         if (!($77)) {
          label = 59;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($5|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          break;
         }
         $26 = HEAP32[$10>>2]|0;
         $27 = ($V_1$0>>>0)<($26>>>0);
         if (!($27)) {
          __THREW__ = 0;
          $28 = (invoke_i(132)|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if ($30) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($28|0));
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if ($32) {
           break;
          }
         }
         $33 = HEAP32[$5>>2]|0;
         $34 = (($33) + 92|0);
         $35 = HEAP32[$34>>2]|0;
         $36 = Math_imul($35, $V_1$0)|0;
         $$sum2 = (($36) + 16)|0;
         $37 = (($5) + ($$sum2)|0);
         $38 = HEAP32[$37>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($38|0));
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break;
         }
         __THREW__ = 0;
         $41 = (invoke_iii(2730,(2397472|0),($38|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($41|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break;
         }
         __THREW__ = 0;
         $46 = (invoke_iii(2734,(2234040|0),($41|0))|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          break;
         }
         if (!($46)) {
          $49 = HEAP32[$17>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           break;
          }
          $52 = HEAP32[$18>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($__this|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break;
          }
          $55 = (($52) + 1)|0;
          HEAP32[$18>>2] = $55;
          __THREW__ = 0;
          invoke_vi(3799,($49|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          $58 = ($52|0)<(0);
          if ($58) {
           label = 25;
          } else {
           $59 = (($49) + 12|0);
           $60 = HEAP32[$59>>2]|0;
           $61 = ($52>>>0)<($60>>>0);
           if (!($61)) {
            label = 25;
           }
          }
          if ((label|0) == 25) {
           label = 0;
           __THREW__ = 0;
           $62 = (invoke_i(132)|0);
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($62|0));
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if ($66) {
            break;
           }
          }
          $67 = HEAP32[$49>>2]|0;
          $68 = (($49) + 16|0);
          $69 = (($67) + 92|0);
          $70 = HEAP32[$69>>2]|0;
          $71 = Math_imul($70, $52)|0;
          $72 = (($68) + ($71)|0);
          HEAP32[$72>>2] = $V_1$0;
         }
         $73 = (($V_1$0) + 1)|0;
         $V_1$0 = $73;
        }
        if ((label|0) == 59) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        $20 = ___cxa_find_matching_catch()|0;
        $21 = tempRet0;
        $lpad$phi$index = $20;$lpad$phi$index3 = $21;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       } else {
        $V_2$0 = 0;
       }
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($5|0));
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if ($149) {
         break;
        }
        $150 = HEAP32[$10>>2]|0;
        $151 = ($V_2$0|0)<($150|0);
        if (!($151)) {
         label = 59;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($5|0));
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         break;
        }
        $80 = HEAP32[$10>>2]|0;
        $81 = ($V_2$0>>>0)<($80>>>0);
        if (!($81)) {
         __THREW__ = 0;
         $82 = (invoke_i(132)|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($82|0));
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          break;
         }
        }
        $87 = HEAP32[$5>>2]|0;
        $88 = (($87) + 92|0);
        $89 = HEAP32[$88>>2]|0;
        $90 = Math_imul($89, $V_2$0)|0;
        $$sum = (($90) + 16)|0;
        $91 = (($5) + ($$sum)|0);
        $92 = HEAP32[$91>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($92|0));
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         break;
        }
        __THREW__ = 0;
        $95 = (invoke_iii(2730,(2397472|0),($92|0))|0);
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($95|0));
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         break;
        }
        __THREW__ = 0;
        $100 = (invoke_iii(2734,(2234040|0),($95|0))|0);
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         break;
        }
        if ($100) {
         label = 47;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($5|0));
         $103 = __THREW__; __THREW__ = 0;
         $104 = $103&1;
         if ($104) {
          break;
         }
         $105 = HEAP32[$10>>2]|0;
         $106 = ($V_2$0>>>0)<($105>>>0);
         if (!($106)) {
          __THREW__ = 0;
          $107 = (invoke_i(132)|0);
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($107|0));
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           break;
          }
         }
         $112 = HEAP32[$5>>2]|0;
         $113 = (($112) + 92|0);
         $114 = HEAP32[$113>>2]|0;
         $115 = Math_imul($114, $V_2$0)|0;
         $$sum1 = (($115) + 16)|0;
         $116 = (($5) + ($$sum1)|0);
         $117 = HEAP32[$116>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($117|0));
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if ($119) {
          break;
         }
         __THREW__ = 0;
         $120 = (invoke_ii(2284,($117|0))|0);
         $121 = __THREW__; __THREW__ = 0;
         $122 = $121&1;
         if ($122) {
          break;
         }
         if ($120) {
          label = 47;
         }
        }
        if ((label|0) == 47) {
         label = 0;
         $123 = HEAP32[$17>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $124 = __THREW__; __THREW__ = 0;
         $125 = $124&1;
         if ($125) {
          break;
         }
         $126 = HEAP32[$18>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($__this|0));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          break;
         }
         $129 = (($126) + 1)|0;
         HEAP32[$18>>2] = $129;
         __THREW__ = 0;
         invoke_vi(3799,($123|0));
         $130 = __THREW__; __THREW__ = 0;
         $131 = $130&1;
         if ($131) {
          break;
         }
         $132 = ($126|0)<(0);
         if ($132) {
          label = 52;
         } else {
          $133 = (($123) + 12|0);
          $134 = HEAP32[$133>>2]|0;
          $135 = ($126>>>0)<($134>>>0);
          if (!($135)) {
           label = 52;
          }
         }
         if ((label|0) == 52) {
          label = 0;
          __THREW__ = 0;
          $136 = (invoke_i(132)|0);
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if ($138) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($136|0));
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           break;
          }
         }
         $141 = HEAP32[$123>>2]|0;
         $142 = (($123) + 16|0);
         $143 = (($141) + 92|0);
         $144 = HEAP32[$143>>2]|0;
         $145 = Math_imul($144, $126)|0;
         $146 = (($142) + ($145)|0);
         HEAP32[$146>>2] = $V_2$0;
        }
        $147 = (($V_2$0) + 1)|0;
        $V_2$0 = $147;
       }
       if ((label|0) == 59) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       $22 = ___cxa_find_matching_catch()|0;
       $23 = tempRet0;
       $lpad$phi$index = $22;$lpad$phi$index3 = $23;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     }
    }
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $lpad$phi$index = $24;$lpad$phi$index3 = $25;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z69mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m_GetInOutArgIndexP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfoi($__this,$inoutArgNum) {
 $__this = $__this|0;
 $inoutArgNum = $inoutArgNum|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2473648);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($inoutArgNum|0)<(0);
   if ($4) {
    label = 4;
   } else {
    $5 = (($1) + 12|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6>>>0)>($inoutArgNum>>>0);
    if (!($7)) {
     label = 4;
    }
   }
   if ((label|0) == 4) {
    __THREW__ = 0;
    $8 = (invoke_i(132)|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
   }
   $15 = HEAP32[$1>>2]|0;
   $16 = (($1) + 16|0);
   $17 = (($15) + 92|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = Math_imul($18, $inoutArgNum)|0;
   $20 = (($16) + ($19)|0);
   $21 = HEAP32[$20>>2]|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($21|0);
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m_GetInOutArgNameP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfoi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2473696);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2730,(2397136|0),($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 8|0);
    $8 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = ($index|0)<(0);
     if ($11) {
      label = 6;
     } else {
      $12 = (($8) + 12|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = ($13>>>0)>($index>>>0);
      if (!($14)) {
       label = 6;
      }
     }
     if ((label|0) == 6) {
      __THREW__ = 0;
      $15 = (invoke_i(132)|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($15|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
     }
     $22 = HEAP32[$8>>2]|0;
     $23 = (($8) + 16|0);
     $24 = (($22) + 92|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = Math_imul($25, $index)|0;
     $27 = (($23) + ($26)|0);
     $28 = HEAP32[$27>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      $31 = ($28|0)<(0);
      if ($31) {
       label = 12;
      } else {
       $32 = (($4) + 12|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = ($28>>>0)<($33>>>0);
       if (!($34)) {
        label = 12;
       }
      }
      if ((label|0) == 12) {
       __THREW__ = 0;
       $35 = (invoke_i(132)|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($35|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
      }
      $40 = HEAP32[$4>>2]|0;
      $41 = (($40) + 92|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = Math_imul($42, $28)|0;
      $$sum = (($43) + 16)|0;
      $44 = (($4) + ($$sum)|0);
      $45 = HEAP32[$44>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($45|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       $48 = (invoke_iii(2730,(2397184|0),($45|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if (!($50)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($48|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m_GetInOutArgCountP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2473744);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m_GetInOutArgsP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfoP26mscorlib_System_Object_arr($__this,$args) {
 $__this = $__this|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $V_1$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2473792);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2765,(1167664|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = HEAP32[$0>>2]|0;
   $8 = ($7|0)>(0);
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
   $9 = (($__this) + 8|0);
   $10 = (($args) + 16|0);
   $11 = (($4) + 16|0);
   $12 = (($4) + 12|0);
   $13 = (($args) + 12|0);
   $V_1$01 = 0;
   while(1) {
    $19 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($19|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     break;
    }
    $18 = (($19) + 12|0);
    $20 = HEAP32[$18>>2]|0;
    $21 = ($V_1$01>>>0)<($20>>>0);
    if (!($21)) {
     __THREW__ = 0;
     $22 = (invoke_i(132)|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($22|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
    }
    $27 = HEAP32[$19>>2]|0;
    $28 = (($19) + 16|0);
    $29 = (($27) + 92|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = Math_imul($30, $V_1$01)|0;
    $32 = (($28) + ($31)|0);
    $33 = HEAP32[$32>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($args|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = ($33|0)<(0);
    if ($36) {
     label = 14;
    } else {
     $37 = HEAP32[$13>>2]|0;
     $38 = ($33>>>0)<($37>>>0);
     if (!($38)) {
      label = 14;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     __THREW__ = 0;
     $39 = (invoke_i(132)|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($39|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
    }
    $44 = HEAP32[$args>>2]|0;
    $45 = (($44) + 92|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = Math_imul($46, $33)|0;
    $48 = (($10) + ($47)|0);
    $49 = HEAP32[$48>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($4|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    $52 = HEAP32[$12>>2]|0;
    $53 = ($V_1$01>>>0)<($52>>>0);
    if (!($53)) {
     __THREW__ = 0;
     $54 = (invoke_i(132)|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($54|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vii(3492,($4|0),($49|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    $61 = HEAP32[$4>>2]|0;
    $62 = (($61) + 92|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = Math_imul($63, $V_1$01)|0;
    $65 = (($11) + ($64)|0);
    HEAP32[$65>>2] = $49;
    $66 = (($V_1$01) + 1)|0;
    $67 = HEAP32[$0>>2]|0;
    $68 = ($66|0)<($67|0);
    if ($68) {
     $V_1$01 = $66;
    } else {
     label = 23;
     break;
    }
   }
   if ((label|0) == 23) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   $lpad$phi$index = $14;$lpad$phi$index2 = $15;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 $lpad$phi$index = $16;$lpad$phi$index2 = $17;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker2I17VoidPointerTraits26mscorlib_System_ByteTraitsE6InvokeEPFvPvS3_hES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$3);
 STACKTOP = sp;return (0|0);
}
function __Z67mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m__ctorP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2474312);
 __THREW__ = 0;
 invoke_vi(2415,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 60|0);
  HEAP32[$2>>2] = $type;
  __THREW__ = 0;
  invoke_vi(3799,($type|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2238368|0),($type|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($__this) + 64|0);
    HEAP32[$8>>2] = $5;
    $9 = (($__this) + 68|0);
    HEAP8[$9>>0] = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z61mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m__ctorP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478176);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z77mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_set_IsContextOkP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2474360);
 $0 = (($__this) + 68|0);
 $1 = $value&1;
 HEAP8[$0>>0] = $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_get_ActivationTypeP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2474408);
 $0 = (($__this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $8 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 $3 = (($__this) + 64|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 $5 = (invoke_iii(769,(0|0),($4|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 HEAP32[$0>>2] = $5;
 $8 = $5;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($8|0);
}
function __Z75mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_set_ActivatorP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2474456);
 $0 = (($__this) + 48|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_SetActivationAttributesP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallP26mscorlib_System_Object_arr($__this,$attributes) {
 $__this = $__this|0;
 $attributes = $attributes|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2474504);
 $0 = (($__this) + 52|0);
 HEAP32[$0>>2] = $attributes;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_get_ContextPropertiesP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2474552);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $10 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2304136|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_ii(3469,(2304136|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(2153,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    HEAP32[$0>>2] = $5;
    $10 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($10|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_GetObjectDataP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0;
 var $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2474600);
 __THREW__ = 0;
 invoke_v(648);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = $context;
   $4 = $3;
   $5 = HEAP32[$4>>2]|0;
   $6 = (($3) + 4)|0;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = $0;
   $10 = $9;
   HEAP32[$10>>2] = $5;
   $11 = (($9) + 4)|0;
   $12 = $11;
   HEAP32[$12>>2] = $8;
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   invoke_viii(614,($__this|0),($info|0),($tmpcast$byval_copy|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = (($__this) + 56|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     $V_0$0 = 0;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($16|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     $22 = (invoke_iii(2736,(2231272|0),($16|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     $25 = ($22|0)==(0);
     $$ = $25 ? 0 : $16;
     $V_0$0 = $$;
    }
    $26 = (($__this) + 48|0);
    $27 = HEAP32[$26>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = HEAP32[3034984>>2]|0;
     __THREW__ = 0;
     invoke_viii(621,($info|0),($30|0),($27|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $33 = (($__this) + 52|0);
      $34 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($info|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       $37 = HEAP32[3034992>>2]|0;
       __THREW__ = 0;
       invoke_viii(621,($info|0),($37|0),($34|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if (!($41)) {
         $42 = HEAP32[3035000>>2]|0;
         __THREW__ = 0;
         invoke_viii(621,($info|0),($42|0),(0|0));
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if (!($44)) {
          __THREW__ = 0;
          invoke_vi(3799,($info|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if (!($46)) {
           $47 = HEAP32[3035008>>2]|0;
           __THREW__ = 0;
           invoke_viii(621,($info|0),($47|0),($V_0$0|0));
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if (!($49)) {
            $50 = (($__this) + 64|0);
            $51 = HEAP32[$50>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($info|0));
            $52 = __THREW__; __THREW__ = 0;
            $53 = $52&1;
            if (!($53)) {
             $54 = HEAP32[3035016>>2]|0;
             __THREW__ = 0;
             invoke_viii(621,($info|0),($54|0),($51|0));
             $55 = __THREW__; __THREW__ = 0;
             $56 = $55&1;
             if (!($56)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z69mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetObjectDataP53mscorlib_System_Runtime_Remoting_Messaging_MethodCallP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$0 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond2 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478224);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(649);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($__this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3035280>>2]|0;
    __THREW__ = 0;
    invoke_viii(621,($info|0),($10|0),($7|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = (($__this) + 16|0);
     $14 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $17 = HEAP32[3035288>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($17|0),($14|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = (($__this) + 24|0);
       $21 = HEAP32[$20>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($info|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = HEAP32[3035296>>2]|0;
        __THREW__ = 0;
        invoke_viii(621,($info|0),($24|0),($21|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($__this) + 20|0);
         $28 = HEAP32[$27>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($info|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          $31 = HEAP32[3035304>>2]|0;
          __THREW__ = 0;
          invoke_viii(621,($info|0),($31|0),($28|0));
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           $34 = (($__this) + 32|0);
           $35 = HEAP32[$34>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($info|0));
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if (!($37)) {
            $38 = HEAP32[3035312>>2]|0;
            __THREW__ = 0;
            invoke_viii(621,($info|0),($38|0),($35|0));
            $39 = __THREW__; __THREW__ = 0;
            $40 = $39&1;
            if (!($40)) {
             $41 = (($__this) + 8|0);
             $42 = HEAP32[$41>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($info|0));
             $43 = __THREW__; __THREW__ = 0;
             $44 = $43&1;
             if (!($44)) {
              $45 = HEAP32[3035320>>2]|0;
              __THREW__ = 0;
              invoke_viii(621,($info|0),($45|0),($42|0));
              $46 = __THREW__; __THREW__ = 0;
              $47 = $46&1;
              if (!($47)) {
               $48 = (($__this) + 40|0);
               $49 = HEAP32[$48>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($info|0));
               $50 = __THREW__; __THREW__ = 0;
               $51 = $50&1;
               if (!($51)) {
                $52 = HEAP32[3035328>>2]|0;
                __THREW__ = 0;
                invoke_viii(621,($info|0),($52|0),($49|0));
                $53 = __THREW__; __THREW__ = 0;
                $54 = $53&1;
                if (!($54)) {
                 $55 = (($__this) + 44|0);
                 $56 = HEAP32[$55>>2]|0;
                 $57 = ($56|0)==(0|0);
                 if ($57) {
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($56|0));
                 $60 = __THREW__; __THREW__ = 0;
                 $61 = $60&1;
                 if (!($61)) {
                  __THREW__ = 0;
                  $62 = (invoke_iii(2739,(2314296|0),($56|0))|0);
                  $63 = __THREW__; __THREW__ = 0;
                  $64 = $63&1;
                  if (!($64)) {
                   while(1) {
                    __THREW__ = 0;
                    invoke_vi(3799,($62|0));
                    $98 = __THREW__; __THREW__ = 0;
                    $99 = $98&1;
                    if ($99) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    $100 = (invoke_iii(2741,(2176240|0),($62|0))|0);
                    $101 = __THREW__; __THREW__ = 0;
                    $102 = $101&1;
                    if ($102) {
                     label = 33;
                     break;
                    }
                    if (!($100)) {
                     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 206;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($62|0));
                    $103 = __THREW__; __THREW__ = 0;
                    $104 = $103&1;
                    if ($104) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    $65 = (invoke_iii(2740,(2176176|0),($62|0))|0);
                    $66 = __THREW__; __THREW__ = 0;
                    $67 = $66&1;
                    if ($67) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2307216|0))|0);
                    $68 = __THREW__; __THREW__ = 0;
                    $69 = $68&1;
                    if ($69) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    $70 = (invoke_iii(2766,($65|0),(2307216|0))|0);
                    $71 = __THREW__; __THREW__ = 0;
                    $72 = $71&1;
                    if ($72) {
                     label = 33;
                     break;
                    }
                    $73 = $70;
                    $74 = $73;
                    $75 = HEAP32[$74>>2]|0;
                    $76 = (($73) + 4)|0;
                    $77 = $76;
                    $78 = HEAP32[$77>>2]|0;
                    $79 = $V_0;
                    $80 = $79;
                    HEAP32[$80>>2] = $75;
                    $81 = (($79) + 4)|0;
                    $82 = $81;
                    HEAP32[$82>>2] = $78;
                    __THREW__ = 0;
                    $83 = (invoke_ii(1954,($V_0|0))|0);
                    $84 = __THREW__; __THREW__ = 0;
                    $85 = $84&1;
                    if ($85) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2191608|0))|0);
                    $86 = __THREW__; __THREW__ = 0;
                    $87 = $86&1;
                    if ($87) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    $88 = (invoke_iii(2764,($83|0),(2191608|0))|0);
                    $89 = __THREW__; __THREW__ = 0;
                    $90 = $89&1;
                    if ($90) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    $91 = (invoke_ii(1955,($V_0|0))|0);
                    $92 = __THREW__; __THREW__ = 0;
                    $93 = $92&1;
                    if ($93) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($info|0));
                    $94 = __THREW__; __THREW__ = 0;
                    $95 = $94&1;
                    if ($95) {
                     label = 33;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viii(621,($info|0),($88|0),($91|0));
                    $96 = __THREW__; __THREW__ = 0;
                    $97 = $96&1;
                    if ($97) {
                     label = 33;
                     break;
                    }
                   }
                   if ((label|0) == 33) {
                    $105 = ___cxa_find_matching_catch(348288|0)|0;
                    $106 = tempRet0;
                    $107 = (_llvm_eh_typeid_for((348288|0))|0);
                    $108 = ($106|0)==($107|0);
                    if (!($108)) {
                     $$0 = $105;$$03 = $106;
                     __ZN16StackTraceSentryD2Ev(0);
                     ___resumeException($$0|0);
                     // unreachable;
                    }
                    $109 = (___cxa_begin_catch(($105|0))|0);
                    $110 = HEAP32[$109>>2]|0;
                    __THREW__ = 0;
                    invoke_v(66);
                    $111 = __THREW__; __THREW__ = 0;
                    $112 = $111&1;
                    if ($112) {
                     break;
                    }
                    $__last_unhandled_exception$0 = $110;$leaveInstructions$sroa$0$0 = 0;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2176856|0))|0);
                   $113 = __THREW__; __THREW__ = 0;
                   $114 = $113&1;
                   if (!($114)) {
                    __THREW__ = 0;
                    $115 = (invoke_iii(2735,($62|0),(2176856|0))|0);
                    $116 = __THREW__; __THREW__ = 0;
                    $117 = $116&1;
                    if ($117) {
                     break;
                    }
                    $118 = ($115|0)==(0|0);
                    if ($118) {
                     $cond1 = ($leaveInstructions$sroa$0$0|0)==(206);
                     if ($cond1) {
                      __ZN16StackTraceSentryD2Ev(0);
                      STACKTOP = sp;return;
                     }
                     __THREW__ = 0;
                     invoke_vi(3837,($__last_unhandled_exception$0|0));
                     $119 = __THREW__; __THREW__ = 0;
                     $120 = $119&1;
                     if ($120) {
                      break;
                     }
                     // unreachable;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($115|0));
                    $121 = __THREW__; __THREW__ = 0;
                    $122 = $121&1;
                    if ($122) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vii(3491,(2176768|0),($115|0));
                    $123 = __THREW__; __THREW__ = 0;
                    $124 = $123&1;
                    if ($124) {
                     break;
                    }
                    $cond2 = ($leaveInstructions$sroa$0$0|0)==(206);
                    if ($cond2) {
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                    __THREW__ = 0;
                    invoke_vi(3837,($__last_unhandled_exception$0|0));
                    $125 = __THREW__; __THREW__ = 0;
                    $126 = $125&1;
                    if ($126) {
                     break;
                    }
                    // unreachable;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $58 = ___cxa_find_matching_catch()|0;
 $59 = tempRet0;
 $$0 = $58;$$03 = $59;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z133mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_StringP22mscorlib_System_Object($__this,$name,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $value = $value|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2498312);
 $1 = ($value|0)==(0|0);
 if ($1) {
  HEAP32[$0>>2] = 1284448;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  $2 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viiii(168,($__this|0),($name|0),(0|0),($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($value|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   $11 = (invoke_ii(1782,($value|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    invoke_viiii(168,($__this|0),($name|0),($value|0),($11|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z90mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Runtime_Remoting_Messaging_EnvoyTerminatorSink_m__ctorP62mscorlib_System_Runtime_Remoting_Messaging_EnvoyTerminatorSink($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2475576);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z71mscorlib_System_Runtime_Remoting_Messaging_EnvoyTerminatorSink_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2475624);
 __THREW__ = 0;
 (invoke_ii(2996,(2475808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2475808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2405,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2475808|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2475808 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z82mscorlib_System_Runtime_Remoting_Messaging_IMessage_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Runtime_Remoting_Messaging_IMessageSink_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Runtime_Remoting_Messaging_IMethodCallMessage_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Runtime_Remoting_Messaging_IMethodMessage_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Runtime_Remoting_Messaging_IRemotingFormatter_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z69mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContext_m__ctorP61mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContext($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2477440);
 __THREW__ = 0;
 (invoke_ii(2996,(2478040|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2478040|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2414,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 12|0);
    HEAP32[$7>>2] = $2;
    __THREW__ = 0;
    invoke_vi(1924,($__this|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z74mscorlib_System_Runtime_Remoting_Messaging_CallContextRemotingData_m__ctorP66mscorlib_System_Runtime_Remoting_Messaging_CallContextRemotingData($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2477912);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z77mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContext_m_GetObjectDataP61mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContextP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$0 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $V_0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond2 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2477488);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(650);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($__this) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3035232>>2]|0;
    __THREW__ = 0;
    invoke_viii(621,($info|0),($10|0),($7|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = (($__this) + 8|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      $20 = (invoke_iii(2730,(2311088|0),($14|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        $58 = (invoke_iii(2741,(2176240|0),($20|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 21;
         break;
        }
        if (!($58)) {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 104;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        $23 = (invoke_iii(2740,(2176176|0),($20|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2307216|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2766,($23|0),(2307216|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 21;
         break;
        }
        $31 = $28;
        $32 = $31;
        $33 = HEAP32[$32>>2]|0;
        $34 = (($31) + 4)|0;
        $35 = $34;
        $36 = HEAP32[$35>>2]|0;
        $37 = $V_0;
        $38 = $37;
        HEAP32[$38>>2] = $33;
        $39 = (($37) + 4)|0;
        $40 = $39;
        HEAP32[$40>>2] = $36;
        __THREW__ = 0;
        $41 = (invoke_ii(1954,($V_0|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        $46 = (invoke_iii(2764,($41|0),(2191608|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_ii(1955,($V_0|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_viii(621,($info|0),($46|0),($49|0));
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 21;
         break;
        }
       }
       if ((label|0) == 21) {
        $63 = ___cxa_find_matching_catch(348288|0)|0;
        $64 = tempRet0;
        $65 = (_llvm_eh_typeid_for((348288|0))|0);
        $66 = ($64|0)==($65|0);
        if (!($66)) {
         $$0 = $63;$$03 = $64;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $67 = (___cxa_begin_catch(($63|0))|0);
        $68 = HEAP32[$67>>2]|0;
        __THREW__ = 0;
        invoke_v(66);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
        $__last_unhandled_exception$0 = $68;$leaveInstructions$sroa$0$0 = 0;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2176856|0))|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if (!($72)) {
        __THREW__ = 0;
        $73 = (invoke_iii(2735,($20|0),(2176856|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if (!($75)) {
         $76 = ($73|0)==(0|0);
         if ($76) {
          $cond1 = ($leaveInstructions$sroa$0$0|0)==(104);
          if ($cond1) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          __THREW__ = 0;
          invoke_vi(3837,($__last_unhandled_exception$0|0));
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($73|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if (!($80)) {
          __THREW__ = 0;
          invoke_vii(3491,(2176768|0),($73|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if (!($82)) {
           $cond2 = ($leaveInstructions$sroa$0$0|0)==(104);
           if ($cond2) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           invoke_vi(3837,($__last_unhandled_exception$0|0));
           $83 = __THREW__; __THREW__ = 0;
           $84 = $83&1;
           if (!($84)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 $$0 = $16;$$03 = $17;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo7320($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z92mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContext_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_ArgCountP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478272);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = (($1) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z64mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_ArgsP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478320);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_HasVarArgsP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478368);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2478416|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_iii(2729,(2397712|0),($0|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return 1;
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_InArgCountP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478464);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($__this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2474176|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2474176|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_viii(611,($7|0),($4|0),0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     HEAP32[$0>>2] = $7;
     $12 = $7;
     label = 6;
    }
   }
  }
 } else {
  $12 = $1;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(3799,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   $15 = (invoke_ii(2300,($12|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_InArgsP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478512);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($__this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2474176|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2474176|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_viii(611,($7|0),($4|0),0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     HEAP32[$0>>2] = $7;
     $14 = $7;
     label = 6;
    }
   }
  }
 } else {
  $14 = $1;
  label = 6;
 }
 if ((label|0) == 6) {
  $12 = (($__this) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($14|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   $17 = (invoke_iii(940,($14|0),($13|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($17|0);
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_LogicalCallContextP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478560);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $10 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2477776|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_ii(3469,(2477776|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(2412,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    HEAP32[$0>>2] = $5;
    $10 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($10|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_MethodBaseP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478416);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $5 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 __THREW__ = 0;
 invoke_vi(2416,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 $$pre = HEAP32[$0>>2]|0;
 $5 = $$pre;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($5|0);
}
function __Z69mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_ResolveMethodP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478992);
 __THREW__ = 0;
 invoke_v(651);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    $346 = (invoke_iii(952,0,($__this|0))|0);
    $347 = __THREW__; __THREW__ = 0;
    $348 = $347&1;
    if ($348) {
     break;
    }
    $349 = (($__this) + 28|0);
    HEAP32[$349>>2] = $346;
    $350 = ($346|0)==(0|0);
    if ($350) {
     $351 = (($__this) + 16|0);
     $352 = HEAP32[$351>>2]|0;
     __THREW__ = 0;
     $353 = (invoke_iii(2730,(2478704|0),($__this|0))|0);
     $354 = __THREW__; __THREW__ = 0;
     $355 = $354&1;
     if ($355) {
      break;
     }
     $356 = HEAP32[3035624>>2]|0;
     $357 = HEAP32[3035632>>2]|0;
     __THREW__ = 0;
     $358 = (invoke_iiiiii(89,(0|0),($356|0),($352|0),($357|0),($353|0))|0);
     $359 = __THREW__; __THREW__ = 0;
     $360 = $359&1;
     if ($360) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2488992|0))|0);
     $361 = __THREW__; __THREW__ = 0;
     $362 = $361&1;
     if ($362) {
      break;
     }
     __THREW__ = 0;
     $363 = (invoke_ii(3469,(2488992|0))|0);
     $364 = __THREW__; __THREW__ = 0;
     $365 = $364&1;
     if ($365) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1891,($363|0),($358|0));
     $366 = __THREW__; __THREW__ = 0;
     $367 = $366&1;
     if ($367) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($363|0));
     $368 = __THREW__; __THREW__ = 0;
     $369 = $368&1;
     if ($369) {
      break;
     }
     // unreachable;
    }
   } else {
    __THREW__ = 0;
    $7 = (invoke_iii(951,0,($3|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = ($7|0)==(0|0);
    $11 = (($__this) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    if ($10) {
     $13 = ($12|0)==(0|0);
     if ($13) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP8[((2191608 + 116|0))>>0]|0;
      $22 = ($21<<24>>24)==(0);
      if ($22) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3836,(2191608|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = HEAP32[((2191608 + 80|0))>>2]|0;
      $32 = HEAP32[$31>>2]|0;
      $G_B5_0$0 = $32;
     } else {
      $14 = HEAP32[3035536>>2]|0;
      $15 = HEAP32[3035544>>2]|0;
      __THREW__ = 0;
      $16 = (invoke_iiiii(101,(0|0),($14|0),($12|0),($15|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      } else {
       $G_B5_0$0 = $16;
      }
     }
     $33 = HEAP32[$2>>2]|0;
     $34 = HEAP32[3035552>>2]|0;
     $35 = HEAP32[3035560>>2]|0;
     __THREW__ = 0;
     $36 = (invoke_iiiiii(89,(0|0),($34|0),($G_B5_0$0|0),($35|0),($33|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2488992|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     __THREW__ = 0;
     $41 = (invoke_ii(3469,(2488992|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1891,($41|0),($36|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($41|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $48 = (invoke_iiii(899,0,($12|0),($7|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    $51 = ($48|0)==(0|0);
    if ($51) {
     __THREW__ = 0;
     (invoke_ii(2996,(1168432|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     __THREW__ = 0;
     $54 = (invoke_iii(2765,(1168432|0),5)|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($54|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     $59 = (($54) + 12|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ($60|0)==(0);
     if ($61) {
      __THREW__ = 0;
      $62 = (invoke_i(132)|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($62|0));
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
     }
     $67 = HEAP32[3035568>>2]|0;
     __THREW__ = 0;
     invoke_vii(3492,($54|0),($67|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     $70 = HEAP32[3035568>>2]|0;
     $71 = (($54) + 16|0);
     HEAP32[$71>>2] = $70;
     $72 = HEAP32[$11>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($54|0));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      break;
     }
     $75 = HEAP32[$59>>2]|0;
     $76 = ($75>>>0)<(2);
     if ($76) {
      __THREW__ = 0;
      $77 = (invoke_i(132)|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($77|0));
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($54|0),($72|0));
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      break;
     }
     $84 = HEAP32[$54>>2]|0;
     $85 = (($84) + 92|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($71) + ($86)|0);
     HEAP32[$87>>2] = $72;
     __THREW__ = 0;
     invoke_vi(3799,($54|0));
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      break;
     }
     $90 = HEAP32[$59>>2]|0;
     $91 = ($90>>>0)<(3);
     if ($91) {
      __THREW__ = 0;
      $92 = (invoke_i(132)|0);
      $93 = __THREW__; __THREW__ = 0;
      $94 = $93&1;
      if ($94) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($92|0));
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       break;
      }
     }
     $97 = HEAP32[3035576>>2]|0;
     __THREW__ = 0;
     invoke_vii(3492,($54|0),($97|0));
     $98 = __THREW__; __THREW__ = 0;
     $99 = $98&1;
     if ($99) {
      break;
     }
     $100 = HEAP32[3035576>>2]|0;
     $101 = HEAP32[$54>>2]|0;
     $102 = (($101) + 92|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = $103 << 1;
     $105 = (($71) + ($104)|0);
     HEAP32[$105>>2] = $100;
     __THREW__ = 0;
     invoke_vi(3799,($7|0));
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if ($107) {
      break;
     }
     __THREW__ = 0;
     $108 = (invoke_iii(2730,(2150320|0),($7|0))|0);
     $109 = __THREW__; __THREW__ = 0;
     $110 = $109&1;
     if ($110) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($54|0));
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      break;
     }
     $113 = HEAP32[$59>>2]|0;
     $114 = ($113>>>0)<(4);
     if ($114) {
      __THREW__ = 0;
      $115 = (invoke_i(132)|0);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($115|0));
      $118 = __THREW__; __THREW__ = 0;
      $119 = $118&1;
      if ($119) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($54|0),($108|0));
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if ($121) {
      break;
     }
     $122 = HEAP32[$54>>2]|0;
     $123 = (($122) + 92|0);
     $124 = HEAP32[$123>>2]|0;
     $125 = ($124*3)|0;
     $126 = (($71) + ($125)|0);
     HEAP32[$126>>2] = $108;
     __THREW__ = 0;
     invoke_vi(3799,($54|0));
     $127 = __THREW__; __THREW__ = 0;
     $128 = $127&1;
     if ($128) {
      break;
     }
     $129 = HEAP32[$59>>2]|0;
     $130 = ($129>>>0)<(5);
     if ($130) {
      __THREW__ = 0;
      $131 = (invoke_i(132)|0);
      $132 = __THREW__; __THREW__ = 0;
      $133 = $132&1;
      if ($133) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($131|0));
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if ($135) {
       break;
      }
     }
     $136 = HEAP32[3035584>>2]|0;
     __THREW__ = 0;
     invoke_vii(3492,($54|0),($136|0));
     $137 = __THREW__; __THREW__ = 0;
     $138 = $137&1;
     if ($138) {
      break;
     }
     $139 = HEAP32[3035584>>2]|0;
     $140 = HEAP32[$54>>2]|0;
     $141 = (($140) + 92|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = $142 << 2;
     $144 = (($71) + ($143)|0);
     HEAP32[$144>>2] = $139;
     __THREW__ = 0;
     $145 = (invoke_iii(639,(0|0),($54|0))|0);
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2488992|0))|0);
     $148 = __THREW__; __THREW__ = 0;
     $149 = $148&1;
     if ($149) {
      break;
     }
     __THREW__ = 0;
     $150 = (invoke_ii(3469,(2488992|0))|0);
     $151 = __THREW__; __THREW__ = 0;
     $152 = $151&1;
     if ($152) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1891,($150|0),($145|0));
     $153 = __THREW__; __THREW__ = 0;
     $154 = $153&1;
     if ($154) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($150|0));
     $155 = __THREW__; __THREW__ = 0;
     $156 = $155&1;
     if ($156) {
      break;
     }
     // unreachable;
    }
    $157 = (($__this) + 16|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = (($__this) + 24|0);
    $160 = HEAP32[$159>>2]|0;
    __THREW__ = 0;
    $161 = (invoke_iiiii(146,0,($48|0),($158|0),($160|0))|0);
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if ($163) {
     break;
    }
    $164 = (($__this) + 28|0);
    HEAP32[$164>>2] = $161;
    $165 = ($161|0)==(0|0);
    if ($165) {
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $166 = __THREW__; __THREW__ = 0;
     $167 = $166&1;
     if ($167) {
      break;
     }
     __THREW__ = 0;
     $168 = (invoke_iii(2765,(1167664|0),4)|0);
     $169 = __THREW__; __THREW__ = 0;
     $170 = $169&1;
     if ($170) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($168|0));
     $171 = __THREW__; __THREW__ = 0;
     $172 = $171&1;
     if ($172) {
      break;
     }
     $173 = (($168) + 12|0);
     $174 = HEAP32[$173>>2]|0;
     $175 = ($174|0)==(0);
     if ($175) {
      __THREW__ = 0;
      $176 = (invoke_i(132)|0);
      $177 = __THREW__; __THREW__ = 0;
      $178 = $177&1;
      if ($178) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($176|0));
      $179 = __THREW__; __THREW__ = 0;
      $180 = $179&1;
      if ($180) {
       break;
      }
     }
     $181 = HEAP32[3035592>>2]|0;
     __THREW__ = 0;
     invoke_vii(3492,($168|0),($181|0));
     $182 = __THREW__; __THREW__ = 0;
     $183 = $182&1;
     if ($183) {
      break;
     }
     $184 = HEAP32[3035592>>2]|0;
     $185 = (($168) + 16|0);
     HEAP32[$185>>2] = $184;
     $186 = HEAP32[$157>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($168|0));
     $187 = __THREW__; __THREW__ = 0;
     $188 = $187&1;
     if ($188) {
      break;
     }
     $189 = HEAP32[$173>>2]|0;
     $190 = ($189>>>0)<(2);
     if ($190) {
      __THREW__ = 0;
      $191 = (invoke_i(132)|0);
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if ($193) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($191|0));
      $194 = __THREW__; __THREW__ = 0;
      $195 = $194&1;
      if ($195) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($168|0),($186|0));
     $196 = __THREW__; __THREW__ = 0;
     $197 = $196&1;
     if ($197) {
      break;
     }
     $198 = HEAP32[$168>>2]|0;
     $199 = (($198) + 92|0);
     $200 = HEAP32[$199>>2]|0;
     $201 = (($185) + ($200)|0);
     HEAP32[$201>>2] = $186;
     __THREW__ = 0;
     invoke_vi(3799,($168|0));
     $202 = __THREW__; __THREW__ = 0;
     $203 = $202&1;
     if ($203) {
      break;
     }
     $204 = HEAP32[$173>>2]|0;
     $205 = ($204>>>0)<(3);
     if ($205) {
      __THREW__ = 0;
      $206 = (invoke_i(132)|0);
      $207 = __THREW__; __THREW__ = 0;
      $208 = $207&1;
      if ($208) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($206|0));
      $209 = __THREW__; __THREW__ = 0;
      $210 = $209&1;
      if ($210) {
       break;
      }
     }
     $211 = HEAP32[3035600>>2]|0;
     __THREW__ = 0;
     invoke_vii(3492,($168|0),($211|0));
     $212 = __THREW__; __THREW__ = 0;
     $213 = $212&1;
     if ($213) {
      break;
     }
     $214 = HEAP32[3035600>>2]|0;
     $215 = HEAP32[$168>>2]|0;
     $216 = (($215) + 92|0);
     $217 = HEAP32[$216>>2]|0;
     $218 = $217 << 1;
     $219 = (($185) + ($218)|0);
     HEAP32[$219>>2] = $214;
     __THREW__ = 0;
     invoke_vi(3799,($168|0));
     $220 = __THREW__; __THREW__ = 0;
     $221 = $220&1;
     if ($221) {
      break;
     }
     $222 = HEAP32[$173>>2]|0;
     $223 = ($222>>>0)<(4);
     if ($223) {
      __THREW__ = 0;
      $224 = (invoke_i(132)|0);
      $225 = __THREW__; __THREW__ = 0;
      $226 = $225&1;
      if ($226) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($224|0));
      $227 = __THREW__; __THREW__ = 0;
      $228 = $227&1;
      if ($228) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($168|0),($48|0));
     $229 = __THREW__; __THREW__ = 0;
     $230 = $229&1;
     if ($230) {
      break;
     }
     $231 = HEAP32[$168>>2]|0;
     $232 = (($231) + 92|0);
     $233 = HEAP32[$232>>2]|0;
     $234 = ($233*3)|0;
     $235 = (($185) + ($234)|0);
     HEAP32[$235>>2] = $48;
     __THREW__ = 0;
     $236 = (invoke_iii(638,(0|0),($168|0))|0);
     $237 = __THREW__; __THREW__ = 0;
     $238 = $237&1;
     if ($238) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2488992|0))|0);
     $239 = __THREW__; __THREW__ = 0;
     $240 = $239&1;
     if ($240) {
      break;
     }
     __THREW__ = 0;
     $241 = (invoke_ii(3469,(2488992|0))|0);
     $242 = __THREW__; __THREW__ = 0;
     $243 = $242&1;
     if ($243) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1891,($241|0),($236|0));
     $244 = __THREW__; __THREW__ = 0;
     $245 = $244&1;
     if ($245) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($241|0));
     $246 = __THREW__; __THREW__ = 0;
     $247 = $246&1;
     if ($247) {
      break;
     }
     // unreachable;
    }
    $248 = ($48|0)==($7|0);
    if (!($248)) {
     __THREW__ = 0;
     invoke_vi(3799,($48|0));
     $249 = __THREW__; __THREW__ = 0;
     $250 = $249&1;
     if ($250) {
      break;
     }
     __THREW__ = 0;
     $251 = (invoke_iii(2734,(2234184|0),($48|0))|0);
     $252 = __THREW__; __THREW__ = 0;
     $253 = $252&1;
     if ($253) {
      break;
     }
     if ($251) {
      __THREW__ = 0;
      invoke_vi(3799,($7|0));
      $254 = __THREW__; __THREW__ = 0;
      $255 = $254&1;
      if ($255) {
       break;
      }
      __THREW__ = 0;
      $256 = (invoke_iii(2734,(2234184|0),($7|0))|0);
      $257 = __THREW__; __THREW__ = 0;
      $258 = $257&1;
      if ($258) {
       break;
      }
      if (!($256)) {
       $259 = HEAP32[$164>>2]|0;
       __THREW__ = 0;
       $260 = (invoke_iiii(902,0,($7|0),($259|0))|0);
       $261 = __THREW__; __THREW__ = 0;
       $262 = $261&1;
       if ($262) {
        break;
       }
       HEAP32[$164>>2] = $260;
       $263 = ($260|0)==(0|0);
       if ($263) {
        __THREW__ = 0;
        (invoke_ii(2996,(1167664|0))|0);
        $264 = __THREW__; __THREW__ = 0;
        $265 = $264&1;
        if ($265) {
         break;
        }
        __THREW__ = 0;
        $266 = (invoke_iii(2765,(1167664|0),4)|0);
        $267 = __THREW__; __THREW__ = 0;
        $268 = $267&1;
        if ($268) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($266|0));
        $269 = __THREW__; __THREW__ = 0;
        $270 = $269&1;
        if ($270) {
         break;
        }
        $271 = (($266) + 12|0);
        $272 = HEAP32[$271>>2]|0;
        $273 = ($272|0)==(0);
        if ($273) {
         __THREW__ = 0;
         $274 = (invoke_i(132)|0);
         $275 = __THREW__; __THREW__ = 0;
         $276 = $275&1;
         if ($276) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($274|0));
         $277 = __THREW__; __THREW__ = 0;
         $278 = $277&1;
         if ($278) {
          break;
         }
        }
        $279 = HEAP32[3035608>>2]|0;
        __THREW__ = 0;
        invoke_vii(3492,($266|0),($279|0));
        $280 = __THREW__; __THREW__ = 0;
        $281 = $280&1;
        if ($281) {
         break;
        }
        $282 = HEAP32[3035608>>2]|0;
        $283 = (($266) + 16|0);
        HEAP32[$283>>2] = $282;
        $284 = HEAP32[$157>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($266|0));
        $285 = __THREW__; __THREW__ = 0;
        $286 = $285&1;
        if ($286) {
         break;
        }
        $287 = HEAP32[$271>>2]|0;
        $288 = ($287>>>0)<(2);
        if ($288) {
         __THREW__ = 0;
         $289 = (invoke_i(132)|0);
         $290 = __THREW__; __THREW__ = 0;
         $291 = $290&1;
         if ($291) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($289|0));
         $292 = __THREW__; __THREW__ = 0;
         $293 = $292&1;
         if ($293) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($266|0),($284|0));
        $294 = __THREW__; __THREW__ = 0;
        $295 = $294&1;
        if ($295) {
         break;
        }
        $296 = HEAP32[$266>>2]|0;
        $297 = (($296) + 92|0);
        $298 = HEAP32[$297>>2]|0;
        $299 = (($283) + ($298)|0);
        HEAP32[$299>>2] = $284;
        __THREW__ = 0;
        invoke_vi(3799,($266|0));
        $300 = __THREW__; __THREW__ = 0;
        $301 = $300&1;
        if ($301) {
         break;
        }
        $302 = HEAP32[$271>>2]|0;
        $303 = ($302>>>0)<(3);
        if ($303) {
         __THREW__ = 0;
         $304 = (invoke_i(132)|0);
         $305 = __THREW__; __THREW__ = 0;
         $306 = $305&1;
         if ($306) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($304|0));
         $307 = __THREW__; __THREW__ = 0;
         $308 = $307&1;
         if ($308) {
          break;
         }
        }
        $309 = HEAP32[3035616>>2]|0;
        __THREW__ = 0;
        invoke_vii(3492,($266|0),($309|0));
        $310 = __THREW__; __THREW__ = 0;
        $311 = $310&1;
        if ($311) {
         break;
        }
        $312 = HEAP32[3035616>>2]|0;
        $313 = HEAP32[$266>>2]|0;
        $314 = (($313) + 92|0);
        $315 = HEAP32[$314>>2]|0;
        $316 = $315 << 1;
        $317 = (($283) + ($316)|0);
        HEAP32[$317>>2] = $312;
        __THREW__ = 0;
        invoke_vi(3799,($266|0));
        $318 = __THREW__; __THREW__ = 0;
        $319 = $318&1;
        if ($319) {
         break;
        }
        $320 = HEAP32[$271>>2]|0;
        $321 = ($320>>>0)<(4);
        if ($321) {
         __THREW__ = 0;
         $322 = (invoke_i(132)|0);
         $323 = __THREW__; __THREW__ = 0;
         $324 = $323&1;
         if ($324) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($322|0));
         $325 = __THREW__; __THREW__ = 0;
         $326 = $325&1;
         if ($326) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($266|0),($7|0));
        $327 = __THREW__; __THREW__ = 0;
        $328 = $327&1;
        if ($328) {
         break;
        }
        $329 = HEAP32[$266>>2]|0;
        $330 = (($329) + 92|0);
        $331 = HEAP32[$330>>2]|0;
        $332 = ($331*3)|0;
        $333 = (($283) + ($332)|0);
        HEAP32[$333>>2] = $7;
        __THREW__ = 0;
        $334 = (invoke_iii(638,(0|0),($266|0))|0);
        $335 = __THREW__; __THREW__ = 0;
        $336 = $335&1;
        if ($336) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2488992|0))|0);
        $337 = __THREW__; __THREW__ = 0;
        $338 = $337&1;
        if ($338) {
         break;
        }
        __THREW__ = 0;
        $339 = (invoke_ii(3469,(2488992|0))|0);
        $340 = __THREW__; __THREW__ = 0;
        $341 = $340&1;
        if ($341) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(1891,($339|0),($334|0));
        $342 = __THREW__; __THREW__ = 0;
        $343 = $342&1;
        if ($343) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3837,($339|0));
        $344 = __THREW__; __THREW__ = 0;
        $345 = $344&1;
        if ($345) {
         break;
        }
        // unreachable;
       }
      }
     }
    }
   }
   $370 = (($__this) + 28|0);
   $371 = HEAP32[$370>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($371|0));
   $372 = __THREW__; __THREW__ = 0;
   $373 = $372&1;
   if (!($373)) {
    __THREW__ = 0;
    $374 = (invoke_iii(2734,(2410944|0),($371|0))|0);
    $375 = __THREW__; __THREW__ = 0;
    $376 = $375&1;
    if (!($376)) {
     if (!($374)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $377 = HEAP32[$370>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($377|0));
     $378 = __THREW__; __THREW__ = 0;
     $379 = $378&1;
     if (!($379)) {
      __THREW__ = 0;
      $380 = (invoke_iii(2734,(2410896|0),($377|0))|0);
      $381 = __THREW__; __THREW__ = 0;
      $382 = $381&1;
      if (!($382)) {
       if (!($380)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       $383 = (invoke_ii(2314,($__this|0))|0);
       $384 = __THREW__; __THREW__ = 0;
       $385 = $384&1;
       if (!($385)) {
        $386 = ($383|0)==(0|0);
        if ($386) {
         __THREW__ = 0;
         (invoke_ii(2996,(2488992|0))|0);
         $387 = __THREW__; __THREW__ = 0;
         $388 = $387&1;
         if ($388) {
          break;
         }
         __THREW__ = 0;
         $389 = (invoke_ii(3469,(2488992|0))|0);
         $390 = __THREW__; __THREW__ = 0;
         $391 = $390&1;
         if ($391) {
          break;
         }
         $392 = HEAP32[3035640>>2]|0;
         __THREW__ = 0;
         invoke_vii(1891,($389|0),($392|0));
         $393 = __THREW__; __THREW__ = 0;
         $394 = $393&1;
         if ($394) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3837,($389|0));
         $395 = __THREW__; __THREW__ = 0;
         $396 = $395&1;
         if ($396) {
          break;
         }
         // unreachable;
        }
        $397 = HEAP32[$370>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2414216|0))|0);
        $398 = __THREW__; __THREW__ = 0;
        $399 = $398&1;
        if (!($399)) {
         __THREW__ = 0;
         $400 = (invoke_iii(2764,($397|0),(2414216|0))|0);
         $401 = __THREW__; __THREW__ = 0;
         $402 = $401&1;
         if (!($402)) {
          __THREW__ = 0;
          $403 = (invoke_ii(2314,($__this|0))|0);
          $404 = __THREW__; __THREW__ = 0;
          $405 = $404&1;
          if (!($405)) {
           __THREW__ = 0;
           invoke_vi(3799,($400|0));
           $406 = __THREW__; __THREW__ = 0;
           $407 = $406&1;
           if (!($407)) {
            __THREW__ = 0;
            $408 = (invoke_iiii(1645,(2413512|0),($400|0),($403|0))|0);
            $409 = __THREW__; __THREW__ = 0;
            $410 = $409&1;
            if (!($410)) {
             HEAP32[$370>>2] = $408;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z70mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_MethodNameP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478608);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $10 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 $3 = (($__this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  $7 = (invoke_iii(2730,(2233608|0),($4|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   HEAP32[$0>>2] = $7;
   $10 = $7;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($10|0);
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_MethodSignatureP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478656);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $68 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($68|0);
 }
 $3 = (($__this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $68 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($68|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  __THREW__ = 0;
  $8 = (invoke_iii(2730,(2397136|0),($4|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __THREW__ = 0;
   invoke_vi(3799,($8|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = (($8) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(1169184|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     $17 = (invoke_iii(2765,(1169184|0),($14|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      HEAP32[$0>>2] = $17;
      $V_1$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($8|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        break;
       }
       $64 = HEAP32[$13>>2]|0;
       $65 = ($V_1$0|0)<($64|0);
       $42 = HEAP32[$0>>2]|0;
       if (!($65)) {
        $68 = $42;
        label = 26;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($8|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        break;
       }
       $24 = HEAP32[$13>>2]|0;
       $25 = ($V_1$0>>>0)<($24>>>0);
       if (!($25)) {
        __THREW__ = 0;
        $26 = (invoke_i(132)|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($26|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break;
        }
       }
       $31 = HEAP32[$8>>2]|0;
       $32 = (($31) + 92|0);
       $33 = HEAP32[$32>>2]|0;
       $34 = Math_imul($33, $V_1$0)|0;
       $$sum = (($34) + 16)|0;
       $35 = (($8) + ($$sum)|0);
       $36 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($36|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       __THREW__ = 0;
       $39 = (invoke_iii(2730,(2397472|0),($36|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $45 = (($42) + 12|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = ($V_1$0>>>0)<($46>>>0);
       if (!($47)) {
        __THREW__ = 0;
        $48 = (invoke_i(132)|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($48|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($42|0),($39|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       $55 = HEAP32[$42>>2]|0;
       $56 = (($42) + 16|0);
       $57 = (($55) + 92|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = Math_imul($58, $V_1$0)|0;
       $60 = (($56) + ($59)|0);
       HEAP32[$60>>2] = $39;
       $61 = (($V_1$0) + 1)|0;
       $V_1$0 = $61;
      }
      if ((label|0) == 26) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($68|0);
      }
      $20 = ___cxa_find_matching_catch()|0;
      $21 = tempRet0;
      $lpad$phi$index = $20;$lpad$phi$index2 = $21;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    }
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $lpad$phi$index = $22;$lpad$phi$index2 = $23;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_TypeNameP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478704);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $15 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($15|0);
 }
 $3 = (($__this) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  $7 = (invoke_iii(2730,(2242504|0),($4|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   invoke_vi(3799,($7|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(2730,(2238368|0),($7|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     HEAP32[$0>>2] = $12;
     $15 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($15|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_UriP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478752);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z62mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetArgP53mscorlib_System_Runtime_Remoting_Messaging_MethodCalli($__this,$argNum) {
 $__this = $__this|0;
 $argNum = $argNum|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478800);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($argNum|0)<(0);
   if ($4) {
    label = 4;
   } else {
    $5 = (($1) + 12|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6>>>0)>($argNum>>>0);
    if (!($7)) {
     label = 4;
    }
   }
   if ((label|0) == 4) {
    __THREW__ = 0;
    $8 = (invoke_i(132)|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
   }
   $15 = HEAP32[$1>>2]|0;
   $16 = (($1) + 16|0);
   $17 = (($15) + 92|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = Math_imul($18, $argNum)|0;
   $20 = (($16) + ($19)|0);
   $21 = HEAP32[$20>>2]|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($21|0);
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetArgNameP53mscorlib_System_Runtime_Remoting_Messaging_MethodCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478848);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2730,(2397136|0),($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = ($index|0)<(0);
     if ($9) {
      label = 6;
     } else {
      $10 = (($4) + 12|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ($11>>>0)>($index>>>0);
      if (!($12)) {
       label = 6;
      }
     }
     if ((label|0) == 6) {
      __THREW__ = 0;
      $13 = (invoke_i(132)|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($13|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
     }
     $20 = HEAP32[$4>>2]|0;
     $21 = (($20) + 92|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = Math_imul($22, $index)|0;
     $$sum = (($23) + 16)|0;
     $24 = (($4) + ($$sum)|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      $28 = (invoke_iii(2730,(2397184|0),($25|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($28|0);
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetInArgP53mscorlib_System_Runtime_Remoting_Messaging_MethodCalli($__this,$argNum) {
 $__this = $__this|0;
 $argNum = $argNum|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478896);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($__this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2474176|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2474176|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_viii(611,($7|0),($4|0),0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     HEAP32[$0>>2] = $7;
     $14 = $7;
     label = 6;
    }
   }
  }
 } else {
  $14 = $1;
  label = 6;
 }
 if ((label|0) == 6) {
  $12 = (($__this) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($14|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   $17 = (invoke_iii(938,($14|0),($argNum|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    invoke_vi(3799,($13|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = ($17|0)<(0);
     if (!($22)) {
      $23 = (($13) + 12|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($17>>>0)<($24>>>0);
      if ($25) {
       $33 = HEAP32[$13>>2]|0;
       $34 = (($13) + 16|0);
       $35 = (($33) + 92|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = Math_imul($36, $17)|0;
       $38 = (($34) + ($37)|0);
       $39 = HEAP32[$38>>2]|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($39|0);
      }
     }
     __THREW__ = 0;
     $26 = (invoke_i(132)|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __THREW__ = 0;
      invoke_vi(3302,($26|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $33 = HEAP32[$13>>2]|0;
       $34 = (($13) + 16|0);
       $35 = (($33) + 92|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = Math_imul($36, $17)|0;
       $38 = (($34) + ($37)|0);
       $39 = HEAP32[$38>>2]|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($39|0);
      }
     }
    }
   }
  }
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($31|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetInArgNameP53mscorlib_System_Runtime_Remoting_Messaging_MethodCalli($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2478944);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (($__this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2474176|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2474176|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_viii(611,($7|0),($4|0),0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     HEAP32[$0>>2] = $7;
     $12 = $7;
     label = 6;
    }
   }
  }
 } else {
  $12 = $1;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(3799,($12|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   $15 = (invoke_iiii(1642,(2473696|0),($12|0),($index|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Runtime_Remoting_RemotingServices_m_GetServerTypeForUriP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$URI) {
 $__this = $__this|0;
 $URI = $URI|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489336);
 __THREW__ = 0;
 $0 = (invoke_iii(953,0,($URI|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2491640|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2735,($0|0),(2491640|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = ($5|0)==(0|0);
    if ($8) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_ii(2329,($5|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $$0 = $13;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_CastToP53mscorlib_System_Runtime_Remoting_Messaging_MethodCallP22mscorlib_System_StringP20mscorlib_System_Type($__this,$clientType,$serverType) {
 $__this = $__this|0;
 $clientType = $clientType|0;
 $serverType = $serverType|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$in = 0, $V_4$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2479040);
 __THREW__ = 0;
 $0 = (invoke_iii(945,0,($clientType|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(3799,($serverType|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2730,(2150320|0),($serverType|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_iiii(574,(0|0),($0|0),($5|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      if ($8) {
       $$0 = $serverType;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($serverType|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_iii(2730,(2235944|0),($serverType|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $V_0$0$in = $19;
        while(1) {
         $33 = ($V_0$0$in|0)==(0|0);
         if ($33) {
          label = 19;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$0$in|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $22 = (invoke_iii(2730,(2150320|0),($V_0$0$in|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if ($24) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $25 = (invoke_iiii(574,(0|0),($0|0),($22|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          label = 7;
          break;
         }
         if ($25) {
          $$0 = $V_0$0$in;
          label = 32;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($V_0$0$in|0));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $30 = (invoke_iii(2730,(2235944|0),($V_0$0$in|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          label = 7;
          break;
         } else {
          $V_0$0$in = $30;
         }
        }
        if ((label|0) == 7) {
         $13 = ___cxa_find_matching_catch()|0;
         $14 = tempRet0;
         $lpad$phi$index = $13;$lpad$phi$index3 = $14;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 19) {
         __THREW__ = 0;
         invoke_vi(3799,($serverType|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break;
         }
         __THREW__ = 0;
         $38 = (invoke_iii(2730,(2239448|0),($serverType|0))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break;
         }
         $41 = (($38) + 12|0);
         $V_4$0 = 0;
         while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($38|0));
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           label = 6;
           break;
          }
          $66 = HEAP32[$41>>2]|0;
          $67 = ($V_4$0|0)<($66|0);
          if (!($67)) {
           $$0 = 0;
           label = 32;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($38|0));
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if ($69) {
           label = 6;
           break;
          }
          $42 = HEAP32[$41>>2]|0;
          $43 = ($V_4$0>>>0)<($42>>>0);
          if (!($43)) {
           __THREW__ = 0;
           $44 = (invoke_i(132)|0);
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            label = 6;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($44|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if ($48) {
            label = 6;
            break;
           }
          }
          $49 = HEAP32[$38>>2]|0;
          $50 = (($49) + 92|0);
          $51 = HEAP32[$50>>2]|0;
          $52 = Math_imul($51, $V_4$0)|0;
          $$sum = (($52) + 16)|0;
          $53 = (($38) + ($$sum)|0);
          $54 = HEAP32[$53>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($54|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           label = 6;
           break;
          }
          __THREW__ = 0;
          $57 = (invoke_iii(2730,(2150320|0),($54|0))|0);
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if ($59) {
           label = 6;
           break;
          }
          __THREW__ = 0;
          $60 = (invoke_iiii(574,(0|0),($0|0),($57|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if ($62) {
           label = 6;
           break;
          }
          $63 = (($V_4$0) + 1)|0;
          if ($60) {
           $$0 = $54;
           label = 32;
           break;
          } else {
           $V_4$0 = $63;
          }
         }
         if ((label|0) == 6) {
          $11 = ___cxa_find_matching_catch()|0;
          $12 = tempRet0;
          $lpad$phi$index = $11;$lpad$phi$index3 = $12;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 32) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        else if ((label|0) == 32) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Runtime_Remoting_RemotingServices_m_GetMethodBaseFromNameP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringP24mscorlib_System_Type_arr($__this,$type,$methodName,$signature) {
 $__this = $__this|0;
 $type = $type|0;
 $methodName = $methodName|0;
 $signature = $signature|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0$in = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489432);
 __THREW__ = 0;
 invoke_v(652);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($type|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2734,(2234184|0),($type|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if ($4) {
      __THREW__ = 0;
      $9 = (invoke_iiiii(147,0,($type|0),($methodName|0),($signature|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break;
      } else {
       $$0 = $9;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $12 = ($signature|0)!=(0|0);
     if ($12) {
      __THREW__ = 0;
      (invoke_ii(2996,(2491144|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = HEAP8[((2491144 + 116|0))>>0]|0;
      $36 = ($35<<24>>24)==(0);
      if ($36) {
       __THREW__ = 0;
       (invoke_ii(2996,(2491144|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2491144|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3836,(2491144|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2491144|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      $45 = HEAP32[((2491144 + 80|0))>>2]|0;
      $46 = (($45) + 20|0);
      $47 = HEAP32[$46>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($type|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      __THREW__ = 0;
      $50 = (invoke_iiiiiiii(120,(2236432|0),($type|0),($methodName|0),($47|0),(0|0),($signature|0),(0|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      } else {
       $V_0$0$in = $50;
      }
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2491144|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      $15 = HEAP8[((2491144 + 116|0))>>0]|0;
      $16 = ($15<<24>>24)==(0);
      if ($16) {
       __THREW__ = 0;
       (invoke_ii(2996,(2491144|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2491144|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3836,(2491144|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2491144|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      $25 = HEAP32[((2491144 + 80|0))>>2]|0;
      $26 = (($25) + 20|0);
      $27 = HEAP32[$26>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($type|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      $30 = (invoke_iiiii(323,(2236384|0),($type|0),($methodName|0),($27|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      } else {
       $V_0$0$in = $30;
      }
     }
     $53 = ($V_0$0$in|0)==(0|0);
     if (!($53)) {
      $$0 = $V_0$0$in;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $54 = HEAP32[3036616>>2]|0;
     __THREW__ = 0;
     $55 = (invoke_iiii(574,(0|0),($methodName|0),($54|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if (!($57)) {
      if ($55) {
       __THREW__ = 0;
       (invoke_ii(2996,(2491144|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
       $60 = HEAP8[((2491144 + 116|0))>>0]|0;
       $61 = ($60<<24>>24)==(0);
       if ($61) {
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3836,(2491144|0));
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2491144|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       $70 = HEAP32[((2491144 + 80|0))>>2]|0;
       $71 = (($70) + 24|0);
       $72 = HEAP32[$71>>2]|0;
       $$0 = $72;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $73 = HEAP32[3036624>>2]|0;
      __THREW__ = 0;
      $74 = (invoke_iiii(574,(0|0),($methodName|0),($73|0))|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if (!($76)) {
       if ($74) {
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         break;
        }
        $79 = HEAP8[((2491144 + 116|0))>>0]|0;
        $80 = ($79<<24>>24)==(0);
        if ($80) {
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3836,(2491144|0));
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         break;
        }
        $89 = HEAP32[((2491144 + 80|0))>>2]|0;
        $90 = (($89) + 28|0);
        $91 = HEAP32[$90>>2]|0;
        $$0 = $91;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       if ($12) {
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if ($128) {
         break;
        }
        $129 = HEAP8[((2491144 + 116|0))>>0]|0;
        $130 = ($129<<24>>24)==(0);
        if ($130) {
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $131 = __THREW__; __THREW__ = 0;
         $132 = $131&1;
         if ($132) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3836,(2491144|0));
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if ($136) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $137 = __THREW__; __THREW__ = 0;
        $138 = $137&1;
        if ($138) {
         break;
        }
        $139 = HEAP32[((2491144 + 80|0))>>2]|0;
        $140 = (($139) + 20|0);
        $141 = HEAP32[$140>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($type|0));
        $142 = __THREW__; __THREW__ = 0;
        $143 = $142&1;
        if ($143) {
         break;
        }
        __THREW__ = 0;
        $144 = (invoke_iiiiiii(131,(2236912|0),($type|0),($141|0),(0|0),($signature|0),(0|0))|0);
        $145 = __THREW__; __THREW__ = 0;
        $146 = $145&1;
        if ($146) {
         break;
        }
        $$0 = $144;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2491144|0))|0);
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if (!($93)) {
        $94 = HEAP8[((2491144 + 116|0))>>0]|0;
        $95 = ($94<<24>>24)==(0);
        if ($95) {
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $98 = __THREW__; __THREW__ = 0;
         $99 = $98&1;
         if ($99) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3836,(2491144|0));
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $102 = __THREW__; __THREW__ = 0;
        $103 = $102&1;
        if (!($103)) {
         $104 = HEAP32[((2491144 + 80|0))>>2]|0;
         $105 = (($104) + 20|0);
         $106 = HEAP32[$105>>2]|0;
         __THREW__ = 0;
         (invoke_ii(2996,(2242320|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if (!($108)) {
          $109 = HEAP8[((2242320 + 116|0))>>0]|0;
          $110 = ($109<<24>>24)==(0);
          if ($110) {
           __THREW__ = 0;
           (invoke_ii(2996,(2242320|0))|0);
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2242320|0))|0);
           $113 = __THREW__; __THREW__ = 0;
           $114 = $113&1;
           if ($114) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3836,(2242320|0));
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2242320|0))|0);
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if (!($118)) {
           $119 = HEAP32[((2242320 + 80|0))>>2]|0;
           $120 = (($119) + 8|0);
           $121 = HEAP32[$120>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($type|0));
           $122 = __THREW__; __THREW__ = 0;
           $123 = $122&1;
           if (!($123)) {
            __THREW__ = 0;
            $124 = (invoke_iiiiiii(131,(2236912|0),($type|0),($106|0),(0|0),($121|0),(0|0))|0);
            $125 = __THREW__; __THREW__ = 0;
            $126 = $125&1;
            if (!($126)) {
             $$0 = $124;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Runtime_Remoting_RemotingServices_m_GetVirtualMethodP22mscorlib_System_ObjectP20mscorlib_System_TypeP37mscorlib_System_Reflection_MethodBase($__this,$type,$method) {
 $__this = $__this|0;
 $type = $type|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489176);
 $0 = HEAP32[2489224>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2489232|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2489224>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($type|0),($method|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z82mscorlib_System_Runtime_Remoting_RemotingServices_m_GetMethodBaseFromMethodMessageP22mscorlib_System_ObjectS0_($__this,$msg) {
 $__this = $__this|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489384);
 __THREW__ = 0;
 invoke_v(653);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($msg|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2739,(2476816|0),($msg|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(769,(0|0),($4|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      $10 = ($7|0)==(0|0);
      if ($10) {
       __THREW__ = 0;
       invoke_vi(3799,($msg|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       $15 = (invoke_iii(2739,(2476816|0),($msg|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
       $18 = HEAP32[3036552>>2]|0;
       $19 = HEAP32[3036560>>2]|0;
       __THREW__ = 0;
       $20 = (invoke_iiiii(101,(0|0),($18|0),($15|0),($19|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2488992|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       $25 = (invoke_ii(3469,(2488992|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(1891,($25|0),($20|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3837,($25|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       // unreachable;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($msg|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       $34 = (invoke_iii(2739,(2476680|0),($msg|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($msg|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       __THREW__ = 0;
       $39 = (invoke_iii(2740,(2476752|0),($msg|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1169184|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break;
       }
       __THREW__ = 0;
       $44 = (invoke_iii(2764,($39|0),(1169184|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       __THREW__ = 0;
       $47 = (invoke_iiiii(146,0,($7|0),($34|0),($44|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($47|0);
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_GenericArgumentsP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2479136);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $3 = (invoke_iii(2730,(2478416|0),($__this|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_iii(2730,(2410848|0),($3|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    HEAP32[$0>>2] = $8;
    $$0 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetTypeNameFromAssemblyQualifiedNameP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$aqname) {
 $__this = $__this|0;
 $aqname = $aqname|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2479088);
 __THREW__ = 0;
 invoke_v(654);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($aqname|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[3036048>>2]|0;
   __THREW__ = 0;
   $5 = (invoke_iii(632,($aqname|0),($4|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($aqname|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $12 = (($5) + 2)|0;
     $13 = ($5|0)==(-1);
     $G_B3_0$0 = $13 ? 0 : $12;
     __THREW__ = 0;
     $14 = (invoke_iiii(540,($aqname|0),44,($G_B3_0$0|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $17 = ($14|0)==(-1);
      if ($17) {
       $$0 = $aqname;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($aqname|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_iiii(528,($aqname|0),0,($14|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         $25 = (invoke_ii(1812,($20|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          $$0 = $25;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Runtime_Remoting_Messaging_MethodCall_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogate_m__ctorP60mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2480536);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z66mscorlib_System_Runtime_Remoting_Messaging_ObjRefSurrogate_m__ctorP58mscorlib_System_Runtime_Remoting_Messaging_ObjRefSurrogate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2480800);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z76mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogateSelector_m__ctorP68mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogateSelector($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2481056);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z77mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogateSelector_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2481104);
 HEAP32[$0>>2] = 2521112;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2481424|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[((2481424 + 80|0))>>2]|0;
   HEAP32[$6>>2] = $1;
   __THREW__ = 0;
   (invoke_ii(2996,(2480920|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2480920|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(2419,($9|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2481424|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = HEAP32[((2481424 + 80|0))>>2]|0;
       $17 = (($16) + 4|0);
       HEAP32[$17>>2] = $9;
       __THREW__ = 0;
       (invoke_ii(2996,(2480664|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        $20 = (invoke_ii(3469,(2480664|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         invoke_vi(2418,($20|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2481424|0))|0);
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           $27 = HEAP32[((2481424 + 80|0))>>2]|0;
           $28 = (($27) + 8|0);
           HEAP32[$28>>2] = $20;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($29|0);
 // unreachable;
}
function __Z99mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogateSelector_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z72mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_CreateInstanceP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP20mscorlib_System_Type($__this,$serverType) {
 $__this = $__this|0;
 $serverType = $serverType|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2481560);
 __THREW__ = 0;
 (invoke_ii(2996,(2468768|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2468768 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2468768|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2468768|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2468768|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2468768|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2468768 + 80|0))>>2]|0;
    $15 = (($14) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2483848|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     $19 = (invoke_ii(3469,(2483848|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_viiii(163,($19|0),($serverType|0),($16|0),(0|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vi(3799,($19|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        $26 = (invoke_iii(2756,(2481608|0),($19|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2255384|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          __THREW__ = 0;
          $31 = (invoke_iii(2764,($26|0),(2255384|0))|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($31|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy_m__ctorP54mscorlib_System_Runtime_Remoting_Proxies_RemotingProxyP20mscorlib_System_TypeP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$type,$activationUrl,$activationAttributes) {
 $__this = $__this|0;
 $type = $type|0;
 $activationUrl = $activationUrl|0;
 $activationAttributes = $activationAttributes|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2483208);
 __THREW__ = 0;
 invoke_vii(1884,($__this|0),($type|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 24|0);
  HEAP8[$2>>0] = 0;
  __THREW__ = 0;
  $3 = (invoke_iiiii(145,(0|0),($type|0),($activationUrl|0),($activationAttributes|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($__this) + 28|0);
   HEAP32[$6>>2] = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z84mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_GetPropertiesForNewContextP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP22mscorlib_System_Object($__this,$msg) {
 $__this = $__this|0;
 $msg = $msg|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2481656);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z69mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_IsContextOKP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP49mscorlib_System_Runtime_Remoting_Contexts_ContextP22mscorlib_System_Object($__this,$ctx,$msg) {
 $__this = $__this|0;
 $ctx = $ctx|0;
 $msg = $msg|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2481704);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z86mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z171mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_GetPropertiesForNewContextP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z156mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_IsContextOKP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z100mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m__ctor_mscorlib_System_Void_mscorlib_System_TypeP50mscorlib_System_Runtime_Remoting_Proxies_RealProxyP20mscorlib_System_Type($__this,$classToProxy) {
 $__this = $__this|0;
 $classToProxy = $classToProxy|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2482144);
 __THREW__ = 0;
 (invoke_ii(2996,(2210080|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 $3 = HEAP32[((2210080 + 80|0))>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(162,($__this|0),($classToProxy|0),($$byval_copy|0),0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z146mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m__ctor_mscorlib_System_Void_mscorlib_System_Type_mscorlib_System_IntPtr_mscorlib_System_ObjectP50mscorlib_System_Runtime_Remoting_Proxies_RealProxyP20mscorlib_System_Type22mscorlib_System_IntPtrP22mscorlib_System_Object($__this,$classToProxy,$stub,$stubData) {
 $__this = $__this|0;
 $classToProxy = $classToProxy|0;
 $stub = $stub|0;
 $stubData = $stubData|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2482192);
 __THREW__ = 0;
 invoke_v(655);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 12|0);
   HEAP32[$4>>2] = -1;
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($classToProxy|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_iii(2734,(2234472|0),($classToProxy|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      if (!($9)) {
       __THREW__ = 0;
       invoke_vi(3799,($classToProxy|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
       __THREW__ = 0;
       $16 = (invoke_iii(2734,(2234184|0),($classToProxy|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       if (!($16)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         break;
        }
        __THREW__ = 0;
        $21 = (invoke_ii(3469,(2560072|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break;
        }
        $24 = HEAP32[3036072>>2]|0;
        __THREW__ = 0;
        invoke_vii(1924,($21|0),($24|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3837,($21|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
        // unreachable;
       }
      }
      $29 = (($__this) + 8|0);
      HEAP32[$29>>2] = $classToProxy;
      __THREW__ = 0;
      (invoke_ii(2996,(2210080|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       $32 = HEAP32[((2210080 + 80|0))>>2]|0;
       $33 = HEAP32[$32>>2]|0;
       $34 = HEAP32[$stub>>2]|0;
       HEAP32[$0>>2] = $34;
       HEAP32[$1>>2] = $33;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       $35 = (invoke_iiii(645,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        if (!($35)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2622808|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         __THREW__ = 0;
         $40 = (invoke_ii(3469,(2622808|0))|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[3036080>>2]|0;
          __THREW__ = 0;
          invoke_vii(1954,($40|0),($43|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if (!($45)) {
           __THREW__ = 0;
           invoke_vi(3837,($40|0));
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z73mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m_InternalGetProxyTypeP22mscorlib_System_ObjectS0_($__this,$transparentProxy) {
 $__this = $__this|0;
 $transparentProxy = $transparentProxy|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2482240);
 $0 = HEAP32[2482288>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2482296|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2482288>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($transparentProxy|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m_GetProxiedTypeP50mscorlib_System_Runtime_Remoting_Proxies_RealProxy($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2482376);
 $1 = (($__this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   $4 = (($__this) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($5|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2734,(2234184|0),($5|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     if ($8) {
      HEAP32[$0>>2] = 2266512;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      $13 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      } else {
       $$0 = $13;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     } else {
      $16 = HEAP32[$4>>2]|0;
      $$0 = $16;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  } else {
   __THREW__ = 0;
   $17 = (invoke_iii(947,0,($2|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $$0 = $17;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m_InternalGetTransparentProxyP50mscorlib_System_Runtime_Remoting_Proxies_RealProxyP22mscorlib_System_String($__this,$className) {
 $__this = $__this|0;
 $className = $className|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2482424);
 $0 = HEAP32[2482472>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2482480|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2482472>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($className|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z72mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m_GetTransparentProxyP50mscorlib_System_Runtime_Remoting_Proxies_RealProxy($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2481608);
 $1 = (($__this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $46 = $2;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($46|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2485312|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L4: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2735,($__this|0),(2485312|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)==(0|0);
    do {
     if ($9) {
      $36 = (($__this) + 8|0);
      $37 = HEAP32[$36>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break L4;
      }
      __THREW__ = 0;
      $40 = (invoke_iii(2730,(2238368|0),($37|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break L4;
      }
      $V_0$0 = $40;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($6|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break L4;
      }
      __THREW__ = 0;
      $14 = (invoke_iii(2739,(2482568|0),($6|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break L4;
      }
      $17 = ($14|0)==(0|0);
      if (!($17)) {
       HEAP32[$0>>2] = 2266512;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       $18 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break L4;
       }
       __THREW__ = 0;
       invoke_vi(3799,($18|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break L4;
       }
       __THREW__ = 0;
       $23 = (invoke_iii(2730,(2238368|0),($18|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break L4;
       }
       __THREW__ = 0;
       $26 = (invoke_iiii(574,(0|0),($14|0),($23|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break L4;
       }
       if (!($26)) {
        $V_0$0 = $14;
        break;
       }
      }
      $29 = (($__this) + 8|0);
      $30 = HEAP32[$29>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($30|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break L4;
      }
      __THREW__ = 0;
      $33 = (invoke_iii(2730,(2238368|0),($30|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break L4;
      }
      $V_0$0 = $33;
     }
    } while(0);
    __THREW__ = 0;
    $43 = (invoke_iiii(1670,(2482424|0),($__this|0),($V_0$0|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if (!($45)) {
     HEAP32[$1>>2] = $43;
     $46 = $43;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($46|0);
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker1I28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_IntPtrTraits28mscorlib_System_ObjectTraitsE6InvokeEPFvPvS4_22mscorlib_System_IntPtrP22mscorlib_System_ObjectES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$0>>2] = $4;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$$byval_copy,$6);
 STACKTOP = sp;return (0|0);
}
function __Z81mscorlib_System_Runtime_Remoting_Proxies_RealProxy_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2483256);
 __THREW__ = 0;
 invoke_v(656);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  HEAP32[$0>>2] = 1284448;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $4 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_vi(3799,($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3036200>>2]|0;
    __THREW__ = 0;
    $10 = (invoke_iiii(1645,(2236288|0),($4|0),($9|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2483848|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = HEAP32[((2483848 + 80|0))>>2]|0;
      HEAP32[$15>>2] = $10;
      HEAP32[$1>>2] = 1284448;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
      $16 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $21 = HEAP32[3036208>>2]|0;
        __THREW__ = 0;
        $22 = (invoke_iiii(1645,(2236288|0),($16|0),($21|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2483848|0))|0);
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          $27 = HEAP32[((2483848 + 80|0))>>2]|0;
          $28 = (($27) + 4|0);
          HEAP32[$28>>2] = $22;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($29|0);
 // unreachable;
}
function __Z69mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy_m_get_TypeNameP54mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy($__this) {
 $__this = $__this|0;
 var $$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2483304);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2486384|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2735,($1|0),(2486384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0|0);
    if (!($7)) {
     $10 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_iiii(1645,(2483352|0),($10|0),(0|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($13|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     $18 = (invoke_iii(2730,(2483400|0),($13|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     $21 = ($18|0)==(0|0);
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3799,($13|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      $24 = (invoke_iii(2730,(2483400|0),($13|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($24|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2739,(2482568|0),($24|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      } else {
       $$0$in = $29;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0$in|0);
     }
    }
    __THREW__ = 0;
    $32 = (invoke_ii(2316,($__this|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      __THREW__ = 0;
      $37 = (invoke_iii(2730,(2238368|0),($32|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $$0$in = $37;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0$in|0);
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy_m_FinalizeP54mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2483448);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 41;
   label = 10;
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2491832|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2735,($1|0),(2491832|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = ($5|0)==(0|0);
     if (!($8)) {
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 41;
      label = 10;
      break;
     }
     $17 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vii(1893,0,($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 41;
      label = 10;
      break;
     }
    }
   }
   $9 = ___cxa_find_matching_catch(348288|0)|0;
   $10 = tempRet0;
   $11 = (_llvm_eh_typeid_for((348288|0))|0);
   $12 = ($10|0)==($11|0);
   if (!($12)) {
    $$0 = $9;$$02 = $10;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $13 = (___cxa_begin_catch(($9|0))|0);
   $14 = HEAP32[$13>>2]|0;
   __THREW__ = 0;
   invoke_v(66);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $__last_unhandled_exception$0 = $14;$leaveInstructions$sroa$0$0 = 0;
    label = 10;
   }
  }
 } while(0);
 if ((label|0) == 10) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if (!($23)) {
   $cond = ($leaveInstructions$sroa$0$0|0)==(41);
   if ($cond) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3837,($__last_unhandled_exception$0|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    // unreachable;
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $$0 = $20;$$02 = $21;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z67mscorlib_System_Runtime_Remoting_RemotingServices_m_DisposeIdentityP22mscorlib_System_ObjectP41mscorlib_System_Runtime_Remoting_Identity($__this,$ident) {
 $__this = $__this|0;
 $ident = $ident|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489864);
 __THREW__ = 0;
 (invoke_ii(2996,(2491144|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2491144 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2491144|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2491144|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2491144|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2491144|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2491144 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_vii(1916,(0|0),($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vi(3799,($ident|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     do {
      if ($19) {
       label = 12;
      } else {
       __THREW__ = 0;
       $20 = (invoke_ii(2324,($ident|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        label = 12;
       } else {
        if ($20) {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 85;
        } else {
         __THREW__ = 0;
         (invoke_ii(2996,(2486384|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          label = 12;
         } else {
          __THREW__ = 0;
          $33 = (invoke_iii(2735,($ident|0),(2486384|0))|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if ($35) {
           label = 12;
          } else {
           $36 = ($33|0)==(0|0);
           if ($36) {
            __THREW__ = 0;
            (invoke_ii(2996,(2491144|0))|0);
            $63 = __THREW__; __THREW__ = 0;
            $64 = $63&1;
            if ($64) {
             label = 12;
             break;
            }
            $65 = HEAP8[((2491144 + 116|0))>>0]|0;
            $66 = ($65<<24>>24)==(0);
            if ($66) {
             __THREW__ = 0;
             (invoke_ii(2996,(2491144|0))|0);
             $67 = __THREW__; __THREW__ = 0;
             $68 = $67&1;
             if ($68) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2491144|0))|0);
             $69 = __THREW__; __THREW__ = 0;
             $70 = $69&1;
             if ($70) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3836,(2491144|0));
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if ($72) {
              label = 12;
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2491144|0))|0);
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 12;
             break;
            }
            $75 = HEAP32[((2491144 + 80|0))>>2]|0;
            $76 = HEAP32[$75>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($ident|0));
            $77 = __THREW__; __THREW__ = 0;
            $78 = $77&1;
            if ($78) {
             label = 12;
             break;
            }
            __THREW__ = 0;
            $79 = (invoke_ii(2323,($ident|0))|0);
            $80 = __THREW__; __THREW__ = 0;
            $81 = $80&1;
            if ($81) {
             label = 12;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($76|0));
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if ($83) {
             label = 12;
             break;
            }
            __THREW__ = 0;
            invoke_viii(2113,(2311280|0),($76|0),($79|0));
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if ($85) {
             label = 12;
             break;
            }
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2491144|0))|0);
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if ($38) {
             label = 12;
             break;
            }
            $39 = HEAP8[((2491144 + 116|0))>>0]|0;
            $40 = ($39<<24>>24)==(0);
            if ($40) {
             __THREW__ = 0;
             (invoke_ii(2996,(2491144|0))|0);
             $41 = __THREW__; __THREW__ = 0;
             $42 = $41&1;
             if ($42) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2491144|0))|0);
             $43 = __THREW__; __THREW__ = 0;
             $44 = $43&1;
             if ($44) {
              label = 12;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3836,(2491144|0));
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              label = 12;
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2491144|0))|0);
            $47 = __THREW__; __THREW__ = 0;
            $48 = $47&1;
            if ($48) {
             label = 12;
             break;
            }
            $49 = HEAP32[((2491144 + 80|0))>>2]|0;
            $50 = HEAP32[$49>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($33|0));
            $51 = __THREW__; __THREW__ = 0;
            $52 = $51&1;
            if ($52) {
             label = 12;
             break;
            }
            __THREW__ = 0;
            $53 = (invoke_ii(2325,($33|0))|0);
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if ($55) {
             label = 12;
             break;
            }
            __THREW__ = 0;
            $56 = (invoke_iii(955,0,($53|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if ($58) {
             label = 12;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($50|0));
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             label = 12;
             break;
            }
            __THREW__ = 0;
            invoke_viii(2113,(2311280|0),($50|0),($56|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             label = 12;
             break;
            }
           }
           __THREW__ = 0;
           invoke_vi(3799,($ident|0));
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if ($87) {
            label = 12;
           } else {
            __THREW__ = 0;
            invoke_vii(1887,($ident|0),1);
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if ($89) {
             label = 12;
            } else {
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 85;
            }
           }
          }
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 12) {
      $23 = ___cxa_find_matching_catch(348288|0)|0;
      $24 = tempRet0;
      $25 = (_llvm_eh_typeid_for((348288|0))|0);
      $26 = ($24|0)==($25|0);
      if (!($26)) {
       $$0 = $23;$$02 = $24;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$0|0);
       // unreachable;
      }
      $27 = (___cxa_begin_catch(($23|0))|0);
      $28 = HEAP32[$27>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $__last_unhandled_exception$0 = $28;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,(0|0),($15|0));
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if (!($91)) {
      $cond1 = ($leaveInstructions$sroa$0$0|0)==(85);
      if ($cond1) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3837,($__last_unhandled_exception$0|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if (!($93)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $10;$$02 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z78mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_m_get_ApplicationUrlP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2483984);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z81mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_m_get_ContextAttributesP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2484032);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z74mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_m_get_ObjectTypeP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2484080);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_m_ToStringP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2484128);
 __THREW__ = 0;
 $0 = (invoke_ii(2331,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(2330,($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(2319,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iiiii(101,(0|0),($0|0),($3|0),($6|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($9|0);
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_Runtime_Remoting_TypeEntry_m_get_TypeNameP42mscorlib_System_Runtime_Remoting_TypeEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2492576);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z61mscorlib_System_Runtime_Remoting_TypeEntry_m_get_AssemblyNameP42mscorlib_System_Runtime_Remoting_TypeEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2492528);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z88mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z50mscorlib_System_Runtime_Remoting_EnvoyInfo_m__ctorP42mscorlib_System_Runtime_Remoting_EnvoyInfoP22mscorlib_System_Object($__this,$sinks) {
 $__this = $__this|0;
 $sinks = $sinks|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2484584);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $sinks;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z76mscorlib_System_Runtime_Remoting_IChannelInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Runtime_Remoting_IEnvoyInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Runtime_Remoting_IRemotingTypeInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z49mscorlib_System_Runtime_Remoting_Identity_m__ctorP41mscorlib_System_Runtime_Remoting_IdentityP22mscorlib_System_String($__this,$objectUri) {
 $__this = $__this|0;
 $objectUri = $objectUri|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2485448);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $objectUri;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57mscorlib_System_Runtime_Remoting_Identity_m_get_ObjectUriP41mscorlib_System_Runtime_Remoting_Identity($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2485496);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z56mscorlib_System_Runtime_Remoting_Identity_m_get_DisposedP41mscorlib_System_Runtime_Remoting_Identity($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2485544);
 $0 = (($__this) + 20|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z56mscorlib_System_Runtime_Remoting_Identity_m_set_DisposedP41mscorlib_System_Runtime_Remoting_Identityb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2485592);
 $0 = (($__this) + 20|0);
 $1 = $value&1;
 HEAP8[$0>>0] = $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_Runtime_Remoting_ClientIdentity_m_CreateObjRefP47mscorlib_System_Runtime_Remoting_ClientIdentityP20mscorlib_System_Type($__this,$requestedType) {
 $__this = $__this|0;
 $requestedType = $requestedType|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486144);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z63mscorlib_System_Runtime_Remoting_ClientIdentity_m_get_TargetUriP47mscorlib_System_Runtime_Remoting_ClientIdentity($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486192);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2730,(2486240|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_Runtime_Remoting_ObjRef_m__ctorP39mscorlib_System_Runtime_Remoting_ObjRef($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486520);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(2435,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z59mscorlib_System_Runtime_Remoting_ObjRef_m_UpdateChannelInfoP39mscorlib_System_Runtime_Remoting_ObjRef($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486808);
 __THREW__ = 0;
 (invoke_ii(2996,(2467680|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2467680|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2387,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 8|0);
    HEAP32[$7>>2] = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z48mscorlib_System_Runtime_Remoting_ObjRef_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486568);
 __THREW__ = 0;
 (invoke_ii(2996,(2487504|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2487504 + 80|0))>>2]|0;
  HEAP32[$2>>2] = 1;
  __THREW__ = 0;
  (invoke_ii(2996,(2487504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[((2487504 + 80|0))>>2]|0;
   $6 = (($5) + 4|0);
   HEAP32[$6>>2] = 2;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z55mscorlib_System_Runtime_Remoting_ObjRef_m_set_EnvoyInfoP39mscorlib_System_Runtime_Remoting_ObjRefP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486616);
 $0 = (($__this) + 20|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_Runtime_Remoting_ObjRef_m_get_TypeInfoP39mscorlib_System_Runtime_Remoting_ObjRef($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2483400);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z54mscorlib_System_Runtime_Remoting_ObjRef_m_set_TypeInfoP39mscorlib_System_Runtime_Remoting_ObjRefP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486664);
 $0 = (($__this) + 16|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z49mscorlib_System_Runtime_Remoting_ObjRef_m_get_URIP39mscorlib_System_Runtime_Remoting_ObjRef($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486240);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z49mscorlib_System_Runtime_Remoting_ObjRef_m_set_URIP39mscorlib_System_Runtime_Remoting_ObjRefP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486712);
 $0 = (($__this) + 12|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_Runtime_Remoting_ObjRef_m_GetObjectDataP39mscorlib_System_Runtime_Remoting_ObjRefP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 16|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2486760);
 __THREW__ = 0;
 invoke_v(657);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_ii(1782,($__this|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vii(1897,($info|0),($5|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($__this) + 12|0);
     $13 = HEAP32[$12>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = HEAP32[3036264>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($16|0),($13|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = (($__this) + 16|0);
       $20 = HEAP32[$19>>2]|0;
       HEAP32[$0>>2] = 2521544;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
       $21 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         $26 = HEAP32[3036272>>2]|0;
         __THREW__ = 0;
         invoke_viiii(168,($info|0),($26|0),($20|0),($21|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($__this) + 20|0);
          $30 = HEAP32[$29>>2]|0;
          HEAP32[$1>>2] = 2521552;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
          $31 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           __THREW__ = 0;
           invoke_vi(3799,($info|0));
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $36 = HEAP32[3036280>>2]|0;
            __THREW__ = 0;
            invoke_viiii(168,($info|0),($36|0),($30|0),($31|0));
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if (!($38)) {
             $39 = (($__this) + 8|0);
             $40 = HEAP32[$39>>2]|0;
             HEAP32[$2>>2] = 2521584;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
             $41 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if (!($43)) {
              __THREW__ = 0;
              invoke_vi(3799,($info|0));
              $44 = __THREW__; __THREW__ = 0;
              $45 = $44&1;
              if (!($45)) {
               $46 = HEAP32[3036288>>2]|0;
               __THREW__ = 0;
               invoke_viiii(168,($info|0),($46|0),($40|0),($41|0));
               $47 = __THREW__; __THREW__ = 0;
               $48 = $47&1;
               if (!($48)) {
                $49 = (($__this) + 24|0);
                $50 = HEAP32[$49>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($info|0));
                $51 = __THREW__; __THREW__ = 0;
                $52 = $51&1;
                if (!($52)) {
                 $53 = HEAP32[3036296>>2]|0;
                 __THREW__ = 0;
                 invoke_viii(618,($info|0),($53|0),($50|0));
                 $54 = __THREW__; __THREW__ = 0;
                 $55 = $54&1;
                 if (!($55)) {
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $56 = ___cxa_find_matching_catch()|0;
 $57 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($56|0);
 // unreachable;
}
function __Z65mscorlib_System_Runtime_Serialization_SerializationInfo_m_SetTypeP55mscorlib_System_Runtime_Serialization_SerializationInfoP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2497928);
 __THREW__ = 0;
 invoke_v(658);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($type|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3036920>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($type|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(2730,(2150320|0),($type|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = (($__this) + 20|0);
     HEAP32[$20>>2] = $17;
     __THREW__ = 0;
     invoke_vi(3799,($type|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_iii(2730,(2238288|0),($type|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       invoke_vi(3799,($23|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __THREW__ = 0;
        $28 = (invoke_iii(2730,(2370792|0),($23|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         $31 = (($__this) + 16|0);
         HEAP32[$31>>2] = $28;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z154mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_TypeP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_StringP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$name,$value,$type) {
 $__this = $__this|0;
 $name = $name|0;
 $value = $value|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_6 = 0, $L_9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 36|0;
 $V_0 = sp;
 $L_6 = sp + 12|0;
 $L_9 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2497880);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(659);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3036768>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($type|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3036776>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = (($__this) + 8|0);
   $27 = HEAP32[$26>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($27|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    __THREW__ = 0;
    $30 = (invoke_iiii(1644,(2311328|0),($27|0),($name|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     if ($30) {
      __THREW__ = 0;
      (invoke_ii(2996,(2497744|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_ii(3469,(2497744|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[3036784>>2]|0;
      __THREW__ = 0;
      invoke_vii(1896,($35|0),($38|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3837,($35|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_viiii(167,($V_0|0),($name|0),($type|0),($value|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      $45 = HEAP32[$26>>2]|0;
      ;HEAP32[$L_6+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$V_0+8>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2497392|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       $48 = (invoke_iii(2724,(2497392|0),($L_6|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if (!($50)) {
        __THREW__ = 0;
        invoke_vi(3799,($45|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if (!($52)) {
         __THREW__ = 0;
         invoke_viiii(465,(2311184|0),($45|0),($name|0),($48|0));
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if (!($54)) {
          $55 = (($__this) + 12|0);
          $56 = HEAP32[$55>>2]|0;
          ;HEAP32[$L_9+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_9+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_9+8>>2]=HEAP32[$V_0+8>>2]|0;
          __THREW__ = 0;
          (invoke_ii(2996,(2497392|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if (!($58)) {
           __THREW__ = 0;
           $59 = (invoke_iii(2724,(2497392|0),($L_9|0))|0);
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if (!($61)) {
            __THREW__ = 0;
            invoke_vi(3799,($56|0));
            $62 = __THREW__; __THREW__ = 0;
            $63 = $62&1;
            if (!($63)) {
             __THREW__ = 0;
             (invoke_iiii(1647,(2297624|0),($56|0),($59|0))|0);
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if (!($65)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z132mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32P55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringi($__this,$name,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $value = $value|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $0 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2498024);
 HEAP32[$L_0>>2] = $value;
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2724,(2155952|0),($L_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$0>>2] = 1285000;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $6 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiii(168,($__this|0),($name|0),($3|0),($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z70mscorlib_System_Runtime_Remoting_ObjRef_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_Runtime_Remoting_RemotingConfiguration_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2487640);
 __THREW__ = 0;
 (invoke_ii(2996,(2488640|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[((2488640 + 80|0))>>2]|0;
   HEAP32[$2>>2] = 0;
   __THREW__ = 0;
   (invoke_ii(2996,(2488640|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP32[((2488640 + 80|0))>>2]|0;
    $6 = (($5) + 4|0);
    HEAP32[$6>>2] = 0;
    __THREW__ = 0;
    (invoke_ii(2996,(2488640|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2488640 + 80|0))>>2]|0;
     $10 = (($9) + 8|0);
     HEAP32[$10>>2] = 0;
     __THREW__ = 0;
     (invoke_ii(2996,(2488640|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = HEAP32[((2488640 + 80|0))>>2]|0;
      $14 = (($13) + 12|0);
      HEAP8[$14>>0] = 0;
      __THREW__ = 0;
      (invoke_ii(2996,(2488640|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = HEAP32[((2488640 + 80|0))>>2]|0;
       $18 = (($17) + 13|0);
       HEAP8[$18>>0] = 0;
       __THREW__ = 0;
       (invoke_ii(2996,(2313960|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        $21 = (invoke_ii(3469,(2313960|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         __THREW__ = 0;
         invoke_vi(2173,($21|0));
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2488640|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           $28 = HEAP32[((2488640 + 80|0))>>2]|0;
           $29 = (($28) + 16|0);
           HEAP32[$29>>2] = $21;
           __THREW__ = 0;
           (invoke_ii(2996,(2313960|0))|0);
           $30 = __THREW__; __THREW__ = 0;
           $31 = $30&1;
           if (!($31)) {
            __THREW__ = 0;
            $32 = (invoke_ii(3469,(2313960|0))|0);
            $33 = __THREW__; __THREW__ = 0;
            $34 = $33&1;
            if (!($34)) {
             __THREW__ = 0;
             invoke_vi(2173,($32|0));
             $35 = __THREW__; __THREW__ = 0;
             $36 = $35&1;
             if (!($36)) {
              __THREW__ = 0;
              (invoke_ii(2996,(2488640|0))|0);
              $37 = __THREW__; __THREW__ = 0;
              $38 = $37&1;
              if (!($38)) {
               $39 = HEAP32[((2488640 + 80|0))>>2]|0;
               $40 = (($39) + 20|0);
               HEAP32[$40>>2] = $32;
               __THREW__ = 0;
               (invoke_ii(2996,(2313960|0))|0);
               $41 = __THREW__; __THREW__ = 0;
               $42 = $41&1;
               if (!($42)) {
                __THREW__ = 0;
                $43 = (invoke_ii(3469,(2313960|0))|0);
                $44 = __THREW__; __THREW__ = 0;
                $45 = $44&1;
                if (!($45)) {
                 __THREW__ = 0;
                 invoke_vi(2173,($43|0));
                 $46 = __THREW__; __THREW__ = 0;
                 $47 = $46&1;
                 if (!($47)) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2488640|0))|0);
                  $48 = __THREW__; __THREW__ = 0;
                  $49 = $48&1;
                  if (!($49)) {
                   $50 = HEAP32[((2488640 + 80|0))>>2]|0;
                   $51 = (($50) + 24|0);
                   HEAP32[$51>>2] = $43;
                   __THREW__ = 0;
                   (invoke_ii(2996,(2313960|0))|0);
                   $52 = __THREW__; __THREW__ = 0;
                   $53 = $52&1;
                   if (!($53)) {
                    __THREW__ = 0;
                    $54 = (invoke_ii(3469,(2313960|0))|0);
                    $55 = __THREW__; __THREW__ = 0;
                    $56 = $55&1;
                    if (!($56)) {
                     __THREW__ = 0;
                     invoke_vi(2173,($54|0));
                     $57 = __THREW__; __THREW__ = 0;
                     $58 = $57&1;
                     if ($58) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2488640|0))|0);
                     $59 = __THREW__; __THREW__ = 0;
                     $60 = $59&1;
                     if ($60) {
                      break;
                     }
                     $61 = HEAP32[((2488640 + 80|0))>>2]|0;
                     $62 = (($61) + 28|0);
                     HEAP32[$62>>2] = $54;
                     __THREW__ = 0;
                     (invoke_ii(2996,(2313960|0))|0);
                     $63 = __THREW__; __THREW__ = 0;
                     $64 = $63&1;
                     if ($64) {
                      break;
                     }
                     __THREW__ = 0;
                     $65 = (invoke_ii(3469,(2313960|0))|0);
                     $66 = __THREW__; __THREW__ = 0;
                     $67 = $66&1;
                     if ($67) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(2173,($65|0));
                     $68 = __THREW__; __THREW__ = 0;
                     $69 = $68&1;
                     if ($69) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2488640|0))|0);
                     $70 = __THREW__; __THREW__ = 0;
                     $71 = $70&1;
                     if ($71) {
                      break;
                     }
                     $72 = HEAP32[((2488640 + 80|0))>>2]|0;
                     $73 = (($72) + 32|0);
                     HEAP32[$73>>2] = $65;
                     __THREW__ = 0;
                     (invoke_ii(2996,(2313960|0))|0);
                     $74 = __THREW__; __THREW__ = 0;
                     $75 = $74&1;
                     if ($75) {
                      break;
                     }
                     __THREW__ = 0;
                     $76 = (invoke_ii(3469,(2313960|0))|0);
                     $77 = __THREW__; __THREW__ = 0;
                     $78 = $77&1;
                     if ($78) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(2173,($76|0));
                     $79 = __THREW__; __THREW__ = 0;
                     $80 = $79&1;
                     if ($80) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2488640|0))|0);
                     $81 = __THREW__; __THREW__ = 0;
                     $82 = $81&1;
                     if ($82) {
                      break;
                     }
                     $83 = HEAP32[((2488640 + 80|0))>>2]|0;
                     $84 = (($83) + 36|0);
                     HEAP32[$84>>2] = $76;
                     __THREW__ = 0;
                     (invoke_ii(2996,(2313960|0))|0);
                     $85 = __THREW__; __THREW__ = 0;
                     $86 = $85&1;
                     if ($86) {
                      break;
                     }
                     __THREW__ = 0;
                     $87 = (invoke_ii(3469,(2313960|0))|0);
                     $88 = __THREW__; __THREW__ = 0;
                     $89 = $88&1;
                     if ($89) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(2173,($87|0));
                     $90 = __THREW__; __THREW__ = 0;
                     $91 = $90&1;
                     if ($91) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2488640|0))|0);
                     $92 = __THREW__; __THREW__ = 0;
                     $93 = $92&1;
                     if ($93) {
                      break;
                     }
                     $94 = HEAP32[((2488640 + 80|0))>>2]|0;
                     $95 = (($94) + 40|0);
                     HEAP32[$95>>2] = $87;
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $96 = ___cxa_find_matching_catch()|0;
 $97 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($96|0);
 // unreachable;
}
function __Z76mscorlib_System_Runtime_Remoting_RemotingConfiguration_m_get_ApplicationNameP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2487688);
 __THREW__ = 0;
 (invoke_ii(2996,(2488640|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2488640 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2488640|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2488640|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2488640|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2488640|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2488640 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Runtime_Remoting_RemotingConfiguration_m_IsRemotelyActivatedClientTypeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$svrType) {
 $__this = $__this|0;
 $svrType = $svrType|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $__last_unhandled_exception$0 = 0;
 var $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2487784);
 __THREW__ = 0;
 (invoke_ii(2996,(2488640|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2488640 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2488640|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2488640|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2488640|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2488640|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2488640 + 80|0))>>2]|0;
    $15 = (($14) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_vii(1916,(0|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2488640|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     do {
      if ($20) {
       label = 14;
      } else {
       $21 = HEAP8[((2488640 + 116|0))>>0]|0;
       $22 = ($21<<24>>24)==(0);
       if ($22) {
        __THREW__ = 0;
        (invoke_ii(2996,(2488640|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if ($24) {
         label = 14;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2488640|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         label = 14;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3836,(2488640|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         label = 14;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2488640|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 14;
       } else {
        $39 = HEAP32[((2488640 + 80|0))>>2]|0;
        $40 = (($39) + 20|0);
        $41 = HEAP32[$40>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($41|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         label = 14;
        } else {
         __THREW__ = 0;
         $44 = (invoke_iiii(1643,(2310848|0),($41|0),($svrType|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 14;
         } else {
          __THREW__ = 0;
          (invoke_ii(2996,(2484448|0))|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           label = 14;
          } else {
           __THREW__ = 0;
           $49 = (invoke_iii(2735,($44|0),(2484448|0))|0);
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           if ($51) {
            label = 14;
           } else {
            $V_1$0 = $49;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 40;
           }
          }
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 14) {
      $29 = ___cxa_find_matching_catch(348288|0)|0;
      $30 = tempRet0;
      $31 = (_llvm_eh_typeid_for((348288|0))|0);
      $32 = ($30|0)==($31|0);
      if (!($32)) {
       $$02 = $29;$$03 = $30;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $33 = (___cxa_begin_catch(($29|0))|0);
      $34 = HEAP32[$33>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $V_1$0 = 0;$__last_unhandled_exception$0 = $34;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,(0|0),($16|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      $cond1 = ($leaveInstructions$sroa$0$0|0)==(40);
      if ($cond1) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($V_1$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3837,($__last_unhandled_exception$0|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if (!($55)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Runtime_Remoting_RemotingConfiguration_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Runtime_Remoting_RemotingException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Runtime_Remoting_RemotingServices_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_11 = 0, $V_1 = 0, $V_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy2 = sp + 80|0;
 $_stackTraceSentry = sp + 72|0;
 $V_1 = sp + 8|0;
 $V_2 = sp + 56|0;
 $0 = sp;
 $1 = sp + 16|0;
 $L_11 = sp + 32|0;
 $2 = sp + 24|0;
 $3 = sp + 48|0;
 $4 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489128);
 $5 = $V_1;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(660);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 do {
  if (!($10)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2313960|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2313960|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     invoke_vi(2173,($13|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2491144|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = HEAP32[((2491144 + 80|0))>>2]|0;
       HEAP32[$20>>2] = $13;
       __THREW__ = 0;
       (invoke_ii(2996,(2491144|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        $23 = HEAP32[((2491144 + 80|0))>>2]|0;
        $24 = (($23) + 16|0);
        HEAP32[$24>>2] = 1;
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = HEAP32[((2491144 + 80|0))>>2]|0;
         $28 = (($27) + 20|0);
         HEAP32[$28>>2] = 52;
         __THREW__ = 0;
         (invoke_ii(2996,(2481424|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          __THREW__ = 0;
          $31 = (invoke_ii(3469,(2481424|0))|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           __THREW__ = 0;
           invoke_vi(2420,($31|0));
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            __THREW__ = 0;
            invoke_viii(622,($V_1|0),16,(0|0));
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if (!($37)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2494456|0))|0);
             $38 = __THREW__; __THREW__ = 0;
             $39 = $38&1;
             if (!($39)) {
              __THREW__ = 0;
              $40 = (invoke_ii(3469,(2494456|0))|0);
              $41 = __THREW__; __THREW__ = 0;
              $42 = $41&1;
              if (!($42)) {
               $43 = $V_1;
               $44 = $43;
               $45 = HEAP32[$44>>2]|0;
               $46 = (($43) + 4)|0;
               $47 = $46;
               $48 = HEAP32[$47>>2]|0;
               $49 = $0;
               $50 = $49;
               HEAP32[$50>>2] = $45;
               $51 = (($49) + 4)|0;
               $52 = $51;
               HEAP32[$52>>2] = $48;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$0+4>>2]|0;
               invoke_viii(616,($40|0),($31|0),($$byval_copy2|0));
               $53 = __THREW__; __THREW__ = 0;
               $54 = $53&1;
               if (!($54)) {
                __THREW__ = 0;
                (invoke_ii(2996,(2491144|0))|0);
                $55 = __THREW__; __THREW__ = 0;
                $56 = $55&1;
                if (!($56)) {
                 $57 = HEAP32[((2491144 + 80|0))>>2]|0;
                 $58 = (($57) + 4|0);
                 HEAP32[$58>>2] = $40;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2494456|0))|0);
                 $59 = __THREW__; __THREW__ = 0;
                 $60 = $59&1;
                 if (!($60)) {
                  __THREW__ = 0;
                  $61 = (invoke_ii(3469,(2494456|0))|0);
                  $62 = __THREW__; __THREW__ = 0;
                  $63 = $62&1;
                  if (!($63)) {
                   $64 = $1;
                   $65 = $64;
                   HEAP32[$65>>2] = $45;
                   $66 = (($64) + 4)|0;
                   $67 = $66;
                   HEAP32[$67>>2] = $48;
                   __THREW__ = 0;
                   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$1+4>>2]|0;
                   invoke_viii(616,($61|0),(0|0),($$byval_copy2|0));
                   $68 = __THREW__; __THREW__ = 0;
                   $69 = $68&1;
                   if (!($69)) {
                    __THREW__ = 0;
                    (invoke_ii(2996,(2491144|0))|0);
                    $70 = __THREW__; __THREW__ = 0;
                    $71 = $70&1;
                    if (!($71)) {
                     $72 = HEAP32[((2491144 + 80|0))>>2]|0;
                     $73 = (($72) + 8|0);
                     HEAP32[$73>>2] = $61;
                     __THREW__ = 0;
                     (invoke_ii(2996,(2491144|0))|0);
                     $74 = __THREW__; __THREW__ = 0;
                     $75 = $74&1;
                     if ($75) {
                      break;
                     }
                     $76 = HEAP32[((2491144 + 80|0))>>2]|0;
                     $77 = (($76) + 4|0);
                     $78 = HEAP32[$77>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($78|0));
                     $79 = __THREW__; __THREW__ = 0;
                     $80 = $79&1;
                     if ($80) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(1895,($78|0),1);
                     $81 = __THREW__; __THREW__ = 0;
                     $82 = $81&1;
                     if ($82) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2491144|0))|0);
                     $83 = __THREW__; __THREW__ = 0;
                     $84 = $83&1;
                     if ($84) {
                      break;
                     }
                     $85 = HEAP32[((2491144 + 80|0))>>2]|0;
                     $86 = (($85) + 8|0);
                     $87 = HEAP32[$86>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($87|0));
                     $88 = __THREW__; __THREW__ = 0;
                     $89 = $88&1;
                     if ($89) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(1895,($87|0),1);
                     $90 = __THREW__; __THREW__ = 0;
                     $91 = $90&1;
                     if ($91) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(2441,0);
                     $92 = __THREW__; __THREW__ = 0;
                     $93 = $92&1;
                     if ($93) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vii(1944,($L_11|0),(0|0));
                     $94 = __THREW__; __THREW__ = 0;
                     $95 = $94&1;
                     if ($95) {
                      break;
                     }
                     ;HEAP32[$V_2+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_11+12>>2]|0;
                     __THREW__ = 0;
                     $96 = (invoke_ii(2446,($V_2|0))|0);
                     $97 = __THREW__; __THREW__ = 0;
                     $98 = $97&1;
                     if ($98) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($96|0));
                     $99 = __THREW__; __THREW__ = 0;
                     $100 = $99&1;
                     if ($100) {
                      break;
                     }
                     __THREW__ = 0;
                     $101 = (invoke_iiii(546,($96|0),45,95)|0);
                     $102 = __THREW__; __THREW__ = 0;
                     $103 = $102&1;
                     if ($103) {
                      break;
                     }
                     $104 = HEAP32[3036408>>2]|0;
                     __THREW__ = 0;
                     $105 = (invoke_iiii(562,(0|0),($101|0),($104|0))|0);
                     $106 = __THREW__; __THREW__ = 0;
                     $107 = $106&1;
                     if ($107) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2491144|0))|0);
                     $108 = __THREW__; __THREW__ = 0;
                     $109 = $108&1;
                     if ($109) {
                      break;
                     }
                     $110 = HEAP32[((2491144 + 80|0))>>2]|0;
                     $111 = (($110) + 12|0);
                     HEAP32[$111>>2] = $105;
                     HEAP32[$2>>2] = 2521328;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
                     $112 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
                     $113 = __THREW__; __THREW__ = 0;
                     $114 = $113&1;
                     if ($114) {
                      break;
                     }
                     $115 = HEAP32[3036416>>2]|0;
                     __THREW__ = 0;
                     (invoke_iiiii(148,0,($112|0),($115|0),1)|0);
                     $116 = __THREW__; __THREW__ = 0;
                     $117 = $116&1;
                     if ($117) {
                      break;
                     }
                     HEAP32[$3>>2] = 1284448;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$3+0>>2]|0;
                     $118 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
                     $119 = __THREW__; __THREW__ = 0;
                     $120 = $119&1;
                     if ($120) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($118|0));
                     $121 = __THREW__; __THREW__ = 0;
                     $122 = $121&1;
                     if ($122) {
                      break;
                     }
                     $123 = HEAP32[3036424>>2]|0;
                     __THREW__ = 0;
                     $124 = (invoke_iiiii(323,(2236384|0),($118|0),($123|0),36)|0);
                     $125 = __THREW__; __THREW__ = 0;
                     $126 = $125&1;
                     if ($126) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2491144|0))|0);
                     $127 = __THREW__; __THREW__ = 0;
                     $128 = $127&1;
                     if ($128) {
                      break;
                     }
                     $129 = HEAP32[((2491144 + 80|0))>>2]|0;
                     $130 = (($129) + 24|0);
                     HEAP32[$130>>2] = $124;
                     HEAP32[$4>>2] = 1284448;
                     __THREW__ = 0;
                     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$4+0>>2]|0;
                     $131 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
                     $132 = __THREW__; __THREW__ = 0;
                     $133 = $132&1;
                     if ($133) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($131|0));
                     $134 = __THREW__; __THREW__ = 0;
                     $135 = $134&1;
                     if ($135) {
                      break;
                     }
                     $136 = HEAP32[3036432>>2]|0;
                     __THREW__ = 0;
                     $137 = (invoke_iiiii(323,(2236384|0),($131|0),($136|0),36)|0);
                     $138 = __THREW__; __THREW__ = 0;
                     $139 = $138&1;
                     if ($139) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2491144|0))|0);
                     $140 = __THREW__; __THREW__ = 0;
                     $141 = $140&1;
                     if ($141) {
                      break;
                     }
                     $142 = HEAP32[((2491144 + 80|0))>>2]|0;
                     $143 = (($142) + 28|0);
                     HEAP32[$143>>2] = $137;
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $144 = ___cxa_find_matching_catch()|0;
 $145 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($144|0);
 // unreachable;
}
function __Z62mscorlib_System_Runtime_Serialization_StreamingContext_m__ctorP54mscorlib_System_Runtime_Serialization_StreamingContextiP22mscorlib_System_Object($__this,$state,$additional) {
 $__this = $__this|0;
 $state = $state|0;
 $additional = $additional|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2499112);
 HEAP32[$__this>>2] = $state;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $additional;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z79mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatter_m__ctorP71mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatterP22mscorlib_System_Object54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$selector,$context) {
 $__this = $__this|0;
 $selector = $selector|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2493896);
 $0 = (($__this) + 24|0);
 HEAP32[$0>>2] = 1;
 $1 = (($__this) + 28|0);
 HEAP32[$1>>2] = 3;
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $4 = (($__this) + 20|0);
  HEAP32[$4>>2] = $selector;
  $5 = (($__this) + 12|0);
  $6 = $context;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $5;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z92mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatter_m_set_AssemblyFormatP71mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatteri($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2493944);
 $0 = (($__this) + 8|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Runtime_Remoting_RemotingServices_m_RegisterInternalChannelsP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489816);
 __THREW__ = 0;
 invoke_vi(2393,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Runtime_Remoting_RemotingServices_m_CreateWellKnownServerIdentityP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_Stringi($__this,$objectType,$objectUri,$mode) {
 $__this = $__this|0;
 $objectType = $objectType|0;
 $objectUri = $objectUri|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$in = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489720);
 $0 = ($mode|0)==(2);
 if ($0) {
  __THREW__ = 0;
  $1 = (invoke_ii(2296,0)|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2492392|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_ii(3469,(2492392|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_viiii(166,($6|0),($objectUri|0),($1|0),($objectType|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $V_0$0$in = $6;
      label = 11;
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  $13 = (invoke_ii(2296,0)|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if (!($15)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2492112|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2492112|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     invoke_viiii(165,($18|0),($objectUri|0),($13|0),($objectType|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $V_0$0$in = $18;
      label = 11;
     }
    }
   }
  }
 }
 if ((label|0) == 11) {
  __THREW__ = 0;
  invoke_vii(1892,0,($V_0$0$in|0));
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if (!($24)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($V_0$0$in|0);
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Runtime_Remoting_RemotingServices_m_GetIdentityForUriP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$uri) {
 $__this = $__this|0;
 $uri = $uri|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $V_3$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489624);
 __THREW__ = 0;
 $0 = (invoke_iii(955,0,($uri|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2491144|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2491144 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2491144|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2491144|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3836,(2491144|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2491144|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2491144 + 80|0))>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,(0|0),($18|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2491144|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      do {
       if ($22) {
        label = 15;
       } else {
        $23 = HEAP8[((2491144 + 116|0))>>0]|0;
        $24 = ($23<<24>>24)==(0);
        if ($24) {
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if ($26) {
          label = 15;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          label = 15;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3836,(2491144|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          label = 15;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 15;
        } else {
         $41 = HEAP32[((2491144 + 80|0))>>2]|0;
         $42 = HEAP32[$41>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($42|0));
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          label = 15;
         } else {
          __THREW__ = 0;
          $45 = (invoke_iiii(1643,(2310848|0),($42|0),($0|0))|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           label = 15;
          } else {
           __THREW__ = 0;
           (invoke_ii(2996,(2486008|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            label = 15;
           } else {
            __THREW__ = 0;
            $50 = (invoke_iii(2764,($45|0),(2486008|0))|0);
            $51 = __THREW__; __THREW__ = 0;
            $52 = $51&1;
            if ($52) {
             label = 15;
            } else {
             $53 = ($50|0)==(0|0);
             if ($53) {
              __THREW__ = 0;
              $54 = (invoke_iii(954,0,($uri|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if ($56) {
               label = 15;
              } else {
               $57 = ($54|0)==(0|0);
               if ($57) {
                $V_3$0 = $50;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 79;
               } else {
                __THREW__ = 0;
                (invoke_ii(2996,(2491144|0))|0);
                $58 = __THREW__; __THREW__ = 0;
                $59 = $58&1;
                if ($59) {
                 label = 15;
                } else {
                 $60 = HEAP8[((2491144 + 116|0))>>0]|0;
                 $61 = ($60<<24>>24)==(0);
                 if ($61) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2491144|0))|0);
                  $62 = __THREW__; __THREW__ = 0;
                  $63 = $62&1;
                  if ($63) {
                   label = 15;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2491144|0))|0);
                  $64 = __THREW__; __THREW__ = 0;
                  $65 = $64&1;
                  if ($65) {
                   label = 15;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3836,(2491144|0));
                  $66 = __THREW__; __THREW__ = 0;
                  $67 = $66&1;
                  if ($67) {
                   label = 15;
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2491144|0))|0);
                 $68 = __THREW__; __THREW__ = 0;
                 $69 = $68&1;
                 if ($69) {
                  label = 15;
                 } else {
                  $70 = HEAP32[((2491144 + 80|0))>>2]|0;
                  $71 = HEAP32[$70>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($71|0));
                  $72 = __THREW__; __THREW__ = 0;
                  $73 = $72&1;
                  if ($73) {
                   label = 15;
                   break;
                  }
                  __THREW__ = 0;
                  $74 = (invoke_iiii(1643,(2310848|0),($71|0),($54|0))|0);
                  $75 = __THREW__; __THREW__ = 0;
                  $76 = $75&1;
                  if ($76) {
                   label = 15;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2486008|0))|0);
                  $77 = __THREW__; __THREW__ = 0;
                  $78 = $77&1;
                  if ($78) {
                   label = 15;
                   break;
                  }
                  __THREW__ = 0;
                  $79 = (invoke_iii(2764,($74|0),(2486008|0))|0);
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   label = 15;
                   break;
                  }
                  $V_3$0 = $79;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 79;
                 }
                }
               }
              }
             } else {
              $V_3$0 = $50;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 79;
             }
            }
           }
          }
         }
        }
       }
      } while(0);
      if ((label|0) == 15) {
       $31 = ___cxa_find_matching_catch(348288|0)|0;
       $32 = tempRet0;
       $33 = (_llvm_eh_typeid_for((348288|0))|0);
       $34 = ($32|0)==($33|0);
       if (!($34)) {
        $$02 = $31;$$03 = $32;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$02|0);
        // unreachable;
       }
       $35 = (___cxa_begin_catch(($31|0))|0);
       $36 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       invoke_v(66);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       $V_3$0 = 0;$__last_unhandled_exception$0 = $36;$leaveInstructions$sroa$0$0 = 0;
      }
      __THREW__ = 0;
      invoke_vii(1917,(0|0),($18|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if (!($83)) {
       $cond1 = ($leaveInstructions$sroa$0$0|0)==(79);
       if ($cond1) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($V_3$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3837,($__last_unhandled_exception$0|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if (!($85)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $$02 = $13;$$03 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Runtime_Remoting_ServerIdentity_m_get_ObjectTypeP47mscorlib_System_Runtime_Remoting_ServerIdentity($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2491328);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z71mscorlib_System_Runtime_Remoting_RemotingServices_m_FindInterfaceMethodP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringP24mscorlib_System_Type_arr($__this,$type,$methodName,$signature) {
 $__this = $__this|0;
 $type = $type|0;
 $methodName = $methodName|0;
 $signature = $signature|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $V_0$0$in = 0, $V_3$0 = 0;
 var $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489480);
 $0 = ($signature|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2491144|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = HEAP8[((2491144 + 116|0))>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2491144|0))|0);
     $5 = __THREW__; __THREW__ = 0;
     $6 = $5&1;
     if ($6) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2491144|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3836,(2491144|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2491144|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2491144 + 80|0))>>2]|0;
     $18 = (($17) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($type|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_iiiii(323,(2236384|0),($type|0),($methodName|0),($19|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       $V_0$0$in = $22;
       label = 21;
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2491144|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    $27 = HEAP8[((2491144 + 116|0))>>0]|0;
    $28 = ($27<<24>>24)==(0);
    if ($28) {
     __THREW__ = 0;
     (invoke_ii(2996,(2491144|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2491144|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3836,(2491144|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2491144|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $37 = HEAP32[((2491144 + 80|0))>>2]|0;
     $38 = (($37) + 20|0);
     $39 = HEAP32[$38>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($type|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if (!($41)) {
      __THREW__ = 0;
      $42 = (invoke_iiiiiiii(120,(2236432|0),($type|0),($methodName|0),($39|0),(0|0),($signature|0),(0|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       $V_0$0$in = $42;
       label = 21;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 21) {
  $45 = ($V_0$0$in|0)==(0|0);
  if (!($45)) {
   $$0 = $V_0$0$in;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($type|0));
  $46 = __THREW__; __THREW__ = 0;
  $47 = $46&1;
  if (!($47)) {
   __THREW__ = 0;
   $48 = (invoke_iii(2730,(2239448|0),($type|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    $51 = (($48) + 12|0);
    $V_3$0 = 0;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($48|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      label = 7;
      break;
     }
     $72 = HEAP32[$51>>2]|0;
     $73 = ($V_3$0|0)<($72|0);
     if (!($73)) {
      $$0 = 0;
      label = 34;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($48|0));
     $74 = __THREW__; __THREW__ = 0;
     $75 = $74&1;
     if ($75) {
      label = 7;
      break;
     }
     $52 = HEAP32[$51>>2]|0;
     $53 = ($V_3$0>>>0)<($52>>>0);
     if (!($53)) {
      __THREW__ = 0;
      $54 = (invoke_i(132)|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 7;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($54|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 7;
       break;
      }
     }
     $59 = HEAP32[$48>>2]|0;
     $60 = (($59) + 92|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = Math_imul($61, $V_3$0)|0;
     $$sum = (($62) + 16)|0;
     $63 = (($48) + ($$sum)|0);
     $64 = HEAP32[$63>>2]|0;
     __THREW__ = 0;
     $65 = (invoke_iiiii(147,0,($64|0),($methodName|0),($signature|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      label = 7;
      break;
     }
     $68 = ($65|0)==(0|0);
     $69 = (($V_3$0) + 1)|0;
     if ($68) {
      $V_3$0 = $69;
     } else {
      $$0 = $65;
      label = 34;
      break;
     }
    }
    if ((label|0) == 7) {
     $11 = ___cxa_find_matching_catch()|0;
     $12 = tempRet0;
     $lpad$phi$index = $11;$lpad$phi$index2 = $12;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 34) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $lpad$phi$index = $13;$lpad$phi$index2 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker5I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEP10MethodInfoPvS5_iS5_S5_S5_($method,$obj,$p1,$p2,$p3,$p4,$p5) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4,$p5)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z69mscorlib_System_Runtime_Remoting_RemotingServices_m_CreateClientProxyP22mscorlib_System_ObjectP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntryP26mscorlib_System_Object_arr($__this,$entry,$activationAttributes) {
 $__this = $__this|0;
 $entry = $entry|0;
 $activationAttributes = $activationAttributes|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489528);
 __THREW__ = 0;
 invoke_v(661);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($entry|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2320,0)|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     $8 = ($activationAttributes|0)==(0|0);
     if ($8) {
      __THREW__ = 0;
      invoke_vi(3799,($entry|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __THREW__ = 0;
      $45 = (invoke_ii(2321,($entry|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($entry|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      __THREW__ = 0;
      $50 = (invoke_ii(2319,($entry|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = HEAP32[3036648>>2]|0;
      __THREW__ = 0;
      $54 = (invoke_iiiiii(82,(0|0),($45|0),($50|0),(0|0),($53|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break;
      } else {
       $$0 = $54;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2304136|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      $11 = (invoke_ii(3469,(2304136|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       invoke_vi(2153,($11|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($entry|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if (!($17)) {
         __THREW__ = 0;
         (invoke_ii(2320,0)|0);
         $18 = __THREW__; __THREW__ = 0;
         $19 = $18&1;
         if (!($19)) {
          __THREW__ = 0;
          invoke_vi(3799,($11|0));
          $20 = __THREW__; __THREW__ = 0;
          $21 = $20&1;
          if (!($21)) {
           __THREW__ = 0;
           invoke_viii(2110,(2298968|0),($11|0),($activationAttributes|0));
           $22 = __THREW__; __THREW__ = 0;
           $23 = $22&1;
           if (!($23)) {
            __THREW__ = 0;
            invoke_vi(3799,($entry|0));
            $24 = __THREW__; __THREW__ = 0;
            $25 = $24&1;
            if (!($25)) {
             __THREW__ = 0;
             $26 = (invoke_ii(2321,($entry|0))|0);
             $27 = __THREW__; __THREW__ = 0;
             $28 = $27&1;
             if (!($28)) {
              __THREW__ = 0;
              invoke_vi(3799,($entry|0));
              $29 = __THREW__; __THREW__ = 0;
              $30 = $29&1;
              if (!($30)) {
               __THREW__ = 0;
               $31 = (invoke_ii(2319,($entry|0))|0);
               $32 = __THREW__; __THREW__ = 0;
               $33 = $32&1;
               if (!($33)) {
                __THREW__ = 0;
                invoke_vi(3799,($11|0));
                $34 = __THREW__; __THREW__ = 0;
                $35 = $34&1;
                if (!($35)) {
                 __THREW__ = 0;
                 $36 = (invoke_iii(2730,(2299160|0),($11|0))|0);
                 $37 = __THREW__; __THREW__ = 0;
                 $38 = $37&1;
                 if (!($38)) {
                  $39 = HEAP32[3036640>>2]|0;
                  __THREW__ = 0;
                  $40 = (invoke_iiiiii(82,(0|0),($26|0),($31|0),($36|0),($39|0))|0);
                  $41 = __THREW__; __THREW__ = 0;
                  $42 = $41&1;
                  if (!($42)) {
                   $$0 = $40;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($$0|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Runtime_Remoting_RemotingServices_m_CreateClientProxyForContextBoundP22mscorlib_System_ObjectP20mscorlib_System_TypeP26mscorlib_System_Object_arr($__this,$type,$activationAttributes) {
 $__this = $__this|0;
 $type = $type|0;
 $activationAttributes = $activationAttributes|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489576);
 __THREW__ = 0;
 invoke_vi(3799,($type|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2734,(2234280|0),($type|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    if ($3) {
     HEAP32[$0>>2] = 1642432;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $8 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iiiii(77,(0|0),($type|0),($8|0),1)|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2482008|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_iii(2764,($11|0),(2482008|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     $19 = ($16|0)==(0|0);
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3799,($16|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      $22 = (invoke_iiii(1645,(2481560|0),($16|0),($type|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      $$0 = $22;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2468768|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = HEAP8[((2468768 + 116|0))>>0]|0;
     $28 = ($27<<24>>24)==(0);
     if ($28) {
      __THREW__ = 0;
      (invoke_ii(2996,(2468768|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2468768|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3836,(2468768|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2468768|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      $37 = HEAP32[((2468768 + 80|0))>>2]|0;
      $38 = (($37) + 12|0);
      $39 = HEAP32[$38>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2483848|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       __THREW__ = 0;
       $42 = (invoke_ii(3469,(2483848|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if (!($44)) {
        __THREW__ = 0;
        invoke_viiii(163,($42|0),($type|0),($39|0),($activationAttributes|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         __THREW__ = 0;
         invoke_vi(3799,($42|0));
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if (!($48)) {
          __THREW__ = 0;
          $49 = (invoke_iii(2756,(2481608|0),($42|0))|0);
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if (!($51)) {
           $$0 = $49;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Runtime_Remoting_RemotingServices_m_GetNormalizedUriP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$uri) {
 $__this = $__this|0;
 $uri = $uri|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489912);
 __THREW__ = 0;
 invoke_v(662);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($uri|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[3036752>>2]|0;
   __THREW__ = 0;
   $5 = (invoke_iii(635,($uri|0),($4|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    if (!($5)) {
     $$0 = $uri;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($uri|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_iii(623,($uri|0),1)|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $$0 = $12;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z72mscorlib_System_Runtime_Remoting_RemotingServices_m_RemoveAppNameFromUriP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$uri) {
 $__this = $__this|0;
 $uri = $uri|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489672);
 __THREW__ = 0;
 invoke_v(663);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(2327,0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = HEAP32[3036664>>2]|0;
   $9 = HEAP32[3036672>>2]|0;
   __THREW__ = 0;
   $10 = (invoke_iiiii(101,(0|0),($8|0),($2|0),($9|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    invoke_vi(3799,($uri|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     $15 = (invoke_iii(635,($uri|0),($10|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      if (!($15)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($10|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(1816,($10|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vi(3799,($uri|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         $25 = (invoke_iii(623,($uri|0),($20|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          $$0 = $25;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Runtime_Remoting_SingleCallIdentity_m__ctorP51mscorlib_System_Runtime_Remoting_SingleCallIdentityP22mscorlib_System_StringP49mscorlib_System_Runtime_Remoting_Contexts_ContextP20mscorlib_System_Type($__this,$objectUri,$context,$objectType) {
 $__this = $__this|0;
 $objectUri = $objectUri|0;
 $context = $context|0;
 $objectType = $objectType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2492248);
 __THREW__ = 0;
 invoke_viiii(164,($__this|0),($objectUri|0),($context|0),($objectType|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z58mscorlib_System_Runtime_Remoting_SingletonIdentity_m__ctorP50mscorlib_System_Runtime_Remoting_SingletonIdentityP22mscorlib_System_StringP49mscorlib_System_Runtime_Remoting_Contexts_ContextP20mscorlib_System_Type($__this,$objectUri,$context,$objectType) {
 $__this = $__this|0;
 $objectUri = $objectUri|0;
 $context = $context|0;
 $objectType = $objectType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2491968);
 __THREW__ = 0;
 invoke_viiii(164,($__this|0),($objectUri|0),($context|0),($objectType|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z74mscorlib_System_Runtime_Remoting_RemotingServices_m_RegisterServerIdentityP22mscorlib_System_ObjectP47mscorlib_System_Runtime_Remoting_ServerIdentity($__this,$identity) {
 $__this = $__this|0;
 $identity = $identity|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2489768);
 __THREW__ = 0;
 invoke_v(664);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2491144|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2491144 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2491144|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2491144|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3836,(2491144|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2491144|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2491144 + 80|0))>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,(0|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2491144|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      do {
       if ($21) {
        label = 15;
       } else {
        $22 = HEAP8[((2491144 + 116|0))>>0]|0;
        $23 = ($22<<24>>24)==(0);
        if ($23) {
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          label = 15;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2491144|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          label = 15;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3836,(2491144|0));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          label = 15;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2491144|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         label = 15;
        } else {
         $40 = HEAP32[((2491144 + 80|0))>>2]|0;
         $41 = HEAP32[$40>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($identity|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 15;
         } else {
          __THREW__ = 0;
          $44 = (invoke_ii(2323,($identity|0))|0);
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           label = 15;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($41|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if ($48) {
            label = 15;
           } else {
            __THREW__ = 0;
            $49 = (invoke_iiii(1644,(2311328|0),($41|0),($44|0))|0);
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if ($51) {
             label = 15;
            } else {
             if ($49) {
              __THREW__ = 0;
              invoke_vi(3799,($identity|0));
              $52 = __THREW__; __THREW__ = 0;
              $53 = $52&1;
              if ($53) {
               label = 15;
               break;
              }
              __THREW__ = 0;
              $54 = (invoke_ii(2323,($identity|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if ($56) {
               label = 15;
               break;
              }
              $57 = HEAP32[3036688>>2]|0;
              $58 = HEAP32[3036696>>2]|0;
              __THREW__ = 0;
              $59 = (invoke_iiiii(101,(0|0),($57|0),($54|0),($58|0))|0);
              $60 = __THREW__; __THREW__ = 0;
              $61 = $60&1;
              if ($61) {
               label = 15;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2488992|0))|0);
              $62 = __THREW__; __THREW__ = 0;
              $63 = $62&1;
              if ($63) {
               label = 15;
               break;
              }
              __THREW__ = 0;
              $64 = (invoke_ii(3469,(2488992|0))|0);
              $65 = __THREW__; __THREW__ = 0;
              $66 = $65&1;
              if ($66) {
               label = 15;
               break;
              }
              __THREW__ = 0;
              invoke_vii(1891,($64|0),($59|0));
              $67 = __THREW__; __THREW__ = 0;
              $68 = $67&1;
              if ($68) {
               label = 15;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3837,($64|0));
              $69 = __THREW__; __THREW__ = 0;
              $70 = $69&1;
              if ($70) {
               label = 15;
               break;
              }
              // unreachable;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2491144|0))|0);
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if ($72) {
              label = 15;
             } else {
              $73 = HEAP8[((2491144 + 116|0))>>0]|0;
              $74 = ($73<<24>>24)==(0);
              if ($74) {
               __THREW__ = 0;
               (invoke_ii(2996,(2491144|0))|0);
               $75 = __THREW__; __THREW__ = 0;
               $76 = $75&1;
               if ($76) {
                label = 15;
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2491144|0))|0);
               $77 = __THREW__; __THREW__ = 0;
               $78 = $77&1;
               if ($78) {
                label = 15;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3836,(2491144|0));
               $79 = __THREW__; __THREW__ = 0;
               $80 = $79&1;
               if ($80) {
                label = 15;
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2491144|0))|0);
              $81 = __THREW__; __THREW__ = 0;
              $82 = $81&1;
              if ($82) {
               label = 15;
              } else {
               $83 = HEAP32[((2491144 + 80|0))>>2]|0;
               $84 = HEAP32[$83>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($identity|0));
               $85 = __THREW__; __THREW__ = 0;
               $86 = $85&1;
               if ($86) {
                label = 15;
               } else {
                __THREW__ = 0;
                $87 = (invoke_ii(2323,($identity|0))|0);
                $88 = __THREW__; __THREW__ = 0;
                $89 = $88&1;
                if ($89) {
                 label = 15;
                } else {
                 __THREW__ = 0;
                 invoke_vi(3799,($84|0));
                 $90 = __THREW__; __THREW__ = 0;
                 $91 = $90&1;
                 if ($91) {
                  label = 15;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiii(465,(2310992|0),($84|0),($87|0),($identity|0));
                 $92 = __THREW__; __THREW__ = 0;
                 $93 = $92&1;
                 if ($93) {
                  label = 15;
                 } else {
                  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 83;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      } while(0);
      if ((label|0) == 15) {
       $30 = ___cxa_find_matching_catch(348288|0)|0;
       $31 = tempRet0;
       $32 = (_llvm_eh_typeid_for((348288|0))|0);
       $33 = ($31|0)==($32|0);
       if (!($33)) {
        $$0 = $30;$$02 = $31;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$0|0);
        // unreachable;
       }
       $34 = (___cxa_begin_catch(($30|0))|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       invoke_v(66);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
       $__last_unhandled_exception$0 = $35;$leaveInstructions$sroa$0$0 = 0;
      }
      __THREW__ = 0;
      invoke_vii(1917,(0|0),($17|0));
      $94 = __THREW__; __THREW__ = 0;
      $95 = $94&1;
      if (!($95)) {
       $cond1 = ($leaveInstructions$sroa$0$0|0)==(83);
       if ($cond1) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       invoke_vi(3837,($__last_unhandled_exception$0|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $$0 = $12;$$02 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z80mscorlib_System_Runtime_Remoting_RemotingServices_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_Runtime_Remoting_ServerIdentity_m__ctorP47mscorlib_System_Runtime_Remoting_ServerIdentityP22mscorlib_System_StringP49mscorlib_System_Runtime_Remoting_Contexts_ContextP20mscorlib_System_Type($__this,$objectUri,$context,$objectType) {
 $__this = $__this|0;
 $objectUri = $objectUri|0;
 $context = $context|0;
 $objectType = $objectType|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2491280);
 __THREW__ = 0;
 invoke_vii(1886,($__this|0),($objectUri|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 24|0);
  HEAP32[$2>>2] = $objectType;
  $3 = (($__this) + 28|0);
  HEAP32[$3>>2] = $context;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62mscorlib_System_Runtime_Remoting_ServerIdentity_m_CreateObjRefP47mscorlib_System_Runtime_Remoting_ServerIdentityP20mscorlib_System_Type($__this,$requestedType) {
 $__this = $__this|0;
 $requestedType = $requestedType|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2491376);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $9 = ($requestedType|0)==(0|0);
   if ($9) {
    $10 = (($__this) + 24|0);
    $11 = HEAP32[$10>>2]|0;
    $$01 = $11;
   } else {
    $$01 = $requestedType;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2487504|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2487504|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __THREW__ = 0;
     invoke_vi(2433,($14|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      HEAP32[$0>>2] = $14;
      __THREW__ = 0;
      (invoke_ii(2996,(2493312|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_ii(3469,(2493312|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vii(1894,($21|0),($$01|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         invoke_vi(3799,($14|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          invoke_viii(2110,(2486664|0),($14|0),($21|0));
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if (!($29)) {
           $30 = HEAP32[$0>>2]|0;
           $31 = (($__this) + 8|0);
           $32 = HEAP32[$31>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($30|0));
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if (!($34)) {
            __THREW__ = 0;
            invoke_viii(2110,(2486712|0),($30|0),($32|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if (!($36)) {
             $37 = (($__this) + 12|0);
             $38 = HEAP32[$37>>2]|0;
             $39 = ($38|0)==(0|0);
             if ($39) {
              $$0 = HEAP32[$0>>2]|0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2475808|0))|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if (!($41)) {
              __THREW__ = 0;
              $42 = (invoke_iii(2735,($38|0),(2475808|0))|0);
              $43 = __THREW__; __THREW__ = 0;
              $44 = $43&1;
              if (!($44)) {
               $45 = ($42|0)==(0|0);
               if (!($45)) {
                $$0 = HEAP32[$0>>2]|0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               $46 = HEAP32[$0>>2]|0;
               $47 = HEAP32[$37>>2]|0;
               __THREW__ = 0;
               (invoke_ii(2996,(2484768|0))|0);
               $48 = __THREW__; __THREW__ = 0;
               $49 = $48&1;
               if (!($49)) {
                __THREW__ = 0;
                $50 = (invoke_ii(3469,(2484768|0))|0);
                $51 = __THREW__; __THREW__ = 0;
                $52 = $51&1;
                if (!($52)) {
                 __THREW__ = 0;
                 invoke_vii(1885,($50|0),($47|0));
                 $53 = __THREW__; __THREW__ = 0;
                 $54 = $53&1;
                 if (!($54)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($46|0));
                  $55 = __THREW__; __THREW__ = 0;
                  $56 = $55&1;
                  if ($56) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(2110,(2486616|0),($46|0),($50|0));
                  $57 = __THREW__; __THREW__ = 0;
                  $58 = $57&1;
                  if ($58) {
                   break;
                  }
                  $$0 = HEAP32[$0>>2]|0;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($1|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(2435,($1|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $$0 = HEAP32[$0>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Runtime_Remoting_TypeInfo_m__ctorP41mscorlib_System_Runtime_Remoting_TypeInfoP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $$byval_copy11 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_1$0$in = 0, $V_1$1$in9 = 0, $V_2$08 = 0, $V_4$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy11 = sp + 16|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2492968);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($type|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2734,(2234184|0),($type|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     if ($7) {
      HEAP32[$0>>2] = 2266512;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$0+0>>2]|0;
      $18 = (invoke_iii(772,(0|0),($$byval_copy11|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($18|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_iii(2730,(2238368|0),($18|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = (($__this) + 8|0);
      HEAP32[$26>>2] = $23;
      __THREW__ = 0;
      (invoke_ii(2996,(1168432|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2765,(1168432|0),0)|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = (($__this) + 12|0);
      HEAP32[$32>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1168432|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_iii(2765,(1168432|0),1)|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($type|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      $40 = (invoke_iii(2730,(2238368|0),($type|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($35|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      $45 = (($35) + 12|0);
      $46 = HEAP32[$45>>2]|0;
      $47 = ($46|0)==(0);
      if ($47) {
       __THREW__ = 0;
       $48 = (invoke_i(132)|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($48|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($35|0),($40|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = (($35) + 16|0);
      HEAP32[$55>>2] = $40;
      $56 = (($__this) + 16|0);
      HEAP32[$56>>2] = $35;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3799,($type|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if (!($58)) {
      __THREW__ = 0;
      $59 = (invoke_iii(2730,(2238368|0),($type|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if (!($61)) {
       $62 = (($__this) + 8|0);
       HEAP32[$62>>2] = $59;
       __THREW__ = 0;
       invoke_vi(3799,($type|0));
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if (!($64)) {
        __THREW__ = 0;
        $65 = (invoke_iii(2730,(2235944|0),($type|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if (!($67)) {
         $V_0$0 = 0;$V_1$0$in = $65;
         while(1) {
          HEAP32[$1>>2] = 2266512;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$1+0>>2]|0;
          $72 = (invoke_iii(772,(0|0),($$byval_copy11|0))|0);
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           label = 7;
           break;
          }
          $75 = ($V_1$0$in|0)==($72|0);
          if ($75) {
           break;
          }
          HEAP32[$2>>2] = 1284448;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy11+0>>2]=HEAP32[$2+0>>2]|0;
          $76 = (invoke_iii(772,(0|0),($$byval_copy11|0))|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           label = 7;
           break;
          }
          $79 = ($V_1$0$in|0)==($76|0);
          if ($79) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($V_1$0$in|0));
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          if ($81) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          $68 = (invoke_iii(2730,(2235944|0),($V_1$0$in|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           label = 7;
           break;
          }
          $71 = (($V_0$0) + 1)|0;
          $V_0$0 = $71;$V_1$0$in = $68;
         }
         if ((label|0) == 7) {
          $14 = ___cxa_find_matching_catch()|0;
          $15 = tempRet0;
          $lpad$phi$index = $14;$lpad$phi$index4 = $15;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1168432|0))|0);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if (!($83)) {
          __THREW__ = 0;
          $84 = (invoke_iii(2765,(1168432|0),($V_0$0|0))|0);
          $85 = __THREW__; __THREW__ = 0;
          $86 = $85&1;
          if (!($86)) {
           $87 = (($__this) + 12|0);
           HEAP32[$87>>2] = $84;
           __THREW__ = 0;
           invoke_vi(3799,($type|0));
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if (!($89)) {
            __THREW__ = 0;
            $90 = (invoke_iii(2730,(2235944|0),($type|0))|0);
            $91 = __THREW__; __THREW__ = 0;
            $92 = $91&1;
            if (!($92)) {
             $93 = ($V_0$0|0)>(0);
             L44: do {
              if ($93) {
               $V_1$1$in9 = $90;$V_2$08 = 0;
               while(1) {
                $97 = HEAP32[$87>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($V_1$1$in9|0));
                $123 = __THREW__; __THREW__ = 0;
                $124 = $123&1;
                if ($124) {
                 break;
                }
                __THREW__ = 0;
                $94 = (invoke_iii(2730,(2238368|0),($V_1$1$in9|0))|0);
                $95 = __THREW__; __THREW__ = 0;
                $96 = $95&1;
                if ($96) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($97|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 break;
                }
                $100 = (($97) + 12|0);
                $101 = HEAP32[$100>>2]|0;
                $102 = ($V_2$08>>>0)<($101>>>0);
                if (!($102)) {
                 __THREW__ = 0;
                 $103 = (invoke_i(132)|0);
                 $104 = __THREW__; __THREW__ = 0;
                 $105 = $104&1;
                 if ($105) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($103|0));
                 $106 = __THREW__; __THREW__ = 0;
                 $107 = $106&1;
                 if ($107) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($97|0),($94|0));
                $108 = __THREW__; __THREW__ = 0;
                $109 = $108&1;
                if ($109) {
                 break;
                }
                $110 = HEAP32[$97>>2]|0;
                $111 = (($97) + 16|0);
                $112 = (($110) + 92|0);
                $113 = HEAP32[$112>>2]|0;
                $114 = Math_imul($113, $V_2$08)|0;
                $115 = (($111) + ($114)|0);
                HEAP32[$115>>2] = $94;
                __THREW__ = 0;
                invoke_vi(3799,($V_1$1$in9|0));
                $116 = __THREW__; __THREW__ = 0;
                $117 = $116&1;
                if ($117) {
                 break;
                }
                __THREW__ = 0;
                $118 = (invoke_iii(2730,(2235944|0),($V_1$1$in9|0))|0);
                $119 = __THREW__; __THREW__ = 0;
                $120 = $119&1;
                if ($120) {
                 break;
                }
                $121 = (($V_2$08) + 1)|0;
                $122 = ($121|0)<($V_0$0|0);
                if ($122) {
                 $V_1$1$in9 = $118;$V_2$08 = $121;
                } else {
                 break L44;
                }
               }
               $12 = ___cxa_find_matching_catch()|0;
               $13 = tempRet0;
               $lpad$phi$index = $12;$lpad$phi$index4 = $13;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($lpad$phi$index|0);
               // unreachable;
              }
             } while(0);
             __THREW__ = 0;
             invoke_vi(3799,($type|0));
             $125 = __THREW__; __THREW__ = 0;
             $126 = $125&1;
             if (!($126)) {
              __THREW__ = 0;
              $127 = (invoke_iii(2730,(2239448|0),($type|0))|0);
              $128 = __THREW__; __THREW__ = 0;
              $129 = $128&1;
              if (!($129)) {
               __THREW__ = 0;
               invoke_vi(3799,($127|0));
               $130 = __THREW__; __THREW__ = 0;
               $131 = $130&1;
               if (!($131)) {
                $132 = (($127) + 12|0);
                $133 = HEAP32[$132>>2]|0;
                __THREW__ = 0;
                (invoke_ii(2996,(1168432|0))|0);
                $134 = __THREW__; __THREW__ = 0;
                $135 = $134&1;
                if (!($135)) {
                 __THREW__ = 0;
                 $136 = (invoke_iii(2765,(1168432|0),($133|0))|0);
                 $137 = __THREW__; __THREW__ = 0;
                 $138 = $137&1;
                 if (!($138)) {
                  $139 = (($__this) + 16|0);
                  HEAP32[$139>>2] = $136;
                  $V_4$0 = 0;
                  while(1) {
                   __THREW__ = 0;
                   invoke_vi(3799,($127|0));
                   $178 = __THREW__; __THREW__ = 0;
                   $179 = $178&1;
                   if ($179) {
                    break;
                   }
                   $180 = HEAP32[$132>>2]|0;
                   $181 = ($V_4$0|0)<($180|0);
                   if (!($181)) {
                    label = 72;
                    break;
                   }
                   $158 = HEAP32[$139>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($127|0));
                   $182 = __THREW__; __THREW__ = 0;
                   $183 = $182&1;
                   if ($183) {
                    break;
                   }
                   $140 = HEAP32[$132>>2]|0;
                   $141 = ($V_4$0>>>0)<($140>>>0);
                   if (!($141)) {
                    __THREW__ = 0;
                    $142 = (invoke_i(132)|0);
                    $143 = __THREW__; __THREW__ = 0;
                    $144 = $143&1;
                    if ($144) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($142|0));
                    $145 = __THREW__; __THREW__ = 0;
                    $146 = $145&1;
                    if ($146) {
                     break;
                    }
                   }
                   $147 = HEAP32[$127>>2]|0;
                   $148 = (($147) + 92|0);
                   $149 = HEAP32[$148>>2]|0;
                   $150 = Math_imul($149, $V_4$0)|0;
                   $$sum = (($150) + 16)|0;
                   $151 = (($127) + ($$sum)|0);
                   $152 = HEAP32[$151>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($152|0));
                   $153 = __THREW__; __THREW__ = 0;
                   $154 = $153&1;
                   if ($154) {
                    break;
                   }
                   __THREW__ = 0;
                   $155 = (invoke_iii(2730,(2238368|0),($152|0))|0);
                   $156 = __THREW__; __THREW__ = 0;
                   $157 = $156&1;
                   if ($157) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($158|0));
                   $159 = __THREW__; __THREW__ = 0;
                   $160 = $159&1;
                   if ($160) {
                    break;
                   }
                   $161 = (($158) + 12|0);
                   $162 = HEAP32[$161>>2]|0;
                   $163 = ($V_4$0>>>0)<($162>>>0);
                   if (!($163)) {
                    __THREW__ = 0;
                    $164 = (invoke_i(132)|0);
                    $165 = __THREW__; __THREW__ = 0;
                    $166 = $165&1;
                    if ($166) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($164|0));
                    $167 = __THREW__; __THREW__ = 0;
                    $168 = $167&1;
                    if ($168) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($158|0),($155|0));
                   $169 = __THREW__; __THREW__ = 0;
                   $170 = $169&1;
                   if ($170) {
                    break;
                   }
                   $171 = HEAP32[$158>>2]|0;
                   $172 = (($158) + 16|0);
                   $173 = (($171) + 92|0);
                   $174 = HEAP32[$173>>2]|0;
                   $175 = Math_imul($174, $V_4$0)|0;
                   $176 = (($172) + ($175)|0);
                   HEAP32[$176>>2] = $155;
                   $177 = (($V_4$0) + 1)|0;
                   $V_4$0 = $177;
                  }
                  if ((label|0) == 72) {
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                  $10 = ___cxa_find_matching_catch()|0;
                  $11 = tempRet0;
                  $lpad$phi$index = $10;$lpad$phi$index4 = $11;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($lpad$phi$index|0);
                  // unreachable;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 $lpad$phi$index = $16;$lpad$phi$index4 = $17;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z73mscorlib_System_Runtime_Remoting_TypeEntry_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z56mscorlib_System_Runtime_Remoting_TypeInfo_m_get_TypeNameP41mscorlib_System_Runtime_Remoting_TypeInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2493016);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z83mscorlib_System_Runtime_Remoting_WellKnownObjectMode_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z102mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatter_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z102mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z98mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z95mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z93mscorlib_System_Runtime_Serialization_IDeserializationCallback_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z79mscorlib_System_Runtime_Serialization_IFormatter_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Runtime_Serialization_IFormatterConverter_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Runtime_Serialization_IObjectReference_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_Runtime_Serialization_ISerializationSurrogate_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_Runtime_Serialization_ISurrogateSelector_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_Runtime_Serialization_SerializationEntry_m__ctorP56mscorlib_System_Runtime_Serialization_SerializationEntryP22mscorlib_System_StringP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$name,$type,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $type = $type|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2497112);
 HEAP32[$__this>>2] = $name;
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $type;
 $1 = (($__this) + 8|0);
 HEAP32[$1>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFvPvS3_S3_P22mscorlib_System_ObjectES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$4);
 STACKTOP = sp;return (0|0);
}
function __Z87mscorlib_System_Runtime_Serialization_SerializationEntry_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_Runtime_Serialization_SerializationException_m__ctorP60mscorlib_System_Runtime_Serialization_SerializationExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2497528);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z91mscorlib_System_Runtime_Serialization_SerializationException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int16P55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Strings($__this,$name,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $value = $value|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 12|0;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2497976);
 HEAP16[$L_0>>1] = $value;
 __THREW__ = 0;
 (invoke_ii(2996,(2173776|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2724,(2173776|0),($L_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$0>>2] = 1691416;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $6 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiii(168,($__this|0),($name|0),($3|0),($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z134mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringb($__this,$name,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $value = $value|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 12|0;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2498072);
 $1 = $value&1;
 HEAP8[$L_0>>0] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2208584|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2724,(2208584|0),($L_0|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   HEAP32[$0>>2] = 1284952;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $7 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_viiii(168,($__this|0),($name|0),($4|0),($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z135mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_DateTimeP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_String24mscorlib_System_DateTime($__this,$name,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $value = $value|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $0 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2498120);
 ;HEAP32[$L_0+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$value+12>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2724,(2592096|0),($L_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$0>>2] = 1692712;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $6 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiii(168,($__this|0),($name|0),($3|0),($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z133mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_SingleP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringf($__this,$name,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $value = Math_fround($value);
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $0 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2498168);
 HEAPF32[$L_0>>2] = $value;
 __THREW__ = 0;
 (invoke_ii(2996,(2194912|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2724,(2194912|0),($L_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   HEAP32[$0>>2] = 1285152;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $6 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiii(168,($__this|0),($name|0),($3|0),($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z132mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int64P55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringx($__this,$name,$0,$1) {
 $__this = $__this|0;
 $name = $name|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_0 = sp;
 $2 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2498216);
 $3 = $L_0;
 $4 = $3;
 HEAP32[$4>>2] = $0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2162248|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __THREW__ = 0;
  $9 = (invoke_iii(2724,(2162248|0),($L_0|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   HEAP32[$2>>2] = 1691360;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   $12 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    invoke_viiii(168,($__this|0),($name|0),($9|0),($12|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z133mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_UInt64P55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringy($__this,$name,$0,$1) {
 $__this = $__this|0;
 $name = $name|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_0 = sp;
 $2 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2498264);
 $3 = $L_0;
 $4 = $3;
 HEAP32[$4>>2] = $0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $1;
 __THREW__ = 0;
 (invoke_ii(2996,(2167208|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __THREW__ = 0;
  $9 = (invoke_iii(2724,(2167208|0),($L_0|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   HEAP32[$2>>2] = 2045848;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
   $12 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    invoke_viiii(168,($__this|0),($name|0),($9|0),($12|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __ZN14ActionInvoker2I17VoidPointerTraits27mscorlib_System_Int16TraitsE6InvokeEPFvPvS3_sES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP16[$2>>1]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$3);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits30mscorlib_System_DateTimeTraitsE6InvokeEPFvPvS3_24mscorlib_System_DateTimeES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits28mscorlib_System_UInt64TraitsE6InvokeEPFvPvS3_yES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$5,$8);
 STACKTOP = sp;return (0|0);
}
function __Z86mscorlib_System_Runtime_Serialization_SerializationInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z220mscorlib_System_Runtime_Serialization_SerializationInfo_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_Runtime_Serialization_StreamingContext_m_EqualsP54mscorlib_System_Runtime_Serialization_StreamingContextP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2499160);
 __THREW__ = 0;
 (invoke_ii(2996,(2499464|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2499464|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2499464|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2766,($obj|0),(2499464|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[$10>>2]|0;
     $14 = HEAP32[$__this>>2]|0;
     $15 = ($13|0)==($14|0);
     if (!($15)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $16 = (($10) + 4|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($__this) + 4|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = ($17|0)==($19|0);
     $$0 = $20;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Runtime_Serialization_StreamingContext_m_GetHashCodeP54mscorlib_System_Runtime_Serialization_StreamingContext($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2499208);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z85mscorlib_System_Runtime_Serialization_StreamingContext_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z91mscorlib_System_Runtime_Serialization_StreamingContextStates_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Security_Cryptography_AsymmetricAlgorithm_m_System_IDisposable_DisposeP57mscorlib_System_Security_Cryptography_AsymmetricAlgorithm($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2500352);
 __THREW__ = 0;
 invoke_viii(2122,(2500400|0),($__this|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1941,(0|0),($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z71mscorlib_System_Security_Cryptography_AsymmetricAlgorithm_m_get_KeySizeP57mscorlib_System_Security_Cryptography_AsymmetricAlgorithm($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2500448);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z88mscorlib_System_Security_Cryptography_AsymmetricAlgorithm_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_Security_Cryptography_CryptoConfig_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2500904);
 __THREW__ = 0;
 (invoke_ii(2996,(2149728|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2149728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1924,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2501376|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2501376 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z63mscorlib_System_Security_Cryptography_CryptoConfig_m_InitializeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2500952);
 __THREW__ = 0;
 invoke_v(665);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2305768|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(2305768|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(2159,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2304904|0))|0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if (!($10)) {
       __THREW__ = 0;
       $11 = (invoke_ii(3469,(2304904|0))|0);
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        __THREW__ = 0;
        invoke_vi(2156,($11|0));
        $14 = __THREW__; __THREW__ = 0;
        $15 = $14&1;
        if (!($15)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2313960|0))|0);
         $16 = __THREW__; __THREW__ = 0;
         $17 = $16&1;
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_ii(3469,(2313960|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           __THREW__ = 0;
           invoke_viii(575,($18|0),($4|0),($11|0));
           $21 = __THREW__; __THREW__ = 0;
           $22 = $21&1;
           if (!($22)) {
            __THREW__ = 0;
            invoke_vi(3799,($18|0));
            $23 = __THREW__; __THREW__ = 0;
            $24 = $23&1;
            if (!($24)) {
             $25 = HEAP32[3036968>>2]|0;
             $26 = HEAP32[3036976>>2]|0;
             __THREW__ = 0;
             invoke_viiii(465,(2311184|0),($18|0),($25|0),($26|0));
             $27 = __THREW__; __THREW__ = 0;
             $28 = $27&1;
             if (!($28)) {
              __THREW__ = 0;
              invoke_vi(3799,($18|0));
              $29 = __THREW__; __THREW__ = 0;
              $30 = $29&1;
              if (!($30)) {
               $31 = HEAP32[3036984>>2]|0;
               $32 = HEAP32[3036992>>2]|0;
               __THREW__ = 0;
               invoke_viiii(465,(2311184|0),($18|0),($31|0),($32|0));
               $33 = __THREW__; __THREW__ = 0;
               $34 = $33&1;
               if (!($34)) {
                __THREW__ = 0;
                invoke_vi(3799,($18|0));
                $35 = __THREW__; __THREW__ = 0;
                $36 = $35&1;
                if (!($36)) {
                 $37 = HEAP32[3037000>>2]|0;
                 $38 = HEAP32[3037008>>2]|0;
                 __THREW__ = 0;
                 invoke_viiii(465,(2311184|0),($18|0),($37|0),($38|0));
                 $39 = __THREW__; __THREW__ = 0;
                 $40 = $39&1;
                 if (!($40)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($18|0));
                  $41 = __THREW__; __THREW__ = 0;
                  $42 = $41&1;
                  if (!($42)) {
                   $43 = HEAP32[3037016>>2]|0;
                   $44 = HEAP32[3037024>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii(465,(2311184|0),($18|0),($43|0),($44|0));
                   $45 = __THREW__; __THREW__ = 0;
                   $46 = $45&1;
                   if (!($46)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($18|0));
                    $47 = __THREW__; __THREW__ = 0;
                    $48 = $47&1;
                    if (!($48)) {
                     $49 = HEAP32[3037032>>2]|0;
                     $50 = HEAP32[3037040>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($49|0),($50|0));
                     $51 = __THREW__; __THREW__ = 0;
                     $52 = $51&1;
                     if ($52) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $53 = __THREW__; __THREW__ = 0;
                     $54 = $53&1;
                     if ($54) {
                      break;
                     }
                     $55 = HEAP32[3037048>>2]|0;
                     $56 = HEAP32[3037056>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($55|0),($56|0));
                     $57 = __THREW__; __THREW__ = 0;
                     $58 = $57&1;
                     if ($58) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $59 = __THREW__; __THREW__ = 0;
                     $60 = $59&1;
                     if ($60) {
                      break;
                     }
                     $61 = HEAP32[3037064>>2]|0;
                     $62 = HEAP32[3037072>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($61|0),($62|0));
                     $63 = __THREW__; __THREW__ = 0;
                     $64 = $63&1;
                     if ($64) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $65 = __THREW__; __THREW__ = 0;
                     $66 = $65&1;
                     if ($66) {
                      break;
                     }
                     $67 = HEAP32[3037080>>2]|0;
                     $68 = HEAP32[3037088>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($67|0),($68|0));
                     $69 = __THREW__; __THREW__ = 0;
                     $70 = $69&1;
                     if ($70) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $71 = __THREW__; __THREW__ = 0;
                     $72 = $71&1;
                     if ($72) {
                      break;
                     }
                     $73 = HEAP32[3037096>>2]|0;
                     $74 = HEAP32[3037104>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($73|0),($74|0));
                     $75 = __THREW__; __THREW__ = 0;
                     $76 = $75&1;
                     if ($76) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $77 = __THREW__; __THREW__ = 0;
                     $78 = $77&1;
                     if ($78) {
                      break;
                     }
                     $79 = HEAP32[3037112>>2]|0;
                     $80 = HEAP32[3037120>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($79|0),($80|0));
                     $81 = __THREW__; __THREW__ = 0;
                     $82 = $81&1;
                     if ($82) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $83 = __THREW__; __THREW__ = 0;
                     $84 = $83&1;
                     if ($84) {
                      break;
                     }
                     $85 = HEAP32[3037128>>2]|0;
                     $86 = HEAP32[3037136>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($85|0),($86|0));
                     $87 = __THREW__; __THREW__ = 0;
                     $88 = $87&1;
                     if ($88) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $89 = __THREW__; __THREW__ = 0;
                     $90 = $89&1;
                     if ($90) {
                      break;
                     }
                     $91 = HEAP32[3037144>>2]|0;
                     $92 = HEAP32[3037152>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($91|0),($92|0));
                     $93 = __THREW__; __THREW__ = 0;
                     $94 = $93&1;
                     if ($94) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $95 = __THREW__; __THREW__ = 0;
                     $96 = $95&1;
                     if ($96) {
                      break;
                     }
                     $97 = HEAP32[3037160>>2]|0;
                     $98 = HEAP32[3037168>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($97|0),($98|0));
                     $99 = __THREW__; __THREW__ = 0;
                     $100 = $99&1;
                     if ($100) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $101 = __THREW__; __THREW__ = 0;
                     $102 = $101&1;
                     if ($102) {
                      break;
                     }
                     $103 = HEAP32[3037176>>2]|0;
                     $104 = HEAP32[3037184>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($103|0),($104|0));
                     $105 = __THREW__; __THREW__ = 0;
                     $106 = $105&1;
                     if ($106) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $107 = __THREW__; __THREW__ = 0;
                     $108 = $107&1;
                     if ($108) {
                      break;
                     }
                     $109 = HEAP32[3037192>>2]|0;
                     $110 = HEAP32[3037200>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($109|0),($110|0));
                     $111 = __THREW__; __THREW__ = 0;
                     $112 = $111&1;
                     if ($112) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $113 = __THREW__; __THREW__ = 0;
                     $114 = $113&1;
                     if ($114) {
                      break;
                     }
                     $115 = HEAP32[3037208>>2]|0;
                     $116 = HEAP32[3037216>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($115|0),($116|0));
                     $117 = __THREW__; __THREW__ = 0;
                     $118 = $117&1;
                     if ($118) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $119 = __THREW__; __THREW__ = 0;
                     $120 = $119&1;
                     if ($120) {
                      break;
                     }
                     $121 = HEAP32[3037224>>2]|0;
                     $122 = HEAP32[3037232>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($121|0),($122|0));
                     $123 = __THREW__; __THREW__ = 0;
                     $124 = $123&1;
                     if ($124) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $125 = __THREW__; __THREW__ = 0;
                     $126 = $125&1;
                     if ($126) {
                      break;
                     }
                     $127 = HEAP32[3037240>>2]|0;
                     $128 = HEAP32[3037248>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($127|0),($128|0));
                     $129 = __THREW__; __THREW__ = 0;
                     $130 = $129&1;
                     if ($130) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $131 = __THREW__; __THREW__ = 0;
                     $132 = $131&1;
                     if ($132) {
                      break;
                     }
                     $133 = HEAP32[3037256>>2]|0;
                     $134 = HEAP32[3037264>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($133|0),($134|0));
                     $135 = __THREW__; __THREW__ = 0;
                     $136 = $135&1;
                     if ($136) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $137 = __THREW__; __THREW__ = 0;
                     $138 = $137&1;
                     if ($138) {
                      break;
                     }
                     $139 = HEAP32[3037272>>2]|0;
                     $140 = HEAP32[3037280>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($139|0),($140|0));
                     $141 = __THREW__; __THREW__ = 0;
                     $142 = $141&1;
                     if ($142) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $143 = __THREW__; __THREW__ = 0;
                     $144 = $143&1;
                     if ($144) {
                      break;
                     }
                     $145 = HEAP32[3037288>>2]|0;
                     $146 = HEAP32[3037296>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($145|0),($146|0));
                     $147 = __THREW__; __THREW__ = 0;
                     $148 = $147&1;
                     if ($148) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $149 = __THREW__; __THREW__ = 0;
                     $150 = $149&1;
                     if ($150) {
                      break;
                     }
                     $151 = HEAP32[3037304>>2]|0;
                     $152 = HEAP32[3037312>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($151|0),($152|0));
                     $153 = __THREW__; __THREW__ = 0;
                     $154 = $153&1;
                     if ($154) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $155 = __THREW__; __THREW__ = 0;
                     $156 = $155&1;
                     if ($156) {
                      break;
                     }
                     $157 = HEAP32[3037320>>2]|0;
                     $158 = HEAP32[3037328>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($157|0),($158|0));
                     $159 = __THREW__; __THREW__ = 0;
                     $160 = $159&1;
                     if ($160) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $161 = __THREW__; __THREW__ = 0;
                     $162 = $161&1;
                     if ($162) {
                      break;
                     }
                     $163 = HEAP32[3037336>>2]|0;
                     $164 = HEAP32[3037344>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($163|0),($164|0));
                     $165 = __THREW__; __THREW__ = 0;
                     $166 = $165&1;
                     if ($166) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $167 = __THREW__; __THREW__ = 0;
                     $168 = $167&1;
                     if ($168) {
                      break;
                     }
                     $169 = HEAP32[3037352>>2]|0;
                     $170 = HEAP32[3037360>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($169|0),($170|0));
                     $171 = __THREW__; __THREW__ = 0;
                     $172 = $171&1;
                     if ($172) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $173 = __THREW__; __THREW__ = 0;
                     $174 = $173&1;
                     if ($174) {
                      break;
                     }
                     $175 = HEAP32[3037368>>2]|0;
                     $176 = HEAP32[3037376>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($175|0),($176|0));
                     $177 = __THREW__; __THREW__ = 0;
                     $178 = $177&1;
                     if ($178) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $179 = __THREW__; __THREW__ = 0;
                     $180 = $179&1;
                     if ($180) {
                      break;
                     }
                     $181 = HEAP32[3037384>>2]|0;
                     $182 = HEAP32[3037392>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($181|0),($182|0));
                     $183 = __THREW__; __THREW__ = 0;
                     $184 = $183&1;
                     if ($184) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $185 = __THREW__; __THREW__ = 0;
                     $186 = $185&1;
                     if ($186) {
                      break;
                     }
                     $187 = HEAP32[3037400>>2]|0;
                     $188 = HEAP32[3037408>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($187|0),($188|0));
                     $189 = __THREW__; __THREW__ = 0;
                     $190 = $189&1;
                     if ($190) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $191 = __THREW__; __THREW__ = 0;
                     $192 = $191&1;
                     if ($192) {
                      break;
                     }
                     $193 = HEAP32[3037416>>2]|0;
                     $194 = HEAP32[3037424>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($193|0),($194|0));
                     $195 = __THREW__; __THREW__ = 0;
                     $196 = $195&1;
                     if ($196) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $197 = __THREW__; __THREW__ = 0;
                     $198 = $197&1;
                     if ($198) {
                      break;
                     }
                     $199 = HEAP32[3037432>>2]|0;
                     $200 = HEAP32[3037440>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($199|0),($200|0));
                     $201 = __THREW__; __THREW__ = 0;
                     $202 = $201&1;
                     if ($202) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $203 = __THREW__; __THREW__ = 0;
                     $204 = $203&1;
                     if ($204) {
                      break;
                     }
                     $205 = HEAP32[3037448>>2]|0;
                     $206 = HEAP32[3037456>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($205|0),($206|0));
                     $207 = __THREW__; __THREW__ = 0;
                     $208 = $207&1;
                     if ($208) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $209 = __THREW__; __THREW__ = 0;
                     $210 = $209&1;
                     if ($210) {
                      break;
                     }
                     $211 = HEAP32[3037464>>2]|0;
                     $212 = HEAP32[3037472>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($211|0),($212|0));
                     $213 = __THREW__; __THREW__ = 0;
                     $214 = $213&1;
                     if ($214) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $215 = __THREW__; __THREW__ = 0;
                     $216 = $215&1;
                     if ($216) {
                      break;
                     }
                     $217 = HEAP32[3037480>>2]|0;
                     $218 = HEAP32[3037488>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($217|0),($218|0));
                     $219 = __THREW__; __THREW__ = 0;
                     $220 = $219&1;
                     if ($220) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $221 = __THREW__; __THREW__ = 0;
                     $222 = $221&1;
                     if ($222) {
                      break;
                     }
                     $223 = HEAP32[3037496>>2]|0;
                     $224 = HEAP32[3037504>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($223|0),($224|0));
                     $225 = __THREW__; __THREW__ = 0;
                     $226 = $225&1;
                     if ($226) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $227 = __THREW__; __THREW__ = 0;
                     $228 = $227&1;
                     if ($228) {
                      break;
                     }
                     $229 = HEAP32[3037512>>2]|0;
                     $230 = HEAP32[3037520>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($229|0),($230|0));
                     $231 = __THREW__; __THREW__ = 0;
                     $232 = $231&1;
                     if ($232) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $233 = __THREW__; __THREW__ = 0;
                     $234 = $233&1;
                     if ($234) {
                      break;
                     }
                     $235 = HEAP32[3037528>>2]|0;
                     $236 = HEAP32[3037536>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($235|0),($236|0));
                     $237 = __THREW__; __THREW__ = 0;
                     $238 = $237&1;
                     if ($238) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $239 = __THREW__; __THREW__ = 0;
                     $240 = $239&1;
                     if ($240) {
                      break;
                     }
                     $241 = HEAP32[3037544>>2]|0;
                     $242 = HEAP32[3037552>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($241|0),($242|0));
                     $243 = __THREW__; __THREW__ = 0;
                     $244 = $243&1;
                     if ($244) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $245 = __THREW__; __THREW__ = 0;
                     $246 = $245&1;
                     if ($246) {
                      break;
                     }
                     $247 = HEAP32[3037560>>2]|0;
                     $248 = HEAP32[3037568>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($247|0),($248|0));
                     $249 = __THREW__; __THREW__ = 0;
                     $250 = $249&1;
                     if ($250) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $251 = __THREW__; __THREW__ = 0;
                     $252 = $251&1;
                     if ($252) {
                      break;
                     }
                     $253 = HEAP32[3037576>>2]|0;
                     $254 = HEAP32[3037584>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($253|0),($254|0));
                     $255 = __THREW__; __THREW__ = 0;
                     $256 = $255&1;
                     if ($256) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $257 = __THREW__; __THREW__ = 0;
                     $258 = $257&1;
                     if ($258) {
                      break;
                     }
                     $259 = HEAP32[3037592>>2]|0;
                     $260 = HEAP32[3037600>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($259|0),($260|0));
                     $261 = __THREW__; __THREW__ = 0;
                     $262 = $261&1;
                     if ($262) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $263 = __THREW__; __THREW__ = 0;
                     $264 = $263&1;
                     if ($264) {
                      break;
                     }
                     $265 = HEAP32[3037608>>2]|0;
                     $266 = HEAP32[3037616>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($265|0),($266|0));
                     $267 = __THREW__; __THREW__ = 0;
                     $268 = $267&1;
                     if ($268) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $269 = __THREW__; __THREW__ = 0;
                     $270 = $269&1;
                     if ($270) {
                      break;
                     }
                     $271 = HEAP32[3037624>>2]|0;
                     $272 = HEAP32[3037632>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($271|0),($272|0));
                     $273 = __THREW__; __THREW__ = 0;
                     $274 = $273&1;
                     if ($274) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $275 = __THREW__; __THREW__ = 0;
                     $276 = $275&1;
                     if ($276) {
                      break;
                     }
                     $277 = HEAP32[3037640>>2]|0;
                     $278 = HEAP32[3037648>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($277|0),($278|0));
                     $279 = __THREW__; __THREW__ = 0;
                     $280 = $279&1;
                     if ($280) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $281 = __THREW__; __THREW__ = 0;
                     $282 = $281&1;
                     if ($282) {
                      break;
                     }
                     $283 = HEAP32[3037656>>2]|0;
                     $284 = HEAP32[3037664>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($283|0),($284|0));
                     $285 = __THREW__; __THREW__ = 0;
                     $286 = $285&1;
                     if ($286) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $287 = __THREW__; __THREW__ = 0;
                     $288 = $287&1;
                     if ($288) {
                      break;
                     }
                     $289 = HEAP32[3037672>>2]|0;
                     $290 = HEAP32[3037680>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($289|0),($290|0));
                     $291 = __THREW__; __THREW__ = 0;
                     $292 = $291&1;
                     if ($292) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $293 = __THREW__; __THREW__ = 0;
                     $294 = $293&1;
                     if ($294) {
                      break;
                     }
                     $295 = HEAP32[3037688>>2]|0;
                     $296 = HEAP32[3037696>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($295|0),($296|0));
                     $297 = __THREW__; __THREW__ = 0;
                     $298 = $297&1;
                     if ($298) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $299 = __THREW__; __THREW__ = 0;
                     $300 = $299&1;
                     if ($300) {
                      break;
                     }
                     $301 = HEAP32[3037704>>2]|0;
                     $302 = HEAP32[3037712>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($301|0),($302|0));
                     $303 = __THREW__; __THREW__ = 0;
                     $304 = $303&1;
                     if ($304) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $305 = __THREW__; __THREW__ = 0;
                     $306 = $305&1;
                     if ($306) {
                      break;
                     }
                     $307 = HEAP32[3037720>>2]|0;
                     $308 = HEAP32[3037728>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($307|0),($308|0));
                     $309 = __THREW__; __THREW__ = 0;
                     $310 = $309&1;
                     if ($310) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $311 = __THREW__; __THREW__ = 0;
                     $312 = $311&1;
                     if ($312) {
                      break;
                     }
                     $313 = HEAP32[3037736>>2]|0;
                     $314 = HEAP32[3037744>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($313|0),($314|0));
                     $315 = __THREW__; __THREW__ = 0;
                     $316 = $315&1;
                     if ($316) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $317 = __THREW__; __THREW__ = 0;
                     $318 = $317&1;
                     if ($318) {
                      break;
                     }
                     $319 = HEAP32[3037752>>2]|0;
                     $320 = HEAP32[3037760>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($319|0),($320|0));
                     $321 = __THREW__; __THREW__ = 0;
                     $322 = $321&1;
                     if ($322) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $323 = __THREW__; __THREW__ = 0;
                     $324 = $323&1;
                     if ($324) {
                      break;
                     }
                     $325 = HEAP32[3037768>>2]|0;
                     $326 = HEAP32[3037776>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($325|0),($326|0));
                     $327 = __THREW__; __THREW__ = 0;
                     $328 = $327&1;
                     if ($328) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $329 = __THREW__; __THREW__ = 0;
                     $330 = $329&1;
                     if ($330) {
                      break;
                     }
                     $331 = HEAP32[3037784>>2]|0;
                     $332 = HEAP32[3037792>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($331|0),($332|0));
                     $333 = __THREW__; __THREW__ = 0;
                     $334 = $333&1;
                     if ($334) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $335 = __THREW__; __THREW__ = 0;
                     $336 = $335&1;
                     if ($336) {
                      break;
                     }
                     $337 = HEAP32[3037800>>2]|0;
                     $338 = HEAP32[3037808>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($337|0),($338|0));
                     $339 = __THREW__; __THREW__ = 0;
                     $340 = $339&1;
                     if ($340) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $341 = __THREW__; __THREW__ = 0;
                     $342 = $341&1;
                     if ($342) {
                      break;
                     }
                     $343 = HEAP32[3037816>>2]|0;
                     $344 = HEAP32[3037824>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($343|0),($344|0));
                     $345 = __THREW__; __THREW__ = 0;
                     $346 = $345&1;
                     if ($346) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $347 = __THREW__; __THREW__ = 0;
                     $348 = $347&1;
                     if ($348) {
                      break;
                     }
                     $349 = HEAP32[3037832>>2]|0;
                     $350 = HEAP32[3037840>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($349|0),($350|0));
                     $351 = __THREW__; __THREW__ = 0;
                     $352 = $351&1;
                     if ($352) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $353 = __THREW__; __THREW__ = 0;
                     $354 = $353&1;
                     if ($354) {
                      break;
                     }
                     $355 = HEAP32[3037848>>2]|0;
                     $356 = HEAP32[3037856>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($355|0),($356|0));
                     $357 = __THREW__; __THREW__ = 0;
                     $358 = $357&1;
                     if ($358) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $359 = __THREW__; __THREW__ = 0;
                     $360 = $359&1;
                     if ($360) {
                      break;
                     }
                     $361 = HEAP32[3037864>>2]|0;
                     $362 = HEAP32[3037872>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($361|0),($362|0));
                     $363 = __THREW__; __THREW__ = 0;
                     $364 = $363&1;
                     if ($364) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $365 = __THREW__; __THREW__ = 0;
                     $366 = $365&1;
                     if ($366) {
                      break;
                     }
                     $367 = HEAP32[3037880>>2]|0;
                     $368 = HEAP32[3037888>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($367|0),($368|0));
                     $369 = __THREW__; __THREW__ = 0;
                     $370 = $369&1;
                     if ($370) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $371 = __THREW__; __THREW__ = 0;
                     $372 = $371&1;
                     if ($372) {
                      break;
                     }
                     $373 = HEAP32[3037896>>2]|0;
                     $374 = HEAP32[3037904>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($373|0),($374|0));
                     $375 = __THREW__; __THREW__ = 0;
                     $376 = $375&1;
                     if ($376) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $377 = __THREW__; __THREW__ = 0;
                     $378 = $377&1;
                     if ($378) {
                      break;
                     }
                     $379 = HEAP32[3037912>>2]|0;
                     $380 = HEAP32[3037920>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($379|0),($380|0));
                     $381 = __THREW__; __THREW__ = 0;
                     $382 = $381&1;
                     if ($382) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $383 = __THREW__; __THREW__ = 0;
                     $384 = $383&1;
                     if ($384) {
                      break;
                     }
                     $385 = HEAP32[3037928>>2]|0;
                     $386 = HEAP32[3037936>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($385|0),($386|0));
                     $387 = __THREW__; __THREW__ = 0;
                     $388 = $387&1;
                     if ($388) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $389 = __THREW__; __THREW__ = 0;
                     $390 = $389&1;
                     if ($390) {
                      break;
                     }
                     $391 = HEAP32[3037944>>2]|0;
                     $392 = HEAP32[3037952>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($391|0),($392|0));
                     $393 = __THREW__; __THREW__ = 0;
                     $394 = $393&1;
                     if ($394) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $395 = __THREW__; __THREW__ = 0;
                     $396 = $395&1;
                     if ($396) {
                      break;
                     }
                     $397 = HEAP32[3037960>>2]|0;
                     $398 = HEAP32[3037968>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($397|0),($398|0));
                     $399 = __THREW__; __THREW__ = 0;
                     $400 = $399&1;
                     if ($400) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $401 = __THREW__; __THREW__ = 0;
                     $402 = $401&1;
                     if ($402) {
                      break;
                     }
                     $403 = HEAP32[3037976>>2]|0;
                     $404 = HEAP32[3037984>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($403|0),($404|0));
                     $405 = __THREW__; __THREW__ = 0;
                     $406 = $405&1;
                     if ($406) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $407 = __THREW__; __THREW__ = 0;
                     $408 = $407&1;
                     if ($408) {
                      break;
                     }
                     $409 = HEAP32[3037992>>2]|0;
                     $410 = HEAP32[3038000>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($409|0),($410|0));
                     $411 = __THREW__; __THREW__ = 0;
                     $412 = $411&1;
                     if ($412) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $413 = __THREW__; __THREW__ = 0;
                     $414 = $413&1;
                     if ($414) {
                      break;
                     }
                     $415 = HEAP32[3038008>>2]|0;
                     $416 = HEAP32[3038016>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($415|0),($416|0));
                     $417 = __THREW__; __THREW__ = 0;
                     $418 = $417&1;
                     if ($418) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $419 = __THREW__; __THREW__ = 0;
                     $420 = $419&1;
                     if ($420) {
                      break;
                     }
                     $421 = HEAP32[3038024>>2]|0;
                     $422 = HEAP32[3038032>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($421|0),($422|0));
                     $423 = __THREW__; __THREW__ = 0;
                     $424 = $423&1;
                     if ($424) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $425 = __THREW__; __THREW__ = 0;
                     $426 = $425&1;
                     if ($426) {
                      break;
                     }
                     $427 = HEAP32[3038040>>2]|0;
                     $428 = HEAP32[3038048>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($427|0),($428|0));
                     $429 = __THREW__; __THREW__ = 0;
                     $430 = $429&1;
                     if ($430) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $431 = __THREW__; __THREW__ = 0;
                     $432 = $431&1;
                     if ($432) {
                      break;
                     }
                     $433 = HEAP32[3038056>>2]|0;
                     $434 = HEAP32[3038064>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($433|0),($434|0));
                     $435 = __THREW__; __THREW__ = 0;
                     $436 = $435&1;
                     if ($436) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $437 = __THREW__; __THREW__ = 0;
                     $438 = $437&1;
                     if ($438) {
                      break;
                     }
                     $439 = HEAP32[3038072>>2]|0;
                     $440 = HEAP32[3038080>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($439|0),($440|0));
                     $441 = __THREW__; __THREW__ = 0;
                     $442 = $441&1;
                     if ($442) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $443 = __THREW__; __THREW__ = 0;
                     $444 = $443&1;
                     if ($444) {
                      break;
                     }
                     $445 = HEAP32[3038088>>2]|0;
                     $446 = HEAP32[3038096>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($445|0),($446|0));
                     $447 = __THREW__; __THREW__ = 0;
                     $448 = $447&1;
                     if ($448) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $449 = __THREW__; __THREW__ = 0;
                     $450 = $449&1;
                     if ($450) {
                      break;
                     }
                     $451 = HEAP32[3038104>>2]|0;
                     $452 = HEAP32[3038112>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($451|0),($452|0));
                     $453 = __THREW__; __THREW__ = 0;
                     $454 = $453&1;
                     if ($454) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $455 = __THREW__; __THREW__ = 0;
                     $456 = $455&1;
                     if ($456) {
                      break;
                     }
                     $457 = HEAP32[3038120>>2]|0;
                     $458 = HEAP32[3038128>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($457|0),($458|0));
                     $459 = __THREW__; __THREW__ = 0;
                     $460 = $459&1;
                     if ($460) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $461 = __THREW__; __THREW__ = 0;
                     $462 = $461&1;
                     if ($462) {
                      break;
                     }
                     $463 = HEAP32[3038136>>2]|0;
                     $464 = HEAP32[3038144>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($463|0),($464|0));
                     $465 = __THREW__; __THREW__ = 0;
                     $466 = $465&1;
                     if ($466) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $467 = __THREW__; __THREW__ = 0;
                     $468 = $467&1;
                     if ($468) {
                      break;
                     }
                     $469 = HEAP32[3038152>>2]|0;
                     $470 = HEAP32[3038160>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($469|0),($470|0));
                     $471 = __THREW__; __THREW__ = 0;
                     $472 = $471&1;
                     if ($472) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $473 = __THREW__; __THREW__ = 0;
                     $474 = $473&1;
                     if ($474) {
                      break;
                     }
                     $475 = HEAP32[3038168>>2]|0;
                     $476 = HEAP32[3038176>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($475|0),($476|0));
                     $477 = __THREW__; __THREW__ = 0;
                     $478 = $477&1;
                     if ($478) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $479 = __THREW__; __THREW__ = 0;
                     $480 = $479&1;
                     if ($480) {
                      break;
                     }
                     $481 = HEAP32[3038184>>2]|0;
                     $482 = HEAP32[3038192>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($481|0),($482|0));
                     $483 = __THREW__; __THREW__ = 0;
                     $484 = $483&1;
                     if ($484) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $485 = __THREW__; __THREW__ = 0;
                     $486 = $485&1;
                     if ($486) {
                      break;
                     }
                     $487 = HEAP32[3038200>>2]|0;
                     $488 = HEAP32[3038208>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($487|0),($488|0));
                     $489 = __THREW__; __THREW__ = 0;
                     $490 = $489&1;
                     if ($490) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $491 = __THREW__; __THREW__ = 0;
                     $492 = $491&1;
                     if ($492) {
                      break;
                     }
                     $493 = HEAP32[3038216>>2]|0;
                     $494 = HEAP32[3038224>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($493|0),($494|0));
                     $495 = __THREW__; __THREW__ = 0;
                     $496 = $495&1;
                     if ($496) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($18|0));
                     $497 = __THREW__; __THREW__ = 0;
                     $498 = $497&1;
                     if ($498) {
                      break;
                     }
                     $499 = HEAP32[3038232>>2]|0;
                     $500 = HEAP32[3038240>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($18|0),($499|0),($500|0));
                     $501 = __THREW__; __THREW__ = 0;
                     $502 = $501&1;
                     if ($502) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2305768|0))|0);
                     $503 = __THREW__; __THREW__ = 0;
                     $504 = $503&1;
                     if ($504) {
                      break;
                     }
                     __THREW__ = 0;
                     $505 = (invoke_ii(3469,(2305768|0))|0);
                     $506 = __THREW__; __THREW__ = 0;
                     $507 = $506&1;
                     if ($507) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(2159,($505|0));
                     $508 = __THREW__; __THREW__ = 0;
                     $509 = $508&1;
                     if ($509) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2304904|0))|0);
                     $510 = __THREW__; __THREW__ = 0;
                     $511 = $510&1;
                     if ($511) {
                      break;
                     }
                     __THREW__ = 0;
                     $512 = (invoke_ii(3469,(2304904|0))|0);
                     $513 = __THREW__; __THREW__ = 0;
                     $514 = $513&1;
                     if ($514) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(2156,($512|0));
                     $515 = __THREW__; __THREW__ = 0;
                     $516 = $515&1;
                     if ($516) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2313960|0))|0);
                     $517 = __THREW__; __THREW__ = 0;
                     $518 = $517&1;
                     if ($518) {
                      break;
                     }
                     __THREW__ = 0;
                     $519 = (invoke_ii(3469,(2313960|0))|0);
                     $520 = __THREW__; __THREW__ = 0;
                     $521 = $520&1;
                     if ($521) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_viii(575,($519|0),($505|0),($512|0));
                     $522 = __THREW__; __THREW__ = 0;
                     $523 = $522&1;
                     if ($523) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $524 = __THREW__; __THREW__ = 0;
                     $525 = $524&1;
                     if ($525) {
                      break;
                     }
                     $526 = HEAP32[3038248>>2]|0;
                     $527 = HEAP32[3038256>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($526|0),($527|0));
                     $528 = __THREW__; __THREW__ = 0;
                     $529 = $528&1;
                     if ($529) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $530 = __THREW__; __THREW__ = 0;
                     $531 = $530&1;
                     if ($531) {
                      break;
                     }
                     $532 = HEAP32[3038264>>2]|0;
                     $533 = HEAP32[3038272>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($532|0),($533|0));
                     $534 = __THREW__; __THREW__ = 0;
                     $535 = $534&1;
                     if ($535) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $536 = __THREW__; __THREW__ = 0;
                     $537 = $536&1;
                     if ($537) {
                      break;
                     }
                     $538 = HEAP32[3038280>>2]|0;
                     $539 = HEAP32[3038288>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($538|0),($539|0));
                     $540 = __THREW__; __THREW__ = 0;
                     $541 = $540&1;
                     if ($541) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $542 = __THREW__; __THREW__ = 0;
                     $543 = $542&1;
                     if ($543) {
                      break;
                     }
                     $544 = HEAP32[3038296>>2]|0;
                     $545 = HEAP32[3038304>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($544|0),($545|0));
                     $546 = __THREW__; __THREW__ = 0;
                     $547 = $546&1;
                     if ($547) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $548 = __THREW__; __THREW__ = 0;
                     $549 = $548&1;
                     if ($549) {
                      break;
                     }
                     $550 = HEAP32[3038312>>2]|0;
                     $551 = HEAP32[3038320>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($550|0),($551|0));
                     $552 = __THREW__; __THREW__ = 0;
                     $553 = $552&1;
                     if ($553) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $554 = __THREW__; __THREW__ = 0;
                     $555 = $554&1;
                     if ($555) {
                      break;
                     }
                     $556 = HEAP32[3038328>>2]|0;
                     $557 = HEAP32[3038336>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($556|0),($557|0));
                     $558 = __THREW__; __THREW__ = 0;
                     $559 = $558&1;
                     if ($559) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $560 = __THREW__; __THREW__ = 0;
                     $561 = $560&1;
                     if ($561) {
                      break;
                     }
                     $562 = HEAP32[3038344>>2]|0;
                     $563 = HEAP32[3038352>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($562|0),($563|0));
                     $564 = __THREW__; __THREW__ = 0;
                     $565 = $564&1;
                     if ($565) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $566 = __THREW__; __THREW__ = 0;
                     $567 = $566&1;
                     if ($567) {
                      break;
                     }
                     $568 = HEAP32[3038360>>2]|0;
                     $569 = HEAP32[3038368>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($568|0),($569|0));
                     $570 = __THREW__; __THREW__ = 0;
                     $571 = $570&1;
                     if ($571) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $572 = __THREW__; __THREW__ = 0;
                     $573 = $572&1;
                     if ($573) {
                      break;
                     }
                     $574 = HEAP32[3038376>>2]|0;
                     $575 = HEAP32[3038384>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($574|0),($575|0));
                     $576 = __THREW__; __THREW__ = 0;
                     $577 = $576&1;
                     if ($577) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $578 = __THREW__; __THREW__ = 0;
                     $579 = $578&1;
                     if ($579) {
                      break;
                     }
                     $580 = HEAP32[3038392>>2]|0;
                     $581 = HEAP32[3038400>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($580|0),($581|0));
                     $582 = __THREW__; __THREW__ = 0;
                     $583 = $582&1;
                     if ($583) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $584 = __THREW__; __THREW__ = 0;
                     $585 = $584&1;
                     if ($585) {
                      break;
                     }
                     $586 = HEAP32[3038408>>2]|0;
                     $587 = HEAP32[3038416>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($586|0),($587|0));
                     $588 = __THREW__; __THREW__ = 0;
                     $589 = $588&1;
                     if ($589) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $590 = __THREW__; __THREW__ = 0;
                     $591 = $590&1;
                     if ($591) {
                      break;
                     }
                     $592 = HEAP32[3038424>>2]|0;
                     $593 = HEAP32[3038432>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($592|0),($593|0));
                     $594 = __THREW__; __THREW__ = 0;
                     $595 = $594&1;
                     if ($595) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $596 = __THREW__; __THREW__ = 0;
                     $597 = $596&1;
                     if ($597) {
                      break;
                     }
                     $598 = HEAP32[3038440>>2]|0;
                     $599 = HEAP32[3038448>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($598|0),($599|0));
                     $600 = __THREW__; __THREW__ = 0;
                     $601 = $600&1;
                     if ($601) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $602 = __THREW__; __THREW__ = 0;
                     $603 = $602&1;
                     if ($603) {
                      break;
                     }
                     $604 = HEAP32[3038456>>2]|0;
                     $605 = HEAP32[3038464>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($604|0),($605|0));
                     $606 = __THREW__; __THREW__ = 0;
                     $607 = $606&1;
                     if ($607) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $608 = __THREW__; __THREW__ = 0;
                     $609 = $608&1;
                     if ($609) {
                      break;
                     }
                     $610 = HEAP32[3038472>>2]|0;
                     $611 = HEAP32[3038480>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($610|0),($611|0));
                     $612 = __THREW__; __THREW__ = 0;
                     $613 = $612&1;
                     if ($613) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $614 = __THREW__; __THREW__ = 0;
                     $615 = $614&1;
                     if ($615) {
                      break;
                     }
                     $616 = HEAP32[3038488>>2]|0;
                     $617 = HEAP32[3038496>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($616|0),($617|0));
                     $618 = __THREW__; __THREW__ = 0;
                     $619 = $618&1;
                     if ($619) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $620 = __THREW__; __THREW__ = 0;
                     $621 = $620&1;
                     if ($621) {
                      break;
                     }
                     $622 = HEAP32[3038504>>2]|0;
                     $623 = HEAP32[3038512>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($622|0),($623|0));
                     $624 = __THREW__; __THREW__ = 0;
                     $625 = $624&1;
                     if ($625) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $626 = __THREW__; __THREW__ = 0;
                     $627 = $626&1;
                     if ($627) {
                      break;
                     }
                     $628 = HEAP32[3038520>>2]|0;
                     $629 = HEAP32[3038528>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($628|0),($629|0));
                     $630 = __THREW__; __THREW__ = 0;
                     $631 = $630&1;
                     if ($631) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $632 = __THREW__; __THREW__ = 0;
                     $633 = $632&1;
                     if ($633) {
                      break;
                     }
                     $634 = HEAP32[3038536>>2]|0;
                     $635 = HEAP32[3038544>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($634|0),($635|0));
                     $636 = __THREW__; __THREW__ = 0;
                     $637 = $636&1;
                     if ($637) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($519|0));
                     $638 = __THREW__; __THREW__ = 0;
                     $639 = $638&1;
                     if ($639) {
                      break;
                     }
                     $640 = HEAP32[3038552>>2]|0;
                     $641 = HEAP32[3038560>>2]|0;
                     __THREW__ = 0;
                     invoke_viiii(465,(2311184|0),($519|0),($640|0),($641|0));
                     $642 = __THREW__; __THREW__ = 0;
                     $643 = $642&1;
                     if ($643) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2501376|0))|0);
                     $644 = __THREW__; __THREW__ = 0;
                     $645 = $644&1;
                     if ($645) {
                      break;
                     }
                     $646 = HEAP8[((2501376 + 116|0))>>0]|0;
                     $647 = ($646<<24>>24)==(0);
                     if ($647) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2501376|0))|0);
                      $648 = __THREW__; __THREW__ = 0;
                      $649 = $648&1;
                      if ($649) {
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2501376|0))|0);
                      $650 = __THREW__; __THREW__ = 0;
                      $651 = $650&1;
                      if ($651) {
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3836,(2501376|0));
                      $652 = __THREW__; __THREW__ = 0;
                      $653 = $652&1;
                      if ($653) {
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2501376|0))|0);
                     $656 = __THREW__; __THREW__ = 0;
                     $657 = $656&1;
                     if ($657) {
                      break;
                     }
                     $658 = HEAP32[((2501376 + 80|0))>>2]|0;
                     $659 = (($658) + 4|0);
                     HEAP32[$659>>2] = $18;
                     __THREW__ = 0;
                     (invoke_ii(2996,(2501376|0))|0);
                     $660 = __THREW__; __THREW__ = 0;
                     $661 = $660&1;
                     if ($661) {
                      break;
                     }
                     $662 = HEAP8[((2501376 + 116|0))>>0]|0;
                     $663 = ($662<<24>>24)==(0);
                     if ($663) {
                      __THREW__ = 0;
                      (invoke_ii(2996,(2501376|0))|0);
                      $664 = __THREW__; __THREW__ = 0;
                      $665 = $664&1;
                      if ($665) {
                       break;
                      }
                      __THREW__ = 0;
                      (invoke_ii(2996,(2501376|0))|0);
                      $666 = __THREW__; __THREW__ = 0;
                      $667 = $666&1;
                      if ($667) {
                       break;
                      }
                      __THREW__ = 0;
                      invoke_vi(3836,(2501376|0));
                      $668 = __THREW__; __THREW__ = 0;
                      $669 = $668&1;
                      if ($669) {
                       break;
                      }
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2501376|0))|0);
                     $670 = __THREW__; __THREW__ = 0;
                     $671 = $670&1;
                     if ($671) {
                      break;
                     }
                     $672 = HEAP32[((2501376 + 80|0))>>2]|0;
                     $673 = (($672) + 8|0);
                     HEAP32[$673>>2] = $519;
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $654 = ___cxa_find_matching_catch()|0;
 $655 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($654|0);
 // unreachable;
}
function __Z113mscorlib_System_Security_Cryptography_CryptoConfig_m_CreateFromName_mscorlib_System_Object_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2501000);
 __THREW__ = 0;
 $0 = (invoke_iiii(909,0,($name|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z144mscorlib_System_Security_Cryptography_CryptoConfig_m_CreateFromName_mscorlib_System_Object_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$name,$args) {
 $__this = $__this|0;
 $name = $name|0;
 $args = $args|0;
 var $$03 = 0, $$04 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, $name$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2501048);
 __THREW__ = 0;
 invoke_v(666);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3050776>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2501376|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP8[((2501376 + 116|0))>>0]|0;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     __THREW__ = 0;
     (invoke_ii(2996,(2501376|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2501376|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3836,(2501376|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2501376|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = HEAP32[((2501376 + 80|0))>>2]|0;
     $28 = HEAP32[$27>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,(0|0),($28|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2501376|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      do {
       if ($32) {
        label = 21;
       } else {
        $33 = HEAP8[((2501376 + 116|0))>>0]|0;
        $34 = ($33<<24>>24)==(0);
        if ($34) {
         __THREW__ = 0;
         (invoke_ii(2996,(2501376|0))|0);
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          label = 21;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2501376|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          label = 21;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3836,(2501376|0));
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          label = 21;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2501376|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 21;
        } else {
         $51 = HEAP32[((2501376 + 80|0))>>2]|0;
         $52 = (($51) + 4|0);
         $53 = HEAP32[$52>>2]|0;
         $54 = ($53|0)==(0|0);
         if ($54) {
          __THREW__ = 0;
          invoke_vi(2464,0);
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           label = 21;
          } else {
           $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 47;
          }
         } else {
          $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 47;
         }
        }
       }
      } while(0);
      if ((label|0) == 21) {
       $41 = ___cxa_find_matching_catch(348288|0)|0;
       $42 = tempRet0;
       $43 = (_llvm_eh_typeid_for((348288|0))|0);
       $44 = ($42|0)==($43|0);
       if (!($44)) {
        $$03 = $41;$$04 = $42;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$03|0);
        // unreachable;
       }
       $45 = (___cxa_begin_catch(($41|0))|0);
       $46 = HEAP32[$45>>2]|0;
       __THREW__ = 0;
       invoke_v(66);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
       $__last_unhandled_exception$0 = $46;$leaveInstructions$sroa$0$0 = 0;
      }
      __THREW__ = 0;
      invoke_vii(1917,(0|0),($28|0));
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if (!($58)) {
       $cond1 = ($leaveInstructions$sroa$0$0|0)==(47);
       if (!($cond1)) {
        __THREW__ = 0;
        invoke_vi(3837,($__last_unhandled_exception$0|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        // unreachable;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2501376|0))|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       do {
        if (!($62)) {
         $63 = HEAP8[((2501376 + 116|0))>>0]|0;
         $64 = ($63<<24>>24)==(0);
         if ($64) {
          __THREW__ = 0;
          (invoke_ii(2996,(2501376|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2501376|0))|0);
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3836,(2501376|0));
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2501376|0))|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if (!($84)) {
          $85 = HEAP32[((2501376 + 80|0))>>2]|0;
          $86 = (($85) + 4|0);
          $87 = HEAP32[$86>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($87|0));
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if (!($89)) {
           __THREW__ = 0;
           $90 = (invoke_iiii(1643,(2310848|0),($87|0),($name|0))|0);
           $91 = __THREW__; __THREW__ = 0;
           $92 = $91&1;
           if (!($92)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if (!($94)) {
             __THREW__ = 0;
             $95 = (invoke_iii(2764,($90|0),(2191608|0))|0);
             $96 = __THREW__; __THREW__ = 0;
             $97 = $96&1;
             if (!($97)) {
              $98 = ($95|0)==(0|0);
              $name$ = $98 ? $name : $95;
              __THREW__ = 0;
              $99 = (invoke_iii(769,(0|0),($name$|0))|0);
              $100 = __THREW__; __THREW__ = 0;
              $101 = $100&1;
              if (!($101)) {
               __THREW__ = 0;
               $102 = (invoke_iiii(958,(0|0),($99|0),($args|0))|0);
               $103 = __THREW__; __THREW__ = 0;
               $104 = $103&1;
               if (!($104)) {
                $V_3$0 = $102;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($V_3$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       } while(0);
       $71 = ___cxa_find_matching_catch(348288|0)|0;
       $72 = tempRet0;
       $73 = (_llvm_eh_typeid_for((348288|0))|0);
       $74 = ($72|0)==($73|0);
       if (!($74)) {
        $$03 = $71;$$04 = $72;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$03|0);
        // unreachable;
       }
       $75 = (___cxa_begin_catch(($71|0))|0);
       $76 = HEAP32[$75>>2]|0;
       $77 = HEAP32[$76>>2]|0;
       __THREW__ = 0;
       $78 = (invoke_iii(2727,(2149728|0),($77|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       do {
        if (!($80)) {
         if ($78) {
          __THREW__ = 0;
          invoke_v(66);
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           break L1;
          } else {
           $V_3$0 = 0;
          }
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($V_3$0|0);
         } else {
          $109 = (___cxa_allocate_exception(4)|0);
          $110 = HEAP32[$75>>2]|0;
          HEAP32[$109>>2] = $110;
          __THREW__ = 0;
          invoke_viii(1567,($109|0),(348288|0),(0|0));
          $111 = __THREW__; __THREW__ = 0;
          $112 = $111&1;
          if ($112) {
           break;
          }
          // unreachable;
         }
        }
       } while(0);
       $105 = ___cxa_find_matching_catch()|0;
       $106 = tempRet0;
       __THREW__ = 0;
       invoke_v(66);
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        $113 = ___cxa_find_matching_catch(0|0)|0;
        $114 = tempRet0;
        ___clang_call_terminate($113);
        // unreachable;
       } else {
        $$03 = $105;$$04 = $106;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$03|0);
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$03 = $3;$$04 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$03|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Security_Cryptography_CryptoConfig_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_Security_Cryptography_CryptographicException_m__ctorP60mscorlib_System_Security_Cryptography_CryptographicExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2501512);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233296);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z91mscorlib_System_Security_Cryptography_CryptographicException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z80mscorlib_System_Security_Cryptography_HashAlgorithm_m_System_IDisposable_DisposeP51mscorlib_System_Security_Cryptography_HashAlgorithm($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2501872);
 __THREW__ = 0;
 invoke_viii(2122,(2501920|0),($__this|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1941,(0|0),($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z123mscorlib_System_Security_Cryptography_HashAlgorithm_m_ComputeHash_mscorlib_System_Byte_arr_arr_mscorlib_System_Byte_arr_arrP51mscorlib_System_Security_Cryptography_HashAlgorithmP24mscorlib_System_Byte_arr($__this,$buffer) {
 $__this = $__this|0;
 $buffer = $buffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2501968);
 __THREW__ = 0;
 invoke_v(667);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($buffer|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($buffer|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($buffer) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iiiii(149,($__this|0),($buffer|0),0,($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3050792>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3837,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z167mscorlib_System_Security_Cryptography_HashAlgorithm_m_ComputeHash_mscorlib_System_Byte_arr_arr_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P51mscorlib_System_Security_Cryptography_HashAlgorithmP24mscorlib_System_Byte_arrii($__this,$buffer,$offset,$count) {
 $__this = $__this|0;
 $buffer = $buffer|0;
 $offset = $offset|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2502016);
 __THREW__ = 0;
 invoke_v(668);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2634432|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2634432|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3050824>>2]|0;
    __THREW__ = 0;
    invoke_vii(1970,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($buffer|0)==(0|0);
   if ($17) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2560584|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3050832>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($20|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($20|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   $28 = ($offset|0)>(-1);
   if (!($28)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    __THREW__ = 0;
    $31 = (invoke_ii(3469,(2561352|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = HEAP32[3050840>>2]|0;
    $35 = HEAP32[3050848>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($31|0),($34|0),($35|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($31|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    // unreachable;
   }
   $40 = ($count|0)>(-1);
   if (!($40)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    $43 = (invoke_ii(3469,(2560072|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    $46 = HEAP32[3050856>>2]|0;
    $47 = HEAP32[3050864>>2]|0;
    __THREW__ = 0;
    invoke_viii(641,($43|0),($46|0),($47|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($43|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($buffer|0));
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if (!($53)) {
    $54 = (($buffer) + 12|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($55) - ($count))|0;
    $57 = ($56|0)<($offset|0);
    if (!($57)) {
     __THREW__ = 0;
     invoke_viiiii(119,(2502064|0),($__this|0),($buffer|0),($offset|0),($count|0));
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      break;
     }
     __THREW__ = 0;
     $74 = (invoke_iii(2730,(2502112|0),($__this|0))|0);
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      break;
     }
     $77 = (($__this) + 8|0);
     HEAP32[$77>>2] = $74;
     __THREW__ = 0;
     invoke_vii(3495,(2502160|0),($__this|0));
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      break;
     }
     $80 = HEAP32[$77>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($80|0);
    }
    $58 = HEAP32[3050880>>2]|0;
    __THREW__ = 0;
    $59 = (invoke_iii(783,(0|0),($58|0))|0);
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if (!($61)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if (!($63)) {
      __THREW__ = 0;
      $64 = (invoke_ii(3469,(2560072|0))|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if (!($66)) {
       $67 = HEAP32[3050872>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($64|0),($67|0),($59|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if (!($69)) {
        __THREW__ = 0;
        invoke_vi(3837,($64|0));
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if (!($71)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __ZN18VirtActionInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEP10MethodInfoPvS5_ii($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($4,$p1,$p2,$p3);
 STACKTOP = sp;return;
}
function __Z60mscorlib_System_Security_Cryptography_HashAlgorithm_m_CreateP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$hashName) {
 $__this = $__this|0;
 $hashName = $hashName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2502208);
 __THREW__ = 0;
 $0 = (invoke_iii(958,0,($hashName|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2502696|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2764,($0|0),(2502696|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Security_Cryptography_HashAlgorithm_m_DisposeP51mscorlib_System_Security_Cryptography_HashAlgorithmb($__this,$disposing) {
 $__this = $__this|0;
 $disposing = $disposing|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2501920);
 $0 = (($__this) + 12|0);
 HEAP8[$0>>0] = 1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Security_Cryptography_HashAlgorithm_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_Security_Cryptography_ICryptoTransform_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m__ctorP62mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503024);
 __THREW__ = 0;
 invoke_vi(2476,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(961,0,(0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $2;
   __THREW__ = 0;
   invoke_vi(2472,($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z67mscorlib_System_Security_Cryptography_RandomNumberGenerator_m__ctorP59mscorlib_System_Security_Cryptography_RandomNumberGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2505112);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z78mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_RngInitializeP22mscorlib_System_ObjectP24mscorlib_System_Byte_arr($__this,$seed) {
 $__this = $__this|0;
 $seed = $seed|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503296);
 $0 = HEAP32[2503344>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2503352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2503344>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($seed|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_CheckP62mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503120);
 __THREW__ = 0;
 invoke_v(669);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($__this) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2210080|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = HEAP32[((2210080 + 80|0))>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$0>>2] = $5;
   HEAP32[$1>>2] = $9;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   $10 = (invoke_iiii(643,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $15 = HEAP32[3050992>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii(783,(0|0),($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2501736|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      $21 = (invoke_ii(3469,(2501736|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vii(1898,($21|0),($16|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        invoke_vi(3837,($21|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z71mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503072);
 __THREW__ = 0;
 $0 = (invoke_ii(2335,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  if (!($0)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2149728|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2149728|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(1924,($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2504152|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = HEAP32[((2504152 + 80|0))>>2]|0;
      HEAP32[$14>>2] = $7;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z72mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_RngOpenP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503168);
 $0 = HEAP32[2503216>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2503224|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2503216>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_RngGetBytesP22mscorlib_System_Object22mscorlib_System_IntPtrP24mscorlib_System_Byte_arr($__this,$handle,$data) {
 $__this = $__this|0;
 $handle = $handle|0;
 $data = $data|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503440);
 $1 = HEAP32[2503488>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2503496|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2503488>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $10 = (invoke_iii($9|0,($$byval_copy|0),($data|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 return 0|0;
}
function __Z73mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_RngCloseP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503592);
 $1 = HEAP32[2503640>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2503648|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2503640>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vi($9|0,($$byval_copy|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z73mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_GetBytesP62mscorlib_System_Security_Cryptography_RNGCryptoServiceProviderP24mscorlib_System_Byte_arr($__this,$data) {
 $__this = $__this|0;
 $data = $data|0;
 var $$0 = 0, $$02 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503728);
 __THREW__ = 0;
 invoke_v(670);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($data|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3051072>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2504152|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP8[((2504152 + 116|0))>>0]|0;
    $20 = ($19<<24>>24)==(0);
    if ($20) {
     __THREW__ = 0;
     (invoke_ii(2996,(2504152|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2504152|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3836,(2504152|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2504152|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = HEAP32[((2504152 + 80|0))>>2]|0;
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $32 = (($__this) + 8|0);
      $33 = HEAP32[$32>>2]|0;
      HEAP32[$0>>2] = $33;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
      $34 = (invoke_iiii(910,0,($$byval_copy1|0),($data|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      HEAP32[$32>>2] = $34;
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2504152|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = HEAP8[((2504152 + 116|0))>>0]|0;
      $40 = ($39<<24>>24)==(0);
      if ($40) {
       __THREW__ = 0;
       (invoke_ii(2996,(2504152|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2504152|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3836,(2504152|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2504152|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = HEAP32[((2504152 + 80|0))>>2]|0;
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_vii(1916,(0|0),($50|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = (($__this) + 8|0);
      $54 = HEAP32[$53>>2]|0;
      HEAP32[$1>>2] = $54;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
      $55 = (invoke_iiii(910,0,($$byval_copy1|0),($data|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       $58 = ___cxa_find_matching_catch(348288|0)|0;
       $59 = tempRet0;
       $60 = (_llvm_eh_typeid_for((348288|0))|0);
       $61 = ($59|0)==($60|0);
       if (!($61)) {
        $$0 = $58;$$02 = $59;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($$0|0);
        // unreachable;
       }
       $62 = (___cxa_begin_catch(($58|0))|0);
       $63 = HEAP32[$62>>2]|0;
       __THREW__ = 0;
       invoke_v(66);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break;
       }
       $__last_unhandled_exception$0 = $63;$leaveInstructions$sroa$0$0 = 0;
      } else {
       HEAP32[$53>>2] = $55;
       $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 80;
      }
      __THREW__ = 0;
      invoke_vii(1917,(0|0),($50|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      $cond1 = ($leaveInstructions$sroa$0$0|0)==(80);
      if (!($cond1)) {
       __THREW__ = 0;
       invoke_vi(3837,($__last_unhandled_exception$0|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     invoke_vi(2472,($__this|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if (!($71)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $$0 = $5;$$02 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z73mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_FinalizeP62mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0;
 var $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy2 = sp + 20|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2503776);
 $3 = (($__this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2210080|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  label = 4;
 } else {
  $7 = HEAP32[((2210080 + 80|0))>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  HEAP32[$0>>2] = $4;
  HEAP32[$1>>2] = $8;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
  $9 = (invoke_iiii(645,(0|0),($$byval_copy|0),($$byval_copy2|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if ($11) {
   label = 4;
  } else {
   if ($9) {
    $20 = HEAP32[$3>>2]|0;
    HEAP32[$2>>2] = $20;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_vii(1900,0,($$byval_copy2|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 4;
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(2210080|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 4;
     } else {
      $25 = HEAP32[((2210080 + 80|0))>>2]|0;
      $26 = HEAP32[$25>>2]|0;
      HEAP32[$3>>2] = $26;
      $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 49;
      label = 11;
     }
    }
   } else {
    $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 49;
    label = 11;
   }
  }
 }
 if ((label|0) == 4) {
  $12 = ___cxa_find_matching_catch(348288|0)|0;
  $13 = tempRet0;
  $14 = (_llvm_eh_typeid_for((348288|0))|0);
  $15 = ($13|0)==($14|0);
  if (!($15)) {
   $$0 = $12;$$02 = $13;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$0|0);
   // unreachable;
  }
  $16 = (___cxa_begin_catch(($12|0))|0);
  $17 = HEAP32[$16>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $__last_unhandled_exception$0 = $17;$leaveInstructions$sroa$0$0 = 0;
   label = 11;
  }
 }
 if ((label|0) == 11) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if (!($30)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(49);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3837,($__last_unhandled_exception$0|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    // unreachable;
   }
  }
 }
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 $$0 = $27;$$02 = $28;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN12FuncInvoker2I28mscorlib_System_IntPtrTraitsS0_17VoidPointerTraitsE6InvokeEPF22mscorlib_System_IntPtrPvS3_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2210080,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN14ActionInvoker1I28mscorlib_System_IntPtrTraitsE6InvokeEPFvPv22mscorlib_System_IntPtrES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z72mscorlib_System_Security_Cryptography_RSA_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Security_Cryptography_RSAParameters_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z128mscorlib_System_Security_Cryptography_RandomNumberGenerator_m_Create_mscorlib_System_Security_Cryptography_RandomNumberGeneratorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2505160);
 __THREW__ = 0;
 invoke_v(671);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3051096>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(962,0,($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z151mscorlib_System_Security_Cryptography_RandomNumberGenerator_m_Create_mscorlib_System_Security_Cryptography_RandomNumberGenerator_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$rngName) {
 $__this = $__this|0;
 $rngName = $rngName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2505208);
 __THREW__ = 0;
 $0 = (invoke_iii(958,0,($rngName|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2505408|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2764,($0|0),(2505408|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Security_Policy_ApplicationTrust_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator_m__ctorP59mscorlib_System_Security_Policy_Evidence_EvidenceEnumeratorP22mscorlib_System_ObjectS2_($__this,$hostenum,$assemblyenum) {
 $__this = $__this|0;
 $hostenum = $hostenum|0;
 $assemblyenum = $assemblyenum|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2505800);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = $hostenum;
  $3 = (($__this) + 16|0);
  HEAP32[$3>>2] = $assemblyenum;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $hostenum;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z70mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator_m_MoveNextP59mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2505848);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $$0 = 0;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($1|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(2741,(2176240|0),($1|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     if ($5) {
      $$0 = 1;
      break;
     }
     $10 = (($__this) + 12|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = HEAP32[$0>>2]|0;
     $13 = ($11|0)==($12|0);
     if (!($13)) {
      $$0 = 0;
      break;
     }
     $14 = (($__this) + 16|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ($15|0)==(0|0);
     if ($16) {
      $$0 = 0;
      break;
     }
     HEAP32[$0>>2] = $15;
     __THREW__ = 0;
     invoke_vi(3799,($15|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      $19 = (invoke_iii(2741,(2176240|0),($15|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $$0 = $19;
       break;
      }
     }
    }
   }
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($8|0);
   // unreachable;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z73mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator_m_get_CurrentP59mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2505896);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2740,(2176176|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Security_Policy_Evidence_m_get_CountP40mscorlib_System_Security_Policy_Evidence($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0;
 var $V_0$1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2506384);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $V_0$0 = 0;
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2729,(2296488|0),($1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $V_0$0 = $5;
    label = 4;
   }
  }
 }
 if ((label|0) == 4) {
  $8 = (($__this) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $V_0$1 = $V_0$0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($V_0$1|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   $15 = (invoke_iii(2729,(2296488|0),($9|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = (($15) + ($V_0$0))|0;
    $V_0$1 = $18;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($V_0$1|0);
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Security_Policy_Evidence_m_get_SyncRootP40mscorlib_System_Security_Policy_Evidence($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2506432);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z63mscorlib_System_Security_Policy_Evidence_m_get_HostEvidenceListP40mscorlib_System_Security_Policy_Evidence($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2506480);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $13 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($13|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2304136|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_ii(3469,(2304136|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(2153,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(825,(0|0),($5|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     HEAP32[$0>>2] = $10;
     $13 = $10;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($13|0);
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Security_Policy_Evidence_m_get_AssemblyEvidenceListP40mscorlib_System_Security_Policy_Evidence($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2506528);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $13 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($13|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2304136|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_ii(3469,(2304136|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(2153,($5|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(825,(0|0),($5|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     HEAP32[$0>>2] = $10;
     $13 = $10;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($13|0);
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Security_Policy_Evidence_m_CopyToP40mscorlib_System_Security_Policy_EvidenceP21mscorlib_System_Arrayi($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2506576);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $V_0$0 = 0;
  label = 8;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2729,(2296488|0),($1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = ($5|0)<(1);
    if ($8) {
     $V_0$0 = $5;
     label = 8;
    } else {
     $11 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_viiii(461,(2298680|0),($11|0),($_____array|0),($index|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $V_0$0 = $5;
       label = 8;
      }
     }
    }
   }
  }
 }
 if ((label|0) == 8) {
  $16 = (($__this) + 12|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  invoke_vi(3799,($17|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   __THREW__ = 0;
   $21 = (invoke_iii(2729,(2296488|0),($17|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = ($21|0)<(1);
    if ($24) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $25 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = (($V_0$0) + ($index))|0;
     __THREW__ = 0;
     invoke_viiii(461,(2298680|0),($25|0),($_____array|0),($28|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z49mscorlib_System_Security_Policy_Evidence_m_EqualsP40mscorlib_System_Security_Policy_EvidenceP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_4$0 = 0, $V_4$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2506624);
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2507336|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2735,($obj|0),(2507336|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0|0);
   if ($6) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $17 = (invoke_ii(2341,($__this|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    invoke_vi(3799,($17|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     $22 = (invoke_iii(2729,(2296488|0),($17|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      invoke_vi(3799,($3|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_ii(2341,($3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($27|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         __THREW__ = 0;
         $32 = (invoke_iii(2729,(2296488|0),($27|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          $35 = ($22|0)==($32|0);
          if (!($35)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $36 = (invoke_ii(2342,($__this|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if (!($38)) {
           __THREW__ = 0;
           invoke_vi(3799,($36|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            __THREW__ = 0;
            $41 = (invoke_iii(2729,(2296488|0),($36|0))|0);
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if (!($43)) {
             __THREW__ = 0;
             invoke_vi(3799,($3|0));
             $44 = __THREW__; __THREW__ = 0;
             $45 = $44&1;
             if (!($45)) {
              __THREW__ = 0;
              $46 = (invoke_ii(2342,($3|0))|0);
              $47 = __THREW__; __THREW__ = 0;
              $48 = $47&1;
              if (!($48)) {
               __THREW__ = 0;
               invoke_vi(3799,($46|0));
               $49 = __THREW__; __THREW__ = 0;
               $50 = $49&1;
               if (!($50)) {
                __THREW__ = 0;
                $51 = (invoke_iii(2729,(2296488|0),($46|0))|0);
                $52 = __THREW__; __THREW__ = 0;
                $53 = $52&1;
                if (!($53)) {
                 $54 = ($41|0)==($51|0);
                 if (!($54)) {
                  $$0 = 0;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                 $55 = (($__this) + 8|0);
                 $56 = (($3) + 8|0);
                 $V_1$1 = 0;
                 L30: while(1) {
                  $86 = HEAP32[$55>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($86|0));
                  $87 = __THREW__; __THREW__ = 0;
                  $88 = $87&1;
                  if ($88) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  $89 = (invoke_iii(2729,(2296488|0),($86|0))|0);
                  $90 = __THREW__; __THREW__ = 0;
                  $91 = $90&1;
                  if ($91) {
                   label = 8;
                   break;
                  }
                  $92 = ($V_1$1|0)<($89|0);
                  if ($92) {
                   $V_1$0 = $V_1$1;
                  } else {
                   label = 43;
                   break;
                  }
                  while(1) {
                   __THREW__ = 0;
                   invoke_vi(3799,($3|0));
                   $75 = __THREW__; __THREW__ = 0;
                   $76 = $75&1;
                   if ($76) {
                    label = 7;
                    break L30;
                   }
                   $77 = HEAP32[$56>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($77|0));
                   $78 = __THREW__; __THREW__ = 0;
                   $79 = $78&1;
                   if ($79) {
                    label = 7;
                    break L30;
                   }
                   __THREW__ = 0;
                   $80 = (invoke_iii(2729,(2296488|0),($77|0))|0);
                   $81 = __THREW__; __THREW__ = 0;
                   $82 = $81&1;
                   if ($82) {
                    label = 7;
                    break L30;
                   }
                   $83 = ($80|0)>(0);
                   if (!($83)) {
                    $$0 = 0;
                    label = 59;
                    break L30;
                   }
                   $57 = HEAP32[$55>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($57|0));
                   $84 = __THREW__; __THREW__ = 0;
                   $85 = $84&1;
                   if ($85) {
                    label = 7;
                    break L30;
                   }
                   __THREW__ = 0;
                   $58 = (invoke_iiii(1648,(2296536|0),($57|0),($V_1$0|0))|0);
                   $59 = __THREW__; __THREW__ = 0;
                   $60 = $59&1;
                   if ($60) {
                    label = 7;
                    break L30;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($3|0));
                   $61 = __THREW__; __THREW__ = 0;
                   $62 = $61&1;
                   if ($62) {
                    label = 7;
                    break L30;
                   }
                   $63 = HEAP32[$56>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($63|0));
                   $64 = __THREW__; __THREW__ = 0;
                   $65 = $64&1;
                   if ($65) {
                    label = 7;
                    break L30;
                   }
                   __THREW__ = 0;
                   $66 = (invoke_iiii(1648,(2296536|0),($63|0),0)|0);
                   $67 = __THREW__; __THREW__ = 0;
                   $68 = $67&1;
                   if ($68) {
                    label = 7;
                    break L30;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($58|0));
                   $69 = __THREW__; __THREW__ = 0;
                   $70 = $69&1;
                   if ($70) {
                    label = 7;
                    break L30;
                   }
                   __THREW__ = 0;
                   $71 = (invoke_iiii(1644,(2148736|0),($58|0),($66|0))|0);
                   $72 = __THREW__; __THREW__ = 0;
                   $73 = $72&1;
                   if ($73) {
                    label = 7;
                    break L30;
                   }
                   $74 = (($V_1$0) + 1)|0;
                   if ($71) {
                    $V_1$1 = $74;
                    continue L30;
                   } else {
                    $V_1$0 = $74;
                   }
                  }
                 }
                 if ((label|0) == 7) {
                  $11 = ___cxa_find_matching_catch()|0;
                  $12 = tempRet0;
                  $lpad$phi$index = $11;$lpad$phi$index5 = $12;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($lpad$phi$index|0);
                  // unreachable;
                 }
                 else if ((label|0) == 8) {
                  $13 = ___cxa_find_matching_catch()|0;
                  $14 = tempRet0;
                  $lpad$phi$index = $13;$lpad$phi$index5 = $14;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($lpad$phi$index|0);
                  // unreachable;
                 }
                 else if ((label|0) == 43) {
                  $93 = (($__this) + 12|0);
                  $94 = (($3) + 12|0);
                  $V_4$1 = 0;
                  L51: while(1) {
                   $124 = HEAP32[$93>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($124|0));
                   $125 = __THREW__; __THREW__ = 0;
                   $126 = $125&1;
                   if ($126) {
                    label = 6;
                    break;
                   }
                   __THREW__ = 0;
                   $127 = (invoke_iii(2729,(2296488|0),($124|0))|0);
                   $128 = __THREW__; __THREW__ = 0;
                   $129 = $128&1;
                   if ($129) {
                    label = 6;
                    break;
                   }
                   $130 = ($V_4$1|0)<($127|0);
                   if ($130) {
                    $V_4$0 = $V_4$1;
                   } else {
                    $$0 = 1;
                    label = 59;
                    break;
                   }
                   while(1) {
                    __THREW__ = 0;
                    invoke_vi(3799,($3|0));
                    $113 = __THREW__; __THREW__ = 0;
                    $114 = $113&1;
                    if ($114) {
                     label = 5;
                     break L51;
                    }
                    $115 = HEAP32[$94>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($115|0));
                    $116 = __THREW__; __THREW__ = 0;
                    $117 = $116&1;
                    if ($117) {
                     label = 5;
                     break L51;
                    }
                    __THREW__ = 0;
                    $118 = (invoke_iii(2729,(2296488|0),($115|0))|0);
                    $119 = __THREW__; __THREW__ = 0;
                    $120 = $119&1;
                    if ($120) {
                     label = 5;
                     break L51;
                    }
                    $121 = ($118|0)>(0);
                    if (!($121)) {
                     $$0 = 0;
                     label = 59;
                     break L51;
                    }
                    $95 = HEAP32[$93>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($95|0));
                    $122 = __THREW__; __THREW__ = 0;
                    $123 = $122&1;
                    if ($123) {
                     label = 5;
                     break L51;
                    }
                    __THREW__ = 0;
                    $96 = (invoke_iiii(1648,(2296536|0),($95|0),($V_4$0|0))|0);
                    $97 = __THREW__; __THREW__ = 0;
                    $98 = $97&1;
                    if ($98) {
                     label = 5;
                     break L51;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($3|0));
                    $99 = __THREW__; __THREW__ = 0;
                    $100 = $99&1;
                    if ($100) {
                     label = 5;
                     break L51;
                    }
                    $101 = HEAP32[$94>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($101|0));
                    $102 = __THREW__; __THREW__ = 0;
                    $103 = $102&1;
                    if ($103) {
                     label = 5;
                     break L51;
                    }
                    __THREW__ = 0;
                    $104 = (invoke_iiii(1648,(2296536|0),($101|0),0)|0);
                    $105 = __THREW__; __THREW__ = 0;
                    $106 = $105&1;
                    if ($106) {
                     label = 5;
                     break L51;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($96|0));
                    $107 = __THREW__; __THREW__ = 0;
                    $108 = $107&1;
                    if ($108) {
                     label = 5;
                     break L51;
                    }
                    __THREW__ = 0;
                    $109 = (invoke_iiii(1644,(2148736|0),($96|0),($104|0))|0);
                    $110 = __THREW__; __THREW__ = 0;
                    $111 = $110&1;
                    if ($111) {
                     label = 5;
                     break L51;
                    }
                    $112 = (($V_4$0) + 1)|0;
                    if ($109) {
                     $V_4$1 = $112;
                     continue L51;
                    } else {
                     $V_4$0 = $112;
                    }
                   }
                  }
                  if ((label|0) == 5) {
                   $7 = ___cxa_find_matching_catch()|0;
                   $8 = tempRet0;
                   $lpad$phi$index = $7;$lpad$phi$index5 = $8;
                   __ZN16StackTraceSentryD2Ev(0);
                   ___resumeException($lpad$phi$index|0);
                   // unreachable;
                  }
                  else if ((label|0) == 6) {
                   $9 = ___cxa_find_matching_catch()|0;
                   $10 = tempRet0;
                   $lpad$phi$index = $9;$lpad$phi$index5 = $10;
                   __ZN16StackTraceSentryD2Ev(0);
                   ___resumeException($lpad$phi$index|0);
                   // unreachable;
                  }
                  else if ((label|0) == 59) {
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($$0|0);
                  }
                 }
                 else if ((label|0) == 59) {
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index5 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Security_Policy_Evidence_m_GetEnumeratorP40mscorlib_System_Security_Policy_Evidence($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2506672);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $V_0$0 = 0;
  label = 5;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2298872|0),($1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $V_0$0 = $5;
    label = 5;
   }
  }
 }
 do {
  if ((label|0) == 5) {
   $8 = (($__this) + 12|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0|0);
   if ($10) {
    $V_1$0 = 0;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($9|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    $15 = (invoke_iii(2730,(2298872|0),($9|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $V_1$0 = $15;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2506248|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2506248|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     invoke_viii(623,($20|0),($V_0$0|0),($V_1$0|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($20|0);
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Security_Policy_Evidence_m_GetHashCodeP40mscorlib_System_Security_Policy_Evidence($__this) {
 $__this = $__this|0;
 var $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2506720);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $63 = HEAP32[$0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($63|0);
 }
 $3 = (($__this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 L4: do {
  if (!($5)) {
   $22 = $4;$V_0$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    $25 = (invoke_iii(2729,(2296488|0),($22|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = ($V_0$0|0)<($25|0);
    if (!($28)) {
     break L4;
    }
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    $6 = HEAP32[$0>>2]|0;
    $7 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iiii(1648,(2296536|0),($7|0),($V_0$0|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($10|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    $15 = (invoke_iii(2729,(2148880|0),($10|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = $15 ^ $6;
    HEAP32[$0>>2] = $20;
    $21 = (($V_0$0) + 1)|0;
    $$pre4 = HEAP32[$3>>2]|0;
    $22 = $$pre4;$V_0$0 = $21;
   }
   $33 = ___cxa_find_matching_catch()|0;
   $34 = tempRet0;
   $lpad$phi$index = $33;$lpad$phi$index2 = $34;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $35 = (($__this) + 12|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $63 = HEAP32[$0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($63|0);
 }
 $54 = $36;$V_1$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($54|0));
  $55 = __THREW__; __THREW__ = 0;
  $56 = $55&1;
  if ($56) {
   break;
  }
  __THREW__ = 0;
  $57 = (invoke_iii(2729,(2296488|0),($54|0))|0);
  $58 = __THREW__; __THREW__ = 0;
  $59 = $58&1;
  if ($59) {
   break;
  }
  $60 = ($V_1$0|0)<($57|0);
  if (!($60)) {
   label = 29;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $61 = __THREW__; __THREW__ = 0;
  $62 = $61&1;
  if ($62) {
   break;
  }
  $38 = HEAP32[$0>>2]|0;
  $39 = HEAP32[$35>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($39|0));
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if ($41) {
   break;
  }
  __THREW__ = 0;
  $42 = (invoke_iiii(1648,(2296536|0),($39|0),($V_1$0|0))|0);
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if ($44) {
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($42|0));
  $45 = __THREW__; __THREW__ = 0;
  $46 = $45&1;
  if ($46) {
   break;
  }
  __THREW__ = 0;
  $47 = (invoke_iii(2729,(2148880|0),($42|0))|0);
  $48 = __THREW__; __THREW__ = 0;
  $49 = $48&1;
  if ($49) {
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $50 = __THREW__; __THREW__ = 0;
  $51 = $50&1;
  if ($51) {
   break;
  }
  $52 = $47 ^ $38;
  HEAP32[$0>>2] = $52;
  $53 = (($V_1$0) + 1)|0;
  $$pre = HEAP32[$35>>2]|0;
  $54 = $$pre;$V_1$0 = $53;
 }
 if ((label|0) == 29) {
  $63 = HEAP32[$0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($63|0);
 }
 $31 = ___cxa_find_matching_catch()|0;
 $32 = tempRet0;
 $lpad$phi$index = $31;$lpad$phi$index2 = $32;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Security_Policy_Evidence_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2507088)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z121mscorlib_System_Security_Policy_Evidence_CustomAttributesCacheGenerator_mscorlib_System_Security_Policy_Evidence_m_EqualsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z126mscorlib_System_Security_Policy_Evidence_CustomAttributesCacheGenerator_mscorlib_System_Security_Policy_Evidence_m_GetHashCodeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z52mscorlib_System_Security_Policy_Hash_m_GetObjectDataP36mscorlib_System_Security_Policy_HashP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2507472);
 __THREW__ = 0;
 invoke_v(672);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if (!($2)) {
    $15 = HEAP32[3051128>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iiii(422,(0|0),($__this|0),($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3051120>>2]|0;
    __THREW__ = 0;
    invoke_viii(621,($info|0),($21|0),($16|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3051112>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3837,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z47mscorlib_System_Security_Policy_Hash_m_ToStringP36mscorlib_System_Security_Policy_Hash($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2507520);
 __THREW__ = 0;
 invoke_v(673);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1782,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(2730,(2150320|0),($2|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2511456|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       $12 = (invoke_ii(3469,(2511456|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        __THREW__ = 0;
        invoke_vii(1902,($12|0),($7|0));
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         __THREW__ = 0;
         invoke_vi(3799,($12|0));
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if (!($18)) {
          $19 = HEAP32[3051264>>2]|0;
          $20 = HEAP32[3051272>>2]|0;
          __THREW__ = 0;
          invoke_viii(628,($12|0),($19|0),($20|0));
          $21 = __THREW__; __THREW__ = 0;
          $22 = $21&1;
          if (!($22)) {
           __THREW__ = 0;
           (invoke_ii(2996,(2537888|0))|0);
           $23 = __THREW__; __THREW__ = 0;
           $24 = $23&1;
           if (!($24)) {
            __THREW__ = 0;
            $25 = (invoke_ii(3469,(2537888|0))|0);
            $26 = __THREW__; __THREW__ = 0;
            $27 = $26&1;
            if (!($27)) {
             __THREW__ = 0;
             invoke_vi(2525,($25|0));
             $28 = __THREW__; __THREW__ = 0;
             $29 = $28&1;
             if (!($29)) {
              $30 = HEAP32[3051280>>2]|0;
              __THREW__ = 0;
              $31 = (invoke_iiii(422,(0|0),($__this|0),($30|0))|0);
              $32 = __THREW__; __THREW__ = 0;
              $33 = $32&1;
              if (!($33)) {
               $34 = (($31) + 12|0);
               $35 = (($31) + 16|0);
               $V_3$0 = 0;
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($31|0));
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if ($62) {
                 label = 15;
                 break;
                }
                $63 = HEAP32[$34>>2]|0;
                $64 = ($V_3$0|0)<($63|0);
                if (!($64)) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($31|0));
                $65 = __THREW__; __THREW__ = 0;
                $66 = $65&1;
                if ($66) {
                 label = 15;
                 break;
                }
                $40 = HEAP32[$34>>2]|0;
                $41 = ($V_3$0>>>0)<($40>>>0);
                if (!($41)) {
                 __THREW__ = 0;
                 $42 = (invoke_i(132)|0);
                 $43 = __THREW__; __THREW__ = 0;
                 $44 = $43&1;
                 if ($44) {
                  label = 15;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($42|0));
                 $45 = __THREW__; __THREW__ = 0;
                 $46 = $45&1;
                 if ($46) {
                  label = 15;
                  break;
                 }
                }
                $47 = HEAP32[$31>>2]|0;
                $48 = (($47) + 92|0);
                $49 = HEAP32[$48>>2]|0;
                $50 = Math_imul($49, $V_3$0)|0;
                $51 = (($35) + ($50)|0);
                $52 = HEAP32[3051288>>2]|0;
                __THREW__ = 0;
                $53 = (invoke_iii(535,($51|0),($52|0))|0);
                $54 = __THREW__; __THREW__ = 0;
                $55 = $54&1;
                if ($55) {
                 label = 15;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($25|0));
                $56 = __THREW__; __THREW__ = 0;
                $57 = $56&1;
                if ($57) {
                 label = 15;
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(989,($25|0),($53|0))|0);
                $58 = __THREW__; __THREW__ = 0;
                $59 = $58&1;
                if ($59) {
                 label = 15;
                 break;
                }
                $60 = (($V_3$0) + 1)|0;
                $V_3$0 = $60;
               }
               if ((label|0) == 15) {
                $36 = ___cxa_find_matching_catch()|0;
                $37 = tempRet0;
                $lpad$phi$index = $36;$lpad$phi$index2 = $37;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
               __THREW__ = 0;
               invoke_vi(3799,($25|0));
               $67 = __THREW__; __THREW__ = 0;
               $68 = $67&1;
               if (!($68)) {
                __THREW__ = 0;
                $69 = (invoke_iii(2730,(2535432|0),($25|0))|0);
                $70 = __THREW__; __THREW__ = 0;
                $71 = $70&1;
                if (!($71)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2511456|0))|0);
                 $72 = __THREW__; __THREW__ = 0;
                 $73 = $72&1;
                 if (!($73)) {
                  __THREW__ = 0;
                  $74 = (invoke_ii(3469,(2511456|0))|0);
                  $75 = __THREW__; __THREW__ = 0;
                  $76 = $75&1;
                  if (!($76)) {
                   $77 = HEAP32[3051296>>2]|0;
                   __THREW__ = 0;
                   invoke_viii(627,($74|0),($77|0),($69|0));
                   $78 = __THREW__; __THREW__ = 0;
                   $79 = $78&1;
                   if (!($79)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($12|0));
                    $80 = __THREW__; __THREW__ = 0;
                    $81 = $80&1;
                    if (!($81)) {
                     __THREW__ = 0;
                     invoke_vii(1904,($12|0),($74|0));
                     $82 = __THREW__; __THREW__ = 0;
                     $83 = $82&1;
                     if ($83) {
                      break;
                     }
                     $84 = HEAP32[3051304>>2]|0;
                     __THREW__ = 0;
                     $85 = (invoke_iiii(419,(0|0),($12|0),($84|0))|0);
                     $86 = __THREW__; __THREW__ = 0;
                     $87 = $86&1;
                     if ($87) {
                      break;
                     }
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return ($85|0);
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 $lpad$phi$index = $38;$lpad$phi$index2 = $39;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Security_SecurityElement_m__ctor_mscorlib_System_Void_mscorlib_System_StringP40mscorlib_System_Security_SecurityElementP22mscorlib_System_String($__this,$tag) {
 $__this = $__this|0;
 $tag = $tag|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2509776);
 __THREW__ = 0;
 invoke_viii(627,($__this|0),($tag|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z55mscorlib_System_Security_SecurityElement_m_AddAttributeP40mscorlib_System_Security_SecurityElementP22mscorlib_System_StringS2_($__this,$name,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2509968);
 __THREW__ = 0;
 invoke_v(674);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3051544>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($value|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3051552>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $26 = (invoke_iii(970,($__this|0),($name|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = ($26|0)==(0|0);
    if (!($29)) {
     $30 = HEAP32[3051560>>2]|0;
     __THREW__ = 0;
     $31 = (invoke_iiii(562,(0|0),($30|0),($name|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     __THREW__ = 0;
     $34 = (invoke_iii(783,(0|0),($31|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     __THREW__ = 0;
     $39 = (invoke_ii(3469,(2560072|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($39|0),($34|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($39|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     // unreachable;
    }
    $46 = (($__this) + 16|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(0|0);
    if ($48) {
     __THREW__ = 0;
     (invoke_ii(2996,(2304136|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     __THREW__ = 0;
     $51 = (invoke_ii(3469,(2304136|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2153,($51|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     HEAP32[$46>>2] = $51;
     $63 = $51;
    } else {
     $63 = $47;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2509640|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if (!($57)) {
     __THREW__ = 0;
     $58 = (invoke_ii(3469,(2509640|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if (!($60)) {
      __THREW__ = 0;
      invoke_viii(626,($58|0),($name|0),($value|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if (!($62)) {
       __THREW__ = 0;
       invoke_vi(3799,($63|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if (!($65)) {
        __THREW__ = 0;
        (invoke_iiii(1647,(2297624|0),($63|0),($58|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if (!($67)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z115mscorlib_System_Security_SecurityElement_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP40mscorlib_System_Security_SecurityElementP22mscorlib_System_StringS2_($__this,$tag,$text) {
 $__this = $__this|0;
 $tag = $tag|0;
 $text = $text|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2509824);
 __THREW__ = 0;
 invoke_v(675);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($tag|0)==(0|0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560584|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2560584|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = HEAP32[3051504>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($9|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $17 = (invoke_iii(968,0,($tag|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     if ($17) {
      $37 = (($__this) + 12|0);
      HEAP32[$37>>2] = $tag;
      __THREW__ = 0;
      invoke_vii(1903,($__this|0),($text|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $20 = HEAP32[3051512>>2]|0;
     __THREW__ = 0;
     $21 = (invoke_iii(783,(0|0),($20|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = HEAP32[3051520>>2]|0;
      __THREW__ = 0;
      $25 = (invoke_iiiii(101,(0|0),($21|0),($24|0),($tag|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_ii(3469,(2560072|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         __THREW__ = 0;
         invoke_vii(1924,($30|0),($25|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          __THREW__ = 0;
          invoke_vi(3837,($30|0));
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if (!($36)) {
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z51mscorlib_System_Security_SecurityElement_m_AddChildP40mscorlib_System_Security_SecurityElementS0_($__this,$child) {
 $__this = $__this|0;
 $child = $child|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510016);
 __THREW__ = 0;
 invoke_v(676);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($child|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3051624>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 20|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    __THREW__ = 0;
    (invoke_ii(2996,(2304136|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2304136|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2153,($20|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    HEAP32[$15>>2] = $20;
    $25 = $20;
   } else {
    $25 = $16;
   }
   __THREW__ = 0;
   invoke_vi(3799,($25|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    (invoke_iiii(1647,(2297624|0),($25|0),($child|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z67mscorlib_System_Security_Policy_Hash_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Security_Principal_IPrincipal_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Security_Principal_PrincipalPolicy_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_Security_IPermission_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_Security_ISecurityEncodable_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z66mscorlib_System_Security_SecurityElement_SecurityAttribute_m__ctorP58mscorlib_System_Security_SecurityElement_SecurityAttributeP22mscorlib_System_StringS2_($__this,$name,$value) {
 $__this = $__this|0;
 $name = $name|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2509296);
 __THREW__ = 0;
 invoke_v(677);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(966,0,($name|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      $9 = HEAP32[3051976>>2]|0;
      __THREW__ = 0;
      $10 = (invoke_iii(783,(0|0),($9|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      $13 = HEAP32[3051984>>2]|0;
      __THREW__ = 0;
      $14 = (invoke_iiiii(101,(0|0),($10|0),($13|0),($name|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      $19 = (invoke_ii(3469,(2560072|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1924,($19|0),($14|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3837,($19|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     $26 = (invoke_iii(967,0,($value|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      if ($26) {
       $46 = (($__this) + 8|0);
       HEAP32[$46>>2] = $name;
       __THREW__ = 0;
       $47 = (invoke_iii(965,0,($value|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
       $50 = (($__this) + 12|0);
       HEAP32[$50>>2] = $47;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $29 = HEAP32[3051992>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iii(783,(0|0),($29|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       $33 = HEAP32[3052000>>2]|0;
       __THREW__ = 0;
       $34 = (invoke_iiiii(101,(0|0),($30|0),($33|0),($value|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         __THREW__ = 0;
         $39 = (invoke_ii(3469,(2560072|0))|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          __THREW__ = 0;
          invoke_vii(1924,($39|0),($34|0));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if (!($43)) {
           __THREW__ = 0;
           invoke_vi(3837,($39|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if (!($45)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z63mscorlib_System_Security_SecurityElement_m_IsValidAttributeNameP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510160);
 $0 = ($name|0)==(0|0);
 if ($0) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2511456|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = HEAP8[((2511456 + 116|0))>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2511456|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2511456|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[((2511456 + 80|0))>>2]|0;
    $16 = (($15) + 8|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($name|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(630,($name|0),($17|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(-1);
      $G_B3_0$0 = $23;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B3_0$0|0);
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_Security_SecurityElement_m_IsValidAttributeValueP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510208);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2511456|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = HEAP8[((2511456 + 116|0))>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2511456|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2511456|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[((2511456 + 80|0))>>2]|0;
    $16 = (($15) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($value|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(630,($value|0),($17|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(-1);
      $G_B3_0$0 = $23;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B3_0$0|0);
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Security_SecurityElement_m_UnescapeP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$str) {
 $__this = $__this|0;
 $str = $str|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510112);
 __THREW__ = 0;
 invoke_v(678);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($str|0)==(0|0);
  if ($2) {
   $$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2537888|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2537888|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vii(1911,($7|0),($str|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3799,($7|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = HEAP32[3051768>>2]|0;
      $15 = HEAP32[3051776>>2]|0;
      __THREW__ = 0;
      (invoke_iiii(930,($7|0),($14|0),($15|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       invoke_vi(3799,($7|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $20 = HEAP32[3051784>>2]|0;
        $21 = HEAP32[3051792>>2]|0;
        __THREW__ = 0;
        (invoke_iiii(930,($7|0),($20|0),($21|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         __THREW__ = 0;
         invoke_vi(3799,($7|0));
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          $26 = HEAP32[3051800>>2]|0;
          $27 = HEAP32[3051808>>2]|0;
          __THREW__ = 0;
          (invoke_iiii(930,($7|0),($26|0),($27|0))|0);
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if (!($29)) {
           __THREW__ = 0;
           invoke_vi(3799,($7|0));
           $30 = __THREW__; __THREW__ = 0;
           $31 = $30&1;
           if (!($31)) {
            $32 = HEAP32[3051816>>2]|0;
            $33 = HEAP32[3051824>>2]|0;
            __THREW__ = 0;
            (invoke_iiii(930,($7|0),($32|0),($33|0))|0);
            $34 = __THREW__; __THREW__ = 0;
            $35 = $34&1;
            if (!($35)) {
             __THREW__ = 0;
             invoke_vi(3799,($7|0));
             $36 = __THREW__; __THREW__ = 0;
             $37 = $36&1;
             if (!($37)) {
              $38 = HEAP32[3051832>>2]|0;
              $39 = HEAP32[3051840>>2]|0;
              __THREW__ = 0;
              (invoke_iiii(930,($7|0),($38|0),($39|0))|0);
              $40 = __THREW__; __THREW__ = 0;
              $41 = $40&1;
              if (!($41)) {
               __THREW__ = 0;
               invoke_vi(3799,($7|0));
               $42 = __THREW__; __THREW__ = 0;
               $43 = $42&1;
               if (!($43)) {
                __THREW__ = 0;
                $44 = (invoke_iii(2730,(2535432|0),($7|0))|0);
                $45 = __THREW__; __THREW__ = 0;
                $46 = $45&1;
                if (!($46)) {
                 $$0 = $44;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Security_SecurityElement_SecurityAttribute_m_get_NameP58mscorlib_System_Security_SecurityElement_SecurityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2509344);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Security_SecurityElement_SecurityAttribute_m_get_ValueP58mscorlib_System_Security_SecurityElement_SecurityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2509392);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z53mscorlib_System_Security_SecurityElement_m_IsValidTagP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$tag) {
 $__this = $__this|0;
 $tag = $tag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510256);
 $0 = ($tag|0)==(0|0);
 if ($0) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2511456|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = HEAP8[((2511456 + 116|0))>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2511456|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2511456|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[((2511456 + 80|0))>>2]|0;
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($tag|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     $19 = (invoke_iii(630,($tag|0),($16|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = ($19|0)==(-1);
      $G_B3_0$0 = $22;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B3_0$0|0);
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Security_SecurityElement_m_set_TextP40mscorlib_System_Security_SecurityElementP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2509920);
 __THREW__ = 0;
 invoke_v(679);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $5 = (invoke_iii(969,0,($value|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    if (!($5)) {
     $8 = HEAP32[3051440>>2]|0;
     __THREW__ = 0;
     $9 = (invoke_iii(783,(0|0),($8|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = HEAP32[3051448>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiiii(101,(0|0),($9|0),($12|0),($value|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     $18 = (invoke_ii(3469,(2560072|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($18|0),($13|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($18|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   $25 = (invoke_iii(965,0,($value|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = (($__this) + 8|0);
    HEAP32[$28>>2] = $25;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z49mscorlib_System_Security_SecurityElement_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2509872);
 __THREW__ = 0;
 (invoke_ii(2996,(1168808|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2765,(1168808|0),3)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = (($3) + 12|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ($9|0)==(0);
     if ($10) {
      __THREW__ = 0;
      $11 = (invoke_i(132)|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($11|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
     $18 = (($3) + 16|0);
     HEAP16[$18>>1] = 32;
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = HEAP32[$8>>2]|0;
      $22 = ($21>>>0)<(2);
      if ($22) {
       __THREW__ = 0;
       $23 = (invoke_i(132)|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($23|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
      }
      $28 = HEAP32[$3>>2]|0;
      $29 = (($28) + 92|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($18) + ($30)|0);
      HEAP16[$31>>1] = 60;
      __THREW__ = 0;
      invoke_vi(3799,($3|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       $34 = HEAP32[$8>>2]|0;
       $35 = ($34>>>0)<(3);
       if ($35) {
        __THREW__ = 0;
        $36 = (invoke_i(132)|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($36|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
       }
       $41 = HEAP32[$3>>2]|0;
       $42 = (($41) + 92|0);
       $43 = HEAP32[$42>>2]|0;
       $44 = $43 << 1;
       $45 = (($18) + ($44)|0);
       HEAP16[$45>>1] = 62;
       __THREW__ = 0;
       (invoke_ii(2996,(2511456|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        $48 = HEAP32[((2511456 + 80|0))>>2]|0;
        HEAP32[$48>>2] = $3;
        __THREW__ = 0;
        (invoke_ii(2996,(1168808|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if (!($50)) {
         __THREW__ = 0;
         $51 = (invoke_iii(2765,(1168808|0),2)|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if (!($53)) {
          __THREW__ = 0;
          invoke_vi(3799,($51|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if (!($55)) {
           $56 = (($51) + 12|0);
           $57 = HEAP32[$56>>2]|0;
           $58 = ($57|0)==(0);
           if ($58) {
            __THREW__ = 0;
            $59 = (invoke_i(132)|0);
            $60 = __THREW__; __THREW__ = 0;
            $61 = $60&1;
            if ($61) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($59|0));
            $62 = __THREW__; __THREW__ = 0;
            $63 = $62&1;
            if ($63) {
             break;
            }
           }
           $64 = (($51) + 16|0);
           HEAP16[$64>>1] = 60;
           __THREW__ = 0;
           invoke_vi(3799,($51|0));
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if (!($66)) {
            $67 = HEAP32[$56>>2]|0;
            $68 = ($67>>>0)<(2);
            if ($68) {
             __THREW__ = 0;
             $69 = (invoke_i(132)|0);
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if ($71) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($69|0));
             $72 = __THREW__; __THREW__ = 0;
             $73 = $72&1;
             if ($73) {
              break;
             }
            }
            $74 = HEAP32[$51>>2]|0;
            $75 = (($74) + 92|0);
            $76 = HEAP32[$75>>2]|0;
            $77 = (($64) + ($76)|0);
            HEAP16[$77>>1] = 62;
            __THREW__ = 0;
            (invoke_ii(2996,(2511456|0))|0);
            $78 = __THREW__; __THREW__ = 0;
            $79 = $78&1;
            if (!($79)) {
             $80 = HEAP32[((2511456 + 80|0))>>2]|0;
             $81 = (($80) + 4|0);
             HEAP32[$81>>2] = $51;
             __THREW__ = 0;
             (invoke_ii(2996,(1168808|0))|0);
             $82 = __THREW__; __THREW__ = 0;
             $83 = $82&1;
             if (!($83)) {
              __THREW__ = 0;
              $84 = (invoke_iii(2765,(1168808|0),3)|0);
              $85 = __THREW__; __THREW__ = 0;
              $86 = $85&1;
              if (!($86)) {
               __THREW__ = 0;
               invoke_vi(3799,($84|0));
               $87 = __THREW__; __THREW__ = 0;
               $88 = $87&1;
               if (!($88)) {
                $89 = (($84) + 12|0);
                $90 = HEAP32[$89>>2]|0;
                $91 = ($90|0)==(0);
                if ($91) {
                 __THREW__ = 0;
                 $92 = (invoke_i(132)|0);
                 $93 = __THREW__; __THREW__ = 0;
                 $94 = $93&1;
                 if ($94) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($92|0));
                 $95 = __THREW__; __THREW__ = 0;
                 $96 = $95&1;
                 if ($96) {
                  break;
                 }
                }
                $97 = (($84) + 16|0);
                HEAP16[$97>>1] = 32;
                __THREW__ = 0;
                invoke_vi(3799,($84|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 break;
                }
                $100 = HEAP32[$89>>2]|0;
                $101 = ($100>>>0)<(2);
                if ($101) {
                 __THREW__ = 0;
                 $102 = (invoke_i(132)|0);
                 $103 = __THREW__; __THREW__ = 0;
                 $104 = $103&1;
                 if ($104) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($102|0));
                 $105 = __THREW__; __THREW__ = 0;
                 $106 = $105&1;
                 if ($106) {
                  break;
                 }
                }
                $107 = HEAP32[$84>>2]|0;
                $108 = (($107) + 92|0);
                $109 = HEAP32[$108>>2]|0;
                $110 = (($97) + ($109)|0);
                HEAP16[$110>>1] = 60;
                __THREW__ = 0;
                invoke_vi(3799,($84|0));
                $111 = __THREW__; __THREW__ = 0;
                $112 = $111&1;
                if ($112) {
                 break;
                }
                $113 = HEAP32[$89>>2]|0;
                $114 = ($113>>>0)<(3);
                if ($114) {
                 __THREW__ = 0;
                 $115 = (invoke_i(132)|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($115|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                }
                $120 = HEAP32[$84>>2]|0;
                $121 = (($120) + 92|0);
                $122 = HEAP32[$121>>2]|0;
                $123 = $122 << 1;
                $124 = (($97) + ($123)|0);
                HEAP16[$124>>1] = 62;
                __THREW__ = 0;
                (invoke_ii(2996,(2511456|0))|0);
                $125 = __THREW__; __THREW__ = 0;
                $126 = $125&1;
                if ($126) {
                 break;
                }
                $127 = HEAP32[((2511456 + 80|0))>>2]|0;
                $128 = (($127) + 8|0);
                HEAP32[$128>>2] = $84;
                __THREW__ = 0;
                (invoke_ii(2996,(1168808|0))|0);
                $129 = __THREW__; __THREW__ = 0;
                $130 = $129&1;
                if ($130) {
                 break;
                }
                __THREW__ = 0;
                $131 = (invoke_iii(2765,(1168808|0),3)|0);
                $132 = __THREW__; __THREW__ = 0;
                $133 = $132&1;
                if ($133) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($131|0));
                $134 = __THREW__; __THREW__ = 0;
                $135 = $134&1;
                if ($135) {
                 break;
                }
                $136 = (($131) + 12|0);
                $137 = HEAP32[$136>>2]|0;
                $138 = ($137|0)==(0);
                if ($138) {
                 __THREW__ = 0;
                 $139 = (invoke_i(132)|0);
                 $140 = __THREW__; __THREW__ = 0;
                 $141 = $140&1;
                 if ($141) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($139|0));
                 $142 = __THREW__; __THREW__ = 0;
                 $143 = $142&1;
                 if ($143) {
                  break;
                 }
                }
                $144 = (($131) + 16|0);
                HEAP16[$144>>1] = 34;
                __THREW__ = 0;
                invoke_vi(3799,($131|0));
                $145 = __THREW__; __THREW__ = 0;
                $146 = $145&1;
                if ($146) {
                 break;
                }
                $147 = HEAP32[$136>>2]|0;
                $148 = ($147>>>0)<(2);
                if ($148) {
                 __THREW__ = 0;
                 $149 = (invoke_i(132)|0);
                 $150 = __THREW__; __THREW__ = 0;
                 $151 = $150&1;
                 if ($151) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($149|0));
                 $152 = __THREW__; __THREW__ = 0;
                 $153 = $152&1;
                 if ($153) {
                  break;
                 }
                }
                $154 = HEAP32[$131>>2]|0;
                $155 = (($154) + 92|0);
                $156 = HEAP32[$155>>2]|0;
                $157 = (($144) + ($156)|0);
                HEAP16[$157>>1] = 60;
                __THREW__ = 0;
                invoke_vi(3799,($131|0));
                $158 = __THREW__; __THREW__ = 0;
                $159 = $158&1;
                if ($159) {
                 break;
                }
                $160 = HEAP32[$136>>2]|0;
                $161 = ($160>>>0)<(3);
                if ($161) {
                 __THREW__ = 0;
                 $162 = (invoke_i(132)|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($162|0));
                 $165 = __THREW__; __THREW__ = 0;
                 $166 = $165&1;
                 if ($166) {
                  break;
                 }
                }
                $167 = HEAP32[$131>>2]|0;
                $168 = (($167) + 92|0);
                $169 = HEAP32[$168>>2]|0;
                $170 = $169 << 1;
                $171 = (($144) + ($170)|0);
                HEAP16[$171>>1] = 62;
                __THREW__ = 0;
                (invoke_ii(2996,(2511456|0))|0);
                $172 = __THREW__; __THREW__ = 0;
                $173 = $172&1;
                if ($173) {
                 break;
                }
                $174 = HEAP32[((2511456 + 80|0))>>2]|0;
                $175 = (($174) + 12|0);
                HEAP32[$175>>2] = $131;
                __THREW__ = 0;
                (invoke_ii(2996,(1168808|0))|0);
                $176 = __THREW__; __THREW__ = 0;
                $177 = $176&1;
                if ($177) {
                 break;
                }
                __THREW__ = 0;
                $178 = (invoke_iii(2765,(1168808|0),5)|0);
                $179 = __THREW__; __THREW__ = 0;
                $180 = $179&1;
                if ($180) {
                 break;
                }
                HEAP32[$0>>2] = 2667248;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
                invoke_viii(551,(0|0),($178|0),($$byval_copy|0));
                $181 = __THREW__; __THREW__ = 0;
                $182 = $181&1;
                if ($182) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2511456|0))|0);
                $183 = __THREW__; __THREW__ = 0;
                $184 = $183&1;
                if ($184) {
                 break;
                }
                $185 = HEAP32[((2511456 + 80|0))>>2]|0;
                $186 = (($185) + 16|0);
                HEAP32[$186>>2] = $178;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z54mscorlib_System_Security_SecurityElement_m_IsValidTextP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$text) {
 $__this = $__this|0;
 $text = $text|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510304);
 $0 = ($text|0)==(0|0);
 if ($0) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2511456|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = HEAP8[((2511456 + 116|0))>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2511456|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2511456|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[((2511456 + 80|0))>>2]|0;
    $16 = (($15) + 4|0);
    $17 = HEAP32[$16>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($text|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(630,($text|0),($17|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(-1);
      $G_B3_0$0 = $23;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B3_0$0|0);
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Security_SecurityElement_m_GetAttributeP40mscorlib_System_Security_SecurityElementP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $__last_unhandled_exception$0 = 0;
 var $_stackTraceSentry = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510448);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L4: do {
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2298872|0),($1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $36 = (invoke_iii(2741,(2176240|0),($5|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      label = 12;
      break;
     }
     if (!($36)) {
      $V_2$0 = 0;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 80;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_iii(2740,(2176176|0),($5|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2509640|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_iii(2764,($10|0),(2509640|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($15|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(2346,($15|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 12;
      break;
     }
     __THREW__ = 0;
     $23 = (invoke_iiii(574,(0|0),($20|0),($name|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      label = 12;
      break;
     }
     if ($23) {
      $V_2$0 = $15;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 82;
      break;
     }
    }
    if ((label|0) == 12) {
     $26 = ___cxa_find_matching_catch(348288|0)|0;
     $27 = tempRet0;
     $28 = (_llvm_eh_typeid_for((348288|0))|0);
     $29 = ($27|0)==($28|0);
     if (!($29)) {
      $$01 = $26;$$02 = $27;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$01|0);
      // unreachable;
     }
     $30 = (___cxa_begin_catch(($26|0))|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     invoke_v(66);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $V_2$0 = 0;$__last_unhandled_exception$0 = $31;$leaveInstructions$sroa$0$0 = 0;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2176856|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     __THREW__ = 0;
     $43 = (invoke_iii(2735,($5|0),(2176856|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      $46 = ($43|0)==(0|0);
      do {
       if ($46) {
        if ((($leaveInstructions$sroa$0$0|0) == 80)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else if ((($leaveInstructions$sroa$0$0|0) == 82)) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3837,($__last_unhandled_exception$0|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break L4;
        }
        // unreachable;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($43|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break L4;
        }
        __THREW__ = 0;
        invoke_vii(3491,(2176768|0),($43|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break L4;
        }
        if ((($leaveInstructions$sroa$0$0|0) == 82)) {
         break;
        } else if ((($leaveInstructions$sroa$0$0|0) == 80)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3837,($__last_unhandled_exception$0|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break L4;
        }
        // unreachable;
       }
      } while(0);
      $$0 = $V_2$0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $$01 = $8;$$02 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$01|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Security_SecurityElement_m_EscapeP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$str) {
 $__this = $__this|0;
 $str = $str|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $V_2$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510064);
 __THREW__ = 0;
 invoke_v(680);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($str|0)==(0|0);
   if ($2) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2511456|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP8[((2511456 + 116|0))>>0]|0;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     __THREW__ = 0;
     (invoke_ii(2996,(2511456|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2511456|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3836,(2511456|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2511456|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[((2511456 + 80|0))>>2]|0;
     $20 = (($19) + 16|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($str|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      $24 = (invoke_iii(630,($str|0),($21|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       $27 = ($24|0)==(-1);
       if ($27) {
        $$0 = $str;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2537888|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_ii(3469,(2537888|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         __THREW__ = 0;
         invoke_vi(2525,($30|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          __THREW__ = 0;
          invoke_vi(3799,($str|0));
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if (!($36)) {
           __THREW__ = 0;
           $37 = (invoke_ii(1816,($str|0))|0);
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if (!($39)) {
            $40 = ($37|0)>(0);
            L23: do {
             if ($40) {
              $V_2$05 = 0;
              L24: while(1) {
               __THREW__ = 0;
               invoke_vi(3799,($str|0));
               $80 = __THREW__; __THREW__ = 0;
               $81 = $80&1;
               if ($81) {
                break;
               }
               __THREW__ = 0;
               $41 = (invoke_iii(621,($str|0),($V_2$05|0))|0);
               $42 = __THREW__; __THREW__ = 0;
               $43 = $42&1;
               if ($43) {
                break;
               }
               $44 = $41&65535;
               $45 = (($44) + 65502)|0;
               $46 = $45 & 65535;
               do {
                if ((($46|0) == 4)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($30|0));
                 $69 = __THREW__; __THREW__ = 0;
                 $70 = $69&1;
                 if ($70) {
                  break L24;
                 }
                 $71 = HEAP32[3051688>>2]|0;
                 __THREW__ = 0;
                 (invoke_iii(989,($30|0),($71|0))|0);
                 $72 = __THREW__; __THREW__ = 0;
                 $73 = $72&1;
                 if ($73) {
                  break L24;
                 }
                } else if ((($46|0) == 5)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($30|0));
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if ($65) {
                  break L24;
                 }
                 $66 = HEAP32[3051680>>2]|0;
                 __THREW__ = 0;
                 (invoke_iii(989,($30|0),($66|0))|0);
                 $67 = __THREW__; __THREW__ = 0;
                 $68 = $67&1;
                 if ($68) {
                  break L24;
                 }
                } else if ((($46|0) == 0)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($30|0));
                 $59 = __THREW__; __THREW__ = 0;
                 $60 = $59&1;
                 if ($60) {
                  break L24;
                 }
                 $61 = HEAP32[3051672>>2]|0;
                 __THREW__ = 0;
                 (invoke_iii(989,($30|0),($61|0))|0);
                 $62 = __THREW__; __THREW__ = 0;
                 $63 = $62&1;
                 if ($63) {
                  break L24;
                 }
                } else {
                 $47 = (($44) + 65476)|0;
                 $48 = $47 & 65535;
                 if ((($48|0) == 2)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($30|0));
                  $54 = __THREW__; __THREW__ = 0;
                  $55 = $54&1;
                  if ($55) {
                   break L24;
                  }
                  $56 = HEAP32[3051664>>2]|0;
                  __THREW__ = 0;
                  (invoke_iii(989,($30|0),($56|0))|0);
                  $57 = __THREW__; __THREW__ = 0;
                  $58 = $57&1;
                  if ($58) {
                   break L24;
                  } else {
                   break;
                  }
                 } else if ((($48|0) == 0)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($30|0));
                  $49 = __THREW__; __THREW__ = 0;
                  $50 = $49&1;
                  if ($50) {
                   break L24;
                  }
                  $51 = HEAP32[3051656>>2]|0;
                  __THREW__ = 0;
                  (invoke_iii(989,($30|0),($51|0))|0);
                  $52 = __THREW__; __THREW__ = 0;
                  $53 = $52&1;
                  if ($53) {
                   break L24;
                  } else {
                   break;
                  }
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($30|0));
                  $74 = __THREW__; __THREW__ = 0;
                  $75 = $74&1;
                  if ($75) {
                   break L24;
                  }
                  __THREW__ = 0;
                  (invoke_iii(992,($30|0),($41|0))|0);
                  $76 = __THREW__; __THREW__ = 0;
                  $77 = $76&1;
                  if ($77) {
                   break L24;
                  } else {
                   break;
                  }
                 }
                }
               } while(0);
               $78 = (($V_2$05) + 1)|0;
               $79 = ($78|0)<($37|0);
               if ($79) {
                $V_2$05 = $78;
               } else {
                break L23;
               }
              }
              $3 = ___cxa_find_matching_catch()|0;
              $4 = tempRet0;
              $lpad$phi$index = $3;$lpad$phi$index2 = $4;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
            } while(0);
            __THREW__ = 0;
            invoke_vi(3799,($30|0));
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_iii(2730,(2535432|0),($30|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $$0 = $84;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_Security_SecurityElement_m_ToStringP40mscorlib_System_Security_SecurityElement($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510352);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 (invoke_ii(2996,(2537888|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2537888|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2525,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    HEAP32[$V_0>>2] = $2;
    __THREW__ = 0;
    invoke_viii(629,($__this|0),($V_0|0),0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[$V_0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($9|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_iii(2730,(2535432|0),($9|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($12|0);
      }
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Security_SecurityElement_m_ToXmlP40mscorlib_System_Security_SecurityElementPP34mscorlib_System_Text_StringBuilderi($__this,$s,$level) {
 $__this = $__this|0;
 $s = $s|0;
 $level = $level|0;
 var $$0 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond2 = 0, $leaveInstructions$sroa$0$0 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2510400);
 __THREW__ = 0;
 invoke_v(681);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if ($1) {
   label = 8;
  } else {
   $2 = HEAP32[$s>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    label = 8;
   } else {
    $5 = HEAP32[3051880>>2]|0;
    __THREW__ = 0;
    (invoke_iii(989,($2|0),($5|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     label = 8;
    } else {
     $8 = HEAP32[$s>>2]|0;
     $9 = (($__this) + 12|0);
     $10 = HEAP32[$9>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 8;
     } else {
      __THREW__ = 0;
      (invoke_iii(989,($8|0),($10|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       label = 8;
      } else {
       $15 = (($__this) + 16|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = ($16|0)==(0|0);
       L7: do {
        if (!($17)) {
         $22 = HEAP32[$s>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($22|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if ($24) {
          label = 8;
          break L1;
         }
         $25 = HEAP32[3051888>>2]|0;
         __THREW__ = 0;
         (invoke_iii(989,($22|0),($25|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          label = 8;
          break L1;
         } else {
          $V_0$0 = 0;
         }
         while(1) {
          $89 = HEAP32[$15>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($89|0));
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           break;
          }
          __THREW__ = 0;
          $92 = (invoke_iii(2729,(2296488|0),($89|0))|0);
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           break;
          }
          $95 = ($V_0$0|0)<($92|0);
          if (!($95)) {
           break L7;
          }
          $28 = HEAP32[$15>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($28|0));
          $96 = __THREW__; __THREW__ = 0;
          $97 = $96&1;
          if ($97) {
           break;
          }
          __THREW__ = 0;
          $29 = (invoke_iiii(1648,(2296536|0),($28|0),($V_0$0|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if ($31) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2509640|0))|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if ($33) {
           break;
          }
          __THREW__ = 0;
          $34 = (invoke_iii(2764,($29|0),(2509640|0))|0);
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if ($36) {
           break;
          }
          $37 = HEAP32[$s>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($34|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
          __THREW__ = 0;
          $40 = (invoke_ii(2346,($34|0))|0);
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($37|0));
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           break;
          }
          __THREW__ = 0;
          $45 = (invoke_iii(989,($37|0),($40|0))|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          $50 = HEAP32[3051896>>2]|0;
          __THREW__ = 0;
          $51 = (invoke_iii(989,($45|0),($50|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($34|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          $56 = (invoke_ii(2347,($34|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if ($58) {
           break;
          }
          __THREW__ = 0;
          $59 = (invoke_iii(964,0,($56|0))|0);
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if ($61) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($51|0));
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           break;
          }
          __THREW__ = 0;
          $64 = (invoke_iii(989,($51|0),($59|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($64|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           break;
          }
          $69 = HEAP32[3051904>>2]|0;
          __THREW__ = 0;
          (invoke_iii(989,($64|0),($69|0))|0);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           break;
          }
          $72 = HEAP32[$15>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($72|0));
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           break;
          }
          __THREW__ = 0;
          $75 = (invoke_iii(2729,(2296488|0),($72|0))|0);
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break;
          }
          $78 = (($75) + -1)|0;
          $79 = ($V_0$0|0)==($78|0);
          if (!($79)) {
           $80 = HEAP32[$s>>2]|0;
           __THREW__ = 0;
           $81 = (invoke_ii(2441,(0|0))|0);
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if ($83) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($80|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            break;
           }
           __THREW__ = 0;
           (invoke_iii(989,($80|0),($81|0))|0);
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if ($87) {
            break;
           }
          }
          $88 = (($V_0$0) + 1)|0;
          $V_0$0 = $88;
         }
         $18 = ___cxa_find_matching_catch()|0;
         $19 = tempRet0;
         $lpad$phi$index = $18;$lpad$phi$index2 = $19;
         break L1;
        }
       } while(0);
       $98 = (($__this) + 8|0);
       $99 = HEAP32[$98>>2]|0;
       $100 = ($99|0)==(0|0);
       if ($100) {
        label = 48;
       } else {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         label = 8;
         break;
        }
        $103 = HEAP8[((2191608 + 116|0))>>0]|0;
        $104 = ($103<<24>>24)==(0);
        if ($104) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          label = 8;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          label = 8;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3836,(2191608|0));
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          label = 8;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $111 = __THREW__; __THREW__ = 0;
        $112 = $111&1;
        if ($112) {
         label = 8;
         break;
        }
        $113 = HEAP32[((2191608 + 80|0))>>2]|0;
        $114 = HEAP32[$113>>2]|0;
        __THREW__ = 0;
        $115 = (invoke_iiii(574,(0|0),($99|0),($114|0))|0);
        $116 = __THREW__; __THREW__ = 0;
        $117 = $116&1;
        if ($117) {
         label = 8;
         break;
        }
        if ($115) {
         label = 48;
        }
       }
       do {
        if ((label|0) == 48) {
         $118 = (($__this) + 20|0);
         $119 = HEAP32[$118>>2]|0;
         $120 = ($119|0)==(0|0);
         if (!($120)) {
          __THREW__ = 0;
          invoke_vi(3799,($119|0));
          $121 = __THREW__; __THREW__ = 0;
          $122 = $121&1;
          if ($122) {
           label = 8;
           break L1;
          }
          __THREW__ = 0;
          $123 = (invoke_iii(2729,(2296488|0),($119|0))|0);
          $124 = __THREW__; __THREW__ = 0;
          $125 = $124&1;
          if ($125) {
           label = 8;
           break L1;
          }
          $126 = ($123|0)==(0);
          if (!($126)) {
           break;
          }
         }
         $127 = HEAP32[$s>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($127|0));
         $128 = __THREW__; __THREW__ = 0;
         $129 = $128&1;
         if ($129) {
          label = 8;
          break L1;
         }
         $130 = HEAP32[3051912>>2]|0;
         __THREW__ = 0;
         $131 = (invoke_iii(989,($127|0),($130|0))|0);
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          label = 8;
          break L1;
         }
         __THREW__ = 0;
         $134 = (invoke_ii(2441,(0|0))|0);
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if ($136) {
          label = 8;
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($131|0));
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if ($138) {
          label = 8;
          break L1;
         }
         __THREW__ = 0;
         (invoke_iii(989,($131|0),($134|0))|0);
         $139 = __THREW__; __THREW__ = 0;
         $140 = $139&1;
         if ($140) {
          label = 8;
          break L1;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       } while(0);
       $141 = HEAP32[$s>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($141|0));
       $142 = __THREW__; __THREW__ = 0;
       $143 = $142&1;
       if ($143) {
        label = 8;
       } else {
        $144 = HEAP32[3051920>>2]|0;
        __THREW__ = 0;
        $145 = (invoke_iii(989,($141|0),($144|0))|0);
        $146 = __THREW__; __THREW__ = 0;
        $147 = $146&1;
        if ($147) {
         label = 8;
        } else {
         $148 = HEAP32[$98>>2]|0;
         __THREW__ = 0;
         $149 = (invoke_iii(964,0,($148|0))|0);
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if ($151) {
          label = 8;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($145|0));
          $152 = __THREW__; __THREW__ = 0;
          $153 = $152&1;
          if ($153) {
           label = 8;
          } else {
           __THREW__ = 0;
           (invoke_iii(989,($145|0),($149|0))|0);
           $154 = __THREW__; __THREW__ = 0;
           $155 = $154&1;
           if ($155) {
            label = 8;
           } else {
            $156 = (($__this) + 20|0);
            $157 = HEAP32[$156>>2]|0;
            $158 = ($157|0)==(0|0);
            do {
             if (!($158)) {
              $159 = HEAP32[$s>>2]|0;
              __THREW__ = 0;
              $160 = (invoke_ii(2441,(0|0))|0);
              $161 = __THREW__; __THREW__ = 0;
              $162 = $161&1;
              if ($162) {
               label = 8;
               break L1;
              }
              __THREW__ = 0;
              invoke_vi(3799,($159|0));
              $163 = __THREW__; __THREW__ = 0;
              $164 = $163&1;
              if ($164) {
               label = 8;
               break L1;
              }
              __THREW__ = 0;
              (invoke_iii(989,($159|0),($160|0))|0);
              $165 = __THREW__; __THREW__ = 0;
              $166 = $165&1;
              if ($166) {
               label = 8;
               break L1;
              }
              $167 = HEAP32[$156>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($167|0));
              $168 = __THREW__; __THREW__ = 0;
              $169 = $168&1;
              if ($169) {
               label = 8;
               break L1;
              }
              __THREW__ = 0;
              $170 = (invoke_iii(2730,(2298872|0),($167|0))|0);
              $171 = __THREW__; __THREW__ = 0;
              $172 = $171&1;
              if ($172) {
               label = 8;
               break L1;
              }
              $173 = (($level) + 1)|0;
              while(1) {
               __THREW__ = 0;
               invoke_vi(3799,($170|0));
               $186 = __THREW__; __THREW__ = 0;
               $187 = $186&1;
               if ($187) {
                label = 78;
                break;
               }
               __THREW__ = 0;
               $188 = (invoke_iii(2741,(2176240|0),($170|0))|0);
               $189 = __THREW__; __THREW__ = 0;
               $190 = $189&1;
               if ($190) {
                label = 78;
                break;
               }
               if (!($188)) {
                $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 362;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($170|0));
               $191 = __THREW__; __THREW__ = 0;
               $192 = $191&1;
               if ($192) {
                label = 78;
                break;
               }
               __THREW__ = 0;
               $174 = (invoke_iii(2740,(2176176|0),($170|0))|0);
               $175 = __THREW__; __THREW__ = 0;
               $176 = $175&1;
               if ($176) {
                label = 78;
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2511456|0))|0);
               $177 = __THREW__; __THREW__ = 0;
               $178 = $177&1;
               if ($178) {
                label = 78;
                break;
               }
               __THREW__ = 0;
               $179 = (invoke_iii(2764,($174|0),(2511456|0))|0);
               $180 = __THREW__; __THREW__ = 0;
               $181 = $180&1;
               if ($181) {
                label = 78;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($179|0));
               $182 = __THREW__; __THREW__ = 0;
               $183 = $182&1;
               if ($183) {
                label = 78;
                break;
               }
               __THREW__ = 0;
               invoke_viii(629,($179|0),($s|0),($173|0));
               $184 = __THREW__; __THREW__ = 0;
               $185 = $184&1;
               if ($185) {
                label = 78;
                break;
               }
              }
              if ((label|0) == 78) {
               $193 = ___cxa_find_matching_catch(348288|0)|0;
               $194 = tempRet0;
               $195 = (_llvm_eh_typeid_for((348288|0))|0);
               $196 = ($194|0)==($195|0);
               if (!($196)) {
                $$0 = $193;$$03 = $194;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($$0|0);
                // unreachable;
               }
               $197 = (___cxa_begin_catch(($193|0))|0);
               $198 = HEAP32[$197>>2]|0;
               __THREW__ = 0;
               invoke_v(66);
               $199 = __THREW__; __THREW__ = 0;
               $200 = $199&1;
               if ($200) {
                label = 8;
                break L1;
               }
               $__last_unhandled_exception$0 = $198;$leaveInstructions$sroa$0$0 = 0;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2176856|0))|0);
              $201 = __THREW__; __THREW__ = 0;
              $202 = $201&1;
              if ($202) {
               label = 8;
               break L1;
              }
              __THREW__ = 0;
              $203 = (invoke_iii(2735,($170|0),(2176856|0))|0);
              $204 = __THREW__; __THREW__ = 0;
              $205 = $204&1;
              if ($205) {
               label = 8;
               break L1;
              }
              $206 = ($203|0)==(0|0);
              if ($206) {
               $cond1 = ($leaveInstructions$sroa$0$0|0)==(362);
               if ($cond1) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3837,($__last_unhandled_exception$0|0));
               $207 = __THREW__; __THREW__ = 0;
               $208 = $207&1;
               if ($208) {
                label = 8;
                break L1;
               }
               // unreachable;
              }
              __THREW__ = 0;
              invoke_vi(3799,($203|0));
              $209 = __THREW__; __THREW__ = 0;
              $210 = $209&1;
              if ($210) {
               label = 8;
               break L1;
              }
              __THREW__ = 0;
              invoke_vii(3491,(2176768|0),($203|0));
              $211 = __THREW__; __THREW__ = 0;
              $212 = $211&1;
              if ($212) {
               label = 8;
               break L1;
              }
              $cond2 = ($leaveInstructions$sroa$0$0|0)==(362);
              if ($cond2) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3837,($__last_unhandled_exception$0|0));
              $213 = __THREW__; __THREW__ = 0;
              $214 = $213&1;
              if ($214) {
               label = 8;
               break L1;
              }
              // unreachable;
             }
            } while(0);
            $215 = HEAP32[$s>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($215|0));
            $216 = __THREW__; __THREW__ = 0;
            $217 = $216&1;
            if ($217) {
             label = 8;
            } else {
             $218 = HEAP32[3051928>>2]|0;
             __THREW__ = 0;
             $219 = (invoke_iii(989,($215|0),($218|0))|0);
             $220 = __THREW__; __THREW__ = 0;
             $221 = $220&1;
             if ($221) {
              label = 8;
             } else {
              $222 = HEAP32[$9>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($219|0));
              $223 = __THREW__; __THREW__ = 0;
              $224 = $223&1;
              if ($224) {
               label = 8;
              } else {
               __THREW__ = 0;
               $225 = (invoke_iii(989,($219|0),($222|0))|0);
               $226 = __THREW__; __THREW__ = 0;
               $227 = $226&1;
               if ($227) {
                label = 8;
               } else {
                __THREW__ = 0;
                invoke_vi(3799,($225|0));
                $228 = __THREW__; __THREW__ = 0;
                $229 = $228&1;
                if ($229) {
                 label = 8;
                } else {
                 $230 = HEAP32[3051936>>2]|0;
                 __THREW__ = 0;
                 $231 = (invoke_iii(989,($225|0),($230|0))|0);
                 $232 = __THREW__; __THREW__ = 0;
                 $233 = $232&1;
                 if ($233) {
                  label = 8;
                 } else {
                  __THREW__ = 0;
                  $234 = (invoke_ii(2441,(0|0))|0);
                  $235 = __THREW__; __THREW__ = 0;
                  $236 = $235&1;
                  if ($236) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($231|0));
                  $237 = __THREW__; __THREW__ = 0;
                  $238 = $237&1;
                  if ($238) {
                   label = 8;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(989,($231|0),($234|0))|0);
                  $239 = __THREW__; __THREW__ = 0;
                  $240 = $239&1;
                  if ($240) {
                   label = 8;
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $lpad$phi$index = $20;$lpad$phi$index2 = $21;
 }
 $$0 = $lpad$phi$index;$$03 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z71mscorlib_System_Security_SecurityElement_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z57mscorlib_System_Security_SecurityException_m_get_DemandedP42mscorlib_System_Security_SecurityException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2511592);
 $0 = (($__this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Security_SecurityException_m_get_FirstPermissionThatFailedP42mscorlib_System_Security_SecurityException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2511640);
 $0 = (($__this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z64mscorlib_System_Security_SecurityException_m_get_PermissionStateP42mscorlib_System_Security_SecurityException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2511688);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z63mscorlib_System_Security_SecurityException_m_get_PermissionTypeP42mscorlib_System_Security_SecurityException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2511736);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z59mscorlib_System_Security_SecurityException_m_get_GrantedSetP42mscorlib_System_Security_SecurityException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2511784);
 $0 = (($__this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z59mscorlib_System_Security_SecurityException_m_get_RefusedSetP42mscorlib_System_Security_SecurityException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2511832);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z58mscorlib_System_Security_SecurityException_m_GetObjectDataP42mscorlib_System_Security_SecurityExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2511880);
 __THREW__ = 0;
 invoke_v(682);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = $context;
   $4 = $3;
   $5 = HEAP32[$4>>2]|0;
   $6 = (($3) + 4)|0;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = $0;
   $10 = $9;
   HEAP32[$10>>2] = $5;
   $11 = (($9) + 4)|0;
   $12 = $11;
   HEAP32[$12>>2] = $8;
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
   invoke_viii(544,($__this|0),($info|0),($tmpcast$byval_copy|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_ii(2351,($__this|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP32[3052128>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($20|0),($15|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
    $25 = ___cxa_find_matching_catch(348288|0)|0;
    $26 = tempRet0;
    $27 = (_llvm_eh_typeid_for((348288|0))|0);
    $28 = ($26|0)==($27|0);
    if (!($28)) {
     $$0 = $25;$$01 = $26;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
    $29 = (___cxa_begin_catch(($25|0))|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = HEAP32[$30>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii(2727,(2512704|0),($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    do {
     if (!($34)) {
      if ($32) {
       __THREW__ = 0;
       invoke_v(66);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break L1;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      } else {
       $41 = (___cxa_allocate_exception(4)|0);
       $42 = HEAP32[$29>>2]|0;
       HEAP32[$41>>2] = $42;
       __THREW__ = 0;
       invoke_viii(1567,($41|0),(348288|0),(0|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       // unreachable;
      }
     }
    } while(0);
    $37 = ___cxa_find_matching_catch()|0;
    $38 = tempRet0;
    __THREW__ = 0;
    invoke_v(66);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     $45 = ___cxa_find_matching_catch(0|0)|0;
     $46 = tempRet0;
     ___clang_call_terminate($45);
     // unreachable;
    } else {
     $$0 = $37;$$01 = $38;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($$0|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $$0 = $23;$$01 = $24;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z53mscorlib_System_Security_SecurityException_m_ToStringP42mscorlib_System_Security_SecurityException($__this) {
 $__this = $__this|0;
 var $$04 = 0, $$05 = 0, $$1 = 0, $$16 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond2 = 0, $cond3 = 0;
 var $leaveInstructions$sroa$1$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2511928);
 __THREW__ = 0;
 invoke_v(683);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP32[3052176>>2]|0;
   __THREW__ = 0;
   $3 = (invoke_iiii(418,(0|0),($__this|0),($2|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2537888|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(3469,(2537888|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vii(1911,($8|0),($3|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       $13 = (($__this) + 56|0);
       $14 = HEAP32[$13>>2]|0;
       $15 = ($14|0)==(0|0);
       if ($15) {
        label = 12;
       } else {
        __THREW__ = 0;
        $18 = (invoke_ii(2441,(0|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         label = 13;
        } else {
         __THREW__ = 0;
         $21 = (invoke_ii(2352,($__this|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if ($23) {
          label = 13;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($8|0));
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if ($25) {
           label = 13;
          } else {
           $26 = HEAP32[3052184>>2]|0;
           __THREW__ = 0;
           (invoke_iiiii(163,($8|0),($26|0),($18|0),($21|0))|0);
           $27 = __THREW__; __THREW__ = 0;
           $28 = $27&1;
           if ($28) {
            label = 13;
           } else {
            label = 12;
           }
          }
         }
        }
       }
       do {
        if ((label|0) == 12) {
         $29 = (($__this) + 76|0);
         $30 = HEAP32[$29>>2]|0;
         $31 = ($30|0)==(0|0);
         if (!($31)) {
          __THREW__ = 0;
          invoke_vi(3799,($30|0));
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if ($35) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $36 = (invoke_iii(2730,(2149112|0),($30|0))|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           label = 13;
           break;
          }
          $41 = HEAP32[3052192>>2]|0;
          __THREW__ = 0;
          $42 = (invoke_iii(632,($36|0),($41|0))|0);
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           label = 13;
           break;
          }
          $45 = (($42) + 1)|0;
          __THREW__ = 0;
          (invoke_ii(2996,(1167664|0))|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $48 = (invoke_iii(2765,(1167664|0),4)|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $51 = (invoke_ii(2441,(0|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($48|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           label = 13;
           break;
          }
          $56 = (($48) + 12|0);
          $57 = HEAP32[$56>>2]|0;
          $58 = ($57|0)==(0);
          if ($58) {
           __THREW__ = 0;
           $59 = (invoke_i(132)|0);
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if ($61) {
            label = 13;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($59|0));
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if ($63) {
            label = 13;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($48|0),($51|0));
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           label = 13;
           break;
          }
          $66 = (($48) + 16|0);
          HEAP32[$66>>2] = $51;
          $67 = HEAP32[$29>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($67|0));
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if ($69) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $70 = (invoke_iii(2730,(2413464|0),($67|0))|0);
          $71 = __THREW__; __THREW__ = 0;
          $72 = $71&1;
          if ($72) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($70|0));
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $75 = (invoke_iii(2730,(2233608|0),($70|0))|0);
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($48|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           label = 13;
           break;
          }
          $80 = HEAP32[$56>>2]|0;
          $81 = ($80>>>0)<(2);
          if ($81) {
           __THREW__ = 0;
           $82 = (invoke_i(132)|0);
           $83 = __THREW__; __THREW__ = 0;
           $84 = $83&1;
           if ($84) {
            label = 13;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($82|0));
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if ($86) {
            label = 13;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($48|0),($75|0));
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           label = 13;
           break;
          }
          $89 = HEAP32[$48>>2]|0;
          $90 = (($89) + 92|0);
          $91 = HEAP32[$90>>2]|0;
          $92 = (($66) + ($91)|0);
          HEAP32[$92>>2] = $75;
          $93 = HEAP32[$29>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($93|0));
          $94 = __THREW__; __THREW__ = 0;
          $95 = $94&1;
          if ($95) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $96 = (invoke_iii(2730,(2242568|0),($93|0))|0);
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($48|0));
          $99 = __THREW__; __THREW__ = 0;
          $100 = $99&1;
          if ($100) {
           label = 13;
           break;
          }
          $101 = HEAP32[$56>>2]|0;
          $102 = ($101>>>0)<(3);
          if ($102) {
           __THREW__ = 0;
           $103 = (invoke_i(132)|0);
           $104 = __THREW__; __THREW__ = 0;
           $105 = $104&1;
           if ($105) {
            label = 13;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($103|0));
           $106 = __THREW__; __THREW__ = 0;
           $107 = $106&1;
           if ($107) {
            label = 13;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($48|0),($96|0));
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           label = 13;
           break;
          }
          $110 = HEAP32[$48>>2]|0;
          $111 = (($110) + 92|0);
          $112 = HEAP32[$111>>2]|0;
          $113 = $112 << 1;
          $114 = (($66) + ($113)|0);
          HEAP32[$114>>2] = $96;
          __THREW__ = 0;
          invoke_vi(3799,($36|0));
          $115 = __THREW__; __THREW__ = 0;
          $116 = $115&1;
          if ($116) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $117 = (invoke_iii(623,($36|0),($45|0))|0);
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          if ($119) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($48|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 13;
           break;
          }
          $122 = HEAP32[$56>>2]|0;
          $123 = ($122>>>0)<(4);
          if ($123) {
           __THREW__ = 0;
           $124 = (invoke_i(132)|0);
           $125 = __THREW__; __THREW__ = 0;
           $126 = $125&1;
           if ($126) {
            label = 13;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($124|0));
           $127 = __THREW__; __THREW__ = 0;
           $128 = $127&1;
           if ($128) {
            label = 13;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($48|0),($117|0));
          $129 = __THREW__; __THREW__ = 0;
          $130 = $129&1;
          if ($130) {
           label = 13;
           break;
          }
          $131 = HEAP32[$48>>2]|0;
          $132 = (($131) + 92|0);
          $133 = HEAP32[$132>>2]|0;
          $134 = ($133*3)|0;
          $135 = (($66) + ($134)|0);
          HEAP32[$135>>2] = $117;
          __THREW__ = 0;
          invoke_vi(3799,($8|0));
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           label = 13;
           break;
          }
          $138 = HEAP32[3052200>>2]|0;
          __THREW__ = 0;
          (invoke_iiii(933,($8|0),($138|0),($48|0))|0);
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           label = 13;
           break;
          }
         }
         $141 = (($__this) + 52|0);
         $142 = HEAP32[$141>>2]|0;
         $143 = ($142|0)==(0|0);
         if (!($143)) {
          __THREW__ = 0;
          $144 = (invoke_ii(2441,(0|0))|0);
          $145 = __THREW__; __THREW__ = 0;
          $146 = $145&1;
          if ($146) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $147 = (invoke_ii(2351,($__this|0))|0);
          $148 = __THREW__; __THREW__ = 0;
          $149 = $148&1;
          if ($149) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($8|0));
          $150 = __THREW__; __THREW__ = 0;
          $151 = $150&1;
          if ($151) {
           label = 13;
           break;
          }
          $152 = HEAP32[3052208>>2]|0;
          __THREW__ = 0;
          (invoke_iiiii(163,($8|0),($152|0),($144|0),($147|0))|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           label = 13;
           break;
          }
         }
         $155 = (($__this) + 60|0);
         $156 = HEAP32[$155>>2]|0;
         $157 = ($156|0)==(0|0);
         if (!($157)) {
          __THREW__ = 0;
          invoke_vi(3799,($156|0));
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $160 = (invoke_ii(1816,($156|0))|0);
          $161 = __THREW__; __THREW__ = 0;
          $162 = $161&1;
          if ($162) {
           label = 13;
           break;
          }
          $163 = ($160|0)<(1);
          if (!($163)) {
           __THREW__ = 0;
           $164 = (invoke_ii(2441,(0|0))|0);
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            label = 13;
            break;
           }
           __THREW__ = 0;
           $167 = (invoke_ii(2353,($__this|0))|0);
           $168 = __THREW__; __THREW__ = 0;
           $169 = $168&1;
           if ($169) {
            label = 13;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($8|0));
           $170 = __THREW__; __THREW__ = 0;
           $171 = $170&1;
           if ($171) {
            label = 13;
            break;
           }
           $172 = HEAP32[3052216>>2]|0;
           __THREW__ = 0;
           (invoke_iiiii(163,($8|0),($172|0),($164|0),($167|0))|0);
           $173 = __THREW__; __THREW__ = 0;
           $174 = $173&1;
           if ($174) {
            label = 13;
            break;
           }
          }
         }
         $175 = (($__this) + 64|0);
         $176 = HEAP32[$175>>2]|0;
         $177 = ($176|0)==(0|0);
         if (!($177)) {
          __THREW__ = 0;
          invoke_vi(3799,($176|0));
          $178 = __THREW__; __THREW__ = 0;
          $179 = $178&1;
          if ($179) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $180 = (invoke_ii(1816,($176|0))|0);
          $181 = __THREW__; __THREW__ = 0;
          $182 = $181&1;
          if ($182) {
           label = 13;
           break;
          }
          $183 = ($180|0)<(1);
          if (!($183)) {
           __THREW__ = 0;
           $184 = (invoke_ii(2441,(0|0))|0);
           $185 = __THREW__; __THREW__ = 0;
           $186 = $185&1;
           if ($186) {
            label = 13;
            break;
           }
           __THREW__ = 0;
           $187 = (invoke_ii(2354,($__this|0))|0);
           $188 = __THREW__; __THREW__ = 0;
           $189 = $188&1;
           if ($189) {
            label = 13;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($8|0));
           $190 = __THREW__; __THREW__ = 0;
           $191 = $190&1;
           if ($191) {
            label = 13;
            break;
           }
           $192 = HEAP32[3052224>>2]|0;
           __THREW__ = 0;
           (invoke_iiiii(163,($8|0),($192|0),($184|0),($187|0))|0);
           $193 = __THREW__; __THREW__ = 0;
           $194 = $193&1;
           if ($194) {
            label = 13;
            break;
           }
          }
         }
         $195 = (($__this) + 68|0);
         $196 = HEAP32[$195>>2]|0;
         $197 = ($196|0)==(0|0);
         if (!($197)) {
          __THREW__ = 0;
          $198 = (invoke_ii(2441,(0|0))|0);
          $199 = __THREW__; __THREW__ = 0;
          $200 = $199&1;
          if ($200) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $201 = (invoke_ii(2349,($__this|0))|0);
          $202 = __THREW__; __THREW__ = 0;
          $203 = $202&1;
          if ($203) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($8|0));
          $204 = __THREW__; __THREW__ = 0;
          $205 = $204&1;
          if ($205) {
           label = 13;
           break;
          }
          $206 = HEAP32[3052232>>2]|0;
          __THREW__ = 0;
          (invoke_iiiii(163,($8|0),($206|0),($198|0),($201|0))|0);
          $207 = __THREW__; __THREW__ = 0;
          $208 = $207&1;
          if ($208) {
           label = 13;
           break;
          }
         }
         $209 = (($__this) + 72|0);
         $210 = HEAP32[$209>>2]|0;
         $211 = ($210|0)==(0|0);
         if (!($211)) {
          __THREW__ = 0;
          $212 = (invoke_ii(2441,(0|0))|0);
          $213 = __THREW__; __THREW__ = 0;
          $214 = $213&1;
          if ($214) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          $215 = (invoke_ii(2350,($__this|0))|0);
          $216 = __THREW__; __THREW__ = 0;
          $217 = $216&1;
          if ($217) {
           label = 13;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($8|0));
          $218 = __THREW__; __THREW__ = 0;
          $219 = $218&1;
          if ($219) {
           label = 13;
           break;
          }
          $220 = HEAP32[3052240>>2]|0;
          __THREW__ = 0;
          (invoke_iiiii(163,($8|0),($220|0),($212|0),($215|0))|0);
          $221 = __THREW__; __THREW__ = 0;
          $222 = $221&1;
          if ($222) {
           label = 13;
           break;
          }
         }
         $223 = (($__this) + 80|0);
         $224 = HEAP32[$223>>2]|0;
         $225 = ($224|0)==(0|0);
         if (!($225)) {
          __THREW__ = 0;
          $226 = (invoke_ii(2441,(0|0))|0);
          $227 = __THREW__; __THREW__ = 0;
          $228 = $227&1;
          if ($228) {
           label = 13;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($8|0));
           $229 = __THREW__; __THREW__ = 0;
           $230 = $229&1;
           if ($230) {
            label = 13;
           } else {
            $231 = HEAP32[3052248>>2]|0;
            __THREW__ = 0;
            (invoke_iiii(934,($8|0),($231|0),($226|0))|0);
            $232 = __THREW__; __THREW__ = 0;
            $233 = $232&1;
            if ($233) {
             label = 13;
            } else {
             $234 = HEAP32[$223>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($234|0));
             $235 = __THREW__; __THREW__ = 0;
             $236 = $235&1;
             if ($236) {
              label = 13;
             } else {
              __THREW__ = 0;
              $237 = (invoke_iii(2730,(2506672|0),($234|0))|0);
              $238 = __THREW__; __THREW__ = 0;
              $239 = $238&1;
              if ($239) {
               label = 13;
              } else {
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($237|0));
                $274 = __THREW__; __THREW__ = 0;
                $275 = $274&1;
                if ($275) {
                 label = 92;
                 break;
                }
                __THREW__ = 0;
                $276 = (invoke_iii(2741,(2176240|0),($237|0))|0);
                $277 = __THREW__; __THREW__ = 0;
                $278 = $277&1;
                if ($278) {
                 label = 92;
                 break;
                }
                if (!($276)) {
                 $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$1$0 = 441;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($237|0));
                $279 = __THREW__; __THREW__ = 0;
                $280 = $279&1;
                if ($280) {
                 label = 92;
                 break;
                }
                __THREW__ = 0;
                $240 = (invoke_iii(2740,(2176176|0),($237|0))|0);
                $241 = __THREW__; __THREW__ = 0;
                $242 = $241&1;
                if ($242) {
                 label = 92;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2507704|0))|0);
                $243 = __THREW__; __THREW__ = 0;
                $244 = $243&1;
                if ($244) {
                 label = 92;
                 break;
                }
                __THREW__ = 0;
                $245 = (invoke_iii(2735,($240|0),(2507704|0))|0);
                $246 = __THREW__; __THREW__ = 0;
                $247 = $246&1;
                if ($247) {
                 label = 92;
                 break;
                }
                $248 = ($245|0)==(0|0);
                if (!($248)) {
                 continue;
                }
                __THREW__ = 0;
                $266 = (invoke_ii(2441,(0|0))|0);
                $267 = __THREW__; __THREW__ = 0;
                $268 = $267&1;
                if ($268) {
                 label = 92;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($8|0));
                $269 = __THREW__; __THREW__ = 0;
                $270 = $269&1;
                if ($270) {
                 label = 92;
                 break;
                }
                $271 = HEAP32[3052256>>2]|0;
                __THREW__ = 0;
                (invoke_iiiii(163,($8|0),($271|0),($266|0),($240|0))|0);
                $272 = __THREW__; __THREW__ = 0;
                $273 = $272&1;
                if ($273) {
                 label = 92;
                 break;
                }
               }
               if ((label|0) == 92) {
                $249 = ___cxa_find_matching_catch(348288|0)|0;
                $250 = tempRet0;
                $251 = (_llvm_eh_typeid_for((348288|0))|0);
                $252 = ($250|0)==($251|0);
                if (!($252)) {
                 $$04 = $249;$$05 = $250;$$pre$phiZ2D = $251;
                 label = 93;
                 break;
                }
                $262 = (___cxa_begin_catch(($249|0))|0);
                $263 = HEAP32[$262>>2]|0;
                __THREW__ = 0;
                invoke_v(66);
                $264 = __THREW__; __THREW__ = 0;
                $265 = $264&1;
                if ($265) {
                 label = 13;
                 break;
                }
                $__last_unhandled_exception$0 = $263;$leaveInstructions$sroa$1$0 = 0;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2176856|0))|0);
               $281 = __THREW__; __THREW__ = 0;
               $282 = $281&1;
               if ($282) {
                label = 13;
                break;
               }
               __THREW__ = 0;
               $283 = (invoke_iii(2735,($237|0),(2176856|0))|0);
               $284 = __THREW__; __THREW__ = 0;
               $285 = $284&1;
               if ($285) {
                label = 13;
                break;
               }
               $286 = ($283|0)==(0|0);
               if ($286) {
                $cond2 = ($leaveInstructions$sroa$1$0|0)==(441);
                if ($cond2) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3837,($__last_unhandled_exception$0|0));
                $287 = __THREW__; __THREW__ = 0;
                $288 = $287&1;
                if ($288) {
                 label = 13;
                 break;
                }
                // unreachable;
               }
               __THREW__ = 0;
               invoke_vi(3799,($283|0));
               $289 = __THREW__; __THREW__ = 0;
               $290 = $289&1;
               if ($290) {
                label = 13;
                break;
               }
               __THREW__ = 0;
               invoke_vii(3491,(2176768|0),($283|0));
               $291 = __THREW__; __THREW__ = 0;
               $292 = $291&1;
               if ($292) {
                label = 13;
                break;
               }
               $cond3 = ($leaveInstructions$sroa$1$0|0)==(441);
               if ($cond3) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3837,($__last_unhandled_exception$0|0));
               $293 = __THREW__; __THREW__ = 0;
               $294 = $293&1;
               if ($294) {
                label = 13;
                break;
               }
               // unreachable;
              }
             }
            }
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 13) {
        $32 = ___cxa_find_matching_catch(348288|0)|0;
        $33 = tempRet0;
        $$pre = (_llvm_eh_typeid_for((348288|0))|0);
        $$04 = $32;$$05 = $33;$$pre$phiZ2D = $$pre;
        label = 93;
       }
       do {
        if ((label|0) == 93) {
         $253 = ($$05|0)==($$pre$phiZ2D|0);
         if (!($253)) {
          $$1 = $$04;$$16 = $$05;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($$1|0);
          // unreachable;
         }
         $254 = (___cxa_begin_catch(($$04|0))|0);
         $255 = HEAP32[$254>>2]|0;
         $256 = HEAP32[$255>>2]|0;
         __THREW__ = 0;
         $257 = (invoke_iii(2727,(2512704|0),($256|0))|0);
         $258 = __THREW__; __THREW__ = 0;
         $259 = $258&1;
         if (!($259)) {
          if ($257) {
           __THREW__ = 0;
           invoke_v(66);
           $260 = __THREW__; __THREW__ = 0;
           $261 = $260&1;
           if ($261) {
            break L1;
           } else {
            break;
           }
          }
          $299 = (___cxa_allocate_exception(4)|0);
          $300 = HEAP32[$254>>2]|0;
          HEAP32[$299>>2] = $300;
          __THREW__ = 0;
          invoke_viii(1567,($299|0),(348288|0),(0|0));
          $301 = __THREW__; __THREW__ = 0;
          $302 = $301&1;
          if (!($302)) {
           // unreachable;
          }
         }
         $295 = ___cxa_find_matching_catch()|0;
         $296 = tempRet0;
         __THREW__ = 0;
         invoke_v(66);
         $297 = __THREW__; __THREW__ = 0;
         $298 = $297&1;
         if ($298) {
          $308 = ___cxa_find_matching_catch(0|0)|0;
          $309 = tempRet0;
          ___clang_call_terminate($308);
          // unreachable;
         } else {
          $$1 = $295;$$16 = $296;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($$1|0);
          // unreachable;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($8|0));
       $303 = __THREW__; __THREW__ = 0;
       $304 = $303&1;
       if (!($304)) {
        __THREW__ = 0;
        $305 = (invoke_iii(2730,(2535432|0),($8|0))|0);
        $306 = __THREW__; __THREW__ = 0;
        $307 = $306&1;
        if (!($307)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($305|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 $$1 = $16;$$16 = $17;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Security_SecurityException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z144mscorlib_System_Security_SecurityException_CustomAttributesCacheGenerator_mscorlib_System_Security_SecurityExceptionTraits_Demanded_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_Security_SecuritySafeCriticalAttribute_m__ctorP54mscorlib_System_Security_SecuritySafeCriticalAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2512840);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z85mscorlib_System_Security_SecuritySafeCriticalAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2512888)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($7,32767);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($7,0);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($7,0);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m__ctorP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2513176);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z94mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,5188);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Security_UnverifiableCodeAttribute_m__ctorP50mscorlib_System_Security_UnverifiableCodeAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2513464);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Security_UnverifiableCodeAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,2);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z42mscorlib_System_Text_ASCIIEncoding_m__ctorP34mscorlib_System_Text_ASCIIEncoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2513744);
 __THREW__ = 0;
 invoke_v(684);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($12|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(1909,($__this|0),20127);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $4 = HEAP32[3052576>>2]|0;
  $5 = (($__this) + 44|0);
  HEAP32[$5>>2] = $4;
  $6 = (($__this) + 36|0);
  HEAP32[$6>>2] = $4;
  $7 = (($__this) + 28|0);
  HEAP32[$7>>2] = $4;
  $8 = HEAP32[3052584>>2]|0;
  $9 = (($__this) + 32|0);
  HEAP32[$9>>2] = $8;
  $10 = (($__this) + 40|0);
  HEAP8[$10>>0] = 1;
  $11 = (($__this) + 41|0);
  HEAP8[$11>>0] = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z144mscorlib_System_Text_ASCIIEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Char_arrii($__this,$chars,$index,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2513792);
 __THREW__ = 0;
 invoke_v(685);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3052632>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($chars) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($count|0);
      }
     }
     $41 = HEAP32[3052664>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,(0|0),($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3052656>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3052648>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,(0|0),($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3052640>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3837,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Text_ASCIIEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP34mscorlib_System_Text_ASCIIEncodingP22mscorlib_System_String($__this,$chars) {
 $__this = $__this|0;
 $chars = $chars|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2513840);
 __THREW__ = 0;
 invoke_v(686);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($chars|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($17|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3052728>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3837,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z191mscorlib_System_Text_ASCIIEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2513888);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiiiiiiii(18,($__this|0),($chars|0),($charIndex|0),($charCount|0),($bytes|0),($byteIndex|0),($V_0|0),($V_1|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z283mscorlib_System_Text_ASCIIEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Text_EncoderFallbackBufferU0026_ref_mscorlib_System_CharU005BU005DU0026_refP34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arriPP42mscorlib_System_Text_EncoderFallbackBufferPS2_($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex,$buffer,$fallback_chars) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $buffer = $buffer|0;
 $fallback_chars = $fallback_chars|0;
 var $$0 = 0, $$01$be = 0, $$0119 = 0, $$1$be = 0, $$120 = 0, $$in = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0;
 var $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0;
 var $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0;
 var $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0;
 var $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0;
 var $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0;
 var $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0;
 var $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2513936);
 __THREW__ = 0;
 invoke_v(687);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3052744>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($bytes|0)==(0|0);
   if ($19) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3052752>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($charIndex|0)<(0);
   if (!($30)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    $33 = (($chars) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)<($charIndex|0);
    if (!($35)) {
     $50 = ($charCount|0)<(0);
     if (!($50)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = HEAP32[$33>>2]|0;
      $54 = (($53) - ($charIndex))|0;
      $55 = ($54|0)<($charCount|0);
      if (!($55)) {
       $70 = ($byteIndex|0)<(0);
       if (!($70)) {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         break;
        }
        $73 = (($bytes) + 12|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ($74|0)<($byteIndex|0);
        if (!($75)) {
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break;
         }
         $92 = HEAP32[$73>>2]|0;
         $93 = (($92) - ($byteIndex))|0;
         $94 = ($93|0)<($charCount|0);
         if ($94) {
          $98 = HEAP32[3052808>>2]|0;
          __THREW__ = 0;
          $99 = (invoke_iii(977,(0|0),($98|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           break;
          }
          __THREW__ = 0;
          $104 = (invoke_ii(3469,(2560072|0))|0);
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1924,($104|0),($99|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if ($108) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3837,($104|0));
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           break;
          }
          // unreachable;
         }
         $95 = ($charCount|0)>(0);
         if (!($95)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($charCount|0);
         }
         $96 = (($chars) + 16|0);
         $97 = (($bytes) + 16|0);
         $$0119 = $byteIndex;$$120 = $charIndex;$$in = $charCount;
         L41: while(1) {
          $144 = (($$in) + -1)|0;
          $162 = (($$120) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $267 = __THREW__; __THREW__ = 0;
          $268 = $267&1;
          if ($268) {
           label = 4;
           break;
          }
          $111 = ($$120|0)<(0);
          if ($111) {
           label = 57;
          } else {
           $112 = HEAP32[$33>>2]|0;
           $113 = ($$120>>>0)<($112>>>0);
           if (!($113)) {
            label = 57;
           }
          }
          if ((label|0) == 57) {
           label = 0;
           __THREW__ = 0;
           $114 = (invoke_i(132)|0);
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($114|0));
           $117 = __THREW__; __THREW__ = 0;
           $118 = $117&1;
           if ($118) {
            label = 4;
            break;
           }
          }
          $119 = HEAP32[$chars>>2]|0;
          $120 = (($119) + 92|0);
          $121 = HEAP32[$120>>2]|0;
          $122 = Math_imul($121, $$120)|0;
          $123 = (($96) + ($122)|0);
          $124 = HEAP16[$123>>1]|0;
          $125 = ($124&65535)>(127);
          if ($125) {
           $145 = HEAP32[$buffer>>2]|0;
           $146 = ($145|0)==(0|0);
           if ($146) {
            __THREW__ = 0;
            $147 = (invoke_ii(2382,($__this|0))|0);
            $148 = __THREW__; __THREW__ = 0;
            $149 = $148&1;
            if ($149) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($147|0));
            $150 = __THREW__; __THREW__ = 0;
            $151 = $150&1;
            if ($151) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            $152 = (invoke_iii(2730,(2526744|0),($147|0))|0);
            $153 = __THREW__; __THREW__ = 0;
            $154 = $153&1;
            if ($154) {
             label = 4;
             break;
            }
            HEAP32[$buffer>>2] = $152;
           }
           __THREW__ = 0;
           $155 = (invoke_iii(603,(0|0),($124|0))|0);
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            label = 4;
            break;
           }
           $$not = $155 ^ 1;
           $158 = ($$in|0)<(3);
           $or$cond = $158 | $$not;
           do {
            if ($or$cond) {
             label = 88;
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($chars|0));
             $159 = __THREW__; __THREW__ = 0;
             $160 = $159&1;
             if ($160) {
              label = 4;
              break L41;
             }
             $161 = ($162|0)<(0);
             if ($161) {
              label = 77;
             } else {
              $163 = HEAP32[$33>>2]|0;
              $164 = ($162>>>0)<($163>>>0);
              if (!($164)) {
               label = 77;
              }
             }
             if ((label|0) == 77) {
              label = 0;
              __THREW__ = 0;
              $165 = (invoke_i(132)|0);
              $166 = __THREW__; __THREW__ = 0;
              $167 = $166&1;
              if ($167) {
               label = 4;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($165|0));
              $168 = __THREW__; __THREW__ = 0;
              $169 = $168&1;
              if ($169) {
               label = 4;
               break L41;
              }
             }
             $170 = HEAP32[$chars>>2]|0;
             $171 = (($170) + 92|0);
             $172 = HEAP32[$171>>2]|0;
             $173 = Math_imul($172, $162)|0;
             $174 = (($96) + ($173)|0);
             $175 = HEAP16[$174>>1]|0;
             __THREW__ = 0;
             $176 = (invoke_iii(603,(0|0),($175|0))|0);
             $177 = __THREW__; __THREW__ = 0;
             $178 = $177&1;
             if ($178) {
              label = 4;
              break L41;
             }
             if (!($176)) {
              label = 88;
              break;
             }
             $179 = HEAP32[$buffer>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($chars|0));
             $180 = __THREW__; __THREW__ = 0;
             $181 = $180&1;
             if ($181) {
              label = 4;
              break L41;
             }
             if ($161) {
              label = 84;
             } else {
              $182 = HEAP32[$33>>2]|0;
              $183 = ($162>>>0)<($182>>>0);
              if (!($183)) {
               label = 84;
              }
             }
             if ((label|0) == 84) {
              label = 0;
              __THREW__ = 0;
              $184 = (invoke_i(132)|0);
              $185 = __THREW__; __THREW__ = 0;
              $186 = $185&1;
              if ($186) {
               label = 4;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($184|0));
              $187 = __THREW__; __THREW__ = 0;
              $188 = $187&1;
              if ($188) {
               label = 4;
               break L41;
              }
             }
             $189 = HEAP32[$chars>>2]|0;
             $190 = (($189) + 92|0);
             $191 = HEAP32[$190>>2]|0;
             $192 = Math_imul($191, $162)|0;
             $193 = (($96) + ($192)|0);
             $194 = HEAP16[$193>>1]|0;
             __THREW__ = 0;
             invoke_vi(3799,($179|0));
             $195 = __THREW__; __THREW__ = 0;
             $196 = $195&1;
             if ($196) {
              label = 4;
              break L41;
             }
             $197 = (($$120) + 2)|0;
             __THREW__ = 0;
             (invoke_iiiiii(237,(2527240|0),($179|0),($124|0),($194|0),($$120|0))|0);
             $198 = __THREW__; __THREW__ = 0;
             $199 = $198&1;
             if ($199) {
              label = 4;
              break L41;
             } else {
              $$0 = $197;
             }
            }
           } while(0);
           if ((label|0) == 88) {
            label = 0;
            $200 = HEAP32[$buffer>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($200|0));
            $201 = __THREW__; __THREW__ = 0;
            $202 = $201&1;
            if ($202) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            (invoke_iiiii(324,(2527152|0),($200|0),($124|0),($$120|0))|0);
            $203 = __THREW__; __THREW__ = 0;
            $204 = $203&1;
            if ($204) {
             label = 4;
             break;
            } else {
             $$0 = $162;
            }
           }
           $205 = HEAP32[$fallback_chars>>2]|0;
           $206 = ($205|0)==(0|0);
           if ($206) {
            label = 95;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($205|0));
            $207 = __THREW__; __THREW__ = 0;
            $208 = $207&1;
            if ($208) {
             label = 4;
             break;
            }
            $209 = (($205) + 12|0);
            $210 = HEAP32[$209>>2]|0;
            $211 = HEAP32[$buffer>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($211|0));
            $212 = __THREW__; __THREW__ = 0;
            $213 = $212&1;
            if ($213) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            $214 = (invoke_iii(2729,(2527080|0),($211|0))|0);
            $215 = __THREW__; __THREW__ = 0;
            $216 = $215&1;
            if ($216) {
             label = 4;
             break;
            }
            $217 = ($210|0)<($214|0);
            if ($217) {
             label = 95;
            } else {
             $V_2$0 = 0;
            }
           }
           if ((label|0) == 95) {
            label = 0;
            $218 = HEAP32[$buffer>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($218|0));
            $219 = __THREW__; __THREW__ = 0;
            $220 = $219&1;
            if ($220) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            $221 = (invoke_iii(2729,(2527080|0),($218|0))|0);
            $222 = __THREW__; __THREW__ = 0;
            $223 = $222&1;
            if ($223) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(1168808|0))|0);
            $224 = __THREW__; __THREW__ = 0;
            $225 = $224&1;
            if ($225) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            $226 = (invoke_iii(2765,(1168808|0),($221|0))|0);
            $227 = __THREW__; __THREW__ = 0;
            $228 = $227&1;
            if ($228) {
             label = 4;
             break;
            }
            HEAP32[$fallback_chars>>2] = $226;
            $V_2$0 = 0;
           }
           while(1) {
            $251 = HEAP32[$fallback_chars>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($251|0));
            $252 = __THREW__; __THREW__ = 0;
            $253 = $252&1;
            if ($253) {
             label = 3;
             break L41;
            }
            $254 = (($251) + 12|0);
            $255 = HEAP32[$254>>2]|0;
            $256 = ($V_2$0|0)<($255|0);
            $233 = HEAP32[$fallback_chars>>2]|0;
            if (!($256)) {
             break;
            }
            $229 = HEAP32[$buffer>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($229|0));
            $257 = __THREW__; __THREW__ = 0;
            $258 = $257&1;
            if ($258) {
             label = 3;
             break L41;
            }
            __THREW__ = 0;
            $230 = (invoke_iii(2767,(2527288|0),($229|0))|0);
            $231 = __THREW__; __THREW__ = 0;
            $232 = $231&1;
            if ($232) {
             label = 3;
             break L41;
            }
            __THREW__ = 0;
            invoke_vi(3799,($233|0));
            $234 = __THREW__; __THREW__ = 0;
            $235 = $234&1;
            if ($235) {
             label = 3;
             break L41;
            }
            $236 = (($233) + 12|0);
            $237 = HEAP32[$236>>2]|0;
            $238 = ($V_2$0>>>0)<($237>>>0);
            if (!($238)) {
             __THREW__ = 0;
             $239 = (invoke_i(132)|0);
             $240 = __THREW__; __THREW__ = 0;
             $241 = $240&1;
             if ($241) {
              label = 3;
              break L41;
             }
             __THREW__ = 0;
             invoke_vi(3302,($239|0));
             $242 = __THREW__; __THREW__ = 0;
             $243 = $242&1;
             if ($243) {
              label = 3;
              break L41;
             }
            }
            $244 = HEAP32[$233>>2]|0;
            $245 = (($233) + 16|0);
            $246 = (($244) + 92|0);
            $247 = HEAP32[$246>>2]|0;
            $248 = Math_imul($247, $V_2$0)|0;
            $249 = (($245) + ($248)|0);
            HEAP16[$249>>1] = $230;
            $250 = (($V_2$0) + 1)|0;
            $V_2$0 = $250;
           }
           __THREW__ = 0;
           invoke_vi(3799,($233|0));
           $259 = __THREW__; __THREW__ = 0;
           $260 = $259&1;
           if ($260) {
            label = 4;
            break;
           }
           $261 = (($233) + 12|0);
           $262 = HEAP32[$261>>2]|0;
           __THREW__ = 0;
           $263 = (invoke_iiiiiiiii(18,($__this|0),($233|0),0,($262|0),($bytes|0),($$0119|0),($buffer|0),($fallback_chars|0))|0);
           $264 = __THREW__; __THREW__ = 0;
           $265 = $264&1;
           if ($265) {
            label = 4;
            break;
           }
           $266 = (($263) + ($$0119))|0;
           $$01$be = $266;$$1$be = $$0;
          } else {
           $126 = (($$0119) + 1)|0;
           $127 = $124&255;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            label = 4;
            break;
           }
           $130 = ($$0119|0)<(0);
           if ($130) {
            label = 63;
           } else {
            $131 = HEAP32[$73>>2]|0;
            $132 = ($$0119>>>0)<($131>>>0);
            if (!($132)) {
             label = 63;
            }
           }
           if ((label|0) == 63) {
            label = 0;
            __THREW__ = 0;
            $133 = (invoke_i(132)|0);
            $134 = __THREW__; __THREW__ = 0;
            $135 = $134&1;
            if ($135) {
             label = 4;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($133|0));
            $136 = __THREW__; __THREW__ = 0;
            $137 = $136&1;
            if ($137) {
             label = 4;
             break;
            }
           }
           $138 = HEAP32[$bytes>>2]|0;
           $139 = (($138) + 92|0);
           $140 = HEAP32[$139>>2]|0;
           $141 = Math_imul($140, $$0119)|0;
           $142 = (($97) + ($141)|0);
           HEAP8[$142>>0] = $127;
           $$01$be = $126;$$1$be = $162;
          }
          $143 = ($144|0)>(0);
          if ($143) {
           $$0119 = $$01$be;$$120 = $$1$be;$$in = $144;
          } else {
           label = 113;
           break;
          }
         }
         if ((label|0) == 3) {
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index3 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 4) {
          $5 = ___cxa_find_matching_catch()|0;
          $6 = tempRet0;
          $lpad$phi$index = $5;$lpad$phi$index3 = $6;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 113) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($charCount|0);
         }
        }
       }
       $76 = HEAP32[3052800>>2]|0;
       __THREW__ = 0;
       $77 = (invoke_iii(977,(0|0),($76|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
       __THREW__ = 0;
       $82 = (invoke_ii(3469,(2561352|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        break;
       }
       $85 = HEAP32[3052792>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($82|0),($85|0),($77|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3837,($82|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       // unreachable;
      }
     }
     $56 = HEAP32[3052784>>2]|0;
     __THREW__ = 0;
     $57 = (invoke_iii(977,(0|0),($56|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     $62 = (invoke_ii(3469,(2561352|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      break;
     }
     $65 = HEAP32[3052776>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($62|0),($65|0),($57|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($62|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     // unreachable;
    }
   }
   $36 = HEAP32[3052768>>2]|0;
   __THREW__ = 0;
   $37 = (invoke_iii(977,(0|0),($36|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if (!($41)) {
     __THREW__ = 0;
     $42 = (invoke_ii(3469,(2561352|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      $45 = HEAP32[3052760>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($42|0),($45|0),($37|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       invoke_vi(3837,($42|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker3I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvtti($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvti($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN16VirtFuncInvoker0I26mscorlib_System_CharTraitsE6InvokeEP10MethodInfoPv($method,$obj) {
 $method = $method|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$3 & 4095]($4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z49mscorlib_System_Text_ASCIIEncoding_m_GetCharCountP34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2513984);
 __THREW__ = 0;
 invoke_v(688);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3052960>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($bytes) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($count|0);
      }
     }
     $41 = HEAP32[3052992>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,(0|0),($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3052984>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3052976>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,(0|0),($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3052968>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3837,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z191mscorlib_System_Text_ASCIIEncoding_m_GetChars_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2514032);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiiiiiii(90,($__this|0),($bytes|0),($byteIndex|0),($byteCount|0),($chars|0),($charIndex|0),($V_0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z243mscorlib_System_Text_ASCIIEncoding_m_GetChars_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Text_DecoderFallbackBufferU0026_refP34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arriPP42mscorlib_System_Text_DecoderFallbackBuffer($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex,$buffer) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $buffer = $buffer|0;
 var $$01 = 0, $$019 = 0, $$1$be = 0, $$118 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2514080);
 __THREW__ = 0;
 invoke_v(689);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3053008>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($chars|0)==(0|0);
   if ($19) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3053016>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($byteIndex|0)<(0);
   if (!($30)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    $33 = (($bytes) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)<($byteIndex|0);
    if (!($35)) {
     $50 = ($byteCount|0)<(0);
     if (!($50)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = HEAP32[$33>>2]|0;
      $54 = (($53) - ($byteIndex))|0;
      $55 = ($54|0)<($byteCount|0);
      if (!($55)) {
       $70 = ($charIndex|0)<(0);
       if (!($70)) {
        __THREW__ = 0;
        invoke_vi(3799,($chars|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         break;
        }
        $73 = (($chars) + 12|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ($74|0)<($charIndex|0);
        if (!($75)) {
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break;
         }
         $92 = HEAP32[$73>>2]|0;
         $93 = (($92) - ($charIndex))|0;
         $94 = ($93|0)<($byteCount|0);
         if ($94) {
          $98 = HEAP32[3053072>>2]|0;
          __THREW__ = 0;
          $99 = (invoke_iii(977,(0|0),($98|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           break;
          }
          __THREW__ = 0;
          $104 = (invoke_ii(3469,(2560072|0))|0);
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1924,($104|0),($99|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if ($108) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3837,($104|0));
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           break;
          }
          // unreachable;
         }
         $95 = ($byteCount|0)>(0);
         if (!($95)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($byteCount|0);
         }
         $96 = (($bytes) + 16|0);
         $97 = (($chars) + 16|0);
         $$019 = $byteIndex;$$118 = $charIndex;$$in = $byteCount;
         L41: while(1) {
          $144 = (($$in) + -1)|0;
          $158 = (($$019) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($bytes|0));
          $190 = __THREW__; __THREW__ = 0;
          $191 = $190&1;
          if ($191) {
           label = 4;
           break;
          }
          $111 = ($$019|0)<(0);
          if ($111) {
           label = 57;
          } else {
           $112 = HEAP32[$33>>2]|0;
           $113 = ($$019>>>0)<($112>>>0);
           if (!($113)) {
            label = 57;
           }
          }
          if ((label|0) == 57) {
           label = 0;
           __THREW__ = 0;
           $114 = (invoke_i(132)|0);
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($114|0));
           $117 = __THREW__; __THREW__ = 0;
           $118 = $117&1;
           if ($118) {
            label = 4;
            break;
           }
          }
          $119 = HEAP32[$bytes>>2]|0;
          $120 = (($119) + 92|0);
          $121 = HEAP32[$120>>2]|0;
          $122 = Math_imul($121, $$019)|0;
          $123 = (($96) + ($122)|0);
          $124 = HEAP8[$123>>0]|0;
          $125 = $124&255;
          $126 = ($124<<24>>24)<(0);
          L50: do {
           if ($126) {
            $145 = HEAP32[$buffer>>2]|0;
            $146 = ($145|0)==(0|0);
            if ($146) {
             __THREW__ = 0;
             $147 = (invoke_ii(2381,($__this|0))|0);
             $148 = __THREW__; __THREW__ = 0;
             $149 = $148&1;
             if ($149) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             invoke_vi(3799,($147|0));
             $150 = __THREW__; __THREW__ = 0;
             $151 = $150&1;
             if ($151) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             $152 = (invoke_iii(2730,(2514128|0),($147|0))|0);
             $153 = __THREW__; __THREW__ = 0;
             $154 = $153&1;
             if ($154) {
              label = 4;
              break L41;
             }
             HEAP32[$buffer>>2] = $152;
             $155 = $152;
            } else {
             $155 = $145;
            }
            __THREW__ = 0;
            invoke_vi(3799,($155|0));
            $156 = __THREW__; __THREW__ = 0;
            $157 = $156&1;
            if ($157) {
             label = 4;
             break L41;
            }
            __THREW__ = 0;
            (invoke_iiiii(325,(2514176|0),($155|0),($bytes|0),($158|0))|0);
            $159 = __THREW__; __THREW__ = 0;
            $160 = $159&1;
            if ($160) {
             label = 4;
             break L41;
            } else {
             $$01 = $$118;
            }
            while(1) {
             $180 = HEAP32[$buffer>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($180|0));
             $181 = __THREW__; __THREW__ = 0;
             $182 = $181&1;
             if ($182) {
              label = 3;
              break L41;
             }
             __THREW__ = 0;
             $183 = (invoke_iii(2729,(2514272|0),($180|0))|0);
             $184 = __THREW__; __THREW__ = 0;
             $185 = $184&1;
             if ($185) {
              label = 3;
              break L41;
             }
             $186 = ($183|0)>(0);
             if (!($186)) {
              $$1$be = $$01;
              break L50;
             }
             $187 = (($$01) + 1)|0;
             $161 = HEAP32[$buffer>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($161|0));
             $188 = __THREW__; __THREW__ = 0;
             $189 = $188&1;
             if ($189) {
              label = 3;
              break L41;
             }
             __THREW__ = 0;
             $162 = (invoke_iii(2767,(2514224|0),($161|0))|0);
             $163 = __THREW__; __THREW__ = 0;
             $164 = $163&1;
             if ($164) {
              label = 3;
              break L41;
             }
             __THREW__ = 0;
             invoke_vi(3799,($chars|0));
             $165 = __THREW__; __THREW__ = 0;
             $166 = $165&1;
             if ($166) {
              label = 3;
              break L41;
             }
             $167 = ($$01|0)<(0);
             if ($167) {
              label = 78;
             } else {
              $168 = HEAP32[$73>>2]|0;
              $169 = ($$01>>>0)<($168>>>0);
              if (!($169)) {
               label = 78;
              }
             }
             if ((label|0) == 78) {
              label = 0;
              __THREW__ = 0;
              $170 = (invoke_i(132)|0);
              $171 = __THREW__; __THREW__ = 0;
              $172 = $171&1;
              if ($172) {
               label = 3;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($170|0));
              $173 = __THREW__; __THREW__ = 0;
              $174 = $173&1;
              if ($174) {
               label = 3;
               break L41;
              }
             }
             $175 = HEAP32[$chars>>2]|0;
             $176 = (($175) + 92|0);
             $177 = HEAP32[$176>>2]|0;
             $178 = Math_imul($177, $$01)|0;
             $179 = (($97) + ($178)|0);
             HEAP16[$179>>1] = $162;
             $$01 = $187;
            }
           } else {
            $127 = (($$118) + 1)|0;
            __THREW__ = 0;
            invoke_vi(3799,($chars|0));
            $128 = __THREW__; __THREW__ = 0;
            $129 = $128&1;
            if ($129) {
             label = 4;
             break L41;
            }
            $130 = ($$118|0)<(0);
            if ($130) {
             label = 63;
            } else {
             $131 = HEAP32[$73>>2]|0;
             $132 = ($$118>>>0)<($131>>>0);
             if (!($132)) {
              label = 63;
             }
            }
            if ((label|0) == 63) {
             label = 0;
             __THREW__ = 0;
             $133 = (invoke_i(132)|0);
             $134 = __THREW__; __THREW__ = 0;
             $135 = $134&1;
             if ($135) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             invoke_vi(3302,($133|0));
             $136 = __THREW__; __THREW__ = 0;
             $137 = $136&1;
             if ($137) {
              label = 4;
              break L41;
             }
            }
            $138 = HEAP32[$chars>>2]|0;
            $139 = (($138) + 92|0);
            $140 = HEAP32[$139>>2]|0;
            $141 = Math_imul($140, $$118)|0;
            $142 = (($97) + ($141)|0);
            HEAP16[$142>>1] = $125;
            $$1$be = $127;
           }
          } while(0);
          $143 = ($144|0)>(0);
          if ($143) {
           $$019 = $158;$$118 = $$1$be;$$in = $144;
          } else {
           label = 86;
           break;
          }
         }
         if ((label|0) == 3) {
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index3 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 4) {
          $5 = ___cxa_find_matching_catch()|0;
          $6 = tempRet0;
          $lpad$phi$index = $5;$lpad$phi$index3 = $6;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 86) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($byteCount|0);
         }
        }
       }
       $76 = HEAP32[3053064>>2]|0;
       __THREW__ = 0;
       $77 = (invoke_iii(977,(0|0),($76|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
       __THREW__ = 0;
       $82 = (invoke_ii(3469,(2561352|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        break;
       }
       $85 = HEAP32[3053056>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($82|0),($85|0),($77|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3837,($82|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       // unreachable;
      }
     }
     $56 = HEAP32[3053048>>2]|0;
     __THREW__ = 0;
     $57 = (invoke_iii(977,(0|0),($56|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     $62 = (invoke_ii(3469,(2561352|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      break;
     }
     $65 = HEAP32[3053040>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($62|0),($65|0),($57|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($62|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     // unreachable;
    }
   }
   $36 = HEAP32[3053032>>2]|0;
   __THREW__ = 0;
   $37 = (invoke_iii(977,(0|0),($36|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if (!($41)) {
     __THREW__ = 0;
     $42 = (invoke_ii(3469,(2561352|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      $45 = HEAP32[3053024>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($42|0),($45|0),($37|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       invoke_vi(3837,($42|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_i($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z46mscorlib_System_Text_ASCIIEncoding_m_GetStringP34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$byteIndex,$byteCount) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $G_B14_0$0 = 0, $G_B18_0$0 = 0, $V_3$010 = 0, $V_5$09 = 0, $_stackTraceSentry = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2514320);
 __THREW__ = 0;
 invoke_v(690);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3053112>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($byteIndex|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($bytes) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($byteIndex|0);
    if (!($20)) {
     $35 = ($byteCount|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($byteIndex))|0;
      $40 = ($39|0)<($byteCount|0);
      if (!($40)) {
       $55 = ($byteCount|0)==(0);
       if ($55) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
        $58 = HEAP8[((2191608 + 116|0))>>0]|0;
        $59 = ($58<<24>>24)==(0);
        if ($59) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3836,(2191608|0));
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
        $68 = HEAP32[((2191608 + 80|0))>>2]|0;
        $69 = HEAP32[$68>>2]|0;
        $$0 = $69;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($bytes|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break;
       }
       $72 = HEAP32[$18>>2]|0;
       $73 = ($72|0)==(0);
       if ($73) {
        $G_B14_0$0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        $76 = HEAP32[$18>>2]|0;
        $77 = ($76|0)==(0);
        if ($77) {
         __THREW__ = 0;
         $78 = (invoke_i(132)|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($78|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          break;
         }
        }
        $83 = (($bytes) + 16|0);
        $G_B14_0$0 = $83;
       }
       __THREW__ = 0;
       $84 = (invoke_iii(643,(0|0),($byteCount|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       __THREW__ = 0;
       $87 = (invoke_ii(1919,(0|0))|0);
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       $$sum = (($byteCount) + ($byteIndex))|0;
       $90 = (($G_B14_0$0) + ($$sum)|0);
       $91 = ($$sum|0)>($byteIndex|0);
       if (!($91)) {
        $$0 = $84;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $92 = $84;
       $93 = (($87) + ($92))|0;
       $94 = (($G_B14_0$0) + ($byteIndex)|0);
       $95 = $93;
       $V_3$010 = $94;$V_5$09 = $95;
       while(1) {
        $96 = (($V_3$010) + 1|0);
        $97 = HEAP8[$V_3$010>>0]|0;
        $98 = (($V_5$09) + 2|0);
        $99 = ($97<<24>>24)<(0);
        $phitmp = $97&255;
        $G_B18_0$0 = $99 ? 63 : $phitmp;
        HEAP16[$V_5$09>>1] = $G_B18_0$0;
        $100 = ($96>>>0)<($90>>>0);
        if ($100) {
         $V_3$010 = $96;$V_5$09 = $98;
        } else {
         $$0 = $84;
         break;
        }
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     $41 = HEAP32[3053144>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,(0|0),($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3053136>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3837,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3053128>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,(0|0),($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3053120>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3837,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z171mscorlib_System_Text_ASCIIEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingPtiPhi($__this,$chars,$charCount,$bytes,$byteCount) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B14_0$0 = 0, $V_0$09 = 0, $_stackTraceSentry = 0, $exitcond = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2514368);
 __THREW__ = 0;
 invoke_v(691);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3053160>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($bytes|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3053168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($charCount|0)>(-1);
   if (!($26)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(3469,(2561352|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[3053176>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($29|0),($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($29|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    // unreachable;
   }
   $37 = ($byteCount|0)>(-1);
   if (!($37)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3469,(2561352|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $43 = HEAP32[3053184>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($40|0),($43|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3837,($40|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    // unreachable;
   }
   $48 = ($byteCount|0)<($charCount|0);
   if (!($48)) {
    $49 = ($charCount|0)>(0);
    if ($49) {
     $V_0$09 = 0;
    } else {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($charCount|0);
    }
    while(1) {
     $61 = (($chars) + ($V_0$09<<1)|0);
     $62 = HEAP16[$61>>1]|0;
     $63 = (($bytes) + ($V_0$09)|0);
     $64 = ($62&65535)>(127);
     $phitmp = $62&255;
     $G_B14_0$0 = $64 ? 63 : $phitmp;
     HEAP8[$63>>0] = $G_B14_0$0;
     $65 = (($V_0$09) + 1)|0;
     $exitcond = ($65|0)==($charCount|0);
     if ($exitcond) {
      break;
     } else {
      $V_0$09 = $65;
     }
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($charCount|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560072|0))|0);
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_ii(3469,(2560072|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     $55 = HEAP32[3053192>>2]|0;
     $56 = HEAP32[3053200>>2]|0;
     __THREW__ = 0;
     invoke_viii(641,($52|0),($55|0),($56|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if (!($58)) {
      __THREW__ = 0;
      invoke_vi(3837,($52|0));
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if (!($60)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z123mscorlib_System_Text_ASCIIEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingPti($__this,$chars,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $count = $count|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2514416);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($count|0);
}
function __ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_E6InvokeEPFiPvS3_iiS3_iES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$6,$8,$11)|0);
 HEAP32[$ret>>2] = $12;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S1_S1_E6InvokeEPFiPvS3_iiS3_iS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$3,$6,$8,$11,$13,$15)|0);
 HEAP32[$ret>>2] = $16;
 $17 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($17|0);
}
function __ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S1_E6InvokeEPFiPvS3_iiS3_iS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$6,$8,$11,$13)|0);
 HEAP32[$ret>>2] = $14;
 $15 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($15|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_E6InvokeEPFiPvS3_iS3_iES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$3,$5,$8)|0);
 HEAP32[$ret>>2] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __Z65mscorlib_System_Text_ASCIIEncoding_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2507088)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 STACKTOP = sp;return;
}
function __Z237mscorlib_System_Text_ASCIIEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_ASCIIEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z189mscorlib_System_Text_ASCIIEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_ASCIIEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z49mscorlib_System_Text_Decoder_m_get_FallbackBufferP28mscorlib_System_Text_Decoder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2515384);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $10 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($10|0);
 }
 $3 = (($__this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  $7 = (invoke_iii(2730,(2514128|0),($4|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   HEAP32[$0>>2] = $7;
   $10 = $7;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($10|0);
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Text_Decoder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z122mscorlib_System_Text_Decoder_CustomAttributesCacheGenerator_mscorlib_System_Text_DecoderTraits_FallbackBuffer_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_Text_DecoderExceptionFallback_m__ctorP45mscorlib_System_Text_DecoderExceptionFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2515768);
 __THREW__ = 0;
 invoke_vi(2504,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44mscorlib_System_Text_DecoderFallback_m__ctorP36mscorlib_System_Text_DecoderFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516720);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z68mscorlib_System_Text_DecoderExceptionFallback_m_CreateFallbackBufferP45mscorlib_System_Text_DecoderExceptionFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2515816);
 __THREW__ = 0;
 (invoke_ii(2996,(2516584|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2516584|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2503,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Text_DecoderExceptionFallbackBuffer_m__ctorP51mscorlib_System_Text_DecoderExceptionFallbackBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516216);
 __THREW__ = 0;
 invoke_vi(2506,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_Text_DecoderExceptionFallback_m_EqualsP45mscorlib_System_Text_DecoderExceptionFallbackP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2515864);
 __THREW__ = 0;
 (invoke_ii(2996,(2516080|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2516080|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)!=(0|0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($5|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Text_DecoderExceptionFallback_m_GetHashCodeP45mscorlib_System_Text_DecoderExceptionFallback($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2515912);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z50mscorlib_System_Text_DecoderFallbackBuffer_m__ctorP42mscorlib_System_Text_DecoderFallbackBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2517424);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z67mscorlib_System_Text_DecoderExceptionFallbackBuffer_m_get_RemainingP51mscorlib_System_Text_DecoderExceptionFallbackBuffer($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516264);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z62mscorlib_System_Text_DecoderExceptionFallbackBuffer_m_FallbackP51mscorlib_System_Text_DecoderExceptionFallbackBufferP24mscorlib_System_Byte_arri($__this,$bytesUnknown,$index) {
 $__this = $__this|0;
 $bytesUnknown = $bytesUnknown|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516312);
 __THREW__ = 0;
 (invoke_ii(2996,(2518104|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2518104|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viiii(171,($2|0),(0|0),($bytesUnknown|0),($index|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3837,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_Text_DecoderFallbackException_m__ctorP45mscorlib_System_Text_DecoderFallbackExceptionP22mscorlib_System_StringP24mscorlib_System_Byte_arri($__this,$message,$bytesUnknown,$index) {
 $__this = $__this|0;
 $message = $message|0;
 $bytesUnknown = $bytesUnknown|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2517784);
 $0 = (($__this) + 60|0);
 HEAP32[$0>>2] = -1;
 __THREW__ = 0;
 invoke_vii(1924,($__this|0),($message|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($__this) + 56|0);
  HEAP32[$3>>2] = $bytesUnknown;
  HEAP32[$0>>2] = $index;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z65mscorlib_System_Text_DecoderExceptionFallbackBuffer_m_GetNextCharP51mscorlib_System_Text_DecoderExceptionFallbackBuffer($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516360);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFbPvS4_iES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$3)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z45mscorlib_System_Text_DecoderFallback_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516768);
 __THREW__ = 0;
 invoke_v(692);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2516080|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2516080|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(2502,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2517288|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = HEAP32[((2517288 + 80|0))>>2]|0;
      HEAP32[$11>>2] = $4;
      __THREW__ = 0;
      (invoke_ii(2996,(2524464|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       $14 = (invoke_ii(3469,(2524464|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __THREW__ = 0;
        invoke_vi(2508,($14|0));
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2517288|0))|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if (!($20)) {
          $21 = HEAP32[((2517288 + 80|0))>>2]|0;
          $22 = (($21) + 4|0);
          HEAP32[$22>>2] = $14;
          __THREW__ = 0;
          (invoke_ii(2996,(2524464|0))|0);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           $25 = (invoke_ii(3469,(2524464|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            $28 = HEAP32[3053320>>2]|0;
            __THREW__ = 0;
            invoke_vii(1905,($25|0),($28|0));
            $29 = __THREW__; __THREW__ = 0;
            $30 = $29&1;
            if (!($30)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2517288|0))|0);
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if (!($32)) {
              $33 = HEAP32[((2517288 + 80|0))>>2]|0;
              $34 = (($33) + 8|0);
              HEAP32[$34>>2] = $25;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($35|0);
 // unreachable;
}
function __Z60mscorlib_System_Text_DecoderFallback_m_get_ExceptionFallbackP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516816);
 __THREW__ = 0;
 (invoke_ii(2996,(2517288|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2517288 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2517288|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2517288|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2517288|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2517288|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2517288 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_Text_DecoderFallback_m_get_ReplacementFallbackP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516864);
 __THREW__ = 0;
 (invoke_ii(2996,(2517288|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2517288 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2517288|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2517288|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2517288|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2517288|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2517288 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Text_DecoderFallback_m_get_StandardSafeFallbackP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2516912);
 __THREW__ = 0;
 (invoke_ii(2996,(2517288|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2517288 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2517288|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2517288|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3836,(2517288|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2517288|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2517288 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Text_DecoderFallbackBuffer_m_ResetP42mscorlib_System_Text_DecoderFallbackBuffer($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2517472);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_Text_DecoderReplacementFallback_m__ctor_mscorlib_System_VoidP47mscorlib_System_Text_DecoderReplacementFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2523888);
 __THREW__ = 0;
 invoke_v(693);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3053344>>2]|0;
  __THREW__ = 0;
  invoke_vii(1905,($__this|0),($2|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z99mscorlib_System_Text_DecoderReplacementFallback_m__ctor_mscorlib_System_Void_mscorlib_System_StringP47mscorlib_System_Text_DecoderReplacementFallbackP22mscorlib_System_String($__this,$replacement) {
 $__this = $__this|0;
 $replacement = $replacement|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2523936);
 __THREW__ = 0;
 invoke_vi(2504,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($replacement|0)==(0|0);
  if (!($2)) {
   $14 = (($__this) + 8|0);
   HEAP32[$14>>2] = $replacement;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(2585,($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3838,($7|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z66mscorlib_System_ArgumentNullException_m__ctor_mscorlib_System_VoidP37mscorlib_System_ArgumentNullException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560208);
 __THREW__ = 0;
 invoke_v(694);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3060416>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1924,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2147467261);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception8559($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_Text_DecoderReplacementFallback_m_get_DefaultStringP47mscorlib_System_Text_DecoderReplacementFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2523984);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Text_DecoderReplacementFallback_m_CreateFallbackBufferP47mscorlib_System_Text_DecoderReplacementFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2524032);
 __THREW__ = 0;
 (invoke_ii(2996,(2525168|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2525168|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1906,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Text_DecoderReplacementFallbackBuffer_m__ctorP53mscorlib_System_Text_DecoderReplacementFallbackBufferP47mscorlib_System_Text_DecoderReplacementFallback($__this,$fallback) {
 $__this = $__this|0;
 $fallback = $fallback|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2524600);
 __THREW__ = 0;
 invoke_v(695);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(2506,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($fallback|0)==(0|0);
    if (!($4)) {
     __THREW__ = 0;
     invoke_vi(3799,($fallback|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_ii(2364,($fallback|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = (($__this) + 16|0);
     HEAP32[$22>>2] = $19;
     $23 = (($__this) + 12|0);
     HEAP32[$23>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2560584|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[3053368>>2]|0;
      __THREW__ = 0;
      invoke_vii(1925,($9|0),($12|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3838,($9|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z56mscorlib_System_Text_DecoderReplacementFallback_m_EqualsP47mscorlib_System_Text_DecoderReplacementFallbackP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2524080);
 __THREW__ = 0;
 (invoke_ii(2996,(2524464|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2524464|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $G_B3_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
   $8 = (($__this) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($2) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_iiii(574,(0|0),($9|0),($13|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $G_B3_0$0 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Text_DecoderReplacementFallback_m_GetHashCodeP47mscorlib_System_Text_DecoderReplacementFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2524128);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(2185544|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z178mscorlib_System_Text_DecoderReplacementFallback_CustomAttributesCacheGenerator_mscorlib_System_Text_DecoderReplacementFallback_m__ctor_mscorlib_System_Void_mscorlib_System_StringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z89mscorlib_System_ArgumentNullException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP37mscorlib_System_ArgumentNullExceptionP22mscorlib_System_String($__this,$paramName) {
 $__this = $__this|0;
 $paramName = $paramName|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560256);
 __THREW__ = 0;
 invoke_v(696);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3060480>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viii(641,($__this|0),($3|0),($paramName|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2147467261);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z69mscorlib_System_Text_DecoderReplacementFallbackBuffer_m_get_RemainingP53mscorlib_System_Text_DecoderReplacementFallbackBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2524648);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 $3 = (($__this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 }
 __THREW__ = 0;
 $7 = (invoke_ii(1816,($4|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 }
 $10 = (($__this) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($7) - ($11))|0;
 $G_B3_0$0 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B3_0$0|0);
}
function __Z64mscorlib_System_Text_DecoderReplacementFallbackBuffer_m_FallbackP53mscorlib_System_Text_DecoderReplacementFallbackBufferP24mscorlib_System_Byte_arri($__this,$bytesUnknown,$index) {
 $__this = $__this|0;
 $bytesUnknown = $bytesUnknown|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2524696);
 __THREW__ = 0;
 invoke_v(697);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytesUnknown|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3053400>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 8|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_iii(2729,(2524648|0),($__this|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = ($18|0)==(0);
    if (!($21)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __THREW__ = 0;
     $24 = (invoke_ii(3469,(2560072|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = HEAP32[3053408>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($24|0),($27|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($24|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
   }
   $32 = ($index|0)<(0);
   if (!($32)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytesUnknown|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($bytesUnknown) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)<($index|0);
    if (!($37)) {
     HEAP8[$15>>0] = 1;
     $48 = (($__this) + 12|0);
     HEAP32[$48>>2] = 0;
     $49 = (($__this) + 16|0);
     $50 = HEAP32[$49>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($50|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     $53 = (invoke_ii(1816,($50|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     $56 = ($53|0)>(0);
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($56|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __THREW__ = 0;
    $40 = (invoke_ii(3469,(2561352|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     $43 = HEAP32[3053416>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($40|0),($43|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      __THREW__ = 0;
      invoke_vi(3838,($40|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_ArgumentException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ArgumentExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2559368);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147024809);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z95mscorlib_System_ArgumentOutOfRangeException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP43mscorlib_System_ArgumentOutOfRangeExceptionP22mscorlib_System_String($__this,$paramName) {
 $__this = $__this|0;
 $paramName = $paramName|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560768);
 __THREW__ = 0;
 invoke_v(698);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3060568>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viii(641,($__this|0),($3|0),($paramName|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233086);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z67mscorlib_System_Text_DecoderReplacementFallbackBuffer_m_GetNextCharP53mscorlib_System_Text_DecoderReplacementFallbackBuffer($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2524744);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($__this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($__this) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if (!($8)) {
  __THREW__ = 0;
  $9 = (invoke_ii(1816,($6|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = ($4|0)<($9|0);
   if (!($12)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $15 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = (($18) + 1)|0;
     HEAP32[$3>>2] = $21;
     __THREW__ = 0;
     invoke_vi(3799,($15|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      $24 = (invoke_iii(621,($15|0),($18|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       $$0 = $24;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Text_DecoderReplacementFallbackBuffer_m_ResetP53mscorlib_System_Text_DecoderReplacementFallbackBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2524792);
 $0 = (($__this) + 8|0);
 HEAP8[$0>>0] = 0;
 $1 = (($__this) + 12|0);
 HEAP32[$1>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_Text_EncoderExceptionFallback_m__ctorP45mscorlib_System_Text_EncoderExceptionFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525304);
 __THREW__ = 0;
 invoke_vi(2513,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44mscorlib_System_Text_EncoderFallback_m__ctorP36mscorlib_System_Text_EncoderFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2526272);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z68mscorlib_System_Text_EncoderExceptionFallback_m_CreateFallbackBufferP45mscorlib_System_Text_EncoderExceptionFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525352);
 __THREW__ = 0;
 (invoke_ii(2996,(2526136|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2526136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2512,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Text_EncoderExceptionFallbackBuffer_m__ctorP51mscorlib_System_Text_EncoderExceptionFallbackBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525728);
 __THREW__ = 0;
 invoke_vi(2515,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_Text_EncoderExceptionFallback_m_EqualsP45mscorlib_System_Text_EncoderExceptionFallbackP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525400);
 __THREW__ = 0;
 (invoke_ii(2996,(2525592|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2525592|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)!=(0|0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($5|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_Text_EncoderExceptionFallback_m_GetHashCodeP45mscorlib_System_Text_EncoderExceptionFallback($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525448);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z50mscorlib_System_Text_EncoderFallbackBuffer_m__ctorP42mscorlib_System_Text_EncoderFallbackBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2527032);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z67mscorlib_System_Text_EncoderExceptionFallbackBuffer_m_get_RemainingP51mscorlib_System_Text_EncoderExceptionFallbackBuffer($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525776);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z129mscorlib_System_Text_EncoderExceptionFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Char_mscorlib_System_Int32P51mscorlib_System_Text_EncoderExceptionFallbackBufferti($__this,$charUnknown,$index) {
 $__this = $__this|0;
 $charUnknown = $charUnknown|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525824);
 __THREW__ = 0;
 (invoke_ii(2996,(2528072|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2528072|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viii(631,($2|0),($charUnknown|0),($index|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Text_EncoderFallbackException_m__ctor_mscorlib_System_Void_mscorlib_System_Char_mscorlib_System_Int32P45mscorlib_System_Text_EncoderFallbackExceptionti($__this,$charUnknown,$index) {
 $__this = $__this|0;
 $charUnknown = $charUnknown|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2527568);
 $0 = (($__this) + 64|0);
 HEAP32[$0>>2] = -1;
 __THREW__ = 0;
 invoke_vii(1924,($__this|0),(0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = (($__this) + 56|0);
  HEAP16[$3>>1] = $charUnknown;
  HEAP32[$0>>2] = $index;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z150mscorlib_System_Text_EncoderExceptionFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Char_mscorlib_System_Char_mscorlib_System_Int32P51mscorlib_System_Text_EncoderExceptionFallbackBuffertti($__this,$charUnknownHigh,$charUnknownLow,$index) {
 $__this = $__this|0;
 $charUnknownHigh = $charUnknownHigh|0;
 $charUnknownLow = $charUnknownLow|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525872);
 __THREW__ = 0;
 (invoke_ii(2996,(2528072|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2528072|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viiii(172,($2|0),($charUnknownHigh|0),($charUnknownLow|0),($index|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z138mscorlib_System_Text_EncoderFallbackException_m__ctor_mscorlib_System_Void_mscorlib_System_Char_mscorlib_System_Char_mscorlib_System_Int32P45mscorlib_System_Text_EncoderFallbackExceptiontti($__this,$charUnknownHigh,$charUnknownLow,$index) {
 $__this = $__this|0;
 $charUnknownHigh = $charUnknownHigh|0;
 $charUnknownLow = $charUnknownLow|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2527616);
 $0 = (($__this) + 64|0);
 HEAP32[$0>>2] = -1;
 __THREW__ = 0;
 invoke_vii(1924,($__this|0),(0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = (($__this) + 58|0);
  HEAP16[$3>>1] = $charUnknownHigh;
  $4 = (($__this) + 60|0);
  HEAP16[$4>>1] = $charUnknownLow;
  HEAP32[$0>>2] = $index;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z65mscorlib_System_Text_EncoderExceptionFallbackBuffer_m_GetNextCharP51mscorlib_System_Text_EncoderExceptionFallbackBuffer($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2525920);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEPFbPvtiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 $6 = $5&1;
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEPFbPvttiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$4,$7)|0);
 $9 = $8&1;
 HEAP8[$ret>>0] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __Z45mscorlib_System_Text_EncoderFallback_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2526320);
 __THREW__ = 0;
 invoke_v(699);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2525592|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2525592|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(2511,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2526896|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = HEAP32[((2526896 + 80|0))>>2]|0;
      HEAP32[$11>>2] = $4;
      __THREW__ = 0;
      (invoke_ii(2996,(2528672|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       $14 = (invoke_ii(3469,(2528672|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __THREW__ = 0;
        invoke_vi(2516,($14|0));
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2526896|0))|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if (!($20)) {
          $21 = HEAP32[((2526896 + 80|0))>>2]|0;
          $22 = (($21) + 4|0);
          HEAP32[$22>>2] = $14;
          __THREW__ = 0;
          (invoke_ii(2996,(2528672|0))|0);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           $25 = (invoke_ii(3469,(2528672|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            $28 = HEAP32[3053872>>2]|0;
            __THREW__ = 0;
            invoke_vii(1907,($25|0),($28|0));
            $29 = __THREW__; __THREW__ = 0;
            $30 = $29&1;
            if (!($30)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2526896|0))|0);
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if (!($32)) {
              $33 = HEAP32[((2526896 + 80|0))>>2]|0;
              $34 = (($33) + 8|0);
              HEAP32[$34>>2] = $25;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($35|0);
 // unreachable;
}
function __Z76mscorlib_System_Text_EncoderReplacementFallback_m__ctor_mscorlib_System_VoidP47mscorlib_System_Text_EncoderReplacementFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528208);
 __THREW__ = 0;
 invoke_v(700);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3053888>>2]|0;
  __THREW__ = 0;
  invoke_vii(1907,($__this|0),($2|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z99mscorlib_System_Text_EncoderReplacementFallback_m__ctor_mscorlib_System_Void_mscorlib_System_StringP47mscorlib_System_Text_EncoderReplacementFallbackP22mscorlib_System_String($__this,$replacement) {
 $__this = $__this|0;
 $replacement = $replacement|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528256);
 __THREW__ = 0;
 invoke_vi(2513,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($replacement|0)==(0|0);
  if (!($2)) {
   $14 = (($__this) + 8|0);
   HEAP32[$14>>2] = $replacement;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(2585,($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3838,($7|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z60mscorlib_System_Text_EncoderFallback_m_get_ExceptionFallbackP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2526368);
 __THREW__ = 0;
 (invoke_ii(2996,(2526896|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2526896 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2526896|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2526896|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2526896|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2526896|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2526896 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZL11RuntimeInitP8TypeInfo8566($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_Text_EncoderFallback_m_get_ReplacementFallbackP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2526416);
 __THREW__ = 0;
 (invoke_ii(2996,(2526896|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2526896 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2526896|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2526896|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2526896|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2526896|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2526896 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_Text_EncoderFallback_m_get_StandardSafeFallbackP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2526464);
 __THREW__ = 0;
 (invoke_ii(2996,(2526896|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2526896 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2526896|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2526896|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2526896|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2526896|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2526896 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker3I26mscorlib_System_CharTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvttiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$4,$7);
 STACKTOP = sp;return (0|0);
}
function __Z67mscorlib_System_Text_EncoderReplacementFallback_m_get_DefaultStringP47mscorlib_System_Text_EncoderReplacementFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528304);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Text_EncoderReplacementFallback_m_CreateFallbackBufferP47mscorlib_System_Text_EncoderReplacementFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528352);
 __THREW__ = 0;
 (invoke_ii(2996,(2529400|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2529400|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1908,($2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Text_EncoderReplacementFallbackBuffer_m__ctorP53mscorlib_System_Text_EncoderReplacementFallbackBufferP47mscorlib_System_Text_EncoderReplacementFallback($__this,$fallback) {
 $__this = $__this|0;
 $fallback = $fallback|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528808);
 __THREW__ = 0;
 invoke_v(701);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(2515,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($fallback|0)==(0|0);
    if (!($4)) {
     __THREW__ = 0;
     invoke_vi(3799,($fallback|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_ii(2376,($fallback|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = (($__this) + 8|0);
     HEAP32[$22>>2] = $19;
     $23 = (($__this) + 12|0);
     HEAP32[$23>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2560584|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[3053904>>2]|0;
      __THREW__ = 0;
      invoke_vii(1925,($9|0),($12|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3838,($9|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z56mscorlib_System_Text_EncoderReplacementFallback_m_EqualsP47mscorlib_System_Text_EncoderReplacementFallbackP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528400);
 __THREW__ = 0;
 (invoke_ii(2996,(2528672|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2528672|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $G_B3_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
   $8 = (($__this) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($2) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_iiii(574,(0|0),($9|0),($13|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $G_B3_0$0 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_Text_EncoderReplacementFallback_m_GetHashCodeP47mscorlib_System_Text_EncoderReplacementFallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528448);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2729,(2185544|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z178mscorlib_System_Text_EncoderReplacementFallback_CustomAttributesCacheGenerator_mscorlib_System_Text_EncoderReplacementFallback_m__ctor_mscorlib_System_Void_mscorlib_System_StringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z69mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_get_RemainingP53mscorlib_System_Text_EncoderReplacementFallbackBuffer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528856);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_ii(1816,($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (($4) - ($8))|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($9|0);
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z131mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Char_mscorlib_System_Int32P53mscorlib_System_Text_EncoderReplacementFallbackBufferti($__this,$charUnknown,$index) {
 $__this = $__this|0;
 $charUnknown = $charUnknown|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528904);
 __THREW__ = 0;
 $0 = (invoke_iii(976,($__this|0),($index|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z110mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Int32P53mscorlib_System_Text_EncoderReplacementFallbackBufferi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529000);
 __THREW__ = 0;
 invoke_v(702);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 16|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if (!($4)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2729,(2528856|0),($__this|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = ($7|0)==(0);
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_ii(3469,(2560072|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = HEAP32[3053920>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($13|0),($16|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($13|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     // unreachable;
    }
   }
   $21 = ($index|0)>(-1);
   if ($21) {
    HEAP8[$2>>0] = 1;
    $32 = (($__this) + 12|0);
    HEAP32[$32>>2] = 0;
    $33 = (($__this) + 8|0);
    $34 = HEAP32[$33>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($34|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(1816,($34|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    $40 = ($37|0)>(0);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($40|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = HEAP32[3053928>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($24|0),($27|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      __THREW__ = 0;
      invoke_vi(3838,($24|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z152mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Char_mscorlib_System_Char_mscorlib_System_Int32P53mscorlib_System_Text_EncoderReplacementFallbackBuffertti($__this,$charUnknownHigh,$charUnknownLow,$index) {
 $__this = $__this|0;
 $charUnknownHigh = $charUnknownHigh|0;
 $charUnknownLow = $charUnknownLow|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2528952);
 __THREW__ = 0;
 $0 = (invoke_iii(976,($__this|0),($index|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z67mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_GetNextCharP53mscorlib_System_Text_EncoderReplacementFallbackBuffer($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529048);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1816,($3|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($1|0)<($6|0);
   if (!($9)) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $12 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $15 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = (($15) + 1)|0;
     HEAP32[$0>>2] = $18;
     __THREW__ = 0;
     invoke_vi(3799,($12|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      $21 = (invoke_iii(621,($12|0),($15|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       $$0 = $21;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Text_Encoding_m__ctorP29mscorlib_System_Text_Encodingi($__this,$codePage) {
 $__this = $__this|0;
 $codePage = $codePage|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529536);
 $0 = (($__this) + 16|0);
 HEAP8[$0>>0] = 1;
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = (($__this) + 12|0);
   HEAP32[$3>>2] = $codePage;
   $4 = (($__this) + 8|0);
   HEAP32[$4>>2] = $codePage;
   if ((($codePage|0) == 54936) | (($codePage|0) == 20127)) {
    __THREW__ = 0;
    $15 = (invoke_ii(2362,(0|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($__this) + 20|0);
    HEAP32[$18>>2] = $15;
    __THREW__ = 0;
    $19 = (invoke_ii(2374,0)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (($__this) + 24|0);
    HEAP32[$22>>2] = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else if ((($codePage|0) == 65001) | (($codePage|0) == 65000) | (($codePage|0) == 12001) | (($codePage|0) == 12000) | (($codePage|0) == 1201) | (($codePage|0) == 1200)) {
    __THREW__ = 0;
    $23 = (invoke_ii(2363,(0|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    $26 = (($__this) + 20|0);
    HEAP32[$26>>2] = $23;
    __THREW__ = 0;
    $27 = (invoke_ii(2375,0)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    $30 = (($__this) + 24|0);
    HEAP32[$30>>2] = $27;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else {
    __THREW__ = 0;
    $7 = (invoke_ii(2362,(0|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = (($__this) + 20|0);
    HEAP32[$10>>2] = $7;
    __THREW__ = 0;
    $11 = (invoke_ii(2374,0)|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = (($__this) + 24|0);
    HEAP32[$14>>2] = $11;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z38mscorlib_System_Text_Encoding_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$sum = 0, $$sum2021 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0;
 var $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0;
 var $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0;
 var $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0;
 var $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0;
 var $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0;
 var $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0;
 var $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0;
 var $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0;
 var $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0;
 var $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0;
 var $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0;
 var $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0;
 var $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0;
 var $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0;
 var $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0;
 var $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0;
 var $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0;
 var $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0;
 var $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0;
 var $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0;
 var $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0;
 var $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0;
 var $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0;
 var $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_111 = 0, $L_123 = 0;
 var $L_138 = 0, $L_147 = 0, $L_45 = 0, $L_6 = 0, $L_69 = 0, $L_90 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_6 = sp + 28|0;
 $L_45 = sp + 24|0;
 $L_69 = sp + 20|0;
 $L_90 = sp + 16|0;
 $L_111 = sp + 8|0;
 $L_123 = sp + 4|0;
 $L_138 = sp;
 $L_147 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529584);
 __THREW__ = 0;
 invoke_v(703);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2768,(1167664|0),43)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     HEAP32[$L_6>>2] = 20127;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_iii(2724,(2155952|0),($L_6|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        $14 = (($4) + 12|0);
        $15 = HEAP32[$14>>2]|0;
        $16 = ($15|0)==(0);
        if ($16) {
         __THREW__ = 0;
         $17 = (invoke_i(132)|0);
         $18 = __THREW__; __THREW__ = 0;
         $19 = $18&1;
         if ($19) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($17|0));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($9|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         $26 = (($4) + 16|0);
         HEAP32[$26>>2] = $9;
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = HEAP32[$14>>2]|0;
          $30 = ($29>>>0)<(2);
          if ($30) {
           __THREW__ = 0;
           $31 = (invoke_i(132)|0);
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if ($33) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($31|0));
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if ($35) {
            break;
           }
          }
          $36 = HEAP32[3053944>>2]|0;
          __THREW__ = 0;
          invoke_vii(3492,($4|0),($36|0));
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if (!($38)) {
           $39 = HEAP32[3053944>>2]|0;
           $40 = HEAP32[$4>>2]|0;
           $41 = (($40) + 92|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = (($26) + ($42)|0);
           HEAP32[$43>>2] = $39;
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if (!($45)) {
            $46 = HEAP32[$14>>2]|0;
            $47 = ($46>>>0)<(3);
            if ($47) {
             __THREW__ = 0;
             $48 = (invoke_i(132)|0);
             $49 = __THREW__; __THREW__ = 0;
             $50 = $49&1;
             if ($50) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($48|0));
             $51 = __THREW__; __THREW__ = 0;
             $52 = $51&1;
             if ($52) {
              break;
             }
            }
            $53 = HEAP32[3053952>>2]|0;
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($53|0));
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if (!($55)) {
             $56 = HEAP32[3053952>>2]|0;
             $57 = HEAP32[$4>>2]|0;
             $58 = (($57) + 92|0);
             $59 = HEAP32[$58>>2]|0;
             $60 = $59 << 1;
             $61 = (($26) + ($60)|0);
             HEAP32[$61>>2] = $56;
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $62 = __THREW__; __THREW__ = 0;
             $63 = $62&1;
             if (!($63)) {
              $64 = HEAP32[$14>>2]|0;
              $65 = ($64>>>0)<(4);
              if ($65) {
               __THREW__ = 0;
               $66 = (invoke_i(132)|0);
               $67 = __THREW__; __THREW__ = 0;
               $68 = $67&1;
               if ($68) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($66|0));
               $69 = __THREW__; __THREW__ = 0;
               $70 = $69&1;
               if ($70) {
                break;
               }
              }
              $71 = HEAP32[3053960>>2]|0;
              __THREW__ = 0;
              invoke_vii(3492,($4|0),($71|0));
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if (!($73)) {
               $74 = HEAP32[3053960>>2]|0;
               $75 = HEAP32[$4>>2]|0;
               $76 = (($75) + 92|0);
               $77 = HEAP32[$76>>2]|0;
               $78 = ($77*3)|0;
               $79 = (($26) + ($78)|0);
               HEAP32[$79>>2] = $74;
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $80 = __THREW__; __THREW__ = 0;
               $81 = $80&1;
               if (!($81)) {
                $82 = HEAP32[$14>>2]|0;
                $83 = ($82>>>0)<(5);
                if ($83) {
                 __THREW__ = 0;
                 $84 = (invoke_i(132)|0);
                 $85 = __THREW__; __THREW__ = 0;
                 $86 = $85&1;
                 if ($86) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($84|0));
                 $87 = __THREW__; __THREW__ = 0;
                 $88 = $87&1;
                 if ($88) {
                  break;
                 }
                }
                $89 = HEAP32[3053968>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($89|0));
                $90 = __THREW__; __THREW__ = 0;
                $91 = $90&1;
                if ($91) {
                 break;
                }
                $92 = HEAP32[3053968>>2]|0;
                $93 = HEAP32[$4>>2]|0;
                $94 = (($93) + 92|0);
                $95 = HEAP32[$94>>2]|0;
                $96 = $95 << 2;
                $97 = (($26) + ($96)|0);
                HEAP32[$97>>2] = $92;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 break;
                }
                $100 = HEAP32[$14>>2]|0;
                $101 = ($100>>>0)<(6);
                if ($101) {
                 __THREW__ = 0;
                 $102 = (invoke_i(132)|0);
                 $103 = __THREW__; __THREW__ = 0;
                 $104 = $103&1;
                 if ($104) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($102|0));
                 $105 = __THREW__; __THREW__ = 0;
                 $106 = $105&1;
                 if ($106) {
                  break;
                 }
                }
                $107 = HEAP32[3053976>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($107|0));
                $108 = __THREW__; __THREW__ = 0;
                $109 = $108&1;
                if ($109) {
                 break;
                }
                $110 = HEAP32[3053976>>2]|0;
                $111 = HEAP32[$4>>2]|0;
                $112 = (($111) + 92|0);
                $113 = HEAP32[$112>>2]|0;
                $114 = ($113*5)|0;
                $115 = (($26) + ($114)|0);
                HEAP32[$115>>2] = $110;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $116 = __THREW__; __THREW__ = 0;
                $117 = $116&1;
                if ($117) {
                 break;
                }
                $118 = HEAP32[$14>>2]|0;
                $119 = ($118>>>0)<(7);
                if ($119) {
                 __THREW__ = 0;
                 $120 = (invoke_i(132)|0);
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($120|0));
                 $123 = __THREW__; __THREW__ = 0;
                 $124 = $123&1;
                 if ($124) {
                  break;
                 }
                }
                $125 = HEAP32[3053984>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($125|0));
                $126 = __THREW__; __THREW__ = 0;
                $127 = $126&1;
                if ($127) {
                 break;
                }
                $128 = HEAP32[3053984>>2]|0;
                $129 = HEAP32[$4>>2]|0;
                $130 = (($129) + 92|0);
                $131 = HEAP32[$130>>2]|0;
                $132 = ($131*6)|0;
                $133 = (($26) + ($132)|0);
                HEAP32[$133>>2] = $128;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $134 = __THREW__; __THREW__ = 0;
                $135 = $134&1;
                if ($135) {
                 break;
                }
                $136 = HEAP32[$14>>2]|0;
                $137 = ($136>>>0)<(8);
                if ($137) {
                 __THREW__ = 0;
                 $138 = (invoke_i(132)|0);
                 $139 = __THREW__; __THREW__ = 0;
                 $140 = $139&1;
                 if ($140) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($138|0));
                 $141 = __THREW__; __THREW__ = 0;
                 $142 = $141&1;
                 if ($142) {
                  break;
                 }
                }
                $143 = HEAP32[3053992>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($143|0));
                $144 = __THREW__; __THREW__ = 0;
                $145 = $144&1;
                if ($145) {
                 break;
                }
                $146 = HEAP32[3053992>>2]|0;
                $147 = HEAP32[$4>>2]|0;
                $148 = (($147) + 92|0);
                $149 = HEAP32[$148>>2]|0;
                $150 = ($149*7)|0;
                $151 = (($26) + ($150)|0);
                HEAP32[$151>>2] = $146;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $152 = __THREW__; __THREW__ = 0;
                $153 = $152&1;
                if ($153) {
                 break;
                }
                $154 = HEAP32[$14>>2]|0;
                $155 = ($154>>>0)<(9);
                if ($155) {
                 __THREW__ = 0;
                 $156 = (invoke_i(132)|0);
                 $157 = __THREW__; __THREW__ = 0;
                 $158 = $157&1;
                 if ($158) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($156|0));
                 $159 = __THREW__; __THREW__ = 0;
                 $160 = $159&1;
                 if ($160) {
                  break;
                 }
                }
                $161 = HEAP32[3054000>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($161|0));
                $162 = __THREW__; __THREW__ = 0;
                $163 = $162&1;
                if ($163) {
                 break;
                }
                $164 = HEAP32[3054000>>2]|0;
                $165 = HEAP32[$4>>2]|0;
                $166 = (($165) + 92|0);
                $167 = HEAP32[$166>>2]|0;
                $168 = $167 << 3;
                $169 = (($26) + ($168)|0);
                HEAP32[$169>>2] = $164;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $170 = __THREW__; __THREW__ = 0;
                $171 = $170&1;
                if ($171) {
                 break;
                }
                $172 = HEAP32[$14>>2]|0;
                $173 = ($172>>>0)<(10);
                if ($173) {
                 __THREW__ = 0;
                 $174 = (invoke_i(132)|0);
                 $175 = __THREW__; __THREW__ = 0;
                 $176 = $175&1;
                 if ($176) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($174|0));
                 $177 = __THREW__; __THREW__ = 0;
                 $178 = $177&1;
                 if ($178) {
                  break;
                 }
                }
                $179 = HEAP32[3054008>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($179|0));
                $180 = __THREW__; __THREW__ = 0;
                $181 = $180&1;
                if ($181) {
                 break;
                }
                $182 = HEAP32[3054008>>2]|0;
                $183 = HEAP32[$4>>2]|0;
                $184 = (($183) + 92|0);
                $185 = HEAP32[$184>>2]|0;
                $186 = ($185*9)|0;
                $187 = (($26) + ($186)|0);
                HEAP32[$187>>2] = $182;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $188 = __THREW__; __THREW__ = 0;
                $189 = $188&1;
                if ($189) {
                 break;
                }
                $190 = HEAP32[$14>>2]|0;
                $191 = ($190>>>0)<(11);
                if ($191) {
                 __THREW__ = 0;
                 $192 = (invoke_i(132)|0);
                 $193 = __THREW__; __THREW__ = 0;
                 $194 = $193&1;
                 if ($194) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($192|0));
                 $195 = __THREW__; __THREW__ = 0;
                 $196 = $195&1;
                 if ($196) {
                  break;
                 }
                }
                $197 = HEAP32[3054016>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($197|0));
                $198 = __THREW__; __THREW__ = 0;
                $199 = $198&1;
                if ($199) {
                 break;
                }
                $200 = HEAP32[3054016>>2]|0;
                $201 = HEAP32[$4>>2]|0;
                $202 = (($201) + 92|0);
                $203 = HEAP32[$202>>2]|0;
                $204 = ($203*10)|0;
                $205 = (($26) + ($204)|0);
                HEAP32[$205>>2] = $200;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $206 = __THREW__; __THREW__ = 0;
                $207 = $206&1;
                if ($207) {
                 break;
                }
                $208 = HEAP32[$14>>2]|0;
                $209 = ($208>>>0)<(12);
                if ($209) {
                 __THREW__ = 0;
                 $210 = (invoke_i(132)|0);
                 $211 = __THREW__; __THREW__ = 0;
                 $212 = $211&1;
                 if ($212) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($210|0));
                 $213 = __THREW__; __THREW__ = 0;
                 $214 = $213&1;
                 if ($214) {
                  break;
                 }
                }
                $215 = HEAP32[3054024>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($215|0));
                $216 = __THREW__; __THREW__ = 0;
                $217 = $216&1;
                if ($217) {
                 break;
                }
                $218 = HEAP32[3054024>>2]|0;
                $219 = HEAP32[$4>>2]|0;
                $220 = (($219) + 92|0);
                $221 = HEAP32[$220>>2]|0;
                $222 = ($221*11)|0;
                $223 = (($26) + ($222)|0);
                HEAP32[$223>>2] = $218;
                HEAP32[$L_45>>2] = 65000;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $224 = __THREW__; __THREW__ = 0;
                $225 = $224&1;
                if ($225) {
                 break;
                }
                __THREW__ = 0;
                $226 = (invoke_iii(2724,(2155952|0),($L_45|0))|0);
                $227 = __THREW__; __THREW__ = 0;
                $228 = $227&1;
                if ($228) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $229 = __THREW__; __THREW__ = 0;
                $230 = $229&1;
                if ($230) {
                 break;
                }
                $231 = HEAP32[$14>>2]|0;
                $232 = ($231>>>0)<(13);
                if ($232) {
                 __THREW__ = 0;
                 $233 = (invoke_i(132)|0);
                 $234 = __THREW__; __THREW__ = 0;
                 $235 = $234&1;
                 if ($235) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($233|0));
                 $236 = __THREW__; __THREW__ = 0;
                 $237 = $236&1;
                 if ($237) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($226|0));
                $238 = __THREW__; __THREW__ = 0;
                $239 = $238&1;
                if ($239) {
                 break;
                }
                $240 = HEAP32[$4>>2]|0;
                $241 = (($240) + 92|0);
                $242 = HEAP32[$241>>2]|0;
                $243 = ($242*12)|0;
                $244 = (($26) + ($243)|0);
                HEAP32[$244>>2] = $226;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $245 = __THREW__; __THREW__ = 0;
                $246 = $245&1;
                if ($246) {
                 break;
                }
                $247 = HEAP32[$14>>2]|0;
                $248 = ($247>>>0)<(14);
                if ($248) {
                 __THREW__ = 0;
                 $249 = (invoke_i(132)|0);
                 $250 = __THREW__; __THREW__ = 0;
                 $251 = $250&1;
                 if ($251) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($249|0));
                 $252 = __THREW__; __THREW__ = 0;
                 $253 = $252&1;
                 if ($253) {
                  break;
                 }
                }
                $254 = HEAP32[3054032>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($254|0));
                $255 = __THREW__; __THREW__ = 0;
                $256 = $255&1;
                if ($256) {
                 break;
                }
                $257 = HEAP32[3054032>>2]|0;
                $258 = HEAP32[$4>>2]|0;
                $259 = (($258) + 92|0);
                $260 = HEAP32[$259>>2]|0;
                $261 = ($260*13)|0;
                $262 = (($26) + ($261)|0);
                HEAP32[$262>>2] = $257;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $263 = __THREW__; __THREW__ = 0;
                $264 = $263&1;
                if ($264) {
                 break;
                }
                $265 = HEAP32[$14>>2]|0;
                $266 = ($265>>>0)<(15);
                if ($266) {
                 __THREW__ = 0;
                 $267 = (invoke_i(132)|0);
                 $268 = __THREW__; __THREW__ = 0;
                 $269 = $268&1;
                 if ($269) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($267|0));
                 $270 = __THREW__; __THREW__ = 0;
                 $271 = $270&1;
                 if ($271) {
                  break;
                 }
                }
                $272 = HEAP32[3054040>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($272|0));
                $273 = __THREW__; __THREW__ = 0;
                $274 = $273&1;
                if ($274) {
                 break;
                }
                $275 = HEAP32[3054040>>2]|0;
                $276 = HEAP32[$4>>2]|0;
                $277 = (($276) + 92|0);
                $278 = HEAP32[$277>>2]|0;
                $279 = ($278*14)|0;
                $280 = (($26) + ($279)|0);
                HEAP32[$280>>2] = $275;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $281 = __THREW__; __THREW__ = 0;
                $282 = $281&1;
                if ($282) {
                 break;
                }
                $283 = HEAP32[$14>>2]|0;
                $284 = ($283>>>0)<(16);
                if ($284) {
                 __THREW__ = 0;
                 $285 = (invoke_i(132)|0);
                 $286 = __THREW__; __THREW__ = 0;
                 $287 = $286&1;
                 if ($287) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($285|0));
                 $288 = __THREW__; __THREW__ = 0;
                 $289 = $288&1;
                 if ($289) {
                  break;
                 }
                }
                $290 = HEAP32[3054048>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($290|0));
                $291 = __THREW__; __THREW__ = 0;
                $292 = $291&1;
                if ($292) {
                 break;
                }
                $293 = HEAP32[3054048>>2]|0;
                $294 = HEAP32[$4>>2]|0;
                $295 = (($294) + 92|0);
                $296 = HEAP32[$295>>2]|0;
                $297 = ($296*15)|0;
                $298 = (($26) + ($297)|0);
                HEAP32[$298>>2] = $293;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $299 = __THREW__; __THREW__ = 0;
                $300 = $299&1;
                if ($300) {
                 break;
                }
                $301 = HEAP32[$14>>2]|0;
                $302 = ($301>>>0)<(17);
                if ($302) {
                 __THREW__ = 0;
                 $303 = (invoke_i(132)|0);
                 $304 = __THREW__; __THREW__ = 0;
                 $305 = $304&1;
                 if ($305) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($303|0));
                 $306 = __THREW__; __THREW__ = 0;
                 $307 = $306&1;
                 if ($307) {
                  break;
                 }
                }
                $308 = HEAP32[3054056>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($308|0));
                $309 = __THREW__; __THREW__ = 0;
                $310 = $309&1;
                if ($310) {
                 break;
                }
                $311 = HEAP32[3054056>>2]|0;
                $312 = HEAP32[$4>>2]|0;
                $313 = (($312) + 92|0);
                $314 = HEAP32[$313>>2]|0;
                $$sum = (($314) + 1)|0;
                $315 = (($4) + ($$sum<<4)|0);
                HEAP32[$315>>2] = $311;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $316 = __THREW__; __THREW__ = 0;
                $317 = $316&1;
                if ($317) {
                 break;
                }
                $318 = HEAP32[$14>>2]|0;
                $319 = ($318>>>0)<(18);
                if ($319) {
                 __THREW__ = 0;
                 $320 = (invoke_i(132)|0);
                 $321 = __THREW__; __THREW__ = 0;
                 $322 = $321&1;
                 if ($322) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($320|0));
                 $323 = __THREW__; __THREW__ = 0;
                 $324 = $323&1;
                 if ($324) {
                  break;
                 }
                }
                $325 = HEAP32[3054064>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($325|0));
                $326 = __THREW__; __THREW__ = 0;
                $327 = $326&1;
                if ($327) {
                 break;
                }
                $328 = HEAP32[3054064>>2]|0;
                $329 = HEAP32[$4>>2]|0;
                $330 = (($329) + 92|0);
                $331 = HEAP32[$330>>2]|0;
                $332 = ($331*17)|0;
                $333 = (($26) + ($332)|0);
                HEAP32[$333>>2] = $328;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $334 = __THREW__; __THREW__ = 0;
                $335 = $334&1;
                if ($335) {
                 break;
                }
                $336 = HEAP32[$14>>2]|0;
                $337 = ($336>>>0)<(19);
                if ($337) {
                 __THREW__ = 0;
                 $338 = (invoke_i(132)|0);
                 $339 = __THREW__; __THREW__ = 0;
                 $340 = $339&1;
                 if ($340) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($338|0));
                 $341 = __THREW__; __THREW__ = 0;
                 $342 = $341&1;
                 if ($342) {
                  break;
                 }
                }
                $343 = HEAP32[3054072>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($343|0));
                $344 = __THREW__; __THREW__ = 0;
                $345 = $344&1;
                if ($345) {
                 break;
                }
                $346 = HEAP32[3054072>>2]|0;
                $347 = HEAP32[$4>>2]|0;
                $348 = (($347) + 92|0);
                $349 = HEAP32[$348>>2]|0;
                $350 = ($349*18)|0;
                $351 = (($26) + ($350)|0);
                HEAP32[$351>>2] = $346;
                HEAP32[$L_69>>2] = 65001;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $352 = __THREW__; __THREW__ = 0;
                $353 = $352&1;
                if ($353) {
                 break;
                }
                __THREW__ = 0;
                $354 = (invoke_iii(2724,(2155952|0),($L_69|0))|0);
                $355 = __THREW__; __THREW__ = 0;
                $356 = $355&1;
                if ($356) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $357 = __THREW__; __THREW__ = 0;
                $358 = $357&1;
                if ($358) {
                 break;
                }
                $359 = HEAP32[$14>>2]|0;
                $360 = ($359>>>0)<(20);
                if ($360) {
                 __THREW__ = 0;
                 $361 = (invoke_i(132)|0);
                 $362 = __THREW__; __THREW__ = 0;
                 $363 = $362&1;
                 if ($363) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($361|0));
                 $364 = __THREW__; __THREW__ = 0;
                 $365 = $364&1;
                 if ($365) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($354|0));
                $366 = __THREW__; __THREW__ = 0;
                $367 = $366&1;
                if ($367) {
                 break;
                }
                $368 = HEAP32[$4>>2]|0;
                $369 = (($368) + 92|0);
                $370 = HEAP32[$369>>2]|0;
                $371 = ($370*19)|0;
                $372 = (($26) + ($371)|0);
                HEAP32[$372>>2] = $354;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $373 = __THREW__; __THREW__ = 0;
                $374 = $373&1;
                if ($374) {
                 break;
                }
                $375 = HEAP32[$14>>2]|0;
                $376 = ($375>>>0)<(21);
                if ($376) {
                 __THREW__ = 0;
                 $377 = (invoke_i(132)|0);
                 $378 = __THREW__; __THREW__ = 0;
                 $379 = $378&1;
                 if ($379) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($377|0));
                 $380 = __THREW__; __THREW__ = 0;
                 $381 = $380&1;
                 if ($381) {
                  break;
                 }
                }
                $382 = HEAP32[3054080>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($382|0));
                $383 = __THREW__; __THREW__ = 0;
                $384 = $383&1;
                if ($384) {
                 break;
                }
                $385 = HEAP32[3054080>>2]|0;
                $386 = HEAP32[$4>>2]|0;
                $387 = (($386) + 92|0);
                $388 = HEAP32[$387>>2]|0;
                $389 = ($388*20)|0;
                $390 = (($26) + ($389)|0);
                HEAP32[$390>>2] = $385;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $391 = __THREW__; __THREW__ = 0;
                $392 = $391&1;
                if ($392) {
                 break;
                }
                $393 = HEAP32[$14>>2]|0;
                $394 = ($393>>>0)<(22);
                if ($394) {
                 __THREW__ = 0;
                 $395 = (invoke_i(132)|0);
                 $396 = __THREW__; __THREW__ = 0;
                 $397 = $396&1;
                 if ($397) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($395|0));
                 $398 = __THREW__; __THREW__ = 0;
                 $399 = $398&1;
                 if ($399) {
                  break;
                 }
                }
                $400 = HEAP32[3054088>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($400|0));
                $401 = __THREW__; __THREW__ = 0;
                $402 = $401&1;
                if ($402) {
                 break;
                }
                $403 = HEAP32[3054088>>2]|0;
                $404 = HEAP32[$4>>2]|0;
                $405 = (($404) + 92|0);
                $406 = HEAP32[$405>>2]|0;
                $407 = ($406*21)|0;
                $408 = (($26) + ($407)|0);
                HEAP32[$408>>2] = $403;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $409 = __THREW__; __THREW__ = 0;
                $410 = $409&1;
                if ($410) {
                 break;
                }
                $411 = HEAP32[$14>>2]|0;
                $412 = ($411>>>0)<(23);
                if ($412) {
                 __THREW__ = 0;
                 $413 = (invoke_i(132)|0);
                 $414 = __THREW__; __THREW__ = 0;
                 $415 = $414&1;
                 if ($415) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($413|0));
                 $416 = __THREW__; __THREW__ = 0;
                 $417 = $416&1;
                 if ($417) {
                  break;
                 }
                }
                $418 = HEAP32[3054096>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($418|0));
                $419 = __THREW__; __THREW__ = 0;
                $420 = $419&1;
                if ($420) {
                 break;
                }
                $421 = HEAP32[3054096>>2]|0;
                $422 = HEAP32[$4>>2]|0;
                $423 = (($422) + 92|0);
                $424 = HEAP32[$423>>2]|0;
                $425 = ($424*22)|0;
                $426 = (($26) + ($425)|0);
                HEAP32[$426>>2] = $421;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $427 = __THREW__; __THREW__ = 0;
                $428 = $427&1;
                if ($428) {
                 break;
                }
                $429 = HEAP32[$14>>2]|0;
                $430 = ($429>>>0)<(24);
                if ($430) {
                 __THREW__ = 0;
                 $431 = (invoke_i(132)|0);
                 $432 = __THREW__; __THREW__ = 0;
                 $433 = $432&1;
                 if ($433) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($431|0));
                 $434 = __THREW__; __THREW__ = 0;
                 $435 = $434&1;
                 if ($435) {
                  break;
                 }
                }
                $436 = HEAP32[3054104>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($436|0));
                $437 = __THREW__; __THREW__ = 0;
                $438 = $437&1;
                if ($438) {
                 break;
                }
                $439 = HEAP32[3054104>>2]|0;
                $440 = HEAP32[$4>>2]|0;
                $441 = (($440) + 92|0);
                $442 = HEAP32[$441>>2]|0;
                $443 = ($442*23)|0;
                $444 = (($26) + ($443)|0);
                HEAP32[$444>>2] = $439;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $445 = __THREW__; __THREW__ = 0;
                $446 = $445&1;
                if ($446) {
                 break;
                }
                $447 = HEAP32[$14>>2]|0;
                $448 = ($447>>>0)<(25);
                if ($448) {
                 __THREW__ = 0;
                 $449 = (invoke_i(132)|0);
                 $450 = __THREW__; __THREW__ = 0;
                 $451 = $450&1;
                 if ($451) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($449|0));
                 $452 = __THREW__; __THREW__ = 0;
                 $453 = $452&1;
                 if ($453) {
                  break;
                 }
                }
                $454 = HEAP32[3054112>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($454|0));
                $455 = __THREW__; __THREW__ = 0;
                $456 = $455&1;
                if ($456) {
                 break;
                }
                $457 = HEAP32[3054112>>2]|0;
                $458 = HEAP32[$4>>2]|0;
                $459 = (($458) + 92|0);
                $460 = HEAP32[$459>>2]|0;
                $461 = ($460*24)|0;
                $462 = (($26) + ($461)|0);
                HEAP32[$462>>2] = $457;
                HEAP32[$L_90>>2] = 1200;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $463 = __THREW__; __THREW__ = 0;
                $464 = $463&1;
                if ($464) {
                 break;
                }
                __THREW__ = 0;
                $465 = (invoke_iii(2724,(2155952|0),($L_90|0))|0);
                $466 = __THREW__; __THREW__ = 0;
                $467 = $466&1;
                if ($467) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $468 = __THREW__; __THREW__ = 0;
                $469 = $468&1;
                if ($469) {
                 break;
                }
                $470 = HEAP32[$14>>2]|0;
                $471 = ($470>>>0)<(26);
                if ($471) {
                 __THREW__ = 0;
                 $472 = (invoke_i(132)|0);
                 $473 = __THREW__; __THREW__ = 0;
                 $474 = $473&1;
                 if ($474) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($472|0));
                 $475 = __THREW__; __THREW__ = 0;
                 $476 = $475&1;
                 if ($476) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($465|0));
                $477 = __THREW__; __THREW__ = 0;
                $478 = $477&1;
                if ($478) {
                 break;
                }
                $479 = HEAP32[$4>>2]|0;
                $480 = (($479) + 92|0);
                $481 = HEAP32[$480>>2]|0;
                $482 = ($481*25)|0;
                $483 = (($26) + ($482)|0);
                HEAP32[$483>>2] = $465;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $484 = __THREW__; __THREW__ = 0;
                $485 = $484&1;
                if ($485) {
                 break;
                }
                $486 = HEAP32[$14>>2]|0;
                $487 = ($486>>>0)<(27);
                if ($487) {
                 __THREW__ = 0;
                 $488 = (invoke_i(132)|0);
                 $489 = __THREW__; __THREW__ = 0;
                 $490 = $489&1;
                 if ($490) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($488|0));
                 $491 = __THREW__; __THREW__ = 0;
                 $492 = $491&1;
                 if ($492) {
                  break;
                 }
                }
                $493 = HEAP32[3054120>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($493|0));
                $494 = __THREW__; __THREW__ = 0;
                $495 = $494&1;
                if ($495) {
                 break;
                }
                $496 = HEAP32[3054120>>2]|0;
                $497 = HEAP32[$4>>2]|0;
                $498 = (($497) + 92|0);
                $499 = HEAP32[$498>>2]|0;
                $500 = ($499*26)|0;
                $501 = (($26) + ($500)|0);
                HEAP32[$501>>2] = $496;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $502 = __THREW__; __THREW__ = 0;
                $503 = $502&1;
                if ($503) {
                 break;
                }
                $504 = HEAP32[$14>>2]|0;
                $505 = ($504>>>0)<(28);
                if ($505) {
                 __THREW__ = 0;
                 $506 = (invoke_i(132)|0);
                 $507 = __THREW__; __THREW__ = 0;
                 $508 = $507&1;
                 if ($508) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($506|0));
                 $509 = __THREW__; __THREW__ = 0;
                 $510 = $509&1;
                 if ($510) {
                  break;
                 }
                }
                $511 = HEAP32[3054128>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($511|0));
                $512 = __THREW__; __THREW__ = 0;
                $513 = $512&1;
                if ($513) {
                 break;
                }
                $514 = HEAP32[3054128>>2]|0;
                $515 = HEAP32[$4>>2]|0;
                $516 = (($515) + 92|0);
                $517 = HEAP32[$516>>2]|0;
                $518 = ($517*27)|0;
                $519 = (($26) + ($518)|0);
                HEAP32[$519>>2] = $514;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $520 = __THREW__; __THREW__ = 0;
                $521 = $520&1;
                if ($521) {
                 break;
                }
                $522 = HEAP32[$14>>2]|0;
                $523 = ($522>>>0)<(29);
                if ($523) {
                 __THREW__ = 0;
                 $524 = (invoke_i(132)|0);
                 $525 = __THREW__; __THREW__ = 0;
                 $526 = $525&1;
                 if ($526) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($524|0));
                 $527 = __THREW__; __THREW__ = 0;
                 $528 = $527&1;
                 if ($528) {
                  break;
                 }
                }
                $529 = HEAP32[3054136>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($529|0));
                $530 = __THREW__; __THREW__ = 0;
                $531 = $530&1;
                if ($531) {
                 break;
                }
                $532 = HEAP32[3054136>>2]|0;
                $533 = HEAP32[$4>>2]|0;
                $534 = (($533) + 92|0);
                $535 = HEAP32[$534>>2]|0;
                $536 = ($535*28)|0;
                $537 = (($26) + ($536)|0);
                HEAP32[$537>>2] = $532;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $538 = __THREW__; __THREW__ = 0;
                $539 = $538&1;
                if ($539) {
                 break;
                }
                $540 = HEAP32[$14>>2]|0;
                $541 = ($540>>>0)<(30);
                if ($541) {
                 __THREW__ = 0;
                 $542 = (invoke_i(132)|0);
                 $543 = __THREW__; __THREW__ = 0;
                 $544 = $543&1;
                 if ($544) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($542|0));
                 $545 = __THREW__; __THREW__ = 0;
                 $546 = $545&1;
                 if ($546) {
                  break;
                 }
                }
                $547 = HEAP32[3054144>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($547|0));
                $548 = __THREW__; __THREW__ = 0;
                $549 = $548&1;
                if ($549) {
                 break;
                }
                $550 = HEAP32[3054144>>2]|0;
                $551 = HEAP32[$4>>2]|0;
                $552 = (($551) + 92|0);
                $553 = HEAP32[$552>>2]|0;
                $554 = ($553*29)|0;
                $555 = (($26) + ($554)|0);
                HEAP32[$555>>2] = $550;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $556 = __THREW__; __THREW__ = 0;
                $557 = $556&1;
                if ($557) {
                 break;
                }
                $558 = HEAP32[$14>>2]|0;
                $559 = ($558>>>0)<(31);
                if ($559) {
                 __THREW__ = 0;
                 $560 = (invoke_i(132)|0);
                 $561 = __THREW__; __THREW__ = 0;
                 $562 = $561&1;
                 if ($562) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($560|0));
                 $563 = __THREW__; __THREW__ = 0;
                 $564 = $563&1;
                 if ($564) {
                  break;
                 }
                }
                $565 = HEAP32[3054152>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($565|0));
                $566 = __THREW__; __THREW__ = 0;
                $567 = $566&1;
                if ($567) {
                 break;
                }
                $568 = HEAP32[3054152>>2]|0;
                $569 = HEAP32[$4>>2]|0;
                $570 = (($569) + 92|0);
                $571 = HEAP32[$570>>2]|0;
                $572 = ($571*30)|0;
                $573 = (($26) + ($572)|0);
                HEAP32[$573>>2] = $568;
                HEAP32[$L_111>>2] = 1201;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $574 = __THREW__; __THREW__ = 0;
                $575 = $574&1;
                if ($575) {
                 break;
                }
                __THREW__ = 0;
                $576 = (invoke_iii(2724,(2155952|0),($L_111|0))|0);
                $577 = __THREW__; __THREW__ = 0;
                $578 = $577&1;
                if ($578) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $579 = __THREW__; __THREW__ = 0;
                $580 = $579&1;
                if ($580) {
                 break;
                }
                $581 = HEAP32[$14>>2]|0;
                $582 = ($581>>>0)<(32);
                if ($582) {
                 __THREW__ = 0;
                 $583 = (invoke_i(132)|0);
                 $584 = __THREW__; __THREW__ = 0;
                 $585 = $584&1;
                 if ($585) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($583|0));
                 $586 = __THREW__; __THREW__ = 0;
                 $587 = $586&1;
                 if ($587) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($576|0));
                $588 = __THREW__; __THREW__ = 0;
                $589 = $588&1;
                if ($589) {
                 break;
                }
                $590 = HEAP32[$4>>2]|0;
                $591 = (($590) + 92|0);
                $592 = HEAP32[$591>>2]|0;
                $593 = ($592*31)|0;
                $594 = (($26) + ($593)|0);
                HEAP32[$594>>2] = $576;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $595 = __THREW__; __THREW__ = 0;
                $596 = $595&1;
                if ($596) {
                 break;
                }
                $597 = HEAP32[$14>>2]|0;
                $598 = ($597>>>0)<(33);
                if ($598) {
                 __THREW__ = 0;
                 $599 = (invoke_i(132)|0);
                 $600 = __THREW__; __THREW__ = 0;
                 $601 = $600&1;
                 if ($601) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($599|0));
                 $602 = __THREW__; __THREW__ = 0;
                 $603 = $602&1;
                 if ($603) {
                  break;
                 }
                }
                $604 = HEAP32[3054160>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($604|0));
                $605 = __THREW__; __THREW__ = 0;
                $606 = $605&1;
                if ($606) {
                 break;
                }
                $607 = HEAP32[3054160>>2]|0;
                $608 = HEAP32[$4>>2]|0;
                $609 = (($608) + 92|0);
                $610 = HEAP32[$609>>2]|0;
                $611 = $610 << 1;
                $$sum2021 = $611 | 1;
                $612 = (($4) + ($$sum2021<<4)|0);
                HEAP32[$612>>2] = $607;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $613 = __THREW__; __THREW__ = 0;
                $614 = $613&1;
                if ($614) {
                 break;
                }
                $615 = HEAP32[$14>>2]|0;
                $616 = ($615>>>0)<(34);
                if ($616) {
                 __THREW__ = 0;
                 $617 = (invoke_i(132)|0);
                 $618 = __THREW__; __THREW__ = 0;
                 $619 = $618&1;
                 if ($619) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($617|0));
                 $620 = __THREW__; __THREW__ = 0;
                 $621 = $620&1;
                 if ($621) {
                  break;
                 }
                }
                $622 = HEAP32[3054168>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($622|0));
                $623 = __THREW__; __THREW__ = 0;
                $624 = $623&1;
                if ($624) {
                 break;
                }
                $625 = HEAP32[3054168>>2]|0;
                $626 = HEAP32[$4>>2]|0;
                $627 = (($626) + 92|0);
                $628 = HEAP32[$627>>2]|0;
                $629 = ($628*33)|0;
                $630 = (($26) + ($629)|0);
                HEAP32[$630>>2] = $625;
                HEAP32[$L_123>>2] = 12000;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $631 = __THREW__; __THREW__ = 0;
                $632 = $631&1;
                if ($632) {
                 break;
                }
                __THREW__ = 0;
                $633 = (invoke_iii(2724,(2155952|0),($L_123|0))|0);
                $634 = __THREW__; __THREW__ = 0;
                $635 = $634&1;
                if ($635) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $636 = __THREW__; __THREW__ = 0;
                $637 = $636&1;
                if ($637) {
                 break;
                }
                $638 = HEAP32[$14>>2]|0;
                $639 = ($638>>>0)<(35);
                if ($639) {
                 __THREW__ = 0;
                 $640 = (invoke_i(132)|0);
                 $641 = __THREW__; __THREW__ = 0;
                 $642 = $641&1;
                 if ($642) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($640|0));
                 $643 = __THREW__; __THREW__ = 0;
                 $644 = $643&1;
                 if ($644) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($633|0));
                $645 = __THREW__; __THREW__ = 0;
                $646 = $645&1;
                if ($646) {
                 break;
                }
                $647 = HEAP32[$4>>2]|0;
                $648 = (($647) + 92|0);
                $649 = HEAP32[$648>>2]|0;
                $650 = ($649*34)|0;
                $651 = (($26) + ($650)|0);
                HEAP32[$651>>2] = $633;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $652 = __THREW__; __THREW__ = 0;
                $653 = $652&1;
                if ($653) {
                 break;
                }
                $654 = HEAP32[$14>>2]|0;
                $655 = ($654>>>0)<(36);
                if ($655) {
                 __THREW__ = 0;
                 $656 = (invoke_i(132)|0);
                 $657 = __THREW__; __THREW__ = 0;
                 $658 = $657&1;
                 if ($658) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($656|0));
                 $659 = __THREW__; __THREW__ = 0;
                 $660 = $659&1;
                 if ($660) {
                  break;
                 }
                }
                $661 = HEAP32[3054176>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($661|0));
                $662 = __THREW__; __THREW__ = 0;
                $663 = $662&1;
                if ($663) {
                 break;
                }
                $664 = HEAP32[3054176>>2]|0;
                $665 = HEAP32[$4>>2]|0;
                $666 = (($665) + 92|0);
                $667 = HEAP32[$666>>2]|0;
                $668 = ($667*35)|0;
                $669 = (($26) + ($668)|0);
                HEAP32[$669>>2] = $664;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $670 = __THREW__; __THREW__ = 0;
                $671 = $670&1;
                if ($671) {
                 break;
                }
                $672 = HEAP32[$14>>2]|0;
                $673 = ($672>>>0)<(37);
                if ($673) {
                 __THREW__ = 0;
                 $674 = (invoke_i(132)|0);
                 $675 = __THREW__; __THREW__ = 0;
                 $676 = $675&1;
                 if ($676) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($674|0));
                 $677 = __THREW__; __THREW__ = 0;
                 $678 = $677&1;
                 if ($678) {
                  break;
                 }
                }
                $679 = HEAP32[3054184>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($679|0));
                $680 = __THREW__; __THREW__ = 0;
                $681 = $680&1;
                if ($681) {
                 break;
                }
                $682 = HEAP32[3054184>>2]|0;
                $683 = HEAP32[$4>>2]|0;
                $684 = (($683) + 92|0);
                $685 = HEAP32[$684>>2]|0;
                $686 = ($685*36)|0;
                $687 = (($26) + ($686)|0);
                HEAP32[$687>>2] = $682;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $688 = __THREW__; __THREW__ = 0;
                $689 = $688&1;
                if ($689) {
                 break;
                }
                $690 = HEAP32[$14>>2]|0;
                $691 = ($690>>>0)<(38);
                if ($691) {
                 __THREW__ = 0;
                 $692 = (invoke_i(132)|0);
                 $693 = __THREW__; __THREW__ = 0;
                 $694 = $693&1;
                 if ($694) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($692|0));
                 $695 = __THREW__; __THREW__ = 0;
                 $696 = $695&1;
                 if ($696) {
                  break;
                 }
                }
                $697 = HEAP32[3054192>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($697|0));
                $698 = __THREW__; __THREW__ = 0;
                $699 = $698&1;
                if ($699) {
                 break;
                }
                $700 = HEAP32[3054192>>2]|0;
                $701 = HEAP32[$4>>2]|0;
                $702 = (($701) + 92|0);
                $703 = HEAP32[$702>>2]|0;
                $704 = ($703*37)|0;
                $705 = (($26) + ($704)|0);
                HEAP32[$705>>2] = $700;
                HEAP32[$L_138>>2] = 12001;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $706 = __THREW__; __THREW__ = 0;
                $707 = $706&1;
                if ($707) {
                 break;
                }
                __THREW__ = 0;
                $708 = (invoke_iii(2724,(2155952|0),($L_138|0))|0);
                $709 = __THREW__; __THREW__ = 0;
                $710 = $709&1;
                if ($710) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $711 = __THREW__; __THREW__ = 0;
                $712 = $711&1;
                if ($712) {
                 break;
                }
                $713 = HEAP32[$14>>2]|0;
                $714 = ($713>>>0)<(39);
                if ($714) {
                 __THREW__ = 0;
                 $715 = (invoke_i(132)|0);
                 $716 = __THREW__; __THREW__ = 0;
                 $717 = $716&1;
                 if ($717) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($715|0));
                 $718 = __THREW__; __THREW__ = 0;
                 $719 = $718&1;
                 if ($719) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($708|0));
                $720 = __THREW__; __THREW__ = 0;
                $721 = $720&1;
                if ($721) {
                 break;
                }
                $722 = HEAP32[$4>>2]|0;
                $723 = (($722) + 92|0);
                $724 = HEAP32[$723>>2]|0;
                $725 = ($724*38)|0;
                $726 = (($26) + ($725)|0);
                HEAP32[$726>>2] = $708;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $727 = __THREW__; __THREW__ = 0;
                $728 = $727&1;
                if ($728) {
                 break;
                }
                $729 = HEAP32[$14>>2]|0;
                $730 = ($729>>>0)<(40);
                if ($730) {
                 __THREW__ = 0;
                 $731 = (invoke_i(132)|0);
                 $732 = __THREW__; __THREW__ = 0;
                 $733 = $732&1;
                 if ($733) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($731|0));
                 $734 = __THREW__; __THREW__ = 0;
                 $735 = $734&1;
                 if ($735) {
                  break;
                 }
                }
                $736 = HEAP32[3054200>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($736|0));
                $737 = __THREW__; __THREW__ = 0;
                $738 = $737&1;
                if ($738) {
                 break;
                }
                $739 = HEAP32[3054200>>2]|0;
                $740 = HEAP32[$4>>2]|0;
                $741 = (($740) + 92|0);
                $742 = HEAP32[$741>>2]|0;
                $743 = ($742*39)|0;
                $744 = (($26) + ($743)|0);
                HEAP32[$744>>2] = $739;
                HEAP32[$L_147>>2] = 28591;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $745 = __THREW__; __THREW__ = 0;
                $746 = $745&1;
                if ($746) {
                 break;
                }
                __THREW__ = 0;
                $747 = (invoke_iii(2724,(2155952|0),($L_147|0))|0);
                $748 = __THREW__; __THREW__ = 0;
                $749 = $748&1;
                if ($749) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $750 = __THREW__; __THREW__ = 0;
                $751 = $750&1;
                if ($751) {
                 break;
                }
                $752 = HEAP32[$14>>2]|0;
                $753 = ($752>>>0)<(41);
                if ($753) {
                 __THREW__ = 0;
                 $754 = (invoke_i(132)|0);
                 $755 = __THREW__; __THREW__ = 0;
                 $756 = $755&1;
                 if ($756) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($754|0));
                 $757 = __THREW__; __THREW__ = 0;
                 $758 = $757&1;
                 if ($758) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($747|0));
                $759 = __THREW__; __THREW__ = 0;
                $760 = $759&1;
                if ($760) {
                 break;
                }
                $761 = HEAP32[$4>>2]|0;
                $762 = (($761) + 92|0);
                $763 = HEAP32[$762>>2]|0;
                $764 = ($763*40)|0;
                $765 = (($26) + ($764)|0);
                HEAP32[$765>>2] = $747;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $766 = __THREW__; __THREW__ = 0;
                $767 = $766&1;
                if ($767) {
                 break;
                }
                $768 = HEAP32[$14>>2]|0;
                $769 = ($768>>>0)<(42);
                if ($769) {
                 __THREW__ = 0;
                 $770 = (invoke_i(132)|0);
                 $771 = __THREW__; __THREW__ = 0;
                 $772 = $771&1;
                 if ($772) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($770|0));
                 $773 = __THREW__; __THREW__ = 0;
                 $774 = $773&1;
                 if ($774) {
                  break;
                 }
                }
                $775 = HEAP32[3054208>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($775|0));
                $776 = __THREW__; __THREW__ = 0;
                $777 = $776&1;
                if ($777) {
                 break;
                }
                $778 = HEAP32[3054208>>2]|0;
                $779 = HEAP32[$4>>2]|0;
                $780 = (($779) + 92|0);
                $781 = HEAP32[$780>>2]|0;
                $782 = ($781*41)|0;
                $783 = (($26) + ($782)|0);
                HEAP32[$783>>2] = $778;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $784 = __THREW__; __THREW__ = 0;
                $785 = $784&1;
                if ($785) {
                 break;
                }
                $786 = HEAP32[$14>>2]|0;
                $787 = ($786>>>0)<(43);
                if ($787) {
                 __THREW__ = 0;
                 $788 = (invoke_i(132)|0);
                 $789 = __THREW__; __THREW__ = 0;
                 $790 = $789&1;
                 if ($790) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($788|0));
                 $791 = __THREW__; __THREW__ = 0;
                 $792 = $791&1;
                 if ($792) {
                  break;
                 }
                }
                $793 = HEAP32[3054216>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($793|0));
                $794 = __THREW__; __THREW__ = 0;
                $795 = $794&1;
                if ($795) {
                 break;
                }
                $796 = HEAP32[3054216>>2]|0;
                $797 = HEAP32[$4>>2]|0;
                $798 = (($797) + 92|0);
                $799 = HEAP32[$798>>2]|0;
                $800 = ($799*42)|0;
                $801 = (($26) + ($800)|0);
                HEAP32[$801>>2] = $796;
                __THREW__ = 0;
                (invoke_ii(2996,(2533856|0))|0);
                $802 = __THREW__; __THREW__ = 0;
                $803 = $802&1;
                if ($803) {
                 break;
                }
                $804 = HEAP32[((2533856 + 80|0))>>2]|0;
                HEAP32[$804>>2] = $4;
                __THREW__ = 0;
                (invoke_ii(2996,(2149728|0))|0);
                $805 = __THREW__; __THREW__ = 0;
                $806 = $805&1;
                if ($806) {
                 break;
                }
                __THREW__ = 0;
                $807 = (invoke_ii(3469,(2149728|0))|0);
                $808 = __THREW__; __THREW__ = 0;
                $809 = $808&1;
                if ($809) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(1924,($807|0));
                $810 = __THREW__; __THREW__ = 0;
                $811 = $810&1;
                if ($811) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2533856|0))|0);
                $812 = __THREW__; __THREW__ = 0;
                $813 = $812&1;
                if ($813) {
                 break;
                }
                $814 = HEAP32[((2533856 + 80|0))>>2]|0;
                $815 = (($814) + 44|0);
                HEAP32[$815>>2] = $807;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj8569($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z33mscorlib_System_Text_Encoding_m__P22mscorlib_System_ObjectP22mscorlib_System_String($__this,$arg) {
 $__this = $__this|0;
 $arg = $arg|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529632);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($arg|0);
}
function __Z51mscorlib_System_Text_Encoding_m_get_DecoderFallbackP29mscorlib_System_Text_Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529680);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51mscorlib_System_Text_Encoding_m_get_EncoderFallbackP29mscorlib_System_Text_Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529728);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51mscorlib_System_Text_Encoding_m_SetFallbackInternalP29mscorlib_System_Text_EncodingP36mscorlib_System_Text_EncoderFallbackP36mscorlib_System_Text_DecoderFallback($__this,$e,$d) {
 $__this = $__this|0;
 $e = $e|0;
 $d = $d|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529776);
 $0 = ($e|0)==(0|0);
 if (!($0)) {
  $1 = (($__this) + 24|0);
  HEAP32[$1>>2] = $e;
 }
 $2 = ($d|0)==(0|0);
 if ($2) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 20|0);
 HEAP32[$3>>2] = $d;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z38mscorlib_System_Text_Encoding_m_EqualsP29mscorlib_System_Text_EncodingP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529824);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2533856|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = (($__this) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($2) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($9|0)==($13|0);
    if (!($14)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $15 = (invoke_ii(2381,($__this|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      $20 = (invoke_ii(2381,($2|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3799,($15|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_iiii(1644,(2148736|0),($15|0),($20|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         if (!($25)) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $28 = (invoke_ii(2382,($__this|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          __THREW__ = 0;
          invoke_vi(3799,($2|0));
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           $33 = (invoke_ii(2382,($2|0))|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            __THREW__ = 0;
            invoke_vi(3799,($28|0));
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if (!($37)) {
             __THREW__ = 0;
             $38 = (invoke_iiii(1644,(2148736|0),($28|0),($33|0))|0);
             $39 = __THREW__; __THREW__ = 0;
             $40 = $39&1;
             if (!($40)) {
              $$0 = $38;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Text_Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP29mscorlib_System_Text_EncodingP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529872);
 __THREW__ = 0;
 invoke_v(704);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3055080>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($s|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(0);
     if ($20) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $21 = (invoke_ii(1919,(0|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = $s;
      $25 = (($21) + ($24))|0;
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       $28 = (invoke_ii(1816,($s|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = $25;
        __THREW__ = 0;
        $32 = (invoke_iiiii(326,(2529920|0),($__this|0),($31|0),($28|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         $$0 = $32;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS5_i($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z95mscorlib_System_Text_Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arrP29mscorlib_System_Text_EncodingP24mscorlib_System_Char_arr($__this,$chars) {
 $__this = $__this|0;
 $chars = $chars|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529968);
 __THREW__ = 0;
 invoke_v(705);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    $7 = (($chars) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    $9 = (invoke_iiiiii(238,(2530016|0),($__this|0),($chars|0),0,($8|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($9|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2560584|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3055096>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3838,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_E6InvokeEP10MethodInfoPvS5_ii($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z92mscorlib_System_Text_Encoding_m_GetBytes_mscorlib_System_Byte_arr_arr_mscorlib_System_StringP29mscorlib_System_Text_EncodingP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B10_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530064);
 __THREW__ = 0;
 invoke_v(706);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3055112>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($s|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(1203320|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_iii(2768,(1203320|0),0)|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      } else {
       $$0$in = $23;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0$in|0);
     }
     __THREW__ = 0;
     $26 = (invoke_iiii(1641,(2529872|0),($__this|0),($s|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = ($26|0)==(0);
      if ($29) {
       __THREW__ = 0;
       (invoke_ii(2996,(1203320|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __THREW__ = 0;
       $32 = (invoke_iii(2768,(1203320|0),0)|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       } else {
        $$0$in = $32;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0$in|0);
      }
      __THREW__ = 0;
      $35 = (invoke_ii(1919,(0|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       $38 = $s;
       $39 = (($35) + ($38))|0;
       __THREW__ = 0;
       (invoke_ii(2996,(1203320|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __THREW__ = 0;
        $42 = (invoke_iii(2768,(1203320|0),($26|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if (!($44)) {
         $45 = ($42|0)==(0|0);
         if ($45) {
          $G_B10_0$0 = 0;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($42|0));
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          $48 = (($42) + 12|0);
          $49 = HEAP32[$48>>2]|0;
          $50 = ($49|0)==(0);
          if ($50) {
           $G_B10_0$0 = 0;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($42|0));
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if ($52) {
            break;
           }
           $53 = HEAP32[$48>>2]|0;
           $54 = ($53|0)==(0);
           if ($54) {
            __THREW__ = 0;
            $55 = (invoke_i(132)|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($55|0));
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             break;
            }
           }
           $60 = (($42) + 16|0);
           $G_B10_0$0 = $60;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($s|0));
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if (!($62)) {
          __THREW__ = 0;
          $63 = (invoke_ii(1816,($s|0))|0);
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if (!($65)) {
           $66 = $39;
           __THREW__ = 0;
           (invoke_iiiiiii(133,(2530112|0),($__this|0),($66|0),($63|0),($G_B10_0$0|0),($26|0))|0);
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if (!($68)) {
            $$0$in = $42;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0$in|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_E6InvokeEP10MethodInfoPvS5_iS5_i($method,$obj,$p1,$p2,$p3,$p4) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z142mscorlib_System_Text_Encoding_m_GetBytes_mscorlib_System_Byte_arr_arr_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P29mscorlib_System_Text_EncodingP24mscorlib_System_Char_arrii($__this,$chars,$index,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530160);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(238,(2530016|0),($__this|0),($chars|0),($index|0),($count|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1203320|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2768,(1203320|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    (invoke_iiiiiiii(121,(2530208|0),($__this|0),($chars|0),($index|0),($count|0),($5|0),0)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($5|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_E6InvokeEP10MethodInfoPvS5_iiS5_i($method,$obj,$p1,$p2,$p3,$p4,$p5) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4,$p5)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z142mscorlib_System_Text_Encoding_m_GetChars_mscorlib_System_Char_arr_arr_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P29mscorlib_System_Text_EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530256);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(238,(2530304|0),($__this|0),($bytes|0),($index|0),($count|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1168808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2768,(1168808|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    (invoke_iiiiiiii(121,(2530352|0),($__this|0),($bytes|0),($index|0),($count|0),($5|0),0)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($5|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Text_Encoding_m_GetEncoding_mscorlib_System_Text_Encoding_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$codepage) {
 $__this = $__this|0;
 $codepage = $codepage|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $L_25 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_25 = sp + 4|0;
 HEAP32[$0>>2] = $codepage;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530400);
 __THREW__ = 0;
 invoke_v(707);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP32[$0>>2]|0;
   $4 = ($3>>>0)<(65536);
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2561352|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3055128>>2]|0;
    $13 = HEAP32[3055136>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($9|0),($12|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   }
   do {
    if ((($3|0) == 12000)) {
     __THREW__ = 0;
     $30 = (invoke_ii(2393,0)|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break L1;
     } else {
      $$0 = $30;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($3|0) == 1200)) {
     __THREW__ = 0;
     $36 = (invoke_ii(2392,0)|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break L1;
     } else {
      $$0 = $36;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($3|0) == 0)) {
     __THREW__ = 0;
     $18 = (invoke_ii(2387,0)|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break L1;
     } else {
      $$0 = $18;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($3|0) == 65001)) {
     __THREW__ = 0;
     $27 = (invoke_ii(2390,0)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break L1;
     } else {
      $$0 = $27;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($3|0) == 20127)) {
     __THREW__ = 0;
     $21 = (invoke_ii(2385,0)|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break L1;
     } else {
      $$0 = $21;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($3|0) == 1201)) {
     __THREW__ = 0;
     $39 = (invoke_ii(2386,0)|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break L1;
     } else {
      $$0 = $39;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($3|0) == 12001)) {
     __THREW__ = 0;
     $33 = (invoke_ii(2394,0)|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break L1;
     } else {
      $$0 = $33;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($3|0) == 28591)) {
     __THREW__ = 0;
     $42 = (invoke_ii(2388,0)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break L1;
     } else {
      $$0 = $42;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($3|0) == 65000)) {
     __THREW__ = 0;
     $24 = (invoke_ii(2389,0)|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break L1;
     } else {
      $$0 = $24;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L1;
     }
     __THREW__ = 0;
     $47 = (invoke_iii(2768,(1167664|0),1)|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break L1;
     }
     $50 = HEAP32[$0>>2]|0;
     HEAP32[$L_25>>2] = $50;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break L1;
     }
     __THREW__ = 0;
     $53 = (invoke_iii(2724,(2155952|0),($L_25|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3799,($47|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break L1;
     }
     $58 = (($47) + 12|0);
     $59 = HEAP32[$58>>2]|0;
     $60 = ($59|0)==(0);
     if ($60) {
      __THREW__ = 0;
      $61 = (invoke_i(132)|0);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3302,($61|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break L1;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($47|0),($53|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break L1;
     }
     $68 = (($47) + 16|0);
     HEAP32[$68>>2] = $53;
     $69 = HEAP32[3055144>>2]|0;
     __THREW__ = 0;
     $70 = (invoke_iiii(1286,(0|0),($69|0),($47|0))|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      break L1;
     }
     __THREW__ = 0;
     $75 = (invoke_iii(2769,($70|0),(2533856|0))|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break L1;
     }
     $78 = ($75|0)==(0|0);
     if (!($78)) {
      __THREW__ = 0;
      invoke_vi(3799,($75|0));
      $79 = __THREW__; __THREW__ = 0;
      $80 = $79&1;
      if ($80) {
       break L1;
      }
      $81 = (($75) + 16|0);
      HEAP8[$81>>0] = 1;
      $$0 = $75;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $82 = (invoke_ii(1791,($0|0))|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if ($84) {
      break L1;
     }
     $85 = HEAP32[3055152>>2]|0;
     __THREW__ = 0;
     $86 = (invoke_iiii(562,(0|0),($85|0),($82|0))|0);
     $87 = __THREW__; __THREW__ = 0;
     $88 = $87&1;
     if ($88) {
      break L1;
     }
     __THREW__ = 0;
     $89 = (invoke_ii(2188,(0|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3799,($89|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      break L1;
     }
     __THREW__ = 0;
     $94 = (invoke_iiii(1645,(2376032|0),($89|0),($86|0))|0);
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      break L1;
     }
     $97 = ($94|0)==(0|0);
     if (!($97)) {
      __THREW__ = 0;
      $98 = (invoke_iii(1002,0,($94|0))|0);
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       break L1;
      }
      __THREW__ = 0;
      $103 = (invoke_iii(2769,($98|0),(2533856|0))|0);
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($103|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       break L1;
      }
      $108 = (($103) + 16|0);
      HEAP8[$108>>0] = 1;
      $$0 = $103;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $109 = (invoke_iii(769,(0|0),($86|0))|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if ($111) {
      break L1;
     }
     $112 = ($109|0)==(0|0);
     if (!($112)) {
      __THREW__ = 0;
      $113 = (invoke_iii(1002,0,($109|0))|0);
      $114 = __THREW__; __THREW__ = 0;
      $115 = $114&1;
      if ($115) {
       break L1;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       break L1;
      }
      __THREW__ = 0;
      $118 = (invoke_iii(2769,($113|0),(2533856|0))|0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($118|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if ($122) {
       break L1;
      }
      $123 = (($118) + 16|0);
      HEAP8[$123>>0] = 1;
      $$0 = $118;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $124 = (invoke_ii(1791,($0|0))|0);
     $125 = __THREW__; __THREW__ = 0;
     $126 = $125&1;
     if ($126) {
      break L1;
     }
     $127 = HEAP32[3055160>>2]|0;
     __THREW__ = 0;
     $128 = (invoke_iiii(552,(0|0),($127|0),($124|0))|0);
     $129 = __THREW__; __THREW__ = 0;
     $130 = $129&1;
     if ($130) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2622808|0))|0);
     $131 = __THREW__; __THREW__ = 0;
     $132 = $131&1;
     if ($132) {
      break L1;
     }
     __THREW__ = 0;
     $133 = (invoke_ii(3469,(2622808|0))|0);
     $134 = __THREW__; __THREW__ = 0;
     $135 = $134&1;
     if ($135) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1954,($133|0),($128|0));
     $136 = __THREW__; __THREW__ = 0;
     $137 = $136&1;
     if ($137) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3838,($133|0));
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if ($139) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z118mscorlib_System_ArgumentOutOfRangeException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP43mscorlib_System_ArgumentOutOfRangeExceptionP22mscorlib_System_StringS2_($__this,$paramName,$message) {
 $__this = $__this|0;
 $paramName = $paramName|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560816);
 __THREW__ = 0;
 invoke_viii(641,($__this|0),($message|0),($paramName|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233086);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z43mscorlib_System_Text_Encoding_m_get_DefaultP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $$04 = 0, $$1 = 0, $$15 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530896);
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     L19: do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        label = 21;
       } else {
        $49 = HEAP32[((2533856 + 80|0))>>2]|0;
        $50 = (($49) + 12|0);
        $51 = HEAP32[$50>>2]|0;
        $52 = ($51|0)==(0|0);
        if ($52) {
         HEAP32[$V_1>>2] = 1;
         __THREW__ = 0;
         $53 = (invoke_iii(985,0,($V_1|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 21;
         } else {
          $56 = HEAP32[$V_1>>2]|0;
          $57 = ($56|0)==(-1);
          do {
           if ($57) {
            __THREW__ = 0;
            $58 = (invoke_iii(983,0,($53|0))|0);
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             label = 32;
            } else {
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $61 = __THREW__; __THREW__ = 0;
             $62 = $61&1;
             if ($62) {
              label = 32;
             } else {
              $63 = HEAP8[((2533856 + 116|0))>>0]|0;
              $64 = ($63<<24>>24)==(0);
              if ($64) {
               __THREW__ = 0;
               (invoke_ii(2996,(2533856|0))|0);
               $65 = __THREW__; __THREW__ = 0;
               $66 = $65&1;
               if ($66) {
                label = 32;
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2533856|0))|0);
               $67 = __THREW__; __THREW__ = 0;
               $68 = $67&1;
               if ($68) {
                label = 32;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3839,(2533856|0));
               $69 = __THREW__; __THREW__ = 0;
               $70 = $69&1;
               if ($70) {
                label = 32;
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $81 = __THREW__; __THREW__ = 0;
              $82 = $81&1;
              if ($82) {
               label = 32;
               break;
              }
              $83 = HEAP32[((2533856 + 80|0))>>2]|0;
              $84 = (($83) + 12|0);
              HEAP32[$84>>2] = $58;
             }
            }
           } else {
            $85 = $56 & 268435455;
            HEAP32[$V_1>>2] = $85;
            switch ($85|0) {
            case 1:  {
             HEAP32[$V_1>>2] = 20127;
             $86 = 20127;
             break;
            }
            case 2:  {
             HEAP32[$V_1>>2] = 65000;
             $86 = 65000;
             break;
            }
            case 3:  {
             HEAP32[$V_1>>2] = 65001;
             $86 = 65001;
             break;
            }
            case 6:  {
             HEAP32[$V_1>>2] = 28591;
             $86 = 28591;
             break;
            }
            case 5:  {
             HEAP32[$V_1>>2] = 1201;
             $86 = 1201;
             break;
            }
            case 4:  {
             HEAP32[$V_1>>2] = 1200;
             $86 = 1200;
             break;
            }
            default: {
             $86 = $85;
            }
            }
            __THREW__ = 0;
            $87 = (invoke_iii(982,0,($86|0))|0);
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if ($89) {
             label = 32;
            } else {
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $90 = __THREW__; __THREW__ = 0;
             $91 = $90&1;
             if ($91) {
              label = 32;
             } else {
              $92 = HEAP8[((2533856 + 116|0))>>0]|0;
              $93 = ($92<<24>>24)==(0);
              if ($93) {
               __THREW__ = 0;
               (invoke_ii(2996,(2533856|0))|0);
               $94 = __THREW__; __THREW__ = 0;
               $95 = $94&1;
               if ($95) {
                label = 32;
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2533856|0))|0);
               $96 = __THREW__; __THREW__ = 0;
               $97 = $96&1;
               if ($97) {
                label = 32;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3839,(2533856|0));
               $98 = __THREW__; __THREW__ = 0;
               $99 = $98&1;
               if ($99) {
                label = 32;
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $100 = __THREW__; __THREW__ = 0;
              $101 = $100&1;
              if ($101) {
               label = 32;
               break;
              }
              $102 = HEAP32[((2533856 + 80|0))>>2]|0;
              $103 = (($102) + 12|0);
              HEAP32[$103>>2] = $87;
             }
            }
           }
          } while(0);
          L56: do {
           if ((label|0) == 32) {
            $71 = ___cxa_find_matching_catch(348288|0)|0;
            $72 = tempRet0;
            $73 = (_llvm_eh_typeid_for((348288|0))|0);
            $74 = ($72|0)==($73|0);
            if (!($74)) {
             $$03 = $71;$$04 = $72;$$pre$phiZ2D = $73;
             label = 58;
             break L19;
            }
            $75 = (___cxa_begin_catch(($71|0))|0);
            $76 = HEAP32[$75>>2]|0;
            $77 = HEAP32[$76>>2]|0;
            __THREW__ = 0;
            $78 = (invoke_iii(2727,(2622808|0),($77|0))|0);
            $79 = __THREW__; __THREW__ = 0;
            $80 = $79&1;
            L59: do {
             if (!($80)) {
              do {
               if ($78) {
                $$02 = 29;
               } else {
                $108 = HEAP32[$75>>2]|0;
                $109 = HEAP32[$108>>2]|0;
                __THREW__ = 0;
                $110 = (invoke_iii(2727,(2560072|0),($109|0))|0);
                $111 = __THREW__; __THREW__ = 0;
                $112 = $111&1;
                if ($112) {
                 break L59;
                }
                if ($110) {
                 $$02 = 30;
                 break;
                }
                $113 = (___cxa_allocate_exception(4)|0);
                $114 = HEAP32[$75>>2]|0;
                HEAP32[$113>>2] = $114;
                __THREW__ = 0;
                invoke_viii(1567,($113|0),(348288|0),(0|0));
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if ($116) {
                 break L59;
                }
                // unreachable;
               }
              } while(0);
              __THREW__ = 0;
              invoke_v(66);
              $117 = __THREW__; __THREW__ = 0;
              $118 = $117&1;
              if ($118) {
               label = 21;
               break L19;
              }
              if ((($$02|0) == 29)) {
               __THREW__ = 0;
               $124 = (invoke_ii(2391,0)|0);
               $125 = __THREW__; __THREW__ = 0;
               $126 = $125&1;
               if ($126) {
                label = 21;
                break L19;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2533856|0))|0);
               $127 = __THREW__; __THREW__ = 0;
               $128 = $127&1;
               if ($128) {
                label = 21;
                break L19;
               }
               $129 = HEAP8[((2533856 + 116|0))>>0]|0;
               $130 = ($129<<24>>24)==(0);
               if ($130) {
                __THREW__ = 0;
                (invoke_ii(2996,(2533856|0))|0);
                $131 = __THREW__; __THREW__ = 0;
                $132 = $131&1;
                if ($132) {
                 label = 21;
                 break L19;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2533856|0))|0);
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 label = 21;
                 break L19;
                }
                __THREW__ = 0;
                invoke_vi(3839,(2533856|0));
                $135 = __THREW__; __THREW__ = 0;
                $136 = $135&1;
                if ($136) {
                 label = 21;
                 break L19;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2533856|0))|0);
               $137 = __THREW__; __THREW__ = 0;
               $138 = $137&1;
               if ($138) {
                label = 21;
                break L19;
               }
               $139 = HEAP32[((2533856 + 80|0))>>2]|0;
               $140 = (($139) + 12|0);
               HEAP32[$140>>2] = $124;
               break L56;
              } else if ((($$02|0) == 30)) {
               __THREW__ = 0;
               $141 = (invoke_ii(2391,0)|0);
               $142 = __THREW__; __THREW__ = 0;
               $143 = $142&1;
               if ($143) {
                label = 21;
                break L19;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2533856|0))|0);
               $144 = __THREW__; __THREW__ = 0;
               $145 = $144&1;
               if ($145) {
                label = 21;
                break L19;
               }
               $146 = HEAP8[((2533856 + 116|0))>>0]|0;
               $147 = ($146<<24>>24)==(0);
               if ($147) {
                __THREW__ = 0;
                (invoke_ii(2996,(2533856|0))|0);
                $148 = __THREW__; __THREW__ = 0;
                $149 = $148&1;
                if ($149) {
                 label = 21;
                 break L19;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2533856|0))|0);
                $150 = __THREW__; __THREW__ = 0;
                $151 = $150&1;
                if ($151) {
                 label = 21;
                 break L19;
                }
                __THREW__ = 0;
                invoke_vi(3839,(2533856|0));
                $152 = __THREW__; __THREW__ = 0;
                $153 = $152&1;
                if ($153) {
                 label = 21;
                 break L19;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2533856|0))|0);
               $154 = __THREW__; __THREW__ = 0;
               $155 = $154&1;
               if ($155) {
                label = 21;
                break L19;
               }
               $156 = HEAP32[((2533856 + 80|0))>>2]|0;
               $157 = (($156) + 12|0);
               HEAP32[$157>>2] = $141;
               break L56;
              } else {
               $$0 = 0;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            } while(0);
            $104 = ___cxa_find_matching_catch(348288|0)|0;
            $105 = tempRet0;
            __THREW__ = 0;
            invoke_v(66);
            $106 = __THREW__; __THREW__ = 0;
            $107 = $106&1;
            if (!($107)) {
             $$03 = $104;$$04 = $105;$$pre$phiZ2D = $73;
             label = 58;
             break L19;
            }
            $195 = ___cxa_find_matching_catch(0|0)|0;
            $196 = tempRet0;
            ___clang_call_terminate($195);
            // unreachable;
           }
          } while(0);
          __THREW__ = 0;
          (invoke_ii(2996,(2533856|0))|0);
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           label = 21;
          } else {
           $160 = HEAP8[((2533856 + 116|0))>>0]|0;
           $161 = ($160<<24>>24)==(0);
           if ($161) {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $162 = __THREW__; __THREW__ = 0;
            $163 = $162&1;
            if ($163) {
             label = 21;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $164 = __THREW__; __THREW__ = 0;
            $165 = $164&1;
            if ($165) {
             label = 21;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2533856|0));
            $166 = __THREW__; __THREW__ = 0;
            $167 = $166&1;
            if ($167) {
             label = 21;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2533856|0))|0);
           $168 = __THREW__; __THREW__ = 0;
           $169 = $168&1;
           if ($169) {
            label = 21;
           } else {
            $170 = HEAP32[((2533856 + 80|0))>>2]|0;
            $171 = (($170) + 12|0);
            $172 = HEAP32[$171>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($172|0));
            $173 = __THREW__; __THREW__ = 0;
            $174 = $173&1;
            if ($174) {
             label = 21;
             break;
            }
            $175 = (($172) + 16|0);
            HEAP8[$175>>0] = 1;
            $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 224;
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 224;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $$pre = (_llvm_eh_typeid_for((348288|0))|0);
      $$03 = $45;$$04 = $46;$$pre$phiZ2D = $$pre;
      label = 58;
     }
     if ((label|0) == 58) {
      $119 = ($$04|0)==($$pre$phiZ2D|0);
      if (!($119)) {
       $$1 = $$03;$$15 = $$04;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$1|0);
       // unreachable;
      }
      $120 = (___cxa_begin_catch(($$03|0))|0);
      $121 = HEAP32[$120>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       break;
      }
      $__last_unhandled_exception$0 = $121;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $176 = __THREW__; __THREW__ = 0;
     $177 = $176&1;
     if ($177) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(224);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $178 = __THREW__; __THREW__ = 0;
      $179 = $178&1;
      if ($179) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if (!($181)) {
     $182 = HEAP8[((2533856 + 116|0))>>0]|0;
     $183 = ($182<<24>>24)==(0);
     if ($183) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $184 = __THREW__; __THREW__ = 0;
      $185 = $184&1;
      if ($185) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $186 = __THREW__; __THREW__ = 0;
      $187 = $186&1;
      if ($187) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $188 = __THREW__; __THREW__ = 0;
      $189 = $188&1;
      if ($189) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $190 = __THREW__; __THREW__ = 0;
     $191 = $190&1;
     if (!($191)) {
      $192 = HEAP32[((2533856 + 80|0))>>2]|0;
      $193 = (($192) + 12|0);
      $194 = HEAP32[$193>>2]|0;
      $$0 = $194;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$1 = $10;$$15 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$1|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_Text_Encoding_m_get_ASCIIP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530688);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 4|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2515248|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2515248|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_vi(2496,($61|0));
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 4|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 51;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 51;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(51);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 4|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Text_Encoding_m_get_UTF7P22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530992);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 16|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2541528|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2541528|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_vi(2531,($61|0));
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 16|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 51;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 51;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(51);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 16|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_Text_Encoding_m_get_UTF8P22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2531040);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 20|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 20|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2544368|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2544368|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_vii(1915,($61|0),1);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 20|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 52;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 52;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(52);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 20|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_Text_Encoding_m_get_UTF32P22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2531184);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 36|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 36|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2539360|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2539360|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_viii(635,($61|0),0,1);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 36|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(53);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 36|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Text_Encoding_m_get_BigEndianUTF32P22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2531232);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 40|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 40|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2539360|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2539360|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_viii(635,($61|0),1,1);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 40|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(53);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 40|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Text_Encoding_m_get_UnicodeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2531136);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 28|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2546152|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2546152|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_viii(637,($61|0),0,1);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 28|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(53);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 28|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Text_Encoding_m_get_BigEndianUnicodeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530736);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 8|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2546152|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2546152|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_viii(637,($61|0),1,1);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 8|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(53);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 8|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_Text_Encoding_m_get_ISOLatin1P22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530944);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 32|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 32|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2535008|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2535008|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_vi(2524,($61|0));
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 32|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 51;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 51;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(51);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 32|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo8580($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z86mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_TypeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2554392);
 __THREW__ = 0;
 $0 = (invoke_iiii(961,0,($type|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z89mscorlib_System_NotSupportedException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP37mscorlib_System_NotSupportedExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2622552);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233067);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z96mscorlib_System_Text_Encoding_m_GetEncoding_mscorlib_System_Text_Encoding_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530448);
 __THREW__ = 0;
 invoke_v(708);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3055400>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($name|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(1814,($name|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vi(3799,($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      $24 = (invoke_iiii(546,($19|0),45,95)|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       $V_1$1 = 0;$V_2$0 = 0;
       while(1) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $111 = __THREW__; __THREW__ = 0;
        $112 = $111&1;
        if ($112) {
         label = 3;
         break;
        }
        $113 = HEAP8[((2533856 + 116|0))>>0]|0;
        $114 = ($113<<24>>24)==(0);
        if ($114) {
         __THREW__ = 0;
         (invoke_ii(2996,(2533856|0))|0);
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2533856|0))|0);
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3839,(2533856|0));
         $119 = __THREW__; __THREW__ = 0;
         $120 = $119&1;
         if ($120) {
          label = 3;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if ($122) {
         label = 3;
         break;
        }
        $123 = HEAP32[((2533856 + 80|0))>>2]|0;
        $124 = HEAP32[$123>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($124|0));
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         label = 3;
         break;
        }
        $127 = (($124) + 12|0);
        $128 = HEAP32[$127>>2]|0;
        $129 = ($V_2$0|0)<($128|0);
        if (!($129)) {
         label = 55;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if ($131) {
         label = 3;
         break;
        }
        $27 = HEAP8[((2533856 + 116|0))>>0]|0;
        $28 = ($27<<24>>24)==(0);
        if ($28) {
         __THREW__ = 0;
         (invoke_ii(2996,(2533856|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2533856|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3839,(2533856|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          label = 3;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         label = 3;
         break;
        }
        $37 = HEAP32[((2533856 + 80|0))>>2]|0;
        $38 = HEAP32[$37>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($38|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 3;
         break;
        }
        $41 = (($38) + 12|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = ($V_2$0>>>0)<($42>>>0);
        if (!($43)) {
         __THREW__ = 0;
         $44 = (invoke_i(132)|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($44|0));
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          label = 3;
          break;
         }
        }
        $49 = HEAP32[$38>>2]|0;
        $50 = (($38) + 16|0);
        $51 = (($49) + 92|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = Math_imul($52, $V_2$0)|0;
        $54 = (($50) + ($53)|0);
        $55 = HEAP32[$54>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        $58 = (invoke_iii(2735,($55|0),(2155952|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 3;
         break;
        }
        $61 = ($58|0)==(0|0);
        if ($61) {
         __THREW__ = 0;
         (invoke_ii(2996,(2533856|0))|0);
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          label = 3;
          break;
         }
         $70 = HEAP8[((2533856 + 116|0))>>0]|0;
         $71 = ($70<<24>>24)==(0);
         if ($71) {
          __THREW__ = 0;
          (invoke_ii(2996,(2533856|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2533856|0))|0);
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2533856|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           label = 3;
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2533856|0))|0);
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          label = 3;
          break;
         }
         $80 = HEAP32[((2533856 + 80|0))>>2]|0;
         $81 = HEAP32[$80>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($81|0));
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          label = 3;
          break;
         }
         $84 = (($81) + 12|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = ($V_2$0>>>0)<($85>>>0);
         if (!($86)) {
          __THREW__ = 0;
          $87 = (invoke_i(132)|0);
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($87|0));
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           label = 3;
           break;
          }
         }
         $92 = HEAP32[$81>>2]|0;
         $93 = (($81) + 16|0);
         $94 = (($92) + 92|0);
         $95 = HEAP32[$94>>2]|0;
         $96 = Math_imul($95, $V_2$0)|0;
         $97 = (($93) + ($96)|0);
         $98 = HEAP32[$97>>2]|0;
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $101 = (invoke_iii(2769,($98|0),(2191608|0))|0);
         $102 = __THREW__; __THREW__ = 0;
         $103 = $102&1;
         if ($103) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $104 = (invoke_iiii(574,(0|0),($24|0),($101|0))|0);
         $105 = __THREW__; __THREW__ = 0;
         $106 = $105&1;
         if ($106) {
          label = 3;
          break;
         }
         if ($104) {
          label = 44;
          break;
         } else {
          $V_1$0 = $V_1$1;
         }
        } else {
         __THREW__ = 0;
         (invoke_ii(2996,(2155952|0))|0);
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          label = 3;
          break;
         }
         __THREW__ = 0;
         $64 = (invoke_iii(2770,($55|0),(2155952|0))|0);
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          label = 3;
          break;
         }
         $67 = HEAP32[$64>>2]|0;
         $V_1$0 = $67;
        }
        $110 = (($V_2$0) + 1)|0;
        $V_1$1 = $V_1$0;$V_2$0 = $110;
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 44) {
        __THREW__ = 0;
        $107 = (invoke_iii(982,0,($V_1$1|0))|0);
        $108 = __THREW__; __THREW__ = 0;
        $109 = $108&1;
        if ($109) {
         break;
        } else {
         $$0 = $107;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 55) {
        __THREW__ = 0;
        (invoke_ii(2996,(1167664|0))|0);
        $132 = __THREW__; __THREW__ = 0;
        $133 = $132&1;
        if ($133) {
         break;
        }
        __THREW__ = 0;
        $134 = (invoke_iii(2768,(1167664|0),1)|0);
        $135 = __THREW__; __THREW__ = 0;
        $136 = $135&1;
        if ($136) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($134|0));
        $137 = __THREW__; __THREW__ = 0;
        $138 = $137&1;
        if ($138) {
         break;
        }
        $139 = (($134) + 12|0);
        $140 = HEAP32[$139>>2]|0;
        $141 = ($140|0)==(0);
        if ($141) {
         __THREW__ = 0;
         $142 = (invoke_i(132)|0);
         $143 = __THREW__; __THREW__ = 0;
         $144 = $143&1;
         if ($144) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($142|0));
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         if ($146) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($134|0),($name|0));
        $147 = __THREW__; __THREW__ = 0;
        $148 = $147&1;
        if ($148) {
         break;
        }
        $149 = (($134) + 16|0);
        HEAP32[$149>>2] = $name;
        $150 = HEAP32[3055408>>2]|0;
        __THREW__ = 0;
        $151 = (invoke_iiii(1286,(0|0),($150|0),($134|0))|0);
        $152 = __THREW__; __THREW__ = 0;
        $153 = $152&1;
        if ($153) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $154 = __THREW__; __THREW__ = 0;
        $155 = $154&1;
        if ($155) {
         break;
        }
        __THREW__ = 0;
        $156 = (invoke_iii(2769,($151|0),(2533856|0))|0);
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         break;
        }
        $159 = ($156|0)==(0|0);
        if (!($159)) {
         $$0 = $156;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $160 = HEAP32[3055416>>2]|0;
        __THREW__ = 0;
        $161 = (invoke_iiii(562,(0|0),($160|0),($24|0))|0);
        $162 = __THREW__; __THREW__ = 0;
        $163 = $162&1;
        if ($163) {
         break;
        }
        __THREW__ = 0;
        $164 = (invoke_ii(2188,(0|0))|0);
        $165 = __THREW__; __THREW__ = 0;
        $166 = $165&1;
        if ($166) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($164|0));
        $167 = __THREW__; __THREW__ = 0;
        $168 = $167&1;
        if ($168) {
         break;
        }
        __THREW__ = 0;
        $169 = (invoke_iiii(1645,(2376032|0),($164|0),($161|0))|0);
        $170 = __THREW__; __THREW__ = 0;
        $171 = $170&1;
        if ($171) {
         break;
        }
        $172 = ($169|0)==(0|0);
        if (!($172)) {
         __THREW__ = 0;
         $173 = (invoke_iii(1002,0,($169|0))|0);
         $174 = __THREW__; __THREW__ = 0;
         $175 = $174&1;
         if ($175) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2533856|0))|0);
         $176 = __THREW__; __THREW__ = 0;
         $177 = $176&1;
         if ($177) {
          break;
         }
         __THREW__ = 0;
         $178 = (invoke_iii(2769,($173|0),(2533856|0))|0);
         $179 = __THREW__; __THREW__ = 0;
         $180 = $179&1;
         if ($180) {
          break;
         }
         $$0 = $178;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        $181 = (invoke_iii(769,(0|0),($161|0))|0);
        $182 = __THREW__; __THREW__ = 0;
        $183 = $182&1;
        if ($183) {
         break;
        }
        $184 = ($181|0)==(0|0);
        if (!($184)) {
         __THREW__ = 0;
         $185 = (invoke_iii(1002,0,($181|0))|0);
         $186 = __THREW__; __THREW__ = 0;
         $187 = $186&1;
         if ($187) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2533856|0))|0);
         $188 = __THREW__; __THREW__ = 0;
         $189 = $188&1;
         if ($189) {
          break;
         }
         __THREW__ = 0;
         $190 = (invoke_iii(2769,($185|0),(2533856|0))|0);
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if ($192) {
          break;
         }
         $$0 = $190;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $193 = HEAP32[3055424>>2]|0;
        __THREW__ = 0;
        $194 = (invoke_iiii(552,(0|0),($193|0),($name|0))|0);
        $195 = __THREW__; __THREW__ = 0;
        $196 = $195&1;
        if ($196) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $197 = __THREW__; __THREW__ = 0;
        $198 = $197&1;
        if ($198) {
         break;
        }
        __THREW__ = 0;
        $199 = (invoke_ii(3469,(2560072|0))|0);
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         break;
        }
        $202 = HEAP32[3055432>>2]|0;
        __THREW__ = 0;
        invoke_viii(641,($199|0),($194|0),($202|0));
        $203 = __THREW__; __THREW__ = 0;
        $204 = $203&1;
        if ($204) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3838,($199|0));
        $205 = __THREW__; __THREW__ = 0;
        $206 = $205&1;
        if ($206) {
         break;
        }
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo8583($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z108mscorlib_System_ArgumentException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP33mscorlib_System_ArgumentExceptionP22mscorlib_System_StringS2_($__this,$message,$paramName) {
 $__this = $__this|0;
 $message = $message|0;
 $paramName = $paramName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2559416);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 52|0);
  HEAP32[$2>>2] = $paramName;
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147024809);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z43mscorlib_System_Text_Encoding_m_GetHashCodeP29mscorlib_System_Text_Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530496);
 __THREW__ = 0;
 $0 = (invoke_ii(2381,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2729,(2148880|0),($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(2382,($__this|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_iii(2729,(2148880|0),($8|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = (($13) + 24)|0;
       $17 = $16 & 31;
       $18 = $5 << $17;
       $19 = (($__this) + 8|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (($20) + 16)|0;
       $22 = $21 & 31;
       $23 = $18 << $22;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($23|0);
      }
     }
    }
   }
  }
 }
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($24|0);
 // unreachable;
 return 0|0;
}
function __Z137mscorlib_System_Text_Encoding_m_GetString_mscorlib_System_String_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P29mscorlib_System_Text_EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530544);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(239,(2530256|0),($__this|0),($bytes|0),($index|0),($count|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2191608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2191608|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(642,($5|0),($0|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($8|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_E6InvokeEP10MethodInfoPvS5_ii($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z93mscorlib_System_Text_Encoding_m_GetString_mscorlib_System_String_mscorlib_System_Byte_arr_arrP29mscorlib_System_Text_EncodingP24mscorlib_System_Byte_arr($__this,$bytes) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530592);
 __THREW__ = 0;
 invoke_v(709);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($bytes) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iiiiii(239,(2530544|0),($__this|0),($bytes|0),0,($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3055552>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3838,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Text_Encoding_m_get_WebNameP29mscorlib_System_Text_Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530640);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z41mscorlib_System_Threading_Monitor_m_EnterP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2547200);
 $0 = HEAP32[2547248>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2547256|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2547248>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($obj|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z40mscorlib_System_Threading_Monitor_m_ExitP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2547304);
 $0 = HEAP32[2547352>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2547360|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2547352>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($obj|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z113mscorlib_System_Text_UnicodeEncoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_BooleanP36mscorlib_System_Text_UnicodeEncodingbb($__this,$bigEndian,$byteOrderMark) {
 $__this = $__this|0;
 $bigEndian = $bigEndian|0;
 $byteOrderMark = $byteOrderMark|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544504);
 __THREW__ = 0;
 invoke_viiii(174,($__this|0),($bigEndian|0),($byteOrderMark|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48mscorlib_System_Text_Encoding_m_InternalCodePageP22mscorlib_System_ObjectPi($__this,$code_page) {
 $__this = $__this|0;
 $code_page = $code_page|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530784);
 $0 = HEAP32[2530832>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2530840|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2530832>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($code_page|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Text_Encoding_m_get_UTF8UnmarkedP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2531088);
 __THREW__ = 0;
 (invoke_ii(2996,(2533856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2533856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2533856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2533856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2533856 + 80|0))>>2]|0;
    $15 = (($14) + 24|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2533856 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2533856 + 80|0))>>2]|0;
     $31 = (($30) + 44|0);
     $32 = HEAP32[$31>>2]|0;
     __THREW__ = 0;
     invoke_vii(1916,0,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     do {
      if ($36) {
       label = 21;
      } else {
       $37 = HEAP8[((2533856 + 116|0))>>0]|0;
       $38 = ($37<<24>>24)==(0);
       if ($38) {
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2533856|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         label = 21;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2533856|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         label = 21;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2533856|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 21;
       } else {
        $55 = HEAP32[((2533856 + 80|0))>>2]|0;
        $56 = (($55) + 24|0);
        $57 = HEAP32[$56>>2]|0;
        $58 = ($57|0)==(0|0);
        if ($58) {
         __THREW__ = 0;
         (invoke_ii(2996,(2544368|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          label = 21;
         } else {
          __THREW__ = 0;
          $61 = (invoke_ii(3469,(2544368|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 21;
          } else {
           __THREW__ = 0;
           invoke_viii(636,($61|0),0,0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 21;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2533856|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             label = 21;
            } else {
             $68 = HEAP8[((2533856 + 116|0))>>0]|0;
             $69 = ($68<<24>>24)==(0);
             if ($69) {
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if ($71) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2533856|0))|0);
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if ($73) {
               label = 21;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2533856|0));
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 21;
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2533856|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              label = 21;
              break;
             }
             $78 = HEAP32[((2533856 + 80|0))>>2]|0;
             $79 = (($78) + 24|0);
             HEAP32[$79>>2] = $61;
             $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
            }
           }
          }
         }
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 53;
        }
       }
      }
     } while(0);
     if ((label|0) == 21) {
      $45 = ___cxa_find_matching_catch(348288|0)|0;
      $46 = tempRet0;
      $47 = (_llvm_eh_typeid_for((348288|0))|0);
      $48 = ($46|0)==($47|0);
      if (!($48)) {
       $$02 = $45;$$03 = $46;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $49 = (___cxa_begin_catch(($45|0))|0);
      $50 = HEAP32[$49>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $__last_unhandled_exception$0 = $50;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,0,($32|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$0|0)==(53);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3838,($__last_unhandled_exception$0|0));
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2533856|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if (!($85)) {
     $86 = HEAP8[((2533856 + 116|0))>>0]|0;
     $87 = ($86<<24>>24)==(0);
     if ($87) {
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2533856|0))|0);
      $90 = __THREW__; __THREW__ = 0;
      $91 = $90&1;
      if ($91) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2533856|0));
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2533856|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if (!($95)) {
      $96 = HEAP32[((2533856 + 80|0))>>2]|0;
      $97 = (($96) + 24|0);
      $98 = HEAP32[$97>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($98|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$02 = $10;$$03 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Text_Latin1Encoding_m__ctorP35mscorlib_System_Text_Latin1Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2533992);
 __THREW__ = 0;
 invoke_vii(1909,($__this|0),28591);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62mscorlib_System_Text_UTF7Encoding_m__ctor_mscorlib_System_VoidP33mscorlib_System_Text_UTF7Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539496);
 __THREW__ = 0;
 invoke_vii(1914,($__this|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z86mscorlib_System_Text_UTF8Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP33mscorlib_System_Text_UTF8Encodingb($__this,$encoderShouldEmitUTF8Identifier) {
 $__this = $__this|0;
 $encoderShouldEmitUTF8Identifier = $encoderShouldEmitUTF8Identifier|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2541664);
 __THREW__ = 0;
 invoke_viii(636,($__this|0),($encoderShouldEmitUTF8Identifier|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z110mscorlib_System_Text_UTF8Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_BooleanP33mscorlib_System_Text_UTF8Encodingbb($__this,$encoderShouldEmitUTF8Identifier,$throwOnInvalidBytes) {
 $__this = $__this|0;
 $encoderShouldEmitUTF8Identifier = $encoderShouldEmitUTF8Identifier|0;
 $throwOnInvalidBytes = $throwOnInvalidBytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2541712);
 __THREW__ = 0;
 invoke_v(710);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1909,($__this|0),65001);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = (($__this) + 48|0);
    $5 = $encoderShouldEmitUTF8Identifier&1;
    HEAP8[$4>>0] = $5;
    if ($throwOnInvalidBytes) {
     __THREW__ = 0;
     $8 = (invoke_ii(2361,(0|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(632,($__this|0),(0|0),($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    } else {
     __THREW__ = 0;
     $13 = (invoke_ii(2363,(0|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(632,($__this|0),(0|0),($13|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
    }
    $18 = HEAP32[3058432>>2]|0;
    $19 = (($__this) + 36|0);
    HEAP32[$19>>2] = $18;
    $20 = (($__this) + 28|0);
    HEAP32[$20>>2] = $18;
    $21 = (($__this) + 44|0);
    HEAP32[$21>>2] = $18;
    $22 = HEAP32[3058440>>2]|0;
    $23 = (($__this) + 32|0);
    HEAP32[$23>>2] = $22;
    $24 = (($__this) + 40|0);
    $25 = (($__this) + 12|0);
    HEAP8[$24>>0]=16843009&255;HEAP8[$24+1>>0]=(16843009>>8)&255;HEAP8[$24+2>>0]=(16843009>>16)&255;HEAP8[$24+3>>0]=16843009>>24;
    HEAP32[$25>>2] = 1200;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z111mscorlib_System_Text_UTF32Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_BooleanP34mscorlib_System_Text_UTF32Encodingbb($__this,$bigEndian,$byteOrderMark) {
 $__this = $__this|0;
 $bigEndian = $bigEndian|0;
 $byteOrderMark = $byteOrderMark|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538024);
 __THREW__ = 0;
 invoke_viiii(173,($__this|0),($bigEndian|0),($byteOrderMark|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z118mscorlib_System_Text_Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P29mscorlib_System_Text_EncodingPti($__this,$chars,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$04 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2529920);
 __THREW__ = 0;
 invoke_v(711);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3055568>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($count|0)>(-1);
   if (!($17)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2561352|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3055576>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($20|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($20|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1168808|0))|0);
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if (!($29)) {
    __THREW__ = 0;
    $30 = (invoke_iii(2768,(1168808|0),($count|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if (!($32)) {
     $33 = ($count|0)>(0);
     L19: do {
      if ($33) {
       $34 = (($30) + 16|0);
       $35 = (($30) + 12|0);
       $V_1$04 = 0;
       while(1) {
        $51 = (($chars) + ($V_1$04<<1)|0);
        $48 = HEAP16[$51>>1]|0;
        __THREW__ = 0;
        invoke_vi(3799,($30|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
        $36 = HEAP32[$35>>2]|0;
        $37 = ($V_1$04>>>0)<($36>>>0);
        if (!($37)) {
         __THREW__ = 0;
         $38 = (invoke_i(132)|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($38|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break;
         }
        }
        $43 = HEAP32[$30>>2]|0;
        $44 = (($43) + 92|0);
        $45 = HEAP32[$44>>2]|0;
        $46 = Math_imul($45, $V_1$04)|0;
        $47 = (($34) + ($46)|0);
        HEAP16[$47>>1] = $48;
        $49 = (($V_1$04) + 1)|0;
        $50 = ($49|0)<($count|0);
        if ($50) {
         $V_1$04 = $49;
        } else {
         break L19;
        }
       }
       $3 = ___cxa_find_matching_catch()|0;
       $4 = tempRet0;
       $lpad$phi$index = $3;$lpad$phi$index2 = $4;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     } while(0);
     __THREW__ = 0;
     $54 = (invoke_iiii(1641,(2529968|0),($__this|0),($30|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($54|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z166mscorlib_System_Text_Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P29mscorlib_System_Text_EncodingPtiPhi($__this,$chars,$charCount,$bytes,$byteCount) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $V_1$015 = 0, $V_4$010 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2530112);
 __THREW__ = 0;
 invoke_v(712);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3055592>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($chars|0)==(0|0);
   if ($19) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3055600>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($charCount|0)>(-1);
   if (!($30)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __THREW__ = 0;
    $33 = (invoke_ii(3469,(2561352|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = HEAP32[3055608>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($33|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($33|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    // unreachable;
   }
   $41 = ($byteCount|0)>(-1);
   if (!($41)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     break;
    }
    __THREW__ = 0;
    $44 = (invoke_ii(3469,(2561352|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    $47 = HEAP32[3055616>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($44|0),($47|0));
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($44|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1168808|0))|0);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if (!($53)) {
    __THREW__ = 0;
    $54 = (invoke_iii(2768,(1168808|0),($charCount|0))|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     $57 = ($charCount|0)>(0);
     L33: do {
      if ($57) {
       $58 = (($54) + 16|0);
       $59 = (($54) + 12|0);
       $V_1$015 = 0;
       while(1) {
        $75 = (($chars) + ($V_1$015<<1)|0);
        $72 = HEAP16[$75>>1]|0;
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         break;
        }
        $60 = HEAP32[$59>>2]|0;
        $61 = ($V_1$015>>>0)<($60>>>0);
        if (!($61)) {
         __THREW__ = 0;
         $62 = (invoke_i(132)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($62|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          break;
         }
        }
        $67 = HEAP32[$54>>2]|0;
        $68 = (($67) + 92|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = Math_imul($69, $V_1$015)|0;
        $71 = (($58) + ($70)|0);
        HEAP16[$71>>1] = $72;
        $73 = (($V_1$015) + 1)|0;
        $74 = ($73|0)<($charCount|0);
        if ($74) {
         $V_1$015 = $73;
        } else {
         break L33;
        }
       }
       $5 = ___cxa_find_matching_catch()|0;
       $6 = tempRet0;
       $lpad$phi$index = $5;$lpad$phi$index3 = $6;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     } while(0);
     __THREW__ = 0;
     $78 = (invoke_iiiiii(239,(2530160|0),($__this|0),($54|0),0,($charCount|0))|0);
     $79 = __THREW__; __THREW__ = 0;
     $80 = $79&1;
     if (!($80)) {
      __THREW__ = 0;
      invoke_vi(3799,($78|0));
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if (!($82)) {
       $83 = (($78) + 12|0);
       $84 = HEAP32[$83>>2]|0;
       $85 = ($84|0)>($byteCount|0);
       if ($85) {
        __THREW__ = 0;
        (invoke_ii(2996,(2560072|0))|0);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         break;
        }
        __THREW__ = 0;
        $89 = (invoke_ii(3469,(2560072|0))|0);
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         break;
        }
        $92 = HEAP32[3055624>>2]|0;
        $93 = HEAP32[3055632>>2]|0;
        __THREW__ = 0;
        invoke_viii(641,($89|0),($92|0),($93|0));
        $94 = __THREW__; __THREW__ = 0;
        $95 = $94&1;
        if ($95) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3838,($89|0));
        $96 = __THREW__; __THREW__ = 0;
        $97 = $96&1;
        if ($97) {
         break;
        }
        // unreachable;
       }
       $86 = ($84|0)>(0);
       L54: do {
        if ($86) {
         $V_4$010 = 0;
         while(1) {
          $111 = (($bytes) + ($V_4$010)|0);
          __THREW__ = 0;
          invoke_vi(3799,($78|0));
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           break;
          }
          $98 = HEAP32[$83>>2]|0;
          $99 = ($V_4$010>>>0)<($98>>>0);
          if (!($99)) {
           __THREW__ = 0;
           $100 = (invoke_i(132)|0);
           $101 = __THREW__; __THREW__ = 0;
           $102 = $101&1;
           if ($102) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($100|0));
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            break;
           }
          }
          $105 = HEAP32[$78>>2]|0;
          $106 = (($105) + 92|0);
          $107 = HEAP32[$106>>2]|0;
          $108 = Math_imul($107, $V_4$010)|0;
          $$sum = (($108) + 16)|0;
          $109 = (($78) + ($$sum)|0);
          $110 = HEAP8[$109>>0]|0;
          HEAP8[$111>>0] = $110;
          $112 = (($V_4$010) + 1)|0;
          $113 = ($112|0)<($84|0);
          if ($113) {
           $V_4$010 = $112;
          } else {
           break L54;
          }
         }
         $3 = ___cxa_find_matching_catch()|0;
         $4 = tempRet0;
         $lpad$phi$index = $3;$lpad$phi$index3 = $4;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($78|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if (!($117)) {
        $118 = HEAP32[$83>>2]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($118|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z60mscorlib_System_Text_Encoding_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z179mscorlib_System_Text_Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z227mscorlib_System_Text_Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z125mscorlib_System_Text_Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_EncodingTraits_DecoderFallback_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z125mscorlib_System_Text_Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_EncodingTraits_EncoderFallback_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z145mscorlib_System_Text_Latin1Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Char_arrii($__this,$chars,$index,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534040);
 __THREW__ = 0;
 invoke_v(713);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3055792>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($chars) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($count|0);
      }
     }
     $41 = HEAP32[3055824>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3055816>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3055808>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3055800>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Text_Latin1Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP35mscorlib_System_Text_Latin1EncodingP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534088);
 __THREW__ = 0;
 invoke_v(714);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($s|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($17|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3055840>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3838,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z192mscorlib_System_Text_Latin1Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534136);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiiiiiiii(19,($__this|0),($chars|0),($charIndex|0),($charCount|0),($bytes|0),($byteIndex|0),($V_0|0),($V_1|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z284mscorlib_System_Text_Latin1Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Text_EncoderFallbackBufferU0026_ref_mscorlib_System_CharU005BU005DU0026_refP35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arriPP42mscorlib_System_Text_EncoderFallbackBufferPS2_($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex,$buffer,$fallback_chars) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $buffer = $buffer|0;
 $fallback_chars = $fallback_chars|0;
 var $$0 = 0, $$01$be = 0, $$0120 = 0, $$1$be = 0, $$121 = 0, $$in = 0, $$not = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534184);
 __THREW__ = 0;
 invoke_v(715);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3055856>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($bytes|0)==(0|0);
   if ($19) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3055864>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($charIndex|0)<(0);
   if (!($30)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    $33 = (($chars) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)<($charIndex|0);
    if (!($35)) {
     $50 = ($charCount|0)<(0);
     if (!($50)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = HEAP32[$33>>2]|0;
      $54 = (($53) - ($charIndex))|0;
      $55 = ($54|0)<($charCount|0);
      if (!($55)) {
       $70 = ($byteIndex|0)<(0);
       if (!($70)) {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         break;
        }
        $73 = (($bytes) + 12|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ($74|0)<($byteIndex|0);
        if (!($75)) {
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break;
         }
         $92 = HEAP32[$73>>2]|0;
         $93 = (($92) - ($byteIndex))|0;
         $94 = ($93|0)<($charCount|0);
         if ($94) {
          $98 = HEAP32[3055920>>2]|0;
          __THREW__ = 0;
          $99 = (invoke_iii(977,0,($98|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           break;
          }
          __THREW__ = 0;
          $104 = (invoke_ii(3469,(2560072|0))|0);
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1924,($104|0),($99|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if ($108) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3838,($104|0));
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           break;
          }
          // unreachable;
         }
         $95 = ($charCount|0)>(0);
         if (!($95)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($charCount|0);
         }
         $96 = (($chars) + 16|0);
         $97 = (($bytes) + 16|0);
         $$0120 = $byteIndex;$$121 = $charIndex;$$in = $charCount;
         L41: while(1) {
          $145 = (($$in) + -1)|0;
          $182 = (($$121) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $287 = __THREW__; __THREW__ = 0;
          $288 = $287&1;
          if ($288) {
           label = 4;
           break;
          }
          $111 = ($$121|0)<(0);
          if ($111) {
           label = 57;
          } else {
           $112 = HEAP32[$33>>2]|0;
           $113 = ($$121>>>0)<($112>>>0);
           if (!($113)) {
            label = 57;
           }
          }
          if ((label|0) == 57) {
           label = 0;
           __THREW__ = 0;
           $114 = (invoke_i(132)|0);
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($114|0));
           $117 = __THREW__; __THREW__ = 0;
           $118 = $117&1;
           if ($118) {
            label = 4;
            break;
           }
          }
          $119 = HEAP32[$chars>>2]|0;
          $120 = (($119) + 92|0);
          $121 = HEAP32[$120>>2]|0;
          $122 = Math_imul($121, $$121)|0;
          $123 = (($96) + ($122)|0);
          $124 = HEAP16[$123>>1]|0;
          $125 = $124&65535;
          $126 = ($124&65535)>(255);
          do {
           if ($126) {
            $$off = (($124) + 255)<<16>>16;
            $146 = ($$off&65535)>(93);
            if (!($146)) {
             $147 = (($$0120) + 1)|0;
             $148 = (($125) + 32)|0;
             $149 = $148&255;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $150 = __THREW__; __THREW__ = 0;
             $151 = $150&1;
             if ($151) {
              label = 4;
              break L41;
             }
             $152 = ($$0120|0)<(0);
             if ($152) {
              label = 71;
             } else {
              $153 = HEAP32[$73>>2]|0;
              $154 = ($$0120>>>0)<($153>>>0);
              if (!($154)) {
               label = 71;
              }
             }
             if ((label|0) == 71) {
              label = 0;
              __THREW__ = 0;
              $155 = (invoke_i(132)|0);
              $156 = __THREW__; __THREW__ = 0;
              $157 = $156&1;
              if ($157) {
               label = 4;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($155|0));
              $158 = __THREW__; __THREW__ = 0;
              $159 = $158&1;
              if ($159) {
               label = 4;
               break L41;
              }
             }
             $160 = HEAP32[$bytes>>2]|0;
             $161 = (($160) + 92|0);
             $162 = HEAP32[$161>>2]|0;
             $163 = Math_imul($162, $$0120)|0;
             $164 = (($97) + ($163)|0);
             HEAP8[$164>>0] = $149;
             $$01$be = $147;$$1$be = $182;
             break;
            }
            $165 = HEAP32[$buffer>>2]|0;
            $166 = ($165|0)==(0|0);
            if ($166) {
             __THREW__ = 0;
             $167 = (invoke_ii(2382,($__this|0))|0);
             $168 = __THREW__; __THREW__ = 0;
             $169 = $168&1;
             if ($169) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             invoke_vi(3799,($167|0));
             $170 = __THREW__; __THREW__ = 0;
             $171 = $170&1;
             if ($171) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             $172 = (invoke_iii(2730,(2526744|0),($167|0))|0);
             $173 = __THREW__; __THREW__ = 0;
             $174 = $173&1;
             if ($174) {
              label = 4;
              break L41;
             }
             HEAP32[$buffer>>2] = $172;
            }
            __THREW__ = 0;
            $175 = (invoke_iii(603,(0|0),($124|0))|0);
            $176 = __THREW__; __THREW__ = 0;
            $177 = $176&1;
            if ($177) {
             label = 4;
             break L41;
            }
            $$not = $175 ^ 1;
            $178 = ($$in|0)<(3);
            $or$cond3 = $178 | $$not;
            do {
             if ($or$cond3) {
              label = 95;
             } else {
              __THREW__ = 0;
              invoke_vi(3799,($chars|0));
              $179 = __THREW__; __THREW__ = 0;
              $180 = $179&1;
              if ($180) {
               label = 4;
               break L41;
              }
              $181 = ($182|0)<(0);
              if ($181) {
               label = 84;
              } else {
               $183 = HEAP32[$33>>2]|0;
               $184 = ($182>>>0)<($183>>>0);
               if (!($184)) {
                label = 84;
               }
              }
              if ((label|0) == 84) {
               label = 0;
               __THREW__ = 0;
               $185 = (invoke_i(132)|0);
               $186 = __THREW__; __THREW__ = 0;
               $187 = $186&1;
               if ($187) {
                label = 4;
                break L41;
               }
               __THREW__ = 0;
               invoke_vi(3302,($185|0));
               $188 = __THREW__; __THREW__ = 0;
               $189 = $188&1;
               if ($189) {
                label = 4;
                break L41;
               }
              }
              $190 = HEAP32[$chars>>2]|0;
              $191 = (($190) + 92|0);
              $192 = HEAP32[$191>>2]|0;
              $193 = Math_imul($192, $182)|0;
              $194 = (($96) + ($193)|0);
              $195 = HEAP16[$194>>1]|0;
              __THREW__ = 0;
              $196 = (invoke_iii(603,(0|0),($195|0))|0);
              $197 = __THREW__; __THREW__ = 0;
              $198 = $197&1;
              if ($198) {
               label = 4;
               break L41;
              }
              if (!($196)) {
               label = 95;
               break;
              }
              $199 = HEAP32[$buffer>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($chars|0));
              $200 = __THREW__; __THREW__ = 0;
              $201 = $200&1;
              if ($201) {
               label = 4;
               break L41;
              }
              if ($181) {
               label = 91;
              } else {
               $202 = HEAP32[$33>>2]|0;
               $203 = ($182>>>0)<($202>>>0);
               if (!($203)) {
                label = 91;
               }
              }
              if ((label|0) == 91) {
               label = 0;
               __THREW__ = 0;
               $204 = (invoke_i(132)|0);
               $205 = __THREW__; __THREW__ = 0;
               $206 = $205&1;
               if ($206) {
                label = 4;
                break L41;
               }
               __THREW__ = 0;
               invoke_vi(3302,($204|0));
               $207 = __THREW__; __THREW__ = 0;
               $208 = $207&1;
               if ($208) {
                label = 4;
                break L41;
               }
              }
              $209 = HEAP32[$chars>>2]|0;
              $210 = (($209) + 92|0);
              $211 = HEAP32[$210>>2]|0;
              $212 = Math_imul($211, $182)|0;
              $213 = (($96) + ($212)|0);
              $214 = HEAP16[$213>>1]|0;
              __THREW__ = 0;
              invoke_vi(3799,($199|0));
              $215 = __THREW__; __THREW__ = 0;
              $216 = $215&1;
              if ($216) {
               label = 4;
               break L41;
              }
              $217 = (($$121) + 2)|0;
              __THREW__ = 0;
              (invoke_iiiiii(237,(2527240|0),($199|0),($124|0),($214|0),($$121|0))|0);
              $218 = __THREW__; __THREW__ = 0;
              $219 = $218&1;
              if ($219) {
               label = 4;
               break L41;
              } else {
               $$0 = $217;
              }
             }
            } while(0);
            if ((label|0) == 95) {
             label = 0;
             $220 = HEAP32[$buffer>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($220|0));
             $221 = __THREW__; __THREW__ = 0;
             $222 = $221&1;
             if ($222) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             (invoke_iiiii(324,(2527152|0),($220|0),($124|0),($$121|0))|0);
             $223 = __THREW__; __THREW__ = 0;
             $224 = $223&1;
             if ($224) {
              label = 4;
              break L41;
             } else {
              $$0 = $182;
             }
            }
            $225 = HEAP32[$fallback_chars>>2]|0;
            $226 = ($225|0)==(0|0);
            if ($226) {
             label = 102;
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($225|0));
             $227 = __THREW__; __THREW__ = 0;
             $228 = $227&1;
             if ($228) {
              label = 4;
              break L41;
             }
             $229 = (($225) + 12|0);
             $230 = HEAP32[$229>>2]|0;
             $231 = HEAP32[$buffer>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($231|0));
             $232 = __THREW__; __THREW__ = 0;
             $233 = $232&1;
             if ($233) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             $234 = (invoke_iii(2729,(2527080|0),($231|0))|0);
             $235 = __THREW__; __THREW__ = 0;
             $236 = $235&1;
             if ($236) {
              label = 4;
              break L41;
             }
             $237 = ($230|0)<($234|0);
             if ($237) {
              label = 102;
             } else {
              $V_2$0 = 0;
             }
            }
            if ((label|0) == 102) {
             label = 0;
             $238 = HEAP32[$buffer>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($238|0));
             $239 = __THREW__; __THREW__ = 0;
             $240 = $239&1;
             if ($240) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             $241 = (invoke_iii(2729,(2527080|0),($238|0))|0);
             $242 = __THREW__; __THREW__ = 0;
             $243 = $242&1;
             if ($243) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(1168808|0))|0);
             $244 = __THREW__; __THREW__ = 0;
             $245 = $244&1;
             if ($245) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             $246 = (invoke_iii(2768,(1168808|0),($241|0))|0);
             $247 = __THREW__; __THREW__ = 0;
             $248 = $247&1;
             if ($248) {
              label = 4;
              break L41;
             }
             HEAP32[$fallback_chars>>2] = $246;
             $V_2$0 = 0;
            }
            while(1) {
             $271 = HEAP32[$fallback_chars>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($271|0));
             $272 = __THREW__; __THREW__ = 0;
             $273 = $272&1;
             if ($273) {
              label = 3;
              break L41;
             }
             $274 = (($271) + 12|0);
             $275 = HEAP32[$274>>2]|0;
             $276 = ($V_2$0|0)<($275|0);
             $253 = HEAP32[$fallback_chars>>2]|0;
             if (!($276)) {
              break;
             }
             $249 = HEAP32[$buffer>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($249|0));
             $277 = __THREW__; __THREW__ = 0;
             $278 = $277&1;
             if ($278) {
              label = 3;
              break L41;
             }
             __THREW__ = 0;
             $250 = (invoke_iii(2767,(2527288|0),($249|0))|0);
             $251 = __THREW__; __THREW__ = 0;
             $252 = $251&1;
             if ($252) {
              label = 3;
              break L41;
             }
             __THREW__ = 0;
             invoke_vi(3799,($253|0));
             $254 = __THREW__; __THREW__ = 0;
             $255 = $254&1;
             if ($255) {
              label = 3;
              break L41;
             }
             $256 = (($253) + 12|0);
             $257 = HEAP32[$256>>2]|0;
             $258 = ($V_2$0>>>0)<($257>>>0);
             if (!($258)) {
              __THREW__ = 0;
              $259 = (invoke_i(132)|0);
              $260 = __THREW__; __THREW__ = 0;
              $261 = $260&1;
              if ($261) {
               label = 3;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($259|0));
              $262 = __THREW__; __THREW__ = 0;
              $263 = $262&1;
              if ($263) {
               label = 3;
               break L41;
              }
             }
             $264 = HEAP32[$253>>2]|0;
             $265 = (($253) + 16|0);
             $266 = (($264) + 92|0);
             $267 = HEAP32[$266>>2]|0;
             $268 = Math_imul($267, $V_2$0)|0;
             $269 = (($265) + ($268)|0);
             HEAP16[$269>>1] = $250;
             $270 = (($V_2$0) + 1)|0;
             $V_2$0 = $270;
            }
            __THREW__ = 0;
            invoke_vi(3799,($253|0));
            $279 = __THREW__; __THREW__ = 0;
            $280 = $279&1;
            if ($280) {
             label = 4;
             break L41;
            }
            $281 = (($253) + 12|0);
            $282 = HEAP32[$281>>2]|0;
            __THREW__ = 0;
            $283 = (invoke_iiiiiiiii(19,($__this|0),($253|0),0,($282|0),($bytes|0),($$0120|0),($buffer|0),($fallback_chars|0))|0);
            $284 = __THREW__; __THREW__ = 0;
            $285 = $284&1;
            if ($285) {
             label = 4;
             break L41;
            }
            $286 = (($283) + ($$0120))|0;
            $$01$be = $286;$$1$be = $$0;
           } else {
            $127 = (($$0120) + 1)|0;
            $128 = $124&255;
            __THREW__ = 0;
            invoke_vi(3799,($bytes|0));
            $129 = __THREW__; __THREW__ = 0;
            $130 = $129&1;
            if ($130) {
             label = 4;
             break L41;
            }
            $131 = ($$0120|0)<(0);
            if ($131) {
             label = 63;
            } else {
             $132 = HEAP32[$73>>2]|0;
             $133 = ($$0120>>>0)<($132>>>0);
             if (!($133)) {
              label = 63;
             }
            }
            if ((label|0) == 63) {
             label = 0;
             __THREW__ = 0;
             $134 = (invoke_i(132)|0);
             $135 = __THREW__; __THREW__ = 0;
             $136 = $135&1;
             if ($136) {
              label = 4;
              break L41;
             }
             __THREW__ = 0;
             invoke_vi(3302,($134|0));
             $137 = __THREW__; __THREW__ = 0;
             $138 = $137&1;
             if ($138) {
              label = 4;
              break L41;
             }
            }
            $139 = HEAP32[$bytes>>2]|0;
            $140 = (($139) + 92|0);
            $141 = HEAP32[$140>>2]|0;
            $142 = Math_imul($141, $$0120)|0;
            $143 = (($97) + ($142)|0);
            HEAP8[$143>>0] = $128;
            $$01$be = $127;$$1$be = $182;
           }
          } while(0);
          $144 = ($145|0)>(0);
          if ($144) {
           $$0120 = $$01$be;$$121 = $$1$be;$$in = $145;
          } else {
           label = 120;
           break;
          }
         }
         if ((label|0) == 3) {
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index3 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 4) {
          $5 = ___cxa_find_matching_catch()|0;
          $6 = tempRet0;
          $lpad$phi$index = $5;$lpad$phi$index3 = $6;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 120) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($charCount|0);
         }
        }
       }
       $76 = HEAP32[3055912>>2]|0;
       __THREW__ = 0;
       $77 = (invoke_iii(977,0,($76|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
       __THREW__ = 0;
       $82 = (invoke_ii(3469,(2561352|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        break;
       }
       $85 = HEAP32[3055904>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($82|0),($85|0),($77|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($82|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       // unreachable;
      }
     }
     $56 = HEAP32[3055896>>2]|0;
     __THREW__ = 0;
     $57 = (invoke_iii(977,0,($56|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     $62 = (invoke_ii(3469,(2561352|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      break;
     }
     $65 = HEAP32[3055888>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($62|0),($65|0),($57|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($62|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     // unreachable;
    }
   }
   $36 = HEAP32[3055880>>2]|0;
   __THREW__ = 0;
   $37 = (invoke_iii(977,0,($36|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if (!($41)) {
     __THREW__ = 0;
     $42 = (invoke_ii(3469,(2561352|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      $45 = HEAP32[3055872>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($42|0),($45|0),($37|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       invoke_vi(3838,($42|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Text_Latin1Encoding_m_GetCharCountP35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534232);
 __THREW__ = 0;
 invoke_v(716);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3055936>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($bytes) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($count|0);
      }
     }
     $41 = HEAP32[3055968>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3055960>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3055952>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3055944>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Text_Latin1Encoding_m_GetCharsP35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 var $$0112 = 0, $$013 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534280);
 __THREW__ = 0;
 invoke_v(717);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3055984>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($chars|0)==(0|0);
   if ($17) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(3469,(2560584|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP32[3055992>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($20|0),($23|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($20|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
   $28 = ($byteIndex|0)<(0);
   if (!($28)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    $31 = (($bytes) + 12|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)<($byteIndex|0);
    if (!($33)) {
     $48 = ($byteCount|0)<(0);
     if (!($48)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = HEAP32[$31>>2]|0;
      $52 = (($51) - ($byteIndex))|0;
      $53 = ($52|0)<($byteCount|0);
      if (!($53)) {
       $68 = ($charIndex|0)<(0);
       if (!($68)) {
        __THREW__ = 0;
        invoke_vi(3799,($chars|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
        $71 = (($chars) + 12|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = ($72|0)<($charIndex|0);
        if (!($73)) {
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $88 = __THREW__; __THREW__ = 0;
         $89 = $88&1;
         if ($89) {
          break;
         }
         $90 = HEAP32[$71>>2]|0;
         $91 = (($90) - ($charIndex))|0;
         $92 = ($91|0)<($byteCount|0);
         if ($92) {
          $96 = HEAP32[3056048>>2]|0;
          __THREW__ = 0;
          $97 = (invoke_iii(977,0,($96|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          __THREW__ = 0;
          $102 = (invoke_ii(3469,(2560072|0))|0);
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1924,($102|0),($97|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3838,($102|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if ($108) {
           break;
          }
          // unreachable;
         }
         $93 = ($byteCount|0)>(0);
         if (!($93)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($byteCount|0);
         }
         $94 = (($bytes) + 16|0);
         $95 = (($chars) + 16|0);
         $$0112 = $charIndex;$$013 = $byteIndex;$$in = $byteCount;
         while(1) {
          $140 = (($$in) + -1)|0;
          $141 = (($$0112) + 1)|0;
          $142 = (($$013) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($bytes|0));
          $143 = __THREW__; __THREW__ = 0;
          $144 = $143&1;
          if ($144) {
           break;
          }
          $109 = ($$013|0)<(0);
          if ($109) {
           label = 56;
          } else {
           $110 = HEAP32[$31>>2]|0;
           $111 = ($$013>>>0)<($110>>>0);
           if (!($111)) {
            label = 56;
           }
          }
          if ((label|0) == 56) {
           label = 0;
           __THREW__ = 0;
           $112 = (invoke_i(132)|0);
           $113 = __THREW__; __THREW__ = 0;
           $114 = $113&1;
           if ($114) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($112|0));
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            break;
           }
          }
          $117 = HEAP32[$bytes>>2]|0;
          $118 = (($117) + 92|0);
          $119 = HEAP32[$118>>2]|0;
          $120 = Math_imul($119, $$013)|0;
          $121 = (($94) + ($120)|0);
          $122 = HEAP8[$121>>0]|0;
          $123 = $122&255;
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $124 = __THREW__; __THREW__ = 0;
          $125 = $124&1;
          if ($125) {
           break;
          }
          $126 = ($$0112|0)<(0);
          if ($126) {
           label = 61;
          } else {
           $127 = HEAP32[$71>>2]|0;
           $128 = ($$0112>>>0)<($127>>>0);
           if (!($128)) {
            label = 61;
           }
          }
          if ((label|0) == 61) {
           label = 0;
           __THREW__ = 0;
           $129 = (invoke_i(132)|0);
           $130 = __THREW__; __THREW__ = 0;
           $131 = $130&1;
           if ($131) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($129|0));
           $132 = __THREW__; __THREW__ = 0;
           $133 = $132&1;
           if ($133) {
            break;
           }
          }
          $134 = HEAP32[$chars>>2]|0;
          $135 = (($134) + 92|0);
          $136 = HEAP32[$135>>2]|0;
          $137 = Math_imul($136, $$0112)|0;
          $138 = (($95) + ($137)|0);
          HEAP16[$138>>1] = $123;
          $139 = ($140|0)>(0);
          if ($139) {
           $$0112 = $141;$$013 = $142;$$in = $140;
          } else {
           label = 65;
           break;
          }
         }
         if ((label|0) == 65) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($byteCount|0);
         }
         $3 = ___cxa_find_matching_catch()|0;
         $4 = tempRet0;
         $lpad$phi$index = $3;$lpad$phi$index2 = $4;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
       }
       $74 = HEAP32[3056040>>2]|0;
       __THREW__ = 0;
       $75 = (invoke_iii(977,0,($74|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
       __THREW__ = 0;
       $80 = (invoke_ii(3469,(2561352|0))|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        break;
       }
       $83 = HEAP32[3056032>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($80|0),($83|0),($75|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($80|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       }
       // unreachable;
      }
     }
     $54 = HEAP32[3056024>>2]|0;
     __THREW__ = 0;
     $55 = (invoke_iii(977,0,($54|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     __THREW__ = 0;
     $60 = (invoke_ii(3469,(2561352|0))|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      break;
     }
     $63 = HEAP32[3056016>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($60|0),($63|0),($55|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($60|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     // unreachable;
    }
   }
   $34 = HEAP32[3056008>>2]|0;
   __THREW__ = 0;
   $35 = (invoke_iii(977,0,($34|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if (!($37)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     __THREW__ = 0;
     $40 = (invoke_ii(3469,(2561352|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      $43 = HEAP32[3056000>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($40|0),($43|0),($35|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       __THREW__ = 0;
       invoke_vi(3838,($40|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z143mscorlib_System_Text_Latin1Encoding_m_GetString_mscorlib_System_String_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $G_B14_0$0 = 0, $V_3$010 = 0, $V_5$09 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534328);
 __THREW__ = 0;
 invoke_v(718);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3056064>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($bytes) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       $55 = ($count|0)==(0);
       if ($55) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
        $58 = HEAP8[((2191608 + 116|0))>>0]|0;
        $59 = ($58<<24>>24)==(0);
        if ($59) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3839,(2191608|0));
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
        $68 = HEAP32[((2191608 + 80|0))>>2]|0;
        $69 = HEAP32[$68>>2]|0;
        $$0 = $69;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($bytes|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break;
       }
       $72 = HEAP32[$18>>2]|0;
       $73 = ($72|0)==(0);
       if ($73) {
        $G_B14_0$0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        $76 = HEAP32[$18>>2]|0;
        $77 = ($76|0)==(0);
        if ($77) {
         __THREW__ = 0;
         $78 = (invoke_i(132)|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($78|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          break;
         }
        }
        $83 = (($bytes) + 16|0);
        $G_B14_0$0 = $83;
       }
       __THREW__ = 0;
       $84 = (invoke_iii(643,(0|0),($count|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       __THREW__ = 0;
       $87 = (invoke_ii(1919,(0|0))|0);
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       $$sum = (($count) + ($index))|0;
       $90 = (($G_B14_0$0) + ($$sum)|0);
       $91 = ($$sum|0)>($index|0);
       if (!($91)) {
        $$0 = $84;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $92 = $84;
       $93 = (($87) + ($92))|0;
       $94 = (($G_B14_0$0) + ($index)|0);
       $95 = $93;
       $V_3$010 = $94;$V_5$09 = $95;
       while(1) {
        $96 = (($V_5$09) + 2|0);
        $97 = (($V_3$010) + 1|0);
        $98 = HEAP8[$V_3$010>>0]|0;
        $99 = $98&255;
        HEAP16[$V_5$09>>1] = $99;
        $100 = ($97>>>0)<($90>>>0);
        if ($100) {
         $V_3$010 = $97;$V_5$09 = $96;
        } else {
         $$0 = $84;
         break;
        }
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     $41 = HEAP32[3056096>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3056088>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3056080>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3056072>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Text_Latin1Encoding_m_GetString_mscorlib_System_String_mscorlib_System_Byte_arr_arrP35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Byte_arr($__this,$bytes) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534376);
 __THREW__ = 0;
 invoke_v(719);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($bytes) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iiiiii(239,(2534328|0),($__this|0),($bytes|0),0,($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3056112>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3838,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Text_Latin1Encoding_m_get_WebNameP35mscorlib_System_Text_Latin1Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2534424);
 __THREW__ = 0;
 invoke_v(720);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP32[3055752>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z152mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderP22mscorlib_System_Stringiii($__this,$value,$startIndex,$length,$capacity) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535144);
 __THREW__ = 0;
 invoke_viiiiii(64,($__this|0),($value|0),($startIndex|0),($length|0),($capacity|0),2147483647);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z174mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderP22mscorlib_System_Stringiiii($__this,$value,$startIndex,$length,$capacity,$maxCapacity) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 $capacity = $capacity|0;
 $maxCapacity = $maxCapacity|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_10 = 0, $L_18 = 0, $L_2 = 0, $L_6 = 0, $_stackTraceSentry = 0, $length$$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_2 = sp;
 $L_6 = sp + 4|0;
 $L_10 = sp + 8|0;
 $L_18 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535192);
 __THREW__ = 0;
 invoke_v(721);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($value|0)==(0|0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     $9 = HEAP8[((2191608 + 116|0))>>0]|0;
     $10 = ($9<<24>>24)==(0);
     if ($10) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2191608|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     $19 = HEAP32[((2191608 + 80|0))>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     $$0 = $20;
    } else {
     $$0 = $value;
    }
    $21 = ($startIndex|0)>(-1);
    if (!($21)) {
     HEAP32[$L_2>>2] = $startIndex;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __THREW__ = 0;
     $24 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     $29 = (invoke_ii(3469,(2561352|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     $32 = HEAP32[3056128>>2]|0;
     $33 = HEAP32[3056136>>2]|0;
     __THREW__ = 0;
     invoke_viiii(176,($29|0),($32|0),($24|0),($33|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($29|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
     // unreachable;
    }
    $38 = ($length|0)>(-1);
    if (!($38)) {
     HEAP32[$L_6>>2] = $length;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     __THREW__ = 0;
     $41 = (invoke_iii(2724,(2155952|0),($L_6|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
     __THREW__ = 0;
     $46 = (invoke_ii(3469,(2561352|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     $49 = HEAP32[3056144>>2]|0;
     $50 = HEAP32[3056152>>2]|0;
     __THREW__ = 0;
     invoke_viiii(176,($46|0),($49|0),($41|0),($50|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($46|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
    $55 = ($capacity|0)>(-1);
    if (!($55)) {
     HEAP32[$L_10>>2] = $capacity;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     __THREW__ = 0;
     $58 = (invoke_iii(2724,(2155952|0),($L_10|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if ($62) {
      break;
     }
     __THREW__ = 0;
     $63 = (invoke_ii(3469,(2561352|0))|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     $66 = HEAP32[3056160>>2]|0;
     $67 = HEAP32[3056168>>2]|0;
     __THREW__ = 0;
     invoke_viiii(176,($63|0),($66|0),($58|0),($67|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($63|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     }
     // unreachable;
    }
    $72 = ($maxCapacity|0)>(0);
    if (!($72)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      break;
     }
     __THREW__ = 0;
     $75 = (invoke_ii(3469,(2561352|0))|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break;
     }
     $78 = HEAP32[3056176>>2]|0;
     $79 = HEAP32[3056184>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($75|0),($78|0),($79|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($75|0));
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if ($83) {
      break;
     }
     // unreachable;
    }
    $84 = ($capacity|0)>($maxCapacity|0);
    if ($84) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      break;
     }
     __THREW__ = 0;
     $87 = (invoke_ii(3469,(2561352|0))|0);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      break;
     }
     $90 = HEAP32[3056192>>2]|0;
     $91 = HEAP32[3056200>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($87|0),($90|0),($91|0));
     $92 = __THREW__; __THREW__ = 0;
     $93 = $92&1;
     if ($93) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($87|0));
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    invoke_vi(3799,($$0|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if (!($97)) {
     __THREW__ = 0;
     $98 = (invoke_ii(1816,($$0|0))|0);
     $99 = __THREW__; __THREW__ = 0;
     $100 = $99&1;
     if (!($100)) {
      $101 = (($98) - ($length))|0;
      $102 = ($101|0)<($startIndex|0);
      if ($102) {
       HEAP32[$L_18>>2] = $startIndex;
       __THREW__ = 0;
       (invoke_ii(2996,(2155952|0))|0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        break;
       }
       __THREW__ = 0;
       $105 = (invoke_iii(2724,(2155952|0),($L_18|0))|0);
       $106 = __THREW__; __THREW__ = 0;
       $107 = $106&1;
       if ($107) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $108 = __THREW__; __THREW__ = 0;
       $109 = $108&1;
       if ($109) {
        break;
       }
       __THREW__ = 0;
       $110 = (invoke_ii(3469,(2561352|0))|0);
       $111 = __THREW__; __THREW__ = 0;
       $112 = $111&1;
       if ($112) {
        break;
       }
       $113 = HEAP32[3056208>>2]|0;
       $114 = HEAP32[3056216>>2]|0;
       __THREW__ = 0;
       invoke_viiii(176,($110|0),($113|0),($105|0),($114|0));
       $115 = __THREW__; __THREW__ = 0;
       $116 = $115&1;
       if ($116) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($110|0));
       $117 = __THREW__; __THREW__ = 0;
       $118 = $117&1;
       if ($118) {
        break;
       }
       // unreachable;
      }
      $119 = ($capacity|0)==(0);
      if ($119) {
       $120 = ($maxCapacity|0)<(17);
       if ($120) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $121 = __THREW__; __THREW__ = 0;
        $122 = $121&1;
        if ($122) {
         break;
        }
        $123 = HEAP8[((2191608 + 116|0))>>0]|0;
        $124 = ($123<<24>>24)==(0);
        if ($124) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $125 = __THREW__; __THREW__ = 0;
         $126 = $125&1;
         if ($126) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3839,(2191608|0));
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if ($132) {
         break;
        }
        $133 = HEAP32[((2191608 + 80|0))>>2]|0;
        $134 = HEAP32[$133>>2]|0;
        $135 = (($__this) + 16|0);
        HEAP32[$135>>2] = $134;
        $136 = (($__this) + 12|0);
        HEAP32[$136>>2] = $134;
        $$01 = 0;
       } else {
        $$01 = 16;
       }
      } else {
       $$01 = $capacity;
      }
      $137 = (($__this) + 20|0);
      HEAP32[$137>>2] = $maxCapacity;
      $138 = (($__this) + 12|0);
      $139 = HEAP32[$138>>2]|0;
      $140 = ($139|0)==(0|0);
      if ($140) {
       $141 = ($$01|0)<($length|0);
       $length$$01 = $141 ? $length : $$01;
       __THREW__ = 0;
       $142 = (invoke_iii(643,(0|0),($length$$01|0))|0);
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $145 = __THREW__; __THREW__ = 0;
       $146 = $145&1;
       if ($146) {
        break;
       }
       HEAP32[$138>>2] = $142;
       $148 = $142;
      } else {
       $148 = $139;
      }
      $147 = ($length|0)<(1);
      if ($147) {
       $151 = (($__this) + 8|0);
       HEAP32[$151>>2] = $length;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_viiiiii(51,(0|0),($148|0),0,($$0|0),($startIndex|0),($length|0));
      $149 = __THREW__; __THREW__ = 0;
      $150 = $149&1;
      if (!($150)) {
       $151 = (($__this) + 8|0);
       HEAP32[$151>>2] = $length;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z141mscorlib_System_ArgumentOutOfRangeException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_StringP43mscorlib_System_ArgumentOutOfRangeExceptionP22mscorlib_System_StringP22mscorlib_System_ObjectS2_($__this,$paramName,$actualValue,$message) {
 $__this = $__this|0;
 $paramName = $paramName|0;
 $actualValue = $actualValue|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560864);
 __THREW__ = 0;
 invoke_viii(641,($__this|0),($message|0),($paramName|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 56|0);
  HEAP32[$2>>2] = $actualValue;
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233086);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z63mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_VoidP34mscorlib_System_Text_StringBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535240);
 __THREW__ = 0;
 invoke_vii(1911,($__this|0),(0|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z86mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_Void_mscorlib_System_StringP34mscorlib_System_Text_StringBuilderP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535336);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    $7 = HEAP8[((2191608 + 116|0))>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2191608|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = HEAP32[((2191608 + 80|0))>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $$0 = $18;
   } else {
    $$0 = $value;
   }
   __THREW__ = 0;
   invoke_vi(3799,($$0|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_ii(1816,($$0|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = (($__this) + 8|0);
     HEAP32[$24>>2] = $21;
     $25 = (($__this) + 16|0);
     HEAP32[$25>>2] = $$0;
     $26 = (($__this) + 12|0);
     HEAP32[$26>>2] = $$0;
     $27 = (($__this) + 20|0);
     HEAP32[$27>>2] = 2147483647;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z85mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderi($__this,$capacity) {
 $__this = $__this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535288);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_viiiii(70,($__this|0),($15|0),0,0,($capacity|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z93mscorlib_System_Text_StringBuilder_m_System_Runtime_Serialization_ISerializable_GetObjectDataP34mscorlib_System_Text_StringBuilderP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535384);
 __THREW__ = 0;
 invoke_v(722);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($info|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[3056736>>2]|0;
   __THREW__ = 0;
   invoke_viii(618,($info|0),($6|0),($3|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(2397,($__this|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = HEAP32[3056744>>2]|0;
      __THREW__ = 0;
      invoke_viii(618,($info|0),($14|0),($9|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2730,(2535432|0),($__this|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         $22 = HEAP32[3056752>>2]|0;
         __THREW__ = 0;
         invoke_viii(621,($info|0),($22|0),($17|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          invoke_vi(3799,($info|0));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           $27 = HEAP32[3056760>>2]|0;
           __THREW__ = 0;
           invoke_viii(618,($info|0),($27|0),0);
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($30|0);
 // unreachable;
}
function __Z49mscorlib_System_Text_StringBuilder_m_get_CapacityP34mscorlib_System_Text_StringBuilder($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535480);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(1816,($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0);
    if ($7) {
     $10 = (($__this) + 20|0);
     $11 = HEAP32[$10>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iiii(1198,0,($11|0),16)|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     } else {
      $$0 = $12;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $15 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     $18 = (invoke_ii(1816,($15|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $$0 = $18;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z26mscorlib_System_Math_m_MinP22mscorlib_System_Objectii($__this,$val1,$val2) {
 $__this = $__this|0;
 $val1 = $val1|0;
 $val2 = $val2|0;
 var $0 = 0, $_stackTraceSentry = 0, $val1$val2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2608976);
 $0 = ($val1|0)<($val2|0);
 $val1$val2 = $0 ? $val1 : $val2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($val1$val2|0);
}
function __Z47mscorlib_System_Text_StringBuilder_m_get_LengthP34mscorlib_System_Text_StringBuilder($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535528);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z47mscorlib_System_Text_StringBuilder_m_set_LengthP34mscorlib_System_Text_StringBuilderi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535576);
 $0 = ($value|0)<(0);
 do {
  if ($0) {
   label = 3;
  } else {
   $1 = (($__this) + 20|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = ($2|0)<($value|0);
   if ($3) {
    label = 3;
   } else {
    $15 = (($__this) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($value|0);
    if ($17) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $18 = ($16|0)>($value|0);
    if (!($18)) {
     $21 = (($value) - ($16))|0;
     __THREW__ = 0;
     (invoke_iiii(932,($__this|0),0,($21|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vii(1913,($__this|0),($value|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     HEAP32[$15>>2] = $value;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2561352|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(2587,($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3838,($6|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      // unreachable;
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z72mscorlib_System_ArgumentOutOfRangeException_m__ctor_mscorlib_System_VoidP43mscorlib_System_ArgumentOutOfRangeException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560720);
 __THREW__ = 0;
 invoke_v(723);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3060496>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1924,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233086);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z59mscorlib_System_Text_StringBuilder_m_InternalEnsureCapacityP34mscorlib_System_Text_StringBuilderi($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var $$op = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0$2 = 0, $V_0$3 = 0, $V_0$4 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, $size$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536488);
 __THREW__ = 0;
 invoke_v(724);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_ii(1816,($3|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = ($6|0)<($size|0);
     if ($9) {
      $$pre = HEAP32[$2>>2]|0;
      $16 = $$pre;
     } else {
      $12 = (($__this) + 16|0);
      $13 = HEAP32[$12>>2]|0;
      $14 = HEAP32[$2>>2]|0;
      $15 = ($13|0)==($14|0);
      if ($15) {
       $16 = $13;
      } else {
       $$pre$phiZ2D = $12;
       HEAP32[$$pre$phiZ2D>>2] = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
     __THREW__ = 0;
     invoke_vi(3799,($16|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      $19 = (invoke_ii(1816,($16|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = ($19|0)<($size|0);
       if ($22) {
        $23 = (($__this) + 16|0);
        $24 = HEAP32[$23>>2]|0;
        $25 = HEAP32[$2>>2]|0;
        $26 = ($24|0)!=($25|0);
        $27 = ($19|0)>(15);
        $or$cond = $26 | $27;
        $$op = $19 << 1;
        $28 = $or$cond ? $$op : 32;
        $29 = ($28|0)<($size|0);
        $size$ = $29 ? $size : $28;
        $30 = ($size$|0)!=(2147483647);
        $31 = ($size$|0)>(-1);
        $or$cond1 = $30 & $31;
        $V_0$2 = $or$cond1 ? $size$ : 2147483647;
        $32 = (($__this) + 20|0);
        $33 = HEAP32[$32>>2]|0;
        $34 = ($V_0$2|0)<=($33|0);
        $35 = ($33|0)<($size|0);
        $or$cond2 = $34 | $35;
        $V_0$3 = $or$cond2 ? $V_0$2 : $33;
        $36 = ($V_0$3|0)>($33|0);
        if ($36) {
         __THREW__ = 0;
         (invoke_ii(2996,(2561352|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break;
         }
         __THREW__ = 0;
         $39 = (invoke_ii(3469,(2561352|0))|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break;
         }
         $42 = HEAP32[3057080>>2]|0;
         $43 = HEAP32[3057088>>2]|0;
         __THREW__ = 0;
         invoke_viii(644,($39|0),($42|0),($43|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3838,($39|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          break;
         }
         // unreachable;
        } else {
         $V_0$4 = $V_0$3;
        }
       } else {
        $V_0$4 = $19;
       }
       __THREW__ = 0;
       $48 = (invoke_iii(643,(0|0),($V_0$4|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if (!($50)) {
        $51 = (($__this) + 8|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = ($52|0)<(1);
        if (!($53)) {
         $54 = HEAP32[$2>>2]|0;
         __THREW__ = 0;
         invoke_viiiiii(51,(0|0),($48|0),0,($54|0),0,($52|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break;
         }
        }
        HEAP32[$2>>2] = $48;
        $$pre3 = (($__this) + 16|0);
        $$pre$phiZ2D = $$pre3;
        HEAP32[$$pre$phiZ2D>>2] = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z121mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_Char_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderti($__this,$value,$repeatCount) {
 $__this = $__this|0;
 $value = $value|0;
 $repeatCount = $repeatCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536056);
 $0 = ($repeatCount|0)>(-1);
 if ($0) {
  $14 = (($__this) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + ($repeatCount))|0;
  __THREW__ = 0;
  invoke_vii(1913,($__this|0),($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   $19 = ($repeatCount|0)>(0);
   if (!($19)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($__this|0);
   }
   $20 = (($__this) + 12|0);
   $V_0$01 = 0;
   while(1) {
    $25 = HEAP32[$20>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $21 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = (($21) + 1)|0;
    HEAP32[$14>>2] = $24;
    __THREW__ = 0;
    invoke_vi(3799,($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(501,($25|0),($21|0),($value|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    $30 = (($V_0$01) + 1)|0;
    $31 = ($30|0)<($repeatCount|0);
    if ($31) {
     $V_0$01 = $30;
    } else {
     label = 18;
     break;
    }
   }
   if ((label|0) == 18) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($__this|0);
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   $lpad$phi$index = $10;$lpad$phi$index2 = $11;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(3469,(2561352|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(2587,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3838,($3|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Text_StringBuilder_m_get_CharsP34mscorlib_System_Text_StringBuilderi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535624);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>($index|0);
 $3 = ($index|0)>(-1);
 $or$cond = $2 & $3;
 if ($or$cond) {
  $15 = (($__this) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($16|0));
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   __THREW__ = 0;
   $19 = (invoke_iii(621,($16|0),($index|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2606944|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2606944|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(2730,($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3838,($6|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      // unreachable;
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_IndexOutOfRangeException_m__ctor_mscorlib_System_VoidP40mscorlib_System_IndexOutOfRangeException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2606664);
 __THREW__ = 0;
 invoke_v(725);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3071368>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z46mscorlib_System_Text_StringBuilder_m_set_CharsP34mscorlib_System_Text_StringBuilderit($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535672);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>($index|0);
 $3 = ($index|0)>(-1);
 $or$cond = $2 & $3;
 do {
  if ($or$cond) {
   $15 = (($__this) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0|0);
   if (!($17)) {
    __THREW__ = 0;
    invoke_vii(1913,($__this|0),($1|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
   }
   $20 = (($__this) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($21|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    invoke_viii(501,($21|0),($index|0),($value|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2606944|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_ii(3469,(2606944|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vi(2730,($6|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3838,($6|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z45mscorlib_System_Text_StringBuilder_m_ToStringP34mscorlib_System_Text_StringBuilder($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535432);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2191608 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2191608|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2191608 + 80|0))>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $$0 = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  } else {
   $19 = (($__this) + 16|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($20|0)==(0|0);
   if (!($21)) {
    $$0 = $20;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $22 = (($__this) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    __THREW__ = 0;
    $26 = (invoke_ii(1816,($23|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = $26 >> 1;
     $30 = ($1|0)<($29|0);
     $31 = HEAP32[$22>>2]|0;
     if ($30) {
      $32 = HEAP32[$0>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($31|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_iiii(529,($31|0),0,($32|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      HEAP32[$19>>2] = $35;
      $$0 = $35;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     } else {
      HEAP32[$19>>2] = $31;
      $38 = HEAP32[$0>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($31|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1766,($31|0),($38|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      $43 = HEAP32[$22>>2]|0;
      $$0 = $43;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Text_StringBuilder_m_RemoveP34mscorlib_System_Text_StringBuilderii($__this,$startIndex,$length) {
 $__this = $__this|0;
 $startIndex = $startIndex|0;
 $length = $length|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535720);
 $0 = $length | $startIndex;
 $1 = ($0|0)<(0);
 do {
  if ($1) {
   label = 3;
  } else {
   $2 = (($__this) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($3) - ($length))|0;
   $5 = ($4|0)<($startIndex|0);
   if ($5) {
    label = 3;
   } else {
    $17 = (($__this) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($18|0)==(0|0);
    if ($19) {
     $24 = $3;
    } else {
     __THREW__ = 0;
     invoke_vii(1913,($__this|0),($3|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $$pre = HEAP32[$2>>2]|0;
     $24 = $$pre;
    }
    $22 = (($length) + ($startIndex))|0;
    $23 = (($24) - ($22))|0;
    $25 = ($23|0)<(1);
    if (!($25)) {
     $26 = (($__this) + 12|0);
     $27 = HEAP32[$26>>2]|0;
     __THREW__ = 0;
     invoke_viiiiii(51,(0|0),($27|0),($startIndex|0),($27|0),($22|0),($23|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = HEAP32[$2>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $35 = (($32) - ($length))|0;
      HEAP32[$2>>2] = $35;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($__this|0);
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 3) {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_ii(3469,(2561352|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(2587,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3838,($8|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Text_StringBuilder_m_Replace_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_StringP34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringS2_($__this,$oldValue,$newValue) {
 $__this = $__this|0;
 $oldValue = $oldValue|0;
 $newValue = $newValue|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535768);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiiiii(117,($__this|0),($oldValue|0),($newValue|0),0,($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z169mscorlib_System_Text_StringBuilder_m_Replace_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringS2_ii($__this,$oldValue,$newValue,$startIndex,$count) {
 $__this = $__this|0;
 $oldValue = $oldValue|0;
 $newValue = $newValue|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535816);
 __THREW__ = 0;
 invoke_v(726);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($oldValue|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3056888>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = $count | $startIndex;
   $16 = ($15|0)<(0);
   if (!($16)) {
    $17 = (($__this) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) - ($count))|0;
    $20 = ($19|0)<($startIndex|0);
    if (!($20)) {
     __THREW__ = 0;
     invoke_vi(3799,($oldValue|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     $32 = (invoke_ii(1816,($oldValue|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     $35 = ($32|0)==(0);
     if ($35) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      __THREW__ = 0;
      $38 = (invoke_ii(3469,(2560072|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      $41 = HEAP32[3056896>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($38|0),($41|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3838,($38|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break;
      }
      // unreachable;
     }
     $46 = (($__this) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($47|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     __THREW__ = 0;
     $50 = (invoke_iiii(528,($47|0),($startIndex|0),($count|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($50|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     __THREW__ = 0;
     $55 = (invoke_iiii(548,($50|0),($oldValue|0),($newValue|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     $58 = ($55|0)==($50|0);
     if ($58) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($__this|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($55|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     __THREW__ = 0;
     $61 = (invoke_ii(1816,($55|0))|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     $64 = HEAP32[$17>>2]|0;
     $65 = (($61) - ($count))|0;
     $66 = (($65) + ($64))|0;
     __THREW__ = 0;
     invoke_vii(1913,($__this|0),($66|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($55|0));
     $69 = __THREW__; __THREW__ = 0;
     $70 = $69&1;
     if ($70) {
      break;
     }
     __THREW__ = 0;
     $71 = (invoke_ii(1816,($55|0))|0);
     $72 = __THREW__; __THREW__ = 0;
     $73 = $72&1;
     if ($73) {
      break;
     }
     $74 = ($71|0)<($count|0);
     do {
      if ($74) {
       $75 = HEAP32[$46>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($55|0));
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break L1;
       }
       __THREW__ = 0;
       $78 = (invoke_ii(1816,($55|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        break L1;
       }
       $81 = (($78) + ($startIndex))|0;
       $82 = HEAP32[$46>>2]|0;
       $83 = (($count) + ($startIndex))|0;
       $84 = HEAP32[$17>>2]|0;
       $85 = (($84) - ($83))|0;
       __THREW__ = 0;
       invoke_viiiiii(51,(0|0),($75|0),($81|0),($82|0),($83|0),($85|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break L1;
       }
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($55|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break L1;
       }
       __THREW__ = 0;
       $90 = (invoke_ii(1816,($55|0))|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        break L1;
       }
       $93 = ($90|0)>($count|0);
       if (!($93)) {
        break;
       }
       $94 = HEAP32[$46>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($55|0));
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        break L1;
       }
       __THREW__ = 0;
       $97 = (invoke_ii(1816,($55|0))|0);
       $98 = __THREW__; __THREW__ = 0;
       $99 = $98&1;
       if ($99) {
        break L1;
       }
       $100 = (($97) + ($startIndex))|0;
       $101 = HEAP32[$46>>2]|0;
       $102 = (($count) + ($startIndex))|0;
       $103 = HEAP32[$17>>2]|0;
       $104 = (($103) - ($102))|0;
       __THREW__ = 0;
       invoke_viiiiii(52,(0|0),($94|0),($100|0),($101|0),($102|0),($104|0));
       $105 = __THREW__; __THREW__ = 0;
       $106 = $105&1;
       if ($106) {
        break L1;
       }
      }
     } while(0);
     $107 = HEAP32[$46>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($55|0));
     $108 = __THREW__; __THREW__ = 0;
     $109 = $108&1;
     if ($109) {
      break;
     }
     __THREW__ = 0;
     $110 = (invoke_ii(1816,($55|0))|0);
     $111 = __THREW__; __THREW__ = 0;
     $112 = $111&1;
     if ($112) {
      break;
     }
     __THREW__ = 0;
     invoke_viiiiii(51,(0|0),($107|0),($startIndex|0),($55|0),0,($110|0));
     $113 = __THREW__; __THREW__ = 0;
     $114 = $113&1;
     if ($114) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($55|0));
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     if ($116) {
      break;
     }
     __THREW__ = 0;
     $117 = (invoke_ii(1816,($55|0))|0);
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      break;
     }
     $120 = HEAP32[$17>>2]|0;
     $121 = (($117) - ($count))|0;
     $122 = (($121) + ($120))|0;
     HEAP32[$17>>2] = $122;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($__this|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    __THREW__ = 0;
    $23 = (invoke_ii(3469,(2561352|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __THREW__ = 0;
     invoke_vi(2587,($23|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      invoke_vi(3838,($23|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_StringP34mscorlib_System_Text_StringBuilderP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$pre$phi5Z2D = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535864);
 $0 = ($value|0)==(0|0);
 if ($0) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($__this|0);
 }
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __THREW__ = 0;
  invoke_vi(3799,($value|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1816,($value|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = (($__this) + 20|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($6|0)<($10|0);
    if ($11) {
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_ii(1816,($value|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = (($__this) + 12|0);
       $20 = HEAP32[$19>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($20|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        $23 = (invoke_ii(1816,($20|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         $26 = ($16|0)>($23|0);
         if ($26) {
          __THREW__ = 0;
          invoke_vi(3799,($value|0));
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           __THREW__ = 0;
           $29 = (invoke_ii(1816,($value|0))|0);
           $30 = __THREW__; __THREW__ = 0;
           $31 = $30&1;
           if (!($31)) {
            HEAP32[$1>>2] = $29;
            $32 = (($__this) + 16|0);
            HEAP32[$32>>2] = $value;
            HEAP32[$19>>2] = $value;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($__this|0);
           }
          }
         } else {
          label = 15;
         }
        }
       }
      }
     }
    } else {
     label = 15;
    }
   }
  }
 } else {
  label = 15;
 }
 do {
  if ((label|0) == 15) {
   $33 = HEAP32[$1>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($value|0));
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    $36 = (invoke_ii(1816,($value|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     $39 = (($36) + ($33))|0;
     $40 = (($__this) + 16|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ($41|0)==(0|0);
     if ($42) {
      $43 = (($__this) + 12|0);
      $44 = HEAP32[$43>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($44|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_ii(1816,($44|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      $50 = ($47|0)<($39|0);
      if ($50) {
       label = 21;
      } else {
       $$pre$phi5Z2D = $43;
      }
     } else {
      label = 21;
     }
     if ((label|0) == 21) {
      __THREW__ = 0;
      invoke_vii(1913,($__this|0),($39|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $$pre4 = (($__this) + 12|0);
      $$pre$phi5Z2D = $$pre4;
     }
     $53 = HEAP32[$$pre$phi5Z2D>>2]|0;
     $54 = HEAP32[$1>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if (!($56)) {
      __THREW__ = 0;
      $57 = (invoke_ii(1816,($value|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       __THREW__ = 0;
       invoke_viiiiii(51,(0|0),($53|0),($54|0),($value|0),0,($57|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if (!($61)) {
        HEAP32[$1>>2] = $39;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($__this|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535912);
 __THREW__ = 0;
 $1 = (invoke_ii(1791,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(989,($__this|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2535960);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = $__this;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($value|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2730,(2149112|0),($value|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(989,($__this|0),($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $$0 = $6;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_CharP34mscorlib_System_Text_StringBuildert($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536008);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 $3 = (($__this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (($__this) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($7|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_ii(1816,($7|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = ($10|0)<($2|0);
    if ($13) {
     label = 6;
    } else {
     $$pre$phiZ2D = $6;
     label = 8;
    }
   }
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vii(1913,($__this|0),($2|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $$pre = (($__this) + 12|0);
   $$pre$phiZ2D = $$pre;
   label = 8;
  }
 }
 if ((label|0) == 8) {
  $18 = HEAP32[$$pre$phiZ2D>>2]|0;
  $19 = HEAP32[$0>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($18|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   __THREW__ = 0;
   invoke_viii(501,($18|0),($19|0),($value|0));
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    HEAP32[$0>>2] = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($__this|0);
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z145mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderP22mscorlib_System_Stringii($__this,$value,$startIndex,$count) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536104);
 __THREW__ = 0;
 invoke_v(727);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $5 = ($startIndex|0)==(0);
    $6 = ($count|0)==(0);
    $or$cond = $5 | $6;
    if ($or$cond) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($__this|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3057048>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = $count | $startIndex;
   $18 = ($17|0)<(0);
   if (!($18)) {
    __THREW__ = 0;
    invoke_vi(3799,($value|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_ii(1816,($value|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = (($21) - ($count))|0;
    $25 = ($24|0)<($startIndex|0);
    if (!($25)) {
     $35 = (($__this) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + ($count))|0;
     $38 = (($__this) + 16|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = ($39|0)==(0|0);
     if ($40) {
      $41 = (($__this) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($42|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __THREW__ = 0;
      $45 = (invoke_ii(1816,($42|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = ($45|0)<($37|0);
      if ($48) {
       label = 23;
      } else {
       $$pre$phiZ2D = $41;
      }
     } else {
      label = 23;
     }
     if ((label|0) == 23) {
      __THREW__ = 0;
      invoke_vii(1913,($__this|0),($37|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $$pre = (($__this) + 12|0);
      $$pre$phiZ2D = $$pre;
     }
     $51 = HEAP32[$$pre$phiZ2D>>2]|0;
     $52 = HEAP32[$35>>2]|0;
     __THREW__ = 0;
     invoke_viiiiii(51,(0|0),($51|0),($52|0),($value|0),($startIndex|0),($count|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     HEAP32[$35>>2] = $37;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($__this|0);
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_ii(3469,(2561352|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __THREW__ = 0;
     invoke_vi(2587,($28|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      invoke_vi(3838,($28|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z138mscorlib_System_Text_StringBuilder_m_AppendFormat_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_Object_arr_arrP34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$format,$args) {
 $__this = $__this|0;
 $format = $format|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536152);
 __THREW__ = 0;
 $0 = (invoke_iiiii(162,($__this|0),(0|0),($format|0),($args|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z170mscorlib_System_Text_StringBuilder_m_AppendFormat_mscorlib_System_Text_StringBuilder_mscorlib_System_IFormatProvider_mscorlib_System_String_mscorlib_System_Object_arr_arrP34mscorlib_System_Text_StringBuilderP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$provider,$format,$args) {
 $__this = $__this|0;
 $provider = $provider|0;
 $format = $format|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536200);
 __THREW__ = 0;
 (invoke_iiiiii(88,(0|0),($__this|0),($provider|0),($format|0),($args|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($__this|0);
 }
 return 0|0;
}
function __Z130mscorlib_System_Text_StringBuilder_m_AppendFormat_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$arg0) {
 $__this = $__this|0;
 $format = $format|0;
 $arg0 = $arg0|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536248);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2768,(1167664|0),1)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($2|0),($arg0|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = (($2) + 16|0);
      HEAP32[$19>>2] = $arg0;
      __THREW__ = 0;
      $20 = (invoke_iiiii(162,($__this|0),(0|0),($format|0),($2|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($20|0);
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z153mscorlib_System_Text_StringBuilder_m_AppendFormat_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringP22mscorlib_System_ObjectS4_($__this,$format,$arg0,$arg1) {
 $__this = $__this|0;
 $format = $format|0;
 $arg0 = $arg0|0;
 $arg1 = $arg1|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536296);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2768,(1167664|0),2)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($2|0),($arg0|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = (($2) + 16|0);
      HEAP32[$19>>2] = $arg0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = HEAP32[$7>>2]|0;
       $23 = ($22>>>0)<(2);
       if ($23) {
        __THREW__ = 0;
        $24 = (invoke_i(132)|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($24|0));
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($2|0),($arg1|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = HEAP32[$2>>2]|0;
        $32 = (($31) + 92|0);
        $33 = HEAP32[$32>>2]|0;
        $34 = (($19) + ($33)|0);
        HEAP32[$34>>2] = $arg1;
        __THREW__ = 0;
        $35 = (invoke_iiiii(162,($__this|0),(0|0),($format|0),($2|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($35|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z123mscorlib_System_Text_StringBuilder_m_Insert_mscorlib_System_Text_StringBuilder_mscorlib_System_Int32_mscorlib_System_StringP34mscorlib_System_Text_StringBuilderiP22mscorlib_System_String($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536344);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>=($index|0);
 $3 = ($index|0)>(-1);
 $or$cond = $2 & $3;
 if ($or$cond) {
  $15 = ($value|0)==(0|0);
  if ($15) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($__this|0);
  }
  __THREW__ = 0;
  invoke_vi(3799,($value|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_ii(1816,($value|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = ($18|0)==(0);
    if ($21) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($__this|0);
    }
    $22 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($value|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     $25 = (invoke_ii(1816,($value|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = (($25) + ($22))|0;
      __THREW__ = 0;
      invoke_vii(1913,($__this|0),($28|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = (($__this) + 12|0);
       $32 = HEAP32[$31>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($value|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        __THREW__ = 0;
        $35 = (invoke_ii(1816,($value|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         $38 = (($35) + ($index))|0;
         $39 = HEAP32[$31>>2]|0;
         $40 = HEAP32[$0>>2]|0;
         $41 = (($40) - ($index))|0;
         __THREW__ = 0;
         invoke_viiiiii(52,(0|0),($32|0),($38|0),($39|0),($index|0),($41|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          $44 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($value|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if (!($46)) {
           __THREW__ = 0;
           $47 = (invoke_ii(1816,($value|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if (!($49)) {
            __THREW__ = 0;
            invoke_viiiiii(51,(0|0),($44|0),($index|0),($value|0),0,($47|0));
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if (!($51)) {
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              $54 = HEAP32[$0>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($value|0));
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               __THREW__ = 0;
               $57 = (invoke_ii(1816,($value|0))|0);
               $58 = __THREW__; __THREW__ = 0;
               $59 = $58&1;
               if (!($59)) {
                __THREW__ = 0;
                invoke_vi(3799,($__this|0));
                $60 = __THREW__; __THREW__ = 0;
                $61 = $60&1;
                if (!($61)) {
                 $62 = (($57) + ($54))|0;
                 HEAP32[$0>>2] = $62;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($__this|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2561352|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(2587,($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vi(3838,($6|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      // unreachable;
     }
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Text_StringBuilder_m_Insert_mscorlib_System_Text_StringBuilder_mscorlib_System_Int32_mscorlib_System_CharP34mscorlib_System_Text_StringBuilderit($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536392);
 __THREW__ = 0;
 invoke_v(728);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>=($index|0);
   $5 = ($index|0)>(-1);
   $or$cond = $4 & $5;
   if (!($or$cond)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3057064>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($10|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   }
   $18 = (($3) + 1)|0;
   __THREW__ = 0;
   invoke_vii(1913,($__this|0),($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = (($__this) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (($index) + 1)|0;
    $24 = HEAP32[$2>>2]|0;
    $25 = (($24) - ($index))|0;
    __THREW__ = 0;
    invoke_viiiiii(52,(0|0),($22|0),($23|0),($22|0),($index|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = HEAP32[$21>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($28|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      invoke_viii(501,($28|0),($index|0),($value|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        $35 = HEAP32[$2>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         $38 = (($35) + 1)|0;
         HEAP32[$2>>2] = $38;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($__this|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z145mscorlib_System_Text_StringBuilder_m_Insert_mscorlib_System_Text_StringBuilder_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderiP22mscorlib_System_Stringi($__this,$index,$value,$count) {
 $__this = $__this|0;
 $index = $index|0;
 $value = $value|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$06 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2536440);
 $0 = ($count|0)>(-1);
 do {
  if ($0) {
   $14 = ($value|0)==(0|0);
   if ($14) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($__this|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    $17 = HEAP8[((2191608 + 116|0))>>0]|0;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2191608|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = HEAP32[((2191608 + 80|0))>>2]|0;
     $28 = HEAP32[$27>>2]|0;
     __THREW__ = 0;
     $29 = (invoke_iiii(575,(0|0),($value|0),($28|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      $32 = ($count|0)>(0);
      $or$cond = $29 & $32;
      if ($or$cond) {
       $V_0$06 = 0;
      } else {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($__this|0);
      }
      while(1) {
       __THREW__ = 0;
       (invoke_iiii(935,($__this|0),($index|0),($value|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       $33 = (($V_0$06) + 1)|0;
       $34 = ($33|0)<($count|0);
       if ($34) {
        $V_0$06 = $33;
       } else {
        label = 21;
        break;
       }
      }
      if ((label|0) == 21) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($__this|0);
      }
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(3469,(2561352|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(2587,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      __THREW__ = 0;
      invoke_vi(3838,($3|0));
      $8 = __THREW__; __THREW__ = 0;
      $9 = $8&1;
      if (!($9)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFvPvS3_iiiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$3,$6,$9);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S1_S1_E6InvokeEPFvPvS3_iiiiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$3,$6,$9,$12);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_27mscorlib_System_Int32TraitsS1_E6InvokeEPFPvS3_S3_S3_iiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$5,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_E6InvokeEPFPvS3_iS3_iES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$3,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z65mscorlib_System_Text_StringBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2537592)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 $10 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $11 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2537600)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($10,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $10;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Text_UTF32Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_Boolean_mscorlib_System_BooleanP34mscorlib_System_Text_UTF32Encodingbbb($__this,$bigEndian,$byteOrderMark,$throwOnInvalidCharacters) {
 $__this = $__this|0;
 $bigEndian = $bigEndian|0;
 $byteOrderMark = $byteOrderMark|0;
 $throwOnInvalidCharacters = $throwOnInvalidCharacters|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538072);
 __THREW__ = 0;
 invoke_v(729);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $$ = $bigEndian ? 12001 : 12000;
    __THREW__ = 0;
    invoke_vii(1909,($__this|0),($$|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = (($__this) + 48|0);
     $9 = $bigEndian&1;
     HEAP8[$8>>0] = $9;
     $10 = (($__this) + 49|0);
     $11 = $byteOrderMark&1;
     HEAP8[$10>>0] = $11;
     if ($throwOnInvalidCharacters) {
      __THREW__ = 0;
      $12 = (invoke_ii(2373,0)|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      $15 = (invoke_ii(2361,(0|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(632,($__this|0),($12|0),($15|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2528672|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      $22 = (invoke_ii(3469,(2528672|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      $25 = HEAP32[3057192>>2]|0;
      __THREW__ = 0;
      invoke_vii(1907,($22|0),($25|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2524464|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      $30 = (invoke_ii(3469,(2524464|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      $33 = HEAP32[3057200>>2]|0;
      __THREW__ = 0;
      invoke_vii(1905,($30|0),($33|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(632,($__this|0),($22|0),($30|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
     }
     if ($bigEndian) {
      $38 = HEAP32[3057208>>2]|0;
      $39 = (($__this) + 28|0);
      HEAP32[$39>>2] = $38;
      $40 = HEAP32[3057216>>2]|0;
      $41 = (($__this) + 32|0);
      HEAP32[$41>>2] = $40;
      $42 = HEAP32[3057224>>2]|0;
      $43 = (($__this) + 36|0);
      HEAP32[$43>>2] = $42;
      $44 = HEAP32[3057232>>2]|0;
      $45 = (($__this) + 44|0);
      HEAP32[$45>>2] = $44;
      $54 = (($__this) + 12|0);
      HEAP32[$54>>2] = 12000;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     } else {
      $46 = HEAP32[3057240>>2]|0;
      $47 = (($__this) + 28|0);
      HEAP32[$47>>2] = $46;
      $48 = HEAP32[3057248>>2]|0;
      $49 = (($__this) + 32|0);
      HEAP32[$49>>2] = $48;
      $50 = HEAP32[3057256>>2]|0;
      $51 = (($__this) + 36|0);
      HEAP32[$51>>2] = $50;
      $52 = HEAP32[3057264>>2]|0;
      $53 = (($__this) + 44|0);
      HEAP32[$53>>2] = $52;
      $54 = (($__this) + 12|0);
      HEAP32[$54>>2] = 12000;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z144mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Char_arrii($__this,$chars,$index,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_0$1$lcssa = 0, $V_0$17 = 0, $V_1$06 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538120);
 __THREW__ = 0;
 invoke_v(730);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3057368>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($index|0)<(0);
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = (($chars) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)<($index|0);
    if (!($22)) {
     $37 = ($count|0)<(0);
     if (!($37)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      $40 = HEAP32[$20>>2]|0;
      $41 = (($40) - ($index))|0;
      $42 = ($41|0)<($count|0);
      if (!($42)) {
       $43 = (($count) + ($index))|0;
       $44 = ($count|0)>(0);
       if (!($44)) {
        $V_0$1$lcssa = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($V_0$1$lcssa|0);
       }
       $45 = (($chars) + 16|0);
       $V_0$17 = 0;$V_1$06 = $index;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($chars|0));
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         break;
        }
        $60 = ($V_1$06|0)<(0);
        if ($60) {
         label = 33;
        } else {
         $61 = HEAP32[$20>>2]|0;
         $62 = ($V_1$06>>>0)<($61>>>0);
         if (!($62)) {
          label = 33;
         }
        }
        if ((label|0) == 33) {
         label = 0;
         __THREW__ = 0;
         $63 = (invoke_i(132)|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($63|0));
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          break;
         }
        }
        $68 = HEAP32[$chars>>2]|0;
        $69 = (($68) + 92|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = Math_imul($70, $V_1$06)|0;
        $72 = (($45) + ($71)|0);
        $73 = HEAP16[$72>>1]|0;
        __THREW__ = 0;
        $74 = (invoke_iii(603,(0|0),($73|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         break;
        }
        $77 = (($V_1$06) + 1)|0;
        if ($74) {
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          break;
         }
         $80 = HEAP32[$20>>2]|0;
         $81 = ($77|0)<($80|0);
         if ($81) {
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if ($83) {
           break;
          }
          $84 = ($77|0)<(0);
          if ($84) {
           label = 42;
          } else {
           $85 = HEAP32[$20>>2]|0;
           $86 = ($77>>>0)<($85>>>0);
           if (!($86)) {
            label = 42;
           }
          }
          if ((label|0) == 42) {
           label = 0;
           __THREW__ = 0;
           $87 = (invoke_i(132)|0);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($87|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            break;
           }
          }
          $92 = HEAP32[$chars>>2]|0;
          $93 = (($92) + 92|0);
          $94 = HEAP32[$93>>2]|0;
          $95 = Math_imul($94, $77)|0;
          $96 = (($45) + ($95)|0);
          $97 = HEAP16[$96>>1]|0;
          __THREW__ = 0;
          (invoke_iii(603,(0|0),($97|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break;
          }
         }
        }
        $V_0$0 = (($V_0$17) + 4)|0;
        $100 = ($77|0)<($43|0);
        if ($100) {
         $V_0$17 = $V_0$0;$V_1$06 = $77;
        } else {
         $V_0$1$lcssa = $V_0$0;
         label = 47;
         break;
        }
       }
       if ((label|0) == 47) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($V_0$1$lcssa|0);
       }
       $3 = ___cxa_find_matching_catch()|0;
       $4 = tempRet0;
       $lpad$phi$index = $3;$lpad$phi$index2 = $4;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     }
     $46 = HEAP32[3057400>>2]|0;
     __THREW__ = 0;
     $47 = (invoke_iii(977,0,($46|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     __THREW__ = 0;
     $52 = (invoke_ii(3469,(2561352|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     $55 = HEAP32[3057392>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($52|0),($55|0),($47|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($52|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     // unreachable;
    }
   }
   $23 = HEAP32[3057384>>2]|0;
   __THREW__ = 0;
   $24 = (invoke_iii(977,0,($23|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     __THREW__ = 0;
     $29 = (invoke_ii(3469,(2561352|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      $32 = HEAP32[3057376>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($29|0),($32|0),($24|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       invoke_vi(3838,($29|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z191mscorlib_System_Text_UTF32Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 var $$0$be = 0, $$01$be = 0, $$031 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$022 = 0, $V_0$1$be = 0, $V_0$1$lcssa = 0, $V_0$129 = 0;
 var $V_2$013 = 0, $V_2$121 = 0, $V_3$012 = 0, $V_4$020 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538168);
 __THREW__ = 0;
 invoke_v(731);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2560584|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[3057416>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($13|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($13|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    // unreachable;
   }
   $21 = ($bytes|0)==(0|0);
   if ($21) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2560584|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = HEAP32[3057424>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($24|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($24|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    // unreachable;
   }
   $32 = ($charIndex|0)<(0);
   if (!($32)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($chars) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)<($charIndex|0);
    if (!($37)) {
     $52 = ($charCount|0)<(0);
     if (!($52)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$35>>2]|0;
      $56 = (($55) - ($charIndex))|0;
      $57 = ($56|0)<($charCount|0);
      if (!($57)) {
       $72 = ($byteIndex|0)<(0);
       if (!($72)) {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         break;
        }
        $75 = (($bytes) + 12|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($76|0)<($byteIndex|0);
        if (!($77)) {
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          break;
         }
         $94 = HEAP32[$75>>2]|0;
         $95 = (($94) - ($byteIndex))|0;
         $96 = $charCount << 2;
         $97 = ($95|0)<($96|0);
         if ($97) {
          $102 = HEAP32[3057480>>2]|0;
          __THREW__ = 0;
          $103 = (invoke_iii(977,0,($102|0))|0);
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $106 = __THREW__; __THREW__ = 0;
          $107 = $106&1;
          if ($107) {
           break;
          }
          __THREW__ = 0;
          $108 = (invoke_ii(3469,(2560072|0))|0);
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1924,($108|0),($103|0));
          $111 = __THREW__; __THREW__ = 0;
          $112 = $111&1;
          if ($112) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3838,($108|0));
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           break;
          }
          // unreachable;
         }
         $98 = ($charCount|0)>(0);
         if (!($98)) {
          $V_0$1$lcssa = $byteIndex;
          $471 = (($V_0$1$lcssa) - ($byteIndex))|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($471|0);
         }
         $99 = (($chars) + 16|0);
         $100 = (($__this) + 48|0);
         $101 = (($bytes) + 16|0);
         $$031 = $charIndex;$$in = $charCount;$V_0$129 = $byteIndex;
         L41: while(1) {
          $468 = (($$in) + -1)|0;
          $142 = (($$031) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $469 = __THREW__; __THREW__ = 0;
          $470 = $469&1;
          if ($470) {
           label = 5;
           break;
          }
          $115 = ($$031|0)<(0);
          if ($115) {
           label = 58;
          } else {
           $116 = HEAP32[$35>>2]|0;
           $117 = ($$031>>>0)<($116>>>0);
           if (!($117)) {
            label = 58;
           }
          }
          if ((label|0) == 58) {
           label = 0;
           __THREW__ = 0;
           $118 = (invoke_i(132)|0);
           $119 = __THREW__; __THREW__ = 0;
           $120 = $119&1;
           if ($120) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($118|0));
           $121 = __THREW__; __THREW__ = 0;
           $122 = $121&1;
           if ($122) {
            label = 5;
            break;
           }
          }
          $123 = HEAP32[$chars>>2]|0;
          $124 = (($123) + 92|0);
          $125 = HEAP32[$124>>2]|0;
          $126 = Math_imul($125, $$031)|0;
          $127 = (($99) + ($126)|0);
          $128 = HEAP16[$127>>1]|0;
          __THREW__ = 0;
          $129 = (invoke_iii(603,(0|0),($128|0))|0);
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           label = 5;
           break;
          }
          L51: do {
           if ($129) {
            $132 = (($$in) + -2)|0;
            $133 = ($$in|0)<(2);
            if (!($133)) {
             $134 = $128&65535;
             $135 = $134 << 10;
             $136 = (($135) + 10485760)|0;
             $137 = $136 & 67107840;
             $138 = (($$031) + 2)|0;
             __THREW__ = 0;
             invoke_vi(3799,($chars|0));
             $139 = __THREW__; __THREW__ = 0;
             $140 = $139&1;
             if ($140) {
              label = 5;
              break L41;
             }
             $141 = ($142|0)<(0);
             if ($141) {
              label = 66;
             } else {
              $143 = HEAP32[$35>>2]|0;
              $144 = ($142>>>0)<($143>>>0);
              if (!($144)) {
               label = 66;
              }
             }
             if ((label|0) == 66) {
              label = 0;
              __THREW__ = 0;
              $145 = (invoke_i(132)|0);
              $146 = __THREW__; __THREW__ = 0;
              $147 = $146&1;
              if ($147) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($145|0));
              $148 = __THREW__; __THREW__ = 0;
              $149 = $148&1;
              if ($149) {
               label = 5;
               break L41;
              }
             }
             $150 = HEAP32[$chars>>2]|0;
             $151 = (($150) + 92|0);
             $152 = HEAP32[$151>>2]|0;
             $153 = Math_imul($152, $142)|0;
             $154 = (($99) + ($153)|0);
             $155 = HEAP16[$154>>1]|0;
             $156 = $155&65535;
             $157 = (($137) + 9216)|0;
             $158 = (($157) + ($156))|0;
             $159 = HEAP8[$100>>0]|0;
             $160 = ($159<<24>>24)==(0);
             if ($160) {
              $V_0$022 = $V_0$129;$V_2$121 = $158;$V_4$020 = 0;
              while(1) {
               $200 = (($V_0$022) + 1)|0;
               $196 = $V_2$121&255;
               __THREW__ = 0;
               invoke_vi(3799,($bytes|0));
               $201 = __THREW__; __THREW__ = 0;
               $202 = $201&1;
               if ($202) {
                label = 4;
                break L41;
               }
               $183 = ($V_0$022|0)<(0);
               if ($183) {
                label = 79;
               } else {
                $184 = HEAP32[$75>>2]|0;
                $185 = ($V_0$022>>>0)<($184>>>0);
                if (!($185)) {
                 label = 79;
                }
               }
               if ((label|0) == 79) {
                label = 0;
                __THREW__ = 0;
                $186 = (invoke_i(132)|0);
                $187 = __THREW__; __THREW__ = 0;
                $188 = $187&1;
                if ($188) {
                 label = 4;
                 break L41;
                }
                __THREW__ = 0;
                invoke_vi(3302,($186|0));
                $189 = __THREW__; __THREW__ = 0;
                $190 = $189&1;
                if ($190) {
                 label = 4;
                 break L41;
                }
               }
               $191 = HEAP32[$bytes>>2]|0;
               $192 = (($191) + 92|0);
               $193 = HEAP32[$192>>2]|0;
               $194 = Math_imul($193, $V_0$022)|0;
               $195 = (($101) + ($194)|0);
               HEAP8[$195>>0] = $196;
               $197 = $V_2$121 >> 8;
               $198 = (($V_4$020) + 1)|0;
               $199 = ($198|0)<(4);
               if ($199) {
                $V_0$022 = $200;$V_2$121 = $197;$V_4$020 = $198;
               } else {
                $$0$be = $138;$$01$be = $132;$V_0$1$be = $200;
                break L51;
               }
              }
             }
             $161 = (($V_0$129) + 3)|0;
             $V_2$013 = $158;$V_3$012 = 0;
             while(1) {
              $163 = (($161) - ($V_3$012))|0;
              $176 = $V_2$013&255;
              __THREW__ = 0;
              invoke_vi(3799,($bytes|0));
              $180 = __THREW__; __THREW__ = 0;
              $181 = $180&1;
              if ($181) {
               label = 3;
               break L41;
              }
              $162 = ($163|0)<(0);
              if ($162) {
               label = 72;
              } else {
               $164 = HEAP32[$75>>2]|0;
               $165 = ($163>>>0)<($164>>>0);
               if (!($165)) {
                label = 72;
               }
              }
              if ((label|0) == 72) {
               label = 0;
               __THREW__ = 0;
               $166 = (invoke_i(132)|0);
               $167 = __THREW__; __THREW__ = 0;
               $168 = $167&1;
               if ($168) {
                label = 3;
                break L41;
               }
               __THREW__ = 0;
               invoke_vi(3302,($166|0));
               $169 = __THREW__; __THREW__ = 0;
               $170 = $169&1;
               if ($170) {
                label = 3;
                break L41;
               }
              }
              $171 = HEAP32[$bytes>>2]|0;
              $172 = (($171) + 92|0);
              $173 = HEAP32[$172>>2]|0;
              $174 = Math_imul($173, $163)|0;
              $175 = (($101) + ($174)|0);
              HEAP8[$175>>0] = $176;
              $177 = $V_2$013 >> 8;
              $178 = (($V_3$012) + 1)|0;
              $179 = ($178|0)<(4);
              if ($179) {
               $V_2$013 = $177;$V_3$012 = $178;
              } else {
               break;
              }
             }
             $182 = (($V_0$129) + 4)|0;
             $$0$be = $138;$$01$be = $132;$V_0$1$be = $182;
             break;
            }
            $203 = HEAP8[$100>>0]|0;
            $204 = ($203<<24>>24)==(0);
            $205 = (($V_0$129) + 1)|0;
            if ($204) {
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $269 = __THREW__; __THREW__ = 0;
             $270 = $269&1;
             if ($270) {
              label = 5;
              break L41;
             }
             $271 = ($V_0$129|0)<(0);
             if ($271) {
              label = 108;
             } else {
              $272 = HEAP32[$75>>2]|0;
              $273 = ($V_0$129>>>0)<($272>>>0);
              if (!($273)) {
               label = 108;
              }
             }
             if ((label|0) == 108) {
              label = 0;
              __THREW__ = 0;
              $274 = (invoke_i(132)|0);
              $275 = __THREW__; __THREW__ = 0;
              $276 = $275&1;
              if ($276) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($274|0));
              $277 = __THREW__; __THREW__ = 0;
              $278 = $277&1;
              if ($278) {
               label = 5;
               break L41;
              }
             }
             $279 = HEAP32[$bytes>>2]|0;
             $280 = (($279) + 92|0);
             $281 = HEAP32[$280>>2]|0;
             $282 = Math_imul($281, $V_0$129)|0;
             $283 = (($101) + ($282)|0);
             HEAP8[$283>>0] = 63;
             $284 = (($V_0$129) + 2)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $285 = __THREW__; __THREW__ = 0;
             $286 = $285&1;
             if ($286) {
              label = 5;
              break L41;
             }
             $287 = ($205|0)<(0);
             if ($287) {
              label = 113;
             } else {
              $288 = HEAP32[$75>>2]|0;
              $289 = ($205>>>0)<($288>>>0);
              if (!($289)) {
               label = 113;
              }
             }
             if ((label|0) == 113) {
              label = 0;
              __THREW__ = 0;
              $290 = (invoke_i(132)|0);
              $291 = __THREW__; __THREW__ = 0;
              $292 = $291&1;
              if ($292) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($290|0));
              $293 = __THREW__; __THREW__ = 0;
              $294 = $293&1;
              if ($294) {
               label = 5;
               break L41;
              }
             }
             $295 = HEAP32[$bytes>>2]|0;
             $296 = (($295) + 92|0);
             $297 = HEAP32[$296>>2]|0;
             $298 = Math_imul($297, $205)|0;
             $299 = (($101) + ($298)|0);
             HEAP8[$299>>0] = 0;
             $300 = (($V_0$129) + 3)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $301 = __THREW__; __THREW__ = 0;
             $302 = $301&1;
             if ($302) {
              label = 5;
              break L41;
             }
             $303 = ($284|0)<(0);
             if ($303) {
              label = 118;
             } else {
              $304 = HEAP32[$75>>2]|0;
              $305 = ($284>>>0)<($304>>>0);
              if (!($305)) {
               label = 118;
              }
             }
             if ((label|0) == 118) {
              label = 0;
              __THREW__ = 0;
              $306 = (invoke_i(132)|0);
              $307 = __THREW__; __THREW__ = 0;
              $308 = $307&1;
              if ($308) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($306|0));
              $309 = __THREW__; __THREW__ = 0;
              $310 = $309&1;
              if ($310) {
               label = 5;
               break L41;
              }
             }
             $311 = HEAP32[$bytes>>2]|0;
             $312 = (($311) + 92|0);
             $313 = HEAP32[$312>>2]|0;
             $314 = Math_imul($313, $284)|0;
             $315 = (($101) + ($314)|0);
             HEAP8[$315>>0] = 0;
             $316 = (($V_0$129) + 4)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $317 = __THREW__; __THREW__ = 0;
             $318 = $317&1;
             if ($318) {
              label = 5;
              break L41;
             }
             $319 = ($300|0)<(0);
             if ($319) {
              label = 123;
             } else {
              $320 = HEAP32[$75>>2]|0;
              $321 = ($300>>>0)<($320>>>0);
              if (!($321)) {
               label = 123;
              }
             }
             if ((label|0) == 123) {
              label = 0;
              __THREW__ = 0;
              $322 = (invoke_i(132)|0);
              $323 = __THREW__; __THREW__ = 0;
              $324 = $323&1;
              if ($324) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($322|0));
              $325 = __THREW__; __THREW__ = 0;
              $326 = $325&1;
              if ($326) {
               label = 5;
               break L41;
              }
             }
             $327 = HEAP32[$bytes>>2]|0;
             $328 = (($327) + 92|0);
             $329 = HEAP32[$328>>2]|0;
             $330 = Math_imul($329, $300)|0;
             $331 = (($101) + ($330)|0);
             HEAP8[$331>>0] = 0;
             $$0$be = $142;$$01$be = $132;$V_0$1$be = $316;
             break;
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $206 = __THREW__; __THREW__ = 0;
             $207 = $206&1;
             if ($207) {
              label = 5;
              break L41;
             }
             $208 = ($V_0$129|0)<(0);
             if ($208) {
              label = 87;
             } else {
              $209 = HEAP32[$75>>2]|0;
              $210 = ($V_0$129>>>0)<($209>>>0);
              if (!($210)) {
               label = 87;
              }
             }
             if ((label|0) == 87) {
              label = 0;
              __THREW__ = 0;
              $211 = (invoke_i(132)|0);
              $212 = __THREW__; __THREW__ = 0;
              $213 = $212&1;
              if ($213) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($211|0));
              $214 = __THREW__; __THREW__ = 0;
              $215 = $214&1;
              if ($215) {
               label = 5;
               break L41;
              }
             }
             $216 = HEAP32[$bytes>>2]|0;
             $217 = (($216) + 92|0);
             $218 = HEAP32[$217>>2]|0;
             $219 = Math_imul($218, $V_0$129)|0;
             $220 = (($101) + ($219)|0);
             HEAP8[$220>>0] = 0;
             $221 = (($V_0$129) + 2)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $222 = __THREW__; __THREW__ = 0;
             $223 = $222&1;
             if ($223) {
              label = 5;
              break L41;
             }
             $224 = ($205|0)<(0);
             if ($224) {
              label = 92;
             } else {
              $225 = HEAP32[$75>>2]|0;
              $226 = ($205>>>0)<($225>>>0);
              if (!($226)) {
               label = 92;
              }
             }
             if ((label|0) == 92) {
              label = 0;
              __THREW__ = 0;
              $227 = (invoke_i(132)|0);
              $228 = __THREW__; __THREW__ = 0;
              $229 = $228&1;
              if ($229) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($227|0));
              $230 = __THREW__; __THREW__ = 0;
              $231 = $230&1;
              if ($231) {
               label = 5;
               break L41;
              }
             }
             $232 = HEAP32[$bytes>>2]|0;
             $233 = (($232) + 92|0);
             $234 = HEAP32[$233>>2]|0;
             $235 = Math_imul($234, $205)|0;
             $236 = (($101) + ($235)|0);
             HEAP8[$236>>0] = 0;
             $237 = (($V_0$129) + 3)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $238 = __THREW__; __THREW__ = 0;
             $239 = $238&1;
             if ($239) {
              label = 5;
              break L41;
             }
             $240 = ($221|0)<(0);
             if ($240) {
              label = 97;
             } else {
              $241 = HEAP32[$75>>2]|0;
              $242 = ($221>>>0)<($241>>>0);
              if (!($242)) {
               label = 97;
              }
             }
             if ((label|0) == 97) {
              label = 0;
              __THREW__ = 0;
              $243 = (invoke_i(132)|0);
              $244 = __THREW__; __THREW__ = 0;
              $245 = $244&1;
              if ($245) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($243|0));
              $246 = __THREW__; __THREW__ = 0;
              $247 = $246&1;
              if ($247) {
               label = 5;
               break L41;
              }
             }
             $248 = HEAP32[$bytes>>2]|0;
             $249 = (($248) + 92|0);
             $250 = HEAP32[$249>>2]|0;
             $251 = Math_imul($250, $221)|0;
             $252 = (($101) + ($251)|0);
             HEAP8[$252>>0] = 0;
             $253 = (($V_0$129) + 4)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $254 = __THREW__; __THREW__ = 0;
             $255 = $254&1;
             if ($255) {
              label = 5;
              break L41;
             }
             $256 = ($237|0)<(0);
             if ($256) {
              label = 102;
             } else {
              $257 = HEAP32[$75>>2]|0;
              $258 = ($237>>>0)<($257>>>0);
              if (!($258)) {
               label = 102;
              }
             }
             if ((label|0) == 102) {
              label = 0;
              __THREW__ = 0;
              $259 = (invoke_i(132)|0);
              $260 = __THREW__; __THREW__ = 0;
              $261 = $260&1;
              if ($261) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($259|0));
              $262 = __THREW__; __THREW__ = 0;
              $263 = $262&1;
              if ($263) {
               label = 5;
               break L41;
              }
             }
             $264 = HEAP32[$bytes>>2]|0;
             $265 = (($264) + 92|0);
             $266 = HEAP32[$265>>2]|0;
             $267 = Math_imul($266, $237)|0;
             $268 = (($101) + ($267)|0);
             HEAP8[$268>>0] = 63;
             $$0$be = $142;$$01$be = $132;$V_0$1$be = $253;
             break;
            }
           } else {
            $332 = HEAP8[$100>>0]|0;
            $333 = ($332<<24>>24)==(0);
            $334 = (($V_0$129) + 1)|0;
            if ($333) {
             $402 = $128&255;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $403 = __THREW__; __THREW__ = 0;
             $404 = $403&1;
             if ($404) {
              label = 5;
              break L41;
             }
             $405 = ($V_0$129|0)<(0);
             if ($405) {
              label = 152;
             } else {
              $406 = HEAP32[$75>>2]|0;
              $407 = ($V_0$129>>>0)<($406>>>0);
              if (!($407)) {
               label = 152;
              }
             }
             if ((label|0) == 152) {
              label = 0;
              __THREW__ = 0;
              $408 = (invoke_i(132)|0);
              $409 = __THREW__; __THREW__ = 0;
              $410 = $409&1;
              if ($410) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($408|0));
              $411 = __THREW__; __THREW__ = 0;
              $412 = $411&1;
              if ($412) {
               label = 5;
               break L41;
              }
             }
             $413 = HEAP32[$bytes>>2]|0;
             $414 = (($413) + 92|0);
             $415 = HEAP32[$414>>2]|0;
             $416 = Math_imul($415, $V_0$129)|0;
             $417 = (($101) + ($416)|0);
             HEAP8[$417>>0] = $402;
             $418 = (($V_0$129) + 2)|0;
             $419 = ($128&65535) >>> 8;
             $420 = $419&255;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $421 = __THREW__; __THREW__ = 0;
             $422 = $421&1;
             if ($422) {
              label = 5;
              break L41;
             }
             $423 = ($334|0)<(0);
             if ($423) {
              label = 157;
             } else {
              $424 = HEAP32[$75>>2]|0;
              $425 = ($334>>>0)<($424>>>0);
              if (!($425)) {
               label = 157;
              }
             }
             if ((label|0) == 157) {
              label = 0;
              __THREW__ = 0;
              $426 = (invoke_i(132)|0);
              $427 = __THREW__; __THREW__ = 0;
              $428 = $427&1;
              if ($428) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($426|0));
              $429 = __THREW__; __THREW__ = 0;
              $430 = $429&1;
              if ($430) {
               label = 5;
               break L41;
              }
             }
             $431 = HEAP32[$bytes>>2]|0;
             $432 = (($431) + 92|0);
             $433 = HEAP32[$432>>2]|0;
             $434 = Math_imul($433, $334)|0;
             $435 = (($101) + ($434)|0);
             HEAP8[$435>>0] = $420;
             $436 = (($V_0$129) + 3)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $437 = __THREW__; __THREW__ = 0;
             $438 = $437&1;
             if ($438) {
              label = 5;
              break L41;
             }
             $439 = ($418|0)<(0);
             if ($439) {
              label = 162;
             } else {
              $440 = HEAP32[$75>>2]|0;
              $441 = ($418>>>0)<($440>>>0);
              if (!($441)) {
               label = 162;
              }
             }
             if ((label|0) == 162) {
              label = 0;
              __THREW__ = 0;
              $442 = (invoke_i(132)|0);
              $443 = __THREW__; __THREW__ = 0;
              $444 = $443&1;
              if ($444) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($442|0));
              $445 = __THREW__; __THREW__ = 0;
              $446 = $445&1;
              if ($446) {
               label = 5;
               break L41;
              }
             }
             $447 = HEAP32[$bytes>>2]|0;
             $448 = (($447) + 92|0);
             $449 = HEAP32[$448>>2]|0;
             $450 = Math_imul($449, $418)|0;
             $451 = (($101) + ($450)|0);
             HEAP8[$451>>0] = 0;
             $452 = (($V_0$129) + 4)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $453 = __THREW__; __THREW__ = 0;
             $454 = $453&1;
             if ($454) {
              label = 5;
              break L41;
             }
             $455 = ($436|0)<(0);
             if ($455) {
              label = 167;
             } else {
              $456 = HEAP32[$75>>2]|0;
              $457 = ($436>>>0)<($456>>>0);
              if (!($457)) {
               label = 167;
              }
             }
             if ((label|0) == 167) {
              label = 0;
              __THREW__ = 0;
              $458 = (invoke_i(132)|0);
              $459 = __THREW__; __THREW__ = 0;
              $460 = $459&1;
              if ($460) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($458|0));
              $461 = __THREW__; __THREW__ = 0;
              $462 = $461&1;
              if ($462) {
               label = 5;
               break L41;
              }
             }
             $463 = HEAP32[$bytes>>2]|0;
             $464 = (($463) + 92|0);
             $465 = HEAP32[$464>>2]|0;
             $466 = Math_imul($465, $436)|0;
             $467 = (($101) + ($466)|0);
             HEAP8[$467>>0] = 0;
             $$0$be = $142;$$01$be = $468;$V_0$1$be = $452;
             break;
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $335 = __THREW__; __THREW__ = 0;
             $336 = $335&1;
             if ($336) {
              label = 5;
              break L41;
             }
             $337 = ($V_0$129|0)<(0);
             if ($337) {
              label = 130;
             } else {
              $338 = HEAP32[$75>>2]|0;
              $339 = ($V_0$129>>>0)<($338>>>0);
              if (!($339)) {
               label = 130;
              }
             }
             if ((label|0) == 130) {
              label = 0;
              __THREW__ = 0;
              $340 = (invoke_i(132)|0);
              $341 = __THREW__; __THREW__ = 0;
              $342 = $341&1;
              if ($342) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($340|0));
              $343 = __THREW__; __THREW__ = 0;
              $344 = $343&1;
              if ($344) {
               label = 5;
               break L41;
              }
             }
             $345 = HEAP32[$bytes>>2]|0;
             $346 = (($345) + 92|0);
             $347 = HEAP32[$346>>2]|0;
             $348 = Math_imul($347, $V_0$129)|0;
             $349 = (($101) + ($348)|0);
             HEAP8[$349>>0] = 0;
             $350 = (($V_0$129) + 2)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $351 = __THREW__; __THREW__ = 0;
             $352 = $351&1;
             if ($352) {
              label = 5;
              break L41;
             }
             $353 = ($334|0)<(0);
             if ($353) {
              label = 135;
             } else {
              $354 = HEAP32[$75>>2]|0;
              $355 = ($334>>>0)<($354>>>0);
              if (!($355)) {
               label = 135;
              }
             }
             if ((label|0) == 135) {
              label = 0;
              __THREW__ = 0;
              $356 = (invoke_i(132)|0);
              $357 = __THREW__; __THREW__ = 0;
              $358 = $357&1;
              if ($358) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($356|0));
              $359 = __THREW__; __THREW__ = 0;
              $360 = $359&1;
              if ($360) {
               label = 5;
               break L41;
              }
             }
             $361 = HEAP32[$bytes>>2]|0;
             $362 = (($361) + 92|0);
             $363 = HEAP32[$362>>2]|0;
             $364 = Math_imul($363, $334)|0;
             $365 = (($101) + ($364)|0);
             HEAP8[$365>>0] = 0;
             $366 = (($V_0$129) + 3)|0;
             $367 = ($128&65535) >>> 8;
             $368 = $367&255;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $369 = __THREW__; __THREW__ = 0;
             $370 = $369&1;
             if ($370) {
              label = 5;
              break L41;
             }
             $371 = ($350|0)<(0);
             if ($371) {
              label = 140;
             } else {
              $372 = HEAP32[$75>>2]|0;
              $373 = ($350>>>0)<($372>>>0);
              if (!($373)) {
               label = 140;
              }
             }
             if ((label|0) == 140) {
              label = 0;
              __THREW__ = 0;
              $374 = (invoke_i(132)|0);
              $375 = __THREW__; __THREW__ = 0;
              $376 = $375&1;
              if ($376) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($374|0));
              $377 = __THREW__; __THREW__ = 0;
              $378 = $377&1;
              if ($378) {
               label = 5;
               break L41;
              }
             }
             $379 = HEAP32[$bytes>>2]|0;
             $380 = (($379) + 92|0);
             $381 = HEAP32[$380>>2]|0;
             $382 = Math_imul($381, $350)|0;
             $383 = (($101) + ($382)|0);
             HEAP8[$383>>0] = $368;
             $384 = (($V_0$129) + 4)|0;
             $385 = $128&255;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $386 = __THREW__; __THREW__ = 0;
             $387 = $386&1;
             if ($387) {
              label = 5;
              break L41;
             }
             $388 = ($366|0)<(0);
             if ($388) {
              label = 145;
             } else {
              $389 = HEAP32[$75>>2]|0;
              $390 = ($366>>>0)<($389>>>0);
              if (!($390)) {
               label = 145;
              }
             }
             if ((label|0) == 145) {
              label = 0;
              __THREW__ = 0;
              $391 = (invoke_i(132)|0);
              $392 = __THREW__; __THREW__ = 0;
              $393 = $392&1;
              if ($393) {
               label = 5;
               break L41;
              }
              __THREW__ = 0;
              invoke_vi(3302,($391|0));
              $394 = __THREW__; __THREW__ = 0;
              $395 = $394&1;
              if ($395) {
               label = 5;
               break L41;
              }
             }
             $396 = HEAP32[$bytes>>2]|0;
             $397 = (($396) + 92|0);
             $398 = HEAP32[$397>>2]|0;
             $399 = Math_imul($398, $366)|0;
             $400 = (($101) + ($399)|0);
             HEAP8[$400>>0] = $385;
             $$0$be = $142;$$01$be = $468;$V_0$1$be = $384;
             break;
            }
           }
          } while(0);
          $401 = ($$01$be|0)>(0);
          if ($401) {
           $$031 = $$0$be;$$in = $$01$be;$V_0$129 = $V_0$1$be;
          } else {
           $V_0$1$lcssa = $V_0$1$be;
           label = 171;
           break;
          }
         }
         if ((label|0) == 3) {
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index4 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 4) {
          $5 = ___cxa_find_matching_catch()|0;
          $6 = tempRet0;
          $lpad$phi$index = $5;$lpad$phi$index4 = $6;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 5) {
          $7 = ___cxa_find_matching_catch()|0;
          $8 = tempRet0;
          $lpad$phi$index = $7;$lpad$phi$index4 = $8;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 171) {
          $471 = (($V_0$1$lcssa) - ($byteIndex))|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($471|0);
         }
        }
       }
       $78 = HEAP32[3057472>>2]|0;
       __THREW__ = 0;
       $79 = (invoke_iii(977,0,($78|0))|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       __THREW__ = 0;
       $84 = (invoke_ii(3469,(2561352|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       $87 = HEAP32[3057464>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($84|0),($87|0),($79|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($84|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        break;
       }
       // unreachable;
      }
     }
     $58 = HEAP32[3057456>>2]|0;
     __THREW__ = 0;
     $59 = (invoke_iii(977,0,($58|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     $64 = (invoke_ii(3469,(2561352|0))|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break;
     }
     $67 = HEAP32[3057448>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($64|0),($67|0),($59|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($64|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     }
     // unreachable;
    }
   }
   $38 = HEAP32[3057440>>2]|0;
   __THREW__ = 0;
   $39 = (invoke_iii(977,0,($38|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     __THREW__ = 0;
     $44 = (invoke_ii(3469,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      $47 = HEAP32[3057432>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($44|0),($47|0),($39|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if (!($49)) {
       __THREW__ = 0;
       invoke_vi(3838,($44|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if (!($51)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index4 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Text_UTF32Encoding_m_GetCharCountP34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538216);
 __THREW__ = 0;
 invoke_v(732);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3057496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($bytes) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       $55 = (($count|0) / 4)&-1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($55|0);
      }
     }
     $41 = HEAP32[3057528>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3057520>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3057512>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3057504>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_Text_UTF32Encoding_m_GetCharsP34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 var $$0125 = 0, $$026 = 0, $$117 = 0, $$1216 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $V_0$024 = 0, $V_0$115 = 0, $V_0$2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538264);
 __THREW__ = 0;
 invoke_v(733);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3057544>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($chars|0)==(0|0);
   if ($19) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2560584|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3057552>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($22|0),($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($byteIndex|0)<(0);
   if (!($30)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    $33 = (($bytes) + 12|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ($34|0)<($byteIndex|0);
    if (!($35)) {
     $50 = ($byteCount|0)<(0);
     if (!($50)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break;
      }
      $53 = HEAP32[$33>>2]|0;
      $54 = (($53) - ($byteIndex))|0;
      $55 = ($54|0)<($byteCount|0);
      if (!($55)) {
       $70 = ($charIndex|0)<(0);
       if (!($70)) {
        __THREW__ = 0;
        invoke_vi(3799,($chars|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         break;
        }
        $73 = (($chars) + 12|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ($74|0)<($charIndex|0);
        if (!($75)) {
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break;
         }
         $92 = HEAP32[$73>>2]|0;
         $93 = (($92) - ($charIndex))|0;
         $94 = (($byteCount|0) / 4)&-1;
         $95 = ($93|0)<($94|0);
         if ($95) {
          $96 = HEAP32[3057608>>2]|0;
          __THREW__ = 0;
          $97 = (invoke_iii(977,0,($96|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          __THREW__ = 0;
          $102 = (invoke_ii(3469,(2560072|0))|0);
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1924,($102|0),($97|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3838,($102|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if ($108) {
           break;
          }
          // unreachable;
         }
         $109 = (($__this) + 48|0);
         $110 = HEAP8[$109>>0]|0;
         $111 = ($110<<24>>24)==(0);
         $112 = ($byteCount|0)>(3);
         if ($111) {
          if (!($112)) {
           $V_0$2 = $charIndex;
           $275 = (($V_0$2) - ($charIndex))|0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($275|0);
          }
          $115 = (($bytes) + 16|0);
          $116 = (($chars) + 16|0);
          $$117 = $byteIndex;$$1216 = $byteCount;$V_0$115 = $charIndex;
          while(1) {
           $272 = (($V_0$115) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $273 = __THREW__; __THREW__ = 0;
           $274 = $273&1;
           if ($274) {
            break;
           }
           $196 = ($$117|0)<(0);
           if ($196) {
            label = 86;
           } else {
            $197 = HEAP32[$33>>2]|0;
            $198 = ($$117>>>0)<($197>>>0);
            if (!($198)) {
             label = 86;
            }
           }
           if ((label|0) == 86) {
            label = 0;
            __THREW__ = 0;
            $199 = (invoke_i(132)|0);
            $200 = __THREW__; __THREW__ = 0;
            $201 = $200&1;
            if ($201) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($199|0));
            $202 = __THREW__; __THREW__ = 0;
            $203 = $202&1;
            if ($203) {
             break;
            }
           }
           $204 = HEAP32[$bytes>>2]|0;
           $205 = (($204) + 92|0);
           $206 = HEAP32[$205>>2]|0;
           $207 = Math_imul($206, $$117)|0;
           $208 = (($115) + ($207)|0);
           $209 = HEAP8[$208>>0]|0;
           $210 = (($$117) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $211 = __THREW__; __THREW__ = 0;
           $212 = $211&1;
           if ($212) {
            break;
           }
           $213 = ($210|0)<(0);
           if ($213) {
            label = 91;
           } else {
            $214 = HEAP32[$33>>2]|0;
            $215 = ($210>>>0)<($214>>>0);
            if (!($215)) {
             label = 91;
            }
           }
           if ((label|0) == 91) {
            label = 0;
            __THREW__ = 0;
            $216 = (invoke_i(132)|0);
            $217 = __THREW__; __THREW__ = 0;
            $218 = $217&1;
            if ($218) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($216|0));
            $219 = __THREW__; __THREW__ = 0;
            $220 = $219&1;
            if ($220) {
             break;
            }
           }
           $221 = HEAP32[$bytes>>2]|0;
           $222 = (($221) + 92|0);
           $223 = HEAP32[$222>>2]|0;
           $224 = Math_imul($223, $210)|0;
           $225 = (($115) + ($224)|0);
           $226 = HEAP8[$225>>0]|0;
           $227 = $226&255;
           $228 = $227 << 8;
           $229 = $209&255;
           $230 = $228 | $229;
           $231 = (($$117) + 2)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $232 = __THREW__; __THREW__ = 0;
           $233 = $232&1;
           if ($233) {
            break;
           }
           $234 = ($231|0)<(0);
           if ($234) {
            label = 96;
           } else {
            $235 = HEAP32[$33>>2]|0;
            $236 = ($231>>>0)<($235>>>0);
            if (!($236)) {
             label = 96;
            }
           }
           if ((label|0) == 96) {
            label = 0;
            __THREW__ = 0;
            $237 = (invoke_i(132)|0);
            $238 = __THREW__; __THREW__ = 0;
            $239 = $238&1;
            if ($239) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($237|0));
            $240 = __THREW__; __THREW__ = 0;
            $241 = $240&1;
            if ($241) {
             break;
            }
           }
           $242 = (($$117) + 3)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $243 = __THREW__; __THREW__ = 0;
           $244 = $243&1;
           if ($244) {
            break;
           }
           $245 = ($242|0)<(0);
           if ($245) {
            label = 101;
           } else {
            $246 = HEAP32[$33>>2]|0;
            $247 = ($242>>>0)<($246>>>0);
            if (!($247)) {
             label = 101;
            }
           }
           if ((label|0) == 101) {
            label = 0;
            __THREW__ = 0;
            $248 = (invoke_i(132)|0);
            $249 = __THREW__; __THREW__ = 0;
            $250 = $249&1;
            if ($250) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($248|0));
            $251 = __THREW__; __THREW__ = 0;
            $252 = $251&1;
            if ($252) {
             break;
            }
           }
           $253 = $230&65535;
           __THREW__ = 0;
           invoke_vi(3799,($chars|0));
           $254 = __THREW__; __THREW__ = 0;
           $255 = $254&1;
           if ($255) {
            break;
           }
           $256 = ($V_0$115|0)<(0);
           if ($256) {
            label = 106;
           } else {
            $257 = HEAP32[$73>>2]|0;
            $258 = ($V_0$115>>>0)<($257>>>0);
            if (!($258)) {
             label = 106;
            }
           }
           if ((label|0) == 106) {
            label = 0;
            __THREW__ = 0;
            $259 = (invoke_i(132)|0);
            $260 = __THREW__; __THREW__ = 0;
            $261 = $260&1;
            if ($261) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($259|0));
            $262 = __THREW__; __THREW__ = 0;
            $263 = $262&1;
            if ($263) {
             break;
            }
           }
           $264 = HEAP32[$chars>>2]|0;
           $265 = (($264) + 92|0);
           $266 = HEAP32[$265>>2]|0;
           $267 = Math_imul($266, $V_0$115)|0;
           $268 = (($116) + ($267)|0);
           HEAP16[$268>>1] = $253;
           $269 = (($$117) + 4)|0;
           $270 = (($$1216) + -4)|0;
           $271 = ($270|0)>(3);
           if ($271) {
            $$117 = $269;$$1216 = $270;$V_0$115 = $272;
           } else {
            $V_0$2 = $272;
            label = 110;
            break;
           }
          }
          if ((label|0) == 110) {
           $275 = (($V_0$2) - ($charIndex))|0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($275|0);
          }
          $3 = ___cxa_find_matching_catch()|0;
          $4 = tempRet0;
          $lpad$phi$index = $3;$lpad$phi$index3 = $4;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         } else {
          if (!($112)) {
           $V_0$2 = $charIndex;
           $275 = (($V_0$2) - ($charIndex))|0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($275|0);
          }
          $113 = (($bytes) + 16|0);
          $114 = (($chars) + 16|0);
          $$0125 = $byteCount;$$026 = $byteIndex;$V_0$024 = $charIndex;
          while(1) {
           $193 = (($V_0$024) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $194 = __THREW__; __THREW__ = 0;
           $195 = $194&1;
           if ($195) {
            break;
           }
           $117 = ($$026|0)<(0);
           if ($117) {
            label = 60;
           } else {
            $118 = HEAP32[$33>>2]|0;
            $119 = ($$026>>>0)<($118>>>0);
            if (!($119)) {
             label = 60;
            }
           }
           if ((label|0) == 60) {
            label = 0;
            __THREW__ = 0;
            $120 = (invoke_i(132)|0);
            $121 = __THREW__; __THREW__ = 0;
            $122 = $121&1;
            if ($122) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($120|0));
            $123 = __THREW__; __THREW__ = 0;
            $124 = $123&1;
            if ($124) {
             break;
            }
           }
           $125 = (($$026) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            break;
           }
           $128 = ($125|0)<(0);
           if ($128) {
            label = 65;
           } else {
            $129 = HEAP32[$33>>2]|0;
            $130 = ($125>>>0)<($129>>>0);
            if (!($130)) {
             label = 65;
            }
           }
           if ((label|0) == 65) {
            label = 0;
            __THREW__ = 0;
            $131 = (invoke_i(132)|0);
            $132 = __THREW__; __THREW__ = 0;
            $133 = $132&1;
            if ($133) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($131|0));
            $134 = __THREW__; __THREW__ = 0;
            $135 = $134&1;
            if ($135) {
             break;
            }
           }
           $136 = (($$026) + 2)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $137 = __THREW__; __THREW__ = 0;
           $138 = $137&1;
           if ($138) {
            break;
           }
           $139 = ($136|0)<(0);
           if ($139) {
            label = 70;
           } else {
            $140 = HEAP32[$33>>2]|0;
            $141 = ($136>>>0)<($140>>>0);
            if (!($141)) {
             label = 70;
            }
           }
           if ((label|0) == 70) {
            label = 0;
            __THREW__ = 0;
            $142 = (invoke_i(132)|0);
            $143 = __THREW__; __THREW__ = 0;
            $144 = $143&1;
            if ($144) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($142|0));
            $145 = __THREW__; __THREW__ = 0;
            $146 = $145&1;
            if ($146) {
             break;
            }
           }
           $147 = HEAP32[$bytes>>2]|0;
           $148 = (($147) + 92|0);
           $149 = HEAP32[$148>>2]|0;
           $150 = Math_imul($149, $136)|0;
           $151 = (($113) + ($150)|0);
           $152 = HEAP8[$151>>0]|0;
           $153 = $152&255;
           $154 = $153 << 8;
           $155 = (($$026) + 3)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            break;
           }
           $158 = ($155|0)<(0);
           if ($158) {
            label = 75;
           } else {
            $159 = HEAP32[$33>>2]|0;
            $160 = ($155>>>0)<($159>>>0);
            if (!($160)) {
             label = 75;
            }
           }
           if ((label|0) == 75) {
            label = 0;
            __THREW__ = 0;
            $161 = (invoke_i(132)|0);
            $162 = __THREW__; __THREW__ = 0;
            $163 = $162&1;
            if ($163) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($161|0));
            $164 = __THREW__; __THREW__ = 0;
            $165 = $164&1;
            if ($165) {
             break;
            }
           }
           $166 = HEAP32[$bytes>>2]|0;
           $167 = (($166) + 92|0);
           $168 = HEAP32[$167>>2]|0;
           $169 = Math_imul($168, $155)|0;
           $170 = (($113) + ($169)|0);
           $171 = HEAP8[$170>>0]|0;
           $172 = $171&255;
           $173 = $172 | $154;
           $174 = $173&65535;
           __THREW__ = 0;
           invoke_vi(3799,($chars|0));
           $175 = __THREW__; __THREW__ = 0;
           $176 = $175&1;
           if ($176) {
            break;
           }
           $177 = ($V_0$024|0)<(0);
           if ($177) {
            label = 80;
           } else {
            $178 = HEAP32[$73>>2]|0;
            $179 = ($V_0$024>>>0)<($178>>>0);
            if (!($179)) {
             label = 80;
            }
           }
           if ((label|0) == 80) {
            label = 0;
            __THREW__ = 0;
            $180 = (invoke_i(132)|0);
            $181 = __THREW__; __THREW__ = 0;
            $182 = $181&1;
            if ($182) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($180|0));
            $183 = __THREW__; __THREW__ = 0;
            $184 = $183&1;
            if ($184) {
             break;
            }
           }
           $185 = HEAP32[$chars>>2]|0;
           $186 = (($185) + 92|0);
           $187 = HEAP32[$186>>2]|0;
           $188 = Math_imul($187, $V_0$024)|0;
           $189 = (($114) + ($188)|0);
           HEAP16[$189>>1] = $174;
           $190 = (($$026) + 4)|0;
           $191 = (($$0125) + -4)|0;
           $192 = ($191|0)>(3);
           if ($192) {
            $$0125 = $191;$$026 = $190;$V_0$024 = $193;
           } else {
            $V_0$2 = $193;
            label = 110;
            break;
           }
          }
          if ((label|0) == 110) {
           $275 = (($V_0$2) - ($charIndex))|0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($275|0);
          }
          $5 = ___cxa_find_matching_catch()|0;
          $6 = tempRet0;
          $lpad$phi$index = $5;$lpad$phi$index3 = $6;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
        }
       }
       $76 = HEAP32[3057600>>2]|0;
       __THREW__ = 0;
       $77 = (invoke_iii(977,0,($76|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
       __THREW__ = 0;
       $82 = (invoke_ii(3469,(2561352|0))|0);
       $83 = __THREW__; __THREW__ = 0;
       $84 = $83&1;
       if ($84) {
        break;
       }
       $85 = HEAP32[3057592>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($82|0),($85|0),($77|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($82|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       // unreachable;
      }
     }
     $56 = HEAP32[3057584>>2]|0;
     __THREW__ = 0;
     $57 = (invoke_iii(977,0,($56|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     $62 = (invoke_ii(3469,(2561352|0))|0);
     $63 = __THREW__; __THREW__ = 0;
     $64 = $63&1;
     if ($64) {
      break;
     }
     $65 = HEAP32[3057576>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($62|0),($65|0),($57|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($62|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     // unreachable;
    }
   }
   $36 = HEAP32[3057568>>2]|0;
   __THREW__ = 0;
   $37 = (invoke_iii(977,0,($36|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if (!($41)) {
     __THREW__ = 0;
     $42 = (invoke_ii(3469,(2561352|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      $45 = HEAP32[3057560>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($42|0),($45|0),($37|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       invoke_vi(3838,($42|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Text_UTF32Encoding_m_EqualsP34mscorlib_System_Text_UTF32EncodingP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538312);
 __THREW__ = 0;
 (invoke_ii(2996,(2539360|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2539360|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = (($__this) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($2) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($9|0)==($13|0);
    if (!($14)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $15 = (($__this) + 48|0);
    $16 = HEAP8[$15>>0]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($2) + 48|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = ($16<<24>>24)==($20<<24>>24);
     if (!($21)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $22 = (($__this) + 49|0);
     $23 = HEAP8[$22>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = (($2) + 49|0);
      $27 = HEAP8[$26>>0]|0;
      $28 = ($23<<24>>24)==($27<<24>>24);
      if (!($28)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      $29 = (invoke_iii(978,($__this|0),($value|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       $$0 = $29;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Text_UTF32Encoding_m_GetHashCodeP34mscorlib_System_Text_UTF32Encoding($__this) {
 $__this = $__this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538360);
 __THREW__ = 0;
 $0 = (invoke_ii(2383,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 } else {
  $3 = (($__this) + 48|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  $6 = $0 ^ 31;
  $$ = $5 ? $0 : $6;
  $7 = (($__this) + 49|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  $10 = $$ ^ 63;
  $V_0$1 = $9 ? $$ : $10;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_0$1|0);
 }
 return 0|0;
}
function __Z123mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P34mscorlib_System_Text_UTF32EncodingPti($__this,$chars,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538408);
 __THREW__ = 0;
 invoke_v(734);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($chars|0)==(0|0);
  if (!($2)) {
   $15 = $count << 2;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($15|0);
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3057624>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3838,($7|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP34mscorlib_System_Text_UTF32EncodingP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538456);
 __THREW__ = 0;
 $0 = (invoke_iii(979,($__this|0),($s|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z171mscorlib_System_Text_UTF32Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P34mscorlib_System_Text_UTF32EncodingPtiPhi($__this,$chars,$charCount,$bytes,$byteCount) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538504);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(116,($__this|0),($chars|0),($charCount|0),($bytes|0),($byteCount|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z46mscorlib_System_Text_UTF32Encoding_m_GetStringP34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2538552);
 __THREW__ = 0;
 $0 = (invoke_iiiii(157,($__this|0),($bytes|0),($index|0),($count|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker2I29mscorlib_System_BooleanTraitsS0_E6InvokeEPFvPvbbES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 FUNCTION_TABLE_viii[$action & 4095]($obj,$2,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I29mscorlib_System_BooleanTraitsS0_S0_E6InvokeEPFvPvbbbES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($args) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 FUNCTION_TABLE_viiii[$action & 511]($obj,$2,$6,$10);
 STACKTOP = sp;return (0|0);
}
function __Z210mscorlib_System_Text_UTF32Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2539160)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z257mscorlib_System_Text_UTF32Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF32Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2539160)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z189mscorlib_System_Text_UTF32Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z237mscorlib_System_Text_UTF32Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF32Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z86mscorlib_System_Text_UTF7Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP33mscorlib_System_Text_UTF7Encodingb($__this,$allowOptionals) {
 $__this = $__this|0;
 $allowOptionals = $allowOptionals|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539544);
 __THREW__ = 0;
 invoke_v(735);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(1909,($__this|0),65000);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  $4 = (($__this) + 48|0);
  $5 = $allowOptionals&1;
  HEAP8[$4>>0] = $5;
  $6 = HEAP32[3057640>>2]|0;
  $7 = (($__this) + 28|0);
  HEAP32[$7>>2] = $6;
  $8 = HEAP32[3057648>>2]|0;
  $9 = (($__this) + 32|0);
  HEAP32[$9>>2] = $8;
  $10 = HEAP32[3057656>>2]|0;
  $11 = (($__this) + 36|0);
  HEAP32[$11>>2] = $10;
  $12 = (($__this) + 40|0);
  HEAP8[$12>>0] = 1;
  $13 = (($__this) + 41|0);
  HEAP8[$13>>0] = 1;
  $14 = HEAP32[3057664>>2]|0;
  $15 = (($__this) + 44|0);
  HEAP32[$15>>2] = $14;
  $16 = (($__this) + 12|0);
  HEAP32[$16>>2] = 1200;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42mscorlib_System_Text_UTF7Encoding_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539592);
 __THREW__ = 0;
 (invoke_ii(2996,(1203320|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2768,(1203320|0),128)|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   HEAP32[$0>>2] = 2667288;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
   invoke_viii(551,(0|0),($4|0),($$byval_copy1|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2541528|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[((2541528 + 80|0))>>2]|0;
     HEAP32[$11>>2] = $4;
     __THREW__ = 0;
     (invoke_ii(2996,(1217360|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      $14 = (invoke_iii(2768,(1217360|0),256)|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       HEAP32[$1>>2] = 2667328;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
       invoke_viii(551,(0|0),($14|0),($$byval_copy1|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2541528|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         $21 = HEAP32[((2541528 + 80|0))>>2]|0;
         $22 = (($21) + 4|0);
         HEAP32[$22>>2] = $14;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
}
function __Z47mscorlib_System_Text_UTF7Encoding_m_GetHashCodeP33mscorlib_System_Text_UTF7Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539640);
 __THREW__ = 0;
 $0 = (invoke_ii(2383,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $3 = (($__this) + 48|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  $6 = (0 - ($0))|0;
  $G_B3_0$0 = $5 ? $0 : $6;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 return 0|0;
}
function __Z42mscorlib_System_Text_UTF7Encoding_m_EqualsP33mscorlib_System_Text_UTF7EncodingP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539688);
 __THREW__ = 0;
 (invoke_ii(2996,(2541528|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2541528|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = (($__this) + 48|0);
   $9 = HEAP8[$8>>0]|0;
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($2) + 48|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = ($9<<24>>24)==($13<<24>>24);
    if (!($14)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $15 = (invoke_ii(2382,($__this|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      $20 = (invoke_ii(2382,($2|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       invoke_vi(3799,($15|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_iiii(1644,(2148736|0),($15|0),($20|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         if (!($25)) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $28 = (invoke_ii(2381,($__this|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          __THREW__ = 0;
          invoke_vi(3799,($2|0));
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           $33 = (invoke_ii(2381,($2|0))|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            __THREW__ = 0;
            invoke_vi(3799,($28|0));
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if (!($37)) {
             __THREW__ = 0;
             $38 = (invoke_iiii(1644,(2148736|0),($28|0),($33|0))|0);
             $39 = __THREW__; __THREW__ = 0;
             $40 = $39&1;
             if (!($40)) {
              $$0 = $38;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_Text_UTF7Encoding_m_InternalGetByteCountP22mscorlib_System_ObjectP24mscorlib_System_Char_arriibibb($__this,$chars,$index,$count,$flush,$leftOver,$isInShifted,$allowOptionals) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 $flush = $flush|0;
 $leftOver = $leftOver|0;
 $isInShifted = $isInShifted|0;
 $allowOptionals = $allowOptionals|0;
 var $$0 = 0, $$0$ph = 0, $$01 = 0, $$01$ph = 0, $$3$off0$ph = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$3 = 0, $V_0$5 = 0, $V_0$6$ = 0, $V_0$6$10 = 0;
 var $V_0$6$12 = 0, $V_0$6$13 = 0, $V_0$6$ph = 0, $V_0$8 = 0, $V_1$3 = 0, $V_1$5 = 0, $V_1$6$op = 0, $V_1$6$ph = 0, $_stackTraceSentry = 0, $brmerge$demorgan = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$ = 0, $not$22 = 0, $not$23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539736);
 __THREW__ = 0;
 invoke_v(736);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3057728>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($index|0)<(0);
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = (($chars) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)<($index|0);
    if (!($22)) {
     $37 = ($count|0)<(0);
     if (!($37)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      $40 = HEAP32[$20>>2]|0;
      $41 = (($40) - ($index))|0;
      $42 = ($41|0)<($count|0);
      if (!($42)) {
       $57 = $leftOver >> 8;
       __THREW__ = 0;
       (invoke_ii(2996,(2541528|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
       $60 = HEAP8[((2541528 + 116|0))>>0]|0;
       $61 = ($60<<24>>24)==(0);
       if ($61) {
        __THREW__ = 0;
        (invoke_ii(2996,(2541528|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2541528|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2541528|0));
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2541528|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       $70 = HEAP32[((2541528 + 80|0))>>2]|0;
       $71 = HEAP32[$70>>2]|0;
       $72 = (($chars) + 16|0);
       $73 = (($71) + 12|0);
       $74 = (($71) + 16|0);
       $$0$ph = $index;$$01$ph = $count;$$3$off0$ph = $isInShifted;$V_0$6$ph = 0;$V_1$6$ph = $57;
       L25: while(1) {
        $$0 = $$0$ph;$$01 = $$01$ph;
        while(1) {
         $125 = ($$01|0)>(0);
         if (!($125)) {
          break L25;
         }
         $126 = (($$0) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          label = 3;
          break L25;
         }
         $75 = ($$0|0)<(0);
         if ($75) {
          label = 38;
         } else {
          $76 = HEAP32[$20>>2]|0;
          $77 = ($$0>>>0)<($76>>>0);
          if (!($77)) {
           label = 38;
          }
         }
         if ((label|0) == 38) {
          label = 0;
          __THREW__ = 0;
          $78 = (invoke_i(132)|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           label = 3;
           break L25;
          }
          __THREW__ = 0;
          invoke_vi(3302,($78|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           label = 3;
           break L25;
          }
         }
         $83 = HEAP32[$chars>>2]|0;
         $84 = (($83) + 92|0);
         $85 = HEAP32[$84>>2]|0;
         $86 = Math_imul($85, $$0)|0;
         $87 = (($72) + ($86)|0);
         $88 = HEAP16[$87>>1]|0;
         $89 = $88&65535;
         $90 = (($$01) + -1)|0;
         $91 = ($88&65535)>(127);
         if ($91) {
          label = 46;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($71|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          label = 3;
          break L25;
         }
         $94 = HEAP32[$73>>2]|0;
         $95 = ($89>>>0)<($94>>>0);
         if (!($95)) {
          __THREW__ = 0;
          $96 = (invoke_i(132)|0);
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if ($98) {
           label = 3;
           break L25;
          }
          __THREW__ = 0;
          invoke_vi(3302,($96|0));
          $99 = __THREW__; __THREW__ = 0;
          $100 = $99&1;
          if ($100) {
           label = 3;
           break L25;
          }
         }
         $101 = HEAP32[$71>>2]|0;
         $102 = (($101) + 92|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = Math_imul($103, $89)|0;
         $105 = (($74) + ($104)|0);
         $106 = HEAP8[$105>>0]|0;
         $107 = $106&255;
         if ((($107|0) == 0)) {
          label = 46;
          break;
         } else if ((($107|0) == 1)) {
          break;
         } else if ((($107|0) == 2)) {
          label = 51;
          break;
         } else if ((($107|0) == 3)) {
          label = 52;
          break;
         } else {
          $$0 = $126;$$01 = $90;
         }
        }
        if ((label|0) == 51) {
         label = 0;
         if (!($allowOptionals)) {
          label = 46;
         }
        }
        else if ((label|0) == 52) {
         label = 0;
         if ($$3$off0$ph) {
          $not$22 = ($V_1$6$ph|0)!=(0);
          $122 = $not$22&1;
          $V_0$6$12 = (($V_0$6$ph) + 1)|0;
          $123 = (($V_0$6$12) + ($122))|0;
          $V_0$5 = $123;$V_1$5 = 0;
         } else {
          $V_0$5 = $V_0$6$ph;$V_1$5 = $V_1$6$ph;
         }
         $124 = (($V_0$5) + 2)|0;
         $$0$ph = $126;$$01$ph = $90;$$3$off0$ph = 0;$V_0$6$ph = $124;$V_1$6$ph = $V_1$5;
         continue;
        }
        if ((label|0) == 46) {
         label = 0;
         $108 = $$3$off0$ph&1;
         $109 = $108 ^ 1;
         $V_0$6$ = (($109) + ($V_0$6$ph))|0;
         $V_1$6$op = (($V_1$6$ph) + 16)|0;
         $110 = $$3$off0$ph ? $V_1$6$op : 16;
         $111 = ($110|0)>(5);
         if (!($111)) {
          $$0$ph = $126;$$01$ph = $90;$$3$off0$ph = 1;$V_0$6$ph = $V_0$6$;$V_1$6$ph = $V_1$6$op;
          continue;
         }
         $112 = (($110) + -6)|0;
         $113 = (($112>>>0) / 6)&-1;
         $114 = (($V_0$6$ph) + 1)|0;
         $115 = (($114) + ($109))|0;
         $116 = Math_imul($113, -6)|0;
         $117 = (($112) + ($116))|0;
         $118 = (($115) + ($113))|0;
         $$0$ph = $126;$$01$ph = $90;$$3$off0$ph = 1;$V_0$6$ph = $118;$V_1$6$ph = $117;
         continue;
        }
        if ($$3$off0$ph) {
         $not$23 = ($V_1$6$ph|0)!=(0);
         $119 = $not$23&1;
         $V_0$6$10 = (($V_0$6$ph) + 1)|0;
         $120 = (($V_0$6$10) + ($119))|0;
         $V_0$3 = $120;$V_1$3 = 0;
        } else {
         $V_0$3 = $V_0$6$ph;$V_1$3 = $V_1$6$ph;
        }
        $121 = (($V_0$3) + 1)|0;
        $$0$ph = $126;$$01$ph = $90;$$3$off0$ph = 0;$V_0$6$ph = $121;$V_1$6$ph = $V_1$3;
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       $brmerge$demorgan = $$3$off0$ph & $flush;
       if (!($brmerge$demorgan)) {
        $V_0$8 = $V_0$6$ph;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($V_0$8|0);
       }
       $not$ = ($V_1$6$ph|0)!=(0);
       $129 = $not$&1;
       $V_0$6$13 = (($V_0$6$ph) + 1)|0;
       $130 = (($V_0$6$13) + ($129))|0;
       $V_0$8 = $130;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($V_0$8|0);
      }
     }
     $43 = HEAP32[3057760>>2]|0;
     __THREW__ = 0;
     $44 = (invoke_iii(977,0,($43|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     __THREW__ = 0;
     $49 = (invoke_ii(3469,(2561352|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     $52 = HEAP32[3057752>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($49|0),($52|0),($44|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($49|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     // unreachable;
    }
   }
   $23 = HEAP32[3057744>>2]|0;
   __THREW__ = 0;
   $24 = (invoke_iii(977,0,($23|0))|0);
   $25 = __THREW__; __THREW__ = 0;
   $26 = $25&1;
   if (!($26)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     __THREW__ = 0;
     $29 = (invoke_ii(3469,(2561352|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      $32 = HEAP32[3057736>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($29|0),($32|0),($24|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       invoke_vi(3838,($29|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z143mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Char_arrii($__this,$chars,$index,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539784);
 $0 = (($__this) + 48|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __THREW__ = 0;
 $3 = (invoke_iiiiiiiii(20,0,($chars|0),($index|0),($count|0),1,0,0,($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Text_UTF7Encoding_m_InternalGetBytesP22mscorlib_System_ObjectP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arribPiPbb($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex,$flush,$leftOver,$isInShifted,$allowOptionals) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $flush = $flush|0;
 $leftOver = $leftOver|0;
 $isInShifted = $isInShifted|0;
 $allowOptionals = $allowOptionals|0;
 var $$0 = 0, $$0$ph = 0, $$01 = 0, $$01$ph = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$141 = 0, $V_0$2 = 0, $V_0$3 = 0, $V_0$4 = 0, $V_0$5 = 0, $V_0$6$ph = 0, $V_0$6$ph$phi = 0, $V_0$7 = 0, $V_0$8 = 0, $V_2$140 = 0;
 var $V_2$2 = 0, $V_2$3 = 0, $V_2$4$ph = 0, $V_2$5 = 0, $V_3$039 = 0, $V_3$1 = 0, $V_3$2 = 0, $V_3$3$ph = 0, $V_3$4 = 0, $_stackTraceSentry = 0, $brmerge = 0, $flush$not = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539832);
 __THREW__ = 0;
 invoke_v(737);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2560584|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[3057776>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($13|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($13|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    // unreachable;
   }
   $21 = ($bytes|0)==(0|0);
   if ($21) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2560584|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = HEAP32[3057784>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($24|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($24|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    // unreachable;
   }
   $32 = ($charIndex|0)<(0);
   if (!($32)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($chars) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)<($charIndex|0);
    if (!($37)) {
     $52 = ($charCount|0)<(0);
     if (!($52)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$35>>2]|0;
      $56 = (($55) - ($charIndex))|0;
      $57 = ($56|0)<($charCount|0);
      if (!($57)) {
       $72 = ($byteIndex|0)<(0);
       if (!($72)) {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         break;
        }
        $75 = (($bytes) + 12|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($76|0)<($byteIndex|0);
        if (!($77)) {
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          break;
         }
         $94 = HEAP32[$75>>2]|0;
         $95 = HEAP32[$leftOver>>2]|0;
         $96 = $95 >> 8;
         $97 = $95 & 255;
         __THREW__ = 0;
         (invoke_ii(2996,(2541528|0))|0);
         $98 = __THREW__; __THREW__ = 0;
         $99 = $98&1;
         if ($99) {
          break;
         }
         $100 = HEAP8[((2541528 + 116|0))>>0]|0;
         $101 = ($100<<24>>24)==(0);
         if ($101) {
          __THREW__ = 0;
          (invoke_ii(2996,(2541528|0))|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2541528|0))|0);
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2541528|0));
          $106 = __THREW__; __THREW__ = 0;
          $107 = $106&1;
          if ($107) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2541528|0))|0);
         $108 = __THREW__; __THREW__ = 0;
         $109 = $108&1;
         if ($109) {
          break;
         }
         $110 = HEAP32[((2541528 + 80|0))>>2]|0;
         $111 = HEAP32[$110>>2]|0;
         $112 = HEAP32[3057840>>2]|0;
         $113 = (($chars) + 16|0);
         $114 = (($111) + 12|0);
         $115 = (($111) + 16|0);
         $116 = (($bytes) + 16|0);
         $$0$ph = $charIndex;$$01$ph = $charCount;$V_0$6$ph = $byteIndex;$V_2$4$ph = $96;$V_3$3$ph = $97;
         L37: while(1) {
          $$0 = $$0$ph;$$01 = $$01$ph;
          while(1) {
           $460 = ($$01|0)>(0);
           if (!($460)) {
            label = 189;
            break L37;
           }
           $461 = (($$0) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($chars|0));
           $462 = __THREW__; __THREW__ = 0;
           $463 = $462&1;
           if ($463) {
            label = 4;
            break L37;
           }
           $117 = ($$0|0)<(0);
           if ($117) {
            label = 56;
           } else {
            $118 = HEAP32[$35>>2]|0;
            $119 = ($$0>>>0)<($118>>>0);
            if (!($119)) {
             label = 56;
            }
           }
           if ((label|0) == 56) {
            label = 0;
            __THREW__ = 0;
            $120 = (invoke_i(132)|0);
            $121 = __THREW__; __THREW__ = 0;
            $122 = $121&1;
            if ($122) {
             label = 4;
             break L37;
            }
            __THREW__ = 0;
            invoke_vi(3302,($120|0));
            $123 = __THREW__; __THREW__ = 0;
            $124 = $123&1;
            if ($124) {
             label = 4;
             break L37;
            }
           }
           $125 = HEAP32[$chars>>2]|0;
           $126 = (($125) + 92|0);
           $127 = HEAP32[$126>>2]|0;
           $128 = Math_imul($127, $$0)|0;
           $129 = (($113) + ($128)|0);
           $130 = HEAP16[$129>>1]|0;
           $131 = $130&65535;
           $132 = (($$01) + -1)|0;
           $133 = ($130&65535)>(127);
           if ($133) {
            label = 64;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($111|0));
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if ($135) {
            label = 4;
            break L37;
           }
           $136 = HEAP32[$114>>2]|0;
           $137 = ($131>>>0)<($136>>>0);
           if (!($137)) {
            __THREW__ = 0;
            $138 = (invoke_i(132)|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 4;
             break L37;
            }
            __THREW__ = 0;
            invoke_vi(3302,($138|0));
            $141 = __THREW__; __THREW__ = 0;
            $142 = $141&1;
            if ($142) {
             label = 4;
             break L37;
            }
           }
           $143 = HEAP32[$111>>2]|0;
           $144 = (($143) + 92|0);
           $145 = HEAP32[$144>>2]|0;
           $146 = Math_imul($145, $131)|0;
           $147 = (($115) + ($146)|0);
           $148 = HEAP8[$147>>0]|0;
           $149 = $148&255;
           if ((($149|0) == 2)) {
            label = 137;
            break;
           } else if ((($149|0) == 3)) {
            label = 138;
            break;
           } else if ((($149|0) == 0)) {
            label = 64;
            break;
           } else if ((($149|0) == 1)) {
            break;
           } else {
            $$0 = $461;$$01 = $132;
           }
          }
          if ((label|0) == 137) {
           label = 0;
           if (!($allowOptionals)) {
            label = 64;
           }
          }
          else if ((label|0) == 138) {
           label = 0;
           $339 = HEAP8[$isInShifted>>0]|0;
           $340 = ($339<<24>>24)==(0);
           if ($340) {
            $V_0$5 = $V_0$6$ph;$V_2$3 = $V_2$4$ph;$V_3$2 = $V_3$3$ph;
           } else {
            $341 = ($V_2$4$ph|0)==(0);
            if ($341) {
             $V_0$4 = $V_0$6$ph;
            } else {
             $342 = (($V_0$6$ph) + 1)|0;
             $343 = ($V_0$6$ph|0)<($94|0);
             if (!($343)) {
              label = 141;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($112|0));
             $358 = __THREW__; __THREW__ = 0;
             $359 = $358&1;
             if ($359) {
              label = 5;
              break;
             }
             $360 = (6 - ($V_2$4$ph))|0;
             $361 = $360 & 31;
             $362 = $V_3$3$ph << $361;
             __THREW__ = 0;
             $363 = (invoke_iii(621,($112|0),($362|0))|0);
             $364 = __THREW__; __THREW__ = 0;
             $365 = $364&1;
             if ($365) {
              label = 5;
              break;
             }
             $366 = $363&255;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $367 = __THREW__; __THREW__ = 0;
             $368 = $367&1;
             if ($368) {
              label = 5;
              break;
             }
             $369 = ($V_0$6$ph|0)<(0);
             if ($369) {
              label = 152;
             } else {
              $370 = HEAP32[$75>>2]|0;
              $371 = ($V_0$6$ph>>>0)<($370>>>0);
              if (!($371)) {
               label = 152;
              }
             }
             if ((label|0) == 152) {
              label = 0;
              __THREW__ = 0;
              $372 = (invoke_i(132)|0);
              $373 = __THREW__; __THREW__ = 0;
              $374 = $373&1;
              if ($374) {
               label = 5;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($372|0));
              $375 = __THREW__; __THREW__ = 0;
              $376 = $375&1;
              if ($376) {
               label = 5;
               break;
              }
             }
             $377 = HEAP32[$bytes>>2]|0;
             $378 = (($377) + 92|0);
             $379 = HEAP32[$378>>2]|0;
             $380 = Math_imul($379, $V_0$6$ph)|0;
             $381 = (($116) + ($380)|0);
             HEAP8[$381>>0] = $366;
             $V_0$4 = $342;
            }
            $382 = (($V_0$4) + 1)|0;
            $383 = ($V_0$4|0)<($94|0);
            if (!($383)) {
             label = 156;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($bytes|0));
            $398 = __THREW__; __THREW__ = 0;
            $399 = $398&1;
            if ($399) {
             label = 5;
             break;
            }
            $400 = ($V_0$4|0)<(0);
            if ($400) {
             label = 165;
            } else {
             $401 = HEAP32[$75>>2]|0;
             $402 = ($V_0$4>>>0)<($401>>>0);
             if (!($402)) {
              label = 165;
             }
            }
            if ((label|0) == 165) {
             label = 0;
             __THREW__ = 0;
             $403 = (invoke_i(132)|0);
             $404 = __THREW__; __THREW__ = 0;
             $405 = $404&1;
             if ($405) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($403|0));
             $406 = __THREW__; __THREW__ = 0;
             $407 = $406&1;
             if ($407) {
              label = 5;
              break;
             }
            }
            $408 = HEAP32[$bytes>>2]|0;
            $409 = (($408) + 92|0);
            $410 = HEAP32[$409>>2]|0;
            $411 = Math_imul($410, $V_0$4)|0;
            $412 = (($116) + ($411)|0);
            HEAP8[$412>>0] = 45;
            HEAP8[$isInShifted>>0] = 0;
            $V_0$5 = $382;$V_2$3 = 0;$V_3$2 = 0;
           }
           $413 = (($V_0$5) + 2)|0;
           $414 = ($413|0)>($94|0);
           if ($414) {
            label = 169;
            break;
           }
           $429 = (($V_0$5) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $430 = __THREW__; __THREW__ = 0;
           $431 = $430&1;
           if ($431) {
            label = 5;
            break;
           }
           $432 = ($V_0$5|0)<(0);
           if ($432) {
            label = 178;
           } else {
            $433 = HEAP32[$75>>2]|0;
            $434 = ($V_0$5>>>0)<($433>>>0);
            if (!($434)) {
             label = 178;
            }
           }
           if ((label|0) == 178) {
            label = 0;
            __THREW__ = 0;
            $435 = (invoke_i(132)|0);
            $436 = __THREW__; __THREW__ = 0;
            $437 = $436&1;
            if ($437) {
             label = 5;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($435|0));
            $438 = __THREW__; __THREW__ = 0;
            $439 = $438&1;
            if ($439) {
             label = 5;
             break;
            }
           }
           $440 = HEAP32[$bytes>>2]|0;
           $441 = (($440) + 92|0);
           $442 = HEAP32[$441>>2]|0;
           $443 = Math_imul($442, $V_0$5)|0;
           $444 = (($116) + ($443)|0);
           HEAP8[$444>>0] = 43;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $445 = __THREW__; __THREW__ = 0;
           $446 = $445&1;
           if ($446) {
            label = 5;
            break;
           }
           $447 = ($429|0)<(0);
           if ($447) {
            label = 183;
           } else {
            $448 = HEAP32[$75>>2]|0;
            $449 = ($429>>>0)<($448>>>0);
            if (!($449)) {
             label = 183;
            }
           }
           if ((label|0) == 183) {
            label = 0;
            __THREW__ = 0;
            $450 = (invoke_i(132)|0);
            $451 = __THREW__; __THREW__ = 0;
            $452 = $451&1;
            if ($452) {
             label = 5;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($450|0));
            $453 = __THREW__; __THREW__ = 0;
            $454 = $453&1;
            if ($454) {
             label = 5;
             break;
            }
           }
           $455 = HEAP32[$bytes>>2]|0;
           $456 = (($455) + 92|0);
           $457 = HEAP32[$456>>2]|0;
           $458 = Math_imul($457, $429)|0;
           $459 = (($116) + ($458)|0);
           HEAP8[$459>>0] = 45;
           $$0$ph = $461;$$01$ph = $132;$V_0$6$ph = $413;$V_2$4$ph = $V_2$3;$V_3$3$ph = $V_3$2;
           continue;
          }
          if ((label|0) == 64) {
           label = 0;
           $150 = HEAP8[$isInShifted>>0]|0;
           $151 = ($150<<24>>24)==(0);
           if ($151) {
            $152 = ($V_0$6$ph|0)<($94|0);
            if (!($152)) {
             label = 66;
             break;
            }
            $167 = (($V_0$6$ph) + 1)|0;
            __THREW__ = 0;
            invoke_vi(3799,($bytes|0));
            $168 = __THREW__; __THREW__ = 0;
            $169 = $168&1;
            if ($169) {
             label = 5;
             break;
            }
            $170 = ($V_0$6$ph|0)<(0);
            if ($170) {
             label = 75;
            } else {
             $171 = HEAP32[$75>>2]|0;
             $172 = ($V_0$6$ph>>>0)<($171>>>0);
             if (!($172)) {
              label = 75;
             }
            }
            if ((label|0) == 75) {
             label = 0;
             __THREW__ = 0;
             $173 = (invoke_i(132)|0);
             $174 = __THREW__; __THREW__ = 0;
             $175 = $174&1;
             if ($175) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($173|0));
             $176 = __THREW__; __THREW__ = 0;
             $177 = $176&1;
             if ($177) {
              label = 5;
              break;
             }
            }
            $178 = HEAP32[$bytes>>2]|0;
            $179 = (($178) + 92|0);
            $180 = HEAP32[$179>>2]|0;
            $181 = Math_imul($180, $V_0$6$ph)|0;
            $182 = (($116) + ($181)|0);
            HEAP8[$182>>0] = 43;
            HEAP8[$isInShifted>>0] = 1;
            $183 = $V_3$3$ph << 16;
            $184 = $131 | $183;
            $V_0$141 = $167;$V_2$140 = 16;$V_3$039 = $184;
           } else {
            $185 = $V_3$3$ph << 16;
            $186 = $131 | $185;
            $187 = (($V_2$4$ph) + 16)|0;
            $188 = ($187|0)>(5);
            if ($188) {
             $V_0$141 = $V_0$6$ph;$V_2$140 = $187;$V_3$039 = $186;
            } else {
             $V_0$6$ph$phi = $V_0$6$ph;$$0$ph = $461;$$01$ph = $132;$V_2$4$ph = $187;$V_3$3$ph = $186;$V_0$6$ph = $V_0$6$ph$phi;
             continue;
            }
           }
           while(1) {
            $232 = ($V_0$141|0)<($94|0);
            if (!($232)) {
             label = 79;
             break L37;
            }
            $203 = (($V_2$140) + -6)|0;
            $204 = (($V_0$141) + 1)|0;
            $205 = $203 & 31;
            __THREW__ = 0;
            invoke_vi(3799,($112|0));
            $206 = __THREW__; __THREW__ = 0;
            $207 = $206&1;
            if ($207) {
             label = 3;
             break L37;
            }
            $208 = $V_3$039 >> $205;
            __THREW__ = 0;
            $209 = (invoke_iii(621,($112|0),($208|0))|0);
            $210 = __THREW__; __THREW__ = 0;
            $211 = $210&1;
            if ($211) {
             label = 3;
             break L37;
            }
            $212 = $209&255;
            __THREW__ = 0;
            invoke_vi(3799,($bytes|0));
            $213 = __THREW__; __THREW__ = 0;
            $214 = $213&1;
            if ($214) {
             label = 3;
             break L37;
            }
            $215 = ($V_0$141|0)<(0);
            if ($215) {
             label = 90;
            } else {
             $216 = HEAP32[$75>>2]|0;
             $217 = ($V_0$141>>>0)<($216>>>0);
             if (!($217)) {
              label = 90;
             }
            }
            if ((label|0) == 90) {
             label = 0;
             __THREW__ = 0;
             $218 = (invoke_i(132)|0);
             $219 = __THREW__; __THREW__ = 0;
             $220 = $219&1;
             if ($220) {
              label = 3;
              break L37;
             }
             __THREW__ = 0;
             invoke_vi(3302,($218|0));
             $221 = __THREW__; __THREW__ = 0;
             $222 = $221&1;
             if ($222) {
              label = 3;
              break L37;
             }
            }
            $223 = HEAP32[$bytes>>2]|0;
            $224 = (($223) + 92|0);
            $225 = HEAP32[$224>>2]|0;
            $226 = Math_imul($225, $V_0$141)|0;
            $227 = (($116) + ($226)|0);
            HEAP8[$227>>0] = $212;
            $228 = 1 << $205;
            $229 = (($228) + -1)|0;
            $230 = $229 & $V_3$039;
            $231 = ($203|0)>(5);
            if ($231) {
             $V_0$141 = $204;$V_2$140 = $203;$V_3$039 = $230;
            } else {
             $$0$ph = $461;$$01$ph = $132;$V_0$6$ph = $204;$V_2$4$ph = $203;$V_3$3$ph = $230;
             continue L37;
            }
           }
          }
          $233 = HEAP8[$isInShifted>>0]|0;
          $234 = ($233<<24>>24)==(0);
          if ($234) {
           $V_0$3 = $V_0$6$ph;$V_2$2 = $V_2$4$ph;$V_3$1 = $V_3$3$ph;
          } else {
           $235 = ($V_2$4$ph|0)==(0);
           if ($235) {
            $V_0$2 = $V_0$6$ph;
           } else {
            $236 = (($V_0$6$ph) + 1)|0;
            $237 = ($V_0$6$ph|0)<($94|0);
            if (!($237)) {
             label = 97;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($112|0));
            $252 = __THREW__; __THREW__ = 0;
            $253 = $252&1;
            if ($253) {
             label = 5;
             break;
            }
            $254 = (6 - ($V_2$4$ph))|0;
            $255 = $254 & 31;
            $256 = $V_3$3$ph << $255;
            __THREW__ = 0;
            $257 = (invoke_iii(621,($112|0),($256|0))|0);
            $258 = __THREW__; __THREW__ = 0;
            $259 = $258&1;
            if ($259) {
             label = 5;
             break;
            }
            $260 = $257&255;
            __THREW__ = 0;
            invoke_vi(3799,($bytes|0));
            $261 = __THREW__; __THREW__ = 0;
            $262 = $261&1;
            if ($262) {
             label = 5;
             break;
            }
            $263 = ($V_0$6$ph|0)<(0);
            if ($263) {
             label = 108;
            } else {
             $264 = HEAP32[$75>>2]|0;
             $265 = ($V_0$6$ph>>>0)<($264>>>0);
             if (!($265)) {
              label = 108;
             }
            }
            if ((label|0) == 108) {
             label = 0;
             __THREW__ = 0;
             $266 = (invoke_i(132)|0);
             $267 = __THREW__; __THREW__ = 0;
             $268 = $267&1;
             if ($268) {
              label = 5;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($266|0));
             $269 = __THREW__; __THREW__ = 0;
             $270 = $269&1;
             if ($270) {
              label = 5;
              break;
             }
            }
            $271 = HEAP32[$bytes>>2]|0;
            $272 = (($271) + 92|0);
            $273 = HEAP32[$272>>2]|0;
            $274 = Math_imul($273, $V_0$6$ph)|0;
            $275 = (($116) + ($274)|0);
            HEAP8[$275>>0] = $260;
            $V_0$2 = $236;
           }
           $276 = (($V_0$2) + 1)|0;
           $277 = ($V_0$2|0)<($94|0);
           if (!($277)) {
            label = 112;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $292 = __THREW__; __THREW__ = 0;
           $293 = $292&1;
           if ($293) {
            label = 5;
            break;
           }
           $294 = ($V_0$2|0)<(0);
           if ($294) {
            label = 121;
           } else {
            $295 = HEAP32[$75>>2]|0;
            $296 = ($V_0$2>>>0)<($295>>>0);
            if (!($296)) {
             label = 121;
            }
           }
           if ((label|0) == 121) {
            label = 0;
            __THREW__ = 0;
            $297 = (invoke_i(132)|0);
            $298 = __THREW__; __THREW__ = 0;
            $299 = $298&1;
            if ($299) {
             label = 5;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($297|0));
            $300 = __THREW__; __THREW__ = 0;
            $301 = $300&1;
            if ($301) {
             label = 5;
             break;
            }
           }
           $302 = HEAP32[$bytes>>2]|0;
           $303 = (($302) + 92|0);
           $304 = HEAP32[$303>>2]|0;
           $305 = Math_imul($304, $V_0$2)|0;
           $306 = (($116) + ($305)|0);
           HEAP8[$306>>0] = 45;
           HEAP8[$isInShifted>>0] = 0;
           $V_0$3 = $276;$V_2$2 = 0;$V_3$1 = 0;
          }
          $307 = ($V_0$3|0)<($94|0);
          if (!($307)) {
           label = 125;
           break;
          }
          $322 = (($V_0$3) + 1)|0;
          $323 = $130&255;
          __THREW__ = 0;
          invoke_vi(3799,($bytes|0));
          $324 = __THREW__; __THREW__ = 0;
          $325 = $324&1;
          if ($325) {
           label = 5;
           break;
          }
          $326 = ($V_0$3|0)<(0);
          if ($326) {
           label = 134;
          } else {
           $327 = HEAP32[$75>>2]|0;
           $328 = ($V_0$3>>>0)<($327>>>0);
           if (!($328)) {
            label = 134;
           }
          }
          if ((label|0) == 134) {
           label = 0;
           __THREW__ = 0;
           $329 = (invoke_i(132)|0);
           $330 = __THREW__; __THREW__ = 0;
           $331 = $330&1;
           if ($331) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($329|0));
           $332 = __THREW__; __THREW__ = 0;
           $333 = $332&1;
           if ($333) {
            label = 5;
            break;
           }
          }
          $334 = HEAP32[$bytes>>2]|0;
          $335 = (($334) + 92|0);
          $336 = HEAP32[$335>>2]|0;
          $337 = Math_imul($336, $V_0$3)|0;
          $338 = (($116) + ($337)|0);
          HEAP8[$338>>0] = $323;
          $$0$ph = $461;$$01$ph = $132;$V_0$6$ph = $322;$V_2$4$ph = $V_2$2;$V_3$3$ph = $V_3$1;
         }
         switch (label|0) {
          case 3: {
           $3 = ___cxa_find_matching_catch()|0;
           $4 = tempRet0;
           $lpad$phi$index = $3;$lpad$phi$index4 = $4;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
           break;
          }
          case 4: {
           $5 = ___cxa_find_matching_catch()|0;
           $6 = tempRet0;
           $lpad$phi$index = $5;$lpad$phi$index4 = $6;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
           break;
          }
          case 5: {
           $7 = ___cxa_find_matching_catch()|0;
           $8 = tempRet0;
           $lpad$phi$index = $7;$lpad$phi$index4 = $8;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
           break;
          }
          case 66: {
           $153 = HEAP32[3057848>>2]|0;
           __THREW__ = 0;
           $154 = (invoke_iii(977,0,($153|0))|0);
           $155 = __THREW__; __THREW__ = 0;
           $156 = $155&1;
           if ($156) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $157 = __THREW__; __THREW__ = 0;
           $158 = $157&1;
           if ($158) {
            break L1;
           }
           __THREW__ = 0;
           $159 = (invoke_ii(3469,(2560072|0))|0);
           $160 = __THREW__; __THREW__ = 0;
           $161 = $160&1;
           if ($161) {
            break L1;
           }
           $162 = HEAP32[3057856>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($159|0),($154|0),($162|0));
           $163 = __THREW__; __THREW__ = 0;
           $164 = $163&1;
           if ($164) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($159|0));
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if ($166) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 79: {
           $189 = HEAP32[3057864>>2]|0;
           __THREW__ = 0;
           $190 = (invoke_iii(977,0,($189|0))|0);
           $191 = __THREW__; __THREW__ = 0;
           $192 = $191&1;
           if ($192) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $193 = __THREW__; __THREW__ = 0;
           $194 = $193&1;
           if ($194) {
            break L1;
           }
           __THREW__ = 0;
           $195 = (invoke_ii(3469,(2560072|0))|0);
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if ($197) {
            break L1;
           }
           $198 = HEAP32[3057872>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($195|0),($190|0),($198|0));
           $199 = __THREW__; __THREW__ = 0;
           $200 = $199&1;
           if ($200) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($195|0));
           $201 = __THREW__; __THREW__ = 0;
           $202 = $201&1;
           if ($202) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 97: {
           $238 = HEAP32[3057880>>2]|0;
           __THREW__ = 0;
           $239 = (invoke_iii(977,0,($238|0))|0);
           $240 = __THREW__; __THREW__ = 0;
           $241 = $240&1;
           if ($241) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $242 = __THREW__; __THREW__ = 0;
           $243 = $242&1;
           if ($243) {
            break L1;
           }
           __THREW__ = 0;
           $244 = (invoke_ii(3469,(2560072|0))|0);
           $245 = __THREW__; __THREW__ = 0;
           $246 = $245&1;
           if ($246) {
            break L1;
           }
           $247 = HEAP32[3057888>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($244|0),($239|0),($247|0));
           $248 = __THREW__; __THREW__ = 0;
           $249 = $248&1;
           if ($249) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($244|0));
           $250 = __THREW__; __THREW__ = 0;
           $251 = $250&1;
           if ($251) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 112: {
           $278 = HEAP32[3057896>>2]|0;
           __THREW__ = 0;
           $279 = (invoke_iii(977,0,($278|0))|0);
           $280 = __THREW__; __THREW__ = 0;
           $281 = $280&1;
           if ($281) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $282 = __THREW__; __THREW__ = 0;
           $283 = $282&1;
           if ($283) {
            break L1;
           }
           __THREW__ = 0;
           $284 = (invoke_ii(3469,(2560072|0))|0);
           $285 = __THREW__; __THREW__ = 0;
           $286 = $285&1;
           if ($286) {
            break L1;
           }
           $287 = HEAP32[3057904>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($284|0),($279|0),($287|0));
           $288 = __THREW__; __THREW__ = 0;
           $289 = $288&1;
           if ($289) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($284|0));
           $290 = __THREW__; __THREW__ = 0;
           $291 = $290&1;
           if ($291) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 125: {
           $308 = HEAP32[3057912>>2]|0;
           __THREW__ = 0;
           $309 = (invoke_iii(977,0,($308|0))|0);
           $310 = __THREW__; __THREW__ = 0;
           $311 = $310&1;
           if ($311) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $312 = __THREW__; __THREW__ = 0;
           $313 = $312&1;
           if ($313) {
            break L1;
           }
           __THREW__ = 0;
           $314 = (invoke_ii(3469,(2560072|0))|0);
           $315 = __THREW__; __THREW__ = 0;
           $316 = $315&1;
           if ($316) {
            break L1;
           }
           $317 = HEAP32[3057920>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($314|0),($309|0),($317|0));
           $318 = __THREW__; __THREW__ = 0;
           $319 = $318&1;
           if ($319) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($314|0));
           $320 = __THREW__; __THREW__ = 0;
           $321 = $320&1;
           if ($321) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 141: {
           $344 = HEAP32[3057928>>2]|0;
           __THREW__ = 0;
           $345 = (invoke_iii(977,0,($344|0))|0);
           $346 = __THREW__; __THREW__ = 0;
           $347 = $346&1;
           if ($347) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $348 = __THREW__; __THREW__ = 0;
           $349 = $348&1;
           if ($349) {
            break L1;
           }
           __THREW__ = 0;
           $350 = (invoke_ii(3469,(2560072|0))|0);
           $351 = __THREW__; __THREW__ = 0;
           $352 = $351&1;
           if ($352) {
            break L1;
           }
           $353 = HEAP32[3057936>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($350|0),($345|0),($353|0));
           $354 = __THREW__; __THREW__ = 0;
           $355 = $354&1;
           if ($355) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($350|0));
           $356 = __THREW__; __THREW__ = 0;
           $357 = $356&1;
           if ($357) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 156: {
           $384 = HEAP32[3057944>>2]|0;
           __THREW__ = 0;
           $385 = (invoke_iii(977,0,($384|0))|0);
           $386 = __THREW__; __THREW__ = 0;
           $387 = $386&1;
           if ($387) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $388 = __THREW__; __THREW__ = 0;
           $389 = $388&1;
           if ($389) {
            break L1;
           }
           __THREW__ = 0;
           $390 = (invoke_ii(3469,(2560072|0))|0);
           $391 = __THREW__; __THREW__ = 0;
           $392 = $391&1;
           if ($392) {
            break L1;
           }
           $393 = HEAP32[3057952>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($390|0),($385|0),($393|0));
           $394 = __THREW__; __THREW__ = 0;
           $395 = $394&1;
           if ($395) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($390|0));
           $396 = __THREW__; __THREW__ = 0;
           $397 = $396&1;
           if ($397) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 169: {
           $415 = HEAP32[3057960>>2]|0;
           __THREW__ = 0;
           $416 = (invoke_iii(977,0,($415|0))|0);
           $417 = __THREW__; __THREW__ = 0;
           $418 = $417&1;
           if ($418) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $419 = __THREW__; __THREW__ = 0;
           $420 = $419&1;
           if ($420) {
            break L1;
           }
           __THREW__ = 0;
           $421 = (invoke_ii(3469,(2560072|0))|0);
           $422 = __THREW__; __THREW__ = 0;
           $423 = $422&1;
           if ($423) {
            break L1;
           }
           $424 = HEAP32[3057968>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($421|0),($416|0),($424|0));
           $425 = __THREW__; __THREW__ = 0;
           $426 = $425&1;
           if ($426) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($421|0));
           $427 = __THREW__; __THREW__ = 0;
           $428 = $427&1;
           if ($428) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 189: {
           $464 = HEAP8[$isInShifted>>0]|0;
           $465 = ($464<<24>>24)==(0);
           $flush$not = $flush ^ 1;
           $brmerge = $465 | $flush$not;
           if ($brmerge) {
            $V_0$8 = $V_0$6$ph;$V_2$5 = $V_2$4$ph;$V_3$4 = $V_3$3$ph;
            $523 = $V_2$5 << 8;
            $524 = $523 | $V_3$4;
            HEAP32[$leftOver>>2] = $524;
            $525 = (($V_0$8) - ($byteIndex))|0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($525|0);
           }
           $466 = ($V_2$4$ph|0)==(0);
           if ($466) {
            $V_0$7 = $V_0$6$ph;
           } else {
            $467 = (($V_0$6$ph) + 1)|0;
            $468 = ($V_0$6$ph|0)<($94|0);
            if (!($468)) {
             $469 = HEAP32[3057976>>2]|0;
             __THREW__ = 0;
             $470 = (invoke_iii(977,0,($469|0))|0);
             $471 = __THREW__; __THREW__ = 0;
             $472 = $471&1;
             if ($472) {
              break L1;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2560072|0))|0);
             $473 = __THREW__; __THREW__ = 0;
             $474 = $473&1;
             if ($474) {
              break L1;
             }
             __THREW__ = 0;
             $475 = (invoke_ii(3469,(2560072|0))|0);
             $476 = __THREW__; __THREW__ = 0;
             $477 = $476&1;
             if ($477) {
              break L1;
             }
             $478 = HEAP32[3057984>>2]|0;
             __THREW__ = 0;
             invoke_viii(641,($475|0),($470|0),($478|0));
             $479 = __THREW__; __THREW__ = 0;
             $480 = $479&1;
             if ($480) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3838,($475|0));
             $481 = __THREW__; __THREW__ = 0;
             $482 = $481&1;
             if ($482) {
              break L1;
             }
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($112|0));
            $483 = __THREW__; __THREW__ = 0;
            $484 = $483&1;
            if ($484) {
             break L1;
            }
            $485 = (6 - ($V_2$4$ph))|0;
            $486 = $485 & 31;
            $487 = $V_3$3$ph << $486;
            __THREW__ = 0;
            $488 = (invoke_iii(621,($112|0),($487|0))|0);
            $489 = __THREW__; __THREW__ = 0;
            $490 = $489&1;
            if ($490) {
             break L1;
            }
            $491 = $488&255;
            __THREW__ = 0;
            invoke_vi(3799,($bytes|0));
            $492 = __THREW__; __THREW__ = 0;
            $493 = $492&1;
            if ($493) {
             break L1;
            }
            $494 = ($V_0$6$ph|0)<(0);
            if ($494) {
             label = 203;
            } else {
             $495 = HEAP32[$75>>2]|0;
             $496 = ($V_0$6$ph>>>0)<($495>>>0);
             if (!($496)) {
              label = 203;
             }
            }
            if ((label|0) == 203) {
             __THREW__ = 0;
             $497 = (invoke_i(132)|0);
             $498 = __THREW__; __THREW__ = 0;
             $499 = $498&1;
             if ($499) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3302,($497|0));
             $500 = __THREW__; __THREW__ = 0;
             $501 = $500&1;
             if ($501) {
              break L1;
             }
            }
            $502 = HEAP32[$bytes>>2]|0;
            $503 = (($502) + 92|0);
            $504 = HEAP32[$503>>2]|0;
            $505 = Math_imul($504, $V_0$6$ph)|0;
            $506 = (($116) + ($505)|0);
            HEAP8[$506>>0] = $491;
            $V_0$7 = $467;
           }
           $507 = (($V_0$7) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $508 = __THREW__; __THREW__ = 0;
           $509 = $508&1;
           if ($509) {
            break L1;
           }
           $510 = ($V_0$7|0)<(0);
           if ($510) {
            label = 209;
           } else {
            $511 = HEAP32[$75>>2]|0;
            $512 = ($V_0$7>>>0)<($511>>>0);
            if (!($512)) {
             label = 209;
            }
           }
           if ((label|0) == 209) {
            __THREW__ = 0;
            $513 = (invoke_i(132)|0);
            $514 = __THREW__; __THREW__ = 0;
            $515 = $514&1;
            if ($515) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3302,($513|0));
            $516 = __THREW__; __THREW__ = 0;
            $517 = $516&1;
            if ($517) {
             break L1;
            }
           }
           $518 = HEAP32[$bytes>>2]|0;
           $519 = (($518) + 92|0);
           $520 = HEAP32[$519>>2]|0;
           $521 = Math_imul($520, $V_0$7)|0;
           $522 = (($116) + ($521)|0);
           HEAP8[$522>>0] = 45;
           HEAP8[$isInShifted>>0] = 0;
           $V_0$8 = $507;$V_2$5 = 0;$V_3$4 = 0;
           $523 = $V_2$5 << 8;
           $524 = $523 | $V_3$4;
           HEAP32[$leftOver>>2] = $524;
           $525 = (($V_0$8) - ($byteIndex))|0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($525|0);
           break;
          }
         }
        }
       }
       $78 = HEAP32[3057832>>2]|0;
       __THREW__ = 0;
       $79 = (invoke_iii(977,0,($78|0))|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       __THREW__ = 0;
       $84 = (invoke_ii(3469,(2561352|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       $87 = HEAP32[3057824>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($84|0),($87|0),($79|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($84|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        break;
       }
       // unreachable;
      }
     }
     $58 = HEAP32[3057816>>2]|0;
     __THREW__ = 0;
     $59 = (invoke_iii(977,0,($58|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     $64 = (invoke_ii(3469,(2561352|0))|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break;
     }
     $67 = HEAP32[3057808>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($64|0),($67|0),($59|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($64|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     }
     // unreachable;
    }
   }
   $38 = HEAP32[3057800>>2]|0;
   __THREW__ = 0;
   $39 = (invoke_iii(977,0,($38|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     __THREW__ = 0;
     $44 = (invoke_ii(3469,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      $47 = HEAP32[3057792>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($44|0),($47|0),($39|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if (!($49)) {
       __THREW__ = 0;
       invoke_vi(3838,($44|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if (!($51)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index4 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z190mscorlib_System_Text_UTF7Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 $V_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539880);
 HEAP32[$V_0>>2] = 0;
 HEAP8[$V_1>>0] = 0;
 $0 = (($__this) + 48|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __THREW__ = 0;
 $3 = (invoke_iiiiiiiiiii(3,0,($chars|0),($charIndex|0),($charCount|0),($bytes|0),($byteIndex|0),1,($V_0|0),($V_1|0),($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z56mscorlib_System_Text_UTF7Encoding_m_InternalGetCharCountP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriii($__this,$bytes,$index,$count,$leftOver) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 $leftOver = $leftOver|0;
 var $$0$ph42 = 0, $$01$ph41 = 0, $$0131 = 0, $$032 = 0, $$V_0$2 = 0, $$V_3$0$off0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$2$ = 0, $V_0$2$lcssa = 0, $V_0$2$ph$be = 0, $V_0$2$ph40 = 0, $V_0$230 = 0;
 var $V_2$1$off0$ph$be = 0, $V_2$1$off0$ph39 = 0, $V_2$1$off029 = 0, $V_3$0$off0$ph38 = 0, $V_3$0$off028 = 0, $V_4$1$ph$be = 0, $V_4$1$ph37 = 0, $_stackTraceSentry = 0, $extract$t = 0, $extract$t3 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539928);
 __THREW__ = 0;
 invoke_v(738);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3058128>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($index|0)<(0);
   if (!($19)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (($bytes) + 12|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)<($index|0);
    if (!($24)) {
     $39 = ($count|0)<(0);
     if (!($39)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      $42 = HEAP32[$22>>2]|0;
      $43 = (($42) - ($index))|0;
      $44 = ($43|0)<($count|0);
      if (!($44)) {
       $59 = $leftOver >>> 16;
       $60 = $59 & 255;
       __THREW__ = 0;
       (invoke_ii(2996,(2541528|0))|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       $63 = HEAP8[((2541528 + 116|0))>>0]|0;
       $64 = ($63<<24>>24)==(0);
       if ($64) {
        __THREW__ = 0;
        (invoke_ii(2996,(2541528|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2541528|0))|0);
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2541528|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2541528|0))|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        break;
       }
       $73 = HEAP32[((2541528 + 80|0))>>2]|0;
       $74 = (($73) + 4|0);
       $75 = HEAP32[$74>>2]|0;
       $76 = ($count|0)>(0);
       if (!($76)) {
        $V_0$2$lcssa = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($V_0$2$lcssa|0);
       }
       $77 = $leftOver & 16777216;
       $78 = $leftOver & 33554432;
       $extract$t3 = ($77|0)==(0);
       $extract$t = ($78|0)!=(0);
       $79 = (($bytes) + 16|0);
       $80 = (($75) + 12|0);
       $81 = (($75) + 16|0);
       $$0$ph42 = $index;$$01$ph41 = $count;$V_0$2$ph40 = 0;$V_2$1$off0$ph39 = $extract$t3;$V_3$0$off0$ph38 = $extract$t;$V_4$1$ph37 = $60;
       L28: while(1) {
        $$0131 = $$01$ph41;$$032 = $$0$ph42;$V_0$230 = $V_0$2$ph40;$V_2$1$off029 = $V_2$1$off0$ph39;$V_3$0$off028 = $V_3$0$off0$ph38;
        while(1) {
         $126 = (($$032) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          label = 3;
          break L28;
         }
         $82 = ($$032|0)<(0);
         if ($82) {
          label = 40;
         } else {
          $83 = HEAP32[$22>>2]|0;
          $84 = ($$032>>>0)<($83>>>0);
          if (!($84)) {
           label = 40;
          }
         }
         if ((label|0) == 40) {
          label = 0;
          __THREW__ = 0;
          $85 = (invoke_i(132)|0);
          $86 = __THREW__; __THREW__ = 0;
          $87 = $86&1;
          if ($87) {
           label = 3;
           break L28;
          }
          __THREW__ = 0;
          invoke_vi(3302,($85|0));
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           label = 3;
           break L28;
          }
         }
         $90 = HEAP32[$bytes>>2]|0;
         $91 = (($90) + 92|0);
         $92 = HEAP32[$91>>2]|0;
         $93 = Math_imul($92, $$032)|0;
         $94 = (($79) + ($93)|0);
         $95 = HEAP8[$94>>0]|0;
         $96 = $95&255;
         $97 = (($$0131) + -1)|0;
         if (!($V_2$1$off029)) {
          break;
         }
         $98 = ($95<<24>>24)==(43);
         $$V_3$0$off0 = $98 | $V_3$0$off028;
         $not$ = $98 ^ 1;
         $99 = $98&1;
         $100 = $99 ^ 1;
         $V_0$2$ = (($100) + ($V_0$230))|0;
         $101 = ($97|0)>(0);
         if ($101) {
          $$0131 = $97;$$032 = $126;$V_0$230 = $V_0$2$;$V_2$1$off029 = $not$;$V_3$0$off028 = $$V_3$0$off0;
         } else {
          $V_0$2$lcssa = $V_0$2$;
          label = 57;
          break L28;
         }
        }
        $102 = ($95<<24>>24)==(45);
        do {
         if ($102) {
          $103 = $V_3$0$off028&1;
          $$V_0$2 = (($V_0$230) + ($103))|0;
          $V_0$2$ph$be = $$V_0$2;$V_2$1$off0$ph$be = 1;$V_4$1$ph$be = 0;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($75|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 4;
           break L28;
          }
          $106 = HEAP32[$80>>2]|0;
          $107 = ($96>>>0)<($106>>>0);
          if (!($107)) {
           __THREW__ = 0;
           $108 = (invoke_i(132)|0);
           $109 = __THREW__; __THREW__ = 0;
           $110 = $109&1;
           if ($110) {
            label = 4;
            break L28;
           }
           __THREW__ = 0;
           invoke_vi(3302,($108|0));
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            label = 4;
            break L28;
           }
          }
          $113 = HEAP32[$75>>2]|0;
          $114 = (($113) + 92|0);
          $115 = HEAP32[$114>>2]|0;
          $116 = Math_imul($115, $96)|0;
          $117 = (($81) + ($116)|0);
          $118 = HEAP8[$117>>0]|0;
          $119 = ($118<<24>>24)==(-1);
          if ($119) {
           $124 = (($V_0$230) + 1)|0;
           $V_0$2$ph$be = $124;$V_2$1$off0$ph$be = 1;$V_4$1$ph$be = 0;
           break;
          }
          $120 = (($V_4$1$ph37) + 6)|0;
          $121 = ($120|0)<(16);
          if ($121) {
           $V_0$2$ph$be = $V_0$230;$V_2$1$off0$ph$be = 0;$V_4$1$ph$be = $120;
           break;
          }
          $122 = (($V_0$230) + 1)|0;
          $123 = (($V_4$1$ph37) + -10)|0;
          $V_0$2$ph$be = $122;$V_2$1$off0$ph$be = 0;$V_4$1$ph$be = $123;
         }
        } while(0);
        $125 = ($97|0)>(0);
        if ($125) {
         $$0$ph42 = $126;$$01$ph41 = $97;$V_0$2$ph40 = $V_0$2$ph$be;$V_2$1$off0$ph39 = $V_2$1$off0$ph$be;$V_3$0$off0$ph38 = 0;$V_4$1$ph37 = $V_4$1$ph$be;
        } else {
         $V_0$2$lcssa = $V_0$2$ph$be;
         label = 57;
         break;
        }
       }
       if ((label|0) == 3) {
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index3 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 4) {
        $5 = ___cxa_find_matching_catch()|0;
        $6 = tempRet0;
        $lpad$phi$index = $5;$lpad$phi$index3 = $6;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 57) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($V_0$2$lcssa|0);
       }
      }
     }
     $45 = HEAP32[3058160>>2]|0;
     __THREW__ = 0;
     $46 = (invoke_iii(977,0,($45|0))|0);
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     __THREW__ = 0;
     $51 = (invoke_ii(3469,(2561352|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     $54 = HEAP32[3058152>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($51|0),($54|0),($46|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($51|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     // unreachable;
    }
   }
   $25 = HEAP32[3058144>>2]|0;
   __THREW__ = 0;
   $26 = (invoke_iii(977,0,($25|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __THREW__ = 0;
     $31 = (invoke_ii(3469,(2561352|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      $34 = HEAP32[3058136>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($31|0),($34|0),($26|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       __THREW__ = 0;
       invoke_vi(3838,($31|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Text_UTF7Encoding_m_GetCharCountP33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2539976);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(119,0,($bytes|0),($index|0),($count|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z52mscorlib_System_Text_UTF7Encoding_m_InternalGetCharsP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arriPi($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex,$leftOver) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $leftOver = $leftOver|0;
 var $$ = 0, $$0$ph$ph290 = 0, $$0$ph190 = 0, $$0$ph5298 = 0, $$01$ph$ph289 = 0, $$01$ph189 = 0, $$01$ph5197 = 0, $$0174 = 0, $$075 = 0, $$15 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0;
 var $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0;
 var $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B56_0$0 = 0, $V_0$2$lcssa = 0, $V_0$2$ph$be = 0, $V_0$2$ph$ph288 = 0;
 var $V_0$2$ph188 = 0, $V_0$2$ph5096 = 0, $V_0$273 = 0, $V_4$1$off0$ph$be = 0, $V_4$1$off0$ph$ph287 = 0, $V_4$1$off0$ph187 = 0, $V_4$1$off0$ph4988 = 0, $V_4$1$off0$ph4995 = 0, $V_5$0$off0$ph$ph286 = 0, $V_5$0$off0$ph186 = 0, $V_5$0$off0$ph4882 = 0, $V_5$0$off0$ph4894 = 0, $V_6$0$off0 = 0, $V_6$2$off0$mux = 0, $V_6$2$off0$ph$ph238 = 0, $V_6$2$off0$ph$ph285 = 0, $V_7$1$ph$be = 0, $V_7$1$ph$ph284 = 0, $V_7$1$ph128 = 0, $V_7$1$ph185 = 0;
 var $V_8$1$ph$be = 0, $V_8$1$ph$ph283 = 0, $V_8$1$ph115 = 0, $V_8$1$ph184 = 0, $_stackTraceSentry = 0, $brmerge = 0, $extract$t = 0, $extract$t10 = 0, $extract$t11 = 0, $lpad$phi$index = 0, $lpad$phi$index4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2540024);
 __THREW__ = 0;
 invoke_v(739);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2560584|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[3058176>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($13|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($13|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    // unreachable;
   }
   $21 = ($chars|0)==(0|0);
   if ($21) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2560584|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = HEAP32[3058184>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($24|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($24|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    // unreachable;
   }
   $32 = ($byteIndex|0)<(0);
   if (!($32)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = (($bytes) + 12|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = ($36|0)<($byteIndex|0);
    if (!($37)) {
     $52 = ($byteCount|0)<(0);
     if (!($52)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      $55 = HEAP32[$35>>2]|0;
      $56 = (($55) - ($byteIndex))|0;
      $57 = ($56|0)<($byteCount|0);
      if (!($57)) {
       $72 = ($charIndex|0)<(0);
       if (!($72)) {
        __THREW__ = 0;
        invoke_vi(3799,($chars|0));
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         break;
        }
        $75 = (($chars) + 12|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($76|0)<($charIndex|0);
        if (!($77)) {
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          break;
         }
         $94 = HEAP32[$75>>2]|0;
         $95 = HEAP32[$leftOver>>2]|0;
         $96 = $95 >>> 16;
         $97 = $96 & 255;
         $98 = $95 & 65535;
         __THREW__ = 0;
         (invoke_ii(2996,(2541528|0))|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          break;
         }
         $101 = HEAP8[((2541528 + 116|0))>>0]|0;
         $102 = ($101<<24>>24)==(0);
         if ($102) {
          __THREW__ = 0;
          (invoke_ii(2996,(2541528|0))|0);
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2541528|0))|0);
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2541528|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if ($108) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2541528|0))|0);
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          break;
         }
         $111 = HEAP32[((2541528 + 80|0))>>2]|0;
         $112 = (($111) + 4|0);
         $113 = HEAP32[$112>>2]|0;
         $114 = $95 & 67108864;
         $extract$t = ($114|0)!=(0);
         $115 = $95 & 33554432;
         $extract$t10 = ($115|0)!=(0);
         $116 = $95 & 16777216;
         $extract$t11 = ($116|0)==(0);
         $117 = ($byteCount|0)>(0);
         if (!($117)) {
          $V_0$2$lcssa = $charIndex;$V_4$1$off0$ph4988 = $extract$t11;$V_5$0$off0$ph4882 = $extract$t10;$V_6$2$off0$ph$ph238 = $extract$t;$V_7$1$ph128 = $97;$V_8$1$ph115 = $98;
          $359 = $V_7$1$ph128 << 16;
          $360 = $359 | $V_8$1$ph115;
          $$ = $V_4$1$off0$ph4988 ? 0 : 16777216;
          $G_B56_0$0 = $V_5$0$off0$ph4882 ? 33554432 : 0;
          $$15 = $V_6$2$off0$ph$ph238 ? 67108864 : 0;
          $361 = $360 | $$15;
          $362 = $361 | $G_B56_0$0;
          $363 = $362 | $$;
          HEAP32[$leftOver>>2] = $363;
          $364 = (($V_0$2$lcssa) - ($charIndex))|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($364|0);
         }
         $118 = (($bytes) + 16|0);
         $119 = (($chars) + 16|0);
         $120 = (($113) + 12|0);
         $121 = (($113) + 16|0);
         $$0$ph$ph290 = $byteIndex;$$01$ph$ph289 = $byteCount;$V_0$2$ph$ph288 = $charIndex;$V_4$1$off0$ph$ph287 = $extract$t11;$V_5$0$off0$ph$ph286 = $extract$t10;$V_6$2$off0$ph$ph285 = $extract$t;$V_7$1$ph$ph284 = $97;$V_8$1$ph$ph283 = $98;
         L40: while(1) {
          $$0$ph190 = $$0$ph$ph290;$$01$ph189 = $$01$ph$ph289;$V_0$2$ph188 = $V_0$2$ph$ph288;$V_4$1$off0$ph187 = $V_4$1$off0$ph$ph287;$V_5$0$off0$ph186 = $V_5$0$off0$ph$ph286;$V_7$1$ph185 = $V_7$1$ph$ph284;$V_8$1$ph184 = $V_8$1$ph$ph283;
          L42: while(1) {
           $$0$ph5298 = $$0$ph190;$$01$ph5197 = $$01$ph189;$V_0$2$ph5096 = $V_0$2$ph188;$V_4$1$off0$ph4995 = $V_4$1$off0$ph187;$V_5$0$off0$ph4894 = $V_5$0$off0$ph186;
           L44: while(1) {
            $$0174 = $$01$ph5197;$$075 = $$0$ph5298;$V_0$273 = $V_0$2$ph5096;
            while(1) {
             $356 = (($$075) + 1)|0;
             __THREW__ = 0;
             invoke_vi(3799,($bytes|0));
             $357 = __THREW__; __THREW__ = 0;
             $358 = $357&1;
             if ($358) {
              label = 3;
              break L40;
             }
             $122 = ($$075|0)<(0);
             if ($122) {
              label = 58;
             } else {
              $123 = HEAP32[$35>>2]|0;
              $124 = ($$075>>>0)<($123>>>0);
              if (!($124)) {
               label = 58;
              }
             }
             if ((label|0) == 58) {
              label = 0;
              __THREW__ = 0;
              $125 = (invoke_i(132)|0);
              $126 = __THREW__; __THREW__ = 0;
              $127 = $126&1;
              if ($127) {
               label = 3;
               break L40;
              }
              __THREW__ = 0;
              invoke_vi(3302,($125|0));
              $128 = __THREW__; __THREW__ = 0;
              $129 = $128&1;
              if ($129) {
               label = 3;
               break L40;
              }
             }
             $130 = HEAP32[$bytes>>2]|0;
             $131 = (($130) + 92|0);
             $132 = HEAP32[$131>>2]|0;
             $133 = Math_imul($132, $$075)|0;
             $134 = (($118) + ($133)|0);
             $135 = HEAP8[$134>>0]|0;
             $136 = $135&255;
             $137 = (($$0174) + -1)|0;
             if (!($V_4$1$off0$ph4995)) {
              break L44;
             }
             $138 = ($135<<24>>24)==(43);
             if ($138) {
              break;
             }
             $139 = ($V_0$273|0)<($94|0);
             if (!($139)) {
              label = 63;
              break L40;
             }
             if ($V_6$2$off0$ph$ph285) {
              label = 70;
              break L40;
             }
             $168 = (($V_0$273) + 1)|0;
             $169 = $135&255;
             __THREW__ = 0;
             invoke_vi(3799,($chars|0));
             $170 = __THREW__; __THREW__ = 0;
             $171 = $170&1;
             if ($171) {
              label = 3;
              break L40;
             }
             $172 = ($V_0$273|0)<(0);
             if ($172) {
              label = 79;
             } else {
              $173 = HEAP32[$75>>2]|0;
              $174 = ($V_0$273>>>0)<($173>>>0);
              if (!($174)) {
               label = 79;
              }
             }
             if ((label|0) == 79) {
              label = 0;
              __THREW__ = 0;
              $175 = (invoke_i(132)|0);
              $176 = __THREW__; __THREW__ = 0;
              $177 = $176&1;
              if ($177) {
               label = 3;
               break L40;
              }
              __THREW__ = 0;
              invoke_vi(3302,($175|0));
              $178 = __THREW__; __THREW__ = 0;
              $179 = $178&1;
              if ($179) {
               label = 3;
               break L40;
              }
             }
             $180 = HEAP32[$chars>>2]|0;
             $181 = (($180) + 92|0);
             $182 = HEAP32[$181>>2]|0;
             $183 = Math_imul($182, $V_0$273)|0;
             $184 = (($119) + ($183)|0);
             HEAP16[$184>>1] = $169;
             $185 = ($137|0)>(0);
             if ($185) {
              $$0174 = $137;$$075 = $356;$V_0$273 = $168;
             } else {
              $V_0$2$lcssa = $168;$V_4$1$off0$ph4988 = 1;$V_5$0$off0$ph4882 = $V_5$0$off0$ph4894;$V_6$2$off0$ph$ph238 = 0;$V_7$1$ph128 = $V_7$1$ph185;$V_8$1$ph115 = $V_8$1$ph184;
              label = 156;
              break L40;
             }
            }
            $355 = ($137|0)>(0);
            if ($355) {
             $$0$ph5298 = $356;$$01$ph5197 = $137;$V_0$2$ph5096 = $V_0$273;$V_4$1$off0$ph4995 = 0;$V_5$0$off0$ph4894 = 1;
            } else {
             $V_0$2$lcssa = $V_0$273;$V_4$1$off0$ph4988 = 0;$V_5$0$off0$ph4882 = 1;$V_6$2$off0$ph$ph238 = $V_6$2$off0$ph$ph285;$V_7$1$ph128 = $V_7$1$ph185;$V_8$1$ph115 = $V_8$1$ph184;
             label = 156;
             break L40;
            }
           }
           $186 = ($135<<24>>24)==(45);
           do {
            if ($186) {
             if (!($V_5$0$off0$ph4894)) {
              $V_0$2$ph$be = $V_0$273;$V_4$1$off0$ph$be = 1;$V_7$1$ph$be = 0;$V_8$1$ph$be = 0;
              break;
             }
             $187 = ($V_0$273|0)<($94|0);
             if (!($187)) {
              label = 85;
              break L40;
             }
             if ($V_6$2$off0$ph$ph285) {
              label = 92;
              break L40;
             }
             $216 = (($V_0$273) + 1)|0;
             __THREW__ = 0;
             invoke_vi(3799,($chars|0));
             $217 = __THREW__; __THREW__ = 0;
             $218 = $217&1;
             if ($218) {
              label = 4;
              break L40;
             }
             $219 = ($V_0$273|0)<(0);
             if ($219) {
              label = 101;
             } else {
              $220 = HEAP32[$75>>2]|0;
              $221 = ($V_0$273>>>0)<($220>>>0);
              if (!($221)) {
               label = 101;
              }
             }
             if ((label|0) == 101) {
              label = 0;
              __THREW__ = 0;
              $222 = (invoke_i(132)|0);
              $223 = __THREW__; __THREW__ = 0;
              $224 = $223&1;
              if ($224) {
               label = 4;
               break L40;
              }
              __THREW__ = 0;
              invoke_vi(3302,($222|0));
              $225 = __THREW__; __THREW__ = 0;
              $226 = $225&1;
              if ($226) {
               label = 4;
               break L40;
              }
             }
             $227 = HEAP32[$chars>>2]|0;
             $228 = (($227) + 92|0);
             $229 = HEAP32[$228>>2]|0;
             $230 = Math_imul($229, $V_0$273)|0;
             $231 = (($119) + ($230)|0);
             HEAP16[$231>>1] = 43;
             $V_0$2$ph$be = $216;$V_4$1$off0$ph$be = 1;$V_7$1$ph$be = 0;$V_8$1$ph$be = 0;
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($113|0));
             $232 = __THREW__; __THREW__ = 0;
             $233 = $232&1;
             if ($233) {
              label = 4;
              break L40;
             }
             $234 = HEAP32[$120>>2]|0;
             $235 = ($136>>>0)<($234>>>0);
             if (!($235)) {
              __THREW__ = 0;
              $236 = (invoke_i(132)|0);
              $237 = __THREW__; __THREW__ = 0;
              $238 = $237&1;
              if ($238) {
               label = 4;
               break L40;
              }
              __THREW__ = 0;
              invoke_vi(3302,($236|0));
              $239 = __THREW__; __THREW__ = 0;
              $240 = $239&1;
              if ($240) {
               label = 4;
               break L40;
              }
             }
             $241 = HEAP32[$113>>2]|0;
             $242 = (($241) + 92|0);
             $243 = HEAP32[$242>>2]|0;
             $244 = Math_imul($243, $136)|0;
             $245 = (($121) + ($244)|0);
             $246 = HEAP8[$245>>0]|0;
             $247 = ($246<<24>>24)==(-1);
             if (!($247)) {
              $248 = $246 << 24 >> 24;
              $249 = $V_8$1$ph184 << 6;
              $250 = $248 | $249;
              $251 = (($V_7$1$ph185) + 6)|0;
              $252 = ($251|0)<(16);
              if ($252) {
               $V_0$2$ph$be = $V_0$273;$V_4$1$off0$ph$be = 0;$V_7$1$ph$be = $251;$V_8$1$ph$be = $250;
               break;
              } else {
               break L42;
              }
             }
             $308 = ($V_0$273|0)<($94|0);
             if (!($308)) {
              label = 132;
              break L40;
             }
             if ($V_6$2$off0$ph$ph285) {
              label = 139;
              break L40;
             }
             $337 = (($V_0$273) + 1)|0;
             $338 = $135&255;
             __THREW__ = 0;
             invoke_vi(3799,($chars|0));
             $339 = __THREW__; __THREW__ = 0;
             $340 = $339&1;
             if ($340) {
              label = 4;
              break L40;
             }
             $341 = ($V_0$273|0)<(0);
             if ($341) {
              label = 148;
             } else {
              $342 = HEAP32[$75>>2]|0;
              $343 = ($V_0$273>>>0)<($342>>>0);
              if (!($343)) {
               label = 148;
              }
             }
             if ((label|0) == 148) {
              label = 0;
              __THREW__ = 0;
              $344 = (invoke_i(132)|0);
              $345 = __THREW__; __THREW__ = 0;
              $346 = $345&1;
              if ($346) {
               label = 4;
               break L40;
              }
              __THREW__ = 0;
              invoke_vi(3302,($344|0));
              $347 = __THREW__; __THREW__ = 0;
              $348 = $347&1;
              if ($348) {
               label = 4;
               break L40;
              }
             }
             $349 = HEAP32[$chars>>2]|0;
             $350 = (($349) + 92|0);
             $351 = HEAP32[$350>>2]|0;
             $352 = Math_imul($351, $V_0$273)|0;
             $353 = (($119) + ($352)|0);
             HEAP16[$353>>1] = $338;
             $V_0$2$ph$be = $337;$V_4$1$off0$ph$be = 1;$V_7$1$ph$be = 0;$V_8$1$ph$be = 0;
            }
           } while(0);
           $354 = ($137|0)>(0);
           if ($354) {
            $$0$ph190 = $356;$$01$ph189 = $137;$V_0$2$ph188 = $V_0$2$ph$be;$V_4$1$off0$ph187 = $V_4$1$off0$ph$be;$V_5$0$off0$ph186 = 0;$V_7$1$ph185 = $V_7$1$ph$be;$V_8$1$ph184 = $V_8$1$ph$be;
           } else {
            $V_0$2$lcssa = $V_0$2$ph$be;$V_4$1$off0$ph4988 = $V_4$1$off0$ph$be;$V_5$0$off0$ph4882 = 0;$V_6$2$off0$ph$ph238 = $V_6$2$off0$ph$ph285;$V_7$1$ph128 = $V_7$1$ph$be;$V_8$1$ph115 = $V_8$1$ph$be;
            label = 156;
            break L40;
           }
          }
          $253 = ($V_0$273|0)<($94|0);
          if (!($253)) {
           label = 111;
           break;
          }
          $268 = (($V_7$1$ph185) + -10)|0;
          $269 = $268 & 31;
          $270 = $250 >> $269;
          $271 = $270&65535;
          $272 = $270 & 64512;
          $273 = ($272|0)==(55296);
          if ($273) {
           $V_6$0$off0 = 1;
          } else {
           $$not = ($272|0)!=(56320);
           $brmerge = $$not | $V_6$2$off0$ph$ph285;
           $V_6$2$off0$mux = $$not & $V_6$2$off0$ph$ph285;
           if ($brmerge) {
            $V_6$0$off0 = $V_6$2$off0$mux;
           } else {
            label = 119;
            break;
           }
          }
          $288 = (($V_0$273) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $289 = __THREW__; __THREW__ = 0;
          $290 = $289&1;
          if ($290) {
           label = 5;
           break;
          }
          $291 = ($V_0$273|0)<(0);
          if ($291) {
           label = 128;
          } else {
           $292 = HEAP32[$75>>2]|0;
           $293 = ($V_0$273>>>0)<($292>>>0);
           if (!($293)) {
            label = 128;
           }
          }
          if ((label|0) == 128) {
           label = 0;
           __THREW__ = 0;
           $294 = (invoke_i(132)|0);
           $295 = __THREW__; __THREW__ = 0;
           $296 = $295&1;
           if ($296) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($294|0));
           $297 = __THREW__; __THREW__ = 0;
           $298 = $297&1;
           if ($298) {
            label = 5;
            break;
           }
          }
          $299 = HEAP32[$chars>>2]|0;
          $300 = (($299) + 92|0);
          $301 = HEAP32[$300>>2]|0;
          $302 = Math_imul($301, $V_0$273)|0;
          $303 = (($119) + ($302)|0);
          HEAP16[$303>>1] = $271;
          $304 = 1 << $269;
          $305 = (($304) + -1)|0;
          $306 = $250 & $305;
          $307 = ($137|0)>(0);
          if ($307) {
           $$0$ph$ph290 = $356;$$01$ph$ph289 = $137;$V_0$2$ph$ph288 = $288;$V_4$1$off0$ph$ph287 = 0;$V_5$0$off0$ph$ph286 = 0;$V_6$2$off0$ph$ph285 = $V_6$0$off0;$V_7$1$ph$ph284 = $268;$V_8$1$ph$ph283 = $306;
          } else {
           $V_0$2$lcssa = $288;$V_4$1$off0$ph4988 = 0;$V_5$0$off0$ph4882 = 0;$V_6$2$off0$ph$ph238 = $V_6$0$off0;$V_7$1$ph128 = $268;$V_8$1$ph115 = $306;
           label = 156;
           break;
          }
         }
         switch (label|0) {
          case 3: {
           $3 = ___cxa_find_matching_catch()|0;
           $4 = tempRet0;
           $lpad$phi$index = $3;$lpad$phi$index4 = $4;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
           break;
          }
          case 4: {
           $5 = ___cxa_find_matching_catch()|0;
           $6 = tempRet0;
           $lpad$phi$index = $5;$lpad$phi$index4 = $6;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
           break;
          }
          case 5: {
           $7 = ___cxa_find_matching_catch()|0;
           $8 = tempRet0;
           $lpad$phi$index = $7;$lpad$phi$index4 = $8;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
           break;
          }
          case 63: {
           $140 = HEAP32[3058240>>2]|0;
           __THREW__ = 0;
           $141 = (invoke_iii(977,0,($140|0))|0);
           $142 = __THREW__; __THREW__ = 0;
           $143 = $142&1;
           if ($143) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $144 = __THREW__; __THREW__ = 0;
           $145 = $144&1;
           if ($145) {
            break L1;
           }
           __THREW__ = 0;
           $146 = (invoke_ii(3469,(2560072|0))|0);
           $147 = __THREW__; __THREW__ = 0;
           $148 = $147&1;
           if ($148) {
            break L1;
           }
           $149 = HEAP32[3058248>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($146|0),($141|0),($149|0));
           $150 = __THREW__; __THREW__ = 0;
           $151 = $150&1;
           if ($151) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($146|0));
           $152 = __THREW__; __THREW__ = 0;
           $153 = $152&1;
           if ($153) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 70: {
           $154 = HEAP32[3058256>>2]|0;
           __THREW__ = 0;
           $155 = (invoke_iii(977,0,($154|0))|0);
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $158 = __THREW__; __THREW__ = 0;
           $159 = $158&1;
           if ($159) {
            break L1;
           }
           __THREW__ = 0;
           $160 = (invoke_ii(3469,(2560072|0))|0);
           $161 = __THREW__; __THREW__ = 0;
           $162 = $161&1;
           if ($162) {
            break L1;
           }
           $163 = HEAP32[3058264>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($160|0),($155|0),($163|0));
           $164 = __THREW__; __THREW__ = 0;
           $165 = $164&1;
           if ($165) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($160|0));
           $166 = __THREW__; __THREW__ = 0;
           $167 = $166&1;
           if ($167) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 85: {
           $188 = HEAP32[3058272>>2]|0;
           __THREW__ = 0;
           $189 = (invoke_iii(977,0,($188|0))|0);
           $190 = __THREW__; __THREW__ = 0;
           $191 = $190&1;
           if ($191) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $192 = __THREW__; __THREW__ = 0;
           $193 = $192&1;
           if ($193) {
            break L1;
           }
           __THREW__ = 0;
           $194 = (invoke_ii(3469,(2560072|0))|0);
           $195 = __THREW__; __THREW__ = 0;
           $196 = $195&1;
           if ($196) {
            break L1;
           }
           $197 = HEAP32[3058280>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($194|0),($189|0),($197|0));
           $198 = __THREW__; __THREW__ = 0;
           $199 = $198&1;
           if ($199) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($194|0));
           $200 = __THREW__; __THREW__ = 0;
           $201 = $200&1;
           if ($201) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 92: {
           $202 = HEAP32[3058288>>2]|0;
           __THREW__ = 0;
           $203 = (invoke_iii(977,0,($202|0))|0);
           $204 = __THREW__; __THREW__ = 0;
           $205 = $204&1;
           if ($205) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $206 = __THREW__; __THREW__ = 0;
           $207 = $206&1;
           if ($207) {
            break L1;
           }
           __THREW__ = 0;
           $208 = (invoke_ii(3469,(2560072|0))|0);
           $209 = __THREW__; __THREW__ = 0;
           $210 = $209&1;
           if ($210) {
            break L1;
           }
           $211 = HEAP32[3058296>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($208|0),($203|0),($211|0));
           $212 = __THREW__; __THREW__ = 0;
           $213 = $212&1;
           if ($213) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($208|0));
           $214 = __THREW__; __THREW__ = 0;
           $215 = $214&1;
           if ($215) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 111: {
           $254 = HEAP32[3058304>>2]|0;
           __THREW__ = 0;
           $255 = (invoke_iii(977,0,($254|0))|0);
           $256 = __THREW__; __THREW__ = 0;
           $257 = $256&1;
           if ($257) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $258 = __THREW__; __THREW__ = 0;
           $259 = $258&1;
           if ($259) {
            break L1;
           }
           __THREW__ = 0;
           $260 = (invoke_ii(3469,(2560072|0))|0);
           $261 = __THREW__; __THREW__ = 0;
           $262 = $261&1;
           if ($262) {
            break L1;
           }
           $263 = HEAP32[3058312>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($260|0),($255|0),($263|0));
           $264 = __THREW__; __THREW__ = 0;
           $265 = $264&1;
           if ($265) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($260|0));
           $266 = __THREW__; __THREW__ = 0;
           $267 = $266&1;
           if ($267) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 119: {
           $274 = HEAP32[3058320>>2]|0;
           __THREW__ = 0;
           $275 = (invoke_iii(977,0,($274|0))|0);
           $276 = __THREW__; __THREW__ = 0;
           $277 = $276&1;
           if ($277) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $278 = __THREW__; __THREW__ = 0;
           $279 = $278&1;
           if ($279) {
            break L1;
           }
           __THREW__ = 0;
           $280 = (invoke_ii(3469,(2560072|0))|0);
           $281 = __THREW__; __THREW__ = 0;
           $282 = $281&1;
           if ($282) {
            break L1;
           }
           $283 = HEAP32[3058328>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($280|0),($275|0),($283|0));
           $284 = __THREW__; __THREW__ = 0;
           $285 = $284&1;
           if ($285) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($280|0));
           $286 = __THREW__; __THREW__ = 0;
           $287 = $286&1;
           if ($287) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 132: {
           $309 = HEAP32[3058336>>2]|0;
           __THREW__ = 0;
           $310 = (invoke_iii(977,0,($309|0))|0);
           $311 = __THREW__; __THREW__ = 0;
           $312 = $311&1;
           if ($312) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $313 = __THREW__; __THREW__ = 0;
           $314 = $313&1;
           if ($314) {
            break L1;
           }
           __THREW__ = 0;
           $315 = (invoke_ii(3469,(2560072|0))|0);
           $316 = __THREW__; __THREW__ = 0;
           $317 = $316&1;
           if ($317) {
            break L1;
           }
           $318 = HEAP32[3058344>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($315|0),($310|0),($318|0));
           $319 = __THREW__; __THREW__ = 0;
           $320 = $319&1;
           if ($320) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($315|0));
           $321 = __THREW__; __THREW__ = 0;
           $322 = $321&1;
           if ($322) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 139: {
           $323 = HEAP32[3058352>>2]|0;
           __THREW__ = 0;
           $324 = (invoke_iii(977,0,($323|0))|0);
           $325 = __THREW__; __THREW__ = 0;
           $326 = $325&1;
           if ($326) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2560072|0))|0);
           $327 = __THREW__; __THREW__ = 0;
           $328 = $327&1;
           if ($328) {
            break L1;
           }
           __THREW__ = 0;
           $329 = (invoke_ii(3469,(2560072|0))|0);
           $330 = __THREW__; __THREW__ = 0;
           $331 = $330&1;
           if ($331) {
            break L1;
           }
           $332 = HEAP32[3058360>>2]|0;
           __THREW__ = 0;
           invoke_viii(641,($329|0),($324|0),($332|0));
           $333 = __THREW__; __THREW__ = 0;
           $334 = $333&1;
           if ($334) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3838,($329|0));
           $335 = __THREW__; __THREW__ = 0;
           $336 = $335&1;
           if ($336) {
            break L1;
           }
           // unreachable;
           break;
          }
          case 156: {
           $359 = $V_7$1$ph128 << 16;
           $360 = $359 | $V_8$1$ph115;
           $$ = $V_4$1$off0$ph4988 ? 0 : 16777216;
           $G_B56_0$0 = $V_5$0$off0$ph4882 ? 33554432 : 0;
           $$15 = $V_6$2$off0$ph$ph238 ? 67108864 : 0;
           $361 = $360 | $$15;
           $362 = $361 | $G_B56_0$0;
           $363 = $362 | $$;
           HEAP32[$leftOver>>2] = $363;
           $364 = (($V_0$2$lcssa) - ($charIndex))|0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($364|0);
           break;
          }
         }
        }
       }
       $78 = HEAP32[3058232>>2]|0;
       __THREW__ = 0;
       $79 = (invoke_iii(977,0,($78|0))|0);
       $80 = __THREW__; __THREW__ = 0;
       $81 = $80&1;
       if ($81) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       __THREW__ = 0;
       $84 = (invoke_ii(3469,(2561352|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       $87 = HEAP32[3058224>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($84|0),($87|0),($79|0));
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($84|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        break;
       }
       // unreachable;
      }
     }
     $58 = HEAP32[3058216>>2]|0;
     __THREW__ = 0;
     $59 = (invoke_iii(977,0,($58|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     $64 = (invoke_ii(3469,(2561352|0))|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      break;
     }
     $67 = HEAP32[3058208>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($64|0),($67|0),($59|0));
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($64|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     }
     // unreachable;
    }
   }
   $38 = HEAP32[3058200>>2]|0;
   __THREW__ = 0;
   $39 = (invoke_iii(977,0,($38|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     __THREW__ = 0;
     $44 = (invoke_ii(3469,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      $47 = HEAP32[3058192>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($44|0),($47|0),($39|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if (!($49)) {
       __THREW__ = 0;
       invoke_vi(3838,($44|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if (!($51)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index4 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_Text_UTF7Encoding_m_GetCharsP33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2540072);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(740);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$V_0>>2] = 0;
  __THREW__ = 0;
  $2 = (invoke_iiiiiiii(91,0,($bytes|0),($byteIndex|0),($byteCount|0),($chars|0),($charIndex|0),($V_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[$V_0>>2]|0;
   $6 = $5 & 67108864;
   $7 = ($6|0)==(0);
   if ($7) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
   $10 = HEAP32[3058408>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iii(977,0,($10|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2560072|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = HEAP32[3058416>>2]|0;
      __THREW__ = 0;
      invoke_viii(641,($16|0),($11|0),($19|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       __THREW__ = 0;
       invoke_vi(3838,($16|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z122mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P33mscorlib_System_Text_UTF7EncodingPti($__this,$chars,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2540120);
 __THREW__ = 0;
 $0 = (invoke_iiii(926,($__this|0),($chars|0),($count|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z93mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP33mscorlib_System_Text_UTF7EncodingP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2540168);
 __THREW__ = 0;
 $0 = (invoke_iii(979,($__this|0),($s|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z170mscorlib_System_Text_UTF7Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P33mscorlib_System_Text_UTF7EncodingPtiPhi($__this,$chars,$charCount,$bytes,$byteCount) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2540216);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(116,($__this|0),($chars|0),($charCount|0),($bytes|0),($byteCount|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z45mscorlib_System_Text_UTF7Encoding_m_GetStringP33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2540264);
 __THREW__ = 0;
 $0 = (invoke_iiiii(157,($__this|0),($bytes|0),($index|0),($count|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_29mscorlib_System_BooleanTraitsS0_S2_S2_E6InvokeEPFiPvS4_iibibbES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (($args) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$3,$6,$10,$13,$17,$21)|0);
 HEAP32[$ret>>2] = $22;
 $23 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($23|0);
}
function __ZN12FuncInvoker9I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_29mscorlib_System_BooleanTraitsS1_S1_S2_E6InvokeEPFiPvS4_iiS4_ibS4_S4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)!=(0);
 $16 = (($args) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($args) + 28|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($args) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)!=(0);
 $24 = (FUNCTION_TABLE_iiiiiiiiiii[$func & 7]($obj,$0,$3,$6,$8,$11,$15,$17,$19,$23)|0);
 HEAP32[$ret>>2] = $24;
 $25 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($25|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S0_E6InvokeEPFiPvS3_iiiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$3,$6,$9)|0);
 HEAP32[$ret>>2] = $10;
 $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($11|0);
}
function __Z64mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2537600)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z112mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetHashCodeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z107mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_EqualsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z187mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z158mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z235mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetStringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z205mscorlib_System_Text_UTF8Encoding_m_InternalGetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_CharU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectP24mscorlib_System_Char_arriiPtb($__this,$chars,$index,$count,$leftOver,$flush) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 $leftOver = $leftOver|0;
 $flush = $flush|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $9 = 0, $G_B17_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2541760);
 __THREW__ = 0;
 invoke_v(741);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3058504>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($chars) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($chars|0));
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
       $57 = HEAP32[$18>>2]|0;
       $58 = ($57|0)==($index|0);
       if ($58) {
        if (!($flush)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $59 = HEAP16[$leftOver>>1]|0;
        $60 = ($59<<16>>16)==(0);
        if ($60) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        HEAP16[$leftOver>>1] = 0;
        $$0 = 3;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($chars|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       $63 = HEAP32[$18>>2]|0;
       $64 = ($63|0)==(0);
       if ($64) {
        $G_B17_0$0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($chars|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         break;
        }
        $67 = HEAP32[$18>>2]|0;
        $68 = ($67|0)==(0);
        if ($68) {
         __THREW__ = 0;
         $69 = (invoke_i(132)|0);
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($69|0));
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          break;
         }
        }
        $74 = (($chars) + 16|0);
        $G_B17_0$0 = $74;
       }
       $75 = $index << 1;
       $76 = (($G_B17_0$0) + ($75)|0);
       __THREW__ = 0;
       $77 = (invoke_iiiiii(121,0,($76|0),($count|0),($leftOver|0),($flush|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       } else {
        $$0 = $77;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     $41 = HEAP32[3058536>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3058528>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3058520>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3058512>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z184mscorlib_System_Text_UTF8Encoding_m_InternalGetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_CharU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectPtiS1_b($__this,$chars,$count,$leftOver,$flush) {
 $__this = $__this|0;
 $chars = $chars|0;
 $count = $count|0;
 $leftOver = $leftOver|0;
 $flush = $flush|0;
 var $$0 = 0, $$18 = 0, $$2 = 0, $$3$be = 0, $$311 = 0, $$off = 0, $$off3 = 0, $$off4 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_0$0 = 0, $V_0$17 = 0, $V_0$2 = 0, $V_0$3$be = 0, $V_0$3$lcssa = 0, $V_0$310 = 0, $V_0$4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2541808);
 $0 = (($chars) + ($count<<1)|0);
 $1 = ($count|0)>(0);
 if ($1) {
  $$pre = HEAP16[$leftOver>>1]|0;
  $$311 = $chars;$25 = $$pre;$V_0$310 = 0;
  while(1) {
   $24 = ($25<<16>>16)==(0);
   L5: do {
    if ($24) {
     $26 = ($$311>>>0)<($0>>>0);
     if ($26) {
      $$18 = $$311;$V_0$17 = $V_0$310;
      L12: while(1) {
       $4 = HEAP16[$$18>>1]|0;
       $17 = ($4&65535)>(127);
       do {
        if ($17) {
         $3 = ($4&65535)>(2047);
         if (!($3)) {
          $5 = (($V_0$17) + 2)|0;
          $$0 = $$18;$V_0$0 = $5;
          break;
         }
         $$off3 = (($4) + 10240)<<16>>16;
         $6 = ($$off3&65535)<(2048);
         if (!($6)) {
          $7 = (($V_0$17) + 3)|0;
          $$0 = $$18;$V_0$0 = $7;
          break;
         }
         $8 = ($4&65535)>(56319);
         if ($8) {
          $14 = (($V_0$17) + 3)|0;
          HEAP16[$leftOver>>1] = 0;
          $$0 = $$18;$V_0$0 = $14;
          break;
         }
         $9 = (($$18) + 2|0);
         $10 = ($9>>>0)<($0>>>0);
         if (!($10)) {
          break L12;
         }
         $11 = HEAP16[$9>>1]|0;
         $$off4 = (($11) + 9216)<<16>>16;
         $12 = ($$off4&65535)>(1023);
         if ($12) {
          break L12;
         }
         $13 = (($V_0$17) + 4)|0;
         $$0 = $9;$V_0$0 = $13;
        } else {
         $2 = (($V_0$17) + 1)|0;
         $$0 = $$18;$V_0$0 = $2;
        }
       } while(0);
       $15 = (($$0) + 2|0);
       $16 = ($15>>>0)<($0>>>0);
       if ($16) {
        $$18 = $15;$V_0$17 = $V_0$0;
       } else {
        $$3$be = $15;$30 = 0;$V_0$3$be = $V_0$0;
        break L5;
       }
      }
      HEAP16[$leftOver>>1] = $4;
      $$3$be = $9;$30 = $4;$V_0$3$be = $V_0$17;
     } else {
      $$3$be = $$311;$30 = 0;$V_0$3$be = $V_0$310;
     }
    } else {
     $18 = HEAP16[$$311>>1]|0;
     $$off = (($18) + 9216)<<16>>16;
     $19 = ($$off&65535)>(1023);
     if ($19) {
      $22 = (($V_0$310) + 3)|0;
      $$2 = $$311;$V_0$2 = $22;
     } else {
      $20 = (($V_0$310) + 4)|0;
      $21 = (($$311) + 2|0);
      $$2 = $21;$V_0$2 = $20;
     }
     HEAP16[$leftOver>>1] = 0;
     $$3$be = $$2;$30 = 0;$V_0$3$be = $V_0$2;
    }
   } while(0);
   $23 = ($$3$be>>>0)<($0>>>0);
   if ($23) {
    $$311 = $$3$be;$25 = $30;$V_0$310 = $V_0$3$be;
   } else {
    $V_0$3$lcssa = $V_0$3$be;
    break;
   }
  }
 } else {
  $V_0$3$lcssa = 0;
 }
 if (!($flush)) {
  $V_0$4 = $V_0$3$lcssa;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_0$4|0);
 }
 $27 = HEAP16[$leftOver>>1]|0;
 $28 = ($27<<16>>16)==(0);
 if ($28) {
  $V_0$4 = $V_0$3$lcssa;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_0$4|0);
 }
 $29 = (($V_0$3$lcssa) + 3)|0;
 HEAP16[$leftOver>>1] = 0;
 $V_0$4 = $29;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($V_0$4|0);
}
function __Z143mscorlib_System_Text_UTF8Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Char_arrii($__this,$chars,$index,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2541856);
 HEAP16[$V_0>>1] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiiiiii(85,0,($chars|0),($index|0),($count|0),($V_0|0),1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z122mscorlib_System_Text_UTF8Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P33mscorlib_System_Text_UTF8EncodingPti($__this,$chars,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2541904);
 HEAP16[$V_0>>1] = 0;
 __THREW__ = 0;
 invoke_v(742);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if (!($2)) {
    $15 = ($count|0)==(0);
    if ($15) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    HEAP16[$V_0>>1] = 0;
    __THREW__ = 0;
    $16 = (invoke_iiiiii(121,0,($chars|0),($count|0),($V_0|0),1)|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    } else {
     $$0 = $16;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3058552>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3838,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z252mscorlib_System_Text_UTF8Encoding_m_InternalGetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_CharU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arriPtb($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex,$leftOver,$flush) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $leftOver = $leftOver|0;
 $flush = $flush|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $G_B22_0$0 = 0, $G_B28_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2541952);
 __THREW__ = 0;
 invoke_v(743);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3058568>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($bytes|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3058576>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($charIndex|0)<(0);
   if (!($26)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = (($chars) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)<($charIndex|0);
    if (!($31)) {
     $46 = ($charCount|0)<(0);
     if (!($46)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = HEAP32[$29>>2]|0;
      $50 = (($49) - ($charIndex))|0;
      $51 = ($50|0)<($charCount|0);
      if (!($51)) {
       $66 = ($byteIndex|0)<(0);
       if (!($66)) {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        $69 = (($bytes) + 12|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($70|0)<($byteIndex|0);
        if (!($71)) {
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         }
         $88 = HEAP32[$29>>2]|0;
         $89 = ($88|0)==($charIndex|0);
         if ($89) {
          if (!($flush)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          $90 = HEAP16[$leftOver>>1]|0;
          $91 = ($90<<16>>16)==(0);
          if ($91) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          HEAP16[$leftOver>>1] = 0;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          break;
         }
         $94 = HEAP32[$29>>2]|0;
         $95 = ($94|0)==(0);
         if ($95) {
          $G_B22_0$0 = 0;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $96 = __THREW__; __THREW__ = 0;
          $97 = $96&1;
          if ($97) {
           break;
          }
          $98 = HEAP32[$29>>2]|0;
          $99 = ($98|0)==(0);
          if ($99) {
           __THREW__ = 0;
           $100 = (invoke_i(132)|0);
           $101 = __THREW__; __THREW__ = 0;
           $102 = $101&1;
           if ($102) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($100|0));
           $103 = __THREW__; __THREW__ = 0;
           $104 = $103&1;
           if ($104) {
            break;
           }
          }
          $105 = (($chars) + 16|0);
          $G_B22_0$0 = $105;
         }
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $106 = __THREW__; __THREW__ = 0;
         $107 = $106&1;
         if ($107) {
          break;
         }
         $108 = HEAP32[$69>>2]|0;
         $109 = ($108|0)==($byteIndex|0);
         if ($109) {
          $110 = $charIndex << 1;
          $111 = (($G_B22_0$0) + ($110)|0);
          __THREW__ = 0;
          $112 = (invoke_iiiiiiii(92,0,($111|0),($charCount|0),(0|0),0,($leftOver|0),($flush|0))|0);
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           break;
          } else {
           $$0 = $112;
          }
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break;
         }
         $117 = HEAP32[$69>>2]|0;
         $118 = ($117|0)==(0);
         if ($118) {
          $G_B28_0$0 = 0;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($bytes|0));
          $119 = __THREW__; __THREW__ = 0;
          $120 = $119&1;
          if ($120) {
           break;
          }
          $121 = HEAP32[$69>>2]|0;
          $122 = ($121|0)==(0);
          if ($122) {
           __THREW__ = 0;
           $123 = (invoke_i(132)|0);
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($123|0));
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            break;
           }
          }
          $128 = (($bytes) + 16|0);
          $G_B28_0$0 = $128;
         }
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          break;
         }
         $131 = $charIndex << 1;
         $132 = (($G_B22_0$0) + ($131)|0);
         $133 = (($G_B28_0$0) + ($byteIndex)|0);
         $134 = HEAP32[$69>>2]|0;
         $135 = (($134) - ($byteIndex))|0;
         __THREW__ = 0;
         $136 = (invoke_iiiiiiii(92,0,($132|0),($charCount|0),($133|0),($135|0),($leftOver|0),($flush|0))|0);
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if ($138) {
          break;
         } else {
          $$0 = $136;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       $72 = HEAP32[3058624>>2]|0;
       __THREW__ = 0;
       $73 = (invoke_iii(977,0,($72|0))|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
       __THREW__ = 0;
       $78 = (invoke_ii(3469,(2561352|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        break;
       }
       $81 = HEAP32[3058616>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($78|0),($81|0),($73|0));
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($78|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       // unreachable;
      }
     }
     $52 = HEAP32[3058608>>2]|0;
     __THREW__ = 0;
     $53 = (invoke_iii(977,0,($52|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     __THREW__ = 0;
     $58 = (invoke_ii(3469,(2561352|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     $61 = HEAP32[3058600>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($58|0),($61|0),($53|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($58|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     // unreachable;
    }
   }
   $32 = HEAP32[3058592>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_iii(977,0,($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     $38 = (invoke_ii(3469,(2561352|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = HEAP32[3058584>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($38|0),($41|0),($33|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       __THREW__ = 0;
       invoke_vi(3838,($38|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z232mscorlib_System_Text_UTF8Encoding_m_InternalGetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_CharU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectPtiPhiS1_b($__this,$chars,$count,$bytes,$bcount,$leftOver,$flush) {
 $__this = $__this|0;
 $chars = $chars|0;
 $count = $count|0;
 $bytes = $bytes|0;
 $bcount = $bcount|0;
 $leftOver = $leftOver|0;
 $flush = $flush|0;
 var $$01 = 0, $$013 = 0, $$1 = 0, $$1212 = 0, $$2$be = 0, $$219 = 0, $$23 = 0, $$3$be = 0, $$3$lcssa = 0, $$318 = 0, $$4 = 0, $$off = 0, $$off5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $fold = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542000);
 __THREW__ = 0;
 invoke_v(744);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $2 = (($chars) + ($count<<1)|0);
 $3 = (($bytes) + ($bcount)|0);
 $4 = ($count|0)>(0);
 L4: do {
  if ($4) {
   $$219 = $chars;$$318 = $bytes;
   while(1) {
    $99 = HEAP16[$leftOver>>1]|0;
    $61 = $99&65535;
    $100 = ($99<<16>>16)==(0);
    L7: do {
     if ($100) {
      $101 = ($$219>>>0)<($2>>>0);
      if ($101) {
       $$013 = $$219;$$1212 = $$318;
       L9: while(1) {
        $10 = HEAP16[$$013>>1]|0;
        $15 = $10&65535;
        $55 = ($10&65535)>(127);
        do {
         if ($55) {
          $11 = ($10&65535)>(2047);
          if (!($11)) {
           $12 = (($$1212) + 1|0);
           $13 = ($12>>>0)<($3>>>0);
           if (!($13)) {
            break L4;
           }
           $14 = $15 >>> 6;
           $16 = $14 | 192;
           $17 = $16&255;
           HEAP8[$$1212>>0] = $17;
           $18 = $15 & 63;
           $19 = $18 | 128;
           $20 = $19&255;
           HEAP8[$12>>0] = $20;
           $21 = (($$1212) + 2|0);
           $$01 = $21;
           break;
          }
          $$off5 = (($10) + 10240)<<16>>16;
          $22 = ($$off5&65535)<(2048);
          if (!($22)) {
           $23 = (($$1212) + 2|0);
           $24 = ($23>>>0)<($3>>>0);
           if (!($24)) {
            break L4;
           }
           $25 = $15 >>> 12;
           $26 = $25 | 224;
           $27 = $26&255;
           HEAP8[$$1212>>0] = $27;
           $28 = (($$1212) + 1|0);
           $29 = $15 >>> 6;
           $30 = $29 & 63;
           $31 = $30 | 128;
           $32 = $31&255;
           HEAP8[$28>>0] = $32;
           $33 = $15 & 63;
           $34 = $33 | 128;
           $35 = $34&255;
           HEAP8[$23>>0] = $35;
           $36 = (($$1212) + 3|0);
           $$01 = $36;
           break;
          }
          $37 = ($10&65535)>(56319);
          if (!($37)) {
           break L9;
          }
          $39 = (($$1212) + 2|0);
          $40 = ($39>>>0)<($3>>>0);
          if (!($40)) {
           break L4;
          }
          $41 = $15 >>> 12;
          $42 = $41 | 224;
          $43 = $42&255;
          HEAP8[$$1212>>0] = $43;
          $44 = (($$1212) + 1|0);
          $45 = $15 >>> 6;
          $46 = $45 & 63;
          $47 = $46 | 128;
          $48 = $47&255;
          HEAP8[$44>>0] = $48;
          $49 = $15 & 63;
          $50 = $49 | 128;
          $51 = $50&255;
          HEAP8[$39>>0] = $51;
          $52 = (($$1212) + 3|0);
          HEAP16[$leftOver>>1] = 0;
          $$01 = $52;
         } else {
          $7 = ($$1212>>>0)<($3>>>0);
          if (!($7)) {
           break L4;
          }
          $8 = (($$1212) + 1|0);
          $9 = $10&255;
          HEAP8[$$1212>>0] = $9;
          $$01 = $8;
         }
        } while(0);
        $53 = (($$013) + 2|0);
        $54 = ($53>>>0)<($2>>>0);
        if ($54) {
         $$013 = $53;$$1212 = $$01;
        } else {
         $$2$be = $53;$$3$be = $$01;
         break L7;
        }
       }
       HEAP16[$leftOver>>1] = $10;
       $38 = (($$013) + 2|0);
       $$2$be = $38;$$3$be = $$1212;
      } else {
       $$2$be = $$219;$$3$be = $$318;
      }
     } else {
      $56 = HEAP16[$$219>>1]|0;
      $$off = (($56) + 9216)<<16>>16;
      $57 = ($$off&65535)>(1023);
      if ($57) {
       $84 = (($$318) + 2|0);
       $85 = ($84>>>0)<($3>>>0);
       if (!($85)) {
        break L4;
       }
       $86 = $61 >>> 12;
       $87 = $86 | 224;
       $88 = $87&255;
       HEAP8[$$318>>0] = $88;
       $89 = (($$318) + 1|0);
       $90 = $61 >>> 6;
       $91 = $90 & 63;
       $92 = $91 | 128;
       $93 = $92&255;
       HEAP8[$89>>0] = $93;
       $94 = $61 & 63;
       $95 = $94 | 128;
       $96 = $95&255;
       HEAP8[$84>>0] = $96;
       $97 = (($$318) + 3|0);
       $$1 = $$219;$$23 = $97;
      } else {
       $58 = $56&65535;
       $59 = $58 | 65536;
       $60 = $61 << 10;
       $62 = (($60) + -56679424)|0;
       $63 = (($62) + ($59))|0;
       $64 = (($$318) + 3|0);
       $65 = ($64>>>0)<($3>>>0);
       if (!($65)) {
        break L4;
       }
       $66 = $63 >>> 18;
       $67 = $66 | 240;
       $68 = $67&255;
       HEAP8[$$318>>0] = $68;
       $69 = (($$318) + 1|0);
       $70 = $63 >>> 12;
       $71 = $70 & 63;
       $72 = $71 | 128;
       $73 = $72&255;
       HEAP8[$69>>0] = $73;
       $74 = (($$318) + 2|0);
       $75 = $63 >>> 6;
       $76 = $75 & 63;
       $77 = $76 | 128;
       $78 = $77&255;
       HEAP8[$74>>0] = $78;
       $fold = (($58) + ($62))|0;
       $79 = $fold & 63;
       $80 = $79 | 128;
       $81 = $80&255;
       HEAP8[$64>>0] = $81;
       $82 = (($$318) + 4|0);
       $83 = (($$219) + 2|0);
       $$1 = $83;$$23 = $82;
      }
      HEAP16[$leftOver>>1] = 0;
      $$2$be = $$1;$$3$be = $$23;
     }
    } while(0);
    $98 = ($$2$be>>>0)<($2>>>0);
    if ($98) {
     $$219 = $$2$be;$$318 = $$3$be;
    } else {
     $$3$lcssa = $$3$be;
     label = 27;
     break;
    }
   }
  } else {
   $$3$lcssa = $bytes;
   label = 27;
  }
 } while(0);
 if ((label|0) == 27) {
  if (!($flush)) {
   $$4 = $$3$lcssa;
   $119 = $3;
   $120 = $$4;
   $121 = (($bcount) - ($119))|0;
   $122 = (($121) + ($120))|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($122|0);
  }
  $102 = HEAP16[$leftOver>>1]|0;
  $103 = $102&65535;
  $104 = ($102<<16>>16)==(0);
  if ($104) {
   $$4 = $$3$lcssa;
   $119 = $3;
   $120 = $$4;
   $121 = (($bcount) - ($119))|0;
   $122 = (($121) + ($120))|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($122|0);
  }
  $105 = (($$3$lcssa) + 2|0);
  $106 = ($105>>>0)<($3>>>0);
  if ($106) {
   $107 = $103 >>> 12;
   $108 = $107 | 224;
   $109 = $108&255;
   HEAP8[$$3$lcssa>>0] = $109;
   $110 = (($$3$lcssa) + 1|0);
   $111 = $103 >>> 6;
   $112 = $111 & 63;
   $113 = $112 | 128;
   $114 = $113&255;
   HEAP8[$110>>0] = $114;
   $115 = $103 & 63;
   $116 = $115 | 128;
   $117 = $116&255;
   HEAP8[$105>>0] = $117;
   $118 = (($$3$lcssa) + 3|0);
   HEAP16[$leftOver>>1] = 0;
   $$4 = $118;
   $119 = $3;
   $120 = $$4;
   $121 = (($bcount) - ($119))|0;
   $122 = (($121) + ($120))|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($122|0);
  }
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2560072|0))|0);
 $123 = __THREW__; __THREW__ = 0;
 $124 = $123&1;
 if ($124) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 __THREW__ = 0;
 $125 = (invoke_ii(3469,(2560072|0))|0);
 $126 = __THREW__; __THREW__ = 0;
 $127 = $126&1;
 if ($127) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $128 = HEAP32[3058640>>2]|0;
 $129 = HEAP32[3058648>>2]|0;
 __THREW__ = 0;
 invoke_viii(641,($125|0),($128|0),($129|0));
 $130 = __THREW__; __THREW__ = 0;
 $131 = $130&1;
 if ($131) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3838,($125|0));
 $132 = __THREW__; __THREW__ = 0;
 $133 = $132&1;
 if ($133) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  // unreachable;
 }
 return 0|0;
}
function __Z190mscorlib_System_Text_UTF8Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542048);
 HEAP16[$V_0>>1] = 0;
 __THREW__ = 0;
 $0 = (invoke_iiiiiiiii(21,0,($chars|0),($charIndex|0),($charCount|0),($bytes|0),($byteIndex|0),($V_0|0),1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z170mscorlib_System_Text_UTF8Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P33mscorlib_System_Text_UTF8EncodingPtiPhi($__this,$chars,$charCount,$bytes,$byteCount) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542096);
 HEAP16[$V_0>>1] = 0;
 __THREW__ = 0;
 invoke_v(745);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3058704>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($charCount|0)>(-1);
   if (!($15)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2606944|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2606944|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3058712>>2]|0;
    __THREW__ = 0;
    invoke_vii(1945,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($bytes|0)==(0|0);
   if ($26) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(3469,(2560584|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[3058720>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($29|0),($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($29|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    // unreachable;
   }
   $37 = ($byteCount|0)>(-1);
   if (!($37)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2606944|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    $40 = (invoke_ii(3469,(2606944|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $43 = HEAP32[3058728>>2]|0;
    __THREW__ = 0;
    invoke_vii(1945,($40|0),($43|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($40|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    // unreachable;
   }
   $48 = ($charCount|0)==(0);
   if ($48) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   HEAP16[$V_0>>1] = 0;
   $49 = ($byteCount|0)==(0);
   if ($49) {
    __THREW__ = 0;
    $50 = (invoke_iiiiiiii(92,0,($chars|0),($charCount|0),(0|0),0,($V_0|0),1)|0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    } else {
     $$0 = $50;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    __THREW__ = 0;
    $53 = (invoke_iiiiiiii(92,0,($chars|0),($charCount|0),($bytes|0),($byteCount|0),($V_0|0),1)|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     break;
    } else {
     $$0 = $53;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_IndexOutOfRangeException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP40mscorlib_System_IndexOutOfRangeExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2606712);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z336mscorlib_System_Text_UTF8Encoding_m_InternalGetCharCount_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_UInt32_mscorlib_System_UInt32_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriijjS0_PP42mscorlib_System_Text_DecoderFallbackBufferPS2_b($__this,$bytes,$index,$count,$leftOverBits,$leftOverCount,$provider,$fallbackBuffer,$bufferArg,$flush) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 $leftOverBits = $leftOverBits|0;
 $leftOverCount = $leftOverCount|0;
 $provider = $provider|0;
 $fallbackBuffer = $fallbackBuffer|0;
 $bufferArg = $bufferArg|0;
 $flush = $flush|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $G_B14_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542144);
 __THREW__ = 0;
 invoke_v(746);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3058744>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($bytes) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       $55 = ($count|0)==(0);
       if ($55) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($bytes|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       $58 = HEAP32[$18>>2]|0;
       $59 = ($58|0)==(0);
       if ($59) {
        $G_B14_0$0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         break;
        }
        $62 = HEAP32[$18>>2]|0;
        $63 = ($62|0)==(0);
        if ($63) {
         __THREW__ = 0;
         $64 = (invoke_i(132)|0);
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($64|0));
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          break;
         }
        }
        $69 = (($bytes) + 16|0);
        $G_B14_0$0 = $69;
       }
       $70 = (($G_B14_0$0) + ($index)|0);
       __THREW__ = 0;
       $71 = (invoke_iiiiiiiiii(11,0,($70|0),($count|0),($leftOverBits|0),($leftOverCount|0),($provider|0),($fallbackBuffer|0),($bufferArg|0),($flush|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       } else {
        $$0 = $71;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     $41 = HEAP32[3058776>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3058768>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3058760>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3058752>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z315mscorlib_System_Text_UTF8Encoding_m_InternalGetCharCount_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_UInt32_mscorlib_System_UInt32_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectPhijjS0_PP42mscorlib_System_Text_DecoderFallbackBufferPP24mscorlib_System_Byte_arrb($__this,$bytes,$count,$leftOverBits,$leftOverCount,$provider,$fallbackBuffer,$bufferArg,$flush) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $count = $count|0;
 $leftOverBits = $leftOverBits|0;
 $leftOverCount = $leftOverCount|0;
 $provider = $provider|0;
 $fallbackBuffer = $fallbackBuffer|0;
 $bufferArg = $bufferArg|0;
 $flush = $flush|0;
 var $$021 = 0, $$1 = 0, $$2$be = 0, $$214 = 0, $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$020 = 0, $V_0$2$be = 0, $V_0$2$lcssa = 0, $V_0$213 = 0, $V_1$1 = 0, $V_1$2 = 0, $V_1$3$be = 0, $V_1$3$lcssa = 0, $V_1$312 = 0, $V_1$4 = 0, $V_4$0$be = 0, $V_4$011 = 0, $V_5$0$be = 0;
 var $V_5$0$lcssa = 0, $V_5$010 = 0, $V_6$0$be = 0, $V_6$0$lcssa = 0, $V_6$09 = 0, $_stackTraceSentry = 0, $flush$not = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542192);
 $0 = ($leftOverCount|0)==(0);
 L1: do {
  if ($0) {
   $1 = ($count|0)>(0);
   if ($1) {
    $$021 = $count;$V_0$020 = 0;
   } else {
    $2 = $leftOverCount >>> 4;
    $3 = $2 & 15;
    $V_0$2$lcssa = 0;$V_1$3$lcssa = 0;$V_5$0$lcssa = 0;$V_6$0$lcssa = $3;
    break;
   }
   while(1) {
    $7 = (($bytes) + ($V_0$020)|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)<(0);
    if ($9) {
     $$1 = $$021;$V_1$1 = $V_0$020;
     label = 6;
     break L1;
    }
    $4 = (($V_0$020) + 1)|0;
    $5 = (($$021) + -1)|0;
    $6 = ($4|0)<($count|0);
    if ($6) {
     $$021 = $5;$V_0$020 = $4;
    } else {
     $$1 = $5;$V_1$1 = $4;
     label = 6;
     break;
    }
   }
  } else {
   $$1 = $count;$V_1$1 = 0;
   label = 6;
  }
 } while(0);
 L8: do {
  if ((label|0) == 6) {
   $10 = $leftOverCount & 15;
   $11 = $leftOverCount >>> 4;
   $12 = $11 & 15;
   $13 = ($$1|0)>(0);
   if ($13) {
    $$214 = $$1;$V_0$213 = $V_1$1;$V_1$312 = $V_1$1;$V_4$011 = $leftOverBits;$V_5$010 = $10;$V_6$09 = $12;
    L10: while(1) {
     $57 = (($V_0$213) + 1)|0;
     $90 = (($bytes) + ($V_0$213)|0);
     $15 = HEAP8[$90>>0]|0;
     $18 = $15&255;
     $91 = (($$214) + -1)|0;
     $92 = ($V_6$09|0)==(0);
     do {
      if ($92) {
       $14 = ($15<<24>>24)<(0);
       if (!($14)) {
        $16 = (($V_1$312) + 1)|0;
        $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $16;$V_4$0$be = $V_4$011;$V_5$0$be = $V_5$010;$V_6$0$be = 0;
        break;
       }
       $17 = $18 & 224;
       $19 = ($17|0)==(192);
       if ($19) {
        $20 = $18 & 31;
        $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $V_1$312;$V_4$0$be = $20;$V_5$0$be = 1;$V_6$0$be = 2;
        break;
       }
       $21 = $18 & 240;
       $22 = ($21|0)==(224);
       if ($22) {
        $23 = $18 & 15;
        $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $V_1$312;$V_4$0$be = $23;$V_5$0$be = 1;$V_6$0$be = 3;
        break;
       }
       $24 = $18 & 248;
       $25 = ($24|0)==(240);
       if ($25) {
        $26 = $18 & 7;
        $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $V_1$312;$V_4$0$be = $26;$V_5$0$be = 1;$V_6$0$be = 4;
        break;
       }
       $27 = $18 & 252;
       $28 = ($27|0)==(248);
       if ($28) {
        $29 = $18 & 3;
        $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $V_1$312;$V_4$0$be = $29;$V_5$0$be = 1;$V_6$0$be = 5;
        break;
       }
       $30 = $18 & 254;
       $31 = ($30|0)==(252);
       if ($31) {
        $32 = $18 & 3;
        $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $V_1$312;$V_4$0$be = $32;$V_5$0$be = 1;$V_6$0$be = 6;
        break;
       }
       $33 = ($V_0$213|0)<(0);
       $34 = $33 << 31 >> 31;
       __THREW__ = 0;
       $35 = (invoke_iiiiiiiii(22,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($V_0$213|0),($34|0),1)|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break L10;
       }
       $38 = (($35) + ($V_1$312))|0;
       $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $38;$V_4$0$be = $V_4$011;$V_5$0$be = $V_5$010;$V_6$0$be = 0;
      } else {
       $43 = $18 & 192;
       $44 = ($43|0)==(128);
       if (!($44)) {
        $81 = ($57|0)<(0);
        $82 = $81 << 31 >> 31;
        $83 = (_i64Subtract(($57|0),($82|0),($V_5$010|0),0)|0);
        $84 = tempRet0;
        __THREW__ = 0;
        $85 = (invoke_iiiiiiiii(22,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($83|0),($84|0),($V_5$010|0))|0);
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         break L10;
        }
        $88 = (($85) + ($V_1$312))|0;
        $$2$be = $$214;$V_0$2$be = $V_0$213;$V_1$3$be = $88;$V_4$0$be = $V_4$011;$V_5$0$be = $V_5$010;$V_6$0$be = 0;
        break;
       }
       $45 = $V_4$011 << 6;
       $46 = $18 & 63;
       $47 = $46 | $45;
       $48 = (($V_5$010) + 1)|0;
       $49 = ($48>>>0)<($V_6$09>>>0);
       if ($49) {
        $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $V_1$312;$V_4$0$be = $47;$V_5$0$be = $48;$V_6$0$be = $V_6$09;
       } else {
        $50 = ($47>>>0)>(65535);
        do {
         if ($50) {
          $73 = ($47>>>0)>(1114111);
          if ($73) {
           $74 = ($57|0)<(0);
           $75 = $74 << 31 >> 31;
           $76 = (_i64Subtract(($57|0),($75|0),($48|0),0)|0);
           $77 = tempRet0;
           __THREW__ = 0;
           $78 = (invoke_iiiiiiiii(22,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($76|0),($77|0),($48|0))|0);
           $79 = __THREW__; __THREW__ = 0;
           $80 = $79&1;
           if ($80) {
            break L10;
           } else {
            $$pn = $78;
           }
          } else {
           $$pn = 2;
          }
         } else {
          switch ($V_6$09|0) {
          case 3:  {
           $52 = ($47>>>0)<(2048);
           if ($52) {
            label = 33;
           }
           break;
          }
          case 4:  {
           $53 = ($47>>>0)<(65536);
           if ($53) {
            label = 33;
           }
           break;
          }
          case 2:  {
           $51 = ($47>>>0)<(128);
           if ($51) {
            label = 33;
           }
           break;
          }
          case 5:  {
           $54 = ($47>>>0)<(2097152);
           if ($54) {
            label = 33;
           }
           break;
          }
          case 6:  {
           $55 = ($47>>>0)<(67108864);
           if ($55) {
            label = 33;
           }
           break;
          }
          default: {
          }
          }
          if ((label|0) == 33) {
           label = 0;
           $56 = ($57|0)<(0);
           $58 = $56 << 31 >> 31;
           $59 = (_i64Subtract(($57|0),($58|0),($48|0),0)|0);
           $60 = tempRet0;
           __THREW__ = 0;
           $61 = (invoke_iiiiiiiii(22,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($59|0),($60|0),($48|0))|0);
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if ($63) {
            break L10;
           } else {
            $$pn = $61;
            break;
           }
          }
          $64 = $45 & 63488;
          $65 = ($64|0)==(55296);
          if ($65) {
           $66 = ($57|0)<(0);
           $67 = $66 << 31 >> 31;
           $68 = (_i64Subtract(($57|0),($67|0),($48|0),0)|0);
           $69 = tempRet0;
           __THREW__ = 0;
           $70 = (invoke_iiiiiiiii(22,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($68|0),($69|0),($48|0))|0);
           $71 = __THREW__; __THREW__ = 0;
           $72 = $71&1;
           if ($72) {
            break L10;
           } else {
            $$pn = $70;
           }
          } else {
           $$pn = 1;
          }
         }
        } while(0);
        $V_1$2 = (($$pn) + ($V_1$312))|0;
        $$2$be = $91;$V_0$2$be = $57;$V_1$3$be = $V_1$2;$V_4$0$be = $47;$V_5$0$be = $48;$V_6$0$be = 0;
       }
      }
     } while(0);
     $89 = ($$2$be|0)>(0);
     if ($89) {
      $$214 = $$2$be;$V_0$213 = $V_0$2$be;$V_1$312 = $V_1$3$be;$V_4$011 = $V_4$0$be;$V_5$010 = $V_5$0$be;$V_6$09 = $V_6$0$be;
     } else {
      $V_0$2$lcssa = $V_0$2$be;$V_1$3$lcssa = $V_1$3$be;$V_5$0$lcssa = $V_5$0$be;$V_6$0$lcssa = $V_6$0$be;
      break L8;
     }
    }
    $39 = ___cxa_find_matching_catch()|0;
    $40 = tempRet0;
    $lpad$phi$index = $39;$lpad$phi$index2 = $40;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   } else {
    $V_0$2$lcssa = $V_1$1;$V_1$3$lcssa = $V_1$1;$V_5$0$lcssa = $10;$V_6$0$lcssa = $12;
   }
  }
 } while(0);
 $flush$not = $flush ^ 1;
 $93 = ($V_6$0$lcssa|0)==(0);
 $or$cond = $93 | $flush$not;
 if ($or$cond) {
  $V_1$4 = $V_1$3$lcssa;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_1$4|0);
 }
 $94 = ($V_0$2$lcssa|0)<(0);
 $95 = $94 << 31 >> 31;
 $96 = (_i64Subtract(($V_0$2$lcssa|0),($95|0),($V_5$0$lcssa|0),0)|0);
 $97 = tempRet0;
 __THREW__ = 0;
 $98 = (invoke_iiiiiiiii(22,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($96|0),($97|0),($V_5$0$lcssa|0))|0);
 $99 = __THREW__; __THREW__ = 0;
 $100 = $99&1;
 if ($100) {
  $41 = ___cxa_find_matching_catch()|0;
  $42 = tempRet0;
  $lpad$phi$index = $41;$lpad$phi$index2 = $42;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 } else {
  $101 = (($98) + ($V_1$3$lcssa))|0;
  $V_1$4 = $101;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_1$4|0);
 }
 return 0|0;
}
function __Z256mscorlib_System_Text_UTF8Encoding_m_Fallback_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int64_mscorlib_System_UInt32P22mscorlib_System_ObjectS0_PP42mscorlib_System_Text_DecoderFallbackBufferPP24mscorlib_System_Byte_arrPhxj($__this,$provider,$buffer,$bufferArg,$bytes,$0,$1,$size) {
 $__this = $__this|0;
 $provider = $provider|0;
 $buffer = $buffer|0;
 $bufferArg = $bufferArg|0;
 $bytes = $bytes|0;
 $0 = $0|0;
 $1 = $1|0;
 $size = $size|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $V_1$0$lcssa = 0, $V_1$06 = 0;
 var $V_2$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542240);
 $2 = HEAP32[$buffer>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   __THREW__ = 0;
   (invoke_ii(2996,(2517288|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_iii(2735,($provider|0),(2517288|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = ($6|0)==(0|0);
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3799,($6|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      __THREW__ = 0;
      $16 = (invoke_iii(2730,(2514128|0),($6|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      HEAP32[$buffer>>2] = $16;
      label = 16;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2515632|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      $21 = (invoke_iii(2769,($provider|0),(2515632|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vi(3799,($21|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        $26 = (invoke_ii(2356,($21|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         HEAP32[$buffer>>2] = $26;
         label = 16;
        }
       }
      }
     }
    }
   }
  } else {
   label = 16;
  }
 } while(0);
 do {
  if ((label|0) == 16) {
   $29 = HEAP32[$bufferArg>>2]|0;
   $30 = ($29|0)==(0|0);
   if ($30) {
    __THREW__ = 0;
    (invoke_ii(2996,(1203320|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __THREW__ = 0;
    $33 = (invoke_iii(2768,(1203320|0),1)|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    HEAP32[$bufferArg>>2] = $33;
    $78 = $33;
   } else {
    $78 = $29;
   }
   $36 = ($size|0)==(0);
   if ($36) {
    $V_1$0$lcssa = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($V_1$0$lcssa|0);
   }
   $38 = $78;$V_1$06 = 0;$V_2$05 = 0;
   while(1) {
    $74 = (($V_2$05) + ($0))|0;
    $75 = (($bytes) + ($74)|0);
    $47 = HEAP8[$75>>0]|0;
    __THREW__ = 0;
    invoke_vi(3799,($38|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     break;
    }
    $37 = (($38) + 12|0);
    $39 = HEAP32[$37>>2]|0;
    $40 = ($39|0)==(0);
    if ($40) {
     __THREW__ = 0;
     $41 = (invoke_i(132)|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($41|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break;
     }
    }
    $46 = (($38) + 16|0);
    HEAP8[$46>>0] = $47;
    $48 = HEAP32[$buffer>>2]|0;
    $49 = HEAP32[$bufferArg>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($48|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    __THREW__ = 0;
    (invoke_iiiii(325,(2514176|0),($48|0),($49|0),0)|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    $54 = HEAP32[$buffer>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($54|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     break;
    }
    __THREW__ = 0;
    $57 = (invoke_iii(2729,(2514272|0),($54|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     break;
    }
    $60 = (($57) + ($V_1$06))|0;
    $61 = HEAP32[$buffer>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($61|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(3495,(2517472|0),($61|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     break;
    }
    $66 = (($V_2$05) + 1)|0;
    $67 = ($66|0)<(0);
    $68 = $67 << 31 >> 31;
    $69 = ($68>>>0)<(0);
    $70 = ($68|0)==(0);
    $71 = ($66>>>0)<($size>>>0);
    $72 = $70 & $71;
    $73 = $69 | $72;
    if (!($73)) {
     $V_1$0$lcssa = $60;
     label = 34;
     break;
    }
    $$pre = HEAP32[$bufferArg>>2]|0;
    $38 = $$pre;$V_1$06 = $60;$V_2$05 = $66;
   }
   if ((label|0) == 34) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($V_1$0$lcssa|0);
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   $lpad$phi$index = $10;$lpad$phi$index2 = $11;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z316mscorlib_System_Text_UTF8Encoding_m_Fallback_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int64_mscorlib_System_UInt32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32U0026_refP22mscorlib_System_ObjectS0_PP42mscorlib_System_Text_DecoderFallbackBufferPP24mscorlib_System_Byte_arrPhxjPtPi($__this,$provider,$buffer,$bufferArg,$bytes,$0,$1,$size,$chars,$charIndex) {
 $__this = $__this|0;
 $provider = $provider|0;
 $buffer = $buffer|0;
 $bufferArg = $bufferArg|0;
 $bytes = $bytes|0;
 $0 = $0|0;
 $1 = $1|0;
 $size = $size|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 var $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $84$phi = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $V_1$08 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542288);
 $2 = HEAP32[$buffer>>2]|0;
 $3 = ($2|0)==(0|0);
 do {
  if ($3) {
   __THREW__ = 0;
   (invoke_ii(2996,(2517288|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_iii(2735,($provider|0),(2517288|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = ($6|0)==(0|0);
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3799,($6|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      $18 = (invoke_iii(2730,(2514128|0),($6|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      HEAP32[$buffer>>2] = $18;
      label = 17;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2515632|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_iii(2769,($provider|0),(2515632|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       invoke_vi(3799,($23|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __THREW__ = 0;
        $28 = (invoke_ii(2356,($23|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         HEAP32[$buffer>>2] = $28;
         label = 17;
        }
       }
      }
     }
    }
   }
  } else {
   label = 17;
  }
 } while(0);
 do {
  if ((label|0) == 17) {
   $31 = HEAP32[$bufferArg>>2]|0;
   $32 = ($31|0)==(0|0);
   if ($32) {
    __THREW__ = 0;
    (invoke_ii(2996,(1203320|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    $35 = (invoke_iii(2768,(1203320|0),1)|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    HEAP32[$bufferArg>>2] = $35;
    $91 = $35;
   } else {
    $91 = $31;
   }
   $38 = ($size|0)==(0);
   if ($38) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else {
    $40 = $91;$84 = 0;$85 = 0;$V_1$08 = 1;
   }
   L23: while(1) {
    $86 = (_i64Add(($84|0),($85|0),($0|0),($1|0))|0);
    $87 = tempRet0;
    $88 = (($bytes) + ($86)|0);
    $49 = HEAP8[$88>>0]|0;
    __THREW__ = 0;
    invoke_vi(3799,($40|0));
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     label = 6;
     break;
    }
    $39 = (($40) + 12|0);
    $41 = HEAP32[$39>>2]|0;
    $42 = ($41|0)==(0);
    if ($42) {
     __THREW__ = 0;
     $43 = (invoke_i(132)|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 6;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($43|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 6;
      break;
     }
    }
    $48 = (($40) + 16|0);
    HEAP8[$48>>0] = $49;
    $50 = HEAP32[$buffer>>2]|0;
    $51 = HEAP32[$bufferArg>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($50|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    (invoke_iiiii(325,(2514176|0),($50|0),($51|0),0)|0);
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     label = 6;
     break;
    }
    while(1) {
     $61 = HEAP32[$buffer>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($61|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      label = 5;
      break L23;
     }
     __THREW__ = 0;
     $64 = (invoke_iii(2729,(2514272|0),($61|0))|0);
     $65 = __THREW__; __THREW__ = 0;
     $66 = $65&1;
     if ($66) {
      label = 5;
      break L23;
     }
     $67 = ($64|0)>(0);
     if (!($67)) {
      break;
     }
     $68 = HEAP32[$charIndex>>2]|0;
     $69 = (($68) + 1)|0;
     HEAP32[$charIndex>>2] = $69;
     $60 = (($chars) + ($68<<1)|0);
     $56 = HEAP32[$buffer>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($56|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      label = 5;
      break L23;
     }
     __THREW__ = 0;
     $57 = (invoke_iii(2767,(2514224|0),($56|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      label = 5;
      break L23;
     }
     HEAP16[$60>>1] = $57;
    }
    $72 = HEAP32[$buffer>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($72|0));
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if ($74) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vii(3495,(2517472|0),($72|0));
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if ($76) {
     label = 6;
     break;
    }
    $77 = ($V_1$08|0)<(0);
    $78 = $77 << 31 >> 31;
    $79 = ($78>>>0)<(0);
    $80 = ($78|0)==(0);
    $81 = ($V_1$08>>>0)<($size>>>0);
    $82 = $80 & $81;
    $83 = $79 | $82;
    if (!($83)) {
     label = 38;
     break;
    }
    $$pre = HEAP32[$bufferArg>>2]|0;
    $phitmp = (($V_1$08) + 1)|0;
    $84$phi = $V_1$08;$40 = $$pre;$85 = $78;$V_1$08 = $phitmp;$84 = $84$phi;
   }
   if ((label|0) == 5) {
    $10 = ___cxa_find_matching_catch()|0;
    $11 = tempRet0;
    $lpad$phi$index = $10;$lpad$phi$index3 = $11;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 6) {
    $12 = ___cxa_find_matching_catch()|0;
    $13 = tempRet0;
    $lpad$phi$index = $12;$lpad$phi$index3 = $13;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 38) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index3 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z48mscorlib_System_Text_UTF8Encoding_m_GetCharCountP33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542336);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(2381,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiiiiiiiii(4,0,($bytes|0),($index|0),($count|0),0,0,($0|0),($V_0|0),($V_1|0),1)|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z401mscorlib_System_Text_UTF8Encoding_m_InternalGetChars_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_UInt32U0026_ref_mscorlib_System_UInt32U0026_ref_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arriPjS5_S0_PP42mscorlib_System_Text_DecoderFallbackBufferPS2_b($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex,$leftOverBits,$leftOverCount,$provider,$fallbackBuffer,$bufferArg,$flush) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $leftOverBits = $leftOverBits|0;
 $leftOverCount = $leftOverCount|0;
 $provider = $provider|0;
 $fallbackBuffer = $fallbackBuffer|0;
 $bufferArg = $bufferArg|0;
 $flush = $flush|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $G_B19_0$0 = 0, $G_B26_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542384);
 __THREW__ = 0;
 invoke_v(747);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3058792>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($chars|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3058800>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($byteIndex|0)<(0);
   if (!($26)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = (($bytes) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)<($byteIndex|0);
    if (!($31)) {
     $46 = ($byteCount|0)<(0);
     if (!($46)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = HEAP32[$29>>2]|0;
      $50 = (($49) - ($byteIndex))|0;
      $51 = ($50|0)<($byteCount|0);
      if (!($51)) {
       $66 = ($charIndex|0)<(0);
       if (!($66)) {
        __THREW__ = 0;
        invoke_vi(3799,($chars|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        $69 = (($chars) + 12|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($70|0)<($charIndex|0);
        if (!($71)) {
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         }
         $88 = HEAP32[$69>>2]|0;
         $89 = ($88|0)==($charIndex|0);
         if ($89) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break;
         }
         $92 = HEAP32[$69>>2]|0;
         $93 = ($92|0)==(0);
         if ($93) {
          $G_B19_0$0 = 0;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $94 = __THREW__; __THREW__ = 0;
          $95 = $94&1;
          if ($95) {
           break;
          }
          $96 = HEAP32[$69>>2]|0;
          $97 = ($96|0)==(0);
          if ($97) {
           __THREW__ = 0;
           $98 = (invoke_i(132)|0);
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($98|0));
           $101 = __THREW__; __THREW__ = 0;
           $102 = $101&1;
           if ($102) {
            break;
           }
          }
          $103 = (($chars) + 16|0);
          $G_B19_0$0 = $103;
         }
         $104 = ($byteCount|0)==(0);
         do {
          if (!($104)) {
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            break L1;
           }
           $107 = HEAP32[$29>>2]|0;
           $108 = ($107|0)==($byteIndex|0);
           if ($108) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($bytes|0));
           $118 = __THREW__; __THREW__ = 0;
           $119 = $118&1;
           if ($119) {
            break L1;
           }
           $120 = HEAP32[$29>>2]|0;
           $121 = ($120|0)==(0);
           if ($121) {
            $G_B26_0$0 = 0;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($bytes|0));
            $122 = __THREW__; __THREW__ = 0;
            $123 = $122&1;
            if ($123) {
             break L1;
            }
            $124 = HEAP32[$29>>2]|0;
            $125 = ($124|0)==(0);
            if ($125) {
             __THREW__ = 0;
             $126 = (invoke_i(132)|0);
             $127 = __THREW__; __THREW__ = 0;
             $128 = $127&1;
             if ($128) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3302,($126|0));
             $129 = __THREW__; __THREW__ = 0;
             $130 = $129&1;
             if ($130) {
              break L1;
             }
            }
            $131 = (($bytes) + 16|0);
            $G_B26_0$0 = $131;
           }
           __THREW__ = 0;
           invoke_vi(3799,($chars|0));
           $132 = __THREW__; __THREW__ = 0;
           $133 = $132&1;
           if ($133) {
            break L1;
           }
           $134 = $charIndex << 1;
           $135 = (($G_B19_0$0) + ($134)|0);
           $136 = (($G_B26_0$0) + ($byteIndex)|0);
           $137 = HEAP32[$69>>2]|0;
           $138 = (($137) - ($charIndex))|0;
           __THREW__ = 0;
           $139 = (invoke_iiiiiiiiiiii(2,0,($136|0),($byteCount|0),($135|0),($138|0),($leftOverBits|0),($leftOverCount|0),($provider|0),($fallbackBuffer|0),($bufferArg|0),($flush|0))|0);
           $140 = __THREW__; __THREW__ = 0;
           $141 = $140&1;
           if ($141) {
            break L1;
           } else {
            $$0 = $139;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if ($110) {
          break;
         }
         $111 = $charIndex << 1;
         $112 = (($G_B19_0$0) + ($111)|0);
         $113 = HEAP32[$69>>2]|0;
         $114 = (($113) - ($charIndex))|0;
         __THREW__ = 0;
         $115 = (invoke_iiiiiiiiiiii(2,0,(0|0),0,($112|0),($114|0),($leftOverBits|0),($leftOverCount|0),($provider|0),($fallbackBuffer|0),($bufferArg|0),($flush|0))|0);
         $116 = __THREW__; __THREW__ = 0;
         $117 = $116&1;
         if ($117) {
          break;
         } else {
          $$0 = $115;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       $72 = HEAP32[3058848>>2]|0;
       __THREW__ = 0;
       $73 = (invoke_iii(977,0,($72|0))|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
       __THREW__ = 0;
       $78 = (invoke_ii(3469,(2561352|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        break;
       }
       $81 = HEAP32[3058840>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($78|0),($81|0),($73|0));
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($78|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       // unreachable;
      }
     }
     $52 = HEAP32[3058832>>2]|0;
     __THREW__ = 0;
     $53 = (invoke_iii(977,0,($52|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     __THREW__ = 0;
     $58 = (invoke_ii(3469,(2561352|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     $61 = HEAP32[3058824>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($58|0),($61|0),($53|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($58|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     // unreachable;
    }
   }
   $32 = HEAP32[3058816>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_iii(977,0,($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     $38 = (invoke_ii(3469,(2561352|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = HEAP32[3058808>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($38|0),($41|0),($33|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       __THREW__ = 0;
       invoke_vi(3838,($38|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z381mscorlib_System_Text_UTF8Encoding_m_InternalGetChars_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_UInt32U0026_ref_mscorlib_System_UInt32U0026_ref_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectPhiPtiPjS3_S0_PP42mscorlib_System_Text_DecoderFallbackBufferPP24mscorlib_System_Byte_arrb($__this,$bytes,$byteCount,$chars,$charCount,$leftOverBits,$leftOverCount,$provider,$fallbackBuffer,$bufferArg,$flush) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 $leftOverBits = $leftOverBits|0;
 $leftOverCount = $leftOverCount|0;
 $provider = $provider|0;
 $fallbackBuffer = $fallbackBuffer|0;
 $bufferArg = $bufferArg|0;
 $flush = $flush|0;
 var $$034 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$033 = 0, $V_1$1 = 0, $V_1$2 = 0, $V_1$3$lcssa = 0, $V_1$328 = 0, $V_3 = 0, $V_6$1 = 0;
 var $V_6$2$lcssa = 0, $V_6$227 = 0, $V_7$0 = 0, $V_7$1$lcssa = 0, $V_7$126 = 0, $V_8$0 = 0, $V_8$1$lcssa = 0, $V_8$125 = 0, $_stackTraceSentry = 0, $flush$not = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542432);
 HEAP32[$V_3>>2] = 0;
 __THREW__ = 0;
 invoke_v(748);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   HEAP32[$V_3>>2] = 0;
   $2 = HEAP32[$leftOverCount>>2]|0;
   $3 = ($2|0)==(0);
   L3: do {
    if ($3) {
     $4 = ($byteCount|0)>(0);
     if ($4) {
      $$034 = $byteCount;$13 = 0;$V_1$033 = 0;
     } else {
      $5 = HEAP32[$leftOverBits>>2]|0;
      $6 = $2 >>> 4;
      $7 = $6 & 15;
      $V_1$3$lcssa = 0;$V_6$2$lcssa = $5;$V_7$1$lcssa = 0;$V_8$1$lcssa = $7;
      break;
     }
     while(1) {
      $20 = (($bytes) + ($V_1$033)|0);
      $15 = HEAP8[$20>>0]|0;
      $21 = ($15<<24>>24)<(0);
      if ($21) {
       $$1 = $$034;$V_1$1 = $V_1$033;
       label = 10;
       break L3;
      }
      $12 = (($chars) + ($13<<1)|0);
      $14 = $15&255;
      HEAP16[$12>>1] = $14;
      $16 = (($13) + 1)|0;
      HEAP32[$V_3>>2] = $16;
      $17 = (($V_1$033) + 1)|0;
      $18 = (($$034) + -1)|0;
      $19 = ($17|0)<($byteCount|0);
      if ($19) {
       $$034 = $18;$13 = $16;$V_1$033 = $17;
      } else {
       $$1 = $18;$V_1$1 = $17;
       label = 10;
       break;
      }
     }
    } else {
     $$1 = $byteCount;$V_1$1 = 0;
     label = 10;
    }
   } while(0);
   L10: do {
    if ((label|0) == 10) {
     $22 = HEAP32[$leftOverBits>>2]|0;
     $23 = $2 & 15;
     $24 = $2 >>> 4;
     $25 = $24 & 15;
     $26 = (($$1) + ($V_1$1))|0;
     $27 = ($$1|0)>(0);
     if ($27) {
      $V_1$328 = $V_1$1;$V_6$227 = $22;$V_7$126 = $23;$V_8$125 = $25;
      L12: while(1) {
       $159 = (($bytes) + ($V_1$328)|0);
       $29 = HEAP8[$159>>0]|0;
       $50 = $29&255;
       $160 = ($V_8$125|0)==(0);
       do {
        if ($160) {
         $28 = ($29<<24>>24)<(0);
         if (!($28)) {
          $30 = HEAP32[$V_3>>2]|0;
          $31 = ($30|0)<($charCount|0);
          if (!($31)) {
           label = 13;
           break L12;
          }
          $46 = (($30) + 1)|0;
          HEAP32[$V_3>>2] = $46;
          $47 = (($chars) + ($30<<1)|0);
          $48 = $29&255;
          HEAP16[$47>>1] = $48;
          $V_1$2 = $V_1$328;$V_6$1 = $V_6$227;$V_7$0 = $V_7$126;$V_8$0 = 0;
          break;
         }
         $49 = $50 & 224;
         $51 = ($49|0)==(192);
         if ($51) {
          $52 = $50 & 31;
          $V_1$2 = $V_1$328;$V_6$1 = $52;$V_7$0 = 1;$V_8$0 = 2;
          break;
         }
         $53 = $50 & 240;
         $54 = ($53|0)==(224);
         if ($54) {
          $55 = $50 & 15;
          $V_1$2 = $V_1$328;$V_6$1 = $55;$V_7$0 = 1;$V_8$0 = 3;
          break;
         }
         $56 = $50 & 248;
         $57 = ($56|0)==(240);
         if ($57) {
          $58 = $50 & 7;
          $V_1$2 = $V_1$328;$V_6$1 = $58;$V_7$0 = 1;$V_8$0 = 4;
          break;
         }
         $59 = $50 & 252;
         $60 = ($59|0)==(248);
         if ($60) {
          $61 = $50 & 3;
          $V_1$2 = $V_1$328;$V_6$1 = $61;$V_7$0 = 1;$V_8$0 = 5;
          break;
         }
         $62 = $50 & 254;
         $63 = ($62|0)==(252);
         if ($63) {
          $64 = $50 & 3;
          $V_1$2 = $V_1$328;$V_6$1 = $64;$V_7$0 = 1;$V_8$0 = 6;
          break;
         } else {
          $65 = ($V_1$328|0)<(0);
          $66 = $65 << 31 >> 31;
          __THREW__ = 0;
          invoke_viiiiiiiiii(5,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($V_1$328|0),($66|0),1,($chars|0),($V_3|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           label = 5;
           break L12;
          } else {
           $V_1$2 = $V_1$328;$V_6$1 = $V_6$227;$V_7$0 = $V_7$126;$V_8$0 = 0;
           break;
          }
         }
        } else {
         $69 = $50 & 192;
         $70 = ($69|0)==(128);
         if (!($70)) {
          $150 = ($V_1$328|0)<(0);
          $151 = $150 << 31 >> 31;
          $152 = (_i64Subtract(($V_1$328|0),($151|0),($V_7$126|0),0)|0);
          $153 = tempRet0;
          __THREW__ = 0;
          invoke_viiiiiiiiii(5,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($152|0),($153|0),($V_7$126|0),($chars|0),($V_3|0));
          $154 = __THREW__; __THREW__ = 0;
          $155 = $154&1;
          if ($155) {
           label = 5;
           break L12;
          }
          $156 = (($V_1$328) + -1)|0;
          $V_1$2 = $156;$V_6$1 = $V_6$227;$V_7$0 = $V_7$126;$V_8$0 = 0;
          break;
         }
         $71 = $V_6$227 << 6;
         $72 = $50 & 63;
         $73 = $72 | $71;
         $74 = (($V_7$126) + 1)|0;
         $75 = ($74>>>0)<($V_8$125>>>0);
         if ($75) {
          $V_1$2 = $V_1$328;$V_6$1 = $73;$V_7$0 = $74;$V_8$0 = $V_8$125;
         } else {
          $76 = ($73>>>0)>(65535);
          if ($76) {
           $115 = ($73>>>0)>(1114111);
           if ($115) {
            $144 = ($V_1$328|0)<(0);
            $145 = $144 << 31 >> 31;
            $146 = (_i64Subtract(($V_1$328|0),($145|0),($74|0),0)|0);
            $147 = tempRet0;
            __THREW__ = 0;
            invoke_viiiiiiiiii(5,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($146|0),($147|0),($74|0),($chars|0),($V_3|0));
            $148 = __THREW__; __THREW__ = 0;
            $149 = $148&1;
            if ($149) {
             label = 5;
             break L12;
            } else {
             $V_1$2 = $V_1$328;$V_6$1 = $73;$V_7$0 = $74;$V_8$0 = 0;
             break;
            }
           }
           $116 = HEAP32[$V_3>>2]|0;
           $117 = (($116) + 2)|0;
           $118 = ($117|0)>($charCount|0);
           if ($118) {
            label = 53;
            break L12;
           }
           $133 = (($73) + -65536)|0;
           $134 = (($116) + 1)|0;
           $135 = (($chars) + ($116<<1)|0);
           $136 = $133 >>> 10;
           $137 = (($136) + 55296)|0;
           $138 = $137&65535;
           HEAP16[$135>>1] = $138;
           $139 = (($116) + 2)|0;
           HEAP32[$V_3>>2] = $139;
           $140 = (($chars) + ($134<<1)|0);
           $141 = $133 & 1023;
           $142 = $141 | 56320;
           $143 = $142&65535;
           HEAP16[$140>>1] = $143;
           $V_1$2 = $V_1$328;$V_6$1 = $133;$V_7$0 = $74;$V_8$0 = 0;
           break;
          }
          switch ($V_8$125|0) {
          case 2:  {
           $77 = ($73>>>0)<(128);
           if ($77) {
            label = 40;
           }
           break;
          }
          case 6:  {
           $81 = ($73>>>0)<(67108864);
           if ($81) {
            label = 40;
           }
           break;
          }
          case 4:  {
           $79 = ($73>>>0)<(65536);
           if ($79) {
            label = 40;
           }
           break;
          }
          case 5:  {
           $80 = ($73>>>0)<(2097152);
           if ($80) {
            label = 40;
           }
           break;
          }
          case 3:  {
           $78 = ($73>>>0)<(2048);
           if ($78) {
            label = 40;
           }
           break;
          }
          default: {
          }
          }
          if ((label|0) == 40) {
           label = 0;
           $82 = ($V_1$328|0)<(0);
           $83 = $82 << 31 >> 31;
           $84 = (_i64Subtract(($V_1$328|0),($83|0),($74|0),0)|0);
           $85 = tempRet0;
           __THREW__ = 0;
           invoke_viiiiiiiiii(5,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($84|0),($85|0),($74|0),($chars|0),($V_3|0));
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if ($87) {
            label = 5;
            break L12;
           } else {
            $V_1$2 = $V_1$328;$V_6$1 = $73;$V_7$0 = $74;$V_8$0 = 0;
            break;
           }
          }
          $88 = $71 & 63488;
          $89 = ($88|0)==(55296);
          if ($89) {
           $90 = ($V_1$328|0)<(0);
           $91 = $90 << 31 >> 31;
           $92 = (_i64Subtract(($V_1$328|0),($91|0),($74|0),0)|0);
           $93 = tempRet0;
           __THREW__ = 0;
           invoke_viiiiiiiiii(5,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($92|0),($93|0),($74|0),($chars|0),($V_3|0));
           $94 = __THREW__; __THREW__ = 0;
           $95 = $94&1;
           if ($95) {
            label = 5;
            break L12;
           } else {
            $V_1$2 = $V_1$328;$V_6$1 = $73;$V_7$0 = $74;$V_8$0 = 0;
            break;
           }
          }
          $96 = HEAP32[$V_3>>2]|0;
          $97 = ($96|0)<($charCount|0);
          if (!($97)) {
           label = 44;
           break L12;
          }
          $112 = (($96) + 1)|0;
          HEAP32[$V_3>>2] = $112;
          $113 = (($chars) + ($96<<1)|0);
          $114 = $73&65535;
          HEAP16[$113>>1] = $114;
          $V_1$2 = $V_1$328;$V_6$1 = $73;$V_7$0 = $74;$V_8$0 = 0;
         }
        }
       } while(0);
       $157 = (($V_1$2) + 1)|0;
       $158 = ($157|0)<($26|0);
       if ($158) {
        $V_1$328 = $157;$V_6$227 = $V_6$1;$V_7$126 = $V_7$0;$V_8$125 = $V_8$0;
       } else {
        $V_1$3$lcssa = $157;$V_6$2$lcssa = $V_6$1;$V_7$1$lcssa = $V_7$0;$V_8$1$lcssa = $V_8$0;
        break L10;
       }
      }
      if ((label|0) == 5) {
       $8 = ___cxa_find_matching_catch()|0;
       $9 = tempRet0;
       $lpad$phi$index = $8;$lpad$phi$index2 = $9;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 13) {
       $32 = HEAP32[3058864>>2]|0;
       __THREW__ = 0;
       $33 = (invoke_iii(977,0,($32|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break L1;
       }
       __THREW__ = 0;
       $38 = (invoke_ii(3469,(2560072|0))|0);
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break L1;
       }
       $41 = HEAP32[3058872>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($38|0),($33|0),($41|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3838,($38|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break L1;
       }
       // unreachable;
      }
      else if ((label|0) == 44) {
       $98 = HEAP32[3058880>>2]|0;
       __THREW__ = 0;
       $99 = (invoke_iii(977,0,($98|0))|0);
       $100 = __THREW__; __THREW__ = 0;
       $101 = $100&1;
       if ($101) {
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if ($103) {
        break L1;
       }
       __THREW__ = 0;
       $104 = (invoke_ii(3469,(2560072|0))|0);
       $105 = __THREW__; __THREW__ = 0;
       $106 = $105&1;
       if ($106) {
        break L1;
       }
       $107 = HEAP32[3058888>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($104|0),($99|0),($107|0));
       $108 = __THREW__; __THREW__ = 0;
       $109 = $108&1;
       if ($109) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3838,($104|0));
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if ($111) {
        break L1;
       }
       // unreachable;
      }
      else if ((label|0) == 53) {
       $119 = HEAP32[3058896>>2]|0;
       __THREW__ = 0;
       $120 = (invoke_iii(977,0,($119|0))|0);
       $121 = __THREW__; __THREW__ = 0;
       $122 = $121&1;
       if ($122) {
        break L1;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        break L1;
       }
       __THREW__ = 0;
       $125 = (invoke_ii(3469,(2560072|0))|0);
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if ($127) {
        break L1;
       }
       $128 = HEAP32[3058904>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($125|0),($120|0),($128|0));
       $129 = __THREW__; __THREW__ = 0;
       $130 = $129&1;
       if ($130) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3838,($125|0));
       $131 = __THREW__; __THREW__ = 0;
       $132 = $131&1;
       if ($132) {
        break L1;
       }
       // unreachable;
      }
     } else {
      $V_1$3$lcssa = $V_1$1;$V_6$2$lcssa = $22;$V_7$1$lcssa = $23;$V_8$1$lcssa = $25;
     }
    }
   } while(0);
   $flush$not = $flush ^ 1;
   $161 = ($V_8$1$lcssa|0)==(0);
   $or$cond = $161 | $flush$not;
   if ($or$cond) {
    HEAP32[$leftOverBits>>2] = $V_6$2$lcssa;
    $168 = $V_8$1$lcssa << 4;
    $169 = $V_7$1$lcssa | $168;
    HEAP32[$leftOverCount>>2] = $169;
    $170 = HEAP32[$V_3>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($170|0);
   }
   $162 = ($V_1$3$lcssa|0)<(0);
   $163 = $162 << 31 >> 31;
   $164 = (_i64Subtract(($V_1$3$lcssa|0),($163|0),($V_7$1$lcssa|0),0)|0);
   $165 = tempRet0;
   __THREW__ = 0;
   invoke_viiiiiiiiii(5,0,($provider|0),($fallbackBuffer|0),($bufferArg|0),($bytes|0),($164|0),($165|0),($V_7$1$lcssa|0),($chars|0),($V_3|0));
   $166 = __THREW__; __THREW__ = 0;
   $167 = $166&1;
   if (!($167)) {
    HEAP32[$leftOverBits>>2] = $V_6$2$lcssa;
    $168 = $V_8$1$lcssa << 4;
    $169 = $V_7$1$lcssa | $168;
    HEAP32[$leftOverCount>>2] = $169;
    $170 = HEAP32[$V_3>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($170|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_Text_UTF8Encoding_m_GetCharsP33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 $V_2 = sp + 8|0;
 $V_3 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542480);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 HEAP32[$V_2>>2] = 0;
 HEAP32[$V_3>>2] = 0;
 __THREW__ = 0;
 $0 = (invoke_ii(2381,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 __THREW__ = 0;
 $3 = (invoke_iiiiiiiiiiiii(2,0,($bytes|0),($byteIndex|0),($byteCount|0),($chars|0),($charIndex|0),($V_0|0),($V_1|0),($0|0),($V_2|0),($V_3|0),1)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z42mscorlib_System_Text_UTF8Encoding_m_EqualsP33mscorlib_System_Text_UTF8EncodingP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542528);
 __THREW__ = 0;
 (invoke_ii(2996,(2544368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2544368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = (($__this) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($2) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($9|0)==($13|0);
    if (!($14)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $15 = (($__this) + 48|0);
    $16 = HEAP8[$15>>0]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($2) + 48|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = ($16<<24>>24)==($20<<24>>24);
     if (!($21)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $22 = (invoke_ii(2381,($__this|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_ii(2381,($2|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($22|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         __THREW__ = 0;
         $32 = (invoke_iiii(1644,(2148736|0),($22|0),($27|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          if (!($32)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          $35 = (invoke_ii(2382,($__this|0))|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if (!($37)) {
           __THREW__ = 0;
           invoke_vi(3799,($2|0));
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if (!($39)) {
            __THREW__ = 0;
            $40 = (invoke_ii(2382,($2|0))|0);
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if (!($42)) {
             __THREW__ = 0;
             invoke_vi(3799,($35|0));
             $43 = __THREW__; __THREW__ = 0;
             $44 = $43&1;
             if (!($44)) {
              __THREW__ = 0;
              $45 = (invoke_iiii(1644,(2148736|0),($35|0),($40|0))|0);
              $46 = __THREW__; __THREW__ = 0;
              $47 = $46&1;
              if (!($47)) {
               $$0 = $45;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_Text_UTF8Encoding_m_GetHashCodeP33mscorlib_System_Text_UTF8Encoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542576);
 __THREW__ = 0;
 $0 = (invoke_ii(2383,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z93mscorlib_System_Text_UTF8Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP33mscorlib_System_Text_UTF8EncodingP22mscorlib_System_String($__this,$chars) {
 $__this = $__this|0;
 $chars = $chars|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542624);
 __THREW__ = 0;
 $0 = (invoke_iii(979,($__this|0),($chars|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z45mscorlib_System_Text_UTF8Encoding_m_GetStringP33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2542672);
 __THREW__ = 0;
 $0 = (invoke_iiiii(157,($__this|0),($bytes|0),($index|0),($count|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iiS4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)!=(0);
 $13 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$6,$8,$12)|0);
 HEAP32[$ret>>2] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iS4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 $10 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$3,$5,$9)|0);
 HEAP32[$ret>>2] = $10;
 $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iiS4_iS4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$3,$6,$8,$11,$13,$17)|0);
 HEAP32[$ret>>2] = $18;
 $19 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($19|0);
}
function __ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iS4_iS4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP8[$12>>0]|0;
 $14 = ($13<<24>>24)!=(0);
 $15 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$5,$8,$10,$14)|0);
 HEAP32[$ret>>2] = $15;
 $16 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($16|0);
}
function __ZN12FuncInvoker9I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_28mscorlib_System_UInt32TraitsS2_28mscorlib_System_ObjectTraitsS1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS6_iijjP22mscorlib_System_ObjectS6_S6_bES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($args) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($args) + 32|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)!=(0);
 $23 = (FUNCTION_TABLE_iiiiiiiiiii[$func & 7]($obj,$0,$3,$6,$9,$12,$14,$16,$18,$22)|0);
 HEAP32[$ret>>2] = $23;
 $24 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($24|0);
}
function __ZN12FuncInvoker8I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_28mscorlib_System_UInt32TraitsS2_28mscorlib_System_ObjectTraitsS1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS6_ijjP22mscorlib_System_ObjectS6_S6_bES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($args) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)!=(0);
 $20 = (FUNCTION_TABLE_iiiiiiiiii[$func & 15]($obj,$0,$3,$6,$9,$11,$13,$15,$19)|0);
 HEAP32[$ret>>2] = $20;
 $21 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($21|0);
}
function __ZN12FuncInvoker6I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsS2_S2_27mscorlib_System_Int64Traits28mscorlib_System_UInt32TraitsE6InvokeEPFiPvP22mscorlib_System_ObjectS6_S6_S6_xjES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$2,$4,$6,$11,$14,$17)|0);
 HEAP32[$ret>>2] = $18;
 $19 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($19|0);
}
function __ZN14ActionInvoker8I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_S1_27mscorlib_System_Int64Traits28mscorlib_System_UInt32TraitsS1_S1_E6InvokeEPFvPvP22mscorlib_System_ObjectS5_S5_S5_xjS5_S5_ES5_PS5_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 20|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($args) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($args) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 FUNCTION_TABLE_viiiiiiiiii[$action & 15]($obj,$0,$2,$4,$6,$11,$14,$17,$19,$21);
 STACKTOP = sp;return (0|0);
}
function __ZN13FuncInvoker11I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S1_S1_28mscorlib_System_ObjectTraitsS1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS5_iiS5_iS5_S5_P22mscorlib_System_ObjectS5_S5_bES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($args) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($args) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($args) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($args) + 40|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)!=(0);
 $26 = (FUNCTION_TABLE_iiiiiiiiiiiii[$func & 3]($obj,$0,$3,$6,$8,$11,$13,$15,$17,$19,$21,$25)|0);
 HEAP32[$ret>>2] = $26;
 $27 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($27|0);
}
function __ZN13FuncInvoker10I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_S1_S1_28mscorlib_System_ObjectTraitsS1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS5_iS5_iS5_S5_P22mscorlib_System_ObjectS5_S5_bES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($args) + 32|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($args) + 36|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)!=(0);
 $23 = (FUNCTION_TABLE_iiiiiiiiiiii[$func & 7]($obj,$0,$3,$5,$8,$10,$12,$14,$16,$18,$22)|0);
 HEAP32[$ret>>2] = $23;
 $24 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($24|0);
}
function __Z64mscorlib_System_Text_UTF8Encoding_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $7 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2544104)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($6,$7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $6;
 $10 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $11 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2537600)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($10,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $10;
 STACKTOP = sp;return;
}
function __Z187mscorlib_System_Text_UTF8Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF8Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z235mscorlib_System_Text_UTF8Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF8Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Text_UTF8Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF8Encoding_m_GetStringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Text_UnicodeEncoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_Boolean_mscorlib_System_BooleanP36mscorlib_System_Text_UnicodeEncodingbbb($__this,$bigEndian,$byteOrderMark,$throwOnInvalidBytes) {
 $__this = $__this|0;
 $bigEndian = $bigEndian|0;
 $byteOrderMark = $byteOrderMark|0;
 $throwOnInvalidBytes = $throwOnInvalidBytes|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544552);
 __THREW__ = 0;
 invoke_v(749);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $$ = $bigEndian ? 1201 : 1200;
    __THREW__ = 0;
    invoke_vii(1909,($__this|0),($$|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     if ($throwOnInvalidBytes) {
      __THREW__ = 0;
      (invoke_ii(2996,(2516080|0))|0);
      $8 = __THREW__; __THREW__ = 0;
      $9 = $8&1;
      if ($9) {
       break;
      }
      __THREW__ = 0;
      $10 = (invoke_ii(3469,(2516080|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(2502,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(632,($__this|0),(0|0),($10|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2524464|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      $19 = (invoke_ii(3469,(2524464|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      $22 = HEAP32[3058920>>2]|0;
      __THREW__ = 0;
      invoke_vii(1905,($19|0),($22|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_viii(632,($__this|0),(0|0),($19|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     $27 = (($__this) + 48|0);
     $28 = $bigEndian&1;
     HEAP8[$27>>0] = $28;
     $29 = (($__this) + 49|0);
     $30 = $byteOrderMark&1;
     HEAP8[$29>>0] = $30;
     if ($bigEndian) {
      $31 = HEAP32[3058928>>2]|0;
      $32 = (($__this) + 28|0);
      HEAP32[$32>>2] = $31;
      $33 = HEAP32[3058936>>2]|0;
      $34 = (($__this) + 32|0);
      HEAP32[$34>>2] = $33;
      $35 = HEAP32[3058944>>2]|0;
      $36 = (($__this) + 36|0);
      HEAP32[$36>>2] = $35;
      $37 = (($__this) + 42|0);
      HEAP8[$37>>0] = 0;
      $38 = HEAP32[3058952>>2]|0;
      $39 = (($__this) + 44|0);
      HEAP32[$39>>2] = $38;
      $49 = (($__this) + 12|0);
      HEAP32[$49>>2] = 1200;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     } else {
      $40 = HEAP32[3058960>>2]|0;
      $41 = (($__this) + 28|0);
      HEAP32[$41>>2] = $40;
      $42 = HEAP32[3058968>>2]|0;
      $43 = (($__this) + 32|0);
      HEAP32[$43>>2] = $42;
      $44 = HEAP32[3058976>>2]|0;
      $45 = (($__this) + 36|0);
      HEAP32[$45>>2] = $44;
      $46 = (($__this) + 42|0);
      HEAP8[$46>>0] = 1;
      $47 = HEAP32[3058984>>2]|0;
      $48 = (($__this) + 44|0);
      HEAP32[$48>>2] = $47;
      $49 = (($__this) + 12|0);
      HEAP32[$49>>2] = 1200;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z146mscorlib_System_Text_UnicodeEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Char_arrii($__this,$chars,$index,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544600);
 __THREW__ = 0;
 invoke_v(750);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3059096>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($chars) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       $55 = $count << 1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($55|0);
      }
     }
     $41 = HEAP32[3059128>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3059120>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3059112>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3059104>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Text_UnicodeEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP36mscorlib_System_Text_UnicodeEncodingP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544648);
 __THREW__ = 0;
 invoke_v(751);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($s|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = $17 << 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3059144>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3838,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Text_UnicodeEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P36mscorlib_System_Text_UnicodeEncodingPti($__this,$chars,$count) {
 $__this = $__this|0;
 $chars = $chars|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544696);
 __THREW__ = 0;
 invoke_v(752);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3059160>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($count|0)>(-1);
   if ($15) {
    $26 = $count << 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2561352|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = HEAP32[3059168>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($18|0),($21|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      invoke_vi(3838,($18|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z193mscorlib_System_Text_UnicodeEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri($__this,$chars,$charIndex,$charCount,$bytes,$byteIndex) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B21_0$0 = 0, $G_B25_0$0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544744);
 __THREW__ = 0;
 invoke_v(753);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($chars|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3059184>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($bytes|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3059192>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($charIndex|0)<(0);
   if (!($26)) {
    __THREW__ = 0;
    invoke_vi(3799,($chars|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = (($chars) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)<($charIndex|0);
    if (!($31)) {
     $46 = ($charCount|0)<(0);
     if (!($46)) {
      __THREW__ = 0;
      invoke_vi(3799,($chars|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = HEAP32[$29>>2]|0;
      $50 = (($49) - ($charIndex))|0;
      $51 = ($50|0)<($charCount|0);
      if (!($51)) {
       $66 = ($byteIndex|0)<(0);
       if (!($66)) {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        $69 = (($bytes) + 12|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($70|0)<($byteIndex|0);
        if (!($71)) {
         $86 = ($charCount|0)==(0);
         if ($86) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          break;
         }
         $89 = HEAP32[$69>>2]|0;
         $90 = (($89) - ($byteIndex))|0;
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break;
         }
         $93 = HEAP32[$69>>2]|0;
         $94 = ($93|0)==(0);
         if ($94) {
          __THREW__ = 0;
          (invoke_ii(2996,(1203320|0))|0);
          $95 = __THREW__; __THREW__ = 0;
          $96 = $95&1;
          if ($96) {
           break;
          }
          __THREW__ = 0;
          $97 = (invoke_iii(2768,(1203320|0),1)|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break;
          }
          $$01 = $97;
         } else {
          $$01 = $bytes;
         }
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          break;
         }
         $102 = HEAP32[$29>>2]|0;
         $103 = ($102|0)==(0);
         if ($103) {
          $G_B21_0$0 = 0;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($chars|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           break;
          }
          $106 = HEAP32[$29>>2]|0;
          $107 = ($106|0)==(0);
          if ($107) {
           __THREW__ = 0;
           $108 = (invoke_i(132)|0);
           $109 = __THREW__; __THREW__ = 0;
           $110 = $109&1;
           if ($110) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($108|0));
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            break;
           }
          }
          $113 = (($chars) + 16|0);
          $G_B21_0$0 = $113;
         }
         $114 = ($$01|0)==(0|0);
         do {
          if ($114) {
           $G_B25_0$0 = 0;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            break L1;
           }
           $117 = (($$01) + 12|0);
           $118 = HEAP32[$117>>2]|0;
           $119 = ($118|0)==(0);
           if ($119) {
            $G_B25_0$0 = 0;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $120 = __THREW__; __THREW__ = 0;
           $121 = $120&1;
           if ($121) {
            break L1;
           }
           $122 = HEAP32[$117>>2]|0;
           $123 = ($122|0)==(0);
           if ($123) {
            __THREW__ = 0;
            $124 = (invoke_i(132)|0);
            $125 = __THREW__; __THREW__ = 0;
            $126 = $125&1;
            if ($126) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3302,($124|0));
            $127 = __THREW__; __THREW__ = 0;
            $128 = $127&1;
            if ($128) {
             break L1;
            }
           }
           $129 = (($$01) + 16|0);
           $G_B25_0$0 = $129;
          }
         } while(0);
         $130 = $charIndex << 1;
         $131 = (($G_B21_0$0) + ($130)|0);
         $132 = (($G_B25_0$0) + ($byteIndex)|0);
         __THREW__ = 0;
         $133 = (invoke_iiiiii(124,($__this|0),($131|0),($charCount|0),($132|0),($90|0))|0);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          break;
         } else {
          $$0 = $133;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       $72 = HEAP32[3059240>>2]|0;
       __THREW__ = 0;
       $73 = (invoke_iii(977,0,($72|0))|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
       __THREW__ = 0;
       $78 = (invoke_ii(3469,(2561352|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        break;
       }
       $81 = HEAP32[3059232>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($78|0),($81|0),($73|0));
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($78|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       // unreachable;
      }
     }
     $52 = HEAP32[3059224>>2]|0;
     __THREW__ = 0;
     $53 = (invoke_iii(977,0,($52|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     __THREW__ = 0;
     $58 = (invoke_ii(3469,(2561352|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     $61 = HEAP32[3059216>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($58|0),($61|0),($53|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($58|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     // unreachable;
    }
   }
   $32 = HEAP32[3059208>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_iii(977,0,($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     $38 = (invoke_ii(3469,(2561352|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = HEAP32[3059200>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($38|0),($41|0),($33|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       __THREW__ = 0;
       invoke_vi(3838,($38|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Text_UnicodeEncoding_m_GetBytesInternalP36mscorlib_System_Text_UnicodeEncodingPtiPhi($__this,$chars,$charCount,$bytes,$byteCount) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544840);
 __THREW__ = 0;
 invoke_v(754);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $charCount << 1;
   $3 = ($2|0)>($byteCount|0);
   if (!($3)) {
    $19 = (($__this) + 48|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = ($20<<24>>24)!=(0);
    __THREW__ = 0;
    invoke_viiiii(71,0,($chars|0),($bytes|0),($2|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
   $6 = HEAP32[3059296>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(977,0,($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2560072|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1924,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z173mscorlib_System_Text_UnicodeEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P36mscorlib_System_Text_UnicodeEncodingPtiPhi($__this,$chars,$charCount,$bytes,$byteCount) {
 $__this = $__this|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544792);
 __THREW__ = 0;
 invoke_v(755);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3059256>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($chars|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3059264>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($charCount|0)>(-1);
   if (!($26)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(3469,(2561352|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    $32 = HEAP32[3059272>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($29|0),($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($29|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    // unreachable;
   }
   $37 = ($byteCount|0)>(-1);
   if ($37) {
    __THREW__ = 0;
    $48 = (invoke_iiiiii(124,($__this|0),($chars|0),($charCount|0),($bytes|0),($byteCount|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($48|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __THREW__ = 0;
    $40 = (invoke_ii(3469,(2561352|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     $43 = HEAP32[3059280>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($40|0),($43|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      __THREW__ = 0;
      invoke_vi(3838,($40|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Text_UnicodeEncoding_m_CopyCharsP22mscorlib_System_ObjectPhS1_ib($__this,$src,$dest,$count,$bigEndian) {
 $__this = $__this|0;
 $src = $src|0;
 $dest = $dest|0;
 $count = $count|0;
 $bigEndian = $bigEndian|0;
 var $$0 = 0, $$030 = 0, $$035 = 0, $$1 = 0, $$131 = 0, $$136 = 0, $$2 = 0, $$232 = 0, $$237 = 0, $$3 = 0, $$333 = 0, $$338 = 0, $$4 = 0, $$434 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond15 = 0, $or$cond17 = 0;
 var $or$cond19 = 0, $or$cond21 = 0, $or$cond27 = 0, $or$cond29 = 0, $or$cond5 = 0, $or$cond7 = 0, $scevgep = 0, $scevgep47 = 0, $switch = 0, $switch39 = 0, $umax = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2545176);
 __THREW__ = 0;
 (invoke_ii(2996,(2564344|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 }
 $2 = HEAP8[((2564344 + 116|0))>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  __THREW__ = 0;
  (invoke_ii(2996,(2564344|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($10|0);
   // unreachable;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2564344|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($10|0);
   // unreachable;
  }
  __THREW__ = 0;
  invoke_vi(3839,(2564344|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($10|0);
   // unreachable;
  }
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2564344|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 }
 $14 = HEAP32[((2564344 + 80|0))>>2]|0;
 $15 = (($14) + 1|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $bigEndian&1;
 $19 = ($17|0)==($18|0);
 if (!($19)) {
  $20 = $count & -2;
  __THREW__ = 0;
  invoke_viiii(123,(0|0),($dest|0),($src|0),($20|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($10|0);
   // unreachable;
  } else {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $switch = ($count>>>0)<(2);
 if ($switch) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $23 = $count & -2;
 $24 = ($23|0)==(2);
 L26: do {
  if ($24) {
   $$4 = $src;$$434 = $dest;
  } else {
   $25 = ($23|0)==(4);
   $26 = ($count|0)==(6);
   $or$cond5 = $25 | $26;
   $27 = ($count|0)==(7);
   $or$cond7 = $or$cond5 | $27;
   do {
    if ($or$cond7) {
     $$2 = $src;$$232 = $dest;$$237 = $count;
     label = 20;
    } else {
     $28 = ($23|0)==(8);
     $29 = ($count|0)==(10);
     $or$cond11 = $28 | $29;
     $30 = ($count|0)==(11);
     $or$cond13 = $or$cond11 | $30;
     $31 = ($count|0)==(12);
     $or$cond15 = $or$cond13 | $31;
     $32 = ($count|0)==(13);
     $or$cond17 = $or$cond15 | $32;
     $33 = ($count|0)==(14);
     $or$cond19 = $or$cond17 | $33;
     $34 = ($count|0)==(15);
     $or$cond21 = $or$cond19 | $34;
     if ($or$cond21) {
      $$1 = $src;$$131 = $dest;$$136 = $count;
     } else {
      $35 = (15 - ($count))|0;
      $36 = ($35>>>0)>(4294967280);
      $umax = $36 ? $35 : -16;
      $37 = (($umax) + ($count))|0;
      $38 = $37 & -16;
      $39 = (($38) + 16)|0;
      $scevgep = (($src) + ($39)|0);
      $$0 = $src;$$030 = $dest;$$035 = $count;
      while(1) {
       $40 = (($$0) + 1|0);
       $41 = HEAP8[$40>>0]|0;
       HEAP8[$$030>>0] = $41;
       $42 = (($$030) + 1|0);
       $43 = HEAP8[$$0>>0]|0;
       HEAP8[$42>>0] = $43;
       $44 = (($$030) + 2|0);
       $45 = (($$0) + 3|0);
       $46 = HEAP8[$45>>0]|0;
       HEAP8[$44>>0] = $46;
       $47 = (($$030) + 3|0);
       $48 = (($$0) + 2|0);
       $49 = HEAP8[$48>>0]|0;
       HEAP8[$47>>0] = $49;
       $50 = (($$030) + 4|0);
       $51 = (($$0) + 5|0);
       $52 = HEAP8[$51>>0]|0;
       HEAP8[$50>>0] = $52;
       $53 = (($$030) + 5|0);
       $54 = (($$0) + 4|0);
       $55 = HEAP8[$54>>0]|0;
       HEAP8[$53>>0] = $55;
       $56 = (($$030) + 6|0);
       $57 = (($$0) + 7|0);
       $58 = HEAP8[$57>>0]|0;
       HEAP8[$56>>0] = $58;
       $59 = (($$030) + 7|0);
       $60 = (($$0) + 6|0);
       $61 = HEAP8[$60>>0]|0;
       HEAP8[$59>>0] = $61;
       $62 = (($$030) + 8|0);
       $63 = (($$0) + 9|0);
       $64 = HEAP8[$63>>0]|0;
       HEAP8[$62>>0] = $64;
       $65 = (($$030) + 9|0);
       $66 = (($$0) + 8|0);
       $67 = HEAP8[$66>>0]|0;
       HEAP8[$65>>0] = $67;
       $68 = (($$030) + 10|0);
       $69 = (($$0) + 11|0);
       $70 = HEAP8[$69>>0]|0;
       HEAP8[$68>>0] = $70;
       $71 = (($$030) + 11|0);
       $72 = (($$0) + 10|0);
       $73 = HEAP8[$72>>0]|0;
       HEAP8[$71>>0] = $73;
       $74 = (($$030) + 12|0);
       $75 = (($$0) + 13|0);
       $76 = HEAP8[$75>>0]|0;
       HEAP8[$74>>0] = $76;
       $77 = (($$030) + 13|0);
       $78 = (($$0) + 12|0);
       $79 = HEAP8[$78>>0]|0;
       HEAP8[$77>>0] = $79;
       $80 = (($$030) + 14|0);
       $81 = (($$0) + 15|0);
       $82 = HEAP8[$81>>0]|0;
       HEAP8[$80>>0] = $82;
       $83 = (($$030) + 15|0);
       $84 = (($$0) + 14|0);
       $85 = HEAP8[$84>>0]|0;
       HEAP8[$83>>0] = $85;
       $86 = (($$030) + 16|0);
       $87 = (($$0) + 16|0);
       $88 = (($$035) + -16)|0;
       $89 = ($88>>>0)>(15);
       if ($89) {
        $$0 = $87;$$030 = $86;$$035 = $88;
       } else {
        break;
       }
      }
      $90 = (($count) + -16)|0;
      $91 = (($90) - ($38))|0;
      $scevgep47 = (($dest) + ($39)|0);
      $switch39 = ($91>>>0)<(2);
      if ($switch39) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $92 = $91 & -2;
      $93 = ($92|0)==(2);
      if ($93) {
       $$4 = $scevgep;$$434 = $scevgep47;
       break L26;
      }
      $94 = ($92|0)==(4);
      $95 = ($91|0)==(6);
      $or$cond27 = $94 | $95;
      $96 = ($91|0)==(7);
      $or$cond29 = $or$cond27 | $96;
      if ($or$cond29) {
       $$2 = $scevgep;$$232 = $scevgep47;$$237 = $91;
       label = 20;
       break;
      } else {
       $$1 = $scevgep;$$131 = $scevgep47;$$136 = $91;
      }
     }
     $97 = (($$1) + 1|0);
     $98 = HEAP8[$97>>0]|0;
     HEAP8[$$131>>0] = $98;
     $99 = (($$131) + 1|0);
     $100 = HEAP8[$$1>>0]|0;
     HEAP8[$99>>0] = $100;
     $101 = (($$131) + 2|0);
     $102 = (($$1) + 3|0);
     $103 = HEAP8[$102>>0]|0;
     HEAP8[$101>>0] = $103;
     $104 = (($$131) + 3|0);
     $105 = (($$1) + 2|0);
     $106 = HEAP8[$105>>0]|0;
     HEAP8[$104>>0] = $106;
     $107 = (($$131) + 4|0);
     $108 = (($$1) + 5|0);
     $109 = HEAP8[$108>>0]|0;
     HEAP8[$107>>0] = $109;
     $110 = (($$131) + 5|0);
     $111 = (($$1) + 4|0);
     $112 = HEAP8[$111>>0]|0;
     HEAP8[$110>>0] = $112;
     $113 = (($$131) + 6|0);
     $114 = (($$1) + 7|0);
     $115 = HEAP8[$114>>0]|0;
     HEAP8[$113>>0] = $115;
     $116 = (($$131) + 7|0);
     $117 = (($$1) + 6|0);
     $118 = HEAP8[$117>>0]|0;
     HEAP8[$116>>0] = $118;
     $119 = (($$131) + 8|0);
     $120 = (($$1) + 8|0);
     $121 = $$136 & 4;
     $122 = ($121|0)==(0);
     if ($122) {
      $$3 = $120;$$333 = $119;$$338 = $$136;
     } else {
      $$2 = $120;$$232 = $119;$$237 = $$136;
      label = 20;
     }
    }
   } while(0);
   if ((label|0) == 20) {
    $123 = (($$2) + 1|0);
    $124 = HEAP8[$123>>0]|0;
    HEAP8[$$232>>0] = $124;
    $125 = (($$232) + 1|0);
    $126 = HEAP8[$$2>>0]|0;
    HEAP8[$125>>0] = $126;
    $127 = (($$232) + 2|0);
    $128 = (($$2) + 3|0);
    $129 = HEAP8[$128>>0]|0;
    HEAP8[$127>>0] = $129;
    $130 = (($$232) + 3|0);
    $131 = (($$2) + 2|0);
    $132 = HEAP8[$131>>0]|0;
    HEAP8[$130>>0] = $132;
    $133 = (($$232) + 4|0);
    $134 = (($$2) + 4|0);
    $$3 = $134;$$333 = $133;$$338 = $$237;
   }
   $135 = $$338 & 2;
   $136 = ($135|0)==(0);
   if ($136) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else {
    $$4 = $$3;$$434 = $$333;
   }
  }
 } while(0);
 $137 = (($$4) + 1|0);
 $138 = HEAP8[$137>>0]|0;
 HEAP8[$$434>>0] = $138;
 $139 = (($$434) + 1|0);
 $140 = HEAP8[$$4>>0]|0;
 HEAP8[$139>>0] = $140;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z51mscorlib_System_Text_UnicodeEncoding_m_GetCharCountP36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544888);
 __THREW__ = 0;
 invoke_v(756);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3059312>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($bytes) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       $55 = (($count|0) / 2)&-1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($55|0);
      }
     }
     $41 = HEAP32[3059344>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3059336>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3059328>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3059320>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_Text_UnicodeEncoding_m_GetCharsP36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri($__this,$bytes,$byteIndex,$byteCount,$chars,$charIndex) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteIndex = $byteIndex|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charIndex = $charIndex|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B21_0$0 = 0, $G_B25_0$0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544936);
 __THREW__ = 0;
 invoke_v(757);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3059360>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($chars|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3059368>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($byteIndex|0)<(0);
   if (!($26)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    $29 = (($bytes) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)<($byteIndex|0);
    if (!($31)) {
     $46 = ($byteCount|0)<(0);
     if (!($46)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = HEAP32[$29>>2]|0;
      $50 = (($49) - ($byteIndex))|0;
      $51 = ($50|0)<($byteCount|0);
      if (!($51)) {
       $66 = ($charIndex|0)<(0);
       if (!($66)) {
        __THREW__ = 0;
        invoke_vi(3799,($chars|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         break;
        }
        $69 = (($chars) + 12|0);
        $70 = HEAP32[$69>>2]|0;
        $71 = ($70|0)<($charIndex|0);
        if (!($71)) {
         $86 = ($byteCount|0)==(0);
         if ($86) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          break;
         }
         $89 = HEAP32[$69>>2]|0;
         $90 = (($89) - ($charIndex))|0;
         __THREW__ = 0;
         invoke_vi(3799,($chars|0));
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break;
         }
         $93 = HEAP32[$69>>2]|0;
         $94 = ($93|0)==(0);
         if ($94) {
          __THREW__ = 0;
          (invoke_ii(2996,(1168808|0))|0);
          $95 = __THREW__; __THREW__ = 0;
          $96 = $95&1;
          if ($96) {
           break;
          }
          __THREW__ = 0;
          $97 = (invoke_iii(2768,(1168808|0),1)|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break;
          }
          $$01 = $97;
         } else {
          $$01 = $chars;
         }
         __THREW__ = 0;
         invoke_vi(3799,($bytes|0));
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          break;
         }
         $102 = HEAP32[$29>>2]|0;
         $103 = ($102|0)==(0);
         if ($103) {
          $G_B21_0$0 = 0;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($bytes|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           break;
          }
          $106 = HEAP32[$29>>2]|0;
          $107 = ($106|0)==(0);
          if ($107) {
           __THREW__ = 0;
           $108 = (invoke_i(132)|0);
           $109 = __THREW__; __THREW__ = 0;
           $110 = $109&1;
           if ($110) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($108|0));
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if ($112) {
            break;
           }
          }
          $113 = (($bytes) + 16|0);
          $G_B21_0$0 = $113;
         }
         $114 = ($$01|0)==(0|0);
         do {
          if ($114) {
           $G_B25_0$0 = 0;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            break L1;
           }
           $117 = (($$01) + 12|0);
           $118 = HEAP32[$117>>2]|0;
           $119 = ($118|0)==(0);
           if ($119) {
            $G_B25_0$0 = 0;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($$01|0));
           $120 = __THREW__; __THREW__ = 0;
           $121 = $120&1;
           if ($121) {
            break L1;
           }
           $122 = HEAP32[$117>>2]|0;
           $123 = ($122|0)==(0);
           if ($123) {
            __THREW__ = 0;
            $124 = (invoke_i(132)|0);
            $125 = __THREW__; __THREW__ = 0;
            $126 = $125&1;
            if ($126) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3302,($124|0));
            $127 = __THREW__; __THREW__ = 0;
            $128 = $127&1;
            if ($128) {
             break L1;
            }
           }
           $129 = (($$01) + 16|0);
           $G_B25_0$0 = $129;
          }
         } while(0);
         $130 = (($G_B21_0$0) + ($byteIndex)|0);
         $131 = $charIndex << 1;
         $132 = (($G_B25_0$0) + ($131)|0);
         __THREW__ = 0;
         $133 = (invoke_iiiiii(125,($__this|0),($130|0),($byteCount|0),($132|0),($90|0))|0);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          break;
         } else {
          $$0 = $133;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       $72 = HEAP32[3059416>>2]|0;
       __THREW__ = 0;
       $73 = (invoke_iii(977,0,($72|0))|0);
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2561352|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break;
       }
       __THREW__ = 0;
       $78 = (invoke_ii(3469,(2561352|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        break;
       }
       $81 = HEAP32[3059408>>2]|0;
       __THREW__ = 0;
       invoke_viii(644,($78|0),($81|0),($73|0));
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($78|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       // unreachable;
      }
     }
     $52 = HEAP32[3059400>>2]|0;
     __THREW__ = 0;
     $53 = (invoke_iii(977,0,($52|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break;
     }
     __THREW__ = 0;
     $58 = (invoke_ii(3469,(2561352|0))|0);
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     $61 = HEAP32[3059392>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($58|0),($61|0),($53|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($58|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     // unreachable;
    }
   }
   $32 = HEAP32[3059384>>2]|0;
   __THREW__ = 0;
   $33 = (invoke_iii(977,0,($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if (!($37)) {
     __THREW__ = 0;
     $38 = (invoke_ii(3469,(2561352|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      $41 = HEAP32[3059376>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($38|0),($41|0),($33|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if (!($43)) {
       __THREW__ = 0;
       invoke_vi(3838,($38|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Text_UnicodeEncoding_m_GetCharsInternalP36mscorlib_System_Text_UnicodeEncodingPhiPti($__this,$bytes,$byteCount,$chars,$charCount) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $byteCount = $byteCount|0;
 $chars = $chars|0;
 $charCount = $charCount|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2545032);
 __THREW__ = 0;
 invoke_v(758);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($byteCount|0) / 2)&-1;
   $3 = ($2|0)>($charCount|0);
   if (!($3)) {
    $19 = (($__this) + 48|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = ($20<<24>>24)!=(0);
    __THREW__ = 0;
    invoke_viiiii(71,0,($bytes|0),($chars|0),($byteCount|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
   $6 = HEAP32[3059480>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(977,0,($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2560072|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1924,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Text_UnicodeEncoding_m_GetStringP36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Byte_arrii($__this,$bytes,$index,$count) {
 $__this = $__this|0;
 $bytes = $bytes|0;
 $index = $index|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $G_B14_0$0 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2544984);
 __THREW__ = 0;
 invoke_v(759);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($bytes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3059432>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)<(0);
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($bytes|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = (($bytes) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)<($index|0);
    if (!($20)) {
     $35 = ($count|0)<(0);
     if (!($35)) {
      __THREW__ = 0;
      invoke_vi(3799,($bytes|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = HEAP32[$18>>2]|0;
      $39 = (($38) - ($index))|0;
      $40 = ($39|0)<($count|0);
      if (!($40)) {
       $55 = ($count|0)==(0);
       if ($55) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
        $58 = HEAP8[((2191608 + 116|0))>>0]|0;
        $59 = ($58<<24>>24)==(0);
        if ($59) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3839,(2191608|0));
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if ($65) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
        $68 = HEAP32[((2191608 + 80|0))>>2]|0;
        $69 = HEAP32[$68>>2]|0;
        $$0 = $69;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $70 = (($count|0) / 2)&-1;
       __THREW__ = 0;
       $71 = (invoke_iii(643,(0|0),($70|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($bytes|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       $76 = HEAP32[$18>>2]|0;
       $77 = ($76|0)==(0);
       if ($77) {
        $G_B14_0$0 = 0;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($bytes|0));
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         break;
        }
        $80 = HEAP32[$18>>2]|0;
        $81 = ($80|0)==(0);
        if ($81) {
         __THREW__ = 0;
         $82 = (invoke_i(132)|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($82|0));
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          break;
         }
        }
        $87 = (($bytes) + 16|0);
        $G_B14_0$0 = $87;
       }
       __THREW__ = 0;
       $88 = (invoke_ii(1919,(0|0))|0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        break;
       }
       $91 = $71;
       $92 = (($88) + ($91))|0;
       $93 = $92;
       $94 = (($G_B14_0$0) + ($index)|0);
       __THREW__ = 0;
       (invoke_iiiiii(125,($__this|0),($94|0),($count|0),($93|0),($70|0))|0);
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        break;
       } else {
        $$0 = $71;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     $41 = HEAP32[3059464>>2]|0;
     __THREW__ = 0;
     $42 = (invoke_iii(977,0,($41|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(3469,(2561352|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = HEAP32[3059456>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($47|0),($50|0),($42|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($47|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     // unreachable;
    }
   }
   $21 = HEAP32[3059448>>2]|0;
   __THREW__ = 0;
   $22 = (invoke_iii(977,0,($21|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2561352|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[3059440>>2]|0;
      __THREW__ = 0;
      invoke_viii(644,($27|0),($30|0),($22|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($27|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_Text_UnicodeEncoding_m_EqualsP36mscorlib_System_Text_UnicodeEncodingP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2545080);
 __THREW__ = 0;
 (invoke_ii(2996,(2546152|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2546152|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = (($__this) + 8|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($2) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($9|0)==($13|0);
    if (!($14)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $15 = (($__this) + 48|0);
    $16 = HEAP8[$15>>0]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($2) + 48|0);
     $20 = HEAP8[$19>>0]|0;
     $21 = ($16<<24>>24)==($20<<24>>24);
     if (!($21)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $22 = (($__this) + 49|0);
     $23 = HEAP8[$22>>0]|0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = (($2) + 49|0);
      $27 = HEAP8[$26>>0]|0;
      $28 = ($23<<24>>24)==($27<<24>>24);
      $$0 = $28;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_Text_UnicodeEncoding_m_GetHashCodeP36mscorlib_System_Text_UnicodeEncoding($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2545128);
 __THREW__ = 0;
 $0 = (invoke_ii(2383,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS4_S4_ibES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$0,$2,$5,$9);
 STACKTOP = sp;return (0|0);
}
function __Z67mscorlib_System_Text_UnicodeEncoding_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2537600)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z193mscorlib_System_Text_UnicodeEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UnicodeEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z241mscorlib_System_Text_UnicodeEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UnicodeEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z116mscorlib_System_Text_UnicodeEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UnicodeEncoding_m_GetStringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_Threading_ExecutionContext_m_GetObjectDataP42mscorlib_System_Threading_ExecutionContextP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2546288);
 __THREW__ = 0;
 invoke_v(760);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($info|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3059496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   } else {
    __THREW__ = 0;
    (invoke_ii(2996,(2622368|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2622368|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2754,($17|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($17|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    // unreachable;
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z68mscorlib_System_NotImplementedException_m__ctor_mscorlib_System_VoidP39mscorlib_System_NotImplementedException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2622096);
 __THREW__ = 0;
 invoke_v(761);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3074016>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2147467263);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z132mscorlib_System_Threading_ExecutionContext_CustomAttributesCacheGenerator_mscorlib_System_Threading_ExecutionContext_m_GetObjectDataP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 __Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_Threading_Interlocked_m_CompareExchangeP22mscorlib_System_ObjectPiii($__this,$location1,$value,$comparand) {
 $__this = $__this|0;
 $location1 = $location1|0;
 $value = $value|0;
 $comparand = $comparand|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2546632);
 $0 = HEAP32[2546680>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2546688|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2546680>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($location1|0),($value|0),($comparand|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_Threading_Interlocked_m_IncrementP22mscorlib_System_ObjectPi($__this,$location) {
 $__this = $__this|0;
 $location = $location|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2546776);
 $0 = HEAP32[2546824>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2546832|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2546824>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($location|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z124mscorlib_System_Threading_Interlocked_CustomAttributesCacheGenerator_mscorlib_System_Threading_Interlocked_m_CompareExchangeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z118mscorlib_System_Threading_Interlocked_CustomAttributesCacheGenerator_mscorlib_System_Threading_Interlocked_m_IncrementP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_Threading_Monitor_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z105mscorlib_System_Threading_Monitor_CustomAttributesCacheGenerator_mscorlib_System_Threading_Monitor_m_ExitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_Threading_NativeEventCalls_m_CloseEvent_internalP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2547672);
 $1 = HEAP32[2547720>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2547728|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2547720>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vi($9|0,($$byval_copy|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z41mscorlib_System_Threading_Thread_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548032);
 __THREW__ = 0;
 (invoke_ii(2996,(2149728|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2149728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1924,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2551552|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2551552 + 80|0))>>2]|0;
     $10 = (($9) + 8|0);
     HEAP32[$10>>2] = $2;
     __THREW__ = 0;
     (invoke_ii(2996,(2149728|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(3469,(2149728|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(1924,($13|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2551552|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         $20 = HEAP32[((2551552 + 80|0))>>2]|0;
         $21 = (($20) + 12|0);
         HEAP32[$21>>2] = $13;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
}
function __Z53mscorlib_System_Threading_Thread_m_get_CurrentContextP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548080);
 __THREW__ = 0;
 $0 = (invoke_ii(2411,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z46mscorlib_System_AppDomain_m_InternalGetContextP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2555496);
 $0 = HEAP32[2555544>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2555552|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2555544>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_Threading_Thread_m_CurrentThread_internalP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548128);
 $0 = HEAP32[2548176>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2548184|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2548176>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_Threading_Thread_m_get_CurrentThreadP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548240);
 __THREW__ = 0;
 $0 = (invoke_ii(2404,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z46mscorlib_System_Threading_Thread_m_GetDomainIDP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548288);
 $0 = HEAP32[2548336>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2548344|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2548336>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_Threading_Thread_m_Thread_free_internalP32mscorlib_System_Threading_Thread22mscorlib_System_IntPtr($__this,$handle) {
 $__this = $__this|0;
 $handle = $handle|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548384);
 $1 = HEAP32[2548432>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2548440|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2548432>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$handle>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii($9|0,($__this|0),($$byval_copy|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43mscorlib_System_Threading_Thread_m_FinalizeP32mscorlib_System_Threading_Thread($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548504);
 $1 = (($__this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vii(1919,($__this|0),($$byval_copy|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch(348288|0)|0;
  $6 = tempRet0;
  $7 = (_llvm_eh_typeid_for((348288|0))|0);
  $8 = ($6|0)==($7|0);
  if (!($8)) {
   $$0 = $6;$$02 = $5;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $9 = (___cxa_begin_catch(($5|0))|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $__last_unhandled_exception$0 = $10;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 21;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(2335,($__this|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(21);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3838,($__last_unhandled_exception$0|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    // unreachable;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $$0 = $14;$$02 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z50mscorlib_System_Threading_Thread_m_GetNewManagedIdP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548552);
 __THREW__ = 0;
 (invoke_ii(2996,(2551552|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2551552 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2551552|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2551552|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2551552|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2551552|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2551552 + 80|0))>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_iii(1001,0,($14|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($15|0);
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_Threading_Thread_m_get_ManagedThreadIdP32mscorlib_System_Threading_Thread($__this) {
 $__this = $__this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548600);
 $0 = (($__this) + 184|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $8 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 __THREW__ = 0;
 $3 = (invoke_ii(2407,0)|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  (invoke_iiiii(177,0,($0|0),($3|0),0)|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $$pre = HEAP32[$0>>2]|0;
   $8 = $$pre;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_Threading_Thread_m_GetHashCodeP32mscorlib_System_Threading_Thread($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2548648);
 __THREW__ = 0;
 $0 = (invoke_ii(2408,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z63mscorlib_System_Threading_Thread_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 $9 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2453576)|0);
 $10 = HEAP32[((2453576 + 48|0))>>2]|0;
 $11 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($10)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($9,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $9;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_local_slotsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2649496)|0);
 __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator__ecP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2649496)|0);
 __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_mscorlib_System_Threading_Thread_m_get_CurrentThreadP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z107mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_mscorlib_System_Threading_Thread_m_FinalizeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z118mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_mscorlib_System_Threading_Thread_m_get_ManagedThreadIdP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_mscorlib_System_Threading_Thread_m_GetHashCodeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z77mscorlib_System_Threading_ThreadAbortException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_Threading_ThreadState_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2602616);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z45mscorlib_System_Threading_WaitHandle_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2552792);
 __THREW__ = 0;
 $0 = (invoke_iii(715,(0|0),-1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2553344|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[((2553344 + 80|0))>>2]|0;
   $6 = (($5) + 4|0);
   HEAP32[$6>>2] = $0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z65mscorlib_System_Threading_WaitHandle_m_System_IDisposable_DisposeP36mscorlib_System_Threading_WaitHandle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2552840);
 __THREW__ = 0;
 invoke_viii(2122,(2552888|0),($__this|0),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1941,0,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z37mscorlib_System_GC_m_SuppressFinalizeP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603312);
 $0 = HEAP32[2603360>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2603368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2603360>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($obj|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z46mscorlib_System_Threading_WaitHandle_m_DisposeP36mscorlib_System_Threading_WaitHandleb($__this,$explicitDisposing) {
 $__this = $__this|0;
 $explicitDisposing = $explicitDisposing|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2552888);
 $0 = (($__this) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 HEAP8[$0>>0] = 1;
 $3 = (($__this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vii(1916,0,($__this|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L7: do {
  if (!($7)) {
   $8 = HEAP32[$3>>2]|0;
   $9 = ($8|0)==(0|0);
   do {
    if ($9) {
     $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 60;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vii(3495,(2446096|0),($8|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 60;
       break;
      }
     }
     $16 = ___cxa_find_matching_catch(348288|0)|0;
     $17 = tempRet0;
     $18 = (_llvm_eh_typeid_for((348288|0))|0);
     $19 = ($17|0)==($18|0);
     if (!($19)) {
      $$0 = $17;$$02 = $16;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($$02|0);
      // unreachable;
     }
     $20 = (___cxa_begin_catch(($16|0))|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     invoke_v(66);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break L7;
     }
     $__last_unhandled_exception$0 = $21;$leaveInstructions$sroa$0$0 = 0;
    }
   } while(0);
   __THREW__ = 0;
   invoke_vii(1917,0,($__this|0));
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    $cond = ($leaveInstructions$sroa$0$0|0)==(60);
    if ($cond) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3838,($__last_unhandled_exception$0|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     // unreachable;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z47mscorlib_System_Threading_WaitHandle_m_FinalizeP36mscorlib_System_Threading_WaitHandle($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2552936);
 __THREW__ = 0;
 invoke_viii(2122,(2552888|0),($__this|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 16;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(16);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3838,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z67mscorlib_System_Threading_WaitHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_AccessViolationException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z92mscorlib_System_ActivationContext_m_System_Runtime_Serialization_ISerializable_GetObjectDataP33mscorlib_System_ActivationContextP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2553784);
 __THREW__ = 0;
 invoke_v(762);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($info|0)==(0|0);
  if (!($2)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3059512>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3838,($7|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z44mscorlib_System_ActivationContext_m_FinalizeP33mscorlib_System_ActivationContext($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2553832);
 __THREW__ = 0;
 invoke_vii(1921,($__this|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 16;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(16);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3838,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z88mscorlib_System_ActivationContext_m_Dispose_mscorlib_System_Void_mscorlib_System_BooleanP33mscorlib_System_ActivationContextb($__this,$disposing) {
 $__this = $__this|0;
 $disposing = $disposing|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2553928);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  HEAP8[$0>>0] = 1;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z64mscorlib_System_ActivationContext_m_Dispose_mscorlib_System_VoidP33mscorlib_System_ActivationContext($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2553880);
 __THREW__ = 0;
 invoke_vii(1921,($__this|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1941,0,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z64mscorlib_System_ActivationContext_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z157mscorlib_System_ActivationContext_CustomAttributesCacheGenerator_mscorlib_System_ActivationContext_m_System_Runtime_Serialization_ISerializable_GetObjectDataP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2554072)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectP20mscorlib_System_Typeb($__this,$type,$nonPublic) {
 $__this = $__this|0;
 $type = $type|0;
 $nonPublic = $nonPublic|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2554584);
 __THREW__ = 0;
 invoke_v(763);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1922,0,($type|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    invoke_vi(3799,($type|0));
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     $6 = (invoke_iii(2734,(2223448|0),($type|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      if ($6) {
       $11 = HEAP32[3059840>>2]|0;
       __THREW__ = 0;
       $12 = (invoke_iiii(559,(0|0),($type|0),($11|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(2560072|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
       $20 = HEAP32[3059848>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($17|0),($12|0),($20|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($17|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vii(1923,0,($type|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2621328|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        $29 = (invoke_iii(2735,($type|0),(2621328|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($29|0)==(0|0);
         if ($32) {
          $$1 = $nonPublic ? 52 : 20;
          __THREW__ = 0;
          (invoke_ii(2996,(2242320|0))|0);
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          }
          $46 = HEAP8[((2242320 + 116|0))>>0]|0;
          $47 = ($46<<24>>24)==(0);
          if ($47) {
           __THREW__ = 0;
           (invoke_ii(2996,(2242320|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2242320|0))|0);
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           if ($51) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3839,(2242320|0));
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if ($53) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2242320|0))|0);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          $56 = HEAP32[((2242320 + 80|0))>>2]|0;
          $57 = (($56) + 8|0);
          $58 = HEAP32[$57>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($type|0));
          $59 = __THREW__; __THREW__ = 0;
          $60 = $59&1;
          if ($60) {
           break;
          }
          __THREW__ = 0;
          $61 = (invoke_iiiiiiii(118,(2236960|0),($type|0),($$1|0),(0|0),3,($58|0),(0|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           break;
          }
          $V_0$0 = $61;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($29|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          __THREW__ = 0;
          $35 = (invoke_ii(2452,($29|0))|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           break;
          }
          $38 = ($35|0)==(0|0);
          $or$cond = $38 | $nonPublic;
          if ($or$cond) {
           $V_0$0 = $35;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($35|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if ($40) {
            break;
           }
           __THREW__ = 0;
           $41 = (invoke_iii(2734,(2410176|0),($35|0))|0);
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if ($43) {
            break;
           }
           $$ = $41 ? $35 : 0;
           $V_0$0 = $$;
          }
         }
         $64 = ($V_0$0|0)==(0|0);
         if (!($64)) {
          __THREW__ = 0;
          invoke_vi(3799,($V_0$0|0));
          $95 = __THREW__; __THREW__ = 0;
          $96 = $95&1;
          if ($96) {
           break;
          }
          __THREW__ = 0;
          $97 = (invoke_iii(906,($V_0$0|0),(0|0))|0);
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if ($99) {
           break;
          } else {
           $$0 = $97;
          }
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($type|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if (!($66)) {
          __THREW__ = 0;
          $67 = (invoke_iii(2734,(2234232|0),($type|0))|0);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if (!($69)) {
           if ($67) {
            __THREW__ = 0;
            $70 = (invoke_iii(1003,0,($type|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            } else {
             $$0 = $70;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           $73 = HEAP32[3059856>>2]|0;
           __THREW__ = 0;
           $74 = (invoke_iii(783,(0|0),($73|0))|0);
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if (!($76)) {
            __THREW__ = 0;
            invoke_vi(3799,($type|0));
            $77 = __THREW__; __THREW__ = 0;
            $78 = $77&1;
            if (!($78)) {
             __THREW__ = 0;
             $79 = (invoke_iii(2730,(2150320|0),($type|0))|0);
             $80 = __THREW__; __THREW__ = 0;
             $81 = $80&1;
             if (!($81)) {
              $82 = HEAP32[3059864>>2]|0;
              __THREW__ = 0;
              $83 = (invoke_iiii(562,(0|0),($82|0),($79|0))|0);
              $84 = __THREW__; __THREW__ = 0;
              $85 = $84&1;
              if (!($85)) {
               __THREW__ = 0;
               (invoke_ii(2996,(2612400|0))|0);
               $86 = __THREW__; __THREW__ = 0;
               $87 = $86&1;
               if (!($87)) {
                __THREW__ = 0;
                $88 = (invoke_ii(3469,(2612400|0))|0);
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if (!($90)) {
                 __THREW__ = 0;
                 invoke_viii(682,($88|0),($74|0),($83|0));
                 $91 = __THREW__; __THREW__ = 0;
                 $92 = $91&1;
                 if ($92) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3838,($88|0));
                 $93 = __THREW__; __THREW__ = 0;
                 $94 = $93&1;
                 if ($94) {
                  break;
                 }
                 // unreachable;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_Type_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP26mscorlib_System_Object_arr($__this,$type,$args) {
 $__this = $__this|0;
 $type = $type|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2554440);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2768,(1167664|0),0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiiii(178,0,($type|0),($args|0),($2|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z148mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_Type_mscorlib_System_Object_arr_arr_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP26mscorlib_System_Object_arrS4_($__this,$type,$args,$activationAttributes) {
 $__this = $__this|0;
 $type = $type|0;
 $args = $args|0;
 $activationAttributes = $activationAttributes|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2554488);
 __THREW__ = 0;
 $0 = (invoke_ii(2196,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiiiiiii(93,0,($type|0),0,($0|0),($args|0),(0|0),($activationAttributes|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z264mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_Type_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfo_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfoS6_($__this,$type,$bindingAttr,$binder,$args,$culture,$activationAttributes) {
 $__this = $__this|0;
 $type = $type|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $args = $args|0;
 $culture = $culture|0;
 $activationAttributes = $activationAttributes|0;
 var $$0 = 0, $$02 = 0, $$bindingAttr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B24_0$0 = 0, $G_B9_0$024 = 0, $V_2$021 = 0;
 var $V_7$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2554536);
 __THREW__ = 0;
 invoke_v(764);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vii(1922,0,($type|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    invoke_vi(3799,($type|0));
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     $6 = (invoke_iii(2734,(2223448|0),($type|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      if ($6) {
       $15 = HEAP32[3059528>>2]|0;
       __THREW__ = 0;
       $16 = (invoke_iiii(559,(0|0),($type|0),($15|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       $21 = (invoke_ii(3469,(2560072|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       $24 = HEAP32[3059536>>2]|0;
       __THREW__ = 0;
       invoke_viii(641,($21|0),($16|0),($24|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($21|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       // unreachable;
      }
      $29 = $bindingAttr & 127;
      $30 = ($29|0)==(0);
      $31 = $bindingAttr | 20;
      $$bindingAttr = $30 ? $31 : $bindingAttr;
      $32 = ($args|0)==(0|0);
      L14: do {
       if ($32) {
        label = 19;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($args|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        $35 = (($args) + 12|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = ($36|0)==(0);
        if ($37) {
         label = 19;
        } else {
         __THREW__ = 0;
         (invoke_ii(2996,(1169184|0))|0);
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          break L1;
         }
         __THREW__ = 0;
         $55 = (invoke_iii(2768,(1169184|0),($36|0))|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          break L1;
         }
         $58 = ($36|0)>(0);
         if ($58) {
          $59 = (($args) + 16|0);
          $60 = (($55) + 16|0);
          $61 = (($55) + 12|0);
          $62 = (($args) + 12|0);
          $V_2$021 = 0;
          while(1) {
           __THREW__ = 0;
           invoke_vi(3799,($args|0));
           $115 = __THREW__; __THREW__ = 0;
           $116 = $115&1;
           if ($116) {
            break;
           }
           $63 = HEAP32[$62>>2]|0;
           $64 = ($V_2$021>>>0)<($63>>>0);
           if (!($64)) {
            __THREW__ = 0;
            $65 = (invoke_i(132)|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($65|0));
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
           }
           $70 = HEAP32[$args>>2]|0;
           $71 = (($70) + 92|0);
           $72 = HEAP32[$71>>2]|0;
           $73 = Math_imul($72, $V_2$021)|0;
           $74 = (($59) + ($73)|0);
           $75 = HEAP32[$74>>2]|0;
           $76 = ($75|0)==(0|0);
           if (!($76)) {
            __THREW__ = 0;
            invoke_vi(3799,($args|0));
            $77 = __THREW__; __THREW__ = 0;
            $78 = $77&1;
            if ($78) {
             break;
            }
            $79 = HEAP32[$62>>2]|0;
            $80 = ($V_2$021>>>0)<($79>>>0);
            if (!($80)) {
             __THREW__ = 0;
             $81 = (invoke_i(132)|0);
             $82 = __THREW__; __THREW__ = 0;
             $83 = $82&1;
             if ($83) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($81|0));
             $84 = __THREW__; __THREW__ = 0;
             $85 = $84&1;
             if ($85) {
              break;
             }
            }
            $86 = HEAP32[$args>>2]|0;
            $87 = (($86) + 92|0);
            $88 = HEAP32[$87>>2]|0;
            $89 = Math_imul($88, $V_2$021)|0;
            $90 = (($59) + ($89)|0);
            $91 = HEAP32[$90>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($91|0));
            $92 = __THREW__; __THREW__ = 0;
            $93 = $92&1;
            if ($93) {
             break;
            }
            __THREW__ = 0;
            $94 = (invoke_ii(1782,($91|0))|0);
            $95 = __THREW__; __THREW__ = 0;
            $96 = $95&1;
            if ($96) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($55|0));
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             break;
            }
            $99 = HEAP32[$61>>2]|0;
            $100 = ($V_2$021>>>0)<($99>>>0);
            if (!($100)) {
             __THREW__ = 0;
             $101 = (invoke_i(132)|0);
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             if ($103) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($101|0));
             $104 = __THREW__; __THREW__ = 0;
             $105 = $104&1;
             if ($105) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($55|0),($94|0));
            $106 = __THREW__; __THREW__ = 0;
            $107 = $106&1;
            if ($107) {
             break;
            }
            $108 = HEAP32[$55>>2]|0;
            $109 = (($108) + 92|0);
            $110 = HEAP32[$109>>2]|0;
            $111 = Math_imul($110, $V_2$021)|0;
            $112 = (($60) + ($111)|0);
            HEAP32[$112>>2] = $94;
           }
           $113 = (($V_2$021) + 1)|0;
           $114 = ($113|0)<($36|0);
           if ($114) {
            $V_2$021 = $113;
           } else {
            $G_B9_0$024 = $55;
            break L14;
           }
          }
          $11 = ___cxa_find_matching_catch()|0;
          $12 = tempRet0;
          $lpad$phi$index = $11;$lpad$phi$index3 = $12;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         } else {
          $G_B9_0$024 = $55;
         }
        }
       }
      } while(0);
      if ((label|0) == 19) {
       __THREW__ = 0;
       (invoke_ii(2996,(2242320|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
       $40 = HEAP8[((2242320 + 116|0))>>0]|0;
       $41 = ($40<<24>>24)==(0);
       if ($41) {
        __THREW__ = 0;
        (invoke_ii(2996,(2242320|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2242320|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2242320|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2242320|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
       $50 = HEAP32[((2242320 + 80|0))>>2]|0;
       $51 = (($50) + 8|0);
       $52 = HEAP32[$51>>2]|0;
       $G_B9_0$024 = $52;
      }
      $117 = ($binder|0)==(0|0);
      if ($117) {
       __THREW__ = 0;
       $118 = (invoke_ii(2196,(0|0))|0);
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        break;
       } else {
        $$02 = $118;
       }
      } else {
       $$02 = $binder;
      }
      __THREW__ = 0;
      invoke_vi(3799,($type|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if (!($122)) {
       __THREW__ = 0;
       $123 = (invoke_iiii(1642,(2240832|0),($type|0),($$bindingAttr|0))|0);
       $124 = __THREW__; __THREW__ = 0;
       $125 = $124&1;
       if (!($125)) {
        __THREW__ = 0;
        invoke_vi(3799,($$02|0));
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if (!($127)) {
         __THREW__ = 0;
         $128 = (invoke_iiiiiii(131,(2399880|0),($$02|0),($$bindingAttr|0),($123|0),($G_B9_0$024|0),(0|0))|0);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if (!($130)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2403064|0))|0);
          $131 = __THREW__; __THREW__ = 0;
          $132 = $131&1;
          if (!($132)) {
           __THREW__ = 0;
           $133 = (invoke_iii(2769,($128|0),(2403064|0))|0);
           $134 = __THREW__; __THREW__ = 0;
           $135 = $134&1;
           if (!($135)) {
            $136 = ($133|0)==(0|0);
            if (!($136)) {
             __THREW__ = 0;
             invoke_vii(1923,0,($type|0));
             $232 = __THREW__; __THREW__ = 0;
             $233 = $232&1;
             if ($233) {
              break;
             }
             $234 = ($activationAttributes|0)==(0|0);
             do {
              if (!($234)) {
               __THREW__ = 0;
               invoke_vi(3799,($activationAttributes|0));
               $235 = __THREW__; __THREW__ = 0;
               $236 = $235&1;
               if ($236) {
                break L1;
               }
               $237 = (($activationAttributes) + 12|0);
               $238 = HEAP32[$237>>2]|0;
               $239 = ($238|0)<(1);
               if ($239) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($type|0));
               $240 = __THREW__; __THREW__ = 0;
               $241 = $240&1;
               if ($241) {
                break L1;
               }
               __THREW__ = 0;
               $242 = (invoke_iii(2734,(2234472|0),($type|0))|0);
               $243 = __THREW__; __THREW__ = 0;
               $244 = $243&1;
               if ($244) {
                break L1;
               }
               if ($242) {
                __THREW__ = 0;
                $281 = (invoke_iiii(895,(0|0),($type|0),($activationAttributes|0))|0);
                $282 = __THREW__; __THREW__ = 0;
                $283 = $282&1;
                if ($283) {
                 break L1;
                }
                $284 = ($281|0)==(0|0);
                if ($284) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($133|0));
                $285 = __THREW__; __THREW__ = 0;
                $286 = $285&1;
                if ($286) {
                 break L1;
                }
                __THREW__ = 0;
                (invoke_iiiiiiii(119,(2410128|0),($133|0),($281|0),($$bindingAttr|0),($$02|0),($args|0),($culture|0))|0);
                $287 = __THREW__; __THREW__ = 0;
                $288 = $287&1;
                if ($288) {
                 break L1;
                } else {
                 $$0 = $281;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               __THREW__ = 0;
               (invoke_ii(2996,(1167664|0))|0);
               $245 = __THREW__; __THREW__ = 0;
               $246 = $245&1;
               if ($246) {
                break L1;
               }
               __THREW__ = 0;
               $247 = (invoke_iii(2768,(1167664|0),1)|0);
               $248 = __THREW__; __THREW__ = 0;
               $249 = $248&1;
               if ($249) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vi(3799,($type|0));
               $250 = __THREW__; __THREW__ = 0;
               $251 = $250&1;
               if ($251) {
                break L1;
               }
               __THREW__ = 0;
               $252 = (invoke_iii(2730,(2150320|0),($type|0))|0);
               $253 = __THREW__; __THREW__ = 0;
               $254 = $253&1;
               if ($254) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vi(3799,($247|0));
               $255 = __THREW__; __THREW__ = 0;
               $256 = $255&1;
               if ($256) {
                break L1;
               }
               $257 = (($247) + 12|0);
               $258 = HEAP32[$257>>2]|0;
               $259 = ($258|0)==(0);
               if ($259) {
                __THREW__ = 0;
                $260 = (invoke_i(132)|0);
                $261 = __THREW__; __THREW__ = 0;
                $262 = $261&1;
                if ($262) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3302,($260|0));
                $263 = __THREW__; __THREW__ = 0;
                $264 = $263&1;
                if ($264) {
                 break L1;
                }
               }
               __THREW__ = 0;
               invoke_vii(3492,($247|0),($252|0));
               $265 = __THREW__; __THREW__ = 0;
               $266 = $265&1;
               if ($266) {
                break L1;
               }
               $267 = (($247) + 16|0);
               HEAP32[$267>>2] = $252;
               $268 = HEAP32[3059568>>2]|0;
               __THREW__ = 0;
               $269 = (invoke_iiii(728,(0|0),($268|0),($247|0))|0);
               $270 = __THREW__; __THREW__ = 0;
               $271 = $270&1;
               if ($271) {
                break L1;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2622808|0))|0);
               $272 = __THREW__; __THREW__ = 0;
               $273 = $272&1;
               if ($273) {
                break L1;
               }
               __THREW__ = 0;
               $274 = (invoke_ii(3469,(2622808|0))|0);
               $275 = __THREW__; __THREW__ = 0;
               $276 = $275&1;
               if ($276) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vii(1954,($274|0),($269|0));
               $277 = __THREW__; __THREW__ = 0;
               $278 = $277&1;
               if ($278) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vi(3838,($274|0));
               $279 = __THREW__; __THREW__ = 0;
               $280 = $279&1;
               if ($280) {
                break L1;
               }
               // unreachable;
              }
             } while(0);
             __THREW__ = 0;
             invoke_vi(3799,($133|0));
             $289 = __THREW__; __THREW__ = 0;
             $290 = $289&1;
             if ($290) {
              break;
             }
             __THREW__ = 0;
             $291 = (invoke_iiiiiii(132,(2402480|0),($133|0),($$bindingAttr|0),($$02|0),($args|0),($culture|0))|0);
             $292 = __THREW__; __THREW__ = 0;
             $293 = $292&1;
             if ($293) {
              break;
             } else {
              $$0 = $291;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            invoke_vi(3799,($type|0));
            $137 = __THREW__; __THREW__ = 0;
            $138 = $137&1;
            if (!($138)) {
             __THREW__ = 0;
             $139 = (invoke_iii(2734,(2234232|0),($type|0))|0);
             $140 = __THREW__; __THREW__ = 0;
             $141 = $140&1;
             if (!($141)) {
              do {
               if ($139) {
                __THREW__ = 0;
                invoke_vi(3799,($G_B9_0$024|0));
                $142 = __THREW__; __THREW__ = 0;
                $143 = $142&1;
                if ($143) {
                 break L1;
                }
                $144 = (($G_B9_0$024) + 12|0);
                $145 = HEAP32[$144>>2]|0;
                $146 = ($145|0)==(0);
                if (!($146)) {
                 break;
                }
                __THREW__ = 0;
                $147 = (invoke_iii(1003,0,($type|0))|0);
                $148 = __THREW__; __THREW__ = 0;
                $149 = $148&1;
                if ($149) {
                 break L1;
                } else {
                 $$0 = $147;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              } while(0);
              __THREW__ = 0;
              (invoke_ii(2996,(2537888|0))|0);
              $150 = __THREW__; __THREW__ = 0;
              $151 = $150&1;
              if (!($151)) {
               __THREW__ = 0;
               $152 = (invoke_ii(3469,(2537888|0))|0);
               $153 = __THREW__; __THREW__ = 0;
               $154 = $153&1;
               if (!($154)) {
                __THREW__ = 0;
                invoke_vi(2525,($152|0));
                $155 = __THREW__; __THREW__ = 0;
                $156 = $155&1;
                if ($156) {
                 break;
                }
                $157 = (($G_B9_0$024) + 12|0);
                $158 = (($G_B9_0$024) + 16|0);
                $V_7$0 = 0;
                while(1) {
                 __THREW__ = 0;
                 invoke_vi(3799,($G_B9_0$024|0));
                 $189 = __THREW__; __THREW__ = 0;
                 $190 = $189&1;
                 if ($190) {
                  label = 6;
                  break;
                 }
                 $191 = HEAP32[$157>>2]|0;
                 $192 = ($V_7$0|0)<($191|0);
                 if (!($192)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($G_B9_0$024|0));
                 $193 = __THREW__; __THREW__ = 0;
                 $194 = $193&1;
                 if ($194) {
                  label = 6;
                  break;
                 }
                 $159 = HEAP32[$157>>2]|0;
                 $160 = ($V_7$0>>>0)<($159>>>0);
                 if (!($160)) {
                  __THREW__ = 0;
                  $161 = (invoke_i(132)|0);
                  $162 = __THREW__; __THREW__ = 0;
                  $163 = $162&1;
                  if ($163) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($161|0));
                  $164 = __THREW__; __THREW__ = 0;
                  $165 = $164&1;
                  if ($165) {
                   label = 6;
                   break;
                  }
                 }
                 $166 = HEAP32[$G_B9_0$024>>2]|0;
                 $167 = (($166) + 92|0);
                 $168 = HEAP32[$167>>2]|0;
                 $169 = Math_imul($168, $V_7$0)|0;
                 $170 = (($158) + ($169)|0);
                 $171 = HEAP32[$170>>2]|0;
                 $172 = ($171|0)==(0|0);
                 if ($172) {
                  $173 = HEAP32[3059544>>2]|0;
                  $G_B24_0$0 = $173;
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($171|0));
                  $174 = __THREW__; __THREW__ = 0;
                  $175 = $174&1;
                  if ($175) {
                   label = 6;
                   break;
                  }
                  __THREW__ = 0;
                  $176 = (invoke_iii(2730,(2149160|0),($171|0))|0);
                  $177 = __THREW__; __THREW__ = 0;
                  $178 = $177&1;
                  if ($178) {
                   label = 6;
                   break;
                  }
                  $G_B24_0$0 = $176;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $179 = __THREW__; __THREW__ = 0;
                 $180 = $179&1;
                 if ($180) {
                  label = 6;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_iii(989,($152|0),($G_B24_0$0|0))|0);
                 $181 = __THREW__; __THREW__ = 0;
                 $182 = $181&1;
                 if ($182) {
                  label = 6;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $183 = __THREW__; __THREW__ = 0;
                 $184 = $183&1;
                 if ($184) {
                  label = 6;
                  break;
                 }
                 $185 = HEAP32[3059552>>2]|0;
                 __THREW__ = 0;
                 (invoke_iii(989,($152|0),($185|0))|0);
                 $186 = __THREW__; __THREW__ = 0;
                 $187 = $186&1;
                 if ($187) {
                  label = 6;
                  break;
                 }
                 $188 = (($V_7$0) + 1)|0;
                 $V_7$0 = $188;
                }
                if ((label|0) == 6) {
                 $9 = ___cxa_find_matching_catch()|0;
                 $10 = tempRet0;
                 $lpad$phi$index = $9;$lpad$phi$index3 = $10;
                 __ZN16StackTraceSentryD2Ev(0);
                 ___resumeException($lpad$phi$index|0);
                 // unreachable;
                }
                __THREW__ = 0;
                invoke_vi(3799,($152|0));
                $195 = __THREW__; __THREW__ = 0;
                $196 = $195&1;
                if ($196) {
                 break;
                }
                __THREW__ = 0;
                $197 = (invoke_ii(2398,($152|0))|0);
                $198 = __THREW__; __THREW__ = 0;
                $199 = $198&1;
                if ($199) {
                 break;
                }
                $200 = ($197|0)<(3);
                if (!($200)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $201 = __THREW__; __THREW__ = 0;
                 $202 = $201&1;
                 if ($202) {
                  break;
                 }
                 __THREW__ = 0;
                 $203 = (invoke_ii(2398,($152|0))|0);
                 $204 = __THREW__; __THREW__ = 0;
                 $205 = $204&1;
                 if ($205) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($152|0));
                 $206 = __THREW__; __THREW__ = 0;
                 $207 = $206&1;
                 if ($207) {
                  break;
                 }
                 $208 = (($203) + -2)|0;
                 __THREW__ = 0;
                 invoke_vii(1912,($152|0),($208|0));
                 $209 = __THREW__; __THREW__ = 0;
                 $210 = $209&1;
                 if ($210) {
                  break;
                 }
                }
                $211 = HEAP32[3059560>>2]|0;
                __THREW__ = 0;
                $212 = (invoke_iii(783,(0|0),($211|0))|0);
                $213 = __THREW__; __THREW__ = 0;
                $214 = $213&1;
                if ($214) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($type|0));
                $215 = __THREW__; __THREW__ = 0;
                $216 = $215&1;
                if ($216) {
                 break;
                }
                __THREW__ = 0;
                $217 = (invoke_iii(2730,(2150320|0),($type|0))|0);
                $218 = __THREW__; __THREW__ = 0;
                $219 = $218&1;
                if ($219) {
                 break;
                }
                __THREW__ = 0;
                $220 = (invoke_iiiii(98,(0|0),($212|0),($217|0),($152|0))|0);
                $221 = __THREW__; __THREW__ = 0;
                $222 = $221&1;
                if ($222) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2612400|0))|0);
                $223 = __THREW__; __THREW__ = 0;
                $224 = $223&1;
                if ($224) {
                 break;
                }
                __THREW__ = 0;
                $225 = (invoke_ii(3469,(2612400|0))|0);
                $226 = __THREW__; __THREW__ = 0;
                $227 = $226&1;
                if ($227) {
                 break;
                }
                __THREW__ = 0;
                invoke_vii(1951,($225|0),($220|0));
                $228 = __THREW__; __THREW__ = 0;
                $229 = $228&1;
                if ($229) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3838,($225|0));
                $230 = __THREW__; __THREW__ = 0;
                $231 = $230&1;
                if ($231) {
                 break;
                }
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_Activator_m_CheckTypeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 20|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2554632);
 __THREW__ = 0;
 invoke_v(765);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = ($type|0)==(0|0);
   if ($6) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3059968>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   HEAP32[$0>>2] = 2266568;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;
   $19 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = ($19|0)==($type|0);
    if (!($22)) {
     HEAP32[$1>>2] = 2266536;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
     $23 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     $26 = ($23|0)==($type|0);
     if (!($26)) {
      HEAP32[$2>>2] = 1271016;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
      $27 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      $30 = ($27|0)==($type|0);
      if (!($30)) {
       HEAP32[$3>>2] = 2266648;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
       $31 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       $34 = ($31|0)==($type|0);
       if (!($34)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __THREW__ = 0;
     $37 = (invoke_iii(2768,(1167664|0),1)|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if (!($39)) {
      __THREW__ = 0;
      invoke_vi(3799,($type|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       __THREW__ = 0;
       $42 = (invoke_iii(2730,(2150320|0),($type|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if (!($44)) {
        __THREW__ = 0;
        invoke_vi(3799,($37|0));
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = (($37) + 12|0);
         $48 = HEAP32[$47>>2]|0;
         $49 = ($48|0)==(0);
         if ($49) {
          __THREW__ = 0;
          $50 = (invoke_i(132)|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($50|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($37|0),($42|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          $57 = (($37) + 16|0);
          HEAP32[$57>>2] = $42;
          $58 = HEAP32[3059976>>2]|0;
          __THREW__ = 0;
          $59 = (invoke_iiii(728,(0|0),($58|0),($37|0))|0);
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if (!($61)) {
           __THREW__ = 0;
           (invoke_ii(2996,(2622808|0))|0);
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if (!($63)) {
            __THREW__ = 0;
            $64 = (invoke_ii(3469,(2622808|0))|0);
            $65 = __THREW__; __THREW__ = 0;
            $66 = $65&1;
            if (!($66)) {
             __THREW__ = 0;
             invoke_vii(1954,($64|0),($59|0));
             $67 = __THREW__; __THREW__ = 0;
             $68 = $67&1;
             if (!($68)) {
              __THREW__ = 0;
              invoke_vi(3838,($64|0));
              $69 = __THREW__; __THREW__ = 0;
              $70 = $69&1;
              if (!($70)) {
               // unreachable;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z50mscorlib_System_Activator_m_CreateInstanceInternalP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2554728);
 $0 = HEAP32[2554776>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2554784|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2554776>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_MissingMethodException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP38mscorlib_System_MissingMethodExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2612048);
 __THREW__ = 0;
 invoke_vii(1950,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233069);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z45mscorlib_System_Activator_m_CheckAbstractTypeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2554680);
 __THREW__ = 0;
 invoke_v(766);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($type|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2734,(2233896|0),($type|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      $11 = (invoke_iii(2768,(1167664|0),1)|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       invoke_vi(3799,($type|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        $16 = (invoke_iii(2730,(2150320|0),($type|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         __THREW__ = 0;
         invoke_vi(3799,($11|0));
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if (!($20)) {
          $21 = (($11) + 12|0);
          $22 = HEAP32[$21>>2]|0;
          $23 = ($22|0)==(0);
          if ($23) {
           __THREW__ = 0;
           $24 = (invoke_i(132)|0);
           $25 = __THREW__; __THREW__ = 0;
           $26 = $25&1;
           if ($26) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($24|0));
           $27 = __THREW__; __THREW__ = 0;
           $28 = $27&1;
           if ($28) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($11|0),($16|0));
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if (!($30)) {
           $31 = (($11) + 16|0);
           HEAP32[$31>>2] = $16;
           $32 = HEAP32[3060104>>2]|0;
           __THREW__ = 0;
           $33 = (invoke_iiii(728,(0|0),($32|0),($11|0))|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2612400|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if (!($37)) {
             __THREW__ = 0;
             $38 = (invoke_ii(3469,(2612400|0))|0);
             $39 = __THREW__; __THREW__ = 0;
             $40 = $39&1;
             if (!($40)) {
              __THREW__ = 0;
              invoke_vii(1951,($38|0),($33|0));
              $41 = __THREW__; __THREW__ = 0;
              $42 = $41&1;
              if (!($42)) {
               __THREW__ = 0;
               invoke_vi(3838,($38|0));
               $43 = __THREW__; __THREW__ = 0;
               $44 = $43&1;
               if (!($44)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z48mscorlib_System_MonoType_m_GetDefaultConstructorP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2615600);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(2615360|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2615360|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2750,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     HEAP32[$0>>2] = $5;
     $10 = $5;
     label = 6;
    }
   }
  }
 } else {
  $10 = $1;
  label = 6;
 }
 do {
  if ((label|0) == 6) {
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $13 = (($10) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0|0);
    if (!($15)) {
     $V_0$0 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_0$0|0);
    }
    $18 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2242320|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = HEAP8[((2242320 + 116|0))>>0]|0;
     $22 = ($21<<24>>24)==(0);
     if ($22) {
      __THREW__ = 0;
      (invoke_ii(2996,(2242320|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2242320|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2242320|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      $31 = HEAP32[((2242320 + 80|0))>>2]|0;
      $32 = (($31) + 8|0);
      $33 = HEAP32[$32>>2]|0;
      __THREW__ = 0;
      $34 = (invoke_iiiiiiii(118,(2236960|0),($__this|0),52,(0|0),3,($33|0),(0|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       __THREW__ = 0;
       invoke_vi(3799,($18|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        $39 = (($18) + 12|0);
        HEAP32[$39>>2] = $34;
        $V_0$0 = $34;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($V_0$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_MissingMethodException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP38mscorlib_System_MissingMethodExceptionP22mscorlib_System_StringS2_($__this,$className,$methodName) {
 $__this = $__this|0;
 $className = $className|0;
 $methodName = $methodName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2612096);
 __THREW__ = 0;
 invoke_viii(680,($__this|0),($className|0),($methodName|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233069);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __ZN12FuncInvoker3I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S5_S5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker6I28mscorlib_System_ObjectTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S1_S1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvS6_iS6_S6_S6_S6_ES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$5,$7,$9,$11)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEPFP22mscorlib_System_ObjectPvS6_bES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z56mscorlib_System_Activator_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443992)|0);
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(2449448)|0);
 $5 = HEAP32[((2449448 + 48|0))>>2]|0;
 $6 = (__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType($5)|0);
 __Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type($4,$6);
 $7 = HEAP32[$3>>2]|0;
 HEAP32[$7>>2] = $4;
 $8 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($8,0);
 $9 = HEAP32[$3>>2]|0;
 $10 = (($9) + 4|0);
 HEAP32[$10>>2] = $8;
 $11 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($11,1);
 $12 = HEAP32[$3>>2]|0;
 $13 = (($12) + 8|0);
 HEAP32[$13>>2] = $11;
 STACKTOP = sp;return;
}
function __Z43mscorlib_System_AppDomain_m_getFriendlyNameP25mscorlib_System_AppDomain($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2555400);
 $0 = HEAP32[2555448>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2555456|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2555448>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_AppDomain_m_InternalGetDefaultContextP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2555592);
 $0 = HEAP32[2555640>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2555648|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2555640>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_AppDomain_m_InternalGetProcessGuidP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$newguid) {
 $__this = $__this|0;
 $newguid = $newguid|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2555696);
 $0 = HEAP32[2555744>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2555752|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2555744>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($newguid|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_AppDomain_m_GetProcessGuidP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_1 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_0 = sp;
 $L_1 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2555808);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2557200|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[((2557200 + 80|0))>>2]|0;
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    invoke_vii(1944,($L_1|0),0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    ;HEAP32[$V_0+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_1+12>>2]|0;
    __THREW__ = 0;
    $9 = (invoke_ii(2446,($V_0|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_iii(1004,0,($9|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2557200|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = HEAP32[((2557200 + 80|0))>>2]|0;
    HEAP32[$17>>2] = $12;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2557200|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = HEAP32[((2557200 + 80|0))>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z30mscorlib_System_Guid_m_NewGuidP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604272);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 (invoke_ii(2996,(1203320|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2768,(1203320|0),16)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2605992|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = HEAP8[((2605992 + 116|0))>>0]|0;
     $8 = ($7<<24>>24)==(0);
     if ($8) {
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2605992|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2605992|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = HEAP32[((2605992 + 80|0))>>2]|0;
      $20 = (($19) + 16|0);
      $21 = HEAP32[$20>>2]|0;
      __THREW__ = 0;
      invoke_vii(1916,0,($21|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2605992|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       do {
        if ($25) {
         label = 16;
        } else {
         $26 = HEAP8[((2605992 + 116|0))>>0]|0;
         $27 = ($26<<24>>24)==(0);
         if ($27) {
          __THREW__ = 0;
          (invoke_ii(2996,(2605992|0))|0);
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if ($29) {
           label = 16;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2605992|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if ($31) {
           label = 16;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2605992|0));
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if ($33) {
           label = 16;
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2605992|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if ($43) {
          label = 16;
         } else {
          $44 = HEAP32[((2605992 + 80|0))>>2]|0;
          $45 = (($44) + 20|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = ($46|0)==(0|0);
          if ($47) {
           __THREW__ = 0;
           $48 = (invoke_ii(2336,(0|0))|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            label = 16;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2605992|0))|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if ($52) {
            label = 16;
            break;
           }
           $53 = HEAP8[((2605992 + 116|0))>>0]|0;
           $54 = ($53<<24>>24)==(0);
           if ($54) {
            __THREW__ = 0;
            (invoke_ii(2996,(2605992|0))|0);
            $55 = __THREW__; __THREW__ = 0;
            $56 = $55&1;
            if ($56) {
             label = 16;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2605992|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if ($58) {
             label = 16;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2605992|0));
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             label = 16;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2605992|0))|0);
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            label = 16;
            break;
           }
           $63 = HEAP32[((2605992 + 80|0))>>2]|0;
           $64 = (($63) + 20|0);
           HEAP32[$64>>2] = $48;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2605992|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           label = 16;
          } else {
           $67 = HEAP8[((2605992 + 116|0))>>0]|0;
           $68 = ($67<<24>>24)==(0);
           if ($68) {
            __THREW__ = 0;
            (invoke_ii(2996,(2605992|0))|0);
            $69 = __THREW__; __THREW__ = 0;
            $70 = $69&1;
            if ($70) {
             label = 16;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2605992|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             label = 16;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2605992|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             label = 16;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2605992|0))|0);
           $75 = __THREW__; __THREW__ = 0;
           $76 = $75&1;
           if ($76) {
            label = 16;
           } else {
            $77 = HEAP32[((2605992 + 80|0))>>2]|0;
            $78 = (($77) + 20|0);
            $79 = HEAP32[$78>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($79|0));
            $80 = __THREW__; __THREW__ = 0;
            $81 = $80&1;
            if ($81) {
             label = 16;
            } else {
             __THREW__ = 0;
             invoke_viii(2110,(2505288|0),($79|0),($2|0));
             $82 = __THREW__; __THREW__ = 0;
             $83 = $82&1;
             if ($83) {
              label = 16;
             } else {
              $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 57;
             }
            }
           }
          }
         }
        }
       } while(0);
       if ((label|0) == 16) {
        $34 = ___cxa_find_matching_catch(348288|0)|0;
        $35 = tempRet0;
        $36 = (_llvm_eh_typeid_for((348288|0))|0);
        $37 = ($35|0)==($36|0);
        if (!($37)) {
         $$0 = $34;$$02 = $35;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $38 = (___cxa_begin_catch(($34|0))|0);
        $39 = HEAP32[$38>>2]|0;
        __THREW__ = 0;
        invoke_v(66);
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        $__last_unhandled_exception$0 = $39;$leaveInstructions$sroa$0$0 = 0;
       }
       __THREW__ = 0;
       invoke_vii(1917,0,($21|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if (!($85)) {
        $cond1 = ($leaveInstructions$sroa$0$0|0)==(57);
        if ($cond1) {
         __THREW__ = 0;
         invoke_vii(1942,($agg$result|0),($2|0));
         $88 = __THREW__; __THREW__ = 0;
         $89 = $88&1;
         if ($89) {
          break;
         }
         $90 = (($agg$result) + 8|0);
         $91 = HEAP8[$90>>0]|0;
         $92 = $91&255;
         $93 = $92 & 63;
         $94 = $93 | 128;
         $95 = $94&255;
         HEAP8[$90>>0] = $95;
         $96 = (($agg$result) + 6|0);
         $97 = HEAP16[$96>>1]|0;
         $98 = $97 & 4095;
         $99 = $98 | 16384;
         HEAP16[$96>>1] = $99;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        } else {
         __THREW__ = 0;
         invoke_vi(3838,($__last_unhandled_exception$0|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         }
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $$0 = $15;$$02 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z54mscorlib_System_Guid_m_ToString_mscorlib_System_StringP20mscorlib_System_Guid($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604512);
 __THREW__ = 0;
 $0 = (invoke_iiiii(184,($__this|0),1,0,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z36mscorlib_System_AppDomain_m_ToStringP25mscorlib_System_AppDomain($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2555856);
 __THREW__ = 0;
 $0 = (invoke_ii(2410,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z56mscorlib_System_AppDomain_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_AppDomain_CustomAttributesCacheGenerator_type_resolve_in_progressP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2649496)|0);
 __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z85mscorlib_System_AppDomain_CustomAttributesCacheGenerator_assembly_resolve_in_progressP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2649496)|0);
 __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z93mscorlib_System_AppDomain_CustomAttributesCacheGenerator_assembly_resolve_in_progress_refonlyP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2649496)|0);
 __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_AppDomain_CustomAttributesCacheGenerator__principalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2649496)|0);
 __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_AppDomainManager_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z61mscorlib_System_AppDomainSetup_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2443176)|0);
 __Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z94mscorlib_System_ApplicationIdentity_m_System_Runtime_Serialization_ISerializable_GetObjectDataP35mscorlib_System_ApplicationIdentityP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2558872);
 __THREW__ = 0;
 invoke_v(767);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($info|0)==(0|0);
  if (!($2)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560584|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2560584|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3060200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3838,($7|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z46mscorlib_System_ApplicationIdentity_m_ToStringP35mscorlib_System_ApplicationIdentity($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2558920);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z66mscorlib_System_ApplicationIdentity_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z161mscorlib_System_ApplicationIdentity_CustomAttributesCacheGenerator_mscorlib_System_ApplicationIdentity_m_System_Runtime_Serialization_ISerializable_GetObjectDataP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2559048)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_ArgumentException_m__ctor_mscorlib_System_VoidP33mscorlib_System_ArgumentException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2559320);
 __THREW__ = 0;
 invoke_v(768);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3060264>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2147024809);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z134mscorlib_System_ArgumentException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_String_mscorlib_System_ExceptionP33mscorlib_System_ArgumentExceptionP22mscorlib_System_StringS2_P25mscorlib_System_Exception($__this,$message,$paramName,$innerException) {
 $__this = $__this|0;
 $message = $message|0;
 $paramName = $paramName|0;
 $innerException = $innerException|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2559464);
 __THREW__ = 0;
 invoke_viii(702,($__this|0),($message|0),($innerException|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 52|0);
  HEAP32[$2>>2] = $paramName;
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147024809);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z49mscorlib_System_ArgumentException_m_get_ParamNameP33mscorlib_System_ArgumentException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2559512);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z47mscorlib_System_ArgumentException_m_get_MessageP33mscorlib_System_ArgumentException($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2559560);
 __THREW__ = 0;
 invoke_v(769);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2730,(2559512|0),($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if (!($5)) {
     __THREW__ = 0;
     $8 = (invoke_iii(2730,(2559512|0),($__this|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_ii(1816,($8|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = ($13|0)==(0);
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_ii(1906,($__this|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      __THREW__ = 0;
      $20 = (invoke_ii(2441,0)|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      $23 = HEAP32[3060216>>2]|0;
      __THREW__ = 0;
      $24 = (invoke_iii(783,(0|0),($23|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_iii(2730,(2559512|0),($__this|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      $30 = (invoke_iiiiii(89,(0|0),($17|0),($20|0),($24|0),($27|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      } else {
       $$0 = $30;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    $33 = (invoke_ii(1906,($__this|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if (!($35)) {
     $$0 = $33;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_Environment_m_get_NewLineP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2601056);
 $0 = HEAP32[2601104>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2601112|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2601104>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_ArgumentException_m_GetObjectDataP33mscorlib_System_ArgumentExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2559608);
 __THREW__ = 0;
 invoke_v(770);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $context;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $0;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  __THREW__ = 0;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  invoke_viii(544,($__this|0),($info|0),($tmpcast$byval_copy|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   $15 = (invoke_iii(2730,(2559512|0),($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = HEAP32[3060376>>2]|0;
     __THREW__ = 0;
     invoke_viii(621,($info|0),($20|0),($15|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
}
function __Z64mscorlib_System_ArgumentException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z112mscorlib_System_ArgumentNullException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP37mscorlib_System_ArgumentNullExceptionP22mscorlib_System_StringS2_($__this,$paramName,$message) {
 $__this = $__this|0;
 $paramName = $paramName|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560304);
 __THREW__ = 0;
 invoke_viii(641,($__this|0),($message|0),($paramName|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147467261);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z68mscorlib_System_ArgumentNullException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z57mscorlib_System_ArgumentOutOfRangeException_m_get_MessageP43mscorlib_System_ArgumentOutOfRangeException($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560912);
 __THREW__ = 0;
 $0 = (invoke_ii(2417,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 56|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   $$0 = $0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $8 = (invoke_ii(2441,0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   $12 = (invoke_iiiii(100,(0|0),($0|0),($8|0),($11|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    $$0 = $12;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_ArgumentOutOfRangeException_m_GetObjectDataP43mscorlib_System_ArgumentOutOfRangeExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2560960);
 __THREW__ = 0;
 invoke_v(771);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $context;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $0;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  __THREW__ = 0;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  invoke_viii(642,($__this|0),($info|0),($tmpcast$byval_copy|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = (($__this) + 56|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3060584>>2]|0;
    __THREW__ = 0;
    invoke_viii(621,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
}
function __Z74mscorlib_System_ArgumentOutOfRangeException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z43mscorlib_System_ArithmeticException_m__ctorP35mscorlib_System_ArithmeticExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2561488);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147024362);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z66mscorlib_System_ArithmeticException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_ArrayTypeMismatchException_m__ctor_mscorlib_System_VoidP42mscorlib_System_ArrayTypeMismatchException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2561840);
 __THREW__ = 0;
 invoke_v(772);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3060624>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233085);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z94mscorlib_System_ArrayTypeMismatchException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP42mscorlib_System_ArrayTypeMismatchExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2561888);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233085);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z73mscorlib_System_ArrayTypeMismatchException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_AssemblyLoadEventArgs_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_AttributeTargets_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($6);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z37mscorlib_System_BitConverter_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2563560);
 __THREW__ = 0;
 (invoke_ii(2420,0)|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2564344|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[((2564344 + 80|0))>>2]|0;
   HEAP8[$4>>0] = 0;
   __THREW__ = 0;
   (invoke_ii(2419,0)|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2564344 + 80|0))>>2]|0;
     $10 = (($9) + 1|0);
     HEAP8[$10>>0] = 1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z52mscorlib_System_BitConverter_m_DoubleWordsAreSwappedP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2563656);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z46mscorlib_System_BitConverter_m_AmILittleEndianP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2563608);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 1;
}
function __Z48mscorlib_System_BitConverter_m_DoubleToInt64BitsP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2563704);
 __THREW__ = 0;
 $0 = (invoke_iid(8,0,(+$value))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(966,0,($0|0),0)|0);
  $4 = tempRet0;
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $4;
   STACKTOP = sp;return ($3|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_BitConverter_m_GetBytes_mscorlib_System_Byte_arr_arr_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $_stackTraceSentry = sp + 8|0;
 HEAPF64[$0>>3] = $value;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2563800);
 HEAPF64[tempDoublePtr>>3] = $value;$1 = HEAP32[tempDoublePtr>>2]|0;
 $2 = HEAP32[tempDoublePtr+4>>2]|0;
 $3 = $2&255;
 $4 = (_bitshift64Lshr(($1|0),($2|0),40)|0);
 $5 = tempRet0;
 $6 = $4&255;
 $7 = (_bitshift64Lshr(($1|0),($2|0),48)|0);
 $8 = tempRet0;
 $9 = $7&255;
 $10 = (_bitshift64Lshr(($1|0),($2|0),56)|0);
 $11 = tempRet0;
 $12 = $10&255;
 $13 = $1&255;
 $14 = (_bitshift64Lshr(($1|0),($2|0),8)|0);
 $15 = tempRet0;
 $16 = $14&255;
 $17 = (_bitshift64Lshr(($1|0),($2|0),16)|0);
 $18 = tempRet0;
 $19 = $17&255;
 $20 = (_bitshift64Lshr(($1|0),($2|0),24)|0);
 $21 = tempRet0;
 $22 = $20&255;
 __THREW__ = 0;
 (invoke_ii(2996,(2564344|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 do {
  if (!($24)) {
   $25 = HEAP8[((2564344 + 116|0))>>0]|0;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2564344|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2564344|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2564344|0))|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    $37 = HEAP32[((2564344 + 80|0))>>2]|0;
    $38 = HEAP8[$37>>0]|0;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     __THREW__ = 0;
     $153 = (invoke_iiii(964,0,($0|0),8)|0);
     $154 = __THREW__; __THREW__ = 0;
     $155 = $154&1;
     if ($155) {
      break;
     } else {
      $$0 = $153;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1203320|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if (!($41)) {
     __THREW__ = 0;
     $42 = (invoke_iii(2768,(1203320|0),8)|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      __THREW__ = 0;
      invoke_vi(3799,($42|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       $47 = (($42) + 12|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ($48|0)==(0);
       if ($49) {
        __THREW__ = 0;
        $50 = (invoke_i(132)|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($50|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
       }
       $55 = (($42) + 16|0);
       HEAP8[$55>>0] = $3;
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if (!($57)) {
        $58 = HEAP32[$47>>2]|0;
        $59 = ($58>>>0)<(2);
        if ($59) {
         __THREW__ = 0;
         $60 = (invoke_i(132)|0);
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($60|0));
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break;
         }
        }
        $65 = HEAP32[$42>>2]|0;
        $66 = (($65) + 92|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = (($55) + ($67)|0);
        HEAP8[$68>>0] = $6;
        __THREW__ = 0;
        invoke_vi(3799,($42|0));
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if (!($70)) {
         $71 = HEAP32[$47>>2]|0;
         $72 = ($71>>>0)<(3);
         if ($72) {
          __THREW__ = 0;
          $73 = (invoke_i(132)|0);
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($73|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break;
          }
         }
         $78 = HEAP32[$42>>2]|0;
         $79 = (($78) + 92|0);
         $80 = HEAP32[$79>>2]|0;
         $81 = $80 << 1;
         $82 = (($55) + ($81)|0);
         HEAP8[$82>>0] = $9;
         __THREW__ = 0;
         invoke_vi(3799,($42|0));
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if (!($84)) {
          $85 = HEAP32[$47>>2]|0;
          $86 = ($85>>>0)<(4);
          if ($86) {
           __THREW__ = 0;
           $87 = (invoke_i(132)|0);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($87|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            break;
           }
          }
          $92 = HEAP32[$42>>2]|0;
          $93 = (($92) + 92|0);
          $94 = HEAP32[$93>>2]|0;
          $95 = ($94*3)|0;
          $96 = (($55) + ($95)|0);
          HEAP8[$96>>0] = $12;
          __THREW__ = 0;
          invoke_vi(3799,($42|0));
          $97 = __THREW__; __THREW__ = 0;
          $98 = $97&1;
          if (!($98)) {
           $99 = HEAP32[$47>>2]|0;
           $100 = ($99>>>0)<(5);
           if ($100) {
            __THREW__ = 0;
            $101 = (invoke_i(132)|0);
            $102 = __THREW__; __THREW__ = 0;
            $103 = $102&1;
            if ($103) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($101|0));
            $104 = __THREW__; __THREW__ = 0;
            $105 = $104&1;
            if ($105) {
             break;
            }
           }
           $106 = HEAP32[$42>>2]|0;
           $107 = (($106) + 92|0);
           $108 = HEAP32[$107>>2]|0;
           $109 = $108 << 2;
           $110 = (($55) + ($109)|0);
           HEAP8[$110>>0] = $13;
           __THREW__ = 0;
           invoke_vi(3799,($42|0));
           $111 = __THREW__; __THREW__ = 0;
           $112 = $111&1;
           if (!($112)) {
            $113 = HEAP32[$47>>2]|0;
            $114 = ($113>>>0)<(6);
            if ($114) {
             __THREW__ = 0;
             $115 = (invoke_i(132)|0);
             $116 = __THREW__; __THREW__ = 0;
             $117 = $116&1;
             if ($117) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($115|0));
             $118 = __THREW__; __THREW__ = 0;
             $119 = $118&1;
             if ($119) {
              break;
             }
            }
            $120 = HEAP32[$42>>2]|0;
            $121 = (($120) + 92|0);
            $122 = HEAP32[$121>>2]|0;
            $123 = ($122*5)|0;
            $124 = (($55) + ($123)|0);
            HEAP8[$124>>0] = $16;
            __THREW__ = 0;
            invoke_vi(3799,($42|0));
            $125 = __THREW__; __THREW__ = 0;
            $126 = $125&1;
            if (!($126)) {
             $127 = HEAP32[$47>>2]|0;
             $128 = ($127>>>0)<(7);
             if ($128) {
              __THREW__ = 0;
              $129 = (invoke_i(132)|0);
              $130 = __THREW__; __THREW__ = 0;
              $131 = $130&1;
              if ($131) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($129|0));
              $132 = __THREW__; __THREW__ = 0;
              $133 = $132&1;
              if ($133) {
               break;
              }
             }
             $134 = HEAP32[$42>>2]|0;
             $135 = (($134) + 92|0);
             $136 = HEAP32[$135>>2]|0;
             $137 = ($136*6)|0;
             $138 = (($55) + ($137)|0);
             HEAP8[$138>>0] = $19;
             __THREW__ = 0;
             invoke_vi(3799,($42|0));
             $139 = __THREW__; __THREW__ = 0;
             $140 = $139&1;
             if ($140) {
              break;
             }
             $141 = HEAP32[$47>>2]|0;
             $142 = ($141>>>0)<(8);
             if ($142) {
              __THREW__ = 0;
              $143 = (invoke_i(132)|0);
              $144 = __THREW__; __THREW__ = 0;
              $145 = $144&1;
              if ($145) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($143|0));
              $146 = __THREW__; __THREW__ = 0;
              $147 = $146&1;
              if ($147) {
               break;
              }
             }
             $148 = HEAP32[$42>>2]|0;
             $149 = (($148) + 92|0);
             $150 = HEAP32[$149>>2]|0;
             $151 = ($150*7)|0;
             $152 = (($55) + ($151)|0);
             HEAP8[$152>>0] = $22;
             $$0 = $42;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $33 = ___cxa_find_matching_catch()|0;
 $34 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($33|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_BitConverter_m_ToInt64P22mscorlib_System_ObjectP24mscorlib_System_Byte_arri($__this,$value,$startIndex) {
 $__this = $__this|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2563896);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viiiii(72,0,($V_0|0),($value|0),($startIndex|0),8);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $6 = $V_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $11;
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z120mscorlib_System_BitConverter_m_GetBytes_mscorlib_System_Byte_arr_arr_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P22mscorlib_System_ObjectPhi($__this,$ptr,$count) {
 $__this = $__this|0;
 $ptr = $ptr|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2563752);
 __THREW__ = 0;
 (invoke_ii(2996,(1203320|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2768,(1203320|0),($count|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($count|0)>(0);
   if (!($5)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
   $6 = (($2) + 16|0);
   $7 = (($2) + 12|0);
   $V_1$01 = 0;
   while(1) {
    $27 = (($ptr) + ($V_1$01)|0);
    $24 = HEAP8[$27>>0]|0;
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    $12 = HEAP32[$7>>2]|0;
    $13 = ($V_1$01>>>0)<($12>>>0);
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_i(132)|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($14|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
    }
    $19 = HEAP32[$2>>2]|0;
    $20 = (($19) + 92|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = Math_imul($21, $V_1$01)|0;
    $23 = (($6) + ($22)|0);
    HEAP8[$23>>0] = $24;
    $25 = (($V_1$01) + 1)|0;
    $26 = ($25|0)<($count|0);
    if ($26) {
     $V_1$01 = $25;
    } else {
     label = 13;
     break;
    }
   }
   if ((label|0) == 13) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($2|0);
   }
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   $lpad$phi$index = $8;$lpad$phi$index2 = $9;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_BitConverter_m_PutBytesP22mscorlib_System_ObjectPhP24mscorlib_System_Byte_arrii($__this,$dst,$src,$start_index,$count) {
 $__this = $__this|0;
 $dst = $dst|0;
 $src = $src|0;
 $start_index = $start_index|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $V_0$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2563848);
 __THREW__ = 0;
 invoke_v(773);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($src|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3060768>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($start_index|0)<(0);
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3799,($src|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = (($src) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)>($start_index|0);
    if ($22) {
     __THREW__ = 0;
     invoke_vi(3799,($src|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     $36 = HEAP32[$20>>2]|0;
     $37 = (($36) - ($count))|0;
     $38 = ($37|0)<($start_index|0);
     if ($38) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      __THREW__ = 0;
      $43 = (invoke_ii(3469,(2560072|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break;
      }
      $46 = HEAP32[3060792>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($43|0),($46|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3838,($43|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      // unreachable;
     }
     $39 = ($count|0)>(0);
     if (!($39)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $40 = (($src) + 16|0);
     $V_0$05 = 0;
     while(1) {
      $66 = (($dst) + ($V_0$05)|0);
      $52 = (($V_0$05) + ($start_index))|0;
      __THREW__ = 0;
      invoke_vi(3799,($src|0));
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       break;
      }
      $51 = ($52|0)<(0);
      if ($51) {
       label = 30;
      } else {
       $53 = HEAP32[$20>>2]|0;
       $54 = ($52>>>0)<($53>>>0);
       if (!($54)) {
        label = 30;
       }
      }
      if ((label|0) == 30) {
       label = 0;
       __THREW__ = 0;
       $55 = (invoke_i(132)|0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($55|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break;
       }
      }
      $60 = HEAP32[$src>>2]|0;
      $61 = (($60) + 92|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = Math_imul($62, $52)|0;
      $64 = (($40) + ($63)|0);
      $65 = HEAP8[$64>>0]|0;
      HEAP8[$66>>0] = $65;
      $67 = (($V_0$05) + 1)|0;
      $68 = ($67|0)<($count|0);
      if ($68) {
       $V_0$05 = $67;
      } else {
       label = 34;
       break;
      }
     }
     if ((label|0) == 34) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $3 = ___cxa_find_matching_catch()|0;
     $4 = tempRet0;
     $lpad$phi$index = $3;$lpad$phi$index2 = $4;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    $25 = (invoke_ii(3469,(2561352|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = HEAP32[3060776>>2]|0;
     $29 = HEAP32[3060784>>2]|0;
     __THREW__ = 0;
     invoke_viii(644,($25|0),($28|0),($29|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if (!($31)) {
      __THREW__ = 0;
      invoke_vi(3838,($25|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_DoubleTraitsE6InvokeEPFxPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I17VoidPointerTraits28mscorlib_System_DoubleTraitsE6InvokeEPFPvS3_dES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int64Traits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFxPvS4_iES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$3)|0);
 $5 = tempRet0;
 $6 = $ret;
 $7 = $6;
 HEAP32[$7>>2] = $4;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __Z35mscorlib_System_Buffer_m_ByteLengthP22mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2564480);
 __THREW__ = 0;
 invoke_v(774);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3061200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_iii(1006,0,($_____array|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)>(-1);
    if ($18) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($15|0);
    }
    $19 = HEAP32[3061208>>2]|0;
    __THREW__ = 0;
    $20 = (invoke_iii(783,(0|0),($19|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      __THREW__ = 0;
      $25 = (invoke_ii(3469,(2560072|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       invoke_vii(1924,($25|0),($20|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3838,($25|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Buffer_m_ByteLengthInternalP22mscorlib_System_ObjectP21mscorlib_System_Array($__this,$_____array) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2564576);
 $0 = HEAP32[2564624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2564632|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2564624>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($_____array|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_Buffer_m_BlockCopyP22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii($__this,$src,$srcOffset,$dst,$dstOffset,$count) {
 $__this = $__this|0;
 $src = $src|0;
 $srcOffset = $srcOffset|0;
 $dst = $dst|0;
 $dstOffset = $dstOffset|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2564528);
 __THREW__ = 0;
 invoke_v(775);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($src|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3061304>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($dst|0)==(0|0);
   if ($15) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2560584|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[3061312>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($18|0),($21|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($18|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    // unreachable;
   }
   $26 = ($srcOffset|0)>(-1);
   if (!($26)) {
    $27 = HEAP32[3061328>>2]|0;
    __THREW__ = 0;
    $28 = (invoke_iii(783,(0|0),($27|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __THREW__ = 0;
    $33 = (invoke_ii(3469,(2561352|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = HEAP32[3061320>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($33|0),($36|0),($28|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($33|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    // unreachable;
   }
   $41 = ($dstOffset|0)>(-1);
   if (!($41)) {
    $42 = HEAP32[3061344>>2]|0;
    __THREW__ = 0;
    $43 = (invoke_iii(783,(0|0),($42|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    __THREW__ = 0;
    $48 = (invoke_ii(3469,(2561352|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    $51 = HEAP32[3061336>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($48|0),($51|0),($43|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($48|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     break;
    }
    // unreachable;
   }
   $56 = ($count|0)>(-1);
   if (!($56)) {
    $57 = HEAP32[3061360>>2]|0;
    __THREW__ = 0;
    $58 = (invoke_iii(783,(0|0),($57|0))|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     break;
    }
    __THREW__ = 0;
    $63 = (invoke_ii(3469,(2561352|0))|0);
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     break;
    }
    $66 = HEAP32[3061352>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($63|0),($66|0),($58|0));
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($63|0));
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $71 = (invoke_iiiiiii(90,0,($src|0),($srcOffset|0),($dst|0),($dstOffset|0),($count|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if (!($73)) {
    if ($71) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    $74 = (invoke_iii(1005,0,($src|0))|0);
    $75 = __THREW__; __THREW__ = 0;
    $76 = $75&1;
    if (!($76)) {
     $77 = (($74) - ($count))|0;
     $78 = ($77|0)<($srcOffset|0);
     if (!($78)) {
      __THREW__ = 0;
      $79 = (invoke_iii(1005,0,($dst|0))|0);
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       break;
      }
      $82 = (($79) - ($count))|0;
      $83 = ($82|0)<($dstOffset|0);
      if (!($83)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
     $84 = HEAP32[3061368>>2]|0;
     __THREW__ = 0;
     $85 = (invoke_iii(783,(0|0),($84|0))|0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if (!($87)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if (!($89)) {
       __THREW__ = 0;
       $90 = (invoke_ii(3469,(2560072|0))|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if (!($92)) {
        __THREW__ = 0;
        invoke_vii(1924,($90|0),($85|0));
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if (!($94)) {
         __THREW__ = 0;
         invoke_vi(3838,($90|0));
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if (!($96)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z42mscorlib_System_Buffer_m_BlockCopyInternalP22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii($__this,$src,$src_offset,$dest,$dest_offset,$count) {
 $__this = $__this|0;
 $src = $src|0;
 $src_offset = $src_offset|0;
 $dest = $dest|0;
 $dest_offset = $dest_offset|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2564680);
 $0 = HEAP32[2564728>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2564736|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2564728>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiiii($7|0,($src|0),($src_offset|0),($dest|0),($dest_offset|0),($count|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_Buffer_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z38mscorlib_System_CharEnumerator_m__ctorP30mscorlib_System_CharEnumeratorP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2565288);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $s;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = -1;
  __THREW__ = 0;
  invoke_vi(3799,($s|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1816,($s|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = (($__this) + 16|0);
    HEAP32[$9>>2] = $6;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z75mscorlib_System_CharEnumerator_m_System_Collections_IEnumerator_get_CurrentP30mscorlib_System_CharEnumerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2565336);
 __THREW__ = 0;
 $0 = (invoke_iii(2767,(2565384|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP16[$L_1>>1] = $0;
  __THREW__ = 0;
  (invoke_ii(2996,(2180696|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2724,(2180696|0),($L_1|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_CharEnumerator_m_System_IDisposable_DisposeP30mscorlib_System_CharEnumerator($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2565432);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z44mscorlib_System_CharEnumerator_m_get_CurrentP30mscorlib_System_CharEnumerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2565384);
 __THREW__ = 0;
 invoke_v(776);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(-1);
   if (!($4)) {
    $7 = (($__this) + 16|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($3|0)<($8|0);
    if ($9) {
     $23 = (($__this) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     $27 = (invoke_iii(621,($24|0),($3|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($27|0);
    }
   }
   $10 = HEAP32[3061744>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iii(783,(0|0),($10|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607872|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2607872|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      invoke_vii(1947,($16|0),($11|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       invoke_vi(3838,($16|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_InvalidOperationException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP41mscorlib_System_InvalidOperationExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2607568);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233079);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z41mscorlib_System_CharEnumerator_m_MoveNextP30mscorlib_System_CharEnumerator($__this) {
 $__this = $__this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2565480);
 __THREW__ = 0;
 invoke_vi(3799,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + 1)|0;
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 16|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($4|0)<($8|0);
   $$ = $9 ? $4 : $8;
   HEAP32[$2>>2] = $$;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($9|0);
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_CharEnumerator_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z65mscorlib_System_ContextBoundObject_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z32mscorlib_System_Convert_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy16 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0;
 var $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0;
 var $367 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy16 = sp + 72|0;
 $_stackTraceSentry = sp + 68|0;
 $0 = sp + 64|0;
 $1 = sp + 60|0;
 $2 = sp + 56|0;
 $3 = sp + 52|0;
 $4 = sp + 48|0;
 $5 = sp + 44|0;
 $6 = sp + 40|0;
 $7 = sp + 36|0;
 $8 = sp + 12|0;
 $9 = sp;
 $10 = sp + 4|0;
 $11 = sp + 8|0;
 $12 = sp + 16|0;
 $13 = sp + 20|0;
 $14 = sp + 24|0;
 $15 = sp + 28|0;
 $16 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566256);
 __THREW__ = 0;
 (invoke_ii(2996,(2583848|0))|0);
 $17 = __THREW__; __THREW__ = 0;
 $18 = $17&1;
 do {
  if (!($18)) {
   $19 = HEAP8[((2583848 + 116|0))>>0]|0;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    __THREW__ = 0;
    (invoke_ii(2996,(2583848|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2583848|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2583848|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2583848|0))|0);
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    $31 = HEAP32[((2583848 + 80|0))>>2]|0;
    $32 = HEAP32[$31>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2581704|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = HEAP32[((2581704 + 80|0))>>2]|0;
     HEAP32[$35>>2] = $32;
     __THREW__ = 0;
     (invoke_ii(2996,(1169184|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(2768,(1169184|0),19)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       HEAP32[$0>>2] = 1284448;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$0+0>>2]|0;
       $41 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if (!($43)) {
        __THREW__ = 0;
        invoke_vi(3799,($38|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($38) + 12|0);
         $47 = HEAP32[$46>>2]|0;
         $48 = ($47>>>0)<(2);
         if ($48) {
          __THREW__ = 0;
          $49 = (invoke_i(132)|0);
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($49|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($38|0),($41|0));
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if (!($55)) {
          $56 = HEAP32[$38>>2]|0;
          $57 = (($38) + 16|0);
          $58 = (($56) + 92|0);
          $59 = HEAP32[$58>>2]|0;
          $60 = (($57) + ($59)|0);
          HEAP32[$60>>2] = $41;
          HEAP32[$1>>2] = 2642920;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$1+0>>2]|0;
          $61 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if (!($63)) {
           __THREW__ = 0;
           invoke_vi(3799,($38|0));
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if (!($65)) {
            $66 = HEAP32[$46>>2]|0;
            $67 = ($66>>>0)<(3);
            if ($67) {
             __THREW__ = 0;
             $68 = (invoke_i(132)|0);
             $69 = __THREW__; __THREW__ = 0;
             $70 = $69&1;
             if ($70) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($68|0));
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if ($72) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($38|0),($61|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if (!($74)) {
             $75 = HEAP32[$38>>2]|0;
             $76 = (($75) + 92|0);
             $77 = HEAP32[$76>>2]|0;
             $78 = $77 << 1;
             $79 = (($57) + ($78)|0);
             HEAP32[$79>>2] = $61;
             HEAP32[$2>>2] = 1284952;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$2+0>>2]|0;
             $80 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
             $81 = __THREW__; __THREW__ = 0;
             $82 = $81&1;
             if (!($82)) {
              __THREW__ = 0;
              invoke_vi(3799,($38|0));
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if (!($84)) {
               $85 = HEAP32[$46>>2]|0;
               $86 = ($85>>>0)<(4);
               if ($86) {
                __THREW__ = 0;
                $87 = (invoke_i(132)|0);
                $88 = __THREW__; __THREW__ = 0;
                $89 = $88&1;
                if ($89) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($87|0));
                $90 = __THREW__; __THREW__ = 0;
                $91 = $90&1;
                if ($91) {
                 break;
                }
               }
               __THREW__ = 0;
               invoke_vii(3492,($38|0),($80|0));
               $92 = __THREW__; __THREW__ = 0;
               $93 = $92&1;
               if (!($93)) {
                $94 = HEAP32[$38>>2]|0;
                $95 = (($94) + 92|0);
                $96 = HEAP32[$95>>2]|0;
                $97 = ($96*3)|0;
                $98 = (($57) + ($97)|0);
                HEAP32[$98>>2] = $80;
                HEAP32[$3>>2] = 1376192;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$3+0>>2]|0;
                $99 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if (!($101)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $102 = __THREW__; __THREW__ = 0;
                 $103 = $102&1;
                 if ($103) {
                  break;
                 }
                 $104 = HEAP32[$46>>2]|0;
                 $105 = ($104>>>0)<(5);
                 if ($105) {
                  __THREW__ = 0;
                  $106 = (invoke_i(132)|0);
                  $107 = __THREW__; __THREW__ = 0;
                  $108 = $107&1;
                  if ($108) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($106|0));
                  $109 = __THREW__; __THREW__ = 0;
                  $110 = $109&1;
                  if ($110) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($99|0));
                 $111 = __THREW__; __THREW__ = 0;
                 $112 = $111&1;
                 if ($112) {
                  break;
                 }
                 $113 = HEAP32[$38>>2]|0;
                 $114 = (($113) + 92|0);
                 $115 = HEAP32[$114>>2]|0;
                 $116 = $115 << 2;
                 $117 = (($57) + ($116)|0);
                 HEAP32[$117>>2] = $99;
                 HEAP32[$4>>2] = 1691448;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$4+0>>2]|0;
                 $118 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $119 = __THREW__; __THREW__ = 0;
                 $120 = $119&1;
                 if ($120) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  break;
                 }
                 $123 = HEAP32[$46>>2]|0;
                 $124 = ($123>>>0)<(6);
                 if ($124) {
                  __THREW__ = 0;
                  $125 = (invoke_i(132)|0);
                  $126 = __THREW__; __THREW__ = 0;
                  $127 = $126&1;
                  if ($127) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($125|0));
                  $128 = __THREW__; __THREW__ = 0;
                  $129 = $128&1;
                  if ($129) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($118|0));
                 $130 = __THREW__; __THREW__ = 0;
                 $131 = $130&1;
                 if ($131) {
                  break;
                 }
                 $132 = HEAP32[$38>>2]|0;
                 $133 = (($132) + 92|0);
                 $134 = HEAP32[$133>>2]|0;
                 $135 = ($134*5)|0;
                 $136 = (($57) + ($135)|0);
                 HEAP32[$136>>2] = $118;
                 HEAP32[$5>>2] = 1998712;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$5+0>>2]|0;
                 $137 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $138 = __THREW__; __THREW__ = 0;
                 $139 = $138&1;
                 if ($139) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $140 = __THREW__; __THREW__ = 0;
                 $141 = $140&1;
                 if ($141) {
                  break;
                 }
                 $142 = HEAP32[$46>>2]|0;
                 $143 = ($142>>>0)<(7);
                 if ($143) {
                  __THREW__ = 0;
                  $144 = (invoke_i(132)|0);
                  $145 = __THREW__; __THREW__ = 0;
                  $146 = $145&1;
                  if ($146) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($144|0));
                  $147 = __THREW__; __THREW__ = 0;
                  $148 = $147&1;
                  if ($148) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($137|0));
                 $149 = __THREW__; __THREW__ = 0;
                 $150 = $149&1;
                 if ($150) {
                  break;
                 }
                 $151 = HEAP32[$38>>2]|0;
                 $152 = (($151) + 92|0);
                 $153 = HEAP32[$152>>2]|0;
                 $154 = ($153*6)|0;
                 $155 = (($57) + ($154)|0);
                 HEAP32[$155>>2] = $137;
                 HEAP32[$6>>2] = 1691416;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$6+0>>2]|0;
                 $156 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $157 = __THREW__; __THREW__ = 0;
                 $158 = $157&1;
                 if ($158) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $159 = __THREW__; __THREW__ = 0;
                 $160 = $159&1;
                 if ($160) {
                  break;
                 }
                 $161 = HEAP32[$46>>2]|0;
                 $162 = ($161>>>0)<(8);
                 if ($162) {
                  __THREW__ = 0;
                  $163 = (invoke_i(132)|0);
                  $164 = __THREW__; __THREW__ = 0;
                  $165 = $164&1;
                  if ($165) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($163|0));
                  $166 = __THREW__; __THREW__ = 0;
                  $167 = $166&1;
                  if ($167) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($156|0));
                 $168 = __THREW__; __THREW__ = 0;
                 $169 = $168&1;
                 if ($169) {
                  break;
                 }
                 $170 = HEAP32[$38>>2]|0;
                 $171 = (($170) + 92|0);
                 $172 = HEAP32[$171>>2]|0;
                 $173 = ($172*7)|0;
                 $174 = (($57) + ($173)|0);
                 HEAP32[$174>>2] = $156;
                 HEAP32[$7>>2] = 2094224;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$7+0>>2]|0;
                 $175 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $176 = __THREW__; __THREW__ = 0;
                 $177 = $176&1;
                 if ($177) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $178 = __THREW__; __THREW__ = 0;
                 $179 = $178&1;
                 if ($179) {
                  break;
                 }
                 $180 = HEAP32[$46>>2]|0;
                 $181 = ($180>>>0)<(9);
                 if ($181) {
                  __THREW__ = 0;
                  $182 = (invoke_i(132)|0);
                  $183 = __THREW__; __THREW__ = 0;
                  $184 = $183&1;
                  if ($184) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($182|0));
                  $185 = __THREW__; __THREW__ = 0;
                  $186 = $185&1;
                  if ($186) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($175|0));
                 $187 = __THREW__; __THREW__ = 0;
                 $188 = $187&1;
                 if ($188) {
                  break;
                 }
                 $189 = HEAP32[$38>>2]|0;
                 $190 = (($189) + 92|0);
                 $191 = HEAP32[$190>>2]|0;
                 $192 = $191 << 3;
                 $193 = (($57) + ($192)|0);
                 HEAP32[$193>>2] = $175;
                 HEAP32[$8>>2] = 1285000;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$8+0>>2]|0;
                 $194 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $195 = __THREW__; __THREW__ = 0;
                 $196 = $195&1;
                 if ($196) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $197 = __THREW__; __THREW__ = 0;
                 $198 = $197&1;
                 if ($198) {
                  break;
                 }
                 $199 = HEAP32[$46>>2]|0;
                 $200 = ($199>>>0)<(10);
                 if ($200) {
                  __THREW__ = 0;
                  $201 = (invoke_i(132)|0);
                  $202 = __THREW__; __THREW__ = 0;
                  $203 = $202&1;
                  if ($203) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($201|0));
                  $204 = __THREW__; __THREW__ = 0;
                  $205 = $204&1;
                  if ($205) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($194|0));
                 $206 = __THREW__; __THREW__ = 0;
                 $207 = $206&1;
                 if ($207) {
                  break;
                 }
                 $208 = HEAP32[$38>>2]|0;
                 $209 = (($208) + 92|0);
                 $210 = HEAP32[$209>>2]|0;
                 $211 = ($210*9)|0;
                 $212 = (($57) + ($211)|0);
                 HEAP32[$212>>2] = $194;
                 HEAP32[$9>>2] = 1285128;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$9+0>>2]|0;
                 $213 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $214 = __THREW__; __THREW__ = 0;
                 $215 = $214&1;
                 if ($215) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $216 = __THREW__; __THREW__ = 0;
                 $217 = $216&1;
                 if ($217) {
                  break;
                 }
                 $218 = HEAP32[$46>>2]|0;
                 $219 = ($218>>>0)<(11);
                 if ($219) {
                  __THREW__ = 0;
                  $220 = (invoke_i(132)|0);
                  $221 = __THREW__; __THREW__ = 0;
                  $222 = $221&1;
                  if ($222) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($220|0));
                  $223 = __THREW__; __THREW__ = 0;
                  $224 = $223&1;
                  if ($224) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($213|0));
                 $225 = __THREW__; __THREW__ = 0;
                 $226 = $225&1;
                 if ($226) {
                  break;
                 }
                 $227 = HEAP32[$38>>2]|0;
                 $228 = (($227) + 92|0);
                 $229 = HEAP32[$228>>2]|0;
                 $230 = ($229*10)|0;
                 $231 = (($57) + ($230)|0);
                 HEAP32[$231>>2] = $213;
                 HEAP32[$10>>2] = 1691360;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$10+0>>2]|0;
                 $232 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $233 = __THREW__; __THREW__ = 0;
                 $234 = $233&1;
                 if ($234) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $235 = __THREW__; __THREW__ = 0;
                 $236 = $235&1;
                 if ($236) {
                  break;
                 }
                 $237 = HEAP32[$46>>2]|0;
                 $238 = ($237>>>0)<(12);
                 if ($238) {
                  __THREW__ = 0;
                  $239 = (invoke_i(132)|0);
                  $240 = __THREW__; __THREW__ = 0;
                  $241 = $240&1;
                  if ($241) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($239|0));
                  $242 = __THREW__; __THREW__ = 0;
                  $243 = $242&1;
                  if ($243) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($232|0));
                 $244 = __THREW__; __THREW__ = 0;
                 $245 = $244&1;
                 if ($245) {
                  break;
                 }
                 $246 = HEAP32[$38>>2]|0;
                 $247 = (($246) + 92|0);
                 $248 = HEAP32[$247>>2]|0;
                 $249 = ($248*11)|0;
                 $250 = (($57) + ($249)|0);
                 HEAP32[$250>>2] = $232;
                 HEAP32[$11>>2] = 2045848;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$11+0>>2]|0;
                 $251 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $252 = __THREW__; __THREW__ = 0;
                 $253 = $252&1;
                 if ($253) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $254 = __THREW__; __THREW__ = 0;
                 $255 = $254&1;
                 if ($255) {
                  break;
                 }
                 $256 = HEAP32[$46>>2]|0;
                 $257 = ($256>>>0)<(13);
                 if ($257) {
                  __THREW__ = 0;
                  $258 = (invoke_i(132)|0);
                  $259 = __THREW__; __THREW__ = 0;
                  $260 = $259&1;
                  if ($260) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($258|0));
                  $261 = __THREW__; __THREW__ = 0;
                  $262 = $261&1;
                  if ($262) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($251|0));
                 $263 = __THREW__; __THREW__ = 0;
                 $264 = $263&1;
                 if ($264) {
                  break;
                 }
                 $265 = HEAP32[$38>>2]|0;
                 $266 = (($265) + 92|0);
                 $267 = HEAP32[$266>>2]|0;
                 $268 = ($267*12)|0;
                 $269 = (($57) + ($268)|0);
                 HEAP32[$269>>2] = $251;
                 HEAP32[$12>>2] = 1285152;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$12+0>>2]|0;
                 $270 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $271 = __THREW__; __THREW__ = 0;
                 $272 = $271&1;
                 if ($272) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $273 = __THREW__; __THREW__ = 0;
                 $274 = $273&1;
                 if ($274) {
                  break;
                 }
                 $275 = HEAP32[$46>>2]|0;
                 $276 = ($275>>>0)<(14);
                 if ($276) {
                  __THREW__ = 0;
                  $277 = (invoke_i(132)|0);
                  $278 = __THREW__; __THREW__ = 0;
                  $279 = $278&1;
                  if ($279) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($277|0));
                  $280 = __THREW__; __THREW__ = 0;
                  $281 = $280&1;
                  if ($281) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($270|0));
                 $282 = __THREW__; __THREW__ = 0;
                 $283 = $282&1;
                 if ($283) {
                  break;
                 }
                 $284 = HEAP32[$38>>2]|0;
                 $285 = (($284) + 92|0);
                 $286 = HEAP32[$285>>2]|0;
                 $287 = ($286*13)|0;
                 $288 = (($57) + ($287)|0);
                 HEAP32[$288>>2] = $270;
                 HEAP32[$13>>2] = 2095368;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$13+0>>2]|0;
                 $289 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $290 = __THREW__; __THREW__ = 0;
                 $291 = $290&1;
                 if ($291) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $292 = __THREW__; __THREW__ = 0;
                 $293 = $292&1;
                 if ($293) {
                  break;
                 }
                 $294 = HEAP32[$46>>2]|0;
                 $295 = ($294>>>0)<(15);
                 if ($295) {
                  __THREW__ = 0;
                  $296 = (invoke_i(132)|0);
                  $297 = __THREW__; __THREW__ = 0;
                  $298 = $297&1;
                  if ($298) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($296|0));
                  $299 = __THREW__; __THREW__ = 0;
                  $300 = $299&1;
                  if ($300) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($289|0));
                 $301 = __THREW__; __THREW__ = 0;
                 $302 = $301&1;
                 if ($302) {
                  break;
                 }
                 $303 = HEAP32[$38>>2]|0;
                 $304 = (($303) + 92|0);
                 $305 = HEAP32[$304>>2]|0;
                 $306 = ($305*14)|0;
                 $307 = (($57) + ($306)|0);
                 HEAP32[$307>>2] = $289;
                 HEAP32[$14>>2] = 2095312;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$14+0>>2]|0;
                 $308 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $309 = __THREW__; __THREW__ = 0;
                 $310 = $309&1;
                 if ($310) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $311 = __THREW__; __THREW__ = 0;
                 $312 = $311&1;
                 if ($312) {
                  break;
                 }
                 $313 = HEAP32[$46>>2]|0;
                 $314 = ($313>>>0)<(16);
                 if ($314) {
                  __THREW__ = 0;
                  $315 = (invoke_i(132)|0);
                  $316 = __THREW__; __THREW__ = 0;
                  $317 = $316&1;
                  if ($317) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($315|0));
                  $318 = __THREW__; __THREW__ = 0;
                  $319 = $318&1;
                  if ($319) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($308|0));
                 $320 = __THREW__; __THREW__ = 0;
                 $321 = $320&1;
                 if ($321) {
                  break;
                 }
                 $322 = HEAP32[$38>>2]|0;
                 $323 = (($322) + 92|0);
                 $324 = HEAP32[$323>>2]|0;
                 $325 = ($324*15)|0;
                 $326 = (($57) + ($325)|0);
                 HEAP32[$326>>2] = $308;
                 HEAP32[$15>>2] = 1692712;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$15+0>>2]|0;
                 $327 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $328 = __THREW__; __THREW__ = 0;
                 $329 = $328&1;
                 if ($329) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $330 = __THREW__; __THREW__ = 0;
                 $331 = $330&1;
                 if ($331) {
                  break;
                 }
                 $332 = HEAP32[$46>>2]|0;
                 $333 = ($332>>>0)<(17);
                 if ($333) {
                  __THREW__ = 0;
                  $334 = (invoke_i(132)|0);
                  $335 = __THREW__; __THREW__ = 0;
                  $336 = $335&1;
                  if ($336) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($334|0));
                  $337 = __THREW__; __THREW__ = 0;
                  $338 = $337&1;
                  if ($338) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($327|0));
                 $339 = __THREW__; __THREW__ = 0;
                 $340 = $339&1;
                 if ($340) {
                  break;
                 }
                 $341 = HEAP32[$38>>2]|0;
                 $342 = (($341) + 92|0);
                 $343 = HEAP32[$342>>2]|0;
                 $$sum = (($343) + 1)|0;
                 $344 = (($38) + ($$sum<<4)|0);
                 HEAP32[$344>>2] = $327;
                 HEAP32[$16>>2] = 1284472;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy16+0>>2]=HEAP32[$16+0>>2]|0;
                 $345 = (invoke_iii(772,(0|0),($$byval_copy16|0))|0);
                 $346 = __THREW__; __THREW__ = 0;
                 $347 = $346&1;
                 if ($347) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($38|0));
                 $348 = __THREW__; __THREW__ = 0;
                 $349 = $348&1;
                 if ($349) {
                  break;
                 }
                 $350 = HEAP32[$46>>2]|0;
                 $351 = ($350>>>0)<(19);
                 if ($351) {
                  __THREW__ = 0;
                  $352 = (invoke_i(132)|0);
                  $353 = __THREW__; __THREW__ = 0;
                  $354 = $353&1;
                  if ($354) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($352|0));
                  $355 = __THREW__; __THREW__ = 0;
                  $356 = $355&1;
                  if ($356) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($38|0),($345|0));
                 $357 = __THREW__; __THREW__ = 0;
                 $358 = $357&1;
                 if ($358) {
                  break;
                 }
                 $359 = HEAP32[$38>>2]|0;
                 $360 = (($359) + 92|0);
                 $361 = HEAP32[$360>>2]|0;
                 $362 = ($361*18)|0;
                 $363 = (($57) + ($362)|0);
                 HEAP32[$363>>2] = $345;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2581704|0))|0);
                 $364 = __THREW__; __THREW__ = 0;
                 $365 = $364&1;
                 if ($365) {
                  break;
                 }
                 $366 = HEAP32[((2581704 + 80|0))>>2]|0;
                 $367 = (($366) + 4|0);
                 HEAP32[$367>>2] = $38;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($27|0);
 // unreachable;
}
function __Z80mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566304);
 $0 = ($value<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z83mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_1$byval_copy = sp + 40|0;
 $value$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566352);
 ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(1767,($L_1|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_1$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
 $2 = (invoke_iiii(636,(0|0),($value$byval_copy|0),($L_1$byval_copy|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566400);
 $0 = $value != 0.0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566448);
 $0 = $value != Math_fround(0.0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z81mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566496);
 $0 = ($value|0)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z81mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566544);
 $2 = ($0|0)!=(0);
 $3 = ($1|0)!=(0);
 $4 = $2 | $3;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($4|0);
}
function __Z81mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566592);
 $0 = ($value<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z81mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566640);
 $0 = ($value<<16>>16)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z114mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566688);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iii(711,(0|0),($value|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566736);
 $0 = ($value|0)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566784);
 $2 = ($0|0)!=(0);
 $3 = ($1|0)!=(0);
 $4 = $2 | $3;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($4|0);
}
function __Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566832);
 $0 = ($value<<16>>16)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z114mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566880);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1671,(2156368|0),($3|0),($provider|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I29mscorlib_System_BooleanTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z77mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566928);
 $$ = $value&1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z74mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_CharP22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2566976);
 __THREW__ = 0;
 invoke_v(777);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value&65535)<(256);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3061816>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_OverflowException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_OverflowExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2635632);
 __THREW__ = 0;
 invoke_vii(1927,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233066);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z77mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_4 = 0, $L_8 = 0, $L_8$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_8$byval_copy = sp + 72|0;
 $value$byval_copy1 = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp + 24|0;
 $L_4 = sp + 40|0;
 $L_8 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567024);
 __THREW__ = 0;
 invoke_v(778);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(1767,($L_1|0),255);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
    ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
    $4 = (invoke_iiii(638,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;HEAP32[$L_4+12>>2]=0|0;
      __THREW__ = 0;
      invoke_vii(1767,($L_4|0),0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
      ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_4+12>>2]|0;
      $11 = (invoke_iiii(639,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
       invoke_viii(679,($L_8|0),0,($L_8$byval_copy|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
       $29 = (invoke_iii(689,(0|0),($L_8$byval_copy|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($29|0);
      }
     }
     $14 = HEAP32[3061904>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2635888|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vii(1971,($20|0),($15|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3838,($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Math_m_Round_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($agg$result,$__this,$d) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d = $d|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0;
 var $L_1 = 0, $L_14 = 0, $L_20 = 0, $L_21 = 0, $L_27 = 0, $L_28 = 0, $L_29 = 0, $L_30 = 0, $L_31 = 0, $L_33 = 0, $L_40 = 0, $L_42 = 0, $L_7 = 0, $V_1 = 0, $V_1$byval_copy3 = 0, $_stackTraceSentry = 0, $agg$result$byval_copy4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $agg$result$byval_copy4 = sp + 264|0;
 $V_1$byval_copy3 = sp + 248|0;
 $_stackTraceSentry = sp + 240|0;
 $V_1 = sp + 224|0;
 $L_0 = sp + 208|0;
 $L_1 = sp + 192|0;
 $L_7 = sp + 176|0;
 $L_14 = sp + 160|0;
 $L_20 = sp + 144|0;
 $L_21 = sp + 128|0;
 $L_27 = sp + 96|0;
 $L_28 = sp + 80|0;
 $L_29 = sp + 64|0;
 $L_30 = sp + 48|0;
 $L_31 = sp + 32|0;
 $L_33 = sp + 16|0;
 $L_40 = sp;
 $L_42 = sp + 112|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2609024);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;
 __THREW__ = 0;
 ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$d+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$d+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$d+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$d+12>>2]|0;
 invoke_viii(510,($L_0|0),(0|0),($agg$result$byval_copy4|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$agg$result+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_0+12>>2]|0;
   __THREW__ = 0;
   ;HEAP32[$V_1$byval_copy3+0>>2]=HEAP32[$d+0>>2]|0;HEAP32[$V_1$byval_copy3+4>>2]=HEAP32[$d+4>>2]|0;HEAP32[$V_1$byval_copy3+8>>2]=HEAP32[$d+8>>2]|0;HEAP32[$V_1$byval_copy3+12>>2]=HEAP32[$d+12>>2]|0;
   ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_0+12>>2]|0;
   invoke_viiii(131,($L_1|0),(0|0),($V_1$byval_copy3|0),($agg$result$byval_copy4|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    ;HEAP32[$V_1+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_1+12>>2]|0;
    ;HEAP32[$L_7+0>>2]=0|0;HEAP32[$L_7+4>>2]=0|0;HEAP32[$L_7+8>>2]=0|0;HEAP32[$L_7+12>>2]=0|0;
    __THREW__ = 0;
    invoke_viiiiii(53,($L_7|0),5,0,0,0,1);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     ;HEAP32[$V_1$byval_copy3+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$V_1$byval_copy3+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$V_1$byval_copy3+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$V_1$byval_copy3+12>>2]=HEAP32[$V_1+12>>2]|0;
     ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_7+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_7+12>>2]|0;
     $6 = (invoke_iiii(637,(0|0),($V_1$byval_copy3|0),($agg$result$byval_copy4|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      if ($6) {
       ;HEAP32[$L_14+0>>2]=0|0;HEAP32[$L_14+4>>2]=0|0;HEAP32[$L_14+8>>2]=0|0;HEAP32[$L_14+12>>2]=0|0;
       __THREW__ = 0;
       invoke_viiiiii(53,($L_14|0),20,0,0,0,1);
       $11 = __THREW__; __THREW__ = 0;
       $12 = $11&1;
       if ($12) {
        break;
       }
       ;HEAP32[$L_20+0>>2]=0|0;HEAP32[$L_20+4>>2]=0|0;HEAP32[$L_20+8>>2]=0|0;HEAP32[$L_20+12>>2]=0|0;
       __THREW__ = 0;
       invoke_viiiiii(53,($L_20|0),20,0,0,0,1);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$V_1$byval_copy3+0>>2]=HEAP32[$agg$result+0>>2]|0;HEAP32[$V_1$byval_copy3+4>>2]=HEAP32[$agg$result+4>>2]|0;HEAP32[$V_1$byval_copy3+8>>2]=HEAP32[$agg$result+8>>2]|0;HEAP32[$V_1$byval_copy3+12>>2]=HEAP32[$agg$result+12>>2]|0;
       ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_20+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_20+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_20+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_20+12>>2]|0;
       invoke_viiii(133,($L_21|0),(0|0),($V_1$byval_copy3|0),($agg$result$byval_copy4|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
       ;HEAP32[$L_27+0>>2]=0|0;HEAP32[$L_27+4>>2]=0|0;HEAP32[$L_27+8>>2]=0|0;HEAP32[$L_27+12>>2]=0|0;
       __THREW__ = 0;
       invoke_viiiiii(53,($L_27|0),20,0,0,0,1);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$V_1$byval_copy3+0>>2]=HEAP32[$agg$result+0>>2]|0;HEAP32[$V_1$byval_copy3+4>>2]=HEAP32[$agg$result+4>>2]|0;HEAP32[$V_1$byval_copy3+8>>2]=HEAP32[$agg$result+8>>2]|0;HEAP32[$V_1$byval_copy3+12>>2]=HEAP32[$agg$result+12>>2]|0;
       ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_27+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_27+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_27+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_27+12>>2]|0;
       invoke_viiii(133,($L_28|0),(0|0),($V_1$byval_copy3|0),($agg$result$byval_copy4|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_28+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_28+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_28+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_28+12>>2]|0;
       invoke_viii(510,($L_29|0),(0|0),($agg$result$byval_copy4|0));
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$V_1$byval_copy3+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$V_1$byval_copy3+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$V_1$byval_copy3+8>>2]=HEAP32[$L_21+8>>2]|0;HEAP32[$V_1$byval_copy3+12>>2]=HEAP32[$L_21+12>>2]|0;
       ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_29+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_29+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_29+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_29+12>>2]|0;
       invoke_viiii(131,($L_30|0),(0|0),($V_1$byval_copy3|0),($agg$result$byval_copy4|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$V_1$byval_copy3+0>>2]=HEAP32[$L_14+0>>2]|0;HEAP32[$V_1$byval_copy3+4>>2]=HEAP32[$L_14+4>>2]|0;HEAP32[$V_1$byval_copy3+8>>2]=HEAP32[$L_14+8>>2]|0;HEAP32[$V_1$byval_copy3+12>>2]=HEAP32[$L_14+12>>2]|0;
       ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_30+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_30+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_30+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_30+12>>2]|0;
       invoke_viiii(132,($L_31|0),(0|0),($V_1$byval_copy3|0),($agg$result$byval_copy4|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       ;HEAP32[$L_33+0>>2]=0|0;HEAP32[$L_33+4>>2]=0|0;HEAP32[$L_33+8>>2]=0|0;HEAP32[$L_33+12>>2]=0|0;
       __THREW__ = 0;
       invoke_vii(1767,($L_33|0),0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$V_1$byval_copy3+0>>2]=HEAP32[$L_31+0>>2]|0;HEAP32[$V_1$byval_copy3+4>>2]=HEAP32[$L_31+4>>2]|0;HEAP32[$V_1$byval_copy3+8>>2]=HEAP32[$L_31+8>>2]|0;HEAP32[$V_1$byval_copy3+12>>2]=HEAP32[$L_31+12>>2]|0;
       ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_33+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_33+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_33+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_33+12>>2]|0;
       $29 = (invoke_iiii(636,(0|0),($V_1$byval_copy3|0),($agg$result$byval_copy4|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       if (!($29)) {
        label = 18;
       }
      } else {
       label = 18;
      }
      if ((label|0) == 18) {
       ;HEAP32[$L_40+0>>2]=0|0;HEAP32[$L_40+4>>2]=0|0;HEAP32[$L_40+8>>2]=0|0;HEAP32[$L_40+12>>2]=0|0;
       __THREW__ = 0;
       invoke_viiiiii(53,($L_40|0),5,0,0,0,1);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$V_1$byval_copy3+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$V_1$byval_copy3+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$V_1$byval_copy3+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$V_1$byval_copy3+12>>2]=HEAP32[$V_1+12>>2]|0;
       ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$L_40+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$L_40+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$L_40+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$L_40+12>>2]|0;
       $34 = (invoke_iiii(638,(0|0),($V_1$byval_copy3|0),($agg$result$byval_copy4|0))|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       if (!($34)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
      __THREW__ = 0;
      ;HEAP32[$agg$result$byval_copy4+0>>2]=HEAP32[$agg$result+0>>2]|0;HEAP32[$agg$result$byval_copy4+4>>2]=HEAP32[$agg$result+4>>2]|0;HEAP32[$agg$result$byval_copy4+8>>2]=HEAP32[$agg$result+8>>2]|0;HEAP32[$agg$result$byval_copy4+12>>2]=HEAP32[$agg$result+12>>2]|0;
      invoke_viii(512,($L_42|0),(0|0),($agg$result$byval_copy4|0));
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if (!($38)) {
       ;HEAP32[$agg$result+0>>2]=HEAP32[$L_42+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_42+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_42+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_42+12>>2]|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567072);
 __THREW__ = 0;
 invoke_v(779);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > 255.0;
   $3 = !($value >= 0.0);
   $or$cond = $2 | $3;
   if ($or$cond) {
    $6 = HEAP32[3062048>>2]|0;
    __THREW__ = 0;
    $7 = (invoke_iii(783,(0|0),($6|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(2635888|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1971,($12|0),($7|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($12|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $19 = (invoke_iid(4,(0|0),(+$value))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    if (!($19)) {
     __THREW__ = 0;
     $22 = (invoke_iid(3,(0|0),(+$value))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     if (!($22)) {
      __THREW__ = 0;
      $38 = (+invoke_did(3,0,(+$value)));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      $41 = (~~(($38))&255);
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($41|0);
     }
    }
    $25 = HEAP32[3062056>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iii(783,(0|0),($25|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2635888|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      $31 = (invoke_ii(3469,(2635888|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_vii(1971,($31|0),($26|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        __THREW__ = 0;
        invoke_vi(3838,($31|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Math_m_Round_mscorlib_System_Double_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$a) {
 $__this = $__this|0;
 $a = +$a;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2609072);
 $0 = HEAP32[2609120>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2609128|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2609120>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (+invoke_dd($7|0,(+$a)));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$8);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return +0;
}
function __Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567120);
 __THREW__ = 0;
 invoke_v(780);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > Math_fround(255.0);
   $3 = !($value >= Math_fround(0.0));
   $or$cond = $2 | $3;
   if ($or$cond) {
    $6 = HEAP32[3062240>>2]|0;
    __THREW__ = 0;
    $7 = (invoke_iii(783,(0|0),($6|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(2635888|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1971,($12|0),($7|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($12|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $19 = (invoke_iif(9,(0|0),(+$value))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    if (!($19)) {
     __THREW__ = 0;
     $22 = (invoke_iif(8,(0|0),(+$value))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     if (!($22)) {
      $38 = +$value;
      __THREW__ = 0;
      $39 = (+invoke_did(3,0,(+$38)));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      $42 = (~~(($39))&255);
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($42|0);
     }
    }
    $25 = HEAP32[3062248>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iii(783,(0|0),($25|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2635888|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      $31 = (invoke_ii(3469,(2635888|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_vii(1971,($31|0),($26|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        __THREW__ = 0;
        invoke_vi(3838,($31|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if (!($37)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567168);
 __THREW__ = 0;
 invoke_v(781);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value>>>0)<(256);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3062560>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567216);
 __THREW__ = 0;
 invoke_v(782);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(256);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $24 = $0&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($24|0);
  }
  $11 = HEAP32[3062576>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567264);
 __THREW__ = 0;
 invoke_v(783);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<24>>24)>(-1);
  if ($2) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3062592>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567312);
 __THREW__ = 0;
 invoke_v(784);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value&65535)<(256);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3062672>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567360);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(489,(0|0),($value|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567408);
 __THREW__ = 0;
 invoke_v(785);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value>>>0)<(256);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3062688>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567456);
 __THREW__ = 0;
 invoke_v(786);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(256);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $24 = $0&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($24|0);
  }
  $11 = HEAP32[3062704>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567504);
 __THREW__ = 0;
 invoke_v(787);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value&65535)<(256);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3062720>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567552);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1672,(2156440|0),($3|0),($provider|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I26mscorlib_System_ByteTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z74mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567600);
 $0 = $value&255;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z75mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567648);
 __THREW__ = 0;
 invoke_v(788);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value>>>0)<(65536);
  if ($2) {
   $18 = $value&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3062736>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567696);
 __THREW__ = 0;
 invoke_v(789);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(65536);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $24 = $0&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($24|0);
  }
  $11 = HEAP32[3062880>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567744);
 __THREW__ = 0;
 invoke_v(790);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2607384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3062896>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3838,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_InvalidCastException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP36mscorlib_System_InvalidCastExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2607128);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147467262);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z75mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567792);
 __THREW__ = 0;
 invoke_v(791);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<24>>24)>(-1);
  if ($2) {
   $18 = $value << 24 >> 24;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3062984>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567840);
 __THREW__ = 0;
 invoke_v(792);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<16>>16)>(-1);
  if ($2) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3063064>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567888);
 __THREW__ = 0;
 $0 = (invoke_iii(605,(0|0),($value|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z76mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567936);
 __THREW__ = 0;
 invoke_v(793);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value>>>0)<(65536);
  if ($2) {
   $18 = $value&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3063080>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2567984);
 __THREW__ = 0;
 invoke_v(794);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(65536);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $24 = $0&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($24|0);
  }
  $11 = HEAP32[3063168>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568032);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($value|0);
}
function __Z108mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568080);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1673,(2156512|0),($3|0),($provider|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I26mscorlib_System_CharTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z116mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($agg$result,$__this,$value,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568128);
 $0 = ($value|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = HEAP8[((2592096 + 116|0))>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $5 = __THREW__; __THREW__ = 0;
     $6 = $5&1;
     if ($6) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2592096|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[((2592096 + 80|0))>>2]|0;
     $16 = (($15) + 16|0);
     ;HEAP32[$agg$result+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$16+12>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  } else {
   __THREW__ = 0;
   invoke_viiii(189,($L_1|0),0,($value|0),($provider|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_1+12>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z112mscorlib_System_DateTime_m_Parse_mscorlib_System_DateTime_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($agg$result,$__this,$s,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586864);
 __THREW__ = 0;
 invoke_viiiii(73,($agg$result|0),0,($s|0),($provider|0),7);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_Int16P22mscorlib_System_Objects($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568176);
 __THREW__ = 0;
 invoke_v(795);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2607384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3063184>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3838,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z83mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_Int32P22mscorlib_System_Objecti($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568224);
 __THREW__ = 0;
 invoke_v(796);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2607384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3063200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3838,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z83mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_Int64P22mscorlib_System_Objectx($agg$result,$__this,$0,$1) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568272);
 __THREW__ = 0;
 invoke_v(797);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2607384|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3063216>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($6|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3838,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z84mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_SingleP22mscorlib_System_Objectf($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568320);
 __THREW__ = 0;
 invoke_v(798);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2607384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3063232>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3838,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z116mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($agg$result,$__this,$value,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568368);
 $0 = ($value|0)==(0|0);
 do {
  if ($0) {
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = HEAP8[((2592096 + 116|0))>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $5 = __THREW__; __THREW__ = 0;
     $6 = $5&1;
     if ($6) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2592096|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[((2592096 + 80|0))>>2]|0;
     $16 = (($15) + 16|0);
     ;HEAP32[$agg$result+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$16+12>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2157656|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_iii(2769,($value|0),(2157656|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vi(3799,($19|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      invoke_viiii(474,($L_2|0),(2156592|0),($19|0),($provider|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       ;HEAP32[$agg$result+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_2+12>>2]|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker1I30mscorlib_System_DateTimeTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($agg$result,$method,$obj,$p1) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($agg$result,$4,$p1);
 STACKTOP = sp;return;
}
function __Z83mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_SByteP22mscorlib_System_Objecta($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568416);
 __THREW__ = 0;
 invoke_v(799);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2607384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3063248>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3838,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z84mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt16P22mscorlib_System_Objectt($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568464);
 __THREW__ = 0;
 invoke_v(800);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2607384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3063264>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3838,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z84mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt32P22mscorlib_System_Objectj($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568512);
 __THREW__ = 0;
 invoke_v(801);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2607384|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3063280>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3838,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z84mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt64P22mscorlib_System_Objecty($agg$result,$__this,$0,$1) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568560);
 __THREW__ = 0;
 invoke_v(802);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2607384|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2607384|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3063296>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($6|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3838,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z83mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_BooleanP22mscorlib_System_Objectb($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568608);
 $$ = $value&1;
 __THREW__ = 0;
 invoke_viii(517,($agg$result|0),(0|0),($$|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z80mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_ByteP22mscorlib_System_Objecth($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568656);
 __THREW__ = 0;
 invoke_viii(513,($agg$result|0),(0|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_DoubleP22mscorlib_System_Objectd($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568704);
 __THREW__ = 0;
 invoke_viid(1,($agg$result|0),(0|0),(+$value));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_SingleP22mscorlib_System_Objectf($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568752);
 __THREW__ = 0;
 invoke_viif(18,($agg$result|0),(0|0),(+$value));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_Int32P22mscorlib_System_Objecti($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568800);
 __THREW__ = 0;
 invoke_viii(517,($agg$result|0),(0|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_Int64P22mscorlib_System_Objectx($agg$result,$__this,$0,$1) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568848);
 __THREW__ = 0;
 invoke_viiii(134,($agg$result|0),(0|0),($0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_SByteP22mscorlib_System_Objecta($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568896);
 __THREW__ = 0;
 invoke_viii(514,($agg$result|0),(0|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_Int16P22mscorlib_System_Objects($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568944);
 __THREW__ = 0;
 invoke_viii(515,($agg$result|0),(0|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z114mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($agg$result,$__this,$value,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $L_1 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_1 = sp;
 $L_2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2568992);
 $0 = ($value|0)==(0|0);
 if ($0) {
  ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
  __THREW__ = 0;
  invoke_vii(1767,($L_1|0),0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if ($2) {
   $3 = ___cxa_find_matching_catch()|0;
   $4 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($3|0);
   // unreachable;
  }
  ;HEAP32[$agg$result+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_1+12>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 } else {
  __THREW__ = 0;
  invoke_viiii(130,($L_2|0),(0|0),($value|0),($provider|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   $3 = ___cxa_find_matching_catch()|0;
   $4 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($3|0);
   // unreachable;
  }
  ;HEAP32[$agg$result+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_2+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_2+12>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt32P22mscorlib_System_Objectj($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569040);
 __THREW__ = 0;
 invoke_viii(518,($agg$result|0),(0|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt64P22mscorlib_System_Objecty($agg$result,$__this,$0,$1) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569088);
 __THREW__ = 0;
 invoke_viiii(135,($agg$result|0),(0|0),($0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt16P22mscorlib_System_Objectt($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569136);
 __THREW__ = 0;
 invoke_viii(516,($agg$result|0),(0|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z114mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($agg$result,$__this,$value,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_1 = sp;
 $L_3 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569184);
 $0 = ($value|0)==(0|0);
 if ($0) {
  ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
  __THREW__ = 0;
  invoke_vii(1767,($L_1|0),0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   ;HEAP32[$agg$result+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_1+12>>2]|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2157656|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_iii(2769,($value|0),(2157656|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vi(3799,($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_viiii(475,($L_3|0),(2156672|0),($7|0),($provider|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      ;HEAP32[$agg$result+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_3+12>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __ZN21InterfaceFuncInvoker1I29mscorlib_System_DecimalTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($agg$result,$method,$obj,$p1) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($agg$result,$4,$p1);
 STACKTOP = sp;return;
}
function __Z81mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569232);
 $$ = $value ? 1.0 : 0.0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$$);
}
function __Z78mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569280);
 $0 = (+($value&255));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$0);
}
function __Z81mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569328);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (+invoke_dii(15,(0|0),($value$byval_copy|0)));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$0);
 }
 return +0;
}
function __Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569376);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$value);
}
function __Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569424);
 $0 = +$value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$0);
}
function __Z79mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569472);
 $0 = (+($value|0));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$0);
}
function __Z79mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569520);
 $2 = (+($0>>>0)) + (4294967296.0*(+($1|0)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$2);
}
function __Z79mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569568);
 $0 = (+($value<<24>>24));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$0);
}
function __Z79mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569616);
 $0 = (+($value<<16>>16));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$0);
}
function __Z112mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0.0, $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569664);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0.0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$$0);
 }
 __THREW__ = 0;
 $1 = (+invoke_diii(1,(0|0),($value|0),($provider|0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$$0);
 }
 return +0;
}
function __Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569712);
 $0 = (+($value>>>0));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$0);
}
function __Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569760);
 $2 = (+($0>>>0)) + (4294967296.0*(+($1>>>0)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$2);
}
function __Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569808);
 $0 = (+($value&65535));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$0);
}
function __Z112mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569856);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0.0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (+$$0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (+invoke_diii(6,(2156752|0),($3|0),($provider|0)));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return (+$$0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return +0;
}
function __ZN21InterfaceFuncInvoker1I28mscorlib_System_DoubleTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (+FUNCTION_TABLE_dii[$3 & 31]($4,$p1));
 STACKTOP = sp;return (+$5);
}
function __Z79mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569904);
 $$ = $value&1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z76mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2569952);
 $0 = $value&255;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z76mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_CharP22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570000);
 __THREW__ = 0;
 invoke_v(803);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<16>>16)>(-1);
  if ($2) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3063312>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_4 = 0, $L_8 = 0, $L_8$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_8$byval_copy = sp + 72|0;
 $value$byval_copy1 = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp + 24|0;
 $L_4 = sp + 40|0;
 $L_8 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570048);
 __THREW__ = 0;
 invoke_v(804);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(1767,($L_1|0),32767);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
    ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
    $4 = (invoke_iiii(638,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;HEAP32[$L_4+12>>2]=0|0;
      __THREW__ = 0;
      invoke_vii(1767,($L_4|0),-32768);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
      ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_4+12>>2]|0;
      $11 = (invoke_iiii(639,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
       invoke_viii(679,($L_8|0),0,($L_8$byval_copy|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
       $29 = (invoke_iii(691,(0|0),($L_8$byval_copy|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($29|0);
      }
     }
     $14 = HEAP32[3063400>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2635888|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vii(1971,($20|0),($15|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3838,($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570096);
 __THREW__ = 0;
 invoke_v(805);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > 32767.0;
   $3 = !($value >= -32768.0);
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    __THREW__ = 0;
    $19 = (+invoke_did(3,0,(+$value)));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (~~(($19)));
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($22|0);
   }
   $6 = HEAP32[3063544>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570144);
 __THREW__ = 0;
 invoke_v(806);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > Math_fround(32767.0);
   $3 = !($value >= Math_fround(-32768.0));
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    $19 = +$value;
    __THREW__ = 0;
    $20 = (+invoke_did(3,0,(+$19)));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (~~(($20)));
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($23|0);
   }
   $6 = HEAP32[3063560>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $value$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570192);
 __THREW__ = 0;
 invoke_v(807);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $value$off = (($value) + 32768)|0;
  $2 = ($value$off>>>0)<(65536);
  if ($2) {
   $18 = $value&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3063576>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570240);
 __THREW__ = 0;
 invoke_v(808);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (_i64Add(($0|0),($1|0),32768,0)|0);
  $5 = tempRet0;
  $6 = ($5>>>0)<(0);
  $7 = ($5|0)==(0);
  $8 = ($4>>>0)<(65536);
  $9 = $7 & $8;
  $10 = $6 | $9;
  if ($10) {
   $26 = $0&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($26|0);
  }
  $13 = HEAP32[3063592>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii(783,(0|0),($13|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2635888|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vii(1971,($19|0),($14|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      invoke_vi(3838,($19|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570288);
 $0 = $value << 24 >> 24;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z77mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570336);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($value|0);
}
function __Z110mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570384);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(503,(0|0),($value|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570432);
 __THREW__ = 0;
 invoke_v(809);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value>>>0)<(32768);
  if ($2) {
   $18 = $value&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3063608>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570480);
 __THREW__ = 0;
 invoke_v(810);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(32768);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $24 = $0&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($24|0);
  }
  $11 = HEAP32[3063624>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570528);
 __THREW__ = 0;
 invoke_v(811);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<16>>16)>(-1);
  if ($2) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3063640>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570576);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1674,(2156824|0),($3|0),($provider|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int16Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z79mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570624);
 $$ = $value&1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z76mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570672);
 $0 = $value&255;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z76mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_CharP22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570720);
 $0 = $value&65535;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z79mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_4 = 0, $L_8 = 0, $L_8$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_8$byval_copy = sp + 72|0;
 $value$byval_copy1 = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp + 24|0;
 $L_4 = sp + 40|0;
 $L_8 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570768);
 __THREW__ = 0;
 invoke_v(812);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(1767,($L_1|0),2147483647);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
    ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
    $4 = (invoke_iiii(638,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;HEAP32[$L_4+12>>2]=0|0;
      __THREW__ = 0;
      invoke_vii(1767,($L_4|0),-2147483648);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
      ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_4+12>>2]|0;
      $11 = (invoke_iiii(639,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
       invoke_viii(679,($L_8|0),0,($L_8$byval_copy|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
       $29 = (invoke_iii(693,(0|0),($L_8$byval_copy|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($29|0);
      }
     }
     $14 = HEAP32[3063656>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2635888|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vii(1971,($20|0),($15|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3838,($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570816);
 __THREW__ = 0;
 invoke_v(813);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > 2147483647.0;
   $3 = !($value >= -2147483648.0);
   $or$cond = $2 | $3;
   if ($or$cond) {
    $6 = HEAP32[3063800>>2]|0;
    __THREW__ = 0;
    $7 = (invoke_iii(783,(0|0),($6|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(2635888|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1971,($12|0),($7|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($12|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   } else {
    __THREW__ = 0;
    $19 = (+invoke_did(3,0,(+$value)));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = $19 > 2147483647.0;
    if (!($22)) {
     $28 = (~~(($19)));
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($28|0);
    }
    __THREW__ = 0;
    $23 = (invoke_i(133)|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($23|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    // unreachable;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570864);
 __THREW__ = 0;
 invoke_v(814);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > Math_fround(2147483648.0);
   $3 = !($value >= Math_fround(-2147483648.0));
   $or$cond = $2 | $3;
   if ($or$cond) {
    $6 = HEAP32[3063816>>2]|0;
    __THREW__ = 0;
    $7 = (invoke_iii(783,(0|0),($6|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(2635888|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1971,($12|0),($7|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($12|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   } else {
    $19 = +$value;
    __THREW__ = 0;
    $20 = (+invoke_did(3,0,(+$19)));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = $20 > 2147483647.0;
    if (!($23)) {
     $29 = (~~(($20)));
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($29|0);
    }
    __THREW__ = 0;
    $24 = (invoke_i(133)|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($24|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    // unreachable;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570912);
 __THREW__ = 0;
 invoke_v(815);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (_i64Add(($0|0),($1|0),-2147483648,0)|0);
  $5 = tempRet0;
  $6 = ($5>>>0)<(1);
  $7 = ($5|0)==(1);
  $8 = ($4>>>0)<(0);
  $9 = $7 & $8;
  $10 = $6 | $9;
  if ($10) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
  $13 = HEAP32[3063832>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii(783,(0|0),($13|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2635888|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vii(1971,($19|0),($14|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      invoke_vi(3838,($19|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2570960);
 $0 = $value << 24 >> 24;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z77mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571008);
 $0 = $value << 16 >> 16;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571056);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iii(474,(0|0),($value|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z110mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571104);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(449,(0|0),($value|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571152);
 __THREW__ = 0;
 invoke_v(816);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value|0)>(-1);
  if ($2) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3063848>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571200);
 __THREW__ = 0;
 invoke_v(817);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(2147483648);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
  $11 = HEAP32[3063936>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571248);
 $0 = $value&65535;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z110mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571296);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1652,(2156896|0),($3|0),($provider|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571344);
 $0 = $value&1;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($0|0);
}
function __Z76mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571392);
 $0 = $value&255;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($0|0);
}
function __Z76mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_CharP22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571440);
 $0 = $value&65535;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($0|0);
}
function __Z79mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_16 = 0, $L_16$byval_copy = 0, $L_5 = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_16$byval_copy = sp + 72|0;
 $value$byval_copy1 = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_5 = sp + 24|0;
 $L_12 = sp + 40|0;
 $L_16 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571488);
 __THREW__ = 0;
 invoke_v(818);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$L_5+0>>2]=0|0;HEAP32[$L_5+4>>2]=0|0;HEAP32[$L_5+8>>2]=0|0;HEAP32[$L_5+12>>2]=0|0;
   __THREW__ = 0;
   invoke_viiiiii(53,($L_5|0),-1,2147483647,0,0,0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
    ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_5+12>>2]|0;
    $4 = (invoke_iiii(638,(0|0),($value$byval_copy1|0),($L_16$byval_copy|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      ;HEAP32[$L_12+0>>2]=0|0;HEAP32[$L_12+4>>2]=0|0;HEAP32[$L_12+8>>2]=0|0;HEAP32[$L_12+12>>2]=0|0;
      __THREW__ = 0;
      invoke_viiiiii(53,($L_12|0),0,-2147483648,0,1,0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
      ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_12+12>>2]|0;
      $11 = (invoke_iiii(639,(0|0),($value$byval_copy1|0),($L_16$byval_copy|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
       invoke_viii(679,($L_16|0),0,($L_16$byval_copy|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_16+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_16+12>>2]|0;
       $29 = (invoke_iii(695,(0|0),($L_16$byval_copy|0))|0);
       $30 = tempRet0;
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       tempRet0 = $30;
       STACKTOP = sp;return ($29|0);
      }
     }
     $14 = HEAP32[3063952>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2635888|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vii(1971,($20|0),($15|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3838,($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571536);
 __THREW__ = 0;
 invoke_v(819);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > 9223372036854775808.0;
   $3 = !($value >= -9223372036854775808.0);
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    __THREW__ = 0;
    $19 = (+invoke_did(3,0,(+$value)));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (~~$19)>>>0;
    $23 = +Math_abs($19) >= 1.0 ? $19 > 0.0 ? (Math_min(+Math_floor($19 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($19 - +(~~$19 >>> 0)) / 4294967296.0) >>> 0 : 0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $23;
    STACKTOP = sp;return ($22|0);
   }
   $6 = HEAP32[3064096>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571584);
 __THREW__ = 0;
 invoke_v(820);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > Math_fround(9223372036854775808.0);
   $3 = !($value >= Math_fround(-9223372036854775808.0));
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    $19 = +$value;
    __THREW__ = 0;
    $20 = (+invoke_did(3,0,(+$19)));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (~~$20)>>>0;
    $24 = +Math_abs($20) >= 1.0 ? $20 > 0.0 ? (Math_min(+Math_floor($20 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($20 - +(~~$20 >>> 0)) / 4294967296.0) >>> 0 : 0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $24;
    STACKTOP = sp;return ($23|0);
   }
   $6 = HEAP32[3064112>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571632);
 $0 = ($value|0)<(0);
 $1 = $0 << 31 >> 31;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $1;
 STACKTOP = sp;return ($value|0);
}
function __Z77mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571680);
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $1;
 STACKTOP = sp;return ($0|0);
}
function __Z77mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571728);
 $0 = $value << 24 >> 24;
 $1 = ($0|0)<(0);
 $2 = $1 << 31 >> 31;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $2;
 STACKTOP = sp;return ($0|0);
}
function __Z77mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571776);
 $0 = $value << 16 >> 16;
 $1 = ($0|0)<(0);
 $2 = $1 << 31 >> 31;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $2;
 STACKTOP = sp;return ($0|0);
}
function __Z110mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571824);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $7 = 0;$8 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($8|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(466,(0|0),($value|0),($provider|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = $2;$8 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571872);
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($value|0);
}
function __Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571920);
 __THREW__ = 0;
 invoke_v(821);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1|0)>(-1);
  $5 = ($1|0)==(-1);
  $6 = ($0>>>0)>(4294967295);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $1;
   STACKTOP = sp;return ($0|0);
  }
  $11 = HEAP32[3064128>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2571968);
 $0 = $value&65535;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($0|0);
}
function __Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572016);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $7 = 0;$8 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($8|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(1060,0,($value|0),(0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = $2;$8 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z110mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572064);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $14 = 0;$15 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $14;
  STACKTOP = sp;return ($15|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1675,(2156968|0),($3|0),($provider|0))|0);
    $9 = tempRet0;
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $14 = $9;$15 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $14;
     STACKTOP = sp;return ($15|0);
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_Int64Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 $6 = tempRet0;
 tempRet0 = $6;
 STACKTOP = sp;return ($5|0);
}
function __Z79mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572112);
 $$ = $value&1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z76mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572160);
 __THREW__ = 0;
 invoke_v(822);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<24>>24)>(-1);
  if ($2) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3064216>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_CharP22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572208);
 __THREW__ = 0;
 invoke_v(823);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value&65535)<(128);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3064304>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_4 = 0, $L_8 = 0, $L_8$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_8$byval_copy = sp + 72|0;
 $value$byval_copy1 = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp + 24|0;
 $L_4 = sp + 40|0;
 $L_8 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572256);
 __THREW__ = 0;
 invoke_v(824);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(1767,($L_1|0),127);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
    ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
    $4 = (invoke_iiii(638,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;HEAP32[$L_4+12>>2]=0|0;
      __THREW__ = 0;
      invoke_vii(1767,($L_4|0),-128);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
      ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_4+12>>2]|0;
      $11 = (invoke_iiii(639,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
       invoke_viii(679,($L_8|0),0,($L_8$byval_copy|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
       $29 = (invoke_iii(690,(0|0),($L_8$byval_copy|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($29|0);
      }
     }
     $14 = HEAP32[3064320>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2635888|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vii(1971,($20|0),($15|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3838,($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572304);
 __THREW__ = 0;
 invoke_v(825);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > 127.0;
   $3 = !($value >= -128.0);
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    __THREW__ = 0;
    $19 = (+invoke_did(3,0,(+$value)));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (~~(($19)));
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($22|0);
   }
   $6 = HEAP32[3064464>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572352);
 __THREW__ = 0;
 invoke_v(826);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > Math_fround(127.0);
   $3 = !($value >= Math_fround(-128.0));
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    $19 = +$value;
    __THREW__ = 0;
    $20 = (+invoke_did(3,0,(+$19)));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (~~(($20)));
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($23|0);
   }
   $6 = HEAP32[3064480>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $value$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572400);
 __THREW__ = 0;
 invoke_v(827);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $value$off = (($value) + 128)|0;
  $2 = ($value$off>>>0)<(256);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3064624>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572448);
 __THREW__ = 0;
 invoke_v(828);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (_i64Add(($0|0),($1|0),128,0)|0);
  $5 = tempRet0;
  $6 = ($5>>>0)<(0);
  $7 = ($5|0)==(0);
  $8 = ($4>>>0)<(256);
  $9 = $7 & $8;
  $10 = $6 | $9;
  if ($10) {
   $26 = $0&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($26|0);
  }
  $13 = HEAP32[3064640>>2]|0;
  __THREW__ = 0;
  $14 = (invoke_iii(783,(0|0),($13|0))|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2635888|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vii(1971,($19|0),($14|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      invoke_vi(3838,($19|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $value$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572496);
 __THREW__ = 0;
 invoke_v(829);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $value$off = (($value) + 128)<<16>>16;
  $2 = ($value$off&65535)<(256);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3064656>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572544);
 __THREW__ = 0;
 invoke_v(830);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iiii(496,(0|0),($value|0),($provider|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3064672>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3838,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572592);
 __THREW__ = 0;
 invoke_v(831);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value>>>0)<(128);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3064688>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572640);
 __THREW__ = 0;
 invoke_v(832);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(128);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $24 = $0&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($24|0);
  }
  $11 = HEAP32[3064704>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572688);
 __THREW__ = 0;
 invoke_v(833);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value&65535)<(128);
  if ($2) {
   $18 = $value&255;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3064720>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572736);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1676,(2157040|0),($3|0),($provider|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I27mscorlib_System_SByteTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z81mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572784);
 $$ = $value ? Math_fround(1.0) : Math_fround(0.0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($$));
}
function __Z78mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572832);
 $0 = (Math_fround(($value&255)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z81mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572880);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (Math_fround(+(invoke_fii(21,(0|0),($value$byval_copy|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($0));
 }
 return Math_fround(0);
}
function __Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572928);
 $0 = Math_fround($value);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2572976);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($value));
}
function __Z79mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573024);
 $0 = (Math_fround(($value|0)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z79mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573072);
 $2 = Math_fround((+($0>>>0)) + (4294967296.0*(+($1|0))));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($2));
}
function __Z79mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573120);
 $0 = (Math_fround(($value<<24>>24)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z79mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573168);
 $0 = (Math_fround(($value<<16>>16)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573216);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = Math_fround(0.0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fii(18,(0|0),($value|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __Z112mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573264);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = Math_fround(0.0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fiii(1,(0|0),($value|0),($provider|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 return Math_fround(0);
}
function __Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0.0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573312);
 $0 = (+($value>>>0));
 $1 = Math_fround($0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0.0, $3 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573360);
 $2 = (+($0>>>0)) + (4294967296.0*(+($1>>>0)));
 $3 = Math_fround($2);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($3));
}
function __Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573408);
 $0 = (Math_fround(($value&65535)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z112mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573456);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = Math_fround(0.0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (Math_fround(+(invoke_fiii(17,(2157120|0),($3|0),($provider|0)))));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return (Math_fround($$0));
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return Math_fround(0);
}
function __ZN21InterfaceFuncInvoker1I28mscorlib_System_SingleTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fii[$3 & 63]($4,$p1)));
 STACKTOP = sp;return (Math_fround($5));
}
function __Z81mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573504);
 $$ = $value&1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z78mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573552);
 $0 = $value&255;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z78mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_CharP22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573600);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($value|0);
}
function __Z81mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_4 = 0, $L_8 = 0, $L_8$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_8$byval_copy = sp + 72|0;
 $value$byval_copy1 = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp + 24|0;
 $L_4 = sp + 40|0;
 $L_8 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573648);
 __THREW__ = 0;
 invoke_v(834);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$L_1+0>>2]=0|0;HEAP32[$L_1+4>>2]=0|0;HEAP32[$L_1+8>>2]=0|0;HEAP32[$L_1+12>>2]=0|0;
   __THREW__ = 0;
   invoke_vii(1767,($L_1|0),65535);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
    ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
    $4 = (invoke_iiii(638,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;HEAP32[$L_4+12>>2]=0|0;
      __THREW__ = 0;
      invoke_vii(1767,($L_4|0),0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
      ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_4+12>>2]|0;
      $11 = (invoke_iiii(639,(0|0),($value$byval_copy1|0),($L_8$byval_copy|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
       invoke_viii(679,($L_8|0),0,($L_8$byval_copy|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
       $29 = (invoke_iii(692,(0|0),($L_8$byval_copy|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($29|0);
      }
     }
     $14 = HEAP32[3064736>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2635888|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vii(1971,($20|0),($15|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3838,($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573696);
 __THREW__ = 0;
 invoke_v(835);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > 65535.0;
   $3 = !($value >= 0.0);
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    __THREW__ = 0;
    $19 = (+invoke_did(3,0,(+$value)));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (~~(($19))&65535);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($22|0);
   }
   $6 = HEAP32[3064888>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573744);
 __THREW__ = 0;
 invoke_v(836);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > Math_fround(65535.0);
   $3 = !($value >= Math_fround(0.0));
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    $19 = +$value;
    __THREW__ = 0;
    $20 = (+invoke_did(3,0,(+$19)));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (~~(($20))&65535);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($23|0);
   }
   $6 = HEAP32[3064904>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573792);
 __THREW__ = 0;
 invoke_v(837);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value>>>0)<(65536);
  if ($2) {
   $18 = $value&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3064920>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573840);
 __THREW__ = 0;
 invoke_v(838);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(65536);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $24 = $0&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($24|0);
  }
  $11 = HEAP32[3064936>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573888);
 __THREW__ = 0;
 invoke_v(839);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<24>>24)>(-1);
  if ($2) {
   $18 = $value << 24 >> 24;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3064952>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573936);
 __THREW__ = 0;
 invoke_v(840);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<16>>16)>(-1);
  if ($2) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3065040>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z112mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2573984);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(510,(0|0),($value|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574032);
 __THREW__ = 0;
 invoke_v(841);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value>>>0)<(65536);
  if ($2) {
   $18 = $value&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3065056>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574080);
 __THREW__ = 0;
 invoke_v(842);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(0);
  $5 = ($1|0)==(0);
  $6 = ($0>>>0)<(65536);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   $24 = $0&65535;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($24|0);
  }
  $11 = HEAP32[3065152>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z112mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574128);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1677,(2157344|0),($3|0),($provider|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I28mscorlib_System_UInt16Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z81mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574176);
 $$ = $value&1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z78mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574224);
 $0 = $value&255;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z78mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_CharP22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574272);
 $0 = $value&65535;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z81mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_12$byval_copy = 0, $L_5 = 0, $L_8 = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_12$byval_copy = sp + 72|0;
 $value$byval_copy1 = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_5 = sp + 24|0;
 $L_8 = sp + 40|0;
 $L_12 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574320);
 __THREW__ = 0;
 invoke_v(843);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$L_5+0>>2]=0|0;HEAP32[$L_5+4>>2]=0|0;HEAP32[$L_5+8>>2]=0|0;HEAP32[$L_5+12>>2]=0|0;
   __THREW__ = 0;
   invoke_viiiiii(53,($L_5|0),-1,0,0,0,0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
    ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$L_5+12>>2]|0;
    $4 = (invoke_iiii(638,(0|0),($value$byval_copy1|0),($L_12$byval_copy|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      ;HEAP32[$L_8+0>>2]=0|0;HEAP32[$L_8+4>>2]=0|0;HEAP32[$L_8+8>>2]=0|0;HEAP32[$L_8+12>>2]=0|0;
      __THREW__ = 0;
      invoke_vii(1767,($L_8|0),0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
      ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
      $11 = (invoke_iiii(639,(0|0),($value$byval_copy1|0),($L_12$byval_copy|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
       invoke_viii(679,($L_12|0),0,($L_12$byval_copy|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$L_12+12>>2]|0;
       $29 = (invoke_iii(694,(0|0),($L_12$byval_copy|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($29|0);
      }
     }
     $14 = HEAP32[3065168>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2635888|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vii(1971,($20|0),($15|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3838,($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574368);
 __THREW__ = 0;
 invoke_v(844);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > 4294967295.0;
   $3 = !($value >= 0.0);
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    __THREW__ = 0;
    $19 = (+invoke_did(3,0,(+$value)));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (~~(($19))>>>0);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($22|0);
   }
   $6 = HEAP32[3065320>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574416);
 __THREW__ = 0;
 invoke_v(845);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > Math_fround(4294967296.0);
   $3 = !($value >= Math_fround(0.0));
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    $19 = +$value;
    __THREW__ = 0;
    $20 = (+invoke_did(3,0,(+$19)));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (~~(($20))>>>0);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($23|0);
   }
   $6 = HEAP32[3065336>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574464);
 __THREW__ = 0;
 invoke_v(846);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value|0)>(-1);
  if ($2) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3065352>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574512);
 __THREW__ = 0;
 invoke_v(847);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(1);
  $5 = ($1|0)==(1);
  $6 = ($0>>>0)<(0);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
  $11 = HEAP32[3065440>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574560);
 __THREW__ = 0;
 invoke_v(848);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<24>>24)>(-1);
  if ($2) {
   $18 = $value << 24 >> 24;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3065456>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574608);
 __THREW__ = 0;
 invoke_v(849);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<16>>16)>(-1);
  if ($2) {
   $18 = $value << 16 >> 16;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3065472>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z112mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574656);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(474,(0|0),($value|0),($provider|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_UInt64P22mscorlib_System_Objecty($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574704);
 __THREW__ = 0;
 invoke_v(850);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1>>>0)<(1);
  $5 = ($1|0)==(1);
  $6 = ($0>>>0)<(0);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
  $11 = HEAP32[3065488>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574752);
 $0 = $value&65535;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z112mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574800);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1678,(2157424|0),($3|0),($provider|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I28mscorlib_System_UInt32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z81mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_BooleanP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574848);
 $0 = $value&1;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($0|0);
}
function __Z78mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_ByteP22mscorlib_System_Objecth($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574896);
 $0 = $value&255;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($0|0);
}
function __Z78mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_CharP22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574944);
 $0 = $value&65535;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($0|0);
}
function __Z81mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_12$byval_copy = 0, $L_5 = 0, $L_8 = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_12$byval_copy = sp + 72|0;
 $value$byval_copy1 = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_5 = sp + 24|0;
 $L_8 = sp + 40|0;
 $L_12 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2574992);
 __THREW__ = 0;
 invoke_v(851);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   ;HEAP32[$L_5+0>>2]=0|0;HEAP32[$L_5+4>>2]=0|0;HEAP32[$L_5+8>>2]=0|0;HEAP32[$L_5+12>>2]=0|0;
   __THREW__ = 0;
   invoke_viiiiii(53,($L_5|0),-1,-1,0,0,0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
    ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$L_5+12>>2]|0;
    $4 = (invoke_iiii(638,(0|0),($value$byval_copy1|0),($L_12$byval_copy|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if (!($4)) {
      ;HEAP32[$L_8+0>>2]=0|0;HEAP32[$L_8+4>>2]=0|0;HEAP32[$L_8+8>>2]=0|0;HEAP32[$L_8+12>>2]=0|0;
      __THREW__ = 0;
      invoke_vii(1767,($L_8|0),0);
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy1+12>>2]=HEAP32[$value+12>>2]|0;
      ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
      $11 = (invoke_iiii(639,(0|0),($value$byval_copy1|0),($L_12$byval_copy|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
       invoke_viii(679,($L_12|0),0,($L_12$byval_copy|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$L_12+12>>2]|0;
       $29 = (invoke_iii(696,(0|0),($L_12$byval_copy|0))|0);
       $30 = tempRet0;
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       tempRet0 = $30;
       STACKTOP = sp;return ($29|0);
      }
     }
     $14 = HEAP32[3065584>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       $20 = (invoke_ii(3469,(2635888|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        invoke_vii(1971,($20|0),($15|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3838,($20|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_DoubleP22mscorlib_System_Objectd($__this,$value) {
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575040);
 __THREW__ = 0;
 invoke_v(852);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > 18446744073709551616.0;
   $3 = !($value >= 0.0);
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    __THREW__ = 0;
    $19 = (+invoke_did(3,0,(+$value)));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = (~~$19)>>>0;
    $23 = +Math_abs($19) >= 1.0 ? $19 > 0.0 ? (Math_min(+Math_floor($19 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($19 - +(~~$19 >>> 0)) / 4294967296.0) >>> 0 : 0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $23;
    STACKTOP = sp;return ($22|0);
   }
   $6 = HEAP32[3065736>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575088);
 __THREW__ = 0;
 invoke_v(853);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = $value > Math_fround(18446744073709551616.0);
   $3 = !($value >= Math_fround(0.0));
   $or$cond = $2 | $3;
   if (!($or$cond)) {
    $19 = +$value;
    __THREW__ = 0;
    $20 = (+invoke_did(3,0,(+$19)));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (~~$20)>>>0;
    $24 = +Math_abs($20) >= 1.0 ? $20 > 0.0 ? (Math_min(+Math_floor($20 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($20 - +(~~$20 >>> 0)) / 4294967296.0) >>> 0 : 0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $24;
    STACKTOP = sp;return ($23|0);
   }
   $6 = HEAP32[3065752>>2]|0;
   __THREW__ = 0;
   $7 = (invoke_iii(783,(0|0),($6|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2635888|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2635888|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vii(1971,($12|0),($7|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vi(3838,($12|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575136);
 __THREW__ = 0;
 invoke_v(854);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value|0)>(-1);
  if ($2) {
   $18 = ($value|0)<(0);
   $19 = $18 << 31 >> 31;
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $19;
   STACKTOP = sp;return ($value|0);
  }
  $5 = HEAP32[3065768>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575184);
 __THREW__ = 0;
 invoke_v(855);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($1|0)>(-1);
  $5 = ($1|0)==(-1);
  $6 = ($0>>>0)>(4294967295);
  $7 = $5 & $6;
  $8 = $4 | $7;
  if ($8) {
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $1;
   STACKTOP = sp;return ($0|0);
  }
  $11 = HEAP32[3065856>>2]|0;
  __THREW__ = 0;
  $12 = (invoke_iii(783,(0|0),($11|0))|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(3469,(2635888|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vii(1971,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3838,($17|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_SByteP22mscorlib_System_Objecta($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575232);
 __THREW__ = 0;
 invoke_v(856);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<24>>24)>(-1);
  if ($2) {
   $15 = $value << 24 >> 24;
   $16 = ($15|0)<(0);
   $17 = $16 << 31 >> 31;
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $17;
   STACKTOP = sp;return ($15|0);
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2635888|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (invoke_ii(3469,(2635888|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[3065872>>2]|0;
    __THREW__ = 0;
    invoke_vii(1971,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3838,($7|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int16P22mscorlib_System_Objects($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575280);
 __THREW__ = 0;
 invoke_v(857);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value<<16>>16)>(-1);
  if ($2) {
   $18 = $value << 16 >> 16;
   $19 = ($18|0)<(0);
   $20 = $19 << 31 >> 31;
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $20;
   STACKTOP = sp;return ($18|0);
  }
  $5 = HEAP32[3065888>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z112mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575328);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $7 = 0;$8 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($8|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(482,(0|0),($value|0),($provider|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = $2;$8 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575376);
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($value|0);
}
function __Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_UInt16P22mscorlib_System_Objectt($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575424);
 $0 = $value&65535;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = 0;
 STACKTOP = sp;return ($0|0);
}
function __Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575472);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $7 = 0;$8 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($8|0);
 }
 __THREW__ = 0;
 $1 = (invoke_iiii(1134,0,($value|0),(0|0))|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $7 = $2;$8 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $7;
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z112mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_($__this,$value,$provider) {
 $__this = $__this|0;
 $value = $value|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575520);
 $0 = ($value|0)==(0|0);
 if ($0) {
  $14 = 0;$15 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $14;
  STACKTOP = sp;return ($15|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2157656|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iii(2769,($value|0),(2157656|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1679,(2157504|0),($3|0),($provider|0))|0);
    $9 = tempRet0;
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $14 = $9;$15 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $14;
     STACKTOP = sp;return ($15|0);
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I28mscorlib_System_UInt64Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 $6 = tempRet0;
 tempRet0 = $6;
 STACKTOP = sp;return ($5|0);
}
function __Z36mscorlib_System_Convert_m_ChangeTypeP22mscorlib_System_ObjectS0_P20mscorlib_System_Type($__this,$value,$conversionType) {
 $__this = $__this|0;
 $value = $value|0;
 $conversionType = $conversionType|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0$in = 0, $_stackTraceSentry = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575568);
 __THREW__ = 0;
 invoke_v(858);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($value|0)!=(0|0);
   $4 = ($conversionType|0)==(0|0);
   $or$cond = $3 & $4;
   if ($or$cond) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3065904>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $17 = (invoke_ii(1982,(0|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    HEAP32[$0>>2] = 1692712;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $20 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = ($20|0)==($conversionType|0);
     if ($23) {
      __THREW__ = 0;
      invoke_vi(3799,($17|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2730,(2330232|0),($17|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      } else {
       $V_1$0$in = $26;
      }
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($17|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      $31 = (invoke_iii(2730,(2330184|0),($17|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      } else {
       $V_1$0$in = $31;
      }
     }
     __THREW__ = 0;
     $34 = (invoke_iiiiii(126,0,($value|0),($conversionType|0),($V_1$0$in|0),1)|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($34|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z32mscorlib_System_Convert_m_ToTypeP22mscorlib_System_ObjectS0_P20mscorlib_System_TypeS0_b($__this,$value,$conversionType,$provider,$try_target_to_type) {
 $__this = $__this|0;
 $value = $value|0;
 $conversionType = $conversionType|0;
 $provider = $provider|0;
 $try_target_to_type = $try_target_to_type|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0;
 var $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0;
 var $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0;
 var $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = Math_fround(0), $637 = 0;
 var $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0;
 var $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0;
 var $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0.0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0;
 var $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0;
 var $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0;
 var $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0;
 var $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0;
 var $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0;
 var $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0;
 var $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0;
 var $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0;
 var $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_21 = 0, $L_27 = 0, $L_33 = 0, $L_39 = 0, $L_45 = 0, $L_51 = 0, $L_57 = 0, $L_63 = 0, $L_69 = 0, $L_75 = 0, $L_81 = 0, $L_87 = 0, $L_92 = 0, $L_93 = 0;
 var $L_98 = 0, $L_99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $_stackTraceSentry = sp + 104|0;
 $L_21 = sp + 114|0;
 $L_27 = sp + 110|0;
 $L_33 = sp + 115|0;
 $L_39 = sp + 116|0;
 $L_45 = sp + 108|0;
 $L_51 = sp + 112|0;
 $L_57 = sp + 100|0;
 $L_63 = sp + 96|0;
 $L_69 = sp + 16|0;
 $L_75 = sp + 24|0;
 $L_81 = sp + 56|0;
 $L_87 = sp + 32|0;
 $L_92 = sp + 64|0;
 $L_93 = sp + 80|0;
 $L_98 = sp;
 $L_99 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2575616);
 __THREW__ = 0;
 invoke_v(859);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   $3 = ($conversionType|0)!=(0|0);
   if ($2) {
    if (!($3)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($conversionType|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_iii(2734,(2234232|0),($conversionType|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    if (!($8)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607384|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2607384|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[3065952>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($13|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($13|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    // unreachable;
   }
   if (!($3)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2607384|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(3469,(2607384|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    $26 = HEAP32[3065960>>2]|0;
    __THREW__ = 0;
    invoke_vii(1946,($23|0),($26|0));
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($23|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($value|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if (!($32)) {
    __THREW__ = 0;
    $33 = (invoke_ii(1782,($value|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if (!($35)) {
     $36 = ($33|0)==($conversionType|0);
     if ($36) {
      $$0 = $value;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2157656|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      __THREW__ = 0;
      $39 = (invoke_iii(2735,($value|0),(2157656|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       $42 = ($39|0)==(0|0);
       do {
        if (!($42)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2157656|0))|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          break L1;
         }
         __THREW__ = 0;
         $45 = (invoke_iii(2769,($value|0),(2157656|0))|0);
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if ($47) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if ($49) {
          break L1;
         }
         $50 = HEAP8[((2581704 + 116|0))>>0]|0;
         $51 = ($50<<24>>24)==(0);
         if ($51) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          break L1;
         }
         $60 = HEAP32[((2581704 + 80|0))>>2]|0;
         $61 = (($60) + 4|0);
         $62 = HEAP32[$61>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($62|0));
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + 12|0);
         $66 = HEAP32[$65>>2]|0;
         $67 = ($66|0)==(0);
         if ($67) {
          __THREW__ = 0;
          $68 = (invoke_i(132)|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($68|0));
          $71 = __THREW__; __THREW__ = 0;
          $72 = $71&1;
          if ($72) {
           break L1;
          }
         }
         $73 = (($62) + 16|0);
         $74 = HEAP32[$73>>2]|0;
         $75 = ($74|0)==($conversionType|0);
         if ($75) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560584|0))|0);
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          $78 = (invoke_ii(3469,(2560584|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(2585,($78|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3838,($78|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           break L1;
          }
          // unreachable;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          break L1;
         }
         $87 = HEAP8[((2581704 + 116|0))>>0]|0;
         $88 = ($87<<24>>24)==(0);
         if ($88) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $91 = __THREW__; __THREW__ = 0;
          $92 = $91&1;
          if ($92) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $93 = __THREW__; __THREW__ = 0;
          $94 = $93&1;
          if ($94) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          break L1;
         }
         $97 = HEAP32[((2581704 + 80|0))>>2]|0;
         $98 = (($97) + 4|0);
         $99 = HEAP32[$98>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($99|0));
         $100 = __THREW__; __THREW__ = 0;
         $101 = $100&1;
         if ($101) {
          break L1;
         }
         $102 = (($99) + 12|0);
         $103 = HEAP32[$102>>2]|0;
         $104 = ($103>>>0)<(2);
         if ($104) {
          __THREW__ = 0;
          $105 = (invoke_i(132)|0);
          $106 = __THREW__; __THREW__ = 0;
          $107 = $106&1;
          if ($107) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($105|0));
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           break L1;
          }
         }
         $110 = HEAP32[$99>>2]|0;
         $111 = (($99) + 16|0);
         $112 = (($110) + 92|0);
         $113 = HEAP32[$112>>2]|0;
         $114 = (($111) + ($113)|0);
         $115 = HEAP32[$114>>2]|0;
         $116 = ($115|0)==($conversionType|0);
         if ($116) {
          $$0 = $value;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          break L1;
         }
         $119 = HEAP8[((2581704 + 116|0))>>0]|0;
         $120 = ($119<<24>>24)==(0);
         if ($120) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $121 = __THREW__; __THREW__ = 0;
          $122 = $121&1;
          if ($122) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if ($124) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $125 = __THREW__; __THREW__ = 0;
          $126 = $125&1;
          if ($126) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          break L1;
         }
         $129 = HEAP32[((2581704 + 80|0))>>2]|0;
         $130 = (($129) + 4|0);
         $131 = HEAP32[$130>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($131|0));
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          break L1;
         }
         $134 = (($131) + 12|0);
         $135 = HEAP32[$134>>2]|0;
         $136 = ($135>>>0)<(3);
         if ($136) {
          __THREW__ = 0;
          $137 = (invoke_i(132)|0);
          $138 = __THREW__; __THREW__ = 0;
          $139 = $138&1;
          if ($139) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($137|0));
          $140 = __THREW__; __THREW__ = 0;
          $141 = $140&1;
          if ($141) {
           break L1;
          }
         }
         $142 = HEAP32[$131>>2]|0;
         $143 = (($131) + 16|0);
         $144 = (($142) + 92|0);
         $145 = HEAP32[$144>>2]|0;
         $146 = $145 << 1;
         $147 = (($143) + ($146)|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ($148|0)==($conversionType|0);
         if ($149) {
          __THREW__ = 0;
          (invoke_ii(2996,(2607384|0))|0);
          $150 = __THREW__; __THREW__ = 0;
          $151 = $150&1;
          if ($151) {
           break L1;
          }
          __THREW__ = 0;
          $152 = (invoke_ii(3469,(2607384|0))|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           break L1;
          }
          $155 = HEAP32[3065968>>2]|0;
          __THREW__ = 0;
          invoke_vii(1946,($152|0),($155|0));
          $156 = __THREW__; __THREW__ = 0;
          $157 = $156&1;
          if ($157) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3838,($152|0));
          $158 = __THREW__; __THREW__ = 0;
          $159 = $158&1;
          if ($159) {
           break L1;
          }
          // unreachable;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $160 = __THREW__; __THREW__ = 0;
         $161 = $160&1;
         if ($161) {
          break L1;
         }
         $162 = HEAP8[((2581704 + 116|0))>>0]|0;
         $163 = ($162<<24>>24)==(0);
         if ($163) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $164 = __THREW__; __THREW__ = 0;
          $165 = $164&1;
          if ($165) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $166 = __THREW__; __THREW__ = 0;
          $167 = $166&1;
          if ($167) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $168 = __THREW__; __THREW__ = 0;
          $169 = $168&1;
          if ($169) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $170 = __THREW__; __THREW__ = 0;
         $171 = $170&1;
         if ($171) {
          break L1;
         }
         $172 = HEAP32[((2581704 + 80|0))>>2]|0;
         $173 = (($172) + 4|0);
         $174 = HEAP32[$173>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($174|0));
         $175 = __THREW__; __THREW__ = 0;
         $176 = $175&1;
         if ($176) {
          break L1;
         }
         $177 = (($174) + 12|0);
         $178 = HEAP32[$177>>2]|0;
         $179 = ($178>>>0)<(4);
         if ($179) {
          __THREW__ = 0;
          $180 = (invoke_i(132)|0);
          $181 = __THREW__; __THREW__ = 0;
          $182 = $181&1;
          if ($182) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($180|0));
          $183 = __THREW__; __THREW__ = 0;
          $184 = $183&1;
          if ($184) {
           break L1;
          }
         }
         $185 = HEAP32[$174>>2]|0;
         $186 = (($174) + 16|0);
         $187 = (($185) + 92|0);
         $188 = HEAP32[$187>>2]|0;
         $189 = ($188*3)|0;
         $190 = (($186) + ($189)|0);
         $191 = HEAP32[$190>>2]|0;
         $192 = ($191|0)==($conversionType|0);
         if ($192) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $193 = __THREW__; __THREW__ = 0;
          $194 = $193&1;
          if ($194) {
           break L1;
          }
          __THREW__ = 0;
          $195 = (invoke_iiii(1671,(2156368|0),($45|0),($provider|0))|0);
          $196 = __THREW__; __THREW__ = 0;
          $197 = $196&1;
          if ($197) {
           break L1;
          }
          $198 = $195&1;
          HEAP8[$L_21>>0] = $198;
          __THREW__ = 0;
          (invoke_ii(2996,(2208584|0))|0);
          $199 = __THREW__; __THREW__ = 0;
          $200 = $199&1;
          if ($200) {
           break L1;
          }
          __THREW__ = 0;
          $201 = (invoke_iii(2724,(2208584|0),($L_21|0))|0);
          $202 = __THREW__; __THREW__ = 0;
          $203 = $202&1;
          if ($203) {
           break L1;
          }
          $$0 = $201;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $204 = __THREW__; __THREW__ = 0;
         $205 = $204&1;
         if ($205) {
          break L1;
         }
         $206 = HEAP8[((2581704 + 116|0))>>0]|0;
         $207 = ($206<<24>>24)==(0);
         if ($207) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $208 = __THREW__; __THREW__ = 0;
          $209 = $208&1;
          if ($209) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $210 = __THREW__; __THREW__ = 0;
          $211 = $210&1;
          if ($211) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $212 = __THREW__; __THREW__ = 0;
          $213 = $212&1;
          if ($213) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $214 = __THREW__; __THREW__ = 0;
         $215 = $214&1;
         if ($215) {
          break L1;
         }
         $216 = HEAP32[((2581704 + 80|0))>>2]|0;
         $217 = (($216) + 4|0);
         $218 = HEAP32[$217>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($218|0));
         $219 = __THREW__; __THREW__ = 0;
         $220 = $219&1;
         if ($220) {
          break L1;
         }
         $221 = (($218) + 12|0);
         $222 = HEAP32[$221>>2]|0;
         $223 = ($222>>>0)<(5);
         if ($223) {
          __THREW__ = 0;
          $224 = (invoke_i(132)|0);
          $225 = __THREW__; __THREW__ = 0;
          $226 = $225&1;
          if ($226) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($224|0));
          $227 = __THREW__; __THREW__ = 0;
          $228 = $227&1;
          if ($228) {
           break L1;
          }
         }
         $229 = HEAP32[$218>>2]|0;
         $230 = (($218) + 16|0);
         $231 = (($229) + 92|0);
         $232 = HEAP32[$231>>2]|0;
         $233 = $232 << 2;
         $234 = (($230) + ($233)|0);
         $235 = HEAP32[$234>>2]|0;
         $236 = ($235|0)==($conversionType|0);
         if ($236) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $237 = __THREW__; __THREW__ = 0;
          $238 = $237&1;
          if ($238) {
           break L1;
          }
          __THREW__ = 0;
          $239 = (invoke_iiii(1673,(2156512|0),($45|0),($provider|0))|0);
          $240 = __THREW__; __THREW__ = 0;
          $241 = $240&1;
          if ($241) {
           break L1;
          }
          HEAP16[$L_27>>1] = $239;
          __THREW__ = 0;
          (invoke_ii(2996,(2180696|0))|0);
          $242 = __THREW__; __THREW__ = 0;
          $243 = $242&1;
          if ($243) {
           break L1;
          }
          __THREW__ = 0;
          $244 = (invoke_iii(2724,(2180696|0),($L_27|0))|0);
          $245 = __THREW__; __THREW__ = 0;
          $246 = $245&1;
          if ($246) {
           break L1;
          }
          $$0 = $244;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $247 = __THREW__; __THREW__ = 0;
         $248 = $247&1;
         if ($248) {
          break L1;
         }
         $249 = HEAP8[((2581704 + 116|0))>>0]|0;
         $250 = ($249<<24>>24)==(0);
         if ($250) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $251 = __THREW__; __THREW__ = 0;
          $252 = $251&1;
          if ($252) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $253 = __THREW__; __THREW__ = 0;
          $254 = $253&1;
          if ($254) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $255 = __THREW__; __THREW__ = 0;
          $256 = $255&1;
          if ($256) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $257 = __THREW__; __THREW__ = 0;
         $258 = $257&1;
         if ($258) {
          break L1;
         }
         $259 = HEAP32[((2581704 + 80|0))>>2]|0;
         $260 = (($259) + 4|0);
         $261 = HEAP32[$260>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($261|0));
         $262 = __THREW__; __THREW__ = 0;
         $263 = $262&1;
         if ($263) {
          break L1;
         }
         $264 = (($261) + 12|0);
         $265 = HEAP32[$264>>2]|0;
         $266 = ($265>>>0)<(6);
         if ($266) {
          __THREW__ = 0;
          $267 = (invoke_i(132)|0);
          $268 = __THREW__; __THREW__ = 0;
          $269 = $268&1;
          if ($269) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($267|0));
          $270 = __THREW__; __THREW__ = 0;
          $271 = $270&1;
          if ($271) {
           break L1;
          }
         }
         $272 = HEAP32[$261>>2]|0;
         $273 = (($261) + 16|0);
         $274 = (($272) + 92|0);
         $275 = HEAP32[$274>>2]|0;
         $276 = ($275*5)|0;
         $277 = (($273) + ($276)|0);
         $278 = HEAP32[$277>>2]|0;
         $279 = ($278|0)==($conversionType|0);
         if ($279) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $280 = __THREW__; __THREW__ = 0;
          $281 = $280&1;
          if ($281) {
           break L1;
          }
          __THREW__ = 0;
          $282 = (invoke_iiii(1676,(2157040|0),($45|0),($provider|0))|0);
          $283 = __THREW__; __THREW__ = 0;
          $284 = $283&1;
          if ($284) {
           break L1;
          }
          HEAP8[$L_33>>0] = $282;
          __THREW__ = 0;
          (invoke_ii(2996,(2171616|0))|0);
          $285 = __THREW__; __THREW__ = 0;
          $286 = $285&1;
          if ($286) {
           break L1;
          }
          __THREW__ = 0;
          $287 = (invoke_iii(2724,(2171616|0),($L_33|0))|0);
          $288 = __THREW__; __THREW__ = 0;
          $289 = $288&1;
          if ($289) {
           break L1;
          }
          $$0 = $287;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $290 = __THREW__; __THREW__ = 0;
         $291 = $290&1;
         if ($291) {
          break L1;
         }
         $292 = HEAP8[((2581704 + 116|0))>>0]|0;
         $293 = ($292<<24>>24)==(0);
         if ($293) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $294 = __THREW__; __THREW__ = 0;
          $295 = $294&1;
          if ($295) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $296 = __THREW__; __THREW__ = 0;
          $297 = $296&1;
          if ($297) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $298 = __THREW__; __THREW__ = 0;
          $299 = $298&1;
          if ($299) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $300 = __THREW__; __THREW__ = 0;
         $301 = $300&1;
         if ($301) {
          break L1;
         }
         $302 = HEAP32[((2581704 + 80|0))>>2]|0;
         $303 = (($302) + 4|0);
         $304 = HEAP32[$303>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($304|0));
         $305 = __THREW__; __THREW__ = 0;
         $306 = $305&1;
         if ($306) {
          break L1;
         }
         $307 = (($304) + 12|0);
         $308 = HEAP32[$307>>2]|0;
         $309 = ($308>>>0)<(7);
         if ($309) {
          __THREW__ = 0;
          $310 = (invoke_i(132)|0);
          $311 = __THREW__; __THREW__ = 0;
          $312 = $311&1;
          if ($312) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($310|0));
          $313 = __THREW__; __THREW__ = 0;
          $314 = $313&1;
          if ($314) {
           break L1;
          }
         }
         $315 = HEAP32[$304>>2]|0;
         $316 = (($304) + 16|0);
         $317 = (($315) + 92|0);
         $318 = HEAP32[$317>>2]|0;
         $319 = ($318*6)|0;
         $320 = (($316) + ($319)|0);
         $321 = HEAP32[$320>>2]|0;
         $322 = ($321|0)==($conversionType|0);
         if ($322) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $323 = __THREW__; __THREW__ = 0;
          $324 = $323&1;
          if ($324) {
           break L1;
          }
          __THREW__ = 0;
          $325 = (invoke_iiii(1672,(2156440|0),($45|0),($provider|0))|0);
          $326 = __THREW__; __THREW__ = 0;
          $327 = $326&1;
          if ($327) {
           break L1;
          }
          HEAP8[$L_39>>0] = $325;
          __THREW__ = 0;
          (invoke_ii(2996,(2169424|0))|0);
          $328 = __THREW__; __THREW__ = 0;
          $329 = $328&1;
          if ($329) {
           break L1;
          }
          __THREW__ = 0;
          $330 = (invoke_iii(2724,(2169424|0),($L_39|0))|0);
          $331 = __THREW__; __THREW__ = 0;
          $332 = $331&1;
          if ($332) {
           break L1;
          }
          $$0 = $330;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $333 = __THREW__; __THREW__ = 0;
         $334 = $333&1;
         if ($334) {
          break L1;
         }
         $335 = HEAP8[((2581704 + 116|0))>>0]|0;
         $336 = ($335<<24>>24)==(0);
         if ($336) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $337 = __THREW__; __THREW__ = 0;
          $338 = $337&1;
          if ($338) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $339 = __THREW__; __THREW__ = 0;
          $340 = $339&1;
          if ($340) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $341 = __THREW__; __THREW__ = 0;
          $342 = $341&1;
          if ($342) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $343 = __THREW__; __THREW__ = 0;
         $344 = $343&1;
         if ($344) {
          break L1;
         }
         $345 = HEAP32[((2581704 + 80|0))>>2]|0;
         $346 = (($345) + 4|0);
         $347 = HEAP32[$346>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($347|0));
         $348 = __THREW__; __THREW__ = 0;
         $349 = $348&1;
         if ($349) {
          break L1;
         }
         $350 = (($347) + 12|0);
         $351 = HEAP32[$350>>2]|0;
         $352 = ($351>>>0)<(8);
         if ($352) {
          __THREW__ = 0;
          $353 = (invoke_i(132)|0);
          $354 = __THREW__; __THREW__ = 0;
          $355 = $354&1;
          if ($355) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($353|0));
          $356 = __THREW__; __THREW__ = 0;
          $357 = $356&1;
          if ($357) {
           break L1;
          }
         }
         $358 = HEAP32[$347>>2]|0;
         $359 = (($347) + 16|0);
         $360 = (($358) + 92|0);
         $361 = HEAP32[$360>>2]|0;
         $362 = ($361*7)|0;
         $363 = (($359) + ($362)|0);
         $364 = HEAP32[$363>>2]|0;
         $365 = ($364|0)==($conversionType|0);
         if ($365) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $366 = __THREW__; __THREW__ = 0;
          $367 = $366&1;
          if ($367) {
           break L1;
          }
          __THREW__ = 0;
          $368 = (invoke_iiii(1674,(2156824|0),($45|0),($provider|0))|0);
          $369 = __THREW__; __THREW__ = 0;
          $370 = $369&1;
          if ($370) {
           break L1;
          }
          HEAP16[$L_45>>1] = $368;
          __THREW__ = 0;
          (invoke_ii(2996,(2173776|0))|0);
          $371 = __THREW__; __THREW__ = 0;
          $372 = $371&1;
          if ($372) {
           break L1;
          }
          __THREW__ = 0;
          $373 = (invoke_iii(2724,(2173776|0),($L_45|0))|0);
          $374 = __THREW__; __THREW__ = 0;
          $375 = $374&1;
          if ($375) {
           break L1;
          }
          $$0 = $373;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $376 = __THREW__; __THREW__ = 0;
         $377 = $376&1;
         if ($377) {
          break L1;
         }
         $378 = HEAP8[((2581704 + 116|0))>>0]|0;
         $379 = ($378<<24>>24)==(0);
         if ($379) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $380 = __THREW__; __THREW__ = 0;
          $381 = $380&1;
          if ($381) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $382 = __THREW__; __THREW__ = 0;
          $383 = $382&1;
          if ($383) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $384 = __THREW__; __THREW__ = 0;
          $385 = $384&1;
          if ($385) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $386 = __THREW__; __THREW__ = 0;
         $387 = $386&1;
         if ($387) {
          break L1;
         }
         $388 = HEAP32[((2581704 + 80|0))>>2]|0;
         $389 = (($388) + 4|0);
         $390 = HEAP32[$389>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($390|0));
         $391 = __THREW__; __THREW__ = 0;
         $392 = $391&1;
         if ($392) {
          break L1;
         }
         $393 = (($390) + 12|0);
         $394 = HEAP32[$393>>2]|0;
         $395 = ($394>>>0)<(9);
         if ($395) {
          __THREW__ = 0;
          $396 = (invoke_i(132)|0);
          $397 = __THREW__; __THREW__ = 0;
          $398 = $397&1;
          if ($398) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($396|0));
          $399 = __THREW__; __THREW__ = 0;
          $400 = $399&1;
          if ($400) {
           break L1;
          }
         }
         $401 = HEAP32[$390>>2]|0;
         $402 = (($390) + 16|0);
         $403 = (($401) + 92|0);
         $404 = HEAP32[$403>>2]|0;
         $405 = $404 << 3;
         $406 = (($402) + ($405)|0);
         $407 = HEAP32[$406>>2]|0;
         $408 = ($407|0)==($conversionType|0);
         if ($408) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $409 = __THREW__; __THREW__ = 0;
          $410 = $409&1;
          if ($410) {
           break L1;
          }
          __THREW__ = 0;
          $411 = (invoke_iiii(1677,(2157344|0),($45|0),($provider|0))|0);
          $412 = __THREW__; __THREW__ = 0;
          $413 = $412&1;
          if ($413) {
           break L1;
          }
          HEAP16[$L_51>>1] = $411;
          __THREW__ = 0;
          (invoke_ii(2996,(2176024|0))|0);
          $414 = __THREW__; __THREW__ = 0;
          $415 = $414&1;
          if ($415) {
           break L1;
          }
          __THREW__ = 0;
          $416 = (invoke_iii(2724,(2176024|0),($L_51|0))|0);
          $417 = __THREW__; __THREW__ = 0;
          $418 = $417&1;
          if ($418) {
           break L1;
          }
          $$0 = $416;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $419 = __THREW__; __THREW__ = 0;
         $420 = $419&1;
         if ($420) {
          break L1;
         }
         $421 = HEAP8[((2581704 + 116|0))>>0]|0;
         $422 = ($421<<24>>24)==(0);
         if ($422) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $423 = __THREW__; __THREW__ = 0;
          $424 = $423&1;
          if ($424) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $425 = __THREW__; __THREW__ = 0;
          $426 = $425&1;
          if ($426) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $427 = __THREW__; __THREW__ = 0;
          $428 = $427&1;
          if ($428) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $429 = __THREW__; __THREW__ = 0;
         $430 = $429&1;
         if ($430) {
          break L1;
         }
         $431 = HEAP32[((2581704 + 80|0))>>2]|0;
         $432 = (($431) + 4|0);
         $433 = HEAP32[$432>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($433|0));
         $434 = __THREW__; __THREW__ = 0;
         $435 = $434&1;
         if ($435) {
          break L1;
         }
         $436 = (($433) + 12|0);
         $437 = HEAP32[$436>>2]|0;
         $438 = ($437>>>0)<(10);
         if ($438) {
          __THREW__ = 0;
          $439 = (invoke_i(132)|0);
          $440 = __THREW__; __THREW__ = 0;
          $441 = $440&1;
          if ($441) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($439|0));
          $442 = __THREW__; __THREW__ = 0;
          $443 = $442&1;
          if ($443) {
           break L1;
          }
         }
         $444 = HEAP32[$433>>2]|0;
         $445 = (($433) + 16|0);
         $446 = (($444) + 92|0);
         $447 = HEAP32[$446>>2]|0;
         $448 = ($447*9)|0;
         $449 = (($445) + ($448)|0);
         $450 = HEAP32[$449>>2]|0;
         $451 = ($450|0)==($conversionType|0);
         if ($451) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $452 = __THREW__; __THREW__ = 0;
          $453 = $452&1;
          if ($453) {
           break L1;
          }
          __THREW__ = 0;
          $454 = (invoke_iiii(1652,(2156896|0),($45|0),($provider|0))|0);
          $455 = __THREW__; __THREW__ = 0;
          $456 = $455&1;
          if ($456) {
           break L1;
          }
          HEAP32[$L_57>>2] = $454;
          __THREW__ = 0;
          (invoke_ii(2996,(2155952|0))|0);
          $457 = __THREW__; __THREW__ = 0;
          $458 = $457&1;
          if ($458) {
           break L1;
          }
          __THREW__ = 0;
          $459 = (invoke_iii(2724,(2155952|0),($L_57|0))|0);
          $460 = __THREW__; __THREW__ = 0;
          $461 = $460&1;
          if ($461) {
           break L1;
          }
          $$0 = $459;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $462 = __THREW__; __THREW__ = 0;
         $463 = $462&1;
         if ($463) {
          break L1;
         }
         $464 = HEAP8[((2581704 + 116|0))>>0]|0;
         $465 = ($464<<24>>24)==(0);
         if ($465) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $466 = __THREW__; __THREW__ = 0;
          $467 = $466&1;
          if ($467) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $468 = __THREW__; __THREW__ = 0;
          $469 = $468&1;
          if ($469) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $470 = __THREW__; __THREW__ = 0;
          $471 = $470&1;
          if ($471) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $472 = __THREW__; __THREW__ = 0;
         $473 = $472&1;
         if ($473) {
          break L1;
         }
         $474 = HEAP32[((2581704 + 80|0))>>2]|0;
         $475 = (($474) + 4|0);
         $476 = HEAP32[$475>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($476|0));
         $477 = __THREW__; __THREW__ = 0;
         $478 = $477&1;
         if ($478) {
          break L1;
         }
         $479 = (($476) + 12|0);
         $480 = HEAP32[$479>>2]|0;
         $481 = ($480>>>0)<(11);
         if ($481) {
          __THREW__ = 0;
          $482 = (invoke_i(132)|0);
          $483 = __THREW__; __THREW__ = 0;
          $484 = $483&1;
          if ($484) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($482|0));
          $485 = __THREW__; __THREW__ = 0;
          $486 = $485&1;
          if ($486) {
           break L1;
          }
         }
         $487 = HEAP32[$476>>2]|0;
         $488 = (($476) + 16|0);
         $489 = (($487) + 92|0);
         $490 = HEAP32[$489>>2]|0;
         $491 = ($490*10)|0;
         $492 = (($488) + ($491)|0);
         $493 = HEAP32[$492>>2]|0;
         $494 = ($493|0)==($conversionType|0);
         if ($494) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $495 = __THREW__; __THREW__ = 0;
          $496 = $495&1;
          if ($496) {
           break L1;
          }
          __THREW__ = 0;
          $497 = (invoke_iiii(1678,(2157424|0),($45|0),($provider|0))|0);
          $498 = __THREW__; __THREW__ = 0;
          $499 = $498&1;
          if ($499) {
           break L1;
          }
          HEAP32[$L_63>>2] = $497;
          __THREW__ = 0;
          (invoke_ii(2996,(2164560|0))|0);
          $500 = __THREW__; __THREW__ = 0;
          $501 = $500&1;
          if ($501) {
           break L1;
          }
          __THREW__ = 0;
          $502 = (invoke_iii(2724,(2164560|0),($L_63|0))|0);
          $503 = __THREW__; __THREW__ = 0;
          $504 = $503&1;
          if ($504) {
           break L1;
          }
          $$0 = $502;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $505 = __THREW__; __THREW__ = 0;
         $506 = $505&1;
         if ($506) {
          break L1;
         }
         $507 = HEAP8[((2581704 + 116|0))>>0]|0;
         $508 = ($507<<24>>24)==(0);
         if ($508) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $509 = __THREW__; __THREW__ = 0;
          $510 = $509&1;
          if ($510) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $511 = __THREW__; __THREW__ = 0;
          $512 = $511&1;
          if ($512) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $513 = __THREW__; __THREW__ = 0;
          $514 = $513&1;
          if ($514) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $515 = __THREW__; __THREW__ = 0;
         $516 = $515&1;
         if ($516) {
          break L1;
         }
         $517 = HEAP32[((2581704 + 80|0))>>2]|0;
         $518 = (($517) + 4|0);
         $519 = HEAP32[$518>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($519|0));
         $520 = __THREW__; __THREW__ = 0;
         $521 = $520&1;
         if ($521) {
          break L1;
         }
         $522 = (($519) + 12|0);
         $523 = HEAP32[$522>>2]|0;
         $524 = ($523>>>0)<(12);
         if ($524) {
          __THREW__ = 0;
          $525 = (invoke_i(132)|0);
          $526 = __THREW__; __THREW__ = 0;
          $527 = $526&1;
          if ($527) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($525|0));
          $528 = __THREW__; __THREW__ = 0;
          $529 = $528&1;
          if ($529) {
           break L1;
          }
         }
         $530 = HEAP32[$519>>2]|0;
         $531 = (($519) + 16|0);
         $532 = (($530) + 92|0);
         $533 = HEAP32[$532>>2]|0;
         $534 = ($533*11)|0;
         $535 = (($531) + ($534)|0);
         $536 = HEAP32[$535>>2]|0;
         $537 = ($536|0)==($conversionType|0);
         if ($537) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $538 = __THREW__; __THREW__ = 0;
          $539 = $538&1;
          if ($539) {
           break L1;
          }
          __THREW__ = 0;
          $540 = (invoke_iiii(1675,(2156968|0),($45|0),($provider|0))|0);
          $541 = tempRet0;
          $542 = __THREW__; __THREW__ = 0;
          $543 = $542&1;
          if ($543) {
           break L1;
          }
          $544 = $L_69;
          $545 = $544;
          HEAP32[$545>>2] = $540;
          $546 = (($544) + 4)|0;
          $547 = $546;
          HEAP32[$547>>2] = $541;
          __THREW__ = 0;
          (invoke_ii(2996,(2162248|0))|0);
          $548 = __THREW__; __THREW__ = 0;
          $549 = $548&1;
          if ($549) {
           break L1;
          }
          __THREW__ = 0;
          $550 = (invoke_iii(2724,(2162248|0),($L_69|0))|0);
          $551 = __THREW__; __THREW__ = 0;
          $552 = $551&1;
          if ($552) {
           break L1;
          }
          $$0 = $550;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $553 = __THREW__; __THREW__ = 0;
         $554 = $553&1;
         if ($554) {
          break L1;
         }
         $555 = HEAP8[((2581704 + 116|0))>>0]|0;
         $556 = ($555<<24>>24)==(0);
         if ($556) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $557 = __THREW__; __THREW__ = 0;
          $558 = $557&1;
          if ($558) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $559 = __THREW__; __THREW__ = 0;
          $560 = $559&1;
          if ($560) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $561 = __THREW__; __THREW__ = 0;
          $562 = $561&1;
          if ($562) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $563 = __THREW__; __THREW__ = 0;
         $564 = $563&1;
         if ($564) {
          break L1;
         }
         $565 = HEAP32[((2581704 + 80|0))>>2]|0;
         $566 = (($565) + 4|0);
         $567 = HEAP32[$566>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($567|0));
         $568 = __THREW__; __THREW__ = 0;
         $569 = $568&1;
         if ($569) {
          break L1;
         }
         $570 = (($567) + 12|0);
         $571 = HEAP32[$570>>2]|0;
         $572 = ($571>>>0)<(13);
         if ($572) {
          __THREW__ = 0;
          $573 = (invoke_i(132)|0);
          $574 = __THREW__; __THREW__ = 0;
          $575 = $574&1;
          if ($575) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($573|0));
          $576 = __THREW__; __THREW__ = 0;
          $577 = $576&1;
          if ($577) {
           break L1;
          }
         }
         $578 = HEAP32[$567>>2]|0;
         $579 = (($567) + 16|0);
         $580 = (($578) + 92|0);
         $581 = HEAP32[$580>>2]|0;
         $582 = ($581*12)|0;
         $583 = (($579) + ($582)|0);
         $584 = HEAP32[$583>>2]|0;
         $585 = ($584|0)==($conversionType|0);
         if ($585) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $586 = __THREW__; __THREW__ = 0;
          $587 = $586&1;
          if ($587) {
           break L1;
          }
          __THREW__ = 0;
          $588 = (invoke_iiii(1679,(2157504|0),($45|0),($provider|0))|0);
          $589 = tempRet0;
          $590 = __THREW__; __THREW__ = 0;
          $591 = $590&1;
          if ($591) {
           break L1;
          }
          $592 = $L_75;
          $593 = $592;
          HEAP32[$593>>2] = $588;
          $594 = (($592) + 4)|0;
          $595 = $594;
          HEAP32[$595>>2] = $589;
          __THREW__ = 0;
          (invoke_ii(2996,(2167208|0))|0);
          $596 = __THREW__; __THREW__ = 0;
          $597 = $596&1;
          if ($597) {
           break L1;
          }
          __THREW__ = 0;
          $598 = (invoke_iii(2724,(2167208|0),($L_75|0))|0);
          $599 = __THREW__; __THREW__ = 0;
          $600 = $599&1;
          if ($600) {
           break L1;
          }
          $$0 = $598;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $601 = __THREW__; __THREW__ = 0;
         $602 = $601&1;
         if ($602) {
          break L1;
         }
         $603 = HEAP8[((2581704 + 116|0))>>0]|0;
         $604 = ($603<<24>>24)==(0);
         if ($604) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $605 = __THREW__; __THREW__ = 0;
          $606 = $605&1;
          if ($606) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $607 = __THREW__; __THREW__ = 0;
          $608 = $607&1;
          if ($608) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $609 = __THREW__; __THREW__ = 0;
          $610 = $609&1;
          if ($610) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $611 = __THREW__; __THREW__ = 0;
         $612 = $611&1;
         if ($612) {
          break L1;
         }
         $613 = HEAP32[((2581704 + 80|0))>>2]|0;
         $614 = (($613) + 4|0);
         $615 = HEAP32[$614>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($615|0));
         $616 = __THREW__; __THREW__ = 0;
         $617 = $616&1;
         if ($617) {
          break L1;
         }
         $618 = (($615) + 12|0);
         $619 = HEAP32[$618>>2]|0;
         $620 = ($619>>>0)<(14);
         if ($620) {
          __THREW__ = 0;
          $621 = (invoke_i(132)|0);
          $622 = __THREW__; __THREW__ = 0;
          $623 = $622&1;
          if ($623) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($621|0));
          $624 = __THREW__; __THREW__ = 0;
          $625 = $624&1;
          if ($625) {
           break L1;
          }
         }
         $626 = HEAP32[$615>>2]|0;
         $627 = (($615) + 16|0);
         $628 = (($626) + 92|0);
         $629 = HEAP32[$628>>2]|0;
         $630 = ($629*13)|0;
         $631 = (($627) + ($630)|0);
         $632 = HEAP32[$631>>2]|0;
         $633 = ($632|0)==($conversionType|0);
         if ($633) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $634 = __THREW__; __THREW__ = 0;
          $635 = $634&1;
          if ($635) {
           break L1;
          }
          __THREW__ = 0;
          $636 = (Math_fround(+(invoke_fiii(17,(2157120|0),($45|0),($provider|0)))));
          $637 = __THREW__; __THREW__ = 0;
          $638 = $637&1;
          if ($638) {
           break L1;
          }
          HEAPF32[$L_81>>2] = $636;
          __THREW__ = 0;
          (invoke_ii(2996,(2194912|0))|0);
          $639 = __THREW__; __THREW__ = 0;
          $640 = $639&1;
          if ($640) {
           break L1;
          }
          __THREW__ = 0;
          $641 = (invoke_iii(2724,(2194912|0),($L_81|0))|0);
          $642 = __THREW__; __THREW__ = 0;
          $643 = $642&1;
          if ($643) {
           break L1;
          }
          $$0 = $641;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $644 = __THREW__; __THREW__ = 0;
         $645 = $644&1;
         if ($645) {
          break L1;
         }
         $646 = HEAP8[((2581704 + 116|0))>>0]|0;
         $647 = ($646<<24>>24)==(0);
         if ($647) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $648 = __THREW__; __THREW__ = 0;
          $649 = $648&1;
          if ($649) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $650 = __THREW__; __THREW__ = 0;
          $651 = $650&1;
          if ($651) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $652 = __THREW__; __THREW__ = 0;
          $653 = $652&1;
          if ($653) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $654 = __THREW__; __THREW__ = 0;
         $655 = $654&1;
         if ($655) {
          break L1;
         }
         $656 = HEAP32[((2581704 + 80|0))>>2]|0;
         $657 = (($656) + 4|0);
         $658 = HEAP32[$657>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($658|0));
         $659 = __THREW__; __THREW__ = 0;
         $660 = $659&1;
         if ($660) {
          break L1;
         }
         $661 = (($658) + 12|0);
         $662 = HEAP32[$661>>2]|0;
         $663 = ($662>>>0)<(15);
         if ($663) {
          __THREW__ = 0;
          $664 = (invoke_i(132)|0);
          $665 = __THREW__; __THREW__ = 0;
          $666 = $665&1;
          if ($666) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($664|0));
          $667 = __THREW__; __THREW__ = 0;
          $668 = $667&1;
          if ($668) {
           break L1;
          }
         }
         $669 = HEAP32[$658>>2]|0;
         $670 = (($658) + 16|0);
         $671 = (($669) + 92|0);
         $672 = HEAP32[$671>>2]|0;
         $673 = ($672*14)|0;
         $674 = (($670) + ($673)|0);
         $675 = HEAP32[$674>>2]|0;
         $676 = ($675|0)==($conversionType|0);
         if ($676) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $677 = __THREW__; __THREW__ = 0;
          $678 = $677&1;
          if ($678) {
           break L1;
          }
          __THREW__ = 0;
          $679 = (+invoke_diii(6,(2156752|0),($45|0),($provider|0)));
          $680 = __THREW__; __THREW__ = 0;
          $681 = $680&1;
          if ($681) {
           break L1;
          }
          HEAPF64[$L_87>>3] = $679;
          __THREW__ = 0;
          (invoke_ii(2996,(2198192|0))|0);
          $682 = __THREW__; __THREW__ = 0;
          $683 = $682&1;
          if ($683) {
           break L1;
          }
          __THREW__ = 0;
          $684 = (invoke_iii(2724,(2198192|0),($L_87|0))|0);
          $685 = __THREW__; __THREW__ = 0;
          $686 = $685&1;
          if ($686) {
           break L1;
          }
          $$0 = $684;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $687 = __THREW__; __THREW__ = 0;
         $688 = $687&1;
         if ($688) {
          break L1;
         }
         $689 = HEAP8[((2581704 + 116|0))>>0]|0;
         $690 = ($689<<24>>24)==(0);
         if ($690) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $691 = __THREW__; __THREW__ = 0;
          $692 = $691&1;
          if ($692) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $693 = __THREW__; __THREW__ = 0;
          $694 = $693&1;
          if ($694) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $695 = __THREW__; __THREW__ = 0;
          $696 = $695&1;
          if ($696) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $697 = __THREW__; __THREW__ = 0;
         $698 = $697&1;
         if ($698) {
          break L1;
         }
         $699 = HEAP32[((2581704 + 80|0))>>2]|0;
         $700 = (($699) + 4|0);
         $701 = HEAP32[$700>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($701|0));
         $702 = __THREW__; __THREW__ = 0;
         $703 = $702&1;
         if ($703) {
          break L1;
         }
         $704 = (($701) + 12|0);
         $705 = HEAP32[$704>>2]|0;
         $706 = ($705>>>0)<(16);
         if ($706) {
          __THREW__ = 0;
          $707 = (invoke_i(132)|0);
          $708 = __THREW__; __THREW__ = 0;
          $709 = $708&1;
          if ($709) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($707|0));
          $710 = __THREW__; __THREW__ = 0;
          $711 = $710&1;
          if ($711) {
           break L1;
          }
         }
         $712 = HEAP32[$701>>2]|0;
         $713 = (($701) + 16|0);
         $714 = (($712) + 92|0);
         $715 = HEAP32[$714>>2]|0;
         $716 = ($715*15)|0;
         $717 = (($713) + ($716)|0);
         $718 = HEAP32[$717>>2]|0;
         $719 = ($718|0)==($conversionType|0);
         if ($719) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $720 = __THREW__; __THREW__ = 0;
          $721 = $720&1;
          if ($721) {
           break L1;
          }
          __THREW__ = 0;
          invoke_viiii(475,($L_92|0),(2156672|0),($45|0),($provider|0));
          $722 = __THREW__; __THREW__ = 0;
          $723 = $722&1;
          if ($723) {
           break L1;
          }
          ;HEAP32[$L_93+0>>2]=HEAP32[$L_92+0>>2]|0;HEAP32[$L_93+4>>2]=HEAP32[$L_92+4>>2]|0;HEAP32[$L_93+8>>2]=HEAP32[$L_92+8>>2]|0;HEAP32[$L_93+12>>2]=HEAP32[$L_92+12>>2]|0;
          __THREW__ = 0;
          (invoke_ii(2996,(2206536|0))|0);
          $724 = __THREW__; __THREW__ = 0;
          $725 = $724&1;
          if ($725) {
           break L1;
          }
          __THREW__ = 0;
          $726 = (invoke_iii(2724,(2206536|0),($L_93|0))|0);
          $727 = __THREW__; __THREW__ = 0;
          $728 = $727&1;
          if ($728) {
           break L1;
          }
          $$0 = $726;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $729 = __THREW__; __THREW__ = 0;
         $730 = $729&1;
         if ($730) {
          break L1;
         }
         $731 = HEAP8[((2581704 + 116|0))>>0]|0;
         $732 = ($731<<24>>24)==(0);
         if ($732) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $733 = __THREW__; __THREW__ = 0;
          $734 = $733&1;
          if ($734) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $735 = __THREW__; __THREW__ = 0;
          $736 = $735&1;
          if ($736) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $737 = __THREW__; __THREW__ = 0;
          $738 = $737&1;
          if ($738) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $739 = __THREW__; __THREW__ = 0;
         $740 = $739&1;
         if ($740) {
          break L1;
         }
         $741 = HEAP32[((2581704 + 80|0))>>2]|0;
         $742 = (($741) + 4|0);
         $743 = HEAP32[$742>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($743|0));
         $744 = __THREW__; __THREW__ = 0;
         $745 = $744&1;
         if ($745) {
          break L1;
         }
         $746 = (($743) + 12|0);
         $747 = HEAP32[$746>>2]|0;
         $748 = ($747>>>0)<(17);
         if ($748) {
          __THREW__ = 0;
          $749 = (invoke_i(132)|0);
          $750 = __THREW__; __THREW__ = 0;
          $751 = $750&1;
          if ($751) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($749|0));
          $752 = __THREW__; __THREW__ = 0;
          $753 = $752&1;
          if ($753) {
           break L1;
          }
         }
         $754 = HEAP32[$743>>2]|0;
         $755 = (($743) + 16|0);
         $756 = (($754) + 92|0);
         $757 = HEAP32[$756>>2]|0;
         $758 = (($755) + ($757<<4)|0);
         $759 = HEAP32[$758>>2]|0;
         $760 = ($759|0)==($conversionType|0);
         if ($760) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $761 = __THREW__; __THREW__ = 0;
          $762 = $761&1;
          if ($762) {
           break L1;
          }
          __THREW__ = 0;
          invoke_viiii(474,($L_98|0),(2156592|0),($45|0),($provider|0));
          $763 = __THREW__; __THREW__ = 0;
          $764 = $763&1;
          if ($764) {
           break L1;
          }
          ;HEAP32[$L_99+0>>2]=HEAP32[$L_98+0>>2]|0;HEAP32[$L_99+4>>2]=HEAP32[$L_98+4>>2]|0;HEAP32[$L_99+8>>2]=HEAP32[$L_98+8>>2]|0;HEAP32[$L_99+12>>2]=HEAP32[$L_98+12>>2]|0;
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $765 = __THREW__; __THREW__ = 0;
          $766 = $765&1;
          if ($766) {
           break L1;
          }
          __THREW__ = 0;
          $767 = (invoke_iii(2724,(2592096|0),($L_99|0))|0);
          $768 = __THREW__; __THREW__ = 0;
          $769 = $768&1;
          if ($769) {
           break L1;
          }
          $$0 = $767;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $770 = __THREW__; __THREW__ = 0;
         $771 = $770&1;
         if ($771) {
          break L1;
         }
         $772 = HEAP8[((2581704 + 116|0))>>0]|0;
         $773 = ($772<<24>>24)==(0);
         if ($773) {
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $774 = __THREW__; __THREW__ = 0;
          $775 = $774&1;
          if ($775) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2581704|0))|0);
          $776 = __THREW__; __THREW__ = 0;
          $777 = $776&1;
          if ($777) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2581704|0));
          $778 = __THREW__; __THREW__ = 0;
          $779 = $778&1;
          if ($779) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2581704|0))|0);
         $780 = __THREW__; __THREW__ = 0;
         $781 = $780&1;
         if ($781) {
          break L1;
         }
         $782 = HEAP32[((2581704 + 80|0))>>2]|0;
         $783 = (($782) + 4|0);
         $784 = HEAP32[$783>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($784|0));
         $785 = __THREW__; __THREW__ = 0;
         $786 = $785&1;
         if ($786) {
          break L1;
         }
         $787 = (($784) + 12|0);
         $788 = HEAP32[$787>>2]|0;
         $789 = ($788>>>0)<(19);
         if ($789) {
          __THREW__ = 0;
          $790 = (invoke_i(132)|0);
          $791 = __THREW__; __THREW__ = 0;
          $792 = $791&1;
          if ($792) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($790|0));
          $793 = __THREW__; __THREW__ = 0;
          $794 = $793&1;
          if ($794) {
           break L1;
          }
         }
         $795 = HEAP32[$784>>2]|0;
         $796 = (($784) + 16|0);
         $797 = (($795) + 92|0);
         $798 = HEAP32[$797>>2]|0;
         $799 = ($798*18)|0;
         $800 = (($796) + ($799)|0);
         $801 = HEAP32[$800>>2]|0;
         $802 = ($801|0)==($conversionType|0);
         if ($802) {
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $803 = __THREW__; __THREW__ = 0;
          $804 = $803&1;
          if ($804) {
           break L1;
          }
          __THREW__ = 0;
          $805 = (invoke_iiii(1680,(2157184|0),($45|0),($provider|0))|0);
          $806 = __THREW__; __THREW__ = 0;
          $807 = $806&1;
          if ($807) {
           break L1;
          }
          $$0 = $805;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         } else {
          if (!($try_target_to_type)) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $808 = __THREW__; __THREW__ = 0;
          $809 = $808&1;
          if ($809) {
           break L1;
          }
          __THREW__ = 0;
          $810 = (invoke_iiiii(327,(2157264|0),($45|0),($conversionType|0),($provider|0))|0);
          $811 = __THREW__; __THREW__ = 0;
          $812 = $811&1;
          if ($812) {
           break L1;
          } else {
           $$0 = $810;
          }
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($value|0));
       $813 = __THREW__; __THREW__ = 0;
       $814 = $813&1;
       if (!($814)) {
        __THREW__ = 0;
        $815 = (invoke_ii(1782,($value|0))|0);
        $816 = __THREW__; __THREW__ = 0;
        $817 = $816&1;
        if (!($817)) {
         __THREW__ = 0;
         invoke_vi(3799,($815|0));
         $818 = __THREW__; __THREW__ = 0;
         $819 = $818&1;
         if (!($819)) {
          __THREW__ = 0;
          $820 = (invoke_iii(2730,(2149160|0),($815|0))|0);
          $821 = __THREW__; __THREW__ = 0;
          $822 = $821&1;
          if (!($822)) {
           __THREW__ = 0;
           invoke_vi(3799,($conversionType|0));
           $823 = __THREW__; __THREW__ = 0;
           $824 = $823&1;
           if (!($824)) {
            __THREW__ = 0;
            $825 = (invoke_iii(2730,(2150320|0),($conversionType|0))|0);
            $826 = __THREW__; __THREW__ = 0;
            $827 = $826&1;
            if (!($827)) {
             $828 = HEAP32[3065976>>2]|0;
             $829 = HEAP32[3065984>>2]|0;
             __THREW__ = 0;
             $830 = (invoke_iiiiii(89,(0|0),($828|0),($820|0),($829|0),($825|0))|0);
             $831 = __THREW__; __THREW__ = 0;
             $832 = $831&1;
             if (!($832)) {
              __THREW__ = 0;
              $833 = (invoke_iii(783,(0|0),($830|0))|0);
              $834 = __THREW__; __THREW__ = 0;
              $835 = $834&1;
              if (!($835)) {
               __THREW__ = 0;
               (invoke_ii(2996,(2607384|0))|0);
               $836 = __THREW__; __THREW__ = 0;
               $837 = $836&1;
               if (!($837)) {
                __THREW__ = 0;
                $838 = (invoke_ii(3469,(2607384|0))|0);
                $839 = __THREW__; __THREW__ = 0;
                $840 = $839&1;
                if (!($840)) {
                 __THREW__ = 0;
                 invoke_vii(1946,($838|0),($833|0));
                 $841 = __THREW__; __THREW__ = 0;
                 $842 = $841&1;
                 if ($842) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3838,($838|0));
                 $843 = __THREW__; __THREW__ = 0;
                 $844 = $843&1;
                 if ($844) {
                  break;
                 }
                 // unreachable;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker1I17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS4_($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN21InterfaceFuncInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits29mscorlib_System_BooleanTraitsE6InvokeEPFhPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits26mscorlib_System_CharTraitsE6InvokeEPFhPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_DoubleTraitsE6InvokeEPFhPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_SingleTraitsE6InvokeEPFhPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits27mscorlib_System_Int64TraitsE6InvokeEPFhPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits27mscorlib_System_SByteTraitsE6InvokeEPFhPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits27mscorlib_System_Int16TraitsE6InvokeEPFhPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_UInt32TraitsE6InvokeEPFhPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_UInt64TraitsE6InvokeEPFhPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_UInt16TraitsE6InvokeEPFhPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I26mscorlib_System_ByteTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFhPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2169424,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits26mscorlib_System_ByteTraitsE6InvokeEPFtPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits27mscorlib_System_Int64TraitsE6InvokeEPFtPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP16[$ret>>1] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits28mscorlib_System_SingleTraitsE6InvokeEPFtPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits27mscorlib_System_SByteTraitsE6InvokeEPFtPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits27mscorlib_System_Int16TraitsE6InvokeEPFtPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I26mscorlib_System_CharTraits17VoidPointerTraitsS1_E6InvokeEPFtPvS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP16[$ret>>1] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits28mscorlib_System_UInt32TraitsE6InvokeEPFtPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits28mscorlib_System_UInt64TraitsE6InvokeEPFtPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP16[$ret>>1] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I26mscorlib_System_CharTraits28mscorlib_System_UInt16TraitsE6InvokeEPFtPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I26mscorlib_System_CharTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFtPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP16[$ret>>1] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2180696,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I30mscorlib_System_DateTimeTraits17VoidPointerTraitsS1_E6InvokeEPF24mscorlib_System_DateTimePvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits27mscorlib_System_Int16TraitsE6InvokeEPF24mscorlib_System_DateTimePvsES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits27mscorlib_System_Int32TraitsE6InvokeEPF24mscorlib_System_DateTimePviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits27mscorlib_System_Int64TraitsE6InvokeEPF24mscorlib_System_DateTimePvxES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$3,$6);
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_SingleTraitsE6InvokeEPF24mscorlib_System_DateTimePvfES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 FUNCTION_TABLE_viif[$func & 63]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker2I30mscorlib_System_DateTimeTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPF24mscorlib_System_DateTimePvP22mscorlib_System_ObjectS5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits27mscorlib_System_SByteTraitsE6InvokeEPF24mscorlib_System_DateTimePvaES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_UInt16TraitsE6InvokeEPF24mscorlib_System_DateTimePvtES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_UInt32TraitsE6InvokeEPF24mscorlib_System_DateTimePvjES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_UInt64TraitsE6InvokeEPF24mscorlib_System_DateTimePvyES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$3,$6);
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_DecimalTraits29mscorlib_System_BooleanTraitsE6InvokeEPF23mscorlib_System_DecimalPvbES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_DecimalTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPF23mscorlib_System_DecimalPvP22mscorlib_System_ObjectS5_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2206536,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits29mscorlib_System_BooleanTraitsE6InvokeEPFdPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$2));
 HEAPF64[$ret>>3] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits26mscorlib_System_ByteTraitsE6InvokeEPFdPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$1));
 HEAPF64[$ret>>3] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraitsS0_E6InvokeEPFdPvdES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (+FUNCTION_TABLE_did[$func & 15]($obj,$1));
 HEAPF64[$ret>>3] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits28mscorlib_System_SingleTraitsE6InvokeEPFdPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0.0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (+FUNCTION_TABLE_dif[$func & 1]($obj,$1));
 HEAPF64[$ret>>3] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits27mscorlib_System_Int32TraitsE6InvokeEPFdPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$1));
 HEAPF64[$ret>>3] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits27mscorlib_System_Int64TraitsE6InvokeEPFdPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (+FUNCTION_TABLE_diii[$func & 15]($obj,$3,$6));
 HEAPF64[$ret>>3] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits27mscorlib_System_SByteTraitsE6InvokeEPFdPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$1));
 HEAPF64[$ret>>3] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits27mscorlib_System_Int16TraitsE6InvokeEPFdPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$1));
 HEAPF64[$ret>>3] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits28mscorlib_System_UInt32TraitsE6InvokeEPFdPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$1));
 HEAPF64[$ret>>3] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits28mscorlib_System_UInt64TraitsE6InvokeEPFdPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (+FUNCTION_TABLE_diii[$func & 15]($obj,$3,$6));
 HEAPF64[$ret>>3] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_DoubleTraits28mscorlib_System_UInt16TraitsE6InvokeEPFdPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (+FUNCTION_TABLE_dii[$func & 31]($obj,$1));
 HEAPF64[$ret>>3] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_DoubleTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFdPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (+FUNCTION_TABLE_diii[$func & 15]($obj,$0,$2));
 HEAPF64[$ret>>3] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits29mscorlib_System_BooleanTraitsE6InvokeEPFsPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 HEAP16[$ret>>1] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits26mscorlib_System_ByteTraitsE6InvokeEPFsPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits26mscorlib_System_CharTraitsE6InvokeEPFsPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_DoubleTraitsE6InvokeEPFsPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_SingleTraitsE6InvokeEPFsPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits27mscorlib_System_Int32TraitsE6InvokeEPFsPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits27mscorlib_System_Int64TraitsE6InvokeEPFsPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP16[$ret>>1] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits27mscorlib_System_SByteTraitsE6InvokeEPFsPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16TraitsS0_E6InvokeEPFsPvsES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_UInt32TraitsE6InvokeEPFsPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_UInt64TraitsE6InvokeEPFsPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP16[$ret>>1] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_UInt16TraitsE6InvokeEPFsPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int16Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFsPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP16[$ret>>1] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2173776,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits29mscorlib_System_BooleanTraitsE6InvokeEPFxPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 $4 = tempRet0;
 $5 = $ret;
 $6 = $5;
 HEAP32[$6>>2] = $3;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $4;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits26mscorlib_System_ByteTraitsE6InvokeEPFxPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits26mscorlib_System_CharTraitsE6InvokeEPFxPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_SingleTraitsE6InvokeEPFxPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64TraitsS0_E6InvokeEPFxPvxES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 $8 = tempRet0;
 $9 = $ret;
 $10 = $9;
 HEAP32[$10>>2] = $7;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits27mscorlib_System_SByteTraitsE6InvokeEPFxPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits27mscorlib_System_Int16TraitsE6InvokeEPFxPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_UInt32TraitsE6InvokeEPFxPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_UInt64TraitsE6InvokeEPFxPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 $8 = tempRet0;
 $9 = $ret;
 $10 = $9;
 HEAP32[$10>>2] = $7;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_UInt16TraitsE6InvokeEPFxPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_ObjectTraitsE6InvokeEPFxPvP22mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 $2 = tempRet0;
 $3 = $ret;
 $4 = $3;
 HEAP32[$4>>2] = $1;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int64Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFxPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 $4 = tempRet0;
 $5 = $ret;
 $6 = $5;
 HEAP32[$6>>2] = $3;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $4;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits29mscorlib_System_BooleanTraitsE6InvokeEPFaPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits26mscorlib_System_ByteTraitsE6InvokeEPFaPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits26mscorlib_System_CharTraitsE6InvokeEPFaPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_DoubleTraitsE6InvokeEPFaPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_SingleTraitsE6InvokeEPFaPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits27mscorlib_System_Int32TraitsE6InvokeEPFaPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits27mscorlib_System_Int64TraitsE6InvokeEPFaPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits27mscorlib_System_Int16TraitsE6InvokeEPFaPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_UInt32TraitsE6InvokeEPFaPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_UInt64TraitsE6InvokeEPFaPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_UInt16TraitsE6InvokeEPFaPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_SByteTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFaPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP8[$ret>>0] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2171616,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits26mscorlib_System_ByteTraitsE6InvokeEPFfPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$1)));
 HEAPF32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits28mscorlib_System_DoubleTraitsE6InvokeEPFfPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = Math_fround(0), $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (Math_fround(FUNCTION_TABLE_fid[$func & 1]($obj,$1)));
 HEAPF32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsE6InvokeEPFfPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$1)));
 HEAPF32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits27mscorlib_System_Int64TraitsE6InvokeEPFfPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$3,$6)));
 HEAPF32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits27mscorlib_System_SByteTraitsE6InvokeEPFfPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$1)));
 HEAPF32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits27mscorlib_System_Int16TraitsE6InvokeEPFfPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$1)));
 HEAPF32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits28mscorlib_System_UInt32TraitsE6InvokeEPFfPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$1)));
 HEAPF32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits28mscorlib_System_UInt64TraitsE6InvokeEPFfPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$3,$6)));
 HEAPF32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits28mscorlib_System_UInt16TraitsE6InvokeEPFfPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$1)));
 HEAPF32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_SingleTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFfPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$0,$2)));
 HEAPF32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits29mscorlib_System_BooleanTraitsE6InvokeEPFtPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 HEAP16[$ret>>1] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits26mscorlib_System_ByteTraitsE6InvokeEPFtPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits26mscorlib_System_CharTraitsE6InvokeEPFtPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits28mscorlib_System_DoubleTraitsE6InvokeEPFtPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits28mscorlib_System_SingleTraitsE6InvokeEPFtPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits27mscorlib_System_Int32TraitsE6InvokeEPFtPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits27mscorlib_System_Int64TraitsE6InvokeEPFtPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP16[$ret>>1] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits27mscorlib_System_SByteTraitsE6InvokeEPFtPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits27mscorlib_System_Int16TraitsE6InvokeEPFtPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits28mscorlib_System_UInt32TraitsE6InvokeEPFtPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP16[$ret>>1] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt16Traits28mscorlib_System_UInt64TraitsE6InvokeEPFtPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP16[$ret>>1] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_UInt16Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFtPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP16[$ret>>1] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2176024,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFjPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits26mscorlib_System_ByteTraitsE6InvokeEPFjPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits26mscorlib_System_CharTraitsE6InvokeEPFjPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits28mscorlib_System_DoubleTraitsE6InvokeEPFjPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits28mscorlib_System_SingleTraitsE6InvokeEPFjPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits27mscorlib_System_Int32TraitsE6InvokeEPFjPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits27mscorlib_System_Int64TraitsE6InvokeEPFjPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits27mscorlib_System_SByteTraitsE6InvokeEPFjPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits27mscorlib_System_Int16TraitsE6InvokeEPFjPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits28mscorlib_System_UInt64TraitsE6InvokeEPFjPvyES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32Traits28mscorlib_System_UInt16TraitsE6InvokeEPFjPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_UInt32Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFjPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits29mscorlib_System_BooleanTraitsE6InvokeEPFyPvbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$2)|0);
 $4 = tempRet0;
 $5 = $ret;
 $6 = $5;
 HEAP32[$6>>2] = $3;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $4;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits26mscorlib_System_ByteTraitsE6InvokeEPFyPvhES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits26mscorlib_System_CharTraitsE6InvokeEPFyPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_DoubleTraitsE6InvokeEPFyPvdES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (FUNCTION_TABLE_iid[$func & 31]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_SingleTraitsE6InvokeEPFyPvfES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits27mscorlib_System_Int32TraitsE6InvokeEPFyPviES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits27mscorlib_System_Int64TraitsE6InvokeEPFyPvxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$3,$6)|0);
 $8 = tempRet0;
 $9 = $ret;
 $10 = $9;
 HEAP32[$10>>2] = $7;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits27mscorlib_System_SByteTraitsE6InvokeEPFyPvaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits27mscorlib_System_Int16TraitsE6InvokeEPFyPvsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_UInt32TraitsE6InvokeEPFyPvjES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_UInt16TraitsE6InvokeEPFyPvtES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 $3 = tempRet0;
 $4 = $ret;
 $5 = $4;
 HEAP32[$5>>2] = $2;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $3;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_ObjectTraitsE6InvokeEPFyPvP22mscorlib_System_ObjectES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$0)|0);
 $2 = tempRet0;
 $3 = $ret;
 $4 = $3;
 HEAP32[$4>>2] = $1;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_UInt64Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFyPvP22mscorlib_System_ObjectS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 $4 = tempRet0;
 $5 = $ret;
 $6 = $5;
 HEAP32[$6>>2] = $3;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $4;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2167208,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker4I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsS1_29mscorlib_System_BooleanTraitsE6InvokeEPFP22mscorlib_System_ObjectPvS5_S6_S6_bES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z138mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z139mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_BooleanP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_ByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_CharP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_DecimalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_DoubleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z165mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z165mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Object_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_BooleanP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_ByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_CharP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_DecimalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_DoubleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Object_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_BooleanP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_ByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_CharP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_DecimalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_DoubleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_UInt64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Object_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_BooleanP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_ByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_CharP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_DecimalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_DoubleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int64P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_SByteP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_UInt32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_UInt16P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_ObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Object_mscorlib_System_IFormatProviderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2164896)|0);
 __Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z30mscorlib_System_DBNull_m__ctorP22mscorlib_System_DBNull($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2581840);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z31mscorlib_System_DBNull_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2581888);
 __THREW__ = 0;
 (invoke_ii(2996,(2583848|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2583848|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2697,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2583848|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2583848 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z54mscorlib_System_DBNull_m_System_IConvertible_ToBooleanP22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2581936);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_InvalidCastException_m__ctor_mscorlib_System_VoidP36mscorlib_System_InvalidCastException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2607080);
 __THREW__ = 0;
 invoke_v(860);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3071440>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2147467262);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z51mscorlib_System_DBNull_m_System_IConvertible_ToByteP22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2581984);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_DBNull_m_System_IConvertible_ToCharP22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582032);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_DBNull_m_System_IConvertible_ToDateTimeP22mscorlib_System_DBNullP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582080);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z54mscorlib_System_DBNull_m_System_IConvertible_ToDecimalP22mscorlib_System_DBNullP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582128);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z53mscorlib_System_DBNull_m_System_IConvertible_ToDoubleP22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582176);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return +0;
}
function __Z52mscorlib_System_DBNull_m_System_IConvertible_ToInt16P22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582224);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_DBNull_m_System_IConvertible_ToInt32P22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582272);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_DBNull_m_System_IConvertible_ToInt64P22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582320);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_DBNull_m_System_IConvertible_ToSByteP22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582368);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_DBNull_m_System_IConvertible_ToSingleP22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582416);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return Math_fround(0);
}
function __Z51mscorlib_System_DBNull_m_System_IConvertible_ToTypeP22mscorlib_System_DBNullP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $$0 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582464);
 HEAP32[$0>>2] = 1284472;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($2|0)==($targetType|0);
   if ($5) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP8[((2191608 + 116|0))>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2191608|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = HEAP32[((2191608 + 80|0))>>2]|0;
    $21 = HEAP32[$20>>2]|0;
    $$0 = $21;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$1>>2] = 2642920;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
   $22 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = ($22|0)==($targetType|0);
    if ($25) {
     $$0 = $__this;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2607384|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __THREW__ = 0;
     $28 = (invoke_ii(3469,(2607384|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      invoke_vi(2732,($28|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_vi(3838,($28|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        // unreachable;
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_DBNull_m_System_IConvertible_ToUInt16P22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582512);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_DBNull_m_System_IConvertible_ToUInt32P22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582560);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_DBNull_m_System_IConvertible_ToUInt64P22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582608);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_DBNull_m_GetObjectDataP22mscorlib_System_DBNullP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582656);
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 invoke_viiii(204,(0|0),($__this|0),($info|0),($tmpcast$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56mscorlib_System_DBNull_m_ToString_mscorlib_System_StringP22mscorlib_System_DBNull($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582704);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_DBNull_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_DBNullP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2582752);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_DBNull_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Int64P24mscorlib_System_DateTimex($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_0 = 0, $L_10 = 0, $L_17 = 0, $L_24 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $_stackTraceSentry = sp + 96|0;
 $V_1 = sp + 80|0;
 $V_2 = sp + 64|0;
 $V_3 = sp + 48|0;
 $V_4 = sp + 32|0;
 $L_0 = sp + 16|0;
 $L_10 = sp + 8|0;
 $L_17 = sp;
 $L_24 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584472);
 ;HEAP32[$V_1+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_2+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_3+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_4+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 invoke_v(861);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = $L_0;
   $5 = $4;
   HEAP32[$5>>2] = 0;
   $6 = (($4) + 4)|0;
   $7 = $6;
   HEAP32[$7>>2] = 0;
   __THREW__ = 0;
   invoke_viii(703,($L_0|0),($0|0),($1|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = $L_0;
    $11 = $10;
    $12 = HEAP32[$11>>2]|0;
    $13 = (($10) + 4)|0;
    $14 = $13;
    $15 = HEAP32[$14>>2]|0;
    $16 = $__this;
    $17 = $16;
    HEAP32[$17>>2] = $12;
    $18 = (($16) + 4)|0;
    $19 = $18;
    HEAP32[$19>>2] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = HEAP8[((2592096 + 116|0))>>0]|0;
     $23 = ($22<<24>>24)==(0);
     if ($23) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2592096|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      $34 = HEAP32[((2592096 + 80|0))>>2]|0;
      $35 = (($34) + 16|0);
      _memmove(($V_1|0),($35|0),16)|0;
      __THREW__ = 0;
      $36 = (invoke_ii(2432,($V_1|0))|0);
      $37 = tempRet0;
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       $40 = ($37|0)>($1|0);
       $41 = ($37|0)==($1|0);
       $42 = ($36>>>0)>($0>>>0);
       $43 = $41 & $42;
       $44 = $40 | $43;
       if (!($44)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        $47 = HEAP8[((2592096 + 116|0))>>0]|0;
        $48 = ($47<<24>>24)==(0);
        if ($48) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if ($50) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3839,(2592096|0));
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if ($54) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
        $57 = HEAP32[((2592096 + 80|0))>>2]|0;
        _memmove(($V_2|0),($57|0),16)|0;
        __THREW__ = 0;
        $58 = (invoke_ii(2432,($V_2|0))|0);
        $59 = tempRet0;
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         break;
        }
        $62 = ($59|0)<($1|0);
        $63 = ($59|0)==($1|0);
        $64 = ($58>>>0)<($0>>>0);
        $65 = $63 & $64;
        $66 = $62 | $65;
        if (!($66)) {
         $192 = (($__this) + 8|0);
         HEAP32[$192>>2] = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1167664|0))|0);
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if (!($68)) {
        __THREW__ = 0;
        $69 = (invoke_iii(2768,(1167664|0),3)|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if (!($71)) {
         $72 = $L_10;
         $73 = $72;
         HEAP32[$73>>2] = $0;
         $74 = (($72) + 4)|0;
         $75 = $74;
         HEAP32[$75>>2] = $1;
         __THREW__ = 0;
         (invoke_ii(2996,(2162248|0))|0);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if (!($77)) {
          __THREW__ = 0;
          $78 = (invoke_iii(2724,(2162248|0),($L_10|0))|0);
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if (!($80)) {
           __THREW__ = 0;
           invoke_vi(3799,($69|0));
           $81 = __THREW__; __THREW__ = 0;
           $82 = $81&1;
           if (!($82)) {
            $83 = (($69) + 12|0);
            $84 = HEAP32[$83>>2]|0;
            $85 = ($84|0)==(0);
            if ($85) {
             __THREW__ = 0;
             $86 = (invoke_i(132)|0);
             $87 = __THREW__; __THREW__ = 0;
             $88 = $87&1;
             if ($88) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($86|0));
             $89 = __THREW__; __THREW__ = 0;
             $90 = $89&1;
             if ($90) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($69|0),($78|0));
            $91 = __THREW__; __THREW__ = 0;
            $92 = $91&1;
            if (!($92)) {
             $93 = (($69) + 16|0);
             HEAP32[$93>>2] = $78;
             __THREW__ = 0;
             (invoke_ii(2996,(2592096|0))|0);
             $94 = __THREW__; __THREW__ = 0;
             $95 = $94&1;
             if (!($95)) {
              $96 = HEAP8[((2592096 + 116|0))>>0]|0;
              $97 = ($96<<24>>24)==(0);
              if ($97) {
               __THREW__ = 0;
               (invoke_ii(2996,(2592096|0))|0);
               $98 = __THREW__; __THREW__ = 0;
               $99 = $98&1;
               if ($99) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2592096|0))|0);
               $100 = __THREW__; __THREW__ = 0;
               $101 = $100&1;
               if ($101) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3839,(2592096|0));
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               if ($103) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2592096|0))|0);
              $104 = __THREW__; __THREW__ = 0;
              $105 = $104&1;
              if (!($105)) {
               $106 = HEAP32[((2592096 + 80|0))>>2]|0;
               $107 = (($106) + 16|0);
               _memmove(($V_3|0),($107|0),16)|0;
               __THREW__ = 0;
               $108 = (invoke_ii(2432,($V_3|0))|0);
               $109 = tempRet0;
               $110 = __THREW__; __THREW__ = 0;
               $111 = $110&1;
               if (!($111)) {
                $112 = $L_17;
                $113 = $112;
                HEAP32[$113>>2] = $108;
                $114 = (($112) + 4)|0;
                $115 = $114;
                HEAP32[$115>>2] = $109;
                __THREW__ = 0;
                (invoke_ii(2996,(2162248|0))|0);
                $116 = __THREW__; __THREW__ = 0;
                $117 = $116&1;
                if (!($117)) {
                 __THREW__ = 0;
                 $118 = (invoke_iii(2724,(2162248|0),($L_17|0))|0);
                 $119 = __THREW__; __THREW__ = 0;
                 $120 = $119&1;
                 if ($120) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($69|0));
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  break;
                 }
                 $123 = HEAP32[$83>>2]|0;
                 $124 = ($123>>>0)<(2);
                 if ($124) {
                  __THREW__ = 0;
                  $125 = (invoke_i(132)|0);
                  $126 = __THREW__; __THREW__ = 0;
                  $127 = $126&1;
                  if ($127) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($125|0));
                  $128 = __THREW__; __THREW__ = 0;
                  $129 = $128&1;
                  if ($129) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($69|0),($118|0));
                 $130 = __THREW__; __THREW__ = 0;
                 $131 = $130&1;
                 if ($131) {
                  break;
                 }
                 $132 = HEAP32[$69>>2]|0;
                 $133 = (($132) + 92|0);
                 $134 = HEAP32[$133>>2]|0;
                 $135 = (($93) + ($134)|0);
                 HEAP32[$135>>2] = $118;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $136 = __THREW__; __THREW__ = 0;
                 $137 = $136&1;
                 if ($137) {
                  break;
                 }
                 $138 = HEAP8[((2592096 + 116|0))>>0]|0;
                 $139 = ($138<<24>>24)==(0);
                 if ($139) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $140 = __THREW__; __THREW__ = 0;
                  $141 = $140&1;
                  if ($141) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $142 = __THREW__; __THREW__ = 0;
                  $143 = $142&1;
                  if ($143) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3839,(2592096|0));
                  $144 = __THREW__; __THREW__ = 0;
                  $145 = $144&1;
                  if ($145) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $146 = __THREW__; __THREW__ = 0;
                 $147 = $146&1;
                 if ($147) {
                  break;
                 }
                 $148 = HEAP32[((2592096 + 80|0))>>2]|0;
                 _memmove(($V_4|0),($148|0),16)|0;
                 __THREW__ = 0;
                 $149 = (invoke_ii(2432,($V_4|0))|0);
                 $150 = tempRet0;
                 $151 = __THREW__; __THREW__ = 0;
                 $152 = $151&1;
                 if ($152) {
                  break;
                 }
                 $153 = $L_24;
                 $154 = $153;
                 HEAP32[$154>>2] = $149;
                 $155 = (($153) + 4)|0;
                 $156 = $155;
                 HEAP32[$156>>2] = $150;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2162248|0))|0);
                 $157 = __THREW__; __THREW__ = 0;
                 $158 = $157&1;
                 if ($158) {
                  break;
                 }
                 __THREW__ = 0;
                 $159 = (invoke_iii(2724,(2162248|0),($L_24|0))|0);
                 $160 = __THREW__; __THREW__ = 0;
                 $161 = $160&1;
                 if ($161) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($69|0));
                 $162 = __THREW__; __THREW__ = 0;
                 $163 = $162&1;
                 if ($163) {
                  break;
                 }
                 $164 = HEAP32[$83>>2]|0;
                 $165 = ($164>>>0)<(3);
                 if ($165) {
                  __THREW__ = 0;
                  $166 = (invoke_i(132)|0);
                  $167 = __THREW__; __THREW__ = 0;
                  $168 = $167&1;
                  if ($168) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($166|0));
                  $169 = __THREW__; __THREW__ = 0;
                  $170 = $169&1;
                  if ($170) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($69|0),($159|0));
                 $171 = __THREW__; __THREW__ = 0;
                 $172 = $171&1;
                 if ($172) {
                  break;
                 }
                 $173 = HEAP32[$69>>2]|0;
                 $174 = (($173) + 92|0);
                 $175 = HEAP32[$174>>2]|0;
                 $176 = $175 << 1;
                 $177 = (($93) + ($176)|0);
                 HEAP32[$177>>2] = $159;
                 $178 = HEAP32[3066336>>2]|0;
                 __THREW__ = 0;
                 $179 = (invoke_iiii(728,(0|0),($178|0),($69|0))|0);
                 $180 = __THREW__; __THREW__ = 0;
                 $181 = $180&1;
                 if ($181) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2561352|0))|0);
                 $182 = __THREW__; __THREW__ = 0;
                 $183 = $182&1;
                 if ($183) {
                  break;
                 }
                 __THREW__ = 0;
                 $184 = (invoke_ii(3469,(2561352|0))|0);
                 $185 = __THREW__; __THREW__ = 0;
                 $186 = $185&1;
                 if ($186) {
                  break;
                 }
                 $187 = HEAP32[3066344>>2]|0;
                 __THREW__ = 0;
                 invoke_viii(644,($184|0),($187|0),($179|0));
                 $188 = __THREW__; __THREW__ = 0;
                 $189 = $188&1;
                 if ($189) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3838,($184|0));
                 $190 = __THREW__; __THREW__ = 0;
                 $191 = $190&1;
                 if ($191) {
                  break;
                 }
                 // unreachable;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($30|0);
 // unreachable;
}
function __Z36mscorlib_System_DateTime_m_get_TicksP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586000);
 __THREW__ = 0;
 $0 = (invoke_ii(2499,($__this|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $1;
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z119mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P24mscorlib_System_DateTimeiii($__this,$year,$month,$day) {
 $__this = $__this|0;
 $year = $year|0;
 $month = $month|0;
 $day = $day|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584520);
 __THREW__ = 0;
 invoke_viiiiiiii(14,($__this|0),($year|0),($month|0),($day|0),0,0,0,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z207mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P24mscorlib_System_DateTimeiiiiiii($__this,$year,$month,$day,$hour,$minute,$second,$millisecond) {
 $__this = $__this|0;
 $year = $year|0;
 $month = $month|0;
 $day = $day|0;
 $hour = $hour|0;
 $minute = $minute|0;
 $second = $second|0;
 $millisecond = $millisecond|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_16 = 0, $_stackTraceSentry = 0, $or$cond1 = 0, $or$cond10 = 0, $or$cond10$not = 0, $or$cond11 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0;
 var $or$cond6 = 0, $or$cond7 = 0, $or$cond8 = 0, $or$cond9 = 0, $year$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_16 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584568);
 __THREW__ = 0;
 invoke_v(862);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $year$off = (($year) + -1)|0;
   $2 = ($year$off>>>0)>(9998);
   $3 = ($month|0)<(1);
   $or$cond1 = $2 | $3;
   $4 = ($month|0)>(12);
   $or$cond2 = $or$cond1 | $4;
   $5 = ($day|0)<(1);
   $or$cond3 = $or$cond2 | $5;
   if (!($or$cond3)) {
    __THREW__ = 0;
    $8 = (invoke_iiii(1148,0,($year|0),($month|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = ($8|0)<($day|0);
    $12 = ($hour|0)<(0);
    $or$cond4 = $11 | $12;
    $13 = ($hour|0)>(23);
    $or$cond5 = $or$cond4 | $13;
    $14 = ($minute|0)<(0);
    $or$cond6 = $or$cond5 | $14;
    $15 = ($minute|0)>(59);
    $or$cond7 = $or$cond6 | $15;
    $16 = ($second|0)<(0);
    $or$cond8 = $or$cond7 | $16;
    $17 = ($second|0)>(59);
    $or$cond9 = $or$cond8 | $17;
    $18 = ($millisecond|0)<(0);
    $or$cond10 = $or$cond9 | $18;
    $or$cond10$not = $or$cond10 ^ 1;
    $19 = ($millisecond|0)<(1000);
    $or$cond11 = $19 & $or$cond10$not;
    if ($or$cond11) {
     __THREW__ = 0;
     $30 = (invoke_iiiii(179,0,($year|0),($month|0),($day|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     $33 = $L_16;
     $34 = $33;
     HEAP32[$34>>2] = 0;
     $35 = (($33) + 4)|0;
     $36 = $35;
     HEAP32[$36>>2] = 0;
     __THREW__ = 0;
     invoke_viiiiii(67,($L_16|0),($30|0),($hour|0),($minute|0),($second|0),($millisecond|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     $39 = $L_16;
     $40 = $39;
     $41 = HEAP32[$40>>2]|0;
     $42 = (($39) + 4)|0;
     $43 = $42;
     $44 = HEAP32[$43>>2]|0;
     $45 = $__this;
     $46 = $45;
     HEAP32[$46>>2] = $41;
     $47 = (($45) + 4)|0;
     $48 = $47;
     HEAP32[$48>>2] = $44;
     $49 = (($__this) + 8|0);
     HEAP32[$49>>2] = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2561352|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     $25 = HEAP32[3066472>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($22|0),($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __THREW__ = 0;
      invoke_vi(3838,($22|0));
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z38mscorlib_System_DateTime_m_DaysInMonthP22mscorlib_System_Objectii($__this,$year,$month) {
 $__this = $__this|0;
 $year = $year|0;
 $month = $month|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $G_B9_0$0 = 0, $G_B9_0$0$in$in = 0, $_stackTraceSentry = 0, $month$off = 0, $year$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586624);
 $month$off = (($month) + -1)|0;
 $0 = ($month$off>>>0)<(12);
 do {
  if ($0) {
   $year$off = (($year) + -1)|0;
   $12 = ($year$off>>>0)<(9999);
   if (!($12)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    $15 = (invoke_ii(3469,(2561352|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(2587,($15|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($15|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $22 = (invoke_iii(1116,0,($year|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    if ($22) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = HEAP8[((2592096 + 116|0))>>0]|0;
     $28 = ($27<<24>>24)==(0);
     if ($28) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2592096|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     $37 = HEAP32[((2592096 + 80|0))>>2]|0;
     $38 = (($37) + 64|0);
     $G_B9_0$0$in$in = $38;
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     $41 = HEAP8[((2592096 + 116|0))>>0]|0;
     $42 = ($41<<24>>24)==(0);
     if ($42) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2592096|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $51 = HEAP32[((2592096 + 80|0))>>2]|0;
     $52 = (($51) + 60|0);
     $G_B9_0$0$in$in = $52;
    }
    $G_B9_0$0 = HEAP32[$G_B9_0$0$in$in>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($G_B9_0$0|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     $55 = ($month|0)<(0);
     if (!($55)) {
      $56 = (($G_B9_0$0) + 12|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57>>>0)>($month>>>0);
      if ($58) {
       $64 = HEAP32[$G_B9_0$0>>2]|0;
       $65 = (($G_B9_0$0) + 16|0);
       $66 = (($64) + 92|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = Math_imul($67, $month)|0;
       $69 = (($65) + ($68)|0);
       $70 = HEAP32[$69>>2]|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($70|0);
      }
     }
     __THREW__ = 0;
     $59 = (invoke_i(132)|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if (!($61)) {
      __THREW__ = 0;
      invoke_vi(3302,($59|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if (!($63)) {
       $64 = HEAP32[$G_B9_0$0>>2]|0;
       $65 = (($G_B9_0$0) + 16|0);
       $66 = (($64) + 92|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = Math_imul($67, $month)|0;
       $69 = (($65) + ($68)|0);
       $70 = HEAP32[$69>>2]|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($70|0);
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(3469,(2561352|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(2587,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      __THREW__ = 0;
      invoke_vi(3838,($3|0));
      $8 = __THREW__; __THREW__ = 0;
      $9 = $8&1;
      if (!($9)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_DateTime_m_AbsoluteDaysP22mscorlib_System_Objectiii($__this,$year,$month,$day) {
 $__this = $__this|0;
 $year = $year|0;
 $month = $month|0;
 $day = $day|0;
 var $$neg = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $G_B3_0$0$in$in = 0, $V_1$0$lcssa = 0, $V_1$010 = 0, $V_2$09 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585480);
 __THREW__ = 0;
 $0 = (invoke_iii(1116,0,($year|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    $9 = HEAP8[((2592096 + 116|0))>>0]|0;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2592096|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    $19 = HEAP32[((2592096 + 80|0))>>2]|0;
    $20 = (($19) + 64|0);
    $G_B3_0$0$in$in = $20;
   } else {
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = HEAP8[((2592096 + 116|0))>>0]|0;
    $24 = ($23<<24>>24)==(0);
    if ($24) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2592096|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    $33 = HEAP32[((2592096 + 80|0))>>2]|0;
    $34 = (($33) + 60|0);
    $G_B3_0$0$in$in = $34;
   }
   $G_B3_0$0 = HEAP32[$G_B3_0$0$in$in>>2]|0;
   $35 = ($month|0)>(1);
   if (!($35)) {
    $V_1$0$lcssa = 0;
    $56 = (($day) + -1)|0;
    $57 = (($year) + -1)|0;
    $58 = ($57*365)|0;
    $59 = (($57|0) / 4)&-1;
    $$neg = (($57|0) / -100)&-1;
    $60 = (($57|0) / 400)&-1;
    $61 = (($56) + ($58))|0;
    $62 = (($61) + ($V_1$0$lcssa))|0;
    $63 = (($62) + ($59))|0;
    $64 = (($63) + ($$neg))|0;
    $65 = (($64) + ($60))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($65|0);
   }
   $36 = (($G_B3_0$0) + 16|0);
   $37 = (($G_B3_0$0) + 12|0);
   $V_1$010 = 0;$V_2$09 = 1;
   while(1) {
    $53 = (($V_2$09) + 1)|0;
    __THREW__ = 0;
    invoke_vi(3799,($G_B3_0$0|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     break;
    }
    $38 = HEAP32[$37>>2]|0;
    $39 = ($V_2$09>>>0)<($38>>>0);
    if (!($39)) {
     __THREW__ = 0;
     $40 = (invoke_i(132)|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($40|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
    }
    $45 = HEAP32[$G_B3_0$0>>2]|0;
    $46 = (($45) + 92|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = Math_imul($47, $V_2$09)|0;
    $49 = (($36) + ($48)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + ($V_1$010))|0;
    $52 = ($53|0)<($month|0);
    if ($52) {
     $V_1$010 = $51;$V_2$09 = $53;
    } else {
     $V_1$0$lcssa = $51;
     label = 27;
     break;
    }
   }
   if ((label|0) == 27) {
    $56 = (($day) + -1)|0;
    $57 = (($year) + -1)|0;
    $58 = ($57*365)|0;
    $59 = (($57|0) / 4)&-1;
    $$neg = (($57|0) / -100)&-1;
    $60 = (($57|0) / 400)&-1;
    $61 = (($56) + ($58))|0;
    $62 = (($61) + ($V_1$0$lcssa))|0;
    $63 = (($62) + ($59))|0;
    $64 = (($63) + ($$neg))|0;
    $65 = (($64) + ($60))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($65|0);
   }
   $3 = ___cxa_find_matching_catch()|0;
   $4 = tempRet0;
   $lpad$phi$index = $3;$lpad$phi$index2 = $4;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_TimeSpanP24mscorlib_System_DateTimeb24mscorlib_System_TimeSpan($__this,$check,$value) {
 $__this = $__this|0;
 $check = $check|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_0 = sp;
 $V_1 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584616);
 ;HEAP32[$V_0+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_1+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2593040+12>>2]|0;
 if (!($check)) {
  $64 = $value;
  $65 = $64;
  $66 = HEAP32[$65>>2]|0;
  $67 = (($64) + 4)|0;
  $68 = $67;
  $69 = HEAP32[$68>>2]|0;
  $70 = $__this;
  $71 = $70;
  HEAP32[$71>>2] = $66;
  $72 = (($70) + 4)|0;
  $73 = $72;
  HEAP32[$73>>2] = $69;
  $74 = (($__this) + 8|0);
  HEAP32[$74>>2] = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 $0 = (invoke_ii(2499,($value|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = HEAP8[((2592096 + 116|0))>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if ($7) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2592096|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[((2592096 + 80|0))>>2]|0;
     $19 = (($18) + 16|0);
     _memmove(($V_0|0),($19|0),16)|0;
     __THREW__ = 0;
     $20 = (invoke_ii(2432,($V_0|0))|0);
     $21 = tempRet0;
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($1|0)<($21|0);
      $25 = ($1|0)==($21|0);
      $26 = ($0>>>0)<($20>>>0);
      $27 = $25 & $26;
      $28 = $24 | $27;
      if (!($28)) {
       __THREW__ = 0;
       $29 = (invoke_ii(2499,($value|0))|0);
       $30 = tempRet0;
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       }
       $35 = HEAP8[((2592096 + 116|0))>>0]|0;
       $36 = ($35<<24>>24)==(0);
       if ($36) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2592096|0));
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $45 = HEAP32[((2592096 + 80|0))>>2]|0;
       _memmove(($V_1|0),($45|0),16)|0;
       __THREW__ = 0;
       $46 = (invoke_ii(2432,($V_1|0))|0);
       $47 = tempRet0;
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
       $50 = ($30|0)>($47|0);
       $51 = ($30|0)==($47|0);
       $52 = ($29>>>0)>($46>>>0);
       $53 = $51 & $52;
       $54 = $50 | $53;
       if (!($54)) {
        $64 = $value;
        $65 = $64;
        $66 = HEAP32[$65>>2]|0;
        $67 = (($64) + 4)|0;
        $68 = $67;
        $69 = HEAP32[$68>>2]|0;
        $70 = $__this;
        $71 = $70;
        HEAP32[$71>>2] = $66;
        $72 = (($70) + 4)|0;
        $73 = $72;
        HEAP32[$73>>2] = $69;
        $74 = (($__this) + 8|0);
        HEAP32[$74>>2] = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2561352|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if (!($56)) {
       __THREW__ = 0;
       $57 = (invoke_ii(3469,(2561352|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if (!($59)) {
        __THREW__ = 0;
        invoke_vi(2587,($57|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if (!($61)) {
         __THREW__ = 0;
         invoke_vi(3838,($57|0));
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if (!($63)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z104mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Int64_mscorlib_System_DateTimeKindP24mscorlib_System_DateTimexi($__this,$0,$1,$kind) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 $kind = $kind|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584664);
 __THREW__ = 0;
 invoke_viii(661,($__this|0),($0|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vii(1932,0,($kind|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($__this) + 8|0);
   HEAP32[$6>>2] = $kind;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z44mscorlib_System_DateTime_m_CheckDateTimeKindP24mscorlib_System_DateTimei($__this,$kind) {
 $__this = $__this|0;
 $kind = $kind|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586720);
 __THREW__ = 0;
 invoke_v(863);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $switch = ($kind>>>0)<(3);
  if ($switch) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2560072|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2560072|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3068040>>2]|0;
    $10 = HEAP32[3068048>>2]|0;
    __THREW__ = 0;
    invoke_viii(641,($6|0),($9|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3838,($6|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($2|0);
 // unreachable;
}
function __Z33mscorlib_System_DateTime_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0;
 var $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0;
 var $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0;
 var $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0;
 var $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0;
 var $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0;
 var $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0;
 var $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0;
 var $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0;
 var $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0;
 var $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0;
 var $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0, $1209 = 0, $121 = 0, $1210 = 0, $1211 = 0;
 var $1212 = 0, $1213 = 0, $1214 = 0, $1215 = 0, $1216 = 0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0, $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0;
 var $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0, $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0;
 var $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0, $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0;
 var $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0, $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0;
 var $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0, $13 = 0, $130 = 0, $1300 = 0, $1301 = 0;
 var $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0, $1311 = 0, $1312 = 0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0, $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0;
 var $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0, $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0;
 var $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0;
 var $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0;
 var $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0;
 var $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0;
 var $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0;
 var $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0;
 var $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0;
 var $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0;
 var $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0;
 var $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0;
 var $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0;
 var $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0;
 var $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0;
 var $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0;
 var $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0;
 var $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0;
 var $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0;
 var $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0;
 var $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0;
 var $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0;
 var $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0;
 var $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0;
 var $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0;
 var $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0;
 var $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0;
 var $996 = 0, $997 = 0, $998 = 0, $999 = 0, $L_2 = 0, $L_3 = 0, $L_7 = 0, $L_8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy3 = sp + 24|0;
 $_stackTraceSentry = sp + 80|0;
 $L_2 = sp + 64|0;
 $L_3 = sp + 48|0;
 $0 = sp + 32|0;
 $L_7 = sp + 40|0;
 $L_8 = sp + 8|0;
 $1 = sp;
 $2 = sp + 72|0;
 $3 = sp + 76|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584712);
 __THREW__ = 0;
 invoke_v(864);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = $L_2;
   $7 = $6;
   HEAP32[$7>>2] = 0;
   $8 = (($6) + 4)|0;
   $9 = $8;
   HEAP32[$9>>2] = 0;
   __THREW__ = 0;
   invoke_viii(703,($L_2|0),-197705729,734668917);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    ;HEAP32[$L_3+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$L_3+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$L_3+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$L_3+12>>2]=HEAP32[2593040+12>>2]|0;
    $12 = $L_2;
    $13 = $12;
    $14 = HEAP32[$13>>2]|0;
    $15 = (($12) + 4)|0;
    $16 = $15;
    $17 = HEAP32[$16>>2]|0;
    $18 = $0;
    $19 = $18;
    HEAP32[$19>>2] = $14;
    $20 = (($18) + 4)|0;
    $21 = $20;
    HEAP32[$21>>2] = $17;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$0+4>>2]|0;
    invoke_viii(662,($L_3|0),0,($$byval_copy3|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[((2592096 + 80|0))>>2]|0;
      ;HEAP32[$26+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$26+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$L_3+12>>2]|0;
      $27 = $L_7;
      $28 = $27;
      HEAP32[$28>>2] = 0;
      $29 = (($27) + 4)|0;
      $30 = $29;
      HEAP32[$30>>2] = 0;
      __THREW__ = 0;
      invoke_viii(703,($L_7|0),0,0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       ;HEAP32[$L_8+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$L_8+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$L_8+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$L_8+12>>2]=HEAP32[2593040+12>>2]|0;
       $33 = $L_7;
       $34 = $33;
       $35 = HEAP32[$34>>2]|0;
       $36 = (($33) + 4)|0;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       $39 = $1;
       $40 = $39;
       HEAP32[$40>>2] = $35;
       $41 = (($39) + 4)|0;
       $42 = $41;
       HEAP32[$42>>2] = $38;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$1+4>>2]|0;
       invoke_viii(662,($L_8|0),0,($$byval_copy3|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if (!($44)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if (!($46)) {
         $47 = HEAP32[((2592096 + 80|0))>>2]|0;
         $48 = (($47) + 16|0);
         ;HEAP32[$48+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$48+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$48+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$48+12>>2]=HEAP32[$L_8+12>>2]|0;
         __THREW__ = 0;
         (invoke_ii(2996,(1168432|0))|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if (!($50)) {
          __THREW__ = 0;
          $51 = (invoke_iii(2768,(1168432|0),9)|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           __THREW__ = 0;
           invoke_vi(3799,($51|0));
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            $56 = (($51) + 12|0);
            $57 = HEAP32[$56>>2]|0;
            $58 = ($57|0)==(0);
            if ($58) {
             __THREW__ = 0;
             $59 = (invoke_i(132)|0);
             $60 = __THREW__; __THREW__ = 0;
             $61 = $60&1;
             if ($61) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($59|0));
             $62 = __THREW__; __THREW__ = 0;
             $63 = $62&1;
             if ($63) {
              break;
             }
            }
            $66 = HEAP32[3066584>>2]|0;
            __THREW__ = 0;
            invoke_vii(3492,($51|0),($66|0));
            $67 = __THREW__; __THREW__ = 0;
            $68 = $67&1;
            if (!($68)) {
             $69 = HEAP32[3066584>>2]|0;
             $70 = (($51) + 16|0);
             HEAP32[$70>>2] = $69;
             __THREW__ = 0;
             invoke_vi(3799,($51|0));
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if (!($72)) {
              $73 = HEAP32[$56>>2]|0;
              $74 = ($73>>>0)<(2);
              if ($74) {
               __THREW__ = 0;
               $75 = (invoke_i(132)|0);
               $76 = __THREW__; __THREW__ = 0;
               $77 = $76&1;
               if ($77) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($75|0));
               $78 = __THREW__; __THREW__ = 0;
               $79 = $78&1;
               if ($79) {
                break;
               }
              }
              $80 = HEAP32[3066592>>2]|0;
              __THREW__ = 0;
              invoke_vii(3492,($51|0),($80|0));
              $81 = __THREW__; __THREW__ = 0;
              $82 = $81&1;
              if (!($82)) {
               $83 = HEAP32[3066592>>2]|0;
               $84 = HEAP32[$51>>2]|0;
               $85 = (($84) + 92|0);
               $86 = HEAP32[$85>>2]|0;
               $87 = (($70) + ($86)|0);
               HEAP32[$87>>2] = $83;
               __THREW__ = 0;
               invoke_vi(3799,($51|0));
               $88 = __THREW__; __THREW__ = 0;
               $89 = $88&1;
               if (!($89)) {
                $90 = HEAP32[$56>>2]|0;
                $91 = ($90>>>0)<(3);
                if ($91) {
                 __THREW__ = 0;
                 $92 = (invoke_i(132)|0);
                 $93 = __THREW__; __THREW__ = 0;
                 $94 = $93&1;
                 if ($94) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($92|0));
                 $95 = __THREW__; __THREW__ = 0;
                 $96 = $95&1;
                 if ($96) {
                  break;
                 }
                }
                $97 = HEAP32[3066600>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($51|0),($97|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if (!($99)) {
                 $100 = HEAP32[3066600>>2]|0;
                 $101 = HEAP32[$51>>2]|0;
                 $102 = (($101) + 92|0);
                 $103 = HEAP32[$102>>2]|0;
                 $104 = $103 << 1;
                 $105 = (($70) + ($104)|0);
                 HEAP32[$105>>2] = $100;
                 __THREW__ = 0;
                 invoke_vi(3799,($51|0));
                 $106 = __THREW__; __THREW__ = 0;
                 $107 = $106&1;
                 if (!($107)) {
                  $108 = HEAP32[$56>>2]|0;
                  $109 = ($108>>>0)<(4);
                  if ($109) {
                   __THREW__ = 0;
                   $110 = (invoke_i(132)|0);
                   $111 = __THREW__; __THREW__ = 0;
                   $112 = $111&1;
                   if ($112) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($110|0));
                   $113 = __THREW__; __THREW__ = 0;
                   $114 = $113&1;
                   if ($114) {
                    break;
                   }
                  }
                  $115 = HEAP32[3066608>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($51|0),($115|0));
                  $116 = __THREW__; __THREW__ = 0;
                  $117 = $116&1;
                  if ($117) {
                   break;
                  }
                  $118 = HEAP32[3066608>>2]|0;
                  $119 = HEAP32[$51>>2]|0;
                  $120 = (($119) + 92|0);
                  $121 = HEAP32[$120>>2]|0;
                  $122 = ($121*3)|0;
                  $123 = (($70) + ($122)|0);
                  HEAP32[$123>>2] = $118;
                  __THREW__ = 0;
                  invoke_vi(3799,($51|0));
                  $124 = __THREW__; __THREW__ = 0;
                  $125 = $124&1;
                  if ($125) {
                   break;
                  }
                  $126 = HEAP32[$56>>2]|0;
                  $127 = ($126>>>0)<(5);
                  if ($127) {
                   __THREW__ = 0;
                   $128 = (invoke_i(132)|0);
                   $129 = __THREW__; __THREW__ = 0;
                   $130 = $129&1;
                   if ($130) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($128|0));
                   $131 = __THREW__; __THREW__ = 0;
                   $132 = $131&1;
                   if ($132) {
                    break;
                   }
                  }
                  $133 = HEAP32[3066616>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($51|0),($133|0));
                  $134 = __THREW__; __THREW__ = 0;
                  $135 = $134&1;
                  if ($135) {
                   break;
                  }
                  $136 = HEAP32[3066616>>2]|0;
                  $137 = HEAP32[$51>>2]|0;
                  $138 = (($137) + 92|0);
                  $139 = HEAP32[$138>>2]|0;
                  $140 = $139 << 2;
                  $141 = (($70) + ($140)|0);
                  HEAP32[$141>>2] = $136;
                  __THREW__ = 0;
                  invoke_vi(3799,($51|0));
                  $142 = __THREW__; __THREW__ = 0;
                  $143 = $142&1;
                  if ($143) {
                   break;
                  }
                  $144 = HEAP32[$56>>2]|0;
                  $145 = ($144>>>0)<(6);
                  if ($145) {
                   __THREW__ = 0;
                   $146 = (invoke_i(132)|0);
                   $147 = __THREW__; __THREW__ = 0;
                   $148 = $147&1;
                   if ($148) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($146|0));
                   $149 = __THREW__; __THREW__ = 0;
                   $150 = $149&1;
                   if ($150) {
                    break;
                   }
                  }
                  $151 = HEAP32[3066624>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($51|0),($151|0));
                  $152 = __THREW__; __THREW__ = 0;
                  $153 = $152&1;
                  if ($153) {
                   break;
                  }
                  $154 = HEAP32[3066624>>2]|0;
                  $155 = HEAP32[$51>>2]|0;
                  $156 = (($155) + 92|0);
                  $157 = HEAP32[$156>>2]|0;
                  $158 = ($157*5)|0;
                  $159 = (($70) + ($158)|0);
                  HEAP32[$159>>2] = $154;
                  __THREW__ = 0;
                  invoke_vi(3799,($51|0));
                  $160 = __THREW__; __THREW__ = 0;
                  $161 = $160&1;
                  if ($161) {
                   break;
                  }
                  $162 = HEAP32[$56>>2]|0;
                  $163 = ($162>>>0)<(7);
                  if ($163) {
                   __THREW__ = 0;
                   $164 = (invoke_i(132)|0);
                   $165 = __THREW__; __THREW__ = 0;
                   $166 = $165&1;
                   if ($166) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($164|0));
                   $167 = __THREW__; __THREW__ = 0;
                   $168 = $167&1;
                   if ($168) {
                    break;
                   }
                  }
                  $169 = HEAP32[3066632>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($51|0),($169|0));
                  $170 = __THREW__; __THREW__ = 0;
                  $171 = $170&1;
                  if ($171) {
                   break;
                  }
                  $172 = HEAP32[3066632>>2]|0;
                  $173 = HEAP32[$51>>2]|0;
                  $174 = (($173) + 92|0);
                  $175 = HEAP32[$174>>2]|0;
                  $176 = ($175*6)|0;
                  $177 = (($70) + ($176)|0);
                  HEAP32[$177>>2] = $172;
                  __THREW__ = 0;
                  invoke_vi(3799,($51|0));
                  $178 = __THREW__; __THREW__ = 0;
                  $179 = $178&1;
                  if ($179) {
                   break;
                  }
                  $180 = HEAP32[$56>>2]|0;
                  $181 = ($180>>>0)<(8);
                  if ($181) {
                   __THREW__ = 0;
                   $182 = (invoke_i(132)|0);
                   $183 = __THREW__; __THREW__ = 0;
                   $184 = $183&1;
                   if ($184) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($182|0));
                   $185 = __THREW__; __THREW__ = 0;
                   $186 = $185&1;
                   if ($186) {
                    break;
                   }
                  }
                  $187 = HEAP32[3066640>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($51|0),($187|0));
                  $188 = __THREW__; __THREW__ = 0;
                  $189 = $188&1;
                  if ($189) {
                   break;
                  }
                  $190 = HEAP32[3066640>>2]|0;
                  $191 = HEAP32[$51>>2]|0;
                  $192 = (($191) + 92|0);
                  $193 = HEAP32[$192>>2]|0;
                  $194 = ($193*7)|0;
                  $195 = (($70) + ($194)|0);
                  HEAP32[$195>>2] = $190;
                  __THREW__ = 0;
                  invoke_vi(3799,($51|0));
                  $196 = __THREW__; __THREW__ = 0;
                  $197 = $196&1;
                  if ($197) {
                   break;
                  }
                  $198 = HEAP32[$56>>2]|0;
                  $199 = ($198>>>0)<(9);
                  if ($199) {
                   __THREW__ = 0;
                   $200 = (invoke_i(132)|0);
                   $201 = __THREW__; __THREW__ = 0;
                   $202 = $201&1;
                   if ($202) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($200|0));
                   $203 = __THREW__; __THREW__ = 0;
                   $204 = $203&1;
                   if ($204) {
                    break;
                   }
                  }
                  $205 = HEAP32[3066648>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($51|0),($205|0));
                  $206 = __THREW__; __THREW__ = 0;
                  $207 = $206&1;
                  if ($207) {
                   break;
                  }
                  $208 = HEAP32[3066648>>2]|0;
                  $209 = HEAP32[$51>>2]|0;
                  $210 = (($209) + 92|0);
                  $211 = HEAP32[$210>>2]|0;
                  $212 = $211 << 3;
                  $213 = (($70) + ($212)|0);
                  HEAP32[$213>>2] = $208;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $214 = __THREW__; __THREW__ = 0;
                  $215 = $214&1;
                  if ($215) {
                   break;
                  }
                  $216 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $217 = (($216) + 32|0);
                  HEAP32[$217>>2] = $51;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1168432|0))|0);
                  $218 = __THREW__; __THREW__ = 0;
                  $219 = $218&1;
                  if ($219) {
                   break;
                  }
                  __THREW__ = 0;
                  $220 = (invoke_iii(2768,(1168432|0),10)|0);
                  $221 = __THREW__; __THREW__ = 0;
                  $222 = $221&1;
                  if ($222) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $223 = __THREW__; __THREW__ = 0;
                  $224 = $223&1;
                  if ($224) {
                   break;
                  }
                  $225 = (($220) + 12|0);
                  $226 = HEAP32[$225>>2]|0;
                  $227 = ($226|0)==(0);
                  if ($227) {
                   __THREW__ = 0;
                   $228 = (invoke_i(132)|0);
                   $229 = __THREW__; __THREW__ = 0;
                   $230 = $229&1;
                   if ($230) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($228|0));
                   $231 = __THREW__; __THREW__ = 0;
                   $232 = $231&1;
                   if ($232) {
                    break;
                   }
                  }
                  $233 = HEAP32[3066656>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($233|0));
                  $234 = __THREW__; __THREW__ = 0;
                  $235 = $234&1;
                  if ($235) {
                   break;
                  }
                  $236 = HEAP32[3066656>>2]|0;
                  $237 = (($220) + 16|0);
                  HEAP32[$237>>2] = $236;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $238 = __THREW__; __THREW__ = 0;
                  $239 = $238&1;
                  if ($239) {
                   break;
                  }
                  $240 = HEAP32[$225>>2]|0;
                  $241 = ($240>>>0)<(2);
                  if ($241) {
                   __THREW__ = 0;
                   $242 = (invoke_i(132)|0);
                   $243 = __THREW__; __THREW__ = 0;
                   $244 = $243&1;
                   if ($244) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($242|0));
                   $245 = __THREW__; __THREW__ = 0;
                   $246 = $245&1;
                   if ($246) {
                    break;
                   }
                  }
                  $247 = HEAP32[3066664>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($247|0));
                  $248 = __THREW__; __THREW__ = 0;
                  $249 = $248&1;
                  if ($249) {
                   break;
                  }
                  $250 = HEAP32[3066664>>2]|0;
                  $251 = HEAP32[$220>>2]|0;
                  $252 = (($251) + 92|0);
                  $253 = HEAP32[$252>>2]|0;
                  $254 = (($237) + ($253)|0);
                  HEAP32[$254>>2] = $250;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $255 = __THREW__; __THREW__ = 0;
                  $256 = $255&1;
                  if ($256) {
                   break;
                  }
                  $257 = HEAP32[$225>>2]|0;
                  $258 = ($257>>>0)<(3);
                  if ($258) {
                   __THREW__ = 0;
                   $259 = (invoke_i(132)|0);
                   $260 = __THREW__; __THREW__ = 0;
                   $261 = $260&1;
                   if ($261) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($259|0));
                   $262 = __THREW__; __THREW__ = 0;
                   $263 = $262&1;
                   if ($263) {
                    break;
                   }
                  }
                  $264 = HEAP32[3066672>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($264|0));
                  $265 = __THREW__; __THREW__ = 0;
                  $266 = $265&1;
                  if ($266) {
                   break;
                  }
                  $267 = HEAP32[3066672>>2]|0;
                  $268 = HEAP32[$220>>2]|0;
                  $269 = (($268) + 92|0);
                  $270 = HEAP32[$269>>2]|0;
                  $271 = $270 << 1;
                  $272 = (($237) + ($271)|0);
                  HEAP32[$272>>2] = $267;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $273 = __THREW__; __THREW__ = 0;
                  $274 = $273&1;
                  if ($274) {
                   break;
                  }
                  $275 = HEAP32[$225>>2]|0;
                  $276 = ($275>>>0)<(4);
                  if ($276) {
                   __THREW__ = 0;
                   $277 = (invoke_i(132)|0);
                   $278 = __THREW__; __THREW__ = 0;
                   $279 = $278&1;
                   if ($279) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($277|0));
                   $280 = __THREW__; __THREW__ = 0;
                   $281 = $280&1;
                   if ($281) {
                    break;
                   }
                  }
                  $282 = HEAP32[3066680>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($282|0));
                  $283 = __THREW__; __THREW__ = 0;
                  $284 = $283&1;
                  if ($284) {
                   break;
                  }
                  $285 = HEAP32[3066680>>2]|0;
                  $286 = HEAP32[$220>>2]|0;
                  $287 = (($286) + 92|0);
                  $288 = HEAP32[$287>>2]|0;
                  $289 = ($288*3)|0;
                  $290 = (($237) + ($289)|0);
                  HEAP32[$290>>2] = $285;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $291 = __THREW__; __THREW__ = 0;
                  $292 = $291&1;
                  if ($292) {
                   break;
                  }
                  $293 = HEAP32[$225>>2]|0;
                  $294 = ($293>>>0)<(5);
                  if ($294) {
                   __THREW__ = 0;
                   $295 = (invoke_i(132)|0);
                   $296 = __THREW__; __THREW__ = 0;
                   $297 = $296&1;
                   if ($297) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($295|0));
                   $298 = __THREW__; __THREW__ = 0;
                   $299 = $298&1;
                   if ($299) {
                    break;
                   }
                  }
                  $300 = HEAP32[3066688>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($300|0));
                  $301 = __THREW__; __THREW__ = 0;
                  $302 = $301&1;
                  if ($302) {
                   break;
                  }
                  $303 = HEAP32[3066688>>2]|0;
                  $304 = HEAP32[$220>>2]|0;
                  $305 = (($304) + 92|0);
                  $306 = HEAP32[$305>>2]|0;
                  $307 = $306 << 2;
                  $308 = (($237) + ($307)|0);
                  HEAP32[$308>>2] = $303;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $309 = __THREW__; __THREW__ = 0;
                  $310 = $309&1;
                  if ($310) {
                   break;
                  }
                  $311 = HEAP32[$225>>2]|0;
                  $312 = ($311>>>0)<(6);
                  if ($312) {
                   __THREW__ = 0;
                   $313 = (invoke_i(132)|0);
                   $314 = __THREW__; __THREW__ = 0;
                   $315 = $314&1;
                   if ($315) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($313|0));
                   $316 = __THREW__; __THREW__ = 0;
                   $317 = $316&1;
                   if ($317) {
                    break;
                   }
                  }
                  $318 = HEAP32[3066696>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($318|0));
                  $319 = __THREW__; __THREW__ = 0;
                  $320 = $319&1;
                  if ($320) {
                   break;
                  }
                  $321 = HEAP32[3066696>>2]|0;
                  $322 = HEAP32[$220>>2]|0;
                  $323 = (($322) + 92|0);
                  $324 = HEAP32[$323>>2]|0;
                  $325 = ($324*5)|0;
                  $326 = (($237) + ($325)|0);
                  HEAP32[$326>>2] = $321;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $327 = __THREW__; __THREW__ = 0;
                  $328 = $327&1;
                  if ($328) {
                   break;
                  }
                  $329 = HEAP32[$225>>2]|0;
                  $330 = ($329>>>0)<(7);
                  if ($330) {
                   __THREW__ = 0;
                   $331 = (invoke_i(132)|0);
                   $332 = __THREW__; __THREW__ = 0;
                   $333 = $332&1;
                   if ($333) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($331|0));
                   $334 = __THREW__; __THREW__ = 0;
                   $335 = $334&1;
                   if ($335) {
                    break;
                   }
                  }
                  $336 = HEAP32[3066704>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($336|0));
                  $337 = __THREW__; __THREW__ = 0;
                  $338 = $337&1;
                  if ($338) {
                   break;
                  }
                  $339 = HEAP32[3066704>>2]|0;
                  $340 = HEAP32[$220>>2]|0;
                  $341 = (($340) + 92|0);
                  $342 = HEAP32[$341>>2]|0;
                  $343 = ($342*6)|0;
                  $344 = (($237) + ($343)|0);
                  HEAP32[$344>>2] = $339;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $345 = __THREW__; __THREW__ = 0;
                  $346 = $345&1;
                  if ($346) {
                   break;
                  }
                  $347 = HEAP32[$225>>2]|0;
                  $348 = ($347>>>0)<(8);
                  if ($348) {
                   __THREW__ = 0;
                   $349 = (invoke_i(132)|0);
                   $350 = __THREW__; __THREW__ = 0;
                   $351 = $350&1;
                   if ($351) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($349|0));
                   $352 = __THREW__; __THREW__ = 0;
                   $353 = $352&1;
                   if ($353) {
                    break;
                   }
                  }
                  $354 = HEAP32[3066712>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($354|0));
                  $355 = __THREW__; __THREW__ = 0;
                  $356 = $355&1;
                  if ($356) {
                   break;
                  }
                  $357 = HEAP32[3066712>>2]|0;
                  $358 = HEAP32[$220>>2]|0;
                  $359 = (($358) + 92|0);
                  $360 = HEAP32[$359>>2]|0;
                  $361 = ($360*7)|0;
                  $362 = (($237) + ($361)|0);
                  HEAP32[$362>>2] = $357;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $363 = __THREW__; __THREW__ = 0;
                  $364 = $363&1;
                  if ($364) {
                   break;
                  }
                  $365 = HEAP32[$225>>2]|0;
                  $366 = ($365>>>0)<(9);
                  if ($366) {
                   __THREW__ = 0;
                   $367 = (invoke_i(132)|0);
                   $368 = __THREW__; __THREW__ = 0;
                   $369 = $368&1;
                   if ($369) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($367|0));
                   $370 = __THREW__; __THREW__ = 0;
                   $371 = $370&1;
                   if ($371) {
                    break;
                   }
                  }
                  $372 = HEAP32[3066720>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($372|0));
                  $373 = __THREW__; __THREW__ = 0;
                  $374 = $373&1;
                  if ($374) {
                   break;
                  }
                  $375 = HEAP32[3066720>>2]|0;
                  $376 = HEAP32[$220>>2]|0;
                  $377 = (($376) + 92|0);
                  $378 = HEAP32[$377>>2]|0;
                  $379 = $378 << 3;
                  $380 = (($237) + ($379)|0);
                  HEAP32[$380>>2] = $375;
                  __THREW__ = 0;
                  invoke_vi(3799,($220|0));
                  $381 = __THREW__; __THREW__ = 0;
                  $382 = $381&1;
                  if ($382) {
                   break;
                  }
                  $383 = HEAP32[$225>>2]|0;
                  $384 = ($383>>>0)<(10);
                  if ($384) {
                   __THREW__ = 0;
                   $385 = (invoke_i(132)|0);
                   $386 = __THREW__; __THREW__ = 0;
                   $387 = $386&1;
                   if ($387) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($385|0));
                   $388 = __THREW__; __THREW__ = 0;
                   $389 = $388&1;
                   if ($389) {
                    break;
                   }
                  }
                  $390 = HEAP32[3066728>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($220|0),($390|0));
                  $391 = __THREW__; __THREW__ = 0;
                  $392 = $391&1;
                  if ($392) {
                   break;
                  }
                  $393 = HEAP32[3066728>>2]|0;
                  $394 = HEAP32[$220>>2]|0;
                  $395 = (($394) + 92|0);
                  $396 = HEAP32[$395>>2]|0;
                  $397 = ($396*9)|0;
                  $398 = (($237) + ($397)|0);
                  HEAP32[$398>>2] = $393;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $399 = __THREW__; __THREW__ = 0;
                  $400 = $399&1;
                  if ($400) {
                   break;
                  }
                  $401 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $402 = (($401) + 36|0);
                  HEAP32[$402>>2] = $220;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1168432|0))|0);
                  $403 = __THREW__; __THREW__ = 0;
                  $404 = $403&1;
                  if ($404) {
                   break;
                  }
                  __THREW__ = 0;
                  $405 = (invoke_iii(2768,(1168432|0),12)|0);
                  $406 = __THREW__; __THREW__ = 0;
                  $407 = $406&1;
                  if ($407) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $408 = __THREW__; __THREW__ = 0;
                  $409 = $408&1;
                  if ($409) {
                   break;
                  }
                  $410 = (($405) + 12|0);
                  $411 = HEAP32[$410>>2]|0;
                  $412 = ($411|0)==(0);
                  if ($412) {
                   __THREW__ = 0;
                   $413 = (invoke_i(132)|0);
                   $414 = __THREW__; __THREW__ = 0;
                   $415 = $414&1;
                   if ($415) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($413|0));
                   $416 = __THREW__; __THREW__ = 0;
                   $417 = $416&1;
                   if ($417) {
                    break;
                   }
                  }
                  $418 = HEAP32[3066736>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($418|0));
                  $419 = __THREW__; __THREW__ = 0;
                  $420 = $419&1;
                  if ($420) {
                   break;
                  }
                  $421 = HEAP32[3066736>>2]|0;
                  $422 = (($405) + 16|0);
                  HEAP32[$422>>2] = $421;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $423 = __THREW__; __THREW__ = 0;
                  $424 = $423&1;
                  if ($424) {
                   break;
                  }
                  $425 = HEAP32[$410>>2]|0;
                  $426 = ($425>>>0)<(2);
                  if ($426) {
                   __THREW__ = 0;
                   $427 = (invoke_i(132)|0);
                   $428 = __THREW__; __THREW__ = 0;
                   $429 = $428&1;
                   if ($429) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($427|0));
                   $430 = __THREW__; __THREW__ = 0;
                   $431 = $430&1;
                   if ($431) {
                    break;
                   }
                  }
                  $432 = HEAP32[3066744>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($432|0));
                  $433 = __THREW__; __THREW__ = 0;
                  $434 = $433&1;
                  if ($434) {
                   break;
                  }
                  $435 = HEAP32[3066744>>2]|0;
                  $436 = HEAP32[$405>>2]|0;
                  $437 = (($436) + 92|0);
                  $438 = HEAP32[$437>>2]|0;
                  $439 = (($422) + ($438)|0);
                  HEAP32[$439>>2] = $435;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $440 = __THREW__; __THREW__ = 0;
                  $441 = $440&1;
                  if ($441) {
                   break;
                  }
                  $442 = HEAP32[$410>>2]|0;
                  $443 = ($442>>>0)<(3);
                  if ($443) {
                   __THREW__ = 0;
                   $444 = (invoke_i(132)|0);
                   $445 = __THREW__; __THREW__ = 0;
                   $446 = $445&1;
                   if ($446) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($444|0));
                   $447 = __THREW__; __THREW__ = 0;
                   $448 = $447&1;
                   if ($448) {
                    break;
                   }
                  }
                  $449 = HEAP32[3066752>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($449|0));
                  $450 = __THREW__; __THREW__ = 0;
                  $451 = $450&1;
                  if ($451) {
                   break;
                  }
                  $452 = HEAP32[3066752>>2]|0;
                  $453 = HEAP32[$405>>2]|0;
                  $454 = (($453) + 92|0);
                  $455 = HEAP32[$454>>2]|0;
                  $456 = $455 << 1;
                  $457 = (($422) + ($456)|0);
                  HEAP32[$457>>2] = $452;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $458 = __THREW__; __THREW__ = 0;
                  $459 = $458&1;
                  if ($459) {
                   break;
                  }
                  $460 = HEAP32[$410>>2]|0;
                  $461 = ($460>>>0)<(4);
                  if ($461) {
                   __THREW__ = 0;
                   $462 = (invoke_i(132)|0);
                   $463 = __THREW__; __THREW__ = 0;
                   $464 = $463&1;
                   if ($464) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($462|0));
                   $465 = __THREW__; __THREW__ = 0;
                   $466 = $465&1;
                   if ($466) {
                    break;
                   }
                  }
                  $467 = HEAP32[3066760>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($467|0));
                  $468 = __THREW__; __THREW__ = 0;
                  $469 = $468&1;
                  if ($469) {
                   break;
                  }
                  $470 = HEAP32[3066760>>2]|0;
                  $471 = HEAP32[$405>>2]|0;
                  $472 = (($471) + 92|0);
                  $473 = HEAP32[$472>>2]|0;
                  $474 = ($473*3)|0;
                  $475 = (($422) + ($474)|0);
                  HEAP32[$475>>2] = $470;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $476 = __THREW__; __THREW__ = 0;
                  $477 = $476&1;
                  if ($477) {
                   break;
                  }
                  $478 = HEAP32[$410>>2]|0;
                  $479 = ($478>>>0)<(5);
                  if ($479) {
                   __THREW__ = 0;
                   $480 = (invoke_i(132)|0);
                   $481 = __THREW__; __THREW__ = 0;
                   $482 = $481&1;
                   if ($482) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($480|0));
                   $483 = __THREW__; __THREW__ = 0;
                   $484 = $483&1;
                   if ($484) {
                    break;
                   }
                  }
                  $485 = HEAP32[3066768>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($485|0));
                  $486 = __THREW__; __THREW__ = 0;
                  $487 = $486&1;
                  if ($487) {
                   break;
                  }
                  $488 = HEAP32[3066768>>2]|0;
                  $489 = HEAP32[$405>>2]|0;
                  $490 = (($489) + 92|0);
                  $491 = HEAP32[$490>>2]|0;
                  $492 = $491 << 2;
                  $493 = (($422) + ($492)|0);
                  HEAP32[$493>>2] = $488;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $494 = __THREW__; __THREW__ = 0;
                  $495 = $494&1;
                  if ($495) {
                   break;
                  }
                  $496 = HEAP32[$410>>2]|0;
                  $497 = ($496>>>0)<(6);
                  if ($497) {
                   __THREW__ = 0;
                   $498 = (invoke_i(132)|0);
                   $499 = __THREW__; __THREW__ = 0;
                   $500 = $499&1;
                   if ($500) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($498|0));
                   $501 = __THREW__; __THREW__ = 0;
                   $502 = $501&1;
                   if ($502) {
                    break;
                   }
                  }
                  $503 = HEAP32[3066776>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($503|0));
                  $504 = __THREW__; __THREW__ = 0;
                  $505 = $504&1;
                  if ($505) {
                   break;
                  }
                  $506 = HEAP32[3066776>>2]|0;
                  $507 = HEAP32[$405>>2]|0;
                  $508 = (($507) + 92|0);
                  $509 = HEAP32[$508>>2]|0;
                  $510 = ($509*5)|0;
                  $511 = (($422) + ($510)|0);
                  HEAP32[$511>>2] = $506;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $512 = __THREW__; __THREW__ = 0;
                  $513 = $512&1;
                  if ($513) {
                   break;
                  }
                  $514 = HEAP32[$410>>2]|0;
                  $515 = ($514>>>0)<(7);
                  if ($515) {
                   __THREW__ = 0;
                   $516 = (invoke_i(132)|0);
                   $517 = __THREW__; __THREW__ = 0;
                   $518 = $517&1;
                   if ($518) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($516|0));
                   $519 = __THREW__; __THREW__ = 0;
                   $520 = $519&1;
                   if ($520) {
                    break;
                   }
                  }
                  $521 = HEAP32[3066784>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($521|0));
                  $522 = __THREW__; __THREW__ = 0;
                  $523 = $522&1;
                  if ($523) {
                   break;
                  }
                  $524 = HEAP32[3066784>>2]|0;
                  $525 = HEAP32[$405>>2]|0;
                  $526 = (($525) + 92|0);
                  $527 = HEAP32[$526>>2]|0;
                  $528 = ($527*6)|0;
                  $529 = (($422) + ($528)|0);
                  HEAP32[$529>>2] = $524;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $530 = __THREW__; __THREW__ = 0;
                  $531 = $530&1;
                  if ($531) {
                   break;
                  }
                  $532 = HEAP32[$410>>2]|0;
                  $533 = ($532>>>0)<(8);
                  if ($533) {
                   __THREW__ = 0;
                   $534 = (invoke_i(132)|0);
                   $535 = __THREW__; __THREW__ = 0;
                   $536 = $535&1;
                   if ($536) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($534|0));
                   $537 = __THREW__; __THREW__ = 0;
                   $538 = $537&1;
                   if ($538) {
                    break;
                   }
                  }
                  $539 = HEAP32[3066792>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($539|0));
                  $540 = __THREW__; __THREW__ = 0;
                  $541 = $540&1;
                  if ($541) {
                   break;
                  }
                  $542 = HEAP32[3066792>>2]|0;
                  $543 = HEAP32[$405>>2]|0;
                  $544 = (($543) + 92|0);
                  $545 = HEAP32[$544>>2]|0;
                  $546 = ($545*7)|0;
                  $547 = (($422) + ($546)|0);
                  HEAP32[$547>>2] = $542;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $548 = __THREW__; __THREW__ = 0;
                  $549 = $548&1;
                  if ($549) {
                   break;
                  }
                  $550 = HEAP32[$410>>2]|0;
                  $551 = ($550>>>0)<(9);
                  if ($551) {
                   __THREW__ = 0;
                   $552 = (invoke_i(132)|0);
                   $553 = __THREW__; __THREW__ = 0;
                   $554 = $553&1;
                   if ($554) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($552|0));
                   $555 = __THREW__; __THREW__ = 0;
                   $556 = $555&1;
                   if ($556) {
                    break;
                   }
                  }
                  $557 = HEAP32[3066800>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($557|0));
                  $558 = __THREW__; __THREW__ = 0;
                  $559 = $558&1;
                  if ($559) {
                   break;
                  }
                  $560 = HEAP32[3066800>>2]|0;
                  $561 = HEAP32[$405>>2]|0;
                  $562 = (($561) + 92|0);
                  $563 = HEAP32[$562>>2]|0;
                  $564 = $563 << 3;
                  $565 = (($422) + ($564)|0);
                  HEAP32[$565>>2] = $560;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $566 = __THREW__; __THREW__ = 0;
                  $567 = $566&1;
                  if ($567) {
                   break;
                  }
                  $568 = HEAP32[$410>>2]|0;
                  $569 = ($568>>>0)<(10);
                  if ($569) {
                   __THREW__ = 0;
                   $570 = (invoke_i(132)|0);
                   $571 = __THREW__; __THREW__ = 0;
                   $572 = $571&1;
                   if ($572) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($570|0));
                   $573 = __THREW__; __THREW__ = 0;
                   $574 = $573&1;
                   if ($574) {
                    break;
                   }
                  }
                  $575 = HEAP32[3066808>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($575|0));
                  $576 = __THREW__; __THREW__ = 0;
                  $577 = $576&1;
                  if ($577) {
                   break;
                  }
                  $578 = HEAP32[3066808>>2]|0;
                  $579 = HEAP32[$405>>2]|0;
                  $580 = (($579) + 92|0);
                  $581 = HEAP32[$580>>2]|0;
                  $582 = ($581*9)|0;
                  $583 = (($422) + ($582)|0);
                  HEAP32[$583>>2] = $578;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $584 = __THREW__; __THREW__ = 0;
                  $585 = $584&1;
                  if ($585) {
                   break;
                  }
                  $586 = HEAP32[$410>>2]|0;
                  $587 = ($586>>>0)<(11);
                  if ($587) {
                   __THREW__ = 0;
                   $588 = (invoke_i(132)|0);
                   $589 = __THREW__; __THREW__ = 0;
                   $590 = $589&1;
                   if ($590) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($588|0));
                   $591 = __THREW__; __THREW__ = 0;
                   $592 = $591&1;
                   if ($592) {
                    break;
                   }
                  }
                  $593 = HEAP32[3066816>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($593|0));
                  $594 = __THREW__; __THREW__ = 0;
                  $595 = $594&1;
                  if ($595) {
                   break;
                  }
                  $596 = HEAP32[3066816>>2]|0;
                  $597 = HEAP32[$405>>2]|0;
                  $598 = (($597) + 92|0);
                  $599 = HEAP32[$598>>2]|0;
                  $600 = ($599*10)|0;
                  $601 = (($422) + ($600)|0);
                  HEAP32[$601>>2] = $596;
                  __THREW__ = 0;
                  invoke_vi(3799,($405|0));
                  $602 = __THREW__; __THREW__ = 0;
                  $603 = $602&1;
                  if ($603) {
                   break;
                  }
                  $604 = HEAP32[$410>>2]|0;
                  $605 = ($604>>>0)<(12);
                  if ($605) {
                   __THREW__ = 0;
                   $606 = (invoke_i(132)|0);
                   $607 = __THREW__; __THREW__ = 0;
                   $608 = $607&1;
                   if ($608) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($606|0));
                   $609 = __THREW__; __THREW__ = 0;
                   $610 = $609&1;
                   if ($610) {
                    break;
                   }
                  }
                  $611 = HEAP32[3066824>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($405|0),($611|0));
                  $612 = __THREW__; __THREW__ = 0;
                  $613 = $612&1;
                  if ($613) {
                   break;
                  }
                  $614 = HEAP32[3066824>>2]|0;
                  $615 = HEAP32[$405>>2]|0;
                  $616 = (($615) + 92|0);
                  $617 = HEAP32[$616>>2]|0;
                  $618 = ($617*11)|0;
                  $619 = (($422) + ($618)|0);
                  HEAP32[$619>>2] = $614;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $620 = __THREW__; __THREW__ = 0;
                  $621 = $620&1;
                  if ($621) {
                   break;
                  }
                  $622 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $623 = (($622) + 40|0);
                  HEAP32[$623>>2] = $405;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1168432|0))|0);
                  $624 = __THREW__; __THREW__ = 0;
                  $625 = $624&1;
                  if ($625) {
                   break;
                  }
                  __THREW__ = 0;
                  $626 = (invoke_iii(2768,(1168432|0),15)|0);
                  $627 = __THREW__; __THREW__ = 0;
                  $628 = $627&1;
                  if ($628) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $629 = __THREW__; __THREW__ = 0;
                  $630 = $629&1;
                  if ($630) {
                   break;
                  }
                  $631 = (($626) + 12|0);
                  $632 = HEAP32[$631>>2]|0;
                  $633 = ($632|0)==(0);
                  if ($633) {
                   __THREW__ = 0;
                   $634 = (invoke_i(132)|0);
                   $635 = __THREW__; __THREW__ = 0;
                   $636 = $635&1;
                   if ($636) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($634|0));
                   $637 = __THREW__; __THREW__ = 0;
                   $638 = $637&1;
                   if ($638) {
                    break;
                   }
                  }
                  $639 = HEAP32[3066832>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($639|0));
                  $640 = __THREW__; __THREW__ = 0;
                  $641 = $640&1;
                  if ($641) {
                   break;
                  }
                  $642 = HEAP32[3066832>>2]|0;
                  $643 = (($626) + 16|0);
                  HEAP32[$643>>2] = $642;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $644 = __THREW__; __THREW__ = 0;
                  $645 = $644&1;
                  if ($645) {
                   break;
                  }
                  $646 = HEAP32[$631>>2]|0;
                  $647 = ($646>>>0)<(2);
                  if ($647) {
                   __THREW__ = 0;
                   $648 = (invoke_i(132)|0);
                   $649 = __THREW__; __THREW__ = 0;
                   $650 = $649&1;
                   if ($650) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($648|0));
                   $651 = __THREW__; __THREW__ = 0;
                   $652 = $651&1;
                   if ($652) {
                    break;
                   }
                  }
                  $653 = HEAP32[3066840>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($653|0));
                  $654 = __THREW__; __THREW__ = 0;
                  $655 = $654&1;
                  if ($655) {
                   break;
                  }
                  $656 = HEAP32[3066840>>2]|0;
                  $657 = HEAP32[$626>>2]|0;
                  $658 = (($657) + 92|0);
                  $659 = HEAP32[$658>>2]|0;
                  $660 = (($643) + ($659)|0);
                  HEAP32[$660>>2] = $656;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $661 = __THREW__; __THREW__ = 0;
                  $662 = $661&1;
                  if ($662) {
                   break;
                  }
                  $663 = HEAP32[$631>>2]|0;
                  $664 = ($663>>>0)<(3);
                  if ($664) {
                   __THREW__ = 0;
                   $665 = (invoke_i(132)|0);
                   $666 = __THREW__; __THREW__ = 0;
                   $667 = $666&1;
                   if ($667) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($665|0));
                   $668 = __THREW__; __THREW__ = 0;
                   $669 = $668&1;
                   if ($669) {
                    break;
                   }
                  }
                  $670 = HEAP32[3066848>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($670|0));
                  $671 = __THREW__; __THREW__ = 0;
                  $672 = $671&1;
                  if ($672) {
                   break;
                  }
                  $673 = HEAP32[3066848>>2]|0;
                  $674 = HEAP32[$626>>2]|0;
                  $675 = (($674) + 92|0);
                  $676 = HEAP32[$675>>2]|0;
                  $677 = $676 << 1;
                  $678 = (($643) + ($677)|0);
                  HEAP32[$678>>2] = $673;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $679 = __THREW__; __THREW__ = 0;
                  $680 = $679&1;
                  if ($680) {
                   break;
                  }
                  $681 = HEAP32[$631>>2]|0;
                  $682 = ($681>>>0)<(4);
                  if ($682) {
                   __THREW__ = 0;
                   $683 = (invoke_i(132)|0);
                   $684 = __THREW__; __THREW__ = 0;
                   $685 = $684&1;
                   if ($685) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($683|0));
                   $686 = __THREW__; __THREW__ = 0;
                   $687 = $686&1;
                   if ($687) {
                    break;
                   }
                  }
                  $688 = HEAP32[3066856>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($688|0));
                  $689 = __THREW__; __THREW__ = 0;
                  $690 = $689&1;
                  if ($690) {
                   break;
                  }
                  $691 = HEAP32[3066856>>2]|0;
                  $692 = HEAP32[$626>>2]|0;
                  $693 = (($692) + 92|0);
                  $694 = HEAP32[$693>>2]|0;
                  $695 = ($694*3)|0;
                  $696 = (($643) + ($695)|0);
                  HEAP32[$696>>2] = $691;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $697 = __THREW__; __THREW__ = 0;
                  $698 = $697&1;
                  if ($698) {
                   break;
                  }
                  $699 = HEAP32[$631>>2]|0;
                  $700 = ($699>>>0)<(5);
                  if ($700) {
                   __THREW__ = 0;
                   $701 = (invoke_i(132)|0);
                   $702 = __THREW__; __THREW__ = 0;
                   $703 = $702&1;
                   if ($703) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($701|0));
                   $704 = __THREW__; __THREW__ = 0;
                   $705 = $704&1;
                   if ($705) {
                    break;
                   }
                  }
                  $706 = HEAP32[3066864>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($706|0));
                  $707 = __THREW__; __THREW__ = 0;
                  $708 = $707&1;
                  if ($708) {
                   break;
                  }
                  $709 = HEAP32[3066864>>2]|0;
                  $710 = HEAP32[$626>>2]|0;
                  $711 = (($710) + 92|0);
                  $712 = HEAP32[$711>>2]|0;
                  $713 = $712 << 2;
                  $714 = (($643) + ($713)|0);
                  HEAP32[$714>>2] = $709;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $715 = __THREW__; __THREW__ = 0;
                  $716 = $715&1;
                  if ($716) {
                   break;
                  }
                  $717 = HEAP32[$631>>2]|0;
                  $718 = ($717>>>0)<(6);
                  if ($718) {
                   __THREW__ = 0;
                   $719 = (invoke_i(132)|0);
                   $720 = __THREW__; __THREW__ = 0;
                   $721 = $720&1;
                   if ($721) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($719|0));
                   $722 = __THREW__; __THREW__ = 0;
                   $723 = $722&1;
                   if ($723) {
                    break;
                   }
                  }
                  $724 = HEAP32[3066872>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($724|0));
                  $725 = __THREW__; __THREW__ = 0;
                  $726 = $725&1;
                  if ($726) {
                   break;
                  }
                  $727 = HEAP32[3066872>>2]|0;
                  $728 = HEAP32[$626>>2]|0;
                  $729 = (($728) + 92|0);
                  $730 = HEAP32[$729>>2]|0;
                  $731 = ($730*5)|0;
                  $732 = (($643) + ($731)|0);
                  HEAP32[$732>>2] = $727;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $733 = __THREW__; __THREW__ = 0;
                  $734 = $733&1;
                  if ($734) {
                   break;
                  }
                  $735 = HEAP32[$631>>2]|0;
                  $736 = ($735>>>0)<(7);
                  if ($736) {
                   __THREW__ = 0;
                   $737 = (invoke_i(132)|0);
                   $738 = __THREW__; __THREW__ = 0;
                   $739 = $738&1;
                   if ($739) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($737|0));
                   $740 = __THREW__; __THREW__ = 0;
                   $741 = $740&1;
                   if ($741) {
                    break;
                   }
                  }
                  $742 = HEAP32[3066880>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($742|0));
                  $743 = __THREW__; __THREW__ = 0;
                  $744 = $743&1;
                  if ($744) {
                   break;
                  }
                  $745 = HEAP32[3066880>>2]|0;
                  $746 = HEAP32[$626>>2]|0;
                  $747 = (($746) + 92|0);
                  $748 = HEAP32[$747>>2]|0;
                  $749 = ($748*6)|0;
                  $750 = (($643) + ($749)|0);
                  HEAP32[$750>>2] = $745;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $751 = __THREW__; __THREW__ = 0;
                  $752 = $751&1;
                  if ($752) {
                   break;
                  }
                  $753 = HEAP32[$631>>2]|0;
                  $754 = ($753>>>0)<(8);
                  if ($754) {
                   __THREW__ = 0;
                   $755 = (invoke_i(132)|0);
                   $756 = __THREW__; __THREW__ = 0;
                   $757 = $756&1;
                   if ($757) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($755|0));
                   $758 = __THREW__; __THREW__ = 0;
                   $759 = $758&1;
                   if ($759) {
                    break;
                   }
                  }
                  $760 = HEAP32[3066888>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($760|0));
                  $761 = __THREW__; __THREW__ = 0;
                  $762 = $761&1;
                  if ($762) {
                   break;
                  }
                  $763 = HEAP32[3066888>>2]|0;
                  $764 = HEAP32[$626>>2]|0;
                  $765 = (($764) + 92|0);
                  $766 = HEAP32[$765>>2]|0;
                  $767 = ($766*7)|0;
                  $768 = (($643) + ($767)|0);
                  HEAP32[$768>>2] = $763;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $769 = __THREW__; __THREW__ = 0;
                  $770 = $769&1;
                  if ($770) {
                   break;
                  }
                  $771 = HEAP32[$631>>2]|0;
                  $772 = ($771>>>0)<(9);
                  if ($772) {
                   __THREW__ = 0;
                   $773 = (invoke_i(132)|0);
                   $774 = __THREW__; __THREW__ = 0;
                   $775 = $774&1;
                   if ($775) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($773|0));
                   $776 = __THREW__; __THREW__ = 0;
                   $777 = $776&1;
                   if ($777) {
                    break;
                   }
                  }
                  $778 = HEAP32[3066896>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($778|0));
                  $779 = __THREW__; __THREW__ = 0;
                  $780 = $779&1;
                  if ($780) {
                   break;
                  }
                  $781 = HEAP32[3066896>>2]|0;
                  $782 = HEAP32[$626>>2]|0;
                  $783 = (($782) + 92|0);
                  $784 = HEAP32[$783>>2]|0;
                  $785 = $784 << 3;
                  $786 = (($643) + ($785)|0);
                  HEAP32[$786>>2] = $781;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $787 = __THREW__; __THREW__ = 0;
                  $788 = $787&1;
                  if ($788) {
                   break;
                  }
                  $789 = HEAP32[$631>>2]|0;
                  $790 = ($789>>>0)<(10);
                  if ($790) {
                   __THREW__ = 0;
                   $791 = (invoke_i(132)|0);
                   $792 = __THREW__; __THREW__ = 0;
                   $793 = $792&1;
                   if ($793) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($791|0));
                   $794 = __THREW__; __THREW__ = 0;
                   $795 = $794&1;
                   if ($795) {
                    break;
                   }
                  }
                  $796 = HEAP32[3066904>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($796|0));
                  $797 = __THREW__; __THREW__ = 0;
                  $798 = $797&1;
                  if ($798) {
                   break;
                  }
                  $799 = HEAP32[3066904>>2]|0;
                  $800 = HEAP32[$626>>2]|0;
                  $801 = (($800) + 92|0);
                  $802 = HEAP32[$801>>2]|0;
                  $803 = ($802*9)|0;
                  $804 = (($643) + ($803)|0);
                  HEAP32[$804>>2] = $799;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $805 = __THREW__; __THREW__ = 0;
                  $806 = $805&1;
                  if ($806) {
                   break;
                  }
                  $807 = HEAP32[$631>>2]|0;
                  $808 = ($807>>>0)<(11);
                  if ($808) {
                   __THREW__ = 0;
                   $809 = (invoke_i(132)|0);
                   $810 = __THREW__; __THREW__ = 0;
                   $811 = $810&1;
                   if ($811) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($809|0));
                   $812 = __THREW__; __THREW__ = 0;
                   $813 = $812&1;
                   if ($813) {
                    break;
                   }
                  }
                  $814 = HEAP32[3066912>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($814|0));
                  $815 = __THREW__; __THREW__ = 0;
                  $816 = $815&1;
                  if ($816) {
                   break;
                  }
                  $817 = HEAP32[3066912>>2]|0;
                  $818 = HEAP32[$626>>2]|0;
                  $819 = (($818) + 92|0);
                  $820 = HEAP32[$819>>2]|0;
                  $821 = ($820*10)|0;
                  $822 = (($643) + ($821)|0);
                  HEAP32[$822>>2] = $817;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $823 = __THREW__; __THREW__ = 0;
                  $824 = $823&1;
                  if ($824) {
                   break;
                  }
                  $825 = HEAP32[$631>>2]|0;
                  $826 = ($825>>>0)<(12);
                  if ($826) {
                   __THREW__ = 0;
                   $827 = (invoke_i(132)|0);
                   $828 = __THREW__; __THREW__ = 0;
                   $829 = $828&1;
                   if ($829) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($827|0));
                   $830 = __THREW__; __THREW__ = 0;
                   $831 = $830&1;
                   if ($831) {
                    break;
                   }
                  }
                  $832 = HEAP32[3066920>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($832|0));
                  $833 = __THREW__; __THREW__ = 0;
                  $834 = $833&1;
                  if ($834) {
                   break;
                  }
                  $835 = HEAP32[3066920>>2]|0;
                  $836 = HEAP32[$626>>2]|0;
                  $837 = (($836) + 92|0);
                  $838 = HEAP32[$837>>2]|0;
                  $839 = ($838*11)|0;
                  $840 = (($643) + ($839)|0);
                  HEAP32[$840>>2] = $835;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $841 = __THREW__; __THREW__ = 0;
                  $842 = $841&1;
                  if ($842) {
                   break;
                  }
                  $843 = HEAP32[$631>>2]|0;
                  $844 = ($843>>>0)<(13);
                  if ($844) {
                   __THREW__ = 0;
                   $845 = (invoke_i(132)|0);
                   $846 = __THREW__; __THREW__ = 0;
                   $847 = $846&1;
                   if ($847) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($845|0));
                   $848 = __THREW__; __THREW__ = 0;
                   $849 = $848&1;
                   if ($849) {
                    break;
                   }
                  }
                  $850 = HEAP32[3066928>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($850|0));
                  $851 = __THREW__; __THREW__ = 0;
                  $852 = $851&1;
                  if ($852) {
                   break;
                  }
                  $853 = HEAP32[3066928>>2]|0;
                  $854 = HEAP32[$626>>2]|0;
                  $855 = (($854) + 92|0);
                  $856 = HEAP32[$855>>2]|0;
                  $857 = ($856*12)|0;
                  $858 = (($643) + ($857)|0);
                  HEAP32[$858>>2] = $853;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $859 = __THREW__; __THREW__ = 0;
                  $860 = $859&1;
                  if ($860) {
                   break;
                  }
                  $861 = HEAP32[$631>>2]|0;
                  $862 = ($861>>>0)<(14);
                  if ($862) {
                   __THREW__ = 0;
                   $863 = (invoke_i(132)|0);
                   $864 = __THREW__; __THREW__ = 0;
                   $865 = $864&1;
                   if ($865) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($863|0));
                   $866 = __THREW__; __THREW__ = 0;
                   $867 = $866&1;
                   if ($867) {
                    break;
                   }
                  }
                  $868 = HEAP32[3066936>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($868|0));
                  $869 = __THREW__; __THREW__ = 0;
                  $870 = $869&1;
                  if ($870) {
                   break;
                  }
                  $871 = HEAP32[3066936>>2]|0;
                  $872 = HEAP32[$626>>2]|0;
                  $873 = (($872) + 92|0);
                  $874 = HEAP32[$873>>2]|0;
                  $875 = ($874*13)|0;
                  $876 = (($643) + ($875)|0);
                  HEAP32[$876>>2] = $871;
                  __THREW__ = 0;
                  invoke_vi(3799,($626|0));
                  $877 = __THREW__; __THREW__ = 0;
                  $878 = $877&1;
                  if ($878) {
                   break;
                  }
                  $879 = HEAP32[$631>>2]|0;
                  $880 = ($879>>>0)<(15);
                  if ($880) {
                   __THREW__ = 0;
                   $881 = (invoke_i(132)|0);
                   $882 = __THREW__; __THREW__ = 0;
                   $883 = $882&1;
                   if ($883) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($881|0));
                   $884 = __THREW__; __THREW__ = 0;
                   $885 = $884&1;
                   if ($885) {
                    break;
                   }
                  }
                  $886 = HEAP32[3066944>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($626|0),($886|0));
                  $887 = __THREW__; __THREW__ = 0;
                  $888 = $887&1;
                  if ($888) {
                   break;
                  }
                  $889 = HEAP32[3066944>>2]|0;
                  $890 = HEAP32[$626>>2]|0;
                  $891 = (($890) + 92|0);
                  $892 = HEAP32[$891>>2]|0;
                  $893 = ($892*14)|0;
                  $894 = (($643) + ($893)|0);
                  HEAP32[$894>>2] = $889;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $895 = __THREW__; __THREW__ = 0;
                  $896 = $895&1;
                  if ($896) {
                   break;
                  }
                  $897 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $898 = (($897) + 44|0);
                  HEAP32[$898>>2] = $626;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1168432|0))|0);
                  $899 = __THREW__; __THREW__ = 0;
                  $900 = $899&1;
                  if ($900) {
                   break;
                  }
                  __THREW__ = 0;
                  $901 = (invoke_iii(2768,(1168432|0),15)|0);
                  $902 = __THREW__; __THREW__ = 0;
                  $903 = $902&1;
                  if ($903) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $904 = __THREW__; __THREW__ = 0;
                  $905 = $904&1;
                  if ($905) {
                   break;
                  }
                  $906 = (($901) + 12|0);
                  $907 = HEAP32[$906>>2]|0;
                  $908 = ($907|0)==(0);
                  if ($908) {
                   __THREW__ = 0;
                   $909 = (invoke_i(132)|0);
                   $910 = __THREW__; __THREW__ = 0;
                   $911 = $910&1;
                   if ($911) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($909|0));
                   $912 = __THREW__; __THREW__ = 0;
                   $913 = $912&1;
                   if ($913) {
                    break;
                   }
                  }
                  $914 = HEAP32[3066952>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($914|0));
                  $915 = __THREW__; __THREW__ = 0;
                  $916 = $915&1;
                  if ($916) {
                   break;
                  }
                  $917 = HEAP32[3066952>>2]|0;
                  $918 = (($901) + 16|0);
                  HEAP32[$918>>2] = $917;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $919 = __THREW__; __THREW__ = 0;
                  $920 = $919&1;
                  if ($920) {
                   break;
                  }
                  $921 = HEAP32[$906>>2]|0;
                  $922 = ($921>>>0)<(2);
                  if ($922) {
                   __THREW__ = 0;
                   $923 = (invoke_i(132)|0);
                   $924 = __THREW__; __THREW__ = 0;
                   $925 = $924&1;
                   if ($925) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($923|0));
                   $926 = __THREW__; __THREW__ = 0;
                   $927 = $926&1;
                   if ($927) {
                    break;
                   }
                  }
                  $928 = HEAP32[3066960>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($928|0));
                  $929 = __THREW__; __THREW__ = 0;
                  $930 = $929&1;
                  if ($930) {
                   break;
                  }
                  $931 = HEAP32[3066960>>2]|0;
                  $932 = HEAP32[$901>>2]|0;
                  $933 = (($932) + 92|0);
                  $934 = HEAP32[$933>>2]|0;
                  $935 = (($918) + ($934)|0);
                  HEAP32[$935>>2] = $931;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $936 = __THREW__; __THREW__ = 0;
                  $937 = $936&1;
                  if ($937) {
                   break;
                  }
                  $938 = HEAP32[$906>>2]|0;
                  $939 = ($938>>>0)<(3);
                  if ($939) {
                   __THREW__ = 0;
                   $940 = (invoke_i(132)|0);
                   $941 = __THREW__; __THREW__ = 0;
                   $942 = $941&1;
                   if ($942) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($940|0));
                   $943 = __THREW__; __THREW__ = 0;
                   $944 = $943&1;
                   if ($944) {
                    break;
                   }
                  }
                  $945 = HEAP32[3066968>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($945|0));
                  $946 = __THREW__; __THREW__ = 0;
                  $947 = $946&1;
                  if ($947) {
                   break;
                  }
                  $948 = HEAP32[3066968>>2]|0;
                  $949 = HEAP32[$901>>2]|0;
                  $950 = (($949) + 92|0);
                  $951 = HEAP32[$950>>2]|0;
                  $952 = $951 << 1;
                  $953 = (($918) + ($952)|0);
                  HEAP32[$953>>2] = $948;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $954 = __THREW__; __THREW__ = 0;
                  $955 = $954&1;
                  if ($955) {
                   break;
                  }
                  $956 = HEAP32[$906>>2]|0;
                  $957 = ($956>>>0)<(4);
                  if ($957) {
                   __THREW__ = 0;
                   $958 = (invoke_i(132)|0);
                   $959 = __THREW__; __THREW__ = 0;
                   $960 = $959&1;
                   if ($960) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($958|0));
                   $961 = __THREW__; __THREW__ = 0;
                   $962 = $961&1;
                   if ($962) {
                    break;
                   }
                  }
                  $963 = HEAP32[3066976>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($963|0));
                  $964 = __THREW__; __THREW__ = 0;
                  $965 = $964&1;
                  if ($965) {
                   break;
                  }
                  $966 = HEAP32[3066976>>2]|0;
                  $967 = HEAP32[$901>>2]|0;
                  $968 = (($967) + 92|0);
                  $969 = HEAP32[$968>>2]|0;
                  $970 = ($969*3)|0;
                  $971 = (($918) + ($970)|0);
                  HEAP32[$971>>2] = $966;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $972 = __THREW__; __THREW__ = 0;
                  $973 = $972&1;
                  if ($973) {
                   break;
                  }
                  $974 = HEAP32[$906>>2]|0;
                  $975 = ($974>>>0)<(5);
                  if ($975) {
                   __THREW__ = 0;
                   $976 = (invoke_i(132)|0);
                   $977 = __THREW__; __THREW__ = 0;
                   $978 = $977&1;
                   if ($978) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($976|0));
                   $979 = __THREW__; __THREW__ = 0;
                   $980 = $979&1;
                   if ($980) {
                    break;
                   }
                  }
                  $981 = HEAP32[3066984>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($981|0));
                  $982 = __THREW__; __THREW__ = 0;
                  $983 = $982&1;
                  if ($983) {
                   break;
                  }
                  $984 = HEAP32[3066984>>2]|0;
                  $985 = HEAP32[$901>>2]|0;
                  $986 = (($985) + 92|0);
                  $987 = HEAP32[$986>>2]|0;
                  $988 = $987 << 2;
                  $989 = (($918) + ($988)|0);
                  HEAP32[$989>>2] = $984;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $990 = __THREW__; __THREW__ = 0;
                  $991 = $990&1;
                  if ($991) {
                   break;
                  }
                  $992 = HEAP32[$906>>2]|0;
                  $993 = ($992>>>0)<(6);
                  if ($993) {
                   __THREW__ = 0;
                   $994 = (invoke_i(132)|0);
                   $995 = __THREW__; __THREW__ = 0;
                   $996 = $995&1;
                   if ($996) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($994|0));
                   $997 = __THREW__; __THREW__ = 0;
                   $998 = $997&1;
                   if ($998) {
                    break;
                   }
                  }
                  $999 = HEAP32[3066992>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($999|0));
                  $1000 = __THREW__; __THREW__ = 0;
                  $1001 = $1000&1;
                  if ($1001) {
                   break;
                  }
                  $1002 = HEAP32[3066992>>2]|0;
                  $1003 = HEAP32[$901>>2]|0;
                  $1004 = (($1003) + 92|0);
                  $1005 = HEAP32[$1004>>2]|0;
                  $1006 = ($1005*5)|0;
                  $1007 = (($918) + ($1006)|0);
                  HEAP32[$1007>>2] = $1002;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1008 = __THREW__; __THREW__ = 0;
                  $1009 = $1008&1;
                  if ($1009) {
                   break;
                  }
                  $1010 = HEAP32[$906>>2]|0;
                  $1011 = ($1010>>>0)<(7);
                  if ($1011) {
                   __THREW__ = 0;
                   $1012 = (invoke_i(132)|0);
                   $1013 = __THREW__; __THREW__ = 0;
                   $1014 = $1013&1;
                   if ($1014) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1012|0));
                   $1015 = __THREW__; __THREW__ = 0;
                   $1016 = $1015&1;
                   if ($1016) {
                    break;
                   }
                  }
                  $1017 = HEAP32[3067000>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1017|0));
                  $1018 = __THREW__; __THREW__ = 0;
                  $1019 = $1018&1;
                  if ($1019) {
                   break;
                  }
                  $1020 = HEAP32[3067000>>2]|0;
                  $1021 = HEAP32[$901>>2]|0;
                  $1022 = (($1021) + 92|0);
                  $1023 = HEAP32[$1022>>2]|0;
                  $1024 = ($1023*6)|0;
                  $1025 = (($918) + ($1024)|0);
                  HEAP32[$1025>>2] = $1020;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1026 = __THREW__; __THREW__ = 0;
                  $1027 = $1026&1;
                  if ($1027) {
                   break;
                  }
                  $1028 = HEAP32[$906>>2]|0;
                  $1029 = ($1028>>>0)<(8);
                  if ($1029) {
                   __THREW__ = 0;
                   $1030 = (invoke_i(132)|0);
                   $1031 = __THREW__; __THREW__ = 0;
                   $1032 = $1031&1;
                   if ($1032) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1030|0));
                   $1033 = __THREW__; __THREW__ = 0;
                   $1034 = $1033&1;
                   if ($1034) {
                    break;
                   }
                  }
                  $1035 = HEAP32[3067008>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1035|0));
                  $1036 = __THREW__; __THREW__ = 0;
                  $1037 = $1036&1;
                  if ($1037) {
                   break;
                  }
                  $1038 = HEAP32[3067008>>2]|0;
                  $1039 = HEAP32[$901>>2]|0;
                  $1040 = (($1039) + 92|0);
                  $1041 = HEAP32[$1040>>2]|0;
                  $1042 = ($1041*7)|0;
                  $1043 = (($918) + ($1042)|0);
                  HEAP32[$1043>>2] = $1038;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1044 = __THREW__; __THREW__ = 0;
                  $1045 = $1044&1;
                  if ($1045) {
                   break;
                  }
                  $1046 = HEAP32[$906>>2]|0;
                  $1047 = ($1046>>>0)<(9);
                  if ($1047) {
                   __THREW__ = 0;
                   $1048 = (invoke_i(132)|0);
                   $1049 = __THREW__; __THREW__ = 0;
                   $1050 = $1049&1;
                   if ($1050) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1048|0));
                   $1051 = __THREW__; __THREW__ = 0;
                   $1052 = $1051&1;
                   if ($1052) {
                    break;
                   }
                  }
                  $1053 = HEAP32[3067016>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1053|0));
                  $1054 = __THREW__; __THREW__ = 0;
                  $1055 = $1054&1;
                  if ($1055) {
                   break;
                  }
                  $1056 = HEAP32[3067016>>2]|0;
                  $1057 = HEAP32[$901>>2]|0;
                  $1058 = (($1057) + 92|0);
                  $1059 = HEAP32[$1058>>2]|0;
                  $1060 = $1059 << 3;
                  $1061 = (($918) + ($1060)|0);
                  HEAP32[$1061>>2] = $1056;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1062 = __THREW__; __THREW__ = 0;
                  $1063 = $1062&1;
                  if ($1063) {
                   break;
                  }
                  $1064 = HEAP32[$906>>2]|0;
                  $1065 = ($1064>>>0)<(10);
                  if ($1065) {
                   __THREW__ = 0;
                   $1066 = (invoke_i(132)|0);
                   $1067 = __THREW__; __THREW__ = 0;
                   $1068 = $1067&1;
                   if ($1068) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1066|0));
                   $1069 = __THREW__; __THREW__ = 0;
                   $1070 = $1069&1;
                   if ($1070) {
                    break;
                   }
                  }
                  $1071 = HEAP32[3067024>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1071|0));
                  $1072 = __THREW__; __THREW__ = 0;
                  $1073 = $1072&1;
                  if ($1073) {
                   break;
                  }
                  $1074 = HEAP32[3067024>>2]|0;
                  $1075 = HEAP32[$901>>2]|0;
                  $1076 = (($1075) + 92|0);
                  $1077 = HEAP32[$1076>>2]|0;
                  $1078 = ($1077*9)|0;
                  $1079 = (($918) + ($1078)|0);
                  HEAP32[$1079>>2] = $1074;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1080 = __THREW__; __THREW__ = 0;
                  $1081 = $1080&1;
                  if ($1081) {
                   break;
                  }
                  $1082 = HEAP32[$906>>2]|0;
                  $1083 = ($1082>>>0)<(11);
                  if ($1083) {
                   __THREW__ = 0;
                   $1084 = (invoke_i(132)|0);
                   $1085 = __THREW__; __THREW__ = 0;
                   $1086 = $1085&1;
                   if ($1086) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1084|0));
                   $1087 = __THREW__; __THREW__ = 0;
                   $1088 = $1087&1;
                   if ($1088) {
                    break;
                   }
                  }
                  $1089 = HEAP32[3067032>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1089|0));
                  $1090 = __THREW__; __THREW__ = 0;
                  $1091 = $1090&1;
                  if ($1091) {
                   break;
                  }
                  $1092 = HEAP32[3067032>>2]|0;
                  $1093 = HEAP32[$901>>2]|0;
                  $1094 = (($1093) + 92|0);
                  $1095 = HEAP32[$1094>>2]|0;
                  $1096 = ($1095*10)|0;
                  $1097 = (($918) + ($1096)|0);
                  HEAP32[$1097>>2] = $1092;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1098 = __THREW__; __THREW__ = 0;
                  $1099 = $1098&1;
                  if ($1099) {
                   break;
                  }
                  $1100 = HEAP32[$906>>2]|0;
                  $1101 = ($1100>>>0)<(12);
                  if ($1101) {
                   __THREW__ = 0;
                   $1102 = (invoke_i(132)|0);
                   $1103 = __THREW__; __THREW__ = 0;
                   $1104 = $1103&1;
                   if ($1104) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1102|0));
                   $1105 = __THREW__; __THREW__ = 0;
                   $1106 = $1105&1;
                   if ($1106) {
                    break;
                   }
                  }
                  $1107 = HEAP32[3067040>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1107|0));
                  $1108 = __THREW__; __THREW__ = 0;
                  $1109 = $1108&1;
                  if ($1109) {
                   break;
                  }
                  $1110 = HEAP32[3067040>>2]|0;
                  $1111 = HEAP32[$901>>2]|0;
                  $1112 = (($1111) + 92|0);
                  $1113 = HEAP32[$1112>>2]|0;
                  $1114 = ($1113*11)|0;
                  $1115 = (($918) + ($1114)|0);
                  HEAP32[$1115>>2] = $1110;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1116 = __THREW__; __THREW__ = 0;
                  $1117 = $1116&1;
                  if ($1117) {
                   break;
                  }
                  $1118 = HEAP32[$906>>2]|0;
                  $1119 = ($1118>>>0)<(13);
                  if ($1119) {
                   __THREW__ = 0;
                   $1120 = (invoke_i(132)|0);
                   $1121 = __THREW__; __THREW__ = 0;
                   $1122 = $1121&1;
                   if ($1122) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1120|0));
                   $1123 = __THREW__; __THREW__ = 0;
                   $1124 = $1123&1;
                   if ($1124) {
                    break;
                   }
                  }
                  $1125 = HEAP32[3067048>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1125|0));
                  $1126 = __THREW__; __THREW__ = 0;
                  $1127 = $1126&1;
                  if ($1127) {
                   break;
                  }
                  $1128 = HEAP32[3067048>>2]|0;
                  $1129 = HEAP32[$901>>2]|0;
                  $1130 = (($1129) + 92|0);
                  $1131 = HEAP32[$1130>>2]|0;
                  $1132 = ($1131*12)|0;
                  $1133 = (($918) + ($1132)|0);
                  HEAP32[$1133>>2] = $1128;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1134 = __THREW__; __THREW__ = 0;
                  $1135 = $1134&1;
                  if ($1135) {
                   break;
                  }
                  $1136 = HEAP32[$906>>2]|0;
                  $1137 = ($1136>>>0)<(14);
                  if ($1137) {
                   __THREW__ = 0;
                   $1138 = (invoke_i(132)|0);
                   $1139 = __THREW__; __THREW__ = 0;
                   $1140 = $1139&1;
                   if ($1140) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1138|0));
                   $1141 = __THREW__; __THREW__ = 0;
                   $1142 = $1141&1;
                   if ($1142) {
                    break;
                   }
                  }
                  $1143 = HEAP32[3067056>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1143|0));
                  $1144 = __THREW__; __THREW__ = 0;
                  $1145 = $1144&1;
                  if ($1145) {
                   break;
                  }
                  $1146 = HEAP32[3067056>>2]|0;
                  $1147 = HEAP32[$901>>2]|0;
                  $1148 = (($1147) + 92|0);
                  $1149 = HEAP32[$1148>>2]|0;
                  $1150 = ($1149*13)|0;
                  $1151 = (($918) + ($1150)|0);
                  HEAP32[$1151>>2] = $1146;
                  __THREW__ = 0;
                  invoke_vi(3799,($901|0));
                  $1152 = __THREW__; __THREW__ = 0;
                  $1153 = $1152&1;
                  if ($1153) {
                   break;
                  }
                  $1154 = HEAP32[$906>>2]|0;
                  $1155 = ($1154>>>0)<(15);
                  if ($1155) {
                   __THREW__ = 0;
                   $1156 = (invoke_i(132)|0);
                   $1157 = __THREW__; __THREW__ = 0;
                   $1158 = $1157&1;
                   if ($1158) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1156|0));
                   $1159 = __THREW__; __THREW__ = 0;
                   $1160 = $1159&1;
                   if ($1160) {
                    break;
                   }
                  }
                  $1161 = HEAP32[3067064>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($901|0),($1161|0));
                  $1162 = __THREW__; __THREW__ = 0;
                  $1163 = $1162&1;
                  if ($1163) {
                   break;
                  }
                  $1164 = HEAP32[3067064>>2]|0;
                  $1165 = HEAP32[$901>>2]|0;
                  $1166 = (($1165) + 92|0);
                  $1167 = HEAP32[$1166>>2]|0;
                  $1168 = ($1167*14)|0;
                  $1169 = (($918) + ($1168)|0);
                  HEAP32[$1169>>2] = $1164;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $1170 = __THREW__; __THREW__ = 0;
                  $1171 = $1170&1;
                  if ($1171) {
                   break;
                  }
                  $1172 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $1173 = (($1172) + 48|0);
                  HEAP32[$1173>>2] = $901;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1168432|0))|0);
                  $1174 = __THREW__; __THREW__ = 0;
                  $1175 = $1174&1;
                  if ($1175) {
                   break;
                  }
                  __THREW__ = 0;
                  $1176 = (invoke_iii(2768,(1168432|0),3)|0);
                  $1177 = __THREW__; __THREW__ = 0;
                  $1178 = $1177&1;
                  if ($1178) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($1176|0));
                  $1179 = __THREW__; __THREW__ = 0;
                  $1180 = $1179&1;
                  if ($1180) {
                   break;
                  }
                  $1181 = (($1176) + 12|0);
                  $1182 = HEAP32[$1181>>2]|0;
                  $1183 = ($1182|0)==(0);
                  if ($1183) {
                   __THREW__ = 0;
                   $1184 = (invoke_i(132)|0);
                   $1185 = __THREW__; __THREW__ = 0;
                   $1186 = $1185&1;
                   if ($1186) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1184|0));
                   $1187 = __THREW__; __THREW__ = 0;
                   $1188 = $1187&1;
                   if ($1188) {
                    break;
                   }
                  }
                  $1189 = HEAP32[3067072>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($1176|0),($1189|0));
                  $1190 = __THREW__; __THREW__ = 0;
                  $1191 = $1190&1;
                  if ($1191) {
                   break;
                  }
                  $1192 = HEAP32[3067072>>2]|0;
                  $1193 = (($1176) + 16|0);
                  HEAP32[$1193>>2] = $1192;
                  __THREW__ = 0;
                  invoke_vi(3799,($1176|0));
                  $1194 = __THREW__; __THREW__ = 0;
                  $1195 = $1194&1;
                  if ($1195) {
                   break;
                  }
                  $1196 = HEAP32[$1181>>2]|0;
                  $1197 = ($1196>>>0)<(2);
                  if ($1197) {
                   __THREW__ = 0;
                   $1198 = (invoke_i(132)|0);
                   $1199 = __THREW__; __THREW__ = 0;
                   $1200 = $1199&1;
                   if ($1200) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1198|0));
                   $1201 = __THREW__; __THREW__ = 0;
                   $1202 = $1201&1;
                   if ($1202) {
                    break;
                   }
                  }
                  $1203 = HEAP32[3067080>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($1176|0),($1203|0));
                  $1204 = __THREW__; __THREW__ = 0;
                  $1205 = $1204&1;
                  if ($1205) {
                   break;
                  }
                  $1206 = HEAP32[3067080>>2]|0;
                  $1207 = HEAP32[$1176>>2]|0;
                  $1208 = (($1207) + 92|0);
                  $1209 = HEAP32[$1208>>2]|0;
                  $1210 = (($1193) + ($1209)|0);
                  HEAP32[$1210>>2] = $1206;
                  __THREW__ = 0;
                  invoke_vi(3799,($1176|0));
                  $1211 = __THREW__; __THREW__ = 0;
                  $1212 = $1211&1;
                  if ($1212) {
                   break;
                  }
                  $1213 = HEAP32[$1181>>2]|0;
                  $1214 = ($1213>>>0)<(3);
                  if ($1214) {
                   __THREW__ = 0;
                   $1215 = (invoke_i(132)|0);
                   $1216 = __THREW__; __THREW__ = 0;
                   $1217 = $1216&1;
                   if ($1217) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1215|0));
                   $1218 = __THREW__; __THREW__ = 0;
                   $1219 = $1218&1;
                   if ($1219) {
                    break;
                   }
                  }
                  $1220 = HEAP32[3067088>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($1176|0),($1220|0));
                  $1221 = __THREW__; __THREW__ = 0;
                  $1222 = $1221&1;
                  if ($1222) {
                   break;
                  }
                  $1223 = HEAP32[3067088>>2]|0;
                  $1224 = HEAP32[$1176>>2]|0;
                  $1225 = (($1224) + 92|0);
                  $1226 = HEAP32[$1225>>2]|0;
                  $1227 = $1226 << 1;
                  $1228 = (($1193) + ($1227)|0);
                  HEAP32[$1228>>2] = $1223;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $1229 = __THREW__; __THREW__ = 0;
                  $1230 = $1229&1;
                  if ($1230) {
                   break;
                  }
                  $1231 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $1232 = (($1231) + 52|0);
                  HEAP32[$1232>>2] = $1176;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1168432|0))|0);
                  $1233 = __THREW__; __THREW__ = 0;
                  $1234 = $1233&1;
                  if ($1234) {
                   break;
                  }
                  __THREW__ = 0;
                  $1235 = (invoke_iii(2768,(1168432|0),3)|0);
                  $1236 = __THREW__; __THREW__ = 0;
                  $1237 = $1236&1;
                  if ($1237) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($1235|0));
                  $1238 = __THREW__; __THREW__ = 0;
                  $1239 = $1238&1;
                  if ($1239) {
                   break;
                  }
                  $1240 = (($1235) + 12|0);
                  $1241 = HEAP32[$1240>>2]|0;
                  $1242 = ($1241|0)==(0);
                  if ($1242) {
                   __THREW__ = 0;
                   $1243 = (invoke_i(132)|0);
                   $1244 = __THREW__; __THREW__ = 0;
                   $1245 = $1244&1;
                   if ($1245) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1243|0));
                   $1246 = __THREW__; __THREW__ = 0;
                   $1247 = $1246&1;
                   if ($1247) {
                    break;
                   }
                  }
                  $1248 = HEAP32[3067096>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($1235|0),($1248|0));
                  $1249 = __THREW__; __THREW__ = 0;
                  $1250 = $1249&1;
                  if ($1250) {
                   break;
                  }
                  $1251 = HEAP32[3067096>>2]|0;
                  $1252 = (($1235) + 16|0);
                  HEAP32[$1252>>2] = $1251;
                  __THREW__ = 0;
                  invoke_vi(3799,($1235|0));
                  $1253 = __THREW__; __THREW__ = 0;
                  $1254 = $1253&1;
                  if ($1254) {
                   break;
                  }
                  $1255 = HEAP32[$1240>>2]|0;
                  $1256 = ($1255>>>0)<(2);
                  if ($1256) {
                   __THREW__ = 0;
                   $1257 = (invoke_i(132)|0);
                   $1258 = __THREW__; __THREW__ = 0;
                   $1259 = $1258&1;
                   if ($1259) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1257|0));
                   $1260 = __THREW__; __THREW__ = 0;
                   $1261 = $1260&1;
                   if ($1261) {
                    break;
                   }
                  }
                  $1262 = HEAP32[3067104>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($1235|0),($1262|0));
                  $1263 = __THREW__; __THREW__ = 0;
                  $1264 = $1263&1;
                  if ($1264) {
                   break;
                  }
                  $1265 = HEAP32[3067104>>2]|0;
                  $1266 = HEAP32[$1235>>2]|0;
                  $1267 = (($1266) + 92|0);
                  $1268 = HEAP32[$1267>>2]|0;
                  $1269 = (($1252) + ($1268)|0);
                  HEAP32[$1269>>2] = $1265;
                  __THREW__ = 0;
                  invoke_vi(3799,($1235|0));
                  $1270 = __THREW__; __THREW__ = 0;
                  $1271 = $1270&1;
                  if ($1271) {
                   break;
                  }
                  $1272 = HEAP32[$1240>>2]|0;
                  $1273 = ($1272>>>0)<(3);
                  if ($1273) {
                   __THREW__ = 0;
                   $1274 = (invoke_i(132)|0);
                   $1275 = __THREW__; __THREW__ = 0;
                   $1276 = $1275&1;
                   if ($1276) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($1274|0));
                   $1277 = __THREW__; __THREW__ = 0;
                   $1278 = $1277&1;
                   if ($1278) {
                    break;
                   }
                  }
                  $1279 = HEAP32[3067112>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(3492,($1235|0),($1279|0));
                  $1280 = __THREW__; __THREW__ = 0;
                  $1281 = $1280&1;
                  if ($1281) {
                   break;
                  }
                  $1282 = HEAP32[3067112>>2]|0;
                  $1283 = HEAP32[$1235>>2]|0;
                  $1284 = (($1283) + 92|0);
                  $1285 = HEAP32[$1284>>2]|0;
                  $1286 = $1285 << 1;
                  $1287 = (($1252) + ($1286)|0);
                  HEAP32[$1287>>2] = $1282;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $1288 = __THREW__; __THREW__ = 0;
                  $1289 = $1288&1;
                  if ($1289) {
                   break;
                  }
                  $1290 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $1291 = (($1290) + 56|0);
                  HEAP32[$1291>>2] = $1235;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1170368|0))|0);
                  $1292 = __THREW__; __THREW__ = 0;
                  $1293 = $1292&1;
                  if ($1293) {
                   break;
                  }
                  __THREW__ = 0;
                  $1294 = (invoke_iii(2768,(1170368|0),13)|0);
                  $1295 = __THREW__; __THREW__ = 0;
                  $1296 = $1295&1;
                  if ($1296) {
                   break;
                  }
                  HEAP32[$2>>2] = 2667368;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
                  invoke_viii(551,(0|0),($1294|0),($$byval_copy3|0));
                  $1297 = __THREW__; __THREW__ = 0;
                  $1298 = $1297&1;
                  if ($1298) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $1299 = __THREW__; __THREW__ = 0;
                  $1300 = $1299&1;
                  if ($1300) {
                   break;
                  }
                  $1301 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $1302 = (($1301) + 60|0);
                  HEAP32[$1302>>2] = $1294;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1170368|0))|0);
                  $1303 = __THREW__; __THREW__ = 0;
                  $1304 = $1303&1;
                  if ($1304) {
                   break;
                  }
                  __THREW__ = 0;
                  $1305 = (invoke_iii(2768,(1170368|0),13)|0);
                  $1306 = __THREW__; __THREW__ = 0;
                  $1307 = $1306&1;
                  if ($1307) {
                   break;
                  }
                  HEAP32[$3>>2] = 2667408;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
                  invoke_viii(551,(0|0),($1305|0),($$byval_copy3|0));
                  $1308 = __THREW__; __THREW__ = 0;
                  $1309 = $1308&1;
                  if ($1309) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $1310 = __THREW__; __THREW__ = 0;
                  $1311 = $1310&1;
                  if ($1311) {
                   break;
                  }
                  $1312 = HEAP32[((2592096 + 80|0))>>2]|0;
                  $1313 = (($1312) + 64|0);
                  HEAP32[$1313>>2] = $1305;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2615032|0))|0);
                  $1314 = __THREW__; __THREW__ = 0;
                  $1315 = $1314&1;
                  if ($1315) {
                   break;
                  }
                  $1316 = HEAP8[((2615032 + 116|0))>>0]|0;
                  $1317 = ($1316<<24>>24)==(0);
                  if ($1317) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2615032|0))|0);
                   $1318 = __THREW__; __THREW__ = 0;
                   $1319 = $1318&1;
                   if ($1319) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2615032|0))|0);
                   $1320 = __THREW__; __THREW__ = 0;
                   $1321 = $1320&1;
                   if ($1321) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3839,(2615032|0));
                   $1322 = __THREW__; __THREW__ = 0;
                   $1323 = $1322&1;
                   if ($1323) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2615032|0))|0);
                  $1324 = __THREW__; __THREW__ = 0;
                  $1325 = $1324&1;
                  if ($1325) {
                   break;
                  }
                  $1326 = HEAP32[((2615032 + 80|0))>>2]|0;
                  $1327 = HEAP8[$1326>>0]|0;
                  $1328 = ($1327<<24>>24)==(0);
                  if ($1328) {
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(1649888|0))|0);
                  $1329 = __THREW__; __THREW__ = 0;
                  $1330 = $1329&1;
                  if ($1330) {
                   break;
                  }
                  __THREW__ = 0;
                  $1331 = (invoke_ii(3469,(1649888|0))|0);
                  $1332 = __THREW__; __THREW__ = 0;
                  $1333 = $1332&1;
                  if ($1333) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(1633,($1331|0));
                  $1334 = __THREW__; __THREW__ = 0;
                  $1335 = $1334&1;
                  if ($1335) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(1651824|0))|0);
                  $1336 = __THREW__; __THREW__ = 0;
                  $1337 = $1336&1;
                  if ($1337) {
                   break;
                  }
                  __THREW__ = 0;
                  $1338 = (invoke_ii(3469,(1651824|0))|0);
                  $1339 = __THREW__; __THREW__ = 0;
                  $1340 = $1339&1;
                  if ($1340) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(1637,($1338|0));
                  $1341 = __THREW__; __THREW__ = 0;
                  $1342 = $1341&1;
                  if ($1342) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $64 = ___cxa_find_matching_catch()|0;
 $65 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($64|0);
 // unreachable;
}
function __Z56mscorlib_System_DateTime_m_System_IConvertible_ToBooleanP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584760);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_DateTime_m_System_IConvertible_ToByteP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584808);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_DateTime_m_System_IConvertible_ToCharP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584856);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_DateTime_m_System_IConvertible_ToDateTimeP24mscorlib_System_DateTimeP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584904);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$__this+12>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z56mscorlib_System_DateTime_m_System_IConvertible_ToDecimalP24mscorlib_System_DateTimeP22mscorlib_System_Object($agg$result,$__this,$provider) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2584952);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z55mscorlib_System_DateTime_m_System_IConvertible_ToDoubleP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585000);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return +0;
}
function __Z54mscorlib_System_DateTime_m_System_IConvertible_ToInt16P24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585048);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_DateTime_m_System_IConvertible_ToInt32P24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585096);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_DateTime_m_System_IConvertible_ToInt64P24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585144);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z54mscorlib_System_DateTime_m_System_IConvertible_ToSByteP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585192);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_DateTime_m_System_IConvertible_ToSingleP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585240);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return Math_fround(0);
}
function __Z53mscorlib_System_DateTime_m_System_IConvertible_ToTypeP24mscorlib_System_DateTimeP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$targetType,$provider) {
 $__this = $__this|0;
 $targetType = $targetType|0;
 $provider = $provider|0;
 var $$0 = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $L_7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp + 48|0;
 $_stackTraceSentry = sp + 44|0;
 $0 = sp + 32|0;
 $L_2 = sp;
 $1 = sp + 36|0;
 $2 = sp + 40|0;
 $L_7 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585288);
 __THREW__ = 0;
 invoke_v(865);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = ($targetType|0)==(0|0);
   if ($5) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = HEAP32[3067944>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($10|0),($13|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($10|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    // unreachable;
   }
   HEAP32[$0>>2] = 1692712;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;
   $18 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = ($18|0)==($targetType|0);
    if ($21) {
     ;HEAP32[$L_2+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[$__this+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __THREW__ = 0;
     $24 = (invoke_iii(2724,(2592096|0),($L_2|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $$0 = $24;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    HEAP32[$1>>2] = 1284472;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;
    $27 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)==($targetType|0);
     if ($30) {
      __THREW__ = 0;
      $31 = (invoke_iii(1117,($__this|0),($provider|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      $$0 = $31;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     HEAP32[$2>>2] = 1284448;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
     $34 = (invoke_iii(772,(0|0),($$byval_copy2|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if (!($36)) {
      $37 = ($34|0)==($targetType|0);
      if ($37) {
       ;HEAP32[$L_7+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_7+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_7+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$L_7+12>>2]=HEAP32[$__this+12>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
       __THREW__ = 0;
       $40 = (invoke_iii(2724,(2592096|0),($L_7|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
       $$0 = $40;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2607384|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       __THREW__ = 0;
       $45 = (invoke_ii(3469,(2607384|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        __THREW__ = 0;
        invoke_vi(2732,($45|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if (!($49)) {
         __THREW__ = 0;
         invoke_vi(3838,($45|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_DateTime_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587584);
 __THREW__ = 0;
 $0 = (invoke_iiii(1160,($__this|0),(0|0),($provider|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z55mscorlib_System_DateTime_m_System_IConvertible_ToUInt16P24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585336);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_DateTime_m_System_IConvertible_ToUInt32P24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585384);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z55mscorlib_System_DateTime_m_System_IConvertible_ToUInt64P24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$provider) {
 $__this = $__this|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585432);
 __THREW__ = 0;
 (invoke_ii(2996,(2607384|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2607384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2732,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_DateTime_m_IsLeapYearP22mscorlib_System_Objecti($__this,$year) {
 $__this = $__this|0;
 $year = $year|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B7_0$0 = 0, $_stackTraceSentry = 0;
 var $or$cond2 = 0, $year$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586816);
 $year$off = (($year) + -1)|0;
 $0 = ($year$off>>>0)<(9999);
 if ($0) {
  $12 = $year & 3;
  $13 = ($12|0)!=(0);
  $14 = (($year|0) % 100)&-1;
  $15 = ($14|0)==(0);
  $or$cond2 = $13 | $15;
  if (!($or$cond2)) {
   $G_B7_0$0 = 1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B7_0$0|0);
  }
  $16 = (($year|0) % 400)&-1;
  $17 = ($16|0)==(0);
  $G_B7_0$0 = $17;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B7_0$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2561352|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(3469,(2561352|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vi(2587,($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3838,($3|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     // unreachable;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_DateTime_m_FromTicksP24mscorlib_System_DateTimei($__this,$what) {
 $__this = $__this|0;
 $what = $what|0;
 var $$ = 0, $$0 = 0, $$off = 0, $$off1 = 0, $$off2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $V_4$0 = 0, $V_4$0$ = 0, $V_5$0$ph = 0, $V_6$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585528);
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP8[((2592096 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2592096|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[((2592096 + 80|0))>>2]|0;
    $17 = (($16) + 60|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_ii(2494,($__this|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($19|0) / 146097)&-1;
     $23 = Math_imul($22, -146097)|0;
     $24 = (($23) + ($19))|0;
     $25 = (($24|0) / 36524)&-1;
     $$off = (($24) + -146096)|0;
     $26 = ($$off>>>0)>(36523);
     $$ = $26 ? $25 : 3;
     $27 = Math_imul($$, -36524)|0;
     $28 = (($27) + ($24))|0;
     $29 = (($28|0) / 1461)&-1;
     $30 = Math_imul($29, -1461)|0;
     $31 = (($28) + ($30))|0;
     $32 = (($31|0) / 365)&-1;
     $$off1 = (($31) + -1460)|0;
     $33 = ($$off1>>>0)>(364);
     $V_3$0 = $33 ? $32 : 3;
     $34 = ($what|0)==(3);
     if ($34) {
      $35 = ($22*400)|0;
      $36 = ($$*100)|0;
      $37 = $29 << 2;
      $38 = $35 | 1;
      $39 = (($38) + ($37))|0;
      $40 = (($39) + ($36))|0;
      $41 = (($40) + ($V_3$0))|0;
      $$0 = $41;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $42 = Math_imul($V_3$0, -365)|0;
     $43 = (($42) + ($31))|0;
     $44 = ($what|0)==(1);
     if ($44) {
      $45 = (($43) + 1)|0;
      $$0 = $45;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $46 = ($V_3$0|0)==(3);
     do {
      if ($46) {
       $47 = ($$|0)==(3);
       if (!($47)) {
        $$off2 = (($28) + -35064)|0;
        $48 = ($$off2>>>0)<(1461);
        if ($48) {
         $V_5$0$ph = $18;
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break L1;
       }
       $51 = HEAP8[((2592096 + 116|0))>>0]|0;
       $52 = ($51<<24>>24)==(0);
       if ($52) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2592096|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         break L1;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break L1;
       }
       $61 = HEAP32[((2592096 + 80|0))>>2]|0;
       $62 = (($61) + 64|0);
       $63 = HEAP32[$62>>2]|0;
       $V_5$0$ph = $63;
      } else {
       $V_5$0$ph = $18;
      }
     } while(0);
     $64 = (($V_5$0$ph) + 16|0);
     $65 = (($V_5$0$ph) + 12|0);
     $V_4$0 = 1;$V_6$0 = $43;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($V_5$0$ph|0));
      $80 = __THREW__; __THREW__ = 0;
      $81 = $80&1;
      if ($81) {
       label = 6;
       break;
      }
      $82 = HEAP32[$65>>2]|0;
      $83 = ($V_4$0>>>0)<($82>>>0);
      if (!($83)) {
       __THREW__ = 0;
       $84 = (invoke_i(132)|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        label = 6;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($84|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        label = 6;
        break;
       }
      }
      $89 = HEAP32[$V_5$0$ph>>2]|0;
      $90 = (($89) + 92|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = Math_imul($91, $V_4$0)|0;
      $93 = (($64) + ($92)|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = ($V_6$0|0)<($94|0);
      if ($95) {
       label = 36;
       break;
      }
      $96 = (($V_4$0) + 1)|0;
      __THREW__ = 0;
      invoke_vi(3799,($V_5$0$ph|0));
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       label = 6;
       break;
      }
      $66 = HEAP32[$65>>2]|0;
      $67 = ($V_4$0>>>0)<($66>>>0);
      if (!($67)) {
       __THREW__ = 0;
       $68 = (invoke_i(132)|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 6;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($68|0));
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        label = 6;
        break;
       }
      }
      $73 = HEAP32[$V_5$0$ph>>2]|0;
      $74 = (($73) + 92|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = Math_imul($75, $V_4$0)|0;
      $77 = (($64) + ($76)|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = (($V_6$0) - ($78))|0;
      $V_4$0 = $96;$V_6$0 = $79;
     }
     if ((label|0) == 6) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 36) {
      $99 = ($what|0)==(2);
      $100 = (($V_6$0) + 1)|0;
      $V_4$0$ = $99 ? $V_4$0 : $100;
      $$0 = $V_4$0$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_DateTime_m_get_MonthP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585576);
 __THREW__ = 0;
 $0 = (invoke_iii(1111,($__this|0),2)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z34mscorlib_System_DateTime_m_get_DayP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585624);
 __THREW__ = 0;
 $0 = (invoke_iii(1111,($__this|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z40mscorlib_System_DateTime_m_get_DayOfWeekP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585672);
 __THREW__ = 0;
 $0 = (invoke_ii(2494,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = (($0) + 1)|0;
  $4 = (($3|0) % 7)&-1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z35mscorlib_System_DateTime_m_get_HourP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585720);
 __THREW__ = 0;
 $0 = (invoke_ii(2495,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z37mscorlib_System_DateTime_m_get_MinuteP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585768);
 __THREW__ = 0;
 $0 = (invoke_ii(2497,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z37mscorlib_System_DateTime_m_get_SecondP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585816);
 __THREW__ = 0;
 $0 = (invoke_ii(2498,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z33mscorlib_System_DateTime_m_GetNowP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585864);
 $0 = HEAP32[2585912>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2585920|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2585912>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = tempRet0;
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $9;
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_DateTime_m_get_NowP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_12 = 0, $L_7 = 0, $V_1 = 0, $V_1$byval_copy1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp + 64|0;
 $V_1$byval_copy1 = sp;
 $_stackTraceSentry = sp + 80|0;
 $V_1 = sp + 24|0;
 $L_7 = sp + 40|0;
 $L_12 = sp + 48|0;
 $0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2585952);
 ;HEAP32[$V_1+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_ii(2431,0)|0);
 $2 = tempRet0;
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   __THREW__ = 0;
   invoke_viii(661,($V_1|0),($1|0),($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP8[((2592096 + 116|0))>>0]|0;
     $10 = ($9<<24>>24)==(0);
     if ($10) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2592096|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = HEAP32[((2592096 + 80|0))>>2]|0;
      $22 = (($21) + 72|0);
      $23 = $22;
      $24 = $23;
      $25 = HEAP32[$24>>2]|0;
      $26 = (($23) + 4)|0;
      $27 = $26;
      $28 = HEAP32[$27>>2]|0;
      $29 = (_i64Subtract(($1|0),($2|0),($25|0),($28|0))|0);
      $30 = tempRet0;
      $31 = ($30|0)<(0);
      $32 = ($30|0)==(0);
      $33 = ($29>>>0)<(600000001);
      $34 = $32 & $33;
      $35 = $31 | $34;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_ii(2504,(0|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($36|0));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$V_1+12>>2]|0;
       $41 = (invoke_iii(1166,($36|0),($$byval_copy|0))|0);
       $42 = tempRet0;
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break;
       }
       $45 = $L_7;
       $46 = $45;
       HEAP32[$46>>2] = $41;
       $47 = (($45) + 4)|0;
       $48 = $47;
       HEAP32[$48>>2] = $42;
       __THREW__ = 0;
       (invoke_ii(2996,(2652728|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
       __THREW__ = 0;
       $51 = (invoke_iii(2724,(2652728|0),($L_7|0))|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       }
       $56 = HEAP8[((2592096 + 116|0))>>0]|0;
       $57 = ($56<<24>>24)==(0);
       if ($57) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2592096|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break;
       }
       $66 = HEAP32[((2592096 + 80|0))>>2]|0;
       $67 = (($66) + 68|0);
       HEAP32[$67>>2] = $51;
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       $70 = HEAP8[((2592096 + 116|0))>>0]|0;
       $71 = ($70<<24>>24)==(0);
       if ($71) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2592096|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       }
       $80 = HEAP32[((2592096 + 80|0))>>2]|0;
       $81 = (($80) + 72|0);
       $82 = $81;
       $83 = $82;
       HEAP32[$83>>2] = $1;
       $84 = (($82) + 4)|0;
       $85 = $84;
       HEAP32[$85>>2] = $2;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if (!($87)) {
       $88 = HEAP8[((2592096 + 116|0))>>0]|0;
       $89 = ($88<<24>>24)==(0);
       if ($89) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2592096|0));
        $94 = __THREW__; __THREW__ = 0;
        $95 = $94&1;
        if ($95) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if (!($97)) {
        $98 = HEAP32[((2592096 + 80|0))>>2]|0;
        $99 = (($98) + 68|0);
        $100 = HEAP32[$99>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2652728|0))|0);
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if (!($102)) {
         __THREW__ = 0;
         $103 = (invoke_iii(2770,($100|0),(2652728|0))|0);
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if (!($105)) {
          $106 = $103;
          $107 = $106;
          $108 = HEAP32[$107>>2]|0;
          $109 = (($106) + 4)|0;
          $110 = $109;
          $111 = HEAP32[$110>>2]|0;
          $112 = $0;
          $113 = $112;
          HEAP32[$113>>2] = $108;
          $114 = (($112) + 4)|0;
          $115 = $114;
          HEAP32[$115>>2] = $111;
          __THREW__ = 0;
          ;HEAP32[$V_1$byval_copy1+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$V_1$byval_copy1+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$V_1$byval_copy1+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$V_1$byval_copy1+12>>2]=HEAP32[$V_1+12>>2]|0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
          invoke_viiii(190,($L_12|0),0,($V_1$byval_copy1|0),($$byval_copy|0));
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if (!($117)) {
           ;HEAP32[$agg$result+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_12+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_12+12>>2]|0;
           $118 = (($agg$result) + 8|0);
           HEAP32[$118>>2] = 2;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z113mscorlib_System_DateTime_m_op_Addition_mscorlib_System_DateTime_mscorlib_System_DateTime_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_DateTime24mscorlib_System_TimeSpan($agg$result,$__this,$d,$t) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d = $d|0;
 $t = $t|0;
 var $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy2 = sp + 32|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 40|0;
 $0 = sp + 16|0;
 $1 = sp + 24|0;
 $2 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587776);
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 $3 = $d;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = $t;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $1;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$1+4>>2]|0;
 $23 = (invoke_iiii(1261,(0|0),($$byval_copy|0),($$byval_copy2|0))|0);
 $24 = tempRet0;
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($36|0);
  // unreachable;
 }
 $27 = $2;
 $28 = $27;
 HEAP32[$28>>2] = $23;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $24;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 invoke_viii(662,($agg$result|0),1,($$byval_copy2|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($36|0);
  // unreachable;
 } else {
  $33 = (($d) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($agg$result) + 8|0);
  HEAP32[$35>>2] = $34;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z36mscorlib_System_DateTime_m_get_TodayP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $V_0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_0 = sp;
 $L_0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586048);
 ;HEAP32[$V_0+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 invoke_vii(1930,($L_0|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$V_0+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_0+12>>2]|0;
  __THREW__ = 0;
  $2 = (invoke_ii(2433,($V_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(2425,($V_0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(2426,($V_0|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_viiii(185,($agg$result|0),($2|0),($5|0),($8|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = (($V_0) + 8|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($agg$result) + 8|0);
      HEAP32[$15>>2] = $14;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z35mscorlib_System_DateTime_m_get_YearP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586096);
 __THREW__ = 0;
 $0 = (invoke_iii(1111,($__this|0),3)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z35mscorlib_System_DateTime_m_get_KindP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586144);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z30mscorlib_System_DateTime_m_AddP24mscorlib_System_DateTime24mscorlib_System_TimeSpan($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586192);
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 $0 = (invoke_ii(2499,($value|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viiii(187,($L_1|0),($__this|0),($0|0),($1|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_1+12>>2]|0;
  $6 = (($__this) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($agg$result) + 8|0);
  HEAP32[$8>>2] = $7;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z35mscorlib_System_DateTime_m_AddTicksP24mscorlib_System_DateTimex($agg$result,$__this,$0,$1) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586240);
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_ii(2499,($__this|0))|0);
 $3 = tempRet0;
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (_i64Add(($2|0),($3|0),($0|0),($1|0))|0);
   $7 = tempRet0;
   $8 = ($7|0)>(734668917);
   $9 = ($7|0)==(734668917);
   $10 = ($6>>>0)>(4097261567);
   $11 = $9 & $10;
   $12 = $8 | $11;
   if (!($12)) {
    __THREW__ = 0;
    $15 = (invoke_ii(2499,($__this|0))|0);
    $16 = tempRet0;
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    $19 = (_i64Add(($15|0),($16|0),($0|0),($1|0))|0);
    $20 = tempRet0;
    $21 = ($20|0)>(-1);
    $22 = ($20|0)==(-1);
    $23 = ($19>>>0)>(4294967295);
    $24 = $22 & $23;
    $25 = $21 | $24;
    if ($25) {
     __THREW__ = 0;
     $35 = (invoke_ii(2499,($__this|0))|0);
     $36 = tempRet0;
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     $39 = (_i64Add(($35|0),($36|0),($0|0),($1|0))|0);
     $40 = tempRet0;
     __THREW__ = 0;
     invoke_viii(661,($agg$result|0),($39|0),($40|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     $43 = (($__this) + 8|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($agg$result) + 8|0);
     HEAP32[$45>>2] = $44;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    __THREW__ = 0;
    $28 = (invoke_ii(3469,(2561352|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if (!($30)) {
     __THREW__ = 0;
     invoke_vi(2587,($28|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      invoke_vi(3838,($28|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z42mscorlib_System_DateTime_m_AddMillisecondsP24mscorlib_System_DateTimed($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586288);
 $0 = $value * 1.0E+4;
 $1 = $0 > 9223372036854775808.0;
 $2 = !($0 >= -9223372036854775808.0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  __THREW__ = 0;
  (invoke_ii(2996,(2561352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2561352|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2587,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3838,($5|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  $14 = (+invoke_did(3,0,(+$0)));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $17 = (~~$14)>>>0;
   $18 = +Math_abs($14) >= 1.0 ? $14 > 0.0 ? (Math_min(+Math_floor($14 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($14 - +(~~$14 >>> 0)) / 4294967296.0) >>> 0 : 0;
   __THREW__ = 0;
   invoke_viiii(187,($agg$result|0),($__this|0),($17|0),($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z37mscorlib_System_DateTime_m_AddSecondsP24mscorlib_System_DateTimed($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = +$value;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586336);
 $0 = $value * 1000.0;
 __THREW__ = 0;
 invoke_viid(3,($agg$result|0),($__this|0),(+$0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z34mscorlib_System_DateTime_m_CompareP22mscorlib_System_Object24mscorlib_System_DateTimeS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$ = 0, $$0 = 0, $$byval_copy2 = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy3 = sp + 40|0;
 $$byval_copy2 = sp;
 $_stackTraceSentry = sp + 48|0;
 $0 = sp + 16|0;
 $1 = sp + 24|0;
 $2 = sp + 32|0;
 $3 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586384);
 $4 = $t1;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $t2;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $0;
 $17 = $16;
 HEAP32[$17>>2] = $6;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $9;
 $20 = $1;
 $21 = $20;
 HEAP32[$21>>2] = $12;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $15;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$1+4>>2]|0;
 $24 = (invoke_iiii(1267,(0|0),($$byval_copy2|0),($$byval_copy3|0))|0);
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($27|0);
  // unreachable;
 }
 if ($24) {
  $$0 = -1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $29 = $2;
 $30 = $29;
 HEAP32[$30>>2] = $6;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $9;
 $33 = $3;
 $34 = $33;
 HEAP32[$34>>2] = $12;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $15;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$3+4>>2]|0;
 $37 = (invoke_iiii(1264,(0|0),($$byval_copy2|0),($$byval_copy3|0))|0);
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $27 = ___cxa_find_matching_catch()|0;
  $28 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($27|0);
  // unreachable;
 }
 $$ = $37&1;
 $$0 = $$;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z81mscorlib_System_DateTime_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 32|0;
 $__this$byval_copy = sp;
 $_stackTraceSentry = sp + 48|0;
 $0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586432);
 __THREW__ = 0;
 invoke_v(866);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($value|0)==(0|0);
   if ($3) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2735,($value|0),(2592096|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = ($8|0)==(0|0);
     if (!($11)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_iii(2770,($value|0),(2592096|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      ;HEAP32[$0+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$27+12>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
      $30 = (invoke_iiii(1145,0,($__this$byval_copy|0),($$byval_copy|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      } else {
       $$0 = $30;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $12 = HEAP32[3067960>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iii(783,(0|0),($12|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_ii(3469,(2560072|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        invoke_vii(1924,($18|0),($13|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         invoke_vi(3838,($18|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_DateTime_m_CompareTo_mscorlib_System_Int32_mscorlib_System_DateTimeP24mscorlib_System_DateTimeS_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $value$byval_copy = sp + 16|0;
 $__this$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586480);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 $0 = (invoke_iiii(1145,0,($__this$byval_copy|0),($value$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z82mscorlib_System_DateTime_m_Equals_mscorlib_System_Boolean_mscorlib_System_DateTimeP24mscorlib_System_DateTimeS_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586528);
 $2 = $value;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $__this;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = $4;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $7;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $10;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $13;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $22 = (invoke_iiii(1263,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($22|0);
 }
 return 0|0;
}
function __Z38mscorlib_System_DateTime_m_SpecifyKindP22mscorlib_System_Object24mscorlib_System_DateTimei($agg$result,$__this,$value,$kind) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 $kind = $kind|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586576);
 __THREW__ = 0;
 $0 = (invoke_ii(2432,($value|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 invoke_viiii(186,($agg$result|0),($0|0),($1|0),($kind|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z80mscorlib_System_DateTime_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP24mscorlib_System_DateTimeP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586672);
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iii(2735,($value|0),(2592096|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = ($4|0)==(0|0);
   if ($7) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(2770,($value|0),(2592096|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = $12;
     $16 = $15;
     $17 = HEAP32[$16>>2]|0;
     $18 = (($15) + 4)|0;
     $19 = $18;
     $20 = HEAP32[$19>>2]|0;
     $21 = $__this;
     $22 = $21;
     $23 = HEAP32[$22>>2]|0;
     $24 = (($21) + 4)|0;
     $25 = $24;
     $26 = HEAP32[$25>>2]|0;
     $27 = $0;
     $28 = $27;
     HEAP32[$28>>2] = $17;
     $29 = (($27) + 4)|0;
     $30 = $29;
     HEAP32[$30>>2] = $20;
     $31 = $1;
     $32 = $31;
     HEAP32[$32>>2] = $23;
     $33 = (($31) + 4)|0;
     $34 = $33;
     HEAP32[$34>>2] = $26;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
     $35 = (invoke_iiii(1263,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      $$0 = $35;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_DateTime_m_GetHashCodeP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586768);
 __THREW__ = 0;
 $0 = (invoke_ii(2499,($__this|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z157mscorlib_System_DateTime_m_Parse_mscorlib_System_DateTime_mscorlib_System_String_mscorlib_System_IFormatProvider_mscorlib_System_Globalization_DateTimeStylesP22mscorlib_System_ObjectP22mscorlib_System_StringS0_i($agg$result,$__this,$s,$provider,$styles) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 $styles = $styles|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_1 = 0, $V_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 28|0;
 $V_1 = sp;
 $V_2 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586912);
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_1+0>>2]=HEAP32[2593152+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2593152+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2593152+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2593152+12>>2]|0;HEAP32[$V_1+16>>2]=HEAP32[2593152+16>>2]|0;HEAP32[$V_1+20>>2]=HEAP32[2593152+20>>2]|0;
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(867);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3068128>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   } else {
    HEAP32[$V_2>>2] = 0;
    __THREW__ = 0;
    $15 = (invoke_iiiiiiiii(23,0,($s|0),($provider|0),($styles|0),($agg$result|0),($V_1|0),1,($V_2|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    if ($15) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $18 = HEAP32[$V_2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3838,($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    // unreachable;
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z36mscorlib_System_DateTime_m_CoreParseP22mscorlib_System_ObjectP22mscorlib_System_StringS0_iP24mscorlib_System_DateTimeP30mscorlib_System_DateTimeOffsetbPP25mscorlib_System_Exception($__this,$s,$provider,$styles,$result,$dto,$setExceptionOnError,$exception) {
 $__this = $__this|0;
 $s = $s|0;
 $provider = $provider|0;
 $styles = $styles|0;
 $result = $result|0;
 $dto = $dto|0;
 $setExceptionOnError = $setExceptionOnError|0;
 $exception = $exception|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $G_B29_0$0 = 0, $G_B29_0$0$in$in = 0, $V_11$0 = 0, $V_12 = 0, $V_13$0 = 0, $V_15 = 0, $V_16$0 = 0, $V_17$0 = 0, $V_2 = 0, $V_3$0 = 0, $V_5 = 0, $V_6$0 = 0, $_stackTraceSentry = 0, $brmerge = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0, $or$cond = 0, $setExceptionOnError$not = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp + 23|0;
 $V_5 = sp + 22|0;
 $V_12 = sp + 20|0;
 $V_15 = sp + 21|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2586960);
 HEAP8[$V_2>>0] = 0;
 HEAP8[$V_5>>0] = 0;
 HEAP8[$V_12>>0] = 0;
 HEAP8[$V_15>>0] = 0;
 __THREW__ = 0;
 invoke_v(868);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2652728 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2652728|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2652728|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if (!($28)) {
     $29 = HEAP32[((2652728 + 80|0))>>2]|0;
     $30 = (($29) + 16|0);
     $31 = $30;
     $32 = $31;
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + 4)|0;
     $35 = $34;
     $36 = HEAP32[$35>>2]|0;
     $37 = $0;
     $38 = $37;
     HEAP32[$38>>2] = $33;
     $39 = (($37) + 4)|0;
     $40 = $39;
     HEAP32[$40>>2] = $36;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     invoke_viiii(192,($dto|0),0,0,($$byval_copy|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      $43 = ($s|0)==(0|0);
      if (!($43)) {
       __THREW__ = 0;
       invoke_vi(3799,($s|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
       __THREW__ = 0;
       $46 = (invoke_ii(1816,($s|0))|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
       $49 = ($46|0)==(0);
       if (!($49)) {
        $72 = ($provider|0)==(0|0);
        if ($72) {
         __THREW__ = 0;
         $73 = (invoke_ii(1982,(0|0))|0);
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          break;
         }
         $$01 = $73;
        } else {
         $$01 = $provider;
        }
        __THREW__ = 0;
        $76 = (invoke_iii(852,(0|0),($$01|0))|0);
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         break;
        }
        __THREW__ = 0;
        $79 = (invoke_iiiii(180,0,($76|0),($setExceptionOnError|0),($exception|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         break;
        }
        $82 = ($79|0)==(0|0);
        if ($82) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break;
         }
         $85 = HEAP8[((2592096 + 116|0))>>0]|0;
         $86 = ($85<<24>>24)==(0);
         if ($86) {
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $87 = __THREW__; __THREW__ = 0;
          $88 = $87&1;
          if ($88) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $89 = __THREW__; __THREW__ = 0;
          $90 = $89&1;
          if ($90) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2592096|0));
          $91 = __THREW__; __THREW__ = 0;
          $92 = $91&1;
          if ($92) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          break;
         }
         $95 = HEAP32[((2592096 + 80|0))>>2]|0;
         $96 = (($95) + 16|0);
         _memmove(($result|0),($96|0),16)|0;
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        HEAP8[$V_2>>0] = 0;
        $97 = (($79) + 12|0);
        $98 = (($79) + 16|0);
        $V_3$0 = 0;
        L33: while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($79|0));
         $188 = __THREW__; __THREW__ = 0;
         $189 = $188&1;
         if ($189) {
          label = 12;
          break;
         }
         $190 = HEAP32[$97>>2]|0;
         $191 = ($V_3$0|0)<($190|0);
         if (!($191)) {
          label = 83;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($79|0));
         $192 = __THREW__; __THREW__ = 0;
         $193 = $192&1;
         if ($193) {
          label = 12;
          break;
         }
         $99 = HEAP32[$97>>2]|0;
         $100 = ($V_3$0>>>0)<($99>>>0);
         if (!($100)) {
          __THREW__ = 0;
          $101 = (invoke_i(132)|0);
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           label = 12;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($101|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 12;
           break;
          }
         }
         $106 = HEAP32[$79>>2]|0;
         $107 = (($106) + 92|0);
         $108 = HEAP32[$107>>2]|0;
         $109 = Math_imul($108, $V_3$0)|0;
         $110 = (($98) + ($109)|0);
         $111 = HEAP32[$110>>2]|0;
         HEAP8[$V_5>>0] = 0;
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if ($113) {
          label = 12;
          break;
         }
         $114 = HEAP8[((2191608 + 116|0))>>0]|0;
         $115 = ($114<<24>>24)==(0);
         if ($115) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $116 = __THREW__; __THREW__ = 0;
          $117 = $116&1;
          if ($117) {
           label = 12;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $118 = __THREW__; __THREW__ = 0;
          $119 = $118&1;
          if ($119) {
           label = 12;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2191608|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 12;
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          label = 12;
          break;
         }
         $124 = HEAP32[((2191608 + 80|0))>>2]|0;
         $125 = HEAP32[$124>>2]|0;
         __THREW__ = 0;
         $126 = (invoke_iiiiiiiiiiiii(3,0,($s|0),($111|0),($125|0),0,($result|0),($dto|0),($76|0),($styles|0),0,($V_5|0),($V_2|0))|0);
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          label = 12;
          break;
         }
         if ($126) {
          $$0 = 1;
          label = 201;
          break;
         }
         $129 = HEAP8[$V_5>>0]|0;
         $130 = ($129<<24>>24)==(0);
         L51: do {
          if (!($130)) {
           $V_6$0 = 0;
           while(1) {
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $165 = __THREW__; __THREW__ = 0;
            $166 = $165&1;
            if ($166) {
             label = 11;
             break L33;
            }
            $167 = HEAP8[((2592096 + 116|0))>>0]|0;
            $168 = ($167<<24>>24)==(0);
            if ($168) {
             __THREW__ = 0;
             (invoke_ii(2996,(2592096|0))|0);
             $169 = __THREW__; __THREW__ = 0;
             $170 = $169&1;
             if ($170) {
              label = 11;
              break L33;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2592096|0))|0);
             $171 = __THREW__; __THREW__ = 0;
             $172 = $171&1;
             if ($172) {
              label = 11;
              break L33;
             }
             __THREW__ = 0;
             invoke_vi(3839,(2592096|0));
             $173 = __THREW__; __THREW__ = 0;
             $174 = $173&1;
             if ($174) {
              label = 11;
              break L33;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $175 = __THREW__; __THREW__ = 0;
            $176 = $175&1;
            if ($176) {
             label = 11;
             break L33;
            }
            $177 = HEAP32[((2592096 + 80|0))>>2]|0;
            $178 = (($177) + 32|0);
            $179 = HEAP32[$178>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($179|0));
            $180 = __THREW__; __THREW__ = 0;
            $181 = $180&1;
            if ($181) {
             label = 11;
             break L33;
            }
            $182 = (($179) + 12|0);
            $183 = HEAP32[$182>>2]|0;
            $184 = ($V_6$0|0)<($183|0);
            if (!($184)) {
             break L51;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $185 = __THREW__; __THREW__ = 0;
            $186 = $185&1;
            if ($186) {
             label = 11;
             break L33;
            }
            $131 = HEAP8[((2592096 + 116|0))>>0]|0;
            $132 = ($131<<24>>24)==(0);
            if ($132) {
             __THREW__ = 0;
             (invoke_ii(2996,(2592096|0))|0);
             $133 = __THREW__; __THREW__ = 0;
             $134 = $133&1;
             if ($134) {
              label = 11;
              break L33;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2592096|0))|0);
             $135 = __THREW__; __THREW__ = 0;
             $136 = $135&1;
             if ($136) {
              label = 11;
              break L33;
             }
             __THREW__ = 0;
             invoke_vi(3839,(2592096|0));
             $137 = __THREW__; __THREW__ = 0;
             $138 = $137&1;
             if ($138) {
              label = 11;
              break L33;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 11;
             break L33;
            }
            $141 = HEAP32[((2592096 + 80|0))>>2]|0;
            $142 = (($141) + 32|0);
            $143 = HEAP32[$142>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($143|0));
            $144 = __THREW__; __THREW__ = 0;
            $145 = $144&1;
            if ($145) {
             label = 11;
             break L33;
            }
            $146 = (($143) + 12|0);
            $147 = HEAP32[$146>>2]|0;
            $148 = ($V_6$0>>>0)<($147>>>0);
            if (!($148)) {
             __THREW__ = 0;
             $149 = (invoke_i(132)|0);
             $150 = __THREW__; __THREW__ = 0;
             $151 = $150&1;
             if ($151) {
              label = 11;
              break L33;
             }
             __THREW__ = 0;
             invoke_vi(3302,($149|0));
             $152 = __THREW__; __THREW__ = 0;
             $153 = $152&1;
             if ($153) {
              label = 11;
              break L33;
             }
            }
            $154 = HEAP32[$143>>2]|0;
            $155 = (($143) + 16|0);
            $156 = (($154) + 92|0);
            $157 = HEAP32[$156>>2]|0;
            $158 = Math_imul($157, $V_6$0)|0;
            $159 = (($155) + ($158)|0);
            $160 = HEAP32[$159>>2]|0;
            __THREW__ = 0;
            $161 = (invoke_iiiiiiiiiiiii(3,0,($s|0),($111|0),($160|0),0,($result|0),($dto|0),($76|0),($styles|0),0,($V_5|0),($V_2|0))|0);
            $162 = __THREW__; __THREW__ = 0;
            $163 = $162&1;
            if ($163) {
             label = 11;
             break L33;
            }
            $164 = (($V_6$0) + 1)|0;
            if ($161) {
             $$0 = 1;
             label = 201;
             break L33;
            } else {
             $V_6$0 = $164;
            }
           }
          }
         } while(0);
         $187 = (($V_3$0) + 1)|0;
         $V_3$0 = $187;
        }
        if ((label|0) == 11) {
         $21 = ___cxa_find_matching_catch()|0;
         $22 = tempRet0;
         $lpad$phi$index = $21;$lpad$phi$index7 = $22;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 12) {
         $23 = ___cxa_find_matching_catch()|0;
         $24 = tempRet0;
         $lpad$phi$index = $23;$lpad$phi$index7 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 83) {
         __THREW__ = 0;
         invoke_vi(3799,($76|0));
         $194 = __THREW__; __THREW__ = 0;
         $195 = $194&1;
         if ($195) {
          break;
         }
         __THREW__ = 0;
         $196 = (invoke_ii(2005,($76|0))|0);
         $197 = __THREW__; __THREW__ = 0;
         $198 = $197&1;
         if ($198) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($196|0));
         $199 = __THREW__; __THREW__ = 0;
         $200 = $199&1;
         if ($200) {
          break;
         }
         __THREW__ = 0;
         $201 = (invoke_iii(631,($196|0),100)|0);
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($76|0));
         $204 = __THREW__; __THREW__ = 0;
         $205 = $204&1;
         if ($205) {
          break;
         }
         __THREW__ = 0;
         $206 = (invoke_ii(2005,($76|0))|0);
         $207 = __THREW__; __THREW__ = 0;
         $208 = $207&1;
         if ($208) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($206|0));
         $209 = __THREW__; __THREW__ = 0;
         $210 = $209&1;
         if ($210) {
          break;
         }
         __THREW__ = 0;
         $211 = (invoke_iii(631,($206|0),77)|0);
         $212 = __THREW__; __THREW__ = 0;
         $213 = $212&1;
         if ($213) {
          break;
         }
         $214 = ($201|0)==(-1);
         $215 = ($211|0)==(-1);
         $or$cond = $214 | $215;
         if ($or$cond) {
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $216 = __THREW__; __THREW__ = 0;
          $217 = $216&1;
          if ($217) {
           break;
          }
          $218 = HEAP8[((2592096 + 116|0))>>0]|0;
          $219 = ($218<<24>>24)==(0);
          if ($219) {
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $220 = __THREW__; __THREW__ = 0;
           $221 = $220&1;
           if ($221) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $222 = __THREW__; __THREW__ = 0;
           $223 = $222&1;
           if ($223) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3839,(2592096|0));
           $224 = __THREW__; __THREW__ = 0;
           $225 = $224&1;
           if ($225) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $226 = __THREW__; __THREW__ = 0;
          $227 = $226&1;
          if ($227) {
           break;
          }
          $228 = HEAP32[((2592096 + 80|0))>>2]|0;
          $229 = (($228) + 16|0);
          _memmove(($result|0),($229|0),16)|0;
          if (!($setExceptionOnError)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          (invoke_ii(2996,(1167664|0))|0);
          $230 = __THREW__; __THREW__ = 0;
          $231 = $230&1;
          if ($231) {
           break;
          }
          __THREW__ = 0;
          $232 = (invoke_iii(2768,(1167664|0),1)|0);
          $233 = __THREW__; __THREW__ = 0;
          $234 = $233&1;
          if ($234) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($76|0));
          $235 = __THREW__; __THREW__ = 0;
          $236 = $235&1;
          if ($236) {
           break;
          }
          __THREW__ = 0;
          $237 = (invoke_ii(2005,($76|0))|0);
          $238 = __THREW__; __THREW__ = 0;
          $239 = $238&1;
          if ($239) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($232|0));
          $240 = __THREW__; __THREW__ = 0;
          $241 = $240&1;
          if ($241) {
           break;
          }
          $242 = (($232) + 12|0);
          $243 = HEAP32[$242>>2]|0;
          $244 = ($243|0)==(0);
          if ($244) {
           __THREW__ = 0;
           $245 = (invoke_i(132)|0);
           $246 = __THREW__; __THREW__ = 0;
           $247 = $246&1;
           if ($247) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($245|0));
           $248 = __THREW__; __THREW__ = 0;
           $249 = $248&1;
           if ($249) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($232|0),($237|0));
          $250 = __THREW__; __THREW__ = 0;
          $251 = $250&1;
          if ($251) {
           break;
          }
          $252 = (($232) + 16|0);
          HEAP32[$252>>2] = $237;
          $253 = HEAP32[3068152>>2]|0;
          __THREW__ = 0;
          $254 = (invoke_iiii(728,(0|0),($253|0),($232|0))|0);
          $255 = __THREW__; __THREW__ = 0;
          $256 = $255&1;
          if ($256) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2603176|0))|0);
          $257 = __THREW__; __THREW__ = 0;
          $258 = $257&1;
          if ($258) {
           break;
          }
          __THREW__ = 0;
          $259 = (invoke_ii(3469,(2603176|0))|0);
          $260 = __THREW__; __THREW__ = 0;
          $261 = $260&1;
          if ($261) {
           break;
          }
          __THREW__ = 0;
          invoke_vii(1940,($259|0),($254|0));
          $262 = __THREW__; __THREW__ = 0;
          $263 = $262&1;
          if ($263) {
           break;
          }
          HEAP32[$exception>>2] = $259;
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         $264 = ($201|0)<($211|0);
         if ($264) {
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $265 = __THREW__; __THREW__ = 0;
          $266 = $265&1;
          if ($266) {
           break;
          }
          $267 = HEAP8[((2592096 + 116|0))>>0]|0;
          $268 = ($267<<24>>24)==(0);
          if ($268) {
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $269 = __THREW__; __THREW__ = 0;
           $270 = $269&1;
           if ($270) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $271 = __THREW__; __THREW__ = 0;
           $272 = $271&1;
           if ($272) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3839,(2592096|0));
           $273 = __THREW__; __THREW__ = 0;
           $274 = $273&1;
           if ($274) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $275 = __THREW__; __THREW__ = 0;
          $276 = $275&1;
          if ($276) {
           break;
          }
          $277 = HEAP32[((2592096 + 80|0))>>2]|0;
          $278 = (($277) + 56|0);
          $G_B29_0$0$in$in = $278;
         } else {
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $279 = __THREW__; __THREW__ = 0;
          $280 = $279&1;
          if ($280) {
           break;
          }
          $281 = HEAP8[((2592096 + 116|0))>>0]|0;
          $282 = ($281<<24>>24)==(0);
          if ($282) {
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $283 = __THREW__; __THREW__ = 0;
           $284 = $283&1;
           if ($284) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $285 = __THREW__; __THREW__ = 0;
           $286 = $285&1;
           if ($286) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3839,(2592096|0));
           $287 = __THREW__; __THREW__ = 0;
           $288 = $287&1;
           if ($288) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $289 = __THREW__; __THREW__ = 0;
          $290 = $289&1;
          if ($290) {
           break;
          }
          $291 = HEAP32[((2592096 + 80|0))>>2]|0;
          $292 = (($291) + 52|0);
          $G_B29_0$0$in$in = $292;
         }
         $G_B29_0$0 = HEAP32[$G_B29_0$0$in$in>>2]|0;
         $293 = (($G_B29_0$0) + 12|0);
         $294 = (($G_B29_0$0) + 16|0);
         $V_11$0 = 0;
         while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($G_B29_0$0|0));
          $326 = __THREW__; __THREW__ = 0;
          $327 = $326&1;
          if ($327) {
           label = 10;
           break;
          }
          $328 = HEAP32[$293>>2]|0;
          $329 = ($V_11$0|0)<($328|0);
          if (!($329)) {
           $V_13$0 = 0;
           label = 184;
           break;
          }
          HEAP8[$V_12>>0] = 0;
          __THREW__ = 0;
          invoke_vi(3799,($G_B29_0$0|0));
          $330 = __THREW__; __THREW__ = 0;
          $331 = $330&1;
          if ($331) {
           label = 10;
           break;
          }
          $295 = HEAP32[$293>>2]|0;
          $296 = ($V_11$0>>>0)<($295>>>0);
          if (!($296)) {
           __THREW__ = 0;
           $297 = (invoke_i(132)|0);
           $298 = __THREW__; __THREW__ = 0;
           $299 = $298&1;
           if ($299) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($297|0));
           $300 = __THREW__; __THREW__ = 0;
           $301 = $300&1;
           if ($301) {
            label = 10;
            break;
           }
          }
          $302 = HEAP32[$G_B29_0$0>>2]|0;
          $303 = (($302) + 92|0);
          $304 = HEAP32[$303>>2]|0;
          $305 = Math_imul($304, $V_11$0)|0;
          $306 = (($294) + ($305)|0);
          $307 = HEAP32[$306>>2]|0;
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $308 = __THREW__; __THREW__ = 0;
          $309 = $308&1;
          if ($309) {
           label = 10;
           break;
          }
          $310 = HEAP8[((2191608 + 116|0))>>0]|0;
          $311 = ($310<<24>>24)==(0);
          if ($311) {
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $312 = __THREW__; __THREW__ = 0;
           $313 = $312&1;
           if ($313) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $314 = __THREW__; __THREW__ = 0;
           $315 = $314&1;
           if ($315) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3839,(2191608|0));
           $316 = __THREW__; __THREW__ = 0;
           $317 = $316&1;
           if ($317) {
            label = 10;
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $318 = __THREW__; __THREW__ = 0;
          $319 = $318&1;
          if ($319) {
           label = 10;
           break;
          }
          $320 = HEAP32[((2191608 + 80|0))>>2]|0;
          $321 = HEAP32[$320>>2]|0;
          __THREW__ = 0;
          $322 = (invoke_iiiiiiiiiiiii(3,0,($s|0),($307|0),($321|0),0,($result|0),($dto|0),($76|0),($styles|0),0,($V_12|0),($V_2|0))|0);
          $323 = __THREW__; __THREW__ = 0;
          $324 = $323&1;
          if ($324) {
           label = 10;
           break;
          }
          $325 = (($V_11$0) + 1)|0;
          if ($322) {
           $$0 = 1;
           label = 201;
           break;
          } else {
           $V_11$0 = $325;
          }
         }
         if ((label|0) == 10) {
          $19 = ___cxa_find_matching_catch()|0;
          $20 = tempRet0;
          $lpad$phi$index = $19;$lpad$phi$index7 = $20;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 184) {
          L157: while(1) {
           label = 0;
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $440 = __THREW__; __THREW__ = 0;
           $441 = $440&1;
           if ($441) {
            label = 9;
            break;
           }
           $442 = HEAP8[((2592096 + 116|0))>>0]|0;
           $443 = ($442<<24>>24)==(0);
           if ($443) {
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $444 = __THREW__; __THREW__ = 0;
            $445 = $444&1;
            if ($445) {
             label = 9;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $446 = __THREW__; __THREW__ = 0;
            $447 = $446&1;
            if ($447) {
             label = 9;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2592096|0));
            $448 = __THREW__; __THREW__ = 0;
            $449 = $448&1;
            if ($449) {
             label = 9;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $450 = __THREW__; __THREW__ = 0;
           $451 = $450&1;
           if ($451) {
            label = 9;
            break;
           }
           $452 = HEAP32[((2592096 + 80|0))>>2]|0;
           $453 = (($452) + 32|0);
           $454 = HEAP32[$453>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($454|0));
           $455 = __THREW__; __THREW__ = 0;
           $456 = $455&1;
           if ($456) {
            label = 9;
            break;
           }
           $457 = (($454) + 12|0);
           $458 = HEAP32[$457>>2]|0;
           $459 = ($V_13$0|0)<($458|0);
           if (!($459)) {
            label = 193;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $460 = __THREW__; __THREW__ = 0;
           $461 = $460&1;
           if ($461) {
            label = 9;
            break;
           }
           $332 = HEAP8[((2592096 + 116|0))>>0]|0;
           $333 = ($332<<24>>24)==(0);
           if ($333) {
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $334 = __THREW__; __THREW__ = 0;
            $335 = $334&1;
            if ($335) {
             label = 9;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $336 = __THREW__; __THREW__ = 0;
            $337 = $336&1;
            if ($337) {
             label = 9;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2592096|0));
            $338 = __THREW__; __THREW__ = 0;
            $339 = $338&1;
            if ($339) {
             label = 9;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $340 = __THREW__; __THREW__ = 0;
           $341 = $340&1;
           if ($341) {
            label = 9;
            break;
           }
           $342 = HEAP32[((2592096 + 80|0))>>2]|0;
           $343 = (($342) + 32|0);
           $344 = HEAP32[$343>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($344|0));
           $345 = __THREW__; __THREW__ = 0;
           $346 = $345&1;
           if ($346) {
            label = 9;
            break;
           }
           $347 = (($344) + 12|0);
           $348 = HEAP32[$347>>2]|0;
           $349 = ($V_13$0>>>0)<($348>>>0);
           if (!($349)) {
            __THREW__ = 0;
            $350 = (invoke_i(132)|0);
            $351 = __THREW__; __THREW__ = 0;
            $352 = $351&1;
            if ($352) {
             label = 9;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($350|0));
            $353 = __THREW__; __THREW__ = 0;
            $354 = $353&1;
            if ($354) {
             label = 9;
             break;
            }
           }
           $355 = HEAP32[$344>>2]|0;
           $356 = (($344) + 16|0);
           $357 = (($355) + 92|0);
           $358 = HEAP32[$357>>2]|0;
           $359 = Math_imul($358, $V_13$0)|0;
           $360 = (($356) + ($359)|0);
           $361 = HEAP32[$360>>2]|0;
           HEAP8[$V_15>>0] = 0;
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $362 = __THREW__; __THREW__ = 0;
           $363 = $362&1;
           if ($363) {
            label = 9;
            break;
           }
           $364 = HEAP8[((2191608 + 116|0))>>0]|0;
           $365 = ($364<<24>>24)==(0);
           if ($365) {
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $366 = __THREW__; __THREW__ = 0;
            $367 = $366&1;
            if ($367) {
             label = 9;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $368 = __THREW__; __THREW__ = 0;
            $369 = $368&1;
            if ($369) {
             label = 9;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2191608|0));
            $370 = __THREW__; __THREW__ = 0;
            $371 = $370&1;
            if ($371) {
             label = 9;
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $372 = __THREW__; __THREW__ = 0;
           $373 = $372&1;
           if ($373) {
            label = 9;
            break;
           }
           $374 = HEAP32[((2191608 + 80|0))>>2]|0;
           $375 = HEAP32[$374>>2]|0;
           __THREW__ = 0;
           $376 = (invoke_iiiiiiiiiiiii(3,0,($s|0),($361|0),($375|0),0,($result|0),($dto|0),($76|0),($styles|0),0,($V_15|0),($V_2|0))|0);
           $377 = __THREW__; __THREW__ = 0;
           $378 = $377&1;
           if ($378) {
            label = 9;
            break;
           }
           if ($376) {
            $$0 = 1;
            label = 201;
            break;
           }
           $379 = HEAP8[$V_15>>0]|0;
           $380 = ($379<<24>>24)==(0);
           L189: do {
            if (!($380)) {
             $V_16$0 = 0;
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($G_B29_0$0|0));
              $398 = __THREW__; __THREW__ = 0;
              $399 = $398&1;
              if ($399) {
               label = 7;
               break L157;
              }
              $400 = HEAP32[$293>>2]|0;
              $401 = ($V_16$0|0)<($400|0);
              if (!($401)) {
               $V_17$0 = 0;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($G_B29_0$0|0));
              $402 = __THREW__; __THREW__ = 0;
              $403 = $402&1;
              if ($403) {
               label = 7;
               break L157;
              }
              $381 = HEAP32[$293>>2]|0;
              $382 = ($V_16$0>>>0)<($381>>>0);
              if (!($382)) {
               __THREW__ = 0;
               $383 = (invoke_i(132)|0);
               $384 = __THREW__; __THREW__ = 0;
               $385 = $384&1;
               if ($385) {
                label = 7;
                break L157;
               }
               __THREW__ = 0;
               invoke_vi(3302,($383|0));
               $386 = __THREW__; __THREW__ = 0;
               $387 = $386&1;
               if ($387) {
                label = 7;
                break L157;
               }
              }
              $388 = HEAP32[$G_B29_0$0>>2]|0;
              $389 = (($388) + 92|0);
              $390 = HEAP32[$389>>2]|0;
              $391 = Math_imul($390, $V_16$0)|0;
              $392 = (($294) + ($391)|0);
              $393 = HEAP32[$392>>2]|0;
              __THREW__ = 0;
              $394 = (invoke_iiiiiiiiiiiii(3,0,($s|0),($361|0),($393|0),0,($result|0),($dto|0),($76|0),($styles|0),0,($V_15|0),($V_2|0))|0);
              $395 = __THREW__; __THREW__ = 0;
              $396 = $395&1;
              if ($396) {
               label = 7;
               break L157;
              }
              $397 = (($V_16$0) + 1)|0;
              if ($394) {
               $$0 = 1;
               label = 201;
               break L157;
              } else {
               $V_16$0 = $397;
              }
             }
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($79|0));
              $433 = __THREW__; __THREW__ = 0;
              $434 = $433&1;
              if ($434) {
               label = 8;
               break L157;
              }
              $435 = HEAP32[$97>>2]|0;
              $436 = ($V_17$0|0)<($435|0);
              if (!($436)) {
               break L189;
              }
              __THREW__ = 0;
              invoke_vi(3799,($79|0));
              $437 = __THREW__; __THREW__ = 0;
              $438 = $437&1;
              if ($438) {
               label = 8;
               break L157;
              }
              $404 = HEAP32[$97>>2]|0;
              $405 = ($V_17$0>>>0)<($404>>>0);
              if (!($405)) {
               __THREW__ = 0;
               $406 = (invoke_i(132)|0);
               $407 = __THREW__; __THREW__ = 0;
               $408 = $407&1;
               if ($408) {
                label = 8;
                break L157;
               }
               __THREW__ = 0;
               invoke_vi(3302,($406|0));
               $409 = __THREW__; __THREW__ = 0;
               $410 = $409&1;
               if ($410) {
                label = 8;
                break L157;
               }
              }
              $411 = HEAP32[$79>>2]|0;
              $412 = (($411) + 92|0);
              $413 = HEAP32[$412>>2]|0;
              $414 = Math_imul($413, $V_17$0)|0;
              $415 = (($98) + ($414)|0);
              $416 = HEAP32[$415>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($416|0));
              $417 = __THREW__; __THREW__ = 0;
              $418 = $417&1;
              if ($418) {
               label = 8;
               break L157;
              }
              __THREW__ = 0;
              $419 = (invoke_ii(1816,($416|0))|0);
              $420 = __THREW__; __THREW__ = 0;
              $421 = $420&1;
              if ($421) {
               label = 8;
               break L157;
              }
              __THREW__ = 0;
              invoke_vi(3799,($416|0));
              $422 = __THREW__; __THREW__ = 0;
              $423 = $422&1;
              if ($423) {
               label = 8;
               break L157;
              }
              $424 = (($419) + -1)|0;
              __THREW__ = 0;
              $425 = (invoke_iii(621,($416|0),($424|0))|0);
              $426 = __THREW__; __THREW__ = 0;
              $427 = $426&1;
              if ($427) {
               label = 8;
               break L157;
              }
              $428 = ($425<<16>>16)==(84);
              if (!($428)) {
               __THREW__ = 0;
               $429 = (invoke_iiiiiiiiiiiii(3,0,($s|0),($361|0),($416|0),0,($result|0),($dto|0),($76|0),($styles|0),0,($V_15|0),($V_2|0))|0);
               $430 = __THREW__; __THREW__ = 0;
               $431 = $430&1;
               if ($431) {
                label = 8;
                break L157;
               }
               if ($429) {
                $$0 = 1;
                label = 201;
                break L157;
               }
              }
              $432 = (($V_17$0) + 1)|0;
              $V_17$0 = $432;
             }
            }
           } while(0);
           $439 = (($V_13$0) + 1)|0;
           $V_13$0 = $439;
           label = 184;
          }
          if ((label|0) == 7) {
           $13 = ___cxa_find_matching_catch()|0;
           $14 = tempRet0;
           $lpad$phi$index = $13;$lpad$phi$index7 = $14;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 8) {
           $15 = ___cxa_find_matching_catch()|0;
           $16 = tempRet0;
           $lpad$phi$index = $15;$lpad$phi$index7 = $16;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 9) {
           $17 = ___cxa_find_matching_catch()|0;
           $18 = tempRet0;
           $lpad$phi$index = $17;$lpad$phi$index7 = $18;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          }
          else if ((label|0) == 193) {
           __THREW__ = 0;
           invoke_vi(3799,($76|0));
           $462 = __THREW__; __THREW__ = 0;
           $463 = $462&1;
           if ($463) {
            break;
           }
           __THREW__ = 0;
           $464 = (invoke_ii(2015,($76|0))|0);
           $465 = __THREW__; __THREW__ = 0;
           $466 = $465&1;
           if ($466) {
            break;
           }
           __THREW__ = 0;
           $467 = (invoke_iiiiiiiiiii(5,0,($s|0),($464|0),($76|0),($styles|0),($result|0),0,($V_2|0),($setExceptionOnError|0),($exception|0))|0);
           $468 = __THREW__; __THREW__ = 0;
           $469 = $468&1;
           if ($469) {
            break;
           }
           $setExceptionOnError$not = $setExceptionOnError ^ 1;
           $brmerge = $467 | $setExceptionOnError$not;
           if ($brmerge) {
            $$0 = $467;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2603176|0))|0);
           $470 = __THREW__; __THREW__ = 0;
           $471 = $470&1;
           if ($471) {
            break;
           }
           __THREW__ = 0;
           $472 = (invoke_ii(3469,(2603176|0))|0);
           $473 = __THREW__; __THREW__ = 0;
           $474 = $473&1;
           if ($474) {
            break;
           }
           $475 = HEAP32[3068160>>2]|0;
           __THREW__ = 0;
           invoke_vii(1940,($472|0),($475|0));
           $476 = __THREW__; __THREW__ = 0;
           $477 = $476&1;
           if ($477) {
            break;
           }
           HEAP32[$exception>>2] = $472;
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          else if ((label|0) == 201) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
         else if ((label|0) == 201) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
        else if ((label|0) == 201) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
      if ($setExceptionOnError) {
       __THREW__ = 0;
       (invoke_ii(2996,(2603176|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       __THREW__ = 0;
       $52 = (invoke_ii(3469,(2603176|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       $55 = HEAP32[3068144>>2]|0;
       __THREW__ = 0;
       invoke_vii(1940,($52|0),($55|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       HEAP32[$exception>>2] = $52;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       $60 = HEAP8[((2592096 + 116|0))>>0]|0;
       $61 = ($60<<24>>24)==(0);
       if ($61) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2592096|0));
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if (!($69)) {
        $70 = HEAP32[((2592096 + 80|0))>>2]|0;
        $71 = (($70) + 16|0);
        _memmove(($result|0),($71|0),16)|0;
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $lpad$phi$index = $25;$lpad$phi$index7 = $26;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_DateTimeOffset_m__ctor_mscorlib_System_Void_mscorlib_System_Int64_mscorlib_System_TimeSpanP30mscorlib_System_DateTimeOffsetx24mscorlib_System_TimeSpan($__this,$0,$1,$offset) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 $offset = $offset|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_0$byval_copy = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 40|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 48|0;
 $L_0 = sp + 24|0;
 $2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2592800);
 ;HEAP32[$L_0+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 invoke_viii(661,($L_0|0),($0|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 $5 = $offset;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $2;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_0$byval_copy+12>>2]=HEAP32[$L_0+12>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 invoke_viii(667,($__this|0),($L_0$byval_copy|0),($$byval_copy|0));
 $15 = __THREW__; __THREW__ = 0;
 $16 = $15&1;
 if ($16) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z83mscorlib_System_FormatException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP31mscorlib_System_FormatExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2602928);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233033);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z46mscorlib_System_DateTime_m_YearMonthDayFormatsP22mscorlib_System_ObjectP48mscorlib_System_Globalization_DateTimeFormatInfobPP25mscorlib_System_Exception($__this,$dfi,$setExceptionOnError,$exc) {
 $__this = $__this|0;
 $dfi = $dfi|0;
 $setExceptionOnError = $setExceptionOnError|0;
 $exc = $exc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587008);
 __THREW__ = 0;
 invoke_v(869);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($dfi|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(2002,($dfi|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_iii(631,($4|0),100)|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($dfi|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        __THREW__ = 0;
        $14 = (invoke_ii(2002,($dfi|0))|0);
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         __THREW__ = 0;
         invoke_vi(3799,($14|0));
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if (!($18)) {
          __THREW__ = 0;
          $19 = (invoke_iii(631,($14|0),77)|0);
          $20 = __THREW__; __THREW__ = 0;
          $21 = $20&1;
          if (!($21)) {
           __THREW__ = 0;
           invoke_vi(3799,($dfi|0));
           $22 = __THREW__; __THREW__ = 0;
           $23 = $22&1;
           if (!($23)) {
            __THREW__ = 0;
            $24 = (invoke_ii(2002,($dfi|0))|0);
            $25 = __THREW__; __THREW__ = 0;
            $26 = $25&1;
            if (!($26)) {
             __THREW__ = 0;
             invoke_vi(3799,($24|0));
             $27 = __THREW__; __THREW__ = 0;
             $28 = $27&1;
             if (!($28)) {
              __THREW__ = 0;
              $29 = (invoke_iii(631,($24|0),121)|0);
              $30 = __THREW__; __THREW__ = 0;
              $31 = $30&1;
              if (!($31)) {
               $32 = ($9|0)==(-1);
               $33 = ($19|0)==(-1);
               $or$cond = $32 | $33;
               $34 = ($29|0)==(-1);
               $or$cond3 = $or$cond | $34;
               if ($or$cond3) {
                if (!($setExceptionOnError)) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1167664|0))|0);
                $37 = __THREW__; __THREW__ = 0;
                $38 = $37&1;
                if ($38) {
                 break;
                }
                __THREW__ = 0;
                $39 = (invoke_iii(2768,(1167664|0),1)|0);
                $40 = __THREW__; __THREW__ = 0;
                $41 = $40&1;
                if ($41) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($dfi|0));
                $42 = __THREW__; __THREW__ = 0;
                $43 = $42&1;
                if ($43) {
                 break;
                }
                __THREW__ = 0;
                $44 = (invoke_ii(2002,($dfi|0))|0);
                $45 = __THREW__; __THREW__ = 0;
                $46 = $45&1;
                if ($46) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($39|0));
                $47 = __THREW__; __THREW__ = 0;
                $48 = $47&1;
                if ($48) {
                 break;
                }
                $49 = (($39) + 12|0);
                $50 = HEAP32[$49>>2]|0;
                $51 = ($50|0)==(0);
                if ($51) {
                 __THREW__ = 0;
                 $52 = (invoke_i(132)|0);
                 $53 = __THREW__; __THREW__ = 0;
                 $54 = $53&1;
                 if ($54) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($52|0));
                 $55 = __THREW__; __THREW__ = 0;
                 $56 = $55&1;
                 if ($56) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($39|0),($44|0));
                $57 = __THREW__; __THREW__ = 0;
                $58 = $57&1;
                if ($58) {
                 break;
                }
                $59 = (($39) + 16|0);
                HEAP32[$59>>2] = $44;
                $60 = HEAP32[3068368>>2]|0;
                __THREW__ = 0;
                $61 = (invoke_iiii(728,(0|0),($60|0),($39|0))|0);
                $62 = __THREW__; __THREW__ = 0;
                $63 = $62&1;
                if ($63) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $64 = __THREW__; __THREW__ = 0;
                $65 = $64&1;
                if ($65) {
                 break;
                }
                __THREW__ = 0;
                $66 = (invoke_ii(3469,(2603176|0))|0);
                $67 = __THREW__; __THREW__ = 0;
                $68 = $67&1;
                if ($68) {
                 break;
                }
                __THREW__ = 0;
                invoke_vii(1940,($66|0),($61|0));
                $69 = __THREW__; __THREW__ = 0;
                $70 = $69&1;
                if ($70) {
                 break;
                }
                HEAP32[$exc>>2] = $66;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               $71 = ($29|0)<($19|0);
               if ($71) {
                $72 = ($19|0)<($9|0);
                if ($72) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if ($74) {
                  break;
                 }
                 $75 = HEAP8[((2592096 + 116|0))>>0]|0;
                 $76 = ($75<<24>>24)==(0);
                 if ($76) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $77 = __THREW__; __THREW__ = 0;
                  $78 = $77&1;
                  if ($78) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $79 = __THREW__; __THREW__ = 0;
                  $80 = $79&1;
                  if ($80) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3839,(2592096|0));
                  $81 = __THREW__; __THREW__ = 0;
                  $82 = $81&1;
                  if ($82) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $83 = __THREW__; __THREW__ = 0;
                 $84 = $83&1;
                 if ($84) {
                  break;
                 }
                 $85 = HEAP32[((2592096 + 80|0))>>2]|0;
                 $86 = (($85) + 40|0);
                 $87 = HEAP32[$86>>2]|0;
                 $$0 = $87;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                $88 = ($29|0)<($9|0);
                if ($88) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $89 = __THREW__; __THREW__ = 0;
                 $90 = $89&1;
                 if ($90) {
                  break;
                 }
                 $91 = HEAP8[((2592096 + 116|0))>>0]|0;
                 $92 = ($91<<24>>24)==(0);
                 if ($92) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $93 = __THREW__; __THREW__ = 0;
                  $94 = $93&1;
                  if ($94) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $95 = __THREW__; __THREW__ = 0;
                  $96 = $95&1;
                  if ($96) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3839,(2592096|0));
                  $97 = __THREW__; __THREW__ = 0;
                  $98 = $97&1;
                  if ($98) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $99 = __THREW__; __THREW__ = 0;
                 $100 = $99&1;
                 if ($100) {
                  break;
                 }
                 $101 = HEAP32[((2592096 + 80|0))>>2]|0;
                 $102 = (($101) + 36|0);
                 $103 = HEAP32[$102>>2]|0;
                 $$0 = $103;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                if (!($setExceptionOnError)) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1167664|0))|0);
                $104 = __THREW__; __THREW__ = 0;
                $105 = $104&1;
                if ($105) {
                 break;
                }
                __THREW__ = 0;
                $106 = (invoke_iii(2768,(1167664|0),1)|0);
                $107 = __THREW__; __THREW__ = 0;
                $108 = $107&1;
                if ($108) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($dfi|0));
                $109 = __THREW__; __THREW__ = 0;
                $110 = $109&1;
                if ($110) {
                 break;
                }
                __THREW__ = 0;
                $111 = (invoke_ii(2002,($dfi|0))|0);
                $112 = __THREW__; __THREW__ = 0;
                $113 = $112&1;
                if ($113) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($106|0));
                $114 = __THREW__; __THREW__ = 0;
                $115 = $114&1;
                if ($115) {
                 break;
                }
                $116 = (($106) + 12|0);
                $117 = HEAP32[$116>>2]|0;
                $118 = ($117|0)==(0);
                if ($118) {
                 __THREW__ = 0;
                 $119 = (invoke_i(132)|0);
                 $120 = __THREW__; __THREW__ = 0;
                 $121 = $120&1;
                 if ($121) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($119|0));
                 $122 = __THREW__; __THREW__ = 0;
                 $123 = $122&1;
                 if ($123) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($106|0),($111|0));
                $124 = __THREW__; __THREW__ = 0;
                $125 = $124&1;
                if ($125) {
                 break;
                }
                $126 = (($106) + 16|0);
                HEAP32[$126>>2] = $111;
                $127 = HEAP32[3068376>>2]|0;
                __THREW__ = 0;
                $128 = (invoke_iiii(728,(0|0),($127|0),($106|0))|0);
                $129 = __THREW__; __THREW__ = 0;
                $130 = $129&1;
                if ($130) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $131 = __THREW__; __THREW__ = 0;
                $132 = $131&1;
                if ($132) {
                 break;
                }
                __THREW__ = 0;
                $133 = (invoke_ii(3469,(2603176|0))|0);
                $134 = __THREW__; __THREW__ = 0;
                $135 = $134&1;
                if ($135) {
                 break;
                }
                __THREW__ = 0;
                invoke_vii(1940,($133|0),($128|0));
                $136 = __THREW__; __THREW__ = 0;
                $137 = $136&1;
                if ($137) {
                 break;
                }
                HEAP32[$exc>>2] = $133;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               } else {
                $138 = ($9|0)<($19|0);
                if ($138) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $139 = __THREW__; __THREW__ = 0;
                 $140 = $139&1;
                 if ($140) {
                  break;
                 }
                 $141 = HEAP8[((2592096 + 116|0))>>0]|0;
                 $142 = ($141<<24>>24)==(0);
                 if ($142) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $143 = __THREW__; __THREW__ = 0;
                  $144 = $143&1;
                  if ($144) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $145 = __THREW__; __THREW__ = 0;
                  $146 = $145&1;
                  if ($146) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3839,(2592096|0));
                  $147 = __THREW__; __THREW__ = 0;
                  $148 = $147&1;
                  if ($148) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $149 = __THREW__; __THREW__ = 0;
                 $150 = $149&1;
                 if ($150) {
                  break;
                 }
                 $151 = HEAP32[((2592096 + 80|0))>>2]|0;
                 $152 = (($151) + 44|0);
                 $153 = HEAP32[$152>>2]|0;
                 $$0 = $153;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                $154 = ($9|0)<($29|0);
                if ($154) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $155 = __THREW__; __THREW__ = 0;
                 $156 = $155&1;
                 if ($156) {
                  break;
                 }
                 $157 = HEAP8[((2592096 + 116|0))>>0]|0;
                 $158 = ($157<<24>>24)==(0);
                 if ($158) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $159 = __THREW__; __THREW__ = 0;
                  $160 = $159&1;
                  if ($160) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2592096|0))|0);
                  $161 = __THREW__; __THREW__ = 0;
                  $162 = $161&1;
                  if ($162) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3839,(2592096|0));
                  $163 = __THREW__; __THREW__ = 0;
                  $164 = $163&1;
                  if ($164) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2592096|0))|0);
                 $165 = __THREW__; __THREW__ = 0;
                 $166 = $165&1;
                 if ($166) {
                  break;
                 }
                 $167 = HEAP32[((2592096 + 80|0))>>2]|0;
                 $168 = (($167) + 48|0);
                 $169 = HEAP32[$168>>2]|0;
                 $$0 = $169;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                if (!($setExceptionOnError)) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1167664|0))|0);
                $170 = __THREW__; __THREW__ = 0;
                $171 = $170&1;
                if ($171) {
                 break;
                }
                __THREW__ = 0;
                $172 = (invoke_iii(2768,(1167664|0),1)|0);
                $173 = __THREW__; __THREW__ = 0;
                $174 = $173&1;
                if ($174) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($dfi|0));
                $175 = __THREW__; __THREW__ = 0;
                $176 = $175&1;
                if ($176) {
                 break;
                }
                __THREW__ = 0;
                $177 = (invoke_ii(2002,($dfi|0))|0);
                $178 = __THREW__; __THREW__ = 0;
                $179 = $178&1;
                if ($179) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($172|0));
                $180 = __THREW__; __THREW__ = 0;
                $181 = $180&1;
                if ($181) {
                 break;
                }
                $182 = (($172) + 12|0);
                $183 = HEAP32[$182>>2]|0;
                $184 = ($183|0)==(0);
                if ($184) {
                 __THREW__ = 0;
                 $185 = (invoke_i(132)|0);
                 $186 = __THREW__; __THREW__ = 0;
                 $187 = $186&1;
                 if ($187) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($185|0));
                 $188 = __THREW__; __THREW__ = 0;
                 $189 = $188&1;
                 if ($189) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($172|0),($177|0));
                $190 = __THREW__; __THREW__ = 0;
                $191 = $190&1;
                if ($191) {
                 break;
                }
                $192 = (($172) + 16|0);
                HEAP32[$192>>2] = $177;
                $193 = HEAP32[3068384>>2]|0;
                __THREW__ = 0;
                $194 = (invoke_iiii(728,(0|0),($193|0),($172|0))|0);
                $195 = __THREW__; __THREW__ = 0;
                $196 = $195&1;
                if ($196) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2603176|0))|0);
                $197 = __THREW__; __THREW__ = 0;
                $198 = $197&1;
                if ($198) {
                 break;
                }
                __THREW__ = 0;
                $199 = (invoke_ii(3469,(2603176|0))|0);
                $200 = __THREW__; __THREW__ = 0;
                $201 = $200&1;
                if ($201) {
                 break;
                }
                __THREW__ = 0;
                invoke_vii(1940,($199|0),($194|0));
                $202 = __THREW__; __THREW__ = 0;
                $203 = $202&1;
                if ($203) {
                 break;
                }
                HEAP32[$exc>>2] = $199;
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $35 = ___cxa_find_matching_catch()|0;
 $36 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($35|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_DateTime_m__DoParseP22mscorlib_System_ObjectP22mscorlib_System_StringS2_S2_bP24mscorlib_System_DateTimeP30mscorlib_System_DateTimeOffsetP48mscorlib_System_Globalization_DateTimeFormatInfoibPbS9_($__this,$s,$firstPart,$secondPart,$exact,$result,$dto,$dfi,$style,$firstPartIsDate,$incompleteFormat,$longYear) {
 $__this = $__this|0;
 $s = $s|0;
 $firstPart = $firstPart|0;
 $secondPart = $secondPart|0;
 $exact = $exact|0;
 $result = $result|0;
 $dto = $dto|0;
 $dfi = $dfi|0;
 $style = $style|0;
 $firstPartIsDate = $firstPartIsDate|0;
 $incompleteFormat = $incompleteFormat|0;
 $longYear = $longYear|0;
 var $$ = 0, $$0 = 0, $$02 = 0, $$04 = 0, $$05 = 0, $$1 = 0, $$15 = 0, $$17 = 0, $$V_12$2 = 0, $$V_12$264 = 0, $$V_16$0 = 0, $$V_16$3 = 0, $$V_18$2 = 0, $$V_21$3 = 0, $$V_23$1 = 0, $$byval_copy22 = 0, $$byval_copy24 = 0, $$lobit = 0, $$lobit6 = 0, $$not = 0;
 var $$not67 = 0, $$pr = 0, $$pr60 = 0, $$pr66 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0;
 var $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0;
 var $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0;
 var $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0;
 var $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0;
 var $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0;
 var $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0;
 var $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0;
 var $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0;
 var $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0;
 var $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0;
 var $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0.0, $661 = 0.0, $662 = 0.0, $663 = 0.0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $G_B3_0$0$off0 = 0, $G_B413_0$0 = 0, $G_B56_0$056 = 0, $L_601 = 0, $L_603 = 0, $L_605 = 0, $L_615 = 0, $L_637 = 0, $L_652 = 0, $L_669 = 0, $L_673 = 0, $L_686 = 0, $L_687 = 0, $V_0 = 0, $V_1 = 0;
 var $V_10$0 = 0, $V_10$0$phi = 0, $V_10$176 = 0, $V_10$2$ph = 0, $V_10$270 = 0, $V_11$0$lcssa = 0, $V_11$0110 = 0, $V_11$1$lcssa = 0, $V_11$195 = 0, $V_11$2 = 0, $V_11$2$ph = 0, $V_11$3 = 0, $V_11$4 = 0, $V_11$4$phi = 0, $V_12$0 = 0, $V_12$1 = 0, $V_12$1$phi = 0, $V_12$2 = 0, $V_13$053 = 0, $V_13$1 = 0;
 var $V_13$2 = 0, $V_13$3 = 0, $V_13$4 = 0, $V_13$4$phi = 0, $V_13$5 = 0, $V_14$0 = 0, $V_14$2 = 0, $V_14$3 = 0, $V_14$3$phi = 0, $V_14$4 = 0, $V_14$5 = 0, $V_14$565 = 0, $V_15$0 = 0, $V_15$0$ph = 0, $V_15$1 = 0, $V_15$2 = 0, $V_15$2$phi = 0, $V_15$3 = 0, $V_15$4 = 0, $V_15$4$off = 0;
 var $V_16$0 = 0, $V_16$1 = 0, $V_16$2 = 0, $V_16$3 = 0, $V_16$3$phi = 0, $V_16$5 = 0, $V_16$5$ = 0, $V_16$6 = 0, $V_17$0 = 0, $V_17$1 = 0, $V_17$2 = 0, $V_17$2$phi = 0, $V_17$3 = 0, $V_18$0 = 0, $V_18$1 = 0, $V_18$2 = 0, $V_18$2$phi = 0, $V_19$0 = 0.0, $V_19$1 = 0.0, $V_19$1$phi = 0.0;
 var $V_19$2 = 0.0, $V_20 = 0, $V_21$0 = 0, $V_21$1 = 0, $V_21$2 = 0, $V_21$3 = 0, $V_21$3$phi = 0, $V_22$0 = 0, $V_22$1 = 0, $V_22$1$phi = 0, $V_22$2 = 0, $V_22$3 = 0, $V_23$0 = 0, $V_23$1 = 0, $V_23$1$phi = 0, $V_23$3 = 0, $V_24$0$off0 = 0, $V_24$0$off0$phi = 0, $V_25 = 0, $V_27$0$off0 = 0;
 var $V_28$0 = 0, $V_28$1 = 0, $V_28$1$ = 0, $V_29 = 0, $V_36 = 0, $V_37 = 0, $V_38 = 0, $V_39 = 0, $V_4$0$lcssa = 0, $V_4$0111 = 0, $V_4$1$lcssa = 0, $V_4$196 = 0, $V_4$2 = 0, $V_4$3 = 0, $V_4$4 = 0, $V_4$4$phi = 0, $V_40 = 0, $V_5$0 = 0, $V_5$1 = 0, $V_5$2 = 0;
 var $V_5$3 = 0, $V_5$4 = 0, $V_5$4$phi = 0, $V_6$0$off0 = 0, $V_6$0$off0$phi = 0, $V_8$0 = 0, $V_8$0$phi = 0, $V_9$0 = 0, $V_9$0$phi = 0, $_stackTraceSentry = 0, $brmerge = 0, $brmerge10 = 0, $brmerge18 = 0, $dfi$ = 0, $lpad$phi$index = 0, $lpad$phi$index8 = 0, $not$exact = 0, $or$cond11 = 0, $or$cond12 = 0, $or$cond14 = 0;
 var $or$cond16 = 0, $or$cond20 = 0, $or$cond21 = 0, $or$cond22 = 0, $or$cond23 = 0, $or$cond25 = 0, $or$cond26 = 0, $or$cond27 = 0, $or$cond28 = 0, $or$cond29 = 0, $or$cond30 = 0, $or$cond31 = 0, $or$cond32 = 0, $or$cond32$not = 0, $or$cond33 = 0, $or$cond35 = 0, $or$cond8 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $$byval_copy24 = sp + 272|0;
 $$byval_copy22 = sp + 288|0;
 $_stackTraceSentry = sp + 312|0;
 $V_0 = sp + 320|0;
 $V_1 = sp + 321|0;
 $V_20 = sp + 304|0;
 $V_25 = sp + 308|0;
 $V_29 = sp + 316|0;
 $V_36 = sp + 256|0;
 $V_37 = sp + 240|0;
 $V_38 = sp + 224|0;
 $V_39 = sp + 208|0;
 $V_40 = sp + 200|0;
 $0 = sp + 192|0;
 $L_601 = sp + 176|0;
 $L_603 = sp + 72|0;
 $L_605 = sp;
 $L_615 = sp + 16|0;
 $L_637 = sp + 32|0;
 $1 = sp + 48|0;
 $L_652 = sp + 64|0;
 $2 = sp + 88|0;
 $3 = sp + 96|0;
 $4 = sp + 104|0;
 $L_669 = sp + 112|0;
 $5 = sp + 120|0;
 $L_673 = sp + 128|0;
 $L_686 = sp + 144|0;
 $L_687 = sp + 160|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587392);
 HEAP8[$V_0>>0] = 0;
 HEAP8[$V_1>>0] = 0;
 HEAP32[$V_20>>2] = 0;
 HEAP32[$V_25>>2] = 0;
 HEAP32[$V_29>>2] = 0;
 ;HEAP32[$V_36+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_36+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_36+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_36+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_37+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_37+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_37+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_37+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_38+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_38+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_38+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_38+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_39+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_39+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_39+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_39+12>>2]=HEAP32[2593040+12>>2]|0;
 $6 = $V_40;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 __THREW__ = 0;
 invoke_v(870);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if ($11) {
   label = 14;
  } else {
   HEAP8[$V_0>>0] = 0;
   HEAP8[$V_1>>0] = 0;
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    label = 14;
   } else {
    $14 = HEAP8[((2652728 + 116|0))>>0]|0;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      label = 14;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      label = 14;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2652728|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      label = 14;
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2652728|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 14;
    } else {
     $40 = HEAP32[((2652728 + 80|0))>>2]|0;
     $41 = (($40) + 16|0);
     $42 = $41;
     $43 = $42;
     $44 = HEAP32[$43>>2]|0;
     $45 = (($42) + 4)|0;
     $46 = $45;
     $47 = HEAP32[$46>>2]|0;
     $48 = $0;
     $49 = $48;
     HEAP32[$49>>2] = $44;
     $50 = (($48) + 4)|0;
     $51 = $50;
     HEAP32[$51>>2] = $47;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy24+4>>2]=HEAP32[$0+4>>2]|0;
     invoke_viiii(192,($dto|0),0,0,($$byval_copy24|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      label = 14;
     } else {
      $54 = ($secondPart|0)!=(0|0);
      $not$exact = $exact ^ 1;
      $G_B3_0$0$off0 = $54 & $not$exact;
      HEAP8[$incompleteFormat>>0] = 0;
      __THREW__ = 0;
      $55 = (invoke_ii(2009,(0|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 14;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($firstPart|0));
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        label = 14;
       } else {
        __THREW__ = 0;
        $60 = (invoke_ii(1816,($firstPart|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 14;
        } else {
         $63 = ($60|0)==(1);
         if ($63) {
          __THREW__ = 0;
          invoke_vi(3799,($firstPart|0));
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           label = 14;
           break;
          }
          __THREW__ = 0;
          $66 = (invoke_iii(621,($firstPart|0),0)|0);
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           label = 14;
           break;
          }
          __THREW__ = 0;
          $69 = (invoke_iiiiii(127,0,($66|0),($dfi|0),($V_0|0),($V_1|0))|0);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           label = 14;
           break;
          } else {
           $V_5$0 = $69;
          }
         } else {
          $V_5$0 = $firstPart;
         }
         __THREW__ = 0;
         invoke_viii(661,($result|0),0,0);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          label = 14;
         } else {
          $74 = ($V_5$0|0)==(0|0);
          $75 = ($s|0)==(0|0);
          $or$cond35 = $74 | $75;
          if ($or$cond35) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          $76 = $style & 1;
          $77 = ($76|0)==(0);
          if ($77) {
           $$02 = $s;$V_5$1 = $V_5$0;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($V_5$0|0));
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if ($79) {
            label = 14;
            break;
           }
           __THREW__ = 0;
           $80 = (invoke_iii(625,($V_5$0|0),(0|0))|0);
           $81 = __THREW__; __THREW__ = 0;
           $82 = $81&1;
           if ($82) {
            label = 14;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($s|0));
           $83 = __THREW__; __THREW__ = 0;
           $84 = $83&1;
           if ($84) {
            label = 14;
            break;
           }
           __THREW__ = 0;
           $85 = (invoke_iii(625,($s|0),(0|0))|0);
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if ($87) {
            label = 14;
            break;
           } else {
            $$02 = $85;$V_5$1 = $80;
           }
          }
          $88 = $style & 2;
          $89 = ($88|0)==(0);
          if ($89) {
           $$1 = $$02;$V_5$2 = $V_5$1;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($V_5$1|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            label = 14;
            break;
           }
           __THREW__ = 0;
           $92 = (invoke_iii(626,($V_5$1|0),(0|0))|0);
           $93 = __THREW__; __THREW__ = 0;
           $94 = $93&1;
           if ($94) {
            label = 14;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($$02|0));
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if ($96) {
            label = 14;
            break;
           }
           __THREW__ = 0;
           $97 = (invoke_iii(626,($$02|0),(0|0))|0);
           $98 = __THREW__; __THREW__ = 0;
           $99 = $98&1;
           if ($99) {
            label = 14;
            break;
           } else {
            $$1 = $97;$V_5$2 = $92;
           }
          }
          $100 = HEAP8[$V_1>>0]|0;
          $101 = ($100<<24>>24)==(0);
          $dfi$ = $101 ? $dfi : $55;
          $102 = $style & 4;
          $103 = ($102|0)!=(0);
          __THREW__ = 0;
          invoke_vi(3799,($V_5$2|0));
          $104 = __THREW__; __THREW__ = 0;
          $105 = $104&1;
          if ($105) {
           label = 14;
          } else {
           __THREW__ = 0;
           $106 = (invoke_ii(1816,($V_5$2|0))|0);
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if ($108) {
            label = 14;
           } else {
            $109 = ($106|0)==(0);
            if ($109) {
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            HEAP32[$V_20>>2] = -1;
            $brmerge10 = $103 | $not$exact;
            $$ = $exact ? 4 : 3;
            $brmerge18 = $G_B3_0$0$off0 | $exact;
            $V_10$0 = 0;$V_11$4 = 0;$V_12$1 = -1;$V_13$4 = -1;$V_14$3 = -1;$V_15$2 = -1;$V_16$3 = -1;$V_17$2 = -1;$V_18$2 = -1;$V_19$1 = -1.0;$V_21$3 = -1;$V_22$1 = -1;$V_23$1 = -1;$V_24$0$off0 = 1;$V_4$4 = 0;$V_5$4 = $V_5$2;$V_6$0$off0 = 0;$V_8$0 = $V_5$2;$V_9$0 = $106;
            L40: while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($$1|0));
             $880 = __THREW__; __THREW__ = 0;
             $881 = $880&1;
             if ($881) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $110 = (invoke_ii(1816,($$1|0))|0);
             $111 = __THREW__; __THREW__ = 0;
             $112 = $111&1;
             if ($112) {
              label = 13;
              break;
             }
             $113 = ($V_4$4|0)==($110|0);
             if ($113) {
              $V_13$5 = $V_13$4;
              label = 432;
              break;
             }
             HEAP32[$V_25>>2] = 0;
             L45: do {
              if ($G_B3_0$0$off0) {
               $114 = (0 - ($V_11$4))|0;
               $115 = ($V_10$0|0)==($114|0);
               if (!($115)) {
                $V_13$2 = $V_13$4;
                break;
               }
               __THREW__ = 0;
               $116 = (invoke_iiii(1157,0,($$1|0),($V_4$4|0))|0);
               $117 = __THREW__; __THREW__ = 0;
               $118 = $117&1;
               if ($118) {
                label = 13;
                break L40;
               }
               do {
                if ($116) {
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $119 = __THREW__; __THREW__ = 0;
                 $120 = $119&1;
                 if ($120) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $121 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                 $122 = __THREW__; __THREW__ = 0;
                 $123 = $122&1;
                 if ($123) {
                  label = 13;
                  break L40;
                 }
                 $124 = ($121<<16>>16)==(90);
                 if ($124) {
                  HEAP32[$V_25>>2] = 1;
                  $130 = 1;
                 } else {
                  $125 = HEAP32[3068776>>2]|0;
                  __THREW__ = 0;
                  (invoke_iiiiiii(91,0,($$1|0),($V_4$4|0),0,($125|0),($V_25|0))|0);
                  $126 = __THREW__; __THREW__ = 0;
                  $127 = $126&1;
                  if ($127) {
                   label = 13;
                   break L40;
                  }
                  $$pr = HEAP32[$V_25>>2]|0;
                  $128 = ($$pr|0)<(1);
                  if ($128) {
                   break;
                  } else {
                   $130 = $$pr;
                  }
                 }
                 $129 = (($130) + ($V_4$4))|0;
                 __THREW__ = 0;
                 $131 = (invoke_iiii(1157,0,($$1|0),($129|0))|0);
                 $132 = __THREW__; __THREW__ = 0;
                 $133 = $132&1;
                 if ($133) {
                  label = 13;
                  break L40;
                 }
                 if ($131) {
                  break;
                 }
                 $134 = HEAP32[$V_25>>2]|0;
                 $135 = (($134) + ($V_4$4))|0;
                 HEAP8[$V_0>>0] = 1;
                 $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_13$4$phi = $V_13$4;$V_12$1$phi = $V_12$1;$V_11$4$phi = $V_11$4;$V_10$0$phi = $V_10$0;$V_4$4 = $135;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_13$4 = $V_13$4$phi;$V_12$1 = $V_12$1$phi;$V_11$4 = $V_11$4$phi;$V_10$0 = $V_10$0$phi;
                 continue L40;
                }
               } while(0);
               do {
                if ($V_6$0$off0) {
                 $V_13$1 = $V_13$4;
                } else {
                 __THREW__ = 0;
                 $136 = (invoke_iiiiiiiii(25,0,($$1|0),($V_4$4|0),0,($dfi$|0),($exact|0),($V_25|0),($V_20|0))|0);
                 $137 = __THREW__; __THREW__ = 0;
                 $138 = $137&1;
                 if ($138) {
                  label = 13;
                  break L40;
                 }
                 do {
                  if ($136) {
                   $139 = HEAP32[$V_25>>2]|0;
                   $140 = (($139) + ($V_4$4))|0;
                   __THREW__ = 0;
                   $141 = (invoke_iiii(1157,0,($$1|0),($140|0))|0);
                   $142 = __THREW__; __THREW__ = 0;
                   $143 = $142&1;
                   if ($143) {
                    label = 13;
                    break L40;
                   }
                   if ($141) {
                    HEAP32[$V_20>>2] = -1;
                    break;
                   }
                   $144 = HEAP32[$V_25>>2]|0;
                   $145 = ($144|0)<(1);
                   if ($145) {
                    break;
                   }
                   $146 = (($144) + ($V_4$4))|0;
                   $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_13$4$phi = $V_13$4;$V_12$1$phi = $V_12$1;$V_11$4$phi = $V_11$4;$V_10$0$phi = $V_10$0;$V_4$4 = $146;$V_6$0$off0 = 0;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_13$4 = $V_13$4$phi;$V_12$1 = $V_12$1$phi;$V_11$4 = $V_11$4$phi;$V_10$0 = $V_10$0$phi;
                   continue L40;
                  }
                 } while(0);
                 $$not67 = ($V_13$4|0)!=(-1);
                 $$not = $116 ^ 1;
                 $brmerge = $$not67 | $$not;
                 if ($brmerge) {
                  $V_13$1 = $V_13$4;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($dfi$|0));
                 $147 = __THREW__; __THREW__ = 0;
                 $148 = $147&1;
                 if ($148) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $149 = (invoke_ii(1995,($dfi$|0))|0);
                 $150 = __THREW__; __THREW__ = 0;
                 $151 = $150&1;
                 if ($151) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($55|0));
                 $152 = __THREW__; __THREW__ = 0;
                 $153 = $152&1;
                 if ($153) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $154 = (invoke_ii(1995,($55|0))|0);
                 $155 = __THREW__; __THREW__ = 0;
                 $156 = $155&1;
                 if ($156) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $157 = (invoke_iiiiiiii(94,0,($$1|0),($V_4$4|0),($149|0),($154|0),($exact|0),($V_25|0))|0);
                 $158 = __THREW__; __THREW__ = 0;
                 $159 = $158&1;
                 if ($159) {
                  label = 13;
                  break L40;
                 }
                 $160 = ($157|0)==(-1);
                 if ($160) {
                  __THREW__ = 0;
                  invoke_vi(3799,($dfi$|0));
                  $161 = __THREW__; __THREW__ = 0;
                  $162 = $161&1;
                  if ($162) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $163 = (invoke_ii(1993,($dfi$|0))|0);
                  $164 = __THREW__; __THREW__ = 0;
                  $165 = $164&1;
                  if ($165) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($55|0));
                  $166 = __THREW__; __THREW__ = 0;
                  $167 = $166&1;
                  if ($167) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $168 = (invoke_ii(1993,($55|0))|0);
                  $169 = __THREW__; __THREW__ = 0;
                  $170 = $169&1;
                  if ($170) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $171 = (invoke_iiiiiiii(94,0,($$1|0),($V_4$4|0),($163|0),($168|0),($exact|0),($V_25|0))|0);
                  $172 = __THREW__; __THREW__ = 0;
                  $173 = $172&1;
                  if ($173) {
                   label = 13;
                   break L40;
                  }
                  $174 = ($171|0)==(-1);
                  if ($174) {
                   $V_13$1 = -1;
                   break;
                  } else {
                   $V_13$053 = $171;
                  }
                 } else {
                  $V_13$053 = $157;
                 }
                 $175 = HEAP32[$V_25>>2]|0;
                 $176 = (($175) + ($V_4$4))|0;
                 __THREW__ = 0;
                 $177 = (invoke_iiii(1157,0,($$1|0),($176|0))|0);
                 $178 = __THREW__; __THREW__ = 0;
                 $179 = $178&1;
                 if ($179) {
                  label = 13;
                  break L40;
                 }
                 if ($177) {
                  $V_13$1 = -1;
                  break;
                 }
                 $180 = HEAP32[$V_25>>2]|0;
                 $181 = (($180) + ($V_4$4))|0;
                 $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_11$4$phi = $V_11$4;$V_10$0$phi = $V_10$0;$V_13$4 = $V_13$053;$V_4$4 = $181;$V_6$0$off0 = 0;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;$V_11$4 = $V_11$4$phi;$V_10$0 = $V_10$0$phi;
                 continue L40;
                }
               } while(0);
               __THREW__ = 0;
               invoke_vi(3799,($$1|0));
               $182 = __THREW__; __THREW__ = 0;
               $183 = $182&1;
               if ($183) {
                label = 13;
                break L40;
               }
               __THREW__ = 0;
               $184 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
               $185 = __THREW__; __THREW__ = 0;
               $186 = $185&1;
               if ($186) {
                label = 13;
                break L40;
               }
               __THREW__ = 0;
               $187 = (invoke_iii(604,(0|0),($184|0))|0);
               $188 = __THREW__; __THREW__ = 0;
               $189 = $188&1;
               if ($189) {
                label = 13;
                break L40;
               }
               do {
                if (!($187)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $190 = __THREW__; __THREW__ = 0;
                 $191 = $190&1;
                 if ($191) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $192 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                 $193 = __THREW__; __THREW__ = 0;
                 $194 = $193&1;
                 if ($194) {
                  label = 13;
                  break L40;
                 }
                 $195 = ($192<<16>>16)==(44);
                 if ($195) {
                  break;
                 }
                 HEAP32[$V_25>>2] = 0;
                 $V_13$2 = $V_13$1;
                 break L45;
                }
               } while(0);
               $196 = (($V_4$4) + 1)|0;
               $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_11$4$phi = $V_11$4;$V_10$0$phi = $V_10$0;$V_13$4 = $V_13$1;$V_4$4 = $196;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;$V_11$4 = $V_11$4$phi;$V_10$0 = $V_10$0$phi;
               continue L40;
              } else {
               $V_13$2 = $V_13$4;
              }
             } while(0);
             $197 = (($V_10$0) + ($V_11$4))|0;
             $198 = ($197|0)<($V_9$0|0);
             if (!($198)) {
              $199 = ($V_11$4|0)==(0);
              $or$cond8 = $G_B3_0$0$off0 & $199;
              if (!($or$cond8)) {
               $V_13$5 = $V_13$2;
               label = 432;
               break;
              }
              do {
               if ($V_24$0$off0) {
                __THREW__ = 0;
                invoke_vi(3799,($firstPart|0));
                $200 = __THREW__; __THREW__ = 0;
                $201 = $200&1;
                if ($201) {
                 label = 13;
                 break L40;
                }
                __THREW__ = 0;
                $202 = (invoke_ii(1816,($firstPart|0))|0);
                $203 = __THREW__; __THREW__ = 0;
                $204 = $203&1;
                if ($204) {
                 label = 13;
                 break L40;
                }
                __THREW__ = 0;
                invoke_vi(3799,($firstPart|0));
                $205 = __THREW__; __THREW__ = 0;
                $206 = $205&1;
                if ($206) {
                 label = 13;
                 break L40;
                }
                $207 = (($202) + -1)|0;
                __THREW__ = 0;
                $208 = (invoke_iii(621,($firstPart|0),($207|0))|0);
                $209 = __THREW__; __THREW__ = 0;
                $210 = $209&1;
                if ($210) {
                 label = 13;
                 break L40;
                }
                $211 = ($208<<16>>16)==(84);
                $G_B56_0$056 = $211;$V_5$3 = $secondPart;
               } else {
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $212 = __THREW__; __THREW__ = 0;
                $213 = $212&1;
                if ($213) {
                 label = 13;
                 break L40;
                }
                $214 = HEAP8[((2191608 + 116|0))>>0]|0;
                $215 = ($214<<24>>24)==(0);
                if ($215) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $216 = __THREW__; __THREW__ = 0;
                 $217 = $216&1;
                 if ($217) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $218 = __THREW__; __THREW__ = 0;
                 $219 = $218&1;
                 if ($219) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3839,(2191608|0));
                 $220 = __THREW__; __THREW__ = 0;
                 $221 = $220&1;
                 if ($221) {
                  label = 13;
                  break L40;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $222 = __THREW__; __THREW__ = 0;
                $223 = $222&1;
                if ($223) {
                 label = 13;
                 break L40;
                }
                $224 = HEAP32[((2191608 + 80|0))>>2]|0;
                $225 = HEAP32[$224>>2]|0;
                __THREW__ = 0;
                $226 = (invoke_iiii(574,(0|0),($V_5$4|0),($225|0))|0);
                $227 = __THREW__; __THREW__ = 0;
                $228 = $227&1;
                if ($228) {
                 label = 13;
                 break L40;
                }
                if ($226) {
                 $V_13$5 = $V_13$2;
                 label = 432;
                 break L40;
                }
                if ($V_24$0$off0) {
                 $G_B56_0$056 = 0;$V_5$3 = $secondPart;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $229 = __THREW__; __THREW__ = 0;
                $230 = $229&1;
                if ($230) {
                 label = 13;
                 break L40;
                }
                $231 = HEAP8[((2191608 + 116|0))>>0]|0;
                $232 = ($231<<24>>24)==(0);
                if ($232) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $233 = __THREW__; __THREW__ = 0;
                 $234 = $233&1;
                 if ($234) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $235 = __THREW__; __THREW__ = 0;
                 $236 = $235&1;
                 if ($236) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3839,(2191608|0));
                 $237 = __THREW__; __THREW__ = 0;
                 $238 = $237&1;
                 if ($238) {
                  label = 13;
                  break L40;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $239 = __THREW__; __THREW__ = 0;
                $240 = $239&1;
                if ($240) {
                 label = 13;
                 break L40;
                }
                $241 = HEAP32[((2191608 + 80|0))>>2]|0;
                $242 = HEAP32[$241>>2]|0;
                $G_B56_0$056 = 0;$V_5$3 = $242;
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($V_5$3|0));
              $243 = __THREW__; __THREW__ = 0;
              $244 = $243&1;
              if ($244) {
               label = 13;
               break;
              }
              __THREW__ = 0;
              $245 = (invoke_ii(1816,($V_5$3|0))|0);
              $246 = __THREW__; __THREW__ = 0;
              $247 = $246&1;
              if ($247) {
               label = 13;
               break;
              } else {
               $V_4$4$phi = $V_4$4;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = 0;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_24$0$off0 = 0;$V_5$4 = $V_5$3;$V_6$0$off0 = $G_B56_0$056;$V_8$0 = $V_5$3;$V_9$0 = $245;$V_4$4 = $V_4$4$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
               continue;
              }
             }
             __THREW__ = 0;
             invoke_vi(3799,($V_8$0|0));
             $248 = __THREW__; __THREW__ = 0;
             $249 = $248&1;
             if ($249) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $250 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
             $251 = __THREW__; __THREW__ = 0;
             $252 = $251&1;
             if ($252) {
              label = 13;
              break;
             }
             $253 = ($250<<16>>16)==(39);
             if ($253) {
              $254 = (($V_10$0) + 1)|0;
              $255 = ($254|0)<($V_9$0|0);
              L133: do {
               if ($255) {
                $256 = $254;$V_11$0110 = 1;$V_4$0111 = $V_4$4;
                while(1) {
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $282 = __THREW__; __THREW__ = 0;
                 $283 = $282&1;
                 if ($283) {
                  label = 12;
                  break L40;
                 }
                 __THREW__ = 0;
                 $257 = (invoke_iii(621,($V_8$0|0),($256|0))|0);
                 $258 = __THREW__; __THREW__ = 0;
                 $259 = $258&1;
                 if ($259) {
                  label = 12;
                  break L40;
                 }
                 $260 = ($257<<16>>16)==(39);
                 if ($260) {
                  $V_11$0$lcssa = $V_11$0110;$V_4$0$lcssa = $V_4$0111;
                  break L133;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $261 = __THREW__; __THREW__ = 0;
                 $262 = $261&1;
                 if ($262) {
                  label = 12;
                  break L40;
                 }
                 __THREW__ = 0;
                 $263 = (invoke_ii(1816,($$1|0))|0);
                 $264 = __THREW__; __THREW__ = 0;
                 $265 = $264&1;
                 if ($265) {
                  label = 12;
                  break L40;
                 }
                 $266 = ($V_4$0111|0)==($263|0);
                 if ($266) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $267 = __THREW__; __THREW__ = 0;
                 $268 = $267&1;
                 if ($268) {
                  label = 12;
                  break L40;
                 }
                 __THREW__ = 0;
                 $269 = (invoke_iii(621,($$1|0),($V_4$0111|0))|0);
                 $270 = __THREW__; __THREW__ = 0;
                 $271 = $270&1;
                 if ($271) {
                  label = 12;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $272 = __THREW__; __THREW__ = 0;
                 $273 = $272&1;
                 if ($273) {
                  label = 12;
                  break L40;
                 }
                 __THREW__ = 0;
                 $274 = (invoke_iii(621,($V_8$0|0),($256|0))|0);
                 $275 = __THREW__; __THREW__ = 0;
                 $276 = $275&1;
                 if ($276) {
                  label = 12;
                  break L40;
                 }
                 $277 = ($269<<16>>16)==($274<<16>>16);
                 if (!($277)) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 $278 = (($V_4$0111) + 1)|0;
                 $279 = (($V_11$0110) + 1)|0;
                 $280 = (($279) + ($V_10$0))|0;
                 $281 = ($280|0)<($V_9$0|0);
                 if ($281) {
                  $256 = $280;$V_11$0110 = $279;$V_4$0111 = $278;
                 } else {
                  $V_11$0$lcssa = $279;$V_4$0$lcssa = $278;
                  break;
                 }
                }
               } else {
                $V_11$0$lcssa = 1;$V_4$0$lcssa = $V_4$4;
               }
              } while(0);
              $284 = (($254) + ($V_11$0$lcssa))|0;
              $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = $284;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_4$4 = $V_4$0$lcssa;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
              continue;
             }
             __THREW__ = 0;
             invoke_vi(3799,($V_8$0|0));
             $285 = __THREW__; __THREW__ = 0;
             $286 = $285&1;
             if ($286) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $287 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
             $288 = __THREW__; __THREW__ = 0;
             $289 = $288&1;
             if ($289) {
              label = 13;
              break;
             }
             $290 = ($287<<16>>16)==(34);
             if ($290) {
              $291 = (($V_10$0) + 1)|0;
              $292 = ($291|0)<($V_9$0|0);
              L153: do {
               if ($292) {
                $293 = $291;$V_11$195 = 1;$V_4$196 = $V_4$4;
                while(1) {
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $319 = __THREW__; __THREW__ = 0;
                 $320 = $319&1;
                 if ($320) {
                  label = 11;
                  break L40;
                 }
                 __THREW__ = 0;
                 $294 = (invoke_iii(621,($V_8$0|0),($293|0))|0);
                 $295 = __THREW__; __THREW__ = 0;
                 $296 = $295&1;
                 if ($296) {
                  label = 11;
                  break L40;
                 }
                 $297 = ($294<<16>>16)==(34);
                 if ($297) {
                  $V_11$1$lcssa = $V_11$195;$V_4$1$lcssa = $V_4$196;
                  break L153;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $298 = __THREW__; __THREW__ = 0;
                 $299 = $298&1;
                 if ($299) {
                  label = 11;
                  break L40;
                 }
                 __THREW__ = 0;
                 $300 = (invoke_ii(1816,($$1|0))|0);
                 $301 = __THREW__; __THREW__ = 0;
                 $302 = $301&1;
                 if ($302) {
                  label = 11;
                  break L40;
                 }
                 $303 = ($V_4$196|0)==($300|0);
                 if ($303) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $304 = __THREW__; __THREW__ = 0;
                 $305 = $304&1;
                 if ($305) {
                  label = 11;
                  break L40;
                 }
                 __THREW__ = 0;
                 $306 = (invoke_iii(621,($$1|0),($V_4$196|0))|0);
                 $307 = __THREW__; __THREW__ = 0;
                 $308 = $307&1;
                 if ($308) {
                  label = 11;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $309 = __THREW__; __THREW__ = 0;
                 $310 = $309&1;
                 if ($310) {
                  label = 11;
                  break L40;
                 }
                 __THREW__ = 0;
                 $311 = (invoke_iii(621,($V_8$0|0),($293|0))|0);
                 $312 = __THREW__; __THREW__ = 0;
                 $313 = $312&1;
                 if ($313) {
                  label = 11;
                  break L40;
                 }
                 $314 = ($306<<16>>16)==($311<<16>>16);
                 if (!($314)) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 $315 = (($V_4$196) + 1)|0;
                 $316 = (($V_11$195) + 1)|0;
                 $317 = (($316) + ($V_10$0))|0;
                 $318 = ($317|0)<($V_9$0|0);
                 if ($318) {
                  $293 = $317;$V_11$195 = $316;$V_4$196 = $315;
                 } else {
                  $V_11$1$lcssa = $316;$V_4$1$lcssa = $315;
                  break;
                 }
                }
               } else {
                $V_11$1$lcssa = 1;$V_4$1$lcssa = $V_4$4;
               }
              } while(0);
              $321 = (($291) + ($V_11$1$lcssa))|0;
              $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = $321;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_4$4 = $V_4$1$lcssa;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
              continue;
             }
             __THREW__ = 0;
             invoke_vi(3799,($V_8$0|0));
             $322 = __THREW__; __THREW__ = 0;
             $323 = $322&1;
             if ($323) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $324 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
             $325 = __THREW__; __THREW__ = 0;
             $326 = $325&1;
             if ($326) {
              label = 13;
              break;
             }
             $327 = ($324<<16>>16)==(92);
             if ($327) {
              $328 = (($V_11$4) + 1)|0;
              $329 = (($328) + ($V_10$0))|0;
              $330 = ($329|0)<($V_9$0|0);
              if (!($330)) {
               $$0 = 0;
               label = 541;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($$1|0));
              $331 = __THREW__; __THREW__ = 0;
              $332 = $331&1;
              if ($332) {
               label = 13;
               break;
              }
              __THREW__ = 0;
              $333 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
              $334 = __THREW__; __THREW__ = 0;
              $335 = $334&1;
              if ($335) {
               label = 13;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($V_8$0|0));
              $336 = __THREW__; __THREW__ = 0;
              $337 = $336&1;
              if ($337) {
               label = 13;
               break;
              }
              __THREW__ = 0;
              $338 = (invoke_iii(621,($V_8$0|0),($329|0))|0);
              $339 = __THREW__; __THREW__ = 0;
              $340 = $339&1;
              if ($340) {
               label = 13;
               break;
              }
              $341 = ($333<<16>>16)==($338<<16>>16);
              if (!($341)) {
               $$0 = 0;
               label = 541;
               break;
              }
              $342 = (($V_4$4) + 1)|0;
              $343 = (($329) + 1)|0;
              $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = $343;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_4$4 = $342;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
              continue;
             }
             __THREW__ = 0;
             invoke_vi(3799,($V_8$0|0));
             $344 = __THREW__; __THREW__ = 0;
             $345 = $344&1;
             if ($345) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $346 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
             $347 = __THREW__; __THREW__ = 0;
             $348 = $347&1;
             if ($348) {
              label = 13;
              break;
             }
             $349 = ($346<<16>>16)==(37);
             if ($349) {
              $350 = (($V_10$0) + 1)|0;
              $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_4$4$phi = $V_4$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_11$4$phi = $V_11$4;$V_10$0 = $350;$V_13$4 = $V_13$2;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_4$4 = $V_4$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;$V_11$4 = $V_11$4$phi;
              continue;
             }
             __THREW__ = 0;
             invoke_vi(3799,($$1|0));
             $351 = __THREW__; __THREW__ = 0;
             $352 = $351&1;
             if ($352) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $353 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
             $354 = __THREW__; __THREW__ = 0;
             $355 = $354&1;
             if ($355) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $356 = (invoke_iii(604,(0|0),($353|0))|0);
             $357 = __THREW__; __THREW__ = 0;
             $358 = $357&1;
             if ($358) {
              label = 13;
              break;
             }
             do {
              if (!($356)) {
               __THREW__ = 0;
               invoke_vi(3799,($$1|0));
               $359 = __THREW__; __THREW__ = 0;
               $360 = $359&1;
               if ($360) {
                label = 13;
                break L40;
               }
               __THREW__ = 0;
               $361 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
               $362 = __THREW__; __THREW__ = 0;
               $363 = $362&1;
               if ($363) {
                label = 13;
                break L40;
               }
               $364 = ($361<<16>>16)==(44);
               if ($364) {
                if (!($exact)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $365 = __THREW__; __THREW__ = 0;
                 $366 = $365&1;
                 if ($366) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $367 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
                 $368 = __THREW__; __THREW__ = 0;
                 $369 = $368&1;
                 if ($369) {
                  label = 13;
                  break L40;
                 }
                 $370 = ($367<<16>>16)==(47);
                 if ($370) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vi(3799,($V_8$0|0));
                $371 = __THREW__; __THREW__ = 0;
                $372 = $371&1;
                if ($372) {
                 label = 13;
                 break L40;
                }
                __THREW__ = 0;
                $373 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
                $374 = __THREW__; __THREW__ = 0;
                $375 = $374&1;
                if ($375) {
                 label = 13;
                 break L40;
                }
                __THREW__ = 0;
                $376 = (invoke_iii(604,(0|0),($373|0))|0);
                $377 = __THREW__; __THREW__ = 0;
                $378 = $377&1;
                if ($378) {
                 label = 13;
                 break L40;
                }
                if ($376) {
                 break;
                }
               }
               $448 = (($197) + 1)|0;
               $449 = ($448|0)<($V_9$0|0);
               do {
                if ($449) {
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $450 = __THREW__; __THREW__ = 0;
                 $451 = $450&1;
                 if ($451) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $452 = (invoke_iii(621,($V_8$0|0),($448|0))|0);
                 $453 = __THREW__; __THREW__ = 0;
                 $454 = $453&1;
                 if ($454) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $455 = __THREW__; __THREW__ = 0;
                 $456 = $455&1;
                 if ($456) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $457 = (invoke_iii(621,($V_8$0|0),($197|0))|0);
                 $458 = __THREW__; __THREW__ = 0;
                 $459 = $458&1;
                 if ($459) {
                  label = 13;
                  break L40;
                 }
                 $460 = ($452<<16>>16)==($457<<16>>16);
                 if (!($460)) {
                  break;
                 }
                 $461 = (($V_11$4) + 1)|0;
                 $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_4$4$phi = $V_4$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0$phi = $V_10$0;$V_11$4 = $461;$V_13$4 = $V_13$2;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_4$4 = $V_4$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;$V_10$0 = $V_10$0$phi;
                 continue L40;
                }
               } while(0);
               __THREW__ = 0;
               invoke_vi(3799,($V_8$0|0));
               $462 = __THREW__; __THREW__ = 0;
               $463 = $462&1;
               if ($463) {
                label = 13;
                break L40;
               }
               __THREW__ = 0;
               $464 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
               $465 = __THREW__; __THREW__ = 0;
               $466 = $465&1;
               if ($466) {
                label = 13;
                break L40;
               }
               $467 = $464&65535;
               $468 = (($467) + 65466)|0;
               $469 = $468 & 65535;
               L213: do {
                switch ($469|0) {
                case 7:  {
                 $510 = ($V_14$3|0)==(-1);
                 if (!($510)) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 if (!($G_B3_0$0$off0)) {
                  if ((($V_11$4|0) == 1)) {
                   __THREW__ = 0;
                   $549 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,1,($103|0),($V_25|0))|0);
                   $550 = __THREW__; __THREW__ = 0;
                   $551 = $550&1;
                   if ($551) {
                    label = 13;
                    break L40;
                   } else {
                    $V_11$3 = 1;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $549;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                    break L213;
                   }
                  } else if ((($V_11$4|0) == 2)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($dfi$|0));
                   $552 = __THREW__; __THREW__ = 0;
                   $553 = $552&1;
                   if ($553) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $554 = (invoke_ii(1994,($dfi$|0))|0);
                   $555 = __THREW__; __THREW__ = 0;
                   $556 = $555&1;
                   if ($556) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($55|0));
                   $557 = __THREW__; __THREW__ = 0;
                   $558 = $557&1;
                   if ($558) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $559 = (invoke_ii(1994,($55|0))|0);
                   $560 = __THREW__; __THREW__ = 0;
                   $561 = $560&1;
                   if ($561) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $562 = (invoke_iiiiiiii(94,0,($$1|0),($V_4$4|0),($554|0),($559|0),($exact|0),($V_25|0))|0);
                   $563 = __THREW__; __THREW__ = 0;
                   $564 = $563&1;
                   if ($564) {
                    label = 13;
                    break L40;
                   }
                   $565 = (($562) + 1)|0;
                   $V_11$3 = 2;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $565;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                   break L213;
                  } else if ((($V_11$4|0) == 0)) {
                   __THREW__ = 0;
                   $546 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,0,($103|0),($V_25|0))|0);
                   $547 = __THREW__; __THREW__ = 0;
                   $548 = $547&1;
                   if ($548) {
                    label = 13;
                    break L40;
                   } else {
                    $V_11$3 = 0;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $546;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                    break L213;
                   }
                  } else {
                   __THREW__ = 0;
                   invoke_vi(3799,($dfi$|0));
                   $566 = __THREW__; __THREW__ = 0;
                   $567 = $566&1;
                   if ($567) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $568 = (invoke_ii(1996,($dfi$|0))|0);
                   $569 = __THREW__; __THREW__ = 0;
                   $570 = $569&1;
                   if ($570) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($55|0));
                   $571 = __THREW__; __THREW__ = 0;
                   $572 = $571&1;
                   if ($572) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $573 = (invoke_ii(1996,($55|0))|0);
                   $574 = __THREW__; __THREW__ = 0;
                   $575 = $574&1;
                   if ($575) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $576 = (invoke_iiiiiiii(94,0,($$1|0),($V_4$4|0),($568|0),($573|0),($exact|0),($V_25|0))|0);
                   $577 = __THREW__; __THREW__ = 0;
                   $578 = $577&1;
                   if ($578) {
                    label = 13;
                    break L40;
                   }
                   $579 = (($576) + 1)|0;
                   $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $579;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                   break L213;
                  }
                 }
                 HEAP32[$V_25>>2] = -1;
                 if ((($V_11$4|0) == 3) | (($V_11$4|0) == 0)) {
                  __THREW__ = 0;
                  $511 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,0,($103|0),($V_25|0))|0);
                  $512 = __THREW__; __THREW__ = 0;
                  $513 = $512&1;
                  if ($513) {
                   label = 13;
                   break L40;
                  } else {
                   $V_14$0 = $511;
                  }
                 } else {
                  $V_14$0 = -1;
                 }
                 $514 = ($V_11$4|0)<(2);
                 if ($514) {
                  $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$0;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                  break L213;
                 }
                 $515 = HEAP32[$V_25>>2]|0;
                 $516 = ($515|0)==(-1);
                 if (!($516)) {
                  $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$0;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                  break L213;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($dfi$|0));
                 $517 = __THREW__; __THREW__ = 0;
                 $518 = $517&1;
                 if ($518) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $519 = (invoke_ii(1996,($dfi$|0))|0);
                 $520 = __THREW__; __THREW__ = 0;
                 $521 = $520&1;
                 if ($521) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($55|0));
                 $522 = __THREW__; __THREW__ = 0;
                 $523 = $522&1;
                 if ($523) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $524 = (invoke_ii(1996,($55|0))|0);
                 $525 = __THREW__; __THREW__ = 0;
                 $526 = $525&1;
                 if ($526) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $527 = (invoke_iiiiiiii(94,0,($$1|0),($V_4$4|0),($519|0),($524|0),($exact|0),($V_25|0))|0);
                 $528 = __THREW__; __THREW__ = 0;
                 $529 = $528&1;
                 if ($529) {
                  label = 13;
                  break L40;
                 }
                 $530 = (($527) + 1)|0;
                 $$pr66 = HEAP32[$V_25>>2]|0;
                 $531 = ($$pr66|0)==(-1);
                 if (!($531)) {
                  $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $530;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                  break L213;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($dfi$|0));
                 $532 = __THREW__; __THREW__ = 0;
                 $533 = $532&1;
                 if ($533) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $534 = (invoke_ii(1994,($dfi$|0))|0);
                 $535 = __THREW__; __THREW__ = 0;
                 $536 = $535&1;
                 if ($536) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($55|0));
                 $537 = __THREW__; __THREW__ = 0;
                 $538 = $537&1;
                 if ($538) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $539 = (invoke_ii(1994,($55|0))|0);
                 $540 = __THREW__; __THREW__ = 0;
                 $541 = $540&1;
                 if ($541) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $542 = (invoke_iiiiiiii(94,0,($$1|0),($V_4$4|0),($534|0),($539|0),($exact|0),($V_25|0))|0);
                 $543 = __THREW__; __THREW__ = 0;
                 $544 = $543&1;
                 if ($544) {
                  label = 13;
                  break L40;
                 }
                 $545 = (($542) + 1)|0;
                 $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $545;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                 break;
                }
                case 2:  {
                 $623 = ($V_16$3|0)==(-1);
                 if (!($623)) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 if (!($G_B3_0$0$off0)) {
                  $624 = HEAP32[$V_20>>2]|0;
                  $625 = ($624|0)<(0);
                  if (!($625)) {
                   $$0 = 0;
                   label = 541;
                   break L40;
                  }
                 }
                 $626 = ($V_11$4|0)==(0);
                 if ($626) {
                  __THREW__ = 0;
                  $627 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,0,($103|0),($V_25|0))|0);
                  $628 = __THREW__; __THREW__ = 0;
                  $629 = $628&1;
                  if ($629) {
                   label = 13;
                   break L40;
                  } else {
                   $V_16$1 = $627;
                  }
                 } else {
                  __THREW__ = 0;
                  $630 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,1,($103|0),($V_25|0))|0);
                  $631 = __THREW__; __THREW__ = 0;
                  $632 = $631&1;
                  if ($632) {
                   label = 13;
                   break L40;
                  } else {
                   $V_16$1 = $630;
                  }
                 }
                 $633 = ($V_16$1|0)<(24);
                 if ($633) {
                  $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$1;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                 } else {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 break;
                }
                case 0:  {
                 $V_27$0$off0 = 0;
                 label = 315;
                 break;
                }
                case 5:  {
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $718 = __THREW__; __THREW__ = 0;
                 $719 = $718&1;
                 if ($719) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $720 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                 $721 = __THREW__; __THREW__ = 0;
                 $722 = $721&1;
                 if ($722) {
                  label = 13;
                  break L40;
                 }
                 $723 = ($720<<16>>16)==(90);
                 if ($723) {
                  $724 = (($V_4$4) + 1)|0;
                  HEAP8[$V_0>>0] = 1;
                  $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $724;
                  break L213;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $725 = __THREW__; __THREW__ = 0;
                 $726 = $725&1;
                 if ($726) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $727 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                 $728 = __THREW__; __THREW__ = 0;
                 $729 = $728&1;
                 if ($729) {
                  label = 13;
                  break L40;
                 }
                 $730 = ($727<<16>>16)==(43);
                 if (!($730)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($$1|0));
                  $731 = __THREW__; __THREW__ = 0;
                  $732 = $731&1;
                  if ($732) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $733 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                  $734 = __THREW__; __THREW__ = 0;
                  $735 = $734&1;
                  if ($735) {
                   label = 13;
                   break L40;
                  }
                  $736 = ($733<<16>>16)==(45);
                  if (!($736)) {
                   $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                   break L213;
                  }
                 }
                 $737 = ($V_21$3|0)==(-1);
                 if (!($737)) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $738 = __THREW__; __THREW__ = 0;
                 $739 = $738&1;
                 if ($739) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $740 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                 $741 = __THREW__; __THREW__ = 0;
                 $742 = $741&1;
                 if ($742) {
                  label = 13;
                  break L40;
                 }
                 $743 = ($740<<16>>16)==(43);
                 if ($743) {
                  $V_21$1 = 0;
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($$1|0));
                  $744 = __THREW__; __THREW__ = 0;
                  $745 = $744&1;
                  if ($745) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $746 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                  $747 = __THREW__; __THREW__ = 0;
                  $748 = $747&1;
                  if ($748) {
                   label = 13;
                   break L40;
                  }
                  $749 = ($746<<16>>16)==(45);
                  $$V_21$3 = $749 ? 1 : -1;
                  $V_21$1 = $$V_21$3;
                 }
                 $750 = (($V_4$4) + 1)|0;
                 __THREW__ = 0;
                 $751 = (invoke_iiiiiiiii(24,0,($$1|0),($750|0),0,2,1,($103|0),($V_25|0))|0);
                 $752 = __THREW__; __THREW__ = 0;
                 $753 = $752&1;
                 if ($753) {
                  label = 13;
                  break L40;
                 }
                 $754 = HEAP32[$V_25>>2]|0;
                 $755 = (($754) + ($750))|0;
                 $756 = ($754|0)>(-1);
                 if (!($756)) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $757 = __THREW__; __THREW__ = 0;
                 $758 = $757&1;
                 if ($758) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $759 = (invoke_iii(621,($$1|0),($755|0))|0);
                 $760 = __THREW__; __THREW__ = 0;
                 $761 = $760&1;
                 if ($761) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $762 = (invoke_iii(600,(0|0),($759|0))|0);
                 $763 = __THREW__; __THREW__ = 0;
                 $764 = $763&1;
                 if ($764) {
                  label = 13;
                  break L40;
                 }
                 if ($762) {
                  HEAP32[$V_25>>2] = 0;
                  $774 = 0;
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($dfi$|0));
                  $765 = __THREW__; __THREW__ = 0;
                  $766 = $765&1;
                  if ($766) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $767 = (invoke_ii(2000,($dfi$|0))|0);
                  $768 = __THREW__; __THREW__ = 0;
                  $769 = $768&1;
                  if ($769) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $770 = (invoke_iiiiiii(91,0,($$1|0),($755|0),0,($767|0),($V_25|0))|0);
                  $771 = __THREW__; __THREW__ = 0;
                  $772 = $771&1;
                  if ($772) {
                   label = 13;
                   break L40;
                  }
                  if (!($770)) {
                   $$0 = 0;
                   label = 541;
                   break L40;
                  }
                  $$pre = HEAP32[$V_25>>2]|0;
                  $774 = $$pre;
                 }
                 $773 = (($774) + ($755))|0;
                 __THREW__ = 0;
                 $775 = (invoke_iiiiiiiii(24,0,($$1|0),($773|0),0,2,1,($103|0),($V_25|0))|0);
                 $776 = __THREW__; __THREW__ = 0;
                 $777 = $776&1;
                 if ($777) {
                  label = 13;
                  break L40;
                 }
                 $778 = HEAP32[$V_25>>2]|0;
                 $779 = ($778|0)>(-1);
                 if ($779) {
                  $V_11$3 = 2;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$1;$V_22$0 = $751;$V_23$0 = $775;$V_4$2 = $773;
                 } else {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 break;
                }
                case 1:  {
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $786 = __THREW__; __THREW__ = 0;
                 $787 = $786&1;
                 if ($787) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $788 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                 $789 = __THREW__; __THREW__ = 0;
                 $790 = $789&1;
                 if ($790) {
                  label = 13;
                  break L40;
                 }
                 $791 = ($788<<16>>16)==(71);
                 if (!($791)) {
                  $$0 = 0;
                  label = 541;
                  break L40;
                 }
                 $792 = (($V_10$0) + 2)|0;
                 $793 = ($792|0)<($V_9$0|0);
                 do {
                  if ($793) {
                   $794 = (($V_4$4) + 2)|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($$1|0));
                   $795 = __THREW__; __THREW__ = 0;
                   $796 = $795&1;
                   if ($796) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $797 = (invoke_ii(1816,($$1|0))|0);
                   $798 = __THREW__; __THREW__ = 0;
                   $799 = $798&1;
                   if ($799) {
                    label = 13;
                    break L40;
                   }
                   $800 = ($794|0)<($797|0);
                   if (!($800)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($V_8$0|0));
                   $801 = __THREW__; __THREW__ = 0;
                   $802 = $801&1;
                   if ($802) {
                    label = 13;
                    break L40;
                   }
                   $803 = (($V_10$0) + 1)|0;
                   __THREW__ = 0;
                   $804 = (invoke_iii(621,($V_8$0|0),($803|0))|0);
                   $805 = __THREW__; __THREW__ = 0;
                   $806 = $805&1;
                   if ($806) {
                    label = 13;
                    break L40;
                   }
                   $807 = ($804<<16>>16)==(77);
                   if (!($807)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($$1|0));
                   $808 = __THREW__; __THREW__ = 0;
                   $809 = $808&1;
                   if ($809) {
                    label = 13;
                    break L40;
                   }
                   $810 = (($V_4$4) + 1)|0;
                   __THREW__ = 0;
                   $811 = (invoke_iii(621,($$1|0),($810|0))|0);
                   $812 = __THREW__; __THREW__ = 0;
                   $813 = $812&1;
                   if ($813) {
                    label = 13;
                    break L40;
                   }
                   $814 = ($811<<16>>16)==(77);
                   if (!($814)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($V_8$0|0));
                   $815 = __THREW__; __THREW__ = 0;
                   $816 = $815&1;
                   if ($816) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $817 = (invoke_iii(621,($V_8$0|0),($792|0))|0);
                   $818 = __THREW__; __THREW__ = 0;
                   $819 = $818&1;
                   if ($819) {
                    label = 13;
                    break L40;
                   }
                   $820 = ($817<<16>>16)==(84);
                   if (!($820)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($$1|0));
                   $821 = __THREW__; __THREW__ = 0;
                   $822 = $821&1;
                   if ($822) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $823 = (invoke_iii(621,($$1|0),($794|0))|0);
                   $824 = __THREW__; __THREW__ = 0;
                   $825 = $824&1;
                   if ($825) {
                    label = 13;
                    break L40;
                   }
                   $826 = ($823<<16>>16)==(84);
                   if (!($826)) {
                    break;
                   }
                   HEAP8[$V_0>>0] = 1;
                   HEAP32[$V_25>>2] = 3;
                   $V_11$3 = 2;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                   break L213;
                  }
                 } while(0);
                 HEAP32[$V_25>>2] = 1;
                 $V_11$3 = 0;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                 break;
                }
                default: {
                 $470 = (($467) + 65421)|0;
                 $471 = $470 & 65535;
                 if ((($471|0) == 6)) {
                  $580 = ($V_15$2|0)==(-1);
                  if (!($580)) {
                   $$0 = 0;
                   label = 541;
                   break L40;
                  }
                  $581 = ($V_11$4|0)==(0);
                  do {
                   if ($581) {
                    __THREW__ = 0;
                    $582 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,0,($103|0),($V_25|0))|0);
                    $583 = __THREW__; __THREW__ = 0;
                    $584 = $583&1;
                    if ($584) {
                     label = 13;
                     break L40;
                    } else {
                     $V_11$2$ph = 0;$V_15$0$ph = $582;
                     label = 289;
                    }
                   } else {
                    $585 = ($V_11$4|0)>(2);
                    if (!($585)) {
                     __THREW__ = 0;
                     $586 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,1,($103|0),($V_25|0))|0);
                     $587 = __THREW__; __THREW__ = 0;
                     $588 = $587&1;
                     if ($588) {
                      label = 13;
                      break L40;
                     } else {
                      $V_11$2$ph = $V_11$4;$V_15$0$ph = $586;
                      label = 289;
                      break;
                     }
                    }
                    __THREW__ = 0;
                    $589 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),($$|0),4,0,($103|0),($V_25|0))|0);
                    $590 = __THREW__; __THREW__ = 0;
                    $591 = $590&1;
                    if ($591) {
                     label = 13;
                     break L40;
                    }
                    $592 = ($589|0)>(999);
                    $593 = HEAP32[$V_25>>2]|0;
                    $594 = ($593|0)==(4);
                    $or$cond14 = $592 & $594;
                    if (!($or$cond14)) {
                     $610 = $593;$V_11$2 = 3;$V_15$0 = $589;
                     break;
                    }
                    $595 = HEAP8[$longYear>>0]|0;
                    $596 = ($595<<24>>24)==(0);
                    if (!($596)) {
                     $V_11$2$ph = 3;$V_15$0$ph = $589;
                     label = 289;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($$1|0));
                    $597 = __THREW__; __THREW__ = 0;
                    $598 = $597&1;
                    if ($598) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $599 = (invoke_ii(1816,($$1|0))|0);
                    $600 = __THREW__; __THREW__ = 0;
                    $601 = $600&1;
                    if ($601) {
                     label = 13;
                     break L40;
                    }
                    $602 = (($V_4$4) + 4)|0;
                    $603 = ($599|0)>($602|0);
                    if (!($603)) {
                     $V_11$2$ph = 3;$V_15$0$ph = $589;
                     label = 289;
                     break;
                    }
                    HEAP32[$V_29>>2] = 0;
                    __THREW__ = 0;
                    $604 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),5,5,0,($103|0),($V_29|0))|0);
                    $605 = __THREW__; __THREW__ = 0;
                    $606 = $605&1;
                    if ($606) {
                     label = 13;
                     break L40;
                    }
                    $607 = ($604|0)>(9999);
                    $608 = $607&1;
                    HEAP8[$longYear>>0] = $608;
                    $V_11$2$ph = 3;$V_15$0$ph = $589;
                    label = 289;
                   }
                  } while(0);
                  if ((label|0) == 289) {
                   label = 0;
                   $$pr60 = HEAP32[$V_25>>2]|0;
                   $610 = $$pr60;$V_11$2 = $V_11$2$ph;$V_15$0 = $V_15$0$ph;
                  }
                  $609 = ($610|0)>(2);
                  if ($609) {
                   $V_11$3 = $V_11$2;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$0;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                   break L213;
                  }
                  $611 = ($V_15$0|0)>(29);
                  $$15 = $611 ? 1900 : 2000;
                  $612 = (($$15) + ($V_15$0))|0;
                  $V_11$3 = $V_11$2;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $612;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                  break L213;
                 } else if ((($471|0) == 7)) {
                  $668 = ($V_21$3|0)==(-1);
                  if (!($668)) {
                   $$0 = 0;
                   label = 541;
                   break L40;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($$1|0));
                  $669 = __THREW__; __THREW__ = 0;
                  $670 = $669&1;
                  if ($670) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $671 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                  $672 = __THREW__; __THREW__ = 0;
                  $673 = $672&1;
                  if ($673) {
                   label = 13;
                   break L40;
                  }
                  $674 = ($671<<16>>16)==(43);
                  if ($674) {
                   $V_21$0 = 0;
                  } else {
                   __THREW__ = 0;
                   invoke_vi(3799,($$1|0));
                   $675 = __THREW__; __THREW__ = 0;
                   $676 = $675&1;
                   if ($676) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $677 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                   $678 = __THREW__; __THREW__ = 0;
                   $679 = $678&1;
                   if ($679) {
                    label = 13;
                    break L40;
                   }
                   $680 = ($677<<16>>16)==(45);
                   if ($680) {
                    $V_21$0 = 1;
                   } else {
                    $$0 = 0;
                    label = 541;
                    break L40;
                   }
                  }
                  $681 = (($V_4$4) + 1)|0;
                  if ((($V_11$4|0) == 0)) {
                   __THREW__ = 0;
                   $682 = (invoke_iiiiiiiii(24,0,($$1|0),($681|0),1,2,0,($103|0),($V_25|0))|0);
                   $683 = __THREW__; __THREW__ = 0;
                   $684 = $683&1;
                   if ($684) {
                    label = 13;
                    break L40;
                   } else {
                    $V_11$3 = 0;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$0;$V_22$0 = $682;$V_23$0 = $V_23$1;$V_4$2 = $681;
                    break L213;
                   }
                  } else if ((($V_11$4|0) == 1)) {
                   __THREW__ = 0;
                   $685 = (invoke_iiiiiiiii(24,0,($$1|0),($681|0),1,2,1,($103|0),($V_25|0))|0);
                   $686 = __THREW__; __THREW__ = 0;
                   $687 = $686&1;
                   if ($687) {
                    label = 13;
                    break L40;
                   } else {
                    $V_11$3 = 1;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$0;$V_22$0 = $685;$V_23$0 = $V_23$1;$V_4$2 = $681;
                    break L213;
                   }
                  } else {
                   __THREW__ = 0;
                   $688 = (invoke_iiiiiiiii(24,0,($$1|0),($681|0),1,2,1,1,($V_25|0))|0);
                   $689 = __THREW__; __THREW__ = 0;
                   $690 = $689&1;
                   if ($690) {
                    label = 13;
                    break L40;
                   }
                   $691 = HEAP32[$V_25>>2]|0;
                   $692 = (($691) + ($681))|0;
                   $693 = ($691|0)>(-1);
                   if (!($693)) {
                    $$0 = 0;
                    label = 541;
                    break L40;
                   }
                   HEAP32[$V_25>>2] = 0;
                   __THREW__ = 0;
                   invoke_vi(3799,($$1|0));
                   $694 = __THREW__; __THREW__ = 0;
                   $695 = $694&1;
                   if ($695) {
                    label = 13;
                    break L40;
                   }
                   __THREW__ = 0;
                   $696 = (invoke_ii(1816,($$1|0))|0);
                   $697 = __THREW__; __THREW__ = 0;
                   $698 = $697&1;
                   if ($698) {
                    label = 13;
                    break L40;
                   }
                   $699 = ($692|0)<($696|0);
                   if ($699) {
                    __THREW__ = 0;
                    invoke_vi(3799,($$1|0));
                    $700 = __THREW__; __THREW__ = 0;
                    $701 = $700&1;
                    if ($701) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $702 = (invoke_iii(621,($$1|0),($692|0))|0);
                    $703 = __THREW__; __THREW__ = 0;
                    $704 = $703&1;
                    if ($704) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $705 = (invoke_iii(600,(0|0),($702|0))|0);
                    $706 = __THREW__; __THREW__ = 0;
                    $707 = $706&1;
                    if ($707) {
                     label = 13;
                     break L40;
                    }
                    if (!($705)) {
                     label = 340;
                    }
                   } else {
                    label = 340;
                   }
                   do {
                    if ((label|0) == 340) {
                     label = 0;
                     __THREW__ = 0;
                     $708 = (invoke_iiiiiii(92,0,($$1|0),($692|0),($dfi$|0),($exact|0),($V_25|0))|0);
                     $709 = __THREW__; __THREW__ = 0;
                     $710 = $709&1;
                     if ($710) {
                      label = 13;
                      break L40;
                     }
                     if ($708) {
                      break;
                     }
                     if (!($G_B3_0$0$off0)) {
                      $$0 = 0;
                      label = 541;
                      break L40;
                     }
                     HEAP32[$V_25>>2] = 0;
                     $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$0;$V_22$0 = $688;$V_23$0 = $V_23$1;$V_4$2 = $692;
                     break L213;
                    }
                   } while(0);
                   $711 = HEAP32[$V_25>>2]|0;
                   $712 = (($711) + ($692))|0;
                   __THREW__ = 0;
                   $713 = (invoke_iiiiiiiii(24,0,($$1|0),($712|0),1,2,1,($103|0),($V_25|0))|0);
                   $714 = __THREW__; __THREW__ = 0;
                   $715 = $714&1;
                   if ($715) {
                    label = 13;
                    break L40;
                   }
                   $716 = HEAP32[$V_25>>2]|0;
                   $717 = ($716|0)>(-1);
                   if ($717) {
                    $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$0;$V_22$0 = $688;$V_23$0 = $713;$V_4$2 = $712;
                    break L213;
                   } else {
                    $$0 = 0;
                    label = 541;
                    break L40;
                   }
                  }
                 } else if ((($471|0) == 0)) {
                  $643 = ($V_18$2|0)==(-1);
                  if (!($643)) {
                   $$0 = 0;
                   label = 541;
                   break L40;
                  }
                  $644 = ($V_11$4|0)==(0);
                  if ($644) {
                   __THREW__ = 0;
                   $645 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,0,($103|0),($V_25|0))|0);
                   $646 = __THREW__; __THREW__ = 0;
                   $647 = $646&1;
                   if ($647) {
                    label = 13;
                    break L40;
                   } else {
                    $V_18$0 = $645;
                   }
                  } else {
                   __THREW__ = 0;
                   $648 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,1,($103|0),($V_25|0))|0);
                   $649 = __THREW__; __THREW__ = 0;
                   $650 = $649&1;
                   if ($650) {
                    label = 13;
                    break L40;
                   } else {
                    $V_18$0 = $648;
                   }
                  }
                  $651 = ($V_18$0|0)<(60);
                  if ($651) {
                   $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$0;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                   break L213;
                  } else {
                   $$0 = 0;
                   label = 541;
                   break L40;
                  }
                 } else if ((($471|0) == 1)) {
                  $664 = ($V_11$4|0)<(1);
                  $$17 = $664&1;
                  __THREW__ = 0;
                  $665 = (invoke_iiiiiiiii(25,0,($$1|0),($V_4$4|0),($$17|0),($dfi$|0),($exact|0),($V_25|0),($V_20|0))|0);
                  $666 = __THREW__; __THREW__ = 0;
                  $667 = $666&1;
                  if ($667) {
                   label = 13;
                   break L40;
                  }
                  if ($665) {
                   $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                   break L213;
                  } else {
                   $$0 = 0;
                   label = 541;
                   break L40;
                  }
                 } else {
                  $472 = (($467) + 65436)|0;
                  $473 = $472 & 65535;
                  if ((($473|0) == 0)) {
                   $474 = ($V_11$4|0)>(1);
                   $475 = ($V_12$1|0)==(-1);
                   $or$cond11 = $474 | $475;
                   if (!($or$cond11)) {
                    $$0 = 0;
                    label = 541;
                    break L40;
                   }
                   $476 = ($V_11$4|0)<(2);
                   $477 = ($V_13$2|0)==(-1);
                   $or$cond12 = $476 | $477;
                   if (!($or$cond12)) {
                    $$0 = 0;
                    label = 541;
                    break L40;
                   }
                   if ((($V_11$4|0) == 1)) {
                    __THREW__ = 0;
                    $481 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,1,($103|0),($V_25|0))|0);
                    $482 = __THREW__; __THREW__ = 0;
                    $483 = $482&1;
                    if ($483) {
                     label = 13;
                     break L40;
                    } else {
                     $V_11$3 = 1;$V_12$0 = $481;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                     break L213;
                    }
                   } else if ((($V_11$4|0) == 0)) {
                    __THREW__ = 0;
                    $478 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,0,($103|0),($V_25|0))|0);
                    $479 = __THREW__; __THREW__ = 0;
                    $480 = $479&1;
                    if ($480) {
                     label = 13;
                     break L40;
                    } else {
                     $V_11$3 = 0;$V_12$0 = $478;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                     break L213;
                    }
                   } else if ((($V_11$4|0) == 2)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($dfi$|0));
                    $484 = __THREW__; __THREW__ = 0;
                    $485 = $484&1;
                    if ($485) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $486 = (invoke_ii(1993,($dfi$|0))|0);
                    $487 = __THREW__; __THREW__ = 0;
                    $488 = $487&1;
                    if ($488) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($55|0));
                    $489 = __THREW__; __THREW__ = 0;
                    $490 = $489&1;
                    if ($490) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $491 = (invoke_ii(1993,($55|0))|0);
                    $492 = __THREW__; __THREW__ = 0;
                    $493 = $492&1;
                    if ($493) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $494 = (invoke_iiiiiiii(94,0,($$1|0),($V_4$4|0),($486|0),($491|0),($exact|0),($V_25|0))|0);
                    $495 = __THREW__; __THREW__ = 0;
                    $496 = $495&1;
                    if ($496) {
                     label = 13;
                     break L40;
                    } else {
                     $V_11$3 = 2;$V_12$0 = $V_12$1;$V_13$3 = $494;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                     break L213;
                    }
                   } else {
                    __THREW__ = 0;
                    invoke_vi(3799,($dfi$|0));
                    $497 = __THREW__; __THREW__ = 0;
                    $498 = $497&1;
                    if ($498) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $499 = (invoke_ii(1995,($dfi$|0))|0);
                    $500 = __THREW__; __THREW__ = 0;
                    $501 = $500&1;
                    if ($501) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($55|0));
                    $502 = __THREW__; __THREW__ = 0;
                    $503 = $502&1;
                    if ($503) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $504 = (invoke_ii(1995,($55|0))|0);
                    $505 = __THREW__; __THREW__ = 0;
                    $506 = $505&1;
                    if ($506) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $507 = (invoke_iiiiiiii(94,0,($$1|0),($V_4$4|0),($499|0),($504|0),($exact|0),($V_25|0))|0);
                    $508 = __THREW__; __THREW__ = 0;
                    $509 = $508&1;
                    if ($509) {
                     label = 13;
                     break L40;
                    } else {
                     $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $507;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                     break L213;
                    }
                   }
                  } else if ((($473|0) == 4)) {
                   $613 = ($V_16$3|0)==(-1);
                   if (!($613)) {
                    $$0 = 0;
                    label = 541;
                    break L40;
                   }
                   $614 = ($V_11$4|0)==(0);
                   if ($614) {
                    __THREW__ = 0;
                    $615 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,0,($103|0),($V_25|0))|0);
                    $616 = __THREW__; __THREW__ = 0;
                    $617 = $616&1;
                    if ($617) {
                     label = 13;
                     break L40;
                    } else {
                     $V_16$0 = $615;
                    }
                   } else {
                    __THREW__ = 0;
                    $618 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,1,($103|0),($V_25|0))|0);
                    $619 = __THREW__; __THREW__ = 0;
                    $620 = $619&1;
                    if ($620) {
                     label = 13;
                     break L40;
                    } else {
                     $V_16$0 = $618;
                    }
                   }
                   $621 = ($V_16$0|0)<(13);
                   if (!($621)) {
                    $$0 = 0;
                    label = 541;
                    break L40;
                   }
                   $622 = ($V_16$0|0)==(12);
                   $$V_16$0 = $622 ? 0 : $V_16$0;
                   $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $$V_16$0;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                   break L213;
                  } else if ((($473|0) == 2)) {
                   $V_27$0$off0 = 1;
                   label = 315;
                   break L213;
                  } else {
                   if ((($464<<16>>16) == 109)) {
                    $634 = ($V_17$2|0)==(-1);
                    if (!($634)) {
                     $$0 = 0;
                     label = 541;
                     break L40;
                    }
                    $635 = ($V_11$4|0)==(0);
                    if ($635) {
                     __THREW__ = 0;
                     $636 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,0,($103|0),($V_25|0))|0);
                     $637 = __THREW__; __THREW__ = 0;
                     $638 = $637&1;
                     if ($638) {
                      label = 13;
                      break L40;
                     } else {
                      $V_17$0 = $636;
                     }
                    } else {
                     __THREW__ = 0;
                     $639 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),1,2,1,($103|0),($V_25|0))|0);
                     $640 = __THREW__; __THREW__ = 0;
                     $641 = $640&1;
                     if ($641) {
                      label = 13;
                      break L40;
                     } else {
                      $V_17$0 = $639;
                     }
                    }
                    $642 = ($V_17$0|0)<(60);
                    if ($642) {
                     $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$0;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                     break L213;
                    } else {
                     $$0 = 0;
                     label = 541;
                     break L40;
                    }
                   } else if ((($464<<16>>16) == 90)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($$1|0));
                    $780 = __THREW__; __THREW__ = 0;
                    $781 = $780&1;
                    if ($781) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $782 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                    $783 = __THREW__; __THREW__ = 0;
                    $784 = $783&1;
                    if ($784) {
                     label = 13;
                     break L40;
                    }
                    $785 = ($782<<16>>16)==(90);
                    if (!($785)) {
                     $$0 = 0;
                     label = 541;
                     break L40;
                    }
                    HEAP32[$V_25>>2] = 1;
                    HEAP8[$V_0>>0] = 1;
                    $V_11$3 = 0;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                    break L213;
                   } else if ((($464<<16>>16) == 47)) {
                    __THREW__ = 0;
                    $830 = (invoke_iiiiiii(93,0,($$1|0),($V_4$4|0),($dfi$|0),($exact|0),($V_25|0))|0);
                    $831 = __THREW__; __THREW__ = 0;
                    $832 = $831&1;
                    if ($832) {
                     label = 13;
                     break L40;
                    }
                    if ($830) {
                     $V_11$3 = 0;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                     break L213;
                    } else {
                     $$0 = 0;
                     label = 541;
                     break L40;
                    }
                   } else if ((($464<<16>>16) == 58)) {
                    __THREW__ = 0;
                    $827 = (invoke_iiiiiii(92,0,($$1|0),($V_4$4|0),($dfi$|0),($exact|0),($V_25|0))|0);
                    $828 = __THREW__; __THREW__ = 0;
                    $829 = $828&1;
                    if ($829) {
                     label = 13;
                     break L40;
                    }
                    if ($827) {
                     $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                     break L213;
                    } else {
                     $$0 = 0;
                     label = 541;
                     break L40;
                    }
                   } else {
                    __THREW__ = 0;
                    invoke_vi(3799,($$1|0));
                    $833 = __THREW__; __THREW__ = 0;
                    $834 = $833&1;
                    if ($834) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $835 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
                    $836 = __THREW__; __THREW__ = 0;
                    $837 = $836&1;
                    if ($837) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($V_8$0|0));
                    $838 = __THREW__; __THREW__ = 0;
                    $839 = $838&1;
                    if ($839) {
                     label = 13;
                     break L40;
                    }
                    __THREW__ = 0;
                    $840 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
                    $841 = __THREW__; __THREW__ = 0;
                    $842 = $841&1;
                    if ($842) {
                     label = 13;
                     break L40;
                    }
                    $843 = ($835<<16>>16)==($840<<16>>16);
                    if (!($843)) {
                     $$0 = 0;
                     label = 541;
                     break L40;
                    }
                    HEAP32[$V_25>>2] = 1;
                    $V_11$3 = 0;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $V_19$1;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
                    break L213;
                   }
                  }
                 }
                }
                }
               } while(0);
               if ((label|0) == 315) {
                label = 0;
                $652 = ($V_11$4|0)<(7);
                $653 = $V_19$1 == -1.0;
                $or$cond16 = $652 & $653;
                if (!($or$cond16)) {
                 $$0 = 0;
                 label = 541;
                 break L40;
                }
                $654 = (($V_11$4) + 1)|0;
                __THREW__ = 0;
                $655 = (invoke_iiiiiiiii(24,0,($$1|0),($V_4$4|0),0,($654|0),($V_27$0$off0|0),($103|0),($V_25|0))|0);
                $656 = __THREW__; __THREW__ = 0;
                $657 = $656&1;
                if ($657) {
                 label = 13;
                 break L40;
                }
                $658 = HEAP32[$V_25>>2]|0;
                $659 = ($658|0)==(-1);
                if ($659) {
                 $$0 = 0;
                 label = 541;
                 break L40;
                }
                $660 = (+($655|0));
                $661 = (+($658|0));
                $662 = (+Math_pow(10.0,(+$661)));
                $663 = $660 / $662;
                $V_11$3 = $V_11$4;$V_12$0 = $V_12$1;$V_13$3 = $V_13$2;$V_14$2 = $V_14$3;$V_15$1 = $V_15$2;$V_16$2 = $V_16$3;$V_17$1 = $V_17$2;$V_18$1 = $V_18$2;$V_19$0 = $663;$V_21$2 = $V_21$3;$V_22$0 = $V_22$1;$V_23$0 = $V_23$1;$V_4$2 = $V_4$4;
               }
               $844 = HEAP32[$V_25>>2]|0;
               $845 = ($844|0)>(-1);
               if (!($845)) {
                $$0 = 0;
                label = 541;
                break L40;
               }
               $846 = (($844) + ($V_4$2))|0;
               L428: do {
                if ($brmerge18) {
                 $V_4$3 = $846;
                } else {
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $847 = __THREW__; __THREW__ = 0;
                 $848 = $847&1;
                 if ($848) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $849 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
                 $850 = __THREW__; __THREW__ = 0;
                 $851 = $850&1;
                 if ($851) {
                  label = 13;
                  break L40;
                 }
                 switch ($849<<16>>16) {
                 case 122: case 115: case 109: case 102: case 70:  {
                  break;
                 }
                 default: {
                  $V_4$3 = $846;
                  break L428;
                 }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $852 = __THREW__; __THREW__ = 0;
                 $853 = $852&1;
                 if ($853) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $854 = (invoke_ii(1816,($$1|0))|0);
                 $855 = __THREW__; __THREW__ = 0;
                 $856 = $855&1;
                 if ($856) {
                  label = 13;
                  break L40;
                 }
                 $857 = ($854|0)>($846|0);
                 if (!($857)) {
                  $V_4$3 = $846;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($$1|0));
                 $858 = __THREW__; __THREW__ = 0;
                 $859 = $858&1;
                 if ($859) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $860 = (invoke_iii(621,($$1|0),($846|0))|0);
                 $861 = __THREW__; __THREW__ = 0;
                 $862 = $861&1;
                 if ($862) {
                  label = 13;
                  break L40;
                 }
                 $863 = ($860<<16>>16)==(90);
                 if (!($863)) {
                  $V_4$3 = $846;
                  break;
                 }
                 $864 = (($V_10$0) + 1)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($V_8$0|0));
                 $865 = __THREW__; __THREW__ = 0;
                 $866 = $865&1;
                 if ($866) {
                  label = 13;
                  break L40;
                 }
                 __THREW__ = 0;
                 $867 = (invoke_ii(1816,($V_8$0|0))|0);
                 $868 = __THREW__; __THREW__ = 0;
                 $869 = $868&1;
                 if ($869) {
                  label = 13;
                  break L40;
                 }
                 $870 = ($864|0)==($867|0);
                 if (!($870)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($V_8$0|0));
                  $871 = __THREW__; __THREW__ = 0;
                  $872 = $871&1;
                  if ($872) {
                   label = 13;
                   break L40;
                  }
                  __THREW__ = 0;
                  $873 = (invoke_iii(621,($V_8$0|0),($864|0))|0);
                  $874 = __THREW__; __THREW__ = 0;
                  $875 = $874&1;
                  if ($875) {
                   label = 13;
                   break L40;
                  }
                  $876 = ($873<<16>>16)==(90);
                  if ($876) {
                   $V_4$3 = $846;
                   break;
                  }
                 }
                 HEAP8[$V_0>>0] = 1;
                 $877 = (($846) + 1)|0;
                 $V_4$3 = $877;
                }
               } while(0);
               $878 = (($V_10$0) + 1)|0;
               $879 = (($878) + ($V_11$3))|0;
               $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_10$0 = $879;$V_11$4 = 0;$V_12$1 = $V_12$0;$V_13$4 = $V_13$3;$V_14$3 = $V_14$2;$V_15$2 = $V_15$1;$V_16$3 = $V_16$2;$V_17$2 = $V_17$1;$V_18$2 = $V_18$1;$V_19$1 = $V_19$0;$V_21$3 = $V_21$2;$V_22$1 = $V_22$0;$V_23$1 = $V_23$0;$V_4$4 = $V_4$3;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;
               continue L40;
              }
             } while(0);
             $379 = (($V_4$4) + 1)|0;
             if ($brmerge10) {
              $V_28$0 = $379;
             } else {
              __THREW__ = 0;
              invoke_vi(3799,($V_8$0|0));
              $380 = __THREW__; __THREW__ = 0;
              $381 = $380&1;
              if ($381) {
               label = 13;
               break;
              }
              __THREW__ = 0;
              $382 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
              $383 = __THREW__; __THREW__ = 0;
              $384 = $383&1;
              if ($384) {
               label = 13;
               break;
              }
              __THREW__ = 0;
              $385 = (invoke_iii(604,(0|0),($382|0))|0);
              $386 = __THREW__; __THREW__ = 0;
              $387 = $386&1;
              if ($387) {
               label = 13;
               break;
              }
              if (!($385)) {
               $$0 = 0;
               label = 541;
               break;
              }
              $388 = (($V_10$0) + 1)|0;
              $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = $388;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_4$4 = $379;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
              continue;
             }
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($$1|0));
              $402 = __THREW__; __THREW__ = 0;
              $403 = $402&1;
              if ($403) {
               label = 9;
               break L40;
              }
              __THREW__ = 0;
              $404 = (invoke_ii(1816,($$1|0))|0);
              $405 = __THREW__; __THREW__ = 0;
              $406 = $405&1;
              if ($406) {
               label = 9;
               break L40;
              }
              $407 = ($V_28$0|0)<($404|0);
              if (!($407)) {
               $V_28$1 = $V_10$0;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($$1|0));
              $408 = __THREW__; __THREW__ = 0;
              $409 = $408&1;
              if ($409) {
               label = 9;
               break L40;
              }
              __THREW__ = 0;
              $389 = (invoke_iii(621,($$1|0),($V_28$0|0))|0);
              $390 = __THREW__; __THREW__ = 0;
              $391 = $390&1;
              if ($391) {
               label = 9;
               break L40;
              }
              __THREW__ = 0;
              $392 = (invoke_iii(604,(0|0),($389|0))|0);
              $393 = __THREW__; __THREW__ = 0;
              $394 = $393&1;
              if ($394) {
               label = 9;
               break L40;
              }
              if (!($392)) {
               __THREW__ = 0;
               invoke_vi(3799,($$1|0));
               $395 = __THREW__; __THREW__ = 0;
               $396 = $395&1;
               if ($396) {
                label = 9;
                break L40;
               }
               __THREW__ = 0;
               $397 = (invoke_iii(621,($$1|0),($V_28$0|0))|0);
               $398 = __THREW__; __THREW__ = 0;
               $399 = $398&1;
               if ($399) {
                label = 9;
                break L40;
               }
               $400 = ($397<<16>>16)==(44);
               if (!($400)) {
                $V_28$1 = $V_10$0;
                break;
               }
              }
              $401 = (($V_28$0) + 1)|0;
              $V_28$0 = $401;
             }
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($V_8$0|0));
              $423 = __THREW__; __THREW__ = 0;
              $424 = $423&1;
              if ($424) {
               label = 10;
               break L40;
              }
              __THREW__ = 0;
              $425 = (invoke_ii(1816,($V_8$0|0))|0);
              $426 = __THREW__; __THREW__ = 0;
              $427 = $426&1;
              if ($427) {
               label = 10;
               break L40;
              }
              $428 = ($V_28$1|0)<($425|0);
              if (!($428)) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($V_8$0|0));
              $429 = __THREW__; __THREW__ = 0;
              $430 = $429&1;
              if ($430) {
               label = 10;
               break L40;
              }
              __THREW__ = 0;
              $410 = (invoke_iii(621,($V_8$0|0),($V_28$1|0))|0);
              $411 = __THREW__; __THREW__ = 0;
              $412 = $411&1;
              if ($412) {
               label = 10;
               break L40;
              }
              __THREW__ = 0;
              $413 = (invoke_iii(604,(0|0),($410|0))|0);
              $414 = __THREW__; __THREW__ = 0;
              $415 = $414&1;
              if ($415) {
               label = 10;
               break L40;
              }
              if (!($413)) {
               __THREW__ = 0;
               invoke_vi(3799,($V_8$0|0));
               $416 = __THREW__; __THREW__ = 0;
               $417 = $416&1;
               if ($417) {
                label = 10;
                break L40;
               }
               __THREW__ = 0;
               $418 = (invoke_iii(621,($V_8$0|0),($V_28$1|0))|0);
               $419 = __THREW__; __THREW__ = 0;
               $420 = $419&1;
               if ($420) {
                label = 10;
                break L40;
               }
               $421 = ($418<<16>>16)==(44);
               if (!($421)) {
                break;
               }
              }
              $422 = (($V_28$1) + 1)|0;
              $V_28$1 = $422;
             }
             if ($exact) {
              $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = $V_28$1;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_4$4 = $V_28$0;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
              continue;
             }
             __THREW__ = 0;
             invoke_vi(3799,($V_8$0|0));
             $431 = __THREW__; __THREW__ = 0;
             $432 = $431&1;
             if ($432) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $433 = (invoke_ii(1816,($V_8$0|0))|0);
             $434 = __THREW__; __THREW__ = 0;
             $435 = $434&1;
             if ($435) {
              label = 13;
              break;
             }
             $436 = ($V_28$1|0)<($433|0);
             if (!($436)) {
              $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = $V_28$1;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_4$4 = $V_28$0;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
              continue;
             }
             __THREW__ = 0;
             invoke_vi(3799,($V_8$0|0));
             $437 = __THREW__; __THREW__ = 0;
             $438 = $437&1;
             if ($438) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $439 = (invoke_iii(621,($V_8$0|0),($V_28$1|0))|0);
             $440 = __THREW__; __THREW__ = 0;
             $441 = $440&1;
             if ($441) {
              label = 13;
              break;
             }
             $442 = ($439<<16>>16)==(47);
             if (!($442)) {
              $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = $V_28$1;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_4$4 = $V_28$0;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
              continue;
             }
             __THREW__ = 0;
             $443 = (invoke_iiiiiii(93,0,($$1|0),($V_28$0|0),($dfi$|0),0,($V_25|0))|0);
             $444 = __THREW__; __THREW__ = 0;
             $445 = $444&1;
             if ($445) {
              label = 13;
              break;
             }
             $446 = $443&1;
             $447 = $446 ^ 1;
             $V_28$1$ = (($447) + ($V_28$1))|0;
             $V_9$0$phi = $V_9$0;$V_8$0$phi = $V_8$0;$V_6$0$off0$phi = $V_6$0$off0;$V_5$4$phi = $V_5$4;$V_24$0$off0$phi = $V_24$0$off0;$V_23$1$phi = $V_23$1;$V_22$1$phi = $V_22$1;$V_21$3$phi = $V_21$3;$V_19$1$phi = $V_19$1;$V_18$2$phi = $V_18$2;$V_17$2$phi = $V_17$2;$V_16$3$phi = $V_16$3;$V_15$2$phi = $V_15$2;$V_14$3$phi = $V_14$3;$V_12$1$phi = $V_12$1;$V_10$0 = $V_28$1$;$V_11$4 = 0;$V_13$4 = $V_13$2;$V_4$4 = $V_28$0;$V_9$0 = $V_9$0$phi;$V_8$0 = $V_8$0$phi;$V_6$0$off0 = $V_6$0$off0$phi;$V_5$4 = $V_5$4$phi;$V_24$0$off0 = $V_24$0$off0$phi;$V_23$1 = $V_23$1$phi;$V_22$1 = $V_22$1$phi;$V_21$3 = $V_21$3$phi;$V_19$1 = $V_19$1$phi;$V_18$2 = $V_18$2$phi;$V_17$2 = $V_17$2$phi;$V_16$3 = $V_16$3$phi;$V_15$2 = $V_15$2$phi;$V_14$3 = $V_14$3$phi;$V_12$1 = $V_12$1$phi;
            }
            if ((label|0) == 9) {
             $26 = ___cxa_find_matching_catch()|0;
             $27 = tempRet0;
             $lpad$phi$index = $26;$lpad$phi$index8 = $27;
             break;
            }
            else if ((label|0) == 10) {
             $28 = ___cxa_find_matching_catch()|0;
             $29 = tempRet0;
             $lpad$phi$index = $28;$lpad$phi$index8 = $29;
             break;
            }
            else if ((label|0) == 11) {
             $30 = ___cxa_find_matching_catch()|0;
             $31 = tempRet0;
             $lpad$phi$index = $30;$lpad$phi$index8 = $31;
             break;
            }
            else if ((label|0) == 12) {
             $32 = ___cxa_find_matching_catch()|0;
             $33 = tempRet0;
             $lpad$phi$index = $32;$lpad$phi$index8 = $33;
             break;
            }
            else if ((label|0) == 13) {
             $34 = ___cxa_find_matching_catch()|0;
             $35 = tempRet0;
             $lpad$phi$index = $34;$lpad$phi$index8 = $35;
             break;
            }
            else if ((label|0) == 432) {
             $882 = (($V_10$0) + 1)|0;
             $883 = ($882|0)<($V_9$0|0);
             L534: do {
              if ($883) {
               __THREW__ = 0;
               invoke_vi(3799,($V_8$0|0));
               $884 = __THREW__; __THREW__ = 0;
               $885 = $884&1;
               if ($885) {
                label = 14;
                break L1;
               }
               __THREW__ = 0;
               $886 = (invoke_iii(621,($V_8$0|0),($V_10$0|0))|0);
               $887 = __THREW__; __THREW__ = 0;
               $888 = $887&1;
               if ($888) {
                label = 14;
                break L1;
               }
               $889 = ($886<<16>>16)==(46);
               if (!($889)) {
                $V_10$2$ph = $V_10$0;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($V_8$0|0));
               $890 = __THREW__; __THREW__ = 0;
               $891 = $890&1;
               if ($891) {
                label = 14;
                break L1;
               }
               __THREW__ = 0;
               $892 = (invoke_iii(621,($V_8$0|0),($882|0))|0);
               $893 = __THREW__; __THREW__ = 0;
               $894 = $893&1;
               if ($894) {
                label = 14;
                break L1;
               }
               $895 = ($892<<16>>16)==(70);
               if ($895) {
                $V_10$176 = $882;
               } else {
                $V_10$2$ph = $V_10$0;
                break;
               }
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($V_8$0|0));
                $899 = __THREW__; __THREW__ = 0;
                $900 = $899&1;
                if ($900) {
                 break;
                }
                __THREW__ = 0;
                $901 = (invoke_iii(621,($V_8$0|0),($V_10$176|0))|0);
                $902 = __THREW__; __THREW__ = 0;
                $903 = $902&1;
                if ($903) {
                 break;
                }
                $904 = ($901<<16>>16)==(70);
                $897 = (($V_10$176) + 1)|0;
                if (!($904)) {
                 $V_10$2$ph = $V_10$176;
                 break L534;
                }
                $896 = ($897|0)<($V_9$0|0);
                if ($896) {
                 $V_10$176 = $897;
                } else {
                 $V_10$2$ph = $897;
                 break L534;
                }
               }
               $24 = ___cxa_find_matching_catch()|0;
               $25 = tempRet0;
               $lpad$phi$index = $24;$lpad$phi$index8 = $25;
               break L1;
              } else {
               $V_10$2$ph = $V_10$0;
              }
             } while(0);
             $898 = ($V_10$2$ph|0)<($V_9$0|0);
             L548: do {
              if ($898) {
               $V_10$270 = $V_10$2$ph;
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($V_8$0|0));
                $907 = __THREW__; __THREW__ = 0;
                $908 = $907&1;
                if ($908) {
                 label = 7;
                 break;
                }
                __THREW__ = 0;
                $909 = (invoke_iii(621,($V_8$0|0),($V_10$270|0))|0);
                $910 = __THREW__; __THREW__ = 0;
                $911 = $910&1;
                if ($911) {
                 label = 7;
                 break;
                }
                $912 = ($909<<16>>16)==(75);
                $906 = (($V_10$270) + 1)|0;
                if (!($912)) {
                 $$0 = 0;
                 label = 541;
                 break;
                }
                $905 = ($906|0)<($V_9$0|0);
                if ($905) {
                 $V_10$270 = $906;
                } else {
                 break L548;
                }
               }
               if ((label|0) == 7) {
                $22 = ___cxa_find_matching_catch()|0;
                $23 = tempRet0;
                $lpad$phi$index = $22;$lpad$phi$index8 = $23;
                break L1;
               }
               else if ((label|0) == 541) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             } while(0);
             __THREW__ = 0;
             invoke_vi(3799,($$1|0));
             $913 = __THREW__; __THREW__ = 0;
             $914 = $913&1;
             if ($914) {
              label = 14;
              break;
             }
             __THREW__ = 0;
             $915 = (invoke_ii(1816,($$1|0))|0);
             $916 = __THREW__; __THREW__ = 0;
             $917 = $916&1;
             if ($917) {
              label = 14;
              break;
             }
             $918 = ($915|0)>($V_4$4|0);
             if ($918) {
              $919 = ($V_4$4|0)==(0);
              if ($919) {
               $$0 = 0;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
              __THREW__ = 0;
              invoke_vi(3799,($$1|0));
              $920 = __THREW__; __THREW__ = 0;
              $921 = $920&1;
              if ($921) {
               label = 14;
               break;
              }
              __THREW__ = 0;
              $922 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
              $923 = __THREW__; __THREW__ = 0;
              $924 = $923&1;
              if ($924) {
               label = 14;
               break;
              }
              __THREW__ = 0;
              $925 = (invoke_iii(600,(0|0),($922|0))|0);
              $926 = __THREW__; __THREW__ = 0;
              $927 = $926&1;
              if ($927) {
               label = 14;
               break;
              }
              do {
               if ($925) {
                __THREW__ = 0;
                invoke_vi(3799,($$1|0));
                $928 = __THREW__; __THREW__ = 0;
                $929 = $928&1;
                if ($929) {
                 label = 14;
                 break L1;
                }
                $930 = (($V_4$4) + -1)|0;
                __THREW__ = 0;
                $931 = (invoke_iii(621,($$1|0),($930|0))|0);
                $932 = __THREW__; __THREW__ = 0;
                $933 = $932&1;
                if ($933) {
                 label = 14;
                 break L1;
                }
                __THREW__ = 0;
                $934 = (invoke_iii(600,(0|0),($931|0))|0);
                $935 = __THREW__; __THREW__ = 0;
                $936 = $935&1;
                if ($936) {
                 label = 14;
                 break L1;
                }
                if ($934) {
                 $$0 = 0;
                } else {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($$1|0));
              $937 = __THREW__; __THREW__ = 0;
              $938 = $937&1;
              if ($938) {
               label = 14;
               break;
              }
              __THREW__ = 0;
              $939 = (invoke_iii(621,($$1|0),($V_4$4|0))|0);
              $940 = __THREW__; __THREW__ = 0;
              $941 = $940&1;
              if ($941) {
               label = 14;
               break;
              }
              __THREW__ = 0;
              $942 = (invoke_iii(601,(0|0),($939|0))|0);
              $943 = __THREW__; __THREW__ = 0;
              $944 = $943&1;
              if ($944) {
               label = 14;
               break;
              }
              do {
               if ($942) {
                __THREW__ = 0;
                invoke_vi(3799,($$1|0));
                $945 = __THREW__; __THREW__ = 0;
                $946 = $945&1;
                if ($946) {
                 label = 14;
                 break L1;
                }
                $947 = (($V_4$4) + -1)|0;
                __THREW__ = 0;
                $948 = (invoke_iii(621,($$1|0),($947|0))|0);
                $949 = __THREW__; __THREW__ = 0;
                $950 = $949&1;
                if ($950) {
                 label = 14;
                 break L1;
                }
                __THREW__ = 0;
                $951 = (invoke_iii(601,(0|0),($948|0))|0);
                $952 = __THREW__; __THREW__ = 0;
                $953 = $952&1;
                if ($953) {
                 label = 14;
                 break L1;
                }
                if ($951) {
                 $$0 = 0;
                } else {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              } while(0);
              HEAP8[$incompleteFormat>>0] = 1;
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             $954 = ($V_16$3|0)==(-1);
             $$V_16$3 = $954 ? 0 : $V_16$3;
             $955 = ($V_17$2|0)==(-1);
             $V_17$3 = $955 ? 0 : $V_17$2;
             $956 = ($V_18$2|0)==(-1);
             $$V_18$2 = $956 ? 0 : $V_18$2;
             $957 = $V_19$1 != -1.0;
             $V_19$2 = $957 ? $V_19$1 : 0.0;
             $958 = ($V_12$1|0)==(-1);
             $959 = ($V_14$3|0)==(-1);
             $or$cond20 = $958 & $959;
             $960 = ($V_15$2|0)==(-1);
             $or$cond21 = $or$cond20 & $960;
             do {
              if ($or$cond21) {
               $961 = $style & 8;
               $962 = ($961|0)==(0);
               if (!($962)) {
                $$V_12$264 = 1;$V_14$565 = 1;$V_15$4 = 1;
                break;
               }
               __THREW__ = 0;
               invoke_vii(1931,($L_601|0),0);
               $963 = __THREW__; __THREW__ = 0;
               $964 = $963&1;
               if ($964) {
                label = 14;
                break L1;
               }
               ;HEAP32[$V_36+0>>2]=HEAP32[$L_601+0>>2]|0;HEAP32[$V_36+4>>2]=HEAP32[$L_601+4>>2]|0;HEAP32[$V_36+8>>2]=HEAP32[$L_601+8>>2]|0;HEAP32[$V_36+12>>2]=HEAP32[$L_601+12>>2]|0;
               __THREW__ = 0;
               $965 = (invoke_ii(2426,($V_36|0))|0);
               $966 = __THREW__; __THREW__ = 0;
               $967 = $966&1;
               if ($967) {
                label = 14;
                break L1;
               }
               __THREW__ = 0;
               invoke_vii(1931,($L_603|0),0);
               $968 = __THREW__; __THREW__ = 0;
               $969 = $968&1;
               if ($969) {
                label = 14;
                break L1;
               }
               ;HEAP32[$V_37+0>>2]=HEAP32[$L_603+0>>2]|0;HEAP32[$V_37+4>>2]=HEAP32[$L_603+4>>2]|0;HEAP32[$V_37+8>>2]=HEAP32[$L_603+8>>2]|0;HEAP32[$V_37+12>>2]=HEAP32[$L_603+12>>2]|0;
               __THREW__ = 0;
               $970 = (invoke_ii(2425,($V_37|0))|0);
               $971 = __THREW__; __THREW__ = 0;
               $972 = $971&1;
               if ($972) {
                label = 14;
                break L1;
               }
               __THREW__ = 0;
               invoke_vii(1931,($L_605|0),0);
               $973 = __THREW__; __THREW__ = 0;
               $974 = $973&1;
               if ($974) {
                label = 14;
                break L1;
               }
               ;HEAP32[$V_38+0>>2]=HEAP32[$L_605+0>>2]|0;HEAP32[$V_38+4>>2]=HEAP32[$L_605+4>>2]|0;HEAP32[$V_38+8>>2]=HEAP32[$L_605+8>>2]|0;HEAP32[$V_38+12>>2]=HEAP32[$L_605+12>>2]|0;
               __THREW__ = 0;
               $975 = (invoke_ii(2433,($V_38|0))|0);
               $976 = __THREW__; __THREW__ = 0;
               $977 = $976&1;
               if ($977) {
                label = 14;
                break L1;
               } else {
                $V_12$2 = $965;$V_14$4 = $970;$V_15$3 = $975;
                label = 478;
               }
              } else {
               $V_12$2 = $V_12$1;$V_14$4 = $V_14$3;$V_15$3 = $V_15$2;
               label = 478;
              }
             } while(0);
             do {
              if ((label|0) == 478) {
               $978 = ($V_12$2|0)==(-1);
               $$V_12$2 = $978 ? 1 : $V_12$2;
               $979 = ($V_14$4|0)==(-1);
               $V_14$5 = $979 ? 1 : $V_14$4;
               $980 = ($V_15$3|0)==(-1);
               if (!($980)) {
                $$V_12$264 = $$V_12$2;$V_14$565 = $V_14$5;$V_15$4 = $V_15$3;
                break;
               }
               $981 = $style & 8;
               $982 = ($981|0)==(0);
               if (!($982)) {
                $$V_12$264 = $$V_12$2;$V_14$565 = $V_14$5;$V_15$4 = 1;
                break;
               }
               __THREW__ = 0;
               invoke_vii(1931,($L_615|0),0);
               $983 = __THREW__; __THREW__ = 0;
               $984 = $983&1;
               if ($984) {
                label = 14;
                break L1;
               }
               ;HEAP32[$V_39+0>>2]=HEAP32[$L_615+0>>2]|0;HEAP32[$V_39+4>>2]=HEAP32[$L_615+4>>2]|0;HEAP32[$V_39+8>>2]=HEAP32[$L_615+8>>2]|0;HEAP32[$V_39+12>>2]=HEAP32[$L_615+12>>2]|0;
               __THREW__ = 0;
               $985 = (invoke_ii(2433,($V_39|0))|0);
               $986 = __THREW__; __THREW__ = 0;
               $987 = $986&1;
               if ($987) {
                label = 14;
                break L1;
               } else {
                $$V_12$264 = $$V_12$2;$V_14$565 = $V_14$5;$V_15$4 = $985;
               }
              }
             } while(0);
             $988 = HEAP32[$V_20>>2]|0;
             $989 = ($988|0)==(0);
             $990 = ($$V_16$3|0)==(12);
             $or$cond22 = $989 & $990;
             $V_16$5 = $or$cond22 ? 0 : $$V_16$3;
             $991 = ($988|0)==(1);
             if ($991) {
              $992 = ($V_16$5|0)>(11);
              $or$cond23 = $G_B3_0$0$off0 & $992;
              $993 = (($V_16$5) + 12)|0;
              $V_16$5$ = $or$cond23 ? $V_16$5 : $993;
              $V_16$6 = $V_16$5$;
             } else {
              $V_16$6 = $V_16$5;
             }
             $V_15$4$off = (($V_15$4) + -1)|0;
             $994 = ($V_15$4$off>>>0)>(9998);
             $995 = ($V_14$565|0)<(1);
             $or$cond25 = $994 | $995;
             $996 = ($V_14$565|0)>(12);
             $or$cond26 = $or$cond25 | $996;
             $997 = ($$V_12$264|0)<(1);
             $or$cond27 = $or$cond26 | $997;
             if ($or$cond27) {
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             $998 = (invoke_iiii(1148,0,($V_15$4|0),($V_14$565|0))|0);
             $999 = __THREW__; __THREW__ = 0;
             $1000 = $999&1;
             if ($1000) {
              label = 14;
              break;
             }
             $1001 = ($$V_12$264|0)>($998|0);
             $1002 = ($V_16$6|0)<(0);
             $or$cond28 = $1001 | $1002;
             $1003 = ($V_16$6|0)>(23);
             $or$cond29 = $or$cond28 | $1003;
             $1004 = ($V_17$3|0)<(0);
             $or$cond30 = $or$cond29 | $1004;
             $1005 = ($V_17$3|0)>(59);
             $or$cond31 = $or$cond30 | $1005;
             $1006 = ($$V_18$2|0)<(0);
             $or$cond32 = $or$cond31 | $1006;
             $or$cond32$not = $or$cond32 ^ 1;
             $1007 = ($$V_18$2|0)<(60);
             $or$cond33 = $1007 & $or$cond32$not;
             if (!($or$cond33)) {
              $$0 = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             invoke_viiiiiiii(14,($result|0),($V_15$4|0),($V_14$565|0),($$V_12$264|0),($V_16$6|0),($V_17$3|0),($$V_18$2|0),0);
             $1008 = __THREW__; __THREW__ = 0;
             $1009 = $1008&1;
             if ($1009) {
              label = 14;
              break;
             }
             __THREW__ = 0;
             invoke_viid(4,($L_637|0),($result|0),(+$V_19$2));
             $1010 = __THREW__; __THREW__ = 0;
             $1011 = $1010&1;
             if ($1011) {
              label = 14;
              break;
             }
             ;HEAP32[$result+0>>2]=HEAP32[$L_637+0>>2]|0;HEAP32[$result+4>>2]=HEAP32[$L_637+4>>2]|0;HEAP32[$result+8>>2]=HEAP32[$L_637+8>>2]|0;HEAP32[$result+12>>2]=HEAP32[$L_637+12>>2]|0;
             $1012 = ($V_13$5|0)==(-1);
             do {
              if (!($1012)) {
               __THREW__ = 0;
               $1013 = (invoke_ii(2427,($result|0))|0);
               $1014 = __THREW__; __THREW__ = 0;
               $1015 = $1014&1;
               if ($1015) {
                label = 14;
                break L1;
               }
               $1016 = ($V_13$5|0)==($1013|0);
               if ($1016) {
                break;
               } else {
                $$0 = 0;
               }
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             } while(0);
             $1017 = ($V_21$3|0)==(-1);
             L619: do {
              if ($1017) {
               __THREW__ = 0;
               (invoke_ii(2996,(2592096|0))|0);
               $1018 = __THREW__; __THREW__ = 0;
               $1019 = $1018&1;
               if ($1019) {
                label = 14;
                break L1;
               }
               $1020 = HEAP8[((2592096 + 116|0))>>0]|0;
               $1021 = ($1020<<24>>24)==(0);
               if ($1021) {
                __THREW__ = 0;
                (invoke_ii(2996,(2592096|0))|0);
                $1022 = __THREW__; __THREW__ = 0;
                $1023 = $1022&1;
                if ($1023) {
                 label = 14;
                 break L1;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2592096|0))|0);
                $1024 = __THREW__; __THREW__ = 0;
                $1025 = $1024&1;
                if ($1025) {
                 label = 14;
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3839,(2592096|0));
                $1026 = __THREW__; __THREW__ = 0;
                $1027 = $1026&1;
                if ($1027) {
                 label = 14;
                 break L1;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2592096|0))|0);
               $1028 = __THREW__; __THREW__ = 0;
               $1029 = $1028&1;
               if ($1029) {
                label = 14;
                break L1;
               }
               $1030 = HEAP32[((2592096 + 80|0))>>2]|0;
               $1031 = (($1030) + 16|0);
               ;HEAP32[$1+0>>2]=HEAP32[$1031+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$1031+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$1031+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$1031+12>>2]|0;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$result+0>>2]|0;HEAP32[$$byval_copy22+4>>2]=HEAP32[$result+4>>2]|0;HEAP32[$$byval_copy22+8>>2]=HEAP32[$result+8>>2]|0;HEAP32[$$byval_copy22+12>>2]=HEAP32[$result+12>>2]|0;
               ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy24+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy24+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy24+12>>2]=HEAP32[$1+12>>2]|0;
               $1032 = (invoke_iiii(1165,0,($$byval_copy22|0),($$byval_copy24|0))|0);
               $1033 = __THREW__; __THREW__ = 0;
               $1034 = $1033&1;
               if ($1034) {
                label = 14;
                break L1;
               }
               if (!($1032)) {
                break;
               }
               __THREW__ = 0;
               ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$result+0>>2]|0;HEAP32[$$byval_copy24+4>>2]=HEAP32[$result+4>>2]|0;HEAP32[$$byval_copy24+8>>2]=HEAP32[$result+8>>2]|0;HEAP32[$$byval_copy24+12>>2]=HEAP32[$result+12>>2]|0;
               invoke_vii(1935,($dto|0),($$byval_copy24|0));
               $1035 = __THREW__; __THREW__ = 0;
               $1036 = $1035&1;
               if (!($1036)) {
                break;
               }
               $1037 = ___cxa_find_matching_catch(348288|0)|0;
               $1038 = tempRet0;
               $1039 = (_llvm_eh_typeid_for((348288|0))|0);
               $1040 = ($1038|0)==($1039|0);
               if (!($1040)) {
                $$04 = $1037;$$05 = $1038;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($$04|0);
                // unreachable;
               }
               $1041 = (___cxa_begin_catch(($1037|0))|0);
               $1042 = HEAP32[$1041>>2]|0;
               $1043 = HEAP32[$1042>>2]|0;
               __THREW__ = 0;
               $1044 = (invoke_iii(2727,(2149728|0),($1043|0))|0);
               $1045 = __THREW__; __THREW__ = 0;
               $1046 = $1045&1;
               do {
                if (!($1046)) {
                 if ($1044) {
                  __THREW__ = 0;
                  invoke_v(66);
                  $1047 = __THREW__; __THREW__ = 0;
                  $1048 = $1047&1;
                  if ($1048) {
                   label = 14;
                   break L1;
                  } else {
                   break L619;
                  }
                 }
                 $1053 = (___cxa_allocate_exception(4)|0);
                 $1054 = HEAP32[$1041>>2]|0;
                 HEAP32[$1053>>2] = $1054;
                 __THREW__ = 0;
                 invoke_viii(1567,($1053|0),(348288|0),(0|0));
                 $1055 = __THREW__; __THREW__ = 0;
                 $1056 = $1055&1;
                 if ($1056) {
                  break;
                 }
                 // unreachable;
                }
               } while(0);
               $1049 = ___cxa_find_matching_catch()|0;
               $1050 = tempRet0;
               __THREW__ = 0;
               invoke_v(66);
               $1051 = __THREW__; __THREW__ = 0;
               $1052 = $1051&1;
               if ($1052) {
                $1178 = ___cxa_find_matching_catch(0|0)|0;
                $1179 = tempRet0;
                ___clang_call_terminate($1178);
                // unreachable;
               } else {
                $$04 = $1049;$$05 = $1050;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($$04|0);
                // unreachable;
               }
              } else {
               $1057 = ($V_23$1|0)==(-1);
               $$V_23$1 = $1057 ? 0 : $V_23$1;
               $1058 = ($V_22$1|0)==(-1);
               $V_22$2 = $1058 ? 0 : $V_22$1;
               $1059 = ($V_21$3|0)==(1);
               if ($1059) {
                $1060 = (0 - ($V_22$2))|0;
                $1061 = (0 - ($$V_23$1))|0;
                $V_22$3 = $1060;$V_23$3 = $1061;
               } else {
                $V_22$3 = $V_22$2;$V_23$3 = $$V_23$1;
               }
               $1062 = $L_652;
               $1063 = $1062;
               HEAP32[$1063>>2] = 0;
               $1064 = (($1062) + 4)|0;
               $1065 = $1064;
               HEAP32[$1065>>2] = 0;
               __THREW__ = 0;
               invoke_viiii(202,($L_652|0),($V_22$3|0),($V_23$3|0),0);
               $1066 = __THREW__; __THREW__ = 0;
               $1067 = $1066&1;
               if (!($1067)) {
                $1068 = $L_652;
                $1069 = $1068;
                $1070 = HEAP32[$1069>>2]|0;
                $1071 = (($1068) + 4)|0;
                $1072 = $1071;
                $1073 = HEAP32[$1072>>2]|0;
                $1074 = $2;
                $1075 = $1074;
                HEAP32[$1075>>2] = $1070;
                $1076 = (($1074) + 4)|0;
                $1077 = $1076;
                HEAP32[$1077>>2] = $1073;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$result+0>>2]|0;HEAP32[$$byval_copy22+4>>2]=HEAP32[$result+4>>2]|0;HEAP32[$$byval_copy22+8>>2]=HEAP32[$result+8>>2]|0;HEAP32[$$byval_copy22+12>>2]=HEAP32[$result+12>>2]|0;
                ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy24+4>>2]=HEAP32[$2+4>>2]|0;
                invoke_viii(667,($dto|0),($$byval_copy22|0),($$byval_copy24|0));
                $1078 = __THREW__; __THREW__ = 0;
                $1079 = $1078&1;
                if (!($1079)) {
                 break;
                }
               }
               $1080 = ___cxa_find_matching_catch(348288|0)|0;
               $1081 = tempRet0;
               $1082 = (_llvm_eh_typeid_for((348288|0))|0);
               $1083 = ($1081|0)==($1082|0);
               if (!($1083)) {
                $$04 = $1080;$$05 = $1081;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($$04|0);
                // unreachable;
               }
               $1084 = (___cxa_begin_catch(($1080|0))|0);
               $1085 = HEAP32[$1084>>2]|0;
               $1086 = HEAP32[$1085>>2]|0;
               __THREW__ = 0;
               $1087 = (invoke_iii(2727,(2149728|0),($1086|0))|0);
               $1088 = __THREW__; __THREW__ = 0;
               $1089 = $1088&1;
               do {
                if (!($1089)) {
                 if ($1087) {
                  __THREW__ = 0;
                  invoke_v(66);
                  $1090 = __THREW__; __THREW__ = 0;
                  $1091 = $1090&1;
                  if ($1091) {
                   label = 14;
                   break L1;
                  } else {
                   break L619;
                  }
                 }
                 $1096 = (___cxa_allocate_exception(4)|0);
                 $1097 = HEAP32[$1084>>2]|0;
                 HEAP32[$1096>>2] = $1097;
                 __THREW__ = 0;
                 invoke_viii(1567,($1096|0),(348288|0),(0|0));
                 $1098 = __THREW__; __THREW__ = 0;
                 $1099 = $1098&1;
                 if ($1099) {
                  break;
                 }
                 // unreachable;
                }
               } while(0);
               $1092 = ___cxa_find_matching_catch()|0;
               $1093 = tempRet0;
               __THREW__ = 0;
               invoke_v(66);
               $1094 = __THREW__; __THREW__ = 0;
               $1095 = $1094&1;
               if ($1095) {
                $1178 = ___cxa_find_matching_catch(0|0)|0;
                $1179 = tempRet0;
                ___clang_call_terminate($1178);
                // unreachable;
               } else {
                $$04 = $1092;$$05 = $1093;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($$04|0);
                // unreachable;
               }
              }
             } while(0);
             $$lobit = $style & 16;
             $1100 = ($$lobit|0)!=(0);
             L665: do {
              if ($1017) {
               $1163 = HEAP8[$V_0>>0]|0;
               $1164 = ($1163<<24>>24)==(0);
               do {
                if ($1164) {
                 $1165 = $style & 64;
                 $1166 = ($1165|0)==(0);
                 if (!($1166)) {
                  break;
                 }
                 $1168 = $style & 32;
                 $1169 = ($1168|0)==(0);
                 if ($1169) {
                  break L665;
                 }
                 $1170 = (($result) + 8|0);
                 HEAP32[$1170>>2] = 2;
                 break L665;
                }
               } while(0);
               $1167 = (($result) + 8|0);
               HEAP32[$1167>>2] = 1;
              } else {
               $1101 = $result;
               $1102 = $1101;
               $1103 = HEAP32[$1102>>2]|0;
               $1104 = (($1101) + 4)|0;
               $1105 = $1104;
               $1106 = HEAP32[$1105>>2]|0;
               __THREW__ = 0;
               $1107 = (invoke_ii(2439,($dto|0))|0);
               $1108 = tempRet0;
               $1109 = __THREW__; __THREW__ = 0;
               $1110 = $1109&1;
               if ($1110) {
                label = 14;
                break L1;
               }
               $1111 = $3;
               $1112 = $1111;
               HEAP32[$1112>>2] = $1103;
               $1113 = (($1111) + 4)|0;
               $1114 = $1113;
               HEAP32[$1114>>2] = $1106;
               $1115 = $4;
               $1116 = $1115;
               HEAP32[$1116>>2] = $1107;
               $1117 = (($1115) + 4)|0;
               $1118 = $1117;
               HEAP32[$1118>>2] = $1108;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy22+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy22+4>>2]=HEAP32[$3+4>>2]|0;
               ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy24+4>>2]=HEAP32[$4+4>>2]|0;
               $1119 = (invoke_iiii(1269,(0|0),($$byval_copy22|0),($$byval_copy24|0))|0);
               $1120 = tempRet0;
               $1121 = __THREW__; __THREW__ = 0;
               $1122 = $1121&1;
               if ($1122) {
                label = 14;
                break L1;
               }
               $1123 = $V_40;
               $1124 = $1123;
               HEAP32[$1124>>2] = $1119;
               $1125 = (($1123) + 4)|0;
               $1126 = $1125;
               HEAP32[$1126>>2] = $1120;
               __THREW__ = 0;
               $1127 = (invoke_ii(2499,($V_40|0))|0);
               $1128 = tempRet0;
               $1129 = __THREW__; __THREW__ = 0;
               $1130 = $1129&1;
               if ($1130) {
                label = 14;
                break L1;
               }
               $1131 = ($1128|0)>(-1);
               $1132 = ($1128|0)==(-1);
               $1133 = ($1127>>>0)>(4294967295);
               $1134 = $1132 & $1133;
               $1135 = $1131 | $1134;
               $1136 = (_i64Add(($1127|0),($1128|0),711573504,201)|0);
               $1137 = tempRet0;
               $1138 = $1135 ? $1127 : $1136;
               $1139 = $1135 ? $1128 : $1137;
               $1140 = $L_669;
               $1141 = $1140;
               HEAP32[$1141>>2] = 0;
               $1142 = (($1140) + 4)|0;
               $1143 = $1142;
               HEAP32[$1143>>2] = 0;
               __THREW__ = 0;
               invoke_viii(703,($L_669|0),($1138|0),($1139|0));
               $1144 = __THREW__; __THREW__ = 0;
               $1145 = $1144&1;
               if ($1145) {
                label = 14;
                break L1;
               }
               $1146 = $L_669;
               $1147 = $1146;
               $1148 = HEAP32[$1147>>2]|0;
               $1149 = (($1146) + 4)|0;
               $1150 = $1149;
               $1151 = HEAP32[$1150>>2]|0;
               $1152 = $5;
               $1153 = $1152;
               HEAP32[$1153>>2] = $1148;
               $1154 = (($1152) + 4)|0;
               $1155 = $1154;
               HEAP32[$1155>>2] = $1151;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy24+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy24+4>>2]=HEAP32[$5+4>>2]|0;
               invoke_viii(662,($result|0),0,($$byval_copy24|0));
               $1156 = __THREW__; __THREW__ = 0;
               $1157 = $1156&1;
               if ($1157) {
                label = 14;
                break L1;
               }
               $1158 = (($result) + 8|0);
               HEAP32[$1158>>2] = 1;
               $1159 = $style & 128;
               $1160 = ($1159|0)==(0);
               if ($1160) {
                break;
               }
               __THREW__ = 0;
               invoke_vii(1933,($L_673|0),($result|0));
               $1161 = __THREW__; __THREW__ = 0;
               $1162 = $1161&1;
               if ($1162) {
                label = 14;
                break L1;
               }
               ;HEAP32[$result+0>>2]=HEAP32[$L_673+0>>2]|0;HEAP32[$result+4>>2]=HEAP32[$L_673+4>>2]|0;HEAP32[$result+8>>2]=HEAP32[$L_673+8>>2]|0;HEAP32[$result+12>>2]=HEAP32[$L_673+12>>2]|0;
              }
             } while(0);
             if ($1100) {
              $G_B413_0$0 = 0;
             } else {
              $$lobit6 = $style & 128;
              $phitmp = ($$lobit6|0)==(0);
              $G_B413_0$0 = $phitmp;
             }
             $1171 = (($result) + 8|0);
             $1172 = HEAP32[$1171>>2]|0;
             $1173 = ($1172|0)==(0);
             if ($1173) {
              $$0 = 1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             if ($1100) {
              __THREW__ = 0;
              invoke_vii(1934,($L_686|0),($result|0));
              $1174 = __THREW__; __THREW__ = 0;
              $1175 = $1174&1;
              if ($1175) {
               label = 14;
               break;
              }
              ;HEAP32[$result+0>>2]=HEAP32[$L_686+0>>2]|0;HEAP32[$result+4>>2]=HEAP32[$L_686+4>>2]|0;HEAP32[$result+8>>2]=HEAP32[$L_686+8>>2]|0;HEAP32[$result+12>>2]=HEAP32[$L_686+12>>2]|0;
              $$0 = 1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             if (!($G_B413_0$0)) {
              $$0 = 1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             __THREW__ = 0;
             invoke_vii(1933,($L_687|0),($result|0));
             $1176 = __THREW__; __THREW__ = 0;
             $1177 = $1176&1;
             if ($1177) {
              label = 14;
              break;
             }
             ;HEAP32[$result+0>>2]=HEAP32[$L_687+0>>2]|0;HEAP32[$result+4>>2]=HEAP32[$L_687+4>>2]|0;HEAP32[$result+8>>2]=HEAP32[$L_687+8>>2]|0;HEAP32[$result+12>>2]=HEAP32[$L_687+12>>2]|0;
             $$0 = 1;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            else if ((label|0) == 541) {
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  $lpad$phi$index = $36;$lpad$phi$index8 = $37;
 }
 $$04 = $lpad$phi$index;$$05 = $lpad$phi$index8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$04|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_DateTime_m_ParseExactP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_String_arrP48mscorlib_System_Globalization_DateTimeFormatInfoiP24mscorlib_System_DateTimebPbbPP25mscorlib_System_Exception($__this,$s,$formats,$dfi,$style,$ret,$exact,$longYear,$setExceptionOnError,$exception) {
 $__this = $__this|0;
 $s = $s|0;
 $formats = $formats|0;
 $dfi = $dfi|0;
 $style = $style|0;
 $ret = $ret|0;
 $exact = $exact|0;
 $longYear = $longYear|0;
 $setExceptionOnError = $setExceptionOnError|0;
 $exception = $exception|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $V_0$0 = 0, $V_1 = 0, $V_2 = 0, $V_4 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $V_1 = sp + 44|0;
 $V_2 = sp + 24|0;
 $V_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587440);
 HEAP8[$V_1>>0] = 0;
 ;HEAP32[$V_2+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_4+0>>2]=HEAP32[2593152+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[2593152+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[2593152+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[2593152+12>>2]|0;HEAP32[$V_4+16>>2]=HEAP32[2593152+16>>2]|0;HEAP32[$V_4+20>>2]=HEAP32[2593152+20>>2]|0;
 __THREW__ = 0;
 invoke_v(871);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   HEAP8[$V_1>>0] = 0;
   $2 = (($formats) + 12|0);
   $3 = (($formats) + 16|0);
   $V_0$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($formats|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     label = 3;
     break;
    }
    $60 = HEAP32[$2>>2]|0;
    $61 = ($V_0$0|0)<($60|0);
    if (!($61)) {
     label = 28;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($formats|0));
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     label = 3;
     break;
    }
    $8 = HEAP32[$2>>2]|0;
    $9 = ($V_0$0>>>0)<($8>>>0);
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_i(132)|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      label = 3;
      break;
     }
    }
    $15 = HEAP32[$formats>>2]|0;
    $16 = (($15) + 92|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = Math_imul($17, $V_0$0)|0;
    $19 = (($3) + ($18)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(0|0);
    if ($21) {
     label = 28;
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 3;
     break;
    }
    $24 = HEAP8[((2191608 + 116|0))>>0]|0;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2191608|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 3;
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     label = 3;
     break;
    }
    $34 = HEAP32[((2191608 + 80|0))>>2]|0;
    $35 = HEAP32[$34>>2]|0;
    __THREW__ = 0;
    $36 = (invoke_iiii(574,(0|0),($20|0),($35|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 3;
     break;
    }
    if ($36) {
     label = 28;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($formats|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 3;
     break;
    }
    $41 = HEAP32[$2>>2]|0;
    $42 = ($V_0$0>>>0)<($41>>>0);
    if (!($42)) {
     __THREW__ = 0;
     $43 = (invoke_i(132)|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 3;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($43|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 3;
      break;
     }
    }
    $48 = HEAP32[$formats>>2]|0;
    $49 = (($48) + 92|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = Math_imul($50, $V_0$0)|0;
    $52 = (($3) + ($51)|0);
    $53 = HEAP32[$52>>2]|0;
    __THREW__ = 0;
    $54 = (invoke_iiiiiiiiiiiii(3,0,($s|0),($53|0),(0|0),($exact|0),($V_2|0),($V_4|0),($dfi|0),($style|0),0,($V_1|0),($longYear|0))|0);
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 3;
     break;
    }
    $57 = (($V_0$0) + 1)|0;
    if ($54) {
     label = 24;
     break;
    } else {
     $V_0$0 = $57;
    }
   }
   if ((label|0) == 3) {
    $4 = ___cxa_find_matching_catch()|0;
    $5 = tempRet0;
    $lpad$phi$index = $4;$lpad$phi$index2 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 24) {
    ;HEAP32[$ret+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$ret+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$ret+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$ret+12>>2]=HEAP32[$V_2+12>>2]|0;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 28) {
    if ($setExceptionOnError) {
     __THREW__ = 0;
     (invoke_ii(2996,(2603176|0))|0);
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     __THREW__ = 0;
     $66 = (invoke_ii(3469,(2603176|0))|0);
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break;
     }
     $69 = HEAP32[3068800>>2]|0;
     __THREW__ = 0;
     invoke_vii(1940,($66|0),($69|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      break;
     }
     HEAP32[$exception>>2] = $66;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     break;
    }
    $74 = HEAP8[((2592096 + 116|0))>>0]|0;
    $75 = ($74<<24>>24)==(0);
    if ($75) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $76 = __THREW__; __THREW__ = 0;
     $77 = $76&1;
     if ($77) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $78 = __THREW__; __THREW__ = 0;
     $79 = $78&1;
     if ($79) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2592096|0));
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    $84 = HEAP32[((2592096 + 80|0))>>2]|0;
    $85 = (($84) + 16|0);
    _memmove(($ret|0),($85|0),16)|0;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 $lpad$phi$index = $6;$lpad$phi$index2 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_DateTime_m__ParseNumberP22mscorlib_System_ObjectP22mscorlib_System_StringiiibbPi($__this,$s,$valuePos,$min_digits,$digits,$leadingzero,$sloppy_parsing,$num_parsed) {
 $__this = $__this|0;
 $s = $s|0;
 $valuePos = $valuePos|0;
 $min_digits = $min_digits|0;
 $digits = $digits|0;
 $leadingzero = $leadingzero|0;
 $sloppy_parsing = $sloppy_parsing|0;
 $num_parsed = $num_parsed|0;
 var $$0 = 0, $$01 = 0, $$leadingzero = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$lcssa = 0, $V_0$06 = 0, $V_1$0 = 0, $V_1$15 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $not$sloppy_parsing = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587056);
 $not$sloppy_parsing = $sloppy_parsing ^ 1;
 $$leadingzero = $not$sloppy_parsing & $leadingzero;
 L1: do {
  if ($$leadingzero) {
   $$01 = $digits;
  } else {
   $0 = (($digits) + ($valuePos))|0;
   $V_1$0 = $valuePos;$V_2$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($s|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    $20 = ($V_1$0|0)<($17|0);
    $21 = ($V_1$0|0)<($0|0);
    $or$cond = $20 & $21;
    if (!($or$cond)) {
     $$01 = $V_2$0;
     break L1;
    }
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    $1 = (invoke_iii(621,($s|0),($V_1$0|0))|0);
    $2 = __THREW__; __THREW__ = 0;
    $3 = $2&1;
    if ($3) {
     break;
    }
    __THREW__ = 0;
    $4 = (invoke_iii(600,(0|0),($1|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    if (!($4)) {
     $$01 = $V_2$0;
     break L1;
    }
    $13 = (($V_2$0) + 1)|0;
    $14 = (($V_1$0) + 1)|0;
    $V_1$0 = $14;$V_2$0 = $13;
   }
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   $lpad$phi$index = $9;$lpad$phi$index3 = $10;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $24 = ($$01|0)<($min_digits|0);
 if ($24) {
  HEAP32[$num_parsed>>2] = -1;
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if (!($26)) {
  __THREW__ = 0;
  $27 = (invoke_ii(1816,($s|0))|0);
  $28 = __THREW__; __THREW__ = 0;
  $29 = $28&1;
  if (!($29)) {
   $30 = (($27) - ($valuePos))|0;
   $31 = ($30|0)<($$01|0);
   if ($31) {
    HEAP32[$num_parsed>>2] = -1;
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $32 = (($$01) + ($valuePos))|0;
   $33 = ($$01|0)>(0);
   L26: do {
    if ($33) {
     $V_0$06 = 0;$V_1$15 = $valuePos;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 6;
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_iii(621,($s|0),($V_1$15|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 6;
       break;
      }
      __THREW__ = 0;
      $37 = (invoke_iii(600,(0|0),($34|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 6;
       break;
      }
      if (!($37)) {
       label = 25;
       break;
      }
      $40 = ($V_0$06*10)|0;
      $41 = $34&65535;
      $42 = (($41) + 208)|0;
      $43 = $42 & 255;
      $44 = (($43) + ($40))|0;
      $45 = (($V_1$15) + 1)|0;
      $46 = ($45|0)<($32|0);
      if ($46) {
       $V_0$06 = $44;$V_1$15 = $45;
      } else {
       $V_0$0$lcssa = $44;
       break L26;
      }
     }
     if ((label|0) == 6) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index3 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 25) {
      HEAP32[$num_parsed>>2] = -1;
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    } else {
     $V_0$0$lcssa = 0;
    }
   } while(0);
   HEAP32[$num_parsed>>2] = $$01;
   $$0 = $V_0$0$lcssa;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_DateTime_m__ParseEnumP22mscorlib_System_ObjectP22mscorlib_System_StringiP26mscorlib_System_String_arrS4_bPi($__this,$s,$sPos,$values,$invValues,$exact,$num_parsed) {
 $__this = $__this|0;
 $s = $s|0;
 $sPos = $sPos|0;
 $values = $values|0;
 $invValues = $invValues|0;
 $exact = $exact|0;
 $num_parsed = $num_parsed|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$06 = 0, $V_0$06$in = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587104);
 __THREW__ = 0;
 invoke_vi(3799,($values|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $2 = (($values) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 L5: do {
  if ($4) {
   $5 = (($values) + 16|0);
   $6 = (($invValues) + 16|0);
   $7 = (($invValues) + 12|0);
   $V_0$06$in = $3;
   L7: while(1) {
    $V_0$06 = (($V_0$06$in) + -1)|0;
    do {
     if ($exact) {
      label = 46;
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($invValues|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       label = 4;
       break L7;
      }
      $14 = HEAP32[$7>>2]|0;
      $15 = ($V_0$06>>>0)<($14>>>0);
      if (!($15)) {
       __THREW__ = 0;
       $16 = (invoke_i(132)|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        label = 4;
        break L7;
       }
       __THREW__ = 0;
       invoke_vi(3302,($16|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        label = 4;
        break L7;
       }
      }
      $21 = HEAP32[$invValues>>2]|0;
      $22 = (($21) + 92|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = Math_imul($23, $V_0$06)|0;
      $25 = (($6) + ($24)|0);
      $26 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       label = 4;
       break L7;
      }
      __THREW__ = 0;
      $29 = (invoke_ii(1816,($26|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break L7;
      }
      __THREW__ = 0;
      invoke_vi(3799,($values|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 4;
       break L7;
      }
      $34 = HEAP32[$2>>2]|0;
      $35 = ($V_0$06>>>0)<($34>>>0);
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_i(132)|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 4;
        break L7;
       }
       __THREW__ = 0;
       invoke_vi(3302,($36|0));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        label = 4;
        break L7;
       }
      }
      $41 = HEAP32[$values>>2]|0;
      $42 = (($41) + 92|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = Math_imul($43, $V_0$06)|0;
      $45 = (($5) + ($44)|0);
      $46 = HEAP32[$45>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($46|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 4;
       break L7;
      }
      __THREW__ = 0;
      $49 = (invoke_ii(1816,($46|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break L7;
      }
      $52 = ($29|0)>($49|0);
      if ($52) {
       __THREW__ = 0;
       invoke_vi(3799,($invValues|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        label = 4;
        break L7;
       }
       $55 = HEAP32[$7>>2]|0;
       $56 = ($V_0$06>>>0)<($55>>>0);
       if (!($56)) {
        __THREW__ = 0;
        $57 = (invoke_i(132)|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break L7;
        }
        __THREW__ = 0;
        invoke_vi(3302,($57|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 4;
         break L7;
        }
       }
       $62 = HEAP32[$invValues>>2]|0;
       $63 = (($62) + 92|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = Math_imul($64, $V_0$06)|0;
       $66 = (($6) + ($65)|0);
       $67 = HEAP32[$66>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($67|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        label = 4;
        break L7;
       }
       __THREW__ = 0;
       $70 = (invoke_ii(1816,($67|0))|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        label = 4;
        break L7;
       }
       $73 = ($70|0)<(1);
       if (!($73)) {
        __THREW__ = 0;
        invoke_vi(3799,($invValues|0));
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 4;
         break L7;
        }
        $76 = HEAP32[$7>>2]|0;
        $77 = ($V_0$06>>>0)<($76>>>0);
        if (!($77)) {
         __THREW__ = 0;
         $78 = (invoke_i(132)|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          label = 4;
          break L7;
         }
         __THREW__ = 0;
         invoke_vi(3302,($78|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          label = 4;
          break L7;
         }
        }
        $83 = HEAP32[$invValues>>2]|0;
        $84 = (($83) + 92|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = Math_imul($85, $V_0$06)|0;
        $87 = (($6) + ($86)|0);
        $88 = HEAP32[$87>>2]|0;
        __THREW__ = 0;
        $89 = (invoke_iiiiiii(91,0,($s|0),($sPos|0),0,($88|0),($num_parsed|0))|0);
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         label = 4;
         break L7;
        }
        if ($89) {
         $$0 = $V_0$06;
         label = 76;
         break L7;
        }
       }
       __THREW__ = 0;
       invoke_vi(3799,($values|0));
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        label = 4;
        break L7;
       }
       $94 = HEAP32[$2>>2]|0;
       $95 = ($V_0$06>>>0)<($94>>>0);
       if (!($95)) {
        __THREW__ = 0;
        $96 = (invoke_i(132)|0);
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if ($98) {
         label = 4;
         break L7;
        }
        __THREW__ = 0;
        invoke_vi(3302,($96|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         label = 4;
         break L7;
        }
       }
       $101 = HEAP32[$values>>2]|0;
       $102 = (($101) + 92|0);
       $103 = HEAP32[$102>>2]|0;
       $104 = Math_imul($103, $V_0$06)|0;
       $105 = (($5) + ($104)|0);
       $106 = HEAP32[$105>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($106|0));
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        label = 4;
        break L7;
       }
       __THREW__ = 0;
       $109 = (invoke_ii(1816,($106|0))|0);
       $110 = __THREW__; __THREW__ = 0;
       $111 = $110&1;
       if ($111) {
        label = 4;
        break L7;
       }
       $112 = ($109|0)<(1);
       if ($112) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($values|0));
       $113 = __THREW__; __THREW__ = 0;
       $114 = $113&1;
       if ($114) {
        label = 4;
        break L7;
       }
       $115 = HEAP32[$2>>2]|0;
       $116 = ($V_0$06>>>0)<($115>>>0);
       if (!($116)) {
        __THREW__ = 0;
        $117 = (invoke_i(132)|0);
        $118 = __THREW__; __THREW__ = 0;
        $119 = $118&1;
        if ($119) {
         label = 4;
         break L7;
        }
        __THREW__ = 0;
        invoke_vi(3302,($117|0));
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if ($121) {
         label = 4;
         break L7;
        }
       }
       $122 = HEAP32[$values>>2]|0;
       $123 = (($122) + 92|0);
       $124 = HEAP32[$123>>2]|0;
       $125 = Math_imul($124, $V_0$06)|0;
       $126 = (($5) + ($125)|0);
       $127 = HEAP32[$126>>2]|0;
       __THREW__ = 0;
       $128 = (invoke_iiiiiii(91,0,($s|0),($sPos|0),0,($127|0),($num_parsed|0))|0);
       $129 = __THREW__; __THREW__ = 0;
       $130 = $129&1;
       if ($130) {
        label = 4;
        break L7;
       }
       if ($128) {
        $$0 = $V_0$06;
        label = 76;
        break L7;
       }
      } else {
       label = 46;
      }
     }
    } while(0);
    if ((label|0) == 46) {
     label = 0;
     __THREW__ = 0;
     invoke_vi(3799,($values|0));
     $131 = __THREW__; __THREW__ = 0;
     $132 = $131&1;
     if ($132) {
      label = 4;
      break;
     }
     $133 = HEAP32[$2>>2]|0;
     $134 = ($V_0$06>>>0)<($133>>>0);
     if (!($134)) {
      __THREW__ = 0;
      $135 = (invoke_i(132)|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($135|0));
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       label = 4;
       break;
      }
     }
     $140 = HEAP32[$values>>2]|0;
     $141 = (($140) + 92|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = Math_imul($142, $V_0$06)|0;
     $144 = (($5) + ($143)|0);
     $145 = HEAP32[$144>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($145|0));
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $148 = (invoke_ii(1816,($145|0))|0);
     $149 = __THREW__; __THREW__ = 0;
     $150 = $149&1;
     if ($150) {
      label = 4;
      break;
     }
     $151 = ($148|0)<(1);
     if (!($151)) {
      __THREW__ = 0;
      invoke_vi(3799,($values|0));
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       label = 4;
       break;
      }
      $154 = HEAP32[$2>>2]|0;
      $155 = ($V_0$06>>>0)<($154>>>0);
      if (!($155)) {
       __THREW__ = 0;
       $156 = (invoke_i(132)|0);
       $157 = __THREW__; __THREW__ = 0;
       $158 = $157&1;
       if ($158) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($156|0));
       $159 = __THREW__; __THREW__ = 0;
       $160 = $159&1;
       if ($160) {
        label = 4;
        break;
       }
      }
      $161 = HEAP32[$values>>2]|0;
      $162 = (($161) + 92|0);
      $163 = HEAP32[$162>>2]|0;
      $164 = Math_imul($163, $V_0$06)|0;
      $165 = (($5) + ($164)|0);
      $166 = HEAP32[$165>>2]|0;
      __THREW__ = 0;
      $167 = (invoke_iiiiiii(91,0,($s|0),($sPos|0),0,($166|0),($num_parsed|0))|0);
      $168 = __THREW__; __THREW__ = 0;
      $169 = $168&1;
      if ($169) {
       label = 4;
       break;
      }
      if ($167) {
       $$0 = $V_0$06;
       label = 76;
       break;
      }
     }
     if (!($exact)) {
      __THREW__ = 0;
      invoke_vi(3799,($invValues|0));
      $170 = __THREW__; __THREW__ = 0;
      $171 = $170&1;
      if ($171) {
       label = 4;
       break;
      }
      $172 = HEAP32[$7>>2]|0;
      $173 = ($V_0$06>>>0)<($172>>>0);
      if (!($173)) {
       __THREW__ = 0;
       $174 = (invoke_i(132)|0);
       $175 = __THREW__; __THREW__ = 0;
       $176 = $175&1;
       if ($176) {
        label = 4;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($174|0));
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        label = 4;
        break;
       }
      }
      $179 = HEAP32[$invValues>>2]|0;
      $180 = (($179) + 92|0);
      $181 = HEAP32[$180>>2]|0;
      $182 = Math_imul($181, $V_0$06)|0;
      $183 = (($6) + ($182)|0);
      $184 = HEAP32[$183>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($184|0));
      $185 = __THREW__; __THREW__ = 0;
      $186 = $185&1;
      if ($186) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $187 = (invoke_ii(1816,($184|0))|0);
      $188 = __THREW__; __THREW__ = 0;
      $189 = $188&1;
      if ($189) {
       label = 4;
       break;
      }
      $190 = ($187|0)<(1);
      if (!($190)) {
       __THREW__ = 0;
       invoke_vi(3799,($invValues|0));
       $191 = __THREW__; __THREW__ = 0;
       $192 = $191&1;
       if ($192) {
        label = 4;
        break;
       }
       $193 = HEAP32[$7>>2]|0;
       $194 = ($V_0$06>>>0)<($193>>>0);
       if (!($194)) {
        __THREW__ = 0;
        $195 = (invoke_i(132)|0);
        $196 = __THREW__; __THREW__ = 0;
        $197 = $196&1;
        if ($197) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($195|0));
        $198 = __THREW__; __THREW__ = 0;
        $199 = $198&1;
        if ($199) {
         label = 4;
         break;
        }
       }
       $200 = HEAP32[$invValues>>2]|0;
       $201 = (($200) + 92|0);
       $202 = HEAP32[$201>>2]|0;
       $203 = Math_imul($202, $V_0$06)|0;
       $204 = (($6) + ($203)|0);
       $205 = HEAP32[$204>>2]|0;
       __THREW__ = 0;
       $206 = (invoke_iiiiiii(91,0,($s|0),($sPos|0),0,($205|0),($num_parsed|0))|0);
       $207 = __THREW__; __THREW__ = 0;
       $208 = $207&1;
       if ($208) {
        label = 4;
        break;
       }
       if ($206) {
        $$0 = $V_0$06;
        label = 76;
        break;
       }
      }
     }
    }
    $209 = ($V_0$06|0)>(0);
    if ($209) {
     $V_0$06$in = $V_0$06;
    } else {
     break L5;
    }
   }
   if ((label|0) == 4) {
    $8 = ___cxa_find_matching_catch()|0;
    $9 = tempRet0;
    $lpad$phi$index = $8;$lpad$phi$index2 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 76) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP32[$num_parsed>>2] = -1;
 $$0 = -1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z39mscorlib_System_DateTime_m__ParseStringP22mscorlib_System_ObjectP22mscorlib_System_StringiiS2_Pi($__this,$s,$sPos,$maxlength,$value,$num_parsed) {
 $__this = $__this|0;
 $s = $s|0;
 $sPos = $sPos|0;
 $maxlength = $maxlength|0;
 $value = $value|0;
 $num_parsed = $num_parsed|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587152);
 $0 = ($maxlength|0)>(0);
 if ($0) {
  $$01 = $maxlength;
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($value|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1816,($value|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $$01 = $3;
    label = 4;
   }
  }
 }
 do {
  if ((label|0) == 4) {
   $6 = (($$01) + ($sPos))|0;
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(1816,($s|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = ($6|0)>($9|0);
     if (!($12)) {
      __THREW__ = 0;
      $15 = (invoke_ii(1982,(0|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      $18 = (invoke_iiiiiiiii(9,(0|0),($s|0),($sPos|0),($value|0),0,($$01|0),1,($15|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = ($18|0)==(0);
      if ($21) {
       $$0 = 1;$storemerge = $$01;
       HEAP32[$num_parsed>>2] = $storemerge;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     $$0 = 0;$storemerge = -1;
     HEAP32[$num_parsed>>2] = $storemerge;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_DateTime_m__ParseAmPmP22mscorlib_System_ObjectP22mscorlib_System_StringiiP48mscorlib_System_Globalization_DateTimeFormatInfobPiS5_($__this,$s,$valuePos,$num,$dfi,$exact,$num_parsed,$ampm) {
 $__this = $__this|0;
 $s = $s|0;
 $valuePos = $valuePos|0;
 $num = $num|0;
 $dfi = $dfi|0;
 $exact = $exact|0;
 $num_parsed = $num_parsed|0;
 $ampm = $ampm|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587200);
 HEAP32[$num_parsed>>2] = -1;
 $0 = HEAP32[$ampm>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $2 = (invoke_iiii(1157,0,($s|0),($valuePos|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L4: do {
  if (!($4)) {
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($dfi|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(1997,($dfi|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP8[((2191608 + 116|0))>>0]|0;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2191608|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = HEAP32[((2191608 + 80|0))>>2]|0;
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(575,(0|0),($9|0),($25|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    if ($26) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    if ($exact) {
     HEAP32[$ampm>>2] = 0;
    }
    HEAP32[$num_parsed>>2] = 0;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $29 = (invoke_ii(2009,(0|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    if ($exact) {
     label = 24;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($29|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     __THREW__ = 0;
     $34 = (invoke_ii(1998,($29|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     __THREW__ = 0;
     $37 = (invoke_iiiiiii(91,0,($s|0),($valuePos|0),($num|0),($34|0),($num_parsed|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     if (!($37)) {
      label = 24;
     }
    }
    do {
     if ((label|0) == 24) {
      __THREW__ = 0;
      invoke_vi(3799,($dfi|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break L4;
      }
      __THREW__ = 0;
      $42 = (invoke_ii(1998,($dfi|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break L4;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break L4;
      }
      $47 = HEAP8[((2191608 + 116|0))>>0]|0;
      $48 = ($47<<24>>24)==(0);
      if ($48) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break L4;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break L4;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2191608|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break L4;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break L4;
      }
      $57 = HEAP32[((2191608 + 80|0))>>2]|0;
      $58 = HEAP32[$57>>2]|0;
      __THREW__ = 0;
      $59 = (invoke_iiii(575,(0|0),($42|0),($58|0))|0);
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break L4;
      }
      if ($59) {
       __THREW__ = 0;
       invoke_vi(3799,($dfi|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        break L4;
       }
       __THREW__ = 0;
       $64 = (invoke_ii(1998,($dfi|0))|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        break L4;
       }
       __THREW__ = 0;
       $67 = (invoke_iiiiiii(91,0,($s|0),($valuePos|0),($num|0),($64|0),($num_parsed|0))|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break L4;
       }
       if ($67) {
        break;
       }
      }
      if ($exact) {
       label = 44;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($29|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break L4;
       }
       __THREW__ = 0;
       $72 = (invoke_ii(1997,($29|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break L4;
       }
       __THREW__ = 0;
       $75 = (invoke_iiiiiii(91,0,($s|0),($valuePos|0),($num|0),($72|0),($num_parsed|0))|0);
       $76 = __THREW__; __THREW__ = 0;
       $77 = $76&1;
       if ($77) {
        break L4;
       }
       if (!($75)) {
        label = 44;
       }
      }
      if ((label|0) == 44) {
       __THREW__ = 0;
       invoke_vi(3799,($dfi|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break L4;
       }
       __THREW__ = 0;
       $80 = (invoke_ii(1997,($dfi|0))|0);
       $81 = __THREW__; __THREW__ = 0;
       $82 = $81&1;
       if ($82) {
        break L4;
       }
       __THREW__ = 0;
       $83 = (invoke_iiiiiii(91,0,($s|0),($valuePos|0),($num|0),($80|0),($num_parsed|0))|0);
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break L4;
       }
       if (!($83)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      if (!($exact)) {
       $86 = HEAP32[$num_parsed>>2]|0;
       $87 = ($86|0)==(0);
       if ($87) {
        $$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
      HEAP32[$ampm>>2] = 0;
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    } while(0);
    HEAP32[$ampm>>2] = 1;
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_DateTime_m_IsLetterP22mscorlib_System_ObjectP22mscorlib_System_Stringi($__this,$s,$pos) {
 $__this = $__this|0;
 $s = $s|0;
 $pos = $pos|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587344);
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($s|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($pos|0);
   if (!($5)) {
    $G_B3_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B3_0$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(621,($s|0),($pos|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_iii(601,(0|0),($10|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $G_B3_0$0 = $13;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B3_0$0|0);
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_DateTime_m__ParseTimeSeparatorP22mscorlib_System_ObjectP22mscorlib_System_StringiP48mscorlib_System_Globalization_DateTimeFormatInfobPi($__this,$s,$sPos,$dfi,$exact,$num_parsed) {
 $__this = $__this|0;
 $s = $s|0;
 $sPos = $sPos|0;
 $dfi = $dfi|0;
 $exact = $exact|0;
 $num_parsed = $num_parsed|0;
 var $$mux = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B6_0$0 = 0;
 var $_stackTraceSentry = 0, $brmerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587248);
 __THREW__ = 0;
 invoke_v(872);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($dfi|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2000,($dfi|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iiiiiii(91,0,($s|0),($sPos|0),0,($4|0),($num_parsed|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $brmerge = $7 | $exact;
     $$mux = $7&1;
     if ($brmerge) {
      $G_B6_0$0 = $$mux;
      $17 = ($G_B6_0$0|0)!=(0);
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($17|0);
     }
     $12 = HEAP32[3068760>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iiiiiii(91,0,($s|0),($sPos|0),0,($12|0),($num_parsed|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = $13&1;
      $G_B6_0$0 = $16;
      $17 = ($G_B6_0$0|0)!=(0);
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($17|0);
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_DateTime_m__ParseDateSeparatorP22mscorlib_System_ObjectP22mscorlib_System_StringiP48mscorlib_System_Globalization_DateTimeFormatInfobPi($__this,$s,$sPos,$dfi,$exact,$num_parsed) {
 $__this = $__this|0;
 $s = $s|0;
 $sPos = $sPos|0;
 $dfi = $dfi|0;
 $exact = $exact|0;
 $num_parsed = $num_parsed|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587296);
 HEAP32[$num_parsed>>2] = -1;
 if ($exact) {
  __THREW__ = 0;
  invoke_vi(3799,($s|0));
  $0 = __THREW__; __THREW__ = 0;
  $1 = $0&1;
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(621,($s|0),($sPos|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2<<16>>16)==(47);
    if ($5) {
     label = 6;
    } else {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } else {
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  $8 = (invoke_iiiiiii(92,0,($s|0),($sPos|0),($dfi|0),($exact|0),($num_parsed|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   if ($8) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($s|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    $13 = (invoke_iii(621,($s|0),($sPos|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_iii(600,(0|0),($13|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      if ($16) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_iii(621,($s|0),($sPos|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        $24 = (invoke_iii(601,(0|0),($21|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         if ($24) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         HEAP32[$num_parsed>>2] = 1;
         $$0 = 1;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z209mscorlib_System_DateTimeUtils_m_GetStandardPattern_mscorlib_System_String_mscorlib_System_Char_mscorlib_System_Globalization_DateTimeFormatInfo_mscorlib_System_BooleanU0026_ref_mscorlib_System_BooleanU0026_refP22mscorlib_System_ObjecttP48mscorlib_System_Globalization_DateTimeFormatInfoPbS3_($__this,$format,$dfi,$useutc,$use_invariant) {
 $__this = $__this|0;
 $format = $format|0;
 $dfi = $dfi|0;
 $useutc = $useutc|0;
 $use_invariant = $use_invariant|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2594376);
 __THREW__ = 0;
 $0 = (invoke_iiiiiii(94,0,($format|0),($dfi|0),($useutc|0),($use_invariant|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z114mscorlib_System_DateTime_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587968);
 $2 = $d1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $d2;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = $4;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $7;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $10;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $13;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $22 = (invoke_iiii(1266,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($22|0);
 }
 return 0|0;
}
function __Z84mscorlib_System_DateTimeOffset_m__ctor_mscorlib_System_Void_mscorlib_System_DateTimeP30mscorlib_System_DateTimeOffset24mscorlib_System_DateTime($__this,$dateTime) {
 $__this = $__this|0;
 $dateTime = $dateTime|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $L_5 = 0, $L_8 = 0, $L_8$byval_copy = 0, $_stackTraceSentry = 0, $tmpcast25$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmpcast25$byval_copy = sp + 64|0;
 $L_8$byval_copy = sp;
 $0 = sp + 16|0;
 $_stackTraceSentry = sp + 80|0;
 $L_5 = sp + 48|0;
 $L_8 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2592704);
 __THREW__ = 0;
 invoke_v(873);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   ;HEAP32[$__this+0>>2]=HEAP32[$dateTime+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$dateTime+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$dateTime+8>>2]|0;HEAP32[$__this+12>>2]=HEAP32[$dateTime+12>>2]|0;
   __THREW__ = 0;
   $3 = (invoke_ii(2434,($dateTime|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(1);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     $11 = HEAP8[((2652728 + 116|0))>>0]|0;
     $12 = ($11<<24>>24)==(0);
     if ($12) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2652728|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     $21 = HEAP32[((2652728 + 80|0))>>2]|0;
     $22 = (($21) + 16|0);
     $23 = $22;
     $24 = $23;
     $25 = HEAP32[$24>>2]|0;
     $26 = (($23) + 4)|0;
     $27 = $26;
     $28 = HEAP32[$27>>2]|0;
     $29 = (($__this) + 16|0);
     $30 = $29;
     $31 = $30;
     HEAP32[$31>>2] = $25;
     $32 = (($30) + 4)|0;
     $33 = $32;
     HEAP32[$33>>2] = $28;
    } else {
     __THREW__ = 0;
     $34 = (invoke_ii(2504,(0|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($34|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     }
     ;HEAP32[$0+0>>2]=HEAP32[$dateTime+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$dateTime+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$dateTime+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$dateTime+12>>2]|0;
     __THREW__ = 0;
     invoke_viii(2112,($L_8$byval_copy|0),(2653200|0),($34|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
     $41 = (($L_8$byval_copy) + 4|0);
     $42 = HEAP32[$41>>2]|0;
     $43 = (($42) + 4|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = HEAP32[$L_8$byval_copy>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$tmpcast25$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast25$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast25$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast25$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
     $46 = (invoke_iii($44|0,($45|0),($tmpcast25$byval_copy|0))|0);
     $47 = tempRet0;
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     $50 = (($__this) + 16|0);
     $51 = $50;
     $52 = $51;
     HEAP32[$52>>2] = $46;
     $53 = (($51) + 4)|0;
     $54 = $53;
     HEAP32[$54>>2] = $47;
    }
    __THREW__ = 0;
    invoke_vii(1937,($L_5|0),($__this|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if (!($56)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2592096|0))|0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if (!($58)) {
      $59 = HEAP8[((2592096 + 116|0))>>0]|0;
      $60 = ($59<<24>>24)==(0);
      if ($60) {
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $63 = __THREW__; __THREW__ = 0;
       $64 = $63&1;
       if ($64) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2592096|0));
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592096|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if (!($68)) {
       $69 = HEAP32[((2592096 + 80|0))>>2]|0;
       $70 = (($69) + 16|0);
       __THREW__ = 0;
       ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_5+12>>2]|0;
       ;HEAP32[$tmpcast25$byval_copy+0>>2]=HEAP32[$70+0>>2]|0;HEAP32[$tmpcast25$byval_copy+4>>2]=HEAP32[$70+4>>2]|0;HEAP32[$tmpcast25$byval_copy+8>>2]=HEAP32[$70+8>>2]|0;HEAP32[$tmpcast25$byval_copy+12>>2]=HEAP32[$70+12>>2]|0;
       $71 = (invoke_iiii(1166,0,($L_8$byval_copy|0),($tmpcast25$byval_copy|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if (!($73)) {
        if (!($71)) {
         __THREW__ = 0;
         invoke_vii(1937,($L_8|0),($__this|0));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          break;
         }
         $78 = HEAP8[((2592096 + 116|0))>>0]|0;
         $79 = ($78<<24>>24)==(0);
         if ($79) {
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          if ($81) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if ($83) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2592096|0));
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if ($85) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         }
         $88 = HEAP32[((2592096 + 80|0))>>2]|0;
         __THREW__ = 0;
         ;HEAP32[$L_8$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_8$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_8$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_8$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
         ;HEAP32[$tmpcast25$byval_copy+0>>2]=HEAP32[$88+0>>2]|0;HEAP32[$tmpcast25$byval_copy+4>>2]=HEAP32[$88+4>>2]|0;HEAP32[$tmpcast25$byval_copy+8>>2]=HEAP32[$88+8>>2]|0;HEAP32[$tmpcast25$byval_copy+12>>2]=HEAP32[$88+12>>2]|0;
         $89 = (invoke_iiii(1163,0,($L_8$byval_copy|0),($tmpcast25$byval_copy|0))|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break;
         }
         if (!($89)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if (!($93)) {
         __THREW__ = 0;
         $94 = (invoke_ii(3469,(2561352|0))|0);
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if (!($96)) {
          $97 = HEAP32[3069072>>2]|0;
          __THREW__ = 0;
          invoke_vii(1926,($94|0),($97|0));
          $98 = __THREW__; __THREW__ = 0;
          $99 = $98&1;
          if (!($99)) {
           __THREW__ = 0;
           invoke_vi(3838,($94|0));
           $100 = __THREW__; __THREW__ = 0;
           $101 = $100&1;
           if (!($101)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z109mscorlib_System_DateTimeOffset_m__ctor_mscorlib_System_Void_mscorlib_System_DateTime_mscorlib_System_TimeSpanP30mscorlib_System_DateTimeOffset24mscorlib_System_DateTime24mscorlib_System_TimeSpan($__this,$dateTime,$offset) {
 $__this = $__this|0;
 $dateTime = $dateTime|0;
 $offset = $offset|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_19 = 0, $L_24 = 0, $L_27 = 0, $L_30 = 0;
 var $L_30$byval_copy = 0, $_stackTraceSentry = 0, $tmpcast39$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $tmpcast39$byval_copy = sp + 144|0;
 $L_30$byval_copy = sp + 128|0;
 $0 = sp + 112|0;
 $_stackTraceSentry = sp + 160|0;
 $1 = sp + 104|0;
 $2 = sp + 96|0;
 $3 = sp + 88|0;
 $4 = sp + 80|0;
 $L_19 = sp + 72|0;
 $5 = sp + 48|0;
 $6 = sp + 40|0;
 $L_24 = sp + 32|0;
 $7 = sp + 24|0;
 $8 = sp + 16|0;
 $L_27 = sp;
 $L_30 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2592752);
 __THREW__ = 0;
 invoke_v(874);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 L1: do {
  if (!($10)) {
   __THREW__ = 0;
   $11 = (invoke_ii(2434,($dateTime|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = ($11|0)==(1);
    if ($14) {
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     $19 = HEAP8[((2652728 + 116|0))>>0]|0;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2652728|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     $29 = HEAP32[((2652728 + 80|0))>>2]|0;
     $30 = (($29) + 16|0);
     $31 = $30;
     $32 = $31;
     $33 = HEAP32[$32>>2]|0;
     $34 = (($31) + 4)|0;
     $35 = $34;
     $36 = HEAP32[$35>>2]|0;
     $37 = $offset;
     $38 = $37;
     $39 = HEAP32[$38>>2]|0;
     $40 = (($37) + 4)|0;
     $41 = $40;
     $42 = HEAP32[$41>>2]|0;
     $43 = $1;
     $44 = $43;
     HEAP32[$44>>2] = $39;
     $45 = (($43) + 4)|0;
     $46 = $45;
     HEAP32[$46>>2] = $42;
     $47 = $2;
     $48 = $47;
     HEAP32[$48>>2] = $33;
     $49 = (($47) + 4)|0;
     $50 = $49;
     HEAP32[$50>>2] = $36;
     __THREW__ = 0;
     ;HEAP32[$L_30$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$L_30$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
     ;HEAP32[$tmpcast39$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast39$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
     $51 = (invoke_iiii(1266,(0|0),($L_30$byval_copy|0),($tmpcast39$byval_copy|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     if ($51) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      __THREW__ = 0;
      $56 = (invoke_ii(3469,(2560072|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = HEAP32[3069304>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($56|0),($59|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if ($61) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3838,($56|0));
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
      // unreachable;
     }
    }
    __THREW__ = 0;
    $64 = (invoke_ii(2434,($dateTime|0))|0);
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if (!($66)) {
     $67 = ($64|0)==(2);
     if ($67) {
      __THREW__ = 0;
      $68 = (invoke_ii(2504,(0|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($68|0));
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       break;
      }
      ;HEAP32[$0+0>>2]=HEAP32[$dateTime+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$dateTime+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$dateTime+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$dateTime+12>>2]|0;
      __THREW__ = 0;
      invoke_viii(2112,($L_30$byval_copy|0),(2653200|0),($68|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       break;
      }
      $75 = (($L_30$byval_copy) + 4|0);
      $76 = HEAP32[$75>>2]|0;
      $77 = (($76) + 4|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = HEAP32[$L_30$byval_copy>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$tmpcast39$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast39$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast39$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast39$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
      $80 = (invoke_iii($78|0,($79|0),($tmpcast39$byval_copy|0))|0);
      $81 = tempRet0;
      $82 = __THREW__; __THREW__ = 0;
      $83 = $82&1;
      if ($83) {
       break;
      }
      $84 = $offset;
      $85 = $84;
      $86 = HEAP32[$85>>2]|0;
      $87 = (($84) + 4)|0;
      $88 = $87;
      $89 = HEAP32[$88>>2]|0;
      $90 = $3;
      $91 = $90;
      HEAP32[$91>>2] = $86;
      $92 = (($90) + 4)|0;
      $93 = $92;
      HEAP32[$93>>2] = $89;
      $94 = $4;
      $95 = $94;
      HEAP32[$95>>2] = $80;
      $96 = (($94) + 4)|0;
      $97 = $96;
      HEAP32[$97>>2] = $81;
      __THREW__ = 0;
      ;HEAP32[$L_30$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$L_30$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
      ;HEAP32[$tmpcast39$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast39$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
      $98 = (invoke_iiii(1266,(0|0),($L_30$byval_copy|0),($tmpcast39$byval_copy|0))|0);
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       break;
      }
      if ($98) {
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $101 = __THREW__; __THREW__ = 0;
       $102 = $101&1;
       if ($102) {
        break;
       }
       __THREW__ = 0;
       $103 = (invoke_ii(3469,(2560072|0))|0);
       $104 = __THREW__; __THREW__ = 0;
       $105 = $104&1;
       if ($105) {
        break;
       }
       $106 = HEAP32[3069312>>2]|0;
       __THREW__ = 0;
       invoke_vii(1924,($103|0),($106|0));
       $107 = __THREW__; __THREW__ = 0;
       $108 = $107&1;
       if ($108) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($103|0));
       $109 = __THREW__; __THREW__ = 0;
       $110 = $109&1;
       if ($110) {
        break;
       }
       // unreachable;
      }
     }
     __THREW__ = 0;
     $111 = (invoke_ii(2499,($offset|0))|0);
     $112 = tempRet0;
     $113 = __THREW__; __THREW__ = 0;
     $114 = $113&1;
     if (!($114)) {
      $115 = (___remdi3(($111|0),($112|0),600000000,0)|0);
      $116 = tempRet0;
      $117 = ($115|0)==(0);
      $118 = ($116|0)==(0);
      $119 = $117 & $118;
      if (!($119)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $120 = __THREW__; __THREW__ = 0;
       $121 = $120&1;
       if ($121) {
        break;
       }
       __THREW__ = 0;
       $122 = (invoke_ii(3469,(2560072|0))|0);
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        break;
       }
       $125 = HEAP32[3069320>>2]|0;
       __THREW__ = 0;
       invoke_vii(1924,($122|0),($125|0));
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if ($127) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($122|0));
       $128 = __THREW__; __THREW__ = 0;
       $129 = $128&1;
       if ($129) {
        break;
       }
       // unreachable;
      }
      $130 = $L_19;
      $131 = $130;
      HEAP32[$131>>2] = 0;
      $132 = (($130) + 4)|0;
      $133 = $132;
      HEAP32[$133>>2] = 0;
      __THREW__ = 0;
      invoke_viiii(202,($L_19|0),-14,0,0);
      $134 = __THREW__; __THREW__ = 0;
      $135 = $134&1;
      if (!($135)) {
       $136 = $offset;
       $137 = $136;
       $138 = HEAP32[$137>>2]|0;
       $139 = (($136) + 4)|0;
       $140 = $139;
       $141 = HEAP32[$140>>2]|0;
       $142 = $5;
       $143 = $142;
       HEAP32[$143>>2] = $138;
       $144 = (($142) + 4)|0;
       $145 = $144;
       HEAP32[$145>>2] = $141;
       $146 = $L_19;
       $147 = $146;
       $148 = HEAP32[$147>>2]|0;
       $149 = (($146) + 4)|0;
       $150 = $149;
       $151 = HEAP32[$150>>2]|0;
       $152 = $6;
       $153 = $152;
       HEAP32[$153>>2] = $148;
       $154 = (($152) + 4)|0;
       $155 = $154;
       HEAP32[$155>>2] = $151;
       __THREW__ = 0;
       ;HEAP32[$L_30$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$L_30$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
       ;HEAP32[$tmpcast39$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast39$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
       $156 = (invoke_iiii(1267,(0|0),($L_30$byval_copy|0),($tmpcast39$byval_copy|0))|0);
       $157 = __THREW__; __THREW__ = 0;
       $158 = $157&1;
       if (!($158)) {
        if (!($156)) {
         $159 = $L_24;
         $160 = $159;
         HEAP32[$160>>2] = 0;
         $161 = (($159) + 4)|0;
         $162 = $161;
         HEAP32[$162>>2] = 0;
         __THREW__ = 0;
         invoke_viiii(202,($L_24|0),14,0,0);
         $163 = __THREW__; __THREW__ = 0;
         $164 = $163&1;
         if ($164) {
          break;
         }
         $165 = $offset;
         $166 = $165;
         $167 = HEAP32[$166>>2]|0;
         $168 = (($165) + 4)|0;
         $169 = $168;
         $170 = HEAP32[$169>>2]|0;
         $171 = $7;
         $172 = $171;
         HEAP32[$172>>2] = $167;
         $173 = (($171) + 4)|0;
         $174 = $173;
         HEAP32[$174>>2] = $170;
         $175 = $L_24;
         $176 = $175;
         $177 = HEAP32[$176>>2]|0;
         $178 = (($175) + 4)|0;
         $179 = $178;
         $180 = HEAP32[$179>>2]|0;
         $181 = $8;
         $182 = $181;
         HEAP32[$182>>2] = $177;
         $183 = (($181) + 4)|0;
         $184 = $183;
         HEAP32[$184>>2] = $180;
         __THREW__ = 0;
         ;HEAP32[$L_30$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$L_30$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
         ;HEAP32[$tmpcast39$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast39$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
         $185 = (invoke_iiii(1264,(0|0),($L_30$byval_copy|0),($tmpcast39$byval_copy|0))|0);
         $186 = __THREW__; __THREW__ = 0;
         $187 = $186&1;
         if ($187) {
          break;
         }
         if (!($185)) {
          ;HEAP32[$__this+0>>2]=HEAP32[$dateTime+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$dateTime+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$dateTime+8>>2]|0;HEAP32[$__this+12>>2]=HEAP32[$dateTime+12>>2]|0;
          $198 = $offset;
          $199 = $198;
          $200 = HEAP32[$199>>2]|0;
          $201 = (($198) + 4)|0;
          $202 = $201;
          $203 = HEAP32[$202>>2]|0;
          $204 = (($__this) + 16|0);
          $205 = $204;
          $206 = $205;
          HEAP32[$206>>2] = $200;
          $207 = (($205) + 4)|0;
          $208 = $207;
          HEAP32[$208>>2] = $203;
          __THREW__ = 0;
          invoke_vii(1937,($L_27|0),($__this|0));
          $209 = __THREW__; __THREW__ = 0;
          $210 = $209&1;
          if ($210) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $211 = __THREW__; __THREW__ = 0;
          $212 = $211&1;
          if ($212) {
           break;
          }
          $213 = HEAP8[((2592096 + 116|0))>>0]|0;
          $214 = ($213<<24>>24)==(0);
          if ($214) {
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $215 = __THREW__; __THREW__ = 0;
           $216 = $215&1;
           if ($216) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2592096|0))|0);
           $217 = __THREW__; __THREW__ = 0;
           $218 = $217&1;
           if ($218) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3839,(2592096|0));
           $219 = __THREW__; __THREW__ = 0;
           $220 = $219&1;
           if ($220) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $221 = __THREW__; __THREW__ = 0;
          $222 = $221&1;
          if ($222) {
           break;
          }
          $223 = HEAP32[((2592096 + 80|0))>>2]|0;
          $224 = (($223) + 16|0);
          __THREW__ = 0;
          ;HEAP32[$L_30$byval_copy+0>>2]=HEAP32[$L_27+0>>2]|0;HEAP32[$L_30$byval_copy+4>>2]=HEAP32[$L_27+4>>2]|0;HEAP32[$L_30$byval_copy+8>>2]=HEAP32[$L_27+8>>2]|0;HEAP32[$L_30$byval_copy+12>>2]=HEAP32[$L_27+12>>2]|0;
          ;HEAP32[$tmpcast39$byval_copy+0>>2]=HEAP32[$224+0>>2]|0;HEAP32[$tmpcast39$byval_copy+4>>2]=HEAP32[$224+4>>2]|0;HEAP32[$tmpcast39$byval_copy+8>>2]=HEAP32[$224+8>>2]|0;HEAP32[$tmpcast39$byval_copy+12>>2]=HEAP32[$224+12>>2]|0;
          $225 = (invoke_iiii(1166,0,($L_30$byval_copy|0),($tmpcast39$byval_copy|0))|0);
          $226 = __THREW__; __THREW__ = 0;
          $227 = $226&1;
          if ($227) {
           break;
          }
          do {
           if (!($225)) {
            __THREW__ = 0;
            invoke_vii(1937,($L_30|0),($__this|0));
            $228 = __THREW__; __THREW__ = 0;
            $229 = $228&1;
            if ($229) {
             break L1;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $230 = __THREW__; __THREW__ = 0;
            $231 = $230&1;
            if ($231) {
             break L1;
            }
            $232 = HEAP8[((2592096 + 116|0))>>0]|0;
            $233 = ($232<<24>>24)==(0);
            if ($233) {
             __THREW__ = 0;
             (invoke_ii(2996,(2592096|0))|0);
             $234 = __THREW__; __THREW__ = 0;
             $235 = $234&1;
             if ($235) {
              break L1;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2592096|0))|0);
             $236 = __THREW__; __THREW__ = 0;
             $237 = $236&1;
             if ($237) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3839,(2592096|0));
             $238 = __THREW__; __THREW__ = 0;
             $239 = $238&1;
             if ($239) {
              break L1;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2592096|0))|0);
            $240 = __THREW__; __THREW__ = 0;
            $241 = $240&1;
            if ($241) {
             break L1;
            }
            $242 = HEAP32[((2592096 + 80|0))>>2]|0;
            __THREW__ = 0;
            ;HEAP32[$L_30$byval_copy+0>>2]=HEAP32[$L_30+0>>2]|0;HEAP32[$L_30$byval_copy+4>>2]=HEAP32[$L_30+4>>2]|0;HEAP32[$L_30$byval_copy+8>>2]=HEAP32[$L_30+8>>2]|0;HEAP32[$L_30$byval_copy+12>>2]=HEAP32[$L_30+12>>2]|0;
            ;HEAP32[$tmpcast39$byval_copy+0>>2]=HEAP32[$242+0>>2]|0;HEAP32[$tmpcast39$byval_copy+4>>2]=HEAP32[$242+4>>2]|0;HEAP32[$tmpcast39$byval_copy+8>>2]=HEAP32[$242+8>>2]|0;HEAP32[$tmpcast39$byval_copy+12>>2]=HEAP32[$242+12>>2]|0;
            $243 = (invoke_iiii(1163,0,($L_30$byval_copy|0),($tmpcast39$byval_copy|0))|0);
            $244 = __THREW__; __THREW__ = 0;
            $245 = $244&1;
            if ($245) {
             break L1;
            }
            if ($243) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          } while(0);
          __THREW__ = 0;
          (invoke_ii(2996,(2561352|0))|0);
          $246 = __THREW__; __THREW__ = 0;
          $247 = $246&1;
          if ($247) {
           break;
          }
          __THREW__ = 0;
          $248 = (invoke_ii(3469,(2561352|0))|0);
          $249 = __THREW__; __THREW__ = 0;
          $250 = $249&1;
          if ($250) {
           break;
          }
          $251 = HEAP32[3069336>>2]|0;
          __THREW__ = 0;
          invoke_vii(1926,($248|0),($251|0));
          $252 = __THREW__; __THREW__ = 0;
          $253 = $252&1;
          if ($253) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3838,($248|0));
          $254 = __THREW__; __THREW__ = 0;
          $255 = $254&1;
          if ($255) {
           break;
          }
          // unreachable;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2561352|0))|0);
        $188 = __THREW__; __THREW__ = 0;
        $189 = $188&1;
        if (!($189)) {
         __THREW__ = 0;
         $190 = (invoke_ii(3469,(2561352|0))|0);
         $191 = __THREW__; __THREW__ = 0;
         $192 = $191&1;
         if (!($192)) {
          $193 = HEAP32[3069328>>2]|0;
          __THREW__ = 0;
          invoke_vii(1926,($190|0),($193|0));
          $194 = __THREW__; __THREW__ = 0;
          $195 = $194&1;
          if (!($195)) {
           __THREW__ = 0;
           invoke_vi(3838,($190|0));
           $196 = __THREW__; __THREW__ = 0;
           $197 = $196&1;
           if (!($197)) {
            // unreachable;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z43mscorlib_System_DateTimeOffset_m_get_OffsetP30mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2593368);
 $0 = (($__this) + 16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $6;
 STACKTOP = sp;return ($3|0);
}
function __Z38mscorlib_System_DateTime_m_ToLocalTimeP24mscorlib_System_DateTime($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $data$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $data$i = sp + 40|0;
 $0 = sp;
 $_stackTraceSentry = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587680);
 __THREW__ = 0;
 $1 = (invoke_ii(2504,(0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   ;HEAP32[$0+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__this+12>>2]|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(2653152|0),($1|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
    invoke_viii($11|0,($agg$result|0),($12|0),($$byval_copy|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z42mscorlib_System_DateTime_m_ToUniversalTimeP24mscorlib_System_DateTime($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $data$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $data$i = sp + 40|0;
 $0 = sp;
 $_stackTraceSentry = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587728);
 __THREW__ = 0;
 $1 = (invoke_ii(2504,(0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   ;HEAP32[$0+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$__this+12>>2]|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(2653248|0),($1|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($data$i) + 4|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (($9) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
    invoke_viii($11|0,($agg$result|0),($12|0),($$byval_copy|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z35mscorlib_System_DateTime_m_SubtractP24mscorlib_System_DateTime24mscorlib_System_TimeSpan($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp + 40|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 48|0;
 $L_2 = sp + 16|0;
 $0 = sp + 24|0;
 $1 = sp + 32|0;
 $2 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587488);
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 $3 = (invoke_ii(2499,($__this|0))|0);
 $4 = tempRet0;
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($46|0);
  // unreachable;
 }
 $7 = $L_2;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 __THREW__ = 0;
 invoke_viii(703,($L_2|0),($3|0),($4|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($46|0);
  // unreachable;
 }
 $13 = $L_2;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $0;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 $23 = $value;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = $1;
 $30 = $29;
 HEAP32[$30>>2] = $25;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $28;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$1+4>>2]|0;
 $33 = (invoke_iiii(1269,(0|0),($$byval_copy|0),($$byval_copy2|0))|0);
 $34 = tempRet0;
 $35 = __THREW__; __THREW__ = 0;
 $36 = $35&1;
 if ($36) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($46|0);
  // unreachable;
 }
 $37 = $2;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $34;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 invoke_viii(662,($agg$result|0),1,($$byval_copy2|0));
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($46|0);
  // unreachable;
 } else {
  $43 = (($__this) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = (($agg$result) + 8|0);
  HEAP32[$45>>2] = $44;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z58mscorlib_System_DateTime_m_ToString_mscorlib_System_StringP24mscorlib_System_DateTime($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587536);
 __THREW__ = 0;
 invoke_v(875);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3068864>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iiii(1160,($__this|0),($2|0),(0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($3|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_DateTime_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP24mscorlib_System_DateTimeP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_11 = 0, $V_1 = 0, $V_2 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__this$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 32|0;
 $V_1 = sp + 37|0;
 $V_2 = sp + 36|0;
 $L_11 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587632);
 HEAP8[$V_1>>0] = 0;
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(876);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(852,(0|0),($provider|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($format|0)==(0|0);
    if ($5) {
     label = 13;
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     $10 = HEAP8[((2191608 + 116|0))>>0]|0;
     $11 = ($10<<24>>24)==(0);
     if ($11) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2191608|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP32[((2191608 + 80|0))>>2]|0;
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     $22 = (invoke_iiii(574,(0|0),($format|0),($21|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     if ($22) {
      label = 13;
     } else {
      $$01 = $format;
     }
    }
    if ((label|0) == 13) {
     $25 = HEAP32[3068880>>2]|0;
     $$01 = $25;
    }
    HEAP8[$V_1>>0] = 0;
    HEAP8[$V_2>>0] = 0;
    __THREW__ = 0;
    invoke_vi(3799,($$01|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __THREW__ = 0;
     $28 = (invoke_ii(1816,($$01|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      $31 = ($28|0)==(1);
      if ($31) {
       __THREW__ = 0;
       invoke_vi(3799,($$01|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       $34 = (invoke_iii(621,($$01|0),0)|0);
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       __THREW__ = 0;
       $37 = (invoke_iiiiii(127,0,($34|0),($2|0),($V_1|0),($V_2|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       }
       $40 = ($34<<16>>16)==(85);
       if ($40) {
        __THREW__ = 0;
        invoke_vii(1934,($L_11|0),($__this|0));
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         break;
        }
        __THREW__ = 0;
        ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$L_11+12>>2]|0;
        $43 = (invoke_iiiii(183,0,($__this$byval_copy|0),($37|0),($2|0))|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        } else {
         $$0 = $43;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $46 = ($37|0)==(0|0);
       if ($46) {
        __THREW__ = 0;
        (invoke_ii(2996,(2603176|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_ii(3469,(2603176|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        $52 = HEAP32[3068888>>2]|0;
        __THREW__ = 0;
        invoke_vii(1940,($49|0),($52|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3838,($49|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
        // unreachable;
       } else {
        $$1 = $37;
       }
      } else {
       $$1 = $$01;
      }
      __THREW__ = 0;
      ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
      $57 = (invoke_iiiii(183,0,($__this$byval_copy|0),($$1|0),($2|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       $$0 = $57;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z160mscorlib_System_DateTimeUtils_m_ToString_mscorlib_System_String_mscorlib_System_DateTime_mscorlib_System_String_mscorlib_System_Globalization_DateTimeFormatInfoP22mscorlib_System_Object24mscorlib_System_DateTimeP22mscorlib_System_StringP48mscorlib_System_Globalization_DateTimeFormatInfo($__this,$dt,$format,$dfi) {
 $__this = $__this|0;
 $dt = $dt|0;
 $format = $format|0;
 $dfi = $dfi|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, $dt$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $dt$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2594472);
 __THREW__ = 0;
 ;HEAP32[$dt$byval_copy+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$dt$byval_copy+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$dt$byval_copy+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$dt$byval_copy+12>>2]=HEAP32[$dt+12>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[2594520+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[2594520+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[2594520+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[2594520+12>>2]|0;
 $0 = (invoke_iiiiii(128,0,($dt$byval_copy|0),($$byval_copy|0),($format|0),($dfi|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z112mscorlib_System_DateTime_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_($__this,$d1,$d2) {
 $__this = $__this|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587824);
 $2 = $d1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $d2;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = $4;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $7;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $10;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $13;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $22 = (invoke_iiii(1263,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($22|0);
 }
 return 0|0;
}
function __Z115mscorlib_System_DateTime_m_op_GreaterThan_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587872);
 $2 = $t1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $t2;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = $4;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $7;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $10;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $13;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $22 = (invoke_iiii(1264,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($22|0);
 }
 return 0|0;
}
function __Z122mscorlib_System_DateTime_m_op_GreaterThanOrEqual_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2587920);
 $2 = $t1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $t2;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = $4;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $7;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $10;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $13;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $22 = (invoke_iiii(1265,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($22|0);
 }
 return 0|0;
}
function __Z112mscorlib_System_DateTime_m_op_LessThan_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2588016);
 $2 = $t1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $t2;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = $4;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $7;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $10;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $13;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $22 = (invoke_iiii(1267,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($22|0);
 }
 return 0|0;
}
function __Z119mscorlib_System_DateTime_m_op_LessThanOrEqual_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2588064);
 $2 = $t1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $t2;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = $4;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $7;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $10;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $13;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $22 = (invoke_iiii(1268,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($22|0);
 }
 return 0|0;
}
function __Z116mscorlib_System_DateTime_m_op_Subtraction_mscorlib_System_DateTime_mscorlib_System_DateTime_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_DateTime24mscorlib_System_TimeSpan($agg$result,$__this,$d,$t) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d = $d|0;
 $t = $t|0;
 var $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy2 = sp + 32|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 40|0;
 $0 = sp + 16|0;
 $1 = sp + 24|0;
 $2 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2588112);
 ;HEAP32[$agg$result+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[2593040+12>>2]|0;
 $3 = $d;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = $t;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $1;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$1+4>>2]|0;
 $23 = (invoke_iiii(1269,(0|0),($$byval_copy|0),($$byval_copy2|0))|0);
 $24 = tempRet0;
 $25 = __THREW__; __THREW__ = 0;
 $26 = $25&1;
 if ($26) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($36|0);
  // unreachable;
 }
 $27 = $2;
 $28 = $27;
 HEAP32[$28>>2] = $23;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $24;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy2+4>>2]=HEAP32[$2+4>>2]|0;
 invoke_viii(662,($agg$result|0),1,($$byval_copy2|0));
 $31 = __THREW__; __THREW__ = 0;
 $32 = $31&1;
 if ($32) {
  $36 = ___cxa_find_matching_catch()|0;
  $37 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($36|0);
  // unreachable;
 } else {
  $33 = (($d) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (($agg$result) + 8|0);
  HEAP32[$35>>2] = $34;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN14ActionInvoker7I27mscorlib_System_Int32TraitsS0_S0_S0_S0_S0_S0_E6InvokeEPFvPviiiiiiiES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($args) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($args) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 FUNCTION_TABLE_viiiiiiii[$action & 63]($obj,$1,$4,$7,$10,$13,$16,$19);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPvb24mscorlib_System_TimeSpanES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = (($args) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$3,$$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int64Traits27mscorlib_System_Int32TraitsE6InvokeEPFvPvxiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$3,$6,$9);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits30mscorlib_System_TimeSpanTraitsE6InvokeEPF24mscorlib_System_DateTimePv24mscorlib_System_TimeSpanES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $ret = sp;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$$byval_copy);
 $12 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_DoubleTraitsE6InvokeEPF24mscorlib_System_DateTimePvdES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 FUNCTION_TABLE_viid[$func & 7]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits30mscorlib_System_DateTimeTraitsE6InvokeEPFbPv24mscorlib_System_DateTimeES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I30mscorlib_System_DateTimeTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEPF24mscorlib_System_DateTimePvS3_iES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 32|0;
 $ret = sp;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$4);
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker3I30mscorlib_System_DateTimeTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEPF24mscorlib_System_DateTimePvS5_S5_iES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiiii[$func & 255]($ret,$obj,$0,$2,$5);
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker7I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS1_S1_S0_S1_E6InvokeEPFbPvS4_S4_iS4_S4_bS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$2,$5,$7,$9,$13,$15)|0);
 $17 = $16&1;
 HEAP8[$ret>>0] = $17;
 $18 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($18|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsS0_E6InvokeEPFPvS3_S3_bS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)!=(0);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$4,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S0_29mscorlib_System_BooleanTraitsS2_S1_E6InvokeEPFiPvS4_iiibbS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 $14 = (($args) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)!=(0);
 $18 = (($args) + 24|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$3,$6,$9,$13,$17,$19)|0);
 HEAP32[$ret>>2] = $20;
 $21 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($21|0);
}
function __ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S1_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS4_iS4_S4_bS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiiiiiii[$func & 127]($obj,$0,$3,$5,$7,$11,$13)|0);
 HEAP32[$ret>>2] = $14;
 $15 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($15|0);
}
function __ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS2_S1_S1_E6InvokeEPFbPvS4_iiS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$6,$8,$10)|0);
 $12 = $11&1;
 HEAP8[$ret>>0] = $12;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker7I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS2_S1_S0_S1_S1_E6InvokeEPFbPvS4_iiS4_bS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)!=(0);
 $13 = (($args) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_iiiiiiiii[$func & 63]($obj,$0,$3,$6,$8,$12,$14,$16)|0);
 $18 = $17&1;
 HEAP8[$ret>>0] = $18;
 $19 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($19|0);
}
function __ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_E6InvokeEPFbPvS4_iS4_bS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)!=(0);
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$3,$5,$9,$11)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN13FuncInvoker11I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_S0_S1_S1_S1_27mscorlib_System_Int32TraitsS0_S1_S1_E6InvokeEPFbPvS4_S4_S4_bS4_S4_S4_ibS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)!=(0);
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($args) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = HEAP8[$19>>0]|0;
 $21 = ($20<<24>>24)!=(0);
 $22 = (($args) + 36|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($args) + 40|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (FUNCTION_TABLE_iiiiiiiiiiiii[$func & 3]($obj,$0,$2,$4,$8,$10,$12,$14,$17,$21,$23,$25)|0);
 $27 = $26&1;
 HEAP8[$ret>>0] = $27;
 $28 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($28|0);
}
function __ZN12FuncInvoker9I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_27mscorlib_System_Int32TraitsS1_S0_S1_S0_S1_E6InvokeEPFbPvS4_S4_S4_iS4_bS4_bS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)!=(0);
 $14 = (($args) + 24|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($args) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)!=(0);
 $20 = (($args) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (FUNCTION_TABLE_iiiiiiiiiii[$func & 7]($obj,$0,$2,$4,$7,$9,$13,$15,$19,$21)|0);
 $23 = $22&1;
 HEAP8[$ret>>0] = $23;
 $24 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($24|0);
}
function __ZN12FuncInvoker2I30mscorlib_System_DateTimeTraitsS0_30mscorlib_System_TimeSpanTraitsE6InvokeEPF24mscorlib_System_DateTimePvS3_24mscorlib_System_TimeSpanES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 56|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 32|0;
 $1 = sp + 48|0;
 $2 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $1;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$$byval_copy1);
 $15 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($15|0);
}
function __Z59mscorlib_System_DateTimeKind_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z48mscorlib_System_DateTimeOffset_m_get_UtcDateTimeP30mscorlib_System_DateTimeOffset($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $L_2$byval_copy = 0;
 var $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_2$byval_copy = sp + 40|0;
 $tmpcast$byval_copy = sp;
 $_stackTraceSentry = sp + 56|0;
 $L_2 = sp + 24|0;
 $0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2593416);
 $1 = (($__this) + 16|0);
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 ;HEAP32[$L_2$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_2$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 invoke_viiii(191,($L_2|0),0,($tmpcast$byval_copy|0),($L_2$byval_copy|0));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$L_2$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_2$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_2$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;HEAP32[$L_2$byval_copy+12>>2]=HEAP32[$L_2+12>>2]|0;
 invoke_viiii(188,($agg$result|0),0,($L_2$byval_copy|0),1);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z39mscorlib_System_DateTimeOffset_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_0 = 0, $L_2 = 0, $L_3 = 0, $L_3$byval_copy = 0, $L_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy1 = sp + 112|0;
 $L_3$byval_copy = sp + 96|0;
 $_stackTraceSentry = sp + 120|0;
 $L_0 = sp + 80|0;
 $L_2 = sp + 56|0;
 $0 = sp + 40|0;
 $L_3 = sp + 24|0;
 $L_5 = sp;
 $1 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2592848);
 __THREW__ = 0;
 (invoke_ii(2996,(2592096|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = HEAP8[((2592096 + 116|0))>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2592096|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2592096|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2592096|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = HEAP32[((2592096 + 80|0))>>2]|0;
    ;HEAP32[$L_0+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$L_0+12>>2]=HEAP32[$16+12>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2652728|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP8[((2652728 + 116|0))>>0]|0;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2652728|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[((2652728 + 80|0))>>2]|0;
      $30 = (($29) + 16|0);
      $31 = $30;
      $32 = $31;
      $33 = HEAP32[$32>>2]|0;
      $34 = (($31) + 4)|0;
      $35 = $34;
      $36 = HEAP32[$35>>2]|0;
      ;HEAP32[$L_2+0>>2]=HEAP32[2593152+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[2593152+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[2593152+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[2593152+12>>2]|0;HEAP32[$L_2+16>>2]=HEAP32[2593152+16>>2]|0;HEAP32[$L_2+20>>2]=HEAP32[2593152+20>>2]|0;
      $37 = $0;
      $38 = $37;
      HEAP32[$38>>2] = $33;
      $39 = (($37) + 4)|0;
      $40 = $39;
      HEAP32[$40>>2] = $36;
      __THREW__ = 0;
      ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_3$byval_copy+12>>2]=HEAP32[$L_0+12>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;
      invoke_viii(667,($L_2|0),($L_3$byval_copy|0),($$byval_copy1|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2594096|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if (!($44)) {
        $45 = HEAP32[((2594096 + 80|0))>>2]|0;
        ;HEAP32[$45+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$45+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$45+8>>2]=HEAP32[$L_2+8>>2]|0;HEAP32[$45+12>>2]=HEAP32[$L_2+12>>2]|0;HEAP32[$45+16>>2]=HEAP32[$L_2+16>>2]|0;HEAP32[$45+20>>2]=HEAP32[$L_2+20>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if (!($47)) {
         $48 = HEAP8[((2592096 + 116|0))>>0]|0;
         $49 = ($48<<24>>24)==(0);
         if ($49) {
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $50 = __THREW__; __THREW__ = 0;
          $51 = $50&1;
          if ($51) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2592096|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if (!($57)) {
          $58 = HEAP32[((2592096 + 80|0))>>2]|0;
          $59 = (($58) + 16|0);
          ;HEAP32[$L_3+0>>2]=HEAP32[$59+0>>2]|0;HEAP32[$L_3+4>>2]=HEAP32[$59+4>>2]|0;HEAP32[$L_3+8>>2]=HEAP32[$59+8>>2]|0;HEAP32[$L_3+12>>2]=HEAP32[$59+12>>2]|0;
          __THREW__ = 0;
          (invoke_ii(2996,(2652728|0))|0);
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if (!($61)) {
           $62 = HEAP8[((2652728 + 116|0))>>0]|0;
           $63 = ($62<<24>>24)==(0);
           if ($63) {
            __THREW__ = 0;
            (invoke_ii(2996,(2652728|0))|0);
            $64 = __THREW__; __THREW__ = 0;
            $65 = $64&1;
            if ($65) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2652728|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2652728|0));
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2652728|0))|0);
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if (!($71)) {
            $72 = HEAP32[((2652728 + 80|0))>>2]|0;
            $73 = (($72) + 16|0);
            $74 = $73;
            $75 = $74;
            $76 = HEAP32[$75>>2]|0;
            $77 = (($74) + 4)|0;
            $78 = $77;
            $79 = HEAP32[$78>>2]|0;
            ;HEAP32[$L_5+0>>2]=HEAP32[2593152+0>>2]|0;HEAP32[$L_5+4>>2]=HEAP32[2593152+4>>2]|0;HEAP32[$L_5+8>>2]=HEAP32[2593152+8>>2]|0;HEAP32[$L_5+12>>2]=HEAP32[2593152+12>>2]|0;HEAP32[$L_5+16>>2]=HEAP32[2593152+16>>2]|0;HEAP32[$L_5+20>>2]=HEAP32[2593152+20>>2]|0;
            $80 = $1;
            $81 = $80;
            HEAP32[$81>>2] = $76;
            $82 = (($80) + 4)|0;
            $83 = $82;
            HEAP32[$83>>2] = $79;
            __THREW__ = 0;
            ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$L_3$byval_copy+12>>2]=HEAP32[$L_3+12>>2]|0;
            ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
            invoke_viii(667,($L_5|0),($L_3$byval_copy|0),($$byval_copy1|0));
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if (!($85)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2594096|0))|0);
             $86 = __THREW__; __THREW__ = 0;
             $87 = $86&1;
             if (!($87)) {
              $88 = HEAP32[((2594096 + 80|0))>>2]|0;
              $89 = (($88) + 24|0);
              ;HEAP32[$89+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$89+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$89+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$89+12>>2]=HEAP32[$L_5+12>>2]|0;HEAP32[$89+16>>2]=HEAP32[$L_5+16>>2]|0;HEAP32[$89+20>>2]=HEAP32[$L_5+20>>2]|0;
              __THREW__ = 0;
              (invoke_ii(2996,(2615032|0))|0);
              $90 = __THREW__; __THREW__ = 0;
              $91 = $90&1;
              if (!($91)) {
               $92 = HEAP8[((2615032 + 116|0))>>0]|0;
               $93 = ($92<<24>>24)==(0);
               if ($93) {
                __THREW__ = 0;
                (invoke_ii(2996,(2615032|0))|0);
                $94 = __THREW__; __THREW__ = 0;
                $95 = $94&1;
                if ($95) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2615032|0))|0);
                $96 = __THREW__; __THREW__ = 0;
                $97 = $96&1;
                if ($97) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3839,(2615032|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2615032|0))|0);
               $100 = __THREW__; __THREW__ = 0;
               $101 = $100&1;
               if (!($101)) {
                $102 = HEAP32[((2615032 + 80|0))>>2]|0;
                $103 = HEAP8[$102>>0]|0;
                $104 = ($103<<24>>24)==(0);
                if ($104) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1658944|0))|0);
                $105 = __THREW__; __THREW__ = 0;
                $106 = $105&1;
                if ($106) {
                 break;
                }
                __THREW__ = 0;
                $107 = (invoke_ii(3469,(1658944|0))|0);
                $108 = __THREW__; __THREW__ = 0;
                $109 = $108&1;
                if ($109) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(1643,($107|0));
                $110 = __THREW__; __THREW__ = 0;
                $111 = $110&1;
                if ($111) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1660704|0))|0);
                $112 = __THREW__; __THREW__ = 0;
                $113 = $112&1;
                if ($113) {
                 break;
                }
                __THREW__ = 0;
                $114 = (invoke_ii(3469,(1660704|0))|0);
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if ($116) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(1647,($114|0));
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z61mscorlib_System_DateTimeOffset_m_System_IComparable_CompareToP30mscorlib_System_DateTimeOffsetP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $_stackTraceSentry = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2592896);
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2770,($obj|0),(2594096|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$2+20>>2]|0;
   $5 = (invoke_iii(1119,($__this|0),($tmpcast$byval_copy|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_DateTimeOffset_m_CompareToP30mscorlib_System_DateTimeOffsetS_($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_1 = 0, $L_1$byval_copy = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_1$byval_copy = sp + 48|0;
 $_stackTraceSentry = sp + 64|0;
 $V_0 = sp + 16|0;
 $L_0 = sp + 32|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2592992);
 ;HEAP32[$V_0+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 invoke_vii(1937,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$V_0+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_0+12>>2]|0;
  __THREW__ = 0;
  invoke_vii(1937,($L_1|0),($other|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_1$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
   $4 = (invoke_iii(1113,($V_0|0),($L_1$byval_copy|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_DateTimeOffset_m_System_Runtime_Serialization_ISerializable_GetObjectDataP30mscorlib_System_DateTimeOffsetP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_4 = 0, $V_0 = 0, $V_0$byval_copy = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $V_0$byval_copy = sp + 56|0;
 $_stackTraceSentry = sp + 72|0;
 $V_0 = sp + 8|0;
 $V_1 = sp + 24|0;
 $L_4 = sp + 40|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2592944);
 ;HEAP32[$V_0+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[2593040+12>>2]|0;
 ;HEAP32[$V_1+0>>2]=HEAP32[2593040+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2593040+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2593040+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2593040+12>>2]|0;
 __THREW__ = 0;
 invoke_v(877);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($info|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3070008>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $16 = (invoke_ii(2432,($__this|0))|0);
   $17 = tempRet0;
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    __THREW__ = 0;
    invoke_viii(661,($V_1|0),($16|0),($17|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 16|0);
     $23 = $22;
     $24 = $23;
     $25 = HEAP32[$24>>2]|0;
     $26 = (($23) + 4)|0;
     $27 = $26;
     $28 = HEAP32[$27>>2]|0;
     $29 = $0;
     $30 = $29;
     HEAP32[$30>>2] = $25;
     $31 = (($29) + 4)|0;
     $32 = $31;
     HEAP32[$32>>2] = $28;
     __THREW__ = 0;
     ;HEAP32[$V_0$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$V_0$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
     invoke_viii(666,($L_4|0),($V_1|0),($V_0$byval_copy|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      ;HEAP32[$V_0+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_4+12>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($info|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       $37 = HEAP32[3070016>>2]|0;
       __THREW__ = 0;
       ;HEAP32[$V_0$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$V_0$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$V_0$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;HEAP32[$V_0$byval_copy+12>>2]=HEAP32[$V_0+12>>2]|0;
       invoke_viii(620,($info|0),($37|0),($V_0$byval_copy|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        $40 = (($__this) + 16|0);
        __THREW__ = 0;
        $41 = (+invoke_di(5,($40|0)));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if (!($43)) {
         __THREW__ = 0;
         invoke_vi(3799,($info|0));
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if (!($45)) {
          $46 = (~~(($41)));
          $47 = HEAP32[3070024>>2]|0;
          __THREW__ = 0;
          invoke_viii(617,($info|0),($47|0),($46|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if (!($49)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z94mscorlib_System_DateTimeOffset_m_Equals_mscorlib_System_Boolean_mscorlib_System_DateTimeOffsetP30mscorlib_System_DateTimeOffsetS_($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $L_0 = 0, $L_0$byval_copy = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_1$byval_copy = sp + 48|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 64|0;
 $L_0 = sp + 32|0;
 $L_1 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2593056);
 __THREW__ = 0;
 invoke_vii(1937,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1937,($L_1|0),($other|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_0$byval_copy+12>>2]=HEAP32[$L_0+12>>2]|0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_1$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
   $4 = (invoke_iiii(1162,0,($L_0$byval_copy|0),($L_1$byval_copy|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($4|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_DateTimeOffset_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP30mscorlib_System_DateTimeOffsetP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $L_1 = 0, $L_1$byval_copy = 0, $L_4 = 0, $L_4$byval_copy = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $L_4$byval_copy = sp + 72|0;
 $L_1$byval_copy = sp;
 $_stackTraceSentry = sp + 88|0;
 $V_0 = sp + 32|0;
 $L_1 = sp + 56|0;
 $L_4 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2593104);
 ;HEAP32[$V_0+0>>2]=HEAP32[2593152+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[2593152+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[2593152+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[2593152+12>>2]|0;HEAP32[$V_0+16>>2]=HEAP32[2593152+16>>2]|0;HEAP32[$V_0+20>>2]=HEAP32[2593152+20>>2]|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2594096|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2594096|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vii(1937,($L_1|0),($__this|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2594096|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_iii(2770,($obj|0),(2594096|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      ;HEAP32[$V_0+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$12+12>>2]|0;HEAP32[$V_0+16>>2]=HEAP32[$12+16>>2]|0;HEAP32[$V_0+20>>2]=HEAP32[$12+20>>2]|0;
      __THREW__ = 0;
      invoke_vii(1937,($L_4|0),($V_0|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_1$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
       ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$L_4$byval_copy+12>>2]=HEAP32[$L_4+12>>2]|0;
       $17 = (invoke_iiii(1162,0,($L_1$byval_copy|0),($L_4$byval_copy|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $$0 = $17;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_DateTimeOffset_m_GetHashCodeP30mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2593176);
 __THREW__ = 0;
 $0 = (invoke_ii(2435,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 16|0);
  __THREW__ = 0;
  $4 = (invoke_ii(2501,($3|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = $4 ^ $0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($7|0);
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z64mscorlib_System_DateTimeOffset_m_ToString_mscorlib_System_StringP30mscorlib_System_DateTimeOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2593224);
 __THREW__ = 0;
 $0 = (invoke_iiii(1172,($__this|0),(0|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z119mscorlib_System_DateTimeOffset_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP30mscorlib_System_DateTimeOffsetP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$formatProvider) {
 $__this = $__this|0;
 $format = $format|0;
 $formatProvider = $formatProvider|0;
 var $$01 = 0, $$02 = 0, $$03 = 0, $$213 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $G_B12_0$0 = 0, $L_15 = 0, $L_17 = 0, $L_19 = 0, $L_19$byval_copy = 0, $L_21 = 0, $L_21$byval_copy = 0, $V_1 = 0, $V_2 = 0, $_stackTraceSentry = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $L_21$byval_copy = sp + 96|0;
 $L_19$byval_copy = sp + 80|0;
 $_stackTraceSentry = sp + 112|0;
 $V_1 = sp + 116|0;
 $V_2 = sp + 117|0;
 $L_15 = sp + 64|0;
 $L_17 = sp + 40|0;
 $0 = sp + 32|0;
 $L_19 = sp + 16|0;
 $L_21 = sp;
 $1 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2593272);
 HEAP8[$V_1>>0] = 0;
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(878);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(852,(0|0),($formatProvider|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($format|0)==(0|0);
    if ($7) {
     label = 13;
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = HEAP8[((2191608 + 116|0))>>0]|0;
     $13 = ($12<<24>>24)==(0);
     if ($13) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2191608|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = HEAP32[((2191608 + 80|0))>>2]|0;
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     $24 = (invoke_iiii(574,(0|0),($format|0),($23|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     if ($24) {
      label = 13;
     } else {
      $$01 = $format;
     }
    }
    if ((label|0) == 13) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     $29 = (invoke_ii(2002,($4|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     __THREW__ = 0;
     $34 = (invoke_ii(2004,($4|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     $37 = HEAP32[3070088>>2]|0;
     $38 = HEAP32[3070096>>2]|0;
     __THREW__ = 0;
     $39 = (invoke_iiiiii(89,(0|0),($29|0),($37|0),($34|0),($38|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break;
     } else {
      $$01 = $39;
     }
    }
    HEAP8[$V_1>>0] = 0;
    HEAP8[$V_2>>0] = 0;
    __THREW__ = 0;
    invoke_vi(3799,($$01|0));
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if (!($43)) {
     __THREW__ = 0;
     $44 = (invoke_ii(1816,($$01|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if (!($46)) {
      $47 = ($44|0)==(1);
      L23: do {
       if ($47) {
        __THREW__ = 0;
        invoke_vi(3799,($$01|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break L1;
        }
        __THREW__ = 0;
        $50 = (invoke_iii(621,($$01|0),0)|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break L1;
        }
        __THREW__ = 0;
        $53 = (invoke_iiiiiii(94,0,($50|0),($4|0),($V_1|0),($V_2|0),1)|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        do {
         if ($55) {
          $56 = ___cxa_find_matching_catch(348288|0)|0;
          $57 = tempRet0;
          $58 = (_llvm_eh_typeid_for((348288|0))|0);
          $59 = ($57|0)==($58|0);
          if (!($59)) {
           $$02 = $56;$$03 = $57;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($$02|0);
           // unreachable;
          }
          $60 = (___cxa_begin_catch(($56|0))|0);
          $61 = HEAP32[$60>>2]|0;
          $62 = HEAP32[$61>>2]|0;
          __THREW__ = 0;
          $63 = (invoke_iii(2727,(2149728|0),($62|0))|0);
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if (!($65)) {
           if ($63) {
            __THREW__ = 0;
            invoke_v(66);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break L1;
            } else {
             break;
            }
           }
           $72 = (___cxa_allocate_exception(4)|0);
           $73 = HEAP32[$60>>2]|0;
           HEAP32[$72>>2] = $73;
           __THREW__ = 0;
           invoke_viii(1567,($72|0),(348288|0),(0|0));
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if (!($75)) {
            // unreachable;
           }
          }
          $68 = ___cxa_find_matching_catch()|0;
          $69 = tempRet0;
          __THREW__ = 0;
          invoke_v(66);
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           $133 = ___cxa_find_matching_catch(0|0)|0;
           $134 = tempRet0;
           ___clang_call_terminate($133);
           // unreachable;
          } else {
           $$02 = $68;$$03 = $69;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($$02|0);
           // unreachable;
          }
         } else {
          $76 = ($53|0)==(0|0);
          if (!($76)) {
           $$pre = HEAP8[$V_1>>0]|0;
           $phitmp = ($$pre<<24>>24)==(0);
           if ($phitmp) {
            $$213 = $53;
            break L23;
           }
           __THREW__ = 0;
           invoke_vii(1937,($L_15|0),($__this|0));
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            break L1;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2652728|0))|0);
           $89 = __THREW__; __THREW__ = 0;
           $90 = $89&1;
           if ($90) {
            break L1;
           }
           $91 = HEAP8[((2652728 + 116|0))>>0]|0;
           $92 = ($91<<24>>24)==(0);
           if ($92) {
            __THREW__ = 0;
            (invoke_ii(2996,(2652728|0))|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break L1;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2652728|0))|0);
            $95 = __THREW__; __THREW__ = 0;
            $96 = $95&1;
            if ($96) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2652728|0));
            $97 = __THREW__; __THREW__ = 0;
            $98 = $97&1;
            if ($98) {
             break L1;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2652728|0))|0);
           $99 = __THREW__; __THREW__ = 0;
           $100 = $99&1;
           if ($100) {
            break L1;
           }
           $101 = HEAP32[((2652728 + 80|0))>>2]|0;
           $102 = (($101) + 16|0);
           $103 = $102;
           $104 = $103;
           $105 = HEAP32[$104>>2]|0;
           $106 = (($103) + 4)|0;
           $107 = $106;
           $108 = HEAP32[$107>>2]|0;
           ;HEAP32[$L_17+0>>2]=HEAP32[2594520+0>>2]|0;HEAP32[$L_17+4>>2]=HEAP32[2594520+4>>2]|0;HEAP32[$L_17+8>>2]=HEAP32[2594520+8>>2]|0;HEAP32[$L_17+12>>2]=HEAP32[2594520+12>>2]|0;
           $109 = $0;
           $110 = $109;
           HEAP32[$110>>2] = $105;
           $111 = (($109) + 4)|0;
           $112 = $111;
           HEAP32[$112>>2] = $108;
           __THREW__ = 0;
           ;HEAP32[$L_21$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_21$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
           invoke_vii(1440,($L_17|0),($L_21$byval_copy|0));
           $113 = __THREW__; __THREW__ = 0;
           $114 = $113&1;
           if ($114) {
            break L1;
           }
           __THREW__ = 0;
           ;HEAP32[$L_19$byval_copy+0>>2]=HEAP32[$L_15+0>>2]|0;HEAP32[$L_19$byval_copy+4>>2]=HEAP32[$L_15+4>>2]|0;HEAP32[$L_19$byval_copy+8>>2]=HEAP32[$L_15+8>>2]|0;HEAP32[$L_19$byval_copy+12>>2]=HEAP32[$L_15+12>>2]|0;
           ;HEAP32[$L_21$byval_copy+0>>2]=HEAP32[$L_17+0>>2]|0;HEAP32[$L_21$byval_copy+4>>2]=HEAP32[$L_17+4>>2]|0;HEAP32[$L_21$byval_copy+8>>2]=HEAP32[$L_17+8>>2]|0;HEAP32[$L_21$byval_copy+12>>2]=HEAP32[$L_17+12>>2]|0;
           $115 = (invoke_iiiiii(128,0,($L_19$byval_copy|0),($L_21$byval_copy|0),($53|0),($4|0))|0);
           $116 = __THREW__; __THREW__ = 0;
           $117 = $116&1;
           if ($117) {
            break L1;
           } else {
            $G_B12_0$0 = $115;
           }
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($G_B12_0$0|0);
          }
         }
        } while(0);
        __THREW__ = 0;
        (invoke_ii(2996,(2603176|0))|0);
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         break L1;
        }
        __THREW__ = 0;
        $79 = (invoke_ii(3469,(2603176|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         break L1;
        }
        $82 = HEAP32[3070104>>2]|0;
        __THREW__ = 0;
        invoke_vii(1940,($79|0),($82|0));
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3838,($79|0));
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         break L1;
        }
        // unreachable;
       } else {
        $$213 = $$01;
       }
      } while(0);
      __THREW__ = 0;
      invoke_vii(1936,($L_19|0),($__this|0));
      $118 = __THREW__; __THREW__ = 0;
      $119 = $118&1;
      if (!($119)) {
       __THREW__ = 0;
       $120 = (invoke_ii(2439,($__this|0))|0);
       $121 = tempRet0;
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if (!($123)) {
        ;HEAP32[$L_21+0>>2]=HEAP32[2594520+0>>2]|0;HEAP32[$L_21+4>>2]=HEAP32[2594520+4>>2]|0;HEAP32[$L_21+8>>2]=HEAP32[2594520+8>>2]|0;HEAP32[$L_21+12>>2]=HEAP32[2594520+12>>2]|0;
        $124 = $1;
        $125 = $124;
        HEAP32[$125>>2] = $120;
        $126 = (($124) + 4)|0;
        $127 = $126;
        HEAP32[$127>>2] = $121;
        __THREW__ = 0;
        ;HEAP32[$L_21$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$L_21$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
        invoke_vii(1440,($L_21|0),($L_21$byval_copy|0));
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if (!($129)) {
         __THREW__ = 0;
         ;HEAP32[$L_19$byval_copy+0>>2]=HEAP32[$L_19+0>>2]|0;HEAP32[$L_19$byval_copy+4>>2]=HEAP32[$L_19+4>>2]|0;HEAP32[$L_19$byval_copy+8>>2]=HEAP32[$L_19+8>>2]|0;HEAP32[$L_19$byval_copy+12>>2]=HEAP32[$L_19+12>>2]|0;
         ;HEAP32[$L_21$byval_copy+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$L_21$byval_copy+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$L_21$byval_copy+8>>2]=HEAP32[$L_21+8>>2]|0;HEAP32[$L_21$byval_copy+12>>2]=HEAP32[$L_21+12>>2]|0;
         $130 = (invoke_iiiiii(128,0,($L_19$byval_copy|0),($L_21$byval_copy|0),($$213|0),($4|0))|0);
         $131 = __THREW__; __THREW__ = 0;
         $132 = $131&1;
         if (!($132)) {
          $G_B12_0$0 = $130;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($G_B12_0$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $$02 = $8;$$03 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z233mscorlib_System_DateTimeUtils_m_GetStandardPattern_mscorlib_System_String_mscorlib_System_Char_mscorlib_System_Globalization_DateTimeFormatInfo_mscorlib_System_BooleanU0026_ref_mscorlib_System_BooleanU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjecttP48mscorlib_System_Globalization_DateTimeFormatInfoPbS3_b($__this,$format,$dfi,$useutc,$use_invariant,$date_time_offset) {
 $__this = $__this|0;
 $format = $format|0;
 $dfi = $dfi|0;
 $useutc = $useutc|0;
 $use_invariant = $use_invariant|0;
 $date_time_offset = $date_time_offset|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2594424);
 __THREW__ = 0;
 invoke_v(879);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   HEAP8[$useutc>>0] = 0;
   HEAP8[$use_invariant>>0] = 0;
   $2 = $format&65535;
   $3 = (($2) + 65427)|0;
   $4 = $3 & 65535;
   L3: do {
    switch ($4|0) {
    case 7:  {
     __THREW__ = 0;
     invoke_vi(3799,($dfi|0));
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      break L1;
     }
     __THREW__ = 0;
     $93 = (invoke_ii(2003,($dfi|0))|0);
     $94 = __THREW__; __THREW__ = 0;
     $95 = $94&1;
     if ($95) {
      break L1;
     } else {
      $V_0$0 = $93;
     }
     break;
    }
    case 6:  {
     __THREW__ = 0;
     invoke_vi(3799,($dfi|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      break L1;
     }
     __THREW__ = 0;
     $88 = (invoke_ii(2013,($dfi|0))|0);
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      break L1;
     }
     HEAP8[$use_invariant>>0] = 1;
     $V_0$0 = $88;
     break;
    }
    case 2:  {
     label = 31;
     break;
    }
    case 8:  {
     __THREW__ = 0;
     invoke_vi(3799,($dfi|0));
     $101 = __THREW__; __THREW__ = 0;
     $102 = $101&1;
     if ($102) {
      break L1;
     }
     __THREW__ = 0;
     $103 = (invoke_ii(2014,($dfi|0))|0);
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if ($105) {
      break L1;
     }
     if ($date_time_offset) {
      HEAP8[$useutc>>0] = 1;
     }
     HEAP8[$use_invariant>>0] = 1;
     $V_0$0 = $103;
     break;
    }
    case 0:  {
     label = 29;
     break;
    }
    case 5:  {
     label = 34;
     break;
    }
    case 12:  {
     label = 55;
     break;
    }
    default: {
     $7 = (($2) + 65459)|0;
     $8 = $7 & 65535;
     switch ($8|0) {
     case 7:  {
      __THREW__ = 0;
      invoke_vi(3799,($dfi|0));
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       break L1;
      }
      __THREW__ = 0;
      $98 = (invoke_ii(2004,($dfi|0))|0);
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       break L1;
      } else {
       $V_0$0 = $98;
       break L3;
      }
      break;
     }
     case 2:  {
      label = 31;
      break L3;
      break;
     }
     case 0:  {
      label = 29;
      break L3;
      break;
     }
     case 5:  {
      label = 34;
      break L3;
      break;
     }
     case 8:  {
      if ($date_time_offset) {
       $V_0$0 = 0;
       break L3;
      }
      __THREW__ = 0;
      invoke_vi(3799,($dfi|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       break L1;
      }
      __THREW__ = 0;
      $108 = (invoke_ii(2007,($dfi|0))|0);
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       break L1;
      }
      HEAP8[$useutc>>0] = 1;
      $V_0$0 = $108;
      break L3;
      break;
     }
     default: {
      $9 = (($2) + 65468)|0;
      $10 = $9 & 65535;
      if ((($10|0) == 3)) {
       __THREW__ = 0;
       invoke_vi(3799,($dfi|0));
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        break L1;
       }
       __THREW__ = 0;
       $59 = (invoke_ii(2002,($dfi|0))|0);
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($dfi|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        break L1;
       }
       __THREW__ = 0;
       $64 = (invoke_ii(2004,($dfi|0))|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        break L1;
       }
       $67 = HEAP32[3070200>>2]|0;
       __THREW__ = 0;
       $68 = (invoke_iiiii(101,(0|0),($59|0),($67|0),($64|0))|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break L1;
       } else {
        $V_0$0 = $68;
        break L3;
       }
      } else if ((($10|0) == 2)) {
       __THREW__ = 0;
       invoke_vi(3799,($dfi|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break L1;
       }
       __THREW__ = 0;
       $40 = (invoke_ii(2007,($dfi|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break L1;
       } else {
        $V_0$0 = $40;
        break L3;
       }
      } else if ((($10|0) == 0)) {
       __THREW__ = 0;
       invoke_vi(3799,($dfi|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if ($20) {
        break L1;
       }
       __THREW__ = 0;
       $21 = (invoke_ii(2001,($dfi|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break L1;
       } else {
        $V_0$0 = $21;
        break L3;
       }
      } else {
       $11 = (($2) + 65436)|0;
       $12 = $11 & 65535;
       if ((($12|0) == 0)) {
        __THREW__ = 0;
        invoke_vi(3799,($dfi|0));
        $14 = __THREW__; __THREW__ = 0;
        $15 = $14&1;
        if ($15) {
         break L1;
        }
        __THREW__ = 0;
        $16 = (invoke_ii(2002,($dfi|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if ($18) {
         break L1;
        } else {
         $V_0$0 = $16;
         break L3;
        }
       } else if ((($12|0) == 2)) {
        __THREW__ = 0;
        invoke_vi(3799,($dfi|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         break L1;
        }
        __THREW__ = 0;
        $26 = (invoke_ii(2001,($dfi|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($dfi|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         break L1;
        }
        __THREW__ = 0;
        $31 = (invoke_ii(2003,($dfi|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break L1;
        }
        $34 = HEAP32[3070184>>2]|0;
        __THREW__ = 0;
        $35 = (invoke_iiiii(101,(0|0),($26|0),($34|0),($31|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        } else {
         $V_0$0 = $35;
         break L3;
        }
       } else if ((($12|0) == 3)) {
        __THREW__ = 0;
        invoke_vi(3799,($dfi|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break L1;
        }
        __THREW__ = 0;
        $45 = (invoke_ii(2002,($dfi|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($dfi|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break L1;
        }
        __THREW__ = 0;
        $50 = (invoke_ii(2003,($dfi|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break L1;
        }
        $53 = HEAP32[3070192>>2]|0;
        __THREW__ = 0;
        $54 = (invoke_iiiii(101,(0|0),($45|0),($53|0),($50|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        } else {
         $V_0$0 = $54;
         break L3;
        }
       } else {
        $13 = ($format<<16>>16)==(89);
        if ($13) {
         label = 55;
         break L3;
        } else {
         $V_0$0 = 0;
         break L3;
        }
       }
      }
     }
     }
    }
    }
   } while(0);
   if ((label|0) == 29) {
    __THREW__ = 0;
    invoke_vi(3799,($dfi|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     break;
    }
    __THREW__ = 0;
    $73 = (invoke_ii(2005,($dfi|0))|0);
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    } else {
     $V_0$0 = $73;
    }
   }
   else if ((label|0) == 31) {
    __THREW__ = 0;
    invoke_vi(3799,($dfi|0));
    $76 = __THREW__; __THREW__ = 0;
    $77 = $76&1;
    if ($77) {
     break;
    }
    __THREW__ = 0;
    $78 = (invoke_ii(2012,($dfi|0))|0);
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     break;
    }
    HEAP8[$use_invariant>>0] = 1;
    $V_0$0 = $78;
   }
   else if ((label|0) == 34) {
    __THREW__ = 0;
    invoke_vi(3799,($dfi|0));
    $81 = __THREW__; __THREW__ = 0;
    $82 = $81&1;
    if ($82) {
     break;
    }
    __THREW__ = 0;
    $83 = (invoke_ii(2011,($dfi|0))|0);
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
    if ($date_time_offset) {
     HEAP8[$useutc>>0] = 1;
    }
    HEAP8[$use_invariant>>0] = 1;
    $V_0$0 = $83;
   }
   else if ((label|0) == 55) {
    __THREW__ = 0;
    invoke_vi(3799,($dfi|0));
    $111 = __THREW__; __THREW__ = 0;
    $112 = $111&1;
    if ($112) {
     break;
    }
    __THREW__ = 0;
    $113 = (invoke_ii(2006,($dfi|0))|0);
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    } else {
     $V_0$0 = $113;
    }
   }
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($V_0$0|0);
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z212mscorlib_System_DateTimeUtils_m_ToString_mscorlib_System_String_mscorlib_System_DateTime_mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_mscorlib_System_String_mscorlib_System_Globalization_DateTimeFormatInfoP22mscorlib_System_Object24mscorlib_System_DateTime51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanP22mscorlib_System_StringP48mscorlib_System_Globalization_DateTimeFormatInfo($__this,$dt,$utc_offset,$format,$dfi) {
 $__this = $__this|0;
 $dt = $dt|0;
 $utc_offset = $utc_offset|0;
 $format = $format|0;
 $dfi = $dfi|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $$4 = 0, $$byval_copy15 = 0, $$dfi = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0.0, $134 = 0.0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0;
 var $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0;
 var $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0;
 var $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0;
 var $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0;
 var $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0;
 var $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B18_0$0 = 0, $G_B47_0$0 = 0, $V_10 = 0, $V_13 = 0, $V_14 = 0, $V_15 = 0, $V_16 = 0, $V_17 = 0, $V_2$0 = 0, $V_3$0 = 0, $V_4$0$off0 = 0, $_stackTraceSentry = 0;
 var $data$i = 0, $data$i11 = 0, $data$i17 = 0, $data$i22 = 0, $data$i28 = 0, $data$i34 = 0, $data$i40 = 0, $data$i46 = 0, $data$i52 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $$byval_copy15 = sp + 152|0;
 $data$i52 = sp + 248|0;
 $0 = sp + 120|0;
 $data$i46 = sp + 240|0;
 $1 = sp + 136|0;
 $data$i40 = sp + 232|0;
 $2 = sp + 72|0;
 $data$i34 = sp + 224|0;
 $3 = sp + 88|0;
 $data$i28 = sp + 216|0;
 $4 = sp + 48|0;
 $data$i22 = sp + 208|0;
 $5 = sp + 32|0;
 $data$i17 = sp + 256|0;
 $6 = sp + 16|0;
 $data$i11 = sp + 168|0;
 $7 = sp;
 $data$i = sp + 184|0;
 $8 = sp + 104|0;
 $_stackTraceSentry = sp + 196|0;
 $V_10 = sp + 64|0;
 $V_13 = sp + 204|0;
 $V_14 = sp + 200|0;
 $V_15 = sp + 192|0;
 $V_16 = sp + 180|0;
 $V_17 = sp + 176|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2594536);
 $9 = $V_10;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = 0;
 HEAP32[$V_13>>2] = 0;
 HEAP32[$V_14>>2] = 0;
 HEAP32[$V_15>>2] = 0;
 HEAP32[$V_16>>2] = 0;
 HEAP32[$V_17>>2] = 0;
 __THREW__ = 0;
 invoke_v(880);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 do {
  if (!($14)) {
   __THREW__ = 0;
   invoke_vi(3799,($format|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($format|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = (($17) + 10)|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2537888|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(2537888|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       invoke_vii(1910,($23|0),($20|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __THREW__ = 0;
        $28 = (invoke_ii(2009,(0|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         __THREW__ = 0;
         invoke_vi(3799,($28|0));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          __THREW__ = 0;
          $33 = (invoke_ii(2011,($28|0))|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __THREW__ = 0;
           $36 = (invoke_iiii(574,(0|0),($format|0),($33|0))|0);
           $37 = __THREW__; __THREW__ = 0;
           $38 = $37&1;
           if (!($38)) {
            if ($36) {
             $$0 = $28;
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($28|0));
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(2014,($28|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             $50 = (invoke_iiii(574,(0|0),($format|0),($47|0))|0);
             $51 = __THREW__; __THREW__ = 0;
             $52 = $51&1;
             if ($52) {
              break;
             }
             $$dfi = $50 ? $28 : $dfi;
             $$0 = $$dfi;
            }
            $53 = (($data$i) + 4|0);
            $54 = (($data$i46) + 4|0);
            $55 = (($data$i40) + 4|0);
            $56 = (($data$i34) + 4|0);
            $57 = (($data$i11) + 4|0);
            $58 = (($data$i22) + 4|0);
            $59 = (($data$i28) + 4|0);
            $60 = (($data$i17) + 4|0);
            $61 = (($data$i52) + 4|0);
            $V_2$0 = 0;
            L18: while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($format|0));
             $687 = __THREW__; __THREW__ = 0;
             $688 = $687&1;
             if ($688) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $689 = (invoke_ii(1816,($format|0))|0);
             $690 = __THREW__; __THREW__ = 0;
             $691 = $690&1;
             if ($691) {
              label = 13;
              break;
             }
             $692 = ($V_2$0|0)<($689|0);
             if (!($692)) {
              label = 269;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($format|0));
             $693 = __THREW__; __THREW__ = 0;
             $694 = $693&1;
             if ($694) {
              label = 13;
              break;
             }
             __THREW__ = 0;
             $62 = (invoke_iii(621,($format|0),($V_2$0|0))|0);
             $63 = __THREW__; __THREW__ = 0;
             $64 = $63&1;
             if ($64) {
              label = 13;
              break;
             }
             $65 = $62&65535;
             $66 = (($65) + 65436)|0;
             $67 = $66 & 65535;
             L25: do {
              switch ($67|0) {
              case 4:  {
               __THREW__ = 0;
               $74 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
               $75 = __THREW__; __THREW__ = 0;
               $76 = $75&1;
               if ($76) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               $77 = (invoke_ii(2428,($dt|0))|0);
               $78 = __THREW__; __THREW__ = 0;
               $79 = $78&1;
               if ($79) {
                label = 13;
                break L18;
               }
               $80 = (($77|0) % 12)&-1;
               $81 = ($80|0)==(0);
               $$ = $81 ? 12 : $80;
               $82 = ($74|0)==(1);
               $G_B18_0$0 = $82 ? 1 : 2;
               __THREW__ = 0;
               invoke_viiii(193,0,($23|0),($$|0),($G_B18_0$0|0));
               $83 = __THREW__; __THREW__ = 0;
               $84 = $83&1;
               if ($84) {
                label = 13;
                break L18;
               } else {
                $V_3$0 = $74;
               }
               break;
              }
              case 2:  {
               $V_4$0$off0 = 0;
               label = 39;
               break;
              }
              case 9:  {
               __THREW__ = 0;
               $94 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
               $95 = __THREW__; __THREW__ = 0;
               $96 = $95&1;
               if ($96) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               $97 = (invoke_ii(2429,($dt|0))|0);
               $98 = __THREW__; __THREW__ = 0;
               $99 = $98&1;
               if ($99) {
                label = 13;
                break L18;
               }
               $100 = ($94|0)==(1);
               $$2 = $100 ? 1 : 2;
               __THREW__ = 0;
               invoke_viiii(193,0,($23|0),($97|0),($$2|0));
               $101 = __THREW__; __THREW__ = 0;
               $102 = $101&1;
               if ($102) {
                label = 13;
                break L18;
               } else {
                $V_3$0 = $94;
               }
               break;
              }
              case 0:  {
               __THREW__ = 0;
               $416 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
               $417 = __THREW__; __THREW__ = 0;
               $418 = $417&1;
               if ($418) {
                label = 13;
                break L18;
               }
               $419 = ($416|0)>(2);
               if (!($419)) {
                __THREW__ = 0;
                invoke_vi(3799,($$0|0));
                $420 = __THREW__; __THREW__ = 0;
                $421 = $420&1;
                if ($421) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $422 = (invoke_ii(2010,($$0|0))|0);
                $423 = __THREW__; __THREW__ = 0;
                $424 = $423&1;
                if ($424) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($422|0));
                $425 = __THREW__; __THREW__ = 0;
                $426 = $425&1;
                if ($426) {
                 label = 13;
                 break L18;
                }
                ;HEAP32[$6+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$dt+12>>2]|0;
                __THREW__ = 0;
                invoke_viii(2112,($data$i17|0),(2322576|0),($422|0));
                $427 = __THREW__; __THREW__ = 0;
                $428 = $427&1;
                if ($428) {
                 label = 13;
                 break L18;
                }
                $429 = HEAP32[$60>>2]|0;
                $430 = (($429) + 4|0);
                $431 = HEAP32[$430>>2]|0;
                $432 = HEAP32[$data$i17>>2]|0;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$6+12>>2]|0;
                $433 = (invoke_iii($431|0,($432|0),($$byval_copy15|0))|0);
                $434 = __THREW__; __THREW__ = 0;
                $435 = $434&1;
                if ($435) {
                 label = 13;
                 break L18;
                }
                $436 = ($416|0)==(1);
                $$4 = $436 ? 1 : 2;
                __THREW__ = 0;
                invoke_viiii(193,0,($23|0),($433|0),($$4|0));
                $437 = __THREW__; __THREW__ = 0;
                $438 = $437&1;
                if ($438) {
                 label = 13;
                 break L18;
                } else {
                 $V_3$0 = $416;
                 break L25;
                }
               }
               $439 = ($416|0)==(3);
               if ($439) {
                __THREW__ = 0;
                invoke_vi(3799,($$0|0));
                $440 = __THREW__; __THREW__ = 0;
                $441 = $440&1;
                if ($441) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $442 = (invoke_ii(2010,($$0|0))|0);
                $443 = __THREW__; __THREW__ = 0;
                $444 = $443&1;
                if ($444) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($442|0));
                $445 = __THREW__; __THREW__ = 0;
                $446 = $445&1;
                if ($446) {
                 label = 13;
                 break L18;
                }
                ;HEAP32[$5+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$dt+12>>2]|0;
                __THREW__ = 0;
                invoke_viii(2112,($data$i22|0),(2322656|0),($442|0));
                $447 = __THREW__; __THREW__ = 0;
                $448 = $447&1;
                if ($448) {
                 label = 13;
                 break L18;
                }
                $449 = HEAP32[$58>>2]|0;
                $450 = (($449) + 4|0);
                $451 = HEAP32[$450>>2]|0;
                $452 = HEAP32[$data$i22>>2]|0;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$5+12>>2]|0;
                $453 = (invoke_iii($451|0,($452|0),($$byval_copy15|0))|0);
                $454 = __THREW__; __THREW__ = 0;
                $455 = $454&1;
                if ($455) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($$0|0));
                $456 = __THREW__; __THREW__ = 0;
                $457 = $456&1;
                if ($457) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $458 = (invoke_iii(860,($$0|0),($453|0))|0);
                $459 = __THREW__; __THREW__ = 0;
                $460 = $459&1;
                if ($460) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $461 = __THREW__; __THREW__ = 0;
                $462 = $461&1;
                if ($462) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                (invoke_iii(989,($23|0),($458|0))|0);
                $463 = __THREW__; __THREW__ = 0;
                $464 = $463&1;
                if ($464) {
                 label = 13;
                 break L18;
                } else {
                 $V_3$0 = 3;
                 break L25;
                }
               } else {
                __THREW__ = 0;
                invoke_vi(3799,($$0|0));
                $465 = __THREW__; __THREW__ = 0;
                $466 = $465&1;
                if ($466) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $467 = (invoke_ii(2010,($$0|0))|0);
                $468 = __THREW__; __THREW__ = 0;
                $469 = $468&1;
                if ($469) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($467|0));
                $470 = __THREW__; __THREW__ = 0;
                $471 = $470&1;
                if ($471) {
                 label = 13;
                 break L18;
                }
                ;HEAP32[$4+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$dt+12>>2]|0;
                __THREW__ = 0;
                invoke_viii(2112,($data$i28|0),(2322656|0),($467|0));
                $472 = __THREW__; __THREW__ = 0;
                $473 = $472&1;
                if ($473) {
                 label = 13;
                 break L18;
                }
                $474 = HEAP32[$59>>2]|0;
                $475 = (($474) + 4|0);
                $476 = HEAP32[$475>>2]|0;
                $477 = HEAP32[$data$i28>>2]|0;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$4+12>>2]|0;
                $478 = (invoke_iii($476|0,($477|0),($$byval_copy15|0))|0);
                $479 = __THREW__; __THREW__ = 0;
                $480 = $479&1;
                if ($480) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($$0|0));
                $481 = __THREW__; __THREW__ = 0;
                $482 = $481&1;
                if ($482) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $483 = (invoke_iii(859,($$0|0),($478|0))|0);
                $484 = __THREW__; __THREW__ = 0;
                $485 = $484&1;
                if ($485) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $486 = __THREW__; __THREW__ = 0;
                $487 = $486&1;
                if ($487) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                (invoke_iii(989,($23|0),($483|0))|0);
                $488 = __THREW__; __THREW__ = 0;
                $489 = $488&1;
                if ($489) {
                 label = 13;
                 break L18;
                } else {
                 $V_3$0 = $416;
                 break L25;
                }
               }
               break;
              }
              case 3:  {
               __THREW__ = 0;
               $572 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
               $573 = __THREW__; __THREW__ = 0;
               $574 = $573&1;
               if ($574) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               invoke_vi(3799,($$0|0));
               $575 = __THREW__; __THREW__ = 0;
               $576 = $575&1;
               if ($576) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               $577 = (invoke_ii(2010,($$0|0))|0);
               $578 = __THREW__; __THREW__ = 0;
               $579 = $578&1;
               if ($579) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               invoke_vi(3799,($577|0));
               $580 = __THREW__; __THREW__ = 0;
               $581 = $580&1;
               if ($581) {
                label = 13;
                break L18;
               }
               ;HEAP32[$0+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$dt+12>>2]|0;
               __THREW__ = 0;
               invoke_viii(2112,($data$i52|0),(2322728|0),($577|0));
               $582 = __THREW__; __THREW__ = 0;
               $583 = $582&1;
               if ($583) {
                label = 13;
                break L18;
               }
               $584 = HEAP32[$61>>2]|0;
               $585 = (($584) + 4|0);
               $586 = HEAP32[$585>>2]|0;
               $587 = HEAP32[$data$i52>>2]|0;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$0+12>>2]|0;
               $588 = (invoke_iii($586|0,($587|0),($$byval_copy15|0))|0);
               $589 = __THREW__; __THREW__ = 0;
               $590 = $589&1;
               if ($590) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               invoke_vi(3799,($$0|0));
               $591 = __THREW__; __THREW__ = 0;
               $592 = $591&1;
               if ($592) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               $593 = (invoke_iii(856,($$0|0),($588|0))|0);
               $594 = __THREW__; __THREW__ = 0;
               $595 = $594&1;
               if ($595) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               invoke_vi(3799,($23|0));
               $596 = __THREW__; __THREW__ = 0;
               $597 = $596&1;
               if ($597) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               (invoke_iii(989,($23|0),($593|0))|0);
               $598 = __THREW__; __THREW__ = 0;
               $599 = $598&1;
               if ($599) {
                label = 13;
                break L18;
               } else {
                $V_3$0 = $572;
               }
               break;
              }
              default: {
               $68 = (($65) + 65466)|0;
               $69 = $68 & 65535;
               if ((($69|0) == 0)) {
                $V_4$0$off0 = 1;
                label = 39;
                break L25;
               } else if ((($69|0) == 2)) {
                __THREW__ = 0;
                $85 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
                $86 = __THREW__; __THREW__ = 0;
                $87 = $86&1;
                if ($87) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $88 = (invoke_ii(2428,($dt|0))|0);
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if ($90) {
                 label = 13;
                 break L18;
                }
                $91 = ($85|0)==(1);
                $$1 = $91 ? 1 : 2;
                __THREW__ = 0;
                invoke_viiii(193,0,($23|0),($88|0),($$1|0));
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 label = 13;
                 break L18;
                } else {
                 $V_3$0 = $85;
                 break L25;
                }
               } else if ((($69|0) == 5)) {
                __THREW__ = 0;
                $329 = (invoke_ii(1199,($utc_offset|0))|0);
                $330 = __THREW__; __THREW__ = 0;
                $331 = $330&1;
                if ($331) {
                 label = 13;
                 break L18;
                }
                do {
                 if (!($329)) {
                  __THREW__ = 0;
                  $332 = (invoke_ii(2434,($dt|0))|0);
                  $333 = __THREW__; __THREW__ = 0;
                  $334 = $333&1;
                  if ($334) {
                   label = 13;
                   break L18;
                  }
                  $335 = ($332|0)==(2);
                  if ($335) {
                   break;
                  }
                  __THREW__ = 0;
                  $408 = (invoke_ii(2434,($dt|0))|0);
                  $409 = __THREW__; __THREW__ = 0;
                  $410 = $409&1;
                  if ($410) {
                   label = 13;
                   break L18;
                  }
                  $411 = ($408|0)==(1);
                  if (!($411)) {
                   $V_3$0 = 1;
                   break L25;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $412 = __THREW__; __THREW__ = 0;
                  $413 = $412&1;
                  if ($413) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(992,($23|0),90)|0);
                  $414 = __THREW__; __THREW__ = 0;
                  $415 = $414&1;
                  if ($415) {
                   label = 13;
                   break L18;
                  } else {
                   $V_3$0 = 1;
                   break L25;
                  }
                 }
                } while(0);
                __THREW__ = 0;
                $336 = (invoke_ii(1199,($utc_offset|0))|0);
                $337 = __THREW__; __THREW__ = 0;
                $338 = $337&1;
                if ($338) {
                 label = 13;
                 break L18;
                }
                if ($336) {
                 __THREW__ = 0;
                 $339 = (invoke_ii(1200,($utc_offset|0))|0);
                 $340 = tempRet0;
                 $341 = __THREW__; __THREW__ = 0;
                 $342 = $341&1;
                 if ($342) {
                  label = 13;
                  break L18;
                 } else {
                  $360 = $339;$363 = $340;
                 }
                } else {
                 __THREW__ = 0;
                 $343 = (invoke_ii(2504,(0|0))|0);
                 $344 = __THREW__; __THREW__ = 0;
                 $345 = $344&1;
                 if ($345) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($343|0));
                 $346 = __THREW__; __THREW__ = 0;
                 $347 = $346&1;
                 if ($347) {
                  label = 13;
                  break L18;
                 }
                 ;HEAP32[$7+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$7+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$dt+12>>2]|0;
                 __THREW__ = 0;
                 invoke_viii(2112,($data$i11|0),(2653200|0),($343|0));
                 $348 = __THREW__; __THREW__ = 0;
                 $349 = $348&1;
                 if ($349) {
                  label = 13;
                  break L18;
                 }
                 $350 = HEAP32[$57>>2]|0;
                 $351 = (($350) + 4|0);
                 $352 = HEAP32[$351>>2]|0;
                 $353 = HEAP32[$data$i11>>2]|0;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$7+12>>2]|0;
                 $354 = (invoke_iii($352|0,($353|0),($$byval_copy15|0))|0);
                 $355 = tempRet0;
                 $356 = __THREW__; __THREW__ = 0;
                 $357 = $356&1;
                 if ($357) {
                  label = 13;
                  break L18;
                 } else {
                  $360 = $354;$363 = $355;
                 }
                }
                $358 = $V_10;
                $359 = $358;
                HEAP32[$359>>2] = $360;
                $361 = (($358) + 4)|0;
                $362 = $361;
                HEAP32[$362>>2] = $363;
                __THREW__ = 0;
                (invoke_ii(2499,($V_10|0))|0);
                $364 = tempRet0;
                $365 = __THREW__; __THREW__ = 0;
                $366 = $365&1;
                if ($366) {
                 label = 13;
                 break L18;
                }
                $367 = ($364|0)<(0);
                if ($367) {
                 __THREW__ = 0;
                 invoke_vi(3799,($23|0));
                 $372 = __THREW__; __THREW__ = 0;
                 $373 = $372&1;
                 if ($373) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 (invoke_iii(992,($23|0),45)|0);
                 $374 = __THREW__; __THREW__ = 0;
                 $375 = $374&1;
                 if ($375) {
                  label = 13;
                  break L18;
                 }
                } else {
                 __THREW__ = 0;
                 invoke_vi(3799,($23|0));
                 $368 = __THREW__; __THREW__ = 0;
                 $369 = $368&1;
                 if ($369) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 (invoke_iii(992,($23|0),43)|0);
                 $370 = __THREW__; __THREW__ = 0;
                 $371 = $370&1;
                 if ($371) {
                  label = 13;
                  break L18;
                 }
                }
                __THREW__ = 0;
                $376 = (invoke_ii(2495,($V_10|0))|0);
                $377 = __THREW__; __THREW__ = 0;
                $378 = $377&1;
                if ($378) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $379 = (invoke_ii(3474,($376|0))|0);
                $380 = __THREW__; __THREW__ = 0;
                $381 = $380&1;
                if ($381) {
                 label = 13;
                 break L18;
                }
                HEAP32[$V_13>>2] = $379;
                $382 = HEAP32[3070248>>2]|0;
                __THREW__ = 0;
                $383 = (invoke_iii(476,($V_13|0),($382|0))|0);
                $384 = __THREW__; __THREW__ = 0;
                $385 = $384&1;
                if ($385) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $386 = __THREW__; __THREW__ = 0;
                $387 = $386&1;
                if ($387) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                (invoke_iii(989,($23|0),($383|0))|0);
                $388 = __THREW__; __THREW__ = 0;
                $389 = $388&1;
                if ($389) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $390 = __THREW__; __THREW__ = 0;
                $391 = $390&1;
                if ($391) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                (invoke_iii(992,($23|0),58)|0);
                $392 = __THREW__; __THREW__ = 0;
                $393 = $392&1;
                if ($393) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $394 = (invoke_ii(2497,($V_10|0))|0);
                $395 = __THREW__; __THREW__ = 0;
                $396 = $395&1;
                if ($396) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $397 = (invoke_ii(3474,($394|0))|0);
                $398 = __THREW__; __THREW__ = 0;
                $399 = $398&1;
                if ($399) {
                 label = 13;
                 break L18;
                }
                HEAP32[$V_17>>2] = $397;
                $400 = HEAP32[3070256>>2]|0;
                __THREW__ = 0;
                $401 = (invoke_iii(476,($V_17|0),($400|0))|0);
                $402 = __THREW__; __THREW__ = 0;
                $403 = $402&1;
                if ($403) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $404 = __THREW__; __THREW__ = 0;
                $405 = $404&1;
                if ($405) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                (invoke_iii(989,($23|0),($401|0))|0);
                $406 = __THREW__; __THREW__ = 0;
                $407 = $406&1;
                if ($407) {
                 label = 13;
                 break L18;
                } else {
                 $V_3$0 = 1;
                 break L25;
                }
               } else if ((($69|0) == 7)) {
                __THREW__ = 0;
                $490 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
                $491 = __THREW__; __THREW__ = 0;
                $492 = $491&1;
                if ($492) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($$0|0));
                $493 = __THREW__; __THREW__ = 0;
                $494 = $493&1;
                if ($494) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                $495 = (invoke_ii(2010,($$0|0))|0);
                $496 = __THREW__; __THREW__ = 0;
                $497 = $496&1;
                if ($497) {
                 label = 13;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($495|0));
                $498 = __THREW__; __THREW__ = 0;
                $499 = $498&1;
                if ($499) {
                 label = 13;
                 break L18;
                }
                ;HEAP32[$3+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$3+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$dt+12>>2]|0;
                __THREW__ = 0;
                invoke_viii(2112,($data$i34|0),(2322808|0),($495|0));
                $500 = __THREW__; __THREW__ = 0;
                $501 = $500&1;
                if ($501) {
                 label = 13;
                 break L18;
                }
                $502 = HEAP32[$56>>2]|0;
                $503 = (($502) + 4|0);
                $504 = HEAP32[$503>>2]|0;
                $505 = HEAP32[$data$i34>>2]|0;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$3+12>>2]|0;
                $506 = (invoke_iii($504|0,($505|0),($$byval_copy15|0))|0);
                $507 = __THREW__; __THREW__ = 0;
                $508 = $507&1;
                if ($508) {
                 label = 13;
                 break L18;
                }
                $509 = ($490|0)>(2);
                if (!($509)) {
                 __THREW__ = 0;
                 invoke_viiii(193,0,($23|0),($506|0),($490|0));
                 $510 = __THREW__; __THREW__ = 0;
                 $511 = $510&1;
                 if ($511) {
                  label = 13;
                  break L18;
                 } else {
                  $V_3$0 = $490;
                  break L25;
                 }
                }
                $512 = ($490|0)==(3);
                if ($512) {
                 __THREW__ = 0;
                 invoke_vi(3799,($$0|0));
                 $513 = __THREW__; __THREW__ = 0;
                 $514 = $513&1;
                 if ($514) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 $515 = (invoke_iii(855,($$0|0),($506|0))|0);
                 $516 = __THREW__; __THREW__ = 0;
                 $517 = $516&1;
                 if ($517) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($23|0));
                 $518 = __THREW__; __THREW__ = 0;
                 $519 = $518&1;
                 if ($519) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 (invoke_iii(989,($23|0),($515|0))|0);
                 $520 = __THREW__; __THREW__ = 0;
                 $521 = $520&1;
                 if ($521) {
                  label = 13;
                  break L18;
                 } else {
                  $V_3$0 = 3;
                  break L25;
                 }
                } else {
                 __THREW__ = 0;
                 invoke_vi(3799,($$0|0));
                 $522 = __THREW__; __THREW__ = 0;
                 $523 = $522&1;
                 if ($523) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 $524 = (invoke_iii(857,($$0|0),($506|0))|0);
                 $525 = __THREW__; __THREW__ = 0;
                 $526 = $525&1;
                 if ($526) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($23|0));
                 $527 = __THREW__; __THREW__ = 0;
                 $528 = $527&1;
                 if ($528) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 (invoke_iii(989,($23|0),($524|0))|0);
                 $529 = __THREW__; __THREW__ = 0;
                 $530 = $529&1;
                 if ($530) {
                  label = 13;
                  break L18;
                 } else {
                  $V_3$0 = $490;
                  break L25;
                 }
                }
               } else {
                $70 = (($65) + 65421)|0;
                $71 = $70 & 65535;
                if ((($71|0) == 0)) {
                 __THREW__ = 0;
                 $103 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
                 $104 = __THREW__; __THREW__ = 0;
                 $105 = $104&1;
                 if ($105) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 $106 = (invoke_ii(2430,($dt|0))|0);
                 $107 = __THREW__; __THREW__ = 0;
                 $108 = $107&1;
                 if ($108) {
                  label = 13;
                  break L18;
                 }
                 $109 = ($103|0)==(1);
                 $$3 = $109 ? 1 : 2;
                 __THREW__ = 0;
                 invoke_viiii(193,0,($23|0),($106|0),($$3|0));
                 $110 = __THREW__; __THREW__ = 0;
                 $111 = $110&1;
                 if ($111) {
                  label = 13;
                  break L18;
                 } else {
                  $V_3$0 = $103;
                  break L25;
                 }
                } else if ((($71|0) == 7)) {
                 __THREW__ = 0;
                 $230 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
                 $231 = __THREW__; __THREW__ = 0;
                 $232 = $231&1;
                 if ($232) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 $233 = (invoke_ii(1199,($utc_offset|0))|0);
                 $234 = __THREW__; __THREW__ = 0;
                 $235 = $234&1;
                 if ($235) {
                  label = 13;
                  break L18;
                 }
                 if ($233) {
                  __THREW__ = 0;
                  $236 = (invoke_ii(1200,($utc_offset|0))|0);
                  $237 = tempRet0;
                  $238 = __THREW__; __THREW__ = 0;
                  $239 = $238&1;
                  if ($239) {
                   label = 13;
                   break L18;
                  } else {
                   $257 = $236;$260 = $237;
                  }
                 } else {
                  __THREW__ = 0;
                  $240 = (invoke_ii(2504,(0|0))|0);
                  $241 = __THREW__; __THREW__ = 0;
                  $242 = $241&1;
                  if ($242) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($240|0));
                  $243 = __THREW__; __THREW__ = 0;
                  $244 = $243&1;
                  if ($244) {
                   label = 13;
                   break L18;
                  }
                  ;HEAP32[$8+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$dt+12>>2]|0;
                  __THREW__ = 0;
                  invoke_viii(2112,($data$i|0),(2653200|0),($240|0));
                  $245 = __THREW__; __THREW__ = 0;
                  $246 = $245&1;
                  if ($246) {
                   label = 13;
                   break L18;
                  }
                  $247 = HEAP32[$53>>2]|0;
                  $248 = (($247) + 4|0);
                  $249 = HEAP32[$248>>2]|0;
                  $250 = HEAP32[$data$i>>2]|0;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$8+12>>2]|0;
                  $251 = (invoke_iii($249|0,($250|0),($$byval_copy15|0))|0);
                  $252 = tempRet0;
                  $253 = __THREW__; __THREW__ = 0;
                  $254 = $253&1;
                  if ($254) {
                   label = 13;
                   break L18;
                  } else {
                   $257 = $251;$260 = $252;
                  }
                 }
                 $255 = $V_10;
                 $256 = $255;
                 HEAP32[$256>>2] = $257;
                 $258 = (($255) + 4)|0;
                 $259 = $258;
                 HEAP32[$259>>2] = $260;
                 __THREW__ = 0;
                 (invoke_ii(2499,($V_10|0))|0);
                 $261 = tempRet0;
                 $262 = __THREW__; __THREW__ = 0;
                 $263 = $262&1;
                 if ($263) {
                  label = 13;
                  break L18;
                 }
                 $264 = ($261|0)<(0);
                 if ($264) {
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $269 = __THREW__; __THREW__ = 0;
                  $270 = $269&1;
                  if ($270) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(992,($23|0),45)|0);
                  $271 = __THREW__; __THREW__ = 0;
                  $272 = $271&1;
                  if ($272) {
                   label = 13;
                   break L18;
                  }
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $265 = __THREW__; __THREW__ = 0;
                  $266 = $265&1;
                  if ($266) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(992,($23|0),43)|0);
                  $267 = __THREW__; __THREW__ = 0;
                  $268 = $267&1;
                  if ($268) {
                   label = 13;
                   break L18;
                  }
                 }
                 HEAP32[$V_13>>2] = $230;
                 if ((($230|0) == 1)) {
                  __THREW__ = 0;
                  $273 = (invoke_ii(2495,($V_10|0))|0);
                  $274 = __THREW__; __THREW__ = 0;
                  $275 = $274&1;
                  if ($275) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $276 = (invoke_ii(3474,($273|0))|0);
                  $277 = __THREW__; __THREW__ = 0;
                  $278 = $277&1;
                  if ($278) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $279 = __THREW__; __THREW__ = 0;
                  $280 = $279&1;
                  if ($280) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(990,($23|0),($276|0))|0);
                  $281 = __THREW__; __THREW__ = 0;
                  $282 = $281&1;
                  if ($282) {
                   label = 13;
                   break L18;
                  } else {
                   $V_3$0 = 1;
                   break L25;
                  }
                 } else if ((($230|0) == 2)) {
                  __THREW__ = 0;
                  $283 = (invoke_ii(2495,($V_10|0))|0);
                  $284 = __THREW__; __THREW__ = 0;
                  $285 = $284&1;
                  if ($285) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $286 = (invoke_ii(3474,($283|0))|0);
                  $287 = __THREW__; __THREW__ = 0;
                  $288 = $287&1;
                  if ($288) {
                   label = 13;
                   break L18;
                  }
                  HEAP32[$V_14>>2] = $286;
                  $289 = HEAP32[3070224>>2]|0;
                  __THREW__ = 0;
                  $290 = (invoke_iii(476,($V_14|0),($289|0))|0);
                  $291 = __THREW__; __THREW__ = 0;
                  $292 = $291&1;
                  if ($292) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $293 = __THREW__; __THREW__ = 0;
                  $294 = $293&1;
                  if ($294) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(989,($23|0),($290|0))|0);
                  $295 = __THREW__; __THREW__ = 0;
                  $296 = $295&1;
                  if ($296) {
                   label = 13;
                   break L18;
                  } else {
                   $V_3$0 = 2;
                   break L25;
                  }
                 } else {
                  __THREW__ = 0;
                  $297 = (invoke_ii(2495,($V_10|0))|0);
                  $298 = __THREW__; __THREW__ = 0;
                  $299 = $298&1;
                  if ($299) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $300 = (invoke_ii(3474,($297|0))|0);
                  $301 = __THREW__; __THREW__ = 0;
                  $302 = $301&1;
                  if ($302) {
                   label = 13;
                   break L18;
                  }
                  HEAP32[$V_15>>2] = $300;
                  $303 = HEAP32[3070232>>2]|0;
                  __THREW__ = 0;
                  $304 = (invoke_iii(476,($V_15|0),($303|0))|0);
                  $305 = __THREW__; __THREW__ = 0;
                  $306 = $305&1;
                  if ($306) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $307 = __THREW__; __THREW__ = 0;
                  $308 = $307&1;
                  if ($308) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(989,($23|0),($304|0))|0);
                  $309 = __THREW__; __THREW__ = 0;
                  $310 = $309&1;
                  if ($310) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $311 = __THREW__; __THREW__ = 0;
                  $312 = $311&1;
                  if ($312) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(992,($23|0),58)|0);
                  $313 = __THREW__; __THREW__ = 0;
                  $314 = $313&1;
                  if ($314) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $315 = (invoke_ii(2497,($V_10|0))|0);
                  $316 = __THREW__; __THREW__ = 0;
                  $317 = $316&1;
                  if ($317) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $318 = (invoke_ii(3474,($315|0))|0);
                  $319 = __THREW__; __THREW__ = 0;
                  $320 = $319&1;
                  if ($320) {
                   label = 13;
                   break L18;
                  }
                  HEAP32[$V_16>>2] = $318;
                  $321 = HEAP32[3070240>>2]|0;
                  __THREW__ = 0;
                  $322 = (invoke_iii(476,($V_16|0),($321|0))|0);
                  $323 = __THREW__; __THREW__ = 0;
                  $324 = $323&1;
                  if ($324) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $325 = __THREW__; __THREW__ = 0;
                  $326 = $325&1;
                  if ($326) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(989,($23|0),($322|0))|0);
                  $327 = __THREW__; __THREW__ = 0;
                  $328 = $327&1;
                  if ($328) {
                   label = 13;
                   break L18;
                  } else {
                   $V_3$0 = $230;
                   break L25;
                  }
                 }
                } else if ((($71|0) == 1)) {
                 __THREW__ = 0;
                 $193 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
                 $194 = __THREW__; __THREW__ = 0;
                 $195 = $194&1;
                 if ($195) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 $196 = (invoke_ii(2428,($dt|0))|0);
                 $197 = __THREW__; __THREW__ = 0;
                 $198 = $197&1;
                 if ($198) {
                  label = 13;
                  break L18;
                 }
                 $199 = ($196|0)>(11);
                 if ($199) {
                  __THREW__ = 0;
                  invoke_vi(3799,($$0|0));
                  $205 = __THREW__; __THREW__ = 0;
                  $206 = $205&1;
                  if ($206) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $207 = (invoke_ii(1998,($$0|0))|0);
                  $208 = __THREW__; __THREW__ = 0;
                  $209 = $208&1;
                  if ($209) {
                   label = 13;
                   break L18;
                  } else {
                   $G_B47_0$0 = $207;
                  }
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($$0|0));
                  $200 = __THREW__; __THREW__ = 0;
                  $201 = $200&1;
                  if ($201) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $202 = (invoke_ii(1997,($$0|0))|0);
                  $203 = __THREW__; __THREW__ = 0;
                  $204 = $203&1;
                  if ($204) {
                   label = 13;
                   break L18;
                  } else {
                   $G_B47_0$0 = $202;
                  }
                 }
                 $210 = ($193|0)==(1);
                 if (!($210)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($23|0));
                  $226 = __THREW__; __THREW__ = 0;
                  $227 = $226&1;
                  if ($227) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  (invoke_iii(989,($23|0),($G_B47_0$0|0))|0);
                  $228 = __THREW__; __THREW__ = 0;
                  $229 = $228&1;
                  if ($229) {
                   label = 13;
                   break L18;
                  } else {
                   $V_3$0 = $193;
                   break L25;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($G_B47_0$0|0));
                 $211 = __THREW__; __THREW__ = 0;
                 $212 = $211&1;
                 if ($212) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 $213 = (invoke_ii(1816,($G_B47_0$0|0))|0);
                 $214 = __THREW__; __THREW__ = 0;
                 $215 = $214&1;
                 if ($215) {
                  label = 13;
                  break L18;
                 }
                 $216 = ($213|0)<(1);
                 if ($216) {
                  $V_3$0 = 1;
                  break L25;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($G_B47_0$0|0));
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 $219 = (invoke_iii(621,($G_B47_0$0|0),0)|0);
                 $220 = __THREW__; __THREW__ = 0;
                 $221 = $220&1;
                 if ($221) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($23|0));
                 $222 = __THREW__; __THREW__ = 0;
                 $223 = $222&1;
                 if ($223) {
                  label = 13;
                  break L18;
                 }
                 __THREW__ = 0;
                 (invoke_iii(992,($23|0),($219|0))|0);
                 $224 = __THREW__; __THREW__ = 0;
                 $225 = $224&1;
                 if ($225) {
                  label = 13;
                  break L18;
                 } else {
                  $V_3$0 = 1;
                  break L25;
                 }
                } else if ((($71|0) == 6)) {
                 __THREW__ = 0;
                 $531 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
                 $532 = __THREW__; __THREW__ = 0;
                 $533 = $532&1;
                 if ($533) {
                  label = 13;
                  break L18;
                 }
                 $534 = ($531|0)>(2);
                 if ($534) {
                  __THREW__ = 0;
                  invoke_vi(3799,($$0|0));
                  $554 = __THREW__; __THREW__ = 0;
                  $555 = $554&1;
                  if ($555) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $556 = (invoke_ii(2010,($$0|0))|0);
                  $557 = __THREW__; __THREW__ = 0;
                  $558 = $557&1;
                  if ($558) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($556|0));
                  $559 = __THREW__; __THREW__ = 0;
                  $560 = $559&1;
                  if ($560) {
                   label = 13;
                   break L18;
                  }
                  ;HEAP32[$1+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$dt+12>>2]|0;
                  __THREW__ = 0;
                  invoke_viii(2112,($data$i46|0),(2322880|0),($556|0));
                  $561 = __THREW__; __THREW__ = 0;
                  $562 = $561&1;
                  if ($562) {
                   label = 13;
                   break L18;
                  }
                  $563 = HEAP32[$54>>2]|0;
                  $564 = (($563) + 4|0);
                  $565 = HEAP32[$564>>2]|0;
                  $566 = HEAP32[$data$i46>>2]|0;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$1+12>>2]|0;
                  $567 = (invoke_iii($565|0,($566|0),($$byval_copy15|0))|0);
                  $568 = __THREW__; __THREW__ = 0;
                  $569 = $568&1;
                  if ($569) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_viiii(193,0,($23|0),($567|0),($531|0));
                  $570 = __THREW__; __THREW__ = 0;
                  $571 = $570&1;
                  if ($571) {
                   label = 13;
                   break L18;
                  } else {
                   $V_3$0 = $531;
                   break L25;
                  }
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($$0|0));
                  $535 = __THREW__; __THREW__ = 0;
                  $536 = $535&1;
                  if ($536) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $537 = (invoke_ii(2010,($$0|0))|0);
                  $538 = __THREW__; __THREW__ = 0;
                  $539 = $538&1;
                  if ($539) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($537|0));
                  $540 = __THREW__; __THREW__ = 0;
                  $541 = $540&1;
                  if ($541) {
                   label = 13;
                   break L18;
                  }
                  ;HEAP32[$2+0>>2]=HEAP32[$dt+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$dt+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$dt+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$dt+12>>2]|0;
                  __THREW__ = 0;
                  invoke_viii(2112,($data$i40|0),(2322880|0),($537|0));
                  $542 = __THREW__; __THREW__ = 0;
                  $543 = $542&1;
                  if ($543) {
                   label = 13;
                   break L18;
                  }
                  $544 = HEAP32[$55>>2]|0;
                  $545 = (($544) + 4|0);
                  $546 = HEAP32[$545>>2]|0;
                  $547 = HEAP32[$data$i40>>2]|0;
                  __THREW__ = 0;
                  ;HEAP32[$$byval_copy15+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy15+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$$byval_copy15+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$$byval_copy15+12>>2]=HEAP32[$2+12>>2]|0;
                  $548 = (invoke_iii($546|0,($547|0),($$byval_copy15|0))|0);
                  $549 = __THREW__; __THREW__ = 0;
                  $550 = $549&1;
                  if ($550) {
                   label = 13;
                   break L18;
                  }
                  $551 = (($548|0) % 100)&-1;
                  __THREW__ = 0;
                  invoke_viiii(193,0,($23|0),($551|0),($531|0));
                  $552 = __THREW__; __THREW__ = 0;
                  $553 = $552&1;
                  if ($553) {
                   label = 13;
                   break L18;
                  } else {
                   $V_3$0 = $531;
                   break L25;
                  }
                 }
                } else {
                 $72 = (($65) + 65502)|0;
                 $73 = $72 & 65535;
                 if ((($73|0) == 3)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($format|0));
                  $621 = __THREW__; __THREW__ = 0;
                  $622 = $621&1;
                  if ($622) {
                   label = 13;
                   break L18;
                  }
                  __THREW__ = 0;
                  $623 = (invoke_ii(1816,($format|0))|0);
                  $624 = __THREW__; __THREW__ = 0;
                  $625 = $624&1;
                  if ($625) {
                   label = 13;
                   break L18;
                  }
                  $626 = (($623) + -1)|0;
                  $627 = ($V_2$0|0)<($626|0);
                  if (!($627)) {
                   label = 237;
                   break L18;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($format|0));
                  $638 = __THREW__; __THREW__ = 0;
                  $639 = $638&1;
                  if ($639) {
                   label = 13;
                   break L18;
                  }
                  $640 = (($V_2$0) + 1)|0;
                  __THREW__ = 0;
                  $641 = (invoke_iii(621,($format|0),($640|0))|0);
                  $642 = __THREW__; __THREW__ = 0;
                  $643 = $642&1;
                  if ($643) {
                   label = 13;
                   break L18;
                  }
                  $644 = ($641<<16>>16)==(37);
                  if ($644) {
                   label = 245;
                   break L18;
                  } else {
                   $V_3$0 = 1;
                   break L25;
                  }
                 } else if ((($73|0) == 5) | (($73|0) == 0)) {
                  __THREW__ = 0;
                  $618 = (invoke_iiiii(182,0,($format|0),($V_2$0|0),($23|0))|0);
                  $619 = __THREW__; __THREW__ = 0;
                  $620 = $619&1;
                  if ($620) {
                   label = 13;
                   break L18;
                  } else {
                   $V_3$0 = $618;
                   break L25;
                  }
                 } else {
                  if ((($62<<16>>16) == 47)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($$0|0));
                   $609 = __THREW__; __THREW__ = 0;
                   $610 = $609&1;
                   if ($610) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   $611 = (invoke_ii(1999,($$0|0))|0);
                   $612 = __THREW__; __THREW__ = 0;
                   $613 = $612&1;
                   if ($613) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($23|0));
                   $614 = __THREW__; __THREW__ = 0;
                   $615 = $614&1;
                   if ($615) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   (invoke_iii(989,($23|0),($611|0))|0);
                   $616 = __THREW__; __THREW__ = 0;
                   $617 = $616&1;
                   if ($617) {
                    label = 13;
                    break L18;
                   } else {
                    $V_3$0 = 1;
                    break L25;
                   }
                  } else if ((($62<<16>>16) == 92)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($format|0));
                   $655 = __THREW__; __THREW__ = 0;
                   $656 = $655&1;
                   if ($656) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   $657 = (invoke_ii(1816,($format|0))|0);
                   $658 = __THREW__; __THREW__ = 0;
                   $659 = $658&1;
                   if ($659) {
                    label = 13;
                    break L18;
                   }
                   $660 = (($657) + -1)|0;
                   $661 = ($V_2$0|0)<($660|0);
                   if (!($661)) {
                    label = 253;
                    break L18;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($format|0));
                   $672 = __THREW__; __THREW__ = 0;
                   $673 = $672&1;
                   if ($673) {
                    label = 13;
                    break L18;
                   }
                   $674 = (($V_2$0) + 1)|0;
                   __THREW__ = 0;
                   $675 = (invoke_iii(621,($format|0),($674|0))|0);
                   $676 = __THREW__; __THREW__ = 0;
                   $677 = $676&1;
                   if ($677) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($23|0));
                   $678 = __THREW__; __THREW__ = 0;
                   $679 = $678&1;
                   if ($679) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   (invoke_iii(992,($23|0),($675|0))|0);
                   $680 = __THREW__; __THREW__ = 0;
                   $681 = $680&1;
                   if ($681) {
                    label = 13;
                    break L18;
                   } else {
                    $V_3$0 = 2;
                    break L25;
                   }
                  } else if ((($62<<16>>16) == 58)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($$0|0));
                   $600 = __THREW__; __THREW__ = 0;
                   $601 = $600&1;
                   if ($601) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   $602 = (invoke_ii(2000,($$0|0))|0);
                   $603 = __THREW__; __THREW__ = 0;
                   $604 = $603&1;
                   if ($604) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($23|0));
                   $605 = __THREW__; __THREW__ = 0;
                   $606 = $605&1;
                   if ($606) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   (invoke_iii(989,($23|0),($602|0))|0);
                   $607 = __THREW__; __THREW__ = 0;
                   $608 = $607&1;
                   if ($608) {
                    label = 13;
                    break L18;
                   } else {
                    $V_3$0 = 1;
                    break L25;
                   }
                  } else {
                   __THREW__ = 0;
                   invoke_vi(3799,($23|0));
                   $682 = __THREW__; __THREW__ = 0;
                   $683 = $682&1;
                   if ($683) {
                    label = 13;
                    break L18;
                   }
                   __THREW__ = 0;
                   (invoke_iii(992,($23|0),($62|0))|0);
                   $684 = __THREW__; __THREW__ = 0;
                   $685 = $684&1;
                   if ($685) {
                    label = 13;
                    break L18;
                   } else {
                    $V_3$0 = 1;
                    break L25;
                   }
                  }
                 }
                }
               }
              }
              }
             } while(0);
             do {
              if ((label|0) == 39) {
               label = 0;
               __THREW__ = 0;
               $112 = (invoke_iiiii(181,0,($format|0),($V_2$0|0),($62|0))|0);
               $113 = __THREW__; __THREW__ = 0;
               $114 = $113&1;
               if ($114) {
                label = 13;
                break L18;
               }
               $115 = ($112|0)<(8);
               if (!($115)) {
                label = 41;
                break L18;
               }
               __THREW__ = 0;
               $126 = (invoke_ii(2432,($dt|0))|0);
               $127 = tempRet0;
               $128 = __THREW__; __THREW__ = 0;
               $129 = $128&1;
               if ($129) {
                label = 13;
                break L18;
               }
               $130 = (___remdi3(($126|0),($127|0),10000000,0)|0);
               $131 = tempRet0;
               $132 = (7 - ($112))|0;
               $133 = (+($132|0));
               $134 = (+Math_pow(10.0,(+$133)));
               $135 = (~~$134)>>>0;
               $136 = +Math_abs($134) >= 1.0 ? $134 > 0.0 ? (Math_min(+Math_floor($134 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($134 - +(~~$134 >>> 0)) / 4294967296.0) >>> 0 : 0;
               $137 = (___divdi3(($130|0),($131|0),($135|0),($136|0))|0);
               $138 = tempRet0;
               __THREW__ = 0;
               invoke_vi(3799,($23|0));
               $139 = __THREW__; __THREW__ = 0;
               $140 = $139&1;
               if ($140) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               $141 = (invoke_ii(2398,($23|0))|0);
               $142 = __THREW__; __THREW__ = 0;
               $143 = $142&1;
               if ($143) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               invoke_viiii(193,0,($23|0),($137|0),($112|0));
               $144 = __THREW__; __THREW__ = 0;
               $145 = $144&1;
               if ($145) {
                label = 13;
                break L18;
               }
               if (!($V_4$0$off0)) {
                $V_3$0 = $112;
                break;
               }
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $154 = __THREW__; __THREW__ = 0;
                $155 = $154&1;
                if ($155) {
                 label = 12;
                 break L18;
                }
                __THREW__ = 0;
                $156 = (invoke_ii(2398,($23|0))|0);
                $157 = __THREW__; __THREW__ = 0;
                $158 = $157&1;
                if ($158) {
                 label = 12;
                 break L18;
                }
                $159 = ($156|0)>($141|0);
                if (!($159)) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $160 = __THREW__; __THREW__ = 0;
                $161 = $160&1;
                if ($161) {
                 label = 12;
                 break L18;
                }
                __THREW__ = 0;
                $162 = (invoke_ii(2398,($23|0))|0);
                $163 = __THREW__; __THREW__ = 0;
                $164 = $163&1;
                if ($164) {
                 label = 12;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $165 = __THREW__; __THREW__ = 0;
                $166 = $165&1;
                if ($166) {
                 label = 12;
                 break L18;
                }
                $167 = (($162) + -1)|0;
                __THREW__ = 0;
                $168 = (invoke_iii(988,($23|0),($167|0))|0);
                $169 = __THREW__; __THREW__ = 0;
                $170 = $169&1;
                if ($170) {
                 label = 12;
                 break L18;
                }
                $171 = ($168<<16>>16)==(48);
                if (!($171)) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $172 = __THREW__; __THREW__ = 0;
                $173 = $172&1;
                if ($173) {
                 label = 12;
                 break L18;
                }
                __THREW__ = 0;
                $146 = (invoke_ii(2398,($23|0))|0);
                $147 = __THREW__; __THREW__ = 0;
                $148 = $147&1;
                if ($148) {
                 label = 12;
                 break L18;
                }
                __THREW__ = 0;
                invoke_vi(3799,($23|0));
                $149 = __THREW__; __THREW__ = 0;
                $150 = $149&1;
                if ($150) {
                 label = 12;
                 break L18;
                }
                $151 = (($146) + -1)|0;
                __THREW__ = 0;
                invoke_vii(1912,($23|0),($151|0));
                $152 = __THREW__; __THREW__ = 0;
                $153 = $152&1;
                if ($153) {
                 label = 12;
                 break L18;
                }
               }
               $174 = ($137|0)!=(0);
               $175 = ($141|0)<(1);
               $or$cond = $174 | $175;
               if ($or$cond) {
                $V_3$0 = $112;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($23|0));
               $176 = __THREW__; __THREW__ = 0;
               $177 = $176&1;
               if ($177) {
                label = 13;
                break L18;
               }
               $178 = (($141) + -1)|0;
               __THREW__ = 0;
               $179 = (invoke_iii(988,($23|0),($178|0))|0);
               $180 = __THREW__; __THREW__ = 0;
               $181 = $180&1;
               if ($181) {
                label = 13;
                break L18;
               }
               $182 = ($179<<16>>16)==(46);
               if (!($182)) {
                $V_3$0 = $112;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($23|0));
               $183 = __THREW__; __THREW__ = 0;
               $184 = $183&1;
               if ($184) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               $185 = (invoke_ii(2398,($23|0))|0);
               $186 = __THREW__; __THREW__ = 0;
               $187 = $186&1;
               if ($187) {
                label = 13;
                break L18;
               }
               __THREW__ = 0;
               invoke_vi(3799,($23|0));
               $188 = __THREW__; __THREW__ = 0;
               $189 = $188&1;
               if ($189) {
                label = 13;
                break L18;
               }
               $190 = (($185) + -1)|0;
               __THREW__ = 0;
               invoke_vii(1912,($23|0),($190|0));
               $191 = __THREW__; __THREW__ = 0;
               $192 = $191&1;
               if ($192) {
                label = 13;
                break L18;
               } else {
                $V_3$0 = $112;
               }
              }
             } while(0);
             $686 = (($V_3$0) + ($V_2$0))|0;
             $V_2$0 = $686;
            }
            if ((label|0) == 12) {
             $39 = ___cxa_find_matching_catch()|0;
             $40 = tempRet0;
             $lpad$phi$index = $39;$lpad$phi$index3 = $40;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            else if ((label|0) == 13) {
             $41 = ___cxa_find_matching_catch()|0;
             $42 = tempRet0;
             $lpad$phi$index = $41;$lpad$phi$index3 = $42;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            else if ((label|0) == 41) {
             __THREW__ = 0;
             (invoke_ii(2996,(2603176|0))|0);
             $116 = __THREW__; __THREW__ = 0;
             $117 = $116&1;
             if ($117) {
              break;
             }
             __THREW__ = 0;
             $118 = (invoke_ii(3469,(2603176|0))|0);
             $119 = __THREW__; __THREW__ = 0;
             $120 = $119&1;
             if ($120) {
              break;
             }
             $121 = HEAP32[3070216>>2]|0;
             __THREW__ = 0;
             invoke_vii(1940,($118|0),($121|0));
             $122 = __THREW__; __THREW__ = 0;
             $123 = $122&1;
             if ($123) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3838,($118|0));
             $124 = __THREW__; __THREW__ = 0;
             $125 = $124&1;
             if ($125) {
              break;
             }
             // unreachable;
            }
            else if ((label|0) == 237) {
             __THREW__ = 0;
             (invoke_ii(2996,(2603176|0))|0);
             $628 = __THREW__; __THREW__ = 0;
             $629 = $628&1;
             if ($629) {
              break;
             }
             __THREW__ = 0;
             $630 = (invoke_ii(3469,(2603176|0))|0);
             $631 = __THREW__; __THREW__ = 0;
             $632 = $631&1;
             if ($632) {
              break;
             }
             $633 = HEAP32[3070264>>2]|0;
             __THREW__ = 0;
             invoke_vii(1940,($630|0),($633|0));
             $634 = __THREW__; __THREW__ = 0;
             $635 = $634&1;
             if ($635) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3838,($630|0));
             $636 = __THREW__; __THREW__ = 0;
             $637 = $636&1;
             if ($637) {
              break;
             }
             // unreachable;
            }
            else if ((label|0) == 245) {
             __THREW__ = 0;
             (invoke_ii(2996,(2603176|0))|0);
             $645 = __THREW__; __THREW__ = 0;
             $646 = $645&1;
             if ($646) {
              break;
             }
             __THREW__ = 0;
             $647 = (invoke_ii(3469,(2603176|0))|0);
             $648 = __THREW__; __THREW__ = 0;
             $649 = $648&1;
             if ($649) {
              break;
             }
             $650 = HEAP32[3070272>>2]|0;
             __THREW__ = 0;
             invoke_vii(1940,($647|0),($650|0));
             $651 = __THREW__; __THREW__ = 0;
             $652 = $651&1;
             if ($652) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3838,($647|0));
             $653 = __THREW__; __THREW__ = 0;
             $654 = $653&1;
             if ($654) {
              break;
             }
             // unreachable;
            }
            else if ((label|0) == 253) {
             __THREW__ = 0;
             (invoke_ii(2996,(2603176|0))|0);
             $662 = __THREW__; __THREW__ = 0;
             $663 = $662&1;
             if ($663) {
              break;
             }
             __THREW__ = 0;
             $664 = (invoke_ii(3469,(2603176|0))|0);
             $665 = __THREW__; __THREW__ = 0;
             $666 = $665&1;
             if ($666) {
              break;
             }
             $667 = HEAP32[3070280>>2]|0;
             __THREW__ = 0;
             invoke_vii(1940,($664|0),($667|0));
             $668 = __THREW__; __THREW__ = 0;
             $669 = $668&1;
             if ($669) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3838,($664|0));
             $670 = __THREW__; __THREW__ = 0;
             $671 = $670&1;
             if ($671) {
              break;
             }
             // unreachable;
            }
            else if ((label|0) == 269) {
             __THREW__ = 0;
             invoke_vi(3799,($23|0));
             $695 = __THREW__; __THREW__ = 0;
             $696 = $695&1;
             if ($696) {
              break;
             }
             __THREW__ = 0;
             $697 = (invoke_iii(2730,(2535432|0),($23|0))|0);
             $698 = __THREW__; __THREW__ = 0;
             $699 = $698&1;
             if ($699) {
              break;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($697|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $43 = ___cxa_find_matching_catch()|0;
 $44 = tempRet0;
 $lpad$phi$index = $43;$lpad$phi$index3 = $44;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_DateTimeOffset_m_get_DateTimeP30mscorlib_System_DateTimeOffset($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2593320);
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 invoke_viiii(188,($agg$result|0),0,($tmpcast$byval_copy|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN14ActionInvoker1I30mscorlib_System_DateTimeTraitsE6InvokeEPFvPv24mscorlib_System_DateTimeES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I30mscorlib_System_DateTimeTraits30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPv24mscorlib_System_DateTime24mscorlib_System_TimeSpanES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 40|0;
 $$byval_copy = sp;
 $0 = sp + 16|0;
 $1 = sp + 32|0;
 $2 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $1;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$$byval_copy,$$byval_copy1);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int64Traits30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPvx24mscorlib_System_TimeSpanES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $0;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$4,$7,$$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits36mscorlib_System_DateTimeOffsetTraitsE6InvokeEPFbPv30mscorlib_System_DateTimeOffsetES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 24|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z43mscorlib_System_DateTimeUtils_m_CountRepeatP22mscorlib_System_ObjectP22mscorlib_System_Stringit($__this,$fmt,$p,$c) {
 $__this = $__this|0;
 $fmt = $fmt|0;
 $p = $p|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $V_1$0$in = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2594232);
 __THREW__ = 0;
 invoke_vi(3799,($fmt|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1816,($fmt|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $V_1$0$in = $p;
   while(1) {
    $V_1$0 = (($V_1$0$in) + 1)|0;
    $9 = ($V_1$0|0)<($2|0);
    if (!($9)) {
     label = 10;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($fmt|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     label = 3;
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_iii(621,($fmt|0),($V_1$0|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 3;
     break;
    }
    $15 = ($12<<16>>16)==($c<<16>>16);
    if ($15) {
     $V_1$0$in = $V_1$0;
    } else {
     label = 10;
     break;
    }
   }
   if ((label|0) == 3) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    $lpad$phi$index = $5;$lpad$phi$index2 = $6;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   else if ((label|0) == 10) {
    $16 = (($V_1$0) - ($p))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_DateTimeUtils_m_ZeroPadP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderii($__this,$output,$digits,$len) {
 $__this = $__this|0;
 $output = $output|0;
 $digits = $digits|0;
 $len = $len|0;
 var $$0 = 0, $$01 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $V_1$1$lcssa = 0, $V_1$12 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2594280);
 $0 = sp + 8|0;
 $$0 = $digits;$$01 = $len;$V_1$0 = 16;
 while(1) {
  $1 = (($V_1$0) + -1)|0;
  $2 = $1 << 1;
  $3 = (($0) + ($2)|0);
  $4 = (($$0|0) % 10)&-1;
  $5 = (($4) + 48)|0;
  $6 = $5&65535;
  HEAP16[$3>>1] = $6;
  $7 = (($$0|0) / 10)&-1;
  $8 = (($$01) + -1)|0;
  $9 = ($$0|0)>(9);
  if ($9) {
   $$0 = $7;$$01 = $8;$V_1$0 = $1;
  } else {
   break;
  }
 }
 $10 = ($8|0)>(0);
 if ($10) {
  $$13 = $8;$V_1$12 = $1;
  while(1) {
   $11 = (($$13) + -1)|0;
   $12 = (($V_1$12) + -1)|0;
   $13 = $12 << 1;
   $14 = (($0) + ($13)|0);
   HEAP16[$14>>1] = 48;
   $15 = ($11|0)>(0);
   if ($15) {
    $$13 = $11;$V_1$12 = $12;
   } else {
    break;
   }
  }
  $16 = (16 - ($len))|0;
  $V_1$1$lcssa = $16;
 } else {
  $V_1$1$lcssa = $1;
 }
 $17 = (16 - ($V_1$1$lcssa))|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  __THREW__ = 0;
  $20 = (invoke_ii(3469,(2191608|0))|0);
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __THREW__ = 0;
   $23 = (invoke_iiiii(103,($20|0),($0|0),($V_1$1$lcssa|0),($17|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    __THREW__ = 0;
    invoke_vi(3799,($output|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __THREW__ = 0;
     (invoke_iii(989,($output|0),($23|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($30|0);
 // unreachable;
}
function __Z49mscorlib_System_DateTimeUtils_m_ParseQuotedStringP22mscorlib_System_ObjectP22mscorlib_System_StringiP34mscorlib_System_Text_StringBuilder($__this,$fmt,$pos,$output) {
 $__this = $__this|0;
 $fmt = $fmt|0;
 $pos = $pos|0;
 $output = $output|0;
 var $$0$be = 0, $$05 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2594328);
 __THREW__ = 0;
 invoke_v(881);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($fmt|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(1816,($fmt|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($fmt|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = (($pos) + 1)|0;
      __THREW__ = 0;
      $10 = (invoke_iii(621,($fmt|0),($pos|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       $13 = ($9|0)<($4|0);
       L7: do {
        if ($13) {
         $$05 = $9;
         while(1) {
          $23 = (($$05) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($fmt|0));
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           label = 8;
           break;
          }
          __THREW__ = 0;
          $18 = (invoke_iii(621,($fmt|0),($$05|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if ($20) {
           label = 8;
           break;
          }
          $21 = ($18<<16>>16)==($10<<16>>16);
          if ($21) {
           label = 13;
           break;
          }
          $24 = ($18<<16>>16)==(92);
          if ($24) {
           $25 = ($23|0)<($4|0);
           if (!($25)) {
            label = 16;
            break;
           }
           $36 = (($$05) + 2)|0;
           __THREW__ = 0;
           invoke_vi(3799,($fmt|0));
           $37 = __THREW__; __THREW__ = 0;
           $38 = $37&1;
           if ($38) {
            label = 8;
            break;
           }
           __THREW__ = 0;
           $39 = (invoke_iii(621,($fmt|0),($23|0))|0);
           $40 = __THREW__; __THREW__ = 0;
           $41 = $40&1;
           if ($41) {
            label = 8;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($output|0));
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if ($43) {
            label = 8;
            break;
           }
           __THREW__ = 0;
           (invoke_iii(992,($output|0),($39|0))|0);
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            label = 8;
            break;
           } else {
            $$0$be = $36;
           }
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($output|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if ($48) {
            label = 8;
            break;
           }
           __THREW__ = 0;
           (invoke_iii(992,($output|0),($18|0))|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            label = 8;
            break;
           } else {
            $$0$be = $23;
           }
          }
          $46 = ($$0$be|0)<($4|0);
          if ($46) {
           $$05 = $$0$be;
          } else {
           break L7;
          }
         }
         if ((label|0) == 8) {
          $14 = ___cxa_find_matching_catch()|0;
          $15 = tempRet0;
          $lpad$phi$index = $14;$lpad$phi$index2 = $15;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         else if ((label|0) == 13) {
          $22 = (($23) - ($pos))|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($22|0);
         }
         else if ((label|0) == 16) {
          __THREW__ = 0;
          (invoke_ii(2996,(2603176|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if ($27) {
           break L1;
          }
          __THREW__ = 0;
          $28 = (invoke_ii(3469,(2603176|0))|0);
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if ($30) {
           break L1;
          }
          $31 = HEAP32[3070128>>2]|0;
          __THREW__ = 0;
          invoke_vii(1940,($28|0),($31|0));
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if ($33) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3838,($28|0));
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if ($35) {
           break L1;
          }
          // unreachable;
         }
        }
       } while(0);
       __THREW__ = 0;
       (invoke_ii(2996,(2603176|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if (!($54)) {
        __THREW__ = 0;
        $55 = (invoke_ii(3469,(2603176|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if (!($57)) {
         $58 = HEAP32[3070136>>2]|0;
         __THREW__ = 0;
         invoke_vii(1940,($55|0),($58|0));
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if (!($60)) {
          __THREW__ = 0;
          invoke_vi(3838,($55|0));
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 $lpad$phi$index = $16;$lpad$phi$index2 = $17;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_26mscorlib_System_CharTraitsE6InvokeEPFiPvS4_itES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP16[$5>>1]|0;
 $7 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$6)|0);
 HEAP32[$ret>>2] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraits26mscorlib_System_CharTraitsS0_S0_S0_E6InvokeEPFPvS3_tS3_S3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$1,$3,$5,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker5I17VoidPointerTraits26mscorlib_System_CharTraitsS0_S0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_tS4_S4_S4_bES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 $12 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$1,$3,$5,$7,$11)|0);
 STACKTOP = sp;return ($12|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraits30mscorlib_System_DateTimeTraitsS0_S0_E6InvokeEPFPvS3_24mscorlib_System_DateTimeS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$$byval_copy,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraits30mscorlib_System_DateTimeTraits57mscorlib_System_Nullable_1_mscorlib_System_TimeSpanTraitsS0_S0_E6InvokeEPFPvS4_24mscorlib_System_DateTime51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $$byval_copy = sp;
 $0 = sp + 16|0;
 $1 = sp + 32|0;
 $2 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$4+12>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$1+12>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$$byval_copy,$$byval_copy1,$6,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __Z56mscorlib_System_DayOfWeek_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z65mscorlib_System_DelegateSerializationHolder_DelegateEntry_m__ctorP57mscorlib_System_DelegateSerializationHolder_DelegateEntryP24mscorlib_System_DelegateP22mscorlib_System_String($__this,$del,$targetLabel) {
 $__this = $__this|0;
 $del = $del|0;
 $targetLabel = $targetLabel|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2596112);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(3799,($del|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(1782,($del|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_iii(2730,(2150320|0),($4|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($__this) + 8|0);
       HEAP32[$12>>2] = $9;
       __THREW__ = 0;
       invoke_vi(3799,($del|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        __THREW__ = 0;
        $15 = (invoke_ii(1782,($del|0))|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if (!($17)) {
         __THREW__ = 0;
         invoke_vi(3799,($15|0));
         $18 = __THREW__; __THREW__ = 0;
         $19 = $18&1;
         if (!($19)) {
          __THREW__ = 0;
          $20 = (invoke_iii(2730,(2238288|0),($15|0))|0);
          $21 = __THREW__; __THREW__ = 0;
          $22 = $21&1;
          if (!($22)) {
           __THREW__ = 0;
           invoke_vi(3799,($20|0));
           $23 = __THREW__; __THREW__ = 0;
           $24 = $23&1;
           if (!($24)) {
            __THREW__ = 0;
            $25 = (invoke_iii(2730,(2370792|0),($20|0))|0);
            $26 = __THREW__; __THREW__ = 0;
            $27 = $26&1;
            if (!($27)) {
             $28 = (($__this) + 12|0);
             HEAP32[$28>>2] = $25;
             $29 = (($__this) + 16|0);
             HEAP32[$29>>2] = $targetLabel;
             __THREW__ = 0;
             invoke_vi(3799,($del|0));
             $30 = __THREW__; __THREW__ = 0;
             $31 = $30&1;
             if (!($31)) {
              __THREW__ = 0;
              $32 = (invoke_ii(1841,($del|0))|0);
              $33 = __THREW__; __THREW__ = 0;
              $34 = $33&1;
              if (!($34)) {
               __THREW__ = 0;
               invoke_vi(3799,($32|0));
               $35 = __THREW__; __THREW__ = 0;
               $36 = $35&1;
               if (!($36)) {
                __THREW__ = 0;
                $37 = (invoke_iii(2730,(2242504|0),($32|0))|0);
                $38 = __THREW__; __THREW__ = 0;
                $39 = $38&1;
                if (!($39)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($37|0));
                 $40 = __THREW__; __THREW__ = 0;
                 $41 = $40&1;
                 if (!($41)) {
                  __THREW__ = 0;
                  $42 = (invoke_iii(2730,(2238288|0),($37|0))|0);
                  $43 = __THREW__; __THREW__ = 0;
                  $44 = $43&1;
                  if (!($44)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($42|0));
                   $45 = __THREW__; __THREW__ = 0;
                   $46 = $45&1;
                   if (!($46)) {
                    __THREW__ = 0;
                    $47 = (invoke_iii(2730,(2370792|0),($42|0))|0);
                    $48 = __THREW__; __THREW__ = 0;
                    $49 = $48&1;
                    if (!($49)) {
                     $50 = (($__this) + 20|0);
                     HEAP32[$50>>2] = $47;
                     __THREW__ = 0;
                     invoke_vi(3799,($del|0));
                     $51 = __THREW__; __THREW__ = 0;
                     $52 = $51&1;
                     if ($52) {
                      break;
                     }
                     __THREW__ = 0;
                     $53 = (invoke_ii(1841,($del|0))|0);
                     $54 = __THREW__; __THREW__ = 0;
                     $55 = $54&1;
                     if ($55) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($53|0));
                     $56 = __THREW__; __THREW__ = 0;
                     $57 = $56&1;
                     if ($57) {
                      break;
                     }
                     __THREW__ = 0;
                     $58 = (invoke_iii(2730,(2242504|0),($53|0))|0);
                     $59 = __THREW__; __THREW__ = 0;
                     $60 = $59&1;
                     if ($60) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($58|0));
                     $61 = __THREW__; __THREW__ = 0;
                     $62 = $61&1;
                     if ($62) {
                      break;
                     }
                     __THREW__ = 0;
                     $63 = (invoke_iii(2730,(2150320|0),($58|0))|0);
                     $64 = __THREW__; __THREW__ = 0;
                     $65 = $64&1;
                     if ($65) {
                      break;
                     }
                     $66 = (($__this) + 24|0);
                     HEAP32[$66>>2] = $63;
                     __THREW__ = 0;
                     invoke_vi(3799,($del|0));
                     $67 = __THREW__; __THREW__ = 0;
                     $68 = $67&1;
                     if ($68) {
                      break;
                     }
                     __THREW__ = 0;
                     $69 = (invoke_ii(1841,($del|0))|0);
                     $70 = __THREW__; __THREW__ = 0;
                     $71 = $70&1;
                     if ($71) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($69|0));
                     $72 = __THREW__; __THREW__ = 0;
                     $73 = $72&1;
                     if ($73) {
                      break;
                     }
                     __THREW__ = 0;
                     $74 = (invoke_iii(2730,(2233608|0),($69|0))|0);
                     $75 = __THREW__; __THREW__ = 0;
                     $76 = $75&1;
                     if ($76) {
                      break;
                     }
                     $77 = (($__this) + 28|0);
                     HEAP32[$77>>2] = $74;
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $78 = ___cxa_find_matching_catch()|0;
 $79 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($78|0);
 // unreachable;
}
function __Z61mscorlib_System_DelegateSerializationHolder_m_GetDelegateDataP22mscorlib_System_ObjectP24mscorlib_System_DelegateP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$instance,$info,$ctx) {
 $__this = $__this|0;
 $instance = $instance|0;
 $info = $info|0;
 $ctx = $ctx|0;
 var $$byval_copy = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $G_B4_0$0 = 0, $L_4 = 0, $V_1$0 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 12|0;
 $_stackTraceSentry = sp;
 $L_4 = sp + 4|0;
 $0 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2596672);
 __THREW__ = 0;
 invoke_v(882);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($instance|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2213528|0),($instance|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($5) + 12|0);
    $V_1$0 = 0;$V_2$0 = 0;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      label = 5;
      break;
     }
     $75 = HEAP32[$8>>2]|0;
     $76 = ($V_2$0|0)<($75|0);
     if (!($76)) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      label = 5;
      break;
     }
     $13 = HEAP32[$8>>2]|0;
     $14 = ($V_2$0>>>0)<($13>>>0);
     if (!($14)) {
      __THREW__ = 0;
      $15 = (invoke_i(132)|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($15|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       label = 5;
       break;
      }
     }
     $20 = HEAP32[$5>>2]|0;
     $21 = (($20) + 92|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = Math_imul($22, $V_2$0)|0;
     $$sum = (($23) + 16)|0;
     $24 = (($5) + ($$sum)|0);
     $25 = HEAP32[$24>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($25|0));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      label = 5;
      break;
     }
     __THREW__ = 0;
     $28 = (invoke_ii(1842,($25|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      label = 5;
      break;
     }
     $31 = ($28|0)==(0|0);
     if ($31) {
      $G_B4_0$0 = 0;
     } else {
      HEAP32[$L_4>>2] = $V_2$0;
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_iii(2724,(2155952|0),($L_4|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       label = 5;
       break;
      }
      $37 = HEAP32[3070504>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_iiii(559,(0|0),($37|0),($34|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 5;
       break;
      } else {
       $G_B4_0$0 = $38;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2596536|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 5;
      break;
     }
     __THREW__ = 0;
     $43 = (invoke_ii(3469,(2596536|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      label = 5;
      break;
     }
     __THREW__ = 0;
     invoke_viii(669,($43|0),($25|0),($G_B4_0$0|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 5;
      break;
     }
     $48 = ($V_1$0|0)==(0|0);
     if ($48) {
      __THREW__ = 0;
      invoke_vi(3799,($info|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 5;
       break;
      }
      $51 = HEAP32[3070512>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($51|0),($43|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 5;
       break;
      }
     } else {
      __THREW__ = 0;
      invoke_vi(3799,($V_1$0|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 5;
       break;
      }
      $56 = (($V_1$0) + 32|0);
      HEAP32[$56>>2] = $43;
     }
     __THREW__ = 0;
     invoke_vi(3799,($25|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      label = 5;
      break;
     }
     __THREW__ = 0;
     $59 = (invoke_ii(1842,($25|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 5;
      break;
     }
     $62 = ($59|0)==(0|0);
     if (!($62)) {
      __THREW__ = 0;
      invoke_vi(3799,($25|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      $65 = (invoke_ii(1842,($25|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($info|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 5;
       break;
      }
      __THREW__ = 0;
      invoke_viii(621,($info|0),($G_B4_0$0|0),($65|0));
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 5;
       break;
      }
     }
     $72 = (($V_2$0) + 1)|0;
     $V_1$0 = $43;$V_2$0 = $72;
    }
    if ((label|0) == 5) {
     $9 = ___cxa_find_matching_catch()|0;
     $10 = tempRet0;
     $lpad$phi$index = $9;$lpad$phi$index2 = $10;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    HEAP32[$0>>2] = 2641384;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $79 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if (!($81)) {
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if (!($83)) {
      __THREW__ = 0;
      invoke_vii(1897,($info|0),($79|0));
      $84 = __THREW__; __THREW__ = 0;
      $85 = $84&1;
      if (!($85)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 $lpad$phi$index = $11;$lpad$phi$index2 = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z59mscorlib_System_DelegateSerializationHolder_m_GetObjectDataP43mscorlib_System_DelegateSerializationHolderP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2596720);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3838,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z66mscorlib_System_NotSupportedException_m__ctor_mscorlib_System_VoidP37mscorlib_System_NotSupportedException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2622504);
 __THREW__ = 0;
 invoke_v(883);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3074120>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233067);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZN14ActionInvoker3I17VoidPointerTraitsS0_60mscorlib_System_Runtime_Serialization_StreamingContextTraitsE6InvokeEPFvPvS3_S3_54mscorlib_System_Runtime_Serialization_StreamingContextES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $0;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$3,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z45mscorlib_System_DivideByZeroException_m__ctorP37mscorlib_System_DivideByZeroException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2597104);
 __THREW__ = 0;
 invoke_v(884);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3070560>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1927,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2147352558);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z68mscorlib_System_DivideByZeroException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z44mscorlib_System_DllNotFoundException_m__ctorP36mscorlib_System_DllNotFoundException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2597440);
 __THREW__ = 0;
 invoke_v(885);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3070608>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1977,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233052);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z67mscorlib_System_DllNotFoundException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z51mscorlib_System_EntryPointNotFoundException_m__ctorP43mscorlib_System_EntryPointNotFoundException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2597808);
 __THREW__ = 0;
 invoke_v(886);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3070656>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1977,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233053);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z74mscorlib_System_EntryPointNotFoundException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z50mscorlib_System_MonoEnumInfo_SByteComparer_m__ctorP42mscorlib_System_MonoEnumInfo_SByteComparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2598184);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z120mscorlib_System_MonoEnumInfo_SByteComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP42mscorlib_System_MonoEnumInfo_SByteComparerP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2598232);
 __THREW__ = 0;
 (invoke_ii(2996,(2171616|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2770,($x|0),(2171616|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP8[$2>>0]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2171616|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2770,($y|0),(2171616|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP8[$8>>0]|0;
     $12 = $5&255;
     $13 = $11&255;
     $14 = (($12) - ($13))|0;
     $15 = $14 & 255;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($15|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z118mscorlib_System_MonoEnumInfo_SByteComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_SByte_mscorlib_System_SByteP42mscorlib_System_MonoEnumInfo_SByteCompareraa($__this,$ix,$iy) {
 $__this = $__this|0;
 $ix = $ix|0;
 $iy = $iy|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2598280);
 $0 = $ix&255;
 $1 = $iy&255;
 $2 = (($0) - ($1))|0;
 $3 = $2 & 255;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits27mscorlib_System_SByteTraitsS1_E6InvokeEPFiPvaaES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z50mscorlib_System_MonoEnumInfo_ShortComparer_m__ctorP42mscorlib_System_MonoEnumInfo_ShortComparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2598624);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z120mscorlib_System_MonoEnumInfo_ShortComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP42mscorlib_System_MonoEnumInfo_ShortComparerP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2598672);
 __THREW__ = 0;
 (invoke_ii(2996,(2173776|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2770,($x|0),(2173776|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP16[$2>>1]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2173776|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2770,($y|0),(2173776|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP16[$8>>1]|0;
     $12 = $5&65535;
     $13 = $11&65535;
     $14 = (($12) - ($13))|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($14|0);
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z118mscorlib_System_MonoEnumInfo_ShortComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Int16_mscorlib_System_Int16P42mscorlib_System_MonoEnumInfo_ShortComparerss($__this,$ix,$iy) {
 $__this = $__this|0;
 $ix = $ix|0;
 $iy = $iy|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2598720);
 $0 = $ix&65535;
 $1 = $iy&65535;
 $2 = (($0) - ($1))|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits27mscorlib_System_Int16TraitsS1_E6InvokeEPFiPvssES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$4)|0);
 HEAP32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z48mscorlib_System_MonoEnumInfo_IntComparer_m__ctorP40mscorlib_System_MonoEnumInfo_IntComparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2599064);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z118mscorlib_System_MonoEnumInfo_IntComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP40mscorlib_System_MonoEnumInfo_IntComparerP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2599112);
 __THREW__ = 0;
 (invoke_ii(2996,(2155952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2770,($x|0),(2155952|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2770,($y|0),(2155952|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[$8>>2]|0;
     $12 = ($5|0)==($11|0);
     if ($12) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $15 = ($5|0)<($11|0);
     $$ = $15 ? -1 : 1;
     $$0 = $$;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z116mscorlib_System_MonoEnumInfo_IntComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P40mscorlib_System_MonoEnumInfo_IntComparerii($__this,$ix,$iy) {
 $__this = $__this|0;
 $ix = $ix|0;
 $iy = $iy|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2599160);
 $0 = ($ix|0)==($iy|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = ($ix|0)<($iy|0);
  $$ = $1 ? -1 : 1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z49mscorlib_System_MonoEnumInfo_LongComparer_m__ctorP41mscorlib_System_MonoEnumInfo_LongComparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2599504);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z119mscorlib_System_MonoEnumInfo_LongComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP41mscorlib_System_MonoEnumInfo_LongComparerP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2599552);
 __THREW__ = 0;
 (invoke_ii(2996,(2162248|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2770,($x|0),(2162248|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $2;
   $6 = $5;
   $7 = HEAP32[$6>>2]|0;
   $8 = (($5) + 4)|0;
   $9 = $8;
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2162248|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    $13 = (invoke_iii(2770,($y|0),(2162248|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = $13;
     $17 = $16;
     $18 = HEAP32[$17>>2]|0;
     $19 = (($16) + 4)|0;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = ($7|0)==($18|0);
     $23 = ($10|0)==($21|0);
     $24 = $22 & $23;
     if ($24) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = ($10|0)<($21|0);
     $28 = ($10|0)==($21|0);
     $29 = ($7>>>0)<($18>>>0);
     $30 = $28 & $29;
     $31 = $27 | $30;
     $$ = $31 ? -1 : 1;
     $$0 = $$;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($25|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_MonoEnumInfo_LongComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Int64_mscorlib_System_Int64P41mscorlib_System_MonoEnumInfo_LongComparerxx($__this,$0,$1,$2,$3) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $$ = 0, $$0 = 0, $10 = 0, $11 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2599600);
 $4 = ($0|0)==($2|0);
 $5 = ($1|0)==($3|0);
 $6 = $4 & $5;
 if ($6) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ($1|0)<($3|0);
 $8 = ($1|0)==($3|0);
 $9 = ($0>>>0)<($2>>>0);
 $10 = $8 & $9;
 $11 = $7 | $10;
 $$ = $11 ? -1 : 1;
 $$0 = $$;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN12FuncInvoker2I27mscorlib_System_Int32Traits27mscorlib_System_Int64TraitsS1_E6InvokeEPFiPvxxES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$3,$6,$11,$14)|0);
 HEAP32[$ret>>2] = $15;
 $16 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($16|0);
}
function __Z36mscorlib_System_MonoEnumInfo_m__ctorP28mscorlib_System_MonoEnumInfoS_($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2599944);
 $0 = HEAP32[$other>>2]|0;
 HEAP32[$__this>>2] = $0;
 $1 = (($other) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (($other) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($__this) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = (($other) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 12|0);
 HEAP32[$9>>2] = $8;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z37mscorlib_System_MonoEnumInfo_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2599992);
 __THREW__ = 0;
 (invoke_ii(2996,(2598488|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(3469,(2598488|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(2710,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2600920|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = HEAP32[((2600920 + 80|0))>>2]|0;
      $10 = (($9) + 8|0);
      HEAP32[$10>>2] = $2;
      __THREW__ = 0;
      (invoke_ii(2996,(2598928|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_ii(3469,(2598928|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(2711,($13|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if (!($17)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2600920|0))|0);
         $18 = __THREW__; __THREW__ = 0;
         $19 = $18&1;
         if (!($19)) {
          $20 = HEAP32[((2600920 + 80|0))>>2]|0;
          $21 = (($20) + 12|0);
          HEAP32[$21>>2] = $13;
          __THREW__ = 0;
          (invoke_ii(2996,(2599368|0))|0);
          $22 = __THREW__; __THREW__ = 0;
          $23 = $22&1;
          if (!($23)) {
           __THREW__ = 0;
           $24 = (invoke_ii(3469,(2599368|0))|0);
           $25 = __THREW__; __THREW__ = 0;
           $26 = $25&1;
           if (!($26)) {
            __THREW__ = 0;
            invoke_vi(2712,($24|0));
            $27 = __THREW__; __THREW__ = 0;
            $28 = $27&1;
            if (!($28)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $29 = __THREW__; __THREW__ = 0;
             $30 = $29&1;
             if (!($30)) {
              $31 = HEAP32[((2600920 + 80|0))>>2]|0;
              $32 = (($31) + 16|0);
              HEAP32[$32>>2] = $24;
              __THREW__ = 0;
              (invoke_ii(2996,(2599808|0))|0);
              $33 = __THREW__; __THREW__ = 0;
              $34 = $33&1;
              if (!($34)) {
               __THREW__ = 0;
               $35 = (invoke_ii(3469,(2599808|0))|0);
               $36 = __THREW__; __THREW__ = 0;
               $37 = $36&1;
               if (!($37)) {
                __THREW__ = 0;
                invoke_vi(2713,($35|0));
                $38 = __THREW__; __THREW__ = 0;
                $39 = $38&1;
                if (!($39)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2600920|0))|0);
                 $40 = __THREW__; __THREW__ = 0;
                 $41 = $40&1;
                 if (!($41)) {
                  $42 = HEAP32[((2600920 + 80|0))>>2]|0;
                  $43 = (($42) + 20|0);
                  HEAP32[$43>>2] = $35;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2149728|0))|0);
                  $44 = __THREW__; __THREW__ = 0;
                  $45 = $44&1;
                  if (!($45)) {
                   __THREW__ = 0;
                   $46 = (invoke_ii(3469,(2149728|0))|0);
                   $47 = __THREW__; __THREW__ = 0;
                   $48 = $47&1;
                   if (!($48)) {
                    __THREW__ = 0;
                    invoke_vi(1924,($46|0));
                    $49 = __THREW__; __THREW__ = 0;
                    $50 = $49&1;
                    if (!($50)) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2600920|0))|0);
                     $51 = __THREW__; __THREW__ = 0;
                     $52 = $51&1;
                     if ($52) {
                      break;
                     }
                     $53 = HEAP32[((2600920 + 80|0))>>2]|0;
                     $54 = (($53) + 4|0);
                     HEAP32[$54>>2] = $46;
                     __THREW__ = 0;
                     (invoke_ii(2996,(2313960|0))|0);
                     $55 = __THREW__; __THREW__ = 0;
                     $56 = $55&1;
                     if ($56) {
                      break;
                     }
                     __THREW__ = 0;
                     $57 = (invoke_ii(3469,(2313960|0))|0);
                     $58 = __THREW__; __THREW__ = 0;
                     $59 = $58&1;
                     if ($59) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(2173,($57|0));
                     $60 = __THREW__; __THREW__ = 0;
                     $61 = $60&1;
                     if ($61) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2600920|0))|0);
                     $62 = __THREW__; __THREW__ = 0;
                     $63 = $62&1;
                     if ($63) {
                      break;
                     }
                     $64 = HEAP32[((2600920 + 80|0))>>2]|0;
                     HEAP32[$64>>2] = $57;
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $65 = ___cxa_find_matching_catch()|0;
 $66 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($65|0);
 // unreachable;
}
function __Z44mscorlib_System_MonoEnumInfo_m_get_enum_infoP22mscorlib_System_ObjectP20mscorlib_System_TypeP28mscorlib_System_MonoEnumInfo($__this,$enumType,$info) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 $info = $info|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2600040);
 $0 = HEAP32[2600088>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2600096|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2600088>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($enumType|0),($info|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z40mscorlib_System_MonoEnumInfo_m_get_CacheP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2600168);
 __THREW__ = 0;
 (invoke_ii(2996,(2600920|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2600920 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2600920|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2600920|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2600920|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2600920|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2600920 + 104|0))>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_ii(3475,($14|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[$15>>2]|0;
     $19 = ($18|0)==(0|0);
     if ($19) {
      __THREW__ = 0;
      (invoke_ii(2996,(2313960|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      $22 = (invoke_ii(3469,(2313960|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(2173,($22|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      $29 = HEAP8[((2600920 + 116|0))>>0]|0;
      $30 = ($29<<24>>24)==(0);
      if ($30) {
       __THREW__ = 0;
       (invoke_ii(2996,(2600920|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2600920|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2600920|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = HEAP32[((2600920 + 104|0))>>2]|0;
      __THREW__ = 0;
      $40 = (invoke_ii(3475,($39|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      HEAP32[$40>>2] = $22;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2600920|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      $45 = HEAP8[((2600920 + 116|0))>>0]|0;
      $46 = ($45<<24>>24)==(0);
      if ($46) {
       __THREW__ = 0;
       (invoke_ii(2996,(2600920|0))|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2600920|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if ($50) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2600920|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if (!($54)) {
       $55 = HEAP32[((2600920 + 104|0))>>2]|0;
       __THREW__ = 0;
       $56 = (invoke_ii(3475,($55|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if (!($58)) {
        $59 = HEAP32[$56>>2]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($59|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_MonoEnumInfo_m_GetInfoP22mscorlib_System_ObjectP20mscorlib_System_TypeP28mscorlib_System_MonoEnumInfo($__this,$enumType,$info) {
 $__this = $__this|0;
 $enumType = $enumType|0;
 $info = $info|0;
 var $$0 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0;
 var $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_40 = 0, $L_49 = 0;
 var $V_2$0 = 0, $V_3$0 = 0, $V_4 = 0, $__last_unhandled_exception$0 = 0, $__last_unhandled_exception$1 = 0, $_stackTraceSentry = 0, $cond2 = 0, $info$byval_copy = 0, $leaveInstructions$sroa$0$0 = 0, $leaveInstructions$sroa$0$1 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $info$byval_copy = sp + 48|0;
 $_stackTraceSentry = sp;
 $V_4 = sp + 8|0;
 $L_40 = sp + 24|0;
 $L_49 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2600216);
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;HEAP32[$V_4+12>>2]=0|0;
 __THREW__ = 0;
 $0 = (invoke_ii(2440,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 6;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    label = 6;
   } else {
    __THREW__ = 0;
    $5 = (invoke_iiii(1644,(2311328|0),($0|0),($enumType|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     label = 6;
    } else {
     if ($5) {
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       label = 6;
       break;
      }
      $14 = HEAP8[((2600920 + 116|0))>>0]|0;
      $15 = ($14<<24>>24)==(0);
      if ($15) {
       __THREW__ = 0;
       (invoke_ii(2996,(2600920|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        label = 6;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2600920|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        label = 6;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2600920|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        label = 6;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 6;
       break;
      }
      $24 = HEAP32[((2600920 + 104|0))>>2]|0;
      __THREW__ = 0;
      $25 = (invoke_ii(3475,($24|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       label = 6;
       break;
      }
      $28 = HEAP32[$25>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($28|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 6;
       break;
      }
      __THREW__ = 0;
      $31 = (invoke_iiii(1643,(2310848|0),($28|0),($enumType|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 6;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 6;
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2770,($31|0),(2600920|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       label = 6;
       break;
      }
      _memmove(($info|0),($36|0),16)|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2600920|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 6;
     } else {
      $41 = HEAP8[((2600920 + 116|0))>>0]|0;
      $42 = ($41<<24>>24)==(0);
      if ($42) {
       __THREW__ = 0;
       (invoke_ii(2996,(2600920|0))|0);
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 6;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2600920|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        label = 6;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2600920|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        label = 6;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2600920|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 6;
      } else {
       $51 = HEAP32[((2600920 + 80|0))>>2]|0;
       $52 = (($51) + 4|0);
       $53 = HEAP32[$52>>2]|0;
       __THREW__ = 0;
       invoke_vii(1916,0,($53|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 6;
       } else {
        __THREW__ = 0;
        (invoke_ii(2996,(2600920|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        do {
         if ($57) {
          label = 32;
         } else {
          $58 = HEAP8[((2600920 + 116|0))>>0]|0;
          $59 = ($58<<24>>24)==(0);
          if ($59) {
           __THREW__ = 0;
           (invoke_ii(2996,(2600920|0))|0);
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if ($61) {
            label = 32;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2600920|0))|0);
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if ($63) {
            label = 32;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3839,(2600920|0));
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if ($65) {
            label = 32;
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2600920|0))|0);
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           label = 32;
          } else {
           $76 = HEAP32[((2600920 + 80|0))>>2]|0;
           $77 = HEAP32[$76>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($77|0));
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if ($79) {
            label = 32;
           } else {
            __THREW__ = 0;
            $80 = (invoke_iiii(1644,(2311328|0),($77|0),($enumType|0))|0);
            $81 = __THREW__; __THREW__ = 0;
            $82 = $81&1;
            if ($82) {
             label = 32;
            } else {
             if ($80) {
              __THREW__ = 0;
              (invoke_ii(2996,(2600920|0))|0);
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if ($84) {
               label = 32;
              } else {
               $85 = HEAP8[((2600920 + 116|0))>>0]|0;
               $86 = ($85<<24>>24)==(0);
               if ($86) {
                __THREW__ = 0;
                (invoke_ii(2996,(2600920|0))|0);
                $87 = __THREW__; __THREW__ = 0;
                $88 = $87&1;
                if ($88) {
                 label = 32;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2600920|0))|0);
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if ($90) {
                 label = 32;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3839,(2600920|0));
                $91 = __THREW__; __THREW__ = 0;
                $92 = $91&1;
                if ($92) {
                 label = 32;
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2600920|0))|0);
               $93 = __THREW__; __THREW__ = 0;
               $94 = $93&1;
               if ($94) {
                label = 32;
               } else {
                $95 = HEAP32[((2600920 + 80|0))>>2]|0;
                $96 = HEAP32[$95>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($96|0));
                $97 = __THREW__; __THREW__ = 0;
                $98 = $97&1;
                if ($98) {
                 label = 32;
                } else {
                 __THREW__ = 0;
                 $99 = (invoke_iiii(1643,(2310848|0),($96|0),($enumType|0))|0);
                 $100 = __THREW__; __THREW__ = 0;
                 $101 = $100&1;
                 if ($101) {
                  label = 32;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2600920|0))|0);
                 $102 = __THREW__; __THREW__ = 0;
                 $103 = $102&1;
                 if ($103) {
                  label = 32;
                  break;
                 }
                 $104 = HEAP8[((2600920 + 116|0))>>0]|0;
                 $105 = ($104<<24>>24)==(0);
                 if ($105) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2600920|0))|0);
                  $106 = __THREW__; __THREW__ = 0;
                  $107 = $106&1;
                  if ($107) {
                   label = 32;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2600920|0))|0);
                  $108 = __THREW__; __THREW__ = 0;
                  $109 = $108&1;
                  if ($109) {
                   label = 32;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3839,(2600920|0));
                  $110 = __THREW__; __THREW__ = 0;
                  $111 = $110&1;
                  if ($111) {
                   label = 32;
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2600920|0))|0);
                 $112 = __THREW__; __THREW__ = 0;
                 $113 = $112&1;
                 if ($113) {
                  label = 32;
                  break;
                 }
                 $114 = HEAP32[((2600920 + 104|0))>>2]|0;
                 __THREW__ = 0;
                 $115 = (invoke_ii(3475,($114|0))|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  label = 32;
                  break;
                 }
                 $118 = HEAP32[$115>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($118|0));
                 $119 = __THREW__; __THREW__ = 0;
                 $120 = $119&1;
                 if ($120) {
                  label = 32;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiii(465,(2310992|0),($118|0),($enumType|0),($99|0));
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  label = 32;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2600920|0))|0);
                 $123 = __THREW__; __THREW__ = 0;
                 $124 = $123&1;
                 if ($124) {
                  label = 32;
                  break;
                 }
                 __THREW__ = 0;
                 $125 = (invoke_iii(2770,($99|0),(2600920|0))|0);
                 $126 = __THREW__; __THREW__ = 0;
                 $127 = $126&1;
                 if ($127) {
                  label = 32;
                  break;
                 }
                 _memmove(($info|0),($125|0),16)|0;
                 $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 350;
                }
               }
              }
             } else {
              $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 111;
             }
            }
           }
          }
         }
        } while(0);
        if ((label|0) == 32) {
         $66 = ___cxa_find_matching_catch(348288|0)|0;
         $67 = tempRet0;
         $68 = (_llvm_eh_typeid_for((348288|0))|0);
         $69 = ($67|0)==($68|0);
         if (!($69)) {
          $$0 = $66;$$03 = $67;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($$0|0);
          // unreachable;
         }
         $70 = (___cxa_begin_catch(($66|0))|0);
         $71 = HEAP32[$70>>2]|0;
         __THREW__ = 0;
         invoke_v(66);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          label = 6;
          break;
         }
         $__last_unhandled_exception$0 = $71;$leaveInstructions$sroa$0$0 = 0;
        }
        __THREW__ = 0;
        invoke_vii(1917,0,($53|0));
        $128 = __THREW__; __THREW__ = 0;
        $129 = $128&1;
        if ($129) {
         label = 6;
        } else {
         if ((($leaveInstructions$sroa$0$0|0) == 111)) {
          __THREW__ = 0;
          invoke_viii(671,0,($enumType|0),($info|0));
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           label = 6;
           break;
          }
          $134 = (($info) + 4|0);
          $135 = HEAP32[$134>>2]|0;
          __THREW__ = 0;
          (invoke_ii(2996,(1170368|0))|0);
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           label = 6;
           break;
          }
          __THREW__ = 0;
          $138 = (invoke_iii(2735,($135|0),(1170368|0))|0);
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           label = 6;
           break;
          }
          $141 = ($138|0)==(0|0);
          do {
           if ($141) {
            $157 = HEAP32[$134>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(1217736|0))|0);
            $158 = __THREW__; __THREW__ = 0;
            $159 = $158&1;
            if ($159) {
             label = 6;
             break L1;
            }
            __THREW__ = 0;
            $160 = (invoke_iii(2735,($157|0),(1217736|0))|0);
            $161 = __THREW__; __THREW__ = 0;
            $162 = $161&1;
            if ($162) {
             label = 6;
             break L1;
            }
            $163 = ($160|0)==(0|0);
            if (!($163)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $164 = __THREW__; __THREW__ = 0;
             $165 = $164&1;
             if ($165) {
              label = 6;
              break L1;
             }
             $166 = HEAP8[((2600920 + 116|0))>>0]|0;
             $167 = ($166<<24>>24)==(0);
             if ($167) {
              __THREW__ = 0;
              (invoke_ii(2996,(2600920|0))|0);
              $168 = __THREW__; __THREW__ = 0;
              $169 = $168&1;
              if ($169) {
               label = 6;
               break L1;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2600920|0))|0);
              $170 = __THREW__; __THREW__ = 0;
              $171 = $170&1;
              if ($171) {
               label = 6;
               break L1;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2600920|0));
              $172 = __THREW__; __THREW__ = 0;
              $173 = $172&1;
              if ($173) {
               label = 6;
               break L1;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $174 = __THREW__; __THREW__ = 0;
             $175 = $174&1;
             if ($175) {
              label = 6;
              break L1;
             }
             $176 = HEAP32[((2600920 + 80|0))>>2]|0;
             $177 = (($176) + 12|0);
             $178 = HEAP32[$177>>2]|0;
             $V_2$0 = $178;
             break;
            }
            $179 = HEAP32[$134>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(1217360|0))|0);
            $180 = __THREW__; __THREW__ = 0;
            $181 = $180&1;
            if ($181) {
             label = 6;
             break L1;
            }
            __THREW__ = 0;
            $182 = (invoke_iii(2735,($179|0),(1217360|0))|0);
            $183 = __THREW__; __THREW__ = 0;
            $184 = $183&1;
            if ($184) {
             label = 6;
             break L1;
            }
            $185 = ($182|0)==(0|0);
            if (!($185)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $186 = __THREW__; __THREW__ = 0;
             $187 = $186&1;
             if ($187) {
              label = 6;
              break L1;
             }
             $188 = HEAP8[((2600920 + 116|0))>>0]|0;
             $189 = ($188<<24>>24)==(0);
             if ($189) {
              __THREW__ = 0;
              (invoke_ii(2996,(2600920|0))|0);
              $190 = __THREW__; __THREW__ = 0;
              $191 = $190&1;
              if ($191) {
               label = 6;
               break L1;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2600920|0))|0);
              $192 = __THREW__; __THREW__ = 0;
              $193 = $192&1;
              if ($193) {
               label = 6;
               break L1;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2600920|0));
              $194 = __THREW__; __THREW__ = 0;
              $195 = $194&1;
              if ($195) {
               label = 6;
               break L1;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $196 = __THREW__; __THREW__ = 0;
             $197 = $196&1;
             if ($197) {
              label = 6;
              break L1;
             }
             $198 = HEAP32[((2600920 + 80|0))>>2]|0;
             $199 = (($198) + 8|0);
             $200 = HEAP32[$199>>2]|0;
             $V_2$0 = $200;
             break;
            }
            $201 = HEAP32[$134>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(1215824|0))|0);
            $202 = __THREW__; __THREW__ = 0;
            $203 = $202&1;
            if ($203) {
             label = 6;
             break L1;
            }
            __THREW__ = 0;
            $204 = (invoke_iii(2735,($201|0),(1215824|0))|0);
            $205 = __THREW__; __THREW__ = 0;
            $206 = $205&1;
            if ($206) {
             label = 6;
             break L1;
            }
            $207 = ($204|0)==(0|0);
            if ($207) {
             $V_2$0 = 0;
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2600920|0))|0);
            $208 = __THREW__; __THREW__ = 0;
            $209 = $208&1;
            if ($209) {
             label = 6;
             break L1;
            }
            $210 = HEAP8[((2600920 + 116|0))>>0]|0;
            $211 = ($210<<24>>24)==(0);
            if ($211) {
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $212 = __THREW__; __THREW__ = 0;
             $213 = $212&1;
             if ($213) {
              label = 6;
              break L1;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $214 = __THREW__; __THREW__ = 0;
             $215 = $214&1;
             if ($215) {
              label = 6;
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3839,(2600920|0));
             $216 = __THREW__; __THREW__ = 0;
             $217 = $216&1;
             if ($217) {
              label = 6;
              break L1;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2600920|0))|0);
            $218 = __THREW__; __THREW__ = 0;
            $219 = $218&1;
            if ($219) {
             label = 6;
             break L1;
            }
            $220 = HEAP32[((2600920 + 80|0))>>2]|0;
            $221 = (($220) + 20|0);
            $222 = HEAP32[$221>>2]|0;
            $V_2$0 = $222;
           } else {
            __THREW__ = 0;
            (invoke_ii(2996,(2600920|0))|0);
            $142 = __THREW__; __THREW__ = 0;
            $143 = $142&1;
            if ($143) {
             label = 6;
             break L1;
            }
            $144 = HEAP8[((2600920 + 116|0))>>0]|0;
            $145 = ($144<<24>>24)==(0);
            if ($145) {
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $146 = __THREW__; __THREW__ = 0;
             $147 = $146&1;
             if ($147) {
              label = 6;
              break L1;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $148 = __THREW__; __THREW__ = 0;
             $149 = $148&1;
             if ($149) {
              label = 6;
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3839,(2600920|0));
             $150 = __THREW__; __THREW__ = 0;
             $151 = $150&1;
             if ($151) {
              label = 6;
              break L1;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2600920|0))|0);
            $152 = __THREW__; __THREW__ = 0;
            $153 = $152&1;
            if ($153) {
             label = 6;
             break L1;
            }
            $154 = HEAP32[((2600920 + 80|0))>>2]|0;
            $155 = (($154) + 16|0);
            $156 = HEAP32[$155>>2]|0;
            $V_2$0 = $156;
           }
          } while(0);
          $223 = HEAP32[$134>>2]|0;
          $224 = (($info) + 8|0);
          $225 = HEAP32[$224>>2]|0;
          __THREW__ = 0;
          invoke_viiii(143,(0|0),($223|0),($225|0),($V_2$0|0));
          $226 = __THREW__; __THREW__ = 0;
          $227 = $226&1;
          if ($227) {
           label = 6;
           break;
          }
          $228 = HEAP32[$224>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($228|0));
          $229 = __THREW__; __THREW__ = 0;
          $230 = $229&1;
          if ($230) {
           label = 6;
           break;
          }
          $231 = (($228) + 12|0);
          $232 = HEAP32[$231>>2]|0;
          $233 = ($232|0)<(51);
          L121: do {
           if (!($233)) {
            $234 = HEAP32[$224>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($234|0));
            $235 = __THREW__; __THREW__ = 0;
            $236 = $235&1;
            if ($236) {
             label = 6;
             break L1;
            }
            $237 = (($234) + 12|0);
            $238 = HEAP32[$237>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2313960|0))|0);
            $239 = __THREW__; __THREW__ = 0;
            $240 = $239&1;
            if ($240) {
             label = 6;
             break L1;
            }
            __THREW__ = 0;
            $241 = (invoke_ii(3469,(2313960|0))|0);
            $242 = __THREW__; __THREW__ = 0;
            $243 = $242&1;
            if ($243) {
             label = 6;
             break L1;
            }
            __THREW__ = 0;
            invoke_vii(1822,($241|0),($238|0));
            $244 = __THREW__; __THREW__ = 0;
            $245 = $244&1;
            if ($245) {
             label = 6;
             break L1;
            }
            $246 = (($info) + 12|0);
            HEAP32[$246>>2] = $241;
            $V_3$0 = 0;
            while(1) {
             $274 = HEAP32[$224>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($274|0));
             $275 = __THREW__; __THREW__ = 0;
             $276 = $275&1;
             if ($276) {
              break;
             }
             $277 = (($274) + 12|0);
             $278 = HEAP32[$277>>2]|0;
             $279 = ($V_3$0|0)<($278|0);
             if (!($279)) {
              break L121;
             }
             $268 = HEAP32[$246>>2]|0;
             $248 = HEAP32[$224>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($248|0));
             $280 = __THREW__; __THREW__ = 0;
             $281 = $280&1;
             if ($281) {
              break;
             }
             $247 = (($248) + 12|0);
             $249 = HEAP32[$247>>2]|0;
             $250 = ($V_3$0>>>0)<($249>>>0);
             if (!($250)) {
              __THREW__ = 0;
              $251 = (invoke_i(132)|0);
              $252 = __THREW__; __THREW__ = 0;
              $253 = $252&1;
              if ($253) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($251|0));
              $254 = __THREW__; __THREW__ = 0;
              $255 = $254&1;
              if ($255) {
               break;
              }
             }
             $256 = HEAP32[$248>>2]|0;
             $257 = (($248) + 16|0);
             $258 = (($256) + 92|0);
             $259 = HEAP32[$258>>2]|0;
             $260 = Math_imul($259, $V_3$0)|0;
             $261 = (($257) + ($260)|0);
             $262 = HEAP32[$261>>2]|0;
             HEAP32[$L_40>>2] = $V_3$0;
             __THREW__ = 0;
             (invoke_ii(2996,(2155952|0))|0);
             $263 = __THREW__; __THREW__ = 0;
             $264 = $263&1;
             if ($264) {
              break;
             }
             __THREW__ = 0;
             $265 = (invoke_iii(2724,(2155952|0),($L_40|0))|0);
             $266 = __THREW__; __THREW__ = 0;
             $267 = $266&1;
             if ($267) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($268|0));
             $269 = __THREW__; __THREW__ = 0;
             $270 = $269&1;
             if ($270) {
              break;
             }
             __THREW__ = 0;
             invoke_viiii(465,(2310992|0),($268|0),($262|0),($265|0));
             $271 = __THREW__; __THREW__ = 0;
             $272 = $271&1;
             if ($272) {
              break;
             }
             $273 = (($V_3$0) + 1)|0;
             $V_3$0 = $273;
            }
            $8 = ___cxa_find_matching_catch()|0;
            $9 = tempRet0;
            $lpad$phi$index = $8;$lpad$phi$index2 = $9;
            break L1;
           }
          } while(0);
          __THREW__ = 0;
          ;HEAP32[$info$byval_copy+0>>2]=HEAP32[$info+0>>2]|0;HEAP32[$info$byval_copy+4>>2]=HEAP32[$info+4>>2]|0;HEAP32[$info$byval_copy+8>>2]=HEAP32[$info+8>>2]|0;HEAP32[$info$byval_copy+12>>2]=HEAP32[$info+12>>2]|0;
          invoke_vii(1938,($V_4|0),($info$byval_copy|0));
          $282 = __THREW__; __THREW__ = 0;
          $283 = $282&1;
          if ($283) {
           label = 6;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2600920|0))|0);
          $284 = __THREW__; __THREW__ = 0;
          $285 = $284&1;
          if ($285) {
           label = 6;
           break;
          }
          $286 = HEAP8[((2600920 + 116|0))>>0]|0;
          $287 = ($286<<24>>24)==(0);
          if ($287) {
           __THREW__ = 0;
           (invoke_ii(2996,(2600920|0))|0);
           $288 = __THREW__; __THREW__ = 0;
           $289 = $288&1;
           if ($289) {
            label = 6;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2600920|0))|0);
           $290 = __THREW__; __THREW__ = 0;
           $291 = $290&1;
           if ($291) {
            label = 6;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3839,(2600920|0));
           $292 = __THREW__; __THREW__ = 0;
           $293 = $292&1;
           if ($293) {
            label = 6;
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2600920|0))|0);
          $294 = __THREW__; __THREW__ = 0;
          $295 = $294&1;
          if ($295) {
           label = 6;
           break;
          }
          $296 = HEAP32[((2600920 + 80|0))>>2]|0;
          $297 = (($296) + 4|0);
          $298 = HEAP32[$297>>2]|0;
          __THREW__ = 0;
          invoke_vii(1916,0,($298|0));
          $299 = __THREW__; __THREW__ = 0;
          $300 = $299&1;
          if ($300) {
           label = 6;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2600920|0))|0);
          $301 = __THREW__; __THREW__ = 0;
          $302 = $301&1;
          do {
           if ($302) {
            label = 136;
           } else {
            $303 = HEAP8[((2600920 + 116|0))>>0]|0;
            $304 = ($303<<24>>24)==(0);
            if ($304) {
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $305 = __THREW__; __THREW__ = 0;
             $306 = $305&1;
             if ($306) {
              label = 136;
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2600920|0))|0);
             $307 = __THREW__; __THREW__ = 0;
             $308 = $307&1;
             if ($308) {
              label = 136;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3839,(2600920|0));
             $309 = __THREW__; __THREW__ = 0;
             $310 = $309&1;
             if ($310) {
              label = 136;
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2600920|0))|0);
            $319 = __THREW__; __THREW__ = 0;
            $320 = $319&1;
            if ($320) {
             label = 136;
             break;
            }
            $321 = HEAP32[((2600920 + 80|0))>>2]|0;
            $322 = HEAP32[$321>>2]|0;
            ;HEAP32[$L_49+0>>2]=HEAP32[$V_4+0>>2]|0;HEAP32[$L_49+4>>2]=HEAP32[$V_4+4>>2]|0;HEAP32[$L_49+8>>2]=HEAP32[$V_4+8>>2]|0;HEAP32[$L_49+12>>2]=HEAP32[$V_4+12>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2600920|0))|0);
            $323 = __THREW__; __THREW__ = 0;
            $324 = $323&1;
            if ($324) {
             label = 136;
             break;
            }
            __THREW__ = 0;
            $325 = (invoke_iii(2724,(2600920|0),($L_49|0))|0);
            $326 = __THREW__; __THREW__ = 0;
            $327 = $326&1;
            if ($327) {
             label = 136;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($322|0));
            $328 = __THREW__; __THREW__ = 0;
            $329 = $328&1;
            if ($329) {
             label = 136;
             break;
            }
            __THREW__ = 0;
            invoke_viiii(465,(2310992|0),($322|0),($enumType|0),($325|0));
            $330 = __THREW__; __THREW__ = 0;
            $331 = $330&1;
            if ($331) {
             label = 136;
            } else {
             $__last_unhandled_exception$1 = $__last_unhandled_exception$0;$leaveInstructions$sroa$0$1 = 350;
            }
           }
          } while(0);
          if ((label|0) == 136) {
           $311 = ___cxa_find_matching_catch(348288|0)|0;
           $312 = tempRet0;
           $313 = (_llvm_eh_typeid_for((348288|0))|0);
           $314 = ($312|0)==($313|0);
           if (!($314)) {
            $$0 = $311;$$03 = $312;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($$0|0);
            // unreachable;
           }
           $315 = (___cxa_begin_catch(($311|0))|0);
           $316 = HEAP32[$315>>2]|0;
           __THREW__ = 0;
           invoke_v(66);
           $317 = __THREW__; __THREW__ = 0;
           $318 = $317&1;
           if ($318) {
            label = 6;
            break;
           }
           $__last_unhandled_exception$1 = $316;$leaveInstructions$sroa$0$1 = 111;
          }
          __THREW__ = 0;
          invoke_vii(1917,0,($298|0));
          $332 = __THREW__; __THREW__ = 0;
          $333 = $332&1;
          if ($333) {
           label = 6;
           break;
          }
          $cond2 = ($leaveInstructions$sroa$0$1|0)==(350);
          if ($cond2) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          __THREW__ = 0;
          invoke_vi(3838,($__last_unhandled_exception$1|0));
          $334 = __THREW__; __THREW__ = 0;
          $335 = $334&1;
          if ($335) {
           label = 6;
           break;
          }
          // unreachable;
         } else if ((($leaveInstructions$sroa$0$0|0) == 350)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         } else {
          __THREW__ = 0;
          invoke_vi(3838,($__last_unhandled_exception$0|0));
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           label = 6;
           break;
          }
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 }
 $$0 = $lpad$phi$index;$$03 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZN14ActionInvoker1I34mscorlib_System_MonoEnumInfoTraitsE6InvokeEPFvPv28mscorlib_System_MonoEnumInfoES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z65mscorlib_System_MonoEnumInfo_CustomAttributesCacheGenerator_cacheP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2649496)|0);
 __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z42mscorlib_System_Environment_m_get_PlatformP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2601152);
 $0 = HEAP32[2601200>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2601208|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2601200>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_Environment_m_GetOSVersionStringP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2601248);
 $0 = HEAP32[2601296>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2601304|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2601296>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_Environment_m_get_OSVersionP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2601352);
 __THREW__ = 0;
 (invoke_ii(2996,(2601784|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[((2601784 + 80|0))>>2]|0;
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    $7 = (invoke_ii(2443,0)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iii(1174,(0|0),($7|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(2442,0)|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2635080|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    $18 = (invoke_ii(3469,(2635080|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    invoke_viii(698,($18|0),($13|0),($10|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2601784|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[((2601784 + 80|0))>>2]|0;
    HEAP32[$25>>2] = $18;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2601784|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = HEAP32[((2601784 + 80|0))>>2]|0;
    $29 = HEAP32[$28>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($29|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_OperatingSystem_m__ctorP31mscorlib_System_OperatingSystemiP23mscorlib_System_Version($__this,$platform,$version) {
 $__this = $__this|0;
 $platform = $platform|0;
 $version = $version|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2634568);
 __THREW__ = 0;
 invoke_v(887);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2191608 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2191608|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2191608 + 80|0))>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     $18 = (($__this) + 16|0);
     HEAP32[$18>>2] = $17;
     __THREW__ = 0;
     invoke_vi(1924,($__this|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      $21 = (invoke_iiii(1278,(0|0),($version|0),(0|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       if (!($21)) {
        $34 = (($__this) + 8|0);
        HEAP32[$34>>2] = $platform;
        $35 = (($__this) + 12|0);
        HEAP32[$35>>2] = $version;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2560584|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        $26 = (invoke_ii(3469,(2560584|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         $29 = HEAP32[3074648>>2]|0;
         __THREW__ = 0;
         invoke_vii(1925,($26|0),($29|0));
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          invoke_vi(3838,($26|0));
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if (!($33)) {
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z60mscorlib_System_Environment_m_internalGetEnvironmentVariableP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$variable) {
 $__this = $__this|0;
 $variable = $variable|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2601400);
 $0 = HEAP32[2601448>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2601456|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2601448>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($variable|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z58mscorlib_System_Environment_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z33mscorlib_System_EventArgs_m__ctorP25mscorlib_System_EventArgs($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2601920);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z34mscorlib_System_EventArgs_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2601968);
 __THREW__ = 0;
 (invoke_ii(2996,(2602128|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2602128|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2717,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2602128|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2602128 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z56mscorlib_System_EventArgs_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z44mscorlib_System_FieldAccessException_m__ctorP36mscorlib_System_FieldAccessExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2602264);
 __THREW__ = 0;
 invoke_vii(1948,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233081);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z89mscorlib_System_MemberAccessException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP37mscorlib_System_MemberAccessExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2610280);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233062);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z67mscorlib_System_FieldAccessException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z61mscorlib_System_FlagsAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,16);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z60mscorlib_System_FormatException_m__ctor_mscorlib_System_VoidP31mscorlib_System_FormatException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2602880);
 __THREW__ = 0;
 invoke_v(888);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3070776>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233033);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z62mscorlib_System_FormatException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z87mscorlib_System_GC_CustomAttributesCacheGenerator_mscorlib_System_GC_m_SuppressFinalizeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z78mscorlib_System_Guid_m__ctor_mscorlib_System_Void_mscorlib_System_Byte_arr_arrP20mscorlib_System_GuidP24mscorlib_System_Byte_arr($__this,$b) {
 $__this = $__this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603648);
 __THREW__ = 0;
 invoke_viii(674,0,($b|0),16);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iiii(781,(0|0),($b|0),0)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    HEAP32[$__this>>2] = $2;
    __THREW__ = 0;
    $5 = (invoke_iiii(779,(0|0),($b|0),4)|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = (($__this) + 4|0);
     HEAP16[$8>>1] = $5;
     __THREW__ = 0;
     $9 = (invoke_iiii(779,(0|0),($b|0),6)|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = (($__this) + 6|0);
      HEAP16[$12>>1] = $9;
      __THREW__ = 0;
      invoke_vi(3799,($b|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = (($b) + 12|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = ($16>>>0)<(9);
       if ($17) {
        __THREW__ = 0;
        $18 = (invoke_i(132)|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($18|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if ($22) {
         break;
        }
       }
       $25 = HEAP32[$b>>2]|0;
       $26 = (($b) + 16|0);
       $27 = (($25) + 92|0);
       $28 = HEAP32[$27>>2]|0;
       $29 = $28 << 3;
       $30 = (($26) + ($29)|0);
       $31 = HEAP8[$30>>0]|0;
       $32 = (($__this) + 8|0);
       HEAP8[$32>>0] = $31;
       __THREW__ = 0;
       invoke_vi(3799,($b|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        $35 = HEAP32[$15>>2]|0;
        $36 = ($35>>>0)<(10);
        if ($36) {
         __THREW__ = 0;
         $37 = (invoke_i(132)|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($37|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break;
         }
        }
        $42 = HEAP32[$b>>2]|0;
        $43 = (($42) + 92|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = ($44*9)|0;
        $46 = (($26) + ($45)|0);
        $47 = HEAP8[$46>>0]|0;
        $48 = (($__this) + 9|0);
        HEAP8[$48>>0] = $47;
        __THREW__ = 0;
        invoke_vi(3799,($b|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if (!($50)) {
         $51 = HEAP32[$15>>2]|0;
         $52 = ($51>>>0)<(11);
         if ($52) {
          __THREW__ = 0;
          $53 = (invoke_i(132)|0);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($53|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
         }
         $58 = HEAP32[$b>>2]|0;
         $59 = (($58) + 92|0);
         $60 = HEAP32[$59>>2]|0;
         $61 = ($60*10)|0;
         $62 = (($26) + ($61)|0);
         $63 = HEAP8[$62>>0]|0;
         $64 = (($__this) + 10|0);
         HEAP8[$64>>0] = $63;
         __THREW__ = 0;
         invoke_vi(3799,($b|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if (!($66)) {
          $67 = HEAP32[$15>>2]|0;
          $68 = ($67>>>0)<(12);
          if ($68) {
           __THREW__ = 0;
           $69 = (invoke_i(132)|0);
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($69|0));
           $72 = __THREW__; __THREW__ = 0;
           $73 = $72&1;
           if ($73) {
            break;
           }
          }
          $74 = HEAP32[$b>>2]|0;
          $75 = (($74) + 92|0);
          $76 = HEAP32[$75>>2]|0;
          $77 = ($76*11)|0;
          $78 = (($26) + ($77)|0);
          $79 = HEAP8[$78>>0]|0;
          $80 = (($__this) + 11|0);
          HEAP8[$80>>0] = $79;
          __THREW__ = 0;
          invoke_vi(3799,($b|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if (!($82)) {
           $83 = HEAP32[$15>>2]|0;
           $84 = ($83>>>0)<(13);
           if ($84) {
            __THREW__ = 0;
            $85 = (invoke_i(132)|0);
            $86 = __THREW__; __THREW__ = 0;
            $87 = $86&1;
            if ($87) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($85|0));
            $88 = __THREW__; __THREW__ = 0;
            $89 = $88&1;
            if ($89) {
             break;
            }
           }
           $90 = HEAP32[$b>>2]|0;
           $91 = (($90) + 92|0);
           $92 = HEAP32[$91>>2]|0;
           $93 = ($92*12)|0;
           $94 = (($26) + ($93)|0);
           $95 = HEAP8[$94>>0]|0;
           $96 = (($__this) + 12|0);
           HEAP8[$96>>0] = $95;
           __THREW__ = 0;
           invoke_vi(3799,($b|0));
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if (!($98)) {
            $99 = HEAP32[$15>>2]|0;
            $100 = ($99>>>0)<(14);
            if ($100) {
             __THREW__ = 0;
             $101 = (invoke_i(132)|0);
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             if ($103) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($101|0));
             $104 = __THREW__; __THREW__ = 0;
             $105 = $104&1;
             if ($105) {
              break;
             }
            }
            $106 = HEAP32[$b>>2]|0;
            $107 = (($106) + 92|0);
            $108 = HEAP32[$107>>2]|0;
            $109 = ($108*13)|0;
            $110 = (($26) + ($109)|0);
            $111 = HEAP8[$110>>0]|0;
            $112 = (($__this) + 13|0);
            HEAP8[$112>>0] = $111;
            __THREW__ = 0;
            invoke_vi(3799,($b|0));
            $113 = __THREW__; __THREW__ = 0;
            $114 = $113&1;
            if (!($114)) {
             $115 = HEAP32[$15>>2]|0;
             $116 = ($115>>>0)<(15);
             if ($116) {
              __THREW__ = 0;
              $117 = (invoke_i(132)|0);
              $118 = __THREW__; __THREW__ = 0;
              $119 = $118&1;
              if ($119) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($117|0));
              $120 = __THREW__; __THREW__ = 0;
              $121 = $120&1;
              if ($121) {
               break;
              }
             }
             $122 = HEAP32[$b>>2]|0;
             $123 = (($122) + 92|0);
             $124 = HEAP32[$123>>2]|0;
             $125 = ($124*14)|0;
             $126 = (($26) + ($125)|0);
             $127 = HEAP8[$126>>0]|0;
             $128 = (($__this) + 14|0);
             HEAP8[$128>>0] = $127;
             __THREW__ = 0;
             invoke_vi(3799,($b|0));
             $129 = __THREW__; __THREW__ = 0;
             $130 = $129&1;
             if (!($130)) {
              $131 = HEAP32[$15>>2]|0;
              $132 = ($131>>>0)<(16);
              if (!($132)) {
               $138 = HEAP32[$b>>2]|0;
               $139 = (($138) + 92|0);
               $140 = HEAP32[$139>>2]|0;
               $141 = ($140*15)|0;
               $142 = (($26) + ($141)|0);
               $143 = HEAP8[$142>>0]|0;
               $144 = (($__this) + 15|0);
               HEAP8[$144>>0] = $143;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
              __THREW__ = 0;
              $133 = (invoke_i(132)|0);
              $134 = __THREW__; __THREW__ = 0;
              $135 = $134&1;
              if ($135) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($133|0));
              $136 = __THREW__; __THREW__ = 0;
              $137 = $136&1;
              if ($137) {
               break;
              }
              $138 = HEAP32[$b>>2]|0;
              $139 = (($138) + 92|0);
              $140 = HEAP32[$139>>2]|0;
              $141 = ($140*15)|0;
              $142 = (($26) + ($141)|0);
              $143 = HEAP8[$142>>0]|0;
              $144 = (($__this) + 15|0);
              HEAP8[$144>>0] = $143;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
}
function __Z33mscorlib_System_Guid_m_CheckArrayP22mscorlib_System_ObjectP24mscorlib_System_Byte_arri($__this,$o,$l) {
 $__this = $__this|0;
 $o = $o|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603888);
 __THREW__ = 0;
 invoke_vii(1943,0,($o|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(673,0,($o|0),($l|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z283mscorlib_System_Guid_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int16_mscorlib_System_Int16_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_ByteP20mscorlib_System_Guidisshhhhhhhh($__this,$a,$b,$c,$d,$e,$f,$g,$h,$i,$j,$k) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 $d = $d|0;
 $e = $e|0;
 $f = $f|0;
 $g = $g|0;
 $h = $h|0;
 $i = $i|0;
 $j = $j|0;
 $k = $k|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603696);
 HEAP32[$__this>>2] = $a;
 $0 = (($__this) + 4|0);
 HEAP16[$0>>1] = $b;
 $1 = (($__this) + 6|0);
 HEAP16[$1>>1] = $c;
 $2 = (($__this) + 8|0);
 HEAP8[$2>>0] = $d;
 $3 = (($__this) + 9|0);
 HEAP8[$3>>0] = $e;
 $4 = (($__this) + 10|0);
 HEAP8[$4>>0] = $f;
 $5 = (($__this) + 11|0);
 HEAP8[$5>>0] = $g;
 $6 = (($__this) + 12|0);
 HEAP8[$6>>0] = $h;
 $7 = (($__this) + 13|0);
 HEAP8[$7>>0] = $i;
 $8 = (($__this) + 14|0);
 HEAP8[$8>>0] = $j;
 $9 = (($__this) + 15|0);
 HEAP8[$9>>0] = $k;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z29mscorlib_System_Guid_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_11 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_11 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603744);
 ;HEAP32[$L_11+0>>2]=0|0;HEAP32[$L_11+4>>2]=0|0;HEAP32[$L_11+8>>2]=0|0;HEAP32[$L_11+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiiiiiiiiii(2,($L_11|0),0,0,0,0,0,0,0,0,0,0,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2605992|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP32[((2605992 + 80|0))>>2]|0;
    ;HEAP32[$4+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$L_11+12>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2149728|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_ii(3469,(2149728|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(1924,($7|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2605992|0))|0);
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        $14 = HEAP32[((2605992 + 80|0))>>2]|0;
        $15 = (($14) + 16|0);
        HEAP32[$15>>2] = $7;
        __THREW__ = 0;
        (invoke_ii(2996,(2615032|0))|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if (!($17)) {
         $18 = HEAP8[((2615032 + 116|0))>>0]|0;
         $19 = ($18<<24>>24)==(0);
         if ($19) {
          __THREW__ = 0;
          (invoke_ii(2996,(2615032|0))|0);
          $20 = __THREW__; __THREW__ = 0;
          $21 = $20&1;
          if ($21) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2615032|0))|0);
          $22 = __THREW__; __THREW__ = 0;
          $23 = $22&1;
          if ($23) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2615032|0));
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if ($25) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2615032|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          $30 = HEAP32[((2615032 + 80|0))>>2]|0;
          $31 = HEAP8[$30>>0]|0;
          $32 = ($31<<24>>24)==(0);
          if ($32) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(1669416|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           __THREW__ = 0;
           $35 = (invoke_ii(3469,(1669416|0))|0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if (!($37)) {
            __THREW__ = 0;
            invoke_vi(1653,($35|0));
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if (!($39)) {
             __THREW__ = 0;
             (invoke_ii(2996,(1671176|0))|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if (!($41)) {
              __THREW__ = 0;
              $42 = (invoke_ii(3469,(1671176|0))|0);
              $43 = __THREW__; __THREW__ = 0;
              $44 = $43&1;
              if (!($44)) {
               __THREW__ = 0;
               invoke_vi(1657,($42|0));
               $45 = __THREW__; __THREW__ = 0;
               $46 = $45&1;
               if (!($46)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($26|0);
 // unreachable;
}
function __Z32mscorlib_System_Guid_m_CheckNullP22mscorlib_System_ObjectS0_($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603792);
 __THREW__ = 0;
 invoke_v(889);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($o|0)==(0|0);
  if (!($2)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  $5 = HEAP32[3070824>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1925,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z34mscorlib_System_Guid_m_CheckLengthP22mscorlib_System_ObjectP24mscorlib_System_Byte_arri($__this,$o,$l) {
 $__this = $__this|0;
 $o = $o|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603840);
 __THREW__ = 0;
 invoke_v(890);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($o|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = (($o) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==($l|0);
   if ($6) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $9 = HEAP32[3070888>>2]|0;
   __THREW__ = 0;
   $10 = (invoke_iii(783,(0|0),($9|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    HEAP32[$L_3>>2] = $l;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     $15 = (invoke_iii(2724,(2155952|0),($L_3|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (invoke_iiii(552,(0|0),($10|0),($15|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if (!($22)) {
        __THREW__ = 0;
        $23 = (invoke_ii(3469,(2560072|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         invoke_vii(1924,($23|0),($18|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __THREW__ = 0;
          invoke_vi(3838,($23|0));
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if (!($29)) {
           // unreachable;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z30mscorlib_System_Guid_m_CompareP22mscorlib_System_Objectii($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603936);
 $0 = ($x|0)<($y|0);
 $$ = $0 ? -1 : 1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z77mscorlib_System_Guid_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP20mscorlib_System_GuidP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2603984);
 __THREW__ = 0;
 invoke_v(891);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($value|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2605992|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($value|0),(2605992|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if (!($10)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2605992|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
      __THREW__ = 0;
      $27 = (invoke_iii(2770,($value|0),(2605992|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if ($29) {
       break;
      }
      __THREW__ = 0;
      ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$27+12>>2]|0;
      $30 = (invoke_iii(1125,($__this|0),($tmpcast$byval_copy|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      } else {
       $$0 = $30;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $11 = HEAP32[3070992>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(2560072|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $20 = HEAP32[3070984>>2]|0;
        __THREW__ = 0;
        invoke_viii(641,($17|0),($20|0),($12|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         invoke_vi(3838,($17|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Guid_m_CompareTo_mscorlib_System_Int32_mscorlib_System_GuidP20mscorlib_System_GuidS_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604080);
 $0 = HEAP32[$__this>>2]|0;
 $1 = HEAP32[$value>>2]|0;
 $2 = ($0|0)==($1|0);
 do {
  if ($2) {
   $8 = (($__this) + 4|0);
   $9 = HEAP16[$8>>1]|0;
   $10 = (($value) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = $11&65535;
   $13 = ($9<<16>>16)==($12<<16>>16);
   if (!($13)) {
    $14 = $9 << 16 >> 16;
    $sext = $11 << 16;
    $15 = $sext >> 16;
    __THREW__ = 0;
    $16 = (invoke_iiii(1191,0,($14|0),($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 3;
     break;
    } else {
     $$0 = $16;
     label = 24;
     break;
    }
   }
   $19 = $11 >>> 16;
   $20 = $19&65535;
   $21 = (($__this) + 6|0);
   $22 = HEAP16[$21>>1]|0;
   $23 = ($22<<16>>16)==($20<<16>>16);
   if (!($23)) {
    $24 = $22 << 16 >> 16;
    $25 = $11 >> 16;
    __THREW__ = 0;
    $26 = (invoke_iiii(1191,0,($24|0),($25|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     label = 3;
     break;
    } else {
     $$0 = $26;
     label = 24;
     break;
    }
   }
   $29 = (($__this) + 8|0);
   $30 = HEAP8[$29>>0]|0;
   $31 = (($value) + 8|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = $32&65535;
   $34 = $32&255;
   $35 = ($30<<24>>24)==($34<<24>>24);
   $36 = ($33&65535) >>> 8;
   $37 = $32 >>> 16;
   $38 = $37&255;
   $39 = $32 >>> 24;
   $40 = $39&255;
   if (!($35)) {
    $41 = $30&255;
    $42 = $32 & 255;
    __THREW__ = 0;
    $43 = (invoke_iiii(1191,0,($41|0),($42|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     label = 3;
     break;
    } else {
     $$0 = $43;
     label = 24;
     break;
    }
   }
   $46 = $36&255;
   $47 = (($__this) + 9|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48<<24>>24)==($46<<24>>24);
   if (!($49)) {
    $50 = $48&255;
    $51 = $36&65535;
    __THREW__ = 0;
    $52 = (invoke_iiii(1191,0,($50|0),($51|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 3;
     break;
    } else {
     $$0 = $52;
     label = 24;
     break;
    }
   }
   $55 = (($__this) + 10|0);
   $56 = HEAP8[$55>>0]|0;
   $57 = ($56<<24>>24)==($38<<24>>24);
   if (!($57)) {
    $58 = $56&255;
    $59 = $37 & 255;
    __THREW__ = 0;
    $60 = (invoke_iiii(1191,0,($58|0),($59|0))|0);
    $61 = __THREW__; __THREW__ = 0;
    $62 = $61&1;
    if ($62) {
     label = 3;
     break;
    } else {
     $$0 = $60;
     label = 24;
     break;
    }
   }
   $63 = (($__this) + 11|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = ($64<<24>>24)==($40<<24>>24);
   if (!($65)) {
    $66 = $64&255;
    __THREW__ = 0;
    $67 = (invoke_iiii(1191,0,($66|0),($39|0))|0);
    $68 = __THREW__; __THREW__ = 0;
    $69 = $68&1;
    if ($69) {
     label = 3;
     break;
    } else {
     $$0 = $67;
     label = 24;
     break;
    }
   }
   $70 = (($__this) + 12|0);
   $71 = HEAP8[$70>>0]|0;
   $72 = (($value) + 12|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = $73&65535;
   $75 = $73&255;
   $76 = ($71<<24>>24)==($75<<24>>24);
   $77 = ($74&65535) >>> 8;
   $78 = $73 >>> 16;
   $79 = $78&255;
   $80 = $73 >>> 24;
   $81 = $80&255;
   if (!($76)) {
    $82 = $71&255;
    $83 = $73 & 255;
    __THREW__ = 0;
    $84 = (invoke_iiii(1191,0,($82|0),($83|0))|0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     label = 3;
     break;
    } else {
     $$0 = $84;
     label = 24;
     break;
    }
   }
   $87 = $77&255;
   $88 = (($__this) + 13|0);
   $89 = HEAP8[$88>>0]|0;
   $90 = ($89<<24>>24)==($87<<24>>24);
   if (!($90)) {
    $91 = $89&255;
    $92 = $77&65535;
    __THREW__ = 0;
    $93 = (invoke_iiii(1191,0,($91|0),($92|0))|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 3;
     break;
    } else {
     $$0 = $93;
     label = 24;
     break;
    }
   }
   $96 = (($__this) + 14|0);
   $97 = HEAP8[$96>>0]|0;
   $98 = ($97<<24>>24)==($79<<24>>24);
   if (!($98)) {
    $99 = $97&255;
    $100 = $78 & 255;
    __THREW__ = 0;
    $101 = (invoke_iiii(1191,0,($99|0),($100|0))|0);
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 3;
     break;
    } else {
     $$0 = $101;
     label = 24;
     break;
    }
   }
   $104 = (($__this) + 15|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = ($105<<24>>24)==($81<<24>>24);
   if ($106) {
    $$0 = 0;
    label = 24;
   } else {
    $107 = $105&255;
    __THREW__ = 0;
    $108 = (invoke_iiii(1191,0,($107|0),($80|0))|0);
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     label = 3;
    } else {
     $$0 = $108;
     label = 24;
    }
   }
  } else {
   __THREW__ = 0;
   $3 = (invoke_iiii(1191,0,($0|0),($1|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    label = 3;
   } else {
    $$0 = $3;
    label = 24;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 else if ((label|0) == 24) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z76mscorlib_System_Guid_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP20mscorlib_System_GuidP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604032);
 __THREW__ = 0;
 (invoke_ii(2996,(2605992|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($o|0),(2605992|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2605992|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2770,($o|0),(2605992|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$10+12>>2]|0;
     $13 = (invoke_iii(1125,($__this|0),($tmpcast$byval_copy|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = ($13|0)==(0);
      $$0 = $16;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Guid_m_Equals_mscorlib_System_Boolean_mscorlib_System_GuidP20mscorlib_System_GuidS_($__this,$g) {
 $__this = $__this|0;
 $g = $g|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $g$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $g$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604128);
 __THREW__ = 0;
 ;HEAP32[$g$byval_copy+0>>2]=HEAP32[$g+0>>2]|0;HEAP32[$g$byval_copy+4>>2]=HEAP32[$g+4>>2]|0;HEAP32[$g$byval_copy+8>>2]=HEAP32[$g+8>>2]|0;HEAP32[$g$byval_copy+12>>2]=HEAP32[$g+12>>2]|0;
 $0 = (invoke_iii(1125,($__this|0),($g$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0|0)==(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z34mscorlib_System_Guid_m_GetHashCodeP20mscorlib_System_Guid($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604176);
 $0 = HEAP32[$__this>>2]|0;
 $1 = (($__this) + 4|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2&65535;
 $4 = $3 << 16;
 $5 = (($__this) + 6|0);
 $6 = HEAP16[$5>>1]|0;
 $7 = $6 << 16 >> 16;
 $8 = $4 | $7;
 $9 = $8 ^ $0;
 $10 = (($__this) + 8|0);
 $11 = HEAP8[$10>>0]|0;
 $12 = $11&255;
 $13 = $12 << 24;
 $14 = $9 ^ $13;
 $15 = (($__this) + 9|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = $16&255;
 $18 = $17 << 16;
 $19 = $14 ^ $18;
 $20 = (($__this) + 10|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = $21&255;
 $23 = $22 << 8;
 $24 = $19 ^ $23;
 $25 = (($__this) + 11|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = $24 ^ $27;
 $29 = (($__this) + 12|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = $30&255;
 $32 = $31 << 24;
 $33 = $28 ^ $32;
 $34 = (($__this) + 13|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = $35&255;
 $37 = $36 << 16;
 $38 = $33 ^ $37;
 $39 = (($__this) + 14|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = $40&255;
 $42 = $41 << 8;
 $43 = $38 ^ $42;
 $44 = (($__this) + 15|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = $45&255;
 $47 = $43 ^ $46;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($47|0);
}
function __Z28mscorlib_System_Guid_m_ToHexP22mscorlib_System_Objecti($__this,$b) {
 $__this = $__this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $G_B3_0$0 = 0, $G_B3_0$0$v = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604224);
 $0 = ($b|0)>(9);
 $G_B3_0$0$v = $0 ? 87 : 48;
 $G_B3_0$0 = (($G_B3_0$0$v) + ($b))|0;
 $1 = $G_B3_0$0&65535;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z32mscorlib_System_Guid_m_AppendIntP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderi($__this,$builder,$value) {
 $__this = $__this|0;
 $builder = $builder|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604320);
 $0 = $value >>> 28;
 __THREW__ = 0;
 $1 = (invoke_iii(1127,0,($0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   invoke_vi(3799,($builder|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    (invoke_iii(992,($builder|0),($1|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = $value >>> 24;
     $9 = $8 & 15;
     __THREW__ = 0;
     $10 = (invoke_iii(1127,0,($9|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($builder|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       (invoke_iii(992,($builder|0),($10|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        $17 = $value >>> 20;
        $18 = $17 & 15;
        __THREW__ = 0;
        $19 = (invoke_iii(1127,0,($18|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         invoke_vi(3799,($builder|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          __THREW__ = 0;
          (invoke_iii(992,($builder|0),($19|0))|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           $26 = $value >>> 16;
           $27 = $26 & 15;
           __THREW__ = 0;
           $28 = (invoke_iii(1127,0,($27|0))|0);
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if (!($30)) {
            __THREW__ = 0;
            invoke_vi(3799,($builder|0));
            $31 = __THREW__; __THREW__ = 0;
            $32 = $31&1;
            if (!($32)) {
             __THREW__ = 0;
             (invoke_iii(992,($builder|0),($28|0))|0);
             $33 = __THREW__; __THREW__ = 0;
             $34 = $33&1;
             if (!($34)) {
              $35 = $value >>> 12;
              $36 = $35 & 15;
              __THREW__ = 0;
              $37 = (invoke_iii(1127,0,($36|0))|0);
              $38 = __THREW__; __THREW__ = 0;
              $39 = $38&1;
              if (!($39)) {
               __THREW__ = 0;
               invoke_vi(3799,($builder|0));
               $40 = __THREW__; __THREW__ = 0;
               $41 = $40&1;
               if (!($41)) {
                __THREW__ = 0;
                (invoke_iii(992,($builder|0),($37|0))|0);
                $42 = __THREW__; __THREW__ = 0;
                $43 = $42&1;
                if (!($43)) {
                 $44 = $value >>> 8;
                 $45 = $44 & 15;
                 __THREW__ = 0;
                 $46 = (invoke_iii(1127,0,($45|0))|0);
                 $47 = __THREW__; __THREW__ = 0;
                 $48 = $47&1;
                 if (!($48)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($builder|0));
                  $49 = __THREW__; __THREW__ = 0;
                  $50 = $49&1;
                  if (!($50)) {
                   __THREW__ = 0;
                   (invoke_iii(992,($builder|0),($46|0))|0);
                   $51 = __THREW__; __THREW__ = 0;
                   $52 = $51&1;
                   if (!($52)) {
                    $53 = $value >>> 4;
                    $54 = $53 & 15;
                    __THREW__ = 0;
                    $55 = (invoke_iii(1127,0,($54|0))|0);
                    $56 = __THREW__; __THREW__ = 0;
                    $57 = $56&1;
                    if (!($57)) {
                     __THREW__ = 0;
                     invoke_vi(3799,($builder|0));
                     $58 = __THREW__; __THREW__ = 0;
                     $59 = $58&1;
                     if ($59) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_iii(992,($builder|0),($55|0))|0);
                     $60 = __THREW__; __THREW__ = 0;
                     $61 = $60&1;
                     if ($61) {
                      break;
                     }
                     $62 = $value & 15;
                     __THREW__ = 0;
                     $63 = (invoke_iii(1127,0,($62|0))|0);
                     $64 = __THREW__; __THREW__ = 0;
                     $65 = $64&1;
                     if ($65) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($builder|0));
                     $66 = __THREW__; __THREW__ = 0;
                     $67 = $66&1;
                     if ($67) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_iii(992,($builder|0),($63|0))|0);
                     $68 = __THREW__; __THREW__ = 0;
                     $69 = $68&1;
                     if ($69) {
                      break;
                     }
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $70 = ___cxa_find_matching_catch()|0;
 $71 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($70|0);
 // unreachable;
}
function __Z34mscorlib_System_Guid_m_AppendShortP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilders($__this,$builder,$value) {
 $__this = $__this|0;
 $builder = $builder|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604368);
 $0 = $value << 16 >> 16;
 $1 = $0 >>> 12;
 $2 = $1 & 15;
 __THREW__ = 0;
 $3 = (invoke_iii(1127,0,($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  invoke_vi(3799,($builder|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   (invoke_iii(992,($builder|0),($3|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = $0 >>> 8;
    $11 = $10 & 15;
    __THREW__ = 0;
    $12 = (invoke_iii(1127,0,($11|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vi(3799,($builder|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      (invoke_iii(992,($builder|0),($12|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = $0 >>> 4;
       $20 = $19 & 15;
       __THREW__ = 0;
       $21 = (invoke_iii(1127,0,($20|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3799,($builder|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         (invoke_iii(992,($builder|0),($21|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          $28 = $0 & 15;
          __THREW__ = 0;
          $29 = (invoke_iii(1127,0,($28|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           __THREW__ = 0;
           invoke_vi(3799,($builder|0));
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            __THREW__ = 0;
            (invoke_iii(992,($builder|0),($29|0))|0);
            $34 = __THREW__; __THREW__ = 0;
            $35 = $34&1;
            if (!($35)) {
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($36|0);
 // unreachable;
}
function __Z33mscorlib_System_Guid_m_AppendByteP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderh($__this,$builder,$value) {
 $__this = $__this|0;
 $builder = $builder|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604416);
 $0 = $value&255;
 $1 = ($value&255) >>> 4;
 $2 = $1&255;
 __THREW__ = 0;
 $3 = (invoke_iii(1127,0,($2|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  invoke_vi(3799,($builder|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   (invoke_iii(992,($builder|0),($3|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = $0 & 15;
    __THREW__ = 0;
    $11 = (invoke_iii(1127,0,($10|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($builder|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_iii(992,($builder|0),($11|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z35mscorlib_System_Guid_m_BaseToStringP20mscorlib_System_Guidbbb($__this,$h,$p,$b) {
 $__this = $__this|0;
 $h = $h|0;
 $p = $p|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604464);
 __THREW__ = 0;
 (invoke_ii(2996,(2537888|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(3469,(2537888|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vii(1910,($2|0),40);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     if ($p) {
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $9 = __THREW__; __THREW__ = 0;
      $10 = $9&1;
      if ($10) {
       break;
      }
      __THREW__ = 0;
      (invoke_iii(992,($2|0),40)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
     } else {
      if ($b) {
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if ($14) {
        break;
       }
       __THREW__ = 0;
       (invoke_iii(992,($2|0),123)|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if ($16) {
        break;
       }
      }
     }
     $17 = HEAP32[$__this>>2]|0;
     __THREW__ = 0;
     invoke_viii(675,0,($2|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      if ($h) {
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       __THREW__ = 0;
       (invoke_iii(992,($2|0),45)|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
      }
      $24 = (($__this) + 4|0);
      $25 = HEAP16[$24>>1]|0;
      __THREW__ = 0;
      invoke_viii(676,0,($2|0),($25|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       if ($h) {
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if ($29) {
         break;
        }
        __THREW__ = 0;
        (invoke_iii(992,($2|0),45)|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         break;
        }
       }
       $32 = (($__this) + 6|0);
       $33 = HEAP16[$32>>1]|0;
       __THREW__ = 0;
       invoke_viii(676,0,($2|0),($33|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        if ($h) {
         __THREW__ = 0;
         invoke_vi(3799,($2|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break;
         }
         __THREW__ = 0;
         (invoke_iii(992,($2|0),45)|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          break;
         }
        }
        $40 = (($__this) + 8|0);
        $41 = HEAP8[$40>>0]|0;
        __THREW__ = 0;
        invoke_viii(677,0,($2|0),($41|0));
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if (!($43)) {
         $44 = (($__this) + 9|0);
         $45 = HEAP8[$44>>0]|0;
         __THREW__ = 0;
         invoke_viii(677,0,($2|0),($45|0));
         $46 = __THREW__; __THREW__ = 0;
         $47 = $46&1;
         if (!($47)) {
          if ($h) {
           __THREW__ = 0;
           invoke_vi(3799,($2|0));
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break;
           }
           __THREW__ = 0;
           (invoke_iii(992,($2|0),45)|0);
           $50 = __THREW__; __THREW__ = 0;
           $51 = $50&1;
           if ($51) {
            break;
           }
          }
          $52 = (($__this) + 10|0);
          $53 = HEAP8[$52>>0]|0;
          __THREW__ = 0;
          invoke_viii(677,0,($2|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if (!($55)) {
           $56 = (($__this) + 11|0);
           $57 = HEAP8[$56>>0]|0;
           __THREW__ = 0;
           invoke_viii(677,0,($2|0),($57|0));
           $58 = __THREW__; __THREW__ = 0;
           $59 = $58&1;
           if (!($59)) {
            $60 = (($__this) + 12|0);
            $61 = HEAP8[$60>>0]|0;
            __THREW__ = 0;
            invoke_viii(677,0,($2|0),($61|0));
            $62 = __THREW__; __THREW__ = 0;
            $63 = $62&1;
            if (!($63)) {
             $64 = (($__this) + 13|0);
             $65 = HEAP8[$64>>0]|0;
             __THREW__ = 0;
             invoke_viii(677,0,($2|0),($65|0));
             $66 = __THREW__; __THREW__ = 0;
             $67 = $66&1;
             if (!($67)) {
              $68 = (($__this) + 14|0);
              $69 = HEAP8[$68>>0]|0;
              __THREW__ = 0;
              invoke_viii(677,0,($2|0),($69|0));
              $70 = __THREW__; __THREW__ = 0;
              $71 = $70&1;
              if (!($71)) {
               $72 = (($__this) + 15|0);
               $73 = HEAP8[$72>>0]|0;
               __THREW__ = 0;
               invoke_viii(677,0,($2|0),($73|0));
               $74 = __THREW__; __THREW__ = 0;
               $75 = $74&1;
               if (!($75)) {
                do {
                 if ($p) {
                  __THREW__ = 0;
                  invoke_vi(3799,($2|0));
                  $76 = __THREW__; __THREW__ = 0;
                  $77 = $76&1;
                  if ($77) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_iii(992,($2|0),41)|0);
                  $78 = __THREW__; __THREW__ = 0;
                  $79 = $78&1;
                  if ($79) {
                   break L1;
                  }
                 } else {
                  if (!($b)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($2|0));
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break L1;
                  }
                  __THREW__ = 0;
                  (invoke_iii(992,($2|0),125)|0);
                  $82 = __THREW__; __THREW__ = 0;
                  $83 = $82&1;
                  if ($83) {
                   break L1;
                  }
                 }
                } while(0);
                __THREW__ = 0;
                invoke_vi(3799,($2|0));
                $84 = __THREW__; __THREW__ = 0;
                $85 = $84&1;
                if ($85) {
                 break;
                }
                __THREW__ = 0;
                $86 = (invoke_iii(2730,(2535432|0),($2|0))|0);
                $87 = __THREW__; __THREW__ = 0;
                $88 = $87&1;
                if ($88) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($86|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Guid_m_ToString_mscorlib_System_String_mscorlib_System_StringP20mscorlib_System_GuidP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$off0 = 0;
 var $V_1$0$off0 = 0, $V_2$0$off0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604560);
 __THREW__ = 0;
 invoke_v(892);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($format|0)==(0|0);
   if ($2) {
    $V_0$0$off0 = 1;$V_1$0$off0 = 0;$V_2$0$off0 = 0;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($format|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(1814,($format|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3071112>>2]|0;
    __THREW__ = 0;
    $11 = (invoke_iiii(574,(0|0),($7|0),($10|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    if ($11) {
     $V_0$0$off0 = 1;$V_1$0$off0 = 0;$V_2$0$off0 = 1;
    } else {
     $14 = HEAP32[3071120>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iiii(574,(0|0),($7|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     if ($15) {
      $V_0$0$off0 = 1;$V_1$0$off0 = 1;$V_2$0$off0 = 0;
     } else {
      $18 = HEAP32[3071128>>2]|0;
      __THREW__ = 0;
      $19 = (invoke_iiii(574,(0|0),($7|0),($18|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      if ($19) {
       $V_0$0$off0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 0;
      } else {
       $22 = HEAP32[3071136>>2]|0;
       __THREW__ = 0;
       $23 = (invoke_iiii(575,(0|0),($7|0),($22|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       if ($23) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
        $28 = HEAP8[((2191608 + 116|0))>>0]|0;
        $29 = ($28<<24>>24)==(0);
        if ($29) {
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2191608|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3839,(2191608|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        $38 = HEAP32[((2191608 + 80|0))>>2]|0;
        $39 = HEAP32[$38>>2]|0;
        __THREW__ = 0;
        $40 = (invoke_iiii(575,(0|0),($7|0),($39|0))|0);
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if ($42) {
         break;
        }
        if ($40) {
         $43 = HEAP32[3071144>>2]|0;
         __THREW__ = 0;
         $44 = (invoke_iii(783,(0|0),($43|0))|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2603176|0))|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          break;
         }
         __THREW__ = 0;
         $49 = (invoke_ii(3469,(2603176|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(1940,($49|0),($44|0));
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3838,($49|0));
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break;
         }
         // unreachable;
        } else {
         $V_0$0$off0 = 1;$V_1$0$off0 = 0;$V_2$0$off0 = 0;
        }
       } else {
        $V_0$0$off0 = 1;$V_1$0$off0 = 0;$V_2$0$off0 = 0;
       }
      }
     }
    }
   }
   __THREW__ = 0;
   $56 = (invoke_iiiii(184,($__this|0),($V_0$0$off0|0),($V_1$0$off0|0),($V_2$0$off0|0))|0);
   $57 = __THREW__; __THREW__ = 0;
   $58 = $57&1;
   if (!($58)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($56|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Guid_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP20mscorlib_System_GuidP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$provider) {
 $__this = $__this|0;
 $format = $format|0;
 $provider = $provider|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2604608);
 __THREW__ = 0;
 $0 = (invoke_iii(1128,($__this|0),($format|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __ZN15ActionInvoker11I27mscorlib_System_Int32Traits27mscorlib_System_Int16TraitsS1_26mscorlib_System_ByteTraitsS2_S2_S2_S2_S2_S2_S2_E6InvokeEPFvPvisshhhhhhhhES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP16[$3>>1]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP16[$6>>1]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP8[$12>>0]|0;
 $14 = (($args) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP8[$15>>0]|0;
 $17 = (($args) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP8[$18>>0]|0;
 $20 = (($args) + 28|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP8[$21>>0]|0;
 $23 = (($args) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP8[$24>>0]|0;
 $26 = (($args) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP8[$27>>0]|0;
 $29 = (($args) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP8[$30>>0]|0;
 FUNCTION_TABLE_viiiiiiiiiiii[$action & 3]($obj,$1,$4,$7,$10,$13,$16,$19,$22,$25,$28,$31);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits26mscorlib_System_GuidTraitsE6InvokeEPFbPv20mscorlib_System_GuidES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker0I26mscorlib_System_GuidTraitsE6InvokeEPF20mscorlib_System_GuidPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2605992,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraits29mscorlib_System_BooleanTraitsS1_S1_E6InvokeEPFPvS3_bbbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($args) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)!=(0);
 $11 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$2,$6,$10)|0);
 STACKTOP = sp;return ($11|0);
}
function __Z51mscorlib_System_Guid_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_ICustomFormatter_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_IFormatProvider_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71mscorlib_System_IndexOutOfRangeException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_InvalidCastException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z70mscorlib_System_InvalidOperationException_m__ctor_mscorlib_System_VoidP41mscorlib_System_InvalidOperationException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2607520);
 __THREW__ = 0;
 invoke_v(893);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3071560>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233079);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z119mscorlib_System_InvalidOperationException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ExceptionP41mscorlib_System_InvalidOperationExceptionP22mscorlib_System_StringP25mscorlib_System_Exception($__this,$message,$innerException) {
 $__this = $__this|0;
 $message = $message|0;
 $innerException = $innerException|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2607616);
 __THREW__ = 0;
 invoke_viii(702,($__this|0),($message|0),($innerException|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233079);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z72mscorlib_System_InvalidOperationException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z65mscorlib_System_LoaderOptimization_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z76mscorlib_System_LoaderOptimization_CustomAttributesCacheGenerator_DomainMaskP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 __Z62mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_ObsoleteAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_LoaderOptimization_CustomAttributesCacheGenerator_DisallowBindingsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 __Z62mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_ObsoleteAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z72mscorlib_System_Math_m_Abs_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = Math_fround(0), $G_B3_0$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2608688);
 $0 = !($value >= Math_fround(0.0));
 if ($0) {
  $1 = Math_fround(-$value);
  $G_B3_0$0 = $1;
 } else {
  $G_B3_0$0 = $value;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($G_B3_0$0));
}
function __Z70mscorlib_System_Math_m_Abs_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2608736);
 __THREW__ = 0;
 invoke_v(894);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($value|0)==(-2147483648);
  if (!($2)) {
   $18 = ($value|0)>(-1);
   $19 = (0 - ($value))|0;
   $G_B5_0$0 = $18 ? $value : $19;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B5_0$0|0);
  }
  $5 = HEAP32[3071704>>2]|0;
  __THREW__ = 0;
  $6 = (invoke_iii(783,(0|0),($5|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2635888|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vii(1971,($11|0),($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3838,($11|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Math_m_Abs_mscorlib_System_Int64_mscorlib_System_Int64P22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2608784);
 __THREW__ = 0;
 invoke_v(895);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($0|0)==(0);
  $5 = ($1|0)==(-2147483648);
  $6 = $4 & $5;
  if (!($6)) {
   $22 = ($1|0)>(-1);
   $23 = ($1|0)==(-1);
   $24 = ($0>>>0)>(4294967295);
   $25 = $23 & $24;
   $26 = $22 | $25;
   $27 = (_i64Subtract(0,0,($0|0),($1|0))|0);
   $28 = tempRet0;
   $29 = $26 ? $0 : $27;
   $30 = $26 ? $1 : $28;
   __ZN16StackTraceSentryD2Ev(0);
   tempRet0 = $30;
   STACKTOP = sp;return ($29|0);
  }
  $9 = HEAP32[3071760>>2]|0;
  __THREW__ = 0;
  $10 = (invoke_iii(783,(0|0),($9|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2635888|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_ii(3469,(2635888|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     invoke_vii(1971,($15|0),($10|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3838,($15|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z28mscorlib_System_Math_m_FloorP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2608832);
 $0 = HEAP32[2608880>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2608888|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2608880>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (+invoke_dd($7|0,(+$d)));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$8);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return +0;
}
function __Z26mscorlib_System_Math_m_MaxP22mscorlib_System_Objectii($__this,$val1,$val2) {
 $__this = $__this|0;
 $val1 = $val1|0;
 $val2 = $val2|0;
 var $0 = 0, $_stackTraceSentry = 0, $val1$val2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2608928);
 $0 = ($val1|0)>($val2|0);
 $val1$val2 = $0 ? $val1 : $val2;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($val1$val2|0);
}
function __Z26mscorlib_System_Math_m_CosP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2609168);
 $0 = HEAP32[2609216>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2609224|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2609216>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (+invoke_dd($7|0,(+$d)));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$8);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return +0;
}
function __Z27mscorlib_System_Math_m_AcosP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2609256);
 $0 = HEAP32[2609304>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2609312|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2609304>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (+invoke_dd($7|0,(+$d)));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$8);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return +0;
}
function __Z27mscorlib_System_Math_m_AsinP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2609352);
 $0 = HEAP32[2609400>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2609408|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2609400>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (+invoke_dd($7|0,(+$d)));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$8);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return +0;
}
function __Z26mscorlib_System_Math_m_PowP22mscorlib_System_Objectdd($__this,$x,$y) {
 $__this = $__this|0;
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2609448);
 $0 = HEAP32[2609496>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2609504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2609496>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (+invoke_ddd($7|0,(+$x),(+$y)));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$8);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return +0;
}
function __Z27mscorlib_System_Math_m_SqrtP22mscorlib_System_Objectd($__this,$d) {
 $__this = $__this|0;
 $d = +$d;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2609552);
 $0 = HEAP32[2609600>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2609608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2609600>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (+invoke_dd($7|0,(+$d)));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (+$8);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return +0;
}
function __ZN12FuncInvoker2I28mscorlib_System_DoubleTraitsS0_S0_E6InvokeEPFdPvddES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = +HEAPF64[$3>>3];
 $5 = (+FUNCTION_TABLE_didd[$func & 3]($obj,$1,$4));
 HEAPF64[$ret>>3] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2198192,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z78mscorlib_System_Math_CustomAttributesCacheGenerator_mscorlib_System_Math_m_MaxP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z78mscorlib_System_Math_CustomAttributesCacheGenerator_mscorlib_System_Math_m_MinP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z79mscorlib_System_Math_CustomAttributesCacheGenerator_mscorlib_System_Math_m_SqrtP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z66mscorlib_System_MemberAccessException_m__ctor_mscorlib_System_VoidP37mscorlib_System_MemberAccessException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2610232);
 __THREW__ = 0;
 invoke_v(896);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3071776>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233062);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z68mscorlib_System_MemberAccessException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_MethodAccessException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z45mscorlib_System_MissingFieldException_m__ctorP37mscorlib_System_MissingFieldExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2610928);
 __THREW__ = 0;
 invoke_vii(1950,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233071);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z90mscorlib_System_MissingMemberException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP38mscorlib_System_MissingMemberExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2611344);
 __THREW__ = 0;
 invoke_vii(1948,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233070);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z51mscorlib_System_MissingFieldException_m_get_MessageP37mscorlib_System_MissingFieldException($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2610976);
 __THREW__ = 0;
 invoke_v(897);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 52|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    $7 = (invoke_ii(2448,($__this|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    } else {
     $$0 = $7;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $10 = HEAP32[3071856>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iii(783,(0|0),($10|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[$2>>2]|0;
    $15 = (($__this) + 56|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iiiii(98,(0|0),($11|0),($14|0),($16|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $$0 = $17;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_MissingMemberException_m_get_MessageP38mscorlib_System_MissingMemberException($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2611488);
 __THREW__ = 0;
 invoke_v(898);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 52|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    $7 = (invoke_ii(1906,($__this|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    } else {
     $$0 = $7;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $10 = HEAP32[3071928>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iii(783,(0|0),($10|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[$2>>2]|0;
    $15 = (($__this) + 56|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iiiii(98,(0|0),($11|0),($14|0),($16|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $$0 = $17;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_MissingFieldException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z113mscorlib_System_MissingMemberException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP38mscorlib_System_MissingMemberExceptionP22mscorlib_System_StringS2_($__this,$className,$memberName) {
 $__this = $__this|0;
 $className = $className|0;
 $memberName = $memberName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2611392);
 __THREW__ = 0;
 invoke_vi(2742,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 52|0);
  HEAP32[$2>>2] = $className;
  $3 = (($__this) + 56|0);
  HEAP32[$3>>2] = $memberName;
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233070);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z54mscorlib_System_MissingMemberException_m_GetObjectDataP38mscorlib_System_MissingMemberExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2611440);
 __THREW__ = 0;
 invoke_v(899);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $context;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $0;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  __THREW__ = 0;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  invoke_viii(544,($__this|0),($info|0),($tmpcast$byval_copy|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = (($__this) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3072000>>2]|0;
    __THREW__ = 0;
    invoke_viii(621,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = (($__this) + 56|0);
     $23 = HEAP32[$22>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[3072008>>2]|0;
      __THREW__ = 0;
      invoke_viii(621,($info|0),($26|0),($23|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = (($__this) + 60|0);
       $30 = HEAP32[$29>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($info|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        $33 = HEAP32[3072016>>2]|0;
        __THREW__ = 0;
        invoke_viii(621,($info|0),($33|0),($30|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if (!($35)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($36|0);
 // unreachable;
}
function __Z69mscorlib_System_MissingMemberException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z52mscorlib_System_MissingMethodException_m_get_MessageP38mscorlib_System_MissingMethodException($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2612144);
 __THREW__ = 0;
 invoke_v(900);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 52|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    $7 = (invoke_ii(2448,($__this|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    } else {
     $$0 = $7;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $10 = HEAP32[3072104>>2]|0;
   __THREW__ = 0;
   $11 = (invoke_iii(783,(0|0),($10|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[$2>>2]|0;
    $15 = (($__this) + 56|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iiiii(98,(0|0),($11|0),($14|0),($16|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $$0 = $17;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_MissingMethodException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_MonoCustomAttrs_AttributeInfo_m__ctorP45mscorlib_System_MonoCustomAttrs_AttributeInfoP39mscorlib_System_AttributeUsageAttributei($__this,$usage,$inheritanceLevel) {
 $__this = $__this|0;
 $usage = $usage|0;
 $inheritanceLevel = $inheritanceLevel|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2612536);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $usage;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $inheritanceLevel;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57mscorlib_System_MonoCustomAttrs_AttributeInfo_m_get_UsageP45mscorlib_System_MonoCustomAttrs_AttributeInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2612584);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_MonoCustomAttrs_AttributeInfo_m_get_InheritanceLevelP45mscorlib_System_MonoCustomAttrs_AttributeInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2612632);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z40mscorlib_System_MonoCustomAttrs_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613048);
 HEAP32[$0>>2] = 2047416;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2614744|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = HEAP32[((2614744 + 80|0))>>2]|0;
   $7 = (($6) + 4|0);
   HEAP32[$7>>2] = $1;
   __THREW__ = 0;
   (invoke_ii(2996,(2159288|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2159288|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vii(1760,($10|0),32767);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2614744|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = HEAP32[((2614744 + 80|0))>>2]|0;
       $18 = (($17) + 8|0);
       HEAP32[$18>>2] = $10;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
}
function __Z53mscorlib_System_MonoCustomAttrs_m_IsUserCattrProviderP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613096);
 __THREW__ = 0;
 (invoke_ii(2996,(2242320|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2735,($obj|0),(2242320|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2621328|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_iii(2735,($3|0),(2621328|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = ($8|0)==(0|0);
      if (!($11)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2374224|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       $16 = (invoke_iii(2735,($3|0),(2374224|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        $19 = ($16|0)==(0|0);
        if (!($19)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2242320|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         $22 = (invoke_iii(2735,($obj|0),(2242320|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          $25 = ($22|0)==(0|0);
          if (!($25)) {
           $$0 = 1;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2614744|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           $28 = HEAP8[((2614744 + 116|0))>>0]|0;
           $29 = ($28<<24>>24)==(0);
           if ($29) {
            __THREW__ = 0;
            (invoke_ii(2996,(2614744|0))|0);
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if ($31) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2614744|0))|0);
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if ($33) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2614744|0));
            $34 = __THREW__; __THREW__ = 0;
            $35 = $34&1;
            if ($35) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2614744|0))|0);
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if (!($37)) {
            $38 = HEAP32[((2614744 + 80|0))>>2]|0;
            $39 = HEAP32[$38>>2]|0;
            $40 = ($39|0)==(0|0);
            if ($40) {
             HEAP32[$0>>2] = 1285000;
             __THREW__ = 0;
             ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
             $41 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($41|0));
             $44 = __THREW__; __THREW__ = 0;
             $45 = $44&1;
             if ($45) {
              break;
             }
             __THREW__ = 0;
             $46 = (invoke_iii(2730,(2238288|0),($41|0))|0);
             $47 = __THREW__; __THREW__ = 0;
             $48 = $47&1;
             if ($48) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2614744|0))|0);
             $49 = __THREW__; __THREW__ = 0;
             $50 = $49&1;
             if ($50) {
              break;
             }
             $51 = HEAP8[((2614744 + 116|0))>>0]|0;
             $52 = ($51<<24>>24)==(0);
             if ($52) {
              __THREW__ = 0;
              (invoke_ii(2996,(2614744|0))|0);
              $53 = __THREW__; __THREW__ = 0;
              $54 = $53&1;
              if ($54) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2614744|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if ($56) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3839,(2614744|0));
              $57 = __THREW__; __THREW__ = 0;
              $58 = $57&1;
              if ($58) {
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2614744|0))|0);
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if ($60) {
              break;
             }
             $61 = HEAP32[((2614744 + 80|0))>>2]|0;
             HEAP32[$61>>2] = $46;
            }
            __THREW__ = 0;
            invoke_vi(3799,($obj|0));
            $62 = __THREW__; __THREW__ = 0;
            $63 = $62&1;
            if (!($63)) {
             __THREW__ = 0;
             $64 = (invoke_ii(1782,($obj|0))|0);
             $65 = __THREW__; __THREW__ = 0;
             $66 = $65&1;
             if (!($66)) {
              __THREW__ = 0;
              invoke_vi(3799,($64|0));
              $67 = __THREW__; __THREW__ = 0;
              $68 = $67&1;
              if (!($68)) {
               __THREW__ = 0;
               $69 = (invoke_iii(2730,(2238288|0),($64|0))|0);
               $70 = __THREW__; __THREW__ = 0;
               $71 = $70&1;
               if (!($71)) {
                __THREW__ = 0;
                (invoke_ii(2996,(2614744|0))|0);
                $72 = __THREW__; __THREW__ = 0;
                $73 = $72&1;
                if ($73) {
                 break;
                }
                $74 = HEAP8[((2614744 + 116|0))>>0]|0;
                $75 = ($74<<24>>24)==(0);
                if ($75) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2614744|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2614744|0))|0);
                 $78 = __THREW__; __THREW__ = 0;
                 $79 = $78&1;
                 if ($79) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3839,(2614744|0));
                 $80 = __THREW__; __THREW__ = 0;
                 $81 = $80&1;
                 if ($81) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2614744|0))|0);
                $82 = __THREW__; __THREW__ = 0;
                $83 = $82&1;
                if ($83) {
                 break;
                }
                $84 = HEAP32[((2614744 + 80|0))>>2]|0;
                $85 = HEAP32[$84>>2]|0;
                $86 = ($69|0)!=($85|0);
                $$0 = $86;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_MonoCustomAttrs_m_GetCustomAttributesInternalP22mscorlib_System_ObjectS0_P20mscorlib_System_Typeb($__this,$obj,$attributeType,$pseudoAttrs) {
 $__this = $__this|0;
 $obj = $obj|0;
 $attributeType = $attributeType|0;
 $pseudoAttrs = $pseudoAttrs|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613144);
 $0 = HEAP32[2613192>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2613200|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2613192>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($obj|0),($attributeType|0),($pseudoAttrs|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_MonoCustomAttrs_m_GetPseudoCustomAttributesP22mscorlib_System_ObjectS0_P20mscorlib_System_Type($__this,$obj,$attributeType) {
 $__this = $__this|0;
 $obj = $obj|0;
 $attributeType = $attributeType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613328);
 __THREW__ = 0;
 (invoke_ii(2996,(2425520|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($obj|0),(2425520|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    do {
     if ($5) {
      __THREW__ = 0;
      (invoke_ii(2996,(2407016|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break L1;
      }
      __THREW__ = 0;
      $22 = (invoke_iii(2735,($obj|0),(2407016|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break L1;
      }
      $25 = ($22|0)==(0|0);
      if (!($25)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2407016|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break L1;
       }
       __THREW__ = 0;
       $28 = (invoke_iii(2769,($obj|0),(2407016|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($28|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break L1;
       }
       __THREW__ = 0;
       $33 = (invoke_ii(2207,($28|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break L1;
       } else {
        $V_0$0 = $33;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2433064|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break L1;
      }
      __THREW__ = 0;
      $38 = (invoke_iii(2735,($obj|0),(2433064|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break L1;
      }
      $41 = ($38|0)==(0|0);
      if (!($41)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2433064|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break L1;
       }
       __THREW__ = 0;
       $44 = (invoke_iii(2769,($obj|0),(2433064|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3799,($44|0));
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break L1;
       }
       __THREW__ = 0;
       $49 = (invoke_ii(2287,($44|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break L1;
       } else {
        $V_0$0 = $49;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2242320|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break L1;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2735,($obj|0),(2242320|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break L1;
      }
      $57 = ($54|0)==(0|0);
      if ($57) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2242320|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       break L1;
      }
      __THREW__ = 0;
      $60 = (invoke_iii(2769,($obj|0),(2242320|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($60|0));
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break L1;
      }
      __THREW__ = 0;
      $65 = (invoke_ii(1900,($60|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break L1;
      } else {
       $V_0$0 = $65;
      }
     } else {
      __THREW__ = 0;
      (invoke_ii(2996,(2425520|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break L1;
      }
      __THREW__ = 0;
      $12 = (invoke_iii(2769,($obj|0),(2425520|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break L1;
      }
      __THREW__ = 0;
      invoke_vi(3799,($12|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if ($16) {
       break L1;
      }
      __THREW__ = 0;
      $17 = (invoke_ii(2258,($12|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break L1;
      } else {
       $V_0$0 = $17;
      }
     }
    } while(0);
    $68 = ($attributeType|0)==(0|0);
    $69 = ($V_0$0|0)==(0|0);
    $or$cond = $68 | $69;
    if ($or$cond) {
     $$0 = $V_0$0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $70 = (($V_0$0) + 12|0);
    $71 = (($V_0$0) + 16|0);
    $V_1$0 = 0;
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($V_0$0|0));
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if ($134) {
      label = 4;
      break;
     }
     $135 = HEAP32[$70>>2]|0;
     $136 = ($V_1$0|0)<($135|0);
     if (!($136)) {
      label = 59;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($V_0$0|0));
     $137 = __THREW__; __THREW__ = 0;
     $138 = $137&1;
     if ($138) {
      label = 4;
      break;
     }
     $72 = HEAP32[$70>>2]|0;
     $73 = ($V_1$0>>>0)<($72>>>0);
     if (!($73)) {
      __THREW__ = 0;
      $74 = (invoke_i(132)|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($74|0));
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       label = 4;
       break;
      }
     }
     $79 = HEAP32[$V_0$0>>2]|0;
     $80 = (($79) + 92|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = Math_imul($81, $V_1$0)|0;
     $83 = (($71) + ($82)|0);
     $84 = HEAP32[$83>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($84|0));
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $87 = (invoke_ii(1782,($84|0))|0);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($attributeType|0));
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $92 = (invoke_iiii(1640,(2235992|0),($attributeType|0),($87|0))|0);
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      label = 4;
      break;
     }
     $95 = (($V_1$0) + 1)|0;
     if ($92) {
      label = 42;
      break;
     } else {
      $V_1$0 = $95;
     }
    }
    if ((label|0) == 4) {
     $6 = ___cxa_find_matching_catch()|0;
     $7 = tempRet0;
     $lpad$phi$index = $6;$lpad$phi$index2 = $7;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 42) {
     __THREW__ = 0;
     invoke_vi(3799,($V_0$0|0));
     $96 = __THREW__; __THREW__ = 0;
     $97 = $96&1;
     if ($97) {
      break;
     }
     $98 = HEAP32[$70>>2]|0;
     $99 = ($98|0)==(1);
     if ($99) {
      $$0 = $V_0$0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $100 = __THREW__; __THREW__ = 0;
     $101 = $100&1;
     if ($101) {
      break;
     }
     __THREW__ = 0;
     $102 = (invoke_iii(2768,(1167664|0),1)|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($V_0$0|0));
     $105 = __THREW__; __THREW__ = 0;
     $106 = $105&1;
     if ($106) {
      break;
     }
     $107 = HEAP32[$70>>2]|0;
     $108 = ($V_1$0>>>0)<($107>>>0);
     if (!($108)) {
      __THREW__ = 0;
      $109 = (invoke_i(132)|0);
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($109|0));
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       break;
      }
     }
     $114 = HEAP32[$V_0$0>>2]|0;
     $115 = (($114) + 92|0);
     $116 = HEAP32[$115>>2]|0;
     $117 = Math_imul($116, $V_1$0)|0;
     $118 = (($71) + ($117)|0);
     $119 = HEAP32[$118>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($102|0));
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if ($121) {
      break;
     }
     $122 = (($102) + 12|0);
     $123 = HEAP32[$122>>2]|0;
     $124 = ($123|0)==(0);
     if ($124) {
      __THREW__ = 0;
      $125 = (invoke_i(132)|0);
      $126 = __THREW__; __THREW__ = 0;
      $127 = $126&1;
      if ($127) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($125|0));
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if ($129) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($102|0),($119|0));
     $130 = __THREW__; __THREW__ = 0;
     $131 = $130&1;
     if ($131) {
      break;
     }
     $132 = (($102) + 16|0);
     HEAP32[$132>>2] = $119;
     $$0 = $102;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    else if ((label|0) == 59) {
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $139 = __THREW__; __THREW__ = 0;
     $140 = $139&1;
     if ($140) {
      break;
     }
     __THREW__ = 0;
     $141 = (invoke_iii(2768,(1167664|0),0)|0);
     $142 = __THREW__; __THREW__ = 0;
     $143 = $142&1;
     if ($143) {
      break;
     }
     $$0 = $141;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_MonoCustomAttrs_m_GetCustomAttributesBaseP22mscorlib_System_ObjectS0_P20mscorlib_System_Type($__this,$obj,$attributeType) {
 $__this = $__this|0;
 $obj = $obj|0;
 $attributeType = $attributeType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613376);
 __THREW__ = 0;
 $0 = (invoke_iii(1130,0,($obj|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    __THREW__ = 0;
    invoke_vi(3799,($obj|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_iiiii(328,(2243192|0),($obj|0),($attributeType|0),1)|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $V_0$0 = $7;
   } else {
    __THREW__ = 0;
    $10 = (invoke_iiiii(185,0,($obj|0),($attributeType|0),0)|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    } else {
     $V_0$0 = $10;
    }
   }
   __THREW__ = 0;
   $13 = (invoke_iiii(1200,0,($obj|0),($attributeType|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = ($13|0)==(0|0);
    if ($16) {
     $$0 = $V_0$0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($V_0$0|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($V_0$0) + 12|0);
     $20 = HEAP32[$19>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($13|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = (($13) + 12|0);
      $24 = HEAP32[$23>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(1167664|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       $27 = (($24) + ($20))|0;
       __THREW__ = 0;
       $28 = (invoke_iii(2768,(1167664|0),($27|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        invoke_vi(3799,($V_0$0|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $33 = HEAP32[$19>>2]|0;
         __THREW__ = 0;
         invoke_viiii(140,(0|0),($V_0$0|0),($28|0),($33|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if (!($35)) {
          __THREW__ = 0;
          invoke_vi(3799,($V_0$0|0));
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if (!($37)) {
           $38 = HEAP32[$19>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            $41 = HEAP32[$23>>2]|0;
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($13|0),0,($28|0),($38|0),($41|0));
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if (!($43)) {
             $$0 = $28;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker2I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvS5_b($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z52mscorlib_System_MonoCustomAttrs_m_GetCustomAttributeP22mscorlib_System_ObjectS0_P20mscorlib_System_Typeb($__this,$obj,$attributeType,$inherit) {
 $__this = $__this|0;
 $obj = $obj|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613424);
 __THREW__ = 0;
 invoke_v(901);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iiiii(187,0,($obj|0),($attributeType|0),($inherit|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = HEAP32[$7>>2]|0;
      $15 = ($14|0)<(2);
      if (!($15)) {
       $16 = HEAP32[3072176>>2]|0;
       __THREW__ = 0;
       $17 = (invoke_iiiii(98,(0|0),($16|0),($obj|0),($attributeType|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2375288|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       __THREW__ = 0;
       $22 = (invoke_ii(3469,(2375288|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(1844,($22|0),($17|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($22|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       // unreachable;
      }
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = HEAP32[$7>>2]|0;
       $32 = ($31|0)==(0);
       if ($32) {
        __THREW__ = 0;
        $33 = (invoke_i(132)|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($33|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
       }
       $38 = (($2) + 16|0);
       $39 = HEAP32[$38>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2151624|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if (!($41)) {
        __THREW__ = 0;
        $42 = (invoke_iii(2769,($39|0),(2151624|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if (!($44)) {
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z181mscorlib_System_MonoCustomAttrs_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Reflection_ICustomAttributeProvider_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectS0_P20mscorlib_System_Typeb($__this,$obj,$attributeType,$inherit) {
 $__this = $__this|0;
 $obj = $obj|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $$0$in = 0, $$02$off0 = 0, $$attributeType = 0, $$byval_copy8 = 0, $$not6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $G_B23_0$0 = 0, $V_1$0 = 0, $V_10$0 = 0, $V_11$0 = 0, $V_14$0$in = 0, $V_6$0 = 0, $V_7$0 = 0, $_stackTraceSentry = 0, $brmerge$demorgan = 0, $brmerge7 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613472);
 __THREW__ = 0;
 invoke_v(902);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if (!($3)) {
   $4 = ($obj|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    $13 = (invoke_ii(3469,(2560584|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[3072288>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($13|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($13|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    // unreachable;
   }
   $21 = ($attributeType|0)==(0|0);
   if ($21) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2560584|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = HEAP32[3072296>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($24|0),($27|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($24|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    // unreachable;
   }
   HEAP32[$0>>2] = 2640016;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
   $32 = (invoke_iii(772,(0|0),($$byval_copy8|0))|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if (!($34)) {
    $35 = ($32|0)==($attributeType|0);
    $$attributeType = $35 ? 0 : $attributeType;
    __THREW__ = 0;
    $36 = (invoke_iiii(1201,0,($obj|0),($$attributeType|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     if (!($inherit)) {
      __THREW__ = 0;
      invoke_vi(3799,($36|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      $41 = (($36) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = ($42|0)==(1);
      if ($43) {
       $44 = ($$attributeType|0)==(0|0);
       if ($44) {
        __THREW__ = 0;
        invoke_vi(3799,($36|0));
        $105 = __THREW__; __THREW__ = 0;
        $106 = $105&1;
        if ($106) {
         break;
        }
        $107 = HEAP32[$41>>2]|0;
        $108 = ($107|0)==(0);
        if ($108) {
         __THREW__ = 0;
         $109 = (invoke_i(132)|0);
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         if ($111) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($109|0));
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if ($113) {
          break;
         }
        }
        $114 = (($36) + 16|0);
        $115 = HEAP32[$114>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($115|0));
        $116 = __THREW__; __THREW__ = 0;
        $117 = $116&1;
        if ($117) {
         break;
        }
        __THREW__ = 0;
        $118 = (invoke_ii(1782,($115|0))|0);
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         break;
        }
        __THREW__ = 0;
        $121 = (invoke_iiii(688,(0|0),($118|0),1)|0);
        $122 = __THREW__; __THREW__ = 0;
        $123 = $122&1;
        if ($123) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1167664|0))|0);
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break;
        }
        __THREW__ = 0;
        $126 = (invoke_iii(2769,($121|0),(1167664|0))|0);
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if ($128) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($36|0));
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         break;
        }
        $131 = HEAP32[$41>>2]|0;
        $132 = ($131|0)==(0);
        if ($132) {
         __THREW__ = 0;
         $133 = (invoke_i(132)|0);
         $134 = __THREW__; __THREW__ = 0;
         $135 = $134&1;
         if ($135) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($133|0));
         $136 = __THREW__; __THREW__ = 0;
         $137 = $136&1;
         if ($137) {
          break;
         }
        }
        $138 = HEAP32[$114>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($126|0));
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         break;
        }
        $141 = (($126) + 12|0);
        $142 = HEAP32[$141>>2]|0;
        $143 = ($142|0)==(0);
        if ($143) {
         __THREW__ = 0;
         $144 = (invoke_i(132)|0);
         $145 = __THREW__; __THREW__ = 0;
         $146 = $145&1;
         if ($146) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($144|0));
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($126|0),($138|0));
        $149 = __THREW__; __THREW__ = 0;
        $150 = $149&1;
        if ($150) {
         break;
        }
        $151 = (($126) + 16|0);
        HEAP32[$151>>2] = $138;
        $$0$in = $126;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0$in|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($36|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       $47 = HEAP32[$41>>2]|0;
       $48 = ($47|0)==(0);
       if ($48) {
        __THREW__ = 0;
        $49 = (invoke_i(132)|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($49|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break;
        }
       }
       $54 = (($36) + 16|0);
       $55 = HEAP32[$54>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($55|0));
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if ($57) {
        break;
       }
       __THREW__ = 0;
       $58 = (invoke_ii(1782,($55|0))|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($$attributeType|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
       __THREW__ = 0;
       $63 = (invoke_iiii(1640,(2235992|0),($$attributeType|0),($58|0))|0);
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break;
       }
       if (!($63)) {
        __THREW__ = 0;
        $97 = (invoke_iiii(688,(0|0),($$attributeType|0),0)|0);
        $98 = __THREW__; __THREW__ = 0;
        $99 = $98&1;
        if ($99) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1167664|0))|0);
        $100 = __THREW__; __THREW__ = 0;
        $101 = $100&1;
        if ($101) {
         break;
        }
        __THREW__ = 0;
        $102 = (invoke_iii(2769,($97|0),(1167664|0))|0);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         break;
        } else {
         $$0$in = $102;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0$in|0);
       }
       __THREW__ = 0;
       $66 = (invoke_iiii(688,(0|0),($$attributeType|0),1)|0);
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1167664|0))|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break;
       }
       __THREW__ = 0;
       $71 = (invoke_iii(2769,($66|0),(1167664|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($36|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        break;
       }
       $76 = HEAP32[$41>>2]|0;
       $77 = ($76|0)==(0);
       if ($77) {
        __THREW__ = 0;
        $78 = (invoke_i(132)|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($78|0));
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         break;
        }
       }
       $83 = HEAP32[$54>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($71|0));
       $84 = __THREW__; __THREW__ = 0;
       $85 = $84&1;
       if ($85) {
        break;
       }
       $86 = (($71) + 12|0);
       $87 = HEAP32[$86>>2]|0;
       $88 = ($87|0)==(0);
       if ($88) {
        __THREW__ = 0;
        $89 = (invoke_i(132)|0);
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($89|0));
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($71|0),($83|0));
       $94 = __THREW__; __THREW__ = 0;
       $95 = $94&1;
       if ($95) {
        break;
       }
       $96 = (($71) + 16|0);
       HEAP32[$96>>2] = $83;
       $$0$in = $71;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0$in|0);
      }
     }
     $152 = ($$attributeType|0)!=(0|0);
     if ($152) {
      __THREW__ = 0;
      invoke_vi(3799,($$attributeType|0));
      $153 = __THREW__; __THREW__ = 0;
      $154 = $153&1;
      if ($154) {
       break;
      }
      __THREW__ = 0;
      $155 = (invoke_iii(2734,(2234760|0),($$attributeType|0))|0);
      $156 = __THREW__; __THREW__ = 0;
      $157 = $156&1;
      if ($157) {
       break;
      }
      $brmerge$demorgan = $155 & $inherit;
      if ($brmerge$demorgan) {
       __THREW__ = 0;
       $158 = (invoke_iii(1133,0,($$attributeType|0))|0);
       $159 = __THREW__; __THREW__ = 0;
       $160 = $159&1;
       if ($160) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($158|0));
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       if ($162) {
        break;
       }
       __THREW__ = 0;
       $163 = (invoke_ii(1793,($158|0))|0);
       $164 = __THREW__; __THREW__ = 0;
       $165 = $164&1;
       if ($165) {
        break;
       } else {
        $$02$off0 = $163;
       }
      } else {
       $$02$off0 = $inherit;
      }
     } else {
      $$02$off0 = $inherit;
     }
     __THREW__ = 0;
     invoke_vi(3799,($36|0));
     $166 = __THREW__; __THREW__ = 0;
     $167 = $166&1;
     if (!($167)) {
      $168 = (($36) + 12|0);
      $169 = HEAP32[$168>>2]|0;
      $170 = ($169|0)>(15);
      if ($170) {
       $G_B23_0$0 = 16;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($36|0));
       $171 = __THREW__; __THREW__ = 0;
       $172 = $171&1;
       if ($172) {
        break;
       }
       $173 = HEAP32[$168>>2]|0;
       $G_B23_0$0 = $173;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2313960|0))|0);
      $174 = __THREW__; __THREW__ = 0;
      $175 = $174&1;
      if (!($175)) {
       __THREW__ = 0;
       $176 = (invoke_ii(3469,(2313960|0))|0);
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if (!($178)) {
        __THREW__ = 0;
        invoke_vii(1822,($176|0),($G_B23_0$0|0));
        $179 = __THREW__; __THREW__ = 0;
        $180 = $179&1;
        if (!($180)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2304136|0))|0);
         $181 = __THREW__; __THREW__ = 0;
         $182 = $181&1;
         if (!($182)) {
          __THREW__ = 0;
          $183 = (invoke_ii(3469,(2304136|0))|0);
          $184 = __THREW__; __THREW__ = 0;
          $185 = $184&1;
          if (!($185)) {
           __THREW__ = 0;
           invoke_vii(1816,($183|0),($G_B23_0$0|0));
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if (!($187)) {
            $V_1$0 = $36;$V_6$0 = $obj;$V_7$0 = 0;
            L98: while(1) {
             $188 = (($V_1$0) + 12|0);
             $189 = (($V_1$0) + 16|0);
             $190 = ($V_7$0|0)==(0);
             $V_10$0 = 0;
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($V_1$0|0));
              $265 = __THREW__; __THREW__ = 0;
              $266 = $265&1;
              if ($266) {
               label = 3;
               break L98;
              }
              $267 = HEAP32[$188>>2]|0;
              $268 = ($V_10$0|0)<($267|0);
              if (!($268)) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($V_1$0|0));
              $269 = __THREW__; __THREW__ = 0;
              $270 = $269&1;
              if ($270) {
               label = 3;
               break L98;
              }
              $191 = HEAP32[$188>>2]|0;
              $192 = ($V_10$0>>>0)<($191>>>0);
              if (!($192)) {
               __THREW__ = 0;
               $193 = (invoke_i(132)|0);
               $194 = __THREW__; __THREW__ = 0;
               $195 = $194&1;
               if ($195) {
                label = 3;
                break L98;
               }
               __THREW__ = 0;
               invoke_vi(3302,($193|0));
               $196 = __THREW__; __THREW__ = 0;
               $197 = $196&1;
               if ($197) {
                label = 3;
                break L98;
               }
              }
              $198 = HEAP32[$V_1$0>>2]|0;
              $199 = (($198) + 92|0);
              $200 = HEAP32[$199>>2]|0;
              $201 = Math_imul($200, $V_10$0)|0;
              $202 = (($189) + ($201)|0);
              $203 = HEAP32[$202>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($203|0));
              $204 = __THREW__; __THREW__ = 0;
              $205 = $204&1;
              if ($205) {
               label = 3;
               break L98;
              }
              __THREW__ = 0;
              $206 = (invoke_ii(1782,($203|0))|0);
              $207 = __THREW__; __THREW__ = 0;
              $208 = $207&1;
              if ($208) {
               label = 3;
               break L98;
              }
              if ($152) {
               __THREW__ = 0;
               invoke_vi(3799,($$attributeType|0));
               $209 = __THREW__; __THREW__ = 0;
               $210 = $209&1;
               if ($210) {
                label = 3;
                break L98;
               }
               __THREW__ = 0;
               $211 = (invoke_iiii(1640,(2235992|0),($$attributeType|0),($206|0))|0);
               $212 = __THREW__; __THREW__ = 0;
               $213 = $212&1;
               if ($213) {
                label = 3;
                break L98;
               }
               if ($211) {
                label = 96;
               }
              } else {
               label = 96;
              }
              do {
               if ((label|0) == 96) {
                label = 0;
                __THREW__ = 0;
                invoke_vi(3799,($176|0));
                $214 = __THREW__; __THREW__ = 0;
                $215 = $214&1;
                if ($215) {
                 label = 3;
                 break L98;
                }
                __THREW__ = 0;
                $216 = (invoke_iiii(1643,(2310848|0),($176|0),($206|0))|0);
                $217 = __THREW__; __THREW__ = 0;
                $218 = $217&1;
                if ($218) {
                 label = 3;
                 break L98;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2612912|0))|0);
                $219 = __THREW__; __THREW__ = 0;
                $220 = $219&1;
                if ($220) {
                 label = 3;
                 break L98;
                }
                __THREW__ = 0;
                $221 = (invoke_iii(2769,($216|0),(2612912|0))|0);
                $222 = __THREW__; __THREW__ = 0;
                $223 = $222&1;
                if ($223) {
                 label = 3;
                 break L98;
                }
                $224 = ($221|0)!=(0|0);
                if ($224) {
                 __THREW__ = 0;
                 invoke_vi(3799,($221|0));
                 $225 = __THREW__; __THREW__ = 0;
                 $226 = $225&1;
                 if ($226) {
                  label = 3;
                  break L98;
                 }
                 __THREW__ = 0;
                 $227 = (invoke_ii(2450,($221|0))|0);
                 $228 = __THREW__; __THREW__ = 0;
                 $229 = $228&1;
                 if ($229) {
                  label = 3;
                  break L98;
                 } else {
                  $V_11$0 = $227;
                 }
                } else {
                 __THREW__ = 0;
                 $230 = (invoke_iii(1133,0,($206|0))|0);
                 $231 = __THREW__; __THREW__ = 0;
                 $232 = $231&1;
                 if ($232) {
                  label = 3;
                  break L98;
                 } else {
                  $V_11$0 = $230;
                 }
                }
                if ($190) {
                 label = 108;
                } else {
                 __THREW__ = 0;
                 invoke_vi(3799,($V_11$0|0));
                 $233 = __THREW__; __THREW__ = 0;
                 $234 = $233&1;
                 if ($234) {
                  label = 3;
                  break L98;
                 }
                 __THREW__ = 0;
                 $235 = (invoke_ii(1793,($V_11$0|0))|0);
                 $236 = __THREW__; __THREW__ = 0;
                 $237 = $236&1;
                 if ($237) {
                  label = 3;
                  break L98;
                 }
                 if ($235) {
                  label = 108;
                 } else {
                  label = 117;
                 }
                }
                do {
                 if ((label|0) == 108) {
                  label = 0;
                  __THREW__ = 0;
                  invoke_vi(3799,($V_11$0|0));
                  $238 = __THREW__; __THREW__ = 0;
                  $239 = $238&1;
                  if ($239) {
                   label = 3;
                   break L98;
                  }
                  __THREW__ = 0;
                  $240 = (invoke_ii(1792,($V_11$0|0))|0);
                  $241 = __THREW__; __THREW__ = 0;
                  $242 = $241&1;
                  if ($242) {
                   label = 3;
                   break L98;
                  }
                  $$not6 = $224 ^ 1;
                  $brmerge7 = $240 | $$not6;
                  if (!($brmerge7)) {
                   if (!($224)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($221|0));
                   $243 = __THREW__; __THREW__ = 0;
                   $244 = $243&1;
                   if ($244) {
                    label = 3;
                    break L98;
                   }
                   __THREW__ = 0;
                   $245 = (invoke_ii(2451,($221|0))|0);
                   $246 = __THREW__; __THREW__ = 0;
                   $247 = $246&1;
                   if ($247) {
                    label = 3;
                    break L98;
                   }
                   $248 = ($245|0)==($V_7$0|0);
                   if (!($248)) {
                    label = 117;
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($183|0));
                  $249 = __THREW__; __THREW__ = 0;
                  $250 = $249&1;
                  if ($250) {
                   label = 3;
                   break L98;
                  }
                  __THREW__ = 0;
                  (invoke_iiii(1647,(2297624|0),($183|0),($203|0))|0);
                  $251 = __THREW__; __THREW__ = 0;
                  $252 = $251&1;
                  if ($252) {
                   label = 3;
                   break L98;
                  } else {
                   label = 117;
                  }
                 }
                } while(0);
                if ((label|0) == 117) {
                 label = 0;
                 if ($224) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2612912|0))|0);
                $253 = __THREW__; __THREW__ = 0;
                $254 = $253&1;
                if ($254) {
                 label = 3;
                 break L98;
                }
                __THREW__ = 0;
                $255 = (invoke_ii(3469,(2612912|0))|0);
                $256 = __THREW__; __THREW__ = 0;
                $257 = $256&1;
                if ($257) {
                 label = 3;
                 break L98;
                }
                __THREW__ = 0;
                invoke_viii(683,($255|0),($V_11$0|0),($V_7$0|0));
                $258 = __THREW__; __THREW__ = 0;
                $259 = $258&1;
                if ($259) {
                 label = 3;
                 break L98;
                }
                __THREW__ = 0;
                invoke_vi(3799,($176|0));
                $260 = __THREW__; __THREW__ = 0;
                $261 = $260&1;
                if ($261) {
                 label = 3;
                 break L98;
                }
                __THREW__ = 0;
                invoke_viiii(465,(2311184|0),($176|0),($206|0),($255|0));
                $262 = __THREW__; __THREW__ = 0;
                $263 = $262&1;
                if ($263) {
                 label = 3;
                 break L98;
                }
               }
              } while(0);
              $264 = (($V_10$0) + 1)|0;
              $V_10$0 = $264;
             }
             __THREW__ = 0;
             $271 = (invoke_iii(1132,0,($V_6$0|0))|0);
             $272 = __THREW__; __THREW__ = 0;
             $273 = $272&1;
             if ($273) {
              label = 4;
              break;
             }
             $274 = ($271|0)==(0|0);
             if ($274) {
              label = 131;
              break;
             }
             __THREW__ = 0;
             $275 = (invoke_iiii(1201,0,($271|0),($$attributeType|0))|0);
             $276 = __THREW__; __THREW__ = 0;
             $277 = $276&1;
             if ($277) {
              label = 4;
              break;
             }
             $278 = (($V_7$0) + 1)|0;
             if ($$02$off0) {
              $V_1$0 = $275;$V_6$0 = $271;$V_7$0 = $278;
             } else {
              label = 131;
              break;
             }
            }
            if ((label|0) == 3) {
             $5 = ___cxa_find_matching_catch()|0;
             $6 = tempRet0;
             $lpad$phi$index = $5;$lpad$phi$index3 = $6;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            else if ((label|0) == 4) {
             $7 = ___cxa_find_matching_catch()|0;
             $8 = tempRet0;
             $lpad$phi$index = $7;$lpad$phi$index3 = $8;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            else if ((label|0) == 131) {
             do {
              if ($152) {
               __THREW__ = 0;
               invoke_vi(3799,($$attributeType|0));
               $279 = __THREW__; __THREW__ = 0;
               $280 = $279&1;
               if ($280) {
                break L1;
               }
               __THREW__ = 0;
               $281 = (invoke_iii(2734,(2234232|0),($$attributeType|0))|0);
               $282 = __THREW__; __THREW__ = 0;
               $283 = $282&1;
               if ($283) {
                break L1;
               }
               if ($281) {
                label = 135;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($183|0));
               $300 = __THREW__; __THREW__ = 0;
               $301 = $300&1;
               if ($301) {
                break L1;
               }
               __THREW__ = 0;
               $302 = (invoke_iii(2729,(2296488|0),($183|0))|0);
               $303 = __THREW__; __THREW__ = 0;
               $304 = $303&1;
               if ($304) {
                break L1;
               }
               __THREW__ = 0;
               $305 = (invoke_iiii(688,(0|0),($$attributeType|0),($302|0))|0);
               $306 = __THREW__; __THREW__ = 0;
               $307 = $306&1;
               if ($307) {
                break L1;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(1167664|0))|0);
               $308 = __THREW__; __THREW__ = 0;
               $309 = $308&1;
               if ($309) {
                break L1;
               }
               __THREW__ = 0;
               $310 = (invoke_iii(2735,($305|0),(1167664|0))|0);
               $311 = __THREW__; __THREW__ = 0;
               $312 = $311&1;
               if ($312) {
                break L1;
               }
               $V_14$0$in = $310;
              } else {
               label = 135;
              }
             } while(0);
             if ((label|0) == 135) {
              HEAP32[$1>>2] = 2047984;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
              $284 = (invoke_iii(772,(0|0),($$byval_copy8|0))|0);
              $285 = __THREW__; __THREW__ = 0;
              $286 = $285&1;
              if ($286) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($183|0));
              $287 = __THREW__; __THREW__ = 0;
              $288 = $287&1;
              if ($288) {
               break;
              }
              __THREW__ = 0;
              $289 = (invoke_iii(2729,(2296488|0),($183|0))|0);
              $290 = __THREW__; __THREW__ = 0;
              $291 = $290&1;
              if ($291) {
               break;
              }
              __THREW__ = 0;
              $292 = (invoke_iiii(688,(0|0),($284|0),($289|0))|0);
              $293 = __THREW__; __THREW__ = 0;
              $294 = $293&1;
              if ($294) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(1167664|0))|0);
              $295 = __THREW__; __THREW__ = 0;
              $296 = $295&1;
              if ($296) {
               break;
              }
              __THREW__ = 0;
              $297 = (invoke_iii(2769,($292|0),(1167664|0))|0);
              $298 = __THREW__; __THREW__ = 0;
              $299 = $298&1;
              if ($299) {
               break;
              } else {
               $V_14$0$in = $297;
              }
             }
             __THREW__ = 0;
             invoke_vi(3799,($183|0));
             $313 = __THREW__; __THREW__ = 0;
             $314 = $313&1;
             if ($314) {
              break;
             }
             __THREW__ = 0;
             invoke_viiii(461,(2298680|0),($183|0),($V_14$0$in|0),0);
             $315 = __THREW__; __THREW__ = 0;
             $316 = $315&1;
             if ($316) {
              break;
             } else {
              $$0$in = $V_14$0$in;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0$in|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index3 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_MonoCustomAttrs_m_RetrieveAttributeUsageP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$attributeType) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613872);
 __THREW__ = 0;
 invoke_v(903);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   HEAP32[$0>>2] = 2047416;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==($attributeType|0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2159288|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2159288|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1760,($11|0),4);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     } else {
      $$0 = $11;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2614744|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP8[((2614744 + 116|0))>>0]|0;
     $19 = ($18<<24>>24)==(0);
     if ($19) {
      __THREW__ = 0;
      (invoke_ii(2996,(2614744|0))|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if ($21) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2614744|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2614744|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2614744|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = HEAP32[((2614744 + 80|0))>>2]|0;
      $29 = (($28) + 4|0);
      $30 = HEAP32[$29>>2]|0;
      __THREW__ = 0;
      $31 = (invoke_iiiii(187,0,($attributeType|0),($30|0),0)|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __THREW__ = 0;
       invoke_vi(3799,($31|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $36 = (($31) + 12|0);
        $37 = HEAP32[$36>>2]|0;
        $38 = ($37|0)==(0);
        if (!($38)) {
         __THREW__ = 0;
         invoke_vi(3799,($31|0));
         $69 = __THREW__; __THREW__ = 0;
         $70 = $69&1;
         if ($70) {
          break;
         }
         $71 = HEAP32[$36>>2]|0;
         $72 = ($71|0)<(2);
         if (!($72)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2603176|0))|0);
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           break;
          }
          __THREW__ = 0;
          $75 = (invoke_ii(3469,(2603176|0))|0);
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break;
          }
          $78 = HEAP32[3072376>>2]|0;
          __THREW__ = 0;
          invoke_vii(1940,($75|0),($78|0));
          $79 = __THREW__; __THREW__ = 0;
          $80 = $79&1;
          if ($80) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3838,($75|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($31|0));
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break;
         }
         $85 = HEAP32[$36>>2]|0;
         $86 = ($85|0)==(0);
         if ($86) {
          __THREW__ = 0;
          $87 = (invoke_i(132)|0);
          $88 = __THREW__; __THREW__ = 0;
          $89 = $88&1;
          if ($89) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($87|0));
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           break;
          }
         }
         $92 = (($31) + 16|0);
         $93 = HEAP32[$92>>2]|0;
         __THREW__ = 0;
         (invoke_ii(2996,(2159288|0))|0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         __THREW__ = 0;
         $96 = (invoke_iii(2769,($93|0),(2159288|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          break;
         }
         $$0 = $96;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($attributeType|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         __THREW__ = 0;
         $41 = (invoke_iii(2730,(2235944|0),($attributeType|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          $44 = ($41|0)==(0|0);
          if (!($44)) {
           __THREW__ = 0;
           invoke_vi(3799,($attributeType|0));
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            break;
           }
           __THREW__ = 0;
           $47 = (invoke_iii(2730,(2235944|0),($attributeType|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break;
           }
           __THREW__ = 0;
           $50 = (invoke_iii(1133,0,($47|0))|0);
           $51 = __THREW__; __THREW__ = 0;
           $52 = $51&1;
           if ($52) {
            break;
           }
           $53 = ($50|0)==(0|0);
           if (!($53)) {
            $$0 = $50;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2614744|0))|0);
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if (!($55)) {
           $56 = HEAP8[((2614744 + 116|0))>>0]|0;
           $57 = ($56<<24>>24)==(0);
           if ($57) {
            __THREW__ = 0;
            (invoke_ii(2996,(2614744|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2614744|0))|0);
            $60 = __THREW__; __THREW__ = 0;
            $61 = $60&1;
            if ($61) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3839,(2614744|0));
            $62 = __THREW__; __THREW__ = 0;
            $63 = $62&1;
            if ($63) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2614744|0))|0);
           $64 = __THREW__; __THREW__ = 0;
           $65 = $64&1;
           if (!($65)) {
            $66 = HEAP32[((2614744 + 80|0))>>2]|0;
            $67 = (($66) + 8|0);
            $68 = HEAP32[$67>>2]|0;
            $$0 = $68;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_MonoCustomAttrs_m_GetBaseP22mscorlib_System_ObjectS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613824);
 $0 = ($obj|0)==(0|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2242320|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_iii(2735,($obj|0),(2242320|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)==(0|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2242320|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(2769,($obj|0),(2242320|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($11|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_iii(2730,(2235944|0),($11|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     $$0 = $16;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2430720|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($obj|0),(2430720|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if (!($24)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2430720|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       $27 = (invoke_iii(2769,($obj|0),(2430720|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
       __THREW__ = 0;
       $30 = (invoke_iii(1131,0,($27|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break;
       }
       $$0 = $30;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2425520|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       $35 = (invoke_iii(2735,($obj|0),(2425520|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        $38 = ($35|0)==(0|0);
        if ($38) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2414216|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         __THREW__ = 0;
         $41 = (invoke_iii(2769,($obj|0),(2414216|0))|0);
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          $44 = ($41|0)==(0|0);
          if ($44) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          invoke_vi(3799,($41|0));
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if (!($46)) {
           __THREW__ = 0;
           $47 = (invoke_iii(2734,(2410608|0),($41|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if (!($49)) {
            if (!($47)) {
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            invoke_vi(3799,($41|0));
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if (!($51)) {
             __THREW__ = 0;
             $52 = (invoke_iii(2730,(2413776|0),($41|0))|0);
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if (!($54)) {
              $55 = ($52|0)==($41|0);
              if ($55) {
               $$0 = 0;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
              $$0 = $52;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z160mscorlib_System_MonoCustomAttrs_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Reflection_ICustomAttributeProvider_mscorlib_System_BooleanP22mscorlib_System_ObjectS0_b($__this,$obj,$inherit) {
 $__this = $__this|0;
 $obj = $obj|0;
 $inherit = $inherit|0;
 var $$0 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613520);
 __THREW__ = 0;
 invoke_v(904);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($obj|0)==(0|0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_ii(3469,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP32[3072344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($8|0),($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($8|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    // unreachable;
   }
   if ($inherit) {
    HEAP32[$0>>2] = 2640016;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $29 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    __THREW__ = 0;
    $32 = (invoke_iiiii(187,0,($obj|0),($29|0),1)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    } else {
     $$0 = $32;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $16 = (invoke_iiii(1201,0,($obj|0),(0|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    invoke_vi(3799,($16|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2756,(2224152|0),($16|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      (invoke_ii(2996,(1167664|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       $26 = (invoke_iii(2769,($21|0),(1167664|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $$0 = $26;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_MonoCustomAttrs_m_IsDefinedP22mscorlib_System_ObjectS0_P20mscorlib_System_Typeb($__this,$obj,$attributeType,$inherit) {
 $__this = $__this|0;
 $obj = $obj|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613568);
 __THREW__ = 0;
 invoke_v(905);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($attributeType|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3072360>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $17 = (invoke_iii(1130,0,($obj|0))|0);
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    if ($17) {
     __THREW__ = 0;
     invoke_vi(3799,($obj|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     $22 = (invoke_iiiii(329,(2243264|0),($obj|0),($attributeType|0),($inherit|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     } else {
      $$0 = $22;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $25 = (invoke_iiii(1203,0,($obj|0),($attributeType|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     if ($25) {
      $$0 = 1;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $28 = (invoke_iiii(1200,0,($obj|0),($attributeType|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      $31 = ($28|0)==(0|0);
      L21: do {
       if (!($31)) {
        $32 = (($28) + 12|0);
        $33 = (($28) + 16|0);
        $V_1$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($28|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          break;
         }
         $60 = HEAP32[$32>>2]|0;
         $61 = ($V_1$0|0)<($60|0);
         if (!($61)) {
          break L21;
         }
         __THREW__ = 0;
         invoke_vi(3799,($28|0));
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break;
         }
         $34 = HEAP32[$32>>2]|0;
         $35 = ($V_1$0>>>0)<($34>>>0);
         if (!($35)) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         $41 = HEAP32[$28>>2]|0;
         $42 = (($41) + 92|0);
         $43 = HEAP32[$42>>2]|0;
         $44 = Math_imul($43, $V_1$0)|0;
         $45 = (($33) + ($44)|0);
         $46 = HEAP32[$45>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($46|0));
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          break;
         }
         __THREW__ = 0;
         $49 = (invoke_ii(1782,($46|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($attributeType|0));
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break;
         }
         __THREW__ = 0;
         $54 = (invoke_iiii(1640,(2235992|0),($attributeType|0),($49|0))|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break;
         }
         $57 = (($V_1$0) + 1)|0;
         if ($54) {
          $$0 = 1;
          label = 35;
          break;
         } else {
          $V_1$0 = $57;
         }
        }
        if ((label|0) == 35) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $3 = ___cxa_find_matching_catch()|0;
        $4 = tempRet0;
        $lpad$phi$index = $3;$lpad$phi$index2 = $4;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
      } while(0);
      if (!($inherit)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      $64 = (invoke_iii(1132,0,($obj|0))|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if (!($66)) {
       $67 = ($64|0)==(0|0);
       if ($67) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       __THREW__ = 0;
       $68 = (invoke_iiiii(188,0,($64|0),($attributeType|0),1)|0);
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if (!($70)) {
        $$0 = $68;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS5_b($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z51mscorlib_System_MonoCustomAttrs_m_IsDefinedInternalP22mscorlib_System_ObjectS0_P20mscorlib_System_Type($__this,$obj,$AttributeType) {
 $__this = $__this|0;
 $obj = $obj|0;
 $AttributeType = $AttributeType|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613616);
 $0 = HEAP32[2613664>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2613672|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2613664>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($obj|0),($AttributeType|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59mscorlib_System_MonoCustomAttrs_m_GetBasePropertyDefinitionP22mscorlib_System_ObjectP39mscorlib_System_Reflection_PropertyInfo($__this,$_____property) {
 $__this = $__this|0;
 $_____property = $_____property|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0$in = 0, $V_4$0 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2613776);
 __THREW__ = 0;
 invoke_vi(3799,($_____property|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iiii(1668,(2434288|0),($_____property|0),1)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     label = 10;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_iii(2734,(2410608|0),($2|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     if ($12) {
      $V_0$0$in = $2;
     } else {
      label = 10;
     }
    }
    if ((label|0) == 10) {
     __THREW__ = 0;
     invoke_vi(3799,($_____property|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_iiii(1668,(2434352|0),($_____property|0),1)|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     } else {
      $V_0$0$in = $17;
     }
    }
    $20 = ($V_0$0$in|0)==(0|0);
    if ($20) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($V_0$0$in|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     __THREW__ = 0;
     $23 = (invoke_iii(2734,(2410608|0),($V_0$0$in|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      if (!($23)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3799,($V_0$0$in|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       $28 = (invoke_iii(2730,(2413776|0),($V_0$0$in|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        $31 = ($28|0)==(0|0);
        $32 = ($28|0)==($V_0$0$in|0);
        $or$cond = $31 | $32;
        if ($or$cond) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        invoke_vi(3799,($_____property|0));
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         __THREW__ = 0;
         $35 = (invoke_iii(2730,(2397856|0),($_____property|0))|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if (!($37)) {
          $38 = ($35|0)==(0|0);
          if (!($38)) {
           __THREW__ = 0;
           invoke_vi(3799,($35|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if ($40) {
            break;
           }
           $41 = (($35) + 12|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = ($42|0)<(1);
           if (!($43)) {
            __THREW__ = 0;
            invoke_vi(3799,($35|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if ($45) {
             break;
            }
            $46 = HEAP32[$41>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(1169184|0))|0);
            $47 = __THREW__; __THREW__ = 0;
            $48 = $47&1;
            if ($48) {
             break;
            }
            __THREW__ = 0;
            $49 = (invoke_iii(2768,(1169184|0),($46|0))|0);
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if ($51) {
             break;
            }
            $52 = (($49) + 12|0);
            $53 = (($49) + 16|0);
            $V_4$0 = 0;
            while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($49|0));
             $89 = __THREW__; __THREW__ = 0;
             $90 = $89&1;
             if ($90) {
              label = 4;
              break;
             }
             $91 = HEAP32[$52>>2]|0;
             $92 = ($V_4$0|0)<($91|0);
             if (!($92)) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($35|0));
             $93 = __THREW__; __THREW__ = 0;
             $94 = $93&1;
             if ($94) {
              label = 4;
              break;
             }
             $54 = HEAP32[$41>>2]|0;
             $55 = ($V_4$0>>>0)<($54>>>0);
             if (!($55)) {
              __THREW__ = 0;
              $56 = (invoke_i(132)|0);
              $57 = __THREW__; __THREW__ = 0;
              $58 = $57&1;
              if ($58) {
               label = 4;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($56|0));
              $59 = __THREW__; __THREW__ = 0;
              $60 = $59&1;
              if ($60) {
               label = 4;
               break;
              }
             }
             $61 = HEAP32[$35>>2]|0;
             $62 = (($61) + 92|0);
             $63 = HEAP32[$62>>2]|0;
             $64 = Math_imul($63, $V_4$0)|0;
             $$sum = (($64) + 16)|0;
             $65 = (($35) + ($$sum)|0);
             $66 = HEAP32[$65>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($66|0));
             $67 = __THREW__; __THREW__ = 0;
             $68 = $67&1;
             if ($68) {
              label = 4;
              break;
             }
             __THREW__ = 0;
             $69 = (invoke_iii(2730,(2397472|0),($66|0))|0);
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if ($71) {
              label = 4;
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($49|0));
             $72 = __THREW__; __THREW__ = 0;
             $73 = $72&1;
             if ($73) {
              label = 4;
              break;
             }
             $74 = HEAP32[$52>>2]|0;
             $75 = ($V_4$0>>>0)<($74>>>0);
             if (!($75)) {
              __THREW__ = 0;
              $76 = (invoke_i(132)|0);
              $77 = __THREW__; __THREW__ = 0;
              $78 = $77&1;
              if ($78) {
               label = 4;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($76|0));
              $79 = __THREW__; __THREW__ = 0;
              $80 = $79&1;
              if ($80) {
               label = 4;
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($49|0),($69|0));
             $81 = __THREW__; __THREW__ = 0;
             $82 = $81&1;
             if ($82) {
              label = 4;
              break;
             }
             $83 = HEAP32[$49>>2]|0;
             $84 = (($83) + 92|0);
             $85 = HEAP32[$84>>2]|0;
             $86 = Math_imul($85, $V_4$0)|0;
             $87 = (($53) + ($86)|0);
             HEAP32[$87>>2] = $69;
             $88 = (($V_4$0) + 1)|0;
             $V_4$0 = $88;
            }
            if ((label|0) == 4) {
             $6 = ___cxa_find_matching_catch()|0;
             $7 = tempRet0;
             $lpad$phi$index = $6;$lpad$phi$index2 = $7;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($28|0));
            $95 = __THREW__; __THREW__ = 0;
            $96 = $95&1;
            if ($96) {
             break;
            }
            __THREW__ = 0;
            $97 = (invoke_iii(2730,(2242504|0),($28|0))|0);
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($_____property|0));
            $100 = __THREW__; __THREW__ = 0;
            $101 = $100&1;
            if ($101) {
             break;
            }
            __THREW__ = 0;
            $102 = (invoke_iii(2730,(2233608|0),($_____property|0))|0);
            $103 = __THREW__; __THREW__ = 0;
            $104 = $103&1;
            if ($104) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($_____property|0));
            $105 = __THREW__; __THREW__ = 0;
            $106 = $105&1;
            if ($106) {
             break;
            }
            __THREW__ = 0;
            $107 = (invoke_iii(2730,(2397904|0),($_____property|0))|0);
            $108 = __THREW__; __THREW__ = 0;
            $109 = $108&1;
            if ($109) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($97|0));
            $110 = __THREW__; __THREW__ = 0;
            $111 = $110&1;
            if ($111) {
             break;
            }
            __THREW__ = 0;
            $112 = (invoke_iiiiii(240,(2236720|0),($97|0),($102|0),($107|0),($49|0))|0);
            $113 = __THREW__; __THREW__ = 0;
            $114 = $113&1;
            if ($114) {
             break;
            }
            $$0 = $112;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($28|0));
          $115 = __THREW__; __THREW__ = 0;
          $116 = $115&1;
          if (!($116)) {
           __THREW__ = 0;
           $117 = (invoke_iii(2730,(2242504|0),($28|0))|0);
           $118 = __THREW__; __THREW__ = 0;
           $119 = $118&1;
           if (!($119)) {
            __THREW__ = 0;
            invoke_vi(3799,($_____property|0));
            $120 = __THREW__; __THREW__ = 0;
            $121 = $120&1;
            if (!($121)) {
             __THREW__ = 0;
             $122 = (invoke_iii(2730,(2233608|0),($_____property|0))|0);
             $123 = __THREW__; __THREW__ = 0;
             $124 = $123&1;
             if (!($124)) {
              __THREW__ = 0;
              invoke_vi(3799,($_____property|0));
              $125 = __THREW__; __THREW__ = 0;
              $126 = $125&1;
              if (!($126)) {
               __THREW__ = 0;
               $127 = (invoke_iii(2730,(2397904|0),($_____property|0))|0);
               $128 = __THREW__; __THREW__ = 0;
               $129 = $128&1;
               if (!($129)) {
                __THREW__ = 0;
                invoke_vi(3799,($117|0));
                $130 = __THREW__; __THREW__ = 0;
                $131 = $130&1;
                if ($131) {
                 break;
                }
                __THREW__ = 0;
                $132 = (invoke_iiiii(317,(2236624|0),($117|0),($122|0),($127|0))|0);
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 break;
                }
                $$0 = $132;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker3I17VoidPointerTraitsS0_S0_S0_E6InvokeEP10MethodInfoPvS4_S4_S4_($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$3 & 511]($4,$p1,$p2,$p3)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z43mscorlib_System_MonoTouchAOTHelper_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2614880);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z36mscorlib_System_MonoTypeInfo_m__ctorP28mscorlib_System_MonoTypeInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2615168);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z41mscorlib_System_MonoType_m_get_attributesP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2615496);
 $0 = HEAP32[2615544>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2615552|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2615544>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z48mscorlib_System_MonoType_m_GetAttributeFlagsImplP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2615648);
 __THREW__ = 0;
 $0 = (invoke_iii(1134,0,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z45mscorlib_System_MonoType_m_GetConstructorImplP24mscorlib_System_MonoTypeiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $$0 = 0, $$02 = 0, $$bindingAttr = 0, $$sum = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_3$0 = 0, $V_3$1 = 0, $V_3$2 = 0, $V_3$3 = 0, $V_6$0 = 0, $V_9$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2615696);
 $0 = ($bindingAttr|0)==(0);
 $$bindingAttr = $0 ? 20 : $bindingAttr;
 __THREW__ = 0;
 $1 = (invoke_iiii(1642,(2615744|0),($__this|0),($$bindingAttr|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if (!($3)) {
   $4 = (($1) + 12|0);
   $5 = ($callConvention|0)==(3);
   $V_1$1 = 0;$V_3$1 = 0;$V_6$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($1|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     label = 4;
     break;
    }
    $36 = HEAP32[$4>>2]|0;
    $37 = ($V_6$0|0)<($36|0);
    if (!($37)) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($1|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     label = 4;
     break;
    }
    $12 = HEAP32[$4>>2]|0;
    $13 = ($V_6$0>>>0)<($12>>>0);
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_i(132)|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($14|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 4;
      break;
     }
    }
    $19 = HEAP32[$1>>2]|0;
    $20 = (($19) + 92|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = Math_imul($21, $V_6$0)|0;
    $$sum6 = (($22) + 16)|0;
    $23 = (($1) + ($$sum6)|0);
    $24 = HEAP32[$23>>2]|0;
    if ($5) {
     label = 14;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $27 = (invoke_iii(2729,(2397712|0),($24|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      label = 4;
      break;
     }
     $30 = $27 & $callConvention;
     $31 = ($30|0)==($callConvention|0);
     if ($31) {
      label = 14;
     } else {
      $V_1$0 = $V_1$1;$V_3$0 = $V_3$1;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     $32 = (($V_3$1) + 1)|0;
     $V_1$0 = $24;$V_3$0 = $32;
    }
    $33 = (($V_6$0) + 1)|0;
    $V_1$1 = $V_1$0;$V_3$1 = $V_3$0;$V_6$0 = $33;
   }
   if ((label|0) == 4) {
    $8 = ___cxa_find_matching_catch()|0;
    $9 = tempRet0;
    $lpad$phi$index = $8;$lpad$phi$index3 = $9;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $40 = ($V_3$1|0)==(0);
   if ($40) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $41 = ($types|0)==(0|0);
   if ($41) {
    $42 = ($V_3$1|0)<(2);
    if ($42) {
     __THREW__ = 0;
     $52 = (invoke_iii(1141,0,($V_1$1|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2403064|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     $57 = (invoke_iii(2769,($52|0),(2403064|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     $$0 = $57;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(2375288|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     __THREW__ = 0;
     $45 = (invoke_ii(3469,(2375288|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(2261,($45|0));
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($45|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     // unreachable;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1238976|0))|0);
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if (!($61)) {
    __THREW__ = 0;
    $62 = (invoke_iii(2768,(1238976|0),($V_3$1|0))|0);
    $63 = __THREW__; __THREW__ = 0;
    $64 = $63&1;
    if (!($64)) {
     $65 = ($V_3$1|0)==(1);
     L42: do {
      if ($65) {
       __THREW__ = 0;
       invoke_vi(3799,($62|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break L1;
       }
       $70 = (($62) + 12|0);
       $71 = HEAP32[$70>>2]|0;
       $72 = ($71|0)==(0);
       if ($72) {
        __THREW__ = 0;
        $73 = (invoke_i(132)|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($73|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         break L1;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($62|0),($V_1$1|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break L1;
       }
       $80 = (($62) + 16|0);
       HEAP32[$80>>2] = $V_1$1;
      } else {
       $66 = (($62) + 16|0);
       $67 = (($62) + 12|0);
       $V_3$3 = 0;$V_9$0 = 0;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($1|0));
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if ($121) {
         break;
        }
        $122 = HEAP32[$4>>2]|0;
        $123 = ($V_9$0|0)<($122|0);
        if (!($123)) {
         break L42;
        }
        __THREW__ = 0;
        invoke_vi(3799,($1|0));
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break;
        }
        $81 = HEAP32[$4>>2]|0;
        $82 = ($V_9$0>>>0)<($81>>>0);
        if (!($82)) {
         __THREW__ = 0;
         $83 = (invoke_i(132)|0);
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($83|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         }
        }
        $88 = HEAP32[$1>>2]|0;
        $89 = (($88) + 92|0);
        $90 = HEAP32[$89>>2]|0;
        $91 = Math_imul($90, $V_9$0)|0;
        $$sum = (($91) + 16)|0;
        $92 = (($1) + ($$sum)|0);
        $93 = HEAP32[$92>>2]|0;
        if ($5) {
         label = 48;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($93|0));
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         __THREW__ = 0;
         $96 = (invoke_iii(2729,(2397712|0),($93|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          break;
         }
         $99 = $96 & $callConvention;
         $100 = ($99|0)==($callConvention|0);
         if ($100) {
          label = 48;
         } else {
          $V_3$2 = $V_3$3;
         }
        }
        if ((label|0) == 48) {
         label = 0;
         $101 = (($V_3$3) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($62|0));
         $102 = __THREW__; __THREW__ = 0;
         $103 = $102&1;
         if ($103) {
          break;
         }
         $104 = ($V_3$3|0)<(0);
         if ($104) {
          label = 51;
         } else {
          $105 = HEAP32[$67>>2]|0;
          $106 = ($V_3$3>>>0)<($105>>>0);
          if (!($106)) {
           label = 51;
          }
         }
         if ((label|0) == 51) {
          label = 0;
          __THREW__ = 0;
          $107 = (invoke_i(132)|0);
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($107|0));
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($62|0),($93|0));
         $112 = __THREW__; __THREW__ = 0;
         $113 = $112&1;
         if ($113) {
          break;
         }
         $114 = HEAP32[$62>>2]|0;
         $115 = (($114) + 92|0);
         $116 = HEAP32[$115>>2]|0;
         $117 = Math_imul($116, $V_3$3)|0;
         $118 = (($66) + ($117)|0);
         HEAP32[$118>>2] = $93;
         $V_3$2 = $101;
        }
        $119 = (($V_9$0) + 1)|0;
        $V_3$3 = $V_3$2;$V_9$0 = $119;
       }
       $6 = ___cxa_find_matching_catch()|0;
       $7 = tempRet0;
       $lpad$phi$index = $6;$lpad$phi$index3 = $7;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
     } while(0);
     $126 = ($binder|0)==(0|0);
     if ($126) {
      __THREW__ = 0;
      $127 = (invoke_ii(2196,(0|0))|0);
      $128 = __THREW__; __THREW__ = 0;
      $129 = $128&1;
      if ($129) {
       break;
      } else {
       $$02 = $127;
      }
     } else {
      $$02 = $binder;
     }
     __THREW__ = 0;
     invoke_vi(3799,($$02|0));
     $130 = __THREW__; __THREW__ = 0;
     $131 = $130&1;
     if (!($131)) {
      __THREW__ = 0;
      $132 = (invoke_iiiiiii(131,(2399880|0),($$02|0),($$bindingAttr|0),($62|0),($types|0),($modifiers|0))|0);
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if (!($134)) {
       __THREW__ = 0;
       $135 = (invoke_iii(1141,0,($132|0))|0);
       $136 = __THREW__; __THREW__ = 0;
       $137 = $136&1;
       if (!($137)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2403064|0))|0);
        $138 = __THREW__; __THREW__ = 0;
        $139 = $138&1;
        if (!($139)) {
         __THREW__ = 0;
         $140 = (invoke_iii(2769,($135|0),(2403064|0))|0);
         $141 = __THREW__; __THREW__ = 0;
         $142 = $141&1;
         if (!($142)) {
          $$0 = $140;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index3 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_MonoType_m_CheckMethodSecurityP24mscorlib_System_MonoTypeP37mscorlib_System_Reflection_MethodBase($__this,$mb) {
 $__this = $__this|0;
 $mb = $mb|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618928);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($mb|0);
}
function __Z51mscorlib_System_MonoType_m_GetConstructors_internalP24mscorlib_System_MonoTypeiP20mscorlib_System_Type($__this,$bindingAttr,$reflected_type) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $reflected_type = $reflected_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2615792);
 $0 = HEAP32[2615840>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2615848|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2615840>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($__this|0),($bindingAttr|0),($reflected_type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_MonoType_m_GetConstructorsP24mscorlib_System_MonoTypei($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2615744);
 __THREW__ = 0;
 $0 = (invoke_iiii(1204,($__this|0),($bindingAttr|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z35mscorlib_System_MonoType_m_GetFieldP24mscorlib_System_MonoTypeP22mscorlib_System_Stringi($__this,$name,$bindingAttr) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2615936);
 $0 = HEAP32[2615984>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2615992|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2615984>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($__this|0),($name|0),($bindingAttr|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_MonoType_m_GetFields_internalP24mscorlib_System_MonoTypeiP20mscorlib_System_Type($__this,$bindingAttr,$reflected_type) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 $reflected_type = $reflected_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616064);
 $0 = HEAP32[2616112>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2616120|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2616112>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($__this|0),($bindingAttr|0),($reflected_type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_MonoType_m_GetFieldsP24mscorlib_System_MonoTypei($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616200);
 __THREW__ = 0;
 $0 = (invoke_iiii(1206,($__this|0),($bindingAttr|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z40mscorlib_System_MonoType_m_GetInterfacesP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616248);
 $0 = HEAP32[2616296>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2616304|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2616296>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z43mscorlib_System_MonoType_m_GetMethodsByNameP24mscorlib_System_MonoTypeP22mscorlib_System_StringibP20mscorlib_System_Type($__this,$name,$bindingAttr,$ignoreCase,$reflected_type) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $ignoreCase = $ignoreCase|0;
 $reflected_type = $reflected_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616344);
 $0 = HEAP32[2616392>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2616400|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2616392>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiiii($7|0,($__this|0),($name|0),($bindingAttr|0),($ignoreCase|0),($reflected_type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_MonoType_m_GetMethodsP24mscorlib_System_MonoTypei($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616512);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(130,($__this|0),(0|0),($bindingAttr|0),0,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z40mscorlib_System_MonoType_m_GetMethodImplP24mscorlib_System_MonoTypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$callConvention,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $callConvention = $callConvention|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $$0 = 0, $$01 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_10$0 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_4$0 = 0, $V_4$1 = 0, $V_4$2 = 0, $V_4$3 = 0, $V_7$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616560);
 $0 = $bindingAttr & 1;
 $1 = ($0|0)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iiiiii(130,($__this|0),($name|0),($bindingAttr|0),($1|0),($__this|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if (!($4)) {
   $5 = (($2) + 12|0);
   $6 = (($2) + 16|0);
   $7 = ($callConvention|0)==(3);
   $V_2$1 = 0;$V_4$1 = 0;$V_7$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 4;
     break;
    }
    $38 = HEAP32[$5>>2]|0;
    $39 = ($V_7$0|0)<($38|0);
    if (!($39)) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     label = 4;
     break;
    }
    $14 = HEAP32[$5>>2]|0;
    $15 = ($V_7$0>>>0)<($14>>>0);
    if (!($15)) {
     __THREW__ = 0;
     $16 = (invoke_i(132)|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($16|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 4;
      break;
     }
    }
    $21 = HEAP32[$2>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $V_7$0)|0;
    $25 = (($6) + ($24)|0);
    $26 = HEAP32[$25>>2]|0;
    if ($7) {
     label = 14;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $29 = (invoke_iii(2729,(2397712|0),($26|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      label = 4;
      break;
     }
     $32 = $29 & $callConvention;
     $33 = ($32|0)==($callConvention|0);
     if ($33) {
      label = 14;
     } else {
      $V_2$0 = $V_2$1;$V_4$0 = $V_4$1;
     }
    }
    if ((label|0) == 14) {
     label = 0;
     $34 = (($V_4$1) + 1)|0;
     $V_2$0 = $26;$V_4$0 = $34;
    }
    $35 = (($V_7$0) + 1)|0;
    $V_2$1 = $V_2$0;$V_4$1 = $V_4$0;$V_7$0 = $35;
   }
   if ((label|0) == 4) {
    $10 = ___cxa_find_matching_catch()|0;
    $11 = tempRet0;
    $lpad$phi$index = $10;$lpad$phi$index3 = $11;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $42 = ($V_4$1|0)==(0);
   if ($42) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $43 = ($V_4$1|0)!=(1);
   $$not = $43 ^ 1;
   $44 = ($types|0)==(0|0);
   $or$cond = $44 & $$not;
   if ($or$cond) {
    __THREW__ = 0;
    $45 = (invoke_iii(1141,0,($V_2$1|0))|0);
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if ($47) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2414216|0))|0);
    $48 = __THREW__; __THREW__ = 0;
    $49 = $48&1;
    if ($49) {
     break;
    }
    __THREW__ = 0;
    $50 = (invoke_iii(2769,($45|0),(2414216|0))|0);
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     break;
    }
    $$0 = $50;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1238976|0))|0);
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if (!($54)) {
    __THREW__ = 0;
    $55 = (invoke_iii(2768,(1238976|0),($V_4$1|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if (!($57)) {
     L35: do {
      if ($43) {
       $58 = (($55) + 16|0);
       $59 = (($55) + 12|0);
       $V_10$0 = 0;$V_4$3 = 0;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         break;
        }
        $114 = HEAP32[$5>>2]|0;
        $115 = ($V_10$0|0)<($114|0);
        if (!($115)) {
         break L35;
        }
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $116 = __THREW__; __THREW__ = 0;
        $117 = $116&1;
        if ($117) {
         break;
        }
        $73 = HEAP32[$5>>2]|0;
        $74 = ($V_10$0>>>0)<($73>>>0);
        if (!($74)) {
         __THREW__ = 0;
         $75 = (invoke_i(132)|0);
         $76 = __THREW__; __THREW__ = 0;
         $77 = $76&1;
         if ($77) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($75|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if ($79) {
          break;
         }
        }
        $80 = HEAP32[$2>>2]|0;
        $81 = (($80) + 92|0);
        $82 = HEAP32[$81>>2]|0;
        $83 = Math_imul($82, $V_10$0)|0;
        $84 = (($6) + ($83)|0);
        $85 = HEAP32[$84>>2]|0;
        if ($7) {
         label = 42;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($85|0));
         $86 = __THREW__; __THREW__ = 0;
         $87 = $86&1;
         if ($87) {
          break;
         }
         __THREW__ = 0;
         $88 = (invoke_iii(2729,(2397712|0),($85|0))|0);
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          break;
         }
         $91 = $88 & $callConvention;
         $92 = ($91|0)==($callConvention|0);
         if ($92) {
          label = 42;
         } else {
          $V_4$2 = $V_4$3;
         }
        }
        if ((label|0) == 42) {
         label = 0;
         $93 = (($V_4$3) + 1)|0;
         __THREW__ = 0;
         invoke_vi(3799,($55|0));
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         $96 = ($V_4$3|0)<(0);
         if ($96) {
          label = 45;
         } else {
          $97 = HEAP32[$59>>2]|0;
          $98 = ($V_4$3>>>0)<($97>>>0);
          if (!($98)) {
           label = 45;
          }
         }
         if ((label|0) == 45) {
          label = 0;
          __THREW__ = 0;
          $99 = (invoke_i(132)|0);
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($99|0));
          $102 = __THREW__; __THREW__ = 0;
          $103 = $102&1;
          if ($103) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($55|0),($85|0));
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          break;
         }
         $106 = HEAP32[$55>>2]|0;
         $107 = (($106) + 92|0);
         $108 = HEAP32[$107>>2]|0;
         $109 = Math_imul($108, $V_4$3)|0;
         $110 = (($58) + ($109)|0);
         HEAP32[$110>>2] = $85;
         $V_4$2 = $93;
        }
        $111 = (($V_10$0) + 1)|0;
        $V_10$0 = $111;$V_4$3 = $V_4$2;
       }
       $8 = ___cxa_find_matching_catch()|0;
       $9 = tempRet0;
       $lpad$phi$index = $8;$lpad$phi$index3 = $9;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($55|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        break L1;
       }
       $62 = (($55) + 12|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = ($63|0)==(0);
       if ($64) {
        __THREW__ = 0;
        $65 = (invoke_i(132)|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($65|0));
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         break L1;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($55|0),($V_2$1|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break L1;
       }
       $72 = (($55) + 16|0);
       HEAP32[$72>>2] = $V_2$1;
      }
     } while(0);
     if ($44) {
      __THREW__ = 0;
      $118 = (invoke_iii(905,(0|0),($55|0))|0);
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if ($120) {
       break;
      }
      __THREW__ = 0;
      $121 = (invoke_iii(1141,0,($118|0))|0);
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2414216|0))|0);
      $124 = __THREW__; __THREW__ = 0;
      $125 = $124&1;
      if ($125) {
       break;
      }
      __THREW__ = 0;
      $126 = (invoke_iii(2769,($121|0),(2414216|0))|0);
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       break;
      }
      $$0 = $126;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $129 = ($binder|0)==(0|0);
     if ($129) {
      __THREW__ = 0;
      $130 = (invoke_ii(2196,(0|0))|0);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       break;
      } else {
       $$01 = $130;
      }
     } else {
      $$01 = $binder;
     }
     __THREW__ = 0;
     invoke_vi(3799,($$01|0));
     $133 = __THREW__; __THREW__ = 0;
     $134 = $133&1;
     if (!($134)) {
      __THREW__ = 0;
      $135 = (invoke_iiiiiii(131,(2399880|0),($$01|0),($bindingAttr|0),($55|0),($types|0),($modifiers|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if (!($137)) {
       __THREW__ = 0;
       $138 = (invoke_iii(1141,0,($135|0))|0);
       $139 = __THREW__; __THREW__ = 0;
       $140 = $139&1;
       if (!($140)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2414216|0))|0);
        $141 = __THREW__; __THREW__ = 0;
        $142 = $141&1;
        if (!($142)) {
         __THREW__ = 0;
         $143 = (invoke_iii(2769,($138|0),(2414216|0))|0);
         $144 = __THREW__; __THREW__ = 0;
         $145 = $144&1;
         if (!($145)) {
          $$0 = $143;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index3 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_MonoType_m_GetPropertiesByNameP24mscorlib_System_MonoTypeP22mscorlib_System_StringibP20mscorlib_System_Type($__this,$name,$bindingAttr,$icase,$reflected_type) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $icase = $icase|0;
 $reflected_type = $reflected_type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616608);
 $0 = HEAP32[2616656>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2616664|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2616656>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiiii($7|0,($__this|0),($name|0),($bindingAttr|0),($icase|0),($reflected_type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_MonoType_m_GetPropertiesP24mscorlib_System_MonoTypei($__this,$bindingAttr) {
 $__this = $__this|0;
 $bindingAttr = $bindingAttr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616776);
 __THREW__ = 0;
 $0 = (invoke_iiiiii(131,($__this|0),(0|0),($bindingAttr|0),0,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z42mscorlib_System_MonoType_m_GetPropertyImplP24mscorlib_System_MonoTypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr($__this,$name,$bindingAttr,$binder,$returnType,$types,$modifiers) {
 $__this = $__this|0;
 $name = $name|0;
 $bindingAttr = $bindingAttr|0;
 $binder = $binder|0;
 $returnType = $returnType|0;
 $types = $types|0;
 $modifiers = $modifiers|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616824);
 $0 = $bindingAttr & 1;
 $1 = ($0|0)!=(0);
 __THREW__ = 0;
 $2 = (invoke_iiiiii(131,($__this|0),($name|0),($bindingAttr|0),($1|0),($__this|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($2) + 12|0);
    $8 = HEAP32[$7>>2]|0;
    if ((($8|0) == 1)) {
     label = 5;
    } else if ((($8|0) == 0)) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    do {
     if ((label|0) == 5) {
      $11 = ($types|0)==(0|0);
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($types|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if ($13) {
        break L1;
       }
       $14 = (($types) + 12|0);
       $15 = HEAP32[$14>>2]|0;
       $16 = ($15|0)==(0);
       if (!($16)) {
        break;
       }
      }
      $17 = ($returnType|0)==(0|0);
      if (!($17)) {
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break L1;
       }
       $20 = HEAP32[$7>>2]|0;
       $21 = ($20|0)==(0);
       if ($21) {
        __THREW__ = 0;
        $22 = (invoke_i(132)|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if ($24) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($22|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break L1;
        }
       }
       $27 = (($2) + 16|0);
       $28 = HEAP32[$27>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($28|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break L1;
       }
       __THREW__ = 0;
       $31 = (invoke_iii(2730,(2397904|0),($28|0))|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break L1;
       }
       $34 = ($31|0)==($returnType|0);
       if (!($34)) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break L1;
      }
      $37 = HEAP32[$7>>2]|0;
      $38 = ($37|0)==(0);
      if ($38) {
       __THREW__ = 0;
       $39 = (invoke_i(132)|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3302,($39|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break L1;
       }
      }
      $44 = (($2) + 16|0);
      $45 = HEAP32[$44>>2]|0;
      $$0 = $45;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    } while(0);
    $46 = ($binder|0)==(0|0);
    if ($46) {
     __THREW__ = 0;
     $47 = (invoke_ii(2196,(0|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     } else {
      $$01 = $47;
     }
    } else {
     $$01 = $binder;
    }
    __THREW__ = 0;
    invoke_vi(3799,($$01|0));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if (!($51)) {
     __THREW__ = 0;
     $52 = (invoke_iiiiiiii(122,(2399992|0),($$01|0),($bindingAttr|0),($2|0),($returnType|0),($types|0),($modifiers|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if (!($54)) {
      $$0 = $52;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEP10MethodInfoPviS5_S5_S5_S5_($method,$obj,$p1,$p2,$p3,$p4,$p5) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiii[$3 & 255]($4,$p1,$p2,$p3,$p4,$p5)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z45mscorlib_System_MonoType_m_HasElementTypeImplP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B4_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616872);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2616920|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    $G_B4_0$0 = 1;
   } else {
    __THREW__ = 0;
    $5 = (invoke_iii(2734,(2616968|0),($__this|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    if ($5) {
     $G_B4_0$0 = 1;
    } else {
     __THREW__ = 0;
     $8 = (invoke_iii(2734,(2617016|0),($__this|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     } else {
      $G_B4_0$0 = $8;
     }
    }
   }
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B4_0$0|0);
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_MonoType_m_IsArrayImplP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616920);
 __THREW__ = 0;
 $0 = (invoke_iii(777,(0|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z38mscorlib_System_MonoType_m_IsByRefImplP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2616968);
 $0 = HEAP32[2617064>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2617072|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2617064>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_MonoType_m_IsPointerImplP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617016);
 $0 = HEAP32[2617104>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2617112|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2617104>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_MonoType_m_IsPrimitiveImplP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617152);
 $0 = HEAP32[2617200>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2617208|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2617200>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_MonoType_m_IsSubclassOfP24mscorlib_System_MonoTypeP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617248);
 __THREW__ = 0;
 invoke_v(906);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($type|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iii(765,($__this|0),($type|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3072544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3838,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_MonoType_m_InvokeMemberP24mscorlib_System_MonoTypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP22mscorlib_System_ObjectP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arr($__this,$name,$invokeAttr,$binder,$target,$args,$modifiers,$culture,$namedParameters) {
 $__this = $__this|0;
 $name = $name|0;
 $invokeAttr = $invokeAttr|0;
 $binder = $binder|0;
 $target = $target|0;
 $args = $args|0;
 $modifiers = $modifiers|0;
 $culture = $culture|0;
 $namedParameters = $namedParameters|0;
 var $$0 = 0, $$01 = 0, $$03 = 0, $$1 = 0, $$byval_copy17 = 0, $$invokeAttr = 0, $$pre = 0, $$pre75 = 0, $$sum = 0, $$sum48 = 0, $$sum49 = 0, $$sum50 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0;
 var $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0;
 var $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0;
 var $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0;
 var $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0;
 var $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0;
 var $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0;
 var $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0;
 var $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0;
 var $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0;
 var $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0;
 var $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0;
 var $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0;
 var $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0;
 var $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0;
 var $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0;
 var $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0;
 var $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0;
 var $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0;
 var $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0;
 var $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0;
 var $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0;
 var $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0;
 var $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0;
 var $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_10 = 0, $V_13$0 = 0, $V_19 = 0, $V_2 = 0, $V_20$0 = 0;
 var $V_20$1 = 0, $V_21$1 = 0, $V_21$1$ = 0, $V_21$2 = 0, $V_21$3 = 0, $V_29 = 0, $V_30$0 = 0, $V_30$1 = 0, $V_31$1 = 0, $V_31$1$ = 0, $V_31$2 = 0, $V_31$3 = 0, $V_7$0 = 0, $V_8$0$off0 = 0, $V_8$1$off0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index6 = 0, $not$ = 0, $not$51 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy17 = sp + 44|0;
 $0 = sp + 40|0;
 $_stackTraceSentry = sp + 36|0;
 $V_2 = sp + 32|0;
 $V_10 = sp + 28|0;
 $V_19 = sp + 24|0;
 $V_29 = sp + 20|0;
 $1 = sp + 12|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = sp + 16|0;
 HEAP32[$0>>2] = $args;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617296);
 HEAP32[$V_2>>2] = 0;
 HEAP32[$V_10>>2] = 0;
 HEAP32[$V_19>>2] = 0;
 HEAP32[$V_29>>2] = 0;
 __THREW__ = 0;
 invoke_v(907);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if (!($7)) {
   $8 = $invokeAttr & 512;
   $9 = ($8|0)==(0);
   if ($9) {
    $34 = ($name|0)==(0|0);
    if ($34) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560584|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     __THREW__ = 0;
     $37 = (invoke_ii(3469,(2560584|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break;
     }
     $40 = HEAP32[3072568>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($37|0),($40|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($37|0));
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break;
     }
     // unreachable;
    }
   } else {
    $22 = $invokeAttr & 13312;
    $23 = ($22|0)==(0);
    if (!($23)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     $26 = (invoke_ii(3469,(2560072|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     $29 = HEAP32[3072560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($26|0),($29|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($26|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     // unreachable;
    }
   }
   $45 = $invokeAttr & 2048;
   $46 = ($45|0)==(0);
   $47 = $invokeAttr & 3072;
   $48 = ($47|0)==(3072);
   if ($48) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    __THREW__ = 0;
    $51 = (invoke_ii(3469,(2560072|0))|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    $54 = HEAP32[3072576>>2]|0;
    $55 = HEAP32[3072584>>2]|0;
    __THREW__ = 0;
    invoke_viii(641,($51|0),($54|0),($55|0));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($51|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     break;
    }
    // unreachable;
   }
   $60 = $invokeAttr & 8192;
   $61 = ($60|0)==(0);
   $62 = $invokeAttr & 12288;
   $63 = ($62|0)==(12288);
   if ($63) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     break;
    }
    __THREW__ = 0;
    $66 = (invoke_ii(3469,(2560072|0))|0);
    $67 = __THREW__; __THREW__ = 0;
    $68 = $67&1;
    if ($68) {
     break;
    }
    $69 = HEAP32[3072592>>2]|0;
    $70 = HEAP32[3072600>>2]|0;
    __THREW__ = 0;
    invoke_viii(641,($66|0),($69|0),($70|0));
    $71 = __THREW__; __THREW__ = 0;
    $72 = $71&1;
    if ($72) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($66|0));
    $73 = __THREW__; __THREW__ = 0;
    $74 = $73&1;
    if ($74) {
     break;
    }
    // unreachable;
   }
   $75 = $invokeAttr & 256;
   $76 = ($75|0)==(0);
   if (!($76)) {
    if (!($46)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $77 = __THREW__; __THREW__ = 0;
     $78 = $77&1;
     if ($78) {
      break;
     }
     __THREW__ = 0;
     $79 = (invoke_ii(3469,(2560072|0))|0);
     $80 = __THREW__; __THREW__ = 0;
     $81 = $80&1;
     if ($81) {
      break;
     }
     $82 = HEAP32[3072608>>2]|0;
     $83 = HEAP32[3072616>>2]|0;
     __THREW__ = 0;
     invoke_viii(641,($79|0),($82|0),($83|0));
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if ($85) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($79|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      break;
     }
     // unreachable;
    }
    if (!($61)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if ($89) {
      break;
     }
     __THREW__ = 0;
     $90 = (invoke_ii(3469,(2560072|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      break;
     }
     $93 = HEAP32[3072624>>2]|0;
     $94 = HEAP32[3072632>>2]|0;
     __THREW__ = 0;
     invoke_viii(641,($90|0),($93|0),($94|0));
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($90|0));
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if ($98) {
      break;
     }
     // unreachable;
    }
   }
   $99 = ($namedParameters|0)==(0|0);
   do {
    if (!($99)) {
     $100 = HEAP32[$0>>2]|0;
     $101 = ($100|0)==(0|0);
     if (!($101)) {
      __THREW__ = 0;
      invoke_vi(3799,($100|0));
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       break L1;
      }
      $104 = HEAP32[$0>>2]|0;
      $105 = (($104) + 12|0);
      $106 = HEAP32[$105>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($namedParameters|0));
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       break L1;
      }
      $109 = (($namedParameters) + 12|0);
      $110 = HEAP32[$109>>2]|0;
      $111 = ($106|0)<($110|0);
      if (!($111)) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $112 = __THREW__; __THREW__ = 0;
     $113 = $112&1;
     if ($113) {
      break L1;
     }
     __THREW__ = 0;
     $114 = (invoke_ii(3469,(2560072|0))|0);
     $115 = __THREW__; __THREW__ = 0;
     $116 = $115&1;
     if ($116) {
      break L1;
     }
     $117 = HEAP32[3072640>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($114|0),($117|0));
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3838,($114|0));
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if ($121) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $122 = $invokeAttr & 16128;
   $123 = ($122|0)==(0);
   if ($123) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $124 = __THREW__; __THREW__ = 0;
    $125 = $124&1;
    if ($125) {
     break;
    }
    __THREW__ = 0;
    $126 = (invoke_ii(3469,(2560072|0))|0);
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     break;
    }
    $129 = HEAP32[3072648>>2]|0;
    $130 = HEAP32[3072656>>2]|0;
    __THREW__ = 0;
    invoke_viii(641,($126|0),($129|0),($130|0));
    $131 = __THREW__; __THREW__ = 0;
    $132 = $131&1;
    if ($132) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($126|0));
    $133 = __THREW__; __THREW__ = 0;
    $134 = $133&1;
    if ($134) {
     break;
    }
    // unreachable;
   }
   $135 = $invokeAttr & 48;
   $136 = ($135|0)==(0);
   $137 = $invokeAttr | 16;
   $$invokeAttr = $136 ? $137 : $invokeAttr;
   $138 = $$invokeAttr & 12;
   $139 = ($138|0)==(0);
   $140 = $$invokeAttr | 12;
   $$1 = $139 ? $140 : $$invokeAttr;
   $141 = ($binder|0)==(0|0);
   if ($141) {
    __THREW__ = 0;
    $142 = (invoke_ii(2196,(0|0))|0);
    $143 = __THREW__; __THREW__ = 0;
    $144 = $143&1;
    if ($144) {
     break;
    } else {
     $$03 = $142;
    }
   } else {
    $$03 = $binder;
   }
   $145 = $$1 & 512;
   $146 = ($145|0)==(0);
   if (!($146)) {
    $147 = $$1 | 2;
    __THREW__ = 0;
    $148 = (invoke_iiii(1642,(2615744|0),($__this|0),($147|0))|0);
    $149 = __THREW__; __THREW__ = 0;
    $150 = $149&1;
    if ($150) {
     break;
    }
    HEAP32[$V_2>>2] = 0;
    __THREW__ = 0;
    invoke_vi(3799,($$03|0));
    $151 = __THREW__; __THREW__ = 0;
    $152 = $151&1;
    if ($152) {
     break;
    }
    __THREW__ = 0;
    $153 = (invoke_iiiiiiiiii(15,(2399672|0),($$03|0),($147|0),($148|0),($0|0),($modifiers|0),($culture|0),($namedParameters|0),($V_2|0))|0);
    $154 = __THREW__; __THREW__ = 0;
    $155 = $154&1;
    if ($155) {
     break;
    }
    $156 = ($153|0)==(0|0);
    if (!($156)) {
     __THREW__ = 0;
     invoke_vi(3799,($153|0));
     $182 = __THREW__; __THREW__ = 0;
     $183 = $182&1;
     if ($183) {
      break;
     }
     $184 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     $185 = (invoke_iiiiiiii(119,(2410128|0),($153|0),($target|0),($147|0),($$03|0),($184|0),($culture|0))|0);
     $186 = __THREW__; __THREW__ = 0;
     $187 = $186&1;
     if ($187) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($$03|0));
     $188 = __THREW__; __THREW__ = 0;
     $189 = $188&1;
     if ($189) {
      break;
     }
     $190 = HEAP32[$V_2>>2]|0;
     __THREW__ = 0;
     invoke_viiii(476,(2399784|0),($$03|0),($0|0),($190|0));
     $191 = __THREW__; __THREW__ = 0;
     $192 = $191&1;
     if ($192) {
      break;
     } else {
      $$0 = $185;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $157 = (invoke_iii(2734,(2234232|0),($__this|0))|0);
    $158 = __THREW__; __THREW__ = 0;
    $159 = $158&1;
    if ($159) {
     break;
    }
    if ($157) {
     $160 = HEAP32[$0>>2]|0;
     $161 = ($160|0)==(0|0);
     if ($161) {
      __THREW__ = 0;
      $162 = (invoke_iii(1003,0,($__this|0))|0);
      $163 = __THREW__; __THREW__ = 0;
      $164 = $163&1;
      if ($164) {
       break;
      } else {
       $$0 = $162;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    $165 = (invoke_iii(2730,(2617344|0),($__this|0))|0);
    $166 = __THREW__; __THREW__ = 0;
    $167 = $166&1;
    if ($167) {
     break;
    }
    $168 = HEAP32[3072664>>2]|0;
    $169 = HEAP32[3072672>>2]|0;
    __THREW__ = 0;
    $170 = (invoke_iiiii(101,(0|0),($168|0),($165|0),($169|0))|0);
    $171 = __THREW__; __THREW__ = 0;
    $172 = $171&1;
    if ($172) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2612400|0))|0);
    $173 = __THREW__; __THREW__ = 0;
    $174 = $173&1;
    if ($174) {
     break;
    }
    __THREW__ = 0;
    $175 = (invoke_ii(3469,(2612400|0))|0);
    $176 = __THREW__; __THREW__ = 0;
    $177 = $176&1;
    if ($177) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1951,($175|0),($170|0));
    $178 = __THREW__; __THREW__ = 0;
    $179 = $178&1;
    if ($179) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($175|0));
    $180 = __THREW__; __THREW__ = 0;
    $181 = $180&1;
    if ($181) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $193 = __THREW__; __THREW__ = 0;
   $194 = $193&1;
   if (!($194)) {
    $195 = HEAP8[((2191608 + 116|0))>>0]|0;
    $196 = ($195<<24>>24)==(0);
    if ($196) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $197 = __THREW__; __THREW__ = 0;
     $198 = $197&1;
     if ($198) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $199 = __THREW__; __THREW__ = 0;
     $200 = $199&1;
     if ($200) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2191608|0));
     $201 = __THREW__; __THREW__ = 0;
     $202 = $201&1;
     if ($202) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $203 = __THREW__; __THREW__ = 0;
    $204 = $203&1;
    if (!($204)) {
     $205 = HEAP32[((2191608 + 80|0))>>2]|0;
     $206 = HEAP32[$205>>2]|0;
     __THREW__ = 0;
     $207 = (invoke_iiii(574,(0|0),($name|0),($206|0))|0);
     $208 = __THREW__; __THREW__ = 0;
     $209 = $208&1;
     if (!($209)) {
      if ($207) {
       HEAP32[$1>>2] = 2145440;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$1+0>>2]|0;
       $210 = (invoke_iii(772,(0|0),($$byval_copy17|0))|0);
       $211 = __THREW__; __THREW__ = 0;
       $212 = $211&1;
       if ($212) {
        break;
       }
       __THREW__ = 0;
       $213 = (invoke_iiii(432,(0|0),($__this|0),($210|0))|0);
       $214 = __THREW__; __THREW__ = 0;
       $215 = $214&1;
       if ($215) {
        break;
       }
       if ($213) {
        HEAP32[$2>>2] = 2145440;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$2+0>>2]|0;
        $216 = (invoke_iii(772,(0|0),($$byval_copy17|0))|0);
        $217 = __THREW__; __THREW__ = 0;
        $218 = $217&1;
        if ($218) {
         break;
        }
        __THREW__ = 0;
        $219 = (invoke_iiii(429,(0|0),($__this|0),($216|0))|0);
        $220 = __THREW__; __THREW__ = 0;
        $221 = $220&1;
        if ($221) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2252392|0))|0);
        $222 = __THREW__; __THREW__ = 0;
        $223 = $222&1;
        if ($223) {
         break;
        }
        __THREW__ = 0;
        $224 = (invoke_iii(2769,($219|0),(2252392|0))|0);
        $225 = __THREW__; __THREW__ = 0;
        $226 = $225&1;
        if ($226) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($224|0));
        $227 = __THREW__; __THREW__ = 0;
        $228 = $227&1;
        if ($228) {
         break;
        }
        __THREW__ = 0;
        $229 = (invoke_ii(1916,($224|0))|0);
        $230 = __THREW__; __THREW__ = 0;
        $231 = $230&1;
        if ($231) {
         break;
        } else {
         $$01 = $229;
        }
       } else {
        $$01 = $name;
       }
      } else {
       $$01 = $name;
      }
      $232 = $$1 & 256;
      $233 = ($232|0)==(0);
      do {
       if ($233) {
        $V_7$0 = 0;
       } else {
        $234 = $$1 & 1;
        $235 = ($234|0)!=(0);
        __THREW__ = 0;
        $236 = (invoke_iiiiii(130,($__this|0),($$01|0),($$1|0),($235|0),($__this|0))|0);
        $237 = __THREW__; __THREW__ = 0;
        $238 = $237&1;
        if ($238) {
         break L1;
        }
        HEAP32[$V_10>>2] = 0;
        $239 = HEAP32[$0>>2]|0;
        $240 = ($239|0)==(0|0);
        if ($240) {
         __THREW__ = 0;
         (invoke_ii(2996,(1167664|0))|0);
         $241 = __THREW__; __THREW__ = 0;
         $242 = $241&1;
         if ($242) {
          break L1;
         }
         __THREW__ = 0;
         $243 = (invoke_iii(2768,(1167664|0),0)|0);
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if ($245) {
          break L1;
         }
         HEAP32[$0>>2] = $243;
        }
        __THREW__ = 0;
        invoke_vi(3799,($$03|0));
        $246 = __THREW__; __THREW__ = 0;
        $247 = $246&1;
        if ($247) {
         break L1;
        }
        __THREW__ = 0;
        $248 = (invoke_iiiiiiiiii(15,(2399672|0),($$03|0),($$1|0),($236|0),($0|0),($modifiers|0),($culture|0),($namedParameters|0),($V_10|0))|0);
        $249 = __THREW__; __THREW__ = 0;
        $250 = $249&1;
        if ($250) {
         break L1;
        }
        $251 = ($248|0)==(0|0);
        if ($251) {
         __THREW__ = 0;
         invoke_vi(3799,($236|0));
         $252 = __THREW__; __THREW__ = 0;
         $253 = $252&1;
         if ($253) {
          break L1;
         }
         $254 = (($236) + 12|0);
         $255 = HEAP32[$254>>2]|0;
         $256 = ($255|0)<(1);
         if ($256) {
          $262 = HEAP32[3072696>>2]|0;
          $263 = HEAP32[3072704>>2]|0;
          __THREW__ = 0;
          $264 = (invoke_iiiii(101,(0|0),($262|0),($$01|0),($263|0))|0);
          $265 = __THREW__; __THREW__ = 0;
          $266 = $265&1;
          if ($266) {
           break L1;
          } else {
           $V_7$0 = $264;
           break;
          }
         } else {
          $257 = HEAP32[3072680>>2]|0;
          $258 = HEAP32[3072688>>2]|0;
          __THREW__ = 0;
          $259 = (invoke_iiiii(101,(0|0),($257|0),($$01|0),($258|0))|0);
          $260 = __THREW__; __THREW__ = 0;
          $261 = $260&1;
          if ($261) {
           break L1;
          } else {
           $V_7$0 = $259;
           break;
          }
         }
        }
        __THREW__ = 0;
        invoke_vi(3799,($248|0));
        $267 = __THREW__; __THREW__ = 0;
        $268 = $267&1;
        if ($268) {
         break L1;
        }
        __THREW__ = 0;
        $269 = (invoke_iii(2730,(2397136|0),($248|0))|0);
        $270 = __THREW__; __THREW__ = 0;
        $271 = $270&1;
        if ($271) {
         break L1;
        }
        $272 = (($269) + 12|0);
        $V_13$0 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($269|0));
         $340 = __THREW__; __THREW__ = 0;
         $341 = $340&1;
         if ($341) {
          label = 7;
          break;
         }
         $342 = HEAP32[$272>>2]|0;
         $343 = ($V_13$0|0)<($342|0);
         if (!($343)) {
          label = 145;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2414728|0))|0);
         $344 = __THREW__; __THREW__ = 0;
         $345 = $344&1;
         if ($345) {
          label = 7;
          break;
         }
         $273 = HEAP8[((2414728 + 116|0))>>0]|0;
         $274 = ($273<<24>>24)==(0);
         if ($274) {
          __THREW__ = 0;
          (invoke_ii(2996,(2414728|0))|0);
          $275 = __THREW__; __THREW__ = 0;
          $276 = $275&1;
          if ($276) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2414728|0))|0);
          $277 = __THREW__; __THREW__ = 0;
          $278 = $277&1;
          if ($278) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3839,(2414728|0));
          $279 = __THREW__; __THREW__ = 0;
          $280 = $279&1;
          if ($280) {
           label = 7;
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2414728|0))|0);
         $281 = __THREW__; __THREW__ = 0;
         $282 = $281&1;
         if ($282) {
          label = 7;
          break;
         }
         $283 = HEAP32[((2414728 + 80|0))>>2]|0;
         $284 = HEAP32[$283>>2]|0;
         $285 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($285|0));
         $286 = __THREW__; __THREW__ = 0;
         $287 = $286&1;
         if ($287) {
          label = 7;
          break;
         }
         $288 = HEAP32[$0>>2]|0;
         $289 = (($288) + 12|0);
         $290 = HEAP32[$289>>2]|0;
         $291 = ($V_13$0>>>0)<($290>>>0);
         if ($291) {
          $298 = $288;
         } else {
          __THREW__ = 0;
          $292 = (invoke_i(132)|0);
          $293 = __THREW__; __THREW__ = 0;
          $294 = $293&1;
          if ($294) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($292|0));
          $295 = __THREW__; __THREW__ = 0;
          $296 = $295&1;
          if ($296) {
           label = 7;
           break;
          }
          $$pre75 = HEAP32[$0>>2]|0;
          $298 = $$pre75;
         }
         $297 = HEAP32[$298>>2]|0;
         $299 = (($298) + 16|0);
         $300 = (($297) + 92|0);
         $301 = HEAP32[$300>>2]|0;
         $302 = Math_imul($301, $V_13$0)|0;
         $303 = (($299) + ($302)|0);
         $304 = HEAP32[$303>>2]|0;
         $305 = ($284|0)==($304|0);
         if ($305) {
          __THREW__ = 0;
          invoke_vi(3799,($269|0));
          $306 = __THREW__; __THREW__ = 0;
          $307 = $306&1;
          if ($307) {
           label = 7;
           break;
          }
          $308 = HEAP32[$272>>2]|0;
          $309 = ($V_13$0>>>0)<($308>>>0);
          if (!($309)) {
           __THREW__ = 0;
           $310 = (invoke_i(132)|0);
           $311 = __THREW__; __THREW__ = 0;
           $312 = $311&1;
           if ($312) {
            label = 7;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($310|0));
           $313 = __THREW__; __THREW__ = 0;
           $314 = $313&1;
           if ($314) {
            label = 7;
            break;
           }
          }
          $315 = HEAP32[$269>>2]|0;
          $316 = (($315) + 92|0);
          $317 = HEAP32[$316>>2]|0;
          $318 = Math_imul($317, $V_13$0)|0;
          $$sum48 = (($318) + 16)|0;
          $319 = (($269) + ($$sum48)|0);
          $320 = HEAP32[$319>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($320|0));
          $321 = __THREW__; __THREW__ = 0;
          $322 = $321&1;
          if ($322) {
           label = 7;
           break;
          }
          __THREW__ = 0;
          $323 = (invoke_iii(2729,(2431784|0),($320|0))|0);
          $324 = __THREW__; __THREW__ = 0;
          $325 = $324&1;
          if ($325) {
           label = 7;
           break;
          }
          $326 = $323 & 4096;
          $327 = ($326|0)==(0);
          if ($327) {
           label = 136;
           break;
          }
         }
         $339 = (($V_13$0) + 1)|0;
         $V_13$0 = $339;
        }
        if ((label|0) == 7) {
         $18 = ___cxa_find_matching_catch()|0;
         $19 = tempRet0;
         $lpad$phi$index = $18;$lpad$phi$index6 = $19;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        else if ((label|0) == 136) {
         __THREW__ = 0;
         (invoke_ii(2996,(2560072|0))|0);
         $328 = __THREW__; __THREW__ = 0;
         $329 = $328&1;
         if ($329) {
          break L1;
         }
         __THREW__ = 0;
         $330 = (invoke_ii(3469,(2560072|0))|0);
         $331 = __THREW__; __THREW__ = 0;
         $332 = $331&1;
         if ($332) {
          break L1;
         }
         $333 = HEAP32[3072712>>2]|0;
         $334 = HEAP32[3072720>>2]|0;
         __THREW__ = 0;
         invoke_viii(641,($330|0),($333|0),($334|0));
         $335 = __THREW__; __THREW__ = 0;
         $336 = $335&1;
         if ($336) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3838,($330|0));
         $337 = __THREW__; __THREW__ = 0;
         $338 = $337&1;
         if ($338) {
          break L1;
         }
         // unreachable;
        }
        else if ((label|0) == 145) {
         __THREW__ = 0;
         invoke_vi(3799,($269|0));
         $346 = __THREW__; __THREW__ = 0;
         $347 = $346&1;
         if ($347) {
          break L1;
         }
         $348 = HEAP32[$272>>2]|0;
         $349 = ($348|0)<(1);
         do {
          if (!($349)) {
           __THREW__ = 0;
           invoke_vi(3799,($269|0));
           $350 = __THREW__; __THREW__ = 0;
           $351 = $350&1;
           if ($351) {
            break L1;
           }
           $352 = HEAP32[$272>>2]|0;
           $353 = (($352) + -1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($269|0));
           $354 = __THREW__; __THREW__ = 0;
           $355 = $354&1;
           if ($355) {
            break L1;
           }
           $356 = ($352|0)<(1);
           if ($356) {
            label = 151;
           } else {
            $357 = HEAP32[$272>>2]|0;
            $358 = ($353>>>0)<($357>>>0);
            if (!($358)) {
             label = 151;
            }
           }
           if ((label|0) == 151) {
            __THREW__ = 0;
            $359 = (invoke_i(132)|0);
            $360 = __THREW__; __THREW__ = 0;
            $361 = $360&1;
            if ($361) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3302,($359|0));
            $362 = __THREW__; __THREW__ = 0;
            $363 = $362&1;
            if ($363) {
             break L1;
            }
           }
           $364 = HEAP32[$269>>2]|0;
           $365 = (($364) + 92|0);
           $366 = HEAP32[$365>>2]|0;
           $367 = Math_imul($366, $353)|0;
           $$sum = (($367) + 16)|0;
           $368 = (($269) + ($$sum)|0);
           $369 = HEAP32[$368>>2]|0;
           HEAP32[$3>>2] = 2093160;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$3+0>>2]|0;
           $370 = (invoke_iii(772,(0|0),($$byval_copy17|0))|0);
           $371 = __THREW__; __THREW__ = 0;
           $372 = $371&1;
           if ($372) {
            break L1;
           }
           __THREW__ = 0;
           $373 = (invoke_iiii(431,(0|0),($369|0),($370|0))|0);
           $374 = __THREW__; __THREW__ = 0;
           $375 = $374&1;
           if ($375) {
            break L1;
           }
           if (!($373)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(685,0,($0|0),($248|0));
           $376 = __THREW__; __THREW__ = 0;
           $377 = $376&1;
           if ($377) {
            break L1;
           }
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3799,($248|0));
         $378 = __THREW__; __THREW__ = 0;
         $379 = $378&1;
         if ($379) {
          break L1;
         }
         $380 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         $381 = (invoke_iiiiiiii(119,(2410128|0),($248|0),($target|0),($$1|0),($$03|0),($380|0),($culture|0))|0);
         $382 = __THREW__; __THREW__ = 0;
         $383 = $382&1;
         if ($383) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($$03|0));
         $384 = __THREW__; __THREW__ = 0;
         $385 = $384&1;
         if ($385) {
          break L1;
         }
         $386 = HEAP32[$V_10>>2]|0;
         __THREW__ = 0;
         invoke_viiii(476,(2399784|0),($$03|0),($0|0),($386|0));
         $387 = __THREW__; __THREW__ = 0;
         $388 = $387&1;
         if ($388) {
          break L1;
         } else {
          $$0 = $381;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      } while(0);
      $389 = $$1 & 1024;
      $390 = ($389|0)==(0);
      do {
       if ($390) {
        $402 = $$1 & 2048;
        $403 = ($402|0)==(0);
        if ($403) {
         $V_8$0$off0 = 0;
        } else {
         __THREW__ = 0;
         $404 = (invoke_iiiii(323,(2615936|0),($__this|0),($$01|0),($$1|0))|0);
         $405 = __THREW__; __THREW__ = 0;
         $406 = $405&1;
         if ($406) {
          break L1;
         }
         $407 = ($404|0)==(0|0);
         if ($407) {
          $455 = $$1 & 8192;
          $456 = ($455|0)==(0);
          $V_8$0$off0 = $456;
          break;
         }
         $408 = HEAP32[$0>>2]|0;
         $409 = ($408|0)==(0|0);
         if ($409) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560584|0))|0);
          $410 = __THREW__; __THREW__ = 0;
          $411 = $410&1;
          if ($411) {
           break L1;
          }
          __THREW__ = 0;
          $412 = (invoke_ii(3469,(2560584|0))|0);
          $413 = __THREW__; __THREW__ = 0;
          $414 = $413&1;
          if ($414) {
           break L1;
          }
          $415 = HEAP32[3072728>>2]|0;
          __THREW__ = 0;
          invoke_vii(1925,($412|0),($415|0));
          $416 = __THREW__; __THREW__ = 0;
          $417 = $416&1;
          if ($417) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3838,($412|0));
          $418 = __THREW__; __THREW__ = 0;
          $419 = $418&1;
          if ($419) {
           break L1;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($408|0));
         $420 = __THREW__; __THREW__ = 0;
         $421 = $420&1;
         if ($421) {
          break L1;
         }
         $422 = HEAP32[$0>>2]|0;
         $423 = (($422) + 12|0);
         $424 = HEAP32[$423>>2]|0;
         $425 = ($424|0)==(1);
         if (!($425)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $426 = __THREW__; __THREW__ = 0;
          $427 = $426&1;
          if ($427) {
           break L1;
          }
          __THREW__ = 0;
          $428 = (invoke_ii(3469,(2560072|0))|0);
          $429 = __THREW__; __THREW__ = 0;
          $430 = $429&1;
          if ($430) {
           break L1;
          }
          $431 = HEAP32[3072736>>2]|0;
          $432 = HEAP32[3072744>>2]|0;
          __THREW__ = 0;
          invoke_viii(641,($428|0),($431|0),($432|0));
          $433 = __THREW__; __THREW__ = 0;
          $434 = $433&1;
          if ($434) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3838,($428|0));
          $435 = __THREW__; __THREW__ = 0;
          $436 = $435&1;
          if ($436) {
           break L1;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($422|0));
         $437 = __THREW__; __THREW__ = 0;
         $438 = $437&1;
         if ($438) {
          break L1;
         }
         $439 = HEAP32[$0>>2]|0;
         $440 = (($439) + 12|0);
         $441 = HEAP32[$440>>2]|0;
         $442 = ($441|0)==(0);
         if ($442) {
          __THREW__ = 0;
          $443 = (invoke_i(132)|0);
          $444 = __THREW__; __THREW__ = 0;
          $445 = $444&1;
          if ($445) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($443|0));
          $446 = __THREW__; __THREW__ = 0;
          $447 = $446&1;
          if ($447) {
           break L1;
          }
          $$pre = HEAP32[$0>>2]|0;
          $449 = $$pre;
         } else {
          $449 = $439;
         }
         $448 = (($449) + 16|0);
         $450 = HEAP32[$448>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($404|0));
         $451 = __THREW__; __THREW__ = 0;
         $452 = $451&1;
         if ($452) {
          break L1;
         }
         __THREW__ = 0;
         invoke_viiii(465,(2405696|0),($404|0),($target|0),($450|0));
         $453 = __THREW__; __THREW__ = 0;
         $454 = $453&1;
         if ($454) {
          break L1;
         } else {
          $$0 = 0;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } else {
        __THREW__ = 0;
        $391 = (invoke_iiiii(323,(2615936|0),($__this|0),($$01|0),($$1|0))|0);
        $392 = __THREW__; __THREW__ = 0;
        $393 = $392&1;
        if ($393) {
         break L1;
        }
        $394 = ($391|0)==(0|0);
        if ($394) {
         $400 = $$1 & 4096;
         $401 = ($400|0)==(0);
         $V_8$0$off0 = $401;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($391|0));
        $395 = __THREW__; __THREW__ = 0;
        $396 = $395&1;
        if ($396) {
         break L1;
        }
        __THREW__ = 0;
        $397 = (invoke_iiii(1643,(2406336|0),($391|0),($target|0))|0);
        $398 = __THREW__; __THREW__ = 0;
        $399 = $398&1;
        if ($399) {
         break L1;
        } else {
         $$0 = $397;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $457 = $$1 & 4096;
      $458 = ($457|0)==(0);
      do {
       if ($458) {
        $598 = $$1 & 8192;
        $599 = ($598|0)==(0);
        if ($599) {
         $V_8$1$off0 = $V_8$0$off0;
        } else {
         $600 = $$1 & 1;
         $601 = ($600|0)!=(0);
         __THREW__ = 0;
         $602 = (invoke_iiiiii(131,($__this|0),($$01|0),($$1|0),($601|0),($__this|0))|0);
         $603 = __THREW__; __THREW__ = 0;
         $604 = $603&1;
         if ($604) {
          break L1;
         }
         HEAP32[$V_29>>2] = 0;
         $605 = (($602) + 12|0);
         $606 = (($602) + 16|0);
         $V_30$0 = 0;$V_31$1 = 0;
         while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($602|0));
          $627 = __THREW__; __THREW__ = 0;
          $628 = $627&1;
          if ($628) {
           label = 4;
           break;
          }
          $629 = HEAP32[$605>>2]|0;
          $630 = ($V_30$0|0)<($629|0);
          if (!($630)) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($602|0));
          $631 = __THREW__; __THREW__ = 0;
          $632 = $631&1;
          if ($632) {
           label = 4;
           break;
          }
          $607 = HEAP32[$605>>2]|0;
          $608 = ($V_30$0>>>0)<($607>>>0);
          if (!($608)) {
           __THREW__ = 0;
           $609 = (invoke_i(132)|0);
           $610 = __THREW__; __THREW__ = 0;
           $611 = $610&1;
           if ($611) {
            label = 4;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($609|0));
           $612 = __THREW__; __THREW__ = 0;
           $613 = $612&1;
           if ($613) {
            label = 4;
            break;
           }
          }
          $614 = HEAP32[$602>>2]|0;
          $615 = (($614) + 92|0);
          $616 = HEAP32[$615>>2]|0;
          $617 = Math_imul($616, $V_30$0)|0;
          $618 = (($606) + ($617)|0);
          $619 = HEAP32[$618>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($619|0));
          $620 = __THREW__; __THREW__ = 0;
          $621 = $620&1;
          if ($621) {
           label = 4;
           break;
          }
          __THREW__ = 0;
          $622 = (invoke_iiii(1668,(2434352|0),($619|0),1)|0);
          $623 = __THREW__; __THREW__ = 0;
          $624 = $623&1;
          if ($624) {
           label = 4;
           break;
          }
          $not$51 = ($622|0)!=(0|0);
          $625 = $not$51&1;
          $V_31$1$ = (($625) + ($V_31$1))|0;
          $626 = (($V_30$0) + 1)|0;
          $V_30$0 = $626;$V_31$1 = $V_31$1$;
         }
         if ((label|0) == 4) {
          $12 = ___cxa_find_matching_catch()|0;
          $13 = tempRet0;
          $lpad$phi$index = $12;$lpad$phi$index6 = $13;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1238976|0))|0);
         $633 = __THREW__; __THREW__ = 0;
         $634 = $633&1;
         if ($634) {
          break L1;
         }
         __THREW__ = 0;
         $635 = (invoke_iii(2768,(1238976|0),($V_31$1|0))|0);
         $636 = __THREW__; __THREW__ = 0;
         $637 = $636&1;
         if ($637) {
          break L1;
         }
         $638 = (($635) + 16|0);
         $639 = (($635) + 12|0);
         $V_30$1 = 0;$V_31$3 = 0;
         while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($602|0));
          $678 = __THREW__; __THREW__ = 0;
          $679 = $678&1;
          if ($679) {
           label = 3;
           break;
          }
          $680 = HEAP32[$605>>2]|0;
          $681 = ($V_30$1|0)<($680|0);
          if (!($681)) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($602|0));
          $682 = __THREW__; __THREW__ = 0;
          $683 = $682&1;
          if ($683) {
           label = 3;
           break;
          }
          $640 = HEAP32[$605>>2]|0;
          $641 = ($V_30$1>>>0)<($640>>>0);
          if (!($641)) {
           __THREW__ = 0;
           $642 = (invoke_i(132)|0);
           $643 = __THREW__; __THREW__ = 0;
           $644 = $643&1;
           if ($644) {
            label = 3;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($642|0));
           $645 = __THREW__; __THREW__ = 0;
           $646 = $645&1;
           if ($646) {
            label = 3;
            break;
           }
          }
          $647 = HEAP32[$602>>2]|0;
          $648 = (($647) + 92|0);
          $649 = HEAP32[$648>>2]|0;
          $650 = Math_imul($649, $V_30$1)|0;
          $651 = (($606) + ($650)|0);
          $652 = HEAP32[$651>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($652|0));
          $653 = __THREW__; __THREW__ = 0;
          $654 = $653&1;
          if ($654) {
           label = 3;
           break;
          }
          __THREW__ = 0;
          $655 = (invoke_iiii(1668,(2434352|0),($652|0),1)|0);
          $656 = __THREW__; __THREW__ = 0;
          $657 = $656&1;
          if ($657) {
           label = 3;
           break;
          }
          $658 = ($655|0)==(0|0);
          if ($658) {
           $V_31$2 = $V_31$3;
          } else {
           $659 = (($V_31$3) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($635|0));
           $660 = __THREW__; __THREW__ = 0;
           $661 = $660&1;
           if ($661) {
            label = 3;
            break;
           }
           $662 = ($V_31$3|0)<(0);
           if ($662) {
            label = 268;
           } else {
            $663 = HEAP32[$639>>2]|0;
            $664 = ($V_31$3>>>0)<($663>>>0);
            if (!($664)) {
             label = 268;
            }
           }
           if ((label|0) == 268) {
            label = 0;
            __THREW__ = 0;
            $665 = (invoke_i(132)|0);
            $666 = __THREW__; __THREW__ = 0;
            $667 = $666&1;
            if ($667) {
             label = 3;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($665|0));
            $668 = __THREW__; __THREW__ = 0;
            $669 = $668&1;
            if ($669) {
             label = 3;
             break;
            }
           }
           __THREW__ = 0;
           invoke_vii(3492,($635|0),($655|0));
           $670 = __THREW__; __THREW__ = 0;
           $671 = $670&1;
           if ($671) {
            label = 3;
            break;
           }
           $672 = HEAP32[$635>>2]|0;
           $673 = (($672) + 92|0);
           $674 = HEAP32[$673>>2]|0;
           $675 = Math_imul($674, $V_31$3)|0;
           $676 = (($638) + ($675)|0);
           HEAP32[$676>>2] = $655;
           $V_31$2 = $659;
          }
          $677 = (($V_30$1) + 1)|0;
          $V_30$1 = $677;$V_31$3 = $V_31$2;
         }
         if ((label|0) == 3) {
          $10 = ___cxa_find_matching_catch()|0;
          $11 = tempRet0;
          $lpad$phi$index = $10;$lpad$phi$index6 = $11;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($$03|0));
         $684 = __THREW__; __THREW__ = 0;
         $685 = $684&1;
         if ($685) {
          break L1;
         }
         __THREW__ = 0;
         $686 = (invoke_iiiiiiiiii(15,(2399672|0),($$03|0),($$1|0),($635|0),($0|0),($modifiers|0),($culture|0),($namedParameters|0),($V_29|0))|0);
         $687 = __THREW__; __THREW__ = 0;
         $688 = $687&1;
         if ($688) {
          break L1;
         }
         $689 = ($686|0)==(0|0);
         if ($689) {
          $V_8$1$off0 = 1;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($686|0));
         $690 = __THREW__; __THREW__ = 0;
         $691 = $690&1;
         if ($691) {
          break L1;
         }
         __THREW__ = 0;
         $692 = (invoke_iii(2730,(2397136|0),($686|0))|0);
         $693 = __THREW__; __THREW__ = 0;
         $694 = $693&1;
         if ($694) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($692|0));
         $695 = __THREW__; __THREW__ = 0;
         $696 = $695&1;
         if ($696) {
          break L1;
         }
         $697 = (($692) + 12|0);
         $698 = HEAP32[$697>>2]|0;
         $699 = ($698|0)<(1);
         do {
          if (!($699)) {
           __THREW__ = 0;
           invoke_vi(3799,($692|0));
           $700 = __THREW__; __THREW__ = 0;
           $701 = $700&1;
           if ($701) {
            break L1;
           }
           $702 = HEAP32[$697>>2]|0;
           $703 = (($702) + -1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($692|0));
           $704 = __THREW__; __THREW__ = 0;
           $705 = $704&1;
           if ($705) {
            break L1;
           }
           $706 = ($702|0)<(1);
           if ($706) {
            label = 287;
           } else {
            $707 = HEAP32[$697>>2]|0;
            $708 = ($703>>>0)<($707>>>0);
            if (!($708)) {
             label = 287;
            }
           }
           if ((label|0) == 287) {
            __THREW__ = 0;
            $709 = (invoke_i(132)|0);
            $710 = __THREW__; __THREW__ = 0;
            $711 = $710&1;
            if ($711) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3302,($709|0));
            $712 = __THREW__; __THREW__ = 0;
            $713 = $712&1;
            if ($713) {
             break L1;
            }
           }
           $714 = HEAP32[$692>>2]|0;
           $715 = (($714) + 92|0);
           $716 = HEAP32[$715>>2]|0;
           $717 = Math_imul($716, $703)|0;
           $$sum50 = (($717) + 16)|0;
           $718 = (($692) + ($$sum50)|0);
           $719 = HEAP32[$718>>2]|0;
           HEAP32[$5>>2] = 2093160;
           __THREW__ = 0;
           ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$5+0>>2]|0;
           $720 = (invoke_iii(772,(0|0),($$byval_copy17|0))|0);
           $721 = __THREW__; __THREW__ = 0;
           $722 = $721&1;
           if ($722) {
            break L1;
           }
           __THREW__ = 0;
           $723 = (invoke_iiii(431,(0|0),($719|0),($720|0))|0);
           $724 = __THREW__; __THREW__ = 0;
           $725 = $724&1;
           if ($725) {
            break L1;
           }
           if (!($723)) {
            break;
           }
           __THREW__ = 0;
           invoke_viii(685,0,($0|0),($686|0));
           $726 = __THREW__; __THREW__ = 0;
           $727 = $726&1;
           if ($727) {
            break L1;
           }
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3799,($686|0));
         $728 = __THREW__; __THREW__ = 0;
         $729 = $728&1;
         if ($729) {
          break L1;
         }
         $730 = HEAP32[$0>>2]|0;
         __THREW__ = 0;
         $731 = (invoke_iiiiiiii(119,(2410128|0),($686|0),($target|0),($$1|0),($$03|0),($730|0),($culture|0))|0);
         $732 = __THREW__; __THREW__ = 0;
         $733 = $732&1;
         if ($733) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($$03|0));
         $734 = __THREW__; __THREW__ = 0;
         $735 = $734&1;
         if ($735) {
          break L1;
         }
         $736 = HEAP32[$V_29>>2]|0;
         __THREW__ = 0;
         invoke_viiii(476,(2399784|0),($$03|0),($0|0),($736|0));
         $737 = __THREW__; __THREW__ = 0;
         $738 = $737&1;
         if ($738) {
          break L1;
         } else {
          $$0 = $731;
         }
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       } else {
        $459 = $$1 & 1;
        $460 = ($459|0)!=(0);
        __THREW__ = 0;
        $461 = (invoke_iiiiii(131,($__this|0),($$01|0),($$1|0),($460|0),($__this|0))|0);
        $462 = __THREW__; __THREW__ = 0;
        $463 = $462&1;
        if ($463) {
         break L1;
        }
        HEAP32[$V_19>>2] = 0;
        $464 = (($461) + 12|0);
        $465 = (($461) + 16|0);
        $V_20$0 = 0;$V_21$1 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($461|0));
         $486 = __THREW__; __THREW__ = 0;
         $487 = $486&1;
         if ($487) {
          label = 6;
          break;
         }
         $488 = HEAP32[$464>>2]|0;
         $489 = ($V_20$0|0)<($488|0);
         if (!($489)) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($461|0));
         $490 = __THREW__; __THREW__ = 0;
         $491 = $490&1;
         if ($491) {
          label = 6;
          break;
         }
         $466 = HEAP32[$464>>2]|0;
         $467 = ($V_20$0>>>0)<($466>>>0);
         if (!($467)) {
          __THREW__ = 0;
          $468 = (invoke_i(132)|0);
          $469 = __THREW__; __THREW__ = 0;
          $470 = $469&1;
          if ($470) {
           label = 6;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($468|0));
          $471 = __THREW__; __THREW__ = 0;
          $472 = $471&1;
          if ($472) {
           label = 6;
           break;
          }
         }
         $473 = HEAP32[$461>>2]|0;
         $474 = (($473) + 92|0);
         $475 = HEAP32[$474>>2]|0;
         $476 = Math_imul($475, $V_20$0)|0;
         $477 = (($465) + ($476)|0);
         $478 = HEAP32[$477>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($478|0));
         $479 = __THREW__; __THREW__ = 0;
         $480 = $479&1;
         if ($480) {
          label = 6;
          break;
         }
         __THREW__ = 0;
         $481 = (invoke_iiii(1668,(2434288|0),($478|0),1)|0);
         $482 = __THREW__; __THREW__ = 0;
         $483 = $482&1;
         if ($483) {
          label = 6;
          break;
         }
         $not$ = ($481|0)!=(0|0);
         $484 = $not$&1;
         $V_21$1$ = (($484) + ($V_21$1))|0;
         $485 = (($V_20$0) + 1)|0;
         $V_20$0 = $485;$V_21$1 = $V_21$1$;
        }
        if ((label|0) == 6) {
         $16 = ___cxa_find_matching_catch()|0;
         $17 = tempRet0;
         $lpad$phi$index = $16;$lpad$phi$index6 = $17;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1238976|0))|0);
        $492 = __THREW__; __THREW__ = 0;
        $493 = $492&1;
        if ($493) {
         break L1;
        }
        __THREW__ = 0;
        $494 = (invoke_iii(2768,(1238976|0),($V_21$1|0))|0);
        $495 = __THREW__; __THREW__ = 0;
        $496 = $495&1;
        if ($496) {
         break L1;
        }
        $497 = (($494) + 16|0);
        $498 = (($494) + 12|0);
        $V_20$1 = 0;$V_21$3 = 0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($461|0));
         $537 = __THREW__; __THREW__ = 0;
         $538 = $537&1;
         if ($538) {
          label = 5;
          break;
         }
         $539 = HEAP32[$464>>2]|0;
         $540 = ($V_20$1|0)<($539|0);
         if (!($540)) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($461|0));
         $541 = __THREW__; __THREW__ = 0;
         $542 = $541&1;
         if ($542) {
          label = 5;
          break;
         }
         $499 = HEAP32[$464>>2]|0;
         $500 = ($V_20$1>>>0)<($499>>>0);
         if (!($500)) {
          __THREW__ = 0;
          $501 = (invoke_i(132)|0);
          $502 = __THREW__; __THREW__ = 0;
          $503 = $502&1;
          if ($503) {
           label = 5;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($501|0));
          $504 = __THREW__; __THREW__ = 0;
          $505 = $504&1;
          if ($505) {
           label = 5;
           break;
          }
         }
         $506 = HEAP32[$461>>2]|0;
         $507 = (($506) + 92|0);
         $508 = HEAP32[$507>>2]|0;
         $509 = Math_imul($508, $V_20$1)|0;
         $510 = (($465) + ($509)|0);
         $511 = HEAP32[$510>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($511|0));
         $512 = __THREW__; __THREW__ = 0;
         $513 = $512&1;
         if ($513) {
          label = 5;
          break;
         }
         __THREW__ = 0;
         $514 = (invoke_iiii(1668,(2434288|0),($511|0),1)|0);
         $515 = __THREW__; __THREW__ = 0;
         $516 = $515&1;
         if ($516) {
          label = 5;
          break;
         }
         $517 = ($514|0)==(0|0);
         if ($517) {
          $V_21$2 = $V_21$3;
         } else {
          $518 = (($V_21$3) + 1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($494|0));
          $519 = __THREW__; __THREW__ = 0;
          $520 = $519&1;
          if ($520) {
           label = 5;
           break;
          }
          $521 = ($V_21$3|0)<(0);
          if ($521) {
           label = 215;
          } else {
           $522 = HEAP32[$498>>2]|0;
           $523 = ($V_21$3>>>0)<($522>>>0);
           if (!($523)) {
            label = 215;
           }
          }
          if ((label|0) == 215) {
           label = 0;
           __THREW__ = 0;
           $524 = (invoke_i(132)|0);
           $525 = __THREW__; __THREW__ = 0;
           $526 = $525&1;
           if ($526) {
            label = 5;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($524|0));
           $527 = __THREW__; __THREW__ = 0;
           $528 = $527&1;
           if ($528) {
            label = 5;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($494|0),($514|0));
          $529 = __THREW__; __THREW__ = 0;
          $530 = $529&1;
          if ($530) {
           label = 5;
           break;
          }
          $531 = HEAP32[$494>>2]|0;
          $532 = (($531) + 92|0);
          $533 = HEAP32[$532>>2]|0;
          $534 = Math_imul($533, $V_21$3)|0;
          $535 = (($497) + ($534)|0);
          HEAP32[$535>>2] = $514;
          $V_21$2 = $518;
         }
         $536 = (($V_20$1) + 1)|0;
         $V_20$1 = $536;$V_21$3 = $V_21$2;
        }
        if ((label|0) == 5) {
         $14 = ___cxa_find_matching_catch()|0;
         $15 = tempRet0;
         $lpad$phi$index = $14;$lpad$phi$index6 = $15;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
        __THREW__ = 0;
        invoke_vi(3799,($$03|0));
        $543 = __THREW__; __THREW__ = 0;
        $544 = $543&1;
        if ($544) {
         break L1;
        }
        __THREW__ = 0;
        $545 = (invoke_iiiiiiiiii(15,(2399672|0),($$03|0),($$1|0),($494|0),($0|0),($modifiers|0),($culture|0),($namedParameters|0),($V_19|0))|0);
        $546 = __THREW__; __THREW__ = 0;
        $547 = $546&1;
        if ($547) {
         break L1;
        }
        $548 = ($545|0)==(0|0);
        if ($548) {
         $V_8$1$off0 = 1;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($545|0));
        $549 = __THREW__; __THREW__ = 0;
        $550 = $549&1;
        if ($550) {
         break L1;
        }
        __THREW__ = 0;
        $551 = (invoke_iii(2730,(2397136|0),($545|0))|0);
        $552 = __THREW__; __THREW__ = 0;
        $553 = $552&1;
        if ($553) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($551|0));
        $554 = __THREW__; __THREW__ = 0;
        $555 = $554&1;
        if ($555) {
         break L1;
        }
        $556 = (($551) + 12|0);
        $557 = HEAP32[$556>>2]|0;
        $558 = ($557|0)<(1);
        do {
         if (!($558)) {
          __THREW__ = 0;
          invoke_vi(3799,($551|0));
          $559 = __THREW__; __THREW__ = 0;
          $560 = $559&1;
          if ($560) {
           break L1;
          }
          $561 = HEAP32[$556>>2]|0;
          $562 = (($561) + -1)|0;
          __THREW__ = 0;
          invoke_vi(3799,($551|0));
          $563 = __THREW__; __THREW__ = 0;
          $564 = $563&1;
          if ($564) {
           break L1;
          }
          $565 = ($561|0)<(1);
          if ($565) {
           label = 234;
          } else {
           $566 = HEAP32[$556>>2]|0;
           $567 = ($562>>>0)<($566>>>0);
           if (!($567)) {
            label = 234;
           }
          }
          if ((label|0) == 234) {
           __THREW__ = 0;
           $568 = (invoke_i(132)|0);
           $569 = __THREW__; __THREW__ = 0;
           $570 = $569&1;
           if ($570) {
            break L1;
           }
           __THREW__ = 0;
           invoke_vi(3302,($568|0));
           $571 = __THREW__; __THREW__ = 0;
           $572 = $571&1;
           if ($572) {
            break L1;
           }
          }
          $573 = HEAP32[$551>>2]|0;
          $574 = (($573) + 92|0);
          $575 = HEAP32[$574>>2]|0;
          $576 = Math_imul($575, $562)|0;
          $$sum49 = (($576) + 16)|0;
          $577 = (($551) + ($$sum49)|0);
          $578 = HEAP32[$577>>2]|0;
          HEAP32[$4>>2] = 2093160;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy17+0>>2]=HEAP32[$4+0>>2]|0;
          $579 = (invoke_iii(772,(0|0),($$byval_copy17|0))|0);
          $580 = __THREW__; __THREW__ = 0;
          $581 = $580&1;
          if ($581) {
           break L1;
          }
          __THREW__ = 0;
          $582 = (invoke_iiii(431,(0|0),($578|0),($579|0))|0);
          $583 = __THREW__; __THREW__ = 0;
          $584 = $583&1;
          if ($584) {
           break L1;
          }
          if (!($582)) {
           break;
          }
          __THREW__ = 0;
          invoke_viii(685,0,($0|0),($545|0));
          $585 = __THREW__; __THREW__ = 0;
          $586 = $585&1;
          if ($586) {
           break L1;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3799,($545|0));
        $587 = __THREW__; __THREW__ = 0;
        $588 = $587&1;
        if ($588) {
         break L1;
        }
        $589 = HEAP32[$0>>2]|0;
        __THREW__ = 0;
        $590 = (invoke_iiiiiiii(119,(2410128|0),($545|0),($target|0),($$1|0),($$03|0),($589|0),($culture|0))|0);
        $591 = __THREW__; __THREW__ = 0;
        $592 = $591&1;
        if ($592) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3799,($$03|0));
        $593 = __THREW__; __THREW__ = 0;
        $594 = $593&1;
        if ($594) {
         break L1;
        }
        $595 = HEAP32[$V_19>>2]|0;
        __THREW__ = 0;
        invoke_viiii(476,(2399784|0),($$03|0),($0|0),($595|0));
        $596 = __THREW__; __THREW__ = 0;
        $597 = $596&1;
        if ($597) {
         break L1;
        } else {
         $$0 = $590;
        }
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      } while(0);
      $739 = ($V_7$0|0)==(0|0);
      if (!($739)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2612400|0))|0);
       $740 = __THREW__; __THREW__ = 0;
       $741 = $740&1;
       if ($741) {
        break;
       }
       __THREW__ = 0;
       $742 = (invoke_ii(3469,(2612400|0))|0);
       $743 = __THREW__; __THREW__ = 0;
       $744 = $743&1;
       if ($744) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(1951,($742|0),($V_7$0|0));
       $745 = __THREW__; __THREW__ = 0;
       $746 = $745&1;
       if ($746) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3838,($742|0));
       $747 = __THREW__; __THREW__ = 0;
       $748 = $747&1;
       if ($748) {
        break;
       }
       // unreachable;
      }
      if (!($V_8$1$off0)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $749 = HEAP32[3072752>>2]|0;
      $750 = HEAP32[3072760>>2]|0;
      __THREW__ = 0;
      $751 = (invoke_iiiii(101,(0|0),($749|0),($$01|0),($750|0))|0);
      $752 = __THREW__; __THREW__ = 0;
      $753 = $752&1;
      if ($753) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2611208|0))|0);
      $754 = __THREW__; __THREW__ = 0;
      $755 = $754&1;
      if ($755) {
       break;
      }
      __THREW__ = 0;
      $756 = (invoke_ii(3469,(2611208|0))|0);
      $757 = __THREW__; __THREW__ = 0;
      $758 = $757&1;
      if ($758) {
       break;
      }
      __THREW__ = 0;
      invoke_vii(1949,($756|0),($751|0));
      $759 = __THREW__; __THREW__ = 0;
      $760 = $759&1;
      if ($760) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3838,($756|0));
      $761 = __THREW__; __THREW__ = 0;
      $762 = $761&1;
      if ($762) {
       break;
      }
      // unreachable;
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 $lpad$phi$index = $20;$lpad$phi$index6 = $21;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN16VirtFuncInvoker7I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_S0_S0_S0_E6InvokeEP10MethodInfoPviS5_S5_S5_S5_S5_S5_($method,$obj,$p1,$p2,$p3,$p4,$p5,$p6,$p7) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $p4 = $p4|0;
 $p5 = $p5|0;
 $p6 = $p6|0;
 $p7 = $p7|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiiiiiiii[$3 & 63]($4,$p1,$p2,$p3,$p4,$p5,$p6,$p7)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN18VirtActionInvoker2I17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvS5_P22mscorlib_System_Object($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z53mscorlib_System_MonoType_m_ReorderParamArrayArgumentsP24mscorlib_System_MonoTypePP26mscorlib_System_Object_arrP37mscorlib_System_Reflection_MethodBase($__this,$args,$method) {
 $__this = $__this|0;
 $args = $args|0;
 $method = $method|0;
 var $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$0 = 0, $V_3$1 = 0, $V_4$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618976);
 __THREW__ = 0;
 invoke_vi(3799,($method|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2730,(2397136|0),($method|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      $11 = (invoke_iii(2768,(1167664|0),($8|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        $16 = HEAP32[$7>>2]|0;
        $17 = (($16) + -1)|0;
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         $20 = ($16|0)<(1);
         if ($20) {
          label = 10;
         } else {
          $21 = HEAP32[$7>>2]|0;
          $22 = ($17>>>0)<($21>>>0);
          if (!($22)) {
           label = 10;
          }
         }
         if ((label|0) == 10) {
          __THREW__ = 0;
          $23 = (invoke_i(132)|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if ($25) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($23|0));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if ($27) {
           break;
          }
         }
         $32 = HEAP32[$2>>2]|0;
         $33 = (($32) + 92|0);
         $34 = HEAP32[$33>>2]|0;
         $35 = Math_imul($34, $17)|0;
         $$sum = (($35) + 16)|0;
         $36 = (($2) + ($$sum)|0);
         $37 = HEAP32[$36>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($37|0));
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if (!($39)) {
          __THREW__ = 0;
          $40 = (invoke_iii(2730,(2397472|0),($37|0))|0);
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if (!($42)) {
           __THREW__ = 0;
           invoke_vi(3799,($40|0));
           $43 = __THREW__; __THREW__ = 0;
           $44 = $43&1;
           if (!($44)) {
            __THREW__ = 0;
            $45 = (invoke_iii(2730,(2224328|0),($40|0))|0);
            $46 = __THREW__; __THREW__ = 0;
            $47 = $46&1;
            if (!($47)) {
             $48 = HEAP32[$args>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($48|0));
             $49 = __THREW__; __THREW__ = 0;
             $50 = $49&1;
             if (!($50)) {
              $51 = (($48) + 12|0);
              $52 = HEAP32[$51>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $53 = __THREW__; __THREW__ = 0;
              $54 = $53&1;
              if (!($54)) {
               $55 = HEAP32[$7>>2]|0;
               $$neg1 = (($52) + 1)|0;
               $56 = (($$neg1) - ($55))|0;
               __THREW__ = 0;
               $57 = (invoke_iiii(688,(0|0),($45|0),($56|0))|0);
               $58 = __THREW__; __THREW__ = 0;
               $59 = $58&1;
               if (!($59)) {
                $60 = (($11) + 16|0);
                $61 = (($11) + 12|0);
                $V_3$1 = 0;$V_4$0 = 0;
                while(1) {
                 $122 = HEAP32[$args>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($122|0));
                 $123 = __THREW__; __THREW__ = 0;
                 $124 = $123&1;
                 if ($124) {
                  label = 12;
                  break;
                 }
                 $125 = (($122) + 12|0);
                 $126 = HEAP32[$125>>2]|0;
                 $127 = ($V_4$0|0)<($126|0);
                 if (!($127)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($2|0));
                 $128 = __THREW__; __THREW__ = 0;
                 $129 = $128&1;
                 if ($129) {
                  label = 12;
                  break;
                 }
                 $62 = HEAP32[$7>>2]|0;
                 $63 = (($62) + -1)|0;
                 $64 = ($V_4$0|0)<($63|0);
                 $65 = HEAP32[$args>>2]|0;
                 if ($64) {
                  __THREW__ = 0;
                  invoke_vi(3799,($65|0));
                  $66 = __THREW__; __THREW__ = 0;
                  $67 = $66&1;
                  if ($67) {
                   label = 12;
                   break;
                  }
                  $68 = (($65) + 12|0);
                  $69 = HEAP32[$68>>2]|0;
                  $70 = ($V_4$0>>>0)<($69>>>0);
                  if (!($70)) {
                   __THREW__ = 0;
                   $71 = (invoke_i(132)|0);
                   $72 = __THREW__; __THREW__ = 0;
                   $73 = $72&1;
                   if ($73) {
                    label = 12;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($71|0));
                   $74 = __THREW__; __THREW__ = 0;
                   $75 = $74&1;
                   if ($75) {
                    label = 12;
                    break;
                   }
                  }
                  $76 = HEAP32[$65>>2]|0;
                  $77 = (($65) + 16|0);
                  $78 = (($76) + 92|0);
                  $79 = HEAP32[$78>>2]|0;
                  $80 = Math_imul($79, $V_4$0)|0;
                  $81 = (($77) + ($80)|0);
                  $82 = HEAP32[$81>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($11|0));
                  $83 = __THREW__; __THREW__ = 0;
                  $84 = $83&1;
                  if ($84) {
                   label = 12;
                   break;
                  }
                  $85 = HEAP32[$61>>2]|0;
                  $86 = ($V_4$0>>>0)<($85>>>0);
                  if (!($86)) {
                   __THREW__ = 0;
                   $87 = (invoke_i(132)|0);
                   $88 = __THREW__; __THREW__ = 0;
                   $89 = $88&1;
                   if ($89) {
                    label = 12;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($87|0));
                   $90 = __THREW__; __THREW__ = 0;
                   $91 = $90&1;
                   if ($91) {
                    label = 12;
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($11|0),($82|0));
                  $92 = __THREW__; __THREW__ = 0;
                  $93 = $92&1;
                  if ($93) {
                   label = 12;
                   break;
                  }
                  $94 = HEAP32[$11>>2]|0;
                  $95 = (($94) + 92|0);
                  $96 = HEAP32[$95>>2]|0;
                  $97 = Math_imul($96, $V_4$0)|0;
                  $98 = (($60) + ($97)|0);
                  HEAP32[$98>>2] = $82;
                  $V_3$0 = $V_3$1;
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($65|0));
                  $99 = __THREW__; __THREW__ = 0;
                  $100 = $99&1;
                  if ($100) {
                   label = 12;
                   break;
                  }
                  $101 = (($65) + 12|0);
                  $102 = HEAP32[$101>>2]|0;
                  $103 = ($V_4$0>>>0)<($102>>>0);
                  if (!($103)) {
                   __THREW__ = 0;
                   $104 = (invoke_i(132)|0);
                   $105 = __THREW__; __THREW__ = 0;
                   $106 = $105&1;
                   if ($106) {
                    label = 12;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($104|0));
                   $107 = __THREW__; __THREW__ = 0;
                   $108 = $107&1;
                   if ($108) {
                    label = 12;
                    break;
                   }
                  }
                  $109 = HEAP32[$65>>2]|0;
                  $110 = (($65) + 16|0);
                  $111 = (($109) + 92|0);
                  $112 = HEAP32[$111>>2]|0;
                  $113 = Math_imul($112, $V_4$0)|0;
                  $114 = (($110) + ($113)|0);
                  $115 = HEAP32[$114>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($57|0));
                  $116 = __THREW__; __THREW__ = 0;
                  $117 = $116&1;
                  if ($117) {
                   label = 12;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(534,($57|0),($115|0),($V_3$1|0));
                  $118 = __THREW__; __THREW__ = 0;
                  $119 = $118&1;
                  if ($119) {
                   label = 12;
                   break;
                  }
                  $120 = (($V_3$1) + 1)|0;
                  $V_3$0 = $120;
                 }
                 $121 = (($V_4$0) + 1)|0;
                 $V_3$1 = $V_3$0;$V_4$0 = $121;
                }
                if ((label|0) == 12) {
                 $28 = ___cxa_find_matching_catch()|0;
                 $29 = tempRet0;
                 $lpad$phi$index = $28;$lpad$phi$index2 = $29;
                 __ZN16StackTraceSentryD2Ev(0);
                 ___resumeException($lpad$phi$index|0);
                 // unreachable;
                }
                __THREW__ = 0;
                invoke_vi(3799,($2|0));
                $130 = __THREW__; __THREW__ = 0;
                $131 = $130&1;
                if (!($131)) {
                 $132 = HEAP32[$7>>2]|0;
                 $133 = (($132) + -1)|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($11|0));
                 $134 = __THREW__; __THREW__ = 0;
                 $135 = $134&1;
                 if (!($135)) {
                  $136 = ($132|0)<(1);
                  if ($136) {
                   label = 49;
                  } else {
                   $137 = HEAP32[$61>>2]|0;
                   $138 = ($133>>>0)<($137>>>0);
                   if (!($138)) {
                    label = 49;
                   }
                  }
                  if ((label|0) == 49) {
                   __THREW__ = 0;
                   $139 = (invoke_i(132)|0);
                   $140 = __THREW__; __THREW__ = 0;
                   $141 = $140&1;
                   if ($141) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($139|0));
                   $142 = __THREW__; __THREW__ = 0;
                   $143 = $142&1;
                   if ($143) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($11|0),($57|0));
                  $144 = __THREW__; __THREW__ = 0;
                  $145 = $144&1;
                  if (!($145)) {
                   $146 = HEAP32[$11>>2]|0;
                   $147 = (($146) + 92|0);
                   $148 = HEAP32[$147>>2]|0;
                   $149 = Math_imul($148, $133)|0;
                   $150 = (($60) + ($149)|0);
                   HEAP32[$150>>2] = $57;
                   HEAP32[$args>>2] = $11;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 $lpad$phi$index = $30;$lpad$phi$index2 = $31;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z41mscorlib_System_MonoType_m_GetElementTypeP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617392);
 $0 = HEAP32[2617440>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2617448|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2617440>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_MonoType_m_get_UnderlyingSystemTypeP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617488);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($__this|0);
}
function __Z39mscorlib_System_MonoType_m_get_AssemblyP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617536);
 $0 = HEAP32[2617584>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2617592|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2617584>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52mscorlib_System_MonoType_m_get_AssemblyQualifiedNameP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617624);
 __THREW__ = 0;
 $0 = (invoke_iiii(1207,($__this|0),1,1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z38mscorlib_System_MonoType_m_getFullNameP24mscorlib_System_MonoTypebb($__this,$full_name,$assembly_qualified) {
 $__this = $__this|0;
 $full_name = $full_name|0;
 $assembly_qualified = $assembly_qualified|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617672);
 $0 = HEAP32[2617720>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2617728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2617720>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($__this|0),($full_name|0),($assembly_qualified|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_MonoType_m_get_BaseTypeP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617792);
 $0 = HEAP32[2617840>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2617848|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2617840>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z39mscorlib_System_MonoType_m_get_FullNameP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617344);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  (invoke_ii(2996,(2615360|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2615360|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2750,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     HEAP32[$0>>2] = $5;
     $10 = $5;
     label = 6;
    }
   }
  }
 } else {
  $10 = $1;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(3799,($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = (($10) + 8|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if (!($15)) {
    $V_0$0 = $14;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($V_0$0|0);
   }
   $18 = HEAP32[$0>>2]|0;
   __THREW__ = 0;
   $19 = (invoke_iiii(1207,($__this|0),1,0)|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    invoke_vi(3799,($18|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = (($18) + 8|0);
     HEAP32[$24>>2] = $19;
     $V_0$0 = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($V_0$0|0);
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z36mscorlib_System_MonoType_m_IsDefinedP24mscorlib_System_MonoTypeP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617880);
 __THREW__ = 0;
 $0 = (invoke_iiiii(188,0,($__this|0),($attributeType|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z101mscorlib_System_MonoType_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP24mscorlib_System_MonoTypeb($__this,$inherit) {
 $__this = $__this|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617928);
 __THREW__ = 0;
 $0 = (invoke_iiii(1202,0,($__this|0),($inherit|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z122mscorlib_System_MonoType_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP24mscorlib_System_MonoTypeP20mscorlib_System_Typeb($__this,$attributeType,$inherit) {
 $__this = $__this|0;
 $attributeType = $attributeType|0;
 $inherit = $inherit|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2617976);
 __THREW__ = 0;
 invoke_v(908);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($attributeType|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    $15 = (invoke_iiiii(187,0,($__this|0),($attributeType|0),($inherit|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3074000>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3838,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_MonoType_m_get_MemberTypeP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618024);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2618072|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = ($0|0)==(0|0);
   if (!($3)) {
    __THREW__ = 0;
    $6 = (invoke_iii(2734,(2618120|0),($__this|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    if (!($6)) {
     $$0 = 128;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   $$0 = 32;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_MonoType_m_get_NameP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618168);
 $0 = HEAP32[2618216>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2618224|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2618216>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_MonoType_m_get_NamespaceP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618256);
 $0 = HEAP32[2618304>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2618312|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2618304>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z37mscorlib_System_MonoType_m_get_ModuleP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618352);
 $0 = HEAP32[2618400>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2618408|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2618400>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_MonoType_m_get_DeclaringTypeP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618072);
 $0 = HEAP32[2618440>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2618448|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2618440>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_MonoType_m_get_ReflectedTypeP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618488);
 __THREW__ = 0;
 $0 = (invoke_iii(2730,(2618072|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z41mscorlib_System_MonoType_m_get_TypeHandleP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618536);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z40mscorlib_System_MonoType_m_GetObjectDataP24mscorlib_System_MonoTypeP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618584);
 $1 = $context;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 invoke_viiii(203,(0|0),($__this|0),($info|0),($tmpcast$byval_copy|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z35mscorlib_System_MonoType_m_ToStringP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618632);
 __THREW__ = 0;
 $0 = (invoke_iiii(1207,($__this|0),0,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z46mscorlib_System_MonoType_m_GetGenericArgumentsP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618680);
 $0 = HEAP32[2618728>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2618736|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2618728>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z56mscorlib_System_MonoType_m_get_ContainsGenericParametersP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618776);
 __THREW__ = 0;
 $0 = (invoke_iii(2734,(2618120|0),($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   if ($0) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   $7 = (invoke_iii(2734,(2237408|0),($__this|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    L7: do {
     if ($7) {
      __THREW__ = 0;
      $10 = (invoke_iii(2730,(2618680|0),($__this|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break L1;
      }
      $13 = (($10) + 12|0);
      $V_2$0 = 0;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($10|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       }
       $35 = HEAP32[$13>>2]|0;
       $36 = ($V_2$0|0)<($35|0);
       if (!($36)) {
        break L7;
       }
       __THREW__ = 0;
       invoke_vi(3799,($10|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       $14 = HEAP32[$13>>2]|0;
       $15 = ($V_2$0>>>0)<($14>>>0);
       if (!($15)) {
        __THREW__ = 0;
        $16 = (invoke_i(132)|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if ($18) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($16|0));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         break;
        }
       }
       $21 = HEAP32[$10>>2]|0;
       $22 = (($21) + 92|0);
       $23 = HEAP32[$22>>2]|0;
       $24 = Math_imul($23, $V_2$0)|0;
       $$sum = (($24) + 16)|0;
       $25 = (($10) + ($$sum)|0);
       $26 = HEAP32[$25>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($26|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       $29 = (invoke_iii(2734,(2223448|0),($26|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       $32 = (($V_2$0) + 1)|0;
       if ($29) {
        $$0 = 1;
        label = 24;
        break;
       } else {
        $V_2$0 = $32;
       }
      }
      if ((label|0) == 24) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $3 = ___cxa_find_matching_catch()|0;
      $4 = tempRet0;
      $lpad$phi$index = $3;$lpad$phi$index2 = $4;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    } while(0);
    __THREW__ = 0;
    $39 = (invoke_iii(2734,(2233800|0),($__this|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if (!($41)) {
     if (!($39)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $42 = (invoke_iii(2730,(2617392|0),($__this|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      __THREW__ = 0;
      invoke_vi(3799,($42|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if (!($46)) {
       __THREW__ = 0;
       $47 = (invoke_iii(2734,(2223448|0),($42|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        $$0 = $47;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_MonoType_m_get_IsGenericParameterP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618120);
 $0 = HEAP32[2618824>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2618832|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2618824>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_MonoType_m_GetGenericTypeDefinitionP24mscorlib_System_MonoType($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2618880);
 __THREW__ = 0;
 $0 = (invoke_ii(1895,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = ($0|0)==(0|0);
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($0|0);
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2607872|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_ii(3469,(2607872|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(2734,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vi(3838,($8|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      // unreachable;
     }
    }
   }
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I17VoidPointerTraits29mscorlib_System_BooleanTraitsS1_E6InvokeEPFPvS3_bbES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$2,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z54mscorlib_System_MulticastNotSupportedException_m__ctorP46mscorlib_System_MulticastNotSupportedExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2621464);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z77mscorlib_System_MulticastNotSupportedException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46mscorlib_System_NonSerializedAttribute_m__ctorP38mscorlib_System_NonSerializedAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2621824);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z69mscorlib_System_NonSerializedAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,256);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z91mscorlib_System_NotImplementedException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP39mscorlib_System_NotImplementedExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2622144);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147467263);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z70mscorlib_System_NotImplementedException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68mscorlib_System_NotSupportedException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_NullReferenceException_m__ctor_mscorlib_System_VoidP38mscorlib_System_NullReferenceException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2622944);
 __THREW__ = 0;
 invoke_v(909);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3074192>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2147467261);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z90mscorlib_System_NullReferenceException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP38mscorlib_System_NullReferenceExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2622992);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147467261);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z69mscorlib_System_NullReferenceException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z50mscorlib_System_NumberFormatter_CustomInfo_m__ctorP42mscorlib_System_NumberFormatter_CustomInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2623384);
 $0 = (($__this) + 16|0);
 HEAP32[$0>>2] = -1;
 $1 = (($__this) + 48|0);
 HEAP8[$1>>0] = 1;
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z61mscorlib_System_NumberFormatter_CustomInfo_m_GetActiveSectionP22mscorlib_System_ObjectP22mscorlib_System_StringPbbPiS4_($__this,$format,$positive,$zero,$offset,$length) {
 $__this = $__this|0;
 $format = $format|0;
 $positive = $positive|0;
 $zero = $zero|0;
 $offset = $offset|0;
 $length = $length|0;
 var $$ = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0;
 var $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0;
 var $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0;
 var $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0;
 var $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_3$0 = 0, $V_3$1 = 0, $V_4$0 = 0, $_stackTraceSentry = 0, $brmerge = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2623432);
 __THREW__ = 0;
 (invoke_ii(2996,(1170368|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2768,(1170368|0),3)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = (($2) + 16|0);
    $6 = (($2) + 12|0);
    $V_1$1 = 0;$V_2$1 = 0;$V_3$1 = 0;$V_4$0 = 0;
    L4: while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($format|0));
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $53 = (invoke_ii(1816,($format|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      label = 4;
      break;
     }
     $56 = ($V_4$0|0)<($53|0);
     if (!($56)) {
      label = 30;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($format|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      label = 4;
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_iii(621,($format|0),($V_4$0|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      label = 4;
      break;
     }
     $14 = ($11<<16>>16)==($V_3$1<<16>>16);
     do {
      if ($14) {
       label = 11;
      } else {
       $15 = ($V_3$1<<16>>16)==(0);
       if ($15) {
        if ((($11<<16>>16) == 39) | (($11<<16>>16) == 34)) {
         label = 11;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($format|0));
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if ($18) {
          label = 4;
          break L4;
         }
         __THREW__ = 0;
         $19 = (invoke_iii(621,($format|0),($V_4$0|0))|0);
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          label = 4;
          break L4;
         }
         $22 = ($19<<16>>16)==(59);
         if ($22) {
          $23 = ($V_4$0|0)==(0);
          if (!($23)) {
           __THREW__ = 0;
           invoke_vi(3799,($format|0));
           $24 = __THREW__; __THREW__ = 0;
           $25 = $24&1;
           if ($25) {
            label = 4;
            break L4;
           }
           $26 = (($V_4$0) + -1)|0;
           __THREW__ = 0;
           $27 = (invoke_iii(621,($format|0),($26|0))|0);
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if ($29) {
            label = 4;
            break L4;
           }
           $30 = ($27<<16>>16)==(92);
           if ($30) {
            $V_1$0 = $V_1$1;$V_2$0 = $V_2$1;$V_3$0 = 0;
            break;
           }
          }
          $31 = (($V_1$1) + 1)|0;
          $32 = (($V_4$0) - ($V_2$1))|0;
          __THREW__ = 0;
          invoke_vi(3799,($2|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           label = 4;
           break L4;
          }
          $35 = ($V_1$1|0)<(0);
          if ($35) {
           label = 22;
          } else {
           $36 = HEAP32[$6>>2]|0;
           $37 = ($V_1$1>>>0)<($36>>>0);
           if (!($37)) {
            label = 22;
           }
          }
          if ((label|0) == 22) {
           label = 0;
           __THREW__ = 0;
           $38 = (invoke_i(132)|0);
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if ($40) {
            label = 4;
            break L4;
           }
           __THREW__ = 0;
           invoke_vi(3302,($38|0));
           $41 = __THREW__; __THREW__ = 0;
           $42 = $41&1;
           if ($42) {
            label = 4;
            break L4;
           }
          }
          $43 = HEAP32[$2>>2]|0;
          $44 = (($43) + 92|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = Math_imul($45, $V_1$1)|0;
          $47 = (($5) + ($46)|0);
          HEAP32[$47>>2] = $32;
          $48 = (($V_4$0) + 1)|0;
          $49 = ($31|0)==(3);
          if ($49) {
           break L4;
          } else {
           $V_1$0 = $31;$V_2$0 = $48;$V_3$0 = 0;
          }
         } else {
          $V_1$0 = $V_1$1;$V_2$0 = $V_2$1;$V_3$0 = 0;
         }
        }
       } else {
        $V_1$0 = $V_1$1;$V_2$0 = $V_2$1;$V_3$0 = $V_3$1;
       }
      }
     } while(0);
     if ((label|0) == 11) {
      label = 0;
      $16 = ($V_3$1<<16>>16)==(0);
      $$ = $16 ? $11 : 0;
      $V_1$0 = $V_1$1;$V_2$0 = $V_2$1;$V_3$0 = $$;
     }
     $50 = (($V_4$0) + 1)|0;
     $V_1$1 = $V_1$0;$V_2$1 = $V_2$0;$V_3$1 = $V_3$0;$V_4$0 = $50;
    }
    if ((label|0) == 4) {
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     $lpad$phi$index = $7;$lpad$phi$index2 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    do {
     if ((label|0) == 30) {
      if ((($V_1$1|0) == 0)) {
       HEAP32[$offset>>2] = 0;
       __THREW__ = 0;
       invoke_vi(3799,($format|0));
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break L1;
       }
       __THREW__ = 0;
       $61 = (invoke_ii(1816,($format|0))|0);
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        break L1;
       }
       HEAP32[$length>>2] = $61;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      } else if ((($V_1$1|0) == 1)) {
       $64 = HEAP8[$positive>>0]|0;
       $$not = ($64<<24>>24)!=(0);
       $brmerge = $$not | $zero;
       if ($brmerge) {
        HEAP32[$offset>>2] = 0;
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         break L1;
        }
        $67 = HEAP32[$6>>2]|0;
        $68 = ($67|0)==(0);
        if ($68) {
         __THREW__ = 0;
         $69 = (invoke_i(132)|0);
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($69|0));
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          break L1;
         }
        }
        $74 = HEAP32[$5>>2]|0;
        HEAP32[$length>>2] = $74;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        break L1;
       }
       $77 = HEAP32[$6>>2]|0;
       $78 = ($77|0)==(0);
       if ($78) {
        __THREW__ = 0;
        $79 = (invoke_i(132)|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($79|0));
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         break L1;
        }
       }
       $84 = HEAP32[$5>>2]|0;
       $85 = (($84) + 1)|0;
       __THREW__ = 0;
       invoke_vi(3799,($format|0));
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break L1;
       }
       __THREW__ = 0;
       $88 = (invoke_ii(1816,($format|0))|0);
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if ($90) {
        break L1;
       }
       $91 = ($85|0)<($88|0);
       if (!($91)) {
        HEAP32[$offset>>2] = 0;
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $110 = __THREW__; __THREW__ = 0;
        $111 = $110&1;
        if ($111) {
         break L1;
        }
        $112 = HEAP32[$6>>2]|0;
        $113 = ($112|0)==(0);
        if ($113) {
         __THREW__ = 0;
         $114 = (invoke_i(132)|0);
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($114|0));
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          break L1;
         }
        }
        $119 = HEAP32[$5>>2]|0;
        HEAP32[$length>>2] = $119;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       HEAP8[$positive>>0] = 1;
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        break L1;
       }
       $94 = HEAP32[$6>>2]|0;
       $95 = ($94|0)==(0);
       if ($95) {
        __THREW__ = 0;
        $96 = (invoke_i(132)|0);
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if ($98) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($96|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         break L1;
        }
       }
       $101 = HEAP32[$5>>2]|0;
       $102 = (($101) + 1)|0;
       HEAP32[$offset>>2] = $102;
       __THREW__ = 0;
       invoke_vi(3799,($format|0));
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        break L1;
       }
       __THREW__ = 0;
       $105 = (invoke_ii(1816,($format|0))|0);
       $106 = __THREW__; __THREW__ = 0;
       $107 = $106&1;
       if ($107) {
        break L1;
       }
       $108 = HEAP32[$offset>>2]|0;
       $109 = (($105) - ($108))|0;
       HEAP32[$length>>2] = $109;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      } else if ((($V_1$1|0) == 2)) {
       if ($zero) {
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if ($121) {
         break L1;
        }
        $122 = HEAP32[$6>>2]|0;
        $123 = ($122|0)==(0);
        if ($123) {
         __THREW__ = 0;
         $124 = (invoke_i(132)|0);
         $125 = __THREW__; __THREW__ = 0;
         $126 = $125&1;
         if ($126) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($124|0));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          break L1;
         }
        }
        $129 = HEAP32[$5>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if ($131) {
         break L1;
        }
        $132 = HEAP32[$6>>2]|0;
        $133 = ($132>>>0)<(2);
        if ($133) {
         __THREW__ = 0;
         $134 = (invoke_i(132)|0);
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if ($136) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($134|0));
         $137 = __THREW__; __THREW__ = 0;
         $138 = $137&1;
         if ($138) {
          break L1;
         }
        }
        $139 = HEAP32[$2>>2]|0;
        $140 = (($139) + 92|0);
        $141 = HEAP32[$140>>2]|0;
        $142 = (($5) + ($141)|0);
        $143 = HEAP32[$142>>2]|0;
        $144 = (($129) + 2)|0;
        $145 = (($144) + ($143))|0;
        HEAP32[$offset>>2] = $145;
        __THREW__ = 0;
        invoke_vi(3799,($format|0));
        $146 = __THREW__; __THREW__ = 0;
        $147 = $146&1;
        if ($147) {
         break L1;
        }
        __THREW__ = 0;
        $148 = (invoke_ii(1816,($format|0))|0);
        $149 = __THREW__; __THREW__ = 0;
        $150 = $149&1;
        if ($150) {
         break L1;
        }
        $151 = HEAP32[$offset>>2]|0;
        $152 = (($148) - ($151))|0;
        HEAP32[$length>>2] = $152;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       $153 = HEAP8[$positive>>0]|0;
       $154 = ($153<<24>>24)==(0);
       if (!($154)) {
        HEAP32[$offset>>2] = 0;
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $155 = __THREW__; __THREW__ = 0;
        $156 = $155&1;
        if ($156) {
         break L1;
        }
        $157 = HEAP32[$6>>2]|0;
        $158 = ($157|0)==(0);
        if ($158) {
         __THREW__ = 0;
         $159 = (invoke_i(132)|0);
         $160 = __THREW__; __THREW__ = 0;
         $161 = $160&1;
         if ($161) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($159|0));
         $162 = __THREW__; __THREW__ = 0;
         $163 = $162&1;
         if ($163) {
          break L1;
         }
        }
        $164 = HEAP32[$5>>2]|0;
        HEAP32[$length>>2] = $164;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $165 = __THREW__; __THREW__ = 0;
       $166 = $165&1;
       if ($166) {
        break L1;
       }
       $167 = HEAP32[$6>>2]|0;
       $168 = ($167>>>0)<(2);
       if ($168) {
        __THREW__ = 0;
        $169 = (invoke_i(132)|0);
        $170 = __THREW__; __THREW__ = 0;
        $171 = $170&1;
        if ($171) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($169|0));
        $172 = __THREW__; __THREW__ = 0;
        $173 = $172&1;
        if ($173) {
         break L1;
        }
       }
       $174 = HEAP32[$2>>2]|0;
       $175 = (($174) + 92|0);
       $176 = HEAP32[$175>>2]|0;
       $177 = (($5) + ($176)|0);
       $178 = HEAP32[$177>>2]|0;
       $179 = ($178|0)<(1);
       if ($179) {
        HEAP32[$offset>>2] = 0;
        __THREW__ = 0;
        invoke_vi(3799,($2|0));
        $205 = __THREW__; __THREW__ = 0;
        $206 = $205&1;
        if ($206) {
         break L1;
        }
        $207 = HEAP32[$6>>2]|0;
        $208 = ($207|0)==(0);
        if ($208) {
         __THREW__ = 0;
         $209 = (invoke_i(132)|0);
         $210 = __THREW__; __THREW__ = 0;
         $211 = $210&1;
         if ($211) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($209|0));
         $212 = __THREW__; __THREW__ = 0;
         $213 = $212&1;
         if ($213) {
          break L1;
         }
        }
        $214 = HEAP32[$5>>2]|0;
        HEAP32[$length>>2] = $214;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       HEAP8[$positive>>0] = 1;
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $180 = __THREW__; __THREW__ = 0;
       $181 = $180&1;
       if ($181) {
        break L1;
       }
       $182 = HEAP32[$6>>2]|0;
       $183 = ($182|0)==(0);
       if ($183) {
        __THREW__ = 0;
        $184 = (invoke_i(132)|0);
        $185 = __THREW__; __THREW__ = 0;
        $186 = $185&1;
        if ($186) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($184|0));
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         break L1;
        }
       }
       $189 = HEAP32[$5>>2]|0;
       $190 = (($189) + 1)|0;
       HEAP32[$offset>>2] = $190;
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $191 = __THREW__; __THREW__ = 0;
       $192 = $191&1;
       if ($192) {
        break L1;
       }
       $193 = HEAP32[$6>>2]|0;
       $194 = ($193>>>0)<(2);
       if ($194) {
        __THREW__ = 0;
        $195 = (invoke_i(132)|0);
        $196 = __THREW__; __THREW__ = 0;
        $197 = $196&1;
        if ($197) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($195|0));
        $198 = __THREW__; __THREW__ = 0;
        $199 = $198&1;
        if ($199) {
         break L1;
        }
       }
       $200 = HEAP32[$2>>2]|0;
       $201 = (($200) + 92|0);
       $202 = HEAP32[$201>>2]|0;
       $203 = (($5) + ($202)|0);
       $204 = HEAP32[$203>>2]|0;
       HEAP32[$length>>2] = $204;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      } else if ((($V_1$1|0) == 3)) {
       break;
      } else {
       __THREW__ = 0;
       (invoke_ii(2996,(2560072|0))|0);
       $318 = __THREW__; __THREW__ = 0;
       $319 = $318&1;
       if ($319) {
        break L1;
       }
       __THREW__ = 0;
       $320 = (invoke_ii(3469,(2560072|0))|0);
       $321 = __THREW__; __THREW__ = 0;
       $322 = $321&1;
       if ($322) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(2583,($320|0));
       $323 = __THREW__; __THREW__ = 0;
       $324 = $323&1;
       if ($324) {
        break L1;
       }
       __THREW__ = 0;
       invoke_vi(3838,($320|0));
       $325 = __THREW__; __THREW__ = 0;
       $326 = $325&1;
       if ($326) {
        break L1;
       }
       // unreachable;
      }
     }
    } while(0);
    if ($zero) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $215 = __THREW__; __THREW__ = 0;
     $216 = $215&1;
     if ($216) {
      break;
     }
     $217 = HEAP32[$6>>2]|0;
     $218 = ($217|0)==(0);
     if ($218) {
      __THREW__ = 0;
      $219 = (invoke_i(132)|0);
      $220 = __THREW__; __THREW__ = 0;
      $221 = $220&1;
      if ($221) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($219|0));
      $222 = __THREW__; __THREW__ = 0;
      $223 = $222&1;
      if ($223) {
       break;
      }
     }
     $224 = HEAP32[$5>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $225 = __THREW__; __THREW__ = 0;
     $226 = $225&1;
     if ($226) {
      break;
     }
     $227 = HEAP32[$6>>2]|0;
     $228 = ($227>>>0)<(2);
     if ($228) {
      __THREW__ = 0;
      $229 = (invoke_i(132)|0);
      $230 = __THREW__; __THREW__ = 0;
      $231 = $230&1;
      if ($231) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($229|0));
      $232 = __THREW__; __THREW__ = 0;
      $233 = $232&1;
      if ($233) {
       break;
      }
     }
     $234 = HEAP32[$2>>2]|0;
     $235 = (($234) + 92|0);
     $236 = HEAP32[$235>>2]|0;
     $237 = (($5) + ($236)|0);
     $238 = HEAP32[$237>>2]|0;
     $239 = (($224) + 2)|0;
     $240 = (($239) + ($238))|0;
     HEAP32[$offset>>2] = $240;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $241 = __THREW__; __THREW__ = 0;
     $242 = $241&1;
     if ($242) {
      break;
     }
     $243 = HEAP32[$6>>2]|0;
     $244 = ($243>>>0)<(3);
     if ($244) {
      __THREW__ = 0;
      $245 = (invoke_i(132)|0);
      $246 = __THREW__; __THREW__ = 0;
      $247 = $246&1;
      if ($247) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($245|0));
      $248 = __THREW__; __THREW__ = 0;
      $249 = $248&1;
      if ($249) {
       break;
      }
     }
     $250 = HEAP32[$2>>2]|0;
     $251 = (($250) + 92|0);
     $252 = HEAP32[$251>>2]|0;
     $253 = $252 << 1;
     $254 = (($5) + ($253)|0);
     $255 = HEAP32[$254>>2]|0;
     HEAP32[$length>>2] = $255;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $256 = HEAP8[$positive>>0]|0;
    $257 = ($256<<24>>24)==(0);
    if (!($257)) {
     HEAP32[$offset>>2] = 0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $258 = __THREW__; __THREW__ = 0;
     $259 = $258&1;
     if ($259) {
      break;
     }
     $260 = HEAP32[$6>>2]|0;
     $261 = ($260|0)==(0);
     if ($261) {
      __THREW__ = 0;
      $262 = (invoke_i(132)|0);
      $263 = __THREW__; __THREW__ = 0;
      $264 = $263&1;
      if ($264) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($262|0));
      $265 = __THREW__; __THREW__ = 0;
      $266 = $265&1;
      if ($266) {
       break;
      }
     }
     $267 = HEAP32[$5>>2]|0;
     HEAP32[$length>>2] = $267;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $268 = __THREW__; __THREW__ = 0;
    $269 = $268&1;
    if (!($269)) {
     $270 = HEAP32[$6>>2]|0;
     $271 = ($270>>>0)<(2);
     if ($271) {
      __THREW__ = 0;
      $272 = (invoke_i(132)|0);
      $273 = __THREW__; __THREW__ = 0;
      $274 = $273&1;
      if ($274) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($272|0));
      $275 = __THREW__; __THREW__ = 0;
      $276 = $275&1;
      if ($276) {
       break;
      }
     }
     $277 = HEAP32[$2>>2]|0;
     $278 = (($277) + 92|0);
     $279 = HEAP32[$278>>2]|0;
     $280 = (($5) + ($279)|0);
     $281 = HEAP32[$280>>2]|0;
     $282 = ($281|0)<(1);
     if ($282) {
      HEAP32[$offset>>2] = 0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $308 = __THREW__; __THREW__ = 0;
      $309 = $308&1;
      if ($309) {
       break;
      }
      $310 = HEAP32[$6>>2]|0;
      $311 = ($310|0)==(0);
      if ($311) {
       __THREW__ = 0;
       $312 = (invoke_i(132)|0);
       $313 = __THREW__; __THREW__ = 0;
       $314 = $313&1;
       if ($314) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($312|0));
       $315 = __THREW__; __THREW__ = 0;
       $316 = $315&1;
       if ($316) {
        break;
       }
      }
      $317 = HEAP32[$5>>2]|0;
      HEAP32[$length>>2] = $317;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     HEAP8[$positive>>0] = 1;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $283 = __THREW__; __THREW__ = 0;
     $284 = $283&1;
     if (!($284)) {
      $285 = HEAP32[$6>>2]|0;
      $286 = ($285|0)==(0);
      if ($286) {
       __THREW__ = 0;
       $287 = (invoke_i(132)|0);
       $288 = __THREW__; __THREW__ = 0;
       $289 = $288&1;
       if ($289) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($287|0));
       $290 = __THREW__; __THREW__ = 0;
       $291 = $290&1;
       if ($291) {
        break;
       }
      }
      $292 = HEAP32[$5>>2]|0;
      $293 = (($292) + 1)|0;
      HEAP32[$offset>>2] = $293;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $294 = __THREW__; __THREW__ = 0;
      $295 = $294&1;
      if (!($295)) {
       $296 = HEAP32[$6>>2]|0;
       $297 = ($296>>>0)<(2);
       if ($297) {
        __THREW__ = 0;
        $298 = (invoke_i(132)|0);
        $299 = __THREW__; __THREW__ = 0;
        $300 = $299&1;
        if ($300) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($298|0));
        $301 = __THREW__; __THREW__ = 0;
        $302 = $301&1;
        if ($302) {
         break;
        }
       }
       $303 = HEAP32[$2>>2]|0;
       $304 = (($303) + 92|0);
       $305 = HEAP32[$304>>2]|0;
       $306 = (($5) + ($305)|0);
       $307 = HEAP32[$306>>2]|0;
       HEAP32[$length>>2] = $307;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z50mscorlib_System_NumberFormatter_CustomInfo_m_ParseP22mscorlib_System_ObjectP22mscorlib_System_StringiiP46mscorlib_System_Globalization_NumberFormatInfo($__this,$format,$offset,$length,$nfi) {
 $__this = $__this|0;
 $format = $format|0;
 $offset = $offset|0;
 $length = $length|0;
 $nfi = $nfi|0;
 var $$c = 0, $$c78 = 0, $$c79 = 0, $$c80 = 0, $$c81 = 0, $$c83 = 0, $$c84 = 0, $$c85 = 0, $$c86 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_0$198 = 0;
 var $V_1$0$off0 = 0, $V_1$1$off097 = 0, $V_2$0$off0 = 0, $V_2$1$off096 = 0, $V_3$0$off0 = 0, $V_3$1$off095 = 0, $V_4$0$off0 = 0, $V_4$1$off0 = 0, $V_4$2$off094 = 0, $V_6$0 = 0, $V_6$1$ = 0, $V_6$1$lcssa = 0, $V_6$193 = 0, $V_7$0 = 0, $V_7$1$c = 0, $V_7$1$c82 = 0, $V_7$192 = 0, $_stackTraceSentry = 0, $brmerge$demorgan = 0, $brmerge89$demorgan = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, $not$ = 0, $not$90 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2623480);
 __THREW__ = 0;
 (invoke_ii(2996,(2624536|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(3469,(2624536|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(2760,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = ($length|0)>(0);
     L5: do {
      if ($7) {
       $8 = (($2) + 16|0);
       $9 = (($2) + 36|0);
       $10 = (($2) + 48|0);
       $11 = (($2) + 60|0);
       $12 = (($2) + 24|0);
       $13 = (($2) + 32|0);
       $14 = (($2) + 8|0);
       $15 = (($2) + 12|0);
       $16 = (($2) + 40|0);
       $17 = (($2) + 20|0);
       $18 = (($2) + 44|0);
       $19 = (($2) + 28|0);
       $20 = (($2) + 56|0);
       $V_0$198 = 0;$V_1$1$off097 = 1;$V_2$1$off096 = 0;$V_3$1$off095 = 0;$V_4$2$off094 = 1;$V_6$193 = 0;$V_7$192 = $offset;
       L7: while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($format|0));
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         break;
        }
        __THREW__ = 0;
        $25 = (invoke_iii(621,($format|0),($V_7$192|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if ($27) {
         break;
        }
        $28 = $25&65535;
        $29 = ($25<<16>>16)==($V_0$198<<16>>16);
        $30 = ($25<<16>>16)!=(0);
        $or$cond = $29 & $30;
        L11: do {
         if ($or$cond) {
          $V_0$0 = 0;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
         } else {
          $31 = ($V_0$198<<16>>16)==(0);
          if ($31) {
           $brmerge$demorgan = $V_3$1$off095 & $30;
           if ($brmerge$demorgan) {
            if (!((($25<<16>>16) == 35) | (($25<<16>>16) == 48))) {
             __THREW__ = 0;
             invoke_vi(3799,($2|0));
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if ($33) {
              break L7;
             }
             $34 = HEAP32[$8>>2]|0;
             $35 = ($34|0)<(0);
             $36 = ($34|0)>(-1);
             $37 = (($V_7$192) + -1)|0;
             $V_0$0 = 0;$V_1$0$off0 = $35;$V_2$0$off0 = $36;$V_3$0$off0 = 0;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $37;
             break;
            }
           }
           $38 = (($28) + 65502)|0;
           $39 = $38 & 65535;
           do {
            if ((($39|0) == 5) | (($39|0) == 0)) {
             if (!((($25<<16>>16) == 39) | (($25<<16>>16) == 34))) {
              $V_0$0 = 0;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
              break L11;
             }
             $V_0$0 = $25;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
             break L11;
            } else if ((($39|0) == 1)) {
             $brmerge89$demorgan = $V_4$2$off094 & $V_1$1$off097;
             if ($brmerge89$demorgan) {
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $43 = __THREW__; __THREW__ = 0;
              $44 = $43&1;
              if ($44) {
               break L7;
              }
              $45 = HEAP32[$19>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $46 = __THREW__; __THREW__ = 0;
              $47 = $46&1;
              if ($47) {
               break L7;
              }
              $48 = (($45) + 1)|0;
              $$c86 = $48;
              HEAP32[$19>>2] = $$c86;
              break;
             }
             if ($V_2$1$off096) {
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $49 = __THREW__; __THREW__ = 0;
              $50 = $49&1;
              if ($50) {
               break L7;
              }
              $51 = HEAP32[$17>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $52 = __THREW__; __THREW__ = 0;
              $53 = $52&1;
              if ($53) {
               break L7;
              }
              $54 = (($51) + 1)|0;
              $$c85 = $54;
              HEAP32[$17>>2] = $$c85;
              break;
             }
             if ($V_3$1$off095) {
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if ($56) {
               break L7;
              }
              $57 = HEAP32[$18>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $58 = __THREW__; __THREW__ = 0;
              $59 = $58&1;
              if ($59) {
               break L7;
              }
              $60 = (($57) + 1)|0;
              $$c84 = $60;
              HEAP32[$18>>2] = $$c84;
             }
            } else if ((($39|0) == 3)) {
             __THREW__ = 0;
             invoke_vi(3799,($2|0));
             $120 = __THREW__; __THREW__ = 0;
             $121 = $120&1;
             if ($121) {
              break L7;
             }
             $122 = HEAP32[$20>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($2|0));
             $123 = __THREW__; __THREW__ = 0;
             $124 = $123&1;
             if ($124) {
              break L7;
             }
             $125 = (($122) + 1)|0;
             $$c83 = $125;
             HEAP32[$20>>2] = $$c83;
             $V_0$0 = 0;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
             break L11;
            } else {
             $40 = (($28) + 65492)|0;
             $41 = $40 & 65535;
             if ((($41|0) == 4)) {
              break;
             } else if ((($41|0) == 0)) {
              if (!($V_1$1$off097)) {
               $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
               break L11;
              }
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $132 = __THREW__; __THREW__ = 0;
              $133 = $132&1;
              if ($133) {
               break L7;
              }
              $134 = HEAP32[$12>>2]|0;
              $not$ = ($134|0)>(0);
              $135 = $not$&1;
              $V_6$1$ = (($135) + ($V_6$193))|0;
              $V_0$0 = 0;$V_1$0$off0 = 1;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$1$;$V_7$0 = $V_7$192;
              break L11;
             } else if ((($41|0) == 2)) {
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $114 = __THREW__; __THREW__ = 0;
              $115 = $114&1;
              if ($115) {
               break L7;
              }
              $116 = HEAP32[$8>>2]|0;
              $117 = ($116|0)==(-1);
              if (!($117)) {
               $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 1;$V_3$0$off0 = 0;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
               break L11;
              }
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $118 = __THREW__; __THREW__ = 0;
              $119 = $118&1;
              if ($119) {
               break L7;
              }
              $V_7$1$c82 = $V_7$192;
              HEAP32[$8>>2] = $V_7$1$c82;
              $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 1;$V_3$0$off0 = 0;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
              break L11;
             } else {
              if ((($25<<16>>16) == 92)) {
               $42 = (($V_7$192) + 1)|0;
               $V_0$0 = 0;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $42;
               break L11;
              } else if ((($25<<16>>16) == 8240)) {
               __THREW__ = 0;
               invoke_vi(3799,($2|0));
               $126 = __THREW__; __THREW__ = 0;
               $127 = $126&1;
               if ($127) {
                break L7;
               }
               $128 = HEAP32[$11>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($2|0));
               $129 = __THREW__; __THREW__ = 0;
               $130 = $129&1;
               if ($130) {
                break L7;
               }
               $131 = (($128) + 1)|0;
               $$c78 = $131;
               HEAP32[$11>>2] = $$c78;
               $V_0$0 = 0;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
               break L11;
              } else if ((($25<<16>>16) == 101) | (($25<<16>>16) == 69)) {
               __THREW__ = 0;
               invoke_vi(3799,($2|0));
               $93 = __THREW__; __THREW__ = 0;
               $94 = $93&1;
               if ($94) {
                break L7;
               }
               $95 = HEAP8[$9>>0]|0;
               $96 = ($95<<24>>24)==(0);
               if (!($96)) {
                $V_0$0 = 0;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
                break L11;
               }
               __THREW__ = 0;
               invoke_vi(3799,($2|0));
               $97 = __THREW__; __THREW__ = 0;
               $98 = $97&1;
               if ($98) {
                break L7;
               }
               HEAP8[$9>>0] = 1;
               $99 = (($V_7$192) + 1)|0;
               $100 = (($99) - ($offset))|0;
               $101 = ($100|0)<($length|0);
               if (!($101)) {
                $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
                break L11;
               }
               __THREW__ = 0;
               invoke_vi(3799,($format|0));
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               if ($103) {
                break L7;
               }
               __THREW__ = 0;
               $104 = (invoke_iii(621,($format|0),($99|0))|0);
               $105 = __THREW__; __THREW__ = 0;
               $106 = $105&1;
               if ($106) {
                break L7;
               }
               if ((($104<<16>>16) == 45)) {
                $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $99;
                break L11;
               } else if ((($104<<16>>16) == 43)) {
                __THREW__ = 0;
                invoke_vi(3799,($2|0));
                $107 = __THREW__; __THREW__ = 0;
                $108 = $107&1;
                if ($108) {
                 break L7;
                }
                HEAP8[$10>>0] = 0;
                $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $99;
                break L11;
               }
               if ((($104<<16>>16) == 35) | (($104<<16>>16) == 48)) {
                $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
                break L11;
               }
               __THREW__ = 0;
               invoke_vi(3799,($2|0));
               $109 = __THREW__; __THREW__ = 0;
               $110 = $109&1;
               if ($110) {
                break L7;
               }
               HEAP8[$9>>0] = 0;
               __THREW__ = 0;
               invoke_vi(3799,($2|0));
               $111 = __THREW__; __THREW__ = 0;
               $112 = $111&1;
               if ($112) {
                break L7;
               }
               $113 = HEAP32[$8>>2]|0;
               $not$90 = ($113|0)<(0);
               $V_0$0 = 0;$V_1$0$off0 = $not$90;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
               break L11;
              } else {
               $V_0$0 = 0;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
               break L11;
              }
             }
            }
           } while(0);
           $61 = ($25<<16>>16)==(35);
           do {
            if ($61) {
             $V_4$0$off0 = $V_4$2$off094;
            } else {
             if ($V_2$1$off096) {
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $62 = __THREW__; __THREW__ = 0;
              $63 = $62&1;
              if ($63) {
               break L7;
              }
              HEAP32[$17>>2] = 0;
              $V_4$0$off0 = 0;
              break;
             }
             if ($V_3$1$off095) {
              __THREW__ = 0;
              invoke_vi(3799,($2|0));
              $64 = __THREW__; __THREW__ = 0;
              $65 = $64&1;
              if ($65) {
               break L7;
              }
              HEAP32[$18>>2] = 0;
              $V_4$0$off0 = 0;
             } else {
              $V_4$0$off0 = 0;
             }
            }
           } while(0);
           __THREW__ = 0;
           invoke_vi(3799,($2|0));
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            break L7;
           }
           $68 = HEAP32[$13>>2]|0;
           $69 = ($68|0)==(-1);
           if ($69) {
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if ($71) {
             break L7;
            }
            $V_7$1$c = $V_7$192;
            HEAP32[$13>>2] = $V_7$1$c;
           }
           if ($V_1$1$off097) {
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if ($73) {
             break L7;
            }
            $74 = HEAP32[$12>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break L7;
            }
            $77 = (($74) + 1)|0;
            $$c81 = $77;
            HEAP32[$12>>2] = $$c81;
            $78 = ($V_6$193|0)<(1);
            if ($78) {
             $V_0$0 = 0;$V_1$0$off0 = 1;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$0$off0;$V_6$0 = 0;$V_7$0 = $V_7$192;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $79 = __THREW__; __THREW__ = 0;
            $80 = $79&1;
            if ($80) {
             break L7;
            }
            HEAP8[$14>>0] = 1;
            $V_0$0 = 0;$V_1$0$off0 = 1;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$0$off0;$V_6$0 = 0;$V_7$0 = $V_7$192;
            break;
           }
           if ($V_2$1$off096) {
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $81 = __THREW__; __THREW__ = 0;
            $82 = $81&1;
            if ($82) {
             break L7;
            }
            $83 = HEAP32[$15>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $84 = __THREW__; __THREW__ = 0;
            $85 = $84&1;
            if ($85) {
             break L7;
            }
            $86 = (($83) + 1)|0;
            $$c80 = $86;
            HEAP32[$15>>2] = $$c80;
            $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 1;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$0$off0;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
            break;
           }
           if ($V_3$1$off095) {
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $87 = __THREW__; __THREW__ = 0;
            $88 = $87&1;
            if ($88) {
             break L7;
            }
            $89 = HEAP32[$16>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($2|0));
            $90 = __THREW__; __THREW__ = 0;
            $91 = $90&1;
            if ($91) {
             break L7;
            }
            $92 = (($89) + 1)|0;
            $$c79 = $92;
            HEAP32[$16>>2] = $$c79;
            $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$1$off0 = $V_4$0$off0;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
           } else {
            $V_0$0 = 0;$V_1$0$off0 = 0;$V_2$0$off0 = 0;$V_3$0$off0 = 0;$V_4$1$off0 = $V_4$0$off0;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
           }
          } else {
           $V_0$0 = $V_0$198;$V_1$0$off0 = $V_1$1$off097;$V_2$0$off0 = $V_2$1$off096;$V_3$0$off0 = $V_3$1$off095;$V_4$1$off0 = $V_4$2$off094;$V_6$0 = $V_6$193;$V_7$0 = $V_7$192;
          }
         }
        } while(0);
        $136 = (($V_7$0) + 1)|0;
        $137 = (($136) - ($offset))|0;
        $138 = ($137|0)<($length|0);
        if ($138) {
         $V_0$198 = $V_0$0;$V_1$1$off097 = $V_1$0$off0;$V_2$1$off096 = $V_2$0$off0;$V_3$1$off095 = $V_3$0$off0;$V_4$2$off094 = $V_4$1$off0;$V_6$193 = $V_6$0;$V_7$192 = $136;
        } else {
         $$pre$phiZ2D = $2;$V_6$1$lcssa = $V_6$0;
         break L5;
        }
       }
       $21 = ___cxa_find_matching_catch()|0;
       $22 = tempRet0;
       $lpad$phi$index = $21;$lpad$phi$index2 = $22;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      } else {
       $$pre$phiZ2D = $2;$V_6$1$lcssa = 0;
      }
     } while(0);
     __THREW__ = 0;
     invoke_vi(3799,($$pre$phiZ2D|0));
     $141 = __THREW__; __THREW__ = 0;
     $142 = $141&1;
     if (!($142)) {
      $143 = (($2) + 40|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = ($144|0)==(0);
      if ($145) {
       __THREW__ = 0;
       invoke_vi(3799,($$pre$phiZ2D|0));
       $146 = __THREW__; __THREW__ = 0;
       $147 = $146&1;
       if ($147) {
        break;
       }
       $148 = (($2) + 36|0);
       HEAP8[$148>>0] = 0;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($$pre$phiZ2D|0));
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if ($150) {
        break;
       }
       $151 = (($2) + 28|0);
       HEAP32[$151>>2] = 0;
      }
      __THREW__ = 0;
      invoke_vi(3799,($$pre$phiZ2D|0));
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if (!($153)) {
       $154 = (($2) + 12|0);
       $155 = HEAP32[$154>>2]|0;
       $156 = ($155|0)==(0);
       if ($156) {
        __THREW__ = 0;
        invoke_vi(3799,($$pre$phiZ2D|0));
        $157 = __THREW__; __THREW__ = 0;
        $158 = $157&1;
        if ($158) {
         break;
        }
        $159 = (($2) + 16|0);
        HEAP32[$159>>2] = (-1);
       }
       __THREW__ = 0;
       invoke_vi(3799,($$pre$phiZ2D|0));
       $160 = __THREW__; __THREW__ = 0;
       $161 = $160&1;
       if (!($161)) {
        $162 = (($2) + 52|0);
        $163 = HEAP32[$162>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($$pre$phiZ2D|0));
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if (!($165)) {
         $166 = ($V_6$1$lcssa*3)|0;
         $167 = (($163) + ($166))|0;
         $$c = $167;
         HEAP32[$162>>2] = $$c;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($2|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $lpad$phi$index = $23;$lpad$phi$index2 = $24;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_NumberFormatter_CustomInfo_m_FormatP42mscorlib_System_NumberFormatter_CustomInfoP22mscorlib_System_StringiiP46mscorlib_System_Globalization_NumberFormatInfobP34mscorlib_System_Text_StringBuilderS6_S6_($__this,$format,$offset,$length,$nfi,$positive,$sb_int,$sb_dec,$sb_exp) {
 $__this = $__this|0;
 $format = $format|0;
 $offset = $offset|0;
 $length = $length|0;
 $nfi = $nfi|0;
 $positive = $positive|0;
 $sb_int = $sb_int|0;
 $sb_dec = $sb_dec|0;
 $sb_exp = $sb_exp|0;
 var $$0 = 0, $$1126 = 0, $$41 = 0, $$lcssa135 = 0, $$neg = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0;
 var $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0;
 var $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0;
 var $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0;
 var $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0;
 var $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0;
 var $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0;
 var $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0;
 var $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B10_0$0 = 0, $V_1$0 = 0, $V_1$1123 = 0, $V_10$0 = 0;
 var $V_11$1 = 0, $V_11$1$V_14$0 = 0, $V_11$2$lcssa = 0, $V_11$2137 = 0, $V_11$3 = 0, $V_11$343 = 0, $V_11$5$ph = 0, $V_11$5$ph57$ph = 0, $V_11$6 = 0, $V_11$7$ph = 0, $V_11$7106 = 0, $V_12$1$ph = 0, $V_12$1$ph56 = 0, $V_12$1$ph56$ph = 0, $V_12$2 = 0, $V_12$3$ph = 0, $V_12$3103 = 0, $V_13$0 = 0, $V_13$0$ = 0, $V_13$042 = 0;
 var $V_13$3$ph = 0, $V_13$4 = 0, $V_13$5$ph = 0, $V_13$5100 = 0, $V_14$0 = 0, $V_16$0 = 0, $V_16$199 = 0, $V_19$0$off0 = 0, $V_19$1$off078 = 0, $V_2$0$off0 = 0, $V_2$1$off0122 = 0, $V_20$074 = 0, $V_20$077 = 0, $V_20$077$lcssa168 = 0, $V_3$0$off0 = 0, $V_3$1$off0121 = 0, $V_4$0 = 0, $V_4$1118 = 0, $V_5$0 = 0, $V_5$0$ph = 0;
 var $V_5$0$ph59 = 0, $V_5$0$ph59$ph = 0, $V_5$0$ph65 = 0, $V_5$1 = 0, $V_5$2 = 0, $V_5$4 = 0, $V_5$5115 = 0, $V_6$0 = 0, $V_6$1112 = 0, $V_9$1$ph = 0, $V_9$1$ph58 = 0, $V_9$1$ph58$ph = 0, $V_9$1$ph64 = 0, $V_9$2 = 0, $V_9$3$ph = 0, $V_9$3109 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index9 = 0, $or$cond = 0;
 var $or$cond40 = 0, $or$cond45 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2623528);
 __THREW__ = 0;
 (invoke_ii(2996,(2537888|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(3469,(2537888|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(2525,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($nfi|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_ii(2033,($nfi|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($nfi|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        __THREW__ = 0;
        $14 = (invoke_ii(2032,($nfi|0))|0);
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         $17 = (($__this) + 8|0);
         $18 = HEAP8[$17>>0]|0;
         $19 = ($18<<24>>24)==(0);
         do {
          if ($19) {
           label = 53;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($9|0));
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if ($39) {
            break L1;
           }
           $40 = (($9) + 12|0);
           $41 = HEAP32[$40>>2]|0;
           $42 = ($41|0)<(1);
           if ($42) {
            label = 53;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($sb_int|0));
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break L1;
            }
            __THREW__ = 0;
            $45 = (invoke_ii(2398,($sb_int|0))|0);
            $46 = __THREW__; __THREW__ = 0;
            $47 = $46&1;
            if ($47) {
             break L1;
            }
            $48 = (($9) + 16|0);
            $V_10$0 = 0;$V_11$1 = 0;$V_14$0 = 0;
            while(1) {
             __THREW__ = 0;
             invoke_vi(3799,($9|0));
             $65 = __THREW__; __THREW__ = 0;
             $66 = $65&1;
             if ($66) {
              label = 16;
              break;
             }
             $67 = HEAP32[$40>>2]|0;
             $68 = ($V_14$0|0)<($67|0);
             if (!($68)) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($9|0));
             $69 = __THREW__; __THREW__ = 0;
             $70 = $69&1;
             if ($70) {
              label = 16;
              break;
             }
             $49 = HEAP32[$40>>2]|0;
             $50 = ($V_14$0>>>0)<($49>>>0);
             if (!($50)) {
              __THREW__ = 0;
              $51 = (invoke_i(132)|0);
              $52 = __THREW__; __THREW__ = 0;
              $53 = $52&1;
              if ($53) {
               label = 16;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($51|0));
              $54 = __THREW__; __THREW__ = 0;
              $55 = $54&1;
              if ($55) {
               label = 16;
               break;
              }
             }
             $56 = HEAP32[$9>>2]|0;
             $57 = (($56) + 92|0);
             $58 = HEAP32[$57>>2]|0;
             $59 = Math_imul($58, $V_14$0)|0;
             $60 = (($48) + ($59)|0);
             $61 = HEAP32[$60>>2]|0;
             $62 = (($61) + ($V_10$0))|0;
             $63 = ($62|0)>($45|0);
             $V_11$1$V_14$0 = $63 ? $V_11$1 : $V_14$0;
             $64 = (($V_14$0) + 1)|0;
             $V_10$0 = $62;$V_11$1 = $V_11$1$V_14$0;$V_14$0 = $64;
            }
            if ((label|0) == 16) {
             $34 = ___cxa_find_matching_catch()|0;
             $35 = tempRet0;
             $lpad$phi$index = $34;$lpad$phi$index9 = $35;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($lpad$phi$index|0);
             // unreachable;
            }
            __THREW__ = 0;
            invoke_vi(3799,($9|0));
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break L1;
            }
            $73 = ($V_11$1|0)<(0);
            if ($73) {
             label = 34;
            } else {
             $74 = HEAP32[$40>>2]|0;
             $75 = ($V_11$1>>>0)<($74>>>0);
             if (!($75)) {
              label = 34;
             }
            }
            if ((label|0) == 34) {
             __THREW__ = 0;
             $76 = (invoke_i(132)|0);
             $77 = __THREW__; __THREW__ = 0;
             $78 = $77&1;
             if ($78) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3302,($76|0));
             $79 = __THREW__; __THREW__ = 0;
             $80 = $79&1;
             if ($80) {
              break L1;
             }
            }
            $81 = HEAP32[$9>>2]|0;
            $82 = (($81) + 92|0);
            $83 = HEAP32[$82>>2]|0;
            $84 = Math_imul($83, $V_11$1)|0;
            $85 = (($48) + ($84)|0);
            $86 = HEAP32[$85>>2]|0;
            $87 = ($45|0)>($V_10$0|0);
            $88 = (($45) - ($V_10$0))|0;
            $G_B10_0$0 = $87 ? $88 : 0;
            $89 = ($86|0)==(0);
            if ($89) {
             L37: do {
              if ($73) {
               $$lcssa135 = 1;$V_11$2$lcssa = $V_11$1;
              } else {
               $V_11$2137 = $V_11$1;
               while(1) {
                __THREW__ = 0;
                invoke_vi(3799,($9|0));
                $91 = __THREW__; __THREW__ = 0;
                $92 = $91&1;
                if ($92) {
                 break;
                }
                $93 = HEAP32[$40>>2]|0;
                $94 = ($V_11$2137>>>0)<($93>>>0);
                if (!($94)) {
                 __THREW__ = 0;
                 $95 = (invoke_i(132)|0);
                 $96 = __THREW__; __THREW__ = 0;
                 $97 = $96&1;
                 if ($97) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($95|0));
                 $98 = __THREW__; __THREW__ = 0;
                 $99 = $98&1;
                 if ($99) {
                  break;
                 }
                }
                $100 = HEAP32[$9>>2]|0;
                $101 = (($100) + 92|0);
                $102 = HEAP32[$101>>2]|0;
                $103 = Math_imul($102, $V_11$2137)|0;
                $104 = (($48) + ($103)|0);
                $105 = HEAP32[$104>>2]|0;
                $106 = ($105|0)==(0);
                $107 = (($V_11$2137) + -1)|0;
                if (!($106)) {
                 $$lcssa135 = 0;$V_11$2$lcssa = $V_11$2137;
                 break L37;
                }
                $90 = ($V_11$2137|0)<(1);
                if ($90) {
                 $$lcssa135 = 1;$V_11$2$lcssa = $107;
                 break L37;
                } else {
                 $V_11$2137 = $107;
                }
               }
               $32 = ___cxa_find_matching_catch()|0;
               $33 = tempRet0;
               $lpad$phi$index = $32;$lpad$phi$index9 = $33;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($lpad$phi$index|0);
               // unreachable;
              }
             } while(0);
             $108 = ($G_B10_0$0|0)<(1);
             if ($108) {
              __THREW__ = 0;
              invoke_vi(3799,($9|0));
              $109 = __THREW__; __THREW__ = 0;
              $110 = $109&1;
              if ($110) {
               break L1;
              }
              if ($$lcssa135) {
               label = 48;
              } else {
               $111 = HEAP32[$40>>2]|0;
               $112 = ($V_11$2$lcssa>>>0)<($111>>>0);
               if (!($112)) {
                label = 48;
               }
              }
              if ((label|0) == 48) {
               __THREW__ = 0;
               $113 = (invoke_i(132)|0);
               $114 = __THREW__; __THREW__ = 0;
               $115 = $114&1;
               if ($115) {
                break L1;
               }
               __THREW__ = 0;
               invoke_vi(3302,($113|0));
               $116 = __THREW__; __THREW__ = 0;
               $117 = $116&1;
               if ($117) {
                break L1;
               }
              }
              $118 = HEAP32[$9>>2]|0;
              $119 = (($118) + 92|0);
              $120 = HEAP32[$119>>2]|0;
              $121 = Math_imul($120, $V_11$2$lcssa)|0;
              $122 = (($48) + ($121)|0);
              $123 = HEAP32[$122>>2]|0;
              $V_11$3 = $V_11$2$lcssa;$V_13$0 = $123;
              label = 51;
             } else {
              $V_11$343 = $V_11$2$lcssa;$V_13$042 = $88;
             }
            } else {
             $V_11$3 = $V_11$1;$V_13$0 = $86;
             label = 51;
            }
            if ((label|0) == 51) {
             $124 = ($G_B10_0$0|0)==(0);
             if ($124) {
              $V_11$7$ph = $V_11$3;$V_12$3$ph = $V_13$0;$V_13$5$ph = $V_13$0;$V_9$3$ph = $45;
              break;
             } else {
              $V_11$343 = $V_11$3;$V_13$042 = $V_13$0;
             }
            }
            $125 = (($G_B10_0$0|0) / ($V_13$042|0))&-1;
            $126 = (($125) + ($V_11$343))|0;
            $127 = (($G_B10_0$0|0) % ($V_13$042|0))&-1;
            $128 = ($127|0)==(0);
            $V_13$0$ = $128 ? $V_13$042 : $127;
            $129 = $128&1;
            $130 = $129 ^ 1;
            $$41 = (($126) + ($130))|0;
            $V_11$7$ph = $$41;$V_12$3$ph = $V_13$0$;$V_13$5$ph = $V_13$042;$V_9$3$ph = $45;
           }
          }
         } while(0);
         if ((label|0) == 53) {
          HEAP8[$17>>0] = 0;
          $V_11$7$ph = 0;$V_12$3$ph = 0;$V_13$5$ph = 0;$V_9$3$ph = 0;
         }
         $131 = ($length|0)>(0);
         L63: do {
          if ($131) {
           $132 = (($__this) + 36|0);
           $133 = (($__this) + 16|0);
           $134 = (($__this) + 12|0);
           $135 = (($__this) + 24|0);
           $136 = (($9) + 12|0);
           $137 = (($9) + 16|0);
           $$1126 = $sb_exp;$V_1$1123 = 0;$V_11$7106 = $V_11$7$ph;$V_12$3103 = $V_12$3$ph;$V_13$5100 = $V_13$5$ph;$V_16$199 = $offset;$V_2$1$off0122 = 1;$V_3$1$off0121 = 0;$V_4$1118 = 0;$V_5$5115 = 0;$V_6$1112 = 0;$V_9$3109 = $V_9$3$ph;
           L65: while(1) {
            __THREW__ = 0;
            invoke_vi(3799,($format|0));
            $354 = __THREW__; __THREW__ = 0;
            $355 = $354&1;
            if ($355) {
             label = 14;
             break;
            }
            __THREW__ = 0;
            $138 = (invoke_iii(621,($format|0),($V_16$199|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if ($140) {
             label = 14;
             break;
            }
            $141 = $138&65535;
            $142 = ($138<<16>>16)==($V_1$1123<<16>>16);
            $143 = ($138<<16>>16)!=(0);
            $or$cond = $142 & $143;
            L69: do {
             if ($or$cond) {
              $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
             } else {
              $144 = ($V_1$1123<<16>>16)==(0);
              if (!($144)) {
               __THREW__ = 0;
               invoke_vi(3799,($2|0));
               $145 = __THREW__; __THREW__ = 0;
               $146 = $145&1;
               if ($146) {
                label = 14;
                break L65;
               }
               __THREW__ = 0;
               (invoke_iii(992,($2|0),($138|0))|0);
               $147 = __THREW__; __THREW__ = 0;
               $148 = $147&1;
               if ($148) {
                label = 14;
                break L65;
               } else {
                $$0 = $$1126;$V_1$0 = $V_1$1123;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                break;
               }
              }
              $149 = (($141) + 65502)|0;
              $150 = $149 & 65535;
              do {
               if ((($150|0) == 5) | (($150|0) == 0)) {
                if (!((($138<<16>>16) == 39) | (($138<<16>>16) == 34))) {
                 $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                 break L69;
                }
                $$0 = $$1126;$V_1$0 = $138;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                break L69;
               } else if ((($150|0) == 3)) {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $329 = __THREW__; __THREW__ = 0;
                $330 = $329&1;
                if ($330) {
                 label = 14;
                 break L65;
                }
                __THREW__ = 0;
                $331 = (invoke_ii(2041,($nfi|0))|0);
                $332 = __THREW__; __THREW__ = 0;
                $333 = $332&1;
                if ($333) {
                 label = 14;
                 break L65;
                }
                __THREW__ = 0;
                invoke_vi(3799,($2|0));
                $334 = __THREW__; __THREW__ = 0;
                $335 = $334&1;
                if ($335) {
                 label = 14;
                 break L65;
                }
                __THREW__ = 0;
                (invoke_iii(989,($2|0),($331|0))|0);
                $336 = __THREW__; __THREW__ = 0;
                $337 = $336&1;
                if ($337) {
                 label = 14;
                 break L65;
                } else {
                 $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                 break L69;
                }
               } else if (!((($150|0) == 1))) {
                $151 = (($141) + 65492)|0;
                $152 = $151 & 65535;
                if ((($152|0) == 4)) {
                 break;
                } else if ((($152|0) == 2)) {
                 $294 = HEAP32[$133>>2]|0;
                 $295 = ($294|0)==($V_16$199|0);
                 if (!($295)) {
                  $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                  break L69;
                 }
                 $296 = HEAP32[$134>>2]|0;
                 $297 = ($296|0)<(1);
                 L80: do {
                  if ($297) {
                   $V_5$2 = $V_5$5115;
                  } else {
                   $V_5$1 = $V_5$5115;
                   while(1) {
                    __THREW__ = 0;
                    invoke_vi(3799,($sb_int|0));
                    $305 = __THREW__; __THREW__ = 0;
                    $306 = $305&1;
                    if ($306) {
                     label = 9;
                     break L65;
                    }
                    __THREW__ = 0;
                    $307 = (invoke_ii(2398,($sb_int|0))|0);
                    $308 = __THREW__; __THREW__ = 0;
                    $309 = $308&1;
                    if ($309) {
                     label = 9;
                     break L65;
                    }
                    $310 = ($V_5$1|0)<($307|0);
                    if (!($310)) {
                     $V_5$2 = $V_5$1;
                     break L80;
                    }
                    $311 = (($V_5$1) + 1)|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($sb_int|0));
                    $312 = __THREW__; __THREW__ = 0;
                    $313 = $312&1;
                    if ($313) {
                     label = 9;
                     break L65;
                    }
                    __THREW__ = 0;
                    $298 = (invoke_iii(988,($sb_int|0),($V_5$1|0))|0);
                    $299 = __THREW__; __THREW__ = 0;
                    $300 = $299&1;
                    if ($300) {
                     label = 9;
                     break L65;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($2|0));
                    $301 = __THREW__; __THREW__ = 0;
                    $302 = $301&1;
                    if ($302) {
                     label = 9;
                     break L65;
                    }
                    __THREW__ = 0;
                    (invoke_iii(992,($2|0),($298|0))|0);
                    $303 = __THREW__; __THREW__ = 0;
                    $304 = $303&1;
                    if ($304) {
                     label = 9;
                     break L65;
                    } else {
                     $V_5$1 = $311;
                    }
                   }
                  }
                 } while(0);
                 __THREW__ = 0;
                 invoke_vi(3799,($sb_dec|0));
                 $314 = __THREW__; __THREW__ = 0;
                 $315 = $314&1;
                 if ($315) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 $316 = (invoke_ii(2398,($sb_dec|0))|0);
                 $317 = __THREW__; __THREW__ = 0;
                 $318 = $317&1;
                 if ($318) {
                  label = 14;
                  break L65;
                 }
                 $319 = ($316|0)<(1);
                 if ($319) {
                  $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$2;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                  break L69;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($nfi|0));
                 $320 = __THREW__; __THREW__ = 0;
                 $321 = $320&1;
                 if ($321) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 $322 = (invoke_ii(2031,($nfi|0))|0);
                 $323 = __THREW__; __THREW__ = 0;
                 $324 = $323&1;
                 if ($324) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($2|0));
                 $325 = __THREW__; __THREW__ = 0;
                 $326 = $325&1;
                 if ($326) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 (invoke_iii(989,($2|0),($322|0))|0);
                 $327 = __THREW__; __THREW__ = 0;
                 $328 = $327&1;
                 if ($328) {
                  label = 14;
                  break L65;
                 } else {
                  $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$2;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                  break L69;
                 }
                } else if ((($152|0) == 0)) {
                 $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                 break L69;
                }
                if ((($138<<16>>16) == 92)) {
                 $153 = (($V_16$199) + 1)|0;
                 $154 = (($153) - ($offset))|0;
                 $155 = ($154|0)<($length|0);
                 if (!($155)) {
                  $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $153;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                  break L69;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($format|0));
                 $156 = __THREW__; __THREW__ = 0;
                 $157 = $156&1;
                 if ($157) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 $158 = (invoke_iii(621,($format|0),($153|0))|0);
                 $159 = __THREW__; __THREW__ = 0;
                 $160 = $159&1;
                 if ($160) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($2|0));
                 $161 = __THREW__; __THREW__ = 0;
                 $162 = $161&1;
                 if ($162) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 (invoke_iii(992,($2|0),($158|0))|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  label = 14;
                  break L65;
                 } else {
                  $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $153;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                  break L69;
                 }
                } else if ((($138<<16>>16) == 101) | (($138<<16>>16) == 69)) {
                 $246 = ($$1126|0)==(0|0);
                 do {
                  if (!($246)) {
                   $247 = HEAP8[$132>>0]|0;
                   $248 = ($247<<24>>24)==(0);
                   if ($248) {
                    break;
                   }
                   $253 = (($V_16$199) + 1)|0;
                   $254 = (($253) - ($offset))|0;
                   $255 = ($254|0)<($length|0);
                   L107: do {
                    if ($255) {
                     $V_19$1$off078 = 0;$V_20$077 = $253;
                     L108: while(1) {
                      __THREW__ = 0;
                      invoke_vi(3799,($format|0));
                      $276 = __THREW__; __THREW__ = 0;
                      $277 = $276&1;
                      if ($277) {
                       label = 13;
                       break L65;
                      }
                      __THREW__ = 0;
                      $256 = (invoke_iii(621,($format|0),($V_20$077|0))|0);
                      $257 = __THREW__; __THREW__ = 0;
                      $258 = $257&1;
                      if ($258) {
                       label = 13;
                       break L65;
                      }
                      $259 = ($256<<16>>16)==(48);
                      do {
                       if ($259) {
                        $V_19$0$off0 = 1;
                       } else {
                        $260 = ($V_20$077|0)==($253|0);
                        if (!($260)) {
                         $V_20$077$lcssa168 = $V_20$077;
                         break L108;
                        }
                        __THREW__ = 0;
                        invoke_vi(3799,($format|0));
                        $261 = __THREW__; __THREW__ = 0;
                        $262 = $261&1;
                        if ($262) {
                         label = 13;
                         break L65;
                        }
                        __THREW__ = 0;
                        $263 = (invoke_iii(621,($format|0),($253|0))|0);
                        $264 = __THREW__; __THREW__ = 0;
                        $265 = $264&1;
                        if ($265) {
                         label = 13;
                         break L65;
                        }
                        $266 = ($263<<16>>16)==(43);
                        if ($266) {
                         $V_19$0$off0 = $V_19$1$off078;
                         break;
                        }
                        __THREW__ = 0;
                        invoke_vi(3799,($format|0));
                        $267 = __THREW__; __THREW__ = 0;
                        $268 = $267&1;
                        if ($268) {
                         label = 13;
                         break L65;
                        }
                        __THREW__ = 0;
                        $269 = (invoke_iii(621,($format|0),($253|0))|0);
                        $270 = __THREW__; __THREW__ = 0;
                        $271 = $270&1;
                        if ($271) {
                         label = 13;
                         break L65;
                        }
                        $272 = ($269<<16>>16)==(45);
                        if ($272) {
                         $V_19$0$off0 = $V_19$1$off078;
                        } else {
                         $V_20$077$lcssa168 = $253;
                         break L108;
                        }
                       }
                      } while(0);
                      $273 = (($V_20$077) + 1)|0;
                      $274 = (($273) - ($offset))|0;
                      $275 = ($274|0)<($length|0);
                      if ($275) {
                       $V_19$1$off078 = $V_19$0$off0;$V_20$077 = $273;
                      } else {
                       $V_20$074 = $273;
                       break L107;
                      }
                     }
                     if ($V_19$1$off078) {
                      $V_20$074 = $V_20$077$lcssa168;
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(3799,($2|0));
                     $290 = __THREW__; __THREW__ = 0;
                     $291 = $290&1;
                     if ($291) {
                      label = 14;
                      break L65;
                     }
                     __THREW__ = 0;
                     (invoke_iii(992,($2|0),($138|0))|0);
                     $292 = __THREW__; __THREW__ = 0;
                     $293 = $292&1;
                     if ($293) {
                      label = 14;
                      break L65;
                     } else {
                      $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                      break L69;
                     }
                    } else {
                     $V_20$074 = $253;
                    }
                   } while(0);
                   $278 = (($V_20$074) + -1)|0;
                   $279 = HEAP32[$133>>2]|0;
                   $280 = ($279|0)<(0);
                   $281 = ($279|0)>(-1);
                   __THREW__ = 0;
                   invoke_vi(3799,($2|0));
                   $282 = __THREW__; __THREW__ = 0;
                   $283 = $282&1;
                   if ($283) {
                    label = 14;
                    break L65;
                   }
                   __THREW__ = 0;
                   (invoke_iii(992,($2|0),($138|0))|0);
                   $284 = __THREW__; __THREW__ = 0;
                   $285 = $284&1;
                   if ($285) {
                    label = 14;
                    break L65;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($2|0));
                   $286 = __THREW__; __THREW__ = 0;
                   $287 = $286&1;
                   if ($287) {
                    label = 14;
                    break L65;
                   }
                   __THREW__ = 0;
                   (invoke_iii(991,($2|0),($$1126|0))|0);
                   $288 = __THREW__; __THREW__ = 0;
                   $289 = $288&1;
                   if ($289) {
                    label = 14;
                    break L65;
                   } else {
                    $$0 = 0;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $278;$V_2$0$off0 = $280;$V_3$0$off0 = $281;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                    break L69;
                   }
                  }
                 } while(0);
                 __THREW__ = 0;
                 invoke_vi(3799,($2|0));
                 $249 = __THREW__; __THREW__ = 0;
                 $250 = $249&1;
                 if ($250) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 (invoke_iii(992,($2|0),($138|0))|0);
                 $251 = __THREW__; __THREW__ = 0;
                 $252 = $251&1;
                 if ($252) {
                  label = 14;
                  break L65;
                 } else {
                  $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                  break L69;
                 }
                } else if ((($138<<16>>16) == 8240)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($nfi|0));
                 $338 = __THREW__; __THREW__ = 0;
                 $339 = $338&1;
                 if ($339) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 $340 = (invoke_ii(2042,($nfi|0))|0);
                 $341 = __THREW__; __THREW__ = 0;
                 $342 = $341&1;
                 if ($342) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($2|0));
                 $343 = __THREW__; __THREW__ = 0;
                 $344 = $343&1;
                 if ($344) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 (invoke_iii(989,($2|0),($340|0))|0);
                 $345 = __THREW__; __THREW__ = 0;
                 $346 = $345&1;
                 if ($346) {
                  label = 14;
                  break L65;
                 } else {
                  $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                  break L69;
                 }
                } else {
                 __THREW__ = 0;
                 invoke_vi(3799,($2|0));
                 $347 = __THREW__; __THREW__ = 0;
                 $348 = $347&1;
                 if ($348) {
                  label = 14;
                  break L65;
                 }
                 __THREW__ = 0;
                 (invoke_iii(992,($2|0),($138|0))|0);
                 $349 = __THREW__; __THREW__ = 0;
                 $350 = $349&1;
                 if ($350) {
                  label = 14;
                  break L65;
                 } else {
                  $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = $V_2$1$off0122;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                  break L69;
                 }
                }
               }
              } while(0);
              if (!($V_2$1$off0122)) {
               if (!($V_3$1$off0121)) {
                __THREW__ = 0;
                invoke_vi(3799,($2|0));
                $242 = __THREW__; __THREW__ = 0;
                $243 = $242&1;
                if ($243) {
                 label = 14;
                 break L65;
                }
                __THREW__ = 0;
                (invoke_iii(992,($2|0),($138|0))|0);
                $244 = __THREW__; __THREW__ = 0;
                $245 = $244&1;
                if ($245) {
                 label = 14;
                 break L65;
                } else {
                 $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = 0;$V_3$0$off0 = 0;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                 break;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($sb_dec|0));
               $226 = __THREW__; __THREW__ = 0;
               $227 = $226&1;
               if ($227) {
                label = 14;
                break L65;
               }
               __THREW__ = 0;
               $228 = (invoke_ii(2398,($sb_dec|0))|0);
               $229 = __THREW__; __THREW__ = 0;
               $230 = $229&1;
               if ($230) {
                label = 14;
                break L65;
               }
               $231 = ($V_6$1112|0)<($228|0);
               if (!($231)) {
                $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
                break;
               }
               $232 = (($V_6$1112) + 1)|0;
               __THREW__ = 0;
               invoke_vi(3799,($sb_dec|0));
               $233 = __THREW__; __THREW__ = 0;
               $234 = $233&1;
               if ($234) {
                label = 14;
                break L65;
               }
               __THREW__ = 0;
               $235 = (invoke_iii(988,($sb_dec|0),($V_6$1112|0))|0);
               $236 = __THREW__; __THREW__ = 0;
               $237 = $236&1;
               if ($237) {
                label = 14;
                break L65;
               }
               __THREW__ = 0;
               invoke_vi(3799,($2|0));
               $238 = __THREW__; __THREW__ = 0;
               $239 = $238&1;
               if ($239) {
                label = 14;
                break L65;
               }
               __THREW__ = 0;
               (invoke_iii(992,($2|0),($235|0))|0);
               $240 = __THREW__; __THREW__ = 0;
               $241 = $240&1;
               if ($241) {
                label = 14;
                break L65;
               } else {
                $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = 0;$V_3$0$off0 = 1;$V_4$0 = $V_4$1118;$V_5$4 = $V_5$5115;$V_6$0 = $232;$V_9$2 = $V_9$3109;
                break;
               }
              }
              $165 = (($V_4$1118) + 1)|0;
              $166 = HEAP32[$135>>2]|0;
              $167 = (($166) - ($165))|0;
              __THREW__ = 0;
              invoke_vi(3799,($sb_int|0));
              $168 = __THREW__; __THREW__ = 0;
              $169 = $168&1;
              if ($169) {
               label = 14;
               break L65;
              }
              __THREW__ = 0;
              $170 = (invoke_ii(2398,($sb_int|0))|0);
              $171 = __THREW__; __THREW__ = 0;
              $172 = $171&1;
              if ($172) {
               label = 14;
               break L65;
              }
              $173 = (($170) + ($V_5$5115))|0;
              $174 = ($167|0)<($173|0);
              $175 = ($138<<16>>16)==(48);
              $or$cond40 = $174 | $175;
              if (!($or$cond40)) {
               $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$7106;$V_12$2 = $V_12$3103;$V_13$4 = $V_13$5100;$V_16$0 = $V_16$199;$V_2$0$off0 = 1;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $165;$V_5$4 = $V_5$5115;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$3109;
               break;
              }
              $$neg = $V_4$1118 ^ -1;
              $V_11$5$ph = $V_11$7106;$V_12$1$ph = $V_12$3103;$V_13$3$ph = $V_13$5100;$V_5$0$ph = $V_5$5115;$V_9$1$ph = $V_9$3109;
              while(1) {
               $V_11$5$ph57$ph = $V_11$5$ph;$V_12$1$ph56$ph = $V_12$1$ph;$V_5$0$ph59$ph = $V_5$0$ph;$V_9$1$ph58$ph = $V_9$1$ph;
               while(1) {
                $V_12$1$ph56 = $V_12$1$ph56$ph;$V_5$0$ph59 = $V_5$0$ph59$ph;$V_9$1$ph58 = $V_9$1$ph58$ph;
                while(1) {
                 $V_5$0$ph65 = $V_5$0$ph59;$V_9$1$ph64 = $V_9$1$ph58;
                 while(1) {
                  $V_5$0 = $V_5$0$ph65;
                  while(1) {
                   $214 = HEAP32[$135>>2]|0;
                   $215 = (($V_5$0) + ($$neg))|0;
                   $216 = (($215) + ($214))|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($sb_int|0));
                   $217 = __THREW__; __THREW__ = 0;
                   $218 = $217&1;
                   if ($218) {
                    label = 10;
                    break L65;
                   }
                   __THREW__ = 0;
                   $219 = (invoke_ii(2398,($sb_int|0))|0);
                   $220 = __THREW__; __THREW__ = 0;
                   $221 = $220&1;
                   if ($221) {
                    label = 10;
                    break L65;
                   }
                   $222 = ($216|0)<($219|0);
                   if (!($222)) {
                    $$0 = $$1126;$V_1$0 = 0;$V_11$6 = $V_11$5$ph57$ph;$V_12$2 = $V_12$1$ph56;$V_13$4 = $V_13$3$ph;$V_16$0 = $V_16$199;$V_2$0$off0 = 1;$V_3$0$off0 = $V_3$1$off0121;$V_4$0 = $165;$V_5$4 = $V_5$0;$V_6$0 = $V_6$1112;$V_9$2 = $V_9$1$ph64;
                    break L69;
                   }
                   $223 = (($V_5$0) + 1)|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($sb_int|0));
                   $224 = __THREW__; __THREW__ = 0;
                   $225 = $224&1;
                   if ($225) {
                    label = 10;
                    break L65;
                   }
                   __THREW__ = 0;
                   $176 = (invoke_iii(988,($sb_int|0),($V_5$0|0))|0);
                   $177 = __THREW__; __THREW__ = 0;
                   $178 = $177&1;
                   if ($178) {
                    label = 10;
                    break L65;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($2|0));
                   $179 = __THREW__; __THREW__ = 0;
                   $180 = $179&1;
                   if ($180) {
                    label = 10;
                    break L65;
                   }
                   __THREW__ = 0;
                   (invoke_iii(992,($2|0),($176|0))|0);
                   $181 = __THREW__; __THREW__ = 0;
                   $182 = $181&1;
                   if ($182) {
                    label = 10;
                    break L65;
                   }
                   $183 = HEAP8[$17>>0]|0;
                   $184 = ($183<<24>>24)==(0);
                   if ($184) {
                    $V_5$0 = $223;
                   } else {
                    break;
                   }
                  }
                  $185 = (($V_9$1$ph64) + -1)|0;
                  $186 = ($V_9$1$ph64|0)<(2);
                  if ($186) {
                   $V_5$0$ph65 = $223;$V_9$1$ph64 = $185;
                  } else {
                   break;
                  }
                 }
                 $187 = (($V_12$1$ph56) + -1)|0;
                 $188 = ($187|0)==(0);
                 if ($188) {
                  break;
                 } else {
                  $V_12$1$ph56 = $187;$V_5$0$ph59 = $223;$V_9$1$ph58 = $185;
                 }
                }
                __THREW__ = 0;
                invoke_vi(3799,($2|0));
                $189 = __THREW__; __THREW__ = 0;
                $190 = $189&1;
                if ($190) {
                 label = 11;
                 break L65;
                }
                __THREW__ = 0;
                (invoke_iii(989,($2|0),($14|0))|0);
                $191 = __THREW__; __THREW__ = 0;
                $192 = $191&1;
                if ($192) {
                 label = 11;
                 break L65;
                }
                $193 = (($V_11$5$ph57$ph) + -1)|0;
                __THREW__ = 0;
                invoke_vi(3799,($9|0));
                $194 = __THREW__; __THREW__ = 0;
                $195 = $194&1;
                if ($195) {
                 label = 11;
                 break L65;
                }
                $196 = HEAP32[$136>>2]|0;
                $197 = ($V_11$5$ph57$ph|0)>($196|0);
                $198 = ($V_11$5$ph57$ph|0)<(1);
                $or$cond45 = $197 | $198;
                if ($or$cond45) {
                 $V_11$5$ph57$ph = $193;$V_12$1$ph56$ph = $V_13$3$ph;$V_5$0$ph59$ph = $223;$V_9$1$ph58$ph = $185;
                } else {
                 break;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($9|0));
               $199 = __THREW__; __THREW__ = 0;
               $200 = $199&1;
               if ($200) {
                label = 12;
                break L65;
               }
               $201 = HEAP32[$136>>2]|0;
               $202 = ($193>>>0)<($201>>>0);
               if (!($202)) {
                __THREW__ = 0;
                $203 = (invoke_i(132)|0);
                $204 = __THREW__; __THREW__ = 0;
                $205 = $204&1;
                if ($205) {
                 label = 12;
                 break L65;
                }
                __THREW__ = 0;
                invoke_vi(3302,($203|0));
                $206 = __THREW__; __THREW__ = 0;
                $207 = $206&1;
                if ($207) {
                 label = 12;
                 break L65;
                }
               }
               $208 = HEAP32[$9>>2]|0;
               $209 = (($208) + 92|0);
               $210 = HEAP32[$209>>2]|0;
               $211 = Math_imul($210, $193)|0;
               $212 = (($137) + ($211)|0);
               $213 = HEAP32[$212>>2]|0;
               $V_11$5$ph = $193;$V_12$1$ph = $213;$V_13$3$ph = $213;$V_5$0$ph = $223;$V_9$1$ph = $185;
              }
             }
            } while(0);
            $351 = (($V_16$0) + 1)|0;
            $352 = (($351) - ($offset))|0;
            $353 = ($352|0)<($length|0);
            if ($353) {
             $$1126 = $$0;$V_1$1123 = $V_1$0;$V_11$7106 = $V_11$6;$V_12$3103 = $V_12$2;$V_13$5100 = $V_13$4;$V_16$199 = $351;$V_2$1$off0122 = $V_2$0$off0;$V_3$1$off0121 = $V_3$0$off0;$V_4$1118 = $V_4$0;$V_5$5115 = $V_5$4;$V_6$1112 = $V_6$0;$V_9$3109 = $V_9$2;
            } else {
             break L63;
            }
           }
           if ((label|0) == 9) {
            $20 = ___cxa_find_matching_catch()|0;
            $21 = tempRet0;
            $lpad$phi$index = $20;$lpad$phi$index9 = $21;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           else if ((label|0) == 10) {
            $22 = ___cxa_find_matching_catch()|0;
            $23 = tempRet0;
            $lpad$phi$index = $22;$lpad$phi$index9 = $23;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           else if ((label|0) == 11) {
            $24 = ___cxa_find_matching_catch()|0;
            $25 = tempRet0;
            $lpad$phi$index = $24;$lpad$phi$index9 = $25;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           else if ((label|0) == 12) {
            $26 = ___cxa_find_matching_catch()|0;
            $27 = tempRet0;
            $lpad$phi$index = $26;$lpad$phi$index9 = $27;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           else if ((label|0) == 13) {
            $28 = ___cxa_find_matching_catch()|0;
            $29 = tempRet0;
            $lpad$phi$index = $28;$lpad$phi$index9 = $29;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
           else if ((label|0) == 14) {
            $30 = ___cxa_find_matching_catch()|0;
            $31 = tempRet0;
            $lpad$phi$index = $30;$lpad$phi$index9 = $31;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
          }
         } while(0);
         if ($positive) {
          $$pre$phiZ2D = $2;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $356 = __THREW__; __THREW__ = 0;
          $357 = $356&1;
          if ($357) {
           break;
          }
          __THREW__ = 0;
          $358 = (invoke_ii(2029,($nfi|0))|0);
          $359 = __THREW__; __THREW__ = 0;
          $360 = $359&1;
          if ($360) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($2|0));
          $361 = __THREW__; __THREW__ = 0;
          $362 = $361&1;
          if ($362) {
           break;
          }
          __THREW__ = 0;
          (invoke_iiii(935,($2|0),0,($358|0))|0);
          $363 = __THREW__; __THREW__ = 0;
          $364 = $363&1;
          if ($364) {
           break;
          } else {
           $$pre$phiZ2D = $2;
          }
         }
         __THREW__ = 0;
         invoke_vi(3799,($$pre$phiZ2D|0));
         $365 = __THREW__; __THREW__ = 0;
         $366 = $365&1;
         if (!($366)) {
          __THREW__ = 0;
          $367 = (invoke_iii(2730,(2535432|0),($$pre$phiZ2D|0))|0);
          $368 = __THREW__; __THREW__ = 0;
          $369 = $368&1;
          if (!($369)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($367|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $36 = ___cxa_find_matching_catch()|0;
 $37 = tempRet0;
 $lpad$phi$index = $36;$lpad$phi$index9 = $37;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker5I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsS0_S0_E6InvokeEPFvPvS3_S3_bS3_S3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)!=(0);
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$0,$2,$6,$8,$10);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker8I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_S0_29mscorlib_System_BooleanTraitsS0_S0_S0_E6InvokeEPFPvS4_S4_iiS4_bS4_S4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP8[$10>>0]|0;
 $12 = ($11<<24>>24)!=(0);
 $13 = (($args) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($args) + 28|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (FUNCTION_TABLE_iiiiiiiiii[$func & 15]($obj,$0,$3,$6,$8,$12,$14,$16,$18)|0);
 STACKTOP = sp;return ($19|0);
}
function __Z39mscorlib_System_NumberFormatter_m__ctorP31mscorlib_System_NumberFormatterP32mscorlib_System_Threading_Thread($__this,$current) {
 $__this = $__this|0;
 $current = $current|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2624672);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1168808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2768,(1168808|0),0)|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 60|0);
    HEAP32[$7>>2] = $4;
    $8 = ($current|0)==(0|0);
    if ($8) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $11 = (($__this) + 8|0);
    HEAP32[$11>>2] = $current;
    __THREW__ = 0;
    $12 = (invoke_iii(1178,(0|0),($current|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __THREW__ = 0;
     invoke_vii(1963,($__this|0),($12|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z52mscorlib_System_NumberFormatter_m_set_CurrentCultureP31mscorlib_System_NumberFormatterP41mscorlib_System_Globalization_CultureInfo($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626208);
 $0 = ($value|0)==(0|0);
 do {
  if (!($0)) {
   __THREW__ = 0;
   invoke_vi(3799,($value|0));
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(1989,($value|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     if (!($3)) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2730,(2330184|0),($value|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       $13 = (($__this) + 12|0);
       HEAP32[$13>>2] = $10;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 } while(0);
 $14 = (($__this) + 12|0);
 HEAP32[$14>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z40mscorlib_System_NumberFormatter_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2624720);
 __THREW__ = 0;
 (invoke_ii(2996,(2633856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2633856 + 80|0))>>2]|0;
  __THREW__ = 0;
  (invoke_ii(2996,(2633856|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[((2633856 + 80|0))>>2]|0;
   $6 = (($5) + 4|0);
   __THREW__ = 0;
   (invoke_ii(2996,(2633856|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[((2633856 + 80|0))>>2]|0;
    $10 = (($9) + 8|0);
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[((2633856 + 80|0))>>2]|0;
     $14 = (($13) + 12|0);
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      $17 = HEAP32[((2633856 + 80|0))>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2633856|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = (($17) + 16|0);
       $21 = HEAP32[((2633856 + 80|0))>>2]|0;
       $22 = (($21) + 20|0);
       __THREW__ = 0;
       invoke_viiiiiii(21,0,($2|0),($6|0),($10|0),($14|0),($20|0),($22|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($25|0);
 // unreachable;
}
function __Z52mscorlib_System_NumberFormatter_m_GetFormatterTablesP22mscorlib_System_ObjectPPyPPiPPtS6_PPxS4_($__this,$MantissaBitsTable,$TensExponentTable,$DigitLowerTable,$DigitUpperTable,$TenPowersList,$DecHexDigits) {
 $__this = $__this|0;
 $MantissaBitsTable = $MantissaBitsTable|0;
 $TensExponentTable = $TensExponentTable|0;
 $DigitLowerTable = $DigitLowerTable|0;
 $DigitUpperTable = $DigitUpperTable|0;
 $TenPowersList = $TenPowersList|0;
 $DecHexDigits = $DecHexDigits|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2624768);
 $0 = HEAP32[2624816>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   __THREW__ = 0;
   $2 = (invoke_ii(3473,(2624824|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($5|0);
    // unreachable;
   } else {
    HEAP32[2624816>>2] = $2;
    $7 = $2;
    break;
   }
  } else {
   $7 = $0;
  }
 } while(0);
 __THREW__ = 0;
 invoke_viiiiii($7|0,($MantissaBitsTable|0),($TensExponentTable|0),($DigitLowerTable|0),($DigitUpperTable|0),($TenPowersList|0),($DecHexDigits|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z47mscorlib_System_NumberFormatter_m_GetTenPowerOfP22mscorlib_System_Objecti($__this,$i) {
 $__this = $__this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2624960);
 __THREW__ = 0;
 (invoke_ii(2996,(2633856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2633856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2633856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2633856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2633856 + 80|0))>>2]|0;
    $15 = (($14) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + ($i<<3)|0);
    $18 = $17;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($18) + 4)|0;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $23;
    STACKTOP = sp;return ($20|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_NumberFormatter_m_InitDecHexDigits_mscorlib_System_Void_mscorlib_System_UInt32P31mscorlib_System_NumberFormatterj($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625008);
 $0 = ($value>>>0)<(100000000);
 do {
  if ($0) {
   $$0 = $value;
  } else {
   $1 = (($value>>>0) / 100000000)&-1;
   __THREW__ = 0;
   $2 = (invoke_iii(1143,0,($1|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $12 = ___cxa_find_matching_catch()|0;
    $13 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($12|0);
    // unreachable;
   } else {
    $5 = Math_imul($1, -100000000)|0;
    $6 = (($5) + ($value))|0;
    $7 = (($__this) + 48|0);
    HEAP32[$7>>2] = $2;
    $$0 = $6;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 $8 = (invoke_iii(1144,0,($$0|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $12 = ___cxa_find_matching_catch()|0;
  $13 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($12|0);
  // unreachable;
 } else {
  $11 = (($__this) + 44|0);
  HEAP32[$11>>2] = $8;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z46mscorlib_System_NumberFormatter_m_FastToDecHexP22mscorlib_System_Objecti($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625152);
 $0 = ($val|0)>(99);
 do {
  if ($0) {
   $20 = ($val*5243)|0;
   $21 = $20 >> 19;
   __THREW__ = 0;
   (invoke_ii(2996,(2633856|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    $24 = HEAP8[((2633856 + 116|0))>>0]|0;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2633856|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     $34 = HEAP32[((2633856 + 80|0))>>2]|0;
     $35 = (($34) + 20|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = (($36) + ($21<<2)|0);
     $38 = HEAP32[$37>>2]|0;
     $39 = $38 << 8;
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if (!($41)) {
      $42 = HEAP8[((2633856 + 116|0))>>0]|0;
      $43 = ($42<<24>>24)==(0);
      if ($43) {
       __THREW__ = 0;
       (invoke_ii(2996,(2633856|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2633856|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2633856|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2633856|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if (!($51)) {
       $52 = HEAP32[((2633856 + 80|0))>>2]|0;
       $53 = (($52) + 20|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($21, -100)|0;
       $56 = (($55) + ($val))|0;
       $57 = (($54) + ($56<<2)|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = $58 | $39;
       $$0 = $59;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2633856|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    $3 = HEAP8[((2633856 + 116|0))>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $5 = __THREW__; __THREW__ = 0;
     $6 = $5&1;
     if ($6) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2633856|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = HEAP32[((2633856 + 80|0))>>2]|0;
     $16 = (($15) + 20|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = (($17) + ($val<<2)|0);
     $19 = HEAP32[$18>>2]|0;
     $$0 = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_NumberFormatter_m_ToDecHexP22mscorlib_System_Objecti($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625200);
 $0 = ($val|0)<(10000);
 if ($0) {
  $$0 = $val;$V_0$0 = 0;
  label = 4;
 } else {
  $1 = (($val|0) / 10000)&-1;
  __THREW__ = 0;
  $2 = (invoke_iii(1143,0,($1|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = Math_imul($1, -10000)|0;
   $6 = (($5) + ($val))|0;
   $7 = $2 << 16;
   $$0 = $6;$V_0$0 = $7;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  __THREW__ = 0;
  $8 = (invoke_iii(1143,0,($$0|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = $8 | $V_0$0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($11|0);
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_NumberFormatter_m_InitDecHexDigits_mscorlib_System_Void_mscorlib_System_UInt64P31mscorlib_System_NumberFormattery($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625056);
 $2 = ($1>>>0)<(0);
 $3 = ($1|0)==(0);
 $4 = ($0>>>0)<(100000000);
 $5 = $3 & $4;
 $6 = $2 | $5;
 do {
  if ($6) {
   $40 = $0;$42 = $1;
  } else {
   $7 = (___udivdi3(($0|0),($1|0),100000000,0)|0);
   $8 = tempRet0;
   $9 = (___muldi3(($7|0),($8|0),-100000000,-1)|0);
   $10 = tempRet0;
   $11 = (_i64Add(($9|0),($10|0),($0|0),($1|0))|0);
   $12 = tempRet0;
   $13 = ($1>>>0)<(2328306);
   $14 = ($1|0)==(2328306);
   $15 = ($0>>>0)<(1874919424);
   $16 = $14 & $15;
   $17 = $13 | $16;
   do {
    if ($17) {
     $29 = $7;$31 = $8;
    } else {
     $18 = (___udivdi3(($0|0),($1|0),1874919424,2328306)|0);
     $19 = tempRet0;
     __THREW__ = 0;
     $20 = (invoke_iii(1144,0,($18|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      $33 = ___cxa_find_matching_catch()|0;
      $34 = tempRet0;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($33|0);
      // unreachable;
     } else {
      $23 = (___muldi3(($18|0),($19|0),-100000000,-1)|0);
      $24 = tempRet0;
      $25 = (_i64Add(($23|0),($24|0),($7|0),($8|0))|0);
      $26 = tempRet0;
      $27 = (($__this) + 52|0);
      HEAP32[$27>>2] = $20;
      $29 = $25;$31 = $26;
      break;
     }
    }
   } while(0);
   $28 = ($29|0)==(0);
   $30 = ($31|0)==(0);
   $32 = $28 & $30;
   if ($32) {
    $40 = $11;$42 = $12;
   } else {
    __THREW__ = 0;
    $35 = (invoke_iii(1144,0,($29|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     $33 = ___cxa_find_matching_catch()|0;
     $34 = tempRet0;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($33|0);
     // unreachable;
    } else {
     $38 = (($__this) + 48|0);
     HEAP32[$38>>2] = $35;
     $40 = $11;$42 = $12;
     break;
    }
   }
  }
 } while(0);
 $39 = ($40|0)==(0);
 $41 = ($42|0)==(0);
 $43 = $39 & $41;
 if ($43) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 $44 = (invoke_iii(1144,0,($40|0))|0);
 $45 = __THREW__; __THREW__ = 0;
 $46 = $45&1;
 if ($46) {
  $33 = ___cxa_find_matching_catch()|0;
  $34 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($33|0);
  // unreachable;
 }
 $47 = (($__this) + 44|0);
 HEAP32[$47>>2] = $44;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z117mscorlib_System_NumberFormatter_m_InitDecHexDigits_mscorlib_System_Void_mscorlib_System_UInt32_mscorlib_System_UInt64P31mscorlib_System_NumberFormatterjy($__this,$hi,$0,$1) {
 $__this = $__this|0;
 $hi = $hi|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$1$off0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $9 = 0, $V_3$0$off0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625104);
 $2 = ($hi|0)==(0);
 if ($2) {
  __THREW__ = 0;
  invoke_viii(686,($__this|0),($0|0),($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  } else {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = (($hi>>>0) / 100000000)&-1;
 $8 = Math_imul($7, -100000000)|0;
 $9 = (($8) + ($hi))|0;
 $10 = (___udivdi3(($0|0),($1|0),100000000,0)|0);
 $11 = tempRet0;
 $12 = (___muldi3(($10|0),($11|0),-100000000,-1)|0);
 $13 = tempRet0;
 $14 = (_i64Add(($12|0),($13|0),($0|0),($1|0))|0);
 $15 = tempRet0;
 $16 = (___muldi3(($9|0),0,9551616,0)|0);
 $17 = tempRet0;
 $18 = (_i64Add(($14|0),($15|0),($16|0),($17|0))|0);
 $19 = tempRet0;
 $20 = (___muldi3(($9|0),0,-216152991,42)|0);
 $21 = tempRet0;
 $22 = (___udivdi3(($18|0),($19|0),100000000,0)|0);
 $23 = tempRet0;
 $24 = (___muldi3(($22|0),($23|0),-100000000,-1)|0);
 $25 = tempRet0;
 $26 = (_i64Add(($18|0),($19|0),($24|0),($25|0))|0);
 $27 = tempRet0;
 $28 = (_i64Add(($22|0),($23|0),($10|0),($11|0))|0);
 $29 = tempRet0;
 $30 = (_i64Add(($28|0),($29|0),($20|0),($21|0))|0);
 $31 = tempRet0;
 __THREW__ = 0;
 $32 = (invoke_iii(1144,0,($26|0))|0);
 $33 = __THREW__; __THREW__ = 0;
 $34 = $33&1;
 if ($34) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $35 = (($__this) + 44|0);
 HEAP32[$35>>2] = $32;
 $36 = (___udivdi3(($30|0),($31|0),100000000,0)|0);
 $37 = tempRet0;
 $38 = (___muldi3(($36|0),($37|0),-100000000,-1)|0);
 $39 = tempRet0;
 $40 = (_i64Add(($38|0),($39|0),($30|0),($31|0))|0);
 $41 = tempRet0;
 $42 = ($hi>>>0)>(99999999);
 if ($42) {
  $43 = (___muldi3(($7|0),0,-216152991,42)|0);
  $44 = tempRet0;
  $45 = (_i64Add(($36|0),($37|0),($43|0),($44|0))|0);
  $46 = tempRet0;
  $47 = (___muldi3(($7|0),0,9551616,0)|0);
  $48 = tempRet0;
  $49 = (_i64Add(($40|0),($41|0),($47|0),($48|0))|0);
  $50 = tempRet0;
  $51 = (___udivdi3(($49|0),($50|0),100000000,0)|0);
  $52 = tempRet0;
  $53 = (_i64Add(($45|0),($46|0),($51|0),($52|0))|0);
  $54 = tempRet0;
  $55 = (___muldi3(($51|0),($52|0),-100000000,-1)|0);
  $56 = tempRet0;
  $57 = (_i64Add(($55|0),($56|0),($49|0),($50|0))|0);
  $58 = tempRet0;
  $64 = $54;$67 = $53;$V_3$0$off0 = $57;
 } else {
  $64 = $37;$67 = $36;$V_3$0$off0 = $40;
 }
 __THREW__ = 0;
 $59 = (invoke_iii(1144,0,($V_3$0$off0|0))|0);
 $60 = __THREW__; __THREW__ = 0;
 $61 = $60&1;
 if ($61) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $62 = (($__this) + 48|0);
 HEAP32[$62>>2] = $59;
 $63 = ($64>>>0)<(0);
 $65 = ($64|0)==(0);
 $66 = ($67>>>0)<(100000000);
 $68 = $65 & $66;
 $69 = $63 | $68;
 do {
  if ($69) {
   $$1$off0 = $67;
  } else {
   $70 = (___udivdi3(($67|0),($64|0),100000000,0)|0);
   $71 = tempRet0;
   __THREW__ = 0;
   $72 = (invoke_iii(1144,0,($70|0))|0);
   $73 = __THREW__; __THREW__ = 0;
   $74 = $73&1;
   if ($74) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($5|0);
    // unreachable;
   } else {
    $75 = (___muldi3(($70|0),($71|0),-100000000,-1)|0);
    $76 = tempRet0;
    $77 = (_i64Add(($75|0),($76|0),($67|0),($64|0))|0);
    $78 = tempRet0;
    $79 = (($__this) + 56|0);
    HEAP32[$79>>2] = $72;
    $$1$off0 = $77;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 $80 = (invoke_iii(1144,0,($$1$off0|0))|0);
 $81 = __THREW__; __THREW__ = 0;
 $82 = $81&1;
 if ($82) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $83 = (($__this) + 52|0);
 HEAP32[$83>>2] = $80;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z47mscorlib_System_NumberFormatter_m_FastDecHexLenP22mscorlib_System_Objecti($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625248);
 $0 = ($val|0)>(255);
 if ($0) {
  $2 = ($val|0)>(4095);
  $$1 = $2 ? 4 : 3;
  $$0 = $$1;
 } else {
  $1 = ($val|0)>(15);
  $$ = $1 ? 2 : 1;
  $$0 = $$;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z88mscorlib_System_NumberFormatter_m_DecHexLen_mscorlib_System_Int32_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625296);
 $0 = ($val>>>0)>(65535);
 if ($0) {
  $6 = $val >>> 16;
  __THREW__ = 0;
  $7 = (invoke_iii(1145,0,($6|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = (($7) + 4)|0;
   $$0 = $10;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  __THREW__ = 0;
  $1 = (invoke_iii(1145,0,($val|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $$0 = $1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z65mscorlib_System_NumberFormatter_m_DecHexLen_mscorlib_System_Int32P31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625344);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   $9 = (($__this) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   if (!($11)) {
    __THREW__ = 0;
    $12 = (invoke_iii(1146,0,($10|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     label = 4;
     break;
    }
    $15 = (($12) + 16)|0;
    $$0 = $15;
    label = 13;
    break;
   }
   $16 = (($__this) + 48|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0);
   if ($18) {
    $23 = (($__this) + 44|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(0);
    if ($25) {
     $$0 = 0;
     label = 13;
     break;
    }
    __THREW__ = 0;
    $26 = (invoke_iii(1146,0,($24|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     label = 4;
     break;
    } else {
     $$0 = $26;
     label = 13;
     break;
    }
   } else {
    __THREW__ = 0;
    $19 = (invoke_iii(1146,0,($17|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 4;
     break;
    }
    $22 = (($19) + 8)|0;
    $$0 = $22;
    label = 13;
    break;
   }
  } else {
   __THREW__ = 0;
   $3 = (invoke_iii(1146,0,($1|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    label = 4;
   } else {
    $6 = (($3) + 24)|0;
    $$0 = $6;
    label = 13;
   }
  }
 } while(0);
 if ((label|0) == 4) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 else if ((label|0) == 13) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z44mscorlib_System_NumberFormatter_m_ScaleOrderP22mscorlib_System_Objectx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$03 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625392);
 $V_0$03 = 18;
 while(1) {
  __THREW__ = 0;
  $6 = (invoke_iii(1142,0,($V_0$03|0))|0);
  $3 = tempRet0;
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   label = 3;
   break;
  }
  $2 = ($3|0)>($1|0);
  $4 = ($3|0)==($1|0);
  $5 = ($6>>>0)>($0>>>0);
  $7 = $4 & $5;
  $8 = $2 | $7;
  if (!($8)) {
   label = 4;
   break;
  }
  $12 = (($V_0$03) + -1)|0;
  $13 = ($V_0$03|0)>(0);
  if ($13) {
   $V_0$03 = $12;
  } else {
   $$0 = 1;
   label = 7;
   break;
  }
 }
 if ((label|0) == 3) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 else if ((label|0) == 4) {
  $11 = (($V_0$03) + 1)|0;
  $$0 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 7) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z58mscorlib_System_NumberFormatter_m_InitialFloatingPrecisionP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625440);
 $0 = (($__this) + 22|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(82);
 do {
  if ($2) {
   $3 = (($__this) + 28|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = (($4) + 2)|0;
   $$0 = $5;
  } else {
   $6 = (($__this) + 24|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($__this) + 28|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($7|0)<($9|0);
   if ($10) {
    $$0 = $9;
   } else {
    if ((($1<<16>>16) == 71)) {
     $11 = (($9) + 2)|0;
     __THREW__ = 0;
     $12 = (invoke_iiii(1198,0,($11|0),($7|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $$0 = $12;
      break;
     }
     $15 = ___cxa_find_matching_catch()|0;
     $16 = tempRet0;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($15|0);
     // unreachable;
    } else if ((($1<<16>>16) == 69)) {
     $17 = (($9) + 2)|0;
     $18 = (($7) + 1)|0;
     __THREW__ = 0;
     $19 = (invoke_iiii(1198,0,($17|0),($18|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $$0 = $19;
      break;
     }
     $15 = ___cxa_find_matching_catch()|0;
     $16 = tempRet0;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($15|0);
     // unreachable;
    } else {
     $$0 = $9;
     break;
    }
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z48mscorlib_System_NumberFormatter_m_ParsePrecisionP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625488);
 $V_0$0 = 0;$V_1$0 = 1;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($format|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if ($14) {
   label = 4;
   break;
  }
  __THREW__ = 0;
  $15 = (invoke_ii(1816,($format|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   label = 4;
   break;
  }
  $18 = ($V_1$0|0)<($15|0);
  if (!($18)) {
   $$0 = $V_0$0;
   label = 9;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($format|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   label = 4;
   break;
  }
  __THREW__ = 0;
  $0 = (invoke_iii(621,($format|0),($V_1$0|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if ($2) {
   label = 4;
   break;
  }
  $3 = $0&65535;
  $4 = (($3) + 65488)|0;
  $5 = $4 & 65535;
  $6 = ($V_0$0*10)|0;
  $7 = (($5) + ($6))|0;
  $8 = ($5>>>0)<(10);
  $9 = ($7|0)<(100);
  $or$cond = $8 & $9;
  $10 = (($V_1$0) + 1)|0;
  if ($or$cond) {
   $V_0$0 = $7;$V_1$0 = $10;
  } else {
   $$0 = -2;
   label = 9;
   break;
  }
 }
 if ((label|0) == 4) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 }
 else if ((label|0) == 9) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z82mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_StringP31mscorlib_System_NumberFormatterP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $$off = 0, $$off2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625536);
 $0 = (($__this) + 44|0);
 $1 = (($__this) + 36|0);
 HEAP32[$1>>2] = 0;
 $2 = (($__this) + 17|0);
 HEAP8[$2>>0] = 0;
 $3 = (($__this) + 16|0);
 HEAP8[$3>>0] = 0;
 $4 = (($__this) + 18|0);
 HEAP8[$4>>0] = 0;
 $5 = (($__this) + 19|0);
 ;HEAP32[$0+0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 HEAP8[$5>>0] = 1;
 $6 = (($__this) + 24|0);
 HEAP32[$6>>2] = -1;
 $7 = ($format|0)==(0|0);
 do {
  if (!($7)) {
   __THREW__ = 0;
   invoke_vi(3799,($format|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(1816,($format|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = ($10|0)==(0);
     if ($13) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($format|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      __THREW__ = 0;
      $19 = (invoke_iii(621,($format|0),0)|0);
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $$off = (($19) + -97)<<16>>16;
       $22 = ($$off&65535)>(25);
       if ($22) {
        $$off2 = (($19) + -65)<<16>>16;
        $26 = ($$off2&65535)<(26);
        if ($26) {
         $V_0$0 = $19;
        } else {
         HEAP8[$4>>0] = 1;
         $27 = (($__this) + 22|0);
         HEAP16[$27>>1] = 48;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       } else {
        $23 = $19&65535;
        $24 = (($23) + 65504)|0;
        $25 = $24&65535;
        HEAP8[$5>>0] = 0;
        $V_0$0 = $25;
       }
       $28 = (($__this) + 22|0);
       HEAP16[$28>>1] = $V_0$0;
       __THREW__ = 0;
       invoke_vi(3799,($format|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        $31 = (invoke_ii(1816,($format|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if (!($33)) {
         $34 = ($31|0)<(2);
         if ($34) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         __THREW__ = 0;
         $35 = (invoke_iii(1147,0,($format|0))|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if (!($37)) {
          HEAP32[$6>>2] = $35;
          $38 = ($35|0)==(-2);
          if (!($38)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          HEAP8[$4>>0] = 1;
          HEAP16[$28>>1] = 48;
          HEAP32[$6>>2] = -1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
   $14 = ___cxa_find_matching_catch()|0;
   $15 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($14|0);
   // unreachable;
  }
 } while(0);
 $16 = (($__this) + 22|0);
 HEAP16[$16>>1] = 71;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z41mscorlib_System_NumberFormatter_m_InitHexP31mscorlib_System_NumberFormattery($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625584);
 $2 = (($__this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 if ((($3|0) == 3)) {
  $7 = $0 & 255;
  $10 = $7;$12 = 0;
 } else if ((($3|0) == 5)) {
  $8 = $0 & 65535;
  $10 = $8;$12 = 0;
 } else {
  $4 = ($3|0)==(10);
  $5 = $4 ? $0 : $0;
  $6 = $4 ? 0 : $1;
  $10 = $5;$12 = $6;
 }
 $9 = (($__this) + 44|0);
 HEAP32[$9>>2] = $10;
 $11 = (($__this) + 48|0);
 HEAP32[$11>>2] = $12;
 __THREW__ = 0;
 $13 = (invoke_ii(2478,($__this|0))|0);
 $14 = __THREW__; __THREW__ = 0;
 $15 = $14&1;
 if ($15) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($21|0);
  // unreachable;
 } else {
  $16 = (($__this) + 32|0);
  HEAP32[$16>>2] = $13;
  $17 = (($__this) + 40|0);
  $18 = ($10|0)==(0);
  $19 = ($12|0)==(0);
  $20 = $18 & $19;
  $$ = $20 ? 1 : $13;
  HEAP32[$17>>2] = $$;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z126mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringii($__this,$format,$value,$defPrecision) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $defPrecision = $defPrecision|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $value$ = 0, $value$lobit = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625632);
 __THREW__ = 0;
 invoke_vii(1958,($__this|0),($format|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 28|0);
   HEAP32[$2>>2] = $defPrecision;
   $3 = (($__this) + 20|0);
   $value$lobit = $value >>> 31;
   $4 = $value$lobit&255;
   $$not = $4 ^ 1;
   HEAP8[$3>>0] = $$not;
   $5 = ($value|0)==(0);
   if (!($5)) {
    $8 = (($__this) + 22|0);
    $9 = HEAP16[$8>>1]|0;
    $10 = ($9<<16>>16)==(88);
    if (!($10)) {
     $15 = ($value|0)>(-1);
     $16 = (0 - ($value))|0;
     $value$ = $15 ? $value : $16;
     __THREW__ = 0;
     invoke_vii(1957,($__this|0),($value$|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     $19 = (invoke_ii(2478,($__this|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     $22 = (($__this) + 32|0);
     HEAP32[$22>>2] = $19;
     $23 = (($__this) + 40|0);
     HEAP32[$23>>2] = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   $11 = ($value|0)<(0);
   $12 = $11 << 31 >> 31;
   __THREW__ = 0;
   invoke_viii(687,($__this|0),($value|0),($12|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z127mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_UInt32_mscorlib_System_Int32P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringji($__this,$format,$value,$defPrecision) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $defPrecision = $defPrecision|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625680);
 __THREW__ = 0;
 invoke_vii(1958,($__this|0),($format|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 28|0);
   HEAP32[$2>>2] = $defPrecision;
   $3 = (($__this) + 20|0);
   HEAP8[$3>>0] = 1;
   $4 = ($value|0)==(0);
   if (!($4)) {
    $7 = (($__this) + 22|0);
    $8 = HEAP16[$7>>1]|0;
    $9 = ($8<<16>>16)==(88);
    if (!($9)) {
     __THREW__ = 0;
     invoke_vii(1957,($__this|0),($value|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     $14 = (invoke_ii(2478,($__this|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     $17 = (($__this) + 32|0);
     HEAP32[$17>>2] = $14;
     $18 = (($__this) + 40|0);
     HEAP32[$18>>2] = $14;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   invoke_viii(687,($__this|0),($value|0),0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z104mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int64P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringx($__this,$format,$0,$1) {
 $__this = $__this|0;
 $format = $format|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$not = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625728);
 __THREW__ = 0;
 invoke_vii(1958,($__this|0),($format|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 28|0);
   HEAP32[$4>>2] = 19;
   $5 = (($__this) + 20|0);
   $6 = (_bitshift64Lshr(($0|0),($1|0),63)|0);
   $7 = tempRet0;
   $8 = $6&255;
   $$not = $8 ^ 1;
   HEAP8[$5>>0] = $$not;
   $9 = ($0|0)==(0);
   $10 = ($1|0)==(0);
   $11 = $9 & $10;
   if (!($11)) {
    $14 = (($__this) + 22|0);
    $15 = HEAP16[$14>>1]|0;
    $16 = ($15<<16>>16)==(88);
    if (!($16)) {
     $19 = ($1|0)>(-1);
     $20 = ($1|0)==(-1);
     $21 = ($0>>>0)>(4294967295);
     $22 = $20 & $21;
     $23 = $19 | $22;
     $24 = (_i64Subtract(0,0,($0|0),($1|0))|0);
     $25 = tempRet0;
     $26 = $23 ? $0 : $24;
     $27 = $23 ? $1 : $25;
     __THREW__ = 0;
     invoke_viii(686,($__this|0),($26|0),($27|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     $30 = (invoke_ii(2478,($__this|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     $33 = (($__this) + 32|0);
     HEAP32[$33>>2] = $30;
     $34 = (($__this) + 40|0);
     HEAP32[$34>>2] = $30;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   invoke_viii(687,($__this|0),($0|0),($1|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z105mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_UInt64P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringy($__this,$format,$0,$1) {
 $__this = $__this|0;
 $format = $format|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625776);
 __THREW__ = 0;
 invoke_vii(1958,($__this|0),($format|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = (($__this) + 28|0);
   HEAP32[$4>>2] = 20;
   $5 = (($__this) + 20|0);
   HEAP8[$5>>0] = 1;
   $6 = ($0|0)==(0);
   $7 = ($1|0)==(0);
   $8 = $6 & $7;
   if (!($8)) {
    $11 = (($__this) + 22|0);
    $12 = HEAP16[$11>>1]|0;
    $13 = ($12<<16>>16)==(88);
    if (!($13)) {
     __THREW__ = 0;
     invoke_viii(686,($__this|0),($0|0),($1|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     $18 = (invoke_ii(2478,($__this|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     $21 = (($__this) + 32|0);
     HEAP32[$21>>2] = $18;
     $22 = (($__this) + 40|0);
     HEAP32[$22>>2] = $18;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
   __THREW__ = 0;
   invoke_viii(687,($__this|0),($0|0),($1|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z127mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Double_mscorlib_System_Int32P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringdi($__this,$format,$value,$defPrecision) {
 $__this = $__this|0;
 $format = $format|0;
 $value = +$value;
 $defPrecision = $defPrecision|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_11$0 = 0, $V_11$1 = 0, $V_3$0 = 0, $V_3$1$lcssa = 0, $V_3$111 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625824);
 __THREW__ = 0;
 invoke_vii(1958,($__this|0),($format|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 28|0);
   HEAP32[$2>>2] = $defPrecision;
   __THREW__ = 0;
   $3 = (invoke_iid(7,0,(+$value))|0);
   $4 = tempRet0;
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 20|0);
    $8 = (_bitshift64Lshr(($3|0),($4|0),63)|0);
    $9 = tempRet0;
    $10 = $8&255;
    $$not = $10 ^ 1;
    HEAP8[$7>>0] = $$not;
    $11 = $4 & 2147483647;
    $12 = ($3|0)==(0);
    $13 = ($11|0)==(0);
    $14 = $12 & $13;
    if ($14) {
     $17 = (($__this) + 40|0);
     HEAP32[$17>>2] = 1;
     $18 = (($__this) + 32|0);
     HEAP32[$18>>2] = 0;
     HEAP8[$7>>0] = 1;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $19 = (_bitshift64Lshr(($3|0),($11|0),52)|0);
    $20 = tempRet0;
    $21 = $4 & 1048575;
    if ((($19|0) == 0)) {
     __THREW__ = 0;
     $29 = (invoke_iiii(1214,0,($3|0),($21|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     $32 = ($29|0)>(14);
     if ($32) {
      $65 = $21;$68 = $3;$V_1$0 = 1;$V_3$0 = 0;
     } else {
      $33 = (15 - ($29))|0;
      __THREW__ = 0;
      $34 = (invoke_iii(1142,0,($33|0))|0);
      $35 = tempRet0;
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = (($29) + -15)|0;
      $39 = (___muldi3(($34|0),($35|0),($3|0),($21|0))|0);
      $40 = tempRet0;
      $65 = $40;$68 = $39;$V_1$0 = 1;$V_3$0 = $38;
     }
    } else if ((($19|0) == 2047)) {
     $22 = ($3|0)==(0);
     $23 = ($21|0)==(0);
     $24 = $22 & $23;
     $25 = (($__this) + 16|0);
     $26 = $24&1;
     $27 = $26 ^ 1;
     HEAP8[$25>>0] = $27;
     $28 = (($__this) + 17|0);
     HEAP8[$28>>0] = $26;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    } else {
     $41 = $21 | 1048576;
     $42 = (___muldi3(($3|0),($41|0),10,0)|0);
     $43 = tempRet0;
     $65 = $43;$68 = $42;$V_1$0 = $19;$V_3$0 = -1;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if (!($45)) {
     $46 = HEAP8[((2633856 + 116|0))>>0]|0;
     $47 = ($46<<24>>24)==(0);
     if ($47) {
      __THREW__ = 0;
      (invoke_ii(2996,(2633856|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2633856|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3839,(2633856|0));
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if (!($55)) {
      $56 = HEAP32[((2633856 + 80|0))>>2]|0;
      $57 = HEAP32[$56>>2]|0;
      $58 = (($57) + ($V_1$0<<3)|0);
      $59 = $58;
      $60 = $59;
      $61 = HEAP32[$60>>2]|0;
      $62 = (($59) + 4)|0;
      $63 = $62;
      $64 = HEAP32[$63>>2]|0;
      $66 = (___muldi3(($61|0),0,($65|0),0)|0);
      $67 = tempRet0;
      $69 = (___muldi3(($64|0),0,($68|0),0)|0);
      $70 = tempRet0;
      $71 = (_i64Add(($66|0),($67|0),($69|0),($70|0))|0);
      $72 = tempRet0;
      (___muldi3(($61|0),0,($68|0),0)|0);
      $73 = tempRet0;
      $74 = (_i64Add(($71|0),($72|0),($73|0),0)|0);
      $75 = tempRet0;
      $76 = (___muldi3(($64|0),0,($65|0),0)|0);
      $77 = tempRet0;
      $78 = (_i64Add(($75|0),0,($76|0),($77|0))|0);
      $79 = tempRet0;
      $80 = ($79|0)<(2328306);
      $81 = ($79|0)==(2328306);
      $82 = ($78>>>0)<(1874919424);
      $83 = $81 & $82;
      $84 = $80 | $83;
      if ($84) {
       $170 = $75;$85 = $74;$88 = $78;$89 = $79;$V_3$111 = $V_3$0;
       while(1) {
        $86 = (___muldi3(($85|0),0,10,0)|0);
        $87 = tempRet0;
        $90 = (___muldi3(($88|0),($89|0),10,0)|0);
        $91 = tempRet0;
        $92 = (_i64Add(($87|0),0,($90|0),($91|0))|0);
        $93 = tempRet0;
        $94 = (($V_3$111) + -1)|0;
        $95 = ($93|0)<(2328306);
        $96 = ($93|0)==(2328306);
        $97 = ($92>>>0)<(1874919424);
        $98 = $96 & $97;
        $99 = $95 | $98;
        if ($99) {
         $170 = $87;$85 = $86;$88 = $92;$89 = $93;$V_3$111 = $94;
        } else {
         $100 = $86;$101 = $87;$105 = $92;$106 = $93;$V_3$1$lcssa = $94;
         break;
        }
       }
      } else {
       $100 = $74;$101 = $75;$105 = $78;$106 = $79;$V_3$1$lcssa = $V_3$0;
      }
      $102 = (_bitshift64Lshr(($100|0),($101|0),31)|0);
      $103 = tempRet0;
      $104 = $102 & 1;
      $107 = (_i64Add(($104|0),0,($105|0),($106|0))|0);
      $108 = tempRet0;
      __THREW__ = 0;
      (invoke_ii(2996,(2633856|0))|0);
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if (!($110)) {
       $111 = HEAP8[((2633856 + 116|0))>>0]|0;
       $112 = ($111<<24>>24)==(0);
       if ($112) {
        __THREW__ = 0;
        (invoke_ii(2996,(2633856|0))|0);
        $113 = __THREW__; __THREW__ = 0;
        $114 = $113&1;
        if ($114) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2633856|0))|0);
        $115 = __THREW__; __THREW__ = 0;
        $116 = $115&1;
        if ($116) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2633856|0));
        $117 = __THREW__; __THREW__ = 0;
        $118 = $117&1;
        if ($118) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2633856|0))|0);
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if (!($120)) {
        $121 = HEAP32[((2633856 + 80|0))>>2]|0;
        $122 = (($121) + 4|0);
        $123 = HEAP32[$122>>2]|0;
        $124 = (($123) + ($V_1$0<<2)|0);
        $125 = HEAP32[$124>>2]|0;
        $126 = (($V_3$1$lcssa) + 17)|0;
        $127 = (($126) + ($125))|0;
        $128 = (($__this) + 40|0);
        HEAP32[$128>>2] = $127;
        __THREW__ = 0;
        $129 = (invoke_ii(2479,($__this|0))|0);
        $130 = __THREW__; __THREW__ = 0;
        $131 = $130&1;
        if (!($131)) {
         $132 = ($129|0)>(16);
         if ($132) {
          $149 = $108;$152 = $107;$V_11$0 = 17;
         } else {
          $133 = (17 - ($129))|0;
          __THREW__ = 0;
          $134 = (invoke_iii(1142,0,($133|0))|0);
          $135 = tempRet0;
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           break;
          }
          $138 = (_bitshift64Ashr(($134|0),($135|0),1)|0);
          $139 = tempRet0;
          $140 = (_i64Add(($138|0),($139|0),($107|0),($108|0))|0);
          $141 = tempRet0;
          $142 = (___divdi3(($140|0),($141|0),($134|0),($135|0))|0);
          $143 = tempRet0;
          $149 = $143;$152 = $142;$V_11$0 = $129;
         }
         __THREW__ = 0;
         $144 = (invoke_iii(1142,0,($V_11$0|0))|0);
         $145 = tempRet0;
         $146 = __THREW__; __THREW__ = 0;
         $147 = $146&1;
         if (!($147)) {
          $148 = ($149|0)<($145|0);
          $150 = ($149|0)==($145|0);
          $151 = ($152>>>0)<($144>>>0);
          $153 = $150 & $151;
          $154 = $148 | $153;
          if ($154) {
           $V_11$1 = $V_11$0;
          } else {
           $155 = (($V_11$0) + 1)|0;
           __THREW__ = 0;
           invoke_vi(3799,($__this|0));
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            break;
           }
           $158 = HEAP32[$128>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($__this|0));
           $159 = __THREW__; __THREW__ = 0;
           $160 = $159&1;
           if ($160) {
            break;
           }
           $161 = (($158) + 1)|0;
           HEAP32[$128>>2] = $161;
           $V_11$1 = $155;
          }
          __THREW__ = 0;
          invoke_viii(686,($__this|0),($152|0),($149|0));
          $162 = __THREW__; __THREW__ = 0;
          $163 = $162&1;
          if (!($163)) {
           __THREW__ = 0;
           $164 = (invoke_ii(2485,($__this|0))|0);
           $165 = __THREW__; __THREW__ = 0;
           $166 = $165&1;
           if (!($166)) {
            $167 = (($__this) + 36|0);
            HEAP32[$167>>2] = $164;
            $168 = (($V_11$1) - ($164))|0;
            $169 = (($__this) + 32|0);
            HEAP32[$169>>2] = $168;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z74mscorlib_System_NumberFormatter_m_CountTrailingZeros_mscorlib_System_Int32P31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626784);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   $8 = (($__this) + 48|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==(0);
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_iii(1152,0,($9|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     label = 3;
     break;
    }
    $14 = (($11) + 8)|0;
    $$0 = $14;
    label = 14;
    break;
   }
   $15 = (($__this) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(0);
   if (!($17)) {
    __THREW__ = 0;
    $18 = (invoke_iii(1152,0,($16|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     label = 3;
     break;
    }
    $21 = (($18) + 16)|0;
    $$0 = $21;
    label = 14;
    break;
   }
   $22 = (($__this) + 56|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0);
   if ($24) {
    $29 = (($__this) + 32|0);
    $30 = HEAP32[$29>>2]|0;
    $$0 = $30;
    label = 14;
    break;
   }
   __THREW__ = 0;
   $25 = (invoke_iii(1152,0,($23|0))|0);
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if ($27) {
    label = 3;
   } else {
    $28 = (($25) + 24)|0;
    $$0 = $28;
    label = 14;
   }
  } else {
   __THREW__ = 0;
   $3 = (invoke_iii(1152,0,($1|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    label = 3;
   } else {
    $$0 = $3;
    label = 14;
   }
  }
 } while(0);
 if ((label|0) == 3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z106mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_DecimalP31mscorlib_System_NumberFormatterP22mscorlib_System_String23mscorlib_System_Decimal($__this,$format,$value) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 var $$lobit = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625872);
 __THREW__ = 0;
 invoke_vii(1958,($__this|0),($format|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 28|0);
   HEAP32[$2>>2] = 100;
   __THREW__ = 0;
   ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
   $3 = (invoke_iii(681,(0|0),($value$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = (($3) + 12|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = ($9>>>0)<(4);
     if ($10) {
      __THREW__ = 0;
      $11 = (invoke_i(132)|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($11|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
     $18 = HEAP32[$3>>2]|0;
     $19 = (($3) + 16|0);
     $20 = (($18) + 92|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21*3)|0;
     $23 = (($19) + ($22)|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = $24 >>> 16;
     $26 = $25 & 31;
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[$8>>2]|0;
      $30 = ($29>>>0)<(4);
      if ($30) {
       __THREW__ = 0;
       $31 = (invoke_i(132)|0);
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($31|0));
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
      }
      $36 = HEAP32[$3>>2]|0;
      $37 = (($36) + 92|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($38*3)|0;
      $40 = (($19) + ($39)|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = (($__this) + 20|0);
      $$lobit = $41 >>> 31;
      $43 = $$lobit&255;
      $$not = $43 ^ 1;
      HEAP8[$42>>0] = $$not;
      __THREW__ = 0;
      invoke_vi(3799,($3|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       $46 = HEAP32[$8>>2]|0;
       $47 = ($46|0)==(0);
       if ($47) {
        __THREW__ = 0;
        $48 = (invoke_i(132)|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($48|0));
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
       }
       $53 = HEAP32[$19>>2]|0;
       $54 = ($53|0)==(0);
       if ($54) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
        $57 = HEAP32[$8>>2]|0;
        $58 = ($57>>>0)<(2);
        if ($58) {
         __THREW__ = 0;
         $59 = (invoke_i(132)|0);
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($59|0));
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if ($63) {
          break;
         }
        }
        $64 = HEAP32[$3>>2]|0;
        $65 = (($64) + 92|0);
        $66 = HEAP32[$65>>2]|0;
        $67 = (($19) + ($66)|0);
        $68 = HEAP32[$67>>2]|0;
        $69 = ($68|0)==(0);
        if ($69) {
         __THREW__ = 0;
         invoke_vi(3799,($3|0));
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          break;
         }
         $72 = HEAP32[$8>>2]|0;
         $73 = ($72>>>0)<(3);
         if ($73) {
          __THREW__ = 0;
          $74 = (invoke_i(132)|0);
          $75 = __THREW__; __THREW__ = 0;
          $76 = $75&1;
          if ($76) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($74|0));
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           break;
          }
         }
         $79 = HEAP32[$3>>2]|0;
         $80 = (($79) + 92|0);
         $81 = HEAP32[$80>>2]|0;
         $82 = $81 << 1;
         $83 = (($19) + ($82)|0);
         $84 = HEAP32[$83>>2]|0;
         $85 = ($84|0)==(0);
         if ($85) {
          $86 = (0 - ($26))|0;
          $87 = (($__this) + 40|0);
          HEAP32[$87>>2] = $86;
          HEAP8[$42>>0] = 1;
          $88 = (($__this) + 32|0);
          HEAP32[$88>>2] = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
       __THREW__ = 0;
       invoke_vi(3799,($3|0));
       $89 = __THREW__; __THREW__ = 0;
       $90 = $89&1;
       if (!($90)) {
        $91 = HEAP32[$8>>2]|0;
        $92 = ($91>>>0)<(3);
        if ($92) {
         __THREW__ = 0;
         $93 = (invoke_i(132)|0);
         $94 = __THREW__; __THREW__ = 0;
         $95 = $94&1;
         if ($95) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($93|0));
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          break;
         }
        }
        $98 = HEAP32[$3>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = $100 << 1;
        $102 = (($19) + ($101)|0);
        $103 = HEAP32[$102>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if (!($105)) {
         $106 = HEAP32[$8>>2]|0;
         $107 = ($106>>>0)<(2);
         if ($107) {
          __THREW__ = 0;
          $108 = (invoke_i(132)|0);
          $109 = __THREW__; __THREW__ = 0;
          $110 = $109&1;
          if ($110) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($108|0));
          $111 = __THREW__; __THREW__ = 0;
          $112 = $111&1;
          if ($112) {
           break;
          }
         }
         $113 = HEAP32[$3>>2]|0;
         $114 = (($113) + 92|0);
         $115 = HEAP32[$114>>2]|0;
         $116 = (($19) + ($115)|0);
         $117 = HEAP32[$116>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($3|0));
         $118 = __THREW__; __THREW__ = 0;
         $119 = $118&1;
         if (!($119)) {
          $120 = HEAP32[$8>>2]|0;
          $121 = ($120|0)==(0);
          if ($121) {
           __THREW__ = 0;
           $122 = (invoke_i(132)|0);
           $123 = __THREW__; __THREW__ = 0;
           $124 = $123&1;
           if ($124) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($122|0));
           $125 = __THREW__; __THREW__ = 0;
           $126 = $125&1;
           if ($126) {
            break;
           }
          }
          $127 = HEAP32[$19>>2]|0;
          __THREW__ = 0;
          invoke_viiii(195,($__this|0),($103|0),($127|0),($117|0));
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if (!($129)) {
           __THREW__ = 0;
           $130 = (invoke_ii(2478,($__this|0))|0);
           $131 = __THREW__; __THREW__ = 0;
           $132 = $131&1;
           if (!($132)) {
            $133 = (($__this) + 32|0);
            HEAP32[$133>>2] = $130;
            $134 = (($130) - ($26))|0;
            $135 = (($__this) + 40|0);
            HEAP32[$135>>2] = $134;
            $136 = (($__this) + 24|0);
            $137 = HEAP32[$136>>2]|0;
            $138 = ($137|0)==(-1);
            do {
             if ($138) {
              $139 = (($__this) + 22|0);
              $140 = HEAP16[$139>>1]|0;
              $141 = ($140<<16>>16)==(71);
              if (!($141)) {
               break;
              }
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            } while(0);
            __THREW__ = 0;
            $142 = (invoke_ii(2485,($__this|0))|0);
            $143 = __THREW__; __THREW__ = 0;
            $144 = $143&1;
            if (!($144)) {
             $145 = (($__this) + 36|0);
             HEAP32[$145>>2] = $142;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $146 = __THREW__; __THREW__ = 0;
             $147 = $146&1;
             if ($147) {
              break;
             }
             $148 = HEAP32[$133>>2]|0;
             $149 = HEAP32[$145>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($__this|0));
             $150 = __THREW__; __THREW__ = 0;
             $151 = $150&1;
             if ($151) {
              break;
             }
             $152 = (($148) - ($149))|0;
             HEAP32[$133>>2] = $152;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z46mscorlib_System_NumberFormatter_m_ResetCharBufP31mscorlib_System_NumberFormatteri($__this,$size) {
 $__this = $__this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625920);
 $0 = (($__this) + 64|0);
 HEAP32[$0>>2] = 0;
 $1 = (($__this) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($2|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($2) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)<($size|0);
  if (!($7)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(1168808|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_iii(2768,(1168808|0),($size|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    HEAP32[$1>>2] = $12;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z40mscorlib_System_NumberFormatter_m_ResizeP31mscorlib_System_NumberFormatteri($__this,$len) {
 $__this = $__this|0;
 $len = $len|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2625968);
 __THREW__ = 0;
 (invoke_ii(2996,(1168808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2768,(1168808|0),($len|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 60|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = (($__this) + 64|0);
   $8 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   invoke_viiii(140,(0|0),($6|0),($2|0),($8|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    HEAP32[$5>>2] = $2;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z82mscorlib_System_NumberFormatter_m_Append_mscorlib_System_Void_mscorlib_System_CharP31mscorlib_System_NumberFormattert($__this,$c) {
 $__this = $__this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626016);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($3) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($1|0)==($7|0);
   if ($8) {
    $11 = HEAP32[$0>>2]|0;
    $12 = (($11) + 10)|0;
    __THREW__ = 0;
    invoke_vii(1960,($__this|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
   }
   $15 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     $21 = (($18) + 1)|0;
     HEAP32[$0>>2] = $21;
     __THREW__ = 0;
     invoke_vi(3799,($15|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($18|0)<(0);
      if (!($24)) {
       $25 = (($15) + 12|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = ($18>>>0)<($26>>>0);
       if ($27) {
        $33 = HEAP32[$15>>2]|0;
        $34 = (($15) + 16|0);
        $35 = (($33) + 92|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = Math_imul($36, $18)|0;
        $38 = (($34) + ($37)|0);
        HEAP16[$38>>1] = $c;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
      __THREW__ = 0;
      $28 = (invoke_i(132)|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       __THREW__ = 0;
       invoke_vi(3302,($28|0));
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if (!($32)) {
        $33 = HEAP32[$15>>2]|0;
        $34 = (($15) + 16|0);
        $35 = (($33) + 92|0);
        $36 = HEAP32[$35>>2]|0;
        $37 = Math_imul($36, $18)|0;
        $38 = (($34) + ($37)|0);
        HEAP16[$38>>1] = $c;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z104mscorlib_System_NumberFormatter_m_Append_mscorlib_System_Void_mscorlib_System_Char_mscorlib_System_Int32P31mscorlib_System_NumberFormatterti($__this,$c,$cnt) {
 $__this = $__this|0;
 $c = $c|0;
 $cnt = $cnt|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626064);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($1) + ($cnt))|0;
   $7 = (($3) + 12|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($6|0)>($8|0);
   if ($9) {
    $14 = HEAP32[$0>>2]|0;
    $15 = (($cnt) + 10)|0;
    $16 = (($15) + ($14))|0;
    __THREW__ = 0;
    invoke_vii(1960,($__this|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
   }
   $19 = ($cnt|0)>(0);
   if (!($19)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $$in = $cnt;
   while(1) {
    $43 = (($$in) + -1)|0;
    $24 = HEAP32[$2>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    $20 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (($20) + 1)|0;
    HEAP32[$0>>2] = $23;
    __THREW__ = 0;
    invoke_vi(3799,($24|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = ($20|0)<(0);
    if ($27) {
     label = 13;
    } else {
     $28 = (($24) + 12|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($20>>>0)<($29>>>0);
     if (!($30)) {
      label = 13;
     }
    }
    if ((label|0) == 13) {
     label = 0;
     __THREW__ = 0;
     $31 = (invoke_i(132)|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($31|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
    }
    $36 = HEAP32[$24>>2]|0;
    $37 = (($24) + 16|0);
    $38 = (($36) + 92|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = Math_imul($39, $20)|0;
    $41 = (($37) + ($40)|0);
    HEAP16[$41>>1] = $c;
    $42 = ($43|0)>(0);
    if ($42) {
     $$in = $43;
    } else {
     label = 17;
     break;
    }
   }
   if ((label|0) == 17) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   $lpad$phi$index = $10;$lpad$phi$index2 = $11;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z84mscorlib_System_NumberFormatter_m_Append_mscorlib_System_Void_mscorlib_System_StringP31mscorlib_System_NumberFormatterP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626112);
 __THREW__ = 0;
 invoke_vi(3799,($s|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1816,($s|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = (($__this) + 64|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (($__this) + 60|0);
    $8 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($6) + ($2))|0;
     $12 = (($8) + 12|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($11|0)>($13|0);
     if ($14) {
      $19 = HEAP32[$5>>2]|0;
      $20 = (($2) + 10)|0;
      $21 = (($20) + ($19))|0;
      __THREW__ = 0;
      invoke_vii(1960,($__this|0),($21|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
     }
     $24 = ($2|0)>(0);
     if (!($24)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $V_1$01 = 0;
     while(1) {
      $34 = HEAP32[$7>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      $25 = HEAP32[$5>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      $28 = (($25) + 1)|0;
      HEAP32[$5>>2] = $28;
      __THREW__ = 0;
      invoke_vi(3799,($s|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      $31 = (invoke_iii(621,($s|0),($V_1$01|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($34|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = ($25|0)<(0);
      if ($37) {
       label = 17;
      } else {
       $38 = (($34) + 12|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = ($25>>>0)<($39>>>0);
       if (!($40)) {
        label = 17;
       }
      }
      if ((label|0) == 17) {
       label = 0;
       __THREW__ = 0;
       $41 = (invoke_i(132)|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if ($43) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($41|0));
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        break;
       }
      }
      $46 = HEAP32[$34>>2]|0;
      $47 = (($34) + 16|0);
      $48 = (($46) + 92|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = Math_imul($49, $25)|0;
      $51 = (($47) + ($50)|0);
      HEAP16[$51>>1] = $31;
      $52 = (($V_1$01) + 1)|0;
      $53 = ($52|0)<($2|0);
      if ($53) {
       $V_1$01 = $52;
      } else {
       label = 21;
       break;
      }
     }
     if ((label|0) == 21) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $15 = ___cxa_find_matching_catch()|0;
     $16 = tempRet0;
     $lpad$phi$index = $15;$lpad$phi$index2 = $16;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 $lpad$phi$index = $17;$lpad$phi$index2 = $18;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z57mscorlib_System_NumberFormatter_m_GetNumberFormatInstanceP31mscorlib_System_NumberFormatterP22mscorlib_System_Object($__this,$fp) {
 $__this = $__this|0;
 $fp = $fp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626160);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0|0);
 $3 = ($fp|0)==(0|0);
 $or$cond = $2 & $3;
 if ($or$cond) {
  $$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $4 = (invoke_iii(867,(0|0),($fp|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  $$0 = $4;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_NumberFormatter_m_get_IntegerDigitsP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626256);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<(1);
 $$ = $2 ? 1 : $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$|0);
}
function __Z51mscorlib_System_NumberFormatter_m_get_DecimalDigitsP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626304);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)>($3|0);
 $5 = (($1) - ($3))|0;
 $G_B3_0$0 = $4 ? $5 : 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B3_0$0|0);
}
function __Z54mscorlib_System_NumberFormatter_m_get_IsFloatingSourceP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626352);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -9;
 $3 = ($2|0)==(7);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($3|0);
}
function __Z44mscorlib_System_NumberFormatter_m_get_IsZeroP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626400);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z51mscorlib_System_NumberFormatter_m_get_IsZeroIntegerP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626448);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $G_B3_0$0 = 1;
 } else {
  $3 = (($__this) + 40|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)<(1);
  $G_B3_0$0 = $5;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B3_0$0|0);
}
function __Z42mscorlib_System_NumberFormatter_m_RoundPosP31mscorlib_System_NumberFormatteri($__this,$pos) {
 $__this = $__this|0;
 $pos = $pos|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626496);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($pos))|0;
 __THREW__ = 0;
 (invoke_iii(1150,($__this|0),($2|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43mscorlib_System_NumberFormatter_m_RoundBitsP31mscorlib_System_NumberFormatteri($__this,$shift) {
 $__this = $__this|0;
 $shift = $shift|0;
 var $$0 = 0, $$01$lcssa = 0, $$013 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0$off0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626592);
 $0 = ($shift|0)>(0);
 if (!($0)) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($__this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)<($shift|0);
 if ($3) {
  HEAP32[$1>>2] = 0;
  $4 = (($__this) + 40|0);
  HEAP32[$4>>2] = 1;
  $5 = (($__this) + 44|0);
  $6 = (($__this) + 20|0);
  ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;HEAP32[$5+12>>2]=0|0;
  HEAP8[$6>>0] = 1;
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (($__this) + 36|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($shift))|0;
 __THREW__ = 0;
 invoke_vi(3799,($__this|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 do {
  if (!($11)) {
   $12 = HEAP32[$1>>2]|0;
   $13 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = (($13) + ($12))|0;
    HEAP32[$1>>2] = $16;
    $17 = ($9|0)>(8);
    L11: do {
     if ($17) {
      $18 = (($__this) + 48|0);
      $19 = (($__this) + 44|0);
      $20 = (($__this) + 52|0);
      $21 = (($__this) + 56|0);
      $$013 = $9;
      while(1) {
       $32 = HEAP32[$18>>2]|0;
       HEAP32[$19>>2] = $32;
       $33 = HEAP32[$20>>2]|0;
       HEAP32[$18>>2] = $33;
       $34 = HEAP32[$21>>2]|0;
       HEAP32[$20>>2] = $34;
       HEAP32[$21>>2] = 0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       $26 = HEAP32[$1>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       $29 = (($26) + -8)|0;
       HEAP32[$1>>2] = $29;
       $30 = (($$013) + -8)|0;
       $31 = ($30|0)>(8);
       if ($31) {
        $$013 = $30;
       } else {
        $$01$lcssa = $30;$$pre$phiZ2D = $19;
        break L11;
       }
      }
      $22 = ___cxa_find_matching_catch()|0;
      $23 = tempRet0;
      $lpad$phi$index = $22;$lpad$phi$index2 = $23;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     } else {
      $$pre = (($__this) + 44|0);
      $$01$lcssa = $9;$$pre$phiZ2D = $$pre;
     }
    } while(0);
    $37 = $$01$lcssa << 2;
    $38 = (($37) + 28)|0;
    $39 = HEAP32[$$pre$phiZ2D>>2]|0;
    $40 = $38 & 28;
    $41 = $39 >>> $40;
    $42 = $41 & 15;
    $43 = $42 ^ $41;
    $44 = $43 << $40;
    HEAP32[$$pre$phiZ2D>>2] = $44;
    $45 = ($42>>>0)<(5);
    if ($45) {
     $V_2$0$off0 = 0;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      break;
     }
     $48 = HEAP32[$$pre$phiZ2D>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break;
     }
     $51 = (0 - ($37))|0;
     $52 = $51 & 28;
     $53 = -1717986919 >>> $52;
     $54 = $48 | $53;
     HEAP32[$$pre$phiZ2D>>2] = $54;
     __THREW__ = 0;
     invoke_vi(2763,($__this|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     $57 = (invoke_ii(2478,($__this|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     $60 = HEAP32[$1>>2]|0;
     $61 = ($57|0)!=($60|0);
     $62 = (($__this) + 40|0);
     $63 = HEAP32[$62>>2]|0;
     $64 = (($57) - ($60))|0;
     $65 = (($64) + ($63))|0;
     HEAP32[$62>>2] = $65;
     HEAP32[$1>>2] = $57;
     $V_2$0$off0 = $61;
    }
    __THREW__ = 0;
    invoke_vi(2762,($__this|0));
    $66 = __THREW__; __THREW__ = 0;
    $67 = $66&1;
    if (!($67)) {
     $$0 = $V_2$0$off0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 $lpad$phi$index = $24;$lpad$phi$index2 = $25;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_NumberFormatter_m_RoundDecimalP31mscorlib_System_NumberFormatteri($__this,$decimals) {
 $__this = $__this|0;
 $decimals = $decimals|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626544);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($decimals))|0;
 $5 = (($4) - ($3))|0;
 __THREW__ = 0;
 $6 = (invoke_iii(1150,($__this|0),($5|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($6|0);
 }
 return 0|0;
}
function __Z69mscorlib_System_NumberFormatter_m_AddOneToDecHex_mscorlib_System_VoidP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626688);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1717986919);
 do {
  if ($2) {
   HEAP32[$0>>2] = 0;
   $3 = (($__this) + 48|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(-1717986919);
   if (!($5)) {
    __THREW__ = 0;
    $19 = (invoke_iii(1151,0,($4|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    HEAP32[$3>>2] = $19;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   HEAP32[$3>>2] = 0;
   $6 = (($__this) + 52|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(-1717986919);
   if ($8) {
    HEAP32[$6>>2] = 0;
    $9 = (($__this) + 56|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    $11 = (invoke_iii(1151,0,($10|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    HEAP32[$9>>2] = $11;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   } else {
    __THREW__ = 0;
    $16 = (invoke_iii(1151,0,($7|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    HEAP32[$6>>2] = $16;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  } else {
   __THREW__ = 0;
   $22 = (invoke_iii(1151,0,($1|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    HEAP32[$0>>2] = $22;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z53mscorlib_System_NumberFormatter_m_RemoveTrailingZerosP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626640);
 __THREW__ = 0;
 $0 = (invoke_ii(2485,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 36|0);
  HEAP32[$3>>2] = $0;
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($__this) + 32|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($7) - ($8))|0;
    HEAP32[$6>>2] = $11;
    $12 = ($7|0)==($8|0);
    if (!($12)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    HEAP32[$3>>2] = 0;
    $15 = (($__this) + 40|0);
    HEAP32[$15>>2] = 1;
    $16 = (($__this) + 20|0);
    HEAP8[$16>>0] = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z94mscorlib_System_NumberFormatter_m_AddOneToDecHex_mscorlib_System_UInt32_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626736);
 $0 = $val & 65535;
 $1 = ($0|0)==(39321);
 do {
  if ($1) {
   $2 = $val & 16777215;
   $3 = ($2|0)==(10066329);
   if ($3) {
    $4 = $val & 268435455;
    $5 = ($4|0)==(161061273);
    if ($5) {
     $6 = (($val) + 107374183)|0;
     $$0 = $6;
     break;
    } else {
     $7 = (($val) + 6710887)|0;
     $$0 = $7;
     break;
    }
   } else {
    $8 = $val & 1048575;
    $9 = ($8|0)==(629145);
    if ($9) {
     $10 = (($val) + 419431)|0;
     $$0 = $10;
     break;
    } else {
     $11 = (($val) + 26215)|0;
     $$0 = $11;
     break;
    }
   }
  } else {
   $12 = $val & 255;
   $13 = ($12|0)==(153);
   if ($13) {
    $14 = $val & 4095;
    $15 = ($14|0)==(2457);
    if ($15) {
     $16 = (($val) + 1639)|0;
     $$0 = $16;
     break;
    } else {
     $17 = (($val) + 103)|0;
     $$0 = $17;
     break;
    }
   } else {
    $18 = $val & 15;
    $19 = ($18|0)==(9);
    if ($19) {
     $20 = (($val) + 7)|0;
     $$0 = $20;
     break;
    } else {
     $21 = (($val) + 1)|0;
     $$0 = $21;
     break;
    }
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z97mscorlib_System_NumberFormatter_m_CountTrailingZeros_mscorlib_System_Int32_mscorlib_System_UInt32P22mscorlib_System_Objectj($__this,$val) {
 $__this = $__this|0;
 $val = $val|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $$2 = 0, $$3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626832);
 $0 = $val & 65535;
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   $2 = $val & 16777215;
   $3 = ($2|0)==(0);
   if ($3) {
    $4 = $val & 268435455;
    $5 = ($4|0)==(0);
    $$ = $5 ? 7 : 6;
    $$0 = $$;
    break;
   } else {
    $6 = $val & 1048575;
    $7 = ($6|0)==(0);
    $$1 = $7 ? 5 : 4;
    $$0 = $$1;
    break;
   }
  } else {
   $8 = $val & 255;
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = $val & 4095;
    $11 = ($10|0)==(0);
    $$2 = $11 ? 3 : 2;
    $$0 = $$2;
    break;
   } else {
    $12 = $val & 15;
    $13 = ($12|0)==(0);
    $$3 = $13&1;
    $$0 = $$3;
    break;
   }
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z45mscorlib_System_NumberFormatter_m_GetInstanceP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626880);
 __THREW__ = 0;
 (invoke_ii(2996,(2633856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2633856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2633856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2633856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2633856 + 104|0))>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_ii(3475,($14|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[$15>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = HEAP8[((2633856 + 116|0))>>0]|0;
      $22 = ($21<<24>>24)==(0);
      if ($22) {
       __THREW__ = 0;
       (invoke_ii(2996,(2633856|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2633856|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2633856|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2633856|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = HEAP32[((2633856 + 104|0))>>2]|0;
       __THREW__ = 0;
       $32 = (invoke_ii(3475,($31|0))|0);
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        HEAP32[$32>>2] = 0;
        $35 = ($18|0)==(0|0);
        if (!($35)) {
         $$0 = $18;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        __THREW__ = 0;
        $36 = (invoke_ii(2405,0)|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if (!($38)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2633856|0))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if (!($40)) {
          __THREW__ = 0;
          $41 = (invoke_ii(3469,(2633856|0))|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if (!($43)) {
           __THREW__ = 0;
           invoke_vii(1956,($41|0),($36|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if (!($45)) {
            $$0 = $41;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_NumberFormatter_m_ReleaseP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626928);
 __THREW__ = 0;
 (invoke_ii(2996,(2633856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2633856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3839,(2633856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2633856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2633856 + 104|0))>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_ii(3475,($14|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     HEAP32[$15>>2] = $__this;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z148mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_SByte_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringaS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2626976);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $value << 24 >> 24;
   __THREW__ = 0;
   invoke_viiii(196,($0|0),($format|0),($5|0),3);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(1239,($0|0),($format|0),($fp|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($0|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(2764,($0|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($10|0);
       }
      }
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_NumberFormatter_m_IntegerToStringP31mscorlib_System_NumberFormatterP22mscorlib_System_StringP22mscorlib_System_Object($__this,$format,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $fp = $fp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627840);
 __THREW__ = 0;
 invoke_v(910);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(1148,($__this|0),($fp|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = (($__this) + 22|0);
    $6 = HEAP16[$5>>1]|0;
    $7 = $6&65535;
    $8 = (($7) + 65469)|0;
    $9 = $8 & 65535;
    switch ($9|0) {
    case 11:  {
     $42 = (($__this) + 24|0);
     $43 = HEAP32[$42>>2]|0;
     __THREW__ = 0;
     $44 = (invoke_iiii(1245,($__this|0),($43|0),($2|0))|0);
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L1;
     } else {
      $$0 = $44;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 0:  {
     $13 = (($__this) + 24|0);
     $14 = HEAP32[$13>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iiii(1241,($__this|0),($14|0),($2|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break L1;
     } else {
      $$0 = $15;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 1:  {
     $18 = (($__this) + 24|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iiii(1242,($__this|0),($19|0),($2|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break L1;
     } else {
      $$0 = $20;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 13:  {
     $47 = (($__this) + 24|0);
     $48 = HEAP32[$47>>2]|0;
     __THREW__ = 0;
     $49 = (invoke_iiii(1246,($__this|0),($48|0),($2|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     } else {
      $$0 = $49;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 4:  {
     $33 = (($__this) + 24|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)>(0);
     if ($35) {
      __THREW__ = 0;
      $39 = (invoke_iiii(1244,($__this|0),($34|0),($2|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break L1;
      } else {
       $$0 = $39;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     } else {
      __THREW__ = 0;
      $36 = (invoke_iiii(1242,($__this|0),-1,($2|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break L1;
      } else {
       $$0 = $36;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     break;
    }
    case 2:  {
     $23 = (($__this) + 24|0);
     $24 = HEAP32[$23>>2]|0;
     __THREW__ = 0;
     $25 = (invoke_iiii(1247,($__this|0),($24|0),($2|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break L1;
     } else {
      $$0 = $25;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    case 3:  {
     $28 = (($__this) + 24|0);
     $29 = HEAP32[$28>>2]|0;
     __THREW__ = 0;
     $30 = (invoke_iiii(1243,($__this|0),($29|0),($2|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break L1;
     } else {
      $$0 = $30;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
     break;
    }
    default: {
     $12 = ($6<<16>>16)==(88);
     if ($12) {
      $52 = (($__this) + 24|0);
      $53 = HEAP32[$52>>2]|0;
      __THREW__ = 0;
      $54 = (invoke_iii(1153,($__this|0),($53|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       break L1;
      } else {
       $$0 = $54;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $57 = (($__this) + 18|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = ($58<<24>>24)==(0);
     if (!($59)) {
      __THREW__ = 0;
      $60 = (invoke_iiii(1248,($__this|0),($format|0),($2|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break L1;
      } else {
       $$0 = $60;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $63 = HEAP32[3074336>>2]|0;
     $64 = HEAP32[3074344>>2]|0;
     __THREW__ = 0;
     $65 = (invoke_iiiii(101,(0|0),($63|0),($format|0),($64|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2603176|0))|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break L1;
     }
     __THREW__ = 0;
     $70 = (invoke_ii(3469,(2603176|0))|0);
     $71 = __THREW__; __THREW__ = 0;
     $72 = $71&1;
     if ($72) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1940,($70|0),($65|0));
     $73 = __THREW__; __THREW__ = 0;
     $74 = $73&1;
     if ($74) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3838,($70|0));
     $75 = __THREW__; __THREW__ = 0;
     $76 = $75&1;
     if ($76) {
      break L1;
     }
     // unreachable;
    }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z147mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Byte_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringhS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627024);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $value&255;
   __THREW__ = 0;
   invoke_viiii(196,($0|0),($format|0),($5|0),3);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(1239,($0|0),($format|0),($fp|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($0|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(2764,($0|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($10|0);
       }
      }
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_UInt16_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringtS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627072);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $value&65535;
   __THREW__ = 0;
   invoke_viiii(196,($0|0),($format|0),($5|0),5);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(1239,($0|0),($format|0),($fp|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($0|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(2764,($0|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($10|0);
       }
      }
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z148mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int16_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringsS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627120);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = $value << 16 >> 16;
   __THREW__ = 0;
   invoke_viiii(196,($0|0),($format|0),($5|0),5);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iiii(1239,($0|0),($format|0),($fp|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($0|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(2764,($0|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($10|0);
       }
      }
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_UInt32_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringjS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627168);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viiii(197,($0|0),($format|0),($value|0),10);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_iiii(1239,($0|0),($format|0),($fp|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      invoke_vi(3799,($0|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       invoke_vi(2764,($0|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($9|0);
       }
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z148mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627216);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viiii(196,($0|0),($format|0),($value|0),10);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_iiii(1239,($0|0),($format|0),($fp|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      invoke_vi(3799,($0|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       invoke_vi(2764,($0|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($9|0);
       }
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_UInt64_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringyS0_($__this,$format,$0,$1,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $0 = $0|0;
 $1 = $1|0;
 $fp = $fp|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627264);
 __THREW__ = 0;
 $2 = (invoke_ii(2486,0)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3799,($2|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_viiii(199,($2|0),($format|0),($0|0),($1|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iiii(1239,($2|0),($format|0),($fp|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(2764,($2|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($11|0);
       }
      }
     }
    }
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z148mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int64_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringxS0_($__this,$format,$0,$1,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $0 = $0|0;
 $1 = $1|0;
 $fp = $fp|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627312);
 __THREW__ = 0;
 $2 = (invoke_ii(2486,0)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vi(3799,($2|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_viiii(198,($2|0),($format|0),($0|0),($1|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_iiii(1239,($2|0),($format|0),($fp|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(2764,($2|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($11|0);
       }
      }
     }
    }
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Single_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringfS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = Math_fround($value);
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627360);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = +$value;
    __THREW__ = 0;
    invoke_viidi(1,($0|0),($format|0),(+$5),7);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3799,($0|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(1148,($0|0),($fp|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($0) + 16|0);
        $16 = HEAP8[$15>>0]|0;
        $17 = ($16<<24>>24)==(0);
        do {
         if ($17) {
          __THREW__ = 0;
          invoke_vi(3799,($0|0));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if ($26) {
           break L1;
          }
          $27 = (($0) + 17|0);
          $28 = HEAP8[$27>>0]|0;
          $29 = ($28<<24>>24)==(0);
          if ($29) {
           __THREW__ = 0;
           invoke_vi(3799,($0|0));
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            break L1;
           }
           $47 = (($0) + 22|0);
           $48 = HEAP16[$47>>1]|0;
           $49 = ($48<<16>>16)==(82);
           if ($49) {
            __THREW__ = 0;
            invoke_vi(3799,($0|0));
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if ($51) {
             break L1;
            }
            __THREW__ = 0;
            $52 = (invoke_iifi(5,($0|0),(+$value),($10|0))|0);
            $53 = __THREW__; __THREW__ = 0;
            $54 = $53&1;
            if ($54) {
             break L1;
            } else {
             $V_2$0 = $52;
             break;
            }
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($0|0));
            $55 = __THREW__; __THREW__ = 0;
            $56 = $55&1;
            if ($56) {
             break L1;
            }
            __THREW__ = 0;
            $57 = (invoke_iiii(1240,($0|0),($format|0),($10|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             break L1;
            } else {
             $V_2$0 = $57;
             break;
            }
           }
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($0|0));
           $30 = __THREW__; __THREW__ = 0;
           $31 = $30&1;
           if ($31) {
            break L1;
           }
           $32 = (($0) + 20|0);
           $33 = HEAP8[$32>>0]|0;
           $34 = ($33<<24>>24)==(0);
           if ($34) {
            __THREW__ = 0;
            invoke_vi(3799,($10|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break L1;
            }
            __THREW__ = 0;
            $42 = (invoke_ii(2028,($10|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break L1;
            } else {
             $V_2$0 = $42;
             break;
            }
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($10|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break L1;
            }
            __THREW__ = 0;
            $37 = (invoke_ii(2043,($10|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break L1;
            } else {
             $V_2$0 = $37;
             break;
            }
           }
          }
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($10|0));
          $20 = __THREW__; __THREW__ = 0;
          $21 = $20&1;
          if ($21) {
           break L1;
          }
          __THREW__ = 0;
          $22 = (invoke_ii(2027,($10|0))|0);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if ($24) {
           break L1;
          } else {
           $V_2$0 = $22;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3799,($0|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if (!($61)) {
         __THREW__ = 0;
         invoke_vi(2764,($0|0));
         $62 = __THREW__; __THREW__ = 0;
         $63 = $62&1;
         if (!($63)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($V_2$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z142mscorlib_System_NumberFormatter_m_FormatRoundtrip_mscorlib_System_String_mscorlib_System_Single_mscorlib_System_Globalization_NumberFormatInfoP31mscorlib_System_NumberFormatterfP46mscorlib_System_Globalization_NumberFormatInfo($__this,$origval,$nfi) {
 $__this = $__this|0;
 $origval = Math_fround($origval);
 $nfi = $nfi|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628176);
 __THREW__ = 0;
 $0 = (invoke_ii(2487,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 28|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  $5 = (invoke_iiii(1244,($__this|0),($4|0),($nfi|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (Math_fround(+(invoke_fiii(1,(0|0),($5|0),($nfi|0)))));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = $8 != $origval;
    if (!($11)) {
     $$0 = $5;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $14 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = (($14) + 2)|0;
     __THREW__ = 0;
     $18 = (invoke_iiii(1244,($0|0),($17|0),($nfi|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $$0 = $18;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z141mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Globalization_NumberFormatInfoP31mscorlib_System_NumberFormatterP22mscorlib_System_StringP46mscorlib_System_Globalization_NumberFormatInfo($__this,$format,$nfi) {
 $__this = $__this|0;
 $format = $format|0;
 $nfi = $nfi|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627888);
 __THREW__ = 0;
 invoke_v(911);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 22|0);
   $3 = HEAP16[$2>>1]|0;
   $4 = $3&65535;
   $5 = (($4) + 65469)|0;
   $6 = $5 & 65535;
   if ((($6|0) == 0)) {
    $14 = (($__this) + 24|0);
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iiii(1241,($__this|0),($15|0),($nfi|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    } else {
     $$0 = $16;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else if ((($6|0) == 3)) {
    $24 = (($__this) + 24|0);
    $25 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $26 = (invoke_iiii(1243,($__this|0),($25|0),($nfi|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    } else {
     $$0 = $26;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else if ((($6|0) == 2)) {
    $19 = (($__this) + 24|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    $21 = (invoke_iiii(1247,($__this|0),($20|0),($nfi|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    } else {
     $$0 = $21;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else if ((($6|0) == 4)) {
    $29 = (($__this) + 24|0);
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iiii(1244,($__this|0),($30|0),($nfi|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    } else {
     $$0 = $31;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    $9 = (($4) + 65458)|0;
    $10 = $9 & 65535;
    if ((($10|0) == 2)) {
     $39 = (($__this) + 24|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     $41 = (invoke_iiii(1246,($__this|0),($40|0),($nfi|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     } else {
      $$0 = $41;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else if ((($10|0) == 0)) {
     $34 = (($__this) + 24|0);
     $35 = HEAP32[$34>>2]|0;
     __THREW__ = 0;
     $36 = (invoke_iiii(1245,($__this|0),($35|0),($nfi|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break;
     } else {
      $$0 = $36;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     $11 = (($__this) + 18|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($12<<24>>24)==(0);
     if (!($13)) {
      __THREW__ = 0;
      $44 = (invoke_iiii(1248,($__this|0),($format|0),($nfi|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      } else {
       $$0 = $44;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $47 = HEAP32[3074432>>2]|0;
     $48 = HEAP32[3074440>>2]|0;
     __THREW__ = 0;
     $49 = (invoke_iiiii(101,(0|0),($47|0),($format|0),($48|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2603176|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
     __THREW__ = 0;
     $54 = (invoke_ii(3469,(2603176|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1940,($54|0),($49|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3838,($54|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break;
     }
     // unreachable;
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Double_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringdS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = +$value;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627408);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_viidi(1,($0|0),($format|0),(+$value),15);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($0|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_iii(1148,($0|0),($fp|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        $14 = (($0) + 16|0);
        $15 = HEAP8[$14>>0]|0;
        $16 = ($15<<24>>24)==(0);
        do {
         if ($16) {
          __THREW__ = 0;
          invoke_vi(3799,($0|0));
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if ($25) {
           break L1;
          }
          $26 = (($0) + 17|0);
          $27 = HEAP8[$26>>0]|0;
          $28 = ($27<<24>>24)==(0);
          if ($28) {
           __THREW__ = 0;
           invoke_vi(3799,($0|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            break L1;
           }
           $46 = (($0) + 22|0);
           $47 = HEAP16[$46>>1]|0;
           $48 = ($47<<16>>16)==(82);
           if ($48) {
            __THREW__ = 0;
            invoke_vi(3799,($0|0));
            $49 = __THREW__; __THREW__ = 0;
            $50 = $49&1;
            if ($50) {
             break L1;
            }
            __THREW__ = 0;
            $51 = (invoke_iidi(2,($0|0),(+$value),($9|0))|0);
            $52 = __THREW__; __THREW__ = 0;
            $53 = $52&1;
            if ($53) {
             break L1;
            } else {
             $V_2$0 = $51;
             break;
            }
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($0|0));
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if ($55) {
             break L1;
            }
            __THREW__ = 0;
            $56 = (invoke_iiii(1240,($0|0),($format|0),($9|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if ($58) {
             break L1;
            } else {
             $V_2$0 = $56;
             break;
            }
           }
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($0|0));
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if ($30) {
            break L1;
           }
           $31 = (($0) + 20|0);
           $32 = HEAP8[$31>>0]|0;
           $33 = ($32<<24>>24)==(0);
           if ($33) {
            __THREW__ = 0;
            invoke_vi(3799,($9|0));
            $39 = __THREW__; __THREW__ = 0;
            $40 = $39&1;
            if ($40) {
             break L1;
            }
            __THREW__ = 0;
            $41 = (invoke_ii(2028,($9|0))|0);
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if ($43) {
             break L1;
            } else {
             $V_2$0 = $41;
             break;
            }
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($9|0));
            $34 = __THREW__; __THREW__ = 0;
            $35 = $34&1;
            if ($35) {
             break L1;
            }
            __THREW__ = 0;
            $36 = (invoke_ii(2043,($9|0))|0);
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if ($38) {
             break L1;
            } else {
             $V_2$0 = $36;
             break;
            }
           }
          }
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($9|0));
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if ($20) {
           break L1;
          }
          __THREW__ = 0;
          $21 = (invoke_ii(2027,($9|0))|0);
          $22 = __THREW__; __THREW__ = 0;
          $23 = $22&1;
          if ($23) {
           break L1;
          } else {
           $V_2$0 = $21;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3799,($0|0));
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if (!($60)) {
         __THREW__ = 0;
         invoke_vi(2764,($0|0));
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if (!($62)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($V_2$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z142mscorlib_System_NumberFormatter_m_FormatRoundtrip_mscorlib_System_String_mscorlib_System_Double_mscorlib_System_Globalization_NumberFormatInfoP31mscorlib_System_NumberFormatterdP46mscorlib_System_Globalization_NumberFormatInfo($__this,$origval,$nfi) {
 $__this = $__this|0;
 $origval = +$origval;
 $nfi = $nfi|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628128);
 __THREW__ = 0;
 $0 = (invoke_ii(2487,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = $origval < -1.79769313486230992021E+308;
   $4 = $origval > 1.79769313486230992021E+308;
   $or$cond = $3 | $4;
   $$pre = (($__this) + 28|0);
   if (!($or$cond)) {
    $7 = HEAP32[$$pre>>2]|0;
    __THREW__ = 0;
    $8 = (invoke_iiii(1244,($__this|0),($7|0),($nfi|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (+invoke_diii(1,(0|0),($8|0),($nfi|0)));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = $11 != $origval;
    if (!($14)) {
     $$0 = $8;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
   $15 = HEAP32[$$pre>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = (($15) + 2)|0;
    __THREW__ = 0;
    $19 = (invoke_iiii(1244,($0|0),($18|0),($nfi|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $$0 = $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z150mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Decimal_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_String23mscorlib_System_DecimalS0_($__this,$format,$value,$fp) {
 $__this = $__this|0;
 $format = $format|0;
 $value = $value|0;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627456);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
   invoke_viii(688,($0|0),($format|0),($value$byval_copy|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($0|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_iii(1148,($0|0),($fp|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      invoke_vi(3799,($0|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       $14 = (invoke_iiii(1240,($0|0),($format|0),($9|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __THREW__ = 0;
        invoke_vi(3799,($0|0));
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         __THREW__ = 0;
         invoke_vi(2764,($0|0));
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if (!($20)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($14|0);
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z126mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_UInt32_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectjS0_($__this,$value,$fp) {
 $__this = $__this|0;
 $value = $value|0;
 $fp = $fp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627504);
 $0 = ($value>>>0)<(100000000);
 if ($0) {
  __THREW__ = 0;
  $6 = (invoke_ii(2486,0)|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vi(3799,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_iiii(1238,($6|0),($value|0),($fp|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(2764,($6|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $$0 = $11;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  $1 = (invoke_iiiii(193,0,(0|0),($value|0),($fp|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $$0 = $1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z53mscorlib_System_NumberFormatter_m_FastIntegerToStringP31mscorlib_System_NumberFormatteriP22mscorlib_System_Object($__this,$value,$fp) {
 $__this = $__this|0;
 $value = $value|0;
 $fp = $fp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627792);
 $0 = ($value|0)>(-1);
 if ($0) {
  __THREW__ = 0;
  invoke_vii(1959,($__this|0),8);
  $22 = __THREW__; __THREW__ = 0;
  $23 = $22&1;
  if (!($23)) {
   $$0 = $value;
   label = 11;
  }
 } else {
  __THREW__ = 0;
  $1 = (invoke_iii(1148,($__this|0),($fp|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   invoke_vi(3799,($1|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_ii(2029,($1|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vi(3799,($6|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      $11 = (invoke_ii(1816,($6|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       $14 = (($11) + 8)|0;
       __THREW__ = 0;
       invoke_vii(1959,($__this|0),($14|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        $17 = (0 - ($value))|0;
        __THREW__ = 0;
        invoke_vii(1962,($__this|0),($6|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         $$0 = $17;
         label = 11;
        }
       }
      }
     }
    }
   }
  }
 }
 do {
  if ((label|0) == 11) {
   $24 = ($$0|0)<(10000);
   if ($24) {
    __THREW__ = 0;
    invoke_viii(695,($__this|0),($$0|0),0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
   } else {
    $25 = (($$0|0) / 10000)&-1;
    __THREW__ = 0;
    invoke_viii(695,($__this|0),($25|0),0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = Math_imul($25, -10000)|0;
    $29 = (($28) + ($$0))|0;
    __THREW__ = 0;
    invoke_viii(695,($__this|0),($29|0),1);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
   }
   $34 = (($__this) + 60|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($__this) + 64|0);
   $37 = HEAP32[$36>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if (!($39)) {
    __THREW__ = 0;
    $40 = (invoke_ii(3469,(2191608|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if (!($42)) {
     __THREW__ = 0;
     $43 = (invoke_iiiii(104,($40|0),($35|0),0,($37|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($43|0);
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectiS0_($__this,$value,$fp) {
 $__this = $__this|0;
 $value = $value|0;
 $fp = $fp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var $value$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627552);
 $value$off = (($value) + 99999999)|0;
 $0 = ($value$off>>>0)<(199999999);
 if ($0) {
  __THREW__ = 0;
  $6 = (invoke_ii(2486,0)|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vi(3799,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_iiii(1238,($6|0),($value|0),($fp|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($6|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(2764,($6|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $$0 = $11;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  $1 = (invoke_iiiii(194,0,(0|0),($value|0),($fp|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $$0 = $1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z126mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_UInt64_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectyS0_($__this,$0,$1,$fp) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 $fp = $fp|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627600);
 $2 = ($1>>>0)<(0);
 $3 = ($1|0)==(0);
 $4 = ($0>>>0)<(100000000);
 $5 = $3 & $4;
 $6 = $2 | $5;
 if ($6) {
  __THREW__ = 0;
  $12 = (invoke_ii(2486,0)|0);
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iiii(1238,($12|0),($0|0),($fp|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     invoke_vi(3799,($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(2764,($12|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       $$0 = $17;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  $7 = (invoke_iiiiii(133,0,(0|0),($0|0),($1|0),($fp|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $$0 = $7;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_Int64_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectxS0_($__this,$0,$1,$fp) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 $fp = $fp|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627648);
 $2 = (_i64Add(($0|0),($1|0),99999999,0)|0);
 $3 = tempRet0;
 $4 = ($3>>>0)<(0);
 $5 = ($3|0)==(0);
 $6 = ($2>>>0)<(199999999);
 $7 = $5 & $6;
 $8 = $4 | $7;
 if ($8) {
  __THREW__ = 0;
  $14 = (invoke_ii(2486,0)|0);
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   __THREW__ = 0;
   invoke_vi(3799,($14|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_iiii(1238,($14|0),($0|0),($fp|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     invoke_vi(3799,($14|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      __THREW__ = 0;
      invoke_vi(2764,($14|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $$0 = $19;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } else {
  __THREW__ = 0;
  $9 = (invoke_iiiiii(134,0,(0|0),($0|0),($1|0),($fp|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $$0 = $9;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z126mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_Single_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectfS0_($__this,$value,$fp) {
 $__this = $__this|0;
 $value = Math_fround($value);
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627696);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = +$value;
    __THREW__ = 0;
    invoke_viidi(1,($0|0),(0|0),(+$5),7);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3799,($0|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(1148,($0|0),($fp|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($0) + 16|0);
        $16 = HEAP8[$15>>0]|0;
        $17 = ($16<<24>>24)==(0);
        do {
         if ($17) {
          __THREW__ = 0;
          invoke_vi(3799,($0|0));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if ($26) {
           break L1;
          }
          $27 = (($0) + 17|0);
          $28 = HEAP8[$27>>0]|0;
          $29 = ($28<<24>>24)==(0);
          if ($29) {
           __THREW__ = 0;
           invoke_vi(3799,($0|0));
           $45 = __THREW__; __THREW__ = 0;
           $46 = $45&1;
           if ($46) {
            break L1;
           }
           __THREW__ = 0;
           $47 = (invoke_iiii(1244,($0|0),-1,($10|0))|0);
           $48 = __THREW__; __THREW__ = 0;
           $49 = $48&1;
           if ($49) {
            break L1;
           } else {
            $V_2$0 = $47;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($0|0));
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if ($31) {
           break L1;
          }
          $32 = (($0) + 20|0);
          $33 = HEAP8[$32>>0]|0;
          $34 = ($33<<24>>24)==(0);
          if ($34) {
           __THREW__ = 0;
           invoke_vi(3799,($10|0));
           $40 = __THREW__; __THREW__ = 0;
           $41 = $40&1;
           if ($41) {
            break L1;
           }
           __THREW__ = 0;
           $42 = (invoke_ii(2028,($10|0))|0);
           $43 = __THREW__; __THREW__ = 0;
           $44 = $43&1;
           if ($44) {
            break L1;
           } else {
            $V_2$0 = $42;
            break;
           }
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($10|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if ($36) {
            break L1;
           }
           __THREW__ = 0;
           $37 = (invoke_ii(2043,($10|0))|0);
           $38 = __THREW__; __THREW__ = 0;
           $39 = $38&1;
           if ($39) {
            break L1;
           } else {
            $V_2$0 = $37;
            break;
           }
          }
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($10|0));
          $20 = __THREW__; __THREW__ = 0;
          $21 = $20&1;
          if ($21) {
           break L1;
          }
          __THREW__ = 0;
          $22 = (invoke_ii(2027,($10|0))|0);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if ($24) {
           break L1;
          } else {
           $V_2$0 = $22;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3799,($0|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if (!($51)) {
         __THREW__ = 0;
         invoke_vi(2764,($0|0));
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if (!($53)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($V_2$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_NumberFormatter_m_FormatGeneralP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo($__this,$precision,$nfi) {
 $__this = $__this|0;
 $precision = $precision|0;
 $nfi = $nfi|0;
 var $$ = 0, $$0 = 0, $$01 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$off0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $brmerge = 0, $or$cond = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628224);
 if ((($precision|0) == 0)) {
  $7 = (($__this) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $$01 = $8;
  label = 6;
 } else if ((($precision|0) == -1)) {
  __THREW__ = 0;
  $0 = (invoke_ii(2482,($__this|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   $3 = (($__this) + 28|0);
   $4 = HEAP32[$3>>2]|0;
   $phitmp = $0 ^ 1;
   $$1 = $4;$V_0$0$off0 = $phitmp;
   label = 7;
  }
 } else {
  $$01 = $precision;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vii(1964,($__this|0),($$01|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $$1 = $$01;$V_0$0$off0 = 0;
   label = 7;
  }
 }
 do {
  if ((label|0) == 7) {
   $11 = (($__this) + 40|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($__this) + 32|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) - ($12))|0;
   $16 = ($12|0)<=($$1|0);
   $17 = ($12|0)>(-4);
   $or$cond = $16 & $17;
   $brmerge = $or$cond | $V_0$0$off0;
   if (!($brmerge)) {
    $18 = (($14) + -1)|0;
    __THREW__ = 0;
    $19 = (invoke_iiiii(198,($__this|0),($18|0),($nfi|0),2)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    } else {
     $$0 = $19;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $22 = ($15|0)<(0);
   $$ = $22 ? 0 : $15;
   $23 = ($12|0)<(0);
   $V_1$0 = $23 ? 0 : $12;
   $24 = (($V_1$0) + 3)|0;
   $25 = (($24) + ($$))|0;
   __THREW__ = 0;
   invoke_vii(1959,($__this|0),($25|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   if (!($27)) {
    $28 = (($__this) + 20|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = ($29<<24>>24)==(0);
    if ($30) {
     __THREW__ = 0;
     invoke_vi(3799,($nfi|0));
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     __THREW__ = 0;
     $33 = (invoke_ii(2029,($nfi|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1962,($__this|0),($33|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      break;
     }
    }
    $38 = ($V_1$0|0)==(0);
    if ($38) {
     __THREW__ = 0;
     invoke_vii(1961,($__this|0),48);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      break;
     }
    } else {
     $41 = (($14) - ($V_1$0))|0;
     __THREW__ = 0;
     invoke_viii(696,($__this|0),($41|0),($14|0));
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     if ($43) {
      break;
     }
    }
    $44 = ($$|0)<(1);
    if (!($44)) {
     __THREW__ = 0;
     invoke_vi(3799,($nfi|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break;
     }
     __THREW__ = 0;
     $47 = (invoke_ii(2031,($nfi|0))|0);
     $48 = __THREW__; __THREW__ = 0;
     $49 = $48&1;
     if ($49) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1962,($__this|0),($47|0));
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     __THREW__ = 0;
     invoke_viii(696,($__this|0),0,($$|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
    }
    $54 = (($__this) + 60|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = (($__this) + 64|0);
    $57 = HEAP32[$56>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if (!($59)) {
     __THREW__ = 0;
     $60 = (invoke_ii(3469,(2191608|0))|0);
     $61 = __THREW__; __THREW__ = 0;
     $62 = $61&1;
     if (!($62)) {
      __THREW__ = 0;
      $63 = (invoke_iiiii(104,($60|0),($55|0),0,($57|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if (!($65)) {
       $$0 = $63;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z126mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_Double_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectdS0_($__this,$value,$fp) {
 $__this = $__this|0;
 $value = +$value;
 $fp = $fp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627744);
 __THREW__ = 0;
 $0 = (invoke_ii(2486,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_iii(1148,($0|0),($fp|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3799,($0|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_viidi(1,($0|0),(0|0),(+$value),15);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        $14 = (($0) + 16|0);
        $15 = HEAP8[$14>>0]|0;
        $16 = ($15<<24>>24)==(0);
        do {
         if ($16) {
          __THREW__ = 0;
          invoke_vi(3799,($0|0));
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if ($25) {
           break L1;
          }
          $26 = (($0) + 17|0);
          $27 = HEAP8[$26>>0]|0;
          $28 = ($27<<24>>24)==(0);
          if ($28) {
           __THREW__ = 0;
           invoke_vi(3799,($0|0));
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            break L1;
           }
           __THREW__ = 0;
           $46 = (invoke_iiii(1244,($0|0),-1,($5|0))|0);
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if ($48) {
            break L1;
           } else {
            $V_2$0 = $46;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($0|0));
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if ($30) {
           break L1;
          }
          $31 = (($0) + 20|0);
          $32 = HEAP8[$31>>0]|0;
          $33 = ($32<<24>>24)==(0);
          if ($33) {
           __THREW__ = 0;
           invoke_vi(3799,($5|0));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if ($40) {
            break L1;
           }
           __THREW__ = 0;
           $41 = (invoke_ii(2028,($5|0))|0);
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if ($43) {
            break L1;
           } else {
            $V_2$0 = $41;
            break;
           }
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($5|0));
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if ($35) {
            break L1;
           }
           __THREW__ = 0;
           $36 = (invoke_ii(2043,($5|0))|0);
           $37 = __THREW__; __THREW__ = 0;
           $38 = $37&1;
           if ($38) {
            break L1;
           } else {
            $V_2$0 = $36;
            break;
           }
          }
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($5|0));
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if ($20) {
           break L1;
          }
          __THREW__ = 0;
          $21 = (invoke_ii(2027,($5|0))|0);
          $22 = __THREW__; __THREW__ = 0;
          $23 = $22&1;
          if ($23) {
           break L1;
          } else {
           $V_2$0 = $21;
          }
         }
        } while(0);
        __THREW__ = 0;
        invoke_vi(3799,($0|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if (!($50)) {
         __THREW__ = 0;
         invoke_vi(2764,($0|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if (!($52)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($V_2$0|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_NumberFormatter_m_FastAppendDigitsP31mscorlib_System_NumberFormatterib($__this,$val,$force) {
 $__this = $__this|0;
 $val = $val|0;
 $force = $force|0;
 var $$pre = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$2 = 0, $V_1$0 = 0, $V_1$0$in = 0, $_stackTraceSentry = 0, $force$not = 0, $or$cond = 0, $or$cond2 = 0, $or$cond4 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628992);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $force$not = $force ^ 1;
 $2 = ($val|0)<(100);
 $or$cond = $2 & $force$not;
 do {
  if ($or$cond) {
   __THREW__ = 0;
   (invoke_ii(2996,(2633856|0))|0);
   $87 = __THREW__; __THREW__ = 0;
   $88 = $87&1;
   if (!($88)) {
    $89 = HEAP8[((2633856 + 116|0))>>0]|0;
    $90 = ($89<<24>>24)==(0);
    if ($90) {
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $93 = __THREW__; __THREW__ = 0;
     $94 = $93&1;
     if ($94) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2633856|0));
     $95 = __THREW__; __THREW__ = 0;
     $96 = $95&1;
     if ($96) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $97 = __THREW__; __THREW__ = 0;
    $98 = $97&1;
    if (!($98)) {
     $99 = HEAP32[((2633856 + 80|0))>>2]|0;
     $100 = (($99) + 20|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = (($101) + ($val<<2)|0);
     $V_0$1 = $1;$V_1$0$in = $102;
     label = 35;
    }
   }
  } else {
   $3 = ($val*5243)|0;
   $4 = $3 >> 19;
   __THREW__ = 0;
   (invoke_ii(2996,(2633856|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP8[((2633856 + 116|0))>>0]|0;
    $8 = ($7<<24>>24)==(0);
    if ($8) {
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2633856|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP32[((2633856 + 80|0))>>2]|0;
     $20 = (($19) + 20|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = (($21) + ($4<<2)|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($val|0)<(1000);
     $or$cond2 = $24 & $force$not;
     $$pre16 = (($__this) + 60|0);
     if ($or$cond2) {
      $V_0$0 = $1;
     } else {
      $25 = HEAP32[$$pre16>>2]|0;
      $26 = (($1) + 1)|0;
      $27 = $23 >>> 4;
      $28 = $27 | 48;
      $29 = $28&65535;
      __THREW__ = 0;
      invoke_vi(3799,($25|0));
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = ($1|0)<(0);
      if ($32) {
       label = 13;
      } else {
       $33 = (($25) + 12|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = ($1>>>0)<($34>>>0);
       if (!($35)) {
        label = 13;
       }
      }
      if ((label|0) == 13) {
       __THREW__ = 0;
       $36 = (invoke_i(132)|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($36|0));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break;
       }
      }
      $41 = HEAP32[$25>>2]|0;
      $42 = (($25) + 16|0);
      $43 = (($41) + 92|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = Math_imul($44, $1)|0;
      $46 = (($42) + ($45)|0);
      HEAP16[$46>>1] = $29;
      $V_0$0 = $26;
     }
     $47 = HEAP32[$$pre16>>2]|0;
     $48 = (($V_0$0) + 1)|0;
     $49 = $23 & 15;
     $50 = $49 | 48;
     $51 = $50&65535;
     __THREW__ = 0;
     invoke_vi(3799,($47|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      $54 = ($V_0$0|0)<(0);
      if ($54) {
       label = 19;
      } else {
       $55 = (($47) + 12|0);
       $56 = HEAP32[$55>>2]|0;
       $57 = ($V_0$0>>>0)<($56>>>0);
       if (!($57)) {
        label = 19;
       }
      }
      if ((label|0) == 19) {
       __THREW__ = 0;
       $58 = (invoke_i(132)|0);
       $59 = __THREW__; __THREW__ = 0;
       $60 = $59&1;
       if ($60) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($58|0));
       $61 = __THREW__; __THREW__ = 0;
       $62 = $61&1;
       if ($62) {
        break;
       }
      }
      $63 = HEAP32[$47>>2]|0;
      $64 = (($47) + 16|0);
      $65 = (($63) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_0$0)|0;
      $68 = (($64) + ($67)|0);
      HEAP16[$68>>1] = $51;
      __THREW__ = 0;
      (invoke_ii(2996,(2633856|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if (!($70)) {
       $71 = HEAP8[((2633856 + 116|0))>>0]|0;
       $72 = ($71<<24>>24)==(0);
       if ($72) {
        __THREW__ = 0;
        (invoke_ii(2996,(2633856|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2633856|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3839,(2633856|0));
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2633856|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if (!($80)) {
        $81 = HEAP32[((2633856 + 80|0))>>2]|0;
        $82 = (($81) + 20|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = Math_imul($4, -100)|0;
        $85 = (($84) + ($val))|0;
        $86 = (($83) + ($85<<2)|0);
        $V_0$1 = $48;$V_1$0$in = $86;
        label = 35;
       }
      }
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 35) {
   $V_1$0 = HEAP32[$V_1$0$in>>2]|0;
   $103 = ($val|0)<(10);
   $or$cond4 = $103 & $force$not;
   $$pre = (($__this) + 60|0);
   if ($or$cond4) {
    $V_0$2 = $V_0$1;
   } else {
    $104 = HEAP32[$$pre>>2]|0;
    $105 = (($V_0$1) + 1)|0;
    $106 = $V_1$0 >>> 4;
    $107 = $106 | 48;
    $108 = $107&65535;
    __THREW__ = 0;
    invoke_vi(3799,($104|0));
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     break;
    }
    $111 = ($V_0$1|0)<(0);
    if ($111) {
     label = 39;
    } else {
     $112 = (($104) + 12|0);
     $113 = HEAP32[$112>>2]|0;
     $114 = ($V_0$1>>>0)<($113>>>0);
     if (!($114)) {
      label = 39;
     }
    }
    if ((label|0) == 39) {
     __THREW__ = 0;
     $115 = (invoke_i(132)|0);
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if ($117) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($115|0));
     $118 = __THREW__; __THREW__ = 0;
     $119 = $118&1;
     if ($119) {
      break;
     }
    }
    $120 = HEAP32[$104>>2]|0;
    $121 = (($104) + 16|0);
    $122 = (($120) + 92|0);
    $123 = HEAP32[$122>>2]|0;
    $124 = Math_imul($123, $V_0$1)|0;
    $125 = (($121) + ($124)|0);
    HEAP16[$125>>1] = $108;
    $V_0$2 = $105;
   }
   $126 = HEAP32[$$pre>>2]|0;
   $127 = (($V_0$2) + 1)|0;
   $128 = $V_1$0 & 15;
   $129 = $128 | 48;
   $130 = $129&65535;
   __THREW__ = 0;
   invoke_vi(3799,($126|0));
   $131 = __THREW__; __THREW__ = 0;
   $132 = $131&1;
   if (!($132)) {
    $133 = ($V_0$2|0)<(0);
    if (!($133)) {
     $134 = (($126) + 12|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($V_0$2>>>0)<($135>>>0);
     if ($136) {
      $142 = HEAP32[$126>>2]|0;
      $143 = (($126) + 16|0);
      $144 = (($142) + 92|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = Math_imul($145, $V_0$2)|0;
      $147 = (($143) + ($146)|0);
      HEAP16[$147>>1] = $130;
      HEAP32[$0>>2] = $127;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
    __THREW__ = 0;
    $137 = (invoke_i(132)|0);
    $138 = __THREW__; __THREW__ = 0;
    $139 = $138&1;
    if (!($139)) {
     __THREW__ = 0;
     invoke_vi(3302,($137|0));
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if (!($141)) {
      $142 = HEAP32[$126>>2]|0;
      $143 = (($126) + 16|0);
      $144 = (($142) + 92|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = Math_imul($145, $V_0$2)|0;
      $147 = (($143) + ($146)|0);
      HEAP16[$147>>1] = $130;
      HEAP32[$0>>2] = $127;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z48mscorlib_System_NumberFormatter_m_FormatCurrencyP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo($__this,$precision,$nfi) {
 $__this = $__this|0;
 $precision = $precision|0;
 $nfi = $nfi|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $G_B3_0$0 = 0, $_stackTraceSentry = 0, $tmp = 0, $tmp8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627936);
 $0 = ($precision|0)<(0);
 if ($0) {
  __THREW__ = 0;
  invoke_vi(3799,($nfi|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2018,($nfi|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $G_B3_0$0 = $3;
    label = 4;
   }
  }
 } else {
  $G_B3_0$0 = $precision;
  label = 4;
 }
 L4: do {
  if ((label|0) == 4) {
   __THREW__ = 0;
   (invoke_iii(1149,($__this|0),($G_B3_0$0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(2480,($__this|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $tmp = (($8) + ($G_B3_0$0))|0;
     $tmp8 = $tmp << 1;
     $11 = (($tmp8) + 16)|0;
     __THREW__ = 0;
     invoke_vii(1959,($__this|0),($11|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 20|0);
      $15 = HEAP8[$14>>0]|0;
      $16 = ($15<<24>>24)==(0);
      L9: do {
       if ($16) {
        __THREW__ = 0;
        invoke_vi(3799,($nfi|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break L4;
        }
        __THREW__ = 0;
        $42 = (invoke_ii(2022,($nfi|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break L4;
        }
        switch ($42|0) {
        case 0:  {
         __THREW__ = 0;
         invoke_vii(1961,($__this|0),40);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if ($50) {
          break L4;
         }
         __THREW__ = 0;
         $51 = (invoke_ii(2024,($nfi|0))|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($51|0));
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break L4;
         } else {
          break L9;
         }
         break;
        }
        case 4:  {
         __THREW__ = 0;
         invoke_vii(1961,($__this|0),40);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break L4;
         } else {
          break L9;
         }
         break;
        }
        case 5:  {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          break L4;
         }
         __THREW__ = 0;
         $95 = (invoke_ii(2029,($nfi|0))|0);
         $96 = __THREW__; __THREW__ = 0;
         $97 = $96&1;
         if ($97) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($95|0));
         $98 = __THREW__; __THREW__ = 0;
         $99 = $98&1;
         if ($99) {
          break L4;
         } else {
          break L9;
         }
         break;
        }
        case 3:  {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $84 = __THREW__; __THREW__ = 0;
         $85 = $84&1;
         if ($85) {
          break L4;
         }
         __THREW__ = 0;
         $86 = (invoke_ii(2024,($nfi|0))|0);
         $87 = __THREW__; __THREW__ = 0;
         $88 = $87&1;
         if ($88) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($86|0));
         $89 = __THREW__; __THREW__ = 0;
         $90 = $89&1;
         if ($90) {
          break L4;
         } else {
          break L9;
         }
         break;
        }
        case 1:  {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          break L4;
         }
         __THREW__ = 0;
         $58 = (invoke_ii(2029,($nfi|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($58|0));
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L4;
         }
         __THREW__ = 0;
         $65 = (invoke_ii(2024,($nfi|0))|0);
         $66 = __THREW__; __THREW__ = 0;
         $67 = $66&1;
         if ($67) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($65|0));
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          break L4;
         } else {
          break L9;
         }
         break;
        }
        case 2:  {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          break L4;
         }
         __THREW__ = 0;
         $72 = (invoke_ii(2024,($nfi|0))|0);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($72|0));
         $75 = __THREW__; __THREW__ = 0;
         $76 = $75&1;
         if ($76) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break L4;
         }
         __THREW__ = 0;
         $79 = (invoke_ii(2029,($nfi|0))|0);
         $80 = __THREW__; __THREW__ = 0;
         $81 = $80&1;
         if ($81) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($79|0));
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          break L4;
         } else {
          break L9;
         }
         break;
        }
        default: {
         $45 = $42 & -2;
         $46 = ($45|0)==(6);
         if ($46) {
          break L9;
         }
         switch ($42|0) {
         case 9:  {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $107 = __THREW__; __THREW__ = 0;
          $108 = $107&1;
          if ($108) {
           break L4;
          }
          __THREW__ = 0;
          $109 = (invoke_ii(2029,($nfi|0))|0);
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($109|0));
          $112 = __THREW__; __THREW__ = 0;
          $113 = $112&1;
          if ($113) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $114 = __THREW__; __THREW__ = 0;
          $115 = $114&1;
          if ($115) {
           break L4;
          }
          __THREW__ = 0;
          $116 = (invoke_ii(2024,($nfi|0))|0);
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($116|0));
          $119 = __THREW__; __THREW__ = 0;
          $120 = $119&1;
          if ($120) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1961,($__this|0),32);
          $121 = __THREW__; __THREW__ = 0;
          $122 = $121&1;
          if ($122) {
           break L4;
          } else {
           break L9;
          }
          break;
         }
         case 8:  {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $100 = __THREW__; __THREW__ = 0;
          $101 = $100&1;
          if ($101) {
           break L4;
          }
          __THREW__ = 0;
          $102 = (invoke_ii(2029,($nfi|0))|0);
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($102|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           break L4;
          } else {
           break L9;
          }
          break;
         }
         case 11:  {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $123 = __THREW__; __THREW__ = 0;
          $124 = $123&1;
          if ($124) {
           break L4;
          }
          __THREW__ = 0;
          $125 = (invoke_ii(2024,($nfi|0))|0);
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($125|0));
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1961,($__this|0),32);
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           break L4;
          } else {
           break L9;
          }
          break;
         }
         case 12:  {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           break L4;
          }
          __THREW__ = 0;
          $134 = (invoke_ii(2024,($nfi|0))|0);
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($134|0));
          $137 = __THREW__; __THREW__ = 0;
          $138 = $137&1;
          if ($138) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1961,($__this|0),32);
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $141 = __THREW__; __THREW__ = 0;
          $142 = $141&1;
          if ($142) {
           break L4;
          }
          __THREW__ = 0;
          $143 = (invoke_ii(2029,($nfi|0))|0);
          $144 = __THREW__; __THREW__ = 0;
          $145 = $144&1;
          if ($145) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($143|0));
          $146 = __THREW__; __THREW__ = 0;
          $147 = $146&1;
          if ($147) {
           break L4;
          } else {
           break L9;
          }
          break;
         }
         case 14:  {
          __THREW__ = 0;
          invoke_vii(1961,($__this|0),40);
          $148 = __THREW__; __THREW__ = 0;
          $149 = $148&1;
          if ($149) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $150 = __THREW__; __THREW__ = 0;
          $151 = $150&1;
          if ($151) {
           break L4;
          }
          __THREW__ = 0;
          $152 = (invoke_ii(2024,($nfi|0))|0);
          $153 = __THREW__; __THREW__ = 0;
          $154 = $153&1;
          if ($154) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($152|0));
          $155 = __THREW__; __THREW__ = 0;
          $156 = $155&1;
          if ($156) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1961,($__this|0),32);
          $157 = __THREW__; __THREW__ = 0;
          $158 = $157&1;
          if ($158) {
           break L4;
          } else {
           break L9;
          }
          break;
         }
         case 15:  {
          __THREW__ = 0;
          invoke_vii(1961,($__this|0),40);
          $159 = __THREW__; __THREW__ = 0;
          $160 = $159&1;
          if ($160) {
           break L4;
          } else {
           break L9;
          }
          break;
         }
         default: {
          break L9;
         }
         }
        }
        }
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($nfi|0));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         break L4;
        }
        __THREW__ = 0;
        $21 = (invoke_ii(2023,($nfi|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break L4;
        }
        if ((($21|0) == 0)) {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if ($25) {
          break L4;
         }
         __THREW__ = 0;
         $26 = (invoke_ii(2024,($nfi|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($26|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break L4;
         } else {
          break;
         }
        } else if (!((($21|0) == 2))) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($nfi|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         break L4;
        }
        __THREW__ = 0;
        $33 = (invoke_ii(2024,($nfi|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break L4;
        }
        __THREW__ = 0;
        invoke_vii(1962,($__this|0),($33|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L4;
        }
        __THREW__ = 0;
        invoke_vii(1961,($__this|0),32);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break L4;
        }
       }
      } while(0);
      __THREW__ = 0;
      invoke_vi(3799,($nfi|0));
      $161 = __THREW__; __THREW__ = 0;
      $162 = $161&1;
      if (!($162)) {
       __THREW__ = 0;
       $163 = (invoke_ii(2021,($nfi|0))|0);
       $164 = __THREW__; __THREW__ = 0;
       $165 = $164&1;
       if (!($165)) {
        __THREW__ = 0;
        invoke_vi(3799,($nfi|0));
        $166 = __THREW__; __THREW__ = 0;
        $167 = $166&1;
        if (!($167)) {
         __THREW__ = 0;
         $168 = (invoke_ii(2020,($nfi|0))|0);
         $169 = __THREW__; __THREW__ = 0;
         $170 = $169&1;
         if (!($170)) {
          __THREW__ = 0;
          invoke_viii(694,($__this|0),($163|0),($168|0));
          $171 = __THREW__; __THREW__ = 0;
          $172 = $171&1;
          if (!($172)) {
           $173 = ($G_B3_0$0|0)<(1);
           if (!($173)) {
            __THREW__ = 0;
            invoke_vi(3799,($nfi|0));
            $174 = __THREW__; __THREW__ = 0;
            $175 = $174&1;
            if ($175) {
             break;
            }
            __THREW__ = 0;
            $176 = (invoke_ii(2019,($nfi|0))|0);
            $177 = __THREW__; __THREW__ = 0;
            $178 = $177&1;
            if ($178) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1962,($__this|0),($176|0));
            $179 = __THREW__; __THREW__ = 0;
            $180 = $179&1;
            if ($180) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1966,($__this|0),($G_B3_0$0|0));
            $181 = __THREW__; __THREW__ = 0;
            $182 = $181&1;
            if ($182) {
             break;
            }
           }
           $183 = HEAP8[$14>>0]|0;
           $184 = ($183<<24>>24)==(0);
           L90: do {
            if ($184) {
             __THREW__ = 0;
             invoke_vi(3799,($nfi|0));
             $206 = __THREW__; __THREW__ = 0;
             $207 = $206&1;
             if ($207) {
              break L4;
             }
             __THREW__ = 0;
             $208 = (invoke_ii(2022,($nfi|0))|0);
             $209 = __THREW__; __THREW__ = 0;
             $210 = $209&1;
             if ($210) {
              break L4;
             }
             $211 = ($208|0)==(0);
             if ($211) {
              __THREW__ = 0;
              invoke_vii(1961,($__this|0),41);
              $213 = __THREW__; __THREW__ = 0;
              $214 = $213&1;
              if ($214) {
               break L4;
              } else {
               break;
              }
             }
             $$off = (($208) + -1)|0;
             $212 = ($$off>>>0)<(2);
             if (!($212)) {
              do {
               switch ($208|0) {
               case 10:  {
                __THREW__ = 0;
                invoke_vii(1961,($__this|0),32);
                $275 = __THREW__; __THREW__ = 0;
                $276 = $275&1;
                if ($276) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $277 = __THREW__; __THREW__ = 0;
                $278 = $277&1;
                if ($278) {
                 break L4;
                }
                __THREW__ = 0;
                $279 = (invoke_ii(2024,($nfi|0))|0);
                $280 = __THREW__; __THREW__ = 0;
                $281 = $280&1;
                if ($281) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($279|0));
                $282 = __THREW__; __THREW__ = 0;
                $283 = $282&1;
                if ($283) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $284 = __THREW__; __THREW__ = 0;
                $285 = $284&1;
                if ($285) {
                 break L4;
                }
                __THREW__ = 0;
                $286 = (invoke_ii(2029,($nfi|0))|0);
                $287 = __THREW__; __THREW__ = 0;
                $288 = $287&1;
                if ($288) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($286|0));
                $289 = __THREW__; __THREW__ = 0;
                $290 = $289&1;
                if ($290) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 13:  {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $298 = __THREW__; __THREW__ = 0;
                $299 = $298&1;
                if ($299) {
                 break L4;
                }
                __THREW__ = 0;
                $300 = (invoke_ii(2029,($nfi|0))|0);
                $301 = __THREW__; __THREW__ = 0;
                $302 = $301&1;
                if ($302) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($300|0));
                $303 = __THREW__; __THREW__ = 0;
                $304 = $303&1;
                if ($304) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1961,($__this|0),32);
                $305 = __THREW__; __THREW__ = 0;
                $306 = $305&1;
                if ($306) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $307 = __THREW__; __THREW__ = 0;
                $308 = $307&1;
                if ($308) {
                 break L4;
                }
                __THREW__ = 0;
                $309 = (invoke_ii(2024,($nfi|0))|0);
                $310 = __THREW__; __THREW__ = 0;
                $311 = $310&1;
                if ($311) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($309|0));
                $312 = __THREW__; __THREW__ = 0;
                $313 = $312&1;
                if ($313) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 11:  {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $291 = __THREW__; __THREW__ = 0;
                $292 = $291&1;
                if ($292) {
                 break L4;
                }
                __THREW__ = 0;
                $293 = (invoke_ii(2029,($nfi|0))|0);
                $294 = __THREW__; __THREW__ = 0;
                $295 = $294&1;
                if ($295) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($293|0));
                $296 = __THREW__; __THREW__ = 0;
                $297 = $296&1;
                if ($297) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 14:  {
                __THREW__ = 0;
                invoke_vii(1961,($__this|0),41);
                $314 = __THREW__; __THREW__ = 0;
                $315 = $314&1;
                if ($315) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 15:  {
                __THREW__ = 0;
                invoke_vii(1961,($__this|0),32);
                $316 = __THREW__; __THREW__ = 0;
                $317 = $316&1;
                if ($317) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $318 = __THREW__; __THREW__ = 0;
                $319 = $318&1;
                if ($319) {
                 break L4;
                }
                __THREW__ = 0;
                $320 = (invoke_ii(2024,($nfi|0))|0);
                $321 = __THREW__; __THREW__ = 0;
                $322 = $321&1;
                if ($322) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($320|0));
                $323 = __THREW__; __THREW__ = 0;
                $324 = $323&1;
                if ($324) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1961,($__this|0),41);
                $325 = __THREW__; __THREW__ = 0;
                $326 = $325&1;
                if ($326) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 5:  {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $231 = __THREW__; __THREW__ = 0;
                $232 = $231&1;
                if ($232) {
                 break L4;
                }
                __THREW__ = 0;
                $233 = (invoke_ii(2024,($nfi|0))|0);
                $234 = __THREW__; __THREW__ = 0;
                $235 = $234&1;
                if ($235) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($233|0));
                $236 = __THREW__; __THREW__ = 0;
                $237 = $236&1;
                if ($237) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 3:  {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $215 = __THREW__; __THREW__ = 0;
                $216 = $215&1;
                if ($216) {
                 break L4;
                }
                __THREW__ = 0;
                $217 = (invoke_ii(2029,($nfi|0))|0);
                $218 = __THREW__; __THREW__ = 0;
                $219 = $218&1;
                if ($219) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($217|0));
                $220 = __THREW__; __THREW__ = 0;
                $221 = $220&1;
                if ($221) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 7:  {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $252 = __THREW__; __THREW__ = 0;
                $253 = $252&1;
                if ($253) {
                 break L4;
                }
                __THREW__ = 0;
                $254 = (invoke_ii(2024,($nfi|0))|0);
                $255 = __THREW__; __THREW__ = 0;
                $256 = $255&1;
                if ($256) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($254|0));
                $257 = __THREW__; __THREW__ = 0;
                $258 = $257&1;
                if ($258) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $259 = __THREW__; __THREW__ = 0;
                $260 = $259&1;
                if ($260) {
                 break L4;
                }
                __THREW__ = 0;
                $261 = (invoke_ii(2029,($nfi|0))|0);
                $262 = __THREW__; __THREW__ = 0;
                $263 = $262&1;
                if ($263) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($261|0));
                $264 = __THREW__; __THREW__ = 0;
                $265 = $264&1;
                if ($265) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 4:  {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $222 = __THREW__; __THREW__ = 0;
                $223 = $222&1;
                if ($223) {
                 break L4;
                }
                __THREW__ = 0;
                $224 = (invoke_ii(2024,($nfi|0))|0);
                $225 = __THREW__; __THREW__ = 0;
                $226 = $225&1;
                if ($226) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($224|0));
                $227 = __THREW__; __THREW__ = 0;
                $228 = $227&1;
                if ($228) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1961,($__this|0),41);
                $229 = __THREW__; __THREW__ = 0;
                $230 = $229&1;
                if ($230) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 6:  {
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $238 = __THREW__; __THREW__ = 0;
                $239 = $238&1;
                if ($239) {
                 break L4;
                }
                __THREW__ = 0;
                $240 = (invoke_ii(2029,($nfi|0))|0);
                $241 = __THREW__; __THREW__ = 0;
                $242 = $241&1;
                if ($242) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($240|0));
                $243 = __THREW__; __THREW__ = 0;
                $244 = $243&1;
                if ($244) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $245 = __THREW__; __THREW__ = 0;
                $246 = $245&1;
                if ($246) {
                 break L4;
                }
                __THREW__ = 0;
                $247 = (invoke_ii(2024,($nfi|0))|0);
                $248 = __THREW__; __THREW__ = 0;
                $249 = $248&1;
                if ($249) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($247|0));
                $250 = __THREW__; __THREW__ = 0;
                $251 = $250&1;
                if ($251) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               case 8:  {
                __THREW__ = 0;
                invoke_vii(1961,($__this|0),32);
                $266 = __THREW__; __THREW__ = 0;
                $267 = $266&1;
                if ($267) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vi(3799,($nfi|0));
                $268 = __THREW__; __THREW__ = 0;
                $269 = $268&1;
                if ($269) {
                 break L4;
                }
                __THREW__ = 0;
                $270 = (invoke_ii(2024,($nfi|0))|0);
                $271 = __THREW__; __THREW__ = 0;
                $272 = $271&1;
                if ($272) {
                 break L4;
                }
                __THREW__ = 0;
                invoke_vii(1962,($__this|0),($270|0));
                $273 = __THREW__; __THREW__ = 0;
                $274 = $273&1;
                if ($274) {
                 break L4;
                } else {
                 break L90;
                }
                break;
               }
               default: {
                break L90;
               }
               }
              } while(0);
             }
            } else {
             __THREW__ = 0;
             invoke_vi(3799,($nfi|0));
             $185 = __THREW__; __THREW__ = 0;
             $186 = $185&1;
             if ($186) {
              break L4;
             }
             __THREW__ = 0;
             $187 = (invoke_ii(2023,($nfi|0))|0);
             $188 = __THREW__; __THREW__ = 0;
             $189 = $188&1;
             if ($189) {
              break L4;
             }
             if ((($187|0) == 1)) {
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $190 = __THREW__; __THREW__ = 0;
              $191 = $190&1;
              if ($191) {
               break L4;
              }
              __THREW__ = 0;
              $192 = (invoke_ii(2024,($nfi|0))|0);
              $193 = __THREW__; __THREW__ = 0;
              $194 = $193&1;
              if ($194) {
               break L4;
              }
              __THREW__ = 0;
              invoke_vii(1962,($__this|0),($192|0));
              $195 = __THREW__; __THREW__ = 0;
              $196 = $195&1;
              if ($196) {
               break L4;
              } else {
               break;
              }
             } else if (!((($187|0) == 3))) {
              break;
             }
             __THREW__ = 0;
             invoke_vii(1961,($__this|0),32);
             $197 = __THREW__; __THREW__ = 0;
             $198 = $197&1;
             if ($198) {
              break L4;
             }
             __THREW__ = 0;
             invoke_vi(3799,($nfi|0));
             $199 = __THREW__; __THREW__ = 0;
             $200 = $199&1;
             if ($200) {
              break L4;
             }
             __THREW__ = 0;
             $201 = (invoke_ii(2024,($nfi|0))|0);
             $202 = __THREW__; __THREW__ = 0;
             $203 = $202&1;
             if ($203) {
              break L4;
             }
             __THREW__ = 0;
             invoke_vii(1962,($__this|0),($201|0));
             $204 = __THREW__; __THREW__ = 0;
             $205 = $204&1;
             if ($205) {
              break L4;
             }
            }
           } while(0);
           $327 = (($__this) + 60|0);
           $328 = HEAP32[$327>>2]|0;
           $329 = (($__this) + 64|0);
           $330 = HEAP32[$329>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $331 = __THREW__; __THREW__ = 0;
           $332 = $331&1;
           if (!($332)) {
            __THREW__ = 0;
            $333 = (invoke_ii(3469,(2191608|0))|0);
            $334 = __THREW__; __THREW__ = 0;
            $335 = $334&1;
            if (!($335)) {
             __THREW__ = 0;
             $336 = (invoke_iiiii(104,($333|0),($328|0),0,($330|0))|0);
             $337 = __THREW__; __THREW__ = 0;
             $338 = $337&1;
             if (!($338)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($336|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_NumberFormatter_m_FormatDecimalP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo($__this,$precision,$nfi) {
 $__this = $__this|0;
 $precision = $precision|0;
 $nfi = $nfi|0;
 var $$0 = 0, $$precision = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2627984);
 __THREW__ = 0;
 invoke_v(912);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 32|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>($precision|0);
   $$precision = $4 ? $3 : $precision;
   $5 = ($$precision|0)==(0);
   if ($5) {
    $8 = HEAP32[3074456>>2]|0;
    $$0 = $8;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $9 = (($$precision) + 1)|0;
   __THREW__ = 0;
   invoke_vii(1959,($__this|0),($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (($__this) + 20|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if ($14) {
     __THREW__ = 0;
     invoke_vi(3799,($nfi|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(2029,($nfi|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1962,($__this|0),($17|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_viii(696,($__this|0),0,($$precision|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = (($__this) + 60|0);
     $25 = HEAP32[$24>>2]|0;
     $26 = (($__this) + 64|0);
     $27 = HEAP32[$26>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      __THREW__ = 0;
      $30 = (invoke_ii(3469,(2191608|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       $33 = (invoke_iiiii(104,($30|0),($25|0),0,($27|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $$0 = $33;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z143mscorlib_System_NumberFormatter_m_FormatExponential_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Globalization_NumberFormatInfoP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo($__this,$precision,$nfi) {
 $__this = $__this|0;
 $precision = $precision|0;
 $nfi = $nfi|0;
 var $$precision = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628368);
 $0 = ($precision|0)==(-1);
 $$precision = $0 ? 6 : $precision;
 $1 = (($$precision) + 1)|0;
 __THREW__ = 0;
 invoke_vii(1964,($__this|0),($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiiii(198,($__this|0),($$precision|0),($nfi|0),3)|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z50mscorlib_System_NumberFormatter_m_FormatFixedPointP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo($__this,$precision,$nfi) {
 $__this = $__this|0;
 $precision = $precision|0;
 $nfi = $nfi|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628080);
 $0 = ($precision|0)==(-1);
 if ($0) {
  __THREW__ = 0;
  invoke_vi(3799,($nfi|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2030,($nfi|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $$0 = $3;
    label = 4;
   }
  }
 } else {
  $$0 = $precision;
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   __THREW__ = 0;
   (invoke_iii(1149,($__this|0),($$0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_ii(2480,($__this|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($$0) + 2)|0;
     $12 = (($11) + ($8))|0;
     __THREW__ = 0;
     invoke_vii(1959,($__this|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = (($__this) + 20|0);
      $16 = HEAP8[$15>>0]|0;
      $17 = ($16<<24>>24)==(0);
      if ($17) {
       __THREW__ = 0;
       invoke_vi(3799,($nfi|0));
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       __THREW__ = 0;
       $22 = (invoke_ii(2029,($nfi|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(1962,($__this|0),($22|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
      }
      __THREW__ = 0;
      $27 = (invoke_ii(2480,($__this|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       __THREW__ = 0;
       invoke_vii(1965,($__this|0),($27|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if (!($31)) {
        $32 = ($$0|0)<(1);
        if (!($32)) {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
         __THREW__ = 0;
         $35 = (invoke_ii(2031,($nfi|0))|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($35|0));
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if ($39) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(1966,($__this|0),($$0|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break;
         }
        }
        $42 = (($__this) + 60|0);
        $43 = HEAP32[$42>>2]|0;
        $44 = (($__this) + 64|0);
        $45 = HEAP32[$44>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if (!($47)) {
         __THREW__ = 0;
         $48 = (invoke_ii(3469,(2191608|0))|0);
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if (!($50)) {
          __THREW__ = 0;
          $51 = (invoke_iiiii(104,($48|0),($43|0),0,($45|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($51|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_NumberFormatter_m_FormatNumberP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo($__this,$precision,$nfi) {
 $__this = $__this|0;
 $precision = $precision|0;
 $nfi = $nfi|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628272);
 $0 = ($precision|0)<(0);
 if ($0) {
  __THREW__ = 0;
  invoke_vi(3799,($nfi|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2030,($nfi|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $G_B3_0$0 = $3;
    label = 4;
   }
  }
 } else {
  $G_B3_0$0 = $precision;
  label = 4;
 }
 L4: do {
  if ((label|0) == 4) {
   __THREW__ = 0;
   $6 = (invoke_ii(2480,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6*3)|0;
    $10 = (($9) + ($G_B3_0$0))|0;
    __THREW__ = 0;
    invoke_vii(1959,($__this|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     (invoke_iii(1149,($__this|0),($G_B3_0$0|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = (($__this) + 20|0);
      $16 = HEAP8[$15>>0]|0;
      $17 = ($16<<24>>24)==(0);
      do {
       if ($17) {
        __THREW__ = 0;
        invoke_vi(3799,($nfi|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break L4;
        }
        __THREW__ = 0;
        $22 = (invoke_ii(2034,($nfi|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if ($24) {
         break L4;
        }
        if ((($22|0) == 0)) {
         __THREW__ = 0;
         invoke_vii(1961,($__this|0),40);
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if ($26) {
          break L4;
         } else {
          break;
         }
        } else if ((($22|0) == 2)) {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          break L4;
         }
         __THREW__ = 0;
         $36 = (invoke_ii(2029,($nfi|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($36|0));
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1961,($__this|0),32);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break L4;
         } else {
          break;
         }
        } else if ((($22|0) == 1)) {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          break L4;
         }
         __THREW__ = 0;
         $29 = (invoke_ii(2029,($nfi|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          break L4;
         }
         __THREW__ = 0;
         invoke_vii(1962,($__this|0),($29|0));
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break L4;
         } else {
          break;
         }
        } else {
         break;
        }
       }
      } while(0);
      __THREW__ = 0;
      invoke_vi(3799,($nfi|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       __THREW__ = 0;
       $45 = (invoke_ii(2033,($nfi|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        __THREW__ = 0;
        invoke_vi(3799,($nfi|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if (!($49)) {
         __THREW__ = 0;
         $50 = (invoke_ii(2032,($nfi|0))|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if (!($52)) {
          __THREW__ = 0;
          invoke_viii(694,($__this|0),($45|0),($50|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           $55 = ($G_B3_0$0|0)<(1);
           if (!($55)) {
            __THREW__ = 0;
            invoke_vi(3799,($nfi|0));
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             break;
            }
            __THREW__ = 0;
            $58 = (invoke_ii(2031,($nfi|0))|0);
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if ($60) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1962,($__this|0),($58|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1966,($__this|0),($G_B3_0$0|0));
            $63 = __THREW__; __THREW__ = 0;
            $64 = $63&1;
            if ($64) {
             break;
            }
           }
           $65 = HEAP8[$15>>0]|0;
           $66 = ($65<<24>>24)==(0);
           do {
            if ($66) {
             __THREW__ = 0;
             invoke_vi(3799,($nfi|0));
             $67 = __THREW__; __THREW__ = 0;
             $68 = $67&1;
             if ($68) {
              break L4;
             }
             __THREW__ = 0;
             $69 = (invoke_ii(2034,($nfi|0))|0);
             $70 = __THREW__; __THREW__ = 0;
             $71 = $70&1;
             if ($71) {
              break L4;
             }
             $72 = ($69|0)==(0);
             if ($72) {
              __THREW__ = 0;
              invoke_vii(1961,($__this|0),41);
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               break L4;
              } else {
               break;
              }
             }
             $$off = (($69) + -1)|0;
             $73 = ($$off>>>0)<(2);
             if (!($73)) {
              if ((($69|0) == 3)) {
               __THREW__ = 0;
               invoke_vi(3799,($nfi|0));
               $76 = __THREW__; __THREW__ = 0;
               $77 = $76&1;
               if ($77) {
                break L4;
               }
               __THREW__ = 0;
               $78 = (invoke_ii(2029,($nfi|0))|0);
               $79 = __THREW__; __THREW__ = 0;
               $80 = $79&1;
               if ($80) {
                break L4;
               }
               __THREW__ = 0;
               invoke_vii(1962,($__this|0),($78|0));
               $81 = __THREW__; __THREW__ = 0;
               $82 = $81&1;
               if ($82) {
                break L4;
               } else {
                break;
               }
              } else if (!((($69|0) == 4))) {
               break;
              }
              __THREW__ = 0;
              invoke_vii(1961,($__this|0),32);
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if ($84) {
               break L4;
              }
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $85 = __THREW__; __THREW__ = 0;
              $86 = $85&1;
              if ($86) {
               break L4;
              }
              __THREW__ = 0;
              $87 = (invoke_ii(2029,($nfi|0))|0);
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if ($89) {
               break L4;
              }
              __THREW__ = 0;
              invoke_vii(1962,($__this|0),($87|0));
              $90 = __THREW__; __THREW__ = 0;
              $91 = $90&1;
              if ($91) {
               break L4;
              }
             }
            }
           } while(0);
           $92 = (($__this) + 60|0);
           $93 = HEAP32[$92>>2]|0;
           $94 = (($__this) + 64|0);
           $95 = HEAP32[$94>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $96 = __THREW__; __THREW__ = 0;
           $97 = $96&1;
           if (!($97)) {
            __THREW__ = 0;
            $98 = (invoke_ii(3469,(2191608|0))|0);
            $99 = __THREW__; __THREW__ = 0;
            $100 = $99&1;
            if (!($100)) {
             __THREW__ = 0;
             $101 = (invoke_iiiii(104,($98|0),($93|0),0,($95|0))|0);
             $102 = __THREW__; __THREW__ = 0;
             $103 = $102&1;
             if (!($103)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($101|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z47mscorlib_System_NumberFormatter_m_FormatPercentP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo($__this,$precision,$nfi) {
 $__this = $__this|0;
 $precision = $precision|0;
 $nfi = $nfi|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628320);
 $0 = ($precision|0)<(0);
 if ($0) {
  __THREW__ = 0;
  invoke_vi(3799,($nfi|0));
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2035,($nfi|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $G_B3_0$0 = $3;
    label = 4;
   }
  }
 } else {
  $G_B3_0$0 = $precision;
  label = 4;
 }
 L4: do {
  if ((label|0) == 4) {
   __THREW__ = 0;
   invoke_vii(1968,($__this|0),2);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    (invoke_iii(1149,($__this|0),($G_B3_0$0|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_ii(2480,($__this|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = $10 << 1;
      $14 = (($G_B3_0$0) + 16)|0;
      $15 = (($14) + ($13))|0;
      __THREW__ = 0;
      invoke_vii(1959,($__this|0),($15|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = (($__this) + 20|0);
       $19 = HEAP8[$18>>0]|0;
       $20 = ($19<<24>>24)==(0);
       do {
        if ($20) {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break L4;
         }
         __THREW__ = 0;
         $38 = (invoke_ii(2039,($nfi|0))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break L4;
         }
         if ((($38|0) == 0)) {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $41 = __THREW__; __THREW__ = 0;
          $42 = $41&1;
          if ($42) {
           break L4;
          }
          __THREW__ = 0;
          $43 = (invoke_ii(2029,($nfi|0))|0);
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($43|0));
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break L4;
          } else {
           break;
          }
         } else if ((($38|0) == 1)) {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break L4;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(2029,($nfi|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($50|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if ($54) {
           break L4;
          } else {
           break;
          }
         } else if ((($38|0) == 2)) {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           break L4;
          }
          __THREW__ = 0;
          $57 = (invoke_ii(2029,($nfi|0))|0);
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if ($59) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($57|0));
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if ($61) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           break L4;
          }
          __THREW__ = 0;
          $64 = (invoke_ii(2041,($nfi|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($64|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           break L4;
          } else {
           break;
          }
         } else {
          break;
         }
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if ($24) {
          break L4;
         }
         __THREW__ = 0;
         $25 = (invoke_ii(2040,($nfi|0))|0);
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if ($27) {
          break L4;
         }
         $28 = ($25|0)==(2);
         if ($28) {
          __THREW__ = 0;
          invoke_vi(3799,($nfi|0));
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if ($30) {
           break L4;
          }
          __THREW__ = 0;
          $31 = (invoke_ii(2041,($nfi|0))|0);
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if ($33) {
           break L4;
          }
          __THREW__ = 0;
          invoke_vii(1962,($__this|0),($31|0));
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if ($35) {
           break L4;
          }
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($nfi|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if (!($70)) {
        __THREW__ = 0;
        $71 = (invoke_ii(2038,($nfi|0))|0);
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if (!($73)) {
         __THREW__ = 0;
         invoke_vi(3799,($nfi|0));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if (!($75)) {
          __THREW__ = 0;
          $76 = (invoke_ii(2037,($nfi|0))|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if (!($78)) {
           __THREW__ = 0;
           invoke_viii(694,($__this|0),($71|0),($76|0));
           $79 = __THREW__; __THREW__ = 0;
           $80 = $79&1;
           if (!($80)) {
            $81 = ($G_B3_0$0|0)<(1);
            if (!($81)) {
             __THREW__ = 0;
             invoke_vi(3799,($nfi|0));
             $82 = __THREW__; __THREW__ = 0;
             $83 = $82&1;
             if ($83) {
              break;
             }
             __THREW__ = 0;
             $84 = (invoke_ii(2036,($nfi|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if ($86) {
              break;
             }
             __THREW__ = 0;
             invoke_vii(1962,($__this|0),($84|0));
             $87 = __THREW__; __THREW__ = 0;
             $88 = $87&1;
             if ($88) {
              break;
             }
             __THREW__ = 0;
             invoke_vii(1966,($__this|0),($G_B3_0$0|0));
             $89 = __THREW__; __THREW__ = 0;
             $90 = $89&1;
             if ($90) {
              break;
             }
            }
            $91 = HEAP8[$18>>0]|0;
            $92 = ($91<<24>>24)==(0);
            do {
             if ($92) {
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $114 = __THREW__; __THREW__ = 0;
              $115 = $114&1;
              if ($115) {
               break L4;
              }
              __THREW__ = 0;
              $116 = (invoke_ii(2039,($nfi|0))|0);
              $117 = __THREW__; __THREW__ = 0;
              $118 = $117&1;
              if ($118) {
               break L4;
              }
              if ((($116|0) == 1)) {
               __THREW__ = 0;
               invoke_vi(3799,($nfi|0));
               $128 = __THREW__; __THREW__ = 0;
               $129 = $128&1;
               if ($129) {
                break L4;
               }
               __THREW__ = 0;
               $130 = (invoke_ii(2041,($nfi|0))|0);
               $131 = __THREW__; __THREW__ = 0;
               $132 = $131&1;
               if ($132) {
                break L4;
               }
               __THREW__ = 0;
               invoke_vii(1962,($__this|0),($130|0));
               $133 = __THREW__; __THREW__ = 0;
               $134 = $133&1;
               if ($134) {
                break L4;
               } else {
                break;
               }
              } else if (!((($116|0) == 0))) {
               break;
              }
              __THREW__ = 0;
              invoke_vii(1961,($__this|0),32);
              $119 = __THREW__; __THREW__ = 0;
              $120 = $119&1;
              if ($120) {
               break L4;
              }
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $121 = __THREW__; __THREW__ = 0;
              $122 = $121&1;
              if ($122) {
               break L4;
              }
              __THREW__ = 0;
              $123 = (invoke_ii(2041,($nfi|0))|0);
              $124 = __THREW__; __THREW__ = 0;
              $125 = $124&1;
              if ($125) {
               break L4;
              }
              __THREW__ = 0;
              invoke_vii(1962,($__this|0),($123|0));
              $126 = __THREW__; __THREW__ = 0;
              $127 = $126&1;
              if ($127) {
               break L4;
              }
             } else {
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $93 = __THREW__; __THREW__ = 0;
              $94 = $93&1;
              if ($94) {
               break L4;
              }
              __THREW__ = 0;
              $95 = (invoke_ii(2040,($nfi|0))|0);
              $96 = __THREW__; __THREW__ = 0;
              $97 = $96&1;
              if ($97) {
               break L4;
              }
              if ((($95|0) == 1)) {
               __THREW__ = 0;
               invoke_vi(3799,($nfi|0));
               $107 = __THREW__; __THREW__ = 0;
               $108 = $107&1;
               if ($108) {
                break L4;
               }
               __THREW__ = 0;
               $109 = (invoke_ii(2041,($nfi|0))|0);
               $110 = __THREW__; __THREW__ = 0;
               $111 = $110&1;
               if ($111) {
                break L4;
               }
               __THREW__ = 0;
               invoke_vii(1962,($__this|0),($109|0));
               $112 = __THREW__; __THREW__ = 0;
               $113 = $112&1;
               if ($113) {
                break L4;
               } else {
                break;
               }
              } else if (!((($95|0) == 0))) {
               break;
              }
              __THREW__ = 0;
              invoke_vii(1961,($__this|0),32);
              $98 = __THREW__; __THREW__ = 0;
              $99 = $98&1;
              if ($99) {
               break L4;
              }
              __THREW__ = 0;
              invoke_vi(3799,($nfi|0));
              $100 = __THREW__; __THREW__ = 0;
              $101 = $100&1;
              if ($101) {
               break L4;
              }
              __THREW__ = 0;
              $102 = (invoke_ii(2041,($nfi|0))|0);
              $103 = __THREW__; __THREW__ = 0;
              $104 = $103&1;
              if ($104) {
               break L4;
              }
              __THREW__ = 0;
              invoke_vii(1962,($__this|0),($102|0));
              $105 = __THREW__; __THREW__ = 0;
              $106 = $105&1;
              if ($106) {
               break L4;
              }
             }
            } while(0);
            $135 = (($__this) + 60|0);
            $136 = HEAP32[$135>>2]|0;
            $137 = (($__this) + 64|0);
            $138 = HEAP32[$137>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $139 = __THREW__; __THREW__ = 0;
            $140 = $139&1;
            if (!($140)) {
             __THREW__ = 0;
             $141 = (invoke_ii(3469,(2191608|0))|0);
             $142 = __THREW__; __THREW__ = 0;
             $143 = $142&1;
             if (!($143)) {
              __THREW__ = 0;
              $144 = (invoke_iiiii(104,($141|0),($136|0),0,($138|0))|0);
              $145 = __THREW__; __THREW__ = 0;
              $146 = $145&1;
              if (!($146)) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($144|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z51mscorlib_System_NumberFormatter_m_FormatHexadecimalP31mscorlib_System_NumberFormatteri($__this,$precision) {
 $__this = $__this|0;
 $precision = $precision|0;
 var $$lcssa = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $G_B3_0$0 = 0, $G_B3_0$0$in$in = 0, $V_0$011 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628032);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiii(1197,0,($precision|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   $5 = (($__this) + 19|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    $28 = HEAP8[((2633856 + 116|0))>>0]|0;
    $29 = ($28<<24>>24)==(0);
    if ($29) {
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2633856|0));
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    $38 = HEAP32[((2633856 + 80|0))>>2]|0;
    $39 = (($38) + 8|0);
    $G_B3_0$0$in$in = $39;
   } else {
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP8[((2633856 + 116|0))>>0]|0;
    $15 = ($14<<24>>24)==(0);
    if ($15) {
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2633856|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3839,(2633856|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2633856|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = HEAP32[((2633856 + 80|0))>>2]|0;
    $25 = (($24) + 12|0);
    $G_B3_0$0$in$in = $25;
   }
   $G_B3_0$0 = HEAP32[$G_B3_0$0$in$in>>2]|0;
   __THREW__ = 0;
   invoke_vii(1959,($__this|0),($2|0));
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    $42 = (($__this) + 64|0);
    HEAP32[$42>>2] = $2;
    $43 = ($2|0)>(0);
    $44 = (($__this) + 60|0);
    $45 = HEAP32[$44>>2]|0;
    do {
     if ($43) {
      $46 = (($__this) + 48|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = (($__this) + 44|0);
      $49 = HEAP32[$48>>2]|0;
      $51 = $45;$67 = $49;$68 = $47;$V_0$011 = $2;
      while(1) {
       $54 = (($V_0$011) + -1)|0;
       $73 = (_bitshift64Shl(($67|0),($68|0),1)|0);
       $74 = tempRet0;
       $75 = $73 & 30;
       $76 = (($G_B3_0$0) + ($75)|0);
       $66 = HEAP16[$76>>1]|0;
       __THREW__ = 0;
       invoke_vi(3799,($51|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        break;
       }
       $50 = (($51) + 12|0);
       $52 = HEAP32[$50>>2]|0;
       $53 = ($54>>>0)<($52>>>0);
       if (!($53)) {
        __THREW__ = 0;
        $55 = (invoke_i(132)|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($55|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         break;
        }
       }
       $60 = HEAP32[$51>>2]|0;
       $61 = (($51) + 16|0);
       $62 = (($60) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $54)|0;
       $65 = (($61) + ($64)|0);
       HEAP16[$65>>1] = $66;
       $69 = (_bitshift64Lshr(($67|0),($68|0),4)|0);
       $70 = tempRet0;
       $71 = ($54|0)>(0);
       $72 = HEAP32[$44>>2]|0;
       if ($71) {
        $51 = $72;$67 = $69;$68 = $70;$V_0$011 = $54;
       } else {
        label = 28;
        break;
       }
      }
      if ((label|0) == 28) {
       $$pre = HEAP32[$42>>2]|0;
       $$lcssa = $72;$84 = $$pre;
       break;
      }
      $8 = ___cxa_find_matching_catch()|0;
      $9 = tempRet0;
      $lpad$phi$index = $8;$lpad$phi$index2 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     } else {
      $$lcssa = $45;$84 = $2;
     }
    } while(0);
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if (!($80)) {
     __THREW__ = 0;
     $81 = (invoke_ii(3469,(2191608|0))|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if (!($83)) {
      __THREW__ = 0;
      $85 = (invoke_iiiii(104,($81|0),($$lcssa|0),0,($84|0))|0);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if (!($87)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($85|0);
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z46mscorlib_System_NumberFormatter_m_FormatCustomP31mscorlib_System_NumberFormatterP22mscorlib_System_StringP46mscorlib_System_Globalization_NumberFormatInfo($__this,$format,$nfi) {
 $__this = $__this|0;
 $format = $format|0;
 $nfi = $nfi|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B22_0$0 = 0, $G_B8_0$0 = 0, $V_0 = 0;
 var $V_1 = 0, $V_2 = 0, $V_7$0 = 0, $V_8$0$off0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp + 12|0;
 $V_1 = sp + 4|0;
 $V_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628464);
 HEAP8[$V_0>>0] = 0;
 HEAP32[$V_1>>2] = 0;
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(913);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = (($__this) + 20|0);
   $3 = HEAP8[$2>>0]|0;
   HEAP8[$V_0>>0] = $3;
   HEAP32[$V_1>>2] = 0;
   HEAP32[$V_2>>2] = 0;
   __THREW__ = 0;
   $4 = (invoke_ii(2483,($__this|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_viiiiii(66,0,($format|0),($V_0|0),($4|0),($V_1|0),($V_2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[$V_2>>2]|0;
     $10 = ($9|0)==(0);
     if ($10) {
      $17 = HEAP8[$2>>0]|0;
      $18 = ($17<<24>>24)==(0);
      if ($18) {
       __THREW__ = 0;
       invoke_vi(3799,($nfi|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if ($34) {
        break;
       }
       __THREW__ = 0;
       $35 = (invoke_ii(2029,($nfi|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       } else {
        $$0 = $35;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP8[((2191608 + 116|0))>>0]|0;
      $22 = ($21<<24>>24)==(0);
      if ($22) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3839,(2191608|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $31 = HEAP32[((2191608 + 80|0))>>2]|0;
      $32 = HEAP32[$31>>2]|0;
      $$0 = $32;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $38 = HEAP8[$V_0>>0]|0;
     HEAP8[$2>>0] = $38;
     $39 = HEAP32[$V_1>>2]|0;
     __THREW__ = 0;
     $40 = (invoke_iiiiii(132,0,($format|0),($39|0),($9|0),0)|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      __THREW__ = 0;
      invoke_vi(3799,($40|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       $45 = (($40) + 24|0);
       $46 = HEAP32[$45>>2]|0;
       $47 = $46 << 1;
       __THREW__ = 0;
       (invoke_ii(2996,(2537888|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if (!($49)) {
        __THREW__ = 0;
        $50 = (invoke_ii(3469,(2537888|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if (!($52)) {
         __THREW__ = 0;
         invoke_vii(1910,($50|0),($47|0));
         $53 = __THREW__; __THREW__ = 0;
         $54 = $53&1;
         if (!($54)) {
          __THREW__ = 0;
          invoke_vi(3799,($40|0));
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if (!($56)) {
           $57 = (($40) + 12|0);
           $58 = HEAP32[$57>>2]|0;
           $59 = $58 << 1;
           __THREW__ = 0;
           (invoke_ii(2996,(2537888|0))|0);
           $60 = __THREW__; __THREW__ = 0;
           $61 = $60&1;
           if (!($61)) {
            __THREW__ = 0;
            $62 = (invoke_ii(3469,(2537888|0))|0);
            $63 = __THREW__; __THREW__ = 0;
            $64 = $63&1;
            if (!($64)) {
             __THREW__ = 0;
             invoke_vii(1910,($62|0),($59|0));
             $65 = __THREW__; __THREW__ = 0;
             $66 = $65&1;
             if (!($66)) {
              __THREW__ = 0;
              invoke_vi(3799,($40|0));
              $67 = __THREW__; __THREW__ = 0;
              $68 = $67&1;
              if (!($68)) {
               $69 = (($40) + 36|0);
               $70 = HEAP8[$69>>0]|0;
               $71 = ($70<<24>>24)==(0);
               if ($71) {
                $G_B8_0$0 = 0;
               } else {
                __THREW__ = 0;
                invoke_vi(3799,($40|0));
                $72 = __THREW__; __THREW__ = 0;
                $73 = $72&1;
                if ($73) {
                 break;
                }
                $74 = (($40) + 40|0);
                $75 = HEAP32[$74>>2]|0;
                $76 = $75 << 1;
                __THREW__ = 0;
                (invoke_ii(2996,(2537888|0))|0);
                $77 = __THREW__; __THREW__ = 0;
                $78 = $77&1;
                if ($78) {
                 break;
                }
                __THREW__ = 0;
                $79 = (invoke_ii(3469,(2537888|0))|0);
                $80 = __THREW__; __THREW__ = 0;
                $81 = $80&1;
                if ($81) {
                 break;
                }
                __THREW__ = 0;
                invoke_vii(1910,($79|0),($76|0));
                $82 = __THREW__; __THREW__ = 0;
                $83 = $82&1;
                if ($83) {
                 break;
                } else {
                 $G_B8_0$0 = $79;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($40|0));
               $84 = __THREW__; __THREW__ = 0;
               $85 = $84&1;
               if (!($85)) {
                $86 = (($40) + 56|0);
                $87 = HEAP32[$86>>2]|0;
                $88 = ($87|0)<(1);
                if (!($88)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($40|0));
                 $89 = __THREW__; __THREW__ = 0;
                 $90 = $89&1;
                 if ($90) {
                  break;
                 }
                 $91 = HEAP32[$86>>2]|0;
                 $92 = $91 << 1;
                 __THREW__ = 0;
                 invoke_vii(1968,($__this|0),($92|0));
                 $93 = __THREW__; __THREW__ = 0;
                 $94 = $93&1;
                 if ($94) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vi(3799,($40|0));
                $95 = __THREW__; __THREW__ = 0;
                $96 = $95&1;
                if (!($96)) {
                 $97 = (($40) + 60|0);
                 $98 = HEAP32[$97>>2]|0;
                 $99 = ($98|0)<(1);
                 if (!($99)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($40|0));
                  $100 = __THREW__; __THREW__ = 0;
                  $101 = $100&1;
                  if ($101) {
                   break;
                  }
                  $102 = HEAP32[$97>>2]|0;
                  $103 = ($102*3)|0;
                  __THREW__ = 0;
                  invoke_vii(1968,($__this|0),($103|0));
                  $104 = __THREW__; __THREW__ = 0;
                  $105 = $104&1;
                  if ($105) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($40|0));
                 $106 = __THREW__; __THREW__ = 0;
                 $107 = $106&1;
                 if ($107) {
                  break;
                 }
                 $108 = (($40) + 52|0);
                 $109 = HEAP32[$108>>2]|0;
                 $110 = ($109|0)<(1);
                 if (!($110)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($40|0));
                  $111 = __THREW__; __THREW__ = 0;
                  $112 = $111&1;
                  if ($112) {
                   break;
                  }
                  $113 = HEAP32[$108>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(1969,($__this|0),($113|0));
                  $114 = __THREW__; __THREW__ = 0;
                  $115 = $114&1;
                  if ($115) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($40|0));
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 $118 = HEAP8[$69>>0]|0;
                 $119 = ($118<<24>>24)==(0);
                 do {
                  if ($119) {
                   label = 61;
                  } else {
                   __THREW__ = 0;
                   invoke_vi(3799,($40|0));
                   $120 = __THREW__; __THREW__ = 0;
                   $121 = $120&1;
                   if ($121) {
                    break L1;
                   }
                   $122 = HEAP32[$57>>2]|0;
                   $123 = ($122|0)>(0);
                   if (!($123)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $124 = __THREW__; __THREW__ = 0;
                    $125 = $124&1;
                    if ($125) {
                     break L1;
                    }
                    $126 = HEAP32[$45>>2]|0;
                    $127 = ($126|0)<(1);
                    if ($127) {
                     label = 61;
                     break;
                    }
                   }
                   __THREW__ = 0;
                   $128 = (invoke_ii(2483,($__this|0))|0);
                   $129 = __THREW__; __THREW__ = 0;
                   $130 = $129&1;
                   if ($130) {
                    break L1;
                   }
                   if ($128) {
                    $V_7$0 = 0;
                   } else {
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $131 = __THREW__; __THREW__ = 0;
                    $132 = $131&1;
                    if ($132) {
                     break L1;
                    }
                    $133 = HEAP32[$57>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $134 = __THREW__; __THREW__ = 0;
                    $135 = $134&1;
                    if ($135) {
                     break L1;
                    }
                    $136 = HEAP32[$45>>2]|0;
                    $137 = (($136) + ($133))|0;
                    __THREW__ = 0;
                    invoke_vii(1964,($__this|0),($137|0));
                    $138 = __THREW__; __THREW__ = 0;
                    $139 = $138&1;
                    if ($139) {
                     break L1;
                    }
                    $140 = (($__this) + 40|0);
                    $141 = HEAP32[$140>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $142 = __THREW__; __THREW__ = 0;
                    $143 = $142&1;
                    if ($143) {
                     break L1;
                    }
                    $144 = HEAP32[$45>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $145 = __THREW__; __THREW__ = 0;
                    $146 = $145&1;
                    if ($146) {
                     break L1;
                    }
                    $147 = (($144) - ($141))|0;
                    $148 = HEAP32[$45>>2]|0;
                    HEAP32[$140>>2] = $148;
                    $V_7$0 = $147;
                   }
                   $149 = ($V_7$0|0)<(1);
                   $150 = ($V_7$0|0)>(-1);
                   $151 = (0 - ($V_7$0))|0;
                   $G_B22_0$0 = $150 ? $V_7$0 : $151;
                   __THREW__ = 0;
                   invoke_viii(691,0,($G_B8_0$0|0),($G_B22_0$0|0));
                   $152 = __THREW__; __THREW__ = 0;
                   $153 = $152&1;
                   if ($153) {
                    break L1;
                   } else {
                    $V_8$0$off0 = $149;
                   }
                  }
                 } while(0);
                 if ((label|0) == 61) {
                  __THREW__ = 0;
                  invoke_vi(3799,($40|0));
                  $154 = __THREW__; __THREW__ = 0;
                  $155 = $154&1;
                  if ($155) {
                   break;
                  }
                  $156 = HEAP32[$57>>2]|0;
                  __THREW__ = 0;
                  (invoke_iii(1149,($__this|0),($156|0))|0);
                  $157 = __THREW__; __THREW__ = 0;
                  $158 = $157&1;
                  if ($158) {
                   break;
                  } else {
                   $V_8$0$off0 = 1;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($40|0));
                 $159 = __THREW__; __THREW__ = 0;
                 $160 = $159&1;
                 if ($160) {
                  break;
                 }
                 $161 = HEAP32[$45>>2]|0;
                 $162 = ($161|0)==(0);
                 if ($162) {
                  __THREW__ = 0;
                  $163 = (invoke_ii(2484,($__this|0))|0);
                  $164 = __THREW__; __THREW__ = 0;
                  $165 = $164&1;
                  if ($165) {
                   break;
                  }
                  if (!($163)) {
                   label = 67;
                  }
                 } else {
                  label = 67;
                 }
                 if ((label|0) == 67) {
                  __THREW__ = 0;
                  $166 = (invoke_ii(2480,($__this|0))|0);
                  $167 = __THREW__; __THREW__ = 0;
                  $168 = $167&1;
                  if ($168) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(692,($__this|0),($166|0),($50|0));
                  $169 = __THREW__; __THREW__ = 0;
                  $170 = $169&1;
                  if ($170) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 $171 = (invoke_ii(2481,($__this|0))|0);
                 $172 = __THREW__; __THREW__ = 0;
                 $173 = $172&1;
                 if ($173) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viii(693,($__this|0),($171|0),($62|0));
                 $174 = __THREW__; __THREW__ = 0;
                 $175 = $174&1;
                 if ($175) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($40|0));
                 $176 = __THREW__; __THREW__ = 0;
                 $177 = $176&1;
                 if ($177) {
                  break;
                 }
                 $178 = HEAP8[$69>>0]|0;
                 $179 = ($178<<24>>24)==(0);
                 do {
                  if ($179) {
                   __THREW__ = 0;
                   invoke_vi(3799,($50|0));
                   $253 = __THREW__; __THREW__ = 0;
                   $254 = $253&1;
                   if ($254) {
                    break L1;
                   }
                   __THREW__ = 0;
                   $255 = (invoke_ii(2398,($50|0))|0);
                   $256 = __THREW__; __THREW__ = 0;
                   $257 = $256&1;
                   if ($257) {
                    break L1;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($40|0));
                   $258 = __THREW__; __THREW__ = 0;
                   $259 = $258&1;
                   if ($259) {
                    break L1;
                   }
                   $260 = HEAP32[$45>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($40|0));
                   $261 = __THREW__; __THREW__ = 0;
                   $262 = $261&1;
                   if ($262) {
                    break L1;
                   }
                   $263 = (($40) + 28|0);
                   $264 = HEAP32[$263>>2]|0;
                   $265 = (($260) - ($264))|0;
                   $266 = ($255|0)<($265|0);
                   if ($266) {
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $267 = __THREW__; __THREW__ = 0;
                    $268 = $267&1;
                    if ($268) {
                     break L1;
                    }
                    $269 = HEAP32[$45>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $270 = __THREW__; __THREW__ = 0;
                    $271 = $270&1;
                    if ($271) {
                     break L1;
                    }
                    $272 = HEAP32[$263>>2]|0;
                    $273 = (($269) - ($272))|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($50|0));
                    $274 = __THREW__; __THREW__ = 0;
                    $275 = $274&1;
                    if ($275) {
                     break L1;
                    }
                    __THREW__ = 0;
                    $276 = (invoke_ii(2398,($50|0))|0);
                    $277 = __THREW__; __THREW__ = 0;
                    $278 = $277&1;
                    if ($278) {
                     break L1;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($50|0));
                    $279 = __THREW__; __THREW__ = 0;
                    $280 = $279&1;
                    if ($280) {
                     break L1;
                    }
                    $281 = (($273) - ($276))|0;
                    $282 = HEAP32[3074480>>2]|0;
                    __THREW__ = 0;
                    (invoke_iiiii(164,($50|0),0,($282|0),($281|0))|0);
                    $283 = __THREW__; __THREW__ = 0;
                    $284 = $283&1;
                    if ($284) {
                     break L1;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($40|0));
                   $285 = __THREW__; __THREW__ = 0;
                   $286 = $285&1;
                   if ($286) {
                    break L1;
                   }
                   $287 = HEAP32[$45>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($40|0));
                   $288 = __THREW__; __THREW__ = 0;
                   $289 = $288&1;
                   if ($289) {
                    break L1;
                   }
                   $290 = HEAP32[$263>>2]|0;
                   $291 = ($287|0)==($290|0);
                   if (!($291)) {
                    break;
                   }
                   __THREW__ = 0;
                   $292 = (invoke_iii(1154,0,($50|0))|0);
                   $293 = __THREW__; __THREW__ = 0;
                   $294 = $293&1;
                   if ($294) {
                    break L1;
                   }
                   if (!($292)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($50|0));
                   $295 = __THREW__; __THREW__ = 0;
                   $296 = $295&1;
                   if ($296) {
                    break L1;
                   }
                   __THREW__ = 0;
                   $297 = (invoke_ii(2398,($50|0))|0);
                   $298 = __THREW__; __THREW__ = 0;
                   $299 = $298&1;
                   if ($299) {
                    break L1;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($50|0));
                   $300 = __THREW__; __THREW__ = 0;
                   $301 = $300&1;
                   if ($301) {
                    break L1;
                   }
                   __THREW__ = 0;
                   (invoke_iiii(929,($50|0),0,($297|0))|0);
                   $302 = __THREW__; __THREW__ = 0;
                   $303 = $302&1;
                   if ($303) {
                    break L1;
                   }
                  } else {
                   __THREW__ = 0;
                   invoke_vi(3799,($40|0));
                   $180 = __THREW__; __THREW__ = 0;
                   $181 = $180&1;
                   if ($181) {
                    break L1;
                   }
                   $182 = HEAP32[$57>>2]|0;
                   $183 = ($182|0)>(0);
                   do {
                    if (!($183)) {
                     __THREW__ = 0;
                     invoke_vi(3799,($40|0));
                     $184 = __THREW__; __THREW__ = 0;
                     $185 = $184&1;
                     if ($185) {
                      break L1;
                     }
                     $186 = HEAP32[$45>>2]|0;
                     $187 = ($186|0)>(0);
                     if ($187) {
                      break;
                     }
                     HEAP8[$2>>0] = 1;
                    }
                   } while(0);
                   __THREW__ = 0;
                   invoke_vi(3799,($50|0));
                   $188 = __THREW__; __THREW__ = 0;
                   $189 = $188&1;
                   if ($189) {
                    break L1;
                   }
                   __THREW__ = 0;
                   $190 = (invoke_ii(2398,($50|0))|0);
                   $191 = __THREW__; __THREW__ = 0;
                   $192 = $191&1;
                   if ($192) {
                    break L1;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($40|0));
                   $193 = __THREW__; __THREW__ = 0;
                   $194 = $193&1;
                   if ($194) {
                    break L1;
                   }
                   $195 = HEAP32[$45>>2]|0;
                   $196 = ($190|0)<($195|0);
                   if ($196) {
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $197 = __THREW__; __THREW__ = 0;
                    $198 = $197&1;
                    if ($198) {
                     break L1;
                    }
                    $199 = HEAP32[$45>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($50|0));
                    $200 = __THREW__; __THREW__ = 0;
                    $201 = $200&1;
                    if ($201) {
                     break L1;
                    }
                    __THREW__ = 0;
                    $202 = (invoke_ii(2398,($50|0))|0);
                    $203 = __THREW__; __THREW__ = 0;
                    $204 = $203&1;
                    if ($204) {
                     break L1;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($50|0));
                    $205 = __THREW__; __THREW__ = 0;
                    $206 = $205&1;
                    if ($206) {
                     break L1;
                    }
                    $207 = (($199) - ($202))|0;
                    $208 = HEAP32[3074472>>2]|0;
                    __THREW__ = 0;
                    (invoke_iiiii(164,($50|0),0,($208|0),($207|0))|0);
                    $209 = __THREW__; __THREW__ = 0;
                    $210 = $209&1;
                    if ($210) {
                     break L1;
                    }
                   }
                   $211 = (($40) + 40|0);
                   $212 = (($40) + 44|0);
                   while(1) {
                    __THREW__ = 0;
                    invoke_vi(3799,($G_B8_0$0|0));
                    $215 = __THREW__; __THREW__ = 0;
                    $216 = $215&1;
                    if ($216) {
                     label = 6;
                     break;
                    }
                    __THREW__ = 0;
                    $217 = (invoke_ii(2398,($G_B8_0$0|0))|0);
                    $218 = __THREW__; __THREW__ = 0;
                    $219 = $218&1;
                    if ($219) {
                     label = 6;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $220 = __THREW__; __THREW__ = 0;
                    $221 = $220&1;
                    if ($221) {
                     label = 6;
                     break;
                    }
                    $222 = HEAP32[$211>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($40|0));
                    $223 = __THREW__; __THREW__ = 0;
                    $224 = $223&1;
                    if ($224) {
                     label = 6;
                     break;
                    }
                    $225 = HEAP32[$212>>2]|0;
                    $226 = (($222) - ($225))|0;
                    $227 = ($217|0)<($226|0);
                    if (!($227)) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($G_B8_0$0|0));
                    $228 = __THREW__; __THREW__ = 0;
                    $229 = $228&1;
                    if ($229) {
                     label = 6;
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_iiii(936,($G_B8_0$0|0),0,48)|0);
                    $213 = __THREW__; __THREW__ = 0;
                    $214 = $213&1;
                    if ($214) {
                     label = 6;
                     break;
                    }
                   }
                   if ((label|0) == 6) {
                    $13 = ___cxa_find_matching_catch()|0;
                    $14 = tempRet0;
                    $lpad$phi$index = $13;$lpad$phi$index3 = $14;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($lpad$phi$index|0);
                    // unreachable;
                   }
                   if (!($V_8$0$off0)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($nfi|0));
                    $244 = __THREW__; __THREW__ = 0;
                    $245 = $244&1;
                    if ($245) {
                     break L1;
                    }
                    __THREW__ = 0;
                    $246 = (invoke_ii(2029,($nfi|0))|0);
                    $247 = __THREW__; __THREW__ = 0;
                    $248 = $247&1;
                    if ($248) {
                     break L1;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($G_B8_0$0|0));
                    $249 = __THREW__; __THREW__ = 0;
                    $250 = $249&1;
                    if ($250) {
                     break L1;
                    }
                    __THREW__ = 0;
                    (invoke_iiii(935,($G_B8_0$0|0),0,($246|0))|0);
                    $251 = __THREW__; __THREW__ = 0;
                    $252 = $251&1;
                    if ($252) {
                     break L1;
                    } else {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($40|0));
                   $230 = __THREW__; __THREW__ = 0;
                   $231 = $230&1;
                   if ($231) {
                    break L1;
                   }
                   $232 = (($40) + 48|0);
                   $233 = HEAP8[$232>>0]|0;
                   $234 = ($233<<24>>24)==(0);
                   if (!($234)) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($nfi|0));
                   $235 = __THREW__; __THREW__ = 0;
                   $236 = $235&1;
                   if ($236) {
                    break L1;
                   }
                   __THREW__ = 0;
                   $237 = (invoke_ii(2044,($nfi|0))|0);
                   $238 = __THREW__; __THREW__ = 0;
                   $239 = $238&1;
                   if ($239) {
                    break L1;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($G_B8_0$0|0));
                   $240 = __THREW__; __THREW__ = 0;
                   $241 = $240&1;
                   if ($241) {
                    break L1;
                   }
                   __THREW__ = 0;
                   (invoke_iiii(935,($G_B8_0$0|0),0,($237|0))|0);
                   $242 = __THREW__; __THREW__ = 0;
                   $243 = $242&1;
                   if ($243) {
                    break L1;
                   }
                  }
                 } while(0);
                 __THREW__ = 0;
                 invoke_viii(690,0,($62|0),1);
                 $304 = __THREW__; __THREW__ = 0;
                 $305 = $304&1;
                 if ($305) {
                  break;
                 }
                 $306 = (($40) + 20|0);
                 while(1) {
                  __THREW__ = 0;
                  invoke_vi(3799,($62|0));
                  $309 = __THREW__; __THREW__ = 0;
                  $310 = $309&1;
                  if ($310) {
                   label = 5;
                   break;
                  }
                  __THREW__ = 0;
                  $311 = (invoke_ii(2398,($62|0))|0);
                  $312 = __THREW__; __THREW__ = 0;
                  $313 = $312&1;
                  if ($313) {
                   label = 5;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($40|0));
                  $314 = __THREW__; __THREW__ = 0;
                  $315 = $314&1;
                  if ($315) {
                   label = 5;
                   break;
                  }
                  $316 = HEAP32[$57>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($40|0));
                  $317 = __THREW__; __THREW__ = 0;
                  $318 = $317&1;
                  if ($318) {
                   label = 5;
                   break;
                  }
                  $319 = HEAP32[$306>>2]|0;
                  $320 = (($316) - ($319))|0;
                  $321 = ($311|0)<($320|0);
                  if (!($321)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($62|0));
                  $322 = __THREW__; __THREW__ = 0;
                  $323 = $322&1;
                  if ($323) {
                   label = 5;
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(992,($62|0),48)|0);
                  $307 = __THREW__; __THREW__ = 0;
                  $308 = $307&1;
                  if ($308) {
                   label = 5;
                   break;
                  }
                 }
                 if ((label|0) == 5) {
                  $11 = ___cxa_find_matching_catch()|0;
                  $12 = tempRet0;
                  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($lpad$phi$index|0);
                  // unreachable;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($62|0));
                 $324 = __THREW__; __THREW__ = 0;
                 $325 = $324&1;
                 if ($325) {
                  break;
                 }
                 __THREW__ = 0;
                 $326 = (invoke_ii(2398,($62|0))|0);
                 $327 = __THREW__; __THREW__ = 0;
                 $328 = $327&1;
                 if ($328) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($40|0));
                 $329 = __THREW__; __THREW__ = 0;
                 $330 = $329&1;
                 if ($330) {
                  break;
                 }
                 $331 = HEAP32[$57>>2]|0;
                 $332 = ($326|0)>($331|0);
                 if ($332) {
                  __THREW__ = 0;
                  invoke_vi(3799,($40|0));
                  $333 = __THREW__; __THREW__ = 0;
                  $334 = $333&1;
                  if ($334) {
                   break;
                  }
                  $335 = HEAP32[$57>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($62|0));
                  $336 = __THREW__; __THREW__ = 0;
                  $337 = $336&1;
                  if ($337) {
                   break;
                  }
                  __THREW__ = 0;
                  $338 = (invoke_ii(2398,($62|0))|0);
                  $339 = __THREW__; __THREW__ = 0;
                  $340 = $339&1;
                  if ($340) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($40|0));
                  $341 = __THREW__; __THREW__ = 0;
                  $342 = $341&1;
                  if ($342) {
                   break;
                  }
                  $343 = HEAP32[$57>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($62|0));
                  $344 = __THREW__; __THREW__ = 0;
                  $345 = $344&1;
                  if ($345) {
                   break;
                  }
                  $346 = (($338) - ($343))|0;
                  __THREW__ = 0;
                  (invoke_iiii(929,($62|0),($335|0),($346|0))|0);
                  $347 = __THREW__; __THREW__ = 0;
                  $348 = $347&1;
                  if ($348) {
                   break;
                  }
                 }
                 $349 = HEAP8[$2>>0]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($40|0));
                 $350 = __THREW__; __THREW__ = 0;
                 $351 = $350&1;
                 if ($351) {
                  break;
                 }
                 $352 = ($349<<24>>24)!=(0);
                 __THREW__ = 0;
                 $353 = (invoke_iiiiiiiiii(13,($40|0),($format|0),($39|0),($9|0),($nfi|0),($352|0),($50|0),($62|0),($G_B8_0$0|0))|0);
                 $354 = __THREW__; __THREW__ = 0;
                 $355 = $354&1;
                 if ($355) {
                  break;
                 } else {
                  $$0 = $353;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_NumberFormatter_m_AppendIntegerStringWithGroupSeparatorP31mscorlib_System_NumberFormatterP25mscorlib_System_Int32_arrP22mscorlib_System_String($__this,$groups,$groupSeparator) {
 $__this = $__this|0;
 $groups = $groups|0;
 $groupSeparator = $groupSeparator|0;
 var $$ = 0, $$lcssa26 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B13_0$0 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_1$0 = 0, $V_1$0$phi = 0, $V_1$1$lcssa = 0, $V_1$128 = 0;
 var $V_1$2 = 0, $V_1$24 = 0, $V_1$4 = 0, $V_1$4$ph = 0, $V_1$4$ph9 = 0, $V_2$0 = 0, $V_3$1 = 0, $V_3$1$ph = 0, $V_3$1$ph8 = 0, $V_4$0 = 0, $V_4$0$ = 0, $V_4$03 = 0, $V_4$2$ph = 0, $V_4$2$ph7 = 0, $V_6$0 = 0, $V_6$0$ph = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $or$cond = 0;
 var $or$cond2 = 0, $or$cond6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628848);
 __THREW__ = 0;
 $0 = (invoke_ii(2484,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    __THREW__ = 0;
    invoke_vii(1961,($__this|0),48);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $3 = (($groups) + 12|0);
   $4 = (($groups) + 16|0);
   $5 = (($__this) + 40|0);
   $V_0$0 = 0;$V_1$0 = 0;$V_2$0 = 0;
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($groups|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 7;
     break;
    }
    $37 = HEAP32[$3>>2]|0;
    $38 = ($V_2$0|0)<($37|0);
    if (!($38)) {
     $V_0$1 = $V_0$0;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($groups|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     label = 7;
     break;
    }
    $18 = HEAP32[$3>>2]|0;
    $19 = ($V_2$0>>>0)<($18>>>0);
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_i(132)|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      label = 7;
      break;
     }
    }
    $25 = HEAP32[$groups>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $V_2$0)|0;
    $29 = (($4) + ($28)|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + ($V_0$0))|0;
    $32 = HEAP32[$5>>2]|0;
    $33 = ($31|0)>($32|0);
    $34 = (($V_2$0) + 1)|0;
    if ($33) {
     $V_0$1 = $31;
     break;
    } else {
     $V_1$0$phi = $V_2$0;$V_0$0 = $31;$V_2$0 = $34;$V_1$0 = $V_1$0$phi;
    }
   }
   if ((label|0) == 7) {
    $12 = ___cxa_find_matching_catch()|0;
    $13 = tempRet0;
    $lpad$phi$index = $12;$lpad$phi$index5 = $13;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($groups|0));
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if (!($42)) {
    $43 = HEAP32[$3>>2]|0;
    $44 = ($43|0)<(1);
    $45 = ($V_0$1|0)<(1);
    $or$cond2 = $44 | $45;
    if ($or$cond2) {
     $145 = (($__this) + 32|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = HEAP32[$5>>2]|0;
     $148 = (($146) - ($147))|0;
     __THREW__ = 0;
     invoke_viii(696,($__this|0),($148|0),($146|0));
     $149 = __THREW__; __THREW__ = 0;
     $150 = $149&1;
     if ($150) {
      break;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    invoke_vi(3799,($groups|0));
    $46 = __THREW__; __THREW__ = 0;
    $47 = $46&1;
    if (!($47)) {
     $48 = ($V_1$0|0)<(0);
     if ($48) {
      label = 23;
     } else {
      $49 = HEAP32[$3>>2]|0;
      $50 = ($V_1$0>>>0)<($49>>>0);
      if (!($50)) {
       label = 23;
      }
     }
     if ((label|0) == 23) {
      __THREW__ = 0;
      $51 = (invoke_i(132)|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($51|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
     }
     $56 = HEAP32[$groups>>2]|0;
     $57 = (($56) + 92|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = Math_imul($58, $V_1$0)|0;
     $60 = (($4) + ($59)|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = HEAP32[$5>>2]|0;
     $63 = ($62|0)>($V_0$1|0);
     $64 = (($62) - ($V_0$1))|0;
     $G_B13_0$0 = $63 ? $64 : 0;
     $65 = ($61|0)==(0);
     if ($65) {
      L34: do {
       if ($48) {
        $$lcssa26 = 1;$V_1$1$lcssa = $V_1$0;
       } else {
        $V_1$128 = $V_1$0;
        while(1) {
         __THREW__ = 0;
         invoke_vi(3799,($groups|0));
         $67 = __THREW__; __THREW__ = 0;
         $68 = $67&1;
         if ($68) {
          break;
         }
         $69 = HEAP32[$3>>2]|0;
         $70 = ($V_1$128>>>0)<($69>>>0);
         if (!($70)) {
          __THREW__ = 0;
          $71 = (invoke_i(132)|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($71|0));
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           break;
          }
         }
         $76 = HEAP32[$groups>>2]|0;
         $77 = (($76) + 92|0);
         $78 = HEAP32[$77>>2]|0;
         $79 = Math_imul($78, $V_1$128)|0;
         $80 = (($4) + ($79)|0);
         $81 = HEAP32[$80>>2]|0;
         $82 = ($81|0)==(0);
         $83 = (($V_1$128) + -1)|0;
         if (!($82)) {
          $$lcssa26 = 0;$V_1$1$lcssa = $V_1$128;
          break L34;
         }
         $66 = ($V_1$128|0)<(1);
         if ($66) {
          $$lcssa26 = 1;$V_1$1$lcssa = $83;
          break L34;
         } else {
          $V_1$128 = $83;
         }
        }
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index5 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
      } while(0);
      $84 = ($G_B13_0$0|0)<(1);
      if ($84) {
       __THREW__ = 0;
       invoke_vi(3799,($groups|0));
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        break;
       }
       if ($$lcssa26) {
        label = 37;
       } else {
        $87 = HEAP32[$3>>2]|0;
        $88 = ($V_1$1$lcssa>>>0)<($87>>>0);
        if (!($88)) {
         label = 37;
        }
       }
       if ((label|0) == 37) {
        __THREW__ = 0;
        $89 = (invoke_i(132)|0);
        $90 = __THREW__; __THREW__ = 0;
        $91 = $90&1;
        if ($91) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($89|0));
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break;
        }
       }
       $94 = HEAP32[$groups>>2]|0;
       $95 = (($94) + 92|0);
       $96 = HEAP32[$95>>2]|0;
       $97 = Math_imul($96, $V_1$1$lcssa)|0;
       $98 = (($4) + ($97)|0);
       $99 = HEAP32[$98>>2]|0;
       $V_1$2 = $V_1$1$lcssa;$V_4$0 = $99;
       label = 40;
      } else {
       $V_1$24 = $V_1$1$lcssa;$V_4$03 = $64;
       label = 41;
      }
     } else {
      $V_1$2 = $V_1$0;$V_4$0 = $61;
      label = 40;
     }
     if ((label|0) == 40) {
      $100 = ($G_B13_0$0|0)==(0);
      if ($100) {
       $V_1$4$ph = $V_1$2;$V_3$1$ph = $V_4$0;$V_4$2$ph = $V_4$0;
      } else {
       $V_1$24 = $V_1$2;$V_4$03 = $V_4$0;
       label = 41;
      }
     }
     if ((label|0) == 41) {
      $101 = (($G_B13_0$0|0) / ($V_4$03|0))&-1;
      $102 = (($101) + ($V_1$24))|0;
      $103 = (($G_B13_0$0|0) % ($V_4$03|0))&-1;
      $104 = ($103|0)==(0);
      $V_4$0$ = $104 ? $V_4$03 : $103;
      $105 = $104&1;
      $106 = $105 ^ 1;
      $$ = (($102) + ($106))|0;
      $V_1$4$ph = $$;$V_3$1$ph = $V_4$0$;$V_4$2$ph = $V_4$03;
     }
     $107 = (($__this) + 32|0);
     $V_1$4$ph9 = $V_1$4$ph;$V_3$1$ph8 = $V_3$1$ph;$V_4$2$ph7 = $V_4$2$ph;$V_6$0$ph = 0;
     L59: while(1) {
      $V_1$4 = $V_1$4$ph9;$V_3$1 = $V_3$1$ph8;$V_6$0 = $V_6$0$ph;
      while(1) {
       $110 = HEAP32[$5>>2]|0;
       $142 = (($110) - ($V_6$0))|0;
       $143 = ($142|0)>($V_3$1|0);
       $144 = ($V_3$1|0)!=(0);
       $or$cond = $143 & $144;
       $109 = HEAP32[$107>>2]|0;
       if (!($or$cond)) {
        label = 43;
        break L59;
       }
       $114 = (($109) - ($V_6$0))|0;
       $115 = (($114) - ($V_3$1))|0;
       __THREW__ = 0;
       invoke_viii(696,($__this|0),($115|0),($114|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 4;
        break L59;
       }
       $118 = (($V_3$1) + ($V_6$0))|0;
       __THREW__ = 0;
       invoke_vii(1962,($__this|0),($groupSeparator|0));
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        label = 4;
        break L59;
       }
       $121 = (($V_1$4) + -1)|0;
       __THREW__ = 0;
       invoke_vi(3799,($groups|0));
       $122 = __THREW__; __THREW__ = 0;
       $123 = $122&1;
       if ($123) {
        label = 4;
        break L59;
       }
       $124 = HEAP32[$3>>2]|0;
       $125 = ($V_1$4|0)>($124|0);
       $126 = ($V_1$4|0)<(1);
       $or$cond6 = $125 | $126;
       if ($or$cond6) {
        $V_1$4 = $121;$V_3$1 = $V_4$2$ph7;$V_6$0 = $118;
       } else {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vi(3799,($groups|0));
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       label = 5;
       break;
      }
      $129 = HEAP32[$3>>2]|0;
      $130 = ($121>>>0)<($129>>>0);
      if (!($130)) {
       __THREW__ = 0;
       $131 = (invoke_i(132)|0);
       $132 = __THREW__; __THREW__ = 0;
       $133 = $132&1;
       if ($133) {
        label = 5;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($131|0));
       $134 = __THREW__; __THREW__ = 0;
       $135 = $134&1;
       if ($135) {
        label = 5;
        break;
       }
      }
      $136 = HEAP32[$groups>>2]|0;
      $137 = (($136) + 92|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = Math_imul($138, $121)|0;
      $140 = (($4) + ($139)|0);
      $141 = HEAP32[$140>>2]|0;
      $V_1$4$ph9 = $121;$V_3$1$ph8 = $141;$V_4$2$ph7 = $141;$V_6$0$ph = $118;
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index5 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 5) {
      $8 = ___cxa_find_matching_catch()|0;
      $9 = tempRet0;
      $lpad$phi$index = $8;$lpad$phi$index5 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 43) {
      $108 = (($109) - ($110))|0;
      $111 = (($109) - ($V_6$0))|0;
      __THREW__ = 0;
      invoke_viii(696,($__this|0),($108|0),($111|0));
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index5 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z96mscorlib_System_NumberFormatter_m_AppendDecimalString_mscorlib_System_Void_mscorlib_System_Int32P31mscorlib_System_NumberFormatteri($__this,$precision) {
 $__this = $__this|0;
 $precision = $precision|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628800);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($precision))|0;
 $3 = (($__this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) - ($4))|0;
 $6 = (($1) - ($4))|0;
 __THREW__ = 0;
 invoke_viii(696,($__this|0),($5|0),($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z111mscorlib_System_NumberFormatter_m_AppendDigits_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32P31mscorlib_System_NumberFormatterii($__this,$start,$end) {
 $__this = $__this|0;
 $start = $start|0;
 $end = $end|0;
 var $$0 = 0, $$V_1$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$2 = 0, $V_0$3 = 0, $V_0$4 = 0, $V_0$5 = 0, $V_0$6 = 0, $V_0$7 = 0, $V_0$8 = 0, $V_1$1 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_2$2 = 0, $V_2$3 = 0;
 var $V_2$4 = 0, $V_2$5 = 0, $V_2$6 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2629040);
 $0 = ($start|0)<($end|0);
 if (!($0)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $1 = (($__this) + 64|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($end) - ($start))|0;
 $4 = (($2) + ($3))|0;
 $5 = (($__this) + 60|0);
 $6 = HEAP32[$5>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($6|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   $9 = (($6) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($4|0)>($10|0);
   if ($11) {
    $16 = (($4) + 10)|0;
    __THREW__ = 0;
    invoke_vii(1960,($__this|0),($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
   }
   HEAP32[$1>>2] = $4;
   $19 = (($__this) + 36|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = (($20) + ($end))|0;
   $22 = (($20) + ($start))|0;
   $23 = (($22) + 8)|0;
   $24 = $22 & 7;
   $25 = (($23) - ($24))|0;
   $26 = (($__this) + 44|0);
   $27 = (($__this) + 48|0);
   $28 = (($__this) + 52|0);
   $29 = (($__this) + 56|0);
   $$0 = $22;$V_0$8 = $4;$V_1$1 = $25;
   L9: while(1) {
    if ((($V_1$1|0) == 8)) {
     $30 = HEAP32[$26>>2]|0;
     $V_2$0 = $30;
    } else if ((($V_1$1|0) == 32)) {
     $33 = HEAP32[$29>>2]|0;
     $V_2$0 = $33;
    } else if ((($V_1$1|0) == 24)) {
     $32 = HEAP32[$28>>2]|0;
     $V_2$0 = $32;
    } else if ((($V_1$1|0) == 16)) {
     $31 = HEAP32[$27>>2]|0;
     $V_2$0 = $31;
    } else {
     $V_2$0 = 0;
    }
    $34 = $$0 << 2;
    $35 = $34 & 28;
    $36 = $V_2$0 >>> $35;
    $37 = ($V_1$1|0)>($21|0);
    $$V_1$1 = $37 ? $21 : $V_1$1;
    $38 = HEAP32[$5>>2]|0;
    $39 = (($V_0$8) + -1)|0;
    $40 = $36 & 15;
    $41 = $40 | 48;
    $42 = $41&65535;
    __THREW__ = 0;
    invoke_vi(3799,($38|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    $45 = ($V_0$8|0)<(1);
    if ($45) {
     label = 16;
    } else {
     $46 = (($38) + 12|0);
     $47 = HEAP32[$46>>2]|0;
     $48 = ($39>>>0)<($47>>>0);
     if (!($48)) {
      label = 16;
     }
    }
    if ((label|0) == 16) {
     label = 0;
     __THREW__ = 0;
     $49 = (invoke_i(132)|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3302,($49|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break;
     }
    }
    $54 = HEAP32[$38>>2]|0;
    $55 = (($38) + 16|0);
    $56 = (($54) + 92|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = Math_imul($57, $39)|0;
    $59 = (($55) + ($58)|0);
    HEAP16[$59>>1] = $42;
    $60 = (($$V_1$1) - ($$0))|0;
    switch ($60|0) {
    case 6:  {
     $V_0$1 = $39;$V_2$2 = $36;
     label = 31;
     break;
    }
    case 8:  {
     $61 = HEAP32[$5>>2]|0;
     $62 = (($V_0$8) + -2)|0;
     $63 = $36 >>> 4;
     $64 = $63 & 15;
     $65 = $64 | 48;
     $66 = $65&65535;
     __THREW__ = 0;
     invoke_vi(3799,($61|0));
     $67 = __THREW__; __THREW__ = 0;
     $68 = $67&1;
     if ($68) {
      break L9;
     }
     $69 = ($62|0)<(0);
     if ($69) {
      label = 22;
     } else {
      $70 = (($61) + 12|0);
      $71 = HEAP32[$70>>2]|0;
      $72 = ($62>>>0)<($71>>>0);
      if (!($72)) {
       label = 22;
      }
     }
     if ((label|0) == 22) {
      label = 0;
      __THREW__ = 0;
      $73 = (invoke_i(132)|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       break L9;
      }
      __THREW__ = 0;
      invoke_vi(3302,($73|0));
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       break L9;
      }
     }
     $78 = HEAP32[$61>>2]|0;
     $79 = (($61) + 16|0);
     $80 = (($78) + 92|0);
     $81 = HEAP32[$80>>2]|0;
     $82 = Math_imul($81, $62)|0;
     $83 = (($79) + ($82)|0);
     HEAP16[$83>>1] = $66;
     $V_0$0 = $62;$V_2$1 = $63;
     label = 25;
     break;
    }
    case 5:  {
     $V_0$2 = $39;$V_2$3 = $36;
     label = 37;
     break;
    }
    case 3:  {
     $V_0$4 = $39;$V_2$5 = $36;
     label = 49;
     break;
    }
    case 4:  {
     $V_0$3 = $39;$V_2$4 = $36;
     label = 43;
     break;
    }
    case 7:  {
     $V_0$0 = $39;$V_2$1 = $36;
     label = 25;
     break;
    }
    case 1:  {
     $V_0$6 = $39;
     label = 61;
     break;
    }
    case 2:  {
     $V_0$5 = $39;$V_2$6 = $36;
     label = 55;
     break;
    }
    default: {
     $V_0$7 = $39;
    }
    }
    if ((label|0) == 25) {
     label = 0;
     $84 = HEAP32[$5>>2]|0;
     $85 = (($V_0$0) + -1)|0;
     $86 = $V_2$1 >>> 4;
     $87 = $86 & 15;
     $88 = $87 | 48;
     $89 = $88&65535;
     __THREW__ = 0;
     invoke_vi(3799,($84|0));
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      break;
     }
     $92 = ($V_0$0|0)<(1);
     if ($92) {
      label = 28;
     } else {
      $93 = (($84) + 12|0);
      $94 = HEAP32[$93>>2]|0;
      $95 = ($85>>>0)<($94>>>0);
      if (!($95)) {
       label = 28;
      }
     }
     if ((label|0) == 28) {
      label = 0;
      __THREW__ = 0;
      $96 = (invoke_i(132)|0);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($96|0));
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       break;
      }
     }
     $101 = HEAP32[$84>>2]|0;
     $102 = (($84) + 16|0);
     $103 = (($101) + 92|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = Math_imul($104, $85)|0;
     $106 = (($102) + ($105)|0);
     HEAP16[$106>>1] = $89;
     $V_0$1 = $85;$V_2$2 = $86;
     label = 31;
    }
    if ((label|0) == 31) {
     label = 0;
     $107 = HEAP32[$5>>2]|0;
     $108 = (($V_0$1) + -1)|0;
     $109 = $V_2$2 >>> 4;
     $110 = $109 & 15;
     $111 = $110 | 48;
     $112 = $111&65535;
     __THREW__ = 0;
     invoke_vi(3799,($107|0));
     $113 = __THREW__; __THREW__ = 0;
     $114 = $113&1;
     if ($114) {
      break;
     }
     $115 = ($V_0$1|0)<(1);
     if ($115) {
      label = 34;
     } else {
      $116 = (($107) + 12|0);
      $117 = HEAP32[$116>>2]|0;
      $118 = ($108>>>0)<($117>>>0);
      if (!($118)) {
       label = 34;
      }
     }
     if ((label|0) == 34) {
      label = 0;
      __THREW__ = 0;
      $119 = (invoke_i(132)|0);
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($119|0));
      $122 = __THREW__; __THREW__ = 0;
      $123 = $122&1;
      if ($123) {
       break;
      }
     }
     $124 = HEAP32[$107>>2]|0;
     $125 = (($107) + 16|0);
     $126 = (($124) + 92|0);
     $127 = HEAP32[$126>>2]|0;
     $128 = Math_imul($127, $108)|0;
     $129 = (($125) + ($128)|0);
     HEAP16[$129>>1] = $112;
     $V_0$2 = $108;$V_2$3 = $109;
     label = 37;
    }
    if ((label|0) == 37) {
     label = 0;
     $130 = HEAP32[$5>>2]|0;
     $131 = (($V_0$2) + -1)|0;
     $132 = $V_2$3 >>> 4;
     $133 = $132 & 15;
     $134 = $133 | 48;
     $135 = $134&65535;
     __THREW__ = 0;
     invoke_vi(3799,($130|0));
     $136 = __THREW__; __THREW__ = 0;
     $137 = $136&1;
     if ($137) {
      break;
     }
     $138 = ($V_0$2|0)<(1);
     if ($138) {
      label = 40;
     } else {
      $139 = (($130) + 12|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = ($131>>>0)<($140>>>0);
      if (!($141)) {
       label = 40;
      }
     }
     if ((label|0) == 40) {
      label = 0;
      __THREW__ = 0;
      $142 = (invoke_i(132)|0);
      $143 = __THREW__; __THREW__ = 0;
      $144 = $143&1;
      if ($144) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($142|0));
      $145 = __THREW__; __THREW__ = 0;
      $146 = $145&1;
      if ($146) {
       break;
      }
     }
     $147 = HEAP32[$130>>2]|0;
     $148 = (($130) + 16|0);
     $149 = (($147) + 92|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = Math_imul($150, $131)|0;
     $152 = (($148) + ($151)|0);
     HEAP16[$152>>1] = $135;
     $V_0$3 = $131;$V_2$4 = $132;
     label = 43;
    }
    if ((label|0) == 43) {
     label = 0;
     $153 = HEAP32[$5>>2]|0;
     $154 = (($V_0$3) + -1)|0;
     $155 = $V_2$4 >>> 4;
     $156 = $155 & 15;
     $157 = $156 | 48;
     $158 = $157&65535;
     __THREW__ = 0;
     invoke_vi(3799,($153|0));
     $159 = __THREW__; __THREW__ = 0;
     $160 = $159&1;
     if ($160) {
      break;
     }
     $161 = ($V_0$3|0)<(1);
     if ($161) {
      label = 46;
     } else {
      $162 = (($153) + 12|0);
      $163 = HEAP32[$162>>2]|0;
      $164 = ($154>>>0)<($163>>>0);
      if (!($164)) {
       label = 46;
      }
     }
     if ((label|0) == 46) {
      label = 0;
      __THREW__ = 0;
      $165 = (invoke_i(132)|0);
      $166 = __THREW__; __THREW__ = 0;
      $167 = $166&1;
      if ($167) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($165|0));
      $168 = __THREW__; __THREW__ = 0;
      $169 = $168&1;
      if ($169) {
       break;
      }
     }
     $170 = HEAP32[$153>>2]|0;
     $171 = (($153) + 16|0);
     $172 = (($170) + 92|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = Math_imul($173, $154)|0;
     $175 = (($171) + ($174)|0);
     HEAP16[$175>>1] = $158;
     $V_0$4 = $154;$V_2$5 = $155;
     label = 49;
    }
    if ((label|0) == 49) {
     label = 0;
     $176 = HEAP32[$5>>2]|0;
     $177 = (($V_0$4) + -1)|0;
     $178 = $V_2$5 >>> 4;
     $179 = $178 & 15;
     $180 = $179 | 48;
     $181 = $180&65535;
     __THREW__ = 0;
     invoke_vi(3799,($176|0));
     $182 = __THREW__; __THREW__ = 0;
     $183 = $182&1;
     if ($183) {
      break;
     }
     $184 = ($V_0$4|0)<(1);
     if ($184) {
      label = 52;
     } else {
      $185 = (($176) + 12|0);
      $186 = HEAP32[$185>>2]|0;
      $187 = ($177>>>0)<($186>>>0);
      if (!($187)) {
       label = 52;
      }
     }
     if ((label|0) == 52) {
      label = 0;
      __THREW__ = 0;
      $188 = (invoke_i(132)|0);
      $189 = __THREW__; __THREW__ = 0;
      $190 = $189&1;
      if ($190) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($188|0));
      $191 = __THREW__; __THREW__ = 0;
      $192 = $191&1;
      if ($192) {
       break;
      }
     }
     $193 = HEAP32[$176>>2]|0;
     $194 = (($176) + 16|0);
     $195 = (($193) + 92|0);
     $196 = HEAP32[$195>>2]|0;
     $197 = Math_imul($196, $177)|0;
     $198 = (($194) + ($197)|0);
     HEAP16[$198>>1] = $181;
     $V_0$5 = $177;$V_2$6 = $178;
     label = 55;
    }
    if ((label|0) == 55) {
     label = 0;
     $199 = HEAP32[$5>>2]|0;
     $200 = (($V_0$5) + -1)|0;
     $201 = $V_2$6 >>> 4;
     $202 = $201 & 15;
     $203 = $202 | 48;
     $204 = $203&65535;
     __THREW__ = 0;
     invoke_vi(3799,($199|0));
     $205 = __THREW__; __THREW__ = 0;
     $206 = $205&1;
     if ($206) {
      break;
     }
     $207 = ($V_0$5|0)<(1);
     if ($207) {
      label = 58;
     } else {
      $208 = (($199) + 12|0);
      $209 = HEAP32[$208>>2]|0;
      $210 = ($200>>>0)<($209>>>0);
      if (!($210)) {
       label = 58;
      }
     }
     if ((label|0) == 58) {
      label = 0;
      __THREW__ = 0;
      $211 = (invoke_i(132)|0);
      $212 = __THREW__; __THREW__ = 0;
      $213 = $212&1;
      if ($213) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($211|0));
      $214 = __THREW__; __THREW__ = 0;
      $215 = $214&1;
      if ($215) {
       break;
      }
     }
     $216 = HEAP32[$199>>2]|0;
     $217 = (($199) + 16|0);
     $218 = (($216) + 92|0);
     $219 = HEAP32[$218>>2]|0;
     $220 = Math_imul($219, $200)|0;
     $221 = (($217) + ($220)|0);
     HEAP16[$221>>1] = $204;
     $V_0$6 = $200;
     label = 61;
    }
    if ((label|0) == 61) {
     label = 0;
     $222 = ($$V_1$1|0)==($21|0);
     if ($222) {
      label = 64;
      break;
     } else {
      $V_0$7 = $V_0$6;
     }
    }
    $223 = (($$V_1$1) + 8)|0;
    $$0 = $$V_1$1;$V_0$8 = $V_0$7;$V_1$1 = $223;
   }
   if ((label|0) == 64) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   $lpad$phi$index = $12;$lpad$phi$index2 = $13;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z96mscorlib_System_NumberFormatter_m_AppendIntegerString_mscorlib_System_Void_mscorlib_System_Int32P31mscorlib_System_NumberFormatteri($__this,$minLength) {
 $__this = $__this|0;
 $minLength = $minLength|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628704);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 do {
  if ($2) {
   $7 = ($1|0)<($minLength|0);
   if ($7) {
    $8 = (($minLength) - ($1))|0;
    __THREW__ = 0;
    invoke_viii(689,($__this|0),48,($8|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $$pre = HEAP32[$0>>2]|0;
    $14 = $$pre;
   } else {
    $14 = $1;
   }
   $11 = (($__this) + 32|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) - ($14))|0;
   __THREW__ = 0;
   invoke_viii(696,($__this|0),($13|0),($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  } else {
   __THREW__ = 0;
   invoke_viii(689,($__this|0),48,($minLength|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z42mscorlib_System_NumberFormatter_m_GetCloneP31mscorlib_System_NumberFormatter($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2629232);
 __THREW__ = 0;
 $0 = (invoke_ii(1783,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2633856|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2769,($0|0),(2633856|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z165mscorlib_System_NumberFormatter_m_FormatExponential_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Globalization_NumberFormatInfo_mscorlib_System_Int32P31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfoi($__this,$precision,$nfi,$expDigits) {
 $__this = $__this|0;
 $precision = $precision|0;
 $nfi = $nfi|0;
 $expDigits = $expDigits|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628416);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 32|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + -1)|0;
 HEAP32[$0>>2] = 1;
 $5 = (($precision) + 8)|0;
 __THREW__ = 0;
 invoke_vii(1959,($__this|0),($5|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 do {
  if (!($7)) {
   $8 = (($__this) + 20|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ($9<<24>>24)==(0);
   if ($10) {
    __THREW__ = 0;
    invoke_vi(3799,($nfi|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    $15 = (invoke_ii(2029,($nfi|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1962,($__this|0),($15|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
   }
   $20 = (($3) + -1)|0;
   __THREW__ = 0;
   invoke_vii(1967,($__this|0),($20|0));
   $21 = __THREW__; __THREW__ = 0;
   $22 = $21&1;
   if (!($22)) {
    $23 = ($precision|0)<(1);
    if (!($23)) {
     __THREW__ = 0;
     invoke_vi(3799,($nfi|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
     __THREW__ = 0;
     $26 = (invoke_ii(2031,($nfi|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1962,($__this|0),($26|0));
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     }
     $31 = $precision ^ -1;
     $32 = (($3) + ($31))|0;
     $33 = HEAP32[$0>>2]|0;
     $34 = (($3) - ($33))|0;
     __THREW__ = 0;
     invoke_viii(696,($__this|0),($32|0),($34|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_viiii(200,($__this|0),($nfi|0),($4|0),($expDigits|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     $39 = (($__this) + 60|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = (($__this) + 64|0);
     $42 = HEAP32[$41>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if (!($44)) {
      __THREW__ = 0;
      $45 = (invoke_ii(3469,(2191608|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if (!($47)) {
       __THREW__ = 0;
       $48 = (invoke_iiiii(104,($45|0),($40|0),0,($42|0))|0);
       $49 = __THREW__; __THREW__ = 0;
       $50 = $49&1;
       if (!($50)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($48|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z44mscorlib_System_NumberFormatter_m_Multiply10P31mscorlib_System_NumberFormatteri($__this,$count) {
 $__this = $__this|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2629136);
 $0 = ($count|0)<(1);
 if ($0) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $1 = (($__this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3799,($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = (($__this) + 40|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = (($7) + ($count))|0;
   HEAP32[$6>>2] = $10;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z48mscorlib_System_NumberFormatter_m_AppendOneDigitP31mscorlib_System_NumberFormatteri($__this,$start) {
 $__this = $__this|0;
 $start = $start|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628944);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 60|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = (($3) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($1|0)==($7|0);
   if ($8) {
    $11 = HEAP32[$0>>2]|0;
    $12 = (($11) + 10)|0;
    __THREW__ = 0;
    invoke_vii(1960,($__this|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
   }
   $15 = (($__this) + 36|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) + ($start))|0;
   $18 = ($17|0)>(-1);
   do {
    if ($18) {
     $19 = ($17|0)>(7);
     if (!($19)) {
      $20 = (($__this) + 44|0);
      $21 = HEAP32[$20>>2]|0;
      $V_0$0 = $21;
      break;
     }
     $22 = ($17|0)>(15);
     if (!($22)) {
      $23 = (($__this) + 48|0);
      $24 = HEAP32[$23>>2]|0;
      $V_0$0 = $24;
      break;
     }
     $25 = ($17|0)>(23);
     if (!($25)) {
      $26 = (($__this) + 52|0);
      $27 = HEAP32[$26>>2]|0;
      $V_0$0 = $27;
      break;
     }
     $28 = ($17|0)>(31);
     if ($28) {
      $V_0$0 = 0;
     } else {
      $29 = (($__this) + 56|0);
      $30 = HEAP32[$29>>2]|0;
      $V_0$0 = $30;
     }
    } else {
     $V_0$0 = 0;
    }
   } while(0);
   $31 = $17 << 2;
   $32 = $31 & 28;
   $33 = $V_0$0 >>> $32;
   $34 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($__this|0));
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if (!($36)) {
    $37 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if (!($39)) {
     $40 = (($37) + 1)|0;
     HEAP32[$0>>2] = $40;
     $41 = $33 & 15;
     $42 = $41 | 48;
     $43 = $42&65535;
     __THREW__ = 0;
     invoke_vi(3799,($34|0));
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if (!($45)) {
      $46 = ($37|0)<(0);
      if (!($46)) {
       $47 = (($34) + 12|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ($37>>>0)<($48>>>0);
       if ($49) {
        $55 = HEAP32[$34>>2]|0;
        $56 = (($34) + 16|0);
        $57 = (($55) + 92|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = Math_imul($58, $37)|0;
        $60 = (($56) + ($59)|0);
        HEAP16[$60>>1] = $43;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
      __THREW__ = 0;
      $50 = (invoke_i(132)|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if (!($52)) {
       __THREW__ = 0;
       invoke_vi(3302,($50|0));
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if (!($54)) {
        $55 = HEAP32[$34>>2]|0;
        $56 = (($34) + 16|0);
        $57 = (($55) + 92|0);
        $58 = HEAP32[$57>>2]|0;
        $59 = Math_imul($58, $37)|0;
        $60 = (($56) + ($59)|0);
        HEAP16[$60>>1] = $43;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z48mscorlib_System_NumberFormatter_m_AppendExponentP31mscorlib_System_NumberFormatterP46mscorlib_System_Globalization_NumberFormatInfoii($__this,$nfi,$exponent,$minDigits) {
 $__this = $__this|0;
 $nfi = $nfi|0;
 $exponent = $exponent|0;
 $minDigits = $minDigits|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628896);
 $0 = (($__this) + 19|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $3 = (($__this) + 22|0);
  $4 = HEAP16[$3>>1]|0;
  $5 = ($4<<16>>16)==(82);
  if ($5) {
   label = 3;
  } else {
   __THREW__ = 0;
   invoke_vii(1961,($__this|0),101);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    label = 6;
   }
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  __THREW__ = 0;
  invoke_vii(1961,($__this|0),69);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   label = 6;
  }
 }
 do {
  if ((label|0) == 6) {
   $12 = ($exponent|0)<(0);
   if ($12) {
    __THREW__ = 0;
    invoke_vi(3799,($nfi|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(2029,($nfi|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1962,($__this|0),($22|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = (0 - ($exponent))|0;
    $$0 = $27;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($nfi|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    $15 = (invoke_ii(2044,($nfi|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(1962,($__this|0),($15|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    } else {
     $$0 = $exponent;
    }
   }
   $28 = ($$0|0)==(0);
   if ($28) {
    __THREW__ = 0;
    invoke_viii(689,($__this|0),48,($minDigits|0));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $31 = ($$0|0)>(9);
   if (!($31)) {
    $32 = (($minDigits) + -1)|0;
    __THREW__ = 0;
    invoke_viii(689,($__this|0),48,($32|0));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    $35 = $$0 | 48;
    $36 = $35&65535;
    __THREW__ = 0;
    invoke_vii(1961,($__this|0),($36|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   $39 = (invoke_iii(1143,0,($$0|0))|0);
   $40 = __THREW__; __THREW__ = 0;
   $41 = $40&1;
   if (!($41)) {
    $42 = ($$0|0)>(99);
    $43 = ($minDigits|0)==(3);
    $or$cond = $42 | $43;
    if ($or$cond) {
     $44 = $39 >>> 8;
     $45 = $44 | 48;
     $46 = $45&65535;
     __THREW__ = 0;
     invoke_vii(1961,($__this|0),($46|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break;
     }
    }
    $49 = $39 >>> 4;
    $50 = $49 & 15;
    $51 = $50 | 48;
    $52 = $51&65535;
    __THREW__ = 0;
    invoke_vii(1961,($__this|0),($52|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if (!($54)) {
     $55 = $39 & 15;
     $56 = $55 | 48;
     $57 = $56&65535;
     __THREW__ = 0;
     invoke_vii(1961,($__this|0),($57|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z42mscorlib_System_NumberFormatter_m_Divide10P31mscorlib_System_NumberFormatteri($__this,$count) {
 $__this = $__this|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2629184);
 $0 = ($count|0)<(1);
 if ($0) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $1 = (($__this) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3799,($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = (($__this) + 40|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = (($7) - ($count))|0;
   HEAP32[$6>>2] = $10;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z57mscorlib_System_NumberFormatter_m_AppendNonNegativeNumberP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderi($__this,$sb,$v) {
 $__this = $__this|0;
 $sb = $sb|0;
 $v = $v|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_0$0$in = 0;
 var $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628608);
 $0 = ($v|0)>(-1);
 if ($0) {
  $14 = ($v|0)<(0);
  $15 = $14 << 31 >> 31;
  __THREW__ = 0;
  $16 = (invoke_iiii(1214,0,($v|0),($15|0))|0);
  $17 = __THREW__; __THREW__ = 0;
  $18 = $17&1;
  if (!($18)) {
   $$0 = $v;$V_0$0$in = $16;
   while(1) {
    $V_0$0 = (($V_0$0$in) + -1)|0;
    __THREW__ = 0;
    $19 = (invoke_iii(1142,0,($V_0$0|0))|0);
    $20 = tempRet0;
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (($$0|0) / ($19|0))&-1;
    __THREW__ = 0;
    invoke_vi(3799,($sb|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    $26 = $23 | 48;
    $27 = $26&65535;
    __THREW__ = 0;
    (invoke_iii(992,($sb|0),($27|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    $30 = (invoke_iii(1142,0,($V_0$0|0))|0);
    $31 = tempRet0;
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = Math_imul($30, $23)|0;
    $35 = (($$0) - ($34))|0;
    $36 = ($V_0$0|0)>(0);
    if ($36) {
     $$0 = $35;$V_0$0$in = $V_0$0;
    } else {
     label = 17;
     break;
    }
   }
   if ((label|0) == 17) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   $lpad$phi$index = $10;$lpad$phi$index2 = $11;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2560072|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(3469,(2560072|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(2583,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3838,($3|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z131mscorlib_System_NumberFormatter_m_AppendIntegerString_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Text_StringBuilderP31mscorlib_System_NumberFormatteriP34mscorlib_System_Text_StringBuilder($__this,$minLength,$sb) {
 $__this = $__this|0;
 $minLength = $minLength|0;
 $sb = $sb|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628656);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 do {
  if ($2) {
   $9 = ($1|0)<($minLength|0);
   if ($9) {
    __THREW__ = 0;
    invoke_vi(3799,($sb|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = (($minLength) - ($1))|0;
    __THREW__ = 0;
    (invoke_iiii(932,($sb|0),48,($12|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    $$pre = HEAP32[$0>>2]|0;
    $18 = $$pre;
   } else {
    $18 = $1;
   }
   $15 = (($__this) + 32|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($16) - ($18))|0;
   __THREW__ = 0;
   invoke_viiii(201,($__this|0),($17|0),($16|0),($sb|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($sb|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    (invoke_iiii(932,($sb|0),48,($minLength|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z131mscorlib_System_NumberFormatter_m_AppendDecimalString_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Text_StringBuilderP31mscorlib_System_NumberFormatteriP34mscorlib_System_Text_StringBuilder($__this,$precision,$sb) {
 $__this = $__this|0;
 $precision = $precision|0;
 $sb = $sb|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628752);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) - ($precision))|0;
 $3 = (($__this) + 40|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) - ($4))|0;
 $6 = (($1) - ($4))|0;
 __THREW__ = 0;
 invoke_viiii(201,($__this|0),($5|0),($6|0),($sb|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44mscorlib_System_NumberFormatter_m_IsZeroOnlyP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilder($__this,$sb) {
 $__this = $__this|0;
 $sb = $sb|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628560);
 $V_0$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($sb|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if ($16) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $17 = (invoke_ii(2398,($sb|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 5;
   break;
  }
  $20 = ($V_0$0|0)<($17|0);
  if (!($20)) {
   $$0 = 1;
   label = 14;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($sb|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if ($22) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $0 = (invoke_iii(988,($sb|0),($V_0$0|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if ($2) {
   label = 5;
   break;
  }
  __THREW__ = 0;
  $3 = (invoke_iii(600,(0|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   label = 5;
   break;
  }
  if ($3) {
   __THREW__ = 0;
   invoke_vi(3799,($sb|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if ($9) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   $10 = (invoke_iii(988,($sb|0),($V_0$0|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if ($12) {
    label = 5;
    break;
   }
   $13 = ($10<<16>>16)==(48);
   if (!($13)) {
    $$0 = 0;
    label = 14;
    break;
   }
  }
  $14 = (($V_0$0) + 1)|0;
  $V_0$0 = $14;
 }
 if ((label|0) == 5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z45mscorlib_System_NumberFormatter_m_ZeroTrimEndP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderb($__this,$sb,$canEmpty) {
 $__this = $__this|0;
 $sb = $sb|0;
 $canEmpty = $canEmpty|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0$lcssa = 0, $V_0$04 = 0, $V_1$0 = 0, $V_1$0$in$sink = 0, $V_1$0$in$sink3 = 0, $V_1$02 = 0, $V_1$05 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2628512);
 __THREW__ = 0;
 invoke_vi(3799,($sb|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(2398,($sb|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $V_1$02 = (($2) + -1)|0;
   $V_1$0$in$sink3 = $canEmpty ? $2 : $V_1$02;
   $5 = ($V_1$0$in$sink3|0)>(0);
   if ($5) {
    $V_0$04 = 0;$V_1$05 = $V_1$02;
   } else {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   while(1) {
    __THREW__ = 0;
    invoke_vi(3799,($sb|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 4;
     break;
    }
    __THREW__ = 0;
    $10 = (invoke_iii(988,($sb|0),($V_1$05|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     label = 4;
     break;
    }
    $13 = ($10<<16>>16)==(48);
    $14 = (($V_0$04) + 1)|0;
    if (!($13)) {
     $V_0$0$lcssa = $V_0$04;
     break;
    }
    $V_1$0 = (($V_1$05) + -1)|0;
    $V_1$0$in$sink = $canEmpty ? $V_1$05 : $V_1$0;
    $15 = ($V_1$0$in$sink|0)>(0);
    if ($15) {
     $V_0$04 = $14;$V_1$05 = $V_1$0;
    } else {
     $V_0$0$lcssa = $14;
     break;
    }
   }
   if ((label|0) == 4) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    $lpad$phi$index = $6;$lpad$phi$index2 = $7;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $18 = ($V_0$0$lcssa|0)<(1);
   if ($18) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3799,($sb|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_ii(2398,($sb|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     __THREW__ = 0;
     invoke_vi(3799,($sb|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = (($21) - ($V_0$0$lcssa))|0;
      __THREW__ = 0;
      (invoke_iiii(929,($sb|0),($26|0),($V_0$0$lcssa|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z146mscorlib_System_NumberFormatter_m_AppendDigits_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Text_StringBuilderP31mscorlib_System_NumberFormatteriiP34mscorlib_System_Text_StringBuilder($__this,$start,$end,$sb) {
 $__this = $__this|0;
 $start = $start|0;
 $end = $end|0;
 $sb = $sb|0;
 var $$0 = 0, $$V_1$1 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$2 = 0, $V_0$3 = 0, $V_0$4 = 0, $V_0$5 = 0, $V_0$6 = 0, $V_0$7 = 0, $V_0$8 = 0;
 var $V_1$1 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_2$2 = 0, $V_2$3 = 0, $V_2$4 = 0, $V_2$5 = 0, $V_2$6 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2629088);
 $0 = ($start|0)<($end|0);
 if (!($0)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3799,($sb|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_ii(2398,($sb|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($end) - ($start))|0;
   $7 = (($3) + ($6))|0;
   __THREW__ = 0;
   invoke_vi(3799,($sb|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    invoke_vii(1912,($sb|0),($7|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = (($__this) + 36|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($13) + ($end))|0;
     $15 = (($13) + ($start))|0;
     $16 = (($15) + 8)|0;
     $17 = $15 & 7;
     $18 = (($16) - ($17))|0;
     $19 = (($__this) + 44|0);
     $20 = (($__this) + 48|0);
     $21 = (($__this) + 52|0);
     $22 = (($__this) + 56|0);
     $$0 = $15;$V_0$8 = $7;$V_1$1 = $18;
     L9: while(1) {
      if ((($V_1$1|0) == 8)) {
       $27 = HEAP32[$19>>2]|0;
       $V_2$0 = $27;
      } else if ((($V_1$1|0) == 32)) {
       $30 = HEAP32[$22>>2]|0;
       $V_2$0 = $30;
      } else if ((($V_1$1|0) == 24)) {
       $29 = HEAP32[$21>>2]|0;
       $V_2$0 = $29;
      } else if ((($V_1$1|0) == 16)) {
       $28 = HEAP32[$20>>2]|0;
       $V_2$0 = $28;
      } else {
       $V_2$0 = 0;
      }
      $31 = $$0 << 2;
      $32 = $31 & 28;
      $33 = $V_2$0 >>> $32;
      $34 = ($V_1$1|0)>($14|0);
      $$V_1$1 = $34 ? $14 : $V_1$1;
      $35 = (($V_0$8) + -1)|0;
      __THREW__ = 0;
      invoke_vi(3799,($sb|0));
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = $33 & 15;
      $39 = $38 | 48;
      $40 = $39&65535;
      __THREW__ = 0;
      invoke_viii(634,($sb|0),($35|0),($40|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      $43 = (($$V_1$1) - ($$0))|0;
      switch ($43|0) {
      case 2:  {
       $V_0$5 = $35;$V_2$6 = $33;
       label = 29;
       break;
      }
      case 1:  {
       $V_0$6 = $35;
       label = 31;
       break;
      }
      case 4:  {
       $V_0$3 = $35;$V_2$4 = $33;
       label = 25;
       break;
      }
      case 7:  {
       $V_0$0 = $35;$V_2$1 = $33;
       label = 19;
       break;
      }
      case 3:  {
       $V_0$4 = $35;$V_2$5 = $33;
       label = 27;
       break;
      }
      case 6:  {
       $V_0$1 = $35;$V_2$2 = $33;
       label = 21;
       break;
      }
      case 8:  {
       $44 = (($V_0$8) + -2)|0;
       $45 = $33 >>> 4;
       __THREW__ = 0;
       invoke_vi(3799,($sb|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break L9;
       }
       $48 = $45 & 15;
       $49 = $48 | 48;
       $50 = $49&65535;
       __THREW__ = 0;
       invoke_viii(634,($sb|0),($44|0),($50|0));
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break L9;
       } else {
        $V_0$0 = $44;$V_2$1 = $45;
        label = 19;
       }
       break;
      }
      case 5:  {
       $V_0$2 = $35;$V_2$3 = $33;
       label = 23;
       break;
      }
      default: {
       $V_0$7 = $35;
      }
      }
      if ((label|0) == 19) {
       label = 0;
       $53 = (($V_0$0) + -1)|0;
       $54 = $V_2$1 >>> 4;
       __THREW__ = 0;
       invoke_vi(3799,($sb|0));
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
       $57 = $54 & 15;
       $58 = $57 | 48;
       $59 = $58&65535;
       __THREW__ = 0;
       invoke_viii(634,($sb|0),($53|0),($59|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if ($61) {
        break;
       } else {
        $V_0$1 = $53;$V_2$2 = $54;
        label = 21;
       }
      }
      if ((label|0) == 21) {
       label = 0;
       $62 = (($V_0$1) + -1)|0;
       $63 = $V_2$2 >>> 4;
       __THREW__ = 0;
       invoke_vi(3799,($sb|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break;
       }
       $66 = $63 & 15;
       $67 = $66 | 48;
       $68 = $67&65535;
       __THREW__ = 0;
       invoke_viii(634,($sb|0),($62|0),($68|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        break;
       } else {
        $V_0$2 = $62;$V_2$3 = $63;
        label = 23;
       }
      }
      if ((label|0) == 23) {
       label = 0;
       $71 = (($V_0$2) + -1)|0;
       $72 = $V_2$3 >>> 4;
       __THREW__ = 0;
       invoke_vi(3799,($sb|0));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       $75 = $72 & 15;
       $76 = $75 | 48;
       $77 = $76&65535;
       __THREW__ = 0;
       invoke_viii(634,($sb|0),($71|0),($77|0));
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        break;
       } else {
        $V_0$3 = $71;$V_2$4 = $72;
        label = 25;
       }
      }
      if ((label|0) == 25) {
       label = 0;
       $80 = (($V_0$3) + -1)|0;
       $81 = $V_2$4 >>> 4;
       __THREW__ = 0;
       invoke_vi(3799,($sb|0));
       $82 = __THREW__; __THREW__ = 0;
       $83 = $82&1;
       if ($83) {
        break;
       }
       $84 = $81 & 15;
       $85 = $84 | 48;
       $86 = $85&65535;
       __THREW__ = 0;
       invoke_viii(634,($sb|0),($80|0),($86|0));
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if ($88) {
        break;
       } else {
        $V_0$4 = $80;$V_2$5 = $81;
        label = 27;
       }
      }
      if ((label|0) == 27) {
       label = 0;
       $89 = (($V_0$4) + -1)|0;
       $90 = $V_2$5 >>> 4;
       __THREW__ = 0;
       invoke_vi(3799,($sb|0));
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        break;
       }
       $93 = $90 & 15;
       $94 = $93 | 48;
       $95 = $94&65535;
       __THREW__ = 0;
       invoke_viii(634,($sb|0),($89|0),($95|0));
       $96 = __THREW__; __THREW__ = 0;
       $97 = $96&1;
       if ($97) {
        break;
       } else {
        $V_0$5 = $89;$V_2$6 = $90;
        label = 29;
       }
      }
      if ((label|0) == 29) {
       label = 0;
       $98 = (($V_0$5) + -1)|0;
       __THREW__ = 0;
       invoke_vi(3799,($sb|0));
       $99 = __THREW__; __THREW__ = 0;
       $100 = $99&1;
       if ($100) {
        break;
       }
       $101 = $V_2$6 >>> 4;
       $102 = $101 & 15;
       $103 = $102 | 48;
       $104 = $103&65535;
       __THREW__ = 0;
       invoke_viii(634,($sb|0),($98|0),($104|0));
       $105 = __THREW__; __THREW__ = 0;
       $106 = $105&1;
       if ($106) {
        break;
       } else {
        $V_0$6 = $98;
        label = 31;
       }
      }
      if ((label|0) == 31) {
       label = 0;
       $107 = ($$V_1$1|0)==($14|0);
       if ($107) {
        label = 34;
        break;
       } else {
        $V_0$7 = $V_0$6;
       }
      }
      $108 = (($$V_1$1) + 8)|0;
      $$0 = $$V_1$1;$V_0$8 = $V_0$7;$V_1$1 = $108;
     }
     if ((label|0) == 34) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     $23 = ___cxa_find_matching_catch()|0;
     $24 = tempRet0;
     $lpad$phi$index = $23;$lpad$phi$index2 = $24;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $lpad$phi$index = $25;$lpad$phi$index2 = $26;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZN14ActionInvoker2I28mscorlib_System_UInt32Traits28mscorlib_System_UInt64TraitsE6InvokeEPFvPvjyES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$6,$9);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_UInt32Traits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_jiES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$3,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_DoubleTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_diES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = +HEAPF64[$2>>3];
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viidi[$action & 1]($obj,$0,$3,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I17VoidPointerTraits29mscorlib_System_DecimalTraitsE6InvokeEPFvPvS3_23mscorlib_System_DecimalES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker1I26mscorlib_System_CharTraitsE6InvokeEPFvPvtES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP16[$0>>1]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$1);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_UInt32TraitsS0_E6InvokeEPFjPvjES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2164560,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_SByteTraitsS0_E6InvokeEPFPvS3_S3_aS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_26mscorlib_System_ByteTraitsS0_E6InvokeEPFPvS3_S3_hS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP8[$2>>0]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_UInt16TraitsS0_E6InvokeEPFPvS3_S3_tS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP16[$2>>1]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int16TraitsS0_E6InvokeEPFPvS3_S3_sS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP16[$2>>1]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_UInt32TraitsS0_E6InvokeEPFPvS3_S3_jS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_E6InvokeEPFPvS3_S3_iS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_UInt64TraitsS0_E6InvokeEPFPvS3_S3_yS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$5,$8,$10)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int64TraitsS0_E6InvokeEPFPvS3_S3_xS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$5,$8,$10)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_SingleTraitsS0_E6InvokeEPFPvS3_S3_fS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiifi[$func & 7]($obj,$0,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_DoubleTraitsS0_E6InvokeEPFPvS3_S3_dS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = +HEAPF64[$2>>3];
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiidi[$func & 1]($obj,$0,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraitsS0_29mscorlib_System_DecimalTraitsS0_E6InvokeEPFPvS3_S3_23mscorlib_System_DecimalS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$$byval_copy,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_UInt32TraitsS0_E6InvokeEPFPvS3_jS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$1,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_UInt64TraitsS0_E6InvokeEPFPvS3_yS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$3,$6,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int64TraitsS0_E6InvokeEPFPvS3_xS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$3,$6,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_SingleTraitsS0_E6InvokeEPFPvS3_fS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iifi[$func & 7]($obj,$1,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_DoubleTraitsS0_E6InvokeEPFPvS3_dS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = +HEAPF64[$0>>3];
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iidi[$func & 3]($obj,$1,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN14ActionInvoker3I27mscorlib_System_Int32TraitsS0_17VoidPointerTraitsE6InvokeEPFvPviiS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$4,$6);
 STACKTOP = sp;return (0|0);
}
function __Z84mscorlib_System_NumberFormatter_CustomAttributesCacheGenerator_threadNumberFormatterP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2649496)|0);
 __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z47mscorlib_System_ObjectDisposedException_m__ctorP39mscorlib_System_ObjectDisposedExceptionP22mscorlib_System_String($__this,$objectName) {
 $__this = $__this|0;
 $objectName = $objectName|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2633992);
 __THREW__ = 0;
 invoke_v(914);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3074496>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1947,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($__this) + 52|0);
    HEAP32[$8>>2] = $objectName;
    $9 = HEAP32[3074504>>2]|0;
    __THREW__ = 0;
    $10 = (invoke_iii(783,(0|0),($9|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = (($__this) + 56|0);
     HEAP32[$13>>2] = $10;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z53mscorlib_System_ObjectDisposedException_m_get_MessageP39mscorlib_System_ObjectDisposedException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2634040);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z55mscorlib_System_ObjectDisposedException_m_GetObjectDataP39mscorlib_System_ObjectDisposedExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2634088);
 __THREW__ = 0;
 invoke_v(915);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $context;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $0;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  __THREW__ = 0;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  invoke_viii(544,($__this|0),($info|0),($tmpcast$byval_copy|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = (($__this) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3074608>>2]|0;
    __THREW__ = 0;
    invoke_viii(621,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
}
function __Z70mscorlib_System_ObjectDisposedException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46mscorlib_System_OperatingSystem_m_get_PlatformP31mscorlib_System_OperatingSystem($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2634616);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z47mscorlib_System_OperatingSystem_m_GetObjectDataP31mscorlib_System_OperatingSystemP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2634664);
 __THREW__ = 0;
 invoke_v(916);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$L_1>>2] = $3;
  __THREW__ = 0;
  (invoke_ii(2996,(2636520|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_iii(2724,(2636520|0),($L_1|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[3074664>>2]|0;
     __THREW__ = 0;
     invoke_viii(621,($info|0),($11|0),($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 12|0);
      $15 = HEAP32[$14>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($info|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       $18 = HEAP32[3074672>>2]|0;
       __THREW__ = 0;
       invoke_viii(621,($info|0),($18|0),($15|0));
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $21 = (($__this) + 16|0);
        $22 = HEAP32[$21>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         $25 = HEAP32[3074680>>2]|0;
         __THREW__ = 0;
         invoke_viii(621,($info|0),($25|0),($22|0));
         $26 = __THREW__; __THREW__ = 0;
         $27 = $26&1;
         if (!($27)) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
}
function __Z42mscorlib_System_OperatingSystem_m_ToStringP31mscorlib_System_OperatingSystem($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2634712);
 __THREW__ = 0;
 invoke_v(917);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = (($__this) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   switch ($3|0) {
   case 0:  {
    $7 = HEAP32[3074768>>2]|0;
    $V_0$0 = $7;
    break;
   }
   case 2:  {
    $6 = HEAP32[3074760>>2]|0;
    $V_0$0 = $6;
    break;
   }
   case 128: case 4:  {
    $10 = HEAP32[3074792>>2]|0;
    $V_0$0 = $10;
    break;
   }
   case 1:  {
    $8 = HEAP32[3074776>>2]|0;
    $V_0$0 = $8;
    break;
   }
   case 3:  {
    $9 = HEAP32[3074784>>2]|0;
    $V_0$0 = $9;
    break;
   }
   case 5:  {
    $11 = HEAP32[3074800>>2]|0;
    $V_0$0 = $11;
    break;
   }
   case 6:  {
    $12 = HEAP32[3074808>>2]|0;
    $V_0$0 = $12;
    break;
   }
   default: {
    $13 = HEAP32[3074816>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_iii(783,(0|0),($13|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break L1;
    } else {
     $V_0$0 = $14;
    }
   }
   }
   $17 = (($__this) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($18|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __THREW__ = 0;
    $21 = (invoke_iii(2730,(2658680|0),($18|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[3074824>>2]|0;
     __THREW__ = 0;
     $25 = (invoke_iiiii(101,(0|0),($V_0$0|0),($24|0),($21|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($25|0);
     }
    }
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z62mscorlib_System_OperatingSystem_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z44mscorlib_System_OutOfMemoryException_m__ctorP36mscorlib_System_OutOfMemoryException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2635216);
 __THREW__ = 0;
 invoke_v(918);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3075040>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2147024882);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z67mscorlib_System_OutOfMemoryException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_OverflowException_m__ctor_mscorlib_System_VoidP33mscorlib_System_OverflowException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2635584);
 __THREW__ = 0;
 invoke_v(919);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3075088>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1927,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233066);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z64mscorlib_System_OverflowException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z57mscorlib_System_PlatformID_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z58mscorlib_System_RankException_m__ctor_mscorlib_System_VoidP29mscorlib_System_RankException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2636656);
 __THREW__ = 0;
 invoke_v(920);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3075136>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233065);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z81mscorlib_System_RankException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP29mscorlib_System_RankExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2636704);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233065);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z60mscorlib_System_RankException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63mscorlib_System_ResolveEventArgs_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z43mscorlib_System_RuntimeMethodHandle_m__ctorP35mscorlib_System_RuntimeMethodHandle22mscorlib_System_IntPtr($__this,$v) {
 $__this = $__this|0;
 $v = $v|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2637264);
 $0 = HEAP32[$v>>2]|0;
 HEAP32[$__this>>2] = $0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z47mscorlib_System_RuntimeMethodHandle_m_get_ValueP35mscorlib_System_RuntimeMethodHandle($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2637312);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z51mscorlib_System_RuntimeMethodHandle_m_GetObjectDataP35mscorlib_System_RuntimeMethodHandleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$byval_copy = 0, $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy3 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2637360);
 __THREW__ = 0;
 invoke_v(921);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   $6 = ($info|0)==(0|0);
   if ($6) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3075256>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3838,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = HEAP32[$__this>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2210080|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP32[((2210080 + 80|0))>>2]|0;
    $23 = HEAP32[$22>>2]|0;
    HEAP32[$0>>2] = $19;
    HEAP32[$1>>2] = $23;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    $24 = (invoke_iiii(643,(0|0),($$byval_copy|0),($$byval_copy3|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     if ($24) {
      __THREW__ = 0;
      (invoke_ii(2996,(2497744|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_ii(3469,(2497744|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = HEAP32[3075264>>2]|0;
      __THREW__ = 0;
      invoke_vii(1896,($29|0),($32|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3838,($29|0));
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      // unreachable;
     }
     $37 = HEAP32[$__this>>2]|0;
     HEAP32[$2>>2] = $37;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
     $38 = (invoke_iii(909,(0|0),($$byval_copy3|0))|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2425520|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       __THREW__ = 0;
       $43 = (invoke_iii(2769,($38|0),(2425520|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if (!($45)) {
        HEAP32[$3>>2] = 2461496;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
        $46 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         __THREW__ = 0;
         invoke_vi(3799,($info|0));
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if (!($50)) {
          $51 = HEAP32[3075272>>2]|0;
          __THREW__ = 0;
          invoke_viiii(168,($info|0),($51|0),($43|0),($46|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z44mscorlib_System_RuntimeMethodHandle_m_EqualsP35mscorlib_System_RuntimeMethodHandleP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $V_0 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp + 8|0;
 $L_0 = sp + 12|0;
 $0 = sp + 16|0;
 $1 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2637408);
 HEAP32[$V_0>>2] = 0;
 $2 = ($obj|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$__this>>2]|0;
 HEAP32[$L_0>>2] = $3;
 __THREW__ = 0;
 (invoke_ii(2996,(2637784|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_iii(2724,(2637784|0),($L_0|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   invoke_vi(3799,($6|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (invoke_ii(1782,($6|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     invoke_vi(3799,($obj|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      $16 = (invoke_ii(1782,($obj|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       $19 = ($11|0)==($16|0);
       if (!($19)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $22 = HEAP32[$__this>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2637784|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        __THREW__ = 0;
        $25 = (invoke_iii(2770,($obj|0),(2637784|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $28 = HEAP32[$25>>2]|0;
         HEAP32[$V_0>>2] = $28;
         __THREW__ = 0;
         $29 = (invoke_ii(2491,($V_0|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          HEAP32[$0>>2] = $22;
          HEAP32[$1>>2] = $29;
          __THREW__ = 0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
          ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
          $32 = (invoke_iiii(643,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           $$0 = $32;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_RuntimeMethodHandle_m_GetHashCodeP35mscorlib_System_RuntimeMethodHandle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2637456);
 __THREW__ = 0;
 $0 = (invoke_ii(1829,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z66mscorlib_System_RuntimeMethodHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2257080)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2637624)|0);
 __Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($7,1);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z111mscorlib_System_RuntimeMethodHandle_CustomAttributesCacheGenerator_mscorlib_System_RuntimeMethodHandle_m_EqualsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2442584)|0);
 __Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii($4,3,2);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z38mscorlib_System_StringComparer_m__ctorP30mscorlib_System_StringComparer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2646496);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z39mscorlib_System_StringComparer_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2646544);
 __THREW__ = 0;
 $0 = (invoke_ii(1982,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2648216|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2648216|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_viii(701,($5|0),($0|0),1);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2647552|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP32[((2647552 + 80|0))>>2]|0;
      HEAP32[$12>>2] = $5;
      __THREW__ = 0;
      $13 = (invoke_ii(1982,(0|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2648216|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        $18 = (invoke_ii(3469,(2648216|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         invoke_viii(701,($18|0),($13|0),0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2647552|0))|0);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           $25 = HEAP32[((2647552 + 80|0))>>2]|0;
           $26 = (($25) + 4|0);
           HEAP32[$26>>2] = $18;
           __THREW__ = 0;
           (invoke_ii(2996,(2648800|0))|0);
           $27 = __THREW__; __THREW__ = 0;
           $28 = $27&1;
           if (!($28)) {
            __THREW__ = 0;
            $29 = (invoke_ii(3469,(2648800|0))|0);
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if (!($31)) {
             __THREW__ = 0;
             invoke_vii(1974,($29|0),1);
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if (!($33)) {
              __THREW__ = 0;
              (invoke_ii(2996,(2647552|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               $36 = HEAP32[((2647552 + 80|0))>>2]|0;
               $37 = (($36) + 8|0);
               HEAP32[$37>>2] = $29;
               __THREW__ = 0;
               (invoke_ii(2996,(2648800|0))|0);
               $38 = __THREW__; __THREW__ = 0;
               $39 = $38&1;
               if (!($39)) {
                __THREW__ = 0;
                $40 = (invoke_ii(3469,(2648800|0))|0);
                $41 = __THREW__; __THREW__ = 0;
                $42 = $41&1;
                if (!($42)) {
                 __THREW__ = 0;
                 invoke_vii(1974,($40|0),0);
                 $43 = __THREW__; __THREW__ = 0;
                 $44 = $43&1;
                 if (!($44)) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2647552|0))|0);
                  $45 = __THREW__; __THREW__ = 0;
                  $46 = $45&1;
                  if (!($46)) {
                   $47 = HEAP32[((2647552 + 80|0))>>2]|0;
                   $48 = (($47) + 12|0);
                   HEAP32[$48>>2] = $40;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $49 = ___cxa_find_matching_catch()|0;
 $50 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($49|0);
 // unreachable;
}
function __Z44mscorlib_System_CultureAwareComparer_m__ctorP36mscorlib_System_CultureAwareComparerP41mscorlib_System_Globalization_CultureInfob($__this,$ci,$ignore_case) {
 $__this = $__this|0;
 $ci = $ci|0;
 $ignore_case = $ignore_case|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2647688);
 __THREW__ = 0;
 invoke_vi(2778,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($ci|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2730,(2304464|0),($ci|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 12|0);
    HEAP32[$7>>2] = $4;
    $8 = (($__this) + 8|0);
    $9 = $ignore_case&1;
    HEAP8[$8>>0] = $9;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z39mscorlib_System_OrdinalComparer_m__ctorP31mscorlib_System_OrdinalComparerb($__this,$ignoreCase) {
 $__this = $__this|0;
 $ignoreCase = $ignoreCase|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2648352);
 __THREW__ = 0;
 invoke_vi(2778,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  $3 = $ignoreCase&1;
  HEAP8[$2>>0] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_StringComparer_m_get_OrdinalIgnoreCaseP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2646592);
 __THREW__ = 0;
 (invoke_ii(2996,(2647552|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2647552 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2647552|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2647552|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3840,(2647552|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2647552|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2647552 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __ZL11RuntimeInitP8TypeInfo9430($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z108mscorlib_System_StringComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP30mscorlib_System_StringComparerP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2646640);
 $0 = ($x|0)==($y|0);
 if ($0) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($x|0)==(0|0);
 if ($1) {
  $$0 = -1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($y|0)==(0|0);
 if ($2) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2735,($x|0),(2191608|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = ($5|0)==(0|0);
    if (!($8)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_iii(2735,($y|0),(2191608|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = ($13|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iiiii(321,(2646688|0),($__this|0),($5|0),($13|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      } else {
       $$0 = $17;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2157896|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     $22 = (invoke_iii(2735,($x|0),(2157896|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $25 = ($22|0)==(0|0);
      if (!($25)) {
       __THREW__ = 0;
       invoke_vi(3799,($22|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if ($36) {
        break;
       }
       __THREW__ = 0;
       $37 = (invoke_iiii(1649,(2157808|0),($22|0),($y|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break;
       } else {
        $$0 = $37;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       $28 = (invoke_ii(3469,(2560072|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        invoke_vi(2583,($28|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         __THREW__ = 0;
         invoke_vi(3841,($28|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if (!($34)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception9431($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z109mscorlib_System_StringComparer_m_Equals_mscorlib_System_Boolean_mscorlib_System_Object_mscorlib_System_ObjectP30mscorlib_System_StringComparerP22mscorlib_System_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2646736);
 $0 = ($x|0)==($y|0);
 if ($0) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($x|0)==(0|0);
 $2 = ($y|0)==(0|0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2735,($x|0),(2191608|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = ($5|0)==(0|0);
    if (!($8)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_iii(2735,($y|0),(2191608|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = ($13|0)==(0|0);
     if (!($16)) {
      __THREW__ = 0;
      $17 = (invoke_iiiii(299,(2646784|0),($__this|0),($5|0),($13|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      } else {
       $$0 = $17;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
    __THREW__ = 0;
    invoke_vi(3799,($x|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     $22 = (invoke_iiii(1644,(2148736|0),($x|0),($y|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $$0 = $22;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_StringComparer_m_GetHashCode_mscorlib_System_Int32_mscorlib_System_ObjectP30mscorlib_System_StringComparerP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2646832);
 __THREW__ = 0;
 invoke_v(922);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($obj|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3075312>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_iii(2735,($obj|0),(2191608|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(0|0);
     if (!($20)) {
      __THREW__ = 0;
      $26 = (invoke_iiii(1641,(2646880|0),($__this|0),($17|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      } else {
       $G_B5_0$0 = $26;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B5_0$0|0);
     }
     __THREW__ = 0;
     invoke_vi(3799,($obj|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      $23 = (invoke_iii(2729,(2148880|0),($obj|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $G_B5_0$0 = $23;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($G_B5_0$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z61mscorlib_System_StringComparer_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46mscorlib_System_CultureAwareComparer_m_CompareP36mscorlib_System_CultureAwareComparerP22mscorlib_System_StringS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2647736);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = (($__this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($3|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $$ = $1&255;
  __THREW__ = 0;
  $6 = (invoke_iiiiii(231,(2304512|0),($3|0),($x|0),($y|0),($$|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($6|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_CultureAwareComparer_m_EqualsP36mscorlib_System_CultureAwareComparerP22mscorlib_System_StringS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2647784);
 __THREW__ = 0;
 $0 = (invoke_iiiii(321,(2647736|0),($__this|0),($x|0),($y|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0|0)==(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z50mscorlib_System_CultureAwareComparer_m_GetHashCodeP36mscorlib_System_CultureAwareComparerP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2647832);
 __THREW__ = 0;
 invoke_v(923);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3075328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   } else {
    $15 = (($__this) + 8|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = (($__this) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($18|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $$ = $16&255;
    __THREW__ = 0;
    $21 = (invoke_iiiii(323,(2326416|0),($18|0),($s|0),($$|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($21|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    __THREW__ = 0;
    $26 = (invoke_iii(2729,(2281128|0),($21|0))|0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z41mscorlib_System_OrdinalComparer_m_CompareP31mscorlib_System_OrdinalComparerP22mscorlib_System_StringS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2648400);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  __THREW__ = 0;
  $8 = (invoke_iiiiiiii(69,(0|0),($x|0),0,2147483647,($y|0),0,2147483647)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $$0 = $8;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  __THREW__ = 0;
  $3 = (invoke_iiiiiiii(70,(0|0),($x|0),0,2147483647,($y|0),0,2147483647)|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $$0 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z40mscorlib_System_OrdinalComparer_m_EqualsP31mscorlib_System_OrdinalComparerP22mscorlib_System_StringS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2648448);
 $0 = (($__this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  __THREW__ = 0;
  $9 = (invoke_iiii(574,(0|0),($x|0),($y|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $$0 = $9;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  __THREW__ = 0;
  $3 = (invoke_iiiii(321,(2648400|0),($__this|0),($x|0),($y|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = ($3|0)==(0);
   $$0 = $6;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z45mscorlib_System_OrdinalComparer_m_GetHashCodeP31mscorlib_System_OrdinalComparerP22mscorlib_System_String($__this,$s) {
 $__this = $__this|0;
 $s = $s|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2648496);
 __THREW__ = 0;
 invoke_v(924);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($s|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3075344>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 8|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    $25 = (invoke_iii(2729,(2185544|0),($s|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    } else {
     $$0 = $25;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($s|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_ii(1818,($s|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    } else {
     $$0 = $20;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_SystemException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP31mscorlib_System_SystemExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2648936);
 __THREW__ = 0;
 invoke_vii(1781,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233087);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z109mscorlib_System_SystemException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ExceptionP31mscorlib_System_SystemExceptionP22mscorlib_System_StringP25mscorlib_System_Exception($__this,$message,$innerException) {
 $__this = $__this|0;
 $message = $message|0;
 $innerException = $innerException|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2648984);
 __THREW__ = 0;
 invoke_viii(543,($__this|0),($message|0),($innerException|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233087);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z62mscorlib_System_SystemException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649360);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z68mscorlib_System_ThreadStaticAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($6,256);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z75mscorlib_System_TimeSpan_m__ctor_mscorlib_System_Void_mscorlib_System_Int64P24mscorlib_System_TimeSpanx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649632);
 $2 = $__this;
 $3 = $2;
 HEAP32[$3>>2] = $0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = $1;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z119mscorlib_System_TimeSpan_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P24mscorlib_System_TimeSpaniii($__this,$hours,$minutes,$seconds) {
 $__this = $__this|0;
 $hours = $hours|0;
 $minutes = $minutes|0;
 $seconds = $seconds|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649680);
 __THREW__ = 0;
 $0 = (invoke_iiiiiii(96,0,0,($hours|0),($minutes|0),($seconds|0),0)|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = $__this;
  $5 = $4;
  HEAP32[$5>>2] = $0;
  $6 = (($4) + 4)|0;
  $7 = $6;
  HEAP32[$7>>2] = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z41mscorlib_System_TimeSpan_m_CalculateTicksP22mscorlib_System_Objectiiiii($__this,$days,$hours,$minutes,$seconds,$milliseconds) {
 $__this = $__this|0;
 $days = $days|0;
 $hours = $hours|0;
 $minutes = $minutes|0;
 $seconds = $seconds|0;
 $milliseconds = $milliseconds|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649824);
 __THREW__ = 0;
 invoke_v(925);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = ($hours*3600)|0;
  $3 = ($minutes*60)|0;
  $4 = (($3) + ($2))|0;
  $5 = (($4) + ($seconds))|0;
  $6 = ($5|0)<(0);
  $7 = $6 << 31 >> 31;
  $8 = (___muldi3(($5|0),($7|0),1000,0)|0);
  $9 = tempRet0;
  $10 = ($milliseconds|0)<(0);
  $11 = $10 << 31 >> 31;
  $12 = (_i64Add(($8|0),($9|0),($milliseconds|0),($11|0))|0);
  $13 = tempRet0;
  $14 = (___muldi3(($12|0),($13|0),10000,0)|0);
  $15 = tempRet0;
  $16 = ($days|0)<(1);
  do {
   if ($16) {
    $31 = ($days|0)>(-1);
    if ($31) {
     $62 = $15;$63 = $14;
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $62;
     STACKTOP = sp;return ($63|0);
    }
    $32 = ($days|0)<(0);
    $33 = $32 << 31 >> 31;
    $34 = (___muldi3(($days|0),($33|0),711573504,201)|0);
    $35 = tempRet0;
    $36 = ($13|0)>(0);
    $37 = ($13|0)==(0);
    $38 = ($12>>>0)>(0);
    $39 = $37 & $38;
    $40 = $36 | $39;
    $41 = (_i64Add(($14|0),($15|0),($34|0),($35|0))|0);
    $42 = tempRet0;
    if ($40) {
     $48 = ($days|0)>(0);
     if ($48) {
      break;
     } else {
      $62 = $42;$63 = $41;
     }
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $62;
     STACKTOP = sp;return ($63|0);
    } else {
     $43 = ($42|0)>(0);
     $44 = ($42|0)==(0);
     $45 = ($41>>>0)>(0);
     $46 = $44 & $45;
     $47 = $43 | $46;
     if ($47) {
      break;
     } else {
      $62 = $42;$63 = $41;
     }
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $62;
     STACKTOP = sp;return ($63|0);
    }
   } else {
    $19 = ($days|0)<(0);
    $20 = $19 << 31 >> 31;
    $21 = (___muldi3(($days|0),($20|0),711573504,201)|0);
    $22 = tempRet0;
    $23 = ($13|0)>(-1);
    $24 = ($13|0)==(-1);
    $25 = ($12>>>0)>(4294967295);
    $26 = $24 & $25;
    $27 = $23 | $26;
    $28 = (_i64Add(($14|0),($15|0),($21|0),($22|0))|0);
    $29 = tempRet0;
    $30 = ($29|0)<(0);
    $or$cond = $27 & $30;
    if (!($or$cond)) {
     $62 = $29;$63 = $28;
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $62;
     STACKTOP = sp;return ($63|0);
    }
   }
  } while(0);
  $49 = HEAP32[3075360>>2]|0;
  __THREW__ = 0;
  $50 = (invoke_iii(783,(0|0),($49|0))|0);
  $51 = __THREW__; __THREW__ = 0;
  $52 = $51&1;
  if (!($52)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $53 = __THREW__; __THREW__ = 0;
   $54 = $53&1;
   if (!($54)) {
    __THREW__ = 0;
    $55 = (invoke_ii(3469,(2561352|0))|0);
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if (!($57)) {
     __THREW__ = 0;
     invoke_vii(1926,($55|0),($50|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      __THREW__ = 0;
      invoke_vi(3841,($55|0));
      $60 = __THREW__; __THREW__ = 0;
      $61 = $60&1;
      if (!($61)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z163mscorlib_System_TimeSpan_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P24mscorlib_System_TimeSpaniiiii($__this,$days,$hours,$minutes,$seconds,$milliseconds) {
 $__this = $__this|0;
 $days = $days|0;
 $hours = $hours|0;
 $minutes = $minutes|0;
 $seconds = $seconds|0;
 $milliseconds = $milliseconds|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649728);
 __THREW__ = 0;
 $0 = (invoke_iiiiiii(96,0,($days|0),($hours|0),($minutes|0),($seconds|0),($milliseconds|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $4 = $__this;
  $5 = $4;
  HEAP32[$5>>2] = $0;
  $6 = (($4) + 4)|0;
  $7 = $6;
  HEAP32[$7>>2] = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z33mscorlib_System_TimeSpan_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $L_1 = 0, $L_3 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_1 = sp;
 $L_3 = sp + 8|0;
 $L_6 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649776);
 $0 = $L_1;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viii(703,($L_1|0),-1,2147483647);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = HEAP32[((2652728 + 80|0))>>2]|0;
    $9 = $L_1;
    $10 = $9;
    $11 = HEAP32[$10>>2]|0;
    $12 = (($9) + 4)|0;
    $13 = $12;
    $14 = HEAP32[$13>>2]|0;
    $15 = $8;
    $16 = $15;
    HEAP32[$16>>2] = $11;
    $17 = (($15) + 4)|0;
    $18 = $17;
    HEAP32[$18>>2] = $14;
    $19 = $L_3;
    $20 = $19;
    HEAP32[$20>>2] = 0;
    $21 = (($19) + 4)|0;
    $22 = $21;
    HEAP32[$22>>2] = 0;
    __THREW__ = 0;
    invoke_viii(703,($L_3|0),0,-2147483648);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if (!($24)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[((2652728 + 80|0))>>2]|0;
      $28 = (($27) + 8|0);
      $29 = $L_3;
      $30 = $29;
      $31 = HEAP32[$30>>2]|0;
      $32 = (($29) + 4)|0;
      $33 = $32;
      $34 = HEAP32[$33>>2]|0;
      $35 = $28;
      $36 = $35;
      HEAP32[$36>>2] = $31;
      $37 = (($35) + 4)|0;
      $38 = $37;
      HEAP32[$38>>2] = $34;
      $39 = $L_6;
      $40 = $39;
      HEAP32[$40>>2] = 0;
      $41 = (($39) + 4)|0;
      $42 = $41;
      HEAP32[$42>>2] = 0;
      __THREW__ = 0;
      invoke_viii(703,($L_6|0),0,0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2652728|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        $47 = HEAP32[((2652728 + 80|0))>>2]|0;
        $48 = (($47) + 16|0);
        $49 = $L_6;
        $50 = $49;
        $51 = HEAP32[$50>>2]|0;
        $52 = (($49) + 4)|0;
        $53 = $52;
        $54 = HEAP32[$53>>2]|0;
        $55 = $48;
        $56 = $55;
        HEAP32[$56>>2] = $51;
        $57 = (($55) + 4)|0;
        $58 = $57;
        HEAP32[$58>>2] = $54;
        __THREW__ = 0;
        (invoke_ii(2996,(2615032|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if (!($60)) {
         $61 = HEAP8[((2615032 + 116|0))>>0]|0;
         $62 = ($61<<24>>24)==(0);
         if ($62) {
          __THREW__ = 0;
          (invoke_ii(2996,(2615032|0))|0);
          $63 = __THREW__; __THREW__ = 0;
          $64 = $63&1;
          if ($64) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2615032|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3840,(2615032|0));
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if ($68) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2615032|0))|0);
         $71 = __THREW__; __THREW__ = 0;
         $72 = $71&1;
         if (!($72)) {
          $73 = HEAP32[((2615032 + 80|0))>>2]|0;
          $74 = HEAP8[$73>>0]|0;
          $75 = ($74<<24>>24)==(0);
          if ($75) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(1685416|0))|0);
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if (!($77)) {
           __THREW__ = 0;
           $78 = (invoke_ii(3469,(1685416|0))|0);
           $79 = __THREW__; __THREW__ = 0;
           $80 = $79&1;
           if (!($80)) {
            __THREW__ = 0;
            invoke_vi(1666,($78|0));
            $81 = __THREW__; __THREW__ = 0;
            $82 = $81&1;
            if (!($82)) {
             __THREW__ = 0;
             (invoke_ii(2996,(1687176|0))|0);
             $83 = __THREW__; __THREW__ = 0;
             $84 = $83&1;
             if (!($84)) {
              __THREW__ = 0;
              $85 = (invoke_ii(3469,(1687176|0))|0);
              $86 = __THREW__; __THREW__ = 0;
              $87 = $86&1;
              if (!($87)) {
               __THREW__ = 0;
               invoke_vi(1670,($85|0));
               $88 = __THREW__; __THREW__ = 0;
               $89 = $88&1;
               if (!($89)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $69 = ___cxa_find_matching_catch()|0;
 $70 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($69|0);
 // unreachable;
}
function __Z35mscorlib_System_TimeSpan_m_get_DaysP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649872);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___divdi3(($2|0),($5|0),711573504,201)|0);
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($6|0);
}
function __Z36mscorlib_System_TimeSpan_m_get_HoursP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649920);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___remdi3(($2|0),($5|0),711573504,201)|0);
 $7 = tempRet0;
 $8 = (___divdi3(($6|0),($7|0),1640261632,8)|0);
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($8|0);
}
function __Z43mscorlib_System_TimeSpan_m_get_MillisecondsP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2649968);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___remdi3(($2|0),($5|0),10000000,0)|0);
 $7 = tempRet0;
 $8 = (___divdi3(($6|0),($7|0),10000,0)|0);
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($8|0);
}
function __Z38mscorlib_System_TimeSpan_m_get_MinutesP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650016);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___remdi3(($2|0),($5|0),1640261632,8)|0);
 $7 = tempRet0;
 $8 = (___divdi3(($6|0),($7|0),600000000,0)|0);
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($8|0);
}
function __Z38mscorlib_System_TimeSpan_m_get_SecondsP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650064);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___remdi3(($2|0),($5|0),600000000,0)|0);
 $7 = tempRet0;
 $8 = (___divdi3(($6|0),($7|0),10000000,0)|0);
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($8|0);
}
function __Z36mscorlib_System_TimeSpan_m_get_TicksP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650112);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 tempRet0 = $5;
 STACKTOP = sp;return ($2|0);
}
function __Z40mscorlib_System_TimeSpan_m_get_TotalDaysP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650160);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (+($2>>>0)) + (4294967296.0*(+($5|0)));
 $7 = $6 / 8.64E+11;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$7);
}
function __Z41mscorlib_System_TimeSpan_m_get_TotalHoursP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650208);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (+($2>>>0)) + (4294967296.0*(+($5|0)));
 $7 = $6 / 3.6E+10;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$7);
}
function __Z48mscorlib_System_TimeSpan_m_get_TotalMillisecondsP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650256);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (+($2>>>0)) + (4294967296.0*(+($5|0)));
 $7 = $6 / 1.0E+4;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$7);
}
function __Z43mscorlib_System_TimeSpan_m_get_TotalMinutesP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650304);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (+($2>>>0)) + (4294967296.0*(+($5|0)));
 $7 = $6 / 6.0E+8;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$7);
}
function __Z43mscorlib_System_TimeSpan_m_get_TotalSecondsP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650352);
 $0 = $__this;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (+($2>>>0)) + (4294967296.0*(+($5|0)));
 $7 = $6 / 1.0E+7;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (+$7);
}
function __Z30mscorlib_System_TimeSpan_m_AddP24mscorlib_System_TimeSpanS_($__this,$ts) {
 $__this = $__this|0;
 $ts = $ts|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650400);
 __THREW__ = 0;
 invoke_v(926);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = $__this;
   $3 = $2;
   $4 = HEAP32[$3>>2]|0;
   $5 = (($2) + 4)|0;
   $6 = $5;
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   $8 = (invoke_ii(2499,($ts|0))|0);
   $9 = tempRet0;
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (_i64Add(($8|0),($9|0),($4|0),($7|0))|0);
    $13 = tempRet0;
    $14 = $L_3;
    $15 = $14;
    HEAP32[$15>>2] = 0;
    $16 = (($14) + 4)|0;
    $17 = $16;
    HEAP32[$17>>2] = 0;
    __THREW__ = 0;
    invoke_viii(703,($L_3|0),($12|0),($13|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = $L_3;
     $21 = $20;
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + 4)|0;
     $24 = $23;
     $25 = HEAP32[$24>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $25;
     STACKTOP = sp;return ($22|0);
    }
   }
   $28 = ___cxa_find_matching_catch(348288|0)|0;
   $29 = tempRet0;
   $30 = (_llvm_eh_typeid_for((348288|0))|0);
   $31 = ($29|0)==($30|0);
   if (!($31)) {
    $$0 = $28;$$01 = $29;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $32 = (___cxa_begin_catch(($28|0))|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   __THREW__ = 0;
   $35 = (invoke_iii(2727,(2635888|0),($34|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   do {
    if (!($37)) {
     if (!($35)) {
      $44 = (___cxa_allocate_exception(4)|0);
      $45 = HEAP32[$32>>2]|0;
      HEAP32[$44>>2] = $45;
      __THREW__ = 0;
      invoke_viii(1567,($44|0),(348288|0),(0|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_v(66);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break L1;
     }
     $48 = HEAP32[3075456>>2]|0;
     __THREW__ = 0;
     $49 = (invoke_iii(783,(0|0),($48|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2635888|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break L1;
     }
     __THREW__ = 0;
     $54 = (invoke_ii(3469,(2635888|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1971,($54|0),($49|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3841,($54|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    $61 = ___cxa_find_matching_catch(0|0)|0;
    $62 = tempRet0;
    ___clang_call_terminate($61);
    // unreachable;
   } else {
    $$0 = $40;$$01 = $41;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 $$0 = $26;$$01 = $27;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __Z34mscorlib_System_TimeSpan_m_CompareP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650448);
 $0 = $t1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $t2;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)<($11|0);
 $13 = ($5|0)==($11|0);
 $14 = ($2>>>0)<($8>>>0);
 $15 = $13 & $14;
 $16 = $12 | $15;
 if ($16) {
  $$0 = -1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $17 = ($5|0)>($11|0);
 $18 = ($5|0)==($11|0);
 $19 = ($2>>>0)>($8>>>0);
 $20 = $18 & $19;
 $21 = $17 | $20;
 $$ = $21&1;
 $$0 = $$;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z81mscorlib_System_TimeSpan_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP24mscorlib_System_TimeSpanP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650496);
 __THREW__ = 0;
 invoke_v(927);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($value|0)==(0|0);
   if ($4) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_iii(2735,($value|0),(2652728|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = ($9|0)==(0|0);
     if (!($12)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2652728|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2771,($value|0),(2652728|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      }
      $32 = $29;
      $33 = $32;
      $34 = HEAP32[$33>>2]|0;
      $35 = (($32) + 4)|0;
      $36 = $35;
      $37 = HEAP32[$36>>2]|0;
      $38 = $__this;
      $39 = $38;
      $40 = HEAP32[$39>>2]|0;
      $41 = (($38) + 4)|0;
      $42 = $41;
      $43 = HEAP32[$42>>2]|0;
      $44 = $0;
      $45 = $44;
      HEAP32[$45>>2] = $40;
      $46 = (($44) + 4)|0;
      $47 = $46;
      HEAP32[$47>>2] = $43;
      $48 = $1;
      $49 = $48;
      HEAP32[$49>>2] = $34;
      $50 = (($48) + 4)|0;
      $51 = $50;
      HEAP32[$51>>2] = $37;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
      $52 = (invoke_iiii(1259,0,($$byval_copy|0),($$byval_copy1|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      } else {
       $$0 = $52;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $13 = HEAP32[3075536>>2]|0;
     __THREW__ = 0;
     $14 = (invoke_iii(783,(0|0),($13|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_ii(3469,(2560072|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = HEAP32[3075544>>2]|0;
        __THREW__ = 0;
        invoke_viii(641,($19|0),($14|0),($22|0));
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3841,($19|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo9456($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z83mscorlib_System_TimeSpan_m_CompareTo_mscorlib_System_Int32_mscorlib_System_TimeSpanP24mscorlib_System_TimeSpanS_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 24|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650544);
 $2 = $__this;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = $value;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = $1;
 $19 = $18;
 HEAP32[$19>>2] = $14;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $22 = (invoke_iiii(1259,0,($$byval_copy|0),($$byval_copy1|0))|0);
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($22|0);
 }
 return 0|0;
}
function __Z82mscorlib_System_TimeSpan_m_Equals_mscorlib_System_Boolean_mscorlib_System_TimeSpanP24mscorlib_System_TimeSpanS_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650592);
 $0 = $obj;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $__this;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($2|0)==($8|0);
 $13 = ($5|0)==($11|0);
 $14 = $12 & $13;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($14|0);
}
function __Z35mscorlib_System_TimeSpan_m_DurationP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650640);
 __THREW__ = 0;
 invoke_v(928);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = $__this;
   $3 = $2;
   $4 = HEAP32[$3>>2]|0;
   $5 = (($2) + 4)|0;
   $6 = $5;
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   $8 = (invoke_ii(3474,($4|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = ($8|0)<(0);
    $12 = $11 << 31 >> 31;
    $13 = $L_2;
    $14 = $13;
    HEAP32[$14>>2] = 0;
    $15 = (($13) + 4)|0;
    $16 = $15;
    HEAP32[$16>>2] = 0;
    __THREW__ = 0;
    invoke_viii(703,($L_2|0),($8|0),($12|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = $L_2;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + 4)|0;
     $23 = $22;
     $24 = HEAP32[$23>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $24;
     STACKTOP = sp;return ($21|0);
    }
   }
   $27 = ___cxa_find_matching_catch(348288|0)|0;
   $28 = tempRet0;
   $29 = (_llvm_eh_typeid_for((348288|0))|0);
   $30 = ($28|0)==($29|0);
   if (!($30)) {
    $$0 = $27;$$01 = $28;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $31 = (___cxa_begin_catch(($27|0))|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = HEAP32[$32>>2]|0;
   __THREW__ = 0;
   $34 = (invoke_iii(2727,(2635888|0),($33|0))|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   do {
    if (!($36)) {
     if (!($34)) {
      $43 = (___cxa_allocate_exception(4)|0);
      $44 = HEAP32[$31>>2]|0;
      HEAP32[$43>>2] = $44;
      __THREW__ = 0;
      invoke_viii(1567,($43|0),(348288|0),(0|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_v(66);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break L1;
     }
     $47 = HEAP32[3075624>>2]|0;
     __THREW__ = 0;
     $48 = (invoke_iii(783,(0|0),($47|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2635888|0))|0);
     $51 = __THREW__; __THREW__ = 0;
     $52 = $51&1;
     if ($52) {
      break L1;
     }
     __THREW__ = 0;
     $53 = (invoke_ii(3469,(2635888|0))|0);
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if ($55) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1971,($53|0),($48|0));
     $56 = __THREW__; __THREW__ = 0;
     $57 = $56&1;
     if ($57) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3841,($53|0));
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $39 = ___cxa_find_matching_catch()|0;
   $40 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $41 = __THREW__; __THREW__ = 0;
   $42 = $41&1;
   if ($42) {
    $60 = ___cxa_find_matching_catch(0|0)|0;
    $61 = tempRet0;
    ___clang_call_terminate($60);
    // unreachable;
   } else {
    $$0 = $39;$$01 = $40;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $$0 = $25;$$01 = $26;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_TimeSpan_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP24mscorlib_System_TimeSpanP22mscorlib_System_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650688);
 __THREW__ = 0;
 (invoke_ii(2996,(2652728|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($value|0),(2652728|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $8 = $__this;
   $9 = $8;
   $10 = HEAP32[$9>>2]|0;
   $11 = (($8) + 4)|0;
   $12 = $11;
   $13 = HEAP32[$12>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __THREW__ = 0;
    $16 = (invoke_iii(2771,($value|0),(2652728|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = $16;
     $20 = $19;
     $21 = HEAP32[$20>>2]|0;
     $22 = (($19) + 4)|0;
     $23 = $22;
     $24 = HEAP32[$23>>2]|0;
     $25 = ($10|0)==($21|0);
     $26 = ($13|0)==($24|0);
     $27 = $25 & $26;
     $$0 = $27;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_TimeSpan_m_GetHashCodeP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650736);
 __THREW__ = 0;
 $0 = (invoke_ii(1794,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z33mscorlib_System_TimeSpan_m_NegateP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $_stackTraceSentry = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650784);
 __THREW__ = 0;
 invoke_v(929);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = $__this;
   $4 = $3;
   $5 = HEAP32[$4>>2]|0;
   $6 = (($3) + 4)|0;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2652728|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP8[((2652728 + 116|0))>>0]|0;
    $12 = ($11<<24>>24)==(0);
    if ($12) {
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2652728|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3840,(2652728|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2652728|0))|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = HEAP32[((2652728 + 80|0))>>2]|0;
     $24 = (($23) + 8|0);
     $25 = $24;
     $26 = $25;
     $27 = HEAP32[$26>>2]|0;
     $28 = (($25) + 4)|0;
     $29 = $28;
     $30 = HEAP32[$29>>2]|0;
     $31 = ($5|0)==($27|0);
     $32 = ($8|0)==($30|0);
     $33 = $31 & $32;
     if (!($33)) {
      $47 = $__this;
      $48 = $47;
      $49 = HEAP32[$48>>2]|0;
      $50 = (($47) + 4)|0;
      $51 = $50;
      $52 = HEAP32[$51>>2]|0;
      $53 = (_i64Subtract(0,0,($49|0),($52|0))|0);
      $54 = tempRet0;
      $55 = $0;
      $56 = $55;
      HEAP32[$56>>2] = 0;
      $57 = (($55) + 4)|0;
      $58 = $57;
      HEAP32[$58>>2] = 0;
      __THREW__ = 0;
      invoke_viii(703,($0|0),($53|0),($54|0));
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      $61 = $0;
      $62 = $61;
      $63 = HEAP32[$62>>2]|0;
      $64 = (($61) + 4)|0;
      $65 = $64;
      $66 = HEAP32[$65>>2]|0;
      tempRet0 = $66;
      STACKTOP = sp;return ($63|0);
     }
     $34 = HEAP32[3075768>>2]|0;
     __THREW__ = 0;
     $35 = (invoke_iii(783,(0|0),($34|0))|0);
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2635888|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if (!($39)) {
       __THREW__ = 0;
       $40 = (invoke_ii(3469,(2635888|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        invoke_vii(1971,($40|0),($35|0));
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if (!($44)) {
         __THREW__ = 0;
         invoke_vi(3841,($40|0));
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if (!($46)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_TimeSpan_m_SubtractP24mscorlib_System_TimeSpanS_($__this,$ts) {
 $__this = $__this|0;
 $ts = $ts|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650832);
 __THREW__ = 0;
 invoke_v(930);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = $__this;
   $3 = $2;
   $4 = HEAP32[$3>>2]|0;
   $5 = (($2) + 4)|0;
   $6 = $5;
   $7 = HEAP32[$6>>2]|0;
   __THREW__ = 0;
   $8 = (invoke_ii(2499,($ts|0))|0);
   $9 = tempRet0;
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = (_i64Subtract(($4|0),($7|0),($8|0),($9|0))|0);
    $13 = tempRet0;
    $14 = $L_3;
    $15 = $14;
    HEAP32[$15>>2] = 0;
    $16 = (($14) + 4)|0;
    $17 = $16;
    HEAP32[$17>>2] = 0;
    __THREW__ = 0;
    invoke_viii(703,($L_3|0),($12|0),($13|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = $L_3;
     $21 = $20;
     $22 = HEAP32[$21>>2]|0;
     $23 = (($20) + 4)|0;
     $24 = $23;
     $25 = HEAP32[$24>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     tempRet0 = $25;
     STACKTOP = sp;return ($22|0);
    }
   }
   $28 = ___cxa_find_matching_catch(348288|0)|0;
   $29 = tempRet0;
   $30 = (_llvm_eh_typeid_for((348288|0))|0);
   $31 = ($29|0)==($30|0);
   if (!($31)) {
    $$0 = $28;$$01 = $29;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
   $32 = (___cxa_begin_catch(($28|0))|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP32[$33>>2]|0;
   __THREW__ = 0;
   $35 = (invoke_iii(2727,(2635888|0),($34|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   do {
    if (!($37)) {
     if (!($35)) {
      $44 = (___cxa_allocate_exception(4)|0);
      $45 = HEAP32[$32>>2]|0;
      HEAP32[$44>>2] = $45;
      __THREW__ = 0;
      invoke_viii(1567,($44|0),(348288|0),(0|0));
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_v(66);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break L1;
     }
     $48 = HEAP32[3075896>>2]|0;
     __THREW__ = 0;
     $49 = (invoke_iii(783,(0|0),($48|0))|0);
     $50 = __THREW__; __THREW__ = 0;
     $51 = $50&1;
     if ($51) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2635888|0))|0);
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      break L1;
     }
     __THREW__ = 0;
     $54 = (invoke_ii(3469,(2635888|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1971,($54|0),($49|0));
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3841,($54|0));
     $59 = __THREW__; __THREW__ = 0;
     $60 = $59&1;
     if ($60) {
      break L1;
     }
     // unreachable;
    }
   } while(0);
   $40 = ___cxa_find_matching_catch()|0;
   $41 = tempRet0;
   __THREW__ = 0;
   invoke_v(66);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    $61 = ___cxa_find_matching_catch(0|0)|0;
    $62 = tempRet0;
    ___clang_call_terminate($61);
    // unreachable;
   } else {
    $$0 = $40;$$01 = $41;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$0|0);
    // unreachable;
   }
  }
 } while(0);
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 $$0 = $26;$$01 = $27;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
 return 0|0;
}
function __Z35mscorlib_System_TimeSpan_m_ToStringP24mscorlib_System_TimeSpan($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_1 = sp;
 $V_2 = sp + 4|0;
 $V_3 = sp + 8|0;
 $V_4 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650880);
 HEAP32[$V_1>>2] = 0;
 HEAP32[$V_2>>2] = 0;
 HEAP32[$V_3>>2] = 0;
 HEAP32[$V_4>>2] = 0;
 __THREW__ = 0;
 invoke_v(931);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2537888|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(2537888|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vii(1910,($4|0),14);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = $__this;
      $10 = $9;
      $11 = HEAP32[$10>>2]|0;
      $12 = (($9) + 4)|0;
      $13 = $12;
      $14 = HEAP32[$13>>2]|0;
      $15 = ($14|0)>(-1);
      $16 = ($14|0)==(-1);
      $17 = ($11>>>0)>(4294967295);
      $18 = $16 & $17;
      $19 = $15 | $18;
      if (!($19)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       __THREW__ = 0;
       (invoke_iii(992,($4|0),45)|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
      }
      __THREW__ = 0;
      $26 = (invoke_ii(2494,($__this|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if (!($28)) {
       $29 = ($26|0)==(0);
       if (!($29)) {
        __THREW__ = 0;
        $30 = (invoke_ii(2494,($__this|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         break;
        }
        __THREW__ = 0;
        $33 = (invoke_ii(3474,($30|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        __THREW__ = 0;
        (invoke_iii(990,($4|0),($33|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         break;
        }
        __THREW__ = 0;
        (invoke_iii(992,($4|0),46)|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
       }
       __THREW__ = 0;
       $44 = (invoke_ii(2495,($__this|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        $47 = (invoke_ii(3474,($44|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if (!($49)) {
         HEAP32[$V_2>>2] = $47;
         $50 = HEAP32[3075912>>2]|0;
         __THREW__ = 0;
         $51 = (invoke_iii(476,($V_2|0),($50|0))|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if (!($53)) {
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if (!($55)) {
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($51|0))|0);
           $56 = __THREW__; __THREW__ = 0;
           $57 = $56&1;
           if (!($57)) {
            __THREW__ = 0;
            invoke_vi(3799,($4|0));
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             __THREW__ = 0;
             (invoke_iii(992,($4|0),58)|0);
             $60 = __THREW__; __THREW__ = 0;
             $61 = $60&1;
             if (!($61)) {
              __THREW__ = 0;
              $62 = (invoke_ii(2497,($__this|0))|0);
              $63 = __THREW__; __THREW__ = 0;
              $64 = $63&1;
              if (!($64)) {
               __THREW__ = 0;
               $65 = (invoke_ii(3474,($62|0))|0);
               $66 = __THREW__; __THREW__ = 0;
               $67 = $66&1;
               if (!($67)) {
                HEAP32[$V_3>>2] = $65;
                $68 = HEAP32[3075920>>2]|0;
                __THREW__ = 0;
                $69 = (invoke_iii(476,($V_3|0),($68|0))|0);
                $70 = __THREW__; __THREW__ = 0;
                $71 = $70&1;
                if (!($71)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $72 = __THREW__; __THREW__ = 0;
                 $73 = $72&1;
                 if (!($73)) {
                  __THREW__ = 0;
                  (invoke_iii(989,($4|0),($69|0))|0);
                  $74 = __THREW__; __THREW__ = 0;
                  $75 = $74&1;
                  if (!($75)) {
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $76 = __THREW__; __THREW__ = 0;
                   $77 = $76&1;
                   if ($77) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(992,($4|0),58)|0);
                   $78 = __THREW__; __THREW__ = 0;
                   $79 = $78&1;
                   if ($79) {
                    break;
                   }
                   __THREW__ = 0;
                   $80 = (invoke_ii(2498,($__this|0))|0);
                   $81 = __THREW__; __THREW__ = 0;
                   $82 = $81&1;
                   if ($82) {
                    break;
                   }
                   __THREW__ = 0;
                   $83 = (invoke_ii(3474,($80|0))|0);
                   $84 = __THREW__; __THREW__ = 0;
                   $85 = $84&1;
                   if ($85) {
                    break;
                   }
                   HEAP32[$V_4>>2] = $83;
                   $86 = HEAP32[3075928>>2]|0;
                   __THREW__ = 0;
                   $87 = (invoke_iii(476,($V_4|0),($86|0))|0);
                   $88 = __THREW__; __THREW__ = 0;
                   $89 = $88&1;
                   if ($89) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $90 = __THREW__; __THREW__ = 0;
                   $91 = $90&1;
                   if ($91) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_iii(989,($4|0),($87|0))|0);
                   $92 = __THREW__; __THREW__ = 0;
                   $93 = $92&1;
                   if ($93) {
                    break;
                   }
                   $94 = $__this;
                   $95 = $94;
                   $96 = HEAP32[$95>>2]|0;
                   $97 = (($94) + 4)|0;
                   $98 = $97;
                   $99 = HEAP32[$98>>2]|0;
                   $100 = (___remdi3(($96|0),($99|0),10000000,0)|0);
                   $101 = tempRet0;
                   __THREW__ = 0;
                   $102 = (invoke_ii(3474,($100|0))|0);
                   $103 = __THREW__; __THREW__ = 0;
                   $104 = $103&1;
                   if ($104) {
                    break;
                   }
                   HEAP32[$V_1>>2] = $102;
                   $105 = ($102|0)==(0);
                   if (!($105)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($4|0));
                    $106 = __THREW__; __THREW__ = 0;
                    $107 = $106&1;
                    if ($107) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_iii(992,($4|0),46)|0);
                    $108 = __THREW__; __THREW__ = 0;
                    $109 = $108&1;
                    if ($109) {
                     break;
                    }
                    $110 = HEAP32[3075936>>2]|0;
                    __THREW__ = 0;
                    $111 = (invoke_iii(476,($V_1|0),($110|0))|0);
                    $112 = __THREW__; __THREW__ = 0;
                    $113 = $112&1;
                    if ($113) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($4|0));
                    $114 = __THREW__; __THREW__ = 0;
                    $115 = $114&1;
                    if ($115) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_iii(989,($4|0),($111|0))|0);
                    $116 = __THREW__; __THREW__ = 0;
                    $117 = $116&1;
                    if ($117) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $118 = __THREW__; __THREW__ = 0;
                   $119 = $118&1;
                   if ($119) {
                    break;
                   }
                   __THREW__ = 0;
                   $120 = (invoke_iii(2730,(2535432|0),($4|0))|0);
                   $121 = __THREW__; __THREW__ = 0;
                   $122 = $121&1;
                   if ($122) {
                    break;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($120|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_TimeSpan_m_op_Addition_mscorlib_System_TimeSpan_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp + 16|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650928);
 $1 = $t2;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(1159,($t1|0),($$byval_copy|0))|0);
 $12 = tempRet0;
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $12;
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z112mscorlib_System_TimeSpan_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2650976);
 $0 = $t1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $t2;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($2|0)==($8|0);
 $13 = ($5|0)==($11|0);
 $14 = $12 & $13;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($14|0);
}
function __Z115mscorlib_System_TimeSpan_m_op_GreaterThan_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2651024);
 $0 = $t1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $t2;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)>($11|0);
 $13 = ($5|0)==($11|0);
 $14 = ($2>>>0)>($8>>>0);
 $15 = $13 & $14;
 $16 = $12 | $15;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($16|0);
}
function __Z122mscorlib_System_TimeSpan_m_op_GreaterThanOrEqual_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2651072);
 $0 = $t1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $t2;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)>($11|0);
 $13 = ($5|0)==($11|0);
 $14 = ($2>>>0)>=($8>>>0);
 $15 = $13 & $14;
 $16 = $12 | $15;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($16|0);
}
function __Z114mscorlib_System_TimeSpan_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2651120);
 $0 = $t1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $t2;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($2|0)!=($8|0);
 $13 = ($5|0)!=($11|0);
 $14 = $12 | $13;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($14|0);
}
function __Z112mscorlib_System_TimeSpan_m_op_LessThan_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2651168);
 $0 = $t1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $t2;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)<($11|0);
 $13 = ($5|0)==($11|0);
 $14 = ($2>>>0)<($8>>>0);
 $15 = $13 & $14;
 $16 = $12 | $15;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($16|0);
}
function __Z119mscorlib_System_TimeSpan_m_op_LessThanOrEqual_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2651216);
 $0 = $t1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $t2;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)<($11|0);
 $13 = ($5|0)==($11|0);
 $14 = ($2>>>0)<=($8>>>0);
 $15 = $13 & $14;
 $16 = $12 | $15;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($16|0);
}
function __Z116mscorlib_System_TimeSpan_m_op_Subtraction_mscorlib_System_TimeSpan_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_($__this,$t1,$t2) {
 $__this = $__this|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp + 16|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2651264);
 $1 = $t2;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $11 = (invoke_iii(1164,($t1|0),($$byval_copy|0))|0);
 $12 = tempRet0;
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $12;
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker5I27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEPFvPviiiiiES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$1,$4,$7,$10,$13);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker5I27mscorlib_System_Int64Traits27mscorlib_System_Int32TraitsS1_S1_S1_S1_E6InvokeEPFxPviiiiiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$12>>2]|0;
 $14 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$1,$4,$7,$10,$13)|0);
 $15 = tempRet0;
 $16 = $ret;
 $17 = $16;
 HEAP32[$17>>2] = $14;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2162248,$ret)|0);
 STACKTOP = sp;return ($20|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_TimeSpanTraitsS0_E6InvokeEPF24mscorlib_System_TimeSpanPvS2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $ret = sp;
 $0 = sp + 8|0;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 $13 = tempRet0;
 $14 = $ret;
 $15 = $14;
 HEAP32[$15>>2] = $12;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 $18 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2652728,$ret)|0);
 STACKTOP = sp;return ($18|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsE6InvokeEPFbPv24mscorlib_System_TimeSpanES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __ZN12FuncInvoker2I30mscorlib_System_TimeSpanTraitsS0_S0_E6InvokeEPF24mscorlib_System_TimeSpanPvS2_S2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy1 = sp + 32|0;
 $$byval_copy = sp;
 $ret = sp + 8|0;
 $0 = sp + 16|0;
 $1 = sp + 24|0;
 $2 = HEAP32[$args>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($args) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $25 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$$byval_copy1)|0);
 $26 = tempRet0;
 $27 = $ret;
 $28 = $27;
 HEAP32[$28>>2] = $25;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $26;
 $31 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2652728,$ret)|0);
 STACKTOP = sp;return ($31|0);
}
function __Z55mscorlib_System_TimeSpan_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z32mscorlib_System_TimeZone_m__ctorP24mscorlib_System_TimeZone($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2652864);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z33mscorlib_System_TimeZone_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2652912);
 __THREW__ = 0;
 $0 = (invoke_ii(2431,(0|0))|0);
 $1 = tempRet0;
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2655088|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2655088|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viii(706,($6|0),($0|0),($1|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2653856|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = HEAP32[((2653856 + 80|0))>>2]|0;
      HEAP32[$13>>2] = $6;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z45mscorlib_System_CurrentSystemTimeZone_m__ctorP37mscorlib_System_CurrentSystemTimeZonex($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$pre = 0, $$pre6 = 0, $$pre7 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 28|0;
 $V_0 = sp + 20|0;
 $V_1 = sp + 16|0;
 $V_2 = sp;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2653992);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 ;HEAP32[$V_2+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[2654384+12>>2]|0;
 __THREW__ = 0;
 invoke_v(932);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2313960|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_ii(3469,(2313960|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vii(1822,($6|0),1);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = (($__this) + 16|0);
      HEAP32[$11>>2] = $6;
      __THREW__ = 0;
      invoke_vi(2786,($__this|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       invoke_viii(661,($V_2|0),($0|0),($1|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        $16 = (invoke_ii(2433,($V_2|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         __THREW__ = 0;
         $19 = (invoke_iiiii(199,0,($16|0),($V_0|0),($V_1|0))|0);
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if (!($21)) {
          if (!($19)) {
           $24 = HEAP32[3076016>>2]|0;
           __THREW__ = 0;
           $25 = (invoke_iii(783,(0|0),($24|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if ($27) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2622808|0))|0);
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if ($29) {
            break;
           }
           __THREW__ = 0;
           $30 = (invoke_ii(3469,(2622808|0))|0);
           $31 = __THREW__; __THREW__ = 0;
           $32 = $31&1;
           if ($32) {
            break;
           }
           __THREW__ = 0;
           invoke_vii(1954,($30|0),($25|0));
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if ($34) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3841,($30|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if ($36) {
            break;
           }
           // unreachable;
          }
          $37 = HEAP32[$V_1>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($37|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if (!($39)) {
           $40 = HEAP32[$V_1>>2]|0;
           $41 = (($40) + 12|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = ($42|0)==(0);
           if ($43) {
            __THREW__ = 0;
            $44 = (invoke_i(132)|0);
            $45 = __THREW__; __THREW__ = 0;
            $46 = $45&1;
            if ($46) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($44|0));
            $47 = __THREW__; __THREW__ = 0;
            $48 = $47&1;
            if ($48) {
             break;
            }
            $$pre = HEAP32[$V_1>>2]|0;
            $50 = $$pre;
           } else {
            $50 = $40;
           }
           $49 = (($50) + 16|0);
           $51 = HEAP32[$49>>2]|0;
           __THREW__ = 0;
           $52 = (invoke_iii(783,(0|0),($51|0))|0);
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if (!($54)) {
            $55 = (($__this) + 8|0);
            HEAP32[$55>>2] = $52;
            $56 = HEAP32[$V_1>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($56|0));
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             $59 = HEAP32[$V_1>>2]|0;
             $60 = (($59) + 12|0);
             $61 = HEAP32[$60>>2]|0;
             $62 = ($61>>>0)<(2);
             if ($62) {
              __THREW__ = 0;
              $63 = (invoke_i(132)|0);
              $64 = __THREW__; __THREW__ = 0;
              $65 = $64&1;
              if ($65) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($63|0));
              $66 = __THREW__; __THREW__ = 0;
              $67 = $66&1;
              if ($67) {
               break;
              }
              $$pre6 = HEAP32[$V_1>>2]|0;
              $69 = $$pre6;
             } else {
              $69 = $59;
             }
             $68 = HEAP32[$69>>2]|0;
             $70 = (($69) + 16|0);
             $71 = (($68) + 92|0);
             $72 = HEAP32[$71>>2]|0;
             $73 = (($70) + ($72)|0);
             $74 = HEAP32[$73>>2]|0;
             __THREW__ = 0;
             $75 = (invoke_iii(783,(0|0),($74|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if (!($77)) {
              $78 = (($__this) + 12|0);
              HEAP32[$78>>2] = $75;
              $79 = HEAP32[$V_0>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($79|0));
              $80 = __THREW__; __THREW__ = 0;
              $81 = $80&1;
              if (!($81)) {
               $82 = HEAP32[$V_0>>2]|0;
               $83 = (($82) + 12|0);
               $84 = HEAP32[$83>>2]|0;
               $85 = ($84>>>0)<(3);
               if ($85) {
                __THREW__ = 0;
                $86 = (invoke_i(132)|0);
                $87 = __THREW__; __THREW__ = 0;
                $88 = $87&1;
                if ($88) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($86|0));
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if ($90) {
                 break;
                }
                $$pre7 = HEAP32[$V_0>>2]|0;
                $92 = $$pre7;
               } else {
                $92 = $82;
               }
               $91 = HEAP32[$92>>2]|0;
               $93 = (($92) + 16|0);
               $94 = (($91) + 92|0);
               $95 = HEAP32[$94>>2]|0;
               $96 = $95 << 1;
               $97 = (($93) + ($96)|0);
               $98 = $97;
               $99 = $98;
               $100 = HEAP32[$99>>2]|0;
               $101 = (($98) + 4)|0;
               $102 = $101;
               $103 = HEAP32[$102>>2]|0;
               $104 = (($__this) + 24|0);
               $105 = $104;
               $106 = $105;
               HEAP32[$106>>2] = $100;
               $107 = (($105) + 4)|0;
               $108 = $107;
               HEAP32[$108>>2] = $103;
               __THREW__ = 0;
               $109 = (invoke_iii(1169,0,($92|0))|0);
               $110 = __THREW__; __THREW__ = 0;
               $111 = $110&1;
               if (!($111)) {
                $112 = HEAP32[$11>>2]|0;
                __THREW__ = 0;
                $113 = (invoke_ii(2433,($V_2|0))|0);
                $114 = __THREW__; __THREW__ = 0;
                $115 = $114&1;
                if (!($115)) {
                 HEAP32[$L_17>>2] = $113;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2155952|0))|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 $118 = (invoke_iii(2724,(2155952|0),($L_17|0))|0);
                 $119 = __THREW__; __THREW__ = 0;
                 $120 = $119&1;
                 if ($120) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($112|0));
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiii(465,(2311184|0),($112|0),($118|0),($109|0));
                 $123 = __THREW__; __THREW__ = 0;
                 $124 = $123&1;
                 if ($124) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vii(1976,($__this|0),($109|0));
                 $125 = __THREW__; __THREW__ = 0;
                 $126 = $125&1;
                 if ($126) {
                  break;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
}
function __Z46mscorlib_System_TimeZone_m_get_CurrentTimeZoneP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2652960);
 __THREW__ = 0;
 (invoke_ii(2996,(2653856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2653856 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2653856|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2653856|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3840,(2653856|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2653856|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2653856 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($15|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_TimeZone_m_IsDaylightSavingTime_mscorlib_System_Boolean_mscorlib_System_DateTimeP24mscorlib_System_TimeZone24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $time$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2653008);
 __THREW__ = 0;
 $0 = (invoke_ii(2433,($time|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (invoke_iiii(1642,(2653056|0),($__this|0),($0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
   $6 = (invoke_iiii(1270,0,($time$byval_copy|0),($3|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($6|0);
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z139mscorlib_System_TimeZone_m_IsDaylightSavingTime_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_Globalization_DaylightTimeP22mscorlib_System_Object24mscorlib_System_DateTimeP42mscorlib_System_Globalization_DaylightTime($__this,$time,$daylightTimes) {
 $__this = $__this|0;
 $time = $time|0;
 $daylightTimes = $daylightTimes|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_1 = 0, $L_10 = 0, $L_13 = 0, $L_18 = 0, $L_21 = 0, $L_24 = 0, $L_27 = 0, $L_3 = 0, $L_6 = 0, $L_8 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0;
 var $V_4 = 0, $V_5 = 0, $V_6 = 0, $V_7 = 0, $V_8 = 0, $V_9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $_stackTraceSentry = sp + 320|0;
 $V_0 = sp + 304|0;
 $V_1 = sp + 288|0;
 $V_2 = sp + 272|0;
 $V_3 = sp + 256|0;
 $V_4 = sp + 240|0;
 $V_5 = sp + 224|0;
 $V_6 = sp + 208|0;
 $V_7 = sp + 192|0;
 $V_8 = sp + 176|0;
 $V_9 = sp + 160|0;
 $L_1 = sp + 48|0;
 $L_3 = sp;
 $L_6 = sp + 16|0;
 $L_8 = sp + 32|0;
 $L_10 = sp + 64|0;
 $L_13 = sp + 80|0;
 $L_18 = sp + 96|0;
 $L_21 = sp + 112|0;
 $L_24 = sp + 128|0;
 $L_27 = sp + 144|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2653104);
 ;HEAP32[$V_0+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_1+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_2+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_3+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_4+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_5+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_5+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_5+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_5+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_6+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_6+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_6+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_6+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_7+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_7+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_7+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_7+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_8+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_8+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_8+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_8+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_9+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_9+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_9+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_9+12>>2]=HEAP32[2654384+12>>2]|0;
 __THREW__ = 0;
 invoke_v(933);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($daylightTimes|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3075968>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($daylightTimes|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    invoke_vii(1838,($L_1|0),($daylightTimes|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     ;HEAP32[$V_0+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_1+12>>2]|0;
     __THREW__ = 0;
     $19 = (invoke_ii(2432,($V_0|0))|0);
     $20 = tempRet0;
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      invoke_vi(3799,($daylightTimes|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       invoke_vii(1839,($L_3|0),($daylightTimes|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        ;HEAP32[$V_1+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_3+12>>2]|0;
        __THREW__ = 0;
        $27 = (invoke_ii(2432,($V_1|0))|0);
        $28 = tempRet0;
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         $31 = ($19|0)==($27|0);
         $32 = ($20|0)==($28|0);
         $33 = $31 & $32;
         if ($33) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($daylightTimes|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if (!($35)) {
          __THREW__ = 0;
          invoke_vii(1838,($L_6|0),($daylightTimes|0));
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if (!($37)) {
           ;HEAP32[$V_2+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_6+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_6+12>>2]|0;
           __THREW__ = 0;
           $38 = (invoke_ii(2432,($V_2|0))|0);
           $39 = tempRet0;
           $40 = __THREW__; __THREW__ = 0;
           $41 = $40&1;
           if (!($41)) {
            __THREW__ = 0;
            invoke_vi(3799,($daylightTimes|0));
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if (!($43)) {
             __THREW__ = 0;
             invoke_vii(1839,($L_8|0),($daylightTimes|0));
             $44 = __THREW__; __THREW__ = 0;
             $45 = $44&1;
             if (!($45)) {
              ;HEAP32[$V_3+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[$L_8+12>>2]|0;
              __THREW__ = 0;
              $46 = (invoke_ii(2432,($V_3|0))|0);
              $47 = tempRet0;
              $48 = __THREW__; __THREW__ = 0;
              $49 = $48&1;
              if (!($49)) {
               $50 = ($39|0)<($47|0);
               $51 = ($39|0)==($47|0);
               $52 = ($38>>>0)<($46>>>0);
               $53 = $51 & $52;
               $54 = $50 | $53;
               do {
                if ($54) {
                 __THREW__ = 0;
                 invoke_vi(3799,($daylightTimes|0));
                 $55 = __THREW__; __THREW__ = 0;
                 $56 = $55&1;
                 if ($56) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(1838,($L_10|0),($daylightTimes|0));
                 $57 = __THREW__; __THREW__ = 0;
                 $58 = $57&1;
                 if ($58) {
                  break L1;
                 }
                 ;HEAP32[$V_4+0>>2]=HEAP32[$L_10+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_10+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_10+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[$L_10+12>>2]|0;
                 __THREW__ = 0;
                 $59 = (invoke_ii(2432,($V_4|0))|0);
                 $60 = tempRet0;
                 $61 = __THREW__; __THREW__ = 0;
                 $62 = $61&1;
                 if ($62) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $63 = (invoke_ii(2432,($time|0))|0);
                 $64 = tempRet0;
                 $65 = __THREW__; __THREW__ = 0;
                 $66 = $65&1;
                 if ($66) {
                  break L1;
                 }
                 $67 = ($60|0)<($64|0);
                 $68 = ($60|0)==($64|0);
                 $69 = ($59>>>0)<($63>>>0);
                 $70 = $68 & $69;
                 $71 = $67 | $70;
                 if (!($71)) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($daylightTimes|0));
                 $72 = __THREW__; __THREW__ = 0;
                 $73 = $72&1;
                 if ($73) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(1839,($L_13|0),($daylightTimes|0));
                 $74 = __THREW__; __THREW__ = 0;
                 $75 = $74&1;
                 if ($75) {
                  break L1;
                 }
                 ;HEAP32[$V_5+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$V_5+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$V_5+8>>2]=HEAP32[$L_13+8>>2]|0;HEAP32[$V_5+12>>2]=HEAP32[$L_13+12>>2]|0;
                 __THREW__ = 0;
                 $76 = (invoke_ii(2432,($V_5|0))|0);
                 $77 = tempRet0;
                 $78 = __THREW__; __THREW__ = 0;
                 $79 = $78&1;
                 if ($79) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $80 = (invoke_ii(2432,($time|0))|0);
                 $81 = tempRet0;
                 $82 = __THREW__; __THREW__ = 0;
                 $83 = $82&1;
                 if ($83) {
                  break L1;
                 }
                 $84 = ($77|0)>($81|0);
                 $85 = ($77|0)==($81|0);
                 $86 = ($76>>>0)>($80>>>0);
                 $87 = $85 & $86;
                 $88 = $84 | $87;
                 if ($88) {
                  $$0 = 1;
                 } else {
                  break;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                } else {
                 __THREW__ = 0;
                 $89 = (invoke_ii(2433,($time|0))|0);
                 $90 = __THREW__; __THREW__ = 0;
                 $91 = $90&1;
                 if ($91) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($daylightTimes|0));
                 $92 = __THREW__; __THREW__ = 0;
                 $93 = $92&1;
                 if ($93) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(1838,($L_18|0),($daylightTimes|0));
                 $94 = __THREW__; __THREW__ = 0;
                 $95 = $94&1;
                 if ($95) {
                  break L1;
                 }
                 ;HEAP32[$V_6+0>>2]=HEAP32[$L_18+0>>2]|0;HEAP32[$V_6+4>>2]=HEAP32[$L_18+4>>2]|0;HEAP32[$V_6+8>>2]=HEAP32[$L_18+8>>2]|0;HEAP32[$V_6+12>>2]=HEAP32[$L_18+12>>2]|0;
                 __THREW__ = 0;
                 $96 = (invoke_ii(2433,($V_6|0))|0);
                 $97 = __THREW__; __THREW__ = 0;
                 $98 = $97&1;
                 if ($98) {
                  break L1;
                 }
                 $99 = ($89|0)==($96|0);
                 if (!($99)) {
                  break;
                 }
                 __THREW__ = 0;
                 $100 = (invoke_ii(2433,($time|0))|0);
                 $101 = __THREW__; __THREW__ = 0;
                 $102 = $101&1;
                 if ($102) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($daylightTimes|0));
                 $103 = __THREW__; __THREW__ = 0;
                 $104 = $103&1;
                 if ($104) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(1839,($L_21|0),($daylightTimes|0));
                 $105 = __THREW__; __THREW__ = 0;
                 $106 = $105&1;
                 if ($106) {
                  break L1;
                 }
                 ;HEAP32[$V_7+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$V_7+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$V_7+8>>2]=HEAP32[$L_21+8>>2]|0;HEAP32[$V_7+12>>2]=HEAP32[$L_21+12>>2]|0;
                 __THREW__ = 0;
                 $107 = (invoke_ii(2433,($V_7|0))|0);
                 $108 = __THREW__; __THREW__ = 0;
                 $109 = $108&1;
                 if ($109) {
                  break L1;
                 }
                 $110 = ($100|0)==($107|0);
                 if (!($110)) {
                  break;
                 }
                 __THREW__ = 0;
                 $111 = (invoke_ii(2432,($time|0))|0);
                 $112 = tempRet0;
                 $113 = __THREW__; __THREW__ = 0;
                 $114 = $113&1;
                 if ($114) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($daylightTimes|0));
                 $115 = __THREW__; __THREW__ = 0;
                 $116 = $115&1;
                 if ($116) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(1839,($L_24|0),($daylightTimes|0));
                 $117 = __THREW__; __THREW__ = 0;
                 $118 = $117&1;
                 if ($118) {
                  break L1;
                 }
                 ;HEAP32[$V_8+0>>2]=HEAP32[$L_24+0>>2]|0;HEAP32[$V_8+4>>2]=HEAP32[$L_24+4>>2]|0;HEAP32[$V_8+8>>2]=HEAP32[$L_24+8>>2]|0;HEAP32[$V_8+12>>2]=HEAP32[$L_24+12>>2]|0;
                 __THREW__ = 0;
                 $119 = (invoke_ii(2432,($V_8|0))|0);
                 $120 = tempRet0;
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  break L1;
                 }
                 $123 = ($112|0)<($120|0);
                 $124 = ($112|0)==($120|0);
                 $125 = ($111>>>0)<($119>>>0);
                 $126 = $124 & $125;
                 $127 = $123 | $126;
                 if ($127) {
                  $$0 = 1;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                 __THREW__ = 0;
                 $128 = (invoke_ii(2432,($time|0))|0);
                 $129 = tempRet0;
                 $130 = __THREW__; __THREW__ = 0;
                 $131 = $130&1;
                 if ($131) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($daylightTimes|0));
                 $132 = __THREW__; __THREW__ = 0;
                 $133 = $132&1;
                 if ($133) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(1838,($L_27|0),($daylightTimes|0));
                 $134 = __THREW__; __THREW__ = 0;
                 $135 = $134&1;
                 if ($135) {
                  break L1;
                 }
                 ;HEAP32[$V_9+0>>2]=HEAP32[$L_27+0>>2]|0;HEAP32[$V_9+4>>2]=HEAP32[$L_27+4>>2]|0;HEAP32[$V_9+8>>2]=HEAP32[$L_27+8>>2]|0;HEAP32[$V_9+12>>2]=HEAP32[$L_27+12>>2]|0;
                 __THREW__ = 0;
                 $136 = (invoke_ii(2432,($V_9|0))|0);
                 $137 = tempRet0;
                 $138 = __THREW__; __THREW__ = 0;
                 $139 = $138&1;
                 if ($139) {
                  break L1;
                 }
                 $140 = ($129|0)>($137|0);
                 $141 = ($129|0)==($137|0);
                 $142 = ($128>>>0)>($136>>>0);
                 $143 = $141 & $142;
                 $144 = $140 | $143;
                 if ($144) {
                  $$0 = 1;
                 } else {
                  break;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               } while(0);
               $$0 = 0;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z38mscorlib_System_TimeZone_m_ToLocalTimeP24mscorlib_System_TimeZone24mscorlib_System_DateTime($agg$result,$__this,$time) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_11 = 0, $L_22 = 0, $L_23 = 0, $L_29 = 0, $L_30 = 0, $L_32 = 0, $L_34 = 0, $L_34$byval_copy = 0;
 var $L_37 = 0, $L_39 = 0, $L_39$byval_copy = 0, $L_41 = 0, $L_7 = 0, $V_0 = 0, $V_1 = 0, $V_4 = 0, $V_5 = 0, $V_6 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 400|0;
 $L_39$byval_copy = sp + 368|0;
 $L_34$byval_copy = sp + 336|0;
 $0 = sp + 352|0;
 $data$i = sp + 384|0;
 $1 = sp + 320|0;
 $_stackTraceSentry = sp + 392|0;
 $V_0 = sp + 312|0;
 $V_1 = sp + 296|0;
 $V_4 = sp + 280|0;
 $V_5 = sp + 272|0;
 $V_6 = sp + 256|0;
 $L_7 = sp + 240|0;
 $2 = sp + 224|0;
 $3 = sp + 216|0;
 $L_11 = sp + 200|0;
 $4 = sp + 72|0;
 $L_22 = sp;
 $5 = sp + 16|0;
 $L_23 = sp + 32|0;
 $6 = sp + 48|0;
 $L_29 = sp + 56|0;
 $L_30 = sp + 88|0;
 $L_32 = sp + 104|0;
 $L_34 = sp + 120|0;
 $7 = sp + 136|0;
 $L_37 = sp + 144|0;
 $L_39 = sp + 160|0;
 $8 = sp + 176|0;
 $L_41 = sp + 184|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2653152);
 $9 = $V_0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = 0;
 ;HEAP32[$V_1+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_4+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[2654384+12>>2]|0;
 $13 = $V_5;
 $14 = $13;
 HEAP32[$14>>2] = 0;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = 0;
 ;HEAP32[$V_6+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_6+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_6+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_6+12>>2]=HEAP32[2654384+12>>2]|0;
 __THREW__ = 0;
 $17 = (invoke_ii(2434,($time|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 L1: do {
  if (!($19)) {
   $20 = ($17|0)==(2);
   if ($20) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$time+12>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   ;HEAP32[$1+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$time+12>>2]|0;
   __THREW__ = 0;
   invoke_viii(2112,($data$i|0),(2653200|0),($__this|0));
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    $25 = (($data$i) + 4|0);
    $26 = HEAP32[$25>>2]|0;
    $27 = (($26) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = HEAP32[$data$i>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
    $30 = (invoke_iii($28|0,($29|0),($L_39$byval_copy|0))|0);
    $31 = tempRet0;
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     $34 = $V_0;
     $35 = $34;
     HEAP32[$35>>2] = $30;
     $36 = (($34) + 4)|0;
     $37 = $36;
     HEAP32[$37>>2] = $31;
     __THREW__ = 0;
     $38 = (invoke_ii(2499,($V_0|0))|0);
     $39 = tempRet0;
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if (!($41)) {
      $42 = ($39|0)<(0);
      $43 = ($39|0)==(0);
      $44 = ($38>>>0)<(1);
      $45 = $43 & $44;
      $46 = $42 | $45;
      if ($46) {
       __THREW__ = 0;
       $90 = (invoke_ii(2499,($V_0|0))|0);
       $91 = tempRet0;
       $92 = __THREW__; __THREW__ = 0;
       $93 = $92&1;
       if ($93) {
        break;
       }
       $94 = ($91|0)>(-1);
       $95 = ($91|0)==(-1);
       $96 = ($90>>>0)>(4294967295);
       $97 = $95 & $96;
       $98 = $94 | $97;
       if (!($98)) {
        __THREW__ = 0;
        $99 = (invoke_ii(2432,($time|0))|0);
        $100 = tempRet0;
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         break;
        }
        __THREW__ = 0;
        $103 = (invoke_ii(2499,($V_0|0))|0);
        $104 = tempRet0;
        $105 = __THREW__; __THREW__ = 0;
        $106 = $105&1;
        if ($106) {
         break;
        }
        $107 = (_i64Add(($103|0),($104|0),($99|0),($100|0))|0);
        $108 = tempRet0;
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $109 = __THREW__; __THREW__ = 0;
        $110 = $109&1;
        if ($110) {
         break;
        }
        $111 = HEAP8[((2592096 + 116|0))>>0]|0;
        $112 = ($111<<24>>24)==(0);
        if ($112) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3840,(2592096|0));
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         break;
        }
        $121 = HEAP32[((2592096 + 80|0))>>2]|0;
        $122 = (($121) + 16|0);
        _memmove(($V_4|0),($122|0),16)|0;
        __THREW__ = 0;
        $123 = (invoke_ii(2432,($V_4|0))|0);
        $124 = tempRet0;
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         break;
        }
        $127 = ($108|0)<($124|0);
        $128 = ($108|0)==($124|0);
        $129 = ($107>>>0)<($123>>>0);
        $130 = $128 & $129;
        $131 = $127 | $130;
        if ($131) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          break;
         }
         $134 = HEAP8[((2592096 + 116|0))>>0]|0;
         $135 = ($134<<24>>24)==(0);
         if ($135) {
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $136 = __THREW__; __THREW__ = 0;
          $137 = $136&1;
          if ($137) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $138 = __THREW__; __THREW__ = 0;
          $139 = $138&1;
          if ($139) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3840,(2592096|0));
          $140 = __THREW__; __THREW__ = 0;
          $141 = $140&1;
          if ($141) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $142 = __THREW__; __THREW__ = 0;
         $143 = $142&1;
         if ($143) {
          break;
         }
         $144 = HEAP32[((2592096 + 80|0))>>2]|0;
         $145 = (($144) + 16|0);
         _memmove(($5|0),($145|0),16)|0;
         __THREW__ = 0;
         ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$5+12>>2]|0;
         invoke_viiii(188,($L_22|0),(0|0),($L_39$byval_copy|0),2);
         $146 = __THREW__; __THREW__ = 0;
         $147 = $146&1;
         if ($147) {
          break;
         }
         ;HEAP32[$agg$result+0>>2]=HEAP32[$L_22+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_22+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_22+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_22+12>>2]|0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      } else {
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $47 = __THREW__; __THREW__ = 0;
       $48 = $47&1;
       if ($48) {
        break;
       }
       $49 = HEAP8[((2592096 + 116|0))>>0]|0;
       $50 = ($49<<24>>24)==(0);
       if ($50) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3840,(2592096|0));
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if ($58) {
        break;
       }
       $59 = HEAP32[((2592096 + 80|0))>>2]|0;
       _memmove(($2|0),($59|0),16)|0;
       $60 = $V_0;
       $61 = $60;
       $62 = HEAP32[$61>>2]|0;
       $63 = (($60) + 4)|0;
       $64 = $63;
       $65 = HEAP32[$64>>2]|0;
       $66 = $3;
       $67 = $66;
       HEAP32[$67>>2] = $62;
       $68 = (($66) + 4)|0;
       $69 = $68;
       HEAP32[$69>>2] = $65;
       __THREW__ = 0;
       ;HEAP32[$L_34$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$L_34$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$L_34$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$L_34$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;
       ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
       invoke_viiii(191,($L_7|0),(0|0),($L_34$byval_copy|0),($L_39$byval_copy|0));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_34$byval_copy+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$L_34$byval_copy+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$L_34$byval_copy+8>>2]=HEAP32[$L_7+8>>2]|0;HEAP32[$L_34$byval_copy+12>>2]=HEAP32[$L_7+12>>2]|0;
       ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
       $72 = (invoke_iiii(1166,(0|0),($L_34$byval_copy|0),($L_39$byval_copy|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       if ($72) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         break;
        }
        $77 = HEAP8[((2592096 + 116|0))>>0]|0;
        $78 = ($77<<24>>24)==(0);
        if ($78) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3840,(2592096|0));
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         break;
        }
        $87 = HEAP32[((2592096 + 80|0))>>2]|0;
        _memmove(($4|0),($87|0),16)|0;
        __THREW__ = 0;
        ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$4+12>>2]|0;
        invoke_viiii(188,($L_11|0),(0|0),($L_39$byval_copy|0),2);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         break;
        }
        ;HEAP32[$agg$result+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_11+12>>2]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
      $148 = $V_0;
      $149 = $148;
      $150 = HEAP32[$149>>2]|0;
      $151 = (($148) + 4)|0;
      $152 = $151;
      $153 = HEAP32[$152>>2]|0;
      $154 = $6;
      $155 = $154;
      HEAP32[$155>>2] = $150;
      $156 = (($154) + 4)|0;
      $157 = $156;
      HEAP32[$157>>2] = $153;
      __THREW__ = 0;
      ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
      invoke_viii(665,($L_23|0),($time|0),($L_39$byval_copy|0));
      $158 = __THREW__; __THREW__ = 0;
      $159 = $158&1;
      if (!($159)) {
       ;HEAP32[$V_1+0>>2]=HEAP32[$L_23+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_23+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_23+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_23+12>>2]|0;
       __THREW__ = 0;
       $160 = (invoke_ii(2433,($time|0))|0);
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       if (!($162)) {
        __THREW__ = 0;
        $163 = (invoke_iiii(1642,(2653056|0),($__this|0),($160|0))|0);
        $164 = __THREW__; __THREW__ = 0;
        $165 = $164&1;
        if (!($165)) {
         __THREW__ = 0;
         invoke_vi(3799,($163|0));
         $166 = __THREW__; __THREW__ = 0;
         $167 = $166&1;
         if (!($167)) {
          __THREW__ = 0;
          $168 = (invoke_ii(2016,($163|0))|0);
          $169 = tempRet0;
          $170 = __THREW__; __THREW__ = 0;
          $171 = $170&1;
          if (!($171)) {
           $172 = $V_5;
           $173 = $172;
           HEAP32[$173>>2] = $168;
           $174 = (($172) + 4)|0;
           $175 = $174;
           HEAP32[$175>>2] = $169;
           __THREW__ = 0;
           $176 = (invoke_ii(2499,($V_5|0))|0);
           $177 = tempRet0;
           $178 = __THREW__; __THREW__ = 0;
           $179 = $178&1;
           if (!($179)) {
            $180 = ($176|0)==(0);
            $181 = ($177|0)==(0);
            $182 = $180 & $181;
            if ($182) {
             __THREW__ = 0;
             ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$V_1+12>>2]|0;
             invoke_viiii(188,($L_29|0),(0|0),($L_39$byval_copy|0),2);
             $183 = __THREW__; __THREW__ = 0;
             $184 = $183&1;
             if ($184) {
              break;
             }
             ;HEAP32[$agg$result+0>>2]=HEAP32[$L_29+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_29+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_29+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_29+12>>2]|0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
            __THREW__ = 0;
            invoke_vi(3799,($163|0));
            $185 = __THREW__; __THREW__ = 0;
            $186 = $185&1;
            if (!($186)) {
             __THREW__ = 0;
             invoke_vii(1839,($L_30|0),($163|0));
             $187 = __THREW__; __THREW__ = 0;
             $188 = $187&1;
             if (!($188)) {
              __THREW__ = 0;
              ;HEAP32[$L_34$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_34$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_34$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$L_34$byval_copy+12>>2]=HEAP32[$V_1+12>>2]|0;
              ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$L_30+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$L_30+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$L_30+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$L_30+12>>2]|0;
              $189 = (invoke_iiii(1166,(0|0),($L_34$byval_copy|0),($L_39$byval_copy|0))|0);
              $190 = __THREW__; __THREW__ = 0;
              $191 = $190&1;
              if (!($191)) {
               do {
                if ($189) {
                 __THREW__ = 0;
                 invoke_vi(3799,($163|0));
                 $192 = __THREW__; __THREW__ = 0;
                 $193 = $192&1;
                 if ($193) {
                  break L1;
                 }
                 __THREW__ = 0;
                 invoke_vii(1839,($L_32|0),($163|0));
                 $194 = __THREW__; __THREW__ = 0;
                 $195 = $194&1;
                 if ($195) {
                  break L1;
                 }
                 ;HEAP32[$V_6+0>>2]=HEAP32[$L_32+0>>2]|0;HEAP32[$V_6+4>>2]=HEAP32[$L_32+4>>2]|0;HEAP32[$V_6+8>>2]=HEAP32[$L_32+8>>2]|0;HEAP32[$V_6+12>>2]=HEAP32[$L_32+12>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($163|0));
                 $196 = __THREW__; __THREW__ = 0;
                 $197 = $196&1;
                 if ($197) {
                  break L1;
                 }
                 __THREW__ = 0;
                 $198 = (invoke_ii(2016,($163|0))|0);
                 $199 = tempRet0;
                 $200 = __THREW__; __THREW__ = 0;
                 $201 = $200&1;
                 if ($201) {
                  break L1;
                 }
                 $202 = $7;
                 $203 = $202;
                 HEAP32[$203>>2] = $198;
                 $204 = (($202) + 4)|0;
                 $205 = $204;
                 HEAP32[$205>>2] = $199;
                 __THREW__ = 0;
                 ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
                 invoke_viii(666,($L_34|0),($V_6|0),($L_39$byval_copy|0));
                 $206 = __THREW__; __THREW__ = 0;
                 $207 = $206&1;
                 if ($207) {
                  break L1;
                 }
                 __THREW__ = 0;
                 ;HEAP32[$L_34$byval_copy+0>>2]=HEAP32[$L_34+0>>2]|0;HEAP32[$L_34$byval_copy+4>>2]=HEAP32[$L_34+4>>2]|0;HEAP32[$L_34$byval_copy+8>>2]=HEAP32[$L_34+8>>2]|0;HEAP32[$L_34$byval_copy+12>>2]=HEAP32[$L_34+12>>2]|0;
                 ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$V_1+12>>2]|0;
                 $208 = (invoke_iiii(1167,(0|0),($L_34$byval_copy|0),($L_39$byval_copy|0))|0);
                 $209 = __THREW__; __THREW__ = 0;
                 $210 = $209&1;
                 if ($210) {
                  break L1;
                 }
                 if (!($208)) {
                  break;
                 }
                 __THREW__ = 0;
                 ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$V_1+12>>2]|0;
                 invoke_viiii(188,($L_37|0),(0|0),($L_39$byval_copy|0),2);
                 $211 = __THREW__; __THREW__ = 0;
                 $212 = $211&1;
                 if ($212) {
                  break L1;
                 }
                 ;HEAP32[$agg$result+0>>2]=HEAP32[$L_37+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_37+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_37+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_37+12>>2]|0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               } while(0);
               ;HEAP32[$0+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$V_1+12>>2]|0;
               __THREW__ = 0;
               invoke_viii(2112,($L_34$byval_copy|0),(2653200|0),($__this|0));
               $213 = __THREW__; __THREW__ = 0;
               $214 = $213&1;
               if (!($214)) {
                $215 = (($L_34$byval_copy) + 4|0);
                $216 = HEAP32[$215>>2]|0;
                $217 = (($216) + 4|0);
                $218 = HEAP32[$217>>2]|0;
                $219 = HEAP32[$L_34$byval_copy>>2]|0;
                __THREW__ = 0;
                ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
                $220 = (invoke_iii($218|0,($219|0),($L_39$byval_copy|0))|0);
                $221 = tempRet0;
                $222 = __THREW__; __THREW__ = 0;
                $223 = $222&1;
                if (!($223)) {
                 $224 = $8;
                 $225 = $224;
                 HEAP32[$225>>2] = $220;
                 $226 = (($224) + 4)|0;
                 $227 = $226;
                 HEAP32[$227>>2] = $221;
                 __THREW__ = 0;
                 ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
                 invoke_viii(665,($L_39|0),($time|0),($L_39$byval_copy|0));
                 $228 = __THREW__; __THREW__ = 0;
                 $229 = $228&1;
                 if ($229) {
                  break;
                 }
                 __THREW__ = 0;
                 ;HEAP32[$L_39$byval_copy+0>>2]=HEAP32[$L_39+0>>2]|0;HEAP32[$L_39$byval_copy+4>>2]=HEAP32[$L_39+4>>2]|0;HEAP32[$L_39$byval_copy+8>>2]=HEAP32[$L_39+8>>2]|0;HEAP32[$L_39$byval_copy+12>>2]=HEAP32[$L_39+12>>2]|0;
                 invoke_viiii(188,($L_41|0),(0|0),($L_39$byval_copy|0),2);
                 $230 = __THREW__; __THREW__ = 0;
                 $231 = $230&1;
                 if ($231) {
                  break;
                 }
                 ;HEAP32[$agg$result+0>>2]=HEAP32[$L_41+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_41+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_41+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_41+12>>2]|0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z42mscorlib_System_TimeZone_m_ToUniversalTimeP24mscorlib_System_TimeZone24mscorlib_System_DateTime($agg$result,$__this,$time) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $time = $time|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_11 = 0, $L_16 = 0, $L_16$byval_copy = 0, $L_20 = 0, $L_24 = 0, $L_24$byval_copy = 0, $L_26 = 0, $L_7 = 0;
 var $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $L_24$byval_copy = sp + 216|0;
 $L_16$byval_copy = sp + 200|0;
 $0 = sp + 184|0;
 $_stackTraceSentry = sp + 232|0;
 $V_0 = sp + 176|0;
 $L_7 = sp + 160|0;
 $1 = sp + 144|0;
 $2 = sp + 136|0;
 $L_11 = sp + 120|0;
 $3 = sp + 88|0;
 $L_16 = sp + 72|0;
 $4 = sp + 56|0;
 $5 = sp + 48|0;
 $L_20 = sp + 32|0;
 $6 = sp + 16|0;
 $L_24 = sp;
 $L_26 = sp + 104|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2653248);
 $7 = $V_0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 __THREW__ = 0;
 $11 = (invoke_ii(2434,($time|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 do {
  if (!($13)) {
   $14 = ($11|0)==(1);
   if ($14) {
    ;HEAP32[$agg$result+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$time+12>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   ;HEAP32[$0+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$time+12>>2]|0;
   __THREW__ = 0;
   invoke_viii(2112,($L_16$byval_copy|0),(2653200|0),($__this|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = (($L_16$byval_copy) + 4|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($20) + 4|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = HEAP32[$L_16$byval_copy>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$L_24$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_24$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_24$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$L_24$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
    $24 = (invoke_iii($22|0,($23|0),($L_24$byval_copy|0))|0);
    $25 = tempRet0;
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = $V_0;
     $29 = $28;
     HEAP32[$29>>2] = $24;
     $30 = (($28) + 4)|0;
     $31 = $30;
     HEAP32[$31>>2] = $25;
     __THREW__ = 0;
     $32 = (invoke_ii(2499,($V_0|0))|0);
     $33 = tempRet0;
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if (!($35)) {
      $36 = ($33|0)>(-1);
      $37 = ($33|0)==(-1);
      $38 = ($32>>>0)>(4294967295);
      $39 = $37 & $38;
      $40 = $36 | $39;
      if ($40) {
       __THREW__ = 0;
       $84 = (invoke_ii(2499,($V_0|0))|0);
       $85 = tempRet0;
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        break;
       }
       $88 = ($85|0)<(0);
       $89 = ($85|0)==(0);
       $90 = ($84>>>0)<(1);
       $91 = $89 & $90;
       $92 = $88 | $91;
       if (!($92)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         break;
        }
        $95 = HEAP8[((2592096 + 116|0))>>0]|0;
        $96 = ($95<<24>>24)==(0);
        if ($96) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $97 = __THREW__; __THREW__ = 0;
         $98 = $97&1;
         if ($98) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3840,(2592096|0));
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         break;
        }
        $105 = HEAP32[((2592096 + 80|0))>>2]|0;
        $106 = (($105) + 16|0);
        _memmove(($4|0),($106|0),16)|0;
        $107 = $V_0;
        $108 = $107;
        $109 = HEAP32[$108>>2]|0;
        $110 = (($107) + 4)|0;
        $111 = $110;
        $112 = HEAP32[$111>>2]|0;
        $113 = $5;
        $114 = $113;
        HEAP32[$114>>2] = $109;
        $115 = (($113) + 4)|0;
        $116 = $115;
        HEAP32[$116>>2] = $112;
        __THREW__ = 0;
        ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$4+12>>2]|0;
        ;HEAP32[$L_24$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$L_24$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
        invoke_viiii(190,($L_16|0),(0|0),($L_16$byval_copy|0),($L_24$byval_copy|0));
        $117 = __THREW__; __THREW__ = 0;
        $118 = $117&1;
        if ($118) {
         break;
        }
        __THREW__ = 0;
        ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_16+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_16+12>>2]|0;
        ;HEAP32[$L_24$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$L_24$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$L_24$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$L_24$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
        $119 = (invoke_iiii(1163,(0|0),($L_16$byval_copy|0),($L_24$byval_copy|0))|0);
        $120 = __THREW__; __THREW__ = 0;
        $121 = $120&1;
        if ($121) {
         break;
        }
        if ($119) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $122 = __THREW__; __THREW__ = 0;
         $123 = $122&1;
         if ($123) {
          break;
         }
         $124 = HEAP8[((2592096 + 116|0))>>0]|0;
         $125 = ($124<<24>>24)==(0);
         if ($125) {
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $126 = __THREW__; __THREW__ = 0;
          $127 = $126&1;
          if ($127) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2592096|0))|0);
          $128 = __THREW__; __THREW__ = 0;
          $129 = $128&1;
          if ($129) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3840,(2592096|0));
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          break;
         }
         $134 = HEAP32[((2592096 + 80|0))>>2]|0;
         $135 = (($134) + 16|0);
         _memmove(($6|0),($135|0),16)|0;
         __THREW__ = 0;
         ;HEAP32[$L_24$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$L_24$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$L_24$byval_copy+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$L_24$byval_copy+12>>2]=HEAP32[$6+12>>2]|0;
         invoke_viiii(188,($L_20|0),(0|0),($L_24$byval_copy|0),1);
         $136 = __THREW__; __THREW__ = 0;
         $137 = $136&1;
         if ($137) {
          break;
         }
         ;HEAP32[$agg$result+0>>2]=HEAP32[$L_20+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_20+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_20+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_20+12>>2]|0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      } else {
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        break;
       }
       $43 = HEAP8[((2592096 + 116|0))>>0]|0;
       $44 = ($43<<24>>24)==(0);
       if ($44) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3840,(2592096|0));
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2592096|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break;
       }
       $53 = HEAP32[((2592096 + 80|0))>>2]|0;
       _memmove(($1|0),($53|0),16)|0;
       $54 = $V_0;
       $55 = $54;
       $56 = HEAP32[$55>>2]|0;
       $57 = (($54) + 4)|0;
       $58 = $57;
       $59 = HEAP32[$58>>2]|0;
       $60 = $2;
       $61 = $60;
       HEAP32[$61>>2] = $56;
       $62 = (($60) + 4)|0;
       $63 = $62;
       HEAP32[$63>>2] = $59;
       __THREW__ = 0;
       ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$1+12>>2]|0;
       ;HEAP32[$L_24$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$L_24$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
       invoke_viiii(190,($L_7|0),(0|0),($L_16$byval_copy|0),($L_24$byval_copy|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        break;
       }
       __THREW__ = 0;
       ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_7+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_7+12>>2]|0;
       ;HEAP32[$L_24$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$L_24$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$L_24$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$L_24$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
       $66 = (invoke_iiii(1166,(0|0),($L_16$byval_copy|0),($L_24$byval_copy|0))|0);
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        break;
       }
       if ($66) {
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break;
        }
        $71 = HEAP8[((2592096 + 116|0))>>0]|0;
        $72 = ($71<<24>>24)==(0);
        if ($72) {
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2592096|0))|0);
         $75 = __THREW__; __THREW__ = 0;
         $76 = $75&1;
         if ($76) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3840,(2592096|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592096|0))|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         break;
        }
        $81 = HEAP32[((2592096 + 80|0))>>2]|0;
        _memmove(($3|0),($81|0),16)|0;
        __THREW__ = 0;
        ;HEAP32[$L_24$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$L_24$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$L_24$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$L_24$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
        invoke_viiii(188,($L_11|0),(0|0),($L_24$byval_copy|0),1);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         break;
        }
        ;HEAP32[$agg$result+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_11+12>>2]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
      __THREW__ = 0;
      $138 = (invoke_ii(2432,($time|0))|0);
      $139 = tempRet0;
      $140 = __THREW__; __THREW__ = 0;
      $141 = $140&1;
      if (!($141)) {
       __THREW__ = 0;
       $142 = (invoke_ii(2499,($V_0|0))|0);
       $143 = tempRet0;
       $144 = __THREW__; __THREW__ = 0;
       $145 = $144&1;
       if (!($145)) {
        $146 = (_i64Subtract(($138|0),($139|0),($142|0),($143|0))|0);
        $147 = tempRet0;
        ;HEAP32[$L_24+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$L_24+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$L_24+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$L_24+12>>2]=HEAP32[2654384+12>>2]|0;
        __THREW__ = 0;
        invoke_viii(661,($L_24|0),($146|0),($147|0));
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if (!($149)) {
         __THREW__ = 0;
         ;HEAP32[$L_24$byval_copy+0>>2]=HEAP32[$L_24+0>>2]|0;HEAP32[$L_24$byval_copy+4>>2]=HEAP32[$L_24+4>>2]|0;HEAP32[$L_24$byval_copy+8>>2]=HEAP32[$L_24+8>>2]|0;HEAP32[$L_24$byval_copy+12>>2]=HEAP32[$L_24+12>>2]|0;
         invoke_viiii(188,($L_26|0),(0|0),($L_24$byval_copy|0),1);
         $150 = __THREW__; __THREW__ = 0;
         $151 = $150&1;
         if (!($151)) {
          ;HEAP32[$agg$result+0>>2]=HEAP32[$L_26+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_26+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_26+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$L_26+12>>2]|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z93mscorlib_System_TimeZone_m_GetLocalTimeDiff_mscorlib_System_TimeSpan_mscorlib_System_DateTimeP24mscorlib_System_TimeZone24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $time$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 40|0;
 $time$byval_copy = sp;
 $0 = sp + 16|0;
 $_stackTraceSentry = sp + 56|0;
 $1 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2653296);
 ;HEAP32[$0+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$time+12>>2]|0;
 __THREW__ = 0;
 invoke_viii(2112,($time$byval_copy|0),(2653200|0),($__this|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($21|0);
  // unreachable;
 }
 $4 = (($time$byval_copy) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$time$byval_copy>>2]|0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$0+12>>2]|0;
 $9 = (invoke_iii($7|0,($8|0),($$byval_copy1|0))|0);
 $10 = tempRet0;
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($21|0);
  // unreachable;
 }
 $13 = $1;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$time$byval_copy+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$time$byval_copy+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$time$byval_copy+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$time$byval_copy+12>>2]=HEAP32[$time+12>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $17 = (invoke_iiii(1274,($__this|0),($time$byval_copy|0),($$byval_copy1|0))|0);
 $18 = tempRet0;
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($21|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $18;
  STACKTOP = sp;return ($17|0);
 }
 return 0|0;
}
function __Z118mscorlib_System_TimeZone_m_GetLocalTimeDiff_mscorlib_System_TimeSpan_mscorlib_System_DateTime_mscorlib_System_TimeSpanP24mscorlib_System_TimeZone24mscorlib_System_DateTime24mscorlib_System_TimeSpan($__this,$time,$utc_offset) {
 $__this = $__this|0;
 $time = $time|0;
 $utc_offset = $utc_offset|0;
 var $$byval_copy6 = 0, $$byval_copy8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_11 = 0, $L_13 = 0, $L_15 = 0, $L_4 = 0, $L_5 = 0, $L_7 = 0, $L_9 = 0, $V_1 = 0;
 var $V_2 = 0, $V_3 = 0, $V_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $$byval_copy8 = sp + 240|0;
 $$byval_copy6 = sp + 224|0;
 $0 = sp + 208|0;
 $_stackTraceSentry = sp + 256|0;
 $V_1 = sp + 192|0;
 $V_2 = sp + 184|0;
 $V_3 = sp + 168|0;
 $V_4 = sp + 152|0;
 $L_4 = sp + 136|0;
 $1 = sp + 128|0;
 $L_5 = sp + 112|0;
 $L_7 = sp + 40|0;
 $L_9 = sp;
 $2 = sp + 16|0;
 $L_11 = sp + 24|0;
 $L_13 = sp + 56|0;
 $L_15 = sp + 72|0;
 $3 = sp + 88|0;
 $4 = sp + 96|0;
 $5 = sp + 104|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2653344);
 ;HEAP32[$V_1+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[2654384+12>>2]|0;
 $6 = $V_2;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 ;HEAP32[$V_3+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_4+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[2654384+12>>2]|0;
 __THREW__ = 0;
 $10 = (invoke_ii(2433,($time|0))|0);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 L1: do {
  if (!($12)) {
   __THREW__ = 0;
   $13 = (invoke_iiii(1642,(2653056|0),($__this|0),($10|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    __THREW__ = 0;
    invoke_vi(3799,($13|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     $18 = (invoke_ii(2016,($13|0))|0);
     $19 = tempRet0;
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = $V_2;
      $23 = $22;
      HEAP32[$23>>2] = $18;
      $24 = (($22) + 4)|0;
      $25 = $24;
      HEAP32[$25>>2] = $19;
      __THREW__ = 0;
      $26 = (invoke_ii(2499,($V_2|0))|0);
      $27 = tempRet0;
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       $30 = ($26|0)==(0);
       $31 = ($27|0)==(0);
       $32 = $30 & $31;
       $33 = $utc_offset;
       $34 = $33;
       $35 = HEAP32[$34>>2]|0;
       $36 = (($33) + 4)|0;
       $37 = $36;
       $38 = HEAP32[$37>>2]|0;
       if ($32) {
        $128 = $38;$129 = $35;
        __ZN16StackTraceSentryD2Ev(0);
        tempRet0 = $128;
        STACKTOP = sp;return ($129|0);
       }
       $41 = $1;
       $42 = $41;
       HEAP32[$42>>2] = $35;
       $43 = (($41) + 4)|0;
       $44 = $43;
       HEAP32[$44>>2] = $38;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$1+4>>2]|0;
       invoke_viii(665,($L_4|0),($time|0),($$byval_copy8|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        ;HEAP32[$V_1+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_4+12>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($13|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         __THREW__ = 0;
         invoke_vii(1839,($L_5|0),($13|0));
         $49 = __THREW__; __THREW__ = 0;
         $50 = $49&1;
         if (!($50)) {
          __THREW__ = 0;
          ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$$byval_copy6+12>>2]=HEAP32[$V_1+12>>2]|0;
          ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$$byval_copy8+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$$byval_copy8+12>>2]=HEAP32[$L_5+12>>2]|0;
          $51 = (invoke_iiii(1166,(0|0),($$byval_copy6|0),($$byval_copy8|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           if ($51) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if ($55) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1839,($L_7|0),($13|0));
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             break;
            }
            ;HEAP32[$V_3+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_7+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[$L_7+12>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             break;
            }
            __THREW__ = 0;
            $60 = (invoke_ii(2016,($13|0))|0);
            $61 = tempRet0;
            $62 = __THREW__; __THREW__ = 0;
            $63 = $62&1;
            if ($63) {
             break;
            }
            $64 = $2;
            $65 = $64;
            HEAP32[$65>>2] = $60;
            $66 = (($64) + 4)|0;
            $67 = $66;
            HEAP32[$67>>2] = $61;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$2+4>>2]|0;
            invoke_viii(666,($L_9|0),($V_3|0),($$byval_copy8|0));
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$L_9+8>>2]|0;HEAP32[$$byval_copy6+12>>2]=HEAP32[$L_9+12>>2]|0;
            ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$$byval_copy8+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$$byval_copy8+12>>2]=HEAP32[$V_1+12>>2]|0;
            $70 = (invoke_iiii(1167,(0|0),($$byval_copy6|0),($$byval_copy8|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            if ($70) {
             $128 = $38;$129 = $35;
             __ZN16StackTraceSentryD2Ev(0);
             tempRet0 = $128;
             STACKTOP = sp;return ($129|0);
            }
           }
           __THREW__ = 0;
           invoke_vi(3799,($13|0));
           $73 = __THREW__; __THREW__ = 0;
           $74 = $73&1;
           if (!($74)) {
            __THREW__ = 0;
            invoke_vii(1838,($L_11|0),($13|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if (!($76)) {
             __THREW__ = 0;
             ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$$byval_copy6+12>>2]=HEAP32[$V_1+12>>2]|0;
             ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$$byval_copy8+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$$byval_copy8+12>>2]=HEAP32[$L_11+12>>2]|0;
             $77 = (invoke_iiii(1164,(0|0),($$byval_copy6|0),($$byval_copy8|0))|0);
             $78 = __THREW__; __THREW__ = 0;
             $79 = $78&1;
             if (!($79)) {
              do {
               if ($77) {
                __THREW__ = 0;
                invoke_vi(3799,($13|0));
                $80 = __THREW__; __THREW__ = 0;
                $81 = $80&1;
                if ($81) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vii(1838,($L_13|0),($13|0));
                $82 = __THREW__; __THREW__ = 0;
                $83 = $82&1;
                if ($83) {
                 break L1;
                }
                ;HEAP32[$V_4+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_13+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[$L_13+12>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($13|0));
                $84 = __THREW__; __THREW__ = 0;
                $85 = $84&1;
                if ($85) {
                 break L1;
                }
                __THREW__ = 0;
                $86 = (invoke_ii(2016,($13|0))|0);
                $87 = tempRet0;
                $88 = __THREW__; __THREW__ = 0;
                $89 = $88&1;
                if ($89) {
                 break L1;
                }
                $90 = $3;
                $91 = $90;
                HEAP32[$91>>2] = $86;
                $92 = (($90) + 4)|0;
                $93 = $92;
                HEAP32[$93>>2] = $87;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$3+4>>2]|0;
                invoke_viii(665,($L_15|0),($V_4|0),($$byval_copy8|0));
                $94 = __THREW__; __THREW__ = 0;
                $95 = $94&1;
                if ($95) {
                 break L1;
                }
                __THREW__ = 0;
                ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$L_15+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$L_15+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$L_15+8>>2]|0;HEAP32[$$byval_copy6+12>>2]=HEAP32[$L_15+12>>2]|0;
                ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$$byval_copy8+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$$byval_copy8+12>>2]=HEAP32[$V_1+12>>2]|0;
                $96 = (invoke_iiii(1163,(0|0),($$byval_copy6|0),($$byval_copy8|0))|0);
                $97 = __THREW__; __THREW__ = 0;
                $98 = $97&1;
                if ($98) {
                 break L1;
                }
                if (!($96)) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($13|0));
                $99 = __THREW__; __THREW__ = 0;
                $100 = $99&1;
                if ($100) {
                 break L1;
                }
                __THREW__ = 0;
                $101 = (invoke_ii(2016,($13|0))|0);
                $102 = tempRet0;
                $103 = __THREW__; __THREW__ = 0;
                $104 = $103&1;
                if ($104) {
                 break L1;
                }
                $105 = $4;
                $106 = $105;
                HEAP32[$106>>2] = $35;
                $107 = (($105) + 4)|0;
                $108 = $107;
                HEAP32[$108>>2] = $38;
                $109 = $5;
                $110 = $109;
                HEAP32[$110>>2] = $101;
                $111 = (($109) + 4)|0;
                $112 = $111;
                HEAP32[$112>>2] = $102;
                __THREW__ = 0;
                ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$4+4>>2]|0;
                ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$5+4>>2]|0;
                $113 = (invoke_iiii(1269,0,($$byval_copy6|0),($$byval_copy8|0))|0);
                $114 = tempRet0;
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if ($116) {
                 break L1;
                } else {
                 $128 = $114;$129 = $113;
                }
                __ZN16StackTraceSentryD2Ev(0);
                tempRet0 = $128;
                STACKTOP = sp;return ($129|0);
               }
              } while(0);
              ;HEAP32[$0+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$V_1+12>>2]|0;
              __THREW__ = 0;
              invoke_viii(2112,($$byval_copy6|0),(2653200|0),($__this|0));
              $117 = __THREW__; __THREW__ = 0;
              $118 = $117&1;
              if (!($118)) {
               $119 = (($$byval_copy6) + 4|0);
               $120 = HEAP32[$119>>2]|0;
               $121 = (($120) + 4|0);
               $122 = HEAP32[$121>>2]|0;
               $123 = HEAP32[$$byval_copy6>>2]|0;
               __THREW__ = 0;
               ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy8+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy8+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy8+12>>2]=HEAP32[$0+12>>2]|0;
               $124 = (invoke_iii($122|0,($123|0),($$byval_copy8|0))|0);
               $125 = tempRet0;
               $126 = __THREW__; __THREW__ = 0;
               $127 = $126&1;
               if (!($127)) {
                $128 = $125;$129 = $124;
                __ZN16StackTraceSentryD2Ev(0);
                tempRet0 = $128;
                STACKTOP = sp;return ($129|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $39 = ___cxa_find_matching_catch()|0;
 $40 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($39|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_DateTimeTraits17VoidPointerTraitsE6InvokeEPFbPv24mscorlib_System_DateTimeS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $ret = sp + 32|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$3)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_DateTimeTraitsS0_E6InvokeEPF24mscorlib_System_DateTimePvS2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2592096,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I30mscorlib_System_TimeSpanTraits30mscorlib_System_DateTimeTraitsE6InvokeEPF24mscorlib_System_TimeSpanPv24mscorlib_System_DateTimeES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = tempRet0;
 $3 = $ret;
 $4 = $3;
 HEAP32[$4>>2] = $1;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2652728,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker2I30mscorlib_System_TimeSpanTraits30mscorlib_System_DateTimeTraitsS0_E6InvokeEPF24mscorlib_System_TimeSpanPv24mscorlib_System_DateTimeS3_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 24|0;
 $1 = sp + 40|0;
 $2 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$2+12>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $1;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;
 $15 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$$byval_copy1)|0);
 $16 = tempRet0;
 $17 = $ret;
 $18 = $17;
 HEAP32[$18>>2] = $15;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2652728,$ret)|0);
 STACKTOP = sp;return ($21|0);
}
function __Z55mscorlib_System_TimeZone_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_CurrentSystemTimeZone_m_GetTimeZoneDataP22mscorlib_System_ObjectiPP25mscorlib_System_Int64_arrPP26mscorlib_System_String_arr($__this,$year,$data,$names) {
 $__this = $__this|0;
 $year = $year|0;
 $data = $data|0;
 $names = $names|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2654040);
 $0 = HEAP32[2654088>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2654096|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2654088>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($year|0),($data|0),($names|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z63mscorlib_System_CurrentSystemTimeZone_m_GetDaylightTimeFromDataP37mscorlib_System_CurrentSystemTimeZoneP25mscorlib_System_Int64_arr($__this,$data) {
 $__this = $__this|0;
 $data = $data|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_2 = 0, $L_2$byval_copy = 0, $L_5 = 0, $L_5$byval_copy = 0, $L_8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp + 80|0;
 $L_5$byval_copy = sp;
 $L_2$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 88|0;
 $L_2 = sp + 40|0;
 $L_5 = sp + 56|0;
 $L_8 = sp + 72|0;
 $0 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2654336);
 __THREW__ = 0;
 invoke_vi(3799,($data|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = (($data) + 12|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0);
   if ($5) {
    __THREW__ = 0;
    $6 = (invoke_i(132)|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($6|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
   }
   $13 = (($data) + 16|0);
   $14 = $13;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   ;HEAP32[$L_2+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$L_2+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$L_2+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$L_2+12>>2]=HEAP32[2654384+12>>2]|0;
   __THREW__ = 0;
   invoke_viii(661,($L_2|0),($16|0),($19|0));
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    __THREW__ = 0;
    invoke_vi(3799,($data|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if (!($23)) {
     $24 = HEAP32[$3>>2]|0;
     $25 = ($24>>>0)<(2);
     if ($25) {
      __THREW__ = 0;
      $26 = (invoke_i(132)|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($26|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
     }
     $31 = HEAP32[$data>>2]|0;
     $32 = (($31) + 92|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = (($13) + ($33)|0);
     $35 = $34;
     $36 = $35;
     $37 = HEAP32[$36>>2]|0;
     $38 = (($35) + 4)|0;
     $39 = $38;
     $40 = HEAP32[$39>>2]|0;
     ;HEAP32[$L_5+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$L_5+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$L_5+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$L_5+12>>2]=HEAP32[2654384+12>>2]|0;
     __THREW__ = 0;
     invoke_viii(661,($L_5|0),($37|0),($40|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      __THREW__ = 0;
      invoke_vi(3799,($data|0));
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if (!($44)) {
       $45 = HEAP32[$3>>2]|0;
       $46 = ($45>>>0)<(4);
       if ($46) {
        __THREW__ = 0;
        $47 = (invoke_i(132)|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($47|0));
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         break;
        }
       }
       $52 = HEAP32[$data>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = ($54*3)|0;
       $56 = (($13) + ($55)|0);
       $57 = $56;
       $58 = $57;
       $59 = HEAP32[$58>>2]|0;
       $60 = (($57) + 4)|0;
       $61 = $60;
       $62 = HEAP32[$61>>2]|0;
       $63 = $L_8;
       $64 = $63;
       HEAP32[$64>>2] = 0;
       $65 = (($63) + 4)|0;
       $66 = $65;
       HEAP32[$66>>2] = 0;
       __THREW__ = 0;
       invoke_viii(703,($L_8|0),($59|0),($62|0));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if (!($68)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2342120|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if (!($70)) {
         __THREW__ = 0;
         $71 = (invoke_ii(3469,(2342120|0))|0);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if (!($73)) {
          $74 = $L_8;
          $75 = $74;
          $76 = HEAP32[$75>>2]|0;
          $77 = (($74) + 4)|0;
          $78 = $77;
          $79 = HEAP32[$78>>2]|0;
          $80 = $0;
          $81 = $80;
          HEAP32[$81>>2] = $76;
          $82 = (($80) + 4)|0;
          $83 = $82;
          HEAP32[$83>>2] = $79;
          __THREW__ = 0;
          ;HEAP32[$L_2$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_2$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_2$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;HEAP32[$L_2$byval_copy+12>>2]=HEAP32[$L_2+12>>2]|0;
          ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$L_5$byval_copy+12>>2]=HEAP32[$L_5+12>>2]|0;
          ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
          invoke_viiii(158,($71|0),($L_2$byval_copy|0),($L_5$byval_copy|0),($$byval_copy|0));
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if (!($85)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($71|0);
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z57mscorlib_System_CurrentSystemTimeZone_m_OnDeserializationP37mscorlib_System_CurrentSystemTimeZoneP42mscorlib_System_Globalization_DaylightTime($__this,$dlt) {
 $__this = $__this|0;
 $dlt = $dlt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_0 = 0, $L_11 = 0, $L_14 = 0, $L_19 = 0, $L_5 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0;
 var $V_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $_stackTraceSentry = sp + 96|0;
 $V_0 = sp + 92|0;
 $V_1 = sp + 88|0;
 $V_2 = sp + 72|0;
 $V_3 = sp + 56|0;
 $V_4 = sp + 48|0;
 $L_0 = sp + 24|0;
 $L_5 = sp + 100|0;
 $L_11 = sp + 8|0;
 $L_14 = sp;
 $L_19 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2654288);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 ;HEAP32[$V_2+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[2654384+12>>2]|0;
 ;HEAP32[$V_3+0>>2]=HEAP32[2654384+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[2654384+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[2654384+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[2654384+12>>2]|0;
 $0 = $V_4;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(934);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   $6 = ($dlt|0)==(0|0);
   do {
    if ($6) {
     __THREW__ = 0;
     invoke_vii(1930,($L_0|0),(0|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break L1;
     }
     ;HEAP32[$V_2+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_0+12>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_ii(2433,($V_2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2655088|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break L1;
     }
     $16 = HEAP32[((2655088 + 80|0))>>2]|0;
     HEAP32[$16>>2] = $11;
     __THREW__ = 0;
     (invoke_ii(2996,(2655088|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break L1;
     }
     $19 = HEAP32[((2655088 + 80|0))>>2]|0;
     $20 = HEAP32[$19>>2]|0;
     __THREW__ = 0;
     $21 = (invoke_iiiii(199,0,($20|0),($V_0|0),($V_1|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break L1;
     }
     if ($21) {
      $49 = HEAP32[$V_0>>2]|0;
      __THREW__ = 0;
      $50 = (invoke_iii(1169,0,($49|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       break L1;
      } else {
       $$0 = $50;
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2655088|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break L1;
     }
     $26 = HEAP32[((2655088 + 80|0))>>2]|0;
     $27 = HEAP32[$26>>2]|0;
     HEAP32[$L_5>>2] = $27;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break L1;
     }
     __THREW__ = 0;
     $30 = (invoke_iii(2724,(2155952|0),($L_5|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break L1;
     }
     $33 = HEAP32[3076256>>2]|0;
     __THREW__ = 0;
     $34 = (invoke_iiii(559,(0|0),($33|0),($30|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break L1;
     }
     __THREW__ = 0;
     $37 = (invoke_iii(783,(0|0),($34|0))|0);
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      break L1;
     }
     __THREW__ = 0;
     $42 = (invoke_ii(3469,(2560072|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1924,($42|0),($37|0));
     $45 = __THREW__; __THREW__ = 0;
     $46 = $45&1;
     if ($46) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3841,($42|0));
     $47 = __THREW__; __THREW__ = 0;
     $48 = $47&1;
     if ($48) {
      break L1;
     }
     // unreachable;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($dlt|0));
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vii(1838,($L_11|0),($dlt|0));
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break L1;
     }
     ;HEAP32[$V_3+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[$L_11+12>>2]|0;
     __THREW__ = 0;
     $57 = (invoke_ii(2433,($V_3|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break L1;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2655088|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break L1;
     }
     $62 = HEAP32[((2655088 + 80|0))>>2]|0;
     HEAP32[$62>>2] = $57;
     $$0 = $dlt;
    }
   } while(0);
   $63 = (($__this) + 24|0);
   $64 = $63;
   $65 = $64;
   $66 = HEAP32[$65>>2]|0;
   $67 = (($64) + 4)|0;
   $68 = $67;
   $69 = HEAP32[$68>>2]|0;
   $70 = $L_14;
   $71 = $70;
   HEAP32[$71>>2] = 0;
   $72 = (($70) + 4)|0;
   $73 = $72;
   HEAP32[$73>>2] = 0;
   __THREW__ = 0;
   invoke_viii(703,($L_14|0),($66|0),($69|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if (!($75)) {
    $76 = $L_14;
    $77 = $76;
    $78 = HEAP32[$77>>2]|0;
    $79 = (($76) + 4)|0;
    $80 = $79;
    $81 = HEAP32[$80>>2]|0;
    $82 = (($__this) + 32|0);
    $83 = $82;
    $84 = $83;
    HEAP32[$84>>2] = $78;
    $85 = (($83) + 4)|0;
    $86 = $85;
    HEAP32[$86>>2] = $81;
    $87 = $63;
    $88 = $87;
    $89 = HEAP32[$88>>2]|0;
    $90 = (($87) + 4)|0;
    $91 = $90;
    $92 = HEAP32[$91>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($$0|0));
    $93 = __THREW__; __THREW__ = 0;
    $94 = $93&1;
    if (!($94)) {
     __THREW__ = 0;
     $95 = (invoke_ii(2016,($$0|0))|0);
     $96 = tempRet0;
     $97 = __THREW__; __THREW__ = 0;
     $98 = $97&1;
     if (!($98)) {
      $99 = $V_4;
      $100 = $99;
      HEAP32[$100>>2] = $95;
      $101 = (($99) + 4)|0;
      $102 = $101;
      HEAP32[$102>>2] = $96;
      __THREW__ = 0;
      $103 = (invoke_ii(2499,($V_4|0))|0);
      $104 = tempRet0;
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if (!($106)) {
       $107 = (_i64Add(($103|0),($104|0),($89|0),($92|0))|0);
       $108 = tempRet0;
       $109 = $L_19;
       $110 = $109;
       HEAP32[$110>>2] = 0;
       $111 = (($109) + 4)|0;
       $112 = $111;
       HEAP32[$112>>2] = 0;
       __THREW__ = 0;
       invoke_viii(703,($L_19|0),($107|0),($108|0));
       $113 = __THREW__; __THREW__ = 0;
       $114 = $113&1;
       if (!($114)) {
        $115 = $L_19;
        $116 = $115;
        $117 = HEAP32[$116>>2]|0;
        $118 = (($115) + 4)|0;
        $119 = $118;
        $120 = HEAP32[$119>>2]|0;
        $121 = (($__this) + 40|0);
        $122 = $121;
        $123 = $122;
        HEAP32[$123>>2] = $117;
        $124 = (($122) + 4)|0;
        $125 = $124;
        HEAP32[$125>>2] = $120;
        __THREW__ = 0;
        (invoke_ii(2996,(2655088|0))|0);
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if (!($127)) {
         $128 = HEAP32[((2655088 + 80|0))>>2]|0;
         $129 = (($128) + 4|0);
         HEAP32[$129>>2] = $$0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z58mscorlib_System_CurrentSystemTimeZone_m_GetDaylightChangesP37mscorlib_System_CurrentSystemTimeZonei($__this,$year) {
 $__this = $__this|0;
 $year = $year|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_11 = 0, $L_16 = 0, $L_2 = 0, $L_23 = 0, $V_2 = 0, $V_3 = 0, $V_4$0 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, $year$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $V_2 = sp;
 $V_3 = sp + 4|0;
 $L_2 = sp + 8|0;
 $L_11 = sp + 12|0;
 $L_16 = sp + 16|0;
 $L_23 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2654192);
 HEAP32[$V_2>>2] = 0;
 HEAP32[$V_3>>2] = 0;
 __THREW__ = 0;
 invoke_v(935);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $year$off = (($year) + -1)|0;
   $2 = ($year$off>>>0)<(9999);
   if (!($2)) {
    HEAP32[$L_2>>2] = $year;
    __THREW__ = 0;
    (invoke_ii(2996,(2155952|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_iii(2724,(2155952|0),($L_2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3076088>>2]|0;
    __THREW__ = 0;
    $11 = (invoke_iii(783,(0|0),($10|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    $14 = (invoke_iiii(559,(0|0),($7|0),($11|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3076080>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($19|0),($22|0),($14|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($19|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2655088|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if (!($28)) {
    $29 = HEAP32[((2655088 + 80|0))>>2]|0;
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==($year|0);
    if ($31) {
     __THREW__ = 0;
     (invoke_ii(2996,(2655088|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     $34 = HEAP32[((2655088 + 80|0))>>2]|0;
     $35 = (($34) + 4|0);
     $36 = HEAP32[$35>>2]|0;
     $$0 = $36;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $37 = (($__this) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    __THREW__ = 0;
    invoke_vii(1916,(0|0),($38|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     $41 = HEAP32[$37>>2]|0;
     HEAP32[$L_11>>2] = $year;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $42 = __THREW__; __THREW__ = 0;
     $43 = $42&1;
     do {
      if ($43) {
       label = 25;
      } else {
       __THREW__ = 0;
       $44 = (invoke_iii(2724,(2155952|0),($L_11|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        label = 25;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($41|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 25;
        } else {
         __THREW__ = 0;
         $49 = (invoke_iiii(1643,(2310848|0),($41|0),($44|0))|0);
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          label = 25;
         } else {
          __THREW__ = 0;
          (invoke_ii(2996,(2342120|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           label = 25;
          } else {
           __THREW__ = 0;
           $54 = (invoke_iii(2772,($49|0),(2342120|0))|0);
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if ($56) {
            label = 25;
           } else {
            $57 = ($54|0)==(0|0);
            if ($57) {
             __THREW__ = 0;
             $66 = (invoke_iiiii(199,0,($year|0),($V_2|0),($V_3|0))|0);
             $67 = __THREW__; __THREW__ = 0;
             $68 = $67&1;
             if ($68) {
              label = 25;
             } else {
              if ($66) {
               $90 = HEAP32[$V_2>>2]|0;
               __THREW__ = 0;
               $91 = (invoke_iii(1169,0,($90|0))|0);
               $92 = __THREW__; __THREW__ = 0;
               $93 = $92&1;
               if ($93) {
                label = 25;
                break;
               }
               $94 = HEAP32[$37>>2]|0;
               HEAP32[$L_23>>2] = $year;
               __THREW__ = 0;
               (invoke_ii(2996,(2155952|0))|0);
               $95 = __THREW__; __THREW__ = 0;
               $96 = $95&1;
               if ($96) {
                label = 25;
                break;
               }
               __THREW__ = 0;
               $97 = (invoke_iii(2724,(2155952|0),($L_23|0))|0);
               $98 = __THREW__; __THREW__ = 0;
               $99 = $98&1;
               if ($99) {
                label = 25;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($94|0));
               $100 = __THREW__; __THREW__ = 0;
               $101 = $100&1;
               if ($101) {
                label = 25;
                break;
               }
               __THREW__ = 0;
               invoke_viiii(465,(2311184|0),($94|0),($97|0),($91|0));
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               if ($103) {
                label = 25;
                break;
               } else {
                $V_4$0 = $91;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 176;
                break;
               }
              }
              HEAP32[$L_16>>2] = $year;
              __THREW__ = 0;
              (invoke_ii(2996,(2155952|0))|0);
              $69 = __THREW__; __THREW__ = 0;
              $70 = $69&1;
              if ($70) {
               label = 25;
              } else {
               __THREW__ = 0;
               $71 = (invoke_iii(2724,(2155952|0),($L_16|0))|0);
               $72 = __THREW__; __THREW__ = 0;
               $73 = $72&1;
               if ($73) {
                label = 25;
               } else {
                $74 = HEAP32[3076096>>2]|0;
                __THREW__ = 0;
                $75 = (invoke_iiii(559,(0|0),($74|0),($71|0))|0);
                $76 = __THREW__; __THREW__ = 0;
                $77 = $76&1;
                if ($77) {
                 label = 25;
                } else {
                 __THREW__ = 0;
                 $78 = (invoke_iii(783,(0|0),($75|0))|0);
                 $79 = __THREW__; __THREW__ = 0;
                 $80 = $79&1;
                 if ($80) {
                  label = 25;
                 } else {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2560072|0))|0);
                  $81 = __THREW__; __THREW__ = 0;
                  $82 = $81&1;
                  if ($82) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  $83 = (invoke_ii(3469,(2560072|0))|0);
                  $84 = __THREW__; __THREW__ = 0;
                  $85 = $84&1;
                  if ($85) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(1924,($83|0),($78|0));
                  $86 = __THREW__; __THREW__ = 0;
                  $87 = $86&1;
                  if ($87) {
                   label = 25;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3841,($83|0));
                  $88 = __THREW__; __THREW__ = 0;
                  $89 = $88&1;
                  if ($89) {
                   label = 25;
                   break;
                  }
                  // unreachable;
                 }
                }
               }
              }
             }
            } else {
             $V_4$0 = $54;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 176;
            }
           }
          }
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 25) {
      $58 = ___cxa_find_matching_catch(348288|0)|0;
      $59 = tempRet0;
      $60 = (_llvm_eh_typeid_for((348288|0))|0);
      $61 = ($59|0)==($60|0);
      if (!($61)) {
       $$02 = $58;$$03 = $59;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $62 = (___cxa_begin_catch(($58|0))|0);
      $63 = HEAP32[$62>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       break;
      }
      $V_4$0 = 0;$__last_unhandled_exception$0 = $63;$leaveInstructions$sroa$0$0 = 0;
     }
     __THREW__ = 0;
     invoke_vii(1917,(0|0),($38|0));
     $104 = __THREW__; __THREW__ = 0;
     $105 = $104&1;
     if (!($105)) {
      $cond1 = ($leaveInstructions$sroa$0$0|0)==(176);
      if ($cond1) {
       $$0 = $V_4$0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      invoke_vi(3841,($__last_unhandled_exception$0|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if (!($107)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$02 = $3;$$03 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo9479($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z52mscorlib_System_CurrentSystemTimeZone_m_GetUtcOffsetP37mscorlib_System_CurrentSystemTimeZone24mscorlib_System_DateTime($__this,$time) {
 $__this = $__this|0;
 $time = $time|0;
 var $$byval_copy = 0, $$sroa$0$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $data$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $data$i = sp + 40|0;
 $0 = sp;
 $_stackTraceSentry = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2654240);
 ;HEAP32[$0+0>>2]=HEAP32[$time+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$time+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$time+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$time+12>>2]|0;
 __THREW__ = 0;
 invoke_viii(2112,($data$i|0),(2653008|0),($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($19|0);
  // unreachable;
 }
 $3 = (($data$i) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$data$i>>2]|0;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $8 = (invoke_iii($6|0,($7|0),($$byval_copy|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $19 = ___cxa_find_matching_catch()|0;
  $20 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($19|0);
  // unreachable;
 } else {
  $11 = (($__this) + 40|0);
  $12 = (($__this) + 32|0);
  $$sroa$0$0$in = $8 ? $11 : $12;
  $13 = $$sroa$0$0$in;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  tempRet0 = $18;
  STACKTOP = sp;return ($15|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker3I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS2_E6InvokeEPFbPviS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$3,$5)|0);
 $7 = $6&1;
 HEAP8[$ret>>0] = $7;
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z55mscorlib_System_TypeCode_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_TypeInitializationException_m_GetObjectDataP43mscorlib_System_TypeInitializationExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2656304);
 __THREW__ = 0;
 invoke_v(936);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = $context;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $0;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  __THREW__ = 0;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
  invoke_viii(544,($__this|0),($info|0),($tmpcast$byval_copy|0));
  $13 = __THREW__; __THREW__ = 0;
  $14 = $13&1;
  if (!($14)) {
   $15 = (($__this) + 52|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[3076272>>2]|0;
    __THREW__ = 0;
    invoke_viii(621,($info|0),($19|0),($16|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
}
function __Z74mscorlib_System_TypeInitializationException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z62mscorlib_System_TypeLoadException_m__ctor_mscorlib_System_VoidP33mscorlib_System_TypeLoadException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2656736);
 __THREW__ = 0;
 invoke_v(937);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3076464>>2]|0;
  __THREW__ = 0;
  $3 = (invoke_iii(783,(0|0),($2|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_vii(1975,($__this|0),($3|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vii(1783,($__this|0),-2146233054);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z85mscorlib_System_TypeLoadException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_TypeLoadExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2656784);
 __THREW__ = 0;
 invoke_vii(1975,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2146233054);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z47mscorlib_System_TypeLoadException_m_get_MessageP33mscorlib_System_TypeLoadException($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2656832);
 __THREW__ = 0;
 invoke_v(938);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 52|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    $38 = (invoke_ii(1906,($__this|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    } else {
     $$0 = $38;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   $7 = (($__this) + 56|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if ($9) {
    $34 = $3;
   } else {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP8[((2191608 + 116|0))>>0]|0;
    $13 = ($12<<24>>24)==(0);
    if ($13) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3840,(2191608|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[((2191608 + 80|0))>>2]|0;
    $23 = HEAP32[$22>>2]|0;
    __THREW__ = 0;
    $24 = (invoke_iiii(575,(0|0),($8|0),($23|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = HEAP32[$2>>2]|0;
    if ($24) {
     $28 = HEAP32[$7>>2]|0;
     $29 = HEAP32[3076288>>2]|0;
     __THREW__ = 0;
     $30 = (invoke_iiiii(98,(0|0),($29|0),($27|0),($28|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     } else {
      $$0 = $30;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    } else {
     $34 = $27;
    }
   }
   $33 = HEAP32[3076296>>2]|0;
   __THREW__ = 0;
   $35 = (invoke_iiii(552,(0|0),($33|0),($34|0))|0);
   $36 = __THREW__; __THREW__ = 0;
   $37 = $36&1;
   if (!($37)) {
    $$0 = $35;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z49mscorlib_System_TypeLoadException_m_GetObjectDataP33mscorlib_System_TypeLoadExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $$byval_copy3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $L_8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy3 = sp + 32|0;
 $_stackTraceSentry = sp + 8|0;
 $0 = sp;
 $1 = sp + 12|0;
 $2 = sp + 16|0;
 $3 = sp + 20|0;
 $L_8 = sp + 24|0;
 $4 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2656880);
 __THREW__ = 0;
 invoke_v(939);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   $7 = ($info|0)==(0|0);
   if ($7) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    $12 = (invoke_ii(3469,(2560584|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    $15 = HEAP32[3076552>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($12|0),($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($12|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    // unreachable;
   }
   $20 = $context;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $0;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy3+4>>2]=HEAP32[$0+4>>2]|0;
   invoke_viii(544,($__this|0),($info|0),($$byval_copy3|0));
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if (!($31)) {
    $32 = (($__this) + 52|0);
    $33 = HEAP32[$32>>2]|0;
    HEAP32[$1>>2] = 1284472;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$1+0>>2]|0;
    $34 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __THREW__ = 0;
     invoke_vi(3799,($info|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      $39 = HEAP32[3076560>>2]|0;
      __THREW__ = 0;
      invoke_viiii(168,($info|0),($39|0),($33|0),($34|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if (!($41)) {
       $42 = (($__this) + 56|0);
       $43 = HEAP32[$42>>2]|0;
       HEAP32[$2>>2] = 1284472;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$2+0>>2]|0;
       $44 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if (!($46)) {
        __THREW__ = 0;
        invoke_vi(3799,($info|0));
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if (!($48)) {
         $49 = HEAP32[3076568>>2]|0;
         __THREW__ = 0;
         invoke_viiii(168,($info|0),($49|0),($43|0),($44|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if (!($53)) {
           $54 = HEAP8[((2191608 + 116|0))>>0]|0;
           $55 = ($54<<24>>24)==(0);
           if ($55) {
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if ($59) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3840,(2191608|0));
            $60 = __THREW__; __THREW__ = 0;
            $61 = $60&1;
            if ($61) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $62 = __THREW__; __THREW__ = 0;
           $63 = $62&1;
           if (!($63)) {
            $64 = HEAP32[((2191608 + 80|0))>>2]|0;
            $65 = HEAP32[$64>>2]|0;
            HEAP32[$3>>2] = 1284472;
            __THREW__ = 0;
            ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$3+0>>2]|0;
            $66 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
            $67 = __THREW__; __THREW__ = 0;
            $68 = $67&1;
            if (!($68)) {
             __THREW__ = 0;
             invoke_vi(3799,($info|0));
             $69 = __THREW__; __THREW__ = 0;
             $70 = $69&1;
             if (!($70)) {
              $71 = HEAP32[3076576>>2]|0;
              __THREW__ = 0;
              invoke_viiii(168,($info|0),($71|0),($65|0),($66|0));
              $72 = __THREW__; __THREW__ = 0;
              $73 = $72&1;
              if (!($73)) {
               HEAP32[$L_8>>2] = 0;
               __THREW__ = 0;
               (invoke_ii(2996,(2155952|0))|0);
               $74 = __THREW__; __THREW__ = 0;
               $75 = $74&1;
               if (!($75)) {
                __THREW__ = 0;
                $76 = (invoke_iii(2724,(2155952|0),($L_8|0))|0);
                $77 = __THREW__; __THREW__ = 0;
                $78 = $77&1;
                if (!($78)) {
                 HEAP32[$4>>2] = 1285000;
                 __THREW__ = 0;
                 ;HEAP32[$$byval_copy3+0>>2]=HEAP32[$4+0>>2]|0;
                 $79 = (invoke_iii(772,(0|0),($$byval_copy3|0))|0);
                 $80 = __THREW__; __THREW__ = 0;
                 $81 = $80&1;
                 if (!($81)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($info|0));
                  $82 = __THREW__; __THREW__ = 0;
                  $83 = $82&1;
                  if (!($83)) {
                   $84 = HEAP32[3076584>>2]|0;
                   __THREW__ = 0;
                   invoke_viiii(168,($info|0),($84|0),($76|0),($79|0));
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z64mscorlib_System_TypeLoadException_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z74mscorlib_System_UnhandledExceptionEventArgs_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_UnitySerializationHolder_m_GetTypeDataP22mscorlib_System_ObjectP20mscorlib_System_TypeP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$instance,$info,$ctx) {
 $__this = $__this|0;
 $instance = $instance|0;
 $info = $info|0;
 $ctx = $ctx|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2657640);
 __THREW__ = 0;
 invoke_v(940);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($instance|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(2730,(2150320|0),($instance|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3076760>>2]|0;
     __THREW__ = 0;
     invoke_viii(621,($info|0),($10|0),($5|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($info|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = HEAP32[3076768>>2]|0;
       __THREW__ = 0;
       invoke_viii(618,($info|0),($15|0),4);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        invoke_vi(3799,($instance|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         $20 = (invoke_iii(2730,(2238288|0),($instance|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          invoke_vi(3799,($20|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           $25 = (invoke_iii(2730,(2370792|0),($20|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            invoke_vi(3799,($info|0));
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             $30 = HEAP32[3076776>>2]|0;
             __THREW__ = 0;
             invoke_viii(621,($info|0),($30|0),($25|0));
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if (!($32)) {
              HEAP32[$0>>2] = 2669472;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
              $33 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               __THREW__ = 0;
               invoke_vi(3799,($info|0));
               $36 = __THREW__; __THREW__ = 0;
               $37 = $36&1;
               if (!($37)) {
                __THREW__ = 0;
                invoke_vii(1897,($info|0),($33|0));
                $38 = __THREW__; __THREW__ = 0;
                $39 = $38&1;
                if (!($39)) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $40 = ___cxa_find_matching_catch()|0;
 $41 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($40|0);
 // unreachable;
}
function __Z56mscorlib_System_UnitySerializationHolder_m_GetDBNullDataP22mscorlib_System_ObjectP22mscorlib_System_DBNullP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$instance,$info,$ctx) {
 $__this = $__this|0;
 $instance = $instance|0;
 $info = $info|0;
 $ctx = $ctx|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2657688);
 __THREW__ = 0;
 invoke_v(941);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($info|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[3076816>>2]|0;
   __THREW__ = 0;
   invoke_viii(621,($info|0),($5|0),(0|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3076824>>2]|0;
     __THREW__ = 0;
     invoke_viii(618,($info|0),($10|0),2);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($instance|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       $15 = (invoke_ii(1782,($instance|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        invoke_vi(3799,($15|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         $20 = (invoke_iii(2730,(2238288|0),($15|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          invoke_vi(3799,($20|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           $25 = (invoke_iii(2730,(2370792|0),($20|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            invoke_vi(3799,($info|0));
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             $30 = HEAP32[3076832>>2]|0;
             __THREW__ = 0;
             invoke_viii(621,($info|0),($30|0),($25|0));
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if (!($32)) {
              HEAP32[$0>>2] = 2669472;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
              $33 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               __THREW__ = 0;
               invoke_vi(3799,($info|0));
               $36 = __THREW__; __THREW__ = 0;
               $37 = $36&1;
               if (!($37)) {
                __THREW__ = 0;
                invoke_vii(1897,($info|0),($33|0));
                $38 = __THREW__; __THREW__ = 0;
                $39 = $38&1;
                if (!($39)) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $40 = ___cxa_find_matching_catch()|0;
 $41 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($40|0);
 // unreachable;
}
function __Z56mscorlib_System_UnitySerializationHolder_m_GetModuleDataP22mscorlib_System_ObjectP33mscorlib_System_Reflection_ModuleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$instance,$info,$ctx) {
 $__this = $__this|0;
 $instance = $instance|0;
 $info = $info|0;
 $ctx = $ctx|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2657736);
 __THREW__ = 0;
 invoke_v(942);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($instance|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(2231,($instance|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($info|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3076848>>2]|0;
     __THREW__ = 0;
     invoke_viii(621,($info|0),($10|0),($5|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($info|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = HEAP32[3076856>>2]|0;
       __THREW__ = 0;
       invoke_viii(618,($info|0),($15|0),5);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        invoke_vi(3799,($instance|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         $20 = (invoke_ii(2230,($instance|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          invoke_vi(3799,($20|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           $25 = (invoke_iii(2730,(2370792|0),($20|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            invoke_vi(3799,($info|0));
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             $30 = HEAP32[3076864>>2]|0;
             __THREW__ = 0;
             invoke_viii(621,($info|0),($30|0),($25|0));
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if (!($32)) {
              HEAP32[$0>>2] = 2669472;
              __THREW__ = 0;
              ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
              $33 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               __THREW__ = 0;
               invoke_vi(3799,($info|0));
               $36 = __THREW__; __THREW__ = 0;
               $37 = $36&1;
               if (!($37)) {
                __THREW__ = 0;
                invoke_vii(1897,($info|0),($33|0));
                $38 = __THREW__; __THREW__ = 0;
                $39 = $38&1;
                if (!($39)) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $40 = ___cxa_find_matching_catch()|0;
 $41 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($40|0);
 // unreachable;
}
function __Z56mscorlib_System_UnitySerializationHolder_m_GetObjectDataP40mscorlib_System_UnitySerializationHolderP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext($__this,$info,$context) {
 $__this = $__this|0;
 $info = $info|0;
 $context = $context|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2657784);
 __THREW__ = 0;
 (invoke_ii(2996,(2622808|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2622808|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2756,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3841,($2|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     // unreachable;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z75mscorlib_System_Version_m__ctor_mscorlib_System_Void_mscorlib_System_StringP23mscorlib_System_VersionP22mscorlib_System_String($__this,$version) {
 $__this = $__this|0;
 $version = $version|0;
 var $$off = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_3$01012 = 0, $V_4$014 = 0, $V_5$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658296);
 __THREW__ = 0;
 invoke_v(943);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = ($version|0)==(0|0);
    if ($4) {
     __THREW__ = 0;
     (invoke_ii(2996,(2560584|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     $9 = (invoke_ii(3469,(2560584|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     $12 = HEAP32[3076880>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3841,($9|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1168808|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     (invoke_ii(2996,(1168808|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      $21 = (invoke_iii(2232,(1168808|0),1)|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vi(3799,($21|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        $26 = (($21) + 12|0);
        $27 = HEAP32[$26>>2]|0;
        $28 = ($27|0)==(0);
        if ($28) {
         __THREW__ = 0;
         $29 = (invoke_i(132)|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($29|0));
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break;
         }
        }
        $34 = (($21) + 16|0);
        HEAP16[$34>>1] = 46;
        __THREW__ = 0;
        invoke_vi(3799,($version|0));
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         __THREW__ = 0;
         $37 = (invoke_iii(622,($version|0),($21|0))|0);
         $38 = __THREW__; __THREW__ = 0;
         $39 = $38&1;
         if (!($39)) {
          __THREW__ = 0;
          invoke_vi(3799,($37|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if (!($41)) {
           $42 = (($37) + 12|0);
           $43 = HEAP32[$42>>2]|0;
           $$off = (($43) + -2)|0;
           $44 = ($$off>>>0)<(3);
           if (!($44)) {
            $45 = HEAP32[3076888>>2]|0;
            __THREW__ = 0;
            $46 = (invoke_iii(783,(0|0),($45|0))|0);
            $47 = __THREW__; __THREW__ = 0;
            $48 = $47&1;
            if ($48) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2560072|0))|0);
            $49 = __THREW__; __THREW__ = 0;
            $50 = $49&1;
            if ($50) {
             break;
            }
            __THREW__ = 0;
            $51 = (invoke_ii(3469,(2560072|0))|0);
            $52 = __THREW__; __THREW__ = 0;
            $53 = $52&1;
            if ($53) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1924,($51|0),($46|0));
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if ($55) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3841,($51|0));
            $56 = __THREW__; __THREW__ = 0;
            $57 = $56&1;
            if ($57) {
             break;
            }
            // unreachable;
           }
           __THREW__ = 0;
           invoke_vi(3799,($37|0));
           $58 = __THREW__; __THREW__ = 0;
           $59 = $58&1;
           if (!($59)) {
            $60 = HEAP32[$42>>2]|0;
            $61 = ($60|0)==(0);
            if ($61) {
             __THREW__ = 0;
             $62 = (invoke_i(132)|0);
             $63 = __THREW__; __THREW__ = 0;
             $64 = $63&1;
             if ($64) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($62|0));
             $65 = __THREW__; __THREW__ = 0;
             $66 = $65&1;
             if ($66) {
              break;
             }
            }
            $67 = (($37) + 16|0);
            $68 = HEAP32[$67>>2]|0;
            __THREW__ = 0;
            $69 = (invoke_iii(474,(0|0),($68|0))|0);
            $70 = __THREW__; __THREW__ = 0;
            $71 = $70&1;
            if (!($71)) {
             $72 = ($43|0)<(2);
             do {
              if ($72) {
               $V_3$01012 = -1;$V_4$014 = -1;$V_5$0 = -1;
              } else {
               __THREW__ = 0;
               invoke_vi(3799,($37|0));
               $73 = __THREW__; __THREW__ = 0;
               $74 = $73&1;
               if ($74) {
                break L1;
               }
               $75 = HEAP32[$42>>2]|0;
               $76 = ($75>>>0)<(2);
               if ($76) {
                __THREW__ = 0;
                $77 = (invoke_i(132)|0);
                $78 = __THREW__; __THREW__ = 0;
                $79 = $78&1;
                if ($79) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3302,($77|0));
                $80 = __THREW__; __THREW__ = 0;
                $81 = $80&1;
                if ($81) {
                 break L1;
                }
               }
               $82 = HEAP32[$37>>2]|0;
               $83 = (($82) + 92|0);
               $84 = HEAP32[$83>>2]|0;
               $85 = (($67) + ($84)|0);
               $86 = HEAP32[$85>>2]|0;
               __THREW__ = 0;
               $87 = (invoke_iii(474,(0|0),($86|0))|0);
               $88 = __THREW__; __THREW__ = 0;
               $89 = $88&1;
               if ($89) {
                break L1;
               }
               $90 = ($43|0)<(3);
               if ($90) {
                $V_3$01012 = $87;$V_4$014 = -1;$V_5$0 = -1;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($37|0));
               $91 = __THREW__; __THREW__ = 0;
               $92 = $91&1;
               if ($92) {
                break L1;
               }
               $93 = HEAP32[$42>>2]|0;
               $94 = ($93>>>0)<(3);
               if ($94) {
                __THREW__ = 0;
                $95 = (invoke_i(132)|0);
                $96 = __THREW__; __THREW__ = 0;
                $97 = $96&1;
                if ($97) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3302,($95|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 break L1;
                }
               }
               $100 = HEAP32[$37>>2]|0;
               $101 = (($100) + 92|0);
               $102 = HEAP32[$101>>2]|0;
               $103 = $102 << 1;
               $104 = (($67) + ($103)|0);
               $105 = HEAP32[$104>>2]|0;
               __THREW__ = 0;
               $106 = (invoke_iii(474,(0|0),($105|0))|0);
               $107 = __THREW__; __THREW__ = 0;
               $108 = $107&1;
               if ($108) {
                break L1;
               }
               $109 = ($43|0)<(4);
               if ($109) {
                $V_3$01012 = $87;$V_4$014 = $106;$V_5$0 = -1;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($37|0));
               $110 = __THREW__; __THREW__ = 0;
               $111 = $110&1;
               if ($111) {
                break L1;
               }
               $112 = HEAP32[$42>>2]|0;
               $113 = ($112>>>0)<(4);
               if ($113) {
                __THREW__ = 0;
                $114 = (invoke_i(132)|0);
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if ($116) {
                 break L1;
                }
                __THREW__ = 0;
                invoke_vi(3302,($114|0));
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 break L1;
                }
               }
               $119 = HEAP32[$37>>2]|0;
               $120 = (($119) + 92|0);
               $121 = HEAP32[$120>>2]|0;
               $122 = ($121*3)|0;
               $123 = (($67) + ($122)|0);
               $124 = HEAP32[$123>>2]|0;
               __THREW__ = 0;
               $125 = (invoke_iii(474,(0|0),($124|0))|0);
               $126 = __THREW__; __THREW__ = 0;
               $127 = $126&1;
               if ($127) {
                break L1;
               } else {
                $V_3$01012 = $87;$V_4$014 = $106;$V_5$0 = $125;
               }
              }
             } while(0);
             __THREW__ = 0;
             invoke_viiiiii(68,($__this|0),($43|0),($69|0),($V_3$01012|0),($V_4$014|0),($V_5$0|0));
             $128 = __THREW__; __THREW__ = 0;
             $129 = $128&1;
             if (!($129)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z36mscorlib_System_Version_m_CheckedSetP23mscorlib_System_Versioniiiii($__this,$defined,$major,$minor,$build,$revision) {
 $__this = $__this|0;
 $defined = $defined|0;
 $major = $major|0;
 $minor = $minor|0;
 $build = $build|0;
 $revision = $revision|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658392);
 __THREW__ = 0;
 invoke_v(944);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($major|0)>(-1);
   if (!($2)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2561352|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3077024>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = (($__this) + 8|0);
   HEAP32[$15>>2] = $major;
   $16 = ($minor|0)>(-1);
   if (!($16)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    $19 = (invoke_ii(3469,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    $22 = HEAP32[3077032>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($19|0),($22|0));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($19|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    // unreachable;
   }
   $27 = (($__this) + 12|0);
   HEAP32[$27>>2] = $minor;
   $28 = ($defined|0)==(2);
   if ($28) {
    $29 = (($__this) + 16|0);
    HEAP32[$29>>2] = -1;
    $30 = (($__this) + 20|0);
    HEAP32[$30>>2] = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $31 = ($build|0)>(-1);
   if (!($31)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    __THREW__ = 0;
    $34 = (invoke_ii(3469,(2561352|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = HEAP32[3077040>>2]|0;
    __THREW__ = 0;
    invoke_vii(1926,($34|0),($37|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3841,($34|0));
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    // unreachable;
   }
   $42 = (($__this) + 16|0);
   HEAP32[$42>>2] = $build;
   $43 = ($defined|0)==(3);
   if ($43) {
    $44 = (($__this) + 20|0);
    HEAP32[$44>>2] = -1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $45 = ($revision|0)>(-1);
   if ($45) {
    $56 = (($__this) + 20|0);
    HEAP32[$56>>2] = $revision;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if (!($47)) {
    __THREW__ = 0;
    $48 = (invoke_ii(3469,(2561352|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if (!($50)) {
     $51 = HEAP32[3077048>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($48|0),($51|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if (!($53)) {
      __THREW__ = 0;
      invoke_vi(3841,($48|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if (!($55)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z140mscorlib_System_Version_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P23mscorlib_System_Versioniiii($__this,$major,$minor,$build,$revision) {
 $__this = $__this|0;
 $major = $major|0;
 $minor = $minor|0;
 $build = $build|0;
 $revision = $revision|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658344);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viiiiii(68,($__this|0),4,($major|0),($minor|0),($build|0),($revision|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z80mscorlib_System_Version_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP23mscorlib_System_VersionP22mscorlib_System_Object($__this,$version) {
 $__this = $__this|0;
 $version = $version|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658440);
 __THREW__ = 0;
 invoke_v(945);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($version|0)==(0|0);
   if ($2) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2659512|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2735,($version|0),(2659512|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7|0)==(0|0);
     if (!($10)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2659512|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      $26 = (invoke_iii(2772,($version|0),(2659512|0))|0);
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iiii(1641,(2658488|0),($__this|0),($26|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       break;
      } else {
       $$0 = $29;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $11 = HEAP32[3077128>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_ii(3469,(2560072|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        invoke_vii(1924,($17|0),($12|0));
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         invoke_vi(3841,($17|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          // unreachable;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Version_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP23mscorlib_System_VersionP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658536);
 __THREW__ = 0;
 (invoke_ii(2996,(2659512|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($obj|0),(2659512|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiii(1640,(2658584|0),($__this|0),($2|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Version_m_CompareTo_mscorlib_System_Int32_mscorlib_System_VersionP23mscorlib_System_VersionS0_($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658488);
 __THREW__ = 0;
 $0 = (invoke_iiii(1278,0,($value|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    $$0 = 1;
   } else {
    $5 = (($__this) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($value|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    $9 = (($value) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($6|0)>($10|0);
    if ($11) {
     $$0 = 1;
    } else {
     $12 = HEAP32[$5>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($value|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = HEAP32[$9>>2]|0;
     $16 = ($12|0)<($15|0);
     if ($16) {
      $$0 = -1;
     } else {
      $17 = (($__this) + 12|0);
      $18 = HEAP32[$17>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($value|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = (($value) + 12|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = ($18|0)>($22|0);
      if ($23) {
       $$0 = 1;
      } else {
       $24 = HEAP32[$17>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($value|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       $27 = HEAP32[$21>>2]|0;
       $28 = ($24|0)<($27|0);
       if ($28) {
        $$0 = -1;
       } else {
        $29 = (($__this) + 16|0);
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($value|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if ($32) {
         break;
        }
        $33 = (($value) + 16|0);
        $34 = HEAP32[$33>>2]|0;
        $35 = ($30|0)>($34|0);
        if ($35) {
         $$0 = 1;
        } else {
         $36 = HEAP32[$29>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($value|0));
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break;
         }
         $39 = HEAP32[$33>>2]|0;
         $40 = ($36|0)<($39|0);
         if ($40) {
          $$0 = -1;
         } else {
          $41 = (($__this) + 20|0);
          $42 = HEAP32[$41>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($value|0));
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if ($44) {
           break;
          }
          $45 = (($value) + 20|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = ($42|0)>($46|0);
          if ($47) {
           $$0 = 1;
          } else {
           $48 = HEAP32[$41>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($value|0));
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            break;
           }
           $51 = HEAP32[$45>>2]|0;
           $52 = ($48|0)<($51|0);
           $$ = $52 << 31 >> 31;
           $$0 = $$;
          }
         }
        }
       }
      }
     }
    }
   }
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Version_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_Version_mscorlib_System_VersionP22mscorlib_System_ObjectP23mscorlib_System_VersionS2_($__this,$v1,$v2) {
 $__this = $__this|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658776);
 __THREW__ = 0;
 $0 = (invoke_iiii(423,(0|0),($v1|0),($v2|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z80mscorlib_System_Version_m_Equals_mscorlib_System_Boolean_mscorlib_System_VersionP23mscorlib_System_VersionS0_($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B6_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658584);
 __THREW__ = 0;
 $0 = (invoke_iiii(1279,0,($obj|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   if ($0) {
    __THREW__ = 0;
    invoke_vi(3799,($obj|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    $7 = (($obj) + 8|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($__this) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($8|0)==($10|0);
    if ($11) {
     __THREW__ = 0;
     invoke_vi(3799,($obj|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = (($obj) + 12|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (($__this) + 12|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($15|0)==($17|0);
     if ($18) {
      __THREW__ = 0;
      invoke_vi(3799,($obj|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = (($obj) + 16|0);
      $22 = HEAP32[$21>>2]|0;
      $23 = (($__this) + 16|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($22|0)==($24|0);
      if ($25) {
       __THREW__ = 0;
       invoke_vi(3799,($obj|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       $28 = (($obj) + 20|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($__this) + 20|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($29|0)==($31|0);
       $G_B6_0$0 = $32;
      } else {
       $G_B6_0$0 = 0;
      }
     } else {
      $G_B6_0$0 = 0;
     }
    } else {
     $G_B6_0$0 = 0;
    }
   } else {
    $G_B6_0$0 = 0;
   }
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B6_0$0|0);
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Version_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_Version_mscorlib_System_VersionP22mscorlib_System_ObjectP23mscorlib_System_VersionS2_($__this,$v1,$v2) {
 $__this = $__this|0;
 $v1 = $v1|0;
 $v2 = $v2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658824);
 __THREW__ = 0;
 $0 = (invoke_iiii(423,(0|0),($v1|0),($v2|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = $0 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z37mscorlib_System_Version_m_GetHashCodeP23mscorlib_System_Version($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658632);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 << 24;
 $3 = (($__this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 16;
 $6 = $5 | $2;
 $7 = (($__this) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 8;
 $10 = $6 | $9;
 $11 = (($__this) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $10 | $12;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($13|0);
}
function __Z34mscorlib_System_Version_m_ToStringP23mscorlib_System_Version($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_0$1 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658680);
 __THREW__ = 0;
 invoke_v(946);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 8|0);
   __THREW__ = 0;
   $3 = (invoke_ii(1791,($2|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($__this) + 12|0);
    __THREW__ = 0;
    $7 = (invoke_ii(1791,($6|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3077240>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iiiii(101,(0|0),($3|0),($10|0),($7|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 16|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = ($15|0)==(-1);
      if ($16) {
       $V_0$0 = $11;
      } else {
       __THREW__ = 0;
       $19 = (invoke_ii(1791,($14|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if ($21) {
        break;
       }
       $22 = HEAP32[3077248>>2]|0;
       __THREW__ = 0;
       $23 = (invoke_iiiii(101,(0|0),($11|0),($22|0),($19|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       } else {
        $V_0$0 = $23;
       }
      }
      $26 = (($__this) + 20|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==(-1);
      if ($28) {
       $V_0$1 = $V_0$0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($V_0$1|0);
      }
      __THREW__ = 0;
      $29 = (invoke_ii(1791,($26|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       $32 = HEAP32[3077256>>2]|0;
       __THREW__ = 0;
       $33 = (invoke_iiiii(101,(0|0),($V_0$0|0),($32|0),($29|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if (!($35)) {
        $V_0$1 = $33;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($V_0$1|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z42mscorlib_System_Version_m_CreateFromStringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$info) {
 $__this = $__this|0;
 $info = $info|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$2 = 0, $V_0$3 = 0, $V_0$4 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_1$2 = 0, $V_1$3 = 0, $V_1$4 = 0, $V_2$0 = 0, $V_2$1 = 0;
 var $V_2$2 = 0, $V_2$3 = 0, $V_2$4 = 0, $V_3$0 = 0, $V_3$1 = 0, $V_3$2 = 0, $V_3$3 = 0, $V_3$4 = 0, $V_4$0 = 0, $V_4$1 = 0, $V_4$2 = 0, $V_5$0 = 0, $V_5$1 = 0, $V_5$2 = 0, $V_6$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2658728);
 $0 = ($info|0)==(0|0);
 if ($0) {
  __THREW__ = 0;
  (invoke_ii(2996,(2659512|0))|0);
  $1 = __THREW__; __THREW__ = 0;
  $2 = $1&1;
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(3469,(2659512|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_viiiii(74,($3|0),0,0,0,0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $$0 = $3;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } else {
  $V_0$2 = 0;$V_1$2 = 0;$V_2$2 = 0;$V_3$2 = 0;$V_4$1 = 1;$V_5$1 = -1;$V_6$0 = 0;
  while(1) {
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $33 = (invoke_ii(1816,($info|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    label = 6;
    break;
   }
   $36 = ($V_6$0|0)<($33|0);
   if (!($36)) {
    $V_0$3 = $V_0$2;$V_1$3 = $V_1$2;$V_2$3 = $V_2$2;$V_3$3 = $V_3$2;$V_4$2 = $V_4$1;$V_5$2 = $V_5$1;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($info|0));
   $37 = __THREW__; __THREW__ = 0;
   $38 = $37&1;
   if ($38) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $12 = (invoke_iii(621,($info|0),($V_6$0|0))|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $15 = (invoke_iii(600,(0|0),($12|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    label = 6;
    break;
   }
   do {
    if ($15) {
     $18 = ($V_5$1|0)>(-1);
     if ($18) {
      $22 = ($V_5$1*10)|0;
      $23 = $12&65535;
      $24 = (($23) + 65488)|0;
      $25 = $24 & 65535;
      $26 = (($25) + ($22))|0;
      $V_0$1 = $V_0$2;$V_1$1 = $V_1$2;$V_2$1 = $V_2$2;$V_3$1 = $V_3$2;$V_4$0 = $V_4$1;$V_5$0 = $26;
      break;
     } else {
      $19 = $12&65535;
      $20 = (($19) + 65488)|0;
      $21 = $20 & 65535;
      $V_0$1 = $V_0$2;$V_1$1 = $V_1$2;$V_2$1 = $V_2$2;$V_3$1 = $V_3$2;$V_4$0 = $V_4$1;$V_5$0 = $21;
      break;
     }
    } else {
     $27 = ($V_5$1|0)<(0);
     if ($27) {
      $V_0$1 = $V_0$2;$V_1$1 = $V_1$2;$V_2$1 = $V_2$2;$V_3$1 = $V_3$2;$V_4$0 = $V_4$1;$V_5$0 = $V_5$1;
     } else {
      if ((($V_4$1|0) == 1)) {
       $V_0$0 = $V_5$1;$V_1$0 = $V_1$2;$V_2$0 = $V_2$2;$V_3$0 = $V_3$2;
      } else if ((($V_4$1|0) == 2)) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_5$1;$V_2$0 = $V_2$2;$V_3$0 = $V_3$2;
      } else if ((($V_4$1|0) == 3)) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;$V_2$0 = $V_5$1;$V_3$0 = $V_3$2;
      } else if ((($V_4$1|0) == 4)) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;$V_2$0 = $V_2$2;$V_3$0 = $V_5$1;
      } else {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;$V_2$0 = $V_2$2;$V_3$0 = $V_3$2;
      }
      $28 = (($V_4$1) + 1)|0;
      $V_0$1 = $V_0$0;$V_1$1 = $V_1$0;$V_2$1 = $V_2$0;$V_3$1 = $V_3$0;$V_4$0 = $28;$V_5$0 = -1;
     }
    }
   } while(0);
   $29 = ($V_4$0|0)==(5);
   $30 = (($V_6$0) + 1)|0;
   if ($29) {
    $V_0$3 = $V_0$1;$V_1$3 = $V_1$1;$V_2$3 = $V_2$1;$V_3$3 = $V_3$1;$V_4$2 = 5;$V_5$2 = $V_5$0;
    break;
   } else {
    $V_0$2 = $V_0$1;$V_1$2 = $V_1$1;$V_2$2 = $V_2$1;$V_3$2 = $V_3$1;$V_4$1 = $V_4$0;$V_5$1 = $V_5$0;$V_6$0 = $30;
   }
  }
  if ((label|0) == 6) {
   $8 = ___cxa_find_matching_catch()|0;
   $9 = tempRet0;
   $lpad$phi$index = $8;$lpad$phi$index2 = $9;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  $39 = ($V_5$2|0)<(0);
  do {
   if ($39) {
    $V_0$4 = $V_0$3;$V_1$4 = $V_1$3;$V_2$4 = $V_2$3;$V_3$4 = $V_3$3;
   } else {
    if ((($V_4$2|0) == 1)) {
     $V_0$4 = $V_5$2;$V_1$4 = $V_1$3;$V_2$4 = $V_2$3;$V_3$4 = $V_3$3;
     break;
    } else if ((($V_4$2|0) == 3)) {
     $V_0$4 = $V_0$3;$V_1$4 = $V_1$3;$V_2$4 = $V_5$2;$V_3$4 = $V_3$3;
     break;
    } else if ((($V_4$2|0) == 2)) {
     $V_0$4 = $V_0$3;$V_1$4 = $V_5$2;$V_2$4 = $V_2$3;$V_3$4 = $V_3$3;
     break;
    } else if ((($V_4$2|0) == 4)) {
     $V_0$4 = $V_0$3;$V_1$4 = $V_1$3;$V_2$4 = $V_2$3;$V_3$4 = $V_5$2;
     break;
    } else {
     $V_0$4 = $V_0$3;$V_1$4 = $V_1$3;$V_2$4 = $V_2$3;$V_3$4 = $V_3$3;
     break;
    }
   }
  } while(0);
  __THREW__ = 0;
  (invoke_ii(2996,(2659512|0))|0);
  $40 = __THREW__; __THREW__ = 0;
  $41 = $40&1;
  if (!($41)) {
   __THREW__ = 0;
   $42 = (invoke_ii(3469,(2659512|0))|0);
   $43 = __THREW__; __THREW__ = 0;
   $44 = $43&1;
   if (!($44)) {
    __THREW__ = 0;
    invoke_viiiii(74,($42|0),($V_0$4|0),($V_1$4|0),($V_2$4|0),($V_3$4|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     $$0 = $42;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker4I27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEPFvPviiiiES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$1,$4,$7,$10);
 STACKTOP = sp;return (0|0);
}
function __Z54mscorlib_System_Version_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z47mscorlib_System_Reflection_MemberFilter_m__ctorP39mscorlib_System_Reflection_MemberFilterP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2659648);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z48mscorlib_System_Reflection_MemberFilter_m_InvokeP39mscorlib_System_Reflection_MemberFilterP37mscorlib_System_Reflection_MemberInfoP22mscorlib_System_Object($__this,$m,$filterCriteria) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2659696);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_iiii(1280,($1|0),($m|0),($filterCriteria|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiii($8|0,($10|0),($m|0),($filterCriteria|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z53mscorlib_System_Reflection_MemberFilter_m_BeginInvokeP39mscorlib_System_Reflection_MemberFilterP37mscorlib_System_Reflection_MemberInfoP22mscorlib_System_ObjectP29mscorlib_System_AsyncCallbackS4_($__this,$m,$filterCriteria,$callback,$object) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2659744);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z51mscorlib_System_Reflection_MemberFilter_m_EndInvokeP39mscorlib_System_Reflection_MemberFilterP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2659792);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS0_S1_E6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectS3_S5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z70mscorlib_System_Reflection_MemberFilter_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z45mscorlib_System_Reflection_TypeFilter_m__ctorP37mscorlib_System_Reflection_TypeFilterP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2660296);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z46mscorlib_System_Reflection_TypeFilter_m_InvokeP37mscorlib_System_Reflection_TypeFilterP20mscorlib_System_TypeP22mscorlib_System_Object($__this,$m,$filterCriteria) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2660344);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_iiii(1282,($1|0),($m|0),($filterCriteria|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiii($8|0,($10|0),($m|0),($filterCriteria|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z51mscorlib_System_Reflection_TypeFilter_m_BeginInvokeP37mscorlib_System_Reflection_TypeFilterP20mscorlib_System_TypeP22mscorlib_System_ObjectP29mscorlib_System_AsyncCallbackS4_($__this,$m,$filterCriteria,$callback,$object) {
 $__this = $__this|0;
 $m = $m|0;
 $filterCriteria = $filterCriteria|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2660392);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z49mscorlib_System_Reflection_TypeFilter_m_EndInvokeP37mscorlib_System_Reflection_TypeFilterP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2660440);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z68mscorlib_System_Reflection_TypeFilter_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z44mscorlib_System_AppDomainInitializer_m__ctorP36mscorlib_System_AppDomainInitializerP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2661248);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z45mscorlib_System_AppDomainInitializer_m_InvokeP36mscorlib_System_AppDomainInitializerP26mscorlib_System_String_arr($__this,$args) {
 $__this = $__this|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2661296);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vii(1979,($1|0),($args|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($10|0),($args|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z50mscorlib_System_AppDomainInitializer_m_BeginInvokeP36mscorlib_System_AppDomainInitializerP26mscorlib_System_String_arrP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$args,$callback,$object) {
 $__this = $__this|0;
 $args = $args|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2661344);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z48mscorlib_System_AppDomainInitializer_m_EndInvokeP36mscorlib_System_AppDomainInitializerP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2661392);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z67mscorlib_System_AppDomainInitializer_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z48mscorlib_System_AssemblyLoadEventHandler_m__ctorP40mscorlib_System_AssemblyLoadEventHandlerP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2661824);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z49mscorlib_System_AssemblyLoadEventHandler_m_InvokeP40mscorlib_System_AssemblyLoadEventHandlerP22mscorlib_System_ObjectP37mscorlib_System_AssemblyLoadEventArgs($__this,$sender,$args) {
 $__this = $__this|0;
 $sender = $sender|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2661872);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  invoke_viii(714,($1|0),($sender|0),($args|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 invoke_viii($8|0,($10|0),($sender|0),($args|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54mscorlib_System_AssemblyLoadEventHandler_m_BeginInvokeP40mscorlib_System_AssemblyLoadEventHandlerP22mscorlib_System_ObjectP37mscorlib_System_AssemblyLoadEventArgsP29mscorlib_System_AsyncCallbackS2_($__this,$sender,$args,$callback,$object) {
 $__this = $__this|0;
 $sender = $sender|0;
 $args = $args|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2661920);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z52mscorlib_System_AssemblyLoadEventHandler_m_EndInvokeP40mscorlib_System_AssemblyLoadEventHandlerP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2661968);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker4I17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_S0_S1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS3_S3_S5_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$0,$2,$4,$6)|0);
 STACKTOP = sp;return ($7|0);
}
function __Z71mscorlib_System_AssemblyLoadEventHandler_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z36mscorlib_System_EventHandler_m__ctorP28mscorlib_System_EventHandlerP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2663312);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z37mscorlib_System_EventHandler_m_InvokeP28mscorlib_System_EventHandlerP22mscorlib_System_ObjectP25mscorlib_System_EventArgs($__this,$sender,$e) {
 $__this = $__this|0;
 $sender = $sender|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2663360);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  invoke_viii(716,($1|0),($sender|0),($e|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 invoke_viii($8|0,($10|0),($sender|0),($e|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42mscorlib_System_EventHandler_m_BeginInvokeP28mscorlib_System_EventHandlerP22mscorlib_System_ObjectP25mscorlib_System_EventArgsP29mscorlib_System_AsyncCallbackS2_($__this,$sender,$e,$callback,$object) {
 $__this = $__this|0;
 $sender = $sender|0;
 $e = $e|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2663408);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z40mscorlib_System_EventHandler_m_EndInvokeP28mscorlib_System_EventHandlerP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2663456);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z59mscorlib_System_EventHandler_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z43mscorlib_System_ResolveEventHandler_m__ctorP35mscorlib_System_ResolveEventHandlerP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2664248);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z44mscorlib_System_ResolveEventHandler_m_InvokeP35mscorlib_System_ResolveEventHandlerP22mscorlib_System_ObjectP32mscorlib_System_ResolveEventArgs($__this,$sender,$args) {
 $__this = $__this|0;
 $sender = $sender|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2664296);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  (invoke_iiii(1284,($1|0),($sender|0),($args|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiii($8|0,($10|0),($sender|0),($args|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __Z49mscorlib_System_ResolveEventHandler_m_BeginInvokeP35mscorlib_System_ResolveEventHandlerP22mscorlib_System_ObjectP32mscorlib_System_ResolveEventArgsP29mscorlib_System_AsyncCallbackS2_($__this,$sender,$args,$callback,$object) {
 $__this = $__this|0;
 $sender = $sender|0;
 $args = $args|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2664344);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z47mscorlib_System_ResolveEventHandler_m_EndInvokeP35mscorlib_System_ResolveEventHandlerP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2664392);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$2)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z66mscorlib_System_ResolveEventHandler_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z54mscorlib_System_UnhandledExceptionEventHandler_m__ctorP46mscorlib_System_UnhandledExceptionEventHandlerP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2664840);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z55mscorlib_System_UnhandledExceptionEventHandler_m_InvokeP46mscorlib_System_UnhandledExceptionEventHandlerP22mscorlib_System_ObjectP43mscorlib_System_UnhandledExceptionEventArgs($__this,$sender,$e) {
 $__this = $__this|0;
 $sender = $sender|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2664888);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  invoke_viii(719,($1|0),($sender|0),($e|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 invoke_viii($8|0,($10|0),($sender|0),($e|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z60mscorlib_System_UnhandledExceptionEventHandler_m_BeginInvokeP46mscorlib_System_UnhandledExceptionEventHandlerP22mscorlib_System_ObjectP43mscorlib_System_UnhandledExceptionEventArgsP29mscorlib_System_AsyncCallbackS2_($__this,$sender,$e,$callback,$object) {
 $__this = $__this|0;
 $sender = $sender|0;
 $e = $e|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2664936);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z58mscorlib_System_UnhandledExceptionEventHandler_m_EndInvokeP46mscorlib_System_UnhandledExceptionEventHandlerP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2664984);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z77mscorlib_System_UnhandledExceptionEventHandler_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z78mscorlib_U003CPrivateImplementationDetailsU003E_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z52replacements_Replacements_Thread_m_GetCurrentCultureP22mscorlib_System_ObjectP32mscorlib_System_Threading_Thread($__this,$_____thread) {
 $__this = $__this|0;
 $_____thread = $_____thread|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2671104);
 __THREW__ = 0;
 $0 = (invoke_ii(1982,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z47replacements_Replacements_Encoding_m_InvokeI18NP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$name,$args) {
 $__this = $__this|0;
 $name = $name|0;
 $args = $args|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2671384);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z60replacements_Replacements_MSCompatUnicodeTable_m_get_IsReadyP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2671656);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return 0;
}
function __Z53replacements_Replacements_Attribute_m_CheckParametersP22mscorlib_System_ObjectS0_P20mscorlib_System_Type($__this,$element,$attributeType) {
 $__this = $__this|0;
 $element = $element|0;
 $attributeType = $attributeType|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2671920);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z70System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m__ctorP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2672520);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z93System_Core_System_Runtime_CompilerServices_ExtensionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,69);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z44System_Core_System_MonoTODOAttribute_m__ctorP36System_Core_System_MonoTODOAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2672832);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z67System_Core_System_MonoTODOAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,32767);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z144System_Core_System_Collections_Generic_HashSet_1_CustomAttributesCacheGenerator_System_Core_System_Collections_Generic_HashSet_1_m_GetObjectDataP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2672976)|0);
 __Z44System_Core_System_MonoTODOAttribute_m__ctorP36System_Core_System_MonoTODOAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81System_Core_U003CPrivateImplementationDetailsU003E_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z72System_System_Collections_Generic_Stack_1_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159616)|0);
 __Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2676544);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54UnityEngine_UnityEngine_AttributeHelperEngine_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2676824);
 __THREW__ = 0;
 (invoke_ii(2996,(1179288|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2773,(1179288|0),1)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2677408|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[((2677408 + 80|0))>>2]|0;
    HEAP32[$7>>2] = $2;
    __THREW__ = 0;
    (invoke_ii(2996,(1179680|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2773,(1179680|0),1)|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2677408|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = HEAP32[((2677408 + 80|0))>>2]|0;
       $16 = (($15) + 4|0);
       HEAP32[$16>>2] = $10;
       __THREW__ = 0;
       (invoke_ii(2996,(1180072|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        $19 = (invoke_iii(2773,(1180072|0),1)|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2677408|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          $24 = HEAP32[((2677408 + 80|0))>>2]|0;
          $25 = (($24) + 8|0);
          HEAP32[$25>>2] = $19;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($26|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj10825($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z89UnityEngine_UnityEngine_AttributeHelperEngine_m_GetParentTypeDisallowingMultipleInclusionP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $$0 = 0, $$015 = 0, $$byval_copy8 = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy8 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2676872);
 __THREW__ = 0;
 (invoke_ii(2996,(1717232|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_ii(3469,(1717232|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_vi(3842,($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($type|0)==(0|0);
    L5: do {
     if ($9) {
      $$pre$phiZ2D = $4;
     } else {
      $$015 = $type;
      while(1) {
       HEAP32[$0>>2] = 1754840;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$0+0>>2]|0;
       $24 = (invoke_iii(772,(0|0),($$byval_copy8|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        break;
       }
       $27 = ($$015|0)==($24|0);
       if ($27) {
        $$pre$phiZ2D = $4;
        break L5;
       }
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(3499,($4|0),($$015|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($$015|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
       __THREW__ = 0;
       $20 = (invoke_iii(2730,(2235944|0),($$015|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        break;
       }
       $23 = ($20|0)==(0|0);
       if ($23) {
        $$pre$phiZ2D = $4;
        break L5;
       } else {
        $$015 = $20;
       }
      }
      $12 = ___cxa_find_matching_catch()|0;
      $13 = tempRet0;
      $lpad$phi$index = $12;$lpad$phi$index3 = $13;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    } while(0);
    while(1) {
     __THREW__ = 0;
     invoke_vi(3799,($$pre$phiZ2D|0));
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     $48 = (invoke_iii(2729,(1716984|0),($$pre$phiZ2D|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      label = 7;
      break;
     }
     $51 = ($48|0)>(0);
     if (!($51)) {
      $$0 = 0;
      label = 29;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($$pre$phiZ2D|0));
     $52 = __THREW__; __THREW__ = 0;
     $53 = $52&1;
     if ($53) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     $30 = (invoke_ii(3476,($4|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      label = 7;
      break;
     }
     HEAP32[$1>>2] = 1755976;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy8+0>>2]=HEAP32[$1+0>>2]|0;
     $33 = (invoke_iii(772,(0|0),($$byval_copy8|0))|0);
     $34 = __THREW__; __THREW__ = 0;
     $35 = $34&1;
     if ($35) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($30|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if ($37) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     $38 = (invoke_iiiii(322,(2242752|0),($30|0),($33|0),0)|0);
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if ($40) {
      label = 7;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($38|0));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      label = 7;
      break;
     }
     $43 = (($38) + 12|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = ($44|0)==(0);
     if (!($45)) {
      $$0 = $30;
      label = 29;
      break;
     }
    }
    if ((label|0) == 7) {
     $10 = ___cxa_find_matching_catch()|0;
     $11 = tempRet0;
     $lpad$phi$index = $10;$lpad$phi$index3 = $11;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
    else if ((label|0) == 29) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index3 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z69UnityEngine_UnityEngine_AttributeHelperEngine_m_GetRequiredComponentsP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$klass) {
 $__this = $__this|0;
 $klass = $klass|0;
 var $$0 = 0, $$0113 = 0, $$byval_copy9 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$2$lcssa = 0, $V_0$212 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy9 = sp + 16|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2676920);
 $3 = ($klass|0)==(0|0);
 if ($3) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $$0113 = $klass;$V_0$212 = 0;
 L4: while(1) {
  HEAP32[$2>>2] = 1754840;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$2+0>>2]|0;
  $166 = (invoke_iii(772,(0|0),($$byval_copy9|0))|0);
  $167 = __THREW__; __THREW__ = 0;
  $168 = $167&1;
  if ($168) {
   label = 7;
   break;
  }
  $169 = ($$0113|0)==($166|0);
  if ($169) {
   $V_0$2$lcssa = $V_0$212;
   label = 71;
   break;
  }
  HEAP32[$0>>2] = 1755432;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$0+0>>2]|0;
  $6 = (invoke_iii(772,(0|0),($$byval_copy9|0))|0);
  $170 = __THREW__; __THREW__ = 0;
  $171 = $170&1;
  if ($171) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($$0113|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if ($5) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  $7 = (invoke_iiiii(322,(2242752|0),($$0113|0),($6|0),0)|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   label = 7;
   break;
  }
  $10 = (($7) + 12|0);
  $V_0$1 = $V_0$212;$V_2$0 = 0;
  while(1) {
   __THREW__ = 0;
   invoke_vi(3799,($7|0));
   $154 = __THREW__; __THREW__ = 0;
   $155 = $154&1;
   if ($155) {
    label = 6;
    break L4;
   }
   $156 = HEAP32[$10>>2]|0;
   $157 = ($V_2$0|0)<($156|0);
   if (!($157)) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($7|0));
   $158 = __THREW__; __THREW__ = 0;
   $159 = $158&1;
   if ($159) {
    label = 6;
    break L4;
   }
   $17 = HEAP32[$10>>2]|0;
   $18 = ($V_2$0>>>0)<($17>>>0);
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_i(132)|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     label = 6;
     break L4;
    }
    __THREW__ = 0;
    invoke_vi(3302,($19|0));
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     label = 6;
     break L4;
    }
   }
   $24 = HEAP32[$7>>2]|0;
   $25 = (($24) + 92|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = Math_imul($26, $V_2$0)|0;
   $$sum = (($27) + 16)|0;
   $28 = (($7) + ($$sum)|0);
   $29 = HEAP32[$28>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2717112|0))|0);
   $30 = __THREW__; __THREW__ = 0;
   $31 = $30&1;
   if ($31) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $32 = (invoke_iii(2774,($29|0),(2717112|0))|0);
   $33 = __THREW__; __THREW__ = 0;
   $34 = $33&1;
   if ($34) {
    label = 6;
    break L4;
   }
   $35 = ($V_0$1|0)==(0|0);
   if ($35) {
    __THREW__ = 0;
    invoke_vi(3799,($7|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     label = 6;
     break L4;
    }
    $38 = HEAP32[$10>>2]|0;
    $39 = ($38|0)==(1);
    if ($39) {
     __THREW__ = 0;
     invoke_vi(3799,($$0113|0));
     $40 = __THREW__; __THREW__ = 0;
     $41 = $40&1;
     if ($41) {
      label = 6;
      break L4;
     }
     __THREW__ = 0;
     $42 = (invoke_iii(2730,(2235944|0),($$0113|0))|0);
     $43 = __THREW__; __THREW__ = 0;
     $44 = $43&1;
     if ($44) {
      label = 6;
      break L4;
     }
     HEAP32[$1>>2] = 1754840;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy9+0>>2]=HEAP32[$1+0>>2]|0;
     $45 = (invoke_iii(772,(0|0),($$byval_copy9|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if ($47) {
      label = 6;
      break L4;
     }
     $48 = ($42|0)==($45|0);
     if ($48) {
      label = 22;
      break L4;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1725200|0))|0);
    $110 = __THREW__; __THREW__ = 0;
    $111 = $110&1;
    if ($111) {
     label = 6;
     break L4;
    }
    __THREW__ = 0;
    $112 = (invoke_ii(3469,(1725200|0))|0);
    $113 = __THREW__; __THREW__ = 0;
    $114 = $113&1;
    if ($114) {
     label = 6;
     break L4;
    }
    __THREW__ = 0;
    invoke_vi(3803,($112|0));
    $115 = __THREW__; __THREW__ = 0;
    $116 = $115&1;
    if ($116) {
     label = 6;
     break L4;
    } else {
     $V_0$0 = $112;
    }
   } else {
    $V_0$0 = $V_0$1;
   }
   __THREW__ = 0;
   invoke_vi(3799,($32|0));
   $117 = __THREW__; __THREW__ = 0;
   $118 = $117&1;
   if ($118) {
    label = 6;
    break L4;
   }
   $119 = (($32) + 8|0);
   $120 = HEAP32[$119>>2]|0;
   $121 = ($120|0)==(0|0);
   if (!($121)) {
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if ($123) {
     label = 6;
     break L4;
    }
    $124 = HEAP32[$119>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($V_0$0|0));
    $125 = __THREW__; __THREW__ = 0;
    $126 = $125&1;
    if ($126) {
     label = 6;
     break L4;
    }
    __THREW__ = 0;
    invoke_viii(2110,(1723192|0),($V_0$0|0),($124|0));
    $127 = __THREW__; __THREW__ = 0;
    $128 = $127&1;
    if ($128) {
     label = 6;
     break L4;
    }
   }
   __THREW__ = 0;
   invoke_vi(3799,($32|0));
   $129 = __THREW__; __THREW__ = 0;
   $130 = $129&1;
   if ($130) {
    label = 6;
    break L4;
   }
   $131 = (($32) + 12|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = ($132|0)==(0|0);
   if (!($133)) {
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $134 = __THREW__; __THREW__ = 0;
    $135 = $134&1;
    if ($135) {
     label = 6;
     break L4;
    }
    $136 = HEAP32[$131>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($V_0$0|0));
    $137 = __THREW__; __THREW__ = 0;
    $138 = $137&1;
    if ($138) {
     label = 6;
     break L4;
    }
    __THREW__ = 0;
    invoke_viii(2110,(1723192|0),($V_0$0|0),($136|0));
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     label = 6;
     break L4;
    }
   }
   __THREW__ = 0;
   invoke_vi(3799,($32|0));
   $141 = __THREW__; __THREW__ = 0;
   $142 = $141&1;
   if ($142) {
    label = 6;
    break L4;
   }
   $143 = (($32) + 16|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ($144|0)==(0|0);
   if (!($145)) {
    __THREW__ = 0;
    invoke_vi(3799,($32|0));
    $146 = __THREW__; __THREW__ = 0;
    $147 = $146&1;
    if ($147) {
     label = 6;
     break L4;
    }
    $148 = HEAP32[$143>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($V_0$0|0));
    $149 = __THREW__; __THREW__ = 0;
    $150 = $149&1;
    if ($150) {
     label = 6;
     break L4;
    }
    __THREW__ = 0;
    invoke_viii(2110,(1723192|0),($V_0$0|0),($148|0));
    $151 = __THREW__; __THREW__ = 0;
    $152 = $151&1;
    if ($152) {
     label = 6;
     break L4;
    }
   }
   $153 = (($V_2$0) + 1)|0;
   $V_0$1 = $V_0$0;$V_2$0 = $153;
  }
  __THREW__ = 0;
  invoke_vi(3799,($$0113|0));
  $160 = __THREW__; __THREW__ = 0;
  $161 = $160&1;
  if ($161) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  $162 = (invoke_iii(2730,(2235944|0),($$0113|0))|0);
  $163 = __THREW__; __THREW__ = 0;
  $164 = $163&1;
  if ($164) {
   label = 7;
   break;
  }
  $165 = ($162|0)==(0|0);
  if ($165) {
   $V_0$2$lcssa = $V_0$1;
   label = 71;
   break;
  } else {
   $$0113 = $162;$V_0$212 = $V_0$1;
  }
 }
 do {
  if ((label|0) == 6) {
   $11 = ___cxa_find_matching_catch()|0;
   $12 = tempRet0;
   $lpad$phi$index = $11;$lpad$phi$index3 = $12;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  else if ((label|0) == 7) {
   $13 = ___cxa_find_matching_catch()|0;
   $14 = tempRet0;
   $lpad$phi$index = $13;$lpad$phi$index3 = $14;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($lpad$phi$index|0);
   // unreachable;
  }
  else if ((label|0) == 22) {
   __THREW__ = 0;
   (invoke_ii(2996,(1169184|0))|0);
   $49 = __THREW__; __THREW__ = 0;
   $50 = $49&1;
   if (!($50)) {
    __THREW__ = 0;
    $51 = (invoke_iii(2773,(1169184|0),3)|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if (!($53)) {
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $54 = __THREW__; __THREW__ = 0;
     $55 = $54&1;
     if (!($55)) {
      $56 = (($32) + 8|0);
      $57 = HEAP32[$56>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($51|0));
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if (!($59)) {
       $60 = (($51) + 12|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = ($61|0)==(0);
       if ($62) {
        __THREW__ = 0;
        $63 = (invoke_i(132)|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($63|0));
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($51|0),($57|0));
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if (!($69)) {
        $70 = (($51) + 16|0);
        HEAP32[$70>>2] = $57;
        __THREW__ = 0;
        invoke_vi(3799,($32|0));
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if (!($72)) {
         $73 = (($32) + 12|0);
         $74 = HEAP32[$73>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($51|0));
         $75 = __THREW__; __THREW__ = 0;
         $76 = $75&1;
         if (!($76)) {
          $77 = HEAP32[$60>>2]|0;
          $78 = ($77>>>0)<(2);
          if ($78) {
           __THREW__ = 0;
           $79 = (invoke_i(132)|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if ($81) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($79|0));
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if ($83) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($51|0),($74|0));
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if (!($85)) {
           $86 = HEAP32[$51>>2]|0;
           $87 = (($86) + 92|0);
           $88 = HEAP32[$87>>2]|0;
           $89 = (($70) + ($88)|0);
           HEAP32[$89>>2] = $74;
           __THREW__ = 0;
           invoke_vi(3799,($32|0));
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if (!($91)) {
            $92 = (($32) + 16|0);
            $93 = HEAP32[$92>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($51|0));
            $94 = __THREW__; __THREW__ = 0;
            $95 = $94&1;
            if (!($95)) {
             $96 = HEAP32[$60>>2]|0;
             $97 = ($96>>>0)<(3);
             if ($97) {
              __THREW__ = 0;
              $98 = (invoke_i(132)|0);
              $99 = __THREW__; __THREW__ = 0;
              $100 = $99&1;
              if ($100) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($98|0));
              $101 = __THREW__; __THREW__ = 0;
              $102 = $101&1;
              if ($102) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($51|0),($93|0));
             $103 = __THREW__; __THREW__ = 0;
             $104 = $103&1;
             if (!($104)) {
              $105 = HEAP32[$51>>2]|0;
              $106 = (($105) + 92|0);
              $107 = HEAP32[$106>>2]|0;
              $108 = $107 << 1;
              $109 = (($70) + ($108)|0);
              HEAP32[$109>>2] = $93;
              $$0 = $51;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
  else if ((label|0) == 71) {
   $172 = ($V_0$2$lcssa|0)==(0|0);
   if ($172) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($V_0$2$lcssa|0));
   $173 = __THREW__; __THREW__ = 0;
   $174 = $173&1;
   if (!($174)) {
    __THREW__ = 0;
    $175 = (invoke_ii(3477,($V_0$2$lcssa|0))|0);
    $176 = __THREW__; __THREW__ = 0;
    $177 = $176&1;
    if (!($177)) {
     $$0 = $175;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo10826($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z67UnityEngine_UnityEngine_AttributeHelperEngine_m_CheckIsEditorScriptP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$klass) {
 $__this = $__this|0;
 $klass = $klass|0;
 var $$0 = 0, $$012 = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2676968);
 $2 = ($klass|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 $$012 = $klass;
 while(1) {
  HEAP32[$1>>2] = 1754840;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
  $22 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   label = 7;
   break;
  }
  $25 = ($$012|0)==($22|0);
  if ($25) {
   $$0 = 0;
   label = 14;
   break;
  }
  HEAP32[$0>>2] = 1755704;
  __THREW__ = 0;
  ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$0+0>>2]|0;
  $5 = (invoke_iii(772,(0|0),($$byval_copy1|0))|0);
  $26 = __THREW__; __THREW__ = 0;
  $27 = $26&1;
  if ($27) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($$012|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  $6 = (invoke_iiiii(322,(2242752|0),($$012|0),($5|0),0)|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($6|0));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 7;
   break;
  }
  $11 = (($6) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if (!($13)) {
   $$0 = 1;
   label = 14;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($$012|0));
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   label = 7;
   break;
  }
  __THREW__ = 0;
  $18 = (invoke_iii(2730,(2235944|0),($$012|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   label = 7;
   break;
  }
  $21 = ($18|0)==(0|0);
  if ($21) {
   $$0 = 0;
   label = 14;
   break;
  } else {
   $$012 = $18;
  }
 }
 if ((label|0) == 7) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 }
 else if ((label|0) == 14) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_SetupCoroutine_m__ctorP38UnityEngine_UnityEngine_SetupCoroutine($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2677544);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53UnityEngine_UnityEngine_SetupCoroutine_m_InvokeMemberP22mscorlib_System_ObjectS0_P22mscorlib_System_StringS0_($__this,$behaviour,$name,$variable) {
 $__this = $__this|0;
 $behaviour = $behaviour|0;
 $name = $name|0;
 $variable = $variable|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2677592);
 $0 = ($variable|0)==(0|0);
 do {
  if ($0) {
   $V_0$0 = 0;
   label = 11;
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_iii(2773,(1167664|0),1)|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      $8 = (($3) + 12|0);
      $9 = HEAP32[$8>>2]|0;
      $10 = ($9|0)==(0);
      if ($10) {
       __THREW__ = 0;
       $11 = (invoke_i(132)|0);
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if ($13) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($11|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($3|0),($variable|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = (($3) + 16|0);
       HEAP32[$20>>2] = $variable;
       $V_0$0 = $3;
       label = 11;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 11) {
  __THREW__ = 0;
  invoke_vi(3799,($behaviour|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __THREW__ = 0;
   $23 = (invoke_ii(1782,($behaviour|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    __THREW__ = 0;
    invoke_vi(3799,($23|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __THREW__ = 0;
     $28 = (invoke_iiiiiiiiiii(6,(2240992|0),($23|0),($name|0),308,(0|0),($behaviour|0),($V_0$0|0),(0|0),(0|0),(0|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($28|0);
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __Z53UnityEngine_UnityEngine_SetupCoroutine_m_InvokeStaticP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringS0_($__this,$klass,$name,$variable) {
 $__this = $__this|0;
 $klass = $klass|0;
 $name = $name|0;
 $variable = $variable|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2677640);
 $0 = ($variable|0)==(0|0);
 do {
  if ($0) {
   $V_0$0 = 0;
   label = 11;
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_iii(2773,(1167664|0),1)|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(3799,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      $8 = (($3) + 12|0);
      $9 = HEAP32[$8>>2]|0;
      $10 = ($9|0)==(0);
      if ($10) {
       __THREW__ = 0;
       $11 = (invoke_i(132)|0);
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if ($13) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($11|0));
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($3|0),($variable|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = (($3) + 16|0);
       HEAP32[$20>>2] = $variable;
       $V_0$0 = $3;
       label = 11;
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 11) {
  __THREW__ = 0;
  invoke_vi(3799,($klass|0));
  $21 = __THREW__; __THREW__ = 0;
  $22 = $21&1;
  if (!($22)) {
   __THREW__ = 0;
   $23 = (invoke_iiiiiiiiiii(6,(2240992|0),($klass|0),($name|0),312,(0|0),(0|0),($V_0$0|0),(0|0),(0|0),(0|0))|0);
   $24 = __THREW__; __THREW__ = 0;
   $25 = $24&1;
   if (!($25)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($23|0);
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker3I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsS0_E6InvokeEPFP22mscorlib_System_ObjectPvS4_S5_S4_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker3I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_S0_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S5_S4_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$0,$2,$4)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z49UnityEngine_UnityEngine_WritableAttribute_m__ctorP41UnityEngine_UnityEngine_WritableAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2677992);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z72UnityEngine_UnityEngine_WritableAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,2048);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z56UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m__ctorP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2678264);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z79UnityEngine_UnityEngine_AssemblyIsEditorAssembly_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z51UnityEngine_UnityEngine_GUI_ScrollViewState_m__ctorP43UnityEngine_UnityEngine_GUI_ScrollViewState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2678840);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_GUI_WindowFunction_m__ctorP42UnityEngine_UnityEngine_GUI_WindowFunctionP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2679336);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z51UnityEngine_UnityEngine_GUI_WindowFunction_m_InvokeP42UnityEngine_UnityEngine_GUI_WindowFunctioni($__this,$id) {
 $__this = $__this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2679384);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vii(1984,($1|0),($id|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($10|0),($id|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z56UnityEngine_UnityEngine_GUI_WindowFunction_m_BeginInvokeP42UnityEngine_UnityEngine_GUI_WindowFunctioniP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$id,$callback,$object) {
 $__this = $__this|0;
 $id = $id|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2679432);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z54UnityEngine_UnityEngine_GUI_WindowFunction_m_EndInvokeP42UnityEngine_UnityEngine_GUI_WindowFunctionP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2679480);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_iS4_P22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$func & 511]($obj,$1,$3,$5)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z36UnityEngine_UnityEngine_GUI_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $L_9 = 0;
 var $L_9$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $L_9$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 32|0;
 $L_9 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2679928);
 __THREW__ = 0;
 invoke_v(947);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2681320|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP32[((2681320 + 80|0))>>2]|0;
    HEAPF32[$4>>2] = Math_fround(10.0);
    $5 = HEAP32[2995184>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = HEAP32[2995184>>2]|0;
     __THREW__ = 0;
     $9 = (invoke_iii(2729,(2185544|0),($8|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2681320|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       $14 = HEAP32[((2681320 + 80|0))>>2]|0;
       $15 = (($14) + 28|0);
       HEAP32[$15>>2] = $9;
       $16 = HEAP32[2995192>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($16|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        $19 = HEAP32[2995192>>2]|0;
        __THREW__ = 0;
        $20 = (invoke_iii(2729,(2185544|0),($19|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         (invoke_ii(2996,(2681320|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          $25 = HEAP32[((2681320 + 80|0))>>2]|0;
          $26 = (($25) + 32|0);
          HEAP32[$26>>2] = $20;
          $27 = HEAP32[2995200>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($27|0));
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if (!($29)) {
           $30 = HEAP32[2995200>>2]|0;
           __THREW__ = 0;
           $31 = (invoke_iii(2729,(2185544|0),($30|0))|0);
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2681320|0))|0);
            $34 = __THREW__; __THREW__ = 0;
            $35 = $34&1;
            if (!($35)) {
             $36 = HEAP32[((2681320 + 80|0))>>2]|0;
             $37 = (($36) + 36|0);
             HEAP32[$37>>2] = $31;
             $38 = HEAP32[2995208>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($38|0));
             $39 = __THREW__; __THREW__ = 0;
             $40 = $39&1;
             if (!($40)) {
              $41 = HEAP32[2995208>>2]|0;
              __THREW__ = 0;
              $42 = (invoke_iii(2729,(2185544|0),($41|0))|0);
              $43 = __THREW__; __THREW__ = 0;
              $44 = $43&1;
              if (!($44)) {
               __THREW__ = 0;
               (invoke_ii(2996,(2681320|0))|0);
               $45 = __THREW__; __THREW__ = 0;
               $46 = $45&1;
               if (!($46)) {
                $47 = HEAP32[((2681320 + 80|0))>>2]|0;
                $48 = (($47) + 40|0);
                HEAP32[$48>>2] = $42;
                $49 = HEAP32[2995216>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($49|0));
                $50 = __THREW__; __THREW__ = 0;
                $51 = $50&1;
                if (!($51)) {
                 $52 = HEAP32[2995216>>2]|0;
                 __THREW__ = 0;
                 $53 = (invoke_iii(2729,(2185544|0),($52|0))|0);
                 $54 = __THREW__; __THREW__ = 0;
                 $55 = $54&1;
                 if (!($55)) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2681320|0))|0);
                  $56 = __THREW__; __THREW__ = 0;
                  $57 = $56&1;
                  if (!($57)) {
                   $58 = HEAP32[((2681320 + 80|0))>>2]|0;
                   $59 = (($58) + 44|0);
                   HEAP32[$59>>2] = $53;
                   $60 = HEAP32[2995224>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($60|0));
                   $61 = __THREW__; __THREW__ = 0;
                   $62 = $61&1;
                   if (!($62)) {
                    $63 = HEAP32[2995224>>2]|0;
                    __THREW__ = 0;
                    $64 = (invoke_iii(2729,(2185544|0),($63|0))|0);
                    $65 = __THREW__; __THREW__ = 0;
                    $66 = $65&1;
                    if (!($66)) {
                     __THREW__ = 0;
                     (invoke_ii(2996,(2681320|0))|0);
                     $67 = __THREW__; __THREW__ = 0;
                     $68 = $67&1;
                     if ($68) {
                      break;
                     }
                     $69 = HEAP32[((2681320 + 80|0))>>2]|0;
                     $70 = (($69) + 48|0);
                     HEAP32[$70>>2] = $64;
                     $71 = HEAP32[2995232>>2]|0;
                     __THREW__ = 0;
                     invoke_vi(3799,($71|0));
                     $72 = __THREW__; __THREW__ = 0;
                     $73 = $72&1;
                     if ($73) {
                      break;
                     }
                     $74 = HEAP32[2995232>>2]|0;
                     __THREW__ = 0;
                     $75 = (invoke_iii(2729,(2185544|0),($74|0))|0);
                     $76 = __THREW__; __THREW__ = 0;
                     $77 = $76&1;
                     if ($77) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2681320|0))|0);
                     $78 = __THREW__; __THREW__ = 0;
                     $79 = $78&1;
                     if ($79) {
                      break;
                     }
                     $80 = HEAP32[((2681320 + 80|0))>>2]|0;
                     $81 = (($80) + 52|0);
                     HEAP32[$81>>2] = $75;
                     __THREW__ = 0;
                     (invoke_ii(2996,(2710208|0))|0);
                     $82 = __THREW__; __THREW__ = 0;
                     $83 = $82&1;
                     if ($83) {
                      break;
                     }
                     __THREW__ = 0;
                     $84 = (invoke_ii(3469,(2710208|0))|0);
                     $85 = __THREW__; __THREW__ = 0;
                     $86 = $85&1;
                     if ($86) {
                      break;
                     }
                     __THREW__ = 0;
                     invoke_vi(2888,($84|0));
                     $87 = __THREW__; __THREW__ = 0;
                     $88 = $87&1;
                     if ($88) {
                      break;
                     }
                     __THREW__ = 0;
                     (invoke_ii(2996,(2681320|0))|0);
                     $89 = __THREW__; __THREW__ = 0;
                     $90 = $89&1;
                     if ($90) {
                      break;
                     }
                     $91 = HEAP32[((2681320 + 80|0))>>2]|0;
                     $92 = (($91) + 56|0);
                     HEAP32[$92>>2] = $84;
                     __THREW__ = 0;
                     invoke_vii(1930,($L_9|0),(0|0));
                     $93 = __THREW__; __THREW__ = 0;
                     $94 = $93&1;
                     if ($94) {
                      break;
                     }
                     __THREW__ = 0;
                     ;HEAP32[$L_9$byval_copy+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$L_9$byval_copy+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$L_9$byval_copy+8>>2]=HEAP32[$L_9+8>>2]|0;HEAP32[$L_9$byval_copy+12>>2]=HEAP32[$L_9+12>>2]|0;
                     invoke_vii(1986,0,($L_9$byval_copy|0));
                     $95 = __THREW__; __THREW__ = 0;
                     $96 = $95&1;
                     if ($96) {
                      break;
                     }
                     __ZN16StackTraceSentryD2Ev(0);
                     STACKTOP = sp;return;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $97 = ___cxa_find_matching_catch()|0;
 $98 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($97|0);
 // unreachable;
}
function __Z52UnityEngine_UnityEngineInternal_GenericStack_m__ctorP44UnityEngine_UnityEngineInternal_GenericStack($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2710048);
 __THREW__ = 0;
 invoke_vi(2188,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52UnityEngine_UnityEngine_GUI_m_set_nextScrollStepTimeP22mscorlib_System_Object24mscorlib_System_DateTime($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2679976);
 __THREW__ = 0;
 (invoke_ii(2996,(2681320|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2681320 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2681320|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2681320|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2681320|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2681320|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2681320 + 80|0))>>2]|0;
    $15 = (($14) + 64|0);
    ;HEAP32[$15+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$15+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$15+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$15+12>>2]=HEAP32[$value+12>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL11RuntimeInitP8TypeInfo10827($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z38UnityEngine_UnityEngine_GUI_m_set_skinP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_GUISkin($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2680024);
 __THREW__ = 0;
 invoke_vi(2940,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(1194,0,($value|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if ($2) {
     $$0 = $value;
    } else {
     __THREW__ = 0;
     $7 = (invoke_ii(2555,0)|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     } else {
      $$0 = $7;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2681320|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP8[((2681320 + 116|0))>>0]|0;
     $13 = ($12<<24>>24)==(0);
     if ($13) {
      __THREW__ = 0;
      (invoke_ii(2996,(2681320|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2681320|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2681320|0));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2681320|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP32[((2681320 + 80|0))>>2]|0;
      $23 = (($22) + 8|0);
      HEAP32[$23>>2] = $$0;
      __THREW__ = 0;
      invoke_vi(3799,($$0|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       invoke_vi(2955,($$0|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z47UnityEngine_UnityEngine_GUIUtility_m_CheckOnGUIP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2734104);
 __THREW__ = 0;
 invoke_v(948);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(2556,0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>(0);
   if ($5) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560072|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2560072|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[2998232>>2]|0;
     __THREW__ = 0;
     invoke_vii(1924,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3844,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z99UnityEngine_UnityEngine_Object_m_op_Implicit_mscorlib_System_Boolean_UnityEngine_UnityEngine_ObjectP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Object($__this,$exists) {
 $__this = $__this|0;
 $exists = $exists|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701728);
 __THREW__ = 0;
 $0 = (invoke_iiii(1317,0,($exists|0),(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = $0 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z51UnityEngine_UnityEngine_GUIUtility_m_GetDefaultSkinP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2733736);
 __THREW__ = 0;
 (invoke_ii(2996,(2734792|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2734792 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2734792|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2734792|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2734792|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2734792|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2734792 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    $16 = (invoke_iii(1207,0,($15|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($16|0);
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_GUISkin_m_MakeCurrentP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738536);
 __THREW__ = 0;
 (invoke_ii(2996,(2742232|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2742232 + 80|0))>>2]|0;
  $3 = (($2) + 8|0);
  HEAP32[$3>>2] = $__this;
  __THREW__ = 0;
  $4 = (invoke_ii(2557,($__this|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   invoke_vii(2064,0,($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2742232|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = HEAP32[((2742232 + 80|0))>>2]|0;
     $12 = (($11) + 4|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = ($13|0)==(0|0);
     if ($14) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2742232|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $19 = HEAP32[((2742232 + 80|0))>>2]|0;
      $20 = (($19) + 4|0);
      $21 = HEAP32[$20>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($21|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vii(3495,(2735560|0),($21|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z38UnityEngine_UnityEngine_GUI_m_get_skinP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2680072);
 __THREW__ = 0;
 invoke_vi(2940,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2681320|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2681320 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2681320|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2681320|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3843,(2681320|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2681320|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2681320 + 80|0))>>2]|0;
     $17 = (($16) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($18|0);
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z41UnityEngine_UnityEngine_GUI_m_set_changedP22mscorlib_System_Objectb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2680120);
 $0 = HEAP32[2680168>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2680176|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2680168>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_GUI_m_CallWindowDelegateP22mscorlib_System_ObjectP42UnityEngine_UnityEngine_GUI_WindowFunctioniP31UnityEngine_UnityEngine_GUISkiniffP32UnityEngine_UnityEngine_GUIStyle($__this,$func,$id,$_skin,$forceRect,$width,$height,$style) {
 $__this = $__this|0;
 $func = $func|0;
 $id = $id|0;
 $_skin = $_skin|0;
 $forceRect = $forceRect|0;
 $width = Math_fround($width);
 $height = Math_fround($height);
 $style = $style|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2680224);
 __THREW__ = 0;
 (invoke_iiii(1333,0,($id|0),1)|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(2509,0)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    $5 = (invoke_ii(2603,0)|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vi(3799,($5|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_ii(2598,($5|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       $13 = ($10|0)==(8);
       do {
        if ($13) {
         $16 = ($forceRect|0)==(0);
         if ($16) {
          __THREW__ = 0;
          invoke_viiii(215,0,($id|0),($style|0),(0|0));
          $58 = __THREW__; __THREW__ = 0;
          $59 = $58&1;
          if ($59) {
           break L1;
          } else {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(1182032|0))|0);
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if ($18) {
          break L1;
         }
         __THREW__ = 0;
         $19 = (invoke_iii(2773,(1182032|0),2)|0);
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          break L1;
         }
         __THREW__ = 0;
         $22 = (invoke_iif(22,0,(+$width))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if ($24) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($19|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if ($26) {
          break L1;
         }
         $27 = (($19) + 12|0);
         $28 = HEAP32[$27>>2]|0;
         $29 = ($28|0)==(0);
         if ($29) {
          __THREW__ = 0;
          $30 = (invoke_i(132)|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if ($32) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($30|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($19|0),($22|0));
         $35 = __THREW__; __THREW__ = 0;
         $36 = $35&1;
         if ($36) {
          break L1;
         }
         $37 = (($19) + 16|0);
         HEAP32[$37>>2] = $22;
         __THREW__ = 0;
         $38 = (invoke_iif(23,0,(+$height))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3799,($19|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break L1;
         }
         $43 = HEAP32[$27>>2]|0;
         $44 = ($43>>>0)<(2);
         if ($44) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break L1;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($19|0),($38|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if ($51) {
          break L1;
         }
         $52 = HEAP32[$19>>2]|0;
         $53 = (($52) + 92|0);
         $54 = HEAP32[$53>>2]|0;
         $55 = (($37) + ($54)|0);
         HEAP32[$55>>2] = $38;
         __THREW__ = 0;
         invoke_viiii(215,0,($id|0),($style|0),($19|0));
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          break L1;
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vii(1987,0,($_skin|0));
       $60 = __THREW__; __THREW__ = 0;
       $61 = $60&1;
       if (!($61)) {
        __THREW__ = 0;
        invoke_vi(3799,($func|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if (!($63)) {
         __THREW__ = 0;
         invoke_viii(2111,(2679384|0),($func|0),($id|0));
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if (!($65)) {
          __THREW__ = 0;
          $66 = (invoke_ii(2603,0)|0);
          $67 = __THREW__; __THREW__ = 0;
          $68 = $67&1;
          if (!($68)) {
           __THREW__ = 0;
           invoke_vi(3799,($66|0));
           $69 = __THREW__; __THREW__ = 0;
           $70 = $69&1;
           if (!($70)) {
            __THREW__ = 0;
            $71 = (invoke_ii(2598,($66|0))|0);
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if (!($73)) {
             $74 = ($71|0)==(8);
             if ($74) {
              __THREW__ = 0;
              invoke_vi(2924,0);
              $75 = __THREW__; __THREW__ = 0;
              $76 = $75&1;
              if ($76) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(1987,0,($2|0));
             $77 = __THREW__; __THREW__ = 0;
             $78 = $77&1;
             if (!($78)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z55UnityEngine_UnityEngine_GUILayoutUtility_m_SelectIDListP22mscorlib_System_Objectib($__this,$instanceID,$isWindow) {
 $__this = $__this|0;
 $instanceID = $instanceID|0;
 $isWindow = $isWindow|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B3_0$0 = 0;
 var $G_B3_0$0$in$in = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726608);
 HEAP32[$V_1>>2] = 0;
 do {
  if ($isWindow) {
   __THREW__ = 0;
   (invoke_ii(2996,(2728312|0))|0);
   $0 = __THREW__; __THREW__ = 0;
   $1 = $0&1;
   if (!($1)) {
    $2 = HEAP8[((2728312 + 116|0))>>0]|0;
    $3 = ($2<<24>>24)==(0);
    if ($3) {
     __THREW__ = 0;
     (invoke_ii(2996,(2728312|0))|0);
     $4 = __THREW__; __THREW__ = 0;
     $5 = $4&1;
     if ($5) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2728312|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3843,(2728312|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[((2728312 + 80|0))>>2]|0;
     $15 = (($14) + 4|0);
     $G_B3_0$0$in$in = $15;
     label = 17;
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2728312|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP8[((2728312 + 116|0))>>0]|0;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     __THREW__ = 0;
     (invoke_ii(2996,(2728312|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2728312|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3843,(2728312|0));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if ($25) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = HEAP32[((2728312 + 80|0))>>2]|0;
     $G_B3_0$0$in$in = $28;
     label = 17;
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 17) {
   $G_B3_0$0 = HEAP32[$G_B3_0$0$in$in>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($G_B3_0$0|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if (!($30)) {
    __THREW__ = 0;
    $31 = (invoke_iiiii(310,(1885392|0),($G_B3_0$0|0),($instanceID|0),($V_1|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     if (!($31)) {
      __THREW__ = 0;
      (invoke_ii(2996,(2726424|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_ii(3469,(2726424|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(2922,($36|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
      HEAP32[$V_1>>2] = $36;
      __THREW__ = 0;
      invoke_vi(3799,($G_B3_0$0|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       break;
      }
      $43 = HEAP32[$V_1>>2]|0;
      __THREW__ = 0;
      invoke_viiii(459,(1884864|0),($G_B3_0$0|0),($instanceID|0),($43|0));
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2728312|0))|0);
     $46 = __THREW__; __THREW__ = 0;
     $47 = $46&1;
     if (!($47)) {
      $48 = HEAP8[((2728312 + 116|0))>>0]|0;
      $49 = ($48<<24>>24)==(0);
      if ($49) {
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2728312|0));
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2728312|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if (!($57)) {
       $58 = HEAP32[((2728312 + 80|0))>>2]|0;
       $59 = (($58) + 8|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = HEAP32[$V_1>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($61|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if (!($63)) {
        $64 = HEAP32[$V_1>>2]|0;
        $65 = (($64) + 8|0);
        $66 = HEAP32[$65>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($60|0));
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if (!($68)) {
         $69 = (($60) + 8|0);
         HEAP32[$69>>2] = $66;
         __THREW__ = 0;
         (invoke_ii(2996,(2728312|0))|0);
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if (!($71)) {
          $72 = HEAP8[((2728312 + 116|0))>>0]|0;
          $73 = ($72<<24>>24)==(0);
          if ($73) {
           __THREW__ = 0;
           (invoke_ii(2996,(2728312|0))|0);
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if ($75) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2728312|0))|0);
           $76 = __THREW__; __THREW__ = 0;
           $77 = $76&1;
           if ($77) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3843,(2728312|0));
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if ($79) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2728312|0))|0);
          $80 = __THREW__; __THREW__ = 0;
          $81 = $80&1;
          if (!($81)) {
           $82 = HEAP32[((2728312 + 80|0))>>2]|0;
           $83 = (($82) + 8|0);
           $84 = HEAP32[$83>>2]|0;
           $85 = HEAP32[$V_1>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($85|0));
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if (!($87)) {
            $88 = HEAP32[$V_1>>2]|0;
            $89 = (($88) + 12|0);
            $90 = HEAP32[$89>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($84|0));
            $91 = __THREW__; __THREW__ = 0;
            $92 = $91&1;
            if (!($92)) {
             $93 = (($84) + 12|0);
             HEAP32[$93>>2] = $90;
             __THREW__ = 0;
             (invoke_ii(2996,(2728312|0))|0);
             $94 = __THREW__; __THREW__ = 0;
             $95 = $94&1;
             if (!($95)) {
              $96 = HEAP8[((2728312 + 116|0))>>0]|0;
              $97 = ($96<<24>>24)==(0);
              if ($97) {
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $98 = __THREW__; __THREW__ = 0;
               $99 = $98&1;
               if ($99) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $100 = __THREW__; __THREW__ = 0;
               $101 = $100&1;
               if ($101) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3843,(2728312|0));
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               if ($103) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2728312|0))|0);
              $104 = __THREW__; __THREW__ = 0;
              $105 = $104&1;
              if (!($105)) {
               $106 = HEAP32[((2728312 + 80|0))>>2]|0;
               $107 = (($106) + 8|0);
               $108 = HEAP32[$107>>2]|0;
               $109 = HEAP32[$V_1>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($109|0));
               $110 = __THREW__; __THREW__ = 0;
               $111 = $110&1;
               if (!($111)) {
                $112 = HEAP32[$V_1>>2]|0;
                $113 = (($112) + 16|0);
                $114 = HEAP32[$113>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($108|0));
                $115 = __THREW__; __THREW__ = 0;
                $116 = $115&1;
                if (!($116)) {
                 $117 = (($108) + 16|0);
                 HEAP32[$117>>2] = $114;
                 $118 = HEAP32[$V_1>>2]|0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($118|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Event_m_get_currentP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2751008);
 __THREW__ = 0;
 (invoke_ii(2996,(2752240|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = HEAP32[((2752240 + 80|0))>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z40UnityEngine_UnityEngine_Event_m_get_typeP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750360);
 $0 = HEAP32[2750408>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2750416|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2750408>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z41UnityEngine_UnityEngine_GUILayout_m_WidthP22mscorlib_System_Objectf($__this,$width) {
 $__this = $__this|0;
 $width = Math_fround($width);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2681456);
 HEAPF32[$L_1>>2] = $width;
 __THREW__ = 0;
 (invoke_ii(2996,(2194912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2194912|0),($L_1|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2733552|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2733552|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_viii(734,($7|0),0,($2|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($7|0);
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z42UnityEngine_UnityEngine_GUILayout_m_HeightP22mscorlib_System_Objectf($__this,$height) {
 $__this = $__this|0;
 $height = Math_fround($height);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2681504);
 HEAPF32[$L_1>>2] = $height;
 __THREW__ = 0;
 (invoke_ii(2996,(2194912|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2194912|0),($L_1|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2733552|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2733552|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_viii(734,($7|0),1,($2|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($7|0);
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z54UnityEngine_UnityEngine_GUILayoutUtility_m_BeginWindowP22mscorlib_System_ObjectiP32UnityEngine_UnityEngine_GUIStyleP43UnityEngine_UnityEngine_GUILayoutOption_arr($__this,$windowID,$style,$options) {
 $__this = $__this|0;
 $windowID = $windowID|0;
 $style = $style|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726704);
 __THREW__ = 0;
 $0 = (invoke_iiii(1333,0,($windowID|0),1)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2603,0)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(2598,($3|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = ($8|0)==(8);
      if (!($11)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $204 = __THREW__; __THREW__ = 0;
       $205 = $204&1;
       if ($205) {
        break;
       }
       $206 = HEAP8[((2728312 + 116|0))>>0]|0;
       $207 = ($206<<24>>24)==(0);
       if ($207) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $208 = __THREW__; __THREW__ = 0;
        $209 = $208&1;
        if ($209) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $210 = __THREW__; __THREW__ = 0;
        $211 = $210&1;
        if ($211) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $212 = __THREW__; __THREW__ = 0;
        $213 = $212&1;
        if ($213) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $214 = __THREW__; __THREW__ = 0;
       $215 = $214&1;
       if ($215) {
        break;
       }
       $216 = HEAP32[((2728312 + 80|0))>>2]|0;
       $217 = (($216) + 8|0);
       $218 = HEAP32[$217>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $219 = __THREW__; __THREW__ = 0;
       $220 = $219&1;
       if ($220) {
        break;
       }
       $221 = (($0) + 8|0);
       $222 = HEAP32[$221>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($218|0));
       $223 = __THREW__; __THREW__ = 0;
       $224 = $223&1;
       if ($224) {
        break;
       }
       $225 = (($218) + 8|0);
       HEAP32[$225>>2] = $222;
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $226 = __THREW__; __THREW__ = 0;
       $227 = $226&1;
       if ($227) {
        break;
       }
       $228 = HEAP8[((2728312 + 116|0))>>0]|0;
       $229 = ($228<<24>>24)==(0);
       if ($229) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $230 = __THREW__; __THREW__ = 0;
        $231 = $230&1;
        if ($231) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $232 = __THREW__; __THREW__ = 0;
        $233 = $232&1;
        if ($233) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $234 = __THREW__; __THREW__ = 0;
        $235 = $234&1;
        if ($235) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $236 = __THREW__; __THREW__ = 0;
       $237 = $236&1;
       if ($237) {
        break;
       }
       $238 = HEAP32[((2728312 + 80|0))>>2]|0;
       $239 = (($238) + 8|0);
       $240 = HEAP32[$239>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $241 = __THREW__; __THREW__ = 0;
       $242 = $241&1;
       if ($242) {
        break;
       }
       $243 = (($0) + 12|0);
       $244 = HEAP32[$243>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($240|0));
       $245 = __THREW__; __THREW__ = 0;
       $246 = $245&1;
       if ($246) {
        break;
       }
       $247 = (($240) + 12|0);
       HEAP32[$247>>2] = $244;
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $248 = __THREW__; __THREW__ = 0;
       $249 = $248&1;
       if ($249) {
        break;
       }
       $250 = HEAP8[((2728312 + 116|0))>>0]|0;
       $251 = ($250<<24>>24)==(0);
       if ($251) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $252 = __THREW__; __THREW__ = 0;
        $253 = $252&1;
        if ($253) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $254 = __THREW__; __THREW__ = 0;
        $255 = $254&1;
        if ($255) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $256 = __THREW__; __THREW__ = 0;
        $257 = $256&1;
        if ($257) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $258 = __THREW__; __THREW__ = 0;
       $259 = $258&1;
       if ($259) {
        break;
       }
       $260 = HEAP32[((2728312 + 80|0))>>2]|0;
       $261 = (($260) + 8|0);
       $262 = HEAP32[$261>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $263 = __THREW__; __THREW__ = 0;
       $264 = $263&1;
       if ($264) {
        break;
       }
       $265 = (($0) + 16|0);
       $266 = HEAP32[$265>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($262|0));
       $267 = __THREW__; __THREW__ = 0;
       $268 = $267&1;
       if ($268) {
        break;
       }
       $269 = (($262) + 16|0);
       HEAP32[$269>>2] = $266;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2728312|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = HEAP8[((2728312 + 116|0))>>0]|0;
       $17 = ($16<<24>>24)==(0);
       if ($17) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        $26 = HEAP32[((2728312 + 80|0))>>2]|0;
        $27 = (($26) + 8|0);
        $28 = HEAP32[$27>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2731232|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         __THREW__ = 0;
         $31 = (invoke_ii(3469,(2731232|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if (!($33)) {
          __THREW__ = 0;
          invoke_vi(2933,($31|0));
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __THREW__ = 0;
           invoke_vi(3799,($0|0));
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if (!($37)) {
            $38 = (($0) + 8|0);
            HEAP32[$38>>2] = $31;
            __THREW__ = 0;
            invoke_vi(3799,($28|0));
            $39 = __THREW__; __THREW__ = 0;
            $40 = $39&1;
            if (!($40)) {
             $41 = (($28) + 8|0);
             HEAP32[$41>>2] = $31;
             __THREW__ = 0;
             (invoke_ii(2996,(2728312|0))|0);
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if (!($43)) {
              $44 = HEAP8[((2728312 + 116|0))>>0]|0;
              $45 = ($44<<24>>24)==(0);
              if ($45) {
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $46 = __THREW__; __THREW__ = 0;
               $47 = $46&1;
               if ($47) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $48 = __THREW__; __THREW__ = 0;
               $49 = $48&1;
               if ($49) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3843,(2728312|0));
               $50 = __THREW__; __THREW__ = 0;
               $51 = $50&1;
               if ($51) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2728312|0))|0);
              $52 = __THREW__; __THREW__ = 0;
              $53 = $52&1;
              if (!($53)) {
               $54 = HEAP32[((2728312 + 80|0))>>2]|0;
               $55 = (($54) + 8|0);
               $56 = HEAP32[$55>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($56|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if (!($58)) {
                $59 = (($56) + 8|0);
                $60 = HEAP32[$59>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($60|0));
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if (!($62)) {
                 __THREW__ = 0;
                 invoke_vii(2026,($60|0),($style|0));
                 $63 = __THREW__; __THREW__ = 0;
                 $64 = $63&1;
                 if (!($64)) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $65 = __THREW__; __THREW__ = 0;
                  $66 = $65&1;
                  if ($66) {
                   break;
                  }
                  $67 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $68 = ($67<<24>>24)==(0);
                  if ($68) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $69 = __THREW__; __THREW__ = 0;
                   $70 = $69&1;
                   if ($70) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $71 = __THREW__; __THREW__ = 0;
                   $72 = $71&1;
                   if ($72) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $73 = __THREW__; __THREW__ = 0;
                   $74 = $73&1;
                   if ($74) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $75 = __THREW__; __THREW__ = 0;
                  $76 = $75&1;
                  if ($76) {
                   break;
                  }
                  $77 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $78 = (($77) + 8|0);
                  $79 = HEAP32[$78>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($79|0));
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break;
                  }
                  $82 = (($79) + 8|0);
                  $83 = HEAP32[$82>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($83|0));
                  $84 = __THREW__; __THREW__ = 0;
                  $85 = $84&1;
                  if ($85) {
                   break;
                  }
                  $86 = (($83) + 68|0);
                  HEAP32[$86>>2] = $windowID;
                  $87 = ($options|0)==(0|0);
                  if (!($87)) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $88 = __THREW__; __THREW__ = 0;
                   $89 = $88&1;
                   if ($89) {
                    break;
                   }
                   $90 = HEAP8[((2728312 + 116|0))>>0]|0;
                   $91 = ($90<<24>>24)==(0);
                   if ($91) {
                    __THREW__ = 0;
                    (invoke_ii(2996,(2728312|0))|0);
                    $92 = __THREW__; __THREW__ = 0;
                    $93 = $92&1;
                    if ($93) {
                     break;
                    }
                    __THREW__ = 0;
                    (invoke_ii(2996,(2728312|0))|0);
                    $94 = __THREW__; __THREW__ = 0;
                    $95 = $94&1;
                    if ($95) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3843,(2728312|0));
                    $96 = __THREW__; __THREW__ = 0;
                    $97 = $96&1;
                    if ($97) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $98 = __THREW__; __THREW__ = 0;
                   $99 = $98&1;
                   if ($99) {
                    break;
                   }
                   $100 = HEAP32[((2728312 + 80|0))>>2]|0;
                   $101 = (($100) + 8|0);
                   $102 = HEAP32[$101>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($102|0));
                   $103 = __THREW__; __THREW__ = 0;
                   $104 = $103&1;
                   if ($104) {
                    break;
                   }
                   $105 = (($102) + 8|0);
                   $106 = HEAP32[$105>>2]|0;
                   __THREW__ = 0;
                   invoke_vi(3799,($106|0));
                   $107 = __THREW__; __THREW__ = 0;
                   $108 = $107&1;
                   if ($108) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viii(2110,(2726752|0),($106|0),($options|0));
                   $109 = __THREW__; __THREW__ = 0;
                   $110 = $109&1;
                   if ($110) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $111 = __THREW__; __THREW__ = 0;
                  $112 = $111&1;
                  if ($112) {
                   break;
                  }
                  $113 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $114 = ($113<<24>>24)==(0);
                  if ($114) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $115 = __THREW__; __THREW__ = 0;
                   $116 = $115&1;
                   if ($116) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $117 = __THREW__; __THREW__ = 0;
                   $118 = $117&1;
                   if ($118) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $119 = __THREW__; __THREW__ = 0;
                   $120 = $119&1;
                   if ($120) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $121 = __THREW__; __THREW__ = 0;
                  $122 = $121&1;
                  if ($122) {
                   break;
                  }
                  $123 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $124 = (($123) + 8|0);
                  $125 = HEAP32[$124>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($125|0));
                  $126 = __THREW__; __THREW__ = 0;
                  $127 = $126&1;
                  if ($127) {
                   break;
                  }
                  $128 = (($125) + 12|0);
                  $129 = HEAP32[$128>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($129|0));
                  $130 = __THREW__; __THREW__ = 0;
                  $131 = $130&1;
                  if ($131) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(3495,(2315400|0),($129|0));
                  $132 = __THREW__; __THREW__ = 0;
                  $133 = $132&1;
                  if ($133) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $134 = __THREW__; __THREW__ = 0;
                  $135 = $134&1;
                  if ($135) {
                   break;
                  }
                  $136 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $137 = ($136<<24>>24)==(0);
                  if ($137) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $138 = __THREW__; __THREW__ = 0;
                   $139 = $138&1;
                   if ($139) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $140 = __THREW__; __THREW__ = 0;
                   $141 = $140&1;
                   if ($141) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $142 = __THREW__; __THREW__ = 0;
                   $143 = $142&1;
                   if ($143) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $144 = __THREW__; __THREW__ = 0;
                  $145 = $144&1;
                  if ($145) {
                   break;
                  }
                  $146 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $147 = (($146) + 8|0);
                  $148 = HEAP32[$147>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($148|0));
                  $149 = __THREW__; __THREW__ = 0;
                  $150 = $149&1;
                  if ($150) {
                   break;
                  }
                  $151 = (($148) + 12|0);
                  $152 = HEAP32[$151>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $153 = __THREW__; __THREW__ = 0;
                  $154 = $153&1;
                  if ($154) {
                   break;
                  }
                  $155 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $156 = ($155<<24>>24)==(0);
                  if ($156) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $157 = __THREW__; __THREW__ = 0;
                   $158 = $157&1;
                   if ($158) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $159 = __THREW__; __THREW__ = 0;
                   $160 = $159&1;
                   if ($160) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $161 = __THREW__; __THREW__ = 0;
                   $162 = $161&1;
                   if ($162) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $163 = __THREW__; __THREW__ = 0;
                  $164 = $163&1;
                  if ($164) {
                   break;
                  }
                  $165 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $166 = (($165) + 8|0);
                  $167 = HEAP32[$166>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($167|0));
                  $168 = __THREW__; __THREW__ = 0;
                  $169 = $168&1;
                  if ($169) {
                   break;
                  }
                  $170 = (($167) + 8|0);
                  $171 = HEAP32[$170>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($152|0));
                  $172 = __THREW__; __THREW__ = 0;
                  $173 = $172&1;
                  if ($173) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(2113,(2315496|0),($152|0),($171|0));
                  $174 = __THREW__; __THREW__ = 0;
                  $175 = $174&1;
                  if ($175) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $176 = __THREW__; __THREW__ = 0;
                  $177 = $176&1;
                  if ($177) {
                   break;
                  }
                  $178 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $179 = ($178<<24>>24)==(0);
                  if ($179) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $180 = __THREW__; __THREW__ = 0;
                   $181 = $180&1;
                   if ($181) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $182 = __THREW__; __THREW__ = 0;
                   $183 = $182&1;
                   if ($183) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $184 = __THREW__; __THREW__ = 0;
                   $185 = $184&1;
                   if ($185) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $186 = __THREW__; __THREW__ = 0;
                  $187 = $186&1;
                  if ($187) {
                   break;
                  }
                  $188 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $189 = (($188) + 8|0);
                  $190 = HEAP32[$189>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2731232|0))|0);
                  $191 = __THREW__; __THREW__ = 0;
                  $192 = $191&1;
                  if ($192) {
                   break;
                  }
                  __THREW__ = 0;
                  $193 = (invoke_ii(3469,(2731232|0))|0);
                  $194 = __THREW__; __THREW__ = 0;
                  $195 = $194&1;
                  if ($195) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(2933,($193|0));
                  $196 = __THREW__; __THREW__ = 0;
                  $197 = $196&1;
                  if ($197) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($0|0));
                  $198 = __THREW__; __THREW__ = 0;
                  $199 = $198&1;
                  if ($199) {
                   break;
                  }
                  $200 = (($0) + 16|0);
                  HEAP32[$200>>2] = $193;
                  __THREW__ = 0;
                  invoke_vi(3799,($190|0));
                  $201 = __THREW__; __THREW__ = 0;
                  $202 = $201&1;
                  if ($202) {
                   break;
                  }
                  $203 = (($190) + 16|0);
                  HEAP32[$203>>2] = $193;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_GUILayoutUtility_m_LayoutP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = Math_fround(0), $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = Math_fround(0), $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726800);
 __THREW__ = 0;
 (invoke_ii(2996,(2728312|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2728312 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2728312|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2728312|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2728312 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($16) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = (($20) + 68|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = ($24|0)==(-1);
      if (!($25)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $199 = __THREW__; __THREW__ = 0;
       $200 = $199&1;
       if ($200) {
        break;
       }
       $201 = HEAP8[((2728312 + 116|0))>>0]|0;
       $202 = ($201<<24>>24)==(0);
       if ($202) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $203 = __THREW__; __THREW__ = 0;
        $204 = $203&1;
        if ($204) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $205 = __THREW__; __THREW__ = 0;
        $206 = $205&1;
        if ($206) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $207 = __THREW__; __THREW__ = 0;
        $208 = $207&1;
        if ($208) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $209 = __THREW__; __THREW__ = 0;
       $210 = $209&1;
       if ($210) {
        break;
       }
       $211 = HEAP32[((2728312 + 80|0))>>2]|0;
       $212 = (($211) + 8|0);
       $213 = HEAP32[$212>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($213|0));
       $214 = __THREW__; __THREW__ = 0;
       $215 = $214&1;
       if ($215) {
        break;
       }
       $216 = (($213) + 8|0);
       $217 = HEAP32[$216>>2]|0;
       __THREW__ = 0;
       invoke_vii(2025,0,($217|0));
       $218 = __THREW__; __THREW__ = 0;
       $219 = $218&1;
       if ($219) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $220 = __THREW__; __THREW__ = 0;
       $221 = $220&1;
       if ($221) {
        break;
       }
       $222 = HEAP8[((2728312 + 116|0))>>0]|0;
       $223 = ($222<<24>>24)==(0);
       if ($223) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $224 = __THREW__; __THREW__ = 0;
        $225 = $224&1;
        if ($225) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $226 = __THREW__; __THREW__ = 0;
        $227 = $226&1;
        if ($227) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $228 = __THREW__; __THREW__ = 0;
        $229 = $228&1;
        if ($229) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $230 = __THREW__; __THREW__ = 0;
       $231 = $230&1;
       if ($231) {
        break;
       }
       $232 = HEAP32[((2728312 + 80|0))>>2]|0;
       $233 = (($232) + 8|0);
       $234 = HEAP32[$233>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($234|0));
       $235 = __THREW__; __THREW__ = 0;
       $236 = $235&1;
       if ($236) {
        break;
       }
       $237 = (($234) + 16|0);
       $238 = HEAP32[$237>>2]|0;
       __THREW__ = 0;
       invoke_vii(2024,0,($238|0));
       $239 = __THREW__; __THREW__ = 0;
       $240 = $239&1;
       if ($240) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2728312|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       $28 = HEAP8[((2728312 + 116|0))>>0]|0;
       $29 = ($28<<24>>24)==(0);
       if ($29) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        $38 = HEAP32[((2728312 + 80|0))>>2]|0;
        $39 = (($38) + 8|0);
        $40 = HEAP32[$39>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($40|0));
        $41 = __THREW__; __THREW__ = 0;
        $42 = $41&1;
        if (!($42)) {
         $43 = (($40) + 8|0);
         $44 = HEAP32[$43>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($44|0));
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if (!($46)) {
          __THREW__ = 0;
          invoke_vii(3495,(2726848|0),($44|0));
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if (!($48)) {
           __THREW__ = 0;
           (invoke_ii(2996,(2728312|0))|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if (!($50)) {
            $51 = HEAP8[((2728312 + 116|0))>>0]|0;
            $52 = ($51<<24>>24)==(0);
            if ($52) {
             __THREW__ = 0;
             (invoke_ii(2996,(2728312|0))|0);
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if ($54) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2728312|0))|0);
             $55 = __THREW__; __THREW__ = 0;
             $56 = $55&1;
             if ($56) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3843,(2728312|0));
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if ($58) {
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2728312|0))|0);
            $59 = __THREW__; __THREW__ = 0;
            $60 = $59&1;
            if (!($60)) {
             $61 = HEAP32[((2728312 + 80|0))>>2]|0;
             $62 = (($61) + 8|0);
             $63 = HEAP32[$62>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($63|0));
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if (!($65)) {
              $66 = (($63) + 8|0);
              $67 = HEAP32[$66>>2]|0;
              __THREW__ = 0;
              $68 = (invoke_ii(2547,0)|0);
              $69 = __THREW__; __THREW__ = 0;
              $70 = $69&1;
              if (!($70)) {
               $71 = (Math_fround(($68|0)));
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $72 = __THREW__; __THREW__ = 0;
               $73 = $72&1;
               if (!($73)) {
                $74 = HEAP8[((2728312 + 116|0))>>0]|0;
                $75 = ($74<<24>>24)==(0);
                if ($75) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $76 = __THREW__; __THREW__ = 0;
                 $77 = $76&1;
                 if ($77) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $78 = __THREW__; __THREW__ = 0;
                 $79 = $78&1;
                 if ($79) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2728312|0));
                 $80 = __THREW__; __THREW__ = 0;
                 $81 = $80&1;
                 if ($81) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $82 = __THREW__; __THREW__ = 0;
                $83 = $82&1;
                if ($83) {
                 break;
                }
                $84 = HEAP32[((2728312 + 80|0))>>2]|0;
                $85 = (($84) + 8|0);
                $86 = HEAP32[$85>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($86|0));
                $87 = __THREW__; __THREW__ = 0;
                $88 = $87&1;
                if ($88) {
                 break;
                }
                $89 = (($86) + 8|0);
                $90 = HEAP32[$89>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($90|0));
                $91 = __THREW__; __THREW__ = 0;
                $92 = $91&1;
                if ($92) {
                 break;
                }
                $93 = (($90) + 12|0);
                $94 = Math_fround(HEAPF32[$93>>2]);
                __THREW__ = 0;
                $95 = (Math_fround(+(invoke_fiff(3,(0|0),(+$71),(+$94)))));
                $96 = __THREW__; __THREW__ = 0;
                $97 = $96&1;
                if ($97) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($67|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiff(2,(2726896|0),($67|0),0.0,(+$95));
                $100 = __THREW__; __THREW__ = 0;
                $101 = $100&1;
                if ($101) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $102 = __THREW__; __THREW__ = 0;
                $103 = $102&1;
                if ($103) {
                 break;
                }
                $104 = HEAP8[((2728312 + 116|0))>>0]|0;
                $105 = ($104<<24>>24)==(0);
                if ($105) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $106 = __THREW__; __THREW__ = 0;
                 $107 = $106&1;
                 if ($107) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $108 = __THREW__; __THREW__ = 0;
                 $109 = $108&1;
                 if ($109) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2728312|0));
                 $110 = __THREW__; __THREW__ = 0;
                 $111 = $110&1;
                 if ($111) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $112 = __THREW__; __THREW__ = 0;
                $113 = $112&1;
                if ($113) {
                 break;
                }
                $114 = HEAP32[((2728312 + 80|0))>>2]|0;
                $115 = (($114) + 8|0);
                $116 = HEAP32[$115>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($116|0));
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 break;
                }
                $119 = (($116) + 8|0);
                $120 = HEAP32[$119>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($120|0));
                $121 = __THREW__; __THREW__ = 0;
                $122 = $121&1;
                if ($122) {
                 break;
                }
                __THREW__ = 0;
                invoke_vii(3495,(2726944|0),($120|0));
                $123 = __THREW__; __THREW__ = 0;
                $124 = $123&1;
                if ($124) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $125 = __THREW__; __THREW__ = 0;
                $126 = $125&1;
                if ($126) {
                 break;
                }
                $127 = HEAP8[((2728312 + 116|0))>>0]|0;
                $128 = ($127<<24>>24)==(0);
                if ($128) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $129 = __THREW__; __THREW__ = 0;
                 $130 = $129&1;
                 if ($130) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $131 = __THREW__; __THREW__ = 0;
                 $132 = $131&1;
                 if ($132) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2728312|0));
                 $133 = __THREW__; __THREW__ = 0;
                 $134 = $133&1;
                 if ($134) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $135 = __THREW__; __THREW__ = 0;
                $136 = $135&1;
                if ($136) {
                 break;
                }
                $137 = HEAP32[((2728312 + 80|0))>>2]|0;
                $138 = (($137) + 8|0);
                $139 = HEAP32[$138>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($139|0));
                $140 = __THREW__; __THREW__ = 0;
                $141 = $140&1;
                if ($141) {
                 break;
                }
                $142 = (($139) + 8|0);
                $143 = HEAP32[$142>>2]|0;
                __THREW__ = 0;
                $144 = (invoke_ii(2548,0)|0);
                $145 = __THREW__; __THREW__ = 0;
                $146 = $145&1;
                if ($146) {
                 break;
                }
                $147 = (Math_fround(($144|0)));
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $148 = __THREW__; __THREW__ = 0;
                $149 = $148&1;
                if ($149) {
                 break;
                }
                $150 = HEAP8[((2728312 + 116|0))>>0]|0;
                $151 = ($150<<24>>24)==(0);
                if ($151) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $152 = __THREW__; __THREW__ = 0;
                 $153 = $152&1;
                 if ($153) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $154 = __THREW__; __THREW__ = 0;
                 $155 = $154&1;
                 if ($155) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2728312|0));
                 $156 = __THREW__; __THREW__ = 0;
                 $157 = $156&1;
                 if ($157) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $158 = __THREW__; __THREW__ = 0;
                $159 = $158&1;
                if ($159) {
                 break;
                }
                $160 = HEAP32[((2728312 + 80|0))>>2]|0;
                $161 = (($160) + 8|0);
                $162 = HEAP32[$161>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($162|0));
                $163 = __THREW__; __THREW__ = 0;
                $164 = $163&1;
                if ($164) {
                 break;
                }
                $165 = (($162) + 8|0);
                $166 = HEAP32[$165>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($166|0));
                $167 = __THREW__; __THREW__ = 0;
                $168 = $167&1;
                if ($168) {
                 break;
                }
                $169 = (($166) + 20|0);
                $170 = Math_fround(HEAPF32[$169>>2]);
                __THREW__ = 0;
                $171 = (Math_fround(+(invoke_fiff(3,(0|0),(+$147),(+$170)))));
                $172 = __THREW__; __THREW__ = 0;
                $173 = $172&1;
                if ($173) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($143|0));
                $174 = __THREW__; __THREW__ = 0;
                $175 = $174&1;
                if ($175) {
                 break;
                }
                __THREW__ = 0;
                invoke_viiff(2,(2726992|0),($143|0),0.0,(+$171));
                $176 = __THREW__; __THREW__ = 0;
                $177 = $176&1;
                if ($177) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $178 = __THREW__; __THREW__ = 0;
                $179 = $178&1;
                if ($179) {
                 break;
                }
                $180 = HEAP8[((2728312 + 116|0))>>0]|0;
                $181 = ($180<<24>>24)==(0);
                if ($181) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $182 = __THREW__; __THREW__ = 0;
                 $183 = $182&1;
                 if ($183) {
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2728312|0))|0);
                 $184 = __THREW__; __THREW__ = 0;
                 $185 = $184&1;
                 if ($185) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2728312|0));
                 $186 = __THREW__; __THREW__ = 0;
                 $187 = $186&1;
                 if ($187) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2728312|0))|0);
                $188 = __THREW__; __THREW__ = 0;
                $189 = $188&1;
                if ($189) {
                 break;
                }
                $190 = HEAP32[((2728312 + 80|0))>>2]|0;
                $191 = (($190) + 8|0);
                $192 = HEAP32[$191>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($192|0));
                $193 = __THREW__; __THREW__ = 0;
                $194 = $193&1;
                if ($194) {
                 break;
                }
                $195 = (($192) + 16|0);
                $196 = HEAP32[$195>>2]|0;
                __THREW__ = 0;
                invoke_vii(2024,0,($196|0));
                $197 = __THREW__; __THREW__ = 0;
                $198 = $197&1;
                if ($198) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZN14ActionInvoker7I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_28mscorlib_System_SingleTraitsS2_S0_E6InvokeEPFvPvS4_iS4_iffS4_ES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_viiiiiffi[$action & 1]($obj,$0,$3,$5,$8,$11,$14,$16);
 STACKTOP = sp;return (0|0);
}
function __Z102UnityEngine_UnityEngine_GUI_CustomAttributesCacheGenerator_U003CnextScrollStepTimeU003Ek__BackingFieldP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z100UnityEngine_UnityEngine_GUI_CustomAttributesCacheGenerator_U003CscrollTroughSideU003Ek__BackingFieldP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z111UnityEngine_UnityEngine_GUI_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUI_m_set_nextScrollStepTimeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z100UnityEngine_UnityEngine_GUI_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUI_m_set_changedP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_GUILayoutOption_m__ctorP39UnityEngine_UnityEngine_GUILayoutOptioniP22mscorlib_System_Object($__this,$type,$value) {
 $__this = $__this|0;
 $type = $type|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2733352);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $type;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = $value;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN12FuncInvoker1I17VoidPointerTraits28mscorlib_System_SingleTraitsE6InvokeEPFPvS3_fES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (FUNCTION_TABLE_iif[$func & 31]($obj,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z61UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_SendMessageP47UnityEngine_UnityEngine_SendMouseEvents_HitInfoP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2681792);
 $0 = HEAP32[$__this>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viiii(214,($0|0),($name|0),(0|0),1);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_GameObject_m_SendMessageP34UnityEngine_UnityEngine_GameObjectP22mscorlib_System_StringP22mscorlib_System_Objecti($__this,$methodName,$value,$options) {
 $__this = $__this|0;
 $methodName = $methodName|0;
 $value = $value|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2700384);
 $0 = HEAP32[2700432>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2700440|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2700432>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiii($7|0,($__this|0),($methodName|0),($value|0),($options|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z57UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_CompareP22mscorlib_System_Object47UnityEngine_UnityEngine_SendMouseEvents_HitInfoS1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2681840);
 $0 = HEAP32[$lhs>>2]|0;
 $1 = HEAP32[$rhs>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_iiii(1318,0,($0|0),($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 if (!($2)) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 $7 = (($lhs) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($rhs) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 $11 = (invoke_iiii(1318,0,($8|0),($10|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $G_B3_0$0 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 return 0|0;
}
function __Z130UnityEngine_UnityEngine_Object_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Object_UnityEngine_UnityEngine_ObjectP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701776);
 __THREW__ = 0;
 $0 = (invoke_iiii(1317,0,($x|0),($y|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z133UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_op_Implicit_mscorlib_System_Boolean_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP22mscorlib_System_Object47UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this,$exists) {
 $__this = $__this|0;
 $exists = $exists|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2681888);
 $0 = HEAP32[$exists>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_iiii(1319,0,($0|0),(0|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  if (!($1)) {
   $G_B3_0$0 = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B3_0$0|0);
  }
  $6 = (($exists) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  $8 = (invoke_iiii(1319,0,($7|0),(0|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $G_B3_0$0 = $8;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B3_0$0|0);
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
 return 0|0;
}
function __Z132UnityEngine_UnityEngine_Object_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Object_UnityEngine_UnityEngine_ObjectP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_ObjectS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701824);
 __THREW__ = 0;
 $0 = (invoke_iiii(1317,0,($x|0),($y|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = $0 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits53UnityEngine_UnityEngine_SendMouseEvents_HitInfoTraitsS1_E6InvokeEPFbPv47UnityEngine_UnityEngine_SendMouseEvents_HitInfoS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$byval_copy = sp + 24|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$args>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($args) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $25 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$tmpcast$byval_copy,$tmpcast1$byval_copy)|0);
 $26 = $25&1;
 HEAP8[$ret>>0] = $26;
 $27 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($27|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits53UnityEngine_UnityEngine_SendMouseEvents_HitInfoTraitsE6InvokeEPFbPv47UnityEngine_UnityEngine_SendMouseEvents_HitInfoES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $13 = $12&1;
 HEAP8[$ret>>0] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __Z48UnityEngine_UnityEngine_SendMouseEvents_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2682296);
 __THREW__ = 0;
 (invoke_ii(2996,(1182416|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2773,(1182416|0),3)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = (($2) + 12|0);
     $8 = HEAP32[$7>>2]|0;
     $9 = ($8|0)==(0);
     if ($9) {
      __THREW__ = 0;
      $10 = (invoke_i(132)|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      }
     }
     $17 = (($2) + 16|0);
     $18 = $17;
     $19 = $18;
     HEAP32[$19>>2] = 0;
     $20 = (($18) + 4)|0;
     $21 = $20;
     HEAP32[$21>>2] = 0;
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = HEAP32[$7>>2]|0;
      $25 = ($24>>>0)<(2);
      if ($25) {
       __THREW__ = 0;
       $26 = (invoke_i(132)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $31 = HEAP32[$2>>2]|0;
      $32 = (($31) + 92|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = (($17) + ($33)|0);
      $35 = $34;
      $36 = $35;
      HEAP32[$36>>2] = 0;
      $37 = (($35) + 4)|0;
      $38 = $37;
      HEAP32[$38>>2] = 0;
      __THREW__ = 0;
      invoke_vi(3799,($2|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       $41 = HEAP32[$7>>2]|0;
       $42 = ($41>>>0)<(3);
       if ($42) {
        __THREW__ = 0;
        $43 = (invoke_i(132)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($43|0));
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break;
        }
       }
       $48 = HEAP32[$2>>2]|0;
       $49 = (($48) + 92|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = $50 << 1;
       $52 = (($17) + ($51)|0);
       $53 = $52;
       $54 = $53;
       HEAP32[$54>>2] = 0;
       $55 = (($53) + 4)|0;
       $56 = $55;
       HEAP32[$56>>2] = 0;
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $57 = __THREW__; __THREW__ = 0;
       $58 = $57&1;
       if (!($58)) {
        $59 = HEAP32[((2682912 + 80|0))>>2]|0;
        $60 = (($59) + 12|0);
        HEAP32[$60>>2] = $2;
        __THREW__ = 0;
        (invoke_ii(2996,(1182416|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if (!($62)) {
         __THREW__ = 0;
         $63 = (invoke_iii(2773,(1182416|0),3)|0);
         $64 = __THREW__; __THREW__ = 0;
         $65 = $64&1;
         if (!($65)) {
          __THREW__ = 0;
          invoke_vi(3799,($63|0));
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if (!($67)) {
           $68 = (($63) + 12|0);
           $69 = HEAP32[$68>>2]|0;
           $70 = ($69|0)==(0);
           if ($70) {
            __THREW__ = 0;
            $71 = (invoke_i(132)|0);
            $72 = __THREW__; __THREW__ = 0;
            $73 = $72&1;
            if ($73) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($71|0));
            $74 = __THREW__; __THREW__ = 0;
            $75 = $74&1;
            if ($75) {
             break;
            }
           }
           $76 = (($63) + 16|0);
           $77 = $76;
           $78 = $77;
           HEAP32[$78>>2] = 0;
           $79 = (($77) + 4)|0;
           $80 = $79;
           HEAP32[$80>>2] = 0;
           __THREW__ = 0;
           invoke_vi(3799,($63|0));
           $81 = __THREW__; __THREW__ = 0;
           $82 = $81&1;
           if (!($82)) {
            $83 = HEAP32[$68>>2]|0;
            $84 = ($83>>>0)<(2);
            if ($84) {
             __THREW__ = 0;
             $85 = (invoke_i(132)|0);
             $86 = __THREW__; __THREW__ = 0;
             $87 = $86&1;
             if ($87) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($85|0));
             $88 = __THREW__; __THREW__ = 0;
             $89 = $88&1;
             if ($89) {
              break;
             }
            }
            $90 = HEAP32[$63>>2]|0;
            $91 = (($90) + 92|0);
            $92 = HEAP32[$91>>2]|0;
            $93 = (($76) + ($92)|0);
            $94 = $93;
            $95 = $94;
            HEAP32[$95>>2] = 0;
            $96 = (($94) + 4)|0;
            $97 = $96;
            HEAP32[$97>>2] = 0;
            __THREW__ = 0;
            invoke_vi(3799,($63|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if (!($99)) {
             $100 = HEAP32[$68>>2]|0;
             $101 = ($100>>>0)<(3);
             if ($101) {
              __THREW__ = 0;
              $102 = (invoke_i(132)|0);
              $103 = __THREW__; __THREW__ = 0;
              $104 = $103&1;
              if ($104) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($102|0));
              $105 = __THREW__; __THREW__ = 0;
              $106 = $105&1;
              if ($106) {
               break;
              }
             }
             $107 = HEAP32[$63>>2]|0;
             $108 = (($107) + 92|0);
             $109 = HEAP32[$108>>2]|0;
             $110 = $109 << 1;
             $111 = (($76) + ($110)|0);
             $112 = $111;
             $113 = $112;
             HEAP32[$113>>2] = 0;
             $114 = (($112) + 4)|0;
             $115 = $114;
             HEAP32[$115>>2] = 0;
             __THREW__ = 0;
             (invoke_ii(2996,(2682912|0))|0);
             $116 = __THREW__; __THREW__ = 0;
             $117 = $116&1;
             if (!($117)) {
              $118 = HEAP32[((2682912 + 80|0))>>2]|0;
              $119 = (($118) + 16|0);
              HEAP32[$119>>2] = $63;
              __THREW__ = 0;
              (invoke_ii(2996,(1182416|0))|0);
              $120 = __THREW__; __THREW__ = 0;
              $121 = $120&1;
              if (!($121)) {
               __THREW__ = 0;
               $122 = (invoke_iii(2773,(1182416|0),3)|0);
               $123 = __THREW__; __THREW__ = 0;
               $124 = $123&1;
               if ($124) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($122|0));
               $125 = __THREW__; __THREW__ = 0;
               $126 = $125&1;
               if ($126) {
                break;
               }
               $127 = (($122) + 12|0);
               $128 = HEAP32[$127>>2]|0;
               $129 = ($128|0)==(0);
               if ($129) {
                __THREW__ = 0;
                $130 = (invoke_i(132)|0);
                $131 = __THREW__; __THREW__ = 0;
                $132 = $131&1;
                if ($132) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($130|0));
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 break;
                }
               }
               $135 = (($122) + 16|0);
               $136 = $135;
               $137 = $136;
               HEAP32[$137>>2] = 0;
               $138 = (($136) + 4)|0;
               $139 = $138;
               HEAP32[$139>>2] = 0;
               __THREW__ = 0;
               invoke_vi(3799,($122|0));
               $140 = __THREW__; __THREW__ = 0;
               $141 = $140&1;
               if ($141) {
                break;
               }
               $142 = HEAP32[$127>>2]|0;
               $143 = ($142>>>0)<(2);
               if ($143) {
                __THREW__ = 0;
                $144 = (invoke_i(132)|0);
                $145 = __THREW__; __THREW__ = 0;
                $146 = $145&1;
                if ($146) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($144|0));
                $147 = __THREW__; __THREW__ = 0;
                $148 = $147&1;
                if ($148) {
                 break;
                }
               }
               $149 = HEAP32[$122>>2]|0;
               $150 = (($149) + 92|0);
               $151 = HEAP32[$150>>2]|0;
               $152 = (($135) + ($151)|0);
               $153 = $152;
               $154 = $153;
               HEAP32[$154>>2] = 0;
               $155 = (($153) + 4)|0;
               $156 = $155;
               HEAP32[$156>>2] = 0;
               __THREW__ = 0;
               invoke_vi(3799,($122|0));
               $157 = __THREW__; __THREW__ = 0;
               $158 = $157&1;
               if ($158) {
                break;
               }
               $159 = HEAP32[$127>>2]|0;
               $160 = ($159>>>0)<(3);
               if ($160) {
                __THREW__ = 0;
                $161 = (invoke_i(132)|0);
                $162 = __THREW__; __THREW__ = 0;
                $163 = $162&1;
                if ($163) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($161|0));
                $164 = __THREW__; __THREW__ = 0;
                $165 = $164&1;
                if ($165) {
                 break;
                }
               }
               $166 = HEAP32[$122>>2]|0;
               $167 = (($166) + 92|0);
               $168 = HEAP32[$167>>2]|0;
               $169 = $168 << 1;
               $170 = (($135) + ($169)|0);
               $171 = $170;
               $172 = $171;
               HEAP32[$172>>2] = 0;
               $173 = (($171) + 4)|0;
               $174 = $173;
               HEAP32[$174>>2] = 0;
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $175 = __THREW__; __THREW__ = 0;
               $176 = $175&1;
               if ($176) {
                break;
               }
               $177 = HEAP32[((2682912 + 80|0))>>2]|0;
               $178 = (($177) + 20|0);
               HEAP32[$178>>2] = $122;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z59UnityEngine_UnityEngine_SendMouseEvents_m_DoSendMouseEventsP22mscorlib_System_Objectii($__this,$mouseUsed,$skipRTCameras) {
 $__this = $__this|0;
 $mouseUsed = $mouseUsed|0;
 $skipRTCameras = $skipRTCameras|0;
 var $$sum = 0, $$sum85 = 0, $$sum86 = 0, $$sum87 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = Math_fround(0), $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = Math_fround(0), $346 = Math_fround(0);
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0;
 var $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0;
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0;
 var $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0;
 var $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0;
 var $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0;
 var $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0;
 var $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0;
 var $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0;
 var $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0;
 var $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0;
 var $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0;
 var $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0;
 var $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0;
 var $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0;
 var $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0;
 var $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0;
 var $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B23_0$0 = Math_fround(0), $L_0 = 0, $L_23 = 0, $L_43 = 0, $L_44 = 0, $V_0 = 0, $V_14$0 = 0, $V_2$0 = 0, $V_5$0 = 0, $V_6 = 0, $V_9 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index4 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $tmpcast$byval_copy = sp + 128|0;
 $_stackTraceSentry = sp + 124|0;
 $V_0 = sp + 112|0;
 $V_6 = sp + 96|0;
 $V_9 = sp + 72|0;
 $L_0 = sp + 60|0;
 $L_23 = sp + 32|0;
 $L_43 = sp + 8|0;
 $L_44 = sp + 48|0;
 $0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2682344);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 ;HEAP32[$V_6+0>>2]=0|0;HEAP32[$V_6+4>>2]=0|0;HEAP32[$V_6+8>>2]=0|0;HEAP32[$V_6+12>>2]=0|0;
 ;HEAP32[$V_9+0>>2]=0|0;HEAP32[$V_9+4>>2]=0|0;HEAP32[$V_9+8>>2]=0|0;HEAP32[$V_9+12>>2]=0|0;HEAP32[$V_9+16>>2]=0|0;HEAP32[$V_9+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2119,($L_0|0),(0|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   ;HEAP32[$V_0+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_0+8>>2]|0;
   __THREW__ = 0;
   $3 = (invoke_ii(2634,(0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2682912|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     $8 = HEAP8[((2682912 + 116|0))>>0]|0;
     $9 = ($8<<24>>24)==(0);
     if ($9) {
      __THREW__ = 0;
      (invoke_ii(2996,(2682912|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2682912|0))|0);
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if ($13) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2682912|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2682912|0))|0);
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      $26 = HEAP32[((2682912 + 80|0))>>2]|0;
      $27 = (($26) + 24|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($28|0)==(0|0);
      if ($29) {
       label = 23;
      } else {
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       $32 = HEAP8[((2682912 + 116|0))>>0]|0;
       $33 = ($32<<24>>24)==(0);
       if ($33) {
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2682912|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if ($39) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $40 = __THREW__; __THREW__ = 0;
       $41 = $40&1;
       if ($41) {
        break;
       }
       $42 = HEAP32[((2682912 + 80|0))>>2]|0;
       $43 = (($42) + 24|0);
       $44 = HEAP32[$43>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($44|0));
       $45 = __THREW__; __THREW__ = 0;
       $46 = $45&1;
       if ($46) {
        break;
       }
       $47 = (($44) + 12|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = ($48|0)==($3|0);
       if (!($49)) {
        label = 23;
       }
      }
      if ((label|0) == 23) {
       __THREW__ = 0;
       (invoke_ii(2996,(1182800|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       __THREW__ = 0;
       $52 = (invoke_iii(2773,(1182800|0),($3|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
       $57 = HEAP8[((2682912 + 116|0))>>0]|0;
       $58 = ($57<<24>>24)==(0);
       if ($58) {
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2682912|0));
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        break;
       }
       $67 = HEAP32[((2682912 + 80|0))>>2]|0;
       $68 = (($67) + 24|0);
       HEAP32[$68>>2] = $52;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2682912|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if (!($70)) {
       $71 = HEAP8[((2682912 + 116|0))>>0]|0;
       $72 = ($71<<24>>24)==(0);
       if ($72) {
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2682912|0));
        $77 = __THREW__; __THREW__ = 0;
        $78 = $77&1;
        if ($78) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if (!($80)) {
        $81 = HEAP32[((2682912 + 80|0))>>2]|0;
        $82 = (($81) + 24|0);
        $83 = HEAP32[$82>>2]|0;
        __THREW__ = 0;
        (invoke_iii(1229,(0|0),($83|0))|0);
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if (!($85)) {
         $V_2$0 = 0;
         while(1) {
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 10;
           break;
          }
          $122 = HEAP8[((2682912 + 116|0))>>0]|0;
          $123 = ($122<<24>>24)==(0);
          if ($123) {
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $124 = __THREW__; __THREW__ = 0;
           $125 = $124&1;
           if ($125) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $126 = __THREW__; __THREW__ = 0;
           $127 = $126&1;
           if ($127) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3843,(2682912|0));
           $128 = __THREW__; __THREW__ = 0;
           $129 = $128&1;
           if ($129) {
            label = 10;
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $130 = __THREW__; __THREW__ = 0;
          $131 = $130&1;
          if ($131) {
           label = 10;
           break;
          }
          $132 = HEAP32[((2682912 + 80|0))>>2]|0;
          $133 = (($132) + 20|0);
          $134 = HEAP32[$133>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($134|0));
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           label = 10;
           break;
          }
          $137 = (($134) + 12|0);
          $138 = HEAP32[$137>>2]|0;
          $139 = ($V_2$0|0)<($138|0);
          if (!($139)) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $140 = __THREW__; __THREW__ = 0;
          $141 = $140&1;
          if ($141) {
           label = 10;
           break;
          }
          $86 = HEAP8[((2682912 + 116|0))>>0]|0;
          $87 = ($86<<24>>24)==(0);
          if ($87) {
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $90 = __THREW__; __THREW__ = 0;
           $91 = $90&1;
           if ($91) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3843,(2682912|0));
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            label = 10;
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $94 = __THREW__; __THREW__ = 0;
          $95 = $94&1;
          if ($95) {
           label = 10;
           break;
          }
          $96 = HEAP32[((2682912 + 80|0))>>2]|0;
          $97 = (($96) + 20|0);
          $98 = HEAP32[$97>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($98|0));
          $99 = __THREW__; __THREW__ = 0;
          $100 = $99&1;
          if ($100) {
           label = 10;
           break;
          }
          $101 = (($98) + 12|0);
          $102 = HEAP32[$101>>2]|0;
          $103 = ($V_2$0>>>0)<($102>>>0);
          if (!($103)) {
           __THREW__ = 0;
           $104 = (invoke_i(132)|0);
           $105 = __THREW__; __THREW__ = 0;
           $106 = $105&1;
           if ($106) {
            label = 10;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($104|0));
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if ($108) {
            label = 10;
            break;
           }
          }
          $109 = HEAP32[$98>>2]|0;
          $110 = (($98) + 16|0);
          $111 = (($109) + 92|0);
          $112 = HEAP32[$111>>2]|0;
          $113 = Math_imul($112, $V_2$0)|0;
          $114 = (($110) + ($113)|0);
          $115 = $114;
          $116 = $115;
          HEAP32[$116>>2] = 0;
          $117 = (($115) + 4)|0;
          $118 = $117;
          HEAP32[$118>>2] = 0;
          $119 = (($V_2$0) + 1)|0;
          $V_2$0 = $119;
         }
         if ((label|0) == 10) {
          $20 = ___cxa_find_matching_catch()|0;
          $21 = tempRet0;
          $lpad$phi$index = $20;$lpad$phi$index4 = $21;
          __ZN16StackTraceSentryD2Ev(0);
          ___resumeException($lpad$phi$index|0);
          // unreachable;
         }
         $142 = ($mouseUsed|0)==(0);
         L67: do {
          if ($142) {
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $143 = __THREW__; __THREW__ = 0;
           $144 = $143&1;
           if ($144) {
            break L1;
           }
           $145 = HEAP8[((2682912 + 116|0))>>0]|0;
           $146 = ($145<<24>>24)==(0);
           if ($146) {
            __THREW__ = 0;
            (invoke_ii(2996,(2682912|0))|0);
            $147 = __THREW__; __THREW__ = 0;
            $148 = $147&1;
            if ($148) {
             break L1;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2682912|0))|0);
            $149 = __THREW__; __THREW__ = 0;
            $150 = $149&1;
            if ($150) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3843,(2682912|0));
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            if ($152) {
             break L1;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $153 = __THREW__; __THREW__ = 0;
           $154 = $153&1;
           if ($154) {
            break L1;
           }
           $155 = HEAP32[((2682912 + 80|0))>>2]|0;
           $156 = (($155) + 24|0);
           $157 = HEAP32[$156>>2]|0;
           $158 = (($157) + 12|0);
           $159 = (($157) + 16|0);
           $160 = ($skipRTCameras|0)==(0);
           $161 = (($L_44) + 8|0);
           $V_5$0 = 0;
           L76: while(1) {
            __THREW__ = 0;
            invoke_vi(3799,($157|0));
            $654 = __THREW__; __THREW__ = 0;
            $655 = $654&1;
            if ($655) {
             break;
            }
            $656 = HEAP32[$158>>2]|0;
            $657 = ($V_5$0|0)<($656|0);
            if (!($657)) {
             $V_14$0 = 0;
             break L67;
            }
            __THREW__ = 0;
            invoke_vi(3799,($157|0));
            $658 = __THREW__; __THREW__ = 0;
            $659 = $658&1;
            if ($659) {
             break;
            }
            $162 = HEAP32[$158>>2]|0;
            $163 = ($V_5$0>>>0)<($162>>>0);
            if (!($163)) {
             __THREW__ = 0;
             $164 = (invoke_i(132)|0);
             $165 = __THREW__; __THREW__ = 0;
             $166 = $165&1;
             if ($166) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($164|0));
             $167 = __THREW__; __THREW__ = 0;
             $168 = $167&1;
             if ($168) {
              break;
             }
            }
            $169 = HEAP32[$157>>2]|0;
            $170 = (($169) + 92|0);
            $171 = HEAP32[$170>>2]|0;
            $172 = Math_imul($171, $V_5$0)|0;
            $173 = (($159) + ($172)|0);
            $174 = HEAP32[$173>>2]|0;
            __THREW__ = 0;
            $175 = (invoke_iiii(1318,0,($174|0),(0|0))|0);
            $176 = __THREW__; __THREW__ = 0;
            $177 = $176&1;
            if ($177) {
             break;
            }
            do {
             if (!($175)) {
              if (!($160)) {
               __THREW__ = 0;
               invoke_vi(3799,($174|0));
               $178 = __THREW__; __THREW__ = 0;
               $179 = $178&1;
               if ($179) {
                break L76;
               }
               __THREW__ = 0;
               $180 = (invoke_ii(2631,($174|0))|0);
               $181 = __THREW__; __THREW__ = 0;
               $182 = $181&1;
               if ($182) {
                break L76;
               }
               __THREW__ = 0;
               $183 = (invoke_iiii(1319,0,($180|0),(0|0))|0);
               $184 = __THREW__; __THREW__ = 0;
               $185 = $184&1;
               if ($185) {
                break L76;
               }
               if ($183) {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $186 = __THREW__; __THREW__ = 0;
              $187 = $186&1;
              if ($187) {
               break L76;
              }
              __THREW__ = 0;
              invoke_vii(2105,($L_23|0),($174|0));
              $188 = __THREW__; __THREW__ = 0;
              $189 = $188&1;
              if ($189) {
               break L76;
              }
              ;HEAP32[$V_6+0>>2]=HEAP32[$L_23+0>>2]|0;HEAP32[$V_6+4>>2]=HEAP32[$L_23+4>>2]|0;HEAP32[$V_6+8>>2]=HEAP32[$L_23+8>>2]|0;HEAP32[$V_6+12>>2]=HEAP32[$L_23+12>>2]|0;
              __THREW__ = 0;
              ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
              $190 = (invoke_iii(1218,($V_6|0),($tmpcast$byval_copy|0))|0);
              $191 = __THREW__; __THREW__ = 0;
              $192 = $191&1;
              if ($192) {
               break L76;
              }
              if (!($190)) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $193 = __THREW__; __THREW__ = 0;
              $194 = $193&1;
              if ($194) {
               break L76;
              }
              __THREW__ = 0;
              $195 = (invoke_iii(2726,($174|0),(2888760|0))|0);
              $196 = __THREW__; __THREW__ = 0;
              $197 = $196&1;
              if ($197) {
               break L76;
              }
              __THREW__ = 0;
              $198 = (invoke_iii(1194,0,($195|0))|0);
              $199 = __THREW__; __THREW__ = 0;
              $200 = $199&1;
              if ($200) {
               break L76;
              }
              do {
               if ($198) {
                __THREW__ = 0;
                invoke_vi(3799,($195|0));
                $201 = __THREW__; __THREW__ = 0;
                $202 = $201&1;
                if ($202) {
                 break L76;
                }
                __THREW__ = 0;
                ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
                $203 = (invoke_iii(1206,($195|0),($tmpcast$byval_copy|0))|0);
                $204 = __THREW__; __THREW__ = 0;
                $205 = $204&1;
                if ($205) {
                 break L76;
                }
                __THREW__ = 0;
                $206 = (invoke_iii(1194,0,($203|0))|0);
                $207 = __THREW__; __THREW__ = 0;
                $208 = $207&1;
                if ($208) {
                 break L76;
                }
                if (!($206)) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $266 = __THREW__; __THREW__ = 0;
                 $267 = $266&1;
                 if ($267) {
                  break L76;
                 }
                 $268 = HEAP8[((2682912 + 116|0))>>0]|0;
                 $269 = ($268<<24>>24)==(0);
                 if ($269) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2682912|0))|0);
                  $270 = __THREW__; __THREW__ = 0;
                  $271 = $270&1;
                  if ($271) {
                   break L76;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2682912|0))|0);
                  $272 = __THREW__; __THREW__ = 0;
                  $273 = $272&1;
                  if ($273) {
                   break L76;
                  }
                  __THREW__ = 0;
                  invoke_vi(3843,(2682912|0));
                  $274 = __THREW__; __THREW__ = 0;
                  $275 = $274&1;
                  if ($275) {
                   break L76;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $276 = __THREW__; __THREW__ = 0;
                 $277 = $276&1;
                 if ($277) {
                  break L76;
                 }
                 $278 = HEAP32[((2682912 + 80|0))>>2]|0;
                 $279 = (($278) + 20|0);
                 $280 = HEAP32[$279>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($280|0));
                 $281 = __THREW__; __THREW__ = 0;
                 $282 = $281&1;
                 if ($282) {
                  break L76;
                 }
                 $283 = (($280) + 12|0);
                 $284 = HEAP32[$283>>2]|0;
                 $285 = ($284|0)==(0);
                 if ($285) {
                  __THREW__ = 0;
                  $286 = (invoke_i(132)|0);
                  $287 = __THREW__; __THREW__ = 0;
                  $288 = $287&1;
                  if ($288) {
                   break L76;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($286|0));
                  $289 = __THREW__; __THREW__ = 0;
                  $290 = $289&1;
                  if ($290) {
                   break L76;
                  }
                 }
                 $291 = (($280) + 16|0);
                 HEAP32[$291>>2] = 0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $292 = __THREW__; __THREW__ = 0;
                 $293 = $292&1;
                 if ($293) {
                  break L76;
                 }
                 $294 = HEAP8[((2682912 + 116|0))>>0]|0;
                 $295 = ($294<<24>>24)==(0);
                 if ($295) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2682912|0))|0);
                  $296 = __THREW__; __THREW__ = 0;
                  $297 = $296&1;
                  if ($297) {
                   break L76;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2682912|0))|0);
                  $298 = __THREW__; __THREW__ = 0;
                  $299 = $298&1;
                  if ($299) {
                   break L76;
                  }
                  __THREW__ = 0;
                  invoke_vi(3843,(2682912|0));
                  $300 = __THREW__; __THREW__ = 0;
                  $301 = $300&1;
                  if ($301) {
                   break L76;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $302 = __THREW__; __THREW__ = 0;
                 $303 = $302&1;
                 if ($303) {
                  break L76;
                 }
                 $304 = HEAP32[((2682912 + 80|0))>>2]|0;
                 $305 = (($304) + 20|0);
                 $306 = HEAP32[$305>>2]|0;
                 __THREW__ = 0;
                 invoke_vi(3799,($306|0));
                 $307 = __THREW__; __THREW__ = 0;
                 $308 = $307&1;
                 if ($308) {
                  break L76;
                 }
                 $309 = (($306) + 12|0);
                 $310 = HEAP32[$309>>2]|0;
                 $311 = ($310|0)==(0);
                 if ($311) {
                  __THREW__ = 0;
                  $312 = (invoke_i(132)|0);
                  $313 = __THREW__; __THREW__ = 0;
                  $314 = $313&1;
                  if ($314) {
                   break L76;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($312|0));
                  $315 = __THREW__; __THREW__ = 0;
                  $316 = $315&1;
                  if ($316) {
                   break L76;
                  }
                 }
                 $317 = (($306) + 20|0);
                 HEAP32[$317>>2] = 0;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $209 = __THREW__; __THREW__ = 0;
                $210 = $209&1;
                if ($210) {
                 break L76;
                }
                $211 = HEAP8[((2682912 + 116|0))>>0]|0;
                $212 = ($211<<24>>24)==(0);
                if ($212) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $213 = __THREW__; __THREW__ = 0;
                 $214 = $213&1;
                 if ($214) {
                  break L76;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $215 = __THREW__; __THREW__ = 0;
                 $216 = $215&1;
                 if ($216) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2682912|0));
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  break L76;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $219 = __THREW__; __THREW__ = 0;
                $220 = $219&1;
                if ($220) {
                 break L76;
                }
                $221 = HEAP32[((2682912 + 80|0))>>2]|0;
                $222 = (($221) + 20|0);
                $223 = HEAP32[$222>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($223|0));
                $224 = __THREW__; __THREW__ = 0;
                $225 = $224&1;
                if ($225) {
                 break L76;
                }
                $226 = (($223) + 12|0);
                $227 = HEAP32[$226>>2]|0;
                $228 = ($227|0)==(0);
                if ($228) {
                 __THREW__ = 0;
                 $229 = (invoke_i(132)|0);
                 $230 = __THREW__; __THREW__ = 0;
                 $231 = $230&1;
                 if ($231) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($229|0));
                 $232 = __THREW__; __THREW__ = 0;
                 $233 = $232&1;
                 if ($233) {
                  break L76;
                 }
                }
                __THREW__ = 0;
                invoke_vi(3799,($203|0));
                $234 = __THREW__; __THREW__ = 0;
                $235 = $234&1;
                if ($235) {
                 break L76;
                }
                __THREW__ = 0;
                $236 = (invoke_ii(2523,($203|0))|0);
                $237 = __THREW__; __THREW__ = 0;
                $238 = $237&1;
                if ($238) {
                 break L76;
                }
                $239 = (($223) + 16|0);
                HEAP32[$239>>2] = $236;
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $240 = __THREW__; __THREW__ = 0;
                $241 = $240&1;
                if ($241) {
                 break L76;
                }
                $242 = HEAP8[((2682912 + 116|0))>>0]|0;
                $243 = ($242<<24>>24)==(0);
                if ($243) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $244 = __THREW__; __THREW__ = 0;
                 $245 = $244&1;
                 if ($245) {
                  break L76;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $246 = __THREW__; __THREW__ = 0;
                 $247 = $246&1;
                 if ($247) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2682912|0));
                 $248 = __THREW__; __THREW__ = 0;
                 $249 = $248&1;
                 if ($249) {
                  break L76;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $250 = __THREW__; __THREW__ = 0;
                $251 = $250&1;
                if ($251) {
                 break L76;
                }
                $252 = HEAP32[((2682912 + 80|0))>>2]|0;
                $253 = (($252) + 20|0);
                $254 = HEAP32[$253>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($254|0));
                $255 = __THREW__; __THREW__ = 0;
                $256 = $255&1;
                if ($256) {
                 break L76;
                }
                $257 = (($254) + 12|0);
                $258 = HEAP32[$257>>2]|0;
                $259 = ($258|0)==(0);
                if ($259) {
                 __THREW__ = 0;
                 $260 = (invoke_i(132)|0);
                 $261 = __THREW__; __THREW__ = 0;
                 $262 = $261&1;
                 if ($262) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($260|0));
                 $263 = __THREW__; __THREW__ = 0;
                 $264 = $263&1;
                 if ($264) {
                  break L76;
                 }
                }
                $265 = (($254) + 20|0);
                HEAP32[$265>>2] = $174;
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $318 = __THREW__; __THREW__ = 0;
              $319 = $318&1;
              if ($319) {
               break L76;
              }
              __THREW__ = 0;
              $320 = (invoke_ii(2630,($174|0))|0);
              $321 = __THREW__; __THREW__ = 0;
              $322 = $321&1;
              if ($322) {
               break L76;
              }
              $323 = ($320|0)==(0);
              if ($323) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $324 = __THREW__; __THREW__ = 0;
              $325 = $324&1;
              if ($325) {
               break L76;
              }
              __THREW__ = 0;
              ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;
              invoke_viii(772,($L_43|0),($174|0),($tmpcast$byval_copy|0));
              $326 = __THREW__; __THREW__ = 0;
              $327 = $326&1;
              if ($327) {
               break L76;
              }
              ;HEAP32[$V_9+0>>2]=HEAP32[$L_43+0>>2]|0;HEAP32[$V_9+4>>2]=HEAP32[$L_43+4>>2]|0;HEAP32[$V_9+8>>2]=HEAP32[$L_43+8>>2]|0;HEAP32[$V_9+12>>2]=HEAP32[$L_43+12>>2]|0;HEAP32[$V_9+16>>2]=HEAP32[$L_43+16>>2]|0;HEAP32[$V_9+20>>2]=HEAP32[$L_43+20>>2]|0;
              __THREW__ = 0;
              invoke_vii(2095,($L_44|0),($V_9|0));
              $328 = __THREW__; __THREW__ = 0;
              $329 = $328&1;
              if ($329) {
               break L76;
              }
              $330 = Math_fround(HEAPF32[$161>>2]);
              __THREW__ = 0;
              $331 = (invoke_iiff(1,(0|0),0.0,(+$330))|0);
              $332 = __THREW__; __THREW__ = 0;
              $333 = $332&1;
              if ($333) {
               break L76;
              }
              if ($331) {
               $G_B23_0$0 = Math_fround(inf);
              } else {
               __THREW__ = 0;
               invoke_vi(3799,($174|0));
               $334 = __THREW__; __THREW__ = 0;
               $335 = $334&1;
               if ($335) {
                break L76;
               }
               __THREW__ = 0;
               $336 = (Math_fround(+(invoke_fi(147,($174|0)))));
               $337 = __THREW__; __THREW__ = 0;
               $338 = $337&1;
               if ($338) {
                break L76;
               }
               __THREW__ = 0;
               invoke_vi(3799,($174|0));
               $339 = __THREW__; __THREW__ = 0;
               $340 = $339&1;
               if ($340) {
                break L76;
               }
               __THREW__ = 0;
               $341 = (Math_fround(+(invoke_fi(146,($174|0)))));
               $342 = __THREW__; __THREW__ = 0;
               $343 = $342&1;
               if ($343) {
                break L76;
               }
               $344 = Math_fround($336 - $341);
               $345 = Math_fround($344 / $330);
               $346 = (Math_fround(Math_abs((Math_fround($345)))));
               $G_B23_0$0 = $346;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $347 = __THREW__; __THREW__ = 0;
              $348 = $347&1;
              if ($348) {
               break L76;
              }
              __THREW__ = 0;
              $349 = (invoke_ii(2629,($174|0))|0);
              $350 = __THREW__; __THREW__ = 0;
              $351 = $350&1;
              if ($351) {
               break L76;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $352 = __THREW__; __THREW__ = 0;
              $353 = $352&1;
              if ($353) {
               break L76;
              }
              __THREW__ = 0;
              $354 = (invoke_ii(2630,($174|0))|0);
              $355 = __THREW__; __THREW__ = 0;
              $356 = $355&1;
              if ($356) {
               break L76;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $357 = __THREW__; __THREW__ = 0;
              $358 = $357&1;
              if ($358) {
               break L76;
              }
              $359 = $354 & $349;
              __THREW__ = 0;
              ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$V_9+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$V_9+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$V_9+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$V_9+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$V_9+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$V_9+20>>2]|0;
              $360 = (invoke_iiifi(2,($174|0),($tmpcast$byval_copy|0),(+$G_B23_0$0),($359|0))|0);
              $361 = __THREW__; __THREW__ = 0;
              $362 = $361&1;
              if ($362) {
               break L76;
              }
              __THREW__ = 0;
              $363 = (invoke_iiii(1319,0,($360|0),(0|0))|0);
              $364 = __THREW__; __THREW__ = 0;
              $365 = $364&1;
              if ($365) {
               break L76;
              }
              do {
               if ($363) {
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $366 = __THREW__; __THREW__ = 0;
                $367 = $366&1;
                if ($367) {
                 break L76;
                }
                $368 = HEAP8[((2682912 + 116|0))>>0]|0;
                $369 = ($368<<24>>24)==(0);
                if ($369) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $370 = __THREW__; __THREW__ = 0;
                 $371 = $370&1;
                 if ($371) {
                  break L76;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $372 = __THREW__; __THREW__ = 0;
                 $373 = $372&1;
                 if ($373) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2682912|0));
                 $374 = __THREW__; __THREW__ = 0;
                 $375 = $374&1;
                 if ($375) {
                  break L76;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $376 = __THREW__; __THREW__ = 0;
                $377 = $376&1;
                if ($377) {
                 break L76;
                }
                $378 = HEAP32[((2682912 + 80|0))>>2]|0;
                $379 = (($378) + 20|0);
                $380 = HEAP32[$379>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($380|0));
                $381 = __THREW__; __THREW__ = 0;
                $382 = $381&1;
                if ($382) {
                 break L76;
                }
                $383 = (($380) + 12|0);
                $384 = HEAP32[$383>>2]|0;
                $385 = ($384>>>0)<(2);
                if ($385) {
                 __THREW__ = 0;
                 $386 = (invoke_i(132)|0);
                 $387 = __THREW__; __THREW__ = 0;
                 $388 = $387&1;
                 if ($388) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($386|0));
                 $389 = __THREW__; __THREW__ = 0;
                 $390 = $389&1;
                 if ($390) {
                  break L76;
                 }
                }
                $391 = HEAP32[$380>>2]|0;
                $392 = (($380) + 16|0);
                $393 = (($391) + 92|0);
                $394 = HEAP32[$393>>2]|0;
                $395 = (($392) + ($394)|0);
                HEAP32[$395>>2] = $360;
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $396 = __THREW__; __THREW__ = 0;
                $397 = $396&1;
                if ($397) {
                 break L76;
                }
                $398 = HEAP8[((2682912 + 116|0))>>0]|0;
                $399 = ($398<<24>>24)==(0);
                if ($399) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $400 = __THREW__; __THREW__ = 0;
                 $401 = $400&1;
                 if ($401) {
                  break L76;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $402 = __THREW__; __THREW__ = 0;
                 $403 = $402&1;
                 if ($403) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2682912|0));
                 $404 = __THREW__; __THREW__ = 0;
                 $405 = $404&1;
                 if ($405) {
                  break L76;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $406 = __THREW__; __THREW__ = 0;
                $407 = $406&1;
                if ($407) {
                 break L76;
                }
                $408 = HEAP32[((2682912 + 80|0))>>2]|0;
                $409 = (($408) + 20|0);
                $410 = HEAP32[$409>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($410|0));
                $411 = __THREW__; __THREW__ = 0;
                $412 = $411&1;
                if ($412) {
                 break L76;
                }
                $413 = (($410) + 12|0);
                $414 = HEAP32[$413>>2]|0;
                $415 = ($414>>>0)<(2);
                if ($415) {
                 __THREW__ = 0;
                 $416 = (invoke_i(132)|0);
                 $417 = __THREW__; __THREW__ = 0;
                 $418 = $417&1;
                 if ($418) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($416|0));
                 $419 = __THREW__; __THREW__ = 0;
                 $420 = $419&1;
                 if ($420) {
                  break L76;
                 }
                }
                $421 = HEAP32[$410>>2]|0;
                $422 = (($410) + 16|0);
                $423 = (($421) + 92|0);
                $424 = HEAP32[$423>>2]|0;
                $$sum87 = (($424) + 4)|0;
                $425 = (($422) + ($$sum87)|0);
                HEAP32[$425>>2] = $174;
               } else {
                __THREW__ = 0;
                invoke_vi(3799,($174|0));
                $426 = __THREW__; __THREW__ = 0;
                $427 = $426&1;
                if ($427) {
                 break L76;
                }
                __THREW__ = 0;
                $428 = (invoke_ii(2632,($174|0))|0);
                $429 = __THREW__; __THREW__ = 0;
                $430 = $429&1;
                if ($430) {
                 break L76;
                }
                $431 = ($428|0)==(1);
                if (!($431)) {
                 __THREW__ = 0;
                 invoke_vi(3799,($174|0));
                 $432 = __THREW__; __THREW__ = 0;
                 $433 = $432&1;
                 if ($433) {
                  break L76;
                 }
                 __THREW__ = 0;
                 $434 = (invoke_ii(2632,($174|0))|0);
                 $435 = __THREW__; __THREW__ = 0;
                 $436 = $435&1;
                 if ($436) {
                  break L76;
                 }
                 $437 = ($434|0)==(2);
                 if (!($437)) {
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $438 = __THREW__; __THREW__ = 0;
                $439 = $438&1;
                if ($439) {
                 break L76;
                }
                $440 = HEAP8[((2682912 + 116|0))>>0]|0;
                $441 = ($440<<24>>24)==(0);
                if ($441) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $442 = __THREW__; __THREW__ = 0;
                 $443 = $442&1;
                 if ($443) {
                  break L76;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $444 = __THREW__; __THREW__ = 0;
                 $445 = $444&1;
                 if ($445) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2682912|0));
                 $446 = __THREW__; __THREW__ = 0;
                 $447 = $446&1;
                 if ($447) {
                  break L76;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $448 = __THREW__; __THREW__ = 0;
                $449 = $448&1;
                if ($449) {
                 break L76;
                }
                $450 = HEAP32[((2682912 + 80|0))>>2]|0;
                $451 = (($450) + 20|0);
                $452 = HEAP32[$451>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($452|0));
                $453 = __THREW__; __THREW__ = 0;
                $454 = $453&1;
                if ($454) {
                 break L76;
                }
                $455 = (($452) + 12|0);
                $456 = HEAP32[$455>>2]|0;
                $457 = ($456>>>0)<(2);
                if ($457) {
                 __THREW__ = 0;
                 $458 = (invoke_i(132)|0);
                 $459 = __THREW__; __THREW__ = 0;
                 $460 = $459&1;
                 if ($460) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($458|0));
                 $461 = __THREW__; __THREW__ = 0;
                 $462 = $461&1;
                 if ($462) {
                  break L76;
                 }
                }
                $463 = HEAP32[$452>>2]|0;
                $464 = (($452) + 16|0);
                $465 = (($463) + 92|0);
                $466 = HEAP32[$465>>2]|0;
                $467 = (($464) + ($466)|0);
                HEAP32[$467>>2] = 0;
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $468 = __THREW__; __THREW__ = 0;
                $469 = $468&1;
                if ($469) {
                 break L76;
                }
                $470 = HEAP8[((2682912 + 116|0))>>0]|0;
                $471 = ($470<<24>>24)==(0);
                if ($471) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $472 = __THREW__; __THREW__ = 0;
                 $473 = $472&1;
                 if ($473) {
                  break L76;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2682912|0))|0);
                 $474 = __THREW__; __THREW__ = 0;
                 $475 = $474&1;
                 if ($475) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2682912|0));
                 $476 = __THREW__; __THREW__ = 0;
                 $477 = $476&1;
                 if ($477) {
                  break L76;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $478 = __THREW__; __THREW__ = 0;
                $479 = $478&1;
                if ($479) {
                 break L76;
                }
                $480 = HEAP32[((2682912 + 80|0))>>2]|0;
                $481 = (($480) + 20|0);
                $482 = HEAP32[$481>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($482|0));
                $483 = __THREW__; __THREW__ = 0;
                $484 = $483&1;
                if ($484) {
                 break L76;
                }
                $485 = (($482) + 12|0);
                $486 = HEAP32[$485>>2]|0;
                $487 = ($486>>>0)<(2);
                if ($487) {
                 __THREW__ = 0;
                 $488 = (invoke_i(132)|0);
                 $489 = __THREW__; __THREW__ = 0;
                 $490 = $489&1;
                 if ($490) {
                  break L76;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($488|0));
                 $491 = __THREW__; __THREW__ = 0;
                 $492 = $491&1;
                 if ($492) {
                  break L76;
                 }
                }
                $493 = HEAP32[$482>>2]|0;
                $494 = (($482) + 16|0);
                $495 = (($493) + 92|0);
                $496 = HEAP32[$495>>2]|0;
                $$sum86 = (($496) + 4)|0;
                $497 = (($494) + ($$sum86)|0);
                HEAP32[$497>>2] = 0;
               }
              } while(0);
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $498 = __THREW__; __THREW__ = 0;
              $499 = $498&1;
              if ($499) {
               break L76;
              }
              __THREW__ = 0;
              $500 = (invoke_ii(2629,($174|0))|0);
              $501 = __THREW__; __THREW__ = 0;
              $502 = $501&1;
              if ($502) {
               break L76;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $503 = __THREW__; __THREW__ = 0;
              $504 = $503&1;
              if ($504) {
               break L76;
              }
              __THREW__ = 0;
              $505 = (invoke_ii(2630,($174|0))|0);
              $506 = __THREW__; __THREW__ = 0;
              $507 = $506&1;
              if ($507) {
               break L76;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $508 = __THREW__; __THREW__ = 0;
              $509 = $508&1;
              if ($509) {
               break L76;
              }
              $510 = $505 & $500;
              __THREW__ = 0;
              ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$V_9+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$V_9+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$V_9+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$V_9+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$V_9+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$V_9+20>>2]|0;
              $511 = (invoke_iiifi(3,($174|0),($tmpcast$byval_copy|0),(+$G_B23_0$0),($510|0))|0);
              $512 = __THREW__; __THREW__ = 0;
              $513 = $512&1;
              if ($513) {
               break L76;
              }
              __THREW__ = 0;
              $514 = (invoke_iiii(1319,0,($511|0),(0|0))|0);
              $515 = __THREW__; __THREW__ = 0;
              $516 = $515&1;
              if ($516) {
               break L76;
              }
              if ($514) {
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $517 = __THREW__; __THREW__ = 0;
               $518 = $517&1;
               if ($518) {
                break L76;
               }
               $519 = HEAP8[((2682912 + 116|0))>>0]|0;
               $520 = ($519<<24>>24)==(0);
               if ($520) {
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $521 = __THREW__; __THREW__ = 0;
                $522 = $521&1;
                if ($522) {
                 break L76;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $523 = __THREW__; __THREW__ = 0;
                $524 = $523&1;
                if ($524) {
                 break L76;
                }
                __THREW__ = 0;
                invoke_vi(3843,(2682912|0));
                $525 = __THREW__; __THREW__ = 0;
                $526 = $525&1;
                if ($526) {
                 break L76;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $527 = __THREW__; __THREW__ = 0;
               $528 = $527&1;
               if ($528) {
                break L76;
               }
               $529 = HEAP32[((2682912 + 80|0))>>2]|0;
               $530 = (($529) + 20|0);
               $531 = HEAP32[$530>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($531|0));
               $532 = __THREW__; __THREW__ = 0;
               $533 = $532&1;
               if ($533) {
                break L76;
               }
               $534 = (($531) + 12|0);
               $535 = HEAP32[$534>>2]|0;
               $536 = ($535>>>0)<(3);
               if ($536) {
                __THREW__ = 0;
                $537 = (invoke_i(132)|0);
                $538 = __THREW__; __THREW__ = 0;
                $539 = $538&1;
                if ($539) {
                 break L76;
                }
                __THREW__ = 0;
                invoke_vi(3302,($537|0));
                $540 = __THREW__; __THREW__ = 0;
                $541 = $540&1;
                if ($541) {
                 break L76;
                }
               }
               $542 = HEAP32[$531>>2]|0;
               $543 = (($531) + 16|0);
               $544 = (($542) + 92|0);
               $545 = HEAP32[$544>>2]|0;
               $546 = $545 << 1;
               $547 = (($543) + ($546)|0);
               HEAP32[$547>>2] = $511;
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $548 = __THREW__; __THREW__ = 0;
               $549 = $548&1;
               if ($549) {
                break L76;
               }
               $550 = HEAP8[((2682912 + 116|0))>>0]|0;
               $551 = ($550<<24>>24)==(0);
               if ($551) {
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $552 = __THREW__; __THREW__ = 0;
                $553 = $552&1;
                if ($553) {
                 break L76;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2682912|0))|0);
                $554 = __THREW__; __THREW__ = 0;
                $555 = $554&1;
                if ($555) {
                 break L76;
                }
                __THREW__ = 0;
                invoke_vi(3843,(2682912|0));
                $556 = __THREW__; __THREW__ = 0;
                $557 = $556&1;
                if ($557) {
                 break L76;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $558 = __THREW__; __THREW__ = 0;
               $559 = $558&1;
               if ($559) {
                break L76;
               }
               $560 = HEAP32[((2682912 + 80|0))>>2]|0;
               $561 = (($560) + 20|0);
               $562 = HEAP32[$561>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($562|0));
               $563 = __THREW__; __THREW__ = 0;
               $564 = $563&1;
               if ($564) {
                break L76;
               }
               $565 = (($562) + 12|0);
               $566 = HEAP32[$565>>2]|0;
               $567 = ($566>>>0)<(3);
               if ($567) {
                __THREW__ = 0;
                $568 = (invoke_i(132)|0);
                $569 = __THREW__; __THREW__ = 0;
                $570 = $569&1;
                if ($570) {
                 break L76;
                }
                __THREW__ = 0;
                invoke_vi(3302,($568|0));
                $571 = __THREW__; __THREW__ = 0;
                $572 = $571&1;
                if ($572) {
                 break L76;
                }
               }
               $573 = HEAP32[$562>>2]|0;
               $574 = (($562) + 16|0);
               $575 = (($573) + 92|0);
               $576 = HEAP32[$575>>2]|0;
               $577 = $576 << 1;
               $$sum85 = (($577) + 4)|0;
               $578 = (($574) + ($$sum85)|0);
               HEAP32[$578>>2] = $174;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($174|0));
              $579 = __THREW__; __THREW__ = 0;
              $580 = $579&1;
              if ($580) {
               break L76;
              }
              __THREW__ = 0;
              $581 = (invoke_ii(2632,($174|0))|0);
              $582 = __THREW__; __THREW__ = 0;
              $583 = $582&1;
              if ($583) {
               break L76;
              }
              $584 = ($581|0)==(1);
              if (!($584)) {
               __THREW__ = 0;
               invoke_vi(3799,($174|0));
               $585 = __THREW__; __THREW__ = 0;
               $586 = $585&1;
               if ($586) {
                break L76;
               }
               __THREW__ = 0;
               $587 = (invoke_ii(2632,($174|0))|0);
               $588 = __THREW__; __THREW__ = 0;
               $589 = $588&1;
               if ($589) {
                break L76;
               }
               $590 = ($587|0)==(2);
               if (!($590)) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2682912|0))|0);
              $591 = __THREW__; __THREW__ = 0;
              $592 = $591&1;
              if ($592) {
               break L76;
              }
              $593 = HEAP8[((2682912 + 116|0))>>0]|0;
              $594 = ($593<<24>>24)==(0);
              if ($594) {
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $595 = __THREW__; __THREW__ = 0;
               $596 = $595&1;
               if ($596) {
                break L76;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $597 = __THREW__; __THREW__ = 0;
               $598 = $597&1;
               if ($598) {
                break L76;
               }
               __THREW__ = 0;
               invoke_vi(3843,(2682912|0));
               $599 = __THREW__; __THREW__ = 0;
               $600 = $599&1;
               if ($600) {
                break L76;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2682912|0))|0);
              $601 = __THREW__; __THREW__ = 0;
              $602 = $601&1;
              if ($602) {
               break L76;
              }
              $603 = HEAP32[((2682912 + 80|0))>>2]|0;
              $604 = (($603) + 20|0);
              $605 = HEAP32[$604>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($605|0));
              $606 = __THREW__; __THREW__ = 0;
              $607 = $606&1;
              if ($607) {
               break L76;
              }
              $608 = (($605) + 12|0);
              $609 = HEAP32[$608>>2]|0;
              $610 = ($609>>>0)<(3);
              if ($610) {
               __THREW__ = 0;
               $611 = (invoke_i(132)|0);
               $612 = __THREW__; __THREW__ = 0;
               $613 = $612&1;
               if ($613) {
                break L76;
               }
               __THREW__ = 0;
               invoke_vi(3302,($611|0));
               $614 = __THREW__; __THREW__ = 0;
               $615 = $614&1;
               if ($615) {
                break L76;
               }
              }
              $616 = HEAP32[$605>>2]|0;
              $617 = (($605) + 16|0);
              $618 = (($616) + 92|0);
              $619 = HEAP32[$618>>2]|0;
              $620 = $619 << 1;
              $621 = (($617) + ($620)|0);
              HEAP32[$621>>2] = 0;
              __THREW__ = 0;
              (invoke_ii(2996,(2682912|0))|0);
              $622 = __THREW__; __THREW__ = 0;
              $623 = $622&1;
              if ($623) {
               break L76;
              }
              $624 = HEAP8[((2682912 + 116|0))>>0]|0;
              $625 = ($624<<24>>24)==(0);
              if ($625) {
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $626 = __THREW__; __THREW__ = 0;
               $627 = $626&1;
               if ($627) {
                break L76;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2682912|0))|0);
               $628 = __THREW__; __THREW__ = 0;
               $629 = $628&1;
               if ($629) {
                break L76;
               }
               __THREW__ = 0;
               invoke_vi(3843,(2682912|0));
               $630 = __THREW__; __THREW__ = 0;
               $631 = $630&1;
               if ($631) {
                break L76;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2682912|0))|0);
              $632 = __THREW__; __THREW__ = 0;
              $633 = $632&1;
              if ($633) {
               break L76;
              }
              $634 = HEAP32[((2682912 + 80|0))>>2]|0;
              $635 = (($634) + 20|0);
              $636 = HEAP32[$635>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($636|0));
              $637 = __THREW__; __THREW__ = 0;
              $638 = $637&1;
              if ($638) {
               break L76;
              }
              $639 = (($636) + 12|0);
              $640 = HEAP32[$639>>2]|0;
              $641 = ($640>>>0)<(3);
              if ($641) {
               __THREW__ = 0;
               $642 = (invoke_i(132)|0);
               $643 = __THREW__; __THREW__ = 0;
               $644 = $643&1;
               if ($644) {
                break L76;
               }
               __THREW__ = 0;
               invoke_vi(3302,($642|0));
               $645 = __THREW__; __THREW__ = 0;
               $646 = $645&1;
               if ($646) {
                break L76;
               }
              }
              $647 = HEAP32[$636>>2]|0;
              $648 = (($636) + 16|0);
              $649 = (($647) + 92|0);
              $650 = HEAP32[$649>>2]|0;
              $651 = $650 << 1;
              $$sum = (($651) + 4)|0;
              $652 = (($648) + ($$sum)|0);
              HEAP32[$652>>2] = 0;
             }
            } while(0);
            $653 = (($V_5$0) + 1)|0;
            $V_5$0 = $653;
           }
           $18 = ___cxa_find_matching_catch()|0;
           $19 = tempRet0;
           $lpad$phi$index = $18;$lpad$phi$index4 = $19;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($lpad$phi$index|0);
           // unreachable;
          } else {
           $V_14$0 = 0;
          }
         } while(0);
         while(1) {
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $702 = __THREW__; __THREW__ = 0;
          $703 = $702&1;
          if ($703) {
           break;
          }
          $704 = HEAP8[((2682912 + 116|0))>>0]|0;
          $705 = ($704<<24>>24)==(0);
          if ($705) {
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $706 = __THREW__; __THREW__ = 0;
           $707 = $706&1;
           if ($707) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $708 = __THREW__; __THREW__ = 0;
           $709 = $708&1;
           if ($709) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3843,(2682912|0));
           $710 = __THREW__; __THREW__ = 0;
           $711 = $710&1;
           if ($711) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $712 = __THREW__; __THREW__ = 0;
          $713 = $712&1;
          if ($713) {
           break;
          }
          $714 = HEAP32[((2682912 + 80|0))>>2]|0;
          $715 = (($714) + 20|0);
          $716 = HEAP32[$715>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($716|0));
          $717 = __THREW__; __THREW__ = 0;
          $718 = $717&1;
          if ($718) {
           break;
          }
          $719 = (($716) + 12|0);
          $720 = HEAP32[$719>>2]|0;
          $721 = ($V_14$0|0)<($720|0);
          if (!($721)) {
           label = 281;
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $722 = __THREW__; __THREW__ = 0;
          $723 = $722&1;
          if ($723) {
           break;
          }
          $660 = HEAP8[((2682912 + 116|0))>>0]|0;
          $661 = ($660<<24>>24)==(0);
          if ($661) {
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $662 = __THREW__; __THREW__ = 0;
           $663 = $662&1;
           if ($663) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $664 = __THREW__; __THREW__ = 0;
           $665 = $664&1;
           if ($665) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3843,(2682912|0));
           $666 = __THREW__; __THREW__ = 0;
           $667 = $666&1;
           if ($667) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $668 = __THREW__; __THREW__ = 0;
          $669 = $668&1;
          if ($669) {
           break;
          }
          $670 = HEAP32[((2682912 + 80|0))>>2]|0;
          $671 = (($670) + 20|0);
          $672 = HEAP32[$671>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($672|0));
          $673 = __THREW__; __THREW__ = 0;
          $674 = $673&1;
          if ($674) {
           break;
          }
          $675 = (($672) + 12|0);
          $676 = HEAP32[$675>>2]|0;
          $677 = ($V_14$0>>>0)<($676>>>0);
          if (!($677)) {
           __THREW__ = 0;
           $678 = (invoke_i(132)|0);
           $679 = __THREW__; __THREW__ = 0;
           $680 = $679&1;
           if ($680) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($678|0));
           $681 = __THREW__; __THREW__ = 0;
           $682 = $681&1;
           if ($682) {
            break;
           }
          }
          $683 = HEAP32[$672>>2]|0;
          $684 = (($672) + 16|0);
          $685 = (($683) + 92|0);
          $686 = HEAP32[$685>>2]|0;
          $687 = Math_imul($686, $V_14$0)|0;
          $688 = (($684) + ($687)|0);
          $689 = $688;
          $690 = $689;
          $691 = HEAP32[$690>>2]|0;
          $692 = (($689) + 4)|0;
          $693 = $692;
          $694 = HEAP32[$693>>2]|0;
          $695 = $0;
          $696 = $695;
          HEAP32[$696>>2] = $691;
          $697 = (($695) + 4)|0;
          $698 = $697;
          HEAP32[$698>>2] = $694;
          __THREW__ = 0;
          ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
          invoke_viii(723,0,($V_14$0|0),($tmpcast$byval_copy|0));
          $699 = __THREW__; __THREW__ = 0;
          $700 = $699&1;
          if ($700) {
           break;
          }
          $701 = (($V_14$0) + 1)|0;
          $V_14$0 = $701;
         }
         if ((label|0) == 281) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         $16 = ___cxa_find_matching_catch()|0;
         $17 = tempRet0;
         $lpad$phi$index = $16;$lpad$phi$index4 = $17;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($lpad$phi$index|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $lpad$phi$index = $22;$lpad$phi$index4 = $23;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_GUILayer_m_HitTestP32UnityEngine_UnityEngine_GUILayer31UnityEngine_UnityEngine_Vector3($__this,$screenPosition) {
 $__this = $__this|0;
 $screenPosition = $screenPosition|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2724512);
 __THREW__ = 0;
 $0 = (invoke_iiii(1330,0,($__this|0),($screenPosition|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z50UnityEngine_UnityEngine_Component_m_get_gameObjectP33UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2699104);
 $0 = HEAP32[2699152>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2699160|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2699152>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52UnityEngine_UnityEngine_SendMouseEvents_m_SendEventsP22mscorlib_System_Objecti47UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this,$i,$hit) {
 $__this = $__this|0;
 $i = $i|0;
 $hit = $hit|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $_stackTraceSentry = 0, $tmpcast1$byval_copy = 0, $tmpcast4$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $tmpcast4$byval_copy = sp + 88|0;
 $tmpcast1$byval_copy = sp + 80|0;
 $_stackTraceSentry = sp + 96|0;
 $0 = sp + 72|0;
 $1 = sp + 64|0;
 $2 = sp + 56|0;
 $3 = sp + 48|0;
 $4 = sp + 32|0;
 $5 = sp + 24|0;
 $6 = sp + 16|0;
 $7 = sp + 8|0;
 $8 = sp;
 $9 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2682392);
 __THREW__ = 0;
 invoke_v(949);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 L1: do {
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_iii(1236,(0|0),0)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    $15 = (invoke_iii(1235,(0|0),0)|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     do {
      if ($12) {
       $20 = $hit;
       $21 = $20;
       $22 = HEAP32[$21>>2]|0;
       $23 = (($20) + 4)|0;
       $24 = $23;
       $25 = HEAP32[$24>>2]|0;
       $26 = $0;
       $27 = $26;
       HEAP32[$27>>2] = $22;
       $28 = (($26) + 4)|0;
       $29 = $28;
       HEAP32[$29>>2] = $25;
       __THREW__ = 0;
       ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
       $30 = (invoke_iii(1182,0,($tmpcast4$byval_copy|0))|0);
       $31 = __THREW__; __THREW__ = 0;
       $32 = $31&1;
       if ($32) {
        break L1;
       }
       if ($30) {
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        $35 = HEAP8[((2682912 + 116|0))>>0]|0;
        $36 = ($35<<24>>24)==(0);
        if ($36) {
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if ($38) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2682912|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break L1;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $43 = __THREW__; __THREW__ = 0;
        $44 = $43&1;
        if ($44) {
         break L1;
        }
        $45 = HEAP32[((2682912 + 80|0))>>2]|0;
        $46 = (($45) + 16|0);
        $47 = HEAP32[$46>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($47|0));
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break L1;
        }
        $50 = ($i|0)<(0);
        if ($50) {
         label = 17;
        } else {
         $51 = (($47) + 12|0);
         $52 = HEAP32[$51>>2]|0;
         $53 = ($52>>>0)>($i>>>0);
         if (!($53)) {
          label = 17;
         }
        }
        if ((label|0) == 17) {
         __THREW__ = 0;
         $54 = (invoke_i(132)|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($54|0));
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break L1;
         }
        }
        $59 = HEAP32[$47>>2]|0;
        $60 = (($47) + 16|0);
        $61 = (($59) + 92|0);
        $62 = HEAP32[$61>>2]|0;
        $63 = Math_imul($62, $i)|0;
        $64 = (($60) + ($63)|0);
        $65 = $64;
        $66 = $65;
        HEAP32[$66>>2] = $22;
        $67 = (($65) + 4)|0;
        $68 = $67;
        HEAP32[$68>>2] = $25;
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = HEAP8[((2682912 + 116|0))>>0]|0;
        $72 = ($71<<24>>24)==(0);
        if ($72) {
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $75 = __THREW__; __THREW__ = 0;
         $76 = $75&1;
         if ($76) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2682912|0));
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break L1;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         break L1;
        }
        $81 = HEAP32[((2682912 + 80|0))>>2]|0;
        $82 = (($81) + 16|0);
        $83 = HEAP32[$82>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($83|0));
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         break L1;
        }
        if ($50) {
         label = 28;
        } else {
         $86 = (($83) + 12|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = ($87>>>0)>($i>>>0);
         if (!($88)) {
          label = 28;
         }
        }
        if ((label|0) == 28) {
         __THREW__ = 0;
         $89 = (invoke_i(132)|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($89|0));
         $92 = __THREW__; __THREW__ = 0;
         $93 = $92&1;
         if ($93) {
          break L1;
         }
        }
        $94 = HEAP32[$83>>2]|0;
        $95 = (($83) + 16|0);
        $96 = (($94) + 92|0);
        $97 = HEAP32[$96>>2]|0;
        $98 = Math_imul($97, $i)|0;
        $99 = (($95) + ($98)|0);
        $100 = HEAP32[2995384>>2]|0;
        __THREW__ = 0;
        invoke_vii(1989,($99|0),($100|0));
        $101 = __THREW__; __THREW__ = 0;
        $102 = $101&1;
        if ($102) {
         break L1;
        }
       }
      } else {
       if ($15) {
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $305 = __THREW__; __THREW__ = 0;
        $306 = $305&1;
        if ($306) {
         break L1;
        }
        $307 = HEAP8[((2682912 + 116|0))>>0]|0;
        $308 = ($307<<24>>24)==(0);
        if ($308) {
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $309 = __THREW__; __THREW__ = 0;
         $310 = $309&1;
         if ($310) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $311 = __THREW__; __THREW__ = 0;
         $312 = $311&1;
         if ($312) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2682912|0));
         $313 = __THREW__; __THREW__ = 0;
         $314 = $313&1;
         if ($314) {
          break L1;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $315 = __THREW__; __THREW__ = 0;
        $316 = $315&1;
        if ($316) {
         break L1;
        }
        $317 = HEAP32[((2682912 + 80|0))>>2]|0;
        $318 = (($317) + 16|0);
        $319 = HEAP32[$318>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($319|0));
        $320 = __THREW__; __THREW__ = 0;
        $321 = $320&1;
        if ($321) {
         break L1;
        }
        $322 = ($i|0)<(0);
        if ($322) {
         label = 103;
        } else {
         $323 = (($319) + 12|0);
         $324 = HEAP32[$323>>2]|0;
         $325 = ($324>>>0)>($i>>>0);
         if (!($325)) {
          label = 103;
         }
        }
        if ((label|0) == 103) {
         __THREW__ = 0;
         $326 = (invoke_i(132)|0);
         $327 = __THREW__; __THREW__ = 0;
         $328 = $327&1;
         if ($328) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($326|0));
         $329 = __THREW__; __THREW__ = 0;
         $330 = $329&1;
         if ($330) {
          break L1;
         }
        }
        $331 = HEAP32[$319>>2]|0;
        $332 = (($319) + 16|0);
        $333 = (($331) + 92|0);
        $334 = HEAP32[$333>>2]|0;
        $335 = Math_imul($334, $i)|0;
        $336 = (($332) + ($335)|0);
        $337 = $336;
        $338 = $337;
        $339 = HEAP32[$338>>2]|0;
        $340 = (($337) + 4)|0;
        $341 = $340;
        $342 = HEAP32[$341>>2]|0;
        $343 = $4;
        $344 = $343;
        HEAP32[$344>>2] = $339;
        $345 = (($343) + 4)|0;
        $346 = $345;
        HEAP32[$346>>2] = $342;
        __THREW__ = 0;
        ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;
        $347 = (invoke_iii(1182,0,($tmpcast4$byval_copy|0))|0);
        $348 = __THREW__; __THREW__ = 0;
        $349 = $348&1;
        if ($349) {
         break L1;
        }
        if (!($347)) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $350 = __THREW__; __THREW__ = 0;
        $351 = $350&1;
        if ($351) {
         break L1;
        }
        $352 = HEAP8[((2682912 + 116|0))>>0]|0;
        $353 = ($352<<24>>24)==(0);
        if ($353) {
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $354 = __THREW__; __THREW__ = 0;
         $355 = $354&1;
         if ($355) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $356 = __THREW__; __THREW__ = 0;
         $357 = $356&1;
         if ($357) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2682912|0));
         $358 = __THREW__; __THREW__ = 0;
         $359 = $358&1;
         if ($359) {
          break L1;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $360 = __THREW__; __THREW__ = 0;
        $361 = $360&1;
        if ($361) {
         break L1;
        }
        $362 = HEAP32[((2682912 + 80|0))>>2]|0;
        $363 = (($362) + 16|0);
        $364 = HEAP32[$363>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($364|0));
        $365 = __THREW__; __THREW__ = 0;
        $366 = $365&1;
        if ($366) {
         break L1;
        }
        if ($322) {
         label = 116;
        } else {
         $367 = (($364) + 12|0);
         $368 = HEAP32[$367>>2]|0;
         $369 = ($368>>>0)>($i>>>0);
         if (!($369)) {
          label = 116;
         }
        }
        if ((label|0) == 116) {
         __THREW__ = 0;
         $370 = (invoke_i(132)|0);
         $371 = __THREW__; __THREW__ = 0;
         $372 = $371&1;
         if ($372) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($370|0));
         $373 = __THREW__; __THREW__ = 0;
         $374 = $373&1;
         if ($374) {
          break L1;
         }
        }
        $375 = HEAP32[$364>>2]|0;
        $376 = (($364) + 16|0);
        $377 = (($375) + 92|0);
        $378 = HEAP32[$377>>2]|0;
        $379 = Math_imul($378, $i)|0;
        $380 = (($376) + ($379)|0);
        $381 = HEAP32[2995408>>2]|0;
        __THREW__ = 0;
        invoke_vii(1989,($380|0),($381|0));
        $382 = __THREW__; __THREW__ = 0;
        $383 = $382&1;
        if ($383) {
         break L1;
        } else {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        break L1;
       }
       $105 = HEAP8[((2682912 + 116|0))>>0]|0;
       $106 = ($105<<24>>24)==(0);
       if ($106) {
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $109 = __THREW__; __THREW__ = 0;
        $110 = $109&1;
        if ($110) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2682912|0));
        $111 = __THREW__; __THREW__ = 0;
        $112 = $111&1;
        if ($112) {
         break L1;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $113 = __THREW__; __THREW__ = 0;
       $114 = $113&1;
       if ($114) {
        break L1;
       }
       $115 = HEAP32[((2682912 + 80|0))>>2]|0;
       $116 = (($115) + 16|0);
       $117 = HEAP32[$116>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($117|0));
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        break L1;
       }
       $120 = ($i|0)<(0);
       if ($120) {
        label = 41;
       } else {
        $121 = (($117) + 12|0);
        $122 = HEAP32[$121>>2]|0;
        $123 = ($122>>>0)>($i>>>0);
        if (!($123)) {
         label = 41;
        }
       }
       if ((label|0) == 41) {
        __THREW__ = 0;
        $124 = (invoke_i(132)|0);
        $125 = __THREW__; __THREW__ = 0;
        $126 = $125&1;
        if ($126) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3302,($124|0));
        $127 = __THREW__; __THREW__ = 0;
        $128 = $127&1;
        if ($128) {
         break L1;
        }
       }
       $129 = HEAP32[$117>>2]|0;
       $130 = (($117) + 16|0);
       $131 = (($129) + 92|0);
       $132 = HEAP32[$131>>2]|0;
       $133 = Math_imul($132, $i)|0;
       $134 = (($130) + ($133)|0);
       $135 = $134;
       $136 = $135;
       $137 = HEAP32[$136>>2]|0;
       $138 = (($135) + 4)|0;
       $139 = $138;
       $140 = HEAP32[$139>>2]|0;
       $141 = $1;
       $142 = $141;
       HEAP32[$142>>2] = $137;
       $143 = (($141) + 4)|0;
       $144 = $143;
       HEAP32[$144>>2] = $140;
       __THREW__ = 0;
       ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
       $145 = (invoke_iii(1182,0,($tmpcast4$byval_copy|0))|0);
       $146 = __THREW__; __THREW__ = 0;
       $147 = $146&1;
       if ($147) {
        break L1;
       }
       if ($145) {
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $148 = __THREW__; __THREW__ = 0;
        $149 = $148&1;
        if ($149) {
         break L1;
        }
        $150 = HEAP8[((2682912 + 116|0))>>0]|0;
        $151 = ($150<<24>>24)==(0);
        if ($151) {
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $152 = __THREW__; __THREW__ = 0;
         $153 = $152&1;
         if ($153) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $154 = __THREW__; __THREW__ = 0;
         $155 = $154&1;
         if ($155) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2682912|0));
         $156 = __THREW__; __THREW__ = 0;
         $157 = $156&1;
         if ($157) {
          break L1;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $158 = __THREW__; __THREW__ = 0;
        $159 = $158&1;
        if ($159) {
         break L1;
        }
        $160 = HEAP32[((2682912 + 80|0))>>2]|0;
        $161 = (($160) + 16|0);
        $162 = HEAP32[$161>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($162|0));
        $163 = __THREW__; __THREW__ = 0;
        $164 = $163&1;
        if ($164) {
         break L1;
        }
        if ($120) {
         label = 54;
        } else {
         $165 = (($162) + 12|0);
         $166 = HEAP32[$165>>2]|0;
         $167 = ($166>>>0)>($i>>>0);
         if (!($167)) {
          label = 54;
         }
        }
        if ((label|0) == 54) {
         __THREW__ = 0;
         $168 = (invoke_i(132)|0);
         $169 = __THREW__; __THREW__ = 0;
         $170 = $169&1;
         if ($170) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($168|0));
         $171 = __THREW__; __THREW__ = 0;
         $172 = $171&1;
         if ($172) {
          break L1;
         }
        }
        $173 = HEAP32[$162>>2]|0;
        $174 = (($162) + 16|0);
        $175 = (($173) + 92|0);
        $176 = HEAP32[$175>>2]|0;
        $177 = Math_imul($176, $i)|0;
        $178 = (($174) + ($177)|0);
        $179 = $hit;
        $180 = $179;
        $181 = HEAP32[$180>>2]|0;
        $182 = (($179) + 4)|0;
        $183 = $182;
        $184 = HEAP32[$183>>2]|0;
        $185 = $2;
        $186 = $185;
        HEAP32[$186>>2] = $181;
        $187 = (($185) + 4)|0;
        $188 = $187;
        HEAP32[$188>>2] = $184;
        $189 = $178;
        $190 = $189;
        $191 = HEAP32[$190>>2]|0;
        $192 = (($189) + 4)|0;
        $193 = $192;
        $194 = HEAP32[$193>>2]|0;
        $195 = $3;
        $196 = $195;
        HEAP32[$196>>2] = $191;
        $197 = (($195) + 4)|0;
        $198 = $197;
        HEAP32[$198>>2] = $194;
        __THREW__ = 0;
        ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
        ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
        $199 = (invoke_iiii(1292,0,($tmpcast1$byval_copy|0),($tmpcast4$byval_copy|0))|0);
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         break L1;
        }
        if ($199) {
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $202 = __THREW__; __THREW__ = 0;
         $203 = $202&1;
         if ($203) {
          break L1;
         }
         $204 = HEAP8[((2682912 + 116|0))>>0]|0;
         $205 = ($204<<24>>24)==(0);
         if ($205) {
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $206 = __THREW__; __THREW__ = 0;
          $207 = $206&1;
          if ($207) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $208 = __THREW__; __THREW__ = 0;
          $209 = $208&1;
          if ($209) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3843,(2682912|0));
          $210 = __THREW__; __THREW__ = 0;
          $211 = $210&1;
          if ($211) {
           break L1;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $212 = __THREW__; __THREW__ = 0;
         $213 = $212&1;
         if ($213) {
          break L1;
         }
         $214 = HEAP32[((2682912 + 80|0))>>2]|0;
         $215 = (($214) + 16|0);
         $216 = HEAP32[$215>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($216|0));
         $217 = __THREW__; __THREW__ = 0;
         $218 = $217&1;
         if ($218) {
          break L1;
         }
         if ($120) {
          label = 67;
         } else {
          $219 = (($216) + 12|0);
          $220 = HEAP32[$219>>2]|0;
          $221 = ($220>>>0)>($i>>>0);
          if (!($221)) {
           label = 67;
          }
         }
         if ((label|0) == 67) {
          __THREW__ = 0;
          $222 = (invoke_i(132)|0);
          $223 = __THREW__; __THREW__ = 0;
          $224 = $223&1;
          if ($224) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3302,($222|0));
          $225 = __THREW__; __THREW__ = 0;
          $226 = $225&1;
          if ($226) {
           break L1;
          }
         }
         $227 = HEAP32[$216>>2]|0;
         $228 = (($216) + 16|0);
         $229 = (($227) + 92|0);
         $230 = HEAP32[$229>>2]|0;
         $231 = Math_imul($230, $i)|0;
         $232 = (($228) + ($231)|0);
         $233 = HEAP32[2995392>>2]|0;
         __THREW__ = 0;
         invoke_vii(1989,($232|0),($233|0));
         $234 = __THREW__; __THREW__ = 0;
         $235 = $234&1;
         if ($235) {
          break L1;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $236 = __THREW__; __THREW__ = 0;
        $237 = $236&1;
        if ($237) {
         break L1;
        }
        $238 = HEAP8[((2682912 + 116|0))>>0]|0;
        $239 = ($238<<24>>24)==(0);
        if ($239) {
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $240 = __THREW__; __THREW__ = 0;
         $241 = $240&1;
         if ($241) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $242 = __THREW__; __THREW__ = 0;
         $243 = $242&1;
         if ($243) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2682912|0));
         $244 = __THREW__; __THREW__ = 0;
         $245 = $244&1;
         if ($245) {
          break L1;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $246 = __THREW__; __THREW__ = 0;
        $247 = $246&1;
        if ($247) {
         break L1;
        }
        $248 = HEAP32[((2682912 + 80|0))>>2]|0;
        $249 = (($248) + 16|0);
        $250 = HEAP32[$249>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($250|0));
        $251 = __THREW__; __THREW__ = 0;
        $252 = $251&1;
        if ($252) {
         break L1;
        }
        if ($120) {
         label = 79;
        } else {
         $253 = (($250) + 12|0);
         $254 = HEAP32[$253>>2]|0;
         $255 = ($254>>>0)>($i>>>0);
         if (!($255)) {
          label = 79;
         }
        }
        if ((label|0) == 79) {
         __THREW__ = 0;
         $256 = (invoke_i(132)|0);
         $257 = __THREW__; __THREW__ = 0;
         $258 = $257&1;
         if ($258) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($256|0));
         $259 = __THREW__; __THREW__ = 0;
         $260 = $259&1;
         if ($260) {
          break L1;
         }
        }
        $261 = HEAP32[$250>>2]|0;
        $262 = (($250) + 16|0);
        $263 = (($261) + 92|0);
        $264 = HEAP32[$263>>2]|0;
        $265 = Math_imul($264, $i)|0;
        $266 = (($262) + ($265)|0);
        $267 = HEAP32[2995400>>2]|0;
        __THREW__ = 0;
        invoke_vii(1989,($266|0),($267|0));
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $270 = __THREW__; __THREW__ = 0;
        $271 = $270&1;
        if ($271) {
         break L1;
        }
        $272 = HEAP8[((2682912 + 116|0))>>0]|0;
        $273 = ($272<<24>>24)==(0);
        if ($273) {
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $274 = __THREW__; __THREW__ = 0;
         $275 = $274&1;
         if ($275) {
          break L1;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $276 = __THREW__; __THREW__ = 0;
         $277 = $276&1;
         if ($277) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2682912|0));
         $278 = __THREW__; __THREW__ = 0;
         $279 = $278&1;
         if ($279) {
          break L1;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682912|0))|0);
        $280 = __THREW__; __THREW__ = 0;
        $281 = $280&1;
        if ($281) {
         break L1;
        }
        $282 = HEAP32[((2682912 + 80|0))>>2]|0;
        $283 = (($282) + 16|0);
        $284 = HEAP32[$283>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($284|0));
        $285 = __THREW__; __THREW__ = 0;
        $286 = $285&1;
        if ($286) {
         break L1;
        }
        if ($120) {
         label = 91;
        } else {
         $287 = (($284) + 12|0);
         $288 = HEAP32[$287>>2]|0;
         $289 = ($288>>>0)>($i>>>0);
         if (!($289)) {
          label = 91;
         }
        }
        if ((label|0) == 91) {
         __THREW__ = 0;
         $290 = (invoke_i(132)|0);
         $291 = __THREW__; __THREW__ = 0;
         $292 = $291&1;
         if ($292) {
          break L1;
         }
         __THREW__ = 0;
         invoke_vi(3302,($290|0));
         $293 = __THREW__; __THREW__ = 0;
         $294 = $293&1;
         if ($294) {
          break L1;
         }
        }
        $295 = HEAP32[$284>>2]|0;
        $296 = (($284) + 16|0);
        $297 = (($295) + 92|0);
        $298 = HEAP32[$297>>2]|0;
        $299 = Math_imul($298, $i)|0;
        $300 = (($296) + ($299)|0);
        $301 = $300;
        $302 = $301;
        HEAP32[$302>>2] = 0;
        $303 = (($301) + 4)|0;
        $304 = $303;
        HEAP32[$304>>2] = 0;
       }
      }
     } while(0);
     __THREW__ = 0;
     (invoke_ii(2996,(2682912|0))|0);
     $384 = __THREW__; __THREW__ = 0;
     $385 = $384&1;
     if (!($385)) {
      $386 = HEAP8[((2682912 + 116|0))>>0]|0;
      $387 = ($386<<24>>24)==(0);
      if ($387) {
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $388 = __THREW__; __THREW__ = 0;
       $389 = $388&1;
       if ($389) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2682912|0))|0);
       $390 = __THREW__; __THREW__ = 0;
       $391 = $390&1;
       if ($391) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2682912|0));
       $392 = __THREW__; __THREW__ = 0;
       $393 = $392&1;
       if ($393) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2682912|0))|0);
      $394 = __THREW__; __THREW__ = 0;
      $395 = $394&1;
      if (!($395)) {
       $396 = HEAP32[((2682912 + 80|0))>>2]|0;
       $397 = (($396) + 12|0);
       $398 = HEAP32[$397>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($398|0));
       $399 = __THREW__; __THREW__ = 0;
       $400 = $399&1;
       if (!($400)) {
        $401 = ($i|0)<(0);
        if ($401) {
         label = 128;
        } else {
         $402 = (($398) + 12|0);
         $403 = HEAP32[$402>>2]|0;
         $404 = ($403>>>0)>($i>>>0);
         if (!($404)) {
          label = 128;
         }
        }
        if ((label|0) == 128) {
         __THREW__ = 0;
         $405 = (invoke_i(132)|0);
         $406 = __THREW__; __THREW__ = 0;
         $407 = $406&1;
         if ($407) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($405|0));
         $408 = __THREW__; __THREW__ = 0;
         $409 = $408&1;
         if ($409) {
          break;
         }
        }
        $410 = HEAP32[$398>>2]|0;
        $411 = (($398) + 16|0);
        $412 = (($410) + 92|0);
        $413 = HEAP32[$412>>2]|0;
        $414 = Math_imul($413, $i)|0;
        $415 = (($411) + ($414)|0);
        $416 = $hit;
        $417 = $416;
        $418 = HEAP32[$417>>2]|0;
        $419 = (($416) + 4)|0;
        $420 = $419;
        $421 = HEAP32[$420>>2]|0;
        $422 = $5;
        $423 = $422;
        HEAP32[$423>>2] = $418;
        $424 = (($422) + 4)|0;
        $425 = $424;
        HEAP32[$425>>2] = $421;
        $426 = $415;
        $427 = $426;
        $428 = HEAP32[$427>>2]|0;
        $429 = (($426) + 4)|0;
        $430 = $429;
        $431 = HEAP32[$430>>2]|0;
        $432 = $6;
        $433 = $432;
        HEAP32[$433>>2] = $428;
        $434 = (($432) + 4)|0;
        $435 = $434;
        HEAP32[$435>>2] = $431;
        __THREW__ = 0;
        ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;
        ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
        $436 = (invoke_iiii(1292,0,($tmpcast1$byval_copy|0),($tmpcast4$byval_copy|0))|0);
        $437 = __THREW__; __THREW__ = 0;
        $438 = $437&1;
        if (!($438)) {
         do {
          if ($436) {
           $439 = $7;
           $440 = $439;
           HEAP32[$440>>2] = $418;
           $441 = (($439) + 4)|0;
           $442 = $441;
           HEAP32[$442>>2] = $421;
           __THREW__ = 0;
           ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
           $443 = (invoke_iii(1182,0,($tmpcast4$byval_copy|0))|0);
           $444 = __THREW__; __THREW__ = 0;
           $445 = $444&1;
           if ($445) {
            break L1;
           }
           if ($443) {
            $446 = HEAP32[2995416>>2]|0;
            __THREW__ = 0;
            invoke_vii(1989,($hit|0),($446|0));
            $447 = __THREW__; __THREW__ = 0;
            $448 = $447&1;
            if ($448) {
             break L1;
            }
           }
          } else {
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $449 = __THREW__; __THREW__ = 0;
           $450 = $449&1;
           if ($450) {
            break L1;
           }
           $451 = HEAP8[((2682912 + 116|0))>>0]|0;
           $452 = ($451<<24>>24)==(0);
           if ($452) {
            __THREW__ = 0;
            (invoke_ii(2996,(2682912|0))|0);
            $453 = __THREW__; __THREW__ = 0;
            $454 = $453&1;
            if ($454) {
             break L1;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2682912|0))|0);
            $455 = __THREW__; __THREW__ = 0;
            $456 = $455&1;
            if ($456) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3843,(2682912|0));
            $457 = __THREW__; __THREW__ = 0;
            $458 = $457&1;
            if ($458) {
             break L1;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $459 = __THREW__; __THREW__ = 0;
           $460 = $459&1;
           if ($460) {
            break L1;
           }
           $461 = HEAP32[((2682912 + 80|0))>>2]|0;
           $462 = (($461) + 12|0);
           $463 = HEAP32[$462>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($463|0));
           $464 = __THREW__; __THREW__ = 0;
           $465 = $464&1;
           if ($465) {
            break L1;
           }
           if ($401) {
            label = 144;
           } else {
            $466 = (($463) + 12|0);
            $467 = HEAP32[$466>>2]|0;
            $468 = ($467>>>0)>($i>>>0);
            if (!($468)) {
             label = 144;
            }
           }
           if ((label|0) == 144) {
            __THREW__ = 0;
            $469 = (invoke_i(132)|0);
            $470 = __THREW__; __THREW__ = 0;
            $471 = $470&1;
            if ($471) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3302,($469|0));
            $472 = __THREW__; __THREW__ = 0;
            $473 = $472&1;
            if ($473) {
             break L1;
            }
           }
           $474 = HEAP32[$463>>2]|0;
           $475 = (($463) + 16|0);
           $476 = (($474) + 92|0);
           $477 = HEAP32[$476>>2]|0;
           $478 = Math_imul($477, $i)|0;
           $479 = (($475) + ($478)|0);
           $480 = $479;
           $481 = $480;
           $482 = HEAP32[$481>>2]|0;
           $483 = (($480) + 4)|0;
           $484 = $483;
           $485 = HEAP32[$484>>2]|0;
           $486 = $8;
           $487 = $486;
           HEAP32[$487>>2] = $482;
           $488 = (($486) + 4)|0;
           $489 = $488;
           HEAP32[$489>>2] = $485;
           __THREW__ = 0;
           ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
           $490 = (invoke_iii(1182,0,($tmpcast4$byval_copy|0))|0);
           $491 = __THREW__; __THREW__ = 0;
           $492 = $491&1;
           if ($492) {
            break L1;
           }
           if ($490) {
            __THREW__ = 0;
            (invoke_ii(2996,(2682912|0))|0);
            $493 = __THREW__; __THREW__ = 0;
            $494 = $493&1;
            if ($494) {
             break L1;
            }
            $495 = HEAP8[((2682912 + 116|0))>>0]|0;
            $496 = ($495<<24>>24)==(0);
            if ($496) {
             __THREW__ = 0;
             (invoke_ii(2996,(2682912|0))|0);
             $497 = __THREW__; __THREW__ = 0;
             $498 = $497&1;
             if ($498) {
              break L1;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2682912|0))|0);
             $499 = __THREW__; __THREW__ = 0;
             $500 = $499&1;
             if ($500) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3843,(2682912|0));
             $501 = __THREW__; __THREW__ = 0;
             $502 = $501&1;
             if ($502) {
              break L1;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2682912|0))|0);
            $503 = __THREW__; __THREW__ = 0;
            $504 = $503&1;
            if ($504) {
             break L1;
            }
            $505 = HEAP32[((2682912 + 80|0))>>2]|0;
            $506 = (($505) + 12|0);
            $507 = HEAP32[$506>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($507|0));
            $508 = __THREW__; __THREW__ = 0;
            $509 = $508&1;
            if ($509) {
             break L1;
            }
            if ($401) {
             label = 157;
            } else {
             $510 = (($507) + 12|0);
             $511 = HEAP32[$510>>2]|0;
             $512 = ($511>>>0)>($i>>>0);
             if (!($512)) {
              label = 157;
             }
            }
            if ((label|0) == 157) {
             __THREW__ = 0;
             $513 = (invoke_i(132)|0);
             $514 = __THREW__; __THREW__ = 0;
             $515 = $514&1;
             if ($515) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3302,($513|0));
             $516 = __THREW__; __THREW__ = 0;
             $517 = $516&1;
             if ($517) {
              break L1;
             }
            }
            $518 = HEAP32[$507>>2]|0;
            $519 = (($507) + 16|0);
            $520 = (($518) + 92|0);
            $521 = HEAP32[$520>>2]|0;
            $522 = Math_imul($521, $i)|0;
            $523 = (($519) + ($522)|0);
            $524 = HEAP32[2995424>>2]|0;
            __THREW__ = 0;
            invoke_vii(1989,($523|0),($524|0));
            $525 = __THREW__; __THREW__ = 0;
            $526 = $525&1;
            if ($526) {
             break L1;
            }
           }
           $527 = $9;
           $528 = $527;
           HEAP32[$528>>2] = $418;
           $529 = (($527) + 4)|0;
           $530 = $529;
           HEAP32[$530>>2] = $421;
           __THREW__ = 0;
           ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
           $531 = (invoke_iii(1182,0,($tmpcast4$byval_copy|0))|0);
           $532 = __THREW__; __THREW__ = 0;
           $533 = $532&1;
           if ($533) {
            break L1;
           }
           if (!($531)) {
            break;
           }
           $534 = HEAP32[2995432>>2]|0;
           __THREW__ = 0;
           invoke_vii(1989,($hit|0),($534|0));
           $535 = __THREW__; __THREW__ = 0;
           $536 = $535&1;
           if ($536) {
            break L1;
           }
           $537 = HEAP32[2995440>>2]|0;
           __THREW__ = 0;
           invoke_vii(1989,($hit|0),($537|0));
           $538 = __THREW__; __THREW__ = 0;
           $539 = $538&1;
           if ($539) {
            break L1;
           }
          }
         } while(0);
         __THREW__ = 0;
         (invoke_ii(2996,(2682912|0))|0);
         $540 = __THREW__; __THREW__ = 0;
         $541 = $540&1;
         if (!($541)) {
          $542 = HEAP8[((2682912 + 116|0))>>0]|0;
          $543 = ($542<<24>>24)==(0);
          if ($543) {
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $544 = __THREW__; __THREW__ = 0;
           $545 = $544&1;
           if ($545) {
            break;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2682912|0))|0);
           $546 = __THREW__; __THREW__ = 0;
           $547 = $546&1;
           if ($547) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3843,(2682912|0));
           $548 = __THREW__; __THREW__ = 0;
           $549 = $548&1;
           if ($549) {
            break;
           }
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2682912|0))|0);
          $550 = __THREW__; __THREW__ = 0;
          $551 = $550&1;
          if (!($551)) {
           $552 = HEAP32[((2682912 + 80|0))>>2]|0;
           $553 = (($552) + 12|0);
           $554 = HEAP32[$553>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($554|0));
           $555 = __THREW__; __THREW__ = 0;
           $556 = $555&1;
           if (!($556)) {
            if (!($401)) {
             $557 = (($554) + 12|0);
             $558 = HEAP32[$557>>2]|0;
             $559 = ($558>>>0)>($i>>>0);
             if ($559) {
              $565 = HEAP32[$554>>2]|0;
              $566 = (($554) + 16|0);
              $567 = (($565) + 92|0);
              $568 = HEAP32[$567>>2]|0;
              $569 = Math_imul($568, $i)|0;
              $570 = (($566) + ($569)|0);
              $571 = $hit;
              $572 = $571;
              $573 = HEAP32[$572>>2]|0;
              $574 = (($571) + 4)|0;
              $575 = $574;
              $576 = HEAP32[$575>>2]|0;
              $577 = $570;
              $578 = $577;
              HEAP32[$578>>2] = $573;
              $579 = (($577) + 4)|0;
              $580 = $579;
              HEAP32[$580>>2] = $576;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
            __THREW__ = 0;
            $560 = (invoke_i(132)|0);
            $561 = __THREW__; __THREW__ = 0;
            $562 = $561&1;
            if (!($562)) {
             __THREW__ = 0;
             invoke_vi(3302,($560|0));
             $563 = __THREW__; __THREW__ = 0;
             $564 = $563&1;
             if (!($564)) {
              $565 = HEAP32[$554>>2]|0;
              $566 = (($554) + 16|0);
              $567 = (($565) + 92|0);
              $568 = HEAP32[$567>>2]|0;
              $569 = Math_imul($568, $i)|0;
              $570 = (($566) + ($569)|0);
              $571 = $hit;
              $572 = $571;
              $573 = HEAP32[$572>>2]|0;
              $574 = (($571) + 4)|0;
              $575 = $574;
              $576 = HEAP32[$575>>2]|0;
              $577 = $570;
              $578 = $577;
              HEAP32[$578>>2] = $573;
              $579 = (($577) + 4)|0;
              $580 = $579;
              HEAP32[$580>>2] = $576;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits53UnityEngine_UnityEngine_SendMouseEvents_HitInfoTraitsE6InvokeEPFvPvi47UnityEngine_UnityEngine_SendMouseEvents_HitInfoES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$2,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z43UnityEngine_UnityEngine_SliderState_m__ctorP35UnityEngine_UnityEngine_SliderState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683048);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z49UnityEngine_UnityEngine_StackTraceUtility_m__ctorP41UnityEngine_UnityEngine_StackTraceUtility($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683416);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_StackTraceUtility_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683464);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2684312|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[((2684312 + 80|0))>>2]|0;
     HEAP32[$18>>2] = $15;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z60UnityEngine_UnityEngine_StackTraceUtility_m_SetProjectFolderP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$folder) {
 $__this = $__this|0;
 $folder = $folder|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683512);
 __THREW__ = 0;
 (invoke_ii(2996,(2684312|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2684312 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2684312|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2684312|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2684312|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2684312|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2684312 + 80|0))>>2]|0;
    HEAP32[$14>>2] = $folder;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z61UnityEngine_UnityEngine_StackTraceUtility_m_ExtractStackTraceP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683560);
 __THREW__ = 0;
 (invoke_ii(2996,(2322024|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2322024|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viii(583,($2|0),1,1);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(1185,0,($2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3799,($7|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_iii(2730,(2184488|0),($7|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($12|0);
      }
     }
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z70UnityEngine_UnityEngine_StackTraceUtility_m_ExtractFormattedStackTraceP22mscorlib_System_ObjectP38mscorlib_System_Diagnostics_StackTrace($__this,$stackTrace) {
 $__this = $__this|0;
 $stackTrace = $stackTrace|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_1$0 = 0, $V_10 = 0, $V_6$0 = 0, $V_8$1$off0 = 0, $V_9$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_10 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683800);
 HEAP32[$V_10>>2] = 0;
 __THREW__ = 0;
 invoke_v(950);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2537888|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_ii(3469,(2537888|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vii(1910,($4|0),255);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $V_1$0 = 0;
      L6: while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($stackTrace|0));
       $258 = __THREW__; __THREW__ = 0;
       $259 = $258&1;
       if ($259) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       $260 = (invoke_iii(2729,(2321312|0),($stackTrace|0))|0);
       $261 = __THREW__; __THREW__ = 0;
       $262 = $261&1;
       if ($262) {
        label = 7;
        break;
       }
       $263 = ($V_1$0|0)<($260|0);
       if (!($263)) {
        label = 120;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($stackTrace|0));
       $264 = __THREW__; __THREW__ = 0;
       $265 = $264&1;
       if ($265) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       $15 = (invoke_iiii(1642,(2321360|0),($stackTrace|0),($V_1$0|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($15|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       $20 = (invoke_iii(2730,(2319784|0),($15|0))|0);
       $21 = __THREW__; __THREW__ = 0;
       $22 = $21&1;
       if ($22) {
        label = 7;
        break;
       }
       $23 = ($20|0)==(0|0);
       if (!($23)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if ($25) {
         label = 7;
         break;
        }
        __THREW__ = 0;
        $26 = (invoke_iii(2730,(2242504|0),($20|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if ($28) {
         label = 7;
         break;
        }
        $29 = ($26|0)==(0|0);
        if (!($29)) {
         __THREW__ = 0;
         invoke_vi(3799,($26|0));
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $32 = (invoke_iii(2730,(2238840|0),($26|0))|0);
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          label = 7;
          break;
         }
         $35 = ($32|0)==(0|0);
         do {
          if (!($35)) {
           __THREW__ = 0;
           invoke_vi(3799,($32|0));
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           $38 = (invoke_ii(1816,($32|0))|0);
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if ($40) {
            label = 7;
            break L6;
           }
           $41 = ($38|0)==(0);
           if ($41) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $42 = __THREW__; __THREW__ = 0;
           $43 = $42&1;
           if ($43) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($32|0))|0);
           $44 = __THREW__; __THREW__ = 0;
           $45 = $44&1;
           if ($45) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if ($47) {
            label = 7;
            break L6;
           }
           $48 = HEAP32[2996888>>2]|0;
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($48|0))|0);
           $49 = __THREW__; __THREW__ = 0;
           $50 = $49&1;
           if ($50) {
            label = 7;
            break L6;
           }
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3799,($26|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $53 = (invoke_iii(2730,(2233608|0),($26|0))|0);
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $56 = __THREW__; __THREW__ = 0;
         $57 = $56&1;
         if ($57) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($53|0))|0);
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if ($59) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          label = 7;
          break;
         }
         $62 = HEAP32[2996896>>2]|0;
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($62|0))|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($20|0));
         $65 = __THREW__; __THREW__ = 0;
         $66 = $65&1;
         if ($66) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $67 = (invoke_iii(2730,(2233608|0),($20|0))|0);
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($67|0))|0);
         $72 = __THREW__; __THREW__ = 0;
         $73 = $72&1;
         if ($73) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $74 = __THREW__; __THREW__ = 0;
         $75 = $74&1;
         if ($75) {
          label = 7;
          break;
         }
         $76 = HEAP32[2996904>>2]|0;
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($76|0))|0);
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($20|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $81 = (invoke_iii(2730,(2397136|0),($20|0))|0);
         $82 = __THREW__; __THREW__ = 0;
         $83 = $82&1;
         if ($83) {
          label = 7;
          break;
         }
         $84 = (($81) + 12|0);
         $V_6$0 = 0;$V_8$1$off0 = 1;
         while(1) {
          __THREW__ = 0;
          invoke_vi(3799,($81|0));
          $120 = __THREW__; __THREW__ = 0;
          $121 = $120&1;
          if ($121) {
           label = 6;
           break L6;
          }
          $122 = HEAP32[$84>>2]|0;
          $123 = ($V_6$0|0)<($122|0);
          if (!($123)) {
           break;
          }
          if (!($V_8$1$off0)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $85 = __THREW__; __THREW__ = 0;
           $86 = $85&1;
           if ($86) {
            label = 6;
            break L6;
           }
           $87 = HEAP32[2996912>>2]|0;
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($87|0))|0);
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            label = 6;
            break L6;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($81|0));
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           label = 6;
           break L6;
          }
          $92 = HEAP32[$84>>2]|0;
          $93 = ($V_6$0>>>0)<($92>>>0);
          if (!($93)) {
           __THREW__ = 0;
           $94 = (invoke_i(132)|0);
           $95 = __THREW__; __THREW__ = 0;
           $96 = $95&1;
           if ($96) {
            label = 6;
            break L6;
           }
           __THREW__ = 0;
           invoke_vi(3302,($94|0));
           $97 = __THREW__; __THREW__ = 0;
           $98 = $97&1;
           if ($98) {
            label = 6;
            break L6;
           }
          }
          $99 = HEAP32[$81>>2]|0;
          $100 = (($99) + 92|0);
          $101 = HEAP32[$100>>2]|0;
          $102 = Math_imul($101, $V_6$0)|0;
          $$sum = (($102) + 16)|0;
          $103 = (($81) + ($$sum)|0);
          $104 = HEAP32[$103>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($104|0));
          $105 = __THREW__; __THREW__ = 0;
          $106 = $105&1;
          if ($106) {
           label = 6;
           break L6;
          }
          __THREW__ = 0;
          $107 = (invoke_iii(2730,(2397472|0),($104|0))|0);
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           label = 6;
           break L6;
          }
          __THREW__ = 0;
          invoke_vi(3799,($107|0));
          $110 = __THREW__; __THREW__ = 0;
          $111 = $110&1;
          if ($111) {
           label = 6;
           break L6;
          }
          __THREW__ = 0;
          $112 = (invoke_iii(2730,(2233608|0),($107|0))|0);
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if ($114) {
           label = 6;
           break L6;
          }
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $115 = __THREW__; __THREW__ = 0;
          $116 = $115&1;
          if ($116) {
           label = 6;
           break L6;
          }
          __THREW__ = 0;
          (invoke_iii(989,($4|0),($112|0))|0);
          $117 = __THREW__; __THREW__ = 0;
          $118 = $117&1;
          if ($118) {
           label = 6;
           break L6;
          }
          $119 = (($V_6$0) + 1)|0;
          $V_6$0 = $119;$V_8$1$off0 = 0;
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $124 = __THREW__; __THREW__ = 0;
         $125 = $124&1;
         if ($125) {
          label = 7;
          break;
         }
         $126 = HEAP32[2996920>>2]|0;
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($126|0))|0);
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($15|0));
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         $131 = (invoke_iii(2730,(2319640|0),($15|0))|0);
         $132 = __THREW__; __THREW__ = 0;
         $133 = $132&1;
         if ($133) {
          label = 7;
          break;
         }
         $134 = ($131|0)==(0|0);
         do {
          if (!($134)) {
           __THREW__ = 0;
           invoke_vi(3799,($26|0));
           $135 = __THREW__; __THREW__ = 0;
           $136 = $135&1;
           if ($136) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           $137 = (invoke_iii(2730,(2233608|0),($26|0))|0);
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            label = 7;
            break L6;
           }
           $140 = HEAP32[2996928>>2]|0;
           __THREW__ = 0;
           $141 = (invoke_iiii(574,(0|0),($137|0),($140|0))|0);
           $142 = __THREW__; __THREW__ = 0;
           $143 = $142&1;
           if ($143) {
            label = 7;
            break L6;
           }
           if ($141) {
            __THREW__ = 0;
            invoke_vi(3799,($26|0));
            $144 = __THREW__; __THREW__ = 0;
            $145 = $144&1;
            if ($145) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            $146 = (invoke_iii(2730,(2238840|0),($26|0))|0);
            $147 = __THREW__; __THREW__ = 0;
            $148 = $147&1;
            if ($148) {
             label = 7;
             break L6;
            }
            $149 = HEAP32[2996936>>2]|0;
            __THREW__ = 0;
            $150 = (invoke_iiii(574,(0|0),($146|0),($149|0))|0);
            $151 = __THREW__; __THREW__ = 0;
            $152 = $151&1;
            if ($152) {
             label = 7;
             break L6;
            }
            if ($150) {
             break;
            }
           }
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $153 = __THREW__; __THREW__ = 0;
           $154 = $153&1;
           if ($154) {
            label = 7;
            break L6;
           }
           $155 = HEAP32[2996944>>2]|0;
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($155|0))|0);
           $156 = __THREW__; __THREW__ = 0;
           $157 = $156&1;
           if ($157) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2684312|0))|0);
           $158 = __THREW__; __THREW__ = 0;
           $159 = $158&1;
           if ($159) {
            label = 7;
            break L6;
           }
           $160 = HEAP8[((2684312 + 116|0))>>0]|0;
           $161 = ($160<<24>>24)==(0);
           if ($161) {
            __THREW__ = 0;
            (invoke_ii(2996,(2684312|0))|0);
            $162 = __THREW__; __THREW__ = 0;
            $163 = $162&1;
            if ($163) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2684312|0))|0);
            $164 = __THREW__; __THREW__ = 0;
            $165 = $164&1;
            if ($165) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            invoke_vi(3843,(2684312|0));
            $166 = __THREW__; __THREW__ = 0;
            $167 = $166&1;
            if ($167) {
             label = 7;
             break L6;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2684312|0))|0);
           $168 = __THREW__; __THREW__ = 0;
           $169 = $168&1;
           if ($169) {
            label = 7;
            break L6;
           }
           $170 = HEAP32[((2684312 + 80|0))>>2]|0;
           $171 = HEAP32[$170>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($131|0));
           $172 = __THREW__; __THREW__ = 0;
           $173 = $172&1;
           if ($173) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           $174 = (invoke_iii(635,($131|0),($171|0))|0);
           $175 = __THREW__; __THREW__ = 0;
           $176 = $175&1;
           if ($176) {
            label = 7;
            break L6;
           }
           if ($174) {
            __THREW__ = 0;
            (invoke_ii(2996,(2684312|0))|0);
            $177 = __THREW__; __THREW__ = 0;
            $178 = $177&1;
            if ($178) {
             label = 7;
             break L6;
            }
            $179 = HEAP8[((2684312 + 116|0))>>0]|0;
            $180 = ($179<<24>>24)==(0);
            if ($180) {
             __THREW__ = 0;
             (invoke_ii(2996,(2684312|0))|0);
             $181 = __THREW__; __THREW__ = 0;
             $182 = $181&1;
             if ($182) {
              label = 7;
              break L6;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2684312|0))|0);
             $183 = __THREW__; __THREW__ = 0;
             $184 = $183&1;
             if ($184) {
              label = 7;
              break L6;
             }
             __THREW__ = 0;
             invoke_vi(3843,(2684312|0));
             $185 = __THREW__; __THREW__ = 0;
             $186 = $185&1;
             if ($186) {
              label = 7;
              break L6;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2684312|0))|0);
            $187 = __THREW__; __THREW__ = 0;
            $188 = $187&1;
            if ($188) {
             label = 7;
             break L6;
            }
            $189 = HEAP32[((2684312 + 80|0))>>2]|0;
            $190 = HEAP32[$189>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($190|0));
            $191 = __THREW__; __THREW__ = 0;
            $192 = $191&1;
            if ($192) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            $193 = (invoke_ii(1816,($190|0))|0);
            $194 = __THREW__; __THREW__ = 0;
            $195 = $194&1;
            if ($195) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            invoke_vi(3799,($131|0));
            $196 = __THREW__; __THREW__ = 0;
            $197 = $196&1;
            if ($197) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            $198 = (invoke_ii(1816,($131|0))|0);
            $199 = __THREW__; __THREW__ = 0;
            $200 = $199&1;
            if ($200) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2684312|0))|0);
            $201 = __THREW__; __THREW__ = 0;
            $202 = $201&1;
            if ($202) {
             label = 7;
             break L6;
            }
            $203 = HEAP8[((2684312 + 116|0))>>0]|0;
            $204 = ($203<<24>>24)==(0);
            if ($204) {
             __THREW__ = 0;
             (invoke_ii(2996,(2684312|0))|0);
             $205 = __THREW__; __THREW__ = 0;
             $206 = $205&1;
             if ($206) {
              label = 7;
              break L6;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2684312|0))|0);
             $207 = __THREW__; __THREW__ = 0;
             $208 = $207&1;
             if ($208) {
              label = 7;
              break L6;
             }
             __THREW__ = 0;
             invoke_vi(3843,(2684312|0));
             $209 = __THREW__; __THREW__ = 0;
             $210 = $209&1;
             if ($210) {
              label = 7;
              break L6;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2684312|0))|0);
            $211 = __THREW__; __THREW__ = 0;
            $212 = $211&1;
            if ($212) {
             label = 7;
             break L6;
            }
            $213 = HEAP32[((2684312 + 80|0))>>2]|0;
            $214 = HEAP32[$213>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($214|0));
            $215 = __THREW__; __THREW__ = 0;
            $216 = $215&1;
            if ($216) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            $217 = (invoke_ii(1816,($214|0))|0);
            $218 = __THREW__; __THREW__ = 0;
            $219 = $218&1;
            if ($219) {
             label = 7;
             break L6;
            }
            __THREW__ = 0;
            invoke_vi(3799,($131|0));
            $220 = __THREW__; __THREW__ = 0;
            $221 = $220&1;
            if ($221) {
             label = 7;
             break L6;
            }
            $222 = (($198) - ($217))|0;
            __THREW__ = 0;
            $223 = (invoke_iiii(528,($131|0),($193|0),($222|0))|0);
            $224 = __THREW__; __THREW__ = 0;
            $225 = $224&1;
            if ($225) {
             label = 7;
             break L6;
            } else {
             $V_9$0 = $223;
            }
           } else {
            $V_9$0 = $131;
           }
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $226 = __THREW__; __THREW__ = 0;
           $227 = $226&1;
           if ($227) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($V_9$0|0))|0);
           $228 = __THREW__; __THREW__ = 0;
           $229 = $228&1;
           if ($229) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $230 = __THREW__; __THREW__ = 0;
           $231 = $230&1;
           if ($231) {
            label = 7;
            break L6;
           }
           $232 = HEAP32[2996952>>2]|0;
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($232|0))|0);
           $233 = __THREW__; __THREW__ = 0;
           $234 = $233&1;
           if ($234) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           invoke_vi(3799,($15|0));
           $235 = __THREW__; __THREW__ = 0;
           $236 = $235&1;
           if ($236) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           $237 = (invoke_iii(2729,(2319592|0),($15|0))|0);
           $238 = __THREW__; __THREW__ = 0;
           $239 = $238&1;
           if ($239) {
            label = 7;
            break L6;
           }
           HEAP32[$V_10>>2] = $237;
           __THREW__ = 0;
           $240 = (invoke_ii(1791,($V_10|0))|0);
           $241 = __THREW__; __THREW__ = 0;
           $242 = $241&1;
           if ($242) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $243 = __THREW__; __THREW__ = 0;
           $244 = $243&1;
           if ($244) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($240|0))|0);
           $245 = __THREW__; __THREW__ = 0;
           $246 = $245&1;
           if ($246) {
            label = 7;
            break L6;
           }
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $247 = __THREW__; __THREW__ = 0;
           $248 = $247&1;
           if ($248) {
            label = 7;
            break L6;
           }
           $249 = HEAP32[2996960>>2]|0;
           __THREW__ = 0;
           (invoke_iii(989,($4|0),($249|0))|0);
           $250 = __THREW__; __THREW__ = 0;
           $251 = $250&1;
           if ($251) {
            label = 7;
            break L6;
           }
          }
         } while(0);
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $252 = __THREW__; __THREW__ = 0;
         $253 = $252&1;
         if ($253) {
          label = 7;
          break;
         }
         $254 = HEAP32[2996968>>2]|0;
         __THREW__ = 0;
         (invoke_iii(989,($4|0),($254|0))|0);
         $255 = __THREW__; __THREW__ = 0;
         $256 = $255&1;
         if ($256) {
          label = 7;
          break;
         }
        }
       }
       $257 = (($V_1$0) + 1)|0;
       $V_1$0 = $257;
      }
      if ((label|0) == 6) {
       $9 = ___cxa_find_matching_catch()|0;
       $10 = tempRet0;
       $lpad$phi$index = $9;$lpad$phi$index3 = $10;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 7) {
       $11 = ___cxa_find_matching_catch()|0;
       $12 = tempRet0;
       $lpad$phi$index = $11;$lpad$phi$index3 = $12;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 120) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $266 = __THREW__; __THREW__ = 0;
       $267 = $266&1;
       if ($267) {
        break;
       }
       __THREW__ = 0;
       $268 = (invoke_iii(2730,(2535432|0),($4|0))|0);
       $269 = __THREW__; __THREW__ = 0;
       $270 = $269&1;
       if ($270) {
        break;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($268|0);
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z66UnityEngine_UnityEngine_StackTraceUtility_m_IsSystemStacktraceTypeP22mscorlib_System_ObjectS0_($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B7_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683608);
 __THREW__ = 0;
 invoke_v(951);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2774,($name|0),(2191608|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      $9 = HEAP32[2995640>>2]|0;
      __THREW__ = 0;
      $10 = (invoke_iii(635,($4|0),($9|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       if ($10) {
        $G_B7_0$0 = 1;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($G_B7_0$0|0);
       }
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        $17 = HEAP32[2995648>>2]|0;
        __THREW__ = 0;
        $18 = (invoke_iii(635,($4|0),($17|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         if ($18) {
          $G_B7_0$0 = 1;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($G_B7_0$0|0);
         }
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          $23 = HEAP32[2995656>>2]|0;
          __THREW__ = 0;
          $24 = (invoke_iii(635,($4|0),($23|0))|0);
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           if ($24) {
            $G_B7_0$0 = 1;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($G_B7_0$0|0);
           }
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $27 = __THREW__; __THREW__ = 0;
           $28 = $27&1;
           if (!($28)) {
            $29 = HEAP32[2995664>>2]|0;
            __THREW__ = 0;
            $30 = (invoke_iii(635,($4|0),($29|0))|0);
            $31 = __THREW__; __THREW__ = 0;
            $32 = $31&1;
            if (!($32)) {
             if ($30) {
              $G_B7_0$0 = 1;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($G_B7_0$0|0);
             }
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $33 = __THREW__; __THREW__ = 0;
             $34 = $33&1;
             if (!($34)) {
              $35 = HEAP32[2995672>>2]|0;
              __THREW__ = 0;
              $36 = (invoke_iii(635,($4|0),($35|0))|0);
              $37 = __THREW__; __THREW__ = 0;
              $38 = $37&1;
              if (!($38)) {
               if ($36) {
                $G_B7_0$0 = 1;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($G_B7_0$0|0);
               }
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $39 = __THREW__; __THREW__ = 0;
               $40 = $39&1;
               if (!($40)) {
                $41 = HEAP32[2995680>>2]|0;
                __THREW__ = 0;
                $42 = (invoke_iii(635,($4|0),($41|0))|0);
                $43 = __THREW__; __THREW__ = 0;
                $44 = $43&1;
                if ($44) {
                 break;
                } else {
                 $G_B7_0$0 = $42;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($G_B7_0$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __Z70UnityEngine_UnityEngine_StackTraceUtility_m_ExtractStringFromExceptionP22mscorlib_System_ObjectS0_($__this,$exception) {
 $__this = $__this|0;
 $exception = $exception|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683656);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 __THREW__ = 0;
 invoke_v(952);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2191608 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3843,(2191608|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     $16 = HEAP32[((2191608 + 80|0))>>2]|0;
     $17 = HEAP32[$16>>2]|0;
     HEAP32[$V_0>>2] = $17;
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      $20 = HEAP8[((2191608 + 116|0))>>0]|0;
      $21 = ($20<<24>>24)==(0);
      if ($21) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if ($23) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2191608|0));
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $28 = __THREW__; __THREW__ = 0;
      $29 = $28&1;
      if (!($29)) {
       $30 = HEAP32[((2191608 + 80|0))>>2]|0;
       $31 = HEAP32[$30>>2]|0;
       HEAP32[$V_1>>2] = $31;
       __THREW__ = 0;
       invoke_viiii(206,0,($exception|0),($V_0|0),($V_1|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if (!($33)) {
        $34 = HEAP32[$V_0>>2]|0;
        $35 = HEAP32[2995880>>2]|0;
        $36 = HEAP32[$V_1>>2]|0;
        __THREW__ = 0;
        $37 = (invoke_iiiii(101,(0|0),($34|0),($35|0),($36|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($37|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z78UnityEngine_UnityEngine_StackTraceUtility_m_ExtractStringFromExceptionInternalP22mscorlib_System_ObjectS0_PP22mscorlib_System_StringS3_($__this,$exceptiono,$message,$stackTrace) {
 $__this = $__this|0;
 $exceptiono = $exceptiono|0;
 $message = $message|0;
 $stackTrace = $stackTrace|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $G_B7_0$0 = 0, $V_0$023 = 0, $V_2$0 = 0, $V_2$1 = 0, $V_2$222 = 0, $V_3$0 = 0, $V_4$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683704);
 __THREW__ = 0;
 invoke_v(953);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($exceptiono|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560072|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560072|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[2995896>>2]|0;
    __THREW__ = 0;
    invoke_vii(1924,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3844,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2246120|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    $19 = (invoke_iii(2735,($exceptiono|0),(2246120|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = ($19|0)==(0|0);
     if ($22) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      $25 = (invoke_ii(3469,(2560072|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      $28 = HEAP32[2995904>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($25|0),($28|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3844,($25|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($19|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      __THREW__ = 0;
      $35 = (invoke_iii(2730,(2244728|0),($19|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if (!($37)) {
       $38 = ($35|0)==(0|0);
       if ($38) {
        $G_B7_0$0 = 512;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($19|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         break;
        }
        __THREW__ = 0;
        $41 = (invoke_iii(2730,(2244728|0),($19|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($41|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if ($45) {
         break;
        }
        __THREW__ = 0;
        $46 = (invoke_ii(1816,($41|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         break;
        }
        $49 = $46 << 1;
        $G_B7_0$0 = $49;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2537888|0))|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if (!($51)) {
        __THREW__ = 0;
        $52 = (invoke_ii(3469,(2537888|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if (!($54)) {
         __THREW__ = 0;
         invoke_vii(1910,($52|0),($G_B7_0$0|0));
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if (!($56)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2191608|0))|0);
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if (!($58)) {
           $59 = HEAP8[((2191608 + 116|0))>>0]|0;
           $60 = ($59<<24>>24)==(0);
           if ($60) {
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if ($62) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $63 = __THREW__; __THREW__ = 0;
            $64 = $63&1;
            if ($64) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3843,(2191608|0));
            $65 = __THREW__; __THREW__ = 0;
            $66 = $65&1;
            if ($66) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2191608|0))|0);
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if (!($68)) {
            $69 = HEAP32[((2191608 + 80|0))>>2]|0;
            $70 = HEAP32[$69>>2]|0;
            HEAP32[$message>>2] = $70;
            __THREW__ = 0;
            (invoke_ii(2996,(2191608|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if (!($72)) {
             $73 = HEAP8[((2191608 + 116|0))>>0]|0;
             $74 = ($73<<24>>24)==(0);
             if ($74) {
              __THREW__ = 0;
              (invoke_ii(2996,(2191608|0))|0);
              $75 = __THREW__; __THREW__ = 0;
              $76 = $75&1;
              if ($76) {
               break;
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2191608|0))|0);
              $77 = __THREW__; __THREW__ = 0;
              $78 = $77&1;
              if ($78) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3843,(2191608|0));
              $79 = __THREW__; __THREW__ = 0;
              $80 = $79&1;
              if ($80) {
               break;
              }
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2191608|0))|0);
             $81 = __THREW__; __THREW__ = 0;
             $82 = $81&1;
             if (!($82)) {
              $83 = HEAP32[((2191608 + 80|0))>>2]|0;
              $84 = HEAP32[$83>>2]|0;
              $V_0$023 = $19;$V_2$222 = $84;
              while(1) {
               __THREW__ = 0;
               invoke_vi(3799,($V_2$222|0));
               $173 = __THREW__; __THREW__ = 0;
               $174 = $173&1;
               if ($174) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               $85 = (invoke_ii(1816,($V_2$222|0))|0);
               $86 = __THREW__; __THREW__ = 0;
               $87 = $86&1;
               if ($87) {
                label = 3;
                break;
               }
               $88 = ($85|0)==(0);
               if ($88) {
                __THREW__ = 0;
                invoke_vi(3799,($V_0$023|0));
                $89 = __THREW__; __THREW__ = 0;
                $90 = $89&1;
                if ($90) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                $91 = (invoke_iii(2730,(2244728|0),($V_0$023|0))|0);
                $92 = __THREW__; __THREW__ = 0;
                $93 = $92&1;
                if ($93) {
                 label = 3;
                 break;
                }
                $V_2$0 = $91;
               } else {
                __THREW__ = 0;
                invoke_vi(3799,($V_0$023|0));
                $94 = __THREW__; __THREW__ = 0;
                $95 = $94&1;
                if ($95) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                $96 = (invoke_iii(2730,(2244728|0),($V_0$023|0))|0);
                $97 = __THREW__; __THREW__ = 0;
                $98 = $97&1;
                if ($98) {
                 label = 3;
                 break;
                }
                $99 = HEAP32[2995912>>2]|0;
                __THREW__ = 0;
                $100 = (invoke_iiiii(101,(0|0),($96|0),($99|0),($V_2$222|0))|0);
                $101 = __THREW__; __THREW__ = 0;
                $102 = $101&1;
                if ($102) {
                 label = 3;
                 break;
                } else {
                 $V_2$0 = $100;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($V_0$023|0));
               $103 = __THREW__; __THREW__ = 0;
               $104 = $103&1;
               if ($104) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               $105 = (invoke_iii(2730,(2244536|0),($V_0$023|0))|0);
               $106 = __THREW__; __THREW__ = 0;
               $107 = $106&1;
               if ($107) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($105|0));
               $108 = __THREW__; __THREW__ = 0;
               $109 = $108&1;
               if ($109) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               $110 = (invoke_iii(2730,(2233608|0),($105|0))|0);
               $111 = __THREW__; __THREW__ = 0;
               $112 = $111&1;
               if ($112) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2191608|0))|0);
               $113 = __THREW__; __THREW__ = 0;
               $114 = $113&1;
               if ($114) {
                label = 3;
                break;
               }
               $115 = HEAP8[((2191608 + 116|0))>>0]|0;
               $116 = ($115<<24>>24)==(0);
               if ($116) {
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $117 = __THREW__; __THREW__ = 0;
                $118 = $117&1;
                if ($118) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $119 = __THREW__; __THREW__ = 0;
                $120 = $119&1;
                if ($120) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3843,(2191608|0));
                $121 = __THREW__; __THREW__ = 0;
                $122 = $121&1;
                if ($122) {
                 label = 3;
                 break;
                }
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2191608|0))|0);
               $123 = __THREW__; __THREW__ = 0;
               $124 = $123&1;
               if ($124) {
                label = 3;
                break;
               }
               $125 = HEAP32[((2191608 + 80|0))>>2]|0;
               $126 = HEAP32[$125>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($V_0$023|0));
               $127 = __THREW__; __THREW__ = 0;
               $128 = $127&1;
               if ($128) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               $129 = (invoke_iii(2730,(2244584|0),($V_0$023|0))|0);
               $130 = __THREW__; __THREW__ = 0;
               $131 = $130&1;
               if ($131) {
                label = 3;
                break;
               }
               $132 = ($129|0)==(0|0);
               if ($132) {
                $V_4$0 = $126;
               } else {
                __THREW__ = 0;
                invoke_vi(3799,($V_0$023|0));
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                $135 = (invoke_iii(2730,(2244584|0),($V_0$023|0))|0);
                $136 = __THREW__; __THREW__ = 0;
                $137 = $136&1;
                if ($137) {
                 label = 3;
                 break;
                }
                $V_4$0 = $135;
               }
               __THREW__ = 0;
               invoke_vi(3799,($V_4$0|0));
               $138 = __THREW__; __THREW__ = 0;
               $139 = $138&1;
               if ($139) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               $140 = (invoke_ii(1812,($V_4$0|0))|0);
               $141 = __THREW__; __THREW__ = 0;
               $142 = $141&1;
               if ($142) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($140|0));
               $143 = __THREW__; __THREW__ = 0;
               $144 = $143&1;
               if ($144) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               $145 = (invoke_ii(1816,($140|0))|0);
               $146 = __THREW__; __THREW__ = 0;
               $147 = $146&1;
               if ($147) {
                label = 3;
                break;
               }
               $148 = ($145|0)==(0);
               if ($148) {
                $V_3$0 = $110;
               } else {
                $149 = HEAP32[2995920>>2]|0;
                __THREW__ = 0;
                $150 = (invoke_iiii(562,(0|0),($110|0),($149|0))|0);
                $151 = __THREW__; __THREW__ = 0;
                $152 = $151&1;
                if ($152) {
                 label = 3;
                 break;
                }
                __THREW__ = 0;
                $153 = (invoke_iiii(562,(0|0),($150|0),($V_4$0|0))|0);
                $154 = __THREW__; __THREW__ = 0;
                $155 = $154&1;
                if ($155) {
                 label = 3;
                 break;
                } else {
                 $V_3$0 = $153;
                }
               }
               HEAP32[$message>>2] = $V_3$0;
               __THREW__ = 0;
               invoke_vi(3799,($V_0$023|0));
               $156 = __THREW__; __THREW__ = 0;
               $157 = $156&1;
               if ($157) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               $158 = (invoke_iii(2730,(2244296|0),($V_0$023|0))|0);
               $159 = __THREW__; __THREW__ = 0;
               $160 = $159&1;
               if ($160) {
                label = 3;
                break;
               }
               $161 = ($158|0)==(0|0);
               if ($161) {
                $V_2$1 = $V_2$0;
               } else {
                $162 = HEAP32[2995928>>2]|0;
                $163 = HEAP32[2995936>>2]|0;
                __THREW__ = 0;
                $164 = (invoke_iiiiii(89,(0|0),($162|0),($V_3$0|0),($163|0),($V_2$0|0))|0);
                $165 = __THREW__; __THREW__ = 0;
                $166 = $165&1;
                if ($166) {
                 label = 3;
                 break;
                } else {
                 $V_2$1 = $164;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($V_0$023|0));
               $167 = __THREW__; __THREW__ = 0;
               $168 = $167&1;
               if ($168) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               $169 = (invoke_iii(2730,(2244296|0),($V_0$023|0))|0);
               $170 = __THREW__; __THREW__ = 0;
               $171 = $170&1;
               if ($171) {
                label = 3;
                break;
               }
               $172 = ($169|0)==(0|0);
               if ($172) {
                break;
               } else {
                $V_0$023 = $169;$V_2$222 = $V_2$1;
               }
              }
              if ((label|0) == 3) {
               $3 = ___cxa_find_matching_catch()|0;
               $4 = tempRet0;
               $lpad$phi$index = $3;$lpad$phi$index2 = $4;
               __ZN16StackTraceSentryD2Ev(0);
               ___resumeException($lpad$phi$index|0);
               // unreachable;
              }
              $175 = HEAP32[2995944>>2]|0;
              __THREW__ = 0;
              $176 = (invoke_iiii(562,(0|0),($V_2$1|0),($175|0))|0);
              $177 = __THREW__; __THREW__ = 0;
              $178 = $177&1;
              if (!($178)) {
               __THREW__ = 0;
               invoke_vi(3799,($52|0));
               $179 = __THREW__; __THREW__ = 0;
               $180 = $179&1;
               if (!($180)) {
                __THREW__ = 0;
                (invoke_iii(989,($52|0),($176|0))|0);
                $181 = __THREW__; __THREW__ = 0;
                $182 = $181&1;
                if ($182) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2322024|0))|0);
                $183 = __THREW__; __THREW__ = 0;
                $184 = $183&1;
                if ($184) {
                 break;
                }
                __THREW__ = 0;
                $185 = (invoke_ii(3469,(2322024|0))|0);
                $186 = __THREW__; __THREW__ = 0;
                $187 = $186&1;
                if ($187) {
                 break;
                }
                __THREW__ = 0;
                invoke_viii(583,($185|0),1,1);
                $188 = __THREW__; __THREW__ = 0;
                $189 = $188&1;
                if ($189) {
                 break;
                }
                __THREW__ = 0;
                $190 = (invoke_iii(1185,0,($185|0))|0);
                $191 = __THREW__; __THREW__ = 0;
                $192 = $191&1;
                if ($192) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($52|0));
                $193 = __THREW__; __THREW__ = 0;
                $194 = $193&1;
                if ($194) {
                 break;
                }
                __THREW__ = 0;
                (invoke_iii(989,($52|0),($190|0))|0);
                $195 = __THREW__; __THREW__ = 0;
                $196 = $195&1;
                if ($196) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($52|0));
                $197 = __THREW__; __THREW__ = 0;
                $198 = $197&1;
                if ($198) {
                 break;
                }
                __THREW__ = 0;
                $199 = (invoke_iii(2730,(2535432|0),($52|0))|0);
                $200 = __THREW__; __THREW__ = 0;
                $201 = $200&1;
                if ($201) {
                 break;
                }
                HEAP32[$stackTrace>>2] = $199;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception10836($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z65UnityEngine_UnityEngine_StackTraceUtility_m_PostprocessStacktraceP22mscorlib_System_ObjectP22mscorlib_System_Stringb($__this,$oldString,$stripEngineInternalInformation) {
 $__this = $__this|0;
 $oldString = $oldString|0;
 $stripEngineInternalInformation = $stripEngineInternalInformation|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $V_3$0 = 0, $V_4$0 = 0, $V_4$1 = 0, $V_4$2 = 0, $V_4$3 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2683752);
 __THREW__ = 0;
 invoke_v(954);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($oldString|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $11 = HEAP8[((2191608 + 116|0))>>0]|0;
    $12 = ($11<<24>>24)==(0);
    if ($12) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3843,(2191608|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = HEAP32[((2191608 + 80|0))>>2]|0;
    $22 = HEAP32[$21>>2]|0;
    $$0 = $22;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1168808|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if (!($24)) {
    __THREW__ = 0;
    $25 = (invoke_iii(2773,(1168808|0),1)|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     __THREW__ = 0;
     invoke_vi(3799,($25|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = (($25) + 12|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==(0);
      if ($32) {
       __THREW__ = 0;
       $33 = (invoke_i(132)|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($33|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if ($37) {
        break;
       }
      }
      $38 = (($25) + 16|0);
      HEAP16[$38>>1] = 10;
      __THREW__ = 0;
      invoke_vi(3799,($oldString|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       $41 = (invoke_iii(622,($oldString|0),($25|0))|0);
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if (!($43)) {
        __THREW__ = 0;
        invoke_vi(3799,($oldString|0));
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         __THREW__ = 0;
         $46 = (invoke_ii(1816,($oldString|0))|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if (!($48)) {
          __THREW__ = 0;
          (invoke_ii(2996,(2537888|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if (!($50)) {
           __THREW__ = 0;
           $51 = (invoke_ii(3469,(2537888|0))|0);
           $52 = __THREW__; __THREW__ = 0;
           $53 = $52&1;
           if (!($53)) {
            __THREW__ = 0;
            invoke_vii(1910,($51|0),($46|0));
            $54 = __THREW__; __THREW__ = 0;
            $55 = $54&1;
            if (!($55)) {
             $56 = (($41) + 12|0);
             $57 = (($41) + 16|0);
             $V_2$0 = 0;
             while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($41|0));
              $93 = __THREW__; __THREW__ = 0;
              $94 = $93&1;
              if ($94) {
               label = 4;
               break;
              }
              $95 = HEAP32[$56>>2]|0;
              $96 = ($V_2$0|0)<($95|0);
              if (!($96)) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($41|0));
              $97 = __THREW__; __THREW__ = 0;
              $98 = $97&1;
              if ($98) {
               label = 4;
               break;
              }
              $58 = HEAP32[$56>>2]|0;
              $59 = ($V_2$0>>>0)<($58>>>0);
              if (!($59)) {
               __THREW__ = 0;
               $60 = (invoke_i(132)|0);
               $61 = __THREW__; __THREW__ = 0;
               $62 = $61&1;
               if ($62) {
                label = 4;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($60|0));
               $63 = __THREW__; __THREW__ = 0;
               $64 = $63&1;
               if ($64) {
                label = 4;
                break;
               }
              }
              $65 = HEAP32[$41>>2]|0;
              $66 = (($65) + 92|0);
              $67 = HEAP32[$66>>2]|0;
              $68 = Math_imul($67, $V_2$0)|0;
              $69 = (($57) + ($68)|0);
              $70 = HEAP32[$69>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($70|0));
              $71 = __THREW__; __THREW__ = 0;
              $72 = $71&1;
              if ($72) {
               label = 4;
               break;
              }
              __THREW__ = 0;
              $73 = (invoke_ii(1812,($70|0))|0);
              $74 = __THREW__; __THREW__ = 0;
              $75 = $74&1;
              if ($75) {
               label = 4;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($41|0));
              $76 = __THREW__; __THREW__ = 0;
              $77 = $76&1;
              if ($77) {
               label = 4;
               break;
              }
              $78 = HEAP32[$56>>2]|0;
              $79 = ($V_2$0>>>0)<($78>>>0);
              if (!($79)) {
               __THREW__ = 0;
               $80 = (invoke_i(132)|0);
               $81 = __THREW__; __THREW__ = 0;
               $82 = $81&1;
               if ($82) {
                label = 4;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($80|0));
               $83 = __THREW__; __THREW__ = 0;
               $84 = $83&1;
               if ($84) {
                label = 4;
                break;
               }
              }
              __THREW__ = 0;
              invoke_vii(3492,($41|0),($73|0));
              $85 = __THREW__; __THREW__ = 0;
              $86 = $85&1;
              if ($86) {
               label = 4;
               break;
              }
              $87 = HEAP32[$41>>2]|0;
              $88 = (($87) + 92|0);
              $89 = HEAP32[$88>>2]|0;
              $90 = Math_imul($89, $V_2$0)|0;
              $91 = (($57) + ($90)|0);
              HEAP32[$91>>2] = $73;
              $92 = (($V_2$0) + 1)|0;
              $V_2$0 = $92;
             }
             if ((label|0) == 4) {
              $5 = ___cxa_find_matching_catch()|0;
              $6 = tempRet0;
              $lpad$phi$index = $5;$lpad$phi$index3 = $6;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
             $V_3$0 = 0;
             L49: while(1) {
              __THREW__ = 0;
              invoke_vi(3799,($41|0));
              $336 = __THREW__; __THREW__ = 0;
              $337 = $336&1;
              if ($337) {
               label = 3;
               break;
              }
              $338 = HEAP32[$56>>2]|0;
              $339 = ($V_3$0|0)<($338|0);
              if (!($339)) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3799,($41|0));
              $340 = __THREW__; __THREW__ = 0;
              $341 = $340&1;
              if ($341) {
               label = 3;
               break;
              }
              $99 = HEAP32[$56>>2]|0;
              $100 = ($V_3$0>>>0)<($99>>>0);
              if (!($100)) {
               __THREW__ = 0;
               $101 = (invoke_i(132)|0);
               $102 = __THREW__; __THREW__ = 0;
               $103 = $102&1;
               if ($103) {
                label = 3;
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($101|0));
               $104 = __THREW__; __THREW__ = 0;
               $105 = $104&1;
               if ($105) {
                label = 3;
                break;
               }
              }
              $106 = HEAP32[$41>>2]|0;
              $107 = (($106) + 92|0);
              $108 = HEAP32[$107>>2]|0;
              $109 = Math_imul($108, $V_3$0)|0;
              $110 = (($57) + ($109)|0);
              $111 = HEAP32[$110>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($111|0));
              $112 = __THREW__; __THREW__ = 0;
              $113 = $112&1;
              if ($113) {
               label = 3;
               break;
              }
              __THREW__ = 0;
              $114 = (invoke_ii(1816,($111|0))|0);
              $115 = __THREW__; __THREW__ = 0;
              $116 = $115&1;
              if ($116) {
               label = 3;
               break;
              }
              $117 = ($114|0)==(0);
              L60: do {
               if (!($117)) {
                __THREW__ = 0;
                invoke_vi(3799,($111|0));
                $118 = __THREW__; __THREW__ = 0;
                $119 = $118&1;
                if ($119) {
                 label = 3;
                 break L49;
                }
                __THREW__ = 0;
                $120 = (invoke_iii(621,($111|0),0)|0);
                $121 = __THREW__; __THREW__ = 0;
                $122 = $121&1;
                if ($122) {
                 label = 3;
                 break L49;
                }
                $123 = ($120<<16>>16)==(10);
                if ($123) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($111|0));
                $124 = __THREW__; __THREW__ = 0;
                $125 = $124&1;
                if ($125) {
                 label = 3;
                 break L49;
                }
                $126 = HEAP32[2996320>>2]|0;
                __THREW__ = 0;
                $127 = (invoke_iii(635,($111|0),($126|0))|0);
                $128 = __THREW__; __THREW__ = 0;
                $129 = $128&1;
                if ($129) {
                 label = 3;
                 break L49;
                }
                if ($127) {
                 break;
                }
                do {
                 if ($stripEngineInternalInformation) {
                  __THREW__ = 0;
                  invoke_vi(3799,($111|0));
                  $130 = __THREW__; __THREW__ = 0;
                  $131 = $130&1;
                  if ($131) {
                   label = 3;
                   break L49;
                  }
                  $132 = HEAP32[2996328>>2]|0;
                  __THREW__ = 0;
                  $133 = (invoke_iii(635,($111|0),($132|0))|0);
                  $134 = __THREW__; __THREW__ = 0;
                  $135 = $134&1;
                  if ($135) {
                   label = 3;
                   break L49;
                  }
                  if ($133) {
                   break L49;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($41|0));
                  $136 = __THREW__; __THREW__ = 0;
                  $137 = $136&1;
                  if ($137) {
                   label = 3;
                   break L49;
                  }
                  $138 = HEAP32[$56>>2]|0;
                  $139 = (($138) + -1)|0;
                  $140 = ($V_3$0|0)<($139|0);
                  if (!($140)) {
                   $V_4$0 = $111;
                   break;
                  }
                  __THREW__ = 0;
                  $141 = (invoke_iii(1183,0,($111|0))|0);
                  $142 = __THREW__; __THREW__ = 0;
                  $143 = $142&1;
                  if ($143) {
                   label = 3;
                   break L49;
                  }
                  if (!($141)) {
                   $V_4$0 = $111;
                   break;
                  }
                  $144 = (($V_3$0) + 1)|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($41|0));
                  $145 = __THREW__; __THREW__ = 0;
                  $146 = $145&1;
                  if ($146) {
                   label = 3;
                   break L49;
                  }
                  $147 = HEAP32[$56>>2]|0;
                  $148 = ($144>>>0)<($147>>>0);
                  if (!($148)) {
                   __THREW__ = 0;
                   $149 = (invoke_i(132)|0);
                   $150 = __THREW__; __THREW__ = 0;
                   $151 = $150&1;
                   if ($151) {
                    label = 3;
                    break L49;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($149|0));
                   $152 = __THREW__; __THREW__ = 0;
                   $153 = $152&1;
                   if ($153) {
                    label = 3;
                    break L49;
                   }
                  }
                  $154 = HEAP32[$41>>2]|0;
                  $155 = (($154) + 92|0);
                  $156 = HEAP32[$155>>2]|0;
                  $157 = Math_imul($156, $144)|0;
                  $158 = (($57) + ($157)|0);
                  $159 = HEAP32[$158>>2]|0;
                  __THREW__ = 0;
                  $160 = (invoke_iii(1183,0,($159|0))|0);
                  $161 = __THREW__; __THREW__ = 0;
                  $162 = $161&1;
                  if ($162) {
                   label = 3;
                   break L49;
                  }
                  if ($160) {
                   break L60;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($111|0));
                  $163 = __THREW__; __THREW__ = 0;
                  $164 = $163&1;
                  if ($164) {
                   label = 3;
                   break L49;
                  }
                  $165 = HEAP32[2996336>>2]|0;
                  __THREW__ = 0;
                  $166 = (invoke_iii(632,($111|0),($165|0))|0);
                  $167 = __THREW__; __THREW__ = 0;
                  $168 = $167&1;
                  if ($168) {
                   label = 3;
                   break L49;
                  }
                  $169 = ($166|0)==(-1);
                  if ($169) {
                   $V_4$0 = $111;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($111|0));
                  $170 = __THREW__; __THREW__ = 0;
                  $171 = $170&1;
                  if ($171) {
                   label = 3;
                   break L49;
                  }
                  __THREW__ = 0;
                  $172 = (invoke_iiii(528,($111|0),0,($166|0))|0);
                  $173 = __THREW__; __THREW__ = 0;
                  $174 = $173&1;
                  if ($174) {
                   label = 3;
                   break L49;
                  } else {
                   $V_4$0 = $172;
                  }
                 } else {
                  $V_4$0 = $111;
                 }
                } while(0);
                __THREW__ = 0;
                invoke_vi(3799,($V_4$0|0));
                $175 = __THREW__; __THREW__ = 0;
                $176 = $175&1;
                if ($176) {
                 label = 3;
                 break L49;
                }
                $177 = HEAP32[2996344>>2]|0;
                __THREW__ = 0;
                $178 = (invoke_iii(632,($V_4$0|0),($177|0))|0);
                $179 = __THREW__; __THREW__ = 0;
                $180 = $179&1;
                if ($180) {
                 label = 3;
                 break L49;
                }
                $181 = ($178|0)==(-1);
                if (!($181)) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($V_4$0|0));
                $182 = __THREW__; __THREW__ = 0;
                $183 = $182&1;
                if ($183) {
                 label = 3;
                 break L49;
                }
                $184 = HEAP32[2996352>>2]|0;
                __THREW__ = 0;
                $185 = (invoke_iii(632,($V_4$0|0),($184|0))|0);
                $186 = __THREW__; __THREW__ = 0;
                $187 = $186&1;
                if ($187) {
                 label = 3;
                 break L49;
                }
                $188 = ($185|0)==(-1);
                if (!($188)) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($V_4$0|0));
                $189 = __THREW__; __THREW__ = 0;
                $190 = $189&1;
                if ($190) {
                 label = 3;
                 break L49;
                }
                $191 = HEAP32[2996360>>2]|0;
                __THREW__ = 0;
                $192 = (invoke_iii(632,($V_4$0|0),($191|0))|0);
                $193 = __THREW__; __THREW__ = 0;
                $194 = $193&1;
                if ($194) {
                 label = 3;
                 break L49;
                }
                $195 = ($192|0)==(-1);
                if (!($195)) {
                 break;
                }
                do {
                 if ($stripEngineInternalInformation) {
                  __THREW__ = 0;
                  invoke_vi(3799,($V_4$0|0));
                  $196 = __THREW__; __THREW__ = 0;
                  $197 = $196&1;
                  if ($197) {
                   label = 3;
                   break L49;
                  }
                  $198 = HEAP32[2996368>>2]|0;
                  __THREW__ = 0;
                  $199 = (invoke_iii(635,($V_4$0|0),($198|0))|0);
                  $200 = __THREW__; __THREW__ = 0;
                  $201 = $200&1;
                  if ($201) {
                   label = 3;
                   break L49;
                  }
                  if (!($199)) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($V_4$0|0));
                  $202 = __THREW__; __THREW__ = 0;
                  $203 = $202&1;
                  if ($203) {
                   label = 3;
                   break L49;
                  }
                  $204 = HEAP32[2996376>>2]|0;
                  __THREW__ = 0;
                  $205 = (invoke_iii(629,($V_4$0|0),($204|0))|0);
                  $206 = __THREW__; __THREW__ = 0;
                  $207 = $206&1;
                  if ($207) {
                   label = 3;
                   break L49;
                  }
                  if ($205) {
                   break L60;
                  }
                 }
                } while(0);
                __THREW__ = 0;
                invoke_vi(3799,($V_4$0|0));
                $208 = __THREW__; __THREW__ = 0;
                $209 = $208&1;
                if ($209) {
                 label = 3;
                 break L49;
                }
                $210 = HEAP32[2996384>>2]|0;
                __THREW__ = 0;
                $211 = (invoke_iii(635,($V_4$0|0),($210|0))|0);
                $212 = __THREW__; __THREW__ = 0;
                $213 = $212&1;
                if ($213) {
                 label = 3;
                 break L49;
                }
                if ($211) {
                 __THREW__ = 0;
                 invoke_vi(3799,($V_4$0|0));
                 $214 = __THREW__; __THREW__ = 0;
                 $215 = $214&1;
                 if ($215) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 $216 = (invoke_iiii(551,($V_4$0|0),0,3)|0);
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  label = 3;
                  break L49;
                 } else {
                  $V_4$1 = $216;
                 }
                } else {
                 $V_4$1 = $V_4$0;
                }
                __THREW__ = 0;
                invoke_vi(3799,($V_4$1|0));
                $219 = __THREW__; __THREW__ = 0;
                $220 = $219&1;
                if ($220) {
                 label = 3;
                 break L49;
                }
                $221 = HEAP32[2996392>>2]|0;
                __THREW__ = 0;
                $222 = (invoke_iii(632,($V_4$1|0),($221|0))|0);
                $223 = __THREW__; __THREW__ = 0;
                $224 = $223&1;
                if ($224) {
                 label = 3;
                 break L49;
                }
                $225 = ($222|0)==(-1);
                do {
                 if ($225) {
                  $V_4$2 = $V_4$1;
                 } else {
                  __THREW__ = 0;
                  invoke_vi(3799,($V_4$1|0));
                  $226 = __THREW__; __THREW__ = 0;
                  $227 = $226&1;
                  if ($227) {
                   label = 3;
                   break L49;
                  }
                  $228 = HEAP32[2996400>>2]|0;
                  __THREW__ = 0;
                  $229 = (invoke_iiii(543,($V_4$1|0),($228|0),($222|0))|0);
                  $230 = __THREW__; __THREW__ = 0;
                  $231 = $230&1;
                  if ($231) {
                   label = 3;
                   break L49;
                  }
                  $232 = ($229|0)>($222|0);
                  if (!($232)) {
                   $V_4$2 = $V_4$1;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($V_4$1|0));
                  $233 = __THREW__; __THREW__ = 0;
                  $234 = $233&1;
                  if ($234) {
                   label = 3;
                   break L49;
                  }
                  $235 = (1 - ($222))|0;
                  $236 = (($235) + ($229))|0;
                  __THREW__ = 0;
                  $237 = (invoke_iiii(551,($V_4$1|0),($222|0),($236|0))|0);
                  $238 = __THREW__; __THREW__ = 0;
                  $239 = $238&1;
                  if ($239) {
                   label = 3;
                   break L49;
                  } else {
                   $V_4$2 = $237;
                  }
                 }
                } while(0);
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $240 = __THREW__; __THREW__ = 0;
                $241 = $240&1;
                if ($241) {
                 label = 3;
                 break L49;
                }
                $242 = HEAP8[((2191608 + 116|0))>>0]|0;
                $243 = ($242<<24>>24)==(0);
                if ($243) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $244 = __THREW__; __THREW__ = 0;
                 $245 = $244&1;
                 if ($245) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $246 = __THREW__; __THREW__ = 0;
                 $247 = $246&1;
                 if ($247) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2191608|0));
                 $248 = __THREW__; __THREW__ = 0;
                 $249 = $248&1;
                 if ($249) {
                  label = 3;
                  break L49;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $250 = __THREW__; __THREW__ = 0;
                $251 = $250&1;
                if ($251) {
                 label = 3;
                 break L49;
                }
                $252 = HEAP32[((2191608 + 80|0))>>2]|0;
                $253 = HEAP32[$252>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($V_4$2|0));
                $254 = __THREW__; __THREW__ = 0;
                $255 = $254&1;
                if ($255) {
                 label = 3;
                 break L49;
                }
                $256 = HEAP32[2996408>>2]|0;
                __THREW__ = 0;
                $257 = (invoke_iiii(548,($V_4$2|0),($256|0),($253|0))|0);
                $258 = __THREW__; __THREW__ = 0;
                $259 = $258&1;
                if ($259) {
                 label = 3;
                 break L49;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2684312|0))|0);
                $260 = __THREW__; __THREW__ = 0;
                $261 = $260&1;
                if ($261) {
                 label = 3;
                 break L49;
                }
                $262 = HEAP8[((2684312 + 116|0))>>0]|0;
                $263 = ($262<<24>>24)==(0);
                if ($263) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2684312|0))|0);
                 $264 = __THREW__; __THREW__ = 0;
                 $265 = $264&1;
                 if ($265) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2684312|0))|0);
                 $266 = __THREW__; __THREW__ = 0;
                 $267 = $266&1;
                 if ($267) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2684312|0));
                 $268 = __THREW__; __THREW__ = 0;
                 $269 = $268&1;
                 if ($269) {
                  label = 3;
                  break L49;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2684312|0))|0);
                $270 = __THREW__; __THREW__ = 0;
                $271 = $270&1;
                if ($271) {
                 label = 3;
                 break L49;
                }
                $272 = HEAP32[((2684312 + 80|0))>>2]|0;
                $273 = HEAP32[$272>>2]|0;
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $274 = __THREW__; __THREW__ = 0;
                $275 = $274&1;
                if ($275) {
                 label = 3;
                 break L49;
                }
                $276 = HEAP8[((2191608 + 116|0))>>0]|0;
                $277 = ($276<<24>>24)==(0);
                if ($277) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $278 = __THREW__; __THREW__ = 0;
                 $279 = $278&1;
                 if ($279) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $280 = __THREW__; __THREW__ = 0;
                 $281 = $280&1;
                 if ($281) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2191608|0));
                 $282 = __THREW__; __THREW__ = 0;
                 $283 = $282&1;
                 if ($283) {
                  label = 3;
                  break L49;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2191608|0))|0);
                $284 = __THREW__; __THREW__ = 0;
                $285 = $284&1;
                if ($285) {
                 label = 3;
                 break L49;
                }
                $286 = HEAP32[((2191608 + 80|0))>>2]|0;
                $287 = HEAP32[$286>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($257|0));
                $288 = __THREW__; __THREW__ = 0;
                $289 = $288&1;
                if ($289) {
                 label = 3;
                 break L49;
                }
                __THREW__ = 0;
                $290 = (invoke_iiii(548,($257|0),($273|0),($287|0))|0);
                $291 = __THREW__; __THREW__ = 0;
                $292 = $291&1;
                if ($292) {
                 label = 3;
                 break L49;
                }
                __THREW__ = 0;
                invoke_vi(3799,($290|0));
                $293 = __THREW__; __THREW__ = 0;
                $294 = $293&1;
                if ($294) {
                 label = 3;
                 break L49;
                }
                __THREW__ = 0;
                $295 = (invoke_iiii(546,($290|0),92,47)|0);
                $296 = __THREW__; __THREW__ = 0;
                $297 = $296&1;
                if ($297) {
                 label = 3;
                 break L49;
                }
                __THREW__ = 0;
                invoke_vi(3799,($295|0));
                $298 = __THREW__; __THREW__ = 0;
                $299 = $298&1;
                if ($299) {
                 label = 3;
                 break L49;
                }
                $300 = HEAP32[2996416>>2]|0;
                __THREW__ = 0;
                $301 = (invoke_iii(633,($295|0),($300|0))|0);
                $302 = __THREW__; __THREW__ = 0;
                $303 = $302&1;
                if ($303) {
                 label = 3;
                 break L49;
                }
                $304 = ($301|0)==(-1);
                if ($304) {
                 $V_4$3 = $295;
                } else {
                 __THREW__ = 0;
                 invoke_vi(3799,($295|0));
                 $305 = __THREW__; __THREW__ = 0;
                 $306 = $305&1;
                 if ($306) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 $307 = (invoke_iiii(551,($295|0),($301|0),5)|0);
                 $308 = __THREW__; __THREW__ = 0;
                 $309 = $308&1;
                 if ($309) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($307|0));
                 $310 = __THREW__; __THREW__ = 0;
                 $311 = $310&1;
                 if ($311) {
                  label = 3;
                  break L49;
                 }
                 $312 = HEAP32[2996424>>2]|0;
                 __THREW__ = 0;
                 $313 = (invoke_iiii(564,($307|0),($301|0),($312|0))|0);
                 $314 = __THREW__; __THREW__ = 0;
                 $315 = $314&1;
                 if ($315) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($313|0));
                 $316 = __THREW__; __THREW__ = 0;
                 $317 = $316&1;
                 if ($317) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 $318 = (invoke_ii(1816,($313|0))|0);
                 $319 = __THREW__; __THREW__ = 0;
                 $320 = $319&1;
                 if ($320) {
                  label = 3;
                  break L49;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($313|0));
                 $321 = __THREW__; __THREW__ = 0;
                 $322 = $321&1;
                 if ($322) {
                  label = 3;
                  break L49;
                 }
                 $323 = HEAP32[2996432>>2]|0;
                 __THREW__ = 0;
                 $324 = (invoke_iiii(564,($313|0),($318|0),($323|0))|0);
                 $325 = __THREW__; __THREW__ = 0;
                 $326 = $325&1;
                 if ($326) {
                  label = 3;
                  break L49;
                 } else {
                  $V_4$3 = $324;
                 }
                }
                $327 = HEAP32[2996440>>2]|0;
                __THREW__ = 0;
                $328 = (invoke_iiii(562,(0|0),($V_4$3|0),($327|0))|0);
                $329 = __THREW__; __THREW__ = 0;
                $330 = $329&1;
                if ($330) {
                 label = 3;
                 break L49;
                }
                __THREW__ = 0;
                invoke_vi(3799,($51|0));
                $331 = __THREW__; __THREW__ = 0;
                $332 = $331&1;
                if ($332) {
                 label = 3;
                 break L49;
                }
                __THREW__ = 0;
                (invoke_iii(989,($51|0),($328|0))|0);
                $333 = __THREW__; __THREW__ = 0;
                $334 = $333&1;
                if ($334) {
                 label = 3;
                 break L49;
                }
               }
              } while(0);
              $335 = (($V_3$0) + 1)|0;
              $V_3$0 = $335;
             }
             if ((label|0) == 3) {
              $3 = ___cxa_find_matching_catch()|0;
              $4 = tempRet0;
              $lpad$phi$index = $3;$lpad$phi$index3 = $4;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
             __THREW__ = 0;
             invoke_vi(3799,($51|0));
             $342 = __THREW__; __THREW__ = 0;
             $343 = $342&1;
             if (!($343)) {
              __THREW__ = 0;
              $344 = (invoke_iii(2730,(2535432|0),($51|0))|0);
              $345 = __THREW__; __THREW__ = 0;
              $346 = $345&1;
              if (!($346)) {
               $$0 = $344;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index3 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker3I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_E6InvokeEPFvPvP22mscorlib_System_ObjectS3_S3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$4);
 STACKTOP = sp;return (0|0);
}
function __Z67UnityEngine_UnityEngine_UnityException_m__ctor_mscorlib_System_VoidP38UnityEngine_UnityEngine_UnityException($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2684448);
 __THREW__ = 0;
 invoke_v(955);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[2997048>>2]|0;
  __THREW__ = 0;
  invoke_vii(1781,($__this|0),($2|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(1783,($__this|0),-2147467261);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z90UnityEngine_UnityEngine_UnityException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP38UnityEngine_UnityEngine_UnityExceptionP22mscorlib_System_String($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2684496);
 __THREW__ = 0;
 invoke_vii(1781,($__this|0),($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147467261);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z116UnityEngine_UnityEngine_UnityException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ExceptionP38UnityEngine_UnityEngine_UnityExceptionP22mscorlib_System_StringP25mscorlib_System_Exception($__this,$message,$innerException) {
 $__this = $__this|0;
 $message = $message|0;
 $innerException = $innerException|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2684544);
 __THREW__ = 0;
 invoke_viii(543,($__this|0),($message|0),($innerException|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(1783,($__this|0),-2147467261);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z53UnityEngine_UnityEngine_StateMachineBehaviour_m__ctorP45UnityEngine_UnityEngine_StateMachineBehaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2684992);
 __THREW__ = 0;
 invoke_vi(2907,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48UnityEngine_UnityEngine_ScriptableObject_m__ctorP40UnityEngine_UnityEngine_ScriptableObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2717880);
 __THREW__ = 0;
 invoke_vi(2862,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2014,0,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z60UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateEnterP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi($__this,$animator,$stateInfo,$layerIndex) {
 $__this = $__this|0;
 $animator = $animator|0;
 $stateInfo = $stateInfo|0;
 $layerIndex = $layerIndex|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2685040);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z61UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateUpdateP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi($__this,$animator,$stateInfo,$layerIndex) {
 $__this = $__this|0;
 $animator = $animator|0;
 $stateInfo = $stateInfo|0;
 $layerIndex = $layerIndex|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2685088);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z59UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateExitP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi($__this,$animator,$stateInfo,$layerIndex) {
 $__this = $__this|0;
 $animator = $animator|0;
 $stateInfo = $stateInfo|0;
 $layerIndex = $layerIndex|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2685136);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z59UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateMoveP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi($__this,$animator,$stateInfo,$layerIndex) {
 $__this = $__this|0;
 $animator = $animator|0;
 $stateInfo = $stateInfo|0;
 $layerIndex = $layerIndex|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2685184);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z57UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateIKP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi($__this,$animator,$stateInfo,$layerIndex) {
 $__this = $__this|0;
 $animator = $animator|0;
 $stateInfo = $stateInfo|0;
 $layerIndex = $layerIndex|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2685232);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z67UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateMachineEnterP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animatori($__this,$animator,$stateMachinePathHash) {
 $__this = $__this|0;
 $animator = $animator|0;
 $stateMachinePathHash = $stateMachinePathHash|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2685280);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z66UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateMachineExitP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animatori($__this,$animator,$stateMachinePathHash) {
 $__this = $__this|0;
 $animator = $animator|0;
 $stateMachinePathHash = $stateMachinePathHash|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2685328);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker3I17VoidPointerTraits47UnityEngine_UnityEngine_AnimatorStateInfoTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_41UnityEngine_UnityEngine_AnimatorStateInfoiES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 28|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$3+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$3+24>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$$byval_copy+24>>2]=HEAP32[$0+24>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$$byval_copy,$6);
 STACKTOP = sp;return (0|0);
}
function __Z42UnityEngine_UnityEngine_TextEditor_m__ctorP34UnityEngine_UnityEngine_TextEditor($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2689272);
 __THREW__ = 0;
 (invoke_ii(2996,(2742984|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2742984|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2980,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 20|0);
    HEAP32[$7>>2] = $2;
    __THREW__ = 0;
    $8 = (invoke_ii(2596,0)|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($__this) + 24|0);
     HEAP32[$11>>2] = $8;
     __THREW__ = 0;
     invoke_vii(2068,($L_2|0),0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 48|0);
      $15 = $L_2;
      $16 = $15;
      $17 = HEAP32[$16>>2]|0;
      $18 = (($15) + 4)|0;
      $19 = $18;
      $20 = HEAP32[$19>>2]|0;
      $21 = $14;
      $22 = $21;
      HEAP32[$22>>2] = $17;
      $23 = (($21) + 4)|0;
      $24 = $23;
      HEAP32[$24>>2] = $20;
      $25 = (($__this) + 88|0);
      HEAP32[$25>>2] = -1;
      __THREW__ = 0;
      invoke_vi(1924,($__this|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
}
function __Z63UnityEngine_UnityEngine_GUIContent_m__ctor_mscorlib_System_VoidP34UnityEngine_UnityEngine_GUIContent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2742368);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = (($__this) + 8|0);
    HEAP32[$16>>2] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP8[((2191608 + 116|0))>>0]|0;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2191608|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[((2191608 + 80|0))>>2]|0;
      $30 = HEAP32[$29>>2]|0;
      $31 = (($__this) + 16|0);
      HEAP32[$31>>2] = $30;
      __THREW__ = 0;
      invoke_vi(1924,($__this|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z43UnityEngine_UnityEngine_GUIStyle_m_get_noneP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2748472);
 __THREW__ = 0;
 (invoke_ii(2996,(2749952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2749952 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2749952|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2749952|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2749952 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2749952|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2749952|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3007,($20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2749952|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = HEAP8[((2749952 + 116|0))>>0]|0;
     $28 = ($27<<24>>24)==(0);
     if ($28) {
      __THREW__ = 0;
      (invoke_ii(2996,(2749952|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2749952|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2749952|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2749952|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     $37 = HEAP32[((2749952 + 80|0))>>2]|0;
     $38 = (($37) + 4|0);
     HEAP32[$38>>2] = $20;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     $41 = HEAP8[((2749952 + 116|0))>>0]|0;
     $42 = ($41<<24>>24)==(0);
     if ($42) {
      __THREW__ = 0;
      (invoke_ii(2996,(2749952|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2749952|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2749952|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2749952|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if (!($50)) {
      $51 = HEAP32[((2749952 + 80|0))>>2]|0;
      $52 = (($51) + 4|0);
      $53 = HEAP32[$52>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($53|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z42UnityEngine_UnityEngine_Vector2_m_get_zeroP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2771136);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_viff(15,($agg$result|0),0.0,0.0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62UnityEngine_UnityEngine_TextGenerationSettings_m_CompareColorsP46UnityEngine_UnityEngine_TextGenerationSettings29UnityEngine_UnityEngine_ColorS1_($__this,$left,$right) {
 $__this = $__this|0;
 $left = $left|0;
 $right = $right|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $L_23 = 0, $L_45 = 0, $_stackTraceSentry = 0, $right$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $right$byval_copy = sp + 24|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $L_1 = sp + 8|0;
 $L_23 = sp + 12|0;
 $L_45 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2690536);
 __THREW__ = 0;
 ;HEAP32[$right$byval_copy+0>>2]=HEAP32[$left+0>>2]|0;HEAP32[$right$byval_copy+4>>2]=HEAP32[$left+4>>2]|0;HEAP32[$right$byval_copy+8>>2]=HEAP32[$left+8>>2]|0;HEAP32[$right$byval_copy+12>>2]=HEAP32[$left+12>>2]|0;
 invoke_viii(741,($L_0|0),(0|0),($right$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[$L_0>>2]|0;
  __THREW__ = 0;
  ;HEAP32[$right$byval_copy+0>>2]=HEAP32[$right+0>>2]|0;HEAP32[$right$byval_copy+4>>2]=HEAP32[$right+4>>2]|0;HEAP32[$right$byval_copy+8>>2]=HEAP32[$right+8>>2]|0;HEAP32[$right$byval_copy+12>>2]=HEAP32[$right+12>>2]|0;
  invoke_viii(741,($L_1|0),(0|0),($right$byval_copy|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[$L_1>>2]|0;
   HEAP32[$L_23>>2] = $2;
   __THREW__ = 0;
   (invoke_ii(2996,(2793720|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    $8 = (invoke_iii(2724,(2793720|0),($L_23|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     HEAP32[$L_45>>2] = $5;
     __THREW__ = 0;
     (invoke_ii(2996,(2793720|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_iii(2724,(2793720|0),($L_45|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(3799,($8|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        $18 = (invoke_iiii(1644,(2150048|0),($8|0),($13|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($18|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z63UnityEngine_UnityEngine_TextGenerationSettings_m_CompareVector2P46UnityEngine_UnityEngine_TextGenerationSettings31UnityEngine_UnityEngine_Vector2S1_($__this,$left,$right) {
 $__this = $__this|0;
 $left = $left|0;
 $right = $right|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2690584);
 $0 = Math_fround(HEAPF32[$left>>2]);
 $1 = Math_fround(HEAPF32[$right>>2]);
 __THREW__ = 0;
 $2 = (invoke_iiff(1,(0|0),(+$0),(+$1))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 if (!($2)) {
  $G_B3_0$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 $7 = (($left) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($right) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 __THREW__ = 0;
 $11 = (invoke_iiff(1,(0|0),(+$8),(+$10))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $G_B3_0$0 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($G_B3_0$0|0);
 }
 return 0|0;
}
function __Z55UnityEngine_UnityEngine_TextGenerationSettings_m_EqualsP46UnityEngine_UnityEngine_TextGenerationSettingsS_($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B19_0$0 = 0, $_stackTraceSentry = 0, $tmpcast4$byval_copy = 0, $tmpcast5$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast5$byval_copy = sp + 56|0;
 $tmpcast4$byval_copy = sp + 40|0;
 $_stackTraceSentry = sp + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2690632);
 $4 = (($__this) + 4|0);
 $5 = (($other) + 4|0);
 __THREW__ = 0;
 ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$tmpcast4$byval_copy+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$tmpcast4$byval_copy+12>>2]=HEAP32[$4+12>>2]|0;
 ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$tmpcast5$byval_copy+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$tmpcast5$byval_copy+12>>2]=HEAP32[$5+12>>2]|0;
 $6 = (invoke_iiii(1299,0,($tmpcast4$byval_copy|0),($tmpcast5$byval_copy|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 do {
  if ($6) {
   $11 = (($__this) + 20|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($other) + 20|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($12|0)==($14|0);
   if ($15) {
    $16 = (($__this) + 44|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($other) + 44|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($17|0)==($19|0);
    if ($20) {
     $21 = (($__this) + 48|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (($other) + 48|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = ($22|0)==($24|0);
     if ($25) {
      $26 = (($__this) + 24|0);
      $27 = Math_fround(HEAPF32[$26>>2]);
      $28 = (($other) + 24|0);
      $29 = Math_fround(HEAPF32[$28>>2]);
      __THREW__ = 0;
      $30 = (invoke_iiff(1,(0|0),(+$27),(+$29))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       $9 = ___cxa_find_matching_catch()|0;
       $10 = tempRet0;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($9|0);
       // unreachable;
      }
      if ($30) {
       $33 = (($__this) + 32|0);
       $34 = HEAP32[$33>>2]|0;
       $35 = (($other) + 32|0);
       $36 = HEAP32[$35>>2]|0;
       $37 = ($34|0)==($36|0);
       if ($37) {
        $38 = (($__this) + 28|0);
        $39 = HEAP8[$38>>0]|0;
        $40 = (($other) + 28|0);
        $41 = HEAP8[$40>>0]|0;
        $42 = ($39<<24>>24)==($41<<24>>24);
        if ($42) {
         $43 = (($__this) + 36|0);
         $44 = HEAP32[$43>>2]|0;
         $45 = (($other) + 36|0);
         $46 = HEAP32[$45>>2]|0;
         $47 = ($44|0)==($46|0);
         if ($47) {
          $48 = (($__this) + 40|0);
          $49 = HEAP8[$48>>0]|0;
          $50 = (($other) + 40|0);
          $51 = HEAP8[$50>>0]|0;
          $52 = ($49<<24>>24)==($51<<24>>24);
          if ($52) {
           $53 = HEAP32[$16>>2]|0;
           $54 = ($53|0)==($17|0);
           if ($54) {
            $55 = HEAP32[$21>>2]|0;
            $$not = ($55|0)==($22|0);
            if ($$not) {
             $56 = (($__this) + 52|0);
             $57 = HEAP8[$56>>0]|0;
             $58 = (($other) + 52|0);
             $59 = HEAP8[$58>>0]|0;
             $60 = ($57<<24>>24)==($59<<24>>24);
             if ($60) {
              $61 = (($__this) + 60|0);
              $62 = HEAP32[$61>>2]|0;
              $63 = (($other) + 60|0);
              $64 = HEAP32[$63>>2]|0;
              $65 = ($62|0)==($64|0);
              if ($65) {
               $66 = (($__this) + 56|0);
               $67 = HEAP32[$66>>2]|0;
               $68 = (($other) + 56|0);
               $69 = HEAP32[$68>>2]|0;
               $70 = ($67|0)==($69|0);
               if ($70) {
                $71 = (($__this) + 64|0);
                $72 = $71;
                $73 = $72;
                $74 = HEAP32[$73>>2]|0;
                $75 = (($72) + 4)|0;
                $76 = $75;
                $77 = HEAP32[$76>>2]|0;
                $78 = (($other) + 64|0);
                $79 = $78;
                $80 = $79;
                $81 = HEAP32[$80>>2]|0;
                $82 = (($79) + 4)|0;
                $83 = $82;
                $84 = HEAP32[$83>>2]|0;
                $85 = $0;
                $86 = $85;
                HEAP32[$86>>2] = $74;
                $87 = (($85) + 4)|0;
                $88 = $87;
                HEAP32[$88>>2] = $77;
                $89 = $1;
                $90 = $89;
                HEAP32[$90>>2] = $81;
                $91 = (($89) + 4)|0;
                $92 = $91;
                HEAP32[$92>>2] = $84;
                __THREW__ = 0;
                ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
                ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
                $93 = (invoke_iiii(1301,0,($tmpcast4$byval_copy|0),($tmpcast5$byval_copy|0))|0);
                $94 = __THREW__; __THREW__ = 0;
                $95 = $94&1;
                if ($95) {
                 $9 = ___cxa_find_matching_catch()|0;
                 $10 = tempRet0;
                 __ZN16StackTraceSentryD2Ev(0);
                 ___resumeException($9|0);
                 // unreachable;
                }
                if ($93) {
                 $96 = (($__this) + 72|0);
                 $97 = $96;
                 $98 = $97;
                 $99 = HEAP32[$98>>2]|0;
                 $100 = (($97) + 4)|0;
                 $101 = $100;
                 $102 = HEAP32[$101>>2]|0;
                 $103 = (($other) + 72|0);
                 $104 = $103;
                 $105 = $104;
                 $106 = HEAP32[$105>>2]|0;
                 $107 = (($104) + 4)|0;
                 $108 = $107;
                 $109 = HEAP32[$108>>2]|0;
                 $110 = $2;
                 $111 = $110;
                 HEAP32[$111>>2] = $99;
                 $112 = (($110) + 4)|0;
                 $113 = $112;
                 HEAP32[$113>>2] = $102;
                 $114 = $3;
                 $115 = $114;
                 HEAP32[$115>>2] = $106;
                 $116 = (($114) + 4)|0;
                 $117 = $116;
                 HEAP32[$117>>2] = $109;
                 __THREW__ = 0;
                 ;HEAP32[$tmpcast4$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast4$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
                 ;HEAP32[$tmpcast5$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast5$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;
                 $118 = (invoke_iiii(1301,0,($tmpcast4$byval_copy|0),($tmpcast5$byval_copy|0))|0);
                 $119 = __THREW__; __THREW__ = 0;
                 $120 = $119&1;
                 if ($120) {
                  $9 = ___cxa_find_matching_catch()|0;
                  $10 = tempRet0;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($9|0);
                  // unreachable;
                 }
                 if (!($118)) {
                  $G_B19_0$0 = 0;
                  break;
                 }
                 $121 = HEAP32[$__this>>2]|0;
                 $122 = HEAP32[$other>>2]|0;
                 __THREW__ = 0;
                 $123 = (invoke_iiii(1318,0,($121|0),($122|0))|0);
                 $124 = __THREW__; __THREW__ = 0;
                 $125 = $124&1;
                 if (!($125)) {
                  $G_B19_0$0 = $123;
                  break;
                 }
                 $9 = ___cxa_find_matching_catch()|0;
                 $10 = tempRet0;
                 __ZN16StackTraceSentryD2Ev(0);
                 ___resumeException($9|0);
                 // unreachable;
                } else {
                 $G_B19_0$0 = 0;
                }
               } else {
                $G_B19_0$0 = 0;
               }
              } else {
               $G_B19_0$0 = 0;
              }
             } else {
              $G_B19_0$0 = 0;
             }
            } else {
             $G_B19_0$0 = 0;
            }
           } else {
            $G_B19_0$0 = 0;
           }
          } else {
           $G_B19_0$0 = 0;
          }
         } else {
          $G_B19_0$0 = 0;
         }
        } else {
         $G_B19_0$0 = 0;
        }
       } else {
        $G_B19_0$0 = 0;
       }
      } else {
       $G_B19_0$0 = 0;
      }
     } else {
      $G_B19_0$0 = 0;
     }
    } else {
     $G_B19_0$0 = 0;
    }
   } else {
    $G_B19_0$0 = 0;
   }
  } else {
   $G_B19_0$0 = 0;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B19_0$0|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits35UnityEngine_UnityEngine_ColorTraitsS1_E6InvokeEPFbPv29UnityEngine_UnityEngine_ColorS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 32|0;
 $$byval_copy = sp;
 $ret = sp + 48|0;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits37UnityEngine_UnityEngine_Vector2TraitsS1_E6InvokeEPFbPv31UnityEngine_UnityEngine_Vector2S4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$byval_copy = sp + 24|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$args>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($args) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $25 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$tmpcast$byval_copy,$tmpcast1$byval_copy)|0);
 $26 = $25&1;
 HEAP8[$ret>>0] = $26;
 $27 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($27|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits52UnityEngine_UnityEngine_TextGenerationSettingsTraitsE6InvokeEPFbPv46UnityEngine_UnityEngine_TextGenerationSettingsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 84|0;
 $0 = HEAP32[$args>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$0+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z66UnityEngine_UnityEngine_TextGenerator_m__ctor_mscorlib_System_VoidP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2691728);
 __THREW__ = 0;
 invoke_vii(1992,($__this|0),50);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z88UnityEngine_UnityEngine_TextGenerator_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P37UnityEngine_UnityEngine_TextGeneratori($__this,$initialCapacity) {
 $__this = $__this|0;
 $initialCapacity = $initialCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2691776);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($initialCapacity) + 1)|0;
  $3 = $2 << 2;
  __THREW__ = 0;
  (invoke_ii(2996,(1782560|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(1782560|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_vii(1511,($6|0),($3|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     $11 = (($__this) + 104|0);
     HEAP32[$11>>2] = $6;
     __THREW__ = 0;
     (invoke_ii(2996,(1790448|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      $14 = (invoke_ii(3469,(1790448|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       invoke_vii(1528,($14|0),($2|0));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        $19 = (($__this) + 108|0);
        HEAP32[$19>>2] = $14;
        __THREW__ = 0;
        (invoke_ii(2996,(1798320|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         $22 = (invoke_ii(3469,(1798320|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          __THREW__ = 0;
          invoke_vii(1545,($22|0),20);
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           $27 = (($__this) + 112|0);
           HEAP32[$27>>2] = $22;
           __THREW__ = 0;
           invoke_vi(2833,($__this|0));
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($30|0);
 // unreachable;
}
function __Z44UnityEngine_UnityEngine_TextGenerator_m_InitP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692304);
 $0 = HEAP32[2692352>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2692360|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2692352>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z66UnityEngine_UnityEngine_TextGenerator_m_System_IDisposable_DisposeP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2691824);
 __THREW__ = 0;
 invoke_vi(2834,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z51UnityEngine_UnityEngine_TextGenerator_m_Dispose_cppP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692400);
 $0 = HEAP32[2692448>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2692456|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2692448>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z57UnityEngine_UnityEngine_TextGenerator_m_ValidatedSettingsP37UnityEngine_UnityEngine_TextGenerator46UnityEngine_UnityEngine_TextGenerationSettings($agg$result,$__this,$settings) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $settings = $settings|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2691872);
 __THREW__ = 0;
 invoke_v(956);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[$settings>>2]|0;
   __THREW__ = 0;
   $3 = (invoke_iiii(1319,0,($2|0),(0|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    if ($3) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(2673,($2|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     if ($10) {
      dest=$agg$result+0|0; src=$settings+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
    $13 = (($settings) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0);
    if ($15) {
     $16 = (($settings) + 32|0);
     $17 = HEAP32[$16>>2]|0;
     $18 = ($17|0)==(0);
     if (!($18)) {
      label = 11;
     }
    } else {
     label = 11;
    }
    if ((label|0) == 11) {
     $19 = HEAP32[2997128>>2]|0;
     __THREW__ = 0;
     invoke_vii(2111,(0|0),($19|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     HEAP32[$13>>2] = 0;
     $22 = (($settings) + 32|0);
     HEAP32[$22>>2] = 0;
    }
    $23 = (($settings) + 40|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)==(0);
    if (!($25)) {
     $26 = HEAP32[2997136>>2]|0;
     __THREW__ = 0;
     invoke_vii(2111,(0|0),($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     HEAP8[$23>>0] = 0;
    }
    dest=$agg$result+0|0; src=$settings+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z50UnityEngine_UnityEngine_TextGenerator_m_InvalidateP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2691920);
 $0 = (($__this) + 100|0);
 HEAP8[$0>>0] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z57UnityEngine_UnityEngine_TextGenerator_m_GetPreferredWidthP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_String46UnityEngine_UnityEngine_TextGenerationSettings($__this,$str,$settings) {
 $__this = $__this|0;
 $str = $str|0;
 $settings = $settings|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $L_4 = 0, $V_0 = 0, $_stackTraceSentry = 0, $settings$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $settings$byval_copy = sp + 40|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 8|0;
 $L_4 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2691968);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 $0 = (($settings) + 60|0);
 HEAP32[$0>>2] = 1;
 $1 = (($settings) + 56|0);
 HEAP32[$1>>2] = 1;
 $2 = (($settings) + 52|0);
 HEAP8[$2>>0] = 1;
 __THREW__ = 0;
 dest=$settings$byval_copy+0|0; src=$settings+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 (invoke_iiii(1306,($__this|0),($str|0),($settings$byval_copy|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vii(1993,($L_4|0),($__this|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   ;HEAP32[$V_0+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_4+12>>2]|0;
   __THREW__ = 0;
   $7 = (Math_fround(+(invoke_fi(140,($V_0|0)))));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return (Math_fround($7));
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return Math_fround(0);
}
function __Z48UnityEngine_UnityEngine_TextGenerator_m_PopulateP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_String46UnityEngine_UnityEngine_TextGenerationSettings($__this,$str,$settings) {
 $__this = $__this|0;
 $str = $str|0;
 $settings = $settings|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, $settings$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $settings$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692064);
 $0 = (($__this) + 100|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  label = 8;
 } else {
  $3 = (($__this) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  $5 = (invoke_iiii(574,(0|0),($str|0),($4|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   if ($5) {
    $10 = (($__this) + 16|0);
    __THREW__ = 0;
    dest=$settings$byval_copy+0|0; src=$10+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $11 = (invoke_iii(1186,($settings|0),($settings$byval_copy|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     if ($11) {
      $14 = (($__this) + 101|0);
      $15 = HEAP8[$14>>0]|0;
      $16 = ($15<<24>>24)!=(0);
      $$0 = $16;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     } else {
      label = 8;
     }
    }
   } else {
    label = 8;
   }
  }
 }
 if ((label|0) == 8) {
  __THREW__ = 0;
  dest=$settings$byval_copy+0|0; src=$settings+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $17 = (invoke_iiii(1308,($__this|0),($str|0),($settings$byval_copy|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if (!($19)) {
   $$0 = $17;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z55UnityEngine_UnityEngine_TextGenerator_m_get_rectExtentsP37UnityEngine_UnityEngine_TextGenerator($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693088);
 $0 = HEAP32[2693136>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2693144|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2693136>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($agg$result|0),($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z58UnityEngine_UnityEngine_TextGenerator_m_GetPreferredHeightP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_String46UnityEngine_UnityEngine_TextGenerationSettings($__this,$str,$settings) {
 $__this = $__this|0;
 $str = $str|0;
 $settings = $settings|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $V_0 = 0, $_stackTraceSentry = 0, $settings$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $settings$byval_copy = sp + 40|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 8|0;
 $L_3 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692016);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 $0 = (($settings) + 56|0);
 HEAP32[$0>>2] = 1;
 $1 = (($settings) + 52|0);
 HEAP8[$1>>0] = 1;
 __THREW__ = 0;
 dest=$settings$byval_copy+0|0; src=$settings+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 (invoke_iiii(1306,($__this|0),($str|0),($settings$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vii(1993,($L_3|0),($__this|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   ;HEAP32[$V_0+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_3+12>>2]|0;
   __THREW__ = 0;
   $6 = (Math_fround(+(invoke_fi(141,($V_0|0)))));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return (Math_fround($6));
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return Math_fround(0);
}
function __Z54UnityEngine_UnityEngine_TextGenerator_m_PopulateAlwaysP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_String46UnityEngine_UnityEngine_TextGenerationSettings($__this,$str,$settings) {
 $__this = $__this|0;
 $str = $str|0;
 $settings = $settings|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $L_4 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $tmpcast1$byval_copy = sp + 128|0;
 $tmpcast$byval_copy = sp + 120|0;
 $$byval_copy = sp + 104|0;
 $_stackTraceSentry = sp + 16|0;
 $L_4 = sp + 20|0;
 $0 = sp;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692112);
 $2 = (($__this) + 12|0);
 HEAP32[$2>>2] = $str;
 $3 = (($__this) + 100|0);
 HEAP8[$3>>0] = 1;
 $4 = (($__this) + 116|0);
 HEAP8[$4>>0] = 0;
 $5 = (($__this) + 117|0);
 HEAP8[$5>>0] = 0;
 $6 = (($__this) + 118|0);
 HEAP8[$6>>0] = 0;
 $7 = (($__this) + 16|0);
 dest=$7+0|0; src=$settings+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 dest=$tmpcast1$byval_copy+0|0; src=$settings+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 invoke_viii(727,($L_4|0),0,($tmpcast1$byval_copy|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($71|0);
  // unreachable;
 }
 $10 = HEAP32[$L_4>>2]|0;
 $11 = (($L_4) + 4|0);
 $12 = (($L_4) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($L_4) + 24|0);
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (($L_4) + 28|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = (($L_4) + 32|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($L_4) + 36|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($L_4) + 40|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = (($L_4) + 44|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($L_4) + 48|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($L_4) + 52|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = (($L_4) + 56|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = (($L_4) + 60|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($L_4) + 64|0);
 $35 = $34;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + 4)|0;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($34) + 8|0);
 $42 = $41;
 $43 = $42;
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + 4)|0;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($L_4) + 80|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = $17 & 1;
 $51 = ($50<<24>>24)!=(0);
 $52 = $23 & 1;
 $53 = ($52<<24>>24)!=(0);
 $54 = $29 & 1;
 $55 = ($54<<24>>24)!=(0);
 $56 = $49 & 1;
 $57 = ($56<<24>>24)!=(0);
 $58 = $0;
 $59 = $58;
 HEAP32[$59>>2] = $37;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $40;
 $62 = $1;
 $63 = $62;
 HEAP32[$63>>2] = $44;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = $47;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$11+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 $66 = (invoke_iiiiiifiiiiiiiiiiii(1,($__this|0),($str|0),($10|0),($$byval_copy|0),($13|0),(+$15),($19|0),($51|0),($53|0),($25|0),($27|0),($31|0),($33|0),($55|0),($21|0),($tmpcast$byval_copy|0),($tmpcast1$byval_copy|0),($57|0))|0);
 $67 = __THREW__; __THREW__ = 0;
 $68 = $67&1;
 if ($68) {
  $71 = ___cxa_find_matching_catch()|0;
  $72 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($71|0);
  // unreachable;
 } else {
  $69 = (($__this) + 101|0);
  $70 = $66&1;
  HEAP8[$69>>0] = $70;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($66|0);
 }
 return 0|0;
}
function __Z57UnityEngine_UnityEngine_TextGenerator_m_Populate_InternalP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_StringP28UnityEngine_UnityEngine_Font29UnityEngine_UnityEngine_Colorifibbiiiibi31UnityEngine_UnityEngine_Vector2S6_b($__this,$str,$font,$color,$fontSize,$lineSpacing,$style,$richText,$resizeTextForBestFit,$resizeTextMinSize,$resizeTextMaxSize,$verticalOverFlow,$horizontalOverflow,$updateBounds,$anchor,$extents,$pivot,$generateOutOfBounds) {
 $__this = $__this|0;
 $str = $str|0;
 $font = $font|0;
 $color = $color|0;
 $fontSize = $fontSize|0;
 $lineSpacing = Math_fround($lineSpacing);
 $style = $style|0;
 $richText = $richText|0;
 $resizeTextForBestFit = $resizeTextForBestFit|0;
 $resizeTextMinSize = $resizeTextMinSize|0;
 $resizeTextMaxSize = $resizeTextMaxSize|0;
 $verticalOverFlow = $verticalOverFlow|0;
 $horizontalOverflow = $horizontalOverflow|0;
 $updateBounds = $updateBounds|0;
 $anchor = $anchor|0;
 $extents = $extents|0;
 $pivot = $pivot|0;
 $generateOutOfBounds = $generateOutOfBounds|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $_stackTraceSentry$i = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry$i = sp + 20|0;
 $0 = sp;
 $_stackTraceSentry = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692552);
 $1 = Math_fround(HEAPF32[$extents>>2]);
 $2 = (($extents) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(HEAPF32[$pivot>>2]);
 $5 = (($pivot) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 ;HEAP32[$0+0>>2]=HEAP32[$color+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$color+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$color+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$color+12>>2]|0;
 __THREW__ = 0;
 invoke_vii(3500,($_stackTraceSentry$i|0),(2692600|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $eh$lpad$body$index2Z2D = $15;$eh$lpad$body$indexZ2D = $14;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 $9 = (invoke_iiiiiiifiiiiiiiiiffffi(1,0,($__this|0),($str|0),($font|0),($0|0),($fontSize|0),(+$lineSpacing),($style|0),($richText|0),($resizeTextForBestFit|0),($resizeTextMinSize|0),($resizeTextMaxSize|0),($verticalOverFlow|0),($horizontalOverflow|0),($updateBounds|0),($anchor|0),(+$1),(+$3),(+$4),(+$6),($generateOutOfBounds|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  __ZN16StackTraceSentryD2Ev(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($9|0);
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 $eh$lpad$body$index2Z2D = $13;$eh$lpad$body$indexZ2D = $12;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
 return 0|0;
}
function __Z49UnityEngine_UnityEngine_TextGenerator_m_get_vertsP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692160);
 $0 = (($__this) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($__this) + 104|0);
 if (!($2)) {
  $7 = HEAP32[$3>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($7|0);
 }
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vii(1994,($__this|0),($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 }
 HEAP8[$0>>0] = 1;
 $7 = HEAP32[$3>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($7|0);
}
function __Z51UnityEngine_UnityEngine_TextGenerator_m_GetVerticesP37UnityEngine_UnityEngine_TextGeneratorP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex($__this,$vertices) {
 $__this = $__this|0;
 $vertices = $vertices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693296);
 __THREW__ = 0;
 invoke_vii(1995,($__this|0),($vertices|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54UnityEngine_UnityEngine_TextGenerator_m_get_charactersP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692208);
 $0 = (($__this) + 117|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($__this) + 108|0);
 if (!($2)) {
  $7 = HEAP32[$3>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($7|0);
 }
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vii(1996,($__this|0),($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 }
 HEAP8[$0>>0] = 1;
 $7 = HEAP32[$3>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($7|0);
}
function __Z53UnityEngine_UnityEngine_TextGenerator_m_GetCharactersP37UnityEngine_UnityEngine_TextGeneratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo($__this,$characters) {
 $__this = $__this|0;
 $characters = $characters|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693672);
 __THREW__ = 0;
 invoke_vii(1997,($__this|0),($characters|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z49UnityEngine_UnityEngine_TextGenerator_m_get_linesP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692256);
 $0 = (($__this) + 118|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 $3 = (($__this) + 112|0);
 if (!($2)) {
  $7 = HEAP32[$3>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($7|0);
 }
 $4 = HEAP32[$3>>2]|0;
 __THREW__ = 0;
 invoke_vii(1998,($__this|0),($4|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 }
 HEAP8[$0>>0] = 1;
 $7 = HEAP32[$3>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($7|0);
}
function __Z48UnityEngine_UnityEngine_TextGenerator_m_GetLinesP37UnityEngine_UnityEngine_TextGeneratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo($__this,$lines) {
 $__this = $__this|0;
 $lines = $lines|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2694048);
 __THREW__ = 0;
 invoke_vii(1999,($__this|0),($lines|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48UnityEngine_UnityEngine_TextGenerator_m_FinalizeP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692504);
 __THREW__ = 0;
 invoke_vii(3491,(2176768|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 18;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(18);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3844,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z61UnityEngine_UnityEngine_TextGenerator_m_Populate_Internal_cppP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_StringP28UnityEngine_UnityEngine_Font29UnityEngine_UnityEngine_Colorifibbiiiibiffffb($__this,$str,$font,$color,$fontSize,$lineSpacing,$style,$richText,$resizeTextForBestFit,$resizeTextMinSize,$resizeTextMaxSize,$verticalOverFlow,$horizontalOverflow,$updateBounds,$anchor,$extentsX,$extentsY,$pivotX,$pivotY,$generateOutOfBounds) {
 $__this = $__this|0;
 $str = $str|0;
 $font = $font|0;
 $color = $color|0;
 $fontSize = $fontSize|0;
 $lineSpacing = Math_fround($lineSpacing);
 $style = $style|0;
 $richText = $richText|0;
 $resizeTextForBestFit = $resizeTextForBestFit|0;
 $resizeTextMinSize = $resizeTextMinSize|0;
 $resizeTextMaxSize = $resizeTextMaxSize|0;
 $verticalOverFlow = $verticalOverFlow|0;
 $horizontalOverflow = $horizontalOverflow|0;
 $updateBounds = $updateBounds|0;
 $anchor = $anchor|0;
 $extentsX = Math_fround($extentsX);
 $extentsY = Math_fround($extentsY);
 $pivotX = Math_fround($pivotX);
 $pivotY = Math_fround($pivotY);
 $generateOutOfBounds = $generateOutOfBounds|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692600);
 __THREW__ = 0;
 $0 = (invoke_iiiiiiifiiiiiiiiiffffi(1,0,($__this|0),($str|0),($font|0),($color|0),($fontSize|0),(+$lineSpacing),($style|0),($richText|0),($resizeTextForBestFit|0),($resizeTextMinSize|0),($resizeTextMaxSize|0),($verticalOverFlow|0),($horizontalOverflow|0),($updateBounds|0),($anchor|0),(+$extentsX),(+$extentsY),(+$pivotX),(+$pivotY),($generateOutOfBounds|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z75UnityEngine_UnityEngine_TextGenerator_m_INTERNAL_CALL_Populate_Internal_cppP22mscorlib_System_ObjectP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_StringP28UnityEngine_UnityEngine_FontP29UnityEngine_UnityEngine_Colorifibbiiiibiffffb($__this,$self,$str,$font,$color,$fontSize,$lineSpacing,$style,$richText,$resizeTextForBestFit,$resizeTextMinSize,$resizeTextMaxSize,$verticalOverFlow,$horizontalOverflow,$updateBounds,$anchor,$extentsX,$extentsY,$pivotX,$pivotY,$generateOutOfBounds) {
 $__this = $__this|0;
 $self = $self|0;
 $str = $str|0;
 $font = $font|0;
 $color = $color|0;
 $fontSize = $fontSize|0;
 $lineSpacing = Math_fround($lineSpacing);
 $style = $style|0;
 $richText = $richText|0;
 $resizeTextForBestFit = $resizeTextForBestFit|0;
 $resizeTextMinSize = $resizeTextMinSize|0;
 $resizeTextMaxSize = $resizeTextMaxSize|0;
 $verticalOverFlow = $verticalOverFlow|0;
 $horizontalOverflow = $horizontalOverflow|0;
 $updateBounds = $updateBounds|0;
 $anchor = $anchor|0;
 $extentsX = Math_fround($extentsX);
 $extentsY = Math_fround($extentsY);
 $pivotX = Math_fround($pivotX);
 $pivotY = Math_fround($pivotY);
 $generateOutOfBounds = $generateOutOfBounds|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2692648);
 $0 = HEAP32[2692696>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   __THREW__ = 0;
   $2 = (invoke_ii(3473,(2692704|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    $5 = ___cxa_find_matching_catch()|0;
    $6 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($5|0);
    // unreachable;
   } else {
    HEAP32[2692696>>2] = $2;
    $7 = $2;
    break;
   }
  } else {
   $7 = $0;
  }
 } while(0);
 __THREW__ = 0;
 $8 = (invoke_iiiiiifiiiiiiiiiffffi($7|0,($self|0),($str|0),($font|0),($color|0),($fontSize|0),(+$lineSpacing),($style|0),($richText|0),($resizeTextForBestFit|0),($resizeTextMinSize|0),($resizeTextMaxSize|0),($verticalOverFlow|0),($horizontalOverflow|0),($updateBounds|0),($anchor|0),(+$extentsX),(+$extentsY),(+$pivotX),(+$pivotY),($generateOutOfBounds|0))|0);
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($8|0);
 }
 return 0|0;
}
function __Z55UnityEngine_UnityEngine_TextGenerator_m_get_vertexCountP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693192);
 $0 = HEAP32[2693240>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2693248|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2693240>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z59UnityEngine_UnityEngine_TextGenerator_m_GetVerticesInternalP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_Object($__this,$vertices) {
 $__this = $__this|0;
 $vertices = $vertices|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693344);
 $0 = HEAP32[2693392>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2693400|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2693392>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($vertices|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z56UnityEngine_UnityEngine_TextGenerator_m_GetVerticesArrayP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693464);
 $0 = HEAP32[2693512>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2693520|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2693512>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z58UnityEngine_UnityEngine_TextGenerator_m_get_characterCountP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693568);
 $0 = HEAP32[2693616>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2693624|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2693616>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z61UnityEngine_UnityEngine_TextGenerator_m_GetCharactersInternalP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_Object($__this,$characters) {
 $__this = $__this|0;
 $characters = $characters|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693720);
 $0 = HEAP32[2693768>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2693776|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2693768>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($characters|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z58UnityEngine_UnityEngine_TextGenerator_m_GetCharactersArrayP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693840);
 $0 = HEAP32[2693888>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2693896|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2693888>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z53UnityEngine_UnityEngine_TextGenerator_m_get_lineCountP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2693944);
 $0 = HEAP32[2693992>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2694000|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2693992>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z56UnityEngine_UnityEngine_TextGenerator_m_GetLinesInternalP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_Object($__this,$lines) {
 $__this = $__this|0;
 $lines = $lines|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2694096);
 $0 = HEAP32[2694144>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2694152|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2694144>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($lines|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z53UnityEngine_UnityEngine_TextGenerator_m_GetLinesArrayP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2694216);
 $0 = HEAP32[2694264>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2694272|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2694264>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z66UnityEngine_UnityEngine_TextGenerator_m_get_fontSizeUsedForBestFitP37UnityEngine_UnityEngine_TextGenerator($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2694320);
 $0 = HEAP32[2694368>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2694376|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2694368>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I52UnityEngine_UnityEngine_TextGenerationSettingsTraitsS0_E6InvokeEPF46UnityEngine_UnityEngine_TextGenerationSettingsPvS2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $tmpcast$byval_copy = sp + 84|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$0+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2691592,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_SingleTraits17VoidPointerTraits52UnityEngine_UnityEngine_TextGenerationSettingsTraitsE6InvokeEPFfPvS4_46UnityEngine_UnityEngine_TextGenerationSettingsES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmpcast$byval_copy = sp + 4|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$2+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $3 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$0,$tmpcast$byval_copy)));
 HEAPF32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraits52UnityEngine_UnityEngine_TextGenerationSettingsTraitsE6InvokeEPFbPvS4_46UnityEngine_UnityEngine_TextGenerationSettingsES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 84|0;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$2+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $3 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$0,$tmpcast$byval_copy)|0);
 $4 = $3&1;
 HEAP8[$ret>>0] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN13FuncInvoker17I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_35UnityEngine_UnityEngine_ColorTraits27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsS3_S0_S0_S3_S3_S3_S3_S0_S3_37UnityEngine_UnityEngine_Vector2TraitsS5_S0_E6InvokeEPFbPvS7_S7_29UnityEngine_UnityEngine_Colorifibbiiiibi31UnityEngine_UnityEngine_Vector2S9_bES7_PS7_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast1$byval_copy = sp + 56|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp + 16|0;
 $ret = sp + 64|0;
 $0 = sp + 32|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = HEAP32[$args>>2]|0;
 $4 = (($args) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$7+12>>2]|0;
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($args) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($args) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)!=(0);
 $21 = (($args) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)!=(0);
 $25 = (($args) + 32|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($args) + 36|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($args) + 40|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($args) + 44|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($args) + 48|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)!=(0);
 $41 = (($args) + 52|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($args) + 56|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = $1;
 $53 = $52;
 HEAP32[$53>>2] = $48;
 $54 = (($52) + 4)|0;
 $55 = $54;
 HEAP32[$55>>2] = $51;
 $56 = (($args) + 60|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = $57;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = (($58) + 4)|0;
 $62 = $61;
 $63 = HEAP32[$62>>2]|0;
 $64 = $2;
 $65 = $64;
 HEAP32[$65>>2] = $60;
 $66 = (($64) + 4)|0;
 $67 = $66;
 HEAP32[$67>>2] = $63;
 $68 = (($args) + 64|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = HEAP8[$69>>0]|0;
 $71 = ($70<<24>>24)!=(0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 $72 = (FUNCTION_TABLE_iiiiiifiiiiiiiiiiii[$func & 1]($obj,$3,$5,$$byval_copy,$10,$13,$16,$20,$24,$27,$30,$33,$36,$40,$43,$tmpcast$byval_copy,$tmpcast1$byval_copy,$71)|0);
 $73 = $72&1;
 HEAP8[$ret>>0] = $73;
 $74 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($74|0);
}
function __ZN13FuncInvoker19I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_35UnityEngine_UnityEngine_ColorTraits27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsS3_S0_S0_S3_S3_S3_S3_S0_S3_S4_S4_S4_S4_S0_E6InvokeEPFbPvS6_S6_29UnityEngine_UnityEngine_ColorifibbiiiibiffffbES6_PS6_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = Math_fround(0), $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 16|0;
 $ret = sp + 32|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$5+12>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = (($args) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($args) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP8[$16>>0]|0;
 $18 = ($17<<24>>24)!=(0);
 $19 = (($args) + 28|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP8[$20>>0]|0;
 $22 = ($21<<24>>24)!=(0);
 $23 = (($args) + 32|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($args) + 36|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($args) + 40|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($args) + 44|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($args) + 48|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = HEAP8[$36>>0]|0;
 $38 = ($37<<24>>24)!=(0);
 $39 = (($args) + 52|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($args) + 56|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = Math_fround(HEAPF32[$43>>2]);
 $45 = (($args) + 60|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = Math_fround(HEAPF32[$46>>2]);
 $48 = (($args) + 64|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = Math_fround(HEAPF32[$49>>2]);
 $51 = (($args) + 68|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = Math_fround(HEAPF32[$52>>2]);
 $54 = (($args) + 72|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = HEAP8[$55>>0]|0;
 $57 = ($56<<24>>24)!=(0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $58 = (FUNCTION_TABLE_iiiiiifiiiiiiiiiffffi[$func & 3]($obj,$1,$3,$$byval_copy,$8,$11,$14,$18,$22,$25,$28,$31,$34,$38,$41,$44,$47,$50,$53,$57)|0);
 $59 = $58&1;
 HEAP8[$ret>>0] = $59;
 $60 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($60|0);
}
function __ZN13FuncInvoker20I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_S1_27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsS2_S0_S0_S2_S2_S2_S2_S0_S2_S3_S3_S3_S3_S0_E6InvokeEPFbPvS5_S5_S5_S5_ifibbiiiibiffffbES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($args) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($args) + 24|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($args) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = HEAP8[$17>>0]|0;
 $19 = ($18<<24>>24)!=(0);
 $20 = (($args) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)!=(0);
 $24 = (($args) + 36|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($args) + 40|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($args) + 44|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($args) + 48|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($args) + 52|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)!=(0);
 $40 = (($args) + 56|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($args) + 60|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = (($args) + 64|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = Math_fround(HEAPF32[$47>>2]);
 $49 = (($args) + 68|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = Math_fround(HEAPF32[$50>>2]);
 $52 = (($args) + 72|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = (($args) + 76|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = HEAP8[$56>>0]|0;
 $58 = ($57<<24>>24)!=(0);
 $59 = (FUNCTION_TABLE_iiiiiiifiiiiiiiiiffffi[$func & 1]($obj,$0,$2,$4,$6,$9,$12,$15,$19,$23,$26,$29,$32,$35,$39,$42,$45,$48,$51,$54,$58)|0);
 $60 = $59&1;
 HEAP8[$ret>>0] = $60;
 $61 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($61|0);
}
function __ZN12FuncInvoker0I34UnityEngine_UnityEngine_RectTraitsE6InvokeEPF28UnityEngine_UnityEngine_RectPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2797856,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z113UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_InitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z120UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_Dispose_cppP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z144UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_INTERNAL_CALL_Populate_Internal_cppP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z124UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_rectExtentsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z124UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_vertexCountP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z128UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetVerticesInternalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z125UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetVerticesArrayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z127UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_characterCountP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetCharactersInternalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z127UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetCharactersArrayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z122UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_lineCountP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z125UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetLinesInternalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z122UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetLinesArrayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_fontSizeUsedForBestFitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z49UnityEngine_UnityEngine_TrackedReference_m_EqualsP40UnityEngine_UnityEngine_TrackedReferenceP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2697024);
 __THREW__ = 0;
 (invoke_ii(2996,(2697336|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($o|0),(2697336|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiii(1313,0,($2|0),($__this|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z160UnityEngine_UnityEngine_TrackedReference_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_TrackedReference_UnityEngine_UnityEngine_TrackedReferenceP22mscorlib_System_ObjectP40UnityEngine_UnityEngine_TrackedReferenceS2_($__this,$x,$y) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 var $$0 = 0, $$byval_copy4 = 0, $$byval_copy5 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy5 = sp + 32|0;
 $$byval_copy4 = sp + 28|0;
 $_stackTraceSentry = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp + 4|0;
 $4 = sp;
 $5 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2697120);
 $6 = ($y|0)!=(0|0);
 $$not = $6 ^ 1;
 $7 = ($x|0)==(0|0);
 $or$cond = $7 & $$not;
 if ($or$cond) {
  $$0 = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 do {
  if ($6) {
   if ($7) {
    __THREW__ = 0;
    invoke_vi(3799,($y|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = (($y) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2210080|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = HEAP32[((2210080 + 80|0))>>2]|0;
    $28 = HEAP32[$27>>2]|0;
    HEAP32[$2>>2] = $24;
    HEAP32[$3>>2] = $28;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$2+0>>2]|0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$3+0>>2]|0;
    $29 = (invoke_iiii(643,(0|0),($$byval_copy4|0),($$byval_copy5|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    } else {
     $$0 = $29;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($x|0));
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    $34 = (($x) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($y|0));
    $36 = __THREW__; __THREW__ = 0;
    $37 = $36&1;
    if ($37) {
     break;
    }
    $38 = (($y) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$4>>2] = $35;
    HEAP32[$5>>2] = $39;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
    ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
    $40 = (invoke_iiii(643,(0|0),($$byval_copy4|0),($$byval_copy5|0))|0);
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    } else {
     $$0 = $40;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($x|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($x) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2210080|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = HEAP32[((2210080 + 80|0))>>2]|0;
     $15 = HEAP32[$14>>2]|0;
     HEAP32[$0>>2] = $11;
     HEAP32[$1>>2] = $15;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$0+0>>2]|0;
     ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$1+0>>2]|0;
     $16 = (invoke_iiii(643,(0|0),($$byval_copy4|0),($$byval_copy5|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      $$0 = $16;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($19|0);
 // unreachable;
 return 0|0;
}
function __Z54UnityEngine_UnityEngine_TrackedReference_m_GetHashCodeP40UnityEngine_UnityEngine_TrackedReference($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2697072);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (invoke_iii(717,(0|0),($$byval_copy|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z55UnityEngine_UnityEngine_Application_LogCallback_m__ctorP47UnityEngine_UnityEngine_Application_LogCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2697472);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z56UnityEngine_UnityEngine_Application_LogCallback_m_InvokeP47UnityEngine_UnityEngine_Application_LogCallbackP22mscorlib_System_StringS2_i($__this,$condition,$stackTrace,$type) {
 $__this = $__this|0;
 $condition = $condition|0;
 $stackTrace = $stackTrace|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2697520);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  invoke_viiii(212,($1|0),($condition|0),($stackTrace|0),($type|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 invoke_viiii($8|0,($10|0),($condition|0),($stackTrace|0),($type|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z61UnityEngine_UnityEngine_Application_LogCallback_m_BeginInvokeP47UnityEngine_UnityEngine_Application_LogCallbackP22mscorlib_System_StringS2_iP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$condition,$stackTrace,$type,$callback,$object) {
 $__this = $__this|0;
 $condition = $condition|0;
 $stackTrace = $stackTrace|0;
 $type = $type|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2697568);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z59UnityEngine_UnityEngine_Application_LogCallback_m_EndInvokeP47UnityEngine_UnityEngine_Application_LogCallbackP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2697616);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker5I17VoidPointerTraitsS0_S0_27mscorlib_System_Int32TraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_S4_S4_iS4_P22mscorlib_System_ObjectES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (FUNCTION_TABLE_iiiiiii[$func & 255]($obj,$0,$2,$5,$7,$9)|0);
 STACKTOP = sp;return ($10|0);
}
function __Z54UnityEngine_UnityEngine_Application_m_ObjectToJSStringP22mscorlib_System_ObjectS0_($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = Math_fround(0), $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0.0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $L_13 = 0, $L_16 = 0, $L_42 = 0, $L_46 = 0, $V_6$043 = 0, $V_7 = 0, $V_8 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 12|0;
 $V_7 = sp + 8|0;
 $V_8 = sp;
 $L_13 = sp + 22|0;
 $L_16 = sp + 16|0;
 $L_42 = sp + 18|0;
 $L_46 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2698072);
 HEAPF32[$V_7>>2] = Math_fround(0.0);
 HEAPF64[$V_8>>3] = 0.0;
 __THREW__ = 0;
 invoke_v(957);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($o|0)==(0|0);
   if ($2) {
    $7 = HEAP32[2997384>>2]|0;
    $$0 = $7;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2735,($o|0),(2191608|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = ($10|0)==(0|0);
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3799,($o|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      __THREW__ = 0;
      $16 = (invoke_iii(2730,(2149112|0),($o|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($16|0));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      $21 = HEAP32[2997392>>2]|0;
      $22 = HEAP32[2997400>>2]|0;
      __THREW__ = 0;
      $23 = (invoke_iiii(548,($16|0),($21|0),($22|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($23|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
      $28 = HEAP32[2997408>>2]|0;
      $29 = HEAP32[2997416>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iiii(548,($23|0),($28|0),($29|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($30|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      $35 = HEAP32[2997424>>2]|0;
      $36 = HEAP32[2997432>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_iiii(548,($30|0),($35|0),($36|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      $42 = HEAP32[2997440>>2]|0;
      $43 = HEAP32[2997448>>2]|0;
      __THREW__ = 0;
      $44 = (invoke_iiii(548,($37|0),($42|0),($43|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
      $49 = HEAP8[((2191608 + 116|0))>>0]|0;
      $50 = ($49<<24>>24)==(0);
      if ($50) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2191608|0));
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       break;
      }
      $59 = HEAP32[((2191608 + 80|0))>>2]|0;
      $60 = HEAP32[$59>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($44|0));
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      $63 = HEAP32[2997456>>2]|0;
      __THREW__ = 0;
      $64 = (invoke_iiii(548,($44|0),($63|0),($60|0))|0);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       break;
      }
      $69 = HEAP8[((2191608 + 116|0))>>0]|0;
      $70 = ($69<<24>>24)==(0);
      if ($70) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $71 = __THREW__; __THREW__ = 0;
       $72 = $71&1;
       if ($72) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2191608|0));
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       break;
      }
      $79 = HEAP32[((2191608 + 80|0))>>2]|0;
      $80 = HEAP32[$79>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($64|0));
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       break;
      }
      $83 = HEAP32[2997464>>2]|0;
      __THREW__ = 0;
      $84 = (invoke_iiii(548,($64|0),($83|0),($80|0))|0);
      $85 = __THREW__; __THREW__ = 0;
      $86 = $85&1;
      if ($86) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $87 = __THREW__; __THREW__ = 0;
      $88 = $87&1;
      if ($88) {
       break;
      }
      $89 = HEAP8[((2191608 + 116|0))>>0]|0;
      $90 = ($89<<24>>24)==(0);
      if ($90) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $91 = __THREW__; __THREW__ = 0;
       $92 = $91&1;
       if ($92) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if ($94) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2191608|0));
       $95 = __THREW__; __THREW__ = 0;
       $96 = $95&1;
       if ($96) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $97 = __THREW__; __THREW__ = 0;
      $98 = $97&1;
      if ($98) {
       break;
      }
      $99 = HEAP32[((2191608 + 80|0))>>2]|0;
      $100 = HEAP32[$99>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($84|0));
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       break;
      }
      $103 = HEAP32[2997472>>2]|0;
      __THREW__ = 0;
      $104 = (invoke_iiii(548,($84|0),($103|0),($100|0))|0);
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       break;
      }
      HEAP16[$L_13>>1] = 34;
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $107 = __THREW__; __THREW__ = 0;
      $108 = $107&1;
      if ($108) {
       break;
      }
      __THREW__ = 0;
      $109 = (invoke_iii(2724,(2180696|0),($L_13|0))|0);
      $110 = __THREW__; __THREW__ = 0;
      $111 = $110&1;
      if ($111) {
       break;
      }
      HEAP16[$L_16>>1] = 34;
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $112 = __THREW__; __THREW__ = 0;
      $113 = $112&1;
      if ($113) {
       break;
      }
      __THREW__ = 0;
      $114 = (invoke_iii(2724,(2180696|0),($L_16|0))|0);
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       break;
      }
      __THREW__ = 0;
      $117 = (invoke_iiiii(100,(0|0),($109|0),($104|0),($114|0))|0);
      $118 = __THREW__; __THREW__ = 0;
      $119 = $118&1;
      if ($119) {
       break;
      } else {
       $$0 = $117;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $120 = __THREW__; __THREW__ = 0;
     $121 = $120&1;
     if (!($121)) {
      __THREW__ = 0;
      $122 = (invoke_iii(2735,($o|0),(2155952|0))|0);
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if (!($124)) {
       $125 = ($122|0)==(0|0);
       do {
        if ($125) {
         __THREW__ = 0;
         (invoke_ii(2996,(2173776|0))|0);
         $126 = __THREW__; __THREW__ = 0;
         $127 = $126&1;
         if ($127) {
          break L1;
         }
         __THREW__ = 0;
         $128 = (invoke_iii(2735,($o|0),(2173776|0))|0);
         $129 = __THREW__; __THREW__ = 0;
         $130 = $129&1;
         if ($130) {
          break L1;
         }
         $131 = ($128|0)==(0|0);
         if ($131) {
          __THREW__ = 0;
          (invoke_ii(2996,(2164560|0))|0);
          $132 = __THREW__; __THREW__ = 0;
          $133 = $132&1;
          if ($133) {
           break L1;
          }
          __THREW__ = 0;
          $134 = (invoke_iii(2735,($o|0),(2164560|0))|0);
          $135 = __THREW__; __THREW__ = 0;
          $136 = $135&1;
          if ($136) {
           break L1;
          }
          $137 = ($134|0)==(0|0);
          if ($137) {
           __THREW__ = 0;
           (invoke_ii(2996,(2176024|0))|0);
           $138 = __THREW__; __THREW__ = 0;
           $139 = $138&1;
           if ($139) {
            break L1;
           }
           __THREW__ = 0;
           $140 = (invoke_iii(2735,($o|0),(2176024|0))|0);
           $141 = __THREW__; __THREW__ = 0;
           $142 = $141&1;
           if ($142) {
            break L1;
           }
           $143 = ($140|0)==(0|0);
           if ($143) {
            __THREW__ = 0;
            (invoke_ii(2996,(2169424|0))|0);
            $144 = __THREW__; __THREW__ = 0;
            $145 = $144&1;
            if ($145) {
             break L1;
            }
            __THREW__ = 0;
            $146 = (invoke_iii(2735,($o|0),(2169424|0))|0);
            $147 = __THREW__; __THREW__ = 0;
            $148 = $147&1;
            if ($148) {
             break L1;
            }
            $149 = ($146|0)==(0|0);
            if (!($149)) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2194912|0))|0);
            $155 = __THREW__; __THREW__ = 0;
            $156 = $155&1;
            if ($156) {
             break L1;
            }
            __THREW__ = 0;
            $157 = (invoke_iii(2735,($o|0),(2194912|0))|0);
            $158 = __THREW__; __THREW__ = 0;
            $159 = $158&1;
            if ($159) {
             break L1;
            }
            $160 = ($157|0)==(0|0);
            if (!($160)) {
             __THREW__ = 0;
             $161 = (invoke_ii(1982,(0|0))|0);
             $162 = __THREW__; __THREW__ = 0;
             $163 = $162&1;
             if ($163) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3799,($161|0));
             $164 = __THREW__; __THREW__ = 0;
             $165 = $164&1;
             if ($165) {
              break L1;
             }
             __THREW__ = 0;
             $166 = (invoke_iii(2730,(2330184|0),($161|0))|0);
             $167 = __THREW__; __THREW__ = 0;
             $168 = $167&1;
             if ($168) {
              break L1;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2194912|0))|0);
             $169 = __THREW__; __THREW__ = 0;
             $170 = $169&1;
             if ($170) {
              break L1;
             }
             __THREW__ = 0;
             $171 = (invoke_iii(2775,($o|0),(2194912|0))|0);
             $172 = __THREW__; __THREW__ = 0;
             $173 = $172&1;
             if ($173) {
              break L1;
             }
             $174 = Math_fround(HEAPF32[$171>>2]);
             HEAPF32[$V_7>>2] = $174;
             __THREW__ = 0;
             $175 = (invoke_iii(656,($V_7|0),($166|0))|0);
             $176 = __THREW__; __THREW__ = 0;
             $177 = $176&1;
             if ($177) {
              break L1;
             } else {
              $$0 = $175;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2198192|0))|0);
            $178 = __THREW__; __THREW__ = 0;
            $179 = $178&1;
            if ($179) {
             break L1;
            }
            __THREW__ = 0;
            $180 = (invoke_iii(2735,($o|0),(2198192|0))|0);
            $181 = __THREW__; __THREW__ = 0;
            $182 = $181&1;
            if ($182) {
             break L1;
            }
            $183 = ($180|0)==(0|0);
            if (!($183)) {
             __THREW__ = 0;
             $184 = (invoke_ii(1982,(0|0))|0);
             $185 = __THREW__; __THREW__ = 0;
             $186 = $185&1;
             if ($186) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3799,($184|0));
             $187 = __THREW__; __THREW__ = 0;
             $188 = $187&1;
             if ($188) {
              break L1;
             }
             __THREW__ = 0;
             $189 = (invoke_iii(2730,(2330184|0),($184|0))|0);
             $190 = __THREW__; __THREW__ = 0;
             $191 = $190&1;
             if ($191) {
              break L1;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2198192|0))|0);
             $192 = __THREW__; __THREW__ = 0;
             $193 = $192&1;
             if ($193) {
              break L1;
             }
             __THREW__ = 0;
             $194 = (invoke_iii(2775,($o|0),(2198192|0))|0);
             $195 = __THREW__; __THREW__ = 0;
             $196 = $195&1;
             if ($196) {
              break L1;
             }
             $197 = +HEAPF64[$194>>3];
             HEAPF64[$V_8>>3] = $197;
             __THREW__ = 0;
             $198 = (invoke_iii(670,($V_8|0),($189|0))|0);
             $199 = __THREW__; __THREW__ = 0;
             $200 = $199&1;
             if ($200) {
              break L1;
             } else {
              $$0 = $198;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2180696|0))|0);
            $201 = __THREW__; __THREW__ = 0;
            $202 = $201&1;
            if ($202) {
             break L1;
            }
            __THREW__ = 0;
            $203 = (invoke_iii(2735,($o|0),(2180696|0))|0);
            $204 = __THREW__; __THREW__ = 0;
            $205 = $204&1;
            if ($205) {
             break L1;
            }
            $206 = ($203|0)==(0|0);
            if (!($206)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2180696|0))|0);
             $207 = __THREW__; __THREW__ = 0;
             $208 = $207&1;
             if ($208) {
              break L1;
             }
             __THREW__ = 0;
             $209 = (invoke_iii(2775,($o|0),(2180696|0))|0);
             $210 = __THREW__; __THREW__ = 0;
             $211 = $210&1;
             if ($211) {
              break L1;
             }
             $212 = HEAP16[$209>>1]|0;
             $213 = ($212<<16>>16)==(34);
             if ($213) {
              $214 = HEAP32[2997480>>2]|0;
              $$0 = $214;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($$0|0);
             }
             HEAP16[$L_42>>1] = 34;
             __THREW__ = 0;
             (invoke_ii(2996,(2180696|0))|0);
             $215 = __THREW__; __THREW__ = 0;
             $216 = $215&1;
             if ($216) {
              break L1;
             }
             __THREW__ = 0;
             $217 = (invoke_iii(2724,(2180696|0),($L_42|0))|0);
             $218 = __THREW__; __THREW__ = 0;
             $219 = $218&1;
             if ($219) {
              break L1;
             }
             __THREW__ = 0;
             invoke_vi(3799,($o|0));
             $220 = __THREW__; __THREW__ = 0;
             $221 = $220&1;
             if ($221) {
              break L1;
             }
             __THREW__ = 0;
             $222 = (invoke_iii(2730,(2149112|0),($o|0))|0);
             $223 = __THREW__; __THREW__ = 0;
             $224 = $223&1;
             if ($224) {
              break L1;
             }
             HEAP16[$L_46>>1] = 34;
             __THREW__ = 0;
             (invoke_ii(2996,(2180696|0))|0);
             $225 = __THREW__; __THREW__ = 0;
             $226 = $225&1;
             if ($226) {
              break L1;
             }
             __THREW__ = 0;
             $227 = (invoke_iii(2724,(2180696|0),($L_46|0))|0);
             $228 = __THREW__; __THREW__ = 0;
             $229 = $228&1;
             if ($229) {
              break L1;
             }
             __THREW__ = 0;
             $230 = (invoke_iiiii(100,(0|0),($217|0),($222|0),($227|0))|0);
             $231 = __THREW__; __THREW__ = 0;
             $232 = $231&1;
             if ($232) {
              break L1;
             } else {
              $$0 = $230;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2232376|0))|0);
            $233 = __THREW__; __THREW__ = 0;
            $234 = $233&1;
            if ($234) {
             break L1;
            }
            __THREW__ = 0;
            $235 = (invoke_iii(2735,($o|0),(2232376|0))|0);
            $236 = __THREW__; __THREW__ = 0;
            $237 = $236&1;
            if ($237) {
             break L1;
            }
            $238 = ($235|0)==(0|0);
            if ($238) {
             __THREW__ = 0;
             invoke_vi(3799,($o|0));
             $292 = __THREW__; __THREW__ = 0;
             $293 = $292&1;
             if ($293) {
              break L1;
             }
             __THREW__ = 0;
             $294 = (invoke_iii(2730,(2149112|0),($o|0))|0);
             $295 = __THREW__; __THREW__ = 0;
             $296 = $295&1;
             if ($296) {
              break L1;
             }
             __THREW__ = 0;
             $297 = (invoke_iii(1188,0,($294|0))|0);
             $298 = __THREW__; __THREW__ = 0;
             $299 = $298&1;
             if ($299) {
              break L1;
             } else {
              $$0 = $297;
             }
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2232376|0))|0);
            $239 = __THREW__; __THREW__ = 0;
            $240 = $239&1;
            if ($240) {
             break L1;
            }
            __THREW__ = 0;
            $241 = (invoke_iii(2774,($o|0),(2232376|0))|0);
            $242 = __THREW__; __THREW__ = 0;
            $243 = $242&1;
            if ($243) {
             break L1;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2537888|0))|0);
            $244 = __THREW__; __THREW__ = 0;
            $245 = $244&1;
            if ($245) {
             break L1;
            }
            __THREW__ = 0;
            $246 = (invoke_ii(3469,(2537888|0))|0);
            $247 = __THREW__; __THREW__ = 0;
            $248 = $247&1;
            if ($248) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(2525,($246|0));
            $249 = __THREW__; __THREW__ = 0;
            $250 = $249&1;
            if ($250) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3799,($246|0));
            $251 = __THREW__; __THREW__ = 0;
            $252 = $251&1;
            if ($252) {
             break L1;
            }
            $253 = HEAP32[2997488>>2]|0;
            __THREW__ = 0;
            (invoke_iii(989,($246|0),($253|0))|0);
            $254 = __THREW__; __THREW__ = 0;
            $255 = $254&1;
            if ($255) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3799,($241|0));
            $256 = __THREW__; __THREW__ = 0;
            $257 = $256&1;
            if ($257) {
             break L1;
            }
            __THREW__ = 0;
            $258 = (invoke_iii(2736,(2231272|0),($241|0))|0);
            $259 = __THREW__; __THREW__ = 0;
            $260 = $259&1;
            if ($260) {
             break L1;
            }
            $261 = ($258|0)>(0);
            L127: do {
             if ($261) {
              $V_6$043 = 0;
              while(1) {
               $281 = ($V_6$043|0)==(0);
               if (!($281)) {
                __THREW__ = 0;
                invoke_vi(3799,($246|0));
                $262 = __THREW__; __THREW__ = 0;
                $263 = $262&1;
                if ($263) {
                 break;
                }
                $264 = HEAP32[2997496>>2]|0;
                __THREW__ = 0;
                (invoke_iii(989,($246|0),($264|0))|0);
                $265 = __THREW__; __THREW__ = 0;
                $266 = $265&1;
                if ($266) {
                 break;
                }
               }
               __THREW__ = 0;
               invoke_vi(3799,($241|0));
               $267 = __THREW__; __THREW__ = 0;
               $268 = $267&1;
               if ($268) {
                break;
               }
               __THREW__ = 0;
               $269 = (invoke_iiii(1681,(2231680|0),($241|0),($V_6$043|0))|0);
               $270 = __THREW__; __THREW__ = 0;
               $271 = $270&1;
               if ($271) {
                break;
               }
               __THREW__ = 0;
               $272 = (invoke_iii(1188,0,($269|0))|0);
               $273 = __THREW__; __THREW__ = 0;
               $274 = $273&1;
               if ($274) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($246|0));
               $275 = __THREW__; __THREW__ = 0;
               $276 = $275&1;
               if ($276) {
                break;
               }
               __THREW__ = 0;
               (invoke_iii(989,($246|0),($272|0))|0);
               $277 = __THREW__; __THREW__ = 0;
               $278 = $277&1;
               if ($278) {
                break;
               }
               $279 = (($V_6$043) + 1)|0;
               $280 = ($279|0)<($258|0);
               if ($280) {
                $V_6$043 = $279;
               } else {
                break L127;
               }
              }
              $3 = ___cxa_find_matching_catch()|0;
              $4 = tempRet0;
              $lpad$phi$index = $3;$lpad$phi$index2 = $4;
              __ZN16StackTraceSentryD2Ev(0);
              ___resumeException($lpad$phi$index|0);
              // unreachable;
             }
            } while(0);
            __THREW__ = 0;
            invoke_vi(3799,($246|0));
            $282 = __THREW__; __THREW__ = 0;
            $283 = $282&1;
            if ($283) {
             break L1;
            }
            $284 = HEAP32[2997504>>2]|0;
            __THREW__ = 0;
            (invoke_iii(989,($246|0),($284|0))|0);
            $285 = __THREW__; __THREW__ = 0;
            $286 = $285&1;
            if ($286) {
             break L1;
            }
            __THREW__ = 0;
            invoke_vi(3799,($246|0));
            $287 = __THREW__; __THREW__ = 0;
            $288 = $287&1;
            if ($288) {
             break L1;
            }
            __THREW__ = 0;
            $289 = (invoke_iii(2730,(2535432|0),($246|0))|0);
            $290 = __THREW__; __THREW__ = 0;
            $291 = $290&1;
            if ($291) {
             break L1;
            }
            $$0 = $289;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
          }
         }
        }
       } while(0);
       __THREW__ = 0;
       invoke_vi(3799,($o|0));
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if (!($151)) {
        __THREW__ = 0;
        $152 = (invoke_iii(2730,(2149112|0),($o|0))|0);
        $153 = __THREW__; __THREW__ = 0;
        $154 = $153&1;
        if (!($154)) {
         $$0 = $152;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo10837($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN21InterfaceFuncInvoker1I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi($method,$obj,$p1) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$3 & 4095]($4,$p1)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z50UnityEngine_UnityEngine_Application_m_ExternalCallP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$functionName,$args) {
 $__this = $__this|0;
 $functionName = $functionName|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2698120);
 __THREW__ = 0;
 $0 = (invoke_iiii(1315,0,($functionName|0),($args|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vii(2001,0,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z65UnityEngine_UnityEngine_Application_m_BuildInvocationForArgumentsP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$functionName,$args) {
 $__this = $__this|0;
 $functionName = $functionName|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$01 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2698168);
 __THREW__ = 0;
 invoke_v(958);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2537888|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2537888|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(2525,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     invoke_vi(3799,($4|0));
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      (invoke_iii(989,($4|0),($functionName|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        __THREW__ = 0;
        (invoke_iii(992,($4|0),40)|0);
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         __THREW__ = 0;
         invoke_vi(3799,($args|0));
         $17 = __THREW__; __THREW__ = 0;
         $18 = $17&1;
         if (!($18)) {
          $19 = (($args) + 12|0);
          $20 = HEAP32[$19>>2]|0;
          $21 = ($20|0)>(0);
          L11: do {
           if ($21) {
            $22 = (($args) + 16|0);
            $V_2$01 = 0;
            while(1) {
             $56 = ($V_2$01|0)==(0);
             if (!($56)) {
              __THREW__ = 0;
              invoke_vi(3799,($4|0));
              $27 = __THREW__; __THREW__ = 0;
              $28 = $27&1;
              if ($28) {
               break;
              }
              $29 = HEAP32[2997624>>2]|0;
              __THREW__ = 0;
              (invoke_iii(989,($4|0),($29|0))|0);
              $30 = __THREW__; __THREW__ = 0;
              $31 = $30&1;
              if ($31) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vi(3799,($args|0));
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if ($33) {
              break;
             }
             $34 = HEAP32[$19>>2]|0;
             $35 = ($V_2$01>>>0)<($34>>>0);
             if (!($35)) {
              __THREW__ = 0;
              $36 = (invoke_i(132)|0);
              $37 = __THREW__; __THREW__ = 0;
              $38 = $37&1;
              if ($38) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($36|0));
              $39 = __THREW__; __THREW__ = 0;
              $40 = $39&1;
              if ($40) {
               break;
              }
             }
             $41 = HEAP32[$args>>2]|0;
             $42 = (($41) + 92|0);
             $43 = HEAP32[$42>>2]|0;
             $44 = Math_imul($43, $V_2$01)|0;
             $45 = (($22) + ($44)|0);
             $46 = HEAP32[$45>>2]|0;
             __THREW__ = 0;
             $47 = (invoke_iii(1188,0,($46|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             (invoke_iii(989,($4|0),($47|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             $54 = (($V_2$01) + 1)|0;
             $55 = ($54|0)<($20|0);
             if ($55) {
              $V_2$01 = $54;
             } else {
              break L11;
             }
            }
            $23 = ___cxa_find_matching_catch()|0;
            $24 = tempRet0;
            $lpad$phi$index = $23;$lpad$phi$index2 = $24;
            __ZN16StackTraceSentryD2Ev(0);
            ___resumeException($lpad$phi$index|0);
            // unreachable;
           }
          } while(0);
          __THREW__ = 0;
          invoke_vi(3799,($4|0));
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if (!($58)) {
           __THREW__ = 0;
           (invoke_iii(992,($4|0),41)|0);
           $59 = __THREW__; __THREW__ = 0;
           $60 = $59&1;
           if (!($60)) {
            __THREW__ = 0;
            invoke_vi(3799,($4|0));
            $61 = __THREW__; __THREW__ = 0;
            $62 = $61&1;
            if (!($62)) {
             __THREW__ = 0;
             (invoke_iii(992,($4|0),59)|0);
             $63 = __THREW__; __THREW__ = 0;
             $64 = $63&1;
             if (!($64)) {
              __THREW__ = 0;
              invoke_vi(3799,($4|0));
              $65 = __THREW__; __THREW__ = 0;
              $66 = $65&1;
              if (!($66)) {
               __THREW__ = 0;
               $67 = (invoke_iii(2730,(2535432|0),($4|0))|0);
               $68 = __THREW__; __THREW__ = 0;
               $69 = $68&1;
               if (!($69)) {
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($67|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 $lpad$phi$index = $25;$lpad$phi$index2 = $26;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z59UnityEngine_UnityEngine_Application_m_Internal_ExternalCallP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$script) {
 $__this = $__this|0;
 $script = $script|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2698216);
 $0 = HEAP32[2698264>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2698272|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2698264>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($script|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z53UnityEngine_UnityEngine_Application_m_CallLogCallbackP22mscorlib_System_ObjectP22mscorlib_System_StringS2_ib($__this,$logString,$stackTrace,$type,$invokedOnMainThread) {
 $__this = $__this|0;
 $logString = $logString|0;
 $stackTrace = $stackTrace|0;
 $type = $type|0;
 $invokedOnMainThread = $invokedOnMainThread|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2698336);
 if ($invokedOnMainThread) {
  __THREW__ = 0;
  (invoke_ii(2996,(2698824|0))|0);
  $0 = __THREW__; __THREW__ = 0;
  $1 = $0&1;
  if (!($1)) {
   $2 = HEAP32[((2698824 + 80|0))>>2]|0;
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    invoke_viiiii(120,(2697520|0),($3|0),($logString|0),($stackTrace|0),($type|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } else {
  __THREW__ = 0;
  (invoke_ii(2996,(2698824|0))|0);
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   $13 = HEAP32[((2698824 + 80|0))>>2]|0;
   $14 = (($13) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if ($16) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3799,($15|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    __THREW__ = 0;
    invoke_viiiii(120,(2697520|0),($15|0),($logString|0),($stackTrace|0),($type|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN18VirtActionInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS5_S5_i($method,$obj,$p1,$p2,$p3) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($4,$p1,$p2,$p3);
 STACKTOP = sp;return;
}
function __Z126UnityEngine_UnityEngine_Application_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Application_m_Internal_ExternalCallP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z41UnityEngine_UnityEngine_Component_m__ctorP33UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2698960);
 __THREW__ = 0;
 invoke_vi(2862,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z38UnityEngine_UnityEngine_Object_m__ctorP30UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2700944);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z49UnityEngine_UnityEngine_Component_m_get_transformP33UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2699008);
 $0 = HEAP32[2699056>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2699064|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2699056>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z103UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Component_mscorlib_System_TypeP33UnityEngine_UnityEngine_ComponentP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2699200);
 __THREW__ = 0;
 $0 = (invoke_ii(2523,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iii(1191,($0|0),($type|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z49UnityEngine_UnityEngine_GameObject_m_GetComponentP34UnityEngine_UnityEngine_GameObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2700072);
 $0 = HEAP32[2700120>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2700128|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2700120>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z157UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Object_UnityEngine_UnityEngine_SendMessageOptionsP33UnityEngine_UnityEngine_ComponentP22mscorlib_System_StringP22mscorlib_System_Objecti($__this,$methodName,$value,$options) {
 $__this = $__this|0;
 $methodName = $methodName|0;
 $value = $value|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2699248);
 $0 = HEAP32[2699296>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2699304|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2699296>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiii($7|0,($__this|0),($methodName|0),($value|0),($options|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z91UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_StringP33UnityEngine_UnityEngine_ComponentP22mscorlib_System_String($__this,$methodName) {
 $__this = $__this|0;
 $methodName = $methodName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2699400);
 __THREW__ = 0;
 invoke_viiii(213,($__this|0),($methodName|0),(0|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z134UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_String_UnityEngine_UnityEngine_SendMessageOptionsP33UnityEngine_UnityEngine_ComponentP22mscorlib_System_Stringi($__this,$methodName,$options) {
 $__this = $__this|0;
 $methodName = $methodName|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2699448);
 __THREW__ = 0;
 invoke_viiii(213,($__this|0),($methodName|0),(0|0),($options|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_P22mscorlib_System_ObjectiES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$2,$5);
 STACKTOP = sp;return (0|0);
}
function __Z114UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_get_transformP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_get_gameObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z168UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Component_mscorlib_System_TypeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2709912)|0);
 __Z138UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngineInternal_TypeInferenceRulesP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributei($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z138UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngineInternal_TypeInferenceRulesP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributei($__this,$rule) {
 $__this = $__this|0;
 $rule = $rule|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2709592);
 HEAP32[$L_0>>2] = $rule;
 __THREW__ = 0;
 (invoke_ii(2996,(2709456|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2724,(2709456|0),($L_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2730,(2216144|0),($2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vii(2010,($__this|0),($7|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z222UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Object_UnityEngine_UnityEngine_SendMessageOptionsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z156UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_StringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2708352);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52UnityEngine_UnityEngine_GameObject_m_CreatePrimitiveP22mscorlib_System_Objecti($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2699944);
 $0 = HEAP32[2699992>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2700000|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2699992>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z50UnityEngine_UnityEngine_GameObject_m_get_transformP34UnityEngine_UnityEngine_GameObject($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2700184);
 $0 = HEAP32[2700232>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2700240|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2700232>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z44UnityEngine_UnityEngine_GameObject_m_set_tagP34UnityEngine_UnityEngine_GameObjectP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2700280);
 $0 = HEAP32[2700328>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2700336|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2700328>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z118UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_CreatePrimitiveP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_GetComponentP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2709912)|0);
 __Z138UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngineInternal_TypeInferenceRulesP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributei($6,0);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z116UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_get_transformP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_set_tagP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z114UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_SendMessageP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Object_m_EqualsP30UnityEngine_UnityEngine_ObjectP22mscorlib_System_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2700992);
 __THREW__ = 0;
 (invoke_ii(2996,(2702448|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($o|0),(2702448|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_iiii(1317,0,($__this|0),($2|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z51UnityEngine_UnityEngine_Object_m_CompareBaseObjectsP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_ObjectS2_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, $brmerge$demorgan = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701088);
 $0 = ($lhs|0)==(0|0);
 $1 = ($rhs|0)==(0|0);
 $brmerge$demorgan = $1 & $0;
 L1: do {
  if ($brmerge$demorgan) {
   $$0 = 1;
  } else {
   do {
    if ($1) {
     __THREW__ = 0;
     $2 = (invoke_iii(1193,0,($lhs|0))|0);
     $3 = __THREW__; __THREW__ = 0;
     $4 = $3&1;
     if (!($4)) {
      $5 = $2 ^ 1;
      $$0 = $5;
      break L1;
     }
    } else {
     if (!($0)) {
      __THREW__ = 0;
      $12 = (invoke_iiii(424,(0|0),($lhs|0),($rhs|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if ($14) {
       break;
      } else {
       $$0 = $12;
       break L1;
      }
     }
     __THREW__ = 0;
     $8 = (invoke_iii(1193,0,($rhs|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = $8 ^ 1;
      $$0 = $11;
      break L1;
     }
    }
   } while(0);
   $6 = ___cxa_find_matching_catch()|0;
   $7 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($6|0);
   // unreachable;
  }
 } while(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z44UnityEngine_UnityEngine_Object_m_GetHashCodeP30UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701040);
 __THREW__ = 0;
 $0 = (invoke_ii(2526,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_Object_m_GetInstanceIDP30UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701184);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52UnityEngine_UnityEngine_Object_m_IsNativeObjectAliveP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Object($__this,$o) {
 $__this = $__this|0;
 $o = $o|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 16|0;
 $$byval_copy = sp;
 $_stackTraceSentry = sp + 4|0;
 $0 = sp + 8|0;
 $1 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701136);
 __THREW__ = 0;
 invoke_vi(3799,($o|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_ii(2527,($o|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2210080|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[((2210080 + 80|0))>>2]|0;
    $10 = HEAP32[$9>>2]|0;
    HEAP32[$0>>2] = $4;
    HEAP32[$1>>2] = $10;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
    $11 = (invoke_iiii(645,(0|0),($$byval_copy|0),($$byval_copy1|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($11|0);
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_Object_m_GetCachedPtrP30UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701232);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z115UnityEngine_UnityEngine_Object_m_Destroy_mscorlib_System_Void_UnityEngine_UnityEngine_Object_mscorlib_System_SingleP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Objectf($__this,$obj,$t) {
 $__this = $__this|0;
 $obj = $obj|0;
 $t = Math_fround($t);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701280);
 $0 = HEAP32[2701328>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2701336|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2701328>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vif($7|0,($obj|0),(+$t));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z92UnityEngine_UnityEngine_Object_m_Destroy_mscorlib_System_Void_UnityEngine_UnityEngine_ObjectP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701400);
 __THREW__ = 0;
 invoke_viif(23,0,($obj|0),0.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z41UnityEngine_UnityEngine_Object_m_get_nameP30UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701448);
 $0 = HEAP32[2701496>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2701504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2701496>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z41UnityEngine_UnityEngine_Object_m_set_nameP30UnityEngine_UnityEngine_ObjectP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701536);
 $0 = HEAP32[2701584>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2701592|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2701584>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z41UnityEngine_UnityEngine_Object_m_ToStringP30UnityEngine_UnityEngine_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2701640);
 $0 = HEAP32[2701688>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2701696|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2701688>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z177UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_Destroy_mscorlib_System_Void_UnityEngine_UnityEngine_Object_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z154UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_Destroy_mscorlib_System_Void_UnityEngine_UnityEngine_ObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z103UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_get_nameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z103UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_set_nameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z103UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_ToStringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z58UnityEngine_UnityEngine_Events_PersistentCallGroup_m__ctorP50UnityEngine_UnityEngine_Events_PersistentCallGroup($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2702984);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1810720|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(1810720|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3803,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($__this) + 8|0);
     HEAP32[$9>>2] = $4;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z89UnityEngine_UnityEngine_Events_PersistentCallGroup_CustomAttributesCacheGenerator_m_CallsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708840)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2703080)|0);
 __Z62UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m__ctorP54UnityEngine_UnityEngine_RenamedSerializedDataAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z62UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m__ctorP54UnityEngine_UnityEngine_RenamedSerializedDataAttributeP22mscorlib_System_String($__this,$oldName) {
 $__this = $__this|0;
 $oldName = $oldName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2708632);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $oldName;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56UnityEngine_UnityEngine_Events_InvokableCallList_m__ctorP48UnityEngine_UnityEngine_Events_InvokableCallList($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2703296);
 __THREW__ = 0;
 (invoke_ii(2996,(1818592|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1818592|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3803,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 8|0);
    HEAP32[$7>>2] = $2;
    __THREW__ = 0;
    (invoke_ii(2996,(1818592|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(1818592|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3803,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = (($__this) + 12|0);
       HEAP32[$15>>2] = $10;
       __THREW__ = 0;
       invoke_vi(1924,($__this|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z66UnityEngine_UnityEngine_Events_InvokableCallList_m_ClearPersistentP48UnityEngine_UnityEngine_Events_InvokableCallList($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2703344);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vii(3495,(1817040|0),($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z53UnityEngine_UnityEngine_Events_UnityEventBase_m__ctorP45UnityEngine_UnityEngine_Events_UnityEventBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2703712);
 $0 = (($__this) + 20|0);
 HEAP8[$0>>0] = 1;
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2703576|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(3469,(2703576|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(2870,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($__this) + 8|0);
     HEAP32[$10>>2] = $5;
     __THREW__ = 0;
     (invoke_ii(2996,(2703160|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      $13 = (invoke_ii(3469,(2703160|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vi(2868,($13|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        $18 = (($__this) + 12|0);
        HEAP32[$18>>2] = $13;
        __THREW__ = 0;
        $19 = (invoke_ii(1782,($__this|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         invoke_vi(3799,($19|0));
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          __THREW__ = 0;
          $24 = (invoke_iii(2730,(2238368|0),($19|0))|0);
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           $27 = (($__this) + 16|0);
           HEAP32[$27>>2] = $24;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $28 = ___cxa_find_matching_catch()|0;
 $29 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($28|0);
 // unreachable;
}
function __Z108UnityEngine_UnityEngine_Events_UnityEventBase_m_UnityEngine_ISerializationCallbackReceiver_OnBeforeSerializeP45UnityEngine_UnityEngine_Events_UnityEventBase($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2703760);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z109UnityEngine_UnityEngine_Events_UnityEventBase_m_UnityEngine_ISerializationCallbackReceiver_OnAfterDeserializeP45UnityEngine_UnityEngine_Events_UnityEventBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2703808);
 __THREW__ = 0;
 invoke_vi(2875,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1782,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3799,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2730,(2238368|0),($2|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (($__this) + 16|0);
     HEAP32[$10>>2] = $7;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z68UnityEngine_UnityEngine_Events_UnityEventBase_m_DirtyPersistentCallsP45UnityEngine_UnityEngine_Events_UnityEventBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2703856);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  invoke_vi(2871,($1|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $6 = (($__this) + 20|0);
   HEAP8[$6>>0] = 1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z56UnityEngine_UnityEngine_Events_UnityEventBase_m_ToStringP45UnityEngine_UnityEngine_Events_UnityEventBase($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2703904);
 __THREW__ = 0;
 invoke_v(959);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1784,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(1782,($__this|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2730,(2150320|0),($5|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      $13 = HEAP32[2997640>>2]|0;
      __THREW__ = 0;
      $14 = (invoke_iiiii(101,(0|0),($2|0),($13|0),($10|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($14|0);
      }
     }
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
 return 0|0;
}
function __Z94UnityEngine_UnityEngine_Events_UnityEventBase_CustomAttributesCacheGenerator_m_PersistentCallsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708840)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2704264)|0);
 __Z62UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m__ctorP54UnityEngine_UnityEngine_RenamedSerializedDataAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 $7 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($7);
 $8 = HEAP32[$3>>2]|0;
 $9 = (($8) + 4|0);
 HEAP32[$9>>2] = $7;
 STACKTOP = sp;return;
}
function __Z87UnityEngine_UnityEngine_Events_UnityEventBase_CustomAttributesCacheGenerator_m_TypeNameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z49UnityEngine_UnityEngine_Events_UnityEvent_m__ctorP41UnityEngine_UnityEngine_Events_UnityEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2704544);
 __THREW__ = 0;
 (invoke_ii(2996,(1167664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2773,(1167664|0),0)|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = (($__this) + 24|0);
   HEAP32[$5>>2] = $2;
   __THREW__ = 0;
   invoke_vi(2872,($__this|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z55UnityEngine_UnityEngine_UserAuthorizationDialog_m__ctorP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2707312);
 __THREW__ = 0;
 invoke_vi(3120,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z55UnityEngine_UnityEngine_UserAuthorizationDialog_m_StartP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2707360);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z55UnityEngine_UnityEngine_UserAuthorizationDialog_m_OnGUIP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2707408);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z75UnityEngine_UnityEngine_UserAuthorizationDialog_m_DoUserAuthorizationDialogP47UnityEngine_UnityEngine_UserAuthorizationDialogi($__this,$windowID) {
 $__this = $__this|0;
 $windowID = $windowID|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2707456);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z78UnityEngine_UnityEngine_UserAuthorizationDialog_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2676392)|0);
 __Z48UnityEngine_UnityEngine_AddComponentMenu_m__ctorP40UnityEngine_UnityEngine_AddComponentMenuP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_AddComponentMenu_m__ctorP40UnityEngine_UnityEngine_AddComponentMenuP22mscorlib_System_String($__this,$menuName) {
 $__this = $__this|0;
 $menuName = $menuName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2717248);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $menuName;
  $3 = (($__this) + 12|0);
  HEAP32[$3>>2] = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m__ctorP54UnityEngine_UnityEngine_Internal_DefaultValueAttributeP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2707792);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $value;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z66UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_get_ValueP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2707840);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z63UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_EqualsP54UnityEngine_UnityEngine_Internal_DefaultValueAttributeP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2707888);
 __THREW__ = 0;
 (invoke_ii(2996,(2708216|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($obj|0),(2708216|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $8 = (($__this) + 8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = ($9|0)==(0|0);
    if ($10) {
     __THREW__ = 0;
     invoke_vi(3799,($2|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     $13 = (invoke_ii(2531,($2|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = ($13|0)==(0|0);
     $$0 = $16;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    invoke_vi(3799,($2|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     $19 = (invoke_ii(2531,($2|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(3799,($9|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       $24 = (invoke_iiii(1644,(2148736|0),($9|0),($19|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        $$0 = $24;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z68UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_GetHashCodeP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2707936);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  $3 = (invoke_ii(1788,($__this|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   $$0 = $3;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($1|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   $10 = (invoke_iii(2729,(2148880|0),($1|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $$0 = $10;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z85UnityEngine_UnityEngine_Internal_DefaultValueAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,18432);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z88UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,64);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z85UnityEngine_UnityEngine_RenamedSerializedDataAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,256);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP22mscorlib_System_String($__this,$rule) {
 $__this = $__this|0;
 $rule = $rule|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2709640);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $rule;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z69UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_ToStringP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2709688);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z89UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,64);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z56UnityEngine_UnityEngine_AssetBundleCreateRequest_m__ctorP48UnityEngine_UnityEngine_AssetBundleCreateRequest($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2710344);
 __THREW__ = 0;
 invoke_vi(3084,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z66UnityEngine_UnityEngine_AssetBundleCreateRequest_m_get_assetBundleP48UnityEngine_UnityEngine_AssetBundleCreateRequest($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2710392);
 $0 = HEAP32[2710440>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2710448|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2710440>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z77UnityEngine_UnityEngine_AssetBundleCreateRequest_m_DisableCompatibilityChecksP48UnityEngine_UnityEngine_AssetBundleCreateRequest($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2710504);
 $0 = HEAP32[2710552>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2710560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2710552>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z146UnityEngine_UnityEngine_AssetBundleCreateRequest_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AssetBundleCreateRequest_m_get_assetBundleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z157UnityEngine_UnityEngine_AssetBundleCreateRequest_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AssetBundleCreateRequest_m_DisableCompatibilityChecksP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z50UnityEngine_UnityEngine_AssetBundleRequest_m__ctorP42UnityEngine_UnityEngine_AssetBundleRequest($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2710928);
 __THREW__ = 0;
 invoke_vi(3084,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54UnityEngine_UnityEngine_AssetBundleRequest_m_get_assetP42UnityEngine_UnityEngine_AssetBundleRequest($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2710976);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  __THREW__ = 0;
  $8 = (invoke_iiii(1320,($1|0),($3|0),($5|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z47UnityEngine_UnityEngine_AssetBundle_m_LoadAssetP35UnityEngine_UnityEngine_AssetBundleP22mscorlib_System_StringP20mscorlib_System_Type($__this,$name,$type) {
 $__this = $__this|0;
 $name = $name|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2711440);
 __THREW__ = 0;
 invoke_v(960);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2623248|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2623248|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[2997664>>2]|0;
    __THREW__ = 0;
    invoke_vii(1955,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3844,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($name|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($name|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(2560072|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = HEAP32[2997672>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($23|0),($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3844,($23|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     }
     $31 = ($type|0)==(0|0);
     if (!($31)) {
      __THREW__ = 0;
      $42 = (invoke_iiii(1321,($__this|0),($name|0),($type|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($42|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2623248|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2623248|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       $37 = HEAP32[2997680>>2]|0;
       __THREW__ = 0;
       invoke_vii(1955,($34|0),($37|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        __THREW__ = 0;
        invoke_vi(3844,($34|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if (!($41)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z58UnityEngine_UnityEngine_AssetBundleRequest_m_get_allAssetsP42UnityEngine_UnityEngine_AssetBundleRequest($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2711024);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($__this) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  __THREW__ = 0;
  $8 = (invoke_iiii(1322,($1|0),($3|0),($5|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
 return 0|0;
}
function __Z60UnityEngine_UnityEngine_AssetBundle_m_LoadAssetWithSubAssetsP35UnityEngine_UnityEngine_AssetBundleP22mscorlib_System_StringP20mscorlib_System_Type($__this,$name,$type) {
 $__this = $__this|0;
 $name = $name|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2711616);
 __THREW__ = 0;
 invoke_v(961);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($name|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2623248|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2623248|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[2997912>>2]|0;
    __THREW__ = 0;
    invoke_vii(1955,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3844,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($name|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if (!($16)) {
    __THREW__ = 0;
    $17 = (invoke_ii(1816,($name|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = ($17|0)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2560072|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      $23 = (invoke_ii(3469,(2560072|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = HEAP32[2997920>>2]|0;
      __THREW__ = 0;
      invoke_vii(1924,($23|0),($26|0));
      $27 = __THREW__; __THREW__ = 0;
      $28 = $27&1;
      if ($28) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3844,($23|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      // unreachable;
     }
     $31 = ($type|0)==(0|0);
     if (!($31)) {
      __THREW__ = 0;
      $42 = (invoke_iiii(1323,($__this|0),($name|0),($type|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($42|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2623248|0))|0);
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if (!($33)) {
      __THREW__ = 0;
      $34 = (invoke_ii(3469,(2623248|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       $37 = HEAP32[2997928>>2]|0;
       __THREW__ = 0;
       invoke_vii(1955,($34|0),($37|0));
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        __THREW__ = 0;
        invoke_vi(3844,($34|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if (!($41)) {
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z56UnityEngine_UnityEngine_AssetBundle_m_LoadAsset_InternalP35UnityEngine_UnityEngine_AssetBundleP22mscorlib_System_StringP20mscorlib_System_Type($__this,$name,$type) {
 $__this = $__this|0;
 $name = $name|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2711488);
 $0 = HEAP32[2711536>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2711544|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2711536>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($__this|0),($name|0),($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z69UnityEngine_UnityEngine_AssetBundle_m_LoadAssetWithSubAssets_InternalP35UnityEngine_UnityEngine_AssetBundleP22mscorlib_System_StringP20mscorlib_System_Type($__this,$name,$type) {
 $__this = $__this|0;
 $name = $name|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2711664);
 $0 = HEAP32[2711712>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2711720|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2711712>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($__this|0),($name|0),($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z123UnityEngine_UnityEngine_AssetBundle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AssetBundle_m_LoadAsset_InternalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2709912)|0);
 __Z138UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngineInternal_TypeInferenceRulesP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributei($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z136UnityEngine_UnityEngine_AssetBundle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AssetBundle_m_LoadAssetWithSubAssets_InternalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z45UnityEngine_UnityEngine_LayerMask_m_get_valueP33UnityEngine_UnityEngine_LayerMask($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2713928);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z45UnityEngine_UnityEngine_LayerMask_m_set_valueP33UnityEngine_UnityEngine_LayerMaski($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2713976);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_LayerMask_m_LayerToNameP22mscorlib_System_Objecti($__this,$layer) {
 $__this = $__this|0;
 $layer = $layer|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2714024);
 $0 = HEAP32[2714072>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2714080|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2714072>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($layer|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z47UnityEngine_UnityEngine_LayerMask_m_NameToLayerP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$layerName) {
 $__this = $__this|0;
 $layerName = $layerName|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2714136);
 $0 = HEAP32[2714184>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2714192|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2714184>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($layerName|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_LayerMask_m_GetMaskP22mscorlib_System_ObjectP26mscorlib_System_String_arr($__this,$layerNames) {
 $__this = $__this|0;
 $layerNames = $layerNames|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_3$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2714248);
 $0 = (($layerNames) + 12|0);
 $1 = (($layerNames) + 16|0);
 $V_0$1 = 0;$V_3$0 = 0;
 while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($layerNames|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   label = 5;
   break;
  }
  $27 = HEAP32[$0>>2]|0;
  $28 = ($V_3$0|0)<($27|0);
  if (!($28)) {
   label = 13;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($layerNames|0));
  $29 = __THREW__; __THREW__ = 0;
  $30 = $29&1;
  if ($30) {
   label = 5;
   break;
  }
  $2 = HEAP32[$0>>2]|0;
  $3 = ($V_3$0>>>0)<($2>>>0);
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_i(132)|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if ($6) {
    label = 5;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($4|0));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    label = 5;
    break;
   }
  }
  $11 = HEAP32[$layerNames>>2]|0;
  $12 = (($11) + 92|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = Math_imul($13, $V_3$0)|0;
  $15 = (($1) + ($14)|0);
  $16 = HEAP32[$15>>2]|0;
  __THREW__ = 0;
  $17 = (invoke_iii(1197,0,($16|0))|0);
  $18 = __THREW__; __THREW__ = 0;
  $19 = $18&1;
  if ($19) {
   label = 5;
   break;
  }
  $20 = ($17|0)==(0);
  if ($20) {
   $V_0$0 = $V_0$1;
  } else {
   $21 = $17 & 31;
   $22 = 1 << $21;
   $23 = $22 | $V_0$1;
   $V_0$0 = $23;
  }
  $24 = (($V_3$0) + 1)|0;
  $V_0$1 = $V_0$0;$V_3$0 = $24;
 }
 if ((label|0) == 5) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 }
 else if ((label|0) == 13) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($V_0$1|0);
 }
 return 0|0;
}
function __Z103UnityEngine_UnityEngine_LayerMask_m_op_Implicit_mscorlib_System_Int32_UnityEngine_UnityEngine_LayerMaskP22mscorlib_System_Object33UnityEngine_UnityEngine_LayerMask($__this,$mask) {
 $__this = $__this|0;
 $mask = $mask|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2714296);
 $0 = HEAP32[$mask>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z103UnityEngine_UnityEngine_LayerMask_m_op_Implicit_UnityEngine_UnityEngine_LayerMask_mscorlib_System_Int32P22mscorlib_System_Objecti($__this,$intVal) {
 $__this = $__this|0;
 $intVal = $intVal|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2714344);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($intVal|0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits39UnityEngine_UnityEngine_LayerMaskTraitsE6InvokeEPFiPv33UnityEngine_UnityEngine_LayerMaskES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = sp + 4|0;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$$byval_copy)|0);
 HEAP32[$ret>>2] = $3;
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker1I39UnityEngine_UnityEngine_LayerMaskTraits27mscorlib_System_Int32TraitsE6InvokeEPF33UnityEngine_UnityEngine_LayerMaskPviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$1)|0);
 HEAP32[$ret>>2] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2714712,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z112UnityEngine_UnityEngine_LayerMask_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_LayerMask_m_LayerToNameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z112UnityEngine_UnityEngine_LayerMask_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_LayerMask_m_NameToLayerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46UnityEngine_UnityEngine_WaitForSeconds_m__ctorP38UnityEngine_UnityEngine_WaitForSecondsf($__this,$seconds) {
 $__this = $__this|0;
 $seconds = Math_fround($seconds);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2715376);
 __THREW__ = 0;
 invoke_vi(3151,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAPF32[$2>>2] = $seconds;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_WaitForFixedUpdate_m__ctorP42UnityEngine_UnityEngine_WaitForFixedUpdate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2715672);
 __THREW__ = 0;
 invoke_vi(3151,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z49UnityEngine_UnityEngine_WaitForEndOfFrame_m__ctorP41UnityEngine_UnityEngine_WaitForEndOfFrame($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2715912);
 __THREW__ = 0;
 invoke_vi(3151,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z41UnityEngine_UnityEngine_Coroutine_m__ctorP33UnityEngine_UnityEngine_Coroutine($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2716152);
 __THREW__ = 0;
 invoke_vi(3151,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52UnityEngine_UnityEngine_Coroutine_m_ReleaseCoroutineP33UnityEngine_UnityEngine_Coroutine($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2716200);
 $0 = HEAP32[2716248>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2716256|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2716248>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z44UnityEngine_UnityEngine_Coroutine_m_FinalizeP33UnityEngine_UnityEngine_Coroutine($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2716304);
 __THREW__ = 0;
 invoke_vi(2901,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 18;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(18);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3844,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z117UnityEngine_UnityEngine_Coroutine_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Coroutine_m_ReleaseCoroutineP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z80UnityEngine_UnityEngine_DisallowMultipleComponent_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,4);
 __Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb($4,0);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_RequireComponent_m__ctorP40UnityEngine_UnityEngine_RequireComponentP20mscorlib_System_Type($__this,$requiredComponent) {
 $__this = $__this|0;
 $requiredComponent = $requiredComponent|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2716848);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 8|0);
  HEAP32[$2>>2] = $requiredComponent;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z71UnityEngine_UnityEngine_RequireComponent_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2159288)|0);
 __Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei($4,4);
 __Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb($4,1);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z49UnityEngine_UnityEngine_ExecuteInEditMode_m__ctorP41UnityEngine_UnityEngine_ExecuteInEditMode($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2717624);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z74UnityEngine_UnityEngine_ScriptableObject_m_Internal_CreateScriptableObjectP22mscorlib_System_ObjectP40UnityEngine_UnityEngine_ScriptableObject($__this,$self) {
 $__this = $__this|0;
 $self = $self|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2717928);
 $0 = HEAP32[2717976>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2717984|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2717976>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($self|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z121UnityEngine_UnityEngine_ScriptableObject_m_CreateInstance_UnityEngine_UnityEngine_ScriptableObject_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$className) {
 $__this = $__this|0;
 $className = $className|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2718080);
 $0 = HEAP32[2718128>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2718136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2718128>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($className|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z119UnityEngine_UnityEngine_ScriptableObject_m_CreateInstance_UnityEngine_UnityEngine_ScriptableObject_mscorlib_System_TypeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2718200);
 __THREW__ = 0;
 $0 = (invoke_iii(1203,0,($type|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z65UnityEngine_UnityEngine_ScriptableObject_m_CreateInstanceFromTypeP22mscorlib_System_ObjectP20mscorlib_System_Type($__this,$type) {
 $__this = $__this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2718248);
 $0 = HEAP32[2718296>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2718304|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2718296>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($type|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z146UnityEngine_UnityEngine_ScriptableObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_ScriptableObject_m_Internal_CreateScriptableObjectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z193UnityEngine_UnityEngine_ScriptableObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_ScriptableObject_m_CreateInstance_UnityEngine_UnityEngine_ScriptableObject_mscorlib_System_StringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z137UnityEngine_UnityEngine_ScriptableObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_ScriptableObject_m_CreateInstanceFromTypeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z94UnityEngine_UnityEngine_Resources_m_Load_UnityEngine_UnityEngine_Object_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$path) {
 $__this = $__this|0;
 $path = $path|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2718768);
 HEAP32[$0>>2] = 1822520;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $1 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (invoke_iiii(1326,0,($path|0),($1|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($4|0);
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z115UnityEngine_UnityEngine_Resources_m_Load_UnityEngine_UnityEngine_Object_mscorlib_System_String_mscorlib_System_TypeP22mscorlib_System_ObjectP22mscorlib_System_StringP20mscorlib_System_Type($__this,$path,$systemTypeInstance) {
 $__this = $__this|0;
 $path = $path|0;
 $systemTypeInstance = $systemTypeInstance|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2718816);
 $0 = HEAP32[2718864>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2718872|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2718864>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($path|0),($systemTypeInstance|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z180UnityEngine_UnityEngine_Resources_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Resources_m_Load_UnityEngine_UnityEngine_Object_mscorlib_System_String_mscorlib_System_TypeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 $6 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2709912)|0);
 __Z138UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngineInternal_TypeInferenceRulesP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributei($6,1);
 $7 = HEAP32[$3>>2]|0;
 $8 = (($7) + 4|0);
 HEAP32[$8>>2] = $6;
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_get_weight0P34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2719728);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_set_weight0P34UnityEngine_UnityEngine_BoneWeightf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2719776);
 HEAPF32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_get_weight1P34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2719824);
 $0 = (($__this) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_set_weight1P34UnityEngine_UnityEngine_BoneWeightf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2719872);
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_get_weight2P34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2719920);
 $0 = (($__this) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_set_weight2P34UnityEngine_UnityEngine_BoneWeightf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2719968);
 $0 = (($__this) + 8|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_get_weight3P34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720016);
 $0 = (($__this) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_set_weight3P34UnityEngine_UnityEngine_BoneWeightf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720064);
 $0 = (($__this) + 12|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z51UnityEngine_UnityEngine_BoneWeight_m_get_boneIndex0P34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720112);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51UnityEngine_UnityEngine_BoneWeight_m_set_boneIndex0P34UnityEngine_UnityEngine_BoneWeighti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720160);
 $0 = (($__this) + 16|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z51UnityEngine_UnityEngine_BoneWeight_m_get_boneIndex1P34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720208);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51UnityEngine_UnityEngine_BoneWeight_m_set_boneIndex1P34UnityEngine_UnityEngine_BoneWeighti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720256);
 $0 = (($__this) + 20|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z51UnityEngine_UnityEngine_BoneWeight_m_get_boneIndex2P34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720304);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51UnityEngine_UnityEngine_BoneWeight_m_set_boneIndex2P34UnityEngine_UnityEngine_BoneWeighti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720352);
 $0 = (($__this) + 24|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z51UnityEngine_UnityEngine_BoneWeight_m_get_boneIndex3P34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720400);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51UnityEngine_UnityEngine_BoneWeight_m_set_boneIndex3P34UnityEngine_UnityEngine_BoneWeighti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720448);
 $0 = (($__this) + 28|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_BoneWeight_m_GetHashCodeP34UnityEngine_UnityEngine_BoneWeight($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $V_5 = 0, $V_6 = 0, $V_7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_0 = sp + 28|0;
 $V_1 = sp + 24|0;
 $V_2 = sp + 20|0;
 $V_3 = sp + 16|0;
 $V_4 = sp + 8|0;
 $V_5 = sp + 4|0;
 $V_6 = sp;
 $V_7 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720496);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 HEAP32[$V_2>>2] = 0;
 HEAP32[$V_3>>2] = 0;
 HEAPF32[$V_4>>2] = Math_fround(0.0);
 HEAPF32[$V_5>>2] = Math_fround(0.0);
 HEAPF32[$V_6>>2] = Math_fround(0.0);
 HEAPF32[$V_7>>2] = Math_fround(0.0);
 __THREW__ = 0;
 $0 = (invoke_ii(2538,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAP32[$V_0>>2] = $0;
  __THREW__ = 0;
  $3 = (invoke_ii(1789,($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(2539,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    HEAP32[$V_1>>2] = $6;
    __THREW__ = 0;
    $9 = (invoke_ii(1789,($V_1|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = $9 << 2;
     $13 = $12 ^ $3;
     __THREW__ = 0;
     $14 = (invoke_ii(2540,($__this|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      HEAP32[$V_2>>2] = $14;
      __THREW__ = 0;
      $17 = (invoke_ii(1789,($V_2|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = $17 >> 2;
       $21 = $13 ^ $20;
       __THREW__ = 0;
       $22 = (invoke_ii(2541,($__this|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        HEAP32[$V_3>>2] = $22;
        __THREW__ = 0;
        $25 = (invoke_ii(1789,($V_3|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $28 = $25 >> 1;
         $29 = $21 ^ $28;
         __THREW__ = 0;
         $30 = (Math_fround(+(invoke_fi(130,($__this|0)))));
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          HEAPF32[$V_4>>2] = $30;
          __THREW__ = 0;
          $33 = (invoke_ii(1819,($V_4|0))|0);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           $36 = $33 << 5;
           $37 = $29 ^ $36;
           __THREW__ = 0;
           $38 = (Math_fround(+(invoke_fi(131,($__this|0)))));
           $39 = __THREW__; __THREW__ = 0;
           $40 = $39&1;
           if (!($40)) {
            HEAPF32[$V_5>>2] = $38;
            __THREW__ = 0;
            $41 = (invoke_ii(1819,($V_5|0))|0);
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if (!($43)) {
             $44 = $41 << 4;
             $45 = $37 ^ $44;
             __THREW__ = 0;
             $46 = (Math_fround(+(invoke_fi(132,($__this|0)))));
             $47 = __THREW__; __THREW__ = 0;
             $48 = $47&1;
             if (!($48)) {
              HEAPF32[$V_6>>2] = $46;
              __THREW__ = 0;
              $49 = (invoke_ii(1819,($V_6|0))|0);
              $50 = __THREW__; __THREW__ = 0;
              $51 = $50&1;
              if (!($51)) {
               $52 = $49 >> 4;
               $53 = $45 ^ $52;
               __THREW__ = 0;
               $54 = (Math_fround(+(invoke_fi(133,($__this|0)))));
               $55 = __THREW__; __THREW__ = 0;
               $56 = $55&1;
               if (!($56)) {
                HEAPF32[$V_7>>2] = $54;
                __THREW__ = 0;
                $57 = (invoke_ii(1819,($V_7|0))|0);
                $58 = __THREW__; __THREW__ = 0;
                $59 = $58&1;
                if (!($59)) {
                 $60 = $57 >> 3;
                 $61 = $53 ^ $60;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($61|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $62 = ___cxa_find_matching_catch()|0;
 $63 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($62|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_BoneWeight_m_EqualsP34UnityEngine_UnityEngine_BoneWeightP22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = Math_fround(0), $56 = 0, $57 = 0, $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = Math_fround(0), $64 = 0, $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $L_24 = 0, $L_25 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $V_5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $_stackTraceSentry = sp + 104|0;
 $V_0 = sp + 72|0;
 $V_1 = sp + 64|0;
 $V_2 = sp + 60|0;
 $V_3 = sp + 56|0;
 $V_4 = sp + 32|0;
 $V_5 = sp + 16|0;
 $L_24 = sp;
 $L_25 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720544);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;HEAP32[$V_0+16>>2]=0|0;HEAP32[$V_0+20>>2]=0|0;HEAP32[$V_0+24>>2]=0|0;HEAP32[$V_0+28>>2]=0|0;
 HEAP32[$V_1>>2] = 0;
 HEAP32[$V_2>>2] = 0;
 HEAP32[$V_3>>2] = 0;
 HEAP32[$V_4>>2] = 0;
 ;HEAP32[$V_5+0>>2]=0|0;HEAP32[$V_5+4>>2]=0|0;HEAP32[$V_5+8>>2]=0|0;HEAP32[$V_5+12>>2]=0|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2721664|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($other|0),(2721664|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2721664|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2775,($other|0),(2721664|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      ;HEAP32[$V_0+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$V_0+16>>2]=HEAP32[$10+16>>2]|0;HEAP32[$V_0+20>>2]=HEAP32[$10+20>>2]|0;HEAP32[$V_0+24>>2]=HEAP32[$10+24>>2]|0;HEAP32[$V_0+28>>2]=HEAP32[$10+28>>2]|0;
      __THREW__ = 0;
      $13 = (invoke_ii(2538,($__this|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       HEAP32[$V_1>>2] = $13;
       __THREW__ = 0;
       $16 = (invoke_ii(2538,($V_0|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        $19 = (invoke_iii(473,($V_1|0),($16|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         if (!($19)) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $22 = (invoke_ii(2539,($__this|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          HEAP32[$V_2>>2] = $22;
          __THREW__ = 0;
          $25 = (invoke_ii(2539,($V_0|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           $28 = (invoke_iii(473,($V_2|0),($25|0))|0);
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if (!($30)) {
            if (!($28)) {
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            $31 = (invoke_ii(2540,($__this|0))|0);
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if (!($33)) {
             HEAP32[$V_3>>2] = $31;
             __THREW__ = 0;
             $34 = (invoke_ii(2540,($V_0|0))|0);
             $35 = __THREW__; __THREW__ = 0;
             $36 = $35&1;
             if (!($36)) {
              __THREW__ = 0;
              $37 = (invoke_iii(473,($V_3|0),($34|0))|0);
              $38 = __THREW__; __THREW__ = 0;
              $39 = $38&1;
              if (!($39)) {
               if (!($37)) {
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               __THREW__ = 0;
               $40 = (invoke_ii(2541,($__this|0))|0);
               $41 = __THREW__; __THREW__ = 0;
               $42 = $41&1;
               if (!($42)) {
                HEAP32[$V_4>>2] = $40;
                __THREW__ = 0;
                $43 = (invoke_ii(2541,($V_0|0))|0);
                $44 = __THREW__; __THREW__ = 0;
                $45 = $44&1;
                if (!($45)) {
                 __THREW__ = 0;
                 $46 = (invoke_iii(473,($V_4|0),($43|0))|0);
                 $47 = __THREW__; __THREW__ = 0;
                 $48 = $47&1;
                 if ($48) {
                  break;
                 }
                 if (!($46)) {
                  $$0 = 0;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                 __THREW__ = 0;
                 $49 = (Math_fround(+(invoke_fi(130,($__this|0)))));
                 $50 = __THREW__; __THREW__ = 0;
                 $51 = $50&1;
                 if ($51) {
                  break;
                 }
                 __THREW__ = 0;
                 $52 = (Math_fround(+(invoke_fi(131,($__this|0)))));
                 $53 = __THREW__; __THREW__ = 0;
                 $54 = $53&1;
                 if ($54) {
                  break;
                 }
                 __THREW__ = 0;
                 $55 = (Math_fround(+(invoke_fi(132,($__this|0)))));
                 $56 = __THREW__; __THREW__ = 0;
                 $57 = $56&1;
                 if ($57) {
                  break;
                 }
                 __THREW__ = 0;
                 $58 = (Math_fround(+(invoke_fi(133,($__this|0)))));
                 $59 = __THREW__; __THREW__ = 0;
                 $60 = $59&1;
                 if ($60) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viffff(5,($V_5|0),(+$49),(+$52),(+$55),(+$58));
                 $61 = __THREW__; __THREW__ = 0;
                 $62 = $61&1;
                 if ($62) {
                  break;
                 }
                 __THREW__ = 0;
                 $63 = (Math_fround(+(invoke_fi(130,($V_0|0)))));
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if ($65) {
                  break;
                 }
                 __THREW__ = 0;
                 $66 = (Math_fround(+(invoke_fi(131,($V_0|0)))));
                 $67 = __THREW__; __THREW__ = 0;
                 $68 = $67&1;
                 if ($68) {
                  break;
                 }
                 __THREW__ = 0;
                 $69 = (Math_fround(+(invoke_fi(132,($V_0|0)))));
                 $70 = __THREW__; __THREW__ = 0;
                 $71 = $70&1;
                 if ($71) {
                  break;
                 }
                 __THREW__ = 0;
                 $72 = (Math_fround(+(invoke_fi(133,($V_0|0)))));
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if ($74) {
                  break;
                 }
                 ;HEAP32[$L_24+0>>2]=0|0;HEAP32[$L_24+4>>2]=0|0;HEAP32[$L_24+8>>2]=0|0;HEAP32[$L_24+12>>2]=0|0;
                 __THREW__ = 0;
                 invoke_viffff(5,($L_24|0),(+$63),(+$66),(+$69),(+$72));
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if ($76) {
                  break;
                 }
                 ;HEAP32[$L_25+0>>2]=HEAP32[$L_24+0>>2]|0;HEAP32[$L_25+4>>2]=HEAP32[$L_24+4>>2]|0;HEAP32[$L_25+8>>2]=HEAP32[$L_24+8>>2]|0;HEAP32[$L_25+12>>2]=HEAP32[$L_24+12>>2]|0;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2807040|0))|0);
                 $77 = __THREW__; __THREW__ = 0;
                 $78 = $77&1;
                 if ($78) {
                  break;
                 }
                 __THREW__ = 0;
                 $79 = (invoke_iii(2724,(2807040|0),($L_25|0))|0);
                 $80 = __THREW__; __THREW__ = 0;
                 $81 = $80&1;
                 if ($81) {
                  break;
                 }
                 __THREW__ = 0;
                 $82 = (invoke_iii(1227,($V_5|0),($79|0))|0);
                 $83 = __THREW__; __THREW__ = 0;
                 $84 = $83&1;
                 if ($84) {
                  break;
                 } else {
                  $$0 = $82;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z142UnityEngine_UnityEngine_BoneWeight_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_BoneWeight_UnityEngine_UnityEngine_BoneWeightP22mscorlib_System_Object34UnityEngine_UnityEngine_BoneWeightS1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = Math_fround(0), $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = Math_fround(0);
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $G_B6_0$0 = 0, $L_12 = 0, $L_12$byval_copy = 0, $L_17 = 0, $L_17$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_17$byval_copy = sp + 56|0;
 $L_12$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_12 = sp + 24|0;
 $L_17 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720592);
 __THREW__ = 0;
 $0 = (invoke_ii(2538,($lhs|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2538,($rhs|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($0|0)==($3|0);
    if (!($6)) {
     $G_B6_0$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B6_0$0|0);
    }
    __THREW__ = 0;
    $9 = (invoke_ii(2539,($lhs|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(2539,($rhs|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = ($9|0)==($12|0);
      if (!($15)) {
       $G_B6_0$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($G_B6_0$0|0);
      }
      __THREW__ = 0;
      $16 = (invoke_ii(2540,($lhs|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_ii(2540,($rhs|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = ($16|0)==($19|0);
        if (!($22)) {
         $G_B6_0$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($G_B6_0$0|0);
        }
        __THREW__ = 0;
        $23 = (invoke_ii(2541,($lhs|0))|0);
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         __THREW__ = 0;
         $26 = (invoke_ii(2541,($rhs|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = ($23|0)==($26|0);
          if (!($29)) {
           $G_B6_0$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($G_B6_0$0|0);
          }
          __THREW__ = 0;
          $30 = (Math_fround(+(invoke_fi(130,($lhs|0)))));
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           $33 = (Math_fround(+(invoke_fi(131,($lhs|0)))));
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            __THREW__ = 0;
            $36 = (Math_fround(+(invoke_fi(132,($lhs|0)))));
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if (!($38)) {
             __THREW__ = 0;
             $39 = (Math_fround(+(invoke_fi(133,($lhs|0)))));
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if (!($41)) {
              ;HEAP32[$L_12+0>>2]=0|0;HEAP32[$L_12+4>>2]=0|0;HEAP32[$L_12+8>>2]=0|0;HEAP32[$L_12+12>>2]=0|0;
              __THREW__ = 0;
              invoke_viffff(5,($L_12|0),(+$30),(+$33),(+$36),(+$39));
              $42 = __THREW__; __THREW__ = 0;
              $43 = $42&1;
              if (!($43)) {
               __THREW__ = 0;
               $44 = (Math_fround(+(invoke_fi(130,($rhs|0)))));
               $45 = __THREW__; __THREW__ = 0;
               $46 = $45&1;
               if (!($46)) {
                __THREW__ = 0;
                $47 = (Math_fround(+(invoke_fi(131,($rhs|0)))));
                $48 = __THREW__; __THREW__ = 0;
                $49 = $48&1;
                if (!($49)) {
                 __THREW__ = 0;
                 $50 = (Math_fround(+(invoke_fi(132,($rhs|0)))));
                 $51 = __THREW__; __THREW__ = 0;
                 $52 = $51&1;
                 if ($52) {
                  break;
                 }
                 __THREW__ = 0;
                 $53 = (Math_fround(+(invoke_fi(133,($rhs|0)))));
                 $54 = __THREW__; __THREW__ = 0;
                 $55 = $54&1;
                 if ($55) {
                  break;
                 }
                 ;HEAP32[$L_17+0>>2]=0|0;HEAP32[$L_17+4>>2]=0|0;HEAP32[$L_17+8>>2]=0|0;HEAP32[$L_17+12>>2]=0|0;
                 __THREW__ = 0;
                 invoke_viffff(5,($L_17|0),(+$44),(+$47),(+$50),(+$53));
                 $56 = __THREW__; __THREW__ = 0;
                 $57 = $56&1;
                 if ($57) {
                  break;
                 }
                 __THREW__ = 0;
                 ;HEAP32[$L_12$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_12$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_12$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;HEAP32[$L_12$byval_copy+12>>2]=HEAP32[$L_12+12>>2]|0;
                 ;HEAP32[$L_17$byval_copy+0>>2]=HEAP32[$L_17+0>>2]|0;HEAP32[$L_17$byval_copy+4>>2]=HEAP32[$L_17+4>>2]|0;HEAP32[$L_17$byval_copy+8>>2]=HEAP32[$L_17+8>>2]|0;HEAP32[$L_17$byval_copy+12>>2]=HEAP32[$L_17+12>>2]|0;
                 $58 = (invoke_iiii(1403,(0|0),($L_12$byval_copy|0),($L_17$byval_copy|0))|0);
                 $59 = __THREW__; __THREW__ = 0;
                 $60 = $59&1;
                 if ($60) {
                  break;
                 } else {
                  $G_B6_0$0 = $58;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($G_B6_0$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z144UnityEngine_UnityEngine_BoneWeight_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_BoneWeight_UnityEngine_UnityEngine_BoneWeightP22mscorlib_System_Object34UnityEngine_UnityEngine_BoneWeightS1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $lhs$byval_copy = 0, $rhs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $rhs$byval_copy = sp + 40|0;
 $lhs$byval_copy = sp;
 $_stackTraceSentry = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2720640);
 __THREW__ = 0;
 ;HEAP32[$lhs$byval_copy+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$lhs$byval_copy+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$lhs$byval_copy+8>>2]=HEAP32[$lhs+8>>2]|0;HEAP32[$lhs$byval_copy+12>>2]=HEAP32[$lhs+12>>2]|0;HEAP32[$lhs$byval_copy+16>>2]=HEAP32[$lhs+16>>2]|0;HEAP32[$lhs$byval_copy+20>>2]=HEAP32[$lhs+20>>2]|0;HEAP32[$lhs$byval_copy+24>>2]=HEAP32[$lhs+24>>2]|0;HEAP32[$lhs$byval_copy+28>>2]=HEAP32[$lhs+28>>2]|0;
 ;HEAP32[$rhs$byval_copy+0>>2]=HEAP32[$rhs+0>>2]|0;HEAP32[$rhs$byval_copy+4>>2]=HEAP32[$rhs+4>>2]|0;HEAP32[$rhs$byval_copy+8>>2]=HEAP32[$rhs+8>>2]|0;HEAP32[$rhs$byval_copy+12>>2]=HEAP32[$rhs+12>>2]|0;HEAP32[$rhs$byval_copy+16>>2]=HEAP32[$rhs+16>>2]|0;HEAP32[$rhs$byval_copy+20>>2]=HEAP32[$rhs+20>>2]|0;HEAP32[$rhs$byval_copy+24>>2]=HEAP32[$rhs+24>>2]|0;HEAP32[$rhs$byval_copy+28>>2]=HEAP32[$rhs+28>>2]|0;
 $0 = (invoke_iiii(1327,0,($lhs$byval_copy|0),($rhs$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = $0 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_BoneWeightTraitsS1_E6InvokeEPFbPv34UnityEngine_UnityEngine_BoneWeightS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $tmpcast$byval_copy = sp + 64|0;
 $$byval_copy = sp;
 $ret = sp + 96|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$1+24>>2]|0;HEAP32[$0+28>>2]=HEAP32[$1+28>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;HEAP32[$$byval_copy+24>>2]=HEAP32[$0+24>>2]|0;HEAP32[$$byval_copy+28>>2]=HEAP32[$0+28>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$3+20>>2]|0;HEAP32[$tmpcast$byval_copy+24>>2]=HEAP32[$3+24>>2]|0;HEAP32[$tmpcast$byval_copy+28>>2]=HEAP32[$3+28>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z47UnityEngine_UnityEngine_Renderer_m_get_materialP32UnityEngine_UnityEngine_Renderer($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2722080);
 $0 = HEAP32[2722128>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2722136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2722128>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z111UnityEngine_UnityEngine_Renderer_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Renderer_m_get_materialP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46UnityEngine_UnityEngine_Resolution_m_get_widthP34UnityEngine_UnityEngine_Resolution($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2722400);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z46UnityEngine_UnityEngine_Resolution_m_set_widthP34UnityEngine_UnityEngine_Resolutioni($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2722448);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_Resolution_m_get_heightP34UnityEngine_UnityEngine_Resolution($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2722496);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z47UnityEngine_UnityEngine_Resolution_m_set_heightP34UnityEngine_UnityEngine_Resolutioni($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2722544);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z52UnityEngine_UnityEngine_Resolution_m_get_refreshRateP34UnityEngine_UnityEngine_Resolution($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2722592);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52UnityEngine_UnityEngine_Resolution_m_set_refreshRateP34UnityEngine_UnityEngine_Resolutioni($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2722640);
 $0 = (($__this) + 8|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z42UnityEngine_UnityEngine_Screen_m_get_widthP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2723368);
 $0 = HEAP32[2723416>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2723424|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2723416>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Screen_m_get_heightP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2723456);
 $0 = HEAP32[2723504>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2723512|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2723504>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z104UnityEngine_UnityEngine_Screen_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Screen_m_get_widthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z105UnityEngine_UnityEngine_Screen_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Screen_m_get_heightP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z56UnityEngine_UnityEngine_GUILayer_m_INTERNAL_CALL_HitTestP22mscorlib_System_ObjectP32UnityEngine_UnityEngine_GUILayerP31UnityEngine_UnityEngine_Vector3($__this,$self,$screenPosition) {
 $__this = $__this|0;
 $self = $self|0;
 $screenPosition = $screenPosition|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2724560);
 $0 = HEAP32[2724608>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2724616|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2724608>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($self|0),($screenPosition|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z120UnityEngine_UnityEngine_GUILayer_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUILayer_m_INTERNAL_CALL_HitTestP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_GradientColorKey_m__ctorP40UnityEngine_UnityEngine_GradientColorKey29UnityEngine_UnityEngine_Colorf($__this,$col,$time) {
 $__this = $__this|0;
 $col = $col|0;
 $time = Math_fround($time);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2724984);
 ;HEAP32[$__this+0>>2]=HEAP32[$col+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$col+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$col+8>>2]|0;HEAP32[$__this+12>>2]=HEAP32[$col+12>>2]|0;
 $0 = (($__this) + 16|0);
 HEAPF32[$0>>2] = $time;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker2I35UnityEngine_UnityEngine_ColorTraits28mscorlib_System_SingleTraitsE6InvokeEPFvPv29UnityEngine_UnityEngine_ColorfES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_viif[$action & 63]($obj,$$byval_copy,$4);
 STACKTOP = sp;return (0|0);
}
function __Z48UnityEngine_UnityEngine_GradientAlphaKey_m__ctorP40UnityEngine_UnityEngine_GradientAlphaKeyff($__this,$alpha,$time) {
 $__this = $__this|0;
 $alpha = Math_fround($alpha);
 $time = Math_fround($time);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2725320);
 HEAPF32[$__this>>2] = $alpha;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $time;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker2I28mscorlib_System_SingleTraitsS0_E6InvokeEPFvPvffES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 FUNCTION_TABLE_viff[$action & 31]($obj,$1,$4);
 STACKTOP = sp;return (0|0);
}
function __Z40UnityEngine_UnityEngine_Gradient_m__ctorP32UnityEngine_UnityEngine_Gradient($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2725656);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(2917,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z39UnityEngine_UnityEngine_Gradient_m_InitP32UnityEngine_UnityEngine_Gradient($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2725704);
 $0 = HEAP32[2725752>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2725760|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2725752>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_Gradient_m_CleanupP32UnityEngine_UnityEngine_Gradient($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2725792);
 $0 = HEAP32[2725840>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2725848|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2725840>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z43UnityEngine_UnityEngine_Gradient_m_FinalizeP32UnityEngine_UnityEngine_Gradient($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2725880);
 __THREW__ = 0;
 invoke_vi(2918,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 18;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(18);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3844,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z103UnityEngine_UnityEngine_Gradient_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Gradient_m_InitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z106UnityEngine_UnityEngine_Gradient_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Gradient_m_CleanupP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z60UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726200);
 __THREW__ = 0;
 (invoke_ii(2996,(2731232|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2731232|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2933,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 8|0);
    HEAP32[$7>>2] = $2;
    __THREW__ = 0;
    (invoke_ii(2996,(2710208|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2710208|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(2888,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = (($__this) + 12|0);
       HEAP32[$15>>2] = $10;
       __THREW__ = 0;
       (invoke_ii(2996,(2731232|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        $18 = (invoke_ii(3469,(2731232|0))|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         invoke_vi(2933,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          $23 = (($__this) + 16|0);
          HEAP32[$23>>2] = $18;
          __THREW__ = 0;
          invoke_vi(1924,($__this|0));
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           $26 = HEAP32[$15>>2]|0;
           $27 = HEAP32[$7>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($26|0));
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            __THREW__ = 0;
            invoke_viii(2113,(2315496|0),($26|0),($27|0));
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if (!($31)) {
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $32 = ___cxa_find_matching_catch()|0;
 $33 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($32|0);
 // unreachable;
}
function __Z46UnityEngine_UnityEngine_GUILayoutGroup_m__ctorP38UnityEngine_UnityEngine_GUILayoutGroup($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2730016);
 __THREW__ = 0;
 (invoke_ii(2996,(1906024|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1906024|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(3803,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 52|0);
    HEAP32[$7>>2] = $2;
    $8 = (($__this) + 56|0);
    HEAP8[$8>>0] = 1;
    $9 = (($__this) + 64|0);
    HEAP8[$9>>0] = 1;
    $10 = (($__this) + 68|0);
    HEAP32[$10>>2] = -1;
    $11 = (($__this) + 76|0);
    HEAP32[$11>>2] = 100;
    $12 = (($__this) + 80|0);
    HEAP32[$12>>2] = 100;
    $13 = (($__this) + 88|0);
    HEAPF32[$13>>2] = Math_fround(100.0);
    $14 = (($__this) + 92|0);
    HEAPF32[$14>>2] = Math_fround(100.0);
    $15 = (($__this) + 96|0);
    HEAPF32[$15>>2] = Math_fround(100.0);
    $16 = (($__this) + 100|0);
    HEAPF32[$16>>2] = Math_fround(100.0);
    __THREW__ = 0;
    (invoke_ii(2996,(2746216|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     __THREW__ = 0;
     $19 = (invoke_ii(3469,(2746216|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      invoke_vi(2991,($19|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       $24 = (($__this) + 104|0);
       HEAP32[$24>>2] = $19;
       __THREW__ = 0;
       $25 = (invoke_ii(2596,0)|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if (!($27)) {
        __THREW__ = 0;
        invoke_viffffi(2,($__this|0),0.0,0.0,0.0,0.0,($25|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if (!($29)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($30|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_GUILayoutUtility_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $L_7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_7 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726560);
 __THREW__ = 0;
 (invoke_ii(2996,(1888288|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(1888288|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(1791,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = HEAP32[((2728312 + 80|0))>>2]|0;
     HEAP32[$9>>2] = $2;
     __THREW__ = 0;
     (invoke_ii(2996,(1888288|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_ii(3469,(1888288|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(1791,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         $19 = HEAP32[((2728312 + 80|0))>>2]|0;
         $20 = (($19) + 4|0);
         HEAP32[$20>>2] = $12;
         __THREW__ = 0;
         (invoke_ii(2996,(2726424|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          $23 = (invoke_ii(3469,(2726424|0))|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           __THREW__ = 0;
           invoke_vi(2922,($23|0));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2728312|0))|0);
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             $30 = HEAP32[((2728312 + 80|0))>>2]|0;
             $31 = (($30) + 8|0);
             HEAP32[$31>>2] = $23;
             ;HEAP32[$L_7+0>>2]=0|0;HEAP32[$L_7+4>>2]=0|0;HEAP32[$L_7+8>>2]=0|0;HEAP32[$L_7+12>>2]=0|0;
             __THREW__ = 0;
             invoke_viffff(4,($L_7|0),0.0,0.0,1.0,1.0);
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if (!($33)) {
              __THREW__ = 0;
              (invoke_ii(2996,(2728312|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               $36 = HEAP32[((2728312 + 80|0))>>2]|0;
               $37 = (($36) + 12|0);
               ;HEAP32[$37+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$37+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$37+8>>2]=HEAP32[$L_7+8>>2]|0;HEAP32[$37+12>>2]=HEAP32[$L_7+12>>2]|0;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $38 = ___cxa_find_matching_catch()|0;
 $39 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($38|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_GUILayoutUtility_m_BeginP22mscorlib_System_Objecti($__this,$instanceID) {
 $__this = $__this|0;
 $instanceID = $instanceID|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726656);
 __THREW__ = 0;
 $0 = (invoke_iiii(1333,0,($instanceID|0),0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(2603,0)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(2598,($3|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      $11 = ($8|0)==(8);
      if (!($11)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $135 = __THREW__; __THREW__ = 0;
       $136 = $135&1;
       if ($136) {
        break;
       }
       $137 = HEAP8[((2728312 + 116|0))>>0]|0;
       $138 = ($137<<24>>24)==(0);
       if ($138) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $139 = __THREW__; __THREW__ = 0;
        $140 = $139&1;
        if ($140) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $141 = __THREW__; __THREW__ = 0;
        $142 = $141&1;
        if ($142) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $143 = __THREW__; __THREW__ = 0;
        $144 = $143&1;
        if ($144) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $145 = __THREW__; __THREW__ = 0;
       $146 = $145&1;
       if ($146) {
        break;
       }
       $147 = HEAP32[((2728312 + 80|0))>>2]|0;
       $148 = (($147) + 8|0);
       $149 = HEAP32[$148>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        break;
       }
       $152 = (($0) + 8|0);
       $153 = HEAP32[$152>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($149|0));
       $154 = __THREW__; __THREW__ = 0;
       $155 = $154&1;
       if ($155) {
        break;
       }
       $156 = (($149) + 8|0);
       HEAP32[$156>>2] = $153;
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $157 = __THREW__; __THREW__ = 0;
       $158 = $157&1;
       if ($158) {
        break;
       }
       $159 = HEAP8[((2728312 + 116|0))>>0]|0;
       $160 = ($159<<24>>24)==(0);
       if ($160) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $161 = __THREW__; __THREW__ = 0;
        $162 = $161&1;
        if ($162) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $163 = __THREW__; __THREW__ = 0;
        $164 = $163&1;
        if ($164) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $165 = __THREW__; __THREW__ = 0;
        $166 = $165&1;
        if ($166) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $167 = __THREW__; __THREW__ = 0;
       $168 = $167&1;
       if ($168) {
        break;
       }
       $169 = HEAP32[((2728312 + 80|0))>>2]|0;
       $170 = (($169) + 8|0);
       $171 = HEAP32[$170>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $172 = __THREW__; __THREW__ = 0;
       $173 = $172&1;
       if ($173) {
        break;
       }
       $174 = (($0) + 12|0);
       $175 = HEAP32[$174>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($171|0));
       $176 = __THREW__; __THREW__ = 0;
       $177 = $176&1;
       if ($177) {
        break;
       }
       $178 = (($171) + 12|0);
       HEAP32[$178>>2] = $175;
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $179 = __THREW__; __THREW__ = 0;
       $180 = $179&1;
       if ($180) {
        break;
       }
       $181 = HEAP8[((2728312 + 116|0))>>0]|0;
       $182 = ($181<<24>>24)==(0);
       if ($182) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $183 = __THREW__; __THREW__ = 0;
        $184 = $183&1;
        if ($184) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $185 = __THREW__; __THREW__ = 0;
        $186 = $185&1;
        if ($186) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $187 = __THREW__; __THREW__ = 0;
        $188 = $187&1;
        if ($188) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $189 = __THREW__; __THREW__ = 0;
       $190 = $189&1;
       if ($190) {
        break;
       }
       $191 = HEAP32[((2728312 + 80|0))>>2]|0;
       $192 = (($191) + 8|0);
       $193 = HEAP32[$192>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($0|0));
       $194 = __THREW__; __THREW__ = 0;
       $195 = $194&1;
       if ($195) {
        break;
       }
       $196 = (($0) + 16|0);
       $197 = HEAP32[$196>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($193|0));
       $198 = __THREW__; __THREW__ = 0;
       $199 = $198&1;
       if ($199) {
        break;
       }
       $200 = (($193) + 16|0);
       HEAP32[$200>>2] = $197;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2728312|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = HEAP8[((2728312 + 116|0))>>0]|0;
       $17 = ($16<<24>>24)==(0);
       if ($17) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2728312|0));
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        $26 = HEAP32[((2728312 + 80|0))>>2]|0;
        $27 = (($26) + 8|0);
        $28 = HEAP32[$27>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2731232|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         __THREW__ = 0;
         $31 = (invoke_ii(3469,(2731232|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if (!($33)) {
          __THREW__ = 0;
          invoke_vi(2933,($31|0));
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if (!($35)) {
           __THREW__ = 0;
           invoke_vi(3799,($0|0));
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if (!($37)) {
            $38 = (($0) + 8|0);
            HEAP32[$38>>2] = $31;
            __THREW__ = 0;
            invoke_vi(3799,($28|0));
            $39 = __THREW__; __THREW__ = 0;
            $40 = $39&1;
            if (!($40)) {
             $41 = (($28) + 8|0);
             HEAP32[$41>>2] = $31;
             __THREW__ = 0;
             (invoke_ii(2996,(2728312|0))|0);
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if (!($43)) {
              $44 = HEAP8[((2728312 + 116|0))>>0]|0;
              $45 = ($44<<24>>24)==(0);
              if ($45) {
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $46 = __THREW__; __THREW__ = 0;
               $47 = $46&1;
               if ($47) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $48 = __THREW__; __THREW__ = 0;
               $49 = $48&1;
               if ($49) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3843,(2728312|0));
               $50 = __THREW__; __THREW__ = 0;
               $51 = $50&1;
               if ($51) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2728312|0))|0);
              $52 = __THREW__; __THREW__ = 0;
              $53 = $52&1;
              if (!($53)) {
               $54 = HEAP32[((2728312 + 80|0))>>2]|0;
               $55 = (($54) + 8|0);
               $56 = HEAP32[$55>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($56|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if (!($58)) {
                $59 = (($56) + 12|0);
                $60 = HEAP32[$59>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($60|0));
                $61 = __THREW__; __THREW__ = 0;
                $62 = $61&1;
                if (!($62)) {
                 __THREW__ = 0;
                 invoke_vii(3495,(2315400|0),($60|0));
                 $63 = __THREW__; __THREW__ = 0;
                 $64 = $63&1;
                 if (!($64)) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $65 = __THREW__; __THREW__ = 0;
                  $66 = $65&1;
                  if ($66) {
                   break;
                  }
                  $67 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $68 = ($67<<24>>24)==(0);
                  if ($68) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $69 = __THREW__; __THREW__ = 0;
                   $70 = $69&1;
                   if ($70) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $71 = __THREW__; __THREW__ = 0;
                   $72 = $71&1;
                   if ($72) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $73 = __THREW__; __THREW__ = 0;
                   $74 = $73&1;
                   if ($74) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $75 = __THREW__; __THREW__ = 0;
                  $76 = $75&1;
                  if ($76) {
                   break;
                  }
                  $77 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $78 = (($77) + 8|0);
                  $79 = HEAP32[$78>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($79|0));
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break;
                  }
                  $82 = (($79) + 12|0);
                  $83 = HEAP32[$82>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $84 = __THREW__; __THREW__ = 0;
                  $85 = $84&1;
                  if ($85) {
                   break;
                  }
                  $86 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $87 = ($86<<24>>24)==(0);
                  if ($87) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $88 = __THREW__; __THREW__ = 0;
                   $89 = $88&1;
                   if ($89) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $90 = __THREW__; __THREW__ = 0;
                   $91 = $90&1;
                   if ($91) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $92 = __THREW__; __THREW__ = 0;
                   $93 = $92&1;
                   if ($93) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $94 = __THREW__; __THREW__ = 0;
                  $95 = $94&1;
                  if ($95) {
                   break;
                  }
                  $96 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $97 = (($96) + 8|0);
                  $98 = HEAP32[$97>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($98|0));
                  $99 = __THREW__; __THREW__ = 0;
                  $100 = $99&1;
                  if ($100) {
                   break;
                  }
                  $101 = (($98) + 8|0);
                  $102 = HEAP32[$101>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($83|0));
                  $103 = __THREW__; __THREW__ = 0;
                  $104 = $103&1;
                  if ($104) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_viii(2113,(2315496|0),($83|0),($102|0));
                  $105 = __THREW__; __THREW__ = 0;
                  $106 = $105&1;
                  if ($106) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $107 = __THREW__; __THREW__ = 0;
                  $108 = $107&1;
                  if ($108) {
                   break;
                  }
                  $109 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $110 = ($109<<24>>24)==(0);
                  if ($110) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $111 = __THREW__; __THREW__ = 0;
                   $112 = $111&1;
                   if ($112) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $113 = __THREW__; __THREW__ = 0;
                   $114 = $113&1;
                   if ($114) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $115 = __THREW__; __THREW__ = 0;
                   $116 = $115&1;
                   if ($116) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $117 = __THREW__; __THREW__ = 0;
                  $118 = $117&1;
                  if ($118) {
                   break;
                  }
                  $119 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $120 = (($119) + 8|0);
                  $121 = HEAP32[$120>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2731232|0))|0);
                  $122 = __THREW__; __THREW__ = 0;
                  $123 = $122&1;
                  if ($123) {
                   break;
                  }
                  __THREW__ = 0;
                  $124 = (invoke_ii(3469,(2731232|0))|0);
                  $125 = __THREW__; __THREW__ = 0;
                  $126 = $125&1;
                  if ($126) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(2933,($124|0));
                  $127 = __THREW__; __THREW__ = 0;
                  $128 = $127&1;
                  if ($128) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($0|0));
                  $129 = __THREW__; __THREW__ = 0;
                  $130 = $129&1;
                  if ($130) {
                   break;
                  }
                  $131 = (($0) + 16|0);
                  HEAP32[$131>>2] = $124;
                  __THREW__ = 0;
                  invoke_vi(3799,($121|0));
                  $132 = __THREW__; __THREW__ = 0;
                  $133 = $132&1;
                  if ($133) {
                   break;
                  }
                  $134 = (($121) + 16|0);
                  HEAP32[$134>>2] = $124;
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z50UnityEngine_UnityEngine_GUILayoutEntry_m_set_styleP38UnityEngine_UnityEngine_GUILayoutEntryP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728592);
 $0 = (($__this) + 48|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_viii(2110,(2728640|0),($__this|0),($value|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN18VirtActionInvoker2I28mscorlib_System_SingleTraitsS0_E6InvokeEP10MethodInfoPvff($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = Math_fround($p1);
 $p2 = Math_fround($p2);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viff[$3 & 31]($4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z58UnityEngine_UnityEngine_GUILayoutUtility_m_LayoutFreeGroupP22mscorlib_System_ObjectP38UnityEngine_UnityEngine_GUILayoutGroup($__this,$toplevel) {
 $__this = $__this|0;
 $toplevel = $toplevel|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_5 = 0, $V_1 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 48|0;
 $V_1 = sp;
 $L_1 = sp + 16|0;
 $L_5 = sp + 32|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2727088);
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(3799,($toplevel|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($toplevel) + 52|0);
   $3 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vii(1633,($L_1|0),($3|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     ;HEAP32[$V_1+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_1+12>>2]|0;
     while(1) {
      __THREW__ = 0;
      $18 = (invoke_ii(3478,($V_1|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       label = 12;
       break;
      }
      if (!($18)) {
       $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 65;
       break;
      }
      __THREW__ = 0;
      $12 = (invoke_ii(3468,($V_1|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 12;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2731232|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if ($11) {
       label = 12;
       break;
      }
      __THREW__ = 0;
      $13 = (invoke_iii(2774,($12|0),(2731232|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       label = 12;
       break;
      }
      __THREW__ = 0;
      invoke_vii(2025,0,($13|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if ($17) {
       label = 12;
       break;
      }
     }
     if ((label|0) == 12) {
      $23 = ___cxa_find_matching_catch(348288|0)|0;
      $24 = tempRet0;
      $25 = (_llvm_eh_typeid_for((348288|0))|0);
      $26 = ($24|0)==($25|0);
      if (!($26)) {
       $$0 = $23;$$02 = $24;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$0|0);
       // unreachable;
      }
      $27 = (___cxa_begin_catch(($23|0))|0);
      $28 = HEAP32[$27>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      $__last_unhandled_exception$0 = $28;$leaveInstructions$sroa$0$0 = 0;
     }
     ;HEAP32[$L_5+0>>2]=HEAP32[$V_1+0>>2]|0;HEAP32[$L_5+4>>2]=HEAP32[$V_1+4>>2]|0;HEAP32[$L_5+8>>2]=HEAP32[$V_1+8>>2]|0;HEAP32[$L_5+12>>2]=HEAP32[$V_1+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1902144|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      __THREW__ = 0;
      $33 = (invoke_iii(2724,(1902144|0),($L_5|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       invoke_vi(3799,($33|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __THREW__ = 0;
        invoke_vii(3491,(2176768|0),($33|0));
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         $cond1 = ($leaveInstructions$sroa$0$0|0)==(65);
         if (!($cond1)) {
          __THREW__ = 0;
          invoke_vi(3844,($__last_unhandled_exception$0|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($toplevel|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          __THREW__ = 0;
          invoke_vi(2934,($toplevel|0));
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if (!($45)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $$0 = $8;$$02 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z60UnityEngine_UnityEngine_GUILayoutUtility_m_LayoutSingleGroupP22mscorlib_System_ObjectP38UnityEngine_UnityEngine_GUILayoutGroup($__this,$i) {
 $__this = $__this|0;
 $i = $i|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = Math_fround(0), $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0);
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = Math_fround(0), $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0;
 var $75 = Math_fround(0), $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = 0, $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $L_14 = 0, $V_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 40|0;
 $_stackTraceSentry = sp;
 $V_4 = sp + 8|0;
 $L_14 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2727136);
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;HEAP32[$V_4+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vi(3799,($i|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($i) + 65|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    $9 = (($i) + 8|0);
    $10 = Math_fround(HEAPF32[$9>>2]);
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    $13 = (($i) + 12|0);
    $14 = Math_fround(HEAPF32[$13>>2]);
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(3495,(2726848|0),($i|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    $21 = (($i) + 24|0);
    __THREW__ = 0;
    $22 = (Math_fround(+(invoke_fi(138,($21|0)))));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = Math_fround(HEAPF32[$13>>2]);
    __THREW__ = 0;
    $28 = (Math_fround(+(invoke_fifff(1,(0|0),(+$27),(+$10),(+$14)))));
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __THREW__ = 0;
    invoke_viiff(2,(2726896|0),($i|0),(+$22),(+$28));
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    $37 = (($i) + 16|0);
    $38 = Math_fround(HEAPF32[$37>>2]);
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    $41 = (($i) + 20|0);
    $42 = Math_fround(HEAPF32[$41>>2]);
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    invoke_vii(3495,(2726944|0),($i|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    __THREW__ = 0;
    $49 = (Math_fround(+(invoke_fi(139,($21|0)))));
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    $54 = Math_fround(HEAPF32[$41>>2]);
    __THREW__ = 0;
    $55 = (Math_fround(+(invoke_fifff(1,(0|0),(+$54),(+$38),(+$42)))));
    $56 = __THREW__; __THREW__ = 0;
    $57 = $56&1;
    if ($57) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($i|0));
    $58 = __THREW__; __THREW__ = 0;
    $59 = $58&1;
    if ($59) {
     break;
    }
    __THREW__ = 0;
    invoke_viiff(2,(2726992|0),($i|0),(+$49),(+$55));
    $60 = __THREW__; __THREW__ = 0;
    $61 = $60&1;
    if ($61) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3799,($i|0));
   $62 = __THREW__; __THREW__ = 0;
   $63 = $62&1;
   if (!($63)) {
    __THREW__ = 0;
    invoke_vii(3495,(2726848|0),($i|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if (!($65)) {
     __THREW__ = 0;
     invoke_vi(3799,($i|0));
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if (!($67)) {
      $68 = (($i) + 68|0);
      $69 = HEAP32[$68>>2]|0;
      __THREW__ = 0;
      invoke_viii(731,($L_14|0),0,($69|0));
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if (!($71)) {
       ;HEAP32[$V_4+0>>2]=HEAP32[$L_14+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_14+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_14+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[$L_14+12>>2]|0;
       __THREW__ = 0;
       $72 = (Math_fround(+(invoke_fi(138,($V_4|0)))));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if (!($74)) {
        __THREW__ = 0;
        $75 = (Math_fround(+(invoke_fi(140,($V_4|0)))));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if (!($77)) {
         __THREW__ = 0;
         invoke_vi(3799,($i|0));
         $78 = __THREW__; __THREW__ = 0;
         $79 = $78&1;
         if (!($79)) {
          $80 = (($i) + 8|0);
          $81 = Math_fround(HEAPF32[$80>>2]);
          __THREW__ = 0;
          invoke_vi(3799,($i|0));
          $82 = __THREW__; __THREW__ = 0;
          $83 = $82&1;
          if (!($83)) {
           $84 = (($i) + 12|0);
           $85 = Math_fround(HEAPF32[$84>>2]);
           __THREW__ = 0;
           $86 = (Math_fround(+(invoke_fifff(1,(0|0),(+$75),(+$81),(+$85)))));
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if (!($88)) {
            __THREW__ = 0;
            invoke_vi(3799,($i|0));
            $89 = __THREW__; __THREW__ = 0;
            $90 = $89&1;
            if (!($90)) {
             __THREW__ = 0;
             invoke_viiff(2,(2726896|0),($i|0),(+$72),(+$86));
             $91 = __THREW__; __THREW__ = 0;
             $92 = $91&1;
             if (!($92)) {
              __THREW__ = 0;
              invoke_vi(3799,($i|0));
              $93 = __THREW__; __THREW__ = 0;
              $94 = $93&1;
              if (!($94)) {
               __THREW__ = 0;
               invoke_vii(3495,(2726944|0),($i|0));
               $95 = __THREW__; __THREW__ = 0;
               $96 = $95&1;
               if (!($96)) {
                __THREW__ = 0;
                $97 = (Math_fround(+(invoke_fi(139,($V_4|0)))));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if (!($99)) {
                 __THREW__ = 0;
                 $100 = (Math_fround(+(invoke_fi(141,($V_4|0)))));
                 $101 = __THREW__; __THREW__ = 0;
                 $102 = $101&1;
                 if (!($102)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($i|0));
                  $103 = __THREW__; __THREW__ = 0;
                  $104 = $103&1;
                  if (!($104)) {
                   $105 = (($i) + 16|0);
                   $106 = Math_fround(HEAPF32[$105>>2]);
                   __THREW__ = 0;
                   invoke_vi(3799,($i|0));
                   $107 = __THREW__; __THREW__ = 0;
                   $108 = $107&1;
                   if (!($108)) {
                    $109 = (($i) + 20|0);
                    $110 = Math_fround(HEAPF32[$109>>2]);
                    __THREW__ = 0;
                    $111 = (Math_fround(+(invoke_fifff(1,(0|0),(+$100),(+$106),(+$110)))));
                    $112 = __THREW__; __THREW__ = 0;
                    $113 = $112&1;
                    if ($113) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($i|0));
                    $114 = __THREW__; __THREW__ = 0;
                    $115 = $114&1;
                    if ($115) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_viiff(2,(2726992|0),($i|0),(+$97),(+$111));
                    $116 = __THREW__; __THREW__ = 0;
                    $117 = $116&1;
                    if ($117) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($i|0));
                    $118 = __THREW__; __THREW__ = 0;
                    $119 = $118&1;
                    if ($119) {
                     break;
                    }
                    $120 = HEAP32[$68>>2]|0;
                    __THREW__ = 0;
                    invoke_vi(3799,($i|0));
                    $121 = __THREW__; __THREW__ = 0;
                    $122 = $121&1;
                    if ($122) {
                     break;
                    }
                    $123 = (($i) + 24|0);
                    __THREW__ = 0;
                    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$123+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$123+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$123+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$123+12>>2]|0;
                    invoke_viii(732,0,($120|0),($$byval_copy|0));
                    $124 = __THREW__; __THREW__ = 0;
                    $125 = $124&1;
                    if ($125) {
                     break;
                    }
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z65UnityEngine_UnityEngine_GUILayoutUtility_m_LayoutFromEditorWindowP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2727040);
 __THREW__ = 0;
 (invoke_ii(2996,(2728312|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2728312 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2728312|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2728312|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2728312 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($16) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($20|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      __THREW__ = 0;
      invoke_vii(3495,(2726848|0),($20|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2728312|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        $27 = HEAP8[((2728312 + 116|0))>>0]|0;
        $28 = ($27<<24>>24)==(0);
        if ($28) {
         __THREW__ = 0;
         (invoke_ii(2996,(2728312|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2728312|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2728312|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         $37 = HEAP32[((2728312 + 80|0))>>2]|0;
         $38 = (($37) + 8|0);
         $39 = HEAP32[$38>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($39|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = (($39) + 8|0);
          $43 = HEAP32[$42>>2]|0;
          __THREW__ = 0;
          $44 = (invoke_ii(2547,0)|0);
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if (!($46)) {
           __THREW__ = 0;
           invoke_vi(3799,($43|0));
           $47 = __THREW__; __THREW__ = 0;
           $48 = $47&1;
           if (!($48)) {
            $49 = (Math_fround(($44|0)));
            __THREW__ = 0;
            invoke_viiff(2,(2726896|0),($43|0),0.0,(+$49));
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if (!($51)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2728312|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              $54 = HEAP8[((2728312 + 116|0))>>0]|0;
              $55 = ($54<<24>>24)==(0);
              if ($55) {
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $56 = __THREW__; __THREW__ = 0;
               $57 = $56&1;
               if ($57) {
                break;
               }
               __THREW__ = 0;
               (invoke_ii(2996,(2728312|0))|0);
               $58 = __THREW__; __THREW__ = 0;
               $59 = $58&1;
               if ($59) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3843,(2728312|0));
               $60 = __THREW__; __THREW__ = 0;
               $61 = $60&1;
               if ($61) {
                break;
               }
              }
              __THREW__ = 0;
              (invoke_ii(2996,(2728312|0))|0);
              $62 = __THREW__; __THREW__ = 0;
              $63 = $62&1;
              if (!($63)) {
               $64 = HEAP32[((2728312 + 80|0))>>2]|0;
               $65 = (($64) + 8|0);
               $66 = HEAP32[$65>>2]|0;
               __THREW__ = 0;
               invoke_vi(3799,($66|0));
               $67 = __THREW__; __THREW__ = 0;
               $68 = $67&1;
               if (!($68)) {
                $69 = (($66) + 8|0);
                $70 = HEAP32[$69>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($70|0));
                $71 = __THREW__; __THREW__ = 0;
                $72 = $71&1;
                if (!($72)) {
                 __THREW__ = 0;
                 invoke_vii(3495,(2726944|0),($70|0));
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if (!($74)) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $75 = __THREW__; __THREW__ = 0;
                  $76 = $75&1;
                  if ($76) {
                   break;
                  }
                  $77 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $78 = ($77<<24>>24)==(0);
                  if ($78) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $79 = __THREW__; __THREW__ = 0;
                   $80 = $79&1;
                   if ($80) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $81 = __THREW__; __THREW__ = 0;
                   $82 = $81&1;
                   if ($82) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $83 = __THREW__; __THREW__ = 0;
                   $84 = $83&1;
                   if ($84) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $85 = __THREW__; __THREW__ = 0;
                  $86 = $85&1;
                  if ($86) {
                   break;
                  }
                  $87 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $88 = (($87) + 8|0);
                  $89 = HEAP32[$88>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($89|0));
                  $90 = __THREW__; __THREW__ = 0;
                  $91 = $90&1;
                  if ($91) {
                   break;
                  }
                  $92 = (($89) + 8|0);
                  $93 = HEAP32[$92>>2]|0;
                  __THREW__ = 0;
                  $94 = (invoke_ii(2548,0)|0);
                  $95 = __THREW__; __THREW__ = 0;
                  $96 = $95&1;
                  if ($96) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($93|0));
                  $97 = __THREW__; __THREW__ = 0;
                  $98 = $97&1;
                  if ($98) {
                   break;
                  }
                  $99 = (Math_fround(($94|0)));
                  __THREW__ = 0;
                  invoke_viiff(2,(2726992|0),($93|0),0.0,(+$99));
                  $100 = __THREW__; __THREW__ = 0;
                  $101 = $100&1;
                  if ($101) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $102 = __THREW__; __THREW__ = 0;
                  $103 = $102&1;
                  if ($103) {
                   break;
                  }
                  $104 = HEAP8[((2728312 + 116|0))>>0]|0;
                  $105 = ($104<<24>>24)==(0);
                  if ($105) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $106 = __THREW__; __THREW__ = 0;
                   $107 = $106&1;
                   if ($107) {
                    break;
                   }
                   __THREW__ = 0;
                   (invoke_ii(2996,(2728312|0))|0);
                   $108 = __THREW__; __THREW__ = 0;
                   $109 = $108&1;
                   if ($109) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3843,(2728312|0));
                   $110 = __THREW__; __THREW__ = 0;
                   $111 = $110&1;
                   if ($111) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2728312|0))|0);
                  $112 = __THREW__; __THREW__ = 0;
                  $113 = $112&1;
                  if ($113) {
                   break;
                  }
                  $114 = HEAP32[((2728312 + 80|0))>>2]|0;
                  $115 = (($114) + 8|0);
                  $116 = HEAP32[$115>>2]|0;
                  __THREW__ = 0;
                  invoke_vi(3799,($116|0));
                  $117 = __THREW__; __THREW__ = 0;
                  $118 = $117&1;
                  if ($118) {
                   break;
                  }
                  $119 = (($116) + 16|0);
                  $120 = HEAP32[$119>>2]|0;
                  __THREW__ = 0;
                  invoke_vii(2024,0,($120|0));
                  $121 = __THREW__; __THREW__ = 0;
                  $122 = $121&1;
                  if ($122) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL103mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_MoveNextP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry10874($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo(1902144)|0);
 $0 = HEAP32[((1902144 + 84|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNext_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z52UnityEngine_UnityEngine_GUILayoutGroup_m_ResetCursorP38UnityEngine_UnityEngine_GUILayoutGroup($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2730160);
 $0 = (($__this) + 72|0);
 HEAP32[$0>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z65UnityEngine_UnityEngine_GUILayoutUtility_m_Internal_GetWindowRectP22mscorlib_System_Objecti($agg$result,$__this,$windowID) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $windowID = $windowID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2727184);
 $0 = HEAP32[2727232>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2727240|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2727232>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($agg$result|0),($windowID|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z62UnityEngine_UnityEngine_GUILayoutUtility_m_Internal_MoveWindowP22mscorlib_System_Objecti28UnityEngine_UnityEngine_Rect($__this,$windowID,$r) {
 $__this = $__this|0;
 $windowID = $windowID|0;
 $r = $r|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2727312);
 __THREW__ = 0;
 invoke_viii(733,0,($windowID|0),($r|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z76UnityEngine_UnityEngine_GUILayoutUtility_m_INTERNAL_CALL_Internal_MoveWindowP22mscorlib_System_ObjectiP28UnityEngine_UnityEngine_Rect($__this,$windowID,$r) {
 $__this = $__this|0;
 $windowID = $windowID|0;
 $r = $r|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2727360);
 $0 = HEAP32[2727408>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2727416|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2727408>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($windowID|0),($r|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z57UnityEngine_UnityEngine_GUILayoutUtility_m_get_spaceStyleP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2727512);
 __THREW__ = 0;
 (invoke_ii(2996,(2728312|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2728312 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2728312|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2728312|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2728312 + 80|0))>>2]|0;
    $15 = (($14) + 28|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2749952|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2749952|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3007,($20|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2728312|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     $27 = HEAP8[((2728312 + 116|0))>>0]|0;
     $28 = ($27<<24>>24)==(0);
     if ($28) {
      __THREW__ = 0;
      (invoke_ii(2996,(2728312|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2728312|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2728312|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2728312|0))|0);
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     $37 = HEAP32[((2728312 + 80|0))>>2]|0;
     $38 = (($37) + 28|0);
     HEAP32[$38>>2] = $20;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2728312|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if (!($40)) {
     $41 = HEAP8[((2728312 + 116|0))>>0]|0;
     $42 = ($41<<24>>24)==(0);
     if ($42) {
      __THREW__ = 0;
      (invoke_ii(2996,(2728312|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2728312|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2728312|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2728312|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if (!($50)) {
      $51 = HEAP32[((2728312 + 80|0))>>2]|0;
      $52 = (($51) + 28|0);
      $53 = HEAP32[$52>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($53|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if (!($55)) {
       __THREW__ = 0;
       invoke_vii(2062,($53|0),0);
       $56 = __THREW__; __THREW__ = 0;
       $57 = $56&1;
       if (!($57)) {
        __THREW__ = 0;
        (invoke_ii(2996,(2728312|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if (!($59)) {
         $60 = HEAP8[((2728312 + 116|0))>>0]|0;
         $61 = ($60<<24>>24)==(0);
         if ($61) {
          __THREW__ = 0;
          (invoke_ii(2996,(2728312|0))|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2728312|0))|0);
          $64 = __THREW__; __THREW__ = 0;
          $65 = $64&1;
          if ($65) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3843,(2728312|0));
          $66 = __THREW__; __THREW__ = 0;
          $67 = $66&1;
          if ($67) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2728312|0))|0);
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if (!($69)) {
          $70 = HEAP32[((2728312 + 80|0))>>2]|0;
          $71 = (($70) + 28|0);
          $72 = HEAP32[$71>>2]|0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($72|0);
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z40UnityEngine_UnityEngine_GUIStyle_m__ctorP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2746848);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3010,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z51UnityEngine_UnityEngine_GUIStyle_m_set_stretchWidthP32UnityEngine_UnityEngine_GUIStyleb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2748032);
 $0 = HEAP32[2748080>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2748088|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2748080>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN14ActionInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_E6InvokeEPFvPviS3_S3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$1,$3,$5);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I34UnityEngine_UnityEngine_RectTraits27mscorlib_System_Int32TraitsE6InvokeEPF28UnityEngine_UnityEngine_RectPviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2797856,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits34UnityEngine_UnityEngine_RectTraitsE6InvokeEPFvPvi28UnityEngine_UnityEngine_RectES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z137UnityEngine_UnityEngine_GUILayoutUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUILayoutUtility_m_Internal_GetWindowRectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z148UnityEngine_UnityEngine_GUILayoutUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUILayoutUtility_m_INTERNAL_CALL_Internal_MoveWindowP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP38UnityEngine_UnityEngine_GUILayoutEntryffffP32UnityEngine_UnityEngine_GUIStyle($__this,$_minWidth,$_maxWidth,$_minHeight,$_maxHeight,$_style) {
 $__this = $__this|0;
 $_minWidth = Math_fround($_minWidth);
 $_maxWidth = Math_fround($_maxWidth);
 $_minHeight = Math_fround($_minHeight);
 $_maxHeight = Math_fround($_maxHeight);
 $_style = $_style|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728448);
 ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;HEAP32[$L_4+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viffff(4,($L_4|0),0.0,0.0,0.0,0.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 24|0);
   ;HEAP32[$2+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$L_4+12>>2]|0;
   __THREW__ = 0;
   $3 = (invoke_ii(2596,0)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = (($__this) + 48|0);
    HEAP32[$6>>2] = $3;
    __THREW__ = 0;
    invoke_vi(1924,($__this|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($__this) + 8|0);
     HEAPF32[$9>>2] = $_minWidth;
     $10 = (($__this) + 12|0);
     HEAPF32[$10>>2] = $_maxWidth;
     $11 = (($__this) + 16|0);
     HEAPF32[$11>>2] = $_minHeight;
     $12 = (($__this) + 20|0);
     HEAPF32[$12>>2] = $_maxHeight;
     $13 = ($_style|0)==(0|0);
     if ($13) {
      __THREW__ = 0;
      $16 = (invoke_ii(2596,0)|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      } else {
       $$0 = $16;
      }
     } else {
      $$0 = $_style;
     }
     __THREW__ = 0;
     invoke_vii(2026,($__this|0),($$0|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z47UnityEngine_UnityEngine_GUILayoutEntry_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_4 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728496);
 ;HEAP32[$L_4+0>>2]=0|0;HEAP32[$L_4+4>>2]=0|0;HEAP32[$L_4+8>>2]=0|0;HEAP32[$L_4+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viffff(4,($L_4|0),0.0,0.0,1.0,1.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2729880|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[((2729880 + 80|0))>>2]|0;
   ;HEAP32[$4+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$L_4+12>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2729880|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[((2729880 + 80|0))>>2]|0;
    $8 = (($7) + 16|0);
    HEAP32[$8>>2] = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z50UnityEngine_UnityEngine_GUILayoutEntry_m_get_styleP38UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728544);
 $0 = (($__this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z51UnityEngine_UnityEngine_GUILayoutEntry_m_get_marginP38UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728688);
 __THREW__ = 0;
 $0 = (invoke_ii(2550,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   $5 = (invoke_ii(2592,($0|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($5|0);
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_GUIStyle_m_get_marginP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747528);
 $1 = (($__this) + 52|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $14 = $2;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($14|0);
 }
 __THREW__ = 0;
 $4 = (invoke_iii(1211,($__this|0),1)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2746216|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_ii(3469,(2746216|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$0>>2] = $4;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viii(737,($9|0),($__this|0),($$byval_copy|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     HEAP32[$1>>2] = $9;
     $14 = $9;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($14|0);
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z50UnityEngine_UnityEngine_GUILayoutEntry_m_CalcWidthP38UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728736);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z51UnityEngine_UnityEngine_GUILayoutEntry_m_CalcHeightP38UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728784);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54UnityEngine_UnityEngine_GUILayoutEntry_m_SetHorizontalP38UnityEngine_UnityEngine_GUILayoutEntryff($__this,$x,$width) {
 $__this = $__this|0;
 $x = Math_fround($x);
 $width = Math_fround($width);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728832);
 $0 = (($__this) + 24|0);
 __THREW__ = 0;
 invoke_vif(114,($0|0),(+$x));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vif(116,($0|0),(+$width));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z52UnityEngine_UnityEngine_GUILayoutEntry_m_SetVerticalP38UnityEngine_UnityEngine_GUILayoutEntryff($__this,$y,$height) {
 $__this = $__this|0;
 $y = Math_fround($y);
 $height = Math_fround($height);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728880);
 $0 = (($__this) + 24|0);
 __THREW__ = 0;
 invoke_vif(115,($0|0),(+$y));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_vif(117,($0|0),(+$height));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z59UnityEngine_UnityEngine_GUILayoutEntry_m_ApplyStyleSettingsP38UnityEngine_UnityEngine_GUILayoutEntryP32UnityEngine_UnityEngine_GUIStyle($__this,$style) {
 $__this = $__this|0;
 $style = $style|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = Math_fround(0), $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B4_0$0 = 0, $G_B8_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728640);
 __THREW__ = 0;
 invoke_vi(3799,($style|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (Math_fround(+(invoke_fi(134,($style|0)))));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = $2 != Math_fround(0.0);
    if ($5) {
     label = 8;
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($style|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(2594,($style|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     if ($10) {
      $G_B4_0$0 = 1;
     } else {
      label = 8;
     }
    }
    if ((label|0) == 8) {
     $G_B4_0$0 = 0;
    }
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = (($__this) + 40|0);
     HEAP32[$15>>2] = $G_B4_0$0;
     __THREW__ = 0;
     invoke_vi(3799,($style|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      $18 = (Math_fround(+(invoke_fi(135,($style|0)))));
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       $21 = $18 != Math_fround(0.0);
       if ($21) {
        label = 16;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($style|0));
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if ($23) {
         break;
        }
        __THREW__ = 0;
        $24 = (invoke_ii(2595,($style|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         break;
        }
        if ($24) {
         $G_B8_0$0 = 1;
        } else {
         label = 16;
        }
       }
       if ((label|0) == 16) {
        $G_B8_0$0 = 0;
       }
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $29 = (($__this) + 44|0);
        HEAP32[$29>>2] = $G_B8_0$0;
        $30 = (($__this) + 48|0);
        HEAP32[$30>>2] = $style;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_GUIStyle_m_get_fixedWidthP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747736);
 $0 = HEAP32[2747784>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747784>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($__this|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z51UnityEngine_UnityEngine_GUIStyle_m_get_stretchWidthP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747928);
 $0 = HEAP32[2747976>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747984|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747976>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z50UnityEngine_UnityEngine_GUIStyle_m_get_fixedHeightP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747832);
 $0 = HEAP32[2747880>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747888|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747880>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($__this|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z52UnityEngine_UnityEngine_GUIStyle_m_get_stretchHeightP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2748144);
 $0 = HEAP32[2748192>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2748200|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2748192>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z53UnityEngine_UnityEngine_GUILayoutEntry_m_ApplyOptionsP38UnityEngine_UnityEngine_GUILayoutEntryP43UnityEngine_UnityEngine_GUILayoutOption_arr($__this,$options) {
 $__this = $__this|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = Math_fround(0), $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = Math_fround(0);
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0), $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728928);
 $0 = ($options|0)==(0|0);
 if ($0) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $1 = (($options) + 12|0);
 $2 = (($options) + 16|0);
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 8|0);
 $5 = (($__this) + 40|0);
 $6 = (($__this) + 20|0);
 $7 = (($__this) + 16|0);
 $8 = (($__this) + 44|0);
 $V_2$0 = 0;
 L4: while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($options|0));
  $117 = __THREW__; __THREW__ = 0;
  $118 = $117&1;
  if ($118) {
   label = 6;
   break;
  }
  $119 = HEAP32[$1>>2]|0;
  $120 = ($V_2$0|0)<($119|0);
  if (!($120)) {
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($options|0));
  $121 = __THREW__; __THREW__ = 0;
  $122 = $121&1;
  if ($122) {
   label = 6;
   break;
  }
  $9 = HEAP32[$1>>2]|0;
  $10 = ($V_2$0>>>0)<($9>>>0);
  if (!($10)) {
   __THREW__ = 0;
   $11 = (invoke_i(132)|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($11|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if ($15) {
    label = 6;
    break;
   }
  }
  $18 = HEAP32[$options>>2]|0;
  $19 = (($18) + 92|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = Math_imul($20, $V_2$0)|0;
  $22 = (($2) + ($21)|0);
  $23 = HEAP32[$22>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($23|0));
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if ($25) {
   label = 6;
   break;
  }
  $26 = (($23) + 8|0);
  $27 = HEAP32[$26>>2]|0;
  switch ($27|0) {
  case 1:  {
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $38 = __THREW__; __THREW__ = 0;
   $39 = $38&1;
   if ($39) {
    label = 6;
    break L4;
   }
   $40 = (($23) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2194912|0))|0);
   $42 = __THREW__; __THREW__ = 0;
   $43 = $42&1;
   if ($43) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $44 = (invoke_iii(2775,($41|0),(2194912|0))|0);
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if ($46) {
    label = 6;
    break L4;
   }
   $47 = Math_fround(HEAPF32[$44>>2]);
   HEAPF32[$6>>2] = $47;
   HEAPF32[$7>>2] = $47;
   HEAP32[$8>>2] = 0;
   break;
  }
  case 0:  {
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $28 = __THREW__; __THREW__ = 0;
   $29 = $28&1;
   if ($29) {
    label = 6;
    break L4;
   }
   $30 = (($23) + 12|0);
   $31 = HEAP32[$30>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2194912|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if ($33) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $34 = (invoke_iii(2775,($31|0),(2194912|0))|0);
   $35 = __THREW__; __THREW__ = 0;
   $36 = $35&1;
   if ($36) {
    label = 6;
    break L4;
   }
   $37 = Math_fround(HEAPF32[$34>>2]);
   HEAPF32[$3>>2] = $37;
   HEAPF32[$4>>2] = $37;
   HEAP32[$5>>2] = 0;
   break;
  }
  case 2:  {
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    label = 6;
    break L4;
   }
   $50 = (($23) + 12|0);
   $51 = HEAP32[$50>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2194912|0))|0);
   $52 = __THREW__; __THREW__ = 0;
   $53 = $52&1;
   if ($53) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $54 = (invoke_iii(2775,($51|0),(2194912|0))|0);
   $55 = __THREW__; __THREW__ = 0;
   $56 = $55&1;
   if ($56) {
    label = 6;
    break L4;
   }
   $57 = Math_fround(HEAPF32[$54>>2]);
   HEAPF32[$4>>2] = $57;
   $58 = Math_fround(HEAPF32[$3>>2]);
   $59 = !($58 >= $57);
   if ($59) {
    HEAPF32[$3>>2] = $57;
   }
   break;
  }
  case 3:  {
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $60 = __THREW__; __THREW__ = 0;
   $61 = $60&1;
   if ($61) {
    label = 6;
    break L4;
   }
   $62 = (($23) + 12|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2194912|0))|0);
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $66 = (invoke_iii(2775,($63|0),(2194912|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break L4;
   }
   $69 = Math_fround(HEAPF32[$66>>2]);
   HEAPF32[$3>>2] = $69;
   $70 = Math_fround(HEAPF32[$4>>2]);
   $71 = !($70 <= $69);
   if ($71) {
    HEAPF32[$4>>2] = $69;
   }
   HEAP32[$5>>2] = 0;
   break;
  }
  case 4:  {
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break L4;
   }
   $74 = (($23) + 12|0);
   $75 = HEAP32[$74>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2194912|0))|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $78 = (invoke_iii(2775,($75|0),(2194912|0))|0);
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    label = 6;
    break L4;
   }
   $81 = Math_fround(HEAPF32[$78>>2]);
   HEAPF32[$7>>2] = $81;
   $82 = Math_fround(HEAPF32[$6>>2]);
   $83 = !($82 >= $81);
   if ($83) {
    HEAPF32[$6>>2] = $81;
   }
   break;
  }
  case 7:  {
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $106 = __THREW__; __THREW__ = 0;
   $107 = $106&1;
   if ($107) {
    label = 6;
    break L4;
   }
   $108 = (($23) + 12|0);
   $109 = HEAP32[$108>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $110 = __THREW__; __THREW__ = 0;
   $111 = $110&1;
   if ($111) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $112 = (invoke_iii(2775,($109|0),(2155952|0))|0);
   $113 = __THREW__; __THREW__ = 0;
   $114 = $113&1;
   if ($114) {
    label = 6;
    break L4;
   }
   $115 = HEAP32[$112>>2]|0;
   HEAP32[$8>>2] = $115;
   break;
  }
  case 6:  {
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $96 = __THREW__; __THREW__ = 0;
   $97 = $96&1;
   if ($97) {
    label = 6;
    break L4;
   }
   $98 = (($23) + 12|0);
   $99 = HEAP32[$98>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $100 = __THREW__; __THREW__ = 0;
   $101 = $100&1;
   if ($101) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $102 = (invoke_iii(2775,($99|0),(2155952|0))|0);
   $103 = __THREW__; __THREW__ = 0;
   $104 = $103&1;
   if ($104) {
    label = 6;
    break L4;
   }
   $105 = HEAP32[$102>>2]|0;
   HEAP32[$5>>2] = $105;
   break;
  }
  case 5:  {
   __THREW__ = 0;
   invoke_vi(3799,($23|0));
   $84 = __THREW__; __THREW__ = 0;
   $85 = $84&1;
   if ($85) {
    label = 6;
    break L4;
   }
   $86 = (($23) + 12|0);
   $87 = HEAP32[$86>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(2194912|0))|0);
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break L4;
   }
   __THREW__ = 0;
   $90 = (invoke_iii(2775,($87|0),(2194912|0))|0);
   $91 = __THREW__; __THREW__ = 0;
   $92 = $91&1;
   if ($92) {
    label = 6;
    break L4;
   }
   $93 = Math_fround(HEAPF32[$90>>2]);
   HEAPF32[$6>>2] = $93;
   $94 = Math_fround(HEAPF32[$7>>2]);
   $95 = !($94 <= $93);
   if ($95) {
    HEAPF32[$7>>2] = $93;
   }
   HEAP32[$8>>2] = 0;
   break;
  }
  default: {
  }
  }
  $116 = (($V_2$0) + 1)|0;
  $V_2$0 = $116;
 }
 if ((label|0) == 6) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 }
 $123 = Math_fround(HEAPF32[$3>>2]);
 $124 = $123 == Math_fround(0.0);
 if (!($124)) {
  $125 = Math_fround(HEAPF32[$4>>2]);
  $126 = !($123 >= $125);
  if ($126) {
   HEAPF32[$3>>2] = $125;
  }
 }
 $127 = Math_fround(HEAPF32[$6>>2]);
 $128 = $127 == Math_fround(0.0);
 if ($128) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $129 = Math_fround(HEAPF32[$7>>2]);
 $130 = !($127 >= $129);
 if (!($130)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 HEAPF32[$6>>2] = $129;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z49UnityEngine_UnityEngine_GUILayoutEntry_m_ToStringP38UnityEngine_UnityEngine_GUILayoutEntry($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = Math_fround(0), $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = Math_fround(0), $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = Math_fround(0), $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = Math_fround(0), $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = Math_fround(0), $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = Math_fround(0), $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = Math_fround(0), $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $G_B12_0$0 = 0, $G_B12_0$0$in = 0, $G_B6_0$0 = 0, $G_B9_0$0 = 0, $G_B9_0$0$in = 0;
 var $L_31 = 0, $L_38 = 0, $L_45 = 0, $L_52 = 0, $L_62 = 0, $L_71 = 0, $L_85 = 0, $L_94 = 0, $V_0$0 = 0, $V_1$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_31 = sp + 28|0;
 $L_38 = sp + 24|0;
 $L_45 = sp + 20|0;
 $L_52 = sp + 16|0;
 $L_62 = sp + 8|0;
 $L_71 = sp + 4|0;
 $L_85 = sp;
 $L_94 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2728976);
 __THREW__ = 0;
 invoke_v(962);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    $4 = HEAP8[((2191608 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3843,(2191608|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[((2191608 + 80|0))>>2]|0;
     $19 = HEAP32[$18>>2]|0;
     $V_0$0 = $19;$V_1$0 = 0;
     while(1) {
      __THREW__ = 0;
      (invoke_ii(2996,(2729880|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 7;
       break;
      }
      $23 = HEAP8[((2729880 + 116|0))>>0]|0;
      $24 = ($23<<24>>24)==(0);
      if ($24) {
       __THREW__ = 0;
       (invoke_ii(2996,(2729880|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if ($26) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2729880|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        label = 7;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2729880|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        label = 7;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2729880|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 7;
       break;
      }
      $33 = HEAP32[((2729880 + 80|0))>>2]|0;
      $34 = (($33) + 16|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ($V_1$0|0)<($35|0);
      if (!($36)) {
       break;
      }
      $37 = HEAP32[2997944>>2]|0;
      __THREW__ = 0;
      $38 = (invoke_iiii(562,(0|0),($V_0$0|0),($37|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 7;
       break;
      }
      $20 = (($V_1$0) + 1)|0;
      $V_0$0 = $38;$V_1$0 = $20;
     }
     if ((label|0) == 7) {
      $12 = ___cxa_find_matching_catch()|0;
      $13 = tempRet0;
      $lpad$phi$index = $12;$lpad$phi$index2 = $13;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if (!($42)) {
      __THREW__ = 0;
      $43 = (invoke_iii(2773,(1167664|0),12)|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if (!($45)) {
       __THREW__ = 0;
       invoke_vi(3799,($43|0));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if (!($47)) {
        $48 = (($43) + 12|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = ($49|0)==(0);
        if ($50) {
         __THREW__ = 0;
         $51 = (invoke_i(132)|0);
         $52 = __THREW__; __THREW__ = 0;
         $53 = $52&1;
         if ($53) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($51|0));
         $54 = __THREW__; __THREW__ = 0;
         $55 = $54&1;
         if ($55) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($43|0),($V_0$0|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if (!($57)) {
         $58 = (($43) + 16|0);
         HEAP32[$58>>2] = $V_0$0;
         __THREW__ = 0;
         (invoke_ii(2996,(1167664|0))|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if (!($60)) {
          __THREW__ = 0;
          $61 = (invoke_iii(2773,(1167664|0),6)|0);
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if (!($63)) {
           __THREW__ = 0;
           $64 = (invoke_ii(2550,($__this|0))|0);
           $65 = __THREW__; __THREW__ = 0;
           $66 = $65&1;
           if (!($66)) {
            $67 = HEAP32[2997952>>2]|0;
            $68 = ($64|0)==(0|0);
            if ($68) {
             $69 = HEAP32[2997960>>2]|0;
             $G_B6_0$0 = $69;
            } else {
             __THREW__ = 0;
             $70 = (invoke_ii(2550,($__this|0))|0);
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if ($72) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3799,($70|0));
             $73 = __THREW__; __THREW__ = 0;
             $74 = $73&1;
             if ($74) {
              break;
             }
             __THREW__ = 0;
             $75 = (invoke_ii(2590,($70|0))|0);
             $76 = __THREW__; __THREW__ = 0;
             $77 = $76&1;
             if ($77) {
              break;
             } else {
              $G_B6_0$0 = $75;
             }
            }
            __THREW__ = 0;
            invoke_vi(3799,($61|0));
            $78 = __THREW__; __THREW__ = 0;
            $79 = $78&1;
            if (!($79)) {
             $80 = (($61) + 12|0);
             $81 = HEAP32[$80>>2]|0;
             $82 = ($81|0)==(0);
             if ($82) {
              __THREW__ = 0;
              $83 = (invoke_i(132)|0);
              $84 = __THREW__; __THREW__ = 0;
              $85 = $84&1;
              if ($85) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($83|0));
              $86 = __THREW__; __THREW__ = 0;
              $87 = $86&1;
              if ($87) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($61|0),($G_B6_0$0|0));
             $88 = __THREW__; __THREW__ = 0;
             $89 = $88&1;
             if (!($89)) {
              $90 = (($61) + 16|0);
              HEAP32[$90>>2] = $G_B6_0$0;
              __THREW__ = 0;
              $91 = (invoke_ii(1782,($__this|0))|0);
              $92 = __THREW__; __THREW__ = 0;
              $93 = $92&1;
              if (!($93)) {
               __THREW__ = 0;
               invoke_vi(3799,($61|0));
               $94 = __THREW__; __THREW__ = 0;
               $95 = $94&1;
               if (!($95)) {
                $96 = HEAP32[$80>>2]|0;
                $97 = ($96>>>0)<(2);
                if ($97) {
                 __THREW__ = 0;
                 $98 = (invoke_i(132)|0);
                 $99 = __THREW__; __THREW__ = 0;
                 $100 = $99&1;
                 if ($100) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($98|0));
                 $101 = __THREW__; __THREW__ = 0;
                 $102 = $101&1;
                 if ($102) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($61|0),($91|0));
                $103 = __THREW__; __THREW__ = 0;
                $104 = $103&1;
                if ($104) {
                 break;
                }
                $105 = HEAP32[$61>>2]|0;
                $106 = (($105) + 92|0);
                $107 = HEAP32[$106>>2]|0;
                $108 = (($90) + ($107)|0);
                HEAP32[$108>>2] = $91;
                $109 = (($__this) + 24|0);
                __THREW__ = 0;
                $110 = (Math_fround(+(invoke_fi(138,($109|0)))));
                $111 = __THREW__; __THREW__ = 0;
                $112 = $111&1;
                if ($112) {
                 break;
                }
                HEAPF32[$L_31>>2] = $110;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $113 = __THREW__; __THREW__ = 0;
                $114 = $113&1;
                if ($114) {
                 break;
                }
                __THREW__ = 0;
                $115 = (invoke_iii(2724,(2194912|0),($L_31|0))|0);
                $116 = __THREW__; __THREW__ = 0;
                $117 = $116&1;
                if ($117) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($61|0));
                $118 = __THREW__; __THREW__ = 0;
                $119 = $118&1;
                if ($119) {
                 break;
                }
                $120 = HEAP32[$80>>2]|0;
                $121 = ($120>>>0)<(3);
                if ($121) {
                 __THREW__ = 0;
                 $122 = (invoke_i(132)|0);
                 $123 = __THREW__; __THREW__ = 0;
                 $124 = $123&1;
                 if ($124) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($122|0));
                 $125 = __THREW__; __THREW__ = 0;
                 $126 = $125&1;
                 if ($126) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($61|0),($115|0));
                $127 = __THREW__; __THREW__ = 0;
                $128 = $127&1;
                if ($128) {
                 break;
                }
                $129 = HEAP32[$61>>2]|0;
                $130 = (($129) + 92|0);
                $131 = HEAP32[$130>>2]|0;
                $132 = $131 << 1;
                $133 = (($90) + ($132)|0);
                HEAP32[$133>>2] = $115;
                __THREW__ = 0;
                $134 = (Math_fround(+(invoke_fi(144,($109|0)))));
                $135 = __THREW__; __THREW__ = 0;
                $136 = $135&1;
                if ($136) {
                 break;
                }
                HEAPF32[$L_38>>2] = $134;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $137 = __THREW__; __THREW__ = 0;
                $138 = $137&1;
                if ($138) {
                 break;
                }
                __THREW__ = 0;
                $139 = (invoke_iii(2724,(2194912|0),($L_38|0))|0);
                $140 = __THREW__; __THREW__ = 0;
                $141 = $140&1;
                if ($141) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($61|0));
                $142 = __THREW__; __THREW__ = 0;
                $143 = $142&1;
                if ($143) {
                 break;
                }
                $144 = HEAP32[$80>>2]|0;
                $145 = ($144>>>0)<(4);
                if ($145) {
                 __THREW__ = 0;
                 $146 = (invoke_i(132)|0);
                 $147 = __THREW__; __THREW__ = 0;
                 $148 = $147&1;
                 if ($148) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($146|0));
                 $149 = __THREW__; __THREW__ = 0;
                 $150 = $149&1;
                 if ($150) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($61|0),($139|0));
                $151 = __THREW__; __THREW__ = 0;
                $152 = $151&1;
                if ($152) {
                 break;
                }
                $153 = HEAP32[$61>>2]|0;
                $154 = (($153) + 92|0);
                $155 = HEAP32[$154>>2]|0;
                $156 = ($155*3)|0;
                $157 = (($90) + ($156)|0);
                HEAP32[$157>>2] = $139;
                __THREW__ = 0;
                $158 = (Math_fround(+(invoke_fi(139,($109|0)))));
                $159 = __THREW__; __THREW__ = 0;
                $160 = $159&1;
                if ($160) {
                 break;
                }
                HEAPF32[$L_45>>2] = $158;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $161 = __THREW__; __THREW__ = 0;
                $162 = $161&1;
                if ($162) {
                 break;
                }
                __THREW__ = 0;
                $163 = (invoke_iii(2724,(2194912|0),($L_45|0))|0);
                $164 = __THREW__; __THREW__ = 0;
                $165 = $164&1;
                if ($165) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($61|0));
                $166 = __THREW__; __THREW__ = 0;
                $167 = $166&1;
                if ($167) {
                 break;
                }
                $168 = HEAP32[$80>>2]|0;
                $169 = ($168>>>0)<(5);
                if ($169) {
                 __THREW__ = 0;
                 $170 = (invoke_i(132)|0);
                 $171 = __THREW__; __THREW__ = 0;
                 $172 = $171&1;
                 if ($172) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($170|0));
                 $173 = __THREW__; __THREW__ = 0;
                 $174 = $173&1;
                 if ($174) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($61|0),($163|0));
                $175 = __THREW__; __THREW__ = 0;
                $176 = $175&1;
                if ($176) {
                 break;
                }
                $177 = HEAP32[$61>>2]|0;
                $178 = (($177) + 92|0);
                $179 = HEAP32[$178>>2]|0;
                $180 = $179 << 2;
                $181 = (($90) + ($180)|0);
                HEAP32[$181>>2] = $163;
                __THREW__ = 0;
                $182 = (Math_fround(+(invoke_fi(145,($109|0)))));
                $183 = __THREW__; __THREW__ = 0;
                $184 = $183&1;
                if ($184) {
                 break;
                }
                HEAPF32[$L_52>>2] = $182;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $185 = __THREW__; __THREW__ = 0;
                $186 = $185&1;
                if ($186) {
                 break;
                }
                __THREW__ = 0;
                $187 = (invoke_iii(2724,(2194912|0),($L_52|0))|0);
                $188 = __THREW__; __THREW__ = 0;
                $189 = $188&1;
                if ($189) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($61|0));
                $190 = __THREW__; __THREW__ = 0;
                $191 = $190&1;
                if ($191) {
                 break;
                }
                $192 = HEAP32[$80>>2]|0;
                $193 = ($192>>>0)<(6);
                if ($193) {
                 __THREW__ = 0;
                 $194 = (invoke_i(132)|0);
                 $195 = __THREW__; __THREW__ = 0;
                 $196 = $195&1;
                 if ($196) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($194|0));
                 $197 = __THREW__; __THREW__ = 0;
                 $198 = $197&1;
                 if ($198) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($61|0),($187|0));
                $199 = __THREW__; __THREW__ = 0;
                $200 = $199&1;
                if ($200) {
                 break;
                }
                $201 = HEAP32[$61>>2]|0;
                $202 = (($201) + 92|0);
                $203 = HEAP32[$202>>2]|0;
                $204 = ($203*5)|0;
                $205 = (($90) + ($204)|0);
                HEAP32[$205>>2] = $187;
                __THREW__ = 0;
                $206 = (invoke_iiii(1417,(0|0),($67|0),($61|0))|0);
                $207 = __THREW__; __THREW__ = 0;
                $208 = $207&1;
                if ($208) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $209 = __THREW__; __THREW__ = 0;
                $210 = $209&1;
                if ($210) {
                 break;
                }
                $211 = HEAP32[$48>>2]|0;
                $212 = ($211>>>0)<(2);
                if ($212) {
                 __THREW__ = 0;
                 $213 = (invoke_i(132)|0);
                 $214 = __THREW__; __THREW__ = 0;
                 $215 = $214&1;
                 if ($215) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($213|0));
                 $216 = __THREW__; __THREW__ = 0;
                 $217 = $216&1;
                 if ($217) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($206|0));
                $218 = __THREW__; __THREW__ = 0;
                $219 = $218&1;
                if ($219) {
                 break;
                }
                $220 = HEAP32[$43>>2]|0;
                $221 = (($220) + 92|0);
                $222 = HEAP32[$221>>2]|0;
                $223 = (($58) + ($222)|0);
                HEAP32[$223>>2] = $206;
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $224 = __THREW__; __THREW__ = 0;
                $225 = $224&1;
                if ($225) {
                 break;
                }
                $226 = HEAP32[$48>>2]|0;
                $227 = ($226>>>0)<(3);
                if ($227) {
                 __THREW__ = 0;
                 $228 = (invoke_i(132)|0);
                 $229 = __THREW__; __THREW__ = 0;
                 $230 = $229&1;
                 if ($230) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($228|0));
                 $231 = __THREW__; __THREW__ = 0;
                 $232 = $231&1;
                 if ($232) {
                  break;
                 }
                }
                $233 = HEAP32[2997968>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($233|0));
                $234 = __THREW__; __THREW__ = 0;
                $235 = $234&1;
                if ($235) {
                 break;
                }
                $236 = HEAP32[2997968>>2]|0;
                $237 = HEAP32[$43>>2]|0;
                $238 = (($237) + 92|0);
                $239 = HEAP32[$238>>2]|0;
                $240 = $239 << 1;
                $241 = (($58) + ($240)|0);
                HEAP32[$241>>2] = $236;
                $242 = (($__this) + 8|0);
                $243 = Math_fround(HEAPF32[$242>>2]);
                HEAPF32[$L_62>>2] = $243;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $244 = __THREW__; __THREW__ = 0;
                $245 = $244&1;
                if ($245) {
                 break;
                }
                __THREW__ = 0;
                $246 = (invoke_iii(2724,(2194912|0),($L_62|0))|0);
                $247 = __THREW__; __THREW__ = 0;
                $248 = $247&1;
                if ($248) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $249 = __THREW__; __THREW__ = 0;
                $250 = $249&1;
                if ($250) {
                 break;
                }
                $251 = HEAP32[$48>>2]|0;
                $252 = ($251>>>0)<(4);
                if ($252) {
                 __THREW__ = 0;
                 $253 = (invoke_i(132)|0);
                 $254 = __THREW__; __THREW__ = 0;
                 $255 = $254&1;
                 if ($255) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($253|0));
                 $256 = __THREW__; __THREW__ = 0;
                 $257 = $256&1;
                 if ($257) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($246|0));
                $258 = __THREW__; __THREW__ = 0;
                $259 = $258&1;
                if ($259) {
                 break;
                }
                $260 = HEAP32[$43>>2]|0;
                $261 = (($260) + 92|0);
                $262 = HEAP32[$261>>2]|0;
                $263 = ($262*3)|0;
                $264 = (($58) + ($263)|0);
                HEAP32[$264>>2] = $246;
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $265 = __THREW__; __THREW__ = 0;
                $266 = $265&1;
                if ($266) {
                 break;
                }
                $267 = HEAP32[$48>>2]|0;
                $268 = ($267>>>0)<(5);
                if ($268) {
                 __THREW__ = 0;
                 $269 = (invoke_i(132)|0);
                 $270 = __THREW__; __THREW__ = 0;
                 $271 = $270&1;
                 if ($271) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($269|0));
                 $272 = __THREW__; __THREW__ = 0;
                 $273 = $272&1;
                 if ($273) {
                  break;
                 }
                }
                $274 = HEAP32[2997976>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($274|0));
                $275 = __THREW__; __THREW__ = 0;
                $276 = $275&1;
                if ($276) {
                 break;
                }
                $277 = HEAP32[2997976>>2]|0;
                $278 = HEAP32[$43>>2]|0;
                $279 = (($278) + 92|0);
                $280 = HEAP32[$279>>2]|0;
                $281 = $280 << 2;
                $282 = (($58) + ($281)|0);
                HEAP32[$282>>2] = $277;
                $283 = (($__this) + 12|0);
                $284 = Math_fround(HEAPF32[$283>>2]);
                HEAPF32[$L_71>>2] = $284;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $285 = __THREW__; __THREW__ = 0;
                $286 = $285&1;
                if ($286) {
                 break;
                }
                __THREW__ = 0;
                $287 = (invoke_iii(2724,(2194912|0),($L_71|0))|0);
                $288 = __THREW__; __THREW__ = 0;
                $289 = $288&1;
                if ($289) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $290 = __THREW__; __THREW__ = 0;
                $291 = $290&1;
                if ($291) {
                 break;
                }
                $292 = HEAP32[$48>>2]|0;
                $293 = ($292>>>0)<(6);
                if ($293) {
                 __THREW__ = 0;
                 $294 = (invoke_i(132)|0);
                 $295 = __THREW__; __THREW__ = 0;
                 $296 = $295&1;
                 if ($296) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($294|0));
                 $297 = __THREW__; __THREW__ = 0;
                 $298 = $297&1;
                 if ($298) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($287|0));
                $299 = __THREW__; __THREW__ = 0;
                $300 = $299&1;
                if ($300) {
                 break;
                }
                $301 = HEAP32[$43>>2]|0;
                $302 = (($301) + 92|0);
                $303 = HEAP32[$302>>2]|0;
                $304 = ($303*5)|0;
                $305 = (($58) + ($304)|0);
                HEAP32[$305>>2] = $287;
                $306 = (($__this) + 40|0);
                $307 = HEAP32[$306>>2]|0;
                $308 = ($307|0)==(0);
                if ($308) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $309 = __THREW__; __THREW__ = 0;
                 $310 = $309&1;
                 if ($310) {
                  break;
                 }
                 $311 = HEAP8[((2191608 + 116|0))>>0]|0;
                 $312 = ($311<<24>>24)==(0);
                 if ($312) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2191608|0))|0);
                  $313 = __THREW__; __THREW__ = 0;
                  $314 = $313&1;
                  if ($314) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2191608|0))|0);
                  $315 = __THREW__; __THREW__ = 0;
                  $316 = $315&1;
                  if ($316) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3843,(2191608|0));
                  $317 = __THREW__; __THREW__ = 0;
                  $318 = $317&1;
                  if ($318) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $319 = __THREW__; __THREW__ = 0;
                 $320 = $319&1;
                 if ($320) {
                  break;
                 }
                 $321 = HEAP32[((2191608 + 80|0))>>2]|0;
                 $G_B9_0$0$in = $321;
                } else {
                 $G_B9_0$0$in = 2997984;
                }
                $G_B9_0$0 = HEAP32[$G_B9_0$0$in>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $322 = __THREW__; __THREW__ = 0;
                $323 = $322&1;
                if ($323) {
                 break;
                }
                $324 = HEAP32[$48>>2]|0;
                $325 = ($324>>>0)<(7);
                if ($325) {
                 __THREW__ = 0;
                 $326 = (invoke_i(132)|0);
                 $327 = __THREW__; __THREW__ = 0;
                 $328 = $327&1;
                 if ($328) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($326|0));
                 $329 = __THREW__; __THREW__ = 0;
                 $330 = $329&1;
                 if ($330) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($G_B9_0$0|0));
                $331 = __THREW__; __THREW__ = 0;
                $332 = $331&1;
                if ($332) {
                 break;
                }
                $333 = HEAP32[$43>>2]|0;
                $334 = (($333) + 92|0);
                $335 = HEAP32[$334>>2]|0;
                $336 = ($335*6)|0;
                $337 = (($58) + ($336)|0);
                HEAP32[$337>>2] = $G_B9_0$0;
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $338 = __THREW__; __THREW__ = 0;
                $339 = $338&1;
                if ($339) {
                 break;
                }
                $340 = HEAP32[$48>>2]|0;
                $341 = ($340>>>0)<(8);
                if ($341) {
                 __THREW__ = 0;
                 $342 = (invoke_i(132)|0);
                 $343 = __THREW__; __THREW__ = 0;
                 $344 = $343&1;
                 if ($344) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($342|0));
                 $345 = __THREW__; __THREW__ = 0;
                 $346 = $345&1;
                 if ($346) {
                  break;
                 }
                }
                $347 = HEAP32[2997992>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($347|0));
                $348 = __THREW__; __THREW__ = 0;
                $349 = $348&1;
                if ($349) {
                 break;
                }
                $350 = HEAP32[2997992>>2]|0;
                $351 = HEAP32[$43>>2]|0;
                $352 = (($351) + 92|0);
                $353 = HEAP32[$352>>2]|0;
                $354 = ($353*7)|0;
                $355 = (($58) + ($354)|0);
                HEAP32[$355>>2] = $350;
                $356 = (($__this) + 16|0);
                $357 = Math_fround(HEAPF32[$356>>2]);
                HEAPF32[$L_85>>2] = $357;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $358 = __THREW__; __THREW__ = 0;
                $359 = $358&1;
                if ($359) {
                 break;
                }
                __THREW__ = 0;
                $360 = (invoke_iii(2724,(2194912|0),($L_85|0))|0);
                $361 = __THREW__; __THREW__ = 0;
                $362 = $361&1;
                if ($362) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $363 = __THREW__; __THREW__ = 0;
                $364 = $363&1;
                if ($364) {
                 break;
                }
                $365 = HEAP32[$48>>2]|0;
                $366 = ($365>>>0)<(9);
                if ($366) {
                 __THREW__ = 0;
                 $367 = (invoke_i(132)|0);
                 $368 = __THREW__; __THREW__ = 0;
                 $369 = $368&1;
                 if ($369) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($367|0));
                 $370 = __THREW__; __THREW__ = 0;
                 $371 = $370&1;
                 if ($371) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($360|0));
                $372 = __THREW__; __THREW__ = 0;
                $373 = $372&1;
                if ($373) {
                 break;
                }
                $374 = HEAP32[$43>>2]|0;
                $375 = (($374) + 92|0);
                $376 = HEAP32[$375>>2]|0;
                $377 = $376 << 3;
                $378 = (($58) + ($377)|0);
                HEAP32[$378>>2] = $360;
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $379 = __THREW__; __THREW__ = 0;
                $380 = $379&1;
                if ($380) {
                 break;
                }
                $381 = HEAP32[$48>>2]|0;
                $382 = ($381>>>0)<(10);
                if ($382) {
                 __THREW__ = 0;
                 $383 = (invoke_i(132)|0);
                 $384 = __THREW__; __THREW__ = 0;
                 $385 = $384&1;
                 if ($385) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($383|0));
                 $386 = __THREW__; __THREW__ = 0;
                 $387 = $386&1;
                 if ($387) {
                  break;
                 }
                }
                $388 = HEAP32[2998000>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($388|0));
                $389 = __THREW__; __THREW__ = 0;
                $390 = $389&1;
                if ($390) {
                 break;
                }
                $391 = HEAP32[2998000>>2]|0;
                $392 = HEAP32[$43>>2]|0;
                $393 = (($392) + 92|0);
                $394 = HEAP32[$393>>2]|0;
                $395 = ($394*9)|0;
                $396 = (($58) + ($395)|0);
                HEAP32[$396>>2] = $391;
                $397 = (($__this) + 20|0);
                $398 = Math_fround(HEAPF32[$397>>2]);
                HEAPF32[$L_94>>2] = $398;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $399 = __THREW__; __THREW__ = 0;
                $400 = $399&1;
                if ($400) {
                 break;
                }
                __THREW__ = 0;
                $401 = (invoke_iii(2724,(2194912|0),($L_94|0))|0);
                $402 = __THREW__; __THREW__ = 0;
                $403 = $402&1;
                if ($403) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $404 = __THREW__; __THREW__ = 0;
                $405 = $404&1;
                if ($405) {
                 break;
                }
                $406 = HEAP32[$48>>2]|0;
                $407 = ($406>>>0)<(11);
                if ($407) {
                 __THREW__ = 0;
                 $408 = (invoke_i(132)|0);
                 $409 = __THREW__; __THREW__ = 0;
                 $410 = $409&1;
                 if ($410) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($408|0));
                 $411 = __THREW__; __THREW__ = 0;
                 $412 = $411&1;
                 if ($412) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($401|0));
                $413 = __THREW__; __THREW__ = 0;
                $414 = $413&1;
                if ($414) {
                 break;
                }
                $415 = HEAP32[$43>>2]|0;
                $416 = (($415) + 92|0);
                $417 = HEAP32[$416>>2]|0;
                $418 = ($417*10)|0;
                $419 = (($58) + ($418)|0);
                HEAP32[$419>>2] = $401;
                $420 = (($__this) + 44|0);
                $421 = HEAP32[$420>>2]|0;
                $422 = ($421|0)==(0);
                if ($422) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $423 = __THREW__; __THREW__ = 0;
                 $424 = $423&1;
                 if ($424) {
                  break;
                 }
                 $425 = HEAP8[((2191608 + 116|0))>>0]|0;
                 $426 = ($425<<24>>24)==(0);
                 if ($426) {
                  __THREW__ = 0;
                  (invoke_ii(2996,(2191608|0))|0);
                  $427 = __THREW__; __THREW__ = 0;
                  $428 = $427&1;
                  if ($428) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_ii(2996,(2191608|0))|0);
                  $429 = __THREW__; __THREW__ = 0;
                  $430 = $429&1;
                  if ($430) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3843,(2191608|0));
                  $431 = __THREW__; __THREW__ = 0;
                  $432 = $431&1;
                  if ($432) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2191608|0))|0);
                 $433 = __THREW__; __THREW__ = 0;
                 $434 = $433&1;
                 if ($434) {
                  break;
                 }
                 $435 = HEAP32[((2191608 + 80|0))>>2]|0;
                 $G_B12_0$0$in = $435;
                } else {
                 $G_B12_0$0$in = 2998008;
                }
                $G_B12_0$0 = HEAP32[$G_B12_0$0$in>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($43|0));
                $436 = __THREW__; __THREW__ = 0;
                $437 = $436&1;
                if ($437) {
                 break;
                }
                $438 = HEAP32[$48>>2]|0;
                $439 = ($438>>>0)<(12);
                if ($439) {
                 __THREW__ = 0;
                 $440 = (invoke_i(132)|0);
                 $441 = __THREW__; __THREW__ = 0;
                 $442 = $441&1;
                 if ($442) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($440|0));
                 $443 = __THREW__; __THREW__ = 0;
                 $444 = $443&1;
                 if ($444) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($43|0),($G_B12_0$0|0));
                $445 = __THREW__; __THREW__ = 0;
                $446 = $445&1;
                if ($446) {
                 break;
                }
                $447 = HEAP32[$43>>2]|0;
                $448 = (($447) + 92|0);
                $449 = HEAP32[$448>>2]|0;
                $450 = ($449*11)|0;
                $451 = (($58) + ($450)|0);
                HEAP32[$451>>2] = $G_B12_0$0;
                __THREW__ = 0;
                $452 = (invoke_iii(638,(0|0),($43|0))|0);
                $453 = __THREW__; __THREW__ = 0;
                $454 = $453&1;
                if ($454) {
                 break;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($452|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_GUIStyle_m_get_nameP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747168);
 $0 = HEAP32[2747216>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747224|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747216>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __ZN14ActionInvoker5I28mscorlib_System_SingleTraitsS0_S0_S0_17VoidPointerTraitsE6InvokeEPFvPvffffS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 FUNCTION_TABLE_viffffi[$action & 3]($obj,$1,$4,$7,$10,$12);
 STACKTOP = sp;return (0|0);
}
function __Z63UnityEngine_UnityEngine_RectOffset_m__ctor_mscorlib_System_VoidP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744104);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(2993,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z51UnityEngine_UnityEngine_GUILayoutGroup_m_get_marginP38UnityEngine_UnityEngine_GUILayoutGroup($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2730064);
 $0 = (($__this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z53UnityEngine_UnityEngine_GUILayoutGroup_m_ApplyOptionsP38UnityEngine_UnityEngine_GUILayoutGroupP43UnityEngine_UnityEngine_GUILayoutOption_arr($__this,$options) {
 $__this = $__this|0;
 $options = $options|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = Math_fround(0), $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_2$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $or$cond11 = 0;
 var $or$cond13 = 0, $or$cond15 = 0, $or$cond15$not = 0, $or$cond17 = 0, $or$cond7 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726752);
 $0 = ($options|0)==(0|0);
 if ($0) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vii(2028,($__this|0),($options|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  $lpad$phi$index = $10;$lpad$phi$index2 = $11;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $3 = (($options) + 12|0);
 $4 = (($options) + 16|0);
 $5 = (($__this) + 60|0);
 $6 = (($__this) + 85|0);
 $7 = (($__this) + 84|0);
 $V_2$0 = 0;
 L8: while(1) {
  __THREW__ = 0;
  invoke_vi(3799,($options|0));
  $49 = __THREW__; __THREW__ = 0;
  $50 = $49&1;
  if ($50) {
   break;
  }
  $51 = HEAP32[$3>>2]|0;
  $52 = ($V_2$0|0)<($51|0);
  if (!($52)) {
   label = 24;
   break;
  }
  __THREW__ = 0;
  invoke_vi(3799,($options|0));
  $53 = __THREW__; __THREW__ = 0;
  $54 = $53&1;
  if ($54) {
   break;
  }
  $12 = HEAP32[$3>>2]|0;
  $13 = ($V_2$0>>>0)<($12>>>0);
  if (!($13)) {
   __THREW__ = 0;
   $14 = (invoke_i(132)|0);
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($14|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    break;
   }
  }
  $19 = HEAP32[$options>>2]|0;
  $20 = (($19) + 92|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = Math_imul($21, $V_2$0)|0;
  $23 = (($4) + ($22)|0);
  $24 = HEAP32[$23>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($24|0));
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   break;
  }
  $27 = (($24) + 8|0);
  $28 = HEAP32[$27>>2]|0;
  do {
   if ((($28|0) == 1)) {
    label = 15;
   } else if ((($28|0) == 0)) {
    label = 14;
   } else {
    $29 = $28 & -2;
    if ((($29|0) == 4)) {
     label = 15;
     break;
    } else if ((($29|0) == 2)) {
     label = 14;
     break;
    }
    $30 = ($29|0)==(6);
    $31 = ($28|0)==(8);
    $or$cond7 = $30 | $31;
    $32 = ($28|0)==(9);
    $or$cond9 = $or$cond7 | $32;
    $33 = ($28|0)==(10);
    $or$cond11 = $or$cond9 | $33;
    $34 = ($28|0)==(11);
    $or$cond13 = $or$cond11 | $34;
    $35 = ($28|0)==(12);
    $or$cond15 = $or$cond13 | $35;
    $or$cond15$not = $or$cond15 ^ 1;
    $36 = ($28|0)==(13);
    $or$cond17 = $36 & $or$cond15$not;
    if ($or$cond17) {
     __THREW__ = 0;
     invoke_vi(3799,($24|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      break L8;
     }
     $39 = (($24) + 12|0);
     $40 = HEAP32[$39>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2155952|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break L8;
     }
     __THREW__ = 0;
     $43 = (invoke_iii(2775,($40|0),(2155952|0))|0);
     $44 = __THREW__; __THREW__ = 0;
     $45 = $44&1;
     if ($45) {
      break L8;
     }
     $46 = HEAP32[$43>>2]|0;
     $47 = (Math_fround(($46|0)));
     HEAPF32[$5>>2] = $47;
    }
   }
  } while(0);
  if ((label|0) == 14) {
   label = 0;
   HEAP8[$6>>0] = 1;
  }
  else if ((label|0) == 15) {
   label = 0;
   HEAP8[$7>>0] = 1;
  }
  $48 = (($V_2$0) + 1)|0;
  $V_2$0 = $48;
 }
 if ((label|0) == 24) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z59UnityEngine_UnityEngine_GUILayoutGroup_m_ApplyStyleSettingsP38UnityEngine_UnityEngine_GUILayoutGroupP32UnityEngine_UnityEngine_GUIStyle($__this,$style) {
 $__this = $__this|0;
 $style = $style|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2730112);
 __THREW__ = 0;
 invoke_vii(2027,($__this|0),($style|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3799,($style|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(2592,($style|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 104|0);
    $8 = HEAP32[$7>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($4|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     $11 = (invoke_ii(2583,($4|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       __THREW__ = 0;
       invoke_vii(2057,($8|0),($11|0));
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        $18 = HEAP32[$7>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if (!($20)) {
         __THREW__ = 0;
         $21 = (invoke_ii(2584,($4|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          __THREW__ = 0;
          invoke_vi(3799,($18|0));
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           __THREW__ = 0;
           invoke_vii(2058,($18|0),($21|0));
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            $28 = HEAP32[$7>>2]|0;
            __THREW__ = 0;
            invoke_vi(3799,($4|0));
            $29 = __THREW__; __THREW__ = 0;
            $30 = $29&1;
            if (!($30)) {
             __THREW__ = 0;
             $31 = (invoke_ii(2585,($4|0))|0);
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if (!($33)) {
              __THREW__ = 0;
              invoke_vi(3799,($28|0));
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               __THREW__ = 0;
               invoke_vii(2059,($28|0),($31|0));
               $36 = __THREW__; __THREW__ = 0;
               $37 = $36&1;
               if (!($37)) {
                $38 = HEAP32[$7>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($4|0));
                $39 = __THREW__; __THREW__ = 0;
                $40 = $39&1;
                if (!($40)) {
                 __THREW__ = 0;
                 $41 = (invoke_ii(2586,($4|0))|0);
                 $42 = __THREW__; __THREW__ = 0;
                 $43 = $42&1;
                 if (!($43)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($38|0));
                  $44 = __THREW__; __THREW__ = 0;
                  $45 = $44&1;
                  if (!($45)) {
                   __THREW__ = 0;
                   invoke_vii(2060,($38|0),($41|0));
                   $46 = __THREW__; __THREW__ = 0;
                   $47 = $46&1;
                   if (!($47)) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $48 = ___cxa_find_matching_catch()|0;
 $49 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($48|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_RectOffset_m_get_leftP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744480);
 $0 = HEAP32[2744528>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2744536|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2744528>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_RectOffset_m_set_leftP34UnityEngine_UnityEngine_RectOffseti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744576);
 $0 = HEAP32[2744624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2744632|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2744624>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z46UnityEngine_UnityEngine_RectOffset_m_get_rightP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744680);
 $0 = HEAP32[2744728>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2744736|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2744728>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_RectOffset_m_set_rightP34UnityEngine_UnityEngine_RectOffseti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744776);
 $0 = HEAP32[2744824>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2744832|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2744824>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z44UnityEngine_UnityEngine_RectOffset_m_get_topP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744880);
 $0 = HEAP32[2744928>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2744936|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2744928>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z44UnityEngine_UnityEngine_RectOffset_m_set_topP34UnityEngine_UnityEngine_RectOffseti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744976);
 $0 = HEAP32[2745024>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2745032|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2745024>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z47UnityEngine_UnityEngine_RectOffset_m_get_bottomP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2745080);
 $0 = HEAP32[2745128>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2745136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2745128>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z47UnityEngine_UnityEngine_RectOffset_m_set_bottomP34UnityEngine_UnityEngine_RectOffseti($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2745176);
 $0 = HEAP32[2745224>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2745232|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2745224>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z50UnityEngine_UnityEngine_GUILayoutGroup_m_CalcWidthP38UnityEngine_UnityEngine_GUILayoutGroup($__this) {
 $__this = $__this|0;
 var $$ = 0, $$0 = 0, $$04 = 0, $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = Math_fround(0), $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = Math_fround(0), $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0), $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = Math_fround(0);
 var $149 = 0, $15 = 0, $150 = Math_fround(0), $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = 0, $155 = 0, $156 = Math_fround(0), $157 = 0, $158 = 0, $159 = Math_fround(0), $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = Math_fround(0), $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = Math_fround(0), $214 = 0, $215 = 0, $216 = Math_fround(0), $217 = Math_fround(0), $218 = Math_fround(0), $219 = 0, $22 = 0;
 var $220 = 0, $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = Math_fround(0), $226 = Math_fround(0), $227 = 0, $228 = 0, $229 = Math_fround(0), $23 = Math_fround(0), $230 = Math_fround(0), $231 = Math_fround(0), $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = Math_fround(0), $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = Math_fround(0), $254 = 0, $255 = 0, $256 = Math_fround(0);
 var $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = Math_fround(0), $264 = 0, $265 = 0, $266 = Math_fround(0), $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = Math_fround(0), $296 = Math_fround(0), $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = Math_fround(0), $303 = Math_fround(0), $304 = 0, $305 = 0, $306 = Math_fround(0), $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = Math_fround(0), $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = Math_fround(0), $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0;
 var $383 = 0, $384 = 0, $385 = 0, $386 = Math_fround(0), $387 = Math_fround(0), $388 = Math_fround(0), $389 = Math_fround(0), $39 = 0, $390 = Math_fround(0), $391 = 0, $392 = 0, $393 = 0, $394 = Math_fround(0), $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = Math_fround(0), $414 = Math_fround(0), $415 = Math_fround(0), $416 = 0, $417 = Math_fround(0), $418 = Math_fround(0);
 var $419 = Math_fround(0), $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = Math_fround(0);
 var $437 = 0, $438 = 0, $439 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = Math_fround(0), $L_111 = 0, $L_16 = 0, $L_46 = 0, $L_62 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$2 = 0, $V_0$3 = 0, $V_0$4 = 0, $V_0$5 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_1$2 = 0, $V_1$3 = 0, $V_1$4 = 0, $V_1$5 = 0;
 var $V_10$0 = 0, $V_11$0 = Math_fround(0), $V_12$0 = Math_fround(0), $V_2$1$off0 = 0, $V_2$2$off0 = 0, $V_2$4$off0$ph = 0, $V_4 = 0, $V_6$0 = 0, $V_6$0$ph = 0, $V_6$1$ph = 0, $V_6$2 = 0, $V_8 = 0, $__last_unhandled_exception$0 = 0, $__last_unhandled_exception$1 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond3 = 0, $leaveInstructions$sroa$0$0 = 0, $leaveInstructions$sroa$0$1 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $_stackTraceSentry = sp + 96|0;
 $V_4 = sp;
 $V_8 = sp + 16|0;
 $L_16 = sp + 32|0;
 $L_46 = sp + 48|0;
 $L_62 = sp + 64|0;
 $L_111 = sp + 80|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726848);
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;HEAP32[$V_4+12>>2]=0|0;
 ;HEAP32[$V_8+0>>2]=0|0;HEAP32[$V_8+4>>2]=0|0;HEAP32[$V_8+8>>2]=0|0;HEAP32[$V_8+12>>2]=0|0;
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2729,(1905272|0),($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0);
    if ($7) {
     __THREW__ = 0;
     $10 = (invoke_ii(2550,($__this|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_ii(2593,($10|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($15|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(2587,($15|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     $23 = (Math_fround(($20|0)));
     $24 = (($__this) + 8|0);
     HEAPF32[$24>>2] = $23;
     $25 = (($__this) + 12|0);
     HEAPF32[$25>>2] = $23;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $26 = (($__this) + 88|0);
    HEAPF32[$26>>2] = Math_fround(0.0);
    $27 = (($__this) + 92|0);
    HEAPF32[$27>>2] = Math_fround(0.0);
    $28 = (($__this) + 76|0);
    HEAP32[$28>>2] = 0;
    $29 = (($__this) + 56|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = ($30<<24>>24)==(0);
    $32 = HEAP32[$0>>2]|0;
    if ($31) {
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $160 = __THREW__; __THREW__ = 0;
     $161 = $160&1;
     if ($161) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1633,($L_62|0),($32|0));
     $162 = __THREW__; __THREW__ = 0;
     $163 = $162&1;
     if ($163) {
      break;
     }
     ;HEAP32[$V_8+0>>2]=HEAP32[$L_62+0>>2]|0;HEAP32[$V_8+4>>2]=HEAP32[$L_62+4>>2]|0;HEAP32[$V_8+8>>2]=HEAP32[$L_62+8>>2]|0;HEAP32[$V_8+12>>2]=HEAP32[$L_62+12>>2]|0;
     $164 = (($__this) + 60|0);
     $V_2$4$off0$ph = 1;$V_6$1$ph = 0;
     L77: while(1) {
      while(1) {
       __THREW__ = 0;
       $277 = (invoke_ii(3478,($V_8|0))|0);
       $278 = __THREW__; __THREW__ = 0;
       $279 = $278&1;
       if ($279) {
        label = 77;
        break L77;
       }
       if (!($277)) {
        $V_6$2 = $V_6$1$ph;$__last_unhandled_exception$1 = 0;$leaveInstructions$sroa$0$1 = 657;
        break L77;
       }
       __THREW__ = 0;
       $165 = (invoke_ii(3468,($V_8|0))|0);
       $280 = __THREW__; __THREW__ = 0;
       $281 = $280&1;
       if ($281) {
        label = 77;
        break L77;
       }
       __THREW__ = 0;
       invoke_vi(3799,($165|0));
       $166 = __THREW__; __THREW__ = 0;
       $167 = $166&1;
       if ($167) {
        label = 77;
        break L77;
       }
       __THREW__ = 0;
       invoke_vii(3495,(2728736|0),($165|0));
       $168 = __THREW__; __THREW__ = 0;
       $169 = $168&1;
       if ($169) {
        label = 77;
        break L77;
       }
       __THREW__ = 0;
       invoke_vi(3799,($165|0));
       $170 = __THREW__; __THREW__ = 0;
       $171 = $170&1;
       if ($171) {
        label = 77;
        break L77;
       }
       __THREW__ = 0;
       $172 = (invoke_iii(2730,(2728688|0),($165|0))|0);
       $173 = __THREW__; __THREW__ = 0;
       $174 = $173&1;
       if ($174) {
        label = 77;
        break L77;
       }
       __THREW__ = 0;
       invoke_vi(3799,($165|0));
       $175 = __THREW__; __THREW__ = 0;
       $176 = $175&1;
       if ($176) {
        label = 77;
        break L77;
       }
       __THREW__ = 0;
       $177 = (invoke_ii(2550,($165|0))|0);
       $178 = __THREW__; __THREW__ = 0;
       $179 = $178&1;
       if ($179) {
        label = 77;
        break L77;
       }
       __THREW__ = 0;
       $180 = (invoke_ii(2549,0)|0);
       $181 = __THREW__; __THREW__ = 0;
       $182 = $181&1;
       if ($182) {
        label = 77;
        break L77;
       }
       $183 = ($177|0)==($180|0);
       if (!($183)) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $247 = __THREW__; __THREW__ = 0;
       $248 = $247&1;
       if ($248) {
        label = 77;
        break L77;
       }
       $249 = Math_fround(HEAPF32[$26>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($165|0));
       $250 = __THREW__; __THREW__ = 0;
       $251 = $250&1;
       if ($251) {
        label = 77;
        break L77;
       }
       $252 = (($165) + 8|0);
       $253 = Math_fround(HEAPF32[$252>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $254 = __THREW__; __THREW__ = 0;
       $255 = $254&1;
       if ($255) {
        label = 77;
        break L77;
       }
       $256 = Math_fround($249 + $253);
       HEAPF32[$26>>2] = $256;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $257 = __THREW__; __THREW__ = 0;
       $258 = $257&1;
       if ($258) {
        label = 77;
        break L77;
       }
       $259 = Math_fround(HEAPF32[$27>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($165|0));
       $260 = __THREW__; __THREW__ = 0;
       $261 = $260&1;
       if ($261) {
        label = 77;
        break L77;
       }
       $262 = (($165) + 12|0);
       $263 = Math_fround(HEAPF32[$262>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $264 = __THREW__; __THREW__ = 0;
       $265 = $264&1;
       if ($265) {
        label = 77;
        break L77;
       }
       $266 = Math_fround($259 + $263);
       HEAPF32[$27>>2] = $266;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $267 = __THREW__; __THREW__ = 0;
       $268 = $267&1;
       if ($268) {
        label = 77;
        break L77;
       }
       $269 = HEAP32[$28>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($165|0));
       $270 = __THREW__; __THREW__ = 0;
       $271 = $270&1;
       if ($271) {
        label = 77;
        break L77;
       }
       $272 = (($165) + 40|0);
       $273 = HEAP32[$272>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $274 = __THREW__; __THREW__ = 0;
       $275 = $274&1;
       if ($275) {
        label = 77;
        break L77;
       }
       $276 = (($273) + ($269))|0;
       HEAP32[$28>>2] = $276;
      }
      if ($V_2$4$off0$ph) {
       $V_10$0 = 0;
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($172|0));
       $194 = __THREW__; __THREW__ = 0;
       $195 = $194&1;
       if ($195) {
        $V_6$0$ph = $V_6$1$ph;
        label = 78;
        break;
       }
       __THREW__ = 0;
       $196 = (invoke_ii(2583,($172|0))|0);
       $197 = __THREW__; __THREW__ = 0;
       $198 = $197&1;
       if ($198) {
        $V_6$0$ph = $V_6$1$ph;
        label = 78;
        break;
       }
       $199 = ($V_6$1$ph|0)>($196|0);
       if ($199) {
        $V_10$0 = $V_6$1$ph;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($172|0));
        $200 = __THREW__; __THREW__ = 0;
        $201 = $200&1;
        if ($201) {
         $V_6$0$ph = $V_6$1$ph;
         label = 78;
         break;
        }
        __THREW__ = 0;
        $202 = (invoke_ii(2583,($172|0))|0);
        $203 = __THREW__; __THREW__ = 0;
        $204 = $203&1;
        if ($204) {
         $V_6$0$ph = $V_6$1$ph;
         label = 78;
         break;
        } else {
         $V_10$0 = $202;
        }
       }
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $205 = __THREW__; __THREW__ = 0;
      $206 = $205&1;
      if ($206) {
       $V_6$0$ph = $V_6$1$ph;
       label = 78;
       break;
      }
      $207 = Math_fround(HEAPF32[$26>>2]);
      __THREW__ = 0;
      invoke_vi(3799,($165|0));
      $208 = __THREW__; __THREW__ = 0;
      $209 = $208&1;
      if ($209) {
       $V_6$0$ph = $V_6$1$ph;
       label = 78;
       break;
      }
      $210 = (($165) + 8|0);
      $211 = Math_fround(HEAPF32[$210>>2]);
      $212 = Math_fround(HEAPF32[$164>>2]);
      $213 = (Math_fround(($V_10$0|0)));
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $214 = __THREW__; __THREW__ = 0;
      $215 = $214&1;
      if ($215) {
       $V_6$0$ph = $V_6$1$ph;
       label = 78;
       break;
      }
      $216 = Math_fround($211 + $212);
      $217 = Math_fround($213 + $216);
      $218 = Math_fround($207 + $217);
      HEAPF32[$26>>2] = $218;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $219 = __THREW__; __THREW__ = 0;
      $220 = $219&1;
      if ($220) {
       $V_6$0$ph = $V_6$1$ph;
       label = 78;
       break;
      }
      $221 = Math_fround(HEAPF32[$27>>2]);
      __THREW__ = 0;
      invoke_vi(3799,($165|0));
      $222 = __THREW__; __THREW__ = 0;
      $223 = $222&1;
      if ($223) {
       $V_6$0$ph = $V_6$1$ph;
       label = 78;
       break;
      }
      $224 = (($165) + 12|0);
      $225 = Math_fround(HEAPF32[$224>>2]);
      $226 = Math_fround(HEAPF32[$164>>2]);
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $227 = __THREW__; __THREW__ = 0;
      $228 = $227&1;
      if ($228) {
       $V_6$0$ph = $V_6$1$ph;
       label = 78;
       break;
      }
      $229 = Math_fround($225 + $226);
      $230 = Math_fround($213 + $229);
      $231 = Math_fround($221 + $230);
      HEAPF32[$27>>2] = $231;
      __THREW__ = 0;
      invoke_vi(3799,($172|0));
      $232 = __THREW__; __THREW__ = 0;
      $233 = $232&1;
      if ($233) {
       $V_6$0$ph = $V_6$1$ph;
       label = 78;
       break;
      }
      __THREW__ = 0;
      $234 = (invoke_ii(2584,($172|0))|0);
      $235 = __THREW__; __THREW__ = 0;
      $236 = $235&1;
      if ($236) {
       $V_6$0$ph = $V_6$1$ph;
       label = 78;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $237 = __THREW__; __THREW__ = 0;
      $238 = $237&1;
      if ($238) {
       $V_6$0$ph = $234;
       label = 78;
       break;
      }
      $239 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($165|0));
      $240 = __THREW__; __THREW__ = 0;
      $241 = $240&1;
      if ($241) {
       $V_6$0$ph = $234;
       label = 78;
       break;
      }
      $242 = (($165) + 40|0);
      $243 = HEAP32[$242>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $244 = __THREW__; __THREW__ = 0;
      $245 = $244&1;
      if ($245) {
       $V_6$0$ph = $234;
       label = 78;
       break;
      }
      $246 = (($243) + ($239))|0;
      HEAP32[$28>>2] = $246;
      $V_2$4$off0$ph = 0;$V_6$1$ph = $234;
     }
     if ((label|0) == 77) {
      $184 = ___cxa_find_matching_catch(348288|0)|0;
      $185 = tempRet0;
      $V_6$0 = $V_6$1$ph;$lpad$phi$index = $184;$lpad$phi$index2 = $185;
      label = 79;
     }
     else if ((label|0) == 78) {
      $186 = ___cxa_find_matching_catch(348288|0)|0;
      $187 = tempRet0;
      $V_6$0 = $V_6$0$ph;$lpad$phi$index = $186;$lpad$phi$index2 = $187;
      label = 79;
     }
     if ((label|0) == 79) {
      $188 = (_llvm_eh_typeid_for((348288|0))|0);
      $189 = ($lpad$phi$index2|0)==($188|0);
      if (!($189)) {
       $$0 = $lpad$phi$index;$$04 = $lpad$phi$index2;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$0|0);
       // unreachable;
      }
      $190 = (___cxa_begin_catch(($lpad$phi$index|0))|0);
      $191 = HEAP32[$190>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if ($193) {
       break;
      }
      $V_6$2 = $V_6$0;$__last_unhandled_exception$1 = $191;$leaveInstructions$sroa$0$1 = 0;
     }
     ;HEAP32[$L_111+0>>2]=HEAP32[$V_8+0>>2]|0;HEAP32[$L_111+4>>2]=HEAP32[$V_8+4>>2]|0;HEAP32[$L_111+8>>2]=HEAP32[$V_8+8>>2]|0;HEAP32[$L_111+12>>2]=HEAP32[$V_8+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1902144|0))|0);
     $282 = __THREW__; __THREW__ = 0;
     $283 = $282&1;
     if ($283) {
      break;
     }
     __THREW__ = 0;
     $284 = (invoke_iii(2724,(1902144|0),($L_111|0))|0);
     $285 = __THREW__; __THREW__ = 0;
     $286 = $285&1;
     if ($286) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($284|0));
     $287 = __THREW__; __THREW__ = 0;
     $288 = $287&1;
     if ($288) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(3491,(2176768|0),($284|0));
     $289 = __THREW__; __THREW__ = 0;
     $290 = $289&1;
     if ($290) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$1|0)==(657);
     if (!($cond1)) {
      __THREW__ = 0;
      invoke_vi(3844,($__last_unhandled_exception$1|0));
      $291 = __THREW__; __THREW__ = 0;
      $292 = $291&1;
      if ($292) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $293 = __THREW__; __THREW__ = 0;
     $294 = $293&1;
     if ($294) {
      break;
     }
     $295 = Math_fround(HEAPF32[$26>>2]);
     $296 = Math_fround(HEAPF32[$164>>2]);
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $297 = __THREW__; __THREW__ = 0;
     $298 = $297&1;
     if ($298) {
      break;
     }
     $299 = Math_fround($295 - $296);
     HEAPF32[$26>>2] = $299;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $300 = __THREW__; __THREW__ = 0;
     $301 = $300&1;
     if ($301) {
      break;
     }
     $302 = Math_fround(HEAPF32[$27>>2]);
     $303 = Math_fround(HEAPF32[$164>>2]);
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $304 = __THREW__; __THREW__ = 0;
     $305 = $304&1;
     if ($305) {
      break;
     }
     $306 = Math_fround($302 - $303);
     HEAPF32[$27>>2] = $306;
     $307 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($307|0));
     $308 = __THREW__; __THREW__ = 0;
     $309 = $308&1;
     if ($309) {
      break;
     }
     __THREW__ = 0;
     $310 = (invoke_iii(2729,(1905272|0),($307|0))|0);
     $311 = __THREW__; __THREW__ = 0;
     $312 = $311&1;
     if ($312) {
      break;
     }
     $313 = ($310|0)==(0);
     if ($313) {
      $V_0$5 = 0;$V_1$5 = 0;
     } else {
      $314 = HEAP32[$0>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($314|0));
      $315 = __THREW__; __THREW__ = 0;
      $316 = $315&1;
      if ($316) {
       break;
      }
      __THREW__ = 0;
      $317 = (invoke_iiii(1642,(1905336|0),($314|0),0)|0);
      $318 = __THREW__; __THREW__ = 0;
      $319 = $318&1;
      if ($319) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($317|0));
      $320 = __THREW__; __THREW__ = 0;
      $321 = $320&1;
      if ($321) {
       break;
      }
      __THREW__ = 0;
      $322 = (invoke_iii(2730,(2728688|0),($317|0))|0);
      $323 = __THREW__; __THREW__ = 0;
      $324 = $323&1;
      if ($324) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($322|0));
      $325 = __THREW__; __THREW__ = 0;
      $326 = $325&1;
      if ($326) {
       break;
      }
      __THREW__ = 0;
      $327 = (invoke_ii(2583,($322|0))|0);
      $328 = __THREW__; __THREW__ = 0;
      $329 = $328&1;
      if ($329) {
       break;
      } else {
       $V_0$5 = $327;$V_1$5 = $V_6$2;
      }
     }
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1633,($L_16|0),($32|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     ;HEAP32[$V_4+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_16+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[$L_16+12>>2]|0;
     $V_0$3 = 0;$V_1$3 = 0;$V_2$2$off0 = 1;
     while(1) {
      __THREW__ = 0;
      $130 = (invoke_ii(3478,($V_4|0))|0);
      $131 = __THREW__; __THREW__ = 0;
      $132 = $131&1;
      if ($132) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      if (!($130)) {
       $V_0$4 = $V_0$3;$V_1$4 = $V_1$3;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 323;
       break;
      }
      __THREW__ = 0;
      $37 = (invoke_ii(3468,($V_4|0))|0);
      $133 = __THREW__; __THREW__ = 0;
      $134 = $133&1;
      if ($134) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      __THREW__ = 0;
      invoke_vii(3495,(2728736|0),($37|0));
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      __THREW__ = 0;
      $44 = (invoke_iii(2730,(2728688|0),($37|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      __THREW__ = 0;
      $49 = (invoke_ii(2550,($37|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      __THREW__ = 0;
      $52 = (invoke_ii(2549,0)|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 23;
       break;
      }
      $55 = ($49|0)==($52|0);
      if ($55) {
       $V_0$2 = $V_0$3;$V_1$2 = $V_1$3;$V_2$1$off0 = $V_2$2$off0;
      } else {
       if ($V_2$2$off0) {
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 23;
         break;
        }
        __THREW__ = 0;
        $82 = (invoke_ii(2583,($44|0))|0);
        $83 = __THREW__; __THREW__ = 0;
        $84 = $83&1;
        if ($84) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 23;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         $V_0$0 = $82;$V_1$0 = $V_1$3;
         label = 23;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_ii(2584,($44|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         $V_0$0 = $82;$V_1$0 = $V_1$3;
         label = 23;
         break;
        } else {
         $V_0$1 = $82;$V_1$1 = $87;
        }
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 23;
         break;
        }
        __THREW__ = 0;
        $66 = (invoke_ii(2583,($44|0))|0);
        $67 = __THREW__; __THREW__ = 0;
        $68 = $67&1;
        if ($68) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 23;
         break;
        }
        __THREW__ = 0;
        $69 = (invoke_iiii(1406,(0|0),($66|0),($V_0$3|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 23;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($44|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         $V_0$0 = $69;$V_1$0 = $V_1$3;
         label = 23;
         break;
        }
        __THREW__ = 0;
        $74 = (invoke_ii(2584,($44|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         $V_0$0 = $69;$V_1$0 = $V_1$3;
         label = 23;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iiii(1406,(0|0),($74|0),($V_1$3|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         $V_0$0 = $69;$V_1$0 = $V_1$3;
         label = 23;
         break;
        } else {
         $V_0$1 = $69;$V_1$1 = $77;
        }
       }
       __THREW__ = 0;
       invoke_vi(3799,($37|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 23;
        break;
       }
       $92 = (($37) + 8|0);
       $93 = Math_fround(HEAPF32[$92>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($44|0));
       $94 = __THREW__; __THREW__ = 0;
       $95 = $94&1;
       if ($95) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 23;
        break;
       }
       __THREW__ = 0;
       $96 = (invoke_ii(2587,($44|0))|0);
       $97 = __THREW__; __THREW__ = 0;
       $98 = $97&1;
       if ($98) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 23;
        break;
       }
       $99 = (Math_fround(($96|0)));
       $100 = Math_fround($93 + $99);
       $101 = Math_fround(HEAPF32[$26>>2]);
       __THREW__ = 0;
       $102 = (Math_fround(+(invoke_fiff(4,(0|0),(+$100),(+$101)))));
       $103 = __THREW__; __THREW__ = 0;
       $104 = $103&1;
       if ($104) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 23;
        break;
       }
       HEAPF32[$26>>2] = $102;
       __THREW__ = 0;
       invoke_vi(3799,($37|0));
       $105 = __THREW__; __THREW__ = 0;
       $106 = $105&1;
       if ($106) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 23;
        break;
       }
       $107 = (($37) + 12|0);
       $108 = Math_fround(HEAPF32[$107>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($44|0));
       $109 = __THREW__; __THREW__ = 0;
       $110 = $109&1;
       if ($110) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 23;
        break;
       }
       __THREW__ = 0;
       $111 = (invoke_ii(2587,($44|0))|0);
       $112 = __THREW__; __THREW__ = 0;
       $113 = $112&1;
       if ($113) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 23;
        break;
       }
       $114 = (Math_fround(($111|0)));
       $115 = Math_fround($108 + $114);
       $116 = Math_fround(HEAPF32[$27>>2]);
       __THREW__ = 0;
       $117 = (Math_fround(+(invoke_fiff(4,(0|0),(+$115),(+$116)))));
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 23;
        break;
       }
       HEAPF32[$27>>2] = $117;
       $V_0$2 = $V_0$1;$V_1$2 = $V_1$1;$V_2$1$off0 = 0;
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $120 = __THREW__; __THREW__ = 0;
      $121 = $120&1;
      if ($121) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;
       label = 23;
       break;
      }
      $122 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($37|0));
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;
       label = 23;
       break;
      }
      $125 = (($37) + 40|0);
      $126 = HEAP32[$125>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $127 = __THREW__; __THREW__ = 0;
      $128 = $127&1;
      if ($128) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;
       label = 23;
       break;
      }
      $129 = (($126) + ($122))|0;
      HEAP32[$28>>2] = $129;
      $V_0$3 = $V_0$2;$V_1$3 = $V_1$2;$V_2$2$off0 = $V_2$1$off0;
     }
     if ((label|0) == 23) {
      $56 = ___cxa_find_matching_catch(348288|0)|0;
      $57 = tempRet0;
      $58 = (_llvm_eh_typeid_for((348288|0))|0);
      $59 = ($57|0)==($58|0);
      if (!($59)) {
       $$0 = $56;$$04 = $57;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$0|0);
       // unreachable;
      }
      $60 = (___cxa_begin_catch(($56|0))|0);
      $61 = HEAP32[$60>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $62 = __THREW__; __THREW__ = 0;
      $63 = $62&1;
      if ($63) {
       break;
      }
      $V_0$4 = $V_0$0;$V_1$4 = $V_1$0;$__last_unhandled_exception$0 = $61;$leaveInstructions$sroa$0$0 = 0;
     }
     ;HEAP32[$L_46+0>>2]=HEAP32[$V_4+0>>2]|0;HEAP32[$L_46+4>>2]=HEAP32[$V_4+4>>2]|0;HEAP32[$L_46+8>>2]=HEAP32[$V_4+8>>2]|0;HEAP32[$L_46+12>>2]=HEAP32[$V_4+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1902144|0))|0);
     $135 = __THREW__; __THREW__ = 0;
     $136 = $135&1;
     if ($136) {
      break;
     }
     __THREW__ = 0;
     $137 = (invoke_iii(2724,(1902144|0),($L_46|0))|0);
     $138 = __THREW__; __THREW__ = 0;
     $139 = $138&1;
     if ($139) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($137|0));
     $140 = __THREW__; __THREW__ = 0;
     $141 = $140&1;
     if ($141) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(3491,(2176768|0),($137|0));
     $142 = __THREW__; __THREW__ = 0;
     $143 = $142&1;
     if ($143) {
      break;
     }
     $cond3 = ($leaveInstructions$sroa$0$0|0)==(323);
     if (!($cond3)) {
      __THREW__ = 0;
      invoke_vi(3844,($__last_unhandled_exception$0|0));
      $144 = __THREW__; __THREW__ = 0;
      $145 = $144&1;
      if ($145) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $146 = __THREW__; __THREW__ = 0;
     $147 = $146&1;
     if ($147) {
      break;
     }
     $148 = Math_fround(HEAPF32[$26>>2]);
     $149 = (($V_0$4) + ($V_1$4))|0;
     $150 = (Math_fround(($149|0)));
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $151 = __THREW__; __THREW__ = 0;
     $152 = $151&1;
     if ($152) {
      break;
     }
     $153 = Math_fround($148 - $150);
     HEAPF32[$26>>2] = $153;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $154 = __THREW__; __THREW__ = 0;
     $155 = $154&1;
     if ($155) {
      break;
     }
     $156 = Math_fround(HEAPF32[$27>>2]);
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $157 = __THREW__; __THREW__ = 0;
     $158 = $157&1;
     if ($158) {
      break;
     }
     $159 = Math_fround($156 - $150);
     HEAPF32[$27>>2] = $159;
     $V_0$5 = $V_0$4;$V_1$5 = $V_1$4;
    }
    __THREW__ = 0;
    $330 = (invoke_ii(2550,($__this|0))|0);
    $331 = __THREW__; __THREW__ = 0;
    $332 = $331&1;
    if (!($332)) {
     __THREW__ = 0;
     $333 = (invoke_ii(2596,0)|0);
     $334 = __THREW__; __THREW__ = 0;
     $335 = $334&1;
     if (!($335)) {
      $336 = ($330|0)==($333|0);
      if ($336) {
       $337 = (($__this) + 84|0);
       $338 = HEAP8[$337>>0]|0;
       $339 = ($338<<24>>24)==(0);
       if ($339) {
        $374 = (($__this) + 104|0);
        $375 = HEAP32[$374>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($375|0));
        $376 = __THREW__; __THREW__ = 0;
        $377 = $376&1;
        if ($377) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(2057,($375|0),($V_0$5|0));
        $378 = __THREW__; __THREW__ = 0;
        $379 = $378&1;
        if ($379) {
         break;
        }
        $380 = HEAP32[$374>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($380|0));
        $381 = __THREW__; __THREW__ = 0;
        $382 = $381&1;
        if ($382) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(2058,($380|0),($V_1$5|0));
        $383 = __THREW__; __THREW__ = 0;
        $384 = $383&1;
        if ($384) {
         break;
        } else {
         $V_11$0 = Math_fround(0.0);$V_12$0 = Math_fround(0.0);
        }
       } else {
        label = 137;
       }
      } else {
       label = 137;
      }
      if ((label|0) == 137) {
       __THREW__ = 0;
       $340 = (invoke_ii(2550,($__this|0))|0);
       $341 = __THREW__; __THREW__ = 0;
       $342 = $341&1;
       if ($342) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($340|0));
       $343 = __THREW__; __THREW__ = 0;
       $344 = $343&1;
       if ($344) {
        break;
       }
       __THREW__ = 0;
       $345 = (invoke_ii(2593,($340|0))|0);
       $346 = __THREW__; __THREW__ = 0;
       $347 = $346&1;
       if ($347) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($345|0));
       $348 = __THREW__; __THREW__ = 0;
       $349 = $348&1;
       if ($349) {
        break;
       }
       __THREW__ = 0;
       $350 = (invoke_ii(2583,($345|0))|0);
       $351 = __THREW__; __THREW__ = 0;
       $352 = $351&1;
       if ($352) {
        break;
       }
       __THREW__ = 0;
       $353 = (invoke_iiii(1407,(0|0),($350|0),($V_0$5|0))|0);
       $354 = __THREW__; __THREW__ = 0;
       $355 = $354&1;
       if ($355) {
        break;
       }
       $356 = (Math_fround(($353|0)));
       __THREW__ = 0;
       $357 = (invoke_ii(2550,($__this|0))|0);
       $358 = __THREW__; __THREW__ = 0;
       $359 = $358&1;
       if ($359) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($357|0));
       $360 = __THREW__; __THREW__ = 0;
       $361 = $360&1;
       if ($361) {
        break;
       }
       __THREW__ = 0;
       $362 = (invoke_ii(2593,($357|0))|0);
       $363 = __THREW__; __THREW__ = 0;
       $364 = $363&1;
       if ($364) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($362|0));
       $365 = __THREW__; __THREW__ = 0;
       $366 = $365&1;
       if ($366) {
        break;
       }
       __THREW__ = 0;
       $367 = (invoke_ii(2584,($362|0))|0);
       $368 = __THREW__; __THREW__ = 0;
       $369 = $368&1;
       if ($369) {
        break;
       }
       __THREW__ = 0;
       $370 = (invoke_iiii(1407,(0|0),($367|0),($V_1$5|0))|0);
       $371 = __THREW__; __THREW__ = 0;
       $372 = $371&1;
       if ($372) {
        break;
       }
       $373 = (Math_fround(($370|0)));
       $V_11$0 = $356;$V_12$0 = $373;
      }
      $385 = (($__this) + 8|0);
      $386 = Math_fround(HEAPF32[$385>>2]);
      $387 = Math_fround(HEAPF32[$26>>2]);
      $388 = Math_fround($V_11$0 + $387);
      $389 = Math_fround($V_12$0 + $388);
      __THREW__ = 0;
      $390 = (Math_fround(+(invoke_fiff(4,(0|0),(+$386),(+$389)))));
      $391 = __THREW__; __THREW__ = 0;
      $392 = $391&1;
      if (!($392)) {
       HEAPF32[$385>>2] = $390;
       $393 = (($__this) + 12|0);
       $394 = Math_fround(HEAPF32[$393>>2]);
       $395 = $394 != Math_fround(0.0);
       if ($395) {
        $416 = (($__this) + 40|0);
        HEAP32[$416>>2] = 0;
        $417 = $394;$418 = $390;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $396 = __THREW__; __THREW__ = 0;
        $397 = $396&1;
        if ($397) {
         break;
        }
        $398 = (($__this) + 40|0);
        $399 = HEAP32[$398>>2]|0;
        $400 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $401 = (invoke_ii(2550,($__this|0))|0);
        $402 = __THREW__; __THREW__ = 0;
        $403 = $402&1;
        if ($403) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($401|0));
        $404 = __THREW__; __THREW__ = 0;
        $405 = $404&1;
        if ($405) {
         break;
        }
        __THREW__ = 0;
        $406 = (invoke_ii(2594,($401|0))|0);
        $407 = __THREW__; __THREW__ = 0;
        $408 = $407&1;
        if ($408) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $409 = __THREW__; __THREW__ = 0;
        $410 = $409&1;
        if ($410) {
         break;
        }
        $$ = $406&1;
        $411 = (($400) + ($399))|0;
        $412 = (($411) + ($$))|0;
        HEAP32[$398>>2] = $412;
        $413 = Math_fround(HEAPF32[$27>>2]);
        $414 = Math_fround($V_11$0 + $413);
        $415 = Math_fround($V_12$0 + $414);
        HEAPF32[$393>>2] = $415;
        $$pre = Math_fround(HEAPF32[$385>>2]);
        $417 = $415;$418 = $$pre;
       }
       __THREW__ = 0;
       $419 = (Math_fround(+(invoke_fiff(4,(0|0),(+$417),(+$418)))));
       $420 = __THREW__; __THREW__ = 0;
       $421 = $420&1;
       if (!($421)) {
        HEAPF32[$393>>2] = $419;
        __THREW__ = 0;
        $422 = (invoke_ii(2550,($__this|0))|0);
        $423 = __THREW__; __THREW__ = 0;
        $424 = $423&1;
        if (!($424)) {
         __THREW__ = 0;
         invoke_vi(3799,($422|0));
         $425 = __THREW__; __THREW__ = 0;
         $426 = $425&1;
         if (!($426)) {
          __THREW__ = 0;
          $427 = (Math_fround(+(invoke_fi(134,($422|0)))));
          $428 = __THREW__; __THREW__ = 0;
          $429 = $428&1;
          if (!($429)) {
           $430 = $427 == Math_fround(0.0);
           if ($430) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           $431 = (invoke_ii(2550,($__this|0))|0);
           $432 = __THREW__; __THREW__ = 0;
           $433 = $432&1;
           if (!($433)) {
            __THREW__ = 0;
            invoke_vi(3799,($431|0));
            $434 = __THREW__; __THREW__ = 0;
            $435 = $434&1;
            if (!($435)) {
             __THREW__ = 0;
             $436 = (Math_fround(+(invoke_fi(134,($431|0)))));
             $437 = __THREW__; __THREW__ = 0;
             $438 = $437&1;
             if (!($438)) {
              HEAPF32[$385>>2] = $436;
              HEAPF32[$393>>2] = $436;
              $439 = (($__this) + 40|0);
              HEAP32[$439>>2] = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $$0 = $8;$$04 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z46UnityEngine_UnityEngine_GUIStyle_m_get_paddingP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747576);
 $1 = (($__this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $14 = $2;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($14|0);
 }
 __THREW__ = 0;
 $4 = (invoke_iii(1211,($__this|0),2)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2746216|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_ii(3469,(2746216|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$0>>2] = $4;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viii(737,($9|0),($__this|0),($$byval_copy|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     HEAP32[$1>>2] = $9;
     $14 = $9;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($14|0);
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z51UnityEngine_UnityEngine_RectOffset_m_get_horizontalP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2745288);
 $0 = HEAP32[2745336>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2745344|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2745336>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z54UnityEngine_UnityEngine_GUILayoutGroup_m_SetHorizontalP38UnityEngine_UnityEngine_GUILayoutGroupff($__this,$x,$width) {
 $__this = $__this|0;
 $x = Math_fround($x);
 $width = Math_fround($width);
 var $$ = 0, $$06 = Math_fround(0), $$07 = 0, $$08 = 0, $$1 = Math_fround(0), $$2 = Math_fround(0), $$3 = Math_fround(0), $$pre = Math_fround(0), $$pre$phiZ2D = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = Math_fround(0), $14 = 0, $140 = Math_fround(0), $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = Math_fround(0), $186 = Math_fround(0), $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = Math_fround(0), $2 = 0, $20 = 0, $200 = Math_fround(0), $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = Math_fround(0), $212 = Math_fround(0), $213 = 0, $214 = 0;
 var $215 = 0, $216 = Math_fround(0), $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = Math_fround(0), $221 = Math_fround(0), $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = Math_fround(0), $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = Math_fround(0);
 var $288 = Math_fround(0), $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0;
 var $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = Math_fround(0), $314 = Math_fround(0), $315 = 0, $316 = 0, $317 = Math_fround(0), $318 = Math_fround(0), $319 = Math_fround(0), $32 = 0, $320 = 0, $321 = Math_fround(0), $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = Math_fround(0), $33 = 0, $330 = Math_fround(0), $331 = Math_fround(0), $332 = 0, $333 = Math_fround(0), $334 = 0, $335 = Math_fround(0), $336 = 0, $337 = Math_fround(0), $338 = Math_fround(0), $339 = Math_fround(0), $34 = 0, $340 = Math_fround(0);
 var $341 = 0, $342 = 0, $343 = 0, $344 = Math_fround(0), $345 = 0, $346 = 0, $347 = 0, $348 = Math_fround(0), $349 = Math_fround(0), $35 = 0, $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = Math_fround(0), $361 = 0, $362 = 0, $363 = 0, $364 = Math_fround(0), $365 = Math_fround(0), $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = Math_fround(0), $373 = Math_fround(0), $374 = Math_fround(0), $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = Math_fround(0), $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = Math_fround(0), $416 = 0, $417 = 0, $418 = Math_fround(0), $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0), $426 = Math_fround(0), $427 = Math_fround(0), $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = Math_fround(0), $71 = Math_fround(0), $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = Math_fround(0), $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = Math_fround(0), $99 = 0, $G_B39_0$0 = 0, $L_124 = 0, $L_149 = 0, $L_28 = 0, $L_39 = 0, $L_62 = 0;
 var $L_8 = 0, $V_10$0 = Math_fround(0), $V_11$0 = Math_fround(0), $V_13$0 = Math_fround(0), $V_14$0 = Math_fround(0), $V_15$0 = 0, $V_15$1 = 0, $V_16$1$off0 = 0, $V_16$2$off0 = 0, $V_18 = 0, $V_2 = 0, $V_9 = 0, $__last_unhandled_exception$0 = 0, $__last_unhandled_exception$1 = 0, $__last_unhandled_exception$2 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond3 = 0, $cond5 = 0, $leaveInstructions$sroa$0$0 = 0;
 var $leaveInstructions$sroa$0$1 = 0, $leaveInstructions$sroa$0$2 = 0, $x$ = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $_stackTraceSentry = sp + 144|0;
 $V_2 = sp + 128|0;
 $V_9 = sp + 112|0;
 $V_18 = sp + 96|0;
 $L_8 = sp + 80|0;
 $L_28 = sp + 64|0;
 $L_39 = sp + 32|0;
 $L_62 = sp + 16|0;
 $L_124 = sp;
 $L_149 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726896);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;
 ;HEAP32[$V_9+0>>2]=0|0;HEAP32[$V_9+4>>2]=0|0;HEAP32[$V_9+8>>2]=0|0;HEAP32[$V_9+12>>2]=0|0;
 ;HEAP32[$V_18+0>>2]=0|0;HEAP32[$V_18+4>>2]=0|0;HEAP32[$V_18+8>>2]=0|0;HEAP32[$V_18+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viff(11,($__this|0),(+$x),(+$width));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 57|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(0);
   $x$ = $4 ? $x : Math_fround(0.0);
   __THREW__ = 0;
   $5 = (invoke_ii(2550,($__this|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    invoke_vi(3799,($5|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     $12 = (invoke_ii(2593,($5|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      $15 = (($__this) + 56|0);
      $16 = HEAP8[$15>>0]|0;
      $17 = ($16<<24>>24)==(0);
      if ($17) {
       __THREW__ = 0;
       $244 = (invoke_ii(2550,($__this|0))|0);
       $245 = __THREW__; __THREW__ = 0;
       $246 = $245&1;
       if ($246) {
        break;
       }
       __THREW__ = 0;
       $247 = (invoke_ii(2596,0)|0);
       $248 = __THREW__; __THREW__ = 0;
       $249 = $248&1;
       if ($249) {
        break;
       }
       $250 = ($244|0)==($247|0);
       if ($250) {
        $$pre22 = (($__this) + 52|0);
        $$06 = $width;$$1 = $x$;$$pre$phiZ2D = $$pre22;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($12|0));
        $251 = __THREW__; __THREW__ = 0;
        $252 = $251&1;
        if ($252) {
         break;
        }
        __THREW__ = 0;
        $253 = (invoke_ii(2583,($12|0))|0);
        $254 = __THREW__; __THREW__ = 0;
        $255 = $254&1;
        if ($255) {
         break;
        }
        $256 = (Math_fround(($253|0)));
        __THREW__ = 0;
        invoke_vi(3799,($12|0));
        $257 = __THREW__; __THREW__ = 0;
        $258 = $257&1;
        if ($258) {
         break;
        }
        __THREW__ = 0;
        $259 = (invoke_ii(2584,($12|0))|0);
        $260 = __THREW__; __THREW__ = 0;
        $261 = $260&1;
        if ($261) {
         break;
        }
        $262 = (Math_fround(($259|0)));
        $263 = (($__this) + 52|0);
        $264 = HEAP32[$263>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($264|0));
        $265 = __THREW__; __THREW__ = 0;
        $266 = $265&1;
        if ($266) {
         break;
        }
        __THREW__ = 0;
        $267 = (invoke_iii(2729,(1905272|0),($264|0))|0);
        $268 = __THREW__; __THREW__ = 0;
        $269 = $268&1;
        if ($269) {
         break;
        }
        $270 = ($267|0)==(0);
        if ($270) {
         $V_10$0 = $256;$V_11$0 = $262;
        } else {
         $271 = HEAP32[$263>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($271|0));
         $272 = __THREW__; __THREW__ = 0;
         $273 = $272&1;
         if ($273) {
          break;
         }
         __THREW__ = 0;
         $274 = (invoke_iiii(1642,(1905336|0),($271|0),0)|0);
         $275 = __THREW__; __THREW__ = 0;
         $276 = $275&1;
         if ($276) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($274|0));
         $277 = __THREW__; __THREW__ = 0;
         $278 = $277&1;
         if ($278) {
          break;
         }
         __THREW__ = 0;
         $279 = (invoke_iii(2730,(2728688|0),($274|0))|0);
         $280 = __THREW__; __THREW__ = 0;
         $281 = $280&1;
         if ($281) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($279|0));
         $282 = __THREW__; __THREW__ = 0;
         $283 = $282&1;
         if ($283) {
          break;
         }
         __THREW__ = 0;
         $284 = (invoke_ii(2583,($279|0))|0);
         $285 = __THREW__; __THREW__ = 0;
         $286 = $285&1;
         if ($286) {
          break;
         }
         $287 = (Math_fround(($284|0)));
         __THREW__ = 0;
         $288 = (Math_fround(+(invoke_fiff(4,(0|0),(+$256),(+$287)))));
         $289 = __THREW__; __THREW__ = 0;
         $290 = $289&1;
         if ($290) {
          break;
         }
         $291 = HEAP32[$263>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($291|0));
         $292 = __THREW__; __THREW__ = 0;
         $293 = $292&1;
         if ($293) {
          break;
         }
         __THREW__ = 0;
         $294 = (invoke_iii(2729,(1905272|0),($291|0))|0);
         $295 = __THREW__; __THREW__ = 0;
         $296 = $295&1;
         if ($296) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($291|0));
         $297 = __THREW__; __THREW__ = 0;
         $298 = $297&1;
         if ($298) {
          break;
         }
         $299 = (($294) + -1)|0;
         __THREW__ = 0;
         $300 = (invoke_iiii(1642,(1905336|0),($291|0),($299|0))|0);
         $301 = __THREW__; __THREW__ = 0;
         $302 = $301&1;
         if ($302) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($300|0));
         $303 = __THREW__; __THREW__ = 0;
         $304 = $303&1;
         if ($304) {
          break;
         }
         __THREW__ = 0;
         $305 = (invoke_iii(2730,(2728688|0),($300|0))|0);
         $306 = __THREW__; __THREW__ = 0;
         $307 = $306&1;
         if ($307) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($305|0));
         $308 = __THREW__; __THREW__ = 0;
         $309 = $308&1;
         if ($309) {
          break;
         }
         __THREW__ = 0;
         $310 = (invoke_ii(2584,($305|0))|0);
         $311 = __THREW__; __THREW__ = 0;
         $312 = $311&1;
         if ($312) {
          break;
         }
         $313 = (Math_fround(($310|0)));
         __THREW__ = 0;
         $314 = (Math_fround(+(invoke_fiff(4,(0|0),(+$262),(+$313)))));
         $315 = __THREW__; __THREW__ = 0;
         $316 = $315&1;
         if ($316) {
          break;
         } else {
          $V_10$0 = $288;$V_11$0 = $314;
         }
        }
        $317 = Math_fround($x$ + $V_10$0);
        $318 = Math_fround($V_11$0 + $V_10$0);
        $319 = Math_fround($width - $318);
        $$06 = $319;$$1 = $317;$$pre$phiZ2D = $263;
       }
       $320 = (($__this) + 60|0);
       $321 = Math_fround(HEAPF32[$320>>2]);
       $322 = HEAP32[$$pre$phiZ2D>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($322|0));
       $323 = __THREW__; __THREW__ = 0;
       $324 = $323&1;
       if ($324) {
        break;
       }
       __THREW__ = 0;
       $325 = (invoke_iii(2729,(1905272|0),($322|0))|0);
       $326 = __THREW__; __THREW__ = 0;
       $327 = $326&1;
       if ($327) {
        break;
       }
       $328 = (($325) + -1)|0;
       $329 = (Math_fround(($328|0)));
       $330 = Math_fround($321 * $329);
       $331 = Math_fround($$06 - $330);
       $332 = (($__this) + 88|0);
       $333 = Math_fround(HEAPF32[$332>>2]);
       $334 = (($__this) + 92|0);
       $335 = Math_fround(HEAPF32[$334>>2]);
       $336 = $333 == $335;
       if ($336) {
        $344 = $335;$V_13$0 = Math_fround(0.0);
       } else {
        $337 = Math_fround($331 - $333);
        $338 = Math_fround($335 - $333);
        $339 = Math_fround($337 / $338);
        __THREW__ = 0;
        $340 = (Math_fround(+(invoke_fifff(1,(0|0),(+$339),0.0,1.0))));
        $341 = __THREW__; __THREW__ = 0;
        $342 = $341&1;
        if ($342) {
         break;
        }
        $$pre = Math_fround(HEAPF32[$334>>2]);
        $344 = $$pre;$V_13$0 = $340;
       }
       $343 = !($331 <= $344);
       if ($343) {
        $345 = (($__this) + 76|0);
        $346 = HEAP32[$345>>2]|0;
        $347 = ($346|0)<(1);
        if ($347) {
         $V_14$0 = Math_fround(0.0);
        } else {
         $348 = Math_fround($331 - $344);
         $349 = (Math_fround(($346|0)));
         $350 = Math_fround($348 / $349);
         $V_14$0 = $350;
        }
       } else {
        $V_14$0 = Math_fround(0.0);
       }
       $351 = HEAP32[$$pre$phiZ2D>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($351|0));
       $352 = __THREW__; __THREW__ = 0;
       $353 = $352&1;
       if ($353) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(1633,($L_124|0),($351|0));
       $354 = __THREW__; __THREW__ = 0;
       $355 = $354&1;
       if ($355) {
        break;
       }
       ;HEAP32[$V_18+0>>2]=HEAP32[$L_124+0>>2]|0;HEAP32[$V_18+4>>2]=HEAP32[$L_124+4>>2]|0;HEAP32[$V_18+8>>2]=HEAP32[$L_124+8>>2]|0;HEAP32[$V_18+12>>2]=HEAP32[$L_124+12>>2]|0;
       $$3 = $$1;$V_15$1 = 0;$V_16$2$off0 = 1;
       while(1) {
        __THREW__ = 0;
        $428 = (invoke_ii(3478,($V_18|0))|0);
        $429 = __THREW__; __THREW__ = 0;
        $430 = $429&1;
        if ($430) {
         label = 143;
         break;
        }
        if (!($428)) {
         $__last_unhandled_exception$2 = 0;$leaveInstructions$sroa$0$2 = 944;
         break;
        }
        __THREW__ = 0;
        $356 = (invoke_ii(3468,($V_18|0))|0);
        $431 = __THREW__; __THREW__ = 0;
        $432 = $431&1;
        if ($432) {
         label = 143;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($356|0));
        $357 = __THREW__; __THREW__ = 0;
        $358 = $357&1;
        if ($358) {
         label = 143;
         break;
        }
        $359 = (($356) + 8|0);
        $360 = Math_fround(HEAPF32[$359>>2]);
        __THREW__ = 0;
        invoke_vi(3799,($356|0));
        $361 = __THREW__; __THREW__ = 0;
        $362 = $361&1;
        if ($362) {
         label = 143;
         break;
        }
        $363 = (($356) + 12|0);
        $364 = Math_fround(HEAPF32[$363>>2]);
        __THREW__ = 0;
        $365 = (Math_fround(+(invoke_fifff(2,(0|0),(+$360),(+$364),(+$V_13$0)))));
        $366 = __THREW__; __THREW__ = 0;
        $367 = $366&1;
        if ($367) {
         label = 143;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($356|0));
        $368 = __THREW__; __THREW__ = 0;
        $369 = $368&1;
        if ($369) {
         label = 143;
         break;
        }
        $370 = (($356) + 40|0);
        $371 = HEAP32[$370>>2]|0;
        $372 = (Math_fround(($371|0)));
        $373 = Math_fround($V_14$0 * $372);
        $374 = Math_fround($365 + $373);
        __THREW__ = 0;
        invoke_vi(3799,($356|0));
        $375 = __THREW__; __THREW__ = 0;
        $376 = $375&1;
        if ($376) {
         label = 143;
         break;
        }
        __THREW__ = 0;
        $377 = (invoke_ii(2550,($356|0))|0);
        $378 = __THREW__; __THREW__ = 0;
        $379 = $378&1;
        if ($379) {
         label = 143;
         break;
        }
        __THREW__ = 0;
        $380 = (invoke_ii(2549,0)|0);
        $381 = __THREW__; __THREW__ = 0;
        $382 = $381&1;
        if ($382) {
         label = 143;
         break;
        }
        $383 = ($377|0)==($380|0);
        if ($383) {
         $$2 = $$3;$V_15$0 = $V_15$1;$V_16$1$off0 = $V_16$2$off0;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($356|0));
         $392 = __THREW__; __THREW__ = 0;
         $393 = $392&1;
         if ($393) {
          label = 143;
          break;
         }
         __THREW__ = 0;
         $394 = (invoke_iii(2730,(2728688|0),($356|0))|0);
         $395 = __THREW__; __THREW__ = 0;
         $396 = $395&1;
         if ($396) {
          label = 143;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($394|0));
         $397 = __THREW__; __THREW__ = 0;
         $398 = $397&1;
         if ($398) {
          label = 143;
          break;
         }
         __THREW__ = 0;
         $399 = (invoke_ii(2583,($394|0))|0);
         $400 = __THREW__; __THREW__ = 0;
         $401 = $400&1;
         if ($401) {
          label = 143;
          break;
         }
         $$ = $V_16$2$off0 ? 0 : $399;
         $402 = ($V_15$1|0)>($$|0);
         $G_B39_0$0 = $402 ? $V_15$1 : $$;
         $403 = (Math_fround(($G_B39_0$0|0)));
         $404 = Math_fround($$3 + $403);
         __THREW__ = 0;
         invoke_vi(3799,($356|0));
         $405 = __THREW__; __THREW__ = 0;
         $406 = $405&1;
         if ($406) {
          label = 143;
          break;
         }
         __THREW__ = 0;
         $407 = (invoke_iii(2730,(2728688|0),($356|0))|0);
         $408 = __THREW__; __THREW__ = 0;
         $409 = $408&1;
         if ($409) {
          label = 143;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($407|0));
         $410 = __THREW__; __THREW__ = 0;
         $411 = $410&1;
         if ($411) {
          label = 143;
          break;
         }
         __THREW__ = 0;
         $412 = (invoke_ii(2584,($407|0))|0);
         $413 = __THREW__; __THREW__ = 0;
         $414 = $413&1;
         if ($414) {
          label = 143;
          break;
         } else {
          $$2 = $404;$V_15$0 = $412;$V_16$1$off0 = 0;
         }
        }
        __THREW__ = 0;
        $415 = (Math_fround(+(invoke_fif(11,(0|0),(+$$2)))));
        $416 = __THREW__; __THREW__ = 0;
        $417 = $416&1;
        if ($417) {
         label = 143;
         break;
        }
        __THREW__ = 0;
        $418 = (Math_fround(+(invoke_fif(11,(0|0),(+$374)))));
        $419 = __THREW__; __THREW__ = 0;
        $420 = $419&1;
        if ($420) {
         label = 143;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($356|0));
        $421 = __THREW__; __THREW__ = 0;
        $422 = $421&1;
        if ($422) {
         label = 143;
         break;
        }
        __THREW__ = 0;
        invoke_viiff(2,(2728832|0),($356|0),(+$415),(+$418));
        $423 = __THREW__; __THREW__ = 0;
        $424 = $423&1;
        if ($424) {
         label = 143;
         break;
        }
        $425 = Math_fround(HEAPF32[$320>>2]);
        $426 = Math_fround($374 + $425);
        $427 = Math_fround($$2 + $426);
        $$3 = $427;$V_15$1 = $V_15$0;$V_16$2$off0 = $V_16$1$off0;
       }
       if ((label|0) == 143) {
        $384 = ___cxa_find_matching_catch(348288|0)|0;
        $385 = tempRet0;
        $386 = (_llvm_eh_typeid_for((348288|0))|0);
        $387 = ($385|0)==($386|0);
        if (!($387)) {
         $$07 = $384;$$08 = $385;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$07|0);
         // unreachable;
        }
        $388 = (___cxa_begin_catch(($384|0))|0);
        $389 = HEAP32[$388>>2]|0;
        __THREW__ = 0;
        invoke_v(66);
        $390 = __THREW__; __THREW__ = 0;
        $391 = $390&1;
        if ($391) {
         break;
        }
        $__last_unhandled_exception$2 = $389;$leaveInstructions$sroa$0$2 = 0;
       }
       ;HEAP32[$L_149+0>>2]=HEAP32[$V_18+0>>2]|0;HEAP32[$L_149+4>>2]=HEAP32[$V_18+4>>2]|0;HEAP32[$L_149+8>>2]=HEAP32[$V_18+8>>2]|0;HEAP32[$L_149+12>>2]=HEAP32[$V_18+12>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(1902144|0))|0);
       $433 = __THREW__; __THREW__ = 0;
       $434 = $433&1;
       if ($434) {
        break;
       }
       __THREW__ = 0;
       $435 = (invoke_iii(2724,(1902144|0),($L_149|0))|0);
       $436 = __THREW__; __THREW__ = 0;
       $437 = $436&1;
       if ($437) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($435|0));
       $438 = __THREW__; __THREW__ = 0;
       $439 = $438&1;
       if ($439) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(3491,(2176768|0),($435|0));
       $440 = __THREW__; __THREW__ = 0;
       $441 = $440&1;
       if ($441) {
        break;
       }
       $cond1 = ($leaveInstructions$sroa$0$2|0)==(944);
       if ($cond1) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
       __THREW__ = 0;
       invoke_vi(3844,($__last_unhandled_exception$2|0));
       $442 = __THREW__; __THREW__ = 0;
       $443 = $442&1;
       if ($443) {
        break;
       }
       // unreachable;
      }
      __THREW__ = 0;
      $18 = (invoke_ii(2550,($__this|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if (!($20)) {
       __THREW__ = 0;
       $21 = (invoke_ii(2596,0)|0);
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = ($18|0)==($21|0);
        if (!($24)) {
         $25 = (($__this) + 52|0);
         $26 = HEAP32[$25>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($26|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(1633,($L_8|0),($26|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         ;HEAP32[$V_2+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_8+12>>2]|0;
         while(1) {
          __THREW__ = 0;
          $105 = (invoke_ii(3478,($V_2|0))|0);
          $106 = __THREW__; __THREW__ = 0;
          $107 = $106&1;
          if ($107) {
           label = 29;
           break;
          }
          if (!($105)) {
           $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 230;
           break;
          }
          __THREW__ = 0;
          $31 = (invoke_ii(3468,($V_2|0))|0);
          $108 = __THREW__; __THREW__ = 0;
          $109 = $108&1;
          if ($109) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($31|0));
          $32 = __THREW__; __THREW__ = 0;
          $33 = $32&1;
          if ($33) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          $34 = (invoke_iii(2730,(2728688|0),($31|0))|0);
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if ($36) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($34|0));
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          $39 = (invoke_ii(2583,($34|0))|0);
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($12|0));
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          $44 = (invoke_ii(2583,($12|0))|0);
          $45 = __THREW__; __THREW__ = 0;
          $46 = $45&1;
          if ($46) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          $47 = (invoke_iiii(1407,(0|0),($39|0),($44|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           label = 29;
           break;
          }
          $50 = (Math_fround(($47|0)));
          $51 = Math_fround($x$ + $50);
          __THREW__ = 0;
          invoke_vi(3799,($31|0));
          $52 = __THREW__; __THREW__ = 0;
          $53 = $52&1;
          if ($53) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          $54 = (invoke_iii(2730,(2728688|0),($31|0))|0);
          $55 = __THREW__; __THREW__ = 0;
          $56 = $55&1;
          if ($56) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($54|0));
          $57 = __THREW__; __THREW__ = 0;
          $58 = $57&1;
          if ($58) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          $59 = (invoke_ii(2584,($54|0))|0);
          $60 = __THREW__; __THREW__ = 0;
          $61 = $60&1;
          if ($61) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($12|0));
          $62 = __THREW__; __THREW__ = 0;
          $63 = $62&1;
          if ($63) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          $64 = (invoke_ii(2584,($12|0))|0);
          $65 = __THREW__; __THREW__ = 0;
          $66 = $65&1;
          if ($66) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          $67 = (invoke_iiii(1407,(0|0),($59|0),($64|0))|0);
          $68 = __THREW__; __THREW__ = 0;
          $69 = $68&1;
          if ($69) {
           label = 29;
           break;
          }
          $70 = (Math_fround(($67|0)));
          $71 = Math_fround($width - $70);
          $72 = Math_fround($71 - $50);
          __THREW__ = 0;
          invoke_vi(3799,($31|0));
          $73 = __THREW__; __THREW__ = 0;
          $74 = $73&1;
          if ($74) {
           label = 29;
           break;
          }
          $75 = (($31) + 40|0);
          $76 = HEAP32[$75>>2]|0;
          $77 = ($76|0)==(0);
          if (!($77)) {
           __THREW__ = 0;
           invoke_vi(3799,($31|0));
           $86 = __THREW__; __THREW__ = 0;
           $87 = $86&1;
           if ($87) {
            label = 29;
            break;
           }
           __THREW__ = 0;
           invoke_viiff(2,(2728832|0),($31|0),(+$51),(+$72));
           $88 = __THREW__; __THREW__ = 0;
           $89 = $88&1;
           if ($89) {
            label = 29;
            break;
           } else {
            continue;
           }
          }
          __THREW__ = 0;
          invoke_vi(3799,($31|0));
          $90 = __THREW__; __THREW__ = 0;
          $91 = $90&1;
          if ($91) {
           label = 29;
           break;
          }
          $92 = (($31) + 8|0);
          $93 = Math_fround(HEAPF32[$92>>2]);
          __THREW__ = 0;
          invoke_vi(3799,($31|0));
          $94 = __THREW__; __THREW__ = 0;
          $95 = $94&1;
          if ($95) {
           label = 29;
           break;
          }
          $96 = (($31) + 12|0);
          $97 = Math_fround(HEAPF32[$96>>2]);
          __THREW__ = 0;
          $98 = (Math_fround(+(invoke_fifff(1,(0|0),(+$72),(+$93),(+$97)))));
          $99 = __THREW__; __THREW__ = 0;
          $100 = $99&1;
          if ($100) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($31|0));
          $101 = __THREW__; __THREW__ = 0;
          $102 = $101&1;
          if ($102) {
           label = 29;
           break;
          }
          __THREW__ = 0;
          invoke_viiff(2,(2728832|0),($31|0),(+$51),(+$98));
          $103 = __THREW__; __THREW__ = 0;
          $104 = $103&1;
          if ($104) {
           label = 29;
           break;
          }
         }
         if ((label|0) == 29) {
          $78 = ___cxa_find_matching_catch(348288|0)|0;
          $79 = tempRet0;
          $80 = (_llvm_eh_typeid_for((348288|0))|0);
          $81 = ($79|0)==($80|0);
          if (!($81)) {
           $$07 = $78;$$08 = $79;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($$07|0);
           // unreachable;
          }
          $82 = (___cxa_begin_catch(($78|0))|0);
          $83 = HEAP32[$82>>2]|0;
          __THREW__ = 0;
          invoke_v(66);
          $84 = __THREW__; __THREW__ = 0;
          $85 = $84&1;
          if ($85) {
           break;
          }
          $__last_unhandled_exception$0 = $83;$leaveInstructions$sroa$0$0 = 0;
         }
         ;HEAP32[$L_28+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_28+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_28+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$L_28+12>>2]=HEAP32[$V_2+12>>2]|0;
         __THREW__ = 0;
         (invoke_ii(2996,(1902144|0))|0);
         $110 = __THREW__; __THREW__ = 0;
         $111 = $110&1;
         if ($111) {
          break;
         }
         __THREW__ = 0;
         $112 = (invoke_iii(2724,(1902144|0),($L_28|0))|0);
         $113 = __THREW__; __THREW__ = 0;
         $114 = $113&1;
         if ($114) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($112|0));
         $115 = __THREW__; __THREW__ = 0;
         $116 = $115&1;
         if ($116) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(3491,(2176768|0),($112|0));
         $117 = __THREW__; __THREW__ = 0;
         $118 = $117&1;
         if ($118) {
          break;
         }
         $cond3 = ($leaveInstructions$sroa$0$0|0)==(230);
         if ($cond3) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         __THREW__ = 0;
         invoke_vi(3844,($__last_unhandled_exception$0|0));
         $119 = __THREW__; __THREW__ = 0;
         $120 = $119&1;
         if ($120) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        $121 = (invoke_iii(2730,(2730064|0),($__this|0))|0);
        $122 = __THREW__; __THREW__ = 0;
        $123 = $122&1;
        if (!($123)) {
         __THREW__ = 0;
         invoke_vi(3799,($121|0));
         $124 = __THREW__; __THREW__ = 0;
         $125 = $124&1;
         if (!($125)) {
          __THREW__ = 0;
          $126 = (invoke_ii(2583,($121|0))|0);
          $127 = __THREW__; __THREW__ = 0;
          $128 = $127&1;
          if (!($128)) {
           $129 = (Math_fround(($126|0)));
           $130 = Math_fround($x$ - $129);
           __THREW__ = 0;
           $131 = (invoke_iii(2730,(2730064|0),($__this|0))|0);
           $132 = __THREW__; __THREW__ = 0;
           $133 = $132&1;
           if (!($133)) {
            __THREW__ = 0;
            invoke_vi(3799,($131|0));
            $134 = __THREW__; __THREW__ = 0;
            $135 = $134&1;
            if (!($135)) {
             __THREW__ = 0;
             $136 = (invoke_ii(2587,($131|0))|0);
             $137 = __THREW__; __THREW__ = 0;
             $138 = $137&1;
             if (!($138)) {
              $139 = (Math_fround(($136|0)));
              $140 = Math_fround($139 + $width);
              $141 = (($__this) + 52|0);
              $142 = HEAP32[$141>>2]|0;
              __THREW__ = 0;
              invoke_vi(3799,($142|0));
              $143 = __THREW__; __THREW__ = 0;
              $144 = $143&1;
              if (!($144)) {
               __THREW__ = 0;
               invoke_vii(1633,($L_39|0),($142|0));
               $145 = __THREW__; __THREW__ = 0;
               $146 = $145&1;
               if (!($146)) {
                ;HEAP32[$V_9+0>>2]=HEAP32[$L_39+0>>2]|0;HEAP32[$V_9+4>>2]=HEAP32[$L_39+4>>2]|0;HEAP32[$V_9+8>>2]=HEAP32[$L_39+8>>2]|0;HEAP32[$V_9+12>>2]=HEAP32[$L_39+12>>2]|0;
                while(1) {
                 __THREW__ = 0;
                 $228 = (invoke_ii(3478,($V_9|0))|0);
                 $229 = __THREW__; __THREW__ = 0;
                 $230 = $229&1;
                 if ($230) {
                  label = 60;
                  break;
                 }
                 if (!($228)) {
                  $__last_unhandled_exception$1 = 0;$leaveInstructions$sroa$0$1 = 438;
                  break;
                 }
                 __THREW__ = 0;
                 $147 = (invoke_ii(3468,($V_9|0))|0);
                 $231 = __THREW__; __THREW__ = 0;
                 $232 = $231&1;
                 if ($232) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($147|0));
                 $148 = __THREW__; __THREW__ = 0;
                 $149 = $148&1;
                 if ($149) {
                  label = 60;
                  break;
                 }
                 $150 = (($147) + 40|0);
                 $151 = HEAP32[$150>>2]|0;
                 $152 = ($151|0)==(0);
                 if (!($152)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($147|0));
                  $161 = __THREW__; __THREW__ = 0;
                  $162 = $161&1;
                  if ($162) {
                   label = 60;
                   break;
                  }
                  __THREW__ = 0;
                  $163 = (invoke_iii(2730,(2728688|0),($147|0))|0);
                  $164 = __THREW__; __THREW__ = 0;
                  $165 = $164&1;
                  if ($165) {
                   label = 60;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($163|0));
                  $166 = __THREW__; __THREW__ = 0;
                  $167 = $166&1;
                  if ($167) {
                   label = 60;
                   break;
                  }
                  __THREW__ = 0;
                  $168 = (invoke_ii(2583,($163|0))|0);
                  $169 = __THREW__; __THREW__ = 0;
                  $170 = $169&1;
                  if ($170) {
                   label = 60;
                   break;
                  }
                  $171 = (Math_fround(($168|0)));
                  $172 = Math_fround($130 + $171);
                  __THREW__ = 0;
                  invoke_vi(3799,($147|0));
                  $173 = __THREW__; __THREW__ = 0;
                  $174 = $173&1;
                  if ($174) {
                   label = 60;
                   break;
                  }
                  __THREW__ = 0;
                  $175 = (invoke_iii(2730,(2728688|0),($147|0))|0);
                  $176 = __THREW__; __THREW__ = 0;
                  $177 = $176&1;
                  if ($177) {
                   label = 60;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($175|0));
                  $178 = __THREW__; __THREW__ = 0;
                  $179 = $178&1;
                  if ($179) {
                   label = 60;
                   break;
                  }
                  __THREW__ = 0;
                  $180 = (invoke_ii(2587,($175|0))|0);
                  $181 = __THREW__; __THREW__ = 0;
                  $182 = $181&1;
                  if ($182) {
                   label = 60;
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($147|0));
                  $183 = __THREW__; __THREW__ = 0;
                  $184 = $183&1;
                  if ($184) {
                   label = 60;
                   break;
                  }
                  $185 = (Math_fround(($180|0)));
                  $186 = Math_fround($140 - $185);
                  __THREW__ = 0;
                  invoke_viiff(2,(2728832|0),($147|0),(+$172),(+$186));
                  $187 = __THREW__; __THREW__ = 0;
                  $188 = $187&1;
                  if ($188) {
                   label = 60;
                   break;
                  } else {
                   continue;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($147|0));
                 $189 = __THREW__; __THREW__ = 0;
                 $190 = $189&1;
                 if ($190) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 $191 = (invoke_iii(2730,(2728688|0),($147|0))|0);
                 $192 = __THREW__; __THREW__ = 0;
                 $193 = $192&1;
                 if ($193) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($191|0));
                 $194 = __THREW__; __THREW__ = 0;
                 $195 = $194&1;
                 if ($195) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 $196 = (invoke_ii(2583,($191|0))|0);
                 $197 = __THREW__; __THREW__ = 0;
                 $198 = $197&1;
                 if ($198) {
                  label = 60;
                  break;
                 }
                 $199 = (Math_fround(($196|0)));
                 $200 = Math_fround($130 + $199);
                 __THREW__ = 0;
                 invoke_vi(3799,($147|0));
                 $201 = __THREW__; __THREW__ = 0;
                 $202 = $201&1;
                 if ($202) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 $203 = (invoke_iii(2730,(2728688|0),($147|0))|0);
                 $204 = __THREW__; __THREW__ = 0;
                 $205 = $204&1;
                 if ($205) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($203|0));
                 $206 = __THREW__; __THREW__ = 0;
                 $207 = $206&1;
                 if ($207) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 $208 = (invoke_ii(2587,($203|0))|0);
                 $209 = __THREW__; __THREW__ = 0;
                 $210 = $209&1;
                 if ($210) {
                  label = 60;
                  break;
                 }
                 $211 = (Math_fround(($208|0)));
                 $212 = Math_fround($140 - $211);
                 __THREW__ = 0;
                 invoke_vi(3799,($147|0));
                 $213 = __THREW__; __THREW__ = 0;
                 $214 = $213&1;
                 if ($214) {
                  label = 60;
                  break;
                 }
                 $215 = (($147) + 8|0);
                 $216 = Math_fround(HEAPF32[$215>>2]);
                 __THREW__ = 0;
                 invoke_vi(3799,($147|0));
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  label = 60;
                  break;
                 }
                 $219 = (($147) + 12|0);
                 $220 = Math_fround(HEAPF32[$219>>2]);
                 __THREW__ = 0;
                 $221 = (Math_fround(+(invoke_fifff(1,(0|0),(+$212),(+$216),(+$220)))));
                 $222 = __THREW__; __THREW__ = 0;
                 $223 = $222&1;
                 if ($223) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($147|0));
                 $224 = __THREW__; __THREW__ = 0;
                 $225 = $224&1;
                 if ($225) {
                  label = 60;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_viiff(2,(2728832|0),($147|0),(+$200),(+$221));
                 $226 = __THREW__; __THREW__ = 0;
                 $227 = $226&1;
                 if ($227) {
                  label = 60;
                  break;
                 }
                }
                if ((label|0) == 60) {
                 $153 = ___cxa_find_matching_catch(348288|0)|0;
                 $154 = tempRet0;
                 $155 = (_llvm_eh_typeid_for((348288|0))|0);
                 $156 = ($154|0)==($155|0);
                 if (!($156)) {
                  $$07 = $153;$$08 = $154;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($$07|0);
                  // unreachable;
                 }
                 $157 = (___cxa_begin_catch(($153|0))|0);
                 $158 = HEAP32[$157>>2]|0;
                 __THREW__ = 0;
                 invoke_v(66);
                 $159 = __THREW__; __THREW__ = 0;
                 $160 = $159&1;
                 if ($160) {
                  break;
                 }
                 $__last_unhandled_exception$1 = $158;$leaveInstructions$sroa$0$1 = 0;
                }
                ;HEAP32[$L_62+0>>2]=HEAP32[$V_9+0>>2]|0;HEAP32[$L_62+4>>2]=HEAP32[$V_9+4>>2]|0;HEAP32[$L_62+8>>2]=HEAP32[$V_9+8>>2]|0;HEAP32[$L_62+12>>2]=HEAP32[$V_9+12>>2]|0;
                __THREW__ = 0;
                (invoke_ii(2996,(1902144|0))|0);
                $233 = __THREW__; __THREW__ = 0;
                $234 = $233&1;
                if (!($234)) {
                 __THREW__ = 0;
                 $235 = (invoke_iii(2724,(1902144|0),($L_62|0))|0);
                 $236 = __THREW__; __THREW__ = 0;
                 $237 = $236&1;
                 if (!($237)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($235|0));
                  $238 = __THREW__; __THREW__ = 0;
                  $239 = $238&1;
                  if (!($239)) {
                   __THREW__ = 0;
                   invoke_vii(3491,(2176768|0),($235|0));
                   $240 = __THREW__; __THREW__ = 0;
                   $241 = $240&1;
                   if ($241) {
                    break;
                   }
                   $cond5 = ($leaveInstructions$sroa$0$1|0)==(438);
                   if ($cond5) {
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                   __THREW__ = 0;
                   invoke_vi(3844,($__last_unhandled_exception$1|0));
                   $242 = __THREW__; __THREW__ = 0;
                   $243 = $242&1;
                   if ($243) {
                    break;
                   }
                   // unreachable;
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $$07 = $8;$$08 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$07|0);
 // unreachable;
}
function __Z51UnityEngine_UnityEngine_GUILayoutGroup_m_CalcHeightP38UnityEngine_UnityEngine_GUILayoutGroup($__this) {
 $__this = $__this|0;
 var $$ = 0, $$0 = 0, $$04 = 0, $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = Math_fround(0), $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = Math_fround(0), $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0, $127 = 0, $128 = Math_fround(0), $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = Math_fround(0), $133 = 0, $134 = 0, $135 = Math_fround(0), $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = Math_fround(0), $165 = Math_fround(0), $166 = 0;
 var $167 = 0, $168 = Math_fround(0), $169 = 0, $17 = 0, $170 = 0, $171 = Math_fround(0), $172 = Math_fround(0), $173 = 0, $174 = 0, $175 = Math_fround(0), $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = Math_fround(0), $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0;
 var $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0;
 var $257 = 0, $258 = 0, $259 = Math_fround(0), $26 = 0, $260 = Math_fround(0), $261 = Math_fround(0), $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = Math_fround(0), $268 = Math_fround(0), $269 = Math_fround(0), $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0;
 var $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0;
 var $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0;
 var $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = Math_fround(0), $325 = 0, $326 = 0, $327 = 0, $328 = 0;
 var $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = Math_fround(0), $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0;
 var $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = Math_fround(0), $355 = Math_fround(0), $356 = Math_fround(0), $357 = Math_fround(0), $358 = Math_fround(0), $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = Math_fround(0), $363 = 0, $364 = 0;
 var $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = Math_fround(0), $382 = Math_fround(0);
 var $383 = Math_fround(0), $384 = 0, $385 = Math_fround(0), $386 = Math_fround(0), $387 = Math_fround(0), $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = Math_fround(0), $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0;
 var $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = 0, $406 = 0, $407 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = 0, $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = 0;
 var $89 = 0, $9 = 0, $90 = Math_fround(0), $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $L_115 = 0, $L_18 = 0, $L_67 = 0, $L_91 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_0$2 = 0, $V_0$3 = 0;
 var $V_0$4 = 0, $V_0$5 = 0, $V_1$0 = 0, $V_1$1 = 0, $V_1$2 = 0, $V_1$3 = 0, $V_1$4 = 0, $V_1$5 = 0, $V_10 = 0, $V_12$0 = Math_fround(0), $V_13$0 = Math_fround(0), $V_2$0 = 0, $V_2$0$ph = 0, $V_2$1$ph = 0, $V_2$2 = 0, $V_3$1$off0$ph = 0, $V_5 = 0, $V_7$0 = Math_fround(0), $V_8$1$off0 = 0, $V_8$2$off0 = 0;
 var $__last_unhandled_exception$0 = 0, $__last_unhandled_exception$1 = 0, $_stackTraceSentry = 0, $cond1 = 0, $cond3 = 0, $leaveInstructions$sroa$0$0 = 0, $leaveInstructions$sroa$0$1 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $_stackTraceSentry = sp + 96|0;
 $V_5 = sp;
 $V_10 = sp + 16|0;
 $L_18 = sp + 32|0;
 $L_67 = sp + 48|0;
 $L_91 = sp + 64|0;
 $L_115 = sp + 80|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726944);
 ;HEAP32[$V_5+0>>2]=0|0;HEAP32[$V_5+4>>2]=0|0;HEAP32[$V_5+8>>2]=0|0;HEAP32[$V_5+12>>2]=0|0;
 ;HEAP32[$V_10+0>>2]=0|0;HEAP32[$V_10+4>>2]=0|0;HEAP32[$V_10+8>>2]=0|0;HEAP32[$V_10+12>>2]=0|0;
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_iii(2729,(1905272|0),($1|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)==(0);
    if ($7) {
     __THREW__ = 0;
     $10 = (invoke_ii(2550,($__this|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($10|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     $15 = (invoke_ii(2593,($10|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($15|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(2588,($15|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     $23 = (Math_fround(($20|0)));
     $24 = (($__this) + 16|0);
     HEAPF32[$24>>2] = $23;
     $25 = (($__this) + 20|0);
     HEAPF32[$25>>2] = $23;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $26 = (($__this) + 100|0);
    HEAPF32[$26>>2] = Math_fround(0.0);
    $27 = (($__this) + 96|0);
    HEAPF32[$27>>2] = Math_fround(0.0);
    $28 = (($__this) + 80|0);
    HEAP32[$28>>2] = 0;
    $29 = (($__this) + 56|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = ($30<<24>>24)==(0);
    $32 = HEAP32[$0>>2]|0;
    if ($31) {
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $199 = __THREW__; __THREW__ = 0;
     $200 = $199&1;
     if ($200) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1633,($L_91|0),($32|0));
     $201 = __THREW__; __THREW__ = 0;
     $202 = $201&1;
     if ($202) {
      break;
     }
     ;HEAP32[$V_10+0>>2]=HEAP32[$L_91+0>>2]|0;HEAP32[$V_10+4>>2]=HEAP32[$L_91+4>>2]|0;HEAP32[$V_10+8>>2]=HEAP32[$L_91+8>>2]|0;HEAP32[$V_10+12>>2]=HEAP32[$L_91+12>>2]|0;
     $V_0$3 = 0;$V_1$3 = 0;$V_8$2$off0 = 1;
     while(1) {
      __THREW__ = 0;
      $282 = (invoke_ii(3478,($V_10|0))|0);
      $283 = __THREW__; __THREW__ = 0;
      $284 = $283&1;
      if ($284) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      if (!($282)) {
       $V_0$4 = $V_0$3;$V_1$4 = $V_1$3;$__last_unhandled_exception$1 = 0;$leaveInstructions$sroa$0$1 = 688;
       break;
      }
      __THREW__ = 0;
      $203 = (invoke_ii(3468,($V_10|0))|0);
      $285 = __THREW__; __THREW__ = 0;
      $286 = $285&1;
      if ($286) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($203|0));
      $204 = __THREW__; __THREW__ = 0;
      $205 = $204&1;
      if ($205) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      __THREW__ = 0;
      invoke_vii(3495,(2728784|0),($203|0));
      $206 = __THREW__; __THREW__ = 0;
      $207 = $206&1;
      if ($207) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($203|0));
      $208 = __THREW__; __THREW__ = 0;
      $209 = $208&1;
      if ($209) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      __THREW__ = 0;
      $210 = (invoke_iii(2730,(2728688|0),($203|0))|0);
      $211 = __THREW__; __THREW__ = 0;
      $212 = $211&1;
      if ($212) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($203|0));
      $213 = __THREW__; __THREW__ = 0;
      $214 = $213&1;
      if ($214) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      __THREW__ = 0;
      $215 = (invoke_ii(2550,($203|0))|0);
      $216 = __THREW__; __THREW__ = 0;
      $217 = $216&1;
      if ($217) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      __THREW__ = 0;
      $218 = (invoke_ii(2549,0)|0);
      $219 = __THREW__; __THREW__ = 0;
      $220 = $219&1;
      if ($220) {
       $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
       label = 90;
       break;
      }
      $221 = ($215|0)==($218|0);
      if ($221) {
       $V_0$2 = $V_0$3;$V_1$2 = $V_1$3;$V_8$1$off0 = $V_8$2$off0;
      } else {
       if ($V_8$2$off0) {
        __THREW__ = 0;
        invoke_vi(3799,($210|0));
        $246 = __THREW__; __THREW__ = 0;
        $247 = $246&1;
        if ($247) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 90;
         break;
        }
        __THREW__ = 0;
        $248 = (invoke_ii(2585,($210|0))|0);
        $249 = __THREW__; __THREW__ = 0;
        $250 = $249&1;
        if ($250) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 90;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($210|0));
        $251 = __THREW__; __THREW__ = 0;
        $252 = $251&1;
        if ($252) {
         $V_0$0 = $248;$V_1$0 = $V_1$3;
         label = 90;
         break;
        }
        __THREW__ = 0;
        $253 = (invoke_ii(2586,($210|0))|0);
        $254 = __THREW__; __THREW__ = 0;
        $255 = $254&1;
        if ($255) {
         $V_0$0 = $248;$V_1$0 = $V_1$3;
         label = 90;
         break;
        } else {
         $V_0$1 = $248;$V_1$1 = $253;
        }
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($210|0));
        $230 = __THREW__; __THREW__ = 0;
        $231 = $230&1;
        if ($231) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 90;
         break;
        }
        __THREW__ = 0;
        $232 = (invoke_ii(2585,($210|0))|0);
        $233 = __THREW__; __THREW__ = 0;
        $234 = $233&1;
        if ($234) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 90;
         break;
        }
        __THREW__ = 0;
        $235 = (invoke_iiii(1406,(0|0),($232|0),($V_0$3|0))|0);
        $236 = __THREW__; __THREW__ = 0;
        $237 = $236&1;
        if ($237) {
         $V_0$0 = $V_0$3;$V_1$0 = $V_1$3;
         label = 90;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($210|0));
        $238 = __THREW__; __THREW__ = 0;
        $239 = $238&1;
        if ($239) {
         $V_0$0 = $235;$V_1$0 = $V_1$3;
         label = 90;
         break;
        }
        __THREW__ = 0;
        $240 = (invoke_ii(2586,($210|0))|0);
        $241 = __THREW__; __THREW__ = 0;
        $242 = $241&1;
        if ($242) {
         $V_0$0 = $235;$V_1$0 = $V_1$3;
         label = 90;
         break;
        }
        __THREW__ = 0;
        $243 = (invoke_iiii(1406,(0|0),($240|0),($V_1$3|0))|0);
        $244 = __THREW__; __THREW__ = 0;
        $245 = $244&1;
        if ($245) {
         $V_0$0 = $235;$V_1$0 = $V_1$3;
         label = 90;
         break;
        } else {
         $V_0$1 = $235;$V_1$1 = $243;
        }
       }
       __THREW__ = 0;
       invoke_vi(3799,($203|0));
       $256 = __THREW__; __THREW__ = 0;
       $257 = $256&1;
       if ($257) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 90;
        break;
       }
       $258 = (($203) + 16|0);
       $259 = Math_fround(HEAPF32[$258>>2]);
       $260 = Math_fround(HEAPF32[$27>>2]);
       __THREW__ = 0;
       $261 = (Math_fround(+(invoke_fiff(4,(0|0),(+$259),(+$260)))));
       $262 = __THREW__; __THREW__ = 0;
       $263 = $262&1;
       if ($263) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 90;
        break;
       }
       HEAPF32[$27>>2] = $261;
       __THREW__ = 0;
       invoke_vi(3799,($203|0));
       $264 = __THREW__; __THREW__ = 0;
       $265 = $264&1;
       if ($265) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 90;
        break;
       }
       $266 = (($203) + 20|0);
       $267 = Math_fround(HEAPF32[$266>>2]);
       $268 = Math_fround(HEAPF32[$26>>2]);
       __THREW__ = 0;
       $269 = (Math_fround(+(invoke_fiff(4,(0|0),(+$267),(+$268)))));
       $270 = __THREW__; __THREW__ = 0;
       $271 = $270&1;
       if ($271) {
        $V_0$0 = $V_0$1;$V_1$0 = $V_1$1;
        label = 90;
        break;
       }
       HEAPF32[$26>>2] = $269;
       $V_0$2 = $V_0$1;$V_1$2 = $V_1$1;$V_8$1$off0 = 0;
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $272 = __THREW__; __THREW__ = 0;
      $273 = $272&1;
      if ($273) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;
       label = 90;
       break;
      }
      $274 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($203|0));
      $275 = __THREW__; __THREW__ = 0;
      $276 = $275&1;
      if ($276) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;
       label = 90;
       break;
      }
      $277 = (($203) + 44|0);
      $278 = HEAP32[$277>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $279 = __THREW__; __THREW__ = 0;
      $280 = $279&1;
      if ($280) {
       $V_0$0 = $V_0$2;$V_1$0 = $V_1$2;
       label = 90;
       break;
      }
      $281 = (($278) + ($274))|0;
      HEAP32[$28>>2] = $281;
      $V_0$3 = $V_0$2;$V_1$3 = $V_1$2;$V_8$2$off0 = $V_8$1$off0;
     }
     if ((label|0) == 90) {
      $222 = ___cxa_find_matching_catch(348288|0)|0;
      $223 = tempRet0;
      $224 = (_llvm_eh_typeid_for((348288|0))|0);
      $225 = ($223|0)==($224|0);
      if (!($225)) {
       $$0 = $222;$$04 = $223;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$0|0);
       // unreachable;
      }
      $226 = (___cxa_begin_catch(($222|0))|0);
      $227 = HEAP32[$226>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $228 = __THREW__; __THREW__ = 0;
      $229 = $228&1;
      if ($229) {
       break;
      }
      $V_0$4 = $V_0$0;$V_1$4 = $V_1$0;$__last_unhandled_exception$1 = $227;$leaveInstructions$sroa$0$1 = 0;
     }
     ;HEAP32[$L_115+0>>2]=HEAP32[$V_10+0>>2]|0;HEAP32[$L_115+4>>2]=HEAP32[$V_10+4>>2]|0;HEAP32[$L_115+8>>2]=HEAP32[$V_10+8>>2]|0;HEAP32[$L_115+12>>2]=HEAP32[$V_10+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1902144|0))|0);
     $287 = __THREW__; __THREW__ = 0;
     $288 = $287&1;
     if ($288) {
      break;
     }
     __THREW__ = 0;
     $289 = (invoke_iii(2724,(1902144|0),($L_115|0))|0);
     $290 = __THREW__; __THREW__ = 0;
     $291 = $290&1;
     if ($291) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($289|0));
     $292 = __THREW__; __THREW__ = 0;
     $293 = $292&1;
     if ($293) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(3491,(2176768|0),($289|0));
     $294 = __THREW__; __THREW__ = 0;
     $295 = $294&1;
     if ($295) {
      break;
     }
     $cond1 = ($leaveInstructions$sroa$0$1|0)==(688);
     if ($cond1) {
      $V_0$5 = $V_0$4;$V_1$5 = $V_1$4;
     } else {
      __THREW__ = 0;
      invoke_vi(3844,($__last_unhandled_exception$1|0));
      $296 = __THREW__; __THREW__ = 0;
      $297 = $296&1;
      if ($297) {
       break;
      }
      // unreachable;
     }
    } else {
     __THREW__ = 0;
     invoke_vi(3799,($32|0));
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if ($34) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1633,($L_18|0),($32|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      break;
     }
     ;HEAP32[$V_5+0>>2]=HEAP32[$L_18+0>>2]|0;HEAP32[$V_5+4>>2]=HEAP32[$L_18+4>>2]|0;HEAP32[$V_5+8>>2]=HEAP32[$L_18+8>>2]|0;HEAP32[$V_5+12>>2]=HEAP32[$L_18+12>>2]|0;
     $37 = (($__this) + 60|0);
     $V_2$1$ph = 0;$V_3$1$off0$ph = 1;
     L17: while(1) {
      while(1) {
       __THREW__ = 0;
       $146 = (invoke_ii(3478,($V_5|0))|0);
       $147 = __THREW__; __THREW__ = 0;
       $148 = $147&1;
       if ($148) {
        label = 24;
        break L17;
       }
       if (!($146)) {
        $V_2$2 = $V_2$1$ph;$__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 375;
        break L17;
       }
       __THREW__ = 0;
       $38 = (invoke_ii(3468,($V_5|0))|0);
       $149 = __THREW__; __THREW__ = 0;
       $150 = $149&1;
       if ($150) {
        label = 24;
        break L17;
       }
       __THREW__ = 0;
       invoke_vi(3799,($38|0));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        label = 24;
        break L17;
       }
       __THREW__ = 0;
       invoke_vii(3495,(2728784|0),($38|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if ($42) {
        label = 24;
        break L17;
       }
       __THREW__ = 0;
       invoke_vi(3799,($38|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        label = 24;
        break L17;
       }
       __THREW__ = 0;
       $45 = (invoke_iii(2730,(2728688|0),($38|0))|0);
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        label = 24;
        break L17;
       }
       __THREW__ = 0;
       invoke_vi(3799,($38|0));
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        label = 24;
        break L17;
       }
       __THREW__ = 0;
       $50 = (invoke_ii(2550,($38|0))|0);
       $51 = __THREW__; __THREW__ = 0;
       $52 = $51&1;
       if ($52) {
        label = 24;
        break L17;
       }
       __THREW__ = 0;
       $53 = (invoke_ii(2549,0)|0);
       $54 = __THREW__; __THREW__ = 0;
       $55 = $54&1;
       if ($55) {
        label = 24;
        break L17;
       }
       $56 = ($50|0)==($53|0);
       if (!($56)) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $116 = __THREW__; __THREW__ = 0;
       $117 = $116&1;
       if ($117) {
        label = 24;
        break L17;
       }
       $118 = Math_fround(HEAPF32[$27>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($38|0));
       $119 = __THREW__; __THREW__ = 0;
       $120 = $119&1;
       if ($120) {
        label = 24;
        break L17;
       }
       $121 = (($38) + 16|0);
       $122 = Math_fround(HEAPF32[$121>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $123 = __THREW__; __THREW__ = 0;
       $124 = $123&1;
       if ($124) {
        label = 24;
        break L17;
       }
       $125 = Math_fround($118 + $122);
       HEAPF32[$27>>2] = $125;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $126 = __THREW__; __THREW__ = 0;
       $127 = $126&1;
       if ($127) {
        label = 24;
        break L17;
       }
       $128 = Math_fround(HEAPF32[$26>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($38|0));
       $129 = __THREW__; __THREW__ = 0;
       $130 = $129&1;
       if ($130) {
        label = 24;
        break L17;
       }
       $131 = (($38) + 20|0);
       $132 = Math_fround(HEAPF32[$131>>2]);
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $133 = __THREW__; __THREW__ = 0;
       $134 = $133&1;
       if ($134) {
        label = 24;
        break L17;
       }
       $135 = Math_fround($128 + $132);
       HEAPF32[$26>>2] = $135;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $136 = __THREW__; __THREW__ = 0;
       $137 = $136&1;
       if ($137) {
        label = 24;
        break L17;
       }
       $138 = HEAP32[$28>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($38|0));
       $139 = __THREW__; __THREW__ = 0;
       $140 = $139&1;
       if ($140) {
        label = 24;
        break L17;
       }
       $141 = (($38) + 44|0);
       $142 = HEAP32[$141>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($__this|0));
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        label = 24;
        break L17;
       }
       $145 = (($142) + ($138))|0;
       HEAP32[$28>>2] = $145;
      }
      if ($V_3$1$off0$ph) {
       $V_7$0 = Math_fround(0.0);
      } else {
       __THREW__ = 0;
       invoke_vi(3799,($45|0));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        $V_2$0$ph = $V_2$1$ph;
        label = 25;
        break;
       }
       __THREW__ = 0;
       $69 = (invoke_ii(2585,($45|0))|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        $V_2$0$ph = $V_2$1$ph;
        label = 25;
        break;
       }
       __THREW__ = 0;
       $72 = (invoke_iiii(1407,(0|0),($V_2$1$ph|0),($69|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        $V_2$0$ph = $V_2$1$ph;
        label = 25;
        break;
       }
       $phitmp = (Math_fround(($72|0)));
       $V_7$0 = $phitmp;
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       $V_2$0$ph = $V_2$1$ph;
       label = 25;
       break;
      }
      $77 = Math_fround(HEAPF32[$27>>2]);
      __THREW__ = 0;
      invoke_vi(3799,($38|0));
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       $V_2$0$ph = $V_2$1$ph;
       label = 25;
       break;
      }
      $80 = (($38) + 16|0);
      $81 = Math_fround(HEAPF32[$80>>2]);
      $82 = Math_fround(HEAPF32[$37>>2]);
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $83 = __THREW__; __THREW__ = 0;
      $84 = $83&1;
      if ($84) {
       $V_2$0$ph = $V_2$1$ph;
       label = 25;
       break;
      }
      $85 = Math_fround($81 + $82);
      $86 = Math_fround($V_7$0 + $85);
      $87 = Math_fround($77 + $86);
      HEAPF32[$27>>2] = $87;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $88 = __THREW__; __THREW__ = 0;
      $89 = $88&1;
      if ($89) {
       $V_2$0$ph = $V_2$1$ph;
       label = 25;
       break;
      }
      $90 = Math_fround(HEAPF32[$26>>2]);
      __THREW__ = 0;
      invoke_vi(3799,($38|0));
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if ($92) {
       $V_2$0$ph = $V_2$1$ph;
       label = 25;
       break;
      }
      $93 = (($38) + 20|0);
      $94 = Math_fround(HEAPF32[$93>>2]);
      $95 = Math_fround(HEAPF32[$37>>2]);
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $96 = __THREW__; __THREW__ = 0;
      $97 = $96&1;
      if ($97) {
       $V_2$0$ph = $V_2$1$ph;
       label = 25;
       break;
      }
      $98 = Math_fround($94 + $95);
      $99 = Math_fround($V_7$0 + $98);
      $100 = Math_fround($90 + $99);
      HEAPF32[$26>>2] = $100;
      __THREW__ = 0;
      invoke_vi(3799,($45|0));
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       $V_2$0$ph = $V_2$1$ph;
       label = 25;
       break;
      }
      __THREW__ = 0;
      $103 = (invoke_ii(2586,($45|0))|0);
      $104 = __THREW__; __THREW__ = 0;
      $105 = $104&1;
      if ($105) {
       $V_2$0$ph = $V_2$1$ph;
       label = 25;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       $V_2$0$ph = $103;
       label = 25;
       break;
      }
      $108 = HEAP32[$28>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($38|0));
      $109 = __THREW__; __THREW__ = 0;
      $110 = $109&1;
      if ($110) {
       $V_2$0$ph = $103;
       label = 25;
       break;
      }
      $111 = (($38) + 44|0);
      $112 = HEAP32[$111>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($__this|0));
      $113 = __THREW__; __THREW__ = 0;
      $114 = $113&1;
      if ($114) {
       $V_2$0$ph = $103;
       label = 25;
       break;
      }
      $115 = (($112) + ($108))|0;
      HEAP32[$28>>2] = $115;
      $V_2$1$ph = $103;$V_3$1$off0$ph = 0;
     }
     if ((label|0) == 24) {
      $57 = ___cxa_find_matching_catch(348288|0)|0;
      $58 = tempRet0;
      $V_2$0 = $V_2$1$ph;$lpad$phi$index = $57;$lpad$phi$index2 = $58;
      label = 26;
     }
     else if ((label|0) == 25) {
      $59 = ___cxa_find_matching_catch(348288|0)|0;
      $60 = tempRet0;
      $V_2$0 = $V_2$0$ph;$lpad$phi$index = $59;$lpad$phi$index2 = $60;
      label = 26;
     }
     if ((label|0) == 26) {
      $61 = (_llvm_eh_typeid_for((348288|0))|0);
      $62 = ($lpad$phi$index2|0)==($61|0);
      if (!($62)) {
       $$0 = $lpad$phi$index;$$04 = $lpad$phi$index2;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$0|0);
       // unreachable;
      }
      $63 = (___cxa_begin_catch(($lpad$phi$index|0))|0);
      $64 = HEAP32[$63>>2]|0;
      __THREW__ = 0;
      invoke_v(66);
      $65 = __THREW__; __THREW__ = 0;
      $66 = $65&1;
      if ($66) {
       break;
      }
      $V_2$2 = $V_2$0;$__last_unhandled_exception$0 = $64;$leaveInstructions$sroa$0$0 = 0;
     }
     ;HEAP32[$L_67+0>>2]=HEAP32[$V_5+0>>2]|0;HEAP32[$L_67+4>>2]=HEAP32[$V_5+4>>2]|0;HEAP32[$L_67+8>>2]=HEAP32[$V_5+8>>2]|0;HEAP32[$L_67+12>>2]=HEAP32[$V_5+12>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(1902144|0))|0);
     $151 = __THREW__; __THREW__ = 0;
     $152 = $151&1;
     if ($152) {
      break;
     }
     __THREW__ = 0;
     $153 = (invoke_iii(2724,(1902144|0),($L_67|0))|0);
     $154 = __THREW__; __THREW__ = 0;
     $155 = $154&1;
     if ($155) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($153|0));
     $156 = __THREW__; __THREW__ = 0;
     $157 = $156&1;
     if ($157) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(3491,(2176768|0),($153|0));
     $158 = __THREW__; __THREW__ = 0;
     $159 = $158&1;
     if ($159) {
      break;
     }
     $cond3 = ($leaveInstructions$sroa$0$0|0)==(375);
     if (!($cond3)) {
      __THREW__ = 0;
      invoke_vi(3844,($__last_unhandled_exception$0|0));
      $160 = __THREW__; __THREW__ = 0;
      $161 = $160&1;
      if ($161) {
       break;
      }
      // unreachable;
     }
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $162 = __THREW__; __THREW__ = 0;
     $163 = $162&1;
     if ($163) {
      break;
     }
     $164 = Math_fround(HEAPF32[$27>>2]);
     $165 = Math_fround(HEAPF32[$37>>2]);
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $166 = __THREW__; __THREW__ = 0;
     $167 = $166&1;
     if ($167) {
      break;
     }
     $168 = Math_fround($164 - $165);
     HEAPF32[$27>>2] = $168;
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $169 = __THREW__; __THREW__ = 0;
     $170 = $169&1;
     if ($170) {
      break;
     }
     $171 = Math_fround(HEAPF32[$26>>2]);
     $172 = Math_fround(HEAPF32[$37>>2]);
     __THREW__ = 0;
     invoke_vi(3799,($__this|0));
     $173 = __THREW__; __THREW__ = 0;
     $174 = $173&1;
     if ($174) {
      break;
     }
     $175 = Math_fround($171 - $172);
     HEAPF32[$26>>2] = $175;
     $176 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vi(3799,($176|0));
     $177 = __THREW__; __THREW__ = 0;
     $178 = $177&1;
     if ($178) {
      break;
     }
     __THREW__ = 0;
     $179 = (invoke_iii(2729,(1905272|0),($176|0))|0);
     $180 = __THREW__; __THREW__ = 0;
     $181 = $180&1;
     if ($181) {
      break;
     }
     $182 = ($179|0)==(0);
     if ($182) {
      $V_0$5 = 0;$V_1$5 = 0;
     } else {
      $183 = HEAP32[$0>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($183|0));
      $184 = __THREW__; __THREW__ = 0;
      $185 = $184&1;
      if ($185) {
       break;
      }
      __THREW__ = 0;
      $186 = (invoke_iiii(1642,(1905336|0),($183|0),0)|0);
      $187 = __THREW__; __THREW__ = 0;
      $188 = $187&1;
      if ($188) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($186|0));
      $189 = __THREW__; __THREW__ = 0;
      $190 = $189&1;
      if ($190) {
       break;
      }
      __THREW__ = 0;
      $191 = (invoke_iii(2730,(2728688|0),($186|0))|0);
      $192 = __THREW__; __THREW__ = 0;
      $193 = $192&1;
      if ($193) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($191|0));
      $194 = __THREW__; __THREW__ = 0;
      $195 = $194&1;
      if ($195) {
       break;
      }
      __THREW__ = 0;
      $196 = (invoke_ii(2585,($191|0))|0);
      $197 = __THREW__; __THREW__ = 0;
      $198 = $197&1;
      if ($198) {
       break;
      } else {
       $V_0$5 = $196;$V_1$5 = $V_2$2;
      }
     }
    }
    __THREW__ = 0;
    $298 = (invoke_ii(2550,($__this|0))|0);
    $299 = __THREW__; __THREW__ = 0;
    $300 = $299&1;
    if (!($300)) {
     __THREW__ = 0;
     $301 = (invoke_ii(2596,0)|0);
     $302 = __THREW__; __THREW__ = 0;
     $303 = $302&1;
     if (!($303)) {
      $304 = ($298|0)==($301|0);
      if ($304) {
       $305 = (($__this) + 85|0);
       $306 = HEAP8[$305>>0]|0;
       $307 = ($306<<24>>24)==(0);
       if ($307) {
        $342 = (($__this) + 104|0);
        $343 = HEAP32[$342>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($343|0));
        $344 = __THREW__; __THREW__ = 0;
        $345 = $344&1;
        if ($345) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(2059,($343|0),($V_0$5|0));
        $346 = __THREW__; __THREW__ = 0;
        $347 = $346&1;
        if ($347) {
         break;
        }
        $348 = HEAP32[$342>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($348|0));
        $349 = __THREW__; __THREW__ = 0;
        $350 = $349&1;
        if ($350) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(2060,($348|0),($V_1$5|0));
        $351 = __THREW__; __THREW__ = 0;
        $352 = $351&1;
        if ($352) {
         break;
        } else {
         $V_12$0 = Math_fround(0.0);$V_13$0 = Math_fround(0.0);
        }
       } else {
        label = 127;
       }
      } else {
       label = 127;
      }
      if ((label|0) == 127) {
       __THREW__ = 0;
       $308 = (invoke_ii(2550,($__this|0))|0);
       $309 = __THREW__; __THREW__ = 0;
       $310 = $309&1;
       if ($310) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($308|0));
       $311 = __THREW__; __THREW__ = 0;
       $312 = $311&1;
       if ($312) {
        break;
       }
       __THREW__ = 0;
       $313 = (invoke_ii(2593,($308|0))|0);
       $314 = __THREW__; __THREW__ = 0;
       $315 = $314&1;
       if ($315) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($313|0));
       $316 = __THREW__; __THREW__ = 0;
       $317 = $316&1;
       if ($317) {
        break;
       }
       __THREW__ = 0;
       $318 = (invoke_ii(2585,($313|0))|0);
       $319 = __THREW__; __THREW__ = 0;
       $320 = $319&1;
       if ($320) {
        break;
       }
       __THREW__ = 0;
       $321 = (invoke_iiii(1407,(0|0),($318|0),($V_0$5|0))|0);
       $322 = __THREW__; __THREW__ = 0;
       $323 = $322&1;
       if ($323) {
        break;
       }
       $324 = (Math_fround(($321|0)));
       __THREW__ = 0;
       $325 = (invoke_ii(2550,($__this|0))|0);
       $326 = __THREW__; __THREW__ = 0;
       $327 = $326&1;
       if ($327) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($325|0));
       $328 = __THREW__; __THREW__ = 0;
       $329 = $328&1;
       if ($329) {
        break;
       }
       __THREW__ = 0;
       $330 = (invoke_ii(2593,($325|0))|0);
       $331 = __THREW__; __THREW__ = 0;
       $332 = $331&1;
       if ($332) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3799,($330|0));
       $333 = __THREW__; __THREW__ = 0;
       $334 = $333&1;
       if ($334) {
        break;
       }
       __THREW__ = 0;
       $335 = (invoke_ii(2586,($330|0))|0);
       $336 = __THREW__; __THREW__ = 0;
       $337 = $336&1;
       if ($337) {
        break;
       }
       __THREW__ = 0;
       $338 = (invoke_iiii(1407,(0|0),($335|0),($V_1$5|0))|0);
       $339 = __THREW__; __THREW__ = 0;
       $340 = $339&1;
       if ($340) {
        break;
       }
       $341 = (Math_fround(($338|0)));
       $V_12$0 = $324;$V_13$0 = $341;
      }
      $353 = (($__this) + 16|0);
      $354 = Math_fround(HEAPF32[$353>>2]);
      $355 = Math_fround(HEAPF32[$27>>2]);
      $356 = Math_fround($V_12$0 + $355);
      $357 = Math_fround($V_13$0 + $356);
      __THREW__ = 0;
      $358 = (Math_fround(+(invoke_fiff(4,(0|0),(+$354),(+$357)))));
      $359 = __THREW__; __THREW__ = 0;
      $360 = $359&1;
      if (!($360)) {
       HEAPF32[$353>>2] = $358;
       $361 = (($__this) + 20|0);
       $362 = Math_fround(HEAPF32[$361>>2]);
       $363 = $362 != Math_fround(0.0);
       if ($363) {
        $384 = (($__this) + 44|0);
        HEAP32[$384>>2] = 0;
        $385 = $362;$386 = $358;
       } else {
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $364 = __THREW__; __THREW__ = 0;
        $365 = $364&1;
        if ($365) {
         break;
        }
        $366 = (($__this) + 44|0);
        $367 = HEAP32[$366>>2]|0;
        $368 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $369 = (invoke_ii(2550,($__this|0))|0);
        $370 = __THREW__; __THREW__ = 0;
        $371 = $370&1;
        if ($371) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($369|0));
        $372 = __THREW__; __THREW__ = 0;
        $373 = $372&1;
        if ($373) {
         break;
        }
        __THREW__ = 0;
        $374 = (invoke_ii(2595,($369|0))|0);
        $375 = __THREW__; __THREW__ = 0;
        $376 = $375&1;
        if ($376) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($__this|0));
        $377 = __THREW__; __THREW__ = 0;
        $378 = $377&1;
        if ($378) {
         break;
        }
        $$ = $374&1;
        $379 = (($368) + ($367))|0;
        $380 = (($379) + ($$))|0;
        HEAP32[$366>>2] = $380;
        $381 = Math_fround(HEAPF32[$26>>2]);
        $382 = Math_fround($V_12$0 + $381);
        $383 = Math_fround($V_13$0 + $382);
        HEAPF32[$361>>2] = $383;
        $$pre = Math_fround(HEAPF32[$353>>2]);
        $385 = $383;$386 = $$pre;
       }
       __THREW__ = 0;
       $387 = (Math_fround(+(invoke_fiff(4,(0|0),(+$385),(+$386)))));
       $388 = __THREW__; __THREW__ = 0;
       $389 = $388&1;
       if (!($389)) {
        HEAPF32[$361>>2] = $387;
        __THREW__ = 0;
        $390 = (invoke_ii(2550,($__this|0))|0);
        $391 = __THREW__; __THREW__ = 0;
        $392 = $391&1;
        if (!($392)) {
         __THREW__ = 0;
         invoke_vi(3799,($390|0));
         $393 = __THREW__; __THREW__ = 0;
         $394 = $393&1;
         if (!($394)) {
          __THREW__ = 0;
          $395 = (Math_fround(+(invoke_fi(135,($390|0)))));
          $396 = __THREW__; __THREW__ = 0;
          $397 = $396&1;
          if (!($397)) {
           $398 = $395 == Math_fround(0.0);
           if ($398) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           $399 = (invoke_ii(2550,($__this|0))|0);
           $400 = __THREW__; __THREW__ = 0;
           $401 = $400&1;
           if (!($401)) {
            __THREW__ = 0;
            invoke_vi(3799,($399|0));
            $402 = __THREW__; __THREW__ = 0;
            $403 = $402&1;
            if (!($403)) {
             __THREW__ = 0;
             $404 = (Math_fround(+(invoke_fi(135,($399|0)))));
             $405 = __THREW__; __THREW__ = 0;
             $406 = $405&1;
             if (!($406)) {
              HEAPF32[$353>>2] = $404;
              HEAPF32[$361>>2] = $404;
              $407 = (($__this) + 44|0);
              HEAP32[$407>>2] = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $$0 = $8;$$04 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_RectOffset_m_get_verticalP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2745392);
 $0 = HEAP32[2745440>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2745448|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2745440>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52UnityEngine_UnityEngine_GUILayoutGroup_m_SetVerticalP38UnityEngine_UnityEngine_GUILayoutGroupff($__this,$y,$height) {
 $__this = $__this|0;
 $y = Math_fround($y);
 $height = Math_fround($height);
 var $$ = 0, $$06 = Math_fround(0), $$07 = 0, $$08 = 0, $$1 = Math_fround(0), $$2 = Math_fround(0), $$3 = Math_fround(0), $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = Math_fround(0), $101 = 0, $102 = Math_fround(0), $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = 0, $116 = Math_fround(0), $117 = 0, $118 = Math_fround(0), $119 = Math_fround(0), $12 = 0, $120 = Math_fround(0), $121 = Math_fround(0), $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0;
 var $127 = 0, $128 = 0, $129 = Math_fround(0), $13 = 0, $130 = Math_fround(0), $131 = Math_fround(0), $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = Math_fround(0), $142 = 0, $143 = 0, $144 = 0;
 var $145 = Math_fround(0), $146 = Math_fround(0), $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = Math_fround(0), $185 = Math_fround(0), $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = Math_fround(0), $197 = 0, $198 = 0, $199 = Math_fround(0);
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = Math_fround(0), $207 = Math_fround(0), $208 = Math_fround(0), $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = Math_fround(0), $257 = Math_fround(0), $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = Math_fround(0), $277 = Math_fround(0), $278 = Math_fround(0), $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = Math_fround(0), $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = Math_fround(0), $304 = Math_fround(0), $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = Math_fround(0), $336 = Math_fround(0), $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = Math_fround(0), $346 = Math_fround(0), $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = Math_fround(0), $377 = Math_fround(0), $378 = 0, $379 = 0;
 var $38 = Math_fround(0), $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = Math_fround(0), $391 = Math_fround(0), $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = Math_fround(0), $405 = Math_fround(0), $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = Math_fround(0), $417 = Math_fround(0), $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = Math_fround(0), $422 = 0, $423 = 0, $424 = 0, $425 = Math_fround(0), $426 = Math_fround(0), $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = Math_fround(0), $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = Math_fround(0), $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = Math_fround(0), $95 = Math_fround(0), $96 = 0, $97 = 0, $98 = Math_fround(0), $99 = Math_fround(0), $G_B22_0$0 = 0, $L_117 = 0, $L_128 = 0;
 var $L_151 = 0, $L_67 = 0, $L_92 = 0, $L_97 = 0, $V_1$0 = Math_fround(0), $V_14 = 0, $V_2$0 = Math_fround(0), $V_21 = 0, $V_4$0 = Math_fround(0), $V_5$0 = Math_fround(0), $V_6$0 = 0, $V_6$1 = 0, $V_7$1$off0 = 0, $V_7$2$off0 = 0, $V_9 = 0, $__last_unhandled_exception$0 = 0, $__last_unhandled_exception$1 = 0, $__last_unhandled_exception$2 = 0, $_stackTraceSentry = 0, $cond1 = 0;
 var $cond3 = 0, $cond5 = 0, $leaveInstructions$sroa$0$0 = 0, $leaveInstructions$sroa$0$1 = 0, $leaveInstructions$sroa$0$2 = 0, $y$ = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $_stackTraceSentry = sp + 144|0;
 $V_9 = sp + 128|0;
 $V_14 = sp + 112|0;
 $V_21 = sp + 96|0;
 $L_67 = sp + 80|0;
 $L_92 = sp + 64|0;
 $L_97 = sp + 32|0;
 $L_117 = sp + 16|0;
 $L_128 = sp;
 $L_151 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2726992);
 ;HEAP32[$V_9+0>>2]=0|0;HEAP32[$V_9+4>>2]=0|0;HEAP32[$V_9+8>>2]=0|0;HEAP32[$V_9+12>>2]=0|0;
 ;HEAP32[$V_14+0>>2]=0|0;HEAP32[$V_14+4>>2]=0|0;HEAP32[$V_14+8>>2]=0|0;HEAP32[$V_14+12>>2]=0|0;
 ;HEAP32[$V_21+0>>2]=0|0;HEAP32[$V_21+4>>2]=0|0;HEAP32[$V_21+8>>2]=0|0;HEAP32[$V_21+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viff(12,($__this|0),(+$y),(+$height));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 52|0);
   $3 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($3|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    $6 = (invoke_iii(2729,(1905272|0),($3|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = ($6|0)==(0);
     if ($9) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     $12 = (invoke_ii(2550,($__this|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3799,($12|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_ii(2593,($12|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        $20 = (($__this) + 57|0);
        $21 = HEAP8[$20>>0]|0;
        $22 = ($21<<24>>24)==(0);
        $y$ = $22 ? $y : Math_fround(0.0);
        $23 = (($__this) + 56|0);
        $24 = HEAP8[$23>>0]|0;
        $25 = ($24<<24>>24)==(0);
        if (!($25)) {
         __THREW__ = 0;
         $26 = (invoke_ii(2550,($__this|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          break;
         }
         __THREW__ = 0;
         $29 = (invoke_ii(2596,0)|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          break;
         }
         $32 = ($26|0)==($29|0);
         if ($32) {
          $$06 = $height;$$1 = $y$;
         } else {
          __THREW__ = 0;
          invoke_vi(3799,($17|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          __THREW__ = 0;
          $35 = (invoke_ii(2585,($17|0))|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           break;
          }
          $38 = (Math_fround(($35|0)));
          __THREW__ = 0;
          invoke_vi(3799,($17|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
          __THREW__ = 0;
          $41 = (invoke_ii(2586,($17|0))|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          $44 = (Math_fround(($41|0)));
          $45 = HEAP32[$2>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($45|0));
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          $48 = (invoke_iii(2729,(1905272|0),($45|0))|0);
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
          $51 = ($48|0)==(0);
          if ($51) {
           $V_1$0 = $38;$V_2$0 = $44;
          } else {
           $52 = HEAP32[$2>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($52|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if ($54) {
            break;
           }
           __THREW__ = 0;
           $55 = (invoke_iiii(1642,(1905336|0),($52|0),0)|0);
           $56 = __THREW__; __THREW__ = 0;
           $57 = $56&1;
           if ($57) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($55|0));
           $58 = __THREW__; __THREW__ = 0;
           $59 = $58&1;
           if ($59) {
            break;
           }
           __THREW__ = 0;
           $60 = (invoke_iii(2730,(2728688|0),($55|0))|0);
           $61 = __THREW__; __THREW__ = 0;
           $62 = $61&1;
           if ($62) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($60|0));
           $63 = __THREW__; __THREW__ = 0;
           $64 = $63&1;
           if ($64) {
            break;
           }
           __THREW__ = 0;
           $65 = (invoke_ii(2585,($60|0))|0);
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            break;
           }
           $68 = (Math_fround(($65|0)));
           __THREW__ = 0;
           $69 = (Math_fround(+(invoke_fiff(4,(0|0),(+$38),(+$68)))));
           $70 = __THREW__; __THREW__ = 0;
           $71 = $70&1;
           if ($71) {
            break;
           }
           $72 = HEAP32[$2>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($72|0));
           $73 = __THREW__; __THREW__ = 0;
           $74 = $73&1;
           if ($74) {
            break;
           }
           __THREW__ = 0;
           $75 = (invoke_iii(2729,(1905272|0),($72|0))|0);
           $76 = __THREW__; __THREW__ = 0;
           $77 = $76&1;
           if ($77) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($72|0));
           $78 = __THREW__; __THREW__ = 0;
           $79 = $78&1;
           if ($79) {
            break;
           }
           $80 = (($75) + -1)|0;
           __THREW__ = 0;
           $81 = (invoke_iiii(1642,(1905336|0),($72|0),($80|0))|0);
           $82 = __THREW__; __THREW__ = 0;
           $83 = $82&1;
           if ($83) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($81|0));
           $84 = __THREW__; __THREW__ = 0;
           $85 = $84&1;
           if ($85) {
            break;
           }
           __THREW__ = 0;
           $86 = (invoke_iii(2730,(2728688|0),($81|0))|0);
           $87 = __THREW__; __THREW__ = 0;
           $88 = $87&1;
           if ($88) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($86|0));
           $89 = __THREW__; __THREW__ = 0;
           $90 = $89&1;
           if ($90) {
            break;
           }
           __THREW__ = 0;
           $91 = (invoke_ii(2586,($86|0))|0);
           $92 = __THREW__; __THREW__ = 0;
           $93 = $92&1;
           if ($93) {
            break;
           }
           $94 = (Math_fround(($91|0)));
           __THREW__ = 0;
           $95 = (Math_fround(+(invoke_fiff(4,(0|0),(+$44),(+$94)))));
           $96 = __THREW__; __THREW__ = 0;
           $97 = $96&1;
           if ($97) {
            break;
           } else {
            $V_1$0 = $69;$V_2$0 = $95;
           }
          }
          $98 = Math_fround($y$ + $V_1$0);
          $99 = Math_fround($V_2$0 + $V_1$0);
          $100 = Math_fround($height - $99);
          $$06 = $100;$$1 = $98;
         }
         $101 = (($__this) + 60|0);
         $102 = Math_fround(HEAPF32[$101>>2]);
         $103 = HEAP32[$2>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($103|0));
         $104 = __THREW__; __THREW__ = 0;
         $105 = $104&1;
         if ($105) {
          break;
         }
         __THREW__ = 0;
         $106 = (invoke_iii(2729,(1905272|0),($103|0))|0);
         $107 = __THREW__; __THREW__ = 0;
         $108 = $107&1;
         if ($108) {
          break;
         }
         $109 = (($106) + -1)|0;
         $110 = (Math_fround(($109|0)));
         $111 = Math_fround($102 * $110);
         $112 = Math_fround($$06 - $111);
         $113 = (($__this) + 96|0);
         $114 = Math_fround(HEAPF32[$113>>2]);
         $115 = (($__this) + 100|0);
         $116 = Math_fround(HEAPF32[$115>>2]);
         $117 = $114 == $116;
         if ($117) {
          $125 = $116;$V_4$0 = Math_fround(0.0);
         } else {
          $118 = Math_fround($112 - $114);
          $119 = Math_fround($116 - $114);
          $120 = Math_fround($118 / $119);
          __THREW__ = 0;
          $121 = (Math_fround(+(invoke_fifff(1,(0|0),(+$120),0.0,1.0))));
          $122 = __THREW__; __THREW__ = 0;
          $123 = $122&1;
          if ($123) {
           break;
          }
          $$pre = Math_fround(HEAPF32[$115>>2]);
          $125 = $$pre;$V_4$0 = $121;
         }
         $124 = !($112 <= $125);
         if ($124) {
          $126 = (($__this) + 80|0);
          $127 = HEAP32[$126>>2]|0;
          $128 = ($127|0)<(1);
          if ($128) {
           $V_5$0 = Math_fround(0.0);
          } else {
           $129 = Math_fround($112 - $125);
           $130 = (Math_fround(($127|0)));
           $131 = Math_fround($129 / $130);
           $V_5$0 = $131;
          }
         } else {
          $V_5$0 = Math_fround(0.0);
         }
         $132 = HEAP32[$2>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($132|0));
         $133 = __THREW__; __THREW__ = 0;
         $134 = $133&1;
         if ($134) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(1633,($L_67|0),($132|0));
         $135 = __THREW__; __THREW__ = 0;
         $136 = $135&1;
         if ($136) {
          break;
         }
         ;HEAP32[$V_9+0>>2]=HEAP32[$L_67+0>>2]|0;HEAP32[$V_9+4>>2]=HEAP32[$L_67+4>>2]|0;HEAP32[$V_9+8>>2]=HEAP32[$L_67+8>>2]|0;HEAP32[$V_9+12>>2]=HEAP32[$L_67+12>>2]|0;
         $$3 = $$1;$V_6$1 = 0;$V_7$2$off0 = 1;
         while(1) {
          __THREW__ = 0;
          $209 = (invoke_ii(3478,($V_9|0))|0);
          $210 = __THREW__; __THREW__ = 0;
          $211 = $210&1;
          if ($211) {
           label = 56;
           break;
          }
          if (!($209)) {
           $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 554;
           break;
          }
          __THREW__ = 0;
          $137 = (invoke_ii(3468,($V_9|0))|0);
          $212 = __THREW__; __THREW__ = 0;
          $213 = $212&1;
          if ($213) {
           label = 56;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($137|0));
          $138 = __THREW__; __THREW__ = 0;
          $139 = $138&1;
          if ($139) {
           label = 56;
           break;
          }
          $140 = (($137) + 16|0);
          $141 = Math_fround(HEAPF32[$140>>2]);
          __THREW__ = 0;
          invoke_vi(3799,($137|0));
          $142 = __THREW__; __THREW__ = 0;
          $143 = $142&1;
          if ($143) {
           label = 56;
           break;
          }
          $144 = (($137) + 20|0);
          $145 = Math_fround(HEAPF32[$144>>2]);
          __THREW__ = 0;
          $146 = (Math_fround(+(invoke_fifff(2,(0|0),(+$141),(+$145),(+$V_4$0)))));
          $147 = __THREW__; __THREW__ = 0;
          $148 = $147&1;
          if ($148) {
           label = 56;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($137|0));
          $149 = __THREW__; __THREW__ = 0;
          $150 = $149&1;
          if ($150) {
           label = 56;
           break;
          }
          $151 = (($137) + 44|0);
          $152 = HEAP32[$151>>2]|0;
          $153 = (Math_fround(($152|0)));
          $154 = Math_fround($V_5$0 * $153);
          $155 = Math_fround($146 + $154);
          __THREW__ = 0;
          invoke_vi(3799,($137|0));
          $156 = __THREW__; __THREW__ = 0;
          $157 = $156&1;
          if ($157) {
           label = 56;
           break;
          }
          __THREW__ = 0;
          $158 = (invoke_ii(2550,($137|0))|0);
          $159 = __THREW__; __THREW__ = 0;
          $160 = $159&1;
          if ($160) {
           label = 56;
           break;
          }
          __THREW__ = 0;
          $161 = (invoke_ii(2549,0)|0);
          $162 = __THREW__; __THREW__ = 0;
          $163 = $162&1;
          if ($163) {
           label = 56;
           break;
          }
          $164 = ($158|0)==($161|0);
          if ($164) {
           $$2 = $$3;$V_6$0 = $V_6$1;$V_7$1$off0 = $V_7$2$off0;
          } else {
           __THREW__ = 0;
           invoke_vi(3799,($137|0));
           $173 = __THREW__; __THREW__ = 0;
           $174 = $173&1;
           if ($174) {
            label = 56;
            break;
           }
           __THREW__ = 0;
           $175 = (invoke_iii(2730,(2728688|0),($137|0))|0);
           $176 = __THREW__; __THREW__ = 0;
           $177 = $176&1;
           if ($177) {
            label = 56;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($175|0));
           $178 = __THREW__; __THREW__ = 0;
           $179 = $178&1;
           if ($179) {
            label = 56;
            break;
           }
           __THREW__ = 0;
           $180 = (invoke_ii(2585,($175|0))|0);
           $181 = __THREW__; __THREW__ = 0;
           $182 = $181&1;
           if ($182) {
            label = 56;
            break;
           }
           $$ = $V_7$2$off0 ? 0 : $180;
           $183 = ($V_6$1|0)>($$|0);
           $G_B22_0$0 = $183 ? $V_6$1 : $$;
           $184 = (Math_fround(($G_B22_0$0|0)));
           $185 = Math_fround($$3 + $184);
           __THREW__ = 0;
           invoke_vi(3799,($137|0));
           $186 = __THREW__; __THREW__ = 0;
           $187 = $186&1;
           if ($187) {
            label = 56;
            break;
           }
           __THREW__ = 0;
           $188 = (invoke_iii(2730,(2728688|0),($137|0))|0);
           $189 = __THREW__; __THREW__ = 0;
           $190 = $189&1;
           if ($190) {
            label = 56;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($188|0));
           $191 = __THREW__; __THREW__ = 0;
           $192 = $191&1;
           if ($192) {
            label = 56;
            break;
           }
           __THREW__ = 0;
           $193 = (invoke_ii(2586,($188|0))|0);
           $194 = __THREW__; __THREW__ = 0;
           $195 = $194&1;
           if ($195) {
            label = 56;
            break;
           } else {
            $$2 = $185;$V_6$0 = $193;$V_7$1$off0 = 0;
           }
          }
          __THREW__ = 0;
          $196 = (Math_fround(+(invoke_fif(11,(0|0),(+$$2)))));
          $197 = __THREW__; __THREW__ = 0;
          $198 = $197&1;
          if ($198) {
           label = 56;
           break;
          }
          __THREW__ = 0;
          $199 = (Math_fround(+(invoke_fif(11,(0|0),(+$155)))));
          $200 = __THREW__; __THREW__ = 0;
          $201 = $200&1;
          if ($201) {
           label = 56;
           break;
          }
          __THREW__ = 0;
          invoke_vi(3799,($137|0));
          $202 = __THREW__; __THREW__ = 0;
          $203 = $202&1;
          if ($203) {
           label = 56;
           break;
          }
          __THREW__ = 0;
          invoke_viiff(2,(2728880|0),($137|0),(+$196),(+$199));
          $204 = __THREW__; __THREW__ = 0;
          $205 = $204&1;
          if ($205) {
           label = 56;
           break;
          }
          $206 = Math_fround(HEAPF32[$101>>2]);
          $207 = Math_fround($155 + $206);
          $208 = Math_fround($$2 + $207);
          $$3 = $208;$V_6$1 = $V_6$0;$V_7$2$off0 = $V_7$1$off0;
         }
         if ((label|0) == 56) {
          $165 = ___cxa_find_matching_catch(348288|0)|0;
          $166 = tempRet0;
          $167 = (_llvm_eh_typeid_for((348288|0))|0);
          $168 = ($166|0)==($167|0);
          if (!($168)) {
           $$07 = $165;$$08 = $166;
           __ZN16StackTraceSentryD2Ev(0);
           ___resumeException($$07|0);
           // unreachable;
          }
          $169 = (___cxa_begin_catch(($165|0))|0);
          $170 = HEAP32[$169>>2]|0;
          __THREW__ = 0;
          invoke_v(66);
          $171 = __THREW__; __THREW__ = 0;
          $172 = $171&1;
          if ($172) {
           break;
          }
          $__last_unhandled_exception$0 = $170;$leaveInstructions$sroa$0$0 = 0;
         }
         ;HEAP32[$L_92+0>>2]=HEAP32[$V_9+0>>2]|0;HEAP32[$L_92+4>>2]=HEAP32[$V_9+4>>2]|0;HEAP32[$L_92+8>>2]=HEAP32[$V_9+8>>2]|0;HEAP32[$L_92+12>>2]=HEAP32[$V_9+12>>2]|0;
         __THREW__ = 0;
         (invoke_ii(2996,(1902144|0))|0);
         $214 = __THREW__; __THREW__ = 0;
         $215 = $214&1;
         if ($215) {
          break;
         }
         __THREW__ = 0;
         $216 = (invoke_iii(2724,(1902144|0),($L_92|0))|0);
         $217 = __THREW__; __THREW__ = 0;
         $218 = $217&1;
         if ($218) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3799,($216|0));
         $219 = __THREW__; __THREW__ = 0;
         $220 = $219&1;
         if ($220) {
          break;
         }
         __THREW__ = 0;
         invoke_vii(3491,(2176768|0),($216|0));
         $221 = __THREW__; __THREW__ = 0;
         $222 = $221&1;
         if ($222) {
          break;
         }
         $cond5 = ($leaveInstructions$sroa$0$0|0)==(554);
         if ($cond5) {
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
         __THREW__ = 0;
         invoke_vi(3844,($__last_unhandled_exception$0|0));
         $223 = __THREW__; __THREW__ = 0;
         $224 = $223&1;
         if ($224) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        $225 = (invoke_ii(2550,($__this|0))|0);
        $226 = __THREW__; __THREW__ = 0;
        $227 = $226&1;
        if (!($227)) {
         __THREW__ = 0;
         $228 = (invoke_ii(2596,0)|0);
         $229 = __THREW__; __THREW__ = 0;
         $230 = $229&1;
         if (!($230)) {
          $231 = ($225|0)==($228|0);
          if (!($231)) {
           $232 = HEAP32[$2>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($232|0));
           $233 = __THREW__; __THREW__ = 0;
           $234 = $233&1;
           if ($234) {
            break;
           }
           __THREW__ = 0;
           invoke_vii(1633,($L_97|0),($232|0));
           $235 = __THREW__; __THREW__ = 0;
           $236 = $235&1;
           if ($236) {
            break;
           }
           ;HEAP32[$V_14+0>>2]=HEAP32[$L_97+0>>2]|0;HEAP32[$V_14+4>>2]=HEAP32[$L_97+4>>2]|0;HEAP32[$V_14+8>>2]=HEAP32[$L_97+8>>2]|0;HEAP32[$V_14+12>>2]=HEAP32[$L_97+12>>2]|0;
           while(1) {
            __THREW__ = 0;
            $311 = (invoke_ii(3478,($V_14|0))|0);
            $312 = __THREW__; __THREW__ = 0;
            $313 = $312&1;
            if ($313) {
             label = 104;
             break;
            }
            if (!($311)) {
             $__last_unhandled_exception$1 = 0;$leaveInstructions$sroa$0$1 = 753;
             break;
            }
            __THREW__ = 0;
            $237 = (invoke_ii(3468,($V_14|0))|0);
            $314 = __THREW__; __THREW__ = 0;
            $315 = $314&1;
            if ($315) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($237|0));
            $238 = __THREW__; __THREW__ = 0;
            $239 = $238&1;
            if ($239) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            $240 = (invoke_iii(2730,(2728688|0),($237|0))|0);
            $241 = __THREW__; __THREW__ = 0;
            $242 = $241&1;
            if ($242) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($240|0));
            $243 = __THREW__; __THREW__ = 0;
            $244 = $243&1;
            if ($244) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            $245 = (invoke_ii(2585,($240|0))|0);
            $246 = __THREW__; __THREW__ = 0;
            $247 = $246&1;
            if ($247) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($17|0));
            $248 = __THREW__; __THREW__ = 0;
            $249 = $248&1;
            if ($249) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            $250 = (invoke_ii(2585,($17|0))|0);
            $251 = __THREW__; __THREW__ = 0;
            $252 = $251&1;
            if ($252) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            $253 = (invoke_iiii(1407,(0|0),($245|0),($250|0))|0);
            $254 = __THREW__; __THREW__ = 0;
            $255 = $254&1;
            if ($255) {
             label = 104;
             break;
            }
            $256 = (Math_fround(($253|0)));
            $257 = Math_fround($y$ + $256);
            __THREW__ = 0;
            invoke_vi(3799,($237|0));
            $258 = __THREW__; __THREW__ = 0;
            $259 = $258&1;
            if ($259) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            $260 = (invoke_iii(2730,(2728688|0),($237|0))|0);
            $261 = __THREW__; __THREW__ = 0;
            $262 = $261&1;
            if ($262) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($260|0));
            $263 = __THREW__; __THREW__ = 0;
            $264 = $263&1;
            if ($264) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            $265 = (invoke_ii(2586,($260|0))|0);
            $266 = __THREW__; __THREW__ = 0;
            $267 = $266&1;
            if ($267) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($17|0));
            $268 = __THREW__; __THREW__ = 0;
            $269 = $268&1;
            if ($269) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            $270 = (invoke_ii(2586,($17|0))|0);
            $271 = __THREW__; __THREW__ = 0;
            $272 = $271&1;
            if ($272) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            $273 = (invoke_iiii(1407,(0|0),($265|0),($270|0))|0);
            $274 = __THREW__; __THREW__ = 0;
            $275 = $274&1;
            if ($275) {
             label = 104;
             break;
            }
            $276 = (Math_fround(($273|0)));
            $277 = Math_fround($height - $276);
            $278 = Math_fround($277 - $256);
            __THREW__ = 0;
            invoke_vi(3799,($237|0));
            $279 = __THREW__; __THREW__ = 0;
            $280 = $279&1;
            if ($280) {
             label = 104;
             break;
            }
            $281 = (($237) + 44|0);
            $282 = HEAP32[$281>>2]|0;
            $283 = ($282|0)==(0);
            if (!($283)) {
             __THREW__ = 0;
             invoke_vi(3799,($237|0));
             $292 = __THREW__; __THREW__ = 0;
             $293 = $292&1;
             if ($293) {
              label = 104;
              break;
             }
             __THREW__ = 0;
             invoke_viiff(2,(2728880|0),($237|0),(+$257),(+$278));
             $294 = __THREW__; __THREW__ = 0;
             $295 = $294&1;
             if ($295) {
              label = 104;
              break;
             } else {
              continue;
             }
            }
            __THREW__ = 0;
            invoke_vi(3799,($237|0));
            $296 = __THREW__; __THREW__ = 0;
            $297 = $296&1;
            if ($297) {
             label = 104;
             break;
            }
            $298 = (($237) + 16|0);
            $299 = Math_fround(HEAPF32[$298>>2]);
            __THREW__ = 0;
            invoke_vi(3799,($237|0));
            $300 = __THREW__; __THREW__ = 0;
            $301 = $300&1;
            if ($301) {
             label = 104;
             break;
            }
            $302 = (($237) + 20|0);
            $303 = Math_fround(HEAPF32[$302>>2]);
            __THREW__ = 0;
            $304 = (Math_fround(+(invoke_fifff(1,(0|0),(+$278),(+$299),(+$303)))));
            $305 = __THREW__; __THREW__ = 0;
            $306 = $305&1;
            if ($306) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            invoke_vi(3799,($237|0));
            $307 = __THREW__; __THREW__ = 0;
            $308 = $307&1;
            if ($308) {
             label = 104;
             break;
            }
            __THREW__ = 0;
            invoke_viiff(2,(2728880|0),($237|0),(+$257),(+$304));
            $309 = __THREW__; __THREW__ = 0;
            $310 = $309&1;
            if ($310) {
             label = 104;
             break;
            }
           }
           if ((label|0) == 104) {
            $284 = ___cxa_find_matching_catch(348288|0)|0;
            $285 = tempRet0;
            $286 = (_llvm_eh_typeid_for((348288|0))|0);
            $287 = ($285|0)==($286|0);
            if (!($287)) {
             $$07 = $284;$$08 = $285;
             __ZN16StackTraceSentryD2Ev(0);
             ___resumeException($$07|0);
             // unreachable;
            }
            $288 = (___cxa_begin_catch(($284|0))|0);
            $289 = HEAP32[$288>>2]|0;
            __THREW__ = 0;
            invoke_v(66);
            $290 = __THREW__; __THREW__ = 0;
            $291 = $290&1;
            if ($291) {
             break;
            }
            $__last_unhandled_exception$1 = $289;$leaveInstructions$sroa$0$1 = 0;
           }
           ;HEAP32[$L_117+0>>2]=HEAP32[$V_14+0>>2]|0;HEAP32[$L_117+4>>2]=HEAP32[$V_14+4>>2]|0;HEAP32[$L_117+8>>2]=HEAP32[$V_14+8>>2]|0;HEAP32[$L_117+12>>2]=HEAP32[$V_14+12>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(1902144|0))|0);
           $316 = __THREW__; __THREW__ = 0;
           $317 = $316&1;
           if ($317) {
            break;
           }
           __THREW__ = 0;
           $318 = (invoke_iii(2724,(1902144|0),($L_117|0))|0);
           $319 = __THREW__; __THREW__ = 0;
           $320 = $319&1;
           if ($320) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3799,($318|0));
           $321 = __THREW__; __THREW__ = 0;
           $322 = $321&1;
           if ($322) {
            break;
           }
           __THREW__ = 0;
           invoke_vii(3491,(2176768|0),($318|0));
           $323 = __THREW__; __THREW__ = 0;
           $324 = $323&1;
           if ($324) {
            break;
           }
           $cond1 = ($leaveInstructions$sroa$0$1|0)==(753);
           if ($cond1) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           __THREW__ = 0;
           invoke_vi(3844,($__last_unhandled_exception$1|0));
           $325 = __THREW__; __THREW__ = 0;
           $326 = $325&1;
           if ($326) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          $327 = (invoke_iii(2730,(2730064|0),($__this|0))|0);
          $328 = __THREW__; __THREW__ = 0;
          $329 = $328&1;
          if (!($329)) {
           __THREW__ = 0;
           invoke_vi(3799,($327|0));
           $330 = __THREW__; __THREW__ = 0;
           $331 = $330&1;
           if (!($331)) {
            __THREW__ = 0;
            $332 = (invoke_ii(2585,($327|0))|0);
            $333 = __THREW__; __THREW__ = 0;
            $334 = $333&1;
            if (!($334)) {
             $335 = (Math_fround(($332|0)));
             $336 = Math_fround($y$ - $335);
             __THREW__ = 0;
             $337 = (invoke_iii(2730,(2730064|0),($__this|0))|0);
             $338 = __THREW__; __THREW__ = 0;
             $339 = $338&1;
             if (!($339)) {
              __THREW__ = 0;
              invoke_vi(3799,($337|0));
              $340 = __THREW__; __THREW__ = 0;
              $341 = $340&1;
              if (!($341)) {
               __THREW__ = 0;
               $342 = (invoke_ii(2588,($337|0))|0);
               $343 = __THREW__; __THREW__ = 0;
               $344 = $343&1;
               if (!($344)) {
                $345 = (Math_fround(($342|0)));
                $346 = Math_fround($345 + $height);
                $347 = HEAP32[$2>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($347|0));
                $348 = __THREW__; __THREW__ = 0;
                $349 = $348&1;
                if (!($349)) {
                 __THREW__ = 0;
                 invoke_vii(1633,($L_128|0),($347|0));
                 $350 = __THREW__; __THREW__ = 0;
                 $351 = $350&1;
                 if (!($351)) {
                  ;HEAP32[$V_21+0>>2]=HEAP32[$L_128+0>>2]|0;HEAP32[$V_21+4>>2]=HEAP32[$L_128+4>>2]|0;HEAP32[$V_21+8>>2]=HEAP32[$L_128+8>>2]|0;HEAP32[$V_21+12>>2]=HEAP32[$L_128+12>>2]|0;
                  while(1) {
                   __THREW__ = 0;
                   $433 = (invoke_ii(3478,($V_21|0))|0);
                   $434 = __THREW__; __THREW__ = 0;
                   $435 = $434&1;
                   if ($435) {
                    label = 135;
                    break;
                   }
                   if (!($433)) {
                    $__last_unhandled_exception$2 = 0;$leaveInstructions$sroa$0$2 = 961;
                    break;
                   }
                   __THREW__ = 0;
                   $352 = (invoke_ii(3468,($V_21|0))|0);
                   $436 = __THREW__; __THREW__ = 0;
                   $437 = $436&1;
                   if ($437) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($352|0));
                   $353 = __THREW__; __THREW__ = 0;
                   $354 = $353&1;
                   if ($354) {
                    label = 135;
                    break;
                   }
                   $355 = (($352) + 44|0);
                   $356 = HEAP32[$355>>2]|0;
                   $357 = ($356|0)==(0);
                   if (!($357)) {
                    __THREW__ = 0;
                    invoke_vi(3799,($352|0));
                    $366 = __THREW__; __THREW__ = 0;
                    $367 = $366&1;
                    if ($367) {
                     label = 135;
                     break;
                    }
                    __THREW__ = 0;
                    $368 = (invoke_iii(2730,(2728688|0),($352|0))|0);
                    $369 = __THREW__; __THREW__ = 0;
                    $370 = $369&1;
                    if ($370) {
                     label = 135;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($368|0));
                    $371 = __THREW__; __THREW__ = 0;
                    $372 = $371&1;
                    if ($372) {
                     label = 135;
                     break;
                    }
                    __THREW__ = 0;
                    $373 = (invoke_ii(2585,($368|0))|0);
                    $374 = __THREW__; __THREW__ = 0;
                    $375 = $374&1;
                    if ($375) {
                     label = 135;
                     break;
                    }
                    $376 = (Math_fround(($373|0)));
                    $377 = Math_fround($336 + $376);
                    __THREW__ = 0;
                    invoke_vi(3799,($352|0));
                    $378 = __THREW__; __THREW__ = 0;
                    $379 = $378&1;
                    if ($379) {
                     label = 135;
                     break;
                    }
                    __THREW__ = 0;
                    $380 = (invoke_iii(2730,(2728688|0),($352|0))|0);
                    $381 = __THREW__; __THREW__ = 0;
                    $382 = $381&1;
                    if ($382) {
                     label = 135;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($380|0));
                    $383 = __THREW__; __THREW__ = 0;
                    $384 = $383&1;
                    if ($384) {
                     label = 135;
                     break;
                    }
                    __THREW__ = 0;
                    $385 = (invoke_ii(2588,($380|0))|0);
                    $386 = __THREW__; __THREW__ = 0;
                    $387 = $386&1;
                    if ($387) {
                     label = 135;
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3799,($352|0));
                    $388 = __THREW__; __THREW__ = 0;
                    $389 = $388&1;
                    if ($389) {
                     label = 135;
                     break;
                    }
                    $390 = (Math_fround(($385|0)));
                    $391 = Math_fround($346 - $390);
                    __THREW__ = 0;
                    invoke_viiff(2,(2728880|0),($352|0),(+$377),(+$391));
                    $392 = __THREW__; __THREW__ = 0;
                    $393 = $392&1;
                    if ($393) {
                     label = 135;
                     break;
                    } else {
                     continue;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($352|0));
                   $394 = __THREW__; __THREW__ = 0;
                   $395 = $394&1;
                   if ($395) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   $396 = (invoke_iii(2730,(2728688|0),($352|0))|0);
                   $397 = __THREW__; __THREW__ = 0;
                   $398 = $397&1;
                   if ($398) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($396|0));
                   $399 = __THREW__; __THREW__ = 0;
                   $400 = $399&1;
                   if ($400) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   $401 = (invoke_ii(2585,($396|0))|0);
                   $402 = __THREW__; __THREW__ = 0;
                   $403 = $402&1;
                   if ($403) {
                    label = 135;
                    break;
                   }
                   $404 = (Math_fround(($401|0)));
                   $405 = Math_fround($336 + $404);
                   __THREW__ = 0;
                   invoke_vi(3799,($352|0));
                   $406 = __THREW__; __THREW__ = 0;
                   $407 = $406&1;
                   if ($407) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   $408 = (invoke_iii(2730,(2728688|0),($352|0))|0);
                   $409 = __THREW__; __THREW__ = 0;
                   $410 = $409&1;
                   if ($410) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($408|0));
                   $411 = __THREW__; __THREW__ = 0;
                   $412 = $411&1;
                   if ($412) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   $413 = (invoke_ii(2588,($408|0))|0);
                   $414 = __THREW__; __THREW__ = 0;
                   $415 = $414&1;
                   if ($415) {
                    label = 135;
                    break;
                   }
                   $416 = (Math_fround(($413|0)));
                   $417 = Math_fround($346 - $416);
                   __THREW__ = 0;
                   invoke_vi(3799,($352|0));
                   $418 = __THREW__; __THREW__ = 0;
                   $419 = $418&1;
                   if ($419) {
                    label = 135;
                    break;
                   }
                   $420 = (($352) + 16|0);
                   $421 = Math_fround(HEAPF32[$420>>2]);
                   __THREW__ = 0;
                   invoke_vi(3799,($352|0));
                   $422 = __THREW__; __THREW__ = 0;
                   $423 = $422&1;
                   if ($423) {
                    label = 135;
                    break;
                   }
                   $424 = (($352) + 20|0);
                   $425 = Math_fround(HEAPF32[$424>>2]);
                   __THREW__ = 0;
                   $426 = (Math_fround(+(invoke_fifff(1,(0|0),(+$417),(+$421),(+$425)))));
                   $427 = __THREW__; __THREW__ = 0;
                   $428 = $427&1;
                   if ($428) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($352|0));
                   $429 = __THREW__; __THREW__ = 0;
                   $430 = $429&1;
                   if ($430) {
                    label = 135;
                    break;
                   }
                   __THREW__ = 0;
                   invoke_viiff(2,(2728880|0),($352|0),(+$405),(+$426));
                   $431 = __THREW__; __THREW__ = 0;
                   $432 = $431&1;
                   if ($432) {
                    label = 135;
                    break;
                   }
                  }
                  if ((label|0) == 135) {
                   $358 = ___cxa_find_matching_catch(348288|0)|0;
                   $359 = tempRet0;
                   $360 = (_llvm_eh_typeid_for((348288|0))|0);
                   $361 = ($359|0)==($360|0);
                   if (!($361)) {
                    $$07 = $358;$$08 = $359;
                    __ZN16StackTraceSentryD2Ev(0);
                    ___resumeException($$07|0);
                    // unreachable;
                   }
                   $362 = (___cxa_begin_catch(($358|0))|0);
                   $363 = HEAP32[$362>>2]|0;
                   __THREW__ = 0;
                   invoke_v(66);
                   $364 = __THREW__; __THREW__ = 0;
                   $365 = $364&1;
                   if ($365) {
                    break;
                   }
                   $__last_unhandled_exception$2 = $363;$leaveInstructions$sroa$0$2 = 0;
                  }
                  ;HEAP32[$L_151+0>>2]=HEAP32[$V_21+0>>2]|0;HEAP32[$L_151+4>>2]=HEAP32[$V_21+4>>2]|0;HEAP32[$L_151+8>>2]=HEAP32[$V_21+8>>2]|0;HEAP32[$L_151+12>>2]=HEAP32[$V_21+12>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(2996,(1902144|0))|0);
                  $438 = __THREW__; __THREW__ = 0;
                  $439 = $438&1;
                  if ($439) {
                   break;
                  }
                  __THREW__ = 0;
                  $440 = (invoke_iii(2724,(1902144|0),($L_151|0))|0);
                  $441 = __THREW__; __THREW__ = 0;
                  $442 = $441&1;
                  if ($442) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($440|0));
                  $443 = __THREW__; __THREW__ = 0;
                  $444 = $443&1;
                  if ($444) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vii(3491,(2176768|0),($440|0));
                  $445 = __THREW__; __THREW__ = 0;
                  $446 = $445&1;
                  if ($446) {
                   break;
                  }
                  $cond3 = ($leaveInstructions$sroa$0$2|0)==(961);
                  if ($cond3) {
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return;
                  }
                  __THREW__ = 0;
                  invoke_vi(3844,($__last_unhandled_exception$2|0));
                  $447 = __THREW__; __THREW__ = 0;
                  $448 = $447&1;
                  if ($448) {
                   break;
                  }
                  // unreachable;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$07 = $10;$$08 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$07|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_GUILayoutGroup_m_ToStringP38UnityEngine_UnityEngine_GUILayoutGroup($__this) {
 $__this = $__this|0;
 var $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_23 = 0;
 var $L_33 = 0, $L_38 = 0, $V_0$0 = 0, $V_1$0 = 0, $V_2$0 = 0, $V_4 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 56|0;
 $V_4 = sp;
 $L_23 = sp + 16|0;
 $L_33 = sp + 24|0;
 $L_38 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2730208);
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;HEAP32[$V_4+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(963);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if ($1) {
   label = 8;
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if ($3) {
    label = 8;
   } else {
    $4 = HEAP8[((2191608 + 116|0))>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if ($5) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if ($7) {
      label = 8;
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      label = 8;
      break;
     }
     __THREW__ = 0;
     invoke_vi(3843,(2191608|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      label = 8;
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     label = 8;
    } else {
     $18 = HEAP32[((2191608 + 80|0))>>2]|0;
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      label = 8;
     } else {
      $22 = HEAP8[((2191608 + 116|0))>>0]|0;
      $23 = ($22<<24>>24)==(0);
      if ($23) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        label = 8;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        label = 8;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2191608|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        label = 8;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 8;
      } else {
       $32 = HEAP32[((2191608 + 80|0))>>2]|0;
       $33 = HEAP32[$32>>2]|0;
       $V_1$0 = $33;$V_2$0 = 0;
       while(1) {
        __THREW__ = 0;
        (invoke_ii(2996,(2729880|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         label = 7;
         break;
        }
        $37 = HEAP8[((2729880 + 116|0))>>0]|0;
        $38 = ($37<<24>>24)==(0);
        if ($38) {
         __THREW__ = 0;
         (invoke_ii(2996,(2729880|0))|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2729880|0))|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          label = 7;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3843,(2729880|0));
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          label = 7;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2729880|0))|0);
        $45 = __THREW__; __THREW__ = 0;
        $46 = $45&1;
        if ($46) {
         label = 7;
         break;
        }
        $47 = HEAP32[((2729880 + 80|0))>>2]|0;
        $48 = (($47) + 16|0);
        $49 = HEAP32[$48>>2]|0;
        $50 = ($V_2$0|0)<($49|0);
        if (!($50)) {
         break;
        }
        $51 = HEAP32[2998152>>2]|0;
        __THREW__ = 0;
        $52 = (invoke_iiii(562,(0|0),($V_1$0|0),($51|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 7;
         break;
        }
        $34 = (($V_2$0) + 1)|0;
        $V_1$0 = $52;$V_2$0 = $34;
       }
       if ((label|0) == 7) {
        $12 = ___cxa_find_matching_catch()|0;
        $13 = tempRet0;
        $lpad$phi$index = $12;$lpad$phi$index2 = $13;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(1167664|0))|0);
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        label = 8;
       } else {
        __THREW__ = 0;
        $57 = (invoke_iii(2773,(1167664|0),5)|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 8;
        } else {
         __THREW__ = 0;
         invoke_vi(3799,($57|0));
         $60 = __THREW__; __THREW__ = 0;
         $61 = $60&1;
         if ($61) {
          label = 8;
         } else {
          $62 = (($57) + 12|0);
          $63 = HEAP32[$62>>2]|0;
          $64 = ($63|0)==(0);
          if ($64) {
           __THREW__ = 0;
           $65 = (invoke_i(132)|0);
           $66 = __THREW__; __THREW__ = 0;
           $67 = $66&1;
           if ($67) {
            label = 8;
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($65|0));
           $68 = __THREW__; __THREW__ = 0;
           $69 = $68&1;
           if ($69) {
            label = 8;
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($57|0),($19|0));
          $70 = __THREW__; __THREW__ = 0;
          $71 = $70&1;
          if ($71) {
           label = 8;
          } else {
           $72 = (($57) + 16|0);
           HEAP32[$72>>2] = $19;
           __THREW__ = 0;
           $73 = (invoke_ii(2552,($__this|0))|0);
           $74 = __THREW__; __THREW__ = 0;
           $75 = $74&1;
           if ($75) {
            label = 8;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($57|0));
            $76 = __THREW__; __THREW__ = 0;
            $77 = $76&1;
            if ($77) {
             label = 8;
            } else {
             $78 = HEAP32[$62>>2]|0;
             $79 = ($78>>>0)<(2);
             if ($79) {
              __THREW__ = 0;
              $80 = (invoke_i(132)|0);
              $81 = __THREW__; __THREW__ = 0;
              $82 = $81&1;
              if ($82) {
               label = 8;
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($80|0));
              $83 = __THREW__; __THREW__ = 0;
              $84 = $83&1;
              if ($84) {
               label = 8;
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($57|0),($73|0));
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if ($86) {
              label = 8;
             } else {
              $87 = HEAP32[$57>>2]|0;
              $88 = (($87) + 92|0);
              $89 = HEAP32[$88>>2]|0;
              $90 = (($72) + ($89)|0);
              HEAP32[$90>>2] = $73;
              __THREW__ = 0;
              invoke_vi(3799,($57|0));
              $91 = __THREW__; __THREW__ = 0;
              $92 = $91&1;
              if ($92) {
               label = 8;
              } else {
               $93 = HEAP32[$62>>2]|0;
               $94 = ($93>>>0)<(3);
               if ($94) {
                __THREW__ = 0;
                $95 = (invoke_i(132)|0);
                $96 = __THREW__; __THREW__ = 0;
                $97 = $96&1;
                if ($97) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($95|0));
                $98 = __THREW__; __THREW__ = 0;
                $99 = $98&1;
                if ($99) {
                 label = 8;
                 break;
                }
               }
               $100 = HEAP32[2998160>>2]|0;
               __THREW__ = 0;
               invoke_vii(3492,($57|0),($100|0));
               $101 = __THREW__; __THREW__ = 0;
               $102 = $101&1;
               if ($102) {
                label = 8;
               } else {
                $103 = HEAP32[2998160>>2]|0;
                $104 = HEAP32[$57>>2]|0;
                $105 = (($104) + 92|0);
                $106 = HEAP32[$105>>2]|0;
                $107 = $106 << 1;
                $108 = (($72) + ($107)|0);
                HEAP32[$108>>2] = $103;
                $109 = (($__this) + 96|0);
                $110 = Math_fround(HEAPF32[$109>>2]);
                HEAPF32[$L_23>>2] = $110;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $111 = __THREW__; __THREW__ = 0;
                $112 = $111&1;
                if ($112) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                $113 = (invoke_iii(2724,(2194912|0),($L_23|0))|0);
                $114 = __THREW__; __THREW__ = 0;
                $115 = $114&1;
                if ($115) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($57|0));
                $116 = __THREW__; __THREW__ = 0;
                $117 = $116&1;
                if ($117) {
                 label = 8;
                 break;
                }
                $118 = HEAP32[$62>>2]|0;
                $119 = ($118>>>0)<(4);
                if ($119) {
                 __THREW__ = 0;
                 $120 = (invoke_i(132)|0);
                 $121 = __THREW__; __THREW__ = 0;
                 $122 = $121&1;
                 if ($122) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($120|0));
                 $123 = __THREW__; __THREW__ = 0;
                 $124 = $123&1;
                 if ($124) {
                  label = 8;
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($57|0),($113|0));
                $125 = __THREW__; __THREW__ = 0;
                $126 = $125&1;
                if ($126) {
                 label = 8;
                 break;
                }
                $127 = HEAP32[$57>>2]|0;
                $128 = (($127) + 92|0);
                $129 = HEAP32[$128>>2]|0;
                $130 = ($129*3)|0;
                $131 = (($72) + ($130)|0);
                HEAP32[$131>>2] = $113;
                __THREW__ = 0;
                invoke_vi(3799,($57|0));
                $132 = __THREW__; __THREW__ = 0;
                $133 = $132&1;
                if ($133) {
                 label = 8;
                 break;
                }
                $134 = HEAP32[$62>>2]|0;
                $135 = ($134>>>0)<(5);
                if ($135) {
                 __THREW__ = 0;
                 $136 = (invoke_i(132)|0);
                 $137 = __THREW__; __THREW__ = 0;
                 $138 = $137&1;
                 if ($138) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($136|0));
                 $139 = __THREW__; __THREW__ = 0;
                 $140 = $139&1;
                 if ($140) {
                  label = 8;
                  break;
                 }
                }
                $141 = HEAP32[2998168>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($57|0),($141|0));
                $142 = __THREW__; __THREW__ = 0;
                $143 = $142&1;
                if ($143) {
                 label = 8;
                 break;
                }
                $144 = HEAP32[2998168>>2]|0;
                $145 = HEAP32[$57>>2]|0;
                $146 = (($145) + 92|0);
                $147 = HEAP32[$146>>2]|0;
                $148 = $147 << 2;
                $149 = (($72) + ($148)|0);
                HEAP32[$149>>2] = $144;
                __THREW__ = 0;
                $150 = (invoke_iii(638,(0|0),($57|0))|0);
                $151 = __THREW__; __THREW__ = 0;
                $152 = $151&1;
                if ($152) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2729880|0))|0);
                $153 = __THREW__; __THREW__ = 0;
                $154 = $153&1;
                if ($154) {
                 label = 8;
                 break;
                }
                $155 = HEAP8[((2729880 + 116|0))>>0]|0;
                $156 = ($155<<24>>24)==(0);
                if ($156) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2729880|0))|0);
                 $157 = __THREW__; __THREW__ = 0;
                 $158 = $157&1;
                 if ($158) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2729880|0))|0);
                 $159 = __THREW__; __THREW__ = 0;
                 $160 = $159&1;
                 if ($160) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2729880|0));
                 $161 = __THREW__; __THREW__ = 0;
                 $162 = $161&1;
                 if ($162) {
                  label = 8;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2729880|0))|0);
                $163 = __THREW__; __THREW__ = 0;
                $164 = $163&1;
                if ($164) {
                 label = 8;
                 break;
                }
                $165 = HEAP32[((2729880 + 80|0))>>2]|0;
                $166 = (($165) + 16|0);
                $167 = HEAP32[$166>>2]|0;
                $168 = (($167) + 4)|0;
                __THREW__ = 0;
                (invoke_ii(2996,(2729880|0))|0);
                $169 = __THREW__; __THREW__ = 0;
                $170 = $169&1;
                if ($170) {
                 label = 8;
                 break;
                }
                $171 = HEAP8[((2729880 + 116|0))>>0]|0;
                $172 = ($171<<24>>24)==(0);
                if ($172) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2729880|0))|0);
                 $173 = __THREW__; __THREW__ = 0;
                 $174 = $173&1;
                 if ($174) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2729880|0))|0);
                 $175 = __THREW__; __THREW__ = 0;
                 $176 = $175&1;
                 if ($176) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2729880|0));
                 $177 = __THREW__; __THREW__ = 0;
                 $178 = $177&1;
                 if ($178) {
                  label = 8;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2729880|0))|0);
                $179 = __THREW__; __THREW__ = 0;
                $180 = $179&1;
                if ($180) {
                 label = 8;
                 break;
                }
                $181 = HEAP32[((2729880 + 80|0))>>2]|0;
                $182 = (($181) + 16|0);
                HEAP32[$182>>2] = $168;
                $183 = (($__this) + 52|0);
                $184 = HEAP32[$183>>2]|0;
                __THREW__ = 0;
                invoke_vi(3799,($184|0));
                $185 = __THREW__; __THREW__ = 0;
                $186 = $185&1;
                if ($186) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                invoke_vii(1633,($L_33|0),($184|0));
                $187 = __THREW__; __THREW__ = 0;
                $188 = $187&1;
                if ($188) {
                 label = 8;
                 break;
                }
                ;HEAP32[$V_4+0>>2]=HEAP32[$L_33+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_33+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_33+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[$L_33+12>>2]|0;
                $V_0$0 = $150;
                while(1) {
                 __THREW__ = 0;
                 $199 = (invoke_ii(3478,($V_4|0))|0);
                 $200 = __THREW__; __THREW__ = 0;
                 $201 = $200&1;
                 if ($201) {
                  label = 79;
                  break;
                 }
                 if (!($199)) {
                  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 191;
                  break;
                 }
                 __THREW__ = 0;
                 $189 = (invoke_ii(3468,($V_4|0))|0);
                 $202 = __THREW__; __THREW__ = 0;
                 $203 = $202&1;
                 if ($203) {
                  label = 79;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($189|0));
                 $190 = __THREW__; __THREW__ = 0;
                 $191 = $190&1;
                 if ($191) {
                  label = 79;
                  break;
                 }
                 __THREW__ = 0;
                 $192 = (invoke_iii(2730,(2728976|0),($189|0))|0);
                 $193 = __THREW__; __THREW__ = 0;
                 $194 = $193&1;
                 if ($194) {
                  label = 79;
                  break;
                 }
                 $195 = HEAP32[2998176>>2]|0;
                 __THREW__ = 0;
                 $196 = (invoke_iiiii(101,(0|0),($V_0$0|0),($192|0),($195|0))|0);
                 $197 = __THREW__; __THREW__ = 0;
                 $198 = $197&1;
                 if ($198) {
                  label = 79;
                  break;
                 } else {
                  $V_0$0 = $196;
                 }
                }
                if ((label|0) == 79) {
                 $204 = ___cxa_find_matching_catch(348288|0)|0;
                 $205 = tempRet0;
                 $206 = (_llvm_eh_typeid_for((348288|0))|0);
                 $207 = ($205|0)==($206|0);
                 if (!($207)) {
                  $$02 = $204;$$03 = $205;
                  __ZN16StackTraceSentryD2Ev(0);
                  ___resumeException($$02|0);
                  // unreachable;
                 }
                 $208 = (___cxa_begin_catch(($204|0))|0);
                 $209 = HEAP32[$208>>2]|0;
                 __THREW__ = 0;
                 invoke_v(66);
                 $210 = __THREW__; __THREW__ = 0;
                 $211 = $210&1;
                 if ($211) {
                  label = 8;
                  break;
                 }
                 $__last_unhandled_exception$0 = $209;$leaveInstructions$sroa$0$0 = 0;
                }
                ;HEAP32[$L_38+0>>2]=HEAP32[$V_4+0>>2]|0;HEAP32[$L_38+4>>2]=HEAP32[$V_4+4>>2]|0;HEAP32[$L_38+8>>2]=HEAP32[$V_4+8>>2]|0;HEAP32[$L_38+12>>2]=HEAP32[$V_4+12>>2]|0;
                __THREW__ = 0;
                (invoke_ii(2996,(1902144|0))|0);
                $212 = __THREW__; __THREW__ = 0;
                $213 = $212&1;
                if ($213) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                $214 = (invoke_iii(2724,(1902144|0),($L_38|0))|0);
                $215 = __THREW__; __THREW__ = 0;
                $216 = $215&1;
                if ($216) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($214|0));
                $217 = __THREW__; __THREW__ = 0;
                $218 = $217&1;
                if ($218) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                invoke_vii(3491,(2176768|0),($214|0));
                $219 = __THREW__; __THREW__ = 0;
                $220 = $219&1;
                if ($220) {
                 label = 8;
                 break;
                }
                $cond1 = ($leaveInstructions$sroa$0$0|0)==(191);
                if (!($cond1)) {
                 __THREW__ = 0;
                 invoke_vi(3844,($__last_unhandled_exception$0|0));
                 $221 = __THREW__; __THREW__ = 0;
                 $222 = $221&1;
                 if ($222) {
                  label = 8;
                  break;
                 }
                 // unreachable;
                }
                $223 = HEAP32[2998184>>2]|0;
                __THREW__ = 0;
                $224 = (invoke_iiiii(101,(0|0),($V_0$0|0),($V_1$0|0),($223|0))|0);
                $225 = __THREW__; __THREW__ = 0;
                $226 = $225&1;
                if ($226) {
                 label = 8;
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2729880|0))|0);
                $227 = __THREW__; __THREW__ = 0;
                $228 = $227&1;
                if ($228) {
                 label = 8;
                 break;
                }
                $229 = HEAP8[((2729880 + 116|0))>>0]|0;
                $230 = ($229<<24>>24)==(0);
                if ($230) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2729880|0))|0);
                 $231 = __THREW__; __THREW__ = 0;
                 $232 = $231&1;
                 if ($232) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2729880|0))|0);
                 $233 = __THREW__; __THREW__ = 0;
                 $234 = $233&1;
                 if ($234) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2729880|0));
                 $235 = __THREW__; __THREW__ = 0;
                 $236 = $235&1;
                 if ($236) {
                  label = 8;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2729880|0))|0);
                $237 = __THREW__; __THREW__ = 0;
                $238 = $237&1;
                if ($238) {
                 label = 8;
                 break;
                }
                $239 = HEAP32[((2729880 + 80|0))>>2]|0;
                $240 = (($239) + 16|0);
                $241 = HEAP32[$240>>2]|0;
                $242 = (($241) + -4)|0;
                __THREW__ = 0;
                (invoke_ii(2996,(2729880|0))|0);
                $243 = __THREW__; __THREW__ = 0;
                $244 = $243&1;
                if ($244) {
                 label = 8;
                 break;
                }
                $245 = HEAP8[((2729880 + 116|0))>>0]|0;
                $246 = ($245<<24>>24)==(0);
                if ($246) {
                 __THREW__ = 0;
                 (invoke_ii(2996,(2729880|0))|0);
                 $247 = __THREW__; __THREW__ = 0;
                 $248 = $247&1;
                 if ($248) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 (invoke_ii(2996,(2729880|0))|0);
                 $249 = __THREW__; __THREW__ = 0;
                 $250 = $249&1;
                 if ($250) {
                  label = 8;
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3843,(2729880|0));
                 $251 = __THREW__; __THREW__ = 0;
                 $252 = $251&1;
                 if ($252) {
                  label = 8;
                  break;
                 }
                }
                __THREW__ = 0;
                (invoke_ii(2996,(2729880|0))|0);
                $253 = __THREW__; __THREW__ = 0;
                $254 = $253&1;
                if ($254) {
                 label = 8;
                 break;
                }
                $255 = HEAP32[((2729880 + 80|0))>>2]|0;
                $256 = (($255) + 16|0);
                HEAP32[$256>>2] = $242;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($224|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 }
 $$02 = $lpad$phi$index;$$03 = $lpad$phi$index2;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_GUIScrollGroup_m__ctorP38UnityEngine_UnityEngine_GUIScrollGroup($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2731368);
 $0 = (($__this) + 132|0);
 HEAP8[$0>>0] = 1;
 $1 = (($__this) + 133|0);
 HEAP8[$1>>0] = 1;
 __THREW__ = 0;
 invoke_vi(2933,($__this|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_GUIScrollGroup_m_CalcWidthP38UnityEngine_UnityEngine_GUIScrollGroup($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2731416);
 $0 = (($__this) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($__this) + 12|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($__this) + 132|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  HEAPF32[$0>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = Math_fround(0.0);
 }
 __THREW__ = 0;
 invoke_vi(2925,($__this|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 }
 $9 = Math_fround(HEAPF32[$0>>2]);
 $10 = (($__this) + 108|0);
 HEAPF32[$10>>2] = $9;
 $11 = Math_fround(HEAPF32[$2>>2]);
 $12 = (($__this) + 112|0);
 HEAPF32[$12>>2] = $11;
 $13 = HEAP8[$4>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $17 = !($9 <= Math_fround(32.0));
 if ($17) {
  HEAPF32[$0>>2] = Math_fround(32.0);
 }
 $18 = $1 == Math_fround(0.0);
 if (!($18)) {
  HEAPF32[$0>>2] = $1;
 }
 $19 = $3 == Math_fround(0.0);
 if ($19) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 HEAPF32[$2>>2] = $3;
 $20 = (($__this) + 40|0);
 HEAP32[$20>>2] = 0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54UnityEngine_UnityEngine_GUIScrollGroup_m_SetHorizontalP38UnityEngine_UnityEngine_GUIScrollGroupff($__this,$x,$width) {
 $__this = $__this|0;
 $x = Math_fround($x);
 $width = Math_fround($width);
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $G_B3_0$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2731464);
 $0 = (($__this) + 135|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $G_B3_0$0 = $width;
  label = 10;
 } else {
  $3 = (($__this) + 140|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (Math_fround(+(invoke_fi(134,($4|0)))));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = Math_fround($width - $7);
    $11 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($11|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     $14 = (invoke_ii(2592,($11|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      __THREW__ = 0;
      invoke_vi(3799,($14|0));
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_ii(2583,($14|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        $22 = (Math_fround(($19|0)));
        $23 = Math_fround($10 - $22);
        $G_B3_0$0 = $23;
        label = 10;
       }
      }
     }
    }
   }
  }
 }
 L9: do {
  if ((label|0) == 10) {
   $26 = (($__this) + 132|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = ($27<<24>>24)==(0);
   do {
    if ($28) {
     $29 = (($__this) + 134|0);
     HEAP8[$29>>0] = 0;
    } else {
     $30 = (($__this) + 108|0);
     $31 = Math_fround(HEAPF32[$30>>2]);
     $32 = !($G_B3_0$0 >= $31);
     $33 = (($__this) + 134|0);
     if (!($32)) {
      HEAP8[$33>>0] = 0;
      $45 = (($__this) + 108|0);
      $46 = Math_fround(HEAPF32[$45>>2]);
      $47 = (($__this) + 8|0);
      HEAPF32[$47>>2] = $46;
      $48 = (($__this) + 112|0);
      $49 = Math_fround(HEAPF32[$48>>2]);
      $50 = (($__this) + 12|0);
      HEAPF32[$50>>2] = $49;
      break;
     }
     HEAP8[$33>>0] = 1;
     $34 = (($__this) + 8|0);
     HEAPF32[$34>>2] = $31;
     $35 = (($__this) + 112|0);
     $36 = Math_fround(HEAPF32[$35>>2]);
     $37 = (($__this) + 12|0);
     HEAPF32[$37>>2] = $36;
     __THREW__ = 0;
     invoke_viff(9,($__this|0),(+$x),(+$31));
     $38 = __THREW__; __THREW__ = 0;
     $39 = $38&1;
     if ($39) {
      break L9;
     }
     $40 = (($__this) + 24|0);
     __THREW__ = 0;
     invoke_vif(116,($40|0),(+$width));
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break L9;
     }
     $43 = Math_fround(HEAPF32[$30>>2]);
     $44 = (($__this) + 124|0);
     HEAPF32[$44>>2] = $43;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   } while(0);
   __THREW__ = 0;
   invoke_viff(9,($__this|0),(+$x),(+$G_B3_0$0));
   $51 = __THREW__; __THREW__ = 0;
   $52 = $51&1;
   if (!($52)) {
    $53 = (($__this) + 24|0);
    __THREW__ = 0;
    invoke_vif(116,($53|0),(+$width));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if (!($55)) {
     $56 = (($__this) + 124|0);
     HEAPF32[$56>>2] = $G_B3_0$0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $24 = ___cxa_find_matching_catch()|0;
 $25 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($24|0);
 // unreachable;
}
function __Z51UnityEngine_UnityEngine_GUIScrollGroup_m_CalcHeightP38UnityEngine_UnityEngine_GUIScrollGroup($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = Math_fround(0), $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0), $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = 0, $51 = 0, $52 = Math_fround(0), $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2731512);
 $0 = (($__this) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($__this) + 20|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($__this) + 133|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  HEAPF32[$0>>2] = Math_fround(0.0);
  HEAPF32[$2>>2] = Math_fround(0.0);
 }
 __THREW__ = 0;
 invoke_vi(2926,($__this|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   $9 = Math_fround(HEAPF32[$0>>2]);
   $10 = (($__this) + 116|0);
   HEAPF32[$10>>2] = $9;
   $11 = Math_fround(HEAPF32[$2>>2]);
   $12 = (($__this) + 120|0);
   HEAPF32[$12>>2] = $11;
   $13 = (($__this) + 134|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if (!($15)) {
    $18 = (($__this) + 136|0);
    $19 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($19|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (Math_fround(+(invoke_fi(135,($19|0)))));
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[$18>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($25|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    $28 = (invoke_ii(2592,($25|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3799,($28|0));
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     break;
    }
    __THREW__ = 0;
    $33 = (invoke_ii(2585,($28|0))|0);
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    $36 = (Math_fround(($33|0)));
    $37 = Math_fround($22 + $36);
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    $40 = Math_fround(HEAPF32[$0>>2]);
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    $43 = Math_fround($37 + $40);
    HEAPF32[$0>>2] = $43;
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    $46 = Math_fround(HEAPF32[$2>>2]);
    __THREW__ = 0;
    invoke_vi(3799,($__this|0));
    $47 = __THREW__; __THREW__ = 0;
    $48 = $47&1;
    if ($48) {
     break;
    }
    $49 = Math_fround($37 + $46);
    HEAPF32[$2>>2] = $49;
   }
   $50 = HEAP8[$4>>0]|0;
   $51 = ($50<<24>>24)==(0);
   if ($51) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   $52 = Math_fround(HEAPF32[$0>>2]);
   $53 = !($52 <= Math_fround(32.0));
   if ($53) {
    HEAPF32[$0>>2] = Math_fround(32.0);
   }
   $54 = $1 == Math_fround(0.0);
   if (!($54)) {
    HEAPF32[$0>>2] = $1;
   }
   $55 = $3 == Math_fround(0.0);
   if ($55) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   HEAPF32[$2>>2] = $3;
   $56 = (($__this) + 44|0);
   HEAP32[$56>>2] = 0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 } while(0);
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z52UnityEngine_UnityEngine_GUIScrollGroup_m_SetVerticalP38UnityEngine_UnityEngine_GUIScrollGroupff($__this,$y,$height) {
 $__this = $__this|0;
 $y = Math_fround($y);
 $height = Math_fround($height);
 var $$pre = Math_fround(0), $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = Math_fround(0), $22 = Math_fround(0);
 var $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = Math_fround(0), $46 = 0, $47 = 0, $48 = Math_fround(0), $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = Math_fround(0), $61 = Math_fround(0), $62 = 0, $63 = 0, $64 = Math_fround(0), $65 = 0, $66 = Math_fround(0), $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = Math_fround(0), $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = Math_fround(0), $81 = 0, $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = Math_fround(0), $92 = 0, $93 = 0, $94 = 0, $95 = Math_fround(0);
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2731560);
 $0 = (($__this) + 134|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $V_0$0 = $height;
  label = 9;
 } else {
  $3 = (($__this) + 136|0);
  $4 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($4|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (Math_fround(+(invoke_fi(135,($4|0)))));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP32[$3>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_ii(2592,($10|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3799,($13|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_ii(2585,($13|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        $21 = (Math_fround(($18|0)));
        $22 = Math_fround($7 + $21);
        $23 = Math_fround($height - $22);
        $V_0$0 = $23;
        label = 9;
       }
      }
     }
    }
   }
  }
 }
 L9: do {
  if ((label|0) == 9) {
   $24 = (($__this) + 133|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = ($25<<24>>24)==(0);
   do {
    if (!($26)) {
     $29 = (($__this) + 116|0);
     $30 = Math_fround(HEAPF32[$29>>2]);
     $31 = !($V_0$0 >= $30);
     if (!($31)) {
      $93 = (($__this) + 16|0);
      HEAPF32[$93>>2] = $30;
      $94 = (($__this) + 120|0);
      $95 = Math_fround(HEAPF32[$94>>2]);
      $96 = (($__this) + 20|0);
      HEAPF32[$96>>2] = $95;
      break;
     }
     $32 = HEAP8[$0>>0]|0;
     $33 = ($32<<24>>24)==(0);
     if ($33) {
      $34 = (($__this) + 135|0);
      $35 = HEAP8[$34>>0]|0;
      $36 = ($35<<24>>24)==(0);
      if ($36) {
       $37 = (($__this) + 24|0);
       __THREW__ = 0;
       $38 = (Math_fround(+(invoke_fi(140,($37|0)))));
       $39 = __THREW__; __THREW__ = 0;
       $40 = $39&1;
       if ($40) {
        break L9;
       }
       $41 = (($__this) + 140|0);
       $42 = HEAP32[$41>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $43 = __THREW__; __THREW__ = 0;
       $44 = $43&1;
       if ($44) {
        break L9;
       }
       __THREW__ = 0;
       $45 = (Math_fround(+(invoke_fi(134,($42|0)))));
       $46 = __THREW__; __THREW__ = 0;
       $47 = $46&1;
       if ($47) {
        break L9;
       }
       $48 = Math_fround($38 - $45);
       $49 = HEAP32[$41>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($49|0));
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break L9;
       }
       __THREW__ = 0;
       $52 = (invoke_ii(2592,($49|0))|0);
       $53 = __THREW__; __THREW__ = 0;
       $54 = $53&1;
       if ($54) {
        break L9;
       }
       __THREW__ = 0;
       invoke_vi(3799,($52|0));
       $55 = __THREW__; __THREW__ = 0;
       $56 = $55&1;
       if ($56) {
        break L9;
       }
       __THREW__ = 0;
       $57 = (invoke_ii(2583,($52|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        break L9;
       }
       $60 = (Math_fround(($57|0)));
       $61 = Math_fround($48 - $60);
       $62 = (($__this) + 124|0);
       HEAPF32[$62>>2] = $61;
       $63 = (($__this) + 108|0);
       $64 = Math_fround(HEAPF32[$63>>2]);
       $65 = !($61 >= $64);
       if ($65) {
        HEAPF32[$62>>2] = $64;
       }
       __THREW__ = 0;
       $66 = (Math_fround(+(invoke_fi(140,($37|0)))));
       $67 = __THREW__; __THREW__ = 0;
       $68 = $67&1;
       if ($68) {
        break L9;
       }
       __THREW__ = 0;
       $69 = (Math_fround(+(invoke_fi(138,($37|0)))));
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        break L9;
       }
       $72 = Math_fround(HEAPF32[$62>>2]);
       __THREW__ = 0;
       invoke_viiff(2,(2731464|0),($__this|0),(+$69),(+$72));
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break L9;
       }
       __THREW__ = 0;
       invoke_vii(3495,(2731512|0),($__this|0));
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        break L9;
       }
       __THREW__ = 0;
       invoke_vif(116,($37|0),(+$66));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        break L9;
       }
       $$pre = Math_fround(HEAPF32[$29>>2]);
       $83 = $$pre;
      } else {
       $83 = $30;
      }
     } else {
      $83 = $30;
     }
     $79 = (($__this) + 16|0);
     $80 = Math_fround(HEAPF32[$79>>2]);
     $81 = (($__this) + 20|0);
     $82 = Math_fround(HEAPF32[$81>>2]);
     HEAPF32[$79>>2] = $83;
     $84 = (($__this) + 120|0);
     $85 = Math_fround(HEAPF32[$84>>2]);
     HEAPF32[$81>>2] = $85;
     __THREW__ = 0;
     invoke_viff(10,($__this|0),(+$y),(+$83));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      break L9;
     }
     HEAPF32[$79>>2] = $80;
     HEAPF32[$81>>2] = $82;
     $88 = (($__this) + 24|0);
     __THREW__ = 0;
     invoke_vif(117,($88|0),(+$height));
     $89 = __THREW__; __THREW__ = 0;
     $90 = $89&1;
     if ($90) {
      break L9;
     }
     $91 = Math_fround(HEAPF32[$29>>2]);
     $92 = (($__this) + 128|0);
     HEAPF32[$92>>2] = $91;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   } while(0);
   __THREW__ = 0;
   invoke_viff(10,($__this|0),(+$y),(+$V_0$0));
   $97 = __THREW__; __THREW__ = 0;
   $98 = $97&1;
   if (!($98)) {
    $99 = (($__this) + 24|0);
    __THREW__ = 0;
    invoke_vif(117,($99|0),(+$height));
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if (!($101)) {
     $102 = (($__this) + 128|0);
     HEAPF32[$102>>2] = $V_0$0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $27 = ___cxa_find_matching_catch()|0;
 $28 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($27|0);
 // unreachable;
}
function __Z43UnityEngine_UnityEngine_GUIUtility_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2733688);
 __THREW__ = 0;
 invoke_vii(2068,($L_0|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2734792|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[((2734792 + 80|0))>>2]|0;
   $5 = (($4) + 8|0);
   $6 = $L_0;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $5;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   __THREW__ = 0;
   (invoke_ii(2996,(2734792|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = HEAP32[((2734792 + 80|0))>>2]|0;
    $19 = (($18) + 16|0);
    HEAP8[$19>>0] = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
}
function __Z60UnityEngine_UnityEngine_GUIUtility_m_Internal_GetDefaultSkinP22mscorlib_System_Objecti($__this,$skinMode) {
 $__this = $__this|0;
 $skinMode = $skinMode|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2733784);
 $0 = HEAP32[2733832>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2733840|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2733832>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($skinMode|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_GUIUtility_m_BeginGUIP22mscorlib_System_Objectiii($__this,$skinMode,$instanceID,$useGUILayout) {
 $__this = $__this|0;
 $skinMode = $skinMode|0;
 $instanceID = $instanceID|0;
 $useGUILayout = $useGUILayout|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2733904);
 __THREW__ = 0;
 (invoke_ii(2996,(2734792|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2734792 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2734792|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2734792|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2734792|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2734792|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2734792 + 80|0))>>2]|0;
    HEAP32[$14>>2] = $skinMode;
    __THREW__ = 0;
    (invoke_ii(2996,(2734792|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP8[((2734792 + 116|0))>>0]|0;
     $18 = ($17<<24>>24)==(0);
     if ($18) {
      __THREW__ = 0;
      (invoke_ii(2996,(2734792|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2734792|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2734792|0));
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2734792|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if (!($26)) {
      $27 = HEAP32[((2734792 + 80|0))>>2]|0;
      $28 = (($27) + 4|0);
      HEAP32[$28>>2] = $instanceID;
      __THREW__ = 0;
      invoke_vii(1987,0,(0|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       $31 = ($useGUILayout|0)==(0);
       if (!($31)) {
        __THREW__ = 0;
        (invoke_iiii(1333,0,($instanceID|0),0)|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        __THREW__ = 0;
        invoke_vii(2022,0,($instanceID|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(1988,0,0);
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z53UnityEngine_UnityEngine_GUIUtility_m_Internal_ExitGUIP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2733952);
 $0 = HEAP32[2734000>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2734008|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2734000>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_v($7|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z43UnityEngine_UnityEngine_GUIUtility_m_EndGUIP22mscorlib_System_Objecti($__this,$layoutType) {
 $__this = $__this|0;
 $layoutType = $layoutType|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2734056);
 __THREW__ = 0;
 $0 = (invoke_ii(2603,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if ($2) {
   label = 5;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if ($4) {
    label = 5;
   } else {
    __THREW__ = 0;
    $5 = (invoke_ii(2598,($0|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     label = 5;
    } else {
     $8 = ($5|0)!=(8);
     $9 = ($layoutType|0)==(0);
     $or$cond = $8 | $9;
     do {
      if (!($or$cond)) {
       if ((($layoutType|0) == 2)) {
        __THREW__ = 0;
        invoke_vi(2927,0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if ($21) {
         label = 5;
         break L1;
        } else {
         break;
        }
       } else if ((($layoutType|0) == 1)) {
        __THREW__ = 0;
        invoke_vi(2924,0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         label = 5;
         break L1;
        } else {
         break;
        }
       } else {
        break;
       }
      }
     } while(0);
     __THREW__ = 0;
     (invoke_ii(2996,(2734792|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      label = 5;
     } else {
      $24 = HEAP8[((2734792 + 116|0))>>0]|0;
      $25 = ($24<<24>>24)==(0);
      if ($25) {
       __THREW__ = 0;
       (invoke_ii(2996,(2734792|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        label = 5;
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2734792|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        label = 5;
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2734792|0));
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        label = 5;
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2734792|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       label = 5;
      } else {
       $34 = HEAP32[((2734792 + 80|0))>>2]|0;
       $35 = (($34) + 4|0);
       $36 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       (invoke_iiii(1333,0,($36|0),0)|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 5;
       } else {
        __THREW__ = 0;
        invoke_vi(2982,0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 5;
        } else {
         $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 94;
         label = 20;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  $10 = ___cxa_find_matching_catch(348288|0)|0;
  $11 = tempRet0;
  $12 = (_llvm_eh_typeid_for((348288|0))|0);
  $13 = ($11|0)==($12|0);
  if (!($13)) {
   $$0 = $10;$$02 = $11;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$0|0);
   // unreachable;
  }
  $14 = (___cxa_begin_catch(($10|0))|0);
  $15 = HEAP32[$14>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   $__last_unhandled_exception$0 = $15;$leaveInstructions$sroa$0$0 = 0;
   label = 20;
  }
 }
 if ((label|0) == 20) {
  __THREW__ = 0;
  invoke_vi(2939,0);
  $43 = __THREW__; __THREW__ = 0;
  $44 = $43&1;
  if (!($44)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(94);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3844,($__last_unhandled_exception$0|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    // unreachable;
   }
  }
 }
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 $$0 = $41;$$02 = $42;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z53UnityEngine_UnityEngine_GUIContent_m_ClearStaticCacheP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2742512);
 __THREW__ = 0;
 (invoke_ii(2996,(2742984|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2742984 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2742984|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2742984|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2742984|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2742984|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2742984 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($16|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = (($16) + 8|0);
     HEAP32[$19>>2] = 0;
     __THREW__ = 0;
     (invoke_ii(2996,(2742984|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP8[((2742984 + 116|0))>>0]|0;
      $23 = ($22<<24>>24)==(0);
      if ($23) {
       __THREW__ = 0;
       (invoke_ii(2996,(2742984|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2742984|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3843,(2742984|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2742984|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       $32 = HEAP32[((2742984 + 80|0))>>2]|0;
       $33 = (($32) + 8|0);
       $34 = HEAP32[$33>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($34|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        $37 = (($34) + 12|0);
        HEAP32[$37>>2] = 0;
        __THREW__ = 0;
        (invoke_ii(2996,(2742984|0))|0);
        $38 = __THREW__; __THREW__ = 0;
        $39 = $38&1;
        if (!($39)) {
         $40 = HEAP8[((2742984 + 116|0))>>0]|0;
         $41 = ($40<<24>>24)==(0);
         if ($41) {
          __THREW__ = 0;
          (invoke_ii(2996,(2742984|0))|0);
          $42 = __THREW__; __THREW__ = 0;
          $43 = $42&1;
          if ($43) {
           break;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2742984|0))|0);
          $44 = __THREW__; __THREW__ = 0;
          $45 = $44&1;
          if ($45) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3843,(2742984|0));
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2742984|0))|0);
         $48 = __THREW__; __THREW__ = 0;
         $49 = $48&1;
         if (!($49)) {
          $50 = HEAP32[((2742984 + 80|0))>>2]|0;
          $51 = (($50) + 12|0);
          $52 = HEAP32[$51>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($52|0));
          $53 = __THREW__; __THREW__ = 0;
          $54 = $53&1;
          if (!($54)) {
           $55 = (($52) + 8|0);
           HEAP32[$55>>2] = 0;
           __THREW__ = 0;
           (invoke_ii(2996,(2742984|0))|0);
           $56 = __THREW__; __THREW__ = 0;
           $57 = $56&1;
           if (!($57)) {
            $58 = HEAP8[((2742984 + 116|0))>>0]|0;
            $59 = ($58<<24>>24)==(0);
            if ($59) {
             __THREW__ = 0;
             (invoke_ii(2996,(2742984|0))|0);
             $60 = __THREW__; __THREW__ = 0;
             $61 = $60&1;
             if ($61) {
              break;
             }
             __THREW__ = 0;
             (invoke_ii(2996,(2742984|0))|0);
             $62 = __THREW__; __THREW__ = 0;
             $63 = $62&1;
             if ($63) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3843,(2742984|0));
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if ($65) {
              break;
             }
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2742984|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if (!($67)) {
             $68 = HEAP32[((2742984 + 80|0))>>2]|0;
             $69 = (($68) + 12|0);
             $70 = HEAP32[$69>>2]|0;
             __THREW__ = 0;
             invoke_vi(3799,($70|0));
             $71 = __THREW__; __THREW__ = 0;
             $72 = $71&1;
             if (!($72)) {
              $73 = (($70) + 12|0);
              HEAP32[$73>>2] = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z57UnityEngine_UnityEngine_GUIUtility_m_Internal_GetGUIDepthP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2734152);
 $0 = HEAP32[2734200>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2734208|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2734200>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z126UnityEngine_UnityEngine_GUIUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIUtility_m_Internal_GetDefaultSkinP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z119UnityEngine_UnityEngine_GUIUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIUtility_m_Internal_ExitGUIP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z123UnityEngine_UnityEngine_GUIUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIUtility_m_Internal_GetGUIDepthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z43UnityEngine_UnityEngine_GUISettings_m__ctorP35UnityEngine_UnityEngine_GUISettings($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $L_7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $L_2 = sp;
 $L_7 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2734928);
 $0 = (($__this) + 8|0);
 HEAP8[$0>>0] = 1;
 $1 = (($__this) + 9|0);
 HEAP8[$1>>0] = 1;
 __THREW__ = 0;
 invoke_vii(2076,($L_2|0),(0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = (($__this) + 12|0);
  ;HEAP32[$4+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$4+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$4+8>>2]=HEAP32[$L_2+8>>2]|0;HEAP32[$4+12>>2]=HEAP32[$L_2+12>>2]|0;
  $5 = (($__this) + 28|0);
  HEAPF32[$5>>2] = Math_fround(-1.0);
  ;HEAP32[$L_7+0>>2]=0|0;HEAP32[$L_7+4>>2]=0|0;HEAP32[$L_7+8>>2]=0|0;HEAP32[$L_7+12>>2]=0|0;
  __THREW__ = 0;
  invoke_vifff(5,($L_7|0),0.5,0.5,1.0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($__this) + 32|0);
   ;HEAP32[$8+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$8+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$8+8>>2]=HEAP32[$L_7+8>>2]|0;HEAP32[$8+12>>2]=HEAP32[$L_7+12>>2]|0;
   __THREW__ = 0;
   invoke_vi(1924,($__this|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $11 = ___cxa_find_matching_catch()|0;
 $12 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($11|0);
 // unreachable;
}
function __Z91UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_DoubleClickSelectsWordP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z91UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_TripleClickSelectsLineP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z80UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_CursorColorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z85UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_CursorFlashSpeedP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z83UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_SelectionColorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z59UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate_m__ctorP51UnityEngine_UnityEngine_GUISkin_SkinChangedDelegateP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2735512);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z60UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate_m_InvokeP51UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2735560);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(2950,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vi($8|0,($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z65UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate_m_BeginInvokeP51UnityEngine_UnityEngine_GUISkin_SkinChangedDelegateP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$callback,$object) {
 $__this = $__this|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2735608);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z63UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate_m_EndInvokeP51UnityEngine_UnityEngine_GUISkin_SkinChangedDelegateP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2735656);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_GUISkin_m__ctorP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736040);
 __THREW__ = 0;
 (invoke_ii(2996,(2735376|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(3469,(2735376|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vi(2944,($2|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = (($__this) + 104|0);
    HEAP32[$7>>2] = $2;
    __THREW__ = 0;
    invoke_vi(2907,($__this|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     (invoke_ii(2996,(1198704|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_iii(2773,(1198704|0),1)|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = (($__this) + 100|0);
       HEAP32[$15>>2] = $12;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_GUISkin_m_OnEnableP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736088);
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z39UnityEngine_UnityEngine_GUISkin_m_ApplyP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738344);
 __THREW__ = 0;
 invoke_v(964);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 100|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    $7 = HEAP32[2998352>>2]|0;
    __THREW__ = 0;
    invoke_vii(2109,(0|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   invoke_vi(2954,($__this|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_GUISkin_m_get_fontP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736136);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z42UnityEngine_UnityEngine_GUISkin_m_set_fontP31UnityEngine_UnityEngine_GUISkinP28UnityEngine_UnityEngine_Font($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736184);
 $0 = (($__this) + 16|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 (invoke_ii(2996,(2742232|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = HEAP32[((2742232 + 80|0))>>2]|0;
   $4 = (($3) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   $6 = (invoke_iiii(1318,0,($5|0),($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    if ($6) {
     $11 = HEAP32[$0>>2]|0;
     __THREW__ = 0;
     invoke_vii(2064,0,($11|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
    }
    __THREW__ = 0;
    invoke_vi(2953,($__this|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_GUIStyle_m_SetDefaultFontP22mscorlib_System_ObjectP28UnityEngine_UnityEngine_Font($__this,$font) {
 $__this = $__this|0;
 $font = $font|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2748360);
 $0 = HEAP32[2748408>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2748416|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2748408>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($font|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z41UnityEngine_UnityEngine_GUISkin_m_get_boxP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736232);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z41UnityEngine_UnityEngine_GUISkin_m_set_boxP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736280);
 $0 = (($__this) + 20|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43UnityEngine_UnityEngine_GUISkin_m_get_labelP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736328);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z43UnityEngine_UnityEngine_GUISkin_m_set_labelP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736376);
 $0 = (($__this) + 32|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z47UnityEngine_UnityEngine_GUISkin_m_get_textFieldP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736424);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z47UnityEngine_UnityEngine_GUISkin_m_set_textFieldP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736472);
 $0 = (($__this) + 36|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z46UnityEngine_UnityEngine_GUISkin_m_get_textAreaP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736520);
 $0 = (($__this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z46UnityEngine_UnityEngine_GUISkin_m_set_textAreaP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736568);
 $0 = (($__this) + 40|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44UnityEngine_UnityEngine_GUISkin_m_get_buttonP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736616);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z44UnityEngine_UnityEngine_GUISkin_m_set_buttonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736664);
 $0 = (($__this) + 24|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44UnityEngine_UnityEngine_GUISkin_m_get_toggleP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736712);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z44UnityEngine_UnityEngine_GUISkin_m_set_toggleP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736760);
 $0 = (($__this) + 28|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44UnityEngine_UnityEngine_GUISkin_m_get_windowP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736808);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z44UnityEngine_UnityEngine_GUISkin_m_set_windowP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736856);
 $0 = (($__this) + 44|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54UnityEngine_UnityEngine_GUISkin_m_get_horizontalSliderP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736904);
 $0 = (($__this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z54UnityEngine_UnityEngine_GUISkin_m_set_horizontalSliderP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2736952);
 $0 = (($__this) + 48|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z59UnityEngine_UnityEngine_GUISkin_m_get_horizontalSliderThumbP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737000);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z59UnityEngine_UnityEngine_GUISkin_m_set_horizontalSliderThumbP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737048);
 $0 = (($__this) + 52|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z52UnityEngine_UnityEngine_GUISkin_m_get_verticalSliderP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737096);
 $0 = (($__this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z52UnityEngine_UnityEngine_GUISkin_m_set_verticalSliderP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737144);
 $0 = (($__this) + 56|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57UnityEngine_UnityEngine_GUISkin_m_get_verticalSliderThumbP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737192);
 $0 = (($__this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z57UnityEngine_UnityEngine_GUISkin_m_set_verticalSliderThumbP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737240);
 $0 = (($__this) + 60|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57UnityEngine_UnityEngine_GUISkin_m_get_horizontalScrollbarP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737288);
 $0 = (($__this) + 64|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z57UnityEngine_UnityEngine_GUISkin_m_set_horizontalScrollbarP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737336);
 $0 = (($__this) + 64|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62UnityEngine_UnityEngine_GUISkin_m_get_horizontalScrollbarThumbP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737384);
 $0 = (($__this) + 68|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z62UnityEngine_UnityEngine_GUISkin_m_set_horizontalScrollbarThumbP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737432);
 $0 = (($__this) + 68|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z67UnityEngine_UnityEngine_GUISkin_m_get_horizontalScrollbarLeftButtonP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737480);
 $0 = (($__this) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67UnityEngine_UnityEngine_GUISkin_m_set_horizontalScrollbarLeftButtonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737528);
 $0 = (($__this) + 72|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z68UnityEngine_UnityEngine_GUISkin_m_get_horizontalScrollbarRightButtonP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737576);
 $0 = (($__this) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z68UnityEngine_UnityEngine_GUISkin_m_set_horizontalScrollbarRightButtonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737624);
 $0 = (($__this) + 76|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z55UnityEngine_UnityEngine_GUISkin_m_get_verticalScrollbarP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737672);
 $0 = (($__this) + 80|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z55UnityEngine_UnityEngine_GUISkin_m_set_verticalScrollbarP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737720);
 $0 = (($__this) + 80|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z60UnityEngine_UnityEngine_GUISkin_m_get_verticalScrollbarThumbP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737768);
 $0 = (($__this) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z60UnityEngine_UnityEngine_GUISkin_m_set_verticalScrollbarThumbP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737816);
 $0 = (($__this) + 84|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z63UnityEngine_UnityEngine_GUISkin_m_get_verticalScrollbarUpButtonP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737864);
 $0 = (($__this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z63UnityEngine_UnityEngine_GUISkin_m_set_verticalScrollbarUpButtonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737912);
 $0 = (($__this) + 88|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z65UnityEngine_UnityEngine_GUISkin_m_get_verticalScrollbarDownButtonP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2737960);
 $0 = (($__this) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65UnityEngine_UnityEngine_GUISkin_m_set_verticalScrollbarDownButtonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738008);
 $0 = (($__this) + 92|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48UnityEngine_UnityEngine_GUISkin_m_get_scrollViewP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738056);
 $0 = (($__this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z48UnityEngine_UnityEngine_GUISkin_m_set_scrollViewP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738104);
 $0 = (($__this) + 96|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_GUISkin_m_get_customStylesP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738152);
 $0 = (($__this) + 100|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z50UnityEngine_UnityEngine_GUISkin_m_set_customStylesP31UnityEngine_UnityEngine_GUISkinP36UnityEngine_UnityEngine_GUIStyle_arr($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738200);
 $0 = (($__this) + 100|0);
 HEAP32[$0>>2] = $value;
 __THREW__ = 0;
 invoke_vi(2953,($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z46UnityEngine_UnityEngine_GUISkin_m_get_settingsP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738248);
 $0 = (($__this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z43UnityEngine_UnityEngine_GUISkin_m_get_errorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738296);
 __THREW__ = 0;
 (invoke_ii(2996,(2742232|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP32[((2742232 + 80|0))>>2]|0;
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2749952|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($9|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2742232|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    $16 = HEAP32[((2742232 + 80|0))>>2]|0;
    HEAP32[$16>>2] = $9;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2742232|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    $19 = HEAP32[((2742232 + 80|0))>>2]|0;
    $20 = HEAP32[$19>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($20|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z49UnityEngine_UnityEngine_GUISkin_m_BuildStyleCacheP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0;
 var $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0;
 var $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0;
 var $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0;
 var $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0;
 var $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0;
 var $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0;
 var $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0;
 var $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_121 = 0, $L_121$byval_copy = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $L_121$byval_copy = sp + 24|0;
 $_stackTraceSentry = sp;
 $L_121 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738392);
 __THREW__ = 0;
 invoke_v(965);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 20|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2749952|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($11|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    HEAP32[$2>>2] = $11;
   }
   $16 = (($__this) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     break;
    }
    __THREW__ = 0;
    $21 = (invoke_ii(3469,(2749952|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($21|0));
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if ($25) {
     break;
    }
    HEAP32[$16>>2] = $21;
   }
   $26 = (($__this) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ($27|0)==(0|0);
   if ($28) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     break;
    }
    __THREW__ = 0;
    $31 = (invoke_ii(3469,(2749952|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($31|0));
    $34 = __THREW__; __THREW__ = 0;
    $35 = $34&1;
    if ($35) {
     break;
    }
    HEAP32[$26>>2] = $31;
   }
   $36 = (($__this) + 32|0);
   $37 = HEAP32[$36>>2]|0;
   $38 = ($37|0)==(0|0);
   if ($38) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $39 = __THREW__; __THREW__ = 0;
    $40 = $39&1;
    if ($40) {
     break;
    }
    __THREW__ = 0;
    $41 = (invoke_ii(3469,(2749952|0))|0);
    $42 = __THREW__; __THREW__ = 0;
    $43 = $42&1;
    if ($43) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($41|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    HEAP32[$36>>2] = $41;
   }
   $46 = (($__this) + 44|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $49 = __THREW__; __THREW__ = 0;
    $50 = $49&1;
    if ($50) {
     break;
    }
    __THREW__ = 0;
    $51 = (invoke_ii(3469,(2749952|0))|0);
    $52 = __THREW__; __THREW__ = 0;
    $53 = $52&1;
    if ($53) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($51|0));
    $54 = __THREW__; __THREW__ = 0;
    $55 = $54&1;
    if ($55) {
     break;
    }
    HEAP32[$46>>2] = $51;
   }
   $56 = (($__this) + 36|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = ($57|0)==(0|0);
   if ($58) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     break;
    }
    __THREW__ = 0;
    $61 = (invoke_ii(3469,(2749952|0))|0);
    $62 = __THREW__; __THREW__ = 0;
    $63 = $62&1;
    if ($63) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($61|0));
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     break;
    }
    HEAP32[$56>>2] = $61;
   }
   $66 = (($__this) + 40|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(0|0);
   if ($68) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $69 = __THREW__; __THREW__ = 0;
    $70 = $69&1;
    if ($70) {
     break;
    }
    __THREW__ = 0;
    $71 = (invoke_ii(3469,(2749952|0))|0);
    $72 = __THREW__; __THREW__ = 0;
    $73 = $72&1;
    if ($73) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($71|0));
    $74 = __THREW__; __THREW__ = 0;
    $75 = $74&1;
    if ($75) {
     break;
    }
    HEAP32[$66>>2] = $71;
   }
   $76 = (($__this) + 48|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if ($78) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $79 = __THREW__; __THREW__ = 0;
    $80 = $79&1;
    if ($80) {
     break;
    }
    __THREW__ = 0;
    $81 = (invoke_ii(3469,(2749952|0))|0);
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($81|0));
    $84 = __THREW__; __THREW__ = 0;
    $85 = $84&1;
    if ($85) {
     break;
    }
    HEAP32[$76>>2] = $81;
   }
   $86 = (($__this) + 52|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ($87|0)==(0|0);
   if ($88) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $89 = __THREW__; __THREW__ = 0;
    $90 = $89&1;
    if ($90) {
     break;
    }
    __THREW__ = 0;
    $91 = (invoke_ii(3469,(2749952|0))|0);
    $92 = __THREW__; __THREW__ = 0;
    $93 = $92&1;
    if ($93) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($91|0));
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     break;
    }
    HEAP32[$86>>2] = $91;
   }
   $96 = (($__this) + 56|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = ($97|0)==(0|0);
   if ($98) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $99 = __THREW__; __THREW__ = 0;
    $100 = $99&1;
    if ($100) {
     break;
    }
    __THREW__ = 0;
    $101 = (invoke_ii(3469,(2749952|0))|0);
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($101|0));
    $104 = __THREW__; __THREW__ = 0;
    $105 = $104&1;
    if ($105) {
     break;
    }
    HEAP32[$96>>2] = $101;
   }
   $106 = (($__this) + 60|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = ($107|0)==(0|0);
   if ($108) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $109 = __THREW__; __THREW__ = 0;
    $110 = $109&1;
    if ($110) {
     break;
    }
    __THREW__ = 0;
    $111 = (invoke_ii(3469,(2749952|0))|0);
    $112 = __THREW__; __THREW__ = 0;
    $113 = $112&1;
    if ($113) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($111|0));
    $114 = __THREW__; __THREW__ = 0;
    $115 = $114&1;
    if ($115) {
     break;
    }
    HEAP32[$106>>2] = $111;
   }
   $116 = (($__this) + 64|0);
   $117 = HEAP32[$116>>2]|0;
   $118 = ($117|0)==(0|0);
   if ($118) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $119 = __THREW__; __THREW__ = 0;
    $120 = $119&1;
    if ($120) {
     break;
    }
    __THREW__ = 0;
    $121 = (invoke_ii(3469,(2749952|0))|0);
    $122 = __THREW__; __THREW__ = 0;
    $123 = $122&1;
    if ($123) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($121|0));
    $124 = __THREW__; __THREW__ = 0;
    $125 = $124&1;
    if ($125) {
     break;
    }
    HEAP32[$116>>2] = $121;
   }
   $126 = (($__this) + 68|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = ($127|0)==(0|0);
   if ($128) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $129 = __THREW__; __THREW__ = 0;
    $130 = $129&1;
    if ($130) {
     break;
    }
    __THREW__ = 0;
    $131 = (invoke_ii(3469,(2749952|0))|0);
    $132 = __THREW__; __THREW__ = 0;
    $133 = $132&1;
    if ($133) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($131|0));
    $134 = __THREW__; __THREW__ = 0;
    $135 = $134&1;
    if ($135) {
     break;
    }
    HEAP32[$126>>2] = $131;
   }
   $136 = (($__this) + 72|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = ($137|0)==(0|0);
   if ($138) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $139 = __THREW__; __THREW__ = 0;
    $140 = $139&1;
    if ($140) {
     break;
    }
    __THREW__ = 0;
    $141 = (invoke_ii(3469,(2749952|0))|0);
    $142 = __THREW__; __THREW__ = 0;
    $143 = $142&1;
    if ($143) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($141|0));
    $144 = __THREW__; __THREW__ = 0;
    $145 = $144&1;
    if ($145) {
     break;
    }
    HEAP32[$136>>2] = $141;
   }
   $146 = (($__this) + 76|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ($147|0)==(0|0);
   if ($148) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $149 = __THREW__; __THREW__ = 0;
    $150 = $149&1;
    if ($150) {
     break;
    }
    __THREW__ = 0;
    $151 = (invoke_ii(3469,(2749952|0))|0);
    $152 = __THREW__; __THREW__ = 0;
    $153 = $152&1;
    if ($153) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($151|0));
    $154 = __THREW__; __THREW__ = 0;
    $155 = $154&1;
    if ($155) {
     break;
    }
    HEAP32[$146>>2] = $151;
   }
   $156 = (($__this) + 80|0);
   $157 = HEAP32[$156>>2]|0;
   $158 = ($157|0)==(0|0);
   if ($158) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $159 = __THREW__; __THREW__ = 0;
    $160 = $159&1;
    if ($160) {
     break;
    }
    __THREW__ = 0;
    $161 = (invoke_ii(3469,(2749952|0))|0);
    $162 = __THREW__; __THREW__ = 0;
    $163 = $162&1;
    if ($163) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($161|0));
    $164 = __THREW__; __THREW__ = 0;
    $165 = $164&1;
    if ($165) {
     break;
    }
    HEAP32[$156>>2] = $161;
   }
   $166 = (($__this) + 84|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = ($167|0)==(0|0);
   if ($168) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $169 = __THREW__; __THREW__ = 0;
    $170 = $169&1;
    if ($170) {
     break;
    }
    __THREW__ = 0;
    $171 = (invoke_ii(3469,(2749952|0))|0);
    $172 = __THREW__; __THREW__ = 0;
    $173 = $172&1;
    if ($173) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($171|0));
    $174 = __THREW__; __THREW__ = 0;
    $175 = $174&1;
    if ($175) {
     break;
    }
    HEAP32[$166>>2] = $171;
   }
   $176 = (($__this) + 88|0);
   $177 = HEAP32[$176>>2]|0;
   $178 = ($177|0)==(0|0);
   if ($178) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $179 = __THREW__; __THREW__ = 0;
    $180 = $179&1;
    if ($180) {
     break;
    }
    __THREW__ = 0;
    $181 = (invoke_ii(3469,(2749952|0))|0);
    $182 = __THREW__; __THREW__ = 0;
    $183 = $182&1;
    if ($183) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($181|0));
    $184 = __THREW__; __THREW__ = 0;
    $185 = $184&1;
    if ($185) {
     break;
    }
    HEAP32[$176>>2] = $181;
   }
   $186 = (($__this) + 92|0);
   $187 = HEAP32[$186>>2]|0;
   $188 = ($187|0)==(0|0);
   if ($188) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $189 = __THREW__; __THREW__ = 0;
    $190 = $189&1;
    if ($190) {
     break;
    }
    __THREW__ = 0;
    $191 = (invoke_ii(3469,(2749952|0))|0);
    $192 = __THREW__; __THREW__ = 0;
    $193 = $192&1;
    if ($193) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($191|0));
    $194 = __THREW__; __THREW__ = 0;
    $195 = $194&1;
    if ($195) {
     break;
    }
    HEAP32[$186>>2] = $191;
   }
   $196 = (($__this) + 96|0);
   $197 = HEAP32[$196>>2]|0;
   $198 = ($197|0)==(0|0);
   if ($198) {
    __THREW__ = 0;
    (invoke_ii(2996,(2749952|0))|0);
    $199 = __THREW__; __THREW__ = 0;
    $200 = $199&1;
    if ($200) {
     break;
    }
    __THREW__ = 0;
    $201 = (invoke_ii(3469,(2749952|0))|0);
    $202 = __THREW__; __THREW__ = 0;
    $203 = $202&1;
    if ($203) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3007,($201|0));
    $204 = __THREW__; __THREW__ = 0;
    $205 = $204&1;
    if ($205) {
     break;
    }
    HEAP32[$196>>2] = $201;
   }
   __THREW__ = 0;
   $206 = (invoke_ii(2493,(0|0))|0);
   $207 = __THREW__; __THREW__ = 0;
   $208 = $207&1;
   if ($208) {
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1919768|0))|0);
   $209 = __THREW__; __THREW__ = 0;
   $210 = $209&1;
   if ($210) {
    break;
   }
   __THREW__ = 0;
   $211 = (invoke_ii(3469,(1919768|0))|0);
   $212 = __THREW__; __THREW__ = 0;
   $213 = $212&1;
   if ($213) {
    break;
   }
   __THREW__ = 0;
   invoke_vii(3501,($211|0),($206|0));
   $214 = __THREW__; __THREW__ = 0;
   $215 = $214&1;
   if ($215) {
    break;
   }
   $216 = (($__this) + 108|0);
   HEAP32[$216>>2] = $211;
   $217 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($211|0));
   $218 = __THREW__; __THREW__ = 0;
   $219 = $218&1;
   if ($219) {
    break;
   }
   $220 = HEAP32[2998416>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($211|0),($220|0),($217|0));
   $221 = __THREW__; __THREW__ = 0;
   $222 = $221&1;
   if ($222) {
    break;
   }
   $223 = HEAP32[$2>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($223|0));
   $224 = __THREW__; __THREW__ = 0;
   $225 = $224&1;
   if ($225) {
    break;
   }
   $226 = HEAP32[2998424>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($223|0),($226|0));
   $227 = __THREW__; __THREW__ = 0;
   $228 = $227&1;
   if ($228) {
    break;
   }
   $229 = HEAP32[$216>>2]|0;
   $230 = HEAP32[$16>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($229|0));
   $231 = __THREW__; __THREW__ = 0;
   $232 = $231&1;
   if ($232) {
    break;
   }
   $233 = HEAP32[2998432>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($229|0),($233|0),($230|0));
   $234 = __THREW__; __THREW__ = 0;
   $235 = $234&1;
   if ($235) {
    break;
   }
   $236 = HEAP32[$16>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($236|0));
   $237 = __THREW__; __THREW__ = 0;
   $238 = $237&1;
   if ($238) {
    break;
   }
   $239 = HEAP32[2998440>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($236|0),($239|0));
   $240 = __THREW__; __THREW__ = 0;
   $241 = $240&1;
   if ($241) {
    break;
   }
   $242 = HEAP32[$216>>2]|0;
   $243 = HEAP32[$26>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($242|0));
   $244 = __THREW__; __THREW__ = 0;
   $245 = $244&1;
   if ($245) {
    break;
   }
   $246 = HEAP32[2998448>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($242|0),($246|0),($243|0));
   $247 = __THREW__; __THREW__ = 0;
   $248 = $247&1;
   if ($248) {
    break;
   }
   $249 = HEAP32[$26>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($249|0));
   $250 = __THREW__; __THREW__ = 0;
   $251 = $250&1;
   if ($251) {
    break;
   }
   $252 = HEAP32[2998456>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($249|0),($252|0));
   $253 = __THREW__; __THREW__ = 0;
   $254 = $253&1;
   if ($254) {
    break;
   }
   $255 = HEAP32[$216>>2]|0;
   $256 = HEAP32[$36>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($255|0));
   $257 = __THREW__; __THREW__ = 0;
   $258 = $257&1;
   if ($258) {
    break;
   }
   $259 = HEAP32[2998464>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($255|0),($259|0),($256|0));
   $260 = __THREW__; __THREW__ = 0;
   $261 = $260&1;
   if ($261) {
    break;
   }
   $262 = HEAP32[$36>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($262|0));
   $263 = __THREW__; __THREW__ = 0;
   $264 = $263&1;
   if ($264) {
    break;
   }
   $265 = HEAP32[2998472>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($262|0),($265|0));
   $266 = __THREW__; __THREW__ = 0;
   $267 = $266&1;
   if ($267) {
    break;
   }
   $268 = HEAP32[$216>>2]|0;
   $269 = HEAP32[$46>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($268|0));
   $270 = __THREW__; __THREW__ = 0;
   $271 = $270&1;
   if ($271) {
    break;
   }
   $272 = HEAP32[2998480>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($268|0),($272|0),($269|0));
   $273 = __THREW__; __THREW__ = 0;
   $274 = $273&1;
   if ($274) {
    break;
   }
   $275 = HEAP32[$46>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($275|0));
   $276 = __THREW__; __THREW__ = 0;
   $277 = $276&1;
   if ($277) {
    break;
   }
   $278 = HEAP32[2998488>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($275|0),($278|0));
   $279 = __THREW__; __THREW__ = 0;
   $280 = $279&1;
   if ($280) {
    break;
   }
   $281 = HEAP32[$216>>2]|0;
   $282 = HEAP32[$56>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($281|0));
   $283 = __THREW__; __THREW__ = 0;
   $284 = $283&1;
   if ($284) {
    break;
   }
   $285 = HEAP32[2998496>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($281|0),($285|0),($282|0));
   $286 = __THREW__; __THREW__ = 0;
   $287 = $286&1;
   if ($287) {
    break;
   }
   $288 = HEAP32[$56>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($288|0));
   $289 = __THREW__; __THREW__ = 0;
   $290 = $289&1;
   if ($290) {
    break;
   }
   $291 = HEAP32[2998504>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($288|0),($291|0));
   $292 = __THREW__; __THREW__ = 0;
   $293 = $292&1;
   if ($293) {
    break;
   }
   $294 = HEAP32[$216>>2]|0;
   $295 = HEAP32[$66>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($294|0));
   $296 = __THREW__; __THREW__ = 0;
   $297 = $296&1;
   if ($297) {
    break;
   }
   $298 = HEAP32[2998512>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($294|0),($298|0),($295|0));
   $299 = __THREW__; __THREW__ = 0;
   $300 = $299&1;
   if ($300) {
    break;
   }
   $301 = HEAP32[$66>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($301|0));
   $302 = __THREW__; __THREW__ = 0;
   $303 = $302&1;
   if ($303) {
    break;
   }
   $304 = HEAP32[2998520>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($301|0),($304|0));
   $305 = __THREW__; __THREW__ = 0;
   $306 = $305&1;
   if ($306) {
    break;
   }
   $307 = HEAP32[$216>>2]|0;
   $308 = HEAP32[$76>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($307|0));
   $309 = __THREW__; __THREW__ = 0;
   $310 = $309&1;
   if ($310) {
    break;
   }
   $311 = HEAP32[2998528>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($307|0),($311|0),($308|0));
   $312 = __THREW__; __THREW__ = 0;
   $313 = $312&1;
   if ($313) {
    break;
   }
   $314 = HEAP32[$76>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($314|0));
   $315 = __THREW__; __THREW__ = 0;
   $316 = $315&1;
   if ($316) {
    break;
   }
   $317 = HEAP32[2998536>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($314|0),($317|0));
   $318 = __THREW__; __THREW__ = 0;
   $319 = $318&1;
   if ($319) {
    break;
   }
   $320 = HEAP32[$216>>2]|0;
   $321 = HEAP32[$86>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($320|0));
   $322 = __THREW__; __THREW__ = 0;
   $323 = $322&1;
   if ($323) {
    break;
   }
   $324 = HEAP32[2998544>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($320|0),($324|0),($321|0));
   $325 = __THREW__; __THREW__ = 0;
   $326 = $325&1;
   if ($326) {
    break;
   }
   $327 = HEAP32[$86>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($327|0));
   $328 = __THREW__; __THREW__ = 0;
   $329 = $328&1;
   if ($329) {
    break;
   }
   $330 = HEAP32[2998552>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($327|0),($330|0));
   $331 = __THREW__; __THREW__ = 0;
   $332 = $331&1;
   if ($332) {
    break;
   }
   $333 = HEAP32[$216>>2]|0;
   $334 = HEAP32[$96>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($333|0));
   $335 = __THREW__; __THREW__ = 0;
   $336 = $335&1;
   if ($336) {
    break;
   }
   $337 = HEAP32[2998560>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($333|0),($337|0),($334|0));
   $338 = __THREW__; __THREW__ = 0;
   $339 = $338&1;
   if ($339) {
    break;
   }
   $340 = HEAP32[$96>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($340|0));
   $341 = __THREW__; __THREW__ = 0;
   $342 = $341&1;
   if ($342) {
    break;
   }
   $343 = HEAP32[2998568>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($340|0),($343|0));
   $344 = __THREW__; __THREW__ = 0;
   $345 = $344&1;
   if ($345) {
    break;
   }
   $346 = HEAP32[$216>>2]|0;
   $347 = HEAP32[$106>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($346|0));
   $348 = __THREW__; __THREW__ = 0;
   $349 = $348&1;
   if ($349) {
    break;
   }
   $350 = HEAP32[2998576>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($346|0),($350|0),($347|0));
   $351 = __THREW__; __THREW__ = 0;
   $352 = $351&1;
   if ($352) {
    break;
   }
   $353 = HEAP32[$106>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($353|0));
   $354 = __THREW__; __THREW__ = 0;
   $355 = $354&1;
   if ($355) {
    break;
   }
   $356 = HEAP32[2998584>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($353|0),($356|0));
   $357 = __THREW__; __THREW__ = 0;
   $358 = $357&1;
   if ($358) {
    break;
   }
   $359 = HEAP32[$216>>2]|0;
   $360 = HEAP32[$116>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($359|0));
   $361 = __THREW__; __THREW__ = 0;
   $362 = $361&1;
   if ($362) {
    break;
   }
   $363 = HEAP32[2998592>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($359|0),($363|0),($360|0));
   $364 = __THREW__; __THREW__ = 0;
   $365 = $364&1;
   if ($365) {
    break;
   }
   $366 = HEAP32[$116>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($366|0));
   $367 = __THREW__; __THREW__ = 0;
   $368 = $367&1;
   if ($368) {
    break;
   }
   $369 = HEAP32[2998600>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($366|0),($369|0));
   $370 = __THREW__; __THREW__ = 0;
   $371 = $370&1;
   if ($371) {
    break;
   }
   $372 = HEAP32[$216>>2]|0;
   $373 = HEAP32[$126>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($372|0));
   $374 = __THREW__; __THREW__ = 0;
   $375 = $374&1;
   if ($375) {
    break;
   }
   $376 = HEAP32[2998608>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($372|0),($376|0),($373|0));
   $377 = __THREW__; __THREW__ = 0;
   $378 = $377&1;
   if ($378) {
    break;
   }
   $379 = HEAP32[$126>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($379|0));
   $380 = __THREW__; __THREW__ = 0;
   $381 = $380&1;
   if ($381) {
    break;
   }
   $382 = HEAP32[2998616>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($379|0),($382|0));
   $383 = __THREW__; __THREW__ = 0;
   $384 = $383&1;
   if ($384) {
    break;
   }
   $385 = HEAP32[$216>>2]|0;
   $386 = HEAP32[$136>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($385|0));
   $387 = __THREW__; __THREW__ = 0;
   $388 = $387&1;
   if ($388) {
    break;
   }
   $389 = HEAP32[2998624>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($385|0),($389|0),($386|0));
   $390 = __THREW__; __THREW__ = 0;
   $391 = $390&1;
   if ($391) {
    break;
   }
   $392 = HEAP32[$136>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($392|0));
   $393 = __THREW__; __THREW__ = 0;
   $394 = $393&1;
   if ($394) {
    break;
   }
   $395 = HEAP32[2998632>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($392|0),($395|0));
   $396 = __THREW__; __THREW__ = 0;
   $397 = $396&1;
   if ($397) {
    break;
   }
   $398 = HEAP32[$216>>2]|0;
   $399 = HEAP32[$146>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($398|0));
   $400 = __THREW__; __THREW__ = 0;
   $401 = $400&1;
   if ($401) {
    break;
   }
   $402 = HEAP32[2998640>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($398|0),($402|0),($399|0));
   $403 = __THREW__; __THREW__ = 0;
   $404 = $403&1;
   if ($404) {
    break;
   }
   $405 = HEAP32[$146>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($405|0));
   $406 = __THREW__; __THREW__ = 0;
   $407 = $406&1;
   if ($407) {
    break;
   }
   $408 = HEAP32[2998648>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($405|0),($408|0));
   $409 = __THREW__; __THREW__ = 0;
   $410 = $409&1;
   if ($410) {
    break;
   }
   $411 = HEAP32[$216>>2]|0;
   $412 = HEAP32[$156>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($411|0));
   $413 = __THREW__; __THREW__ = 0;
   $414 = $413&1;
   if ($414) {
    break;
   }
   $415 = HEAP32[2998656>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($411|0),($415|0),($412|0));
   $416 = __THREW__; __THREW__ = 0;
   $417 = $416&1;
   if ($417) {
    break;
   }
   $418 = HEAP32[$156>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($418|0));
   $419 = __THREW__; __THREW__ = 0;
   $420 = $419&1;
   if ($420) {
    break;
   }
   $421 = HEAP32[2998664>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($418|0),($421|0));
   $422 = __THREW__; __THREW__ = 0;
   $423 = $422&1;
   if ($423) {
    break;
   }
   $424 = HEAP32[$216>>2]|0;
   $425 = HEAP32[$166>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($424|0));
   $426 = __THREW__; __THREW__ = 0;
   $427 = $426&1;
   if ($427) {
    break;
   }
   $428 = HEAP32[2998672>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($424|0),($428|0),($425|0));
   $429 = __THREW__; __THREW__ = 0;
   $430 = $429&1;
   if ($430) {
    break;
   }
   $431 = HEAP32[$166>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($431|0));
   $432 = __THREW__; __THREW__ = 0;
   $433 = $432&1;
   if ($433) {
    break;
   }
   $434 = HEAP32[2998680>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($431|0),($434|0));
   $435 = __THREW__; __THREW__ = 0;
   $436 = $435&1;
   if ($436) {
    break;
   }
   $437 = HEAP32[$216>>2]|0;
   $438 = HEAP32[$176>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($437|0));
   $439 = __THREW__; __THREW__ = 0;
   $440 = $439&1;
   if ($440) {
    break;
   }
   $441 = HEAP32[2998688>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($437|0),($441|0),($438|0));
   $442 = __THREW__; __THREW__ = 0;
   $443 = $442&1;
   if ($443) {
    break;
   }
   $444 = HEAP32[$176>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($444|0));
   $445 = __THREW__; __THREW__ = 0;
   $446 = $445&1;
   if ($446) {
    break;
   }
   $447 = HEAP32[2998696>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($444|0),($447|0));
   $448 = __THREW__; __THREW__ = 0;
   $449 = $448&1;
   if ($449) {
    break;
   }
   $450 = HEAP32[$216>>2]|0;
   $451 = HEAP32[$186>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($450|0));
   $452 = __THREW__; __THREW__ = 0;
   $453 = $452&1;
   if ($453) {
    break;
   }
   $454 = HEAP32[2998704>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($450|0),($454|0),($451|0));
   $455 = __THREW__; __THREW__ = 0;
   $456 = $455&1;
   if ($456) {
    break;
   }
   $457 = HEAP32[$186>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($457|0));
   $458 = __THREW__; __THREW__ = 0;
   $459 = $458&1;
   if ($459) {
    break;
   }
   $460 = HEAP32[2998712>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($457|0),($460|0));
   $461 = __THREW__; __THREW__ = 0;
   $462 = $461&1;
   if ($462) {
    break;
   }
   $463 = HEAP32[$216>>2]|0;
   $464 = HEAP32[$196>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($463|0));
   $465 = __THREW__; __THREW__ = 0;
   $466 = $465&1;
   if ($466) {
    break;
   }
   $467 = HEAP32[2998720>>2]|0;
   __THREW__ = 0;
   invoke_viiii(460,(1918288|0),($463|0),($467|0),($464|0));
   $468 = __THREW__; __THREW__ = 0;
   $469 = $468&1;
   if ($469) {
    break;
   }
   $470 = HEAP32[$196>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($470|0));
   $471 = __THREW__; __THREW__ = 0;
   $472 = $471&1;
   if ($472) {
    break;
   }
   $473 = HEAP32[2998728>>2]|0;
   __THREW__ = 0;
   invoke_vii(2061,($470|0),($473|0));
   $474 = __THREW__; __THREW__ = 0;
   $475 = $474&1;
   if ($475) {
    break;
   }
   $476 = (($__this) + 100|0);
   $477 = HEAP32[$476>>2]|0;
   $478 = ($477|0)==(0|0);
   L207: do {
    if (!($478)) {
     $543 = $477;$V_0$0 = 0;
     while(1) {
      __THREW__ = 0;
      invoke_vi(3799,($543|0));
      $544 = __THREW__; __THREW__ = 0;
      $545 = $544&1;
      if ($545) {
       break;
      }
      $546 = (($543) + 12|0);
      $547 = HEAP32[$546>>2]|0;
      $548 = ($V_0$0|0)<($547|0);
      if (!($548)) {
       break L207;
      }
      $480 = HEAP32[$476>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($480|0));
      $549 = __THREW__; __THREW__ = 0;
      $550 = $549&1;
      if ($550) {
       break;
      }
      $479 = (($480) + 12|0);
      $481 = HEAP32[$479>>2]|0;
      $482 = ($V_0$0>>>0)<($481>>>0);
      if (!($482)) {
       __THREW__ = 0;
       $483 = (invoke_i(132)|0);
       $484 = __THREW__; __THREW__ = 0;
       $485 = $484&1;
       if ($485) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($483|0));
       $486 = __THREW__; __THREW__ = 0;
       $487 = $486&1;
       if ($487) {
        break;
       }
      }
      $488 = HEAP32[$480>>2]|0;
      $489 = (($480) + 16|0);
      $490 = (($488) + 92|0);
      $491 = HEAP32[$490>>2]|0;
      $492 = Math_imul($491, $V_0$0)|0;
      $493 = (($489) + ($492)|0);
      $494 = HEAP32[$493>>2]|0;
      $495 = ($494|0)==(0|0);
      if (!($495)) {
       $496 = HEAP32[$216>>2]|0;
       $497 = HEAP32[$476>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($497|0));
       $498 = __THREW__; __THREW__ = 0;
       $499 = $498&1;
       if ($499) {
        break;
       }
       $500 = (($497) + 12|0);
       $501 = HEAP32[$500>>2]|0;
       $502 = ($V_0$0>>>0)<($501>>>0);
       if (!($502)) {
        __THREW__ = 0;
        $503 = (invoke_i(132)|0);
        $504 = __THREW__; __THREW__ = 0;
        $505 = $504&1;
        if ($505) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($503|0));
        $506 = __THREW__; __THREW__ = 0;
        $507 = $506&1;
        if ($507) {
         break;
        }
       }
       $508 = HEAP32[$497>>2]|0;
       $509 = (($497) + 16|0);
       $510 = (($508) + 92|0);
       $511 = HEAP32[$510>>2]|0;
       $512 = Math_imul($511, $V_0$0)|0;
       $513 = (($509) + ($512)|0);
       $514 = HEAP32[$513>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($514|0));
       $515 = __THREW__; __THREW__ = 0;
       $516 = $515&1;
       if ($516) {
        break;
       }
       __THREW__ = 0;
       $517 = (invoke_ii(2590,($514|0))|0);
       $518 = __THREW__; __THREW__ = 0;
       $519 = $518&1;
       if ($519) {
        break;
       }
       $520 = HEAP32[$476>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($520|0));
       $521 = __THREW__; __THREW__ = 0;
       $522 = $521&1;
       if ($522) {
        break;
       }
       $523 = (($520) + 12|0);
       $524 = HEAP32[$523>>2]|0;
       $525 = ($V_0$0>>>0)<($524>>>0);
       if (!($525)) {
        __THREW__ = 0;
        $526 = (invoke_i(132)|0);
        $527 = __THREW__; __THREW__ = 0;
        $528 = $527&1;
        if ($528) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($526|0));
        $529 = __THREW__; __THREW__ = 0;
        $530 = $529&1;
        if ($530) {
         break;
        }
       }
       $531 = HEAP32[$520>>2]|0;
       $532 = (($520) + 16|0);
       $533 = (($531) + 92|0);
       $534 = HEAP32[$533>>2]|0;
       $535 = Math_imul($534, $V_0$0)|0;
       $536 = (($532) + ($535)|0);
       $537 = HEAP32[$536>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($496|0));
       $538 = __THREW__; __THREW__ = 0;
       $539 = $538&1;
       if ($539) {
        break;
       }
       __THREW__ = 0;
       invoke_viiii(460,(1918288|0),($496|0),($517|0),($537|0));
       $540 = __THREW__; __THREW__ = 0;
       $541 = $540&1;
       if ($541) {
        break;
       }
      }
      $542 = (($V_0$0) + 1)|0;
      $$pre = HEAP32[$476>>2]|0;
      $543 = $$pre;$V_0$0 = $542;
     }
     $5 = ___cxa_find_matching_catch()|0;
     $6 = tempRet0;
     $lpad$phi$index = $5;$lpad$phi$index2 = $6;
     __ZN16StackTraceSentryD2Ev(0);
     ___resumeException($lpad$phi$index|0);
     // unreachable;
    }
   } while(0);
   __THREW__ = 0;
   $551 = (invoke_ii(2580,0)|0);
   $552 = __THREW__; __THREW__ = 0;
   $553 = $552&1;
   if ($553) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($551|0));
   $554 = __THREW__; __THREW__ = 0;
   $555 = $554&1;
   if ($555) {
    break;
   }
   __THREW__ = 0;
   invoke_vii(2063,($551|0),1);
   $556 = __THREW__; __THREW__ = 0;
   $557 = $556&1;
   if ($557) {
    break;
   }
   __THREW__ = 0;
   $558 = (invoke_ii(2580,0)|0);
   $559 = __THREW__; __THREW__ = 0;
   $560 = $559&1;
   if ($560) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($558|0));
   $561 = __THREW__; __THREW__ = 0;
   $562 = $561&1;
   if ($562) {
    break;
   }
   __THREW__ = 0;
   $563 = (invoke_ii(2591,($558|0))|0);
   $564 = __THREW__; __THREW__ = 0;
   $565 = $564&1;
   if ($565) {
    break;
   }
   __THREW__ = 0;
   invoke_vii(2075,($L_121|0),(0|0));
   $566 = __THREW__; __THREW__ = 0;
   $567 = $566&1;
   if ($567) {
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($563|0));
   $568 = __THREW__; __THREW__ = 0;
   $569 = $568&1;
   if ($569) {
    break;
   }
   __THREW__ = 0;
   ;HEAP32[$L_121$byval_copy+0>>2]=HEAP32[$L_121+0>>2]|0;HEAP32[$L_121$byval_copy+4>>2]=HEAP32[$L_121+4>>2]|0;HEAP32[$L_121$byval_copy+8>>2]=HEAP32[$L_121+8>>2]|0;HEAP32[$L_121$byval_copy+12>>2]=HEAP32[$L_121+12>>2]|0;
   invoke_vii(2056,($563|0),($L_121$byval_copy|0));
   $570 = __THREW__; __THREW__ = 0;
   $571 = $570&1;
   if ($571) {
    break;
   }
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z43UnityEngine_UnityEngine_GUIStyle_m_set_nameP32UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747264);
 $0 = HEAP32[2747312>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747320|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747312>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z52UnityEngine_UnityEngine_GUIStyle_m_set_stretchHeightP32UnityEngine_UnityEngine_GUIStyleb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2748248);
 $0 = HEAP32[2748296>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2748304|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2748296>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_GUIStyle_m_get_normalP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747368);
 $1 = (($__this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $14 = $2;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($14|0);
 }
 __THREW__ = 0;
 $4 = (invoke_iii(1210,($__this|0),0)|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2743968|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_ii(3469,(2743968|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$0>>2] = $4;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    invoke_viii(736,($9|0),($__this|0),($$byval_copy|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     HEAP32[$1>>2] = $9;
     $14 = $9;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($14|0);
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z53UnityEngine_UnityEngine_GUIStyleState_m_set_textColorP37UnityEngine_UnityEngine_GUIStyleState29UnityEngine_UnityEngine_Color($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2743552);
 __THREW__ = 0;
 invoke_vii(2055,($__this|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42UnityEngine_UnityEngine_GUISkin_m_GetStyleP31UnityEngine_UnityEngine_GUISkinP22mscorlib_System_String($__this,$styleName) {
 $__this = $__this|0;
 $styleName = $styleName|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_24 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_24 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738440);
 __THREW__ = 0;
 invoke_v(966);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(1209,($__this|0),($styleName|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if (!($5)) {
     $$0 = $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2773,(1167664|0),6)|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3799,($10|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       $15 = (($10) + 12|0);
       $16 = HEAP32[$15>>2]|0;
       $17 = ($16|0)==(0);
       if ($17) {
        __THREW__ = 0;
        $18 = (invoke_i(132)|0);
        $19 = __THREW__; __THREW__ = 0;
        $20 = $19&1;
        if ($20) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($18|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if ($22) {
         break;
        }
       }
       $23 = HEAP32[2999448>>2]|0;
       __THREW__ = 0;
       invoke_vii(3492,($10|0),($23|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        $26 = HEAP32[2999448>>2]|0;
        $27 = (($10) + 16|0);
        HEAP32[$27>>2] = $26;
        __THREW__ = 0;
        invoke_vi(3799,($10|0));
        $28 = __THREW__; __THREW__ = 0;
        $29 = $28&1;
        if (!($29)) {
         $30 = HEAP32[$15>>2]|0;
         $31 = ($30>>>0)<(2);
         if ($31) {
          __THREW__ = 0;
          $32 = (invoke_i(132)|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($32|0));
          $35 = __THREW__; __THREW__ = 0;
          $36 = $35&1;
          if ($36) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($10|0),($styleName|0));
         $37 = __THREW__; __THREW__ = 0;
         $38 = $37&1;
         if (!($38)) {
          $39 = HEAP32[$10>>2]|0;
          $40 = (($39) + 92|0);
          $41 = HEAP32[$40>>2]|0;
          $42 = (($27) + ($41)|0);
          HEAP32[$42>>2] = $styleName;
          __THREW__ = 0;
          invoke_vi(3799,($10|0));
          $43 = __THREW__; __THREW__ = 0;
          $44 = $43&1;
          if (!($44)) {
           $45 = HEAP32[$15>>2]|0;
           $46 = ($45>>>0)<(3);
           if ($46) {
            __THREW__ = 0;
            $47 = (invoke_i(132)|0);
            $48 = __THREW__; __THREW__ = 0;
            $49 = $48&1;
            if ($49) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3302,($47|0));
            $50 = __THREW__; __THREW__ = 0;
            $51 = $50&1;
            if ($51) {
             break;
            }
           }
           $52 = HEAP32[2999456>>2]|0;
           __THREW__ = 0;
           invoke_vii(3492,($10|0),($52|0));
           $53 = __THREW__; __THREW__ = 0;
           $54 = $53&1;
           if (!($54)) {
            $55 = HEAP32[2999456>>2]|0;
            $56 = HEAP32[$10>>2]|0;
            $57 = (($56) + 92|0);
            $58 = HEAP32[$57>>2]|0;
            $59 = $58 << 1;
            $60 = (($27) + ($59)|0);
            HEAP32[$60>>2] = $55;
            __THREW__ = 0;
            $61 = (invoke_ii(2528,($__this|0))|0);
            $62 = __THREW__; __THREW__ = 0;
            $63 = $62&1;
            if (!($63)) {
             __THREW__ = 0;
             invoke_vi(3799,($10|0));
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if (!($65)) {
              $66 = HEAP32[$15>>2]|0;
              $67 = ($66>>>0)<(4);
              if ($67) {
               __THREW__ = 0;
               $68 = (invoke_i(132)|0);
               $69 = __THREW__; __THREW__ = 0;
               $70 = $69&1;
               if ($70) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($68|0));
               $71 = __THREW__; __THREW__ = 0;
               $72 = $71&1;
               if ($72) {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vii(3492,($10|0),($61|0));
              $73 = __THREW__; __THREW__ = 0;
              $74 = $73&1;
              if (!($74)) {
               $75 = HEAP32[$10>>2]|0;
               $76 = (($75) + 92|0);
               $77 = HEAP32[$76>>2]|0;
               $78 = ($77*3)|0;
               $79 = (($27) + ($78)|0);
               HEAP32[$79>>2] = $61;
               __THREW__ = 0;
               invoke_vi(3799,($10|0));
               $80 = __THREW__; __THREW__ = 0;
               $81 = $80&1;
               if (!($81)) {
                $82 = HEAP32[$15>>2]|0;
                $83 = ($82>>>0)<(5);
                if ($83) {
                 __THREW__ = 0;
                 $84 = (invoke_i(132)|0);
                 $85 = __THREW__; __THREW__ = 0;
                 $86 = $85&1;
                 if ($86) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($84|0));
                 $87 = __THREW__; __THREW__ = 0;
                 $88 = $87&1;
                 if ($88) {
                  break;
                 }
                }
                $89 = HEAP32[2999464>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($10|0),($89|0));
                $90 = __THREW__; __THREW__ = 0;
                $91 = $90&1;
                if ($91) {
                 break;
                }
                $92 = HEAP32[2999464>>2]|0;
                $93 = HEAP32[$10>>2]|0;
                $94 = (($93) + 92|0);
                $95 = HEAP32[$94>>2]|0;
                $96 = $95 << 2;
                $97 = (($27) + ($96)|0);
                HEAP32[$97>>2] = $92;
                __THREW__ = 0;
                $98 = (invoke_ii(2603,0)|0);
                $99 = __THREW__; __THREW__ = 0;
                $100 = $99&1;
                if ($100) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($98|0));
                $101 = __THREW__; __THREW__ = 0;
                $102 = $101&1;
                if ($102) {
                 break;
                }
                __THREW__ = 0;
                $103 = (invoke_ii(2598,($98|0))|0);
                $104 = __THREW__; __THREW__ = 0;
                $105 = $104&1;
                if ($105) {
                 break;
                }
                HEAP32[$L_24>>2] = $103;
                __THREW__ = 0;
                (invoke_ii(2996,(2770104|0))|0);
                $106 = __THREW__; __THREW__ = 0;
                $107 = $106&1;
                if ($107) {
                 break;
                }
                __THREW__ = 0;
                $108 = (invoke_iii(2724,(2770104|0),($L_24|0))|0);
                $109 = __THREW__; __THREW__ = 0;
                $110 = $109&1;
                if ($110) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($10|0));
                $111 = __THREW__; __THREW__ = 0;
                $112 = $111&1;
                if ($112) {
                 break;
                }
                $113 = HEAP32[$15>>2]|0;
                $114 = ($113>>>0)<(6);
                if ($114) {
                 __THREW__ = 0;
                 $115 = (invoke_i(132)|0);
                 $116 = __THREW__; __THREW__ = 0;
                 $117 = $116&1;
                 if ($117) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($115|0));
                 $118 = __THREW__; __THREW__ = 0;
                 $119 = $118&1;
                 if ($119) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($10|0),($108|0));
                $120 = __THREW__; __THREW__ = 0;
                $121 = $120&1;
                if ($121) {
                 break;
                }
                $122 = HEAP32[$10>>2]|0;
                $123 = (($122) + 92|0);
                $124 = HEAP32[$123>>2]|0;
                $125 = ($124*5)|0;
                $126 = (($27) + ($125)|0);
                HEAP32[$126>>2] = $108;
                __THREW__ = 0;
                $127 = (invoke_iii(638,(0|0),($10|0))|0);
                $128 = __THREW__; __THREW__ = 0;
                $129 = $128&1;
                if ($129) {
                 break;
                }
                __THREW__ = 0;
                invoke_vii(2111,(0|0),($127|0));
                $130 = __THREW__; __THREW__ = 0;
                $131 = $130&1;
                if ($131) {
                 break;
                }
                __THREW__ = 0;
                $132 = (invoke_ii(2580,0)|0);
                $133 = __THREW__; __THREW__ = 0;
                $134 = $133&1;
                if ($134) {
                 break;
                } else {
                 $$0 = $132;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_GUISkin_m_FindStyleP31UnityEngine_UnityEngine_GUISkinP22mscorlib_System_String($__this,$styleName) {
 $__this = $__this|0;
 $styleName = $styleName|0;
 var $$ = 0, $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738488);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(967);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iiii(1318,0,($__this|0),(0|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if ($2) {
     $7 = HEAP32[2999560>>2]|0;
     __THREW__ = 0;
     invoke_vii(2110,(0|0),($7|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     } else {
      $$0 = 0;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    $10 = (($__this) + 108|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     __THREW__ = 0;
     invoke_vi(2954,($__this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $$pre = HEAP32[$10>>2]|0;
     $15 = $$pre;
    } else {
     $15 = $11;
    }
    __THREW__ = 0;
    invoke_vi(3799,($15|0));
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     $18 = (invoke_iiiii(299,(1917128|0),($15|0),($styleName|0),($V_0|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = HEAP32[$V_0>>2]|0;
      $$ = $18 ? $21 : 0;
      $$0 = $$;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z47UnityEngine_UnityEngine_GUISkin_m_GetEnumeratorP31UnityEngine_UnityEngine_GUISkin($__this) {
 $__this = $__this|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $L_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 40|0;
 $L_3 = sp;
 $L_4 = sp + 20|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2738584);
 $0 = (($__this) + 108|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  invoke_vi(2954,($__this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $$pre = HEAP32[$0>>2]|0;
   $5 = $$pre;
   label = 4;
  }
 } else {
  $5 = $1;
  label = 4;
 }
 if ((label|0) == 4) {
  __THREW__ = 0;
  invoke_vi(3799,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_ii(3479,($5|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    invoke_vi(3799,($8|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     invoke_vii(1659,($L_3|0),($8|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      ;HEAP32[$L_4+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_4+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_4+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$L_4+12>>2]=HEAP32[$L_3+12>>2]|0;HEAP32[$L_4+16>>2]=HEAP32[$L_3+16>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(1924688|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       __THREW__ = 0;
       $17 = (invoke_iii(2724,(1924688|0),($L_4|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($17|0);
       }
      }
     }
    }
   }
  }
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z62UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2717744)|0);
 __Z49UnityEngine_UnityEngine_ExecuteInEditMode_m__ctorP41UnityEngine_UnityEngine_ExecuteInEditMode($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z69UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_FontP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_boxP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_buttonP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_toggleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z70UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_labelP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z74UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_textFieldP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_textAreaP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z71UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_windowP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z81UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalSliderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z86UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalSliderThumbP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z79UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalSliderP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z84UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalSliderThumbP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z84UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalScrollbarP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z89UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalScrollbarThumbP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z94UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalScrollbarLeftButtonP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z95UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalScrollbarRightButtonP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z82UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalScrollbarP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z87UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalScrollbarThumbP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z90UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalScrollbarUpButtonP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z92UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalScrollbarDownButtonP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z75UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_ScrollViewP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z77UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_CustomStylesP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_SettingsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z86UnityEngine_UnityEngine_GUIContent_m__ctor_mscorlib_System_Void_mscorlib_System_StringP34UnityEngine_UnityEngine_GUIContentP22mscorlib_System_String($__this,$text) {
 $__this = $__this|0;
 $text = $text|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2742416);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    $16 = (($__this) + 8|0);
    HEAP32[$16>>2] = $15;
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if (!($18)) {
     $19 = HEAP8[((2191608 + 116|0))>>0]|0;
     $20 = ($19<<24>>24)==(0);
     if ($20) {
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if ($24) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3843,(2191608|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if ($26) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[((2191608 + 80|0))>>2]|0;
      $30 = HEAP32[$29>>2]|0;
      $31 = (($__this) + 16|0);
      HEAP32[$31>>2] = $30;
      __THREW__ = 0;
      invoke_vi(1924,($__this|0));
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if (!($33)) {
       HEAP32[$16>>2] = $text;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z43UnityEngine_UnityEngine_GUIContent_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2742464);
 __THREW__ = 0;
 (invoke_ii(2996,(2191608|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2191608 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3843,(2191608|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2191608 + 80|0))>>2]|0;
    $15 = HEAP32[$14>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2742984|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     __THREW__ = 0;
     $18 = (invoke_ii(3469,(2742984|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __THREW__ = 0;
      invoke_vii(2054,($18|0),($15|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2742984|0))|0);
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        $25 = HEAP32[((2742984 + 80|0))>>2]|0;
        HEAP32[$25>>2] = $18;
        __THREW__ = 0;
        (invoke_ii(2996,(2742984|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         __THREW__ = 0;
         $28 = (invoke_ii(3469,(2742984|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          __THREW__ = 0;
          invoke_vi(2980,($28|0));
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           (invoke_ii(2996,(2742984|0))|0);
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if (!($34)) {
            $35 = HEAP32[((2742984 + 80|0))>>2]|0;
            $36 = (($35) + 4|0);
            HEAP32[$36>>2] = $28;
            __THREW__ = 0;
            (invoke_ii(2996,(2742984|0))|0);
            $37 = __THREW__; __THREW__ = 0;
            $38 = $37&1;
            if (!($38)) {
             __THREW__ = 0;
             $39 = (invoke_ii(3469,(2742984|0))|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if (!($41)) {
              __THREW__ = 0;
              invoke_vi(2980,($39|0));
              $42 = __THREW__; __THREW__ = 0;
              $43 = $42&1;
              if (!($43)) {
               __THREW__ = 0;
               (invoke_ii(2996,(2742984|0))|0);
               $44 = __THREW__; __THREW__ = 0;
               $45 = $44&1;
               if (!($45)) {
                $46 = HEAP32[((2742984 + 80|0))>>2]|0;
                $47 = (($46) + 8|0);
                HEAP32[$47>>2] = $39;
                __THREW__ = 0;
                (invoke_ii(2996,(2742984|0))|0);
                $48 = __THREW__; __THREW__ = 0;
                $49 = $48&1;
                if (!($49)) {
                 __THREW__ = 0;
                 $50 = (invoke_ii(3469,(2742984|0))|0);
                 $51 = __THREW__; __THREW__ = 0;
                 $52 = $51&1;
                 if (!($52)) {
                  __THREW__ = 0;
                  invoke_vi(2980,($50|0));
                  $53 = __THREW__; __THREW__ = 0;
                  $54 = $53&1;
                  if (!($54)) {
                   __THREW__ = 0;
                   (invoke_ii(2996,(2742984|0))|0);
                   $55 = __THREW__; __THREW__ = 0;
                   $56 = $55&1;
                   if (!($56)) {
                    $57 = HEAP32[((2742984 + 80|0))>>2]|0;
                    $58 = (($57) + 12|0);
                    HEAP32[$58>>2] = $50;
                    __ZN16StackTraceSentryD2Ev(0);
                    STACKTOP = sp;return;
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z72UnityEngine_UnityEngine_GUIContent_CustomAttributesCacheGenerator_m_TextP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73UnityEngine_UnityEngine_GUIContent_CustomAttributesCacheGenerator_m_ImageP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z75UnityEngine_UnityEngine_GUIContent_CustomAttributesCacheGenerator_m_TooltipP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2811104)|0);
 __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z45UnityEngine_UnityEngine_GUIStyleState_m__ctorP37UnityEngine_UnityEngine_GUIStyleStateP32UnityEngine_UnityEngine_GUIStyle22mscorlib_System_IntPtr($__this,$sourceStyle,$source) {
 $__this = $__this|0;
 $sourceStyle = $sourceStyle|0;
 $source = $source|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2743120);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = $sourceStyle;
  $3 = HEAP32[$source>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __THREW__ = 0;
  $5 = (invoke_ii(2582,($__this|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($__this) + 16|0);
   HEAP32[$8>>2] = $5;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z61UnityEngine_UnityEngine_GUIStyleState_m_GetBackgroundInternalP37UnityEngine_UnityEngine_GUIStyleState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2743312);
 $0 = HEAP32[2743360>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2743368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2743360>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z48UnityEngine_UnityEngine_GUIStyleState_m_FinalizeP37UnityEngine_UnityEngine_GUIStyleState($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2743168);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  invoke_vi(2987,($__this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch(348288|0)|0;
   $6 = tempRet0;
   $7 = (_llvm_eh_typeid_for((348288|0))|0);
   $8 = ($6|0)==($7|0);
   if (!($8)) {
    $$0 = $6;$$02 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
   $9 = (___cxa_begin_catch(($5|0))|0);
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_v(66);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $__last_unhandled_exception$0 = $10;$leaveInstructions$sroa$0$0 = 0;
    label = 7;
   }
  } else {
   $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 29;
   label = 7;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 29;
  label = 7;
 }
 if ((label|0) == 7) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(29);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3844,($__last_unhandled_exception$0|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    // unreachable;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $$0 = $14;$$02 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z47UnityEngine_UnityEngine_GUIStyleState_m_CleanupP37UnityEngine_UnityEngine_GUIStyleState($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2743216);
 $0 = HEAP32[2743264>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2743272|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2743264>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z62UnityEngine_UnityEngine_GUIStyleState_m_INTERNAL_set_textColorP37UnityEngine_UnityEngine_GUIStyleStateP29UnityEngine_UnityEngine_Color($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2743424);
 $0 = HEAP32[2743472>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2743480|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2743472>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN14ActionInvoker1I35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPFvPv29UnityEngine_UnityEngine_ColorES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __Z116UnityEngine_UnityEngine_GUIStyleState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyleState_m_CleanupP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130UnityEngine_UnityEngine_GUIStyleState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyleState_m_GetBackgroundInternalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131UnityEngine_UnityEngine_GUIStyleState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyleState_m_INTERNAL_set_textColorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z41UnityEngine_UnityEngine_RectOffset_m_InitP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744296);
 $0 = HEAP32[2744344>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2744352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2744344>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z119UnityEngine_UnityEngine_RectOffset_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngine_GUIStyle_mscorlib_System_IntPtrP34UnityEngine_UnityEngine_RectOffsetP32UnityEngine_UnityEngine_GUIStyle22mscorlib_System_IntPtr($__this,$sourceStyle,$source) {
 $__this = $__this|0;
 $sourceStyle = $sourceStyle|0;
 $source = $source|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744152);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  HEAP32[$2>>2] = $sourceStyle;
  $3 = HEAP32[$source>>2]|0;
  $4 = (($__this) + 8|0);
  HEAP32[$4>>2] = $3;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z151UnityEngine_UnityEngine_RectOffset_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P34UnityEngine_UnityEngine_RectOffsetiiii($__this,$left,$right,$top,$bottom) {
 $__this = $__this|0;
 $left = $left|0;
 $right = $right|0;
 $top = $top|0;
 $bottom = $bottom|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744200);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(2993,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   invoke_vii(2057,($__this|0),($left|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vii(2058,($__this|0),($right|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vii(2059,($__this|0),($top|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vii(2060,($__this|0),($bottom|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_RectOffset_m_FinalizeP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0, $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744248);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __THREW__ = 0;
  invoke_vi(2994,($__this|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch(348288|0)|0;
   $6 = tempRet0;
   $7 = (_llvm_eh_typeid_for((348288|0))|0);
   $8 = ($6|0)==($7|0);
   if (!($8)) {
    $$0 = $6;$$02 = $5;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($$02|0);
    // unreachable;
   }
   $9 = (___cxa_begin_catch(($5|0))|0);
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_v(66);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    $__last_unhandled_exception$0 = $10;$leaveInstructions$sroa$0$0 = 0;
    label = 7;
   }
  } else {
   $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 29;
   label = 7;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 29;
  label = 7;
 }
 if ((label|0) == 7) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  if (!($16)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(29);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3844,($__last_unhandled_exception$0|0));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    // unreachable;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $$0 = $14;$$02 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z44UnityEngine_UnityEngine_RectOffset_m_CleanupP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2744384);
 $0 = HEAP32[2744432>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2744440|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2744432>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_RectOffset_m_ToStringP34UnityEngine_UnityEngine_RectOffset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_12 = 0, $L_18 = 0, $L_24 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_6 = sp;
 $L_12 = sp + 4|0;
 $L_18 = sp + 8|0;
 $L_24 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2745488);
 __THREW__ = 0;
 invoke_v(968);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2773,(1167664|0),4)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_ii(2583,($__this|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      HEAP32[$L_6>>2] = $7;
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       $12 = (invoke_iii(2724,(2155952|0),($L_6|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         $17 = (($4) + 12|0);
         $18 = HEAP32[$17>>2]|0;
         $19 = ($18|0)==(0);
         if ($19) {
          __THREW__ = 0;
          $20 = (invoke_i(132)|0);
          $21 = __THREW__; __THREW__ = 0;
          $22 = $21&1;
          if ($22) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($20|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if ($24) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($4|0),($12|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($4) + 16|0);
          HEAP32[$29>>2] = $12;
          __THREW__ = 0;
          $30 = (invoke_ii(2584,($__this|0))|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           HEAP32[$L_12>>2] = $30;
           __THREW__ = 0;
           (invoke_ii(2996,(2155952|0))|0);
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if (!($34)) {
            __THREW__ = 0;
            $35 = (invoke_iii(2724,(2155952|0),($L_12|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if (!($37)) {
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $38 = __THREW__; __THREW__ = 0;
             $39 = $38&1;
             if (!($39)) {
              $40 = HEAP32[$17>>2]|0;
              $41 = ($40>>>0)<(2);
              if ($41) {
               __THREW__ = 0;
               $42 = (invoke_i(132)|0);
               $43 = __THREW__; __THREW__ = 0;
               $44 = $43&1;
               if ($44) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($42|0));
               $45 = __THREW__; __THREW__ = 0;
               $46 = $45&1;
               if ($46) {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vii(3492,($4|0),($35|0));
              $47 = __THREW__; __THREW__ = 0;
              $48 = $47&1;
              if (!($48)) {
               $49 = HEAP32[$4>>2]|0;
               $50 = (($49) + 92|0);
               $51 = HEAP32[$50>>2]|0;
               $52 = (($29) + ($51)|0);
               HEAP32[$52>>2] = $35;
               __THREW__ = 0;
               $53 = (invoke_ii(2585,($__this|0))|0);
               $54 = __THREW__; __THREW__ = 0;
               $55 = $54&1;
               if (!($55)) {
                HEAP32[$L_18>>2] = $53;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $56 = __THREW__; __THREW__ = 0;
                $57 = $56&1;
                if (!($57)) {
                 __THREW__ = 0;
                 $58 = (invoke_iii(2724,(2155952|0),($L_18|0))|0);
                 $59 = __THREW__; __THREW__ = 0;
                 $60 = $59&1;
                 if (!($60)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $61 = __THREW__; __THREW__ = 0;
                  $62 = $61&1;
                  if (!($62)) {
                   $63 = HEAP32[$17>>2]|0;
                   $64 = ($63>>>0)<(3);
                   if ($64) {
                    __THREW__ = 0;
                    $65 = (invoke_i(132)|0);
                    $66 = __THREW__; __THREW__ = 0;
                    $67 = $66&1;
                    if ($67) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($65|0));
                    $68 = __THREW__; __THREW__ = 0;
                    $69 = $68&1;
                    if ($69) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($4|0),($58|0));
                   $70 = __THREW__; __THREW__ = 0;
                   $71 = $70&1;
                   if ($71) {
                    break;
                   }
                   $72 = HEAP32[$4>>2]|0;
                   $73 = (($72) + 92|0);
                   $74 = HEAP32[$73>>2]|0;
                   $75 = $74 << 1;
                   $76 = (($29) + ($75)|0);
                   HEAP32[$76>>2] = $58;
                   __THREW__ = 0;
                   $77 = (invoke_ii(2586,($__this|0))|0);
                   $78 = __THREW__; __THREW__ = 0;
                   $79 = $78&1;
                   if ($79) {
                    break;
                   }
                   HEAP32[$L_24>>2] = $77;
                   __THREW__ = 0;
                   (invoke_ii(2996,(2155952|0))|0);
                   $80 = __THREW__; __THREW__ = 0;
                   $81 = $80&1;
                   if ($81) {
                    break;
                   }
                   __THREW__ = 0;
                   $82 = (invoke_iii(2724,(2155952|0),($L_24|0))|0);
                   $83 = __THREW__; __THREW__ = 0;
                   $84 = $83&1;
                   if ($84) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   $87 = HEAP32[$17>>2]|0;
                   $88 = ($87>>>0)<(4);
                   if ($88) {
                    __THREW__ = 0;
                    $89 = (invoke_i(132)|0);
                    $90 = __THREW__; __THREW__ = 0;
                    $91 = $90&1;
                    if ($91) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($89|0));
                    $92 = __THREW__; __THREW__ = 0;
                    $93 = $92&1;
                    if ($93) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($4|0),($82|0));
                   $94 = __THREW__; __THREW__ = 0;
                   $95 = $94&1;
                   if ($95) {
                    break;
                   }
                   $96 = HEAP32[$4>>2]|0;
                   $97 = (($96) + 92|0);
                   $98 = HEAP32[$97>>2]|0;
                   $99 = ($98*3)|0;
                   $100 = (($29) + ($99)|0);
                   HEAP32[$100>>2] = $82;
                   $101 = HEAP32[2999608>>2]|0;
                   __THREW__ = 0;
                   $102 = (invoke_iiii(1417,(0|0),($101|0),($4|0))|0);
                   $103 = __THREW__; __THREW__ = 0;
                   $104 = $103&1;
                   if ($104) {
                    break;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($102|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($25|0);
 // unreachable;
 return 0|0;
}
function __Z107UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_InitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_CleanupP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z111UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_leftP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z111UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_set_leftP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z112UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_rightP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z112UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_set_rightP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_topP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_set_topP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z113UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_bottomP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z113UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_set_bottomP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z117UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_horizontalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_verticalP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_GUIStyle_m_InitP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2746992);
 $0 = HEAP32[2747040>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747048|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747040>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z41UnityEngine_UnityEngine_GUIStyle_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2746896);
 __THREW__ = 0;
 (invoke_ii(2996,(2749952|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = HEAP32[((2749952 + 80|0))>>2]|0;
  HEAP8[$2>>0] = 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43UnityEngine_UnityEngine_GUIStyle_m_FinalizeP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2746944);
 __THREW__ = 0;
 invoke_vi(3011,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 18;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(18);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3844,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_GUIStyle_m_CleanupP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747080);
 $0 = HEAP32[2747128>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747136|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747128>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z51UnityEngine_UnityEngine_GUIStyle_m_GetStyleStatePtrP32UnityEngine_UnityEngine_GUIStylei($__this,$idx) {
 $__this = $__this|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747416);
 $0 = HEAP32[2747464>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747472|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747464>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($idx|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z51UnityEngine_UnityEngine_GUIStyle_m_GetRectOffsetPtrP32UnityEngine_UnityEngine_GUIStylei($__this,$idx) {
 $__this = $__this|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2747624);
 $0 = HEAP32[2747672>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2747680|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2747672>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($idx|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_GUIStyle_m_ToStringP32UnityEngine_UnityEngine_GUIStyle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2748520);
 __THREW__ = 0;
 invoke_v(969);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2773,(1167664|0),1)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_ii(2590,($__this|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($4) + 12|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = ($13|0)==(0);
       if ($14) {
        __THREW__ = 0;
        $15 = (invoke_i(132)|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($15|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($4|0),($7|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = (($4) + 16|0);
        HEAP32[$24>>2] = $7;
        $25 = HEAP32[2999696>>2]|0;
        __THREW__ = 0;
        $26 = (invoke_iiii(1417,(0|0),($25|0),($4|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($26|0);
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z103UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_InitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z106UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_CleanupP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z107UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_nameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z107UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_set_nameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_GetStyleStatePtrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_GetRectOffsetPtrP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z113UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_fixedWidthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z114UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_fixedHeightP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_stretchWidthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_set_stretchWidthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_stretchHeightP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_set_stretchHeightP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z113UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_SetDefaultFontP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z37UnityEngine_UnityEngine_Event_m__ctorP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750088);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vi(3026,($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z36UnityEngine_UnityEngine_Event_m_InitP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750136);
 $0 = HEAP32[2750184>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2750192|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2750184>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z40UnityEngine_UnityEngine_Event_m_FinalizeP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750224);
 __THREW__ = 0;
 invoke_vi(3028,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 18;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(18);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3844,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z39UnityEngine_UnityEngine_Event_m_CleanupP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750272);
 $0 = HEAP32[2750320>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2750328|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2750320>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_Event_m_get_mousePositionP29UnityEngine_UnityEngine_Event($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750448);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2066,($__this|0),($agg$result|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57UnityEngine_UnityEngine_Event_m_Internal_GetMousePositionP29UnityEngine_UnityEngine_EventP31UnityEngine_UnityEngine_Vector2($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750496);
 $0 = HEAP32[2750544>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2750552|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2750544>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_Event_m_get_modifiersP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750624);
 $0 = HEAP32[2750672>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2750680|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2750672>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_Event_m_get_characterP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750720);
 $0 = HEAP32[2750768>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2750776|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2750768>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z47UnityEngine_UnityEngine_Event_m_get_commandNameP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750816);
 $0 = HEAP32[2750864>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2750872|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2750864>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Event_m_get_keyCodeP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2750912);
 $0 = HEAP32[2750960>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2750968|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2750960>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z55UnityEngine_UnityEngine_Event_m_Internal_SetNativeEventP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$ptr) {
 $__this = $__this|0;
 $ptr = $ptr|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2751056);
 $1 = HEAP32[2751104>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2751112|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2751104>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$ptr>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_vi($9|0,($$byval_copy|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z63UnityEngine_UnityEngine_Event_m_Internal_MakeMasterEventCurrentP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2751176);
 __THREW__ = 0;
 (invoke_ii(2996,(2752240|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = HEAP32[((2752240 + 80|0))>>2]|0;
   $4 = (($3) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if ($6) {
    __THREW__ = 0;
    (invoke_ii(2996,(2752240|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2752240|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3025,($11|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2752240|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    $18 = HEAP32[((2752240 + 80|0))>>2]|0;
    $19 = (($18) + 4|0);
    HEAP32[$19>>2] = $11;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2752240|0))|0);
   $20 = __THREW__; __THREW__ = 0;
   $21 = $20&1;
   if (!($21)) {
    $22 = HEAP32[((2752240 + 80|0))>>2]|0;
    $23 = (($22) + 4|0);
    $24 = HEAP32[$23>>2]|0;
    __THREW__ = 0;
    (invoke_ii(2996,(2752240|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = HEAP32[((2752240 + 80|0))>>2]|0;
     HEAP32[$27>>2] = $24;
     __THREW__ = 0;
     (invoke_ii(2996,(2752240|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[((2752240 + 80|0))>>2]|0;
      $31 = (($30) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($32|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       $35 = (($32) + 8|0);
       $36 = HEAP32[$35>>2]|0;
       HEAP32[$0>>2] = $36;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_vii(2067,0,($$byval_copy|0));
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z41UnityEngine_UnityEngine_Event_m_get_isKeyP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2751224);
 __THREW__ = 0;
 $0 = (invoke_ii(2598,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $3 = $0 & -2;
  $4 = ($3|0)==(4);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Event_m_get_isMouseP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2751272);
 __THREW__ = 0;
 $0 = (invoke_ii(2598,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = ($0>>>0)<(4);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Event_m_GetHashCodeP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_5 = 0, $V_0$0 = 0, $V_0$1 = 0, $V_1 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_1 = sp;
 $L_5 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2751320);
 $0 = $V_1;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 $4 = (invoke_ii(2604,($__this|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   if ($4) {
    __THREW__ = 0;
    $9 = (invoke_ii(2602,($__this|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = $9 & 65535;
    $V_0$0 = $12;
   } else {
    $V_0$0 = 1;
   }
   __THREW__ = 0;
   $13 = (invoke_ii(2605,($__this|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    if ($13) {
     __THREW__ = 0;
     invoke_vii(2065,($L_5|0),($__this|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     $18 = $L_5;
     $19 = $18;
     $20 = HEAP32[$19>>2]|0;
     $21 = (($18) + 4)|0;
     $22 = $21;
     $23 = HEAP32[$22>>2]|0;
     $24 = $V_1;
     $25 = $24;
     HEAP32[$25>>2] = $20;
     $26 = (($24) + 4)|0;
     $27 = $26;
     HEAP32[$27>>2] = $23;
     __THREW__ = 0;
     $28 = (invoke_ii(2609,($V_1|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if ($30) {
      break;
     } else {
      $V_0$1 = $28;
     }
    } else {
     $V_0$1 = $V_0$0;
    }
    __THREW__ = 0;
    $31 = (invoke_ii(2599,($__this|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if (!($33)) {
     $34 = ($V_0$1*37)|0;
     $35 = $34 | $31;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($35|0);
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_Vector2_m_GetHashCodeP31UnityEngine_UnityEngine_Vector2($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2770992);
 __THREW__ = 0;
 $0 = (invoke_ii(1819,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 4|0);
  __THREW__ = 0;
  $4 = (invoke_ii(1819,($3|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = $4 << 2;
   $8 = $7 ^ $0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z38UnityEngine_UnityEngine_Event_m_EqualsP29UnityEngine_UnityEngine_EventP22mscorlib_System_Object($__this,$obj) {
 $__this = $__this|0;
 $obj = $obj|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_21 = 0, $L_22 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, $tmpcast2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast2$byval_copy = sp + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $_stackTraceSentry = sp + 32|0;
 $L_21 = sp + 16|0;
 $L_22 = sp + 8|0;
 $0 = sp;
 $1 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2751368);
 $2 = ($obj|0)==(0|0);
 if ($2) {
  $$0 = 0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($$0|0);
 }
 __THREW__ = 0;
 $3 = (invoke_iiii(424,(0|0),($__this|0),($obj|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   if ($3) {
    $$0 = 1;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   invoke_vi(3799,($obj|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(1782,($obj|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     __THREW__ = 0;
     $13 = (invoke_ii(1782,($__this|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      $16 = ($10|0)==($13|0);
      if (!($16)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2752240|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if (!($18)) {
       __THREW__ = 0;
       $19 = (invoke_iii(2774,($obj|0),(2752240|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        $22 = (invoke_ii(2598,($__this|0))|0);
        $23 = __THREW__; __THREW__ = 0;
        $24 = $23&1;
        if (!($24)) {
         __THREW__ = 0;
         invoke_vi(3799,($19|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          __THREW__ = 0;
          $27 = (invoke_ii(2598,($19|0))|0);
          $28 = __THREW__; __THREW__ = 0;
          $29 = $28&1;
          if (!($29)) {
           $30 = ($22|0)==($27|0);
           if (!($30)) {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           $31 = (invoke_ii(2599,($__this|0))|0);
           $32 = __THREW__; __THREW__ = 0;
           $33 = $32&1;
           if (!($33)) {
            __THREW__ = 0;
            invoke_vi(3799,($19|0));
            $34 = __THREW__; __THREW__ = 0;
            $35 = $34&1;
            if (!($35)) {
             __THREW__ = 0;
             $36 = (invoke_ii(2599,($19|0))|0);
             $37 = __THREW__; __THREW__ = 0;
             $38 = $37&1;
             if (!($38)) {
              $39 = $36 ^ $31;
              $40 = $39 & -33;
              $41 = ($40|0)==(0);
              if (!($41)) {
               $$0 = 0;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
              __THREW__ = 0;
              $42 = (invoke_ii(2604,($__this|0))|0);
              $43 = __THREW__; __THREW__ = 0;
              $44 = $43&1;
              if (!($44)) {
               if ($42) {
                __THREW__ = 0;
                $45 = (invoke_ii(2602,($__this|0))|0);
                $46 = __THREW__; __THREW__ = 0;
                $47 = $46&1;
                if ($47) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($19|0));
                $48 = __THREW__; __THREW__ = 0;
                $49 = $48&1;
                if ($49) {
                 break;
                }
                __THREW__ = 0;
                $50 = (invoke_ii(2602,($19|0))|0);
                $51 = __THREW__; __THREW__ = 0;
                $52 = $51&1;
                if ($52) {
                 break;
                }
                $53 = ($45|0)==($50|0);
                $$0 = $53;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               __THREW__ = 0;
               $54 = (invoke_ii(2605,($__this|0))|0);
               $55 = __THREW__; __THREW__ = 0;
               $56 = $55&1;
               if ($56) {
                break;
               }
               if (!($54)) {
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               __THREW__ = 0;
               invoke_vii(2065,($L_21|0),($__this|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if ($58) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3799,($19|0));
               $59 = __THREW__; __THREW__ = 0;
               $60 = $59&1;
               if ($60) {
                break;
               }
               __THREW__ = 0;
               invoke_vii(2065,($L_22|0),($19|0));
               $61 = __THREW__; __THREW__ = 0;
               $62 = $61&1;
               if ($62) {
                break;
               }
               $63 = $L_21;
               $64 = $63;
               $65 = HEAP32[$64>>2]|0;
               $66 = (($63) + 4)|0;
               $67 = $66;
               $68 = HEAP32[$67>>2]|0;
               $69 = $0;
               $70 = $69;
               HEAP32[$70>>2] = $65;
               $71 = (($69) + 4)|0;
               $72 = $71;
               HEAP32[$72>>2] = $68;
               $73 = $L_22;
               $74 = $73;
               $75 = HEAP32[$74>>2]|0;
               $76 = (($73) + 4)|0;
               $77 = $76;
               $78 = HEAP32[$77>>2]|0;
               $79 = $1;
               $80 = $79;
               HEAP32[$80>>2] = $75;
               $81 = (($79) + 4)|0;
               $82 = $81;
               HEAP32[$82>>2] = $78;
               __THREW__ = 0;
               ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
               ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
               $83 = (invoke_iiii(1343,0,($tmpcast$byval_copy|0),($tmpcast2$byval_copy|0))|0);
               $84 = __THREW__; __THREW__ = 0;
               $85 = $84&1;
               if ($85) {
                break;
               } else {
                $$0 = $83;
               }
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z133UnityEngine_UnityEngine_Vector2_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Vector2_UnityEngine_UnityEngine_Vector2P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector2S1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, $tmpcast$byval_copy = 0, $tmpcast2$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast2$byval_copy = sp + 48|0;
 $tmpcast$byval_copy = sp + 40|0;
 $_stackTraceSentry = sp + 32|0;
 $L_0 = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2771232);
 $3 = $lhs;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = $rhs;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $1;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 __THREW__ = 0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 invoke_viiii(217,($L_0|0),0,($tmpcast$byval_copy|0),($tmpcast2$byval_copy|0));
 $23 = __THREW__; __THREW__ = 0;
 $24 = $23&1;
 if ($24) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($39|0);
  // unreachable;
 }
 $25 = $L_0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $2;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 __THREW__ = 0;
 ;HEAP32[$tmpcast2$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast2$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;
 $35 = (Math_fround(+(invoke_fii(35,0,($tmpcast2$byval_copy|0)))));
 $36 = __THREW__; __THREW__ = 0;
 $37 = $36&1;
 if ($37) {
  $39 = ___cxa_find_matching_catch()|0;
  $40 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($39|0);
  // unreachable;
 } else {
  $38 = $35 < Math_fround(9.99999943962492920946E-11);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($38|0);
 }
 return 0|0;
}
function __Z40UnityEngine_UnityEngine_Event_m_ToStringP29UnityEngine_UnityEngine_Event($__this) {
 $__this = $__this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0;
 var $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0;
 var $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0;
 var $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0;
 var $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0;
 var $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_106 = 0, $L_14 = 0, $L_20 = 0, $L_32 = 0, $L_41 = 0, $L_50 = 0, $L_59 = 0, $L_72 = 0, $L_77 = 0, $L_78 = 0, $L_8 = 0, $L_84 = 0, $L_97 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 60|0;
 $L_8 = sp + 56|0;
 $L_14 = sp + 52|0;
 $L_20 = sp + 48|0;
 $L_32 = sp + 44|0;
 $L_41 = sp + 40|0;
 $L_50 = sp + 36|0;
 $L_59 = sp + 32|0;
 $L_72 = sp + 24|0;
 $L_77 = sp + 8|0;
 $L_78 = sp;
 $L_84 = sp + 16|0;
 $L_97 = sp + 20|0;
 $L_106 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2751416);
 __THREW__ = 0;
 invoke_v(970);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(2604,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if (!($2)) {
     __THREW__ = 0;
     $269 = (invoke_ii(2605,($__this|0))|0);
     $270 = __THREW__; __THREW__ = 0;
     $271 = $270&1;
     if ($271) {
      break;
     }
     if ($269) {
      __THREW__ = 0;
      (invoke_ii(2996,(1167664|0))|0);
      $272 = __THREW__; __THREW__ = 0;
      $273 = $272&1;
      if ($273) {
       break;
      }
      __THREW__ = 0;
      $274 = (invoke_iii(2773,(1167664|0),3)|0);
      $275 = __THREW__; __THREW__ = 0;
      $276 = $275&1;
      if ($276) {
       break;
      }
      __THREW__ = 0;
      $277 = (invoke_ii(2598,($__this|0))|0);
      $278 = __THREW__; __THREW__ = 0;
      $279 = $278&1;
      if ($279) {
       break;
      }
      HEAP32[$L_72>>2] = $277;
      __THREW__ = 0;
      (invoke_ii(2996,(2770104|0))|0);
      $280 = __THREW__; __THREW__ = 0;
      $281 = $280&1;
      if ($281) {
       break;
      }
      __THREW__ = 0;
      $282 = (invoke_iii(2724,(2770104|0),($L_72|0))|0);
      $283 = __THREW__; __THREW__ = 0;
      $284 = $283&1;
      if ($284) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($274|0));
      $285 = __THREW__; __THREW__ = 0;
      $286 = $285&1;
      if ($286) {
       break;
      }
      $287 = (($274) + 12|0);
      $288 = HEAP32[$287>>2]|0;
      $289 = ($288|0)==(0);
      if ($289) {
       __THREW__ = 0;
       $290 = (invoke_i(132)|0);
       $291 = __THREW__; __THREW__ = 0;
       $292 = $291&1;
       if ($292) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($290|0));
       $293 = __THREW__; __THREW__ = 0;
       $294 = $293&1;
       if ($294) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($274|0),($282|0));
      $295 = __THREW__; __THREW__ = 0;
      $296 = $295&1;
      if ($296) {
       break;
      }
      $297 = (($274) + 16|0);
      HEAP32[$297>>2] = $282;
      __THREW__ = 0;
      invoke_vii(2065,($L_77|0),($__this|0));
      $298 = __THREW__; __THREW__ = 0;
      $299 = $298&1;
      if ($299) {
       break;
      }
      $300 = $L_77;
      $301 = $300;
      $302 = HEAP32[$301>>2]|0;
      $303 = (($300) + 4)|0;
      $304 = $303;
      $305 = HEAP32[$304>>2]|0;
      $306 = $L_78;
      $307 = $306;
      HEAP32[$307>>2] = $302;
      $308 = (($306) + 4)|0;
      $309 = $308;
      HEAP32[$309>>2] = $305;
      __THREW__ = 0;
      (invoke_ii(2996,(2771616|0))|0);
      $310 = __THREW__; __THREW__ = 0;
      $311 = $310&1;
      if ($311) {
       break;
      }
      __THREW__ = 0;
      $312 = (invoke_iii(2724,(2771616|0),($L_78|0))|0);
      $313 = __THREW__; __THREW__ = 0;
      $314 = $313&1;
      if ($314) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($274|0));
      $315 = __THREW__; __THREW__ = 0;
      $316 = $315&1;
      if ($316) {
       break;
      }
      $317 = HEAP32[$287>>2]|0;
      $318 = ($317>>>0)<(2);
      if ($318) {
       __THREW__ = 0;
       $319 = (invoke_i(132)|0);
       $320 = __THREW__; __THREW__ = 0;
       $321 = $320&1;
       if ($321) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($319|0));
       $322 = __THREW__; __THREW__ = 0;
       $323 = $322&1;
       if ($323) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($274|0),($312|0));
      $324 = __THREW__; __THREW__ = 0;
      $325 = $324&1;
      if ($325) {
       break;
      }
      $326 = HEAP32[$274>>2]|0;
      $327 = (($326) + 92|0);
      $328 = HEAP32[$327>>2]|0;
      $329 = (($297) + ($328)|0);
      HEAP32[$329>>2] = $312;
      __THREW__ = 0;
      $330 = (invoke_ii(2599,($__this|0))|0);
      $331 = __THREW__; __THREW__ = 0;
      $332 = $331&1;
      if ($332) {
       break;
      }
      HEAP32[$L_84>>2] = $330;
      __THREW__ = 0;
      (invoke_ii(2996,(2770760|0))|0);
      $333 = __THREW__; __THREW__ = 0;
      $334 = $333&1;
      if ($334) {
       break;
      }
      __THREW__ = 0;
      $335 = (invoke_iii(2724,(2770760|0),($L_84|0))|0);
      $336 = __THREW__; __THREW__ = 0;
      $337 = $336&1;
      if ($337) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($274|0));
      $338 = __THREW__; __THREW__ = 0;
      $339 = $338&1;
      if ($339) {
       break;
      }
      $340 = HEAP32[$287>>2]|0;
      $341 = ($340>>>0)<(3);
      if ($341) {
       __THREW__ = 0;
       $342 = (invoke_i(132)|0);
       $343 = __THREW__; __THREW__ = 0;
       $344 = $343&1;
       if ($344) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($342|0));
       $345 = __THREW__; __THREW__ = 0;
       $346 = $345&1;
       if ($346) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($274|0),($335|0));
      $347 = __THREW__; __THREW__ = 0;
      $348 = $347&1;
      if ($348) {
       break;
      }
      $349 = HEAP32[$274>>2]|0;
      $350 = (($349) + 92|0);
      $351 = HEAP32[$350>>2]|0;
      $352 = $351 << 1;
      $353 = (($297) + ($352)|0);
      HEAP32[$353>>2] = $335;
      $354 = HEAP32[2999784>>2]|0;
      __THREW__ = 0;
      $355 = (invoke_iiii(1417,(0|0),($354|0),($274|0))|0);
      $356 = __THREW__; __THREW__ = 0;
      $357 = $356&1;
      if ($357) {
       break;
      } else {
       $$0 = $355;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     $358 = (invoke_ii(2598,($__this|0))|0);
     $359 = __THREW__; __THREW__ = 0;
     $360 = $359&1;
     if ($360) {
      break;
     }
     $361 = ($358|0)==(14);
     if (!($361)) {
      __THREW__ = 0;
      $362 = (invoke_ii(2598,($__this|0))|0);
      $363 = __THREW__; __THREW__ = 0;
      $364 = $363&1;
      if ($364) {
       break;
      }
      $365 = ($362|0)==(13);
      if (!($365)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $414 = __THREW__; __THREW__ = 0;
       $415 = $414&1;
       if ($415) {
        break;
       }
       $416 = HEAP8[((2191608 + 116|0))>>0]|0;
       $417 = ($416<<24>>24)==(0);
       if ($417) {
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $418 = __THREW__; __THREW__ = 0;
        $419 = $418&1;
        if ($419) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2191608|0))|0);
        $420 = __THREW__; __THREW__ = 0;
        $421 = $420&1;
        if ($421) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3843,(2191608|0));
        $422 = __THREW__; __THREW__ = 0;
        $423 = $422&1;
        if ($423) {
         break;
        }
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $424 = __THREW__; __THREW__ = 0;
       $425 = $424&1;
       if ($425) {
        break;
       }
       $426 = HEAP32[((2191608 + 80|0))>>2]|0;
       $427 = HEAP32[$426>>2]|0;
       __THREW__ = 0;
       $428 = (invoke_ii(2598,($__this|0))|0);
       $429 = __THREW__; __THREW__ = 0;
       $430 = $429&1;
       if ($430) {
        break;
       }
       HEAP32[$L_106>>2] = $428;
       __THREW__ = 0;
       (invoke_ii(2996,(2770104|0))|0);
       $431 = __THREW__; __THREW__ = 0;
       $432 = $431&1;
       if ($432) {
        break;
       }
       __THREW__ = 0;
       $433 = (invoke_iii(2724,(2770104|0),($L_106|0))|0);
       $434 = __THREW__; __THREW__ = 0;
       $435 = $434&1;
       if ($435) {
        break;
       }
       __THREW__ = 0;
       $436 = (invoke_iiii(559,(0|0),($427|0),($433|0))|0);
       $437 = __THREW__; __THREW__ = 0;
       $438 = $437&1;
       if ($438) {
        break;
       } else {
        $$0 = $436;
       }
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $366 = __THREW__; __THREW__ = 0;
     $367 = $366&1;
     if ($367) {
      break;
     }
     __THREW__ = 0;
     $368 = (invoke_iii(2773,(1167664|0),2)|0);
     $369 = __THREW__; __THREW__ = 0;
     $370 = $369&1;
     if ($370) {
      break;
     }
     __THREW__ = 0;
     $371 = (invoke_ii(2598,($__this|0))|0);
     $372 = __THREW__; __THREW__ = 0;
     $373 = $372&1;
     if ($373) {
      break;
     }
     HEAP32[$L_97>>2] = $371;
     __THREW__ = 0;
     (invoke_ii(2996,(2770104|0))|0);
     $374 = __THREW__; __THREW__ = 0;
     $375 = $374&1;
     if ($375) {
      break;
     }
     __THREW__ = 0;
     $376 = (invoke_iii(2724,(2770104|0),($L_97|0))|0);
     $377 = __THREW__; __THREW__ = 0;
     $378 = $377&1;
     if ($378) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($368|0));
     $379 = __THREW__; __THREW__ = 0;
     $380 = $379&1;
     if ($380) {
      break;
     }
     $381 = (($368) + 12|0);
     $382 = HEAP32[$381>>2]|0;
     $383 = ($382|0)==(0);
     if ($383) {
      __THREW__ = 0;
      $384 = (invoke_i(132)|0);
      $385 = __THREW__; __THREW__ = 0;
      $386 = $385&1;
      if ($386) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($384|0));
      $387 = __THREW__; __THREW__ = 0;
      $388 = $387&1;
      if ($388) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($368|0),($376|0));
     $389 = __THREW__; __THREW__ = 0;
     $390 = $389&1;
     if ($390) {
      break;
     }
     $391 = (($368) + 16|0);
     HEAP32[$391>>2] = $376;
     __THREW__ = 0;
     $392 = (invoke_ii(2601,($__this|0))|0);
     $393 = __THREW__; __THREW__ = 0;
     $394 = $393&1;
     if ($394) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3799,($368|0));
     $395 = __THREW__; __THREW__ = 0;
     $396 = $395&1;
     if ($396) {
      break;
     }
     $397 = HEAP32[$381>>2]|0;
     $398 = ($397>>>0)<(2);
     if ($398) {
      __THREW__ = 0;
      $399 = (invoke_i(132)|0);
      $400 = __THREW__; __THREW__ = 0;
      $401 = $400&1;
      if ($401) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3302,($399|0));
      $402 = __THREW__; __THREW__ = 0;
      $403 = $402&1;
      if ($403) {
       break;
      }
     }
     __THREW__ = 0;
     invoke_vii(3492,($368|0),($392|0));
     $404 = __THREW__; __THREW__ = 0;
     $405 = $404&1;
     if ($405) {
      break;
     }
     $406 = HEAP32[$368>>2]|0;
     $407 = (($406) + 92|0);
     $408 = HEAP32[$407>>2]|0;
     $409 = (($391) + ($408)|0);
     HEAP32[$409>>2] = $392;
     $410 = HEAP32[2999792>>2]|0;
     __THREW__ = 0;
     $411 = (invoke_iiii(1417,(0|0),($410|0),($368|0))|0);
     $412 = __THREW__; __THREW__ = 0;
     $413 = $412&1;
     if ($413) {
      break;
     } else {
      $$0 = $411;
     }
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    $7 = (invoke_ii(2600,($__this|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = ($7<<16>>16)==(0);
     if ($10) {
      __THREW__ = 0;
      (invoke_ii(2996,(1167664|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       break;
      }
      __THREW__ = 0;
      $13 = (invoke_iii(2773,(1167664|0),3)|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if ($15) {
       break;
      }
      __THREW__ = 0;
      $16 = (invoke_ii(2598,($__this|0))|0);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       break;
      }
      HEAP32[$L_8>>2] = $16;
      __THREW__ = 0;
      (invoke_ii(2996,(2770104|0))|0);
      $19 = __THREW__; __THREW__ = 0;
      $20 = $19&1;
      if ($20) {
       break;
      }
      __THREW__ = 0;
      $21 = (invoke_iii(2724,(2770104|0),($L_8|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($13|0));
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      $26 = (($13) + 12|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==(0);
      if ($28) {
       __THREW__ = 0;
       $29 = (invoke_i(132)|0);
       $30 = __THREW__; __THREW__ = 0;
       $31 = $30&1;
       if ($31) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($29|0));
       $32 = __THREW__; __THREW__ = 0;
       $33 = $32&1;
       if ($33) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($13|0),($21|0));
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      $36 = (($13) + 16|0);
      HEAP32[$36>>2] = $21;
      __THREW__ = 0;
      $37 = (invoke_ii(2599,($__this|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      HEAP32[$L_14>>2] = $37;
      __THREW__ = 0;
      (invoke_ii(2996,(2770760|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2770760|0),($L_14|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($13|0));
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      $47 = HEAP32[$26>>2]|0;
      $48 = ($47>>>0)<(2);
      if ($48) {
       __THREW__ = 0;
       $49 = (invoke_i(132)|0);
       $50 = __THREW__; __THREW__ = 0;
       $51 = $50&1;
       if ($51) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($49|0));
       $52 = __THREW__; __THREW__ = 0;
       $53 = $52&1;
       if ($53) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($13|0),($42|0));
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       break;
      }
      $56 = HEAP32[$13>>2]|0;
      $57 = (($56) + 92|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (($36) + ($58)|0);
      HEAP32[$59>>2] = $42;
      __THREW__ = 0;
      $60 = (invoke_ii(2602,($__this|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       break;
      }
      HEAP32[$L_20>>2] = $60;
      __THREW__ = 0;
      (invoke_ii(2996,(2768456|0))|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       break;
      }
      __THREW__ = 0;
      $65 = (invoke_iii(2724,(2768456|0),($L_20|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($13|0));
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       break;
      }
      $70 = HEAP32[$26>>2]|0;
      $71 = ($70>>>0)<(3);
      if ($71) {
       __THREW__ = 0;
       $72 = (invoke_i(132)|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3302,($72|0));
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        break;
       }
      }
      __THREW__ = 0;
      invoke_vii(3492,($13|0),($65|0));
      $77 = __THREW__; __THREW__ = 0;
      $78 = $77&1;
      if ($78) {
       break;
      }
      $79 = HEAP32[$13>>2]|0;
      $80 = (($79) + 92|0);
      $81 = HEAP32[$80>>2]|0;
      $82 = $81 << 1;
      $83 = (($36) + ($82)|0);
      HEAP32[$83>>2] = $65;
      $84 = HEAP32[2999744>>2]|0;
      __THREW__ = 0;
      $85 = (invoke_iiii(1417,(0|0),($84|0),($13|0))|0);
      $86 = __THREW__; __THREW__ = 0;
      $87 = $86&1;
      if ($87) {
       break;
      } else {
       $$0 = $85;
      }
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     __THREW__ = 0;
     (invoke_ii(2996,(1167664|0))|0);
     $88 = __THREW__; __THREW__ = 0;
     $89 = $88&1;
     if (!($89)) {
      __THREW__ = 0;
      $90 = (invoke_iii(2773,(1167664|0),8)|0);
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      if (!($92)) {
       __THREW__ = 0;
       invoke_vi(3799,($90|0));
       $93 = __THREW__; __THREW__ = 0;
       $94 = $93&1;
       if (!($94)) {
        $95 = (($90) + 12|0);
        $96 = HEAP32[$95>>2]|0;
        $97 = ($96|0)==(0);
        if ($97) {
         __THREW__ = 0;
         $98 = (invoke_i(132)|0);
         $99 = __THREW__; __THREW__ = 0;
         $100 = $99&1;
         if ($100) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($98|0));
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if ($102) {
          break;
         }
        }
        $103 = HEAP32[2999752>>2]|0;
        __THREW__ = 0;
        invoke_vii(3492,($90|0),($103|0));
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if (!($105)) {
         $106 = HEAP32[2999752>>2]|0;
         $107 = (($90) + 16|0);
         HEAP32[$107>>2] = $106;
         __THREW__ = 0;
         $108 = (invoke_ii(2598,($__this|0))|0);
         $109 = __THREW__; __THREW__ = 0;
         $110 = $109&1;
         if (!($110)) {
          HEAP32[$L_32>>2] = $108;
          __THREW__ = 0;
          (invoke_ii(2996,(2770104|0))|0);
          $111 = __THREW__; __THREW__ = 0;
          $112 = $111&1;
          if (!($112)) {
           __THREW__ = 0;
           $113 = (invoke_iii(2724,(2770104|0),($L_32|0))|0);
           $114 = __THREW__; __THREW__ = 0;
           $115 = $114&1;
           if (!($115)) {
            __THREW__ = 0;
            invoke_vi(3799,($90|0));
            $116 = __THREW__; __THREW__ = 0;
            $117 = $116&1;
            if (!($117)) {
             $118 = HEAP32[$95>>2]|0;
             $119 = ($118>>>0)<(2);
             if ($119) {
              __THREW__ = 0;
              $120 = (invoke_i(132)|0);
              $121 = __THREW__; __THREW__ = 0;
              $122 = $121&1;
              if ($122) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($120|0));
              $123 = __THREW__; __THREW__ = 0;
              $124 = $123&1;
              if ($124) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($90|0),($113|0));
             $125 = __THREW__; __THREW__ = 0;
             $126 = $125&1;
             if (!($126)) {
              $127 = HEAP32[$90>>2]|0;
              $128 = (($127) + 92|0);
              $129 = HEAP32[$128>>2]|0;
              $130 = (($107) + ($129)|0);
              HEAP32[$130>>2] = $113;
              __THREW__ = 0;
              invoke_vi(3799,($90|0));
              $131 = __THREW__; __THREW__ = 0;
              $132 = $131&1;
              if (!($132)) {
               $133 = HEAP32[$95>>2]|0;
               $134 = ($133>>>0)<(3);
               if ($134) {
                __THREW__ = 0;
                $135 = (invoke_i(132)|0);
                $136 = __THREW__; __THREW__ = 0;
                $137 = $136&1;
                if ($137) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3302,($135|0));
                $138 = __THREW__; __THREW__ = 0;
                $139 = $138&1;
                if ($139) {
                 break;
                }
               }
               $140 = HEAP32[2999760>>2]|0;
               __THREW__ = 0;
               invoke_vii(3492,($90|0),($140|0));
               $141 = __THREW__; __THREW__ = 0;
               $142 = $141&1;
               if (!($142)) {
                $143 = HEAP32[2999760>>2]|0;
                $144 = HEAP32[$90>>2]|0;
                $145 = (($144) + 92|0);
                $146 = HEAP32[$145>>2]|0;
                $147 = $146 << 1;
                $148 = (($107) + ($147)|0);
                HEAP32[$148>>2] = $143;
                __THREW__ = 0;
                $149 = (invoke_ii(2600,($__this|0))|0);
                $150 = __THREW__; __THREW__ = 0;
                $151 = $150&1;
                if ($151) {
                 break;
                }
                $152 = $149&65535;
                HEAP32[$L_41>>2] = $152;
                __THREW__ = 0;
                (invoke_ii(2996,(2155952|0))|0);
                $153 = __THREW__; __THREW__ = 0;
                $154 = $153&1;
                if ($154) {
                 break;
                }
                __THREW__ = 0;
                $155 = (invoke_iii(2724,(2155952|0),($L_41|0))|0);
                $156 = __THREW__; __THREW__ = 0;
                $157 = $156&1;
                if ($157) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($90|0));
                $158 = __THREW__; __THREW__ = 0;
                $159 = $158&1;
                if ($159) {
                 break;
                }
                $160 = HEAP32[$95>>2]|0;
                $161 = ($160>>>0)<(4);
                if ($161) {
                 __THREW__ = 0;
                 $162 = (invoke_i(132)|0);
                 $163 = __THREW__; __THREW__ = 0;
                 $164 = $163&1;
                 if ($164) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($162|0));
                 $165 = __THREW__; __THREW__ = 0;
                 $166 = $165&1;
                 if ($166) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($90|0),($155|0));
                $167 = __THREW__; __THREW__ = 0;
                $168 = $167&1;
                if ($168) {
                 break;
                }
                $169 = HEAP32[$90>>2]|0;
                $170 = (($169) + 92|0);
                $171 = HEAP32[$170>>2]|0;
                $172 = ($171*3)|0;
                $173 = (($107) + ($172)|0);
                HEAP32[$173>>2] = $155;
                __THREW__ = 0;
                invoke_vi(3799,($90|0));
                $174 = __THREW__; __THREW__ = 0;
                $175 = $174&1;
                if ($175) {
                 break;
                }
                $176 = HEAP32[$95>>2]|0;
                $177 = ($176>>>0)<(5);
                if ($177) {
                 __THREW__ = 0;
                 $178 = (invoke_i(132)|0);
                 $179 = __THREW__; __THREW__ = 0;
                 $180 = $179&1;
                 if ($180) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($178|0));
                 $181 = __THREW__; __THREW__ = 0;
                 $182 = $181&1;
                 if ($182) {
                  break;
                 }
                }
                $183 = HEAP32[2999768>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($90|0),($183|0));
                $184 = __THREW__; __THREW__ = 0;
                $185 = $184&1;
                if ($185) {
                 break;
                }
                $186 = HEAP32[2999768>>2]|0;
                $187 = HEAP32[$90>>2]|0;
                $188 = (($187) + 92|0);
                $189 = HEAP32[$188>>2]|0;
                $190 = $189 << 2;
                $191 = (($107) + ($190)|0);
                HEAP32[$191>>2] = $186;
                __THREW__ = 0;
                $192 = (invoke_ii(2599,($__this|0))|0);
                $193 = __THREW__; __THREW__ = 0;
                $194 = $193&1;
                if ($194) {
                 break;
                }
                HEAP32[$L_50>>2] = $192;
                __THREW__ = 0;
                (invoke_ii(2996,(2770760|0))|0);
                $195 = __THREW__; __THREW__ = 0;
                $196 = $195&1;
                if ($196) {
                 break;
                }
                __THREW__ = 0;
                $197 = (invoke_iii(2724,(2770760|0),($L_50|0))|0);
                $198 = __THREW__; __THREW__ = 0;
                $199 = $198&1;
                if ($199) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($90|0));
                $200 = __THREW__; __THREW__ = 0;
                $201 = $200&1;
                if ($201) {
                 break;
                }
                $202 = HEAP32[$95>>2]|0;
                $203 = ($202>>>0)<(6);
                if ($203) {
                 __THREW__ = 0;
                 $204 = (invoke_i(132)|0);
                 $205 = __THREW__; __THREW__ = 0;
                 $206 = $205&1;
                 if ($206) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($204|0));
                 $207 = __THREW__; __THREW__ = 0;
                 $208 = $207&1;
                 if ($208) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($90|0),($197|0));
                $209 = __THREW__; __THREW__ = 0;
                $210 = $209&1;
                if ($210) {
                 break;
                }
                $211 = HEAP32[$90>>2]|0;
                $212 = (($211) + 92|0);
                $213 = HEAP32[$212>>2]|0;
                $214 = ($213*5)|0;
                $215 = (($107) + ($214)|0);
                HEAP32[$215>>2] = $197;
                __THREW__ = 0;
                invoke_vi(3799,($90|0));
                $216 = __THREW__; __THREW__ = 0;
                $217 = $216&1;
                if ($217) {
                 break;
                }
                $218 = HEAP32[$95>>2]|0;
                $219 = ($218>>>0)<(7);
                if ($219) {
                 __THREW__ = 0;
                 $220 = (invoke_i(132)|0);
                 $221 = __THREW__; __THREW__ = 0;
                 $222 = $221&1;
                 if ($222) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($220|0));
                 $223 = __THREW__; __THREW__ = 0;
                 $224 = $223&1;
                 if ($224) {
                  break;
                 }
                }
                $225 = HEAP32[2999776>>2]|0;
                __THREW__ = 0;
                invoke_vii(3492,($90|0),($225|0));
                $226 = __THREW__; __THREW__ = 0;
                $227 = $226&1;
                if ($227) {
                 break;
                }
                $228 = HEAP32[2999776>>2]|0;
                $229 = HEAP32[$90>>2]|0;
                $230 = (($229) + 92|0);
                $231 = HEAP32[$230>>2]|0;
                $232 = ($231*6)|0;
                $233 = (($107) + ($232)|0);
                HEAP32[$233>>2] = $228;
                __THREW__ = 0;
                $234 = (invoke_ii(2602,($__this|0))|0);
                $235 = __THREW__; __THREW__ = 0;
                $236 = $235&1;
                if ($236) {
                 break;
                }
                HEAP32[$L_59>>2] = $234;
                __THREW__ = 0;
                (invoke_ii(2996,(2768456|0))|0);
                $237 = __THREW__; __THREW__ = 0;
                $238 = $237&1;
                if ($238) {
                 break;
                }
                __THREW__ = 0;
                $239 = (invoke_iii(2724,(2768456|0),($L_59|0))|0);
                $240 = __THREW__; __THREW__ = 0;
                $241 = $240&1;
                if ($241) {
                 break;
                }
                __THREW__ = 0;
                invoke_vi(3799,($90|0));
                $242 = __THREW__; __THREW__ = 0;
                $243 = $242&1;
                if ($243) {
                 break;
                }
                $244 = HEAP32[$95>>2]|0;
                $245 = ($244>>>0)<(8);
                if ($245) {
                 __THREW__ = 0;
                 $246 = (invoke_i(132)|0);
                 $247 = __THREW__; __THREW__ = 0;
                 $248 = $247&1;
                 if ($248) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($246|0));
                 $249 = __THREW__; __THREW__ = 0;
                 $250 = $249&1;
                 if ($250) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($90|0),($239|0));
                $251 = __THREW__; __THREW__ = 0;
                $252 = $251&1;
                if ($252) {
                 break;
                }
                $253 = HEAP32[$90>>2]|0;
                $254 = (($253) + 92|0);
                $255 = HEAP32[$254>>2]|0;
                $256 = ($255*7)|0;
                $257 = (($107) + ($256)|0);
                HEAP32[$257>>2] = $239;
                __THREW__ = 0;
                $258 = (invoke_iii(638,(0|0),($90|0))|0);
                $259 = __THREW__; __THREW__ = 0;
                $260 = $259&1;
                if ($260) {
                 break;
                }
                __THREW__ = 0;
                (invoke_ii(2996,(1167664|0))|0);
                $261 = __THREW__; __THREW__ = 0;
                $262 = $261&1;
                if ($262) {
                 break;
                }
                __THREW__ = 0;
                $263 = (invoke_iii(2773,(1167664|0),0)|0);
                $264 = __THREW__; __THREW__ = 0;
                $265 = $264&1;
                if ($265) {
                 break;
                }
                __THREW__ = 0;
                $266 = (invoke_iiii(1417,(0|0),($258|0),($263|0))|0);
                $267 = __THREW__; __THREW__ = 0;
                $268 = $267&1;
                if ($268) {
                 break;
                } else {
                 $$0 = $266;
                }
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker0I37UnityEngine_UnityEngine_Vector2TraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector2PvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2771616,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z89UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map0P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2250832)|0);
 __Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z97UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_InitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z100UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_CleanupP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z101UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_typeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z118UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_Internal_GetMousePositionP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z106UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_modifiersP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z106UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_characterP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z108UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_commandNameP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z104UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_keyCodeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_Internal_SetNativeEventP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z69UnityEngine_UnityEngine_EventModifiers_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2602744)|0);
 __Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Vector2_m__ctorP31UnityEngine_UnityEngine_Vector2ff($__this,$x,$y) {
 $__this = $__this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2770896);
 HEAPF32[$__this>>2] = $x;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $y;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z42UnityEngine_UnityEngine_Vector2_m_ToStringP31UnityEngine_UnityEngine_Vector2($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_6 = sp;
 $L_12 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2770944);
 __THREW__ = 0;
 invoke_v(971);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2773,(1167664|0),2)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = Math_fround(HEAPF32[$__this>>2]);
     HEAPF32[$L_6>>2] = $7;
     __THREW__ = 0;
     (invoke_ii(2996,(2194912|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($4) + 12|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = ($16|0)==(0);
        if ($17) {
         __THREW__ = 0;
         $18 = (invoke_i(132)|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if ($20) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($10|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($4) + 16|0);
         HEAP32[$27>>2] = $10;
         $28 = (($__this) + 4|0);
         $29 = Math_fround(HEAPF32[$28>>2]);
         HEAPF32[$L_12>>2] = $29;
         __THREW__ = 0;
         (invoke_ii(2996,(2194912|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          $32 = (invoke_iii(2724,(2194912|0),($L_12|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if (!($36)) {
            $37 = HEAP32[$15>>2]|0;
            $38 = ($37>>>0)<(2);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($32|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             $46 = HEAP32[$4>>2]|0;
             $47 = (($46) + 92|0);
             $48 = HEAP32[$47>>2]|0;
             $49 = (($27) + ($48)|0);
             HEAP32[$49>>2] = $32;
             $50 = HEAP32[3000152>>2]|0;
             __THREW__ = 0;
             $51 = (invoke_iiii(1417,(0|0),($50|0),($4|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($51|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z40UnityEngine_UnityEngine_Vector2_m_EqualsP31UnityEngine_UnityEngine_Vector2P22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2771040);
 __THREW__ = 0;
 (invoke_ii(2996,(2771616|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($other|0),(2771616|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2771616|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2775,($other|0),(2771616|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = Math_fround(HEAPF32[$10>>2]);
     $14 = (($10) + 4|0);
     $15 = Math_fround(HEAPF32[$14>>2]);
     __THREW__ = 0;
     $16 = (invoke_iif(7,($__this|0),(+$13))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if (!($18)) {
      if (!($16)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $19 = (($__this) + 4|0);
      __THREW__ = 0;
      $20 = (invoke_iif(7,($19|0),(+$15))|0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if (!($22)) {
       $$0 = $20;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_Vector2_m_SqrMagnitudeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector2($__this,$a) {
 $__this = $__this|0;
 $a = $a|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2771088);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($5));
}
function __Z144UnityEngine_UnityEngine_Vector2_m_op_Subtraction_UnityEngine_UnityEngine_Vector2_UnityEngine_UnityEngine_Vector2_UnityEngine_UnityEngine_Vector2P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector2S1_($agg$result,$__this,$a,$b) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2771184);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround(HEAPF32[$b>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($a) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($b) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = $agg$result;
 $9 = $8;
 HEAP32[$9>>2] = 0;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = 0;
 __THREW__ = 0;
 invoke_viff(15,($agg$result|0),(+$2),(+$7));
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($14|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector2TraitsE6InvokeEPFfPv31UnityEngine_UnityEngine_Vector2ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = $1;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $0;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $12 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$tmpcast$byval_copy)));
 HEAPF32[$ret>>2] = $12;
 $13 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($13|0);
}
function __ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector2TraitsS0_S0_E6InvokeEPF31UnityEngine_UnityEngine_Vector2PvS2_S2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$byval_copy = sp + 32|0;
 $tmpcast$byval_copy = sp + 24|0;
 $ret = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = HEAP32[$args>>2]|0;
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($args) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$tmpcast$byval_copy,$tmpcast1$byval_copy);
 $25 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2771616,$ret)|0);
 STACKTOP = sp;return ($25|0);
}
function __Z62UnityEngine_UnityEngine_Vector2_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2771496)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Vector3_m__ctorP31UnityEngine_UnityEngine_Vector3fff($__this,$x,$y,$z) {
 $__this = $__this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2788856);
 HEAPF32[$__this>>2] = $x;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $y;
 $1 = (($__this) + 8|0);
 HEAPF32[$1>>2] = $z;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Vector3_m_SlerpP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_f($agg$result,$__this,$from,$to,$t) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $from = $from|0;
 $to = $to|0;
 $t = Math_fround($t);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2788904);
 __THREW__ = 0;
 invoke_viiiif(3,($agg$result|0),0,($from|0),($to|0),(+$t));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53UnityEngine_UnityEngine_Vector3_m_INTERNAL_CALL_SlerpP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_f($agg$result,$__this,$from,$to,$t) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $from = $from|0;
 $to = $to|0;
 $t = Math_fround($t);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2788952);
 $0 = HEAP32[2789000>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2789008|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2789000>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiif($7|0,($agg$result|0),($from|0),($to|0),(+$t));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z47UnityEngine_UnityEngine_Vector3_m_RotateTowardsP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_ff($agg$result,$__this,$current,$target,$maxRadiansDelta,$maxMagnitudeDelta) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $current = $current|0;
 $target = $target|0;
 $maxRadiansDelta = Math_fround($maxRadiansDelta);
 $maxMagnitudeDelta = Math_fround($maxMagnitudeDelta);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789112);
 __THREW__ = 0;
 invoke_viiiiff(2,($agg$result|0),0,($current|0),($target|0),(+$maxRadiansDelta),(+$maxMagnitudeDelta));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z61UnityEngine_UnityEngine_Vector3_m_INTERNAL_CALL_RotateTowardsP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_ff($agg$result,$__this,$current,$target,$maxRadiansDelta,$maxMagnitudeDelta) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $current = $current|0;
 $target = $target|0;
 $maxRadiansDelta = Math_fround($maxRadiansDelta);
 $maxMagnitudeDelta = Math_fround($maxMagnitudeDelta);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789160);
 $0 = HEAP32[2789208>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2789216|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2789208>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiiff($7|0,($agg$result|0),($current|0),($target|0),(+$maxRadiansDelta),(+$maxMagnitudeDelta));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z39UnityEngine_UnityEngine_Vector3_m_CrossP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$lhs,$rhs) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789336);
 $0 = (($lhs) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($rhs) + 8|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 * $3);
 $5 = (($lhs) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($rhs) + 4|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = Math_fround($6 * $8);
 $10 = Math_fround($4 - $9);
 $11 = Math_fround(HEAPF32[$rhs>>2]);
 $12 = Math_fround($6 * $11);
 $13 = Math_fround(HEAPF32[$lhs>>2]);
 $14 = Math_fround($3 * $13);
 $15 = Math_fround($12 - $14);
 $16 = Math_fround($8 * $13);
 $17 = Math_fround($1 * $11);
 $18 = Math_fround($16 - $17);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),(+$10),(+$15),(+$18));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch()|0;
  $22 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($21|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z45UnityEngine_UnityEngine_Vector3_m_GetHashCodeP31UnityEngine_UnityEngine_Vector3($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789384);
 __THREW__ = 0;
 $0 = (invoke_ii(1819,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 4|0);
  __THREW__ = 0;
  $4 = (invoke_ii(1819,($3|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 8|0);
   __THREW__ = 0;
   $8 = (invoke_ii(1819,($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = $4 << 2;
    $12 = $11 ^ $0;
    $13 = $8 >> 2;
    $14 = $12 ^ $13;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($14|0);
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
 return 0|0;
}
function __Z40UnityEngine_UnityEngine_Vector3_m_EqualsP31UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789432);
 __THREW__ = 0;
 (invoke_ii(2996,(2792272|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($other|0),(2792272|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2792272|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2776,($other|0),(2792272|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = Math_fround(HEAPF32[$10>>2]);
     $14 = (($10) + 4|0);
     $15 = Math_fround(HEAPF32[$14>>2]);
     $16 = (($10) + 8|0);
     $17 = Math_fround(HEAPF32[$16>>2]);
     __THREW__ = 0;
     $18 = (invoke_iif(7,($__this|0),(+$13))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      if (!($18)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $21 = (($__this) + 4|0);
      __THREW__ = 0;
      $22 = (invoke_iif(7,($21|0),(+$15))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       if (!($22)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $25 = (($__this) + 8|0);
       __THREW__ = 0;
       $26 = (invoke_iif(7,($25|0),(+$17))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        $$0 = $26;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo11868($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z43UnityEngine_UnityEngine_Vector3_m_NormalizeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$value) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $value = $value|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $L_3 = 0, $_stackTraceSentry = 0, $value$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $value$byval_copy1 = sp + 28|0;
 $_stackTraceSentry = sp;
 $L_2 = sp + 4|0;
 $L_3 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789480);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;
 $0 = (Math_fround(+(invoke_fii(36,0,($value$byval_copy1|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 $3 = !($0 <= Math_fround(9.99999974737875163555E-6));
 if ($3) {
  __THREW__ = 0;
  ;HEAP32[$value$byval_copy1+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy1+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy1+8>>2]=HEAP32[$value+8>>2]|0;
  invoke_viiif(3,($L_2|0),0,($value$byval_copy1|0),(+$0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $4 = ___cxa_find_matching_catch()|0;
   $5 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($4|0);
   // unreachable;
  }
  ;HEAP32[$agg$result+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_2+8>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 } else {
  __THREW__ = 0;
  invoke_vii(2070,($L_3|0),0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $4 = ___cxa_find_matching_catch()|0;
   $5 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($4|0);
   // unreachable;
  }
  ;HEAP32[$agg$result+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_3+8>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43UnityEngine_UnityEngine_Vector3_m_MagnitudeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($__this,$a) {
 $__this = $__this|0;
 $a = $a|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789816);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($a) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (Math_fround(Math_sqrt((Math_fround($9)))));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($10));
}
function __Z132UnityEngine_UnityEngine_Vector3_m_op_Division_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3_mscorlib_System_SingleP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3f($agg$result,$__this,$a,$d) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $a = $a|0;
 $d = Math_fround($d);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790584);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround($0 / $d);
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 / $d);
 $5 = (($a) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 / $d);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),(+$1),(+$4),(+$7));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42UnityEngine_UnityEngine_Vector3_m_get_zeroP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790104);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),0.0,0.0,0.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48UnityEngine_UnityEngine_Vector3_m_get_normalizedP31UnityEngine_UnityEngine_Vector3($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__this$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789528);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;
 invoke_viii(738,($agg$result|0),0,($__this$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z65UnityEngine_UnityEngine_Vector3_m_ToString_mscorlib_System_StringP31UnityEngine_UnityEngine_Vector3($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_18 = 0, $L_6 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $L_6 = sp;
 $L_12 = sp + 4|0;
 $L_18 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789576);
 __THREW__ = 0;
 invoke_v(972);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),3)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = Math_fround(HEAPF32[$__this>>2]);
     HEAPF32[$L_6>>2] = $7;
     __THREW__ = 0;
     (invoke_ii(2996,(2194912|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($4) + 12|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = ($16|0)==(0);
        if ($17) {
         __THREW__ = 0;
         $18 = (invoke_i(132)|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if ($20) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($10|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($4) + 16|0);
         HEAP32[$27>>2] = $10;
         $28 = (($__this) + 4|0);
         $29 = Math_fround(HEAPF32[$28>>2]);
         HEAPF32[$L_12>>2] = $29;
         __THREW__ = 0;
         (invoke_ii(2996,(2194912|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          $32 = (invoke_iii(2724,(2194912|0),($L_12|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if (!($36)) {
            $37 = HEAP32[$15>>2]|0;
            $38 = ($37>>>0)<(2);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($32|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             $46 = HEAP32[$4>>2]|0;
             $47 = (($46) + 92|0);
             $48 = HEAP32[$47>>2]|0;
             $49 = (($27) + ($48)|0);
             HEAP32[$49>>2] = $32;
             $50 = (($__this) + 8|0);
             $51 = Math_fround(HEAPF32[$50>>2]);
             HEAPF32[$L_18>>2] = $51;
             __THREW__ = 0;
             (invoke_ii(2996,(2194912|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2724,(2194912|0),($L_18|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if (!($58)) {
                $59 = HEAP32[$15>>2]|0;
                $60 = ($59>>>0)<(3);
                if ($60) {
                 __THREW__ = 0;
                 $61 = (invoke_i(132)|0);
                 $62 = __THREW__; __THREW__ = 0;
                 $63 = $62&1;
                 if ($63) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($61|0));
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if ($65) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($54|0));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if (!($67)) {
                 $68 = HEAP32[$4>>2]|0;
                 $69 = (($68) + 92|0);
                 $70 = HEAP32[$69>>2]|0;
                 $71 = $70 << 1;
                 $72 = (($27) + ($71)|0);
                 HEAP32[$72>>2] = $54;
                 $73 = HEAP32[3000200>>2]|0;
                 __THREW__ = 0;
                 $74 = (invoke_iiii(1417,0,($73|0),($4|0))|0);
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if (!($76)) {
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($74|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __ZL10SZArrayNewP8TypeInfoj11875($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z44UnityEngine_UnityEngine_UnityString_m_FormatP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr($__this,$fmt,$args) {
 $__this = $__this|0;
 $fmt = $fmt|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2814704);
 __THREW__ = 0;
 $0 = (invoke_iiii(556,(0|0),($fmt|0),($args|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z88UnityEngine_UnityEngine_Vector3_m_ToString_mscorlib_System_String_mscorlib_System_StringP31UnityEngine_UnityEngine_Vector3P22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789624);
 __THREW__ = 0;
 invoke_v(973);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),3)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(657,($__this|0),($format|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($4) + 12|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = ($13|0)==(0);
       if ($14) {
        __THREW__ = 0;
        $15 = (invoke_i(132)|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($15|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($4|0),($7|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = (($4) + 16|0);
        HEAP32[$24>>2] = $7;
        $25 = (($__this) + 4|0);
        __THREW__ = 0;
        $26 = (invoke_iii(657,($25|0),($format|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          $31 = HEAP32[$12>>2]|0;
          $32 = ($31>>>0)<(2);
          if ($32) {
           __THREW__ = 0;
           $33 = (invoke_i(132)|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if ($35) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($33|0));
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($4|0),($26|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if (!($39)) {
           $40 = HEAP32[$4>>2]|0;
           $41 = (($40) + 92|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = (($24) + ($42)|0);
           HEAP32[$43>>2] = $26;
           $44 = (($__this) + 8|0);
           __THREW__ = 0;
           $45 = (invoke_iii(657,($44|0),($format|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            __THREW__ = 0;
            invoke_vi(3799,($4|0));
            $48 = __THREW__; __THREW__ = 0;
            $49 = $48&1;
            if (!($49)) {
             $50 = HEAP32[$12>>2]|0;
             $51 = ($50>>>0)<(3);
             if ($51) {
              __THREW__ = 0;
              $52 = (invoke_i(132)|0);
              $53 = __THREW__; __THREW__ = 0;
              $54 = $53&1;
              if ($54) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($52|0));
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if ($56) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($4|0),($45|0));
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if (!($58)) {
              $59 = HEAP32[$4>>2]|0;
              $60 = (($59) + 92|0);
              $61 = HEAP32[$60>>2]|0;
              $62 = $61 << 1;
              $63 = (($24) + ($62)|0);
              HEAP32[$63>>2] = $45;
              $64 = HEAP32[3000264>>2]|0;
              __THREW__ = 0;
              $65 = (invoke_iiii(1417,0,($64|0),($4|0))|0);
              $66 = __THREW__; __THREW__ = 0;
              $67 = $66&1;
              if (!($67)) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($65|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z37UnityEngine_UnityEngine_Vector3_m_DotP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789672);
 $0 = Math_fround(HEAPF32[$lhs>>2]);
 $1 = Math_fround(HEAPF32[$rhs>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($lhs) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($rhs) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($lhs) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($rhs) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($14));
}
function __Z41UnityEngine_UnityEngine_Vector3_m_ProjectP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$vector,$onNormal) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $vector = $vector|0;
 $onNormal = $onNormal|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $L_4 = 0, $L_4$byval_copy = 0, $L_5 = 0, $_stackTraceSentry = 0, $vector$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_4$byval_copy = sp + 64|0;
 $vector$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $0 = sp + 16|0;
 $L_2 = sp + 28|0;
 $L_4 = sp + 40|0;
 $L_5 = sp + 52|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789720);
 ;HEAP32[$0+0>>2]=HEAP32[$onNormal+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$onNormal+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$onNormal+8>>2]|0;
 __THREW__ = 0;
 ;HEAP32[$vector$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$vector$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$vector$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$onNormal+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$onNormal+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$onNormal+8>>2]|0;
 $1 = (Math_fround(+(invoke_fiii(8,0,($vector$byval_copy|0),($L_4$byval_copy|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   (invoke_ii(2996,(2810112|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = HEAP8[((2810112 + 116|0))>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if ($7) {
     __THREW__ = 0;
     (invoke_ii(2996,(2810112|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2810112|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3845,(2810112|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2810112|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if (!($17)) {
     $18 = HEAP32[((2810112 + 80|0))>>2]|0;
     $19 = Math_fround(HEAPF32[$18>>2]);
     $20 = !($1 >= $19);
     if ($20) {
      __THREW__ = 0;
      invoke_vii(2070,($L_2|0),0);
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       break;
      }
      ;HEAP32[$agg$result+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_2+8>>2]|0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     ;HEAP32[$vector$byval_copy+0>>2]=HEAP32[$vector+0>>2]|0;HEAP32[$vector$byval_copy+4>>2]=HEAP32[$vector+4>>2]|0;HEAP32[$vector$byval_copy+8>>2]=HEAP32[$vector+8>>2]|0;
     ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$onNormal+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$onNormal+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$onNormal+8>>2]|0;
     $23 = (Math_fround(+(invoke_fiii(8,0,($vector$byval_copy|0),($L_4$byval_copy|0)))));
     $24 = __THREW__; __THREW__ = 0;
     $25 = $24&1;
     if (!($25)) {
      __THREW__ = 0;
      ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$onNormal+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$onNormal+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$onNormal+8>>2]|0;
      invoke_viiif(2,($L_4|0),0,($L_4$byval_copy|0),(+$23));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;
       invoke_viiif(3,($L_5|0),0,($L_4$byval_copy|0),(+$1));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        ;HEAP32[$agg$result+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$L_5+8>>2]|0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __ZL11RuntimeInitP8TypeInfo11882($klass) {
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($klass) + 116|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN6il2cpp2vm7Runtime9ClassInitEP8TypeInfo($klass);
 STACKTOP = sp;return;
}
function __Z132UnityEngine_UnityEngine_Vector3_m_op_Multiply_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3_mscorlib_System_SingleP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3f($agg$result,$__this,$a,$d) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $a = $a|0;
 $d = Math_fround($d);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790488);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround($0 * $d);
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $d);
 $5 = (($a) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $d);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),(+$1),(+$4),(+$7));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z39UnityEngine_UnityEngine_Vector3_m_AngleP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($__this,$from,$to) {
 $__this = $__this|0;
 $from = $from|0;
 $to = $to|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $L_0 = 0, $L_0$byval_copy = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_1$byval_copy = sp + 40|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 $L_1 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789768);
 __THREW__ = 0;
 invoke_vii(2069,($L_0|0),($from|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2069,($L_1|0),($to|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   $4 = (Math_fround(+(invoke_fiii(8,0,($L_0$byval_copy|0),($L_1$byval_copy|0)))));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (Math_fround(+(invoke_fifff(1,0,(+$4),-1.0,1.0))));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = (Math_fround(+(Math_acos((+$7)))));
     $11 = Math_fround($10 * Math_fround(57.295780181884765625));
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return (Math_fround($11));
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return Math_fround(0);
}
function __Z37UnityEngine_UnityEngine_Mathf_m_ClampP22mscorlib_System_Objectfff($__this,$value,$min,$max) {
 $__this = $__this|0;
 $value = Math_fround($value);
 $min = Math_fround($min);
 $max = Math_fround($max);
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808648);
 $0 = !($value >= $min);
 if ($0) {
  $$0 = $min;
 } else {
  $1 = !($value <= $max);
  if ($1) {
   $$0 = $max;
  } else {
   $$0 = $value;
  }
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($$0));
}
function __Z47UnityEngine_UnityEngine_Vector3_m_get_magnitudeP31UnityEngine_UnityEngine_Vector3($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789864);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($__this) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($__this) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 $10 = (Math_fround(Math_sqrt((Math_fround($9)))));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($10));
}
function __Z46UnityEngine_UnityEngine_Vector3_m_SqrMagnitudeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($__this,$a) {
 $__this = $__this|0;
 $a = $a|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789912);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($a) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($9));
}
function __Z50UnityEngine_UnityEngine_Vector3_m_get_sqrMagnitudeP31UnityEngine_UnityEngine_Vector3($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2789960);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 $1 = Math_fround($0 * $0);
 $2 = (($__this) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $3);
 $5 = Math_fround($1 + $4);
 $6 = (($__this) + 8|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * $7);
 $9 = Math_fround($5 + $8);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($9));
}
function __Z37UnityEngine_UnityEngine_Vector3_m_MinP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$lhs,$rhs) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790008);
 $0 = Math_fround(HEAPF32[$lhs>>2]);
 $1 = Math_fround(HEAPF32[$rhs>>2]);
 __THREW__ = 0;
 $2 = (Math_fround(+(invoke_fiff(3,0,(+$0),(+$1)))));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($lhs) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($rhs) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  __THREW__ = 0;
  $9 = (Math_fround(+(invoke_fiff(3,0,(+$6),(+$8)))));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = (($lhs) + 8|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = (($rhs) + 8|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   __THREW__ = 0;
   $16 = (Math_fround(+(invoke_fiff(3,0,(+$13),(+$15)))));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
    __THREW__ = 0;
    invoke_vifff(4,($agg$result|0),(+$2),(+$9),(+$16));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z104UnityEngine_UnityEngine_Mathf_m_Min_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_Objectff($__this,$a,$b) {
 $__this = $__this|0;
 $a = Math_fround($a);
 $b = Math_fround($b);
 var $0 = 0, $_stackTraceSentry = 0, $a$b = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808360);
 $0 = !($a >= $b);
 $a$b = $0 ? $a : $b;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($a$b));
}
function __Z37UnityEngine_UnityEngine_Vector3_m_MaxP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$lhs,$rhs) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0);
 var $7 = 0, $8 = Math_fround(0), $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790056);
 $0 = Math_fround(HEAPF32[$lhs>>2]);
 $1 = Math_fround(HEAPF32[$rhs>>2]);
 __THREW__ = 0;
 $2 = (Math_fround(+(invoke_fiff(4,0,(+$0),(+$1)))));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = (($lhs) + 4|0);
  $6 = Math_fround(HEAPF32[$5>>2]);
  $7 = (($rhs) + 4|0);
  $8 = Math_fround(HEAPF32[$7>>2]);
  __THREW__ = 0;
  $9 = (Math_fround(+(invoke_fiff(4,0,(+$6),(+$8)))));
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = (($lhs) + 8|0);
   $13 = Math_fround(HEAPF32[$12>>2]);
   $14 = (($rhs) + 8|0);
   $15 = Math_fround(HEAPF32[$14>>2]);
   __THREW__ = 0;
   $16 = (Math_fround(+(invoke_fiff(4,0,(+$13),(+$15)))));
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if (!($18)) {
    ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
    __THREW__ = 0;
    invoke_vifff(4,($agg$result|0),(+$2),(+$9),(+$16));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z104UnityEngine_UnityEngine_Mathf_m_Max_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_Objectff($__this,$a,$b) {
 $__this = $__this|0;
 $a = Math_fround($a);
 $b = Math_fround($b);
 var $0 = 0, $_stackTraceSentry = 0, $a$b = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808456);
 $0 = !($a <= $b);
 $a$b = $0 ? $a : $b;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($a$b));
}
function __Z45UnityEngine_UnityEngine_Vector3_m_get_forwardP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790152);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),0.0,0.0,1.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42UnityEngine_UnityEngine_Vector3_m_get_backP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790200);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),0.0,0.0,-1.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z40UnityEngine_UnityEngine_Vector3_m_get_upP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790248);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),0.0,1.0,0.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42UnityEngine_UnityEngine_Vector3_m_get_downP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790296);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),0.0,-1.0,0.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z141UnityEngine_UnityEngine_Vector3_m_op_Addition_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$a,$b) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790344);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround(HEAPF32[$b>>2]);
 $2 = Math_fround($0 + $1);
 $3 = (($a) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($b) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 + $6);
 $8 = (($a) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($b) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 + $11);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),(+$2),(+$7),(+$12));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z144UnityEngine_UnityEngine_Vector3_m_op_Subtraction_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$a,$b) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790392);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround(HEAPF32[$b>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($a) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($b) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($a) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($b) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),(+$2),(+$7),(+$12));
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z114UnityEngine_UnityEngine_Vector3_m_op_UnaryNegation_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$a) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $a = $a|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790440);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround(-$0);
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround(-$3);
 $5 = (($a) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround(-$6);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),(+$1),(+$4),(+$7));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z132UnityEngine_UnityEngine_Vector3_m_op_Multiply_UnityEngine_UnityEngine_Vector3_mscorlib_System_Single_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Objectf31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$d,$a) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $d = Math_fround($d);
 $a = $a|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790536);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround($0 * $d);
 $2 = (($a) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($3 * $d);
 $5 = (($a) + 8|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($6 * $d);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($agg$result|0),(+$1),(+$4),(+$7));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($10|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z133UnityEngine_UnityEngine_Vector3_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $L_0$byval_copy = 0, $_stackTraceSentry = 0, $lhs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $L_0$byval_copy = sp + 28|0;
 $lhs$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790632);
 __THREW__ = 0;
 ;HEAP32[$lhs$byval_copy+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$lhs$byval_copy+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$lhs$byval_copy+8>>2]=HEAP32[$lhs+8>>2]|0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$rhs+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$rhs+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$rhs+8>>2]|0;
 invoke_viiii(223,($L_0|0),0,($lhs$byval_copy|0),($L_0$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
 $2 = (Math_fround(+(invoke_fii(37,0,($L_0$byval_copy|0)))));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = $2 < Math_fround(9.99999943962492920946E-11);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z135UnityEngine_UnityEngine_Vector3_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $L_0$byval_copy = 0, $_stackTraceSentry = 0, $lhs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $L_0$byval_copy = sp + 28|0;
 $lhs$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2790680);
 __THREW__ = 0;
 ;HEAP32[$lhs$byval_copy+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$lhs$byval_copy+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$lhs$byval_copy+8>>2]=HEAP32[$lhs+8>>2]|0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$rhs+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$rhs+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$rhs+8>>2]|0;
 invoke_viiii(223,($L_0|0),0,($lhs$byval_copy|0),($L_0$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
 $2 = (Math_fround(+(invoke_fii(37,0,($L_0$byval_copy|0)))));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = !($2 < Math_fround(9.99999943962492920946E-11));
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker3I28mscorlib_System_SingleTraitsS0_S0_E6InvokeEPFvPvfffES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 FUNCTION_TABLE_vifff[$action & 15]($obj,$1,$4,$7);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I37UnityEngine_UnityEngine_Vector3Traits17VoidPointerTraitsS1_28mscorlib_System_SingleTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS5_S5_fES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$4>>2]);
 FUNCTION_TABLE_viiiif[$func & 3]($ret,$obj,$0,$2,$5);
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker4I37UnityEngine_UnityEngine_Vector3TraitsS0_S0_28mscorlib_System_SingleTraitsS1_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS3_S3_ffES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy1 = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 12|0;
 $0 = sp + 24|0;
 $1 = sp + 36|0;
 $2 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$4+8>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_fround(HEAPF32[$9>>2]);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;
 FUNCTION_TABLE_viiiiff[$func & 3]($ret,$obj,$$byval_copy,$$byval_copy1,$7,$10);
 $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN12FuncInvoker4I37UnityEngine_UnityEngine_Vector3Traits17VoidPointerTraitsS1_28mscorlib_System_SingleTraitsS2_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS5_S5_ffES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = Math_fround(HEAPF32[$7>>2]);
 FUNCTION_TABLE_viiiiff[$func & 3]($ret,$obj,$0,$2,$5,$8);
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector3TraitsS1_E6InvokeEPFfPv31UnityEngine_UnityEngine_Vector3S4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 28|0;
 $$byval_copy = sp;
 $ret = sp + 12|0;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 $4 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$$byval_copy,$tmpcast$byval_copy)));
 HEAPF32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3TraitsS0_28mscorlib_System_SingleTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS3_fES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 24|0;
 $ret = sp;
 $0 = sp + 12|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 FUNCTION_TABLE_viiif[$func & 15]($ret,$obj,$$byval_copy,$4);
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3Traits28mscorlib_System_SingleTraitsS0_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvfS3_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 12|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 FUNCTION_TABLE_viifi[$func & 7]($ret,$obj,$1,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits37UnityEngine_UnityEngine_Vector3TraitsS1_E6InvokeEPFbPv31UnityEngine_UnityEngine_Vector3S4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 24|0;
 $$byval_copy = sp;
 $ret = sp + 36|0;
 $0 = sp + 12|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z62UnityEngine_UnityEngine_Vector3_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2791992)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116UnityEngine_UnityEngine_Vector3_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Vector3_m_INTERNAL_CALL_SlerpP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z124UnityEngine_UnityEngine_Vector3_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Vector3_m_INTERNAL_CALL_RotateTowardsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z150UnityEngine_UnityEngine_Color_m__ctor_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP29UnityEngine_UnityEngine_Colorffff($__this,$r,$g,$b,$a) {
 $__this = $__this|0;
 $r = Math_fround($r);
 $g = Math_fround($g);
 $b = Math_fround($b);
 $a = Math_fround($a);
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2792408);
 HEAPF32[$__this>>2] = $r;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $g;
 $1 = (($__this) + 8|0);
 HEAPF32[$1>>2] = $b;
 $2 = (($__this) + 12|0);
 HEAPF32[$2>>2] = $a;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z127UnityEngine_UnityEngine_Color_m__ctor_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP29UnityEngine_UnityEngine_Colorfff($__this,$r,$g,$b) {
 $__this = $__this|0;
 $r = Math_fround($r);
 $g = Math_fround($g);
 $b = Math_fround($b);
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2792456);
 HEAPF32[$__this>>2] = $r;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $g;
 $1 = (($__this) + 8|0);
 HEAPF32[$1>>2] = $b;
 $2 = (($__this) + 12|0);
 HEAPF32[$2>>2] = Math_fround(1.0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z40UnityEngine_UnityEngine_Color_m_ToStringP29UnityEngine_UnityEngine_Color($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_12 = 0, $L_18 = 0, $L_24 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_6 = sp;
 $L_12 = sp + 4|0;
 $L_18 = sp + 8|0;
 $L_24 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2792504);
 __THREW__ = 0;
 invoke_v(974);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),4)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = Math_fround(HEAPF32[$__this>>2]);
     HEAPF32[$L_6>>2] = $7;
     __THREW__ = 0;
     (invoke_ii(2996,(2194912|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($4) + 12|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = ($16|0)==(0);
        if ($17) {
         __THREW__ = 0;
         $18 = (invoke_i(132)|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if ($20) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($10|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($4) + 16|0);
         HEAP32[$27>>2] = $10;
         $28 = (($__this) + 4|0);
         $29 = Math_fround(HEAPF32[$28>>2]);
         HEAPF32[$L_12>>2] = $29;
         __THREW__ = 0;
         (invoke_ii(2996,(2194912|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          $32 = (invoke_iii(2724,(2194912|0),($L_12|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if (!($36)) {
            $37 = HEAP32[$15>>2]|0;
            $38 = ($37>>>0)<(2);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($32|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             $46 = HEAP32[$4>>2]|0;
             $47 = (($46) + 92|0);
             $48 = HEAP32[$47>>2]|0;
             $49 = (($27) + ($48)|0);
             HEAP32[$49>>2] = $32;
             $50 = (($__this) + 8|0);
             $51 = Math_fround(HEAPF32[$50>>2]);
             HEAPF32[$L_18>>2] = $51;
             __THREW__ = 0;
             (invoke_ii(2996,(2194912|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2724,(2194912|0),($L_18|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if (!($58)) {
                $59 = HEAP32[$15>>2]|0;
                $60 = ($59>>>0)<(3);
                if ($60) {
                 __THREW__ = 0;
                 $61 = (invoke_i(132)|0);
                 $62 = __THREW__; __THREW__ = 0;
                 $63 = $62&1;
                 if ($63) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($61|0));
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if ($65) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($54|0));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if (!($67)) {
                 $68 = HEAP32[$4>>2]|0;
                 $69 = (($68) + 92|0);
                 $70 = HEAP32[$69>>2]|0;
                 $71 = $70 << 1;
                 $72 = (($27) + ($71)|0);
                 HEAP32[$72>>2] = $54;
                 $73 = (($__this) + 12|0);
                 $74 = Math_fround(HEAPF32[$73>>2]);
                 HEAPF32[$L_24>>2] = $74;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2194912|0))|0);
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if (!($76)) {
                  __THREW__ = 0;
                  $77 = (invoke_iii(2724,(2194912|0),($L_24|0))|0);
                  $78 = __THREW__; __THREW__ = 0;
                  $79 = $78&1;
                  if ($79) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break;
                  }
                  $82 = HEAP32[$15>>2]|0;
                  $83 = ($82>>>0)<(4);
                  if ($83) {
                   __THREW__ = 0;
                   $84 = (invoke_i(132)|0);
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($84|0));
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($77|0));
                  $89 = __THREW__; __THREW__ = 0;
                  $90 = $89&1;
                  if ($90) {
                   break;
                  }
                  $91 = HEAP32[$4>>2]|0;
                  $92 = (($91) + 92|0);
                  $93 = HEAP32[$92>>2]|0;
                  $94 = ($93*3)|0;
                  $95 = (($27) + ($94)|0);
                  HEAP32[$95>>2] = $77;
                  $96 = HEAP32[3000312>>2]|0;
                  __THREW__ = 0;
                  $97 = (invoke_iiii(1417,0,($96|0),($4|0))|0);
                  $98 = __THREW__; __THREW__ = 0;
                  $99 = $98&1;
                  if ($99) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($97|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Color_m_GetHashCodeP29UnityEngine_UnityEngine_Color($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $L_0 = 0, $V_0 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__this$byval_copy = sp + 40|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 8|0;
 $L_0 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2792552);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 invoke_viii(740,($L_0|0),0,($__this$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 ;HEAP32[$V_0+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_0+12>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_ii(2624,($V_0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($2|0);
 }
 return 0|0;
}
function __Z105UnityEngine_UnityEngine_Color_m_op_Implicit_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_ColorP22mscorlib_System_Object29UnityEngine_UnityEngine_Color($agg$result,$__this,$c) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $c = $c|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2792744);
 $0 = Math_fround(HEAPF32[$c>>2]);
 $1 = (($c) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($c) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($c) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viffff(5,($agg$result|0),(+$0),(+$2),(+$4),(+$6));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z45UnityEngine_UnityEngine_Vector4_m_GetHashCodeP31UnityEngine_UnityEngine_Vector4($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2806344);
 __THREW__ = 0;
 $0 = (invoke_ii(1819,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 4|0);
  __THREW__ = 0;
  $4 = (invoke_ii(1819,($3|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 8|0);
   __THREW__ = 0;
   $8 = (invoke_ii(1819,($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($__this) + 12|0);
    __THREW__ = 0;
    $12 = (invoke_ii(1819,($11|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = $4 << 2;
     $16 = $8 >> 2;
     $17 = $15 ^ $0;
     $18 = $17 ^ $16;
     $19 = $12 >> 1;
     $20 = $18 ^ $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($20|0);
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z38UnityEngine_UnityEngine_Color_m_EqualsP29UnityEngine_UnityEngine_ColorP22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2792600);
 __THREW__ = 0;
 (invoke_ii(2996,(2793208|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($other|0),(2793208|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2793208|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2776,($other|0),(2793208|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = Math_fround(HEAPF32[$10>>2]);
     $14 = (($10) + 4|0);
     $15 = Math_fround(HEAPF32[$14>>2]);
     $16 = (($10) + 8|0);
     $17 = Math_fround(HEAPF32[$16>>2]);
     $18 = (($10) + 12|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     __THREW__ = 0;
     $20 = (invoke_iif(7,($__this|0),(+$13))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      if (!($20)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $23 = (($__this) + 4|0);
      __THREW__ = 0;
      $24 = (invoke_iif(7,($23|0),(+$15))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       if (!($24)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $27 = (($__this) + 8|0);
       __THREW__ = 0;
       $28 = (invoke_iif(7,($27|0),(+$17))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        if (!($28)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $31 = (($__this) + 12|0);
        __THREW__ = 0;
        $32 = (invoke_iif(7,($31|0),(+$19))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         $$0 = $32;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z39UnityEngine_UnityEngine_Color_m_get_redP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2792648);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viffff(2,($agg$result|0),1.0,0.0,0.0,1.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z41UnityEngine_UnityEngine_Color_m_get_whiteP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2792696);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viffff(2,($agg$result|0),1.0,1.0,1.0,1.0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z39UnityEngine_UnityEngine_Vector4_m__ctorP31UnityEngine_UnityEngine_Vector4ffff($__this,$x,$y,$z,$w) {
 $__this = $__this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 $w = Math_fround($w);
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2806296);
 HEAPF32[$__this>>2] = $x;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $y;
 $1 = (($__this) + 8|0);
 HEAPF32[$1>>2] = $z;
 $2 = (($__this) + 12|0);
 HEAPF32[$2>>2] = $w;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN14ActionInvoker4I28mscorlib_System_SingleTraitsS0_S0_S0_E6InvokeEPFvPvffffES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_fround(HEAPF32[$9>>2]);
 FUNCTION_TABLE_viffff[$action & 15]($obj,$1,$4,$7,$10);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker0I35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPF29UnityEngine_UnityEngine_ColorPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2793208,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector4Traits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector4Pv29UnityEngine_UnityEngine_ColorES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2807040,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z60UnityEngine_UnityEngine_Color_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2791992)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Color32_m__ctorP31UnityEngine_UnityEngine_Color32hhhh($__this,$r,$g,$b,$a) {
 $__this = $__this|0;
 $r = $r|0;
 $g = $g|0;
 $b = $b|0;
 $a = $a|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2793344);
 HEAP8[$__this>>0] = $r;
 $0 = (($__this) + 1|0);
 HEAP8[$0>>0] = $g;
 $1 = (($__this) + 2|0);
 HEAP8[$1>>0] = $b;
 $2 = (($__this) + 3|0);
 HEAP8[$2>>0] = $a;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z42UnityEngine_UnityEngine_Color32_m_ToStringP31UnityEngine_UnityEngine_Color32($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_12 = 0, $L_18 = 0, $L_24 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $L_6 = sp + 7|0;
 $L_12 = sp + 4|0;
 $L_18 = sp + 5|0;
 $L_24 = sp + 6|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2793392);
 __THREW__ = 0;
 invoke_v(975);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),4)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = HEAP8[$__this>>0]|0;
     HEAP8[$L_6>>0] = $7;
     __THREW__ = 0;
     (invoke_ii(2996,(2169424|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2724,(2169424|0),($L_6|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($4) + 12|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = ($16|0)==(0);
        if ($17) {
         __THREW__ = 0;
         $18 = (invoke_i(132)|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if ($20) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($10|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($4) + 16|0);
         HEAP32[$27>>2] = $10;
         $28 = (($__this) + 1|0);
         $29 = HEAP8[$28>>0]|0;
         HEAP8[$L_12>>0] = $29;
         __THREW__ = 0;
         (invoke_ii(2996,(2169424|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          $32 = (invoke_iii(2724,(2169424|0),($L_12|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if (!($36)) {
            $37 = HEAP32[$15>>2]|0;
            $38 = ($37>>>0)<(2);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($32|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             $46 = HEAP32[$4>>2]|0;
             $47 = (($46) + 92|0);
             $48 = HEAP32[$47>>2]|0;
             $49 = (($27) + ($48)|0);
             HEAP32[$49>>2] = $32;
             $50 = (($__this) + 2|0);
             $51 = HEAP8[$50>>0]|0;
             HEAP8[$L_18>>0] = $51;
             __THREW__ = 0;
             (invoke_ii(2996,(2169424|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2724,(2169424|0),($L_18|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if (!($58)) {
                $59 = HEAP32[$15>>2]|0;
                $60 = ($59>>>0)<(3);
                if ($60) {
                 __THREW__ = 0;
                 $61 = (invoke_i(132)|0);
                 $62 = __THREW__; __THREW__ = 0;
                 $63 = $62&1;
                 if ($63) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($61|0));
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if ($65) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($54|0));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if (!($67)) {
                 $68 = HEAP32[$4>>2]|0;
                 $69 = (($68) + 92|0);
                 $70 = HEAP32[$69>>2]|0;
                 $71 = $70 << 1;
                 $72 = (($27) + ($71)|0);
                 HEAP32[$72>>2] = $54;
                 $73 = (($__this) + 3|0);
                 $74 = HEAP8[$73>>0]|0;
                 HEAP8[$L_24>>0] = $74;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2169424|0))|0);
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if (!($76)) {
                  __THREW__ = 0;
                  $77 = (invoke_iii(2724,(2169424|0),($L_24|0))|0);
                  $78 = __THREW__; __THREW__ = 0;
                  $79 = $78&1;
                  if ($79) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break;
                  }
                  $82 = HEAP32[$15>>2]|0;
                  $83 = ($82>>>0)<(4);
                  if ($83) {
                   __THREW__ = 0;
                   $84 = (invoke_i(132)|0);
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($84|0));
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($77|0));
                  $89 = __THREW__; __THREW__ = 0;
                  $90 = $89&1;
                  if ($90) {
                   break;
                  }
                  $91 = HEAP32[$4>>2]|0;
                  $92 = (($91) + 92|0);
                  $93 = HEAP32[$92>>2]|0;
                  $94 = ($93*3)|0;
                  $95 = (($27) + ($94)|0);
                  HEAP32[$95>>2] = $77;
                  $96 = HEAP32[3000400>>2]|0;
                  __THREW__ = 0;
                  $97 = (invoke_iiii(1417,0,($96|0),($4|0))|0);
                  $98 = __THREW__; __THREW__ = 0;
                  $99 = $98&1;
                  if ($99) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($97|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z107UnityEngine_UnityEngine_Color32_m_op_Implicit_UnityEngine_UnityEngine_Color32_UnityEngine_UnityEngine_ColorP22mscorlib_System_Object29UnityEngine_UnityEngine_Color($agg$result,$__this,$c) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $c = $c|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2793440);
 $0 = Math_fround(HEAPF32[$c>>2]);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fif(12,0,(+$0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = Math_fround($1 * Math_fround(255.0));
  $5 = (~~(($4))&255);
  $6 = (($c) + 4|0);
  $7 = Math_fround(HEAPF32[$6>>2]);
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fif(12,0,(+$7)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = Math_fround($8 * Math_fround(255.0));
   $12 = (~~(($11))&255);
   $13 = (($c) + 8|0);
   $14 = Math_fround(HEAPF32[$13>>2]);
   __THREW__ = 0;
   $15 = (Math_fround(+(invoke_fif(12,0,(+$14)))));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = (($c) + 12|0);
    $19 = Math_fround(HEAPF32[$18>>2]);
    __THREW__ = 0;
    $20 = (Math_fround(+(invoke_fif(12,0,(+$19)))));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if (!($22)) {
     $23 = Math_fround($15 * Math_fround(255.0));
     $24 = (~~(($23))&255);
     $25 = Math_fround($20 * Math_fround(255.0));
     $26 = (~~(($25))&255);
     HEAP8[$agg$result>>0]=0&255;HEAP8[$agg$result+1>>0]=(0>>8)&255;HEAP8[$agg$result+2>>0]=(0>>16)&255;HEAP8[$agg$result+3>>0]=0>>24;
     __THREW__ = 0;
     invoke_viiiii(77,($agg$result|0),($5|0),($12|0),($24|0),($26|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($29|0);
 // unreachable;
}
function __Z39UnityEngine_UnityEngine_Mathf_m_Clamp01P22mscorlib_System_Objectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $$0 = Math_fround(0), $$value = Math_fround(0), $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808696);
 $0 = !($value >= Math_fround(0.0));
 if ($0) {
  $$0 = Math_fround(0.0);
 } else {
  $1 = !($value <= Math_fround(1.0));
  $$value = $1 ? Math_fround(1.0) : $value;
  $$0 = $$value;
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Color32Traits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPF31UnityEngine_UnityEngine_Color32Pv29UnityEngine_UnityEngine_ColorES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2793720,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z42UnityEngine_UnityEngine_Quaternion_m__ctorP34UnityEngine_UnityEngine_Quaternionffff($__this,$x,$y,$z,$w) {
 $__this = $__this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 $w = Math_fround($w);
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2793856);
 HEAPF32[$__this>>2] = $x;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $y;
 $1 = (($__this) + 8|0);
 HEAPF32[$1>>2] = $z;
 $2 = (($__this) + 12|0);
 HEAPF32[$2>>2] = $w;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z51UnityEngine_UnityEngine_Quaternion_m_FromToRotationP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$fromDirection,$toDirection) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $fromDirection = $fromDirection|0;
 $toDirection = $toDirection|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2793904);
 __THREW__ = 0;
 invoke_viiii(225,($agg$result|0),0,($fromDirection|0),($toDirection|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z65UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_FromToRotationP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_($agg$result,$__this,$fromDirection,$toDirection) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $fromDirection = $fromDirection|0;
 $toDirection = $toDirection|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2793952);
 $0 = HEAP32[2794000>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2794008|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2794000>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($fromDirection|0),($toDirection|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z148UnityEngine_UnityEngine_Quaternion_m_LookRotation_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($agg$result,$__this,$forward,$upwards) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $forward = $forward|0;
 $upwards = $upwards|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794104);
 __THREW__ = 0;
 invoke_viiii(227,($agg$result|0),0,($forward|0),($upwards|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z63UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_LookRotationP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_($agg$result,$__this,$forward,$upwards) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $forward = $forward|0;
 $upwards = $upwards|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794200);
 $0 = HEAP32[2794248>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2794256|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2794248>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($forward|0),($upwards|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z116UnityEngine_UnityEngine_Quaternion_m_LookRotation_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$forward) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $forward = $forward|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $V_0 = sp;
 $L_0 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794152);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2073,($L_0|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 ;HEAP32[$V_0+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_0+8>>2]|0;
 __THREW__ = 0;
 invoke_viiii(227,($agg$result|0),0,($forward|0),($V_0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44UnityEngine_UnityEngine_Quaternion_m_InverseP22mscorlib_System_Object34UnityEngine_UnityEngine_Quaternion($agg$result,$__this,$rotation) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794352);
 __THREW__ = 0;
 invoke_viii(744,($agg$result|0),0,($rotation|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z58UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_InverseP22mscorlib_System_ObjectP34UnityEngine_UnityEngine_Quaternion($agg$result,$__this,$rotation) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794400);
 $0 = HEAP32[2794448>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2794456|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2794448>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($agg$result|0),($rotation|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_Quaternion_m_ToStringP34UnityEngine_UnityEngine_Quaternion($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_12 = 0, $L_18 = 0, $L_24 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_6 = sp;
 $L_12 = sp + 4|0;
 $L_18 = sp + 8|0;
 $L_24 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794528);
 __THREW__ = 0;
 invoke_v(976);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),4)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = Math_fround(HEAPF32[$__this>>2]);
     HEAPF32[$L_6>>2] = $7;
     __THREW__ = 0;
     (invoke_ii(2996,(2194912|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($4) + 12|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = ($16|0)==(0);
        if ($17) {
         __THREW__ = 0;
         $18 = (invoke_i(132)|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if ($20) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($10|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($4) + 16|0);
         HEAP32[$27>>2] = $10;
         $28 = (($__this) + 4|0);
         $29 = Math_fround(HEAPF32[$28>>2]);
         HEAPF32[$L_12>>2] = $29;
         __THREW__ = 0;
         (invoke_ii(2996,(2194912|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          $32 = (invoke_iii(2724,(2194912|0),($L_12|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if (!($36)) {
            $37 = HEAP32[$15>>2]|0;
            $38 = ($37>>>0)<(2);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($32|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             $46 = HEAP32[$4>>2]|0;
             $47 = (($46) + 92|0);
             $48 = HEAP32[$47>>2]|0;
             $49 = (($27) + ($48)|0);
             HEAP32[$49>>2] = $32;
             $50 = (($__this) + 8|0);
             $51 = Math_fround(HEAPF32[$50>>2]);
             HEAPF32[$L_18>>2] = $51;
             __THREW__ = 0;
             (invoke_ii(2996,(2194912|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2724,(2194912|0),($L_18|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if (!($58)) {
                $59 = HEAP32[$15>>2]|0;
                $60 = ($59>>>0)<(3);
                if ($60) {
                 __THREW__ = 0;
                 $61 = (invoke_i(132)|0);
                 $62 = __THREW__; __THREW__ = 0;
                 $63 = $62&1;
                 if ($63) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($61|0));
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if ($65) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($54|0));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if (!($67)) {
                 $68 = HEAP32[$4>>2]|0;
                 $69 = (($68) + 92|0);
                 $70 = HEAP32[$69>>2]|0;
                 $71 = $70 << 1;
                 $72 = (($27) + ($71)|0);
                 HEAP32[$72>>2] = $54;
                 $73 = (($__this) + 12|0);
                 $74 = Math_fround(HEAPF32[$73>>2]);
                 HEAPF32[$L_24>>2] = $74;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2194912|0))|0);
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if (!($76)) {
                  __THREW__ = 0;
                  $77 = (invoke_iii(2724,(2194912|0),($L_24|0))|0);
                  $78 = __THREW__; __THREW__ = 0;
                  $79 = $78&1;
                  if ($79) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break;
                  }
                  $82 = HEAP32[$15>>2]|0;
                  $83 = ($82>>>0)<(4);
                  if ($83) {
                   __THREW__ = 0;
                   $84 = (invoke_i(132)|0);
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($84|0));
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($77|0));
                  $89 = __THREW__; __THREW__ = 0;
                  $90 = $89&1;
                  if ($90) {
                   break;
                  }
                  $91 = HEAP32[$4>>2]|0;
                  $92 = (($91) + 92|0);
                  $93 = HEAP32[$92>>2]|0;
                  $94 = ($93*3)|0;
                  $95 = (($27) + ($94)|0);
                  HEAP32[$95>>2] = $77;
                  $96 = HEAP32[3000464>>2]|0;
                  __THREW__ = 0;
                  $97 = (invoke_iiii(1417,0,($96|0),($4|0))|0);
                  $98 = __THREW__; __THREW__ = 0;
                  $99 = $98&1;
                  if ($99) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($97|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z52UnityEngine_UnityEngine_Quaternion_m_get_eulerAnglesP34UnityEngine_UnityEngine_Quaternion($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $L_0$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $L_0$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794576);
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$L_0$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;
 invoke_viii(745,($L_0|0),0,($L_0$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
 invoke_viiif(2,($agg$result|0),0,($L_0$byval_copy|0),57.295780181884765625);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56UnityEngine_UnityEngine_Quaternion_m_Internal_ToEulerRadP22mscorlib_System_Object34UnityEngine_UnityEngine_Quaternion($agg$result,$__this,$rotation) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794672);
 __THREW__ = 0;
 invoke_viii(746,($agg$result|0),0,($rotation|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42UnityEngine_UnityEngine_Quaternion_m_EulerP22mscorlib_System_Objectfff($agg$result,$__this,$x,$y,$z) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $x = Math_fround($x);
 $y = Math_fround($y);
 $z = Math_fround($z);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $L_2 = 0, $L_2$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $L_2$byval_copy = sp + 28|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 $L_2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794624);
 ;HEAP32[$L_0+0>>2]=0|0;HEAP32[$L_0+4>>2]=0|0;HEAP32[$L_0+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($L_0|0),(+$x),(+$y),(+$z));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  ;HEAP32[$L_2$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_2$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_2$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
  invoke_viiif(2,($L_2|0),0,($L_2$byval_copy|0),0.0174532923847436904907);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_2$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_2$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_2$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;
   invoke_viii(747,($agg$result|0),0,($L_2$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z58UnityEngine_UnityEngine_Quaternion_m_Internal_FromEulerRadP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$euler) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $euler = $euler|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794864);
 __THREW__ = 0;
 invoke_viii(748,($agg$result|0),0,($euler|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z70UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_Internal_ToEulerRadP22mscorlib_System_ObjectP34UnityEngine_UnityEngine_Quaternion($agg$result,$__this,$rotation) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794720);
 $0 = HEAP32[2794768>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2794776|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2794768>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($agg$result|0),($rotation|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z72UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_Internal_FromEulerRadP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$euler) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $euler = $euler|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2794912);
 $0 = HEAP32[2794960>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2794968|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2794960>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($agg$result|0),($euler|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_Quaternion_m_GetHashCodeP34UnityEngine_UnityEngine_Quaternion($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2795056);
 __THREW__ = 0;
 $0 = (invoke_ii(1819,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 4|0);
  __THREW__ = 0;
  $4 = (invoke_ii(1819,($3|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($__this) + 8|0);
   __THREW__ = 0;
   $8 = (invoke_ii(1819,($7|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($__this) + 12|0);
    __THREW__ = 0;
    $12 = (invoke_ii(1819,($11|0))|0);
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     $15 = $4 << 2;
     $16 = $8 >> 2;
     $17 = $15 ^ $0;
     $18 = $17 ^ $16;
     $19 = $12 >> 1;
     $20 = $18 ^ $19;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($20|0);
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Quaternion_m_EqualsP34UnityEngine_UnityEngine_QuaternionP22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2795104);
 __THREW__ = 0;
 (invoke_ii(2996,(2796280|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($other|0),(2796280|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2796280|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2776,($other|0),(2796280|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = Math_fround(HEAPF32[$10>>2]);
     $14 = (($10) + 4|0);
     $15 = Math_fround(HEAPF32[$14>>2]);
     $16 = (($10) + 8|0);
     $17 = Math_fround(HEAPF32[$16>>2]);
     $18 = (($10) + 12|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     __THREW__ = 0;
     $20 = (invoke_iif(7,($__this|0),(+$13))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      if (!($20)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $23 = (($__this) + 4|0);
      __THREW__ = 0;
      $24 = (invoke_iif(7,($23|0),(+$15))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       if (!($24)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $27 = (($__this) + 8|0);
       __THREW__ = 0;
       $28 = (invoke_iif(7,($27|0),(+$17))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        if (!($28)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $31 = (($__this) + 12|0);
        __THREW__ = 0;
        $32 = (invoke_iif(7,($31|0),(+$19))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         $$0 = $32;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z153UnityEngine_UnityEngine_Quaternion_m_op_Multiply_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_QuaternionP22mscorlib_System_Object34UnityEngine_UnityEngine_QuaternionS1_($agg$result,$__this,$lhs,$rhs) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2795152);
 $0 = (($lhs) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$rhs>>2]);
 $3 = Math_fround($1 * $2);
 $4 = Math_fround(HEAPF32[$lhs>>2]);
 $5 = (($rhs) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($3 + $7);
 $9 = (($lhs) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($rhs) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($lhs) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($rhs) + 4|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 - $19);
 $21 = Math_fround($1 * $18);
 $22 = Math_fround($6 * $10);
 $23 = Math_fround($22 + $21);
 $24 = Math_fround($2 * $16);
 $25 = Math_fround($24 + $23);
 $26 = Math_fround($4 * $12);
 $27 = Math_fround($25 - $26);
 $28 = Math_fround($1 * $12);
 $29 = Math_fround($6 * $16);
 $30 = Math_fround($28 + $29);
 $31 = Math_fround($4 * $18);
 $32 = Math_fround($30 + $31);
 $33 = Math_fround($2 * $10);
 $34 = Math_fround($32 - $33);
 $35 = Math_fround($1 * $6);
 $36 = Math_fround($2 * $4);
 $37 = Math_fround($35 - $36);
 $38 = Math_fround($10 * $18);
 $39 = Math_fround($37 - $38);
 $40 = Math_fround($12 * $16);
 $41 = Math_fround($39 - $40);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viffff(3,($agg$result|0),(+$20),(+$27),(+$34),(+$41));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($44|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z147UnityEngine_UnityEngine_Quaternion_m_op_Multiply_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object34UnityEngine_UnityEngine_Quaternion31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$rotation,$point) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $rotation = $rotation|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = Math_fround(0);
 var $45 = Math_fround(0), $46 = 0, $47 = Math_fround(0), $48 = Math_fround(0), $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = Math_fround(0), $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2795200);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = Math_fround(HEAPF32[$rotation>>2]);
 $5 = Math_fround($4 * Math_fround(2.0));
 $6 = (($rotation) + 4|0);
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = Math_fround($7 * Math_fround(2.0));
 $9 = (($rotation) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($10 * Math_fround(2.0));
 $12 = Math_fround($4 * $5);
 $13 = Math_fround($7 * $8);
 $14 = Math_fround($10 * $11);
 $15 = Math_fround($4 * $8);
 $16 = Math_fround($4 * $11);
 $17 = Math_fround($7 * $11);
 $18 = (($rotation) + 12|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($5 * $19);
 $21 = Math_fround($8 * $19);
 $22 = Math_fround($19 * $11);
 $23 = Math_fround($13 + $14);
 $24 = Math_fround(Math_fround(1.0) - $23);
 $25 = Math_fround(HEAPF32[$point>>2]);
 $26 = Math_fround($25 * $24);
 $27 = Math_fround($15 - $22);
 $28 = (($point) + 4|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($27 * $29);
 $31 = Math_fround($30 + $26);
 $32 = Math_fround($16 + $21);
 $33 = (($point) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($32 * $34);
 $36 = Math_fround($35 + $31);
 HEAPF32[$agg$result>>2] = $36;
 $37 = Math_fround($15 + $22);
 $38 = Math_fround($37 * $25);
 $39 = Math_fround($12 + $14);
 $40 = Math_fround(Math_fround(1.0) - $39);
 $41 = Math_fround($40 * $29);
 $42 = Math_fround($38 + $41);
 $43 = Math_fround($17 - $20);
 $44 = Math_fround($43 * $34);
 $45 = Math_fround($42 + $44);
 $46 = (($agg$result) + 4|0);
 HEAPF32[$46>>2] = $45;
 $47 = Math_fround($16 - $21);
 $48 = Math_fround($47 * $25);
 $49 = Math_fround($17 + $20);
 $50 = Math_fround($49 * $29);
 $51 = Math_fround($48 + $50);
 $52 = Math_fround($12 + $13);
 $53 = Math_fround(Math_fround(1.0) - $52);
 $54 = Math_fround($53 * $34);
 $55 = Math_fround($51 + $54);
 $56 = (($agg$result) + 8|0);
 HEAPF32[$56>>2] = $55;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __ZN12FuncInvoker2I40UnityEngine_UnityEngine_QuaternionTraits37UnityEngine_UnityEngine_Vector3TraitsS1_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPv31UnityEngine_UnityEngine_Vector3S5_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 44|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2796280,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I40UnityEngine_UnityEngine_QuaternionTraits17VoidPointerTraitsS1_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2796280,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker1I40UnityEngine_UnityEngine_QuaternionTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPF34UnityEngine_UnityEngine_QuaternionPv31UnityEngine_UnityEngine_Vector3ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2796280,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker1I40UnityEngine_UnityEngine_QuaternionTraitsS0_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvS2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2796280,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker3I40UnityEngine_UnityEngine_QuaternionTraits28mscorlib_System_SingleTraitsS1_S1_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvfffES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 FUNCTION_TABLE_viifff[$func & 3]($ret,$obj,$1,$4,$7);
 $8 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2796280,$ret)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector3Traits40UnityEngine_UnityEngine_QuaternionTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3Pv34UnityEngine_UnityEngine_QuaternionES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker2I40UnityEngine_UnityEngine_QuaternionTraitsS0_S0_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvS2_S2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2796280,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3Traits40UnityEngine_UnityEngine_QuaternionTraitsS0_E6InvokeEPF31UnityEngine_UnityEngine_Vector3Pv34UnityEngine_UnityEngine_QuaternionS3_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z65UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2791992)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_FromToRotationP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z182UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_LookRotation_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Vector3P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z129UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_LookRotationP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z124UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_InverseP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_Internal_ToEulerRadP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z138UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_Internal_FromEulerRadP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z36UnityEngine_UnityEngine_Rect_m__ctorP28UnityEngine_UnityEngine_Rectffff($__this,$left,$top,$width,$height) {
 $__this = $__this|0;
 $left = Math_fround($left);
 $top = Math_fround($top);
 $width = Math_fround($width);
 $height = Math_fround($height);
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796416);
 HEAPF32[$__this>>2] = $left;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $top;
 $1 = (($__this) + 8|0);
 HEAPF32[$1>>2] = $width;
 $2 = (($__this) + 12|0);
 HEAPF32[$2>>2] = $height;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z36UnityEngine_UnityEngine_Rect_m_get_xP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796464);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z36UnityEngine_UnityEngine_Rect_m_set_xP28UnityEngine_UnityEngine_Rectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796512);
 HEAPF32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z36UnityEngine_UnityEngine_Rect_m_get_yP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796560);
 $0 = (($__this) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z36UnityEngine_UnityEngine_Rect_m_set_yP28UnityEngine_UnityEngine_Rectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796608);
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z40UnityEngine_UnityEngine_Rect_m_get_widthP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796656);
 $0 = (($__this) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z40UnityEngine_UnityEngine_Rect_m_set_widthP28UnityEngine_UnityEngine_Rectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796704);
 $0 = (($__this) + 8|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z41UnityEngine_UnityEngine_Rect_m_get_heightP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796752);
 $0 = (($__this) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z41UnityEngine_UnityEngine_Rect_m_set_heightP28UnityEngine_UnityEngine_Rectf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796800);
 $0 = (($__this) + 12|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Rect_m_get_xMinP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796848);
 $0 = Math_fround(HEAPF32[$__this>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z39UnityEngine_UnityEngine_Rect_m_get_yMinP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796896);
 $0 = (($__this) + 4|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z39UnityEngine_UnityEngine_Rect_m_get_xMaxP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796944);
 $0 = (($__this) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = Math_fround(HEAPF32[$__this>>2]);
 $3 = Math_fround($1 + $2);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($3));
}
function __Z39UnityEngine_UnityEngine_Rect_m_get_yMaxP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2796992);
 $0 = (($__this) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($__this) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = Math_fround($1 + $3);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($4));
}
function __Z39UnityEngine_UnityEngine_Rect_m_ToStringP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = Math_fround(0), $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = Math_fround(0), $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_12 = 0, $L_18 = 0, $L_24 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_6 = sp;
 $L_12 = sp + 4|0;
 $L_18 = sp + 8|0;
 $L_24 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2797040);
 __THREW__ = 0;
 invoke_v(977);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),4)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (Math_fround(+(invoke_fi(138,($__this|0)))));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      HEAPF32[$L_6>>2] = $7;
      __THREW__ = 0;
      (invoke_ii(2996,(2194912|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       $12 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $15 = __THREW__; __THREW__ = 0;
        $16 = $15&1;
        if (!($16)) {
         $17 = (($4) + 12|0);
         $18 = HEAP32[$17>>2]|0;
         $19 = ($18|0)==(0);
         if ($19) {
          __THREW__ = 0;
          $20 = (invoke_i(132)|0);
          $21 = __THREW__; __THREW__ = 0;
          $22 = $21&1;
          if ($22) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($20|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if ($24) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($4|0),($12|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = (($4) + 16|0);
          HEAP32[$29>>2] = $12;
          __THREW__ = 0;
          $30 = (Math_fround(+(invoke_fi(139,($__this|0)))));
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           HEAPF32[$L_12>>2] = $30;
           __THREW__ = 0;
           (invoke_ii(2996,(2194912|0))|0);
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if (!($34)) {
            __THREW__ = 0;
            $35 = (invoke_iii(2724,(2194912|0),($L_12|0))|0);
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if (!($37)) {
             __THREW__ = 0;
             invoke_vi(3799,($4|0));
             $38 = __THREW__; __THREW__ = 0;
             $39 = $38&1;
             if (!($39)) {
              $40 = HEAP32[$17>>2]|0;
              $41 = ($40>>>0)<(2);
              if ($41) {
               __THREW__ = 0;
               $42 = (invoke_i(132)|0);
               $43 = __THREW__; __THREW__ = 0;
               $44 = $43&1;
               if ($44) {
                break;
               }
               __THREW__ = 0;
               invoke_vi(3302,($42|0));
               $45 = __THREW__; __THREW__ = 0;
               $46 = $45&1;
               if ($46) {
                break;
               }
              }
              __THREW__ = 0;
              invoke_vii(3492,($4|0),($35|0));
              $47 = __THREW__; __THREW__ = 0;
              $48 = $47&1;
              if (!($48)) {
               $49 = HEAP32[$4>>2]|0;
               $50 = (($49) + 92|0);
               $51 = HEAP32[$50>>2]|0;
               $52 = (($29) + ($51)|0);
               HEAP32[$52>>2] = $35;
               __THREW__ = 0;
               $53 = (Math_fround(+(invoke_fi(140,($__this|0)))));
               $54 = __THREW__; __THREW__ = 0;
               $55 = $54&1;
               if (!($55)) {
                HEAPF32[$L_18>>2] = $53;
                __THREW__ = 0;
                (invoke_ii(2996,(2194912|0))|0);
                $56 = __THREW__; __THREW__ = 0;
                $57 = $56&1;
                if (!($57)) {
                 __THREW__ = 0;
                 $58 = (invoke_iii(2724,(2194912|0),($L_18|0))|0);
                 $59 = __THREW__; __THREW__ = 0;
                 $60 = $59&1;
                 if (!($60)) {
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $61 = __THREW__; __THREW__ = 0;
                  $62 = $61&1;
                  if (!($62)) {
                   $63 = HEAP32[$17>>2]|0;
                   $64 = ($63>>>0)<(3);
                   if ($64) {
                    __THREW__ = 0;
                    $65 = (invoke_i(132)|0);
                    $66 = __THREW__; __THREW__ = 0;
                    $67 = $66&1;
                    if ($67) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($65|0));
                    $68 = __THREW__; __THREW__ = 0;
                    $69 = $68&1;
                    if ($69) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($4|0),($58|0));
                   $70 = __THREW__; __THREW__ = 0;
                   $71 = $70&1;
                   if ($71) {
                    break;
                   }
                   $72 = HEAP32[$4>>2]|0;
                   $73 = (($72) + 92|0);
                   $74 = HEAP32[$73>>2]|0;
                   $75 = $74 << 1;
                   $76 = (($29) + ($75)|0);
                   HEAP32[$76>>2] = $58;
                   __THREW__ = 0;
                   $77 = (Math_fround(+(invoke_fi(141,($__this|0)))));
                   $78 = __THREW__; __THREW__ = 0;
                   $79 = $78&1;
                   if ($79) {
                    break;
                   }
                   HEAPF32[$L_24>>2] = $77;
                   __THREW__ = 0;
                   (invoke_ii(2996,(2194912|0))|0);
                   $80 = __THREW__; __THREW__ = 0;
                   $81 = $80&1;
                   if ($81) {
                    break;
                   }
                   __THREW__ = 0;
                   $82 = (invoke_iii(2724,(2194912|0),($L_24|0))|0);
                   $83 = __THREW__; __THREW__ = 0;
                   $84 = $83&1;
                   if ($84) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3799,($4|0));
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   $87 = HEAP32[$17>>2]|0;
                   $88 = ($87>>>0)<(4);
                   if ($88) {
                    __THREW__ = 0;
                    $89 = (invoke_i(132)|0);
                    $90 = __THREW__; __THREW__ = 0;
                    $91 = $90&1;
                    if ($91) {
                     break;
                    }
                    __THREW__ = 0;
                    invoke_vi(3302,($89|0));
                    $92 = __THREW__; __THREW__ = 0;
                    $93 = $92&1;
                    if ($93) {
                     break;
                    }
                   }
                   __THREW__ = 0;
                   invoke_vii(3492,($4|0),($82|0));
                   $94 = __THREW__; __THREW__ = 0;
                   $95 = $94&1;
                   if ($95) {
                    break;
                   }
                   $96 = HEAP32[$4>>2]|0;
                   $97 = (($96) + 92|0);
                   $98 = HEAP32[$97>>2]|0;
                   $99 = ($98*3)|0;
                   $100 = (($29) + ($99)|0);
                   HEAP32[$100>>2] = $82;
                   $101 = HEAP32[3000544>>2]|0;
                   __THREW__ = 0;
                   $102 = (invoke_iiii(1417,0,($101|0),($4|0))|0);
                   $103 = __THREW__; __THREW__ = 0;
                   $104 = $103&1;
                   if ($104) {
                    break;
                   }
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($102|0);
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $25 = ___cxa_find_matching_catch()|0;
 $26 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($25|0);
 // unreachable;
 return 0|0;
}
function __Z39UnityEngine_UnityEngine_Rect_m_ContainsP28UnityEngine_UnityEngine_Rect31UnityEngine_UnityEngine_Vector3($__this,$point) {
 $__this = $__this|0;
 $point = $point|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0;
 var $9 = 0, $G_B5_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2797088);
 $0 = Math_fround(HEAPF32[$point>>2]);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(142,($__this|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = $0 < $1;
   if ($4) {
    $G_B5_0$0 = 0;
   } else {
    __THREW__ = 0;
    $7 = (Math_fround(+(invoke_fi(144,($__this|0)))));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = !($0 >= $7);
    if ($10) {
     $11 = (($point) + 4|0);
     $12 = Math_fround(HEAPF32[$11>>2]);
     __THREW__ = 0;
     $13 = (Math_fround(+(invoke_fi(143,($__this|0)))));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     $16 = $12 < $13;
     if ($16) {
      $G_B5_0$0 = 0;
     } else {
      __THREW__ = 0;
      $17 = (Math_fround(+(invoke_fi(145,($__this|0)))));
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       break;
      }
      $20 = $12 < $17;
      $G_B5_0$0 = $20;
     }
    } else {
     $G_B5_0$0 = 0;
    }
   }
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B5_0$0|0);
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42UnityEngine_UnityEngine_Rect_m_GetHashCodeP28UnityEngine_UnityEngine_Rect($__this) {
 $__this = $__this|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_0 = sp;
 $V_1 = sp + 4|0;
 $V_2 = sp + 8|0;
 $V_3 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2797136);
 HEAPF32[$V_0>>2] = Math_fround(0.0);
 HEAPF32[$V_1>>2] = Math_fround(0.0);
 HEAPF32[$V_2>>2] = Math_fround(0.0);
 HEAPF32[$V_3>>2] = Math_fround(0.0);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fi(138,($__this|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  HEAPF32[$V_0>>2] = $0;
  __THREW__ = 0;
  $3 = (invoke_ii(1819,($V_0|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (Math_fround(+(invoke_fi(140,($__this|0)))));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    HEAPF32[$V_1>>2] = $6;
    __THREW__ = 0;
    $9 = (invoke_ii(1819,($V_1|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = $9 << 2;
     $13 = $12 ^ $3;
     __THREW__ = 0;
     $14 = (Math_fround(+(invoke_fi(139,($__this|0)))));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if (!($16)) {
      HEAPF32[$V_2>>2] = $14;
      __THREW__ = 0;
      $17 = (invoke_ii(1819,($V_2|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       $20 = $17 >> 2;
       $21 = $13 ^ $20;
       __THREW__ = 0;
       $22 = (Math_fround(+(invoke_fi(141,($__this|0)))));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if (!($24)) {
        HEAPF32[$V_3>>2] = $22;
        __THREW__ = 0;
        $25 = (invoke_ii(1819,($V_3|0))|0);
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         $28 = $25 >> 1;
         $29 = $21 ^ $28;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($29|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $30 = ___cxa_find_matching_catch()|0;
 $31 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($30|0);
 // unreachable;
 return 0|0;
}
function __Z37UnityEngine_UnityEngine_Rect_m_EqualsP28UnityEngine_UnityEngine_RectP22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = Math_fround(0), $23 = 0, $24 = 0, $25 = Math_fround(0);
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = Math_fround(0), $41 = 0, $42 = 0, $43 = Math_fround(0);
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_0 = sp;
 $V_1 = sp + 16|0;
 $V_2 = sp + 20|0;
 $V_3 = sp + 24|0;
 $V_4 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2797184);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 HEAPF32[$V_1>>2] = Math_fround(0.0);
 HEAPF32[$V_2>>2] = Math_fround(0.0);
 HEAPF32[$V_3>>2] = Math_fround(0.0);
 HEAPF32[$V_4>>2] = Math_fround(0.0);
 __THREW__ = 0;
 (invoke_ii(2996,(2797856|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($other|0),(2797856|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2797856|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2776,($other|0),(2797856|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      ;HEAP32[$V_0+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$10+12>>2]|0;
      __THREW__ = 0;
      $13 = (Math_fround(+(invoke_fi(138,($__this|0)))));
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       HEAPF32[$V_1>>2] = $13;
       __THREW__ = 0;
       $16 = (Math_fround(+(invoke_fi(138,($V_0|0)))));
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        $19 = (invoke_iif(7,($V_1|0),(+$16))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         if (!($19)) {
          $$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($$0|0);
         }
         __THREW__ = 0;
         $22 = (Math_fround(+(invoke_fi(139,($__this|0)))));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          HEAPF32[$V_2>>2] = $22;
          __THREW__ = 0;
          $25 = (Math_fround(+(invoke_fi(139,($V_0|0)))));
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           $28 = (invoke_iif(7,($V_2|0),(+$25))|0);
           $29 = __THREW__; __THREW__ = 0;
           $30 = $29&1;
           if (!($30)) {
            if (!($28)) {
             $$0 = 0;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($$0|0);
            }
            __THREW__ = 0;
            $31 = (Math_fround(+(invoke_fi(140,($__this|0)))));
            $32 = __THREW__; __THREW__ = 0;
            $33 = $32&1;
            if (!($33)) {
             HEAPF32[$V_3>>2] = $31;
             __THREW__ = 0;
             $34 = (Math_fround(+(invoke_fi(140,($V_0|0)))));
             $35 = __THREW__; __THREW__ = 0;
             $36 = $35&1;
             if (!($36)) {
              __THREW__ = 0;
              $37 = (invoke_iif(7,($V_3|0),(+$34))|0);
              $38 = __THREW__; __THREW__ = 0;
              $39 = $38&1;
              if (!($39)) {
               if (!($37)) {
                $$0 = 0;
                __ZN16StackTraceSentryD2Ev(0);
                STACKTOP = sp;return ($$0|0);
               }
               __THREW__ = 0;
               $40 = (Math_fround(+(invoke_fi(141,($__this|0)))));
               $41 = __THREW__; __THREW__ = 0;
               $42 = $41&1;
               if (!($42)) {
                HEAPF32[$V_4>>2] = $40;
                __THREW__ = 0;
                $43 = (Math_fround(+(invoke_fi(141,($V_0|0)))));
                $44 = __THREW__; __THREW__ = 0;
                $45 = $44&1;
                if (!($45)) {
                 __THREW__ = 0;
                 $46 = (invoke_iif(7,($V_4|0),(+$43))|0);
                 $47 = __THREW__; __THREW__ = 0;
                 $48 = $47&1;
                 if ($48) {
                  break;
                 } else {
                  $$0 = $46;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFbPv31UnityEngine_UnityEngine_Vector3ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 12|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __Z111UnityEngine_UnityEngine_Matrix4x4_m_get_Item_mscorlib_System_Single_mscorlib_System_Int32_mscorlib_System_Int32P33UnityEngine_UnityEngine_Matrix4x4ii($__this,$row,$column) {
 $__this = $__this|0;
 $row = $row|0;
 $column = $column|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2797992);
 $0 = $column << 2;
 $1 = (($0) + ($row))|0;
 __THREW__ = 0;
 $2 = (Math_fround(+(invoke_fii(38,($__this|0),($1|0)))));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($2));
 }
 return Math_fround(0);
}
function __Z89UnityEngine_UnityEngine_Matrix4x4_m_get_Item_mscorlib_System_Single_mscorlib_System_Int32P33UnityEngine_UnityEngine_Matrix4x4i($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$0 = Math_fround(0), $$0$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798088);
 __THREW__ = 0;
 invoke_v(978);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   do {
    switch ($index|0) {
    case 10:  {
     $13 = (($__this) + 40|0);
     $$0$in = $13;
     break;
    }
    case 9:  {
     $12 = (($__this) + 36|0);
     $$0$in = $12;
     break;
    }
    case 14:  {
     $17 = (($__this) + 56|0);
     $$0$in = $17;
     break;
    }
    case 5:  {
     $8 = (($__this) + 20|0);
     $$0$in = $8;
     break;
    }
    case 0:  {
     $$0$in = $__this;
     break;
    }
    case 12:  {
     $15 = (($__this) + 48|0);
     $$0$in = $15;
     break;
    }
    case 15:  {
     $18 = (($__this) + 60|0);
     $$0$in = $18;
     break;
    }
    case 11:  {
     $14 = (($__this) + 44|0);
     $$0$in = $14;
     break;
    }
    case 13:  {
     $16 = (($__this) + 52|0);
     $$0$in = $16;
     break;
    }
    case 3:  {
     $6 = (($__this) + 12|0);
     $$0$in = $6;
     break;
    }
    case 1:  {
     $4 = (($__this) + 4|0);
     $$0$in = $4;
     break;
    }
    case 2:  {
     $5 = (($__this) + 8|0);
     $$0$in = $5;
     break;
    }
    case 7:  {
     $10 = (($__this) + 28|0);
     $$0$in = $10;
     break;
    }
    case 8:  {
     $11 = (($__this) + 32|0);
     $$0$in = $11;
     break;
    }
    case 4:  {
     $7 = (($__this) + 16|0);
     $$0$in = $7;
     break;
    }
    case 6:  {
     $9 = (($__this) + 24|0);
     $$0$in = $9;
     break;
    }
    default: {
     __THREW__ = 0;
     (invoke_ii(2996,(2606944|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break L1;
     }
     __THREW__ = 0;
     $21 = (invoke_ii(3469,(2606944|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break L1;
     }
     $24 = HEAP32[3000664>>2]|0;
     __THREW__ = 0;
     invoke_vii(1945,($21|0),($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3846,($21|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break L1;
     }
     // unreachable;
    }
    }
   } while(0);
   $$0 = Math_fround(HEAPF32[$$0$in>>2]);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($$0));
  }
 } while(0);
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($2|0);
 // unreachable;
 return Math_fround(0);
}
function __Z132UnityEngine_UnityEngine_Matrix4x4_m_set_Item_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_SingleP33UnityEngine_UnityEngine_Matrix4x4iif($__this,$row,$column,$value) {
 $__this = $__this|0;
 $row = $row|0;
 $column = $column|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798040);
 $0 = $column << 2;
 $1 = (($0) + ($row))|0;
 __THREW__ = 0;
 invoke_viif(25,($__this|0),($1|0),(+$value));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z110UnityEngine_UnityEngine_Matrix4x4_m_set_Item_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_SingleP33UnityEngine_UnityEngine_Matrix4x4if($__this,$index,$value) {
 $__this = $__this|0;
 $index = $index|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798136);
 __THREW__ = 0;
 invoke_v(979);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   do {
    switch ($index|0) {
    case 7:  {
     $10 = (($__this) + 28|0);
     HEAPF32[$10>>2] = $value;
     break;
    }
    case 6:  {
     $9 = (($__this) + 24|0);
     HEAPF32[$9>>2] = $value;
     break;
    }
    case 4:  {
     $7 = (($__this) + 16|0);
     HEAPF32[$7>>2] = $value;
     break;
    }
    case 13:  {
     $16 = (($__this) + 52|0);
     HEAPF32[$16>>2] = $value;
     break;
    }
    case 1:  {
     $4 = (($__this) + 4|0);
     HEAPF32[$4>>2] = $value;
     break;
    }
    case 0:  {
     HEAPF32[$__this>>2] = $value;
     break;
    }
    case 8:  {
     $11 = (($__this) + 32|0);
     HEAPF32[$11>>2] = $value;
     break;
    }
    case 10:  {
     $13 = (($__this) + 40|0);
     HEAPF32[$13>>2] = $value;
     break;
    }
    case 12:  {
     $15 = (($__this) + 48|0);
     HEAPF32[$15>>2] = $value;
     break;
    }
    case 15:  {
     $18 = (($__this) + 60|0);
     HEAPF32[$18>>2] = $value;
     break;
    }
    case 5:  {
     $8 = (($__this) + 20|0);
     HEAPF32[$8>>2] = $value;
     break;
    }
    case 9:  {
     $12 = (($__this) + 36|0);
     HEAPF32[$12>>2] = $value;
     break;
    }
    case 2:  {
     $5 = (($__this) + 8|0);
     HEAPF32[$5>>2] = $value;
     break;
    }
    case 11:  {
     $14 = (($__this) + 44|0);
     HEAPF32[$14>>2] = $value;
     break;
    }
    case 14:  {
     $17 = (($__this) + 56|0);
     HEAPF32[$17>>2] = $value;
     break;
    }
    case 3:  {
     $6 = (($__this) + 12|0);
     HEAPF32[$6>>2] = $value;
     break;
    }
    default: {
     __THREW__ = 0;
     (invoke_ii(2996,(2606944|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break L1;
     }
     __THREW__ = 0;
     $21 = (invoke_ii(3469,(2606944|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break L1;
     }
     $24 = HEAP32[3000728>>2]|0;
     __THREW__ = 0;
     invoke_vii(1945,($21|0),($24|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break L1;
     }
     __THREW__ = 0;
     invoke_vi(3846,($21|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break L1;
     }
     // unreachable;
    }
    }
   } while(0);
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 } while(0);
 $2 = ___cxa_find_matching_catch()|0;
 $3 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($2|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception11973($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_Matrix4x4_m_GetHashCodeP33UnityEngine_UnityEngine_Matrix4x4($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_10 = 0, $L_16 = 0, $L_4 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $_stackTraceSentry = sp + 128|0;
 $V_0 = sp + 112|0;
 $V_1 = sp + 96|0;
 $V_2 = sp + 80|0;
 $V_3 = sp + 64|0;
 $L_1 = sp + 32|0;
 $L_4 = sp + 16|0;
 $L_10 = sp;
 $L_16 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798184);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;HEAP32[$V_3+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(753,($L_1|0),($__this|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$V_0+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_1+12>>2]|0;
  __THREW__ = 0;
  $2 = (invoke_ii(2624,($V_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viii(753,($L_4|0),($__this|0),1);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    ;HEAP32[$V_1+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_4+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_4+12>>2]|0;
    __THREW__ = 0;
    $7 = (invoke_ii(2624,($V_1|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = $7 << 2;
     $11 = $10 ^ $2;
     __THREW__ = 0;
     invoke_viii(753,($L_10|0),($__this|0),2);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      ;HEAP32[$V_2+0>>2]=HEAP32[$L_10+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_10+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_10+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_10+12>>2]|0;
      __THREW__ = 0;
      $14 = (invoke_ii(2624,($V_2|0))|0);
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       $17 = $14 >> 2;
       $18 = $11 ^ $17;
       __THREW__ = 0;
       invoke_viii(753,($L_16|0),($__this|0),3);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        ;HEAP32[$V_3+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_16+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[$L_16+12>>2]|0;
        __THREW__ = 0;
        $21 = (invoke_ii(2624,($V_3|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         $24 = $21 >> 1;
         $25 = $18 ^ $24;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($25|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($26|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_Matrix4x4_m_GetColumnP33UnityEngine_UnityEngine_Matrix4x4i($agg$result,$__this,$i) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $i = $i|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799024);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fiii(10,($__this|0),0,($i|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fiii(10,($__this|0),1,($i|0)))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (Math_fround(+(invoke_fiii(10,($__this|0),2,($i|0)))));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (Math_fround(+(invoke_fiii(10,($__this|0),3,($i|0)))));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
     __THREW__ = 0;
     invoke_viffff(5,($agg$result|0),(+$0),(+$3),(+$6),(+$9));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_Matrix4x4_m_EqualsP33UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $L_12 = 0, $L_14 = 0, $L_15 = 0, $L_19 = 0, $L_21 = 0, $L_22 = 0, $L_26 = 0, $L_28 = 0, $L_29 = 0, $L_5 = 0, $L_7 = 0, $L_8 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $V_3 = 0, $V_4 = 0, $_stackTraceSentry = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $_stackTraceSentry = sp + 320|0;
 $V_0 = sp + 256|0;
 $V_1 = sp + 240|0;
 $V_2 = sp + 224|0;
 $V_3 = sp + 208|0;
 $V_4 = sp + 192|0;
 $L_5 = sp + 176|0;
 $L_7 = sp + 160|0;
 $L_8 = sp + 144|0;
 $L_12 = sp + 128|0;
 $L_14 = sp + 96|0;
 $L_15 = sp + 80|0;
 $L_19 = sp + 64|0;
 $L_21 = sp + 48|0;
 $L_22 = sp + 32|0;
 $L_26 = sp + 16|0;
 $L_28 = sp;
 $L_29 = sp + 112|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798232);
 dest=$V_0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;HEAP32[$V_1+12>>2]=0|0;
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;
 ;HEAP32[$V_3+0>>2]=0|0;HEAP32[$V_3+4>>2]=0|0;HEAP32[$V_3+8>>2]=0|0;HEAP32[$V_3+12>>2]=0|0;
 ;HEAP32[$V_4+0>>2]=0|0;HEAP32[$V_4+4>>2]=0|0;HEAP32[$V_4+8>>2]=0|0;HEAP32[$V_4+12>>2]=0|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2802392|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2735,($other|0),(2802392|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)==(0|0);
    if ($5) {
     $$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($$0|0);
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2802392|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     $10 = (invoke_iii(2776,($other|0),(2802392|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      dest=$V_0+0|0; src=$10+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      __THREW__ = 0;
      invoke_viii(753,($L_5|0),($__this|0),0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       ;HEAP32[$V_1+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$V_1+12>>2]=HEAP32[$L_5+12>>2]|0;
       __THREW__ = 0;
       invoke_viii(753,($L_7|0),($V_0|0),0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        ;HEAP32[$L_8+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$L_8+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$L_8+8>>2]=HEAP32[$L_7+8>>2]|0;HEAP32[$L_8+12>>2]=HEAP32[$L_7+12>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2807040|0))|0);
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        if (!($18)) {
         __THREW__ = 0;
         $19 = (invoke_iii(2724,(2807040|0),($L_8|0))|0);
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if (!($21)) {
          __THREW__ = 0;
          $22 = (invoke_iii(1227,($V_1|0),($19|0))|0);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           if (!($22)) {
            $$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($$0|0);
           }
           __THREW__ = 0;
           invoke_viii(753,($L_12|0),($__this|0),1);
           $25 = __THREW__; __THREW__ = 0;
           $26 = $25&1;
           if (!($26)) {
            ;HEAP32[$V_2+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_12+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_12+12>>2]|0;
            __THREW__ = 0;
            invoke_viii(753,($L_14|0),($V_0|0),1);
            $27 = __THREW__; __THREW__ = 0;
            $28 = $27&1;
            if (!($28)) {
             ;HEAP32[$L_15+0>>2]=HEAP32[$L_14+0>>2]|0;HEAP32[$L_15+4>>2]=HEAP32[$L_14+4>>2]|0;HEAP32[$L_15+8>>2]=HEAP32[$L_14+8>>2]|0;HEAP32[$L_15+12>>2]=HEAP32[$L_14+12>>2]|0;
             __THREW__ = 0;
             (invoke_ii(2996,(2807040|0))|0);
             $29 = __THREW__; __THREW__ = 0;
             $30 = $29&1;
             if (!($30)) {
              __THREW__ = 0;
              $31 = (invoke_iii(2724,(2807040|0),($L_15|0))|0);
              $32 = __THREW__; __THREW__ = 0;
              $33 = $32&1;
              if (!($33)) {
               __THREW__ = 0;
               $34 = (invoke_iii(1227,($V_2|0),($31|0))|0);
               $35 = __THREW__; __THREW__ = 0;
               $36 = $35&1;
               if (!($36)) {
                if (!($34)) {
                 $$0 = 0;
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($$0|0);
                }
                __THREW__ = 0;
                invoke_viii(753,($L_19|0),($__this|0),2);
                $37 = __THREW__; __THREW__ = 0;
                $38 = $37&1;
                if (!($38)) {
                 ;HEAP32[$V_3+0>>2]=HEAP32[$L_19+0>>2]|0;HEAP32[$V_3+4>>2]=HEAP32[$L_19+4>>2]|0;HEAP32[$V_3+8>>2]=HEAP32[$L_19+8>>2]|0;HEAP32[$V_3+12>>2]=HEAP32[$L_19+12>>2]|0;
                 __THREW__ = 0;
                 invoke_viii(753,($L_21|0),($V_0|0),2);
                 $39 = __THREW__; __THREW__ = 0;
                 $40 = $39&1;
                 if (!($40)) {
                  ;HEAP32[$L_22+0>>2]=HEAP32[$L_21+0>>2]|0;HEAP32[$L_22+4>>2]=HEAP32[$L_21+4>>2]|0;HEAP32[$L_22+8>>2]=HEAP32[$L_21+8>>2]|0;HEAP32[$L_22+12>>2]=HEAP32[$L_21+12>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2807040|0))|0);
                  $41 = __THREW__; __THREW__ = 0;
                  $42 = $41&1;
                  if ($42) {
                   break;
                  }
                  __THREW__ = 0;
                  $43 = (invoke_iii(2724,(2807040|0),($L_22|0))|0);
                  $44 = __THREW__; __THREW__ = 0;
                  $45 = $44&1;
                  if ($45) {
                   break;
                  }
                  __THREW__ = 0;
                  $46 = (invoke_iii(1227,($V_3|0),($43|0))|0);
                  $47 = __THREW__; __THREW__ = 0;
                  $48 = $47&1;
                  if ($48) {
                   break;
                  }
                  if (!($46)) {
                   $$0 = 0;
                   __ZN16StackTraceSentryD2Ev(0);
                   STACKTOP = sp;return ($$0|0);
                  }
                  __THREW__ = 0;
                  invoke_viii(753,($L_26|0),($__this|0),3);
                  $49 = __THREW__; __THREW__ = 0;
                  $50 = $49&1;
                  if ($50) {
                   break;
                  }
                  ;HEAP32[$V_4+0>>2]=HEAP32[$L_26+0>>2]|0;HEAP32[$V_4+4>>2]=HEAP32[$L_26+4>>2]|0;HEAP32[$V_4+8>>2]=HEAP32[$L_26+8>>2]|0;HEAP32[$V_4+12>>2]=HEAP32[$L_26+12>>2]|0;
                  __THREW__ = 0;
                  invoke_viii(753,($L_28|0),($V_0|0),3);
                  $51 = __THREW__; __THREW__ = 0;
                  $52 = $51&1;
                  if ($52) {
                   break;
                  }
                  ;HEAP32[$L_29+0>>2]=HEAP32[$L_28+0>>2]|0;HEAP32[$L_29+4>>2]=HEAP32[$L_28+4>>2]|0;HEAP32[$L_29+8>>2]=HEAP32[$L_28+8>>2]|0;HEAP32[$L_29+12>>2]=HEAP32[$L_28+12>>2]|0;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2807040|0))|0);
                  $53 = __THREW__; __THREW__ = 0;
                  $54 = $53&1;
                  if ($54) {
                   break;
                  }
                  __THREW__ = 0;
                  $55 = (invoke_iii(2724,(2807040|0),($L_29|0))|0);
                  $56 = __THREW__; __THREW__ = 0;
                  $57 = $56&1;
                  if ($57) {
                   break;
                  }
                  __THREW__ = 0;
                  $58 = (invoke_iii(1227,($V_4|0),($55|0))|0);
                  $59 = __THREW__; __THREW__ = 0;
                  $60 = $59&1;
                  if ($60) {
                   break;
                  } else {
                   $$0 = $58;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($$0|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z40UnityEngine_UnityEngine_Vector4_m_EqualsP31UnityEngine_UnityEngine_Vector4P22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = Math_fround(0), $16 = 0, $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2806392);
 __THREW__ = 0;
 (invoke_ii(2996,(2807040|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($other|0),(2807040|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2807040|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2776,($other|0),(2807040|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = Math_fround(HEAPF32[$10>>2]);
     $14 = (($10) + 4|0);
     $15 = Math_fround(HEAPF32[$14>>2]);
     $16 = (($10) + 8|0);
     $17 = Math_fround(HEAPF32[$16>>2]);
     $18 = (($10) + 12|0);
     $19 = Math_fround(HEAPF32[$18>>2]);
     __THREW__ = 0;
     $20 = (invoke_iif(7,($__this|0),(+$13))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      if (!($20)) {
       $$0 = 0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $23 = (($__this) + 4|0);
      __THREW__ = 0;
      $24 = (invoke_iif(7,($23|0),(+$15))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       if (!($24)) {
        $$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
       $27 = (($__this) + 8|0);
       __THREW__ = 0;
       $28 = (invoke_iif(7,($27|0),(+$17))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        if (!($28)) {
         $$0 = 0;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
        $31 = (($__this) + 12|0);
        __THREW__ = 0;
        $32 = (invoke_iif(7,($31|0),(+$19))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if (!($34)) {
         $$0 = $32;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Matrix4x4_m_InverseP22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4($agg$result,$__this,$m) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $m = $m|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798280);
 __THREW__ = 0;
 invoke_viii(750,($agg$result|0),0,($m|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_InverseP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_Matrix4x4($agg$result,$__this,$m) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $m = $m|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798328);
 $0 = HEAP32[2798376>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2798384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2798376>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($agg$result|0),($m|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_Matrix4x4_m_TransposeP22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4($agg$result,$__this,$m) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $m = $m|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798456);
 __THREW__ = 0;
 invoke_viii(752,($agg$result|0),0,($m|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z59UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_TransposeP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_Matrix4x4($agg$result,$__this,$m) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $m = $m|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798504);
 $0 = HEAP32[2798552>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2798560|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2798552>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($agg$result|0),($m|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_Matrix4x4_m_InvertP22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4PS1_($__this,$inMatrix,$dest) {
 $__this = $__this|0;
 $inMatrix = $inMatrix|0;
 $dest = $dest|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798632);
 __THREW__ = 0;
 $0 = (invoke_iiii(1372,0,($inMatrix|0),($dest|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z56UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_InvertP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_Matrix4x4S2_($__this,$inMatrix,$dest) {
 $__this = $__this|0;
 $inMatrix = $inMatrix|0;
 $dest = $dest|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798680);
 $0 = HEAP32[2798728>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2798736|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2798728>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($inMatrix|0),($dest|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z47UnityEngine_UnityEngine_Matrix4x4_m_get_inverseP33UnityEngine_UnityEngine_Matrix4x4($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798832);
 __THREW__ = 0;
 dest=$__this$byval_copy+0|0; src=$__this+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 invoke_viii(749,($agg$result|0),0,($__this$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z49UnityEngine_UnityEngine_Matrix4x4_m_get_transposeP33UnityEngine_UnityEngine_Matrix4x4($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $__this$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798880);
 __THREW__ = 0;
 dest=$__this$byval_copy+0|0; src=$__this+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 invoke_viii(751,($agg$result|0),0,($__this$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_Matrix4x4_m_get_isIdentityP33UnityEngine_UnityEngine_Matrix4x4($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2798928);
 $0 = HEAP32[2798976>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2798984|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2798976>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42UnityEngine_UnityEngine_Matrix4x4_m_GetRowP33UnityEngine_UnityEngine_Matrix4x4i($agg$result,$__this,$i) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $i = $i|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799072);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fiii(10,($__this|0),($i|0),0))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fiii(10,($__this|0),($i|0),1))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (Math_fround(+(invoke_fiii(10,($__this|0),($i|0),2))));
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (Math_fround(+(invoke_fiii(10,($__this|0),($i|0),3))));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
     __THREW__ = 0;
     invoke_viffff(5,($agg$result|0),(+$0),(+$3),(+$6),(+$9));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_Matrix4x4_m_SetColumnP33UnityEngine_UnityEngine_Matrix4x4i31UnityEngine_UnityEngine_Vector4($__this,$i,$v) {
 $__this = $__this|0;
 $i = $i|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799120);
 $0 = Math_fround(HEAPF32[$v>>2]);
 __THREW__ = 0;
 invoke_viiif(4,($__this|0),0,($i|0),(+$0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($v) + 4|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  __THREW__ = 0;
  invoke_viiif(4,($__this|0),1,($i|0),(+$4));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($v) + 8|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   __THREW__ = 0;
   invoke_viiif(4,($__this|0),2,($i|0),(+$8));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($v) + 12|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    __THREW__ = 0;
    invoke_viiif(4,($__this|0),3,($i|0),(+$12));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_Matrix4x4_m_SetRowP33UnityEngine_UnityEngine_Matrix4x4i31UnityEngine_UnityEngine_Vector4($__this,$i,$v) {
 $__this = $__this|0;
 $i = $i|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799168);
 $0 = Math_fround(HEAPF32[$v>>2]);
 __THREW__ = 0;
 invoke_viiif(4,($__this|0),($i|0),0,(+$0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($v) + 4|0);
  $4 = Math_fround(HEAPF32[$3>>2]);
  __THREW__ = 0;
  invoke_viiif(4,($__this|0),($i|0),1,(+$4));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = (($v) + 8|0);
   $8 = Math_fround(HEAPF32[$7>>2]);
   __THREW__ = 0;
   invoke_viiif(4,($__this|0),($i|0),2,(+$8));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = (($v) + 12|0);
    $12 = Math_fround(HEAPF32[$11>>2]);
    __THREW__ = 0;
    invoke_viiif(4,($__this|0),($i|0),3,(+$12));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $15 = ___cxa_find_matching_catch()|0;
 $16 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($15|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_Matrix4x4_m_MultiplyPointP33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector3($agg$result,$__this,$v) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = 0, $52 = Math_fround(0), $53 = Math_fround(0), $54 = Math_fround(0), $55 = 0, $56 = Math_fround(0), $57 = Math_fround(0), $58 = Math_fround(0), $59 = 0, $6 = Math_fround(0), $60 = Math_fround(0), $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = Math_fround(0), $65 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799216);
 HEAP32[$agg$result>>2] = 0;
 $0 = Math_fround(HEAPF32[$__this>>2]);
 $1 = Math_fround(HEAPF32[$v>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($__this) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($v) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($__this) + 32|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($v) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($__this) + 48|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($16 + $14);
 $18 = (($__this) + 4|0);
 $19 = Math_fround(HEAPF32[$18>>2]);
 $20 = Math_fround($19 * $1);
 $21 = (($__this) + 20|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $6);
 $24 = Math_fround($20 + $23);
 $25 = (($__this) + 36|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $12);
 $28 = Math_fround($24 + $27);
 $29 = (($__this) + 52|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 + $28);
 $32 = (($agg$result) + 4|0);
 $33 = (($__this) + 8|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 * $1);
 $36 = (($__this) + 24|0);
 $37 = Math_fround(HEAPF32[$36>>2]);
 $38 = Math_fround($37 * $6);
 $39 = Math_fround($35 + $38);
 $40 = (($__this) + 40|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 * $12);
 $43 = Math_fround($39 + $42);
 $44 = (($__this) + 56|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 + $43);
 $47 = (($agg$result) + 8|0);
 $48 = (($__this) + 12|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * $1);
 $51 = (($__this) + 28|0);
 $52 = Math_fround(HEAPF32[$51>>2]);
 $53 = Math_fround($52 * $6);
 $54 = Math_fround($50 + $53);
 $55 = (($__this) + 44|0);
 $56 = Math_fround(HEAPF32[$55>>2]);
 $57 = Math_fround($56 * $12);
 $58 = Math_fround($54 + $57);
 $59 = (($__this) + 60|0);
 $60 = Math_fround(HEAPF32[$59>>2]);
 $61 = Math_fround($60 + $58);
 $62 = Math_fround(Math_fround(1.0) / $61);
 $63 = Math_fround($62 * $17);
 HEAPF32[$agg$result>>2] = $63;
 $64 = Math_fround($62 * $31);
 HEAPF32[$32>>2] = $64;
 $65 = Math_fround($62 * $46);
 HEAPF32[$47>>2] = $65;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z52UnityEngine_UnityEngine_Matrix4x4_m_MultiplyPoint3x4P33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector3($agg$result,$__this,$v) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = 0, $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = Math_fround(0), $33 = 0, $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $6 = Math_fround(0), $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799264);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = Math_fround(HEAPF32[$__this>>2]);
 $5 = Math_fround(HEAPF32[$v>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($__this) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($v) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = Math_fround($6 + $11);
 $13 = (($__this) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($v) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = Math_fround($12 + $17);
 $19 = (($__this) + 48|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 + $18);
 HEAPF32[$agg$result>>2] = $21;
 $22 = (($__this) + 4|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $5);
 $25 = (($__this) + 20|0);
 $26 = Math_fround(HEAPF32[$25>>2]);
 $27 = Math_fround($26 * $10);
 $28 = Math_fround($24 + $27);
 $29 = (($__this) + 36|0);
 $30 = Math_fround(HEAPF32[$29>>2]);
 $31 = Math_fround($30 * $16);
 $32 = Math_fround($28 + $31);
 $33 = (($__this) + 52|0);
 $34 = Math_fround(HEAPF32[$33>>2]);
 $35 = Math_fround($34 + $32);
 $36 = (($agg$result) + 4|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($__this) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($38 * $5);
 $40 = (($__this) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 * $10);
 $43 = Math_fround($39 + $42);
 $44 = (($__this) + 40|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 * $16);
 $47 = Math_fround($43 + $46);
 $48 = (($__this) + 56|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 + $47);
 $51 = (($agg$result) + 8|0);
 HEAPF32[$51>>2] = $50;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z50UnityEngine_UnityEngine_Matrix4x4_m_MultiplyVectorP33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector3($agg$result,$__this,$v) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = Math_fround(0), $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = Math_fround(0), $34 = 0, $35 = Math_fround(0), $36 = Math_fround(0), $37 = Math_fround(0), $38 = 0, $39 = Math_fround(0), $4 = Math_fround(0), $40 = Math_fround(0), $41 = Math_fround(0), $42 = 0, $5 = Math_fround(0), $6 = Math_fround(0);
 var $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799312);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = Math_fround(HEAPF32[$__this>>2]);
 $5 = Math_fround(HEAPF32[$v>>2]);
 $6 = Math_fround($4 * $5);
 $7 = (($__this) + 16|0);
 $8 = Math_fround(HEAPF32[$7>>2]);
 $9 = (($v) + 4|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = Math_fround($8 * $10);
 $12 = Math_fround($6 + $11);
 $13 = (($__this) + 32|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($v) + 8|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 * $16);
 $18 = Math_fround($12 + $17);
 HEAPF32[$agg$result>>2] = $18;
 $19 = (($__this) + 4|0);
 $20 = Math_fround(HEAPF32[$19>>2]);
 $21 = Math_fround($20 * $5);
 $22 = (($__this) + 20|0);
 $23 = Math_fround(HEAPF32[$22>>2]);
 $24 = Math_fround($23 * $10);
 $25 = Math_fround($21 + $24);
 $26 = (($__this) + 36|0);
 $27 = Math_fround(HEAPF32[$26>>2]);
 $28 = Math_fround($27 * $16);
 $29 = Math_fround($25 + $28);
 $30 = (($agg$result) + 4|0);
 HEAPF32[$30>>2] = $29;
 $31 = (($__this) + 8|0);
 $32 = Math_fround(HEAPF32[$31>>2]);
 $33 = Math_fround($32 * $5);
 $34 = (($__this) + 24|0);
 $35 = Math_fround(HEAPF32[$34>>2]);
 $36 = Math_fround($35 * $10);
 $37 = Math_fround($33 + $36);
 $38 = (($__this) + 40|0);
 $39 = Math_fround(HEAPF32[$38>>2]);
 $40 = Math_fround($39 * $16);
 $41 = Math_fround($37 + $40);
 $42 = (($agg$result) + 8|0);
 HEAPF32[$42>>2] = $41;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z41UnityEngine_UnityEngine_Matrix4x4_m_ScaleP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$v) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799360);
 dest=$agg$result+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = Math_fround(HEAPF32[$v>>2]);
 HEAPF32[$agg$result>>2] = $0;
 $1 = (($agg$result) + 16|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($agg$result) + 32|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($agg$result) + 48|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($agg$result) + 4|0);
 HEAPF32[$4>>2] = Math_fround(0.0);
 $5 = (($v) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = (($agg$result) + 20|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($agg$result) + 36|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($agg$result) + 52|0);
 HEAPF32[$9>>2] = Math_fround(0.0);
 $10 = (($agg$result) + 8|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($agg$result) + 24|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($v) + 8|0);
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($agg$result) + 40|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($agg$result) + 56|0);
 HEAPF32[$15>>2] = Math_fround(0.0);
 $16 = (($agg$result) + 12|0);
 HEAPF32[$16>>2] = Math_fround(0.0);
 $17 = (($agg$result) + 28|0);
 HEAPF32[$17>>2] = Math_fround(0.0);
 $18 = (($agg$result) + 44|0);
 HEAPF32[$18>>2] = Math_fround(0.0);
 $19 = (($agg$result) + 60|0);
 HEAPF32[$19>>2] = Math_fround(1.0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z44UnityEngine_UnityEngine_Matrix4x4_m_get_zeroP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799408);
 dest=$agg$result+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_Matrix4x4_m_get_identityP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799456);
 dest=$agg$result+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAPF32[$agg$result>>2] = Math_fround(1.0);
 $0 = (($agg$result) + 16|0);
 HEAPF32[$0>>2] = Math_fround(0.0);
 $1 = (($agg$result) + 32|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($agg$result) + 48|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 $3 = (($agg$result) + 4|0);
 HEAPF32[$3>>2] = Math_fround(0.0);
 $4 = (($agg$result) + 20|0);
 HEAPF32[$4>>2] = Math_fround(1.0);
 $5 = (($agg$result) + 36|0);
 HEAPF32[$5>>2] = Math_fround(0.0);
 $6 = (($agg$result) + 52|0);
 HEAPF32[$6>>2] = Math_fround(0.0);
 $7 = (($agg$result) + 8|0);
 HEAPF32[$7>>2] = Math_fround(0.0);
 $8 = (($agg$result) + 24|0);
 HEAPF32[$8>>2] = Math_fround(0.0);
 $9 = (($agg$result) + 40|0);
 HEAPF32[$9>>2] = Math_fround(1.0);
 $10 = (($agg$result) + 56|0);
 HEAPF32[$10>>2] = Math_fround(0.0);
 $11 = (($agg$result) + 12|0);
 HEAPF32[$11>>2] = Math_fround(0.0);
 $12 = (($agg$result) + 28|0);
 HEAPF32[$12>>2] = Math_fround(0.0);
 $13 = (($agg$result) + 44|0);
 HEAPF32[$13>>2] = Math_fround(0.0);
 $14 = (($agg$result) + 60|0);
 HEAPF32[$14>>2] = Math_fround(1.0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z42UnityEngine_UnityEngine_Matrix4x4_m_SetTRSP33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector334UnityEngine_UnityEngine_QuaternionS1_($__this,$pos,$q,$s) {
 $__this = $__this|0;
 $pos = $pos|0;
 $q = $q|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $_stackTraceSentry = 0, $_stackTraceSentry$i = 0, $eh$lpad$body$index2Z2D = 0, $eh$lpad$body$indexZ2D = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $_stackTraceSentry$i = sp + 112|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = sp + 32|0;
 $_stackTraceSentry = sp + 44|0;
 $L_0 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799504);
 ;HEAP32[$2+0>>2]=HEAP32[$pos+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$pos+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$pos+8>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$q+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$q+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$q+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$q+12>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$s+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$s+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$s+8>>2]|0;
 __THREW__ = 0;
 invoke_vii(3500,($_stackTraceSentry$i|0),(2799552|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $eh$lpad$body$index2Z2D = $10;$eh$lpad$body$indexZ2D = $9;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($eh$lpad$body$indexZ2D|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_viiiii(79,($L_0|0),0,($2|0),($1|0),($0|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZN16StackTraceSentryD2Ev(0);
  dest=$__this+0|0; src=$L_0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 $eh$lpad$body$index2Z2D = $8;$eh$lpad$body$indexZ2D = $7;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($eh$lpad$body$indexZ2D|0);
 // unreachable;
}
function __Z39UnityEngine_UnityEngine_Matrix4x4_m_TRSP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector334UnityEngine_UnityEngine_QuaternionS1_($agg$result,$__this,$pos,$q,$s) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $pos = $pos|0;
 $q = $q|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799552);
 __THREW__ = 0;
 invoke_viiiii(79,($agg$result|0),0,($pos|0),($q|0),($s|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_TRSP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3P34UnityEngine_UnityEngine_QuaternionS2_($agg$result,$__this,$pos,$q,$s) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $pos = $pos|0;
 $q = $q|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799600);
 $0 = HEAP32[2799648>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2799656|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2799648>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiii($7|0,($agg$result|0),($pos|0),($q|0),($s|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z67UnityEngine_UnityEngine_Matrix4x4_m_ToString_mscorlib_System_StringP33UnityEngine_UnityEngine_Matrix4x4($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = Math_fround(0), $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = Math_fround(0), $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = Math_fround(0), $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = Math_fround(0), $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = Math_fround(0), $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = Math_fround(0), $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = Math_fround(0), $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = Math_fround(0), $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = Math_fround(0), $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = Math_fround(0), $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = Math_fround(0), $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = Math_fround(0), $98 = 0, $99 = 0, $L_12 = 0, $L_18 = 0, $L_24 = 0, $L_30 = 0;
 var $L_36 = 0, $L_42 = 0, $L_48 = 0, $L_54 = 0, $L_6 = 0, $L_60 = 0, $L_66 = 0, $L_72 = 0, $L_78 = 0, $L_84 = 0, $L_90 = 0, $L_96 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $_stackTraceSentry = sp + 64|0;
 $L_6 = sp + 60|0;
 $L_12 = sp + 56|0;
 $L_18 = sp + 52|0;
 $L_24 = sp + 48|0;
 $L_30 = sp + 44|0;
 $L_36 = sp + 40|0;
 $L_42 = sp + 36|0;
 $L_48 = sp + 32|0;
 $L_54 = sp + 24|0;
 $L_60 = sp + 20|0;
 $L_66 = sp + 16|0;
 $L_72 = sp + 12|0;
 $L_78 = sp + 8|0;
 $L_84 = sp + 4|0;
 $L_90 = sp;
 $L_96 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799768);
 __THREW__ = 0;
 invoke_v(980);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),16)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = Math_fround(HEAPF32[$__this>>2]);
     HEAPF32[$L_6>>2] = $7;
     __THREW__ = 0;
     (invoke_ii(2996,(2194912|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($4) + 12|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = ($16|0)==(0);
        if ($17) {
         __THREW__ = 0;
         $18 = (invoke_i(132)|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if ($20) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($10|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($4) + 16|0);
         HEAP32[$27>>2] = $10;
         $28 = (($__this) + 16|0);
         $29 = Math_fround(HEAPF32[$28>>2]);
         HEAPF32[$L_12>>2] = $29;
         __THREW__ = 0;
         (invoke_ii(2996,(2194912|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          $32 = (invoke_iii(2724,(2194912|0),($L_12|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if (!($36)) {
            $37 = HEAP32[$15>>2]|0;
            $38 = ($37>>>0)<(2);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($32|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             $46 = HEAP32[$4>>2]|0;
             $47 = (($46) + 92|0);
             $48 = HEAP32[$47>>2]|0;
             $49 = (($27) + ($48)|0);
             HEAP32[$49>>2] = $32;
             $50 = (($__this) + 32|0);
             $51 = Math_fround(HEAPF32[$50>>2]);
             HEAPF32[$L_18>>2] = $51;
             __THREW__ = 0;
             (invoke_ii(2996,(2194912|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2724,(2194912|0),($L_18|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if (!($58)) {
                $59 = HEAP32[$15>>2]|0;
                $60 = ($59>>>0)<(3);
                if ($60) {
                 __THREW__ = 0;
                 $61 = (invoke_i(132)|0);
                 $62 = __THREW__; __THREW__ = 0;
                 $63 = $62&1;
                 if ($63) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($61|0));
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if ($65) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($54|0));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if (!($67)) {
                 $68 = HEAP32[$4>>2]|0;
                 $69 = (($68) + 92|0);
                 $70 = HEAP32[$69>>2]|0;
                 $71 = $70 << 1;
                 $72 = (($27) + ($71)|0);
                 HEAP32[$72>>2] = $54;
                 $73 = (($__this) + 48|0);
                 $74 = Math_fround(HEAPF32[$73>>2]);
                 HEAPF32[$L_24>>2] = $74;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2194912|0))|0);
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if (!($76)) {
                  __THREW__ = 0;
                  $77 = (invoke_iii(2724,(2194912|0),($L_24|0))|0);
                  $78 = __THREW__; __THREW__ = 0;
                  $79 = $78&1;
                  if ($79) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break;
                  }
                  $82 = HEAP32[$15>>2]|0;
                  $83 = ($82>>>0)<(4);
                  if ($83) {
                   __THREW__ = 0;
                   $84 = (invoke_i(132)|0);
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($84|0));
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($77|0));
                  $89 = __THREW__; __THREW__ = 0;
                  $90 = $89&1;
                  if ($90) {
                   break;
                  }
                  $91 = HEAP32[$4>>2]|0;
                  $92 = (($91) + 92|0);
                  $93 = HEAP32[$92>>2]|0;
                  $94 = ($93*3)|0;
                  $95 = (($27) + ($94)|0);
                  HEAP32[$95>>2] = $77;
                  $96 = (($__this) + 4|0);
                  $97 = Math_fround(HEAPF32[$96>>2]);
                  HEAPF32[$L_30>>2] = $97;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $98 = __THREW__; __THREW__ = 0;
                  $99 = $98&1;
                  if ($99) {
                   break;
                  }
                  __THREW__ = 0;
                  $100 = (invoke_iii(2724,(2194912|0),($L_30|0))|0);
                  $101 = __THREW__; __THREW__ = 0;
                  $102 = $101&1;
                  if ($102) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $103 = __THREW__; __THREW__ = 0;
                  $104 = $103&1;
                  if ($104) {
                   break;
                  }
                  $105 = HEAP32[$15>>2]|0;
                  $106 = ($105>>>0)<(5);
                  if ($106) {
                   __THREW__ = 0;
                   $107 = (invoke_i(132)|0);
                   $108 = __THREW__; __THREW__ = 0;
                   $109 = $108&1;
                   if ($109) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($107|0));
                   $110 = __THREW__; __THREW__ = 0;
                   $111 = $110&1;
                   if ($111) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($100|0));
                  $112 = __THREW__; __THREW__ = 0;
                  $113 = $112&1;
                  if ($113) {
                   break;
                  }
                  $114 = HEAP32[$4>>2]|0;
                  $115 = (($114) + 92|0);
                  $116 = HEAP32[$115>>2]|0;
                  $117 = $116 << 2;
                  $118 = (($27) + ($117)|0);
                  HEAP32[$118>>2] = $100;
                  $119 = (($__this) + 20|0);
                  $120 = Math_fround(HEAPF32[$119>>2]);
                  HEAPF32[$L_36>>2] = $120;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $121 = __THREW__; __THREW__ = 0;
                  $122 = $121&1;
                  if ($122) {
                   break;
                  }
                  __THREW__ = 0;
                  $123 = (invoke_iii(2724,(2194912|0),($L_36|0))|0);
                  $124 = __THREW__; __THREW__ = 0;
                  $125 = $124&1;
                  if ($125) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $126 = __THREW__; __THREW__ = 0;
                  $127 = $126&1;
                  if ($127) {
                   break;
                  }
                  $128 = HEAP32[$15>>2]|0;
                  $129 = ($128>>>0)<(6);
                  if ($129) {
                   __THREW__ = 0;
                   $130 = (invoke_i(132)|0);
                   $131 = __THREW__; __THREW__ = 0;
                   $132 = $131&1;
                   if ($132) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($130|0));
                   $133 = __THREW__; __THREW__ = 0;
                   $134 = $133&1;
                   if ($134) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($123|0));
                  $135 = __THREW__; __THREW__ = 0;
                  $136 = $135&1;
                  if ($136) {
                   break;
                  }
                  $137 = HEAP32[$4>>2]|0;
                  $138 = (($137) + 92|0);
                  $139 = HEAP32[$138>>2]|0;
                  $140 = ($139*5)|0;
                  $141 = (($27) + ($140)|0);
                  HEAP32[$141>>2] = $123;
                  $142 = (($__this) + 36|0);
                  $143 = Math_fround(HEAPF32[$142>>2]);
                  HEAPF32[$L_42>>2] = $143;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $144 = __THREW__; __THREW__ = 0;
                  $145 = $144&1;
                  if ($145) {
                   break;
                  }
                  __THREW__ = 0;
                  $146 = (invoke_iii(2724,(2194912|0),($L_42|0))|0);
                  $147 = __THREW__; __THREW__ = 0;
                  $148 = $147&1;
                  if ($148) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $149 = __THREW__; __THREW__ = 0;
                  $150 = $149&1;
                  if ($150) {
                   break;
                  }
                  $151 = HEAP32[$15>>2]|0;
                  $152 = ($151>>>0)<(7);
                  if ($152) {
                   __THREW__ = 0;
                   $153 = (invoke_i(132)|0);
                   $154 = __THREW__; __THREW__ = 0;
                   $155 = $154&1;
                   if ($155) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($153|0));
                   $156 = __THREW__; __THREW__ = 0;
                   $157 = $156&1;
                   if ($157) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($146|0));
                  $158 = __THREW__; __THREW__ = 0;
                  $159 = $158&1;
                  if ($159) {
                   break;
                  }
                  $160 = HEAP32[$4>>2]|0;
                  $161 = (($160) + 92|0);
                  $162 = HEAP32[$161>>2]|0;
                  $163 = ($162*6)|0;
                  $164 = (($27) + ($163)|0);
                  HEAP32[$164>>2] = $146;
                  $165 = (($__this) + 52|0);
                  $166 = Math_fround(HEAPF32[$165>>2]);
                  HEAPF32[$L_48>>2] = $166;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $167 = __THREW__; __THREW__ = 0;
                  $168 = $167&1;
                  if ($168) {
                   break;
                  }
                  __THREW__ = 0;
                  $169 = (invoke_iii(2724,(2194912|0),($L_48|0))|0);
                  $170 = __THREW__; __THREW__ = 0;
                  $171 = $170&1;
                  if ($171) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $172 = __THREW__; __THREW__ = 0;
                  $173 = $172&1;
                  if ($173) {
                   break;
                  }
                  $174 = HEAP32[$15>>2]|0;
                  $175 = ($174>>>0)<(8);
                  if ($175) {
                   __THREW__ = 0;
                   $176 = (invoke_i(132)|0);
                   $177 = __THREW__; __THREW__ = 0;
                   $178 = $177&1;
                   if ($178) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($176|0));
                   $179 = __THREW__; __THREW__ = 0;
                   $180 = $179&1;
                   if ($180) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($169|0));
                  $181 = __THREW__; __THREW__ = 0;
                  $182 = $181&1;
                  if ($182) {
                   break;
                  }
                  $183 = HEAP32[$4>>2]|0;
                  $184 = (($183) + 92|0);
                  $185 = HEAP32[$184>>2]|0;
                  $186 = ($185*7)|0;
                  $187 = (($27) + ($186)|0);
                  HEAP32[$187>>2] = $169;
                  $188 = (($__this) + 8|0);
                  $189 = Math_fround(HEAPF32[$188>>2]);
                  HEAPF32[$L_54>>2] = $189;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $190 = __THREW__; __THREW__ = 0;
                  $191 = $190&1;
                  if ($191) {
                   break;
                  }
                  __THREW__ = 0;
                  $192 = (invoke_iii(2724,(2194912|0),($L_54|0))|0);
                  $193 = __THREW__; __THREW__ = 0;
                  $194 = $193&1;
                  if ($194) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $195 = __THREW__; __THREW__ = 0;
                  $196 = $195&1;
                  if ($196) {
                   break;
                  }
                  $197 = HEAP32[$15>>2]|0;
                  $198 = ($197>>>0)<(9);
                  if ($198) {
                   __THREW__ = 0;
                   $199 = (invoke_i(132)|0);
                   $200 = __THREW__; __THREW__ = 0;
                   $201 = $200&1;
                   if ($201) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($199|0));
                   $202 = __THREW__; __THREW__ = 0;
                   $203 = $202&1;
                   if ($203) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($192|0));
                  $204 = __THREW__; __THREW__ = 0;
                  $205 = $204&1;
                  if ($205) {
                   break;
                  }
                  $206 = HEAP32[$4>>2]|0;
                  $207 = (($206) + 92|0);
                  $208 = HEAP32[$207>>2]|0;
                  $209 = $208 << 3;
                  $210 = (($27) + ($209)|0);
                  HEAP32[$210>>2] = $192;
                  $211 = (($__this) + 24|0);
                  $212 = Math_fround(HEAPF32[$211>>2]);
                  HEAPF32[$L_60>>2] = $212;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $213 = __THREW__; __THREW__ = 0;
                  $214 = $213&1;
                  if ($214) {
                   break;
                  }
                  __THREW__ = 0;
                  $215 = (invoke_iii(2724,(2194912|0),($L_60|0))|0);
                  $216 = __THREW__; __THREW__ = 0;
                  $217 = $216&1;
                  if ($217) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $218 = __THREW__; __THREW__ = 0;
                  $219 = $218&1;
                  if ($219) {
                   break;
                  }
                  $220 = HEAP32[$15>>2]|0;
                  $221 = ($220>>>0)<(10);
                  if ($221) {
                   __THREW__ = 0;
                   $222 = (invoke_i(132)|0);
                   $223 = __THREW__; __THREW__ = 0;
                   $224 = $223&1;
                   if ($224) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($222|0));
                   $225 = __THREW__; __THREW__ = 0;
                   $226 = $225&1;
                   if ($226) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($215|0));
                  $227 = __THREW__; __THREW__ = 0;
                  $228 = $227&1;
                  if ($228) {
                   break;
                  }
                  $229 = HEAP32[$4>>2]|0;
                  $230 = (($229) + 92|0);
                  $231 = HEAP32[$230>>2]|0;
                  $232 = ($231*9)|0;
                  $233 = (($27) + ($232)|0);
                  HEAP32[$233>>2] = $215;
                  $234 = (($__this) + 40|0);
                  $235 = Math_fround(HEAPF32[$234>>2]);
                  HEAPF32[$L_66>>2] = $235;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $236 = __THREW__; __THREW__ = 0;
                  $237 = $236&1;
                  if ($237) {
                   break;
                  }
                  __THREW__ = 0;
                  $238 = (invoke_iii(2724,(2194912|0),($L_66|0))|0);
                  $239 = __THREW__; __THREW__ = 0;
                  $240 = $239&1;
                  if ($240) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $241 = __THREW__; __THREW__ = 0;
                  $242 = $241&1;
                  if ($242) {
                   break;
                  }
                  $243 = HEAP32[$15>>2]|0;
                  $244 = ($243>>>0)<(11);
                  if ($244) {
                   __THREW__ = 0;
                   $245 = (invoke_i(132)|0);
                   $246 = __THREW__; __THREW__ = 0;
                   $247 = $246&1;
                   if ($247) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($245|0));
                   $248 = __THREW__; __THREW__ = 0;
                   $249 = $248&1;
                   if ($249) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($238|0));
                  $250 = __THREW__; __THREW__ = 0;
                  $251 = $250&1;
                  if ($251) {
                   break;
                  }
                  $252 = HEAP32[$4>>2]|0;
                  $253 = (($252) + 92|0);
                  $254 = HEAP32[$253>>2]|0;
                  $255 = ($254*10)|0;
                  $256 = (($27) + ($255)|0);
                  HEAP32[$256>>2] = $238;
                  $257 = (($__this) + 56|0);
                  $258 = Math_fround(HEAPF32[$257>>2]);
                  HEAPF32[$L_72>>2] = $258;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $259 = __THREW__; __THREW__ = 0;
                  $260 = $259&1;
                  if ($260) {
                   break;
                  }
                  __THREW__ = 0;
                  $261 = (invoke_iii(2724,(2194912|0),($L_72|0))|0);
                  $262 = __THREW__; __THREW__ = 0;
                  $263 = $262&1;
                  if ($263) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $264 = __THREW__; __THREW__ = 0;
                  $265 = $264&1;
                  if ($265) {
                   break;
                  }
                  $266 = HEAP32[$15>>2]|0;
                  $267 = ($266>>>0)<(12);
                  if ($267) {
                   __THREW__ = 0;
                   $268 = (invoke_i(132)|0);
                   $269 = __THREW__; __THREW__ = 0;
                   $270 = $269&1;
                   if ($270) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($268|0));
                   $271 = __THREW__; __THREW__ = 0;
                   $272 = $271&1;
                   if ($272) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($261|0));
                  $273 = __THREW__; __THREW__ = 0;
                  $274 = $273&1;
                  if ($274) {
                   break;
                  }
                  $275 = HEAP32[$4>>2]|0;
                  $276 = (($275) + 92|0);
                  $277 = HEAP32[$276>>2]|0;
                  $278 = ($277*11)|0;
                  $279 = (($27) + ($278)|0);
                  HEAP32[$279>>2] = $261;
                  $280 = (($__this) + 12|0);
                  $281 = Math_fround(HEAPF32[$280>>2]);
                  HEAPF32[$L_78>>2] = $281;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $282 = __THREW__; __THREW__ = 0;
                  $283 = $282&1;
                  if ($283) {
                   break;
                  }
                  __THREW__ = 0;
                  $284 = (invoke_iii(2724,(2194912|0),($L_78|0))|0);
                  $285 = __THREW__; __THREW__ = 0;
                  $286 = $285&1;
                  if ($286) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $287 = __THREW__; __THREW__ = 0;
                  $288 = $287&1;
                  if ($288) {
                   break;
                  }
                  $289 = HEAP32[$15>>2]|0;
                  $290 = ($289>>>0)<(13);
                  if ($290) {
                   __THREW__ = 0;
                   $291 = (invoke_i(132)|0);
                   $292 = __THREW__; __THREW__ = 0;
                   $293 = $292&1;
                   if ($293) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($291|0));
                   $294 = __THREW__; __THREW__ = 0;
                   $295 = $294&1;
                   if ($295) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($284|0));
                  $296 = __THREW__; __THREW__ = 0;
                  $297 = $296&1;
                  if ($297) {
                   break;
                  }
                  $298 = HEAP32[$4>>2]|0;
                  $299 = (($298) + 92|0);
                  $300 = HEAP32[$299>>2]|0;
                  $301 = ($300*12)|0;
                  $302 = (($27) + ($301)|0);
                  HEAP32[$302>>2] = $284;
                  $303 = (($__this) + 28|0);
                  $304 = Math_fround(HEAPF32[$303>>2]);
                  HEAPF32[$L_84>>2] = $304;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $305 = __THREW__; __THREW__ = 0;
                  $306 = $305&1;
                  if ($306) {
                   break;
                  }
                  __THREW__ = 0;
                  $307 = (invoke_iii(2724,(2194912|0),($L_84|0))|0);
                  $308 = __THREW__; __THREW__ = 0;
                  $309 = $308&1;
                  if ($309) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $310 = __THREW__; __THREW__ = 0;
                  $311 = $310&1;
                  if ($311) {
                   break;
                  }
                  $312 = HEAP32[$15>>2]|0;
                  $313 = ($312>>>0)<(14);
                  if ($313) {
                   __THREW__ = 0;
                   $314 = (invoke_i(132)|0);
                   $315 = __THREW__; __THREW__ = 0;
                   $316 = $315&1;
                   if ($316) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($314|0));
                   $317 = __THREW__; __THREW__ = 0;
                   $318 = $317&1;
                   if ($318) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($307|0));
                  $319 = __THREW__; __THREW__ = 0;
                  $320 = $319&1;
                  if ($320) {
                   break;
                  }
                  $321 = HEAP32[$4>>2]|0;
                  $322 = (($321) + 92|0);
                  $323 = HEAP32[$322>>2]|0;
                  $324 = ($323*13)|0;
                  $325 = (($27) + ($324)|0);
                  HEAP32[$325>>2] = $307;
                  $326 = (($__this) + 44|0);
                  $327 = Math_fround(HEAPF32[$326>>2]);
                  HEAPF32[$L_90>>2] = $327;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $328 = __THREW__; __THREW__ = 0;
                  $329 = $328&1;
                  if ($329) {
                   break;
                  }
                  __THREW__ = 0;
                  $330 = (invoke_iii(2724,(2194912|0),($L_90|0))|0);
                  $331 = __THREW__; __THREW__ = 0;
                  $332 = $331&1;
                  if ($332) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $333 = __THREW__; __THREW__ = 0;
                  $334 = $333&1;
                  if ($334) {
                   break;
                  }
                  $335 = HEAP32[$15>>2]|0;
                  $336 = ($335>>>0)<(15);
                  if ($336) {
                   __THREW__ = 0;
                   $337 = (invoke_i(132)|0);
                   $338 = __THREW__; __THREW__ = 0;
                   $339 = $338&1;
                   if ($339) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($337|0));
                   $340 = __THREW__; __THREW__ = 0;
                   $341 = $340&1;
                   if ($341) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($330|0));
                  $342 = __THREW__; __THREW__ = 0;
                  $343 = $342&1;
                  if ($343) {
                   break;
                  }
                  $344 = HEAP32[$4>>2]|0;
                  $345 = (($344) + 92|0);
                  $346 = HEAP32[$345>>2]|0;
                  $347 = ($346*14)|0;
                  $348 = (($27) + ($347)|0);
                  HEAP32[$348>>2] = $330;
                  $349 = (($__this) + 60|0);
                  $350 = Math_fround(HEAPF32[$349>>2]);
                  HEAPF32[$L_96>>2] = $350;
                  __THREW__ = 0;
                  (invoke_ii(2996,(2194912|0))|0);
                  $351 = __THREW__; __THREW__ = 0;
                  $352 = $351&1;
                  if ($352) {
                   break;
                  }
                  __THREW__ = 0;
                  $353 = (invoke_iii(2724,(2194912|0),($L_96|0))|0);
                  $354 = __THREW__; __THREW__ = 0;
                  $355 = $354&1;
                  if ($355) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $356 = __THREW__; __THREW__ = 0;
                  $357 = $356&1;
                  if ($357) {
                   break;
                  }
                  $358 = HEAP32[$15>>2]|0;
                  $359 = ($358>>>0)<(16);
                  if ($359) {
                   __THREW__ = 0;
                   $360 = (invoke_i(132)|0);
                   $361 = __THREW__; __THREW__ = 0;
                   $362 = $361&1;
                   if ($362) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($360|0));
                   $363 = __THREW__; __THREW__ = 0;
                   $364 = $363&1;
                   if ($364) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($353|0));
                  $365 = __THREW__; __THREW__ = 0;
                  $366 = $365&1;
                  if ($366) {
                   break;
                  }
                  $367 = HEAP32[$4>>2]|0;
                  $368 = (($367) + 92|0);
                  $369 = HEAP32[$368>>2]|0;
                  $370 = ($369*15)|0;
                  $371 = (($27) + ($370)|0);
                  HEAP32[$371>>2] = $353;
                  $372 = HEAP32[3000744>>2]|0;
                  __THREW__ = 0;
                  $373 = (invoke_iiii(1417,0,($372|0),($4|0))|0);
                  $374 = __THREW__; __THREW__ = 0;
                  $375 = $374&1;
                  if ($375) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($373|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z90UnityEngine_UnityEngine_Matrix4x4_m_ToString_mscorlib_System_String_mscorlib_System_StringP33UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799816);
 __THREW__ = 0;
 invoke_v(981);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),16)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(657,($__this|0),($format|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($4) + 12|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = ($13|0)==(0);
       if ($14) {
        __THREW__ = 0;
        $15 = (invoke_i(132)|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($15|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($4|0),($7|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = (($4) + 16|0);
        HEAP32[$24>>2] = $7;
        $25 = (($__this) + 16|0);
        __THREW__ = 0;
        $26 = (invoke_iii(657,($25|0),($format|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          $31 = HEAP32[$12>>2]|0;
          $32 = ($31>>>0)<(2);
          if ($32) {
           __THREW__ = 0;
           $33 = (invoke_i(132)|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if ($35) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($33|0));
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($4|0),($26|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if (!($39)) {
           $40 = HEAP32[$4>>2]|0;
           $41 = (($40) + 92|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = (($24) + ($42)|0);
           HEAP32[$43>>2] = $26;
           $44 = (($__this) + 32|0);
           __THREW__ = 0;
           $45 = (invoke_iii(657,($44|0),($format|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            __THREW__ = 0;
            invoke_vi(3799,($4|0));
            $48 = __THREW__; __THREW__ = 0;
            $49 = $48&1;
            if (!($49)) {
             $50 = HEAP32[$12>>2]|0;
             $51 = ($50>>>0)<(3);
             if ($51) {
              __THREW__ = 0;
              $52 = (invoke_i(132)|0);
              $53 = __THREW__; __THREW__ = 0;
              $54 = $53&1;
              if ($54) {
               break;
              }
              __THREW__ = 0;
              invoke_vi(3302,($52|0));
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if ($56) {
               break;
              }
             }
             __THREW__ = 0;
             invoke_vii(3492,($4|0),($45|0));
             $57 = __THREW__; __THREW__ = 0;
             $58 = $57&1;
             if (!($58)) {
              $59 = HEAP32[$4>>2]|0;
              $60 = (($59) + 92|0);
              $61 = HEAP32[$60>>2]|0;
              $62 = $61 << 1;
              $63 = (($24) + ($62)|0);
              HEAP32[$63>>2] = $45;
              $64 = (($__this) + 48|0);
              __THREW__ = 0;
              $65 = (invoke_iii(657,($64|0),($format|0))|0);
              $66 = __THREW__; __THREW__ = 0;
              $67 = $66&1;
              if (!($67)) {
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $68 = __THREW__; __THREW__ = 0;
               $69 = $68&1;
               if (!($69)) {
                $70 = HEAP32[$12>>2]|0;
                $71 = ($70>>>0)<(4);
                if ($71) {
                 __THREW__ = 0;
                 $72 = (invoke_i(132)|0);
                 $73 = __THREW__; __THREW__ = 0;
                 $74 = $73&1;
                 if ($74) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($72|0));
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if ($76) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($65|0));
                $77 = __THREW__; __THREW__ = 0;
                $78 = $77&1;
                if (!($78)) {
                 $79 = HEAP32[$4>>2]|0;
                 $80 = (($79) + 92|0);
                 $81 = HEAP32[$80>>2]|0;
                 $82 = ($81*3)|0;
                 $83 = (($24) + ($82)|0);
                 HEAP32[$83>>2] = $65;
                 $84 = (($__this) + 4|0);
                 __THREW__ = 0;
                 $85 = (invoke_iii(657,($84|0),($format|0))|0);
                 $86 = __THREW__; __THREW__ = 0;
                 $87 = $86&1;
                 if ($87) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $88 = __THREW__; __THREW__ = 0;
                 $89 = $88&1;
                 if ($89) {
                  break;
                 }
                 $90 = HEAP32[$12>>2]|0;
                 $91 = ($90>>>0)<(5);
                 if ($91) {
                  __THREW__ = 0;
                  $92 = (invoke_i(132)|0);
                  $93 = __THREW__; __THREW__ = 0;
                  $94 = $93&1;
                  if ($94) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($92|0));
                  $95 = __THREW__; __THREW__ = 0;
                  $96 = $95&1;
                  if ($96) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($85|0));
                 $97 = __THREW__; __THREW__ = 0;
                 $98 = $97&1;
                 if ($98) {
                  break;
                 }
                 $99 = HEAP32[$4>>2]|0;
                 $100 = (($99) + 92|0);
                 $101 = HEAP32[$100>>2]|0;
                 $102 = $101 << 2;
                 $103 = (($24) + ($102)|0);
                 HEAP32[$103>>2] = $85;
                 $104 = (($__this) + 20|0);
                 __THREW__ = 0;
                 $105 = (invoke_iii(657,($104|0),($format|0))|0);
                 $106 = __THREW__; __THREW__ = 0;
                 $107 = $106&1;
                 if ($107) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $108 = __THREW__; __THREW__ = 0;
                 $109 = $108&1;
                 if ($109) {
                  break;
                 }
                 $110 = HEAP32[$12>>2]|0;
                 $111 = ($110>>>0)<(6);
                 if ($111) {
                  __THREW__ = 0;
                  $112 = (invoke_i(132)|0);
                  $113 = __THREW__; __THREW__ = 0;
                  $114 = $113&1;
                  if ($114) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($112|0));
                  $115 = __THREW__; __THREW__ = 0;
                  $116 = $115&1;
                  if ($116) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($105|0));
                 $117 = __THREW__; __THREW__ = 0;
                 $118 = $117&1;
                 if ($118) {
                  break;
                 }
                 $119 = HEAP32[$4>>2]|0;
                 $120 = (($119) + 92|0);
                 $121 = HEAP32[$120>>2]|0;
                 $122 = ($121*5)|0;
                 $123 = (($24) + ($122)|0);
                 HEAP32[$123>>2] = $105;
                 $124 = (($__this) + 36|0);
                 __THREW__ = 0;
                 $125 = (invoke_iii(657,($124|0),($format|0))|0);
                 $126 = __THREW__; __THREW__ = 0;
                 $127 = $126&1;
                 if ($127) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $128 = __THREW__; __THREW__ = 0;
                 $129 = $128&1;
                 if ($129) {
                  break;
                 }
                 $130 = HEAP32[$12>>2]|0;
                 $131 = ($130>>>0)<(7);
                 if ($131) {
                  __THREW__ = 0;
                  $132 = (invoke_i(132)|0);
                  $133 = __THREW__; __THREW__ = 0;
                  $134 = $133&1;
                  if ($134) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($132|0));
                  $135 = __THREW__; __THREW__ = 0;
                  $136 = $135&1;
                  if ($136) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($125|0));
                 $137 = __THREW__; __THREW__ = 0;
                 $138 = $137&1;
                 if ($138) {
                  break;
                 }
                 $139 = HEAP32[$4>>2]|0;
                 $140 = (($139) + 92|0);
                 $141 = HEAP32[$140>>2]|0;
                 $142 = ($141*6)|0;
                 $143 = (($24) + ($142)|0);
                 HEAP32[$143>>2] = $125;
                 $144 = (($__this) + 52|0);
                 __THREW__ = 0;
                 $145 = (invoke_iii(657,($144|0),($format|0))|0);
                 $146 = __THREW__; __THREW__ = 0;
                 $147 = $146&1;
                 if ($147) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $148 = __THREW__; __THREW__ = 0;
                 $149 = $148&1;
                 if ($149) {
                  break;
                 }
                 $150 = HEAP32[$12>>2]|0;
                 $151 = ($150>>>0)<(8);
                 if ($151) {
                  __THREW__ = 0;
                  $152 = (invoke_i(132)|0);
                  $153 = __THREW__; __THREW__ = 0;
                  $154 = $153&1;
                  if ($154) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($152|0));
                  $155 = __THREW__; __THREW__ = 0;
                  $156 = $155&1;
                  if ($156) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($145|0));
                 $157 = __THREW__; __THREW__ = 0;
                 $158 = $157&1;
                 if ($158) {
                  break;
                 }
                 $159 = HEAP32[$4>>2]|0;
                 $160 = (($159) + 92|0);
                 $161 = HEAP32[$160>>2]|0;
                 $162 = ($161*7)|0;
                 $163 = (($24) + ($162)|0);
                 HEAP32[$163>>2] = $145;
                 $164 = (($__this) + 8|0);
                 __THREW__ = 0;
                 $165 = (invoke_iii(657,($164|0),($format|0))|0);
                 $166 = __THREW__; __THREW__ = 0;
                 $167 = $166&1;
                 if ($167) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $168 = __THREW__; __THREW__ = 0;
                 $169 = $168&1;
                 if ($169) {
                  break;
                 }
                 $170 = HEAP32[$12>>2]|0;
                 $171 = ($170>>>0)<(9);
                 if ($171) {
                  __THREW__ = 0;
                  $172 = (invoke_i(132)|0);
                  $173 = __THREW__; __THREW__ = 0;
                  $174 = $173&1;
                  if ($174) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($172|0));
                  $175 = __THREW__; __THREW__ = 0;
                  $176 = $175&1;
                  if ($176) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($165|0));
                 $177 = __THREW__; __THREW__ = 0;
                 $178 = $177&1;
                 if ($178) {
                  break;
                 }
                 $179 = HEAP32[$4>>2]|0;
                 $180 = (($179) + 92|0);
                 $181 = HEAP32[$180>>2]|0;
                 $182 = $181 << 3;
                 $183 = (($24) + ($182)|0);
                 HEAP32[$183>>2] = $165;
                 $184 = (($__this) + 24|0);
                 __THREW__ = 0;
                 $185 = (invoke_iii(657,($184|0),($format|0))|0);
                 $186 = __THREW__; __THREW__ = 0;
                 $187 = $186&1;
                 if ($187) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $188 = __THREW__; __THREW__ = 0;
                 $189 = $188&1;
                 if ($189) {
                  break;
                 }
                 $190 = HEAP32[$12>>2]|0;
                 $191 = ($190>>>0)<(10);
                 if ($191) {
                  __THREW__ = 0;
                  $192 = (invoke_i(132)|0);
                  $193 = __THREW__; __THREW__ = 0;
                  $194 = $193&1;
                  if ($194) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($192|0));
                  $195 = __THREW__; __THREW__ = 0;
                  $196 = $195&1;
                  if ($196) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($185|0));
                 $197 = __THREW__; __THREW__ = 0;
                 $198 = $197&1;
                 if ($198) {
                  break;
                 }
                 $199 = HEAP32[$4>>2]|0;
                 $200 = (($199) + 92|0);
                 $201 = HEAP32[$200>>2]|0;
                 $202 = ($201*9)|0;
                 $203 = (($24) + ($202)|0);
                 HEAP32[$203>>2] = $185;
                 $204 = (($__this) + 40|0);
                 __THREW__ = 0;
                 $205 = (invoke_iii(657,($204|0),($format|0))|0);
                 $206 = __THREW__; __THREW__ = 0;
                 $207 = $206&1;
                 if ($207) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $208 = __THREW__; __THREW__ = 0;
                 $209 = $208&1;
                 if ($209) {
                  break;
                 }
                 $210 = HEAP32[$12>>2]|0;
                 $211 = ($210>>>0)<(11);
                 if ($211) {
                  __THREW__ = 0;
                  $212 = (invoke_i(132)|0);
                  $213 = __THREW__; __THREW__ = 0;
                  $214 = $213&1;
                  if ($214) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($212|0));
                  $215 = __THREW__; __THREW__ = 0;
                  $216 = $215&1;
                  if ($216) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($205|0));
                 $217 = __THREW__; __THREW__ = 0;
                 $218 = $217&1;
                 if ($218) {
                  break;
                 }
                 $219 = HEAP32[$4>>2]|0;
                 $220 = (($219) + 92|0);
                 $221 = HEAP32[$220>>2]|0;
                 $222 = ($221*10)|0;
                 $223 = (($24) + ($222)|0);
                 HEAP32[$223>>2] = $205;
                 $224 = (($__this) + 56|0);
                 __THREW__ = 0;
                 $225 = (invoke_iii(657,($224|0),($format|0))|0);
                 $226 = __THREW__; __THREW__ = 0;
                 $227 = $226&1;
                 if ($227) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $228 = __THREW__; __THREW__ = 0;
                 $229 = $228&1;
                 if ($229) {
                  break;
                 }
                 $230 = HEAP32[$12>>2]|0;
                 $231 = ($230>>>0)<(12);
                 if ($231) {
                  __THREW__ = 0;
                  $232 = (invoke_i(132)|0);
                  $233 = __THREW__; __THREW__ = 0;
                  $234 = $233&1;
                  if ($234) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($232|0));
                  $235 = __THREW__; __THREW__ = 0;
                  $236 = $235&1;
                  if ($236) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($225|0));
                 $237 = __THREW__; __THREW__ = 0;
                 $238 = $237&1;
                 if ($238) {
                  break;
                 }
                 $239 = HEAP32[$4>>2]|0;
                 $240 = (($239) + 92|0);
                 $241 = HEAP32[$240>>2]|0;
                 $242 = ($241*11)|0;
                 $243 = (($24) + ($242)|0);
                 HEAP32[$243>>2] = $225;
                 $244 = (($__this) + 12|0);
                 __THREW__ = 0;
                 $245 = (invoke_iii(657,($244|0),($format|0))|0);
                 $246 = __THREW__; __THREW__ = 0;
                 $247 = $246&1;
                 if ($247) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $248 = __THREW__; __THREW__ = 0;
                 $249 = $248&1;
                 if ($249) {
                  break;
                 }
                 $250 = HEAP32[$12>>2]|0;
                 $251 = ($250>>>0)<(13);
                 if ($251) {
                  __THREW__ = 0;
                  $252 = (invoke_i(132)|0);
                  $253 = __THREW__; __THREW__ = 0;
                  $254 = $253&1;
                  if ($254) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($252|0));
                  $255 = __THREW__; __THREW__ = 0;
                  $256 = $255&1;
                  if ($256) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($245|0));
                 $257 = __THREW__; __THREW__ = 0;
                 $258 = $257&1;
                 if ($258) {
                  break;
                 }
                 $259 = HEAP32[$4>>2]|0;
                 $260 = (($259) + 92|0);
                 $261 = HEAP32[$260>>2]|0;
                 $262 = ($261*12)|0;
                 $263 = (($24) + ($262)|0);
                 HEAP32[$263>>2] = $245;
                 $264 = (($__this) + 28|0);
                 __THREW__ = 0;
                 $265 = (invoke_iii(657,($264|0),($format|0))|0);
                 $266 = __THREW__; __THREW__ = 0;
                 $267 = $266&1;
                 if ($267) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $268 = __THREW__; __THREW__ = 0;
                 $269 = $268&1;
                 if ($269) {
                  break;
                 }
                 $270 = HEAP32[$12>>2]|0;
                 $271 = ($270>>>0)<(14);
                 if ($271) {
                  __THREW__ = 0;
                  $272 = (invoke_i(132)|0);
                  $273 = __THREW__; __THREW__ = 0;
                  $274 = $273&1;
                  if ($274) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($272|0));
                  $275 = __THREW__; __THREW__ = 0;
                  $276 = $275&1;
                  if ($276) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($265|0));
                 $277 = __THREW__; __THREW__ = 0;
                 $278 = $277&1;
                 if ($278) {
                  break;
                 }
                 $279 = HEAP32[$4>>2]|0;
                 $280 = (($279) + 92|0);
                 $281 = HEAP32[$280>>2]|0;
                 $282 = ($281*13)|0;
                 $283 = (($24) + ($282)|0);
                 HEAP32[$283>>2] = $265;
                 $284 = (($__this) + 44|0);
                 __THREW__ = 0;
                 $285 = (invoke_iii(657,($284|0),($format|0))|0);
                 $286 = __THREW__; __THREW__ = 0;
                 $287 = $286&1;
                 if ($287) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $288 = __THREW__; __THREW__ = 0;
                 $289 = $288&1;
                 if ($289) {
                  break;
                 }
                 $290 = HEAP32[$12>>2]|0;
                 $291 = ($290>>>0)<(15);
                 if ($291) {
                  __THREW__ = 0;
                  $292 = (invoke_i(132)|0);
                  $293 = __THREW__; __THREW__ = 0;
                  $294 = $293&1;
                  if ($294) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($292|0));
                  $295 = __THREW__; __THREW__ = 0;
                  $296 = $295&1;
                  if ($296) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($285|0));
                 $297 = __THREW__; __THREW__ = 0;
                 $298 = $297&1;
                 if ($298) {
                  break;
                 }
                 $299 = HEAP32[$4>>2]|0;
                 $300 = (($299) + 92|0);
                 $301 = HEAP32[$300>>2]|0;
                 $302 = ($301*14)|0;
                 $303 = (($24) + ($302)|0);
                 HEAP32[$303>>2] = $285;
                 $304 = (($__this) + 60|0);
                 __THREW__ = 0;
                 $305 = (invoke_iii(657,($304|0),($format|0))|0);
                 $306 = __THREW__; __THREW__ = 0;
                 $307 = $306&1;
                 if ($307) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3799,($4|0));
                 $308 = __THREW__; __THREW__ = 0;
                 $309 = $308&1;
                 if ($309) {
                  break;
                 }
                 $310 = HEAP32[$12>>2]|0;
                 $311 = ($310>>>0)<(16);
                 if ($311) {
                  __THREW__ = 0;
                  $312 = (invoke_i(132)|0);
                  $313 = __THREW__; __THREW__ = 0;
                  $314 = $313&1;
                  if ($314) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($312|0));
                  $315 = __THREW__; __THREW__ = 0;
                  $316 = $315&1;
                  if ($316) {
                   break;
                  }
                 }
                 __THREW__ = 0;
                 invoke_vii(3492,($4|0),($305|0));
                 $317 = __THREW__; __THREW__ = 0;
                 $318 = $317&1;
                 if ($318) {
                  break;
                 }
                 $319 = HEAP32[$4>>2]|0;
                 $320 = (($319) + 92|0);
                 $321 = HEAP32[$320>>2]|0;
                 $322 = ($321*15)|0;
                 $323 = (($24) + ($322)|0);
                 HEAP32[$323>>2] = $305;
                 $324 = HEAP32[3001000>>2]|0;
                 __THREW__ = 0;
                 $325 = (invoke_iiii(1417,0,($324|0),($4|0))|0);
                 $326 = __THREW__; __THREW__ = 0;
                 $327 = $326&1;
                 if ($327) {
                  break;
                 }
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return ($325|0);
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z41UnityEngine_UnityEngine_Matrix4x4_m_OrthoP22mscorlib_System_Objectffffff($agg$result,$__this,$left,$right,$bottom,$top,$zNear,$zFar) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $left = Math_fround($left);
 $right = Math_fround($right);
 $bottom = Math_fround($bottom);
 $top = Math_fround($top);
 $zNear = Math_fround($zNear);
 $zFar = Math_fround($zFar);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2799864);
 $0 = HEAP32[2799912>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2799920|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2799912>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viffffff($7|0,($agg$result|0),(+$left),(+$right),(+$bottom),(+$top),(+$zNear),(+$zFar));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z47UnityEngine_UnityEngine_Matrix4x4_m_PerspectiveP22mscorlib_System_Objectffff($agg$result,$__this,$fov,$aspect,$zNear,$zFar) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $fov = Math_fround($fov);
 $aspect = Math_fround($aspect);
 $zNear = Math_fround($zNear);
 $zFar = Math_fround($zFar);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2800040);
 $0 = HEAP32[2800088>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2800096|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2800088>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viffff($7|0,($agg$result|0),(+$fov),(+$aspect),(+$zNear),(+$zFar));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z149UnityEngine_UnityEngine_Matrix4x4_m_op_Multiply_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4S1_($agg$result,$__this,$lhs,$rhs) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $100 = 0, $101 = Math_fround(0), $102 = Math_fround(0), $103 = Math_fround(0), $104 = Math_fround(0), $105 = Math_fround(0), $106 = Math_fround(0), $107 = Math_fround(0), $108 = 0, $109 = 0, $11 = 0, $110 = Math_fround(0), $111 = Math_fround(0), $112 = Math_fround(0), $113 = 0, $114 = Math_fround(0), $115 = Math_fround(0);
 var $116 = Math_fround(0), $117 = Math_fround(0), $118 = 0, $119 = Math_fround(0), $12 = Math_fround(0), $120 = Math_fround(0), $121 = Math_fround(0), $122 = Math_fround(0), $123 = 0, $124 = Math_fround(0), $125 = Math_fround(0), $126 = Math_fround(0), $127 = Math_fround(0), $128 = 0, $129 = Math_fround(0), $13 = Math_fround(0), $130 = Math_fround(0), $131 = Math_fround(0), $132 = Math_fround(0), $133 = Math_fround(0);
 var $134 = Math_fround(0), $135 = Math_fround(0), $136 = Math_fround(0), $137 = Math_fround(0), $138 = Math_fround(0), $139 = Math_fround(0), $14 = Math_fround(0), $140 = 0, $141 = Math_fround(0), $142 = Math_fround(0), $143 = Math_fround(0), $144 = Math_fround(0), $145 = Math_fround(0), $146 = Math_fround(0), $147 = Math_fround(0), $148 = Math_fround(0), $149 = Math_fround(0), $15 = 0, $150 = Math_fround(0), $151 = Math_fround(0);
 var $152 = 0, $153 = Math_fround(0), $154 = Math_fround(0), $155 = Math_fround(0), $156 = Math_fround(0), $157 = Math_fround(0), $158 = Math_fround(0), $159 = Math_fround(0), $16 = Math_fround(0), $160 = Math_fround(0), $161 = Math_fround(0), $162 = Math_fround(0), $163 = Math_fround(0), $164 = 0, $165 = 0, $166 = Math_fround(0), $167 = Math_fround(0), $168 = 0, $169 = Math_fround(0), $17 = 0;
 var $170 = Math_fround(0), $171 = Math_fround(0), $172 = 0, $173 = Math_fround(0), $174 = Math_fround(0), $175 = Math_fround(0), $176 = 0, $177 = Math_fround(0), $178 = Math_fround(0), $179 = Math_fround(0), $18 = Math_fround(0), $180 = 0, $181 = Math_fround(0), $182 = Math_fround(0), $183 = Math_fround(0), $184 = Math_fround(0), $185 = Math_fround(0), $186 = Math_fround(0), $187 = Math_fround(0), $188 = 0;
 var $189 = Math_fround(0), $19 = Math_fround(0), $190 = Math_fround(0), $191 = Math_fround(0), $192 = Math_fround(0), $193 = Math_fround(0), $194 = Math_fround(0), $195 = Math_fround(0), $196 = 0, $197 = Math_fround(0), $198 = Math_fround(0), $199 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $200 = Math_fround(0), $201 = Math_fround(0), $202 = Math_fround(0), $203 = Math_fround(0), $204 = 0, $21 = 0;
 var $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0), $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0);
 var $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0, $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0);
 var $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0), $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = Math_fround(0), $71 = Math_fround(0), $72 = 0, $73 = Math_fround(0), $74 = Math_fround(0), $75 = Math_fround(0), $76 = 0;
 var $77 = Math_fround(0), $78 = Math_fround(0), $79 = Math_fround(0), $8 = Math_fround(0), $80 = 0, $81 = Math_fround(0), $82 = Math_fround(0), $83 = Math_fround(0), $84 = 0, $85 = Math_fround(0), $86 = Math_fround(0), $87 = Math_fround(0), $88 = Math_fround(0), $89 = Math_fround(0), $9 = 0, $90 = Math_fround(0), $91 = Math_fround(0), $92 = 0, $93 = Math_fround(0), $94 = Math_fround(0);
 var $95 = Math_fround(0), $96 = Math_fround(0), $97 = Math_fround(0), $98 = Math_fround(0), $99 = Math_fround(0), $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2800192);
 dest=$agg$result+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = Math_fround(HEAPF32[$lhs>>2]);
 $1 = Math_fround(HEAPF32[$rhs>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($lhs) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($rhs) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($lhs) + 32|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($rhs) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($lhs) + 48|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($rhs) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 + $19);
 HEAPF32[$agg$result>>2] = $20;
 $21 = (($rhs) + 16|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($0 * $22);
 $24 = (($rhs) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($4 * $25);
 $27 = Math_fround($23 + $26);
 $28 = (($rhs) + 24|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($10 * $29);
 $31 = Math_fround($27 + $30);
 $32 = (($rhs) + 28|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($16 * $33);
 $35 = Math_fround($31 + $34);
 $36 = (($agg$result) + 16|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($rhs) + 32|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($0 * $38);
 $40 = (($rhs) + 36|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($4 * $41);
 $43 = Math_fround($39 + $42);
 $44 = (($rhs) + 40|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($10 * $45);
 $47 = Math_fround($43 + $46);
 $48 = (($rhs) + 44|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($16 * $49);
 $51 = Math_fround($47 + $50);
 $52 = (($agg$result) + 32|0);
 HEAPF32[$52>>2] = $51;
 $53 = (($rhs) + 48|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($0 * $54);
 $56 = (($rhs) + 52|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($4 * $57);
 $59 = Math_fround($55 + $58);
 $60 = (($rhs) + 56|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($10 * $61);
 $63 = Math_fround($59 + $62);
 $64 = (($rhs) + 60|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($16 * $65);
 $67 = Math_fround($63 + $66);
 $68 = (($agg$result) + 48|0);
 HEAPF32[$68>>2] = $67;
 $69 = (($lhs) + 4|0);
 $70 = Math_fround(HEAPF32[$69>>2]);
 $71 = Math_fround($70 * $1);
 $72 = (($lhs) + 20|0);
 $73 = Math_fround(HEAPF32[$72>>2]);
 $74 = Math_fround($73 * $6);
 $75 = Math_fround($71 + $74);
 $76 = (($lhs) + 36|0);
 $77 = Math_fround(HEAPF32[$76>>2]);
 $78 = Math_fround($77 * $12);
 $79 = Math_fround($75 + $78);
 $80 = (($lhs) + 52|0);
 $81 = Math_fround(HEAPF32[$80>>2]);
 $82 = Math_fround($81 * $18);
 $83 = Math_fround($79 + $82);
 $84 = (($agg$result) + 4|0);
 HEAPF32[$84>>2] = $83;
 $85 = Math_fround($70 * $22);
 $86 = Math_fround($73 * $25);
 $87 = Math_fround($85 + $86);
 $88 = Math_fround($77 * $29);
 $89 = Math_fround($87 + $88);
 $90 = Math_fround($81 * $33);
 $91 = Math_fround($89 + $90);
 $92 = (($agg$result) + 20|0);
 HEAPF32[$92>>2] = $91;
 $93 = Math_fround($70 * $38);
 $94 = Math_fround($73 * $41);
 $95 = Math_fround($93 + $94);
 $96 = Math_fround($77 * $45);
 $97 = Math_fround($95 + $96);
 $98 = Math_fround($81 * $49);
 $99 = Math_fround($97 + $98);
 $100 = (($agg$result) + 36|0);
 HEAPF32[$100>>2] = $99;
 $101 = Math_fround($70 * $54);
 $102 = Math_fround($73 * $57);
 $103 = Math_fround($101 + $102);
 $104 = Math_fround($77 * $61);
 $105 = Math_fround($103 + $104);
 $106 = Math_fround($81 * $65);
 $107 = Math_fround($105 + $106);
 $108 = (($agg$result) + 52|0);
 HEAPF32[$108>>2] = $107;
 $109 = (($lhs) + 8|0);
 $110 = Math_fround(HEAPF32[$109>>2]);
 $111 = Math_fround(HEAPF32[$rhs>>2]);
 $112 = Math_fround($110 * $111);
 $113 = (($lhs) + 24|0);
 $114 = Math_fround(HEAPF32[$113>>2]);
 $115 = Math_fround(HEAPF32[$5>>2]);
 $116 = Math_fround($114 * $115);
 $117 = Math_fround($112 + $116);
 $118 = (($lhs) + 40|0);
 $119 = Math_fround(HEAPF32[$118>>2]);
 $120 = Math_fround(HEAPF32[$11>>2]);
 $121 = Math_fround($119 * $120);
 $122 = Math_fround($117 + $121);
 $123 = (($lhs) + 56|0);
 $124 = Math_fround(HEAPF32[$123>>2]);
 $125 = Math_fround(HEAPF32[$17>>2]);
 $126 = Math_fround($124 * $125);
 $127 = Math_fround($122 + $126);
 $128 = (($agg$result) + 8|0);
 HEAPF32[$128>>2] = $127;
 $129 = Math_fround(HEAPF32[$21>>2]);
 $130 = Math_fround($110 * $129);
 $131 = Math_fround(HEAPF32[$24>>2]);
 $132 = Math_fround($114 * $131);
 $133 = Math_fround($130 + $132);
 $134 = Math_fround(HEAPF32[$28>>2]);
 $135 = Math_fround($119 * $134);
 $136 = Math_fround($133 + $135);
 $137 = Math_fround(HEAPF32[$32>>2]);
 $138 = Math_fround($124 * $137);
 $139 = Math_fround($136 + $138);
 $140 = (($agg$result) + 24|0);
 HEAPF32[$140>>2] = $139;
 $141 = Math_fround(HEAPF32[$37>>2]);
 $142 = Math_fround($110 * $141);
 $143 = Math_fround(HEAPF32[$40>>2]);
 $144 = Math_fround($114 * $143);
 $145 = Math_fround($142 + $144);
 $146 = Math_fround(HEAPF32[$44>>2]);
 $147 = Math_fround($119 * $146);
 $148 = Math_fround($145 + $147);
 $149 = Math_fround(HEAPF32[$48>>2]);
 $150 = Math_fround($124 * $149);
 $151 = Math_fround($148 + $150);
 $152 = (($agg$result) + 40|0);
 HEAPF32[$152>>2] = $151;
 $153 = Math_fround(HEAPF32[$53>>2]);
 $154 = Math_fround($110 * $153);
 $155 = Math_fround(HEAPF32[$56>>2]);
 $156 = Math_fround($114 * $155);
 $157 = Math_fround($154 + $156);
 $158 = Math_fround(HEAPF32[$60>>2]);
 $159 = Math_fround($119 * $158);
 $160 = Math_fround($157 + $159);
 $161 = Math_fround(HEAPF32[$64>>2]);
 $162 = Math_fround($124 * $161);
 $163 = Math_fround($160 + $162);
 $164 = (($agg$result) + 56|0);
 HEAPF32[$164>>2] = $163;
 $165 = (($lhs) + 12|0);
 $166 = Math_fround(HEAPF32[$165>>2]);
 $167 = Math_fround($166 * $111);
 $168 = (($lhs) + 28|0);
 $169 = Math_fround(HEAPF32[$168>>2]);
 $170 = Math_fround($169 * $115);
 $171 = Math_fround($167 + $170);
 $172 = (($lhs) + 44|0);
 $173 = Math_fround(HEAPF32[$172>>2]);
 $174 = Math_fround($173 * $120);
 $175 = Math_fround($171 + $174);
 $176 = (($lhs) + 60|0);
 $177 = Math_fround(HEAPF32[$176>>2]);
 $178 = Math_fround($177 * $125);
 $179 = Math_fround($175 + $178);
 $180 = (($agg$result) + 12|0);
 HEAPF32[$180>>2] = $179;
 $181 = Math_fround($166 * $129);
 $182 = Math_fround($169 * $131);
 $183 = Math_fround($181 + $182);
 $184 = Math_fround($173 * $134);
 $185 = Math_fround($183 + $184);
 $186 = Math_fround($177 * $137);
 $187 = Math_fround($185 + $186);
 $188 = (($agg$result) + 28|0);
 HEAPF32[$188>>2] = $187;
 $189 = Math_fround($166 * $141);
 $190 = Math_fround($169 * $143);
 $191 = Math_fround($189 + $190);
 $192 = Math_fround($173 * $146);
 $193 = Math_fround($191 + $192);
 $194 = Math_fround($177 * $149);
 $195 = Math_fround($193 + $194);
 $196 = (($agg$result) + 44|0);
 HEAPF32[$196>>2] = $195;
 $197 = Math_fround($166 * $153);
 $198 = Math_fround($169 * $155);
 $199 = Math_fround($197 + $198);
 $200 = Math_fround($173 * $158);
 $201 = Math_fround($199 + $200);
 $202 = Math_fround($177 * $161);
 $203 = Math_fround($201 + $202);
 $204 = (($agg$result) + 60|0);
 HEAPF32[$204>>2] = $203;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z145UnityEngine_UnityEngine_Matrix4x4_m_op_Multiply_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Vector4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector4($agg$result,$__this,$lhs,$v) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $lhs = $lhs|0;
 $v = $v|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $21 = 0, $22 = Math_fround(0), $23 = Math_fround(0), $24 = 0, $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = Math_fround(0), $34 = Math_fround(0), $35 = Math_fround(0), $36 = 0, $37 = 0, $38 = Math_fround(0), $39 = Math_fround(0), $4 = Math_fround(0), $40 = 0, $41 = Math_fround(0), $42 = Math_fround(0), $43 = Math_fround(0), $44 = 0;
 var $45 = Math_fround(0), $46 = Math_fround(0), $47 = Math_fround(0), $48 = 0, $49 = Math_fround(0), $5 = 0, $50 = Math_fround(0), $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = Math_fround(0), $55 = Math_fround(0), $56 = 0, $57 = Math_fround(0), $58 = Math_fround(0), $59 = Math_fround(0), $6 = Math_fround(0), $60 = 0, $61 = Math_fround(0), $62 = Math_fround(0);
 var $63 = Math_fround(0), $64 = 0, $65 = Math_fround(0), $66 = Math_fround(0), $67 = Math_fround(0), $68 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2800240);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $0 = Math_fround(HEAPF32[$lhs>>2]);
 $1 = Math_fround(HEAPF32[$v>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($lhs) + 16|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($v) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($lhs) + 32|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($v) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($lhs) + 48|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($v) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 + $19);
 HEAPF32[$agg$result>>2] = $20;
 $21 = (($lhs) + 4|0);
 $22 = Math_fround(HEAPF32[$21>>2]);
 $23 = Math_fround($22 * $1);
 $24 = (($lhs) + 20|0);
 $25 = Math_fround(HEAPF32[$24>>2]);
 $26 = Math_fround($25 * $6);
 $27 = Math_fround($23 + $26);
 $28 = (($lhs) + 36|0);
 $29 = Math_fround(HEAPF32[$28>>2]);
 $30 = Math_fround($29 * $12);
 $31 = Math_fround($27 + $30);
 $32 = (($lhs) + 52|0);
 $33 = Math_fround(HEAPF32[$32>>2]);
 $34 = Math_fround($33 * $18);
 $35 = Math_fround($31 + $34);
 $36 = (($agg$result) + 4|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($lhs) + 8|0);
 $38 = Math_fround(HEAPF32[$37>>2]);
 $39 = Math_fround($38 * $1);
 $40 = (($lhs) + 24|0);
 $41 = Math_fround(HEAPF32[$40>>2]);
 $42 = Math_fround($41 * $6);
 $43 = Math_fround($39 + $42);
 $44 = (($lhs) + 40|0);
 $45 = Math_fround(HEAPF32[$44>>2]);
 $46 = Math_fround($45 * $12);
 $47 = Math_fround($43 + $46);
 $48 = (($lhs) + 56|0);
 $49 = Math_fround(HEAPF32[$48>>2]);
 $50 = Math_fround($49 * $18);
 $51 = Math_fround($47 + $50);
 $52 = (($agg$result) + 8|0);
 HEAPF32[$52>>2] = $51;
 $53 = (($lhs) + 12|0);
 $54 = Math_fround(HEAPF32[$53>>2]);
 $55 = Math_fround($54 * $1);
 $56 = (($lhs) + 28|0);
 $57 = Math_fround(HEAPF32[$56>>2]);
 $58 = Math_fround($57 * $6);
 $59 = Math_fround($55 + $58);
 $60 = (($lhs) + 44|0);
 $61 = Math_fround(HEAPF32[$60>>2]);
 $62 = Math_fround($61 * $12);
 $63 = Math_fround($59 + $62);
 $64 = (($lhs) + 60|0);
 $65 = Math_fround(HEAPF32[$64>>2]);
 $66 = Math_fround($65 * $18);
 $67 = Math_fround($63 + $66);
 $68 = (($agg$result) + 12|0);
 HEAPF32[$68>>2] = $67;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z139UnityEngine_UnityEngine_Matrix4x4_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4S1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B5_0$0 = 0, $L_1 = 0, $L_11 = 0, $L_13 = 0, $L_16 = 0, $L_16$byval_copy = 0, $L_18 = 0, $L_18$byval_copy = 0, $L_3 = 0, $L_6 = 0;
 var $L_8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $L_18$byval_copy = sp + 152|0;
 $L_16$byval_copy = sp + 136|0;
 $_stackTraceSentry = sp + 128|0;
 $L_1 = sp + 112|0;
 $L_3 = sp + 96|0;
 $L_6 = sp + 80|0;
 $L_8 = sp + 48|0;
 $L_11 = sp + 32|0;
 $L_13 = sp + 16|0;
 $L_16 = sp;
 $L_18 = sp + 64|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2800288);
 __THREW__ = 0;
 invoke_viii(753,($L_1|0),($lhs|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_viii(753,($L_3|0),($rhs|0),0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_1+12>>2]|0;
   ;HEAP32[$L_18$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_18$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_18$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$L_18$byval_copy+12>>2]=HEAP32[$L_3+12>>2]|0;
   $4 = (invoke_iiii(1403,0,($L_16$byval_copy|0),($L_18$byval_copy|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if (!($4)) {
     $G_B5_0$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B5_0$0|0);
    }
    __THREW__ = 0;
    invoke_viii(753,($L_6|0),($lhs|0),1);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_viii(753,($L_8|0),($rhs|0),1);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_6+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_6+12>>2]|0;
      ;HEAP32[$L_18$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_18$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_18$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_18$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
      $13 = (invoke_iiii(1403,0,($L_16$byval_copy|0),($L_18$byval_copy|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       if (!($13)) {
        $G_B5_0$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($G_B5_0$0|0);
       }
       __THREW__ = 0;
       invoke_viii(753,($L_11|0),($lhs|0),2);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if (!($17)) {
        __THREW__ = 0;
        invoke_viii(753,($L_13|0),($rhs|0),2);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_11+12>>2]|0;
         ;HEAP32[$L_18$byval_copy+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$L_18$byval_copy+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$L_18$byval_copy+8>>2]=HEAP32[$L_13+8>>2]|0;HEAP32[$L_18$byval_copy+12>>2]=HEAP32[$L_13+12>>2]|0;
         $20 = (invoke_iiii(1403,0,($L_16$byval_copy|0),($L_18$byval_copy|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          if (!($20)) {
           $G_B5_0$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($G_B5_0$0|0);
          }
          __THREW__ = 0;
          invoke_viii(753,($L_16|0),($lhs|0),3);
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           __THREW__ = 0;
           invoke_viii(753,($L_18|0),($rhs|0),3);
           $25 = __THREW__; __THREW__ = 0;
           $26 = $25&1;
           if (!($26)) {
            __THREW__ = 0;
            ;HEAP32[$L_16$byval_copy+0>>2]=HEAP32[$L_16+0>>2]|0;HEAP32[$L_16$byval_copy+4>>2]=HEAP32[$L_16+4>>2]|0;HEAP32[$L_16$byval_copy+8>>2]=HEAP32[$L_16+8>>2]|0;HEAP32[$L_16$byval_copy+12>>2]=HEAP32[$L_16+12>>2]|0;
            ;HEAP32[$L_18$byval_copy+0>>2]=HEAP32[$L_18+0>>2]|0;HEAP32[$L_18$byval_copy+4>>2]=HEAP32[$L_18+4>>2]|0;HEAP32[$L_18$byval_copy+8>>2]=HEAP32[$L_18+8>>2]|0;HEAP32[$L_18$byval_copy+12>>2]=HEAP32[$L_18+12>>2]|0;
            $27 = (invoke_iiii(1403,0,($L_16$byval_copy|0),($L_18$byval_copy|0))|0);
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             $G_B5_0$0 = $27;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($G_B5_0$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z133UnityEngine_UnityEngine_Vector4_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_Vector4P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4S1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $2 = Math_fround(0), $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $L_0$byval_copy = 0, $_stackTraceSentry = 0, $lhs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_0$byval_copy = sp + 40|0;
 $lhs$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2806632);
 __THREW__ = 0;
 ;HEAP32[$lhs$byval_copy+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$lhs$byval_copy+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$lhs$byval_copy+8>>2]=HEAP32[$lhs+8>>2]|0;HEAP32[$lhs$byval_copy+12>>2]=HEAP32[$lhs+12>>2]|0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$rhs+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$rhs+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$rhs+8>>2]|0;HEAP32[$L_0$byval_copy+12>>2]=HEAP32[$rhs+12>>2]|0;
 invoke_viiii(235,($L_0|0),0,($lhs$byval_copy|0),($L_0$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_0$byval_copy+12>>2]=HEAP32[$L_0+12>>2]|0;
 $2 = (Math_fround(+(invoke_fii(40,0,($L_0$byval_copy|0)))));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = $2 < Math_fround(9.99999943962492920946E-11);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z141UnityEngine_UnityEngine_Matrix4x4_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4S1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $lhs$byval_copy = 0, $rhs$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $rhs$byval_copy = sp + 72|0;
 $lhs$byval_copy = sp;
 $_stackTraceSentry = sp + 64|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2800336);
 __THREW__ = 0;
 dest=$lhs$byval_copy+0|0; src=$lhs+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$rhs$byval_copy+0|0; src=$rhs+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $0 = (invoke_iiii(1384,0,($lhs$byval_copy|0),($rhs$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = $0 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN12FuncInvoker2I28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFfPviiES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$1,$4)));
 HEAPF32[$ret>>2] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN14ActionInvoker3I27mscorlib_System_Int32TraitsS0_28mscorlib_System_SingleTraitsE6InvokeEPFvPviifES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 FUNCTION_TABLE_viiif[$action & 15]($obj,$1,$4,$7);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I39UnityEngine_UnityEngine_Matrix4x4TraitsS0_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvS2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $tmpcast$byval_copy = sp + 64|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 dest=$tmpcast$byval_copy+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits39UnityEngine_UnityEngine_Matrix4x4Traits17VoidPointerTraitsE6InvokeEPFbPv33UnityEngine_UnityEngine_Matrix4x4S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 64|0;
 $ret = sp + 128|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 dest=$0+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$3)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker0I39UnityEngine_UnityEngine_Matrix4x4TraitsE6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector4Traits27mscorlib_System_Int32TraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector4PviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2807040,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits37UnityEngine_UnityEngine_Vector4TraitsE6InvokeEPFvPvi31UnityEngine_UnityEngine_Vector4ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I39UnityEngine_UnityEngine_Matrix4x4Traits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4Pv31UnityEngine_UnityEngine_Vector3ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast$byval_copy = sp + 64|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN14ActionInvoker3I37UnityEngine_UnityEngine_Vector3Traits40UnityEngine_UnityEngine_QuaternionTraitsS0_E6InvokeEPFvPv31UnityEngine_UnityEngine_Vector334UnityEngine_UnityEngine_QuaternionS4_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast$byval_copy = sp + 56|0;
 $$byval_copy1 = sp;
 $$byval_copy = sp + 16|0;
 $0 = sp + 28|0;
 $1 = sp + 40|0;
 $2 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$4+12>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$1+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$6+8>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$$byval_copy,$$byval_copy1,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker3I39UnityEngine_UnityEngine_Matrix4x4Traits37UnityEngine_UnityEngine_Vector3Traits40UnityEngine_UnityEngine_QuaternionTraitsS1_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4Pv31UnityEngine_UnityEngine_Vector334UnityEngine_UnityEngine_QuaternionS6_ES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $tmpcast$byval_copy = sp + 128|0;
 $$byval_copy1 = sp;
 $$byval_copy = sp + 16|0;
 $ret = sp + 32|0;
 $0 = sp + 96|0;
 $1 = sp + 112|0;
 $2 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$2+8>>2]|0;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$1+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$4+12>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy1+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy1+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$$byval_copy1+12>>2]=HEAP32[$1+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$6+8>>2]|0;
 FUNCTION_TABLE_viiiii[$func & 255]($ret,$obj,$$byval_copy,$$byval_copy1,$tmpcast$byval_copy);
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker3I39UnityEngine_UnityEngine_Matrix4x4Traits17VoidPointerTraitsS1_S1_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvS4_S4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_viiiii[$func & 255]($ret,$obj,$0,$2,$4);
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker6I39UnityEngine_UnityEngine_Matrix4x4Traits28mscorlib_System_SingleTraitsS1_S1_S1_S1_S1_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvffffffES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = Math_fround(0), $17 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $ret = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($args) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = Math_fround(HEAPF32[$12>>2]);
 $14 = (($args) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = Math_fround(HEAPF32[$15>>2]);
 FUNCTION_TABLE_viiffffff[$func & 1]($ret,$obj,$1,$4,$7,$10,$13,$16);
 $17 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($17|0);
}
function __ZN12FuncInvoker4I39UnityEngine_UnityEngine_Matrix4x4Traits28mscorlib_System_SingleTraitsS1_S1_S1_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvffffES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = Math_fround(HEAPF32[$9>>2]);
 FUNCTION_TABLE_viiffff[$func & 1]($ret,$obj,$1,$4,$7,$10);
 $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN12FuncInvoker2I39UnityEngine_UnityEngine_Matrix4x4TraitsS0_S0_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvS2_S2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $tmpcast$byval_copy = sp + 192|0;
 $$byval_copy = sp;
 $ret = sp + 64|0;
 $0 = sp + 128|0;
 $1 = HEAP32[$args>>2]|0;
 dest=$0+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$tmpcast$byval_copy+0|0; src=$3+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2802392,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector4Traits39UnityEngine_UnityEngine_Matrix4x4TraitsS0_E6InvokeEPF31UnityEngine_UnityEngine_Vector4Pv33UnityEngine_UnityEngine_Matrix4x4S3_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $tmpcast$byval_copy = sp + 144|0;
 $$byval_copy = sp;
 $ret = sp + 64|0;
 $0 = sp + 80|0;
 $1 = HEAP32[$args>>2]|0;
 dest=$0+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2807040,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits39UnityEngine_UnityEngine_Matrix4x4TraitsS1_E6InvokeEPFbPv33UnityEngine_UnityEngine_Matrix4x4S4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $tmpcast$byval_copy = sp + 128|0;
 $$byval_copy = sp;
 $ret = sp + 192|0;
 $0 = sp + 64|0;
 $1 = HEAP32[$args>>2]|0;
 dest=$0+0|0; src=$1+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 dest=$$byval_copy+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 dest=$tmpcast$byval_copy+0|0; src=$3+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z64UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2791992)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z122UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_InverseP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z124UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_TransposeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z121UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_InvertP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_get_isIdentityP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z118UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_TRSP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z106UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_OrthoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z112UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_PerspectiveP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z38UnityEngine_UnityEngine_Bounds_m__ctorP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3S1_($__this,$center,$size) {
 $__this = $__this|0;
 $center = $center|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $L_1 = 0, $_stackTraceSentry = 0, $size$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $size$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802528);
 ;HEAP32[$__this+0>>2]=HEAP32[$center+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$center+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$center+8>>2]|0;
 __THREW__ = 0;
 ;HEAP32[$size$byval_copy+0>>2]=HEAP32[$size+0>>2]|0;HEAP32[$size$byval_copy+4>>2]=HEAP32[$size+4>>2]|0;HEAP32[$size$byval_copy+8>>2]=HEAP32[$size+8>>2]|0;
 invoke_viiif(2,($L_1|0),0,($size$byval_copy|0),0.5);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  ;HEAP32[$2+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$L_1+8>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44UnityEngine_UnityEngine_Bounds_m_GetHashCodeP30UnityEngine_UnityEngine_Bounds($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 48|0;
 $V_0 = sp;
 $V_1 = sp + 12|0;
 $L_0 = sp + 24|0;
 $L_2 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802576);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2082,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  ;HEAP32[$V_0+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_0+8>>2]|0;
  __THREW__ = 0;
  $2 = (invoke_ii(2610,($V_0|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_vii(2086,($L_2|0),($__this|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    ;HEAP32[$V_1+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_2+8>>2]|0;
    __THREW__ = 0;
    $7 = (invoke_ii(2610,($V_1|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = $7 << 2;
     $11 = $10 ^ $2;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($11|0);
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Bounds_m_get_centerP30UnityEngine_UnityEngine_Bounds($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802672);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$__this+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z44UnityEngine_UnityEngine_Bounds_m_get_extentsP30UnityEngine_UnityEngine_Bounds($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802864);
 $0 = (($__this) + 12|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Bounds_m_EqualsP30UnityEngine_UnityEngine_BoundsP22mscorlib_System_Object($__this,$other) {
 $__this = $__this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_10 = 0, $L_11 = 0;
 var $L_4 = 0, $L_5 = 0, $L_6 = 0, $L_9 = 0, $V_0 = 0, $V_1 = 0, $V_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $_stackTraceSentry = sp + 120|0;
 $V_0 = sp + 96|0;
 $V_1 = sp + 84|0;
 $V_2 = sp + 72|0;
 $L_4 = sp + 60|0;
 $L_5 = sp + 48|0;
 $L_6 = sp + 24|0;
 $L_9 = sp + 12|0;
 $L_10 = sp;
 $L_11 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802624);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;HEAP32[$V_0+16>>2]=0|0;HEAP32[$V_0+20>>2]=0|0;
 ;HEAP32[$V_1+0>>2]=0|0;HEAP32[$V_1+4>>2]=0|0;HEAP32[$V_1+8>>2]=0|0;
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;
 __THREW__ = 0;
 (invoke_ii(2996,(2806160|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2735,($other|0),(2806160|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)==(0|0);
   if ($5) {
    $$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2806160|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_iii(2776,($other|0),(2806160|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     ;HEAP32[$V_0+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$V_0+16>>2]=HEAP32[$10+16>>2]|0;HEAP32[$V_0+20>>2]=HEAP32[$10+20>>2]|0;
     __THREW__ = 0;
     invoke_vii(2082,($L_4|0),($__this|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      ;HEAP32[$V_1+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$V_1+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$V_1+8>>2]=HEAP32[$L_4+8>>2]|0;
      __THREW__ = 0;
      invoke_vii(2082,($L_5|0),($V_0|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       ;HEAP32[$L_6+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$L_5+8>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2792272|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        __THREW__ = 0;
        $19 = (invoke_iii(2724,(2792272|0),($L_6|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         $22 = (invoke_iii(1214,($V_1|0),($19|0))|0);
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          if (!($22)) {
           $$0 = 0;
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return ($$0|0);
          }
          __THREW__ = 0;
          invoke_vii(2086,($L_9|0),($__this|0));
          $25 = __THREW__; __THREW__ = 0;
          $26 = $25&1;
          if (!($26)) {
           ;HEAP32[$V_2+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_9+8>>2]|0;
           __THREW__ = 0;
           invoke_vii(2086,($L_10|0),($V_0|0));
           $27 = __THREW__; __THREW__ = 0;
           $28 = $27&1;
           if (!($28)) {
            ;HEAP32[$L_11+0>>2]=HEAP32[$L_10+0>>2]|0;HEAP32[$L_11+4>>2]=HEAP32[$L_10+4>>2]|0;HEAP32[$L_11+8>>2]=HEAP32[$L_10+8>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2792272|0))|0);
            $29 = __THREW__; __THREW__ = 0;
            $30 = $29&1;
            if (!($30)) {
             __THREW__ = 0;
             $31 = (invoke_iii(2724,(2792272|0),($L_11|0))|0);
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if (!($33)) {
              __THREW__ = 0;
              $34 = (invoke_iii(1214,($V_2|0),($31|0))|0);
              $35 = __THREW__; __THREW__ = 0;
              $36 = $35&1;
              if (!($36)) {
               $$0 = $34;
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return ($$0|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z43UnityEngine_UnityEngine_Bounds_m_set_centerP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802720);
 ;HEAP32[$__this+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$value+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z41UnityEngine_UnityEngine_Bounds_m_get_sizeP30UnityEngine_UnityEngine_Bounds($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802768);
 $0 = (($__this) + 12|0);
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 invoke_viiif(2,($agg$result|0),0,($$byval_copy|0),2.0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z41UnityEngine_UnityEngine_Bounds_m_set_sizeP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $L_1 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_1 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802816);
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;
 invoke_viiif(2,($L_1|0),0,($value$byval_copy|0),0.5);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  $2 = (($__this) + 12|0);
  ;HEAP32[$2+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$L_1+8>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z44UnityEngine_UnityEngine_Bounds_m_set_extentsP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802912);
 $0 = (($__this) + 12|0);
 ;HEAP32[$0+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$value+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z40UnityEngine_UnityEngine_Bounds_m_get_minP30UnityEngine_UnityEngine_Bounds($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $L_0$byval_copy = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_1$byval_copy = sp + 40|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 $L_1 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2802960);
 __THREW__ = 0;
 invoke_vii(2082,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2086,($L_1|0),($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   invoke_viiii(223,($agg$result|0),0,($L_0$byval_copy|0),($L_1$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z40UnityEngine_UnityEngine_Bounds_m_set_minP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $L_0$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $L_0$byval_copy = sp + 28|0;
 $value$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803008);
 __THREW__ = 0;
 invoke_vii(2090,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
 invoke_viii(762,($__this|0),($value$byval_copy|0),($L_0$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z40UnityEngine_UnityEngine_Bounds_m_get_maxP30UnityEngine_UnityEngine_Bounds($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $L_0$byval_copy = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_1$byval_copy = sp + 40|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 $L_1 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803056);
 __THREW__ = 0;
 invoke_vii(2082,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2086,($L_1|0),($__this|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   invoke_viiii(222,($agg$result|0),0,($L_0$byval_copy|0),($L_1$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_Bounds_m_SetMinMaxP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3S1_($__this,$min,$max) {
 $__this = $__this|0;
 $min = $min|0;
 $max = $max|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_2 = 0, $L_3 = 0, $L_4 = 0, $L_4$byval_copy = 0, $_stackTraceSentry = 0;
 var $min$byval_copy1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_4$byval_copy = sp + 64|0;
 $min$byval_copy1 = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 $L_2 = sp + 28|0;
 $L_3 = sp + 40|0;
 $L_4 = sp + 52|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803152);
 __THREW__ = 0;
 ;HEAP32[$min$byval_copy1+0>>2]=HEAP32[$max+0>>2]|0;HEAP32[$min$byval_copy1+4>>2]=HEAP32[$max+4>>2]|0;HEAP32[$min$byval_copy1+8>>2]=HEAP32[$max+8>>2]|0;
 ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$min+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$min+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$min+8>>2]|0;
 invoke_viiii(223,($L_0|0),0,($min$byval_copy1|0),($L_4$byval_copy|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
  invoke_viiif(2,($L_2|0),0,($L_4$byval_copy|0),0.5);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;
   invoke_vii(2087,($__this|0),($L_4$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vii(2086,($L_3|0),($__this|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     ;HEAP32[$min$byval_copy1+0>>2]=HEAP32[$min+0>>2]|0;HEAP32[$min$byval_copy1+4>>2]=HEAP32[$min+4>>2]|0;HEAP32[$min$byval_copy1+8>>2]=HEAP32[$min+8>>2]|0;
     ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;
     invoke_viiii(222,($L_4|0),0,($min$byval_copy1|0),($L_4$byval_copy|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;
      invoke_vii(2083,($__this|0),($L_4$byval_copy|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z40UnityEngine_UnityEngine_Bounds_m_set_maxP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $L_0$byval_copy = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $value$byval_copy = sp + 28|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803104);
 __THREW__ = 0;
 invoke_vii(2088,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;
 invoke_viii(762,($__this|0),($L_0$byval_copy|0),($value$byval_copy|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z97UnityEngine_UnityEngine_Bounds_m_Encapsulate_mscorlib_System_Void_UnityEngine_UnityEngine_Vector3P30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$point) {
 $__this = $__this|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $L_1$byval_copy = 0, $L_2 = 0, $L_3 = 0, $L_3$byval_copy = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_3$byval_copy = sp + 64|0;
 $L_1$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 $L_1 = sp + 28|0;
 $L_2 = sp + 40|0;
 $L_3 = sp + 52|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803200);
 __THREW__ = 0;
 invoke_vii(2088,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
  ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$point+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$point+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$point+8>>2]|0;
  invoke_viiii(220,($L_1|0),0,($L_1$byval_copy|0),($L_3$byval_copy|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   invoke_vii(2090,($L_2|0),($__this|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;
    ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$point+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$point+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$point+8>>2]|0;
    invoke_viiii(221,($L_3|0),0,($L_1$byval_copy|0),($L_3$byval_copy|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
     ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;
     invoke_viii(762,($__this|0),($L_1$byval_copy|0),($L_3$byval_copy|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z96UnityEngine_UnityEngine_Bounds_m_Encapsulate_mscorlib_System_Void_UnityEngine_UnityEngine_BoundsP30UnityEngine_UnityEngine_BoundsS_($__this,$bounds) {
 $__this = $__this|0;
 $bounds = $bounds|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0;
 var $L_2 = 0, $L_3 = 0, $L_3$byval_copy = 0, $L_4 = 0, $L_5 = 0, $L_5$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $L_5$byval_copy = sp + 88|0;
 $L_3$byval_copy = sp + 76|0;
 $_stackTraceSentry = sp + 72|0;
 $L_0 = sp + 60|0;
 $L_1 = sp + 48|0;
 $L_2 = sp + 24|0;
 $L_3 = sp + 12|0;
 $L_4 = sp;
 $L_5 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803248);
 __THREW__ = 0;
 invoke_vii(2082,($L_0|0),($bounds|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2086,($L_1|0),($bounds|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
   ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   invoke_viiii(223,($L_2|0),0,($L_3$byval_copy|0),($L_5$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;
    invoke_vii(2092,($__this|0),($L_5$byval_copy|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     invoke_vii(2082,($L_3|0),($bounds|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vii(2086,($L_4|0),($bounds|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;
       ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;
       invoke_viiii(222,($L_5|0),0,($L_3$byval_copy|0),($L_5$byval_copy|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        __THREW__ = 0;
        ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;
        invoke_vii(2092,($__this|0),($L_5$byval_copy|0));
        $14 = __THREW__; __THREW__ = 0;
        $15 = $14&1;
        if (!($15)) {
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch()|0;
 $17 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($16|0);
 // unreachable;
}
function __Z83UnityEngine_UnityEngine_Bounds_m_Expand_mscorlib_System_Void_mscorlib_System_SingleP30UnityEngine_UnityEngine_Boundsf($__this,$amount) {
 $__this = $__this|0;
 $amount = Math_fround($amount);
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_4 = 0, $L_4$byval_copy = 0, $L_5 = 0, $L_6 = 0, $L_6$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_6$byval_copy = sp + 52|0;
 $L_4$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_4 = sp + 16|0;
 $L_5 = sp + 28|0;
 $L_6 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803296);
 $0 = Math_fround($amount * Math_fround(0.5));
 __THREW__ = 0;
 invoke_vii(2086,($L_4|0),($__this|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  ;HEAP32[$L_5+0>>2]=0|0;HEAP32[$L_5+4>>2]=0|0;HEAP32[$L_5+8>>2]=0|0;
  __THREW__ = 0;
  invoke_vifff(4,($L_5|0),(+$0),(+$0),(+$0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;
   ;HEAP32[$L_6$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_6$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_6$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;
   invoke_viiii(222,($L_6|0),0,($L_4$byval_copy|0),($L_6$byval_copy|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    ;HEAP32[$L_6$byval_copy+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$L_6$byval_copy+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$L_6$byval_copy+8>>2]=HEAP32[$L_6+8>>2]|0;
    invoke_vii(2087,($__this|0),($L_6$byval_copy|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
}
function __Z92UnityEngine_UnityEngine_Bounds_m_Expand_mscorlib_System_Void_UnityEngine_UnityEngine_Vector3P30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$amount) {
 $__this = $__this|0;
 $amount = $amount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_2 = 0, $L_2$byval_copy = 0, $L_4 = 0, $L_5 = 0, $L_5$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_5$byval_copy = sp + 52|0;
 $L_2$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_2 = sp + 16|0;
 $L_4 = sp + 28|0;
 $L_5 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803344);
 __THREW__ = 0;
 invoke_vii(2086,($L_2|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$amount+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$amount+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$amount+8>>2]|0;
  invoke_viiif(2,($L_4|0),0,($L_5$byval_copy|0),0.5);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_2$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_2$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_2$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;
   ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;
   invoke_viiii(222,($L_5|0),0,($L_2$byval_copy|0),($L_5$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    ;HEAP32[$L_5$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_5$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_5$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;
    invoke_vii(2087,($__this|0),($L_5$byval_copy|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z43UnityEngine_UnityEngine_Bounds_m_IntersectsP30UnityEngine_UnityEngine_BoundsS_($__this,$bounds) {
 $__this = $__this|0;
 $bounds = $bounds|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = Math_fround(0), $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = Math_fround(0), $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = Math_fround(0), $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = Math_fround(0), $47 = 0, $48 = 0, $49 = 0, $5 = Math_fround(0), $50 = Math_fround(0), $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B7_0$0 = 0, $L_0 = 0, $L_10 = 0, $L_12 = 0, $L_14 = 0, $L_16 = 0, $L_18 = 0, $L_2 = 0;
 var $L_20 = 0, $L_22 = 0, $L_4 = 0, $L_6 = 0, $L_8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $_stackTraceSentry = sp + 144|0;
 $L_0 = sp + 132|0;
 $L_2 = sp + 120|0;
 $L_4 = sp + 108|0;
 $L_6 = sp + 96|0;
 $L_8 = sp + 84|0;
 $L_10 = sp + 72|0;
 $L_12 = sp + 48|0;
 $L_14 = sp + 36|0;
 $L_16 = sp + 24|0;
 $L_18 = sp + 12|0;
 $L_20 = sp;
 $L_22 = sp + 60|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803392);
 __THREW__ = 0;
 invoke_vii(2088,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = Math_fround(HEAPF32[$L_0>>2]);
  __THREW__ = 0;
  invoke_vii(2090,($L_2|0),($bounds|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = Math_fround(HEAPF32[$L_2>>2]);
   $6 = $2 > $5;
   if ($6) {
    $G_B7_0$0 = 0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($G_B7_0$0|0);
   }
   __THREW__ = 0;
   invoke_vii(2090,($L_4|0),($__this|0));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = Math_fround(HEAPF32[$L_4>>2]);
    __THREW__ = 0;
    invoke_vii(2088,($L_6|0),($bounds|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = Math_fround(HEAPF32[$L_6>>2]);
     $15 = $11 < $14;
     if ($15) {
      $G_B7_0$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($G_B7_0$0|0);
     }
     __THREW__ = 0;
     invoke_vii(2088,($L_8|0),($__this|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      $18 = (($L_8) + 4|0);
      $19 = Math_fround(HEAPF32[$18>>2]);
      __THREW__ = 0;
      invoke_vii(2090,($L_10|0),($bounds|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       $22 = (($L_10) + 4|0);
       $23 = Math_fround(HEAPF32[$22>>2]);
       $24 = $19 > $23;
       if ($24) {
        $G_B7_0$0 = 0;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($G_B7_0$0|0);
       }
       __THREW__ = 0;
       invoke_vii(2090,($L_12|0),($__this|0));
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        $27 = (($L_12) + 4|0);
        $28 = Math_fround(HEAPF32[$27>>2]);
        __THREW__ = 0;
        invoke_vii(2088,($L_14|0),($bounds|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         $31 = (($L_14) + 4|0);
         $32 = Math_fround(HEAPF32[$31>>2]);
         $33 = $28 < $32;
         if ($33) {
          $G_B7_0$0 = 0;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return ($G_B7_0$0|0);
         }
         __THREW__ = 0;
         invoke_vii(2088,($L_16|0),($__this|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if (!($35)) {
          $36 = (($L_16) + 8|0);
          $37 = Math_fround(HEAPF32[$36>>2]);
          __THREW__ = 0;
          invoke_vii(2090,($L_18|0),($bounds|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if (!($39)) {
           $40 = (($L_18) + 8|0);
           $41 = Math_fround(HEAPF32[$40>>2]);
           $42 = $37 > $41;
           if ($42) {
            $G_B7_0$0 = 0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($G_B7_0$0|0);
           }
           __THREW__ = 0;
           invoke_vii(2090,($L_20|0),($__this|0));
           $43 = __THREW__; __THREW__ = 0;
           $44 = $43&1;
           if (!($44)) {
            $45 = (($L_20) + 8|0);
            $46 = Math_fround(HEAPF32[$45>>2]);
            __THREW__ = 0;
            invoke_vii(2088,($L_22|0),($bounds|0));
            $47 = __THREW__; __THREW__ = 0;
            $48 = $47&1;
            if (!($48)) {
             $49 = (($L_22) + 8|0);
             $50 = Math_fround(HEAPF32[$49>>2]);
             $51 = !($46 < $50);
             $G_B7_0$0 = $51;
             __ZN16StackTraceSentryD2Ev(0);
             STACKTOP = sp;return ($G_B7_0$0|0);
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z50UnityEngine_UnityEngine_Bounds_m_Internal_ContainsP22mscorlib_System_Object30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$m,$point) {
 $__this = $__this|0;
 $m = $m|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803440);
 __THREW__ = 0;
 $0 = (invoke_iiii(1391,0,($m|0),($point|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z64UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_ContainsP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_BoundsP31UnityEngine_UnityEngine_Vector3($__this,$m,$point) {
 $__this = $__this|0;
 $m = $m|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803488);
 $0 = HEAP32[2803536>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2803544|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2803536>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($m|0),($point|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z41UnityEngine_UnityEngine_Bounds_m_ContainsP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$point) {
 $__this = $__this|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, $point$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $point$byval_copy = sp + 28|0;
 $__this$byval_copy = sp;
 $_stackTraceSentry = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803640);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;HEAP32[$__this$byval_copy+16>>2]=HEAP32[$__this+16>>2]|0;HEAP32[$__this$byval_copy+20>>2]=HEAP32[$__this+20>>2]|0;
 ;HEAP32[$point$byval_copy+0>>2]=HEAP32[$point+0>>2]|0;HEAP32[$point$byval_copy+4>>2]=HEAP32[$point+4>>2]|0;HEAP32[$point$byval_copy+8>>2]=HEAP32[$point+8>>2]|0;
 $0 = (invoke_iiii(1389,0,($__this$byval_copy|0),($point$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z53UnityEngine_UnityEngine_Bounds_m_Internal_SqrDistanceP22mscorlib_System_Object30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$m,$point) {
 $__this = $__this|0;
 $m = $m|0;
 $point = $point|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803688);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fiii(12,0,($m|0),($point|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($0));
 }
 return Math_fround(0);
}
function __Z67UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_SqrDistanceP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_BoundsP31UnityEngine_UnityEngine_Vector3($__this,$m,$point) {
 $__this = $__this|0;
 $m = $m|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803736);
 $0 = HEAP32[2803784>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2803792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2803784>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fii($7|0,($m|0),($point|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z44UnityEngine_UnityEngine_Bounds_m_SqrDistanceP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($__this,$point) {
 $__this = $__this|0;
 $point = $point|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $__this$byval_copy = 0, $_stackTraceSentry = 0, $point$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $point$byval_copy = sp + 28|0;
 $__this$byval_copy = sp;
 $_stackTraceSentry = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803896);
 __THREW__ = 0;
 ;HEAP32[$__this$byval_copy+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$__this$byval_copy+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$__this$byval_copy+8>>2]=HEAP32[$__this+8>>2]|0;HEAP32[$__this$byval_copy+12>>2]=HEAP32[$__this+12>>2]|0;HEAP32[$__this$byval_copy+16>>2]=HEAP32[$__this+16>>2]|0;HEAP32[$__this$byval_copy+20>>2]=HEAP32[$__this+20>>2]|0;
 ;HEAP32[$point$byval_copy+0>>2]=HEAP32[$point+0>>2]|0;HEAP32[$point$byval_copy+4>>2]=HEAP32[$point+4>>2]|0;HEAP32[$point$byval_copy+8>>2]=HEAP32[$point+8>>2]|0;
 $0 = (Math_fround(+(invoke_fiii(11,0,($__this$byval_copy|0),($point$byval_copy|0)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($0));
 }
 return Math_fround(0);
}
function __Z54UnityEngine_UnityEngine_Bounds_m_Internal_IntersectRayP22mscorlib_System_ObjectP27UnityEngine_UnityEngine_RayP30UnityEngine_UnityEngine_BoundsPf($__this,$ray,$bounds,$distance) {
 $__this = $__this|0;
 $ray = $ray|0;
 $bounds = $bounds|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803944);
 __THREW__ = 0;
 $0 = (invoke_iiiii(205,0,($ray|0),($bounds|0),($distance|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z68UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_IntersectRayP22mscorlib_System_ObjectP27UnityEngine_UnityEngine_RayP30UnityEngine_UnityEngine_BoundsPf($__this,$ray,$bounds,$distance) {
 $__this = $__this|0;
 $ray = $ray|0;
 $bounds = $bounds|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2803992);
 $0 = HEAP32[2804040>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2804048|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2804040>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiii($7|0,($ray|0),($bounds|0),($distance|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z97UnityEngine_UnityEngine_Bounds_m_IntersectRay_mscorlib_System_Boolean_UnityEngine_UnityEngine_RayP30UnityEngine_UnityEngine_Bounds27UnityEngine_UnityEngine_Ray($__this,$ray) {
 $__this = $__this|0;
 $ray = $ray|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804160);
 HEAPF32[$V_0>>2] = Math_fround(0.0);
 __THREW__ = 0;
 $0 = (invoke_iiiii(204,0,($ray|0),($__this|0),($V_0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z129UnityEngine_UnityEngine_Bounds_m_IntersectRay_mscorlib_System_Boolean_UnityEngine_UnityEngine_Ray_mscorlib_System_SingleU0026_refP30UnityEngine_UnityEngine_Bounds27UnityEngine_UnityEngine_RayPf($__this,$ray,$distance) {
 $__this = $__this|0;
 $ray = $ray|0;
 $distance = $distance|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804208);
 __THREW__ = 0;
 $0 = (invoke_iiiii(204,0,($ray|0),($__this|0),($distance|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z57UnityEngine_UnityEngine_Bounds_m_Internal_GetClosestPointP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_BoundsP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$bounds,$point) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $bounds = $bounds|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804256);
 __THREW__ = 0;
 invoke_viiii(234,($agg$result|0),0,($bounds|0),($point|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z71UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_GetClosestPointP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_BoundsP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$bounds,$point) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $bounds = $bounds|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804304);
 $0 = HEAP32[2804352>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2804360|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2804352>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($bounds|0),($point|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_Bounds_m_ClosestPointP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$point) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804464);
 __THREW__ = 0;
 invoke_viiii(233,($agg$result|0),0,($__this|0),($point|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z64UnityEngine_UnityEngine_Bounds_m_ToString_mscorlib_System_StringP30UnityEngine_UnityEngine_Bounds($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_6 = sp;
 $L_12 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804512);
 __THREW__ = 0;
 invoke_v(982);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),2)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     ;HEAP32[$L_6+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$__this+8>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2792272|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_iii(2724,(2792272|0),($L_6|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        $14 = (($4) + 12|0);
        $15 = HEAP32[$14>>2]|0;
        $16 = ($15|0)==(0);
        if ($16) {
         __THREW__ = 0;
         $17 = (invoke_i(132)|0);
         $18 = __THREW__; __THREW__ = 0;
         $19 = $18&1;
         if ($19) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($17|0));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($9|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         $26 = (($4) + 16|0);
         HEAP32[$26>>2] = $9;
         $27 = (($__this) + 12|0);
         ;HEAP32[$L_12+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$27+8>>2]|0;
         __THREW__ = 0;
         (invoke_ii(2996,(2792272|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          __THREW__ = 0;
          $30 = (invoke_iii(2724,(2792272|0),($L_12|0))|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if (!($34)) {
            $35 = HEAP32[$14>>2]|0;
            $36 = ($35>>>0)<(2);
            if ($36) {
             __THREW__ = 0;
             $37 = (invoke_i(132)|0);
             $38 = __THREW__; __THREW__ = 0;
             $39 = $38&1;
             if ($39) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($37|0));
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($30|0));
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if (!($43)) {
             $44 = HEAP32[$4>>2]|0;
             $45 = (($44) + 92|0);
             $46 = HEAP32[$45>>2]|0;
             $47 = (($26) + ($46)|0);
             HEAP32[$47>>2] = $30;
             $48 = HEAP32[3001160>>2]|0;
             __THREW__ = 0;
             $49 = (invoke_iiii(1417,0,($48|0),($4|0))|0);
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if (!($51)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($49|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
 return 0|0;
}
function __Z87UnityEngine_UnityEngine_Bounds_m_ToString_mscorlib_System_String_mscorlib_System_StringP30UnityEngine_UnityEngine_BoundsP22mscorlib_System_String($__this,$format) {
 $__this = $__this|0;
 $format = $format|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804560);
 __THREW__ = 0;
 invoke_v(983);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),2)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_iii(1215,($__this|0),($format|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3799,($4|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       $12 = (($4) + 12|0);
       $13 = HEAP32[$12>>2]|0;
       $14 = ($13|0)==(0);
       if ($14) {
        __THREW__ = 0;
        $15 = (invoke_i(132)|0);
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        if ($17) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($15|0));
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if ($19) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($4|0),($7|0));
       $22 = __THREW__; __THREW__ = 0;
       $23 = $22&1;
       if (!($23)) {
        $24 = (($4) + 16|0);
        HEAP32[$24>>2] = $7;
        $25 = (($__this) + 12|0);
        __THREW__ = 0;
        $26 = (invoke_iii(1215,($25|0),($format|0))|0);
        $27 = __THREW__; __THREW__ = 0;
        $28 = $27&1;
        if (!($28)) {
         __THREW__ = 0;
         invoke_vi(3799,($4|0));
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if (!($30)) {
          $31 = HEAP32[$12>>2]|0;
          $32 = ($31>>>0)<(2);
          if ($32) {
           __THREW__ = 0;
           $33 = (invoke_i(132)|0);
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if ($35) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($33|0));
           $36 = __THREW__; __THREW__ = 0;
           $37 = $36&1;
           if ($37) {
            break;
           }
          }
          __THREW__ = 0;
          invoke_vii(3492,($4|0),($26|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if (!($39)) {
           $40 = HEAP32[$4>>2]|0;
           $41 = (($40) + 92|0);
           $42 = HEAP32[$41>>2]|0;
           $43 = (($24) + ($42)|0);
           HEAP32[$43>>2] = $26;
           $44 = HEAP32[3001232>>2]|0;
           __THREW__ = 0;
           $45 = (invoke_iiii(1417,0,($44|0),($4|0))|0);
           $46 = __THREW__; __THREW__ = 0;
           $47 = $46&1;
           if (!($47)) {
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return ($45|0);
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($20|0);
 // unreachable;
 return 0|0;
}
function __Z130UnityEngine_UnityEngine_Bounds_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Bounds_UnityEngine_UnityEngine_BoundsP22mscorlib_System_Object30UnityEngine_UnityEngine_BoundsS1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $L_0 = 0, $L_1 = 0, $L_3 = 0;
 var $L_3$byval_copy = 0, $L_4 = 0, $L_4$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $L_4$byval_copy = sp + 64|0;
 $L_3$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 $L_1 = sp + 28|0;
 $L_3 = sp + 40|0;
 $L_4 = sp + 52|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804608);
 __THREW__ = 0;
 invoke_vii(2082,($L_0|0),($lhs|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2082,($L_1|0),($rhs|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
   ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   $4 = (invoke_iiii(1351,0,($L_3$byval_copy|0),($L_4$byval_copy|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    if (!($4)) {
     $G_B3_0$0 = 0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return ($G_B3_0$0|0);
    }
    __THREW__ = 0;
    invoke_vii(2086,($L_3|0),($lhs|0));
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if (!($10)) {
     __THREW__ = 0;
     invoke_vii(2086,($L_4|0),($rhs|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      ;HEAP32[$L_3$byval_copy+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$L_3$byval_copy+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$L_3$byval_copy+8>>2]=HEAP32[$L_3+8>>2]|0;
      ;HEAP32[$L_4$byval_copy+0>>2]=HEAP32[$L_4+0>>2]|0;HEAP32[$L_4$byval_copy+4>>2]=HEAP32[$L_4+4>>2]|0;HEAP32[$L_4$byval_copy+8>>2]=HEAP32[$L_4+8>>2]|0;
      $13 = (invoke_iiii(1351,0,($L_3$byval_copy|0),($L_4$byval_copy|0))|0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $G_B3_0$0 = $13;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($G_B3_0$0|0);
      }
     }
    }
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
 return 0|0;
}
function __Z132UnityEngine_UnityEngine_Bounds_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Bounds_UnityEngine_UnityEngine_BoundsP22mscorlib_System_Object30UnityEngine_UnityEngine_BoundsS1_($__this,$lhs,$rhs) {
 $__this = $__this|0;
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, $lhs$byval_copy = 0, $rhs$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $rhs$byval_copy = sp + 32|0;
 $lhs$byval_copy = sp;
 $_stackTraceSentry = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2804656);
 __THREW__ = 0;
 ;HEAP32[$lhs$byval_copy+0>>2]=HEAP32[$lhs+0>>2]|0;HEAP32[$lhs$byval_copy+4>>2]=HEAP32[$lhs+4>>2]|0;HEAP32[$lhs$byval_copy+8>>2]=HEAP32[$lhs+8>>2]|0;HEAP32[$lhs$byval_copy+12>>2]=HEAP32[$lhs+12>>2]|0;HEAP32[$lhs$byval_copy+16>>2]=HEAP32[$lhs+16>>2]|0;HEAP32[$lhs$byval_copy+20>>2]=HEAP32[$lhs+20>>2]|0;
 ;HEAP32[$rhs$byval_copy+0>>2]=HEAP32[$rhs+0>>2]|0;HEAP32[$rhs$byval_copy+4>>2]=HEAP32[$rhs+4>>2]|0;HEAP32[$rhs$byval_copy+8>>2]=HEAP32[$rhs+8>>2]|0;HEAP32[$rhs$byval_copy+12>>2]=HEAP32[$rhs+12>>2]|0;HEAP32[$rhs$byval_copy+16>>2]=HEAP32[$rhs+16>>2]|0;HEAP32[$rhs$byval_copy+20>>2]=HEAP32[$rhs+20>>2]|0;
 $0 = (invoke_iiii(1397,0,($lhs$byval_copy|0),($rhs$byval_copy|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $3 = $0 ^ 1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZN14ActionInvoker1I36UnityEngine_UnityEngine_BoundsTraitsE6InvokeEPFvPv30UnityEngine_UnityEngine_BoundsES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits36UnityEngine_UnityEngine_BoundsTraitsE6InvokeEPFbPv30UnityEngine_UnityEngine_BoundsES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 24|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits36UnityEngine_UnityEngine_BoundsTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFbPv30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 60|0;
 $0 = sp + 24|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker2I28mscorlib_System_SingleTraits36UnityEngine_UnityEngine_BoundsTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFfPv30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast$byval_copy = sp + 56|0;
 $$byval_copy = sp;
 $ret = sp + 24|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;
 $4 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$$byval_copy,$tmpcast$byval_copy)));
 HEAPF32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker1I29mscorlib_System_BooleanTraits33UnityEngine_UnityEngine_RayTraitsE6InvokeEPFbPv27UnityEngine_UnityEngine_RayES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp;
 $ret = sp + 24|0;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 $2 = $1&1;
 HEAP8[$ret>>0] = $2;
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits33UnityEngine_UnityEngine_RayTraits17VoidPointerTraitsE6InvokeEPFbPv27UnityEngine_UnityEngine_RayS4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp + 24|0;
 $ret = sp + 48|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$3)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3Traits17VoidPointerTraitsS1_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits36UnityEngine_UnityEngine_BoundsTraitsS1_E6InvokeEPFbPv30UnityEngine_UnityEngine_BoundsS4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 72|0;
 $0 = sp + 24|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;HEAP32[$tmpcast$byval_copy+16>>2]=HEAP32[$3+16>>2]|0;HEAP32[$tmpcast$byval_copy+20>>2]=HEAP32[$3+20>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z126UnityEngine_UnityEngine_Bounds_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_ContainsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z129UnityEngine_UnityEngine_Bounds_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_SqrDistanceP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130UnityEngine_UnityEngine_Bounds_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_IntersectRayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133UnityEngine_UnityEngine_Bounds_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_GetClosestPointP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z42UnityEngine_UnityEngine_Vector4_m_ToStringP31UnityEngine_UnityEngine_Vector4($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = Math_fround(0), $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = Math_fround(0), $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = Math_fround(0), $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = Math_fround(0), $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_12 = 0, $L_18 = 0, $L_24 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_6 = sp;
 $L_12 = sp + 4|0;
 $L_18 = sp + 8|0;
 $L_24 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2806440);
 __THREW__ = 0;
 invoke_v(984);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),4)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     $7 = Math_fround(HEAPF32[$__this>>2]);
     HEAPF32[$L_6>>2] = $7;
     __THREW__ = 0;
     (invoke_ii(2996,(2194912|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      $10 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $13 = __THREW__; __THREW__ = 0;
       $14 = $13&1;
       if (!($14)) {
        $15 = (($4) + 12|0);
        $16 = HEAP32[$15>>2]|0;
        $17 = ($16|0)==(0);
        if ($17) {
         __THREW__ = 0;
         $18 = (invoke_i(132)|0);
         $19 = __THREW__; __THREW__ = 0;
         $20 = $19&1;
         if ($20) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($18|0));
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if ($22) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($10|0));
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = (($4) + 16|0);
         HEAP32[$27>>2] = $10;
         $28 = (($__this) + 4|0);
         $29 = Math_fround(HEAPF32[$28>>2]);
         HEAPF32[$L_12>>2] = $29;
         __THREW__ = 0;
         (invoke_ii(2996,(2194912|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if (!($31)) {
          __THREW__ = 0;
          $32 = (invoke_iii(2724,(2194912|0),($L_12|0))|0);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $35 = __THREW__; __THREW__ = 0;
           $36 = $35&1;
           if (!($36)) {
            $37 = HEAP32[$15>>2]|0;
            $38 = ($37>>>0)<(2);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($32|0));
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if (!($45)) {
             $46 = HEAP32[$4>>2]|0;
             $47 = (($46) + 92|0);
             $48 = HEAP32[$47>>2]|0;
             $49 = (($27) + ($48)|0);
             HEAP32[$49>>2] = $32;
             $50 = (($__this) + 8|0);
             $51 = Math_fround(HEAPF32[$50>>2]);
             HEAPF32[$L_18>>2] = $51;
             __THREW__ = 0;
             (invoke_ii(2996,(2194912|0))|0);
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if (!($53)) {
              __THREW__ = 0;
              $54 = (invoke_iii(2724,(2194912|0),($L_18|0))|0);
              $55 = __THREW__; __THREW__ = 0;
              $56 = $55&1;
              if (!($56)) {
               __THREW__ = 0;
               invoke_vi(3799,($4|0));
               $57 = __THREW__; __THREW__ = 0;
               $58 = $57&1;
               if (!($58)) {
                $59 = HEAP32[$15>>2]|0;
                $60 = ($59>>>0)<(3);
                if ($60) {
                 __THREW__ = 0;
                 $61 = (invoke_i(132)|0);
                 $62 = __THREW__; __THREW__ = 0;
                 $63 = $62&1;
                 if ($63) {
                  break;
                 }
                 __THREW__ = 0;
                 invoke_vi(3302,($61|0));
                 $64 = __THREW__; __THREW__ = 0;
                 $65 = $64&1;
                 if ($65) {
                  break;
                 }
                }
                __THREW__ = 0;
                invoke_vii(3492,($4|0),($54|0));
                $66 = __THREW__; __THREW__ = 0;
                $67 = $66&1;
                if (!($67)) {
                 $68 = HEAP32[$4>>2]|0;
                 $69 = (($68) + 92|0);
                 $70 = HEAP32[$69>>2]|0;
                 $71 = $70 << 1;
                 $72 = (($27) + ($71)|0);
                 HEAP32[$72>>2] = $54;
                 $73 = (($__this) + 12|0);
                 $74 = Math_fround(HEAPF32[$73>>2]);
                 HEAPF32[$L_24>>2] = $74;
                 __THREW__ = 0;
                 (invoke_ii(2996,(2194912|0))|0);
                 $75 = __THREW__; __THREW__ = 0;
                 $76 = $75&1;
                 if (!($76)) {
                  __THREW__ = 0;
                  $77 = (invoke_iii(2724,(2194912|0),($L_24|0))|0);
                  $78 = __THREW__; __THREW__ = 0;
                  $79 = $78&1;
                  if ($79) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3799,($4|0));
                  $80 = __THREW__; __THREW__ = 0;
                  $81 = $80&1;
                  if ($81) {
                   break;
                  }
                  $82 = HEAP32[$15>>2]|0;
                  $83 = ($82>>>0)<(4);
                  if ($83) {
                   __THREW__ = 0;
                   $84 = (invoke_i(132)|0);
                   $85 = __THREW__; __THREW__ = 0;
                   $86 = $85&1;
                   if ($86) {
                    break;
                   }
                   __THREW__ = 0;
                   invoke_vi(3302,($84|0));
                   $87 = __THREW__; __THREW__ = 0;
                   $88 = $87&1;
                   if ($88) {
                    break;
                   }
                  }
                  __THREW__ = 0;
                  invoke_vii(3492,($4|0),($77|0));
                  $89 = __THREW__; __THREW__ = 0;
                  $90 = $89&1;
                  if ($90) {
                   break;
                  }
                  $91 = HEAP32[$4>>2]|0;
                  $92 = (($91) + 92|0);
                  $93 = HEAP32[$92>>2]|0;
                  $94 = ($93*3)|0;
                  $95 = (($27) + ($94)|0);
                  HEAP32[$95>>2] = $77;
                  $96 = HEAP32[3001248>>2]|0;
                  __THREW__ = 0;
                  $97 = (invoke_iiii(1417,0,($96|0),($4|0))|0);
                  $98 = __THREW__; __THREW__ = 0;
                  $99 = $98&1;
                  if ($99) {
                   break;
                  }
                  __ZN16StackTraceSentryD2Ev(0);
                  STACKTOP = sp;return ($97|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($23|0);
 // unreachable;
 return 0|0;
}
function __Z37UnityEngine_UnityEngine_Vector4_m_DotP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4S1_($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = 0, $18 = Math_fround(0), $19 = Math_fround(0), $2 = Math_fround(0), $20 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0);
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2806488);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround(HEAPF32[$b>>2]);
 $2 = Math_fround($0 * $1);
 $3 = (($a) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($b) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($2 + $7);
 $9 = (($a) + 8|0);
 $10 = Math_fround(HEAPF32[$9>>2]);
 $11 = (($b) + 8|0);
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = Math_fround($10 * $12);
 $14 = Math_fround($8 + $13);
 $15 = (($a) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = (($b) + 12|0);
 $18 = Math_fround(HEAPF32[$17>>2]);
 $19 = Math_fround($16 * $18);
 $20 = Math_fround($14 + $19);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($20));
}
function __Z46UnityEngine_UnityEngine_Vector4_m_SqrMagnitudeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4($__this,$a) {
 $__this = $__this|0;
 $a = $a|0;
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = 0, $17 = 0, $2 = Math_fround(0), $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, $_stackTraceSentry$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry$i = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2806536);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = (($a) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($a) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($a) + 12|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 __THREW__ = 0;
 invoke_vii(3500,($_stackTraceSentry$i|0),(2806488|0));
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($16|0);
  // unreachable;
 } else {
  $9 = Math_fround($0 * $0);
  $10 = Math_fround($2 * $2);
  $11 = Math_fround($9 + $10);
  $12 = Math_fround($4 * $4);
  $13 = Math_fround($11 + $12);
  $14 = Math_fround($6 * $6);
  $15 = Math_fround($13 + $14);
  __ZN16StackTraceSentryD2Ev(0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($15));
 }
 return Math_fround(0);
}
function __Z144UnityEngine_UnityEngine_Vector4_m_op_Subtraction_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_Vector4P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4S1_($agg$result,$__this,$a,$b) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = Math_fround(0), $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = Math_fround(0), $7 = Math_fround(0);
 var $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2806584);
 $0 = Math_fround(HEAPF32[$a>>2]);
 $1 = Math_fround(HEAPF32[$b>>2]);
 $2 = Math_fround($0 - $1);
 $3 = (($a) + 4|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($b) + 4|0);
 $6 = Math_fround(HEAPF32[$5>>2]);
 $7 = Math_fround($4 - $6);
 $8 = (($a) + 8|0);
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($b) + 8|0);
 $11 = Math_fround(HEAPF32[$10>>2]);
 $12 = Math_fround($9 - $11);
 $13 = (($a) + 12|0);
 $14 = Math_fround(HEAPF32[$13>>2]);
 $15 = (($b) + 12|0);
 $16 = Math_fround(HEAPF32[$15>>2]);
 $17 = Math_fround($14 - $16);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_viffff(5,($agg$result|0),(+$2),(+$7),(+$12),(+$17));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($20|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN12FuncInvoker2I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector4TraitsS1_E6InvokeEPFfPv31UnityEngine_UnityEngine_Vector4S4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 40|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 24|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (Math_fround(FUNCTION_TABLE_fiii[$func & 31]($obj,$$byval_copy,$tmpcast$byval_copy)));
 HEAPF32[$ret>>2] = $4;
 $5 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($5|0);
}
function __ZN12FuncInvoker1I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector4TraitsE6InvokeEPFfPv31UnityEngine_UnityEngine_Vector4ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $tmpcast$byval_copy = sp + 8|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 $1 = (Math_fround(FUNCTION_TABLE_fii[$func & 63]($obj,$tmpcast$byval_copy)));
 HEAPF32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector4TraitsS0_S0_E6InvokeEPF31UnityEngine_UnityEngine_Vector4PvS2_S2_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 48|0;
 $$byval_copy = sp;
 $ret = sp + 16|0;
 $0 = sp + 32|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$$byval_copy,$tmpcast$byval_copy);
 $4 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2807040,$ret)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits37UnityEngine_UnityEngine_Vector4TraitsS1_E6InvokeEPFbPv31UnityEngine_UnityEngine_Vector4S4_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $tmpcast$byval_copy = sp + 32|0;
 $$byval_copy = sp;
 $ret = sp + 48|0;
 $0 = sp + 16|0;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$func & 2047]($obj,$$byval_copy,$tmpcast$byval_copy)|0);
 $5 = $4&1;
 HEAP8[$ret>>0] = $5;
 $6 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($6|0);
}
function __Z62UnityEngine_UnityEngine_Vector4_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2791992)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z43UnityEngine_UnityEngine_Ray_m_get_directionP27UnityEngine_UnityEngine_Ray($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2807176);
 $0 = (($__this) + 12|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z38UnityEngine_UnityEngine_Ray_m_GetPointP27UnityEngine_UnityEngine_Rayf($agg$result,$__this,$distance) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $distance = Math_fround($distance);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $L_0 = 0, $L_0$byval_copy = 0, $L_2 = 0, $L_2$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_2$byval_copy = sp + 40|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 12|0;
 $L_0 = sp + 16|0;
 $L_2 = sp + 28|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2807224);
 ;HEAP32[$L_0+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_0+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_0+8>>2]=HEAP32[$__this+8>>2]|0;
 $0 = (($__this) + 12|0);
 __THREW__ = 0;
 ;HEAP32[$L_2$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$L_2$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$L_2$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 invoke_viiif(2,($L_2|0),0,($L_2$byval_copy|0),(+$distance));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
 ;HEAP32[$L_2$byval_copy+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$L_2$byval_copy+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$L_2$byval_copy+8>>2]=HEAP32[$L_2+8>>2]|0;
 invoke_viiii(222,($agg$result|0),0,($L_0$byval_copy|0),($L_2$byval_copy|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z38UnityEngine_UnityEngine_Ray_m_ToStringP27UnityEngine_UnityEngine_Ray($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 24|0;
 $L_6 = sp;
 $L_12 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2807272);
 __THREW__ = 0;
 invoke_v(985);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   (invoke_ii(2996,(1167664|0))|0);
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iii(2777,(1167664|0),2)|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     ;HEAP32[$L_6+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$__this+8>>2]|0;
     __THREW__ = 0;
     (invoke_ii(2996,(2792272|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if (!($8)) {
      __THREW__ = 0;
      $9 = (invoke_iii(2724,(2792272|0),($L_6|0))|0);
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($4|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        $14 = (($4) + 12|0);
        $15 = HEAP32[$14>>2]|0;
        $16 = ($15|0)==(0);
        if ($16) {
         __THREW__ = 0;
         $17 = (invoke_i(132)|0);
         $18 = __THREW__; __THREW__ = 0;
         $19 = $18&1;
         if ($19) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($17|0));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($4|0),($9|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         $26 = (($4) + 16|0);
         HEAP32[$26>>2] = $9;
         $27 = (($__this) + 12|0);
         ;HEAP32[$L_12+0>>2]=HEAP32[$27+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$27+8>>2]|0;
         __THREW__ = 0;
         (invoke_ii(2996,(2792272|0))|0);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          __THREW__ = 0;
          $30 = (invoke_iii(2724,(2792272|0),($L_12|0))|0);
          $31 = __THREW__; __THREW__ = 0;
          $32 = $31&1;
          if (!($32)) {
           __THREW__ = 0;
           invoke_vi(3799,($4|0));
           $33 = __THREW__; __THREW__ = 0;
           $34 = $33&1;
           if (!($34)) {
            $35 = HEAP32[$14>>2]|0;
            $36 = ($35>>>0)<(2);
            if ($36) {
             __THREW__ = 0;
             $37 = (invoke_i(132)|0);
             $38 = __THREW__; __THREW__ = 0;
             $39 = $38&1;
             if ($39) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($37|0));
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
            }
            __THREW__ = 0;
            invoke_vii(3492,($4|0),($30|0));
            $42 = __THREW__; __THREW__ = 0;
            $43 = $42&1;
            if (!($43)) {
             $44 = HEAP32[$4>>2]|0;
             $45 = (($44) + 92|0);
             $46 = HEAP32[$45>>2]|0;
             $47 = (($26) + ($46)|0);
             HEAP32[$47>>2] = $30;
             $48 = HEAP32[3001264>>2]|0;
             __THREW__ = 0;
             $49 = (invoke_iiii(1417,0,($48|0),($4|0))|0);
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if (!($51)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return ($49|0);
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector3Traits28mscorlib_System_SingleTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvfES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 FUNCTION_TABLE_viif[$func & 63]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2792272,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z54UnityEngine_UnityEngineInternal_MathfInternal_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2807656);
 __THREW__ = 0;
 (invoke_ii(2996,(2807936|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2807936 + 80|0))>>2]|0;
  HEAPF32[$2>>2] = Math_fround(1.17549435082228750797E-38);
  __THREW__ = 0;
  (invoke_ii(2996,(2807936|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = HEAP32[((2807936 + 80|0))>>2]|0;
   $6 = (($5) + 4|0);
   HEAPF32[$6>>2] = Math_fround(1.40129846432481707092E-45);
   __THREW__ = 0;
   (invoke_ii(2996,(2807936|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[((2807936 + 80|0))>>2]|0;
    $10 = (($9) + 4|0);
    $11 = Math_fround(HEAPF32[$10>>2]);
    __THREW__ = 0;
    (invoke_ii(2996,(2807936|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = $11 == Math_fround(0.0);
     $15 = HEAP32[((2807936 + 80|0))>>2]|0;
     $16 = (($15) + 8|0);
     $17 = $14&1;
     HEAP8[$16>>0] = $17;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
}
function __Z38UnityEngine_UnityEngine_Mathf_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = Math_fround(0), $G_B3_0$0$in$in = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808072);
 __THREW__ = 0;
 (invoke_ii(2996,(2807936|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2807936 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2807936|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2807936|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3845,(2807936|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2807936|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2807936 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if ($17) {
     __THREW__ = 0;
     (invoke_ii(2996,(2807936|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if ($32) {
      break;
     }
     $33 = HEAP8[((2807936 + 116|0))>>0]|0;
     $34 = ($33<<24>>24)==(0);
     if ($34) {
      __THREW__ = 0;
      (invoke_ii(2996,(2807936|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2807936|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3845,(2807936|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2807936|0))|0);
     $41 = __THREW__; __THREW__ = 0;
     $42 = $41&1;
     if ($42) {
      break;
     }
     $43 = HEAP32[((2807936 + 80|0))>>2]|0;
     $44 = (($43) + 4|0);
     $G_B3_0$0$in$in = $44;
    } else {
     __THREW__ = 0;
     (invoke_ii(2996,(2807936|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP8[((2807936 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2807936|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2807936|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3845,(2807936|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2807936|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = HEAP32[((2807936 + 80|0))>>2]|0;
     $G_B3_0$0$in$in = $30;
    }
    $G_B3_0$0 = Math_fround(HEAPF32[$G_B3_0$0$in$in>>2]);
    __THREW__ = 0;
    (invoke_ii(2996,(2810112|0))|0);
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if (!($46)) {
     $47 = HEAP32[((2810112 + 80|0))>>2]|0;
     HEAPF32[$47>>2] = $G_B3_0$0;
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z35UnityEngine_UnityEngine_Mathf_m_CosP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0.0, $1 = 0.0, $2 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808120);
 $0 = +$f;
 $1 = (+Math_cos((+$0)));
 $2 = Math_fround($1);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($2));
}
function __Z36UnityEngine_UnityEngine_Mathf_m_AsinP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0.0, $1 = 0.0, $2 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808168);
 $0 = +$f;
 $1 = (+Math_asin((+$0)));
 $2 = Math_fround($1);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($2));
}
function __Z36UnityEngine_UnityEngine_Mathf_m_AcosP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0.0, $1 = 0.0, $2 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808216);
 $0 = +$f;
 $1 = (+Math_acos((+$0)));
 $2 = Math_fround($1);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($2));
}
function __Z36UnityEngine_UnityEngine_Mathf_m_SqrtP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808264);
 $0 = (Math_fround(Math_sqrt((Math_fround($f)))));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z35UnityEngine_UnityEngine_Mathf_m_AbsP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808312);
 $0 = (Math_fround(Math_abs((Math_fround($f)))));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($0));
}
function __Z101UnityEngine_UnityEngine_Mathf_m_Min_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Objectii($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $_stackTraceSentry = 0, $a$b = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808408);
 $0 = ($a|0)<($b|0);
 $a$b = $0 ? $a : $b;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($a$b|0);
}
function __Z101UnityEngine_UnityEngine_Mathf_m_Max_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Objectii($__this,$a,$b) {
 $__this = $__this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $_stackTraceSentry = 0, $a$b = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808504);
 $0 = ($a|0)>($b|0);
 $a$b = $0 ? $a : $b;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($a$b|0);
}
function __Z37UnityEngine_UnityEngine_Mathf_m_FloorP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $_stackTraceSentry = 0, $floorf = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808552);
 $floorf = (Math_fround(Math_floor((Math_fround($f)))));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($floorf));
}
function __Z37UnityEngine_UnityEngine_Mathf_m_RoundP22mscorlib_System_Objectf($__this,$f) {
 $__this = $__this|0;
 $f = Math_fround($f);
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808600);
 $0 = +$f;
 __THREW__ = 0;
 $1 = (+invoke_did(3,(0|0),(+$0)));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $4 = Math_fround($1);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($4));
 }
 return Math_fround(0);
}
function __Z36UnityEngine_UnityEngine_Mathf_m_LerpP22mscorlib_System_Objectfff($__this,$from,$to,$t) {
 $__this = $__this|0;
 $from = Math_fround($from);
 $to = Math_fround($to);
 $t = Math_fround($t);
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808744);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fif(12,0,(+$t)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $3 = Math_fround($to - $from);
  $4 = Math_fround($3 * $0);
  $5 = Math_fround($4 + $from);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($5));
 }
 return Math_fround(0);
}
function __Z45UnityEngine_UnityEngine_Mathf_m_ApproximatelyP22mscorlib_System_Objectff($__this,$a,$b) {
 $__this = $__this|0;
 $a = Math_fround($a);
 $b = Math_fround($b);
 var $0 = Math_fround(0), $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = 0;
 var $27 = 0, $28 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808792);
 $0 = Math_fround($b - $a);
 $1 = (Math_fround(Math_abs((Math_fround($0)))));
 $2 = (Math_fround(Math_abs((Math_fround($a)))));
 $3 = (Math_fround(Math_abs((Math_fround($b)))));
 __THREW__ = 0;
 $4 = (Math_fround(+(invoke_fiff(4,0,(+$2),(+$3)))));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   $7 = Math_fround($4 * Math_fround(9.99999997475242707878E-7));
   __THREW__ = 0;
   (invoke_ii(2996,(2810112|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = HEAP8[((2810112 + 116|0))>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     __THREW__ = 0;
     (invoke_ii(2996,(2810112|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2810112|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3845,(2810112|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2810112|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     $22 = HEAP32[((2810112 + 80|0))>>2]|0;
     $23 = Math_fround(HEAPF32[$22>>2]);
     $24 = Math_fround($23 * Math_fround(8.0));
     __THREW__ = 0;
     $25 = (Math_fround(+(invoke_fiff(4,0,(+$7),(+$24)))));
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if (!($27)) {
      $28 = $1 < $25;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($28|0);
     }
    }
   }
  }
 } while(0);
 $18 = ___cxa_find_matching_catch()|0;
 $19 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($18|0);
 // unreachable;
 return 0|0;
}
function __Z166UnityEngine_UnityEngine_Mathf_m_SmoothDamp_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_SingleP22mscorlib_System_ObjectffPff($__this,$current,$target,$currentVelocity,$smoothTime) {
 $__this = $__this|0;
 $current = Math_fround($current);
 $target = Math_fround($target);
 $currentVelocity = $currentVelocity|0;
 $smoothTime = Math_fround($smoothTime);
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808840);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fi(149,0))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fiffifff(1,0,(+$current),(+$target),($currentVelocity|0),(+$smoothTime),inf,(+$0)))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($3));
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return Math_fround(0);
}
function __Z44UnityEngine_UnityEngine_Time_m_get_deltaTimeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2832328);
 $0 = HEAP32[2832376>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2832384|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2832376>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_f($7|0))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z212UnityEngine_UnityEngine_Mathf_m_SmoothDamp_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_ObjectffPffff($__this,$current,$target,$currentVelocity,$smoothTime,$maxSpeed,$deltaTime) {
 $__this = $__this|0;
 $current = Math_fround($current);
 $target = Math_fround($target);
 $currentVelocity = $currentVelocity|0;
 $smoothTime = Math_fround($smoothTime);
 $maxSpeed = Math_fround($maxSpeed);
 $deltaTime = Math_fround($deltaTime);
 var $0 = Math_fround(0), $1 = 0, $10 = Math_fround(0), $11 = Math_fround(0), $12 = Math_fround(0), $13 = Math_fround(0), $14 = Math_fround(0), $15 = Math_fround(0), $16 = Math_fround(0), $17 = Math_fround(0), $18 = 0, $19 = 0, $2 = 0, $20 = Math_fround(0), $21 = Math_fround(0), $22 = Math_fround(0), $23 = Math_fround(0), $24 = Math_fround(0), $25 = Math_fround(0), $26 = Math_fround(0);
 var $27 = Math_fround(0), $28 = Math_fround(0), $29 = Math_fround(0), $3 = Math_fround(0), $30 = Math_fround(0), $31 = Math_fround(0), $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = Math_fround(0), $38 = Math_fround(0), $4 = Math_fround(0), $5 = Math_fround(0), $6 = Math_fround(0), $7 = Math_fround(0), $8 = Math_fround(0), $9 = Math_fround(0), $V_7$0 = Math_fround(0);
 var $_stackTraceSentry = 0, $storemerge = Math_fround(0), label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808888);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fiff(4,0,9.99999974737875163555E-5,(+$smoothTime)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($35|0);
  // unreachable;
 }
 $3 = Math_fround(Math_fround(2.0) / $0);
 $4 = Math_fround($3 * $deltaTime);
 $5 = Math_fround($4 + Math_fround(1.0));
 $6 = Math_fround($4 * Math_fround(0.47999998927116394043));
 $7 = Math_fround($4 * $6);
 $8 = Math_fround($5 + $7);
 $9 = Math_fround($4 * Math_fround(0.234999999403953552246));
 $10 = Math_fround($4 * $9);
 $11 = Math_fround($4 * $10);
 $12 = Math_fround($8 + $11);
 $13 = Math_fround(Math_fround(1.0) / $12);
 $14 = Math_fround($current - $target);
 $15 = Math_fround($0 * $maxSpeed);
 $16 = Math_fround(-$15);
 __THREW__ = 0;
 $17 = (Math_fround(+(invoke_fifff(1,0,(+$14),(+$16),(+$15)))));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $35 = ___cxa_find_matching_catch()|0;
  $36 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($35|0);
  // unreachable;
 }
 $20 = Math_fround($current - $17);
 $21 = Math_fround(HEAPF32[$currentVelocity>>2]);
 $22 = Math_fround($3 * $17);
 $23 = Math_fround($22 + $21);
 $24 = Math_fround($23 * $deltaTime);
 $25 = Math_fround($3 * $24);
 $26 = Math_fround($21 - $25);
 $27 = Math_fround($13 * $26);
 $28 = Math_fround($17 + $24);
 $29 = Math_fround($13 * $28);
 $30 = Math_fround($20 + $29);
 $31 = Math_fround($target - $current);
 $32 = $31 > Math_fround(0.0);
 $33 = $30 > $target;
 $34 = $32 ^ $33;
 if ($34) {
  $V_7$0 = $30;$storemerge = $27;
  HEAPF32[$currentVelocity>>2] = $storemerge;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($V_7$0));
 }
 $37 = Math_fround($target - $target);
 $38 = Math_fround($37 / $deltaTime);
 $V_7$0 = $target;$storemerge = $38;
 HEAPF32[$currentVelocity>>2] = $storemerge;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($V_7$0));
}
function __Z194UnityEngine_UnityEngine_Mathf_m_SmoothDampAngle_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_ObjectffPfff($__this,$current,$target,$currentVelocity,$smoothTime,$maxSpeed) {
 $__this = $__this|0;
 $current = Math_fround($current);
 $target = Math_fround($target);
 $currentVelocity = $currentVelocity|0;
 $smoothTime = Math_fround($smoothTime);
 $maxSpeed = Math_fround($maxSpeed);
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808936);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fi(149,0))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  $3 = (Math_fround(+(invoke_fiffifff(2,0,(+$current),(+$target),($currentVelocity|0),(+$smoothTime),(+$maxSpeed),(+$0)))));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($3));
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return Math_fround(0);
}
function __Z217UnityEngine_UnityEngine_Mathf_m_SmoothDampAngle_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_ObjectffPffff($__this,$current,$target,$currentVelocity,$smoothTime,$maxSpeed,$deltaTime) {
 $__this = $__this|0;
 $current = Math_fround($current);
 $target = Math_fround($target);
 $currentVelocity = $currentVelocity|0;
 $smoothTime = Math_fround($smoothTime);
 $maxSpeed = Math_fround($maxSpeed);
 $deltaTime = Math_fround($deltaTime);
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2808984);
 __THREW__ = 0;
 $0 = (Math_fround(+(invoke_fiff(6,0,(+$current),(+$target)))));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 }
 $3 = Math_fround($0 + $current);
 __THREW__ = 0;
 $4 = (Math_fround(+(invoke_fiffifff(1,0,(+$current),(+$3),($currentVelocity|0),(+$smoothTime),(+$maxSpeed),(+$deltaTime)))));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $7 = ___cxa_find_matching_catch()|0;
  $8 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($7|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($4));
 }
 return Math_fround(0);
}
function __Z42UnityEngine_UnityEngine_Mathf_m_DeltaAngleP22mscorlib_System_Objectff($__this,$current,$target) {
 $__this = $__this|0;
 $current = Math_fround($current);
 $target = Math_fround($target);
 var $0 = Math_fround(0), $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $V_0$0 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2809080);
 $0 = Math_fround($target - $current);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fiff(5,0,(+$0),360.0))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $4 = !($1 <= Math_fround(180.0));
 if (!($4)) {
  $V_0$0 = $1;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return (Math_fround($V_0$0));
 }
 $7 = Math_fround($1 + Math_fround(-360.0));
 $V_0$0 = $7;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($V_0$0));
}
function __Z38UnityEngine_UnityEngine_Mathf_m_RepeatP22mscorlib_System_Objectff($__this,$t,$length) {
 $__this = $__this|0;
 $t = Math_fround($t);
 $length = Math_fround($length);
 var $0 = Math_fround(0), $1 = Math_fround(0), $2 = Math_fround(0), $3 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2809032);
 $0 = Math_fround($t / $length);
 $1 = (Math_fround(Math_floor((Math_fround($0)))));
 $2 = Math_fround($1 * $length);
 $3 = Math_fround($t - $2);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($3));
}
function __ZN12FuncInvoker3I28mscorlib_System_SingleTraitsS0_S0_S0_E6InvokeEPFfPvfffES2_PS2_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (Math_fround(FUNCTION_TABLE_fifff[$func & 3]($obj,$1,$4,$7)));
 HEAPF32[$ret>>2] = $8;
 $9 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN12FuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_SingleTraitsS1_E6InvokeEPFbPvffES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (FUNCTION_TABLE_iiff[$func & 1]($obj,$1,$4)|0);
 $6 = $5&1;
 HEAP8[$ret>>0] = $6;
 $7 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2208584,$ret)|0);
 STACKTOP = sp;return ($7|0);
}
function __ZN12FuncInvoker4I28mscorlib_System_SingleTraitsS0_S0_17VoidPointerTraitsS0_E6InvokeEPFfPvffS3_fES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (Math_fround(FUNCTION_TABLE_fiffif[$func & 1]($obj,$1,$4,$6,$9)));
 HEAPF32[$ret>>2] = $10;
 $11 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($11|0);
}
function __ZN12FuncInvoker6I28mscorlib_System_SingleTraitsS0_S0_17VoidPointerTraitsS0_S0_S0_E6InvokeEPFfPvffS3_fffES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = 0, $14 = 0, $15 = Math_fround(0), $16 = Math_fround(0), $17 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $ret = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (($args) + 20|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = Math_fround(HEAPF32[$14>>2]);
 $16 = (Math_fround(FUNCTION_TABLE_fiffifff[$func & 3]($obj,$1,$4,$6,$9,$12,$15)));
 HEAPF32[$ret>>2] = $16;
 $17 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($17|0);
}
function __ZN12FuncInvoker5I28mscorlib_System_SingleTraitsS0_S0_17VoidPointerTraitsS0_S0_E6InvokeEPFfPvffS3_ffES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = Math_fround(0), $13 = Math_fround(0), $14 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = Math_fround(0), $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = Math_fround(HEAPF32[$8>>2]);
 $10 = (($args) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = Math_fround(HEAPF32[$11>>2]);
 $13 = (Math_fround(FUNCTION_TABLE_fiffiff[$func & 1]($obj,$1,$4,$6,$9,$12)));
 HEAPF32[$ret>>2] = $13;
 $14 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2194912,$ret)|0);
 STACKTOP = sp;return ($14|0);
}
function __Z227UnityEngine_UnityEngine_Mathf_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Mathf_m_SmoothDamp_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z255UnityEngine_UnityEngine_Mathf_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Mathf_m_SmoothDampAngle_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_Single_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z44UnityEngine_UnityEngine_TextAsset_m_get_textP33UnityEngine_UnityEngine_TextAsset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2810248);
 $0 = HEAP32[2810296>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2810304|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2810296>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z44UnityEngine_UnityEngine_TextAsset_m_ToStringP33UnityEngine_UnityEngine_TextAsset($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2810344);
 __THREW__ = 0;
 $0 = (invoke_ii(2627,($__this|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z109UnityEngine_UnityEngine_TextAsset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextAsset_m_get_textP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z57UnityEngine_UnityEngine_SerializePrivateVariables_m__ctorP49UnityEngine_UnityEngine_SerializePrivateVariables($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2810624);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z80UnityEngine_UnityEngine_SerializePrivateVariables_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2810672)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2810992);
 __THREW__ = 0;
 invoke_vi(1931,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z45UnityEngine_UnityEngine_Shader_m_PropertyToIDP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2811568);
 $0 = HEAP32[2811616>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2811624|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2811616>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($name|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z107UnityEngine_UnityEngine_Shader_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Shader_m_PropertyToIDP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z44UnityEngine_UnityEngine_Material_m_get_colorP32UnityEngine_UnityEngine_Material($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2811896);
 __THREW__ = 0;
 invoke_v(986);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[3001328>>2]|0;
  __THREW__ = 0;
  invoke_viii(766,($agg$result|0),($__this|0),($2|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z96UnityEngine_UnityEngine_Material_m_GetColor_UnityEngine_UnityEngine_Color_mscorlib_System_StringP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_String($agg$result,$__this,$propertyName) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $propertyName = $propertyName|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812248);
 __THREW__ = 0;
 $0 = (invoke_iii(1228,0,($propertyName|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viii(767,($agg$result|0),($__this|0),($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z44UnityEngine_UnityEngine_Material_m_set_colorP32UnityEngine_UnityEngine_Material29UnityEngine_UnityEngine_Color($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, $value$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $value$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2811944);
 __THREW__ = 0;
 invoke_v(987);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 $2 = HEAP32[3001360>>2]|0;
 __THREW__ = 0;
 ;HEAP32[$value$byval_copy+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$value$byval_copy+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$value$byval_copy+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$value$byval_copy+12>>2]=HEAP32[$value+12>>2]|0;
 invoke_viii(764,($__this|0),($2|0),($value$byval_copy|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z117UnityEngine_UnityEngine_Material_m_SetColor_mscorlib_System_Void_mscorlib_System_String_UnityEngine_UnityEngine_ColorP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_String29UnityEngine_UnityEngine_Color($__this,$propertyName,$color) {
 $__this = $__this|0;
 $propertyName = $propertyName|0;
 $color = $color|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, $color$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $color$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2811992);
 __THREW__ = 0;
 $0 = (invoke_iii(1228,0,($propertyName|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$color$byval_copy+0>>2]=HEAP32[$color+0>>2]|0;HEAP32[$color$byval_copy+4>>2]=HEAP32[$color+4>>2]|0;HEAP32[$color$byval_copy+8>>2]=HEAP32[$color+8>>2]|0;HEAP32[$color$byval_copy+12>>2]=HEAP32[$color+12>>2]|0;
 invoke_viii(765,($__this|0),($0|0),($color$byval_copy|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z116UnityEngine_UnityEngine_Material_m_SetColor_mscorlib_System_Void_mscorlib_System_Int32_UnityEngine_UnityEngine_ColorP32UnityEngine_UnityEngine_Materiali29UnityEngine_UnityEngine_Color($__this,$nameID,$color) {
 $__this = $__this|0;
 $nameID = $nameID|0;
 $color = $color|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812040);
 __THREW__ = 0;
 invoke_viiii(236,0,($__this|0),($nameID|0),($color|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57UnityEngine_UnityEngine_Material_m_INTERNAL_CALL_SetColorP22mscorlib_System_ObjectP32UnityEngine_UnityEngine_MaterialiP29UnityEngine_UnityEngine_Color($__this,$self,$nameID,$color) {
 $__this = $__this|0;
 $self = $self|0;
 $nameID = $nameID|0;
 $color = $color|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812088);
 $0 = HEAP32[2812136>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2812144|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2812136>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($self|0),($nameID|0),($color|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z95UnityEngine_UnityEngine_Material_m_GetColor_UnityEngine_UnityEngine_Color_mscorlib_System_Int32P32UnityEngine_UnityEngine_Materiali($agg$result,$__this,$nameID) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $nameID = $nameID|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812296);
 $0 = HEAP32[2812344>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2812352|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2812344>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($__this|0),($nameID|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z110UnityEngine_UnityEngine_Material_m_SetFloat_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_SingleP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_Stringf($__this,$propertyName,$value) {
 $__this = $__this|0;
 $propertyName = $propertyName|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812400);
 __THREW__ = 0;
 $0 = (invoke_iii(1228,0,($propertyName|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viif(28,($__this|0),($0|0),(+$value));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z109UnityEngine_UnityEngine_Material_m_SetFloat_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_SingleP32UnityEngine_UnityEngine_Materialif($__this,$nameID,$value) {
 $__this = $__this|0;
 $nameID = $nameID|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812448);
 $0 = HEAP32[2812496>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2812504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2812496>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viif($7|0,($__this|0),($nameID|0),(+$value));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z41UnityEngine_UnityEngine_Material_m_SetIntP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_Stringi($__this,$propertyName,$value) {
 $__this = $__this|0;
 $propertyName = $propertyName|0;
 $value = $value|0;
 var $0 = Math_fround(0), $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812568);
 $0 = (Math_fround(($value|0)));
 __THREW__ = 0;
 invoke_viif(27,($__this|0),($propertyName|0),(+$0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_Material_m_set_renderQueueP32UnityEngine_UnityEngine_Materiali($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812616);
 $0 = HEAP32[2812664>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2812672|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2812664>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_Material_m_EnableKeywordP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_String($__this,$keyword) {
 $__this = $__this|0;
 $keyword = $keyword|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812728);
 $0 = HEAP32[2812776>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2812784|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2812776>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($keyword|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_Material_m_DisableKeywordP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_String($__this,$keyword) {
 $__this = $__this|0;
 $keyword = $keyword|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2812840);
 $0 = HEAP32[2812888>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2812896|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2812888>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($keyword|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN14ActionInvoker2I17VoidPointerTraits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPFvPvS3_29UnityEngine_UnityEngine_ColorES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$2+12>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$0,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I27mscorlib_System_Int32Traits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPFvPvi29UnityEngine_UnityEngine_ColorES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$3+12>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$1,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_E6InvokeEPFvPvS3_iS3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$0,$3,$5);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker1I35UnityEngine_UnityEngine_ColorTraits27mscorlib_System_Int32TraitsE6InvokeEPF29UnityEngine_UnityEngine_ColorPviES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$1);
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2793208,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z121UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_INTERNAL_CALL_SetColorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z159UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_GetColor_UnityEngine_UnityEngine_Color_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z173UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_SetFloat_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z114UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_set_renderQueueP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z112UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_EnableKeywordP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z113UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_DisableKeywordP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_WWWForm_m__ctorP31UnityEngine_UnityEngine_WWWForm($__this) {
 $__this = $__this|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $V_0$010 = 0, $V_1$1 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2813712);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(1960648|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(1960648|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3803,($4|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     $9 = (($__this) + 8|0);
     HEAP32[$9>>2] = $4;
     __THREW__ = 0;
     (invoke_ii(2996,(1333136|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      $12 = (invoke_ii(3469,(1333136|0))|0);
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       __THREW__ = 0;
       invoke_vi(3803,($12|0));
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        $17 = (($__this) + 12|0);
        HEAP32[$17>>2] = $12;
        __THREW__ = 0;
        (invoke_ii(2996,(1333136|0))|0);
        $18 = __THREW__; __THREW__ = 0;
        $19 = $18&1;
        if (!($19)) {
         __THREW__ = 0;
         $20 = (invoke_ii(3469,(1333136|0))|0);
         $21 = __THREW__; __THREW__ = 0;
         $22 = $21&1;
         if (!($22)) {
          __THREW__ = 0;
          invoke_vi(3803,($20|0));
          $23 = __THREW__; __THREW__ = 0;
          $24 = $23&1;
          if (!($24)) {
           $25 = (($__this) + 16|0);
           HEAP32[$25>>2] = $20;
           __THREW__ = 0;
           (invoke_ii(2996,(1333136|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            $28 = (invoke_ii(3469,(1333136|0))|0);
            $29 = __THREW__; __THREW__ = 0;
            $30 = $29&1;
            if (!($30)) {
             __THREW__ = 0;
             invoke_vi(3803,($28|0));
             $31 = __THREW__; __THREW__ = 0;
             $32 = $31&1;
             if (!($32)) {
              $33 = (($__this) + 20|0);
              HEAP32[$33>>2] = $28;
              __THREW__ = 0;
              (invoke_ii(2996,(1203320|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               __THREW__ = 0;
               $36 = (invoke_iii(2777,(1203320|0),40)|0);
               $37 = __THREW__; __THREW__ = 0;
               $38 = $37&1;
               if (!($38)) {
                $39 = (($__this) + 24|0);
                HEAP32[$39>>2] = $36;
                $V_0$010 = 0;
                while(1) {
                 __THREW__ = 0;
                 $45 = (invoke_iiii(1434,0,48,110)|0);
                 $69 = __THREW__; __THREW__ = 0;
                 $70 = $69&1;
                 if ($70) {
                  break;
                 }
                 $44 = ($45|0)<(58);
                 $46 = (($45) + 7)|0;
                 $$ = $44 ? $45 : $46;
                 $47 = ($$|0)<(91);
                 $48 = (($$) + 6)|0;
                 $V_1$1 = $47 ? $$ : $48;
                 $49 = HEAP32[$39>>2]|0;
                 $50 = $V_1$1&255;
                 __THREW__ = 0;
                 invoke_vi(3799,($49|0));
                 $51 = __THREW__; __THREW__ = 0;
                 $52 = $51&1;
                 if ($52) {
                  break;
                 }
                 $53 = (($49) + 12|0);
                 $54 = HEAP32[$53>>2]|0;
                 $55 = ($V_0$010>>>0)<($54>>>0);
                 if (!($55)) {
                  __THREW__ = 0;
                  $56 = (invoke_i(132)|0);
                  $57 = __THREW__; __THREW__ = 0;
                  $58 = $57&1;
                  if ($58) {
                   break;
                  }
                  __THREW__ = 0;
                  invoke_vi(3302,($56|0));
                  $59 = __THREW__; __THREW__ = 0;
                  $60 = $59&1;
                  if ($60) {
                   break;
                  }
                 }
                 $61 = HEAP32[$49>>2]|0;
                 $62 = (($49) + 16|0);
                 $63 = (($61) + 92|0);
                 $64 = HEAP32[$63>>2]|0;
                 $65 = Math_imul($64, $V_0$010)|0;
                 $66 = (($62) + ($65)|0);
                 HEAP8[$66>>0] = $50;
                 $67 = (($V_0$010) + 1)|0;
                 $68 = ($67|0)<(40);
                 if ($68) {
                  $V_0$010 = $67;
                 } else {
                  label = 26;
                  break;
                 }
                }
                if ((label|0) == 26) {
                 __ZN16StackTraceSentryD2Ev(0);
                 STACKTOP = sp;return;
                }
                $40 = ___cxa_find_matching_catch()|0;
                $41 = tempRet0;
                $lpad$phi$index = $40;$lpad$phi$index2 = $41;
                __ZN16StackTraceSentryD2Ev(0);
                ___resumeException($lpad$phi$index|0);
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $42 = ___cxa_find_matching_catch()|0;
 $43 = tempRet0;
 $lpad$phi$index = $42;$lpad$phi$index2 = $43;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z38UnityEngine_UnityEngine_Random_m_RangeP22mscorlib_System_Objectii($__this,$min,$max) {
 $__this = $__this|0;
 $min = $min|0;
 $max = $max|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2832688);
 __THREW__ = 0;
 $0 = (invoke_iiii(1435,0,($min|0),($max|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z109UnityEngine_UnityEngine_WWWForm_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP31UnityEngine_UnityEngine_WWWFormP22mscorlib_System_StringS2_($__this,$fieldName,$value) {
 $__this = $__this|0;
 $fieldName = $fieldName|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2813760);
 __THREW__ = 0;
 $0 = (invoke_ii(2390,(0|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  __THREW__ = 0;
  invoke_viiii(237,($__this|0),($fieldName|0),($value|0),($0|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z139UnityEngine_UnityEngine_WWWForm_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Text_EncodingP31UnityEngine_UnityEngine_WWWFormP22mscorlib_System_StringS2_P29mscorlib_System_Text_Encoding($__this,$fieldName,$value,$e) {
 $__this = $__this|0;
 $fieldName = $fieldName|0;
 $value = $value|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2813808);
 __THREW__ = 0;
 invoke_v(988);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = (($__this) + 12|0);
  $3 = HEAP32[$2>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($3|0));
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   invoke_viii(2110,(1331280|0),($3|0),($fieldName|0));
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    $8 = (($__this) + 16|0);
    $9 = HEAP32[$8>>2]|0;
    __THREW__ = 0;
    invoke_vi(3799,($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_viii(2110,(1331280|0),($9|0),(0|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      $14 = (($__this) + 8|0);
      $15 = HEAP32[$14>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($e|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       $18 = (invoke_iiii(1645,(2530064|0),($e|0),($value|0))|0);
       $19 = __THREW__; __THREW__ = 0;
       $20 = $19&1;
       if (!($20)) {
        __THREW__ = 0;
        invoke_vi(3799,($15|0));
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         __THREW__ = 0;
         invoke_viii(2110,(1958640|0),($15|0),($18|0));
         $23 = __THREW__; __THREW__ = 0;
         $24 = $23&1;
         if (!($24)) {
          $25 = (($__this) + 20|0);
          $26 = HEAP32[$25>>2]|0;
          __THREW__ = 0;
          invoke_vi(3799,($e|0));
          $27 = __THREW__; __THREW__ = 0;
          $28 = $27&1;
          if (!($28)) {
           __THREW__ = 0;
           $29 = (invoke_iii(2730,(2530640|0),($e|0))|0);
           $30 = __THREW__; __THREW__ = 0;
           $31 = $30&1;
           if (!($31)) {
            $32 = HEAP32[3001376>>2]|0;
            $33 = HEAP32[3001384>>2]|0;
            __THREW__ = 0;
            $34 = (invoke_iiiii(101,(0|0),($32|0),($29|0),($33|0))|0);
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if (!($36)) {
             __THREW__ = 0;
             invoke_vi(3799,($26|0));
             $37 = __THREW__; __THREW__ = 0;
             $38 = $37&1;
             if (!($38)) {
              __THREW__ = 0;
              invoke_viii(2110,(1331280|0),($26|0),($34|0));
              $39 = __THREW__; __THREW__ = 0;
              $40 = $39&1;
              if (!($40)) {
               __ZN16StackTraceSentryD2Ev(0);
               STACKTOP = sp;return;
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($41|0);
 // unreachable;
}
function __Z172UnityEngine_UnityEngine_WWWForm_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_WWWForm_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z65UnityEngine_UnityEngine_CacheIndex_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2814456)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46UnityEngine_UnityEngine_AsyncOperation_m__ctorP38UnityEngine_UnityEngine_AsyncOperation($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2814968);
 __THREW__ = 0;
 invoke_vi(3151,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48UnityEngine_UnityEngine_YieldInstruction_m__ctorP40UnityEngine_UnityEngine_YieldInstruction($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833128);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56UnityEngine_UnityEngine_AsyncOperation_m_InternalDestroyP38UnityEngine_UnityEngine_AsyncOperation($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2815016);
 $0 = HEAP32[2815064>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2815072|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2815064>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_AsyncOperation_m_FinalizeP38UnityEngine_UnityEngine_AsyncOperation($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2815120);
 __THREW__ = 0;
 invoke_vi(3085,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 18;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(18);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3846,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z126UnityEngine_UnityEngine_AsyncOperation_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AsyncOperation_m_InternalDestroyP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z41UnityEngine_UnityEngine_Behaviour_m__ctorP33UnityEngine_UnityEngine_Behaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2815448);
 __THREW__ = 0;
 invoke_vi(2851,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z47UnityEngine_UnityEngine_Behaviour_m_set_enabledP33UnityEngine_UnityEngine_Behaviourb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2815496);
 $0 = HEAP32[2815544>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2815552|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2815544>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z112UnityEngine_UnityEngine_Behaviour_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Behaviour_m_set_enabledP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z53UnityEngine_UnityEngine_Camera_CameraCallback_m__ctorP45UnityEngine_UnityEngine_Camera_CameraCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2815856);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54UnityEngine_UnityEngine_Camera_CameraCallback_m_InvokeP45UnityEngine_UnityEngine_Camera_CameraCallbackP30UnityEngine_UnityEngine_Camera($__this,$cam) {
 $__this = $__this|0;
 $cam = $cam|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2815904);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vii(2102,($1|0),($cam|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($10|0),($cam|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z59UnityEngine_UnityEngine_Camera_CameraCallback_m_BeginInvokeP45UnityEngine_UnityEngine_Camera_CameraCallbackP30UnityEngine_UnityEngine_CameraP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$cam,$callback,$object) {
 $__this = $__this|0;
 $cam = $cam|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2815952);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z57UnityEngine_UnityEngine_Camera_CameraCallback_m_EndInvokeP45UnityEngine_UnityEngine_Camera_CameraCallbackP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2816000);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z50UnityEngine_UnityEngine_Camera_m_get_nearClipPlaneP30UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2816456);
 $0 = HEAP32[2816504>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2816512|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2816504>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($__this|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z49UnityEngine_UnityEngine_Camera_m_get_farClipPlaneP30UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2816552);
 $0 = HEAP32[2816600>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2816608|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2816600>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($__this|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z48UnityEngine_UnityEngine_Camera_m_get_cullingMaskP30UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2816648);
 $0 = HEAP32[2816696>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2816704|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2816696>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_Camera_m_get_eventMaskP30UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2816744);
 $0 = HEAP32[2816792>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2816800|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2816792>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z55UnityEngine_UnityEngine_Camera_m_INTERNAL_get_pixelRectP30UnityEngine_UnityEngine_CameraP28UnityEngine_UnityEngine_Rect($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2816840);
 $0 = HEAP32[2816888>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2816896|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2816888>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z46UnityEngine_UnityEngine_Camera_m_get_pixelRectP30UnityEngine_UnityEngine_Camera($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2816960);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2104,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_Camera_m_get_targetTextureP30UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817008);
 $0 = HEAP32[2817056>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2817064|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2817056>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z47UnityEngine_UnityEngine_Camera_m_get_clearFlagsP30UnityEngine_UnityEngine_Camera($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817104);
 $0 = HEAP32[2817152>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2817160|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2817152>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z51UnityEngine_UnityEngine_Camera_m_ViewportPointToRayP30UnityEngine_UnityEngine_Camera31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$position) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817200);
 __THREW__ = 0;
 invoke_viiii(238,($agg$result|0),0,($__this|0),($position|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z65UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_ViewportPointToRayP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_CameraP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$self,$position) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $self = $self|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817248);
 $0 = HEAP32[2817296>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2817304|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2817296>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($self|0),($position|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_Camera_m_ScreenPointToRayP30UnityEngine_UnityEngine_Camera31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$position) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817400);
 __THREW__ = 0;
 invoke_viiii(239,($agg$result|0),0,($__this|0),($position|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z63UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_ScreenPointToRayP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_CameraP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$self,$position) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $self = $self|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817448);
 $0 = HEAP32[2817496>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2817504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2817496>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($self|0),($position|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z41UnityEngine_UnityEngine_Camera_m_get_mainP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817600);
 $0 = HEAP32[2817648>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2817656|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2817648>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z52UnityEngine_UnityEngine_Camera_m_get_allCamerasCountP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817688);
 $0 = HEAP32[2817736>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2817744|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2817736>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_Camera_m_GetAllCamerasP22mscorlib_System_ObjectP34UnityEngine_UnityEngine_Camera_arr($__this,$cameras) {
 $__this = $__this|0;
 $cameras = $cameras|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817792);
 $0 = HEAP32[2817840>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2817848|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2817840>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($cameras|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_Camera_m_FireOnPreCullP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Camera($__this,$cam) {
 $__this = $__this|0;
 $cam = $cam|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817904);
 __THREW__ = 0;
 (invoke_ii(2996,(2819832|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2819832 + 80|0))>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2819832|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = HEAP32[((2819832 + 80|0))>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    invoke_viii(2110,(2815904|0),($10|0),($cam|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_Camera_m_FireOnPreRenderP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Camera($__this,$cam) {
 $__this = $__this|0;
 $cam = $cam|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2817952);
 __THREW__ = 0;
 (invoke_ii(2996,(2819832|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2819832 + 80|0))>>2]|0;
  $3 = (($2) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2819832|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = HEAP32[((2819832 + 80|0))>>2]|0;
   $11 = (($10) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    invoke_viii(2110,(2815904|0),($12|0),($cam|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_Camera_m_FireOnPostRenderP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Camera($__this,$cam) {
 $__this = $__this|0;
 $cam = $cam|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2818000);
 __THREW__ = 0;
 (invoke_ii(2996,(2819832|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2819832 + 80|0))>>2]|0;
  $3 = (($2) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2819832|0))|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $10 = HEAP32[((2819832 + 80|0))>>2]|0;
   $11 = (($10) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if (!($14)) {
    __THREW__ = 0;
    invoke_viii(2110,(2815904|0),($12|0),($cam|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z43UnityEngine_UnityEngine_Camera_m_RaycastTryP30UnityEngine_UnityEngine_Camera27UnityEngine_UnityEngine_Rayfi($__this,$ray,$distance,$layerMask) {
 $__this = $__this|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $layerMask = $layerMask|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2818048);
 __THREW__ = 0;
 $0 = (invoke_iiiifi(1,0,($__this|0),($ray|0),(+$distance),($layerMask|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z57UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_RaycastTryP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_CameraP27UnityEngine_UnityEngine_Rayfi($__this,$self,$ray,$distance,$layerMask) {
 $__this = $__this|0;
 $self = $self|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $layerMask = $layerMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2818096);
 $0 = HEAP32[2818144>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2818152|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2818144>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiifi($7|0,($self|0),($ray|0),(+$distance),($layerMask|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_Camera_m_RaycastTry2DP30UnityEngine_UnityEngine_Camera27UnityEngine_UnityEngine_Rayfi($__this,$ray,$distance,$layerMask) {
 $__this = $__this|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $layerMask = $layerMask|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2818264);
 __THREW__ = 0;
 $0 = (invoke_iiiifi(2,0,($__this|0),($ray|0),(+$distance),($layerMask|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z59UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_RaycastTry2DP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_CameraP27UnityEngine_UnityEngine_Rayfi($__this,$self,$ray,$distance,$layerMask) {
 $__this = $__this|0;
 $self = $self|0;
 $ray = $ray|0;
 $distance = Math_fround($distance);
 $layerMask = $layerMask|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2818312);
 $0 = HEAP32[2818360>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2818368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2818360>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiifi($7|0,($self|0),($ray|0),(+$distance),($layerMask|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __ZN12FuncInvoker1I33UnityEngine_UnityEngine_RayTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPF27UnityEngine_UnityEngine_RayPv31UnityEngine_UnityEngine_Vector3ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast$byval_copy = sp + 24|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 FUNCTION_TABLE_viii[$func & 4095]($ret,$obj,$tmpcast$byval_copy);
 $1 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2807520,$ret)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12FuncInvoker2I33UnityEngine_UnityEngine_RayTraits17VoidPointerTraitsS1_E6InvokeEPF27UnityEngine_UnityEngine_RayPvS4_S4_ES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_viiii[$func & 511]($ret,$obj,$0,$2);
 $3 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2807520,$ret)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN12FuncInvoker3I17VoidPointerTraits33UnityEngine_UnityEngine_RayTraits28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsE6InvokeEPFPvS5_27UnityEngine_UnityEngine_RayfiES5_PS5_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$1+20>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$$byval_copy+16>>2]=HEAP32[$0+16>>2]|0;HEAP32[$$byval_copy+20>>2]=HEAP32[$0+20>>2]|0;
 $8 = (FUNCTION_TABLE_iiifi[$func & 7]($obj,$$byval_copy,$4,$7)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsE6InvokeEPFPvS4_S4_S4_fiES4_PS4_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = Math_fround(0), $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = Math_fround(HEAPF32[$4>>2]);
 $6 = (($args) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiifi[$func & 3]($obj,$0,$2,$5,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __Z112UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_nearClipPlaneP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z111UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_farClipPlaneP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_cullingMaskP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z108UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_eventMaskP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z117UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_get_pixelRectP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z112UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_targetTextureP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z109UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_clearFlagsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z127UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_ViewportPointToRayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z125UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_ScreenPointToRayP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z103UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_mainP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z114UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_allCamerasCountP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z108UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_GetAllCamerasP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z119UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_RaycastTryP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z121UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_RaycastTry2DP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z40UnityEngine_UnityEngine_Debug_m_DrawLineP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_($__this,$start,$end) {
 $__this = $__this|0;
 $start = $start|0;
 $end = $end|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_2 = 0, $V_2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_2 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2819968);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2076,($L_2|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 ;HEAP32[$V_2+0>>2]=HEAP32[$L_2+0>>2]|0;HEAP32[$V_2+4>>2]=HEAP32[$L_2+4>>2]|0;HEAP32[$V_2+8>>2]=HEAP32[$L_2+8>>2]|0;HEAP32[$V_2+12>>2]=HEAP32[$L_2+12>>2]|0;
 __THREW__ = 0;
 invoke_viiiifi(1,0,($start|0),($end|0),($V_2|0),0.0,1);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54UnityEngine_UnityEngine_Debug_m_INTERNAL_CALL_DrawLineP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_P29UnityEngine_UnityEngine_Colorfb($__this,$start,$end,$color,$duration,$depthTest) {
 $__this = $__this|0;
 $start = $start|0;
 $end = $end|0;
 $color = $color|0;
 $duration = Math_fround($duration);
 $depthTest = $depthTest|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2820016);
 $0 = HEAP32[2820064>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2820072|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2820064>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiifi($7|0,($start|0),($end|0),($color|0),(+$duration),($depthTest|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z44UnityEngine_UnityEngine_Debug_m_Internal_LogP22mscorlib_System_ObjectiP22mscorlib_System_StringP30UnityEngine_UnityEngine_Object($__this,$level,$msg,$obj) {
 $__this = $__this|0;
 $level = $level|0;
 $msg = $msg|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2820208);
 $0 = HEAP32[2820256>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2820264|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2820256>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($level|0),($msg|0),($obj|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z35UnityEngine_UnityEngine_Debug_m_LogP22mscorlib_System_ObjectS0_($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2820344);
 __THREW__ = 0;
 invoke_v(989);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($message|0)==(0|0);
   if ($2) {
    $3 = HEAP32[3001448>>2]|0;
    $G_B3_0$0 = $3;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($message|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_iii(2730,(2149112|0),($message|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $G_B3_0$0 = $8;
   }
   __THREW__ = 0;
   invoke_viiii(240,0,0,($G_B3_0$0|0),(0|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z40UnityEngine_UnityEngine_Debug_m_LogErrorP22mscorlib_System_ObjectS0_($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2820392);
 __THREW__ = 0;
 invoke_v(990);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($message|0)==(0|0);
   if ($2) {
    $3 = HEAP32[3001472>>2]|0;
    $G_B3_0$0 = $3;
   } else {
    __THREW__ = 0;
    invoke_vi(3799,($message|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    $8 = (invoke_iii(2730,(2149112|0),($message|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    $G_B3_0$0 = $8;
   }
   __THREW__ = 0;
   invoke_viiii(240,0,2,($G_B3_0$0|0),(0|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_Debug_m_LogWarningP22mscorlib_System_ObjectS0_($__this,$message) {
 $__this = $__this|0;
 $message = $message|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2820440);
 __THREW__ = 0;
 invoke_vi(3799,($message|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_iii(2730,(2149112|0),($message|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   __THREW__ = 0;
   invoke_viiii(240,0,1,($2|0),(0|0));
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __ZN14ActionInvoker5I17VoidPointerTraitsS0_S0_28mscorlib_System_SingleTraits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS4_S4_S4_fbES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($args) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($args) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)!=(0);
 FUNCTION_TABLE_viiiifi[$action & 1]($obj,$0,$2,$4,$7,$11);
 STACKTOP = sp;return (0|0);
}
function __Z101UnityEngine_UnityEngine_Debug_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Debug_m_DrawLineP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_Debug_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Debug_m_INTERNAL_CALL_DrawLineP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z105UnityEngine_UnityEngine_Debug_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Debug_m_Internal_LogP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate_m__ctorP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegateP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821008);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z64UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate_m_InvokeP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821056);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3107,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vi($8|0,($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z69UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate_m_BeginInvokeP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegateP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$callback,$object) {
 $__this = $__this|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821104);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z67UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate_m_EndInvokeP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegateP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821152);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z60UnityEngine_UnityEngine_Display_m__ctor_mscorlib_System_VoidP31UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_1 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821536);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  HEAP32[$L_1>>2] = 0;
  __THREW__ = 0;
  invoke_vii(1770,($L_1|0),0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[$L_1>>2]|0;
   $5 = (($__this) + 8|0);
   HEAP32[$5>>2] = $4;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z83UnityEngine_UnityEngine_Display_m__ctor_mscorlib_System_Void_mscorlib_System_IntPtrP31UnityEngine_UnityEngine_Display22mscorlib_System_IntPtr($__this,$nativeDisplay) {
 $__this = $__this|0;
 $nativeDisplay = $nativeDisplay|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821584);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  $2 = HEAP32[$nativeDisplay>>2]|0;
  $3 = (($__this) + 8|0);
  HEAP32[$3>>2] = $2;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z40UnityEngine_UnityEngine_Display_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821632);
 __THREW__ = 0;
 (invoke_ii(2996,(1204088|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_iii(2777,(1204088|0),1)|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if (!($6)) {
     __THREW__ = 0;
     $7 = (invoke_ii(3469,(2825200|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if (!($9)) {
      __THREW__ = 0;
      invoke_vi(3108,($7|0));
      $10 = __THREW__; __THREW__ = 0;
      $11 = $10&1;
      if (!($11)) {
       __THREW__ = 0;
       invoke_vi(3799,($2|0));
       $12 = __THREW__; __THREW__ = 0;
       $13 = $12&1;
       if (!($13)) {
        $14 = (($2) + 12|0);
        $15 = HEAP32[$14>>2]|0;
        $16 = ($15|0)==(0);
        if ($16) {
         __THREW__ = 0;
         $17 = (invoke_i(132)|0);
         $18 = __THREW__; __THREW__ = 0;
         $19 = $18&1;
         if ($19) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($17|0));
         $20 = __THREW__; __THREW__ = 0;
         $21 = $20&1;
         if ($21) {
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($2|0),($7|0));
        $24 = __THREW__; __THREW__ = 0;
        $25 = $24&1;
        if (!($25)) {
         $26 = (($2) + 16|0);
         HEAP32[$26>>2] = $7;
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if (!($28)) {
          $29 = HEAP32[((2825200 + 80|0))>>2]|0;
          HEAP32[$29>>2] = $2;
          __THREW__ = 0;
          (invoke_ii(2996,(2825200|0))|0);
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           $32 = HEAP32[((2825200 + 80|0))>>2]|0;
           $33 = HEAP32[$32>>2]|0;
           __THREW__ = 0;
           invoke_vi(3799,($33|0));
           $34 = __THREW__; __THREW__ = 0;
           $35 = $34&1;
           if (!($35)) {
            $36 = (($33) + 12|0);
            $37 = HEAP32[$36>>2]|0;
            $38 = ($37|0)==(0);
            if ($38) {
             __THREW__ = 0;
             $39 = (invoke_i(132)|0);
             $40 = __THREW__; __THREW__ = 0;
             $41 = $40&1;
             if ($41) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3302,($39|0));
             $42 = __THREW__; __THREW__ = 0;
             $43 = $42&1;
             if ($43) {
              break;
             }
            }
            $44 = (($33) + 16|0);
            $45 = HEAP32[$44>>2]|0;
            __THREW__ = 0;
            (invoke_ii(2996,(2825200|0))|0);
            $46 = __THREW__; __THREW__ = 0;
            $47 = $46&1;
            if (!($47)) {
             $48 = HEAP32[((2825200 + 80|0))>>2]|0;
             $49 = (($48) + 4|0);
             HEAP32[$49>>2] = $45;
             __THREW__ = 0;
             (invoke_ii(2996,(2825200|0))|0);
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if (!($51)) {
              $52 = HEAP32[((2825200 + 80|0))>>2]|0;
              $53 = (($52) + 8|0);
              HEAP32[$53>>2] = 0;
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($22|0);
 // unreachable;
}
function __Z55UnityEngine_UnityEngine_Display_m_add_onDisplaysUpdatedP22mscorlib_System_ObjectP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821680);
 __THREW__ = 0;
 (invoke_ii(2996,(2825200|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2825200 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3845,(2825200|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2825200|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2825200 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iiii(660,(0|0),($16|0),($value|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2821400|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_iii(2778,($17|0),(2821400|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2825200|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        $27 = HEAP8[((2825200 + 116|0))>>0]|0;
        $28 = ($27<<24>>24)==(0);
        if ($28) {
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3845,(2825200|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2825200|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         $37 = HEAP32[((2825200 + 80|0))>>2]|0;
         $38 = (($37) + 8|0);
         HEAP32[$38>>2] = $22;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo12068($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z58UnityEngine_UnityEngine_Display_m_remove_onDisplaysUpdatedP22mscorlib_System_ObjectP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821728);
 __THREW__ = 0;
 (invoke_ii(2996,(2825200|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2825200 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3845,(2825200|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2825200|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2825200 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iiii(661,(0|0),($16|0),($value|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2821400|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      $22 = (invoke_iii(2778,($17|0),(2821400|0))|0);
      $23 = __THREW__; __THREW__ = 0;
      $24 = $23&1;
      if (!($24)) {
       __THREW__ = 0;
       (invoke_ii(2996,(2825200|0))|0);
       $25 = __THREW__; __THREW__ = 0;
       $26 = $25&1;
       if (!($26)) {
        $27 = HEAP8[((2825200 + 116|0))>>0]|0;
        $28 = ($27<<24>>24)==(0);
        if ($28) {
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if ($32) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3845,(2825200|0));
         $33 = __THREW__; __THREW__ = 0;
         $34 = $33&1;
         if ($34) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2825200|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if (!($36)) {
         $37 = HEAP32[((2825200 + 80|0))>>2]|0;
         $38 = (($37) + 8|0);
         HEAP32[$38>>2] = $22;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z52UnityEngine_UnityEngine_Display_m_get_renderingWidthP31UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 $V_1 = sp + 8|0;
 $0 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821776);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(243,0,($$byval_copy|0),($V_0|0),($V_1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = HEAP32[$V_0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z53UnityEngine_UnityEngine_Display_m_GetRenderingExtImplP22mscorlib_System_Object22mscorlib_System_IntPtrPiS2_($__this,$nativeDisplay,$w,$h) {
 $__this = $__this|0;
 $nativeDisplay = $nativeDisplay|0;
 $w = $w|0;
 $h = $h|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822640);
 $1 = HEAP32[2822688>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2822696|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2822688>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$nativeDisplay>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii($9|0,($$byval_copy|0),($w|0),($h|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53UnityEngine_UnityEngine_Display_m_get_renderingHeightP31UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 $V_1 = sp + 8|0;
 $0 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821824);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(243,0,($$byval_copy|0),($V_0|0),($V_1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = HEAP32[$V_1>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z49UnityEngine_UnityEngine_Display_m_get_systemWidthP31UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 $V_1 = sp + 8|0;
 $0 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821872);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(242,0,($$byval_copy|0),($V_0|0),($V_1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = HEAP32[$V_0>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z50UnityEngine_UnityEngine_Display_m_GetSystemExtImplP22mscorlib_System_Object22mscorlib_System_IntPtrPiS2_($__this,$nativeDisplay,$w,$h) {
 $__this = $__this|0;
 $nativeDisplay = $nativeDisplay|0;
 $w = $w|0;
 $h = $h|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822496);
 $1 = HEAP32[2822544>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2822552|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2822544>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$nativeDisplay>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii($9|0,($$byval_copy|0),($w|0),($h|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z50UnityEngine_UnityEngine_Display_m_get_systemHeightP31UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $V_0 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 $V_1 = sp + 8|0;
 $0 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821920);
 HEAP32[$V_0>>2] = 0;
 HEAP32[$V_1>>2] = 0;
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(242,0,($$byval_copy|0),($V_0|0),($V_1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = HEAP32[$V_1>>2]|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z49UnityEngine_UnityEngine_Display_m_get_colorBufferP31UnityEngine_UnityEngine_Display($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_1 = sp;
 $0 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2821968);
 $1 = $agg$result;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = $V_1;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($__this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(244,0,($$byval_copy|0),($agg$result|0),($V_1|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z57UnityEngine_UnityEngine_Display_m_GetRenderingBuffersImplP22mscorlib_System_Object22mscorlib_System_IntPtrP36UnityEngine_UnityEngine_RenderBufferS3_($__this,$nativeDisplay,$color,$depth) {
 $__this = $__this|0;
 $nativeDisplay = $nativeDisplay|0;
 $color = $color|0;
 $depth = $depth|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822784);
 $1 = HEAP32[2822832>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2822840|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2822832>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$nativeDisplay>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii($9|0,($$byval_copy|0),($color|0),($depth|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z49UnityEngine_UnityEngine_Display_m_get_depthBufferP31UnityEngine_UnityEngine_Display($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 $0 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822016);
 $1 = $V_0;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = $agg$result;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($__this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$0>>2] = $10;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(244,0,($$byval_copy|0),($V_0|0),($agg$result|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($13|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z63UnityEngine_UnityEngine_Display_m_Activate_mscorlib_System_VoidP31UnityEngine_UnityEngine_Display($__this) {
 $__this = $__this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822064);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiii(81,0,($$byval_copy|0),0,0,60);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53UnityEngine_UnityEngine_Display_m_ActivateDisplayImplP22mscorlib_System_Object22mscorlib_System_IntPtriii($__this,$nativeDisplay,$width,$height,$refreshRate) {
 $__this = $__this|0;
 $nativeDisplay = $nativeDisplay|0;
 $width = $width|0;
 $height = $height|0;
 $refreshRate = $refreshRate|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2823104);
 $1 = HEAP32[2823152>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2823160|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2823152>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$nativeDisplay>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii($9|0,($$byval_copy|0),($width|0),($height|0),($refreshRate|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z129UnityEngine_UnityEngine_Display_m_Activate_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P31UnityEngine_UnityEngine_Displayiii($__this,$width,$height,$refreshRate) {
 $__this = $__this|0;
 $width = $width|0;
 $height = $height|0;
 $refreshRate = $refreshRate|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822112);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiii(81,0,($$byval_copy|0),($width|0),($height|0),($refreshRate|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z43UnityEngine_UnityEngine_Display_m_SetParamsP31UnityEngine_UnityEngine_Displayiiii($__this,$width,$height,$x,$y) {
 $__this = $__this|0;
 $width = $width|0;
 $height = $height|0;
 $x = $x|0;
 $y = $y|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822160);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiiii(69,0,($$byval_copy|0),($width|0),($height|0),($x|0),($y|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z47UnityEngine_UnityEngine_Display_m_SetParamsImplP22mscorlib_System_Object22mscorlib_System_IntPtriiii($__this,$nativeDisplay,$width,$height,$x,$y) {
 $__this = $__this|0;
 $nativeDisplay = $nativeDisplay|0;
 $width = $width|0;
 $height = $height|0;
 $x = $x|0;
 $y = $y|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2823256);
 $1 = HEAP32[2823304>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2823312|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2823304>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$nativeDisplay>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiiii($9|0,($$byval_copy|0),($width|0),($height|0),($x|0),($y|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56UnityEngine_UnityEngine_Display_m_SetRenderingResolutionP31UnityEngine_UnityEngine_Displayii($__this,$w,$h) {
 $__this = $__this|0;
 $w = $w|0;
 $h = $h|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822208);
 $1 = (($__this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viiii(245,0,($$byval_copy|0),($w|0),($h|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z60UnityEngine_UnityEngine_Display_m_SetRenderingResolutionImplP22mscorlib_System_Object22mscorlib_System_IntPtrii($__this,$nativeDisplay,$w,$h) {
 $__this = $__this|0;
 $nativeDisplay = $nativeDisplay|0;
 $w = $w|0;
 $h = $h|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822952);
 $1 = HEAP32[2823000>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_ii(3473,(2823008|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $6 = ___cxa_find_matching_catch()|0;
    $7 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($6|0);
    // unreachable;
   } else {
    HEAP32[2823000>>2] = $3;
    $9 = $3;
    break;
   }
  } else {
   $9 = $1;
  }
 } while(0);
 $8 = HEAP32[$nativeDisplay>>2]|0;
 HEAP32[$0>>2] = $8;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 invoke_viii($9|0,($$byval_copy|0),($w|0),($h|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53UnityEngine_UnityEngine_Display_m_MultiDisplayLicenseP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822256);
 __THREW__ = 0;
 $0 = (invoke_ii(2641,0)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z57UnityEngine_UnityEngine_Display_m_MultiDisplayLicenseImplP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2823416);
 $0 = HEAP32[2823464>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2823472|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2823464>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_i($7|0)|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z49UnityEngine_UnityEngine_Display_m_RelativeMouseAtP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$inputMouseCoordinates) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $inputMouseCoordinates = $inputMouseCoordinates|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = Math_fround(0), $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $V_1 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_1 = sp;
 $V_2 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822304);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 HEAP32[$V_1>>2] = 0;
 HEAP32[$V_2>>2] = 0;
 $0 = Math_fround(HEAPF32[$inputMouseCoordinates>>2]);
 $1 = (~~(($0)));
 $2 = (($inputMouseCoordinates) + 4|0);
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (~~(($3)));
 __THREW__ = 0;
 $5 = (invoke_iiiiii(141,0,($1|0),($4|0),($V_1|0),($V_2|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $8 = (Math_fround(($5|0)));
  $9 = (($agg$result) + 8|0);
  HEAPF32[$9>>2] = $8;
  $10 = HEAP32[$V_1>>2]|0;
  $11 = (Math_fround(($10|0)));
  HEAPF32[$agg$result>>2] = $11;
  $12 = HEAP32[$V_2>>2]|0;
  $13 = (Math_fround(($12|0)));
  $14 = (($agg$result) + 4|0);
  HEAPF32[$14>>2] = $13;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53UnityEngine_UnityEngine_Display_m_RelativeMouseAtImplP22mscorlib_System_ObjectiiPiS1_($__this,$x,$y,$rx,$ry) {
 $__this = $__this|0;
 $x = $x|0;
 $y = $y|0;
 $rx = $rx|0;
 $ry = $ry|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2823520);
 $0 = HEAP32[2823568>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2823576|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2823568>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iiiii($7|0,($x|0),($y|0),($rx|0),($ry|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z42UnityEngine_UnityEngine_Display_m_get_mainP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822352);
 __THREW__ = 0;
 (invoke_ii(2996,(2825200|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2825200 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3845,(2825200|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2825200|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2825200 + 80|0))>>2]|0;
    $15 = (($14) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($16|0);
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z53UnityEngine_UnityEngine_Display_m_RecreateDisplayListP22mscorlib_System_ObjectP26mscorlib_System_IntPtr_arr($__this,$nativeDisplay) {
 $__this = $__this|0;
 $nativeDisplay = $nativeDisplay|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822400);
 __THREW__ = 0;
 invoke_vi(3799,($nativeDisplay|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   $3 = (($nativeDisplay) + 12|0);
   $4 = HEAP32[$3>>2]|0;
   __THREW__ = 0;
   (invoke_ii(2996,(1204088|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_iii(2777,(1204088|0),($4|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2825200|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      $12 = HEAP8[((2825200 + 116|0))>>0]|0;
      $13 = ($12<<24>>24)==(0);
      if ($13) {
       __THREW__ = 0;
       (invoke_ii(2996,(2825200|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if ($15) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2825200|0))|0);
       $16 = __THREW__; __THREW__ = 0;
       $17 = $16&1;
       if ($17) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3845,(2825200|0));
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if ($19) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2825200|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       $26 = HEAP32[((2825200 + 80|0))>>2]|0;
       HEAP32[$26>>2] = $7;
       $27 = (($nativeDisplay) + 16|0);
       $V_0$0 = 0;
       while(1) {
        __THREW__ = 0;
        invoke_vi(3799,($nativeDisplay|0));
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 9;
         break;
        }
        $83 = HEAP32[$3>>2]|0;
        $84 = ($V_0$0|0)<($83|0);
        if (!($84)) {
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2825200|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 9;
         break;
        }
        $28 = HEAP8[((2825200 + 116|0))>>0]|0;
        $29 = ($28<<24>>24)==(0);
        if ($29) {
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $30 = __THREW__; __THREW__ = 0;
         $31 = $30&1;
         if ($31) {
          label = 9;
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          label = 9;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3845,(2825200|0));
         $34 = __THREW__; __THREW__ = 0;
         $35 = $34&1;
         if ($35) {
          label = 9;
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2825200|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         label = 9;
         break;
        }
        $38 = HEAP32[((2825200 + 80|0))>>2]|0;
        $39 = HEAP32[$38>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($nativeDisplay|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if ($41) {
         label = 9;
         break;
        }
        $42 = HEAP32[$3>>2]|0;
        $43 = ($V_0$0>>>0)<($42>>>0);
        if (!($43)) {
         __THREW__ = 0;
         $44 = (invoke_i(132)|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          label = 9;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($44|0));
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          label = 9;
          break;
         }
        }
        $49 = HEAP32[$nativeDisplay>>2]|0;
        $50 = (($49) + 92|0);
        $51 = HEAP32[$50>>2]|0;
        $52 = Math_imul($51, $V_0$0)|0;
        $53 = (($27) + ($52)|0);
        $54 = HEAP32[$53>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2825200|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 9;
         break;
        }
        __THREW__ = 0;
        $57 = (invoke_ii(3469,(2825200|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 9;
         break;
        }
        HEAP32[$0>>2] = $54;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_vii(2113,($57|0),($$byval_copy|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 9;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($39|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 9;
         break;
        }
        $64 = (($39) + 12|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = ($V_0$0>>>0)<($65>>>0);
        if (!($66)) {
         __THREW__ = 0;
         $67 = (invoke_i(132)|0);
         $68 = __THREW__; __THREW__ = 0;
         $69 = $68&1;
         if ($69) {
          label = 9;
          break;
         }
         __THREW__ = 0;
         invoke_vi(3302,($67|0));
         $70 = __THREW__; __THREW__ = 0;
         $71 = $70&1;
         if ($71) {
          label = 9;
          break;
         }
        }
        __THREW__ = 0;
        invoke_vii(3492,($39|0),($57|0));
        $72 = __THREW__; __THREW__ = 0;
        $73 = $72&1;
        if ($73) {
         label = 9;
         break;
        }
        $74 = HEAP32[$39>>2]|0;
        $75 = (($39) + 16|0);
        $76 = (($74) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_0$0)|0;
        $79 = (($75) + ($78)|0);
        HEAP32[$79>>2] = $57;
        $80 = (($V_0$0) + 1)|0;
        $V_0$0 = $80;
       }
       if ((label|0) == 9) {
        $20 = ___cxa_find_matching_catch()|0;
        $21 = tempRet0;
        $lpad$phi$index = $20;$lpad$phi$index2 = $21;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2825200|0))|0);
       $87 = __THREW__; __THREW__ = 0;
       $88 = $87&1;
       if (!($88)) {
        $89 = HEAP8[((2825200 + 116|0))>>0]|0;
        $90 = ($89<<24>>24)==(0);
        if ($90) {
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $91 = __THREW__; __THREW__ = 0;
         $92 = $91&1;
         if ($92) {
          break;
         }
         __THREW__ = 0;
         (invoke_ii(2996,(2825200|0))|0);
         $93 = __THREW__; __THREW__ = 0;
         $94 = $93&1;
         if ($94) {
          break;
         }
         __THREW__ = 0;
         invoke_vi(3845,(2825200|0));
         $95 = __THREW__; __THREW__ = 0;
         $96 = $95&1;
         if ($96) {
          break;
         }
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2825200|0))|0);
        $97 = __THREW__; __THREW__ = 0;
        $98 = $97&1;
        if (!($98)) {
         $99 = HEAP32[((2825200 + 80|0))>>2]|0;
         $100 = HEAP32[$99>>2]|0;
         __THREW__ = 0;
         invoke_vi(3799,($100|0));
         $101 = __THREW__; __THREW__ = 0;
         $102 = $101&1;
         if (!($102)) {
          $103 = (($100) + 12|0);
          $104 = HEAP32[$103>>2]|0;
          $105 = ($104|0)==(0);
          if ($105) {
           __THREW__ = 0;
           $106 = (invoke_i(132)|0);
           $107 = __THREW__; __THREW__ = 0;
           $108 = $107&1;
           if ($108) {
            break;
           }
           __THREW__ = 0;
           invoke_vi(3302,($106|0));
           $109 = __THREW__; __THREW__ = 0;
           $110 = $109&1;
           if ($110) {
            break;
           }
          }
          $111 = (($100) + 16|0);
          $112 = HEAP32[$111>>2]|0;
          __THREW__ = 0;
          (invoke_ii(2996,(2825200|0))|0);
          $113 = __THREW__; __THREW__ = 0;
          $114 = $113&1;
          if (!($114)) {
           $115 = HEAP8[((2825200 + 116|0))>>0]|0;
           $116 = ($115<<24>>24)==(0);
           if ($116) {
            __THREW__ = 0;
            (invoke_ii(2996,(2825200|0))|0);
            $117 = __THREW__; __THREW__ = 0;
            $118 = $117&1;
            if ($118) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2825200|0))|0);
            $119 = __THREW__; __THREW__ = 0;
            $120 = $119&1;
            if ($120) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3845,(2825200|0));
            $121 = __THREW__; __THREW__ = 0;
            $122 = $121&1;
            if ($122) {
             break;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(2825200|0))|0);
           $123 = __THREW__; __THREW__ = 0;
           $124 = $123&1;
           if (!($124)) {
            $125 = HEAP32[((2825200 + 80|0))>>2]|0;
            $126 = (($125) + 4|0);
            HEAP32[$126>>2] = $112;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $lpad$phi$index = $22;$lpad$phi$index2 = $23;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __Z53UnityEngine_UnityEngine_Display_m_FireDisplaysUpdatedP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2822448);
 __THREW__ = 0;
 (invoke_ii(2996,(2825200|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = HEAP8[((2825200 + 116|0))>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if ($3) {
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if ($7) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3845,(2825200|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2825200|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    $14 = HEAP32[((2825200 + 80|0))>>2]|0;
    $15 = (($14) + 8|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(0|0);
    if ($17) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2825200|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = HEAP8[((2825200 + 116|0))>>0]|0;
     $21 = ($20<<24>>24)==(0);
     if ($21) {
      __THREW__ = 0;
      (invoke_ii(2996,(2825200|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2825200|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if ($25) {
       break;
      }
      __THREW__ = 0;
      invoke_vi(3845,(2825200|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if ($27) {
       break;
      }
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2825200|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = HEAP32[((2825200 + 80|0))>>2]|0;
      $31 = (($30) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      __THREW__ = 0;
      invoke_vi(3799,($32|0));
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if (!($34)) {
       __THREW__ = 0;
       invoke_vii(3495,(2821056|0),($32|0));
       $35 = __THREW__; __THREW__ = 0;
       $36 = $35&1;
       if (!($36)) {
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZN12FuncInvoker0I42UnityEngine_UnityEngine_RenderBufferTraitsE6InvokeEPF36UnityEngine_UnityEngine_RenderBufferPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2678704,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14ActionInvoker3I28mscorlib_System_IntPtrTraits17VoidPointerTraitsS1_E6InvokeEPFvPv22mscorlib_System_IntPtrS3_S3_ES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$$byval_copy,$4,$6);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker3I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFvPv22mscorlib_System_IntPtriiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiii[$action & 511]($obj,$$byval_copy,$5,$8);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFvPv22mscorlib_System_IntPtriiiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiiii[$action & 255]($obj,$$byval_copy,$5,$8,$11);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker5I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32TraitsS1_S1_S1_E6InvokeEPFvPv22mscorlib_System_IntPtriiiiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = (($args) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($args) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($args) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($args) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 FUNCTION_TABLE_viiiiii[$action & 255]($obj,$$byval_copy,$5,$8,$11,$14);
 STACKTOP = sp;return (0|0);
}
function __ZN12FuncInvoker4I27mscorlib_System_Int32TraitsS0_S0_17VoidPointerTraitsS1_E6InvokeEPFiPviiS3_S3_ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($args) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$func & 255]($obj,$1,$4,$6,$8)|0);
 HEAP32[$ret>>2] = $9;
 $10 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($10|0);
}
function __Z113UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_GetSystemExtImplP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_GetRenderingExtImplP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z120UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_GetRenderingBuffersImplP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z123UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_SetRenderingResolutionImplP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_ActivateDisplayImplP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_SetParamsImplP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z120UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_MultiDisplayLicenseImplP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z116UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_RelativeMouseAtImplP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z45UnityEngine_UnityEngine_MonoBehaviour_m__ctorP37UnityEngine_UnityEngine_MonoBehaviour($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2825336);
 __THREW__ = 0;
 invoke_vi(3088,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z59UnityEngine_UnityEngine_MonoBehaviour_m_StartCoroutine_AutoP37UnityEngine_UnityEngine_MonoBehaviourP22mscorlib_System_Object($__this,$routine) {
 $__this = $__this|0;
 $routine = $routine|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2825384);
 $0 = HEAP32[2825432>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2825440|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2825432>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($routine|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z128UnityEngine_UnityEngine_MonoBehaviour_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_MonoBehaviour_m_StartCoroutine_AutoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z38UnityEngine_UnityEngine_Input_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2825768);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z41UnityEngine_UnityEngine_Input_m_GetKeyIntP22mscorlib_System_Objecti($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2825816);
 $0 = HEAP32[2825864>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2825872|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2825864>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($key|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z39UnityEngine_UnityEngine_Input_m_GetAxisP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$axisName) {
 $__this = $__this|0;
 $axisName = $axisName|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2825920);
 $0 = HEAP32[2825968>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2825976|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2825968>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($axisName|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z42UnityEngine_UnityEngine_Input_m_GetAxisRawP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$axisName) {
 $__this = $__this|0;
 $axisName = $axisName|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2826024);
 $0 = HEAP32[2826072>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2826080|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2826072>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($axisName|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z41UnityEngine_UnityEngine_Input_m_GetButtonP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$buttonName) {
 $__this = $__this|0;
 $buttonName = $buttonName|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2826128);
 $0 = HEAP32[2826176>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2826184|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2826176>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($buttonName|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z45UnityEngine_UnityEngine_Input_m_GetButtonDownP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$buttonName) {
 $__this = $__this|0;
 $buttonName = $buttonName|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2826232);
 $0 = HEAP32[2826280>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2826288|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2826280>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($buttonName|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z38UnityEngine_UnityEngine_Input_m_GetKeyP22mscorlib_System_Objecti($__this,$key) {
 $__this = $__this|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2826336);
 __THREW__ = 0;
 $0 = (invoke_iii(1231,0,($key|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_Input_m_GetMouseButtonP22mscorlib_System_Objecti($__this,$button) {
 $__this = $__this|0;
 $button = $button|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2826384);
 $0 = HEAP32[2826432>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2826440|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2826432>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($button|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z50UnityEngine_UnityEngine_Input_m_GetMouseButtonDownP22mscorlib_System_Objecti($__this,$button) {
 $__this = $__this|0;
 $button = $button|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2826488);
 $0 = HEAP32[2826536>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2826544|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2826536>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($button|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z46UnityEngine_UnityEngine_Input_m_ResetInputAxesP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2826600);
 $0 = HEAP32[2826648>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2826656|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2826648>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_v($7|0);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_Input_m_get_mousePositionP22mscorlib_System_Object($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2826696);
 $0 = HEAP32[2826744>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2826752|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2826744>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($agg$result|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z102UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetKeyIntP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z100UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetAxisP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z103UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetAxisRawP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z102UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetButtonP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z106UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetButtonDownP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z107UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetMouseButtonP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z111UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetMouseButtonDownP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z107UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_ResetInputAxesP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z110UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_get_mousePositionP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z57UnityEngine_UnityEngine_Transform_m_INTERNAL_get_positionP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2827448);
 $0 = HEAP32[2827496>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2827504|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2827496>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z57UnityEngine_UnityEngine_Transform_m_INTERNAL_set_positionP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2827576);
 $0 = HEAP32[2827624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2827632|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2827624>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_Transform_m_get_positionP33UnityEngine_UnityEngine_Transform($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2827704);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2120,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48UnityEngine_UnityEngine_Transform_m_set_positionP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2827752);
 __THREW__ = 0;
 invoke_vii(2121,($__this|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z51UnityEngine_UnityEngine_Transform_m_get_eulerAnglesP33UnityEngine_UnityEngine_Transform($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_0 = sp;
 $L_0 = sp + 16|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2827800);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2133,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 ;HEAP32[$V_0+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_0+12>>2]|0;
 __THREW__ = 0;
 invoke_vii(2077,($agg$result|0),($V_0|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z48UnityEngine_UnityEngine_Transform_m_get_rotationP33UnityEngine_UnityEngine_Transform($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828568);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2131,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z65UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localEulerAnglesP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2827848);
 $0 = HEAP32[2827896>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2827904|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2827896>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z65UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localEulerAnglesP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2827984);
 $0 = HEAP32[2828032>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2828040|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2828032>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z56UnityEngine_UnityEngine_Transform_m_get_localEulerAnglesP33UnityEngine_UnityEngine_Transform($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828120);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2125,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56UnityEngine_UnityEngine_Transform_m_set_localEulerAnglesP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828168);
 __THREW__ = 0;
 invoke_vii(2126,($__this|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z42UnityEngine_UnityEngine_Transform_m_get_upP33UnityEngine_UnityEngine_Transform($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $L_0$byval_copy = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_1$byval_copy = sp + 52|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp + 24|0;
 $L_1 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828216);
 __THREW__ = 0;
 invoke_vii(2133,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2073,($L_1|0),0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_0$byval_copy+12>>2]=HEAP32[$L_0+12>>2]|0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   invoke_viiii(229,($agg$result|0),0,($L_0$byval_copy|0),($L_1$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z47UnityEngine_UnityEngine_Transform_m_get_forwardP33UnityEngine_UnityEngine_Transform($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $L_0 = 0, $L_0$byval_copy = 0, $L_1 = 0, $L_1$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $L_1$byval_copy = sp + 52|0;
 $L_0$byval_copy = sp;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp + 24|0;
 $L_1 = sp + 40|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828264);
 __THREW__ = 0;
 invoke_vii(2133,($L_0|0),($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2071,($L_1|0),0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;HEAP32[$L_0$byval_copy+12>>2]=HEAP32[$L_0+12>>2]|0;
   ;HEAP32[$L_1$byval_copy+0>>2]=HEAP32[$L_1+0>>2]|0;HEAP32[$L_1$byval_copy+4>>2]=HEAP32[$L_1+4>>2]|0;HEAP32[$L_1$byval_copy+8>>2]=HEAP32[$L_1+8>>2]|0;
   invoke_viiii(229,($agg$result|0),0,($L_0$byval_copy|0),($L_1$byval_copy|0));
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z57UnityEngine_UnityEngine_Transform_m_INTERNAL_get_rotationP33UnityEngine_UnityEngine_TransformP34UnityEngine_UnityEngine_Quaternion($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828312);
 $0 = HEAP32[2828360>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2828368|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2828360>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z57UnityEngine_UnityEngine_Transform_m_INTERNAL_set_rotationP33UnityEngine_UnityEngine_TransformP34UnityEngine_UnityEngine_Quaternion($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828440);
 $0 = HEAP32[2828488>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2828496|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2828488>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_Transform_m_set_rotationP33UnityEngine_UnityEngine_Transform34UnityEngine_UnityEngine_Quaternion($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828616);
 __THREW__ = 0;
 invoke_vii(2132,($__this|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z62UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localRotationP33UnityEngine_UnityEngine_TransformP34UnityEngine_UnityEngine_Quaternion($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828664);
 $0 = HEAP32[2828712>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2828720|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2828712>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z62UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localRotationP33UnityEngine_UnityEngine_TransformP34UnityEngine_UnityEngine_Quaternion($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828800);
 $0 = HEAP32[2828848>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2828856|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2828848>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z53UnityEngine_UnityEngine_Transform_m_get_localRotationP33UnityEngine_UnityEngine_Transform($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828936);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2135,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z53UnityEngine_UnityEngine_Transform_m_set_localRotationP33UnityEngine_UnityEngine_Transform34UnityEngine_UnityEngine_Quaternion($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2828984);
 __THREW__ = 0;
 invoke_vii(2136,($__this|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z59UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localScaleP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829032);
 $0 = HEAP32[2829080>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2829088|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2829080>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z50UnityEngine_UnityEngine_Transform_m_set_localScaleP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829160);
 __THREW__ = 0;
 invoke_vii(2139,($__this|0),($value|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z67UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localToWorldMatrixP33UnityEngine_UnityEngine_TransformP33UnityEngine_UnityEngine_Matrix4x4($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829208);
 $0 = HEAP32[2829256>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2829264|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2829256>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z58UnityEngine_UnityEngine_Transform_m_get_localToWorldMatrixP33UnityEngine_UnityEngine_Transform($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829344);
 dest=$agg$result+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_vii(2141,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z125UnityEngine_UnityEngine_Transform_m_Rotate_mscorlib_System_Void_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_SpaceP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3i($__this,$eulerAngles,$relativeTo) {
 $__this = $__this|0;
 $eulerAngles = $eulerAngles|0;
 $relativeTo = $relativeTo|0;
 var $0 = Math_fround(0), $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = Math_fround(0), $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_10 = 0, $L_11 = 0, $L_12 = 0, $L_13 = 0, $L_13$byval_copy = 0, $L_3 = 0, $L_5 = 0, $L_6 = 0;
 var $L_7 = 0, $L_7$byval_copy = 0, $L_8 = 0, $L_9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $L_13$byval_copy = sp + 200|0;
 $L_7$byval_copy = sp + 184|0;
 $_stackTraceSentry = sp + 176|0;
 $V_0 = sp + 160|0;
 $L_3 = sp + 144|0;
 $L_5 = sp + 128|0;
 $L_6 = sp + 112|0;
 $L_7 = sp + 96|0;
 $L_8 = sp + 64|0;
 $L_9 = sp + 48|0;
 $L_10 = sp + 32|0;
 $L_11 = sp + 16|0;
 $L_12 = sp;
 $L_13 = sp + 80|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829392);
 ;HEAP32[$V_0+0>>2]=0|0;HEAP32[$V_0+4>>2]=0|0;HEAP32[$V_0+8>>2]=0|0;HEAP32[$V_0+12>>2]=0|0;
 $0 = Math_fround(HEAPF32[$eulerAngles>>2]);
 $1 = (($eulerAngles) + 4|0);
 $2 = Math_fround(HEAPF32[$1>>2]);
 $3 = (($eulerAngles) + 8|0);
 $4 = Math_fround(HEAPF32[$3>>2]);
 __THREW__ = 0;
 invoke_viifff(2,($L_3|0),0,(+$0),(+$2),(+$4));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 do {
  if (!($6)) {
   ;HEAP32[$V_0+0>>2]=HEAP32[$L_3+0>>2]|0;HEAP32[$V_0+4>>2]=HEAP32[$L_3+4>>2]|0;HEAP32[$V_0+8>>2]=HEAP32[$L_3+8>>2]|0;HEAP32[$V_0+12>>2]=HEAP32[$L_3+12>>2]|0;
   $7 = ($relativeTo|0)==(1);
   if ($7) {
    __THREW__ = 0;
    invoke_vii(2137,($L_5|0),($__this|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    __THREW__ = 0;
    ;HEAP32[$L_7$byval_copy+0>>2]=HEAP32[$L_5+0>>2]|0;HEAP32[$L_7$byval_copy+4>>2]=HEAP32[$L_5+4>>2]|0;HEAP32[$L_7$byval_copy+8>>2]=HEAP32[$L_5+8>>2]|0;HEAP32[$L_7$byval_copy+12>>2]=HEAP32[$L_5+12>>2]|0;
    ;HEAP32[$L_13$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_13$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_13$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;HEAP32[$L_13$byval_copy+12>>2]=HEAP32[$V_0+12>>2]|0;
    invoke_viiii(228,($L_6|0),0,($L_7$byval_copy|0),($L_13$byval_copy|0));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    __THREW__ = 0;
    ;HEAP32[$L_13$byval_copy+0>>2]=HEAP32[$L_6+0>>2]|0;HEAP32[$L_13$byval_copy+4>>2]=HEAP32[$L_6+4>>2]|0;HEAP32[$L_13$byval_copy+8>>2]=HEAP32[$L_6+8>>2]|0;HEAP32[$L_13$byval_copy+12>>2]=HEAP32[$L_6+12>>2]|0;
    invoke_vii(2138,($__this|0),($L_13$byval_copy|0));
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vii(2133,($L_7|0),($__this|0));
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    __THREW__ = 0;
    invoke_vii(2133,($L_8|0),($__this|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     ;HEAP32[$L_13$byval_copy+0>>2]=HEAP32[$L_8+0>>2]|0;HEAP32[$L_13$byval_copy+4>>2]=HEAP32[$L_8+4>>2]|0;HEAP32[$L_13$byval_copy+8>>2]=HEAP32[$L_8+8>>2]|0;HEAP32[$L_13$byval_copy+12>>2]=HEAP32[$L_8+12>>2]|0;
     invoke_viii(743,($L_9|0),0,($L_13$byval_copy|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      __THREW__ = 0;
      ;HEAP32[$L_7$byval_copy+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$L_7$byval_copy+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$L_7$byval_copy+8>>2]=HEAP32[$L_9+8>>2]|0;HEAP32[$L_7$byval_copy+12>>2]=HEAP32[$L_9+12>>2]|0;
      ;HEAP32[$L_13$byval_copy+0>>2]=HEAP32[$V_0+0>>2]|0;HEAP32[$L_13$byval_copy+4>>2]=HEAP32[$V_0+4>>2]|0;HEAP32[$L_13$byval_copy+8>>2]=HEAP32[$V_0+8>>2]|0;HEAP32[$L_13$byval_copy+12>>2]=HEAP32[$V_0+12>>2]|0;
      invoke_viiii(228,($L_10|0),0,($L_7$byval_copy|0),($L_13$byval_copy|0));
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if (!($23)) {
       __THREW__ = 0;
       invoke_vii(2133,($L_11|0),($__this|0));
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if (!($25)) {
        __THREW__ = 0;
        ;HEAP32[$L_7$byval_copy+0>>2]=HEAP32[$L_10+0>>2]|0;HEAP32[$L_7$byval_copy+4>>2]=HEAP32[$L_10+4>>2]|0;HEAP32[$L_7$byval_copy+8>>2]=HEAP32[$L_10+8>>2]|0;HEAP32[$L_7$byval_copy+12>>2]=HEAP32[$L_10+12>>2]|0;
        ;HEAP32[$L_13$byval_copy+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$L_13$byval_copy+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$L_13$byval_copy+8>>2]=HEAP32[$L_11+8>>2]|0;HEAP32[$L_13$byval_copy+12>>2]=HEAP32[$L_11+12>>2]|0;
        invoke_viiii(228,($L_12|0),0,($L_7$byval_copy|0),($L_13$byval_copy|0));
        $26 = __THREW__; __THREW__ = 0;
        $27 = $26&1;
        if (!($27)) {
         __THREW__ = 0;
         ;HEAP32[$L_7$byval_copy+0>>2]=HEAP32[$L_7+0>>2]|0;HEAP32[$L_7$byval_copy+4>>2]=HEAP32[$L_7+4>>2]|0;HEAP32[$L_7$byval_copy+8>>2]=HEAP32[$L_7+8>>2]|0;HEAP32[$L_7$byval_copy+12>>2]=HEAP32[$L_7+12>>2]|0;
         ;HEAP32[$L_13$byval_copy+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$L_13$byval_copy+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$L_13$byval_copy+8>>2]=HEAP32[$L_12+8>>2]|0;HEAP32[$L_13$byval_copy+12>>2]=HEAP32[$L_12+12>>2]|0;
         invoke_viiii(228,($L_13|0),0,($L_7$byval_copy|0),($L_13$byval_copy|0));
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if (!($29)) {
          __THREW__ = 0;
          ;HEAP32[$L_13$byval_copy+0>>2]=HEAP32[$L_13+0>>2]|0;HEAP32[$L_13$byval_copy+4>>2]=HEAP32[$L_13+4>>2]|0;HEAP32[$L_13$byval_copy+8>>2]=HEAP32[$L_13+8>>2]|0;HEAP32[$L_13$byval_copy+12>>2]=HEAP32[$L_13+12>>2]|0;
          invoke_vii(2134,($__this|0),($L_13$byval_copy|0));
          $30 = __THREW__; __THREW__ = 0;
          $31 = $30&1;
          if (!($31)) {
           __ZN16StackTraceSentryD2Ev(0);
           STACKTOP = sp;return;
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z132UnityEngine_UnityEngine_Transform_m_Rotate_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP33UnityEngine_UnityEngine_Transformfff($__this,$xAngle,$yAngle,$zAngle) {
 $__this = $__this|0;
 $xAngle = Math_fround($xAngle);
 $yAngle = Math_fround($yAngle);
 $zAngle = Math_fround($zAngle);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829440);
 __THREW__ = 0;
 invoke_vifffi(1,($__this|0),(+$xAngle),(+$yAngle),(+$zAngle),1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z162UnityEngine_UnityEngine_Transform_m_Rotate_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_UnityEngine_UnityEngine_SpaceP33UnityEngine_UnityEngine_Transformfffi($__this,$xAngle,$yAngle,$zAngle,$relativeTo) {
 $__this = $__this|0;
 $xAngle = Math_fround($xAngle);
 $yAngle = Math_fround($yAngle);
 $zAngle = Math_fround($zAngle);
 $relativeTo = $relativeTo|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $L_0 = 0, $L_0$byval_copy = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $L_0$byval_copy = sp + 16|0;
 $_stackTraceSentry = sp;
 $L_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829488);
 ;HEAP32[$L_0+0>>2]=0|0;HEAP32[$L_0+4>>2]=0|0;HEAP32[$L_0+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vifff(4,($L_0|0),(+$xAngle),(+$yAngle),(+$zAngle));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 }
 __THREW__ = 0;
 ;HEAP32[$L_0$byval_copy+0>>2]=HEAP32[$L_0+0>>2]|0;HEAP32[$L_0$byval_copy+4>>2]=HEAP32[$L_0+4>>2]|0;HEAP32[$L_0$byval_copy+8>>2]=HEAP32[$L_0+8>>2]|0;
 invoke_viii(777,($__this|0),($L_0$byval_copy|0),($relativeTo|0));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $4 = ___cxa_find_matching_catch()|0;
  $5 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($4|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z54UnityEngine_UnityEngine_Transform_m_TransformDirectionP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$direction) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $direction = $direction|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829536);
 __THREW__ = 0;
 invoke_viiii(246,($agg$result|0),0,($__this|0),($direction|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z68UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_TransformDirectionP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$self,$direction) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $self = $self|0;
 $direction = $direction|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829584);
 $0 = HEAP32[2829632>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2829640|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2829632>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($self|0),($direction|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z61UnityEngine_UnityEngine_Transform_m_InverseTransformDirectionP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$direction) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $direction = $direction|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829744);
 __THREW__ = 0;
 invoke_viiii(247,($agg$result|0),0,($__this|0),($direction|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z75UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_InverseTransformDirectionP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$self,$direction) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $self = $self|0;
 $direction = $direction|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829792);
 $0 = HEAP32[2829840>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2829848|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2829840>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($self|0),($direction|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z50UnityEngine_UnityEngine_Transform_m_TransformPointP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$position) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2829960);
 __THREW__ = 0;
 invoke_viiii(248,($agg$result|0),0,($__this|0),($position|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z64UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_TransformPointP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$self,$position) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $self = $self|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2830008);
 $0 = HEAP32[2830056>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2830064|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2830056>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($self|0),($position|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z57UnityEngine_UnityEngine_Transform_m_InverseTransformPointP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$position) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2830160);
 __THREW__ = 0;
 invoke_viiii(249,($agg$result|0),0,($__this|0),($position|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z71UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_InverseTransformPointP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3($agg$result,$__this,$self,$position) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $self = $self|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2830208);
 $0 = HEAP32[2830256>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2830264|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2830256>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viii($7|0,($agg$result|0),($self|0),($position|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN12FuncInvoker0I40UnityEngine_UnityEngine_QuaternionTraitsE6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2796280,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN14ActionInvoker1I40UnityEngine_UnityEngine_QuaternionTraitsE6InvokeEPFvPv34UnityEngine_UnityEngine_QuaternionES2_PS2_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$tmpcast$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 FUNCTION_TABLE_vii[$action & 4095]($obj,$tmpcast$byval_copy);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker2I37UnityEngine_UnityEngine_Vector3Traits27mscorlib_System_Int32TraitsE6InvokeEPFvPv31UnityEngine_UnityEngine_Vector3iES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 12|0;
 $0 = sp;
 $1 = HEAP32[$args>>2]|0;
 ;HEAP32[$0+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$1+8>>2]|0;
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 FUNCTION_TABLE_viii[$action & 4095]($obj,$$byval_copy,$4);
 STACKTOP = sp;return (0|0);
}
function __ZN14ActionInvoker4I28mscorlib_System_SingleTraitsS0_S0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvfffiES3_PS3_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (($args) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = Math_fround(HEAPF32[$3>>2]);
 $5 = (($args) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = Math_fround(HEAPF32[$6>>2]);
 $8 = (($args) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 FUNCTION_TABLE_vifffi[$action & 3]($obj,$1,$4,$7,$10);
 STACKTOP = sp;return (0|0);
}
function __Z122UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_positionP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z122UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_positionP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localEulerAnglesP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z130UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localEulerAnglesP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z122UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_rotationP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z122UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_rotationP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z127UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localRotationP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z127UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localRotationP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z124UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localScaleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z132UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localToWorldMatrixP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z197UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_Rotate_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z133UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_TransformDirectionP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z140UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_InverseTransformDirectionP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z129UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_TransformPointP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z136UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_InverseTransformPointP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Time_m_get_timeP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2832240);
 $0 = HEAP32[2832288>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2832296|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2832288>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_f($7|0))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z99UnityEngine_UnityEngine_Time_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Time_m_get_timeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z104UnityEngine_UnityEngine_Time_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Time_m_get_deltaTimeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_Random_m_RandomRangeIntP22mscorlib_System_Objectii($__this,$min,$max) {
 $__this = $__this|0;
 $min = $min|0;
 $max = $max|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2832736);
 $0 = HEAP32[2832784>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2832792|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2832784>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($min|0),($max|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z109UnityEngine_UnityEngine_Random_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Random_m_RandomRangeIntP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_Particle_m_get_positionP32UnityEngine_UnityEngine_Particle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833544);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$__this+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$__this+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$__this+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_Particle_m_set_positionP32UnityEngine_UnityEngine_Particle31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833592);
 ;HEAP32[$__this+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$__this+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$__this+8>>2]=HEAP32[$value+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_Particle_m_get_velocityP32UnityEngine_UnityEngine_Particle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833640);
 $0 = (($__this) + 12|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_Particle_m_set_velocityP32UnityEngine_UnityEngine_Particle31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833688);
 $0 = (($__this) + 12|0);
 ;HEAP32[$0+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$value+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z45UnityEngine_UnityEngine_Particle_m_get_energyP32UnityEngine_UnityEngine_Particle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833736);
 $0 = (($__this) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z45UnityEngine_UnityEngine_Particle_m_set_energyP32UnityEngine_UnityEngine_Particlef($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833784);
 $0 = (($__this) + 36|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z50UnityEngine_UnityEngine_Particle_m_get_startEnergyP32UnityEngine_UnityEngine_Particle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833832);
 $0 = (($__this) + 40|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z50UnityEngine_UnityEngine_Particle_m_set_startEnergyP32UnityEngine_UnityEngine_Particlef($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833880);
 $0 = (($__this) + 40|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z43UnityEngine_UnityEngine_Particle_m_get_sizeP32UnityEngine_UnityEngine_Particle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833928);
 $0 = (($__this) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z43UnityEngine_UnityEngine_Particle_m_set_sizeP32UnityEngine_UnityEngine_Particlef($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2833976);
 $0 = (($__this) + 24|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z47UnityEngine_UnityEngine_Particle_m_get_rotationP32UnityEngine_UnityEngine_Particle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2834024);
 $0 = (($__this) + 28|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z47UnityEngine_UnityEngine_Particle_m_set_rotationP32UnityEngine_UnityEngine_Particlef($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2834072);
 $0 = (($__this) + 28|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54UnityEngine_UnityEngine_Particle_m_get_angularVelocityP32UnityEngine_UnityEngine_Particle($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2834120);
 $0 = (($__this) + 32|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z54UnityEngine_UnityEngine_Particle_m_set_angularVelocityP32UnityEngine_UnityEngine_Particlef($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2834168);
 $0 = (($__this) + 32|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z44UnityEngine_UnityEngine_Particle_m_get_colorP32UnityEngine_UnityEngine_Particle($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2834216);
 $0 = (($__this) + 44|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$0+12>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z44UnityEngine_UnityEngine_Particle_m_set_colorP32UnityEngine_UnityEngine_Particle29UnityEngine_UnityEngine_Color($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2834264);
 $0 = (($__this) + 44|0);
 ;HEAP32[$0+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$value+12>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54UnityEngine_UnityEngine_Rigidbody_m_set_freezeRotationP33UnityEngine_UnityEngine_Rigidbodyb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2835224);
 $0 = HEAP32[2835272>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2835280|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2835272>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z119UnityEngine_UnityEngine_Rigidbody_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Rigidbody_m_set_freezeRotationP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z46UnityEngine_UnityEngine_Collider_m_set_enabledP32UnityEngine_UnityEngine_Colliderb($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2835592);
 $0 = HEAP32[2835640>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2835648|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2835640>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z54UnityEngine_UnityEngine_Collider_m_INTERNAL_get_boundsP32UnityEngine_UnityEngine_ColliderP30UnityEngine_UnityEngine_Bounds($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2835704);
 $0 = HEAP32[2835752>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2835760|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2835752>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_Collider_m_get_boundsP32UnityEngine_UnityEngine_Collider($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2835824);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;HEAP32[$agg$result+20>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2151,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN12FuncInvoker0I36UnityEngine_UnityEngine_BoundsTraitsE6InvokeEPF30UnityEngine_UnityEngine_BoundsPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2806160,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z110UnityEngine_UnityEngine_Collider_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Collider_m_set_enabledP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z118UnityEngine_UnityEngine_Collider_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Collider_m_INTERNAL_get_boundsP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z60UnityEngine_UnityEngine_ControllerColliderHit_m_get_colliderP45UnityEngine_UnityEngine_ControllerColliderHit($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2836824);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z57UnityEngine_UnityEngine_ControllerColliderHit_m_get_pointP45UnityEngine_UnityEngine_ControllerColliderHit($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2836872);
 $0 = (($__this) + 16|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z58UnityEngine_UnityEngine_ControllerColliderHit_m_get_normalP45UnityEngine_UnityEngine_ControllerColliderHit($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2836920);
 $0 = (($__this) + 28|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z65UnityEngine_UnityEngine_ControllerColliderHit_m_get_moveDirectionP45UnityEngine_UnityEngine_ControllerColliderHit($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2836968);
 $0 = (($__this) + 40|0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$0+8>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z50UnityEngine_UnityEngine_CharacterController_m_MoveP43UnityEngine_UnityEngine_CharacterController31UnityEngine_UnityEngine_Vector3($__this,$motion) {
 $__this = $__this|0;
 $motion = $motion|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2837616);
 __THREW__ = 0;
 $0 = (invoke_iiii(1438,0,($__this|0),($motion|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z64UnityEngine_UnityEngine_CharacterController_m_INTERNAL_CALL_MoveP22mscorlib_System_ObjectP43UnityEngine_UnityEngine_CharacterControllerP31UnityEngine_UnityEngine_Vector3($__this,$self,$motion) {
 $__this = $__this|0;
 $self = $self|0;
 $motion = $motion|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2837664);
 $0 = HEAP32[2837712>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2837720|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2837712>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($self|0),($motion|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z67UnityEngine_UnityEngine_CharacterController_m_INTERNAL_get_velocityP43UnityEngine_UnityEngine_CharacterControllerP31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2837832);
 $0 = HEAP32[2837880>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2837888|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2837880>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z58UnityEngine_UnityEngine_CharacterController_m_get_velocityP43UnityEngine_UnityEngine_CharacterController($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2837968);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2156,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z56UnityEngine_UnityEngine_CharacterController_m_get_radiusP43UnityEngine_UnityEngine_CharacterController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2838016);
 $0 = HEAP32[2838064>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2838072|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2838064>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($__this|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z56UnityEngine_UnityEngine_CharacterController_m_get_heightP43UnityEngine_UnityEngine_CharacterController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2838120);
 $0 = HEAP32[2838168>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2838176|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2838168>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($__this|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z65UnityEngine_UnityEngine_CharacterController_m_INTERNAL_get_centerP43UnityEngine_UnityEngine_CharacterControllerP31UnityEngine_UnityEngine_Vector3($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2838224);
 $0 = HEAP32[2838272>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2838280|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2838272>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z56UnityEngine_UnityEngine_CharacterController_m_get_centerP43UnityEngine_UnityEngine_CharacterController($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2838360);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2158,($__this|0),($agg$result|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z60UnityEngine_UnityEngine_CharacterController_m_get_slopeLimitP43UnityEngine_UnityEngine_CharacterController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2838408);
 $0 = HEAP32[2838456>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2838464|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2838456>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($__this|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z60UnityEngine_UnityEngine_CharacterController_m_get_stepOffsetP43UnityEngine_UnityEngine_CharacterController($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2838520);
 $0 = HEAP32[2838568>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2838576|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2838568>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fi($7|0,($__this|0)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __ZN12FuncInvoker1I27mscorlib_System_Int32Traits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFiPv31UnityEngine_UnityEngine_Vector3ES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $ret = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 4|0;
 $ret = sp;
 $0 = HEAP32[$args>>2]|0;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$tmpcast$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$func & 4095]($obj,$tmpcast$byval_copy)|0);
 HEAP32[$ret>>2] = $1;
 $2 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2155952,$ret)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z139UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_INTERNAL_CALL_MoveP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z142UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_INTERNAL_get_velocityP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_get_radiusP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z131UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_get_heightP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z140UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_INTERNAL_get_centerP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_get_slopeLimitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z135UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_get_stepOffsetP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z59UnityEngine_UnityEngine_AudioClip_PCMReaderCallback_m__ctorP51UnityEngine_UnityEngine_AudioClip_PCMReaderCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2839208);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z60UnityEngine_UnityEngine_AudioClip_PCMReaderCallback_m_InvokeP51UnityEngine_UnityEngine_AudioClip_PCMReaderCallbackP26mscorlib_System_Single_arr($__this,$data) {
 $__this = $__this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2839256);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vii(2160,($1|0),($data|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vii($8|0,($10|0),($data|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z65UnityEngine_UnityEngine_AudioClip_PCMReaderCallback_m_BeginInvokeP51UnityEngine_UnityEngine_AudioClip_PCMReaderCallbackP26mscorlib_System_Single_arrP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$data,$callback,$object) {
 $__this = $__this|0;
 $data = $data|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2839304);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z63UnityEngine_UnityEngine_AudioClip_PCMReaderCallback_m_EndInvokeP51UnityEngine_UnityEngine_AudioClip_PCMReaderCallbackP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2839352);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z64UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallback_m__ctorP56UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2839768);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z65UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallback_m_InvokeP56UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallbacki($__this,$position) {
 $__this = $__this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2839816);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  __THREW__ = 0;
  invoke_vii(2162,($1|0),($position|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if ($4) {
   $5 = ___cxa_find_matching_catch()|0;
   $6 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($5|0);
   // unreachable;
  }
 }
 $7 = (($__this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($__this) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 __THREW__ = 0;
 invoke_vii($8|0,($10|0),($position|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z70UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallback_m_BeginInvokeP56UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallbackiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$position,$callback,$object) {
 $__this = $__this|0;
 $position = $position|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2839864);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z68UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallback_m_EndInvokeP56UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallbackP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2839912);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z68UnityEngine_UnityEngine_AudioClip_m_InvokePCMReaderCallback_InternalP33UnityEngine_UnityEngine_AudioClipP26mscorlib_System_Single_arr($__this,$data) {
 $__this = $__this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2840328);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viii(2110,(2839256|0),($1|0),($data|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z73UnityEngine_UnityEngine_AudioClip_m_InvokePCMSetPositionCallback_InternalP33UnityEngine_UnityEngine_AudioClipi($__this,$position) {
 $__this = $__this|0;
 $position = $position|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2840376);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_viii(2111,(2839816|0),($1|0),($position|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z46UnityEngine_UnityEngine_AnimationEvent_m__ctorP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2841896);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = (($__this) + 8|0);
   HEAPF32[$2>>2] = Math_fround(0.0);
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = HEAP8[((2191608 + 116|0))>>0]|0;
    $6 = ($5<<24>>24)==(0);
    if ($6) {
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $7 = __THREW__; __THREW__ = 0;
     $8 = $7&1;
     if ($8) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3845,(2191608|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2191608|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[((2191608 + 80|0))>>2]|0;
     $18 = HEAP32[$17>>2]|0;
     $19 = (($__this) + 12|0);
     HEAP32[$19>>2] = $18;
     __THREW__ = 0;
     (invoke_ii(2996,(2191608|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP8[((2191608 + 116|0))>>0]|0;
      $23 = ($22<<24>>24)==(0);
      if ($23) {
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $24 = __THREW__; __THREW__ = 0;
       $25 = $24&1;
       if ($25) {
        break;
       }
       __THREW__ = 0;
       (invoke_ii(2996,(2191608|0))|0);
       $26 = __THREW__; __THREW__ = 0;
       $27 = $26&1;
       if ($27) {
        break;
       }
       __THREW__ = 0;
       invoke_vi(3845,(2191608|0));
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if ($29) {
        break;
       }
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2191608|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if (!($31)) {
       $32 = HEAP32[((2191608 + 80|0))>>2]|0;
       $33 = HEAP32[$32>>2]|0;
       $34 = (($__this) + 16|0);
       HEAP32[$34>>2] = $33;
       $35 = (($__this) + 20|0);
       ;HEAP32[$35+0>>2]=0|0;HEAP32[$35+4>>2]=0|0;HEAP32[$35+8>>2]=0|0;HEAP32[$35+12>>2]=0|0;HEAP32[$35+16>>2]=0|0;HEAP32[$35+20>>2]=0|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_AnimationEvent_m_get_dataP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2841944);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z49UnityEngine_UnityEngine_AnimationEvent_m_set_dataP38UnityEngine_UnityEngine_AnimationEventP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2841992);
 $0 = (($__this) + 16|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z60UnityEngine_UnityEngine_AnimationEvent_m_get_stringParameterP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842040);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z60UnityEngine_UnityEngine_AnimationEvent_m_set_stringParameterP38UnityEngine_UnityEngine_AnimationEventP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842088);
 $0 = (($__this) + 16|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z59UnityEngine_UnityEngine_AnimationEvent_m_get_floatParameterP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842136);
 $0 = (($__this) + 24|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z59UnityEngine_UnityEngine_AnimationEvent_m_set_floatParameterP38UnityEngine_UnityEngine_AnimationEventf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842184);
 $0 = (($__this) + 24|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z57UnityEngine_UnityEngine_AnimationEvent_m_get_intParameterP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842232);
 $0 = (($__this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z57UnityEngine_UnityEngine_AnimationEvent_m_set_intParameterP38UnityEngine_UnityEngine_AnimationEventi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842280);
 $0 = (($__this) + 28|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z69UnityEngine_UnityEngine_AnimationEvent_m_get_objectReferenceParameterP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842328);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z69UnityEngine_UnityEngine_AnimationEvent_m_set_objectReferenceParameterP38UnityEngine_UnityEngine_AnimationEventP30UnityEngine_UnityEngine_Object($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842376);
 $0 = (($__this) + 20|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z57UnityEngine_UnityEngine_AnimationEvent_m_get_functionNameP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842424);
 $0 = (($__this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z57UnityEngine_UnityEngine_AnimationEvent_m_set_functionNameP38UnityEngine_UnityEngine_AnimationEventP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842472);
 $0 = (($__this) + 12|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z49UnityEngine_UnityEngine_AnimationEvent_m_get_timeP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842520);
 $0 = (($__this) + 8|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z49UnityEngine_UnityEngine_AnimationEvent_m_set_timeP38UnityEngine_UnityEngine_AnimationEventf($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842568);
 $0 = (($__this) + 8|0);
 HEAPF32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z59UnityEngine_UnityEngine_AnimationEvent_m_get_messageOptionsP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842616);
 $0 = (($__this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z59UnityEngine_UnityEngine_AnimationEvent_m_set_messageOptionsP38UnityEngine_UnityEngine_AnimationEventi($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842664);
 $0 = (($__this) + 32|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z60UnityEngine_UnityEngine_AnimationEvent_m_get_isFiredByLegacyP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842712);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(1);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z62UnityEngine_UnityEngine_AnimationEvent_m_get_isFiredByAnimatorP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842760);
 $0 = (($__this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z59UnityEngine_UnityEngine_AnimationEvent_m_get_animationStateP38UnityEngine_UnityEngine_AnimationEvent($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842808);
 __THREW__ = 0;
 invoke_v(991);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(2649,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   if ($2) {
    $10 = (($__this) + 40|0);
    $11 = HEAP32[$10>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($11|0);
   }
   $7 = HEAP32[3001488>>2]|0;
   __THREW__ = 0;
   invoke_vii(2110,0,($7|0));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = (($__this) + 40|0);
    $11 = HEAP32[$10>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($11|0);
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z62UnityEngine_UnityEngine_AnimationEvent_m_get_animatorStateInfoP38UnityEngine_UnityEngine_AnimationEvent($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842856);
 __THREW__ = 0;
 invoke_v(992);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(2650,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if (!($2)) {
     $7 = HEAP32[3001704>>2]|0;
     __THREW__ = 0;
     invoke_vii(2110,0,($7|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
    }
    $10 = (($__this) + 44|0);
    ;HEAP32[$agg$result+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$agg$result+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$agg$result+16>>2]=HEAP32[$10+16>>2]|0;HEAP32[$agg$result+20>>2]=HEAP32[$10+20>>2]|0;HEAP32[$agg$result+24>>2]=HEAP32[$10+24>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z61UnityEngine_UnityEngine_AnimationEvent_m_get_animatorClipInfoP38UnityEngine_UnityEngine_AnimationEvent($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2842904);
 __THREW__ = 0;
 invoke_v(993);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(2650,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    if (!($2)) {
     $7 = HEAP32[3001928>>2]|0;
     __THREW__ = 0;
     invoke_vii(2110,0,($7|0));
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
    }
    $10 = (($__this) + 72|0);
    $11 = $10;
    $12 = $11;
    $13 = HEAP32[$12>>2]|0;
    $14 = (($11) + 4)|0;
    $15 = $14;
    $16 = HEAP32[$15>>2]|0;
    $17 = $agg$result;
    $18 = $17;
    HEAP32[$18>>2] = $13;
    $19 = (($17) + 4)|0;
    $20 = $19;
    HEAP32[$20>>2] = $16;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __ZN12FuncInvoker0I47UnityEngine_UnityEngine_AnimatorStateInfoTraitsE6InvokeEPF41UnityEngine_UnityEngine_AnimatorStateInfoPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2849248,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12FuncInvoker0I46UnityEngine_UnityEngine_AnimatorClipInfoTraitsE6InvokeEPF40UnityEngine_UnityEngine_AnimatorClipInfoPvES3_PS3_($func,$obj,$args) {
 $func = $func|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $ret = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ret = sp;
 FUNCTION_TABLE_vii[$func & 4095]($ret,$obj);
 $0 = (__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv(2848024,$ret)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z132UnityEngine_UnityEngine_AnimationEvent_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationEventTraits_data_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2844040)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z40UnityEngine_UnityEngine_Keyframe_m__ctorP32UnityEngine_UnityEngine_Keyframeff($__this,$time,$value) {
 $__this = $__this|0;
 $time = Math_fround($time);
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2844648);
 HEAPF32[$__this>>2] = $time;
 $0 = (($__this) + 4|0);
 HEAPF32[$0>>2] = $value;
 $1 = (($__this) + 8|0);
 HEAPF32[$1>>2] = Math_fround(0.0);
 $2 = (($__this) + 12|0);
 HEAPF32[$2>>2] = Math_fround(0.0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z108UnityEngine_UnityEngine_AnimationCurve_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngine_Keyframe_arr_arrP38UnityEngine_UnityEngine_AnimationCurveP36UnityEngine_UnityEngine_Keyframe_arr($__this,$keys) {
 $__this = $__this|0;
 $keys = $keys|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2845064);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2175,($__this|0),($keys|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z45UnityEngine_UnityEngine_AnimationCurve_m_InitP38UnityEngine_UnityEngine_AnimationCurveP36UnityEngine_UnityEngine_Keyframe_arr($__this,$keys) {
 $__this = $__this|0;
 $keys = $keys|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2845416);
 $0 = HEAP32[2845464>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2845472|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2845464>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($keys|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z67UnityEngine_UnityEngine_AnimationCurve_m__ctor_mscorlib_System_VoidP38UnityEngine_UnityEngine_AnimationCurve($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2845112);
 __THREW__ = 0;
 invoke_vi(1924,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(2175,($__this|0),(0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $4 = ___cxa_find_matching_catch()|0;
 $5 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($4|0);
 // unreachable;
}
function __Z48UnityEngine_UnityEngine_AnimationCurve_m_CleanupP38UnityEngine_UnityEngine_AnimationCurve($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2845160);
 $0 = HEAP32[2845208>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2845216|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2845208>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vi($7|0,($__this|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_AnimationCurve_m_FinalizeP38UnityEngine_UnityEngine_AnimationCurve($__this) {
 $__this = $__this|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__last_unhandled_exception$0 = 0, $_stackTraceSentry = 0;
 var $cond1 = 0, $leaveInstructions$sroa$0$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2845256);
 __THREW__ = 0;
 invoke_vi(3165,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch(348288|0)|0;
  $3 = tempRet0;
  $4 = (_llvm_eh_typeid_for((348288|0))|0);
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $$0 = $3;$$02 = $2;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($$02|0);
   // unreachable;
  }
  $6 = (___cxa_begin_catch(($2|0))|0);
  $7 = HEAP32[$6>>2]|0;
  __THREW__ = 0;
  invoke_v(66);
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   $__last_unhandled_exception$0 = $7;$leaveInstructions$sroa$0$0 = 0;
   label = 6;
  }
 } else {
  $__last_unhandled_exception$0 = 0;$leaveInstructions$sroa$0$0 = 18;
  label = 6;
 }
 if ((label|0) == 6) {
  __THREW__ = 0;
  invoke_vi(1925,($__this|0));
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if (!($13)) {
   $cond1 = ($leaveInstructions$sroa$0$0|0)==(18);
   if ($cond1) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3846,($__last_unhandled_exception$0|0));
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    // unreachable;
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $$0 = $11;$$02 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
}
function __Z49UnityEngine_UnityEngine_AnimationCurve_m_EvaluateP38UnityEngine_UnityEngine_AnimationCurvef($__this,$time) {
 $__this = $__this|0;
 $time = Math_fround($time);
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2845304);
 $0 = HEAP32[2845352>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2845360|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2845352>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (Math_fround(+(invoke_fif($7|0,($__this|0),(+$time)))));
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return (Math_fround($8));
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return Math_fround(0);
}
function __Z69UnityEngine_UnityEngine_AnimationCurve_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2791992)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z118UnityEngine_UnityEngine_AnimationCurve_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationCurve_m_CleanupP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z119UnityEngine_UnityEngine_AnimationCurve_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationCurve_m_EvaluateP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z115UnityEngine_UnityEngine_AnimationCurve_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationCurve_m_InitP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z44UnityEngine_UnityEngine_Animation_m_get_ItemP33UnityEngine_UnityEngine_AnimationP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2846336);
 __THREW__ = 0;
 $0 = (invoke_iii(1239,($__this|0),($name|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($3|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($0|0);
 }
 return 0|0;
}
function __Z44UnityEngine_UnityEngine_Animation_m_GetStateP33UnityEngine_UnityEngine_AnimationP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2846576);
 $0 = HEAP32[2846624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2846632|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2846624>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_iii($7|0,($__this|0),($name|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z145UnityEngine_UnityEngine_Animation_m_CrossFade_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Single_UnityEngine_UnityEngine_PlayModeP33UnityEngine_UnityEngine_AnimationP22mscorlib_System_Stringfi($__this,$animation,$fadeLength,$mode) {
 $__this = $__this|0;
 $animation = $animation|0;
 $fadeLength = Math_fround($fadeLength);
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2846384);
 $0 = HEAP32[2846432>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2846440|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2846432>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viifi($7|0,($__this|0),($animation|0),(+$fadeLength),($mode|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z89UnityEngine_UnityEngine_Animation_m_CrossFade_mscorlib_System_Void_mscorlib_System_StringP33UnityEngine_UnityEngine_AnimationP22mscorlib_System_String($__this,$animation) {
 $__this = $__this|0;
 $animation = $animation|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2846528);
 __THREW__ = 0;
 invoke_viifi(4,($__this|0),($animation|0),0.300000011920928955078,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_fiES4_PS4_($action,$obj,$args) {
 $action = $action|0;
 $obj = $obj|0;
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$args>>2]|0;
 $1 = (($args) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = Math_fround(HEAPF32[$2>>2]);
 $4 = (($args) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viifi[$action & 7]($obj,$0,$3,$6);
 STACKTOP = sp;return (0|0);
}
function __Z64UnityEngine_UnityEngine_Animation_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2252392)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2791992)|0);
 __Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z210UnityEngine_UnityEngine_Animation_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animation_m_CrossFade_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Single_UnityEngine_UnityEngine_PlayModeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z154UnityEngine_UnityEngine_Animation_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animation_m_CrossFade_mscorlib_System_Void_mscorlib_System_StringP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z109UnityEngine_UnityEngine_Animation_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animation_m_GetStateP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z53UnityEngine_UnityEngine_AnimationState_m_set_wrapModeP38UnityEngine_UnityEngine_AnimationStatei($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2847096);
 $0 = HEAP32[2847144>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2847152|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2847144>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vii($7|0,($__this|0),($value|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z50UnityEngine_UnityEngine_AnimationState_m_set_speedP38UnityEngine_UnityEngine_AnimationStatef($__this,$value) {
 $__this = $__this|0;
 $value = Math_fround($value);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2847216);
 $0 = HEAP32[2847264>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2847272|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2847264>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_vif($7|0,($__this|0),(+$value));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z123UnityEngine_UnityEngine_AnimationState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationState_m_set_wrapModeP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z120UnityEngine_UnityEngine_AnimationState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationState_m_set_speedP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z68UnityEngine_UnityEngine_AnimationInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2847632)|0);
 __Z109mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_Stringb($4,$5,1);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z50UnityEngine_UnityEngine_AnimatorStateInfo_m_IsNameP41UnityEngine_UnityEngine_AnimatorStateInfoP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B4_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848160);
 __THREW__ = 0;
 $0 = (invoke_iii(1244,0,($name|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 }
 $3 = (($__this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($0|0)==($4|0);
 if ($5) {
  $G_B4_0$0 = 1;
 } else {
  $8 = HEAP32[$__this>>2]|0;
  $9 = ($0|0)==($8|0);
  if ($9) {
   $G_B4_0$0 = 1;
  } else {
   $10 = (($__this) + 4|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($0|0)==($11|0);
   $G_B4_0$0 = $12;
  }
 }
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($G_B4_0$0|0);
}
function __Z47UnityEngine_UnityEngine_Animator_m_StringToHashP22mscorlib_System_ObjectP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2850600);
 $0 = HEAP32[2850648>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2850656|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2850648>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($name|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z60UnityEngine_UnityEngine_AnimatorStateInfo_m_get_fullPathHashP41UnityEngine_UnityEngine_AnimatorStateInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848208);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z56UnityEngine_UnityEngine_AnimatorStateInfo_m_get_nameHashP41UnityEngine_UnityEngine_AnimatorStateInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848256);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z61UnityEngine_UnityEngine_AnimatorStateInfo_m_get_shortNameHashP41UnityEngine_UnityEngine_AnimatorStateInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848304);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z62UnityEngine_UnityEngine_AnimatorStateInfo_m_get_normalizedTimeP41UnityEngine_UnityEngine_AnimatorStateInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848352);
 $0 = (($__this) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z54UnityEngine_UnityEngine_AnimatorStateInfo_m_get_lengthP41UnityEngine_UnityEngine_AnimatorStateInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848400);
 $0 = (($__this) + 16|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z55UnityEngine_UnityEngine_AnimatorStateInfo_m_get_tagHashP41UnityEngine_UnityEngine_AnimatorStateInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848448);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z49UnityEngine_UnityEngine_AnimatorStateInfo_m_IsTagP41UnityEngine_UnityEngine_AnimatorStateInfoP22mscorlib_System_String($__this,$tag) {
 $__this = $__this|0;
 $tag = $tag|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848496);
 __THREW__ = 0;
 $0 = (invoke_iii(1244,0,($tag|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $3 = (($__this) + 20|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($0|0)==($4|0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z52UnityEngine_UnityEngine_AnimatorStateInfo_m_get_loopP41UnityEngine_UnityEngine_AnimatorStateInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2848544);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z142UnityEngine_UnityEngine_AnimatorStateInfo_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimatorStateInfoTraits_nameHash_PropertyInfoP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2849032)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z55UnityEngine_UnityEngine_AnimatorTransitionInfo_m_IsNameP46UnityEngine_UnityEngine_AnimatorTransitionInfoP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849384);
 __THREW__ = 0;
 $0 = (invoke_iii(1244,0,($name|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = (($__this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($0|0)==($4|0);
  if ($5) {
   $G_B3_0$0 = 1;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B3_0$0|0);
  }
  __THREW__ = 0;
  $8 = (invoke_iii(1244,0,($name|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = HEAP32[$__this>>2]|0;
   $12 = ($8|0)==($11|0);
   $G_B3_0$0 = $12;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($G_B3_0$0|0);
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z59UnityEngine_UnityEngine_AnimatorTransitionInfo_m_IsUserNameP46UnityEngine_UnityEngine_AnimatorTransitionInfoP22mscorlib_System_String($__this,$name) {
 $__this = $__this|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849432);
 __THREW__ = 0;
 $0 = (invoke_iii(1244,0,($name|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $3 = (($__this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($0|0)==($4|0);
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z65UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_fullPathHashP46UnityEngine_UnityEngine_AnimatorTransitionInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849480);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z61UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_nameHashP46UnityEngine_UnityEngine_AnimatorTransitionInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849528);
 $0 = (($__this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z65UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_userNameHashP46UnityEngine_UnityEngine_AnimatorTransitionInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849576);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z67UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_normalizedTimeP46UnityEngine_UnityEngine_AnimatorTransitionInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849624);
 $0 = (($__this) + 12|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (Math_fround($1));
}
function __Z61UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_anyStateP46UnityEngine_UnityEngine_AnimatorTransitionInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849672);
 $0 = (($__this) + 16|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z58UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_entryP46UnityEngine_UnityEngine_AnimatorTransitionInfo($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849720);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $$lobit = $1 & 2;
 $2 = ($$lobit|0)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z57UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_exitP46UnityEngine_UnityEngine_AnimatorTransitionInfo($__this) {
 $__this = $__this|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2849768);
 $0 = (($__this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $$lobit = $1 & 4;
 $2 = ($$lobit|0)!=(0);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z127UnityEngine_UnityEngine_Animator_m_Play_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_SingleP32UnityEngine_UnityEngine_Animatoriif($__this,$stateNameHash,$layer,$normalizedTime) {
 $__this = $__this|0;
 $stateNameHash = $stateNameHash|0;
 $layer = $layer|0;
 $normalizedTime = Math_fround($normalizedTime);
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2850424);
 $0 = HEAP32[2850472>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2850480|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2850472>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  invoke_viiif($7|0,($__this|0),($stateNameHash|0),($layer|0),(+$normalizedTime));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z82UnityEngine_UnityEngine_Animator_m_Play_mscorlib_System_Void_mscorlib_System_Int32P32UnityEngine_UnityEngine_Animatori($__this,$stateNameHash) {
 $__this = $__this|0;
 $stateNameHash = $stateNameHash|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2850552);
 __THREW__ = 0;
 invoke_viiif(5,($__this|0),($stateNameHash|0),-1,-inf);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z191UnityEngine_UnityEngine_Animator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animator_m_Play_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_SingleP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z146UnityEngine_UnityEngine_Animator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animator_m_Play_mscorlib_System_Void_mscorlib_System_Int32P21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2708496)|0);
 __Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z111UnityEngine_UnityEngine_Animator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animator_m_StringToHashP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z48UnityEngine_UnityEngine_HumanBone_m_get_boneNameP33UnityEngine_UnityEngine_HumanBone($__this) {
 $__this = $__this|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2851808);
 $0 = HEAP32[$__this>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($0|0);
}
function __Z48UnityEngine_UnityEngine_HumanBone_m_set_boneNameP33UnityEngine_UnityEngine_HumanBoneP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2851856);
 HEAP32[$__this>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z49UnityEngine_UnityEngine_HumanBone_m_get_humanNameP33UnityEngine_UnityEngine_HumanBone($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2851904);
 $0 = (($__this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($1|0);
}
function __Z49UnityEngine_UnityEngine_HumanBone_m_set_humanNameP33UnityEngine_UnityEngine_HumanBoneP22mscorlib_System_String($__this,$value) {
 $__this = $__this|0;
 $value = $value|0;
 var $0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2851952);
 $0 = (($__this) + 4|0);
 HEAP32[$0>>2] = $value;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z39UnityEngine_UnityEngine_Terrain_m__ctorP31UnityEngine_UnityEngine_Terrain($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2852440);
 __THREW__ = 0;
 invoke_vi(3088,($__this|0));
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $2 = ___cxa_find_matching_catch()|0;
  $3 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($2|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z51UnityEngine_UnityEngine_CharacterInfo_m_get_advanceP37UnityEngine_UnityEngine_CharacterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854264);
 $0 = (($__this) + 36|0);
 $1 = Math_fround(HEAPF32[$0>>2]);
 $2 = (~~(($1)));
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return ($2|0);
}
function __Z54UnityEngine_UnityEngine_CharacterInfo_m_get_glyphWidthP37UnityEngine_UnityEngine_CharacterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854312);
 $0 = (($__this) + 20|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(140,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $4 = (~~(($1)));
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z55UnityEngine_UnityEngine_CharacterInfo_m_get_glyphHeightP37UnityEngine_UnityEngine_CharacterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854360);
 $0 = (($__this) + 20|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(141,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($6|0);
  // unreachable;
 } else {
  $4 = Math_fround(-$1);
  $5 = (~~(($4)));
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($5|0);
 }
 return 0|0;
}
function __Z51UnityEngine_UnityEngine_CharacterInfo_m_get_bearingP37UnityEngine_UnityEngine_CharacterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854408);
 $0 = (($__this) + 20|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(138,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $4 = (~~(($1)));
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z48UnityEngine_UnityEngine_CharacterInfo_m_get_minYP37UnityEngine_UnityEngine_CharacterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = Math_fround(0), $7 = 0, $8 = 0, $9 = Math_fround(0), $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854456);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 20|0);
 __THREW__ = 0;
 $3 = (Math_fround(+(invoke_fi(139,($2|0)))));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (Math_fround(+(invoke_fi(141,($2|0)))));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = Math_fround($3 + $6);
   $10 = (~~(($9)));
   $11 = (($10) + ($1))|0;
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($11|0);
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z48UnityEngine_UnityEngine_CharacterInfo_m_get_maxYP37UnityEngine_UnityEngine_CharacterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = Math_fround(0), $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854504);
 $0 = (($__this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($__this) + 20|0);
 __THREW__ = 0;
 $3 = (Math_fround(+(invoke_fi(139,($2|0)))));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($8|0);
  // unreachable;
 } else {
  $6 = (~~(($3)));
  $7 = (($6) + ($1))|0;
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($7|0);
 }
 return 0|0;
}
function __Z48UnityEngine_UnityEngine_CharacterInfo_m_get_minXP37UnityEngine_UnityEngine_CharacterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854552);
 $0 = (($__this) + 20|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(138,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $5 = ___cxa_find_matching_catch()|0;
  $6 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($5|0);
  // unreachable;
 } else {
  $4 = (~~(($1)));
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($4|0);
 }
 return 0|0;
}
function __Z48UnityEngine_UnityEngine_CharacterInfo_m_get_maxXP37UnityEngine_UnityEngine_CharacterInfo($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854600);
 $0 = (($__this) + 20|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(138,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (Math_fround(+(invoke_fi(140,($0|0)))));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = Math_fround($1 + $4);
   $8 = (~~(($7)));
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __Z65UnityEngine_UnityEngine_CharacterInfo_m_get_uvBottomLeftUnFlippedP37UnityEngine_UnityEngine_CharacterInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854648);
 $0 = (($__this) + 4|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(138,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (Math_fround(+(invoke_fi(139,($0|0)))));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = $agg$result;
   $8 = $7;
   HEAP32[$8>>2] = 0;
   $9 = (($7) + 4)|0;
   $10 = $9;
   HEAP32[$10>>2] = 0;
   __THREW__ = 0;
   invoke_viff(15,($agg$result|0),(+$1),(+$4));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z66UnityEngine_UnityEngine_CharacterInfo_m_get_uvBottomRightUnFlippedP37UnityEngine_UnityEngine_CharacterInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854696);
 $0 = (($__this) + 4|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(138,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (Math_fround(+(invoke_fi(140,($0|0)))));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (Math_fround(+(invoke_fi(139,($0|0)))));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = Math_fround($1 + $4);
    $11 = $agg$result;
    $12 = $11;
    HEAP32[$12>>2] = 0;
    $13 = (($11) + 4)|0;
    $14 = $13;
    HEAP32[$14>>2] = 0;
    __THREW__ = 0;
    invoke_viff(15,($agg$result|0),(+$10),(+$7));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z63UnityEngine_UnityEngine_CharacterInfo_m_get_uvTopRightUnFlippedP37UnityEngine_UnityEngine_CharacterInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = 0, $11 = Math_fround(0), $12 = 0, $13 = 0, $14 = Math_fround(0), $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0;
 var $7 = Math_fround(0), $8 = Math_fround(0), $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854744);
 $0 = (($__this) + 4|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(138,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (Math_fround(+(invoke_fi(140,($0|0)))));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   $7 = Math_fround($1 + $4);
   __THREW__ = 0;
   $8 = (Math_fround(+(invoke_fi(139,($0|0)))));
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    __THREW__ = 0;
    $11 = (Math_fround(+(invoke_fi(141,($0|0)))));
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     $14 = Math_fround($8 + $11);
     $15 = $agg$result;
     $16 = $15;
     HEAP32[$16>>2] = 0;
     $17 = (($15) + 4)|0;
     $18 = $17;
     HEAP32[$18>>2] = 0;
     __THREW__ = 0;
     invoke_viff(15,($agg$result|0),(+$7),(+$14));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
}
function __Z62UnityEngine_UnityEngine_CharacterInfo_m_get_uvTopLeftUnFlippedP37UnityEngine_UnityEngine_CharacterInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = Math_fround(0), $10 = Math_fround(0), $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = Math_fround(0), $5 = 0, $6 = 0, $7 = Math_fround(0), $8 = 0, $9 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854792);
 $0 = (($__this) + 4|0);
 __THREW__ = 0;
 $1 = (Math_fround(+(invoke_fi(138,($0|0)))));
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  $4 = (Math_fround(+(invoke_fi(139,($0|0)))));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __THREW__ = 0;
   $7 = (Math_fround(+(invoke_fi(141,($0|0)))));
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    $10 = Math_fround($4 + $7);
    $11 = $agg$result;
    $12 = $11;
    HEAP32[$12>>2] = 0;
    $13 = (($11) + 4)|0;
    $14 = $13;
    HEAP32[$14>>2] = 0;
    __THREW__ = 0;
    invoke_viff(15,($agg$result|0),(+$1),(+$10));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $17 = ___cxa_find_matching_catch()|0;
 $18 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($17|0);
 // unreachable;
}
function __Z56UnityEngine_UnityEngine_CharacterInfo_m_get_uvBottomLeftP37UnityEngine_UnityEngine_CharacterInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_2 = 0, $_stackTraceSentry = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 $L_2 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854840);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($__this) + 48|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  __THREW__ = 0;
  invoke_vii(2181,($L_2|0),($__this|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  } else {
   $storemerge$in = $L_2;
  }
 } else {
  __THREW__ = 0;
  invoke_vii(2181,($L_1|0),($__this|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  } else {
   $storemerge$in = $L_1;
  }
 }
 $13 = $storemerge$in;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $agg$result;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z57UnityEngine_UnityEngine_CharacterInfo_m_get_uvBottomRightP37UnityEngine_UnityEngine_CharacterInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_2 = 0, $_stackTraceSentry = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 $L_2 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854888);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($__this) + 48|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  __THREW__ = 0;
  invoke_vii(2182,($L_2|0),($__this|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  } else {
   $storemerge$in = $L_2;
  }
 } else {
  __THREW__ = 0;
  invoke_vii(2184,($L_1|0),($__this|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  } else {
   $storemerge$in = $L_1;
  }
 }
 $13 = $storemerge$in;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $agg$result;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z54UnityEngine_UnityEngine_CharacterInfo_m_get_uvTopRightP37UnityEngine_UnityEngine_CharacterInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_2 = 0, $_stackTraceSentry = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 $L_2 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854936);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($__this) + 48|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  __THREW__ = 0;
  invoke_vii(2183,($L_2|0),($__this|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  } else {
   $storemerge$in = $L_2;
  }
 } else {
  __THREW__ = 0;
  invoke_vii(2183,($L_1|0),($__this|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  } else {
   $storemerge$in = $L_1;
  }
 }
 $13 = $storemerge$in;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $agg$result;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z53UnityEngine_UnityEngine_CharacterInfo_m_get_uvTopLeftP37UnityEngine_UnityEngine_CharacterInfo($agg$result,$__this) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_1 = 0, $L_2 = 0, $_stackTraceSentry = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_1 = sp;
 $L_2 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2854984);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($__this) + 48|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  __THREW__ = 0;
  invoke_vii(2184,($L_2|0),($__this|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if ($12) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  } else {
   $storemerge$in = $L_2;
  }
 } else {
  __THREW__ = 0;
  invoke_vii(2182,($L_1|0),($__this|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch()|0;
   $10 = tempRet0;
   __ZN16StackTraceSentryD2Ev(0);
   ___resumeException($9|0);
   // unreachable;
  } else {
   $storemerge$in = $L_1;
  }
 }
 $13 = $storemerge$in;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $agg$result;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z71UnityEngine_UnityEngine_CharacterInfo_CustomAttributesCacheGenerator_uvP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2855672)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z73UnityEngine_UnityEngine_CharacterInfo_CustomAttributesCacheGenerator_vertP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2855776)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z74UnityEngine_UnityEngine_CharacterInfo_CustomAttributesCacheGenerator_widthP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2855848)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z76UnityEngine_UnityEngine_CharacterInfo_CustomAttributesCacheGenerator_flippedP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2248488)|0);
 $5 = (__ZN6il2cpp2vm6String10NewWrapperEPKc(2855904)|0);
 __Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String($4,$5);
 $6 = HEAP32[$3>>2]|0;
 HEAP32[$6>>2] = $4;
 STACKTOP = sp;return;
}
function __Z63UnityEngine_UnityEngine_Font_FontTextureRebuildCallback_m__ctorP55UnityEngine_UnityEngine_Font_FontTextureRebuildCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2856416);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z64UnityEngine_UnityEngine_Font_FontTextureRebuildCallback_m_InvokeP55UnityEngine_UnityEngine_Font_FontTextureRebuildCallback($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2856464);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3187,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vi($8|0,($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z69UnityEngine_UnityEngine_Font_FontTextureRebuildCallback_m_BeginInvokeP55UnityEngine_UnityEngine_Font_FontTextureRebuildCallbackP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$callback,$object) {
 $__this = $__this|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2856512);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z67UnityEngine_UnityEngine_Font_FontTextureRebuildCallback_m_EndInvokeP55UnityEngine_UnityEngine_Font_FontTextureRebuildCallbackP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2856560);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z72UnityEngine_UnityEngine_Font_m_InvokeFontTextureRebuildCallback_InternalP28UnityEngine_UnityEngine_Font($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2856952);
 $0 = (($__this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vi(3799,($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  invoke_vii(3495,(2856464|0),($1|0));
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if (!($6)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z42UnityEngine_UnityEngine_Font_m_get_dynamicP28UnityEngine_UnityEngine_Font($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2857000);
 $0 = HEAP32[2857048>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  __THREW__ = 0;
  $2 = (invoke_ii(3473,(2857056|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   HEAP32[2857048>>2] = $2;
   $7 = $2;
   label = 5;
  }
 } else {
  $7 = $0;
  label = 5;
 }
 if ((label|0) == 5) {
  __THREW__ = 0;
  $8 = (invoke_ii($7|0,($__this|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return ($8|0);
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z102UnityEngine_UnityEngine_Font_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Font_m_get_dynamicP21CustomAttributesCache($cache) {
 $cache = $cache|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$cache>>2]|0;
 $1 = $0 << 2;
 $2 = (__Z21il2cpp_gc_alloc_fixedjPv($1,0)|0);
 $3 = (($cache) + 4|0);
 HEAP32[$3>>2] = $2;
 $4 = (__ZN6il2cpp2vm6Object3NewEP8TypeInfo(2676688)|0);
 __Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall($4);
 $5 = HEAP32[$3>>2]|0;
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __Z57UnityEngine_UnityEngine_Canvas_WillRenderCanvases_m__ctorP49UnityEngine_UnityEngine_Canvas_WillRenderCanvasesP22mscorlib_System_Object22mscorlib_System_IntPtr($__this,$object,$method) {
 $__this = $__this|0;
 $object = $object|0;
 $method = $method|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2857976);
 $0 = HEAP32[$method>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__this) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = (($__this) + 20|0);
 HEAP32[$4>>2] = $0;
 $5 = (($__this) + 16|0);
 HEAP32[$5>>2] = $object;
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z58UnityEngine_UnityEngine_Canvas_WillRenderCanvases_m_InvokeP49UnityEngine_UnityEngine_Canvas_WillRenderCanvases($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2858024);
 $0 = (($__this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3190,($1|0));
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $7 = (($__this) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($__this) + 16|0);
  $10 = HEAP32[$9>>2]|0;
  __THREW__ = 0;
  invoke_vi($8|0,($10|0));
  $11 = __THREW__; __THREW__ = 0;
  $12 = $11&1;
  if (!($12)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z63UnityEngine_UnityEngine_Canvas_WillRenderCanvases_m_BeginInvokeP49UnityEngine_UnityEngine_Canvas_WillRenderCanvasesP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object($__this,$callback,$object) {
 $__this = $__this|0;
 $callback = $callback|0;
 $object = $object|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2858072);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return (0|0);
}
function __Z61UnityEngine_UnityEngine_Canvas_WillRenderCanvases_m_EndInvokeP49UnityEngine_UnityEngine_Canvas_WillRenderCanvasesP22mscorlib_System_Object($__this,$result) {
 $__this = $__this|0;
 $result = $result|0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2858120);
 __ZN16StackTraceSentryD2Ev(0);
 STACKTOP = sp;return;
}
function __Z55UnityEngine_UnityEngine_Canvas_m_SendWillRenderCanvasesP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2858504);
 __THREW__ = 0;
 (invoke_ii(2996,(2858672|0))|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  $2 = HEAP32[((2858672 + 80|0))>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
  __THREW__ = 0;
  (invoke_ii(2996,(2858672|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = HEAP32[((2858672 + 80|0))>>2]|0;
   $10 = HEAP32[$9>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($10|0));
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __THREW__ = 0;
    invoke_vii(3495,(2858024|0),($10|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if (!($14)) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
   }
  }
 }
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
}
function __Z41UnityEngine_UnityEngine_UIVertex_m__cctorP22mscorlib_System_Object($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_10 = 0;
 var $L_11 = 0, $L_14 = 0, $L_15 = 0, $L_4 = 0, $L_9 = 0, $V_0$sroa$0 = 0, $V_0$sroa$4 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $_stackTraceSentry = sp + 100|0;
 $V_0$sroa$0 = sp;
 $V_0$sroa$4 = sp + 24|0;
 $L_4 = sp + 96|0;
 $L_9 = sp + 80|0;
 $L_10 = sp + 56|0;
 $L_11 = sp + 68|0;
 $L_14 = sp + 40|0;
 $L_15 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2858808);
 ;HEAP32[$V_0$sroa$0+0>>2]=0|0;HEAP32[$V_0$sroa$0+4>>2]=0|0;HEAP32[$V_0$sroa$0+8>>2]=0|0;HEAP32[$V_0$sroa$0+12>>2]=0|0;HEAP32[$V_0$sroa$0+16>>2]=0|0;HEAP32[$V_0$sroa$0+20>>2]=0|0;
 ;HEAP32[$V_0$sroa$4+0>>2]=0|0;HEAP32[$V_0$sroa$4+4>>2]=0|0;HEAP32[$V_0$sroa$4+8>>2]=0|0;HEAP32[$V_0$sroa$4+12>>2]=0|0;
 HEAP32[$L_4>>2] = 0;
 __THREW__ = 0;
 invoke_viiiii(77,($L_4|0),-1,-1,-1,-1);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2859256|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = HEAP32[((2859256 + 80|0))>>2]|0;
   $5 = HEAP32[$L_4>>2]|0;
   HEAP8[$4>>0]=$5&255;HEAP8[$4+1>>0]=($5>>8)&255;HEAP8[$4+2>>0]=($5>>16)&255;HEAP8[$4+3>>0]=$5>>24;
   ;HEAP32[$L_9+0>>2]=0|0;HEAP32[$L_9+4>>2]=0|0;HEAP32[$L_9+8>>2]=0|0;HEAP32[$L_9+12>>2]=0|0;
   __THREW__ = 0;
   invoke_viffff(5,($L_9|0),1.0,0.0,0.0,-1.0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   if (!($7)) {
    __THREW__ = 0;
    (invoke_ii(2996,(2859256|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[((2859256 + 80|0))>>2]|0;
     $11 = (($10) + 4|0);
     ;HEAP32[$11+0>>2]=HEAP32[$L_9+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$L_9+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$L_9+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$L_9+12>>2]|0;
     __THREW__ = 0;
     invoke_vii(2070,($L_10|0),0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      ;HEAP32[$V_0$sroa$0+0>>2]=HEAP32[$L_10+0>>2]|0;HEAP32[$V_0$sroa$0+4>>2]=HEAP32[$L_10+4>>2]|0;HEAP32[$V_0$sroa$0+8>>2]=HEAP32[$L_10+8>>2]|0;
      __THREW__ = 0;
      invoke_vii(2072,($L_11|0),0);
      $14 = __THREW__; __THREW__ = 0;
      $15 = $14&1;
      if (!($15)) {
       $16 = (($V_0$sroa$0) + 12|0);
       ;HEAP32[$16+0>>2]=HEAP32[$L_11+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$L_11+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$L_11+8>>2]|0;
       __THREW__ = 0;
       (invoke_ii(2996,(2859256|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if (!($18)) {
        $19 = HEAP32[((2859256 + 80|0))>>2]|0;
        $20 = (($19) + 4|0);
        ;HEAP32[$V_0$sroa$4+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$V_0$sroa$4+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$V_0$sroa$4+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$V_0$sroa$4+12>>2]=HEAP32[$20+12>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2859256|0))|0);
        $21 = __THREW__; __THREW__ = 0;
        $22 = $21&1;
        if (!($22)) {
         $23 = HEAP32[((2859256 + 80|0))>>2]|0;
         $24 = HEAPU8[$23>>0]|(HEAPU8[$23+1>>0]<<8)|(HEAPU8[$23+2>>0]<<16)|(HEAPU8[$23+3>>0]<<24);
         __THREW__ = 0;
         invoke_vii(2068,($L_14|0),(0|0));
         $25 = __THREW__; __THREW__ = 0;
         $26 = $25&1;
         if (!($26)) {
          $27 = $L_14;
          $28 = $27;
          $29 = HEAP32[$28>>2]|0;
          $30 = (($27) + 4)|0;
          $31 = $30;
          $32 = HEAP32[$31>>2]|0;
          __THREW__ = 0;
          invoke_vii(2068,($L_15|0),(0|0));
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if (!($34)) {
           $35 = $L_15;
           $36 = $35;
           $37 = HEAP32[$36>>2]|0;
           $38 = (($35) + 4)|0;
           $39 = $38;
           $40 = HEAP32[$39>>2]|0;
           __THREW__ = 0;
           (invoke_ii(2996,(2859256|0))|0);
           $41 = __THREW__; __THREW__ = 0;
           $42 = $41&1;
           if (!($42)) {
            $43 = HEAP32[((2859256 + 80|0))>>2]|0;
            $44 = (($43) + 20|0);
            ;HEAP32[$44+0>>2]=HEAP32[$V_0$sroa$0+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$V_0$sroa$0+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$V_0$sroa$0+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$V_0$sroa$0+12>>2]|0;HEAP32[$44+16>>2]=HEAP32[$V_0$sroa$0+16>>2]|0;HEAP32[$44+20>>2]=HEAP32[$V_0$sroa$0+20>>2]|0;
            $45 = (($43) + 44|0);
            HEAP32[$45>>2] = $24;
            $46 = (($43) + 48|0);
            $47 = $46;
            $48 = $47;
            HEAP32[$48>>2] = $29;
            $49 = (($47) + 4)|0;
            $50 = $49;
            HEAP32[$50>>2] = $32;
            $51 = (($43) + 56|0);
            $52 = $51;
            $53 = $52;
            HEAP32[$53>>2] = $37;
            $54 = (($52) + 4)|0;
            $55 = $54;
            HEAP32[$55>>2] = $40;
            $56 = (($43) + 64|0);
            ;HEAP32[$56+0>>2]=HEAP32[$V_0$sroa$4+0>>2]|0;HEAP32[$56+4>>2]=HEAP32[$V_0$sroa$4+4>>2]|0;HEAP32[$56+8>>2]=HEAP32[$V_0$sroa$4+8>>2]|0;HEAP32[$56+12>>2]=HEAP32[$V_0$sroa$4+12>>2]|0;
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $57 = ___cxa_find_matching_catch()|0;
 $58 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($57|0);
 // unreachable;
}
function __Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2866824);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception12995($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __ZL70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ObjectP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharp_BJControllerP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP32AssemblyU002DCSharp_BJController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2867024);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZL77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ObjectP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP32AssemblyU002DCSharp_BJController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$mrgctx) {
 $__this = $__this|0;
 $item = $item|0;
 $mrgctx = $mrgctx|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_1$03 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2867168);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if (!($26)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = (($__this) + 16|0);
     $28 = ($item|0)==(0|0);
     $V_1$03 = 0;
     while(1) {
      $38 = HEAP32[$__this>>2]|0;
      $39 = (($38) + 28|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = (($40) + 92|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = Math_imul($42, $V_1$03)|0;
      $44 = (($27) + ($43)|0);
      _memcpy(($V_2|0),($44|0),($42|0))|0;
      $30 = HEAP32[$V_2>>2]|0;
      if ($28) {
       label = 16;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($item|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $33 = (invoke_iiii(1644,(2148736|0),($item|0),($30|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       label = 4;
       break;
      }
      $36 = (($V_1$03) + 1)|0;
      if ($33) {
       $$0 = 1;
       label = 22;
       break;
      }
      $37 = ($36|0)<($23|0);
      if ($37) {
       $V_1$03 = $36;
      } else {
       $$0 = 0;
       label = 22;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 16) {
      $29 = ($30|0)==(0|0);
      $$0 = $29;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 22) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ObjectP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP36AssemblyU002DCSharp_BJController_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2867312);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __ZL80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ObjectP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2867360);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __ZL80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ObjectP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$mrgctx) {
 $__this = $__this|0;
 $item = $item|0;
 $mrgctx = $mrgctx|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $V_1$06 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_2 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2867448);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $28 = ($item|0)==(0|0);
       $V_1$06 = 0;
       while(1) {
        $50 = HEAP32[$__this>>2]|0;
        $51 = (($50) + 28|0);
        $52 = HEAP32[$51>>2]|0;
        $53 = (($52) + 92|0);
        $54 = HEAP32[$53>>2]|0;
        $55 = Math_imul($54, $V_1$06)|0;
        $56 = (($27) + ($55)|0);
        _memcpy(($V_2|0),($56|0),($54|0))|0;
        $30 = HEAP32[$V_2>>2]|0;
        if ($28) {
         label = 16;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($30|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $41 = (invoke_iiii(1644,(2148736|0),($30|0),($item|0))|0);
        $42 = __THREW__; __THREW__ = 0;
        $43 = $42&1;
        if ($43) {
         label = 4;
         break;
        }
        $44 = (($V_1$06) + 1)|0;
        if ($41) {
         label = 24;
         break;
        }
        $49 = ($44|0)<($23|0);
        if ($49) {
         $V_1$06 = $44;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 16) {
        $29 = ($30|0)==(0|0);
        if ($29) {
         __THREW__ = 0;
         $31 = (invoke_iii(755,($__this|0),0)|0);
         $32 = __THREW__; __THREW__ = 0;
         $33 = $32&1;
         if ($33) {
          break L1;
         }
         $34 = (($31) + ($V_1$06))|0;
         $$0 = $34;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $35 = (invoke_iii(755,($__this|0),0)|0);
         $36 = __THREW__; __THREW__ = 0;
         $37 = $36&1;
         if ($37) {
          break L1;
         }
         $38 = (($35) + -1)|0;
         $$0 = $38;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 24) {
        __THREW__ = 0;
        $45 = (invoke_iii(755,($__this|0),0)|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         break L1;
        }
        $48 = (($45) + ($V_1$06))|0;
        $$0 = $48;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $57 = (invoke_iii(755,($__this|0),0)|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if (!($59)) {
      $60 = (($57) + -1)|0;
      $$0 = $60;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ObjectP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2867528);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZL68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ObjectP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$mrgctx) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 $mrgctx = $mrgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 4|0;
 $_stackTraceSentry = sp;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2867600);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $44 = (($__this) + 16|0);
       $45 = HEAP32[$__this>>2]|0;
       $46 = (($45) + 28|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = (($47) + 92|0);
       $49 = HEAP32[$48>>2]|0;
       $50 = Math_imul($49, $index)|0;
       $51 = (($44) + ($50)|0);
       _memcpy(($51|0),($0|0),($49|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      __THREW__ = 0;
      invoke_vi(3799,($21|0));
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       $27 = ($index|0)<(0);
       if ($27) {
        label = 16;
       } else {
        $28 = (($21) + 12|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = ($29>>>0)>($index>>>0);
        if (!($30)) {
         label = 16;
        }
       }
       if ((label|0) == 16) {
        __THREW__ = 0;
        $31 = (invoke_i(132)|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($31|0));
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break;
        }
       }
       __THREW__ = 0;
       invoke_vii(3492,($21|0),($item|0));
       $36 = __THREW__; __THREW__ = 0;
       $37 = $36&1;
       if (!($37)) {
        $38 = HEAP32[$21>>2]|0;
        $39 = (($21) + 16|0);
        $40 = (($38) + 92|0);
        $41 = HEAP32[$40>>2]|0;
        $42 = Math_imul($41, $index)|0;
        $43 = (($39) + ($42)|0);
        HEAP32[$43>>2] = $item;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __ZL70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ObjectP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$mrgctx) {
 $__this = $__this|0;
 $mrgctx = $mrgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2867680);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($mrgctx) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 __THREW__ = 0;
 invoke_vii($7|0,($L_0|0),($__this|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($24|0);
  // unreachable;
 }
 $10 = $L_0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $L_1;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = HEAP32[$mrgctx>>2]|0;
 __THREW__ = 0;
 $21 = (invoke_iii(2724,($20|0),($L_1|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $24 = ___cxa_find_matching_catch()|0;
  $25 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($24|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return ($21|0);
 }
 return 0|0;
}
function __ZL87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ObjectP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2867680 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP32AssemblyU002DCSharp_BJController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL79mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP32AssemblyU002DCSharp_BJController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayiP32AssemblyU002DCSharp_BJController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL80mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayiP32AssemblyU002DCSharp_BJController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharp_BJControllerP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2868000 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP32AssemblyU002DCSharp_LevelBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP32AssemblyU002DCSharp_LevelBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP36AssemblyU002DCSharp_LevelBuilder_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP32AssemblyU002DCSharp_LevelBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL79mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP32AssemblyU002DCSharp_LevelBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayiP32AssemblyU002DCSharp_LevelBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL80mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayiP32AssemblyU002DCSharp_LevelBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2868464 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z81UnityEngine_UnityEngine_Component_m_GetComponent_mscorlib_System_Object_T_gsharedP33UnityEngine_UnityEngine_ComponentPPv($__this,$mrgctx) {
 $__this = $__this|0;
 $mrgctx = $mrgctx|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2868536);
 $1 = HEAP32[$mrgctx>>2]|0;
 HEAP32[$0>>2] = $1;
 __THREW__ = 0;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iii(1189,($__this|0),($2|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   $8 = (($mrgctx) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   __THREW__ = 0;
   $10 = (invoke_iii(2779,($5|0),($9|0))|0);
   $11 = __THREW__; __THREW__ = 0;
   $12 = $11&1;
   if (!($12)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($10|0);
   }
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
 return 0|0;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo12998($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZL73UnityEngine_UnityEngine_Component_m_GetComponent_mscorlib_System_Object_TP33UnityEngine_UnityEngine_Component($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2868536 + 40|0))>>2]|0;
 $1 = (__Z81UnityEngine_UnityEngine_Component_m_GetComponent_mscorlib_System_Object_T_gsharedP33UnityEngine_UnityEngine_ComponentPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_StringP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_StringP21mscorlib_System_ArrayP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_StringP21mscorlib_System_ArrayP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_StringP21mscorlib_System_ArrayP26mscorlib_System_String_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_StringP21mscorlib_System_ArrayP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_StringP21mscorlib_System_ArrayP22mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_StringP21mscorlib_System_ArrayiP22mscorlib_System_String($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_StringP21mscorlib_System_ArrayiP22mscorlib_System_String($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_StringP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2869008 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_CharP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869056);
 HEAP16[$V_0>>1] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP16[$V_0>>1]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_CharP21mscorlib_System_Arrayt($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869104);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_CharP21mscorlib_System_Arrayt($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 12|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 6|0;
 $L_8 = sp + 8|0;
 $L_12 = sp + 10|0;
 HEAP16[$0>>1] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869152);
 HEAP16[$V_2>>1] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP16[$0>>1]|0;
      HEAP16[$L_6>>1] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2180696|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP16[$V_2>>1]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP16[$L_12>>1] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2180696|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2180696|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2180696|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP16[$L_8>>1] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2180696|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_CharP21mscorlib_System_ArrayP24mscorlib_System_Char_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869208);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z78mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_CharP21mscorlib_System_Arrayt($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869256);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_CharP21mscorlib_System_Arrayt($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 10|0;
 $L_6 = sp + 4|0;
 $L_8 = sp + 6|0;
 $L_17 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869304);
 HEAP16[$V_2>>1] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP16[$L_6>>1] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2180696|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2180696|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP16[$L_17>>1] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2180696|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2180696|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2180696|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2180696|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2180696|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2180696|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP16[$V_2>>1]|0;
        HEAP16[$L_8>>1] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2180696|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2180696|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_CharP21mscorlib_System_Arrayit($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869360);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z68mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_CharP21mscorlib_System_Arrayit($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 6|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP16[$0>>1] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869408);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP16[$L_3>>1] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2180696|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2180696|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z85mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_CharP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869464);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1218,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1311944|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1311944|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv($__this,$_____array,$newSize,$mrgctx) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 $mrgctx = $mrgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869528);
 $0 = HEAP32[$_____array>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $G_B3_0$0 = 0;
  } else {
   __THREW__ = 0;
   invoke_vi(3799,($0|0));
   $2 = __THREW__; __THREW__ = 0;
   $3 = $2&1;
   if ($3) {
    $11 = ___cxa_find_matching_catch()|0;
    $12 = tempRet0;
    __ZN16StackTraceSentryD2Ev(0);
    ___resumeException($11|0);
    // unreachable;
   } else {
    $4 = (($0) + 12|0);
    $5 = HEAP32[$4>>2]|0;
    $G_B3_0$0 = $5;
    break;
   }
  }
 } while(0);
 $6 = HEAP32[$mrgctx>>2]|0;
 $7 = (($6) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 __THREW__ = 0;
 invoke_viiii($8|0,(0|0),($_____array|0),($G_B3_0$0|0),($newSize|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($11|0);
  // unreachable;
 } else {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL117mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP26mscorlib_System_Object_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2869528 + 40|0))>>2]|0;
 __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv(0,$_____array,$newSize,$0);
 STACKTOP = sp;return;
}
function __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv($__this,$_____array,$length,$newSize,$mrgctx) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $length = $length|0;
 $newSize = $newSize|0;
 $mrgctx = $mrgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869592);
 $0 = ($newSize|0)>(-1);
 do {
  if ($0) {
   $12 = HEAP32[$_____array>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    $14 = HEAP32[$mrgctx>>2]|0;
    __THREW__ = 0;
    $15 = (invoke_iii(2780,($14|0),($newSize|0))|0);
    $16 = __THREW__; __THREW__ = 0;
    $17 = $16&1;
    if ($17) {
     break;
    }
    HEAP32[$_____array>>2] = $15;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $18 = __THREW__; __THREW__ = 0;
   $19 = $18&1;
   if (!($19)) {
    $20 = (($12) + 12|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ($21|0)==($newSize|0);
    if ($22) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    $23 = HEAP32[$mrgctx>>2]|0;
    __THREW__ = 0;
    $24 = (invoke_iii(2780,($23|0),($newSize|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = HEAP32[$_____array>>2]|0;
     __THREW__ = 0;
     $28 = (invoke_iiii(1198,(0|0),($newSize|0),($length|0))|0);
     $29 = __THREW__; __THREW__ = 0;
     $30 = $29&1;
     if (!($30)) {
      __THREW__ = 0;
      invoke_viiii(140,(0|0),($27|0),($24|0),($28|0));
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       HEAP32[$_____array>>2] = $24;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(3469,(2561352|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(2587,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      __THREW__ = 0;
      invoke_vi(3847,($3|0));
      $8 = __THREW__; __THREW__ = 0;
      $9 = $8&1;
      if (!($9)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj13002($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL139mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP26mscorlib_System_Object_arrii($__this,$p0,$p1,$p2) {
 $__this = $__this|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2869592 + 40|0))>>2]|0;
 __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv(0,$p0,$p1,$p2,$0);
 STACKTOP = sp;return;
}
function __Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv($__this,$_____array,$value,$startIndex,$count,$mrgctx) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 $mrgctx = $mrgctx|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $V_2$03 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2869648);
 __THREW__ = 0;
 invoke_v(1002);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3016328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($count|0)<(0);
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_iii(755,($_____array|0),0)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = ($20|0)>($startIndex|0);
    if (!($23)) {
     $24 = (($startIndex) + -1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     $27 = (invoke_iii(758,($_____array|0),0)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = (($27) - ($count))|0;
     $31 = ($24|0)>($30|0);
     if (!($31)) {
      $41 = (($count) + ($startIndex))|0;
      $42 = HEAP32[$mrgctx>>2]|0;
      $43 = (($42) + 4|0);
      $44 = HEAP32[$43>>2]|0;
      __THREW__ = 0;
      $45 = (invoke_ii($44|0,(0|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      $48 = ($count|0)>(0);
      if (!($48)) {
       $$0 = -1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $49 = (($_____array) + 16|0);
      $50 = (($mrgctx) + 4|0);
      $51 = (($_____array) + 12|0);
      $V_2$03 = $startIndex;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $74 = __THREW__; __THREW__ = 0;
       $75 = $74&1;
       if ($75) {
        label = 3;
        break;
       }
       $52 = ($V_2$03|0)<(0);
       if ($52) {
        label = 28;
       } else {
        $53 = HEAP32[$51>>2]|0;
        $54 = ($V_2$03>>>0)<($53>>>0);
        if (!($54)) {
         label = 28;
        }
       }
       if ((label|0) == 28) {
        label = 0;
        __THREW__ = 0;
        $55 = (invoke_i(132)|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($55|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 3;
         break;
        }
       }
       $60 = HEAP32[$_____array>>2]|0;
       $61 = (($60) + 92|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = Math_imul($62, $V_2$03)|0;
       $64 = (($49) + ($63)|0);
       $65 = HEAP32[$64>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($45|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        label = 3;
        break;
       }
       $68 = HEAP32[$50>>2]|0;
       __THREW__ = 0;
       $69 = (invoke_iiiii(300,($68|0),($45|0),($65|0),($value|0))|0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 3;
        break;
       }
       $72 = (($V_2$03) + 1)|0;
       if ($69) {
        $$0 = $V_2$03;
        label = 35;
        break;
       }
       $73 = ($72|0)<($41|0);
       if ($73) {
        $V_2$03 = $72;
       } else {
        $$0 = -1;
        label = 35;
        break;
       }
      }
      if ((label|0) == 3) {
       $3 = ___cxa_find_matching_catch()|0;
       $4 = tempRet0;
       $lpad$phi$index = $3;$lpad$phi$index2 = $4;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 35) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_ii(3469,(2561352|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __THREW__ = 0;
     invoke_vi(2587,($34|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      __THREW__ = 0;
      invoke_vi(3847,($34|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL132mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_ii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2869648 + 40|0))>>2]|0;
 $1 = (__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv(0,$_____array,$value,$startIndex,$count,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL68mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_TypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL75mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_TypeP21mscorlib_System_ArrayP20mscorlib_System_Type($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL80mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_TypeP21mscorlib_System_ArrayP20mscorlib_System_Type($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_TypeP21mscorlib_System_ArrayP24mscorlib_System_Type_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_TypeP21mscorlib_System_ArrayP20mscorlib_System_Type($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL67mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_TypeP21mscorlib_System_ArrayP20mscorlib_System_Type($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL66mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_TypeP21mscorlib_System_ArrayiP20mscorlib_System_Type($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL68mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_TypeP21mscorlib_System_ArrayiP20mscorlib_System_Type($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_TypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2870128 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP34AssemblyU002DCSharp_JSONObject_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL77mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP30AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayiP30AssemblyU002DCSharp_JSONObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL78mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayiP30AssemblyU002DCSharp_JSONObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2870592 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL125mscorlib_System_Array_m_Resize_AssemblyU002DCSharp_JSONObject_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP34AssemblyU002DCSharp_JSONObject_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2870648 + 40|0))>>2]|0;
 __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv(0,$_____array,$newSize,$0);
 STACKTOP = sp;return;
}
function __ZL147mscorlib_System_Array_m_Resize_AssemblyU002DCSharp_JSONObject_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP34AssemblyU002DCSharp_JSONObject_arrii($__this,$p0,$p1,$p2) {
 $__this = $__this|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2870704 + 40|0))>>2]|0;
 __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv(0,$p0,$p1,$p2,$0);
 STACKTOP = sp;return;
}
function __ZL140mscorlib_System_Array_m_IndexOf_AssemblyU002DCSharp_JSONObject_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP34AssemblyU002DCSharp_JSONObject_arrP30AssemblyU002DCSharp_JSONObjectii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2870760 + 40|0))>>2]|0;
 $1 = (__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv(0,$_____array,$value,$startIndex,$count,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Array_m_Resize_mscorlib_System_String_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP26mscorlib_System_String_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2870816 + 40|0))>>2]|0;
 __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv(0,$_____array,$newSize,$0);
 STACKTOP = sp;return;
}
function __ZL139mscorlib_System_Array_m_Resize_mscorlib_System_String_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP26mscorlib_System_String_arrii($__this,$p0,$p1,$p2) {
 $__this = $__this|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2870872 + 40|0))>>2]|0;
 __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv(0,$p0,$p1,$p2,$0);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Array_m_IndexOf_mscorlib_System_String_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP26mscorlib_System_String_arrP22mscorlib_System_Stringii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2870928 + 40|0))>>2]|0;
 $1 = (__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv(0,$_____array,$value,$startIndex,$count,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z153mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2870976);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3847,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z160mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871024);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z165mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871072);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(1344808|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(1344808|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1344808|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(1344808|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1344808|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(1344808|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1344808|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(1344808|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1344808|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(1344808|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z163mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871128);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z163mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871176);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z152mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871224);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1344808|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(1344808|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1344808|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(1344808|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1344808|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(1344808|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1344808|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(1344808|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(1344808|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1344808|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z151mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871280);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z153mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871328);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1344808|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(1344808|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z170mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871384);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1275,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1345432|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1345432|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871440);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871488);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871536);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2155952|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2155952|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2155952|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2155952|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2155952|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Int32P21mscorlib_System_ArrayP25mscorlib_System_Int32_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871592);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871640);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Int32P21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871688);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2155952|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2155952|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2155952|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2155952|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2155952|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2155952|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Int32P21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871744);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z69mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Int32P21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871792);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2155952|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2155952|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Int32P21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871848);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1277,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1347104|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1347104|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871904);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3847,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array40mscorlib_System_Collections_Generic_Link($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2871952);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array40mscorlib_System_Collections_Generic_Link($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872000);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(2288504|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(2288504|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2288504|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(2288504|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2288504|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(2288504|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2288504|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(2288504|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2288504|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(2288504|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_ArrayP44mscorlib_System_Collections_Generic_Link_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872056);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array40mscorlib_System_Collections_Generic_Link($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872104);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array40mscorlib_System_Collections_Generic_Link($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872152);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2288504|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(2288504|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2288504|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(2288504|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2288504|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(2288504|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2288504|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(2288504|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(2288504|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2288504|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Arrayi40mscorlib_System_Collections_Generic_Link($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872208);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z88mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Arrayi40mscorlib_System_Collections_Generic_Link($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872256);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(2288504|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(2288504|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872312);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1278,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1349368|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1349368|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_Object_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$_____array,$index,$transform,$mrgctx) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 $mrgctx = $mrgctx|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872368);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP32[$mrgctx>>2]|0;
   HEAP32[$0>>2] = $3;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $4 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if (!($8)) {
     __THREW__ = 0;
     $9 = (invoke_ii(1782,($_____array|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      __THREW__ = 0;
      invoke_vi(3799,($9|0));
      $12 = __THREW__; __THREW__ = 0;
      $13 = $12&1;
      if (!($13)) {
       __THREW__ = 0;
       $14 = (invoke_iii(2730,(2224328|0),($9|0))|0);
       $15 = __THREW__; __THREW__ = 0;
       $16 = $15&1;
       if (!($16)) {
        __THREW__ = 0;
        invoke_vi(3799,($4|0));
        $17 = __THREW__; __THREW__ = 0;
        $18 = $17&1;
        do {
         if (!($18)) {
          __THREW__ = 0;
          $19 = (invoke_iii(2734,(2234664|0),($4|0))|0);
          $20 = __THREW__; __THREW__ = 0;
          $21 = $20&1;
          if (!($21)) {
           if ($19) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($14|0));
            $36 = __THREW__; __THREW__ = 0;
            $37 = $36&1;
            if ($37) {
             break;
            }
            __THREW__ = 0;
            $38 = (invoke_iii(2734,(2234664|0),($14|0))|0);
            $39 = __THREW__; __THREW__ = 0;
            $40 = $39&1;
            if ($40) {
             break;
            }
            if ($38) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($14|0));
            $41 = __THREW__; __THREW__ = 0;
            $42 = $41&1;
            if ($42) {
             break;
            }
            __THREW__ = 0;
            $43 = (invoke_iiii(1640,(2235992|0),($14|0),($4|0))|0);
            $44 = __THREW__; __THREW__ = 0;
            $45 = $44&1;
            if ($45) {
             break;
            }
            if (!($43)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $46 = __THREW__; __THREW__ = 0;
             $47 = $46&1;
             if ($47) {
              break;
             }
             __THREW__ = 0;
             $48 = (invoke_ii(3469,(2246120|0))|0);
             $49 = __THREW__; __THREW__ = 0;
             $50 = $49&1;
             if ($50) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($48|0));
             $51 = __THREW__; __THREW__ = 0;
             $52 = $51&1;
             if ($52) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3847,($48|0));
             $53 = __THREW__; __THREW__ = 0;
             $54 = $53&1;
             if ($54) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $55 = __THREW__; __THREW__ = 0;
           $56 = $55&1;
           if (!($56)) {
            __THREW__ = 0;
            $57 = (invoke_iii(2779,($_____array|0),(1167664|0))|0);
            $58 = __THREW__; __THREW__ = 0;
            $59 = $58&1;
            if (!($59)) {
             $60 = (($mrgctx) + 4|0);
             $61 = HEAP32[$60>>2]|0;
             $62 = (($61) + 4|0);
             $63 = HEAP32[$62>>2]|0;
             __THREW__ = 0;
             invoke_viiii($63|0,($__this|0),($57|0),($index|0),($transform|0));
             $64 = __THREW__; __THREW__ = 0;
             $65 = $64&1;
             if (!($65)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $24 = ___cxa_find_matching_catch(348288|0)|0;
        $25 = tempRet0;
        $26 = (_llvm_eh_typeid_for((348288|0))|0);
        $27 = ($25|0)==($26|0);
        if (!($27)) {
         $$0 = $24;$$01 = $25;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $28 = (___cxa_begin_catch(($24|0))|0);
        $29 = HEAP32[$28>>2]|0;
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        $31 = (invoke_iii(2727,(2246120|0),($30|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        do {
         if (!($33)) {
          if (!($31)) {
           $70 = (___cxa_allocate_exception(4)|0);
           $71 = HEAP32[$28>>2]|0;
           HEAP32[$70>>2] = $71;
           __THREW__ = 0;
           invoke_viii(1567,($70|0),(348288|0),(0|0));
           $72 = __THREW__; __THREW__ = 0;
           $73 = $72&1;
           if ($73) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $34 = __THREW__; __THREW__ = 0;
          $35 = $34&1;
          if ($35) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $74 = __THREW__; __THREW__ = 0;
          $75 = $74&1;
          if ($75) {
           break L1;
          }
          __THREW__ = 0;
          $76 = (invoke_ii(3469,(2560072|0))|0);
          $77 = __THREW__; __THREW__ = 0;
          $78 = $77&1;
          if ($78) {
           break L1;
          }
          $79 = HEAP32[3020648>>2]|0;
          $80 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($76|0),($79|0),($80|0),($29|0));
          $81 = __THREW__; __THREW__ = 0;
          $82 = $81&1;
          if ($82) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3847,($76|0));
          $83 = __THREW__; __THREW__ = 0;
          $84 = $83&1;
          if ($84) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $66 = ___cxa_find_matching_catch()|0;
        $67 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         $85 = ___cxa_find_matching_catch(0|0)|0;
         $86 = tempRet0;
         ___clang_call_terminate($85);
         // unreachable;
        } else {
         $$0 = $66;$$01 = $67;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $22 = ___cxa_find_matching_catch()|0;
 $23 = tempRet0;
 $$0 = $22;$$01 = $23;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZL149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2872368 + 40|0))>>2]|0;
 __Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_Object_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$_____array,$index,$transform,$0);
 STACKTOP = sp;return;
}
function __Z170mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_CopyTo_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arriP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872448);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(330,(1354144|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2779,($66|0),(2149728|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS6_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z91mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872528);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3847,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array43mscorlib_System_Collections_DictionaryEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872576);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array43mscorlib_System_Collections_DictionaryEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872624);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(2307216|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(2307216|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2307216|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(2307216|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2307216|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(2307216|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2307216|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(2307216|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2307216|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(2307216|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_ArrayP47mscorlib_System_Collections_DictionaryEntry_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872680);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z101mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array43mscorlib_System_Collections_DictionaryEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872728);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array43mscorlib_System_Collections_DictionaryEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872776);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2307216|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(2307216|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2307216|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(2307216|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2307216|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(2307216|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2307216|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(2307216|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(2307216|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2307216|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Arrayi43mscorlib_System_Collections_DictionaryEntry($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872832);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z91mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Arrayi43mscorlib_System_Collections_DictionaryEntry($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872880);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(2307216|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(2307216|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z108mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872936);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1287,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1356024|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1356024|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z212mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP47mscorlib_System_Collections_DictionaryEntry_arriP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2872992);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(121,($L_14|0),(1354776|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(2307216|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2781,($80|0),(2307216|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo13013($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873056);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1372392;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3847,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2779,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(257,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3847,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z253mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arriP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_14 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873112);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if ($107) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(122,($L_14|0),(1357616|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1344808|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1344808|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2779,($80|0),(2149728|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break;
   }
   $90 = ($$14|0)<(0);
   if ($90) {
    label = 25;
   } else {
    $91 = HEAP32[$7>>2]|0;
    $92 = ($$14>>>0)<($91>>>0);
    if (!($92)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $93 = (invoke_i(132)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($93|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 6;
     break;
    }
   }
   $98 = HEAP32[$_____array>>2]|0;
   $99 = (($98) + 92|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = Math_imul($100, $$14)|0;
   $102 = (($6) + ($101)|0);
   HEAP32[$102>>2] = $85;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $103 = (($V_0$02) + 1)|0;
  $104 = HEAP32[$0>>2]|0;
  $105 = ($103|0)<($104|0);
  if ($105) {
   $$14 = $$0;$V_0$02 = $103;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z336mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arriP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873176);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(122,($L_14|0),(1357616|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1344808|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1344808|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1344808|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2781,($80|0),(1344808|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z153mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873240);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3847,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z160mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873288);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z165mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873336);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(1360328|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(1360328|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1360328|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(1360328|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1360328|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(1360328|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1360328|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(1360328|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1360328|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(1360328|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z163mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_ArrayP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_StringU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873392);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z163mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873440);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z152mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873488);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1360328|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(1360328|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1360328|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(1360328|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1360328|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(1360328|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1360328|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(1360328|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(1360328|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1360328|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z151mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873544);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z153mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873592);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1360328|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(1360328|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z170mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873648);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1293,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1360952|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1360952|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_ICollectionCopyTo_mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2873712 + 40|0))>>2]|0;
 __Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_Object_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$_____array,$index,$transform,$0);
 STACKTOP = sp;return;
}
function __Z170mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_StringU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP26mscorlib_System_Object_arriP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873760);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(317,(1364664|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2779,($66|0),(2149728|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z170mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP26mscorlib_System_String_arriP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873824);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(317,(1364664|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2191608|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2779,($66|0),(2191608|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z212mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP47mscorlib_System_Collections_DictionaryEntry_arriP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873888);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(123,($L_14|0),(1365192|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(2307216|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2781,($80|0),(2307216|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_ArrayiP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2873952);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1371304;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3847,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2779,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(264,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3847,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z253mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP26mscorlib_System_Object_arriP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_14 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874008);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if ($107) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(124,($L_14|0),(1365768|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1360328|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1360328|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2779,($80|0),(2149728|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break;
   }
   $90 = ($$14|0)<(0);
   if ($90) {
    label = 25;
   } else {
    $91 = HEAP32[$7>>2]|0;
    $92 = ($$14>>>0)<($91>>>0);
    if (!($92)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $93 = (invoke_i(132)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($93|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 6;
     break;
    }
   }
   $98 = HEAP32[$_____array>>2]|0;
   $99 = (($98) + 92|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = Math_imul($100, $$14)|0;
   $102 = (($6) + ($101)|0);
   HEAP32[$102>>2] = $85;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $103 = (($V_0$02) + 1)|0;
  $104 = HEAP32[$0>>2]|0;
  $105 = ($103|0)<($104|0);
  if ($105) {
   $$14 = $$0;$V_0$02 = $103;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z336mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_StringU003E_arriP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874072);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(124,($L_14|0),(1365768|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1360328|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1360328|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1360328|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2781,($80|0),(1360328|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z161mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874136);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3847,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z168mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874184);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z173mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874232);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(1378648|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(1378648|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1378648|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(1378648|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1378648|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(1378648|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1378648|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(1378648|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1378648|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(1378648|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z171mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP92mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CJSONObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874288);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z171mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874336);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z160mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874384);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1378648|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(1378648|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1378648|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(1378648|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1378648|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(1378648|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1378648|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(1378648|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(1378648|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1378648|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z159mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874440);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z161mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874488);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1378648|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(1378648|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z178mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874544);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1311,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1379392|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1379392|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL165mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_ICollectionCopyTo_AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayiP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2874608 + 40|0))>>2]|0;
 __Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_Object_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$_____array,$index,$transform,$0);
 STACKTOP = sp;return;
}
function __Z186mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_ObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP26mscorlib_System_Object_arriP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874656);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(317,(1383872|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2779,($66|0),(2149728|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z194mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP34AssemblyU002DCSharp_JSONObject_arriP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874720);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(317,(1383872|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1281560|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2779,($66|0),(1281560|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z220mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP47mscorlib_System_Collections_DictionaryEntry_arriP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874784);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(123,($L_14|0),(1384448|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(2307216|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2781,($80|0),(2307216|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z248mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayiP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874848);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1370544;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3847,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2779,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(271,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3847,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z269mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_ObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP26mscorlib_System_Object_arriP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_14 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874904);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if ($107) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(125,($L_14|0),(1385024|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1378648|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1378648|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2779,($80|0),(2149728|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break;
   }
   $90 = ($$14|0)<(0);
   if ($90) {
    label = 25;
   } else {
    $91 = HEAP32[$7>>2]|0;
    $92 = ($$14>>>0)<($91>>>0);
    if (!($92)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $93 = (invoke_i(132)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($93|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 6;
     break;
    }
   }
   $98 = HEAP32[$_____array>>2]|0;
   $99 = (($98) + 92|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = Math_imul($100, $$14)|0;
   $102 = (($6) + ($101)|0);
   HEAP32[$102>>2] = $85;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $103 = (($V_0$02) + 1)|0;
  $104 = HEAP32[$0>>2]|0;
  $105 = ($103|0)<($104|0);
  if ($105) {
   $$14 = $$0;$V_0$02 = $103;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z360mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP92mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CJSONObjectU003E_arriP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2874968);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(125,($L_14|0),(1385024|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1378648|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1378648|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1378648|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2781,($80|0),(1378648|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z86mscorlib_System_Array_m_IndexOf_mscorlib_System_Char_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP24mscorlib_System_Char_arrt($__this,$_____array,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875032);
 __THREW__ = 0;
 invoke_v(1004);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($_____array) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iiiiii(145,0,($_____array|0),($value|0),0,($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016312>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3847,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z130mscorlib_System_Array_m_IndexOf_mscorlib_System_Char_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP24mscorlib_System_Char_arrtii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $V_2$03 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875088);
 __THREW__ = 0;
 invoke_v(1002);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3016328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($count|0)<(0);
   if (!($17)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    $20 = (invoke_iii(755,($_____array|0),0)|0);
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     break;
    }
    $23 = ($20|0)>($startIndex|0);
    if (!($23)) {
     $24 = (($startIndex) + -1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     $27 = (invoke_iii(758,($_____array|0),0)|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     $30 = (($27) - ($count))|0;
     $31 = ($24|0)>($30|0);
     if (!($31)) {
      $41 = (($count) + ($startIndex))|0;
      __THREW__ = 0;
      $42 = (invoke_ii(878,(0|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       break;
      }
      $45 = ($count|0)>(0);
      if (!($45)) {
       $$0 = -1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $46 = (($_____array) + 16|0);
      $47 = (($_____array) + 12|0);
      $V_2$03 = $startIndex;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 3;
        break;
       }
       $48 = ($V_2$03|0)<(0);
       if ($48) {
        label = 28;
       } else {
        $49 = HEAP32[$47>>2]|0;
        $50 = ($V_2$03>>>0)<($49>>>0);
        if (!($50)) {
         label = 28;
        }
       }
       if ((label|0) == 28) {
        label = 0;
        __THREW__ = 0;
        $51 = (invoke_i(132)|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($51|0));
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 3;
         break;
        }
       }
       $56 = HEAP32[$_____array>>2]|0;
       $57 = (($56) + 92|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = Math_imul($58, $V_2$03)|0;
       $60 = (($46) + ($59)|0);
       $61 = HEAP16[$60>>1]|0;
       __THREW__ = 0;
       invoke_vi(3799,($42|0));
       $62 = __THREW__; __THREW__ = 0;
       $63 = $62&1;
       if ($63) {
        label = 3;
        break;
       }
       __THREW__ = 0;
       $64 = (invoke_iiiii(303,(1386360|0),($42|0),($61|0),($value|0))|0);
       $65 = __THREW__; __THREW__ = 0;
       $66 = $65&1;
       if ($66) {
        label = 3;
        break;
       }
       $67 = (($V_2$03) + 1)|0;
       if ($64) {
        $$0 = $V_2$03;
        label = 35;
        break;
       }
       $68 = ($67|0)<($41|0);
       if ($68) {
        $V_2$03 = $67;
       } else {
        $$0 = -1;
        label = 35;
        break;
       }
      }
      if ((label|0) == 3) {
       $3 = ___cxa_find_matching_catch()|0;
       $4 = tempRet0;
       $lpad$phi$index = $3;$lpad$phi$index2 = $4;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 35) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $32 = __THREW__; __THREW__ = 0;
   $33 = $32&1;
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_ii(3469,(2561352|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     __THREW__ = 0;
     invoke_vi(2587,($34|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if (!($38)) {
      __THREW__ = 0;
      invoke_vi(3847,($34|0));
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $lpad$phi$index = $5;$lpad$phi$index2 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875144);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875192);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875240);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(1273800|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(1273800|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(1273800|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(1273800|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1273800|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(1273800|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1273800|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(1273800|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(1273800|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(1273800|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_ArrayP39AssemblyU002DCSharp_JSONObject_Type_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875296);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875344);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z82mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875392);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(1273800|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(1273800|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(1273800|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(1273800|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1273800|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1273800|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1273800|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(1273800|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(1273800|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(1273800|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875448);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z83mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875496);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(1273800|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(1273800|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875552);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1322,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1388904|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1388904|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z124mscorlib_System_Array_m_InternalArray__get_Item_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875608);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3847,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z131mscorlib_System_Array_m_InternalArray__ICollection_Add_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875656);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z136mscorlib_System_Array_m_InternalArray__ICollection_Contains_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875704);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(1393256|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(1393256|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1393256|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(1393256|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1393256|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(1393256|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1393256|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(1393256|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1393256|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(1393256|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z134mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_ArrayP80System_Core_System_Collections_Generic_HashSet_1_LinkU003CSystem_ObjectU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875760);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z134mscorlib_System_Array_m_InternalArray__ICollection_Remove_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875808);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z123mscorlib_System_Array_m_InternalArray__IndexOf_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875856);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1393256|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(1393256|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1393256|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(1393256|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1393256|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(1393256|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1393256|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(1393256|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(1393256|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1393256|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z122mscorlib_System_Array_m_InternalArray__Insert_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Arrayi76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875912);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z124mscorlib_System_Array_m_InternalArray__set_Item_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Arrayi76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2875960);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1393256|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(1393256|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z141mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876016);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1325,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1393880|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1393880|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z152mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876072);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3847,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z159mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876120);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z164mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876168);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(1402568|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(1402568|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1402568|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(1402568|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1402568|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(1402568|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1402568|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(1402568|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1402568|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(1402568|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z162mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_ArrayP94mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_Int32U003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876224);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z162mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876272);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z151mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876320);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1402568|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(1402568|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1402568|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(1402568|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1402568|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(1402568|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1402568|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(1402568|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(1402568|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1402568|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z150mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876376);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z152mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876424);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1402568|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(1402568|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z169mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876480);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1335,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1403192|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1403192|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z147mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_ICollectionCopyTo_mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_ArrayiP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876536);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1285000;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3847,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2779,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(274,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3847,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z168mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Int32U002CU0020mscorlib_System_ObjectP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P26mscorlib_System_Object_arriP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_15 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876592);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $97 = __THREW__; __THREW__ = 0;
  $98 = $97&1;
  if ($98) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(326,(1406856|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   HEAP32[$L_15>>2] = $66;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2724,(2155952|0),($L_15|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $76 = (invoke_iii(2779,($71|0),(2149728|0))|0);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    label = 6;
    break;
   }
   $81 = ($$14|0)<(0);
   if ($81) {
    label = 25;
   } else {
    $82 = HEAP32[$7>>2]|0;
    $83 = ($$14>>>0)<($82>>>0);
    if (!($83)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $84 = (invoke_i(132)|0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($84|0));
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     label = 6;
     break;
    }
   }
   $89 = HEAP32[$_____array>>2]|0;
   $90 = (($89) + 92|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = Math_imul($91, $$14)|0;
   $93 = (($6) + ($92)|0);
   HEAP32[$93>>2] = $76;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $94 = (($V_0$02) + 1)|0;
  $95 = HEAP32[$0>>2]|0;
  $96 = ($94|0)<($95|0);
  if ($96) {
   $$14 = $$0;$V_0$02 = $94;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z167mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Int32U002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P25mscorlib_System_Int32_arriP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_15 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876656);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $98 = __THREW__; __THREW__ = 0;
  $99 = $98&1;
  if ($99) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(326,(1406856|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   HEAP32[$L_15>>2] = $66;
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2724,(2155952|0),($L_15|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2155952|0))|0);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $76 = (invoke_iii(2781,($71|0),(2155952|0))|0);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    label = 6;
    break;
   }
   $79 = HEAP32[$76>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    label = 6;
    break;
   }
   $82 = ($$14|0)<(0);
   if ($82) {
    label = 25;
   } else {
    $83 = HEAP32[$7>>2]|0;
    $84 = ($$14>>>0)<($83>>>0);
    if (!($84)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $85 = (invoke_i(132)|0);
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($85|0));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     label = 6;
     break;
    }
   }
   $90 = HEAP32[$_____array>>2]|0;
   $91 = (($90) + 92|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = Math_imul($92, $$14)|0;
   $94 = (($6) + ($93)|0);
   HEAP32[$94>>2] = $79;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $95 = (($V_0$02) + 1)|0;
  $96 = HEAP32[$0>>2]|0;
  $97 = ($95|0)<($96|0);
  if ($97) {
   $$14 = $$0;$V_0$02 = $95;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z211mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P47mscorlib_System_Collections_DictionaryEntry_arriP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876720);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(126,($L_14|0),(1407432|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(2307216|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2781,($80|0),(2307216|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_i($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z230mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_ArrayiP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876784);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1437112;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3847,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2779,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(278,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3847,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z251mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_ObjectP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P26mscorlib_System_Object_arriP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_14 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876840);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if ($107) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(127,($L_14|0),(1408008|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1402568|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1402568|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2779,($80|0),(2149728|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break;
   }
   $90 = ($$14|0)<(0);
   if ($90) {
    label = 25;
   } else {
    $91 = HEAP32[$7>>2]|0;
    $92 = ($$14>>>0)<($91>>>0);
    if (!($92)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $93 = (invoke_i(132)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($93|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 6;
     break;
    }
   }
   $98 = HEAP32[$_____array>>2]|0;
   $99 = (($98) + 92|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = Math_imul($100, $$14)|0;
   $102 = (($6) + ($101)|0);
   HEAP32[$102>>2] = $85;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $103 = (($V_0$02) + 1)|0;
  $104 = HEAP32[$0>>2]|0;
  $105 = ($103|0)<($104|0);
  if ($105) {
   $$14 = $$0;$V_0$02 = $103;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32Traits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_i($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z333mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P94mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_Int32U003E_arriP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2876904);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(127,($L_14|0),(1408008|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1402568|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1402568|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1402568|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2781,($80|0),(1402568|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL84mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_FieldInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_FieldInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_FieldInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_FieldInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL83mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_FieldInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayiP36mscorlib_System_Reflection_FieldInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL84mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayiP36mscorlib_System_Reflection_FieldInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2877384 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP39mscorlib_System_Reflection_PropertyInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP39mscorlib_System_Reflection_PropertyInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP43mscorlib_System_Reflection_PropertyInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP39mscorlib_System_Reflection_PropertyInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL86mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP39mscorlib_System_Reflection_PropertyInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayiP39mscorlib_System_Reflection_PropertyInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL87mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayiP39mscorlib_System_Reflection_PropertyInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2877848 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP47AssemblyU002DCSharpU002Dfirstpass_MouseLook_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL90mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayiP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL91mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayiP43AssemblyU002DCSharpU002Dfirstpass_MouseLook($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2878312 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z104mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878368);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878416);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z116mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878464);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(1270104|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(1270104|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(1270104|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(1270104|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1270104|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(1270104|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1270104|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(1270104|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(1270104|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(1270104|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_ArrayP60AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878520);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z114mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878568);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878616);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(1270104|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(1270104|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(1270104|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(1270104|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1270104|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1270104|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1270104|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(1270104|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(1270104|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(1270104|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878672);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878720);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(1270104|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(1270104|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878776);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1349,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1418296|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1418296|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878832);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($agg$result|0),($25|0),($23|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array32UnityEngine_UnityEngine_Keyframe($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878880);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array32UnityEngine_UnityEngine_Keyframe($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $_stackTraceSentry = sp + 64|0;
 $V_2 = sp;
 $L_6 = sp + 16|0;
 $L_8 = sp + 32|0;
 $L_12 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878928);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(996);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if (!($26)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $60 = HEAP32[$__this>>2]|0;
      $61 = (($60) + 28|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = (($62) + 92|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = Math_imul($64, $V_1$011)|0;
      $66 = (($27) + ($65)|0);
      _memcpy(($V_2|0),($66|0),($64|0))|0;
      ;HEAP32[$L_6+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$item+12>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2844928|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iii(2724,(2844928|0),($L_6|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = ($28|0)==(0|0);
      if ($31) {
       label = 18;
       break;
      }
      ;HEAP32[$L_12+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$L_12+12>>2]=HEAP32[$V_2+12>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2844928|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $40 = (invoke_iii(2724,(2844928|0),($L_12|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2844928|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $45 = (invoke_iii(2724,(2844928|0),($item|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($45|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2844928|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $52 = (invoke_iii(2724,(2844928|0),($item|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $55 = (invoke_iiii(1644,(2148736|0),($52|0),($40|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      $58 = (($V_1$011) + 1)|0;
      if ($55) {
       $$0 = 1;
       label = 32;
       break;
      }
      $59 = ($58|0)<($23|0);
      if ($59) {
       $V_1$011 = $58;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      ;HEAP32[$L_8+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_8+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_8+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$L_8+12>>2]=HEAP32[$V_2+12>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2844928|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_iii(2724,(2844928|0),($L_8|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = ($34|0)==(0|0);
      $$0 = $37;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Keyframe_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2878984);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array32UnityEngine_UnityEngine_Keyframe($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879032);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array32UnityEngine_UnityEngine_Keyframe($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $_stackTraceSentry = sp + 64|0;
 $V_2 = sp;
 $L_6 = sp + 16|0;
 $L_8 = sp + 32|0;
 $L_17 = sp + 48|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879080);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $72 = HEAP32[$__this>>2]|0;
        $73 = (($72) + 28|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = (($74) + 92|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = Math_imul($76, $V_1$013)|0;
        $78 = (($27) + ($77)|0);
        _memcpy(($V_2|0),($78|0),($76|0))|0;
        ;HEAP32[$L_6+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$item+12>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2844928|0))|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2844928|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        ;HEAP32[$L_17+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_17+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_17+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$L_17+12>>2]=HEAP32[$item+12>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2844928|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_iii(2724,(2844928|0),($L_17|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2844928|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $53 = (invoke_iii(2724,(2844928|0),($V_2|0))|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($53|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2844928|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(2724,(2844928|0),($V_2|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $63 = (invoke_iiii(1644,(2148736|0),($60|0),($48|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 4;
         break;
        }
        $66 = (($V_1$013) + 1)|0;
        if ($63) {
         label = 34;
         break;
        }
        $71 = ($66|0)<($23|0);
        if ($71) {
         $V_1$013 = $66;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        ;HEAP32[$L_8+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_8+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_8+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$L_8+12>>2]=HEAP32[$V_2+12>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2844928|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break L1;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2724,(2844928|0),($L_8|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break L1;
        }
        $37 = ($34|0)==(0|0);
        if ($37) {
         __THREW__ = 0;
         $38 = (invoke_iii(755,($__this|0),0)|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break L1;
         }
         $41 = (($38) + ($V_1$013))|0;
         $$0 = $41;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $42 = (invoke_iii(755,($__this|0),0)|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          break L1;
         }
         $45 = (($42) + -1)|0;
         $$0 = $45;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $67 = (invoke_iii(755,($__this|0),0)|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         break L1;
        }
        $70 = (($67) + ($V_1$013))|0;
        $$0 = $70;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $81 = (invoke_iii(755,($__this|0),0)|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if (!($83)) {
      $84 = (($81) + -1)|0;
      $$0 = $84;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Arrayi32UnityEngine_UnityEngine_Keyframe($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879136);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Arrayi32UnityEngine_UnityEngine_Keyframe($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879184);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $48 = (($__this) + 16|0);
       $49 = HEAP32[$__this>>2]|0;
       $50 = (($49) + 28|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 92|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = Math_imul($53, $index)|0;
       $55 = (($48) + ($54)|0);
       _memcpy(($55|0),($item|0),($53|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      ;HEAP32[$L_3+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_3+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_3+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$L_3+12>>2]=HEAP32[$item+12>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2844928|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       $26 = (invoke_iii(2724,(2844928|0),($L_3|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         $31 = ($index|0)<(0);
         if ($31) {
          label = 18;
         } else {
          $32 = (($20) + 12|0);
          $33 = HEAP32[$32>>2]|0;
          $34 = ($33>>>0)>($index>>>0);
          if (!($34)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $35 = (invoke_i(132)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($35|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($26|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = HEAP32[$20>>2]|0;
          $43 = (($20) + 16|0);
          $44 = (($42) + 92|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = Math_imul($45, $index)|0;
          $47 = (($43) + ($46)|0);
          HEAP32[$47>>2] = $26;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879240);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1350,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1420560|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1420560|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879296);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z116mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879344);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z121mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879392);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(1287200|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(1287200|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(1287200|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(1287200|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1287200|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(1287200|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1287200|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(1287200|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(1287200|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(1287200|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_ArrayP65AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879448);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z119mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879496);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879544);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(1287200|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(1287200|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(1287200|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(1287200|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1287200|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1287200|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1287200|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(1287200|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(1287200|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(1287200|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879600);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879648);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(1287200|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(1287200|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z126mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2879704);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1352,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1422824|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1422824|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL101mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL100mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayiP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL101mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayiP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2880176 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_CharacterController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_CharacterController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_CharacterController_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_CharacterController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL90mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_CharacterController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayiP43UnityEngine_UnityEngine_CharacterController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL91mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayiP43UnityEngine_UnityEngine_CharacterController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2880640 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP61AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL104mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayiP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL105mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayiP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2881104 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP66AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL109mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayiP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL110mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayiP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2881568 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL103mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayiP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL104mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayiP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2882032 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP64AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL107mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayiP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL108mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayiP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2882496 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z101mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882560);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882608);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z113mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882656);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(1296504|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(1296504|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(1296504|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(1296504|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1296504|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(1296504|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1296504|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(1296504|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(1296504|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(1296504|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882712);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z111mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882760);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882808);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(1296504|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(1296504|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(1296504|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(1296504|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1296504|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1296504|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1296504|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(1296504|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(1296504|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(1296504|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882864);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z101mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882912);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(1296504|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(1296504|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2882968);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1451,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1703480|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1703480|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AnimationP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Animation($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Animation($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Animation_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Animation($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Animation($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Animation($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Animation($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AnimationP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2883440 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_WrapperlessIcall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_WrapperlessIcall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_WrapperlessIcall_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_WrapperlessIcall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_WrapperlessIcall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_WrapperlessIcall($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_WrapperlessIcall($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2883904 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_DisallowMultipleComponent($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_DisallowMultipleComponent($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP53UnityEngine_UnityEngine_DisallowMultipleComponent_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_DisallowMultipleComponent($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL96mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_DisallowMultipleComponent($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayiP49UnityEngine_UnityEngine_DisallowMultipleComponent($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL97mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayiP49UnityEngine_UnityEngine_DisallowMultipleComponent($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2884368 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_ExecuteInEditMode($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL101mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_ExecuteInEditMode($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_ExecuteInEditMode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_ExecuteInEditMode($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL88mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_ExecuteInEditMode($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayiP41UnityEngine_UnityEngine_ExecuteInEditMode($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL89mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayiP41UnityEngine_UnityEngine_ExecuteInEditMode($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2884832 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_RequireComponent($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_RequireComponent($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_RequireComponent_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_RequireComponent($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_RequireComponent($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_RequireComponent($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_RequireComponent($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2885296 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_m_Resize_mscorlib_System_Type_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP24mscorlib_System_Type_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2885352 + 40|0))>>2]|0;
 __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv(0,$_____array,$newSize,$0);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Array_m_Resize_mscorlib_System_Type_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP24mscorlib_System_Type_arrii($__this,$p0,$p1,$p2) {
 $__this = $__this|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2885408 + 40|0))>>2]|0;
 __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv(0,$p0,$p1,$p2,$0);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_MonoBehaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_MonoBehaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_MonoBehaviour_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_MonoBehaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL84mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_MonoBehaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_MonoBehaviour($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL85mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_MonoBehaviour($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2885872 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL130mscorlib_System_Array_m_IndexOf_mscorlib_System_Type_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP24mscorlib_System_Type_arrP20mscorlib_System_Typeii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2885928 + 40|0))>>2]|0;
 $1 = (__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv(0,$_____array,$value,$startIndex,$count,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$sroa$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$sroa$0 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2885976);
 HEAP32[$$sroa$0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($$sroa$0|0),($25|0),($23|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    $26 = HEAP32[$$sroa$0>>2]|0;
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3847,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array44mscorlib_System_Reflection_ParameterModifier($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2886024);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array44mscorlib_System_Reflection_ParameterModifier($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2$sroa$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2$sroa$0 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_12 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2886072);
 HEAP32[$V_2$sroa$0>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if (!($26)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $61 = HEAP32[$__this>>2]|0;
      $62 = (($61) + 28|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 92|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $V_1$011)|0;
      $67 = (($27) + ($66)|0);
      _memcpy(($V_2$sroa$0|0),($67|0),($65|0))|0;
      $68 = HEAP32[$item>>2]|0;
      HEAP32[$L_6>>2] = $68;
      __THREW__ = 0;
      (invoke_ii(2996,(2433320|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iii(2724,(2433320|0),($L_6|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = ($28|0)==(0|0);
      $32 = HEAP32[$V_2$sroa$0>>2]|0;
      if ($31) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $32;
      __THREW__ = 0;
      (invoke_ii(2996,(2433320|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $41 = (invoke_iii(2724,(2433320|0),($L_12|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2433320|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $46 = (invoke_iii(2724,(2433320|0),($item|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($46|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2433320|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $53 = (invoke_iii(2724,(2433320|0),($item|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1644,(2148736|0),($53|0),($41|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 4;
       break;
      }
      $59 = (($V_1$011) + 1)|0;
      if ($56) {
       $$0 = 1;
       label = 32;
       break;
      }
      $60 = ($59|0)<($23|0);
      if ($60) {
       $V_1$011 = $59;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $32;
      __THREW__ = 0;
      (invoke_ii(2996,(2433320|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_iii(2724,(2433320|0),($L_8|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = ($35|0)==(0|0);
      $$0 = $38;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_ArrayP48mscorlib_System_Reflection_ParameterModifier_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2886128);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array44mscorlib_System_Reflection_ParameterModifier($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2886176);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array44mscorlib_System_Reflection_ParameterModifier($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2886224);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $28 = HEAP32[$item>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $74 = HEAP32[$__this>>2]|0;
        $75 = (($74) + 28|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = (($76) + 92|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = Math_imul($78, $V_1$013)|0;
        $80 = (($27) + ($79)|0);
        _memcpy(($V_2|0),($80|0),($78|0))|0;
        HEAP32[$L_6>>2] = $28;
        __THREW__ = 0;
        (invoke_ii(2996,(2433320|0))|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $29 = (invoke_iii(2724,(2433320|0),($L_6|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 4;
         break;
        }
        $32 = ($29|0)==(0|0);
        if ($32) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $28;
        __THREW__ = 0;
        (invoke_ii(2996,(2433320|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $50 = (invoke_iii(2724,(2433320|0),($L_17|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2433320|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $55 = (invoke_iii(2724,(2433320|0),($V_2|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2433320|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $62 = (invoke_iii(2724,(2433320|0),($V_2|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $65 = (invoke_iiii(1644,(2148736|0),($62|0),($50|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         label = 4;
         break;
        }
        $68 = (($V_1$013) + 1)|0;
        if ($65) {
         label = 34;
         break;
        }
        $73 = ($68|0)<($23|0);
        if ($73) {
         $V_1$013 = $68;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $33 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $33;
        __THREW__ = 0;
        (invoke_ii(2996,(2433320|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break L1;
        }
        __THREW__ = 0;
        $36 = (invoke_iii(2724,(2433320|0),($L_8|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break L1;
        }
        $39 = ($36|0)==(0|0);
        if ($39) {
         __THREW__ = 0;
         $40 = (invoke_iii(755,($__this|0),0)|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break L1;
         }
         $43 = (($40) + ($V_1$013))|0;
         $$0 = $43;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $44 = (invoke_iii(755,($__this|0),0)|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          break L1;
         }
         $47 = (($44) + -1)|0;
         $$0 = $47;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $69 = (invoke_iii(755,($__this|0),0)|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break L1;
        }
        $72 = (($69) + ($V_1$013))|0;
        $$0 = $72;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $83 = (invoke_iii(755,($__this|0),0)|0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if (!($85)) {
      $86 = (($83) + -1)|0;
      $$0 = $86;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Arrayi44mscorlib_System_Reflection_ParameterModifier($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2886280);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Arrayi44mscorlib_System_Reflection_ParameterModifier($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2886328);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($item|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = HEAP32[$item>>2]|0;
      HEAP32[$L_3>>2] = $24;
      __THREW__ = 0;
      (invoke_ii(2996,(2433320|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2433320|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($20) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$20>>2]|0;
          $44 = (($20) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2886384);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1478,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1728904|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1728904|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL89mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_WritableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL101mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_WritableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_WritableAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_WritableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL88mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_WritableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayiP41UnityEngine_UnityEngine_WritableAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL89mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayiP41UnityEngine_UnityEngine_WritableAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2886856 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_AssemblyIsEditorAssembly_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL95mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayiP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL96mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayiP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2887320 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_GUILayoutOption($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_GUILayoutOption($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_GUILayoutOption_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_GUILayoutOption($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL86mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_GUILayoutOption($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayiP39UnityEngine_UnityEngine_GUILayoutOption($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL87mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayiP39UnityEngine_UnityEngine_GUILayoutOption($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2887784 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z95mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2887832);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3847,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array47UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2887880);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array47UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2887928);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(2682160|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(2682160|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2682160|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(2682160|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2682160|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(2682160|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2682160|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(2682160|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2682160|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(2682160|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_ArrayP51UnityEngine_UnityEngine_SendMouseEvents_HitInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2887984);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3847,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3847,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3847,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3847,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array47UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2888032);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array47UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2888080);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2682160|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(2682160|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2682160|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(2682160|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682160|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(2682160|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2682160|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(2682160|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(2682160|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2682160|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Arrayi47UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2888136);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3847,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Arrayi47UnityEngine_UnityEngine_SendMouseEvents_HitInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2888184);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3847,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(2682160|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(2682160|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2888240);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1482,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1737960|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1737960|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CameraP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Camera($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0);
 // unreachable;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Camera($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Camera_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Camera($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object(0,0)|0);
 // unreachable;
 return 0|0;
}
function __ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Camera($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Camera($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object(0,0,0);
 // unreachable;
}
function __ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Camera($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,0);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CameraP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2888712 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_ParameterInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_ParameterInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2888944 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP44mscorlib_System_Reflection_ParameterInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_ParameterInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_ParameterInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2889200 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayiP40mscorlib_System_Reflection_ParameterInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayiP40mscorlib_System_Reflection_ParameterInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2889352 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2889456 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_StateMachineBehaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_StateMachineBehaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2889632 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_StateMachineBehaviour_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_StateMachineBehaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_StateMachineBehaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2889784 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayiP45UnityEngine_UnityEngine_StateMachineBehaviour($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayiP45UnityEngine_UnityEngine_StateMachineBehaviour($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2889888 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2889944 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z183mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2889992);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3848,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception13875($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z190mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890040);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z195mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890088);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(1758568|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(1758568|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1758568|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(1758568|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1758568|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(1758568|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1758568|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(1758568|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1758568|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(1758568|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z193mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_ArrayP119mscorlib_System_Collections_Generic_KeyValuePair_2U003CUnityEngine_EventU002CUnityEngine_TextEditor_TextEditOpU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890144);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z193mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890192);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z182mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890240);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1758568|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(1758568|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1758568|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(1758568|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1758568|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(1758568|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1758568|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(1758568|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(1758568|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1758568|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z181mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890296);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z183mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890344);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1758568|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(1758568|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z200mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890400);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1494,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1759312|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1759312|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL77mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_EventP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP29UnityEngine_UnityEngine_Event($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP29UnityEngine_UnityEngine_Event($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2890560 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Event_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP29UnityEngine_UnityEngine_Event($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL76mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP29UnityEngine_UnityEngine_Event($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2890712 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL75mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayiP29UnityEngine_UnityEngine_Event($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL77mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayiP29UnityEngine_UnityEngine_Event($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2890816 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_EventP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2890872 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z93mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890920);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2890968);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891016);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2689136|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2689136|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2689136|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2689136|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2689136|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2689136|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2689136|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2689136|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2689136|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2689136|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_TextEditor_TextEditOp_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891072);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891120);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891168);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2689136|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2689136|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2689136|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2689136|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2689136|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2689136|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2689136|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2689136|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2689136|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2689136|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891224);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891272);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2689136|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2689136|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891328);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1497,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1763808|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1763808|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z202mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_ICollectionCopyTo_UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_ArrayiP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891384);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1751528;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3848,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2782,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(282,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3848,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo13880($obj,$targetType) {
 $obj = $obj|0;
 $targetType = $targetType|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 do {
  if ($0) {
   $$0 = 0;
  } else {
   $1 = (__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo($obj,$targetType)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $3 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
    __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($3);
    $$0 = 0;
    break;
   } else {
    $$0 = $1;
    break;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __Z223mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_ObjectP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP26mscorlib_System_Object_arriP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_15 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891464);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $97 = __THREW__; __THREW__ = 0;
  $98 = $97&1;
  if ($98) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(326,(1768720|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   HEAP32[$L_15>>2] = $66;
   __THREW__ = 0;
   (invoke_ii(2996,(2689136|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2724,(2689136|0),($L_15|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $76 = (invoke_iii(2782,($71|0),(2149728|0))|0);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $79 = __THREW__; __THREW__ = 0;
   $80 = $79&1;
   if ($80) {
    label = 6;
    break;
   }
   $81 = ($$14|0)<(0);
   if ($81) {
    label = 25;
   } else {
    $82 = HEAP32[$7>>2]|0;
    $83 = ($$14>>>0)<($82>>>0);
    if (!($83)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $84 = (invoke_i(132)|0);
    $85 = __THREW__; __THREW__ = 0;
    $86 = $85&1;
    if ($86) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($84|0));
    $87 = __THREW__; __THREW__ = 0;
    $88 = $87&1;
    if ($88) {
     label = 6;
     break;
    }
   }
   $89 = HEAP32[$_____array>>2]|0;
   $90 = (($89) + 92|0);
   $91 = HEAP32[$90>>2]|0;
   $92 = Math_imul($91, $$14)|0;
   $93 = (($6) + ($92)|0);
   HEAP32[$93>>2] = $76;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $94 = (($V_0$02) + 1)|0;
  $95 = HEAP32[$0>>2]|0;
  $96 = ($94|0)<($95|0);
  if ($96) {
   $$14 = $$0;$V_0$02 = $94;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z246mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP49UnityEngine_UnityEngine_TextEditor_TextEditOp_arriP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_15 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891544);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $98 = __THREW__; __THREW__ = 0;
  $99 = $98&1;
  if ($99) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(326,(1768720|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   HEAP32[$L_15>>2] = $66;
   __THREW__ = 0;
   (invoke_ii(2996,(2689136|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2724,(2689136|0),($L_15|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2689136|0))|0);
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $76 = (invoke_iii(2783,($71|0),(2689136|0))|0);
   $77 = __THREW__; __THREW__ = 0;
   $78 = $77&1;
   if ($78) {
    label = 6;
    break;
   }
   $79 = HEAP32[$76>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    label = 6;
    break;
   }
   $82 = ($$14|0)<(0);
   if ($82) {
    label = 25;
   } else {
    $83 = HEAP32[$7>>2]|0;
    $84 = ($$14>>>0)<($83>>>0);
    if (!($84)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $85 = (invoke_i(132)|0);
    $86 = __THREW__; __THREW__ = 0;
    $87 = $86&1;
    if ($87) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($85|0));
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     label = 6;
     break;
    }
   }
   $90 = HEAP32[$_____array>>2]|0;
   $91 = (($90) + 92|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = Math_imul($92, $$14)|0;
   $94 = (($6) + ($93)|0);
   HEAP32[$94>>2] = $79;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $95 = (($V_0$02) + 1)|0;
  $96 = HEAP32[$0>>2]|0;
  $97 = ($95|0)<($96|0);
  if ($97) {
   $$14 = $$0;$V_0$02 = $95;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo13883($obj,$klass) {
 $obj = $obj|0;
 $klass = $klass|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($obj|0)==(0|0);
 if ($0) {
  __ZN6il2cpp2vm9Exception27RaiseNullReferenceExceptionEv();
 }
 $1 = HEAP32[$obj>>2]|0;
 $2 = (($1) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($klass) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)==($5|0);
 if (!($6)) {
  $7 = (__ZN6il2cpp2vm9Exception23GetInvalidCastExceptionEv()|0);
  __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($7);
 }
 $8 = (__ZN6il2cpp2vm6Object5UnboxEP12Il2CppObject($obj)|0);
 STACKTOP = sp;return ($8|0);
}
function __Z242mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP47mscorlib_System_Collections_DictionaryEntry_arriP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891608);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(126,($L_14|0),(1769352|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(2307216|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2783,($80|0),(2307216|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z292mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_ArrayiP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891672);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1751360;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3848,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2782,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(286,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3848,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z313mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_ObjectP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP26mscorlib_System_Object_arriP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_14 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891728);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if ($107) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(128,($L_14|0),(1769928|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1758568|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1758568|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2782,($80|0),(2149728|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break;
   }
   $90 = ($$14|0)<(0);
   if ($90) {
    label = 25;
   } else {
    $91 = HEAP32[$7>>2]|0;
    $92 = ($$14>>>0)<($91>>>0);
    if (!($92)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $93 = (invoke_i(132)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($93|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 6;
     break;
    }
   }
   $98 = HEAP32[$_____array>>2]|0;
   $99 = (($98) + 92|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = Math_imul($100, $$14)|0;
   $102 = (($6) + ($101)|0);
   HEAP32[$102>>2] = $85;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $103 = (($V_0$02) + 1)|0;
  $104 = HEAP32[$0>>2]|0;
  $105 = ($103|0)<($104|0);
  if ($105) {
   $$14 = $$0;$V_0$02 = $103;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_i($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z426mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP119mscorlib_System_Collections_Generic_KeyValuePair_2U003CUnityEngine_EventU002CUnityEngine_TextEditor_TextEditOpU003E_arriP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891792);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(128,($L_14|0),(1769928|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1758568|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1758568|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1758568|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2783,($80|0),(1758568|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z99mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891856);
 HEAP8[$V_0>>0] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP8[$V_0>>0]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891904);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z111mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 5|0;
 $L_8 = sp + 6|0;
 $L_12 = sp + 7|0;
 HEAP8[$0>>0] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2891952);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP8[$0>>0]|0;
      HEAP8[$L_6>>0] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2686296|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2686296|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP8[$V_2>>0]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP8[$L_12>>0] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2686296|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2686296|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2686296|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2686296|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2686296|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2686296|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP8[$L_8>>0] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2686296|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2686296|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_ArrayP55UnityEngine_UnityEngine_TextEditor_DblClickSnapping_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892008);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892056);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 7|0;
 $L_6 = sp + 4|0;
 $L_8 = sp + 5|0;
 $L_17 = sp + 6|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892104);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP8[$L_6>>0] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2686296|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2686296|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP8[$L_17>>0] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2686296|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2686296|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2686296|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2686296|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2686296|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2686296|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP8[$V_2>>0]|0;
        HEAP8[$L_8>>0] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2686296|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2686296|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayih($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892160);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z99mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayih($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP8[$0>>0] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892208);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP8[$L_3>>0] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2686296|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2686296|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892264);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1507,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1775256|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1775256|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892320);
 dest=$agg$result+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($agg$result|0),($25|0),($23|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array32UnityEngine_UnityEngine_UIVertex($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892368);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array32UnityEngine_UnityEngine_UIVertex($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$015 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $_stackTraceSentry = sp + 240|0;
 $V_2 = sp;
 $L_6 = sp + 60|0;
 $L_8 = sp + 120|0;
 $L_12 = sp + 180|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892416);
 dest=$V_2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_v(996);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if (!($26)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = (($__this) + 16|0);
     $V_1$015 = 0;
     while(1) {
      $60 = HEAP32[$__this>>2]|0;
      $61 = (($60) + 28|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = (($62) + 92|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = Math_imul($64, $V_1$015)|0;
      $66 = (($27) + ($65)|0);
      _memcpy(($V_2|0),($66|0),($64|0))|0;
      dest=$L_6+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      __THREW__ = 0;
      (invoke_ii(2996,(2859256|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iii(2724,(2859256|0),($L_6|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = ($28|0)==(0|0);
      if ($31) {
       label = 18;
       break;
      }
      dest=$L_12+0|0; src=$V_2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      __THREW__ = 0;
      (invoke_ii(2996,(2859256|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $40 = (invoke_iii(2724,(2859256|0),($L_12|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2859256|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $45 = (invoke_iii(2724,(2859256|0),($item|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($45|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2859256|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $52 = (invoke_iii(2724,(2859256|0),($item|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $55 = (invoke_iiii(1644,(2148736|0),($52|0),($40|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      $58 = (($V_1$015) + 1)|0;
      if ($55) {
       $$0 = 1;
       label = 32;
       break;
      }
      $59 = ($58|0)<($23|0);
      if ($59) {
       $V_1$015 = $58;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      dest=$L_8+0|0; src=$V_2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      __THREW__ = 0;
      (invoke_ii(2996,(2859256|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_iii(2724,(2859256|0),($L_8|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = ($34|0)==(0|0);
      $$0 = $37;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_UIVertex_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892472);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array32UnityEngine_UnityEngine_UIVertex($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892520);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array32UnityEngine_UnityEngine_UIVertex($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$017 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $_stackTraceSentry = sp + 240|0;
 $V_2 = sp;
 $L_6 = sp + 60|0;
 $L_8 = sp + 120|0;
 $L_17 = sp + 180|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892568);
 dest=$V_2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$017 = 0;
       while(1) {
        $72 = HEAP32[$__this>>2]|0;
        $73 = (($72) + 28|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = (($74) + 92|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = Math_imul($76, $V_1$017)|0;
        $78 = (($27) + ($77)|0);
        _memcpy(($V_2|0),($78|0),($76|0))|0;
        dest=$L_6+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        __THREW__ = 0;
        (invoke_ii(2996,(2859256|0))|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2859256|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        dest=$L_17+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        __THREW__ = 0;
        (invoke_ii(2996,(2859256|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_iii(2724,(2859256|0),($L_17|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2859256|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $53 = (invoke_iii(2724,(2859256|0),($V_2|0))|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($53|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2859256|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(2724,(2859256|0),($V_2|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $63 = (invoke_iiii(1644,(2148736|0),($60|0),($48|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 4;
         break;
        }
        $66 = (($V_1$017) + 1)|0;
        if ($63) {
         label = 34;
         break;
        }
        $71 = ($66|0)<($23|0);
        if ($71) {
         $V_1$017 = $66;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        dest=$L_8+0|0; src=$V_2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
        __THREW__ = 0;
        (invoke_ii(2996,(2859256|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break L1;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2724,(2859256|0),($L_8|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break L1;
        }
        $37 = ($34|0)==(0|0);
        if ($37) {
         __THREW__ = 0;
         $38 = (invoke_iii(755,($__this|0),0)|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break L1;
         }
         $41 = (($38) + ($V_1$017))|0;
         $$0 = $41;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $42 = (invoke_iii(755,($__this|0),0)|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          break L1;
         }
         $45 = (($42) + -1)|0;
         $$0 = $45;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $67 = (invoke_iii(755,($__this|0),0)|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         break L1;
        }
        $70 = (($67) + ($V_1$017))|0;
        $$0 = $70;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $81 = (invoke_iii(755,($__this|0),0)|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if (!($83)) {
      $84 = (($81) + -1)|0;
      $$0 = $84;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Arrayi32UnityEngine_UnityEngine_UIVertex($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892624);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Arrayi32UnityEngine_UnityEngine_UIVertex($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 60|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892672);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $48 = (($__this) + 16|0);
       $49 = HEAP32[$__this>>2]|0;
       $50 = (($49) + 28|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 92|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = Math_imul($53, $index)|0;
       $55 = (($48) + ($54)|0);
       _memcpy(($55|0),($item|0),($53|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      dest=$L_3+0|0; src=$item+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      __THREW__ = 0;
      (invoke_ii(2996,(2859256|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       $26 = (invoke_iii(2724,(2859256|0),($L_3|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         $31 = ($index|0)<(0);
         if ($31) {
          label = 18;
         } else {
          $32 = (($20) + 12|0);
          $33 = HEAP32[$32>>2]|0;
          $34 = ($33>>>0)>($index>>>0);
          if (!($34)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $35 = (invoke_i(132)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($35|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($26|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = HEAP32[$20>>2]|0;
          $43 = (($20) + 16|0);
          $44 = (($42) + 92|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = Math_imul($45, $index)|0;
          $47 = (($43) + ($46)|0);
          HEAP32[$47>>2] = $26;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892728);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1508,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1778920|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1778920|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z127mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UIVertex_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP36UnityEngine_UnityEngine_UIVertex_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892784);
 $0 = HEAP32[$_____array>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $G_B3_0$0 = 0;
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = (($0) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $G_B3_0$0 = $5;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  __THREW__ = 0;
  invoke_viiii(288,0,($_____array|0),($G_B3_0$0|0),($newSize|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z149mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UIVertex_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP36UnityEngine_UnityEngine_UIVertex_arrii($__this,$_____array,$length,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $length = $length|0;
 $newSize = $newSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892848);
 $0 = ($newSize|0)>(-1);
 do {
  if ($0) {
   $12 = HEAP32[$_____array>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    __THREW__ = 0;
    (invoke_ii(2996,(1185480|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    $16 = (invoke_iii(2784,(1185480|0),($newSize|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    HEAP32[$_____array>>2] = $16;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = (($12) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($newSize|0);
    if ($23) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1185480|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __THREW__ = 0;
     $26 = (invoke_iii(2784,(1185480|0),($newSize|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[$_____array>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iiii(1198,(0|0),($newSize|0),($length|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_viiii(140,(0|0),($29|0),($26|0),($30|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        HEAP32[$_____array>>2] = $26;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(3469,(2561352|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(2587,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      __THREW__ = 0;
      invoke_vi(3848,($3|0));
      $8 = __THREW__; __THREW__ = 0;
      $9 = $8&1;
      if (!($9)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __ZL10SZArrayNewP8TypeInfoj13896($arrayType,$length) {
 $arrayType = $arrayType|0;
 $length = $length|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN6il2cpp2vm5Class4InitEP8TypeInfo($arrayType)|0);
 $0 = (__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj($arrayType,$length)|0);
 STACKTOP = sp;return ($0|0);
}
function __Z142mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_UIVertex_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP36UnityEngine_UnityEngine_UIVertex_arr32UnityEngine_UnityEngine_UIVertexii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $8 = 0, $9 = 0, $L_12 = 0, $V_2$08 = 0, $_stackTraceSentry = 0, $data$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $$byval_copy6 = sp + 260|0;
 $$byval_copy = sp + 136|0;
 $data$i = sp + 128|0;
 $0 = sp;
 $1 = sp + 64|0;
 $_stackTraceSentry = sp + 196|0;
 $L_12 = sp + 200|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892904);
 __THREW__ = 0;
 invoke_v(1002);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($_____array|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3016328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($count|0)<(0);
   if (!($19)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_iii(755,($_____array|0),0)|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = ($22|0)>($startIndex|0);
    if (!($25)) {
     $26 = (($startIndex) + -1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     $29 = (invoke_iii(758,($_____array|0),0)|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     $32 = (($29) - ($count))|0;
     $33 = ($26|0)>($32|0);
     if (!($33)) {
      $43 = (($count) + ($startIndex))|0;
      __THREW__ = 0;
      $44 = (invoke_ii(1349,(0|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      $47 = ($count|0)>(0);
      if (!($47)) {
       $$0 = -1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $48 = (($_____array) + 16|0);
      $49 = (($data$i) + 4|0);
      $50 = (($_____array) + 12|0);
      $V_2$08 = $startIndex;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        label = 3;
        break;
       }
       $51 = ($V_2$08|0)<(0);
       if ($51) {
        label = 28;
       } else {
        $52 = HEAP32[$50>>2]|0;
        $53 = ($V_2$08>>>0)<($52>>>0);
        if (!($53)) {
         label = 28;
        }
       }
       if ((label|0) == 28) {
        label = 0;
        __THREW__ = 0;
        $54 = (invoke_i(132)|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 3;
         break;
        }
       }
       $59 = HEAP32[$_____array>>2]|0;
       $60 = (($59) + 92|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = Math_imul($61, $V_2$08)|0;
       $63 = (($48) + ($62)|0);
       dest=$L_12+0|0; src=$63+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       __THREW__ = 0;
       invoke_vi(3799,($44|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        label = 3;
        break;
       }
       dest=$1+0|0; src=$L_12+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       dest=$0+0|0; src=$value+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       __THREW__ = 0;
       invoke_viii(2112,($data$i|0),(1783696|0),($44|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        label = 3;
        break;
       }
       $68 = HEAP32[$49>>2]|0;
       $69 = (($68) + 4|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = HEAP32[$data$i>>2]|0;
       __THREW__ = 0;
       dest=$$byval_copy+0|0; src=$1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       dest=$$byval_copy6+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       $72 = (invoke_iiii($70|0,($71|0),($$byval_copy|0),($$byval_copy6|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 3;
        break;
       }
       $75 = (($V_2$08) + 1)|0;
       if ($72) {
        $$0 = $V_2$08;
        label = 36;
        break;
       }
       $76 = ($75|0)<($43|0);
       if ($76) {
        $V_2$08 = $75;
       } else {
        $$0 = -1;
        label = 36;
        break;
       }
      }
      if ((label|0) == 3) {
       $5 = ___cxa_find_matching_catch()|0;
       $6 = tempRet0;
       $lpad$phi$index = $5;$lpad$phi$index2 = $6;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 36) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    $36 = (invoke_ii(3469,(2561352|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     __THREW__ = 0;
     invoke_vi(2587,($36|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      __THREW__ = 0;
      invoke_vi(3848,($36|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2892968);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($agg$result|0),($25|0),($23|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UICharInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893016);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UICharInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 48|0;
 $V_2 = sp;
 $L_6 = sp + 12|0;
 $L_8 = sp + 24|0;
 $L_12 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893064);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(996);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if (!($26)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $60 = HEAP32[$__this>>2]|0;
      $61 = (($60) + 28|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = (($62) + 92|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = Math_imul($64, $V_1$011)|0;
      $66 = (($27) + ($65)|0);
      _memcpy(($V_2|0),($66|0),($64|0))|0;
      ;HEAP32[$L_6+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$item+8>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2857568|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iii(2724,(2857568|0),($L_6|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = ($28|0)==(0|0);
      if ($31) {
       label = 18;
       break;
      }
      ;HEAP32[$L_12+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$V_2+8>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2857568|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $40 = (invoke_iii(2724,(2857568|0),($L_12|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2857568|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $45 = (invoke_iii(2724,(2857568|0),($item|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($45|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2857568|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $52 = (invoke_iii(2724,(2857568|0),($item|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $55 = (invoke_iiii(1644,(2148736|0),($52|0),($40|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      $58 = (($V_1$011) + 1)|0;
      if ($55) {
       $$0 = 1;
       label = 32;
       break;
      }
      $59 = ($58|0)<($23|0);
      if ($59) {
       $V_1$011 = $58;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      ;HEAP32[$L_8+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_8+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_8+8>>2]=HEAP32[$V_2+8>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2857568|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_iii(2724,(2857568|0),($L_8|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = ($34|0)==(0|0);
      $$0 = $37;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_UICharInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893120);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UICharInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893168);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UICharInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $_stackTraceSentry = sp + 48|0;
 $V_2 = sp;
 $L_6 = sp + 12|0;
 $L_8 = sp + 24|0;
 $L_17 = sp + 36|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893216);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $72 = HEAP32[$__this>>2]|0;
        $73 = (($72) + 28|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = (($74) + 92|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = Math_imul($76, $V_1$013)|0;
        $78 = (($27) + ($77)|0);
        _memcpy(($V_2|0),($78|0),($76|0))|0;
        ;HEAP32[$L_6+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$item+8>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2857568|0))|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2857568|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        ;HEAP32[$L_17+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_17+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_17+8>>2]=HEAP32[$item+8>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2857568|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_iii(2724,(2857568|0),($L_17|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2857568|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $53 = (invoke_iii(2724,(2857568|0),($V_2|0))|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($53|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2857568|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(2724,(2857568|0),($V_2|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $63 = (invoke_iiii(1644,(2148736|0),($60|0),($48|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 4;
         break;
        }
        $66 = (($V_1$013) + 1)|0;
        if ($63) {
         label = 34;
         break;
        }
        $71 = ($66|0)<($23|0);
        if ($71) {
         $V_1$013 = $66;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        ;HEAP32[$L_8+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_8+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_8+8>>2]=HEAP32[$V_2+8>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2857568|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break L1;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2724,(2857568|0),($L_8|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break L1;
        }
        $37 = ($34|0)==(0|0);
        if ($37) {
         __THREW__ = 0;
         $38 = (invoke_iii(755,($__this|0),0)|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break L1;
         }
         $41 = (($38) + ($V_1$013))|0;
         $$0 = $41;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $42 = (invoke_iii(755,($__this|0),0)|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          break L1;
         }
         $45 = (($42) + -1)|0;
         $$0 = $45;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $67 = (invoke_iii(755,($__this|0),0)|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         break L1;
        }
        $70 = (($67) + ($V_1$013))|0;
        $$0 = $70;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $81 = (invoke_iii(755,($__this|0),0)|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if (!($83)) {
      $84 = (($81) + -1)|0;
      $$0 = $84;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Arrayi34UnityEngine_UnityEngine_UICharInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893272);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Arrayi34UnityEngine_UnityEngine_UICharInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 12|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893320);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $48 = (($__this) + 16|0);
       $49 = HEAP32[$__this>>2]|0;
       $50 = (($49) + 28|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 92|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = Math_imul($53, $index)|0;
       $55 = (($48) + ($54)|0);
       _memcpy(($55|0),($item|0),($53|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      ;HEAP32[$L_3+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_3+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_3+8>>2]=HEAP32[$item+8>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2857568|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       $26 = (invoke_iii(2724,(2857568|0),($L_3|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         $31 = ($index|0)<(0);
         if ($31) {
          label = 18;
         } else {
          $32 = (($20) + 12|0);
          $33 = HEAP32[$32>>2]|0;
          $34 = ($33>>>0)>($index>>>0);
          if (!($34)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $35 = (invoke_i(132)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($35|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($26|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = HEAP32[$20>>2]|0;
          $43 = (($20) + 16|0);
          $44 = (($42) + 92|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = Math_imul($45, $index)|0;
          $47 = (($43) + ($46)|0);
          HEAP32[$47>>2] = $26;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893376);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1525,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1787384|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1787384|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z129mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UICharInfo_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP38UnityEngine_UnityEngine_UICharInfo_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893432);
 $0 = HEAP32[$_____array>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $G_B3_0$0 = 0;
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = (($0) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $G_B3_0$0 = $5;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  __THREW__ = 0;
  invoke_viiii(289,0,($_____array|0),($G_B3_0$0|0),($newSize|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z151mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UICharInfo_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP38UnityEngine_UnityEngine_UICharInfo_arrii($__this,$_____array,$length,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $length = $length|0;
 $newSize = $newSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893488);
 $0 = ($newSize|0)>(-1);
 do {
  if ($0) {
   $12 = HEAP32[$_____array>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    __THREW__ = 0;
    (invoke_ii(2996,(1185864|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    $16 = (invoke_iii(2784,(1185864|0),($newSize|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    HEAP32[$_____array>>2] = $16;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = (($12) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($newSize|0);
    if ($23) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1185864|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __THREW__ = 0;
     $26 = (invoke_iii(2784,(1185864|0),($newSize|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[$_____array>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iiii(1198,(0|0),($newSize|0),($length|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_viiii(140,(0|0),($29|0),($26|0),($30|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        HEAP32[$_____array>>2] = $26;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(3469,(2561352|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(2587,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      __THREW__ = 0;
      invoke_vi(3848,($3|0));
      $8 = __THREW__; __THREW__ = 0;
      $9 = $8&1;
      if (!($9)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z144mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_UICharInfo_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP38UnityEngine_UnityEngine_UICharInfo_arr34UnityEngine_UnityEngine_UICharInfoii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $$byval_copy = 0, $$byval_copy6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $8 = 0, $9 = 0, $L_12 = 0, $V_2$07 = 0, $_stackTraceSentry = 0, $data$i = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy6 = sp + 68|0;
 $$byval_copy = sp + 40|0;
 $data$i = sp + 32|0;
 $0 = sp;
 $1 = sp + 16|0;
 $_stackTraceSentry = sp + 52|0;
 $L_12 = sp + 56|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893544);
 __THREW__ = 0;
 invoke_v(1002);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($_____array|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3016328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($count|0)<(0);
   if (!($19)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_iii(755,($_____array|0),0)|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = ($22|0)>($startIndex|0);
    if (!($25)) {
     $26 = (($startIndex) + -1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     $29 = (invoke_iii(758,($_____array|0),0)|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     $32 = (($29) - ($count))|0;
     $33 = ($26|0)>($32|0);
     if (!($33)) {
      $43 = (($count) + ($startIndex))|0;
      __THREW__ = 0;
      $44 = (invoke_ii(1360,(0|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      $47 = ($count|0)>(0);
      if (!($47)) {
       $$0 = -1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $48 = (($_____array) + 16|0);
      $49 = (($data$i) + 4|0);
      $50 = (($_____array) + 12|0);
      $V_2$07 = $startIndex;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $77 = __THREW__; __THREW__ = 0;
       $78 = $77&1;
       if ($78) {
        label = 3;
        break;
       }
       $51 = ($V_2$07|0)<(0);
       if ($51) {
        label = 28;
       } else {
        $52 = HEAP32[$50>>2]|0;
        $53 = ($V_2$07>>>0)<($52>>>0);
        if (!($53)) {
         label = 28;
        }
       }
       if ((label|0) == 28) {
        label = 0;
        __THREW__ = 0;
        $54 = (invoke_i(132)|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 3;
         break;
        }
       }
       $59 = HEAP32[$_____array>>2]|0;
       $60 = (($59) + 92|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = Math_imul($61, $V_2$07)|0;
       $63 = (($48) + ($62)|0);
       ;HEAP32[$L_12+0>>2]=HEAP32[$63+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$63+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$63+8>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($44|0));
       $64 = __THREW__; __THREW__ = 0;
       $65 = $64&1;
       if ($65) {
        label = 3;
        break;
       }
       ;HEAP32[$1+0>>2]=HEAP32[$L_12+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$L_12+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$L_12+8>>2]|0;
       ;HEAP32[$0+0>>2]=HEAP32[$value+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$value+8>>2]|0;
       __THREW__ = 0;
       invoke_viii(2112,($data$i|0),(1791568|0),($44|0));
       $66 = __THREW__; __THREW__ = 0;
       $67 = $66&1;
       if ($67) {
        label = 3;
        break;
       }
       $68 = HEAP32[$49>>2]|0;
       $69 = (($68) + 4|0);
       $70 = HEAP32[$69>>2]|0;
       $71 = HEAP32[$data$i>>2]|0;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$1+8>>2]|0;
       ;HEAP32[$$byval_copy6+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy6+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy6+8>>2]=HEAP32[$0+8>>2]|0;
       $72 = (invoke_iiii($70|0,($71|0),($$byval_copy|0),($$byval_copy6|0))|0);
       $73 = __THREW__; __THREW__ = 0;
       $74 = $73&1;
       if ($74) {
        label = 3;
        break;
       }
       $75 = (($V_2$07) + 1)|0;
       if ($72) {
        $$0 = $V_2$07;
        label = 36;
        break;
       }
       $76 = ($75|0)<($43|0);
       if ($76) {
        $V_2$07 = $75;
       } else {
        $$0 = -1;
        label = 36;
        break;
       }
      }
      if ((label|0) == 3) {
       $5 = ___cxa_find_matching_catch()|0;
       $6 = tempRet0;
       $lpad$phi$index = $5;$lpad$phi$index2 = $6;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 36) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    $36 = (invoke_ii(3469,(2561352|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     __THREW__ = 0;
     invoke_vi(2587,($36|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      __THREW__ = 0;
      invoke_vi(3848,($36|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893600);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3848,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UILineInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893648);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UILineInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893696);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(2857840|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(2857840|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2857840|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(2857840|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2857840|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(2857840|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2857840|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(2857840|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2857840|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(2857840|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_UILineInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893752);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UILineInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893800);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UILineInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893848);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2857840|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(2857840|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2857840|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(2857840|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2857840|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(2857840|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2857840|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(2857840|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(2857840|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2857840|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Arrayi34UnityEngine_UnityEngine_UILineInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893904);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Arrayi34UnityEngine_UnityEngine_UILineInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2893952);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(2857840|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(2857840|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2894008);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1542,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1795256|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1795256|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z129mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UILineInfo_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP38UnityEngine_UnityEngine_UILineInfo_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $G_B3_0$0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2894064);
 $0 = HEAP32[$_____array>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $G_B3_0$0 = 0;
  label = 4;
 } else {
  __THREW__ = 0;
  invoke_vi(3799,($0|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   $4 = (($0) + 12|0);
   $5 = HEAP32[$4>>2]|0;
   $G_B3_0$0 = $5;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  __THREW__ = 0;
  invoke_viiii(290,0,($_____array|0),($G_B3_0$0|0),($newSize|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __ZN16StackTraceSentryD2Ev(0);
   STACKTOP = sp;return;
  }
 }
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z151mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UILineInfo_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP38UnityEngine_UnityEngine_UILineInfo_arrii($__this,$_____array,$length,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $length = $length|0;
 $newSize = $newSize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2894120);
 $0 = ($newSize|0)>(-1);
 do {
  if ($0) {
   $12 = HEAP32[$_____array>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    __THREW__ = 0;
    (invoke_ii(2996,(1186248|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if ($15) {
     break;
    }
    __THREW__ = 0;
    $16 = (invoke_iii(2784,(1186248|0),($newSize|0))|0);
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    HEAP32[$_____array>>2] = $16;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   invoke_vi(3799,($12|0));
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    $21 = (($12) + 12|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==($newSize|0);
    if ($23) {
     __ZN16StackTraceSentryD2Ev(0);
     STACKTOP = sp;return;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1186248|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     __THREW__ = 0;
     $26 = (invoke_iii(2784,(1186248|0),($newSize|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if (!($28)) {
      $29 = HEAP32[$_____array>>2]|0;
      __THREW__ = 0;
      $30 = (invoke_iiii(1198,(0|0),($newSize|0),($length|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if (!($32)) {
       __THREW__ = 0;
       invoke_viiii(140,(0|0),($29|0),($26|0),($30|0));
       $33 = __THREW__; __THREW__ = 0;
       $34 = $33&1;
       if (!($34)) {
        HEAP32[$_____array>>2] = $26;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return;
       }
      }
     }
    }
   }
  } else {
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $1 = __THREW__; __THREW__ = 0;
   $2 = $1&1;
   if (!($2)) {
    __THREW__ = 0;
    $3 = (invoke_ii(3469,(2561352|0))|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if (!($5)) {
     __THREW__ = 0;
     invoke_vi(2587,($3|0));
     $6 = __THREW__; __THREW__ = 0;
     $7 = $6&1;
     if (!($7)) {
      __THREW__ = 0;
      invoke_vi(3848,($3|0));
      $8 = __THREW__; __THREW__ = 0;
      $9 = $8&1;
      if (!($9)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z144mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_UILineInfo_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP38UnityEngine_UnityEngine_UILineInfo_arr34UnityEngine_UnityEngine_UILineInfoii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $V_2$04 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $tmpcast$byval_copy = 0, $tmpcast1$byval_copy = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $tmpcast1$byval_copy = sp + 32|0;
 $tmpcast$byval_copy = sp + 24|0;
 $_stackTraceSentry = sp + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2894176);
 __THREW__ = 0;
 invoke_v(1002);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($_____array|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $9 = __THREW__; __THREW__ = 0;
    $10 = $9&1;
    if ($10) {
     break;
    }
    __THREW__ = 0;
    $11 = (invoke_ii(3469,(2560584|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if ($13) {
     break;
    }
    $14 = HEAP32[3016328>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($11|0),($14|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($11|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    // unreachable;
   }
   $19 = ($count|0)<(0);
   if (!($19)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_iii(755,($_____array|0),0)|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = ($22|0)>($startIndex|0);
    if (!($25)) {
     $26 = (($startIndex) + -1)|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     __THREW__ = 0;
     $29 = (invoke_iii(758,($_____array|0),0)|0);
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     $32 = (($29) - ($count))|0;
     $33 = ($26|0)>($32|0);
     if (!($33)) {
      $43 = (($count) + ($startIndex))|0;
      __THREW__ = 0;
      $44 = (invoke_ii(1371,(0|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       break;
      }
      $47 = ($count|0)>(0);
      if (!($47)) {
       $$0 = -1;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $48 = (($_____array) + 16|0);
      $49 = (($_____array) + 12|0);
      $V_2$04 = $startIndex;
      while(1) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $90 = __THREW__; __THREW__ = 0;
       $91 = $90&1;
       if ($91) {
        label = 3;
        break;
       }
       $50 = ($V_2$04|0)<(0);
       if ($50) {
        label = 28;
       } else {
        $51 = HEAP32[$49>>2]|0;
        $52 = ($V_2$04>>>0)<($51>>>0);
        if (!($52)) {
         label = 28;
        }
       }
       if ((label|0) == 28) {
        label = 0;
        __THREW__ = 0;
        $53 = (invoke_i(132)|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 3;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3302,($53|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 3;
         break;
        }
       }
       $58 = HEAP32[$_____array>>2]|0;
       $59 = (($58) + 92|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = Math_imul($60, $V_2$04)|0;
       $62 = (($48) + ($61)|0);
       $63 = $62;
       $64 = $63;
       $65 = HEAP32[$64>>2]|0;
       $66 = (($63) + 4)|0;
       $67 = $66;
       $68 = HEAP32[$67>>2]|0;
       __THREW__ = 0;
       invoke_vi(3799,($44|0));
       $69 = __THREW__; __THREW__ = 0;
       $70 = $69&1;
       if ($70) {
        label = 3;
        break;
       }
       $71 = $0;
       $72 = $71;
       HEAP32[$72>>2] = $65;
       $73 = (($71) + 4)|0;
       $74 = $73;
       HEAP32[$74>>2] = $68;
       $75 = $value;
       $76 = $75;
       $77 = HEAP32[$76>>2]|0;
       $78 = (($75) + 4)|0;
       $79 = $78;
       $80 = HEAP32[$79>>2]|0;
       $81 = $1;
       $82 = $81;
       HEAP32[$82>>2] = $77;
       $83 = (($81) + 4)|0;
       $84 = $83;
       HEAP32[$84>>2] = $80;
       __THREW__ = 0;
       ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
       ;HEAP32[$tmpcast1$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$tmpcast1$byval_copy+4>>2]=HEAP32[$1+4>>2]|0;
       $85 = (invoke_iiiii(309,(1799440|0),($44|0),($tmpcast$byval_copy|0),($tmpcast1$byval_copy|0))|0);
       $86 = __THREW__; __THREW__ = 0;
       $87 = $86&1;
       if ($87) {
        label = 3;
        break;
       }
       $88 = (($V_2$04) + 1)|0;
       if ($85) {
        $$0 = $V_2$04;
        label = 35;
        break;
       }
       $89 = ($88|0)<($43|0);
       if ($89) {
        $V_2$04 = $88;
       } else {
        $$0 = -1;
        label = 35;
        break;
       }
      }
      if ((label|0) == 3) {
       $5 = ___cxa_find_matching_catch()|0;
       $6 = tempRet0;
       $lpad$phi$index = $5;$lpad$phi$index2 = $6;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($lpad$phi$index|0);
       // unreachable;
      }
      else if ((label|0) == 35) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if (!($35)) {
    __THREW__ = 0;
    $36 = (invoke_ii(3469,(2561352|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     __THREW__ = 0;
     invoke_vi(2587,($36|0));
     $39 = __THREW__; __THREW__ = 0;
     $40 = $39&1;
     if (!($40)) {
      __THREW__ = 0;
      invoke_vi(3848,($36|0));
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if (!($42)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 $lpad$phi$index = $7;$lpad$phi$index2 = $8;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ComponentP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Component($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Component($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2894336 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Component_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Component($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Component($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2894488 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Component($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Component($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2894592 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ComponentP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2894648 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GameObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GameObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2894800 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GameObject_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GameObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GameObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2894952 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayiP34UnityEngine_UnityEngine_GameObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayiP34UnityEngine_UnityEngine_GameObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895056 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895112 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ObjectP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895264 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Object_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895416 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895520 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ObjectP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895576 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895728 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_Events_PersistentCall_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895880 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayiP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayiP45UnityEngine_UnityEngine_Events_PersistentCall($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2895984 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896040 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL140mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_Events_PersistentCall_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP49UnityEngine_UnityEngine_Events_PersistentCall_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896096 + 40|0))>>2]|0;
 __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv($__this,$_____array,$newSize,$0);
 STACKTOP = sp;return;
}
function __ZL162mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_Events_PersistentCall_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP49UnityEngine_UnityEngine_Events_PersistentCall_arrii($__this,$p0,$p1,$p2) {
 $__this = $__this|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896152 + 40|0))>>2]|0;
 __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv($__this,$p0,$p1,$p2,$0);
 STACKTOP = sp;return;
}
function __ZL155mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_Events_PersistentCall_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP49UnityEngine_UnityEngine_Events_PersistentCall_arrP45UnityEngine_UnityEngine_Events_PersistentCallii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896208 + 40|0))>>2]|0;
 $1 = (__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv($__this,$_____array,$value,$startIndex,$count,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896360 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896512 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayiP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayiP48UnityEngine_UnityEngine_Events_BaseInvokableCall($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896616 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896672 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL143mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_Events_BaseInvokableCall_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896728 + 40|0))>>2]|0;
 __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv($__this,$_____array,$newSize,$0);
 STACKTOP = sp;return;
}
function __ZL165mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_Events_BaseInvokableCall_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arrii($__this,$p0,$p1,$p2) {
 $__this = $__this|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896784 + 40|0))>>2]|0;
 __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv($__this,$p0,$p1,$p2,$0);
 STACKTOP = sp;return;
}
function __ZL158mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_Events_BaseInvokableCall_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arrP48UnityEngine_UnityEngine_Events_BaseInvokableCallii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896840 + 40|0))>>2]|0;
 $1 = (__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv($__this,$_____array,$value,$startIndex,$count,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2896992 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP51UnityEngine_UnityEngine_UserAuthorizationDialog_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2897144 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayiP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayiP47UnityEngine_UnityEngine_UserAuthorizationDialog($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2897248 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2897304 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2897456 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngine_Internal_DefaultValueAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2897608 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayiP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayiP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2897712 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2897768 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2897920 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP61UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2898072 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayiP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayiP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2898176 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2898232 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2898384 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngine_RenamedSerializedDataAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2898536 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayiP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayiP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2898640 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2898696 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z98mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2898744);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2898792);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2898840);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2709456|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2709456|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2709456|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2709456|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2709456|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2709456|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2709456|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2709456|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2709456|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2709456|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_ArrayP54UnityEngine_UnityEngineInternal_TypeInferenceRules_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2898896);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z108mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2898944);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2898992);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2709456|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2709456|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2709456|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2709456|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2709456|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2709456|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2709456|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2709456|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2709456|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2709456|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2899048);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2899096);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2709456|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2709456|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z115mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2899152);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1596,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1840352|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1840352|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL106mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2899312 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP62UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2899464 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayiP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayiP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2899568 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2899624 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_AssetBundle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_AssetBundle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2899776 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_AssetBundle_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_AssetBundle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_AssetBundle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2899928 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayiP35UnityEngine_UnityEngine_AssetBundle($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayiP35UnityEngine_UnityEngine_AssetBundle($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2900032 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2900088 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z90mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900136);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900184);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900232);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2712816|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2712816|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2712816|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2712816|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2712816|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2712816|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2712816|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2712816|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2712816|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2712816|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_ArrayP46UnityEngine_UnityEngine_SendMessageOptions_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900288);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900336);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900384);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2712816|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2712816|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2712816|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2712816|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2712816|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2712816|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2712816|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2712816|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2712816|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2712816|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900440);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900488);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2712816|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2712816|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900544);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1599,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1847144|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1847144|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900600);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900648);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900696);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2713392|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2713392|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2713392|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2713392|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2713392|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2713392|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2713392|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2713392|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2713392|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2713392|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_PrimitiveType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900752);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900800);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900848);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2713392|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2713392|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2713392|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2713392|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2713392|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2713392|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2713392|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2713392|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2713392|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2713392|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900904);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z85mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2900952);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2713392|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2713392|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901008);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1600,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1849408|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1849408|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901064);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901112);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901160);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2713792|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2713792|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2713792|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2713792|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2713792|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2713792|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2713792|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2713792|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2713792|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2713792|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SpaceP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Space_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901216);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901264);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901312);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2713792|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2713792|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2713792|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2713792|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2713792|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2713792|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2713792|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2713792|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2713792|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2713792|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901368);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z77mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901416);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2713792|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2713792|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z94mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901472);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1601,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1851672|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1851672|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901528);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901576);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901624);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2715240|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2715240|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2715240|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2715240|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2715240|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2715240|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2715240|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2715240|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2715240|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2715240|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_LogType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901680);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901728);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901776);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2715240|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2715240|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2715240|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2715240|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2715240|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2715240|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2715240|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2715240|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2715240|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2715240|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901832);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901880);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2715240|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2715240|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2901936);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1602,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1853936|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1853936|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_AddComponentMenu($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_AddComponentMenu($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2902096 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_AddComponentMenu_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_AddComponentMenu($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_AddComponentMenu($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2902248 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_AddComponentMenu($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_AddComponentMenu($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2902352 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2902408 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_ScriptableObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_ScriptableObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2902560 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_ScriptableObject_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_ScriptableObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_ScriptableObject($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2902712 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_ScriptableObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_ScriptableObject($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2902816 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2902872 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2902920);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2902968);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2903016);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2719592|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2719592|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2719592|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2719592|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2719592|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2719592|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2719592|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2719592|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2719592|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2719592|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_CameraClearFlags_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2903072);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2903120);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2903168);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2719592|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2719592|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2719592|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2719592|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2719592|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2719592|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2719592|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2719592|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2719592|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2719592|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2903224);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2903272);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2719592|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2719592|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2903328);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1605,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1860728|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1860728|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RendererP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Renderer($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Renderer($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2903488 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Renderer_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Renderer($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Renderer($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2903640 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Renderer($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Renderer($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2903744 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RendererP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2903800 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_ReflectionProbe($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_ReflectionProbe($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2903952 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_ReflectionProbe_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_ReflectionProbe($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_ReflectionProbe($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2904104 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayiP39UnityEngine_UnityEngine_ReflectionProbe($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayiP39UnityEngine_UnityEngine_ReflectionProbe($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2904208 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2904264 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextureP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Texture($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Texture($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2904416 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_Texture_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Texture($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Texture($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2904568 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Texture($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Texture($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2904672 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextureP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2904728 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Texture2D($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Texture2D($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2904880 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Texture2D_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Texture2D($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Texture2D($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905032 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Texture2D($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Texture2D($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905136 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905192 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_RenderTexture($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_RenderTexture($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905344 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_RenderTexture_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_RenderTexture($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_RenderTexture($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905496 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_RenderTexture($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_RenderTexture($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905600 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905656 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GUIElement($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GUIElement($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905808 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUIElement_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GUIElement($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GUIElement($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2905960 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayiP34UnityEngine_UnityEngine_GUIElement($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayiP34UnityEngine_UnityEngine_GUIElement($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2906064 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2906120 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUILayer($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUILayer($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2906272 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_GUILayer_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUILayer($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUILayer($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2906424 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_GUILayer($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_GUILayer($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2906528 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2906584 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z182mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2906632);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3848,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z189mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2906680);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z194mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2906728);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(1890144|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(1890144|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1890144|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(1890144|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1890144|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(1890144|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1890144|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(1890144|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1890144|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(1890144|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z192mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP121mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_Int32U002CUnityEngine_GUILayoutUtility_LayoutCacheU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2906784);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z192mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2906832);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z181mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2906880);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1890144|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(1890144|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1890144|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(1890144|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1890144|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(1890144|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1890144|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(1890144|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(1890144|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1890144|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z180mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2906936);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z182mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2906984);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1890144|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(1890144|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z199mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2907040);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1620,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1890768|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1890768|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL100mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2907200 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP56UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2907352 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2907456 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2907512 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z208mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_ICollectionCopyTo_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayiP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2907560);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1943624;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3848,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2782,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(294,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3848,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z229mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_ObjectP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP26mscorlib_System_Object_arriP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2907616);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(331,(1897264|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2782,($66|0),(2149728|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_E6InvokeEP10MethodInfoPviS5_($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z259mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP56UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_arriP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2907680);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(331,(1897264|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2726424|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2782,($66|0),(2726424|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP47mscorlib_System_Collections_DictionaryEntry_arriP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2907744);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(129,($L_14|0),(1897896|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(2307216|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2783,($80|0),(2307216|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPviS6_($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z290mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayiP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2907808);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1943856;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3848,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2782,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(298,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3848,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z311mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_ObjectP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP26mscorlib_System_Object_arriP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_14 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2907864);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if ($107) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(130,($L_14|0),(1898472|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1890144|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1890144|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2782,($80|0),(2149728|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break;
   }
   $90 = ($$14|0)<(0);
   if ($90) {
    label = 25;
   } else {
    $91 = HEAP32[$7>>2]|0;
    $92 = ($$14>>>0)<($91>>>0);
    if (!($92)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $93 = (invoke_i(132)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($93|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 6;
     break;
    }
   }
   $98 = HEAP32[$_____array>>2]|0;
   $99 = (($98) + 92|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = Math_imul($100, $$14)|0;
   $102 = (($6) + ($101)|0);
   HEAP32[$102>>2] = $85;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $103 = (($V_0$02) + 1)|0;
  $104 = HEAP32[$0>>2]|0;
  $105 = ($103|0)<($104|0);
  if ($105) {
   $$14 = $$0;$V_0$02 = $103;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPviS6_($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z423mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP121mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_Int32U002CUnityEngine_GUILayoutUtility_LayoutCacheU003E_arriP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2907928);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(130,($L_14|0),(1898472|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1890144|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1890144|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1890144|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2783,($80|0),(1890144|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZL86mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2908096 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP42UnityEngine_UnityEngine_GUILayoutEntry_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2908248 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayiP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayiP38UnityEngine_UnityEngine_GUILayoutEntry($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2908352 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2908408 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL133mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_GUILayoutEntry_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP42UnityEngine_UnityEngine_GUILayoutEntry_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2908464 + 40|0))>>2]|0;
 __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv($__this,$_____array,$newSize,$0);
 STACKTOP = sp;return;
}
function __ZL155mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_GUILayoutEntry_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP42UnityEngine_UnityEngine_GUILayoutEntry_arrii($__this,$p0,$p1,$p2) {
 $__this = $__this|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2908520 + 40|0))>>2]|0;
 __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv($__this,$p0,$p1,$p2,$0);
 STACKTOP = sp;return;
}
function __ZL148mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_GUILayoutEntry_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP42UnityEngine_UnityEngine_GUILayoutEntry_arrP38UnityEngine_UnityEngine_GUILayoutEntryii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2908576 + 40|0))>>2]|0;
 $1 = (__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv($__this,$_____array,$value,$startIndex,$count,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z92mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2908624);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3848,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2908672);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2908720);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2733216|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2733216|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2733216|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2733216|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2733216|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2733216|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2733216|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2733216|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2733216|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2733216|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_GUILayoutOption_Type_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2908776);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2908824);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2908872);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2733216|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2733216|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2733216|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2733216|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2733216|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2733216|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2733216|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2733216|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2733216|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2733216|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2908928);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2908976);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2733216|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2733216|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2909032);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1647,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1910720|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1910720|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_GUISkin($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_GUISkin($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2909192 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_GUISkin_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_GUISkin($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_GUISkin($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2909344 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_GUISkin($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_GUISkin($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2909448 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2909504 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2909656 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_GUIStyle_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2909808 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_GUIStyle($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_GUIStyle($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2909912 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2909968 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z163mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910016);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3848,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z170mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910064);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z175mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910112);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(1921528|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(1921528|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1921528|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(1921528|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1921528|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(1921528|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(1921528|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(1921528|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(1921528|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(1921528|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z173mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP102mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CUnityEngine_GUIStyleU003E_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910168);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3848,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3848,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3848,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3848,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z173mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910216);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z162mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910264);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1921528|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(1921528|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(1921528|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(1921528|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1921528|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(1921528|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(1921528|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(1921528|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(1921528|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(1921528|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z161mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910320);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3848,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z163mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910368);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3848,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(1921528|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(1921528|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z180mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910424);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1657,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1922152|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1922152|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL169mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_ICollectionCopyTo_UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayiP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2910488 + 40|0))>>2]|0;
 __Z157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_Object_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv($__this,$_____array,$index,$transform,$0);
 STACKTOP = sp;return;
}
function __Z190mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_ObjectP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP26mscorlib_System_Object_arriP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910536);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(317,(1925864|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2782,($66|0),(2149728|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z200mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP36UnityEngine_UnityEngine_GUIStyle_arriP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $V_0$01 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910600);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$13 = $index;$V_0$01 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $92 = __THREW__; __THREW__ = 0;
  $93 = $92&1;
  if ($93) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$01>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$01)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$13) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$01>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$01)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$01>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$01)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $66 = (invoke_iiiii(317,(1925864|0),($transform|0),($45|0),($63|0))|0);
   $67 = __THREW__; __THREW__ = 0;
   $68 = $67&1;
   if ($68) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2749952|0))|0);
   $69 = __THREW__; __THREW__ = 0;
   $70 = $69&1;
   if ($70) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $71 = (invoke_iii(2782,($66|0),(2749952|0))|0);
   $72 = __THREW__; __THREW__ = 0;
   $73 = $72&1;
   if ($73) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $74 = __THREW__; __THREW__ = 0;
   $75 = $74&1;
   if ($75) {
    label = 6;
    break;
   }
   $76 = ($$13|0)<(0);
   if ($76) {
    label = 23;
   } else {
    $77 = HEAP32[$7>>2]|0;
    $78 = ($$13>>>0)<($77>>>0);
    if (!($78)) {
     label = 23;
    }
   }
   if ((label|0) == 23) {
    label = 0;
    __THREW__ = 0;
    $79 = (invoke_i(132)|0);
    $80 = __THREW__; __THREW__ = 0;
    $81 = $80&1;
    if ($81) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($79|0));
    $82 = __THREW__; __THREW__ = 0;
    $83 = $82&1;
    if ($83) {
     label = 6;
     break;
    }
   }
   $84 = HEAP32[$_____array>>2]|0;
   $85 = (($84) + 92|0);
   $86 = HEAP32[$85>>2]|0;
   $87 = Math_imul($86, $$13)|0;
   $88 = (($6) + ($87)|0);
   HEAP32[$88>>2] = $71;
   $$0 = $27;
  } else {
   $$0 = $$13;
  }
  $89 = (($V_0$01) + 1)|0;
  $90 = HEAP32[$0>>2]|0;
  $91 = ($89|0)<($90|0);
  if ($91) {
   $$13 = $$0;$V_0$01 = $89;
  } else {
   label = 28;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 28) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z222mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP47mscorlib_System_Collections_DictionaryEntry_arriP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910664);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(123,($L_14|0),(1926392|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(2307216|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2307216|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2783,($80|0),(2307216|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z252mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayiP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $_stackTraceSentry = sp;
 $0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910728);
 __THREW__ = 0;
 invoke_v(1003);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   HEAP32[$0>>2] = 1940640;
   __THREW__ = 0;
   ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
   $3 = (invoke_iii(772,(0|0),($$byval_copy|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $6 = __THREW__; __THREW__ = 0;
    $7 = $6&1;
    if (!($7)) {
     __THREW__ = 0;
     $8 = (invoke_ii(1782,($_____array|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if (!($10)) {
      __THREW__ = 0;
      invoke_vi(3799,($8|0));
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if (!($12)) {
       __THREW__ = 0;
       $13 = (invoke_iii(2730,(2224328|0),($8|0))|0);
       $14 = __THREW__; __THREW__ = 0;
       $15 = $14&1;
       if (!($15)) {
        __THREW__ = 0;
        invoke_vi(3799,($3|0));
        $16 = __THREW__; __THREW__ = 0;
        $17 = $16&1;
        do {
         if (!($17)) {
          __THREW__ = 0;
          $18 = (invoke_iii(2734,(2234664|0),($3|0))|0);
          $19 = __THREW__; __THREW__ = 0;
          $20 = $19&1;
          if (!($20)) {
           if ($18) {
            label = 18;
           } else {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $35 = __THREW__; __THREW__ = 0;
            $36 = $35&1;
            if ($36) {
             break;
            }
            __THREW__ = 0;
            $37 = (invoke_iii(2734,(2234664|0),($13|0))|0);
            $38 = __THREW__; __THREW__ = 0;
            $39 = $38&1;
            if ($39) {
             break;
            }
            if ($37) {
             label = 18;
            }
           }
           if ((label|0) == 18) {
            __THREW__ = 0;
            invoke_vi(3799,($13|0));
            $40 = __THREW__; __THREW__ = 0;
            $41 = $40&1;
            if ($41) {
             break;
            }
            __THREW__ = 0;
            $42 = (invoke_iiii(1640,(2235992|0),($13|0),($3|0))|0);
            $43 = __THREW__; __THREW__ = 0;
            $44 = $43&1;
            if ($44) {
             break;
            }
            if (!($42)) {
             __THREW__ = 0;
             (invoke_ii(2996,(2246120|0))|0);
             $45 = __THREW__; __THREW__ = 0;
             $46 = $45&1;
             if ($46) {
              break;
             }
             __THREW__ = 0;
             $47 = (invoke_ii(3469,(2246120|0))|0);
             $48 = __THREW__; __THREW__ = 0;
             $49 = $48&1;
             if ($49) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(2085,($47|0));
             $50 = __THREW__; __THREW__ = 0;
             $51 = $50&1;
             if ($51) {
              break;
             }
             __THREW__ = 0;
             invoke_vi(3848,($47|0));
             $52 = __THREW__; __THREW__ = 0;
             $53 = $52&1;
             if ($53) {
              break;
             }
             // unreachable;
            }
           }
           __THREW__ = 0;
           (invoke_ii(2996,(1167664|0))|0);
           $54 = __THREW__; __THREW__ = 0;
           $55 = $54&1;
           if (!($55)) {
            __THREW__ = 0;
            $56 = (invoke_iii(2782,($_____array|0),(1167664|0))|0);
            $57 = __THREW__; __THREW__ = 0;
            $58 = $57&1;
            if (!($58)) {
             __THREW__ = 0;
             invoke_viiii(306,($__this|0),($56|0),($index|0),($transform|0));
             $59 = __THREW__; __THREW__ = 0;
             $60 = $59&1;
             if (!($60)) {
              __ZN16StackTraceSentryD2Ev(0);
              STACKTOP = sp;return;
             }
            }
           }
          }
         }
        } while(0);
        $23 = ___cxa_find_matching_catch(348288|0)|0;
        $24 = tempRet0;
        $25 = (_llvm_eh_typeid_for((348288|0))|0);
        $26 = ($24|0)==($25|0);
        if (!($26)) {
         $$0 = $23;$$01 = $24;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
        $27 = (___cxa_begin_catch(($23|0))|0);
        $28 = HEAP32[$27>>2]|0;
        $29 = HEAP32[$28>>2]|0;
        __THREW__ = 0;
        $30 = (invoke_iii(2727,(2246120|0),($29|0))|0);
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        do {
         if (!($32)) {
          if (!($30)) {
           $65 = (___cxa_allocate_exception(4)|0);
           $66 = HEAP32[$27>>2]|0;
           HEAP32[$65>>2] = $66;
           __THREW__ = 0;
           invoke_viii(1567,($65|0),(348288|0),(0|0));
           $67 = __THREW__; __THREW__ = 0;
           $68 = $67&1;
           if ($68) {
            break;
           }
           // unreachable;
          }
          __THREW__ = 0;
          invoke_v(66);
          $33 = __THREW__; __THREW__ = 0;
          $34 = $33&1;
          if ($34) {
           break L1;
          }
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $69 = __THREW__; __THREW__ = 0;
          $70 = $69&1;
          if ($70) {
           break L1;
          }
          __THREW__ = 0;
          $71 = (invoke_ii(3469,(2560072|0))|0);
          $72 = __THREW__; __THREW__ = 0;
          $73 = $72&1;
          if ($73) {
           break L1;
          }
          $74 = HEAP32[3020648>>2]|0;
          $75 = HEAP32[3020656>>2]|0;
          __THREW__ = 0;
          invoke_viiii(175,($71|0),($74|0),($75|0),($28|0));
          $76 = __THREW__; __THREW__ = 0;
          $77 = $76&1;
          if ($77) {
           break L1;
          }
          __THREW__ = 0;
          invoke_vi(3848,($71|0));
          $78 = __THREW__; __THREW__ = 0;
          $79 = $78&1;
          if ($79) {
           break L1;
          }
          // unreachable;
         }
        } while(0);
        $61 = ___cxa_find_matching_catch()|0;
        $62 = tempRet0;
        __THREW__ = 0;
        invoke_v(66);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         $80 = ___cxa_find_matching_catch(0|0)|0;
         $81 = tempRet0;
         ___clang_call_terminate($80);
         // unreachable;
        } else {
         $$0 = $61;$$01 = $62;
         __ZN16StackTraceSentryD2Ev(0);
         ___resumeException($$0|0);
         // unreachable;
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 $$0 = $21;$$01 = $22;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$0|0);
 // unreachable;
}
function __Z273mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_ObjectP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP26mscorlib_System_Object_arriP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$14 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_14 = 0, $L_15 = 0, $V_0$02 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910784);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$14 = $index;$V_0$02 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $106 = __THREW__; __THREW__ = 0;
  $107 = $106&1;
  if ($107) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$02>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$02)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$14) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$02>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$02)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$02>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$02)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(131,($L_14|0),(1926968|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1921528|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1921528|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2149728|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2782,($80|0),(2149728|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break;
   }
   $90 = ($$14|0)<(0);
   if ($90) {
    label = 25;
   } else {
    $91 = HEAP32[$7>>2]|0;
    $92 = ($$14>>>0)<($91>>>0);
    if (!($92)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $93 = (invoke_i(132)|0);
    $94 = __THREW__; __THREW__ = 0;
    $95 = $94&1;
    if ($95) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($93|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 6;
     break;
    }
   }
   $98 = HEAP32[$_____array>>2]|0;
   $99 = (($98) + 92|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = Math_imul($100, $$14)|0;
   $102 = (($6) + ($101)|0);
   HEAP32[$102>>2] = $85;
   $$0 = $27;
  } else {
   $$0 = $$14;
  }
  $103 = (($V_0$02) + 1)|0;
  $104 = HEAP32[$0>>2]|0;
  $105 = ($103|0)<($104|0);
  if ($105) {
   $$14 = $$0;$V_0$02 = $103;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __ZN16VirtFuncInvoker2I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_($agg$result,$method,$obj,$p1,$p2) {
 $agg$result = $agg$result|0;
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 FUNCTION_TABLE_viiii[$3 & 511]($agg$result,$4,$p1,$p2);
 STACKTOP = sp;return;
}
function __Z366mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP102mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CUnityEngine_GUIStyleU003E_arriP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle($__this,$_____array,$index,$transform) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $transform = $transform|0;
 var $$0 = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $L_14 = 0, $L_15 = 0, $V_0$04 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_14 = sp;
 $L_15 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910848);
 $0 = (($__this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
 $3 = (($__this) + 12|0);
 $4 = (($__this) + 16|0);
 $5 = (($__this) + 20|0);
 $6 = (($_____array) + 16|0);
 $7 = (($_____array) + 12|0);
 $$16 = $index;$V_0$04 = 0;
 while(1) {
  $9 = HEAP32[$3>>2]|0;
  __THREW__ = 0;
  invoke_vi(3799,($9|0));
  $116 = __THREW__; __THREW__ = 0;
  $117 = $116&1;
  if ($117) {
   label = 6;
   break;
  }
  $8 = (($9) + 12|0);
  $10 = HEAP32[$8>>2]|0;
  $11 = ($V_0$04>>>0)<($10>>>0);
  if (!($11)) {
   __THREW__ = 0;
   $12 = (invoke_i(132)|0);
   $13 = __THREW__; __THREW__ = 0;
   $14 = $13&1;
   if ($14) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_vi(3302,($12|0));
   $15 = __THREW__; __THREW__ = 0;
   $16 = $15&1;
   if ($16) {
    label = 6;
    break;
   }
  }
  $19 = HEAP32[$9>>2]|0;
  $20 = (($9) + 16|0);
  $21 = (($19) + 92|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = Math_imul($22, $V_0$04)|0;
  $24 = (($20) + ($23)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)<(0);
  if ($26) {
   $27 = (($$16) + 1)|0;
   $28 = HEAP32[$4>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($28|0));
   $29 = __THREW__; __THREW__ = 0;
   $30 = $29&1;
   if ($30) {
    label = 6;
    break;
   }
   $31 = (($28) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($V_0$04>>>0)<($32>>>0);
   if (!($33)) {
    __THREW__ = 0;
    $34 = (invoke_i(132)|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($34|0));
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     label = 6;
     break;
    }
   }
   $39 = HEAP32[$28>>2]|0;
   $40 = (($28) + 16|0);
   $41 = (($39) + 92|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = Math_imul($42, $V_0$04)|0;
   $44 = (($40) + ($43)|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$5>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($46|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if ($48) {
    label = 6;
    break;
   }
   $49 = (($46) + 12|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ($V_0$04>>>0)<($50>>>0);
   if (!($51)) {
    __THREW__ = 0;
    $52 = (invoke_i(132)|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($52|0));
    $55 = __THREW__; __THREW__ = 0;
    $56 = $55&1;
    if ($56) {
     label = 6;
     break;
    }
   }
   $57 = HEAP32[$46>>2]|0;
   $58 = (($46) + 16|0);
   $59 = (($57) + 92|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = Math_imul($60, $V_0$04)|0;
   $62 = (($58) + ($61)|0);
   $63 = HEAP32[$62>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($transform|0));
   $64 = __THREW__; __THREW__ = 0;
   $65 = $64&1;
   if ($65) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   invoke_viiiii(131,($L_14|0),(1926968|0),($transform|0),($45|0),($63|0));
   $66 = __THREW__; __THREW__ = 0;
   $67 = $66&1;
   if ($67) {
    label = 6;
    break;
   }
   $68 = $L_14;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $L_15;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __THREW__ = 0;
   (invoke_ii(2996,(1921528|0))|0);
   $78 = __THREW__; __THREW__ = 0;
   $79 = $78&1;
   if ($79) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $80 = (invoke_iii(2724,(1921528|0),($L_15|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(1921528|0))|0);
   $83 = __THREW__; __THREW__ = 0;
   $84 = $83&1;
   if ($84) {
    label = 6;
    break;
   }
   __THREW__ = 0;
   $85 = (invoke_iii(2783,($80|0),(1921528|0))|0);
   $86 = __THREW__; __THREW__ = 0;
   $87 = $86&1;
   if ($87) {
    label = 6;
    break;
   }
   $88 = $85;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = (($88) + 4)|0;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $94 = __THREW__; __THREW__ = 0;
   $95 = $94&1;
   if ($95) {
    label = 6;
    break;
   }
   $96 = ($$16|0)<(0);
   if ($96) {
    label = 25;
   } else {
    $97 = HEAP32[$7>>2]|0;
    $98 = ($$16>>>0)<($97>>>0);
    if (!($98)) {
     label = 25;
    }
   }
   if ((label|0) == 25) {
    label = 0;
    __THREW__ = 0;
    $99 = (invoke_i(132)|0);
    $100 = __THREW__; __THREW__ = 0;
    $101 = $100&1;
    if ($101) {
     label = 6;
     break;
    }
    __THREW__ = 0;
    invoke_vi(3302,($99|0));
    $102 = __THREW__; __THREW__ = 0;
    $103 = $102&1;
    if ($103) {
     label = 6;
     break;
    }
   }
   $104 = HEAP32[$_____array>>2]|0;
   $105 = (($104) + 92|0);
   $106 = HEAP32[$105>>2]|0;
   $107 = Math_imul($106, $$16)|0;
   $108 = (($6) + ($107)|0);
   $109 = $108;
   $110 = $109;
   HEAP32[$110>>2] = $90;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $93;
   $$0 = $27;
  } else {
   $$0 = $$16;
  }
  $113 = (($V_0$04) + 1)|0;
  $114 = HEAP32[$0>>2]|0;
  $115 = ($113|0)<($114|0);
  if ($115) {
   $$16 = $$0;$V_0$04 = $113;
  } else {
   label = 30;
   break;
  }
 }
 if ((label|0) == 6) {
  $17 = ___cxa_find_matching_catch()|0;
  $18 = tempRet0;
  __ZN16StackTraceSentryD2Ev(0);
  ___resumeException($17|0);
  // unreachable;
 }
 else if ((label|0) == 30) {
  __ZN16StackTraceSentryD2Ev(0);
  STACKTOP = sp;return;
 }
}
function __Z81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910912);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception14770($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2910984);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911064);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2746712|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2746712|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2746712|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2746712|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2746712|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2746712|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2746712|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2746712|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2746712|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2746712|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_FontStyle_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911160);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911248);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911336);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2746712|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2746712|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2746712|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2746712|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2746712|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2746712|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2746712|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2746712|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2746712|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2746712|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911416);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911488);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2746712|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2746712|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911568);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1668,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1930512|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1930512|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911672);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911720);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911768);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2768456|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2768456|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2768456|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2768456|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2768456|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2768456|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2768456|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2768456|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2768456|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2768456|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_KeyCode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911824);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911872);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911920);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2768456|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2768456|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2768456|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2768456|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2768456|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2768456|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2768456|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2768456|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2768456|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2768456|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2911976);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912024);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2768456|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2768456|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912080);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1669,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1932776|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1932776|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912136);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912184);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912232);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2770104|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2770104|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2770104|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2770104|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2770104|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2770104|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2770104|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2770104|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2770104|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2770104|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_EventType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912288);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912336);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912384);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2770104|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2770104|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2770104|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2770104|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2770104|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2770104|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2770104|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2770104|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2770104|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2770104|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912440);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912488);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2770104|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2770104|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912544);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1670,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1935040|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1935040|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912600);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912648);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912696);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2770760|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2770760|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2770760|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2770760|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2770760|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2770760|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2770760|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2770760|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2770760|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2770760|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_ArrayP42UnityEngine_UnityEngine_EventModifiers_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912752);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z96mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912800);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912848);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2770760|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2770760|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2770760|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2770760|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2770760|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2770760|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2770760|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2770760|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2770760|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2770760|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912904);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2912952);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2770760|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2770760|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2913008);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1671,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1937304|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1937304|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_TextAsset($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_TextAsset($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2913168 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_TextAsset_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_TextAsset($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_TextAsset($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2913320 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_TextAsset($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_TextAsset($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2913424 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2913480 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_SerializePrivateVariables($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_SerializePrivateVariables($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2913632 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP53UnityEngine_UnityEngine_SerializePrivateVariables_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_SerializePrivateVariables($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_SerializePrivateVariables($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2913784 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayiP49UnityEngine_UnityEngine_SerializePrivateVariables($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayiP49UnityEngine_UnityEngine_SerializePrivateVariables($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2913888 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2913944 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_SerializeField($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_SerializeField($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2914096 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP42UnityEngine_UnityEngine_SerializeField_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_SerializeField($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_SerializeField($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2914248 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayiP38UnityEngine_UnityEngine_SerializeField($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayiP38UnityEngine_UnityEngine_SerializeField($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2914352 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2914408 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ShaderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Shader($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Shader($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2914560 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Shader_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Shader($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Shader($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2914712 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Shader($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Shader($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2914816 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ShaderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2914872 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_MaterialP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Material($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Material($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915024 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Material_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Material($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Material($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915176 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Material($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Material($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915280 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_MaterialP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915336 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL72mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Byte_arrP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP24mscorlib_System_Byte_arr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP24mscorlib_System_Byte_arr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915488 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP34mscorlib_System_ByteU005BU005D_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP24mscorlib_System_Byte_arr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL71mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP24mscorlib_System_Byte_arr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915640 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL70mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Byte_arrP21mscorlib_System_ArrayiP24mscorlib_System_Byte_arr($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL72mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Byte_arrP21mscorlib_System_ArrayiP24mscorlib_System_Byte_arr($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915744 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Byte_arrP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915800 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL119mscorlib_System_Array_m_Resize_mscorlib_System_Byte_arr_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP34mscorlib_System_ByteU005BU005D_arri($__this,$_____array,$newSize) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $newSize = $newSize|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915864 + 40|0))>>2]|0;
 __Z125mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriPPv($__this,$_____array,$newSize,$0);
 STACKTOP = sp;return;
}
function __ZL141mscorlib_System_Array_m_Resize_mscorlib_System_Byte_arr_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP34mscorlib_System_ByteU005BU005D_arrii($__this,$p0,$p1,$p2) {
 $__this = $__this|0;
 $p0 = $p0|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915920 + 40|0))>>2]|0;
 __Z147mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectPP26mscorlib_System_Object_arriiPPv($__this,$p0,$p1,$p2,$0);
 STACKTOP = sp;return;
}
function __ZL134mscorlib_System_Array_m_IndexOf_mscorlib_System_Byte_arr_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP34mscorlib_System_ByteU005BU005D_arrP24mscorlib_System_Byte_arrii($__this,$_____array,$value,$startIndex,$count) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $startIndex = $startIndex|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2915984 + 40|0))>>2]|0;
 $1 = (__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv($__this,$_____array,$value,$startIndex,$count,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z68mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ByteP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916032);
 HEAP8[$V_0>>0] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP8[$V_0>>0]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ByteP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916080);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ByteP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 5|0;
 $L_8 = sp + 6|0;
 $L_12 = sp + 7|0;
 HEAP8[$0>>0] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916128);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP8[$0>>0]|0;
      HEAP8[$L_6>>0] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2169424|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP8[$V_2>>0]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP8[$L_12>>0] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2169424|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2169424|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2169424|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP8[$L_8>>0] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2169424|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ByteP21mscorlib_System_ArrayP24mscorlib_System_Byte_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916184);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z78mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ByteP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916232);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ByteP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 7|0;
 $L_6 = sp + 4|0;
 $L_8 = sp + 5|0;
 $L_17 = sp + 6|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916280);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP8[$L_6>>0] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2169424|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2169424|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP8[$L_17>>0] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2169424|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2169424|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2169424|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2169424|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2169424|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2169424|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP8[$V_2>>0]|0;
        HEAP8[$L_8>>0] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2169424|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2169424|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z66mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ByteP21mscorlib_System_Arrayih($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916336);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z68mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ByteP21mscorlib_System_Arrayih($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP8[$0>>0] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916384);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP8[$L_3>>0] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2169424|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2169424|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z85mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ByteP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2916440);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1692,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1966632|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1966632|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Behaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Behaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2916600 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Behaviour_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Behaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Behaviour($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2916752 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Behaviour($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Behaviour($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2916856 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2916912 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_DisplayP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Display($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Display($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2917064 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_Display_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Display($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Display($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2917216 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Display($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Display($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2917320 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_DisplayP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2917376 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_IntPtrP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$sroa$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$sroa$0 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917424);
 HEAP32[$$sroa$0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($$sroa$0|0),($25|0),($23|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    $26 = HEAP32[$$sroa$0>>2]|0;
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_IntPtrP21mscorlib_System_Array22mscorlib_System_IntPtr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917472);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_IntPtrP21mscorlib_System_Array22mscorlib_System_IntPtr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2$sroa$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2$sroa$0 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_12 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917520);
 HEAP32[$V_2$sroa$0>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if (!($26)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $61 = HEAP32[$__this>>2]|0;
      $62 = (($61) + 28|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 92|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $V_1$011)|0;
      $67 = (($27) + ($66)|0);
      _memcpy(($V_2$sroa$0|0),($67|0),($65|0))|0;
      $68 = HEAP32[$item>>2]|0;
      HEAP32[$L_6>>2] = $68;
      __THREW__ = 0;
      (invoke_ii(2996,(2210080|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iii(2724,(2210080|0),($L_6|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = ($28|0)==(0|0);
      $32 = HEAP32[$V_2$sroa$0>>2]|0;
      if ($31) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $32;
      __THREW__ = 0;
      (invoke_ii(2996,(2210080|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $41 = (invoke_iii(2724,(2210080|0),($L_12|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2210080|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $46 = (invoke_iii(2724,(2210080|0),($item|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($46|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2210080|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $53 = (invoke_iii(2724,(2210080|0),($item|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1644,(2148736|0),($53|0),($41|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 4;
       break;
      }
      $59 = (($V_1$011) + 1)|0;
      if ($56) {
       $$0 = 1;
       label = 32;
       break;
      }
      $60 = ($59|0)<($23|0);
      if ($60) {
       $V_1$011 = $59;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $32;
      __THREW__ = 0;
      (invoke_ii(2996,(2210080|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_iii(2724,(2210080|0),($L_8|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = ($35|0)==(0|0);
      $$0 = $38;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_IntPtrP21mscorlib_System_ArrayP26mscorlib_System_IntPtr_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917576);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_IntPtrP21mscorlib_System_Array22mscorlib_System_IntPtr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917624);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_IntPtrP21mscorlib_System_Array22mscorlib_System_IntPtr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917672);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $28 = HEAP32[$item>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $74 = HEAP32[$__this>>2]|0;
        $75 = (($74) + 28|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = (($76) + 92|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = Math_imul($78, $V_1$013)|0;
        $80 = (($27) + ($79)|0);
        _memcpy(($V_2|0),($80|0),($78|0))|0;
        HEAP32[$L_6>>2] = $28;
        __THREW__ = 0;
        (invoke_ii(2996,(2210080|0))|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $29 = (invoke_iii(2724,(2210080|0),($L_6|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 4;
         break;
        }
        $32 = ($29|0)==(0|0);
        if ($32) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $28;
        __THREW__ = 0;
        (invoke_ii(2996,(2210080|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $50 = (invoke_iii(2724,(2210080|0),($L_17|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2210080|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $55 = (invoke_iii(2724,(2210080|0),($V_2|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2210080|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $62 = (invoke_iii(2724,(2210080|0),($V_2|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $65 = (invoke_iiii(1644,(2148736|0),($62|0),($50|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         label = 4;
         break;
        }
        $68 = (($V_1$013) + 1)|0;
        if ($65) {
         label = 34;
         break;
        }
        $73 = ($68|0)<($23|0);
        if ($73) {
         $V_1$013 = $68;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $33 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $33;
        __THREW__ = 0;
        (invoke_ii(2996,(2210080|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break L1;
        }
        __THREW__ = 0;
        $36 = (invoke_iii(2724,(2210080|0),($L_8|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break L1;
        }
        $39 = ($36|0)==(0|0);
        if ($39) {
         __THREW__ = 0;
         $40 = (invoke_iii(755,($__this|0),0)|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break L1;
         }
         $43 = (($40) + ($V_1$013))|0;
         $$0 = $43;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $44 = (invoke_iii(755,($__this|0),0)|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          break L1;
         }
         $47 = (($44) + -1)|0;
         $$0 = $47;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $69 = (invoke_iii(755,($__this|0),0)|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break L1;
        }
        $72 = (($69) + ($V_1$013))|0;
        $$0 = $72;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $83 = (invoke_iii(755,($__this|0),0)|0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if (!($85)) {
      $86 = (($83) + -1)|0;
      $$0 = $86;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_IntPtrP21mscorlib_System_Arrayi22mscorlib_System_IntPtr($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917728);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_IntPtrP21mscorlib_System_Arrayi22mscorlib_System_IntPtr($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917776);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($item|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = HEAP32[$item>>2]|0;
      HEAP32[$L_3>>2] = $24;
      __THREW__ = 0;
      (invoke_ii(2996,(2210080|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2210080|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($20) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$20>>2]|0;
          $44 = (($20) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_IntPtrP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2917832);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1695,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1973424|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1973424|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TransformP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Transform($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Transform($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2917992 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Transform_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Transform($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Transform($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2918144 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Transform($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Transform($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2918248 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TransformP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2918304 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_MotionP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Motion($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Motion($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2918456 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Motion_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Motion($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Motion($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2918608 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Motion($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Motion($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2918712 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_MotionP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2918768 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Rigidbody($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Rigidbody($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2918920 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Rigidbody_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Rigidbody($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Rigidbody($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2919072 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Rigidbody($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Rigidbody($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2919176 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2919232 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ColliderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Collider($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Collider($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2919384 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Collider_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Collider($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Collider($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2919536 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Collider($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Collider($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2919640 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ColliderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2919696 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z86mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2919744);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2919792);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2919840);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2836688|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2836688|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2836688|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2836688|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2836688|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2836688|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2836688|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2836688|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2836688|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2836688|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_ArrayP42UnityEngine_UnityEngine_CollisionFlags_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2919896);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z96mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2919944);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2919992);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2836688|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2836688|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2836688|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2836688|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2836688|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2836688|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2836688|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2836688|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2836688|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2836688|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920048);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920096);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2836688|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2836688|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920152);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1700,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1984744|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1984744|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_AudioClip($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_AudioClip($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2920312 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AudioClip_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_AudioClip($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_AudioClip($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2920464 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_AudioClip($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_AudioClip($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2920568 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2920624 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_SingleP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = Math_fround(0);
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920672);
 HEAPF32[$V_0>>2] = Math_fround(0.0);
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = Math_fround(HEAPF32[$V_0>>2]);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return (Math_fround($26));
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return Math_fround(0);
}
function __Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_SingleP21mscorlib_System_Arrayf($__this,$item) {
 $__this = $__this|0;
 $item = Math_fround($item);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920720);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_SingleP21mscorlib_System_Arrayf($__this,$item) {
 $__this = $__this|0;
 $item = Math_fround($item);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = Math_fround(0), $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = Math_fround(0), $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAPF32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920768);
 HEAPF32[$V_2>>2] = Math_fround(0.0);
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = Math_fround(HEAPF32[$0>>2]);
      HEAPF32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2194912|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = Math_fround(HEAPF32[$V_2>>2]);
      if ($32) {
       label = 18;
       break;
      }
      HEAPF32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2194912|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2194912|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2194912|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2194912|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2194912|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2194912|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAPF32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2194912|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2194912|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_SingleP21mscorlib_System_ArrayP26mscorlib_System_Single_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920824);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_SingleP21mscorlib_System_Arrayf($__this,$item) {
 $__this = $__this|0;
 $item = Math_fround($item);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920872);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_SingleP21mscorlib_System_Arrayf($__this,$item) {
 $__this = $__this|0;
 $item = Math_fround($item);
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = Math_fround(0), $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920920);
 HEAPF32[$V_2>>2] = Math_fround(0.0);
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAPF32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2194912|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2194912|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAPF32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2194912|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2194912|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2194912|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2194912|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2194912|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2194912|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = Math_fround(HEAPF32[$V_2>>2]);
        HEAPF32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2194912|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2194912|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_SingleP21mscorlib_System_Arrayif($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = Math_fround($item);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2920976);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_SingleP21mscorlib_System_Arrayif($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = Math_fround($item);
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAPF32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921024);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAPF32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2194912|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2194912|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_SingleP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921080);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1702,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1989272|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1989272|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921136);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921184);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921232);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2841288|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2841288|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2841288|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2841288|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2841288|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2841288|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2841288|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2841288|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2841288|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2841288|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_WrapMode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921288);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921336);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921384);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2841288|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2841288|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2841288|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2841288|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2841288|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2841288|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2841288|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2841288|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2841288|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2841288|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921440);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921488);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2841288|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2841288|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921544);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1703,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1991536|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1991536|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921600);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921648);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921696);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2841760|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2841760|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2841760|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2841760|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2841760|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2841760|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2841760|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2841760|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2841760|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2841760|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AnimationEventSource_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921752);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921800);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921848);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2841760|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2841760|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2841760|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2841760|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2841760|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2841760|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2841760|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2841760|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2841760|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2841760|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921904);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2921952);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2841760|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2841760|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922008);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1704,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1993800|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1993800|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL85mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AnimationClip($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AnimationClip($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2922168 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_AnimationClip_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AnimationClip($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AnimationClip($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2922320 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_AnimationClip($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_AnimationClip($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2922424 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2922480 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922528);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922576);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922624);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2846200|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2846200|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2846200|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2846200|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2846200|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2846200|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2846200|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2846200|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2846200|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2846200|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_PlayMode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922680);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922728);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922776);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2846200|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2846200|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2846200|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2846200|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2846200|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2846200|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2846200|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2846200|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2846200|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2846200|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922832);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922880);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2846200|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2846200|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2922936);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1706,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2004584|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2004584|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Animator($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Animator($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2923096 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Animator_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Animator($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Animator($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2923248 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Animator($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Animator($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2923352 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2923408 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TerrainP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Terrain($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Terrain($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2923560 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_Terrain_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Terrain($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Terrain($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2923712 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Terrain($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Terrain($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2923816 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TerrainP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2923872 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2923920);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2923968);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924016);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2853288|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2853288|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2853288|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2853288|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2853288|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2853288|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2853288|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2853288|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2853288|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2853288|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_TextAnchor_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924072);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924120);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924168);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2853288|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2853288|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2853288|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2853288|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2853288|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2853288|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2853288|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2853288|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2853288|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2853288|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924224);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924272);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2853288|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2853288|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924328);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1709,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2011376|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2011376|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924384);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924432);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924480);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2853712|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2853712|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2853712|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2853712|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2853712|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2853712|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2853712|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2853712|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2853712|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2853712|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_ArrayP46UnityEngine_UnityEngine_HorizontalWrapMode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924536);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924584);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924632);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2853712|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2853712|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2853712|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2853712|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2853712|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2853712|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2853712|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2853712|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2853712|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2853712|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924688);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924736);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2853712|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2853712|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924792);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1710,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2013640|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2013640|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924848);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924896);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2924944);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2854128|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2854128|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2854128|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2854128|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2854128|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2854128|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2854128|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2854128|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2854128|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2854128|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_VerticalWrapMode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2925000);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2925048);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2925096);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2854128|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2854128|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2854128|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2854128|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2854128|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2854128|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2854128|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2854128|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2854128|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2854128|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2925152);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2925200);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2854128|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2854128|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2925256);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1711,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2015904|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2015904|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL76mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_FontP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP28UnityEngine_UnityEngine_Font($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP28UnityEngine_UnityEngine_Font($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2925416 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Font_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP28UnityEngine_UnityEngine_Font($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL75mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP28UnityEngine_UnityEngine_Font($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2925568 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL74mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayiP28UnityEngine_UnityEngine_Font($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL76mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayiP28UnityEngine_UnityEngine_Font($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2925672 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_FontP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2925728 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CanvasP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Canvas($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Canvas($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2925880 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Canvas_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Canvas($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Canvas($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926032 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Canvas($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Canvas($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926136 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CanvasP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926192 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__get_Item_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Add_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_Contains_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926344 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP66System_Core_System_Runtime_CompilerServices_ExtensionAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_Remove_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__IndexOf_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926496 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__Insert_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayiP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__set_Item_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayiP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926600 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926656 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__get_Item_System_Core_System_MonoTODOAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Add_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP36System_Core_System_MonoTODOAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Contains_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP36System_Core_System_MonoTODOAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926808 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP40System_Core_System_MonoTODOAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_Remove_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP36System_Core_System_MonoTODOAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__IndexOf_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP36System_Core_System_MonoTODOAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2926960 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__Insert_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayiP36System_Core_System_MonoTODOAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_m_InternalArray__set_Item_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayiP36System_Core_System_MonoTODOAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927064 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_System_Core_System_MonoTODOAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927120 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL73mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_AttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_AttributeP21mscorlib_System_ArrayP25mscorlib_System_Attribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_AttributeP21mscorlib_System_ArrayP25mscorlib_System_Attribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927272 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_AttributeP21mscorlib_System_ArrayP29mscorlib_System_Attribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_AttributeP21mscorlib_System_ArrayP25mscorlib_System_Attribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL72mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_AttributeP21mscorlib_System_ArrayP25mscorlib_System_Attribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927424 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL71mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_AttributeP21mscorlib_System_ArrayiP25mscorlib_System_Attribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL73mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_AttributeP21mscorlib_System_ArrayiP25mscorlib_System_Attribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927528 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_AttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927584 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_SerializableAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP37mscorlib_System_SerializableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP37mscorlib_System_SerializableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927736 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP41mscorlib_System_SerializableAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP37mscorlib_System_SerializableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP37mscorlib_System_SerializableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927888 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayiP37mscorlib_System_SerializableAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayiP37mscorlib_System_SerializableAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2927992 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_SerializableAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928048 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL87mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP39mscorlib_System_AttributeUsageAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP39mscorlib_System_AttributeUsageAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928200 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP43mscorlib_System_AttributeUsageAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP39mscorlib_System_AttributeUsageAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP39mscorlib_System_AttributeUsageAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928352 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayiP39mscorlib_System_AttributeUsageAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL87mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayiP39mscorlib_System_AttributeUsageAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928456 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928512 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928664 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928816 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928920 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2928976 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z69mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Int64P21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929024);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($V_0|0),($29|0),($27|0))|0;
    $30 = $V_0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $35;
    STACKTOP = sp;return ($32|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3849,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Int64P21mscorlib_System_Arrayx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929072);
 __THREW__ = 0;
 invoke_v(995);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2622808|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($6|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3849,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Int64P21mscorlib_System_Arrayx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $2 = sp + 32|0;
 $_stackTraceSentry = sp + 40|0;
 $V_2 = sp + 8|0;
 $L_6 = sp + 16|0;
 $L_8 = sp + 24|0;
 $L_12 = sp;
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = $0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $1;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929120);
 $7 = $V_2;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if (!($12)) {
   __THREW__ = 0;
   $13 = (invoke_ii(1859,($__this|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = ($13|0)<(2);
    if (!($16)) {
     $21 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $22 = (invoke_iii(783,(0|0),($21|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2636920|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($27|0),($22|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($27|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $34 = (invoke_ii(1857,($__this|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $37 = ($34|0)>(0);
     if (!($37)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $38 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $85 = HEAP32[$__this>>2]|0;
      $86 = (($85) + 28|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = (($87) + 92|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = Math_imul($89, $V_1$011)|0;
      $91 = (($38) + ($90)|0);
      _memcpy(($V_2|0),($91|0),($89|0))|0;
      $92 = $2;
      $93 = $92;
      $94 = HEAP32[$93>>2]|0;
      $95 = (($92) + 4)|0;
      $96 = $95;
      $97 = HEAP32[$96>>2]|0;
      $98 = $L_6;
      $99 = $98;
      HEAP32[$99>>2] = $94;
      $100 = (($98) + 4)|0;
      $101 = $100;
      HEAP32[$101>>2] = $97;
      __THREW__ = 0;
      (invoke_ii(2996,(2162248|0))|0);
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $39 = (invoke_iii(2724,(2162248|0),($L_6|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      $42 = ($39|0)==(0|0);
      $43 = $V_2;
      $44 = $43;
      $45 = HEAP32[$44>>2]|0;
      $46 = (($43) + 4)|0;
      $47 = $46;
      $48 = HEAP32[$47>>2]|0;
      if ($42) {
       label = 18;
       break;
      }
      $59 = $L_12;
      $60 = $59;
      HEAP32[$60>>2] = $45;
      $61 = (($59) + 4)|0;
      $62 = $61;
      HEAP32[$62>>2] = $48;
      __THREW__ = 0;
      (invoke_ii(2996,(2162248|0))|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $65 = (invoke_iii(2724,(2162248|0),($L_12|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2162248|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(2162248|0),($2|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($70|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2162248|0))|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $77 = (invoke_iii(2724,(2162248|0),($2|0))|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $80 = (invoke_iiii(1644,(2148736|0),($77|0),($65|0))|0);
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       label = 4;
       break;
      }
      $83 = (($V_1$011) + 1)|0;
      if ($80) {
       $$0 = 1;
       label = 32;
       break;
      }
      $84 = ($83|0)<($34|0);
      if ($84) {
       $V_1$011 = $83;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $17 = ___cxa_find_matching_catch()|0;
      $18 = tempRet0;
      $lpad$phi$index = $17;$lpad$phi$index2 = $18;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $49 = $L_8;
      $50 = $49;
      HEAP32[$50>>2] = $45;
      $51 = (($49) + 4)|0;
      $52 = $51;
      HEAP32[$52>>2] = $48;
      __THREW__ = 0;
      (invoke_ii(2996,(2162248|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      __THREW__ = 0;
      $55 = (invoke_iii(2724,(2162248|0),($L_8|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = ($55|0)==(0|0);
      $$0 = $58;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $lpad$phi$index = $19;$lpad$phi$index2 = $20;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Int64P21mscorlib_System_ArrayP25mscorlib_System_Int64_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929176);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Int64P21mscorlib_System_Arrayx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929224);
 __THREW__ = 0;
 invoke_v(998);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2622808|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($6|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3849,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Int64P21mscorlib_System_Arrayx($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929272);
 $2 = $V_2;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_ii(1859,($__this|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = ($8|0)<(2);
    if (!($11)) {
     $16 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $17 = (invoke_iii(783,(0|0),($16|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     $22 = (invoke_ii(3469,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($22|0),($17|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($22|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($__this|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = ($29|0)>(0);
     L13: do {
      if ($32) {
       $33 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $92 = HEAP32[$__this>>2]|0;
        $93 = (($92) + 28|0);
        $94 = HEAP32[$93>>2]|0;
        $95 = (($94) + 92|0);
        $96 = HEAP32[$95>>2]|0;
        $97 = Math_imul($96, $V_1$013)|0;
        $98 = (($33) + ($97)|0);
        _memcpy(($V_2|0),($98|0),($96|0))|0;
        $99 = $L_6;
        $100 = $99;
        HEAP32[$100>>2] = $0;
        $101 = (($99) + 4)|0;
        $102 = $101;
        HEAP32[$102>>2] = $1;
        __THREW__ = 0;
        (invoke_ii(2996,(2162248|0))|0);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2724,(2162248|0),($L_6|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         label = 4;
         break;
        }
        $37 = ($34|0)==(0|0);
        if ($37) {
         label = 18;
         break;
        }
        $62 = $L_17;
        $63 = $62;
        HEAP32[$63>>2] = $0;
        $64 = (($62) + 4)|0;
        $65 = $64;
        HEAP32[$65>>2] = $1;
        __THREW__ = 0;
        (invoke_ii(2996,(2162248|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $68 = (invoke_iii(2724,(2162248|0),($L_17|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2162248|0))|0);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $73 = (invoke_iii(2724,(2162248|0),($V_2|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($73|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2162248|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $80 = (invoke_iii(2724,(2162248|0),($V_2|0))|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $83 = (invoke_iiii(1644,(2148736|0),($80|0),($68|0))|0);
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         label = 4;
         break;
        }
        $86 = (($V_1$013) + 1)|0;
        if ($83) {
         label = 34;
         break;
        }
        $91 = ($86|0)<($29|0);
        if ($91) {
         $V_1$013 = $86;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $12 = ___cxa_find_matching_catch()|0;
        $13 = tempRet0;
        $lpad$phi$index = $12;$lpad$phi$index2 = $13;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $38 = $V_2;
        $39 = $38;
        $40 = HEAP32[$39>>2]|0;
        $41 = (($38) + 4)|0;
        $42 = $41;
        $43 = HEAP32[$42>>2]|0;
        $44 = $L_8;
        $45 = $44;
        HEAP32[$45>>2] = $40;
        $46 = (($44) + 4)|0;
        $47 = $46;
        HEAP32[$47>>2] = $43;
        __THREW__ = 0;
        (invoke_ii(2996,(2162248|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break L1;
        }
        __THREW__ = 0;
        $50 = (invoke_iii(2724,(2162248|0),($L_8|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break L1;
        }
        $53 = ($50|0)==(0|0);
        if ($53) {
         __THREW__ = 0;
         $54 = (invoke_iii(755,($__this|0),0)|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break L1;
         }
         $57 = (($54) + ($V_1$013))|0;
         $$0 = $57;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + -1)|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $87 = (invoke_iii(755,($__this|0),0)|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         break L1;
        }
        $90 = (($87) + ($V_1$013))|0;
        $$0 = $90;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $105 = (invoke_iii(755,($__this|0),0)|0);
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if (!($107)) {
      $108 = (($105) + -1)|0;
      $$0 = $108;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Int64P21mscorlib_System_Arrayix($__this,$index,$0,$1) {
 $__this = $__this|0;
 $index = $index|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929328);
 __THREW__ = 0;
 invoke_v(1000);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2622808|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($6|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3849,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z69mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Int64P21mscorlib_System_Arrayix($__this,$index,$0,$1) {
 $__this = $__this|0;
 $index = $index|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $2 = sp + 8|0;
 $_stackTraceSentry = sp + 16|0;
 $L_3 = sp;
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = $0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $1;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929376);
 __THREW__ = 0;
 invoke_v(1001);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_ii(1857,($__this|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = ($9|0)>($index|0);
    if (!($12)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2561352|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($17|0),($20|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = ($27|0)==(0|0);
      if ($30) {
       $59 = (($__this) + 16|0);
       $60 = HEAP32[$__this>>2]|0;
       $61 = (($60) + 28|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($62) + 92|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = Math_imul($64, $index)|0;
       $66 = (($59) + ($65)|0);
       _memcpy(($66|0),($2|0),($64|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $31 = $L_3;
      $32 = $31;
      HEAP32[$32>>2] = $0;
      $33 = (($31) + 4)|0;
      $34 = $33;
      HEAP32[$34>>2] = $1;
      __THREW__ = 0;
      (invoke_ii(2996,(2162248|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       __THREW__ = 0;
       $37 = (invoke_iii(2724,(2162248|0),($L_3|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        __THREW__ = 0;
        invoke_vi(3799,($27|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if (!($41)) {
         $42 = ($index|0)<(0);
         if ($42) {
          label = 18;
         } else {
          $43 = (($27) + 12|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = ($44>>>0)>($index>>>0);
          if (!($45)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $46 = (invoke_i(132)|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($46|0));
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($27|0),($37|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if (!($52)) {
          $53 = HEAP32[$27>>2]|0;
          $54 = (($27) + 16|0);
          $55 = (($53) + 92|0);
          $56 = HEAP32[$55>>2]|0;
          $57 = Math_imul($56, $index)|0;
          $58 = (($54) + ($57)|0);
          HEAP32[$58>>2] = $37;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Int64P21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929432);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1720,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2036552|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2036552|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_UInt32P21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929488);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_UInt32P21mscorlib_System_Arrayj($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929536);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_UInt32P21mscorlib_System_Arrayj($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929584);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2164560|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2164560|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2164560|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2164560|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2164560|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_UInt32P21mscorlib_System_ArrayP26mscorlib_System_UInt32_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929640);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_UInt32P21mscorlib_System_Arrayj($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929688);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_UInt32P21mscorlib_System_Arrayj($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929736);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2164560|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2164560|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2164560|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2164560|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2164560|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2164560|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2164560|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2164560|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2164560|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2164560|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_UInt32P21mscorlib_System_Arrayij($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929792);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_UInt32P21mscorlib_System_Arrayij($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929840);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2164560|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2164560|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_UInt32P21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2929896);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1721,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2039304|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2039304|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP37mscorlib_System_CLSCompliantAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP37mscorlib_System_CLSCompliantAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2930056 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP41mscorlib_System_CLSCompliantAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP37mscorlib_System_CLSCompliantAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP37mscorlib_System_CLSCompliantAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2930208 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayiP37mscorlib_System_CLSCompliantAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayiP37mscorlib_System_CLSCompliantAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2930312 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2930368 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_UInt64P21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930416);
 $0 = $V_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($V_0|0),($29|0),($27|0))|0;
    $30 = $V_0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    tempRet0 = $35;
    STACKTOP = sp;return ($32|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3849,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_UInt64P21mscorlib_System_Arrayy($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930464);
 __THREW__ = 0;
 invoke_v(995);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2622808|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($6|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3849,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_UInt64P21mscorlib_System_Arrayy($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $2 = sp + 32|0;
 $_stackTraceSentry = sp + 40|0;
 $V_2 = sp + 8|0;
 $L_6 = sp + 16|0;
 $L_8 = sp + 24|0;
 $L_12 = sp;
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = $0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $1;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930512);
 $7 = $V_2;
 $8 = $7;
 HEAP32[$8>>2] = 0;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 do {
  if (!($12)) {
   __THREW__ = 0;
   $13 = (invoke_ii(1859,($__this|0))|0);
   $14 = __THREW__; __THREW__ = 0;
   $15 = $14&1;
   if (!($15)) {
    $16 = ($13|0)<(2);
    if (!($16)) {
     $21 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $22 = (invoke_iii(783,(0|0),($21|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     $27 = (invoke_ii(3469,(2636920|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($27|0),($22|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($27|0));
     $32 = __THREW__; __THREW__ = 0;
     $33 = $32&1;
     if ($33) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $34 = (invoke_ii(1857,($__this|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $37 = ($34|0)>(0);
     if (!($37)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $38 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $85 = HEAP32[$__this>>2]|0;
      $86 = (($85) + 28|0);
      $87 = HEAP32[$86>>2]|0;
      $88 = (($87) + 92|0);
      $89 = HEAP32[$88>>2]|0;
      $90 = Math_imul($89, $V_1$011)|0;
      $91 = (($38) + ($90)|0);
      _memcpy(($V_2|0),($91|0),($89|0))|0;
      $92 = $2;
      $93 = $92;
      $94 = HEAP32[$93>>2]|0;
      $95 = (($92) + 4)|0;
      $96 = $95;
      $97 = HEAP32[$96>>2]|0;
      $98 = $L_6;
      $99 = $98;
      HEAP32[$99>>2] = $94;
      $100 = (($98) + 4)|0;
      $101 = $100;
      HEAP32[$101>>2] = $97;
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $102 = __THREW__; __THREW__ = 0;
      $103 = $102&1;
      if ($103) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $39 = (invoke_iii(2724,(2167208|0),($L_6|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      $42 = ($39|0)==(0|0);
      $43 = $V_2;
      $44 = $43;
      $45 = HEAP32[$44>>2]|0;
      $46 = (($43) + 4)|0;
      $47 = $46;
      $48 = HEAP32[$47>>2]|0;
      if ($42) {
       label = 18;
       break;
      }
      $59 = $L_12;
      $60 = $59;
      HEAP32[$60>>2] = $45;
      $61 = (($59) + 4)|0;
      $62 = $61;
      HEAP32[$62>>2] = $48;
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $63 = __THREW__; __THREW__ = 0;
      $64 = $63&1;
      if ($64) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $65 = (invoke_iii(2724,(2167208|0),($L_12|0))|0);
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(2167208|0),($2|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($70|0));
      $73 = __THREW__; __THREW__ = 0;
      $74 = $73&1;
      if ($74) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $77 = (invoke_iii(2724,(2167208|0),($2|0))|0);
      $78 = __THREW__; __THREW__ = 0;
      $79 = $78&1;
      if ($79) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $80 = (invoke_iiii(1644,(2148736|0),($77|0),($65|0))|0);
      $81 = __THREW__; __THREW__ = 0;
      $82 = $81&1;
      if ($82) {
       label = 4;
       break;
      }
      $83 = (($V_1$011) + 1)|0;
      if ($80) {
       $$0 = 1;
       label = 32;
       break;
      }
      $84 = ($83|0)<($34|0);
      if ($84) {
       $V_1$011 = $83;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $17 = ___cxa_find_matching_catch()|0;
      $18 = tempRet0;
      $lpad$phi$index = $17;$lpad$phi$index2 = $18;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $49 = $L_8;
      $50 = $49;
      HEAP32[$50>>2] = $45;
      $51 = (($49) + 4)|0;
      $52 = $51;
      HEAP32[$52>>2] = $48;
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       break;
      }
      __THREW__ = 0;
      $55 = (invoke_iii(2724,(2167208|0),($L_8|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       break;
      }
      $58 = ($55|0)==(0|0);
      $$0 = $58;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $19 = ___cxa_find_matching_catch()|0;
 $20 = tempRet0;
 $lpad$phi$index = $19;$lpad$phi$index2 = $20;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_UInt64P21mscorlib_System_ArrayP26mscorlib_System_UInt64_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930568);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_UInt64P21mscorlib_System_Arrayy($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930616);
 __THREW__ = 0;
 invoke_v(998);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2622808|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($6|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3849,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_UInt64P21mscorlib_System_Arrayy($__this,$0,$1) {
 $__this = $__this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930664);
 $2 = $V_2;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L1: do {
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_ii(1859,($__this|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = ($8|0)<(2);
    if (!($11)) {
     $16 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $17 = (invoke_iii(783,(0|0),($16|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     $22 = (invoke_ii(3469,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($22|0),($17|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($22|0));
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $29 = (invoke_ii(1857,($__this|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if (!($31)) {
     $32 = ($29|0)>(0);
     L13: do {
      if ($32) {
       $33 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $92 = HEAP32[$__this>>2]|0;
        $93 = (($92) + 28|0);
        $94 = HEAP32[$93>>2]|0;
        $95 = (($94) + 92|0);
        $96 = HEAP32[$95>>2]|0;
        $97 = Math_imul($96, $V_1$013)|0;
        $98 = (($33) + ($97)|0);
        _memcpy(($V_2|0),($98|0),($96|0))|0;
        $99 = $L_6;
        $100 = $99;
        HEAP32[$100>>2] = $0;
        $101 = (($99) + 4)|0;
        $102 = $101;
        HEAP32[$102>>2] = $1;
        __THREW__ = 0;
        (invoke_ii(2996,(2167208|0))|0);
        $103 = __THREW__; __THREW__ = 0;
        $104 = $103&1;
        if ($104) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2724,(2167208|0),($L_6|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         label = 4;
         break;
        }
        $37 = ($34|0)==(0|0);
        if ($37) {
         label = 18;
         break;
        }
        $62 = $L_17;
        $63 = $62;
        HEAP32[$63>>2] = $0;
        $64 = (($62) + 4)|0;
        $65 = $64;
        HEAP32[$65>>2] = $1;
        __THREW__ = 0;
        (invoke_ii(2996,(2167208|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $68 = (invoke_iii(2724,(2167208|0),($L_17|0))|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2167208|0))|0);
        $71 = __THREW__; __THREW__ = 0;
        $72 = $71&1;
        if ($72) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $73 = (invoke_iii(2724,(2167208|0),($V_2|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($73|0));
        $76 = __THREW__; __THREW__ = 0;
        $77 = $76&1;
        if ($77) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2167208|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $80 = (invoke_iii(2724,(2167208|0),($V_2|0))|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $83 = (invoke_iiii(1644,(2148736|0),($80|0),($68|0))|0);
        $84 = __THREW__; __THREW__ = 0;
        $85 = $84&1;
        if ($85) {
         label = 4;
         break;
        }
        $86 = (($V_1$013) + 1)|0;
        if ($83) {
         label = 34;
         break;
        }
        $91 = ($86|0)<($29|0);
        if ($91) {
         $V_1$013 = $86;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $12 = ___cxa_find_matching_catch()|0;
        $13 = tempRet0;
        $lpad$phi$index = $12;$lpad$phi$index2 = $13;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $38 = $V_2;
        $39 = $38;
        $40 = HEAP32[$39>>2]|0;
        $41 = (($38) + 4)|0;
        $42 = $41;
        $43 = HEAP32[$42>>2]|0;
        $44 = $L_8;
        $45 = $44;
        HEAP32[$45>>2] = $40;
        $46 = (($44) + 4)|0;
        $47 = $46;
        HEAP32[$47>>2] = $43;
        __THREW__ = 0;
        (invoke_ii(2996,(2167208|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break L1;
        }
        __THREW__ = 0;
        $50 = (invoke_iii(2724,(2167208|0),($L_8|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         break L1;
        }
        $53 = ($50|0)==(0|0);
        if ($53) {
         __THREW__ = 0;
         $54 = (invoke_iii(755,($__this|0),0)|0);
         $55 = __THREW__; __THREW__ = 0;
         $56 = $55&1;
         if ($56) {
          break L1;
         }
         $57 = (($54) + ($V_1$013))|0;
         $$0 = $57;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + -1)|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $87 = (invoke_iii(755,($__this|0),0)|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         break L1;
        }
        $90 = (($87) + ($V_1$013))|0;
        $$0 = $90;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $105 = (invoke_iii(755,($__this|0),0)|0);
     $106 = __THREW__; __THREW__ = 0;
     $107 = $106&1;
     if (!($107)) {
      $108 = (($105) + -1)|0;
      $$0 = $108;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 $lpad$phi$index = $14;$lpad$phi$index2 = $15;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_UInt64P21mscorlib_System_Arrayiy($__this,$index,$0,$1) {
 $__this = $__this|0;
 $index = $index|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930720);
 __THREW__ = 0;
 invoke_v(1000);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $4 = __THREW__; __THREW__ = 0;
  $5 = $4&1;
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(3469,(2622808|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($6|0),($9|0));
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     __THREW__ = 0;
     invoke_vi(3849,($6|0));
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if (!($13)) {
      // unreachable;
     }
    }
   }
  }
 }
 $14 = ___cxa_find_matching_catch()|0;
 $15 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($14|0);
 // unreachable;
}
function __Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_UInt64P21mscorlib_System_Arrayiy($__this,$index,$0,$1) {
 $__this = $__this|0;
 $index = $index|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $2 = sp + 8|0;
 $_stackTraceSentry = sp + 16|0;
 $L_3 = sp;
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = $0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = $1;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930768);
 __THREW__ = 0;
 invoke_v(1001);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 do {
  if (!($8)) {
   __THREW__ = 0;
   $9 = (invoke_ii(1857,($__this|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $12 = ($9|0)>($index|0);
    if (!($12)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2561352|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     $20 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($17|0),($20|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     __THREW__ = 0;
     $27 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if (!($29)) {
      $30 = ($27|0)==(0|0);
      if ($30) {
       $59 = (($__this) + 16|0);
       $60 = HEAP32[$__this>>2]|0;
       $61 = (($60) + 28|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($62) + 92|0);
       $64 = HEAP32[$63>>2]|0;
       $65 = Math_imul($64, $index)|0;
       $66 = (($59) + ($65)|0);
       _memcpy(($66|0),($2|0),($64|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $31 = $L_3;
      $32 = $31;
      HEAP32[$32>>2] = $0;
      $33 = (($31) + 4)|0;
      $34 = $33;
      HEAP32[$34>>2] = $1;
      __THREW__ = 0;
      (invoke_ii(2996,(2167208|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if (!($36)) {
       __THREW__ = 0;
       $37 = (invoke_iii(2724,(2167208|0),($L_3|0))|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if (!($39)) {
        __THREW__ = 0;
        invoke_vi(3799,($27|0));
        $40 = __THREW__; __THREW__ = 0;
        $41 = $40&1;
        if (!($41)) {
         $42 = ($index|0)<(0);
         if ($42) {
          label = 18;
         } else {
          $43 = (($27) + 12|0);
          $44 = HEAP32[$43>>2]|0;
          $45 = ($44>>>0)>($index>>>0);
          if (!($45)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $46 = (invoke_i(132)|0);
          $47 = __THREW__; __THREW__ = 0;
          $48 = $47&1;
          if ($48) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($46|0));
          $49 = __THREW__; __THREW__ = 0;
          $50 = $49&1;
          if ($50) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($27|0),($37|0));
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if (!($52)) {
          $53 = HEAP32[$27>>2]|0;
          $54 = (($27) + 16|0);
          $55 = (($53) + 92|0);
          $56 = HEAP32[$55>>2]|0;
          $57 = Math_imul($56, $index)|0;
          $58 = (($54) + ($57)|0);
          HEAP32[$58>>2] = $37;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($13|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_UInt64P21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930824);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1723,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2044296|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2044296|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_SByteP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930880);
 HEAP8[$V_0>>0] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP8[$V_0>>0]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_SByteP21mscorlib_System_Arraya($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930928);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_SByteP21mscorlib_System_Arraya($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 5|0;
 $L_8 = sp + 6|0;
 $L_12 = sp + 7|0;
 HEAP8[$0>>0] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2930976);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP8[$0>>0]|0;
      HEAP8[$L_6>>0] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2171616|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2171616|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP8[$V_2>>0]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP8[$L_12>>0] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2171616|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2171616|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2171616|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2171616|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2171616|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2171616|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP8[$L_8>>0] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2171616|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2171616|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_SByteP21mscorlib_System_ArrayP25mscorlib_System_SByte_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931032);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_SByteP21mscorlib_System_Arraya($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931080);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_SByteP21mscorlib_System_Arraya($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 7|0;
 $L_6 = sp + 4|0;
 $L_8 = sp + 5|0;
 $L_17 = sp + 6|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931128);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP8[$L_6>>0] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2171616|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2171616|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP8[$L_17>>0] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2171616|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2171616|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2171616|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2171616|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2171616|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2171616|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP8[$V_2>>0]|0;
        HEAP8[$L_8>>0] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2171616|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2171616|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_SByteP21mscorlib_System_Arrayia($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931184);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z69mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_SByteP21mscorlib_System_Arrayia($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP8[$0>>0] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931232);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP8[$L_3>>0] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2171616|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2171616|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_SByteP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931288);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1724,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2053144|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2053144|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Int16P21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931344);
 HEAP16[$V_0>>1] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP16[$V_0>>1]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Int16P21mscorlib_System_Arrays($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931392);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Int16P21mscorlib_System_Arrays($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 12|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 6|0;
 $L_8 = sp + 8|0;
 $L_12 = sp + 10|0;
 HEAP16[$0>>1] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931440);
 HEAP16[$V_2>>1] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP16[$0>>1]|0;
      HEAP16[$L_6>>1] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2173776|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2173776|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP16[$V_2>>1]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP16[$L_12>>1] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2173776|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2173776|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2173776|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2173776|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2173776|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2173776|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP16[$L_8>>1] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2173776|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2173776|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Int16P21mscorlib_System_ArrayP25mscorlib_System_Int16_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931496);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Int16P21mscorlib_System_Arrays($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931544);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Int16P21mscorlib_System_Arrays($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 10|0;
 $L_6 = sp + 4|0;
 $L_8 = sp + 6|0;
 $L_17 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931592);
 HEAP16[$V_2>>1] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP16[$L_6>>1] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2173776|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2173776|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP16[$L_17>>1] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2173776|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2173776|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2173776|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2173776|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2173776|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2173776|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP16[$V_2>>1]|0;
        HEAP16[$L_8>>1] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2173776|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2173776|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z67mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Int16P21mscorlib_System_Arrayis($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931648);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z69mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Int16P21mscorlib_System_Arrayis($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 6|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP16[$0>>1] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931696);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP16[$L_3>>1] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2173776|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2173776|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Int16P21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931752);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1725,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2056072|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2056072|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_UInt16P21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931808);
 HEAP16[$V_0>>1] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP16[$V_0>>1]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_UInt16P21mscorlib_System_Arrayt($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931856);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_UInt16P21mscorlib_System_Arrayt($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 12|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 6|0;
 $L_8 = sp + 8|0;
 $L_12 = sp + 10|0;
 HEAP16[$0>>1] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931904);
 HEAP16[$V_2>>1] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP16[$0>>1]|0;
      HEAP16[$L_6>>1] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2176024|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP16[$V_2>>1]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP16[$L_12>>1] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2176024|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2176024|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2176024|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP16[$L_8>>1] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2176024|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_UInt16P21mscorlib_System_ArrayP26mscorlib_System_UInt16_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2931960);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3849,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3849,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3849,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3849,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_UInt16P21mscorlib_System_Arrayt($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932008);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_UInt16P21mscorlib_System_Arrayt($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 10|0;
 $L_6 = sp + 4|0;
 $L_8 = sp + 6|0;
 $L_17 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932056);
 HEAP16[$V_2>>1] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP16[$L_6>>1] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2176024|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2176024|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP16[$L_17>>1] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2176024|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2176024|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2176024|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2176024|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2176024|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2176024|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP16[$V_2>>1]|0;
        HEAP16[$L_8>>1] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2176024|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2176024|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_UInt16P21mscorlib_System_Arrayit($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932112);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3849,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_UInt16P21mscorlib_System_Arrayit($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 6|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP16[$0>>1] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932160);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3849,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP16[$L_3>>1] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2176024|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2176024|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_UInt16P21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932216);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1726,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2058800|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2058800|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DoubleP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932272);
 HEAPF64[$V_0>>3] = 0.0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = +HEAPF64[$V_0>>3];
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return (+$26);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3849,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return +0;
}
function __Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DoubleP21mscorlib_System_Arrayd($__this,$item) {
 $__this = $__this|0;
 $item = +$item;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932320);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception15629($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DoubleP21mscorlib_System_Arrayd($__this,$item) {
 $__this = $__this|0;
 $item = +$item;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 32|0;
 $_stackTraceSentry = sp + 40|0;
 $V_2 = sp + 8|0;
 $L_6 = sp + 16|0;
 $L_8 = sp + 24|0;
 $L_12 = sp;
 HEAPF64[$0>>3] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932400);
 HEAPF64[$V_2>>3] = 0.0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = +HEAPF64[$0>>3];
      HEAPF64[$L_6>>3] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2198192|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2198192|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = +HEAPF64[$V_2>>3];
      if ($32) {
       label = 18;
       break;
      }
      HEAPF64[$L_12>>3] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2198192|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2198192|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2198192|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2198192|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2198192|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2198192|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAPF64[$L_8>>3] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2198192|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2198192|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DoubleP21mscorlib_System_ArrayP26mscorlib_System_Double_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932496);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DoubleP21mscorlib_System_Arrayd($__this,$item) {
 $__this = $__this|0;
 $item = +$item;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932584);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DoubleP21mscorlib_System_Arrayd($__this,$item) {
 $__this = $__this|0;
 $item = +$item;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932672);
 HEAPF64[$V_2>>3] = 0.0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAPF64[$L_6>>3] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2198192|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2198192|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAPF64[$L_17>>3] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2198192|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2198192|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2198192|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2198192|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2198192|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2198192|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = +HEAPF64[$V_2>>3];
        HEAPF64[$L_8>>3] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2198192|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2198192|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DoubleP21mscorlib_System_Arrayid($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = +$item;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932752);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DoubleP21mscorlib_System_Arrayid($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = +$item;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp + 16|0;
 $L_3 = sp;
 HEAPF64[$0>>3] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932824);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAPF64[$L_3>>3] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2198192|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2198192|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DoubleP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2932904);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1727,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2062688|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2062688|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_BooleanP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933008);
 HEAP8[$V_0>>0] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP8[$V_0>>0]|0;
    $27 = ($26<<24>>24)!=(0);
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($27|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_BooleanP21mscorlib_System_Arrayb($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933080);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z83mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_BooleanP21mscorlib_System_Arrayb($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 5|0;
 $L_8 = sp + 6|0;
 $L_12 = sp + 7|0;
 $1 = $item&1;
 HEAP8[$0>>0] = $1;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933128);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(1859,($__this|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)<(2);
    if (!($7)) {
     $12 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $13 = (invoke_iii(783,(0|0),($12|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     $18 = (invoke_ii(3469,(2636920|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($18|0),($13|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($18|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $25 = (invoke_ii(1857,($__this|0))|0);
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if (!($27)) {
     $28 = ($25|0)>(0);
     if (!($28)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $29 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $63 = HEAP32[$__this>>2]|0;
      $64 = (($63) + 28|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = (($65) + 92|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = Math_imul($67, $V_1$011)|0;
      $69 = (($29) + ($68)|0);
      _memcpy(($V_2|0),($69|0),($67|0))|0;
      $70 = HEAP8[$0>>0]|0;
      HEAP8[$L_6>>0] = $70;
      __THREW__ = 0;
      (invoke_ii(2996,(2208584|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $30 = (invoke_iii(2724,(2208584|0),($L_6|0))|0);
      $31 = __THREW__; __THREW__ = 0;
      $32 = $31&1;
      if ($32) {
       label = 4;
       break;
      }
      $33 = ($30|0)==(0|0);
      $34 = HEAP8[$V_2>>0]|0;
      if ($33) {
       label = 18;
       break;
      }
      HEAP8[$L_12>>0] = $34;
      __THREW__ = 0;
      (invoke_ii(2996,(2208584|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $43 = (invoke_iii(2724,(2208584|0),($L_12|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2208584|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(2208584|0),($0|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($48|0));
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2208584|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $55 = (invoke_iii(2724,(2208584|0),($0|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iiii(1644,(2148736|0),($55|0),($43|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      $61 = (($V_1$011) + 1)|0;
      if ($58) {
       $$0 = 1;
       label = 32;
       break;
      }
      $62 = ($61|0)<($25|0);
      if ($62) {
       $V_1$011 = $61;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $8 = ___cxa_find_matching_catch()|0;
      $9 = tempRet0;
      $lpad$phi$index = $8;$lpad$phi$index2 = $9;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP8[$L_8>>0] = $34;
      __THREW__ = 0;
      (invoke_ii(2996,(2208584|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      __THREW__ = 0;
      $37 = (invoke_iii(2724,(2208584|0),($L_8|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       break;
      }
      $40 = ($37|0)==(0|0);
      $$0 = $40;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 $lpad$phi$index = $10;$lpad$phi$index2 = $11;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_BooleanP21mscorlib_System_ArrayP27mscorlib_System_Boolean_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933184);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_BooleanP21mscorlib_System_Arrayb($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933232);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_BooleanP21mscorlib_System_Arrayb($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 7|0;
 $L_6 = sp + 4|0;
 $L_8 = sp + 5|0;
 $L_17 = sp + 6|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933280);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $28 = $item&1;
       $V_1$013 = 0;
       while(1) {
        $74 = HEAP32[$__this>>2]|0;
        $75 = (($74) + 28|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = (($76) + 92|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = Math_imul($78, $V_1$013)|0;
        $80 = (($27) + ($79)|0);
        _memcpy(($V_2|0),($80|0),($78|0))|0;
        HEAP8[$L_6>>0] = $28;
        __THREW__ = 0;
        (invoke_ii(2996,(2208584|0))|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $29 = (invoke_iii(2724,(2208584|0),($L_6|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 4;
         break;
        }
        $32 = ($29|0)==(0|0);
        if ($32) {
         label = 18;
         break;
        }
        HEAP8[$L_17>>0] = $28;
        __THREW__ = 0;
        (invoke_ii(2996,(2208584|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $50 = (invoke_iii(2724,(2208584|0),($L_17|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2208584|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $55 = (invoke_iii(2724,(2208584|0),($V_2|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2208584|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $62 = (invoke_iii(2724,(2208584|0),($V_2|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $65 = (invoke_iiii(1644,(2148736|0),($62|0),($50|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         label = 4;
         break;
        }
        $68 = (($V_1$013) + 1)|0;
        if ($65) {
         label = 34;
         break;
        }
        $73 = ($68|0)<($23|0);
        if ($73) {
         $V_1$013 = $68;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $33 = HEAP8[$V_2>>0]|0;
        HEAP8[$L_8>>0] = $33;
        __THREW__ = 0;
        (invoke_ii(2996,(2208584|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break L1;
        }
        __THREW__ = 0;
        $36 = (invoke_iii(2724,(2208584|0),($L_8|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break L1;
        }
        $39 = ($36|0)==(0|0);
        if ($39) {
         __THREW__ = 0;
         $40 = (invoke_iii(755,($__this|0),0)|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break L1;
         }
         $43 = (($40) + ($V_1$013))|0;
         $$0 = $43;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $44 = (invoke_iii(755,($__this|0),0)|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          break L1;
         }
         $47 = (($44) + -1)|0;
         $$0 = $47;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $69 = (invoke_iii(755,($__this|0),0)|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break L1;
        }
        $72 = (($69) + ($V_1$013))|0;
        $$0 = $72;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $83 = (invoke_iii(755,($__this|0),0)|0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if (!($85)) {
      $86 = (($83) + -1)|0;
      $$0 = $86;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_BooleanP21mscorlib_System_Arrayib($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933336);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z71mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_BooleanP21mscorlib_System_Arrayib($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 $1 = $item&1;
 HEAP8[$0>>0] = $1;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933384);
 __THREW__ = 0;
 invoke_v(1001);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(1857,($__this|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = ($4|0)>($index|0);
    if (!($7)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if ($11) {
      break;
     }
     __THREW__ = 0;
     $12 = (invoke_ii(3469,(2561352|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     $15 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($12|0),($15|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($12|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if (!($21)) {
     __THREW__ = 0;
     $22 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $25 = ($22|0)==(0|0);
      if ($25) {
       $50 = (($__this) + 16|0);
       $51 = HEAP32[$__this>>2]|0;
       $52 = (($51) + 28|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = (($53) + 92|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = Math_imul($55, $index)|0;
       $57 = (($50) + ($56)|0);
       _memcpy(($57|0),($0|0),($55|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP8[$L_3>>0] = $1;
      __THREW__ = 0;
      (invoke_ii(2996,(2208584|0))|0);
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       __THREW__ = 0;
       $28 = (invoke_iii(2724,(2208584|0),($L_3|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if (!($30)) {
        __THREW__ = 0;
        invoke_vi(3799,($22|0));
        $31 = __THREW__; __THREW__ = 0;
        $32 = $31&1;
        if (!($32)) {
         $33 = ($index|0)<(0);
         if ($33) {
          label = 18;
         } else {
          $34 = (($22) + 12|0);
          $35 = HEAP32[$34>>2]|0;
          $36 = ($35>>>0)>($index>>>0);
          if (!($36)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $37 = (invoke_i(132)|0);
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($37|0));
          $40 = __THREW__; __THREW__ = 0;
          $41 = $40&1;
          if ($41) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($22|0),($28|0));
         $42 = __THREW__; __THREW__ = 0;
         $43 = $42&1;
         if (!($43)) {
          $44 = HEAP32[$22>>2]|0;
          $45 = (($22) + 16|0);
          $46 = (($44) + 92|0);
          $47 = HEAP32[$46>>2]|0;
          $48 = Math_imul($47, $index)|0;
          $49 = (($45) + ($48)|0);
          HEAP32[$49>>2] = $28;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($8|0);
 // unreachable;
}
function __Z88mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_BooleanP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933440);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1728,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2065880|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2065880|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_UIntPtrP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $$sroa$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$sroa$0 = sp + 4|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933496);
 HEAP32[$$sroa$0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($$sroa$0|0),($25|0),($23|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    $26 = HEAP32[$$sroa$0>>2]|0;
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_UIntPtrP21mscorlib_System_Array23mscorlib_System_UIntPtr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933544);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z83mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_UIntPtrP21mscorlib_System_Array23mscorlib_System_UIntPtr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2$sroa$0 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2$sroa$0 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_12 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933592);
 HEAP32[$V_2$sroa$0>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if (!($26)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $61 = HEAP32[$__this>>2]|0;
      $62 = (($61) + 28|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = (($63) + 92|0);
      $65 = HEAP32[$64>>2]|0;
      $66 = Math_imul($65, $V_1$011)|0;
      $67 = (($27) + ($66)|0);
      _memcpy(($V_2$sroa$0|0),($67|0),($65|0))|0;
      $68 = HEAP32[$item>>2]|0;
      HEAP32[$L_6>>2] = $68;
      __THREW__ = 0;
      (invoke_ii(2996,(2212032|0))|0);
      $69 = __THREW__; __THREW__ = 0;
      $70 = $69&1;
      if ($70) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iii(2724,(2212032|0),($L_6|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = ($28|0)==(0|0);
      $32 = HEAP32[$V_2$sroa$0>>2]|0;
      if ($31) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $32;
      __THREW__ = 0;
      (invoke_ii(2996,(2212032|0))|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if ($40) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $41 = (invoke_iii(2724,(2212032|0),($L_12|0))|0);
      $42 = __THREW__; __THREW__ = 0;
      $43 = $42&1;
      if ($43) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2212032|0))|0);
      $44 = __THREW__; __THREW__ = 0;
      $45 = $44&1;
      if ($45) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $46 = (invoke_iii(2724,(2212032|0),($item|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($46|0));
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2212032|0))|0);
      $51 = __THREW__; __THREW__ = 0;
      $52 = $51&1;
      if ($52) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $53 = (invoke_iii(2724,(2212032|0),($item|0))|0);
      $54 = __THREW__; __THREW__ = 0;
      $55 = $54&1;
      if ($55) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $56 = (invoke_iiii(1644,(2148736|0),($53|0),($41|0))|0);
      $57 = __THREW__; __THREW__ = 0;
      $58 = $57&1;
      if ($58) {
       label = 4;
       break;
      }
      $59 = (($V_1$011) + 1)|0;
      if ($56) {
       $$0 = 1;
       label = 32;
       break;
      }
      $60 = ($59|0)<($23|0);
      if ($60) {
       $V_1$011 = $59;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $32;
      __THREW__ = 0;
      (invoke_ii(2996,(2212032|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       break;
      }
      __THREW__ = 0;
      $35 = (invoke_iii(2724,(2212032|0),($L_8|0))|0);
      $36 = __THREW__; __THREW__ = 0;
      $37 = $36&1;
      if ($37) {
       break;
      }
      $38 = ($35|0)==(0|0);
      $$0 = $38;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_UIntPtrP21mscorlib_System_ArrayP27mscorlib_System_UIntPtr_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933648);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_UIntPtrP21mscorlib_System_Array23mscorlib_System_UIntPtr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933696);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_UIntPtrP21mscorlib_System_Array23mscorlib_System_UIntPtr($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933744);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $28 = HEAP32[$item>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $74 = HEAP32[$__this>>2]|0;
        $75 = (($74) + 28|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = (($76) + 92|0);
        $78 = HEAP32[$77>>2]|0;
        $79 = Math_imul($78, $V_1$013)|0;
        $80 = (($27) + ($79)|0);
        _memcpy(($V_2|0),($80|0),($78|0))|0;
        HEAP32[$L_6>>2] = $28;
        __THREW__ = 0;
        (invoke_ii(2996,(2212032|0))|0);
        $81 = __THREW__; __THREW__ = 0;
        $82 = $81&1;
        if ($82) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $29 = (invoke_iii(2724,(2212032|0),($L_6|0))|0);
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if ($31) {
         label = 4;
         break;
        }
        $32 = ($29|0)==(0|0);
        if ($32) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $28;
        __THREW__ = 0;
        (invoke_ii(2996,(2212032|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $50 = (invoke_iii(2724,(2212032|0),($L_17|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2212032|0))|0);
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if ($54) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $55 = (invoke_iii(2724,(2212032|0),($V_2|0))|0);
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($55|0));
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2212032|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $62 = (invoke_iii(2724,(2212032|0),($V_2|0))|0);
        $63 = __THREW__; __THREW__ = 0;
        $64 = $63&1;
        if ($64) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $65 = (invoke_iiii(1644,(2148736|0),($62|0),($50|0))|0);
        $66 = __THREW__; __THREW__ = 0;
        $67 = $66&1;
        if ($67) {
         label = 4;
         break;
        }
        $68 = (($V_1$013) + 1)|0;
        if ($65) {
         label = 34;
         break;
        }
        $73 = ($68|0)<($23|0);
        if ($73) {
         $V_1$013 = $68;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $33 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $33;
        __THREW__ = 0;
        (invoke_ii(2996,(2212032|0))|0);
        $34 = __THREW__; __THREW__ = 0;
        $35 = $34&1;
        if ($35) {
         break L1;
        }
        __THREW__ = 0;
        $36 = (invoke_iii(2724,(2212032|0),($L_8|0))|0);
        $37 = __THREW__; __THREW__ = 0;
        $38 = $37&1;
        if ($38) {
         break L1;
        }
        $39 = ($36|0)==(0|0);
        if ($39) {
         __THREW__ = 0;
         $40 = (invoke_iii(755,($__this|0),0)|0);
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if ($42) {
          break L1;
         }
         $43 = (($40) + ($V_1$013))|0;
         $$0 = $43;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $44 = (invoke_iii(755,($__this|0),0)|0);
         $45 = __THREW__; __THREW__ = 0;
         $46 = $45&1;
         if ($46) {
          break L1;
         }
         $47 = (($44) + -1)|0;
         $$0 = $47;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $69 = (invoke_iii(755,($__this|0),0)|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         break L1;
        }
        $72 = (($69) + ($V_1$013))|0;
        $$0 = $72;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $83 = (invoke_iii(755,($__this|0),0)|0);
     $84 = __THREW__; __THREW__ = 0;
     $85 = $84&1;
     if (!($85)) {
      $86 = (($83) + -1)|0;
      $$0 = $86;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z69mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_UIntPtrP21mscorlib_System_Arrayi23mscorlib_System_UIntPtr($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933800);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z71mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_UIntPtrP21mscorlib_System_Arrayi23mscorlib_System_UIntPtr($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933848);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($item|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = HEAP32[$item>>2]|0;
      HEAP32[$L_3>>2] = $24;
      __THREW__ = 0;
      (invoke_ii(2996,(2212032|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2212032|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($20) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$20>>2]|0;
          $44 = (($20) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z88mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_UIntPtrP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2933904);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1729,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2068608|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2068608|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL72mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DelegateP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DelegateP21mscorlib_System_ArrayP24mscorlib_System_Delegate($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DelegateP21mscorlib_System_ArrayP24mscorlib_System_Delegate($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2934064 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DelegateP21mscorlib_System_ArrayP28mscorlib_System_Delegate_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DelegateP21mscorlib_System_ArrayP24mscorlib_System_Delegate($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL71mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DelegateP21mscorlib_System_ArrayP24mscorlib_System_Delegate($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2934216 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL70mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DelegateP21mscorlib_System_ArrayiP24mscorlib_System_Delegate($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL72mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DelegateP21mscorlib_System_ArrayiP24mscorlib_System_Delegate($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2934320 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DelegateP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2934376 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z93mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt32_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP26mscorlib_System_UInt32_arrj($__this,$_____array,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2934424);
 __THREW__ = 0;
 invoke_v(1005);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($_____array) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iiiiiii(98,0,($_____array|0),0,($18|0),($value|0),(0|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016232>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3850,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z187mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt32_mscorlib_System_Int32_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_T_mscorlib_System_Collections_Generic_IComparer_1_TP22mscorlib_System_ObjectP26mscorlib_System_UInt32_arriijS0_($__this,$_____array,$index,$length,$value,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 $value = $value|0;
 $comparer = $comparer|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $V_0$0$lcssa = 0, $V_0$0$ph23 = 0, $V_0$017 = 0, $V_1$0$ph22 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2934496);
 __THREW__ = 0;
 invoke_v(1006);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3016248>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)>(-1);
   if (!($15)) {
    $16 = HEAP32[3016264>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iii(783,(0|0),($16|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2561352|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3016256>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($22|0),($25|0),($17|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($length|0)>(-1);
   if (!($30)) {
    $31 = HEAP32[3016280>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii(783,(0|0),($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3469,(2561352|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    $40 = HEAP32[3016272>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($37|0),($40|0),($32|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($37|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    $47 = (($_____array) + 12|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) - ($length))|0;
    $50 = ($49|0)<($index|0);
    if ($50) {
     $51 = HEAP32[3016288>>2]|0;
     __THREW__ = 0;
     $52 = (invoke_iii(783,(0|0),($51|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     $57 = (invoke_ii(3469,(2560072|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($57|0),($52|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($57|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     // unreachable;
    }
    $64 = ($comparer|0)==(0|0);
    if ($64) {
     __THREW__ = 0;
     $65 = (invoke_ii(1698,(0|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     $$01 = $65;
    } else {
     $$01 = $comparer;
    }
    $68 = (($index) + -1)|0;
    $69 = (($68) + ($length))|0;
    $70 = ($69|0)<($index|0);
    L39: do {
     if ($70) {
      $V_0$0$lcssa = $index;
     } else {
      $71 = (($_____array) + 16|0);
      $V_0$0$ph23 = $index;$V_1$0$ph22 = $69;
      L41: while(1) {
       $V_0$017 = $V_0$0$ph23;
       while(1) {
        $110 = (($V_1$0$ph22) - ($V_0$017))|0;
        $111 = (($110|0) / 2)&-1;
        $73 = (($111) + ($V_0$017))|0;
        __THREW__ = 0;
        invoke_vi(3799,($_____array|0));
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         break L41;
        }
        $72 = ($73|0)<(0);
        if ($72) {
         label = 39;
        } else {
         $74 = HEAP32[$47>>2]|0;
         $75 = ($73>>>0)<($74>>>0);
         if (!($75)) {
          label = 39;
         }
        }
        if ((label|0) == 39) {
         label = 0;
         __THREW__ = 0;
         $76 = (invoke_i(132)|0);
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break L41;
         }
         __THREW__ = 0;
         invoke_vi(3302,($76|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break L41;
         }
        }
        $93 = HEAP32[$_____array>>2]|0;
        $94 = (($93) + 92|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = Math_imul($95, $73)|0;
        $97 = (($71) + ($96)|0);
        $98 = HEAP32[$97>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($$01|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         break L41;
        }
        __THREW__ = 0;
        $101 = (invoke_iiiii(332,(2072448|0),($$01|0),($value|0),($98|0))|0);
        $102 = __THREW__; __THREW__ = 0;
        $103 = $102&1;
        if ($103) {
         break L41;
        }
        $104 = ($101|0)==(0);
        if ($104) {
         $$0 = $73;
         label = 61;
         break L41;
        }
        $105 = ($101|0)>(-1);
        $106 = (($73) + 1)|0;
        if (!($105)) {
         break;
        }
        $109 = ($73|0)<($V_1$0$ph22|0);
        if ($109) {
         $V_0$017 = $106;
        } else {
         $V_0$0$lcssa = $106;
         break L39;
        }
       }
       $107 = (($73) + -1)|0;
       $108 = ($V_0$017|0)>($107|0);
       if ($108) {
        $V_0$0$lcssa = $V_0$017;
        break L39;
       } else {
        $V_0$0$ph23 = $V_0$017;$V_1$0$ph22 = $107;
       }
      }
      if ((label|0) == 61) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $81 = ___cxa_find_matching_catch(348288|0)|0;
      $82 = tempRet0;
      $83 = (_llvm_eh_typeid_for((348288|0))|0);
      $84 = ($82|0)==($83|0);
      if (!($84)) {
       $$02 = $81;$$03 = $82;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $85 = (___cxa_begin_catch(($81|0))|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = HEAP32[$86>>2]|0;
      __THREW__ = 0;
      $88 = (invoke_iii(2727,(2246120|0),($87|0))|0);
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      do {
       if (!($90)) {
        if (!($88)) {
         $118 = (___cxa_allocate_exception(4)|0);
         $119 = HEAP32[$85>>2]|0;
         HEAP32[$118>>2] = $119;
         __THREW__ = 0;
         invoke_viii(1567,($118|0),(348288|0),(0|0));
         $120 = __THREW__; __THREW__ = 0;
         $121 = $120&1;
         if ($121) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        invoke_v(66);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         break L1;
        }
        $122 = HEAP32[3016296>>2]|0;
        __THREW__ = 0;
        $123 = (invoke_iii(783,(0|0),($122|0))|0);
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2607872|0))|0);
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if ($127) {
         break L1;
        }
        __THREW__ = 0;
        $128 = (invoke_ii(3469,(2607872|0))|0);
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         break L1;
        }
        __THREW__ = 0;
        invoke_viii(678,($128|0),($123|0),($86|0));
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if ($132) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3850,($128|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         break L1;
        }
        // unreachable;
       }
      } while(0);
      $114 = ___cxa_find_matching_catch()|0;
      $115 = tempRet0;
      __THREW__ = 0;
      invoke_v(66);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       $136 = ___cxa_find_matching_catch(0|0)|0;
       $137 = tempRet0;
       ___clang_call_terminate($136);
       // unreachable;
      } else {
       $$02 = $114;$$03 = $115;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
     }
    } while(0);
    $135 = $V_0$0$lcssa ^ -1;
    $$0 = $135;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$02 = $3;$$03 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsS1_E6InvokeEP10MethodInfoPvjj($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z93mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt16_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP26mscorlib_System_UInt16_arrt($__this,$_____array,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2934552);
 __THREW__ = 0;
 invoke_v(1005);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($_____array) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iiiiiii(99,0,($_____array|0),0,($18|0),($value|0),(0|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016232>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3850,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z187mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt16_mscorlib_System_Int32_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_T_mscorlib_System_Collections_Generic_IComparer_1_TP22mscorlib_System_ObjectP26mscorlib_System_UInt16_arriitS0_($__this,$_____array,$index,$length,$value,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 $value = $value|0;
 $comparer = $comparer|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $V_0$0$lcssa = 0, $V_0$0$ph23 = 0, $V_0$017 = 0, $V_1$0$ph22 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2934608);
 __THREW__ = 0;
 invoke_v(1006);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3016248>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)>(-1);
   if (!($15)) {
    $16 = HEAP32[3016264>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iii(783,(0|0),($16|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2561352|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3016256>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($22|0),($25|0),($17|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($length|0)>(-1);
   if (!($30)) {
    $31 = HEAP32[3016280>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii(783,(0|0),($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3469,(2561352|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    $40 = HEAP32[3016272>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($37|0),($40|0),($32|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($37|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    $47 = (($_____array) + 12|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) - ($length))|0;
    $50 = ($49|0)<($index|0);
    if ($50) {
     $51 = HEAP32[3016288>>2]|0;
     __THREW__ = 0;
     $52 = (invoke_iii(783,(0|0),($51|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     $57 = (invoke_ii(3469,(2560072|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($57|0),($52|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($57|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     // unreachable;
    }
    $64 = ($comparer|0)==(0|0);
    if ($64) {
     __THREW__ = 0;
     $65 = (invoke_ii(1699,(0|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     $$01 = $65;
    } else {
     $$01 = $comparer;
    }
    $68 = (($index) + -1)|0;
    $69 = (($68) + ($length))|0;
    $70 = ($69|0)<($index|0);
    L39: do {
     if ($70) {
      $V_0$0$lcssa = $index;
     } else {
      $71 = (($_____array) + 16|0);
      $V_0$0$ph23 = $index;$V_1$0$ph22 = $69;
      L41: while(1) {
       $V_0$017 = $V_0$0$ph23;
       while(1) {
        $110 = (($V_1$0$ph22) - ($V_0$017))|0;
        $111 = (($110|0) / 2)&-1;
        $73 = (($111) + ($V_0$017))|0;
        __THREW__ = 0;
        invoke_vi(3799,($_____array|0));
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         break L41;
        }
        $72 = ($73|0)<(0);
        if ($72) {
         label = 39;
        } else {
         $74 = HEAP32[$47>>2]|0;
         $75 = ($73>>>0)<($74>>>0);
         if (!($75)) {
          label = 39;
         }
        }
        if ((label|0) == 39) {
         label = 0;
         __THREW__ = 0;
         $76 = (invoke_i(132)|0);
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break L41;
         }
         __THREW__ = 0;
         invoke_vi(3302,($76|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break L41;
         }
        }
        $93 = HEAP32[$_____array>>2]|0;
        $94 = (($93) + 92|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = Math_imul($95, $73)|0;
        $97 = (($71) + ($96)|0);
        $98 = HEAP16[$97>>1]|0;
        __THREW__ = 0;
        invoke_vi(3799,($$01|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         break L41;
        }
        __THREW__ = 0;
        $101 = (invoke_iiiii(333,(2073848|0),($$01|0),($value|0),($98|0))|0);
        $102 = __THREW__; __THREW__ = 0;
        $103 = $102&1;
        if ($103) {
         break L41;
        }
        $104 = ($101|0)==(0);
        if ($104) {
         $$0 = $73;
         label = 61;
         break L41;
        }
        $105 = ($101|0)>(-1);
        $106 = (($73) + 1)|0;
        if (!($105)) {
         break;
        }
        $109 = ($73|0)<($V_1$0$ph22|0);
        if ($109) {
         $V_0$017 = $106;
        } else {
         $V_0$0$lcssa = $106;
         break L39;
        }
       }
       $107 = (($73) + -1)|0;
       $108 = ($V_0$017|0)>($107|0);
       if ($108) {
        $V_0$0$lcssa = $V_0$017;
        break L39;
       } else {
        $V_0$0$ph23 = $V_0$017;$V_1$0$ph22 = $107;
       }
      }
      if ((label|0) == 61) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $81 = ___cxa_find_matching_catch(348288|0)|0;
      $82 = tempRet0;
      $83 = (_llvm_eh_typeid_for((348288|0))|0);
      $84 = ($82|0)==($83|0);
      if (!($84)) {
       $$02 = $81;$$03 = $82;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $85 = (___cxa_begin_catch(($81|0))|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = HEAP32[$86>>2]|0;
      __THREW__ = 0;
      $88 = (invoke_iii(2727,(2246120|0),($87|0))|0);
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      do {
       if (!($90)) {
        if (!($88)) {
         $118 = (___cxa_allocate_exception(4)|0);
         $119 = HEAP32[$85>>2]|0;
         HEAP32[$118>>2] = $119;
         __THREW__ = 0;
         invoke_viii(1567,($118|0),(348288|0),(0|0));
         $120 = __THREW__; __THREW__ = 0;
         $121 = $120&1;
         if ($121) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        invoke_v(66);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         break L1;
        }
        $122 = HEAP32[3016296>>2]|0;
        __THREW__ = 0;
        $123 = (invoke_iii(783,(0|0),($122|0))|0);
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2607872|0))|0);
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if ($127) {
         break L1;
        }
        __THREW__ = 0;
        $128 = (invoke_ii(3469,(2607872|0))|0);
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         break L1;
        }
        __THREW__ = 0;
        invoke_viii(678,($128|0),($123|0),($86|0));
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if ($132) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3850,($128|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         break L1;
        }
        // unreachable;
       }
      } while(0);
      $114 = ___cxa_find_matching_catch()|0;
      $115 = tempRet0;
      __THREW__ = 0;
      invoke_v(66);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       $136 = ___cxa_find_matching_catch(0|0)|0;
       $137 = tempRet0;
       ___clang_call_terminate($136);
       // unreachable;
      } else {
       $$02 = $114;$$03 = $115;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
     }
    } while(0);
    $135 = $V_0$0$lcssa ^ -1;
    $$0 = $135;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$02 = $3;$$03 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsS1_E6InvokeEP10MethodInfoPvtt($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z91mscorlib_System_Array_m_BinarySearch_mscorlib_System_Byte_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP24mscorlib_System_Byte_arrh($__this,$_____array,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2934664);
 __THREW__ = 0;
 invoke_v(1005);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($_____array) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iiiiiii(100,0,($_____array|0),0,($18|0),($value|0),(0|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($19|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016232>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3850,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __Z185mscorlib_System_Array_m_BinarySearch_mscorlib_System_Byte_mscorlib_System_Int32_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_T_mscorlib_System_Collections_Generic_IComparer_1_TP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriihS0_($__this,$_____array,$index,$length,$value,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 $value = $value|0;
 $comparer = $comparer|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $V_0$0$lcssa = 0, $V_0$0$ph23 = 0, $V_0$017 = 0, $V_1$0$ph22 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2934720);
 __THREW__ = 0;
 invoke_v(1006);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3016248>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   $15 = ($index|0)>(-1);
   if (!($15)) {
    $16 = HEAP32[3016264>>2]|0;
    __THREW__ = 0;
    $17 = (invoke_iii(783,(0|0),($16|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    $22 = (invoke_ii(3469,(2561352|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    $25 = HEAP32[3016256>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($22|0),($25|0),($17|0));
    $26 = __THREW__; __THREW__ = 0;
    $27 = $26&1;
    if ($27) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($22|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    // unreachable;
   }
   $30 = ($length|0)>(-1);
   if (!($30)) {
    $31 = HEAP32[3016280>>2]|0;
    __THREW__ = 0;
    $32 = (invoke_iii(783,(0|0),($31|0))|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if ($34) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    $37 = (invoke_ii(3469,(2561352|0))|0);
    $38 = __THREW__; __THREW__ = 0;
    $39 = $38&1;
    if ($39) {
     break;
    }
    $40 = HEAP32[3016272>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($37|0),($40|0),($32|0));
    $41 = __THREW__; __THREW__ = 0;
    $42 = $41&1;
    if ($42) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($37|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $45 = __THREW__; __THREW__ = 0;
   $46 = $45&1;
   if (!($46)) {
    $47 = (($_____array) + 12|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = (($48) - ($length))|0;
    $50 = ($49|0)<($index|0);
    if ($50) {
     $51 = HEAP32[3016288>>2]|0;
     __THREW__ = 0;
     $52 = (invoke_iii(783,(0|0),($51|0))|0);
     $53 = __THREW__; __THREW__ = 0;
     $54 = $53&1;
     if ($54) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     $57 = (invoke_ii(3469,(2560072|0))|0);
     $58 = __THREW__; __THREW__ = 0;
     $59 = $58&1;
     if ($59) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($57|0),($52|0));
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($57|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     // unreachable;
    }
    $64 = ($comparer|0)==(0|0);
    if ($64) {
     __THREW__ = 0;
     $65 = (invoke_ii(1700,(0|0))|0);
     $66 = __THREW__; __THREW__ = 0;
     $67 = $66&1;
     if ($67) {
      break;
     }
     $$01 = $65;
    } else {
     $$01 = $comparer;
    }
    $68 = (($index) + -1)|0;
    $69 = (($68) + ($length))|0;
    $70 = ($69|0)<($index|0);
    L39: do {
     if ($70) {
      $V_0$0$lcssa = $index;
     } else {
      $71 = (($_____array) + 16|0);
      $V_0$0$ph23 = $index;$V_1$0$ph22 = $69;
      L41: while(1) {
       $V_0$017 = $V_0$0$ph23;
       while(1) {
        $110 = (($V_1$0$ph22) - ($V_0$017))|0;
        $111 = (($110|0) / 2)&-1;
        $73 = (($111) + ($V_0$017))|0;
        __THREW__ = 0;
        invoke_vi(3799,($_____array|0));
        $112 = __THREW__; __THREW__ = 0;
        $113 = $112&1;
        if ($113) {
         break L41;
        }
        $72 = ($73|0)<(0);
        if ($72) {
         label = 39;
        } else {
         $74 = HEAP32[$47>>2]|0;
         $75 = ($73>>>0)<($74>>>0);
         if (!($75)) {
          label = 39;
         }
        }
        if ((label|0) == 39) {
         label = 0;
         __THREW__ = 0;
         $76 = (invoke_i(132)|0);
         $77 = __THREW__; __THREW__ = 0;
         $78 = $77&1;
         if ($78) {
          break L41;
         }
         __THREW__ = 0;
         invoke_vi(3302,($76|0));
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break L41;
         }
        }
        $93 = HEAP32[$_____array>>2]|0;
        $94 = (($93) + 92|0);
        $95 = HEAP32[$94>>2]|0;
        $96 = Math_imul($95, $73)|0;
        $97 = (($71) + ($96)|0);
        $98 = HEAP8[$97>>0]|0;
        __THREW__ = 0;
        invoke_vi(3799,($$01|0));
        $99 = __THREW__; __THREW__ = 0;
        $100 = $99&1;
        if ($100) {
         break L41;
        }
        __THREW__ = 0;
        $101 = (invoke_iiiii(334,(2075120|0),($$01|0),($value|0),($98|0))|0);
        $102 = __THREW__; __THREW__ = 0;
        $103 = $102&1;
        if ($103) {
         break L41;
        }
        $104 = ($101|0)==(0);
        if ($104) {
         $$0 = $73;
         label = 61;
         break L41;
        }
        $105 = ($101|0)>(-1);
        $106 = (($73) + 1)|0;
        if (!($105)) {
         break;
        }
        $109 = ($73|0)<($V_1$0$ph22|0);
        if ($109) {
         $V_0$017 = $106;
        } else {
         $V_0$0$lcssa = $106;
         break L39;
        }
       }
       $107 = (($73) + -1)|0;
       $108 = ($V_0$017|0)>($107|0);
       if ($108) {
        $V_0$0$lcssa = $V_0$017;
        break L39;
       } else {
        $V_0$0$ph23 = $V_0$017;$V_1$0$ph22 = $107;
       }
      }
      if ((label|0) == 61) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $81 = ___cxa_find_matching_catch(348288|0)|0;
      $82 = tempRet0;
      $83 = (_llvm_eh_typeid_for((348288|0))|0);
      $84 = ($82|0)==($83|0);
      if (!($84)) {
       $$02 = $81;$$03 = $82;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $85 = (___cxa_begin_catch(($81|0))|0);
      $86 = HEAP32[$85>>2]|0;
      $87 = HEAP32[$86>>2]|0;
      __THREW__ = 0;
      $88 = (invoke_iii(2727,(2246120|0),($87|0))|0);
      $89 = __THREW__; __THREW__ = 0;
      $90 = $89&1;
      do {
       if (!($90)) {
        if (!($88)) {
         $118 = (___cxa_allocate_exception(4)|0);
         $119 = HEAP32[$85>>2]|0;
         HEAP32[$118>>2] = $119;
         __THREW__ = 0;
         invoke_viii(1567,($118|0),(348288|0),(0|0));
         $120 = __THREW__; __THREW__ = 0;
         $121 = $120&1;
         if ($121) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        invoke_v(66);
        $91 = __THREW__; __THREW__ = 0;
        $92 = $91&1;
        if ($92) {
         break L1;
        }
        $122 = HEAP32[3016296>>2]|0;
        __THREW__ = 0;
        $123 = (invoke_iii(783,(0|0),($122|0))|0);
        $124 = __THREW__; __THREW__ = 0;
        $125 = $124&1;
        if ($125) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2607872|0))|0);
        $126 = __THREW__; __THREW__ = 0;
        $127 = $126&1;
        if ($127) {
         break L1;
        }
        __THREW__ = 0;
        $128 = (invoke_ii(3469,(2607872|0))|0);
        $129 = __THREW__; __THREW__ = 0;
        $130 = $129&1;
        if ($130) {
         break L1;
        }
        __THREW__ = 0;
        invoke_viii(678,($128|0),($123|0),($86|0));
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if ($132) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3850,($128|0));
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         break L1;
        }
        // unreachable;
       }
      } while(0);
      $114 = ___cxa_find_matching_catch()|0;
      $115 = tempRet0;
      __THREW__ = 0;
      invoke_v(66);
      $116 = __THREW__; __THREW__ = 0;
      $117 = $116&1;
      if ($117) {
       $136 = ___cxa_find_matching_catch(0|0)|0;
       $137 = tempRet0;
       ___clang_call_terminate($136);
       // unreachable;
      } else {
       $$02 = $114;$$03 = $115;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
     }
    } while(0);
    $135 = $V_0$0$lcssa ^ -1;
    $$0 = $135;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 $$02 = $3;$$03 = $4;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsS1_E6InvokeEP10MethodInfoPvhh($method,$obj,$p1,$p2) {
 $method = $method|0;
 $obj = $obj|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $0 = (($data) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$data>>2]|0;
 $5 = (FUNCTION_TABLE_iiii[$3 & 2047]($4,$p1,$p2)|0);
 STACKTOP = sp;return ($5|0);
}
function __Z93mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt64_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP26mscorlib_System_UInt64_arry($__this,$_____array,$0,$1) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2934776);
 __THREW__ = 0;
 invoke_v(1005);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = ($_____array|0)==(0|0);
   if (!($4)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     break;
    }
    $19 = (($_____array) + 12|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    $21 = (invoke_iiiiiiii(97,0,($_____array|0),0,($20|0),($0|0),($1|0),(0|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($21|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if (!($11)) {
     $12 = HEAP32[3016232>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($9|0),($12|0));
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if (!($14)) {
      __THREW__ = 0;
      invoke_vi(3850,($9|0));
      $15 = __THREW__; __THREW__ = 0;
      $16 = $15&1;
      if (!($16)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($5|0);
 // unreachable;
 return 0|0;
}
function __Z187mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt64_mscorlib_System_Int32_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_T_mscorlib_System_Collections_Generic_IComparer_1_TP22mscorlib_System_ObjectP26mscorlib_System_UInt64_arriiyS0_($__this,$_____array,$index,$length,$0,$1,$comparer) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 $length = $length|0;
 $0 = $0|0;
 $1 = $1|0;
 $comparer = $comparer|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$03 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $V_0$0$lcssa = 0, $V_0$0$ph23 = 0, $V_0$017 = 0, $V_1$0$ph22 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2934832);
 __THREW__ = 0;
 invoke_v(1006);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 L1: do {
  if (!($3)) {
   $4 = ($_____array|0)==(0|0);
   if ($4) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     break;
    }
    __THREW__ = 0;
    $9 = (invoke_ii(3469,(2560584|0))|0);
    $10 = __THREW__; __THREW__ = 0;
    $11 = $10&1;
    if ($11) {
     break;
    }
    $12 = HEAP32[3016248>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($9|0),($12|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($9|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    // unreachable;
   }
   $17 = ($index|0)>(-1);
   if (!($17)) {
    $18 = HEAP32[3016264>>2]|0;
    __THREW__ = 0;
    $19 = (invoke_iii(783,(0|0),($18|0))|0);
    $20 = __THREW__; __THREW__ = 0;
    $21 = $20&1;
    if ($21) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(3469,(2561352|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if ($26) {
     break;
    }
    $27 = HEAP32[3016256>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($24|0),($27|0),($19|0));
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($24|0));
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     break;
    }
    // unreachable;
   }
   $32 = ($length|0)>(-1);
   if (!($32)) {
    $33 = HEAP32[3016280>>2]|0;
    __THREW__ = 0;
    $34 = (invoke_iii(783,(0|0),($33|0))|0);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if ($36) {
     break;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(2561352|0))|0);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if ($38) {
     break;
    }
    __THREW__ = 0;
    $39 = (invoke_ii(3469,(2561352|0))|0);
    $40 = __THREW__; __THREW__ = 0;
    $41 = $40&1;
    if ($41) {
     break;
    }
    $42 = HEAP32[3016272>>2]|0;
    __THREW__ = 0;
    invoke_viii(644,($39|0),($42|0),($34|0));
    $43 = __THREW__; __THREW__ = 0;
    $44 = $43&1;
    if ($44) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($39|0));
    $45 = __THREW__; __THREW__ = 0;
    $46 = $45&1;
    if ($46) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   invoke_vi(3799,($_____array|0));
   $47 = __THREW__; __THREW__ = 0;
   $48 = $47&1;
   if (!($48)) {
    $49 = (($_____array) + 12|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) - ($length))|0;
    $52 = ($51|0)<($index|0);
    if ($52) {
     $53 = HEAP32[3016288>>2]|0;
     __THREW__ = 0;
     $54 = (invoke_iii(783,(0|0),($53|0))|0);
     $55 = __THREW__; __THREW__ = 0;
     $56 = $55&1;
     if ($56) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2560072|0))|0);
     $57 = __THREW__; __THREW__ = 0;
     $58 = $57&1;
     if ($58) {
      break;
     }
     __THREW__ = 0;
     $59 = (invoke_ii(3469,(2560072|0))|0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1924,($59|0),($54|0));
     $62 = __THREW__; __THREW__ = 0;
     $63 = $62&1;
     if ($63) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($59|0));
     $64 = __THREW__; __THREW__ = 0;
     $65 = $64&1;
     if ($65) {
      break;
     }
     // unreachable;
    }
    $66 = ($comparer|0)==(0|0);
    if ($66) {
     __THREW__ = 0;
     $67 = (invoke_ii(1701,(0|0))|0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      break;
     }
     $$01 = $67;
    } else {
     $$01 = $comparer;
    }
    $70 = (($index) + -1)|0;
    $71 = (($70) + ($length))|0;
    $72 = ($71|0)<($index|0);
    L39: do {
     if ($72) {
      $V_0$0$lcssa = $index;
     } else {
      $73 = (($_____array) + 16|0);
      $V_0$0$ph23 = $index;$V_1$0$ph22 = $71;
      L41: while(1) {
       $V_0$017 = $V_0$0$ph23;
       while(1) {
        $117 = (($V_1$0$ph22) - ($V_0$017))|0;
        $118 = (($117|0) / 2)&-1;
        $75 = (($118) + ($V_0$017))|0;
        __THREW__ = 0;
        invoke_vi(3799,($_____array|0));
        $119 = __THREW__; __THREW__ = 0;
        $120 = $119&1;
        if ($120) {
         break L41;
        }
        $74 = ($75|0)<(0);
        if ($74) {
         label = 39;
        } else {
         $76 = HEAP32[$49>>2]|0;
         $77 = ($75>>>0)<($76>>>0);
         if (!($77)) {
          label = 39;
         }
        }
        if ((label|0) == 39) {
         label = 0;
         __THREW__ = 0;
         $78 = (invoke_i(132)|0);
         $79 = __THREW__; __THREW__ = 0;
         $80 = $79&1;
         if ($80) {
          break L41;
         }
         __THREW__ = 0;
         invoke_vi(3302,($78|0));
         $81 = __THREW__; __THREW__ = 0;
         $82 = $81&1;
         if ($82) {
          break L41;
         }
        }
        $95 = HEAP32[$_____array>>2]|0;
        $96 = (($95) + 92|0);
        $97 = HEAP32[$96>>2]|0;
        $98 = Math_imul($97, $75)|0;
        $99 = (($73) + ($98)|0);
        $100 = $99;
        $101 = $100;
        $102 = HEAP32[$101>>2]|0;
        $103 = (($100) + 4)|0;
        $104 = $103;
        $105 = HEAP32[$104>>2]|0;
        __THREW__ = 0;
        invoke_vi(3799,($$01|0));
        $106 = __THREW__; __THREW__ = 0;
        $107 = $106&1;
        if ($107) {
         break L41;
        }
        __THREW__ = 0;
        $108 = (invoke_iiiiiii(134,(2076392|0),($$01|0),($0|0),($1|0),($102|0),($105|0))|0);
        $109 = __THREW__; __THREW__ = 0;
        $110 = $109&1;
        if ($110) {
         break L41;
        }
        $111 = ($108|0)==(0);
        if ($111) {
         $$0 = $75;
         label = 61;
         break L41;
        }
        $112 = ($108|0)>(-1);
        $113 = (($75) + 1)|0;
        if (!($112)) {
         break;
        }
        $116 = ($75|0)<($V_1$0$ph22|0);
        if ($116) {
         $V_0$017 = $113;
        } else {
         $V_0$0$lcssa = $113;
         break L39;
        }
       }
       $114 = (($75) + -1)|0;
       $115 = ($V_0$017|0)>($114|0);
       if ($115) {
        $V_0$0$lcssa = $V_0$017;
        break L39;
       } else {
        $V_0$0$ph23 = $V_0$017;$V_1$0$ph22 = $114;
       }
      }
      if ((label|0) == 61) {
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return ($$0|0);
      }
      $83 = ___cxa_find_matching_catch(348288|0)|0;
      $84 = tempRet0;
      $85 = (_llvm_eh_typeid_for((348288|0))|0);
      $86 = ($84|0)==($85|0);
      if (!($86)) {
       $$02 = $83;$$03 = $84;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
      $87 = (___cxa_begin_catch(($83|0))|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = HEAP32[$88>>2]|0;
      __THREW__ = 0;
      $90 = (invoke_iii(2727,(2246120|0),($89|0))|0);
      $91 = __THREW__; __THREW__ = 0;
      $92 = $91&1;
      do {
       if (!($92)) {
        if (!($90)) {
         $125 = (___cxa_allocate_exception(4)|0);
         $126 = HEAP32[$87>>2]|0;
         HEAP32[$125>>2] = $126;
         __THREW__ = 0;
         invoke_viii(1567,($125|0),(348288|0),(0|0));
         $127 = __THREW__; __THREW__ = 0;
         $128 = $127&1;
         if ($128) {
          break;
         }
         // unreachable;
        }
        __THREW__ = 0;
        invoke_v(66);
        $93 = __THREW__; __THREW__ = 0;
        $94 = $93&1;
        if ($94) {
         break L1;
        }
        $129 = HEAP32[3016296>>2]|0;
        __THREW__ = 0;
        $130 = (invoke_iii(783,(0|0),($129|0))|0);
        $131 = __THREW__; __THREW__ = 0;
        $132 = $131&1;
        if ($132) {
         break L1;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2607872|0))|0);
        $133 = __THREW__; __THREW__ = 0;
        $134 = $133&1;
        if ($134) {
         break L1;
        }
        __THREW__ = 0;
        $135 = (invoke_ii(3469,(2607872|0))|0);
        $136 = __THREW__; __THREW__ = 0;
        $137 = $136&1;
        if ($137) {
         break L1;
        }
        __THREW__ = 0;
        invoke_viii(678,($135|0),($130|0),($88|0));
        $138 = __THREW__; __THREW__ = 0;
        $139 = $138&1;
        if ($139) {
         break L1;
        }
        __THREW__ = 0;
        invoke_vi(3850,($135|0));
        $140 = __THREW__; __THREW__ = 0;
        $141 = $140&1;
        if ($141) {
         break L1;
        }
        // unreachable;
       }
      } while(0);
      $121 = ___cxa_find_matching_catch()|0;
      $122 = tempRet0;
      __THREW__ = 0;
      invoke_v(66);
      $123 = __THREW__; __THREW__ = 0;
      $124 = $123&1;
      if ($124) {
       $143 = ___cxa_find_matching_catch(0|0)|0;
       $144 = tempRet0;
       ___clang_call_terminate($143);
       // unreachable;
      } else {
       $$02 = $121;$$03 = $122;
       __ZN16StackTraceSentryD2Ev(0);
       ___resumeException($$02|0);
       // unreachable;
      }
     }
    } while(0);
    $142 = $V_0$0$lcssa ^ -1;
    $$0 = $142;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $5 = ___cxa_find_matching_catch()|0;
 $6 = tempRet0;
 $$02 = $5;$$03 = $6;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($$02|0);
 // unreachable;
 return 0|0;
}
function __ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsS1_E6InvokeEP10MethodInfoPvyy($method,$obj,$0,$1,$2,$3) {
 $method = $method|0;
 $obj = $obj|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $data = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $data = sp;
 __ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv($data,$method,$obj);
 $4 = (($data) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$data>>2]|0;
 $9 = (FUNCTION_TABLE_iiiiii[$7 & 255]($8,$0,$1,$2,$3)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2934992 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP41mscorlib_System_Reflection_MethodInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2935144 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayiP37mscorlib_System_Reflection_MethodInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayiP37mscorlib_System_Reflection_MethodInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2935248 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2935304 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP42mscorlib_System_Reflection_ConstructorInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP42mscorlib_System_Reflection_ConstructorInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2935456 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP46mscorlib_System_Reflection_ConstructorInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP42mscorlib_System_Reflection_ConstructorInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP42mscorlib_System_Reflection_ConstructorInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2935608 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayiP42mscorlib_System_Reflection_ConstructorInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayiP42mscorlib_System_Reflection_ConstructorInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2935712 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2935768 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ParamArrayAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP35mscorlib_System_ParamArrayAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP35mscorlib_System_ParamArrayAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2935920 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP39mscorlib_System_ParamArrayAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP35mscorlib_System_ParamArrayAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP35mscorlib_System_ParamArrayAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2936072 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayiP35mscorlib_System_ParamArrayAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL83mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayiP35mscorlib_System_ParamArrayAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2936176 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ParamArrayAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2936232 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP52mscorlib_System_Runtime_InteropServices_OutAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP52mscorlib_System_Runtime_InteropServices_OutAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2936384 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_InteropServices_OutAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP52mscorlib_System_Runtime_InteropServices_OutAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP52mscorlib_System_Runtime_InteropServices_OutAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2936536 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayiP52mscorlib_System_Runtime_InteropServices_OutAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayiP52mscorlib_System_Runtime_InteropServices_OutAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2936640 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2936696 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ObsoleteAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP33mscorlib_System_ObsoleteAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP33mscorlib_System_ObsoleteAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2936848 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP37mscorlib_System_ObsoleteAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP33mscorlib_System_ObsoleteAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP33mscorlib_System_ObsoleteAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937000 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayiP33mscorlib_System_ObsoleteAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayiP33mscorlib_System_ObsoleteAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937104 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ObsoleteAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937160 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937312 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_DllImportAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937464 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_DllImportAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937568 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937624 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937776 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2937928 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938032 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938088 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP51mscorlib_System_Runtime_InteropServices_InAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP51mscorlib_System_Runtime_InteropServices_InAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938240 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_InteropServices_InAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP51mscorlib_System_Runtime_InteropServices_InAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP51mscorlib_System_Runtime_InteropServices_InAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938392 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Runtime_InteropServices_InAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Runtime_InteropServices_InAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938496 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938552 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP53mscorlib_System_Runtime_InteropServices_GuidAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP53mscorlib_System_Runtime_InteropServices_GuidAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938704 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_GuidAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP53mscorlib_System_Runtime_InteropServices_GuidAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP53mscorlib_System_Runtime_InteropServices_GuidAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938856 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Runtime_InteropServices_GuidAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Runtime_InteropServices_GuidAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2938960 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939016 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939168 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_ComImportAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939320 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_ComImportAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939424 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939480 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939632 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP61mscorlib_System_Runtime_InteropServices_OptionalAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939784 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayiP57mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayiP57mscorlib_System_Runtime_InteropServices_OptionalAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939888 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2939944 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2940096 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL125mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP71mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2940248 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2940352 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2940408 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL123mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2940560 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL126mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2940712 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayiP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayiP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2940816 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2940872 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL118mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL125mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941024 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL128mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP74mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941176 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayiP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayiP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941280 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL135mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941336 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941488 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP55mscorlib_System_Diagnostics_DebuggerHiddenAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941640 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941744 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941800 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_DefaultMemberAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_DefaultMemberAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2941952 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_DefaultMemberAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_DefaultMemberAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_DefaultMemberAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2942104 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayiP49mscorlib_System_Reflection_DefaultMemberAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayiP49mscorlib_System_Reflection_DefaultMemberAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2942208 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2942264 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2942416 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL123mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP69mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2942568 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayiP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayiP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2942672 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2942728 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2942880 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2943032 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayiP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayiP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2943136 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2943192 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL81mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_MonoTODOAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP33mscorlib_System_MonoTODOAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP33mscorlib_System_MonoTODOAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2943344 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP37mscorlib_System_MonoTODOAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP33mscorlib_System_MonoTODOAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL80mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP33mscorlib_System_MonoTODOAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2943496 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayiP33mscorlib_System_MonoTODOAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL81mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayiP33mscorlib_System_MonoTODOAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2943600 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_MonoTODOAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2943656 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2943704);
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;HEAP32[$agg$result+12>>2]=0|0;HEAP32[$agg$result+16>>2]=0|0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($agg$result|0),($25|0),($23|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2943752);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $_stackTraceSentry = sp + 80|0;
 $V_2 = sp;
 $L_6 = sp + 20|0;
 $L_8 = sp + 40|0;
 $L_12 = sp + 60|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2943800);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;HEAP32[$V_2+16>>2]=0|0;
 __THREW__ = 0;
 invoke_v(996);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     if (!($26)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $27 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $60 = HEAP32[$__this>>2]|0;
      $61 = (($60) + 28|0);
      $62 = HEAP32[$61>>2]|0;
      $63 = (($62) + 92|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = Math_imul($64, $V_1$011)|0;
      $66 = (($27) + ($65)|0);
      _memcpy(($V_2|0),($66|0),($64|0))|0;
      ;HEAP32[$L_6+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$item+12>>2]|0;HEAP32[$L_6+16>>2]=HEAP32[$item+16>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2258184|0))|0);
      $67 = __THREW__; __THREW__ = 0;
      $68 = $67&1;
      if ($68) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $28 = (invoke_iii(2724,(2258184|0),($L_6|0))|0);
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if ($30) {
       label = 4;
       break;
      }
      $31 = ($28|0)==(0|0);
      if ($31) {
       label = 18;
       break;
      }
      ;HEAP32[$L_12+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_12+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_12+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$L_12+12>>2]=HEAP32[$V_2+12>>2]|0;HEAP32[$L_12+16>>2]=HEAP32[$V_2+16>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2258184|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $40 = (invoke_iii(2724,(2258184|0),($L_12|0))|0);
      $41 = __THREW__; __THREW__ = 0;
      $42 = $41&1;
      if ($42) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2258184|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $45 = (invoke_iii(2724,(2258184|0),($item|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($45|0));
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2258184|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $52 = (invoke_iii(2724,(2258184|0),($item|0))|0);
      $53 = __THREW__; __THREW__ = 0;
      $54 = $53&1;
      if ($54) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $55 = (invoke_iiii(1644,(2148736|0),($52|0),($40|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      $58 = (($V_1$011) + 1)|0;
      if ($55) {
       $$0 = 1;
       label = 32;
       break;
      }
      $59 = ($58|0)<($23|0);
      if ($59) {
       $V_1$011 = $58;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $6 = ___cxa_find_matching_catch()|0;
      $7 = tempRet0;
      $lpad$phi$index = $6;$lpad$phi$index2 = $7;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      ;HEAP32[$L_8+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_8+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_8+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$L_8+12>>2]=HEAP32[$V_2+12>>2]|0;HEAP32[$L_8+16>>2]=HEAP32[$V_2+16>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2258184|0))|0);
      $32 = __THREW__; __THREW__ = 0;
      $33 = $32&1;
      if ($33) {
       break;
      }
      __THREW__ = 0;
      $34 = (invoke_iii(2724,(2258184|0),($L_8|0))|0);
      $35 = __THREW__; __THREW__ = 0;
      $36 = $35&1;
      if ($36) {
       break;
      }
      $37 = ($34|0)==(0|0);
      $$0 = $37;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_ArrayP67mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2943856);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2943904);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $_stackTraceSentry = sp + 80|0;
 $V_2 = sp;
 $L_6 = sp + 20|0;
 $L_8 = sp + 40|0;
 $L_17 = sp + 60|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2943952);
 ;HEAP32[$V_2+0>>2]=0|0;HEAP32[$V_2+4>>2]=0|0;HEAP32[$V_2+8>>2]=0|0;HEAP32[$V_2+12>>2]=0|0;HEAP32[$V_2+16>>2]=0|0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $72 = HEAP32[$__this>>2]|0;
        $73 = (($72) + 28|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = (($74) + 92|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = Math_imul($76, $V_1$013)|0;
        $78 = (($27) + ($77)|0);
        _memcpy(($V_2|0),($78|0),($76|0))|0;
        ;HEAP32[$L_6+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_6+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_6+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$L_6+12>>2]=HEAP32[$item+12>>2]|0;HEAP32[$L_6+16>>2]=HEAP32[$item+16>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2258184|0))|0);
        $79 = __THREW__; __THREW__ = 0;
        $80 = $79&1;
        if ($80) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2258184|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        ;HEAP32[$L_17+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_17+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_17+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$L_17+12>>2]=HEAP32[$item+12>>2]|0;HEAP32[$L_17+16>>2]=HEAP32[$item+16>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2258184|0))|0);
        $46 = __THREW__; __THREW__ = 0;
        $47 = $46&1;
        if ($47) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $48 = (invoke_iii(2724,(2258184|0),($L_17|0))|0);
        $49 = __THREW__; __THREW__ = 0;
        $50 = $49&1;
        if ($50) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2258184|0))|0);
        $51 = __THREW__; __THREW__ = 0;
        $52 = $51&1;
        if ($52) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $53 = (invoke_iii(2724,(2258184|0),($V_2|0))|0);
        $54 = __THREW__; __THREW__ = 0;
        $55 = $54&1;
        if ($55) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($53|0));
        $56 = __THREW__; __THREW__ = 0;
        $57 = $56&1;
        if ($57) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2258184|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $60 = (invoke_iii(2724,(2258184|0),($V_2|0))|0);
        $61 = __THREW__; __THREW__ = 0;
        $62 = $61&1;
        if ($62) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $63 = (invoke_iiii(1644,(2148736|0),($60|0),($48|0))|0);
        $64 = __THREW__; __THREW__ = 0;
        $65 = $64&1;
        if ($65) {
         label = 4;
         break;
        }
        $66 = (($V_1$013) + 1)|0;
        if ($63) {
         label = 34;
         break;
        }
        $71 = ($66|0)<($23|0);
        if ($71) {
         $V_1$013 = $66;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        ;HEAP32[$L_8+0>>2]=HEAP32[$V_2+0>>2]|0;HEAP32[$L_8+4>>2]=HEAP32[$V_2+4>>2]|0;HEAP32[$L_8+8>>2]=HEAP32[$V_2+8>>2]|0;HEAP32[$L_8+12>>2]=HEAP32[$V_2+12>>2]|0;HEAP32[$L_8+16>>2]=HEAP32[$V_2+16>>2]|0;
        __THREW__ = 0;
        (invoke_ii(2996,(2258184|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         break L1;
        }
        __THREW__ = 0;
        $34 = (invoke_iii(2724,(2258184|0),($L_8|0))|0);
        $35 = __THREW__; __THREW__ = 0;
        $36 = $35&1;
        if ($36) {
         break L1;
        }
        $37 = ($34|0)==(0|0);
        if ($37) {
         __THREW__ = 0;
         $38 = (invoke_iii(755,($__this|0),0)|0);
         $39 = __THREW__; __THREW__ = 0;
         $40 = $39&1;
         if ($40) {
          break L1;
         }
         $41 = (($38) + ($V_1$013))|0;
         $$0 = $41;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $42 = (invoke_iii(755,($__this|0),0)|0);
         $43 = __THREW__; __THREW__ = 0;
         $44 = $43&1;
         if ($44) {
          break L1;
         }
         $45 = (($42) + -1)|0;
         $$0 = $45;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $67 = (invoke_iii(755,($__this|0),0)|0);
        $68 = __THREW__; __THREW__ = 0;
        $69 = $68&1;
        if ($69) {
         break L1;
        }
        $70 = (($67) + ($V_1$013))|0;
        $$0 = $70;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $81 = (invoke_iii(755,($__this|0),0)|0);
     $82 = __THREW__; __THREW__ = 0;
     $83 = $82&1;
     if (!($83)) {
      $84 = (($81) + -1)|0;
      $$0 = $84;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Arrayi63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2944008);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Arrayi63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 20|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2944056);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $48 = (($__this) + 16|0);
       $49 = HEAP32[$__this>>2]|0;
       $50 = (($49) + 28|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (($51) + 92|0);
       $53 = HEAP32[$52>>2]|0;
       $54 = Math_imul($53, $index)|0;
       $55 = (($48) + ($54)|0);
       _memcpy(($55|0),($item|0),($53|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      ;HEAP32[$L_3+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$L_3+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$L_3+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$L_3+12>>2]=HEAP32[$item+12>>2]|0;HEAP32[$L_3+16>>2]=HEAP32[$item+16>>2]|0;
      __THREW__ = 0;
      (invoke_ii(2996,(2258184|0))|0);
      $24 = __THREW__; __THREW__ = 0;
      $25 = $24&1;
      if (!($25)) {
       __THREW__ = 0;
       $26 = (invoke_iii(2724,(2258184|0),($L_3|0))|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if (!($28)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if (!($30)) {
         $31 = ($index|0)<(0);
         if ($31) {
          label = 18;
         } else {
          $32 = (($20) + 12|0);
          $33 = HEAP32[$32>>2]|0;
          $34 = ($33>>>0)>($index>>>0);
          if (!($34)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $35 = (invoke_i(132)|0);
          $36 = __THREW__; __THREW__ = 0;
          $37 = $36&1;
          if ($37) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($35|0));
          $38 = __THREW__; __THREW__ = 0;
          $39 = $38&1;
          if ($39) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($26|0));
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if (!($41)) {
          $42 = HEAP32[$20>>2]|0;
          $43 = (($20) + 16|0);
          $44 = (($42) + 92|0);
          $45 = HEAP32[$44>>2]|0;
          $46 = Math_imul($45, $index)|0;
          $47 = (($43) + ($46)|0);
          HEAP32[$47>>2] = $26;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2944112);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1750,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2126488|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2126488|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2944272 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP53mscorlib_Mono_Globalization_Unicode_TailoringInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2944424 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayiP49mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayiP49mscorlib_Mono_Globalization_Unicode_TailoringInfo($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2944528 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2944584 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP47mscorlib_Mono_Globalization_Unicode_Contraction($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP47mscorlib_Mono_Globalization_Unicode_Contraction($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2944736 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP51mscorlib_Mono_Globalization_Unicode_Contraction_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP47mscorlib_Mono_Globalization_Unicode_Contraction($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP47mscorlib_Mono_Globalization_Unicode_Contraction($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2944888 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayiP47mscorlib_Mono_Globalization_Unicode_Contraction($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayiP47mscorlib_Mono_Globalization_Unicode_Contraction($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2944992 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2945048 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP45mscorlib_Mono_Globalization_Unicode_Level2Map($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP45mscorlib_Mono_Globalization_Unicode_Level2Map($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2945200 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_Level2Map_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP45mscorlib_Mono_Globalization_Unicode_Level2Map($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP45mscorlib_Mono_Globalization_Unicode_Level2Map($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2945352 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayiP45mscorlib_Mono_Globalization_Unicode_Level2Map($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayiP45mscorlib_Mono_Globalization_Unicode_Level2Map($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2945456 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2945512 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945560);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945608);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945656);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2273368|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2273368|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2273368|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2273368|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2273368|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2273368|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2273368|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2273368|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2273368|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2273368|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_ArrayP67mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945712);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945760);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945808);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2273368|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2273368|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2273368|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2273368|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2273368|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2273368|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2273368|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2273368|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2273368|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2273368|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945864);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945912);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2273368|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2273368|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2945968);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1755,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2135544|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2135544|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Arrayi($agg$result,$__this,$index) {
 $agg$result = $agg$result|0;
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946024);
 $0 = $agg$result;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  __THREW__ = 0;
  $6 = (invoke_ii(1857,($__this|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   $9 = ($6|0)>($index|0);
   if ($9) {
    $22 = (($__this) + 16|0);
    $23 = HEAP32[$__this>>2]|0;
    $24 = (($23) + 28|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + 92|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = Math_imul($27, $index)|0;
    $29 = (($22) + ($28)|0);
    _memcpy(($agg$result|0),($29|0),($27|0))|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return;
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    $14 = (invoke_ii(3469,(2561352|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     $17 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($14|0),($17|0));
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if (!($19)) {
      __THREW__ = 0;
      invoke_vi(3850,($14|0));
      $20 = __THREW__; __THREW__ = 0;
      $21 = $20&1;
      if (!($21)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $10 = ___cxa_find_matching_catch()|0;
 $11 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($10|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array42mscorlib_System_Collections_Hashtable_Slot($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946072);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array42mscorlib_System_Collections_Hashtable_Slot($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $L_12 = 0, $L_6 = 0;
 var $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_12 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946120);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     if (!($30)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $31 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $78 = HEAP32[$__this>>2]|0;
      $79 = (($78) + 28|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($80) + 92|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = Math_imul($82, $V_1$011)|0;
      $84 = (($31) + ($83)|0);
      _memcpy(($V_2|0),($84|0),($82|0))|0;
      $85 = $item;
      $86 = $85;
      $87 = HEAP32[$86>>2]|0;
      $88 = (($85) + 4)|0;
      $89 = $88;
      $90 = HEAP32[$89>>2]|0;
      $91 = $L_6;
      $92 = $91;
      HEAP32[$92>>2] = $87;
      $93 = (($91) + 4)|0;
      $94 = $93;
      HEAP32[$94>>2] = $90;
      __THREW__ = 0;
      (invoke_ii(2996,(2307464|0))|0);
      $95 = __THREW__; __THREW__ = 0;
      $96 = $95&1;
      if ($96) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $32 = (invoke_iii(2724,(2307464|0),($L_6|0))|0);
      $33 = __THREW__; __THREW__ = 0;
      $34 = $33&1;
      if ($34) {
       label = 4;
       break;
      }
      $35 = ($32|0)==(0|0);
      $36 = $V_2;
      $37 = $36;
      $38 = HEAP32[$37>>2]|0;
      $39 = (($36) + 4)|0;
      $40 = $39;
      $41 = HEAP32[$40>>2]|0;
      if ($35) {
       label = 18;
       break;
      }
      $52 = $L_12;
      $53 = $52;
      HEAP32[$53>>2] = $38;
      $54 = (($52) + 4)|0;
      $55 = $54;
      HEAP32[$55>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2307464|0))|0);
      $56 = __THREW__; __THREW__ = 0;
      $57 = $56&1;
      if ($57) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $58 = (invoke_iii(2724,(2307464|0),($L_12|0))|0);
      $59 = __THREW__; __THREW__ = 0;
      $60 = $59&1;
      if ($60) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2307464|0))|0);
      $61 = __THREW__; __THREW__ = 0;
      $62 = $61&1;
      if ($62) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $63 = (invoke_iii(2724,(2307464|0),($item|0))|0);
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($63|0));
      $66 = __THREW__; __THREW__ = 0;
      $67 = $66&1;
      if ($67) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2307464|0))|0);
      $68 = __THREW__; __THREW__ = 0;
      $69 = $68&1;
      if ($69) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $70 = (invoke_iii(2724,(2307464|0),($item|0))|0);
      $71 = __THREW__; __THREW__ = 0;
      $72 = $71&1;
      if ($72) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $73 = (invoke_iiii(1644,(2148736|0),($70|0),($58|0))|0);
      $74 = __THREW__; __THREW__ = 0;
      $75 = $74&1;
      if ($75) {
       label = 4;
       break;
      }
      $76 = (($V_1$011) + 1)|0;
      if ($73) {
       $$0 = 1;
       label = 32;
       break;
      }
      $77 = ($76|0)<($27|0);
      if ($77) {
       $V_1$011 = $76;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $10 = ___cxa_find_matching_catch()|0;
      $11 = tempRet0;
      $lpad$phi$index = $10;$lpad$phi$index2 = $11;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      $42 = $L_8;
      $43 = $42;
      HEAP32[$43>>2] = $38;
      $44 = (($42) + 4)|0;
      $45 = $44;
      HEAP32[$45>>2] = $41;
      __THREW__ = 0;
      (invoke_ii(2996,(2307464|0))|0);
      $46 = __THREW__; __THREW__ = 0;
      $47 = $46&1;
      if ($47) {
       break;
      }
      __THREW__ = 0;
      $48 = (invoke_iii(2724,(2307464|0),($L_8|0))|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       break;
      }
      $51 = ($48|0)==(0|0);
      $$0 = $51;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_ArrayP46mscorlib_System_Collections_Hashtable_Slot_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946176);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array42mscorlib_System_Collections_Hashtable_Slot($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946224);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array42mscorlib_System_Collections_Hashtable_Slot($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0;
 var $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $_stackTraceSentry = sp + 32|0;
 $V_2 = sp;
 $L_6 = sp + 8|0;
 $L_8 = sp + 16|0;
 $L_17 = sp + 24|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946272);
 $0 = $V_2;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 L1: do {
  if (!($5)) {
   __THREW__ = 0;
   $6 = (invoke_ii(1859,($__this|0))|0);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if (!($8)) {
    $9 = ($6|0)<(2);
    if (!($9)) {
     $14 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $15 = (invoke_iii(783,(0|0),($14|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     $20 = (invoke_ii(3469,(2636920|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($20|0),($15|0));
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($20|0));
     $25 = __THREW__; __THREW__ = 0;
     $26 = $25&1;
     if ($26) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $27 = (invoke_ii(1857,($__this|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = ($27|0)>(0);
     L13: do {
      if ($30) {
       $31 = (($__this) + 16|0);
       $32 = $item;
       $33 = $32;
       $34 = HEAP32[$33>>2]|0;
       $35 = (($32) + 4)|0;
       $36 = $35;
       $37 = HEAP32[$36>>2]|0;
       $V_1$013 = 0;
       while(1) {
        $96 = HEAP32[$__this>>2]|0;
        $97 = (($96) + 28|0);
        $98 = HEAP32[$97>>2]|0;
        $99 = (($98) + 92|0);
        $100 = HEAP32[$99>>2]|0;
        $101 = Math_imul($100, $V_1$013)|0;
        $102 = (($31) + ($101)|0);
        _memcpy(($V_2|0),($102|0),($100|0))|0;
        $103 = $L_6;
        $104 = $103;
        HEAP32[$104>>2] = $34;
        $105 = (($103) + 4)|0;
        $106 = $105;
        HEAP32[$106>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2307464|0))|0);
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if ($108) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $38 = (invoke_iii(2724,(2307464|0),($L_6|0))|0);
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if ($40) {
         label = 4;
         break;
        }
        $41 = ($38|0)==(0|0);
        if ($41) {
         label = 18;
         break;
        }
        $66 = $L_17;
        $67 = $66;
        HEAP32[$67>>2] = $34;
        $68 = (($66) + 4)|0;
        $69 = $68;
        HEAP32[$69>>2] = $37;
        __THREW__ = 0;
        (invoke_ii(2996,(2307464|0))|0);
        $70 = __THREW__; __THREW__ = 0;
        $71 = $70&1;
        if ($71) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $72 = (invoke_iii(2724,(2307464|0),($L_17|0))|0);
        $73 = __THREW__; __THREW__ = 0;
        $74 = $73&1;
        if ($74) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2307464|0))|0);
        $75 = __THREW__; __THREW__ = 0;
        $76 = $75&1;
        if ($76) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $77 = (invoke_iii(2724,(2307464|0),($V_2|0))|0);
        $78 = __THREW__; __THREW__ = 0;
        $79 = $78&1;
        if ($79) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($77|0));
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2307464|0))|0);
        $82 = __THREW__; __THREW__ = 0;
        $83 = $82&1;
        if ($83) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $84 = (invoke_iii(2724,(2307464|0),($V_2|0))|0);
        $85 = __THREW__; __THREW__ = 0;
        $86 = $85&1;
        if ($86) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $87 = (invoke_iiii(1644,(2148736|0),($84|0),($72|0))|0);
        $88 = __THREW__; __THREW__ = 0;
        $89 = $88&1;
        if ($89) {
         label = 4;
         break;
        }
        $90 = (($V_1$013) + 1)|0;
        if ($87) {
         label = 34;
         break;
        }
        $95 = ($90|0)<($27|0);
        if ($95) {
         $V_1$013 = $90;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $10 = ___cxa_find_matching_catch()|0;
        $11 = tempRet0;
        $lpad$phi$index = $10;$lpad$phi$index2 = $11;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $42 = $V_2;
        $43 = $42;
        $44 = HEAP32[$43>>2]|0;
        $45 = (($42) + 4)|0;
        $46 = $45;
        $47 = HEAP32[$46>>2]|0;
        $48 = $L_8;
        $49 = $48;
        HEAP32[$49>>2] = $44;
        $50 = (($48) + 4)|0;
        $51 = $50;
        HEAP32[$51>>2] = $47;
        __THREW__ = 0;
        (invoke_ii(2996,(2307464|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         break L1;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2307464|0),($L_8|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         break L1;
        }
        $57 = ($54|0)==(0|0);
        if ($57) {
         __THREW__ = 0;
         $58 = (invoke_iii(755,($__this|0),0)|0);
         $59 = __THREW__; __THREW__ = 0;
         $60 = $59&1;
         if ($60) {
          break L1;
         }
         $61 = (($58) + ($V_1$013))|0;
         $$0 = $61;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $62 = (invoke_iii(755,($__this|0),0)|0);
         $63 = __THREW__; __THREW__ = 0;
         $64 = $63&1;
         if ($64) {
          break L1;
         }
         $65 = (($62) + -1)|0;
         $$0 = $65;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $91 = (invoke_iii(755,($__this|0),0)|0);
        $92 = __THREW__; __THREW__ = 0;
        $93 = $92&1;
        if ($93) {
         break L1;
        }
        $94 = (($91) + ($V_1$013))|0;
        $$0 = $94;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $109 = (invoke_iii(755,($__this|0),0)|0);
     $110 = __THREW__; __THREW__ = 0;
     $111 = $110&1;
     if (!($111)) {
      $112 = (($109) + -1)|0;
      $$0 = $112;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 $lpad$phi$index = $12;$lpad$phi$index2 = $13;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Arrayi42mscorlib_System_Collections_Hashtable_Slot($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946328);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Arrayi42mscorlib_System_Collections_Hashtable_Slot($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 8|0;
 $L_3 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946376);
 __THREW__ = 0;
 invoke_v(1001);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1857,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)>($index|0);
    if (!($5)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $8 = __THREW__; __THREW__ = 0;
     $9 = $8&1;
     if ($9) {
      break;
     }
     __THREW__ = 0;
     $10 = (invoke_ii(3469,(2561352|0))|0);
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if ($12) {
      break;
     }
     $13 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($10|0));
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if ($17) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     __THREW__ = 0;
     $20 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      $23 = ($20|0)==(0|0);
      if ($23) {
       $58 = (($__this) + 16|0);
       $59 = HEAP32[$__this>>2]|0;
       $60 = (($59) + 28|0);
       $61 = HEAP32[$60>>2]|0;
       $62 = (($61) + 92|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = Math_imul($63, $index)|0;
       $65 = (($58) + ($64)|0);
       _memcpy(($65|0),($item|0),($63|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      $24 = $item;
      $25 = $24;
      $26 = HEAP32[$25>>2]|0;
      $27 = (($24) + 4)|0;
      $28 = $27;
      $29 = HEAP32[$28>>2]|0;
      $30 = $L_3;
      $31 = $30;
      HEAP32[$31>>2] = $26;
      $32 = (($30) + 4)|0;
      $33 = $32;
      HEAP32[$33>>2] = $29;
      __THREW__ = 0;
      (invoke_ii(2996,(2307464|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if (!($35)) {
       __THREW__ = 0;
       $36 = (invoke_iii(2724,(2307464|0),($L_3|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if (!($38)) {
        __THREW__ = 0;
        invoke_vi(3799,($20|0));
        $39 = __THREW__; __THREW__ = 0;
        $40 = $39&1;
        if (!($40)) {
         $41 = ($index|0)<(0);
         if ($41) {
          label = 18;
         } else {
          $42 = (($20) + 12|0);
          $43 = HEAP32[$42>>2]|0;
          $44 = ($43>>>0)>($index>>>0);
          if (!($44)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $45 = (invoke_i(132)|0);
          $46 = __THREW__; __THREW__ = 0;
          $47 = $46&1;
          if ($47) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($45|0));
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($20|0),($36|0));
         $50 = __THREW__; __THREW__ = 0;
         $51 = $50&1;
         if (!($51)) {
          $52 = HEAP32[$20>>2]|0;
          $53 = (($20) + 16|0);
          $54 = (($52) + 92|0);
          $55 = HEAP32[$54>>2]|0;
          $56 = Math_imul($55, $index)|0;
          $57 = (($53) + ($56)|0);
          HEAP32[$57>>2] = $36;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946432);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1756,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2137808|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2137808|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946488);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946536);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946584);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2308264|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2308264|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2308264|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2308264|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2308264|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2308264|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2308264|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2308264|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2308264|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2308264|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_ArrayP56mscorlib_System_Collections_Hashtable_EnumeratorMode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946640);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946688);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946736);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2308264|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2308264|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2308264|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2308264|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2308264|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2308264|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2308264|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2308264|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2308264|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2308264|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946792);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946840);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2308264|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2308264|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946896);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1758,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2140072|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2140072|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2946952);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947000);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z122mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947048);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2316496|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2316496|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2316496|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2316496|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2316496|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2316496|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2316496|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2316496|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2316496|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2316496|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_ArrayP66mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947104);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z120mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947152);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947200);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2316496|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2316496|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2316496|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2316496|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2316496|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2316496|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2316496|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2316496|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2316496|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2316496|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947256);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947304);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2316496|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2316496|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947360);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1759,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(2142336|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(2142336|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947416);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z124mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947464);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z129mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947512);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2317000|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2317000|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2317000|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2317000|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2317000|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2317000|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2317000|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2317000|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2317000|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2317000|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z127mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_ArrayP73mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947568);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z127mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947616);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z116mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947664);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2317000|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2317000|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2317000|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2317000|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2317000|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2317000|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2317000|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2317000|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2317000|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2317000|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947720);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z117mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947768);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2317000|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2317000|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z134mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2947824);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1357,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1442584|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1442584|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL95mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP47mscorlib_System_Diagnostics_DebuggableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP47mscorlib_System_Diagnostics_DebuggableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2947984 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggableAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP47mscorlib_System_Diagnostics_DebuggableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP47mscorlib_System_Diagnostics_DebuggableAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2948136 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayiP47mscorlib_System_Diagnostics_DebuggableAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayiP47mscorlib_System_Diagnostics_DebuggableAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2948240 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2948296 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z110mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948344);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948392);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z122mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948440);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2317584|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2317584|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2317584|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2317584|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2317584|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2317584|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2317584|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2317584|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2317584|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2317584|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_ArrayP66mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948496);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z120mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948544);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948592);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2317584|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2317584|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2317584|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2317584|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2317584|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2317584|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2317584|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2317584|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2317584|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2317584|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948648);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948696);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2317584|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2317584|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2948752);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1359,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1447112|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1447112|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2948912 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerDisplayAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949064 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayiP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayiP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949168 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949224 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949376 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP60mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949528 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949632 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949688 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949840 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP58mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2949992 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayiP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayiP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2950096 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2950152 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP38mscorlib_System_Diagnostics_StackFrame($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP38mscorlib_System_Diagnostics_StackFrame($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2950304 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP42mscorlib_System_Diagnostics_StackFrame_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP38mscorlib_System_Diagnostics_StackFrame($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP38mscorlib_System_Diagnostics_StackFrame($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2950456 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayiP38mscorlib_System_Diagnostics_StackFrame($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayiP38mscorlib_System_Diagnostics_StackFrame($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2950560 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2950616 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2950664);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2950712);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2950760);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2329520|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2329520|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2329520|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2329520|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2329520|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2329520|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2329520|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2329520|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2329520|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2329520|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_ArrayP48mscorlib_System_Globalization_CompareOptions_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2950816);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2950864);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2950912);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2329520|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2329520|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2329520|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2329520|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2329520|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2329520|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2329520|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2329520|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2329520|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2329520|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2950968);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951016);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2329520|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2329520|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951072);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1364,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1458432|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1458432|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL86mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_CalendarP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP38mscorlib_System_Globalization_Calendar($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP38mscorlib_System_Globalization_Calendar($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2951232 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP42mscorlib_System_Globalization_Calendar_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP38mscorlib_System_Globalization_Calendar($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP38mscorlib_System_Globalization_Calendar($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2951384 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayiP38mscorlib_System_Globalization_Calendar($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayiP38mscorlib_System_Globalization_Calendar($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2951488 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_CalendarP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2951544 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951592);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951640);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951688);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2334344|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2334344|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2334344|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2334344|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2334344|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2334344|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2334344|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2334344|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2334344|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2334344|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_ArrayP53mscorlib_System_Globalization_DateTimeFormatFlags_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951744);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951792);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951840);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2334344|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2334344|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2334344|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2334344|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2334344|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2334344|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2334344|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2334344|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2334344|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2334344|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951896);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2951944);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2334344|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2334344|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952000);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1366,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1462960|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1462960|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952056);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952104);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952152);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2341504|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2341504|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2341504|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2341504|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2341504|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2341504|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2341504|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2341504|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2341504|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2341504|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_ArrayP48mscorlib_System_Globalization_DateTimeStyles_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952208);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952256);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952304);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2341504|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2341504|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2341504|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2341504|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2341504|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2341504|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2341504|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2341504|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2341504|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2341504|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952360);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952408);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2341504|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2341504|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952464);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1367,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1465224|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1465224|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952520);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952568);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952616);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2343728|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2343728|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2343728|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2343728|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2343728|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2343728|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2343728|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2343728|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2343728|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2343728|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_ArrayP56mscorlib_System_Globalization_GregorianCalendarTypes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952672);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952720);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952768);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2343728|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2343728|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2343728|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2343728|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2343728|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2343728|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2343728|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2343728|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2343728|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2343728|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952824);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952872);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2343728|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2343728|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952928);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1368,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1467488|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1467488|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2952984);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953032);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953080);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2349736|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2349736|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2349736|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2349736|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2349736|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2349736|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2349736|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2349736|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2349736|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2349736|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_ArrayP46mscorlib_System_Globalization_NumberStyles_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953136);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953184);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953232);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2349736|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2349736|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2349736|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2349736|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2349736|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2349736|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2349736|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2349736|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2349736|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2349736|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953288);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953336);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2349736|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2349736|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953392);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1369,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1469752|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1469752|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953448);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3850,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953496);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953544);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2352928|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2352928|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2352928|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2352928|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2352928|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2352928|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2352928|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2352928|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2352928|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2352928|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_ArrayP49mscorlib_System_Globalization_UnicodeCategory_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953600);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3850,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3850,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3850,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3850,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953648);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953696);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2352928|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2352928|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2352928|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2352928|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2352928|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2352928|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2352928|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2352928|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2352928|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2352928|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953752);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3850,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953800);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3850,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2352928|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2352928|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2953856);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1370,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1472016|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1472016|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL96mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2954160 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP52mscorlib_System_Reflection_Emit_ParameterBuilder_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2954416 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayiP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayiP48mscorlib_System_Reflection_Emit_ParameterBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2954568 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2954624 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2954776 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP63mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2954928 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayiP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayiP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955032 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955088 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP45mscorlib_System_Reflection_Emit_MethodBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP45mscorlib_System_Reflection_Emit_MethodBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955240 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP49mscorlib_System_Reflection_Emit_MethodBuilder_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP45mscorlib_System_Reflection_Emit_MethodBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP45mscorlib_System_Reflection_Emit_MethodBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955392 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayiP45mscorlib_System_Reflection_Emit_MethodBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayiP45mscorlib_System_Reflection_Emit_MethodBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955496 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955552 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955704 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP54mscorlib_System_Reflection_Emit_ConstructorBuilder_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955856 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayiP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayiP50mscorlib_System_Reflection_Emit_ConstructorBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2955960 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956016 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956168 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP51mscorlib_System_Reflection_Emit_PropertyBuilder_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL94mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956320 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayiP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayiP47mscorlib_System_Reflection_Emit_PropertyBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956424 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956480 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP44mscorlib_System_Reflection_Emit_FieldBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP44mscorlib_System_Reflection_Emit_FieldBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956632 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_FieldBuilder_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP44mscorlib_System_Reflection_Emit_FieldBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP44mscorlib_System_Reflection_Emit_FieldBuilder($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956784 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayiP44mscorlib_System_Reflection_Emit_FieldBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayiP44mscorlib_System_Reflection_Emit_FieldBuilder($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956888 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2956944 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodBase($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodBase($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2957096 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP41mscorlib_System_Reflection_MethodBase_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodBase($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodBase($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2957248 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayiP37mscorlib_System_Reflection_MethodBase($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayiP37mscorlib_System_Reflection_MethodBase($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2957352 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2957408 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyCompanyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyCompanyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2957560 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyCompanyAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyCompanyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyCompanyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2957712 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyCompanyAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyCompanyAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2957816 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2957872 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958024 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP61mscorlib_System_Reflection_AssemblyConfigurationAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958176 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayiP57mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL105mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayiP57mscorlib_System_Reflection_AssemblyConfigurationAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958280 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958336 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958488 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyCopyrightAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958640 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyCopyrightAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958744 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958800 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2958952 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP60mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2959104 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2959208 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2959264 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2959416 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyDelaySignAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2959568 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyDelaySignAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2959672 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2959728 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2959880 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Reflection_AssemblyDescriptionAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960032 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Reflection_AssemblyDescriptionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960136 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960192 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960344 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Reflection_AssemblyFileVersionAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960496 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Reflection_AssemblyFileVersionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960600 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960656 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL119mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960808 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP68mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2960960 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayiP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayiP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961064 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961120 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961272 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyKeyFileAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961424 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyKeyFileAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961528 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961584 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961736 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyKeyNameAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961888 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyKeyNameAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2961992 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2962048 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962096);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception16498($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962144);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962192);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2395880|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2395880|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2395880|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2395880|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2395880|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2395880|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2395880|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2395880|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2395880|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2395880|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_ArrayP48mscorlib_System_Reflection_AssemblyNameFlags_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962248);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962296);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962344);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2395880|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2395880|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2395880|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2395880|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2395880|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2395880|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2395880|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2395880|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2395880|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2395880|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962400);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962448);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2395880|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2395880|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2962504);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1388,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1518736|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1518736|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyProductAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyProductAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2962664 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyProductAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyProductAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyProductAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2962816 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyProductAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyProductAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2962920 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2962976 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_AssemblyTitleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_AssemblyTitleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963128 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTitleAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_AssemblyTitleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_AssemblyTitleAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963280 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayiP49mscorlib_System_Reflection_AssemblyTitleAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayiP49mscorlib_System_Reflection_AssemblyTitleAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963384 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963440 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963592 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyTrademarkAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963744 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyTrademarkAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963848 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963904 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z96mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_PPv($__this,$_____array,$value,$mrgctx) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 $mrgctx = $mrgctx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2963968);
 __THREW__ = 0;
 invoke_v(1004);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if (!($2)) {
    __THREW__ = 0;
    invoke_vi(3799,($_____array|0));
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if ($16) {
     break;
    }
    $17 = (($_____array) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = HEAP32[$mrgctx>>2]|0;
    $20 = (($19) + 4|0);
    $21 = HEAP32[$20>>2]|0;
    __THREW__ = 0;
    $22 = (invoke_iiiiii($21|0,(0|0),($_____array|0),($value|0),0,($18|0))|0);
    $23 = __THREW__; __THREW__ = 0;
    $24 = $23&1;
    if ($24) {
     break;
    }
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($22|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2560584|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     $10 = HEAP32[3016312>>2]|0;
     __THREW__ = 0;
     invoke_vii(1925,($7|0),($10|0));
     $11 = __THREW__; __THREW__ = 0;
     $12 = $11&1;
     if (!($12)) {
      __THREW__ = 0;
      invoke_vi(3851,($7|0));
      $13 = __THREW__; __THREW__ = 0;
      $14 = $13&1;
      if (!($14)) {
       // unreachable;
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
 return 0|0;
}
function __ZL88mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_($__this,$_____array,$value) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $value = $value|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2963968 + 40|0))>>2]|0;
 $1 = (__Z96mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_PPv(0,$_____array,$value,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z87mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964024);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964072);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964120);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2401632|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2401632|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2401632|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2401632|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2401632|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2401632|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2401632|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2401632|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2401632|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2401632|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_ArrayP43mscorlib_System_Reflection_BindingFlags_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964176);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964224);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964272);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2401632|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2401632|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2401632|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2401632|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2401632|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2401632|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2401632|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2401632|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2401632|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2401632|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964328);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z87mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964376);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2401632|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2401632|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964432);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1392,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1527792|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1527792|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964488);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964536);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964584);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2402200|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2402200|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2402200|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2402200|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2402200|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2402200|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2402200|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2402200|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2402200|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2402200|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_ArrayP49mscorlib_System_Reflection_CallingConventions_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964640);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964688);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964736);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2402200|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2402200|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2402200|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2402200|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2402200|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2402200|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2402200|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2402200|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2402200|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2402200|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964792);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964840);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2402200|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2402200|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964896);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1393,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1530056|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1530056|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2964952);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965000);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965048);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2403584|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2403584|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2403584|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2403584|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2403584|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2403584|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2403584|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2403584|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2403584|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2403584|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_ArrayP46mscorlib_System_Reflection_EventAttributes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965104);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965152);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965200);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2403584|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2403584|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2403584|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2403584|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2403584|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2403584|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2403584|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2403584|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2403584|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2403584|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965256);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965304);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2403584|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2403584|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965360);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1394,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1532320|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1532320|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965416);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965464);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965512);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2405320|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2405320|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2405320|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2405320|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2405320|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2405320|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2405320|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2405320|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2405320|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2405320|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_ArrayP46mscorlib_System_Reflection_FieldAttributes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965568);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965616);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965664);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2405320|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2405320|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2405320|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2405320|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2405320|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2405320|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2405320|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2405320|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2405320|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2405320|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965720);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965768);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2405320|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2405320|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965824);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1395,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1534584|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1534584|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965880);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965928);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2965976);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2408328|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2408328|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2408328|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2408328|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2408328|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2408328|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2408328|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2408328|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2408328|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2408328|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_ArrayP42mscorlib_System_Reflection_MemberTypes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966032);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z96mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966080);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966128);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2408328|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2408328|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2408328|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2408328|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2408328|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2408328|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2408328|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2408328|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2408328|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2408328|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966184);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966232);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2408328|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2408328|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966288);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1396,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1536848|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1536848|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966344);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966392);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966440);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2409648|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2409648|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2409648|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2409648|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2409648|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2409648|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2409648|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2409648|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2409648|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2409648|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_ArrayP47mscorlib_System_Reflection_MethodAttributes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966496);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z101mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966544);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966592);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2409648|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2409648|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2409648|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2409648|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2409648|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2409648|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2409648|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2409648|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2409648|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2409648|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966648);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z91mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966696);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2409648|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2409648|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z108mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966752);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1397,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1545064|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1545064|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966808);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966856);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966904);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2413280|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2413280|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2413280|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2413280|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2413280|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2413280|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2413280|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2413280|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2413280|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2413280|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_ArrayP51mscorlib_System_Reflection_MethodImplAttributes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2966960);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967008);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967056);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2413280|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2413280|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2413280|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2413280|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2413280|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2413280|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2413280|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2413280|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2413280|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2413280|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967112);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967160);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2413280|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2413280|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967216);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1398,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1547328|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1547328|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967272);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967320);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967368);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2428456|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2428456|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2428456|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2428456|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2428456|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2428456|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2428456|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2428456|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2428456|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2428456|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_PInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_PInfo_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967424);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967472);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967520);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2428456|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2428456|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2428456|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2428456|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2428456|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2428456|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2428456|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2428456|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2428456|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2428456|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967576);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967624);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2428456|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2428456|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_PInfoP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967680);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1399,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1549592|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1549592|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967736);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967784);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z106mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967832);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2431504|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2431504|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2431504|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2431504|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2431504|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2431504|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2431504|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2431504|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2431504|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2431504|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_ArrayP50mscorlib_System_Reflection_ParameterAttributes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967888);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967936);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2967984);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2431504|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2431504|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2431504|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2431504|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2431504|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2431504|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2431504|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2431504|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2431504|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2431504|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968040);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z94mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968088);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2431504|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2431504|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z111mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968144);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1400,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1551856|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1551856|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968200);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968248);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968296);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2433944|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2433944|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2433944|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2433944|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2433944|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2433944|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2433944|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2433944|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2433944|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2433944|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_ArrayP49mscorlib_System_Reflection_PropertyAttributes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968352);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968400);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968448);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2433944|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2433944|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2433944|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2433944|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2433944|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2433944|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2433944|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2433944|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2433944|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2433944|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968504);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968552);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2433944|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2433944|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968608);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1401,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1554120|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1554120|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968664);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968712);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z101mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968760);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2438136|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2438136|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2438136|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2438136|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2438136|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2438136|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2438136|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2438136|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2438136|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2438136|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_ArrayP45mscorlib_System_Reflection_TypeAttributes_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968816);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z99mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968864);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968912);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2438136|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2438136|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2438136|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2438136|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2438136|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2438136|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2438136|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2438136|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2438136|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2438136|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2968968);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z89mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2969016);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2438136|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2438136|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z106mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2969072);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1402,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1556384|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1556384|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2969232 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP63mscorlib_System_Resources_NeutralResourcesLanguageAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2969384 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2969488 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2969544 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_SatelliteContractVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_SatelliteContractVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2969696 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Resources_SatelliteContractVersionAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_SatelliteContractVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_SatelliteContractVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2969848 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Resources_SatelliteContractVersionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Resources_SatelliteContractVersionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2969952 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2970008 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970056);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970104);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970152);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2439288|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2439288|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2439288|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2439288|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2439288|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2439288|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2439288|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2439288|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2439288|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2439288|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970208);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970256);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970304);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2439288|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2439288|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2439288|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2439288|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2439288|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2439288|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2439288|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2439288|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2439288|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2439288|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970360);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970408);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2439288|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2439288|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2970464);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1405,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1563176|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1563176|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL120mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL127mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2970624 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL130mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP76mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL130mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL119mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2970776 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL118mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayiP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayiP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2970880 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL137mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2970936 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2971088 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL125mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP71mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2971240 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2971344 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2971400 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971448);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971496);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971544);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2440608|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2440608|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2440608|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2440608|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2440608|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2440608|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2440608|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2440608|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2440608|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2440608|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_ArrayP53mscorlib_System_Runtime_CompilerServices_LoadHint_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971600);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971648);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971696);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2440608|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2440608|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2440608|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2440608|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2440608|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2440608|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2440608|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2440608|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2440608|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2440608|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971752);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971800);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2440608|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2440608|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2971856);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1408,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1569968|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1569968|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL112mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL119mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2972016 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2972168 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayiP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayiP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2972272 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL129mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2972328 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z96mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972376);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972424);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z108mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972472);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2441352|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2441352|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2441352|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2441352|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2441352|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2441352|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2441352|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2441352|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2441352|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2441352|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_ArrayP52mscorlib_System_Runtime_ConstrainedExecution_Cer_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972528);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z106mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972576);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972624);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2441352|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2441352|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2441352|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2441352|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2441352|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2441352|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2441352|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2441352|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2441352|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2441352|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z94mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972680);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z96mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972728);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2441352|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2441352|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z113mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972784);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1410,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1574496|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1574496|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972840);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972888);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972936);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2441904|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2441904|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2441904|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2441904|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2441904|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2441904|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2441904|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2441904|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2441904|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2441904|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_ArrayP60mscorlib_System_Runtime_ConstrainedExecution_Consistency_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2972992);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2973040);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2973088);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2441904|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2441904|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2441904|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2441904|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2441904|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2441904|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2441904|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2441904|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2441904|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2441904|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2973144);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2973192);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2441904|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2441904|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2973248);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1411,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1576760|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1576760|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL121mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL128mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2973408 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL131mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP77mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL131mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL120mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2973560 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL119mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayiP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayiP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2973664 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL138mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2973720 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2973872 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2974024 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2974128 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2974184 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974232);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974280);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974328);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2443656|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2443656|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2443656|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2443656|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2443656|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2443656|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2443656|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2443656|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2443656|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2443656|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_ClassInterfaceType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974384);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3851,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3851,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3851,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3851,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974432);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974480);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2443656|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2443656|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2443656|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2443656|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2443656|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2443656|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2443656|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2443656|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2443656|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2443656|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974536);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3851,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974584);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3851,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2443656|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2443656|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2974640);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1414,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1583552|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1583552|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL116mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL123mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2974800 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL126mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL126mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2974952 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayiP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayiP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2975056 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL133mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2975112 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975160);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3851,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975208);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception17121($ex) {
 $ex = $ex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException($ex);
 STACKTOP = sp;return;
}
function __Z116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975288);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2444504|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2444504|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2444504|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2444504|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2444504|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2444504|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2444504|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2444504|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2444504|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2444504|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_ComInterfaceType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975384);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975472);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975560);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2444504|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2444504|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2444504|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2444504|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2444504|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2444504|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2444504|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2444504|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2444504|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2444504|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975640);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975712);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2444504|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2444504|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2975792);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1416,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1588080|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1588080|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL110mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976024 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP66mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976176 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayiP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayiP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976280 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976336 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976488 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976640 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayiP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayiP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976744 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976800 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL115mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL122mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL127mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2976952 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL125mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP71mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL125mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2977104 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2977208 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL132mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2977264 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2977416 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2977568 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2977672 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2977728 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2977776);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2977824);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2977872);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2449232|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2449232|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2449232|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2449232|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2449232|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2449232|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2449232|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2449232|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2449232|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2449232|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_UnmanagedType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2977928);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2977976);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2978024);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2449232|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2449232|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2449232|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2449232|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2449232|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2449232|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2449232|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2449232|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2449232|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2449232|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2978080);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2978128);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2449232|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2449232|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2978184);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1421,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1605352|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1605352|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2978344 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2978496 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2978600 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2978656 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2978808 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2978960 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2979064 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2979120 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z102mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_0 = sp + 4|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979168);
 HEAP8[$V_0>>0] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP8[$V_0>>0]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z109mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979216);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z114mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 5|0;
 $L_8 = sp + 6|0;
 $L_12 = sp + 7|0;
 HEAP8[$0>>0] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979264);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP8[$0>>0]|0;
      HEAP8[$L_6>>0] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2473464|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2473464|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP8[$V_2>>0]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP8[$L_12>>0] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2473464|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2473464|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2473464|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2473464|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2473464|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2473464|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP8[$L_8>>0] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2473464|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2473464|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979320);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z112mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979368);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z101mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayh($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 7|0;
 $L_6 = sp + 4|0;
 $L_8 = sp + 5|0;
 $L_17 = sp + 6|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979416);
 HEAP8[$V_2>>0] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP8[$L_6>>0] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2473464|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2473464|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP8[$L_17>>0] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2473464|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2473464|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2473464|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2473464|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2473464|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2473464|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP8[$V_2>>0]|0;
        HEAP8[$L_8>>0] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2473464|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2473464|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z100mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayih($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979472);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayih($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 5|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP8[$0>>0] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979520);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP8[$L_3>>0] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2473464|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2473464|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2979576);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1424,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1612144|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1612144|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL103mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2979736 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL113mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL102mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2979888 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2979992 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL120mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2980048 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2980200 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2980352 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2980456 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2980512 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980560);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980608);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980656);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2493760|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2493760|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2493760|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2493760|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2493760|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2493760|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2493760|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2493760|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2493760|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2493760|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_WellKnownObjectMode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980712);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980760);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980808);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2493760|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2493760|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2493760|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2493760|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2493760|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2493760|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2493760|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2493760|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2493760|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2493760|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980864);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980912);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2493760|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2493760|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2980968);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1427,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1618936|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1618936|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981024);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z126mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981072);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z131mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981120);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2494928|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2494928|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2494928|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2494928|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2494928|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2494928|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2494928|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2494928|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2494928|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2494928|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z129mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_ArrayP75mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981176);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z129mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981224);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z118mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981272);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2494928|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2494928|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2494928|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2494928|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2494928|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2494928|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2494928|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2494928|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2494928|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2494928|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z117mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981328);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z119mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981376);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2494928|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2494928|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z136mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981432);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1428,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1621200|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1621200|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981488);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z122mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981536);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z127mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981584);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2495424|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2495424|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2495424|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2495424|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2495424|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2495424|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2495424|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2495424|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2495424|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2495424|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z125mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_ArrayP71mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981640);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z125mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981688);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z114mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981736);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2495424|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2495424|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2495424|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2495424|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2495424|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2495424|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2495424|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2495424|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2495424|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2495424|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z113mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981792);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z115mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981840);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2495424|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2495424|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z132mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981896);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1429,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1623464|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1623464|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z112mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2981952);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z119mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982000);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z124mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982048);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2495840|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2495840|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2495840|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2495840|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2495840|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2495840|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2495840|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2495840|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2495840|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2495840|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z122mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_ArrayP68mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982104);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z122mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982152);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z111mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982200);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2495840|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2495840|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2495840|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2495840|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2495840|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2495840|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2495840|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2495840|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2495840|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2495840|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z110mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982256);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z112mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982304);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2495840|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2495840|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z129mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982360);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1430,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1625728|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1625728|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982416);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z115mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982464);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z120mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982512);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2500216|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2500216|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2500216|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2500216|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2500216|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2500216|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2500216|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2500216|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2500216|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2500216|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z118mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_ArrayP64mscorlib_System_Runtime_Serialization_StreamingContextStates_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982568);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z118mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982616);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z107mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982664);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2500216|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2500216|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2500216|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2500216|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2500216|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2500216|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2500216|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2500216|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2500216|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2500216|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z106mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982720);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z108mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982768);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2500216|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2500216|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z125mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982824);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1431,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1627992|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1627992|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z98mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982880);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z105mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982928);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z110mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2982976);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2508592|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2508592|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2508592|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2508592|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2508592|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2508592|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2508592|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2508592|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2508592|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2508592|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z108mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_ArrayP54mscorlib_System_Security_Principal_PrincipalPolicy_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2983032);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z108mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2983080);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z97mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2983128);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2508592|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2508592|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2508592|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2508592|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2508592|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2508592|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2508592|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2508592|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2508592|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2508592|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z96mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2983184);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z98mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2983232);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2508592|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2508592|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z115mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2983288);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1432,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1630256|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1630256|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL102mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_SecuritySafeCriticalAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL114mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_SecuritySafeCriticalAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2983448 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP58mscorlib_System_Security_SecuritySafeCriticalAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL112mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_SecuritySafeCriticalAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL101mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_SecuritySafeCriticalAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2983600 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL100mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayiP54mscorlib_System_Security_SecuritySafeCriticalAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayiP54mscorlib_System_Security_SecuritySafeCriticalAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2983704 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2983760 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2983912 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP67mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2984064 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2984168 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2984224 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL98mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL105mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP50mscorlib_System_Security_UnverifiableCodeAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL110mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP50mscorlib_System_Security_UnverifiableCodeAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2984376 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_UnverifiableCodeAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL108mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP50mscorlib_System_Security_UnverifiableCodeAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL97mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP50mscorlib_System_Security_UnverifiableCodeAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2984528 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayiP50mscorlib_System_Security_UnverifiableCodeAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayiP50mscorlib_System_Security_UnverifiableCodeAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2984632 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL115mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2984688 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2984736);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2984784);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2984832);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2552656|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2552656|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2552656|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2552656|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2552656|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2552656|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2552656|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2552656|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2552656|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2552656|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Threading_ThreadStateP21mscorlib_System_ArrayP41mscorlib_System_Threading_ThreadState_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2984888);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2984936);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2984984);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2552656|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2552656|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2552656|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2552656|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2552656|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2552656|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2552656|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2552656|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2552656|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2552656|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985040);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985088);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2552656|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2552656|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985144);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1436,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1639312|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1639312|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985200);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985248);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985296);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2563424|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2563424|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2563424|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2563424|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2563424|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2563424|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2563424|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2563424|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2563424|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2563424|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_AttributeTargetsP21mscorlib_System_ArrayP36mscorlib_System_AttributeTargets_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985352);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985400);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985448);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2563424|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2563424|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2563424|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2563424|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2563424|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2563424|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2563424|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2563424|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2563424|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2563424|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985504);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z80mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985552);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2563424|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2563424|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_AttributeTargetsP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985608);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1437,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1647528|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1647528|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985664);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985712);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985760);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2584336|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2584336|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2584336|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2584336|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2584336|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2584336|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2584336|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2584336|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2584336|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2584336|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DateTime_WhichP21mscorlib_System_ArrayP34mscorlib_System_DateTime_Which_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985816);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985864);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985912);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2584336|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2584336|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2584336|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2584336|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2584336|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2584336|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2584336|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2584336|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2584336|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2584336|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2985968);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986016);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2584336|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2584336|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DateTime_WhichP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986072);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1438,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1654416|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1654416|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z76mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986128);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986176);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z88mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986224);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2592568|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2592568|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2592568|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2592568|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592568|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2592568|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2592568|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2592568|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2592568|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2592568|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z86mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DateTimeKindP21mscorlib_System_ArrayP32mscorlib_System_DateTimeKind_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986280);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986328);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z75mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986376);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2592568|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2592568|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2592568|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2592568|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592568|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2592568|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2592568|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2592568|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2592568|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2592568|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z74mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986432);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z76mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986480);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2592568|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2592568|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z93mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DateTimeKindP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986536);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1439,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1656680|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1656680|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986592);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986640);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z85mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986688);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2595696|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2595696|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2595696|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2595696|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2595696|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2595696|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2595696|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2595696|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2595696|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2595696|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z83mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DayOfWeekP21mscorlib_System_ArrayP29mscorlib_System_DayOfWeek_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986744);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z83mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986792);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z72mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986840);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2595696|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2595696|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2595696|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2595696|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2595696|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2595696|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2595696|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2595696|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2595696|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2595696|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986896);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z73mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2986944);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2595696|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2595696|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z90mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DayOfWeekP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987000);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1441,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1663928|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1663928|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_FlagsAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP30mscorlib_System_FlagsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP30mscorlib_System_FlagsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2987160 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP34mscorlib_System_FlagsAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP30mscorlib_System_FlagsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP30mscorlib_System_FlagsAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2987312 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayiP30mscorlib_System_FlagsAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayiP30mscorlib_System_FlagsAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2987416 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_FlagsAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2987472 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z82mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987520);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z89mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987568);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z94mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987616);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2608552|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2608552|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2608552|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2608552|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2608552|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2608552|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2608552|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2608552|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2608552|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2608552|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_LoaderOptimizationP21mscorlib_System_ArrayP38mscorlib_System_LoaderOptimization_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987672);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z92mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987720);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987768);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2608552|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2608552|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2608552|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2608552|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2608552|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2608552|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2608552|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2608552|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2608552|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2608552|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z80mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987824);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987872);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2608552|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2608552|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_LoaderOptimizationP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2987928);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1443,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1673616|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1673616|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL72mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_MonoTypeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL79mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP24mscorlib_System_MonoType($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL84mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP24mscorlib_System_MonoType($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2988088 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL82mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP28mscorlib_System_MonoType_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL82mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP24mscorlib_System_MonoType($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL71mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP24mscorlib_System_MonoType($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2988240 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL70mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_MonoTypeP21mscorlib_System_ArrayiP24mscorlib_System_MonoType($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL72mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_MonoTypeP21mscorlib_System_ArrayiP24mscorlib_System_MonoType($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2988344 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL89mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_MonoTypeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2988400 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL86mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_NonSerializedAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP38mscorlib_System_NonSerializedAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP38mscorlib_System_NonSerializedAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2988552 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP42mscorlib_System_NonSerializedAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP38mscorlib_System_NonSerializedAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL85mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP38mscorlib_System_NonSerializedAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2988704 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayiP38mscorlib_System_NonSerializedAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL86mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayiP38mscorlib_System_NonSerializedAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2988808 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_NonSerializedAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2988864 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z74mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2988912);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z81mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2988960);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z86mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989008);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2636520|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2636520|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2636520|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2636520|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636520|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2636520|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2636520|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2636520|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2636520|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2636520|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z84mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_PlatformIDP21mscorlib_System_ArrayP30mscorlib_System_PlatformID_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989064);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z84mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989112);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z73mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989160);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2636520|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2636520|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2636520|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2636520|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2636520|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2636520|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2636520|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2636520|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2636520|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2636520|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z72mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_PlatformIDP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989216);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z74mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_PlatformIDP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989264);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2636520|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2636520|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z91mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_PlatformIDP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989320);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1446,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1680408|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1680408|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Object_gsharedP21mscorlib_System_Arrayi($__this,$index)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP37mscorlib_System_ThreadStaticAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item);
 STACKTOP = sp;return;
}
function __ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP37mscorlib_System_ThreadStaticAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2989480 + 40|0))>>2]|0;
 $1 = (__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP41mscorlib_System_ThreadStaticAttribute_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP26mscorlib_System_Object_arri($__this,$_____array,$index);
 STACKTOP = sp;return;
}
function __ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP37mscorlib_System_ThreadStaticAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_Object($__this,$item)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP37mscorlib_System_ThreadStaticAttribute($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2989632 + 40|0))>>2]|0;
 $1 = (__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayP22mscorlib_System_ObjectPPv($__this,$item,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayiP37mscorlib_System_ThreadStaticAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_Object($__this,$index,$item);
 STACKTOP = sp;return;
}
function __ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayiP37mscorlib_System_ThreadStaticAttribute($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2989736 + 40|0))>>2]|0;
 __Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayiP22mscorlib_System_ObjectPPv($__this,$index,$item,$0);
 STACKTOP = sp;return;
}
function __ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[((2989792 + 40|0))>>2]|0;
 $1 = (__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Object_gsharedP21mscorlib_System_ArrayPPv($__this,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __Z72mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi($__this,$index) {
 $__this = $__this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $V_0 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp + 4|0;
 $V_0 = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989840);
 HEAP32[$V_0>>2] = 0;
 __THREW__ = 0;
 invoke_v(994);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  $2 = (invoke_ii(1857,($__this|0))|0);
  $3 = __THREW__; __THREW__ = 0;
  $4 = $3&1;
  if (!($4)) {
   $5 = ($2|0)>($index|0);
   if ($5) {
    $18 = (($__this) + 16|0);
    $19 = HEAP32[$__this>>2]|0;
    $20 = (($19) + 28|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = (($21) + 92|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = Math_imul($23, $index)|0;
    $25 = (($18) + ($24)|0);
    _memcpy(($V_0|0),($25|0),($23|0))|0;
    $26 = HEAP32[$V_0>>2]|0;
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($26|0);
   }
   __THREW__ = 0;
   (invoke_ii(2996,(2561352|0))|0);
   $8 = __THREW__; __THREW__ = 0;
   $9 = $8&1;
   if (!($9)) {
    __THREW__ = 0;
    $10 = (invoke_ii(3469,(2561352|0))|0);
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if (!($12)) {
     $13 = HEAP32[3012544>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($10|0),($13|0));
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      invoke_vi(3852,($10|0));
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       // unreachable;
      }
     }
    }
   }
  }
 }
 $6 = ___cxa_find_matching_catch()|0;
 $7 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($6|0);
 // unreachable;
 return 0|0;
}
function __Z79mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989888);
 __THREW__ = 0;
 invoke_v(995);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012152>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z84mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $L_12 = 0, $L_6 = 0, $L_8 = 0, $V_1$011 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0;
 var $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 20|0;
 $_stackTraceSentry = sp;
 $V_2 = sp + 4|0;
 $L_6 = sp + 8|0;
 $L_8 = sp + 12|0;
 $L_12 = sp + 16|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989936);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(996);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1859,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)<(2);
    if (!($6)) {
     $11 = HEAP32[3012184>>2]|0;
     __THREW__ = 0;
     $12 = (invoke_iii(783,(0|0),($11|0))|0);
     $13 = __THREW__; __THREW__ = 0;
     $14 = $13&1;
     if ($14) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     $17 = (invoke_ii(3469,(2636920|0))|0);
     $18 = __THREW__; __THREW__ = 0;
     $19 = $18&1;
     if ($19) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($17|0),($12|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if ($21) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($17|0));
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if ($23) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $24 = (invoke_ii(1857,($__this|0))|0);
    $25 = __THREW__; __THREW__ = 0;
    $26 = $25&1;
    if (!($26)) {
     $27 = ($24|0)>(0);
     if (!($27)) {
      $$0 = 0;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     $28 = (($__this) + 16|0);
     $V_1$011 = 0;
     while(1) {
      $62 = HEAP32[$__this>>2]|0;
      $63 = (($62) + 28|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = (($64) + 92|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = Math_imul($66, $V_1$011)|0;
      $68 = (($28) + ($67)|0);
      _memcpy(($V_2|0),($68|0),($66|0))|0;
      $69 = HEAP32[$0>>2]|0;
      HEAP32[$L_6>>2] = $69;
      __THREW__ = 0;
      (invoke_ii(2996,(2656168|0))|0);
      $70 = __THREW__; __THREW__ = 0;
      $71 = $70&1;
      if ($71) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $29 = (invoke_iii(2724,(2656168|0),($L_6|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 4;
       break;
      }
      $32 = ($29|0)==(0|0);
      $33 = HEAP32[$V_2>>2]|0;
      if ($32) {
       label = 18;
       break;
      }
      HEAP32[$L_12>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2656168|0))|0);
      $40 = __THREW__; __THREW__ = 0;
      $41 = $40&1;
      if ($41) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $42 = (invoke_iii(2724,(2656168|0),($L_12|0))|0);
      $43 = __THREW__; __THREW__ = 0;
      $44 = $43&1;
      if ($44) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2656168|0))|0);
      $45 = __THREW__; __THREW__ = 0;
      $46 = $45&1;
      if ($46) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $47 = (invoke_iii(2724,(2656168|0),($0|0))|0);
      $48 = __THREW__; __THREW__ = 0;
      $49 = $48&1;
      if ($49) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      invoke_vi(3799,($47|0));
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      (invoke_ii(2996,(2656168|0))|0);
      $52 = __THREW__; __THREW__ = 0;
      $53 = $52&1;
      if ($53) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $54 = (invoke_iii(2724,(2656168|0),($0|0))|0);
      $55 = __THREW__; __THREW__ = 0;
      $56 = $55&1;
      if ($56) {
       label = 4;
       break;
      }
      __THREW__ = 0;
      $57 = (invoke_iiii(1644,(2148736|0),($54|0),($42|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 4;
       break;
      }
      $60 = (($V_1$011) + 1)|0;
      if ($57) {
       $$0 = 1;
       label = 32;
       break;
      }
      $61 = ($60|0)<($24|0);
      if ($61) {
       $V_1$011 = $60;
      } else {
       $$0 = 0;
       label = 32;
       break;
      }
     }
     if ((label|0) == 4) {
      $7 = ___cxa_find_matching_catch()|0;
      $8 = tempRet0;
      $lpad$phi$index = $7;$lpad$phi$index2 = $8;
      __ZN16StackTraceSentryD2Ev(0);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 18) {
      HEAP32[$L_8>>2] = $33;
      __THREW__ = 0;
      (invoke_ii(2996,(2656168|0))|0);
      $34 = __THREW__; __THREW__ = 0;
      $35 = $34&1;
      if ($35) {
       break;
      }
      __THREW__ = 0;
      $36 = (invoke_iii(2724,(2656168|0),($L_8|0))|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = ($36|0)==(0|0);
      $$0 = $39;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
     else if ((label|0) == 32) {
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 $lpad$phi$index = $9;$lpad$phi$index2 = $10;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z82mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_TypeCodeP21mscorlib_System_ArrayP28mscorlib_System_TypeCode_arri($__this,$_____array,$index) {
 $__this = $__this|0;
 $_____array = $_____array|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2989992);
 __THREW__ = 0;
 invoke_v(997);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 do {
  if (!($1)) {
   $2 = ($_____array|0)==(0|0);
   if ($2) {
    __THREW__ = 0;
    (invoke_ii(2996,(2560584|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     break;
    }
    __THREW__ = 0;
    $7 = (invoke_ii(3469,(2560584|0))|0);
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if ($9) {
     break;
    }
    $10 = HEAP32[3012200>>2]|0;
    __THREW__ = 0;
    invoke_vii(1925,($7|0),($10|0));
    $11 = __THREW__; __THREW__ = 0;
    $12 = $11&1;
    if ($12) {
     break;
    }
    __THREW__ = 0;
    invoke_vi(3852,($7|0));
    $13 = __THREW__; __THREW__ = 0;
    $14 = $13&1;
    if ($14) {
     break;
    }
    // unreachable;
   }
   __THREW__ = 0;
   $15 = (invoke_ii(1859,($__this|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if (!($17)) {
    $18 = ($15|0)<(2);
    if (!($18)) {
     $19 = HEAP32[3012208>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_iii(783,(0|0),($19|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if ($24) {
      break;
     }
     __THREW__ = 0;
     $25 = (invoke_ii(3469,(2636920|0))|0);
     $26 = __THREW__; __THREW__ = 0;
     $27 = $26&1;
     if ($27) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($25|0),($20|0));
     $28 = __THREW__; __THREW__ = 0;
     $29 = $28&1;
     if ($29) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($25|0));
     $30 = __THREW__; __THREW__ = 0;
     $31 = $30&1;
     if ($31) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $32 = (invoke_iii(753,($__this|0),0)|0);
    $33 = __THREW__; __THREW__ = 0;
    $34 = $33&1;
    if (!($34)) {
     $35 = (($32) + ($index))|0;
     __THREW__ = 0;
     invoke_vi(3799,($_____array|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     if (!($37)) {
      __THREW__ = 0;
      $38 = (invoke_iii(755,($_____array|0),0)|0);
      $39 = __THREW__; __THREW__ = 0;
      $40 = $39&1;
      if (!($40)) {
       __THREW__ = 0;
       invoke_vi(3799,($_____array|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        __THREW__ = 0;
        $43 = (invoke_iii(753,($_____array|0),0)|0);
        $44 = __THREW__; __THREW__ = 0;
        $45 = $44&1;
        if (!($45)) {
         $46 = (($43) + ($38))|0;
         $47 = ($35|0)>($46|0);
         if ($47) {
          __THREW__ = 0;
          (invoke_ii(2996,(2560072|0))|0);
          $48 = __THREW__; __THREW__ = 0;
          $49 = $48&1;
          if ($49) {
           break;
          }
          __THREW__ = 0;
          $50 = (invoke_ii(3469,(2560072|0))|0);
          $51 = __THREW__; __THREW__ = 0;
          $52 = $51&1;
          if ($52) {
           break;
          }
          $53 = HEAP32[3012216>>2]|0;
          __THREW__ = 0;
          invoke_vii(1924,($50|0),($53|0));
          $54 = __THREW__; __THREW__ = 0;
          $55 = $54&1;
          if ($55) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3852,($50|0));
          $56 = __THREW__; __THREW__ = 0;
          $57 = $56&1;
          if ($57) {
           break;
          }
          // unreachable;
         }
         __THREW__ = 0;
         invoke_vi(3799,($_____array|0));
         $58 = __THREW__; __THREW__ = 0;
         $59 = $58&1;
         if (!($59)) {
          __THREW__ = 0;
          $60 = (invoke_ii(1859,($_____array|0))|0);
          $61 = __THREW__; __THREW__ = 0;
          $62 = $61&1;
          if (!($62)) {
           $63 = ($60|0)<(2);
           if (!($63)) {
            $64 = HEAP32[3012224>>2]|0;
            __THREW__ = 0;
            $65 = (invoke_iii(783,(0|0),($64|0))|0);
            $66 = __THREW__; __THREW__ = 0;
            $67 = $66&1;
            if ($67) {
             break;
            }
            __THREW__ = 0;
            (invoke_ii(2996,(2636920|0))|0);
            $68 = __THREW__; __THREW__ = 0;
            $69 = $68&1;
            if ($69) {
             break;
            }
            __THREW__ = 0;
            $70 = (invoke_ii(3469,(2636920|0))|0);
            $71 = __THREW__; __THREW__ = 0;
            $72 = $71&1;
            if ($72) {
             break;
            }
            __THREW__ = 0;
            invoke_vii(1972,($70|0),($65|0));
            $73 = __THREW__; __THREW__ = 0;
            $74 = $73&1;
            if ($74) {
             break;
            }
            __THREW__ = 0;
            invoke_vi(3852,($70|0));
            $75 = __THREW__; __THREW__ = 0;
            $76 = $75&1;
            if ($76) {
             break;
            }
            // unreachable;
           }
           $77 = ($index|0)>(-1);
           if ($77) {
            __THREW__ = 0;
            $92 = (invoke_iii(755,($__this|0),0)|0);
            $93 = __THREW__; __THREW__ = 0;
            $94 = $93&1;
            if ($94) {
             break;
            }
            __THREW__ = 0;
            $95 = (invoke_iii(753,($__this|0),0)|0);
            $96 = __THREW__; __THREW__ = 0;
            $97 = $96&1;
            if ($97) {
             break;
            }
            __THREW__ = 0;
            invoke_viiiiii(55,(0|0),($__this|0),($92|0),($_____array|0),($index|0),($95|0));
            $98 = __THREW__; __THREW__ = 0;
            $99 = $98&1;
            if ($99) {
             break;
            }
            __ZN16StackTraceSentryD2Ev(0);
            STACKTOP = sp;return;
           }
           $78 = HEAP32[3012240>>2]|0;
           __THREW__ = 0;
           $79 = (invoke_iii(783,(0|0),($78|0))|0);
           $80 = __THREW__; __THREW__ = 0;
           $81 = $80&1;
           if (!($81)) {
            __THREW__ = 0;
            (invoke_ii(2996,(2561352|0))|0);
            $82 = __THREW__; __THREW__ = 0;
            $83 = $82&1;
            if (!($83)) {
             __THREW__ = 0;
             $84 = (invoke_ii(3469,(2561352|0))|0);
             $85 = __THREW__; __THREW__ = 0;
             $86 = $85&1;
             if (!($86)) {
              $87 = HEAP32[3012232>>2]|0;
              __THREW__ = 0;
              invoke_viii(644,($84|0),($87|0),($79|0));
              $88 = __THREW__; __THREW__ = 0;
              $89 = $88&1;
              if (!($89)) {
               __THREW__ = 0;
               invoke_vi(3852,($84|0));
               $90 = __THREW__; __THREW__ = 0;
               $91 = $90&1;
               if (!($91)) {
                // unreachable;
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $3 = ___cxa_find_matching_catch()|0;
 $4 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($3|0);
 // unreachable;
}
function __Z82mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2990040);
 __THREW__ = 0;
 invoke_v(998);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012168>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
 return 0|0;
}
function __Z71mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi($__this,$item) {
 $__this = $__this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $L_17 = 0, $L_6 = 0, $L_8 = 0, $V_1$013 = 0, $V_2 = 0, $_stackTraceSentry = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $V_2 = sp;
 $L_6 = sp + 4|0;
 $L_8 = sp + 8|0;
 $L_17 = sp + 12|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2990088);
 HEAP32[$V_2>>2] = 0;
 __THREW__ = 0;
 invoke_v(999);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   __THREW__ = 0;
   $2 = (invoke_ii(1859,($__this|0))|0);
   $3 = __THREW__; __THREW__ = 0;
   $4 = $3&1;
   if (!($4)) {
    $5 = ($2|0)<(2);
    if (!($5)) {
     $10 = HEAP32[3012528>>2]|0;
     __THREW__ = 0;
     $11 = (invoke_iii(783,(0|0),($10|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     __THREW__ = 0;
     (invoke_ii(2996,(2636920|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if ($15) {
      break;
     }
     __THREW__ = 0;
     $16 = (invoke_ii(3469,(2636920|0))|0);
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     __THREW__ = 0;
     invoke_vii(1972,($16|0),($11|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($16|0));
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if ($22) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    $23 = (invoke_ii(1857,($__this|0))|0);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     $26 = ($23|0)>(0);
     L13: do {
      if ($26) {
       $27 = (($__this) + 16|0);
       $V_1$013 = 0;
       while(1) {
        $73 = HEAP32[$__this>>2]|0;
        $74 = (($73) + 28|0);
        $75 = HEAP32[$74>>2]|0;
        $76 = (($75) + 92|0);
        $77 = HEAP32[$76>>2]|0;
        $78 = Math_imul($77, $V_1$013)|0;
        $79 = (($27) + ($78)|0);
        _memcpy(($V_2|0),($79|0),($77|0))|0;
        HEAP32[$L_6>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2656168|0))|0);
        $80 = __THREW__; __THREW__ = 0;
        $81 = $80&1;
        if ($81) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $28 = (invoke_iii(2724,(2656168|0),($L_6|0))|0);
        $29 = __THREW__; __THREW__ = 0;
        $30 = $29&1;
        if ($30) {
         label = 4;
         break;
        }
        $31 = ($28|0)==(0|0);
        if ($31) {
         label = 18;
         break;
        }
        HEAP32[$L_17>>2] = $item;
        __THREW__ = 0;
        (invoke_ii(2996,(2656168|0))|0);
        $47 = __THREW__; __THREW__ = 0;
        $48 = $47&1;
        if ($48) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $49 = (invoke_iii(2724,(2656168|0),($L_17|0))|0);
        $50 = __THREW__; __THREW__ = 0;
        $51 = $50&1;
        if ($51) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2656168|0))|0);
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if ($53) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $54 = (invoke_iii(2724,(2656168|0),($V_2|0))|0);
        $55 = __THREW__; __THREW__ = 0;
        $56 = $55&1;
        if ($56) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        invoke_vi(3799,($54|0));
        $57 = __THREW__; __THREW__ = 0;
        $58 = $57&1;
        if ($58) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        (invoke_ii(2996,(2656168|0))|0);
        $59 = __THREW__; __THREW__ = 0;
        $60 = $59&1;
        if ($60) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $61 = (invoke_iii(2724,(2656168|0),($V_2|0))|0);
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         label = 4;
         break;
        }
        __THREW__ = 0;
        $64 = (invoke_iiii(1644,(2148736|0),($61|0),($49|0))|0);
        $65 = __THREW__; __THREW__ = 0;
        $66 = $65&1;
        if ($66) {
         label = 4;
         break;
        }
        $67 = (($V_1$013) + 1)|0;
        if ($64) {
         label = 34;
         break;
        }
        $72 = ($67|0)<($23|0);
        if ($72) {
         $V_1$013 = $67;
        } else {
         break L13;
        }
       }
       if ((label|0) == 4) {
        $6 = ___cxa_find_matching_catch()|0;
        $7 = tempRet0;
        $lpad$phi$index = $6;$lpad$phi$index2 = $7;
        __ZN16StackTraceSentryD2Ev(0);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       }
       else if ((label|0) == 18) {
        $32 = HEAP32[$V_2>>2]|0;
        HEAP32[$L_8>>2] = $32;
        __THREW__ = 0;
        (invoke_ii(2996,(2656168|0))|0);
        $33 = __THREW__; __THREW__ = 0;
        $34 = $33&1;
        if ($34) {
         break L1;
        }
        __THREW__ = 0;
        $35 = (invoke_iii(2724,(2656168|0),($L_8|0))|0);
        $36 = __THREW__; __THREW__ = 0;
        $37 = $36&1;
        if ($37) {
         break L1;
        }
        $38 = ($35|0)==(0|0);
        if ($38) {
         __THREW__ = 0;
         $39 = (invoke_iii(755,($__this|0),0)|0);
         $40 = __THREW__; __THREW__ = 0;
         $41 = $40&1;
         if ($41) {
          break L1;
         }
         $42 = (($39) + ($V_1$013))|0;
         $$0 = $42;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        } else {
         __THREW__ = 0;
         $43 = (invoke_iii(755,($__this|0),0)|0);
         $44 = __THREW__; __THREW__ = 0;
         $45 = $44&1;
         if ($45) {
          break L1;
         }
         $46 = (($43) + -1)|0;
         $$0 = $46;
         __ZN16StackTraceSentryD2Ev(0);
         STACKTOP = sp;return ($$0|0);
        }
       }
       else if ((label|0) == 34) {
        __THREW__ = 0;
        $68 = (invoke_iii(755,($__this|0),0)|0);
        $69 = __THREW__; __THREW__ = 0;
        $70 = $69&1;
        if ($70) {
         break L1;
        }
        $71 = (($68) + ($V_1$013))|0;
        $$0 = $71;
        __ZN16StackTraceSentryD2Ev(0);
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     __THREW__ = 0;
     $82 = (invoke_iii(755,($__this|0),0)|0);
     $83 = __THREW__; __THREW__ = 0;
     $84 = $83&1;
     if (!($84)) {
      $85 = (($82) + -1)|0;
      $$0 = $85;
      __ZN16StackTraceSentryD2Ev(0);
      STACKTOP = sp;return ($$0|0);
     }
    }
   }
  }
 } while(0);
 $8 = ___cxa_find_matching_catch()|0;
 $9 = tempRet0;
 $lpad$phi$index = $8;$lpad$phi$index2 = $9;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
 return 0|0;
}
function __Z70mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_TypeCodeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_stackTraceSentry = sp;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2990144);
 __THREW__ = 0;
 invoke_v(1000);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  (invoke_ii(2996,(2622808|0))|0);
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   __THREW__ = 0;
   $4 = (invoke_ii(3469,(2622808|0))|0);
   $5 = __THREW__; __THREW__ = 0;
   $6 = $5&1;
   if (!($6)) {
    $7 = HEAP32[3012496>>2]|0;
    __THREW__ = 0;
    invoke_vii(1954,($4|0),($7|0));
    $8 = __THREW__; __THREW__ = 0;
    $9 = $8&1;
    if (!($9)) {
     __THREW__ = 0;
     invoke_vi(3852,($4|0));
     $10 = __THREW__; __THREW__ = 0;
     $11 = $10&1;
     if (!($11)) {
      // unreachable;
     }
    }
   }
  }
 }
 $12 = ___cxa_find_matching_catch()|0;
 $13 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($12|0);
 // unreachable;
}
function __Z72mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_TypeCodeP21mscorlib_System_Arrayii($__this,$index,$item) {
 $__this = $__this|0;
 $index = $index|0;
 $item = $item|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $L_3 = 0, $_stackTraceSentry = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $_stackTraceSentry = sp;
 $L_3 = sp + 4|0;
 HEAP32[$0>>2] = $item;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2990192);
 __THREW__ = 0;
 invoke_v(1001);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 do {
  if (!($2)) {
   __THREW__ = 0;
   $3 = (invoke_ii(1857,($__this|0))|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if (!($5)) {
    $6 = ($3|0)>($index|0);
    if (!($6)) {
     __THREW__ = 0;
     (invoke_ii(2996,(2561352|0))|0);
     $9 = __THREW__; __THREW__ = 0;
     $10 = $9&1;
     if ($10) {
      break;
     }
     __THREW__ = 0;
     $11 = (invoke_ii(3469,(2561352|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      break;
     }
     $14 = HEAP32[3012560>>2]|0;
     __THREW__ = 0;
     invoke_vii(1926,($11|0),($14|0));
     $15 = __THREW__; __THREW__ = 0;
     $16 = $15&1;
     if ($16) {
      break;
     }
     __THREW__ = 0;
     invoke_vi(3852,($11|0));
     $17 = __THREW__; __THREW__ = 0;
     $18 = $17&1;
     if ($18) {
      break;
     }
     // unreachable;
    }
    __THREW__ = 0;
    (invoke_ii(2996,(1167664|0))|0);
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if (!($20)) {
     __THREW__ = 0;
     $21 = (invoke_iii(2735,($__this|0),(1167664|0))|0);
     $22 = __THREW__; __THREW__ = 0;
     $23 = $22&1;
     if (!($23)) {
      $24 = ($21|0)==(0|0);
      if ($24) {
       $49 = (($__this) + 16|0);
       $50 = HEAP32[$__this>>2]|0;
       $51 = (($50) + 28|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($52) + 92|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = Math_imul($54, $index)|0;
       $56 = (($49) + ($55)|0);
       _memcpy(($56|0),($0|0),($54|0))|0;
       __ZN16StackTraceSentryD2Ev(0);
       STACKTOP = sp;return;
      }
      HEAP32[$L_3>>2] = $item;
      __THREW__ = 0;
      (invoke_ii(2996,(2656168|0))|0);
      $25 = __THREW__; __THREW__ = 0;
      $26 = $25&1;
      if (!($26)) {
       __THREW__ = 0;
       $27 = (invoke_iii(2724,(2656168|0),($L_3|0))|0);
       $28 = __THREW__; __THREW__ = 0;
       $29 = $28&1;
       if (!($29)) {
        __THREW__ = 0;
        invoke_vi(3799,($21|0));
        $30 = __THREW__; __THREW__ = 0;
        $31 = $30&1;
        if (!($31)) {
         $32 = ($index|0)<(0);
         if ($32) {
          label = 18;
         } else {
          $33 = (($21) + 12|0);
          $34 = HEAP32[$33>>2]|0;
          $35 = ($34>>>0)>($index>>>0);
          if (!($35)) {
           label = 18;
          }
         }
         if ((label|0) == 18) {
          __THREW__ = 0;
          $36 = (invoke_i(132)|0);
          $37 = __THREW__; __THREW__ = 0;
          $38 = $37&1;
          if ($38) {
           break;
          }
          __THREW__ = 0;
          invoke_vi(3302,($36|0));
          $39 = __THREW__; __THREW__ = 0;
          $40 = $39&1;
          if ($40) {
           break;
          }
         }
         __THREW__ = 0;
         invoke_vii(3492,($21|0),($27|0));
         $41 = __THREW__; __THREW__ = 0;
         $42 = $41&1;
         if (!($42)) {
          $43 = HEAP32[$21>>2]|0;
          $44 = (($21) + 16|0);
          $45 = (($43) + 92|0);
          $46 = HEAP32[$45>>2]|0;
          $47 = Math_imul($46, $index)|0;
          $48 = (($44) + ($47)|0);
          HEAP32[$48>>2] = $27;
          __ZN16StackTraceSentryD2Ev(0);
          STACKTOP = sp;return;
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $7 = ___cxa_find_matching_catch()|0;
 $8 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($7|0);
 // unreachable;
}
function __Z89mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_TypeCodeP21mscorlib_System_Array($__this) {
 $__this = $__this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $L_0 = 0, $L_1 = 0, $_stackTraceSentry = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $_stackTraceSentry = sp + 16|0;
 $L_0 = sp;
 $L_1 = sp + 8|0;
 __ZN16StackTraceSentryC2EP10MethodInfo($_stackTraceSentry,2990248);
 $0 = $L_0;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 __THREW__ = 0;
 invoke_vii(1448,($L_0|0),($__this|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = $L_0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $L_1;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  __THREW__ = 0;
  (invoke_ii(2996,(1694344|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if (!($17)) {
   __THREW__ = 0;
   $18 = (invoke_iii(2724,(1694344|0),($L_1|0))|0);
   $19 = __THREW__; __THREW__ = 0;
   $20 = $19&1;
   if (!($20)) {
    __ZN16StackTraceSentryD2Ev(0);
    STACKTOP = sp;return ($18|0);
   }
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZN16StackTraceSentryD2Ev(0);
 ___resumeException($21|0);
 // unreachable;
 return 0|0;
}
function __Z19_il2cpp_strinit_s_2v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2990320>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990328,7)|0);
 HEAP32[2990304>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990344,7)|0);
 HEAP32[2990312>>2] = $3;
 HEAP8[2990320>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_3v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2990456>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990464,9)|0);
 HEAP32[2990360>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990488,10)|0);
 HEAP32[2990368>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990512,12)|0);
 HEAP32[2990376>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990536,11)|0);
 HEAP32[2990384>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990536,11)|0);
 HEAP32[2990392>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990512,12)|0);
 HEAP32[2990400>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990488,10)|0);
 HEAP32[2990408>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990464,9)|0);
 HEAP32[2990416>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990560,15)|0);
 HEAP32[2990424>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990592,7)|0);
 HEAP32[2990432>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990608,2)|0);
 HEAP32[2990440>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990616,8)|0);
 HEAP32[2990448>>2] = $13;
 HEAP8[2990456>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_0v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2990696>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990704,4)|0);
 HEAP32[2990632>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[2990640>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990720,1)|0);
 HEAP32[2990648>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990728,9)|0);
 HEAP32[2990656>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990752,9)|0);
 HEAP32[2990664>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990776,7)|0);
 HEAP32[2990672>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990792,13)|0);
 HEAP32[2990680>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990824,14)|0);
 HEAP32[2990688>>2] = $9;
 HEAP8[2990696>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2990864>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990872,3)|0);
 HEAP32[2990856>>2] = $2;
 HEAP8[2990864>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_4v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2990944>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990952,66)|0);
 HEAP32[2990880>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991088,4)|0);
 HEAP32[2990888>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991096,5)|0);
 HEAP32[2990896>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991112,4)|0);
 HEAP32[2990904>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991120,10)|0);
 HEAP32[2990912>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991144,13)|0);
 HEAP32[2990920>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991176,5)|0);
 HEAP32[2990928>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991192,25)|0);
 HEAP32[2990936>>2] = $9;
 HEAP8[2990944>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2991256>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991264,55)|0);
 HEAP32[2991248>>2] = $2;
 HEAP8[2991256>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_6v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2991592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991600,18)|0);
 HEAP32[2991376>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991640,1)|0);
 HEAP32[2991384>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991640,1)|0);
 HEAP32[2991392>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991120,10)|0);
 HEAP32[2991400>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991144,13)|0);
 HEAP32[2991408>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991176,5)|0);
 HEAP32[2991416>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991648,1)|0);
 HEAP32[2991424>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2991432>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991664,1)|0);
 HEAP32[2991440>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991640,1)|0);
 HEAP32[2991448>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991672,2)|0);
 HEAP32[2991456>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990720,1)|0);
 HEAP32[2991464>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2991472>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2991480>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991664,1)|0);
 HEAP32[2991488>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991680,1)|0);
 HEAP32[2991496>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991688,1)|0);
 HEAP32[2991504>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2991512>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991664,1)|0);
 HEAP32[2991520>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990720,1)|0);
 HEAP32[2991528>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2991536>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2991544>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991664,1)|0);
 HEAP32[2991552>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991696,1)|0);
 HEAP32[2991560>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991088,4)|0);
 HEAP32[2991568>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991096,5)|0);
 HEAP32[2991576>>2] = $27;
 $28 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991112,4)|0);
 HEAP32[2991584>>2] = $28;
 HEAP8[2991592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2991728>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991736,17)|0);
 HEAP32[2991704>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991776,25)|0);
 HEAP32[2991712>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991832,53)|0);
 HEAP32[2991720>>2] = $4;
 HEAP8[2991728>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2991952>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991640,1)|0);
 HEAP32[2991944>>2] = $2;
 HEAP8[2991952>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_9v() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2992032>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992040,4)|0);
 HEAP32[2991960>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992048,40)|0);
 HEAP32[2991968>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992128,10)|0);
 HEAP32[2991976>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992152,17)|0);
 HEAP32[2991984>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992040,4)|0);
 HEAP32[2991992>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992048,40)|0);
 HEAP32[2992000>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992128,10)|0);
 HEAP32[2992008>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992152,17)|0);
 HEAP32[2992016>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992192,34)|0);
 HEAP32[2992024>>2] = $10;
 HEAP8[2992032>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2992296>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992264>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992272>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992280>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992288>>2] = $5;
 HEAP8[2992296>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2992336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992320>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992328>>2] = $3;
 HEAP8[2992336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_Cv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2992368>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992344>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992352>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2992360>>2] = $4;
 HEAP8[2992368>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2992432>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992384>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992392>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992400>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992408>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2992416>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2992424>>2] = $7;
 HEAP8[2992432>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2992472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992440>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992448>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2992456>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992480,1)|0);
 HEAP32[2992464>>2] = $5;
 HEAP8[2992472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z19_il2cpp_strinit_s_Fv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2992552>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992488>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2992496>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992504>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2992512>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2992520>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2992528>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992480,1)|0);
 HEAP32[2992536>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992480,1)|0);
 HEAP32[2992544>>2] = $9;
 HEAP8[2992552>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_10v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2992688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992696,3)|0);
 HEAP32[2992560>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992704,3)|0);
 HEAP32[2992568>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992712,3)|0);
 HEAP32[2992576>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992720,3)|0);
 HEAP32[2992584>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992728,3)|0);
 HEAP32[2992592>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992736,3)|0);
 HEAP32[2992600>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992744,3)|0);
 HEAP32[2992608>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992752,3)|0);
 HEAP32[2992616>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992760,3)|0);
 HEAP32[2992624>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992768,3)|0);
 HEAP32[2992632>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992776,3)|0);
 HEAP32[2992640>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992784,3)|0);
 HEAP32[2992648>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992792,3)|0);
 HEAP32[2992656>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992800,3)|0);
 HEAP32[2992664>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992808,3)|0);
 HEAP32[2992672>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992816,3)|0);
 HEAP32[2992680>>2] = $17;
 HEAP8[2992688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_11v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992696,3)|0);
 HEAP32[2992824>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992696,3)|0);
 HEAP32[2992832>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992704,3)|0);
 HEAP32[2992840>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992704,3)|0);
 HEAP32[2992848>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992712,3)|0);
 HEAP32[2992856>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992712,3)|0);
 HEAP32[2992864>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992720,3)|0);
 HEAP32[2992872>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992720,3)|0);
 HEAP32[2992880>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992728,3)|0);
 HEAP32[2992888>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992728,3)|0);
 HEAP32[2992896>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992736,3)|0);
 HEAP32[2992904>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992736,3)|0);
 HEAP32[2992912>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992744,3)|0);
 HEAP32[2992920>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992744,3)|0);
 HEAP32[2992928>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992752,3)|0);
 HEAP32[2992936>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992752,3)|0);
 HEAP32[2992944>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992760,3)|0);
 HEAP32[2992952>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992760,3)|0);
 HEAP32[2992960>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992768,3)|0);
 HEAP32[2992968>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992768,3)|0);
 HEAP32[2992976>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992776,3)|0);
 HEAP32[2992984>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992776,3)|0);
 HEAP32[2992992>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992784,3)|0);
 HEAP32[2993000>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992784,3)|0);
 HEAP32[2993008>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992792,3)|0);
 HEAP32[2993016>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992792,3)|0);
 HEAP32[2993024>>2] = $27;
 $28 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992800,3)|0);
 HEAP32[2993032>>2] = $28;
 $29 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992800,3)|0);
 HEAP32[2993040>>2] = $29;
 $30 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992808,3)|0);
 HEAP32[2993048>>2] = $30;
 $31 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992808,3)|0);
 HEAP32[2993056>>2] = $31;
 $32 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992816,3)|0);
 HEAP32[2993064>>2] = $32;
 $33 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992816,3)|0);
 HEAP32[2993072>>2] = $33;
 HEAP8[2993080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_12v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992480,1)|0);
 HEAP32[2993088>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2993096>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2993104>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2993112>>2] = $5;
 HEAP8[2993120>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_13v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993192>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2993128>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2993136>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2993144>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2993152>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2993160>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992376,1)|0);
 HEAP32[2993168>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992480,1)|0);
 HEAP32[2993176>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992480,1)|0);
 HEAP32[2993184>>2] = $9;
 HEAP8[2993192>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_14v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993232>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993240,1)|0);
 HEAP32[2993200>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993248,1)|0);
 HEAP32[2993208>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993256,1)|0);
 HEAP32[2993216>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993264,1)|0);
 HEAP32[2993224>>2] = $5;
 HEAP8[2993232>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_15v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993240,1)|0);
 HEAP32[2993272>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993248,1)|0);
 HEAP32[2993280>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993256,1)|0);
 HEAP32[2993288>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993264,1)|0);
 HEAP32[2993296>>2] = $5;
 HEAP8[2993304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_16v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993320>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[2993312>>2] = $2;
 HEAP8[2993320>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_17v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[2993344>>2] = $2;
 HEAP8[2993352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_18v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993392>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2993360>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2993368>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993400,6)|0);
 HEAP32[2993376>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993416,5)|0);
 HEAP32[2993384>>2] = $5;
 HEAP8[2993392>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_19v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993464>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992304,1)|0);
 HEAP32[2993432>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2992312,1)|0);
 HEAP32[2993440>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993400,6)|0);
 HEAP32[2993448>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993416,5)|0);
 HEAP32[2993456>>2] = $5;
 HEAP8[2993464>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_1Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993504>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993512,6)|0);
 HEAP32[2993472>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993528,4)|0);
 HEAP32[2993480>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993536,5)|0);
 HEAP32[2993488>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993552,3)|0);
 HEAP32[2993496>>2] = $5;
 HEAP8[2993504>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_1Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993512,6)|0);
 HEAP32[2993560>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993528,4)|0);
 HEAP32[2993568>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993536,5)|0);
 HEAP32[2993576>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993552,3)|0);
 HEAP32[2993584>>2] = $5;
 HEAP8[2993592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_1Cv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993640,7)|0);
 HEAP32[2993600>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993656,7)|0);
 HEAP32[2993608>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993640,7)|0);
 HEAP32[2993616>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993656,7)|0);
 HEAP32[2993624>>2] = $5;
 HEAP8[2993632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_1Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993696,6)|0);
 HEAP32[2993672>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993712,6)|0);
 HEAP32[2993680>>2] = $3;
 HEAP8[2993688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_1Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993736>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993744,6)|0);
 HEAP32[2993728>>2] = $2;
 HEAP8[2993736>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_1Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993768>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993776,18)|0);
 HEAP32[2993760>>2] = $2;
 HEAP8[2993768>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_20v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993848,10)|0);
 HEAP32[2993816>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993872,8)|0);
 HEAP32[2993824>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993888,4)|0);
 HEAP32[2993832>>2] = $4;
 HEAP8[2993840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_21v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993920>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993848,10)|0);
 HEAP32[2993896>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993872,8)|0);
 HEAP32[2993904>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993888,4)|0);
 HEAP32[2993912>>2] = $4;
 HEAP8[2993920>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_22v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2993944>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993952,55)|0);
 HEAP32[2993928>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2994064,86)|0);
 HEAP32[2993936>>2] = $3;
 HEAP8[2993944>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_23v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2994248>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2994256,5)|0);
 HEAP32[2994240>>2] = $2;
 HEAP8[2994248>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_24v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2994312>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2994320,93)|0);
 HEAP32[2994272>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2994512,48)|0);
 HEAP32[2994280>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2994608,48)|0);
 HEAP32[2994288>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2994704,47)|0);
 HEAP32[2994296>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2994800,86)|0);
 HEAP32[2994304>>2] = $6;
 HEAP8[2994312>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_25v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2994992>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993872,8)|0);
 HEAP32[2994976>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993848,10)|0);
 HEAP32[2994984>>2] = $3;
 HEAP8[2994992>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_26v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995008>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995016,7)|0);
 HEAP32[2995000>>2] = $2;
 HEAP8[2995008>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_27v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995048>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993888,4)|0);
 HEAP32[2995032>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995056,16)|0);
 HEAP32[2995040>>2] = $3;
 HEAP8[2995048>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_28v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995104>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993888,4)|0);
 HEAP32[2995088>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995112,7)|0);
 HEAP32[2995096>>2] = $3;
 HEAP8[2995104>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_29v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995144>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993872,8)|0);
 HEAP32[2995128>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993848,10)|0);
 HEAP32[2995136>>2] = $3;
 HEAP8[2995144>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_2Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995160>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995168,6)|0);
 HEAP32[2995152>>2] = $2;
 HEAP8[2995160>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_2Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995240>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995248,3)|0);
 HEAP32[2995184>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995256,12)|0);
 HEAP32[2995192>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995280,6)|0);
 HEAP32[2995200>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995296,10)|0);
 HEAP32[2995208>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995320,6)|0);
 HEAP32[2995216>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995336,10)|0);
 HEAP32[2995224>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995360,10)|0);
 HEAP32[2995232>>2] = $8;
 HEAP8[2995240>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_2Cv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995448>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995456,11)|0);
 HEAP32[2995384>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995480,17)|0);
 HEAP32[2995392>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995520,9)|0);
 HEAP32[2995400>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995544,11)|0);
 HEAP32[2995408>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995568,11)|0);
 HEAP32[2995416>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995592,11)|0);
 HEAP32[2995424>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995616,12)|0);
 HEAP32[2995432>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995568,11)|0);
 HEAP32[2995440>>2] = $9;
 HEAP8[2995448>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_2Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995696,12)|0);
 HEAP32[2995640>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995720,12)|0);
 HEAP32[2995648>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995744,7)|0);
 HEAP32[2995656>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995760,17)|0);
 HEAP32[2995664>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995800,9)|0);
 HEAP32[2995672>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995824,26)|0);
 HEAP32[2995680>>2] = $7;
 HEAP8[2995688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_2Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995888>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2995880>>2] = $2;
 HEAP8[2995888>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_2Fv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2995952>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2995960,61)|0);
 HEAP32[2995896>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996088,97)|0);
 HEAP32[2995904>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2995912>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996288,2)|0);
 HEAP32[2995920>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996296,11)|0);
 HEAP32[2995928>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2995936>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2995944>>2] = $8;
 HEAP8[2995952>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_30v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2996448>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996456,14)|0);
 HEAP32[2996320>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996488,50)|0);
 HEAP32[2996328>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996592,4)|0);
 HEAP32[2996336>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996600,27)|0);
 HEAP32[2996344>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996656,25)|0);
 HEAP32[2996352>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996712,29)|0);
 HEAP32[2996360>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991688,1)|0);
 HEAP32[2996368>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991696,1)|0);
 HEAP32[2996376>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996776,3)|0);
 HEAP32[2996384>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996784,3)|0);
 HEAP32[2996392>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991696,1)|0);
 HEAP32[2996400>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996792,25)|0);
 HEAP32[2996408>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996848,5)|0);
 HEAP32[2996416>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996864,5)|0);
 HEAP32[2996424>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[2996432>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2996440>>2] = $17;
 HEAP8[2996448>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_31v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2996976>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[2996888>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996992,1)|0);
 HEAP32[2996896>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997000,1)|0);
 HEAP32[2996904>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[2996912>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[2996920>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997008,5)|0);
 HEAP32[2996928>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997024,11)|0);
 HEAP32[2996936>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996864,5)|0);
 HEAP32[2996944>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996992,1)|0);
 HEAP32[2996952>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[2996960>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2996968>>2] = $12;
 HEAP8[2996976>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_32v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2997056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997064,31)|0);
 HEAP32[2997048>>2] = $2;
 HEAP8[2997056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_33v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2997144>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997152,67)|0);
 HEAP32[2997128>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997288,45)|0);
 HEAP32[2997136>>2] = $3;
 HEAP8[2997144>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_34v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2997512>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991112,4)|0);
 HEAP32[2997384>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997520,1)|0);
 HEAP32[2997392>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997528,2)|0);
 HEAP32[2997400>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991640,1)|0);
 HEAP32[2997408>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997536,2)|0);
 HEAP32[2997416>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2997424>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997544,2)|0);
 HEAP32[2997432>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997552,1)|0);
 HEAP32[2997440>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997560,2)|0);
 HEAP32[2997448>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997568,1)|0);
 HEAP32[2997456>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997576,1)|0);
 HEAP32[2997464>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997584,1)|0);
 HEAP32[2997472>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997592,4)|0);
 HEAP32[2997480>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997600,10)|0);
 HEAP32[2997488>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[2997496>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[2997504>>2] = $17;
 HEAP8[2997512>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_35v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2997632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[2997624>>2] = $2;
 HEAP8[2997632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_36v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2997648>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[2997640>>2] = $2;
 HEAP8[2997648>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_37v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2997688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997696,36)|0);
 HEAP32[2997664>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997768,37)|0);
 HEAP32[2997672>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997848,30)|0);
 HEAP32[2997680>>2] = $4;
 HEAP8[2997688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_38v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2997936>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997696,36)|0);
 HEAP32[2997912>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997768,37)|0);
 HEAP32[2997920>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997848,30)|0);
 HEAP32[2997928>>2] = $4;
 HEAP8[2997936>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_39v() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2998016>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[2997944>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998024,30)|0);
 HEAP32[2997952>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998088,4)|0);
 HEAP32[2997960>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998096,10)|0);
 HEAP32[2997968>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998120,1)|0);
 HEAP32[2997976>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998128,1)|0);
 HEAP32[2997984>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998136,5)|0);
 HEAP32[2997992>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998120,1)|0);
 HEAP32[2998000>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998128,1)|0);
 HEAP32[2998008>>2] = $10;
 HEAP8[2998016>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_3Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2998192>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[2998152>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998200,10)|0);
 HEAP32[2998160>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998224,3)|0);
 HEAP32[2998168>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991656,1)|0);
 HEAP32[2998176>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991680,1)|0);
 HEAP32[2998184>>2] = $6;
 HEAP8[2998192>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_3Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2998240>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998248,50)|0);
 HEAP32[2998232>>2] = $2;
 HEAP8[2998240>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_3Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2998360>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998368,21)|0);
 HEAP32[2998352>>2] = $2;
 HEAP8[2998360>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_3Dv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2998736>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998744,3)|0);
 HEAP32[2998416>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998744,3)|0);
 HEAP32[2998424>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998752,6)|0);
 HEAP32[2998432>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998752,6)|0);
 HEAP32[2998440>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998768,6)|0);
 HEAP32[2998448>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998768,6)|0);
 HEAP32[2998456>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998784,5)|0);
 HEAP32[2998464>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998784,5)|0);
 HEAP32[2998472>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998800,6)|0);
 HEAP32[2998480>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998800,6)|0);
 HEAP32[2998488>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998816,9)|0);
 HEAP32[2998496>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998816,9)|0);
 HEAP32[2998504>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998840,8)|0);
 HEAP32[2998512>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998840,8)|0);
 HEAP32[2998520>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998856,16)|0);
 HEAP32[2998528>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998856,16)|0);
 HEAP32[2998536>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998888,21)|0);
 HEAP32[2998544>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998888,21)|0);
 HEAP32[2998552>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998936,14)|0);
 HEAP32[2998560>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998936,14)|0);
 HEAP32[2998568>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998968,19)|0);
 HEAP32[2998576>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998968,19)|0);
 HEAP32[2998584>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999008,19)|0);
 HEAP32[2998592>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999008,19)|0);
 HEAP32[2998600>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999048,24)|0);
 HEAP32[2998608>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999048,24)|0);
 HEAP32[2998616>>2] = $27;
 $28 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999096,29)|0);
 HEAP32[2998624>>2] = $28;
 $29 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999096,29)|0);
 HEAP32[2998632>>2] = $29;
 $30 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999160,30)|0);
 HEAP32[2998640>>2] = $30;
 $31 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999160,30)|0);
 HEAP32[2998648>>2] = $31;
 $32 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999224,17)|0);
 HEAP32[2998656>>2] = $32;
 $33 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999224,17)|0);
 HEAP32[2998664>>2] = $33;
 $34 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999264,22)|0);
 HEAP32[2998672>>2] = $34;
 $35 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999264,22)|0);
 HEAP32[2998680>>2] = $35;
 $36 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999312,25)|0);
 HEAP32[2998688>>2] = $36;
 $37 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999312,25)|0);
 HEAP32[2998696>>2] = $37;
 $38 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999368,27)|0);
 HEAP32[2998704>>2] = $38;
 $39 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999368,27)|0);
 HEAP32[2998712>>2] = $39;
 $40 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999424,10)|0);
 HEAP32[2998720>>2] = $40;
 $41 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999424,10)|0);
 HEAP32[2998728>>2] = $41;
 HEAP8[2998736>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_3Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2999472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999480,22)|0);
 HEAP32[2999448>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999528,11)|0);
 HEAP32[2999456>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999552,2)|0);
 HEAP32[2999464>>2] = $4;
 HEAP8[2999472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_3Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2999568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999576,15)|0);
 HEAP32[2999560>>2] = $2;
 HEAP8[2999568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_40v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2999616>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999624,36)|0);
 HEAP32[2999608>>2] = $2;
 HEAP8[2999616>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_41v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2999704>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999712,14)|0);
 HEAP32[2999696>>2] = $2;
 HEAP8[2999704>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_42v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[2999800>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999808,54)|0);
 HEAP32[2999744>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999920,6)|0);
 HEAP32[2999752>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999936,13)|0);
 HEAP32[2999760>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2999968,13)|0);
 HEAP32[2999768>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000000,11)|0);
 HEAP32[2999776>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000024,41)|0);
 HEAP32[2999784>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000112,17)|0);
 HEAP32[2999792>>2] = $8;
 HEAP8[2999800>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_43v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000160>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000168,16)|0);
 HEAP32[3000152>>2] = $2;
 HEAP8[3000160>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_44v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000216,24)|0);
 HEAP32[3000200>>2] = $2;
 HEAP8[3000208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_45v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000272>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000280,15)|0);
 HEAP32[3000264>>2] = $2;
 HEAP8[3000272>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_46v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000320>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000328,36)|0);
 HEAP32[3000312>>2] = $2;
 HEAP8[3000320>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_47v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000408>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000416,24)|0);
 HEAP32[3000400>>2] = $2;
 HEAP8[3000408>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_48v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000480,32)|0);
 HEAP32[3000464>>2] = $2;
 HEAP8[3000472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_49v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000552>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000560,49)|0);
 HEAP32[3000544>>2] = $2;
 HEAP8[3000552>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_4Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000672>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000680,21)|0);
 HEAP32[3000664>>2] = $2;
 HEAP8[3000672>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_4Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000736>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000680,21)|0);
 HEAP32[3000728>>2] = $2;
 HEAP8[3000736>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_4Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3000752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000760,118)|0);
 HEAP32[3000744>>2] = $2;
 HEAP8[3000752>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_4Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001008>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001016,70)|0);
 HEAP32[3001000>>2] = $2;
 HEAP8[3001008>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_4Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001168>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001176,25)|0);
 HEAP32[3001160>>2] = $2;
 HEAP8[3001168>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_4Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001240>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001176,25)|0);
 HEAP32[3001232>>2] = $2;
 HEAP8[3001240>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_50v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001256>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3000480,32)|0);
 HEAP32[3001248>>2] = $2;
 HEAP8[3001256>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_51v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001272>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001280,21)|0);
 HEAP32[3001264>>2] = $2;
 HEAP8[3001272>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_52v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001344,6)|0);
 HEAP32[3001328>>2] = $2;
 HEAP8[3001336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_53v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001368>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001344,6)|0);
 HEAP32[3001360>>2] = $2;
 HEAP8[3001368>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_54v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001392>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001400,21)|0);
 HEAP32[3001376>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991640,1)|0);
 HEAP32[3001384>>2] = $3;
 HEAP8[3001392>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_55v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001456>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001464,4)|0);
 HEAP32[3001448>>2] = $2;
 HEAP8[3001456>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_56v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001480>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001464,4)|0);
 HEAP32[3001472>>2] = $2;
 HEAP8[3001480>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_57v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001496>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001504,100)|0);
 HEAP32[3001488>>2] = $2;
 HEAP8[3001496>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_58v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001712>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001720,102)|0);
 HEAP32[3001704>>2] = $2;
 HEAP8[3001712>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_59v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3001936>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3001944,101)|0);
 HEAP32[3001928>>2] = $2;
 HEAP8[3001936>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2D4v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002160>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002168,14)|0);
 HEAP32[3002152>>2] = $2;
 HEAP8[3002160>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2D0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002216,8)|0);
 HEAP32[3002200>>2] = $2;
 HEAP8[3002208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2D1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002264>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3002232>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3002240>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002304,46)|0);
 HEAP32[3002248>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002400,53)|0);
 HEAP32[3002256>>2] = $5;
 HEAP8[3002264>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2D2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002520>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002528,20)|0);
 HEAP32[3002512>>2] = $2;
 HEAP8[3002520>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2D3v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002576>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002584,53)|0);
 HEAP32[3002568>>2] = $2;
 HEAP8[3002576>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_5Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002704>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002712,69)|0);
 HEAP32[3002696>>2] = $2;
 HEAP8[3002704>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_5Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002864>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3002856>>2] = $2;
 HEAP8[3002864>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_5Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002904>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002912,27)|0);
 HEAP32[3002896>>2] = $2;
 HEAP8[3002904>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_5Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3002984>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3002968>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003000,18)|0);
 HEAP32[3002976>>2] = $3;
 HEAP8[3002984>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_5Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3003056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003064,83)|0);
 HEAP32[3003040>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003232,24)|0);
 HEAP32[3003048>>2] = $3;
 HEAP8[3003056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_5Fv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3003296>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3003280>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3003288>>2] = $3;
 HEAP8[3003296>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_60v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3003376>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003384,42)|0);
 HEAP32[3003368>>2] = $2;
 HEAP8[3003376>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_61v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3003496>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3003472>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3003480>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3003488>>2] = $4;
 HEAP8[3003496>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_62v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3003512>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3003504>>2] = $2;
 HEAP8[3003512>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_63v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3003528>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003536,27)|0);
 HEAP32[3003520>>2] = $2;
 HEAP8[3003528>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_64v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3003680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3003592>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003688,56)|0);
 HEAP32[3003600>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003800,62)|0);
 HEAP32[3003608>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003928,62)|0);
 HEAP32[3003616>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3003624>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3003632>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004056,57)|0);
 HEAP32[3003640>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004176,88)|0);
 HEAP32[3003648>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004352,69)|0);
 HEAP32[3003656>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004496,79)|0);
 HEAP32[3003664>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004656,12)|0);
 HEAP32[3003672>>2] = $12;
 HEAP8[3003680>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_65v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3004688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3004680>>2] = $2;
 HEAP8[3004688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_66v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3004704>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004712,29)|0);
 HEAP32[3004696>>2] = $2;
 HEAP8[3004704>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_67v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3004808>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3004776>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3004784>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3004792>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004816,15)|0);
 HEAP32[3004800>>2] = $5;
 HEAP8[3004808>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_68v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3004856>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3004848>>2] = $2;
 HEAP8[3004856>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_69v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3004872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004880,29)|0);
 HEAP32[3004864>>2] = $2;
 HEAP8[3004872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_6Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3004976>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3004944>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3004952>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3004960>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3004816,15)|0);
 HEAP32[3004968>>2] = $5;
 HEAP8[3004976>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_6Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3004992>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3004984>>2] = $2;
 HEAP8[3004992>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_6Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005008>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005016,27)|0);
 HEAP32[3005000>>2] = $2;
 HEAP8[3005008>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_6Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005088,16)|0);
 HEAP32[3005072>>2] = $2;
 HEAP8[3005080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_6Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005128>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3005120>>2] = $2;
 HEAP8[3005128>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_6Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005144>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005152,28)|0);
 HEAP32[3005136>>2] = $2;
 HEAP8[3005144>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_70v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005216>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3005208>>2] = $2;
 HEAP8[3005216>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_71v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005232>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3005224>>2] = $2;
 HEAP8[3005232>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_72v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005248>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005256,27)|0);
 HEAP32[3005240>>2] = $2;
 HEAP8[3005248>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_73v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005320>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3003304,29)|0);
 HEAP32[3005312>>2] = $2;
 HEAP8[3005320>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_74v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3005328>>2] = $2;
 HEAP8[3005336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_75v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005360,29)|0);
 HEAP32[3005344>>2] = $2;
 HEAP8[3005352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_76v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005432>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005088,16)|0);
 HEAP32[3005424>>2] = $2;
 HEAP8[3005432>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_77v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005448>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3005440>>2] = $2;
 HEAP8[3005448>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_78v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005464>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005472,26)|0);
 HEAP32[3005456>>2] = $2;
 HEAP8[3005464>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_79v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005544>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3005528>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005552,35)|0);
 HEAP32[3005536>>2] = $3;
 HEAP8[3005544>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_7Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005640,7)|0);
 HEAP32[3005624>>2] = $2;
 HEAP8[3005632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_7Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005664>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(0,0)|0);
 HEAP32[3005656>>2] = $2;
 HEAP8[3005664>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_7Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005688,4)|0);
 HEAP32[3005672>>2] = $2;
 HEAP8[3005680>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_7Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005744>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3005696>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005776,3)|0);
 HEAP32[3005704>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3005712>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005776,3)|0);
 HEAP32[3005720>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3005728>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005800,46)|0);
 HEAP32[3005736>>2] = $7;
 HEAP8[3005744>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_7Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005904>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3005896>>2] = $2;
 HEAP8[3005904>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_7Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3005936>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3005928>>2] = $2;
 HEAP8[3005936>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_80v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006008>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3005944>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006016,19)|0);
 HEAP32[3005952>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3005960>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006016,19)|0);
 HEAP32[3005968>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3005976>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006056,31)|0);
 HEAP32[3005984>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3005992>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006120,33)|0);
 HEAP32[3006000>>2] = $9;
 HEAP8[3006008>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_81v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006200>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005640,7)|0);
 HEAP32[3006192>>2] = $2;
 HEAP8[3006200>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_82v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006216>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005640,7)|0);
 HEAP32[3006208>>2] = $2;
 HEAP8[3006216>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_83v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006232>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3006224>>2] = $2;
 HEAP8[3006232>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_84v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006272>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3006240>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005776,3)|0);
 HEAP32[3006248>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3006256>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006280,24)|0);
 HEAP32[3006264>>2] = $5;
 HEAP8[3006272>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_85v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3006328>>2] = $2;
 HEAP8[3006336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_86v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006384>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3006344>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3006352>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006392,59)|0);
 HEAP32[3006360>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3006368>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006512,59)|0);
 HEAP32[3006376>>2] = $6;
 HEAP8[3006384>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_87v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3006632>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3006640>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006688,20)|0);
 HEAP32[3006648>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3006656>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006688,20)|0);
 HEAP32[3006664>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006728,26)|0);
 HEAP32[3006672>>2] = $7;
 HEAP8[3006680>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_88v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006800>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006808,10)|0);
 HEAP32[3006784>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005776,3)|0);
 HEAP32[3006792>>2] = $3;
 HEAP8[3006800>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_89v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3006832>>2] = $2;
 HEAP8[3006840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_8Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3006864>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006872,8)|0);
 HEAP32[3006848>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006888,29)|0);
 HEAP32[3006856>>2] = $3;
 HEAP8[3006864>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_8Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007000>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3006952>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006016,19)|0);
 HEAP32[3006960>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3006968>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006016,19)|0);
 HEAP32[3006976>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3006984>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007008,32)|0);
 HEAP32[3006992>>2] = $7;
 HEAP8[3007000>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_8Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005640,7)|0);
 HEAP32[3007072>>2] = $2;
 HEAP8[3007080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_8Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007128,6)|0);
 HEAP32[3007088>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007144,4)|0);
 HEAP32[3007096>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007152,101)|0);
 HEAP32[3007104>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007360,41)|0);
 HEAP32[3007112>>2] = $5;
 HEAP8[3007120>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_8Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007456>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007144,4)|0);
 HEAP32[3007448>>2] = $2;
 HEAP8[3007456>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_8Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007480,6)|0);
 HEAP32[3007464>>2] = $2;
 HEAP8[3007472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_90v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007520>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3007496>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3007504>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007528,70)|0);
 HEAP32[3007512>>2] = $4;
 HEAP8[3007520>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_91v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007704>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007360,41)|0);
 HEAP32[3007672>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007360,41)|0);
 HEAP32[3007680>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007360,41)|0);
 HEAP32[3007688>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007360,41)|0);
 HEAP32[3007696>>2] = $5;
 HEAP8[3007704>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_92v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007720>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007728,3)|0);
 HEAP32[3007712>>2] = $2;
 HEAP8[3007720>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_93v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007760,9)|0);
 HEAP32[3007736>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007784,28)|0);
 HEAP32[3007744>>2] = $3;
 HEAP8[3007752>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_94v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3007872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007880,3)|0);
 HEAP32[3007840>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007888,39)|0);
 HEAP32[3007848>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007880,3)|0);
 HEAP32[3007856>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007888,39)|0);
 HEAP32[3007864>>2] = $5;
 HEAP8[3007872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_95v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3007968>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008064,29)|0);
 HEAP32[3007976>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3007984>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008064,29)|0);
 HEAP32[3007992>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3008000>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008128,60)|0);
 HEAP32[3008008>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3008016>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007880,3)|0);
 HEAP32[3008024>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008128,60)|0);
 HEAP32[3008032>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3008040>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008128,60)|0);
 HEAP32[3008048>>2] = $12;
 HEAP8[3008056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_96v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008272>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3008248>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3008256>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3008264>>2] = $4;
 HEAP8[3008272>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_97v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3008280>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3008288>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006016,19)|0);
 HEAP32[3008296>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3008304>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3006016,19)|0);
 HEAP32[3008312>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3008320>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008344,61)|0);
 HEAP32[3008328>>2] = $8;
 HEAP8[3008336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_98v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008480>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3008472>>2] = $2;
 HEAP8[3008480>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_99v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008496>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3008488>>2] = $2;
 HEAP8[3008496>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_9Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008512>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008520,29)|0);
 HEAP32[3008504>>2] = $2;
 HEAP8[3008512>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_9Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3008584>>2] = $2;
 HEAP8[3008592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_9Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008608>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008616,28)|0);
 HEAP32[3008600>>2] = $2;
 HEAP8[3008608>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_9Dv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3008672>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008760,42)|0);
 HEAP32[3008680>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008848,17)|0);
 HEAP32[3008688>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008888,20)|0);
 HEAP32[3008696>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008928,14)|0);
 HEAP32[3008704>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008928,14)|0);
 HEAP32[3008712>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008928,14)|0);
 HEAP32[3008720>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008928,14)|0);
 HEAP32[3008728>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008928,14)|0);
 HEAP32[3008736>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008960,12)|0);
 HEAP32[3008744>>2] = $11;
 HEAP8[3008752>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_9Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3008992>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009000,30)|0);
 HEAP32[3008984>>2] = $2;
 HEAP8[3008992>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_9Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009072>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009080,72)|0);
 HEAP32[3009064>>2] = $2;
 HEAP8[3009072>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009232>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009080,72)|0);
 HEAP32[3009224>>2] = $2;
 HEAP8[3009232>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009248>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3009240>>2] = $2;
 HEAP8[3009248>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009264>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009272,33)|0);
 HEAP32[3009256>>2] = $2;
 HEAP8[3009264>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A3v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009360>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009368,41)|0);
 HEAP32[3009344>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[3009352>>2] = $3;
 HEAP8[3009360>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A4v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009464>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009472,29)|0);
 HEAP32[3009456>>2] = $2;
 HEAP8[3009464>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009544>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009552,33)|0);
 HEAP32[3009536>>2] = $2;
 HEAP8[3009544>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A6v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009640,16)|0);
 HEAP32[3009624>>2] = $2;
 HEAP8[3009632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009696,15)|0);
 HEAP32[3009672>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009728,29)|0);
 HEAP32[3009680>>2] = $3;
 HEAP8[3009688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A8v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009816>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3009792>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009824,50)|0);
 HEAP32[3009800>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009928,5)|0);
 HEAP32[3009808>>2] = $4;
 HEAP8[3009816>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_A9v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3009968>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3009976,29)|0);
 HEAP32[3009944>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010040,29)|0);
 HEAP32[3009952>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010104,1)|0);
 HEAP32[3009960>>2] = $4;
 HEAP8[3009968>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_AAv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010128,1)|0);
 HEAP32[3010112>>2] = $2;
 HEAP8[3010120>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_ABv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010144>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010128,1)|0);
 HEAP32[3010136>>2] = $2;
 HEAP8[3010144>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_ACv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010168>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010176,5)|0);
 HEAP32[3010152>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010192,4)|0);
 HEAP32[3010160>>2] = $3;
 HEAP8[3010168>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_ADv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3010200>>2] = $2;
 HEAP8[3010208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_AEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010224>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010232,24)|0);
 HEAP32[3010216>>2] = $2;
 HEAP8[3010224>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_AFv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010296>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3010280>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010304,60)|0);
 HEAP32[3010288>>2] = $3;
 HEAP8[3010296>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B0v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010440>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3010424>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3010432>>2] = $3;
 HEAP8[3010440>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010464>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010472,28)|0);
 HEAP32[3010456>>2] = $2;
 HEAP8[3010464>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B2v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010544>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3010528>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010552,7)|0);
 HEAP32[3010536>>2] = $3;
 HEAP8[3010544>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B3v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010576>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010584,28)|0);
 HEAP32[3010568>>2] = $2;
 HEAP8[3010576>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B4v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010648>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010584,28)|0);
 HEAP32[3010640>>2] = $2;
 HEAP8[3010648>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010664>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3010656>>2] = $2;
 HEAP8[3010664>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010704>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010712,8)|0);
 HEAP32[3010672>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3010680>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010728,29)|0);
 HEAP32[3010688>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010712,8)|0);
 HEAP32[3010696>>2] = $5;
 HEAP8[3010704>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010816>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010712,8)|0);
 HEAP32[3010792>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010728,29)|0);
 HEAP32[3010800>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010712,8)|0);
 HEAP32[3010808>>2] = $4;
 HEAP8[3010816>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3010832>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010840,92)|0);
 HEAP32[3010824>>2] = $2;
 HEAP8[3010832>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_B9v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3011032>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010128,1)|0);
 HEAP32[3011024>>2] = $2;
 HEAP8[3011032>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_BAv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3011048>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010128,1)|0);
 HEAP32[3011040>>2] = $2;
 HEAP8[3011048>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_BBv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3011064>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010128,1)|0);
 HEAP32[3011056>>2] = $2;
 HEAP8[3011064>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_BCv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3011080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010128,1)|0);
 HEAP32[3011072>>2] = $2;
 HEAP8[3011080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_BDv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3011224>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011232,2)|0);
 HEAP32[3011088>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011240,2)|0);
 HEAP32[3011096>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011232,2)|0);
 HEAP32[3011104>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011240,2)|0);
 HEAP32[3011112>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011248,2)|0);
 HEAP32[3011120>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011256,2)|0);
 HEAP32[3011128>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011248,2)|0);
 HEAP32[3011136>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011256,2)|0);
 HEAP32[3011144>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011264,2)|0);
 HEAP32[3011152>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011272,2)|0);
 HEAP32[3011160>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011264,2)|0);
 HEAP32[3011168>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011272,2)|0);
 HEAP32[3011176>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011280,3)|0);
 HEAP32[3011184>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011288,3)|0);
 HEAP32[3011192>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011280,3)|0);
 HEAP32[3011200>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011288,3)|0);
 HEAP32[3011208>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011296,34)|0);
 HEAP32[3011216>>2] = $18;
 HEAP8[3011224>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_BEv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3011440>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011448,1)|0);
 HEAP32[3011368>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3011376>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3011384>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3011392>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3011400>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3011408>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3011416>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3011424>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3011432>>2] = $10;
 HEAP8[3011440>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_BFv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3011528>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010712,8)|0);
 HEAP32[3011456>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3011464>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007128,6)|0);
 HEAP32[3011472>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010728,29)|0);
 HEAP32[3011480>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010712,8)|0);
 HEAP32[3011488>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010840,92)|0);
 HEAP32[3011496>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011536,126)|0);
 HEAP32[3011504>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011792,61)|0);
 HEAP32[3011512>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011792,61)|0);
 HEAP32[3011520>>2] = $10;
 HEAP8[3011528>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3011936>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3011920>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3011928>>2] = $3;
 HEAP8[3011936>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C2v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012048>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3012032>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3012040>>2] = $3;
 HEAP8[3012048>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C3v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012064>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3012056>>2] = $2;
 HEAP8[3012064>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C4v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3012072>>2] = $2;
 HEAP8[3012080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012096>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012104,23)|0);
 HEAP32[3012088>>2] = $2;
 HEAP8[3012096>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2ABv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012160>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012104,23)|0);
 HEAP32[3012152>>2] = $2;
 HEAP8[3012160>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2AEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012176>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012104,23)|0);
 HEAP32[3012168>>2] = $2;
 HEAP8[3012176>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2ACv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012192>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3012184>>2] = $2;
 HEAP8[3012192>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2ADv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012248>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3012200>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3012208>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012256,96)|0);
 HEAP32[3012216>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3012224>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3012232>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3012240>>2] = $7;
 HEAP8[3012248>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012504>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012104,23)|0);
 HEAP32[3012496>>2] = $2;
 HEAP8[3012504>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C6v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012520>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012104,23)|0);
 HEAP32[3012512>>2] = $2;
 HEAP8[3012520>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2AFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012536>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3012528>>2] = $2;
 HEAP8[3012536>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2AAv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012552>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3012544>>2] = $2;
 HEAP8[3012552>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3012560>>2] = $2;
 HEAP8[3012568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012600,38)|0);
 HEAP32[3012576>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012680,59)|0);
 HEAP32[3012584>>2] = $3;
 HEAP8[3012592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C8v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012816>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3012800>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3012808>>2] = $3;
 HEAP8[3012816>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C9v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3012944>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012952,6)|0);
 HEAP32[3012912>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3012920>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012968,6)|0);
 HEAP32[3012928>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3012936>>2] = $5;
 HEAP8[3012944>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_CAv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3013032>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012952,6)|0);
 HEAP32[3012984>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3012992>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012968,6)|0);
 HEAP32[3013000>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3013008>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013040,6)|0);
 HEAP32[3013016>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3013024>>2] = $7;
 HEAP8[3013032>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_CBv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3013072>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3013056>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3013064>>2] = $3;
 HEAP8[3013072>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_CCv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3013112>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012952,6)|0);
 HEAP32[3013080>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3013088>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012968,6)|0);
 HEAP32[3013096>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3013104>>2] = $5;
 HEAP8[3013112>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_CDv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3013168>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012952,6)|0);
 HEAP32[3013120>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3013128>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012968,6)|0);
 HEAP32[3013136>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3013144>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013040,6)|0);
 HEAP32[3013152>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3013160>>2] = $7;
 HEAP8[3013168>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_CEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3013192>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012600,38)|0);
 HEAP32[3013176>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013200,63)|0);
 HEAP32[3013184>>2] = $3;
 HEAP8[3013192>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_CFv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3013376>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013384,11)|0);
 HEAP32[3013328>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013408,7)|0);
 HEAP32[3013336>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013424,44)|0);
 HEAP32[3013344>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013384,11)|0);
 HEAP32[3013352>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013512,26)|0);
 HEAP32[3013360>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013568,42)|0);
 HEAP32[3013368>>2] = $7;
 HEAP8[3013376>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D0v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3013760>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013384,11)|0);
 HEAP32[3013656>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013408,7)|0);
 HEAP32[3013664>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013768,11)|0);
 HEAP32[3013672>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013424,44)|0);
 HEAP32[3013680>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013384,11)|0);
 HEAP32[3013688>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013512,26)|0);
 HEAP32[3013696>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013568,42)|0);
 HEAP32[3013704>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013792,34)|0);
 HEAP32[3013712>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013864,28)|0);
 HEAP32[3013720>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013408,7)|0);
 HEAP32[3013728>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013920,26)|0);
 HEAP32[3013736>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013408,7)|0);
 HEAP32[3013744>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013976,46)|0);
 HEAP32[3013752>>2] = $14;
 HEAP8[3013760>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014088>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3007480,6)|0);
 HEAP32[3014072>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014096,48)|0);
 HEAP32[3014080>>2] = $3;
 HEAP8[3014088>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014200>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013408,7)|0);
 HEAP32[3014192>>2] = $2;
 HEAP8[3014200>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D3v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014216>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014224,7)|0);
 HEAP32[3014208>>2] = $2;
 HEAP8[3014216>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D4v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014248>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014224,7)|0);
 HEAP32[3014240>>2] = $2;
 HEAP8[3014248>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D5v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014280>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3014256>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3014264>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014288,35)|0);
 HEAP32[3014272>>2] = $4;
 HEAP8[3014280>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014384>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3014360>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3014368>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014392,56)|0);
 HEAP32[3014376>>2] = $4;
 HEAP8[3014384>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3014504>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3014512>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3014520>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014576,44)|0);
 HEAP32[3014528>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3014536>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3014544>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014664,55)|0);
 HEAP32[3014552>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014776,34)|0);
 HEAP32[3014560>>2] = $9;
 HEAP8[3014568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D8v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014912>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3014848>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3014856>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3014864>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014576,44)|0);
 HEAP32[3014872>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3014880>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3014888>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014664,55)|0);
 HEAP32[3014896>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014392,56)|0);
 HEAP32[3014904>>2] = $9;
 HEAP8[3014912>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_D9v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3014928>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014936,28)|0);
 HEAP32[3014920>>2] = $2;
 HEAP8[3014928>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_DAv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015024>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3014992>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015032,10)|0);
 HEAP32[3015000>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015056,19)|0);
 HEAP32[3015008>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015096,21)|0);
 HEAP32[3015016>>2] = $5;
 HEAP8[3015024>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_DBv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015160>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015168,11)|0);
 HEAP32[3015144>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015192,16)|0);
 HEAP32[3015152>>2] = $3;
 HEAP8[3015160>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_DCv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015328>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015168,11)|0);
 HEAP32[3015224>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015192,16)|0);
 HEAP32[3015232>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3015240>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3015248>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015336,11)|0);
 HEAP32[3015256>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3015264>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015360,16)|0);
 HEAP32[3015272>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3015280>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3015288>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015392,95)|0);
 HEAP32[3015296>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3013864,28)|0);
 HEAP32[3015304>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015584,32)|0);
 HEAP32[3015312>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015584,32)|0);
 HEAP32[3015320>>2] = $14;
 HEAP8[3015328>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_DDv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015712>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015168,11)|0);
 HEAP32[3015648>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015192,16)|0);
 HEAP32[3015656>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015336,11)|0);
 HEAP32[3015664>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015720,27)|0);
 HEAP32[3015672>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015360,16)|0);
 HEAP32[3015680>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015720,27)|0);
 HEAP32[3015688>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3015696>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3015704>>2] = $9;
 HEAP8[3015712>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_DEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015792>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3015776>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3015784>>2] = $3;
 HEAP8[3015792>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_DFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015808>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015800>>2] = $2;
 HEAP8[3015808>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015824>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015816>>2] = $2;
 HEAP8[3015824>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015848>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015832>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3015840>>2] = $3;
 HEAP8[3015848>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015864>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015856>>2] = $2;
 HEAP8[3015864>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E3v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015880>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015872>>2] = $2;
 HEAP8[3015880>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E4v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015904>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015888>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3015896>>2] = $3;
 HEAP8[3015904>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015920>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015912>>2] = $2;
 HEAP8[3015920>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015944>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015928>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3015936>>2] = $3;
 HEAP8[3015944>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E7v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015960>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015952>>2] = $2;
 HEAP8[3015960>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3015976>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015984,4)|0);
 HEAP32[3015968>>2] = $2;
 HEAP8[3015976>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_E9v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016000>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3015992>>2] = $2;
 HEAP8[3016000>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_EAv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016016>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015984,4)|0);
 HEAP32[3016008>>2] = $2;
 HEAP8[3016016>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_EBv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016064>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3015984,4)|0);
 HEAP32[3016024>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3016032>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3016040>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3016048>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016072,32)|0);
 HEAP32[3016056>>2] = $6;
 HEAP8[3016064>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_ECv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016184>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3016136>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3016144>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012256,96)|0);
 HEAP32[3016152>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011944,43)|0);
 HEAP32[3016160>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3016168>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3016176>>2] = $7;
 HEAP8[3016184>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_EDv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3016192>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012824,41)|0);
 HEAP32[3016200>>2] = $3;
 HEAP8[3016208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016240>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3016232>>2] = $2;
 HEAP8[3016240>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3016248>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3016256>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014576,44)|0);
 HEAP32[3016264>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3016272>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3012448,21)|0);
 HEAP32[3016280>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014664,55)|0);
 HEAP32[3016288>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3014936,28)|0);
 HEAP32[3016296>>2] = $8;
 HEAP8[3016304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B4v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016320>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3016312>>2] = $2;
 HEAP8[3016320>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3016328>>2] = $2;
 HEAP8[3016336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016360>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016368,42)|0);
 HEAP32[3016344>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016456,28)|0);
 HEAP32[3016352>>2] = $3;
 HEAP8[3016360>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_C0v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016528>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016536,28)|0);
 HEAP32[3016512>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016592,29)|0);
 HEAP32[3016520>>2] = $3;
 HEAP8[3016528>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_EEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016664>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016672,8)|0);
 HEAP32[3016656>>2] = $2;
 HEAP8[3016664>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_EFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016696>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3016688>>2] = $2;
 HEAP8[3016696>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016720>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3016712>>2] = $2;
 HEAP8[3016720>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3016728>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016760,5)|0);
 HEAP32[3016736>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016760,5)|0);
 HEAP32[3016744>>2] = $4;
 HEAP8[3016752>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3016776>>2] = $2;
 HEAP8[3016784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F3v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016816>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3016792>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016760,5)|0);
 HEAP32[3016800>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016760,5)|0);
 HEAP32[3016808>>2] = $4;
 HEAP8[3016816>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F4v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016760,5)|0);
 HEAP32[3016824>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016760,5)|0);
 HEAP32[3016832>>2] = $3;
 HEAP8[3016840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3016856>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016864,47)|0);
 HEAP32[3016848>>2] = $2;
 HEAP8[3016856>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3017008>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017016,29)|0);
 HEAP32[3016960>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017080,13)|0);
 HEAP32[3016968>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017112,155)|0);
 HEAP32[3016976>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017080,13)|0);
 HEAP32[3016984>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017080,13)|0);
 HEAP32[3016992>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017080,13)|0);
 HEAP32[3017000>>2] = $7;
 HEAP8[3017008>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F7v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3017432>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017440,35)|0);
 HEAP32[3017424>>2] = $2;
 HEAP8[3017432>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F8v() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3017584>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017592,9)|0);
 HEAP32[3017512>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017616,2)|0);
 HEAP32[3017520>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017624,16)|0);
 HEAP32[3017528>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017656,6)|0);
 HEAP32[3017536>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017616,2)|0);
 HEAP32[3017544>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017672,14)|0);
 HEAP32[3017552>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017704,12)|0);
 HEAP32[3017560>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017728,12)|0);
 HEAP32[3017568>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017752,11)|0);
 HEAP32[3017576>>2] = $10;
 HEAP8[3017584>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_F9v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3017872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3017776>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017880,9)|0);
 HEAP32[3017784>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017904,7)|0);
 HEAP32[3017792>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017920,14)|0);
 HEAP32[3017800>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017952,7)|0);
 HEAP32[3017808>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017968,16)|0);
 HEAP32[3017816>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018000,22)|0);
 HEAP32[3017824>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018048,16)|0);
 HEAP32[3017832>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018080,7)|0);
 HEAP32[3017840>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018096,6)|0);
 HEAP32[3017848>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018112,15)|0);
 HEAP32[3017856>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018144,4)|0);
 HEAP32[3017864>>2] = $13;
 HEAP8[3017872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_FAv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3018184>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996288,2)|0);
 HEAP32[3018152>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018192,6)|0);
 HEAP32[3018160>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018208,42)|0);
 HEAP32[3018168>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018296,44)|0);
 HEAP32[3018176>>2] = $5;
 HEAP8[3018184>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_FBv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3018456>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3018384>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991688,1)|0);
 HEAP32[3018392>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990720,1)|0);
 HEAP32[3018400>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991696,1)|0);
 HEAP32[3018408>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018464,2)|0);
 HEAP32[3018416>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3018424>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3018432>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3018440>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[3018448>>2] = $10;
 HEAP8[3018456>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_FCv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3018496>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3018472>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018504,45)|0);
 HEAP32[3018480>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018600,8)|0);
 HEAP32[3018488>>2] = $4;
 HEAP8[3018496>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_FDv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3018640>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3018616>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018504,45)|0);
 HEAP32[3018624>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018648,7)|0);
 HEAP32[3018632>>2] = $4;
 HEAP8[3018640>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_FEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3018672>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018680,46)|0);
 HEAP32[3018664>>2] = $2;
 HEAP8[3018672>>0] = 1;
 STACKTOP = sp;return;
}
function __Z20_il2cpp_strinit_s_FFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3018784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018792,36)|0);
 HEAP32[3018776>>2] = $2;
 HEAP8[3018784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2D6v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3018872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018880,34)|0);
 HEAP32[3018864>>2] = $2;
 HEAP8[3018872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_100v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3018968>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018976,18)|0);
 HEAP32[3018952>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019016,23)|0);
 HEAP32[3018960>>2] = $3;
 HEAP8[3018968>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_101v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3019072>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019080,109)|0);
 HEAP32[3019064>>2] = $2;
 HEAP8[3019072>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_102v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3019336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019344,6)|0);
 HEAP32[3019304>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019360,6)|0);
 HEAP32[3019312>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019376,2)|0);
 HEAP32[3019320>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019384,2)|0);
 HEAP32[3019328>>2] = $5;
 HEAP8[3019336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_103v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3019512>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019344,6)|0);
 HEAP32[3019392>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019360,6)|0);
 HEAP32[3019400>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019376,2)|0);
 HEAP32[3019408>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019384,2)|0);
 HEAP32[3019416>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019520,6)|0);
 HEAP32[3019424>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019536,6)|0);
 HEAP32[3019432>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019552,5)|0);
 HEAP32[3019440>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019568,5)|0);
 HEAP32[3019448>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019584,17)|0);
 HEAP32[3019456>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019344,6)|0);
 HEAP32[3019464>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019360,6)|0);
 HEAP32[3019472>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019376,2)|0);
 HEAP32[3019480>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019384,2)|0);
 HEAP32[3019488>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019568,5)|0);
 HEAP32[3019496>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019624,22)|0);
 HEAP32[3019504>>2] = $16;
 HEAP8[3019512>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_104v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3019688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019696,35)|0);
 HEAP32[3019672>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019768,3)|0);
 HEAP32[3019680>>2] = $3;
 HEAP8[3019688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_105v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3019784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019792,88)|0);
 HEAP32[3019776>>2] = $2;
 HEAP8[3019784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_106v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3019976>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019984,70)|0);
 HEAP32[3019968>>2] = $2;
 HEAP8[3019976>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_107v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020144>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019984,70)|0);
 HEAP32[3020128>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020152,74)|0);
 HEAP32[3020136>>2] = $3;
 HEAP8[3020144>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_108v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020312>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019984,70)|0);
 HEAP32[3020304>>2] = $2;
 HEAP8[3020312>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_109v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020344,8)|0);
 HEAP32[3020320>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020360,8)|0);
 HEAP32[3020328>>2] = $3;
 HEAP8[3020336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_10Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020400>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020408,10)|0);
 HEAP32[3020376>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3020384>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3020392>>2] = $4;
 HEAP8[3020400>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_10Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020440>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020448,3)|0);
 HEAP32[3020432>>2] = $2;
 HEAP8[3020440>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_10Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020464>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020472,4)|0);
 HEAP32[3020456>>2] = $2;
 HEAP8[3020464>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2D5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020488>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020496,34)|0);
 HEAP32[3020480>>2] = $2;
 HEAP8[3020488>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020576>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020584,3)|0);
 HEAP32[3020568>>2] = $2;
 HEAP8[3020576>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C3v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020600>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002216,8)|0);
 HEAP32[3020592>>2] = $2;
 HEAP8[3020600>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C4v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020640>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3020608>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3020616>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002304,46)|0);
 HEAP32[3020624>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002400,53)|0);
 HEAP32[3020632>>2] = $5;
 HEAP8[3020640>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B3v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020664>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020672,59)|0);
 HEAP32[3020648>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3020656>>2] = $3;
 HEAP8[3020664>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C5v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020808>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020584,3)|0);
 HEAP32[3020792>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020816,62)|0);
 HEAP32[3020800>>2] = $3;
 HEAP8[3020808>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3020984>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3020944>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020992,7)|0);
 HEAP32[3020952>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021008,8)|0);
 HEAP32[3020960>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021024,8)|0);
 HEAP32[3020968>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021040,13)|0);
 HEAP32[3020976>>2] = $6;
 HEAP8[3020984>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C7v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020584,3)|0);
 HEAP32[3021072>>2] = $2;
 HEAP8[3021080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021096>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020584,3)|0);
 HEAP32[3021088>>2] = $2;
 HEAP8[3021096>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2CEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021112>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021120,11)|0);
 HEAP32[3021104>>2] = $2;
 HEAP8[3021112>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2CFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021152>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002528,20)|0);
 HEAP32[3021144>>2] = $2;
 HEAP8[3021152>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2CAv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021168>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021176,10)|0);
 HEAP32[3021160>>2] = $2;
 HEAP8[3021168>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2CBv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021216,30)|0);
 HEAP32[3021200>>2] = $2;
 HEAP8[3021208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2CCv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021216,30)|0);
 HEAP32[3021280>>2] = $2;
 HEAP8[3021288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2CDv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021216,30)|0);
 HEAP32[3021296>>2] = $2;
 HEAP8[3021304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C9v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991688,1)|0);
 HEAP32[3021312>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3021320>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991696,1)|0);
 HEAP32[3021328>>2] = $4;
 HEAP8[3021336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2BCv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3021344>>2] = $2;
 HEAP8[3021352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021368>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3021360>>2] = $2;
 HEAP8[3021368>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2C1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021384>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3021376>>2] = $2;
 HEAP8[3021384>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B9v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021400>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002216,8)|0);
 HEAP32[3021392>>2] = $2;
 HEAP8[3021400>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2BAv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021416>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021424,4)|0);
 HEAP32[3021408>>2] = $2;
 HEAP8[3021416>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2BBv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021440>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021424,4)|0);
 HEAP32[3021432>>2] = $2;
 HEAP8[3021440>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2BDv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021456>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3021448>>2] = $2;
 HEAP8[3021456>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2BEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021480,10)|0);
 HEAP32[3021464>>2] = $2;
 HEAP8[3021472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2BFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021512>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3021504>>2] = $2;
 HEAP8[3021512>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2B8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021528>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021536,63)|0);
 HEAP32[3021520>>2] = $2;
 HEAP8[3021528>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_110v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3021672>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021696,61)|0);
 HEAP32[3021680>>2] = $3;
 HEAP8[3021688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_111v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3021824>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021696,61)|0);
 HEAP32[3021832>>2] = $3;
 HEAP8[3021840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_10Fv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3021864>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002216,8)|0);
 HEAP32[3021848>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021872,48)|0);
 HEAP32[3021856>>2] = $3;
 HEAP8[3021864>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_112v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022016>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3021968>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022024,29)|0);
 HEAP32[3021976>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3021984>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022088,21)|0);
 HEAP32[3021992>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3022000>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022136,51)|0);
 HEAP32[3022008>>2] = $7;
 HEAP8[3022016>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_113v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022256>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3022240>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022264,32)|0);
 HEAP32[3022248>>2] = $3;
 HEAP8[3022256>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_114v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022360,1)|0);
 HEAP32[3022328>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3022336>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022264,32)|0);
 HEAP32[3022344>>2] = $4;
 HEAP8[3022352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_115v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022384>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3022368>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022392,36)|0);
 HEAP32[3022376>>2] = $3;
 HEAP8[3022384>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_116v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022488>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3022464>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022496,28)|0);
 HEAP32[3022472>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3022480>>2] = $4;
 HEAP8[3022488>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_117v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022560>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021664,4)|0);
 HEAP32[3022552>>2] = $2;
 HEAP8[3022560>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_10Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022584>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022592,22)|0);
 HEAP32[3022568>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022640,16)|0);
 HEAP32[3022576>>2] = $3;
 HEAP8[3022584>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_10Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022688,17)|0);
 HEAP32[3022672>>2] = $2;
 HEAP8[3022680>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_118v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022736>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005640,7)|0);
 HEAP32[3022728>>2] = $2;
 HEAP8[3022736>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_119v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022760,3)|0);
 HEAP32[3022744>>2] = $2;
 HEAP8[3022752>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_11Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022776>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005640,7)|0);
 HEAP32[3022768>>2] = $2;
 HEAP8[3022776>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_11Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022792>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022800,43)|0);
 HEAP32[3022784>>2] = $2;
 HEAP8[3022792>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_11Cv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022904>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3022888>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022912,11)|0);
 HEAP32[3022896>>2] = $3;
 HEAP8[3022904>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_122v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3022952>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020584,3)|0);
 HEAP32[3022936>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022960,8)|0);
 HEAP32[3022944>>2] = $3;
 HEAP8[3022952>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_121v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3023016>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002216,8)|0);
 HEAP32[3022976>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023024,17)|0);
 HEAP32[3022984>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023064,10)|0);
 HEAP32[3022992>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023088,11)|0);
 HEAP32[3023000>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023112,15)|0);
 HEAP32[3023008>>2] = $6;
 HEAP8[3023016>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_123v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3023184>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3023144>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023192,10)|0);
 HEAP32[3023152>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023216,25)|0);
 HEAP32[3023160>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023272,51)|0);
 HEAP32[3023168>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023376,66)|0);
 HEAP32[3023176>>2] = $6;
 HEAP8[3023184>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_124v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3023592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3023512>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023600,10)|0);
 HEAP32[3023520>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020992,7)|0);
 HEAP32[3023528>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023624,11)|0);
 HEAP32[3023536>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021008,8)|0);
 HEAP32[3023544>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023648,16)|0);
 HEAP32[3023552>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3021024,8)|0);
 HEAP32[3023560>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023680,4)|0);
 HEAP32[3023568>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023688,6)|0);
 HEAP32[3023576>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023704,16)|0);
 HEAP32[3023584>>2] = $11;
 HEAP8[3023592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_125v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3023744>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023752,5)|0);
 HEAP32[3023736>>2] = $2;
 HEAP8[3023744>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_126v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3023784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020584,3)|0);
 HEAP32[3023768>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022960,8)|0);
 HEAP32[3023776>>2] = $3;
 HEAP8[3023784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_127v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3023816>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020584,3)|0);
 HEAP32[3023792>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022960,8)|0);
 HEAP32[3023800>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023824,29)|0);
 HEAP32[3023808>>2] = $4;
 HEAP8[3023816>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_11Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3023896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023904,19)|0);
 HEAP32[3023888>>2] = $2;
 HEAP8[3023896>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_11Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3023952>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023960,43)|0);
 HEAP32[3023944>>2] = $2;
 HEAP8[3023952>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_11Fv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3024048>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3024056>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023192,10)|0);
 HEAP32[3024064>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024088,16)|0);
 HEAP32[3024072>>2] = $5;
 HEAP8[3024080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_120v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024152>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3024120>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3024128>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3023192,10)|0);
 HEAP32[3024136>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024088,16)|0);
 HEAP32[3024144>>2] = $5;
 HEAP8[3024152>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_128v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024176>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3024160>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3024168>>2] = $3;
 HEAP8[3024176>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_129v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024192>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024200,18)|0);
 HEAP32[3024184>>2] = $2;
 HEAP8[3024192>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_12Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017624,16)|0);
 HEAP32[3024240>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024296,4)|0);
 HEAP32[3024248>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024304,16)|0);
 HEAP32[3024256>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024336,7)|0);
 HEAP32[3024264>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024352,21)|0);
 HEAP32[3024272>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024400,8)|0);
 HEAP32[3024280>>2] = $7;
 HEAP8[3024288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_12Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024440>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024448,1)|0);
 HEAP32[3024416>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005776,3)|0);
 HEAP32[3024424>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024456,10)|0);
 HEAP32[3024432>>2] = $4;
 HEAP8[3024440>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_12Cv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024496>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005776,3)|0);
 HEAP32[3024480>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024456,10)|0);
 HEAP32[3024488>>2] = $3;
 HEAP8[3024496>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_12Dv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024616>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024624,10)|0);
 HEAP32[3024504>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017616,2)|0);
 HEAP32[3024512>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017624,16)|0);
 HEAP32[3024520>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024648,16)|0);
 HEAP32[3024528>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024680,7)|0);
 HEAP32[3024536>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017616,2)|0);
 HEAP32[3024544>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024696,7)|0);
 HEAP32[3024552>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997000,1)|0);
 HEAP32[3024560>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3024568>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3024576>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024712,6)|0);
 HEAP32[3024584>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024728,4)|0);
 HEAP32[3024592>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[3024600>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024200,18)|0);
 HEAP32[3024608>>2] = $15;
 HEAP8[3024616>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_12Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024744>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024752,37)|0);
 HEAP32[3024736>>2] = $2;
 HEAP8[3024744>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_12Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024848,27)|0);
 HEAP32[3024832>>2] = $2;
 HEAP8[3024840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_130v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3024920>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024928,30)|0);
 HEAP32[3024904>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3019768,3)|0);
 HEAP32[3024912>>2] = $3;
 HEAP8[3024920>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_131v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3025000>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025008,7)|0);
 HEAP32[3024992>>2] = $2;
 HEAP8[3025000>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_132v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3025072>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025008,7)|0);
 HEAP32[3025024>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025080,46)|0);
 HEAP32[3025032>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025176,57)|0);
 HEAP32[3025040>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025296,57)|0);
 HEAP32[3025048>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025416,83)|0);
 HEAP32[3025056>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025584,83)|0);
 HEAP32[3025064>>2] = $7;
 HEAP8[3025072>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_133v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3025768>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025776,27)|0);
 HEAP32[3025752>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025008,7)|0);
 HEAP32[3025760>>2] = $3;
 HEAP8[3025768>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_134v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3025872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025880,6)|0);
 HEAP32[3025832>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3025840>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3025848>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3025856>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025008,7)|0);
 HEAP32[3025864>>2] = $6;
 HEAP8[3025872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_135v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3025912>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025880,6)|0);
 HEAP32[3025896>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025920,6)|0);
 HEAP32[3025904>>2] = $3;
 HEAP8[3025912>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_136v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3025952>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025880,6)|0);
 HEAP32[3025936>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025960,6)|0);
 HEAP32[3025944>>2] = $3;
 HEAP8[3025952>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_137v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3026016>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025880,6)|0);
 HEAP32[3025976>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3025984>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3025992>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3026000>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3025008,7)|0);
 HEAP32[3026008>>2] = $6;
 HEAP8[3026016>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_138v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3026032>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026040,14)|0);
 HEAP32[3026024>>2] = $2;
 HEAP8[3026032>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_139v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3026104>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005640,7)|0);
 HEAP32[3026072>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026112,25)|0);
 HEAP32[3026080>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026168,53)|0);
 HEAP32[3026088>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005640,7)|0);
 HEAP32[3026096>>2] = $5;
 HEAP8[3026104>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_13Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3026288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026296,26)|0);
 HEAP32[3026280>>2] = $2;
 HEAP8[3026288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_13Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3026368>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026376,9)|0);
 HEAP32[3026352>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026400,129)|0);
 HEAP32[3026360>>2] = $3;
 HEAP8[3026368>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_13Cv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3026704>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026712,38)|0);
 HEAP32[3026664>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026792,3)|0);
 HEAP32[3026672>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026800,2)|0);
 HEAP32[3026680>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026808,11)|0);
 HEAP32[3026688>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026792,3)|0);
 HEAP32[3026696>>2] = $6;
 HEAP8[3026704>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_140v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3026840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3026832>>2] = $2;
 HEAP8[3026840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_141v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3026856>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026864,38)|0);
 HEAP32[3026848>>2] = $2;
 HEAP8[3026856>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_13Dv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3027056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027064,2)|0);
 HEAP32[3026944>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027072,2)|0);
 HEAP32[3026952>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027080,1)|0);
 HEAP32[3026960>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996992,1)|0);
 HEAP32[3026968>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027088,10)|0);
 HEAP32[3026976>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027112,18)|0);
 HEAP32[3026984>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027152,5)|0);
 HEAP32[3026992>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027168,8)|0);
 HEAP32[3027000>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027184,7)|0);
 HEAP32[3027008>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027200,9)|0);
 HEAP32[3027016>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027224,27)|0);
 HEAP32[3027024>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027280,35)|0);
 HEAP32[3027032>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027352,29)|0);
 HEAP32[3027040>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027416,30)|0);
 HEAP32[3027048>>2] = $15;
 HEAP8[3027056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_13Ev() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3027864>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3026296,26)|0);
 HEAP32[3027480>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027872,43)|0);
 HEAP32[3027488>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027960,42)|0);
 HEAP32[3027496>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028048,3)|0);
 HEAP32[3027504>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028056,3)|0);
 HEAP32[3027512>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028064,3)|0);
 HEAP32[3027520>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028072,3)|0);
 HEAP32[3027528>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028080,3)|0);
 HEAP32[3027536>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028088,3)|0);
 HEAP32[3027544>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028096,3)|0);
 HEAP32[3027552>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028104,6)|0);
 HEAP32[3027560>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028120,6)|0);
 HEAP32[3027568>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028136,7)|0);
 HEAP32[3027576>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028152,9)|0);
 HEAP32[3027584>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028176,8)|0);
 HEAP32[3027592>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028192,6)|0);
 HEAP32[3027600>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028208,8)|0);
 HEAP32[3027608>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028224,3)|0);
 HEAP32[3027616>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028232,3)|0);
 HEAP32[3027624>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028240,3)|0);
 HEAP32[3027632>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028248,3)|0);
 HEAP32[3027640>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028256,3)|0);
 HEAP32[3027648>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028264,3)|0);
 HEAP32[3027656>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028272,3)|0);
 HEAP32[3027664>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028280,3)|0);
 HEAP32[3027672>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028288,3)|0);
 HEAP32[3027680>>2] = $27;
 $28 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028296,3)|0);
 HEAP32[3027688>>2] = $28;
 $29 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028304,3)|0);
 HEAP32[3027696>>2] = $29;
 $30 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028312,3)|0);
 HEAP32[3027704>>2] = $30;
 $31 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028320,7)|0);
 HEAP32[3027712>>2] = $31;
 $32 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028336,8)|0);
 HEAP32[3027720>>2] = $32;
 $33 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028352,5)|0);
 HEAP32[3027728>>2] = $33;
 $34 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028368,5)|0);
 HEAP32[3027736>>2] = $34;
 $35 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028256,3)|0);
 HEAP32[3027744>>2] = $35;
 $36 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028384,4)|0);
 HEAP32[3027752>>2] = $36;
 $37 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028392,4)|0);
 HEAP32[3027760>>2] = $37;
 $38 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028400,6)|0);
 HEAP32[3027768>>2] = $38;
 $39 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028416,9)|0);
 HEAP32[3027776>>2] = $39;
 $40 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028440,7)|0);
 HEAP32[3027784>>2] = $40;
 $41 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028456,8)|0);
 HEAP32[3027792>>2] = $41;
 $42 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028472,8)|0);
 HEAP32[3027800>>2] = $42;
 $43 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028488,2)|0);
 HEAP32[3027808>>2] = $43;
 $44 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028496,2)|0);
 HEAP32[3027816>>2] = $44;
 $45 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028504,2)|0);
 HEAP32[3027824>>2] = $45;
 $46 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028512,2)|0);
 HEAP32[3027832>>2] = $46;
 $47 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028520,2)|0);
 HEAP32[3027840>>2] = $47;
 $48 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028528,2)|0);
 HEAP32[3027848>>2] = $48;
 $49 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028536,2)|0);
 HEAP32[3027856>>2] = $49;
 HEAP8[3027864>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_13Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3028552>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028560,3)|0);
 HEAP32[3028544>>2] = $2;
 HEAP8[3028552>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_142v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3028608>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3028568>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3028576>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3028584>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3028592>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028616,29)|0);
 HEAP32[3028600>>2] = $6;
 HEAP8[3028608>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_143v() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3028752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027088,10)|0);
 HEAP32[3028680>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027112,18)|0);
 HEAP32[3028688>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027168,8)|0);
 HEAP32[3028696>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027152,5)|0);
 HEAP32[3028704>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028760,8)|0);
 HEAP32[3028712>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028776,4)|0);
 HEAP32[3028720>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028784,7)|0);
 HEAP32[3028728>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027184,7)|0);
 HEAP32[3028736>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027200,9)|0);
 HEAP32[3028744>>2] = $10;
 HEAP8[3028752>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_144v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3028808>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3028800>>2] = $2;
 HEAP8[3028808>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_145v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3028832>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028840,2)|0);
 HEAP32[3028816>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028848,4)|0);
 HEAP32[3028824>>2] = $3;
 HEAP8[3028832>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_148v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3028872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3028880,70)|0);
 HEAP32[3028856>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029024,67)|0);
 HEAP32[3028864>>2] = $3;
 HEAP8[3028872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_146v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029296,1)|0);
 HEAP32[3029160>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011448,1)|0);
 HEAP32[3029168>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3029176>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990720,1)|0);
 HEAP32[3029184>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029304,1)|0);
 HEAP32[3029192>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029312,3)|0);
 HEAP32[3029200>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029320,9)|0);
 HEAP32[3029208>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998120,1)|0);
 HEAP32[3029216>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3029224>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990720,1)|0);
 HEAP32[3029232>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3029240>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990720,1)|0);
 HEAP32[3029248>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029344,1)|0);
 HEAP32[3029256>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029352,1)|0);
 HEAP32[3029264>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029360,8)|0);
 HEAP32[3029272>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(2998128,1)|0);
 HEAP32[3029280>>2] = $17;
 HEAP8[3029288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_147v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029456>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011448,1)|0);
 HEAP32[3029376>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010104,1)|0);
 HEAP32[3029384>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029464,1)|0);
 HEAP32[3029392>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029472,1)|0);
 HEAP32[3029400>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029480,1)|0);
 HEAP32[3029408>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029488,1)|0);
 HEAP32[3029416>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029496,1)|0);
 HEAP32[3029424>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029504,1)|0);
 HEAP32[3029432>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029512,1)|0);
 HEAP32[3029440>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029520,1)|0);
 HEAP32[3029448>>2] = $11;
 HEAP8[3029456>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_149v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029536>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029544,11)|0);
 HEAP32[3029528>>2] = $2;
 HEAP8[3029536>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_14Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029576>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029584,3)|0);
 HEAP32[3029568>>2] = $2;
 HEAP8[3029576>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_14Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029608>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029616,21)|0);
 HEAP32[3029592>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029664,2)|0);
 HEAP32[3029600>>2] = $3;
 HEAP8[3029608>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_14Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029688,56)|0);
 HEAP32[3029672>>2] = $2;
 HEAP8[3029680>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_14Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029808>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029816,28)|0);
 HEAP32[3029800>>2] = $2;
 HEAP8[3029808>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_14Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029880>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029688,56)|0);
 HEAP32[3029872>>2] = $2;
 HEAP8[3029880>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_14Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029688,56)|0);
 HEAP32[3029888>>2] = $2;
 HEAP8[3029896>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_150v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029928>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029936,15)|0);
 HEAP32[3029904>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029968,2)|0);
 HEAP32[3029912>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991696,1)|0);
 HEAP32[3029920>>2] = $4;
 HEAP8[3029928>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_151v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3029984>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029688,56)|0);
 HEAP32[3029976>>2] = $2;
 HEAP8[3029984>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_152v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030000>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029688,56)|0);
 HEAP32[3029992>>2] = $2;
 HEAP8[3030000>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_153v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030016>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3030008>>2] = $2;
 HEAP8[3030016>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_154v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030032>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030040,32)|0);
 HEAP32[3030024>>2] = $2;
 HEAP8[3030032>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_155v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030112>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3029688,56)|0);
 HEAP32[3030104>>2] = $2;
 HEAP8[3030112>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_156v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030128>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030136,19)|0);
 HEAP32[3030120>>2] = $2;
 HEAP8[3030128>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_157v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030184>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030192,39)|0);
 HEAP32[3030176>>2] = $2;
 HEAP8[3030184>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_158v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3030272>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030296,20)|0);
 HEAP32[3030280>>2] = $3;
 HEAP8[3030288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_159v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030344>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030352,7)|0);
 HEAP32[3030336>>2] = $2;
 HEAP8[3030344>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_15Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030376>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030384,60)|0);
 HEAP32[3030368>>2] = $2;
 HEAP8[3030376>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_15Bv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030608>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3030504>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030616,5)|0);
 HEAP32[3030512>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030632,10)|0);
 HEAP32[3030520>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030656,15)|0);
 HEAP32[3030528>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030688,12)|0);
 HEAP32[3030536>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030712,9)|0);
 HEAP32[3030544>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030736,8)|0);
 HEAP32[3030552>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030752,14)|0);
 HEAP32[3030560>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030784,24)|0);
 HEAP32[3030568>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030832,18)|0);
 HEAP32[3030576>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030872,21)|0);
 HEAP32[3030584>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030920,6)|0);
 HEAP32[3030592>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030936,15)|0);
 HEAP32[3030600>>2] = $14;
 HEAP8[3030608>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_15Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3030976>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016216,5)|0);
 HEAP32[3030968>>2] = $2;
 HEAP8[3030976>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_15Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031000>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031008,22)|0);
 HEAP32[3030984>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016216,5)|0);
 HEAP32[3030992>>2] = $3;
 HEAP8[3031000>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_15Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031072>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031080,5)|0);
 HEAP32[3031056>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031096,6)|0);
 HEAP32[3031064>>2] = $3;
 HEAP8[3031072>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_15Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031128,22)|0);
 HEAP32[3031112>>2] = $2;
 HEAP8[3031120>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_160v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031184>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031192,32)|0);
 HEAP32[3031176>>2] = $2;
 HEAP8[3031184>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_161v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031312,12)|0);
 HEAP32[3031256>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3017880,9)|0);
 HEAP32[3031264>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031336,4)|0);
 HEAP32[3031272>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031344,9)|0);
 HEAP32[3031280>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031368,10)|0);
 HEAP32[3031288>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031392,16)|0);
 HEAP32[3031296>>2] = $7;
 HEAP8[3031304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_164v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031432>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031080,5)|0);
 HEAP32[3031424>>2] = $2;
 HEAP8[3031432>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_162v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031456>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031128,22)|0);
 HEAP32[3031440>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031128,22)|0);
 HEAP32[3031448>>2] = $3;
 HEAP8[3031456>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_163v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031480,63)|0);
 HEAP32[3031464>>2] = $2;
 HEAP8[3031472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_165v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031616>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3031608>>2] = $2;
 HEAP8[3031616>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_166v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031640,1)|0);
 HEAP32[3031624>>2] = $2;
 HEAP8[3031632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_167v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031656>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031640,1)|0);
 HEAP32[3031648>>2] = $2;
 HEAP8[3031656>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_168v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031672>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3031664>>2] = $2;
 HEAP8[3031672>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_169v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031696,34)|0);
 HEAP32[3031680>>2] = $2;
 HEAP8[3031688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_16Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031776>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031784,7)|0);
 HEAP32[3031768>>2] = $2;
 HEAP8[3031776>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_16Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3031840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031696,34)|0);
 HEAP32[3031800>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031848,27)|0);
 HEAP32[3031808>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031904,12)|0);
 HEAP32[3031816>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031928,37)|0);
 HEAP32[3031824>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032008,3)|0);
 HEAP32[3031832>>2] = $6;
 HEAP8[3031840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_16Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3032024>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032032,112)|0);
 HEAP32[3032016>>2] = $2;
 HEAP8[3032024>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_16Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3032288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032296,33)|0);
 HEAP32[3032256>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032368,28)|0);
 HEAP32[3032264>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032296,33)|0);
 HEAP32[3032272>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032424,106)|0);
 HEAP32[3032280>>2] = $5;
 HEAP8[3032288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_16Ev() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3032720>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3032640>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991688,1)|0);
 HEAP32[3032648>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990720,1)|0);
 HEAP32[3032656>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991696,1)|0);
 HEAP32[3032664>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997000,1)|0);
 HEAP32[3032672>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3032680>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3024712,6)|0);
 HEAP32[3032688>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3032696>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032728,3)|0);
 HEAP32[3032704>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[3032712>>2] = $11;
 HEAP8[3032720>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_16Fv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3032752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032760,19)|0);
 HEAP32[3032736>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032800,82)|0);
 HEAP32[3032744>>2] = $3;
 HEAP8[3032752>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_170v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033016>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032296,33)|0);
 HEAP32[3032968>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032368,28)|0);
 HEAP32[3032976>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3032296,33)|0);
 HEAP32[3032984>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033024,29)|0);
 HEAP32[3032992>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033088,48)|0);
 HEAP32[3033000>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033184,64)|0);
 HEAP32[3033008>>2] = $7;
 HEAP8[3033016>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_171v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033360,5)|0);
 HEAP32[3033312>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997000,1)|0);
 HEAP32[3033320>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3033328>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033376,5)|0);
 HEAP32[3033336>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[3033344>>2] = $6;
 HEAP8[3033352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_172v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033408>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033416,26)|0);
 HEAP32[3033392>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033472,1)|0);
 HEAP32[3033400>>2] = $3;
 HEAP8[3033408>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_173v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033488>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3033480>>2] = $2;
 HEAP8[3033488>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_174v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033528>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033536,10)|0);
 HEAP32[3033496>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033560,17)|0);
 HEAP32[3033504>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033600,16)|0);
 HEAP32[3033512>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033632,13)|0);
 HEAP32[3033520>>2] = $5;
 HEAP8[3033528>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_175v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033672>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033680,57)|0);
 HEAP32[3033664>>2] = $2;
 HEAP8[3033672>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_176v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033808>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033816,50)|0);
 HEAP32[3033800>>2] = $2;
 HEAP8[3033808>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_177v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033928>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033936,15)|0);
 HEAP32[3033920>>2] = $2;
 HEAP8[3033928>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_178v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3033984>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033992,71)|0);
 HEAP32[3033968>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034136,116)|0);
 HEAP32[3033976>>2] = $3;
 HEAP8[3033984>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_179v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3034392>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034400,14)|0);
 HEAP32[3034368>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034432,44)|0);
 HEAP32[3034376>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034520,38)|0);
 HEAP32[3034384>>2] = $4;
 HEAP8[3034392>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_17Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3034632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034640,4)|0);
 HEAP32[3034600>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034648,70)|0);
 HEAP32[3034608>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034792,8)|0);
 HEAP32[3034616>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034808,19)|0);
 HEAP32[3034624>>2] = $5;
 HEAP8[3034632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_17Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3034856>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034864,7)|0);
 HEAP32[3034848>>2] = $2;
 HEAP8[3034856>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_17Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3034888>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034896,11)|0);
 HEAP32[3034880>>2] = $2;
 HEAP8[3034888>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_17Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3034928>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034936,7)|0);
 HEAP32[3034920>>2] = $2;
 HEAP8[3034928>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_17Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3034968>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034936,7)|0);
 HEAP32[3034952>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034976,3)|0);
 HEAP32[3034960>>2] = $3;
 HEAP8[3034968>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_17Fv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3035024>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035032,11)|0);
 HEAP32[3034984>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035056,30)|0);
 HEAP32[3034992>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035120,16)|0);
 HEAP32[3035000>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035152,19)|0);
 HEAP32[3035008>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035192,20)|0);
 HEAP32[3035016>>2] = $6;
 HEAP8[3035024>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_180v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3035240>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035248,14)|0);
 HEAP32[3035232>>2] = $2;
 HEAP8[3035240>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_181v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3035336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035344,10)|0);
 HEAP32[3035280>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035368,12)|0);
 HEAP32[3035288>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035392,17)|0);
 HEAP32[3035296>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035432,6)|0);
 HEAP32[3035304>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035448,13)|0);
 HEAP32[3035312>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035480,5)|0);
 HEAP32[3035320>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035496,18)|0);
 HEAP32[3035328>>2] = $8;
 HEAP8[3035336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_182v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3035648>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018464,2)|0);
 HEAP32[3035536>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996880,1)|0);
 HEAP32[3035544>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035656,27)|0);
 HEAP32[3035552>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035712,22)|0);
 HEAP32[3035560>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035760,30)|0);
 HEAP32[3035568>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035824,18)|0);
 HEAP32[3035576>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033472,1)|0);
 HEAP32[3035584>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035864,7)|0);
 HEAP32[3035592>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035880,14)|0);
 HEAP32[3035600>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035864,7)|0);
 HEAP32[3035608>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035880,14)|0);
 HEAP32[3035616>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035864,7)|0);
 HEAP32[3035624>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035880,14)|0);
 HEAP32[3035632>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3035912,66)|0);
 HEAP32[3035640>>2] = $15;
 HEAP8[3035648>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_183v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036064,2)|0);
 HEAP32[3036048>>2] = $2;
 HEAP8[3036056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_184v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036088>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036096,27)|0);
 HEAP32[3036072>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036152,24)|0);
 HEAP32[3036080>>2] = $3;
 HEAP8[3036088>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_185v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036216>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036224,7)|0);
 HEAP32[3036200>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036240,11)|0);
 HEAP32[3036208>>2] = $3;
 HEAP8[3036216>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_186v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036312,3)|0);
 HEAP32[3036264>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036320,8)|0);
 HEAP32[3036272>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036336,9)|0);
 HEAP32[3036280>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036360,11)|0);
 HEAP32[3036288>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036384,11)|0);
 HEAP32[3036296>>2] = $6;
 HEAP8[3036304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_187v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036440>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027080,1)|0);
 HEAP32[3036408>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036448,27)|0);
 HEAP32[3036416>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036504,11)|0);
 HEAP32[3036424>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036528,11)|0);
 HEAP32[3036432>>2] = $5;
 HEAP8[3036440>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_188v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036576,6)|0);
 HEAP32[3036552>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036592,12)|0);
 HEAP32[3036560>>2] = $3;
 HEAP8[3036568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_189v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036504,11)|0);
 HEAP32[3036616>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036528,11)|0);
 HEAP32[3036624>>2] = $3;
 HEAP8[3036632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_18Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036656>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034136,116)|0);
 HEAP32[3036640>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3034136,116)|0);
 HEAP32[3036648>>2] = $3;
 HEAP8[3036656>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_18Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027080,1)|0);
 HEAP32[3036664>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027080,1)|0);
 HEAP32[3036672>>2] = $3;
 HEAP8[3036680>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_18Cv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036704>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036712,20)|0);
 HEAP32[3036688>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3036696>>2] = $3;
 HEAP8[3036704>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_18Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036760>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3027080,1)|0);
 HEAP32[3036752>>2] = $2;
 HEAP8[3036760>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_18Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036792>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036800,12)|0);
 HEAP32[3036768>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036824,12)|0);
 HEAP32[3036776>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036848,34)|0);
 HEAP32[3036784>>2] = $4;
 HEAP8[3036792>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_18Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3036928>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036936,13)|0);
 HEAP32[3036920>>2] = $2;
 HEAP8[3036928>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_190v() {
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3038568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038576,3)|0);
 HEAP32[3036968>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038584,54)|0);
 HEAP32[3036976>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020472,4)|0);
 HEAP32[3036984>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038584,54)|0);
 HEAP32[3036992>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038696,33)|0);
 HEAP32[3037000>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038584,54)|0);
 HEAP32[3037008>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038768,42)|0);
 HEAP32[3037016>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038584,54)|0);
 HEAP32[3037024>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038856,3)|0);
 HEAP32[3037032>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038864,53)|0);
 HEAP32[3037040>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038976,32)|0);
 HEAP32[3037048>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038864,53)|0);
 HEAP32[3037056>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039040,6)|0);
 HEAP32[3037064>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039056,42)|0);
 HEAP32[3037072>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039144,7)|0);
 HEAP32[3037080>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039056,42)|0);
 HEAP32[3037088>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039160,35)|0);
 HEAP32[3037096>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039056,42)|0);
 HEAP32[3037104>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039232,6)|0);
 HEAP32[3037112>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039248,42)|0);
 HEAP32[3037120>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039336,7)|0);
 HEAP32[3037128>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039248,42)|0);
 HEAP32[3037136>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039352,35)|0);
 HEAP32[3037144>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039248,42)|0);
 HEAP32[3037152>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039424,6)|0);
 HEAP32[3037160>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039440,42)|0);
 HEAP32[3037168>>2] = $27;
 $28 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039528,7)|0);
 HEAP32[3037176>>2] = $28;
 $29 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039440,42)|0);
 HEAP32[3037184>>2] = $29;
 $30 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039544,35)|0);
 HEAP32[3037192>>2] = $30;
 $31 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039440,42)|0);
 HEAP32[3037200>>2] = $31;
 $32 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039616,3)|0);
 HEAP32[3037208>>2] = $32;
 $33 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039624,53)|0);
 HEAP32[3037216>>2] = $33;
 $34 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039736,32)|0);
 HEAP32[3037224>>2] = $34;
 $35 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039624,53)|0);
 HEAP32[3037232>>2] = $35;
 $36 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039800,48)|0);
 HEAP32[3037240>>2] = $36;
 $37 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039624,53)|0);
 HEAP32[3037248>>2] = $37;
 $38 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039896,3)|0);
 HEAP32[3037256>>2] = $38;
 $39 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039904,53)|0);
 HEAP32[3037264>>2] = $39;
 $40 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040016,32)|0);
 HEAP32[3037272>>2] = $40;
 $41 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039904,53)|0);
 HEAP32[3037280>>2] = $41;
 $42 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040080,3)|0);
 HEAP32[3037288>>2] = $42;
 $43 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040088,53)|0);
 HEAP32[3037296>>2] = $43;
 $44 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040200,32)|0);
 HEAP32[3037304>>2] = $44;
 $45 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040088,53)|0);
 HEAP32[3037312>>2] = $45;
 $46 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040264,4)|0);
 HEAP32[3037320>>2] = $46;
 $47 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040272,59)|0);
 HEAP32[3037328>>2] = $47;
 $48 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040392,9)|0);
 HEAP32[3037336>>2] = $48;
 $49 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040272,59)|0);
 HEAP32[3037344>>2] = $49;
 $50 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040416,10)|0);
 HEAP32[3037352>>2] = $50;
 $51 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040272,59)|0);
 HEAP32[3037360>>2] = $51;
 $52 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040440,38)|0);
 HEAP32[3037368>>2] = $52;
 $53 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040272,59)|0);
 HEAP32[3037376>>2] = $53;
 $54 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040520,3)|0);
 HEAP32[3037384>>2] = $54;
 $55 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040528,53)|0);
 HEAP32[3037392>>2] = $55;
 $56 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040640,32)|0);
 HEAP32[3037400>>2] = $56;
 $57 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040528,53)|0);
 HEAP32[3037408>>2] = $57;
 $58 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040704,8)|0);
 HEAP32[3037416>>2] = $58;
 $59 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040720,44)|0);
 HEAP32[3037424>>2] = $59;
 $60 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040808,37)|0);
 HEAP32[3037432>>2] = $60;
 $61 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040720,44)|0);
 HEAP32[3037440>>2] = $61;
 $62 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040888,47)|0);
 HEAP32[3037448>>2] = $62;
 $63 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040720,44)|0);
 HEAP32[3037456>>2] = $63;
 $64 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040984,21)|0);
 HEAP32[3037464>>2] = $64;
 $65 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041032,53)|0);
 HEAP32[3037472>>2] = $65;
 $66 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041144,50)|0);
 HEAP32[3037480>>2] = $66;
 $67 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041032,53)|0);
 HEAP32[3037488>>2] = $67;
 $68 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041248,47)|0);
 HEAP32[3037496>>2] = $68;
 $69 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041344,37)|0);
 HEAP32[3037504>>2] = $69;
 $70 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041424,8)|0);
 HEAP32[3037512>>2] = $70;
 $71 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041344,37)|0);
 HEAP32[3037520>>2] = $71;
 $72 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041344,37)|0);
 HEAP32[3037528>>2] = $72;
 $73 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041344,37)|0);
 HEAP32[3037536>>2] = $73;
 $74 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041440,12)|0);
 HEAP32[3037544>>2] = $74;
 $75 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041464,41)|0);
 HEAP32[3037552>>2] = $75;
 $76 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041464,41)|0);
 HEAP32[3037560>>2] = $76;
 $77 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041464,41)|0);
 HEAP32[3037568>>2] = $77;
 $78 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041552,9)|0);
 HEAP32[3037576>>2] = $78;
 $79 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041576,45)|0);
 HEAP32[3037584>>2] = $79;
 $80 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041672,10)|0);
 HEAP32[3037592>>2] = $80;
 $81 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041576,45)|0);
 HEAP32[3037600>>2] = $81;
 $82 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041696,38)|0);
 HEAP32[3037608>>2] = $82;
 $83 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041576,45)|0);
 HEAP32[3037616>>2] = $83;
 $84 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041776,33)|0);
 HEAP32[3037624>>2] = $84;
 $85 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041344,37)|0);
 HEAP32[3037632>>2] = $85;
 $86 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041848,7)|0);
 HEAP32[3037640>>2] = $86;
 $87 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041864,36)|0);
 HEAP32[3037648>>2] = $87;
 $88 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041864,36)|0);
 HEAP32[3037656>>2] = $88;
 $89 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041864,36)|0);
 HEAP32[3037664>>2] = $89;
 $90 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041936,13)|0);
 HEAP32[3037672>>2] = $90;
 $91 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041968,42)|0);
 HEAP32[3037680>>2] = $91;
 $92 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041968,42)|0);
 HEAP32[3037688>>2] = $92;
 $93 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041968,42)|0);
 HEAP32[3037696>>2] = $93;
 $94 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042056,10)|0);
 HEAP32[3037704>>2] = $94;
 $95 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042080,39)|0);
 HEAP32[3037712>>2] = $95;
 $96 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042080,39)|0);
 HEAP32[3037720>>2] = $96;
 $97 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042080,39)|0);
 HEAP32[3037728>>2] = $97;
 $98 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042160,10)|0);
 HEAP32[3037736>>2] = $98;
 $99 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042184,39)|0);
 HEAP32[3037744>>2] = $99;
 $100 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042184,39)|0);
 HEAP32[3037752>>2] = $100;
 $101 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042184,39)|0);
 HEAP32[3037760>>2] = $101;
 $102 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042264,10)|0);
 HEAP32[3037768>>2] = $102;
 $103 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042288,39)|0);
 HEAP32[3037776>>2] = $103;
 $104 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042288,39)|0);
 HEAP32[3037784>>2] = $104;
 $105 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042288,39)|0);
 HEAP32[3037792>>2] = $105;
 $106 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042368,42)|0);
 HEAP32[3037800>>2] = $106;
 $107 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042456,52)|0);
 HEAP32[3037808>>2] = $107;
 $108 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042560,42)|0);
 HEAP32[3037816>>2] = $108;
 $109 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042648,61)|0);
 HEAP32[3037824>>2] = $109;
 $110 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042776,38)|0);
 HEAP32[3037832>>2] = $110;
 $111 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038584,54)|0);
 HEAP32[3037840>>2] = $111;
 $112 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042856,47)|0);
 HEAP32[3037848>>2] = $112;
 $113 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042952,137)|0);
 HEAP32[3037856>>2] = $113;
 $114 = (__ZN6il2cpp2vm6String4LoadEPKtj(3043232,60)|0);
 HEAP32[3037864>>2] = $114;
 $115 = (__ZN6il2cpp2vm6String4LoadEPKtj(3043352,149)|0);
 HEAP32[3037872>>2] = $115;
 $116 = (__ZN6il2cpp2vm6String4LoadEPKtj(3043656,40)|0);
 HEAP32[3037880>>2] = $116;
 $117 = (__ZN6il2cpp2vm6String4LoadEPKtj(3043736,139)|0);
 HEAP32[3037888>>2] = $117;
 $118 = (__ZN6il2cpp2vm6String4LoadEPKtj(3044016,44)|0);
 HEAP32[3037896>>2] = $118;
 $119 = (__ZN6il2cpp2vm6String4LoadEPKtj(3044104,138)|0);
 HEAP32[3037904>>2] = $119;
 $120 = (__ZN6il2cpp2vm6String4LoadEPKtj(3044384,43)|0);
 HEAP32[3037912>>2] = $120;
 $121 = (__ZN6il2cpp2vm6String4LoadEPKtj(3044472,137)|0);
 HEAP32[3037920>>2] = $121;
 $122 = (__ZN6il2cpp2vm6String4LoadEPKtj(3044752,53)|0);
 HEAP32[3037928>>2] = $122;
 $123 = (__ZN6il2cpp2vm6String4LoadEPKtj(3044864,151)|0);
 HEAP32[3037936>>2] = $123;
 $124 = (__ZN6il2cpp2vm6String4LoadEPKtj(3045168,39)|0);
 HEAP32[3037944>>2] = $124;
 $125 = (__ZN6il2cpp2vm6String4LoadEPKtj(3045248,140)|0);
 HEAP32[3037952>>2] = $125;
 $126 = (__ZN6il2cpp2vm6String4LoadEPKtj(3045528,51)|0);
 HEAP32[3037960>>2] = $126;
 $127 = (__ZN6il2cpp2vm6String4LoadEPKtj(3045632,152)|0);
 HEAP32[3037968>>2] = $127;
 $128 = (__ZN6il2cpp2vm6String4LoadEPKtj(3045936,37)|0);
 HEAP32[3037976>>2] = $128;
 $129 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046016,139)|0);
 HEAP32[3037984>>2] = $129;
 $130 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046296,39)|0);
 HEAP32[3037992>>2] = $130;
 $131 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039056,42)|0);
 HEAP32[3038000>>2] = $131;
 $132 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046376,39)|0);
 HEAP32[3038008>>2] = $132;
 $133 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039440,42)|0);
 HEAP32[3038016>>2] = $133;
 $134 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046456,50)|0);
 HEAP32[3038024>>2] = $134;
 $135 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042080,39)|0);
 HEAP32[3038032>>2] = $135;
 $136 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046560,50)|0);
 HEAP32[3038040>>2] = $136;
 $137 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042184,39)|0);
 HEAP32[3038048>>2] = $137;
 $138 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046664,50)|0);
 HEAP32[3038056>>2] = $138;
 $139 = (__ZN6il2cpp2vm6String4LoadEPKtj(3042288,39)|0);
 HEAP32[3038064>>2] = $139;
 $140 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046768,53)|0);
 HEAP32[3038072>>2] = $140;
 $141 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041968,42)|0);
 HEAP32[3038080>>2] = $141;
 $142 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046880,43)|0);
 HEAP32[3038088>>2] = $142;
 $143 = (__ZN6il2cpp2vm6String4LoadEPKtj(3046968,132)|0);
 HEAP32[3038096>>2] = $143;
 $144 = (__ZN6il2cpp2vm6String4LoadEPKtj(3047232,42)|0);
 HEAP32[3038104>>2] = $144;
 $145 = (__ZN6il2cpp2vm6String4LoadEPKtj(3047320,128)|0);
 HEAP32[3038112>>2] = $145;
 $146 = (__ZN6il2cpp2vm6String4LoadEPKtj(3047576,55)|0);
 HEAP32[3038120>>2] = $146;
 $147 = (__ZN6il2cpp2vm6String4LoadEPKtj(3047688,128)|0);
 HEAP32[3038128>>2] = $147;
 $148 = (__ZN6il2cpp2vm6String4LoadEPKtj(3047944,55)|0);
 HEAP32[3038136>>2] = $148;
 $149 = (__ZN6il2cpp2vm6String4LoadEPKtj(3048056,128)|0);
 HEAP32[3038144>>2] = $149;
 $150 = (__ZN6il2cpp2vm6String4LoadEPKtj(3048312,50)|0);
 HEAP32[3038152>>2] = $150;
 $151 = (__ZN6il2cpp2vm6String4LoadEPKtj(3048416,139)|0);
 HEAP32[3038160>>2] = $151;
 $152 = (__ZN6il2cpp2vm6String4LoadEPKtj(3048696,9)|0);
 HEAP32[3038168>>2] = $152;
 $153 = (__ZN6il2cpp2vm6String4LoadEPKtj(3048720,154)|0);
 HEAP32[3038176>>2] = $153;
 $154 = (__ZN6il2cpp2vm6String4LoadEPKtj(3049032,9)|0);
 HEAP32[3038184>>2] = $154;
 $155 = (__ZN6il2cpp2vm6String4LoadEPKtj(3049056,142)|0);
 HEAP32[3038192>>2] = $155;
 $156 = (__ZN6il2cpp2vm6String4LoadEPKtj(3049344,9)|0);
 HEAP32[3038200>>2] = $156;
 $157 = (__ZN6il2cpp2vm6String4LoadEPKtj(3049368,150)|0);
 HEAP32[3038208>>2] = $157;
 $158 = (__ZN6il2cpp2vm6String4LoadEPKtj(3049672,9)|0);
 HEAP32[3038216>>2] = $158;
 $159 = (__ZN6il2cpp2vm6String4LoadEPKtj(3049696,150)|0);
 HEAP32[3038224>>2] = $159;
 $160 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050000,9)|0);
 HEAP32[3038232>>2] = $160;
 $161 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050024,130)|0);
 HEAP32[3038240>>2] = $161;
 $162 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038584,54)|0);
 HEAP32[3038248>>2] = $162;
 $163 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050288,13)|0);
 HEAP32[3038256>>2] = $163;
 $164 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050320,40)|0);
 HEAP32[3038264>>2] = $164;
 $165 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050288,13)|0);
 HEAP32[3038272>>2] = $165;
 $166 = (__ZN6il2cpp2vm6String4LoadEPKtj(3020472,4)|0);
 HEAP32[3038280>>2] = $166;
 $167 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050288,13)|0);
 HEAP32[3038288>>2] = $167;
 $168 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038696,33)|0);
 HEAP32[3038296>>2] = $168;
 $169 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050288,13)|0);
 HEAP32[3038304>>2] = $169;
 $170 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038864,53)|0);
 HEAP32[3038312>>2] = $170;
 $171 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050400,18)|0);
 HEAP32[3038320>>2] = $171;
 $172 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038856,3)|0);
 HEAP32[3038328>>2] = $172;
 $173 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050400,18)|0);
 HEAP32[3038336>>2] = $173;
 $174 = (__ZN6il2cpp2vm6String4LoadEPKtj(3038976,32)|0);
 HEAP32[3038344>>2] = $174;
 $175 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050400,18)|0);
 HEAP32[3038352>>2] = $175;
 $176 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039056,42)|0);
 HEAP32[3038360>>2] = $176;
 $177 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050440,22)|0);
 HEAP32[3038368>>2] = $177;
 $178 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039040,6)|0);
 HEAP32[3038376>>2] = $178;
 $179 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050440,22)|0);
 HEAP32[3038384>>2] = $179;
 $180 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039160,35)|0);
 HEAP32[3038392>>2] = $180;
 $181 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050440,22)|0);
 HEAP32[3038400>>2] = $181;
 $182 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039248,42)|0);
 HEAP32[3038408>>2] = $182;
 $183 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050488,22)|0);
 HEAP32[3038416>>2] = $183;
 $184 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039232,6)|0);
 HEAP32[3038424>>2] = $184;
 $185 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050488,22)|0);
 HEAP32[3038432>>2] = $185;
 $186 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039352,35)|0);
 HEAP32[3038440>>2] = $186;
 $187 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050488,22)|0);
 HEAP32[3038448>>2] = $187;
 $188 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039440,42)|0);
 HEAP32[3038456>>2] = $188;
 $189 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050536,22)|0);
 HEAP32[3038464>>2] = $189;
 $190 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039424,6)|0);
 HEAP32[3038472>>2] = $190;
 $191 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050536,22)|0);
 HEAP32[3038480>>2] = $191;
 $192 = (__ZN6il2cpp2vm6String4LoadEPKtj(3039544,35)|0);
 HEAP32[3038488>>2] = $192;
 $193 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050536,22)|0);
 HEAP32[3038496>>2] = $193;
 $194 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050584,16)|0);
 HEAP32[3038504>>2] = $194;
 $195 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050616,25)|0);
 HEAP32[3038512>>2] = $195;
 $196 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040080,3)|0);
 HEAP32[3038520>>2] = $196;
 $197 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050672,12)|0);
 HEAP32[3038528>>2] = $197;
 $198 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040392,9)|0);
 HEAP32[3038536>>2] = $198;
 $199 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050696,18)|0);
 HEAP32[3038544>>2] = $199;
 $200 = (__ZN6il2cpp2vm6String4LoadEPKtj(3040520,3)|0);
 HEAP32[3038552>>2] = $200;
 $201 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050736,18)|0);
 HEAP32[3038560>>2] = $201;
 HEAP8[3038568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_191v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3050784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3050776>>2] = $2;
 HEAP8[3050784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_192v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3050800>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050808,6)|0);
 HEAP32[3050792>>2] = $2;
 HEAP8[3050800>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_193v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3050888>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050896,13)|0);
 HEAP32[3050824>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050808,6)|0);
 HEAP32[3050832>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050928,6)|0);
 HEAP32[3050840>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005776,3)|0);
 HEAP32[3050848>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3050856>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005776,3)|0);
 HEAP32[3050864>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050944,14)|0);
 HEAP32[3050872>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3050976,8)|0);
 HEAP32[3050880>>2] = $9;
 HEAP8[3050888>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_194v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051000>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051008,30)|0);
 HEAP32[3050992>>2] = $2;
 HEAP8[3051000>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_195v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051088,4)|0);
 HEAP32[3051072>>2] = $2;
 HEAP8[3051080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_196v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051104>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3041144,50)|0);
 HEAP32[3051096>>2] = $2;
 HEAP8[3051104>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_197v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051136>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3051112>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051144,7)|0);
 HEAP32[3051120>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051160,52)|0);
 HEAP32[3051128>>2] = $4;
 HEAP8[3051136>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_198v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051312>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030352,7)|0);
 HEAP32[3051264>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010104,1)|0);
 HEAP32[3051272>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051160,52)|0);
 HEAP32[3051280>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011232,2)|0);
 HEAP32[3051288>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051144,7)|0);
 HEAP32[3051296>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051320,57)|0);
 HEAP32[3051304>>2] = $7;
 HEAP8[3051312>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_19Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051456>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051464,18)|0);
 HEAP32[3051440>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996288,2)|0);
 HEAP32[3051448>>2] = $3;
 HEAP8[3051456>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_19Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051528>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051536,3)|0);
 HEAP32[3051504>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051464,18)|0);
 HEAP32[3051512>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996288,2)|0);
 HEAP32[3051520>>2] = $4;
 HEAP8[3051528>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_19Cv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3051544>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3051552>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051576,22)|0);
 HEAP32[3051560>>2] = $4;
 HEAP8[3051568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_19Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051640,5)|0);
 HEAP32[3051624>>2] = $2;
 HEAP8[3051632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_19Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051696>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051704,4)|0);
 HEAP32[3051656>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051712,4)|0);
 HEAP32[3051664>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051720,6)|0);
 HEAP32[3051672>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051736,6)|0);
 HEAP32[3051680>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051752,5)|0);
 HEAP32[3051688>>2] = $6;
 HEAP8[3051696>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_19Fv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051848>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051704,4)|0);
 HEAP32[3051768>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051856,1)|0);
 HEAP32[3051776>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051712,4)|0);
 HEAP32[3051784>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051864,1)|0);
 HEAP32[3051792>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051752,5)|0);
 HEAP32[3051800>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051872,1)|0);
 HEAP32[3051808>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051720,6)|0);
 HEAP32[3051816>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991640,1)|0);
 HEAP32[3051824>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051736,6)|0);
 HEAP32[3051832>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3033472,1)|0);
 HEAP32[3051840>>2] = $11;
 HEAP8[3051848>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A0v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3051944>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051856,1)|0);
 HEAP32[3051880>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3051888>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051952,2)|0);
 HEAP32[3051896>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2991640,1)|0);
 HEAP32[3051904>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051960,2)|0);
 HEAP32[3051912>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051864,1)|0);
 HEAP32[3051920>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051968,2)|0);
 HEAP32[3051928>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3051864,1)|0);
 HEAP32[3051936>>2] = $9;
 HEAP8[3051944>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_199v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3052008>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052016,26)|0);
 HEAP32[3051976>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996288,2)|0);
 HEAP32[3051984>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052072,27)|0);
 HEAP32[3051992>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996288,2)|0);
 HEAP32[3052000>>2] = $5;
 HEAP8[3052008>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3052136>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052144,15)|0);
 HEAP32[3052128>>2] = $2;
 HEAP8[3052136>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A2v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3052264>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018208,42)|0);
 HEAP32[3052176>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052272,12)|0);
 HEAP32[3052184>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3052192>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052296,22)|0);
 HEAP32[3052200>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052344,13)|0);
 HEAP32[3052208>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052376,15)|0);
 HEAP32[3052216>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052408,15)|0);
 HEAP32[3052224>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052440,16)|0);
 HEAP32[3052232>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052472,25)|0);
 HEAP32[3052240>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052528,13)|0);
 HEAP32[3052248>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052560,7)|0);
 HEAP32[3052256>>2] = $12;
 HEAP8[3052264>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A3v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3052592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052600,8)|0);
 HEAP32[3052576>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052616,8)|0);
 HEAP32[3052584>>2] = $3;
 HEAP8[3052592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A4v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3052672>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3052632>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3052640>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3052648>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3052656>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3052664>>2] = $6;
 HEAP8[3052672>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3052736>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3052728>>2] = $2;
 HEAP8[3052736>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A6v() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3052816>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3052744>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3052752>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3052760>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3052768>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3052776>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3052784>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3052792>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3052800>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3052808>>2] = $10;
 HEAP8[3052816>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053000>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3052960>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3052968>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3052976>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3052984>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3052992>>2] = $6;
 HEAP8[3053000>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A8v() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3053008>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3053016>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3053024>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3053032>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3053040>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3053048>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3053056>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3053064>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3053072>>2] = $10;
 HEAP8[3053080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1A9v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053152>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3053112>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3053120>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3053128>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3053136>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3053144>>2] = $6;
 HEAP8[3053152>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1AAv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3053160>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3053168>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3053176>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3053184>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053216,51)|0);
 HEAP32[3053192>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3053200>>2] = $7;
 HEAP8[3053208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1ABv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053328>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053336,1)|0);
 HEAP32[3053320>>2] = $2;
 HEAP8[3053328>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1ACv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053360,1)|0);
 HEAP32[3053344>>2] = $2;
 HEAP8[3053352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1ADv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053376>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053384,8)|0);
 HEAP32[3053368>>2] = $2;
 HEAP8[3053376>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1AEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053424>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053432,12)|0);
 HEAP32[3053400>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053456,206)|0);
 HEAP32[3053408>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3053416>>2] = $4;
 HEAP8[3053424>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1AFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053880>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053336,1)|0);
 HEAP32[3053872>>2] = $2;
 HEAP8[3053880>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053360,1)|0);
 HEAP32[3053888>>2] = $2;
 HEAP8[3053896>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053912>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053384,8)|0);
 HEAP32[3053904>>2] = $2;
 HEAP8[3053912>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B2v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3053936>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053456,206)|0);
 HEAP32[3053920>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3053928>>2] = $3;
 HEAP8[3053936>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B3v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3054224>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054232,5)|0);
 HEAP32[3053944>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054248,8)|0);
 HEAP32[3053952>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054264,2)|0);
 HEAP32[3053960>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054272,14)|0);
 HEAP32[3053968>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054304,14)|0);
 HEAP32[3053976>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054336,5)|0);
 HEAP32[3053984>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054352,7)|0);
 HEAP32[3053992>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054368,6)|0);
 HEAP32[3054000>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054384,8)|0);
 HEAP32[3054008>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054400,9)|0);
 HEAP32[3054016>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054424,16)|0);
 HEAP32[3054024>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054456,5)|0);
 HEAP32[3054032>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054472,15)|0);
 HEAP32[3054040>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054504,17)|0);
 HEAP32[3054048>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054544,17)|0);
 HEAP32[3054056>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054584,19)|0);
 HEAP32[3054064>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054624,19)|0);
 HEAP32[3054072>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054664,5)|0);
 HEAP32[3054080>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054680,17)|0);
 HEAP32[3054088>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054720,17)|0);
 HEAP32[3054096>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054760,19)|0);
 HEAP32[3054104>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054800,19)|0);
 HEAP32[3054112>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054840,6)|0);
 HEAP32[3054120>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054856,8)|0);
 HEAP32[3054128>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054872,5)|0);
 HEAP32[3054136>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054888,7)|0);
 HEAP32[3054144>>2] = $27;
 $28 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054904,14)|0);
 HEAP32[3054152>>2] = $28;
 $29 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054936,11)|0);
 HEAP32[3054160>>2] = $29;
 $30 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054960,8)|0);
 HEAP32[3054168>>2] = $30;
 $31 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054976,6)|0);
 HEAP32[3054176>>2] = $31;
 $32 = (__ZN6il2cpp2vm6String4LoadEPKtj(3054992,8)|0);
 HEAP32[3054184>>2] = $32;
 $33 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055008,5)|0);
 HEAP32[3054192>>2] = $33;
 $34 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055024,8)|0);
 HEAP32[3054200>>2] = $34;
 $35 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055040,10)|0);
 HEAP32[3054208>>2] = $35;
 $36 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055064,6)|0);
 HEAP32[3054216>>2] = $36;
 HEAP8[3054224>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B4v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055088>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3055080>>2] = $2;
 HEAP8[3055088>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055104>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3055096>>2] = $2;
 HEAP8[3055104>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B6v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3055112>>2] = $2;
 HEAP8[3055120>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055168>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055176,8)|0);
 HEAP32[3055128>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055192,48)|0);
 HEAP32[3055136>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055288,11)|0);
 HEAP32[3055144>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055312,14)|0);
 HEAP32[3055152>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055344,26)|0);
 HEAP32[3055160>>2] = $6;
 HEAP8[3055168>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B8v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055440>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3055400>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055288,11)|0);
 HEAP32[3055408>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055448,15)|0);
 HEAP32[3055416>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055480,33)|0);
 HEAP32[3055424>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3055432>>2] = $6;
 HEAP8[3055440>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1B9v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055560>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3055552>>2] = $2;
 HEAP8[3055560>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1BAv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055584>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3055568>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3055576>>2] = $3;
 HEAP8[3055584>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1BBv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055640>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3055592>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3055600>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3055608>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3055616>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055648,51)|0);
 HEAP32[3055624>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3055632>>2] = $7;
 HEAP8[3055640>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C3v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055760>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3055768,10)|0);
 HEAP32[3055752>>2] = $2;
 HEAP8[3055760>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1BCv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055832>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3055792>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3055800>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3055808>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3055816>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3055824>>2] = $6;
 HEAP8[3055832>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1BDv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055848>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3055840>>2] = $2;
 HEAP8[3055848>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1BEv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055928>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3055856>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3055864>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3055872>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3055880>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3055888>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3055896>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3055904>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3055912>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3055920>>2] = $10;
 HEAP8[3055928>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1BFv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3055976>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3055936>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3055944>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3055952>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3055960>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3055968>>2] = $6;
 HEAP8[3055976>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C0v() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3056056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3055984>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3055992>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3056000>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3056008>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3056016>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3056024>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3056032>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3056040>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3056048>>2] = $10;
 HEAP8[3056056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3056104>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3056064>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3056072>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3056080>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3056088>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3056096>>2] = $6;
 HEAP8[3056104>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3056120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3056112>>2] = $2;
 HEAP8[3056120>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C4v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3056224>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3056128>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056232,36)|0);
 HEAP32[3056136>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005784,6)|0);
 HEAP32[3056144>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056304,32)|0);
 HEAP32[3056152>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002216,8)|0);
 HEAP32[3056160>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056368,35)|0);
 HEAP32[3056168>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056440,11)|0);
 HEAP32[3056176>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056464,29)|0);
 HEAP32[3056184>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002216,8)|0);
 HEAP32[3056192>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056528,34)|0);
 HEAP32[3056200>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3056208>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056600,65)|0);
 HEAP32[3056216>>2] = $13;
 HEAP8[3056224>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C5v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3056768>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056776,13)|0);
 HEAP32[3056736>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056808,8)|0);
 HEAP32[3056744>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056824,13)|0);
 HEAP32[3056752>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056856,15)|0);
 HEAP32[3056760>>2] = $5;
 HEAP8[3056768>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3056904>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056912,29)|0);
 HEAP32[3056888>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3056976,36)|0);
 HEAP32[3056896>>2] = $3;
 HEAP8[3056904>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C7v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3057048>>2] = $2;
 HEAP8[3057056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057072>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3057064>>2] = $2;
 HEAP8[3057072>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1C9v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057096>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057104,4)|0);
 HEAP32[3057080>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057112,40)|0);
 HEAP32[3057088>>2] = $3;
 HEAP8[3057096>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1CAv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057272>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053336,1)|0);
 HEAP32[3057192>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053336,1)|0);
 HEAP32[3057200>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057280,8)|0);
 HEAP32[3057208>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057296,19)|0);
 HEAP32[3057216>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057280,8)|0);
 HEAP32[3057224>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057280,8)|0);
 HEAP32[3057232>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057336,6)|0);
 HEAP32[3057240>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057352,6)|0);
 HEAP32[3057248>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057336,6)|0);
 HEAP32[3057256>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057336,6)|0);
 HEAP32[3057264>>2] = $11;
 HEAP8[3057272>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1CBv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057408>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3057368>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3057376>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057384>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3057392>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057400>>2] = $6;
 HEAP8[3057408>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1CCv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057488>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3057416>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057424>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3057432>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057440>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3057448>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057456>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3057464>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057472>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057480>>2] = $10;
 HEAP8[3057488>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1CDv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057536>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057496>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3057504>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057512>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3057520>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057528>>2] = $6;
 HEAP8[3057536>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1CEv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057616>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057544>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3057552>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3057560>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057568>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3057576>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057584>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3057592>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057600>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057608>>2] = $10;
 HEAP8[3057616>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1CFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3057624>>2] = $2;
 HEAP8[3057632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D0v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057672>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057680,5)|0);
 HEAP32[3057640>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057696,15)|0);
 HEAP32[3057648>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057680,5)|0);
 HEAP32[3057656>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3057680,5)|0);
 HEAP32[3057664>>2] = $5;
 HEAP8[3057672>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057768>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3057728>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3057736>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057744>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3057752>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057760>>2] = $6;
 HEAP8[3057768>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D2v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3057992>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3057776>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057784>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3057792>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057800>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3057808>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057816>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3057824>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3057832>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058000,64)|0);
 HEAP32[3057840>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057848>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057856>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057864>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057872>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057880>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057888>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057896>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057904>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057912>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057920>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057928>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057936>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057944>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057952>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057960>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057968>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3057976>>2] = $27;
 $28 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3057984>>2] = $28;
 HEAP8[3057992>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D3v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058168>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3058128>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3058136>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058144>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3058152>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058160>>2] = $6;
 HEAP8[3058168>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D4v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058368>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3058176>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058184>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3058192>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058200>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3058208>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058216>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3058224>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058232>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3058240>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058248>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058376,15)|0);
 HEAP32[3058256>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058264>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3058272>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058280>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058376,15)|0);
 HEAP32[3058288>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058296>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3058304>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058312>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058376,15)|0);
 HEAP32[3058320>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058328>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3058336>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058344>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058376,15)|0);
 HEAP32[3058352>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058360>>2] = $25;
 HEAP8[3058368>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D5v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058424>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058376,15)|0);
 HEAP32[3058408>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058416>>2] = $3;
 HEAP8[3058424>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058448>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058456,5)|0);
 HEAP32[3058432>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058472,15)|0);
 HEAP32[3058440>>2] = $3;
 HEAP8[3058448>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058544>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058504>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3058512>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058520>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3058528>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058536>>2] = $6;
 HEAP8[3058544>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058560>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058552>>2] = $2;
 HEAP8[3058560>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1D9v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058568>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3058576>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3058584>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058592>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3058600>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058608>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3058616>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058624>>2] = $9;
 HEAP8[3058632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1DAv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058656>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3058664,18)|0);
 HEAP32[3058640>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3058648>>2] = $3;
 HEAP8[3058656>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1DBv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058736>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058704>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3058712>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3058720>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3058728>>2] = $5;
 HEAP8[3058736>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1DCv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3058744>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3058752>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058760>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3058768>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058776>>2] = $6;
 HEAP8[3058784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1DDv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058856>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3058792>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058800>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3058808>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058816>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3058824>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058832>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3058840>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3058848>>2] = $9;
 HEAP8[3058856>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1DEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058912>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3058864>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058872>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3058880>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058888>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3058896>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3058904>>2] = $7;
 HEAP8[3058912>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1DFv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3058992>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053336,1)|0);
 HEAP32[3058920>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059000,11)|0);
 HEAP32[3058928>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059024,20)|0);
 HEAP32[3058936>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059000,11)|0);
 HEAP32[3058944>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059000,11)|0);
 HEAP32[3058952>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059064,6)|0);
 HEAP32[3058960>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059080,7)|0);
 HEAP32[3058968>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059064,6)|0);
 HEAP32[3058976>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059064,6)|0);
 HEAP32[3058984>>2] = $10;
 HEAP8[3058992>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E0v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059136>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3059096>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3059104>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059112>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3059120>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059128>>2] = $6;
 HEAP8[3059136>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059152>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3059144>>2] = $2;
 HEAP8[3059152>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E2v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059176>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3059160>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3059168>>2] = $3;
 HEAP8[3059176>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E3v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059248>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3059184>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3059192>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3059200>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059208>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3059216>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059224>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3059232>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059240>>2] = $9;
 HEAP8[3059248>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E4v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3059256>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3059264>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052864,9)|0);
 HEAP32[3059272>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3059280>>2] = $5;
 HEAP8[3059288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3059296>>2] = $2;
 HEAP8[3059304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3059312>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3059320>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059328>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3059336>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059344>>2] = $6;
 HEAP8[3059352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059424>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3059360>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052680,5)|0);
 HEAP32[3059368>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052888,9)|0);
 HEAP32[3059376>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059384>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3053088,9)|0);
 HEAP32[3059392>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059400>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052840,9)|0);
 HEAP32[3059408>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059416>>2] = $9;
 HEAP8[3059424>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E8v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052824,5)|0);
 HEAP32[3059432>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002288,5)|0);
 HEAP32[3059440>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059448>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3059456>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052696,14)|0);
 HEAP32[3059464>>2] = $6;
 HEAP8[3059472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1E9v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059488>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3052912,21)|0);
 HEAP32[3059480>>2] = $2;
 HEAP8[3059488>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1EAv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059504>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3059496>>2] = $2;
 HEAP8[3059504>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1EBv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059520>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3059512>>2] = $2;
 HEAP8[3059520>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1ECv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059576>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059584,24)|0);
 HEAP32[3059528>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005688,4)|0);
 HEAP32[3059536>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059632,9)|0);
 HEAP32[3059544>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(2990712,2)|0);
 HEAP32[3059552>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059656,40)|0);
 HEAP32[3059560>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059736,50)|0);
 HEAP32[3059568>>2] = $7;
 HEAP8[3059576>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1EDv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059584,24)|0);
 HEAP32[3059840>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005688,4)|0);
 HEAP32[3059848>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059880,30)|0);
 HEAP32[3059856>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059944,11)|0);
 HEAP32[3059864>>2] = $5;
 HEAP8[3059872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1EEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3059984>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005688,4)|0);
 HEAP32[3059968>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3059992,56)|0);
 HEAP32[3059976>>2] = $3;
 HEAP8[3059984>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1EFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060112>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060120,38)|0);
 HEAP32[3060104>>2] = $2;
 HEAP8[3060112>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3060200>>2] = $2;
 HEAP8[3060208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F2v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060224>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060232,16)|0);
 HEAP32[3060216>>2] = $2;
 HEAP8[3060224>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F1v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060272>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060280,46)|0);
 HEAP32[3060264>>2] = $2;
 HEAP8[3060272>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F3v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060384>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060392,9)|0);
 HEAP32[3060376>>2] = $2;
 HEAP8[3060384>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F4v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060424>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060432,24)|0);
 HEAP32[3060416>>2] = $2;
 HEAP8[3060424>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F5v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060488>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060432,24)|0);
 HEAP32[3060480>>2] = $2;
 HEAP8[3060488>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F6v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060504>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060512,25)|0);
 HEAP32[3060496>>2] = $2;
 HEAP8[3060504>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F7v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060576>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060512,25)|0);
 HEAP32[3060568>>2] = $2;
 HEAP8[3060576>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060600,11)|0);
 HEAP32[3060584>>2] = $2;
 HEAP8[3060592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1F9v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060640,63)|0);
 HEAP32[3060624>>2] = $2;
 HEAP8[3060632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1FAv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3060800>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3060768>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005752,10)|0);
 HEAP32[3060776>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060808,86)|0);
 HEAP32[3060784>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3060984,107)|0);
 HEAP32[3060792>>2] = $5;
 HEAP8[3060800>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1FBv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3061216>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002272,5)|0);
 HEAP32[3061200>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061224,38)|0);
 HEAP32[3061208>>2] = $3;
 HEAP8[3061216>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1FCv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3061376>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061384,3)|0);
 HEAP32[3061304>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061392,3)|0);
 HEAP32[3061312>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061400,9)|0);
 HEAP32[3061320>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008064,29)|0);
 HEAP32[3061328>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061424,9)|0);
 HEAP32[3061336>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008064,29)|0);
 HEAP32[3061344>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005912,5)|0);
 HEAP32[3061352>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3008064,29)|0);
 HEAP32[3061360>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061448,146)|0);
 HEAP32[3061368>>2] = $10;
 HEAP8[3061376>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1FDv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3061752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061760,26)|0);
 HEAP32[3061744>>2] = $2;
 HEAP8[3061752>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1FEv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3061824>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061832,35)|0);
 HEAP32[3061816>>2] = $2;
 HEAP8[3061824>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_1FFv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3061912>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061920,62)|0);
 HEAP32[3061904>>2] = $2;
 HEAP8[3061912>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_200v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062064>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061920,62)|0);
 HEAP32[3062048>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062072,81)|0);
 HEAP32[3062056>>2] = $3;
 HEAP8[3062064>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_201v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062256>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062264,61)|0);
 HEAP32[3062240>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062392,81)|0);
 HEAP32[3062248>>2] = $3;
 HEAP8[3062256>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_202v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061920,62)|0);
 HEAP32[3062560>>2] = $2;
 HEAP8[3062568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_203v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062584>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061920,62)|0);
 HEAP32[3062576>>2] = $2;
 HEAP8[3062584>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_204v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062600>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062608,32)|0);
 HEAP32[3062592>>2] = $2;
 HEAP8[3062600>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_205v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061920,62)|0);
 HEAP32[3062672>>2] = $2;
 HEAP8[3062680>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_206v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062696>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061832,35)|0);
 HEAP32[3062688>>2] = $2;
 HEAP8[3062696>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_207v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062712>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061832,35)|0);
 HEAP32[3062704>>2] = $2;
 HEAP8[3062712>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_208v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062728>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3061832,35)|0);
 HEAP32[3062720>>2] = $2;
 HEAP8[3062728>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_209v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062744>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062752,62)|0);
 HEAP32[3062736>>2] = $2;
 HEAP8[3062744>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_20Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062888>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062752,62)|0);
 HEAP32[3062880>>2] = $2;
 HEAP8[3062888>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_20Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062904>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3062896>>2] = $2;
 HEAP8[3062904>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_20Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3062992>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063000,32)|0);
 HEAP32[3062984>>2] = $2;
 HEAP8[3062992>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_20Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063072>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063000,32)|0);
 HEAP32[3063064>>2] = $2;
 HEAP8[3063072>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_20Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063088>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063096,35)|0);
 HEAP32[3063080>>2] = $2;
 HEAP8[3063088>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_20Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063176>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063096,35)|0);
 HEAP32[3063168>>2] = $2;
 HEAP8[3063176>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_210v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063192>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3063184>>2] = $2;
 HEAP8[3063192>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_211v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3063200>>2] = $2;
 HEAP8[3063208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_212v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063224>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3063216>>2] = $2;
 HEAP8[3063224>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_213v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063240>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3063232>>2] = $2;
 HEAP8[3063240>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_214v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063256>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3063248>>2] = $2;
 HEAP8[3063256>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_215v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063272>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3063264>>2] = $2;
 HEAP8[3063272>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_216v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3063280>>2] = $2;
 HEAP8[3063288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_217v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3062912,33)|0);
 HEAP32[3063296>>2] = $2;
 HEAP8[3063304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_218v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063320>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063328,36)|0);
 HEAP32[3063312>>2] = $2;
 HEAP8[3063320>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_219v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063408>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063416,64)|0);
 HEAP32[3063400>>2] = $2;
 HEAP8[3063408>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_21Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063552>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063416,64)|0);
 HEAP32[3063544>>2] = $2;
 HEAP8[3063552>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_21Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063416,64)|0);
 HEAP32[3063560>>2] = $2;
 HEAP8[3063568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_21Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063584>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063416,64)|0);
 HEAP32[3063576>>2] = $2;
 HEAP8[3063584>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_21Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063600>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063416,64)|0);
 HEAP32[3063592>>2] = $2;
 HEAP8[3063600>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_21Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063616>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063328,36)|0);
 HEAP32[3063608>>2] = $2;
 HEAP8[3063616>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_21Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063328,36)|0);
 HEAP32[3063624>>2] = $2;
 HEAP8[3063632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_220v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063648>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063328,36)|0);
 HEAP32[3063640>>2] = $2;
 HEAP8[3063648>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_221v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063664>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063672,64)|0);
 HEAP32[3063656>>2] = $2;
 HEAP8[3063664>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_222v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063808>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063672,64)|0);
 HEAP32[3063800>>2] = $2;
 HEAP8[3063808>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_223v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063824>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063672,64)|0);
 HEAP32[3063816>>2] = $2;
 HEAP8[3063824>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_224v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063672,64)|0);
 HEAP32[3063832>>2] = $2;
 HEAP8[3063840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_225v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063856>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063864,36)|0);
 HEAP32[3063848>>2] = $2;
 HEAP8[3063856>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_226v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063944>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063864,36)|0);
 HEAP32[3063936>>2] = $2;
 HEAP8[3063944>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_227v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3063960>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063968,64)|0);
 HEAP32[3063952>>2] = $2;
 HEAP8[3063960>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_228v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064104>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063968,64)|0);
 HEAP32[3064096>>2] = $2;
 HEAP8[3064104>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_229v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3063968,64)|0);
 HEAP32[3064112>>2] = $2;
 HEAP8[3064120>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_22Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064136>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064144,36)|0);
 HEAP32[3064128>>2] = $2;
 HEAP8[3064136>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_22Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064224>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064232,36)|0);
 HEAP32[3064216>>2] = $2;
 HEAP8[3064224>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_22Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064312>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064232,36)|0);
 HEAP32[3064304>>2] = $2;
 HEAP8[3064312>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_22Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064328>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064336,64)|0);
 HEAP32[3064320>>2] = $2;
 HEAP8[3064328>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_22Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064336,64)|0);
 HEAP32[3064464>>2] = $2;
 HEAP8[3064472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_22Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064488>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064496,63)|0);
 HEAP32[3064480>>2] = $2;
 HEAP8[3064488>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_230v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064336,64)|0);
 HEAP32[3064624>>2] = $2;
 HEAP8[3064632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_231v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064648>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064336,64)|0);
 HEAP32[3064640>>2] = $2;
 HEAP8[3064648>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_232v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064664>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064336,64)|0);
 HEAP32[3064656>>2] = $2;
 HEAP8[3064664>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_233v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3064672>>2] = $2;
 HEAP8[3064680>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_234v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064696>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064232,36)|0);
 HEAP32[3064688>>2] = $2;
 HEAP8[3064696>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_235v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064712>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064232,36)|0);
 HEAP32[3064704>>2] = $2;
 HEAP8[3064712>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_236v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064728>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064232,36)|0);
 HEAP32[3064720>>2] = $2;
 HEAP8[3064728>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_237v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064744>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064752,66)|0);
 HEAP32[3064736>>2] = $2;
 HEAP8[3064744>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_238v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064752,66)|0);
 HEAP32[3064888>>2] = $2;
 HEAP8[3064896>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_239v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064912>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064752,66)|0);
 HEAP32[3064904>>2] = $2;
 HEAP8[3064912>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_23Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064928>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064752,66)|0);
 HEAP32[3064920>>2] = $2;
 HEAP8[3064928>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_23Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064944>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064752,66)|0);
 HEAP32[3064936>>2] = $2;
 HEAP8[3064944>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_23Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3064960>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064968,34)|0);
 HEAP32[3064952>>2] = $2;
 HEAP8[3064960>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_23Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065048>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3064968,34)|0);
 HEAP32[3065040>>2] = $2;
 HEAP8[3065048>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_23Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065064>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065072,37)|0);
 HEAP32[3065056>>2] = $2;
 HEAP8[3065064>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_23Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065160>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065072,37)|0);
 HEAP32[3065152>>2] = $2;
 HEAP8[3065160>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_240v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065176>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065184,66)|0);
 HEAP32[3065168>>2] = $2;
 HEAP8[3065176>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_241v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065328>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065184,66)|0);
 HEAP32[3065320>>2] = $2;
 HEAP8[3065328>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_242v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065344>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065184,66)|0);
 HEAP32[3065336>>2] = $2;
 HEAP8[3065344>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_243v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065360>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065368,34)|0);
 HEAP32[3065352>>2] = $2;
 HEAP8[3065360>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_244v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065448>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065184,66)|0);
 HEAP32[3065440>>2] = $2;
 HEAP8[3065448>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_245v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065464>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065368,34)|0);
 HEAP32[3065456>>2] = $2;
 HEAP8[3065464>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_246v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065480>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065368,34)|0);
 HEAP32[3065472>>2] = $2;
 HEAP8[3065480>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_247v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065496>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065504,37)|0);
 HEAP32[3065488>>2] = $2;
 HEAP8[3065496>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_248v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065600,66)|0);
 HEAP32[3065584>>2] = $2;
 HEAP8[3065592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_249v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065744>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065600,66)|0);
 HEAP32[3065736>>2] = $2;
 HEAP8[3065744>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_24Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065760>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065600,66)|0);
 HEAP32[3065752>>2] = $2;
 HEAP8[3065760>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_24Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065776>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065784,34)|0);
 HEAP32[3065768>>2] = $2;
 HEAP8[3065776>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_24Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065864>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065784,34)|0);
 HEAP32[3065856>>2] = $2;
 HEAP8[3065864>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_24Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065880>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065784,34)|0);
 HEAP32[3065872>>2] = $2;
 HEAP8[3065880>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_24Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065784,34)|0);
 HEAP32[3065888>>2] = $2;
 HEAP8[3065896>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_24Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065912>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3065920,14)|0);
 HEAP32[3065904>>2] = $2;
 HEAP8[3065912>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_250v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3065992>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3066000,49)|0);
 HEAP32[3065952>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3066104,32)|0);
 HEAP32[3065960>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3066168,44)|0);
 HEAP32[3065968>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3066256,35)|0);
 HEAP32[3065976>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3066328,4)|0);
 HEAP32[3065984>>2] = $6;
 HEAP8[3065992>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_251v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3066352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3066360,47)|0);
 HEAP32[3066336>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3066456,5)|0);
 HEAP32[3066344>>2] = $3;
 HEAP8[3066352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_252v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3066480>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3066488,48)|0);
 HEAP32[3066472>>2] = $2;
 HEAP8[3066480>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_253v() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3067120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067128,16)|0);
 HEAP32[3066584>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067160,13)|0);
 HEAP32[3066592>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067192,12)|0);
 HEAP32[3066600>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067216,8)|0);
 HEAP32[3066608>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067232,5)|0);
 HEAP32[3066616>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067248,6)|0);
 HEAP32[3066624>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067264,3)|0);
 HEAP32[3066632>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067272,4)|0);
 HEAP32[3066640>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067280,12)|0);
 HEAP32[3066648>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067304,9)|0);
 HEAP32[3066656>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067328,9)|0);
 HEAP32[3066664>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067352,14)|0);
 HEAP32[3066672>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067384,11)|0);
 HEAP32[3066680>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067408,10)|0);
 HEAP32[3066688>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067432,11)|0);
 HEAP32[3066696>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067456,10)|0);
 HEAP32[3066704>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067480,11)|0);
 HEAP32[3066712>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067504,10)|0);
 HEAP32[3066720>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067528,6)|0);
 HEAP32[3066728>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067304,9)|0);
 HEAP32[3066736>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067328,9)|0);
 HEAP32[3066744>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067352,14)|0);
 HEAP32[3066752>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067544,11)|0);
 HEAP32[3066760>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067568,10)|0);
 HEAP32[3066768>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067592,11)|0);
 HEAP32[3066776>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067616,10)|0);
 HEAP32[3066784>>2] = $27;
 $28 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067640,11)|0);
 HEAP32[3066792>>2] = $28;
 $29 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067664,10)|0);
 HEAP32[3066800>>2] = $29;
 $30 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067688,9)|0);
 HEAP32[3066808>>2] = $30;
 $31 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067712,8)|0);
 HEAP32[3066816>>2] = $31;
 $32 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067728,8)|0);
 HEAP32[3066824>>2] = $32;
 $33 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067304,9)|0);
 HEAP32[3066832>>2] = $33;
 $34 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067328,9)|0);
 HEAP32[3066840>>2] = $34;
 $35 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067352,14)|0);
 HEAP32[3066848>>2] = $35;
 $36 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067544,11)|0);
 HEAP32[3066856>>2] = $36;
 $37 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067568,10)|0);
 HEAP32[3066864>>2] = $37;
 $38 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067432,11)|0);
 HEAP32[3066872>>2] = $38;
 $39 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067456,10)|0);
 HEAP32[3066880>>2] = $39;
 $40 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067640,11)|0);
 HEAP32[3066888>>2] = $40;
 $41 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067664,10)|0);
 HEAP32[3066896>>2] = $41;
 $42 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067744,9)|0);
 HEAP32[3066904>>2] = $42;
 $43 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067768,8)|0);
 HEAP32[3066912>>2] = $43;
 $44 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067784,8)|0);
 HEAP32[3066920>>2] = $44;
 $45 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067712,8)|0);
 HEAP32[3066928>>2] = $45;
 $46 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067800,8)|0);
 HEAP32[3066936>>2] = $46;
 $47 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067728,8)|0);
 HEAP32[3066944>>2] = $47;
 $48 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067304,9)|0);
 HEAP32[3066952>>2] = $48;
 $49 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067328,9)|0);
 HEAP32[3066960>>2] = $49;
 $50 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067352,14)|0);
 HEAP32[3066968>>2] = $50;
 $51 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067544,11)|0);
 HEAP32[3066976>>2] = $51;
 $52 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067568,10)|0);
 HEAP32[3066984>>2] = $52;
 $53 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067592,11)|0);
 HEAP32[3066992>>2] = $53;
 $54 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067616,10)|0);
 HEAP32[3067000>>2] = $54;
 $55 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067640,11)|0);
 HEAP32[3067008>>2] = $55;
 $56 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067664,10)|0);
 HEAP32[3067016>>2] = $56;
 $57 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067816,9)|0);
 HEAP32[3067024>>2] = $57;
 $58 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067728,8)|0);
 HEAP32[3067032>>2] = $58;
 $59 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067840,8)|0);
 HEAP32[3067040>>2] = $59;
 $60 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067768,8)|0);
 HEAP32[3067048>>2] = $60;
 $61 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067784,8)|0);
 HEAP32[3067056>>2] = $61;
 $62 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067712,8)|0);
 HEAP32[3067064>>2] = $62;
 $63 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067856,6)|0);
 HEAP32[3067072>>2] = $63;
 $64 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067872,5)|0);
 HEAP32[3067080>>2] = $64;
 $65 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067888,9)|0);
 HEAP32[3067088>>2] = $65;
 $66 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067912,6)|0);
 HEAP32[3067096>>2] = $66;
 $67 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067928,6)|0);
 HEAP32[3067104>>2] = $67;
 $68 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067888,9)|0);
 HEAP32[3067112>>2] = $68;
 HEAP8[3067120>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_254v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3067952>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002872,10)|0);
 HEAP32[3067944>>2] = $2;
 HEAP8[3067952>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_255v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3067968>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3067976,30)|0);
 HEAP32[3067960>>2] = $2;
 HEAP8[3067968>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_256v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068064,27)|0);
 HEAP32[3068040>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068120,4)|0);
 HEAP32[3068048>>2] = $3;
 HEAP8[3068056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_257v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068136>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3068128>>2] = $2;
 HEAP8[3068136>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_258v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068168>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068176,46)|0);
 HEAP32[3068144>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068272,45)|0);
 HEAP32[3068152>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068176,46)|0);
 HEAP32[3068160>>2] = $4;
 HEAP8[3068168>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_259v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068392>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068400,51)|0);
 HEAP32[3068368>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068504,61)|0);
 HEAP32[3068376>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068632,61)|0);
 HEAP32[3068384>>2] = $4;
 HEAP8[3068392>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_25Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068768>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996992,1)|0);
 HEAP32[3068760>>2] = $2;
 HEAP8[3068768>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_25Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068792,3)|0);
 HEAP32[3068776>>2] = $2;
 HEAP8[3068784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_25Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068808>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068816,21)|0);
 HEAP32[3068800>>2] = $2;
 HEAP8[3068808>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_25Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010128,1)|0);
 HEAP32[3068864>>2] = $2;
 HEAP8[3068872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_25Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3068896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010128,1)|0);
 HEAP32[3068880>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068904,83)|0);
 HEAP32[3068888>>2] = $3;
 HEAP8[3068896>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_25Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3069080>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3069088,108)|0);
 HEAP32[3069072>>2] = $2;
 HEAP8[3069080>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_260v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3069344>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3069352,56)|0);
 HEAP32[3069304>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3069464,96)|0);
 HEAP32[3069312>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3069656,41)|0);
 HEAP32[3069320>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3069744,55)|0);
 HEAP32[3069328>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3069856,73)|0);
 HEAP32[3069336>>2] = $6;
 HEAP8[3069344>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_261v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070032>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3070008>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070040,8)|0);
 HEAP32[3070016>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070056,13)|0);
 HEAP32[3070024>>2] = $4;
 HEAP8[3070032>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_262v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070112>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3070088>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070120,4)|0);
 HEAP32[3070096>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3068904,83)|0);
 HEAP32[3070104>>2] = $4;
 HEAP8[3070112>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_263v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070144>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070152,14)|0);
 HEAP32[3070128>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070152,14)|0);
 HEAP32[3070136>>2] = $3;
 HEAP8[3070144>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_264v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070208>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3070184>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3070192>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3070200>>2] = $4;
 HEAP8[3070208>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_265v() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070296,21)|0);
 HEAP32[3070216>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070344,2)|0);
 HEAP32[3070224>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070344,2)|0);
 HEAP32[3070232>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070344,2)|0);
 HEAP32[3070240>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070344,2)|0);
 HEAP32[3070248>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070344,2)|0);
 HEAP32[3070256>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070352,28)|0);
 HEAP32[3070264>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070408,17)|0);
 HEAP32[3070272>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070448,28)|0);
 HEAP32[3070280>>2] = $10;
 HEAP8[3070288>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_266v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070520>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070528,6)|0);
 HEAP32[3070504>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070544,8)|0);
 HEAP32[3070512>>2] = $3;
 HEAP8[3070520>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_267v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070576,16)|0);
 HEAP32[3070560>>2] = $2;
 HEAP8[3070568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_268v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070616>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070624,14)|0);
 HEAP32[3070608>>2] = $2;
 HEAP8[3070616>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_269v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070664>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070672,50)|0);
 HEAP32[3070656>>2] = $2;
 HEAP8[3070664>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_26Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070792,15)|0);
 HEAP32[3070776>>2] = $2;
 HEAP8[3070784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_26Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070832>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070840,21)|0);
 HEAP32[3070824>>2] = $2;
 HEAP8[3070832>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_26Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3070896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3070904,39)|0);
 HEAP32[3070888>>2] = $2;
 HEAP8[3070896>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_26Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071000>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3070984>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071008,51)|0);
 HEAP32[3070992>>2] = $3;
 HEAP8[3071000>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_26Ev() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071152>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993256,1)|0);
 HEAP32[3071112>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071160,1)|0);
 HEAP32[3071120>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071168,1)|0);
 HEAP32[3071128>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071176,1)|0);
 HEAP32[3071136>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071184,91)|0);
 HEAP32[3071144>>2] = $6;
 HEAP8[3071152>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_26Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071376>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071384,28)|0);
 HEAP32[3071368>>2] = $2;
 HEAP8[3071376>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_270v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071448>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071456,49)|0);
 HEAP32[3071440>>2] = $2;
 HEAP8[3071448>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_271v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071568>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071576,61)|0);
 HEAP32[3071560>>2] = $2;
 HEAP8[3071568>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_272v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071712>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071720,19)|0);
 HEAP32[3071704>>2] = $2;
 HEAP8[3071712>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_273v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071768>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071720,19)|0);
 HEAP32[3071760>>2] = $2;
 HEAP8[3071768>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_274v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071792,29)|0);
 HEAP32[3071776>>2] = $2;
 HEAP8[3071784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_275v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071864>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071872,26)|0);
 HEAP32[3071856>>2] = $2;
 HEAP8[3071864>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_277v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3071936>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3071944,25)|0);
 HEAP32[3071928>>2] = $2;
 HEAP8[3071936>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_276v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072024>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072032,11)|0);
 HEAP32[3072000>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072056,12)|0);
 HEAP32[3072008>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072080,11)|0);
 HEAP32[3072016>>2] = $4;
 HEAP8[3072024>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_278v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072112>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072120,28)|0);
 HEAP32[3072104>>2] = $2;
 HEAP8[3072112>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_279v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072184>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072192,46)|0);
 HEAP32[3072176>>2] = $2;
 HEAP8[3072184>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_27Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022760,3)|0);
 HEAP32[3072288>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072312,13)|0);
 HEAP32[3072296>>2] = $3;
 HEAP8[3072304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_27Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022760,3)|0);
 HEAP32[3072344>>2] = $2;
 HEAP8[3072352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_27Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072368>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072312,13)|0);
 HEAP32[3072360>>2] = $2;
 HEAP8[3072368>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_27Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072384>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072392,75)|0);
 HEAP32[3072376>>2] = $2;
 HEAP8[3072384>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_27Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072552>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3005688,4)|0);
 HEAP32[3072544>>2] = $2;
 HEAP8[3072552>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_27Fv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3072768>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072776,12)|0);
 HEAP32[3072560>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016704,4)|0);
 HEAP32[3072568>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072800,43)|0);
 HEAP32[3072576>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072776,12)|0);
 HEAP32[3072584>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072888,46)|0);
 HEAP32[3072592>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072776,12)|0);
 HEAP32[3072600>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072984,53)|0);
 HEAP32[3072608>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072776,12)|0);
 HEAP32[3072616>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073096,56)|0);
 HEAP32[3072624>>2] = $10;
 $11 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072776,12)|0);
 HEAP32[3072632>>2] = $11;
 $12 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073208,61)|0);
 HEAP32[3072640>>2] = $12;
 $13 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073336,68)|0);
 HEAP32[3072648>>2] = $13;
 $14 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072776,12)|0);
 HEAP32[3072656>>2] = $14;
 $15 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073472,21)|0);
 HEAP32[3072664>>2] = $15;
 $16 = (__ZN6il2cpp2vm6String4LoadEPKtj(3036592,12)|0);
 HEAP32[3072672>>2] = $16;
 $17 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073520,26)|0);
 HEAP32[3072680>>2] = $17;
 $18 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073576,28)|0);
 HEAP32[3072688>>2] = $18;
 $19 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073632,19)|0);
 HEAP32[3072696>>2] = $19;
 $20 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3072704>>2] = $20;
 $21 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073672,53)|0);
 HEAP32[3072712>>2] = $21;
 $22 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073784,10)|0);
 HEAP32[3072720>>2] = $22;
 $23 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073808,12)|0);
 HEAP32[3072728>>2] = $23;
 $24 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073832,59)|0);
 HEAP32[3072736>>2] = $24;
 $25 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072776,12)|0);
 HEAP32[3072744>>2] = $25;
 $26 = (__ZN6il2cpp2vm6String4LoadEPKtj(3073952,21)|0);
 HEAP32[3072752>>2] = $26;
 $27 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3072760>>2] = $27;
 HEAP8[3072768>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_280v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074008>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3072312,13)|0);
 HEAP32[3074000>>2] = $2;
 HEAP8[3074008>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_281v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074024>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074032,41)|0);
 HEAP32[3074016>>2] = $2;
 HEAP8[3074024>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_282v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074128>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074136,27)|0);
 HEAP32[3074120>>2] = $2;
 HEAP8[3074128>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_283v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074200>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074208,61)|0);
 HEAP32[3074192>>2] = $2;
 HEAP8[3074200>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_284v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074360,22)|0);
 HEAP32[3074336>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074408,12)|0);
 HEAP32[3074344>>2] = $3;
 HEAP8[3074352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_285v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074448>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074360,22)|0);
 HEAP32[3074432>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074408,12)|0);
 HEAP32[3074440>>2] = $3;
 HEAP8[3074448>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_286v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074464>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011448,1)|0);
 HEAP32[3074456>>2] = $2;
 HEAP8[3074464>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_287v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074488>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011448,1)|0);
 HEAP32[3074472>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3011448,1)|0);
 HEAP32[3074480>>2] = $3;
 HEAP8[3074488>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_288v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074512>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074520,41)|0);
 HEAP32[3074496>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074520,41)|0);
 HEAP32[3074504>>2] = $3;
 HEAP8[3074512>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_289v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074616>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074624,10)|0);
 HEAP32[3074608>>2] = $2;
 HEAP8[3074616>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_28Av() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074656>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030352,7)|0);
 HEAP32[3074648>>2] = $2;
 HEAP8[3074656>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_28Bv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074688>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074696,9)|0);
 HEAP32[3074664>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074720,8)|0);
 HEAP32[3074672>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074736,12)|0);
 HEAP32[3074680>>2] = $4;
 HEAP8[3074688>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_28Cv() {
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3074832>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074840,20)|0);
 HEAP32[3074760>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074880,16)|0);
 HEAP32[3074768>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074912,20)|0);
 HEAP32[3074776>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074952,20)|0);
 HEAP32[3074784>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3074992,4)|0);
 HEAP32[3074792>>2] = $6;
 $7 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075000,4)|0);
 HEAP32[3074800>>2] = $7;
 $8 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075008,3)|0);
 HEAP32[3074808>>2] = $8;
 $9 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075016,9)|0);
 HEAP32[3074816>>2] = $9;
 $10 = (__ZN6il2cpp2vm6String4LoadEPKtj(2997656,1)|0);
 HEAP32[3074824>>2] = $10;
 HEAP8[3074832>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_28Dv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075048>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075056,14)|0);
 HEAP32[3075040>>2] = $2;
 HEAP8[3075048>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_28Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075096>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075104,16)|0);
 HEAP32[3075088>>2] = $2;
 HEAP8[3075096>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_28Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075144>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075152,51)|0);
 HEAP32[3075136>>2] = $2;
 HEAP8[3075144>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_290v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075280>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3075256>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018504,45)|0);
 HEAP32[3075264>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075288,9)|0);
 HEAP32[3075272>>2] = $4;
 HEAP8[3075280>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_291v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075320>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3022760,3)|0);
 HEAP32[3075312>>2] = $2;
 HEAP8[3075320>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_292v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075336>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3075328>>2] = $2;
 HEAP8[3075336>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_293v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075352>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3002992,1)|0);
 HEAP32[3075344>>2] = $2;
 HEAP8[3075352>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_294v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075368>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075376,37)|0);
 HEAP32[3075360>>2] = $2;
 HEAP8[3075368>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_295v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075464>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075472,30)|0);
 HEAP32[3075456>>2] = $2;
 HEAP8[3075464>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_296v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075552>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075560,30)|0);
 HEAP32[3075536>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2993328,5)|0);
 HEAP32[3075544>>2] = $3;
 HEAP8[3075552>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_297v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075632>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075640,63)|0);
 HEAP32[3075624>>2] = $2;
 HEAP8[3075632>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_298v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075776>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075784,54)|0);
 HEAP32[3075768>>2] = $2;
 HEAP8[3075776>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_299v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075904>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075472,30)|0);
 HEAP32[3075896>>2] = $2;
 HEAP8[3075904>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_29Av() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075944>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075952,2)|0);
 HEAP32[3075912>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075952,2)|0);
 HEAP32[3075920>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075952,2)|0);
 HEAP32[3075928>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075960,2)|0);
 HEAP32[3075936>>2] = $5;
 HEAP8[3075944>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_29Bv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3075976>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3075984,13)|0);
 HEAP32[3075968>>2] = $2;
 HEAP8[3075976>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_29Cv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076024>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076032,24)|0);
 HEAP32[3076016>>2] = $2;
 HEAP8[3076024>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_29Dv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076104>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076112,4)|0);
 HEAP32[3076080>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076120,38)|0);
 HEAP32[3076088>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076200,28)|0);
 HEAP32[3076096>>2] = $4;
 HEAP8[3076104>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_29Ev() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076264>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076200,28)|0);
 HEAP32[3076256>>2] = $2;
 HEAP8[3076264>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_29Fv() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076280>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3016672,8)|0);
 HEAP32[3076272>>2] = $2;
 HEAP8[3076280>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A1v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076304>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076312,46)|0);
 HEAP32[3076288>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076408,26)|0);
 HEAP32[3076296>>2] = $3;
 HEAP8[3076304>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A0v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076472>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076480,35)|0);
 HEAP32[3076464>>2] = $2;
 HEAP8[3076472>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A2v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076592>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3010448,4)|0);
 HEAP32[3076552>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076600,17)|0);
 HEAP32[3076560>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076640,20)|0);
 HEAP32[3076568>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076680,18)|0);
 HEAP32[3076576>>2] = $5;
 $6 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076720,18)|0);
 HEAP32[3076584>>2] = $6;
 HEAP8[3076592>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A3v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076784>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018144,4)|0);
 HEAP32[3076760>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076792,9)|0);
 HEAP32[3076768>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031312,12)|0);
 HEAP32[3076776>>2] = $4;
 HEAP8[3076784>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A4v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076840>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018144,4)|0);
 HEAP32[3076816>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076792,9)|0);
 HEAP32[3076824>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031312,12)|0);
 HEAP32[3076832>>2] = $4;
 HEAP8[3076840>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A5v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076872>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3018144,4)|0);
 HEAP32[3076848>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076792,9)|0);
 HEAP32[3076856>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3031312,12)|0);
 HEAP32[3076864>>2] = $4;
 HEAP8[3076872>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A6v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3076896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3030352,7)|0);
 HEAP32[3076880>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3076904,57)|0);
 HEAP32[3076888>>2] = $3;
 HEAP8[3076896>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A7v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3077056>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3077064,5)|0);
 HEAP32[3077024>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(3077080,5)|0);
 HEAP32[3077032>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(3077096,5)|0);
 HEAP32[3077040>>2] = $4;
 $5 = (__ZN6il2cpp2vm6String4LoadEPKtj(3077112,8)|0);
 HEAP32[3077048>>2] = $5;
 HEAP8[3077056>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A8v() {
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3077136>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(3077144,48)|0);
 HEAP32[3077128>>2] = $2;
 HEAP8[3077136>>0] = 1;
 STACKTOP = sp;return;
}
function __Z21_il2cpp_strinit_s_2A9v() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3077264>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 $2 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3077240>>2] = $2;
 $3 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3077248>>2] = $3;
 $4 = (__ZN6il2cpp2vm6String4LoadEPKtj(2996984,1)|0);
 HEAP32[3077256>>2] = $4;
 HEAP8[3077264>>0] = 1;
 STACKTOP = sp;return;
}
function __ZL22s_mscorlibRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(3083512);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a23365() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(3083592,1007,0,0);
 STACKTOP = sp;return;
}
function __ZL26s_replacementsRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(3083728);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a23371() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(3083816,1008,0,0);
 STACKTOP = sp;return;
}
function __ZL25s_System_CoreRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(3084184);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a23378() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(3084264,1009,0,0);
 STACKTOP = sp;return;
}
function __ZL20s_SystemRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(3084536);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a23385() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(3084616,1010,0,0);
 STACKTOP = sp;return;
}
function __Z39RegisterStaticallyLinkedModulesGranularv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z24RegisterModule_Animationv();
 __Z20RegisterModule_Audiov();
 __Z22RegisterModule_Physicsv();
 __Z22RegisterModule_Terrainv();
 __Z28RegisterModule_TextRenderingv();
 STACKTOP = sp;return;
}
function __Z18RegisterAllClassesv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z23RegisterClass_Componentv();
 __Z24RegisterClass_GameObjectv();
 __Z25RegisterClass_AssetBundlev();
 __Z22RegisterClass_Rendererv();
 __Z22RegisterClass_GUILayerv();
 __Z23RegisterClass_TextAssetv();
 __Z20RegisterClass_Shaderv();
 __Z22RegisterClass_Materialv();
 __Z23RegisterClass_Behaviourv();
 __Z20RegisterClass_Camerav();
 __Z27RegisterClass_MonoBehaviourv();
 __Z23RegisterClass_Transformv();
 __Z23RegisterClass_Rigidbodyv();
 __Z22RegisterClass_Colliderv();
 __Z33RegisterClass_CharacterControllerv();
 __Z23RegisterClass_AudioClipv();
 __Z23RegisterClass_Animationv();
 __Z22RegisterClass_Animatorv();
 __Z21RegisterClass_Terrainv();
 __Z18RegisterClass_Fontv();
 __Z20RegisterClass_Canvasv();
 __Z27RegisterClass_AnimationClipv();
 __Z25RegisterClass_PreloadDatav();
 __Z21RegisterClass_Cubemapv();
 __Z23RegisterClass_Texture3Dv();
 __Z27RegisterClass_RenderTexturev();
 __Z30RegisterClass_LevelGameManagerv();
 __Z25RegisterClass_GameManagerv();
 __Z29RegisterClass_EditorExtensionv();
 __Z26RegisterClass_MeshRendererv();
 __Z21RegisterClass_Texturev();
 __Z23RegisterClass_Texture2Dv();
 __Z24RegisterClass_MeshFilterv();
 __Z18RegisterClass_Meshv();
 __Z26RegisterClass_MeshColliderv();
 __Z27RegisterClass_AudioListenerv();
 __Z32RegisterClass_AnimatorControllerv();
 __Z39RegisterClass_RuntimeAnimatorControllerv();
 __Z22RegisterClass_TextMeshv();
 __Z28RegisterClass_RenderSettingsv();
 __Z19RegisterClass_Lightv();
 __Z24RegisterClass_MonoScriptv();
 __Z24RegisterClass_FlareLayerv();
 __Z25RegisterClass_HaloManagerv();
 __Z25RegisterClass_NamedObjectv();
 __Z30RegisterClass_LightmapSettingsv();
 __Z28RegisterClass_AudioBehaviourv();
 __Z20RegisterClass_Motionv();
 __Z25RegisterClass_LightProbesv();
 __Z25RegisterClass_TimeManagerv();
 __Z26RegisterClass_AudioManagerv();
 __Z26RegisterClass_InputManagerv();
 __Z30RegisterClass_GraphicsSettingsv();
 __Z29RegisterClass_QualitySettingsv();
 __Z28RegisterClass_PhysicsManagerv();
 __Z24RegisterClass_TagManagerv();
 __Z26RegisterClass_ScriptMapperv();
 __Z32RegisterClass_DelayedCallManagerv();
 __Z25RegisterClass_MonoManagerv();
 __Z28RegisterClass_PlayerSettingsv();
 __Z27RegisterClass_BuildSettingsv();
 __Z29RegisterClass_ResourceManagerv();
 STACKTOP = sp;return;
}
function __ZL25s_UnityEngineRegistrationv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp2vm8Assembly8RegisterEP14Il2CppAssembly(3088264);
 STACKTOP = sp;return;
}
function __GLOBAL__I_a23391() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6il2cpp5utils35RegisterRuntimeInitializeAndCleanupC2EPFvvES3_i(3088344,1011,0,0);
 STACKTOP = sp;return;
}
function __Z32RegisterAllStrippedInternalCallsv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __Z40Register_UnityEngine_Animation_CrossFadev();
 __Z39Register_UnityEngine_Animation_GetStatev();
 __Z44Register_UnityEngine_AnimationCurve_Evaluatev();
 __Z43Register_UnityEngine_AnimationCurve_Cleanupv();
 __Z40Register_UnityEngine_AnimationCurve_Initv();
 __Z45Register_UnityEngine_AnimationState_set_speedv();
 __Z48Register_UnityEngine_AnimationState_set_wrapModev();
 __Z42Register_UnityEngine_Animator_StringToHashv();
 __Z34Register_UnityEngine_Animator_Playv();
 __Z54Register_UnityEngine_Application_Internal_ExternalCallv();
 __Z51Register_UnityEngine_AssetBundle_LoadAsset_Internalv();
 __Z64Register_UnityEngine_AssetBundle_LoadAssetWithSubAssets_Internalv();
 __Z72Register_UnityEngine_AssetBundleCreateRequest_DisableCompatibilityChecksv();
 __Z61Register_UnityEngine_AssetBundleCreateRequest_get_assetBundlev();
 __Z51Register_UnityEngine_AsyncOperation_InternalDestroyv();
 __Z42Register_UnityEngine_Behaviour_set_enabledv();
 __Z59Register_UnityEngine_Bounds_INTERNAL_CALL_Internal_Containsv();
 __Z63Register_UnityEngine_Bounds_INTERNAL_CALL_Internal_IntersectRayv();
 __Z62Register_UnityEngine_Bounds_INTERNAL_CALL_Internal_SqrDistancev();
 __Z66Register_UnityEngine_Bounds_INTERNAL_CALL_Internal_GetClosestPointv();
 __Z41Register_UnityEngine_Camera_GetAllCamerasv();
 __Z47Register_UnityEngine_Camera_get_allCamerasCountv();
 __Z43Register_UnityEngine_Camera_get_cullingMaskv();
 __Z41Register_UnityEngine_Camera_get_eventMaskv();
 __Z44Register_UnityEngine_Camera_get_farClipPlanev();
 __Z45Register_UnityEngine_Camera_get_nearClipPlanev();
 __Z50Register_UnityEngine_Camera_INTERNAL_get_pixelRectv();
 __Z36Register_UnityEngine_Camera_get_mainv();
 __Z42Register_UnityEngine_Camera_get_clearFlagsv();
 __Z52Register_UnityEngine_Camera_INTERNAL_CALL_RaycastTryv();
 __Z54Register_UnityEngine_Camera_INTERNAL_CALL_RaycastTry2Dv();
 __Z58Register_UnityEngine_Camera_INTERNAL_CALL_ScreenPointToRayv();
 __Z60Register_UnityEngine_Camera_INTERNAL_CALL_ViewportPointToRayv();
 __Z45Register_UnityEngine_Camera_get_targetTexturev();
 __Z51Register_UnityEngine_CharacterController_get_heightv();
 __Z51Register_UnityEngine_CharacterController_get_radiusv();
 __Z55Register_UnityEngine_CharacterController_get_slopeLimitv();
 __Z55Register_UnityEngine_CharacterController_get_stepOffsetv();
 __Z60Register_UnityEngine_CharacterController_INTERNAL_get_centerv();
 __Z62Register_UnityEngine_CharacterController_INTERNAL_get_velocityv();
 __Z59Register_UnityEngine_CharacterController_INTERNAL_CALL_Movev();
 __Z49Register_UnityEngine_Collider_INTERNAL_get_boundsv();
 __Z41Register_UnityEngine_Collider_set_enabledv();
 __Z42Register_UnityEngine_Component_SendMessagev();
 __Z45Register_UnityEngine_Component_get_gameObjectv();
 __Z44Register_UnityEngine_Component_get_transformv();
 __Z47Register_UnityEngine_Coroutine_ReleaseCoroutinev();
 __Z49Register_UnityEngine_Debug_INTERNAL_CALL_DrawLinev();
 __Z39Register_UnityEngine_Debug_Internal_Logv();
 __Z52Register_UnityEngine_Display_MultiDisplayLicenseImplv();
 __Z48Register_UnityEngine_Display_RelativeMouseAtImplv();
 __Z48Register_UnityEngine_Display_ActivateDisplayImplv();
 __Z52Register_UnityEngine_Display_GetRenderingBuffersImplv();
 __Z48Register_UnityEngine_Display_GetRenderingExtImplv();
 __Z45Register_UnityEngine_Display_GetSystemExtImplv();
 __Z42Register_UnityEngine_Display_SetParamsImplv();
 __Z55Register_UnityEngine_Display_SetRenderingResolutionImplv();
 __Z40Register_UnityEngine_Event_get_characterv();
 __Z42Register_UnityEngine_Event_get_commandNamev();
 __Z34Register_UnityEngine_Event_Cleanupv();
 __Z31Register_UnityEngine_Event_Initv();
 __Z52Register_UnityEngine_Event_Internal_GetMousePositionv();
 __Z50Register_UnityEngine_Event_Internal_SetNativeEventv();
 __Z40Register_UnityEngine_Event_get_modifiersv();
 __Z35Register_UnityEngine_Event_get_typev();
 __Z38Register_UnityEngine_Event_get_keyCodev();
 __Z37Register_UnityEngine_Font_get_dynamicv();
 __Z43Register_UnityEngine_GameObject_SendMessagev();
 __Z39Register_UnityEngine_GameObject_set_tagv();
 __Z44Register_UnityEngine_GameObject_GetComponentv();
 __Z47Register_UnityEngine_GameObject_CreatePrimitivev();
 __Z45Register_UnityEngine_GameObject_get_transformv();
 __Z37Register_UnityEngine_Gradient_Cleanupv();
 __Z34Register_UnityEngine_Gradient_Initv();
 __Z36Register_UnityEngine_GUI_set_changedv();
 __Z51Register_UnityEngine_GUILayer_INTERNAL_CALL_HitTestv();
 __Z71Register_UnityEngine_GUILayoutUtility_INTERNAL_CALL_Internal_MoveWindowv();
 __Z60Register_UnityEngine_GUILayoutUtility_Internal_GetWindowRectv();
 __Z47Register_UnityEngine_GUIStyle_get_stretchHeightv();
 __Z46Register_UnityEngine_GUIStyle_get_stretchWidthv();
 __Z46Register_UnityEngine_GUIStyle_GetRectOffsetPtrv();
 __Z46Register_UnityEngine_GUIStyle_GetStyleStatePtrv();
 __Z45Register_UnityEngine_GUIStyle_get_fixedHeightv();
 __Z44Register_UnityEngine_GUIStyle_get_fixedWidthv();
 __Z38Register_UnityEngine_GUIStyle_get_namev();
 __Z37Register_UnityEngine_GUIStyle_Cleanupv();
 __Z34Register_UnityEngine_GUIStyle_Initv();
 __Z44Register_UnityEngine_GUIStyle_SetDefaultFontv();
 __Z38Register_UnityEngine_GUIStyle_set_namev();
 __Z47Register_UnityEngine_GUIStyle_set_stretchHeightv();
 __Z46Register_UnityEngine_GUIStyle_set_stretchWidthv();
 __Z42Register_UnityEngine_GUIStyleState_Cleanupv();
 __Z57Register_UnityEngine_GUIStyleState_INTERNAL_set_textColorv();
 __Z56Register_UnityEngine_GUIStyleState_GetBackgroundInternalv();
 __Z52Register_UnityEngine_GUIUtility_Internal_GetGUIDepthv();
 __Z48Register_UnityEngine_GUIUtility_Internal_ExitGUIv();
 __Z55Register_UnityEngine_GUIUtility_Internal_GetDefaultSkinv();
 __Z36Register_UnityEngine_Input_GetButtonv();
 __Z40Register_UnityEngine_Input_GetButtonDownv();
 __Z36Register_UnityEngine_Input_GetKeyIntv();
 __Z41Register_UnityEngine_Input_GetMouseButtonv();
 __Z45Register_UnityEngine_Input_GetMouseButtonDownv();
 __Z34Register_UnityEngine_Input_GetAxisv();
 __Z37Register_UnityEngine_Input_GetAxisRawv();
 __Z41Register_UnityEngine_Input_ResetInputAxesv();
 __Z44Register_UnityEngine_Input_get_mousePositionv();
 __Z42Register_UnityEngine_LayerMask_NameToLayerv();
 __Z42Register_UnityEngine_LayerMask_LayerToNamev();
 __Z44Register_UnityEngine_Material_DisableKeywordv();
 __Z43Register_UnityEngine_Material_EnableKeywordv();
 __Z52Register_UnityEngine_Material_INTERNAL_CALL_SetColorv();
 __Z38Register_UnityEngine_Material_SetFloatv();
 __Z45Register_UnityEngine_Material_set_renderQueuev();
 __Z38Register_UnityEngine_Material_GetColorv();
 __Z51Register_UnityEngine_Matrix4x4_INTERNAL_CALL_Invertv();
 __Z45Register_UnityEngine_Matrix4x4_get_isIdentityv();
 __Z52Register_UnityEngine_Matrix4x4_INTERNAL_CALL_Inversev();
 __Z48Register_UnityEngine_Matrix4x4_INTERNAL_CALL_TRSv();
 __Z54Register_UnityEngine_Matrix4x4_INTERNAL_CALL_Transposev();
 __Z36Register_UnityEngine_Matrix4x4_Orthov();
 __Z42Register_UnityEngine_Matrix4x4_Perspectivev();
 __Z54Register_UnityEngine_MonoBehaviour_StartCoroutine_Autov();
 __Z36Register_UnityEngine_Object_ToStringv();
 __Z36Register_UnityEngine_Object_get_namev();
 __Z35Register_UnityEngine_Object_Destroyv();
 __Z36Register_UnityEngine_Object_set_namev();
 __Z60Register_UnityEngine_Quaternion_INTERNAL_CALL_FromToRotationv();
 __Z67Register_UnityEngine_Quaternion_INTERNAL_CALL_Internal_FromEulerRadv();
 __Z53Register_UnityEngine_Quaternion_INTERNAL_CALL_Inversev();
 __Z58Register_UnityEngine_Quaternion_INTERNAL_CALL_LookRotationv();
 __Z65Register_UnityEngine_Quaternion_INTERNAL_CALL_Internal_ToEulerRadv();
 __Z42Register_UnityEngine_Random_RandomRangeIntv();
 __Z42Register_UnityEngine_RectOffset_get_bottomv();
 __Z46Register_UnityEngine_RectOffset_get_horizontalv();
 __Z40Register_UnityEngine_RectOffset_get_leftv();
 __Z41Register_UnityEngine_RectOffset_get_rightv();
 __Z39Register_UnityEngine_RectOffset_get_topv();
 __Z44Register_UnityEngine_RectOffset_get_verticalv();
 __Z39Register_UnityEngine_RectOffset_Cleanupv();
 __Z36Register_UnityEngine_RectOffset_Initv();
 __Z42Register_UnityEngine_RectOffset_set_bottomv();
 __Z40Register_UnityEngine_RectOffset_set_leftv();
 __Z41Register_UnityEngine_RectOffset_set_rightv();
 __Z39Register_UnityEngine_RectOffset_set_topv();
 __Z42Register_UnityEngine_Renderer_get_materialv();
 __Z35Register_UnityEngine_Resources_Loadv();
 __Z49Register_UnityEngine_Rigidbody_set_freezeRotationv();
 __Z38Register_UnityEngine_Screen_get_heightv();
 __Z37Register_UnityEngine_Screen_get_widthv();
 __Z69Register_UnityEngine_ScriptableObject_Internal_CreateScriptableObjectv();
 __Z52Register_UnityEngine_ScriptableObject_CreateInstancev();
 __Z60Register_UnityEngine_ScriptableObject_CreateInstanceFromTypev();
 __Z40Register_UnityEngine_Shader_PropertyToIDv();
 __Z39Register_UnityEngine_TextAsset_get_textv();
 __Z70Register_UnityEngine_TextGenerator_INTERNAL_CALL_Populate_Internal_cppv();
 __Z53Register_UnityEngine_TextGenerator_get_characterCountv();
 __Z61Register_UnityEngine_TextGenerator_get_fontSizeUsedForBestFitv();
 __Z48Register_UnityEngine_TextGenerator_get_lineCountv();
 __Z50Register_UnityEngine_TextGenerator_get_vertexCountv();
 __Z46Register_UnityEngine_TextGenerator_Dispose_cppv();
 __Z56Register_UnityEngine_TextGenerator_GetCharactersInternalv();
 __Z51Register_UnityEngine_TextGenerator_GetLinesInternalv();
 __Z54Register_UnityEngine_TextGenerator_GetVerticesInternalv();
 __Z39Register_UnityEngine_TextGenerator_Initv();
 __Z50Register_UnityEngine_TextGenerator_get_rectExtentsv();
 __Z53Register_UnityEngine_TextGenerator_GetCharactersArrayv();
 __Z48Register_UnityEngine_TextGenerator_GetLinesArrayv();
 __Z51Register_UnityEngine_TextGenerator_GetVerticesArrayv();
 __Z39Register_UnityEngine_Time_get_deltaTimev();
 __Z34Register_UnityEngine_Time_get_timev();
 __Z60Register_UnityEngine_Transform_INTERNAL_get_localEulerAnglesv();
 __Z57Register_UnityEngine_Transform_INTERNAL_get_localRotationv();
 __Z62Register_UnityEngine_Transform_INTERNAL_get_localToWorldMatrixv();
 __Z52Register_UnityEngine_Transform_INTERNAL_get_positionv();
 __Z52Register_UnityEngine_Transform_INTERNAL_get_rotationv();
 __Z60Register_UnityEngine_Transform_INTERNAL_set_localEulerAnglesv();
 __Z57Register_UnityEngine_Transform_INTERNAL_set_localRotationv();
 __Z54Register_UnityEngine_Transform_INTERNAL_set_localScalev();
 __Z52Register_UnityEngine_Transform_INTERNAL_set_positionv();
 __Z52Register_UnityEngine_Transform_INTERNAL_set_rotationv();
 __Z70Register_UnityEngine_Transform_INTERNAL_CALL_InverseTransformDirectionv();
 __Z66Register_UnityEngine_Transform_INTERNAL_CALL_InverseTransformPointv();
 __Z63Register_UnityEngine_Transform_INTERNAL_CALL_TransformDirectionv();
 __Z59Register_UnityEngine_Transform_INTERNAL_CALL_TransformPointv();
 __Z56Register_UnityEngine_Vector3_INTERNAL_CALL_RotateTowardsv();
 __Z48Register_UnityEngine_Vector3_INTERNAL_CALL_Slerpv();
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0;
 var $__i$06 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 2;
   switch ($4|0) {
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 45;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   default: {
   }
   }
   $14 = ($3|0)<(124);
   if ($14) {
    label = 10;
    break L1;
   }
   $15 = ($3|0)>(3996);
   $16 = (($4|0) / 2)&-1;
   $17 = (($$0) + ($16<<2)|0);
   if ($15) {
    $18 = (($4|0) / 4)&-1;
    $19 = (($$0) + ($18<<2)|0);
    $$sum = (($18) + ($16))|0;
    $20 = (($$0) + ($$sum<<2)|0);
    $21 = (__ZNSt3__17__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_($$0,$19,$17,$20,$1,0)|0);
    $__n_swaps$0 = $21;
   } else {
    $22 = (__ZNSt3__17__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($$0,$17,$1,0)|0);
    $__n_swaps$0 = $22;
   }
   $23 = HEAP32[$$0>>2]|0;
   $24 = HEAP32[$17>>2]|0;
   $25 = ($23|0)<($24|0);
   do {
    if ($25) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $26 = (($__j$0) + -4|0);
      $27 = ($$0|0)==($26|0);
      if ($27) {
       break;
      }
      $45 = HEAP32[$26>>2]|0;
      $46 = ($45|0)<($24|0);
      if ($46) {
       label = 28;
       break;
      } else {
       $__j$0 = $26;
      }
     }
     if ((label|0) == 28) {
      label = 0;
      HEAP32[$$0>>2] = $45;
      HEAP32[$26>>2] = $23;
      $47 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $26;$__n_swaps$3 = $47;
      break;
     }
     $28 = (($$0) + 4|0);
     $29 = HEAP32[$1>>2]|0;
     $30 = ($23|0)<($29|0);
     if ($30) {
      $__i$1 = $28;
     } else {
      $31 = ($28|0)==($1|0);
      if ($31) {
       label = 45;
       break L1;
      } else {
       $__i$06 = $28;
      }
      while(1) {
       $34 = HEAP32[$__i$06>>2]|0;
       $35 = ($23|0)<($34|0);
       $33 = (($__i$06) + 4|0);
       if ($35) {
        break;
       }
       $32 = ($33|0)==($1|0);
       if ($32) {
        label = 45;
        break L1;
       } else {
        $__i$06 = $33;
       }
      }
      HEAP32[$__i$06>>2] = $29;
      HEAP32[$1>>2] = $34;
      $__i$1 = $33;
     }
     $36 = ($__i$1|0)==($1|0);
     if ($36) {
      label = 45;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $37 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $38 = HEAP32[$__i$2>>2]|0;
       $39 = ($37|0)<($38|0);
       $40 = (($__i$2) + 4|0);
       if ($39) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $40;
       }
      }
      while(1) {
       $41 = (($__j$2) + -4|0);
       $42 = HEAP32[$41>>2]|0;
       $43 = ($37|0)<($42|0);
       if ($43) {
        $__j$2 = $41;
       } else {
        break;
       }
      }
      $44 = ($__i$2>>>0)<($41>>>0);
      if (!($44)) {
       $$0 = $__i$2;
       continue L3;
      }
      HEAP32[$__i$2>>2] = $42;
      HEAP32[$41>>2] = $38;
      $__i$2$ph = $40;$__j$1$ph = $41;
     }
    }
   } while(0);
   $48 = (($$0) + 4|0);
   $49 = ($48>>>0)<($__j$3>>>0);
   L34: do {
    if ($49) {
     $__i$3$ph = $48;$__j$4$ph = $__j$3;$__m$0$ph = $17;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $50 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $51 = HEAP32[$__i$3>>2]|0;
       $52 = ($51|0)<($50|0);
       $53 = (($__i$3) + 4|0);
       if ($52) {
        $__i$3 = $53;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $54 = (($__j$5) + -4|0);
       $55 = HEAP32[$54>>2]|0;
       $56 = ($55|0)<($50|0);
       if ($56) {
        break;
       } else {
        $__j$5 = $54;
       }
      }
      $57 = ($__i$3>>>0)>($54>>>0);
      if ($57) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      HEAP32[$__i$3>>2] = $55;
      HEAP32[$54>>2] = $51;
      $58 = (($__n_swaps$4$ph) + 1)|0;
      $59 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $59 ? $54 : $__m$0$ph;
      $__i$3$ph = $53;$__j$4$ph = $54;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $58;
     }
    } else {
     $__i$4 = $48;$__m$2 = $17;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $60 = ($__i$4|0)==($__m$2|0);
   if ($60) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $61 = HEAP32[$__m$2>>2]|0;
    $62 = HEAP32[$__i$4>>2]|0;
    $63 = ($61|0)<($62|0);
    if ($63) {
     HEAP32[$__i$4>>2] = $61;
     HEAP32[$__m$2>>2] = $62;
     $64 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $64;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $65 = ($__n_swaps$6|0)==(0);
   if ($65) {
    $66 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_($$0,$__i$4,0)|0);
    $67 = (($__i$4) + 4|0);
    $68 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_($67,$$01$ph,0)|0);
    if ($68) {
     label = 40;
     break;
    }
    if ($66) {
     $$0 = $67;
     continue;
    }
   }
   $69 = $__i$4;
   $70 = (($69) - ($2))|0;
   $71 = (($0) - ($69))|0;
   $72 = ($70|0)<($71|0);
   if (!($72)) {
    label = 44;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_($$0,$__i$4,$__comp);
   $73 = (($__i$4) + 4|0);
   $$0 = $73;
  }
  if ((label|0) == 40) {
   label = 0;
   if ($66) {
    label = 45;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 44) {
   label = 0;
   $74 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_($74,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$1>>2]|0;
  $6 = HEAP32[$$0>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $5;
  HEAP32[$1>>2] = $6;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $8 = (($$0) + 4|0);
  (__ZNSt3__17__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($$0,$8,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $9 = (($$0) + 4|0);
  $10 = (($$0) + 8|0);
  (__ZNSt3__17__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_($$0,$9,$10,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $11 = (($$0) + 4|0);
  $12 = (($$0) + 8|0);
  $13 = (($$0) + 12|0);
  (__ZNSt3__17__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_($$0,$11,$12,$13,$1,0)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  __ZNSt3__118__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_($$0,$$01$ph,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 45) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__y>>2]|0;
 $1 = HEAP32[$__x>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = HEAP32[$__z>>2]|0;
 $4 = ($3|0)<($0|0);
 do {
  if ($2) {
   if ($4) {
    HEAP32[$__x>>2] = $3;
    HEAP32[$__z>>2] = $1;
    $$0 = 1;
    break;
   }
   HEAP32[$__x>>2] = $0;
   HEAP32[$__y>>2] = $1;
   $8 = HEAP32[$__z>>2]|0;
   $9 = ($8|0)<($1|0);
   if ($9) {
    HEAP32[$__y>>2] = $8;
    HEAP32[$__z>>2] = $1;
    $$0 = 2;
   } else {
    $$0 = 1;
   }
  } else {
   if ($4) {
    HEAP32[$__y>>2] = $3;
    HEAP32[$__z>>2] = $0;
    $5 = HEAP32[$__y>>2]|0;
    $6 = HEAP32[$__x>>2]|0;
    $7 = ($5|0)<($6|0);
    if ($7) {
     HEAP32[$__x>>2] = $5;
     HEAP32[$__y>>2] = $6;
     $$0 = 2;
    } else {
     $$0 = 1;
    }
   } else {
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($__x1,$__x2,$__x3,0)|0);
 $1 = HEAP32[$__x4>>2]|0;
 $2 = HEAP32[$__x3>>2]|0;
 $3 = ($1|0)<($2|0);
 if (!($3)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $1;
 HEAP32[$__x4>>2] = $2;
 $4 = (($0) + 1)|0;
 $5 = HEAP32[$__x3>>2]|0;
 $6 = HEAP32[$__x2>>2]|0;
 $7 = ($5|0)<($6|0);
 if (!($7)) {
  $__r$0 = $4;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $5;
 HEAP32[$__x3>>2] = $6;
 $8 = (($0) + 2)|0;
 $9 = HEAP32[$__x2>>2]|0;
 $10 = HEAP32[$__x1>>2]|0;
 $11 = ($9|0)<($10|0);
 if (!($11)) {
  $__r$0 = $8;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $9;
 HEAP32[$__x2>>2] = $10;
 $12 = (($0) + 3)|0;
 $__r$0 = $12;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0;
 var $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 8|0);
 $1 = (($__first) + 4|0);
 (__ZNSt3__17__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($__first,$1,$0,0)|0);
 $2 = (($__first) + 12|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $2;$__j$01 = $0;
 }
 while(1) {
  $4 = HEAP32[$__i$02>>2]|0;
  $5 = HEAP32[$__j$01>>2]|0;
  $6 = ($4|0)<($5|0);
  if ($6) {
   $7 = $5;$__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    HEAP32[$__j$1>>2] = $7;
    $8 = ($__k$0|0)==($__first|0);
    if ($8) {
     $__k$0$lcssa = $__first;
     break;
    }
    $9 = (($__k$0) + -4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = ($4|0)<($10|0);
    if ($11) {
     $__j$1$phi = $__k$0;$7 = $10;$__k$0 = $9;$__j$1 = $__j$1$phi;
    } else {
     $__k$0$lcssa = $__k$0;
     break;
    }
   }
   HEAP32[$__k$0$lcssa>>2] = $4;
  }
  $12 = (($__i$02) + 4|0);
  $13 = ($12|0)==($__last|0);
  if ($13) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $12;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0, $__j$02 = 0;
 var $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__k$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 2:  {
  $4 = (($__last) + -4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = ($5|0)<($6|0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $13 = (($__first) + 4|0);
  $14 = (($__first) + 8|0);
  $15 = (($__first) + 12|0);
  $16 = (($__last) + -4|0);
  (__ZNSt3__17__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_($__first,$13,$14,$15,$16,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $10 = (($__first) + 4|0);
  $11 = (($__first) + 8|0);
  $12 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_($__first,$10,$11,$12,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $8 = (($__first) + 4|0);
  $9 = (($__last) + -4|0);
  (__ZNSt3__17__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($__first,$8,$9,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $17 = (($__first) + 8|0);
  $18 = (($__first) + 4|0);
  (__ZNSt3__17__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_($__first,$18,$17,0)|0);
  $19 = (($__first) + 12|0);
  $20 = ($19|0)==($__last|0);
  if ($20) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $19;$__j$02 = $17;
  }
  while(1) {
   $21 = HEAP32[$__i$04>>2]|0;
   $22 = HEAP32[$__j$02>>2]|0;
   $23 = ($21|0)<($22|0);
   if ($23) {
    $24 = $22;$__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     HEAP32[$__j$1>>2] = $24;
     $25 = ($__k$0|0)==($__first|0);
     if ($25) {
      $__k$0$lcssa = $__first;
      break;
     }
     $26 = (($__k$0) + -4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($21|0)<($27|0);
     if ($28) {
      $__j$1$phi = $__k$0;$24 = $27;$__k$0 = $26;$__j$1 = $__j$1$phi;
     } else {
      $__k$0$lcssa = $__k$0;
      break;
     }
    }
    HEAP32[$__k$0$lcssa>>2] = $21;
    $29 = (($__count$03) + 1)|0;
    $30 = ($29|0)==(8);
    if ($30) {
     break;
    } else {
     $__count$1 = $29;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $33 = (($__i$04) + 4|0);
   $34 = ($33|0)==($__last|0);
   if ($34) {
    $$0 = 1;
    label = 14;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $33;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 14) {
   STACKTOP = sp;return ($$0|0);
  }
  $31 = (($__i$04) + 4|0);
  $32 = ($31|0)==($__last|0);
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return 0|0;
}
function __ZNSt3__18ios_base4InitC2Ev($this) {
 $this = $this|0;
 var $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[_stdin>>2]|0;
 __ZNSt3__110__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t(3089056,$0,3089112);
 HEAP32[3088352>>2] = ((3090696 + 12|0));
 HEAP32[((3088352 + 8|0))>>2] = ((3090696 + 32|0));
 HEAP32[((3088352 + 4|0))>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2480,(((3088352 + 8|0))|0),(3089056|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  __ZNSt3__18ios_baseD2Ev(((3088352 + 8|0)));
  ___resumeException($3|0);
  // unreachable;
 }
 HEAP32[((3088352 + 80|0))>>2] = 0;
 HEAP32[((3088352 + 84|0))>>2] = -1;
 $5 = HEAP32[_stdout>>2]|0;
 __ZNSt3__111__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t(3089160,$5,((3089112 + 8|0)));
 HEAP32[3088440>>2] = ((3090776 + 12|0));
 HEAP32[((3088440 + 4|0))>>2] = ((3090776 + 32|0));
 __THREW__ = 0;
 invoke_vii(2480,(((3088440 + 4|0))|0),(3089160|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZNSt3__18ios_baseD2Ev(((3088440 + 4|0)));
  ___resumeException($8|0);
  // unreachable;
 }
 HEAP32[((3088440 + 76|0))>>2] = 0;
 HEAP32[((3088440 + 80|0))>>2] = -1;
 $10 = HEAP32[_stderr>>2]|0;
 __ZNSt3__111__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t(3089208,$10,((3089112 + 16|0)));
 HEAP32[3088528>>2] = ((3090776 + 12|0));
 HEAP32[((3088528 + 4|0))>>2] = ((3090776 + 32|0));
 __THREW__ = 0;
 invoke_vii(2480,(((3088528 + 4|0))|0),(3089208|0));
 $11 = __THREW__; __THREW__ = 0;
 $12 = $11&1;
 if ($12) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  __ZNSt3__18ios_baseD2Ev(((3088528 + 4|0)));
  ___resumeException($13|0);
  // unreachable;
 }
 HEAP32[((3088528 + 76|0))>>2] = 0;
 HEAP32[((3088528 + 80|0))>>2] = -1;
 $15 = HEAP32[3088528>>2]|0;
 $16 = (($15) + -12|0);
 $17 = HEAP32[$16>>2]|0;
 $$sum = (($17) + 24)|0;
 $18 = (3088528 + ($$sum)|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[3088616>>2] = ((3090776 + 12|0));
 HEAP32[((3088616 + 4|0))>>2] = ((3090776 + 32|0));
 __THREW__ = 0;
 invoke_vii(2480,(((3088616 + 4|0))|0),($19|0));
 $20 = __THREW__; __THREW__ = 0;
 $21 = $20&1;
 if ($21) {
  $22 = ___cxa_find_matching_catch()|0;
  $23 = tempRet0;
  __ZNSt3__18ios_baseD2Ev(((3088616 + 4|0)));
  ___resumeException($22|0);
  // unreachable;
 }
 HEAP32[((3088616 + 76|0))>>2] = 0;
 HEAP32[((3088616 + 80|0))>>2] = -1;
 $24 = HEAP32[3088352>>2]|0;
 $25 = (($24) + -12|0);
 $26 = HEAP32[$25>>2]|0;
 $$sum5 = (($26) + 72)|0;
 $27 = (3088352 + ($$sum5)|0);
 HEAP32[$27>>2] = 3088440;
 $28 = HEAP32[3088528>>2]|0;
 $29 = (($28) + -12|0);
 $30 = HEAP32[$29>>2]|0;
 $$sum6 = (($30) + 4)|0;
 $31 = (3088528 + ($$sum6)|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 | 8192;
 HEAP32[$31>>2] = $33;
 $34 = HEAP32[3088528>>2]|0;
 $35 = (($34) + -12|0);
 $36 = HEAP32[$35>>2]|0;
 $$sum7 = (($36) + 72)|0;
 $37 = (3088528 + ($$sum7)|0);
 HEAP32[$37>>2] = 3088440;
 __ZNSt3__110__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t(3089256,$0,((3089112 + 24|0)));
 HEAP32[3088704>>2] = ((3090736 + 12|0));
 HEAP32[((3088704 + 8|0))>>2] = ((3090736 + 32|0));
 HEAP32[((3088704 + 4|0))>>2] = 0;
 __THREW__ = 0;
 invoke_vii(2480,(((3088704 + 8|0))|0),(3089256|0));
 $38 = __THREW__; __THREW__ = 0;
 $39 = $38&1;
 if ($39) {
  $40 = ___cxa_find_matching_catch()|0;
  $41 = tempRet0;
  __ZNSt3__18ios_baseD2Ev(((3088704 + 8|0)));
  ___resumeException($40|0);
  // unreachable;
 }
 HEAP32[((3088704 + 80|0))>>2] = 0;
 HEAP32[((3088704 + 84|0))>>2] = -1;
 __ZNSt3__111__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t(3089312,$5,((3089112 + 32|0)));
 HEAP32[3088792>>2] = ((3090816 + 12|0));
 HEAP32[((3088792 + 4|0))>>2] = ((3090816 + 32|0));
 __THREW__ = 0;
 invoke_vii(2480,(((3088792 + 4|0))|0),(3089312|0));
 $42 = __THREW__; __THREW__ = 0;
 $43 = $42&1;
 if ($43) {
  $44 = ___cxa_find_matching_catch()|0;
  $45 = tempRet0;
  __ZNSt3__18ios_baseD2Ev(((3088792 + 4|0)));
  ___resumeException($44|0);
  // unreachable;
 }
 HEAP32[((3088792 + 76|0))>>2] = 0;
 HEAP32[((3088792 + 80|0))>>2] = -1;
 __ZNSt3__111__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t(3089360,$10,((3089112 + 40|0)));
 HEAP32[3088880>>2] = ((3090816 + 12|0));
 HEAP32[((3088880 + 4|0))>>2] = ((3090816 + 32|0));
 __THREW__ = 0;
 invoke_vii(2480,(((3088880 + 4|0))|0),(3089360|0));
 $46 = __THREW__; __THREW__ = 0;
 $47 = $46&1;
 if ($47) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  __ZNSt3__18ios_baseD2Ev(((3088880 + 4|0)));
  ___resumeException($48|0);
  // unreachable;
 }
 HEAP32[((3088880 + 76|0))>>2] = 0;
 HEAP32[((3088880 + 80|0))>>2] = -1;
 $50 = HEAP32[3088880>>2]|0;
 $51 = (($50) + -12|0);
 $52 = HEAP32[$51>>2]|0;
 $$sum8 = (($52) + 24)|0;
 $53 = (3088880 + ($$sum8)|0);
 $54 = HEAP32[$53>>2]|0;
 HEAP32[3088968>>2] = ((3090816 + 12|0));
 HEAP32[((3088968 + 4|0))>>2] = ((3090816 + 32|0));
 __THREW__ = 0;
 invoke_vii(2480,(((3088968 + 4|0))|0),($54|0));
 $55 = __THREW__; __THREW__ = 0;
 $56 = $55&1;
 if ($56) {
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  __ZNSt3__18ios_baseD2Ev(((3088968 + 4|0)));
  ___resumeException($57|0);
  // unreachable;
 } else {
  HEAP32[((3088968 + 76|0))>>2] = 0;
  HEAP32[((3088968 + 80|0))>>2] = -1;
  $59 = HEAP32[3088704>>2]|0;
  $60 = (($59) + -12|0);
  $61 = HEAP32[$60>>2]|0;
  $$sum9 = (($61) + 72)|0;
  $62 = (3088704 + ($$sum9)|0);
  HEAP32[$62>>2] = 3088792;
  $63 = HEAP32[3088880>>2]|0;
  $64 = (($63) + -12|0);
  $65 = HEAP32[$64>>2]|0;
  $$sum10 = (($65) + 4)|0;
  $66 = (3088880 + ($$sum10)|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = $67 | 8192;
  HEAP32[$66>>2] = $68;
  $69 = HEAP32[3088880>>2]|0;
  $70 = (($69) + -12|0);
  $71 = HEAP32[$70>>2]|0;
  $$sum11 = (($71) + 72)|0;
  $72 = (3088880 + ($$sum11)|0);
  HEAP32[$72>>2] = 3088792;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__111__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t($this,$__fp,$__st) {
 $this = $this|0;
 $__fp = $__fp|0;
 $__st = $__st|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEEC2Ev($this);
 HEAP32[$this>>2] = ((3089408 + 8|0));
 $1 = (($this) + 32|0);
 HEAP32[$1>>2] = $__fp;
 $2 = (($this) + 4|0);
 __ZNSt3__16localeC2ERKS0_($0,$2);
 __THREW__ = 0;
 $3 = (invoke_iii(2228,($0|0),(3093408|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZNSt3__16localeD2Ev($0);
  HEAP32[$this>>2] = ((3090632 + 8|0));
  __ZNSt3__16localeD2Ev($2);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $6 = (($this) + 36|0);
  __ZNSt3__16localeD2Ev($0);
  HEAP32[$6>>2] = $3;
  $7 = (($this) + 40|0);
  HEAP32[$7>>2] = $__st;
  $8 = (($this) + 44|0);
  $9 = HEAP32[$3>>2]|0;
  $10 = (($9) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($3)|0);
  $13 = $12&1;
  HEAP8[$8>>0] = $13;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__111__stdoutbufIwED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__111__stdoutbufIwED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090632 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__111__stdoutbufIwE5imbueERKNS_6localeE($this,$__loc) {
 $this = $this|0;
 $__loc = $__loc|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $3 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093408)|0);
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = $3;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($5) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($3)|0);
 $9 = (($this) + 44|0);
 $10 = $8&1;
 HEAP8[$9>>0] = $10;
 STACKTOP = sp;return;
}
function __ZNSt3__111__stdoutbufIwE4syncEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__extbe = 0, $__extbuf = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__extbuf = sp + 8|0;
 $__extbe = sp;
 $0 = (($this) + 36|0);
 $1 = (($this) + 40|0);
 $2 = (($__extbuf) + 8|0);
 $3 = $__extbuf;
 $4 = (($this) + 32|0);
 while(1) {
  $5 = HEAP32[$0>>2]|0;
  $6 = HEAP32[$1>>2]|0;
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_iiiiii[$9 & 255]($5,$6,$__extbuf,$2,$__extbe)|0);
  $11 = HEAP32[$__extbe>>2]|0;
  $12 = $11;
  $13 = (($12) - ($3))|0;
  $14 = HEAP32[$4>>2]|0;
  $15 = (_fwrite(($__extbuf|0),1,($13|0),($14|0))|0);
  $16 = ($15|0)==($13|0);
  if (!($16)) {
   $$0 = -1;
   label = 5;
   break;
  }
  if ((($10|0) == 2)) {
   $$0 = -1;
   label = 5;
   break;
  } else if (!((($10|0) == 1))) {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $17 = HEAP32[$4>>2]|0;
  $18 = (_fflush(($17|0))|0);
  $not$ = ($18|0)!=(0);
  $$ = $not$ << 31 >> 31;
  $$0 = $$;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__111__stdoutbufIwE6xsputnEPKwi($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $$0 = 0, $$012 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$03 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $4 = (($this) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (_fwrite(($__s|0),4,($__n|0),($5|0))|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($__n|0)>(0);
 if ($3) {
  $$012 = $__s;$__i$03 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $7 = HEAP32[$this>>2]|0;
  $8 = (($7) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$$012>>2]|0;
  $11 = (FUNCTION_TABLE_iii[$9 & 4095]($this,$10)|0);
  $12 = ($11|0)==(-1);
  if ($12) {
   $$0 = $__i$03;
   label = 6;
   break;
  }
  $13 = (($__i$03) + 1)|0;
  $14 = (($$012) + 4|0);
  $15 = ($13|0)<($__n|0);
  if ($15) {
   $$012 = $14;$__i$03 = $13;
  } else {
   $$0 = $13;
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__111__stdoutbufIwE8overflowEj($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $$0 = 0, $$__c$i = 0, $$pbase$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__1buf = 0, $__e = 0;
 var $__extbe = 0, $__extbuf = 0, $pbase$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__extbuf = sp + 16|0;
 $__1buf = sp;
 $__extbe = sp + 4|0;
 $__e = sp + 8|0;
 $0 = ($__c|0)==(-1);
 L1: do {
  if (!($0)) {
   HEAP32[$__1buf>>2] = $__c;
   $1 = (($this) + 44|0);
   $2 = HEAP8[$1>>0]|0;
   $3 = ($2<<24>>24)==(0);
   if (!($3)) {
    $4 = (($this) + 32|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = (_fwrite(($__1buf|0),4,1,($5|0))|0);
    $7 = ($6|0)==(1);
    if ($7) {
     break;
    } else {
     $$0 = -1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__extbe>>2] = $__extbuf;
   $8 = (($__1buf) + 4|0);
   $9 = (($this) + 36|0);
   $10 = (($this) + 40|0);
   $11 = (($__extbuf) + 8|0);
   $12 = $__extbuf;
   $13 = (($this) + 32|0);
   $pbase$0 = $__1buf;
   while(1) {
    $14 = HEAP32[$9>>2]|0;
    $15 = HEAP32[$10>>2]|0;
    $16 = HEAP32[$14>>2]|0;
    $17 = (($16) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (FUNCTION_TABLE_iiiiiiiii[$18 & 63]($14,$15,$pbase$0,$8,$__e,$__extbuf,$11,$__extbe)|0);
    $20 = HEAP32[$__e>>2]|0;
    $21 = ($20|0)==($pbase$0|0);
    if ($21) {
     $$0 = -1;
     label = 12;
     break;
    }
    $22 = ($19|0)==(3);
    if ($22) {
     label = 7;
     break;
    }
    $26 = ($19|0)==(1);
    $27 = ($19>>>0)<(2);
    if (!($27)) {
     $$0 = -1;
     label = 12;
     break;
    }
    $28 = HEAP32[$__extbe>>2]|0;
    $29 = $28;
    $30 = (($29) - ($12))|0;
    $31 = HEAP32[$13>>2]|0;
    $32 = (_fwrite(($__extbuf|0),1,($30|0),($31|0))|0);
    $33 = ($32|0)==($30|0);
    if (!($33)) {
     $$0 = -1;
     label = 12;
     break;
    }
    $34 = HEAP32[$__e>>2]|0;
    $$pbase$0 = $26 ? $34 : $pbase$0;
    if ($26) {
     $pbase$0 = $$pbase$0;
    } else {
     break L1;
    }
   }
   if ((label|0) == 7) {
    $23 = HEAP32[$13>>2]|0;
    $24 = (_fwrite(($pbase$0|0),1,1,($23|0))|0);
    $25 = ($24|0)==(1);
    if ($25) {
     break;
    } else {
     $$0 = -1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 12) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $$__c$i = $0 ? 0 : $__c;
 $$0 = $$__c$i;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__110__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t($this,$__fp,$__st) {
 $this = $this|0;
 $__fp = $__fp|0;
 $__st = $__st|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEEC2Ev($this);
 HEAP32[$this>>2] = ((3089520 + 8|0));
 $1 = (($this) + 32|0);
 HEAP32[$1>>2] = $__fp;
 $2 = (($this) + 40|0);
 HEAP32[$2>>2] = $__st;
 $3 = (($this) + 48|0);
 HEAP32[$3>>2] = -1;
 $4 = (($this) + 52|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 4|0);
 __ZNSt3__16localeC2ERKS0_($0,$5);
 __THREW__ = 0;
 invoke_vii(2438,($this|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZNSt3__16localeD2Ev($0);
  HEAP32[$this>>2] = ((3090632 + 8|0));
  __ZNSt3__16localeD2Ev($5);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZNSt3__16localeD2Ev($0);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__110__stdinbufIwED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__110__stdinbufIwED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090632 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__110__stdinbufIwE5imbueERKNS_6localeE($this,$__loc) {
 $this = $this|0;
 $__loc = $__loc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093408)|0);
 $1 = (($this) + 36|0);
 HEAP32[$1>>2] = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($0)|0);
 $6 = (($this) + 44|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $12 = (($this) + 53|0);
 $13 = $11&1;
 HEAP8[$12>>0] = $13;
 $14 = HEAP32[$6>>2]|0;
 $15 = ($14|0)>(8);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 __ZNSt3__121__throw_runtime_errorEPKc(3089624);
 STACKTOP = sp;return;
}
function __ZNSt3__110__stdinbufIwE9underflowEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__110__stdinbufIwE9__getcharEb($this,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__110__stdinbufIwE5uflowEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__110__stdinbufIwE9__getcharEb($this,1)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__110__stdinbufIwE9pbackfailEj($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__ci = 0, $__enxt = 0, $__extbuf = 0, $__inxt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__extbuf = sp + 16|0;
 $__enxt = sp;
 $__ci = sp + 4|0;
 $__inxt = sp + 8|0;
 $0 = ($__c|0)==(-1);
 $1 = (($this) + 52|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($0) {
  if ($3) {
   $$01 = -1;
   STACKTOP = sp;return ($$01|0);
  }
  $4 = (($this) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)!=(-1);
  $7 = $6&1;
  HEAP8[$1>>0] = $7;
  $$01 = $5;
  STACKTOP = sp;return ($$01|0);
 }
 $8 = (($this) + 48|0);
 L8: do {
  if ($3) {
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$__ci>>2] = $9;
   $10 = (($this) + 36|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($this) + 40|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($__ci) + 4|0);
   $15 = (($__extbuf) + 8|0);
   $16 = HEAP32[$11>>2]|0;
   $17 = (($16) + 12|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = (FUNCTION_TABLE_iiiiiiiii[$18 & 63]($11,$13,$__ci,$14,$__inxt,$__extbuf,$15,$__enxt)|0);
   if ((($19|0) == 1) | (($19|0) == 2)) {
    $$01 = -1;
    STACKTOP = sp;return ($$01|0);
   } else if ((($19|0) == 3)) {
    $20 = HEAP32[$8>>2]|0;
    $21 = $20&255;
    HEAP8[$__extbuf>>0] = $21;
    $22 = (($__extbuf) + 1|0);
    HEAP32[$__enxt>>2] = $22;
   }
   $23 = (($this) + 32|0);
   while(1) {
    $24 = HEAP32[$__enxt>>2]|0;
    $25 = ($24>>>0)>($__extbuf>>>0);
    if (!($25)) {
     break L8;
    }
    $26 = (($24) + -1|0);
    HEAP32[$__enxt>>2] = $26;
    $27 = HEAP8[$26>>0]|0;
    $28 = $27 << 24 >> 24;
    $29 = HEAP32[$23>>2]|0;
    $30 = (_ungetc(($28|0),($29|0))|0);
    $31 = ($30|0)==(-1);
    if ($31) {
     $$01 = -1;
     break;
    }
   }
   STACKTOP = sp;return ($$01|0);
  }
 } while(0);
 HEAP32[$8>>2] = $__c;
 HEAP8[$1>>0] = 1;
 $$01 = $__c;
 STACKTOP = sp;return ($$01|0);
}
function __ZNSt3__110__stdinbufIwE9__getcharEb($this,$__consume) {
 $this = $this|0;
 $__consume = $__consume|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $__1buf = 0, $__enxt = 0, $__extbuf = 0, $__i$09 = 0, $__i2$0 = 0, $__inxt = 0, $__nread$0 = 0, $__nread$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__extbuf = sp + 16|0;
 $__1buf = sp;
 $__enxt = sp + 4|0;
 $__inxt = sp + 8|0;
 $0 = (($this) + 52|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 48|0);
  $4 = HEAP32[$3>>2]|0;
  if (!($__consume)) {
   $$0 = $4;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$3>>2] = -1;
  HEAP8[$0>>0] = 0;
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(1);
 $8 = $7 ? $6 : 1;
 $9 = ($8|0)>(0);
 L8: do {
  if ($9) {
   $10 = (($this) + 32|0);
   $__i$09 = 0;
   while(1) {
    $11 = HEAP32[$10>>2]|0;
    $12 = (_getc(($11|0))|0);
    $13 = ($12|0)==(-1);
    if ($13) {
     $$0 = -1;
     break;
    }
    $14 = $12&255;
    $15 = (($__extbuf) + ($__i$09)|0);
    HEAP8[$15>>0] = $14;
    $16 = (($__i$09) + 1)|0;
    $17 = ($16|0)<($8|0);
    if ($17) {
     $__i$09 = $16;
    } else {
     break L8;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $18 = (($this) + 53|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 L15: do {
  if ($20) {
   $21 = (($this) + 40|0);
   $22 = (($this) + 36|0);
   $23 = (($__1buf) + 4|0);
   $24 = (($this) + 32|0);
   $__nread$0 = $8;
   while(1) {
    $27 = HEAP32[$21>>2]|0;
    $28 = $27;
    $29 = $28;
    $30 = HEAP32[$29>>2]|0;
    $31 = (($28) + 4)|0;
    $32 = $31;
    $33 = HEAP32[$32>>2]|0;
    $34 = HEAP32[$22>>2]|0;
    $35 = (($__extbuf) + ($__nread$0)|0);
    $36 = HEAP32[$34>>2]|0;
    $37 = (($36) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = (FUNCTION_TABLE_iiiiiiiii[$38 & 63]($34,$27,$__extbuf,$35,$__enxt,$__1buf,$23,$__inxt)|0);
    if ((($39|0) == 3)) {
     label = 14;
     break;
    } else if ((($39|0) == 2)) {
     $$0 = -1;
     label = 22;
     break;
    } else if (!((($39|0) == 1))) {
     $__nread$2 = $__nread$0;
     break L15;
    }
    $40 = HEAP32[$21>>2]|0;
    $41 = $40;
    $42 = $41;
    HEAP32[$42>>2] = $30;
    $43 = (($41) + 4)|0;
    $44 = $43;
    HEAP32[$44>>2] = $33;
    $45 = ($__nread$0|0)==(8);
    if ($45) {
     $$0 = -1;
     label = 22;
     break;
    }
    $46 = HEAP32[$24>>2]|0;
    $47 = (_getc(($46|0))|0);
    $48 = ($47|0)==(-1);
    if ($48) {
     $$0 = -1;
     label = 22;
     break;
    }
    $51 = $47&255;
    HEAP8[$35>>0] = $51;
    $52 = (($__nread$0) + 1)|0;
    $__nread$0 = $52;
   }
   if ((label|0) == 14) {
    $49 = HEAP8[$__extbuf>>0]|0;
    $50 = $49 << 24 >> 24;
    HEAP32[$__1buf>>2] = $50;
    $__nread$2 = $__nread$0;
    break;
   }
   else if ((label|0) == 22) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $25 = HEAP8[$__extbuf>>0]|0;
   $26 = $25 << 24 >> 24;
   HEAP32[$__1buf>>2] = $26;
   $__nread$2 = $8;
  }
 } while(0);
 if ($__consume) {
  $62 = HEAP32[$__1buf>>2]|0;
  $63 = (($this) + 48|0);
  HEAP32[$63>>2] = $62;
  $$0 = $62;
  STACKTOP = sp;return ($$0|0);
 }
 $53 = (($this) + 32|0);
 $__i2$0 = $__nread$2;
 while(1) {
  $54 = ($__i2$0|0)>(0);
  if (!($54)) {
   break;
  }
  $55 = (($__i2$0) + -1)|0;
  $56 = (($__extbuf) + ($55)|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57 << 24 >> 24;
  $59 = HEAP32[$53>>2]|0;
  $60 = (_ungetc(($58|0),($59|0))|0);
  $61 = ($60|0)==(-1);
  if ($61) {
   $$0 = -1;
   label = 22;
   break;
  } else {
   $__i2$0 = $55;
  }
 }
 if ((label|0) == 22) {
  STACKTOP = sp;return ($$0|0);
 }
 $$pre = HEAP32[$__1buf>>2]|0;
 $$0 = $$pre;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__111__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t($this,$__fp,$__st) {
 $this = $this|0;
 $__fp = $__fp|0;
 $__st = $__st|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEEC2Ev($this);
 HEAP32[$this>>2] = ((3089664 + 8|0));
 $1 = (($this) + 32|0);
 HEAP32[$1>>2] = $__fp;
 $2 = (($this) + 4|0);
 __ZNSt3__16localeC2ERKS0_($0,$2);
 __THREW__ = 0;
 $3 = (invoke_iii(2228,($0|0),(3093400|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $14 = ___cxa_find_matching_catch()|0;
  $15 = tempRet0;
  __ZNSt3__16localeD2Ev($0);
  HEAP32[$this>>2] = ((3090568 + 8|0));
  __ZNSt3__16localeD2Ev($2);
  ___resumeException($14|0);
  // unreachable;
 } else {
  $6 = (($this) + 36|0);
  __ZNSt3__16localeD2Ev($0);
  HEAP32[$6>>2] = $3;
  $7 = (($this) + 40|0);
  HEAP32[$7>>2] = $__st;
  $8 = (($this) + 44|0);
  $9 = HEAP32[$3>>2]|0;
  $10 = (($9) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (FUNCTION_TABLE_ii[$11 & 4095]($3)|0);
  $13 = $12&1;
  HEAP8[$8>>0] = $13;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__111__stdoutbufIcED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__111__stdoutbufIcED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090568 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__111__stdoutbufIcE5imbueERKNS_6localeE($this,$__loc) {
 $this = $this|0;
 $__loc = $__loc|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $3 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093400)|0);
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = $3;
 $5 = HEAP32[$3>>2]|0;
 $6 = (($5) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 4095]($3)|0);
 $9 = (($this) + 44|0);
 $10 = $8&1;
 HEAP8[$9>>0] = $10;
 STACKTOP = sp;return;
}
function __ZNSt3__111__stdoutbufIcE4syncEv($this) {
 $this = $this|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__extbe = 0, $__extbuf = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__extbuf = sp + 8|0;
 $__extbe = sp;
 $0 = (($this) + 36|0);
 $1 = (($this) + 40|0);
 $2 = (($__extbuf) + 8|0);
 $3 = $__extbuf;
 $4 = (($this) + 32|0);
 while(1) {
  $5 = HEAP32[$0>>2]|0;
  $6 = HEAP32[$1>>2]|0;
  $7 = HEAP32[$5>>2]|0;
  $8 = (($7) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (FUNCTION_TABLE_iiiiii[$9 & 255]($5,$6,$__extbuf,$2,$__extbe)|0);
  $11 = HEAP32[$__extbe>>2]|0;
  $12 = $11;
  $13 = (($12) - ($3))|0;
  $14 = HEAP32[$4>>2]|0;
  $15 = (_fwrite(($__extbuf|0),1,($13|0),($14|0))|0);
  $16 = ($15|0)==($13|0);
  if (!($16)) {
   $$0 = -1;
   label = 5;
   break;
  }
  if ((($10|0) == 2)) {
   $$0 = -1;
   label = 5;
   break;
  } else if (!((($10|0) == 1))) {
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  $17 = HEAP32[$4>>2]|0;
  $18 = (_fflush(($17|0))|0);
  $not$ = ($18|0)!=(0);
  $$ = $not$ << 31 >> 31;
  $$0 = $$;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__111__stdoutbufIcE6xsputnEPKci($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $$0 = 0, $$012 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$03 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $4 = (($this) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (_fwrite(($__s|0),1,($__n|0),($5|0))|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($__n|0)>(0);
 if ($3) {
  $$012 = $__s;$__i$03 = 0;
 } else {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $7 = HEAP32[$this>>2]|0;
  $8 = (($7) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP8[$$012>>0]|0;
  $11 = $10&255;
  $12 = (FUNCTION_TABLE_iii[$9 & 4095]($this,$11)|0);
  $13 = ($12|0)==(-1);
  if ($13) {
   $$0 = $__i$03;
   label = 6;
   break;
  }
  $14 = (($__i$03) + 1)|0;
  $15 = (($$012) + 1|0);
  $16 = ($14|0)<($__n|0);
  if ($16) {
   $$012 = $15;$__i$03 = $14;
  } else {
   $$0 = $14;
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__111__stdoutbufIcE8overflowEi($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $$0 = 0, $$__c$i = 0, $$pbase$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__1buf = 0;
 var $__e = 0, $__extbe = 0, $__extbuf = 0, $pbase$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__extbuf = sp + 16|0;
 $__1buf = sp + 8|0;
 $__extbe = sp;
 $__e = sp + 4|0;
 $0 = ($__c|0)==(-1);
 L1: do {
  if (!($0)) {
   $1 = $__c&255;
   HEAP8[$__1buf>>0] = $1;
   $2 = (($this) + 44|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if (!($4)) {
    $5 = (($this) + 32|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = (_fwrite(($__1buf|0),1,1,($6|0))|0);
    $8 = ($7|0)==(1);
    if ($8) {
     break;
    } else {
     $$0 = -1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__extbe>>2] = $__extbuf;
   $9 = (($__1buf) + 1|0);
   $10 = (($this) + 36|0);
   $11 = (($this) + 40|0);
   $12 = (($__extbuf) + 8|0);
   $13 = $__extbuf;
   $14 = (($this) + 32|0);
   $pbase$0 = $__1buf;
   while(1) {
    $15 = HEAP32[$10>>2]|0;
    $16 = HEAP32[$11>>2]|0;
    $17 = HEAP32[$15>>2]|0;
    $18 = (($17) + 12|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (FUNCTION_TABLE_iiiiiiiii[$19 & 63]($15,$16,$pbase$0,$9,$__e,$__extbuf,$12,$__extbe)|0);
    $21 = HEAP32[$__e>>2]|0;
    $22 = ($21|0)==($pbase$0|0);
    if ($22) {
     $$0 = -1;
     label = 12;
     break;
    }
    $23 = ($20|0)==(3);
    if ($23) {
     label = 7;
     break;
    }
    $27 = ($20|0)==(1);
    $28 = ($20>>>0)<(2);
    if (!($28)) {
     $$0 = -1;
     label = 12;
     break;
    }
    $29 = HEAP32[$__extbe>>2]|0;
    $30 = $29;
    $31 = (($30) - ($13))|0;
    $32 = HEAP32[$14>>2]|0;
    $33 = (_fwrite(($__extbuf|0),1,($31|0),($32|0))|0);
    $34 = ($33|0)==($31|0);
    if (!($34)) {
     $$0 = -1;
     label = 12;
     break;
    }
    $35 = HEAP32[$__e>>2]|0;
    $$pbase$0 = $27 ? $35 : $pbase$0;
    if ($27) {
     $pbase$0 = $$pbase$0;
    } else {
     break L1;
    }
   }
   if ((label|0) == 7) {
    $24 = HEAP32[$14>>2]|0;
    $25 = (_fwrite(($pbase$0|0),1,1,($24|0))|0);
    $26 = ($25|0)==(1);
    if ($26) {
     break;
    } else {
     $$0 = -1;
    }
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 12) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $$__c$i = $0 ? 0 : $__c;
 $$0 = $$__c$i;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__110__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t($this,$__fp,$__st) {
 $this = $this|0;
 $__fp = $__fp|0;
 $__st = $__st|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEEC2Ev($this);
 HEAP32[$this>>2] = ((3089776 + 8|0));
 $1 = (($this) + 32|0);
 HEAP32[$1>>2] = $__fp;
 $2 = (($this) + 40|0);
 HEAP32[$2>>2] = $__st;
 $3 = (($this) + 48|0);
 HEAP32[$3>>2] = -1;
 $4 = (($this) + 52|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 4|0);
 __ZNSt3__16localeC2ERKS0_($0,$5);
 __THREW__ = 0;
 invoke_vii(2440,($this|0),($0|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch()|0;
  $9 = tempRet0;
  __ZNSt3__16localeD2Ev($0);
  HEAP32[$this>>2] = ((3090568 + 8|0));
  __ZNSt3__16localeD2Ev($5);
  ___resumeException($8|0);
  // unreachable;
 } else {
  __ZNSt3__16localeD2Ev($0);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__110__stdinbufIcED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__110__stdinbufIcED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090568 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__110__stdinbufIcE5imbueERKNS_6localeE($this,$__loc) {
 $this = $this|0;
 $__loc = $__loc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093400)|0);
 $1 = (($this) + 36|0);
 HEAP32[$1>>2] = $0;
 $2 = HEAP32[$0>>2]|0;
 $3 = (($2) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($0)|0);
 $6 = (($this) + 44|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$1>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (FUNCTION_TABLE_ii[$10 & 4095]($7)|0);
 $12 = (($this) + 53|0);
 $13 = $11&1;
 HEAP8[$12>>0] = $13;
 $14 = HEAP32[$6>>2]|0;
 $15 = ($14|0)>(8);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 __ZNSt3__121__throw_runtime_errorEPKc(3089624);
 STACKTOP = sp;return;
}
function __ZNSt3__110__stdinbufIcE9underflowEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__110__stdinbufIcE9__getcharEb($this,0)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__110__stdinbufIcE5uflowEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__110__stdinbufIcE9__getcharEb($this,1)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__110__stdinbufIcE9pbackfailEi($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__ci = 0, $__enxt = 0, $__extbuf = 0, $__inxt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__extbuf = sp + 16|0;
 $__enxt = sp;
 $__ci = sp + 8|0;
 $__inxt = sp + 4|0;
 $0 = ($__c|0)==(-1);
 $1 = (($this) + 52|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 if ($0) {
  if ($3) {
   $$01 = -1;
   STACKTOP = sp;return ($$01|0);
  }
  $4 = (($this) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)!=(-1);
  $7 = $6&1;
  HEAP8[$1>>0] = $7;
  $$01 = $5;
  STACKTOP = sp;return ($$01|0);
 }
 $8 = (($this) + 48|0);
 L8: do {
  if ($3) {
   $9 = HEAP32[$8>>2]|0;
   $10 = $9&255;
   HEAP8[$__ci>>0] = $10;
   $11 = (($this) + 36|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 40|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($__ci) + 1|0);
   $16 = (($__extbuf) + 8|0);
   $17 = HEAP32[$12>>2]|0;
   $18 = (($17) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (FUNCTION_TABLE_iiiiiiiii[$19 & 63]($12,$14,$__ci,$15,$__inxt,$__extbuf,$16,$__enxt)|0);
   if ((($20|0) == 1) | (($20|0) == 2)) {
    $$01 = -1;
    STACKTOP = sp;return ($$01|0);
   } else if ((($20|0) == 3)) {
    $21 = HEAP32[$8>>2]|0;
    $22 = $21&255;
    HEAP8[$__extbuf>>0] = $22;
    $23 = (($__extbuf) + 1|0);
    HEAP32[$__enxt>>2] = $23;
   }
   $24 = (($this) + 32|0);
   while(1) {
    $25 = HEAP32[$__enxt>>2]|0;
    $26 = ($25>>>0)>($__extbuf>>>0);
    if (!($26)) {
     break L8;
    }
    $27 = (($25) + -1|0);
    HEAP32[$__enxt>>2] = $27;
    $28 = HEAP8[$27>>0]|0;
    $29 = $28 << 24 >> 24;
    $30 = HEAP32[$24>>2]|0;
    $31 = (_ungetc(($29|0),($30|0))|0);
    $32 = ($31|0)==(-1);
    if ($32) {
     $$01 = -1;
     break;
    }
   }
   STACKTOP = sp;return ($$01|0);
  }
 } while(0);
 HEAP32[$8>>2] = $__c;
 HEAP8[$1>>0] = 1;
 $$01 = $__c;
 STACKTOP = sp;return ($$01|0);
}
function __ZNSt3__110__stdinbufIcE9__getcharEb($this,$__consume) {
 $this = $this|0;
 $__consume = $__consume|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $__1buf = 0, $__enxt = 0, $__extbuf = 0, $__i$09 = 0, $__i2$0 = 0, $__inxt = 0, $__nread$0 = 0, $__nread$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__extbuf = sp + 16|0;
 $__1buf = sp + 8|0;
 $__enxt = sp;
 $__inxt = sp + 4|0;
 $0 = (($this) + 52|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  $3 = (($this) + 48|0);
  $4 = HEAP32[$3>>2]|0;
  if (!($__consume)) {
   $$0 = $4;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$3>>2] = -1;
  HEAP8[$0>>0] = 0;
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(1);
 $8 = $7 ? $6 : 1;
 $9 = ($8|0)>(0);
 L8: do {
  if ($9) {
   $10 = (($this) + 32|0);
   $__i$09 = 0;
   while(1) {
    $11 = HEAP32[$10>>2]|0;
    $12 = (_getc(($11|0))|0);
    $13 = ($12|0)==(-1);
    if ($13) {
     $$0 = -1;
     break;
    }
    $14 = $12&255;
    $15 = (($__extbuf) + ($__i$09)|0);
    HEAP8[$15>>0] = $14;
    $16 = (($__i$09) + 1)|0;
    $17 = ($16|0)<($8|0);
    if ($17) {
     $__i$09 = $16;
    } else {
     break L8;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $18 = (($this) + 53|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = ($19<<24>>24)==(0);
 L15: do {
  if ($20) {
   $21 = (($this) + 40|0);
   $22 = (($this) + 36|0);
   $23 = (($__1buf) + 1|0);
   $24 = (($this) + 32|0);
   $__nread$0 = $8;
   while(1) {
    $26 = HEAP32[$21>>2]|0;
    $27 = $26;
    $28 = $27;
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 4)|0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = HEAP32[$22>>2]|0;
    $34 = (($__extbuf) + ($__nread$0)|0);
    $35 = HEAP32[$33>>2]|0;
    $36 = (($35) + 16|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (FUNCTION_TABLE_iiiiiiiii[$37 & 63]($33,$26,$__extbuf,$34,$__enxt,$__1buf,$23,$__inxt)|0);
    if ((($38|0) == 3)) {
     label = 14;
     break;
    } else if ((($38|0) == 2)) {
     $$0 = -1;
     label = 23;
     break;
    } else if (!((($38|0) == 1))) {
     $__nread$2 = $__nread$0;
     break L15;
    }
    $39 = HEAP32[$21>>2]|0;
    $40 = $39;
    $41 = $40;
    HEAP32[$41>>2] = $29;
    $42 = (($40) + 4)|0;
    $43 = $42;
    HEAP32[$43>>2] = $32;
    $44 = ($__nread$0|0)==(8);
    if ($44) {
     $$0 = -1;
     label = 23;
     break;
    }
    $45 = HEAP32[$24>>2]|0;
    $46 = (_getc(($45|0))|0);
    $47 = ($46|0)==(-1);
    if ($47) {
     $$0 = -1;
     label = 23;
     break;
    }
    $49 = $46&255;
    HEAP8[$34>>0] = $49;
    $50 = (($__nread$0) + 1)|0;
    $__nread$0 = $50;
   }
   if ((label|0) == 14) {
    $48 = HEAP8[$__extbuf>>0]|0;
    HEAP8[$__1buf>>0] = $48;
    $__nread$2 = $__nread$0;
    break;
   }
   else if ((label|0) == 23) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $25 = HEAP8[$__extbuf>>0]|0;
   HEAP8[$__1buf>>0] = $25;
   $__nread$2 = $8;
  }
 } while(0);
 do {
  if ($__consume) {
   $60 = HEAP8[$__1buf>>0]|0;
   $61 = $60&255;
   $62 = (($this) + 48|0);
   HEAP32[$62>>2] = $61;
   $64 = $60;
  } else {
   $51 = (($this) + 32|0);
   $__i2$0 = $__nread$2;
   while(1) {
    $52 = ($__i2$0|0)>(0);
    if (!($52)) {
     label = 21;
     break;
    }
    $53 = (($__i2$0) + -1)|0;
    $54 = (($__extbuf) + ($53)|0);
    $55 = HEAP8[$54>>0]|0;
    $56 = $55&255;
    $57 = HEAP32[$51>>2]|0;
    $58 = (_ungetc(($56|0),($57|0))|0);
    $59 = ($58|0)==(-1);
    if ($59) {
     $$0 = -1;
     label = 23;
     break;
    } else {
     $__i2$0 = $53;
    }
   }
   if ((label|0) == 21) {
    $$pre = HEAP8[$__1buf>>0]|0;
    $64 = $$pre;
    break;
   }
   else if ((label|0) == 23) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $63 = $64&255;
 $$0 = $63;
 STACKTOP = sp;return ($$0|0);
}
function __GLOBAL__I_a1496() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__18ios_base4InitC2Ev(0);
 STACKTOP = sp;return;
}
function __ZNSt3__114__shared_countD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt3__114__shared_count12__add_sharedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = (($1+1)|0);
 STACKTOP = sp;return;
}
function __ZNSt3__114__shared_count16__release_sharedEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;HEAP32[$0>>2] = (($1+-1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_vi[$5 & 4095]($this);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt11logic_errorC2EPKc($this,$msg) {
 $this = $this|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3105496 + 8|0));
 $0 = (($this) + 4|0);
 __THREW__ = 0;
 invoke_vii(3502,($0|0),($msg|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  ___resumeException($3|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt13runtime_errorC2ERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE($this,$msg) {
 $this = $this|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3105520 + 8|0));
 $0 = (($this) + 4|0);
 $1 = HEAP8[$msg>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($msg) + 1|0);
  $7 = $6;
 } else {
  $4 = (($msg) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 __THREW__ = 0;
 invoke_vii(3502,($0|0),($7|0));
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $10 = ___cxa_find_matching_catch()|0;
  $11 = tempRet0;
  ___resumeException($10|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt13runtime_errorC2EPKc($this,$msg) {
 $this = $this|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3105520 + 8|0));
 $0 = (($this) + 4|0);
 __THREW__ = 0;
 invoke_vii(3502,($0|0),($msg|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  ___resumeException($3|0);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN12_GLOBAL__N_114__libcpp_nmstrC2EPKc($this,$msg) {
 $this = $this|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($msg|0))|0);
 $1 = (($0) + 1)|0;
 $2 = (($0) + 13)|0;
 $3 = (__Znaj($2)|0);
 $4 = (($3) + 4|0);
 HEAP32[$4>>2] = $0;
 HEAP32[$3>>2] = $0;
 $5 = (($3) + 12|0);
 HEAP32[$this>>2] = $5;
 $6 = (($3) + 8|0);
 HEAP32[$6>>2] = 0;
 _memcpy(($5|0),($msg|0),($1|0))|0;
 STACKTOP = sp;return;
}
function __ZNSt3__114error_categoryD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__114error_category23default_error_conditionEi($agg$result,$this,$ev) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $ev = $ev|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$agg$result>>2] = $ev;
 $0 = (($agg$result) + 4|0);
 HEAP32[$0>>2] = $this;
 STACKTOP = sp;return;
}
function __ZNKSt3__114error_category10equivalentEiRKNS_15error_conditionE($this,$code,$condition) {
 $this = $this|0;
 $code = $code|0;
 $condition = $condition|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_viii[$3 & 4095]($0,$this,$code);
 $4 = (($0) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($condition) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)==($7|0);
 if (!($8)) {
  $12 = 0;
  STACKTOP = sp;return ($12|0);
 }
 $9 = HEAP32[$0>>2]|0;
 $10 = HEAP32[$condition>>2]|0;
 $11 = ($9|0)==($10|0);
 $12 = $11;
 STACKTOP = sp;return ($12|0);
}
function __ZNKSt3__114error_category10equivalentERKNS_10error_codeEi($this,$code,$condition) {
 $this = $this|0;
 $code = $code|0;
 $condition = $condition|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($code) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($this|0);
 if (!($2)) {
  $5 = 0;
  STACKTOP = sp;return ($5|0);
 }
 $3 = HEAP32[$code>>2]|0;
 $4 = ($3|0)==($condition|0);
 $5 = $4;
 STACKTOP = sp;return ($5|0);
}
function __ZNKSt3__112__do_message7messageEi($agg$result,$this,$ev) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $ev = $ev|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strerror(($ev|0))|0);
 $1 = (_strlen(($0|0))|0);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj($agg$result,$0,$1);
 STACKTOP = sp;return;
}
function __ZNSt3__112system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$ec,$what_arg) {
 $agg$result = $agg$result|0;
 $ec = $ec|0;
 $what_arg = $what_arg|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$ec>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  ;HEAP32[$agg$result+0>>2]=HEAP32[$what_arg+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$what_arg+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$what_arg+8>>2]|0;
  ;HEAP32[$what_arg+0>>2]=0|0;HEAP32[$what_arg+4>>2]=0|0;HEAP32[$what_arg+8>>2]=0|0;
  STACKTOP = sp;return;
 }
 $3 = HEAP8[$what_arg>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $8 = $3&255;
  $9 = $8 >>> 1;
  $11 = $9;
 } else {
  $6 = (($what_arg) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $11 = $7;
 }
 $10 = ($11|0)==(0);
 if ($10) {
  $17 = $1;
 } else {
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc($what_arg,3089920)|0);
  $$pre = HEAP32[$ec>>2]|0;
  $17 = $$pre;
 }
 $12 = (($ec) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 FUNCTION_TABLE_viii[$16 & 4095]($0,$13,$17);
 $18 = HEAP8[$0>>0]|0;
 $19 = $18 & 1;
 $20 = ($19<<24>>24)==(0);
 if ($20) {
  $25 = (($0) + 1|0);
  $26 = $18&255;
  $27 = $26 >>> 1;
  $28 = $25;$29 = $27;
 } else {
  $21 = (($0) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($0) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $28 = $22;$29 = $24;
 }
 __THREW__ = 0;
 (invoke_iiii(1480,($what_arg|0),($28|0),($29|0))|0);
 $30 = __THREW__; __THREW__ = 0;
 $31 = $30&1;
 if ($31) {
  $32 = ___cxa_find_matching_catch()|0;
  $33 = tempRet0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0);
  ___resumeException($32|0);
  // unreachable;
 }
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0);
 ;HEAP32[$agg$result+0>>2]=HEAP32[$what_arg+0>>2]|0;HEAP32[$agg$result+4>>2]=HEAP32[$what_arg+4>>2]|0;HEAP32[$agg$result+8>>2]=HEAP32[$what_arg+8>>2]|0;
 ;HEAP32[$what_arg+0>>2]=0|0;HEAP32[$what_arg+4>>2]=0|0;HEAP32[$what_arg+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNSt3__112system_errorC2ENS_10error_codeEPKc($this,$ec,$what_arg) {
 $this = $this|0;
 $ec = $ec|0;
 $what_arg = $what_arg|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 12|0;
 $1 = sp;
 $2 = (_strlen(($what_arg|0))|0);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj($1,$what_arg,$2);
 __THREW__ = 0;
 invoke_viii(2126,($0|0),($ec|0),($1|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $18 = ___cxa_find_matching_catch()|0;
  $19 = tempRet0;
  $$0 = $19;$$01 = $18;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  ___resumeException($$01|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vii(3503,($this|0),($0|0));
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0);
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
  HEAP32[$this>>2] = ((3089928 + 8|0));
  $7 = (($this) + 8|0);
  $8 = $ec;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $7;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  STACKTOP = sp;return;
 }
 $20 = ___cxa_find_matching_catch()|0;
 $21 = tempRet0;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($0);
 $$0 = $21;$$01 = $20;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($1);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZNSt3__112system_errorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt13runtime_errorD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__112system_errorD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt13runtime_errorD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__112__next_primeEj($n) {
 $n = $n|0;
 var $$ = 0, $$0 = 0, $$k0$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $i$09 = 0, $in$0 = 0, $j$04 = 0, $k0$0 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 4|0;
 HEAP32[$1>>2] = $n;
 $3 = ($n>>>0)<(212);
 if ($3) {
  $4 = (__ZNSt3__113__lower_boundIRNS_6__lessIjjEEPKjjEET0_S6_S6_RKT1_T_(3090072,((3090072 + 192|0)),$1,$0)|0);
  $5 = HEAP32[$4>>2]|0;
  $$0 = $5;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = ($n>>>0)>(4294967291);
 if ($6) {
  $7 = (___cxa_allocate_exception(8)|0);
  __THREW__ = 0;
  invoke_vii(3504,($7|0),(3090456|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if ($9) {
   $10 = ___cxa_find_matching_catch()|0;
   $11 = tempRet0;
   ___cxa_free_exception(($7|0));
   ___resumeException($10|0);
   // unreachable;
  } else {
   HEAP32[$7>>2] = ((3105744 + 8|0));
   ___cxa_throw(($7|0),(3105792|0),(3284|0));
   // unreachable;
  }
 }
 $12 = (($n>>>0) / 210)&-1;
 $13 = ($12*210)|0;
 $14 = (($n) - ($13))|0;
 HEAP32[$2>>2] = $14;
 $15 = (__ZNSt3__113__lower_boundIRNS_6__lessIjjEEPKjjEET0_S6_S6_RKT1_T_(3090264,((3090264 + 192|0)),$2,$0)|0);
 $16 = $15;
 $17 = (($16) - (3090264))|0;
 $18 = $17 >> 2;
 $19 = (3090264 + ($18<<2)|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + ($13))|0;
 $in$0 = $18;$k0$0 = $12;$storemerge = $21;
 L11: while(1) {
  $j$04 = 5;
  while(1) {
   $24 = (3090072 + ($j$04<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($storemerge>>>0) / ($25>>>0))&-1;
   $27 = ($26>>>0)<($25>>>0);
   if ($27) {
    label = 111;
    break L11;
   }
   $28 = Math_imul($26, $25)|0;
   $29 = ($storemerge|0)==($28|0);
   $23 = (($j$04) + 1)|0;
   if ($29) {
    break;
   }
   $22 = ($23>>>0)<(47);
   if ($22) {
    $j$04 = $23;
   } else {
    label = 12;
    break;
   }
  }
  L17: do {
   if ((label|0) == 12) {
    label = 0;
    $30 = ($storemerge>>>0)<(44521);
    if ($30) {
     label = 114;
     break L11;
    }
    $31 = (($storemerge>>>0) / 211)&-1;
    $36 = $31;$i$09 = 211;
    while(1) {
     $35 = Math_imul($36, $i$09)|0;
     $37 = ($storemerge|0)==($35|0);
     if ($37) {
      break L17;
     }
     $38 = (($i$09) + 10)|0;
     $39 = (($storemerge>>>0) / ($38>>>0))&-1;
     $40 = ($39>>>0)<($38>>>0);
     if ($40) {
      label = 112;
      break L11;
     }
     $41 = Math_imul($39, $38)|0;
     $42 = ($storemerge|0)==($41|0);
     if ($42) {
      break L17;
     }
     $43 = (($i$09) + 12)|0;
     $44 = (($storemerge>>>0) / ($43>>>0))&-1;
     $45 = ($44>>>0)<($43>>>0);
     if ($45) {
      label = 112;
      break L11;
     }
     $46 = Math_imul($44, $43)|0;
     $47 = ($storemerge|0)==($46|0);
     if ($47) {
      break L17;
     }
     $48 = (($i$09) + 16)|0;
     $49 = (($storemerge>>>0) / ($48>>>0))&-1;
     $50 = ($49>>>0)<($48>>>0);
     if ($50) {
      label = 112;
      break L11;
     }
     $51 = Math_imul($49, $48)|0;
     $52 = ($storemerge|0)==($51|0);
     if ($52) {
      break L17;
     }
     $53 = (($i$09) + 18)|0;
     $54 = (($storemerge>>>0) / ($53>>>0))&-1;
     $55 = ($54>>>0)<($53>>>0);
     if ($55) {
      label = 112;
      break L11;
     }
     $56 = Math_imul($54, $53)|0;
     $57 = ($storemerge|0)==($56|0);
     if ($57) {
      break L17;
     }
     $58 = (($i$09) + 22)|0;
     $59 = (($storemerge>>>0) / ($58>>>0))&-1;
     $60 = ($59>>>0)<($58>>>0);
     if ($60) {
      label = 112;
      break L11;
     }
     $61 = Math_imul($59, $58)|0;
     $62 = ($storemerge|0)==($61|0);
     if ($62) {
      break L17;
     }
     $63 = (($i$09) + 28)|0;
     $64 = (($storemerge>>>0) / ($63>>>0))&-1;
     $65 = ($64>>>0)<($63>>>0);
     if ($65) {
      label = 112;
      break L11;
     }
     $66 = Math_imul($64, $63)|0;
     $67 = ($storemerge|0)==($66|0);
     if ($67) {
      break L17;
     }
     $68 = (($i$09) + 30)|0;
     $69 = (($storemerge>>>0) / ($68>>>0))&-1;
     $70 = ($69>>>0)<($68>>>0);
     if ($70) {
      label = 112;
      break L11;
     }
     $71 = Math_imul($69, $68)|0;
     $72 = ($storemerge|0)==($71|0);
     if ($72) {
      break L17;
     }
     $73 = (($i$09) + 36)|0;
     $74 = (($storemerge>>>0) / ($73>>>0))&-1;
     $75 = ($74>>>0)<($73>>>0);
     if ($75) {
      label = 112;
      break L11;
     }
     $76 = Math_imul($74, $73)|0;
     $77 = ($storemerge|0)==($76|0);
     if ($77) {
      break L17;
     }
     $78 = (($i$09) + 40)|0;
     $79 = (($storemerge>>>0) / ($78>>>0))&-1;
     $80 = ($79>>>0)<($78>>>0);
     if ($80) {
      label = 112;
      break L11;
     }
     $81 = Math_imul($79, $78)|0;
     $82 = ($storemerge|0)==($81|0);
     if ($82) {
      break L17;
     }
     $83 = (($i$09) + 42)|0;
     $84 = (($storemerge>>>0) / ($83>>>0))&-1;
     $85 = ($84>>>0)<($83>>>0);
     if ($85) {
      label = 112;
      break L11;
     }
     $86 = Math_imul($84, $83)|0;
     $87 = ($storemerge|0)==($86|0);
     if ($87) {
      break L17;
     }
     $88 = (($i$09) + 46)|0;
     $89 = (($storemerge>>>0) / ($88>>>0))&-1;
     $90 = ($89>>>0)<($88>>>0);
     if ($90) {
      label = 112;
      break L11;
     }
     $91 = Math_imul($89, $88)|0;
     $92 = ($storemerge|0)==($91|0);
     if ($92) {
      break L17;
     }
     $93 = (($i$09) + 52)|0;
     $94 = (($storemerge>>>0) / ($93>>>0))&-1;
     $95 = ($94>>>0)<($93>>>0);
     if ($95) {
      label = 112;
      break L11;
     }
     $96 = Math_imul($94, $93)|0;
     $97 = ($storemerge|0)==($96|0);
     if ($97) {
      break L17;
     }
     $98 = (($i$09) + 58)|0;
     $99 = (($storemerge>>>0) / ($98>>>0))&-1;
     $100 = ($99>>>0)<($98>>>0);
     if ($100) {
      label = 112;
      break L11;
     }
     $101 = Math_imul($99, $98)|0;
     $102 = ($storemerge|0)==($101|0);
     if ($102) {
      break L17;
     }
     $103 = (($i$09) + 60)|0;
     $104 = (($storemerge>>>0) / ($103>>>0))&-1;
     $105 = ($104>>>0)<($103>>>0);
     if ($105) {
      label = 112;
      break L11;
     }
     $106 = Math_imul($104, $103)|0;
     $107 = ($storemerge|0)==($106|0);
     if ($107) {
      break L17;
     }
     $108 = (($i$09) + 66)|0;
     $109 = (($storemerge>>>0) / ($108>>>0))&-1;
     $110 = ($109>>>0)<($108>>>0);
     if ($110) {
      label = 112;
      break L11;
     }
     $111 = Math_imul($109, $108)|0;
     $112 = ($storemerge|0)==($111|0);
     if ($112) {
      break L17;
     }
     $113 = (($i$09) + 70)|0;
     $114 = (($storemerge>>>0) / ($113>>>0))&-1;
     $115 = ($114>>>0)<($113>>>0);
     if ($115) {
      label = 112;
      break L11;
     }
     $116 = Math_imul($114, $113)|0;
     $117 = ($storemerge|0)==($116|0);
     if ($117) {
      break L17;
     }
     $118 = (($i$09) + 72)|0;
     $119 = (($storemerge>>>0) / ($118>>>0))&-1;
     $120 = ($119>>>0)<($118>>>0);
     if ($120) {
      label = 112;
      break L11;
     }
     $121 = Math_imul($119, $118)|0;
     $122 = ($storemerge|0)==($121|0);
     if ($122) {
      break L17;
     }
     $123 = (($i$09) + 78)|0;
     $124 = (($storemerge>>>0) / ($123>>>0))&-1;
     $125 = ($124>>>0)<($123>>>0);
     if ($125) {
      label = 112;
      break L11;
     }
     $126 = Math_imul($124, $123)|0;
     $127 = ($storemerge|0)==($126|0);
     if ($127) {
      break L17;
     }
     $128 = (($i$09) + 82)|0;
     $129 = (($storemerge>>>0) / ($128>>>0))&-1;
     $130 = ($129>>>0)<($128>>>0);
     if ($130) {
      label = 112;
      break L11;
     }
     $131 = Math_imul($129, $128)|0;
     $132 = ($storemerge|0)==($131|0);
     if ($132) {
      break L17;
     }
     $133 = (($i$09) + 88)|0;
     $134 = (($storemerge>>>0) / ($133>>>0))&-1;
     $135 = ($134>>>0)<($133>>>0);
     if ($135) {
      label = 112;
      break L11;
     }
     $136 = Math_imul($134, $133)|0;
     $137 = ($storemerge|0)==($136|0);
     if ($137) {
      break L17;
     }
     $138 = (($i$09) + 96)|0;
     $139 = (($storemerge>>>0) / ($138>>>0))&-1;
     $140 = ($139>>>0)<($138>>>0);
     if ($140) {
      label = 112;
      break L11;
     }
     $141 = Math_imul($139, $138)|0;
     $142 = ($storemerge|0)==($141|0);
     if ($142) {
      break L17;
     }
     $143 = (($i$09) + 100)|0;
     $144 = (($storemerge>>>0) / ($143>>>0))&-1;
     $145 = ($144>>>0)<($143>>>0);
     if ($145) {
      label = 112;
      break L11;
     }
     $146 = Math_imul($144, $143)|0;
     $147 = ($storemerge|0)==($146|0);
     if ($147) {
      break L17;
     }
     $148 = (($i$09) + 102)|0;
     $149 = (($storemerge>>>0) / ($148>>>0))&-1;
     $150 = ($149>>>0)<($148>>>0);
     if ($150) {
      label = 112;
      break L11;
     }
     $151 = Math_imul($149, $148)|0;
     $152 = ($storemerge|0)==($151|0);
     if ($152) {
      break L17;
     }
     $153 = (($i$09) + 106)|0;
     $154 = (($storemerge>>>0) / ($153>>>0))&-1;
     $155 = ($154>>>0)<($153>>>0);
     if ($155) {
      label = 112;
      break L11;
     }
     $156 = Math_imul($154, $153)|0;
     $157 = ($storemerge|0)==($156|0);
     if ($157) {
      break L17;
     }
     $158 = (($i$09) + 108)|0;
     $159 = (($storemerge>>>0) / ($158>>>0))&-1;
     $160 = ($159>>>0)<($158>>>0);
     if ($160) {
      label = 112;
      break L11;
     }
     $161 = Math_imul($159, $158)|0;
     $162 = ($storemerge|0)==($161|0);
     if ($162) {
      break L17;
     }
     $163 = (($i$09) + 112)|0;
     $164 = (($storemerge>>>0) / ($163>>>0))&-1;
     $165 = ($164>>>0)<($163>>>0);
     if ($165) {
      label = 112;
      break L11;
     }
     $166 = Math_imul($164, $163)|0;
     $167 = ($storemerge|0)==($166|0);
     if ($167) {
      break L17;
     }
     $168 = (($i$09) + 120)|0;
     $169 = (($storemerge>>>0) / ($168>>>0))&-1;
     $170 = ($169>>>0)<($168>>>0);
     if ($170) {
      label = 112;
      break L11;
     }
     $171 = Math_imul($169, $168)|0;
     $172 = ($storemerge|0)==($171|0);
     if ($172) {
      break L17;
     }
     $173 = (($i$09) + 126)|0;
     $174 = (($storemerge>>>0) / ($173>>>0))&-1;
     $175 = ($174>>>0)<($173>>>0);
     if ($175) {
      label = 112;
      break L11;
     }
     $176 = Math_imul($174, $173)|0;
     $177 = ($storemerge|0)==($176|0);
     if ($177) {
      break L17;
     }
     $178 = (($i$09) + 130)|0;
     $179 = (($storemerge>>>0) / ($178>>>0))&-1;
     $180 = ($179>>>0)<($178>>>0);
     if ($180) {
      label = 112;
      break L11;
     }
     $181 = Math_imul($179, $178)|0;
     $182 = ($storemerge|0)==($181|0);
     if ($182) {
      break L17;
     }
     $183 = (($i$09) + 136)|0;
     $184 = (($storemerge>>>0) / ($183>>>0))&-1;
     $185 = ($184>>>0)<($183>>>0);
     if ($185) {
      label = 112;
      break L11;
     }
     $186 = Math_imul($184, $183)|0;
     $187 = ($storemerge|0)==($186|0);
     if ($187) {
      break L17;
     }
     $188 = (($i$09) + 138)|0;
     $189 = (($storemerge>>>0) / ($188>>>0))&-1;
     $190 = ($189>>>0)<($188>>>0);
     if ($190) {
      label = 112;
      break L11;
     }
     $191 = Math_imul($189, $188)|0;
     $192 = ($storemerge|0)==($191|0);
     if ($192) {
      break L17;
     }
     $193 = (($i$09) + 142)|0;
     $194 = (($storemerge>>>0) / ($193>>>0))&-1;
     $195 = ($194>>>0)<($193>>>0);
     if ($195) {
      label = 112;
      break L11;
     }
     $196 = Math_imul($194, $193)|0;
     $197 = ($storemerge|0)==($196|0);
     if ($197) {
      break L17;
     }
     $198 = (($i$09) + 148)|0;
     $199 = (($storemerge>>>0) / ($198>>>0))&-1;
     $200 = ($199>>>0)<($198>>>0);
     if ($200) {
      label = 112;
      break L11;
     }
     $201 = Math_imul($199, $198)|0;
     $202 = ($storemerge|0)==($201|0);
     if ($202) {
      break L17;
     }
     $203 = (($i$09) + 150)|0;
     $204 = (($storemerge>>>0) / ($203>>>0))&-1;
     $205 = ($204>>>0)<($203>>>0);
     if ($205) {
      label = 112;
      break L11;
     }
     $206 = Math_imul($204, $203)|0;
     $207 = ($storemerge|0)==($206|0);
     if ($207) {
      break L17;
     }
     $208 = (($i$09) + 156)|0;
     $209 = (($storemerge>>>0) / ($208>>>0))&-1;
     $210 = ($209>>>0)<($208>>>0);
     if ($210) {
      label = 112;
      break L11;
     }
     $211 = Math_imul($209, $208)|0;
     $212 = ($storemerge|0)==($211|0);
     if ($212) {
      break L17;
     }
     $213 = (($i$09) + 162)|0;
     $214 = (($storemerge>>>0) / ($213>>>0))&-1;
     $215 = ($214>>>0)<($213>>>0);
     if ($215) {
      label = 112;
      break L11;
     }
     $216 = Math_imul($214, $213)|0;
     $217 = ($storemerge|0)==($216|0);
     if ($217) {
      break L17;
     }
     $218 = (($i$09) + 166)|0;
     $219 = (($storemerge>>>0) / ($218>>>0))&-1;
     $220 = ($219>>>0)<($218>>>0);
     if ($220) {
      label = 112;
      break L11;
     }
     $221 = Math_imul($219, $218)|0;
     $222 = ($storemerge|0)==($221|0);
     if ($222) {
      break L17;
     }
     $223 = (($i$09) + 168)|0;
     $224 = (($storemerge>>>0) / ($223>>>0))&-1;
     $225 = ($224>>>0)<($223>>>0);
     if ($225) {
      label = 112;
      break L11;
     }
     $226 = Math_imul($224, $223)|0;
     $227 = ($storemerge|0)==($226|0);
     if ($227) {
      break L17;
     }
     $228 = (($i$09) + 172)|0;
     $229 = (($storemerge>>>0) / ($228>>>0))&-1;
     $230 = ($229>>>0)<($228>>>0);
     if ($230) {
      label = 112;
      break L11;
     }
     $231 = Math_imul($229, $228)|0;
     $232 = ($storemerge|0)==($231|0);
     if ($232) {
      break L17;
     }
     $233 = (($i$09) + 178)|0;
     $234 = (($storemerge>>>0) / ($233>>>0))&-1;
     $235 = ($234>>>0)<($233>>>0);
     if ($235) {
      label = 112;
      break L11;
     }
     $236 = Math_imul($234, $233)|0;
     $237 = ($storemerge|0)==($236|0);
     if ($237) {
      break L17;
     }
     $238 = (($i$09) + 180)|0;
     $239 = (($storemerge>>>0) / ($238>>>0))&-1;
     $240 = ($239>>>0)<($238>>>0);
     if ($240) {
      label = 112;
      break L11;
     }
     $241 = Math_imul($239, $238)|0;
     $242 = ($storemerge|0)==($241|0);
     if ($242) {
      break L17;
     }
     $243 = (($i$09) + 186)|0;
     $244 = (($storemerge>>>0) / ($243>>>0))&-1;
     $245 = ($244>>>0)<($243>>>0);
     if ($245) {
      label = 112;
      break L11;
     }
     $246 = Math_imul($244, $243)|0;
     $247 = ($storemerge|0)==($246|0);
     if ($247) {
      break L17;
     }
     $248 = (($i$09) + 190)|0;
     $249 = (($storemerge>>>0) / ($248>>>0))&-1;
     $250 = ($249>>>0)<($248>>>0);
     if ($250) {
      label = 112;
      break L11;
     }
     $251 = Math_imul($249, $248)|0;
     $252 = ($storemerge|0)==($251|0);
     if ($252) {
      break L17;
     }
     $253 = (($i$09) + 192)|0;
     $254 = (($storemerge>>>0) / ($253>>>0))&-1;
     $255 = ($254>>>0)<($253>>>0);
     if ($255) {
      label = 112;
      break L11;
     }
     $256 = Math_imul($254, $253)|0;
     $257 = ($storemerge|0)==($256|0);
     if ($257) {
      break L17;
     }
     $258 = (($i$09) + 196)|0;
     $259 = (($storemerge>>>0) / ($258>>>0))&-1;
     $260 = ($259>>>0)<($258>>>0);
     if ($260) {
      label = 112;
      break L11;
     }
     $261 = Math_imul($259, $258)|0;
     $262 = ($storemerge|0)==($261|0);
     if ($262) {
      break L17;
     }
     $263 = (($i$09) + 198)|0;
     $264 = (($storemerge>>>0) / ($263>>>0))&-1;
     $265 = ($264>>>0)<($263>>>0);
     if ($265) {
      label = 112;
      break L11;
     }
     $266 = Math_imul($264, $263)|0;
     $267 = ($storemerge|0)==($266|0);
     if ($267) {
      break L17;
     }
     $268 = (($i$09) + 208)|0;
     $269 = (($storemerge>>>0) / ($268>>>0))&-1;
     $270 = ($269>>>0)<($268>>>0);
     if ($270) {
      label = 112;
      break L11;
     }
     $271 = Math_imul($269, $268)|0;
     $272 = ($storemerge|0)==($271|0);
     $33 = (($i$09) + 210)|0;
     if ($272) {
      break L17;
     }
     $32 = (($storemerge>>>0) / ($33>>>0))&-1;
     $34 = ($32>>>0)<($33>>>0);
     if ($34) {
      label = 113;
      break L11;
     } else {
      $36 = $32;$i$09 = $33;
     }
    }
   }
  } while(0);
  $273 = (($in$0) + 1)|0;
  $274 = ($273|0)==(48);
  $$ = $274 ? 0 : $273;
  $275 = $274&1;
  $$k0$0 = (($275) + ($k0$0))|0;
  $276 = ($$k0$0*210)|0;
  $277 = (3090264 + ($$<<2)|0);
  $278 = HEAP32[$277>>2]|0;
  $279 = (($278) + ($276))|0;
  $in$0 = $$;$k0$0 = $$k0$0;$storemerge = $279;
 }
 if ((label|0) == 111) {
  HEAP32[$1>>2] = $storemerge;
  $$0 = $storemerge;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 112) {
  HEAP32[$1>>2] = $storemerge;
  $$0 = $storemerge;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 113) {
  HEAP32[$1>>2] = $storemerge;
  $$0 = $storemerge;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 114) {
  HEAP32[$1>>2] = $storemerge;
  $$0 = $storemerge;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__113__lower_boundIRNS_6__lessIjjEEPKjjEET0_S6_S6_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + ($5<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = HEAP32[$__value_>>2]|0;
   $9 = ($7>>>0)<($8>>>0);
   if ($9) {
    break;
   } else {
    $__len$0 = $5;
   }
  }
  $$sum = (($5) + 1)|0;
  $10 = (($$0$ph) + ($$sum<<2)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $11 = (($$neg1) - ($5))|0;
  $$0$ph = $10;$__len$0$ph = $11;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZNSt3__111__call_onceERVmPvPFvS2_E($flag,$arg,$func) {
 $flag = $flag|0;
 $arg = $arg|0;
 $func = $func|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_pthread_mutex_lock((3090480|0))|0);
 $0 = HEAP32[$flag>>2]|0;
 $1 = ($0|0)==(1);
 if ($1) {
  while(1) {
   (_pthread_cond_wait((3090504|0),(3090480|0))|0);
   $2 = HEAP32[$flag>>2]|0;
   $3 = ($2|0)==(1);
   if (!($3)) {
    break;
   }
  }
 }
 $4 = HEAP32[$flag>>2]|0;
 $5 = ($4|0)==(0);
 if (!($5)) {
  (_pthread_mutex_unlock((3090480|0))|0);
  STACKTOP = sp;return;
 }
 HEAP32[$flag>>2] = 1;
 __THREW__ = 0;
 (invoke_ii(3480,(3090480|0))|0);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  __THREW__ = 0;
  invoke_vi($func|0,($arg|0));
  $8 = __THREW__; __THREW__ = 0;
  $9 = $8&1;
  if (!($9)) {
   __THREW__ = 0;
   (invoke_ii(3481,(3090480|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    HEAP32[$flag>>2] = -1;
    __THREW__ = 0;
    (invoke_ii(3480,(3090480|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     (invoke_ii(3482,(3090504|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $16 = ___cxa_find_matching_catch(0|0)|0;
 $17 = tempRet0;
 (___cxa_begin_catch(($16|0))|0);
 __THREW__ = 0;
 (invoke_ii(3481,(3090480|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if (!($19)) {
  HEAP32[$flag>>2] = 0;
  __THREW__ = 0;
  (invoke_ii(3480,(3090480|0))|0);
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if (!($21)) {
   __THREW__ = 0;
   (invoke_ii(3482,(3090504|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if (!($23)) {
    __THREW__ = 0;
    invoke_v(140);
    $24 = __THREW__; __THREW__ = 0;
    $25 = $24&1;
    if (!($25)) {
     // unreachable;
    }
   }
  }
 }
 $26 = ___cxa_find_matching_catch()|0;
 $27 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $30 = ___cxa_find_matching_catch(0|0)|0;
  $31 = tempRet0;
  ___clang_call_terminate($30);
  // unreachable;
 } else {
  ___resumeException($26|0);
  // unreachable;
 }
}
function __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(3505,($0|0),(3090552|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  ___cxa_free_exception(($0|0));
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[$0>>2] = ((3105576 + 8|0));
  ___cxa_throw(($0|0),(3105624|0),(3282|0));
  // unreachable;
 }
}
function __ZNKSt3__121__basic_string_commonILb1EE20__throw_out_of_rangeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(3505,($0|0),(3090552|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  ___cxa_free_exception(($0|0));
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[$0>>2] = ((3105640 + 8|0));
  ___cxa_throw(($0|0),(3105688|0),(3282|0));
  // unreachable;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_($this,$__str) {
 $this = $this|0;
 $__str = $__str|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($this,$__str);
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_($this,$__str) {
 $this = $this|0;
 $__str = $__str|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$__str>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  ;HEAP32[$this+0>>2]=HEAP32[$__str+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$__str+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$__str+8>>2]|0;
  STACKTOP = sp;return;
 } else {
  $3 = (($__str) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($__str) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj($this,$4,$6);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj($this,$__s,$__sz) {
 $this = $this|0;
 $__s = $__s|0;
 $__sz = $__sz|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__sz>>>0)>(4294967279);
 if ($0) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $1 = ($__sz>>>0)<(11);
 if ($1) {
  $2 = $__sz << 1;
  $3 = $2&255;
  HEAP8[$this>>0] = $3;
  $4 = (($this) + 1|0);
  $__p$0 = $4;
 } else {
  $5 = (($__sz) + 16)|0;
  $6 = $5 & -16;
  $7 = (__Znwj($6)|0);
  $8 = (($this) + 8|0);
  HEAP32[$8>>2] = $7;
  $9 = $6 | 1;
  HEAP32[$this>>2] = $9;
  $10 = (($this) + 4|0);
  HEAP32[$10>>2] = $__sz;
  $__p$0 = $7;
 }
 _memcpy(($__p$0|0),($__s|0),($__sz|0))|0;
 $11 = (($__p$0) + ($__sz)|0);
 HEAP8[$11>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEjc($this,$__n,$__c) {
 $this = $this|0;
 $__n = $__n|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n>>>0)>(4294967279);
 if ($0) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $1 = ($__n>>>0)<(11);
 if ($1) {
  $2 = $__n << 1;
  $3 = $2&255;
  HEAP8[$this>>0] = $3;
  $4 = (($this) + 1|0);
  $__p$0 = $4;
 } else {
  $5 = (($__n) + 16)|0;
  $6 = $5 & -16;
  $7 = (__Znwj($6)|0);
  $8 = (($this) + 8|0);
  HEAP32[$8>>2] = $7;
  $9 = $6 | 1;
  HEAP32[$this>>2] = $9;
  $10 = (($this) + 4|0);
  HEAP32[$10>>2] = $__n;
  $__p$0 = $7;
 }
 _memset(($__p$0|0),($__c|0),($__n|0))|0;
 $11 = (($__p$0) + ($__n)|0);
 HEAP8[$11>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_($this,$__str,$__pos,$__n,$__a) {
 $this = $this|0;
 $__str = $__str|0;
 $__pos = $__pos|0;
 $__n = $__n|0;
 $__a = $__a|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$__str>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($__str) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8>>>0)<($__pos>>>0);
 if ($7) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_out_of_rangeEv(0);
  // unreachable;
 }
 if ($2) {
  $11 = (($__str) + 1|0);
  $13 = $11;
 } else {
  $9 = (($__str) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  $13 = $10;
 }
 $12 = (($13) + ($__pos)|0);
 $14 = (($8) - ($__pos))|0;
 $15 = ($14>>>0)<($__n>>>0);
 $16 = $15 ? $14 : $__n;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj($this,$12,$16);
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $__p$0$lcssa = 0, $__p$0$ph = 0, $__p$01 = 0, $scevgep = 0, $scevgep3 = 0, $scevgep4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__first;
 $1 = $__last;
 $2 = (($1) - ($0))|0;
 $3 = ($2>>>0)>(4294967279);
 if ($3) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $4 = ($2>>>0)<(11);
 if ($4) {
  $5 = $2 << 1;
  $6 = $5&255;
  HEAP8[$this>>0] = $6;
  $7 = (($this) + 1|0);
  $__p$0$ph = $7;
 } else {
  $8 = (($2) + 16)|0;
  $9 = $8 & -16;
  $10 = (__Znwj($9)|0);
  $11 = (($this) + 8|0);
  HEAP32[$11>>2] = $10;
  $12 = $9 | 1;
  HEAP32[$this>>2] = $12;
  $13 = (($this) + 4|0);
  HEAP32[$13>>2] = $2;
  $__p$0$ph = $10;
 }
 $14 = ($__first|0)==($__last|0);
 if ($14) {
  $__p$0$lcssa = $__p$0$ph;
  HEAP8[$__p$0$lcssa>>0] = 0;
  STACKTOP = sp;return;
 }
 $15 = (0 - ($0))|0;
 $scevgep = (($__last) + ($15)|0);
 $scevgep3 = $scevgep;
 $$02 = $__first;$__p$01 = $__p$0$ph;
 while(1) {
  $16 = HEAP8[$$02>>0]|0;
  HEAP8[$__p$01>>0] = $16;
  $17 = (($$02) + 1|0);
  $18 = (($__p$01) + 1|0);
  $19 = ($17|0)==($__last|0);
  if ($19) {
   break;
  } else {
   $$02 = $17;$__p$01 = $18;
  }
 }
 $scevgep4 = (($__p$0$ph) + ($scevgep3)|0);
 $__p$0$lcssa = $scevgep4;
 HEAP8[$__p$0$lcssa>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __ZdlPv($4);
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_($this,$__str) {
 $this = $this|0;
 $__str = $__str|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==($__str|0);
 if ($0) {
  STACKTOP = sp;return ($this|0);
 }
 $1 = HEAP8[$__str>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $8 = (($__str) + 1|0);
  $9 = $1&255;
  $10 = $9 >>> 1;
  $11 = $8;$12 = $10;
 } else {
  $4 = (($__str) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($__str) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $11 = $5;$12 = $7;
 }
 (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($this,$11,$12)|0);
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc($this,$__s) {
 $this = $this|0;
 $__s = $__s|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($__s|0))|0);
 $1 = (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($this,$__s,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcj($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = 10;$9 = $0;
 } else {
  $3 = HEAP32[$this>>2]|0;
  $4 = $3 & -2;
  $phitmp$i = (($4) + -1)|0;
  $5 = $3&255;
  $7 = $phitmp$i;$9 = $5;
 }
 $6 = ($7>>>0)<($__n>>>0);
 $8 = $9 & 1;
 $10 = ($8<<24>>24)==(0);
 if ($6) {
  if ($10) {
   $24 = $9&255;
   $25 = $24 >>> 1;
   $27 = $25;
  } else {
   $22 = (($this) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $27 = $23;
  }
  $26 = (($__n) - ($7))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($this,$7,$26,$27,0,$27,$__n,$__s);
  STACKTOP = sp;return ($this|0);
 }
 if ($10) {
  $13 = (($this) + 1|0);
  $14 = $13;
 } else {
  $11 = (($this) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $14 = $12;
 }
 _memmove(($14|0),($__s|0),($__n|0))|0;
 $15 = (($14) + ($__n)|0);
 HEAP8[$15>>0] = 0;
 $16 = HEAP8[$this>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $20 = $__n << 1;
  $21 = $20&255;
  HEAP8[$this>>0] = $21;
  STACKTOP = sp;return ($this|0);
 } else {
  $19 = (($this) + 4|0);
  HEAP32[$19>>2] = $__n;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc($this,$__n,$__c) {
 $this = $this|0;
 $__n = $__n|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8>>>0)<($__n>>>0);
 if ($7) {
  $9 = (($__n) - ($8))|0;
  (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEjc($this,$9,$__c)|0);
  STACKTOP = sp;return;
 }
 if ($2) {
  $14 = ((($this) + ($__n)|0) + 1|0);
  HEAP8[$14>>0] = 0;
  $15 = $__n << 1;
  $16 = $15&255;
  HEAP8[$this>>0] = $16;
  STACKTOP = sp;return;
 } else {
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + ($__n)|0);
  HEAP8[$12>>0] = 0;
  $13 = (($this) + 4|0);
  HEAP32[$13>>2] = $__n;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEjc($this,$__n,$__c) {
 $this = $this|0;
 $__n = $__n|0;
 $__c = $__c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)==(0);
 if ($0) {
  STACKTOP = sp;return ($this|0);
 }
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $15 = 10;$8 = $1;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 & -2;
  $phitmp$i = (($5) + -1)|0;
  $6 = $4&255;
  $15 = $phitmp$i;$8 = $6;
 }
 $7 = $8 & 1;
 $9 = ($7<<24>>24)==(0);
 if ($9) {
  $12 = $8&255;
  $13 = $12 >>> 1;
  $16 = $13;
 } else {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $16 = $11;
 }
 $14 = (($15) - ($16))|0;
 $17 = ($14>>>0)<($__n>>>0);
 if ($17) {
  $18 = (($__n) - ($15))|0;
  $19 = (($18) + ($16))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($this,$15,$19,$16,$16,0,0);
  $$pre = HEAP8[$this>>0]|0;
  $21 = $$pre;
 } else {
  $21 = $8;
 }
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($22) {
  $25 = (($this) + 1|0);
  $27 = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $27 = $24;
 }
 $26 = (($27) + ($16)|0);
 _memset(($26|0),($__c|0),($__n|0))|0;
 $28 = (($16) + ($__n))|0;
 $29 = HEAP8[$this>>0]|0;
 $30 = $29 & 1;
 $31 = ($30<<24>>24)==(0);
 if ($31) {
  $33 = $28 << 1;
  $34 = $33&255;
  HEAP8[$this>>0] = $34;
 } else {
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $28;
 }
 $35 = (($27) + ($28)|0);
 HEAP8[$35>>0] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj($this,$__res_arg) {
 $this = $this|0;
 $__res_arg = $__res_arg|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_data$0 = 0, $__new_data$1 = 0, $__now_long$0$off0 = 0, $__p$0 = 0, $__was_long$0$off0 = 0, $phitmp$i = 0;
 var $phitmp$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__res_arg>>>0)>(4294967279);
 if ($0) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $22 = 10;$8 = $1;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 & -2;
  $phitmp$i = (($5) + -1)|0;
  $6 = $4&255;
  $22 = $phitmp$i;$8 = $6;
 }
 $7 = $8 & 1;
 $9 = ($7<<24>>24)==(0);
 if ($9) {
  $12 = $8&255;
  $13 = $12 >>> 1;
  $15 = $13;
 } else {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $15 = $11;
 }
 $14 = ($15>>>0)>($__res_arg>>>0);
 $16 = $14 ? $15 : $__res_arg;
 $17 = ($16>>>0)<(11);
 if ($17) {
  $21 = 10;
 } else {
  $18 = (($16) + 16)|0;
  $19 = $18 & -16;
  $phitmp$i2 = (($19) + -1)|0;
  $21 = $phitmp$i2;
 }
 $20 = ($21|0)==($22|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $23 = ($21|0)==(10);
 do {
  if ($23) {
   $24 = (($this) + 1|0);
   $25 = (($this) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $__new_data$1 = $24;$__now_long$0$off0 = 0;$__p$0 = $26;$__was_long$0$off0 = 1;
  } else {
   $27 = ($21>>>0)>($22>>>0);
   $28 = (($21) + 1)|0;
   if ($27) {
    $29 = (__Znwj($28)|0);
    $__new_data$0 = $29;
   } else {
    __THREW__ = 0;
    $30 = (invoke_ii(2988,($28|0))|0);
    $31 = __THREW__; __THREW__ = 0;
    $32 = $31&1;
    if ($32) {
     $33 = ___cxa_find_matching_catch(0|0)|0;
     $34 = tempRet0;
     (___cxa_begin_catch(($33|0))|0);
     ___cxa_end_catch();
     STACKTOP = sp;return;
    } else {
     $__new_data$0 = $30;
    }
   }
   $35 = $8 & 1;
   $36 = ($35<<24>>24)==(0);
   if ($36) {
    $39 = (($this) + 1|0);
    $__new_data$1 = $__new_data$0;$__now_long$0$off0 = 1;$__p$0 = $39;$__was_long$0$off0 = 0;
    break;
   } else {
    $37 = (($this) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    $__new_data$1 = $__new_data$0;$__now_long$0$off0 = 1;$__p$0 = $38;$__was_long$0$off0 = 1;
    break;
   }
  }
 } while(0);
 $40 = $8 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  $44 = $8&255;
  $45 = $44 >>> 1;
  $47 = $45;
 } else {
  $42 = (($this) + 4|0);
  $43 = HEAP32[$42>>2]|0;
  $47 = $43;
 }
 $46 = (($47) + 1)|0;
 _memcpy(($__new_data$1|0),($__p$0|0),($46|0))|0;
 if ($__was_long$0$off0) {
  __ZdlPv($__p$0);
 }
 if ($__now_long$0$off0) {
  $48 = (($21) + 1)|0;
  $49 = $48 | 1;
  HEAP32[$this>>2] = $49;
  $50 = (($this) + 4|0);
  HEAP32[$50>>2] = $15;
  $51 = (($this) + 8|0);
  HEAP32[$51>>2] = $__new_data$1;
  STACKTOP = sp;return;
 } else {
  $52 = $15 << 1;
  $53 = $52&255;
  HEAP8[$this>>0] = $53;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc($this,$__s) {
 $this = $this|0;
 $__s = $__s|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($__s|0))|0);
 $1 = (__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($this,$__s,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__cap$0 = 0, $__p$0 = 0, $__p$0$sum$pre = 0, $__p$0$sum$pre$phiZZZ2D = 0, $__sz$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)!=(0);
 if ($2) {
  $5 = HEAP32[$this>>2]|0;
  $6 = $5 & -2;
  $7 = (($6) + -1)|0;
  $8 = (($this) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $__cap$0 = $7;$__sz$0 = $9;
 } else {
  $3 = $0&255;
  $4 = $3 >>> 1;
  $__cap$0 = 10;$__sz$0 = $4;
 }
 $10 = ($__sz$0|0)==($__cap$0|0);
 if ($10) {
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($this,$__cap$0,1,$__cap$0,$__cap$0,0,0);
  $11 = HEAP8[$this>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 7;
  } else {
   label = 8;
  }
 } else {
  if ($2) {
   label = 8;
  } else {
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $14 = (($this) + 1|0);
  $15 = $__sz$0 << 1;
  $16 = (($15) + 2)|0;
  $17 = $16&255;
  HEAP8[$this>>0] = $17;
  $__p$0$sum$pre = (($__sz$0) + 1)|0;
  $$pn = $14;$__p$0$sum$pre$phiZZZ2D = $__p$0$sum$pre;
  $__p$0 = (($$pn) + ($__sz$0)|0);
  HEAP8[$__p$0>>0] = $__c;
  $22 = (($$pn) + ($__p$0$sum$pre$phiZZZ2D)|0);
  HEAP8[$22>>0] = 0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $18 = (($this) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($__sz$0) + 1)|0;
  $21 = (($this) + 4|0);
  HEAP32[$21>>2] = $20;
  $$pn = $19;$__p$0$sum$pre$phiZZZ2D = $20;
  $__p$0 = (($$pn) + ($__sz$0)|0);
  HEAP8[$__p$0>>0] = $__c;
  $22 = (($$pn) + ($__p$0$sum$pre$phiZZZ2D)|0);
  HEAP8[$22>>0] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $14 = 10;$7 = $0;
 } else {
  $3 = HEAP32[$this>>2]|0;
  $4 = $3 & -2;
  $phitmp$i = (($4) + -1)|0;
  $5 = $3&255;
  $14 = $phitmp$i;$7 = $5;
 }
 $6 = $7 & 1;
 $8 = ($6<<24>>24)==(0);
 if ($8) {
  $11 = $7&255;
  $12 = $11 >>> 1;
  $15 = $12;
 } else {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $15 = $10;
 }
 $13 = (($14) - ($15))|0;
 $16 = ($13>>>0)<($__n>>>0);
 if ($16) {
  $33 = (($__n) - ($14))|0;
  $34 = (($33) + ($15))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($this,$14,$34,$15,$15,0,$__n,$__s);
  STACKTOP = sp;return ($this|0);
 }
 $17 = ($__n|0)==(0);
 if ($17) {
  STACKTOP = sp;return ($this|0);
 }
 $18 = $7 & 1;
 $19 = ($18<<24>>24)==(0);
 if ($19) {
  $22 = (($this) + 1|0);
  $24 = $22;
 } else {
  $20 = (($this) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $24 = $21;
 }
 $23 = (($24) + ($15)|0);
 _memcpy(($23|0),($__s|0),($__n|0))|0;
 $25 = (($15) + ($__n))|0;
 $26 = HEAP8[$this>>0]|0;
 $27 = $26 & 1;
 $28 = ($27<<24>>24)==(0);
 if ($28) {
  $30 = $25 << 1;
  $31 = $30&255;
  HEAP8[$this>>0] = $31;
 } else {
  $29 = (($this) + 4|0);
  HEAP32[$29>>2] = $25;
 }
 $32 = (($24) + ($25)|0);
 HEAP8[$32>>0] = 0;
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add,$__p_new_stuff) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 $__p_new_stuff = $__p_new_stuff|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (-18 - ($__old_cap))|0;
 $1 = ($0>>>0)<($__delta_cap>>>0);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = HEAP8[$this>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = (($this) + 1|0);
  $19 = $7;
 } else {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $19 = $6;
 }
 $8 = ($__old_cap>>>0)<(2147483623);
 if ($8) {
  $9 = (($__delta_cap) + ($__old_cap))|0;
  $10 = $__old_cap << 1;
  $11 = ($9>>>0)<($10>>>0);
  $12 = $11 ? $10 : $9;
  $13 = ($12>>>0)<(11);
  if ($13) {
   $16 = 11;
  } else {
   $14 = (($12) + 16)|0;
   $15 = $14 & -16;
   $16 = $15;
  }
 } else {
  $16 = -17;
 }
 $17 = (__Znwj($16)|0);
 $18 = ($__n_copy|0)==(0);
 if (!($18)) {
  _memcpy(($17|0),($19|0),($__n_copy|0))|0;
 }
 $20 = ($__n_add|0)==(0);
 if (!($20)) {
  $21 = (($17) + ($__n_copy)|0);
  _memcpy(($21|0),($__p_new_stuff|0),($__n_add|0))|0;
 }
 $22 = (($__old_sz) - ($__n_del))|0;
 $23 = ($22|0)==($__n_copy|0);
 if (!($23)) {
  $24 = (($22) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $25 = (($17) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $26 = (($19) + ($$sum1)|0);
  _memcpy(($25|0),($26|0),($24|0))|0;
 }
 $27 = ($__old_cap|0)==(10);
 if ($27) {
  $28 = (($this) + 8|0);
  HEAP32[$28>>2] = $17;
  $29 = $16 | 1;
  HEAP32[$this>>2] = $29;
  $30 = (($22) + ($__n_add))|0;
  $31 = (($this) + 4|0);
  HEAP32[$31>>2] = $30;
  $32 = (($17) + ($30)|0);
  HEAP8[$32>>0] = 0;
  STACKTOP = sp;return;
 }
 __ZdlPv($19);
 $28 = (($this) + 8|0);
 HEAP32[$28>>2] = $17;
 $29 = $16 | 1;
 HEAP32[$this>>2] = $29;
 $30 = (($22) + ($__n_add))|0;
 $31 = (($this) + 4|0);
 HEAP32[$31>>2] = $30;
 $32 = (($17) + ($30)|0);
 HEAP8[$32>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (-17 - ($__old_cap))|0;
 $1 = ($0>>>0)<($__delta_cap>>>0);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = HEAP8[$this>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = (($this) + 1|0);
  $19 = $7;
 } else {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $19 = $6;
 }
 $8 = ($__old_cap>>>0)<(2147483623);
 if ($8) {
  $9 = (($__delta_cap) + ($__old_cap))|0;
  $10 = $__old_cap << 1;
  $11 = ($9>>>0)<($10>>>0);
  $12 = $11 ? $10 : $9;
  $13 = ($12>>>0)<(11);
  if ($13) {
   $16 = 11;
  } else {
   $14 = (($12) + 16)|0;
   $15 = $14 & -16;
   $16 = $15;
  }
 } else {
  $16 = -17;
 }
 $17 = (__Znwj($16)|0);
 $18 = ($__n_copy|0)==(0);
 if (!($18)) {
  _memcpy(($17|0),($19|0),($__n_copy|0))|0;
 }
 $20 = (($__old_sz) - ($__n_del))|0;
 $21 = ($20|0)==($__n_copy|0);
 if (!($21)) {
  $22 = (($20) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $23 = (($17) + ($$sum)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $24 = (($19) + ($$sum1)|0);
  _memcpy(($23|0),($24|0),($22|0))|0;
 }
 $25 = ($__old_cap|0)==(10);
 if ($25) {
  $26 = (($this) + 8|0);
  HEAP32[$26>>2] = $17;
  $27 = $16 | 1;
  HEAP32[$this>>2] = $27;
  STACKTOP = sp;return;
 }
 __ZdlPv($19);
 $26 = (($this) + 8|0);
 HEAP32[$26>>2] = $17;
 $27 = $16 | 1;
 HEAP32[$this>>2] = $27;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcjj($this,$__s,$__sz,$__reserve) {
 $this = $this|0;
 $__s = $__s|0;
 $__sz = $__sz|0;
 $__reserve = $__reserve|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__reserve>>>0)>(4294967279);
 if ($0) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $1 = ($__reserve>>>0)<(11);
 if ($1) {
  $2 = $__sz << 1;
  $3 = $2&255;
  HEAP8[$this>>0] = $3;
  $4 = (($this) + 1|0);
  $__p$0 = $4;
 } else {
  $5 = (($__reserve) + 16)|0;
  $6 = $5 & -16;
  $7 = (__Znwj($6)|0);
  $8 = (($this) + 8|0);
  HEAP32[$8>>2] = $7;
  $9 = $6 | 1;
  HEAP32[$this>>2] = $9;
  $10 = (($this) + 4|0);
  HEAP32[$10>>2] = $__sz;
  $__p$0 = $7;
 }
 _memcpy(($__p$0|0),($__s|0),($__sz|0))|0;
 $11 = (($__p$0) + ($__sz)|0);
 HEAP8[$11>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj($this,$__s,$__sz) {
 $this = $this|0;
 $__s = $__s|0;
 $__sz = $__sz|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__sz>>>0)>(1073741807);
 if ($0) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $1 = ($__sz>>>0)<(2);
 if ($1) {
  $2 = $__sz << 1;
  $3 = $2&255;
  HEAP8[$this>>0] = $3;
  $4 = (($this) + 4|0);
  $__p$0 = $4;
 } else {
  $5 = (($__sz) + 4)|0;
  $6 = $5 & -4;
  $7 = $6 << 2;
  $8 = (__Znwj($7)|0);
  $9 = (($this) + 8|0);
  HEAP32[$9>>2] = $8;
  $10 = $6 | 1;
  HEAP32[$this>>2] = $10;
  $11 = (($this) + 4|0);
  HEAP32[$11>>2] = $__sz;
  $__p$0 = $8;
 }
 (_wmemcpy($__p$0,$__s,$__sz)|0);
 $12 = (($__p$0) + ($__sz<<2)|0);
 HEAP32[$12>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEjw($this,$__n,$__c) {
 $this = $this|0;
 $__n = $__n|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n>>>0)>(1073741807);
 if ($0) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $1 = ($__n>>>0)<(2);
 if ($1) {
  $2 = $__n << 1;
  $3 = $2&255;
  HEAP8[$this>>0] = $3;
  $4 = (($this) + 4|0);
  $__p$0 = $4;
 } else {
  $5 = (($__n) + 4)|0;
  $6 = $5 & -4;
  $7 = $6 << 2;
  $8 = (__Znwj($7)|0);
  $9 = (($this) + 8|0);
  HEAP32[$9>>2] = $8;
  $10 = $6 | 1;
  HEAP32[$this>>2] = $10;
  $11 = (($this) + 4|0);
  HEAP32[$11>>2] = $__n;
  $__p$0 = $8;
 }
 (_wmemset($__p$0,$__c,$__n)|0);
 $12 = (($__p$0) + ($__n<<2)|0);
 HEAP32[$12>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$lcssa = 0, $__p$0$ph = 0, $__p$01 = 0, $scevgep = 0, $scevgep5 = 0, $uglygep = 0, $uglygep4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__first;
 $1 = $__last;
 $2 = (($1) - ($0))|0;
 $3 = $2 >> 2;
 $4 = ($3>>>0)>(1073741807);
 if ($4) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $5 = ($3>>>0)<(2);
 if ($5) {
  $6 = $2 >>> 1;
  $7 = $6&255;
  HEAP8[$this>>0] = $7;
  $8 = (($this) + 4|0);
  $__p$0$ph = $8;
 } else {
  $9 = (($3) + 4)|0;
  $10 = $9 & -4;
  $11 = $10 << 2;
  $12 = (__Znwj($11)|0);
  $13 = (($this) + 8|0);
  HEAP32[$13>>2] = $12;
  $14 = $10 | 1;
  HEAP32[$this>>2] = $14;
  $15 = (($this) + 4|0);
  HEAP32[$15>>2] = $3;
  $__p$0$ph = $12;
 }
 $16 = ($__first|0)==($__last|0);
 if ($16) {
  $__p$0$lcssa = $__p$0$ph;
  HEAP32[$__p$0$lcssa>>2] = 0;
  STACKTOP = sp;return;
 }
 $scevgep = (($__last) + -4|0);
 $17 = (0 - ($0))|0;
 $uglygep = (($scevgep) + ($17)|0);
 $uglygep4 = $uglygep;
 $18 = $uglygep4 >>> 2;
 $19 = (($18) + 1)|0;
 $$02 = $__first;$__p$01 = $__p$0$ph;
 while(1) {
  $20 = HEAP32[$$02>>2]|0;
  HEAP32[$__p$01>>2] = $20;
  $21 = (($$02) + 4|0);
  $22 = (($__p$01) + 4|0);
  $23 = ($21|0)==($__last|0);
  if ($23) {
   break;
  } else {
   $$02 = $21;$__p$01 = $22;
  }
 }
 $scevgep5 = (($__p$0$ph) + ($19<<2)|0);
 $__p$0$lcssa = $scevgep5;
 HEAP32[$__p$0$lcssa>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __ZdlPv($4);
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw($this,$__s) {
 $this = $this|0;
 $__s = $__s|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_wcslen($__s)|0);
 $1 = (__ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwj($this,$__s,$0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwj($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = 1;$9 = $0;
 } else {
  $3 = HEAP32[$this>>2]|0;
  $4 = $3 & -2;
  $phitmp$i = (($4) + -1)|0;
  $5 = $3&255;
  $7 = $phitmp$i;$9 = $5;
 }
 $6 = ($7>>>0)<($__n>>>0);
 $8 = $9 & 1;
 $10 = ($8<<24>>24)==(0);
 if ($6) {
  if ($10) {
   $24 = $9&255;
   $25 = $24 >>> 1;
   $27 = $25;
  } else {
   $22 = (($this) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $27 = $23;
  }
  $26 = (($__n) - ($7))|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEjjjjjjPKw($this,$7,$26,$27,0,$27,$__n,$__s);
  STACKTOP = sp;return ($this|0);
 }
 if ($10) {
  $13 = (($this) + 4|0);
  $14 = $13;
 } else {
  $11 = (($this) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  $14 = $12;
 }
 (_wmemmove($14,$__s,$__n)|0);
 $15 = (($14) + ($__n<<2)|0);
 HEAP32[$15>>2] = 0;
 $16 = HEAP8[$this>>0]|0;
 $17 = $16 & 1;
 $18 = ($17<<24>>24)==(0);
 if ($18) {
  $20 = $__n << 1;
  $21 = $20&255;
  HEAP8[$this>>0] = $21;
  STACKTOP = sp;return ($this|0);
 } else {
  $19 = (($this) + 4|0);
  HEAP32[$19>>2] = $__n;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj($this,$__res_arg) {
 $this = $this|0;
 $__res_arg = $__res_arg|0;
 var $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_data$1 = 0, $__now_long$0$off0 = 0, $__p$0 = 0, $__was_long$0$off0 = 0;
 var $phitmp$i = 0, $phitmp$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__res_arg>>>0)>(1073741807);
 if ($0) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $22 = 1;$8 = $1;
 } else {
  $4 = HEAP32[$this>>2]|0;
  $5 = $4 & -2;
  $phitmp$i = (($5) + -1)|0;
  $6 = $4&255;
  $22 = $phitmp$i;$8 = $6;
 }
 $7 = $8 & 1;
 $9 = ($7<<24>>24)==(0);
 if ($9) {
  $12 = $8&255;
  $13 = $12 >>> 1;
  $15 = $13;
 } else {
  $10 = (($this) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  $15 = $11;
 }
 $14 = ($15>>>0)>($__res_arg>>>0);
 $16 = $14 ? $15 : $__res_arg;
 $17 = ($16>>>0)<(2);
 if ($17) {
  $21 = 1;
 } else {
  $18 = (($16) + 4)|0;
  $19 = $18 & -4;
  $phitmp$i2 = (($19) + -1)|0;
  $21 = $phitmp$i2;
 }
 $20 = ($21|0)==($22|0);
 if ($20) {
  STACKTOP = sp;return;
 }
 $23 = ($21|0)==(1);
 do {
  if ($23) {
   $24 = (($this) + 4|0);
   $25 = (($this) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $__new_data$1 = $24;$__now_long$0$off0 = 0;$__p$0 = $26;$__was_long$0$off0 = 1;
  } else {
   $27 = ($21>>>0)>($22>>>0);
   $28 = $21 << 2;
   $29 = (($28) + 4)|0;
   if ($27) {
    $30 = (__Znwj($29)|0);
    $$sink = $30;
   } else {
    __THREW__ = 0;
    $31 = (invoke_ii(2988,($29|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     $34 = ___cxa_find_matching_catch(0|0)|0;
     $35 = tempRet0;
     (___cxa_begin_catch(($34|0))|0);
     ___cxa_end_catch();
     STACKTOP = sp;return;
    } else {
     $$sink = $31;
    }
   }
   $36 = $8 & 1;
   $37 = ($36<<24>>24)==(0);
   if ($37) {
    $40 = (($this) + 4|0);
    $__new_data$1 = $$sink;$__now_long$0$off0 = 1;$__p$0 = $40;$__was_long$0$off0 = 0;
    break;
   } else {
    $38 = (($this) + 8|0);
    $39 = HEAP32[$38>>2]|0;
    $__new_data$1 = $$sink;$__now_long$0$off0 = 1;$__p$0 = $39;$__was_long$0$off0 = 1;
    break;
   }
  }
 } while(0);
 $41 = $8 & 1;
 $42 = ($41<<24>>24)==(0);
 if ($42) {
  $45 = $8&255;
  $46 = $45 >>> 1;
  $48 = $46;
 } else {
  $43 = (($this) + 4|0);
  $44 = HEAP32[$43>>2]|0;
  $48 = $44;
 }
 $47 = (($48) + 1)|0;
 (_wmemcpy($__new_data$1,$__p$0,$47)|0);
 if ($__was_long$0$off0) {
  __ZdlPv($__p$0);
 }
 if ($__now_long$0$off0) {
  $49 = (($21) + 1)|0;
  $50 = $49 | 1;
  HEAP32[$this>>2] = $50;
  $51 = (($this) + 4|0);
  HEAP32[$51>>2] = $15;
  $52 = (($this) + 8|0);
  HEAP32[$52>>2] = $__new_data$1;
  STACKTOP = sp;return;
 } else {
  $53 = $15 << 1;
  $54 = $53&255;
  HEAP8[$this>>0] = $54;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__cap$0 = 0, $__p$0 = 0, $__p$0$sum$pre = 0, $__p$0$sum$pre$phiZZZ2D = 0, $__sz$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)!=(0);
 if ($2) {
  $5 = HEAP32[$this>>2]|0;
  $6 = $5 & -2;
  $7 = (($6) + -1)|0;
  $8 = (($this) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $__cap$0 = $7;$__sz$0 = $9;
 } else {
  $3 = $0&255;
  $4 = $3 >>> 1;
  $__cap$0 = 1;$__sz$0 = $4;
 }
 $10 = ($__sz$0|0)==($__cap$0|0);
 if ($10) {
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj($this,$__cap$0,1,$__cap$0,$__cap$0,0,0);
  $11 = HEAP8[$this>>0]|0;
  $12 = $11 & 1;
  $13 = ($12<<24>>24)==(0);
  if ($13) {
   label = 7;
  } else {
   label = 8;
  }
 } else {
  if ($2) {
   label = 8;
  } else {
   label = 7;
  }
 }
 if ((label|0) == 7) {
  $14 = (($this) + 4|0);
  $15 = $__sz$0 << 1;
  $16 = (($15) + 2)|0;
  $17 = $16&255;
  HEAP8[$this>>0] = $17;
  $__p$0$sum$pre = (($__sz$0) + 1)|0;
  $$pn = $14;$__p$0$sum$pre$phiZZZ2D = $__p$0$sum$pre;
  $__p$0 = (($$pn) + ($__sz$0<<2)|0);
  HEAP32[$__p$0>>2] = $__c;
  $22 = (($$pn) + ($__p$0$sum$pre$phiZZZ2D<<2)|0);
  HEAP32[$22>>2] = 0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $18 = (($this) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = (($__sz$0) + 1)|0;
  $21 = (($this) + 4|0);
  HEAP32[$21>>2] = $20;
  $$pn = $19;$__p$0$sum$pre$phiZZZ2D = $20;
  $__p$0 = (($$pn) + ($__sz$0<<2)|0);
  HEAP32[$__p$0>>2] = $__c;
  $22 = (($$pn) + ($__p$0$sum$pre$phiZZZ2D<<2)|0);
  HEAP32[$22>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEjjjjjjPKw($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add,$__p_new_stuff) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 $__p_new_stuff = $__p_new_stuff|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1073741806 - ($__old_cap))|0;
 $1 = ($0>>>0)<($__delta_cap>>>0);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = HEAP8[$this>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = (($this) + 4|0);
  $20 = $7;
 } else {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $20 = $6;
 }
 $8 = ($__old_cap>>>0)<(536870887);
 if ($8) {
  $9 = (($__delta_cap) + ($__old_cap))|0;
  $10 = $__old_cap << 1;
  $11 = ($9>>>0)<($10>>>0);
  $12 = $11 ? $10 : $9;
  $13 = ($12>>>0)<(2);
  if ($13) {
   $17 = 2;
  } else {
   $14 = (($12) + 4)|0;
   $15 = $14 & -4;
   $17 = $15;
  }
 } else {
  $17 = 1073741807;
 }
 $16 = $17 << 2;
 $18 = (__Znwj($16)|0);
 $19 = ($__n_copy|0)==(0);
 if (!($19)) {
  (_wmemcpy($18,$20,$__n_copy)|0);
 }
 $21 = ($__n_add|0)==(0);
 if (!($21)) {
  $22 = (($18) + ($__n_copy<<2)|0);
  (_wmemcpy($22,$__p_new_stuff,$__n_add)|0);
 }
 $23 = (($__old_sz) - ($__n_del))|0;
 $24 = ($23|0)==($__n_copy|0);
 if (!($24)) {
  $25 = (($23) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $26 = (($18) + ($$sum<<2)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $27 = (($20) + ($$sum1<<2)|0);
  (_wmemcpy($26,$27,$25)|0);
 }
 $28 = ($__old_cap|0)==(1);
 if ($28) {
  $29 = (($this) + 8|0);
  HEAP32[$29>>2] = $18;
  $30 = $17 | 1;
  HEAP32[$this>>2] = $30;
  $31 = (($23) + ($__n_add))|0;
  $32 = (($this) + 4|0);
  HEAP32[$32>>2] = $31;
  $33 = (($18) + ($31<<2)|0);
  HEAP32[$33>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZdlPv($20);
 $29 = (($this) + 8|0);
 HEAP32[$29>>2] = $18;
 $30 = $17 | 1;
 HEAP32[$this>>2] = $30;
 $31 = (($23) + ($__n_add))|0;
 $32 = (($this) + 4|0);
 HEAP32[$32>>2] = $31;
 $33 = (($18) + ($31<<2)|0);
 HEAP32[$33>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj($this,$__old_cap,$__delta_cap,$__old_sz,$__n_copy,$__n_del,$__n_add) {
 $this = $this|0;
 $__old_cap = $__old_cap|0;
 $__delta_cap = $__delta_cap|0;
 $__old_sz = $__old_sz|0;
 $__n_copy = $__n_copy|0;
 $__n_del = $__n_del|0;
 $__n_add = $__n_add|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (1073741807 - ($__old_cap))|0;
 $1 = ($0>>>0)<($__delta_cap>>>0);
 if ($1) {
  __ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $2 = HEAP8[$this>>0]|0;
 $3 = $2 & 1;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $7 = (($this) + 4|0);
  $20 = $7;
 } else {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $20 = $6;
 }
 $8 = ($__old_cap>>>0)<(536870887);
 if ($8) {
  $9 = (($__delta_cap) + ($__old_cap))|0;
  $10 = $__old_cap << 1;
  $11 = ($9>>>0)<($10>>>0);
  $12 = $11 ? $10 : $9;
  $13 = ($12>>>0)<(2);
  if ($13) {
   $17 = 2;
  } else {
   $14 = (($12) + 4)|0;
   $15 = $14 & -4;
   $17 = $15;
  }
 } else {
  $17 = 1073741807;
 }
 $16 = $17 << 2;
 $18 = (__Znwj($16)|0);
 $19 = ($__n_copy|0)==(0);
 if (!($19)) {
  (_wmemcpy($18,$20,$__n_copy)|0);
 }
 $21 = (($__old_sz) - ($__n_del))|0;
 $22 = ($21|0)==($__n_copy|0);
 if (!($22)) {
  $23 = (($21) - ($__n_copy))|0;
  $$sum = (($__n_add) + ($__n_copy))|0;
  $24 = (($18) + ($$sum<<2)|0);
  $$sum1 = (($__n_del) + ($__n_copy))|0;
  $25 = (($20) + ($$sum1<<2)|0);
  (_wmemcpy($24,$25,$23)|0);
 }
 $26 = ($__old_cap|0)==(1);
 if ($26) {
  $27 = (($this) + 8|0);
  HEAP32[$27>>2] = $18;
  $28 = $17 | 1;
  HEAP32[$this>>2] = $28;
  STACKTOP = sp;return;
 }
 __ZdlPv($20);
 $27 = (($this) + 8|0);
 HEAP32[$27>>2] = $18;
 $28 = $17 | 1;
 HEAP32[$this>>2] = $28;
 STACKTOP = sp;return;
}
function __ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_($agg$result,$__lhs,$__rhs) {
 $agg$result = $agg$result|0;
 $__lhs = $__lhs|0;
 $__rhs = $__rhs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $0 = (_strlen(($__lhs|0))|0);
 $1 = HEAP8[$__rhs>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = $1&255;
  $7 = $6 >>> 1;
  $9 = $7;
 } else {
  $4 = (($__rhs) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $9 = $5;
 }
 $8 = (($9) + ($0))|0;
 __THREW__ = 0;
 invoke_viiii(477,($agg$result|0),($__lhs|0),($0|0),($8|0));
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if (!($11)) {
  $12 = HEAP8[$__rhs>>0]|0;
  $13 = $12 & 1;
  $14 = ($13<<24>>24)==(0);
  if ($14) {
   $17 = (($__rhs) + 1|0);
   $18 = $17;
  } else {
   $15 = (($__rhs) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $18 = $16;
  }
  __THREW__ = 0;
  (invoke_iiii(1480,($agg$result|0),($18|0),($9|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if (!($20)) {
   STACKTOP = sp;return;
  }
 }
 $21 = ___cxa_find_matching_catch()|0;
 $22 = tempRet0;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev($agg$result);
 ___resumeException($21|0);
 // unreachable;
}
function __ZNSt3__18ios_base5clearEj($this,$state) {
 $this = $this|0;
 $state = $state|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = $state | 1;
  $6 = (($this) + 16|0);
  HEAP32[$6>>2] = $5;
 } else {
  $4 = (($this) + 16|0);
  HEAP32[$4>>2] = $state;
 }
 $7 = $3&1;
 $8 = $7 | $state;
 $9 = (($this) + 20|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $8 & $10;
 $12 = ($11|0)==(0);
 if ($12) {
  STACKTOP = sp;return;
 }
 $13 = (___cxa_allocate_exception(16)|0);
 (__ZNSt3__117iostream_categoryEv()|0);
 $14 = $0;
 $15 = $14;
 HEAP32[$15>>2] = 1;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = (3090912);
 __THREW__ = 0;
 invoke_viii(2127,($13|0),(3090968|0),($0|0));
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  ___cxa_free_exception(($13|0));
  ___resumeException($20|0);
  // unreachable;
 } else {
  ___cxa_throw(($13|0),(3091016|0),(3215|0));
  // unreachable;
 }
}
function __ZNSt3__18ios_baseD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090952 + 8|0));
 __THREW__ = 0;
 invoke_vii(3506,($this|0),0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if ($1) {
  $11 = ___cxa_find_matching_catch(0|0)|0;
  $12 = tempRet0;
  ___clang_call_terminate($11);
  // unreachable;
 } else {
  $2 = (($this) + 28|0);
  __ZNSt3__16localeD2Ev($2);
  $3 = (($this) + 32|0);
  $4 = HEAP32[$3>>2]|0;
  _free($4);
  $5 = (($this) + 36|0);
  $6 = HEAP32[$5>>2]|0;
  _free($6);
  $7 = (($this) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  _free($8);
  $9 = (($this) + 60|0);
  $10 = HEAP32[$9>>2]|0;
  _free($10);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__18ios_base16__call_callbacksENS0_5eventE($this,$ev) {
 $this = $this|0;
 $ev = $ev|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 32|0);
 $4 = (($this) + 36|0);
 $i$01 = $1;
 while(1) {
  $5 = (($i$01) + -1)|0;
  $6 = HEAP32[$3>>2]|0;
  $7 = (($6) + ($5<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$4>>2]|0;
  $10 = (($9) + ($5<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  FUNCTION_TABLE_viii[$8 & 4095]($ev,$this,$11);
  $12 = ($5|0)==(0);
  if ($12) {
   break;
  } else {
   $i$01 = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__18ios_base6getlocEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 __ZNSt3__16localeC2ERKS0_($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__18ios_base4initEPv($this,$sb) {
 $this = $this|0;
 $sb = $sb|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $not$ = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 HEAP32[$0>>2] = $sb;
 $not$ = ($sb|0)==(0|0);
 $1 = $not$&1;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 20|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 4|0);
 HEAP32[$4>>2] = 4098;
 $5 = (($this) + 12|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 8|0);
 HEAP32[$6>>2] = 6;
 $7 = (($this) + 32|0);
 $8 = (($this) + 28|0);
 dest=$7+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 __ZNSt3__16localeC2Ev($8);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090568 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090568 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090568 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEEC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090568 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeC2Ev($0);
 $1 = (($this) + 8|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE6setbufEPci($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj($agg$result,$this,$0,$1,$2,$3) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $agg$result;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($agg$result) + 8|0);
 $9 = $8;
 $10 = $9;
 HEAP32[$10>>2] = -1;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = -1;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj($agg$result,$this,$0,$1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $agg$result;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($agg$result) + 8|0);
 $7 = $6;
 $8 = $7;
 HEAP32[$8>>2] = -1;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = -1;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE4syncEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE9showmanycEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPci($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$0$lcssa = 0, $__i$02 = 0;
 var $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)>(0);
 if (!($0)) {
  $__i$0$lcssa = 0;
  STACKTOP = sp;return ($__i$0$lcssa|0);
 }
 $1 = (($this) + 12|0);
 $2 = (($this) + 16|0);
 $$01 = $__s;$__i$02 = 0;
 while(1) {
  $3 = HEAP32[$1>>2]|0;
  $4 = HEAP32[$2>>2]|0;
  $5 = ($3>>>0)<($4>>>0);
  if ($5) {
   $6 = (($3) + 1|0);
   HEAP32[$1>>2] = $6;
   $7 = HEAP8[$3>>0]|0;
   $storemerge = $7;
  } else {
   $8 = HEAP32[$this>>2]|0;
   $9 = (($8) + 40|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
   $12 = ($11|0)==(-1);
   if ($12) {
    $__i$0$lcssa = $__i$02;
    label = 8;
    break;
   }
   $13 = $11&255;
   $storemerge = $13;
  }
  HEAP8[$$01>>0] = $storemerge;
  $14 = (($__i$02) + 1)|0;
  $15 = (($$01) + 1|0);
  $16 = ($14|0)<($__n|0);
  if ($16) {
   $$01 = $15;$__i$02 = $14;
  } else {
   $__i$0$lcssa = $14;
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($__i$0$lcssa|0);
 }
 return 0|0;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE9underflowEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE5uflowEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = ($3|0)==(-1);
 if ($4) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1|0);
 HEAP32[$5>>2] = $7;
 $8 = HEAP8[$6>>0]|0;
 $9 = $8&255;
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKci($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$0$lcssa = 0;
 var $__i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)>(0);
 if (!($0)) {
  $__i$0$lcssa = 0;
  STACKTOP = sp;return ($__i$0$lcssa|0);
 }
 $1 = (($this) + 24|0);
 $2 = (($this) + 28|0);
 $$02 = $__s;$__i$01 = 0;
 while(1) {
  $3 = HEAP32[$1>>2]|0;
  $4 = HEAP32[$2>>2]|0;
  $5 = ($3>>>0)<($4>>>0);
  if ($5) {
   $6 = HEAP8[$$02>>0]|0;
   $7 = (($3) + 1|0);
   HEAP32[$1>>2] = $7;
   HEAP8[$3>>0] = $6;
  } else {
   $8 = HEAP32[$this>>2]|0;
   $9 = (($8) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP8[$$02>>0]|0;
   $12 = $11&255;
   $13 = (FUNCTION_TABLE_iii[$10 & 4095]($this,$12)|0);
   $14 = ($13|0)==(-1);
   if ($14) {
    $__i$0$lcssa = $__i$01;
    label = 7;
    break;
   }
  }
  $15 = (($$02) + 1|0);
  $16 = (($__i$01) + 1)|0;
  $17 = ($16|0)<($__n|0);
  if ($17) {
   $$02 = $15;$__i$01 = $16;
  } else {
   $__i$0$lcssa = $16;
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($__i$0$lcssa|0);
 }
 return 0|0;
}
function __ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE8overflowEi($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090632 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090632 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090632 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEEC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3090632 + 8|0));
 $0 = (($this) + 4|0);
 __ZNSt3__16localeC2Ev($0);
 $1 = (($this) + 8|0);
 ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;HEAP32[$1+16>>2]=0|0;HEAP32[$1+20>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE6setbufEPwi($this,$0,$1) {
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj($agg$result,$this,$0,$1,$2,$3) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = $agg$result;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($agg$result) + 8|0);
 $9 = $8;
 $10 = $9;
 HEAP32[$10>>2] = -1;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = -1;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj($agg$result,$this,$0,$1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = $agg$result;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($agg$result) + 8|0);
 $7 = $6;
 $8 = $7;
 HEAP32[$8>>2] = -1;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = -1;
 STACKTOP = sp;return;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE4syncEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE9showmanycEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwi($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$0$lcssa = 0, $__i$02 = 0, $storemerge = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)>(0);
 if (!($0)) {
  $__i$0$lcssa = 0;
  STACKTOP = sp;return ($__i$0$lcssa|0);
 }
 $1 = (($this) + 12|0);
 $2 = (($this) + 16|0);
 $$01 = $__s;$__i$02 = 0;
 while(1) {
  $3 = HEAP32[$1>>2]|0;
  $4 = HEAP32[$2>>2]|0;
  $5 = ($3>>>0)<($4>>>0);
  if ($5) {
   $6 = (($3) + 4|0);
   HEAP32[$1>>2] = $6;
   $7 = HEAP32[$3>>2]|0;
   $storemerge = $7;
  } else {
   $8 = HEAP32[$this>>2]|0;
   $9 = (($8) + 40|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (FUNCTION_TABLE_ii[$10 & 4095]($this)|0);
   $12 = ($11|0)==(-1);
   if ($12) {
    $__i$0$lcssa = $__i$02;
    label = 8;
    break;
   } else {
    $storemerge = $11;
   }
  }
  HEAP32[$$01>>2] = $storemerge;
  $13 = (($__i$02) + 1)|0;
  $14 = ($13|0)<($__n|0);
  if (!($14)) {
   $__i$0$lcssa = $13;
   label = 8;
   break;
  }
  $15 = (($$01) + 4|0);
  $$01 = $15;$__i$02 = $13;
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($__i$0$lcssa|0);
 }
 return 0|0;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE9underflowEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE5uflowEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 36|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 4095]($this)|0);
 $4 = ($3|0)==(-1);
 if ($4) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 4|0);
 HEAP32[$5>>2] = $7;
 $8 = HEAP32[$6>>2]|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwi($this,$__s,$__n) {
 $this = $this|0;
 $__s = $__s|0;
 $__n = $__n|0;
 var $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$0$lcssa = 0, $__i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n|0)>(0);
 if (!($0)) {
  $__i$0$lcssa = 0;
  STACKTOP = sp;return ($__i$0$lcssa|0);
 }
 $1 = (($this) + 24|0);
 $2 = (($this) + 28|0);
 $$02 = $__s;$__i$01 = 0;
 while(1) {
  $3 = HEAP32[$1>>2]|0;
  $4 = HEAP32[$2>>2]|0;
  $5 = ($3>>>0)<($4>>>0);
  if ($5) {
   $6 = HEAP32[$$02>>2]|0;
   $7 = (($3) + 4|0);
   HEAP32[$1>>2] = $7;
   HEAP32[$3>>2] = $6;
  } else {
   $8 = HEAP32[$this>>2]|0;
   $9 = (($8) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = HEAP32[$$02>>2]|0;
   $12 = (FUNCTION_TABLE_iii[$10 & 4095]($this,$11)|0);
   $13 = ($12|0)==(-1);
   if ($13) {
    $__i$0$lcssa = $__i$01;
    label = 8;
    break;
   }
  }
  $14 = (($__i$01) + 1)|0;
  $15 = ($14|0)<($__n|0);
  if (!($15)) {
   $__i$0$lcssa = $14;
   label = 8;
   break;
  }
  $16 = (($$02) + 4|0);
  $$02 = $16;$__i$01 = $14;
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($__i$0$lcssa|0);
 }
 return 0|0;
}
function __ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE8overflowEj($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return -1;
}
function __ZNSt3__113basic_istreamIcNS_11char_traitsIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNSt3__18ios_baseD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__113basic_istreamIcNS_11char_traitsIcEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNSt3__18ios_baseD2Ev($0);
 STACKTOP = sp;return;
}
function __ZTv0_n12_NSt3__113basic_istreamIcNS_11char_traitsIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2)|0);
 __ZNSt3__113basic_istreamIcNS_11char_traitsIcEEED0Ev($3);
 STACKTOP = sp;return;
}
function __ZTv0_n12_NSt3__113basic_istreamIcNS_11char_traitsIcEEED1Ev($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $$sum = (($2) + 8)|0;
 $3 = (($this) + ($$sum)|0);
 __ZNSt3__18ios_baseD2Ev($3);
 STACKTOP = sp;return;
}
function __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE5flushEv($this) {
 $this = $this|0;
 var $$0 = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__s = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__s = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $$sum = (($2) + 24)|0;
 $3 = (($this) + ($$sum)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return ($this|0);
 }
 __THREW__ = 0;
 invoke_vii(3507,($__s|0),($this|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 L4: do {
  if ($7) {
   $31 = ___cxa_find_matching_catch(0|0)|0;
   $32 = tempRet0;
   $$0 = $31;
  } else {
   $8 = HEAP8[$__s>>0]|0;
   $9 = ($8<<24>>24)==(0);
   do {
    if (!($9)) {
     $10 = HEAP32[$this>>2]|0;
     $11 = (($10) + -12|0);
     $12 = HEAP32[$11>>2]|0;
     $$sum1 = (($12) + 24)|0;
     $13 = (($this) + ($$sum1)|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = HEAP32[$14>>2]|0;
     $16 = (($15) + 24|0);
     $17 = HEAP32[$16>>2]|0;
     __THREW__ = 0;
     $18 = (invoke_ii($17|0,($14|0))|0);
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if (!($20)) {
      $21 = ($18|0)==(-1);
      if (!($21)) {
       break;
      }
      $22 = HEAP32[$this>>2]|0;
      $23 = (($22) + -12|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = (($this) + ($24)|0);
      $$sum2 = (($24) + 16)|0;
      $26 = (($this) + ($$sum2)|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = $27 | 1;
      __THREW__ = 0;
      invoke_vii(2476,($25|0),($28|0));
      $29 = __THREW__; __THREW__ = 0;
      $30 = $29&1;
      if (!($30)) {
       break;
      }
     }
     $33 = ___cxa_find_matching_catch(0|0)|0;
     $34 = tempRet0;
     __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($__s);
     $$0 = $33;
     break L4;
    }
   } while(0);
   __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($__s);
   STACKTOP = sp;return ($this|0);
  }
 } while(0);
 (___cxa_begin_catch(($$0|0))|0);
 $35 = HEAP32[$this>>2]|0;
 $36 = (($35) + -12|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($this) + ($37)|0);
 __THREW__ = 0;
 invoke_vi(3301,($38|0));
 $39 = __THREW__; __THREW__ = 0;
 $40 = $39&1;
 if (!($40)) {
  ___cxa_end_catch();
  STACKTOP = sp;return ($this|0);
 }
 $41 = ___cxa_find_matching_catch()|0;
 $42 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $43 = __THREW__; __THREW__ = 0;
 $44 = $43&1;
 if ($44) {
  $45 = ___cxa_find_matching_catch(0|0)|0;
  $46 = tempRet0;
  ___clang_call_terminate($45);
  // unreachable;
 } else {
  ___resumeException($41|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__18ios_base33__set_badbit_and_consider_rethrowEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 | 1;
 HEAP32[$0>>2] = $2;
 $3 = (($this) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 1;
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 } else {
  ___cxa_rethrow();
  // unreachable;
 }
}
function __ZNSt3__113basic_istreamIwNS_11char_traitsIwEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNSt3__18ios_baseD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__113basic_istreamIwNS_11char_traitsIwEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNSt3__18ios_baseD2Ev($0);
 STACKTOP = sp;return;
}
function __ZTv0_n12_NSt3__113basic_istreamIwNS_11char_traitsIwEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2)|0);
 __ZNSt3__113basic_istreamIwNS_11char_traitsIwEEED0Ev($3);
 STACKTOP = sp;return;
}
function __ZTv0_n12_NSt3__113basic_istreamIwNS_11char_traitsIwEEED1Ev($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $$sum = (($2) + 8)|0;
 $3 = (($this) + ($$sum)|0);
 __ZNSt3__18ios_baseD2Ev($3);
 STACKTOP = sp;return;
}
function __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 __ZNSt3__18ios_baseD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 __ZNSt3__18ios_baseD2Ev($0);
 STACKTOP = sp;return;
}
function __ZTv0_n12_NSt3__113basic_ostreamIcNS_11char_traitsIcEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2)|0);
 __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEED0Ev($3);
 STACKTOP = sp;return;
}
function __ZTv0_n12_NSt3__113basic_ostreamIcNS_11char_traitsIcEEED1Ev($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $$sum = (($2) + 4)|0;
 $3 = (($this) + ($$sum)|0);
 __ZNSt3__18ios_baseD2Ev($3);
 STACKTOP = sp;return;
}
function __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_($this,$__os) {
 $this = $this|0;
 $__os = $__os|0;
 var $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$this>>0] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $__os;
 $1 = HEAP32[$__os>>2]|0;
 $2 = (($1) + -12|0);
 $3 = HEAP32[$2>>2]|0;
 $$sum = (($3) + 16)|0;
 $4 = (($__os) + ($$sum)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $$sum1 = (($3) + 72)|0;
 $7 = (($__os) + ($$sum1)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  (__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE5flushEv($8)|0);
 }
 HEAP8[$this>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($this) {
 $this = $this|0;
 var $$sum = 0, $$sum1 = 0, $$sum2 = 0, $$sum3 = 0, $$sum4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + -12|0);
 $4 = HEAP32[$3>>2]|0;
 $$sum = (($4) + 24)|0;
 $5 = (($1) + ($$sum)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $$sum1 = (($4) + 16)|0;
 $8 = (($1) + ($$sum1)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $$sum2 = (($4) + 4)|0;
 $11 = (($1) + ($$sum2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 & 8192;
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = (__ZSt18uncaught_exceptionv()|0);
 if ($15) {
  STACKTOP = sp;return;
 }
 $16 = HEAP32[$0>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + -12|0);
 $19 = HEAP32[$18>>2]|0;
 $$sum3 = (($19) + 24)|0;
 $20 = (($16) + ($$sum3)|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 __THREW__ = 0;
 $25 = (invoke_ii($24|0,($21|0))|0);
 $26 = __THREW__; __THREW__ = 0;
 $27 = $26&1;
 if (!($27)) {
  $28 = ($25|0)==(-1);
  if (!($28)) {
   STACKTOP = sp;return;
  }
  $29 = HEAP32[$0>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + -12|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($29) + ($32)|0);
  $$sum4 = (($32) + 16)|0;
  $34 = (($29) + ($$sum4)|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = $35 | 1;
  __THREW__ = 0;
  invoke_vii(2476,($33|0),($36|0));
  $37 = __THREW__; __THREW__ = 0;
  $38 = $37&1;
  if (!($38)) {
   STACKTOP = sp;return;
  }
 }
 $39 = ___cxa_find_matching_catch(0|0)|0;
 $40 = tempRet0;
 (___cxa_begin_catch(($39|0))|0);
 __THREW__ = 0;
 invoke_v(66);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $43 = ___cxa_find_matching_catch(0|0)|0;
  $44 = tempRet0;
  ___clang_call_terminate($43);
  // unreachable;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEt($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0 = 0, $$1 = 0, $$byval_copy = 0, $$pre$phi7Z2D = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum$i$i = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $8 = 0, $9 = 0, $__s = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__s = sp + 8|0;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 __THREW__ = 0;
 invoke_vii(3507,($__s|0),($this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $55 = ___cxa_find_matching_catch(0|0)|0;
   $56 = tempRet0;
   $$1 = $55;$$pre$phi7Z2D = $this;$$pre$phiZ2D = $this;
  } else {
   $5 = HEAP8[$__s>>0]|0;
   $6 = ($5<<24>>24)==(0);
   do {
    if (!($6)) {
     $7 = HEAP32[$this>>2]|0;
     $8 = (($7) + -12|0);
     $9 = HEAP32[$8>>2]|0;
     $$sum = (($9) + 28)|0;
     $10 = (($this) + ($$sum)|0);
     __ZNSt3__16localeC2ERKS0_($1,$10);
     __THREW__ = 0;
     $11 = (invoke_iii(2228,($1|0),(3092024|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      $59 = ___cxa_find_matching_catch(0|0)|0;
      $60 = tempRet0;
      __ZNSt3__16localeD2Ev($1);
      $$0 = $59;
     } else {
      __ZNSt3__16localeD2Ev($1);
      $14 = HEAP32[$this>>2]|0;
      $15 = (($14) + -12|0);
      $16 = HEAP32[$15>>2]|0;
      $$sum$i$i = (($16) + 24)|0;
      $17 = (($this) + ($$sum$i$i)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($this) + ($16)|0);
      $$sum3 = (($16) + 76)|0;
      $20 = (($this) + ($$sum3)|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21|0)==(-1);
      do {
       if ($22) {
        $$sum5 = (($16) + 28)|0;
        $23 = (($this) + ($$sum5)|0);
        __ZNSt3__16localeC2ERKS0_($$byval_copy,$23);
        __THREW__ = 0;
        $24 = (invoke_iii(2228,($$byval_copy|0),(3093336|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = HEAP32[$24>>2]|0;
         $28 = (($27) + 28|0);
         $29 = HEAP32[$28>>2]|0;
         __THREW__ = 0;
         $30 = (invoke_iii($29|0,($24|0),32)|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          __ZNSt3__16localeD2Ev($$byval_copy);
          $35 = $30 << 24 >> 24;
          HEAP32[$20>>2] = $35;
          $37 = $35;
          label = 9;
          break;
         }
        }
        $33 = ___cxa_find_matching_catch(0|0)|0;
        $34 = tempRet0;
        __ZNSt3__16localeD2Ev($$byval_copy);
        $eh$lpad$body$indexZ2D = $33;
       } else {
        $37 = $21;
        label = 9;
       }
      } while(0);
      if ((label|0) == 9) {
       $36 = $37&255;
       $38 = $__n&65535;
       $39 = HEAP32[$11>>2]|0;
       $40 = (($39) + 24|0);
       $41 = HEAP32[$40>>2]|0;
       HEAP32[$0>>2] = $18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_viiiiii($41|0,($2|0),($11|0),($$byval_copy|0),($19|0),($36|0),($38|0));
       $42 = __THREW__; __THREW__ = 0;
       $43 = $42&1;
       if (!($43)) {
        $44 = HEAP32[$2>>2]|0;
        $45 = ($44|0)==(0|0);
        if (!($45)) {
         break;
        }
        $46 = HEAP32[$this>>2]|0;
        $47 = (($46) + -12|0);
        $48 = HEAP32[$47>>2]|0;
        $49 = (($this) + ($48)|0);
        $$sum4 = (($48) + 16)|0;
        $50 = (($this) + ($$sum4)|0);
        $51 = HEAP32[$50>>2]|0;
        $52 = $51 | 5;
        __THREW__ = 0;
        invoke_vii(2476,($49|0),($52|0));
        $53 = __THREW__; __THREW__ = 0;
        $54 = $53&1;
        if (!($54)) {
         break;
        }
       }
       $57 = ___cxa_find_matching_catch(0|0)|0;
       $58 = tempRet0;
       $eh$lpad$body$indexZ2D = $57;
      }
      $$0 = $eh$lpad$body$indexZ2D;
     }
     __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($__s);
     $$1 = $$0;$$pre$phi7Z2D = $this;$$pre$phiZ2D = $this;
     break L1;
    }
   } while(0);
   __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($__s);
   STACKTOP = sp;return ($this|0);
  }
 } while(0);
 (___cxa_begin_catch(($$1|0))|0);
 $61 = HEAP32[$$pre$phiZ2D>>2]|0;
 $62 = (($61) + -12|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($$pre$phi7Z2D) + ($63)|0);
 __THREW__ = 0;
 invoke_vi(3301,($64|0));
 $65 = __THREW__; __THREW__ = 0;
 $66 = $65&1;
 if (!($66)) {
  ___cxa_end_catch();
  STACKTOP = sp;return ($this|0);
 }
 $67 = ___cxa_find_matching_catch()|0;
 $68 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $69 = __THREW__; __THREW__ = 0;
 $70 = $69&1;
 if ($70) {
  $71 = ___cxa_find_matching_catch(0|0)|0;
  $72 = tempRet0;
  ___clang_call_terminate($71);
  // unreachable;
 } else {
  ___resumeException($67|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEi($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0 = 0, $$1 = 0, $$byval_copy = 0, $$pre$phi8Z2D = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum$i$i = 0, $$sum4 = 0, $$sum5 = 0, $$sum6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $8 = 0, $9 = 0, $__s = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__s = sp + 8|0;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 __THREW__ = 0;
 invoke_vii(3507,($__s|0),($this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $54 = ___cxa_find_matching_catch(0|0)|0;
   $55 = tempRet0;
   $$1 = $54;$$pre$phi8Z2D = $this;$$pre$phiZ2D = $this;
  } else {
   $5 = HEAP8[$__s>>0]|0;
   $6 = ($5<<24>>24)==(0);
   do {
    if (!($6)) {
     $7 = HEAP32[$this>>2]|0;
     $8 = (($7) + -12|0);
     $9 = HEAP32[$8>>2]|0;
     $$sum = (($9) + 28)|0;
     $10 = (($this) + ($$sum)|0);
     __ZNSt3__16localeC2ERKS0_($1,$10);
     __THREW__ = 0;
     $11 = (invoke_iii(2228,($1|0),(3092024|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      $58 = ___cxa_find_matching_catch(0|0)|0;
      $59 = tempRet0;
      __ZNSt3__16localeD2Ev($1);
      $$0 = $58;
     } else {
      __ZNSt3__16localeD2Ev($1);
      $14 = HEAP32[$this>>2]|0;
      $15 = (($14) + -12|0);
      $16 = HEAP32[$15>>2]|0;
      $$sum$i$i = (($16) + 24)|0;
      $17 = (($this) + ($$sum$i$i)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($this) + ($16)|0);
      $$sum4 = (($16) + 76)|0;
      $20 = (($this) + ($$sum4)|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21|0)==(-1);
      do {
       if ($22) {
        $$sum6 = (($16) + 28)|0;
        $23 = (($this) + ($$sum6)|0);
        __ZNSt3__16localeC2ERKS0_($$byval_copy,$23);
        __THREW__ = 0;
        $24 = (invoke_iii(2228,($$byval_copy|0),(3093336|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = HEAP32[$24>>2]|0;
         $28 = (($27) + 28|0);
         $29 = HEAP32[$28>>2]|0;
         __THREW__ = 0;
         $30 = (invoke_iii($29|0,($24|0),32)|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          __ZNSt3__16localeD2Ev($$byval_copy);
          $35 = $30 << 24 >> 24;
          HEAP32[$20>>2] = $35;
          $37 = $35;
          label = 9;
          break;
         }
        }
        $33 = ___cxa_find_matching_catch(0|0)|0;
        $34 = tempRet0;
        __ZNSt3__16localeD2Ev($$byval_copy);
        $eh$lpad$body$indexZ2D = $33;
       } else {
        $37 = $21;
        label = 9;
       }
      } while(0);
      if ((label|0) == 9) {
       $36 = $37&255;
       $38 = HEAP32[$11>>2]|0;
       $39 = (($38) + 16|0);
       $40 = HEAP32[$39>>2]|0;
       HEAP32[$0>>2] = $18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_viiiiii($40|0,($2|0),($11|0),($$byval_copy|0),($19|0),($36|0),($__n|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        $43 = HEAP32[$2>>2]|0;
        $44 = ($43|0)==(0|0);
        if (!($44)) {
         break;
        }
        $45 = HEAP32[$this>>2]|0;
        $46 = (($45) + -12|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = (($this) + ($47)|0);
        $$sum5 = (($47) + 16)|0;
        $49 = (($this) + ($$sum5)|0);
        $50 = HEAP32[$49>>2]|0;
        $51 = $50 | 5;
        __THREW__ = 0;
        invoke_vii(2476,($48|0),($51|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if (!($53)) {
         break;
        }
       }
       $56 = ___cxa_find_matching_catch(0|0)|0;
       $57 = tempRet0;
       $eh$lpad$body$indexZ2D = $56;
      }
      $$0 = $eh$lpad$body$indexZ2D;
     }
     __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($__s);
     $$1 = $$0;$$pre$phi8Z2D = $this;$$pre$phiZ2D = $this;
     break L1;
    }
   } while(0);
   __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($__s);
   STACKTOP = sp;return ($this|0);
  }
 } while(0);
 (___cxa_begin_catch(($$1|0))|0);
 $60 = HEAP32[$$pre$phiZ2D>>2]|0;
 $61 = (($60) + -12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($$pre$phi8Z2D) + ($62)|0);
 __THREW__ = 0;
 invoke_vi(3301,($63|0));
 $64 = __THREW__; __THREW__ = 0;
 $65 = $64&1;
 if (!($65)) {
  ___cxa_end_catch();
  STACKTOP = sp;return ($this|0);
 }
 $66 = ___cxa_find_matching_catch()|0;
 $67 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $70 = ___cxa_find_matching_catch(0|0)|0;
  $71 = tempRet0;
  ___clang_call_terminate($70);
  // unreachable;
 } else {
  ___resumeException($66|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0 = 0, $$1 = 0, $$byval_copy = 0, $$pre$phi7Z2D = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum$i$i = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $8 = 0, $9 = 0, $__s = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 24|0;
 $0 = sp;
 $__s = sp + 8|0;
 $1 = sp + 16|0;
 $2 = sp + 20|0;
 __THREW__ = 0;
 invoke_vii(3507,($__s|0),($this|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $54 = ___cxa_find_matching_catch(0|0)|0;
   $55 = tempRet0;
   $$1 = $54;$$pre$phi7Z2D = $this;$$pre$phiZ2D = $this;
  } else {
   $5 = HEAP8[$__s>>0]|0;
   $6 = ($5<<24>>24)==(0);
   do {
    if (!($6)) {
     $7 = HEAP32[$this>>2]|0;
     $8 = (($7) + -12|0);
     $9 = HEAP32[$8>>2]|0;
     $$sum = (($9) + 28)|0;
     $10 = (($this) + ($$sum)|0);
     __ZNSt3__16localeC2ERKS0_($1,$10);
     __THREW__ = 0;
     $11 = (invoke_iii(2228,($1|0),(3092024|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      $58 = ___cxa_find_matching_catch(0|0)|0;
      $59 = tempRet0;
      __ZNSt3__16localeD2Ev($1);
      $$0 = $58;
     } else {
      __ZNSt3__16localeD2Ev($1);
      $14 = HEAP32[$this>>2]|0;
      $15 = (($14) + -12|0);
      $16 = HEAP32[$15>>2]|0;
      $$sum$i$i = (($16) + 24)|0;
      $17 = (($this) + ($$sum$i$i)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($this) + ($16)|0);
      $$sum3 = (($16) + 76)|0;
      $20 = (($this) + ($$sum3)|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = ($21|0)==(-1);
      do {
       if ($22) {
        $$sum5 = (($16) + 28)|0;
        $23 = (($this) + ($$sum5)|0);
        __ZNSt3__16localeC2ERKS0_($$byval_copy,$23);
        __THREW__ = 0;
        $24 = (invoke_iii(2228,($$byval_copy|0),(3093336|0))|0);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if (!($26)) {
         $27 = HEAP32[$24>>2]|0;
         $28 = (($27) + 28|0);
         $29 = HEAP32[$28>>2]|0;
         __THREW__ = 0;
         $30 = (invoke_iii($29|0,($24|0),32)|0);
         $31 = __THREW__; __THREW__ = 0;
         $32 = $31&1;
         if (!($32)) {
          __ZNSt3__16localeD2Ev($$byval_copy);
          $35 = $30 << 24 >> 24;
          HEAP32[$20>>2] = $35;
          $37 = $35;
          label = 9;
          break;
         }
        }
        $33 = ___cxa_find_matching_catch(0|0)|0;
        $34 = tempRet0;
        __ZNSt3__16localeD2Ev($$byval_copy);
        $eh$lpad$body$indexZ2D = $33;
       } else {
        $37 = $21;
        label = 9;
       }
      } while(0);
      if ((label|0) == 9) {
       $36 = $37&255;
       $38 = HEAP32[$11>>2]|0;
       $39 = (($38) + 24|0);
       $40 = HEAP32[$39>>2]|0;
       HEAP32[$0>>2] = $18;
       __THREW__ = 0;
       ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
       invoke_viiiiii($40|0,($2|0),($11|0),($$byval_copy|0),($19|0),($36|0),($__n|0));
       $41 = __THREW__; __THREW__ = 0;
       $42 = $41&1;
       if (!($42)) {
        $43 = HEAP32[$2>>2]|0;
        $44 = ($43|0)==(0|0);
        if (!($44)) {
         break;
        }
        $45 = HEAP32[$this>>2]|0;
        $46 = (($45) + -12|0);
        $47 = HEAP32[$46>>2]|0;
        $48 = (($this) + ($47)|0);
        $$sum4 = (($47) + 16)|0;
        $49 = (($this) + ($$sum4)|0);
        $50 = HEAP32[$49>>2]|0;
        $51 = $50 | 5;
        __THREW__ = 0;
        invoke_vii(2476,($48|0),($51|0));
        $52 = __THREW__; __THREW__ = 0;
        $53 = $52&1;
        if (!($53)) {
         break;
        }
       }
       $56 = ___cxa_find_matching_catch(0|0)|0;
       $57 = tempRet0;
       $eh$lpad$body$indexZ2D = $56;
      }
      $$0 = $eh$lpad$body$indexZ2D;
     }
     __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($__s);
     $$1 = $$0;$$pre$phi7Z2D = $this;$$pre$phiZ2D = $this;
     break L1;
    }
   } while(0);
   __ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev($__s);
   STACKTOP = sp;return ($this|0);
  }
 } while(0);
 (___cxa_begin_catch(($$1|0))|0);
 $60 = HEAP32[$$pre$phiZ2D>>2]|0;
 $61 = (($60) + -12|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($$pre$phi7Z2D) + ($62)|0);
 __THREW__ = 0;
 invoke_vi(3301,($63|0));
 $64 = __THREW__; __THREW__ = 0;
 $65 = $64&1;
 if (!($65)) {
  ___cxa_end_catch();
  STACKTOP = sp;return ($this|0);
 }
 $66 = ___cxa_find_matching_catch()|0;
 $67 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $68 = __THREW__; __THREW__ = 0;
 $69 = $68&1;
 if ($69) {
  $70 = ___cxa_find_matching_catch(0|0)|0;
  $71 = tempRet0;
  ___clang_call_terminate($70);
  // unreachable;
 } else {
  ___resumeException($66|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__113basic_ostreamIwNS_11char_traitsIwEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 __ZNSt3__18ios_baseD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__113basic_ostreamIwNS_11char_traitsIwEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 __ZNSt3__18ios_baseD2Ev($0);
 STACKTOP = sp;return;
}
function __ZTv0_n12_NSt3__113basic_ostreamIwNS_11char_traitsIwEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + ($2)|0);
 __ZNSt3__113basic_ostreamIwNS_11char_traitsIwEEED0Ev($3);
 STACKTOP = sp;return;
}
function __ZTv0_n12_NSt3__113basic_ostreamIwNS_11char_traitsIwEEED1Ev($this) {
 $this = $this|0;
 var $$sum = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -12|0);
 $2 = HEAP32[$1>>2]|0;
 $$sum = (($2) + 4)|0;
 $3 = (($this) + ($$sum)|0);
 __ZNSt3__18ios_baseD2Ev($3);
 STACKTOP = sp;return;
}
function __ZNKSt3__119__iostream_category4nameEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (3090856|0);
}
function __ZNKSt3__119__iostream_category7messageEi($agg$result,$this,$ev) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $ev = $ev|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ev|0)==(1);
 if ($0) {
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj($agg$result,3090872,35);
  STACKTOP = sp;return;
 } else {
  __ZNKSt3__112__do_message7messageEi($agg$result,$this,$ev);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__117iostream_categoryEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3090920>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (___cxa_guard_acquire((3090920|0))|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   HEAP32[3090912>>2] = ((3091608 + 8|0));
   ___cxa_guard_release((3090920|0));
  }
 }
 STACKTOP = sp;return (3090912|0);
}
function __ZNSt3__119__iostream_categoryD1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt3__18ios_base7failureC2EPKcRKNS_10error_codeE($this,$msg,$ec) {
 $this = $this|0;
 $msg = $msg|0;
 $ec = $ec|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = $ec;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 __ZNSt3__112system_errorC2ENS_10error_codeEPKc($this,$tmpcast$byval_copy,$msg);
 HEAP32[$this>>2] = ((3090928 + 8|0));
 STACKTOP = sp;return;
}
function __ZNSt3__18ios_base7failureD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112system_errorD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18ios_base7failureD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112system_errorD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18ios_baseD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__18ios_baseD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__119__iostream_categoryD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__17collateIcED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__17collateIcED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5facetD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__17collateIcE10do_compareEPKcS3_S3_S3_($this,$__lo1,$__hi1,$__lo2,$__hi2) {
 $this = $this|0;
 $__lo1 = $__lo1|0;
 $__hi1 = $__hi1|0;
 $__lo2 = $__lo2|0;
 $__hi2 = $__hi2|0;
 var $$0 = 0, $$015 = 0, $$02$lcssa = 0, $$024 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__lo2|0)==($__hi2|0);
 L1: do {
  if ($0) {
   $$02$lcssa = $__lo1;
   label = 6;
  } else {
   $$015 = $__lo2;$$024 = $__lo1;
   while(1) {
    $1 = ($$024|0)==($__hi1|0);
    if ($1) {
     $$0 = -1;
     break L1;
    }
    $2 = HEAP8[$$024>>0]|0;
    $3 = HEAP8[$$015>>0]|0;
    $4 = ($2<<24>>24)<($3<<24>>24);
    if ($4) {
     $$0 = -1;
     break L1;
    }
    $5 = ($3<<24>>24)<($2<<24>>24);
    if ($5) {
     $$0 = 1;
     break L1;
    }
    $6 = (($$024) + 1|0);
    $7 = (($$015) + 1|0);
    $8 = ($7|0)==($__hi2|0);
    if ($8) {
     $$02$lcssa = $6;
     label = 6;
     break;
    } else {
     $$015 = $7;$$024 = $6;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $9 = ($$02$lcssa|0)!=($__hi1|0);
  $10 = $9&1;
  $$0 = $10;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17collateIcE12do_transformEPKcS3_($agg$result,$this,$__lo,$__hi) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__lo = $__lo|0;
 $__hi = $__hi|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($agg$result,$__lo,$__hi);
 STACKTOP = sp;return;
}
function __ZNKSt3__17collateIcE7do_hashEPKcS3_($this,$__lo,$__hi) {
 $this = $this|0;
 $__lo = $__lo|0;
 $__hi = $__hi|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__h$0$lcssa = 0, $__h$02 = 0, $__p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__lo|0)==($__hi|0);
 if ($0) {
  $__h$0$lcssa = 0;
  STACKTOP = sp;return ($__h$0$lcssa|0);
 } else {
  $__h$02 = 0;$__p$01 = $__lo;
 }
 while(1) {
  $1 = $__h$02 << 4;
  $2 = HEAP8[$__p$01>>0]|0;
  $3 = $2 << 24 >> 24;
  $4 = (($3) + ($1))|0;
  $5 = $4 & -268435456;
  $6 = $5 >>> 24;
  $7 = $6 | $5;
  $8 = $7 ^ $4;
  $9 = (($__p$01) + 1|0);
  $10 = ($9|0)==($__hi|0);
  if ($10) {
   $__h$0$lcssa = $8;
   break;
  } else {
   $__h$02 = $8;$__p$01 = $9;
  }
 }
 STACKTOP = sp;return ($__h$0$lcssa|0);
}
function __ZNSt3__17collateIwED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__17collateIwED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__17collateIwE10do_compareEPKwS3_S3_S3_($this,$__lo1,$__hi1,$__lo2,$__hi2) {
 $this = $this|0;
 $__lo1 = $__lo1|0;
 $__hi1 = $__hi1|0;
 $__lo2 = $__lo2|0;
 $__hi2 = $__hi2|0;
 var $$0 = 0, $$015 = 0, $$02$lcssa = 0, $$024 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__lo2|0)==($__hi2|0);
 L1: do {
  if ($0) {
   $$02$lcssa = $__lo1;
   label = 6;
  } else {
   $$015 = $__lo2;$$024 = $__lo1;
   while(1) {
    $1 = ($$024|0)==($__hi1|0);
    if ($1) {
     $$0 = -1;
     break L1;
    }
    $2 = HEAP32[$$024>>2]|0;
    $3 = HEAP32[$$015>>2]|0;
    $4 = ($2|0)<($3|0);
    if ($4) {
     $$0 = -1;
     break L1;
    }
    $5 = ($3|0)<($2|0);
    if ($5) {
     $$0 = 1;
     break L1;
    }
    $6 = (($$024) + 4|0);
    $7 = (($$015) + 4|0);
    $8 = ($7|0)==($__hi2|0);
    if ($8) {
     $$02$lcssa = $6;
     label = 6;
     break;
    } else {
     $$015 = $7;$$024 = $6;
    }
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $9 = ($$02$lcssa|0)!=($__hi1|0);
  $10 = $9&1;
  $$0 = $10;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17collateIwE12do_transformEPKwS3_($agg$result,$this,$__lo,$__hi) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__lo = $__lo|0;
 $__hi = $__hi|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_($agg$result,$__lo,$__hi);
 STACKTOP = sp;return;
}
function __ZNKSt3__17collateIwE7do_hashEPKwS3_($this,$__lo,$__hi) {
 $this = $this|0;
 $__lo = $__lo|0;
 $__hi = $__hi|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__h$0$lcssa = 0, $__h$02 = 0, $__p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__lo|0)==($__hi|0);
 if ($0) {
  $__h$0$lcssa = 0;
  STACKTOP = sp;return ($__h$0$lcssa|0);
 } else {
  $__h$02 = 0;$__p$01 = $__lo;
 }
 while(1) {
  $1 = $__h$02 << 4;
  $2 = HEAP32[$__p$01>>2]|0;
  $3 = (($2) + ($1))|0;
  $4 = $3 & -268435456;
  $5 = $4 >>> 24;
  $6 = $5 | $4;
  $7 = $6 ^ $3;
  $8 = (($__p$01) + 4|0);
  $9 = ($8|0)==($__hi|0);
  if ($9) {
   $__h$0$lcssa = $7;
   break;
  } else {
   $__h$02 = $7;$__p$01 = $8;
  }
 }
 STACKTOP = sp;return ($__h$0$lcssa|0);
}
function __ZNSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__lv = 0, $__names = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp + 56|0;
 $$byval_copy = sp + 52|0;
 $__lv = sp + 48|0;
 $0 = sp + 44|0;
 $1 = sp + 40|0;
 $2 = sp + 36|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $__names = sp;
 $5 = sp + 32|0;
 $6 = (($__iob) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$__lv>>2] = -1;
  $10 = HEAP32[$this>>2]|0;
  $11 = (($10) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$__b>>2]|0;
  HEAP32[$1>>2] = $13;
  $14 = HEAP32[$__e>>2]|0;
  HEAP32[$2>>2] = $14;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  FUNCTION_TABLE_viiiiiii[$12 & 127]($0,$this,$$byval_copy,$$byval_copy2,$__iob,$__err,$__lv);
  $15 = HEAP32[$0>>2]|0;
  HEAP32[$__b>>2] = $15;
  $16 = HEAP32[$__lv>>2]|0;
  if ((($16|0) == 0)) {
   HEAP8[$__v>>0] = 0;
  } else if ((($16|0) == 1)) {
   HEAP8[$__v>>0] = 1;
  } else {
   HEAP8[$__v>>0] = 1;
   HEAP32[$__err>>2] = 4;
  }
  HEAP32[$agg$result>>2] = $15;
  STACKTOP = sp;return;
 }
 __ZNKSt3__18ios_base6getlocEv($3,$__iob);
 __THREW__ = 0;
 $17 = (invoke_iii(2228,($3|0),(3093336|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  $47 = HEAP32[$3>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($47)|0);
  $$0 = $45;$$01 = $46;
  ___resumeException($$0|0);
  // unreachable;
 }
 $20 = HEAP32[$3>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($20)|0);
 __ZNKSt3__18ios_base6getlocEv($4,$__iob);
 __THREW__ = 0;
 $21 = (invoke_iii(2228,($4|0),(3093480|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $50 = HEAP32[$4>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($50)|0);
  $$0 = $48;$$01 = $49;
  ___resumeException($$0|0);
  // unreachable;
 }
 $24 = HEAP32[$4>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($24)|0);
 $25 = HEAP32[$21>>2]|0;
 $26 = (($25) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 __THREW__ = 0;
 invoke_vii($27|0,($__names|0),($21|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $$02 = $__names;
 } else {
  $30 = (($__names) + 12|0);
  $31 = HEAP32[$21>>2]|0;
  $32 = (($31) + 28|0);
  $33 = HEAP32[$32>>2]|0;
  __THREW__ = 0;
  invoke_vii($33|0,($30|0),($21|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $$02 = $30;
  } else {
   $36 = HEAP32[$__e>>2]|0;
   HEAP32[$5>>2] = $36;
   $37 = (($__names) + 24|0);
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$5+0>>2]|0;
   $38 = (invoke_iiiiiiii(123,($__b|0),($$byval_copy2|0),($__names|0),($37|0),($17|0),($__err|0),1)|0);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $57 = ___cxa_find_matching_catch()|0;
    $58 = tempRet0;
    $59 = (($__names) + 12|0);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($59);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__names);
    $$0 = $57;$$01 = $58;
    ___resumeException($$0|0);
    // unreachable;
   } else {
    $41 = ($38|0)==($__names|0);
    $42 = $41&1;
    HEAP8[$__v>>0] = $42;
    $43 = HEAP32[$__b>>2]|0;
    HEAP32[$agg$result>>2] = $43;
    $44 = (($__names) + 12|0);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($44);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__names);
    STACKTOP = sp;return;
   }
  }
 }
 $51 = ___cxa_find_matching_catch()|0;
 $52 = tempRet0;
 $53 = ($__names|0)==($$02|0);
 if ($53) {
  $$0 = $51;$$01 = $52;
  ___resumeException($$0|0);
  // unreachable;
 } else {
  $55 = $$02;
 }
 while(1) {
  $54 = (($55) + -12|0);
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($54);
  $56 = ($54|0)==($__names|0);
  if ($56) {
   $$0 = $51;$$01 = $52;
   break;
  } else {
   $55 = $54;
  }
 }
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb($__b,$__e,$__kb,$__ke,$__ct,$__err,$__case_sensitive) {
 $__b = $__b|0;
 $__e = $__e|0;
 $__kb = $__kb|0;
 $__ke = $__ke|0;
 $__ct = $__ct|0;
 $__err = $__err|0;
 $__case_sensitive = $__case_sensitive|0;
 var $$ = 0, $$0$i$i = 0, $$024 = 0, $$02676 = 0, $$index = 0, $$index10 = 0, $$not = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i12 = 0, $$pre$i2$i$i16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__c$0 = 0, $__consume$0$off035 = 0, $__consume$1$off0 = 0, $__indx$0 = 0, $__kc$0 = 0, $__ky$062 = 0, $__ky1$036 = 0, $__ky2$047 = 0, $__n_does_match$0$lcssa = 0, $__n_does_match$060 = 0, $__n_does_match$1 = 0, $__n_does_match$2 = 0, $__n_does_match$2$phi = 0, $__n_does_match$332 = 0;
 var $__n_does_match$4 = 0, $__n_does_match$545 = 0, $__n_does_match$6 = 0, $__n_might_match$0$lcssa = 0, $__n_might_match$059 = 0, $__n_might_match$1 = 0, $__n_might_match$2 = 0, $__n_might_match$2$phi = 0, $__n_might_match$331 = 0, $__n_might_match$4 = 0, $__st$061 = 0, $__st$133 = 0, $__st$246 = 0, $__st$32577 = 0, $__statbuf = 0, $__status$0 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $tmp$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $__statbuf = sp;
 $0 = $__ke;
 $1 = $__kb;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 12)&-1;
 $4 = ($3>>>0)>(100);
 if ($4) {
  $5 = (_malloc($3)|0);
  $6 = ($5|0)==(0|0);
  if ($6) {
   __THREW__ = 0;
   invoke_v(1012);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    $$index = $9;$$index10 = $10;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $18 = 0;$__status$0 = 0;
   }
  } else {
   $18 = $5;$__status$0 = $5;
  }
 } else {
  $18 = 0;$__status$0 = $__statbuf;
 }
 $23 = ($__kb|0)==($__ke|0);
 if ($23) {
  $__n_does_match$0$lcssa = 0;$__n_might_match$0$lcssa = $3;
 } else {
  $__ky$062 = $__kb;$__n_does_match$060 = 0;$__n_might_match$059 = $3;$__st$061 = $__status$0;
  while(1) {
   $24 = HEAP8[$__ky$062>>0]|0;
   $25 = $24 & 1;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    $29 = $24&255;
    $30 = $29 >>> 1;
    $32 = $30;
   } else {
    $27 = (($__ky$062) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $32 = $28;
   }
   $31 = ($32|0)==(0);
   if ($31) {
    HEAP8[$__st$061>>0] = 2;
    $33 = (($__n_might_match$059) + -1)|0;
    $34 = (($__n_does_match$060) + 1)|0;
    $__n_does_match$1 = $34;$__n_might_match$1 = $33;
   } else {
    HEAP8[$__st$061>>0] = 1;
    $__n_does_match$1 = $__n_does_match$060;$__n_might_match$1 = $__n_might_match$059;
   }
   $35 = (($__ky$062) + 12|0);
   $36 = (($__st$061) + 1|0);
   $37 = ($35|0)==($__ke|0);
   if ($37) {
    $__n_does_match$0$lcssa = $__n_does_match$1;$__n_might_match$0$lcssa = $__n_might_match$1;
    break;
   } else {
    $__ky$062 = $35;$__n_does_match$060 = $__n_does_match$1;$__n_might_match$059 = $__n_might_match$1;$__st$061 = $36;
   }
  }
 }
 $__indx$0 = 0;$__n_does_match$2 = $__n_does_match$0$lcssa;$__n_might_match$2 = $__n_might_match$0$lcssa;
 L19: while(1) {
  $38 = HEAP32[$__b>>2]|0;
  $39 = ($38|0)==(0|0);
  do {
   if ($39) {
    $53 = 0;
   } else {
    $40 = (($38) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($38) + 16|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($41|0)==($43|0);
    if ($44) {
     $45 = HEAP32[$38>>2]|0;
     $46 = (($45) + 36|0);
     $47 = HEAP32[$46>>2]|0;
     __THREW__ = 0;
     $48 = (invoke_ii($47|0,($38|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      label = 6;
      break L19;
     }
     $51 = ($48|0)==(-1);
     if ($51) {
      HEAP32[$__b>>2] = 0;
      $53 = 0;
      break;
     } else {
      $$pre$i$i$i = HEAP32[$__b>>2]|0;
      $53 = $$pre$i$i$i;
      break;
     }
    } else {
     $53 = $38;
    }
   }
  } while(0);
  $52 = ($53|0)==(0|0);
  $54 = HEAP32[$__e>>2]|0;
  $55 = ($54|0)==(0|0);
  if ($55) {
   $$pre$i2$i$i16 = 0;
  } else {
   $56 = (($54) + 12|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($54) + 16|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($57|0)==($59|0);
   if ($60) {
    $61 = HEAP32[$54>>2]|0;
    $62 = (($61) + 36|0);
    $63 = HEAP32[$62>>2]|0;
    __THREW__ = 0;
    $64 = (invoke_ii($63|0,($54|0))|0);
    $65 = __THREW__; __THREW__ = 0;
    $66 = $65&1;
    if ($66) {
     label = 6;
     break;
    }
    $67 = ($64|0)==(-1);
    if ($67) {
     HEAP32[$__e>>2] = 0;
     $$pre$i2$i$i16 = 0;
    } else {
     $$pre$i2$i$i16 = $54;
    }
   } else {
    $$pre$i2$i$i16 = $54;
   }
  }
  $68 = ($$pre$i2$i$i16|0)==(0|0);
  $tmp$i$i = $52 ^ $68;
  $69 = ($__n_might_match$2|0)!=(0);
  $$ = $tmp$i$i & $69;
  $70 = HEAP32[$__b>>2]|0;
  if (!($$)) {
   label = 66;
   break;
  }
  $71 = (($70) + 12|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($70) + 16|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($72|0)==($74|0);
  if ($75) {
   $76 = HEAP32[$70>>2]|0;
   $77 = (($76) + 36|0);
   $78 = HEAP32[$77>>2]|0;
   __THREW__ = 0;
   $79 = (invoke_ii($78|0,($70|0))|0);
   $80 = __THREW__; __THREW__ = 0;
   $81 = $80&1;
   if ($81) {
    label = 6;
    break;
   } else {
    $$0$i$i = $79;
   }
  } else {
   $82 = HEAP8[$72>>0]|0;
   $83 = $82&255;
   $$0$i$i = $83;
  }
  $84 = $$0$i$i&255;
  if ($__case_sensitive) {
   $__c$0 = $84;
  } else {
   $85 = HEAP32[$__ct>>2]|0;
   $86 = (($85) + 12|0);
   $87 = HEAP32[$86>>2]|0;
   __THREW__ = 0;
   $88 = (invoke_iii($87|0,($__ct|0),($84|0))|0);
   $89 = __THREW__; __THREW__ = 0;
   $90 = $89&1;
   if ($90) {
    label = 6;
    break;
   } else {
    $__c$0 = $88;
   }
  }
  $$pre = (($__indx$0) + 1)|0;
  if ($23) {
   $__n_might_match$2$phi = $__n_might_match$2;$__n_does_match$2$phi = $__n_does_match$2;$__indx$0 = $$pre;$__n_might_match$2 = $__n_might_match$2$phi;$__n_does_match$2 = $__n_does_match$2$phi;
   continue;
  } else {
   $__consume$0$off035 = 0;$__ky1$036 = $__kb;$__n_does_match$332 = $__n_does_match$2;$__n_might_match$331 = $__n_might_match$2;$__st$133 = $__status$0;
  }
  while(1) {
   $91 = HEAP8[$__st$133>>0]|0;
   $92 = ($91<<24>>24)==(1);
   do {
    if ($92) {
     $93 = HEAP8[$__ky1$036>>0]|0;
     $94 = $93 & 1;
     $95 = ($94<<24>>24)==(0);
     if ($95) {
      $98 = (($__ky1$036) + 1|0);
      $100 = $98;
     } else {
      $96 = (($__ky1$036) + 8|0);
      $97 = HEAP32[$96>>2]|0;
      $100 = $97;
     }
     $99 = (($100) + ($__indx$0)|0);
     $101 = HEAP8[$99>>0]|0;
     if ($__case_sensitive) {
      $__kc$0 = $101;
     } else {
      $102 = HEAP32[$__ct>>2]|0;
      $103 = (($102) + 12|0);
      $104 = HEAP32[$103>>2]|0;
      __THREW__ = 0;
      $105 = (invoke_iii($104|0,($__ct|0),($101|0))|0);
      $106 = __THREW__; __THREW__ = 0;
      $107 = $106&1;
      if ($107) {
       label = 5;
       break L19;
      } else {
       $__kc$0 = $105;
      }
     }
     $108 = ($__c$0<<24>>24)==($__kc$0<<24>>24);
     if (!($108)) {
      HEAP8[$__st$133>>0] = 0;
      $120 = (($__n_might_match$331) + -1)|0;
      $__consume$1$off0 = $__consume$0$off035;$__n_does_match$4 = $__n_does_match$332;$__n_might_match$4 = $120;
      break;
     }
     $109 = HEAP8[$__ky1$036>>0]|0;
     $110 = $109 & 1;
     $111 = ($110<<24>>24)==(0);
     if ($111) {
      $114 = $109&255;
      $115 = $114 >>> 1;
      $117 = $115;
     } else {
      $112 = (($__ky1$036) + 4|0);
      $113 = HEAP32[$112>>2]|0;
      $117 = $113;
     }
     $116 = ($117|0)==($$pre|0);
     if ($116) {
      HEAP8[$__st$133>>0] = 2;
      $118 = (($__n_might_match$331) + -1)|0;
      $119 = (($__n_does_match$332) + 1)|0;
      $__consume$1$off0 = 1;$__n_does_match$4 = $119;$__n_might_match$4 = $118;
     } else {
      $__consume$1$off0 = 1;$__n_does_match$4 = $__n_does_match$332;$__n_might_match$4 = $__n_might_match$331;
     }
    } else {
     $__consume$1$off0 = $__consume$0$off035;$__n_does_match$4 = $__n_does_match$332;$__n_might_match$4 = $__n_might_match$331;
    }
   } while(0);
   $121 = (($__ky1$036) + 12|0);
   $122 = ($121|0)==($__ke|0);
   if ($122) {
    break;
   }
   $123 = (($__st$133) + 1|0);
   $__consume$0$off035 = $__consume$1$off0;$__ky1$036 = $121;$__n_does_match$332 = $__n_does_match$4;$__n_might_match$331 = $__n_might_match$4;$__st$133 = $123;
  }
  if (!($__consume$1$off0)) {
   $__indx$0 = $$pre;$__n_does_match$2 = $__n_does_match$4;$__n_might_match$2 = $__n_might_match$4;
   continue;
  }
  $124 = HEAP32[$__b>>2]|0;
  $125 = (($124) + 12|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (($124) + 16|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($126|0)==($128|0);
  if ($129) {
   $130 = HEAP32[$124>>2]|0;
   $131 = (($130) + 40|0);
   $132 = HEAP32[$131>>2]|0;
   __THREW__ = 0;
   (invoke_ii($132|0,($124|0))|0);
   $133 = __THREW__; __THREW__ = 0;
   $134 = $133&1;
   if ($134) {
    label = 6;
    break;
   }
  } else {
   $135 = (($126) + 1|0);
   HEAP32[$125>>2] = $135;
  }
  $136 = (($__n_does_match$4) + ($__n_might_match$4))|0;
  $$not = ($136>>>0)<(2);
  if ($$not) {
   $__indx$0 = $$pre;$__n_does_match$2 = $__n_does_match$4;$__n_might_match$2 = $__n_might_match$4;
   continue;
  } else {
   $__ky2$047 = $__kb;$__n_does_match$545 = $__n_does_match$4;$__st$246 = $__status$0;
  }
  while(1) {
   $137 = HEAP8[$__st$246>>0]|0;
   $138 = ($137<<24>>24)==(2);
   if ($138) {
    $139 = HEAP8[$__ky2$047>>0]|0;
    $140 = $139 & 1;
    $141 = ($140<<24>>24)==(0);
    if ($141) {
     $144 = $139&255;
     $145 = $144 >>> 1;
     $147 = $145;
    } else {
     $142 = (($__ky2$047) + 4|0);
     $143 = HEAP32[$142>>2]|0;
     $147 = $143;
    }
    $146 = ($147|0)==($$pre|0);
    if ($146) {
     $__n_does_match$6 = $__n_does_match$545;
    } else {
     HEAP8[$__st$246>>0] = 0;
     $148 = (($__n_does_match$545) + -1)|0;
     $__n_does_match$6 = $148;
    }
   } else {
    $__n_does_match$6 = $__n_does_match$545;
   }
   $149 = (($__ky2$047) + 12|0);
   $150 = (($__st$246) + 1|0);
   $151 = ($149|0)==($__ke|0);
   if ($151) {
    $__indx$0 = $$pre;$__n_does_match$2 = $__n_does_match$6;$__n_might_match$2 = $__n_might_match$4;
    continue L19;
   } else {
    $__ky2$047 = $149;$__n_does_match$545 = $__n_does_match$6;$__st$246 = $150;
   }
  }
 }
 if ((label|0) == 5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 else if ((label|0) == 6) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 }
 else if ((label|0) == 66) {
  $152 = ($70|0)==(0|0);
  do {
   if ($152) {
    $166 = 0;
    label = 72;
   } else {
    $153 = (($70) + 12|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = (($70) + 16|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = ($154|0)==($156|0);
    if ($157) {
     $158 = HEAP32[$70>>2]|0;
     $159 = (($158) + 36|0);
     $160 = HEAP32[$159>>2]|0;
     __THREW__ = 0;
     $161 = (invoke_ii($160|0,($70|0))|0);
     $162 = __THREW__; __THREW__ = 0;
     $163 = $162&1;
     if (!($163)) {
      $164 = ($161|0)==(-1);
      if ($164) {
       HEAP32[$__b>>2] = 0;
       $166 = 0;
       label = 72;
       break;
      } else {
       $$pre$i$i$i12 = HEAP32[$__b>>2]|0;
       $166 = $$pre$i$i$i12;
       label = 72;
       break;
      }
     }
    } else {
     $166 = $70;
     label = 72;
    }
   }
  } while(0);
  L89: do {
   if ((label|0) == 72) {
    $165 = ($166|0)==(0|0);
    do {
     if ($68) {
      label = 78;
     } else {
      $167 = (($$pre$i2$i$i16) + 12|0);
      $168 = HEAP32[$167>>2]|0;
      $169 = (($$pre$i2$i$i16) + 16|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = ($168|0)==($170|0);
      if (!($171)) {
       if ($165) {
        break;
       } else {
        label = 80;
        break;
       }
      }
      $172 = HEAP32[$$pre$i2$i$i16>>2]|0;
      $173 = (($172) + 36|0);
      $174 = HEAP32[$173>>2]|0;
      __THREW__ = 0;
      $175 = (invoke_ii($174|0,($$pre$i2$i$i16|0))|0);
      $176 = __THREW__; __THREW__ = 0;
      $177 = $176&1;
      if ($177) {
       break L89;
      }
      $178 = ($175|0)==(-1);
      if ($178) {
       HEAP32[$__e>>2] = 0;
       label = 78;
       break;
      } else {
       if ($165) {
        break;
       } else {
        label = 80;
        break;
       }
      }
     }
    } while(0);
    if ((label|0) == 78) {
     if ($165) {
      label = 80;
     }
    }
    if ((label|0) == 80) {
     $179 = HEAP32[$__err>>2]|0;
     $180 = $179 | 2;
     HEAP32[$__err>>2] = $180;
    }
    L105: do {
     if ($23) {
      label = 85;
     } else {
      $181 = HEAP8[$__status$0>>0]|0;
      $182 = ($181<<24>>24)==(2);
      if ($182) {
       $$024 = $__kb;
      } else {
       $$02676 = $__kb;$__st$32577 = $__status$0;
       while(1) {
        $186 = (($$02676) + 12|0);
        $187 = ($186|0)==($__ke|0);
        $184 = (($__st$32577) + 1|0);
        if ($187) {
         label = 85;
         break L105;
        }
        $183 = HEAP8[$184>>0]|0;
        $185 = ($183<<24>>24)==(2);
        if ($185) {
         $$024 = $186;
         break;
        } else {
         $$02676 = $186;$__st$32577 = $184;
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 85) {
     $188 = HEAP32[$__err>>2]|0;
     $189 = $188 | 4;
     HEAP32[$__err>>2] = $189;
     $$024 = $__ke;
    }
    $190 = ($18|0)==(0|0);
    if ($190) {
     STACKTOP = sp;return ($$024|0);
    }
    __THREW__ = 0;
    invoke_vi(3853,($18|0));
    $191 = __THREW__; __THREW__ = 0;
    $192 = $191&1;
    if ($192) {
     $193 = ___cxa_find_matching_catch(0|0)|0;
     $194 = tempRet0;
     ___clang_call_terminate($193);
     // unreachable;
    } else {
     STACKTOP = sp;return ($$024|0);
    }
   }
  } while(0);
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 }
 $17 = ($18|0)==(0|0);
 if ($17) {
  $$index = $lpad$phi$index;$$index10 = $lpad$phi$index3;
  ___resumeException($$index|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3853,($18|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index10 = $lpad$phi$index3;
  ___resumeException($$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre31 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $__atoms = sp + 198|0;
 $__thousands_sep = sp + 196|0;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 192|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre33 = (($__buf) + 8|0);
    $$pre$phi32Z2D = $8;$$pre$phi34Z2D = $$pre33;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre31 = (($__buf) + 1|0);
    $$pre$phi32Z2D = $$pre31;$$pre$phi34Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $158 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $158 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $158 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi32Z2D;
     } else {
      $73 = HEAP32[$$pre$phi34Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($94,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $158;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP32[$__g_end>>2]|0;
    $116 = $115;
    $117 = $__g;
    $118 = (($116) - ($117))|0;
    $119 = ($118|0)<(160);
    if ($119) {
     $120 = HEAP32[$__dc>>2]|0;
     $121 = (($115) + 4|0);
     HEAP32[$__g_end>>2] = $121;
     HEAP32[$115>>2] = $120;
    }
   }
   $122 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $123 = (invoke_iiiii(335,($__a$2|0),($122|0),($__err|0),($0|0))|0);
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if (!($125)) {
    HEAP32[$__v>>2] = $123;
    $126 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$126,$__err);
    $127 = ($26|0)==(0|0);
    if ($127) {
     $141 = 0;
    } else {
     $128 = (($26) + 12|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = (($26) + 16|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($129|0)==($131|0);
     if ($132) {
      $133 = HEAP32[$26>>2]|0;
      $134 = (($133) + 36|0);
      $135 = HEAP32[$134>>2]|0;
      __THREW__ = 0;
      $136 = (invoke_ii($135|0,($26|0))|0);
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break;
      }
      $139 = ($136|0)==(-1);
      if ($139) {
       HEAP32[$__b>>2] = 0;
       $141 = 0;
      } else {
       $141 = $26;
      }
     } else {
      $141 = $26;
     }
    }
    $140 = ($141|0)==(0|0);
    $142 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($142) {
      label = 61;
     } else {
      $143 = (($$pre$i2$i$i) + 12|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($$pre$i2$i$i) + 16|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if (!($147)) {
       if (!($140)) {
        break;
       }
       HEAP32[$agg$result>>2] = $141;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $148 = HEAP32[$$pre$i2$i$i>>2]|0;
      $149 = (($148) + 36|0);
      $150 = HEAP32[$149>>2]|0;
      __THREW__ = 0;
      $151 = (invoke_ii($150|0,($$pre$i2$i$i|0))|0);
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       break L1;
      }
      $154 = ($151|0)==(-1);
      if ($154) {
       HEAP32[$__e>>2] = 0;
       label = 61;
       break;
      }
      $155 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $140 ^ $155;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $141;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 61) {
     if (!($140)) {
      HEAP32[$agg$result>>2] = $141;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $156 = HEAP32[$__err>>2]|0;
    $157 = $156 | 2;
    HEAP32[$__err>>2] = $157;
    HEAP32[$agg$result>>2] = $141;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre31 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0;
 var $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $__atoms = sp + 198|0;
 $__thousands_sep = sp + 196|0;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 192|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre33 = (($__buf) + 8|0);
    $$pre$phi32Z2D = $8;$$pre$phi34Z2D = $$pre33;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre31 = (($__buf) + 1|0);
    $$pre$phi32Z2D = $$pre31;$$pre$phi34Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $163 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $163 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $163 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi32Z2D;
     } else {
      $73 = HEAP32[$$pre$phi34Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($94,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $163;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP32[$__g_end>>2]|0;
    $116 = $115;
    $117 = $__g;
    $118 = (($116) - ($117))|0;
    $119 = ($118|0)<(160);
    if ($119) {
     $120 = HEAP32[$__dc>>2]|0;
     $121 = (($115) + 4|0);
     HEAP32[$__g_end>>2] = $121;
     HEAP32[$115>>2] = $120;
    }
   }
   $122 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $123 = (invoke_iiiii(336,($__a$2|0),($122|0),($__err|0),($0|0))|0);
   $124 = tempRet0;
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if (!($126)) {
    $127 = $__v;
    $128 = $127;
    HEAP32[$128>>2] = $123;
    $129 = (($127) + 4)|0;
    $130 = $129;
    HEAP32[$130>>2] = $124;
    $131 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$131,$__err);
    $132 = ($26|0)==(0|0);
    if ($132) {
     $146 = 0;
    } else {
     $133 = (($26) + 12|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($26) + 16|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = ($134|0)==($136|0);
     if ($137) {
      $138 = HEAP32[$26>>2]|0;
      $139 = (($138) + 36|0);
      $140 = HEAP32[$139>>2]|0;
      __THREW__ = 0;
      $141 = (invoke_ii($140|0,($26|0))|0);
      $142 = __THREW__; __THREW__ = 0;
      $143 = $142&1;
      if ($143) {
       break;
      }
      $144 = ($141|0)==(-1);
      if ($144) {
       HEAP32[$__b>>2] = 0;
       $146 = 0;
      } else {
       $146 = $26;
      }
     } else {
      $146 = $26;
     }
    }
    $145 = ($146|0)==(0|0);
    $147 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($147) {
      label = 61;
     } else {
      $148 = (($$pre$i2$i$i) + 12|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = (($$pre$i2$i$i) + 16|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = ($149|0)==($151|0);
      if (!($152)) {
       if (!($145)) {
        break;
       }
       HEAP32[$agg$result>>2] = $146;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $153 = HEAP32[$$pre$i2$i$i>>2]|0;
      $154 = (($153) + 36|0);
      $155 = HEAP32[$154>>2]|0;
      __THREW__ = 0;
      $156 = (invoke_ii($155|0,($$pre$i2$i$i|0))|0);
      $157 = __THREW__; __THREW__ = 0;
      $158 = $157&1;
      if ($158) {
       break L1;
      }
      $159 = ($156|0)==(-1);
      if ($159) {
       HEAP32[$__e>>2] = 0;
       label = 61;
       break;
      }
      $160 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $145 ^ $160;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $146;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 61) {
     if (!($145)) {
      HEAP32[$agg$result>>2] = $146;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $161 = HEAP32[$__err>>2]|0;
    $162 = $161 | 2;
    HEAP32[$__err>>2] = $162;
    HEAP32[$agg$result>>2] = $146;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre31 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $__atoms = sp + 198|0;
 $__thousands_sep = sp + 196|0;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 192|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre33 = (($__buf) + 8|0);
    $$pre$phi32Z2D = $8;$$pre$phi34Z2D = $$pre33;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre31 = (($__buf) + 1|0);
    $$pre$phi32Z2D = $$pre31;$$pre$phi34Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $158 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $158 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $158 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi32Z2D;
     } else {
      $73 = HEAP32[$$pre$phi34Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($94,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $158;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP32[$__g_end>>2]|0;
    $116 = $115;
    $117 = $__g;
    $118 = (($116) - ($117))|0;
    $119 = ($118|0)<(160);
    if ($119) {
     $120 = HEAP32[$__dc>>2]|0;
     $121 = (($115) + 4|0);
     HEAP32[$__g_end>>2] = $121;
     HEAP32[$115>>2] = $120;
    }
   }
   $122 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $123 = (invoke_iiiii(337,($__a$2|0),($122|0),($__err|0),($0|0))|0);
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if (!($125)) {
    HEAP16[$__v>>1] = $123;
    $126 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$126,$__err);
    $127 = ($26|0)==(0|0);
    if ($127) {
     $141 = 0;
    } else {
     $128 = (($26) + 12|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = (($26) + 16|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($129|0)==($131|0);
     if ($132) {
      $133 = HEAP32[$26>>2]|0;
      $134 = (($133) + 36|0);
      $135 = HEAP32[$134>>2]|0;
      __THREW__ = 0;
      $136 = (invoke_ii($135|0,($26|0))|0);
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break;
      }
      $139 = ($136|0)==(-1);
      if ($139) {
       HEAP32[$__b>>2] = 0;
       $141 = 0;
      } else {
       $141 = $26;
      }
     } else {
      $141 = $26;
     }
    }
    $140 = ($141|0)==(0|0);
    $142 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($142) {
      label = 61;
     } else {
      $143 = (($$pre$i2$i$i) + 12|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($$pre$i2$i$i) + 16|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if (!($147)) {
       if (!($140)) {
        break;
       }
       HEAP32[$agg$result>>2] = $141;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $148 = HEAP32[$$pre$i2$i$i>>2]|0;
      $149 = (($148) + 36|0);
      $150 = HEAP32[$149>>2]|0;
      __THREW__ = 0;
      $151 = (invoke_ii($150|0,($$pre$i2$i$i|0))|0);
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       break L1;
      }
      $154 = ($151|0)==(-1);
      if ($154) {
       HEAP32[$__e>>2] = 0;
       label = 61;
       break;
      }
      $155 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $140 ^ $155;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $141;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 61) {
     if (!($140)) {
      HEAP32[$agg$result>>2] = $141;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $156 = HEAP32[$__err>>2]|0;
    $157 = $156 | 2;
    HEAP32[$__err>>2] = $157;
    HEAP32[$agg$result>>2] = $141;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre31 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $__atoms = sp + 198|0;
 $__thousands_sep = sp + 196|0;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 192|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre33 = (($__buf) + 8|0);
    $$pre$phi32Z2D = $8;$$pre$phi34Z2D = $$pre33;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre31 = (($__buf) + 1|0);
    $$pre$phi32Z2D = $$pre31;$$pre$phi34Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $158 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $158 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $158 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi32Z2D;
     } else {
      $73 = HEAP32[$$pre$phi34Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($94,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $158;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP32[$__g_end>>2]|0;
    $116 = $115;
    $117 = $__g;
    $118 = (($116) - ($117))|0;
    $119 = ($118|0)<(160);
    if ($119) {
     $120 = HEAP32[$__dc>>2]|0;
     $121 = (($115) + 4|0);
     HEAP32[$__g_end>>2] = $121;
     HEAP32[$115>>2] = $120;
    }
   }
   $122 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $123 = (invoke_iiiii(338,($__a$2|0),($122|0),($__err|0),($0|0))|0);
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if (!($125)) {
    HEAP32[$__v>>2] = $123;
    $126 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$126,$__err);
    $127 = ($26|0)==(0|0);
    if ($127) {
     $141 = 0;
    } else {
     $128 = (($26) + 12|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = (($26) + 16|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($129|0)==($131|0);
     if ($132) {
      $133 = HEAP32[$26>>2]|0;
      $134 = (($133) + 36|0);
      $135 = HEAP32[$134>>2]|0;
      __THREW__ = 0;
      $136 = (invoke_ii($135|0,($26|0))|0);
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break;
      }
      $139 = ($136|0)==(-1);
      if ($139) {
       HEAP32[$__b>>2] = 0;
       $141 = 0;
      } else {
       $141 = $26;
      }
     } else {
      $141 = $26;
     }
    }
    $140 = ($141|0)==(0|0);
    $142 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($142) {
      label = 61;
     } else {
      $143 = (($$pre$i2$i$i) + 12|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($$pre$i2$i$i) + 16|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if (!($147)) {
       if (!($140)) {
        break;
       }
       HEAP32[$agg$result>>2] = $141;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $148 = HEAP32[$$pre$i2$i$i>>2]|0;
      $149 = (($148) + 36|0);
      $150 = HEAP32[$149>>2]|0;
      __THREW__ = 0;
      $151 = (invoke_ii($150|0,($$pre$i2$i$i|0))|0);
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       break L1;
      }
      $154 = ($151|0)==(-1);
      if ($154) {
       HEAP32[$__e>>2] = 0;
       label = 61;
       break;
      }
      $155 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $140 ^ $155;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $141;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 61) {
     if (!($140)) {
      HEAP32[$agg$result>>2] = $141;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $156 = HEAP32[$__err>>2]|0;
    $157 = $156 | 2;
    HEAP32[$__err>>2] = $157;
    HEAP32[$agg$result>>2] = $141;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre31 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $__atoms = sp + 198|0;
 $__thousands_sep = sp + 196|0;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 192|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre33 = (($__buf) + 8|0);
    $$pre$phi32Z2D = $8;$$pre$phi34Z2D = $$pre33;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre31 = (($__buf) + 1|0);
    $$pre$phi32Z2D = $$pre31;$$pre$phi34Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $158 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $158 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $158 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi32Z2D;
     } else {
      $73 = HEAP32[$$pre$phi34Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($94,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $158;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP32[$__g_end>>2]|0;
    $116 = $115;
    $117 = $__g;
    $118 = (($116) - ($117))|0;
    $119 = ($118|0)<(160);
    if ($119) {
     $120 = HEAP32[$__dc>>2]|0;
     $121 = (($115) + 4|0);
     HEAP32[$__g_end>>2] = $121;
     HEAP32[$115>>2] = $120;
    }
   }
   $122 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $123 = (invoke_iiiii(339,($__a$2|0),($122|0),($__err|0),($0|0))|0);
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if (!($125)) {
    HEAP32[$__v>>2] = $123;
    $126 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$126,$__err);
    $127 = ($26|0)==(0|0);
    if ($127) {
     $141 = 0;
    } else {
     $128 = (($26) + 12|0);
     $129 = HEAP32[$128>>2]|0;
     $130 = (($26) + 16|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($129|0)==($131|0);
     if ($132) {
      $133 = HEAP32[$26>>2]|0;
      $134 = (($133) + 36|0);
      $135 = HEAP32[$134>>2]|0;
      __THREW__ = 0;
      $136 = (invoke_ii($135|0,($26|0))|0);
      $137 = __THREW__; __THREW__ = 0;
      $138 = $137&1;
      if ($138) {
       break;
      }
      $139 = ($136|0)==(-1);
      if ($139) {
       HEAP32[$__b>>2] = 0;
       $141 = 0;
      } else {
       $141 = $26;
      }
     } else {
      $141 = $26;
     }
    }
    $140 = ($141|0)==(0|0);
    $142 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($142) {
      label = 61;
     } else {
      $143 = (($$pre$i2$i$i) + 12|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($$pre$i2$i$i) + 16|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if (!($147)) {
       if (!($140)) {
        break;
       }
       HEAP32[$agg$result>>2] = $141;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $148 = HEAP32[$$pre$i2$i$i>>2]|0;
      $149 = (($148) + 36|0);
      $150 = HEAP32[$149>>2]|0;
      __THREW__ = 0;
      $151 = (invoke_ii($150|0,($$pre$i2$i$i|0))|0);
      $152 = __THREW__; __THREW__ = 0;
      $153 = $152&1;
      if ($153) {
       break L1;
      }
      $154 = ($151|0)==(-1);
      if ($154) {
       HEAP32[$__e>>2] = 0;
       label = 61;
       break;
      }
      $155 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $140 ^ $155;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $141;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 61) {
     if (!($140)) {
      HEAP32[$agg$result>>2] = $141;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $156 = HEAP32[$__err>>2]|0;
    $157 = $156 | 2;
    HEAP32[$__err>>2] = $157;
    HEAP32[$agg$result>>2] = $141;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi32Z2D = 0, $$pre$phi34Z2D = 0, $$pre31 = 0, $$pre33 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0;
 var $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $__atoms = sp + 198|0;
 $__thousands_sep = sp + 196|0;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 192|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre33 = (($__buf) + 8|0);
    $$pre$phi32Z2D = $8;$$pre$phi34Z2D = $$pre33;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre31 = (($__buf) + 1|0);
    $$pre$phi32Z2D = $$pre31;$$pre$phi34Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $163 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $163 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $163 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi32Z2D;
     } else {
      $73 = HEAP32[$$pre$phi34Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($94,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $163;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP32[$__g_end>>2]|0;
    $116 = $115;
    $117 = $__g;
    $118 = (($116) - ($117))|0;
    $119 = ($118|0)<(160);
    if ($119) {
     $120 = HEAP32[$__dc>>2]|0;
     $121 = (($115) + 4|0);
     HEAP32[$__g_end>>2] = $121;
     HEAP32[$115>>2] = $120;
    }
   }
   $122 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $123 = (invoke_iiiii(340,($__a$2|0),($122|0),($__err|0),($0|0))|0);
   $124 = tempRet0;
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if (!($126)) {
    $127 = $__v;
    $128 = $127;
    HEAP32[$128>>2] = $123;
    $129 = (($127) + 4)|0;
    $130 = $129;
    HEAP32[$130>>2] = $124;
    $131 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$131,$__err);
    $132 = ($26|0)==(0|0);
    if ($132) {
     $146 = 0;
    } else {
     $133 = (($26) + 12|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($26) + 16|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = ($134|0)==($136|0);
     if ($137) {
      $138 = HEAP32[$26>>2]|0;
      $139 = (($138) + 36|0);
      $140 = HEAP32[$139>>2]|0;
      __THREW__ = 0;
      $141 = (invoke_ii($140|0,($26|0))|0);
      $142 = __THREW__; __THREW__ = 0;
      $143 = $142&1;
      if ($143) {
       break;
      }
      $144 = ($141|0)==(-1);
      if ($144) {
       HEAP32[$__b>>2] = 0;
       $146 = 0;
      } else {
       $146 = $26;
      }
     } else {
      $146 = $26;
     }
    }
    $145 = ($146|0)==(0|0);
    $147 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($147) {
      label = 61;
     } else {
      $148 = (($$pre$i2$i$i) + 12|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = (($$pre$i2$i$i) + 16|0);
      $151 = HEAP32[$150>>2]|0;
      $152 = ($149|0)==($151|0);
      if (!($152)) {
       if (!($145)) {
        break;
       }
       HEAP32[$agg$result>>2] = $146;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $153 = HEAP32[$$pre$i2$i$i>>2]|0;
      $154 = (($153) + 36|0);
      $155 = HEAP32[$154>>2]|0;
      __THREW__ = 0;
      $156 = (invoke_ii($155|0,($$pre$i2$i$i|0))|0);
      $157 = __THREW__; __THREW__ = 0;
      $158 = $157&1;
      if ($158) {
       break L1;
      }
      $159 = ($156|0)==(-1);
      if ($159) {
       HEAP32[$__e>>2] = 0;
       label = 61;
       break;
      }
      $160 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $145 ^ $160;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $146;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 61) {
     if (!($145)) {
      HEAP32[$agg$result>>2] = $146;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $161 = HEAP32[$__err>>2]|0;
    $162 = $161 | 2;
    HEAP32[$__err>>2] = $162;
    HEAP32[$agg$result>>2] = $146;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi33Z2D = 0, $$pre$phi35Z2D = 0, $$pre32 = 0, $$pre34 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = Math_fround(0), $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__decimal_point = 0, $__exp = 0, $__g = 0, $__g_end = 0;
 var $__grouping = 0, $__in_units = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $__atoms = sp + 200|0;
 $__decimal_point = sp + 199|0;
 $__thousands_sep = sp + 198|0;
 $__grouping = sp + 8|0;
 $__buf = sp + 20|0;
 $__a_end = sp + 192|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 4|0;
 $__in_units = sp + 197|0;
 $__exp = sp + 196|0;
 __ZNSt3__19__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_($__grouping,$__iob,$__atoms,$__decimal_point,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP8[$__buf>>0]|0;
   $3 = $2 & 1;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    $7 = (($__buf) + 1|0);
    $$pre34 = (($__buf) + 8|0);
    $$pre$phi33Z2D = $7;$$pre$phi35Z2D = $$pre34;$8 = $7;
   } else {
    $5 = (($__buf) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $$pre32 = (($__buf) + 1|0);
    $$pre$phi33Z2D = $$pre32;$$pre$phi35Z2D = $5;$8 = $6;
   }
   HEAP32[$__a_end>>2] = $8;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   HEAP8[$__in_units>>0] = 1;
   HEAP8[$__exp>>0] = 69;
   $9 = (($__buf) + 4|0);
   $10 = HEAP8[$__decimal_point>>0]|0;
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $8;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $160 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $160 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $160 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$9>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$9>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi33Z2D;
     } else {
      $73 = HEAP32[$$pre$phi35Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_($94,$__in_units,$__exp,$__a$1,$__a_end,$10,$11,$__grouping,$__g,$__g_end,$__dc,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $160;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP8[$__in_units>>0]|0;
    $116 = ($115<<24>>24)==(0);
    if (!($116)) {
     $117 = HEAP32[$__g_end>>2]|0;
     $118 = $117;
     $119 = $__g;
     $120 = (($118) - ($119))|0;
     $121 = ($120|0)<(160);
     if ($121) {
      $122 = HEAP32[$__dc>>2]|0;
      $123 = (($117) + 4|0);
      HEAP32[$__g_end>>2] = $123;
      HEAP32[$117>>2] = $122;
     }
    }
   }
   $124 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $125 = (Math_fround(+(invoke_fiii(18,($__a$2|0),($124|0),($__err|0)))));
   $126 = __THREW__; __THREW__ = 0;
   $127 = $126&1;
   if (!($127)) {
    HEAPF32[$__v>>2] = $125;
    $128 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$128,$__err);
    $129 = ($26|0)==(0|0);
    if ($129) {
     $143 = 0;
    } else {
     $130 = (($26) + 12|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = (($26) + 16|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($131|0)==($133|0);
     if ($134) {
      $135 = HEAP32[$26>>2]|0;
      $136 = (($135) + 36|0);
      $137 = HEAP32[$136>>2]|0;
      __THREW__ = 0;
      $138 = (invoke_ii($137|0,($26|0))|0);
      $139 = __THREW__; __THREW__ = 0;
      $140 = $139&1;
      if ($140) {
       break;
      }
      $141 = ($138|0)==(-1);
      if ($141) {
       HEAP32[$__b>>2] = 0;
       $143 = 0;
      } else {
       $143 = $26;
      }
     } else {
      $143 = $26;
     }
    }
    $142 = ($143|0)==(0|0);
    $144 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($144) {
      label = 62;
     } else {
      $145 = (($$pre$i2$i$i) + 12|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = (($$pre$i2$i$i) + 16|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ($146|0)==($148|0);
      if (!($149)) {
       if (!($142)) {
        break;
       }
       HEAP32[$agg$result>>2] = $143;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $150 = HEAP32[$$pre$i2$i$i>>2]|0;
      $151 = (($150) + 36|0);
      $152 = HEAP32[$151>>2]|0;
      __THREW__ = 0;
      $153 = (invoke_ii($152|0,($$pre$i2$i$i|0))|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       break L1;
      }
      $156 = ($153|0)==(-1);
      if ($156) {
       HEAP32[$__e>>2] = 0;
       label = 62;
       break;
      }
      $157 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $142 ^ $157;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $143;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 62) {
     if (!($142)) {
      HEAP32[$agg$result>>2] = $143;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $158 = HEAP32[$__err>>2]|0;
    $159 = $158 | 2;
    HEAP32[$__err>>2] = $159;
    HEAP32[$agg$result>>2] = $143;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi33Z2D = 0, $$pre$phi35Z2D = 0, $$pre32 = 0, $$pre34 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__decimal_point = 0, $__exp = 0, $__g = 0, $__g_end = 0;
 var $__grouping = 0, $__in_units = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $__atoms = sp + 200|0;
 $__decimal_point = sp + 199|0;
 $__thousands_sep = sp + 198|0;
 $__grouping = sp + 8|0;
 $__buf = sp + 20|0;
 $__a_end = sp + 192|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 4|0;
 $__in_units = sp + 197|0;
 $__exp = sp + 196|0;
 __ZNSt3__19__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_($__grouping,$__iob,$__atoms,$__decimal_point,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP8[$__buf>>0]|0;
   $3 = $2 & 1;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    $7 = (($__buf) + 1|0);
    $$pre34 = (($__buf) + 8|0);
    $$pre$phi33Z2D = $7;$$pre$phi35Z2D = $$pre34;$8 = $7;
   } else {
    $5 = (($__buf) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $$pre32 = (($__buf) + 1|0);
    $$pre$phi33Z2D = $$pre32;$$pre$phi35Z2D = $5;$8 = $6;
   }
   HEAP32[$__a_end>>2] = $8;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   HEAP8[$__in_units>>0] = 1;
   HEAP8[$__exp>>0] = 69;
   $9 = (($__buf) + 4|0);
   $10 = HEAP8[$__decimal_point>>0]|0;
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $8;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $160 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $160 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $160 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$9>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$9>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi33Z2D;
     } else {
      $73 = HEAP32[$$pre$phi35Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_($94,$__in_units,$__exp,$__a$1,$__a_end,$10,$11,$__grouping,$__g,$__g_end,$__dc,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $160;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP8[$__in_units>>0]|0;
    $116 = ($115<<24>>24)==(0);
    if (!($116)) {
     $117 = HEAP32[$__g_end>>2]|0;
     $118 = $117;
     $119 = $__g;
     $120 = (($118) - ($119))|0;
     $121 = ($120|0)<(160);
     if ($121) {
      $122 = HEAP32[$__dc>>2]|0;
      $123 = (($117) + 4|0);
      HEAP32[$__g_end>>2] = $123;
      HEAP32[$117>>2] = $122;
     }
    }
   }
   $124 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $125 = (+invoke_diii(7,($__a$2|0),($124|0),($__err|0)));
   $126 = __THREW__; __THREW__ = 0;
   $127 = $126&1;
   if (!($127)) {
    HEAPF64[$__v>>3] = $125;
    $128 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$128,$__err);
    $129 = ($26|0)==(0|0);
    if ($129) {
     $143 = 0;
    } else {
     $130 = (($26) + 12|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = (($26) + 16|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($131|0)==($133|0);
     if ($134) {
      $135 = HEAP32[$26>>2]|0;
      $136 = (($135) + 36|0);
      $137 = HEAP32[$136>>2]|0;
      __THREW__ = 0;
      $138 = (invoke_ii($137|0,($26|0))|0);
      $139 = __THREW__; __THREW__ = 0;
      $140 = $139&1;
      if ($140) {
       break;
      }
      $141 = ($138|0)==(-1);
      if ($141) {
       HEAP32[$__b>>2] = 0;
       $143 = 0;
      } else {
       $143 = $26;
      }
     } else {
      $143 = $26;
     }
    }
    $142 = ($143|0)==(0|0);
    $144 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($144) {
      label = 62;
     } else {
      $145 = (($$pre$i2$i$i) + 12|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = (($$pre$i2$i$i) + 16|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ($146|0)==($148|0);
      if (!($149)) {
       if (!($142)) {
        break;
       }
       HEAP32[$agg$result>>2] = $143;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $150 = HEAP32[$$pre$i2$i$i>>2]|0;
      $151 = (($150) + 36|0);
      $152 = HEAP32[$151>>2]|0;
      __THREW__ = 0;
      $153 = (invoke_ii($152|0,($$pre$i2$i$i|0))|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       break L1;
      }
      $156 = ($153|0)==(-1);
      if ($156) {
       HEAP32[$__e>>2] = 0;
       label = 62;
       break;
      }
      $157 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $142 ^ $157;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $143;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 62) {
     if (!($142)) {
      HEAP32[$agg$result>>2] = $143;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $158 = HEAP32[$__err>>2]|0;
    $159 = $158 | 2;
    HEAP32[$__err>>2] = $159;
    HEAP32[$agg$result>>2] = $143;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$pre = 0, $$pre$i$i$i4 = 0, $$pre$i2$i$i = 0, $$pre$phi33Z2D = 0, $$pre$phi35Z2D = 0, $$pre32 = 0, $$pre34 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__decimal_point = 0, $__exp = 0, $__g = 0, $__g_end = 0;
 var $__grouping = 0, $__in_units = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i19 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $__atoms = sp + 200|0;
 $__decimal_point = sp + 199|0;
 $__thousands_sep = sp + 198|0;
 $__grouping = sp + 8|0;
 $__buf = sp + 20|0;
 $__a_end = sp + 192|0;
 $__g = sp + 32|0;
 $__g_end = sp;
 $__dc = sp + 4|0;
 $__in_units = sp + 197|0;
 $__exp = sp + 196|0;
 __ZNSt3__19__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_($__grouping,$__iob,$__atoms,$__decimal_point,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP8[$__buf>>0]|0;
   $3 = $2 & 1;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    $7 = (($__buf) + 1|0);
    $$pre34 = (($__buf) + 8|0);
    $$pre$phi33Z2D = $7;$$pre$phi35Z2D = $$pre34;$8 = $7;
   } else {
    $5 = (($__buf) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $$pre32 = (($__buf) + 1|0);
    $$pre$phi33Z2D = $$pre32;$$pre$phi35Z2D = $5;$8 = $6;
   }
   HEAP32[$__a_end>>2] = $8;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   HEAP8[$__in_units>>0] = 1;
   HEAP8[$__exp>>0] = 69;
   $9 = (($__buf) + 4|0);
   $10 = HEAP8[$__decimal_point>>0]|0;
   $11 = HEAP8[$__thousands_sep>>0]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i4 = $$pre;$__a$0 = $8;
   L7: while(1) {
    $12 = ($$pre$i$i$i4|0)==(0|0);
    if ($12) {
     $26 = 0;
    } else {
     $13 = (($$pre$i$i$i4) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i4) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i4>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i4|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 33;
       break;
      }
      $24 = ($21|0)==(-1);
      if ($24) {
       HEAP32[$__b>>2] = 0;
       $26 = 0;
      } else {
       $26 = $$pre$i$i$i4;
      }
     } else {
      $26 = $$pre$i$i$i4;
     }
    }
    $25 = ($26|0)==(0|0);
    $27 = HEAP32[$__e>>2]|0;
    $28 = ($27|0)==(0|0);
    do {
     if ($28) {
      label = 17;
     } else {
      $29 = (($27) + 12|0);
      $30 = HEAP32[$29>>2]|0;
      $31 = (($27) + 16|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($30|0)==($32|0);
      if (!($33)) {
       if ($25) {
        $160 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
      $34 = HEAP32[$27>>2]|0;
      $35 = (($34) + 36|0);
      $36 = HEAP32[$35>>2]|0;
      __THREW__ = 0;
      $37 = (invoke_ii($36|0,($27|0))|0);
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 33;
       break L7;
      }
      $40 = ($37|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 17;
       break;
      } else {
       if ($25) {
        $160 = $27;
        break;
       } else {
        $$pre$i2$i$i = $27;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 17) {
     label = 0;
     if ($25) {
      $$pre$i2$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $160 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$9>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$9>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 33;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i19 = (($66) + -1)|0;
      $67 = $phitmp$i19;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 33;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi33Z2D;
     } else {
      $73 = HEAP32[$$pre$phi35Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($26) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = (($26) + 16|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($82|0)==($84|0);
    if ($85) {
     $86 = HEAP32[$26>>2]|0;
     $87 = (($86) + 36|0);
     $88 = HEAP32[$87>>2]|0;
     __THREW__ = 0;
     $89 = (invoke_ii($88|0,($26|0))|0);
     $90 = __THREW__; __THREW__ = 0;
     $91 = $90&1;
     if ($91) {
      label = 33;
      break;
     } else {
      $$0$i$i = $89;
     }
    } else {
     $92 = HEAP8[$82>>0]|0;
     $93 = $92&255;
     $$0$i$i = $93;
    }
    $94 = $$0$i$i&255;
    $95 = (__ZNSt3__19__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_($94,$__in_units,$__exp,$__a$1,$__a_end,$10,$11,$__grouping,$__g,$__g_end,$__dc,$__atoms)|0);
    $96 = ($95|0)==(0);
    if (!($96)) {
     $$pre$i2$i$i = $160;$__a$2 = $__a$1;
     break;
    }
    $97 = HEAP32[$81>>2]|0;
    $98 = HEAP32[$83>>2]|0;
    $99 = ($97|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$26>>2]|0;
     $101 = (($100) + 40|0);
     $102 = HEAP32[$101>>2]|0;
     __THREW__ = 0;
     (invoke_ii($102|0,($26|0))|0);
     $103 = __THREW__; __THREW__ = 0;
     $104 = $103&1;
     if ($104) {
      label = 33;
      break;
     } else {
      $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $105 = (($97) + 1|0);
     HEAP32[$81>>2] = $105;
     $$pre$i$i$i4 = $26;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 33) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $106 = HEAP8[$__grouping>>0]|0;
   $107 = $106 & 1;
   $108 = ($107<<24>>24)==(0);
   if ($108) {
    $111 = $106&255;
    $112 = $111 >>> 1;
    $114 = $112;
   } else {
    $109 = (($__grouping) + 4|0);
    $110 = HEAP32[$109>>2]|0;
    $114 = $110;
   }
   $113 = ($114|0)==(0);
   if (!($113)) {
    $115 = HEAP8[$__in_units>>0]|0;
    $116 = ($115<<24>>24)==(0);
    if (!($116)) {
     $117 = HEAP32[$__g_end>>2]|0;
     $118 = $117;
     $119 = $__g;
     $120 = (($118) - ($119))|0;
     $121 = ($120|0)<(160);
     if ($121) {
      $122 = HEAP32[$__dc>>2]|0;
      $123 = (($117) + 4|0);
      HEAP32[$__g_end>>2] = $123;
      HEAP32[$117>>2] = $122;
     }
    }
   }
   $124 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $125 = (+invoke_diii(8,($__a$2|0),($124|0),($__err|0)));
   $126 = __THREW__; __THREW__ = 0;
   $127 = $126&1;
   if (!($127)) {
    HEAPF64[$__v>>3] = $125;
    $128 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$128,$__err);
    $129 = ($26|0)==(0|0);
    if ($129) {
     $143 = 0;
    } else {
     $130 = (($26) + 12|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = (($26) + 16|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = ($131|0)==($133|0);
     if ($134) {
      $135 = HEAP32[$26>>2]|0;
      $136 = (($135) + 36|0);
      $137 = HEAP32[$136>>2]|0;
      __THREW__ = 0;
      $138 = (invoke_ii($137|0,($26|0))|0);
      $139 = __THREW__; __THREW__ = 0;
      $140 = $139&1;
      if ($140) {
       break;
      }
      $141 = ($138|0)==(-1);
      if ($141) {
       HEAP32[$__b>>2] = 0;
       $143 = 0;
      } else {
       $143 = $26;
      }
     } else {
      $143 = $26;
     }
    }
    $142 = ($143|0)==(0|0);
    $144 = ($$pre$i2$i$i|0)==(0|0);
    do {
     if ($144) {
      label = 62;
     } else {
      $145 = (($$pre$i2$i$i) + 12|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = (($$pre$i2$i$i) + 16|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = ($146|0)==($148|0);
      if (!($149)) {
       if (!($142)) {
        break;
       }
       HEAP32[$agg$result>>2] = $143;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
      $150 = HEAP32[$$pre$i2$i$i>>2]|0;
      $151 = (($150) + 36|0);
      $152 = HEAP32[$151>>2]|0;
      __THREW__ = 0;
      $153 = (invoke_ii($152|0,($$pre$i2$i$i|0))|0);
      $154 = __THREW__; __THREW__ = 0;
      $155 = $154&1;
      if ($155) {
       break L1;
      }
      $156 = ($153|0)==(-1);
      if ($156) {
       HEAP32[$__e>>2] = 0;
       label = 62;
       break;
      }
      $157 = ($$pre$i2$i$i|0)==(0|0);
      $tmp$i$i = $142 ^ $157;
      if ($tmp$i$i) {
       HEAP32[$agg$result>>2] = $143;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 62) {
     if (!($142)) {
      HEAP32[$agg$result>>2] = $143;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $158 = HEAP32[$__err>>2]|0;
    $159 = $158 | 2;
    HEAP32[$__err>>2] = $159;
    HEAP32[$agg$result>>2] = $143;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$01 = 0, $$pre = 0, $$pre$i$i$i8 = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre33 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0, $__g_end = 0;
 var $__grouping = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i22 = 0, $tmp$i$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $vararg_buffer = sp;
 $__atoms = sp + 208|0;
 $__grouping = sp + 184|0;
 $0 = sp + 180|0;
 $__buf = sp + 196|0;
 $__a_end = sp + 168|0;
 $__g = sp + 8|0;
 $__g_end = sp + 172|0;
 $__dc = sp + 176|0;
 ;HEAP32[$__grouping+0>>2]=0|0;HEAP32[$__grouping+4>>2]=0|0;HEAP32[$__grouping+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2475,($0|0),($__iob|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $87 = ___cxa_find_matching_catch()|0;
  $88 = tempRet0;
  $$0 = $87;$$01 = $88;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
  ___resumeException($$0|0);
  // unreachable;
 }
 __THREW__ = 0;
 $3 = (invoke_iii(2228,($0|0),(3093336|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = HEAP32[$3>>2]|0;
  $7 = (($6) + 32|0);
  $8 = HEAP32[$7>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($8|0,($3|0),(3091848|0),(((3091848 + 26|0))|0),($__atoms|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = HEAP32[$0>>2]|0;
   (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
   ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viii(2128,($__buf|0),10,0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   L8: do {
    if ($13) {
     label = 39;
    } else {
     $14 = HEAP8[$__buf>>0]|0;
     $15 = $14 & 1;
     $16 = ($15<<24>>24)==(0);
     if ($16) {
      $19 = (($__buf) + 1|0);
      $$pre35 = (($__buf) + 8|0);
      $$pre$phi34Z2D = $19;$$pre$phi36Z2D = $$pre35;$20 = $19;
     } else {
      $17 = (($__buf) + 8|0);
      $18 = HEAP32[$17>>2]|0;
      $$pre33 = (($__buf) + 1|0);
      $$pre$phi34Z2D = $$pre33;$$pre$phi36Z2D = $17;$20 = $18;
     }
     HEAP32[$__a_end>>2] = $20;
     HEAP32[$__g_end>>2] = $__g;
     HEAP32[$__dc>>2] = 0;
     $21 = (($__buf) + 4|0);
     $$pre = HEAP32[$__b>>2]|0;
     $$pre$i$i$i8 = $$pre;$__a$0 = $20;
     L14: while(1) {
      $22 = ($$pre$i$i$i8|0)==(0|0);
      if ($22) {
       $36 = 0;
      } else {
       $23 = (($$pre$i$i$i8) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($$pre$i$i$i8) + 16|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = ($24|0)==($26|0);
       if ($27) {
        $28 = HEAP32[$$pre$i$i$i8>>2]|0;
        $29 = (($28) + 36|0);
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        $31 = (invoke_ii($30|0,($$pre$i$i$i8|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         label = 38;
         break;
        }
        $34 = ($31|0)==(-1);
        if ($34) {
         HEAP32[$__b>>2] = 0;
         $36 = 0;
        } else {
         $36 = $$pre$i$i$i8;
        }
       } else {
        $36 = $$pre$i$i$i8;
       }
      }
      $35 = ($36|0)==(0|0);
      $37 = HEAP32[$__e>>2]|0;
      $38 = ($37|0)==(0|0);
      do {
       if ($38) {
        label = 20;
       } else {
        $39 = (($37) + 12|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = (($37) + 16|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = ($40|0)==($42|0);
        if (!($43)) {
         if ($35) {
          break;
         } else {
          $__a$2 = $__a$0;
          break L14;
         }
        }
        $44 = HEAP32[$37>>2]|0;
        $45 = (($44) + 36|0);
        $46 = HEAP32[$45>>2]|0;
        __THREW__ = 0;
        $47 = (invoke_ii($46|0,($37|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 38;
         break L14;
        }
        $50 = ($47|0)==(-1);
        if ($50) {
         HEAP32[$__e>>2] = 0;
         label = 20;
         break;
        } else {
         if ($35) {
          break;
         } else {
          $__a$2 = $__a$0;
          break L14;
         }
        }
       }
      } while(0);
      if ((label|0) == 20) {
       label = 0;
       if ($35) {
        $__a$2 = $__a$0;
        break;
       }
      }
      $51 = HEAP32[$__a_end>>2]|0;
      $52 = $51;
      $53 = $__a$0;
      $54 = (($52) - ($53))|0;
      $55 = HEAP8[$__buf>>0]|0;
      $56 = $55 & 1;
      $57 = ($56<<24>>24)==(0);
      if ($57) {
       $59 = $55&255;
       $60 = $59 >>> 1;
       $62 = $60;
      } else {
       $58 = HEAP32[$21>>2]|0;
       $62 = $58;
      }
      $61 = ($54|0)==($62|0);
      if ($61) {
       if ($57) {
        $64 = $55&255;
        $65 = $64 >>> 1;
        $66 = $55&255;
        $67 = $66 >>> 1;
        $69 = $67;$86 = $65;
       } else {
        $63 = HEAP32[$21>>2]|0;
        $69 = $63;$86 = $63;
       }
       $68 = $69 << 1;
       __THREW__ = 0;
       invoke_viii(2128,($__buf|0),($68|0),0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 38;
        break;
       }
       $72 = HEAP8[$__buf>>0]|0;
       $73 = $72 & 1;
       $74 = ($73<<24>>24)==(0);
       if ($74) {
        $77 = 10;
       } else {
        $75 = HEAP32[$__buf>>2]|0;
        $76 = $75 & -2;
        $phitmp$i22 = (($76) + -1)|0;
        $77 = $phitmp$i22;
       }
       __THREW__ = 0;
       invoke_viii(2128,($__buf|0),($77|0),0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 38;
        break;
       }
       $80 = HEAP8[$__buf>>0]|0;
       $81 = $80 & 1;
       $82 = ($81<<24>>24)==(0);
       if ($82) {
        $85 = $$pre$phi34Z2D;
       } else {
        $83 = HEAP32[$$pre$phi36Z2D>>2]|0;
        $85 = $83;
       }
       $84 = (($85) + ($86)|0);
       HEAP32[$__a_end>>2] = $84;
       $__a$1 = $85;
      } else {
       $__a$1 = $__a$0;
      }
      $96 = (($36) + 12|0);
      $97 = HEAP32[$96>>2]|0;
      $98 = (($36) + 16|0);
      $99 = HEAP32[$98>>2]|0;
      $100 = ($97|0)==($99|0);
      if ($100) {
       $101 = HEAP32[$36>>2]|0;
       $102 = (($101) + 36|0);
       $103 = HEAP32[$102>>2]|0;
       __THREW__ = 0;
       $104 = (invoke_ii($103|0,($36|0))|0);
       $105 = __THREW__; __THREW__ = 0;
       $106 = $105&1;
       if ($106) {
        label = 38;
        break;
       } else {
        $$0$i$i = $104;
       }
      } else {
       $107 = HEAP8[$97>>0]|0;
       $108 = $107&255;
       $$0$i$i = $108;
      }
      $109 = $$0$i$i&255;
      $110 = (__ZNSt3__19__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($109,16,$__a$1,$__a_end,$__dc,0,$__grouping,$__g,$__g_end,$__atoms)|0);
      $111 = ($110|0)==(0);
      if (!($111)) {
       $__a$2 = $__a$1;
       break;
      }
      $112 = HEAP32[$96>>2]|0;
      $113 = HEAP32[$98>>2]|0;
      $114 = ($112|0)==($113|0);
      if ($114) {
       $115 = HEAP32[$36>>2]|0;
       $116 = (($115) + 40|0);
       $117 = HEAP32[$116>>2]|0;
       __THREW__ = 0;
       (invoke_ii($117|0,($36|0))|0);
       $118 = __THREW__; __THREW__ = 0;
       $119 = $118&1;
       if ($119) {
        label = 38;
        break;
       } else {
        $$pre$i$i$i8 = $36;$__a$0 = $__a$1;
        continue;
       }
      } else {
       $120 = (($112) + 1|0);
       HEAP32[$96>>2] = $120;
       $$pre$i$i$i8 = $36;$__a$0 = $__a$1;
       continue;
      }
     }
     if ((label|0) == 38) {
      $92 = ___cxa_find_matching_catch()|0;
      $93 = tempRet0;
      $lpad$phi$index = $92;$lpad$phi$index2 = $93;
      break;
     }
     $121 = (($__a$2) + 3|0);
     HEAP8[$121>>0] = 0;
     __THREW__ = 0;
     $122 = (invoke_i(134)|0);
     $123 = __THREW__; __THREW__ = 0;
     $124 = $123&1;
     if ($124) {
      label = 39;
     } else {
      __THREW__ = 0;
      HEAP32[$vararg_buffer>>2] = $__v;
      $125 = (invoke_iiiii(341,($__a$2|0),($122|0),(3091888|0),($vararg_buffer|0))|0);
      $126 = __THREW__; __THREW__ = 0;
      $127 = $126&1;
      if ($127) {
       label = 39;
      } else {
       $128 = ($125|0)==(1);
       if (!($128)) {
        HEAP32[$__err>>2] = 4;
       }
       $129 = HEAP32[$__b>>2]|0;
       $130 = ($129|0)==(0|0);
       if ($130) {
        $144 = 0;
       } else {
        $131 = (($129) + 12|0);
        $132 = HEAP32[$131>>2]|0;
        $133 = (($129) + 16|0);
        $134 = HEAP32[$133>>2]|0;
        $135 = ($132|0)==($134|0);
        if ($135) {
         $136 = HEAP32[$129>>2]|0;
         $137 = (($136) + 36|0);
         $138 = HEAP32[$137>>2]|0;
         __THREW__ = 0;
         $139 = (invoke_ii($138|0,($129|0))|0);
         $140 = __THREW__; __THREW__ = 0;
         $141 = $140&1;
         if ($141) {
          label = 39;
          break;
         }
         $142 = ($139|0)==(-1);
         if ($142) {
          HEAP32[$__b>>2] = 0;
          $144 = 0;
         } else {
          $144 = $129;
         }
        } else {
         $144 = $129;
        }
       }
       $143 = ($144|0)==(0|0);
       $145 = HEAP32[$__e>>2]|0;
       $146 = ($145|0)==(0|0);
       do {
        if ($146) {
         label = 63;
        } else {
         $147 = (($145) + 12|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = (($145) + 16|0);
         $150 = HEAP32[$149>>2]|0;
         $151 = ($148|0)==($150|0);
         if (!($151)) {
          if (!($143)) {
           break;
          }
          HEAP32[$agg$result>>2] = $144;
          __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
          __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
          STACKTOP = sp;return;
         }
         $152 = HEAP32[$145>>2]|0;
         $153 = (($152) + 36|0);
         $154 = HEAP32[$153>>2]|0;
         __THREW__ = 0;
         $155 = (invoke_ii($154|0,($145|0))|0);
         $156 = __THREW__; __THREW__ = 0;
         $157 = $156&1;
         if ($157) {
          label = 39;
          break L8;
         }
         $158 = ($155|0)==(-1);
         if ($158) {
          HEAP32[$__e>>2] = 0;
          label = 63;
          break;
         }
         $159 = ($145|0)==(0|0);
         $tmp$i$i = $143 ^ $159;
         if ($tmp$i$i) {
          HEAP32[$agg$result>>2] = $144;
          __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
          __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
          STACKTOP = sp;return;
         }
        }
       } while(0);
       if ((label|0) == 63) {
        if (!($143)) {
         HEAP32[$agg$result>>2] = $144;
         __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
         __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
         STACKTOP = sp;return;
        }
       }
       $160 = HEAP32[$__err>>2]|0;
       $161 = $160 | 2;
       HEAP32[$__err>>2] = $161;
       HEAP32[$agg$result>>2] = $144;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    }
   } while(0);
   if ((label|0) == 39) {
    $94 = ___cxa_find_matching_catch()|0;
    $95 = tempRet0;
    $lpad$phi$index = $94;$lpad$phi$index2 = $95;
   }
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
   $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
   ___resumeException($$0|0);
   // unreachable;
  }
 }
 $89 = ___cxa_find_matching_catch()|0;
 $90 = tempRet0;
 $91 = HEAP32[$0>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($91)|0);
 $$0 = $89;$$01 = $90;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNSt3__19__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_S2_($__ct,$__base,$__a,$__a_end,$__dc,$__thousands_sep,$__grouping,$__g,$__g_end,$__atoms) {
 $__ct = $__ct|0;
 $__base = $__base|0;
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__dc = $__dc|0;
 $__thousands_sep = $__thousands_sep|0;
 $__grouping = $__grouping|0;
 $__g = $__g|0;
 $__g_end = $__g_end|0;
 $__atoms = $__atoms|0;
 var $$0 = 0, $$0$lcssa$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__a_end>>2]|0;
 $1 = ($0|0)==($__a|0);
 do {
  if ($1) {
   $2 = (($__atoms) + 24|0);
   $3 = HEAP8[$2>>0]|0;
   $4 = ($3<<24>>24)==($__ct<<24>>24);
   if (!($4)) {
    $5 = (($__atoms) + 25|0);
    $6 = HEAP8[$5>>0]|0;
    $7 = ($6<<24>>24)==($__ct<<24>>24);
    if (!($7)) {
     break;
    }
   }
   $8 = $4 ? 43 : 45;
   $9 = (($__a) + 1|0);
   HEAP32[$__a_end>>2] = $9;
   HEAP8[$__a>>0] = $8;
   HEAP32[$__dc>>2] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $10 = HEAP8[$__grouping>>0]|0;
 $11 = $10 & 1;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $15 = $10&255;
  $16 = $15 >>> 1;
  $18 = $16;
 } else {
  $13 = (($__grouping) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $18 = $14;
 }
 $17 = ($18|0)!=(0);
 $19 = ($__ct<<24>>24)==($__thousands_sep<<24>>24);
 $or$cond = $17 & $19;
 if ($or$cond) {
  $20 = HEAP32[$__g_end>>2]|0;
  $21 = $20;
  $22 = $__g;
  $23 = (($21) - ($22))|0;
  $24 = ($23|0)<(160);
  if (!($24)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $25 = HEAP32[$__dc>>2]|0;
  $26 = (($20) + 4|0);
  HEAP32[$__g_end>>2] = $26;
  HEAP32[$20>>2] = $25;
  HEAP32[$__dc>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = (($__atoms) + 26|0);
 $$01$i = $__atoms;
 while(1) {
  $30 = HEAP8[$$01$i>>0]|0;
  $31 = ($30<<24>>24)==($__ct<<24>>24);
  $29 = (($$01$i) + 1|0);
  if ($31) {
   $$0$lcssa$i = $$01$i;
   break;
  }
  $28 = ($29|0)==($27|0);
  if ($28) {
   $$0$lcssa$i = $27;
   break;
  } else {
   $$01$i = $29;
  }
 }
 $32 = $$0$lcssa$i;
 $33 = $__atoms;
 $34 = (($32) - ($33))|0;
 $35 = ($34|0)>(23);
 if ($35) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 if ((($__base|0) == 10) | (($__base|0) == 8)) {
  $36 = ($34|0)<($__base|0);
  if (!($36)) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } else if ((($__base|0) == 16)) {
  $37 = ($34|0)<(22);
  if (!($37)) {
   if ($1) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $38 = $0;
   $39 = $__a;
   $40 = (($38) - ($39))|0;
   $41 = ($40|0)<(3);
   if (!($41)) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $42 = (($0) + -1|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = ($43<<24>>24)==(48);
   if (!($44)) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__dc>>2] = 0;
   $45 = (3091848 + ($34)|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = (($0) + 1|0);
   HEAP32[$__a_end>>2] = $47;
   HEAP8[$0>>0] = $46;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $48 = (3091848 + ($34)|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = (($0) + 1|0);
 HEAP32[$__a_end>>2] = $50;
 HEAP8[$0>>0] = $49;
 $51 = HEAP32[$__dc>>2]|0;
 $52 = (($51) + 1)|0;
 HEAP32[$__dc>>2] = $52;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__110__sscanf_lEPKcP15__locale_structS1_z($__s,$__l,$__format,$varargs) {
 $__s = $__s|0;
 $__l = $__l|0;
 $__format = $__format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $__va = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__va = sp;
 HEAP32[$__va>>2] = $varargs;
 $0 = (_uselocale(($__l|0))|0);
 $1 = (_vsscanf($__s,$__format,$__va)|0);
 $2 = ($0|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return ($1|0);
 }
 __THREW__ = 0;
 (invoke_ii(3483,($0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch(0|0)|0;
  $6 = tempRet0;
  ___clang_call_terminate($5);
  // unreachable;
 } else {
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZNSt3__16__clocEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093232>>0]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   $2 = (___cxa_guard_acquire((3093232|0))|0);
   $3 = ($2|0)==(0);
   if (!($3)) {
    __THREW__ = 0;
    $4 = (invoke_iiii(1682,2147483647,(3093240|0),(0|0))|0);
    $5 = __THREW__; __THREW__ = 0;
    $6 = $5&1;
    if ($6) {
     $8 = ___cxa_find_matching_catch()|0;
     $9 = tempRet0;
     ___cxa_guard_abort((3093232|0));
     ___resumeException($8|0);
     // unreachable;
    } else {
     HEAP32[3093224>>2] = $4;
     ___cxa_guard_release((3093232|0));
     break;
    }
   }
  }
 } while(0);
 $7 = HEAP32[3093224>>2]|0;
 STACKTOP = sp;return ($7|0);
}
function __ZNSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$byval_copy = 0, $$byval_copy2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__lv = 0, $__names = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy2 = sp + 56|0;
 $$byval_copy = sp + 52|0;
 $__lv = sp + 48|0;
 $0 = sp + 44|0;
 $1 = sp + 40|0;
 $2 = sp + 36|0;
 $3 = sp + 28|0;
 $4 = sp + 24|0;
 $__names = sp;
 $5 = sp + 32|0;
 $6 = (($__iob) + 4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 1;
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$__lv>>2] = -1;
  $10 = HEAP32[$this>>2]|0;
  $11 = (($10) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$__b>>2]|0;
  HEAP32[$1>>2] = $13;
  $14 = HEAP32[$__e>>2]|0;
  HEAP32[$2>>2] = $14;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$2+0>>2]|0;
  FUNCTION_TABLE_viiiiiii[$12 & 127]($0,$this,$$byval_copy,$$byval_copy2,$__iob,$__err,$__lv);
  $15 = HEAP32[$0>>2]|0;
  HEAP32[$__b>>2] = $15;
  $16 = HEAP32[$__lv>>2]|0;
  if ((($16|0) == 0)) {
   HEAP8[$__v>>0] = 0;
  } else if ((($16|0) == 1)) {
   HEAP8[$__v>>0] = 1;
  } else {
   HEAP8[$__v>>0] = 1;
   HEAP32[$__err>>2] = 4;
  }
  HEAP32[$agg$result>>2] = $15;
  STACKTOP = sp;return;
 }
 __ZNKSt3__18ios_base6getlocEv($3,$__iob);
 __THREW__ = 0;
 $17 = (invoke_iii(2228,($3|0),(3093328|0))|0);
 $18 = __THREW__; __THREW__ = 0;
 $19 = $18&1;
 if ($19) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  $47 = HEAP32[$3>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($47)|0);
  $$0 = $45;$$01 = $46;
  ___resumeException($$0|0);
  // unreachable;
 }
 $20 = HEAP32[$3>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($20)|0);
 __ZNKSt3__18ios_base6getlocEv($4,$__iob);
 __THREW__ = 0;
 $21 = (invoke_iii(2228,($4|0),(3093488|0))|0);
 $22 = __THREW__; __THREW__ = 0;
 $23 = $22&1;
 if ($23) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $50 = HEAP32[$4>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($50)|0);
  $$0 = $48;$$01 = $49;
  ___resumeException($$0|0);
  // unreachable;
 }
 $24 = HEAP32[$4>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($24)|0);
 $25 = HEAP32[$21>>2]|0;
 $26 = (($25) + 24|0);
 $27 = HEAP32[$26>>2]|0;
 __THREW__ = 0;
 invoke_vii($27|0,($__names|0),($21|0));
 $28 = __THREW__; __THREW__ = 0;
 $29 = $28&1;
 if ($29) {
  $$02 = $__names;
 } else {
  $30 = (($__names) + 12|0);
  $31 = HEAP32[$21>>2]|0;
  $32 = (($31) + 28|0);
  $33 = HEAP32[$32>>2]|0;
  __THREW__ = 0;
  invoke_vii($33|0,($30|0),($21|0));
  $34 = __THREW__; __THREW__ = 0;
  $35 = $34&1;
  if ($35) {
   $$02 = $30;
  } else {
   $36 = HEAP32[$__e>>2]|0;
   HEAP32[$5>>2] = $36;
   $37 = (($__names) + 24|0);
   __THREW__ = 0;
   ;HEAP32[$$byval_copy2+0>>2]=HEAP32[$5+0>>2]|0;
   $38 = (invoke_iiiiiiii(124,($__b|0),($$byval_copy2|0),($__names|0),($37|0),($17|0),($__err|0),1)|0);
   $39 = __THREW__; __THREW__ = 0;
   $40 = $39&1;
   if ($40) {
    $57 = ___cxa_find_matching_catch()|0;
    $58 = tempRet0;
    $59 = (($__names) + 12|0);
    __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($59);
    __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__names);
    $$0 = $57;$$01 = $58;
    ___resumeException($$0|0);
    // unreachable;
   } else {
    $41 = ($38|0)==($__names|0);
    $42 = $41&1;
    HEAP8[$__v>>0] = $42;
    $43 = HEAP32[$__b>>2]|0;
    HEAP32[$agg$result>>2] = $43;
    $44 = (($__names) + 12|0);
    __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($44);
    __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__names);
    STACKTOP = sp;return;
   }
  }
 }
 $51 = ___cxa_find_matching_catch()|0;
 $52 = tempRet0;
 $53 = ($__names|0)==($$02|0);
 if ($53) {
  $$0 = $51;$$01 = $52;
  ___resumeException($$0|0);
  // unreachable;
 } else {
  $55 = $$02;
 }
 while(1) {
  $54 = (($55) + -12|0);
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($54);
  $56 = ($54|0)==($__names|0);
  if ($56) {
   $$0 = $51;$$01 = $52;
   break;
  } else {
   $55 = $54;
  }
 }
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb($__b,$__e,$__kb,$__ke,$__ct,$__err,$__case_sensitive) {
 $__b = $__b|0;
 $__e = $__e|0;
 $__kb = $__kb|0;
 $__ke = $__ke|0;
 $__ct = $__ct|0;
 $__err = $__err|0;
 $__case_sensitive = $__case_sensitive|0;
 var $$ = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i11 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i17 = 0, $$028 = 0, $$03078 = 0, $$index = 0, $$index10 = 0, $$not = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i13 = 0, $$pre$i3$i$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__c$0 = 0, $__consume$0$off039 = 0, $__consume$1$off0 = 0, $__indx$0 = 0, $__kc$0 = 0, $__ky$066 = 0, $__ky1$040 = 0, $__ky2$051 = 0, $__n_does_match$0$lcssa = 0;
 var $__n_does_match$064 = 0, $__n_does_match$1 = 0, $__n_does_match$2 = 0, $__n_does_match$2$phi = 0, $__n_does_match$336 = 0, $__n_does_match$4 = 0, $__n_does_match$549 = 0, $__n_does_match$6 = 0, $__n_might_match$0$lcssa = 0, $__n_might_match$063 = 0, $__n_might_match$1 = 0, $__n_might_match$2 = 0, $__n_might_match$2$phi = 0, $__n_might_match$335 = 0, $__n_might_match$4 = 0, $__st$065 = 0, $__st$137 = 0, $__st$250 = 0, $__st$32979 = 0, $__statbuf = 0;
 var $__status$0 = 0, $lpad$phi$index = 0, $lpad$phi$index3 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i14 = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $__statbuf = sp;
 $0 = $__ke;
 $1 = $__kb;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 12)&-1;
 $4 = ($3>>>0)>(100);
 if ($4) {
  $5 = (_malloc($3)|0);
  $6 = ($5|0)==(0|0);
  if ($6) {
   __THREW__ = 0;
   invoke_v(1012);
   $7 = __THREW__; __THREW__ = 0;
   $8 = $7&1;
   if ($8) {
    $9 = ___cxa_find_matching_catch()|0;
    $10 = tempRet0;
    $$index = $9;$$index10 = $10;
    ___resumeException($$index|0);
    // unreachable;
   } else {
    $18 = 0;$__status$0 = 0;
   }
  } else {
   $18 = $5;$__status$0 = $5;
  }
 } else {
  $18 = 0;$__status$0 = $__statbuf;
 }
 $23 = ($__kb|0)==($__ke|0);
 if ($23) {
  $__n_does_match$0$lcssa = 0;$__n_might_match$0$lcssa = $3;
 } else {
  $__ky$066 = $__kb;$__n_does_match$064 = 0;$__n_might_match$063 = $3;$__st$065 = $__status$0;
  while(1) {
   $24 = HEAP8[$__ky$066>>0]|0;
   $25 = $24 & 1;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    $29 = $24&255;
    $30 = $29 >>> 1;
    $32 = $30;
   } else {
    $27 = (($__ky$066) + 4|0);
    $28 = HEAP32[$27>>2]|0;
    $32 = $28;
   }
   $31 = ($32|0)==(0);
   if ($31) {
    HEAP8[$__st$065>>0] = 2;
    $33 = (($__n_might_match$063) + -1)|0;
    $34 = (($__n_does_match$064) + 1)|0;
    $__n_does_match$1 = $34;$__n_might_match$1 = $33;
   } else {
    HEAP8[$__st$065>>0] = 1;
    $__n_does_match$1 = $__n_does_match$064;$__n_might_match$1 = $__n_might_match$063;
   }
   $35 = (($__ky$066) + 12|0);
   $36 = (($__st$065) + 1|0);
   $37 = ($35|0)==($__ke|0);
   if ($37) {
    $__n_does_match$0$lcssa = $__n_does_match$1;$__n_might_match$0$lcssa = $__n_might_match$1;
    break;
   } else {
    $__ky$066 = $35;$__n_does_match$064 = $__n_does_match$1;$__n_might_match$063 = $__n_might_match$1;$__st$065 = $36;
   }
  }
 }
 $__indx$0 = 0;$__n_does_match$2 = $__n_does_match$0$lcssa;$__n_might_match$2 = $__n_might_match$0$lcssa;
 L19: while(1) {
  $38 = HEAP32[$__b>>2]|0;
  $39 = ($38|0)==(0|0);
  do {
   if ($39) {
    $68 = 1;
   } else {
    $40 = (($38) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = (($38) + 16|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = ($41|0)==($43|0);
    if ($44) {
     $45 = HEAP32[$38>>2]|0;
     $46 = (($45) + 36|0);
     $47 = HEAP32[$46>>2]|0;
     __THREW__ = 0;
     $48 = (invoke_ii($47|0,($38|0))|0);
     $49 = __THREW__; __THREW__ = 0;
     $50 = $49&1;
     if ($50) {
      label = 6;
      break L19;
     } else {
      $$0$i$i$i$i = $48;
     }
    } else {
     $51 = HEAP32[$41>>2]|0;
     $$0$i$i$i$i = $51;
    }
    $52 = ($$0$i$i$i$i|0)==(-1);
    if ($52) {
     HEAP32[$__b>>2] = 0;
     $68 = 1;
     break;
    } else {
     $$pre$i$i$i = HEAP32[$__b>>2]|0;
     $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
     $68 = $phitmp$i$i$i;
     break;
    }
   }
  } while(0);
  $53 = HEAP32[$__e>>2]|0;
  $54 = ($53|0)==(0|0);
  if ($54) {
   $$pre$i3$i$i19 = 0;$69 = 1;
  } else {
   $55 = (($53) + 12|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = (($53) + 16|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($56|0)==($58|0);
   if ($59) {
    $60 = HEAP32[$53>>2]|0;
    $61 = (($60) + 36|0);
    $62 = HEAP32[$61>>2]|0;
    __THREW__ = 0;
    $63 = (invoke_ii($62|0,($53|0))|0);
    $64 = __THREW__; __THREW__ = 0;
    $65 = $64&1;
    if ($65) {
     label = 6;
     break;
    } else {
     $$0$i$i1$i$i = $63;
    }
   } else {
    $66 = HEAP32[$56>>2]|0;
    $$0$i$i1$i$i = $66;
   }
   $67 = ($$0$i$i1$i$i|0)==(-1);
   if ($67) {
    HEAP32[$__e>>2] = 0;
    $$pre$i3$i$i19 = 0;$69 = 1;
   } else {
    $$pre$i3$i$i19 = $53;$69 = 0;
   }
  }
  $tmp$i$i = $68 ^ $69;
  $70 = ($__n_might_match$2|0)!=(0);
  $$ = $tmp$i$i & $70;
  $71 = HEAP32[$__b>>2]|0;
  if (!($$)) {
   label = 68;
   break;
  }
  $72 = (($71) + 12|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($71) + 16|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ($73|0)==($75|0);
  if ($76) {
   $77 = HEAP32[$71>>2]|0;
   $78 = (($77) + 36|0);
   $79 = HEAP32[$78>>2]|0;
   __THREW__ = 0;
   $80 = (invoke_ii($79|0,($71|0))|0);
   $81 = __THREW__; __THREW__ = 0;
   $82 = $81&1;
   if ($82) {
    label = 6;
    break;
   } else {
    $$0$i$i = $80;
   }
  } else {
   $83 = HEAP32[$73>>2]|0;
   $$0$i$i = $83;
  }
  if ($__case_sensitive) {
   $__c$0 = $$0$i$i;
  } else {
   $84 = HEAP32[$__ct>>2]|0;
   $85 = (($84) + 28|0);
   $86 = HEAP32[$85>>2]|0;
   __THREW__ = 0;
   $87 = (invoke_iii($86|0,($__ct|0),($$0$i$i|0))|0);
   $88 = __THREW__; __THREW__ = 0;
   $89 = $88&1;
   if ($89) {
    label = 6;
    break;
   } else {
    $__c$0 = $87;
   }
  }
  $$pre = (($__indx$0) + 1)|0;
  if ($23) {
   $__n_might_match$2$phi = $__n_might_match$2;$__n_does_match$2$phi = $__n_does_match$2;$__indx$0 = $$pre;$__n_might_match$2 = $__n_might_match$2$phi;$__n_does_match$2 = $__n_does_match$2$phi;
   continue;
  } else {
   $__consume$0$off039 = 0;$__ky1$040 = $__kb;$__n_does_match$336 = $__n_does_match$2;$__n_might_match$335 = $__n_might_match$2;$__st$137 = $__status$0;
  }
  while(1) {
   $90 = HEAP8[$__st$137>>0]|0;
   $91 = ($90<<24>>24)==(1);
   do {
    if ($91) {
     $92 = HEAP8[$__ky1$040>>0]|0;
     $93 = $92 & 1;
     $94 = ($93<<24>>24)==(0);
     if ($94) {
      $97 = (($__ky1$040) + 4|0);
      $99 = $97;
     } else {
      $95 = (($__ky1$040) + 8|0);
      $96 = HEAP32[$95>>2]|0;
      $99 = $96;
     }
     $98 = (($99) + ($__indx$0<<2)|0);
     $100 = HEAP32[$98>>2]|0;
     if ($__case_sensitive) {
      $__kc$0 = $100;
     } else {
      $101 = HEAP32[$__ct>>2]|0;
      $102 = (($101) + 28|0);
      $103 = HEAP32[$102>>2]|0;
      __THREW__ = 0;
      $104 = (invoke_iii($103|0,($__ct|0),($100|0))|0);
      $105 = __THREW__; __THREW__ = 0;
      $106 = $105&1;
      if ($106) {
       label = 5;
       break L19;
      } else {
       $__kc$0 = $104;
      }
     }
     $107 = ($__c$0|0)==($__kc$0|0);
     if (!($107)) {
      HEAP8[$__st$137>>0] = 0;
      $119 = (($__n_might_match$335) + -1)|0;
      $__consume$1$off0 = $__consume$0$off039;$__n_does_match$4 = $__n_does_match$336;$__n_might_match$4 = $119;
      break;
     }
     $108 = HEAP8[$__ky1$040>>0]|0;
     $109 = $108 & 1;
     $110 = ($109<<24>>24)==(0);
     if ($110) {
      $113 = $108&255;
      $114 = $113 >>> 1;
      $116 = $114;
     } else {
      $111 = (($__ky1$040) + 4|0);
      $112 = HEAP32[$111>>2]|0;
      $116 = $112;
     }
     $115 = ($116|0)==($$pre|0);
     if ($115) {
      HEAP8[$__st$137>>0] = 2;
      $117 = (($__n_might_match$335) + -1)|0;
      $118 = (($__n_does_match$336) + 1)|0;
      $__consume$1$off0 = 1;$__n_does_match$4 = $118;$__n_might_match$4 = $117;
     } else {
      $__consume$1$off0 = 1;$__n_does_match$4 = $__n_does_match$336;$__n_might_match$4 = $__n_might_match$335;
     }
    } else {
     $__consume$1$off0 = $__consume$0$off039;$__n_does_match$4 = $__n_does_match$336;$__n_might_match$4 = $__n_might_match$335;
    }
   } while(0);
   $120 = (($__ky1$040) + 12|0);
   $121 = ($120|0)==($__ke|0);
   if ($121) {
    break;
   }
   $122 = (($__st$137) + 1|0);
   $__consume$0$off039 = $__consume$1$off0;$__ky1$040 = $120;$__n_does_match$336 = $__n_does_match$4;$__n_might_match$335 = $__n_might_match$4;$__st$137 = $122;
  }
  if (!($__consume$1$off0)) {
   $__indx$0 = $$pre;$__n_does_match$2 = $__n_does_match$4;$__n_might_match$2 = $__n_might_match$4;
   continue;
  }
  $123 = HEAP32[$__b>>2]|0;
  $124 = (($123) + 12|0);
  $125 = HEAP32[$124>>2]|0;
  $126 = (($123) + 16|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = ($125|0)==($127|0);
  if ($128) {
   $129 = HEAP32[$123>>2]|0;
   $130 = (($129) + 40|0);
   $131 = HEAP32[$130>>2]|0;
   __THREW__ = 0;
   (invoke_ii($131|0,($123|0))|0);
   $132 = __THREW__; __THREW__ = 0;
   $133 = $132&1;
   if ($133) {
    label = 6;
    break;
   }
  } else {
   $134 = (($125) + 4|0);
   HEAP32[$124>>2] = $134;
  }
  $135 = (($__n_does_match$4) + ($__n_might_match$4))|0;
  $$not = ($135>>>0)<(2);
  if ($$not) {
   $__indx$0 = $$pre;$__n_does_match$2 = $__n_does_match$4;$__n_might_match$2 = $__n_might_match$4;
   continue;
  } else {
   $__ky2$051 = $__kb;$__n_does_match$549 = $__n_does_match$4;$__st$250 = $__status$0;
  }
  while(1) {
   $136 = HEAP8[$__st$250>>0]|0;
   $137 = ($136<<24>>24)==(2);
   if ($137) {
    $138 = HEAP8[$__ky2$051>>0]|0;
    $139 = $138 & 1;
    $140 = ($139<<24>>24)==(0);
    if ($140) {
     $143 = $138&255;
     $144 = $143 >>> 1;
     $146 = $144;
    } else {
     $141 = (($__ky2$051) + 4|0);
     $142 = HEAP32[$141>>2]|0;
     $146 = $142;
    }
    $145 = ($146|0)==($$pre|0);
    if ($145) {
     $__n_does_match$6 = $__n_does_match$549;
    } else {
     HEAP8[$__st$250>>0] = 0;
     $147 = (($__n_does_match$549) + -1)|0;
     $__n_does_match$6 = $147;
    }
   } else {
    $__n_does_match$6 = $__n_does_match$549;
   }
   $148 = (($__ky2$051) + 12|0);
   $149 = (($__st$250) + 1|0);
   $150 = ($148|0)==($__ke|0);
   if ($150) {
    $__indx$0 = $$pre;$__n_does_match$2 = $__n_does_match$6;$__n_might_match$2 = $__n_might_match$4;
    continue L19;
   } else {
    $__ky2$051 = $148;$__n_does_match$549 = $__n_does_match$6;$__st$250 = $149;
   }
  }
 }
 if ((label|0) == 5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $lpad$phi$index = $11;$lpad$phi$index3 = $12;
 }
 else if ((label|0) == 6) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $lpad$phi$index = $13;$lpad$phi$index3 = $14;
 }
 else if ((label|0) == 68) {
  $151 = ($71|0)==(0|0);
  do {
   if ($151) {
    $195 = 1;
    label = 75;
   } else {
    $152 = (($71) + 12|0);
    $153 = HEAP32[$152>>2]|0;
    $154 = (($71) + 16|0);
    $155 = HEAP32[$154>>2]|0;
    $156 = ($153|0)==($155|0);
    if ($156) {
     $157 = HEAP32[$71>>2]|0;
     $158 = (($157) + 36|0);
     $159 = HEAP32[$158>>2]|0;
     __THREW__ = 0;
     $160 = (invoke_ii($159|0,($71|0))|0);
     $161 = __THREW__; __THREW__ = 0;
     $162 = $161&1;
     if ($162) {
      break;
     } else {
      $$0$i$i$i$i11 = $160;
     }
    } else {
     $163 = HEAP32[$153>>2]|0;
     $$0$i$i$i$i11 = $163;
    }
    $164 = ($$0$i$i$i$i11|0)==(-1);
    if ($164) {
     HEAP32[$__b>>2] = 0;
     $195 = 1;
     label = 75;
     break;
    } else {
     $$pre$i$i$i13 = HEAP32[$__b>>2]|0;
     $phitmp$i$i$i14 = ($$pre$i$i$i13|0)==(0|0);
     $195 = $phitmp$i$i$i14;
     label = 75;
     break;
    }
   }
  } while(0);
  L97: do {
   if ((label|0) == 75) {
    $165 = ($$pre$i3$i$i19|0)==(0|0);
    do {
     if ($165) {
      label = 81;
     } else {
      $166 = (($$pre$i3$i$i19) + 12|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = (($$pre$i3$i$i19) + 16|0);
      $169 = HEAP32[$168>>2]|0;
      $170 = ($167|0)==($169|0);
      if ($170) {
       $171 = HEAP32[$$pre$i3$i$i19>>2]|0;
       $172 = (($171) + 36|0);
       $173 = HEAP32[$172>>2]|0;
       __THREW__ = 0;
       $174 = (invoke_ii($173|0,($$pre$i3$i$i19|0))|0);
       $175 = __THREW__; __THREW__ = 0;
       $176 = $175&1;
       if ($176) {
        break L97;
       } else {
        $$0$i$i1$i$i17 = $174;
       }
      } else {
       $177 = HEAP32[$167>>2]|0;
       $$0$i$i1$i$i17 = $177;
      }
      $178 = ($$0$i$i1$i$i17|0)==(-1);
      if ($178) {
       HEAP32[$__e>>2] = 0;
       label = 81;
       break;
      } else {
       if ($195) {
        break;
       } else {
        label = 83;
        break;
       }
      }
     }
    } while(0);
    if ((label|0) == 81) {
     if ($195) {
      label = 83;
     }
    }
    if ((label|0) == 83) {
     $179 = HEAP32[$__err>>2]|0;
     $180 = $179 | 2;
     HEAP32[$__err>>2] = $180;
    }
    L113: do {
     if ($23) {
      label = 88;
     } else {
      $181 = HEAP8[$__status$0>>0]|0;
      $182 = ($181<<24>>24)==(2);
      if ($182) {
       $$028 = $__kb;
      } else {
       $$03078 = $__kb;$__st$32979 = $__status$0;
       while(1) {
        $186 = (($$03078) + 12|0);
        $187 = ($186|0)==($__ke|0);
        $184 = (($__st$32979) + 1|0);
        if ($187) {
         label = 88;
         break L113;
        }
        $183 = HEAP8[$184>>0]|0;
        $185 = ($183<<24>>24)==(2);
        if ($185) {
         $$028 = $186;
         break;
        } else {
         $$03078 = $186;$__st$32979 = $184;
        }
       }
      }
     }
    } while(0);
    if ((label|0) == 88) {
     $188 = HEAP32[$__err>>2]|0;
     $189 = $188 | 4;
     HEAP32[$__err>>2] = $189;
     $$028 = $__ke;
    }
    $190 = ($18|0)==(0|0);
    if ($190) {
     STACKTOP = sp;return ($$028|0);
    }
    __THREW__ = 0;
    invoke_vi(3853,($18|0));
    $191 = __THREW__; __THREW__ = 0;
    $192 = $191&1;
    if ($192) {
     $193 = ___cxa_find_matching_catch(0|0)|0;
     $194 = tempRet0;
     ___clang_call_terminate($193);
     // unreachable;
    } else {
     STACKTOP = sp;return ($$028|0);
    }
   }
  } while(0);
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $lpad$phi$index = $15;$lpad$phi$index3 = $16;
 }
 $17 = ($18|0)==(0|0);
 if ($17) {
  $$index = $lpad$phi$index;$$index10 = $lpad$phi$index3;
  ___resumeException($$index|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3853,($18|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $21 = ___cxa_find_matching_catch(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 } else {
  $$index = $lpad$phi$index;$$index10 = $lpad$phi$index3;
  ___resumeException($$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre33 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0;
 var $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $__atoms = sp + 200|0;
 $__thousands_sep = sp;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp + 192|0;
 $__dc = sp + 196|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre35 = (($__buf) + 8|0);
    $$pre$phi34Z2D = $8;$$pre$phi36Z2D = $$pre35;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre33 = (($__buf) + 1|0);
    $$pre$phi34Z2D = $$pre33;$$pre$phi36Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $157 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $157 = 1;$82 = 0;
     } else {
      $157 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($157) {
        $158 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($157) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $158 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi34Z2D;
     } else {
      $73 = HEAP32[$$pre$phi36Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($$0$i$i,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $158;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP32[$__g_end>>2]|0;
    $115 = $114;
    $116 = $__g;
    $117 = (($115) - ($116))|0;
    $118 = ($117|0)<(160);
    if ($118) {
     $119 = HEAP32[$__dc>>2]|0;
     $120 = (($114) + 4|0);
     HEAP32[$__g_end>>2] = $120;
     HEAP32[$114>>2] = $119;
    }
   }
   $121 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $122 = (invoke_iiiii(335,($__a$2|0),($121|0),($__err|0),($0|0))|0);
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if (!($124)) {
    HEAP32[$__v>>2] = $122;
    $125 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$125,$__err);
    $126 = ($82|0)==(0|0);
    if ($126) {
     $156 = 0;$159 = 1;
    } else {
     $127 = (($82) + 12|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = (($82) + 16|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($128|0)==($130|0);
     if ($131) {
      $132 = HEAP32[$82>>2]|0;
      $133 = (($132) + 36|0);
      $134 = HEAP32[$133>>2]|0;
      __THREW__ = 0;
      $135 = (invoke_ii($134|0,($82|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break;
      } else {
       $$0$i$i$i$i = $135;
      }
     } else {
      $138 = HEAP32[$128>>2]|0;
      $$0$i$i$i$i = $138;
     }
     $139 = ($$0$i$i$i$i|0)==(-1);
     if ($139) {
      HEAP32[$__b>>2] = 0;
      $156 = 0;$159 = 1;
     } else {
      $156 = $82;$159 = 0;
     }
    }
    $140 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($140) {
      label = 63;
     } else {
      $141 = (($$pre$i3$i$i) + 12|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = (($$pre$i3$i$i) + 16|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = ($142|0)==($144|0);
      if ($145) {
       $146 = HEAP32[$$pre$i3$i$i>>2]|0;
       $147 = (($146) + 36|0);
       $148 = HEAP32[$147>>2]|0;
       __THREW__ = 0;
       $149 = (invoke_ii($148|0,($$pre$i3$i$i|0))|0);
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        break L1;
       } else {
        $$0$i$i1$i$i = $149;
       }
      } else {
       $152 = HEAP32[$142>>2]|0;
       $$0$i$i1$i$i = $152;
      }
      $153 = ($$0$i$i1$i$i|0)==(-1);
      if ($153) {
       HEAP32[$__e>>2] = 0;
       label = 63;
       break;
      }
      if ($159) {
       HEAP32[$agg$result>>2] = $156;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 63) {
     if (!($159)) {
      HEAP32[$agg$result>>2] = $156;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $154 = HEAP32[$__err>>2]|0;
    $155 = $154 | 2;
    HEAP32[$__err>>2] = $155;
    HEAP32[$agg$result>>2] = $156;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre33 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0;
 var $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $__atoms = sp + 200|0;
 $__thousands_sep = sp;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp + 192|0;
 $__dc = sp + 196|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre35 = (($__buf) + 8|0);
    $$pre$phi34Z2D = $8;$$pre$phi36Z2D = $$pre35;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre33 = (($__buf) + 1|0);
    $$pre$phi34Z2D = $$pre33;$$pre$phi36Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $162 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $162 = 1;$82 = 0;
     } else {
      $162 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($162) {
        $163 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($162) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $163 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi34Z2D;
     } else {
      $73 = HEAP32[$$pre$phi36Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($$0$i$i,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $163;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP32[$__g_end>>2]|0;
    $115 = $114;
    $116 = $__g;
    $117 = (($115) - ($116))|0;
    $118 = ($117|0)<(160);
    if ($118) {
     $119 = HEAP32[$__dc>>2]|0;
     $120 = (($114) + 4|0);
     HEAP32[$__g_end>>2] = $120;
     HEAP32[$114>>2] = $119;
    }
   }
   $121 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $122 = (invoke_iiiii(336,($__a$2|0),($121|0),($__err|0),($0|0))|0);
   $123 = tempRet0;
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if (!($125)) {
    $126 = $__v;
    $127 = $126;
    HEAP32[$127>>2] = $122;
    $128 = (($126) + 4)|0;
    $129 = $128;
    HEAP32[$129>>2] = $123;
    $130 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$130,$__err);
    $131 = ($82|0)==(0|0);
    if ($131) {
     $161 = 0;$164 = 1;
    } else {
     $132 = (($82) + 12|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = (($82) + 16|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($133|0)==($135|0);
     if ($136) {
      $137 = HEAP32[$82>>2]|0;
      $138 = (($137) + 36|0);
      $139 = HEAP32[$138>>2]|0;
      __THREW__ = 0;
      $140 = (invoke_ii($139|0,($82|0))|0);
      $141 = __THREW__; __THREW__ = 0;
      $142 = $141&1;
      if ($142) {
       break;
      } else {
       $$0$i$i$i$i = $140;
      }
     } else {
      $143 = HEAP32[$133>>2]|0;
      $$0$i$i$i$i = $143;
     }
     $144 = ($$0$i$i$i$i|0)==(-1);
     if ($144) {
      HEAP32[$__b>>2] = 0;
      $161 = 0;$164 = 1;
     } else {
      $161 = $82;$164 = 0;
     }
    }
    $145 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($145) {
      label = 63;
     } else {
      $146 = (($$pre$i3$i$i) + 12|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = (($$pre$i3$i$i) + 16|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = ($147|0)==($149|0);
      if ($150) {
       $151 = HEAP32[$$pre$i3$i$i>>2]|0;
       $152 = (($151) + 36|0);
       $153 = HEAP32[$152>>2]|0;
       __THREW__ = 0;
       $154 = (invoke_ii($153|0,($$pre$i3$i$i|0))|0);
       $155 = __THREW__; __THREW__ = 0;
       $156 = $155&1;
       if ($156) {
        break L1;
       } else {
        $$0$i$i1$i$i = $154;
       }
      } else {
       $157 = HEAP32[$147>>2]|0;
       $$0$i$i1$i$i = $157;
      }
      $158 = ($$0$i$i1$i$i|0)==(-1);
      if ($158) {
       HEAP32[$__e>>2] = 0;
       label = 63;
       break;
      }
      if ($164) {
       HEAP32[$agg$result>>2] = $161;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 63) {
     if (!($164)) {
      HEAP32[$agg$result>>2] = $161;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $159 = HEAP32[$__err>>2]|0;
    $160 = $159 | 2;
    HEAP32[$__err>>2] = $160;
    HEAP32[$agg$result>>2] = $161;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre33 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0;
 var $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $__atoms = sp + 200|0;
 $__thousands_sep = sp;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp + 192|0;
 $__dc = sp + 196|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre35 = (($__buf) + 8|0);
    $$pre$phi34Z2D = $8;$$pre$phi36Z2D = $$pre35;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre33 = (($__buf) + 1|0);
    $$pre$phi34Z2D = $$pre33;$$pre$phi36Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $157 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $157 = 1;$82 = 0;
     } else {
      $157 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($157) {
        $158 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($157) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $158 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi34Z2D;
     } else {
      $73 = HEAP32[$$pre$phi36Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($$0$i$i,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $158;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP32[$__g_end>>2]|0;
    $115 = $114;
    $116 = $__g;
    $117 = (($115) - ($116))|0;
    $118 = ($117|0)<(160);
    if ($118) {
     $119 = HEAP32[$__dc>>2]|0;
     $120 = (($114) + 4|0);
     HEAP32[$__g_end>>2] = $120;
     HEAP32[$114>>2] = $119;
    }
   }
   $121 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $122 = (invoke_iiiii(337,($__a$2|0),($121|0),($__err|0),($0|0))|0);
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if (!($124)) {
    HEAP16[$__v>>1] = $122;
    $125 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$125,$__err);
    $126 = ($82|0)==(0|0);
    if ($126) {
     $156 = 0;$159 = 1;
    } else {
     $127 = (($82) + 12|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = (($82) + 16|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($128|0)==($130|0);
     if ($131) {
      $132 = HEAP32[$82>>2]|0;
      $133 = (($132) + 36|0);
      $134 = HEAP32[$133>>2]|0;
      __THREW__ = 0;
      $135 = (invoke_ii($134|0,($82|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break;
      } else {
       $$0$i$i$i$i = $135;
      }
     } else {
      $138 = HEAP32[$128>>2]|0;
      $$0$i$i$i$i = $138;
     }
     $139 = ($$0$i$i$i$i|0)==(-1);
     if ($139) {
      HEAP32[$__b>>2] = 0;
      $156 = 0;$159 = 1;
     } else {
      $156 = $82;$159 = 0;
     }
    }
    $140 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($140) {
      label = 63;
     } else {
      $141 = (($$pre$i3$i$i) + 12|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = (($$pre$i3$i$i) + 16|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = ($142|0)==($144|0);
      if ($145) {
       $146 = HEAP32[$$pre$i3$i$i>>2]|0;
       $147 = (($146) + 36|0);
       $148 = HEAP32[$147>>2]|0;
       __THREW__ = 0;
       $149 = (invoke_ii($148|0,($$pre$i3$i$i|0))|0);
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        break L1;
       } else {
        $$0$i$i1$i$i = $149;
       }
      } else {
       $152 = HEAP32[$142>>2]|0;
       $$0$i$i1$i$i = $152;
      }
      $153 = ($$0$i$i1$i$i|0)==(-1);
      if ($153) {
       HEAP32[$__e>>2] = 0;
       label = 63;
       break;
      }
      if ($159) {
       HEAP32[$agg$result>>2] = $156;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 63) {
     if (!($159)) {
      HEAP32[$agg$result>>2] = $156;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $154 = HEAP32[$__err>>2]|0;
    $155 = $154 | 2;
    HEAP32[$__err>>2] = $155;
    HEAP32[$agg$result>>2] = $156;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre33 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0;
 var $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $__atoms = sp + 200|0;
 $__thousands_sep = sp;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp + 192|0;
 $__dc = sp + 196|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre35 = (($__buf) + 8|0);
    $$pre$phi34Z2D = $8;$$pre$phi36Z2D = $$pre35;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre33 = (($__buf) + 1|0);
    $$pre$phi34Z2D = $$pre33;$$pre$phi36Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $157 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $157 = 1;$82 = 0;
     } else {
      $157 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($157) {
        $158 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($157) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $158 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi34Z2D;
     } else {
      $73 = HEAP32[$$pre$phi36Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($$0$i$i,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $158;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP32[$__g_end>>2]|0;
    $115 = $114;
    $116 = $__g;
    $117 = (($115) - ($116))|0;
    $118 = ($117|0)<(160);
    if ($118) {
     $119 = HEAP32[$__dc>>2]|0;
     $120 = (($114) + 4|0);
     HEAP32[$__g_end>>2] = $120;
     HEAP32[$114>>2] = $119;
    }
   }
   $121 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $122 = (invoke_iiiii(338,($__a$2|0),($121|0),($__err|0),($0|0))|0);
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if (!($124)) {
    HEAP32[$__v>>2] = $122;
    $125 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$125,$__err);
    $126 = ($82|0)==(0|0);
    if ($126) {
     $156 = 0;$159 = 1;
    } else {
     $127 = (($82) + 12|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = (($82) + 16|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($128|0)==($130|0);
     if ($131) {
      $132 = HEAP32[$82>>2]|0;
      $133 = (($132) + 36|0);
      $134 = HEAP32[$133>>2]|0;
      __THREW__ = 0;
      $135 = (invoke_ii($134|0,($82|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break;
      } else {
       $$0$i$i$i$i = $135;
      }
     } else {
      $138 = HEAP32[$128>>2]|0;
      $$0$i$i$i$i = $138;
     }
     $139 = ($$0$i$i$i$i|0)==(-1);
     if ($139) {
      HEAP32[$__b>>2] = 0;
      $156 = 0;$159 = 1;
     } else {
      $156 = $82;$159 = 0;
     }
    }
    $140 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($140) {
      label = 63;
     } else {
      $141 = (($$pre$i3$i$i) + 12|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = (($$pre$i3$i$i) + 16|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = ($142|0)==($144|0);
      if ($145) {
       $146 = HEAP32[$$pre$i3$i$i>>2]|0;
       $147 = (($146) + 36|0);
       $148 = HEAP32[$147>>2]|0;
       __THREW__ = 0;
       $149 = (invoke_ii($148|0,($$pre$i3$i$i|0))|0);
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        break L1;
       } else {
        $$0$i$i1$i$i = $149;
       }
      } else {
       $152 = HEAP32[$142>>2]|0;
       $$0$i$i1$i$i = $152;
      }
      $153 = ($$0$i$i1$i$i|0)==(-1);
      if ($153) {
       HEAP32[$__e>>2] = 0;
       label = 63;
       break;
      }
      if ($159) {
       HEAP32[$agg$result>>2] = $156;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 63) {
     if (!($159)) {
      HEAP32[$agg$result>>2] = $156;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $154 = HEAP32[$__err>>2]|0;
    $155 = $154 | 2;
    HEAP32[$__err>>2] = $155;
    HEAP32[$agg$result>>2] = $156;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre33 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0;
 var $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $__atoms = sp + 200|0;
 $__thousands_sep = sp;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp + 192|0;
 $__dc = sp + 196|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre35 = (($__buf) + 8|0);
    $$pre$phi34Z2D = $8;$$pre$phi36Z2D = $$pre35;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre33 = (($__buf) + 1|0);
    $$pre$phi34Z2D = $$pre33;$$pre$phi36Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $157 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $157 = 1;$82 = 0;
     } else {
      $157 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($157) {
        $158 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($157) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $158 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi34Z2D;
     } else {
      $73 = HEAP32[$$pre$phi36Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($$0$i$i,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $158;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP32[$__g_end>>2]|0;
    $115 = $114;
    $116 = $__g;
    $117 = (($115) - ($116))|0;
    $118 = ($117|0)<(160);
    if ($118) {
     $119 = HEAP32[$__dc>>2]|0;
     $120 = (($114) + 4|0);
     HEAP32[$__g_end>>2] = $120;
     HEAP32[$114>>2] = $119;
    }
   }
   $121 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $122 = (invoke_iiiii(339,($__a$2|0),($121|0),($__err|0),($0|0))|0);
   $123 = __THREW__; __THREW__ = 0;
   $124 = $123&1;
   if (!($124)) {
    HEAP32[$__v>>2] = $122;
    $125 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$125,$__err);
    $126 = ($82|0)==(0|0);
    if ($126) {
     $156 = 0;$159 = 1;
    } else {
     $127 = (($82) + 12|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = (($82) + 16|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($128|0)==($130|0);
     if ($131) {
      $132 = HEAP32[$82>>2]|0;
      $133 = (($132) + 36|0);
      $134 = HEAP32[$133>>2]|0;
      __THREW__ = 0;
      $135 = (invoke_ii($134|0,($82|0))|0);
      $136 = __THREW__; __THREW__ = 0;
      $137 = $136&1;
      if ($137) {
       break;
      } else {
       $$0$i$i$i$i = $135;
      }
     } else {
      $138 = HEAP32[$128>>2]|0;
      $$0$i$i$i$i = $138;
     }
     $139 = ($$0$i$i$i$i|0)==(-1);
     if ($139) {
      HEAP32[$__b>>2] = 0;
      $156 = 0;$159 = 1;
     } else {
      $156 = $82;$159 = 0;
     }
    }
    $140 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($140) {
      label = 63;
     } else {
      $141 = (($$pre$i3$i$i) + 12|0);
      $142 = HEAP32[$141>>2]|0;
      $143 = (($$pre$i3$i$i) + 16|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = ($142|0)==($144|0);
      if ($145) {
       $146 = HEAP32[$$pre$i3$i$i>>2]|0;
       $147 = (($146) + 36|0);
       $148 = HEAP32[$147>>2]|0;
       __THREW__ = 0;
       $149 = (invoke_ii($148|0,($$pre$i3$i$i|0))|0);
       $150 = __THREW__; __THREW__ = 0;
       $151 = $150&1;
       if ($151) {
        break L1;
       } else {
        $$0$i$i1$i$i = $149;
       }
      } else {
       $152 = HEAP32[$142>>2]|0;
       $$0$i$i1$i$i = $152;
      }
      $153 = ($$0$i$i1$i$i|0)==(-1);
      if ($153) {
       HEAP32[$__e>>2] = 0;
       label = 63;
       break;
      }
      if ($159) {
       HEAP32[$agg$result>>2] = $156;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 63) {
     if (!($159)) {
      HEAP32[$agg$result>>2] = $156;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $154 = HEAP32[$__err>>2]|0;
    $155 = $154 | 2;
    HEAP32[$__err>>2] = $155;
    HEAP32[$agg$result>>2] = $156;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi34Z2D = 0, $$pre$phi36Z2D = 0, $$pre33 = 0, $$pre35 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0;
 var $__a_end = 0, $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $__atoms = sp + 200|0;
 $__thousands_sep = sp;
 $__grouping = sp + 4|0;
 $__buf = sp + 16|0;
 $__a_end = sp + 28|0;
 $__g = sp + 32|0;
 $__g_end = sp + 192|0;
 $__dc = sp + 196|0;
 $0 = (__ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($__iob)|0);
 __ZNSt3__19__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($__grouping,$__iob,$__atoms,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 L1: do {
  if (!($2)) {
   $3 = HEAP8[$__buf>>0]|0;
   $4 = $3 & 1;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $8 = (($__buf) + 1|0);
    $$pre35 = (($__buf) + 8|0);
    $$pre$phi34Z2D = $8;$$pre$phi36Z2D = $$pre35;$9 = $8;
   } else {
    $6 = (($__buf) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $$pre33 = (($__buf) + 1|0);
    $$pre$phi34Z2D = $$pre33;$$pre$phi36Z2D = $6;$9 = $7;
   }
   HEAP32[$__a_end>>2] = $9;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   $10 = (($__buf) + 4|0);
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $9;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $162 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $162 = 1;$82 = 0;
     } else {
      $162 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($162) {
        $163 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($162) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $163 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$10>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$10>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi34Z2D;
     } else {
      $73 = HEAP32[$$pre$phi36Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($$0$i$i,$0,$__a$1,$__a_end,$__dc,$11,$__grouping,$__g,$__g_end,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $163;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP32[$__g_end>>2]|0;
    $115 = $114;
    $116 = $__g;
    $117 = (($115) - ($116))|0;
    $118 = ($117|0)<(160);
    if ($118) {
     $119 = HEAP32[$__dc>>2]|0;
     $120 = (($114) + 4|0);
     HEAP32[$__g_end>>2] = $120;
     HEAP32[$114>>2] = $119;
    }
   }
   $121 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $122 = (invoke_iiiii(340,($__a$2|0),($121|0),($__err|0),($0|0))|0);
   $123 = tempRet0;
   $124 = __THREW__; __THREW__ = 0;
   $125 = $124&1;
   if (!($125)) {
    $126 = $__v;
    $127 = $126;
    HEAP32[$127>>2] = $122;
    $128 = (($126) + 4)|0;
    $129 = $128;
    HEAP32[$129>>2] = $123;
    $130 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$130,$__err);
    $131 = ($82|0)==(0|0);
    if ($131) {
     $161 = 0;$164 = 1;
    } else {
     $132 = (($82) + 12|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = (($82) + 16|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($133|0)==($135|0);
     if ($136) {
      $137 = HEAP32[$82>>2]|0;
      $138 = (($137) + 36|0);
      $139 = HEAP32[$138>>2]|0;
      __THREW__ = 0;
      $140 = (invoke_ii($139|0,($82|0))|0);
      $141 = __THREW__; __THREW__ = 0;
      $142 = $141&1;
      if ($142) {
       break;
      } else {
       $$0$i$i$i$i = $140;
      }
     } else {
      $143 = HEAP32[$133>>2]|0;
      $$0$i$i$i$i = $143;
     }
     $144 = ($$0$i$i$i$i|0)==(-1);
     if ($144) {
      HEAP32[$__b>>2] = 0;
      $161 = 0;$164 = 1;
     } else {
      $161 = $82;$164 = 0;
     }
    }
    $145 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($145) {
      label = 63;
     } else {
      $146 = (($$pre$i3$i$i) + 12|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = (($$pre$i3$i$i) + 16|0);
      $149 = HEAP32[$148>>2]|0;
      $150 = ($147|0)==($149|0);
      if ($150) {
       $151 = HEAP32[$$pre$i3$i$i>>2]|0;
       $152 = (($151) + 36|0);
       $153 = HEAP32[$152>>2]|0;
       __THREW__ = 0;
       $154 = (invoke_ii($153|0,($$pre$i3$i$i|0))|0);
       $155 = __THREW__; __THREW__ = 0;
       $156 = $155&1;
       if ($156) {
        break L1;
       } else {
        $$0$i$i1$i$i = $154;
       }
      } else {
       $157 = HEAP32[$147>>2]|0;
       $$0$i$i1$i$i = $157;
      }
      $158 = ($$0$i$i1$i$i|0)==(-1);
      if ($158) {
       HEAP32[$__e>>2] = 0;
       label = 63;
       break;
      }
      if ($164) {
       HEAP32[$agg$result>>2] = $161;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 63) {
     if (!($164)) {
      HEAP32[$agg$result>>2] = $161;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $159 = HEAP32[$__err>>2]|0;
    $160 = $159 | 2;
    HEAP32[$__err>>2] = $160;
    HEAP32[$agg$result>>2] = $161;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi35Z2D = 0, $$pre$phi37Z2D = 0, $$pre34 = 0, $$pre36 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = Math_fround(0), $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0;
 var $__dc = 0, $__decimal_point = 0, $__exp = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__in_units = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $__atoms = sp + 176|0;
 $__decimal_point = sp + 332|0;
 $__thousands_sep = sp + 328|0;
 $__grouping = sp + 316|0;
 $__buf = sp + 304|0;
 $__a_end = sp + 168|0;
 $__g = sp + 8|0;
 $__g_end = sp + 4|0;
 $__dc = sp;
 $__in_units = sp + 337|0;
 $__exp = sp + 336|0;
 __ZNSt3__19__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_($__grouping,$__iob,$__atoms,$__decimal_point,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP8[$__buf>>0]|0;
   $3 = $2 & 1;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    $7 = (($__buf) + 1|0);
    $$pre36 = (($__buf) + 8|0);
    $$pre$phi35Z2D = $7;$$pre$phi37Z2D = $$pre36;$8 = $7;
   } else {
    $5 = (($__buf) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $$pre34 = (($__buf) + 1|0);
    $$pre$phi35Z2D = $$pre34;$$pre$phi37Z2D = $5;$8 = $6;
   }
   HEAP32[$__a_end>>2] = $8;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   HEAP8[$__in_units>>0] = 1;
   HEAP8[$__exp>>0] = 69;
   $9 = (($__buf) + 4|0);
   $10 = HEAP32[$__decimal_point>>2]|0;
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $8;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $159 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $159 = 1;$82 = 0;
     } else {
      $159 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($159) {
        $160 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($159) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $160 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$9>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$9>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi35Z2D;
     } else {
      $73 = HEAP32[$$pre$phi37Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw($$0$i$i,$__in_units,$__exp,$__a$1,$__a_end,$10,$11,$__grouping,$__g,$__g_end,$__dc,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $160;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP8[$__in_units>>0]|0;
    $115 = ($114<<24>>24)==(0);
    if (!($115)) {
     $116 = HEAP32[$__g_end>>2]|0;
     $117 = $116;
     $118 = $__g;
     $119 = (($117) - ($118))|0;
     $120 = ($119|0)<(160);
     if ($120) {
      $121 = HEAP32[$__dc>>2]|0;
      $122 = (($116) + 4|0);
      HEAP32[$__g_end>>2] = $122;
      HEAP32[$116>>2] = $121;
     }
    }
   }
   $123 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $124 = (Math_fround(+(invoke_fiii(18,($__a$2|0),($123|0),($__err|0)))));
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if (!($126)) {
    HEAPF32[$__v>>2] = $124;
    $127 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$127,$__err);
    $128 = ($82|0)==(0|0);
    if ($128) {
     $158 = 0;$161 = 1;
    } else {
     $129 = (($82) + 12|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = (($82) + 16|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ($130|0)==($132|0);
     if ($133) {
      $134 = HEAP32[$82>>2]|0;
      $135 = (($134) + 36|0);
      $136 = HEAP32[$135>>2]|0;
      __THREW__ = 0;
      $137 = (invoke_ii($136|0,($82|0))|0);
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       break;
      } else {
       $$0$i$i$i$i = $137;
      }
     } else {
      $140 = HEAP32[$130>>2]|0;
      $$0$i$i$i$i = $140;
     }
     $141 = ($$0$i$i$i$i|0)==(-1);
     if ($141) {
      HEAP32[$__b>>2] = 0;
      $158 = 0;$161 = 1;
     } else {
      $158 = $82;$161 = 0;
     }
    }
    $142 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($142) {
      label = 64;
     } else {
      $143 = (($$pre$i3$i$i) + 12|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($$pre$i3$i$i) + 16|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if ($147) {
       $148 = HEAP32[$$pre$i3$i$i>>2]|0;
       $149 = (($148) + 36|0);
       $150 = HEAP32[$149>>2]|0;
       __THREW__ = 0;
       $151 = (invoke_ii($150|0,($$pre$i3$i$i|0))|0);
       $152 = __THREW__; __THREW__ = 0;
       $153 = $152&1;
       if ($153) {
        break L1;
       } else {
        $$0$i$i1$i$i = $151;
       }
      } else {
       $154 = HEAP32[$144>>2]|0;
       $$0$i$i1$i$i = $154;
      }
      $155 = ($$0$i$i1$i$i|0)==(-1);
      if ($155) {
       HEAP32[$__e>>2] = 0;
       label = 64;
       break;
      }
      if ($161) {
       HEAP32[$agg$result>>2] = $158;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 64) {
     if (!($161)) {
      HEAP32[$agg$result>>2] = $158;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $156 = HEAP32[$__err>>2]|0;
    $157 = $156 | 2;
    HEAP32[$__err>>2] = $157;
    HEAP32[$agg$result>>2] = $158;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi35Z2D = 0, $$pre$phi37Z2D = 0, $$pre34 = 0, $$pre36 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0;
 var $__dc = 0, $__decimal_point = 0, $__exp = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__in_units = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $__atoms = sp + 176|0;
 $__decimal_point = sp + 332|0;
 $__thousands_sep = sp + 328|0;
 $__grouping = sp + 316|0;
 $__buf = sp + 304|0;
 $__a_end = sp + 168|0;
 $__g = sp + 8|0;
 $__g_end = sp + 4|0;
 $__dc = sp;
 $__in_units = sp + 337|0;
 $__exp = sp + 336|0;
 __ZNSt3__19__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_($__grouping,$__iob,$__atoms,$__decimal_point,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP8[$__buf>>0]|0;
   $3 = $2 & 1;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    $7 = (($__buf) + 1|0);
    $$pre36 = (($__buf) + 8|0);
    $$pre$phi35Z2D = $7;$$pre$phi37Z2D = $$pre36;$8 = $7;
   } else {
    $5 = (($__buf) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $$pre34 = (($__buf) + 1|0);
    $$pre$phi35Z2D = $$pre34;$$pre$phi37Z2D = $5;$8 = $6;
   }
   HEAP32[$__a_end>>2] = $8;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   HEAP8[$__in_units>>0] = 1;
   HEAP8[$__exp>>0] = 69;
   $9 = (($__buf) + 4|0);
   $10 = HEAP32[$__decimal_point>>2]|0;
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $8;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $159 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $159 = 1;$82 = 0;
     } else {
      $159 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($159) {
        $160 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($159) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $160 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$9>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$9>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi35Z2D;
     } else {
      $73 = HEAP32[$$pre$phi37Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw($$0$i$i,$__in_units,$__exp,$__a$1,$__a_end,$10,$11,$__grouping,$__g,$__g_end,$__dc,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $160;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP8[$__in_units>>0]|0;
    $115 = ($114<<24>>24)==(0);
    if (!($115)) {
     $116 = HEAP32[$__g_end>>2]|0;
     $117 = $116;
     $118 = $__g;
     $119 = (($117) - ($118))|0;
     $120 = ($119|0)<(160);
     if ($120) {
      $121 = HEAP32[$__dc>>2]|0;
      $122 = (($116) + 4|0);
      HEAP32[$__g_end>>2] = $122;
      HEAP32[$116>>2] = $121;
     }
    }
   }
   $123 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $124 = (+invoke_diii(7,($__a$2|0),($123|0),($__err|0)));
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if (!($126)) {
    HEAPF64[$__v>>3] = $124;
    $127 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$127,$__err);
    $128 = ($82|0)==(0|0);
    if ($128) {
     $158 = 0;$161 = 1;
    } else {
     $129 = (($82) + 12|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = (($82) + 16|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ($130|0)==($132|0);
     if ($133) {
      $134 = HEAP32[$82>>2]|0;
      $135 = (($134) + 36|0);
      $136 = HEAP32[$135>>2]|0;
      __THREW__ = 0;
      $137 = (invoke_ii($136|0,($82|0))|0);
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       break;
      } else {
       $$0$i$i$i$i = $137;
      }
     } else {
      $140 = HEAP32[$130>>2]|0;
      $$0$i$i$i$i = $140;
     }
     $141 = ($$0$i$i$i$i|0)==(-1);
     if ($141) {
      HEAP32[$__b>>2] = 0;
      $158 = 0;$161 = 1;
     } else {
      $158 = $82;$161 = 0;
     }
    }
    $142 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($142) {
      label = 64;
     } else {
      $143 = (($$pre$i3$i$i) + 12|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($$pre$i3$i$i) + 16|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if ($147) {
       $148 = HEAP32[$$pre$i3$i$i>>2]|0;
       $149 = (($148) + 36|0);
       $150 = HEAP32[$149>>2]|0;
       __THREW__ = 0;
       $151 = (invoke_ii($150|0,($$pre$i3$i$i|0))|0);
       $152 = __THREW__; __THREW__ = 0;
       $153 = $152&1;
       if ($153) {
        break L1;
       } else {
        $$0$i$i1$i$i = $151;
       }
      } else {
       $154 = HEAP32[$144>>2]|0;
       $$0$i$i1$i$i = $154;
      }
      $155 = ($$0$i$i1$i$i|0)==(-1);
      if ($155) {
       HEAP32[$__e>>2] = 0;
       label = 64;
       break;
      }
      if ($161) {
       HEAP32[$agg$result>>2] = $158;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 64) {
     if (!($161)) {
      HEAP32[$agg$result>>2] = $158;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $156 = HEAP32[$__err>>2]|0;
    $157 = $156 | 2;
    HEAP32[$__err>>2] = $157;
    HEAP32[$agg$result>>2] = $158;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,0,$$byval_copy,$$byval_copy1,$__iob,$__err,$__v);
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i9 = 0, $$pre = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i = 0, $$pre$phi35Z2D = 0, $$pre$phi37Z2D = 0, $$pre34 = 0, $$pre36 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0, $__atoms = 0, $__buf = 0;
 var $__dc = 0, $__decimal_point = 0, $__exp = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $__in_units = 0, $__thousands_sep = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $__atoms = sp + 176|0;
 $__decimal_point = sp + 332|0;
 $__thousands_sep = sp + 328|0;
 $__grouping = sp + 316|0;
 $__buf = sp + 304|0;
 $__a_end = sp + 168|0;
 $__g = sp + 8|0;
 $__g_end = sp + 4|0;
 $__dc = sp;
 $__in_units = sp + 337|0;
 $__exp = sp + 336|0;
 __ZNSt3__19__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_($__grouping,$__iob,$__atoms,$__decimal_point,$__thousands_sep);
 ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viii(2128,($__buf|0),10,0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 L1: do {
  if (!($1)) {
   $2 = HEAP8[$__buf>>0]|0;
   $3 = $2 & 1;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    $7 = (($__buf) + 1|0);
    $$pre36 = (($__buf) + 8|0);
    $$pre$phi35Z2D = $7;$$pre$phi37Z2D = $$pre36;$8 = $7;
   } else {
    $5 = (($__buf) + 8|0);
    $6 = HEAP32[$5>>2]|0;
    $$pre34 = (($__buf) + 1|0);
    $$pre$phi35Z2D = $$pre34;$$pre$phi37Z2D = $5;$8 = $6;
   }
   HEAP32[$__a_end>>2] = $8;
   HEAP32[$__g_end>>2] = $__g;
   HEAP32[$__dc>>2] = 0;
   HEAP8[$__in_units>>0] = 1;
   HEAP8[$__exp>>0] = 69;
   $9 = (($__buf) + 4|0);
   $10 = HEAP32[$__decimal_point>>2]|0;
   $11 = HEAP32[$__thousands_sep>>2]|0;
   $$pre = HEAP32[$__b>>2]|0;
   $$pre$i$i$i5 = $$pre;$__a$0 = $8;
   L7: while(1) {
    $12 = ($$pre$i$i$i5|0)==(0|0);
    if ($12) {
     $159 = 1;$82 = 0;
    } else {
     $13 = (($$pre$i$i$i5) + 12|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (($$pre$i$i$i5) + 16|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = ($14|0)==($16|0);
     if ($17) {
      $18 = HEAP32[$$pre$i$i$i5>>2]|0;
      $19 = (($18) + 36|0);
      $20 = HEAP32[$19>>2]|0;
      __THREW__ = 0;
      $21 = (invoke_ii($20|0,($$pre$i$i$i5|0))|0);
      $22 = __THREW__; __THREW__ = 0;
      $23 = $22&1;
      if ($23) {
       label = 34;
       break;
      } else {
       $$0$i$i$i$i3 = $21;
      }
     } else {
      $24 = HEAP32[$14>>2]|0;
      $$0$i$i$i$i3 = $24;
     }
     $25 = ($$0$i$i$i$i3|0)==(-1);
     if ($25) {
      HEAP32[$__b>>2] = 0;
      $159 = 1;$82 = 0;
     } else {
      $159 = 0;$82 = $$pre$i$i$i5;
     }
    }
    $26 = HEAP32[$__e>>2]|0;
    $27 = ($26|0)==(0|0);
    do {
     if ($27) {
      label = 18;
     } else {
      $28 = (($26) + 12|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = (($26) + 16|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($29|0)==($31|0);
      if ($32) {
       $33 = HEAP32[$26>>2]|0;
       $34 = (($33) + 36|0);
       $35 = HEAP32[$34>>2]|0;
       __THREW__ = 0;
       $36 = (invoke_ii($35|0,($26|0))|0);
       $37 = __THREW__; __THREW__ = 0;
       $38 = $37&1;
       if ($38) {
        label = 34;
        break L7;
       } else {
        $$0$i$i1$i$i9 = $36;
       }
      } else {
       $39 = HEAP32[$29>>2]|0;
       $$0$i$i1$i$i9 = $39;
      }
      $40 = ($$0$i$i1$i$i9|0)==(-1);
      if ($40) {
       HEAP32[$__e>>2] = 0;
       label = 18;
       break;
      } else {
       if ($159) {
        $160 = $26;
        break;
       } else {
        $$pre$i3$i$i = $26;$__a$2 = $__a$0;
        break L7;
       }
      }
     }
    } while(0);
    if ((label|0) == 18) {
     label = 0;
     if ($159) {
      $$pre$i3$i$i = 0;$__a$2 = $__a$0;
      break;
     } else {
      $160 = 0;
     }
    }
    $41 = HEAP32[$__a_end>>2]|0;
    $42 = $41;
    $43 = $__a$0;
    $44 = (($42) - ($43))|0;
    $45 = HEAP8[$__buf>>0]|0;
    $46 = $45 & 1;
    $47 = ($46<<24>>24)==(0);
    if ($47) {
     $49 = $45&255;
     $50 = $49 >>> 1;
     $52 = $50;
    } else {
     $48 = HEAP32[$9>>2]|0;
     $52 = $48;
    }
    $51 = ($44|0)==($52|0);
    if ($51) {
     if ($47) {
      $54 = $45&255;
      $55 = $54 >>> 1;
      $56 = $45&255;
      $57 = $56 >>> 1;
      $59 = $57;$76 = $55;
     } else {
      $53 = HEAP32[$9>>2]|0;
      $59 = $53;$76 = $53;
     }
     $58 = $59 << 1;
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($58|0),0);
     $60 = __THREW__; __THREW__ = 0;
     $61 = $60&1;
     if ($61) {
      label = 34;
      break;
     }
     $62 = HEAP8[$__buf>>0]|0;
     $63 = $62 & 1;
     $64 = ($63<<24>>24)==(0);
     if ($64) {
      $67 = 10;
     } else {
      $65 = HEAP32[$__buf>>2]|0;
      $66 = $65 & -2;
      $phitmp$i23 = (($66) + -1)|0;
      $67 = $phitmp$i23;
     }
     __THREW__ = 0;
     invoke_viii(2128,($__buf|0),($67|0),0);
     $68 = __THREW__; __THREW__ = 0;
     $69 = $68&1;
     if ($69) {
      label = 34;
      break;
     }
     $70 = HEAP8[$__buf>>0]|0;
     $71 = $70 & 1;
     $72 = ($71<<24>>24)==(0);
     if ($72) {
      $75 = $$pre$phi35Z2D;
     } else {
      $73 = HEAP32[$$pre$phi37Z2D>>2]|0;
      $75 = $73;
     }
     $74 = (($75) + ($76)|0);
     HEAP32[$__a_end>>2] = $74;
     $__a$1 = $75;
    } else {
     $__a$1 = $__a$0;
    }
    $81 = (($82) + 12|0);
    $83 = HEAP32[$81>>2]|0;
    $84 = (($82) + 16|0);
    $85 = HEAP32[$84>>2]|0;
    $86 = ($83|0)==($85|0);
    if ($86) {
     $87 = HEAP32[$82>>2]|0;
     $88 = (($87) + 36|0);
     $89 = HEAP32[$88>>2]|0;
     __THREW__ = 0;
     $90 = (invoke_ii($89|0,($82|0))|0);
     $91 = __THREW__; __THREW__ = 0;
     $92 = $91&1;
     if ($92) {
      label = 34;
      break;
     } else {
      $$0$i$i = $90;
     }
    } else {
     $93 = HEAP32[$83>>2]|0;
     $$0$i$i = $93;
    }
    $94 = (__ZNSt3__19__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw($$0$i$i,$__in_units,$__exp,$__a$1,$__a_end,$10,$11,$__grouping,$__g,$__g_end,$__dc,$__atoms)|0);
    $95 = ($94|0)==(0);
    if (!($95)) {
     $$pre$i3$i$i = $160;$__a$2 = $__a$1;
     break;
    }
    $96 = HEAP32[$81>>2]|0;
    $97 = HEAP32[$84>>2]|0;
    $98 = ($96|0)==($97|0);
    if ($98) {
     $99 = HEAP32[$82>>2]|0;
     $100 = (($99) + 40|0);
     $101 = HEAP32[$100>>2]|0;
     __THREW__ = 0;
     (invoke_ii($101|0,($82|0))|0);
     $102 = __THREW__; __THREW__ = 0;
     $103 = $102&1;
     if ($103) {
      label = 34;
      break;
     } else {
      $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
      continue;
     }
    } else {
     $104 = (($96) + 4|0);
     HEAP32[$81>>2] = $104;
     $$pre$i$i$i5 = $82;$__a$0 = $__a$1;
     continue;
    }
   }
   if ((label|0) == 34) {
    $77 = ___cxa_find_matching_catch()|0;
    $78 = tempRet0;
    $lpad$phi$index = $77;$lpad$phi$index2 = $78;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    ___resumeException($lpad$phi$index|0);
    // unreachable;
   }
   $105 = HEAP8[$__grouping>>0]|0;
   $106 = $105 & 1;
   $107 = ($106<<24>>24)==(0);
   if ($107) {
    $110 = $105&255;
    $111 = $110 >>> 1;
    $113 = $111;
   } else {
    $108 = (($__grouping) + 4|0);
    $109 = HEAP32[$108>>2]|0;
    $113 = $109;
   }
   $112 = ($113|0)==(0);
   if (!($112)) {
    $114 = HEAP8[$__in_units>>0]|0;
    $115 = ($114<<24>>24)==(0);
    if (!($115)) {
     $116 = HEAP32[$__g_end>>2]|0;
     $117 = $116;
     $118 = $__g;
     $119 = (($117) - ($118))|0;
     $120 = ($119|0)<(160);
     if ($120) {
      $121 = HEAP32[$__dc>>2]|0;
      $122 = (($116) + 4|0);
      HEAP32[$__g_end>>2] = $122;
      HEAP32[$116>>2] = $121;
     }
    }
   }
   $123 = HEAP32[$__a_end>>2]|0;
   __THREW__ = 0;
   $124 = (+invoke_diii(8,($__a$2|0),($123|0),($__err|0)));
   $125 = __THREW__; __THREW__ = 0;
   $126 = $125&1;
   if (!($126)) {
    HEAPF64[$__v>>3] = $124;
    $127 = HEAP32[$__g_end>>2]|0;
    __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$127,$__err);
    $128 = ($82|0)==(0|0);
    if ($128) {
     $158 = 0;$161 = 1;
    } else {
     $129 = (($82) + 12|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = (($82) + 16|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ($130|0)==($132|0);
     if ($133) {
      $134 = HEAP32[$82>>2]|0;
      $135 = (($134) + 36|0);
      $136 = HEAP32[$135>>2]|0;
      __THREW__ = 0;
      $137 = (invoke_ii($136|0,($82|0))|0);
      $138 = __THREW__; __THREW__ = 0;
      $139 = $138&1;
      if ($139) {
       break;
      } else {
       $$0$i$i$i$i = $137;
      }
     } else {
      $140 = HEAP32[$130>>2]|0;
      $$0$i$i$i$i = $140;
     }
     $141 = ($$0$i$i$i$i|0)==(-1);
     if ($141) {
      HEAP32[$__b>>2] = 0;
      $158 = 0;$161 = 1;
     } else {
      $158 = $82;$161 = 0;
     }
    }
    $142 = ($$pre$i3$i$i|0)==(0|0);
    do {
     if ($142) {
      label = 64;
     } else {
      $143 = (($$pre$i3$i$i) + 12|0);
      $144 = HEAP32[$143>>2]|0;
      $145 = (($$pre$i3$i$i) + 16|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = ($144|0)==($146|0);
      if ($147) {
       $148 = HEAP32[$$pre$i3$i$i>>2]|0;
       $149 = (($148) + 36|0);
       $150 = HEAP32[$149>>2]|0;
       __THREW__ = 0;
       $151 = (invoke_ii($150|0,($$pre$i3$i$i|0))|0);
       $152 = __THREW__; __THREW__ = 0;
       $153 = $152&1;
       if ($153) {
        break L1;
       } else {
        $$0$i$i1$i$i = $151;
       }
      } else {
       $154 = HEAP32[$144>>2]|0;
       $$0$i$i1$i$i = $154;
      }
      $155 = ($$0$i$i1$i$i|0)==(-1);
      if ($155) {
       HEAP32[$__e>>2] = 0;
       label = 64;
       break;
      }
      if ($161) {
       HEAP32[$agg$result>>2] = $158;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    } while(0);
    if ((label|0) == 64) {
     if (!($161)) {
      HEAP32[$agg$result>>2] = $158;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      STACKTOP = sp;return;
     }
    }
    $156 = HEAP32[$__err>>2]|0;
    $157 = $156 | 2;
    HEAP32[$__err>>2] = $157;
    HEAP32[$agg$result>>2] = $158;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $79 = ___cxa_find_matching_catch()|0;
 $80 = tempRet0;
 $lpad$phi$index = $79;$lpad$phi$index2 = $80;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv($agg$result,$this,$__b,$__e,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i7 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i13 = 0, $$01 = 0, $$pre = 0, $$pre$i$i$i9 = 0, $$pre$phi36Z2D = 0, $$pre$phi38Z2D = 0, $$pre35 = 0, $$pre37 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__a$0 = 0, $__a$1 = 0, $__a$2 = 0, $__a_end = 0;
 var $__atoms = 0, $__buf = 0, $__dc = 0, $__g = 0, $__g_end = 0, $__grouping = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $phitmp$i26 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 320|0;
 $vararg_buffer = sp;
 $__atoms = sp + 200|0;
 $__grouping = sp + 184|0;
 $0 = sp + 180|0;
 $__buf = sp + 304|0;
 $__a_end = sp + 168|0;
 $__g = sp + 8|0;
 $__g_end = sp + 172|0;
 $__dc = sp + 176|0;
 ;HEAP32[$__grouping+0>>2]=0|0;HEAP32[$__grouping+4>>2]=0|0;HEAP32[$__grouping+8>>2]=0|0;
 __THREW__ = 0;
 invoke_vii(2475,($0|0),($__iob|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $87 = ___cxa_find_matching_catch()|0;
  $88 = tempRet0;
  $$0 = $87;$$01 = $88;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
  ___resumeException($$0|0);
  // unreachable;
 }
 __THREW__ = 0;
 $3 = (invoke_iii(2228,($0|0),(3093328|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if (!($5)) {
  $6 = HEAP32[$3>>2]|0;
  $7 = (($6) + 48|0);
  $8 = HEAP32[$7>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($8|0,($3|0),(3091848|0),(((3091848 + 26|0))|0),($__atoms|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if (!($10)) {
   $11 = HEAP32[$0>>2]|0;
   (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
   ;HEAP32[$__buf+0>>2]=0|0;HEAP32[$__buf+4>>2]=0|0;HEAP32[$__buf+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viii(2128,($__buf|0),10,0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   L8: do {
    if ($13) {
     label = 40;
    } else {
     $14 = HEAP8[$__buf>>0]|0;
     $15 = $14 & 1;
     $16 = ($15<<24>>24)==(0);
     if ($16) {
      $19 = (($__buf) + 1|0);
      $$pre37 = (($__buf) + 8|0);
      $$pre$phi36Z2D = $19;$$pre$phi38Z2D = $$pre37;$20 = $19;
     } else {
      $17 = (($__buf) + 8|0);
      $18 = HEAP32[$17>>2]|0;
      $$pre35 = (($__buf) + 1|0);
      $$pre$phi36Z2D = $$pre35;$$pre$phi38Z2D = $17;$20 = $18;
     }
     HEAP32[$__a_end>>2] = $20;
     HEAP32[$__g_end>>2] = $__g;
     HEAP32[$__dc>>2] = 0;
     $21 = (($__buf) + 4|0);
     $$pre = HEAP32[$__b>>2]|0;
     $$pre$i$i$i9 = $$pre;$__a$0 = $20;
     L14: while(1) {
      $22 = ($$pre$i$i$i9|0)==(0|0);
      if ($22) {
       $161 = 1;$97 = 0;
      } else {
       $23 = (($$pre$i$i$i9) + 12|0);
       $24 = HEAP32[$23>>2]|0;
       $25 = (($$pre$i$i$i9) + 16|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = ($24|0)==($26|0);
       if ($27) {
        $28 = HEAP32[$$pre$i$i$i9>>2]|0;
        $29 = (($28) + 36|0);
        $30 = HEAP32[$29>>2]|0;
        __THREW__ = 0;
        $31 = (invoke_ii($30|0,($$pre$i$i$i9|0))|0);
        $32 = __THREW__; __THREW__ = 0;
        $33 = $32&1;
        if ($33) {
         label = 39;
         break;
        } else {
         $$0$i$i$i$i7 = $31;
        }
       } else {
        $34 = HEAP32[$24>>2]|0;
        $$0$i$i$i$i7 = $34;
       }
       $35 = ($$0$i$i$i$i7|0)==(-1);
       if ($35) {
        HEAP32[$__b>>2] = 0;
        $161 = 1;$97 = 0;
       } else {
        $161 = 0;$97 = $$pre$i$i$i9;
       }
      }
      $36 = HEAP32[$__e>>2]|0;
      $37 = ($36|0)==(0|0);
      do {
       if ($37) {
        label = 21;
       } else {
        $38 = (($36) + 12|0);
        $39 = HEAP32[$38>>2]|0;
        $40 = (($36) + 16|0);
        $41 = HEAP32[$40>>2]|0;
        $42 = ($39|0)==($41|0);
        if ($42) {
         $43 = HEAP32[$36>>2]|0;
         $44 = (($43) + 36|0);
         $45 = HEAP32[$44>>2]|0;
         __THREW__ = 0;
         $46 = (invoke_ii($45|0,($36|0))|0);
         $47 = __THREW__; __THREW__ = 0;
         $48 = $47&1;
         if ($48) {
          label = 39;
          break L14;
         } else {
          $$0$i$i1$i$i13 = $46;
         }
        } else {
         $49 = HEAP32[$39>>2]|0;
         $$0$i$i1$i$i13 = $49;
        }
        $50 = ($$0$i$i1$i$i13|0)==(-1);
        if ($50) {
         HEAP32[$__e>>2] = 0;
         label = 21;
         break;
        } else {
         if ($161) {
          break;
         } else {
          $__a$2 = $__a$0;
          break L14;
         }
        }
       }
      } while(0);
      if ((label|0) == 21) {
       label = 0;
       if ($161) {
        $__a$2 = $__a$0;
        break;
       }
      }
      $51 = HEAP32[$__a_end>>2]|0;
      $52 = $51;
      $53 = $__a$0;
      $54 = (($52) - ($53))|0;
      $55 = HEAP8[$__buf>>0]|0;
      $56 = $55 & 1;
      $57 = ($56<<24>>24)==(0);
      if ($57) {
       $59 = $55&255;
       $60 = $59 >>> 1;
       $62 = $60;
      } else {
       $58 = HEAP32[$21>>2]|0;
       $62 = $58;
      }
      $61 = ($54|0)==($62|0);
      if ($61) {
       if ($57) {
        $64 = $55&255;
        $65 = $64 >>> 1;
        $66 = $55&255;
        $67 = $66 >>> 1;
        $69 = $67;$86 = $65;
       } else {
        $63 = HEAP32[$21>>2]|0;
        $69 = $63;$86 = $63;
       }
       $68 = $69 << 1;
       __THREW__ = 0;
       invoke_viii(2128,($__buf|0),($68|0),0);
       $70 = __THREW__; __THREW__ = 0;
       $71 = $70&1;
       if ($71) {
        label = 39;
        break;
       }
       $72 = HEAP8[$__buf>>0]|0;
       $73 = $72 & 1;
       $74 = ($73<<24>>24)==(0);
       if ($74) {
        $77 = 10;
       } else {
        $75 = HEAP32[$__buf>>2]|0;
        $76 = $75 & -2;
        $phitmp$i26 = (($76) + -1)|0;
        $77 = $phitmp$i26;
       }
       __THREW__ = 0;
       invoke_viii(2128,($__buf|0),($77|0),0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 39;
        break;
       }
       $80 = HEAP8[$__buf>>0]|0;
       $81 = $80 & 1;
       $82 = ($81<<24>>24)==(0);
       if ($82) {
        $85 = $$pre$phi36Z2D;
       } else {
        $83 = HEAP32[$$pre$phi38Z2D>>2]|0;
        $85 = $83;
       }
       $84 = (($85) + ($86)|0);
       HEAP32[$__a_end>>2] = $84;
       $__a$1 = $85;
      } else {
       $__a$1 = $__a$0;
      }
      $96 = (($97) + 12|0);
      $98 = HEAP32[$96>>2]|0;
      $99 = (($97) + 16|0);
      $100 = HEAP32[$99>>2]|0;
      $101 = ($98|0)==($100|0);
      if ($101) {
       $102 = HEAP32[$97>>2]|0;
       $103 = (($102) + 36|0);
       $104 = HEAP32[$103>>2]|0;
       __THREW__ = 0;
       $105 = (invoke_ii($104|0,($97|0))|0);
       $106 = __THREW__; __THREW__ = 0;
       $107 = $106&1;
       if ($107) {
        label = 39;
        break;
       } else {
        $$0$i$i = $105;
       }
      } else {
       $108 = HEAP32[$98>>2]|0;
       $$0$i$i = $108;
      }
      $109 = (__ZNSt3__19__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($$0$i$i,16,$__a$1,$__a_end,$__dc,0,$__grouping,$__g,$__g_end,$__atoms)|0);
      $110 = ($109|0)==(0);
      if (!($110)) {
       $__a$2 = $__a$1;
       break;
      }
      $111 = HEAP32[$96>>2]|0;
      $112 = HEAP32[$99>>2]|0;
      $113 = ($111|0)==($112|0);
      if ($113) {
       $114 = HEAP32[$97>>2]|0;
       $115 = (($114) + 40|0);
       $116 = HEAP32[$115>>2]|0;
       __THREW__ = 0;
       (invoke_ii($116|0,($97|0))|0);
       $117 = __THREW__; __THREW__ = 0;
       $118 = $117&1;
       if ($118) {
        label = 39;
        break;
       } else {
        $$pre$i$i$i9 = $97;$__a$0 = $__a$1;
        continue;
       }
      } else {
       $119 = (($111) + 4|0);
       HEAP32[$96>>2] = $119;
       $$pre$i$i$i9 = $97;$__a$0 = $__a$1;
       continue;
      }
     }
     if ((label|0) == 39) {
      $92 = ___cxa_find_matching_catch()|0;
      $93 = tempRet0;
      $lpad$phi$index = $92;$lpad$phi$index2 = $93;
      break;
     }
     $120 = (($__a$2) + 3|0);
     HEAP8[$120>>0] = 0;
     __THREW__ = 0;
     $121 = (invoke_i(134)|0);
     $122 = __THREW__; __THREW__ = 0;
     $123 = $122&1;
     if ($123) {
      label = 40;
     } else {
      __THREW__ = 0;
      HEAP32[$vararg_buffer>>2] = $__v;
      $124 = (invoke_iiiii(341,($__a$2|0),($121|0),(3091888|0),($vararg_buffer|0))|0);
      $125 = __THREW__; __THREW__ = 0;
      $126 = $125&1;
      if ($126) {
       label = 40;
      } else {
       $127 = ($124|0)==(1);
       if (!($127)) {
        HEAP32[$__err>>2] = 4;
       }
       $128 = HEAP32[$__b>>2]|0;
       $129 = ($128|0)==(0|0);
       if ($129) {
        $160 = 0;$162 = 1;
       } else {
        $130 = (($128) + 12|0);
        $131 = HEAP32[$130>>2]|0;
        $132 = (($128) + 16|0);
        $133 = HEAP32[$132>>2]|0;
        $134 = ($131|0)==($133|0);
        if ($134) {
         $135 = HEAP32[$128>>2]|0;
         $136 = (($135) + 36|0);
         $137 = HEAP32[$136>>2]|0;
         __THREW__ = 0;
         $138 = (invoke_ii($137|0,($128|0))|0);
         $139 = __THREW__; __THREW__ = 0;
         $140 = $139&1;
         if ($140) {
          label = 40;
          break;
         } else {
          $$0$i$i$i$i = $138;
         }
        } else {
         $141 = HEAP32[$131>>2]|0;
         $$0$i$i$i$i = $141;
        }
        $142 = ($$0$i$i$i$i|0)==(-1);
        if ($142) {
         HEAP32[$__b>>2] = 0;
         $160 = 0;$162 = 1;
        } else {
         $160 = $128;$162 = 0;
        }
       }
       $143 = HEAP32[$__e>>2]|0;
       $144 = ($143|0)==(0|0);
       do {
        if ($144) {
         label = 65;
        } else {
         $145 = (($143) + 12|0);
         $146 = HEAP32[$145>>2]|0;
         $147 = (($143) + 16|0);
         $148 = HEAP32[$147>>2]|0;
         $149 = ($146|0)==($148|0);
         if ($149) {
          $150 = HEAP32[$143>>2]|0;
          $151 = (($150) + 36|0);
          $152 = HEAP32[$151>>2]|0;
          __THREW__ = 0;
          $153 = (invoke_ii($152|0,($143|0))|0);
          $154 = __THREW__; __THREW__ = 0;
          $155 = $154&1;
          if ($155) {
           label = 40;
           break L8;
          } else {
           $$0$i$i1$i$i = $153;
          }
         } else {
          $156 = HEAP32[$146>>2]|0;
          $$0$i$i1$i$i = $156;
         }
         $157 = ($$0$i$i1$i$i|0)==(-1);
         if ($157) {
          HEAP32[$__e>>2] = 0;
          label = 65;
          break;
         }
         if ($162) {
          HEAP32[$agg$result>>2] = $160;
          __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
          __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
          STACKTOP = sp;return;
         }
        }
       } while(0);
       if ((label|0) == 65) {
        if (!($162)) {
         HEAP32[$agg$result>>2] = $160;
         __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
         __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
         STACKTOP = sp;return;
        }
       }
       $158 = HEAP32[$__err>>2]|0;
       $159 = $158 | 2;
       HEAP32[$__err>>2] = $159;
       HEAP32[$agg$result>>2] = $160;
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
       STACKTOP = sp;return;
      }
     }
    }
   } while(0);
   if ((label|0) == 40) {
    $94 = ___cxa_find_matching_catch()|0;
    $95 = tempRet0;
    $lpad$phi$index = $94;$lpad$phi$index2 = $95;
   }
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__buf);
   $$0 = $lpad$phi$index;$$01 = $lpad$phi$index2;
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
   ___resumeException($$0|0);
   // unreachable;
  }
 }
 $89 = ___cxa_find_matching_catch()|0;
 $90 = tempRet0;
 $91 = HEAP32[$0>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($91)|0);
 $$0 = $89;$$01 = $90;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($$0|0);
 // unreachable;
}
function __ZNSt3__19__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_Pw($__ct,$__base,$__a,$__a_end,$__dc,$__thousands_sep,$__grouping,$__g,$__g_end,$__atoms) {
 $__ct = $__ct|0;
 $__base = $__base|0;
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__dc = $__dc|0;
 $__thousands_sep = $__thousands_sep|0;
 $__grouping = $__grouping|0;
 $__g = $__g|0;
 $__g_end = $__g_end|0;
 $__atoms = $__atoms|0;
 var $$0 = 0, $$0$lcssa$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__a_end>>2]|0;
 $1 = ($0|0)==($__a|0);
 do {
  if ($1) {
   $2 = (($__atoms) + 96|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==($__ct|0);
   if (!($4)) {
    $5 = (($__atoms) + 100|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)==($__ct|0);
    if (!($7)) {
     break;
    }
   }
   $8 = $4 ? 43 : 45;
   $9 = (($__a) + 1|0);
   HEAP32[$__a_end>>2] = $9;
   HEAP8[$__a>>0] = $8;
   HEAP32[$__dc>>2] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $10 = HEAP8[$__grouping>>0]|0;
 $11 = $10 & 1;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $15 = $10&255;
  $16 = $15 >>> 1;
  $18 = $16;
 } else {
  $13 = (($__grouping) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $18 = $14;
 }
 $17 = ($18|0)!=(0);
 $19 = ($__ct|0)==($__thousands_sep|0);
 $or$cond = $17 & $19;
 if ($or$cond) {
  $20 = HEAP32[$__g_end>>2]|0;
  $21 = $20;
  $22 = $__g;
  $23 = (($21) - ($22))|0;
  $24 = ($23|0)<(160);
  if (!($24)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $25 = HEAP32[$__dc>>2]|0;
  $26 = (($20) + 4|0);
  HEAP32[$__g_end>>2] = $26;
  HEAP32[$20>>2] = $25;
  HEAP32[$__dc>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $27 = (($__atoms) + 104|0);
 $$01$i = $__atoms;
 while(1) {
  $30 = HEAP32[$$01$i>>2]|0;
  $31 = ($30|0)==($__ct|0);
  $29 = (($$01$i) + 4|0);
  if ($31) {
   $$0$lcssa$i = $$01$i;
   break;
  }
  $28 = ($29|0)==($27|0);
  if ($28) {
   $$0$lcssa$i = $27;
   break;
  } else {
   $$01$i = $29;
  }
 }
 $32 = $$0$lcssa$i;
 $33 = $__atoms;
 $34 = (($32) - ($33))|0;
 $35 = $34 >> 2;
 $36 = ($34|0)>(92);
 if ($36) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 if ((($__base|0) == 10) | (($__base|0) == 8)) {
  $37 = ($35|0)<($__base|0);
  if (!($37)) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } else if ((($__base|0) == 16)) {
  $38 = ($34|0)<(88);
  if (!($38)) {
   if ($1) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $39 = $0;
   $40 = $__a;
   $41 = (($39) - ($40))|0;
   $42 = ($41|0)<(3);
   if (!($42)) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $43 = (($0) + -1|0);
   $44 = HEAP8[$43>>0]|0;
   $45 = ($44<<24>>24)==(48);
   if (!($45)) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   HEAP32[$__dc>>2] = 0;
   $46 = (3091848 + ($35)|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = (($0) + 1|0);
   HEAP32[$__a_end>>2] = $48;
   HEAP8[$0>>0] = $47;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $49 = (3091848 + ($35)|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = (($0) + 1|0);
 HEAP32[$__a_end>>2] = $51;
 HEAP8[$0>>0] = $50;
 $52 = HEAP32[$__dc>>2]|0;
 $53 = (($52) + 1)|0;
 HEAP32[$__dc>>2] = $53;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__19__num_getIcE17__stage2_int_prepERNS_8ios_baseEPcRc($agg$result,$__iob,$__atoms,$__thousands_sep) {
 $agg$result = $agg$result|0;
 $__iob = $__iob|0;
 $__atoms = $__atoms|0;
 $__thousands_sep = $__thousands_sep|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__loc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__loc = sp;
 __ZNKSt3__18ios_base6getlocEv($__loc,$__iob);
 __THREW__ = 0;
 $0 = (invoke_iii(2228,($__loc|0),(3093336|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = HEAP32[$0>>2]|0;
  $4 = (($3) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($5|0,($0|0),(3091848|0),(((3091848 + 26|0))|0),($__atoms|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_iii(2228,($__loc|0),(3093480|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP32[$8>>2]|0;
    $12 = (($11) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_ii($13|0,($8|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     HEAP8[$__thousands_sep>>0] = $14;
     $17 = HEAP32[$8>>2]|0;
     $18 = (($17) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     invoke_vii($19|0,($agg$result|0),($8|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP32[$__loc>>2]|0;
      (__ZNSt3__114__shared_count16__release_sharedEv($22)|0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$__loc>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($25)|0);
 ___resumeException($23|0);
 // unreachable;
}
function __ZNSt3__19__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_($agg$result,$__iob,$__atoms,$__decimal_point,$__thousands_sep) {
 $agg$result = $agg$result|0;
 $__iob = $__iob|0;
 $__atoms = $__atoms|0;
 $__decimal_point = $__decimal_point|0;
 $__thousands_sep = $__thousands_sep|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__loc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__loc = sp;
 __ZNKSt3__18ios_base6getlocEv($__loc,$__iob);
 __THREW__ = 0;
 $0 = (invoke_iii(2228,($__loc|0),(3093336|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = HEAP32[$0>>2]|0;
  $4 = (($3) + 32|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($5|0,($0|0),(3091848|0),(((3091848 + 32|0))|0),($__atoms|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_iii(2228,($__loc|0),(3093480|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP32[$8>>2]|0;
    $12 = (($11) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_ii($13|0,($8|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     HEAP8[$__decimal_point>>0] = $14;
     $17 = HEAP32[$8>>2]|0;
     $18 = (($17) + 16|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_ii($19|0,($8|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      HEAP8[$__thousands_sep>>0] = $20;
      $23 = HEAP32[$8>>2]|0;
      $24 = (($23) + 20|0);
      $25 = HEAP32[$24>>2]|0;
      __THREW__ = 0;
      invoke_vii($25|0,($agg$result|0),($8|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       $28 = HEAP32[$__loc>>2]|0;
       (__ZNSt3__114__shared_count16__release_sharedEv($28)|0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$__loc>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($31)|0);
 ___resumeException($29|0);
 // unreachable;
}
function __ZNSt3__19__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_($__ct,$__in_units,$__exp,$__a,$__a_end,$__decimal_point,$__thousands_sep,$__grouping,$__g,$__g_end,$__dc,$__atoms) {
 $__ct = $__ct|0;
 $__in_units = $__in_units|0;
 $__exp = $__exp|0;
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__decimal_point = $__decimal_point|0;
 $__thousands_sep = $__thousands_sep|0;
 $__grouping = $__grouping|0;
 $__g = $__g|0;
 $__g_end = $__g_end|0;
 $__dc = $__dc|0;
 $__atoms = $__atoms|0;
 var $$0 = 0, $$0$lcssa$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__ct<<24>>24)==($__decimal_point<<24>>24);
 if ($0) {
  $1 = HEAP8[$__in_units>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP8[$__in_units>>0] = 0;
  $3 = HEAP32[$__a_end>>2]|0;
  $4 = (($3) + 1|0);
  HEAP32[$__a_end>>2] = $4;
  HEAP8[$3>>0] = 46;
  $5 = HEAP8[$__grouping>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   $10 = $5&255;
   $11 = $10 >>> 1;
   $13 = $11;
  } else {
   $8 = (($__grouping) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $13 = $9;
  }
  $12 = ($13|0)==(0);
  if ($12) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $14 = HEAP32[$__g_end>>2]|0;
  $15 = $14;
  $16 = $__g;
  $17 = (($15) - ($16))|0;
  $18 = ($17|0)<(160);
  if (!($18)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $19 = HEAP32[$__dc>>2]|0;
  $20 = (($14) + 4|0);
  HEAP32[$__g_end>>2] = $20;
  HEAP32[$14>>2] = $19;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = ($__ct<<24>>24)==($__thousands_sep<<24>>24);
 if ($21) {
  $22 = HEAP8[$__grouping>>0]|0;
  $23 = $22 & 1;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   $27 = $22&255;
   $28 = $27 >>> 1;
   $30 = $28;
  } else {
   $25 = (($__grouping) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $30 = $26;
  }
  $29 = ($30|0)==(0);
  if (!($29)) {
   $31 = HEAP8[$__in_units>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $33 = HEAP32[$__g_end>>2]|0;
   $34 = $33;
   $35 = $__g;
   $36 = (($34) - ($35))|0;
   $37 = ($36|0)<(160);
   if (!($37)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $38 = HEAP32[$__dc>>2]|0;
   $39 = (($33) + 4|0);
   HEAP32[$__g_end>>2] = $39;
   HEAP32[$33>>2] = $38;
   HEAP32[$__dc>>2] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $40 = (($__atoms) + 32|0);
 $$01$i = $__atoms;
 while(1) {
  $43 = HEAP8[$$01$i>>0]|0;
  $44 = ($43<<24>>24)==($__ct<<24>>24);
  $42 = (($$01$i) + 1|0);
  if ($44) {
   $$0$lcssa$i = $$01$i;
   break;
  }
  $41 = ($42|0)==($40|0);
  if ($41) {
   $$0$lcssa$i = $40;
   break;
  } else {
   $$01$i = $42;
  }
 }
 $45 = $$0$lcssa$i;
 $46 = $__atoms;
 $47 = (($45) - ($46))|0;
 $48 = ($47|0)>(31);
 if ($48) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = (3091848 + ($47)|0);
 $50 = HEAP8[$49>>0]|0;
 if ((($47|0) == 24) | (($47|0) == 25)) {
  $51 = HEAP32[$__a_end>>2]|0;
  $52 = ($51|0)==($__a|0);
  if (!($52)) {
   $53 = (($51) + -1|0);
   $54 = HEAP8[$53>>0]|0;
   $55 = $54&255;
   $56 = $55 & 95;
   $57 = HEAP8[$__exp>>0]|0;
   $58 = $57&255;
   $59 = $58 & 127;
   $60 = ($56|0)==($59|0);
   if (!($60)) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $61 = (($51) + 1|0);
  HEAP32[$__a_end>>2] = $61;
  HEAP8[$51>>0] = $50;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($47|0) == 23) | (($47|0) == 22)) {
  HEAP8[$__exp>>0] = 80;
  $62 = HEAP32[$__a_end>>2]|0;
  $63 = (($62) + 1|0);
  HEAP32[$__a_end>>2] = $63;
  HEAP8[$62>>0] = $50;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $64 = $50&255;
  $65 = $64 & 95;
  $66 = HEAP8[$__exp>>0]|0;
  $67 = $66 << 24 >> 24;
  $68 = ($65|0)==($67|0);
  if ($68) {
   $69 = $65 | 128;
   $70 = $69&255;
   HEAP8[$__exp>>0] = $70;
   $71 = HEAP8[$__in_units>>0]|0;
   $72 = ($71<<24>>24)==(0);
   if (!($72)) {
    HEAP8[$__in_units>>0] = 0;
    $73 = HEAP8[$__grouping>>0]|0;
    $74 = $73 & 1;
    $75 = ($74<<24>>24)==(0);
    if ($75) {
     $78 = $73&255;
     $79 = $78 >>> 1;
     $81 = $79;
    } else {
     $76 = (($__grouping) + 4|0);
     $77 = HEAP32[$76>>2]|0;
     $81 = $77;
    }
    $80 = ($81|0)==(0);
    if (!($80)) {
     $82 = HEAP32[$__g_end>>2]|0;
     $83 = $82;
     $84 = $__g;
     $85 = (($83) - ($84))|0;
     $86 = ($85|0)<(160);
     if ($86) {
      $87 = HEAP32[$__dc>>2]|0;
      $88 = (($82) + 4|0);
      HEAP32[$__g_end>>2] = $88;
      HEAP32[$82>>2] = $87;
     }
    }
   }
  }
  $89 = HEAP32[$__a_end>>2]|0;
  $90 = (($89) + 1|0);
  HEAP32[$__a_end>>2] = $90;
  HEAP8[$89>>0] = $50;
  $91 = ($47|0)>(21);
  if ($91) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $92 = HEAP32[$__dc>>2]|0;
  $93 = (($92) + 1)|0;
  HEAP32[$__dc>>2] = $93;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__19__num_getIwE17__stage2_int_prepERNS_8ios_baseEPwRw($agg$result,$__iob,$__atoms,$__thousands_sep) {
 $agg$result = $agg$result|0;
 $__iob = $__iob|0;
 $__atoms = $__atoms|0;
 $__thousands_sep = $__thousands_sep|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__loc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__loc = sp;
 __ZNKSt3__18ios_base6getlocEv($__loc,$__iob);
 __THREW__ = 0;
 $0 = (invoke_iii(2228,($__loc|0),(3093328|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = HEAP32[$0>>2]|0;
  $4 = (($3) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($5|0,($0|0),(3091848|0),(((3091848 + 26|0))|0),($__atoms|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_iii(2228,($__loc|0),(3093488|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP32[$8>>2]|0;
    $12 = (($11) + 16|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_ii($13|0,($8|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     HEAP32[$__thousands_sep>>2] = $14;
     $17 = HEAP32[$8>>2]|0;
     $18 = (($17) + 20|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     invoke_vii($19|0,($agg$result|0),($8|0));
     $20 = __THREW__; __THREW__ = 0;
     $21 = $20&1;
     if (!($21)) {
      $22 = HEAP32[$__loc>>2]|0;
      (__ZNSt3__114__shared_count16__release_sharedEv($22)|0);
      STACKTOP = sp;return;
     }
    }
   }
  }
 }
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $25 = HEAP32[$__loc>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($25)|0);
 ___resumeException($23|0);
 // unreachable;
}
function __ZNSt3__19__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_($agg$result,$__iob,$__atoms,$__decimal_point,$__thousands_sep) {
 $agg$result = $agg$result|0;
 $__iob = $__iob|0;
 $__atoms = $__atoms|0;
 $__decimal_point = $__decimal_point|0;
 $__thousands_sep = $__thousands_sep|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__loc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__loc = sp;
 __ZNKSt3__18ios_base6getlocEv($__loc,$__iob);
 __THREW__ = 0;
 $0 = (invoke_iii(2228,($__loc|0),(3093328|0))|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if (!($2)) {
  $3 = HEAP32[$0>>2]|0;
  $4 = (($3) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  __THREW__ = 0;
  (invoke_iiiii($5|0,($0|0),(3091848|0),(((3091848 + 32|0))|0),($__atoms|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   __THREW__ = 0;
   $8 = (invoke_iii(2228,($__loc|0),(3093488|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if (!($10)) {
    $11 = HEAP32[$8>>2]|0;
    $12 = (($11) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    __THREW__ = 0;
    $14 = (invoke_ii($13|0,($8|0))|0);
    $15 = __THREW__; __THREW__ = 0;
    $16 = $15&1;
    if (!($16)) {
     HEAP32[$__decimal_point>>2] = $14;
     $17 = HEAP32[$8>>2]|0;
     $18 = (($17) + 16|0);
     $19 = HEAP32[$18>>2]|0;
     __THREW__ = 0;
     $20 = (invoke_ii($19|0,($8|0))|0);
     $21 = __THREW__; __THREW__ = 0;
     $22 = $21&1;
     if (!($22)) {
      HEAP32[$__thousands_sep>>2] = $20;
      $23 = HEAP32[$8>>2]|0;
      $24 = (($23) + 20|0);
      $25 = HEAP32[$24>>2]|0;
      __THREW__ = 0;
      invoke_vii($25|0,($agg$result|0),($8|0));
      $26 = __THREW__; __THREW__ = 0;
      $27 = $26&1;
      if (!($27)) {
       $28 = HEAP32[$__loc>>2]|0;
       (__ZNSt3__114__shared_count16__release_sharedEv($28)|0);
       STACKTOP = sp;return;
      }
     }
    }
   }
  }
 }
 $29 = ___cxa_find_matching_catch()|0;
 $30 = tempRet0;
 $31 = HEAP32[$__loc>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($31)|0);
 ___resumeException($29|0);
 // unreachable;
}
function __ZNSt3__19__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw($__ct,$__in_units,$__exp,$__a,$__a_end,$__decimal_point,$__thousands_sep,$__grouping,$__g,$__g_end,$__dc,$__atoms) {
 $__ct = $__ct|0;
 $__in_units = $__in_units|0;
 $__exp = $__exp|0;
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__decimal_point = $__decimal_point|0;
 $__thousands_sep = $__thousands_sep|0;
 $__grouping = $__grouping|0;
 $__g = $__g|0;
 $__g_end = $__g_end|0;
 $__dc = $__dc|0;
 $__atoms = $__atoms|0;
 var $$0 = 0, $$0$lcssa$i = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__ct|0)==($__decimal_point|0);
 if ($0) {
  $1 = HEAP8[$__in_units>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP8[$__in_units>>0] = 0;
  $3 = HEAP32[$__a_end>>2]|0;
  $4 = (($3) + 1|0);
  HEAP32[$__a_end>>2] = $4;
  HEAP8[$3>>0] = 46;
  $5 = HEAP8[$__grouping>>0]|0;
  $6 = $5 & 1;
  $7 = ($6<<24>>24)==(0);
  if ($7) {
   $10 = $5&255;
   $11 = $10 >>> 1;
   $13 = $11;
  } else {
   $8 = (($__grouping) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $13 = $9;
  }
  $12 = ($13|0)==(0);
  if ($12) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $14 = HEAP32[$__g_end>>2]|0;
  $15 = $14;
  $16 = $__g;
  $17 = (($15) - ($16))|0;
  $18 = ($17|0)<(160);
  if (!($18)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $19 = HEAP32[$__dc>>2]|0;
  $20 = (($14) + 4|0);
  HEAP32[$__g_end>>2] = $20;
  HEAP32[$14>>2] = $19;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $21 = ($__ct|0)==($__thousands_sep|0);
 if ($21) {
  $22 = HEAP8[$__grouping>>0]|0;
  $23 = $22 & 1;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   $27 = $22&255;
   $28 = $27 >>> 1;
   $30 = $28;
  } else {
   $25 = (($__grouping) + 4|0);
   $26 = HEAP32[$25>>2]|0;
   $30 = $26;
  }
  $29 = ($30|0)==(0);
  if (!($29)) {
   $31 = HEAP8[$__in_units>>0]|0;
   $32 = ($31<<24>>24)==(0);
   if ($32) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
   $33 = HEAP32[$__g_end>>2]|0;
   $34 = $33;
   $35 = $__g;
   $36 = (($34) - ($35))|0;
   $37 = ($36|0)<(160);
   if (!($37)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $38 = HEAP32[$__dc>>2]|0;
   $39 = (($33) + 4|0);
   HEAP32[$__g_end>>2] = $39;
   HEAP32[$33>>2] = $38;
   HEAP32[$__dc>>2] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $40 = (($__atoms) + 128|0);
 $$01$i = $__atoms;
 while(1) {
  $43 = HEAP32[$$01$i>>2]|0;
  $44 = ($43|0)==($__ct|0);
  $42 = (($$01$i) + 4|0);
  if ($44) {
   $$0$lcssa$i = $$01$i;
   break;
  }
  $41 = ($42|0)==($40|0);
  if ($41) {
   $$0$lcssa$i = $40;
   break;
  } else {
   $$01$i = $42;
  }
 }
 $45 = $$0$lcssa$i;
 $46 = $__atoms;
 $47 = (($45) - ($46))|0;
 $48 = $47 >> 2;
 $49 = ($47|0)>(124);
 if ($49) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $50 = (3091848 + ($48)|0);
 $51 = HEAP8[$50>>0]|0;
 if ((($48|0) == 24) | (($48|0) == 25)) {
  $52 = HEAP32[$__a_end>>2]|0;
  $53 = ($52|0)==($__a|0);
  if (!($53)) {
   $54 = (($52) + -1|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55&255;
   $57 = $56 & 95;
   $58 = HEAP8[$__exp>>0]|0;
   $59 = $58&255;
   $60 = $59 & 127;
   $61 = ($57|0)==($60|0);
   if (!($61)) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $62 = (($52) + 1|0);
  HEAP32[$__a_end>>2] = $62;
  HEAP8[$52>>0] = $51;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else if ((($48|0) == 23) | (($48|0) == 22)) {
  HEAP8[$__exp>>0] = 80;
 } else {
  $63 = $51&255;
  $64 = $63 & 95;
  $65 = HEAP8[$__exp>>0]|0;
  $66 = $65 << 24 >> 24;
  $67 = ($64|0)==($66|0);
  if ($67) {
   $68 = $64 | 128;
   $69 = $68&255;
   HEAP8[$__exp>>0] = $69;
   $70 = HEAP8[$__in_units>>0]|0;
   $71 = ($70<<24>>24)==(0);
   if (!($71)) {
    HEAP8[$__in_units>>0] = 0;
    $72 = HEAP8[$__grouping>>0]|0;
    $73 = $72 & 1;
    $74 = ($73<<24>>24)==(0);
    if ($74) {
     $77 = $72&255;
     $78 = $77 >>> 1;
     $80 = $78;
    } else {
     $75 = (($__grouping) + 4|0);
     $76 = HEAP32[$75>>2]|0;
     $80 = $76;
    }
    $79 = ($80|0)==(0);
    if (!($79)) {
     $81 = HEAP32[$__g_end>>2]|0;
     $82 = $81;
     $83 = $__g;
     $84 = (($82) - ($83))|0;
     $85 = ($84|0)<(160);
     if ($85) {
      $86 = HEAP32[$__dc>>2]|0;
      $87 = (($81) + 4|0);
      HEAP32[$__g_end>>2] = $87;
      HEAP32[$81>>2] = $86;
     }
    }
   }
  }
 }
 $88 = HEAP32[$__a_end>>2]|0;
 $89 = (($88) + 1|0);
 HEAP32[$__a_end>>2] = $89;
 HEAP8[$88>>0] = $51;
 $90 = ($47|0)>(84);
 if ($90) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $91 = HEAP32[$__dc>>2]|0;
 $92 = (($91) + 1)|0;
 HEAP32[$__dc>>2] = $92;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = $__v|0;
 var $$0 = 0, $$01 = 0, $$byval_copy = 0, $$ph = 0, $$pre = 0, $$pre$phi4Z2D = 0, $$pre$phi6Z2D = 0, $$pre3 = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $__nm = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__nm = sp + 8|0;
 $2 = (($__iob) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  $7 = (($6) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$__s>>2]|0;
  HEAP32[$0>>2] = $9;
  $10 = $__v&1;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_viiiiii[$8 & 255]($agg$result,$this,$$byval_copy,$__iob,$__fl,$10);
  STACKTOP = sp;return;
 }
 __ZNKSt3__18ios_base6getlocEv($1,$__iob);
 __THREW__ = 0;
 $11 = (invoke_iii(2228,($1|0),(3093480|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $57 = ___cxa_find_matching_catch()|0;
  $58 = tempRet0;
  $59 = HEAP32[$1>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($59)|0);
  $$0 = $57;$$01 = $58;
  ___resumeException($$0|0);
  // unreachable;
 }
 $14 = HEAP32[$1>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($14)|0);
 $15 = HEAP32[$11>>2]|0;
 if ($__v) {
  $16 = (($15) + 24|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 4095]($__nm,$11);
 } else {
  $18 = (($15) + 28|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vii[$19 & 4095]($__nm,$11);
 }
 $20 = HEAP8[$__nm>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $25 = (($__nm) + 1|0);
  $$pre5 = (($__nm) + 8|0);
  $$ph = $25;$$pre$phi4Z2D = $25;$$pre$phi6Z2D = $$pre5;
 } else {
  $23 = (($__nm) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $$pre3 = (($__nm) + 1|0);
  $$ph = $24;$$pre$phi4Z2D = $$pre3;$$pre$phi6Z2D = $23;
 }
 $26 = (($__nm) + 4|0);
 $28 = $20;$38 = $$ph;
 L17: while(1) {
  $27 = $28 & 1;
  $29 = ($27<<24>>24)==(0);
  if ($29) {
   $32 = $28&255;
   $33 = $32 >>> 1;
   $35 = $$pre$phi4Z2D;$36 = $33;
  } else {
   $30 = HEAP32[$$pre$phi6Z2D>>2]|0;
   $31 = HEAP32[$26>>2]|0;
   $35 = $30;$36 = $31;
  }
  $34 = (($35) + ($36)|0);
  $37 = ($38|0)==($34|0);
  if ($37) {
   label = 24;
   break;
  }
  $39 = HEAP8[$38>>0]|0;
  $40 = HEAP32[$__s>>2]|0;
  $41 = ($40|0)==(0|0);
  do {
   if (!($41)) {
    $42 = (($40) + 24|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($40) + 28|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ($43|0)==($45|0);
    if (!($46)) {
     $47 = (($43) + 1|0);
     HEAP32[$42>>2] = $47;
     HEAP8[$43>>0] = $39;
     break;
    }
    $48 = HEAP32[$40>>2]|0;
    $49 = (($48) + 52|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = $39&255;
    __THREW__ = 0;
    $52 = (invoke_iii($50|0,($40|0),($51|0))|0);
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     label = 23;
     break L17;
    }
    $55 = ($52|0)==(-1);
    if ($55) {
     HEAP32[$__s>>2] = 0;
    }
   }
  } while(0);
  $56 = (($38) + 1|0);
  $$pre = HEAP8[$__nm>>0]|0;
  $28 = $$pre;$38 = $56;
 }
 if ((label|0) == 23) {
  $60 = ___cxa_find_matching_catch()|0;
  $61 = tempRet0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__nm);
  $$0 = $60;$$01 = $61;
  ___resumeException($$0|0);
  // unreachable;
 }
 else if ((label|0) == 24) {
  $62 = HEAP32[$__s>>2]|0;
  HEAP32[$agg$result>>2] = $62;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__nm);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0;
 var $__nar = 0, $__o = 0, $__oe = 0, $__op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp;
 $__fmt = sp + 56|0;
 $__nar = sp + 44|0;
 $__o = sp + 20|0;
 $__op = sp + 12|0;
 $__oe = sp + 8|0;
 $0 = sp + 4|0;
 $1 = sp + 16|0;
 ;HEAP8[$__fmt+0>>0]=HEAP8[3092128+0>>0]|0;HEAP8[$__fmt+1>>0]=HEAP8[3092128+1>>0]|0;HEAP8[$__fmt+2>>0]=HEAP8[3092128+2>>0]|0;HEAP8[$__fmt+3>>0]=HEAP8[3092128+3>>0]|0;HEAP8[$__fmt+4>>0]=HEAP8[3092128+4>>0]|0;HEAP8[$__fmt+5>>0]=HEAP8[3092128+5>>0]|0;
 $2 = (($__fmt) + 1|0);
 $3 = (($__iob) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__114__num_put_base12__format_intEPcPKcbj($2,3092032,1,$4);
 $5 = (__ZNSt3__16__clocEv()|0);
 HEAP32[$$byval_copy>>2] = $__v;
 $6 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,12,$5,$__fmt,$$byval_copy)|0);
 $7 = (($__nar) + ($6)|0);
 $8 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$7,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 invoke_viiiiiii(77,($__nar|0),($8|0),($7|0),($__o|0),($__op|0),($__oe|0),($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($17)|0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  $12 = HEAP32[$__s>>2]|0;
  HEAP32[$1>>2] = $12;
  $13 = HEAP32[$__op>>2]|0;
  $14 = HEAP32[$__oe>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__116__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$13,$14,$__iob,$__fl);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__114__num_put_base12__format_intEPcPKcbj($__fmtp,$__len,$__signd,$__flags) {
 $__fmtp = $__fmtp|0;
 $__len = $__len|0;
 $__signd = $__signd|0;
 $__flags = $__flags|0;
 var $$0 = 0, $$012 = 0, $$1$lcssa = 0, $$1$ph = 0, $$13 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__flags & 2048;
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = $__fmtp;
 } else {
  $2 = (($__fmtp) + 1|0);
  HEAP8[$__fmtp>>0] = 43;
  $$0 = $2;
 }
 $3 = $__flags & 512;
 $4 = ($3|0)==(0);
 if ($4) {
  $$1$ph = $$0;
 } else {
  $5 = (($$0) + 1|0);
  HEAP8[$$0>>0] = 35;
  $$1$ph = $5;
 }
 $6 = HEAP8[$__len>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $$1$lcssa = $$1$ph;
 } else {
  $$012 = $__len;$$13 = $$1$ph;$10 = $6;
  while(1) {
   $8 = (($$012) + 1|0);
   $9 = (($$13) + 1|0);
   HEAP8[$$13>>0] = $10;
   $11 = HEAP8[$8>>0]|0;
   $12 = ($11<<24>>24)==(0);
   if ($12) {
    $$1$lcssa = $9;
    break;
   } else {
    $$012 = $8;$$13 = $9;$10 = $11;
   }
  }
 }
 $13 = $__flags & 74;
 if ((($13|0) == 64)) {
  HEAP8[$$1$lcssa>>0] = 111;
  STACKTOP = sp;return;
 } else if ((($13|0) == 8)) {
  $14 = $__flags & 16384;
  $15 = ($14|0)==(0);
  if ($15) {
   HEAP8[$$1$lcssa>>0] = 120;
   STACKTOP = sp;return;
  } else {
   HEAP8[$$1$lcssa>>0] = 88;
   STACKTOP = sp;return;
  }
 } else {
  if ($__signd) {
   HEAP8[$$1$lcssa>>0] = 100;
   STACKTOP = sp;return;
  } else {
   HEAP8[$$1$lcssa>>0] = 117;
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__s,$__n,$__l,$__format,$varargs) {
 $__s = $__s|0;
 $__n = $__n|0;
 $__l = $__l|0;
 $__format = $__format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $__va = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__va = sp;
 HEAP32[$__va>>2] = $varargs;
 $0 = (_uselocale(($__l|0))|0);
 $1 = (_vsnprintf($__s,$__n,$__format,$__va)|0);
 $2 = ($0|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return ($1|0);
 }
 __THREW__ = 0;
 (invoke_ii(3483,($0|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $5 = ___cxa_find_matching_catch(0|0)|0;
  $6 = tempRet0;
  ___clang_call_terminate($5);
  // unreachable;
 } else {
  STACKTOP = sp;return ($1|0);
 }
 return 0|0;
}
function __ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nb,$__ne,$__iob) {
 $__nb = $__nb|0;
 $__ne = $__ne|0;
 $__iob = $__iob|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__iob) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 176;
 do {
  if ((($2|0) == 16)) {
   $3 = HEAP8[$__nb>>0]|0;
   if ((($3<<24>>24) == 43) | (($3<<24>>24) == 45)) {
    $4 = (($__nb) + 1|0);
    $$0 = $4;
    break;
   }
   $5 = $__ne;
   $6 = $__nb;
   $7 = (($5) - ($6))|0;
   $8 = ($7|0)>(1);
   $9 = ($3<<24>>24)==(48);
   $or$cond = $8 & $9;
   if ($or$cond) {
    $10 = (($__nb) + 1|0);
    $11 = HEAP8[$10>>0]|0;
    if ((($11<<24>>24) == 88) | (($11<<24>>24) == 120)) {
     $12 = (($__nb) + 2|0);
     $$0 = $12;
    } else {
     label = 7;
    }
   } else {
    label = 7;
   }
  } else if ((($2|0) == 32)) {
   $$0 = $__ne;
  } else {
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $$0 = $__nb;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__19__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE($__nb,$__np,$__ne,$__ob,$__op,$__oe,$__loc) {
 $__nb = $__nb|0;
 $__np = $__np|0;
 $__ne = $__ne|0;
 $__ob = $__ob|0;
 $__op = $__op|0;
 $__oe = $__oe|0;
 $__loc = $__loc|0;
 var $$ = 0, $$012$i$i = 0, $$012$i$i5 = 0, $$12 = 0, $$__dg$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__dc$09 = 0, $__dc$1 = 0, $__dg$010 = 0, $__dg$1 = 0, $__grouping = 0, $__nf$0 = 0, $__nf$1 = 0, $__p$011 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__grouping = sp;
 $0 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093336)|0);
 $1 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093480)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($__grouping,$1);
 $5 = HEAP8[$__grouping>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = $5&255;
  $11 = $10 >>> 1;
  $13 = $11;
 } else {
  $8 = (($__grouping) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $13 = $9;
 }
 $12 = ($13|0)==(0);
 do {
  if ($12) {
   $14 = HEAP32[$0>>2]|0;
   $15 = (($14) + 32|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($16|0,($0|0),($__nb|0),($__ne|0),($__ob|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 8;
   } else {
    $19 = $__ne;
    $20 = $__nb;
    $21 = (($19) - ($20))|0;
    $22 = (($__ob) + ($21)|0);
    HEAP32[$__oe>>2] = $22;
   }
  } else {
   HEAP32[$__oe>>2] = $__ob;
   $27 = HEAP8[$__nb>>0]|0;
   if ((($27<<24>>24) == 43) | (($27<<24>>24) == 45)) {
    $28 = HEAP32[$0>>2]|0;
    $29 = (($28) + 28|0);
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iii($30|0,($0|0),($27|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     label = 8;
     break;
    }
    $34 = (($__nb) + 1|0);
    $35 = HEAP32[$__oe>>2]|0;
    $36 = (($35) + 1|0);
    HEAP32[$__oe>>2] = $36;
    HEAP8[$35>>0] = $31;
    $__nf$0 = $34;
   } else {
    $__nf$0 = $__nb;
   }
   $37 = $__ne;
   $38 = $__nf$0;
   $39 = (($37) - ($38))|0;
   $40 = ($39|0)>(1);
   if ($40) {
    $41 = HEAP8[$__nf$0>>0]|0;
    $42 = ($41<<24>>24)==(48);
    if ($42) {
     $43 = (($__nf$0) + 1|0);
     $44 = HEAP8[$43>>0]|0;
     if ((($44<<24>>24) == 88) | (($44<<24>>24) == 120)) {
      $45 = HEAP32[$0>>2]|0;
      $46 = (($45) + 28|0);
      $47 = HEAP32[$46>>2]|0;
      __THREW__ = 0;
      $48 = (invoke_iii($47|0,($0|0),48)|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 8;
       break;
      }
      $51 = HEAP32[$__oe>>2]|0;
      $52 = (($51) + 1|0);
      HEAP32[$__oe>>2] = $52;
      HEAP8[$51>>0] = $48;
      $53 = HEAP8[$43>>0]|0;
      $54 = HEAP32[$0>>2]|0;
      $55 = (($54) + 28|0);
      $56 = HEAP32[$55>>2]|0;
      __THREW__ = 0;
      $57 = (invoke_iii($56|0,($0|0),($53|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 8;
       break;
      }
      $60 = (($__nf$0) + 2|0);
      $61 = HEAP32[$__oe>>2]|0;
      $62 = (($61) + 1|0);
      HEAP32[$__oe>>2] = $62;
      HEAP8[$61>>0] = $57;
      $__nf$1 = $60;
     } else {
      $__nf$1 = $__nf$0;
     }
    } else {
     $__nf$1 = $__nf$0;
    }
   } else {
    $__nf$1 = $__nf$0;
   }
   $63 = ($__nf$1|0)==($__ne|0);
   if (!($63)) {
    $64 = (($__ne) + -1|0);
    $65 = ($64>>>0)>($__nf$1>>>0);
    if ($65) {
     $$012$i$i5 = $__nf$1;$68 = $64;
     while(1) {
      $66 = HEAP8[$$012$i$i5>>0]|0;
      $67 = HEAP8[$68>>0]|0;
      HEAP8[$$012$i$i5>>0] = $67;
      HEAP8[$68>>0] = $66;
      $69 = (($$012$i$i5) + 1|0);
      $70 = (($68) + -1|0);
      $71 = ($69>>>0)<($70>>>0);
      if ($71) {
       $$012$i$i5 = $69;$68 = $70;
      } else {
       break;
      }
     }
    }
   }
   $72 = HEAP32[$1>>2]|0;
   $73 = (($72) + 16|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_ii($74|0,($1|0))|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 8;
   } else {
    $78 = ($__nf$1>>>0)<($__ne>>>0);
    L26: do {
     if ($78) {
      $79 = (($__grouping) + 1|0);
      $80 = (($__grouping) + 4|0);
      $81 = (($__grouping) + 8|0);
      $__dc$09 = 0;$__dg$010 = 0;$__p$011 = $__nf$1;
      while(1) {
       $82 = HEAP8[$__grouping>>0]|0;
       $83 = $82 & 1;
       $84 = ($83<<24>>24)==(0);
       $85 = HEAP32[$81>>2]|0;
       $$ = $84 ? $79 : $85;
       $86 = (($$) + ($__dg$010)|0);
       $87 = HEAP8[$86>>0]|0;
       $88 = ($87<<24>>24)==(0);
       if ($88) {
        $__dc$1 = $__dc$09;$__dg$1 = $__dg$010;
       } else {
        $89 = HEAP32[$81>>2]|0;
        $$12 = $84 ? $79 : $89;
        $90 = (($$12) + ($__dg$010)|0);
        $91 = HEAP8[$90>>0]|0;
        $92 = $91 << 24 >> 24;
        $93 = ($__dc$09|0)==($92|0);
        if ($93) {
         $94 = HEAP32[$__oe>>2]|0;
         $95 = (($94) + 1|0);
         HEAP32[$__oe>>2] = $95;
         HEAP8[$94>>0] = $75;
         $96 = HEAP8[$__grouping>>0]|0;
         $97 = $96 & 1;
         $98 = ($97<<24>>24)==(0);
         if ($98) {
          $100 = $96&255;
          $101 = $100 >>> 1;
          $103 = $101;
         } else {
          $99 = HEAP32[$80>>2]|0;
          $103 = $99;
         }
         $102 = (($103) + -1)|0;
         $104 = ($__dg$010>>>0)<($102>>>0);
         $105 = $104&1;
         $$__dg$0 = (($105) + ($__dg$010))|0;
         $__dc$1 = 0;$__dg$1 = $$__dg$0;
        } else {
         $__dc$1 = $__dc$09;$__dg$1 = $__dg$010;
        }
       }
       $106 = HEAP8[$__p$011>>0]|0;
       $107 = HEAP32[$0>>2]|0;
       $108 = (($107) + 28|0);
       $109 = HEAP32[$108>>2]|0;
       __THREW__ = 0;
       $110 = (invoke_iii($109|0,($0|0),($106|0))|0);
       $111 = __THREW__; __THREW__ = 0;
       $112 = $111&1;
       if ($112) {
        break;
       }
       $113 = HEAP32[$__oe>>2]|0;
       $114 = (($113) + 1|0);
       HEAP32[$__oe>>2] = $114;
       HEAP8[$113>>0] = $110;
       $115 = (($__dc$1) + 1)|0;
       $116 = (($__p$011) + 1|0);
       $117 = ($116>>>0)<($__ne>>>0);
       if ($117) {
        $__dc$09 = $115;$__dg$010 = $__dg$1;$__p$011 = $116;
       } else {
        break L26;
       }
      }
      $23 = ___cxa_find_matching_catch()|0;
      $24 = tempRet0;
      $lpad$phi$index = $23;$lpad$phi$index2 = $24;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    } while(0);
    $118 = $__nf$1;
    $119 = $__nb;
    $120 = (($118) - ($119))|0;
    $121 = (($__ob) + ($120)|0);
    $122 = HEAP32[$__oe>>2]|0;
    $123 = ($121|0)==($122|0);
    if (!($123)) {
     $124 = (($122) + -1|0);
     $125 = ($124>>>0)>($121>>>0);
     if ($125) {
      $$012$i$i = $121;$128 = $124;
      while(1) {
       $126 = HEAP8[$$012$i$i>>0]|0;
       $127 = HEAP8[$128>>0]|0;
       HEAP8[$$012$i$i>>0] = $127;
       HEAP8[$128>>0] = $126;
       $129 = (($$012$i$i) + 1|0);
       $130 = (($128) + -1|0);
       $131 = ($129>>>0)<($130>>>0);
       if ($131) {
        $$012$i$i = $129;$128 = $130;
       } else {
        break;
       }
      }
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index2 = $26;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $132 = ($__np|0)==($__ne|0);
 if ($132) {
  $133 = HEAP32[$__oe>>2]|0;
  $storemerge = $133;
  HEAP32[$__op>>2] = $storemerge;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
  STACKTOP = sp;return;
 } else {
  $134 = $__np;
  $135 = $__nb;
  $136 = (($134) - ($135))|0;
  $137 = (($__ob) + ($136)|0);
  $storemerge = $137;
  HEAP32[$__op>>2] = $storemerge;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx($agg$result,$this,$__s,$__iob,$__fl,$0,$1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__o = 0, $__oe = 0, $__op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $$byval_copy = sp + 8|0;
 $__fmt = sp;
 $__nar = sp + 74|0;
 $__o = sp + 32|0;
 $__op = sp + 20|0;
 $__oe = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 $4 = $__fmt;
 $5 = $4;
 HEAP32[$5>>2] = 37;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($__fmt) + 1|0);
 $9 = (($__iob) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNSt3__114__num_put_base12__format_intEPcPKcbj($8,3092040,1,$10);
 $11 = (__ZNSt3__16__clocEv()|0);
 $12 = $$byval_copy;
 $13 = $12;
 HEAP32[$13>>2] = $0;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $1;
 $16 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,22,$11,$__fmt,$$byval_copy)|0);
 $17 = (($__nar) + ($16)|0);
 $18 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$17,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($2,$__iob);
 __THREW__ = 0;
 invoke_viiiiiii(77,($__nar|0),($18|0),($17|0),($__o|0),($__op|0),($__oe|0),($2|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $27 = HEAP32[$2>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($27)|0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  $21 = HEAP32[$2>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($21)|0);
  $22 = HEAP32[$__s>>2]|0;
  HEAP32[$3>>2] = $22;
  $23 = HEAP32[$__op>>2]|0;
  $24 = HEAP32[$__oe>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
  __ZNSt3__116__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$23,$24,$__iob,$__fl);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0;
 var $__nar = 0, $__o = 0, $__oe = 0, $__op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $$byval_copy = sp;
 $__fmt = sp + 56|0;
 $__nar = sp + 44|0;
 $__o = sp + 20|0;
 $__op = sp + 12|0;
 $__oe = sp + 8|0;
 $0 = sp + 4|0;
 $1 = sp + 16|0;
 ;HEAP8[$__fmt+0>>0]=HEAP8[3092128+0>>0]|0;HEAP8[$__fmt+1>>0]=HEAP8[3092128+1>>0]|0;HEAP8[$__fmt+2>>0]=HEAP8[3092128+2>>0]|0;HEAP8[$__fmt+3>>0]=HEAP8[3092128+3>>0]|0;HEAP8[$__fmt+4>>0]=HEAP8[3092128+4>>0]|0;HEAP8[$__fmt+5>>0]=HEAP8[3092128+5>>0]|0;
 $2 = (($__fmt) + 1|0);
 $3 = (($__iob) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__114__num_put_base12__format_intEPcPKcbj($2,3092032,0,$4);
 $5 = (__ZNSt3__16__clocEv()|0);
 HEAP32[$$byval_copy>>2] = $__v;
 $6 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,12,$5,$__fmt,$$byval_copy)|0);
 $7 = (($__nar) + ($6)|0);
 $8 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$7,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 invoke_viiiiiii(77,($__nar|0),($8|0),($7|0),($__o|0),($__op|0),($__oe|0),($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($17)|0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  $12 = HEAP32[$__s>>2]|0;
  HEAP32[$1>>2] = $12;
  $13 = HEAP32[$__op>>2]|0;
  $14 = HEAP32[$__oe>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__116__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$13,$14,$__iob,$__fl);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy($agg$result,$this,$__s,$__iob,$__fl,$0,$1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__o = 0, $__oe = 0, $__op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $$byval_copy = sp + 8|0;
 $__fmt = sp;
 $__nar = sp + 75|0;
 $__o = sp + 32|0;
 $__op = sp + 20|0;
 $__oe = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 28|0;
 $4 = $__fmt;
 $5 = $4;
 HEAP32[$5>>2] = 37;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($__fmt) + 1|0);
 $9 = (($__iob) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNSt3__114__num_put_base12__format_intEPcPKcbj($8,3092040,0,$10);
 $11 = (__ZNSt3__16__clocEv()|0);
 $12 = $$byval_copy;
 $13 = $12;
 HEAP32[$13>>2] = $0;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $1;
 $16 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,23,$11,$__fmt,$$byval_copy)|0);
 $17 = (($__nar) + ($16)|0);
 $18 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$17,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($2,$__iob);
 __THREW__ = 0;
 invoke_viiiiiii(77,($__nar|0),($18|0),($17|0),($__o|0),($__op|0),($__oe|0),($2|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $27 = HEAP32[$2>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($27)|0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  $21 = HEAP32[$2>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($21)|0);
  $22 = HEAP32[$__s>>2]|0;
  HEAP32[$3>>2] = $22;
  $23 = HEAP32[$__op>>2]|0;
  $24 = HEAP32[$__oe>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
  __ZNSt3__116__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$23,$24,$__iob,$__fl);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = +$__v;
 var $$0 = 0, $$01 = 0, $$127 = 0, $$18 = 0, $$byval_copy = 0, $$pre = 0, $$pre10 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__nb = 0;
 var $__nc$0 = 0, $__nc$1 = 0, $__nc$2 = 0, $__o = 0, $__ob$0 = 0, $__oe = 0, $__op = 0, $vararg_ptr1 = 0, $vararg_ptr12 = 0, $vararg_ptr8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 8|0;
 $__fmt = sp;
 $__nar = sp + 44|0;
 $__nb = sp + 36|0;
 $__o = sp + 74|0;
 $__op = sp + 40|0;
 $__oe = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 28|0;
 $2 = sp + 32|0;
 $3 = $__fmt;
 $4 = $3;
 HEAP32[$4>>2] = 37;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($__fmt) + 1|0);
 $8 = (($__iob) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNSt3__114__num_put_base14__format_floatEPcPKcj($7,3092048,$9)|0);
 HEAP32[$__nb>>2] = $__nar;
 $11 = (__ZNSt3__16__clocEv()|0);
 if ($10) {
  $12 = (($__iob) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$$byval_copy>>2] = $13;
  $vararg_ptr1 = (($$byval_copy) + 4|0);
  HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr1+4>>2]=HEAP32[tempDoublePtr+4>>2];
  $14 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,30,$11,$__fmt,$$byval_copy)|0);
  $__nc$0 = $14;
 } else {
  HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
  $15 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,30,$11,$__fmt,$$byval_copy)|0);
  $__nc$0 = $15;
 }
 $16 = ($__nc$0|0)>(29);
 do {
  if ($16) {
   if ($10) {
    __THREW__ = 0;
    $17 = (invoke_i(134)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = (($__iob) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     HEAP32[$$byval_copy>>2] = $21;
     $vararg_ptr8 = (($$byval_copy) + 4|0);
     HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr8>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr8+4>>2]=HEAP32[tempDoublePtr+4>>2];
     $22 = (invoke_iiiii(342,($__nb|0),($17|0),($__fmt|0),($$byval_copy|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $__nc$1 = $22;
      label = 12;
     }
    }
   } else {
    __THREW__ = 0;
    $27 = (invoke_i(134)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = (($__iob) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     HEAP32[$$byval_copy>>2] = $31;
     $vararg_ptr12 = (($$byval_copy) + 4|0);
     HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
     $32 = (invoke_iiiii(342,($__nb|0),($27|0),($__fmt|0),($$byval_copy|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $__nc$1 = $32;
      label = 12;
     }
    }
   }
   if ((label|0) == 12) {
    $35 = HEAP32[$__nb>>2]|0;
    $36 = ($35|0)==(0|0);
    if (!($36)) {
     $40 = $35;$69 = $35;$__nc$2 = $__nc$1;
     break;
    }
    __THREW__ = 0;
    invoke_v(1012);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     $$pre = HEAP32[$__nb>>2]|0;
     $40 = $$pre;$69 = $$pre;$__nc$2 = $__nc$1;
     break;
    }
   }
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   $$127 = $26;$$18 = $25;
   ___resumeException($$18|0);
   // unreachable;
  } else {
   $$pre9 = HEAP32[$__nb>>2]|0;
   $40 = $$pre9;$69 = 0;$__nc$2 = $__nc$0;
  }
 } while(0);
 $39 = (($40) + ($__nc$2)|0);
 $41 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($40,$39,$__iob)|0);
 $42 = ($40|0)==($__nar|0);
 if ($42) {
  $52 = $__nar;$63 = 0;$__ob$0 = $__o;
  label = 20;
 } else {
  $43 = $__nc$2 << 1;
  $44 = (_malloc($43)|0);
  $45 = ($44|0)==(0|0);
  if ($45) {
   __THREW__ = 0;
   invoke_v(1012);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $88 = 0;
    label = 19;
   } else {
    $$pre10 = HEAP32[$__nb>>2]|0;
    $52 = $$pre10;$63 = 0;$__ob$0 = 0;
    label = 20;
   }
  } else {
   $52 = $40;$63 = $44;$__ob$0 = $44;
   label = 20;
  }
 }
 do {
  if ((label|0) == 20) {
   __THREW__ = 0;
   invoke_vii(2475,($0|0),($__iob|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $88 = $63;
    label = 19;
   } else {
    __THREW__ = 0;
    invoke_viiiiiii(78,($52|0),($41|0),($39|0),($__ob$0|0),($__op|0),($__oe|0),($0|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     $74 = ___cxa_find_matching_catch()|0;
     $75 = tempRet0;
     $76 = HEAP32[$0>>2]|0;
     (__ZNSt3__114__shared_count16__release_sharedEv($76)|0);
     $$0 = $74;$$01 = $75;$78 = $63;
     break;
    }
    $55 = HEAP32[$0>>2]|0;
    (__ZNSt3__114__shared_count16__release_sharedEv($55)|0);
    $56 = HEAP32[$__s>>2]|0;
    HEAP32[$2>>2] = $56;
    $57 = HEAP32[$__op>>2]|0;
    $58 = HEAP32[$__oe>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viiiiiii(60,($1|0),($$byval_copy|0),($__ob$0|0),($57|0),($58|0),($__iob|0),($__fl|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     $88 = $63;
     label = 19;
    } else {
     $61 = HEAP32[$1>>2]|0;
     HEAP32[$__s>>2] = $61;
     HEAP32[$agg$result>>2] = $61;
     $62 = ($63|0)==(0|0);
     if (!($62)) {
      __THREW__ = 0;
      invoke_vi(3853,($63|0));
      $64 = __THREW__; __THREW__ = 0;
      $65 = $64&1;
      if ($65) {
       $66 = ___cxa_find_matching_catch(0|0)|0;
       $67 = tempRet0;
       ___clang_call_terminate($66);
       // unreachable;
      }
     }
     $68 = ($69|0)==(0|0);
     if ($68) {
      STACKTOP = sp;return;
     }
     __THREW__ = 0;
     invoke_vi(3853,($69|0));
     $70 = __THREW__; __THREW__ = 0;
     $71 = $70&1;
     if ($71) {
      $72 = ___cxa_find_matching_catch(0|0)|0;
      $73 = tempRet0;
      ___clang_call_terminate($72);
      // unreachable;
     } else {
      STACKTOP = sp;return;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $$0 = $48;$$01 = $49;$78 = $88;
 }
 $77 = ($78|0)==(0|0);
 if (!($77)) {
  __THREW__ = 0;
  invoke_vi(3853,($78|0));
  $79 = __THREW__; __THREW__ = 0;
  $80 = $79&1;
  if ($80) {
   $81 = ___cxa_find_matching_catch(0|0)|0;
   $82 = tempRet0;
   ___clang_call_terminate($81);
   // unreachable;
  }
 }
 $83 = ($69|0)==(0|0);
 if ($83) {
  $$127 = $$01;$$18 = $$0;
  ___resumeException($$18|0);
  // unreachable;
 }
 __THREW__ = 0;
 invoke_vi(3853,($69|0));
 $84 = __THREW__; __THREW__ = 0;
 $85 = $84&1;
 if ($85) {
  $86 = ___cxa_find_matching_catch(0|0)|0;
  $87 = tempRet0;
  ___clang_call_terminate($86);
  // unreachable;
 } else {
  $$127 = $$01;$$18 = $$0;
  ___resumeException($$18|0);
  // unreachable;
 }
}
function __ZNSt3__114__num_put_base14__format_floatEPcPKcj($__fmtp,$__len,$__flags) {
 $__fmtp = $__fmtp|0;
 $__len = $__len|0;
 $__flags = $__flags|0;
 var $$0 = 0, $$012 = 0, $$1 = 0, $$2$lcssa = 0, $$2$ph = 0, $$23 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $specify_precision$0$off0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__flags & 2048;
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = $__fmtp;
 } else {
  $2 = (($__fmtp) + 1|0);
  HEAP8[$__fmtp>>0] = 43;
  $$0 = $2;
 }
 $3 = $__flags & 1024;
 $4 = ($3|0)==(0);
 if ($4) {
  $$1 = $$0;
 } else {
  $5 = (($$0) + 1|0);
  HEAP8[$$0>>0] = 35;
  $$1 = $5;
 }
 $6 = $__flags & 260;
 $7 = $__flags >>> 14;
 $8 = ($6|0)==(260);
 if ($8) {
  $$2$ph = $$1;$specify_precision$0$off0$ph = 0;
 } else {
  $9 = (($$1) + 1|0);
  HEAP8[$$1>>0] = 46;
  $10 = (($$1) + 2|0);
  HEAP8[$9>>0] = 42;
  $$2$ph = $10;$specify_precision$0$off0$ph = 1;
 }
 $11 = HEAP8[$__len>>0]|0;
 $12 = ($11<<24>>24)==(0);
 if ($12) {
  $$2$lcssa = $$2$ph;
 } else {
  $$012 = $__len;$$23 = $$2$ph;$15 = $11;
  while(1) {
   $13 = (($$012) + 1|0);
   $14 = (($$23) + 1|0);
   HEAP8[$$23>>0] = $15;
   $16 = HEAP8[$13>>0]|0;
   $17 = ($16<<24>>24)==(0);
   if ($17) {
    $$2$lcssa = $14;
    break;
   } else {
    $$012 = $13;$$23 = $14;$15 = $16;
   }
  }
 }
 do {
  if ((($6|0) == 4)) {
   $18 = $7 & 1;
   $19 = ($18|0)==(0);
   if ($19) {
    HEAP8[$$2$lcssa>>0] = 102;
    break;
   } else {
    HEAP8[$$2$lcssa>>0] = 70;
    break;
   }
  } else if ((($6|0) == 256)) {
   $20 = $7 & 1;
   $21 = ($20|0)==(0);
   if ($21) {
    HEAP8[$$2$lcssa>>0] = 101;
    break;
   } else {
    HEAP8[$$2$lcssa>>0] = 69;
    break;
   }
  } else {
   $22 = $7 & 1;
   $23 = ($22|0)!=(0);
   if ($8) {
    if ($23) {
     HEAP8[$$2$lcssa>>0] = 65;
     break;
    } else {
     HEAP8[$$2$lcssa>>0] = 97;
     break;
    }
   } else {
    if ($23) {
     HEAP8[$$2$lcssa>>0] = 71;
     break;
    } else {
     HEAP8[$$2$lcssa>>0] = 103;
     break;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($specify_precision$0$off0$ph|0);
}
function __ZNSt3__112__asprintf_lEPPcP15__locale_structPKcz($__s,$__l,$__format,$varargs) {
 $__s = $__s|0;
 $__l = $__l|0;
 $__format = $__format|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__va = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__va = sp;
 HEAP32[$__va>>2] = $varargs;
 $0 = (_uselocale(($__l|0))|0);
 __THREW__ = 0;
 $1 = (invoke_iiii(1683,($__s|0),($__format|0),($__va|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if ($3) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = ($0|0)==(0|0);
  if ($11) {
   ___resumeException($9|0);
   // unreachable;
  }
  __THREW__ = 0;
  (invoke_ii(3483,($0|0))|0);
  $12 = __THREW__; __THREW__ = 0;
  $13 = $12&1;
  if ($13) {
   $14 = ___cxa_find_matching_catch(0|0)|0;
   $15 = tempRet0;
   ___clang_call_terminate($14);
   // unreachable;
  } else {
   ___resumeException($9|0);
   // unreachable;
  }
 } else {
  $4 = ($0|0)==(0|0);
  if ($4) {
   STACKTOP = sp;return ($1|0);
  }
  __THREW__ = 0;
  (invoke_ii(3483,($0|0))|0);
  $5 = __THREW__; __THREW__ = 0;
  $6 = $5&1;
  if ($6) {
   $7 = ___cxa_find_matching_catch(0|0)|0;
   $8 = tempRet0;
   ___clang_call_terminate($7);
   // unreachable;
  } else {
   STACKTOP = sp;return ($1|0);
  }
 }
 return 0|0;
}
function __ZNSt3__19__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE($__nb,$__np,$__ne,$__ob,$__op,$__oe,$__loc) {
 $__nb = $__nb|0;
 $__np = $__np|0;
 $__ne = $__ne|0;
 $__ob = $__ob|0;
 $__op = $__op|0;
 $__oe = $__oe|0;
 $__loc = $__loc|0;
 var $$ = 0, $$012$i$i = 0, $$012$i$i7 = 0, $$47 = 0, $$__dg$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__dc$018 = 0, $__dc$1 = 0, $__dg$019 = 0, $__dg$1 = 0, $__grouping = 0, $__nf$0 = 0, $__nf$1 = 0, $__nf$214 = 0, $__nf$3 = 0, $__ns$034 = 0, $__ns$126 = 0, $__ns$2 = 0, $__p$020 = 0, $lpad$phi$index = 0;
 var $lpad$phi$index5 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__grouping = sp;
 $0 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093336)|0);
 $1 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093480)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($__grouping,$1);
 HEAP32[$__oe>>2] = $__ob;
 $5 = HEAP8[$__nb>>0]|0;
 if ((($5<<24>>24) == 43) | (($5<<24>>24) == 45)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = (($6) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  __THREW__ = 0;
  $9 = (invoke_iii($8|0,($0|0),($5|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = (($__nb) + 1|0);
   $13 = HEAP32[$__oe>>2]|0;
   $14 = (($13) + 1|0);
   HEAP32[$__oe>>2] = $14;
   HEAP8[$13>>0] = $9;
   $__nf$0 = $12;
   label = 10;
  }
 } else {
  $__nf$0 = $__nb;
  label = 10;
 }
 L4: do {
  if ((label|0) == 10) {
   $25 = $__ne;
   $26 = $__nf$0;
   $27 = (($25) - ($26))|0;
   $28 = ($27|0)>(1);
   L6: do {
    if ($28) {
     $30 = HEAP8[$__nf$0>>0]|0;
     $31 = ($30<<24>>24)==(48);
     if ($31) {
      $32 = (($__nf$0) + 1|0);
      $33 = HEAP8[$32>>0]|0;
      if ((($33<<24>>24) == 88) | (($33<<24>>24) == 120)) {
       $34 = HEAP32[$0>>2]|0;
       $35 = (($34) + 28|0);
       $36 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       $37 = (invoke_iii($36|0,($0|0),48)|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break L4;
       }
       $40 = HEAP32[$__oe>>2]|0;
       $41 = (($40) + 1|0);
       HEAP32[$__oe>>2] = $41;
       HEAP8[$40>>0] = $37;
       $42 = (($__nf$0) + 2|0);
       $43 = HEAP8[$32>>0]|0;
       $44 = HEAP32[$0>>2]|0;
       $45 = (($44) + 28|0);
       $46 = HEAP32[$45>>2]|0;
       __THREW__ = 0;
       $47 = (invoke_iii($46|0,($0|0),($43|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break L4;
       }
       $50 = HEAP32[$__oe>>2]|0;
       $51 = (($50) + 1|0);
       HEAP32[$__oe>>2] = $51;
       HEAP8[$50>>0] = $47;
       $52 = ($42>>>0)<($__ne>>>0);
       if ($52) {
        $__ns$034 = $42;
        while(1) {
         $55 = HEAP8[$__ns$034>>0]|0;
         __THREW__ = 0;
         $56 = (invoke_i(134)|0);
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break;
         }
         $59 = $55 << 24 >> 24;
         __THREW__ = 0;
         $60 = (invoke_iii(2785,($59|0),($56|0))|0);
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          break;
         }
         $63 = ($60|0)==(0);
         $54 = (($__ns$034) + 1|0);
         if ($63) {
          $__nf$1 = $42;$__ns$2 = $__ns$034;
          break L6;
         }
         $53 = ($54>>>0)<($__ne>>>0);
         if ($53) {
          $__ns$034 = $54;
         } else {
          $__nf$1 = $42;$__ns$2 = $54;
          break L6;
         }
        }
        $21 = ___cxa_find_matching_catch()|0;
        $22 = tempRet0;
        $lpad$phi$index = $21;$lpad$phi$index5 = $22;
        __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       } else {
        $__nf$1 = $42;$__ns$2 = $42;
       }
      } else {
       label = 11;
      }
     } else {
      label = 11;
     }
    } else {
     label = 11;
    }
   } while(0);
   L19: do {
    if ((label|0) == 11) {
     $29 = ($__nf$0>>>0)<($__ne>>>0);
     if ($29) {
      $__ns$126 = $__nf$0;
      while(1) {
       $66 = HEAP8[$__ns$126>>0]|0;
       __THREW__ = 0;
       $67 = (invoke_i(134)|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       $70 = $66 << 24 >> 24;
       __THREW__ = 0;
       $71 = (invoke_iii(2786,($70|0),($67|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = ($71|0)==(0);
       $65 = (($__ns$126) + 1|0);
       if ($74) {
        $__nf$1 = $__nf$0;$__ns$2 = $__ns$126;
        break L19;
       }
       $64 = ($65>>>0)<($__ne>>>0);
       if ($64) {
        $__ns$126 = $65;
       } else {
        $__nf$1 = $__nf$0;$__ns$2 = $65;
        break L19;
       }
      }
      $19 = ___cxa_find_matching_catch()|0;
      $20 = tempRet0;
      $lpad$phi$index = $19;$lpad$phi$index5 = $20;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     } else {
      $__nf$1 = $__nf$0;$__ns$2 = $__nf$0;
     }
    }
   } while(0);
   $75 = HEAP8[$__grouping>>0]|0;
   $76 = $75 & 1;
   $77 = ($76<<24>>24)==(0);
   if ($77) {
    $80 = $75&255;
    $81 = $80 >>> 1;
    $83 = $81;
   } else {
    $78 = (($__grouping) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $83 = $79;
   }
   $82 = ($83|0)==(0);
   if ($82) {
    $84 = HEAP32[$__oe>>2]|0;
    $85 = HEAP32[$0>>2]|0;
    $86 = (($85) + 32|0);
    $87 = HEAP32[$86>>2]|0;
    __THREW__ = 0;
    (invoke_iiiii($87|0,($0|0),($__nf$1|0),($__ns$2|0),($84|0))|0);
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     break;
    }
    $90 = $__ns$2;
    $91 = $__nf$1;
    $92 = (($90) - ($91))|0;
    $93 = HEAP32[$__oe>>2]|0;
    $94 = (($93) + ($92)|0);
    HEAP32[$__oe>>2] = $94;
   } else {
    $95 = ($__nf$1|0)==($__ns$2|0);
    if (!($95)) {
     $96 = (($__ns$2) + -1|0);
     $97 = ($96>>>0)>($__nf$1>>>0);
     if ($97) {
      $$012$i$i = $__nf$1;$100 = $96;
      while(1) {
       $98 = HEAP8[$$012$i$i>>0]|0;
       $99 = HEAP8[$100>>0]|0;
       HEAP8[$$012$i$i>>0] = $99;
       HEAP8[$100>>0] = $98;
       $101 = (($$012$i$i) + 1|0);
       $102 = (($100) + -1|0);
       $103 = ($101>>>0)<($102>>>0);
       if ($103) {
        $$012$i$i = $101;$100 = $102;
       } else {
        break;
       }
      }
     }
    }
    $104 = HEAP32[$1>>2]|0;
    $105 = (($104) + 16|0);
    $106 = HEAP32[$105>>2]|0;
    __THREW__ = 0;
    $107 = (invoke_ii($106|0,($1|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     break;
    }
    $110 = ($__nf$1>>>0)<($__ns$2>>>0);
    L41: do {
     if ($110) {
      $111 = (($__grouping) + 1|0);
      $112 = (($__grouping) + 4|0);
      $113 = (($__grouping) + 8|0);
      $__dc$018 = 0;$__dg$019 = 0;$__p$020 = $__nf$1;
      while(1) {
       $114 = HEAP8[$__grouping>>0]|0;
       $115 = $114 & 1;
       $116 = ($115<<24>>24)==(0);
       $117 = HEAP32[$113>>2]|0;
       $$ = $116 ? $111 : $117;
       $118 = (($$) + ($__dg$019)|0);
       $119 = HEAP8[$118>>0]|0;
       $120 = ($119<<24>>24)>(0);
       if ($120) {
        $121 = HEAP32[$113>>2]|0;
        $$47 = $116 ? $111 : $121;
        $122 = (($$47) + ($__dg$019)|0);
        $123 = HEAP8[$122>>0]|0;
        $124 = $123 << 24 >> 24;
        $125 = ($__dc$018|0)==($124|0);
        if ($125) {
         $126 = HEAP32[$__oe>>2]|0;
         $127 = (($126) + 1|0);
         HEAP32[$__oe>>2] = $127;
         HEAP8[$126>>0] = $107;
         $128 = HEAP8[$__grouping>>0]|0;
         $129 = $128 & 1;
         $130 = ($129<<24>>24)==(0);
         if ($130) {
          $132 = $128&255;
          $133 = $132 >>> 1;
          $135 = $133;
         } else {
          $131 = HEAP32[$112>>2]|0;
          $135 = $131;
         }
         $134 = (($135) + -1)|0;
         $136 = ($__dg$019>>>0)<($134>>>0);
         $137 = $136&1;
         $$__dg$0 = (($137) + ($__dg$019))|0;
         $__dc$1 = 0;$__dg$1 = $$__dg$0;
        } else {
         $__dc$1 = $__dc$018;$__dg$1 = $__dg$019;
        }
       } else {
        $__dc$1 = $__dc$018;$__dg$1 = $__dg$019;
       }
       $138 = HEAP8[$__p$020>>0]|0;
       $139 = HEAP32[$0>>2]|0;
       $140 = (($139) + 28|0);
       $141 = HEAP32[$140>>2]|0;
       __THREW__ = 0;
       $142 = (invoke_iii($141|0,($0|0),($138|0))|0);
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        break;
       }
       $145 = HEAP32[$__oe>>2]|0;
       $146 = (($145) + 1|0);
       HEAP32[$__oe>>2] = $146;
       HEAP8[$145>>0] = $142;
       $147 = (($__dc$1) + 1)|0;
       $148 = (($__p$020) + 1|0);
       $149 = ($148>>>0)<($__ns$2>>>0);
       if ($149) {
        $__dc$018 = $147;$__dg$019 = $__dg$1;$__p$020 = $148;
       } else {
        break L41;
       }
      }
      $17 = ___cxa_find_matching_catch()|0;
      $18 = tempRet0;
      $lpad$phi$index = $17;$lpad$phi$index5 = $18;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
    } while(0);
    $150 = $__nf$1;
    $151 = $__nb;
    $152 = (($150) - ($151))|0;
    $153 = (($__ob) + ($152)|0);
    $154 = HEAP32[$__oe>>2]|0;
    $155 = ($153|0)==($154|0);
    if (!($155)) {
     $156 = (($154) + -1|0);
     $157 = ($156>>>0)>($153>>>0);
     if ($157) {
      $$012$i$i7 = $153;$160 = $156;
      while(1) {
       $158 = HEAP8[$$012$i$i7>>0]|0;
       $159 = HEAP8[$160>>0]|0;
       HEAP8[$$012$i$i7>>0] = $159;
       HEAP8[$160>>0] = $158;
       $161 = (($$012$i$i7) + 1|0);
       $162 = (($160) + -1|0);
       $163 = ($161>>>0)<($162>>>0);
       if ($163) {
        $$012$i$i7 = $161;$160 = $162;
       } else {
        break;
       }
      }
     }
    }
   }
   $164 = ($__ns$2>>>0)<($__ne>>>0);
   L63: do {
    if ($164) {
     $__nf$214 = $__ns$2;
     while(1) {
      $165 = HEAP8[$__nf$214>>0]|0;
      $166 = ($165<<24>>24)==(46);
      if ($166) {
       label = 51;
       break;
      }
      $176 = HEAP32[$0>>2]|0;
      $177 = (($176) + 28|0);
      $178 = HEAP32[$177>>2]|0;
      __THREW__ = 0;
      $179 = (invoke_iii($178|0,($0|0),($165|0))|0);
      $180 = __THREW__; __THREW__ = 0;
      $181 = $180&1;
      if ($181) {
       label = 4;
       break;
      }
      $182 = HEAP32[$__oe>>2]|0;
      $183 = (($182) + 1|0);
      HEAP32[$__oe>>2] = $183;
      HEAP8[$182>>0] = $179;
      $184 = (($__nf$214) + 1|0);
      $185 = ($184>>>0)<($__ne>>>0);
      if ($185) {
       $__nf$214 = $184;
      } else {
       $__nf$3 = $184;
       break L63;
      }
     }
     if ((label|0) == 4) {
      $15 = ___cxa_find_matching_catch()|0;
      $16 = tempRet0;
      $lpad$phi$index = $15;$lpad$phi$index5 = $16;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 51) {
      $167 = HEAP32[$1>>2]|0;
      $168 = (($167) + 12|0);
      $169 = HEAP32[$168>>2]|0;
      __THREW__ = 0;
      $170 = (invoke_ii($169|0,($1|0))|0);
      $171 = __THREW__; __THREW__ = 0;
      $172 = $171&1;
      if ($172) {
       break L4;
      }
      $173 = HEAP32[$__oe>>2]|0;
      $174 = (($173) + 1|0);
      HEAP32[$__oe>>2] = $174;
      HEAP8[$173>>0] = $170;
      $175 = (($__nf$214) + 1|0);
      $__nf$3 = $175;
      break;
     }
    } else {
     $__nf$3 = $__ns$2;
    }
   } while(0);
   $186 = HEAP32[$__oe>>2]|0;
   $187 = HEAP32[$0>>2]|0;
   $188 = (($187) + 32|0);
   $189 = HEAP32[$188>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($189|0,($0|0),($__nf$3|0),($__ne|0),($186|0))|0);
   $190 = __THREW__; __THREW__ = 0;
   $191 = $190&1;
   if (!($191)) {
    $192 = $__nf$3;
    $193 = (($25) - ($192))|0;
    $194 = HEAP32[$__oe>>2]|0;
    $195 = (($194) + ($193)|0);
    HEAP32[$__oe>>2] = $195;
    $196 = ($__np|0)==($__ne|0);
    if ($196) {
     $storemerge = $195;
     HEAP32[$__op>>2] = $storemerge;
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
     STACKTOP = sp;return;
    }
    $197 = $__np;
    $198 = $__nb;
    $199 = (($197) - ($198))|0;
    $200 = (($__ob) + ($199)|0);
    $storemerge = $200;
    HEAP32[$__op>>2] = $storemerge;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $lpad$phi$index = $23;$lpad$phi$index5 = $24;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = +$__v;
 var $$0 = 0, $$01 = 0, $$127 = 0, $$18 = 0, $$byval_copy = 0, $$pre = 0, $$pre10 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__nb = 0, $__nc$0 = 0, $__nc$1 = 0;
 var $__nc$2 = 0, $__o = 0, $__ob$0 = 0, $__oe = 0, $__op = 0, $vararg_ptr1 = 0, $vararg_ptr8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 8|0;
 $__fmt = sp;
 $__nar = sp + 44|0;
 $__nb = sp + 36|0;
 $__o = sp + 74|0;
 $__op = sp + 40|0;
 $__oe = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 28|0;
 $2 = sp + 32|0;
 $3 = $__fmt;
 $4 = $3;
 HEAP32[$4>>2] = 37;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($__fmt) + 1|0);
 $8 = (($__iob) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNSt3__114__num_put_base14__format_floatEPcPKcj($7,3092056,$9)|0);
 HEAP32[$__nb>>2] = $__nar;
 $11 = (__ZNSt3__16__clocEv()|0);
 if ($10) {
  $12 = (($__iob) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$$byval_copy>>2] = $13;
  $vararg_ptr1 = (($$byval_copy) + 4|0);
  HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr1+4>>2]=HEAP32[tempDoublePtr+4>>2];
  $14 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,30,$11,$__fmt,$$byval_copy)|0);
  $__nc$0 = $14;
 } else {
  HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
  $15 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,30,$11,$__fmt,$$byval_copy)|0);
  $__nc$0 = $15;
 }
 $16 = ($__nc$0|0)>(29);
 do {
  if ($16) {
   if ($10) {
    __THREW__ = 0;
    $17 = (invoke_i(134)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = (($__iob) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     HEAP32[$$byval_copy>>2] = $21;
     $vararg_ptr8 = (($$byval_copy) + 4|0);
     HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr8>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr8+4>>2]=HEAP32[tempDoublePtr+4>>2];
     $22 = (invoke_iiiii(342,($__nb|0),($17|0),($__fmt|0),($$byval_copy|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $__nc$1 = $22;
      label = 12;
     }
    }
   } else {
    __THREW__ = 0;
    $27 = (invoke_i(134)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     __THREW__ = 0;
     HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
     $30 = (invoke_iiiii(342,($__nb|0),($27|0),($__fmt|0),($$byval_copy|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $__nc$1 = $30;
      label = 12;
     }
    }
   }
   if ((label|0) == 12) {
    $33 = HEAP32[$__nb>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     $38 = $33;$61 = $33;$__nc$2 = $__nc$1;
     break;
    }
    __THREW__ = 0;
    invoke_v(1012);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $$pre = HEAP32[$__nb>>2]|0;
     $38 = $$pre;$61 = $$pre;$__nc$2 = $__nc$1;
     break;
    }
   }
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   $$127 = $26;$$18 = $25;
   ___resumeException($$18|0);
   // unreachable;
  } else {
   $$pre9 = HEAP32[$__nb>>2]|0;
   $38 = $$pre9;$61 = 0;$__nc$2 = $__nc$0;
  }
 } while(0);
 $37 = (($38) + ($__nc$2)|0);
 $39 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($38,$37,$__iob)|0);
 $40 = ($38|0)==($__nar|0);
 if ($40) {
  $50 = $__nar;$60 = 0;$__ob$0 = $__o;
  label = 20;
 } else {
  $41 = $__nc$2 << 1;
  $42 = (_malloc($41)|0);
  $43 = ($42|0)==(0|0);
  if ($43) {
   __THREW__ = 0;
   invoke_v(1012);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $66 = 0;
    label = 19;
   } else {
    $$pre10 = HEAP32[$__nb>>2]|0;
    $50 = $$pre10;$60 = 0;$__ob$0 = 0;
    label = 20;
   }
  } else {
   $50 = $38;$60 = $42;$__ob$0 = $42;
   label = 20;
  }
 }
 do {
  if ((label|0) == 20) {
   __THREW__ = 0;
   invoke_vii(2475,($0|0),($__iob|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $66 = $60;
    label = 19;
   } else {
    __THREW__ = 0;
    invoke_viiiiiii(78,($50|0),($39|0),($37|0),($__ob$0|0),($__op|0),($__oe|0),($0|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     $62 = ___cxa_find_matching_catch()|0;
     $63 = tempRet0;
     $64 = HEAP32[$0>>2]|0;
     (__ZNSt3__114__shared_count16__release_sharedEv($64)|0);
     $$0 = $62;$$01 = $63;$65 = $60;
     break;
    }
    $53 = HEAP32[$0>>2]|0;
    (__ZNSt3__114__shared_count16__release_sharedEv($53)|0);
    $54 = HEAP32[$__s>>2]|0;
    HEAP32[$2>>2] = $54;
    $55 = HEAP32[$__op>>2]|0;
    $56 = HEAP32[$__oe>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viiiiiii(60,($1|0),($$byval_copy|0),($__ob$0|0),($55|0),($56|0),($__iob|0),($__fl|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $66 = $60;
     label = 19;
    } else {
     $59 = HEAP32[$1>>2]|0;
     HEAP32[$agg$result>>2] = $59;
     _free($60);
     _free($61);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $$0 = $46;$$01 = $47;$65 = $66;
 }
 _free($65);
 _free($61);
 $$127 = $$01;$$18 = $$0;
 ___resumeException($$18|0);
 // unreachable;
}
function __ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__o = 0, $__op$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $$byval_copy = sp;
 $__fmt = sp + 72|0;
 $__nar = sp + 52|0;
 $__o = sp + 12|0;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 ;HEAP8[$__fmt+0>>0]=HEAP8[3092136+0>>0]|0;HEAP8[$__fmt+1>>0]=HEAP8[3092136+1>>0]|0;HEAP8[$__fmt+2>>0]=HEAP8[3092136+2>>0]|0;HEAP8[$__fmt+3>>0]=HEAP8[3092136+3>>0]|0;HEAP8[$__fmt+4>>0]=HEAP8[3092136+4>>0]|0;HEAP8[$__fmt+5>>0]=HEAP8[3092136+5>>0]|0;
 $2 = (__ZNSt3__16__clocEv()|0);
 HEAP32[$$byval_copy>>2] = $__v;
 $3 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,20,$2,$__fmt,$$byval_copy)|0);
 $4 = (($__nar) + ($3)|0);
 $5 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$4,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $6 = (invoke_iii(2228,($0|0),(3093336|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($17)|0);
  ___resumeException($15|0);
  // unreachable;
 }
 $9 = HEAP32[$0>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($9)|0);
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiiii[$12 & 511]($6,$__nar,$4,$__o)|0);
 $13 = (($__o) + ($3)|0);
 $14 = ($5|0)==($4|0);
 if ($14) {
  $__op$0 = $13;
  $22 = HEAP32[$__s>>2]|0;
  HEAP32[$1>>2] = $22;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__116__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$__op$0,$13,$__iob,$__fl);
  STACKTOP = sp;return;
 }
 $18 = $__nar;
 $19 = $5;
 $20 = (($19) - ($18))|0;
 $21 = (($__o) + ($20)|0);
 $__op$0 = $21;
 $22 = HEAP32[$__s>>2]|0;
 HEAP32[$1>>2] = $22;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__116__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$__op$0,$13,$__iob,$__fl);
 STACKTOP = sp;return;
}
function __ZNSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i = 0, $$01 = 0, $$byval_copy = 0, $$ph = 0, $$pre = 0, $$pre$phi4Z2D = 0, $$pre$phiZ2D = 0, $$pre2 = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $__nm = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy = sp + 20|0;
 $0 = sp;
 $1 = sp + 4|0;
 $__nm = sp + 8|0;
 $2 = (($__iob) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = HEAP32[$this>>2]|0;
  $7 = (($6) + 24|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$__s>>2]|0;
  HEAP32[$0>>2] = $9;
  $10 = $__v&1;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
  FUNCTION_TABLE_viiiiii[$8 & 255]($agg$result,$this,$$byval_copy,$__iob,$__fl,$10);
  STACKTOP = sp;return;
 }
 __ZNKSt3__18ios_base6getlocEv($1,$__iob);
 __THREW__ = 0;
 $11 = (invoke_iii(2228,($1|0),(3093488|0))|0);
 $12 = __THREW__; __THREW__ = 0;
 $13 = $12&1;
 if ($13) {
  $55 = ___cxa_find_matching_catch()|0;
  $56 = tempRet0;
  $57 = HEAP32[$1>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($57)|0);
  $$0 = $55;$$01 = $56;
  ___resumeException($$0|0);
  // unreachable;
 }
 $14 = HEAP32[$1>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($14)|0);
 $15 = HEAP32[$11>>2]|0;
 if ($__v) {
  $16 = (($15) + 24|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 4095]($__nm,$11);
 } else {
  $18 = (($15) + 28|0);
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vii[$19 & 4095]($__nm,$11);
 }
 $20 = HEAP8[$__nm>>0]|0;
 $21 = $20 & 1;
 $22 = ($21<<24>>24)==(0);
 if ($22) {
  $25 = (($__nm) + 4|0);
  $$pre3 = (($__nm) + 8|0);
  $$ph = $25;$$pre$phi4Z2D = $$pre3;$$pre$phiZ2D = $25;
 } else {
  $23 = (($__nm) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $$pre2 = (($__nm) + 4|0);
  $$ph = $24;$$pre$phi4Z2D = $23;$$pre$phiZ2D = $$pre2;
 }
 $27 = $20;$37 = $$ph;
 while(1) {
  $26 = $27 & 1;
  $28 = ($26<<24>>24)==(0);
  if ($28) {
   $31 = $27&255;
   $32 = $31 >>> 1;
   $34 = $$pre$phiZ2D;$35 = $32;
  } else {
   $29 = HEAP32[$$pre$phi4Z2D>>2]|0;
   $30 = HEAP32[$$pre$phiZ2D>>2]|0;
   $34 = $29;$35 = $30;
  }
  $33 = (($34) + ($35<<2)|0);
  $36 = ($37|0)==($33|0);
  if ($36) {
   label = 24;
   break;
  }
  $38 = HEAP32[$37>>2]|0;
  $39 = HEAP32[$__s>>2]|0;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   $41 = (($39) + 24|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (($39) + 28|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = ($42|0)==($44|0);
   if ($45) {
    $46 = HEAP32[$39>>2]|0;
    $47 = (($46) + 52|0);
    $48 = HEAP32[$47>>2]|0;
    __THREW__ = 0;
    $49 = (invoke_iii($48|0,($39|0),($38|0))|0);
    $50 = __THREW__; __THREW__ = 0;
    $51 = $50&1;
    if ($51) {
     label = 23;
     break;
    } else {
     $$0$i$i = $49;
    }
   } else {
    $52 = (($42) + 4|0);
    HEAP32[$41>>2] = $52;
    HEAP32[$42>>2] = $38;
    $$0$i$i = $38;
   }
   $53 = ($$0$i$i|0)==(-1);
   if ($53) {
    HEAP32[$__s>>2] = 0;
   }
  }
  $54 = (($37) + 4|0);
  $$pre = HEAP8[$__nm>>0]|0;
  $27 = $$pre;$37 = $54;
 }
 if ((label|0) == 23) {
  $58 = ___cxa_find_matching_catch()|0;
  $59 = tempRet0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__nm);
  $$0 = $58;$$01 = $59;
  ___resumeException($$0|0);
  // unreachable;
 }
 else if ((label|0) == 24) {
  $60 = HEAP32[$__s>>2]|0;
  HEAP32[$agg$result>>2] = $60;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__nm);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0;
 var $__nar = 0, $__o = 0, $__oe = 0, $__op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp;
 $__fmt = sp + 116|0;
 $__nar = sp + 104|0;
 $__o = sp + 8|0;
 $__op = sp + 92|0;
 $__oe = sp + 96|0;
 $0 = sp + 4|0;
 $1 = sp + 100|0;
 ;HEAP8[$__fmt+0>>0]=HEAP8[3092128+0>>0]|0;HEAP8[$__fmt+1>>0]=HEAP8[3092128+1>>0]|0;HEAP8[$__fmt+2>>0]=HEAP8[3092128+2>>0]|0;HEAP8[$__fmt+3>>0]=HEAP8[3092128+3>>0]|0;HEAP8[$__fmt+4>>0]=HEAP8[3092128+4>>0]|0;HEAP8[$__fmt+5>>0]=HEAP8[3092128+5>>0]|0;
 $2 = (($__fmt) + 1|0);
 $3 = (($__iob) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__114__num_put_base12__format_intEPcPKcbj($2,3092032,1,$4);
 $5 = (__ZNSt3__16__clocEv()|0);
 HEAP32[$$byval_copy>>2] = $__v;
 $6 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,12,$5,$__fmt,$$byval_copy)|0);
 $7 = (($__nar) + ($6)|0);
 $8 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$7,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 invoke_viiiiiii(79,($__nar|0),($8|0),($7|0),($__o|0),($__op|0),($__oe|0),($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($17)|0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  $12 = HEAP32[$__s>>2]|0;
  HEAP32[$1>>2] = $12;
  $13 = HEAP32[$__op>>2]|0;
  $14 = HEAP32[$__oe>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__116__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$13,$14,$__iob,$__fl);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__19__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE($__nb,$__np,$__ne,$__ob,$__op,$__oe,$__loc) {
 $__nb = $__nb|0;
 $__np = $__np|0;
 $__ne = $__ne|0;
 $__ob = $__ob|0;
 $__op = $__op|0;
 $__oe = $__oe|0;
 $__loc = $__loc|0;
 var $$ = 0, $$012$i$i = 0, $$012$i$i5 = 0, $$11 = 0, $$__dg$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__dc$08 = 0, $__dc$1 = 0, $__dg$09 = 0, $__dg$1 = 0, $__grouping = 0, $__nf$0 = 0, $__nf$1 = 0, $__p$010 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__grouping = sp;
 $0 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093328)|0);
 $1 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093488)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($__grouping,$1);
 $5 = HEAP8[$__grouping>>0]|0;
 $6 = $5 & 1;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $10 = $5&255;
  $11 = $10 >>> 1;
  $13 = $11;
 } else {
  $8 = (($__grouping) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $13 = $9;
 }
 $12 = ($13|0)==(0);
 do {
  if ($12) {
   $14 = HEAP32[$0>>2]|0;
   $15 = (($14) + 48|0);
   $16 = HEAP32[$15>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($16|0,($0|0),($__nb|0),($__ne|0),($__ob|0))|0);
   $17 = __THREW__; __THREW__ = 0;
   $18 = $17&1;
   if ($18) {
    label = 8;
   } else {
    $19 = $__ne;
    $20 = $__nb;
    $21 = (($19) - ($20))|0;
    $22 = (($__ob) + ($21<<2)|0);
    HEAP32[$__oe>>2] = $22;
    $137 = $22;
   }
  } else {
   HEAP32[$__oe>>2] = $__ob;
   $27 = HEAP8[$__nb>>0]|0;
   if ((($27<<24>>24) == 43) | (($27<<24>>24) == 45)) {
    $28 = HEAP32[$0>>2]|0;
    $29 = (($28) + 44|0);
    $30 = HEAP32[$29>>2]|0;
    __THREW__ = 0;
    $31 = (invoke_iii($30|0,($0|0),($27|0))|0);
    $32 = __THREW__; __THREW__ = 0;
    $33 = $32&1;
    if ($33) {
     label = 8;
     break;
    }
    $34 = (($__nb) + 1|0);
    $35 = HEAP32[$__oe>>2]|0;
    $36 = (($35) + 4|0);
    HEAP32[$__oe>>2] = $36;
    HEAP32[$35>>2] = $31;
    $__nf$0 = $34;
   } else {
    $__nf$0 = $__nb;
   }
   $37 = $__ne;
   $38 = $__nf$0;
   $39 = (($37) - ($38))|0;
   $40 = ($39|0)>(1);
   if ($40) {
    $41 = HEAP8[$__nf$0>>0]|0;
    $42 = ($41<<24>>24)==(48);
    if ($42) {
     $43 = (($__nf$0) + 1|0);
     $44 = HEAP8[$43>>0]|0;
     if ((($44<<24>>24) == 88) | (($44<<24>>24) == 120)) {
      $45 = HEAP32[$0>>2]|0;
      $46 = (($45) + 44|0);
      $47 = HEAP32[$46>>2]|0;
      __THREW__ = 0;
      $48 = (invoke_iii($47|0,($0|0),48)|0);
      $49 = __THREW__; __THREW__ = 0;
      $50 = $49&1;
      if ($50) {
       label = 8;
       break;
      }
      $51 = HEAP32[$__oe>>2]|0;
      $52 = (($51) + 4|0);
      HEAP32[$__oe>>2] = $52;
      HEAP32[$51>>2] = $48;
      $53 = HEAP8[$43>>0]|0;
      $54 = HEAP32[$0>>2]|0;
      $55 = (($54) + 44|0);
      $56 = HEAP32[$55>>2]|0;
      __THREW__ = 0;
      $57 = (invoke_iii($56|0,($0|0),($53|0))|0);
      $58 = __THREW__; __THREW__ = 0;
      $59 = $58&1;
      if ($59) {
       label = 8;
       break;
      }
      $60 = (($__nf$0) + 2|0);
      $61 = HEAP32[$__oe>>2]|0;
      $62 = (($61) + 4|0);
      HEAP32[$__oe>>2] = $62;
      HEAP32[$61>>2] = $57;
      $__nf$1 = $60;
     } else {
      $__nf$1 = $__nf$0;
     }
    } else {
     $__nf$1 = $__nf$0;
    }
   } else {
    $__nf$1 = $__nf$0;
   }
   $63 = ($__nf$1|0)==($__ne|0);
   if (!($63)) {
    $64 = (($__ne) + -1|0);
    $65 = ($64>>>0)>($__nf$1>>>0);
    if ($65) {
     $$012$i$i5 = $__nf$1;$68 = $64;
     while(1) {
      $66 = HEAP8[$$012$i$i5>>0]|0;
      $67 = HEAP8[$68>>0]|0;
      HEAP8[$$012$i$i5>>0] = $67;
      HEAP8[$68>>0] = $66;
      $69 = (($$012$i$i5) + 1|0);
      $70 = (($68) + -1|0);
      $71 = ($69>>>0)<($70>>>0);
      if ($71) {
       $$012$i$i5 = $69;$68 = $70;
      } else {
       break;
      }
     }
    }
   }
   $72 = HEAP32[$1>>2]|0;
   $73 = (($72) + 16|0);
   $74 = HEAP32[$73>>2]|0;
   __THREW__ = 0;
   $75 = (invoke_ii($74|0,($1|0))|0);
   $76 = __THREW__; __THREW__ = 0;
   $77 = $76&1;
   if ($77) {
    label = 8;
   } else {
    $78 = ($__nf$1>>>0)<($__ne>>>0);
    L26: do {
     if ($78) {
      $79 = (($__grouping) + 1|0);
      $80 = (($__grouping) + 4|0);
      $81 = (($__grouping) + 8|0);
      $__dc$08 = 0;$__dg$09 = 0;$__p$010 = $__nf$1;
      while(1) {
       $82 = HEAP8[$__grouping>>0]|0;
       $83 = $82 & 1;
       $84 = ($83<<24>>24)==(0);
       $85 = HEAP32[$81>>2]|0;
       $$ = $84 ? $79 : $85;
       $86 = (($$) + ($__dg$09)|0);
       $87 = HEAP8[$86>>0]|0;
       $88 = ($87<<24>>24)==(0);
       if ($88) {
        $__dc$1 = $__dc$08;$__dg$1 = $__dg$09;
       } else {
        $89 = HEAP32[$81>>2]|0;
        $$11 = $84 ? $79 : $89;
        $90 = (($$11) + ($__dg$09)|0);
        $91 = HEAP8[$90>>0]|0;
        $92 = $91 << 24 >> 24;
        $93 = ($__dc$08|0)==($92|0);
        if ($93) {
         $94 = HEAP32[$__oe>>2]|0;
         $95 = (($94) + 4|0);
         HEAP32[$__oe>>2] = $95;
         HEAP32[$94>>2] = $75;
         $96 = HEAP8[$__grouping>>0]|0;
         $97 = $96 & 1;
         $98 = ($97<<24>>24)==(0);
         if ($98) {
          $100 = $96&255;
          $101 = $100 >>> 1;
          $103 = $101;
         } else {
          $99 = HEAP32[$80>>2]|0;
          $103 = $99;
         }
         $102 = (($103) + -1)|0;
         $104 = ($__dg$09>>>0)<($102>>>0);
         $105 = $104&1;
         $$__dg$0 = (($105) + ($__dg$09))|0;
         $__dc$1 = 0;$__dg$1 = $$__dg$0;
        } else {
         $__dc$1 = $__dc$08;$__dg$1 = $__dg$09;
        }
       }
       $106 = HEAP8[$__p$010>>0]|0;
       $107 = HEAP32[$0>>2]|0;
       $108 = (($107) + 44|0);
       $109 = HEAP32[$108>>2]|0;
       __THREW__ = 0;
       $110 = (invoke_iii($109|0,($0|0),($106|0))|0);
       $111 = __THREW__; __THREW__ = 0;
       $112 = $111&1;
       if ($112) {
        break;
       }
       $113 = HEAP32[$__oe>>2]|0;
       $114 = (($113) + 4|0);
       HEAP32[$__oe>>2] = $114;
       HEAP32[$113>>2] = $110;
       $115 = (($__dc$1) + 1)|0;
       $116 = (($__p$010) + 1|0);
       $117 = ($116>>>0)<($__ne>>>0);
       if ($117) {
        $__dc$08 = $115;$__dg$09 = $__dg$1;$__p$010 = $116;
       } else {
        $123 = $114;
        break L26;
       }
      }
      $23 = ___cxa_find_matching_catch()|0;
      $24 = tempRet0;
      $lpad$phi$index = $23;$lpad$phi$index2 = $24;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     } else {
      $$pre = HEAP32[$__oe>>2]|0;
      $123 = $$pre;
     }
    } while(0);
    $118 = $__nf$1;
    $119 = $__nb;
    $120 = (($118) - ($119))|0;
    $121 = (($__ob) + ($120<<2)|0);
    $122 = ($121|0)==($123|0);
    if ($122) {
     $137 = $123;
    } else {
     $124 = (($123) + -4|0);
     $125 = ($124>>>0)>($121>>>0);
     if ($125) {
      $$012$i$i = $121;$128 = $124;
      while(1) {
       $126 = HEAP32[$$012$i$i>>2]|0;
       $127 = HEAP32[$128>>2]|0;
       HEAP32[$$012$i$i>>2] = $127;
       HEAP32[$128>>2] = $126;
       $129 = (($$012$i$i) + 4|0);
       $130 = (($128) + -4|0);
       $131 = ($129>>>0)<($130>>>0);
       if ($131) {
        $$012$i$i = $129;$128 = $130;
       } else {
        $137 = $123;
        break;
       }
      }
     } else {
      $137 = $123;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 8) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $lpad$phi$index = $25;$lpad$phi$index2 = $26;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $132 = ($__np|0)==($__ne|0);
 if ($132) {
  $storemerge = $137;
  HEAP32[$__op>>2] = $storemerge;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
  STACKTOP = sp;return;
 }
 $133 = $__np;
 $134 = $__nb;
 $135 = (($133) - ($134))|0;
 $136 = (($__ob) + ($135<<2)|0);
 $storemerge = $136;
 HEAP32[$__op>>2] = $storemerge;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 STACKTOP = sp;return;
}
function __ZNSt3__116__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$__s,$__ob,$__op,$__oe,$__iob,$__fl) {
 $agg$result = $agg$result|0;
 $__s = $__s|0;
 $__ob = $__ob|0;
 $__op = $__op|0;
 $__oe = $__oe|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__ns$0 = 0, $__sp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__sp = sp;
 $0 = HEAP32[$__s>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[$agg$result>>2] = 0;
  STACKTOP = sp;return;
 }
 $2 = $__oe;
 $3 = $__ob;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (($__iob) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>($5|0);
 $9 = (($7) - ($5))|0;
 $__ns$0 = $8 ? $9 : 0;
 $10 = $__op;
 $11 = (($10) - ($3))|0;
 $12 = $11 >> 2;
 $13 = ($11|0)>(0);
 if ($13) {
  $14 = HEAP32[$0>>2]|0;
  $15 = (($14) + 48|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (FUNCTION_TABLE_iiii[$16 & 2047]($0,$__ob,$12)|0);
  $18 = ($17|0)==($12|0);
  if (!($18)) {
   HEAP32[$__s>>2] = 0;
   HEAP32[$agg$result>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $19 = ($__ns$0|0)>(0);
 do {
  if ($19) {
   __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEjw($__sp,$__ns$0,$__fl);
   $20 = HEAP8[$__sp>>0]|0;
   $21 = $20 & 1;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    $25 = (($__sp) + 4|0);
    $29 = $25;
   } else {
    $23 = (($__sp) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    $29 = $24;
   }
   $26 = HEAP32[$0>>2]|0;
   $27 = (($26) + 48|0);
   $28 = HEAP32[$27>>2]|0;
   __THREW__ = 0;
   $30 = (invoke_iiii($28|0,($0|0),($29|0),($__ns$0|0))|0);
   $31 = __THREW__; __THREW__ = 0;
   $32 = $31&1;
   if ($32) {
    $34 = ___cxa_find_matching_catch()|0;
    $35 = tempRet0;
    __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sp);
    ___resumeException($34|0);
    // unreachable;
   }
   $33 = ($30|0)==($__ns$0|0);
   if ($33) {
    __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sp);
    break;
   }
   HEAP32[$__s>>2] = 0;
   HEAP32[$agg$result>>2] = 0;
   __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sp);
   STACKTOP = sp;return;
  }
 } while(0);
 $36 = (($2) - ($10))|0;
 $37 = $36 >> 2;
 $38 = ($36|0)>(0);
 if ($38) {
  $39 = HEAP32[$0>>2]|0;
  $40 = (($39) + 48|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (FUNCTION_TABLE_iiii[$41 & 2047]($0,$__op,$37)|0);
  $43 = ($42|0)==($37|0);
  if (!($43)) {
   HEAP32[$__s>>2] = 0;
   HEAP32[$agg$result>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 HEAP32[$6>>2] = 0;
 HEAP32[$agg$result>>2] = $0;
 STACKTOP = sp;return;
}
function __ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx($agg$result,$this,$__s,$__iob,$__fl,$0,$1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__o = 0, $__oe = 0, $__op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $$byval_copy = sp + 8|0;
 $__fmt = sp;
 $__nar = sp + 196|0;
 $__o = sp + 16|0;
 $__op = sp + 180|0;
 $__oe = sp + 184|0;
 $2 = sp + 188|0;
 $3 = sp + 192|0;
 $4 = $__fmt;
 $5 = $4;
 HEAP32[$5>>2] = 37;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($__fmt) + 1|0);
 $9 = (($__iob) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNSt3__114__num_put_base12__format_intEPcPKcbj($8,3092040,1,$10);
 $11 = (__ZNSt3__16__clocEv()|0);
 $12 = $$byval_copy;
 $13 = $12;
 HEAP32[$13>>2] = $0;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $1;
 $16 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,22,$11,$__fmt,$$byval_copy)|0);
 $17 = (($__nar) + ($16)|0);
 $18 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$17,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($2,$__iob);
 __THREW__ = 0;
 invoke_viiiiiii(79,($__nar|0),($18|0),($17|0),($__o|0),($__op|0),($__oe|0),($2|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $27 = HEAP32[$2>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($27)|0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  $21 = HEAP32[$2>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($21)|0);
  $22 = HEAP32[$__s>>2]|0;
  HEAP32[$3>>2] = $22;
  $23 = HEAP32[$__op>>2]|0;
  $24 = HEAP32[$__oe>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
  __ZNSt3__116__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$23,$24,$__iob,$__fl);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0;
 var $__nar = 0, $__o = 0, $__oe = 0, $__op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy = sp;
 $__fmt = sp + 116|0;
 $__nar = sp + 104|0;
 $__o = sp + 8|0;
 $__op = sp + 92|0;
 $__oe = sp + 96|0;
 $0 = sp + 4|0;
 $1 = sp + 100|0;
 ;HEAP8[$__fmt+0>>0]=HEAP8[3092128+0>>0]|0;HEAP8[$__fmt+1>>0]=HEAP8[3092128+1>>0]|0;HEAP8[$__fmt+2>>0]=HEAP8[3092128+2>>0]|0;HEAP8[$__fmt+3>>0]=HEAP8[3092128+3>>0]|0;HEAP8[$__fmt+4>>0]=HEAP8[3092128+4>>0]|0;HEAP8[$__fmt+5>>0]=HEAP8[3092128+5>>0]|0;
 $2 = (($__fmt) + 1|0);
 $3 = (($__iob) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNSt3__114__num_put_base12__format_intEPcPKcbj($2,3092032,0,$4);
 $5 = (__ZNSt3__16__clocEv()|0);
 HEAP32[$$byval_copy>>2] = $__v;
 $6 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,12,$5,$__fmt,$$byval_copy)|0);
 $7 = (($__nar) + ($6)|0);
 $8 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$7,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 invoke_viiiiiii(79,($__nar|0),($8|0),($7|0),($__o|0),($__op|0),($__oe|0),($0|0));
 $9 = __THREW__; __THREW__ = 0;
 $10 = $9&1;
 if ($10) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($17)|0);
  ___resumeException($15|0);
  // unreachable;
 } else {
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  $12 = HEAP32[$__s>>2]|0;
  HEAP32[$1>>2] = $12;
  $13 = HEAP32[$__op>>2]|0;
  $14 = HEAP32[$__oe>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__116__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$13,$14,$__iob,$__fl);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy($agg$result,$this,$__s,$__iob,$__fl,$0,$1) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$byval_copy = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__o = 0, $__oe = 0, $__op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $$byval_copy = sp + 8|0;
 $__fmt = sp;
 $__nar = sp + 204|0;
 $__o = sp + 16|0;
 $__op = sp + 188|0;
 $__oe = sp + 192|0;
 $2 = sp + 196|0;
 $3 = sp + 200|0;
 $4 = $__fmt;
 $5 = $4;
 HEAP32[$5>>2] = 37;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = (($__fmt) + 1|0);
 $9 = (($__iob) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 __ZNSt3__114__num_put_base12__format_intEPcPKcbj($8,3092040,0,$10);
 $11 = (__ZNSt3__16__clocEv()|0);
 $12 = $$byval_copy;
 $13 = $12;
 HEAP32[$13>>2] = $0;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $1;
 $16 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,23,$11,$__fmt,$$byval_copy)|0);
 $17 = (($__nar) + ($16)|0);
 $18 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$17,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($2,$__iob);
 __THREW__ = 0;
 invoke_viiiiiii(79,($__nar|0),($18|0),($17|0),($__o|0),($__op|0),($__oe|0),($2|0));
 $19 = __THREW__; __THREW__ = 0;
 $20 = $19&1;
 if ($20) {
  $25 = ___cxa_find_matching_catch()|0;
  $26 = tempRet0;
  $27 = HEAP32[$2>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($27)|0);
  ___resumeException($25|0);
  // unreachable;
 } else {
  $21 = HEAP32[$2>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($21)|0);
  $22 = HEAP32[$__s>>2]|0;
  HEAP32[$3>>2] = $22;
  $23 = HEAP32[$__op>>2]|0;
  $24 = HEAP32[$__oe>>2]|0;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
  __ZNSt3__116__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$23,$24,$__iob,$__fl);
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = +$__v;
 var $$0 = 0, $$01 = 0, $$125 = 0, $$16 = 0, $$byval_copy = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $__fmt = 0;
 var $__nar = 0, $__nb = 0, $__nc$0 = 0, $__nc$1 = 0, $__nc$2 = 0, $__o = 0, $__ob$0 = 0, $__oe = 0, $__op = 0, $vararg_ptr1 = 0, $vararg_ptr12 = 0, $vararg_ptr8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy = sp + 8|0;
 $__fmt = sp;
 $__nar = sp + 272|0;
 $__nb = sp + 264|0;
 $__o = sp + 36|0;
 $__op = sp + 268|0;
 $__oe = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 28|0;
 $2 = sp + 32|0;
 $3 = $__fmt;
 $4 = $3;
 HEAP32[$4>>2] = 37;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($__fmt) + 1|0);
 $8 = (($__iob) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNSt3__114__num_put_base14__format_floatEPcPKcj($7,3092048,$9)|0);
 HEAP32[$__nb>>2] = $__nar;
 $11 = (__ZNSt3__16__clocEv()|0);
 if ($10) {
  $12 = (($__iob) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$$byval_copy>>2] = $13;
  $vararg_ptr1 = (($$byval_copy) + 4|0);
  HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr1+4>>2]=HEAP32[tempDoublePtr+4>>2];
  $14 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,30,$11,$__fmt,$$byval_copy)|0);
  $__nc$0 = $14;
 } else {
  HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
  $15 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,30,$11,$__fmt,$$byval_copy)|0);
  $__nc$0 = $15;
 }
 $16 = ($__nc$0|0)>(29);
 do {
  if ($16) {
   if ($10) {
    __THREW__ = 0;
    $17 = (invoke_i(134)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = (($__iob) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     HEAP32[$$byval_copy>>2] = $21;
     $vararg_ptr8 = (($$byval_copy) + 4|0);
     HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr8>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr8+4>>2]=HEAP32[tempDoublePtr+4>>2];
     $22 = (invoke_iiiii(342,($__nb|0),($17|0),($__fmt|0),($$byval_copy|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $__nc$1 = $22;
      label = 12;
     }
    }
   } else {
    __THREW__ = 0;
    $27 = (invoke_i(134)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     $30 = (($__iob) + 8|0);
     $31 = HEAP32[$30>>2]|0;
     __THREW__ = 0;
     HEAP32[$$byval_copy>>2] = $31;
     $vararg_ptr12 = (($$byval_copy) + 4|0);
     HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
     $32 = (invoke_iiiii(342,($__nb|0),($27|0),($__fmt|0),($$byval_copy|0))|0);
     $33 = __THREW__; __THREW__ = 0;
     $34 = $33&1;
     if (!($34)) {
      $__nc$1 = $32;
      label = 12;
     }
    }
   }
   if ((label|0) == 12) {
    $35 = HEAP32[$__nb>>2]|0;
    $36 = ($35|0)==(0|0);
    if (!($36)) {
     $40 = $35;$64 = $35;$__nc$2 = $__nc$1;
     break;
    }
    __THREW__ = 0;
    invoke_v(1012);
    $37 = __THREW__; __THREW__ = 0;
    $38 = $37&1;
    if (!($38)) {
     $$pre = HEAP32[$__nb>>2]|0;
     $40 = $$pre;$64 = $$pre;$__nc$2 = $__nc$1;
     break;
    }
   }
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   $$125 = $26;$$16 = $25;
   ___resumeException($$16|0);
   // unreachable;
  } else {
   $$pre7 = HEAP32[$__nb>>2]|0;
   $40 = $$pre7;$64 = 0;$__nc$2 = $__nc$0;
  }
 } while(0);
 $39 = (($40) + ($__nc$2)|0);
 $41 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($40,$39,$__iob)|0);
 $42 = ($40|0)==($__nar|0);
 if ($42) {
  $52 = $__nar;$63 = 0;$__ob$0 = $__o;
  label = 20;
 } else {
  $43 = $__nc$2 << 3;
  $44 = (_malloc($43)|0);
  $45 = ($44|0)==(0|0);
  if ($45) {
   __THREW__ = 0;
   invoke_v(1012);
   $46 = __THREW__; __THREW__ = 0;
   $47 = $46&1;
   if ($47) {
    $70 = 0;
    label = 19;
   } else {
    $$pre8 = HEAP32[$__nb>>2]|0;
    $52 = $$pre8;$63 = $44;$__ob$0 = $44;
    label = 20;
   }
  } else {
   $52 = $40;$63 = $44;$__ob$0 = $44;
   label = 20;
  }
 }
 do {
  if ((label|0) == 20) {
   __THREW__ = 0;
   invoke_vii(2475,($0|0),($__iob|0));
   $50 = __THREW__; __THREW__ = 0;
   $51 = $50&1;
   if ($51) {
    $70 = $63;
    label = 19;
   } else {
    __THREW__ = 0;
    invoke_viiiiiii(80,($52|0),($41|0),($39|0),($__ob$0|0),($__op|0),($__oe|0),($0|0));
    $53 = __THREW__; __THREW__ = 0;
    $54 = $53&1;
    if ($54) {
     $65 = ___cxa_find_matching_catch()|0;
     $66 = tempRet0;
     $67 = HEAP32[$0>>2]|0;
     (__ZNSt3__114__shared_count16__release_sharedEv($67)|0);
     $$0 = $65;$$01 = $66;$69 = $63;
     break;
    }
    $55 = HEAP32[$0>>2]|0;
    (__ZNSt3__114__shared_count16__release_sharedEv($55)|0);
    $56 = HEAP32[$__s>>2]|0;
    HEAP32[$2>>2] = $56;
    $57 = HEAP32[$__op>>2]|0;
    $58 = HEAP32[$__oe>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viiiiiii(81,($1|0),($$byval_copy|0),($__ob$0|0),($57|0),($58|0),($__iob|0),($__fl|0));
    $59 = __THREW__; __THREW__ = 0;
    $60 = $59&1;
    if ($60) {
     $70 = $63;
     label = 19;
    } else {
     $61 = HEAP32[$1>>2]|0;
     HEAP32[$__s>>2] = $61;
     HEAP32[$agg$result>>2] = $61;
     $62 = ($63|0)==(0|0);
     if ($62) {
      _free($64);
      STACKTOP = sp;return;
     }
     _free($63);
     _free($64);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $48 = ___cxa_find_matching_catch()|0;
  $49 = tempRet0;
  $$0 = $48;$$01 = $49;$69 = $70;
 }
 $68 = ($69|0)==(0|0);
 if (!($68)) {
  _free($69);
 }
 _free($64);
 $$125 = $$01;$$16 = $$0;
 ___resumeException($$16|0);
 // unreachable;
}
function __ZNSt3__19__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE($__nb,$__np,$__ne,$__ob,$__op,$__oe,$__loc) {
 $__nb = $__nb|0;
 $__np = $__np|0;
 $__ne = $__ne|0;
 $__ob = $__ob|0;
 $__op = $__op|0;
 $__oe = $__oe|0;
 $__loc = $__loc|0;
 var $$ = 0, $$012$i$i = 0, $$012$i$i7 = 0, $$46 = 0, $$__dg$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__dc$017 = 0, $__dc$1 = 0, $__dg$018 = 0, $__dg$1 = 0, $__grouping = 0, $__nf$0 = 0, $__nf$1 = 0, $__nf$213 = 0, $__nf$3 = 0, $__ns$033 = 0, $__ns$125 = 0, $__ns$2 = 0;
 var $__p$019 = 0, $lpad$phi$index = 0, $lpad$phi$index5 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__grouping = sp;
 $0 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093328)|0);
 $1 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3093488)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 FUNCTION_TABLE_vii[$4 & 4095]($__grouping,$1);
 HEAP32[$__oe>>2] = $__ob;
 $5 = HEAP8[$__nb>>0]|0;
 if ((($5<<24>>24) == 43) | (($5<<24>>24) == 45)) {
  $6 = HEAP32[$0>>2]|0;
  $7 = (($6) + 44|0);
  $8 = HEAP32[$7>>2]|0;
  __THREW__ = 0;
  $9 = (invoke_iii($8|0,($0|0),($5|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   $12 = (($__nb) + 1|0);
   $13 = HEAP32[$__oe>>2]|0;
   $14 = (($13) + 4|0);
   HEAP32[$__oe>>2] = $14;
   HEAP32[$13>>2] = $9;
   $__nf$0 = $12;
   label = 10;
  }
 } else {
  $__nf$0 = $__nb;
  label = 10;
 }
 L4: do {
  if ((label|0) == 10) {
   $25 = $__ne;
   $26 = $__nf$0;
   $27 = (($25) - ($26))|0;
   $28 = ($27|0)>(1);
   L6: do {
    if ($28) {
     $30 = HEAP8[$__nf$0>>0]|0;
     $31 = ($30<<24>>24)==(48);
     if ($31) {
      $32 = (($__nf$0) + 1|0);
      $33 = HEAP8[$32>>0]|0;
      if ((($33<<24>>24) == 88) | (($33<<24>>24) == 120)) {
       $34 = HEAP32[$0>>2]|0;
       $35 = (($34) + 44|0);
       $36 = HEAP32[$35>>2]|0;
       __THREW__ = 0;
       $37 = (invoke_iii($36|0,($0|0),48)|0);
       $38 = __THREW__; __THREW__ = 0;
       $39 = $38&1;
       if ($39) {
        break L4;
       }
       $40 = HEAP32[$__oe>>2]|0;
       $41 = (($40) + 4|0);
       HEAP32[$__oe>>2] = $41;
       HEAP32[$40>>2] = $37;
       $42 = (($__nf$0) + 2|0);
       $43 = HEAP8[$32>>0]|0;
       $44 = HEAP32[$0>>2]|0;
       $45 = (($44) + 44|0);
       $46 = HEAP32[$45>>2]|0;
       __THREW__ = 0;
       $47 = (invoke_iii($46|0,($0|0),($43|0))|0);
       $48 = __THREW__; __THREW__ = 0;
       $49 = $48&1;
       if ($49) {
        break L4;
       }
       $50 = HEAP32[$__oe>>2]|0;
       $51 = (($50) + 4|0);
       HEAP32[$__oe>>2] = $51;
       HEAP32[$50>>2] = $47;
       $52 = ($42>>>0)<($__ne>>>0);
       if ($52) {
        $__ns$033 = $42;
        while(1) {
         $55 = HEAP8[$__ns$033>>0]|0;
         __THREW__ = 0;
         $56 = (invoke_i(134)|0);
         $57 = __THREW__; __THREW__ = 0;
         $58 = $57&1;
         if ($58) {
          break;
         }
         $59 = $55 << 24 >> 24;
         __THREW__ = 0;
         $60 = (invoke_iii(2785,($59|0),($56|0))|0);
         $61 = __THREW__; __THREW__ = 0;
         $62 = $61&1;
         if ($62) {
          break;
         }
         $63 = ($60|0)==(0);
         $54 = (($__ns$033) + 1|0);
         if ($63) {
          $__nf$1 = $42;$__ns$2 = $__ns$033;
          break L6;
         }
         $53 = ($54>>>0)<($__ne>>>0);
         if ($53) {
          $__ns$033 = $54;
         } else {
          $__nf$1 = $42;$__ns$2 = $54;
          break L6;
         }
        }
        $21 = ___cxa_find_matching_catch()|0;
        $22 = tempRet0;
        $lpad$phi$index = $21;$lpad$phi$index5 = $22;
        __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
        ___resumeException($lpad$phi$index|0);
        // unreachable;
       } else {
        $__nf$1 = $42;$__ns$2 = $42;
       }
      } else {
       label = 11;
      }
     } else {
      label = 11;
     }
    } else {
     label = 11;
    }
   } while(0);
   L19: do {
    if ((label|0) == 11) {
     $29 = ($__nf$0>>>0)<($__ne>>>0);
     if ($29) {
      $__ns$125 = $__nf$0;
      while(1) {
       $66 = HEAP8[$__ns$125>>0]|0;
       __THREW__ = 0;
       $67 = (invoke_i(134)|0);
       $68 = __THREW__; __THREW__ = 0;
       $69 = $68&1;
       if ($69) {
        break;
       }
       $70 = $66 << 24 >> 24;
       __THREW__ = 0;
       $71 = (invoke_iii(2786,($70|0),($67|0))|0);
       $72 = __THREW__; __THREW__ = 0;
       $73 = $72&1;
       if ($73) {
        break;
       }
       $74 = ($71|0)==(0);
       $65 = (($__ns$125) + 1|0);
       if ($74) {
        $__nf$1 = $__nf$0;$__ns$2 = $__ns$125;
        break L19;
       }
       $64 = ($65>>>0)<($__ne>>>0);
       if ($64) {
        $__ns$125 = $65;
       } else {
        $__nf$1 = $__nf$0;$__ns$2 = $65;
        break L19;
       }
      }
      $19 = ___cxa_find_matching_catch()|0;
      $20 = tempRet0;
      $lpad$phi$index = $19;$lpad$phi$index5 = $20;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     } else {
      $__nf$1 = $__nf$0;$__ns$2 = $__nf$0;
     }
    }
   } while(0);
   $75 = HEAP8[$__grouping>>0]|0;
   $76 = $75 & 1;
   $77 = ($76<<24>>24)==(0);
   if ($77) {
    $80 = $75&255;
    $81 = $80 >>> 1;
    $83 = $81;
   } else {
    $78 = (($__grouping) + 4|0);
    $79 = HEAP32[$78>>2]|0;
    $83 = $79;
   }
   $82 = ($83|0)==(0);
   if ($82) {
    $84 = HEAP32[$__oe>>2]|0;
    $85 = HEAP32[$0>>2]|0;
    $86 = (($85) + 48|0);
    $87 = HEAP32[$86>>2]|0;
    __THREW__ = 0;
    (invoke_iiiii($87|0,($0|0),($__nf$1|0),($__ns$2|0),($84|0))|0);
    $88 = __THREW__; __THREW__ = 0;
    $89 = $88&1;
    if ($89) {
     break;
    }
    $90 = $__ns$2;
    $91 = $__nf$1;
    $92 = (($90) - ($91))|0;
    $93 = HEAP32[$__oe>>2]|0;
    $94 = (($93) + ($92<<2)|0);
    HEAP32[$__oe>>2] = $94;
    $201 = $94;
   } else {
    $95 = ($__nf$1|0)==($__ns$2|0);
    if (!($95)) {
     $96 = (($__ns$2) + -1|0);
     $97 = ($96>>>0)>($__nf$1>>>0);
     if ($97) {
      $$012$i$i = $__nf$1;$100 = $96;
      while(1) {
       $98 = HEAP8[$$012$i$i>>0]|0;
       $99 = HEAP8[$100>>0]|0;
       HEAP8[$$012$i$i>>0] = $99;
       HEAP8[$100>>0] = $98;
       $101 = (($$012$i$i) + 1|0);
       $102 = (($100) + -1|0);
       $103 = ($101>>>0)<($102>>>0);
       if ($103) {
        $$012$i$i = $101;$100 = $102;
       } else {
        break;
       }
      }
     }
    }
    $104 = HEAP32[$1>>2]|0;
    $105 = (($104) + 16|0);
    $106 = HEAP32[$105>>2]|0;
    __THREW__ = 0;
    $107 = (invoke_ii($106|0,($1|0))|0);
    $108 = __THREW__; __THREW__ = 0;
    $109 = $108&1;
    if ($109) {
     break;
    }
    $110 = ($__nf$1>>>0)<($__ns$2>>>0);
    L43: do {
     if ($110) {
      $111 = (($__grouping) + 1|0);
      $112 = (($__grouping) + 4|0);
      $113 = (($__grouping) + 8|0);
      $__dc$017 = 0;$__dg$018 = 0;$__p$019 = $__nf$1;
      while(1) {
       $114 = HEAP8[$__grouping>>0]|0;
       $115 = $114 & 1;
       $116 = ($115<<24>>24)==(0);
       $117 = HEAP32[$113>>2]|0;
       $$ = $116 ? $111 : $117;
       $118 = (($$) + ($__dg$018)|0);
       $119 = HEAP8[$118>>0]|0;
       $120 = ($119<<24>>24)>(0);
       if ($120) {
        $121 = HEAP32[$113>>2]|0;
        $$46 = $116 ? $111 : $121;
        $122 = (($$46) + ($__dg$018)|0);
        $123 = HEAP8[$122>>0]|0;
        $124 = $123 << 24 >> 24;
        $125 = ($__dc$017|0)==($124|0);
        if ($125) {
         $126 = HEAP32[$__oe>>2]|0;
         $127 = (($126) + 4|0);
         HEAP32[$__oe>>2] = $127;
         HEAP32[$126>>2] = $107;
         $128 = HEAP8[$__grouping>>0]|0;
         $129 = $128 & 1;
         $130 = ($129<<24>>24)==(0);
         if ($130) {
          $132 = $128&255;
          $133 = $132 >>> 1;
          $135 = $133;
         } else {
          $131 = HEAP32[$112>>2]|0;
          $135 = $131;
         }
         $134 = (($135) + -1)|0;
         $136 = ($__dg$018>>>0)<($134>>>0);
         $137 = $136&1;
         $$__dg$0 = (($137) + ($__dg$018))|0;
         $__dc$1 = 0;$__dg$1 = $$__dg$0;
        } else {
         $__dc$1 = $__dc$017;$__dg$1 = $__dg$018;
        }
       } else {
        $__dc$1 = $__dc$017;$__dg$1 = $__dg$018;
       }
       $138 = HEAP8[$__p$019>>0]|0;
       $139 = HEAP32[$0>>2]|0;
       $140 = (($139) + 44|0);
       $141 = HEAP32[$140>>2]|0;
       __THREW__ = 0;
       $142 = (invoke_iii($141|0,($0|0),($138|0))|0);
       $143 = __THREW__; __THREW__ = 0;
       $144 = $143&1;
       if ($144) {
        break;
       }
       $145 = HEAP32[$__oe>>2]|0;
       $146 = (($145) + 4|0);
       HEAP32[$__oe>>2] = $146;
       HEAP32[$145>>2] = $142;
       $147 = (($__dc$1) + 1)|0;
       $148 = (($__p$019) + 1|0);
       $149 = ($148>>>0)<($__ns$2>>>0);
       if ($149) {
        $__dc$017 = $147;$__dg$018 = $__dg$1;$__p$019 = $148;
       } else {
        $155 = $146;
        break L43;
       }
      }
      $17 = ___cxa_find_matching_catch()|0;
      $18 = tempRet0;
      $lpad$phi$index = $17;$lpad$phi$index5 = $18;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     } else {
      $$pre = HEAP32[$__oe>>2]|0;
      $155 = $$pre;
     }
    } while(0);
    $150 = $__nf$1;
    $151 = $__nb;
    $152 = (($150) - ($151))|0;
    $153 = (($__ob) + ($152<<2)|0);
    $154 = ($153|0)==($155|0);
    if ($154) {
     $201 = $155;
    } else {
     $156 = (($155) + -4|0);
     $157 = ($156>>>0)>($153>>>0);
     if ($157) {
      $$012$i$i7 = $153;$160 = $156;
      while(1) {
       $158 = HEAP32[$$012$i$i7>>2]|0;
       $159 = HEAP32[$160>>2]|0;
       HEAP32[$$012$i$i7>>2] = $159;
       HEAP32[$160>>2] = $158;
       $161 = (($$012$i$i7) + 4|0);
       $162 = (($160) + -4|0);
       $163 = ($161>>>0)<($162>>>0);
       if ($163) {
        $$012$i$i7 = $161;$160 = $162;
       } else {
        $201 = $155;
        break;
       }
      }
     } else {
      $201 = $155;
     }
    }
   }
   $164 = ($__ns$2>>>0)<($__ne>>>0);
   L64: do {
    if ($164) {
     $__nf$213 = $__ns$2;
     while(1) {
      $165 = HEAP8[$__nf$213>>0]|0;
      $166 = ($165<<24>>24)==(46);
      if ($166) {
       label = 52;
       break;
      }
      $176 = HEAP32[$0>>2]|0;
      $177 = (($176) + 44|0);
      $178 = HEAP32[$177>>2]|0;
      __THREW__ = 0;
      $179 = (invoke_iii($178|0,($0|0),($165|0))|0);
      $180 = __THREW__; __THREW__ = 0;
      $181 = $180&1;
      if ($181) {
       label = 4;
       break;
      }
      $182 = HEAP32[$__oe>>2]|0;
      $183 = (($182) + 4|0);
      HEAP32[$__oe>>2] = $183;
      HEAP32[$182>>2] = $179;
      $184 = (($__nf$213) + 1|0);
      $185 = ($184>>>0)<($__ne>>>0);
      if ($185) {
       $__nf$213 = $184;
      } else {
       $189 = $183;$__nf$3 = $184;
       break L64;
      }
     }
     if ((label|0) == 4) {
      $15 = ___cxa_find_matching_catch()|0;
      $16 = tempRet0;
      $lpad$phi$index = $15;$lpad$phi$index5 = $16;
      __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
      ___resumeException($lpad$phi$index|0);
      // unreachable;
     }
     else if ((label|0) == 52) {
      $167 = HEAP32[$1>>2]|0;
      $168 = (($167) + 12|0);
      $169 = HEAP32[$168>>2]|0;
      __THREW__ = 0;
      $170 = (invoke_ii($169|0,($1|0))|0);
      $171 = __THREW__; __THREW__ = 0;
      $172 = $171&1;
      if ($172) {
       break L4;
      }
      $173 = HEAP32[$__oe>>2]|0;
      $174 = (($173) + 4|0);
      HEAP32[$__oe>>2] = $174;
      HEAP32[$173>>2] = $170;
      $175 = (($__nf$213) + 1|0);
      $189 = $174;$__nf$3 = $175;
      break;
     }
    } else {
     $189 = $201;$__nf$3 = $__ns$2;
    }
   } while(0);
   $186 = HEAP32[$0>>2]|0;
   $187 = (($186) + 48|0);
   $188 = HEAP32[$187>>2]|0;
   __THREW__ = 0;
   (invoke_iiiii($188|0,($0|0),($__nf$3|0),($__ne|0),($189|0))|0);
   $190 = __THREW__; __THREW__ = 0;
   $191 = $190&1;
   if (!($191)) {
    $192 = $__nf$3;
    $193 = (($25) - ($192))|0;
    $194 = HEAP32[$__oe>>2]|0;
    $195 = (($194) + ($193<<2)|0);
    HEAP32[$__oe>>2] = $195;
    $196 = ($__np|0)==($__ne|0);
    if ($196) {
     $storemerge = $195;
     HEAP32[$__op>>2] = $storemerge;
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
     STACKTOP = sp;return;
    }
    $197 = $__np;
    $198 = $__nb;
    $199 = (($197) - ($198))|0;
    $200 = (($__ob) + ($199<<2)|0);
    $storemerge = $200;
    HEAP32[$__op>>2] = $storemerge;
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $23 = ___cxa_find_matching_catch()|0;
 $24 = tempRet0;
 $lpad$phi$index = $23;$lpad$phi$index5 = $24;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grouping);
 ___resumeException($lpad$phi$index|0);
 // unreachable;
}
function __ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = +$__v;
 var $$0 = 0, $$01 = 0, $$125 = 0, $$16 = 0, $$byval_copy = 0, $$pre = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__nb = 0;
 var $__nc$0 = 0, $__nc$1 = 0, $__nc$2 = 0, $__o = 0, $__ob$0 = 0, $__oe = 0, $__op = 0, $vararg_ptr1 = 0, $vararg_ptr8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $$byval_copy = sp + 8|0;
 $__fmt = sp;
 $__nar = sp + 272|0;
 $__nb = sp + 264|0;
 $__o = sp + 36|0;
 $__op = sp + 268|0;
 $__oe = sp + 24|0;
 $0 = sp + 20|0;
 $1 = sp + 28|0;
 $2 = sp + 32|0;
 $3 = $__fmt;
 $4 = $3;
 HEAP32[$4>>2] = 37;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 $7 = (($__fmt) + 1|0);
 $8 = (($__iob) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNSt3__114__num_put_base14__format_floatEPcPKcj($7,3092056,$9)|0);
 HEAP32[$__nb>>2] = $__nar;
 $11 = (__ZNSt3__16__clocEv()|0);
 if ($10) {
  $12 = (($__iob) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[$$byval_copy>>2] = $13;
  $vararg_ptr1 = (($$byval_copy) + 4|0);
  HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr1>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr1+4>>2]=HEAP32[tempDoublePtr+4>>2];
  $14 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,30,$11,$__fmt,$$byval_copy)|0);
  $__nc$0 = $14;
 } else {
  HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
  $15 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,30,$11,$__fmt,$$byval_copy)|0);
  $__nc$0 = $15;
 }
 $16 = ($__nc$0|0)>(29);
 do {
  if ($16) {
   if ($10) {
    __THREW__ = 0;
    $17 = (invoke_i(134)|0);
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if (!($19)) {
     $20 = (($__iob) + 8|0);
     $21 = HEAP32[$20>>2]|0;
     __THREW__ = 0;
     HEAP32[$$byval_copy>>2] = $21;
     $vararg_ptr8 = (($$byval_copy) + 4|0);
     HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$vararg_ptr8>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr8+4>>2]=HEAP32[tempDoublePtr+4>>2];
     $22 = (invoke_iiiii(342,($__nb|0),($17|0),($__fmt|0),($$byval_copy|0))|0);
     $23 = __THREW__; __THREW__ = 0;
     $24 = $23&1;
     if (!($24)) {
      $__nc$1 = $22;
      label = 12;
     }
    }
   } else {
    __THREW__ = 0;
    $27 = (invoke_i(134)|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if (!($29)) {
     __THREW__ = 0;
     HEAPF64[tempDoublePtr>>3]=$__v;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
     $30 = (invoke_iiiii(342,($__nb|0),($27|0),($__fmt|0),($$byval_copy|0))|0);
     $31 = __THREW__; __THREW__ = 0;
     $32 = $31&1;
     if (!($32)) {
      $__nc$1 = $30;
      label = 12;
     }
    }
   }
   if ((label|0) == 12) {
    $33 = HEAP32[$__nb>>2]|0;
    $34 = ($33|0)==(0|0);
    if (!($34)) {
     $38 = $33;$62 = $33;$__nc$2 = $__nc$1;
     break;
    }
    __THREW__ = 0;
    invoke_v(1012);
    $35 = __THREW__; __THREW__ = 0;
    $36 = $35&1;
    if (!($36)) {
     $$pre = HEAP32[$__nb>>2]|0;
     $38 = $$pre;$62 = $$pre;$__nc$2 = $__nc$1;
     break;
    }
   }
   $25 = ___cxa_find_matching_catch()|0;
   $26 = tempRet0;
   $$125 = $26;$$16 = $25;
   ___resumeException($$16|0);
   // unreachable;
  } else {
   $$pre7 = HEAP32[$__nb>>2]|0;
   $38 = $$pre7;$62 = 0;$__nc$2 = $__nc$0;
  }
 } while(0);
 $37 = (($38) + ($__nc$2)|0);
 $39 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($38,$37,$__iob)|0);
 $40 = ($38|0)==($__nar|0);
 if ($40) {
  $50 = $__nar;$61 = 0;$__ob$0 = $__o;
  label = 20;
 } else {
  $41 = $__nc$2 << 3;
  $42 = (_malloc($41)|0);
  $43 = ($42|0)==(0|0);
  if ($43) {
   __THREW__ = 0;
   invoke_v(1012);
   $44 = __THREW__; __THREW__ = 0;
   $45 = $44&1;
   if ($45) {
    $68 = 0;
    label = 19;
   } else {
    $$pre8 = HEAP32[$__nb>>2]|0;
    $50 = $$pre8;$61 = $42;$__ob$0 = $42;
    label = 20;
   }
  } else {
   $50 = $38;$61 = $42;$__ob$0 = $42;
   label = 20;
  }
 }
 do {
  if ((label|0) == 20) {
   __THREW__ = 0;
   invoke_vii(2475,($0|0),($__iob|0));
   $48 = __THREW__; __THREW__ = 0;
   $49 = $48&1;
   if ($49) {
    $68 = $61;
    label = 19;
   } else {
    __THREW__ = 0;
    invoke_viiiiiii(80,($50|0),($39|0),($37|0),($__ob$0|0),($__op|0),($__oe|0),($0|0));
    $51 = __THREW__; __THREW__ = 0;
    $52 = $51&1;
    if ($52) {
     $63 = ___cxa_find_matching_catch()|0;
     $64 = tempRet0;
     $65 = HEAP32[$0>>2]|0;
     (__ZNSt3__114__shared_count16__release_sharedEv($65)|0);
     $$0 = $63;$$01 = $64;$67 = $61;
     break;
    }
    $53 = HEAP32[$0>>2]|0;
    (__ZNSt3__114__shared_count16__release_sharedEv($53)|0);
    $54 = HEAP32[$__s>>2]|0;
    HEAP32[$2>>2] = $54;
    $55 = HEAP32[$__op>>2]|0;
    $56 = HEAP32[$__oe>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
    invoke_viiiiiii(81,($1|0),($$byval_copy|0),($__ob$0|0),($55|0),($56|0),($__iob|0),($__fl|0));
    $57 = __THREW__; __THREW__ = 0;
    $58 = $57&1;
    if ($58) {
     $68 = $61;
     label = 19;
    } else {
     $59 = HEAP32[$1>>2]|0;
     HEAP32[$__s>>2] = $59;
     HEAP32[$agg$result>>2] = $59;
     $60 = ($61|0)==(0|0);
     if ($60) {
      _free($62);
      STACKTOP = sp;return;
     }
     _free($61);
     _free($62);
     STACKTOP = sp;return;
    }
   }
  }
 } while(0);
 if ((label|0) == 19) {
  $46 = ___cxa_find_matching_catch()|0;
  $47 = tempRet0;
  $$0 = $46;$$01 = $47;$67 = $68;
 }
 $66 = ($67|0)==(0|0);
 if (!($66)) {
  _free($67);
 }
 _free($62);
 $$125 = $$01;$$16 = $$0;
 ___resumeException($$16|0);
 // unreachable;
}
function __ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv($agg$result,$this,$__s,$__iob,$__fl,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__v = $__v|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__fmt = 0, $__nar = 0, $__o = 0, $__op$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $$byval_copy = sp;
 $__fmt = sp + 180|0;
 $__nar = sp + 160|0;
 $__o = sp + 8|0;
 $0 = sp + 4|0;
 $1 = sp + 156|0;
 ;HEAP8[$__fmt+0>>0]=HEAP8[3092136+0>>0]|0;HEAP8[$__fmt+1>>0]=HEAP8[3092136+1>>0]|0;HEAP8[$__fmt+2>>0]=HEAP8[3092136+2>>0]|0;HEAP8[$__fmt+3>>0]=HEAP8[3092136+3>>0]|0;HEAP8[$__fmt+4>>0]=HEAP8[3092136+4>>0]|0;HEAP8[$__fmt+5>>0]=HEAP8[3092136+5>>0]|0;
 $2 = (__ZNSt3__16__clocEv()|0);
 HEAP32[$$byval_copy>>2] = $__v;
 $3 = (__ZNSt3__112__snprintf_lEPcjP15__locale_structPKcz($__nar,20,$2,$__fmt,$$byval_copy)|0);
 $4 = (($__nar) + ($3)|0);
 $5 = (__ZNSt3__114__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE($__nar,$4,$__iob)|0);
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $6 = (invoke_iii(2228,($0|0),(3093328|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $15 = ___cxa_find_matching_catch()|0;
  $16 = tempRet0;
  $17 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($17)|0);
  ___resumeException($15|0);
  // unreachable;
 }
 $9 = HEAP32[$0>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($9)|0);
 $10 = HEAP32[$6>>2]|0;
 $11 = (($10) + 48|0);
 $12 = HEAP32[$11>>2]|0;
 (FUNCTION_TABLE_iiiii[$12 & 511]($6,$__nar,$4,$__o)|0);
 $13 = (($__o) + ($3<<2)|0);
 $14 = ($5|0)==($4|0);
 if ($14) {
  $__op$0 = $13;
  $22 = HEAP32[$__s>>2]|0;
  HEAP32[$1>>2] = $22;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNSt3__116__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$__op$0,$13,$__iob,$__fl);
  STACKTOP = sp;return;
 }
 $18 = $__nar;
 $19 = $5;
 $20 = (($19) - ($18))|0;
 $21 = (($__o) + ($20<<2)|0);
 $__op$0 = $21;
 $22 = HEAP32[$__s>>2]|0;
 HEAP32[$1>>2] = $22;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNSt3__116__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_($agg$result,$$byval_copy,$__o,$__op$0,$13,$__iob,$__fl);
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm,$__fmtb,$__fmte) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 $__fmtb = $__fmtb|0;
 $__fmte = $__fmte|0;
 var $$0$i$i = 0, $$0$i$i24 = 0, $$0$ph$be = 0, $$0$ph37 = 0, $$0$pn = 0, $$1 = 0, $$2 = 0, $$2$lcssa = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i15 = 0, $$pre$i$i$i6 = 0, $$pre$i2$i$i19 = 0, $$pre$i2$i$i1939 = 0, $$pre$i2$i$i1940 = 0, $$pre38 = 0, $$pre38$pre = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__cmd$0 = 0, $__opt$0 = 0, $isascii1$i = 0, $isascii1$i22 = 0, $isascii1$i3 = 0, $sext = 0, $tmp$i$i21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $4 = (invoke_iii(2228,($0|0),(3093336|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $38 = ___cxa_find_matching_catch()|0;
  $39 = tempRet0;
  $40 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($40)|0);
  ___resumeException($38|0);
  // unreachable;
 }
 $7 = HEAP32[$0>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($7)|0);
 HEAP32[$__err>>2] = 0;
 $8 = ($__fmtb|0)==($__fmte|0);
 L4: do {
  if ($8) {
   label = 62;
  } else {
   $9 = (($4) + 8|0);
   $$0$ph37 = $__fmtb;$$pre38 = 0;
   L6: while(1) {
    $11 = $$pre38;
    while(1) {
     $10 = ($11|0)==(0);
     if (!($10)) {
      label = 62;
      break L4;
     }
     $12 = HEAP32[$__b>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      $25 = 0;
     } else {
      $14 = (($12) + 12|0);
      $15 = HEAP32[$14>>2]|0;
      $16 = (($12) + 16|0);
      $17 = HEAP32[$16>>2]|0;
      $18 = ($15|0)==($17|0);
      if ($18) {
       $19 = HEAP32[$12>>2]|0;
       $20 = (($19) + 36|0);
       $21 = HEAP32[$20>>2]|0;
       $22 = (FUNCTION_TABLE_ii[$21 & 4095]($12)|0);
       $23 = ($22|0)==(-1);
       if ($23) {
        HEAP32[$__b>>2] = 0;
        $25 = 0;
       } else {
        $25 = $12;
       }
      } else {
       $25 = $12;
      }
     }
     $24 = ($25|0)==(0|0);
     $26 = HEAP32[$__e>>2]|0;
     $27 = ($26|0)==(0|0);
     do {
      if ($27) {
       label = 15;
      } else {
       $28 = (($26) + 12|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = (($26) + 16|0);
       $31 = HEAP32[$30>>2]|0;
       $32 = ($29|0)==($31|0);
       if ($32) {
        $33 = HEAP32[$26>>2]|0;
        $34 = (($33) + 36|0);
        $35 = HEAP32[$34>>2]|0;
        $36 = (FUNCTION_TABLE_ii[$35 & 4095]($26)|0);
        $37 = ($36|0)==(-1);
        if ($37) {
         HEAP32[$__e>>2] = 0;
         label = 15;
         break;
        }
       }
       if ($24) {
        $64 = $26;
       } else {
        label = 16;
        break L6;
       }
      }
     } while(0);
     if ((label|0) == 15) {
      label = 0;
      if ($24) {
       label = 16;
       break L6;
      } else {
       $64 = 0;
      }
     }
     $41 = HEAP8[$$0$ph37>>0]|0;
     $42 = HEAP32[$4>>2]|0;
     $43 = (($42) + 36|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (FUNCTION_TABLE_iiii[$44 & 2047]($4,$41,0)|0);
     $46 = ($45<<24>>24)==(37);
     if ($46) {
      label = 19;
      break;
     }
     $68 = HEAP8[$$0$ph37>>0]|0;
     $isascii1$i = ($68<<24>>24)>(-1);
     if ($isascii1$i) {
      $69 = $68 << 24 >> 24;
      $70 = HEAP32[$9>>2]|0;
      $71 = (($70) + ($69<<1)|0);
      $72 = HEAP16[$71>>1]|0;
      $73 = $72 & 8192;
      $74 = ($73<<16>>16)==(0);
      if (!($74)) {
       $$0$pn = $$0$ph37;
       label = 30;
       break;
      }
     }
     $133 = (($25) + 12|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($25) + 16|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = ($134|0)==($136|0);
     if ($137) {
      $138 = HEAP32[$25>>2]|0;
      $139 = (($138) + 36|0);
      $140 = HEAP32[$139>>2]|0;
      $141 = (FUNCTION_TABLE_ii[$140 & 4095]($25)|0);
      $$0$i$i24 = $141;
     } else {
      $142 = HEAP8[$134>>0]|0;
      $143 = $142&255;
      $$0$i$i24 = $143;
     }
     $144 = $$0$i$i24&255;
     $145 = HEAP32[$4>>2]|0;
     $146 = (($145) + 12|0);
     $147 = HEAP32[$146>>2]|0;
     $148 = (FUNCTION_TABLE_iii[$147 & 4095]($4,$144)|0);
     $149 = HEAP8[$$0$ph37>>0]|0;
     $150 = HEAP32[$4>>2]|0;
     $151 = (($150) + 12|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = (FUNCTION_TABLE_iii[$152 & 4095]($4,$149)|0);
     $154 = ($148<<24>>24)==($153<<24>>24);
     if ($154) {
      label = 57;
      break;
     }
     HEAP32[$__err>>2] = 4;
     $11 = 4;
    }
    L34: do {
     if ((label|0) == 19) {
      label = 0;
      $47 = (($$0$ph37) + 1|0);
      $48 = ($47|0)==($__fmte|0);
      if ($48) {
       label = 20;
       break L6;
      }
      $49 = HEAP8[$47>>0]|0;
      $50 = HEAP32[$4>>2]|0;
      $51 = (($50) + 36|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = (FUNCTION_TABLE_iiii[$52 & 2047]($4,$49,0)|0);
      if ((($53<<24>>24) == 48) | (($53<<24>>24) == 69)) {
       $54 = (($$0$ph37) + 2|0);
       $55 = ($54|0)==($__fmte|0);
       if ($55) {
        label = 23;
        break L6;
       }
       $56 = HEAP8[$54>>0]|0;
       $57 = HEAP32[$4>>2]|0;
       $58 = (($57) + 36|0);
       $59 = HEAP32[$58>>2]|0;
       $60 = (FUNCTION_TABLE_iiii[$59 & 2047]($4,$56,0)|0);
       $$1 = $54;$__cmd$0 = $60;$__opt$0 = $53;
      } else {
       $$1 = $47;$__cmd$0 = $53;$__opt$0 = 0;
      }
      $61 = HEAP32[$this>>2]|0;
      $62 = (($61) + 36|0);
      $63 = HEAP32[$62>>2]|0;
      HEAP32[$2>>2] = $25;
      HEAP32[$3>>2] = $64;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$3+0>>2]|0;
      FUNCTION_TABLE_viiiiiiiii[$63 & 31]($1,$this,$$byval_copy,$$byval_copy1,$__iob,$__err,$__tm,$__cmd$0,$__opt$0);
      $65 = HEAP32[$1>>2]|0;
      HEAP32[$__b>>2] = $65;
      $66 = (($$1) + 1|0);
      $$0$ph$be = $66;
     }
     else if ((label|0) == 30) {
      while(1) {
       label = 0;
       $$2 = (($$0$pn) + 1|0);
       $75 = ($$2|0)==($__fmte|0);
       if ($75) {
        $$2$lcssa = $__fmte;
        break;
       }
       $76 = HEAP8[$$2>>0]|0;
       $isascii1$i3 = ($76<<24>>24)>(-1);
       if (!($isascii1$i3)) {
        $$2$lcssa = $$2;
        break;
       }
       $77 = $76 << 24 >> 24;
       $78 = (($70) + ($77<<1)|0);
       $79 = HEAP16[$78>>1]|0;
       $80 = $79 & 8192;
       $81 = ($80<<16>>16)==(0);
       if ($81) {
        $$2$lcssa = $$2;
        break;
       } else {
        $$0$pn = $$2;
        label = 30;
       }
      }
      $$pre$i$i$i15 = $25;$$pre$i2$i$i19 = $64;$96 = $64;
      while(1) {
       $82 = ($$pre$i$i$i15|0)==(0|0);
       if ($82) {
        $94 = 0;
       } else {
        $83 = (($$pre$i$i$i15) + 12|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = (($$pre$i$i$i15) + 16|0);
        $86 = HEAP32[$85>>2]|0;
        $87 = ($84|0)==($86|0);
        if ($87) {
         $88 = HEAP32[$$pre$i$i$i15>>2]|0;
         $89 = (($88) + 36|0);
         $90 = HEAP32[$89>>2]|0;
         $91 = (FUNCTION_TABLE_ii[$90 & 4095]($$pre$i$i$i15)|0);
         $92 = ($91|0)==(-1);
         if ($92) {
          HEAP32[$__b>>2] = 0;
          $94 = 0;
         } else {
          $94 = $$pre$i$i$i15;
         }
        } else {
         $94 = $$pre$i$i$i15;
        }
       }
       $93 = ($94|0)==(0|0);
       $95 = ($96|0)==(0|0);
       do {
        if ($95) {
         $$pre$i2$i$i1940 = $$pre$i2$i$i19;
         label = 43;
        } else {
         $97 = (($96) + 12|0);
         $98 = HEAP32[$97>>2]|0;
         $99 = (($96) + 16|0);
         $100 = HEAP32[$99>>2]|0;
         $101 = ($98|0)==($100|0);
         if (!($101)) {
          if ($93) {
           $$pre$i2$i$i1939 = $$pre$i2$i$i19;$190 = $96;
           break;
          } else {
           $$0$ph$be = $$2$lcssa;
           break L34;
          }
         }
         $102 = HEAP32[$96>>2]|0;
         $103 = (($102) + 36|0);
         $104 = HEAP32[$103>>2]|0;
         $105 = (FUNCTION_TABLE_ii[$104 & 4095]($96)|0);
         $106 = ($105|0)==(-1);
         if ($106) {
          HEAP32[$__e>>2] = 0;
          $$pre$i2$i$i1940 = 0;
          label = 43;
          break;
         } else {
          $107 = ($$pre$i2$i$i19|0)==(0|0);
          $tmp$i$i21 = $93 ^ $107;
          if ($tmp$i$i21) {
           $$pre$i2$i$i1939 = $$pre$i2$i$i19;$190 = $$pre$i2$i$i19;
           break;
          } else {
           $$0$ph$be = $$2$lcssa;
           break L34;
          }
         }
        }
       } while(0);
       if ((label|0) == 43) {
        label = 0;
        if ($93) {
         $$0$ph$be = $$2$lcssa;
         break L34;
        } else {
         $$pre$i2$i$i1939 = $$pre$i2$i$i1940;$190 = 0;
        }
       }
       $108 = (($94) + 12|0);
       $109 = HEAP32[$108>>2]|0;
       $110 = (($94) + 16|0);
       $111 = HEAP32[$110>>2]|0;
       $112 = ($109|0)==($111|0);
       if ($112) {
        $113 = HEAP32[$94>>2]|0;
        $114 = (($113) + 36|0);
        $115 = HEAP32[$114>>2]|0;
        $116 = (FUNCTION_TABLE_ii[$115 & 4095]($94)|0);
        $$0$i$i = $116;
       } else {
        $117 = HEAP8[$109>>0]|0;
        $118 = $117&255;
        $$0$i$i = $118;
       }
       $119 = $$0$i$i&255;
       $isascii1$i22 = ($119<<24>>24)>(-1);
       if (!($isascii1$i22)) {
        $$0$ph$be = $$2$lcssa;
        break L34;
       }
       $sext = $$0$i$i << 24;
       $120 = $sext >> 24;
       $121 = HEAP32[$9>>2]|0;
       $122 = (($121) + ($120<<1)|0);
       $123 = HEAP16[$122>>1]|0;
       $124 = $123 & 8192;
       $125 = ($124<<16>>16)==(0);
       if ($125) {
        $$0$ph$be = $$2$lcssa;
        break L34;
       }
       $126 = HEAP32[$108>>2]|0;
       $127 = HEAP32[$110>>2]|0;
       $128 = ($126|0)==($127|0);
       if ($128) {
        $129 = HEAP32[$94>>2]|0;
        $130 = (($129) + 40|0);
        $131 = HEAP32[$130>>2]|0;
        (FUNCTION_TABLE_ii[$131 & 4095]($94)|0);
        $$pre$i$i$i15 = $94;$$pre$i2$i$i19 = $$pre$i2$i$i1939;$96 = $190;
        continue;
       } else {
        $132 = (($126) + 1|0);
        HEAP32[$108>>2] = $132;
        $$pre$i$i$i15 = $94;$$pre$i2$i$i19 = $$pre$i2$i$i1939;$96 = $190;
        continue;
       }
      }
     }
     else if ((label|0) == 57) {
      label = 0;
      $155 = HEAP32[$133>>2]|0;
      $156 = HEAP32[$135>>2]|0;
      $157 = ($155|0)==($156|0);
      if ($157) {
       $158 = HEAP32[$25>>2]|0;
       $159 = (($158) + 40|0);
       $160 = HEAP32[$159>>2]|0;
       (FUNCTION_TABLE_ii[$160 & 4095]($25)|0);
      } else {
       $161 = (($155) + 1|0);
       HEAP32[$133>>2] = $161;
      }
      $162 = (($$0$ph37) + 1|0);
      $$0$ph$be = $162;
     }
    } while(0);
    $67 = ($$0$ph$be|0)==($__fmte|0);
    if ($67) {
     label = 62;
     break L4;
    }
    $$pre38$pre = HEAP32[$__err>>2]|0;
    $$0$ph37 = $$0$ph$be;$$pre38 = $$pre38$pre;
   }
   if ((label|0) == 16) {
    HEAP32[$__err>>2] = 4;
    $$pre$i$i$i6 = $25;
    break;
   }
   else if ((label|0) == 20) {
    HEAP32[$__err>>2] = 4;
    $$pre$i$i$i6 = $25;
    break;
   }
   else if ((label|0) == 23) {
    HEAP32[$__err>>2] = 4;
    $$pre$i$i$i6 = $25;
    break;
   }
  }
 } while(0);
 if ((label|0) == 62) {
  $$pre = HEAP32[$__b>>2]|0;
  $$pre$i$i$i6 = $$pre;
 }
 $163 = ($$pre$i$i$i6|0)==(0|0);
 if ($163) {
  $175 = 0;
 } else {
  $164 = (($$pre$i$i$i6) + 12|0);
  $165 = HEAP32[$164>>2]|0;
  $166 = (($$pre$i$i$i6) + 16|0);
  $167 = HEAP32[$166>>2]|0;
  $168 = ($165|0)==($167|0);
  if ($168) {
   $169 = HEAP32[$$pre$i$i$i6>>2]|0;
   $170 = (($169) + 36|0);
   $171 = HEAP32[$170>>2]|0;
   $172 = (FUNCTION_TABLE_ii[$171 & 4095]($$pre$i$i$i6)|0);
   $173 = ($172|0)==(-1);
   if ($173) {
    HEAP32[$__b>>2] = 0;
    $175 = 0;
   } else {
    $175 = $$pre$i$i$i6;
   }
  } else {
   $175 = $$pre$i$i$i6;
  }
 }
 $174 = ($175|0)==(0|0);
 $176 = HEAP32[$__e>>2]|0;
 $177 = ($176|0)==(0|0);
 do {
  if ($177) {
   label = 72;
  } else {
   $178 = (($176) + 12|0);
   $179 = HEAP32[$178>>2]|0;
   $180 = (($176) + 16|0);
   $181 = HEAP32[$180>>2]|0;
   $182 = ($179|0)==($181|0);
   if ($182) {
    $183 = HEAP32[$176>>2]|0;
    $184 = (($183) + 36|0);
    $185 = HEAP32[$184>>2]|0;
    $186 = (FUNCTION_TABLE_ii[$185 & 4095]($176)|0);
    $187 = ($186|0)==(-1);
    if ($187) {
     HEAP32[$__e>>2] = 0;
     label = 72;
     break;
    }
   }
   if ($174) {
    HEAP32[$agg$result>>2] = $175;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 72) {
  if (!($174)) {
   HEAP32[$agg$result>>2] = $175;
   STACKTOP = sp;return;
  }
 }
 $188 = HEAP32[$__err>>2]|0;
 $189 = $188 | 2;
 HEAP32[$__err>>2] = $189;
 HEAP32[$agg$result>>2] = $175;
 STACKTOP = sp;return;
}
function __ZNSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($agg$result,$this,$$byval_copy,$$byval_copy1,$__iob,$__err,$__tm,3092240,((3092240 + 8|0)));
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $7;
 $8 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $8;
 $9 = HEAP8[$6>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $16 = (($6) + 1|0);
  $17 = (($6) + 1|0);
  $18 = $9&255;
  $19 = $18 >>> 1;
  $21 = $17;$22 = $19;$23 = $16;
 } else {
  $12 = (($6) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $21 = $13;$22 = $15;$23 = $13;
 }
 $20 = (($21) + ($22)|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($agg$result,$this,$$byval_copy,$$byval_copy1,$__iob,$__err,$__tm,$23,$20);
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $2 = (invoke_iii(2228,($0|0),(3093336|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($5)|0);
  $6 = (($__tm) + 24|0);
  $7 = HEAP32[$__e>>2]|0;
  HEAP32[$1>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE($this,$6,$__b,$$byval_copy,$__err,$2);
  $8 = HEAP32[$__b>>2]|0;
  HEAP32[$agg$result>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__w,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__w = $__w|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($1)|0);
 $5 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $5;
 $6 = (($4) + 168|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $7 = (__ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb($__b,$$byval_copy,$4,$6,$__ct,$__err,0)|0);
 $8 = $7;
 $9 = $4;
 $10 = (($8) - ($9))|0;
 $11 = ($10|0)<(168);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($10|0) / 12)&-1;
 $13 = (($12|0) % 7)&-1;
 HEAP32[$__w>>2] = $13;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $2 = (invoke_iii(2228,($0|0),(3093336|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($5)|0);
  $6 = (($__tm) + 16|0);
  $7 = HEAP32[$__e>>2]|0;
  HEAP32[$1>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE($this,$6,$__b,$$byval_copy,$__err,$2);
  $8 = HEAP32[$__b>>2]|0;
  HEAP32[$agg$result>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__m,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__m = $__m|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $6;
 $7 = (($5) + 288|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $8 = (__ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb($__b,$$byval_copy,$5,$7,$__ct,$__err,0)|0);
 $9 = $8;
 $10 = $5;
 $11 = (($9) - ($10))|0;
 $12 = ($11|0)<(288);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($11|0) / 12)&-1;
 $14 = (($13|0) % 12)&-1;
 HEAP32[$__m>>2] = $14;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $2 = (invoke_iii(2228,($0|0),(3093336|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($5)|0);
  $6 = (($__tm) + 20|0);
  $7 = HEAP32[$__e>>2]|0;
  HEAP32[$1>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE(0,$6,$__b,$$byval_copy,$__err,$2);
  $8 = HEAP32[$__b>>2]|0;
  HEAP32[$agg$result>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__y,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__y = $__y|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$ = 0, $$byval_copy = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__t$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,4)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = ($2|0)<(69);
 if ($6) {
  $7 = (($2) + 2000)|0;
  $__t$0 = $7;
 } else {
  $$off = (($2) + -69)|0;
  $8 = ($$off>>>0)<(31);
  $9 = (($2) + 1900)|0;
  $$ = $8 ? $9 : $2;
  $__t$0 = $$;
 }
 $10 = (($__t$0) + -1900)|0;
 HEAP32[$__y>>2] = $10;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm,$__fmt,$0) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 $__fmt = $__fmt|0;
 $0 = $0|0;
 var $$byval_copy26 = 0, $$byval_copy30 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy30 = sp + 160|0;
 $$byval_copy26 = sp + 156|0;
 $1 = sp + 152|0;
 $2 = sp + 148|0;
 $3 = sp + 144|0;
 $4 = sp + 140|0;
 $5 = sp + 136|0;
 $6 = sp + 132|0;
 $7 = sp + 128|0;
 $8 = sp + 124|0;
 $9 = sp + 120|0;
 $10 = sp + 116|0;
 $11 = sp + 112|0;
 $12 = sp + 108|0;
 $13 = sp + 104|0;
 $14 = sp + 100|0;
 $15 = sp + 96|0;
 $16 = sp + 92|0;
 $17 = sp + 88|0;
 $18 = sp + 84|0;
 $19 = sp + 80|0;
 $20 = sp + 32|0;
 $21 = sp + 28|0;
 $22 = sp + 24|0;
 $23 = sp + 20|0;
 $24 = sp + 16|0;
 $25 = sp + 8|0;
 $26 = sp + 4|0;
 $27 = sp;
 $28 = sp + 12|0;
 $29 = sp + 36|0;
 $30 = sp + 40|0;
 $31 = sp + 44|0;
 $32 = sp + 48|0;
 $33 = sp + 52|0;
 $34 = sp + 56|0;
 $35 = sp + 60|0;
 $36 = sp + 64|0;
 $37 = sp + 68|0;
 $38 = sp + 72|0;
 $39 = sp + 76|0;
 HEAP32[$__err>>2] = 0;
 __ZNKSt3__18ios_base6getlocEv($1,$__iob);
 __THREW__ = 0;
 $40 = (invoke_iii(2228,($1|0),(3093336|0))|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  $47 = HEAP32[$1>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($47)|0);
  ___resumeException($45|0);
  // unreachable;
 }
 $43 = HEAP32[$1>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($43)|0);
 $44 = $__fmt << 24 >> 24;
 do {
  switch ($44|0) {
  case 106:  {
   $87 = (($__tm) + 28|0);
   $88 = HEAP32[$__e>>2]|0;
   HEAP32[$16>>2] = $88;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$16+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE(0,$87,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 109:  {
   $89 = (($__tm) + 16|0);
   $90 = HEAP32[$__e>>2]|0;
   HEAP32[$17>>2] = $90;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$17+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE(0,$89,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 72:  {
   $83 = (($__tm) + 8|0);
   $84 = HEAP32[$__e>>2]|0;
   HEAP32[$14>>2] = $84;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$14+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE(0,$83,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 73:  {
   $85 = (($__tm) + 8|0);
   $86 = HEAP32[$__e>>2]|0;
   HEAP32[$15>>2] = $86;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$15+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE(0,$85,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 99:  {
   $52 = (($this) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (FUNCTION_TABLE_ii[$55 & 4095]($52)|0);
   $57 = HEAP32[$__b>>2]|0;
   HEAP32[$5>>2] = $57;
   $58 = HEAP32[$__e>>2]|0;
   HEAP32[$6>>2] = $58;
   $59 = HEAP8[$56>>0]|0;
   $60 = $59 & 1;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    $66 = (($56) + 1|0);
    $67 = (($56) + 1|0);
    $68 = $59&255;
    $69 = $68 >>> 1;
    $71 = $67;$72 = $69;$73 = $66;
   } else {
    $62 = (($56) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($56) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    $71 = $63;$72 = $65;$73 = $63;
   }
   $70 = (($71) + ($72)|0);
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$5+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$6+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($4,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,$73,$70);
   $74 = HEAP32[$4>>2]|0;
   HEAP32[$__b>>2] = $74;
   break;
  }
  case 65: case 97:  {
   $48 = (($__tm) + 24|0);
   $49 = HEAP32[$__e>>2]|0;
   HEAP32[$2>>2] = $49;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$2+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE($this,$48,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 68:  {
   $77 = HEAP32[$__b>>2]|0;
   HEAP32[$9>>2] = $77;
   $78 = HEAP32[$__e>>2]|0;
   HEAP32[$10>>2] = $78;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$9+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$10+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($8,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092248,((3092248 + 8|0)));
   $79 = HEAP32[$8>>2]|0;
   HEAP32[$__b>>2] = $79;
   break;
  }
  case 104: case 66: case 98:  {
   $50 = (($__tm) + 16|0);
   $51 = HEAP32[$__e>>2]|0;
   HEAP32[$3>>2] = $51;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$3+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE($this,$50,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 101: case 100:  {
   $75 = (($__tm) + 12|0);
   $76 = HEAP32[$__e>>2]|0;
   HEAP32[$7>>2] = $76;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$7+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE(0,$75,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 70:  {
   $80 = HEAP32[$__b>>2]|0;
   HEAP32[$12>>2] = $80;
   $81 = HEAP32[$__e>>2]|0;
   HEAP32[$13>>2] = $81;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$12+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$13+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($11,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092256,((3092256 + 8|0)));
   $82 = HEAP32[$11>>2]|0;
   HEAP32[$__b>>2] = $82;
   break;
  }
  case 119:  {
   $106 = (($__tm) + 24|0);
   $107 = HEAP32[$__e>>2]|0;
   HEAP32[$31>>2] = $107;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$31+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE(0,$106,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 116: case 110:  {
   $93 = HEAP32[$__e>>2]|0;
   HEAP32[$19>>2] = $93;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$19+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE(0,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 88:  {
   $113 = (($this) + 8|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = (($114) + 24|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (FUNCTION_TABLE_ii[$116 & 4095]($113)|0);
   $118 = HEAP32[$__b>>2]|0;
   HEAP32[$35>>2] = $118;
   $119 = HEAP32[$__e>>2]|0;
   HEAP32[$36>>2] = $119;
   $120 = HEAP8[$117>>0]|0;
   $121 = $120 & 1;
   $122 = ($121<<24>>24)==(0);
   if ($122) {
    $127 = (($117) + 1|0);
    $128 = (($117) + 1|0);
    $129 = $120&255;
    $130 = $129 >>> 1;
    $132 = $128;$133 = $130;$134 = $127;
   } else {
    $123 = (($117) + 8|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (($117) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    $132 = $124;$133 = $126;$134 = $124;
   }
   $131 = (($132) + ($133)|0);
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$35+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$36+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($34,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,$134,$131);
   $135 = HEAP32[$34>>2]|0;
   HEAP32[$__b>>2] = $135;
   break;
  }
  case 83:  {
   $102 = HEAP32[$__e>>2]|0;
   HEAP32[$27>>2] = $102;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$27+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE(0,$__tm,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 120:  {
   $108 = HEAP32[$this>>2]|0;
   $109 = (($108) + 20|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = HEAP32[$__b>>2]|0;
   HEAP32[$32>>2] = $111;
   $112 = HEAP32[$__e>>2]|0;
   HEAP32[$33>>2] = $112;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$32+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$33+0>>2]|0;
   FUNCTION_TABLE_viiiiiii[$110 & 127]($agg$result,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm);
   STACKTOP = sp;return;
   break;
  }
  case 77:  {
   $91 = (($__tm) + 4|0);
   $92 = HEAP32[$__e>>2]|0;
   HEAP32[$18>>2] = $92;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$18+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE(0,$91,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 114:  {
   $96 = HEAP32[$__b>>2]|0;
   HEAP32[$22>>2] = $96;
   $97 = HEAP32[$__e>>2]|0;
   HEAP32[$23>>2] = $97;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$22+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$23+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($21,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092264,((3092264 + 11|0)));
   $98 = HEAP32[$21>>2]|0;
   HEAP32[$__b>>2] = $98;
   break;
  }
  case 112:  {
   $94 = (($__tm) + 8|0);
   $95 = HEAP32[$__e>>2]|0;
   HEAP32[$20>>2] = $95;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$20+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE($this,$94,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 82:  {
   $99 = HEAP32[$__b>>2]|0;
   HEAP32[$25>>2] = $99;
   $100 = HEAP32[$__e>>2]|0;
   HEAP32[$26>>2] = $100;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$25+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$26+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($24,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092280,((3092280 + 5|0)));
   $101 = HEAP32[$24>>2]|0;
   HEAP32[$__b>>2] = $101;
   break;
  }
  case 84:  {
   $103 = HEAP32[$__b>>2]|0;
   HEAP32[$29>>2] = $103;
   $104 = HEAP32[$__e>>2]|0;
   HEAP32[$30>>2] = $104;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$29+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$30+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_($28,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092288,((3092288 + 8|0)));
   $105 = HEAP32[$28>>2]|0;
   HEAP32[$__b>>2] = $105;
   break;
  }
  case 89:  {
   $138 = (($__tm) + 20|0);
   $139 = HEAP32[$__e>>2]|0;
   HEAP32[$38>>2] = $139;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$38+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE(0,$138,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 37:  {
   $140 = HEAP32[$__e>>2]|0;
   HEAP32[$39>>2] = $140;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$39+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE(0,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 121:  {
   $136 = (($__tm) + 20|0);
   $137 = HEAP32[$__e>>2]|0;
   HEAP32[$37>>2] = $137;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$37+0>>2]|0;
   __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE(0,$136,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  default: {
   $141 = HEAP32[$__err>>2]|0;
   $142 = $141 | 4;
   HEAP32[$__err>>2] = $142;
  }
  }
 } while(0);
 $143 = HEAP32[$__b>>2]|0;
 HEAP32[$agg$result>>2] = $143;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__d,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__d = $__d|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $$off = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if ($5) {
  $$off = (($2) + -1)|0;
  $6 = ($$off>>>0)<(31);
  if ($6) {
   HEAP32[$__d>>2] = $2;
   STACKTOP = sp;return;
  }
 }
 $7 = $3 | 4;
 HEAP32[$__err>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__h,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__h = $__h|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(24);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__h>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__h,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__h = $__h|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $$off = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if ($5) {
  $$off = (($2) + -1)|0;
  $6 = ($$off>>>0)<(12);
  if ($6) {
   HEAP32[$__h>>2] = $2;
   STACKTOP = sp;return;
  }
 }
 $7 = $3 | 4;
 HEAP32[$__err>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__d,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__d = $__d|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,3)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(366);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__d>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__m,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__m = $__m|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(13);
 $or$cond = $5 & $6;
 if ($or$cond) {
  $7 = (($2) + -1)|0;
  HEAP32[$__m>>2] = $7;
  STACKTOP = sp;return;
 } else {
  $8 = $3 | 4;
  HEAP32[$__err>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__m,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__m = $__m|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(60);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__m>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE($this,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$0$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i2 = 0, $$pre$i2$i$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $isascii1$i = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__ct) + 8|0);
 L1: while(1) {
  $1 = HEAP32[$__b>>2]|0;
  $2 = ($1|0)==(0|0);
  do {
   if ($2) {
    $14 = 0;
   } else {
    $3 = (($1) + 12|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = (($1) + 16|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)==($6|0);
    if ($7) {
     $8 = HEAP32[$1>>2]|0;
     $9 = (($8) + 36|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = (FUNCTION_TABLE_ii[$10 & 4095]($1)|0);
     $12 = ($11|0)==(-1);
     if ($12) {
      HEAP32[$__b>>2] = 0;
      $14 = 0;
      break;
     } else {
      $$pre$i$i$i = HEAP32[$__b>>2]|0;
      $14 = $$pre$i$i$i;
      break;
     }
    } else {
     $14 = $1;
    }
   }
  } while(0);
  $13 = ($14|0)==(0|0);
  $15 = HEAP32[$__e>>2]|0;
  $16 = ($15|0)==(0|0);
  do {
   if ($16) {
    label = 12;
   } else {
    $17 = (($15) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = (($15) + 16|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($18|0)==($20|0);
    if (!($21)) {
     if ($13) {
      $83 = $15;
      break;
     } else {
      $$pre$i2$i$i6 = $15;
      break L1;
     }
    }
    $22 = HEAP32[$15>>2]|0;
    $23 = (($22) + 36|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (FUNCTION_TABLE_ii[$24 & 4095]($15)|0);
    $26 = ($25|0)==(-1);
    if ($26) {
     HEAP32[$__e>>2] = 0;
     label = 12;
     break;
    } else {
     if ($13) {
      $83 = $15;
      break;
     } else {
      $$pre$i2$i$i6 = $15;
      break L1;
     }
    }
   }
  } while(0);
  if ((label|0) == 12) {
   label = 0;
   if ($13) {
    $$pre$i2$i$i6 = 0;
    break;
   } else {
    $83 = 0;
   }
  }
  $27 = HEAP32[$__b>>2]|0;
  $28 = (($27) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 16|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ($29|0)==($31|0);
  if ($32) {
   $33 = HEAP32[$27>>2]|0;
   $34 = (($33) + 36|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (FUNCTION_TABLE_ii[$35 & 4095]($27)|0);
   $$0$i$i = $36;
  } else {
   $37 = HEAP8[$29>>0]|0;
   $38 = $37&255;
   $$0$i$i = $38;
  }
  $39 = $$0$i$i&255;
  $isascii1$i = ($39<<24>>24)>(-1);
  if (!($isascii1$i)) {
   $$pre$i2$i$i6 = $83;
   break;
  }
  $sext = $$0$i$i << 24;
  $40 = $sext >> 24;
  $41 = HEAP32[$0>>2]|0;
  $42 = (($41) + ($40<<1)|0);
  $43 = HEAP16[$42>>1]|0;
  $44 = $43 & 8192;
  $45 = ($44<<16>>16)==(0);
  if ($45) {
   $$pre$i2$i$i6 = $83;
   break;
  }
  $46 = HEAP32[$__b>>2]|0;
  $47 = (($46) + 12|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($46) + 16|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = ($48|0)==($50|0);
  if ($51) {
   $52 = HEAP32[$46>>2]|0;
   $53 = (($52) + 40|0);
   $54 = HEAP32[$53>>2]|0;
   (FUNCTION_TABLE_ii[$54 & 4095]($46)|0);
   continue;
  } else {
   $55 = (($48) + 1|0);
   HEAP32[$47>>2] = $55;
   continue;
  }
 }
 $56 = HEAP32[$__b>>2]|0;
 $57 = ($56|0)==(0|0);
 do {
  if ($57) {
   $69 = 0;
  } else {
   $58 = (($56) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($56) + 16|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($59|0)==($61|0);
   if ($62) {
    $63 = HEAP32[$56>>2]|0;
    $64 = (($63) + 36|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (FUNCTION_TABLE_ii[$65 & 4095]($56)|0);
    $67 = ($66|0)==(-1);
    if ($67) {
     HEAP32[$__b>>2] = 0;
     $69 = 0;
     break;
    } else {
     $$pre$i$i$i2 = HEAP32[$__b>>2]|0;
     $69 = $$pre$i$i$i2;
     break;
    }
   } else {
    $69 = $56;
   }
  }
 } while(0);
 $68 = ($69|0)==(0|0);
 $70 = ($$pre$i2$i$i6|0)==(0|0);
 do {
  if ($70) {
   label = 32;
  } else {
   $71 = (($$pre$i2$i$i6) + 12|0);
   $72 = HEAP32[$71>>2]|0;
   $73 = (($$pre$i2$i$i6) + 16|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($72|0)==($74|0);
   if ($75) {
    $76 = HEAP32[$$pre$i2$i$i6>>2]|0;
    $77 = (($76) + 36|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = (FUNCTION_TABLE_ii[$78 & 4095]($$pre$i2$i$i6)|0);
    $80 = ($79|0)==(-1);
    if ($80) {
     HEAP32[$__e>>2] = 0;
     label = 32;
     break;
    }
   }
   if ($68) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 32) {
  if (!($68)) {
   STACKTOP = sp;return;
  }
 }
 $81 = HEAP32[$__err>>2]|0;
 $82 = $81 | 2;
 HEAP32[$__err>>2] = $82;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__h,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__h = $__h|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $11 = $6&255;
  $12 = $11 >>> 1;
  $24 = $12;
 } else {
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $24 = $10;
 }
 $13 = (($5) + 12|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $19 = $14&255;
  $20 = $19 >>> 1;
  $22 = $20;
 } else {
  $17 = (($5) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $22 = $18;
 }
 $21 = (0 - ($22))|0;
 $23 = ($24|0)==($21|0);
 if ($23) {
  $25 = HEAP32[$__err>>2]|0;
  $26 = $25 | 4;
  HEAP32[$__err>>2] = $26;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $27;
 $28 = (($5) + 24|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $29 = (__ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb($__b,$$byval_copy,$5,$28,$__ct,$__err,0)|0);
 $30 = $29;
 $31 = $5;
 $32 = (($30) - ($31))|0;
 $33 = ($29|0)==($5|0);
 if ($33) {
  $34 = HEAP32[$__h>>2]|0;
  $35 = ($34|0)==(12);
  if ($35) {
   HEAP32[$__h>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $36 = ($32|0)==(12);
 if (!($36)) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$__h>>2]|0;
 $38 = ($37|0)<(12);
 if (!($38)) {
  STACKTOP = sp;return;
 }
 $39 = (($37) + 12)|0;
 HEAP32[$__h>>2] = $39;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__s,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__s = $__s|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(61);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__s>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__w,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__w = $__w|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,1)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(7);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__w>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE($this,$__y,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__y = $__y|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,4)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($2) + -1900)|0;
 HEAP32[$__y>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE($this,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$0$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i$i2 = 0, $$pre$i2$i$i611 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__b>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $13 = 0;
  } else {
   $2 = (($0) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($0) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3|0)==($5|0);
   if ($6) {
    $7 = HEAP32[$0>>2]|0;
    $8 = (($7) + 36|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (FUNCTION_TABLE_ii[$9 & 4095]($0)|0);
    $11 = ($10|0)==(-1);
    if ($11) {
     HEAP32[$__b>>2] = 0;
     $13 = 0;
     break;
    } else {
     $$pre$i$i$i = HEAP32[$__b>>2]|0;
     $13 = $$pre$i$i$i;
     break;
    }
   } else {
    $13 = $0;
   }
  }
 } while(0);
 $12 = ($13|0)==(0|0);
 $14 = HEAP32[$__e>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   label = 11;
  } else {
   $16 = (($14) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($14) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($17|0)==($19|0);
   if ($20) {
    $21 = HEAP32[$14>>2]|0;
    $22 = (($21) + 36|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (FUNCTION_TABLE_ii[$23 & 4095]($14)|0);
    $25 = ($24|0)==(-1);
    if ($25) {
     HEAP32[$__e>>2] = 0;
     label = 11;
     break;
    }
   }
   if ($12) {
    $$pre$i2$i$i611 = $14;
   } else {
    label = 12;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  if ($12) {
   label = 12;
  } else {
   $$pre$i2$i$i611 = 0;
  }
 }
 if ((label|0) == 12) {
  $26 = HEAP32[$__err>>2]|0;
  $27 = $26 | 6;
  HEAP32[$__err>>2] = $27;
  STACKTOP = sp;return;
 }
 $28 = HEAP32[$__b>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($30|0)==($32|0);
 if ($33) {
  $34 = HEAP32[$28>>2]|0;
  $35 = (($34) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (FUNCTION_TABLE_ii[$36 & 4095]($28)|0);
  $$0$i$i = $37;
 } else {
  $38 = HEAP8[$30>>0]|0;
  $39 = $38&255;
  $$0$i$i = $39;
 }
 $40 = $$0$i$i&255;
 $41 = HEAP32[$__ct>>2]|0;
 $42 = (($41) + 36|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (FUNCTION_TABLE_iiii[$43 & 2047]($__ct,$40,0)|0);
 $45 = ($44<<24>>24)==(37);
 if (!($45)) {
  $46 = HEAP32[$__err>>2]|0;
  $47 = $46 | 4;
  HEAP32[$__err>>2] = $47;
  STACKTOP = sp;return;
 }
 $48 = HEAP32[$__b>>2]|0;
 $49 = (($48) + 12|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($48) + 16|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ($50|0)==($52|0);
 if ($53) {
  $54 = HEAP32[$48>>2]|0;
  $55 = (($54) + 40|0);
  $56 = HEAP32[$55>>2]|0;
  (FUNCTION_TABLE_ii[$56 & 4095]($48)|0);
 } else {
  $57 = (($50) + 1|0);
  HEAP32[$49>>2] = $57;
 }
 $58 = HEAP32[$__b>>2]|0;
 $59 = ($58|0)==(0|0);
 do {
  if ($59) {
   $71 = 0;
  } else {
   $60 = (($58) + 12|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = (($58) + 16|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = ($61|0)==($63|0);
   if ($64) {
    $65 = HEAP32[$58>>2]|0;
    $66 = (($65) + 36|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = (FUNCTION_TABLE_ii[$67 & 4095]($58)|0);
    $69 = ($68|0)==(-1);
    if ($69) {
     HEAP32[$__b>>2] = 0;
     $71 = 0;
     break;
    } else {
     $$pre$i$i$i2 = HEAP32[$__b>>2]|0;
     $71 = $$pre$i$i$i2;
     break;
    }
   } else {
    $71 = $58;
   }
  }
 } while(0);
 $70 = ($71|0)==(0|0);
 $72 = ($$pre$i2$i$i611|0)==(0|0);
 do {
  if ($72) {
   label = 31;
  } else {
   $73 = (($$pre$i2$i$i611) + 12|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($$pre$i2$i$i611) + 16|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($74|0)==($76|0);
   if ($77) {
    $78 = HEAP32[$$pre$i2$i$i611>>2]|0;
    $79 = (($78) + 36|0);
    $80 = HEAP32[$79>>2]|0;
    $81 = (FUNCTION_TABLE_ii[$80 & 4095]($$pre$i2$i$i611)|0);
    $82 = ($81|0)==(-1);
    if ($82) {
     HEAP32[$__e>>2] = 0;
     label = 31;
     break;
    }
   }
   if ($70) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 31) {
  if (!($70)) {
   STACKTOP = sp;return;
  }
 }
 $83 = HEAP32[$__err>>2]|0;
 $84 = $83 | 2;
 HEAP32[$__err>>2] = $84;
 STACKTOP = sp;return;
}
function __ZNSt3__120__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$__e,$__err,$__ct,$__n) {
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 $__n = $__n|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i10 = 0, $$0$in = 0, $$01 = 0, $$pre$i$i$i = 0, $$pre$i$i$i16 = 0, $$pre$i$i$i3 = 0, $$pre$i2$i$i20 = 0, $$pre$i2$i$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__r$0$in = 0, $isascii1$i = 0, $isascii1$i12 = 0, $sext = 0, $sext24 = 0, $tmp$i$i9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__b>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $13 = 0;
  } else {
   $2 = (($0) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($0) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3|0)==($5|0);
   if ($6) {
    $7 = HEAP32[$0>>2]|0;
    $8 = (($7) + 36|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (FUNCTION_TABLE_ii[$9 & 4095]($0)|0);
    $11 = ($10|0)==(-1);
    if ($11) {
     HEAP32[$__b>>2] = 0;
     $13 = 0;
     break;
    } else {
     $$pre$i$i$i = HEAP32[$__b>>2]|0;
     $13 = $$pre$i$i$i;
     break;
    }
   } else {
    $13 = $0;
   }
  }
 } while(0);
 $12 = ($13|0)==(0|0);
 $14 = HEAP32[$__e>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if ($15) {
   label = 11;
  } else {
   $16 = (($14) + 12|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($14) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($17|0)==($19|0);
   if ($20) {
    $21 = HEAP32[$14>>2]|0;
    $22 = (($21) + 36|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (FUNCTION_TABLE_ii[$23 & 4095]($14)|0);
    $25 = ($24|0)==(-1);
    if ($25) {
     HEAP32[$__e>>2] = 0;
     label = 11;
     break;
    }
   }
   if ($12) {
    $156 = $14;
   } else {
    label = 12;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  if ($12) {
   label = 12;
  } else {
   $156 = 0;
  }
 }
 if ((label|0) == 12) {
  $26 = HEAP32[$__err>>2]|0;
  $27 = $26 | 6;
  HEAP32[$__err>>2] = $27;
  $$01 = 0;
  STACKTOP = sp;return ($$01|0);
 }
 $28 = HEAP32[$__b>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($30|0)==($32|0);
 if ($33) {
  $34 = HEAP32[$28>>2]|0;
  $35 = (($34) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (FUNCTION_TABLE_ii[$36 & 4095]($28)|0);
  $$0$i$i = $37;
 } else {
  $38 = HEAP8[$30>>0]|0;
  $39 = $38&255;
  $$0$i$i = $39;
 }
 $40 = $$0$i$i&255;
 $isascii1$i = ($40<<24>>24)>(-1);
 if ($isascii1$i) {
  $sext = $$0$i$i << 24;
  $41 = $sext >> 24;
  $42 = (($__ct) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + ($41<<1)|0);
  $45 = HEAP16[$44>>1]|0;
  $46 = $45 & 2048;
  $47 = ($46<<16>>16)==(0);
  if (!($47)) {
   $50 = HEAP32[$__ct>>2]|0;
   $51 = (($50) + 36|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = (FUNCTION_TABLE_iiii[$52 & 2047]($__ct,$40,0)|0);
   $54 = $53 << 24 >> 24;
   $55 = HEAP32[$__b>>2]|0;
   $56 = (($55) + 12|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($55) + 16|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ($57|0)==($59|0);
   if ($60) {
    $61 = HEAP32[$55>>2]|0;
    $62 = (($61) + 40|0);
    $63 = HEAP32[$62>>2]|0;
    (FUNCTION_TABLE_ii[$63 & 4095]($55)|0);
    $$0$in = $__n;$$pre$i2$i$i7 = $156;$80 = $156;$__r$0$in = $54;
   } else {
    $64 = (($57) + 1|0);
    HEAP32[$56>>2] = $64;
    $$0$in = $__n;$$pre$i2$i$i7 = $156;$80 = $156;$__r$0$in = $54;
   }
   while(1) {
    $__r$0 = (($__r$0$in) + -48)|0;
    $$0 = (($$0$in) + -1)|0;
    $65 = HEAP32[$__b>>2]|0;
    $66 = ($65|0)==(0|0);
    do {
     if ($66) {
      $78 = 0;
     } else {
      $67 = (($65) + 12|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (($65) + 16|0);
      $70 = HEAP32[$69>>2]|0;
      $71 = ($68|0)==($70|0);
      if ($71) {
       $72 = HEAP32[$65>>2]|0;
       $73 = (($72) + 36|0);
       $74 = HEAP32[$73>>2]|0;
       $75 = (FUNCTION_TABLE_ii[$74 & 4095]($65)|0);
       $76 = ($75|0)==(-1);
       if ($76) {
        HEAP32[$__b>>2] = 0;
        $78 = 0;
        break;
       } else {
        $$pre$i$i$i3 = HEAP32[$__b>>2]|0;
        $78 = $$pre$i$i$i3;
        break;
       }
      } else {
       $78 = $65;
      }
     }
    } while(0);
    $77 = ($78|0)==(0|0);
    $79 = ($80|0)==(0|0);
    if ($79) {
     $$pre$i2$i$i20 = $$pre$i2$i$i7;$92 = 0;
    } else {
     $81 = (($80) + 12|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = (($80) + 16|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = ($82|0)==($84|0);
     if ($85) {
      $86 = HEAP32[$80>>2]|0;
      $87 = (($86) + 36|0);
      $88 = HEAP32[$87>>2]|0;
      $89 = (FUNCTION_TABLE_ii[$88 & 4095]($80)|0);
      $90 = ($89|0)==(-1);
      if ($90) {
       HEAP32[$__e>>2] = 0;
       $$pre$i2$i$i20 = 0;$92 = 0;
      } else {
       $$pre$i2$i$i20 = $$pre$i2$i$i7;$92 = $$pre$i2$i$i7;
      }
     } else {
      $$pre$i2$i$i20 = $$pre$i2$i$i7;$92 = $80;
     }
    }
    $91 = ($92|0)==(0|0);
    $tmp$i$i9 = $77 ^ $91;
    $93 = ($$0|0)>(0);
    $$ = $tmp$i$i9 & $93;
    $94 = HEAP32[$__b>>2]|0;
    if (!($$)) {
     label = 40;
     break;
    }
    $95 = (($94) + 12|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = (($94) + 16|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ($96|0)==($98|0);
    if ($99) {
     $100 = HEAP32[$94>>2]|0;
     $101 = (($100) + 36|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = (FUNCTION_TABLE_ii[$102 & 4095]($94)|0);
     $$0$i$i10 = $103;
    } else {
     $104 = HEAP8[$96>>0]|0;
     $105 = $104&255;
     $$0$i$i10 = $105;
    }
    $106 = $$0$i$i10&255;
    $isascii1$i12 = ($106<<24>>24)>(-1);
    if (!($isascii1$i12)) {
     $$01 = $__r$0;
     label = 52;
     break;
    }
    $sext24 = $$0$i$i10 << 24;
    $107 = $sext24 >> 24;
    $108 = HEAP32[$42>>2]|0;
    $109 = (($108) + ($107<<1)|0);
    $110 = HEAP16[$109>>1]|0;
    $111 = $110 & 2048;
    $112 = ($111<<16>>16)==(0);
    if ($112) {
     $$01 = $__r$0;
     label = 52;
     break;
    }
    $113 = ($__r$0*10)|0;
    $114 = HEAP32[$__ct>>2]|0;
    $115 = (($114) + 36|0);
    $116 = HEAP32[$115>>2]|0;
    $117 = (FUNCTION_TABLE_iiii[$116 & 2047]($__ct,$106,0)|0);
    $118 = $117 << 24 >> 24;
    $119 = (($118) + ($113))|0;
    $120 = HEAP32[$__b>>2]|0;
    $121 = (($120) + 12|0);
    $122 = HEAP32[$121>>2]|0;
    $123 = (($120) + 16|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = ($122|0)==($124|0);
    if ($125) {
     $126 = HEAP32[$120>>2]|0;
     $127 = (($126) + 40|0);
     $128 = HEAP32[$127>>2]|0;
     (FUNCTION_TABLE_ii[$128 & 4095]($120)|0);
     $$0$in = $$0;$$pre$i2$i$i7 = $$pre$i2$i$i20;$80 = $92;$__r$0$in = $119;
     continue;
    } else {
     $129 = (($122) + 1|0);
     HEAP32[$121>>2] = $129;
     $$0$in = $$0;$$pre$i2$i$i7 = $$pre$i2$i$i20;$80 = $92;$__r$0$in = $119;
     continue;
    }
   }
   if ((label|0) == 40) {
    $130 = ($94|0)==(0|0);
    do {
     if ($130) {
      $142 = 0;
     } else {
      $131 = (($94) + 12|0);
      $132 = HEAP32[$131>>2]|0;
      $133 = (($94) + 16|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = ($132|0)==($134|0);
      if ($135) {
       $136 = HEAP32[$94>>2]|0;
       $137 = (($136) + 36|0);
       $138 = HEAP32[$137>>2]|0;
       $139 = (FUNCTION_TABLE_ii[$138 & 4095]($94)|0);
       $140 = ($139|0)==(-1);
       if ($140) {
        HEAP32[$__b>>2] = 0;
        $142 = 0;
        break;
       } else {
        $$pre$i$i$i16 = HEAP32[$__b>>2]|0;
        $142 = $$pre$i$i$i16;
        break;
       }
      } else {
       $142 = $94;
      }
     }
    } while(0);
    $141 = ($142|0)==(0|0);
    $143 = ($$pre$i2$i$i20|0)==(0|0);
    do {
     if ($143) {
      label = 50;
     } else {
      $144 = (($$pre$i2$i$i20) + 12|0);
      $145 = HEAP32[$144>>2]|0;
      $146 = (($$pre$i2$i$i20) + 16|0);
      $147 = HEAP32[$146>>2]|0;
      $148 = ($145|0)==($147|0);
      if ($148) {
       $149 = HEAP32[$$pre$i2$i$i20>>2]|0;
       $150 = (($149) + 36|0);
       $151 = HEAP32[$150>>2]|0;
       $152 = (FUNCTION_TABLE_ii[$151 & 4095]($$pre$i2$i$i20)|0);
       $153 = ($152|0)==(-1);
       if ($153) {
        HEAP32[$__e>>2] = 0;
        label = 50;
        break;
       }
      }
      if ($141) {
       $$01 = $__r$0;
       STACKTOP = sp;return ($$01|0);
      }
     }
    } while(0);
    if ((label|0) == 50) {
     if (!($141)) {
      $$01 = $__r$0;
      STACKTOP = sp;return ($$01|0);
     }
    }
    $154 = HEAP32[$__err>>2]|0;
    $155 = $154 | 2;
    HEAP32[$__err>>2] = $155;
    $$01 = $__r$0;
    STACKTOP = sp;return ($$01|0);
   }
   else if ((label|0) == 52) {
    STACKTOP = sp;return ($$01|0);
   }
  }
 }
 $48 = HEAP32[$__err>>2]|0;
 $49 = $48 | 4;
 HEAP32[$__err>>2] = $49;
 $$01 = 0;
 STACKTOP = sp;return ($$01|0);
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm,$__fmtb,$__fmte) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 $__fmtb = $__fmtb|0;
 $__fmte = $__fmte|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i18 = 0, $$0$i$i$i$i3 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i24 = 0, $$0$i$i1$i$i9 = 0, $$0$i$i15 = 0, $$0$ph$be = 0, $$0$ph42 = 0, $$0$pn = 0, $$1 = 0, $$2 = 0, $$2$lcssa = 0, $$byval_copy = 0, $$byval_copy1 = 0, $$pre = 0, $$pre$i$i$i20 = 0, $$pre$i$i$i5 = 0, $$pre$i3$i$i11 = 0;
 var $$pre$i3$i$i1144 = 0, $$pre$i3$i$i1145 = 0, $$pre43 = 0, $$pre43$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__cmd$0 = 0, $__opt$0 = 0, $phitmp$i4$i$i12 = 0, $tmp$i$i14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $$byval_copy1 = sp + 20|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = sp + 12|0;
 $3 = sp + 16|0;
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $4 = (invoke_iii(2228,($0|0),(3093328|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if ($6) {
  $37 = ___cxa_find_matching_catch()|0;
  $38 = tempRet0;
  $39 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($39)|0);
  ___resumeException($37|0);
  // unreachable;
 }
 $7 = HEAP32[$0>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($7)|0);
 HEAP32[$__err>>2] = 0;
 $8 = ($__fmtb|0)==($__fmte|0);
 L4: do {
  if ($8) {
   label = 66;
  } else {
   $$0$ph42 = $__fmtb;$$pre43 = 0;
   L6: while(1) {
    $10 = $$pre43;
    while(1) {
     $9 = ($10|0)==(0);
     if (!($9)) {
      label = 66;
      break L4;
     }
     $11 = HEAP32[$__b>>2]|0;
     $12 = ($11|0)==(0|0);
     if ($12) {
      $183 = 1;$63 = 0;
     } else {
      $13 = (($11) + 12|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = (($11) + 16|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($14|0)==($16|0);
      if ($17) {
       $18 = HEAP32[$11>>2]|0;
       $19 = (($18) + 36|0);
       $20 = HEAP32[$19>>2]|0;
       $21 = (FUNCTION_TABLE_ii[$20 & 4095]($11)|0);
       $$0$i$i$i$i = $21;
      } else {
       $22 = HEAP32[$14>>2]|0;
       $$0$i$i$i$i = $22;
      }
      $23 = ($$0$i$i$i$i|0)==(-1);
      if ($23) {
       HEAP32[$__b>>2] = 0;
       $183 = 1;$63 = 0;
      } else {
       $183 = 0;$63 = $11;
      }
     }
     $24 = HEAP32[$__e>>2]|0;
     $25 = ($24|0)==(0|0);
     do {
      if ($25) {
       label = 18;
      } else {
       $26 = (($24) + 12|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = (($24) + 16|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($27|0)==($29|0);
       if ($30) {
        $31 = HEAP32[$24>>2]|0;
        $32 = (($31) + 36|0);
        $33 = HEAP32[$32>>2]|0;
        $34 = (FUNCTION_TABLE_ii[$33 & 4095]($24)|0);
        $$0$i$i1$i$i = $34;
       } else {
        $35 = HEAP32[$27>>2]|0;
        $$0$i$i1$i$i = $35;
       }
       $36 = ($$0$i$i1$i$i|0)==(-1);
       if ($36) {
        HEAP32[$__e>>2] = 0;
        label = 18;
        break;
       } else {
        if ($183) {
         $64 = $24;
         break;
        } else {
         label = 20;
         break L6;
        }
       }
      }
     } while(0);
     if ((label|0) == 18) {
      label = 0;
      if ($183) {
       label = 20;
       break L6;
      } else {
       $64 = 0;
      }
     }
     $40 = HEAP32[$$0$ph42>>2]|0;
     $41 = HEAP32[$4>>2]|0;
     $42 = (($41) + 52|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (FUNCTION_TABLE_iiii[$43 & 2047]($4,$40,0)|0);
     $45 = ($44<<24>>24)==(37);
     if ($45) {
      label = 23;
      break;
     }
     $68 = HEAP32[$$0$ph42>>2]|0;
     $69 = HEAP32[$4>>2]|0;
     $70 = (($69) + 12|0);
     $71 = HEAP32[$70>>2]|0;
     $72 = (FUNCTION_TABLE_iiii[$71 & 2047]($4,8192,$68)|0);
     if ($72) {
      $$0$pn = $$0$ph42;
      label = 33;
      break;
     }
     $127 = (($63) + 12|0);
     $128 = HEAP32[$127>>2]|0;
     $129 = (($63) + 16|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($128|0)==($130|0);
     if ($131) {
      $132 = HEAP32[$63>>2]|0;
      $133 = (($132) + 36|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = (FUNCTION_TABLE_ii[$134 & 4095]($63)|0);
      $$0$i$i15 = $135;
     } else {
      $136 = HEAP32[$128>>2]|0;
      $$0$i$i15 = $136;
     }
     $137 = HEAP32[$4>>2]|0;
     $138 = (($137) + 28|0);
     $139 = HEAP32[$138>>2]|0;
     $140 = (FUNCTION_TABLE_iii[$139 & 4095]($4,$$0$i$i15)|0);
     $141 = HEAP32[$$0$ph42>>2]|0;
     $142 = HEAP32[$4>>2]|0;
     $143 = (($142) + 28|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = (FUNCTION_TABLE_iii[$144 & 4095]($4,$141)|0);
     $146 = ($140|0)==($145|0);
     if ($146) {
      label = 61;
      break;
     }
     HEAP32[$__err>>2] = 4;
     $10 = 4;
    }
    L38: do {
     if ((label|0) == 23) {
      label = 0;
      $46 = (($$0$ph42) + 4|0);
      $47 = ($46|0)==($__fmte|0);
      if ($47) {
       label = 24;
       break L6;
      }
      $48 = HEAP32[$46>>2]|0;
      $49 = HEAP32[$4>>2]|0;
      $50 = (($49) + 52|0);
      $51 = HEAP32[$50>>2]|0;
      $52 = (FUNCTION_TABLE_iiii[$51 & 2047]($4,$48,0)|0);
      if ((($52<<24>>24) == 48) | (($52<<24>>24) == 69)) {
       $53 = (($$0$ph42) + 8|0);
       $54 = ($53|0)==($__fmte|0);
       if ($54) {
        label = 27;
        break L6;
       }
       $55 = HEAP32[$53>>2]|0;
       $56 = HEAP32[$4>>2]|0;
       $57 = (($56) + 52|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (FUNCTION_TABLE_iiii[$58 & 2047]($4,$55,0)|0);
       $$1 = $53;$__cmd$0 = $59;$__opt$0 = $52;
      } else {
       $$1 = $46;$__cmd$0 = $52;$__opt$0 = 0;
      }
      $60 = HEAP32[$this>>2]|0;
      $61 = (($60) + 36|0);
      $62 = HEAP32[$61>>2]|0;
      HEAP32[$2>>2] = $63;
      HEAP32[$3>>2] = $64;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
      ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$3+0>>2]|0;
      FUNCTION_TABLE_viiiiiiiii[$62 & 31]($1,$this,$$byval_copy,$$byval_copy1,$__iob,$__err,$__tm,$__cmd$0,$__opt$0);
      $65 = HEAP32[$1>>2]|0;
      HEAP32[$__b>>2] = $65;
      $66 = (($$1) + 4|0);
      $$0$ph$be = $66;
     }
     else if ((label|0) == 33) {
      while(1) {
       label = 0;
       $$2 = (($$0$pn) + 4|0);
       $73 = ($$2|0)==($__fmte|0);
       if ($73) {
        $$2$lcssa = $__fmte;
        break;
       }
       $74 = HEAP32[$$2>>2]|0;
       $75 = HEAP32[$4>>2]|0;
       $76 = (($75) + 12|0);
       $77 = HEAP32[$76>>2]|0;
       $78 = (FUNCTION_TABLE_iiii[$77 & 2047]($4,8192,$74)|0);
       if ($78) {
        $$0$pn = $$2;
        label = 33;
       } else {
        $$2$lcssa = $$2;
        break;
       }
      }
      $$pre$i$i$i5 = $63;$$pre$i3$i$i11 = $64;$92 = $64;
      while(1) {
       $79 = ($$pre$i$i$i5|0)==(0|0);
       if ($79) {
        $104 = 1;$106 = 0;
       } else {
        $80 = (($$pre$i$i$i5) + 12|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = (($$pre$i$i$i5) + 16|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = ($81|0)==($83|0);
        if ($84) {
         $85 = HEAP32[$$pre$i$i$i5>>2]|0;
         $86 = (($85) + 36|0);
         $87 = HEAP32[$86>>2]|0;
         $88 = (FUNCTION_TABLE_ii[$87 & 4095]($$pre$i$i$i5)|0);
         $$0$i$i$i$i3 = $88;
        } else {
         $89 = HEAP32[$81>>2]|0;
         $$0$i$i$i$i3 = $89;
        }
        $90 = ($$0$i$i$i$i3|0)==(-1);
        if ($90) {
         HEAP32[$__b>>2] = 0;
         $104 = 1;$106 = 0;
        } else {
         $104 = 0;$106 = $$pre$i$i$i5;
        }
       }
       $91 = ($92|0)==(0|0);
       do {
        if ($91) {
         $$pre$i3$i$i1145 = $$pre$i3$i$i11;
         label = 48;
        } else {
         $93 = (($92) + 12|0);
         $94 = HEAP32[$93>>2]|0;
         $95 = (($92) + 16|0);
         $96 = HEAP32[$95>>2]|0;
         $97 = ($94|0)==($96|0);
         if ($97) {
          $98 = HEAP32[$92>>2]|0;
          $99 = (($98) + 36|0);
          $100 = HEAP32[$99>>2]|0;
          $101 = (FUNCTION_TABLE_ii[$100 & 4095]($92)|0);
          $$0$i$i1$i$i9 = $101;
         } else {
          $102 = HEAP32[$94>>2]|0;
          $$0$i$i1$i$i9 = $102;
         }
         $103 = ($$0$i$i1$i$i9|0)==(-1);
         if ($103) {
          HEAP32[$__e>>2] = 0;
          $$pre$i3$i$i1145 = 0;
          label = 48;
          break;
         } else {
          $phitmp$i4$i$i12 = ($$pre$i3$i$i11|0)==(0|0);
          $tmp$i$i14 = $104 ^ $phitmp$i4$i$i12;
          if ($tmp$i$i14) {
           $$pre$i3$i$i1144 = $$pre$i3$i$i11;$184 = $$pre$i3$i$i11;
           break;
          } else {
           $$0$ph$be = $$2$lcssa;
           break L38;
          }
         }
        }
       } while(0);
       if ((label|0) == 48) {
        label = 0;
        if ($104) {
         $$0$ph$be = $$2$lcssa;
         break L38;
        } else {
         $$pre$i3$i$i1144 = $$pre$i3$i$i1145;$184 = 0;
        }
       }
       $105 = (($106) + 12|0);
       $107 = HEAP32[$105>>2]|0;
       $108 = (($106) + 16|0);
       $109 = HEAP32[$108>>2]|0;
       $110 = ($107|0)==($109|0);
       if ($110) {
        $111 = HEAP32[$106>>2]|0;
        $112 = (($111) + 36|0);
        $113 = HEAP32[$112>>2]|0;
        $114 = (FUNCTION_TABLE_ii[$113 & 4095]($106)|0);
        $$0$i$i = $114;
       } else {
        $115 = HEAP32[$107>>2]|0;
        $$0$i$i = $115;
       }
       $116 = HEAP32[$4>>2]|0;
       $117 = (($116) + 12|0);
       $118 = HEAP32[$117>>2]|0;
       $119 = (FUNCTION_TABLE_iiii[$118 & 2047]($4,8192,$$0$i$i)|0);
       if (!($119)) {
        $$0$ph$be = $$2$lcssa;
        break L38;
       }
       $120 = HEAP32[$105>>2]|0;
       $121 = HEAP32[$108>>2]|0;
       $122 = ($120|0)==($121|0);
       if ($122) {
        $123 = HEAP32[$106>>2]|0;
        $124 = (($123) + 40|0);
        $125 = HEAP32[$124>>2]|0;
        (FUNCTION_TABLE_ii[$125 & 4095]($106)|0);
        $$pre$i$i$i5 = $106;$$pre$i3$i$i11 = $$pre$i3$i$i1144;$92 = $184;
        continue;
       } else {
        $126 = (($120) + 4|0);
        HEAP32[$105>>2] = $126;
        $$pre$i$i$i5 = $106;$$pre$i3$i$i11 = $$pre$i3$i$i1144;$92 = $184;
        continue;
       }
      }
     }
     else if ((label|0) == 61) {
      label = 0;
      $147 = HEAP32[$127>>2]|0;
      $148 = HEAP32[$129>>2]|0;
      $149 = ($147|0)==($148|0);
      if ($149) {
       $150 = HEAP32[$63>>2]|0;
       $151 = (($150) + 40|0);
       $152 = HEAP32[$151>>2]|0;
       (FUNCTION_TABLE_ii[$152 & 4095]($63)|0);
      } else {
       $153 = (($147) + 4|0);
       HEAP32[$127>>2] = $153;
      }
      $154 = (($$0$ph42) + 4|0);
      $$0$ph$be = $154;
     }
    } while(0);
    $67 = ($$0$ph$be|0)==($__fmte|0);
    if ($67) {
     label = 66;
     break L4;
    }
    $$pre43$pre = HEAP32[$__err>>2]|0;
    $$0$ph42 = $$0$ph$be;$$pre43 = $$pre43$pre;
   }
   if ((label|0) == 20) {
    HEAP32[$__err>>2] = 4;
    $$pre$i$i$i20 = $63;
    break;
   }
   else if ((label|0) == 24) {
    HEAP32[$__err>>2] = 4;
    $$pre$i$i$i20 = $63;
    break;
   }
   else if ((label|0) == 27) {
    HEAP32[$__err>>2] = 4;
    $$pre$i$i$i20 = $63;
    break;
   }
  }
 } while(0);
 if ((label|0) == 66) {
  $$pre = HEAP32[$__b>>2]|0;
  $$pre$i$i$i20 = $$pre;
 }
 $155 = ($$pre$i$i$i20|0)==(0|0);
 if ($155) {
  $182 = 0;$185 = 1;
 } else {
  $156 = (($$pre$i$i$i20) + 12|0);
  $157 = HEAP32[$156>>2]|0;
  $158 = (($$pre$i$i$i20) + 16|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = ($157|0)==($159|0);
  if ($160) {
   $161 = HEAP32[$$pre$i$i$i20>>2]|0;
   $162 = (($161) + 36|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = (FUNCTION_TABLE_ii[$163 & 4095]($$pre$i$i$i20)|0);
   $$0$i$i$i$i18 = $164;
  } else {
   $165 = HEAP32[$157>>2]|0;
   $$0$i$i$i$i18 = $165;
  }
  $166 = ($$0$i$i$i$i18|0)==(-1);
  if ($166) {
   HEAP32[$__b>>2] = 0;
   $182 = 0;$185 = 1;
  } else {
   $182 = $$pre$i$i$i20;$185 = 0;
  }
 }
 $167 = HEAP32[$__e>>2]|0;
 $168 = ($167|0)==(0|0);
 do {
  if ($168) {
   label = 79;
  } else {
   $169 = (($167) + 12|0);
   $170 = HEAP32[$169>>2]|0;
   $171 = (($167) + 16|0);
   $172 = HEAP32[$171>>2]|0;
   $173 = ($170|0)==($172|0);
   if ($173) {
    $174 = HEAP32[$167>>2]|0;
    $175 = (($174) + 36|0);
    $176 = HEAP32[$175>>2]|0;
    $177 = (FUNCTION_TABLE_ii[$176 & 4095]($167)|0);
    $$0$i$i1$i$i24 = $177;
   } else {
    $178 = HEAP32[$170>>2]|0;
    $$0$i$i1$i$i24 = $178;
   }
   $179 = ($$0$i$i1$i$i24|0)==(-1);
   if ($179) {
    HEAP32[$__e>>2] = 0;
    label = 79;
    break;
   }
   if ($185) {
    HEAP32[$agg$result>>2] = $182;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 79) {
  if (!($185)) {
   HEAP32[$agg$result>>2] = $182;
   STACKTOP = sp;return;
  }
 }
 $180 = HEAP32[$__err>>2]|0;
 $181 = $180 | 2;
 HEAP32[$__err>>2] = $181;
 HEAP32[$agg$result>>2] = $182;
 STACKTOP = sp;return;
}
function __ZNSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $3;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($agg$result,$this,$$byval_copy,$$byval_copy1,$__iob,$__err,$__tm,3092392,((3092392 + 32|0)));
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $$byval_copy1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy1 = sp + 12|0;
 $$byval_copy = sp;
 $0 = sp + 4|0;
 $1 = sp + 8|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_ii[$5 & 4095]($2)|0);
 $7 = HEAP32[$__b>>2]|0;
 HEAP32[$0>>2] = $7;
 $8 = HEAP32[$__e>>2]|0;
 HEAP32[$1>>2] = $8;
 $9 = HEAP8[$6>>0]|0;
 $10 = $9 & 1;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $16 = (($6) + 4|0);
  $17 = (($6) + 4|0);
  $18 = $9&255;
  $19 = $18 >>> 1;
  $21 = $17;$22 = $19;$23 = $16;
 } else {
  $12 = (($6) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($6) + 4|0);
  $15 = HEAP32[$14>>2]|0;
  $21 = $13;$22 = $15;$23 = $13;
 }
 $20 = (($21) + ($22<<2)|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 ;HEAP32[$$byval_copy1+0>>2]=HEAP32[$1+0>>2]|0;
 __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($agg$result,$this,$$byval_copy,$$byval_copy1,$__iob,$__err,$__tm,$23,$20);
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $2 = (invoke_iii(2228,($0|0),(3093328|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($5)|0);
  $6 = (($__tm) + 24|0);
  $7 = HEAP32[$__e>>2]|0;
  HEAP32[$1>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE($this,$6,$__b,$$byval_copy,$__err,$2);
  $8 = HEAP32[$__b>>2]|0;
  HEAP32[$agg$result>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__w,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__w = $__w|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_ii[$3 & 4095]($1)|0);
 $5 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $5;
 $6 = (($4) + 168|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $7 = (__ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb($__b,$$byval_copy,$4,$6,$__ct,$__err,0)|0);
 $8 = $7;
 $9 = $4;
 $10 = (($8) - ($9))|0;
 $11 = ($10|0)<(168);
 if (!($11)) {
  STACKTOP = sp;return;
 }
 $12 = (($10|0) / 12)&-1;
 $13 = (($12|0) % 7)&-1;
 HEAP32[$__w>>2] = $13;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $2 = (invoke_iii(2228,($0|0),(3093328|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($5)|0);
  $6 = (($__tm) + 16|0);
  $7 = HEAP32[$__e>>2]|0;
  HEAP32[$1>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE($this,$6,$__b,$$byval_copy,$__err,$2);
  $8 = HEAP32[$__b>>2]|0;
  HEAP32[$agg$result>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__m,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__m = $__m|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $6;
 $7 = (($5) + 288|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $8 = (__ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb($__b,$$byval_copy,$5,$7,$__ct,$__err,0)|0);
 $9 = $8;
 $10 = $5;
 $11 = (($9) - ($10))|0;
 $12 = ($11|0)<(288);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($11|0) / 12)&-1;
 $14 = (($13|0) % 12)&-1;
 HEAP32[$__m>>2] = $14;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = sp + 4|0;
 __ZNKSt3__18ios_base6getlocEv($0,$__iob);
 __THREW__ = 0;
 $2 = (invoke_iii(2228,($0|0),(3093328|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $9 = ___cxa_find_matching_catch()|0;
  $10 = tempRet0;
  $11 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($11)|0);
  ___resumeException($9|0);
  // unreachable;
 } else {
  $5 = HEAP32[$0>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($5)|0);
  $6 = (($__tm) + 20|0);
  $7 = HEAP32[$__e>>2]|0;
  HEAP32[$1>>2] = $7;
  ;HEAP32[$$byval_copy+0>>2]=HEAP32[$1+0>>2]|0;
  __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE(0,$6,$__b,$$byval_copy,$__err,$2);
  $8 = HEAP32[$__b>>2]|0;
  HEAP32[$agg$result>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__y,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__y = $__y|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$ = 0, $$byval_copy = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__t$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,4)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = ($2|0)<(69);
 if ($6) {
  $7 = (($2) + 2000)|0;
  $__t$0 = $7;
 } else {
  $$off = (($2) + -69)|0;
  $8 = ($$off>>>0)<(31);
  $9 = (($2) + 1900)|0;
  $$ = $8 ? $9 : $2;
  $__t$0 = $$;
 }
 $10 = (($__t$0) + -1900)|0;
 HEAP32[$__y>>2] = $10;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc($agg$result,$this,$__b,$__e,$__iob,$__err,$__tm,$__fmt,$0) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__tm = $__tm|0;
 $__fmt = $__fmt|0;
 $0 = $0|0;
 var $$byval_copy26 = 0, $$byval_copy30 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy30 = sp + 160|0;
 $$byval_copy26 = sp + 156|0;
 $1 = sp + 152|0;
 $2 = sp + 148|0;
 $3 = sp + 144|0;
 $4 = sp + 140|0;
 $5 = sp + 136|0;
 $6 = sp + 132|0;
 $7 = sp + 128|0;
 $8 = sp + 124|0;
 $9 = sp + 120|0;
 $10 = sp + 116|0;
 $11 = sp + 112|0;
 $12 = sp + 108|0;
 $13 = sp + 104|0;
 $14 = sp + 100|0;
 $15 = sp + 96|0;
 $16 = sp + 92|0;
 $17 = sp + 88|0;
 $18 = sp + 84|0;
 $19 = sp + 80|0;
 $20 = sp + 32|0;
 $21 = sp + 28|0;
 $22 = sp + 24|0;
 $23 = sp + 20|0;
 $24 = sp + 16|0;
 $25 = sp + 8|0;
 $26 = sp + 4|0;
 $27 = sp;
 $28 = sp + 12|0;
 $29 = sp + 36|0;
 $30 = sp + 40|0;
 $31 = sp + 44|0;
 $32 = sp + 48|0;
 $33 = sp + 52|0;
 $34 = sp + 56|0;
 $35 = sp + 60|0;
 $36 = sp + 64|0;
 $37 = sp + 68|0;
 $38 = sp + 72|0;
 $39 = sp + 76|0;
 HEAP32[$__err>>2] = 0;
 __ZNKSt3__18ios_base6getlocEv($1,$__iob);
 __THREW__ = 0;
 $40 = (invoke_iii(2228,($1|0),(3093328|0))|0);
 $41 = __THREW__; __THREW__ = 0;
 $42 = $41&1;
 if ($42) {
  $45 = ___cxa_find_matching_catch()|0;
  $46 = tempRet0;
  $47 = HEAP32[$1>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($47)|0);
  ___resumeException($45|0);
  // unreachable;
 }
 $43 = HEAP32[$1>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($43)|0);
 $44 = $__fmt << 24 >> 24;
 do {
  switch ($44|0) {
  case 106:  {
   $87 = (($__tm) + 28|0);
   $88 = HEAP32[$__e>>2]|0;
   HEAP32[$16>>2] = $88;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$16+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE(0,$87,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 120:  {
   $108 = HEAP32[$this>>2]|0;
   $109 = (($108) + 20|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = HEAP32[$__b>>2]|0;
   HEAP32[$32>>2] = $111;
   $112 = HEAP32[$__e>>2]|0;
   HEAP32[$33>>2] = $112;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$32+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$33+0>>2]|0;
   FUNCTION_TABLE_viiiiiii[$110 & 127]($agg$result,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm);
   STACKTOP = sp;return;
   break;
  }
  case 88:  {
   $113 = (($this) + 8|0);
   $114 = HEAP32[$113>>2]|0;
   $115 = (($114) + 24|0);
   $116 = HEAP32[$115>>2]|0;
   $117 = (FUNCTION_TABLE_ii[$116 & 4095]($113)|0);
   $118 = HEAP32[$__b>>2]|0;
   HEAP32[$35>>2] = $118;
   $119 = HEAP32[$__e>>2]|0;
   HEAP32[$36>>2] = $119;
   $120 = HEAP8[$117>>0]|0;
   $121 = $120 & 1;
   $122 = ($121<<24>>24)==(0);
   if ($122) {
    $127 = (($117) + 4|0);
    $128 = (($117) + 4|0);
    $129 = $120&255;
    $130 = $129 >>> 1;
    $132 = $128;$133 = $130;$134 = $127;
   } else {
    $123 = (($117) + 8|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (($117) + 4|0);
    $126 = HEAP32[$125>>2]|0;
    $132 = $124;$133 = $126;$134 = $124;
   }
   $131 = (($132) + ($133<<2)|0);
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$35+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$36+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($34,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,$134,$131);
   $135 = HEAP32[$34>>2]|0;
   HEAP32[$__b>>2] = $135;
   break;
  }
  case 109:  {
   $89 = (($__tm) + 16|0);
   $90 = HEAP32[$__e>>2]|0;
   HEAP32[$17>>2] = $90;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$17+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE(0,$89,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 112:  {
   $94 = (($__tm) + 8|0);
   $95 = HEAP32[$__e>>2]|0;
   HEAP32[$20>>2] = $95;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$20+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE($this,$94,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 68:  {
   $77 = HEAP32[$__b>>2]|0;
   HEAP32[$9>>2] = $77;
   $78 = HEAP32[$__e>>2]|0;
   HEAP32[$10>>2] = $78;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$9+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$10+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($8,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092424,((3092424 + 32|0)));
   $79 = HEAP32[$8>>2]|0;
   HEAP32[$__b>>2] = $79;
   break;
  }
  case 114:  {
   $96 = HEAP32[$__b>>2]|0;
   HEAP32[$22>>2] = $96;
   $97 = HEAP32[$__e>>2]|0;
   HEAP32[$23>>2] = $97;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$22+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$23+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($21,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092488,((3092488 + 44|0)));
   $98 = HEAP32[$21>>2]|0;
   HEAP32[$__b>>2] = $98;
   break;
  }
  case 37:  {
   $140 = HEAP32[$__e>>2]|0;
   HEAP32[$39>>2] = $140;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$39+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE(0,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 101: case 100:  {
   $75 = (($__tm) + 12|0);
   $76 = HEAP32[$__e>>2]|0;
   HEAP32[$7>>2] = $76;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$7+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE(0,$75,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 89:  {
   $138 = (($__tm) + 20|0);
   $139 = HEAP32[$__e>>2]|0;
   HEAP32[$38>>2] = $139;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$38+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE(0,$138,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 99:  {
   $52 = (($this) + 8|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = (($53) + 12|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = (FUNCTION_TABLE_ii[$55 & 4095]($52)|0);
   $57 = HEAP32[$__b>>2]|0;
   HEAP32[$5>>2] = $57;
   $58 = HEAP32[$__e>>2]|0;
   HEAP32[$6>>2] = $58;
   $59 = HEAP8[$56>>0]|0;
   $60 = $59 & 1;
   $61 = ($60<<24>>24)==(0);
   if ($61) {
    $66 = (($56) + 4|0);
    $67 = (($56) + 4|0);
    $68 = $59&255;
    $69 = $68 >>> 1;
    $71 = $67;$72 = $69;$73 = $66;
   } else {
    $62 = (($56) + 8|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($56) + 4|0);
    $65 = HEAP32[$64>>2]|0;
    $71 = $63;$72 = $65;$73 = $63;
   }
   $70 = (($71) + ($72<<2)|0);
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$5+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$6+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($4,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,$73,$70);
   $74 = HEAP32[$4>>2]|0;
   HEAP32[$__b>>2] = $74;
   break;
  }
  case 70:  {
   $80 = HEAP32[$__b>>2]|0;
   HEAP32[$12>>2] = $80;
   $81 = HEAP32[$__e>>2]|0;
   HEAP32[$13>>2] = $81;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$12+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$13+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($11,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092456,((3092456 + 32|0)));
   $82 = HEAP32[$11>>2]|0;
   HEAP32[$__b>>2] = $82;
   break;
  }
  case 116: case 110:  {
   $93 = HEAP32[$__e>>2]|0;
   HEAP32[$19>>2] = $93;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$19+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE(0,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 119:  {
   $106 = (($__tm) + 24|0);
   $107 = HEAP32[$__e>>2]|0;
   HEAP32[$31>>2] = $107;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$31+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE(0,$106,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 121:  {
   $136 = (($__tm) + 20|0);
   $137 = HEAP32[$__e>>2]|0;
   HEAP32[$37>>2] = $137;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$37+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE(0,$136,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 73:  {
   $85 = (($__tm) + 8|0);
   $86 = HEAP32[$__e>>2]|0;
   HEAP32[$15>>2] = $86;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$15+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE(0,$85,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 104: case 66: case 98:  {
   $50 = (($__tm) + 16|0);
   $51 = HEAP32[$__e>>2]|0;
   HEAP32[$3>>2] = $51;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$3+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE($this,$50,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 65: case 97:  {
   $48 = (($__tm) + 24|0);
   $49 = HEAP32[$__e>>2]|0;
   HEAP32[$2>>2] = $49;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$2+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE($this,$48,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 72:  {
   $83 = (($__tm) + 8|0);
   $84 = HEAP32[$__e>>2]|0;
   HEAP32[$14>>2] = $84;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$14+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE(0,$83,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 77:  {
   $91 = (($__tm) + 4|0);
   $92 = HEAP32[$__e>>2]|0;
   HEAP32[$18>>2] = $92;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$18+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE(0,$91,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 83:  {
   $102 = HEAP32[$__e>>2]|0;
   HEAP32[$27>>2] = $102;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$27+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE(0,$__tm,$__b,$$byval_copy30,$__err,$40);
   break;
  }
  case 84:  {
   $103 = HEAP32[$__b>>2]|0;
   HEAP32[$29>>2] = $103;
   $104 = HEAP32[$__e>>2]|0;
   HEAP32[$30>>2] = $104;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$29+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$30+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($28,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092560,((3092560 + 32|0)));
   $105 = HEAP32[$28>>2]|0;
   HEAP32[$__b>>2] = $105;
   break;
  }
  case 82:  {
   $99 = HEAP32[$__b>>2]|0;
   HEAP32[$25>>2] = $99;
   $100 = HEAP32[$__e>>2]|0;
   HEAP32[$26>>2] = $100;
   ;HEAP32[$$byval_copy26+0>>2]=HEAP32[$25+0>>2]|0;
   ;HEAP32[$$byval_copy30+0>>2]=HEAP32[$26+0>>2]|0;
   __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_($24,$this,$$byval_copy26,$$byval_copy30,$__iob,$__err,$__tm,3092536,((3092536 + 20|0)));
   $101 = HEAP32[$24>>2]|0;
   HEAP32[$__b>>2] = $101;
   break;
  }
  default: {
   $141 = HEAP32[$__err>>2]|0;
   $142 = $141 | 4;
   HEAP32[$__err>>2] = $142;
  }
  }
 } while(0);
 $143 = HEAP32[$__b>>2]|0;
 HEAP32[$agg$result>>2] = $143;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__d,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__d = $__d|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $$off = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if ($5) {
  $$off = (($2) + -1)|0;
  $6 = ($$off>>>0)<(31);
  if ($6) {
   HEAP32[$__d>>2] = $2;
   STACKTOP = sp;return;
  }
 }
 $7 = $3 | 4;
 HEAP32[$__err>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__h,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__h = $__h|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(24);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__h>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__h,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__h = $__h|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $$off = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if ($5) {
  $$off = (($2) + -1)|0;
  $6 = ($$off>>>0)<(12);
  if ($6) {
   HEAP32[$__h>>2] = $2;
   STACKTOP = sp;return;
  }
 }
 $7 = $3 | 4;
 HEAP32[$__err>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__d,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__d = $__d|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,3)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(366);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__d>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__m,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__m = $__m|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(13);
 $or$cond = $5 & $6;
 if ($or$cond) {
  $7 = (($2) + -1)|0;
  HEAP32[$__m>>2] = $7;
  STACKTOP = sp;return;
 } else {
  $8 = $3 | 4;
  HEAP32[$__err>>2] = $8;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__m,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__m = $__m|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(60);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__m>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE($this,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i1 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i7 = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre$i3$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 L1: while(1) {
  $0 = HEAP32[$__b>>2]|0;
  $1 = ($0|0)==(0|0);
  do {
   if ($1) {
    $78 = 1;
   } else {
    $2 = (($0) + 12|0);
    $3 = HEAP32[$2>>2]|0;
    $4 = (($0) + 16|0);
    $5 = HEAP32[$4>>2]|0;
    $6 = ($3|0)==($5|0);
    if ($6) {
     $7 = HEAP32[$0>>2]|0;
     $8 = (($7) + 36|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = (FUNCTION_TABLE_ii[$9 & 4095]($0)|0);
     $$0$i$i$i$i = $10;
    } else {
     $11 = HEAP32[$3>>2]|0;
     $$0$i$i$i$i = $11;
    }
    $12 = ($$0$i$i$i$i|0)==(-1);
    if ($12) {
     HEAP32[$__b>>2] = 0;
     $78 = 1;
     break;
    } else {
     $$pre$i$i$i = HEAP32[$__b>>2]|0;
     $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
     $78 = $phitmp$i$i$i;
     break;
    }
   }
  } while(0);
  $13 = HEAP32[$__e>>2]|0;
  $14 = ($13|0)==(0|0);
  do {
   if ($14) {
    label = 15;
   } else {
    $15 = (($13) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($13) + 16|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($16|0)==($18|0);
    if ($19) {
     $20 = HEAP32[$13>>2]|0;
     $21 = (($20) + 36|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (FUNCTION_TABLE_ii[$22 & 4095]($13)|0);
     $$0$i$i1$i$i = $23;
    } else {
     $24 = HEAP32[$16>>2]|0;
     $$0$i$i1$i$i = $24;
    }
    $25 = ($$0$i$i1$i$i|0)==(-1);
    if ($25) {
     HEAP32[$__e>>2] = 0;
     label = 15;
     break;
    } else {
     if ($78) {
      $79 = $13;
      break;
     } else {
      $$pre$i3$i$i9 = $13;
      break L1;
     }
    }
   }
  } while(0);
  if ((label|0) == 15) {
   label = 0;
   if ($78) {
    $$pre$i3$i$i9 = 0;
    break;
   } else {
    $79 = 0;
   }
  }
  $26 = HEAP32[$__b>>2]|0;
  $27 = (($26) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 16|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28|0)==($30|0);
  if ($31) {
   $32 = HEAP32[$26>>2]|0;
   $33 = (($32) + 36|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (FUNCTION_TABLE_ii[$34 & 4095]($26)|0);
   $$0$i$i = $35;
  } else {
   $36 = HEAP32[$28>>2]|0;
   $$0$i$i = $36;
  }
  $37 = HEAP32[$__ct>>2]|0;
  $38 = (($37) + 12|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (FUNCTION_TABLE_iiii[$39 & 2047]($__ct,8192,$$0$i$i)|0);
  if (!($40)) {
   $$pre$i3$i$i9 = $79;
   break;
  }
  $41 = HEAP32[$__b>>2]|0;
  $42 = (($41) + 12|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 16|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($43|0)==($45|0);
  if ($46) {
   $47 = HEAP32[$41>>2]|0;
   $48 = (($47) + 40|0);
   $49 = HEAP32[$48>>2]|0;
   (FUNCTION_TABLE_ii[$49 & 4095]($41)|0);
   continue;
  } else {
   $50 = (($43) + 4|0);
   HEAP32[$42>>2] = $50;
   continue;
  }
 }
 $51 = HEAP32[$__b>>2]|0;
 $52 = ($51|0)==(0|0);
 do {
  if ($52) {
   $80 = 1;
  } else {
   $53 = (($51) + 12|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (($51) + 16|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ($54|0)==($56|0);
   if ($57) {
    $58 = HEAP32[$51>>2]|0;
    $59 = (($58) + 36|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = (FUNCTION_TABLE_ii[$60 & 4095]($51)|0);
    $$0$i$i$i$i1 = $61;
   } else {
    $62 = HEAP32[$54>>2]|0;
    $$0$i$i$i$i1 = $62;
   }
   $63 = ($$0$i$i$i$i1|0)==(-1);
   if ($63) {
    HEAP32[$__b>>2] = 0;
    $80 = 1;
    break;
   } else {
    $$pre$i$i$i3 = HEAP32[$__b>>2]|0;
    $phitmp$i$i$i4 = ($$pre$i$i$i3|0)==(0|0);
    $80 = $phitmp$i$i$i4;
    break;
   }
  }
 } while(0);
 $64 = ($$pre$i3$i$i9|0)==(0|0);
 do {
  if ($64) {
   label = 37;
  } else {
   $65 = (($$pre$i3$i$i9) + 12|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = (($$pre$i3$i$i9) + 16|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($66|0)==($68|0);
   if ($69) {
    $70 = HEAP32[$$pre$i3$i$i9>>2]|0;
    $71 = (($70) + 36|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (FUNCTION_TABLE_ii[$72 & 4095]($$pre$i3$i$i9)|0);
    $$0$i$i1$i$i7 = $73;
   } else {
    $74 = HEAP32[$66>>2]|0;
    $$0$i$i1$i$i7 = $74;
   }
   $75 = ($$0$i$i1$i$i7|0)==(-1);
   if ($75) {
    HEAP32[$__e>>2] = 0;
    label = 37;
    break;
   }
   if ($80) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 37) {
  if (!($80)) {
   STACKTOP = sp;return;
  }
 }
 $76 = HEAP32[$__err>>2]|0;
 $77 = $76 | 2;
 HEAP32[$__err>>2] = $77;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__h,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__h = $__h|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 4095]($1)|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 & 1;
 $8 = ($7<<24>>24)==(0);
 if ($8) {
  $11 = $6&255;
  $12 = $11 >>> 1;
  $24 = $12;
 } else {
  $9 = (($5) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $24 = $10;
 }
 $13 = (($5) + 12|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14 & 1;
 $16 = ($15<<24>>24)==(0);
 if ($16) {
  $19 = $14&255;
  $20 = $19 >>> 1;
  $22 = $20;
 } else {
  $17 = (($5) + 16|0);
  $18 = HEAP32[$17>>2]|0;
  $22 = $18;
 }
 $21 = (0 - ($22))|0;
 $23 = ($24|0)==($21|0);
 if ($23) {
  $25 = HEAP32[$__err>>2]|0;
  $26 = $25 | 4;
  HEAP32[$__err>>2] = $26;
  STACKTOP = sp;return;
 }
 $27 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $27;
 $28 = (($5) + 24|0);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $29 = (__ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb($__b,$$byval_copy,$5,$28,$__ct,$__err,0)|0);
 $30 = $29;
 $31 = $5;
 $32 = (($30) - ($31))|0;
 $33 = ($29|0)==($5|0);
 if ($33) {
  $34 = HEAP32[$__h>>2]|0;
  $35 = ($34|0)==(12);
  if ($35) {
   HEAP32[$__h>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 $36 = ($32|0)==(12);
 if (!($36)) {
  STACKTOP = sp;return;
 }
 $37 = HEAP32[$__h>>2]|0;
 $38 = ($37|0)<(12);
 if (!($38)) {
  STACKTOP = sp;return;
 }
 $39 = (($37) + 12)|0;
 HEAP32[$__h>>2] = $39;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__s,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__s = $__s|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,2)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(61);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__s>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__w,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__w = $__w|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,1)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 $6 = ($2|0)<(7);
 $or$cond = $5 & $6;
 if ($or$cond) {
  HEAP32[$__w>>2] = $2;
  STACKTOP = sp;return;
 } else {
  $7 = $3 | 4;
  HEAP32[$__err>>2] = $7;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE($this,$__y,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__y = $__y|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 4|0;
 $0 = sp;
 $1 = HEAP32[$__e>>2]|0;
 HEAP32[$0>>2] = $1;
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
 $2 = (__ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$$byval_copy,$__err,$__ct,4)|0);
 $3 = HEAP32[$__err>>2]|0;
 $4 = $3 & 4;
 $5 = ($4|0)==(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($2) + -1900)|0;
 HEAP32[$__y>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE($this,$__b,$__e,$__err,$__ct) {
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 var $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i1 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i7 = 0, $$pre$i$i$i = 0, $$pre$i$i$i3 = 0, $$pre$i3$i$i915 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__b>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $83 = 1;
  } else {
   $2 = (($0) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($0) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3|0)==($5|0);
   if ($6) {
    $7 = HEAP32[$0>>2]|0;
    $8 = (($7) + 36|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (FUNCTION_TABLE_ii[$9 & 4095]($0)|0);
    $$0$i$i$i$i = $10;
   } else {
    $11 = HEAP32[$3>>2]|0;
    $$0$i$i$i$i = $11;
   }
   $12 = ($$0$i$i$i$i|0)==(-1);
   if ($12) {
    HEAP32[$__b>>2] = 0;
    $83 = 1;
    break;
   } else {
    $$pre$i$i$i = HEAP32[$__b>>2]|0;
    $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
    $83 = $phitmp$i$i$i;
    break;
   }
  }
 } while(0);
 $13 = HEAP32[$__e>>2]|0;
 $14 = ($13|0)==(0|0);
 do {
  if ($14) {
   label = 14;
  } else {
   $15 = (($13) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($13) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)==($18|0);
   if ($19) {
    $20 = HEAP32[$13>>2]|0;
    $21 = (($20) + 36|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (FUNCTION_TABLE_ii[$22 & 4095]($13)|0);
    $$0$i$i1$i$i = $23;
   } else {
    $24 = HEAP32[$16>>2]|0;
    $$0$i$i1$i$i = $24;
   }
   $25 = ($$0$i$i1$i$i|0)==(-1);
   if ($25) {
    HEAP32[$__e>>2] = 0;
    label = 14;
    break;
   } else {
    if ($83) {
     $$pre$i3$i$i915 = $13;
     break;
    } else {
     label = 16;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  if ($83) {
   label = 16;
  } else {
   $$pre$i3$i$i915 = 0;
  }
 }
 if ((label|0) == 16) {
  $26 = HEAP32[$__err>>2]|0;
  $27 = $26 | 6;
  HEAP32[$__err>>2] = $27;
  STACKTOP = sp;return;
 }
 $28 = HEAP32[$__b>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($30|0)==($32|0);
 if ($33) {
  $34 = HEAP32[$28>>2]|0;
  $35 = (($34) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (FUNCTION_TABLE_ii[$36 & 4095]($28)|0);
  $$0$i$i = $37;
 } else {
  $38 = HEAP32[$30>>2]|0;
  $$0$i$i = $38;
 }
 $39 = HEAP32[$__ct>>2]|0;
 $40 = (($39) + 52|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (FUNCTION_TABLE_iiii[$41 & 2047]($__ct,$$0$i$i,0)|0);
 $43 = ($42<<24>>24)==(37);
 if (!($43)) {
  $44 = HEAP32[$__err>>2]|0;
  $45 = $44 | 4;
  HEAP32[$__err>>2] = $45;
  STACKTOP = sp;return;
 }
 $46 = HEAP32[$__b>>2]|0;
 $47 = (($46) + 12|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 16|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($48|0)==($50|0);
 if ($51) {
  $52 = HEAP32[$46>>2]|0;
  $53 = (($52) + 40|0);
  $54 = HEAP32[$53>>2]|0;
  (FUNCTION_TABLE_ii[$54 & 4095]($46)|0);
 } else {
  $55 = (($48) + 4|0);
  HEAP32[$47>>2] = $55;
 }
 $56 = HEAP32[$__b>>2]|0;
 $57 = ($56|0)==(0|0);
 do {
  if ($57) {
   $84 = 1;
  } else {
   $58 = (($56) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = (($56) + 16|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($59|0)==($61|0);
   if ($62) {
    $63 = HEAP32[$56>>2]|0;
    $64 = (($63) + 36|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = (FUNCTION_TABLE_ii[$65 & 4095]($56)|0);
    $$0$i$i$i$i1 = $66;
   } else {
    $67 = HEAP32[$59>>2]|0;
    $$0$i$i$i$i1 = $67;
   }
   $68 = ($$0$i$i$i$i1|0)==(-1);
   if ($68) {
    HEAP32[$__b>>2] = 0;
    $84 = 1;
    break;
   } else {
    $$pre$i$i$i3 = HEAP32[$__b>>2]|0;
    $phitmp$i$i$i4 = ($$pre$i$i$i3|0)==(0|0);
    $84 = $phitmp$i$i$i4;
    break;
   }
  }
 } while(0);
 $69 = ($$pre$i3$i$i915|0)==(0|0);
 do {
  if ($69) {
   label = 38;
  } else {
   $70 = (($$pre$i3$i$i915) + 12|0);
   $71 = HEAP32[$70>>2]|0;
   $72 = (($$pre$i3$i$i915) + 16|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = ($71|0)==($73|0);
   if ($74) {
    $75 = HEAP32[$$pre$i3$i$i915>>2]|0;
    $76 = (($75) + 36|0);
    $77 = HEAP32[$76>>2]|0;
    $78 = (FUNCTION_TABLE_ii[$77 & 4095]($$pre$i3$i$i915)|0);
    $$0$i$i1$i$i7 = $78;
   } else {
    $79 = HEAP32[$71>>2]|0;
    $$0$i$i1$i$i7 = $79;
   }
   $80 = ($$0$i$i1$i$i7|0)==(-1);
   if ($80) {
    HEAP32[$__e>>2] = 0;
    label = 38;
    break;
   }
   if ($84) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 if ((label|0) == 38) {
  if (!($84)) {
   STACKTOP = sp;return;
  }
 }
 $81 = HEAP32[$__err>>2]|0;
 $82 = $81 | 2;
 HEAP32[$__err>>2] = $82;
 STACKTOP = sp;return;
}
function __ZNSt3__120__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi($__b,$__e,$__err,$__ct,$__n) {
 $__b = $__b|0;
 $__e = $__e|0;
 $__err = $__err|0;
 $__ct = $__ct|0;
 $__n = $__n|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i17 = 0, $$0$i$i$i$i2 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i23 = 0, $$0$i$i1$i$i8 = 0, $$0$i$i14 = 0, $$0$in = 0, $$01 = 0, $$pre$i$i$i = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i4 = 0, $$pre$i3$i$i10 = 0, $$pre$i3$i$i25 = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__r$0 = 0, $__r$0$in = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i20 = 0, $phitmp$i$i$i5 = 0, $phitmp$i4$i$i11 = 0, $tmp$i$i13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__b>>2]|0;
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $147 = 1;
  } else {
   $2 = (($0) + 12|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (($0) + 16|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3|0)==($5|0);
   if ($6) {
    $7 = HEAP32[$0>>2]|0;
    $8 = (($7) + 36|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = (FUNCTION_TABLE_ii[$9 & 4095]($0)|0);
    $$0$i$i$i$i = $10;
   } else {
    $11 = HEAP32[$3>>2]|0;
    $$0$i$i$i$i = $11;
   }
   $12 = ($$0$i$i$i$i|0)==(-1);
   if ($12) {
    HEAP32[$__b>>2] = 0;
    $147 = 1;
    break;
   } else {
    $$pre$i$i$i = HEAP32[$__b>>2]|0;
    $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
    $147 = $phitmp$i$i$i;
    break;
   }
  }
 } while(0);
 $13 = HEAP32[$__e>>2]|0;
 $14 = ($13|0)==(0|0);
 do {
  if ($14) {
   label = 14;
  } else {
   $15 = (($13) + 12|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = (($13) + 16|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($16|0)==($18|0);
   if ($19) {
    $20 = HEAP32[$13>>2]|0;
    $21 = (($20) + 36|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = (FUNCTION_TABLE_ii[$22 & 4095]($13)|0);
    $$0$i$i1$i$i = $23;
   } else {
    $24 = HEAP32[$16>>2]|0;
    $$0$i$i1$i$i = $24;
   }
   $25 = ($$0$i$i1$i$i|0)==(-1);
   if ($25) {
    HEAP32[$__e>>2] = 0;
    label = 14;
    break;
   } else {
    if ($147) {
     $148 = $13;
     break;
    } else {
     label = 16;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 14) {
  if ($147) {
   label = 16;
  } else {
   $148 = 0;
  }
 }
 if ((label|0) == 16) {
  $26 = HEAP32[$__err>>2]|0;
  $27 = $26 | 6;
  HEAP32[$__err>>2] = $27;
  $$01 = 0;
  STACKTOP = sp;return ($$01|0);
 }
 $28 = HEAP32[$__b>>2]|0;
 $29 = (($28) + 12|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($30|0)==($32|0);
 if ($33) {
  $34 = HEAP32[$28>>2]|0;
  $35 = (($34) + 36|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (FUNCTION_TABLE_ii[$36 & 4095]($28)|0);
  $$0$i$i = $37;
 } else {
  $38 = HEAP32[$30>>2]|0;
  $$0$i$i = $38;
 }
 $39 = HEAP32[$__ct>>2]|0;
 $40 = (($39) + 12|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (FUNCTION_TABLE_iiii[$41 & 2047]($__ct,2048,$$0$i$i)|0);
 if (!($42)) {
  $43 = HEAP32[$__err>>2]|0;
  $44 = $43 | 4;
  HEAP32[$__err>>2] = $44;
  $$01 = 0;
  STACKTOP = sp;return ($$01|0);
 }
 $45 = HEAP32[$__ct>>2]|0;
 $46 = (($45) + 52|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (FUNCTION_TABLE_iiii[$47 & 2047]($__ct,$$0$i$i,0)|0);
 $49 = $48 << 24 >> 24;
 $50 = HEAP32[$__b>>2]|0;
 $51 = (($50) + 12|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($52|0)==($54|0);
 if ($55) {
  $56 = HEAP32[$50>>2]|0;
  $57 = (($56) + 40|0);
  $58 = HEAP32[$57>>2]|0;
  (FUNCTION_TABLE_ii[$58 & 4095]($50)|0);
  $$0$in = $__n;$$pre$i3$i$i10 = $148;$74 = $148;$__r$0$in = $49;
 } else {
  $59 = (($52) + 4|0);
  HEAP32[$51>>2] = $59;
  $$0$in = $__n;$$pre$i3$i$i10 = $148;$74 = $148;$__r$0$in = $49;
 }
 while(1) {
  $__r$0 = (($__r$0$in) + -48)|0;
  $$0 = (($$0$in) + -1)|0;
  $60 = HEAP32[$__b>>2]|0;
  $61 = ($60|0)==(0|0);
  do {
   if ($61) {
    $86 = 1;
   } else {
    $62 = (($60) + 12|0);
    $63 = HEAP32[$62>>2]|0;
    $64 = (($60) + 16|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = ($63|0)==($65|0);
    if ($66) {
     $67 = HEAP32[$60>>2]|0;
     $68 = (($67) + 36|0);
     $69 = HEAP32[$68>>2]|0;
     $70 = (FUNCTION_TABLE_ii[$69 & 4095]($60)|0);
     $$0$i$i$i$i2 = $70;
    } else {
     $71 = HEAP32[$63>>2]|0;
     $$0$i$i$i$i2 = $71;
    }
    $72 = ($$0$i$i$i$i2|0)==(-1);
    if ($72) {
     HEAP32[$__b>>2] = 0;
     $86 = 1;
     break;
    } else {
     $$pre$i$i$i4 = HEAP32[$__b>>2]|0;
     $phitmp$i$i$i5 = ($$pre$i$i$i4|0)==(0|0);
     $86 = $phitmp$i$i$i5;
     break;
    }
   }
  } while(0);
  $73 = ($74|0)==(0|0);
  do {
   if ($73) {
    $$pre$i3$i$i25 = $$pre$i3$i$i10;$149 = 0;$87 = 1;
   } else {
    $75 = (($74) + 12|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = (($74) + 16|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ($76|0)==($78|0);
    if ($79) {
     $80 = HEAP32[$74>>2]|0;
     $81 = (($80) + 36|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = (FUNCTION_TABLE_ii[$82 & 4095]($74)|0);
     $$0$i$i1$i$i8 = $83;
    } else {
     $84 = HEAP32[$76>>2]|0;
     $$0$i$i1$i$i8 = $84;
    }
    $85 = ($$0$i$i1$i$i8|0)==(-1);
    if ($85) {
     HEAP32[$__e>>2] = 0;
     $$pre$i3$i$i25 = 0;$149 = 0;$87 = 1;
     break;
    } else {
     $phitmp$i4$i$i11 = ($$pre$i3$i$i10|0)==(0|0);
     $$pre$i3$i$i25 = $$pre$i3$i$i10;$149 = $$pre$i3$i$i10;$87 = $phitmp$i4$i$i11;
     break;
    }
   }
  } while(0);
  $tmp$i$i13 = $86 ^ $87;
  $88 = ($$0|0)>(0);
  $$ = $tmp$i$i13 & $88;
  $89 = HEAP32[$__b>>2]|0;
  if (!($$)) {
   break;
  }
  $90 = (($89) + 12|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($89) + 16|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = ($91|0)==($93|0);
  if ($94) {
   $95 = HEAP32[$89>>2]|0;
   $96 = (($95) + 36|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = (FUNCTION_TABLE_ii[$97 & 4095]($89)|0);
   $$0$i$i14 = $98;
  } else {
   $99 = HEAP32[$91>>2]|0;
   $$0$i$i14 = $99;
  }
  $100 = HEAP32[$__ct>>2]|0;
  $101 = (($100) + 12|0);
  $102 = HEAP32[$101>>2]|0;
  $103 = (FUNCTION_TABLE_iiii[$102 & 2047]($__ct,2048,$$0$i$i14)|0);
  if (!($103)) {
   $$01 = $__r$0;
   label = 63;
   break;
  }
  $104 = ($__r$0*10)|0;
  $105 = HEAP32[$__ct>>2]|0;
  $106 = (($105) + 52|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (FUNCTION_TABLE_iiii[$107 & 2047]($__ct,$$0$i$i14,0)|0);
  $109 = $108 << 24 >> 24;
  $110 = (($109) + ($104))|0;
  $111 = HEAP32[$__b>>2]|0;
  $112 = (($111) + 12|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = (($111) + 16|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = ($113|0)==($115|0);
  if ($116) {
   $117 = HEAP32[$111>>2]|0;
   $118 = (($117) + 40|0);
   $119 = HEAP32[$118>>2]|0;
   (FUNCTION_TABLE_ii[$119 & 4095]($111)|0);
   $$0$in = $$0;$$pre$i3$i$i10 = $$pre$i3$i$i25;$74 = $149;$__r$0$in = $110;
   continue;
  } else {
   $120 = (($113) + 4|0);
   HEAP32[$112>>2] = $120;
   $$0$in = $$0;$$pre$i3$i$i10 = $$pre$i3$i$i25;$74 = $149;$__r$0$in = $110;
   continue;
  }
 }
 if ((label|0) == 63) {
  STACKTOP = sp;return ($$01|0);
 }
 $121 = ($89|0)==(0|0);
 do {
  if ($121) {
   $150 = 1;
  } else {
   $122 = (($89) + 12|0);
   $123 = HEAP32[$122>>2]|0;
   $124 = (($89) + 16|0);
   $125 = HEAP32[$124>>2]|0;
   $126 = ($123|0)==($125|0);
   if ($126) {
    $127 = HEAP32[$89>>2]|0;
    $128 = (($127) + 36|0);
    $129 = HEAP32[$128>>2]|0;
    $130 = (FUNCTION_TABLE_ii[$129 & 4095]($89)|0);
    $$0$i$i$i$i17 = $130;
   } else {
    $131 = HEAP32[$123>>2]|0;
    $$0$i$i$i$i17 = $131;
   }
   $132 = ($$0$i$i$i$i17|0)==(-1);
   if ($132) {
    HEAP32[$__b>>2] = 0;
    $150 = 1;
    break;
   } else {
    $$pre$i$i$i19 = HEAP32[$__b>>2]|0;
    $phitmp$i$i$i20 = ($$pre$i$i$i19|0)==(0|0);
    $150 = $phitmp$i$i$i20;
    break;
   }
  }
 } while(0);
 $133 = ($$pre$i3$i$i25|0)==(0|0);
 do {
  if ($133) {
   label = 60;
  } else {
   $134 = (($$pre$i3$i$i25) + 12|0);
   $135 = HEAP32[$134>>2]|0;
   $136 = (($$pre$i3$i$i25) + 16|0);
   $137 = HEAP32[$136>>2]|0;
   $138 = ($135|0)==($137|0);
   if ($138) {
    $139 = HEAP32[$$pre$i3$i$i25>>2]|0;
    $140 = (($139) + 36|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = (FUNCTION_TABLE_ii[$141 & 4095]($$pre$i3$i$i25)|0);
    $$0$i$i1$i$i23 = $142;
   } else {
    $143 = HEAP32[$135>>2]|0;
    $$0$i$i1$i$i23 = $143;
   }
   $144 = ($$0$i$i1$i$i23|0)==(-1);
   if ($144) {
    HEAP32[$__e>>2] = 0;
    label = 60;
    break;
   }
   if ($150) {
    $$01 = $__r$0;
    STACKTOP = sp;return ($$01|0);
   }
  }
 } while(0);
 if ((label|0) == 60) {
  if (!($150)) {
   $$01 = $__r$0;
   STACKTOP = sp;return ($$01|0);
  }
 }
 $145 = HEAP32[$__err>>2]|0;
 $146 = $145 | 2;
 HEAP32[$__err>>2] = $146;
 $$01 = $__r$0;
 STACKTOP = sp;return ($$01|0);
}
function __ZNSt3__18time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNSt3__110__time_putD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNSt3__110__time_putD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNSt3__110__time_putD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 __THREW__ = 0;
 $1 = (invoke_i(134)|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $4 = ($0|0)==($1|0);
  if ($4) {
   STACKTOP = sp;return;
  }
  $5 = HEAP32[$this>>2]|0;
  __THREW__ = 0;
  invoke_vi(3854,($5|0));
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if (!($7)) {
   STACKTOP = sp;return;
  }
 }
 $8 = ___cxa_find_matching_catch(0|0)|0;
 $9 = tempRet0;
 ___clang_call_terminate($8);
 // unreachable;
}
function __ZNKSt3__18time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc($agg$result,$this,$__s,$0,$1,$__tm,$__fmt,$__mod) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $0 = $0|0;
 $1 = $1|0;
 $__tm = $__tm|0;
 $__fmt = $__fmt|0;
 $__mod = $__mod|0;
 var $$$i = 0, $$01$i$i = 0, $$7$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nar = 0, $__ne = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $__nar = sp + 4|0;
 $__ne = sp;
 $2 = (($__nar) + 100|0);
 HEAP32[$__ne>>2] = $2;
 $3 = (($this) + 8|0);
 __ZNKSt3__110__time_put8__do_putEPcRS1_PK2tmcc($3,$__nar,$__ne,$__tm,$__fmt,$__mod);
 $4 = HEAP32[$__ne>>2]|0;
 $5 = HEAP32[$__s>>2]|0;
 $6 = ($__nar|0)==($4|0);
 if ($6) {
  $25 = $5;
  HEAP32[$agg$result>>2] = $25;
  STACKTOP = sp;return;
 } else {
  $$01$i$i = $__nar;$22 = $5;$9 = $5;
 }
 while(1) {
  $7 = HEAP8[$$01$i$i>>0]|0;
  $8 = ($9|0)==(0|0);
  do {
   if ($8) {
    $26 = $22;$27 = 0;
   } else {
    $10 = (($9) + 24|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($9) + 28|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($11|0)==($13|0);
    if ($14) {
     $16 = HEAP32[$9>>2]|0;
     $17 = (($16) + 52|0);
     $18 = HEAP32[$17>>2]|0;
     $19 = $7&255;
     $20 = (FUNCTION_TABLE_iii[$18 & 4095]($9,$19)|0);
     $21 = ($20|0)==(-1);
     $$$i = $21 ? 0 : $22;
     $$7$i = $21 ? 0 : $9;
     $26 = $$$i;$27 = $$7$i;
     break;
    } else {
     $15 = (($11) + 1|0);
     HEAP32[$10>>2] = $15;
     HEAP8[$11>>0] = $7;
     $26 = $22;$27 = $9;
     break;
    }
   }
  } while(0);
  $23 = (($$01$i$i) + 1|0);
  $24 = ($23|0)==($4|0);
  if ($24) {
   $25 = $26;
   break;
  } else {
   $$01$i$i = $23;$22 = $26;$9 = $27;
  }
 }
 HEAP32[$agg$result>>2] = $25;
 STACKTOP = sp;return;
}
function __ZNKSt3__110__time_put8__do_putEPcRS1_PK2tmcc($this,$__nb,$__ne,$__tm,$__fmt,$__mod) {
 $this = $this|0;
 $__nb = $__nb|0;
 $__ne = $__ne|0;
 $__tm = $__tm|0;
 $__fmt = $__fmt|0;
 $__mod = $__mod|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fmt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fmt = sp;
 HEAP8[$fmt>>0] = 37;
 $0 = (($fmt) + 1|0);
 HEAP8[$0>>0] = $__fmt;
 $1 = (($fmt) + 2|0);
 HEAP8[$1>>0] = $__mod;
 $2 = (($fmt) + 3|0);
 HEAP8[$2>>0] = 0;
 $3 = ($__mod<<24>>24)==(0);
 if (!($3)) {
  HEAP8[$0>>0] = $__mod;
  HEAP8[$1>>0] = $__fmt;
 }
 $4 = HEAP32[$__ne>>2]|0;
 $5 = $4;
 $6 = $__nb;
 $7 = (($5) - ($6))|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (_strftime_l(($__nb|0),($7|0),($fmt|0),($__tm|0),($8|0))|0);
 $10 = (($__nb) + ($9)|0);
 HEAP32[$__ne>>2] = $10;
 STACKTOP = sp;return;
}
function __ZNSt3__18time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNSt3__110__time_putD2Ev($0);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZNSt3__110__time_putD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNKSt3__18time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc($agg$result,$this,$__s,$0,$1,$__tm,$__fmt,$__mod) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $0 = $0|0;
 $1 = $1|0;
 $__tm = $__tm|0;
 $__fmt = $__fmt|0;
 $__mod = $__mod|0;
 var $$$i = 0, $$0$i$i$i$i = 0, $$01$i$i = 0, $$7$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nar = 0, $__ne = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 416|0;
 $__nar = sp + 8|0;
 $__ne = sp;
 $2 = (($__nar) + 400|0);
 HEAP32[$__ne>>2] = $2;
 $3 = (($this) + 8|0);
 __ZNKSt3__110__time_put8__do_putEPwRS1_PK2tmcc($3,$__nar,$__ne,$__tm,$__fmt,$__mod);
 $4 = HEAP32[$__ne>>2]|0;
 $5 = HEAP32[$__s>>2]|0;
 $6 = ($__nar|0)==($4|0);
 if ($6) {
  $24 = $5;
  HEAP32[$agg$result>>2] = $24;
  STACKTOP = sp;return;
 } else {
  $$01$i$i = $__nar;$21 = $5;$9 = $5;
 }
 while(1) {
  $7 = HEAP32[$$01$i$i>>2]|0;
  $8 = ($9|0)==(0|0);
  if ($8) {
   $25 = $21;$26 = 0;
  } else {
   $10 = (($9) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($11|0)==($13|0);
   if ($14) {
    $15 = HEAP32[$9>>2]|0;
    $16 = (($15) + 52|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (FUNCTION_TABLE_iii[$17 & 4095]($9,$7)|0);
    $$0$i$i$i$i = $18;
   } else {
    $19 = (($11) + 4|0);
    HEAP32[$10>>2] = $19;
    HEAP32[$11>>2] = $7;
    $$0$i$i$i$i = $7;
   }
   $20 = ($$0$i$i$i$i|0)==(-1);
   $$$i = $20 ? 0 : $21;
   $$7$i = $20 ? 0 : $9;
   $25 = $$$i;$26 = $$7$i;
  }
  $22 = (($$01$i$i) + 4|0);
  $23 = ($22|0)==($4|0);
  if ($23) {
   $24 = $25;
   break;
  } else {
   $$01$i$i = $22;$21 = $25;$9 = $26;
  }
 }
 HEAP32[$agg$result>>2] = $24;
 STACKTOP = sp;return;
}
function __ZNKSt3__110__time_put8__do_putEPwRS1_PK2tmcc($this,$__wb,$__we,$__tm,$__fmt,$__mod) {
 $this = $this|0;
 $__wb = $__wb|0;
 $__we = $__we|0;
 $__tm = $__tm|0;
 $__fmt = $__fmt|0;
 $__mod = $__mod|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__nar = 0, $__nb = 0, $__ne = 0, $mb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $__nar = sp + 16|0;
 $__ne = sp + 8|0;
 $mb = sp;
 $__nb = sp + 12|0;
 $0 = (($__nar) + 100|0);
 HEAP32[$__ne>>2] = $0;
 __ZNKSt3__110__time_put8__do_putEPcRS1_PK2tmcc($this,$__nar,$__ne,$__tm,$__fmt,$__mod);
 $1 = $mb;
 $2 = $1;
 HEAP32[$2>>2] = 0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 HEAP32[$__nb>>2] = $__nar;
 $5 = HEAP32[$__we>>2]|0;
 $6 = $5;
 $7 = $__wb;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 2;
 $10 = HEAP32[$this>>2]|0;
 $11 = (_uselocale(($10|0))|0);
 __THREW__ = 0;
 $12 = (invoke_iiiii(343,($__wb|0),($__nb|0),($9|0),($mb|0))|0);
 $13 = __THREW__; __THREW__ = 0;
 $14 = $13&1;
 if ($14) {
  $20 = ___cxa_find_matching_catch()|0;
  $21 = tempRet0;
  $22 = ($11|0)==(0|0);
  if ($22) {
   ___resumeException($20|0);
   // unreachable;
  }
  __THREW__ = 0;
  (invoke_ii(3483,($11|0))|0);
  $23 = __THREW__; __THREW__ = 0;
  $24 = $23&1;
  if ($24) {
   $25 = ___cxa_find_matching_catch(0|0)|0;
   $26 = tempRet0;
   ___clang_call_terminate($25);
   // unreachable;
  } else {
   ___resumeException($20|0);
   // unreachable;
  }
 }
 $15 = ($11|0)==(0|0);
 if (!($15)) {
  __THREW__ = 0;
  (invoke_ii(3483,($11|0))|0);
  $16 = __THREW__; __THREW__ = 0;
  $17 = $16&1;
  if ($17) {
   $18 = ___cxa_find_matching_catch(0|0)|0;
   $19 = tempRet0;
   ___clang_call_terminate($18);
   // unreachable;
  }
 }
 $27 = ($12|0)==(-1);
 if ($27) {
  __ZNSt3__121__throw_runtime_errorEPKc(3094216);
  // unreachable;
 } else {
  $28 = (($__wb) + ($12<<2)|0);
  HEAP32[$__we>>2] = $28;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__110moneypunctIcLb0EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__110moneypunctIcLb0EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb0EE16do_decimal_pointEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 127;
}
function __ZNKSt3__110moneypunctIcLb0EE16do_thousands_sepEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 127;
}
function __ZNKSt3__110moneypunctIcLb0EE11do_groupingEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb0EE14do_curr_symbolEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb0EE16do_positive_signEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb0EE16do_negative_signEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEjc($agg$result,1,45);
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb0EE14do_frac_digitsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__110moneypunctIcLb0EE13do_pos_formatEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0]=67109634&255;HEAP8[$agg$result+1>>0]=(67109634>>8)&255;HEAP8[$agg$result+2>>0]=(67109634>>16)&255;HEAP8[$agg$result+3>>0]=67109634>>24;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb0EE13do_neg_formatEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0]=67109634&255;HEAP8[$agg$result+1>>0]=(67109634>>8)&255;HEAP8[$agg$result+2>>0]=(67109634>>16)&255;HEAP8[$agg$result+3>>0]=67109634>>24;
 STACKTOP = sp;return;
}
function __ZNSt3__110moneypunctIcLb1EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__110moneypunctIcLb1EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb1EE16do_decimal_pointEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 127;
}
function __ZNKSt3__110moneypunctIcLb1EE16do_thousands_sepEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 127;
}
function __ZNKSt3__110moneypunctIcLb1EE11do_groupingEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb1EE14do_curr_symbolEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb1EE16do_positive_signEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb1EE16do_negative_signEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEjc($agg$result,1,45);
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb1EE14do_frac_digitsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__110moneypunctIcLb1EE13do_pos_formatEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0]=67109634&255;HEAP8[$agg$result+1>>0]=(67109634>>8)&255;HEAP8[$agg$result+2>>0]=(67109634>>16)&255;HEAP8[$agg$result+3>>0]=67109634>>24;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIcLb1EE13do_neg_formatEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0]=67109634&255;HEAP8[$agg$result+1>>0]=(67109634>>8)&255;HEAP8[$agg$result+2>>0]=(67109634>>16)&255;HEAP8[$agg$result+3>>0]=67109634>>24;
 STACKTOP = sp;return;
}
function __ZNSt3__110moneypunctIwLb0EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__110moneypunctIwLb0EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb0EE16do_decimal_pointEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2147483647;
}
function __ZNKSt3__110moneypunctIwLb0EE16do_thousands_sepEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2147483647;
}
function __ZNKSt3__110moneypunctIwLb0EE11do_groupingEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb0EE14do_curr_symbolEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb0EE16do_positive_signEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb0EE16do_negative_signEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEjw($agg$result,1,45);
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb0EE14do_frac_digitsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__110moneypunctIwLb0EE13do_pos_formatEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0]=67109634&255;HEAP8[$agg$result+1>>0]=(67109634>>8)&255;HEAP8[$agg$result+2>>0]=(67109634>>16)&255;HEAP8[$agg$result+3>>0]=67109634>>24;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb0EE13do_neg_formatEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0]=67109634&255;HEAP8[$agg$result+1>>0]=(67109634>>8)&255;HEAP8[$agg$result+2>>0]=(67109634>>16)&255;HEAP8[$agg$result+3>>0]=67109634>>24;
 STACKTOP = sp;return;
}
function __ZNSt3__110moneypunctIwLb1EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__110moneypunctIwLb1EED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb1EE16do_decimal_pointEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2147483647;
}
function __ZNKSt3__110moneypunctIwLb1EE16do_thousands_sepEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 2147483647;
}
function __ZNKSt3__110moneypunctIwLb1EE11do_groupingEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb1EE14do_curr_symbolEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb1EE16do_positive_signEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb1EE16do_negative_signEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEjw($agg$result,1,45);
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb1EE14do_frac_digitsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__110moneypunctIwLb1EE13do_pos_formatEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0]=67109634&255;HEAP8[$agg$result+1>>0]=(67109634>>8)&255;HEAP8[$agg$result+2>>0]=(67109634>>16)&255;HEAP8[$agg$result+3>>0]=67109634>>24;
 STACKTOP = sp;return;
}
function __ZNKSt3__110moneypunctIwLb1EE13do_neg_formatEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$agg$result>>0]=67109634&255;HEAP8[$agg$result+1>>0]=(67109634>>8)&255;HEAP8[$agg$result+2>>0]=(67109634>>16)&255;HEAP8[$agg$result+3>>0]=67109634>>24;
 STACKTOP = sp;return;
}
function __ZNSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe($agg$result,$this,$__b,$__e,$__intl,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__intl = $__intl|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$lcssa$i = 0, $$01 = 0, $$01$i = 0, $$115 = 0, $$116 = 0, $$1213 = 0, $$1214 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $__atoms = 0, $__loc = 0, $__nbuf = 0, $__nc$0 = 0, $__nc$1 = 0, $__nc$2$lcssa = 0, $__nc$27 = 0, $__neg = 0, $__w$08 = 0, $__wb = 0, $__wbuf = 0, $__wn = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $$byval_copy = sp;
 $__wbuf = sp + 24|0;
 $__wb = sp + 16|0;
 $__wn = sp + 8|0;
 $__loc = sp + 4|0;
 $__neg = sp + 236|0;
 $0 = sp + 12|0;
 $__atoms = sp + 124|0;
 $__nbuf = sp + 136|0;
 HEAP32[$__wb>>2] = $__wbuf;
 $1 = (($__wb) + 4|0);
 HEAP32[$1>>2] = 3855;
 $2 = (($__wbuf) + 100|0);
 __THREW__ = 0;
 invoke_vii(2475,($__loc|0),($__iob|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if ($4) {
   $32 = ___cxa_find_matching_catch()|0;
   $33 = tempRet0;
   HEAP32[$__wb>>2] = 0;
   $$115 = $32;$$1213 = $33;$105 = 3855;$106 = $__wbuf;
  } else {
   __THREW__ = 0;
   $5 = (invoke_iii(2228,($__loc|0),(3093336|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   L3: do {
    if ($7) {
     label = 11;
    } else {
     HEAP8[$__neg>>0] = 0;
     $8 = HEAP32[$__e>>2]|0;
     HEAP32[$0>>2] = $8;
     $9 = (($__iob) + 4|0);
     $10 = HEAP32[$9>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $11 = (invoke_iiiiiiiiiiii(3,($__b|0),($$byval_copy|0),($__intl|0),($__loc|0),($10|0),($__err|0),($__neg|0),($5|0),($__wb|0),($__wn|0),($2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      label = 11;
     } else {
      if ($11) {
       $14 = HEAP32[$5>>2]|0;
       $15 = (($14) + 32|0);
       $16 = HEAP32[$15>>2]|0;
       __THREW__ = 0;
       (invoke_iiiii($16|0,($5|0),(3092952|0),(((3092952 + 10|0))|0),($__atoms|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        label = 11;
        break;
       }
       $19 = HEAP32[$__wn>>2]|0;
       $20 = HEAP32[$__wb>>2]|0;
       $21 = $19;
       $22 = $20;
       $23 = (($21) - ($22))|0;
       $24 = ($23|0)>(98);
       if ($24) {
        $25 = (($23) + 2)|0;
        $26 = (_malloc($25)|0);
        $27 = ($26|0)==(0|0);
        if ($27) {
         __THREW__ = 0;
         invoke_v(1012);
         $28 = __THREW__; __THREW__ = 0;
         $29 = $28&1;
         if ($29) {
          $30 = ___cxa_find_matching_catch()|0;
          $31 = tempRet0;
          $$0 = $30;$$01 = $31;
          break;
         } else {
          $38 = 0;$__nc$0 = 0;
         }
        } else {
         $38 = $26;$__nc$0 = $26;
        }
       } else {
        $38 = 0;$__nc$0 = $__nbuf;
       }
       $39 = HEAP8[$__neg>>0]|0;
       $40 = ($39<<24>>24)==(0);
       if ($40) {
        $__nc$1 = $__nc$0;
       } else {
        $41 = (($__nc$0) + 1|0);
        HEAP8[$__nc$0>>0] = 45;
        $__nc$1 = $41;
       }
       $42 = ($20>>>0)<($19>>>0);
       if ($42) {
        $43 = (($__atoms) + 10|0);
        $44 = $__atoms;
        $__nc$27 = $__nc$1;$__w$08 = $20;
        while(1) {
         $45 = HEAP8[$__w$08>>0]|0;
         $$01$i = $__atoms;
         while(1) {
          $48 = HEAP8[$$01$i>>0]|0;
          $49 = ($48<<24>>24)==($45<<24>>24);
          $47 = (($$01$i) + 1|0);
          if ($49) {
           $$0$lcssa$i = $$01$i;
           break;
          }
          $46 = ($47|0)==($43|0);
          if ($46) {
           $$0$lcssa$i = $43;
           break;
          } else {
           $$01$i = $47;
          }
         }
         $50 = $$0$lcssa$i;
         $51 = (($50) - ($44))|0;
         $52 = (3092952 + ($51)|0);
         $53 = HEAP8[$52>>0]|0;
         HEAP8[$__nc$27>>0] = $53;
         $54 = (($__w$08) + 1|0);
         $55 = (($__nc$27) + 1|0);
         $56 = HEAP32[$__wn>>2]|0;
         $57 = ($54>>>0)<($56>>>0);
         if ($57) {
          $__nc$27 = $55;$__w$08 = $54;
         } else {
          $__nc$2$lcssa = $55;
          break;
         }
        }
       } else {
        $__nc$2$lcssa = $__nc$1;
       }
       HEAP8[$__nc$2$lcssa>>0] = 0;
       HEAP32[$$byval_copy>>2] = $__v;
       $58 = (_sscanf($__nbuf,3092968,$$byval_copy)|0);
       $59 = ($58|0)==(1);
       if (!($59)) {
        __THREW__ = 0;
        invoke_vi(3856,(3092976|0));
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         $36 = ___cxa_find_matching_catch()|0;
         $37 = tempRet0;
         _free($38);
         $$0 = $36;$$01 = $37;
         break;
        }
       }
       _free($38);
      }
      $62 = HEAP32[$__b>>2]|0;
      $63 = ($62|0)==(0|0);
      do {
       if ($63) {
        $77 = 0;
       } else {
        $64 = (($62) + 12|0);
        $65 = HEAP32[$64>>2]|0;
        $66 = (($62) + 16|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = ($65|0)==($67|0);
        if ($68) {
         $69 = HEAP32[$62>>2]|0;
         $70 = (($69) + 36|0);
         $71 = HEAP32[$70>>2]|0;
         __THREW__ = 0;
         $72 = (invoke_ii($71|0,($62|0))|0);
         $73 = __THREW__; __THREW__ = 0;
         $74 = $73&1;
         if ($74) {
          label = 11;
          break L3;
         }
         $75 = ($72|0)==(-1);
         if ($75) {
          HEAP32[$__b>>2] = 0;
          $77 = 0;
          break;
         } else {
          $$pre$i$i$i = HEAP32[$__b>>2]|0;
          $77 = $$pre$i$i$i;
          break;
         }
        } else {
         $77 = $62;
        }
       }
      } while(0);
      $76 = ($77|0)==(0|0);
      $78 = HEAP32[$__e>>2]|0;
      $79 = ($78|0)==(0|0);
      do {
       if ($79) {
        label = 36;
       } else {
        $80 = (($78) + 12|0);
        $81 = HEAP32[$80>>2]|0;
        $82 = (($78) + 16|0);
        $83 = HEAP32[$82>>2]|0;
        $84 = ($81|0)==($83|0);
        if (!($84)) {
         if ($76) {
          break;
         } else {
          label = 38;
          break;
         }
        }
        $85 = HEAP32[$78>>2]|0;
        $86 = (($85) + 36|0);
        $87 = HEAP32[$86>>2]|0;
        __THREW__ = 0;
        $88 = (invoke_ii($87|0,($78|0))|0);
        $89 = __THREW__; __THREW__ = 0;
        $90 = $89&1;
        if ($90) {
         label = 11;
         break L3;
        }
        $91 = ($88|0)==(-1);
        if ($91) {
         HEAP32[$__e>>2] = 0;
         label = 36;
         break;
        } else {
         if ($76) {
          break;
         } else {
          label = 38;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 36) {
       if ($76) {
        label = 38;
       }
      }
      if ((label|0) == 38) {
       $92 = HEAP32[$__err>>2]|0;
       $93 = $92 | 2;
       HEAP32[$__err>>2] = $93;
      }
      $94 = HEAP32[$__b>>2]|0;
      HEAP32[$agg$result>>2] = $94;
      $95 = HEAP32[$__loc>>2]|0;
      (__ZNSt3__114__shared_count16__release_sharedEv($95)|0);
      $96 = HEAP32[$__wb>>2]|0;
      HEAP32[$__wb>>2] = 0;
      $97 = ($96|0)==(0|0);
      if ($97) {
       STACKTOP = sp;return;
      }
      $98 = HEAP32[$1>>2]|0;
      __THREW__ = 0;
      invoke_vi($98|0,($96|0));
      $99 = __THREW__; __THREW__ = 0;
      $100 = $99&1;
      if ($100) {
       $101 = ___cxa_find_matching_catch(0|0)|0;
       $102 = tempRet0;
       ___clang_call_terminate($101);
       // unreachable;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   } while(0);
   if ((label|0) == 11) {
    $34 = ___cxa_find_matching_catch()|0;
    $35 = tempRet0;
    $$0 = $34;$$01 = $35;
   }
   $103 = HEAP32[$__loc>>2]|0;
   (__ZNSt3__114__shared_count16__release_sharedEv($103)|0);
   $$pre = HEAP32[$__wb>>2]|0;
   HEAP32[$__wb>>2] = 0;
   $104 = ($$pre|0)==(0|0);
   if ($104) {
    $$116 = $$0;$$1214 = $$01;
    ___resumeException($$116|0);
    // unreachable;
   } else {
    $$pre18 = HEAP32[$1>>2]|0;
    $$115 = $$0;$$1213 = $$01;$105 = $$pre18;$106 = $$pre;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi($105|0,($106|0));
 $107 = __THREW__; __THREW__ = 0;
 $108 = $107&1;
 if ($108) {
  $109 = ___cxa_find_matching_catch(0|0)|0;
  $110 = tempRet0;
  ___clang_call_terminate($109);
  // unreachable;
 } else {
  $$116 = $$115;$$1214 = $$1213;
  ___resumeException($$116|0);
  // unreachable;
 }
}
function __ZNSt3__112__do_nothingEPv($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_($__b,$__e,$__intl,$__loc,$__flags,$__err,$__neg,$__ct,$__wb,$__wn,$__we) {
 $__b = $__b|0;
 $__e = $__e|0;
 $__intl = $__intl|0;
 $__loc = $__loc|0;
 $__flags = $__flags|0;
 $__err = $__err|0;
 $__neg = $__neg|0;
 $__ct = $__ct|0;
 $__wb = $__wb|0;
 $__wn = $__wn|0;
 $__we = $__we|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i106 = 0, $$0$i$i115 = 0, $$0$i$i125 = 0, $$0$i$i142 = 0, $$0$i$i29 = 0, $$0$i$i32 = 0, $$0$i$i45 = 0, $$0$i$i50 = 0, $$0$i$i53 = 0, $$0$i$i60 = 0, $$0$i$i79 = 0, $$0$i$i82 = 0, $$0$i$i99 = 0, $$283 = 0, $$284 = 0, $$285 = 0, $$286 = 0;
 var $$287 = 0, $$288 = 0, $$289 = 0, $$290 = 0, $$291 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i129 = 0, $$pre$i$i$i146 = 0, $$pre$i$i$i19 = 0, $$pre$i$i$i35 = 0, $$pre$i$i$i65 = 0, $$pre$i$i$i89 = 0, $$pre$i2$i$i = 0, $$pre$i2$i$i133 = 0, $$pre$i2$i$i150 = 0, $$pre$i2$i$i150238 = 0, $$pre$i2$i$i150239 = 0, $$pre$i2$i$i244$ph = 0, $$pre$i2$i$i244281 = 0;
 var $$pre$i2$i$i39 = 0, $$pre$i2$i$i39235 = 0, $$pre$i2$i$i39237 = 0, $$pre$i2$i$i69 = 0, $$pre$i2$i$i69242$ph = 0, $$pre$i2$i$i69242278 = 0, $$pre$i2$i$i93 = 0, $$pre268 = 0, $$pre269 = 0, $$pre270 = 0, $$pre271 = 0, $$pre272 = 0, $$pre273 = 0, $$sum = 0, $$sum274 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0;
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0;
 var $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0;
 var $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__dp = 0, $__et = 0, $__fd = 0, $__gb = 0, $__gbuf = 0, $__ge = 0, $__gn = 0, $__grp = 0, $__i$0 = 0, $__ng$0 = 0, $__ng$1 = 0, $__nsn = 0, $__nsn$__trailing_sign$0 = 0, $__nsn$__trailing_sign$06 = 0;
 var $__p$0227 = 0, $__pat = 0, $__psn = 0, $__psn$__trailing_sign$0 = 0, $__psn$__trailing_sign$05 = 0, $__spaces = 0, $__sym = 0, $__trailing_sign$0$lcssa = 0, $__trailing_sign$0229 = 0, $__trailing_sign$1 = 0, $__ts = 0, $brmerge = 0, $cond = 0, $isascii1$i = 0, $isascii1$i123 = 0, $isascii1$i156 = 0, $isascii1$i48 = 0, $isascii1$i58 = 0, $lpad$phi$index = 0, $lpad$phi$index7 = 0;
 var $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond292 = 0, $or$cond7$not = 0, $or$cond8 = 0, $sext = 0, $sext194 = 0, $sext195 = 0, $sext196 = 0, $switch = 0, $tmp$i$i = 0, $tmp$i$i135 = 0, $tmp$i$i152 = 0, $tmp$i$i41 = 0, $tmp$i$i71 = 0, $tmp$i$i95 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 68|0;
 $__gbuf = sp + 96|0;
 $__gb = sp + 88|0;
 $__gn = sp + 80|0;
 $__ge = sp + 76|0;
 $__pat = sp + 72|0;
 $__dp = sp + 497|0;
 $__ts = sp + 496|0;
 $__grp = sp + 52|0;
 $__sym = sp + 40|0;
 $__psn = sp + 28|0;
 $__nsn = sp + 16|0;
 $__spaces = sp + 4|0;
 $__fd = sp;
 $__et = sp + 64|0;
 HEAP32[$0>>2] = $__we;
 HEAP32[$__gb>>2] = $__gbuf;
 $1 = (($__gb) + 4|0);
 HEAP32[$1>>2] = 3855;
 HEAP32[$__gn>>2] = $__gbuf;
 $2 = (($__gbuf) + 400|0);
 HEAP32[$__ge>>2] = $2;
 HEAP32[$__pat>>2] = 0;
 ;HEAP32[$__grp+0>>2]=0|0;HEAP32[$__grp+4>>2]=0|0;HEAP32[$__grp+8>>2]=0|0;
 ;HEAP32[$__sym+0>>2]=0|0;HEAP32[$__sym+4>>2]=0|0;HEAP32[$__sym+8>>2]=0|0;
 ;HEAP32[$__psn+0>>2]=0|0;HEAP32[$__psn+4>>2]=0|0;HEAP32[$__psn+8>>2]=0|0;
 ;HEAP32[$__nsn+0>>2]=0|0;HEAP32[$__nsn+4>>2]=0|0;HEAP32[$__nsn+8>>2]=0|0;
 ;HEAP32[$__spaces+0>>2]=0|0;HEAP32[$__spaces+4>>2]=0|0;HEAP32[$__spaces+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiiiiiiii(10,($__intl|0),($__loc|0),($__pat|0),($__dp|0),($__ts|0),($__grp|0),($__sym|0),($__psn|0),($__nsn|0),($__fd|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $69 = ___cxa_find_matching_catch()|0;
   $70 = tempRet0;
   $lpad$phi$index = $69;$lpad$phi$index7 = $70;
  } else {
   $5 = HEAP32[$__wb>>2]|0;
   HEAP32[$__wn>>2] = $5;
   $6 = (($__ct) + 8|0);
   $7 = (($__nsn) + 1|0);
   $8 = (($__nsn) + 4|0);
   $9 = (($__nsn) + 8|0);
   $10 = (($__psn) + 1|0);
   $11 = (($__psn) + 4|0);
   $12 = (($__psn) + 8|0);
   $13 = $__flags & 512;
   $14 = ($13|0)!=(0);
   $15 = (($__sym) + 1|0);
   $16 = (($__sym) + 8|0);
   $17 = (($__sym) + 4|0);
   $18 = (($__spaces) + 1|0);
   $19 = (($__spaces) + 8|0);
   $20 = (($__spaces) + 4|0);
   $21 = (($__pat) + 3|0);
   $22 = (($__grp) + 4|0);
   $874 = $__gbuf;$__p$0227 = 0;$__trailing_sign$0229 = 0;
   L4: while(1) {
    $23 = HEAP32[$__b>>2]|0;
    $24 = ($23|0)==(0|0);
    do {
     if ($24) {
      $38 = 0;
     } else {
      $25 = (($23) + 12|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = (($23) + 16|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = ($26|0)==($28|0);
      if ($29) {
       $30 = HEAP32[$23>>2]|0;
       $31 = (($30) + 36|0);
       $32 = HEAP32[$31>>2]|0;
       __THREW__ = 0;
       $33 = (invoke_ii($32|0,($23|0))|0);
       $34 = __THREW__; __THREW__ = 0;
       $35 = $34&1;
       if ($35) {
        label = 24;
        break L4;
       }
       $36 = ($33|0)==(-1);
       if ($36) {
        HEAP32[$__b>>2] = 0;
        $38 = 0;
        break;
       } else {
        $$pre$i$i$i19 = HEAP32[$__b>>2]|0;
        $38 = $$pre$i$i$i19;
        break;
       }
      } else {
       $38 = $23;
      }
     }
    } while(0);
    $37 = ($38|0)==(0|0);
    $39 = HEAP32[$__e>>2]|0;
    $40 = ($39|0)==(0|0);
    do {
     if ($40) {
      label = 15;
     } else {
      $41 = (($39) + 12|0);
      $42 = HEAP32[$41>>2]|0;
      $43 = (($39) + 16|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($42|0)==($44|0);
      if (!($45)) {
       if ($37) {
        $875 = $39;
        break;
       } else {
        $862 = $874;$876 = $39;$__trailing_sign$0$lcssa = $__trailing_sign$0229;
        label = 280;
        break L4;
       }
      }
      $46 = HEAP32[$39>>2]|0;
      $47 = (($46) + 36|0);
      $48 = HEAP32[$47>>2]|0;
      __THREW__ = 0;
      $49 = (invoke_ii($48|0,($39|0))|0);
      $50 = __THREW__; __THREW__ = 0;
      $51 = $50&1;
      if ($51) {
       label = 24;
       break L4;
      }
      $52 = ($49|0)==(-1);
      if ($52) {
       HEAP32[$__e>>2] = 0;
       label = 15;
       break;
      } else {
       if ($37) {
        $875 = $39;
        break;
       } else {
        $862 = $874;$876 = $39;$__trailing_sign$0$lcssa = $__trailing_sign$0229;
        label = 280;
        break L4;
       }
      }
     }
    } while(0);
    if ((label|0) == 15) {
     label = 0;
     if ($37) {
      $862 = $874;$876 = 0;$__trailing_sign$0$lcssa = $__trailing_sign$0229;
      label = 280;
      break;
     } else {
      $875 = 0;
     }
    }
    $53 = (($__pat) + ($__p$0227)|0);
    $54 = HEAP8[$53>>0]|0;
    $55 = $54 << 24 >> 24;
    L26: do {
     switch ($55|0) {
     case 0:  {
      label = 41;
      break;
     }
     case 1:  {
      $cond = ($__p$0227|0)==(3);
      if ($cond) {
       $862 = $874;$876 = $875;$__trailing_sign$0$lcssa = $__trailing_sign$0229;
       label = 280;
       break L4;
      }
      $78 = HEAP32[$__b>>2]|0;
      $79 = (($78) + 12|0);
      $80 = HEAP32[$79>>2]|0;
      $81 = (($78) + 16|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = ($80|0)==($82|0);
      if ($83) {
       $84 = HEAP32[$78>>2]|0;
       $85 = (($84) + 36|0);
       $86 = HEAP32[$85>>2]|0;
       __THREW__ = 0;
       $87 = (invoke_ii($86|0,($78|0))|0);
       $88 = __THREW__; __THREW__ = 0;
       $89 = $88&1;
       if ($89) {
        label = 24;
        break L4;
       } else {
        $$0$i$i29 = $87;
       }
      } else {
       $90 = HEAP8[$80>>0]|0;
       $91 = $90&255;
       $$0$i$i29 = $91;
      }
      $92 = $$0$i$i29&255;
      $isascii1$i = ($92<<24>>24)>(-1);
      if (!($isascii1$i)) {
       label = 40;
       break L4;
      }
      $sext196 = $$0$i$i29 << 24;
      $93 = $sext196 >> 24;
      $94 = HEAP32[$6>>2]|0;
      $95 = (($94) + ($93<<1)|0);
      $96 = HEAP16[$95>>1]|0;
      $97 = $96 & 8192;
      $98 = ($97<<16>>16)==(0);
      if ($98) {
       label = 40;
       break L4;
      }
      $99 = HEAP32[$__b>>2]|0;
      $100 = (($99) + 12|0);
      $101 = HEAP32[$100>>2]|0;
      $102 = (($99) + 16|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = ($101|0)==($103|0);
      if ($104) {
       $105 = HEAP32[$99>>2]|0;
       $106 = (($105) + 40|0);
       $107 = HEAP32[$106>>2]|0;
       __THREW__ = 0;
       $108 = (invoke_ii($107|0,($99|0))|0);
       $109 = __THREW__; __THREW__ = 0;
       $110 = $109&1;
       if ($110) {
        label = 24;
        break L4;
       } else {
        $$0$i$i32 = $108;
       }
      } else {
       $111 = (($101) + 1|0);
       HEAP32[$100>>2] = $111;
       $112 = HEAP8[$101>>0]|0;
       $113 = $112&255;
       $$0$i$i32 = $113;
      }
      $114 = $$0$i$i32&255;
      __THREW__ = 0;
      invoke_vii(3508,($__spaces|0),($114|0));
      $115 = __THREW__; __THREW__ = 0;
      $116 = $115&1;
      if ($116) {
       label = 24;
       break L4;
      } else {
       label = 41;
      }
      break;
     }
     case 4:  {
      $56 = HEAP8[$__ts>>0]|0;
      $$pre$i2$i$i133 = $875;$539 = $875;$592 = $874;$__ng$0 = 0;
      L40: while(1) {
       $522 = HEAP32[$__b>>2]|0;
       $523 = ($522|0)==(0|0);
       do {
        if ($523) {
         $537 = 0;
        } else {
         $524 = (($522) + 12|0);
         $525 = HEAP32[$524>>2]|0;
         $526 = (($522) + 16|0);
         $527 = HEAP32[$526>>2]|0;
         $528 = ($525|0)==($527|0);
         if ($528) {
          $529 = HEAP32[$522>>2]|0;
          $530 = (($529) + 36|0);
          $531 = HEAP32[$530>>2]|0;
          __THREW__ = 0;
          $532 = (invoke_ii($531|0,($522|0))|0);
          $533 = __THREW__; __THREW__ = 0;
          $534 = $533&1;
          if ($534) {
           label = 20;
           break L4;
          }
          $535 = ($532|0)==(-1);
          if ($535) {
           HEAP32[$__b>>2] = 0;
           $537 = 0;
           break;
          } else {
           $$pre$i$i$i129 = HEAP32[$__b>>2]|0;
           $537 = $$pre$i$i$i129;
           break;
          }
         } else {
          $537 = $522;
         }
        }
       } while(0);
       $536 = ($537|0)==(0|0);
       $538 = ($539|0)==(0|0);
       do {
        if ($538) {
         $882 = $$pre$i2$i$i133;
         label = 198;
        } else {
         $540 = (($539) + 12|0);
         $541 = HEAP32[$540>>2]|0;
         $542 = (($539) + 16|0);
         $543 = HEAP32[$542>>2]|0;
         $544 = ($541|0)==($543|0);
         if (!($544)) {
          if ($536) {
           $883 = $$pre$i2$i$i133;$884 = $539;
           break;
          } else {
           $$pre$i2$i$i93 = $$pre$i2$i$i133;
           break L40;
          }
         }
         $545 = HEAP32[$539>>2]|0;
         $546 = (($545) + 36|0);
         $547 = HEAP32[$546>>2]|0;
         __THREW__ = 0;
         $548 = (invoke_ii($547|0,($539|0))|0);
         $549 = __THREW__; __THREW__ = 0;
         $550 = $549&1;
         if ($550) {
          label = 20;
          break L4;
         }
         $551 = ($548|0)==(-1);
         if ($551) {
          HEAP32[$__e>>2] = 0;
          $882 = 0;
          label = 198;
          break;
         } else {
          $552 = ($$pre$i2$i$i133|0)==(0|0);
          $tmp$i$i135 = $536 ^ $552;
          if ($tmp$i$i135) {
           $883 = $$pre$i2$i$i133;$884 = $$pre$i2$i$i133;
           break;
          } else {
           $$pre$i2$i$i93 = $$pre$i2$i$i133;
           break L40;
          }
         }
        }
       } while(0);
       if ((label|0) == 198) {
        label = 0;
        if ($536) {
         $$pre$i2$i$i93 = $882;
         break;
        } else {
         $883 = $882;$884 = 0;
        }
       }
       $553 = HEAP32[$__b>>2]|0;
       $554 = (($553) + 12|0);
       $555 = HEAP32[$554>>2]|0;
       $556 = (($553) + 16|0);
       $557 = HEAP32[$556>>2]|0;
       $558 = ($555|0)==($557|0);
       if ($558) {
        $559 = HEAP32[$553>>2]|0;
        $560 = (($559) + 36|0);
        $561 = HEAP32[$560>>2]|0;
        __THREW__ = 0;
        $562 = (invoke_ii($561|0,($553|0))|0);
        $563 = __THREW__; __THREW__ = 0;
        $564 = $563&1;
        if ($564) {
         label = 20;
         break L4;
        } else {
         $$0$i$i125 = $562;
        }
       } else {
        $565 = HEAP8[$555>>0]|0;
        $566 = $565&255;
        $$0$i$i125 = $566;
       }
       $567 = $$0$i$i125&255;
       $isascii1$i123 = ($567<<24>>24)>(-1);
       if ($isascii1$i123) {
        $sext194 = $$0$i$i125 << 24;
        $568 = $sext194 >> 24;
        $569 = HEAP32[$6>>2]|0;
        $570 = (($569) + ($568<<1)|0);
        $571 = HEAP16[$570>>1]|0;
        $572 = $571 & 2048;
        $573 = ($572<<16>>16)==(0);
        if ($573) {
         label = 209;
        } else {
         $574 = HEAP32[$__wn>>2]|0;
         $575 = HEAP32[$0>>2]|0;
         $576 = ($574|0)==($575|0);
         if ($576) {
          __THREW__ = 0;
          invoke_viii(2129,($__wb|0),($__wn|0),($0|0));
          $577 = __THREW__; __THREW__ = 0;
          $578 = $577&1;
          if ($578) {
           label = 20;
           break L4;
          }
          $$pre272 = HEAP32[$__wn>>2]|0;
          $580 = $$pre272;
         } else {
          $580 = $574;
         }
         $579 = (($580) + 1|0);
         HEAP32[$__wn>>2] = $579;
         HEAP8[$580>>0] = $567;
         $581 = (($__ng$0) + 1)|0;
         $885 = $592;$__ng$1 = $581;
        }
       } else {
        label = 209;
       }
       if ((label|0) == 209) {
        label = 0;
        $582 = HEAP8[$__grp>>0]|0;
        $583 = $582 & 1;
        $584 = ($583<<24>>24)==(0);
        if ($584) {
         $586 = $582&255;
         $587 = $586 >>> 1;
         $588 = $587;
        } else {
         $585 = HEAP32[$22>>2]|0;
         $588 = $585;
        }
        $notlhs = ($588|0)!=(0);
        $notrhs = ($__ng$0|0)!=(0);
        $or$cond7$not = $notrhs & $notlhs;
        $589 = ($567<<24>>24)==($56<<24>>24);
        $or$cond292 = $or$cond7$not & $589;
        if (!($or$cond292)) {
         $$pre$i2$i$i93 = $883;
         break;
        }
        $590 = HEAP32[$__ge>>2]|0;
        $591 = ($592|0)==($590|0);
        if ($591) {
         __THREW__ = 0;
         invoke_viii(2130,($__gb|0),($__gn|0),($__ge|0));
         $593 = __THREW__; __THREW__ = 0;
         $594 = $593&1;
         if ($594) {
          label = 20;
          break L4;
         }
         $$pre273 = HEAP32[$__gn>>2]|0;
         $596 = $$pre273;
        } else {
         $596 = $592;
        }
        $595 = (($596) + 4|0);
        HEAP32[$__gn>>2] = $595;
        HEAP32[$596>>2] = $__ng$0;
        $885 = $595;$__ng$1 = 0;
       }
       $597 = HEAP32[$__b>>2]|0;
       $598 = (($597) + 12|0);
       $599 = HEAP32[$598>>2]|0;
       $600 = (($597) + 16|0);
       $601 = HEAP32[$600>>2]|0;
       $602 = ($599|0)==($601|0);
       if ($602) {
        $603 = HEAP32[$597>>2]|0;
        $604 = (($603) + 40|0);
        $605 = HEAP32[$604>>2]|0;
        __THREW__ = 0;
        (invoke_ii($605|0,($597|0))|0);
        $606 = __THREW__; __THREW__ = 0;
        $607 = $606&1;
        if ($607) {
         label = 20;
         break L4;
        } else {
         $$pre$i2$i$i133 = $883;$539 = $884;$592 = $885;$__ng$0 = $__ng$1;
         continue;
        }
       } else {
        $608 = (($599) + 1|0);
        HEAP32[$598>>2] = $608;
        $$pre$i2$i$i133 = $883;$539 = $884;$592 = $885;$__ng$0 = $__ng$1;
        continue;
       }
      }
      $609 = HEAP32[$__gb>>2]|0;
      $610 = ($609|0)==($592|0);
      $611 = ($__ng$0|0)==(0);
      $or$cond8 = $610 | $611;
      if ($or$cond8) {
       $886 = $592;
      } else {
       $612 = HEAP32[$__ge>>2]|0;
       $613 = ($592|0)==($612|0);
       if ($613) {
        __THREW__ = 0;
        invoke_viii(2130,($__gb|0),($__gn|0),($__ge|0));
        $614 = __THREW__; __THREW__ = 0;
        $615 = $614&1;
        if ($615) {
         label = 24;
         break L4;
        }
        $$pre271 = HEAP32[$__gn>>2]|0;
        $617 = $$pre271;
       } else {
        $617 = $592;
       }
       $616 = (($617) + 4|0);
       HEAP32[$__gn>>2] = $616;
       HEAP32[$617>>2] = $__ng$0;
       $886 = $616;
      }
      $618 = HEAP32[$__fd>>2]|0;
      $619 = ($618|0)>(0);
      if ($619) {
       $620 = HEAP32[$__b>>2]|0;
       $621 = ($620|0)==(0|0);
       do {
        if ($621) {
         $635 = 0;
        } else {
         $622 = (($620) + 12|0);
         $623 = HEAP32[$622>>2]|0;
         $624 = (($620) + 16|0);
         $625 = HEAP32[$624>>2]|0;
         $626 = ($623|0)==($625|0);
         if ($626) {
          $627 = HEAP32[$620>>2]|0;
          $628 = (($627) + 36|0);
          $629 = HEAP32[$628>>2]|0;
          __THREW__ = 0;
          $630 = (invoke_ii($629|0,($620|0))|0);
          $631 = __THREW__; __THREW__ = 0;
          $632 = $631&1;
          if ($632) {
           label = 24;
           break L4;
          }
          $633 = ($630|0)==(-1);
          if ($633) {
           HEAP32[$__b>>2] = 0;
           $635 = 0;
           break;
          } else {
           $$pre$i$i$i89 = HEAP32[$__b>>2]|0;
           $635 = $$pre$i$i$i89;
           break;
          }
         } else {
          $635 = $620;
         }
        }
       } while(0);
       $634 = ($635|0)==(0|0);
       $636 = ($$pre$i2$i$i93|0)==(0|0);
       do {
        if ($636) {
         label = 238;
        } else {
         $637 = (($$pre$i2$i$i93) + 12|0);
         $638 = HEAP32[$637>>2]|0;
         $639 = (($$pre$i2$i$i93) + 16|0);
         $640 = HEAP32[$639>>2]|0;
         $641 = ($638|0)==($640|0);
         if (!($641)) {
          if ($634) {
           $888 = $$pre$i2$i$i93;
           break;
          } else {
           label = 244;
           break L4;
          }
         }
         $642 = HEAP32[$$pre$i2$i$i93>>2]|0;
         $643 = (($642) + 36|0);
         $644 = HEAP32[$643>>2]|0;
         __THREW__ = 0;
         $645 = (invoke_ii($644|0,($$pre$i2$i$i93|0))|0);
         $646 = __THREW__; __THREW__ = 0;
         $647 = $646&1;
         if ($647) {
          label = 24;
          break L4;
         }
         $648 = ($645|0)==(-1);
         if ($648) {
          HEAP32[$__e>>2] = 0;
          label = 238;
          break;
         } else {
          $649 = ($$pre$i2$i$i93|0)==(0|0);
          $tmp$i$i95 = $634 ^ $649;
          if ($tmp$i$i95) {
           $888 = $$pre$i2$i$i93;
           break;
          } else {
           label = 244;
           break L4;
          }
         }
        }
       } while(0);
       if ((label|0) == 238) {
        label = 0;
        if ($634) {
         label = 244;
         break L4;
        } else {
         $888 = 0;
        }
       }
       $650 = HEAP32[$__b>>2]|0;
       $651 = (($650) + 12|0);
       $652 = HEAP32[$651>>2]|0;
       $653 = (($650) + 16|0);
       $654 = HEAP32[$653>>2]|0;
       $655 = ($652|0)==($654|0);
       if ($655) {
        $656 = HEAP32[$650>>2]|0;
        $657 = (($656) + 36|0);
        $658 = HEAP32[$657>>2]|0;
        __THREW__ = 0;
        $659 = (invoke_ii($658|0,($650|0))|0);
        $660 = __THREW__; __THREW__ = 0;
        $661 = $660&1;
        if ($661) {
         label = 24;
         break L4;
        } else {
         $$0$i$i82 = $659;
        }
       } else {
        $662 = HEAP8[$652>>0]|0;
        $663 = $662&255;
        $$0$i$i82 = $663;
       }
       $664 = $$0$i$i82&255;
       $665 = HEAP8[$__dp>>0]|0;
       $666 = ($664<<24>>24)==($665<<24>>24);
       if (!($666)) {
        label = 244;
        break L4;
       }
       $669 = HEAP32[$__b>>2]|0;
       $670 = (($669) + 12|0);
       $671 = HEAP32[$670>>2]|0;
       $672 = (($669) + 16|0);
       $673 = HEAP32[$672>>2]|0;
       $674 = ($671|0)==($673|0);
       if ($674) {
        $675 = HEAP32[$669>>2]|0;
        $676 = (($675) + 40|0);
        $677 = HEAP32[$676>>2]|0;
        __THREW__ = 0;
        (invoke_ii($677|0,($669|0))|0);
        $678 = __THREW__; __THREW__ = 0;
        $679 = $678&1;
        if ($679) {
         label = 24;
         break L4;
        } else {
         $$pre$i2$i$i69 = $888;$698 = $888;$758 = $618;
        }
       } else {
        $680 = (($671) + 1|0);
        HEAP32[$670>>2] = $680;
        $$pre$i2$i$i69 = $888;$698 = $888;$758 = $618;
       }
       while(1) {
        $681 = HEAP32[$__b>>2]|0;
        $682 = ($681|0)==(0|0);
        do {
         if ($682) {
          $696 = 0;
         } else {
          $683 = (($681) + 12|0);
          $684 = HEAP32[$683>>2]|0;
          $685 = (($681) + 16|0);
          $686 = HEAP32[$685>>2]|0;
          $687 = ($684|0)==($686|0);
          if ($687) {
           $688 = HEAP32[$681>>2]|0;
           $689 = (($688) + 36|0);
           $690 = HEAP32[$689>>2]|0;
           __THREW__ = 0;
           $691 = (invoke_ii($690|0,($681|0))|0);
           $692 = __THREW__; __THREW__ = 0;
           $693 = $692&1;
           if ($693) {
            label = 21;
            break L4;
           }
           $694 = ($691|0)==(-1);
           if ($694) {
            HEAP32[$__b>>2] = 0;
            $696 = 0;
            break;
           } else {
            $$pre$i$i$i65 = HEAP32[$__b>>2]|0;
            $696 = $$pre$i$i$i65;
            break;
           }
          } else {
           $696 = $681;
          }
         }
        } while(0);
        $695 = ($696|0)==(0|0);
        $697 = ($698|0)==(0|0);
        do {
         if ($697) {
          $$pre$i2$i$i69242$ph = $$pre$i2$i$i69;
          label = 260;
         } else {
          $699 = (($698) + 12|0);
          $700 = HEAP32[$699>>2]|0;
          $701 = (($698) + 16|0);
          $702 = HEAP32[$701>>2]|0;
          $703 = ($700|0)==($702|0);
          if (!($703)) {
           if ($695) {
            $$pre$i2$i$i69242278 = $$pre$i2$i$i69;$889 = $698;
            break;
           } else {
            label = 267;
            break L4;
           }
          }
          $704 = HEAP32[$698>>2]|0;
          $705 = (($704) + 36|0);
          $706 = HEAP32[$705>>2]|0;
          __THREW__ = 0;
          $707 = (invoke_ii($706|0,($698|0))|0);
          $708 = __THREW__; __THREW__ = 0;
          $709 = $708&1;
          if ($709) {
           label = 21;
           break L4;
          }
          $710 = ($707|0)==(-1);
          if ($710) {
           HEAP32[$__e>>2] = 0;
           $$pre$i2$i$i69242$ph = 0;
           label = 260;
           break;
          } else {
           $711 = ($$pre$i2$i$i69|0)==(0|0);
           $tmp$i$i71 = $695 ^ $711;
           if ($tmp$i$i71) {
            $$pre$i2$i$i69242278 = $$pre$i2$i$i69;$889 = $$pre$i2$i$i69;
            break;
           } else {
            label = 267;
            break L4;
           }
          }
         }
        } while(0);
        if ((label|0) == 260) {
         label = 0;
         if ($695) {
          label = 267;
          break L4;
         } else {
          $$pre$i2$i$i69242278 = $$pre$i2$i$i69242$ph;$889 = 0;
         }
        }
        $712 = HEAP32[$__b>>2]|0;
        $713 = (($712) + 12|0);
        $714 = HEAP32[$713>>2]|0;
        $715 = (($712) + 16|0);
        $716 = HEAP32[$715>>2]|0;
        $717 = ($714|0)==($716|0);
        if ($717) {
         $718 = HEAP32[$712>>2]|0;
         $719 = (($718) + 36|0);
         $720 = HEAP32[$719>>2]|0;
         __THREW__ = 0;
         $721 = (invoke_ii($720|0,($712|0))|0);
         $722 = __THREW__; __THREW__ = 0;
         $723 = $722&1;
         if ($723) {
          label = 21;
          break L4;
         } else {
          $$0$i$i60 = $721;
         }
        } else {
         $724 = HEAP8[$714>>0]|0;
         $725 = $724&255;
         $$0$i$i60 = $725;
        }
        $726 = $$0$i$i60&255;
        $isascii1$i58 = ($726<<24>>24)>(-1);
        if (!($isascii1$i58)) {
         label = 267;
         break L4;
        }
        $sext = $$0$i$i60 << 24;
        $727 = $sext >> 24;
        $728 = HEAP32[$6>>2]|0;
        $729 = (($728) + ($727<<1)|0);
        $730 = HEAP16[$729>>1]|0;
        $731 = $730 & 2048;
        $732 = ($731<<16>>16)==(0);
        if ($732) {
         label = 267;
         break L4;
        }
        $735 = HEAP32[$__wn>>2]|0;
        $736 = HEAP32[$0>>2]|0;
        $737 = ($735|0)==($736|0);
        if ($737) {
         __THREW__ = 0;
         invoke_viii(2129,($__wb|0),($__wn|0),($0|0));
         $738 = __THREW__; __THREW__ = 0;
         $739 = $738&1;
         if ($739) {
          label = 21;
          break L4;
         }
        }
        $740 = HEAP32[$__b>>2]|0;
        $741 = (($740) + 12|0);
        $742 = HEAP32[$741>>2]|0;
        $743 = (($740) + 16|0);
        $744 = HEAP32[$743>>2]|0;
        $745 = ($742|0)==($744|0);
        if ($745) {
         $746 = HEAP32[$740>>2]|0;
         $747 = (($746) + 36|0);
         $748 = HEAP32[$747>>2]|0;
         __THREW__ = 0;
         $749 = (invoke_ii($748|0,($740|0))|0);
         $750 = __THREW__; __THREW__ = 0;
         $751 = $750&1;
         if ($751) {
          label = 21;
          break L4;
         } else {
          $$0$i$i53 = $749;
         }
        } else {
         $752 = HEAP8[$742>>0]|0;
         $753 = $752&255;
         $$0$i$i53 = $753;
        }
        $754 = $$0$i$i53&255;
        $755 = HEAP32[$__wn>>2]|0;
        $756 = (($755) + 1|0);
        HEAP32[$__wn>>2] = $756;
        HEAP8[$755>>0] = $754;
        $757 = (($758) + -1)|0;
        HEAP32[$__fd>>2] = $757;
        $759 = HEAP32[$__b>>2]|0;
        $760 = (($759) + 12|0);
        $761 = HEAP32[$760>>2]|0;
        $762 = (($759) + 16|0);
        $763 = HEAP32[$762>>2]|0;
        $764 = ($761|0)==($763|0);
        if ($764) {
         $765 = HEAP32[$759>>2]|0;
         $766 = (($765) + 40|0);
         $767 = HEAP32[$766>>2]|0;
         __THREW__ = 0;
         (invoke_ii($767|0,($759|0))|0);
         $768 = __THREW__; __THREW__ = 0;
         $769 = $768&1;
         if ($769) {
          label = 21;
          break L4;
         }
        } else {
         $771 = (($761) + 1|0);
         HEAP32[$760>>2] = $771;
        }
        $770 = ($757|0)>(0);
        if ($770) {
         $$pre$i2$i$i69 = $$pre$i2$i$i69242278;$698 = $889;$758 = $757;
        } else {
         $887 = $$pre$i2$i$i69242278;
         break;
        }
       }
      } else {
       $887 = $$pre$i2$i$i93;
      }
      $772 = HEAP32[$__wn>>2]|0;
      $773 = HEAP32[$__wb>>2]|0;
      $774 = ($772|0)==($773|0);
      if ($774) {
       label = 278;
       break L4;
      } else {
       $877 = $887;$878 = $886;$__trailing_sign$1 = $__trailing_sign$0229;
      }
      break;
     }
     case 3:  {
      $190 = HEAP8[$__psn>>0]|0;
      $191 = $190 & 1;
      $192 = ($191<<24>>24)==(0);
      if ($192) {
       $194 = $190&255;
       $195 = $194 >>> 1;
       $205 = $195;
      } else {
       $193 = HEAP32[$11>>2]|0;
       $205 = $193;
      }
      $196 = HEAP8[$__nsn>>0]|0;
      $197 = $196 & 1;
      $198 = ($197<<24>>24)==(0);
      if ($198) {
       $200 = $196&255;
       $201 = $200 >>> 1;
       $203 = $201;
      } else {
       $199 = HEAP32[$8>>2]|0;
       $203 = $199;
      }
      $202 = (0 - ($203))|0;
      $204 = ($205|0)==($202|0);
      if ($204) {
       $877 = $875;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
      } else {
       if ($192) {
        $207 = $190&255;
        $208 = $207 >>> 1;
        $210 = $208;
       } else {
        $206 = HEAP32[$11>>2]|0;
        $210 = $206;
       }
       $209 = ($210|0)==(0);
       if (!($209)) {
        if ($198) {
         $212 = $196&255;
         $213 = $212 >>> 1;
         $215 = $213;
        } else {
         $211 = HEAP32[$8>>2]|0;
         $215 = $211;
        }
        $214 = ($215|0)==(0);
        if (!($214)) {
         $297 = HEAP32[$__b>>2]|0;
         $298 = (($297) + 12|0);
         $299 = HEAP32[$298>>2]|0;
         $300 = (($297) + 16|0);
         $301 = HEAP32[$300>>2]|0;
         $302 = ($299|0)==($301|0);
         if ($302) {
          $303 = HEAP32[$297>>2]|0;
          $304 = (($303) + 36|0);
          $305 = HEAP32[$304>>2]|0;
          __THREW__ = 0;
          $306 = (invoke_ii($305|0,($297|0))|0);
          $307 = __THREW__; __THREW__ = 0;
          $308 = $307&1;
          if ($308) {
           label = 24;
           break L4;
          }
          $$pre270 = HEAP8[$__psn>>0]|0;
          $$0$i$i106 = $306;$313 = $$pre270;
         } else {
          $309 = HEAP8[$299>>0]|0;
          $310 = $309&255;
          $$0$i$i106 = $310;$313 = $190;
         }
         $311 = $$0$i$i106&255;
         $312 = $313 & 1;
         $314 = ($312<<24>>24)==(0);
         $315 = HEAP32[$12>>2]|0;
         $$284 = $314 ? $10 : $315;
         $316 = HEAP8[$$284>>0]|0;
         $317 = ($311<<24>>24)==($316<<24>>24);
         $318 = HEAP32[$__b>>2]|0;
         $319 = (($318) + 12|0);
         $320 = HEAP32[$319>>2]|0;
         $321 = (($318) + 16|0);
         $322 = HEAP32[$321>>2]|0;
         $323 = ($320|0)==($322|0);
         if ($317) {
          if ($323) {
           $324 = HEAP32[$318>>2]|0;
           $325 = (($324) + 40|0);
           $326 = HEAP32[$325>>2]|0;
           __THREW__ = 0;
           (invoke_ii($326|0,($318|0))|0);
           $327 = __THREW__; __THREW__ = 0;
           $328 = $327&1;
           if ($328) {
            label = 24;
            break L4;
           }
          } else {
           $329 = (($320) + 1|0);
           HEAP32[$319>>2] = $329;
          }
          $330 = HEAP8[$__psn>>0]|0;
          $331 = $330 & 1;
          $332 = ($331<<24>>24)==(0);
          if ($332) {
           $334 = $330&255;
           $335 = $334 >>> 1;
           $337 = $335;
          } else {
           $333 = HEAP32[$11>>2]|0;
           $337 = $333;
          }
          $336 = ($337>>>0)>(1);
          $__psn$__trailing_sign$05 = $336 ? $__psn : $__trailing_sign$0229;
          $877 = $875;$878 = $874;$__trailing_sign$1 = $__psn$__trailing_sign$05;
          break L26;
         }
         if ($323) {
          $338 = HEAP32[$318>>2]|0;
          $339 = (($338) + 36|0);
          $340 = HEAP32[$339>>2]|0;
          __THREW__ = 0;
          $341 = (invoke_ii($340|0,($318|0))|0);
          $342 = __THREW__; __THREW__ = 0;
          $343 = $342&1;
          if ($343) {
           label = 24;
           break L4;
          } else {
           $$0$i$i115 = $341;
          }
         } else {
          $344 = HEAP8[$320>>0]|0;
          $345 = $344&255;
          $$0$i$i115 = $345;
         }
         $346 = $$0$i$i115&255;
         $347 = HEAP8[$__nsn>>0]|0;
         $348 = $347 & 1;
         $349 = ($348<<24>>24)==(0);
         $350 = HEAP32[$9>>2]|0;
         $$285 = $349 ? $7 : $350;
         $351 = HEAP8[$$285>>0]|0;
         $352 = ($346<<24>>24)==($351<<24>>24);
         if (!($352)) {
          label = 132;
          break L4;
         }
         $353 = HEAP32[$__b>>2]|0;
         $354 = (($353) + 12|0);
         $355 = HEAP32[$354>>2]|0;
         $356 = (($353) + 16|0);
         $357 = HEAP32[$356>>2]|0;
         $358 = ($355|0)==($357|0);
         if ($358) {
          $359 = HEAP32[$353>>2]|0;
          $360 = (($359) + 40|0);
          $361 = HEAP32[$360>>2]|0;
          __THREW__ = 0;
          (invoke_ii($361|0,($353|0))|0);
          $362 = __THREW__; __THREW__ = 0;
          $363 = $362&1;
          if ($363) {
           label = 24;
           break L4;
          }
         } else {
          $364 = (($355) + 1|0);
          HEAP32[$354>>2] = $364;
         }
         HEAP8[$__neg>>0] = 1;
         $365 = HEAP8[$__nsn>>0]|0;
         $366 = $365 & 1;
         $367 = ($366<<24>>24)==(0);
         if ($367) {
          $369 = $365&255;
          $370 = $369 >>> 1;
          $372 = $370;
         } else {
          $368 = HEAP32[$8>>2]|0;
          $372 = $368;
         }
         $371 = ($372>>>0)>(1);
         $__nsn$__trailing_sign$06 = $371 ? $__nsn : $__trailing_sign$0229;
         $877 = $875;$878 = $874;$__trailing_sign$1 = $__nsn$__trailing_sign$06;
         break L26;
        }
       }
       if ($192) {
        $217 = $190&255;
        $218 = $217 >>> 1;
        $220 = $218;
       } else {
        $216 = HEAP32[$11>>2]|0;
        $220 = $216;
       }
       $219 = ($220|0)==(0);
       $221 = HEAP32[$__b>>2]|0;
       $222 = (($221) + 12|0);
       $223 = HEAP32[$222>>2]|0;
       $224 = (($221) + 16|0);
       $225 = HEAP32[$224>>2]|0;
       $226 = ($223|0)==($225|0);
       if ($219) {
        if ($226) {
         $262 = HEAP32[$221>>2]|0;
         $263 = (($262) + 36|0);
         $264 = HEAP32[$263>>2]|0;
         __THREW__ = 0;
         $265 = (invoke_ii($264|0,($221|0))|0);
         $266 = __THREW__; __THREW__ = 0;
         $267 = $266&1;
         if ($267) {
          label = 24;
          break L4;
         }
         $$pre268 = HEAP8[$__nsn>>0]|0;
         $$0$i$i99 = $265;$272 = $$pre268;
        } else {
         $268 = HEAP8[$223>>0]|0;
         $269 = $268&255;
         $$0$i$i99 = $269;$272 = $196;
        }
        $270 = $$0$i$i99&255;
        $271 = $272 & 1;
        $273 = ($271<<24>>24)==(0);
        $274 = HEAP32[$9>>2]|0;
        $$283 = $273 ? $7 : $274;
        $275 = HEAP8[$$283>>0]|0;
        $276 = ($270<<24>>24)==($275<<24>>24);
        if (!($276)) {
         $877 = $875;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
         break L26;
        }
        $277 = HEAP32[$__b>>2]|0;
        $278 = (($277) + 12|0);
        $279 = HEAP32[$278>>2]|0;
        $280 = (($277) + 16|0);
        $281 = HEAP32[$280>>2]|0;
        $282 = ($279|0)==($281|0);
        if ($282) {
         $283 = HEAP32[$277>>2]|0;
         $284 = (($283) + 40|0);
         $285 = HEAP32[$284>>2]|0;
         __THREW__ = 0;
         (invoke_ii($285|0,($277|0))|0);
         $286 = __THREW__; __THREW__ = 0;
         $287 = $286&1;
         if ($287) {
          label = 24;
          break L4;
         }
        } else {
         $288 = (($279) + 1|0);
         HEAP32[$278>>2] = $288;
        }
        HEAP8[$__neg>>0] = 1;
        $289 = HEAP8[$__nsn>>0]|0;
        $290 = $289 & 1;
        $291 = ($290<<24>>24)==(0);
        if ($291) {
         $293 = $289&255;
         $294 = $293 >>> 1;
         $296 = $294;
        } else {
         $292 = HEAP32[$8>>2]|0;
         $296 = $292;
        }
        $295 = ($296>>>0)>(1);
        $__nsn$__trailing_sign$0 = $295 ? $__nsn : $__trailing_sign$0229;
        $877 = $875;$878 = $874;$__trailing_sign$1 = $__nsn$__trailing_sign$0;
        break L26;
       }
       if ($226) {
        $227 = HEAP32[$221>>2]|0;
        $228 = (($227) + 36|0);
        $229 = HEAP32[$228>>2]|0;
        __THREW__ = 0;
        $230 = (invoke_ii($229|0,($221|0))|0);
        $231 = __THREW__; __THREW__ = 0;
        $232 = $231&1;
        if ($232) {
         label = 24;
         break L4;
        }
        $$pre269 = HEAP8[$__psn>>0]|0;
        $$0$i$i79 = $230;$237 = $$pre269;
       } else {
        $233 = HEAP8[$223>>0]|0;
        $234 = $233&255;
        $$0$i$i79 = $234;$237 = $190;
       }
       $235 = $$0$i$i79&255;
       $236 = $237 & 1;
       $238 = ($236<<24>>24)==(0);
       $239 = HEAP32[$12>>2]|0;
       $$ = $238 ? $10 : $239;
       $240 = HEAP8[$$>>0]|0;
       $241 = ($235<<24>>24)==($240<<24>>24);
       if (!($241)) {
        HEAP8[$__neg>>0] = 1;
        $877 = $875;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
        break L26;
       }
       $242 = HEAP32[$__b>>2]|0;
       $243 = (($242) + 12|0);
       $244 = HEAP32[$243>>2]|0;
       $245 = (($242) + 16|0);
       $246 = HEAP32[$245>>2]|0;
       $247 = ($244|0)==($246|0);
       if ($247) {
        $248 = HEAP32[$242>>2]|0;
        $249 = (($248) + 40|0);
        $250 = HEAP32[$249>>2]|0;
        __THREW__ = 0;
        (invoke_ii($250|0,($242|0))|0);
        $251 = __THREW__; __THREW__ = 0;
        $252 = $251&1;
        if ($252) {
         label = 24;
         break L4;
        }
       } else {
        $253 = (($244) + 1|0);
        HEAP32[$243>>2] = $253;
       }
       $254 = HEAP8[$__psn>>0]|0;
       $255 = $254 & 1;
       $256 = ($255<<24>>24)==(0);
       if ($256) {
        $258 = $254&255;
        $259 = $258 >>> 1;
        $261 = $259;
       } else {
        $257 = HEAP32[$11>>2]|0;
        $261 = $257;
       }
       $260 = ($261>>>0)>(1);
       $__psn$__trailing_sign$0 = $260 ? $__psn : $__trailing_sign$0229;
       $877 = $875;$878 = $874;$__trailing_sign$1 = $__psn$__trailing_sign$0;
      }
      break;
     }
     case 2:  {
      $375 = ($__trailing_sign$0229|0)!=(0|0);
      $376 = ($__p$0227>>>0)<(2);
      $or$cond = $375 | $376;
      if (!($or$cond)) {
       $377 = ($__p$0227|0)==(2);
       if ($377) {
        $378 = HEAP8[$21>>0]|0;
        $379 = ($378<<24>>24)!=(0);
        $380 = $379;
       } else {
        $380 = 0;
       }
       $brmerge = $14 | $380;
       if (!($brmerge)) {
        $877 = $875;$878 = $874;$__trailing_sign$1 = 0;
        break L26;
       }
      }
      $381 = HEAP8[$__sym>>0]|0;
      $382 = $381 & 1;
      $383 = ($382<<24>>24)==(0);
      $384 = HEAP32[$16>>2]|0;
      $$286 = $383 ? $15 : $384;
      $385 = ($__p$0227|0)==(0);
      L261: do {
       if ($385) {
        $$pre$i2$i$i150 = $875;$437 = $381;$447 = $$286;$465 = $875;
       } else {
        $386 = (($__p$0227) + -1)|0;
        $387 = (($__pat) + ($386)|0);
        $388 = HEAP8[$387>>0]|0;
        $switch = ($388&255)<(2);
        if ($switch) {
         $389 = $381&255;
         $390 = $389 >>> 1;
         $391 = HEAP32[$16>>2]|0;
         $392 = HEAP32[$17>>2]|0;
         $395 = $$286;
         while(1) {
          $$287 = $383 ? $15 : $391;
          $$288 = $383 ? $390 : $392;
          $393 = (($$287) + ($$288)|0);
          $394 = ($395|0)==($393|0);
          if ($394) {
           break;
          }
          $396 = HEAP8[$395>>0]|0;
          $isascii1$i156 = ($396<<24>>24)>(-1);
          if (!($isascii1$i156)) {
           break;
          }
          $397 = $396 << 24 >> 24;
          $398 = HEAP32[$6>>2]|0;
          $399 = (($398) + ($397<<1)|0);
          $400 = HEAP16[$399>>1]|0;
          $401 = $400 & 8192;
          $402 = ($401<<16>>16)==(0);
          $403 = (($395) + 1|0);
          if ($402) {
           break;
          } else {
           $395 = $403;
          }
         }
         $$289 = $383 ? $15 : $391;
         $404 = $395;
         $405 = $$289;
         $406 = (($404) - ($405))|0;
         $407 = HEAP8[$__spaces>>0]|0;
         $408 = $407 & 1;
         $409 = ($408<<24>>24)==(0);
         if ($409) {
          $411 = $407&255;
          $412 = $411 >>> 1;
          $414 = $412;
         } else {
          $410 = HEAP32[$20>>2]|0;
          $414 = $410;
         }
         $413 = ($406>>>0)>($414>>>0);
         L273: do {
          if (!($413)) {
           if ($409) {
            $418 = $407&255;
            $419 = $418 >>> 1;
            $$sum274 = (($419) - ($406))|0;
            $420 = ((($__spaces) + ($$sum274)|0) + 1|0);
            $421 = $407&255;
            $422 = $421 >>> 1;
            $424 = $18;$425 = $422;$427 = $420;
           } else {
            $415 = HEAP32[$19>>2]|0;
            $416 = HEAP32[$20>>2]|0;
            $$sum = (($416) - ($406))|0;
            $417 = (($415) + ($$sum)|0);
            $424 = $415;$425 = $416;$427 = $417;
           }
           $423 = (($424) + ($425)|0);
           $$290 = $383 ? $15 : $391;
           $426 = ($427|0)==($423|0);
           if ($426) {
            $$pre$i2$i$i150 = $875;$437 = $381;$447 = $395;$465 = $875;
            break L261;
           } else {
            $429 = $427;$431 = $$290;
           }
           while(1) {
            $428 = HEAP8[$429>>0]|0;
            $430 = HEAP8[$431>>0]|0;
            $432 = ($428<<24>>24)==($430<<24>>24);
            if (!($432)) {
             break L273;
            }
            $433 = (($429) + 1|0);
            $434 = (($431) + 1|0);
            $435 = ($433|0)==($423|0);
            if ($435) {
             $$pre$i2$i$i150 = $875;$437 = $381;$447 = $395;$465 = $875;
             break L261;
            } else {
             $429 = $433;$431 = $434;
            }
           }
          }
         } while(0);
         $$291 = $383 ? $15 : $391;
         $$pre$i2$i$i150 = $875;$437 = $381;$447 = $$291;$465 = $875;
        } else {
         $$pre$i2$i$i150 = $875;$437 = $381;$447 = $$286;$465 = $875;
        }
       }
      } while(0);
      L283: while(1) {
       $436 = $437 & 1;
       $438 = ($436<<24>>24)==(0);
       if ($438) {
        $441 = $437&255;
        $442 = $441 >>> 1;
        $444 = $15;$445 = $442;
       } else {
        $439 = HEAP32[$16>>2]|0;
        $440 = HEAP32[$17>>2]|0;
        $444 = $439;$445 = $440;
       }
       $443 = (($444) + ($445)|0);
       $446 = ($447|0)==($443|0);
       if ($446) {
        $880 = $$pre$i2$i$i150;
        break;
       }
       $448 = HEAP32[$__b>>2]|0;
       $449 = ($448|0)==(0|0);
       do {
        if ($449) {
         $463 = 0;
        } else {
         $450 = (($448) + 12|0);
         $451 = HEAP32[$450>>2]|0;
         $452 = (($448) + 16|0);
         $453 = HEAP32[$452>>2]|0;
         $454 = ($451|0)==($453|0);
         if ($454) {
          $455 = HEAP32[$448>>2]|0;
          $456 = (($455) + 36|0);
          $457 = HEAP32[$456>>2]|0;
          __THREW__ = 0;
          $458 = (invoke_ii($457|0,($448|0))|0);
          $459 = __THREW__; __THREW__ = 0;
          $460 = $459&1;
          if ($460) {
           label = 22;
           break L4;
          }
          $461 = ($458|0)==(-1);
          if ($461) {
           HEAP32[$__b>>2] = 0;
           $463 = 0;
           break;
          } else {
           $$pre$i$i$i146 = HEAP32[$__b>>2]|0;
           $463 = $$pre$i$i$i146;
           break;
          }
         } else {
          $463 = $448;
         }
        }
       } while(0);
       $462 = ($463|0)==(0|0);
       $464 = ($465|0)==(0|0);
       do {
        if ($464) {
         $$pre$i2$i$i150239 = $$pre$i2$i$i150;
         label = 170;
        } else {
         $466 = (($465) + 12|0);
         $467 = HEAP32[$466>>2]|0;
         $468 = (($465) + 16|0);
         $469 = HEAP32[$468>>2]|0;
         $470 = ($467|0)==($469|0);
         if (!($470)) {
          if ($462) {
           $$pre$i2$i$i150238 = $$pre$i2$i$i150;$881 = $465;
           break;
          } else {
           $880 = $$pre$i2$i$i150;
           break L283;
          }
         }
         $471 = HEAP32[$465>>2]|0;
         $472 = (($471) + 36|0);
         $473 = HEAP32[$472>>2]|0;
         __THREW__ = 0;
         $474 = (invoke_ii($473|0,($465|0))|0);
         $475 = __THREW__; __THREW__ = 0;
         $476 = $475&1;
         if ($476) {
          label = 22;
          break L4;
         }
         $477 = ($474|0)==(-1);
         if ($477) {
          HEAP32[$__e>>2] = 0;
          $$pre$i2$i$i150239 = 0;
          label = 170;
          break;
         } else {
          $478 = ($$pre$i2$i$i150|0)==(0|0);
          $tmp$i$i152 = $462 ^ $478;
          if ($tmp$i$i152) {
           $$pre$i2$i$i150238 = $$pre$i2$i$i150;$881 = $$pre$i2$i$i150;
           break;
          } else {
           $880 = $$pre$i2$i$i150;
           break L283;
          }
         }
        }
       } while(0);
       if ((label|0) == 170) {
        label = 0;
        if ($462) {
         $880 = $$pre$i2$i$i150239;
         break;
        } else {
         $$pre$i2$i$i150238 = $$pre$i2$i$i150239;$881 = 0;
        }
       }
       $479 = HEAP32[$__b>>2]|0;
       $480 = (($479) + 12|0);
       $481 = HEAP32[$480>>2]|0;
       $482 = (($479) + 16|0);
       $483 = HEAP32[$482>>2]|0;
       $484 = ($481|0)==($483|0);
       if ($484) {
        $485 = HEAP32[$479>>2]|0;
        $486 = (($485) + 36|0);
        $487 = HEAP32[$486>>2]|0;
        __THREW__ = 0;
        $488 = (invoke_ii($487|0,($479|0))|0);
        $489 = __THREW__; __THREW__ = 0;
        $490 = $489&1;
        if ($490) {
         label = 22;
         break L4;
        } else {
         $$0$i$i142 = $488;
        }
       } else {
        $491 = HEAP8[$481>>0]|0;
        $492 = $491&255;
        $$0$i$i142 = $492;
       }
       $493 = $$0$i$i142&255;
       $494 = HEAP8[$447>>0]|0;
       $495 = ($493<<24>>24)==($494<<24>>24);
       if (!($495)) {
        $880 = $$pre$i2$i$i150238;
        break;
       }
       $496 = HEAP32[$__b>>2]|0;
       $497 = (($496) + 12|0);
       $498 = HEAP32[$497>>2]|0;
       $499 = (($496) + 16|0);
       $500 = HEAP32[$499>>2]|0;
       $501 = ($498|0)==($500|0);
       if ($501) {
        $502 = HEAP32[$496>>2]|0;
        $503 = (($502) + 40|0);
        $504 = HEAP32[$503>>2]|0;
        __THREW__ = 0;
        (invoke_ii($504|0,($496|0))|0);
        $505 = __THREW__; __THREW__ = 0;
        $506 = $505&1;
        if ($506) {
         label = 22;
         break L4;
        }
       } else {
        $507 = (($498) + 1|0);
        HEAP32[$497>>2] = $507;
       }
       $508 = (($447) + 1|0);
       $$pre = HEAP8[$__sym>>0]|0;
       $$pre$i2$i$i150 = $$pre$i2$i$i150238;$437 = $$pre;$447 = $508;$465 = $881;
      }
      if ($14) {
       $509 = HEAP8[$__sym>>0]|0;
       $510 = $509 & 1;
       $511 = ($510<<24>>24)==(0);
       if ($511) {
        $514 = $509&255;
        $515 = $514 >>> 1;
        $517 = $15;$518 = $515;
       } else {
        $512 = HEAP32[$16>>2]|0;
        $513 = HEAP32[$17>>2]|0;
        $517 = $512;$518 = $513;
       }
       $516 = (($517) + ($518)|0);
       $519 = ($447|0)==($516|0);
       if ($519) {
        $877 = $880;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
       } else {
        label = 185;
        break L4;
       }
      } else {
       $877 = $880;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
      }
      break;
     }
     default: {
      $877 = $875;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
     }
     }
    } while(0);
    L325: do {
     if ((label|0) == 41) {
      label = 0;
      $119 = ($__p$0227|0)==(3);
      if ($119) {
       $862 = $874;$876 = $875;$__trailing_sign$0$lcssa = $__trailing_sign$0229;
       label = 280;
       break L4;
      } else {
       $$pre$i2$i$i39 = $875;$137 = $875;
      }
      while(1) {
       $120 = HEAP32[$__b>>2]|0;
       $121 = ($120|0)==(0|0);
       do {
        if ($121) {
         $135 = 0;
        } else {
         $122 = (($120) + 12|0);
         $123 = HEAP32[$122>>2]|0;
         $124 = (($120) + 16|0);
         $125 = HEAP32[$124>>2]|0;
         $126 = ($123|0)==($125|0);
         if ($126) {
          $127 = HEAP32[$120>>2]|0;
          $128 = (($127) + 36|0);
          $129 = HEAP32[$128>>2]|0;
          __THREW__ = 0;
          $130 = (invoke_ii($129|0,($120|0))|0);
          $131 = __THREW__; __THREW__ = 0;
          $132 = $131&1;
          if ($132) {
           label = 23;
           break L4;
          }
          $133 = ($130|0)==(-1);
          if ($133) {
           HEAP32[$__b>>2] = 0;
           $135 = 0;
           break;
          } else {
           $$pre$i$i$i35 = HEAP32[$__b>>2]|0;
           $135 = $$pre$i$i$i35;
           break;
          }
         } else {
          $135 = $120;
         }
        }
       } while(0);
       $134 = ($135|0)==(0|0);
       $136 = ($137|0)==(0|0);
       do {
        if ($136) {
         $$pre$i2$i$i39235 = $$pre$i2$i$i39;
         label = 54;
        } else {
         $138 = (($137) + 12|0);
         $139 = HEAP32[$138>>2]|0;
         $140 = (($137) + 16|0);
         $141 = HEAP32[$140>>2]|0;
         $142 = ($139|0)==($141|0);
         if (!($142)) {
          if ($134) {
           $$pre$i2$i$i39237 = $$pre$i2$i$i39;$879 = $137;
           break;
          } else {
           $877 = $$pre$i2$i$i39;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
           break L325;
          }
         }
         $143 = HEAP32[$137>>2]|0;
         $144 = (($143) + 36|0);
         $145 = HEAP32[$144>>2]|0;
         __THREW__ = 0;
         $146 = (invoke_ii($145|0,($137|0))|0);
         $147 = __THREW__; __THREW__ = 0;
         $148 = $147&1;
         if ($148) {
          label = 23;
          break L4;
         }
         $149 = ($146|0)==(-1);
         if ($149) {
          HEAP32[$__e>>2] = 0;
          $$pre$i2$i$i39235 = 0;
          label = 54;
          break;
         } else {
          $150 = ($$pre$i2$i$i39|0)==(0|0);
          $tmp$i$i41 = $134 ^ $150;
          if ($tmp$i$i41) {
           $$pre$i2$i$i39237 = $$pre$i2$i$i39;$879 = $$pre$i2$i$i39;
           break;
          } else {
           $877 = $$pre$i2$i$i39;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
           break L325;
          }
         }
        }
       } while(0);
       if ((label|0) == 54) {
        label = 0;
        if ($134) {
         $877 = $$pre$i2$i$i39235;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
         break L325;
        } else {
         $$pre$i2$i$i39237 = $$pre$i2$i$i39235;$879 = 0;
        }
       }
       $151 = HEAP32[$__b>>2]|0;
       $152 = (($151) + 12|0);
       $153 = HEAP32[$152>>2]|0;
       $154 = (($151) + 16|0);
       $155 = HEAP32[$154>>2]|0;
       $156 = ($153|0)==($155|0);
       if ($156) {
        $157 = HEAP32[$151>>2]|0;
        $158 = (($157) + 36|0);
        $159 = HEAP32[$158>>2]|0;
        __THREW__ = 0;
        $160 = (invoke_ii($159|0,($151|0))|0);
        $161 = __THREW__; __THREW__ = 0;
        $162 = $161&1;
        if ($162) {
         label = 23;
         break L4;
        } else {
         $$0$i$i45 = $160;
        }
       } else {
        $163 = HEAP8[$153>>0]|0;
        $164 = $163&255;
        $$0$i$i45 = $164;
       }
       $165 = $$0$i$i45&255;
       $isascii1$i48 = ($165<<24>>24)>(-1);
       if (!($isascii1$i48)) {
        $877 = $$pre$i2$i$i39237;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
        break L325;
       }
       $sext195 = $$0$i$i45 << 24;
       $166 = $sext195 >> 24;
       $167 = HEAP32[$6>>2]|0;
       $168 = (($167) + ($166<<1)|0);
       $169 = HEAP16[$168>>1]|0;
       $170 = $169 & 8192;
       $171 = ($170<<16>>16)==(0);
       if ($171) {
        $877 = $$pre$i2$i$i39237;$878 = $874;$__trailing_sign$1 = $__trailing_sign$0229;
        break L325;
       }
       $172 = HEAP32[$__b>>2]|0;
       $173 = (($172) + 12|0);
       $174 = HEAP32[$173>>2]|0;
       $175 = (($172) + 16|0);
       $176 = HEAP32[$175>>2]|0;
       $177 = ($174|0)==($176|0);
       if ($177) {
        $178 = HEAP32[$172>>2]|0;
        $179 = (($178) + 40|0);
        $180 = HEAP32[$179>>2]|0;
        __THREW__ = 0;
        $181 = (invoke_ii($180|0,($172|0))|0);
        $182 = __THREW__; __THREW__ = 0;
        $183 = $182&1;
        if ($183) {
         label = 23;
         break L4;
        } else {
         $$0$i$i50 = $181;
        }
       } else {
        $184 = (($174) + 1|0);
        HEAP32[$173>>2] = $184;
        $185 = HEAP8[$174>>0]|0;
        $186 = $185&255;
        $$0$i$i50 = $186;
       }
       $187 = $$0$i$i50&255;
       __THREW__ = 0;
       invoke_vii(3508,($__spaces|0),($187|0));
       $188 = __THREW__; __THREW__ = 0;
       $189 = $188&1;
       if ($189) {
        label = 23;
        break L4;
       } else {
        $$pre$i2$i$i39 = $$pre$i2$i$i39237;$137 = $879;
       }
      }
     }
    } while(0);
    $777 = (($__p$0227) + 1)|0;
    $778 = ($777>>>0)<(4);
    if ($778) {
     $874 = $878;$__p$0227 = $777;$__trailing_sign$0229 = $__trailing_sign$1;
    } else {
     $862 = $878;$876 = $877;$__trailing_sign$0$lcssa = $__trailing_sign$1;
     label = 280;
     break;
    }
   }
   L360:    switch (label|0) {
    case 20: {
     $59 = ___cxa_find_matching_catch()|0;
     $60 = tempRet0;
     $lpad$phi$index = $59;$lpad$phi$index7 = $60;
     break L1;
     break;
    }
    case 21: {
     $61 = ___cxa_find_matching_catch()|0;
     $62 = tempRet0;
     $lpad$phi$index = $61;$lpad$phi$index7 = $62;
     break L1;
     break;
    }
    case 22: {
     $63 = ___cxa_find_matching_catch()|0;
     $64 = tempRet0;
     $lpad$phi$index = $63;$lpad$phi$index7 = $64;
     break L1;
     break;
    }
    case 23: {
     $65 = ___cxa_find_matching_catch()|0;
     $66 = tempRet0;
     $lpad$phi$index = $65;$lpad$phi$index7 = $66;
     break L1;
     break;
    }
    case 24: {
     $67 = ___cxa_find_matching_catch()|0;
     $68 = tempRet0;
     $lpad$phi$index = $67;$lpad$phi$index7 = $68;
     break L1;
     break;
    }
    case 40: {
     $117 = HEAP32[$__err>>2]|0;
     $118 = $117 | 4;
     HEAP32[$__err>>2] = $118;
     $$0 = 0;
     break;
    }
    case 132: {
     $373 = HEAP32[$__err>>2]|0;
     $374 = $373 | 4;
     HEAP32[$__err>>2] = $374;
     $$0 = 0;
     break;
    }
    case 185: {
     $520 = HEAP32[$__err>>2]|0;
     $521 = $520 | 4;
     HEAP32[$__err>>2] = $521;
     $$0 = 0;
     break;
    }
    case 244: {
     $667 = HEAP32[$__err>>2]|0;
     $668 = $667 | 4;
     HEAP32[$__err>>2] = $668;
     $$0 = 0;
     break;
    }
    case 267: {
     $733 = HEAP32[$__err>>2]|0;
     $734 = $733 | 4;
     HEAP32[$__err>>2] = $734;
     $$0 = 0;
     break;
    }
    case 278: {
     $775 = HEAP32[$__err>>2]|0;
     $776 = $775 | 4;
     HEAP32[$__err>>2] = $776;
     $$0 = 0;
     break;
    }
    case 280: {
     $779 = ($__trailing_sign$0$lcssa|0)==(0|0);
     L364: do {
      if (!($779)) {
       $780 = (($__trailing_sign$0$lcssa) + 1|0);
       $781 = (($__trailing_sign$0$lcssa) + 8|0);
       $782 = (($__trailing_sign$0$lcssa) + 4|0);
       $$pre$i2$i$i = $876;$808 = $876;$__i$0 = 1;
       L366: while(1) {
        $783 = HEAP8[$__trailing_sign$0$lcssa>>0]|0;
        $784 = $783 & 1;
        $785 = ($784<<24>>24)==(0);
        if ($785) {
         $787 = $783&255;
         $788 = $787 >>> 1;
         $790 = $788;
        } else {
         $786 = HEAP32[$782>>2]|0;
         $790 = $786;
        }
        $789 = ($__i$0>>>0)<($790>>>0);
        if (!($789)) {
         break L364;
        }
        $791 = HEAP32[$__b>>2]|0;
        $792 = ($791|0)==(0|0);
        do {
         if ($792) {
          $806 = 0;
         } else {
          $793 = (($791) + 12|0);
          $794 = HEAP32[$793>>2]|0;
          $795 = (($791) + 16|0);
          $796 = HEAP32[$795>>2]|0;
          $797 = ($794|0)==($796|0);
          if ($797) {
           $798 = HEAP32[$791>>2]|0;
           $799 = (($798) + 36|0);
           $800 = HEAP32[$799>>2]|0;
           __THREW__ = 0;
           $801 = (invoke_ii($800|0,($791|0))|0);
           $802 = __THREW__; __THREW__ = 0;
           $803 = $802&1;
           if ($803) {
            label = 19;
            break L366;
           }
           $804 = ($801|0)==(-1);
           if ($804) {
            HEAP32[$__b>>2] = 0;
            $806 = 0;
            break;
           } else {
            $$pre$i$i$i = HEAP32[$__b>>2]|0;
            $806 = $$pre$i$i$i;
            break;
           }
          } else {
           $806 = $791;
          }
         }
        } while(0);
        $805 = ($806|0)==(0|0);
        $807 = ($808|0)==(0|0);
        do {
         if ($807) {
          $$pre$i2$i$i244$ph = $$pre$i2$i$i;
          label = 298;
         } else {
          $809 = (($808) + 12|0);
          $810 = HEAP32[$809>>2]|0;
          $811 = (($808) + 16|0);
          $812 = HEAP32[$811>>2]|0;
          $813 = ($810|0)==($812|0);
          if (!($813)) {
           if ($805) {
            $$pre$i2$i$i244281 = $$pre$i2$i$i;$890 = $808;
            break;
           } else {
            label = 306;
            break L366;
           }
          }
          $814 = HEAP32[$808>>2]|0;
          $815 = (($814) + 36|0);
          $816 = HEAP32[$815>>2]|0;
          __THREW__ = 0;
          $817 = (invoke_ii($816|0,($808|0))|0);
          $818 = __THREW__; __THREW__ = 0;
          $819 = $818&1;
          if ($819) {
           label = 19;
           break L366;
          }
          $820 = ($817|0)==(-1);
          if ($820) {
           HEAP32[$__e>>2] = 0;
           $$pre$i2$i$i244$ph = 0;
           label = 298;
           break;
          } else {
           $821 = ($$pre$i2$i$i|0)==(0|0);
           $tmp$i$i = $805 ^ $821;
           if ($tmp$i$i) {
            $$pre$i2$i$i244281 = $$pre$i2$i$i;$890 = $$pre$i2$i$i;
            break;
           } else {
            label = 306;
            break L366;
           }
          }
         }
        } while(0);
        if ((label|0) == 298) {
         label = 0;
         if ($805) {
          label = 306;
          break;
         } else {
          $$pre$i2$i$i244281 = $$pre$i2$i$i244$ph;$890 = 0;
         }
        }
        $822 = HEAP32[$__b>>2]|0;
        $823 = (($822) + 12|0);
        $824 = HEAP32[$823>>2]|0;
        $825 = (($822) + 16|0);
        $826 = HEAP32[$825>>2]|0;
        $827 = ($824|0)==($826|0);
        if ($827) {
         $828 = HEAP32[$822>>2]|0;
         $829 = (($828) + 36|0);
         $830 = HEAP32[$829>>2]|0;
         __THREW__ = 0;
         $831 = (invoke_ii($830|0,($822|0))|0);
         $832 = __THREW__; __THREW__ = 0;
         $833 = $832&1;
         if ($833) {
          label = 19;
          break;
         } else {
          $$0$i$i = $831;
         }
        } else {
         $834 = HEAP8[$824>>0]|0;
         $835 = $834&255;
         $$0$i$i = $835;
        }
        $836 = $$0$i$i&255;
        $837 = HEAP8[$__trailing_sign$0$lcssa>>0]|0;
        $838 = $837 & 1;
        $839 = ($838<<24>>24)==(0);
        if ($839) {
         $842 = $780;
        } else {
         $840 = HEAP32[$781>>2]|0;
         $842 = $840;
        }
        $841 = (($842) + ($__i$0)|0);
        $843 = HEAP8[$841>>0]|0;
        $844 = ($836<<24>>24)==($843<<24>>24);
        if (!($844)) {
         label = 306;
         break;
        }
        $847 = (($__i$0) + 1)|0;
        $848 = HEAP32[$__b>>2]|0;
        $849 = (($848) + 12|0);
        $850 = HEAP32[$849>>2]|0;
        $851 = (($848) + 16|0);
        $852 = HEAP32[$851>>2]|0;
        $853 = ($850|0)==($852|0);
        if ($853) {
         $854 = HEAP32[$848>>2]|0;
         $855 = (($854) + 40|0);
         $856 = HEAP32[$855>>2]|0;
         __THREW__ = 0;
         (invoke_ii($856|0,($848|0))|0);
         $857 = __THREW__; __THREW__ = 0;
         $858 = $857&1;
         if ($858) {
          label = 19;
          break;
         } else {
          $$pre$i2$i$i = $$pre$i2$i$i244281;$808 = $890;$__i$0 = $847;
          continue;
         }
        } else {
         $859 = (($850) + 1|0);
         HEAP32[$849>>2] = $859;
         $$pre$i2$i$i = $$pre$i2$i$i244281;$808 = $890;$__i$0 = $847;
         continue;
        }
       }
       if ((label|0) == 19) {
        $57 = ___cxa_find_matching_catch()|0;
        $58 = tempRet0;
        $lpad$phi$index = $57;$lpad$phi$index7 = $58;
        break L1;
       }
       else if ((label|0) == 306) {
        $845 = HEAP32[$__err>>2]|0;
        $846 = $845 | 4;
        HEAP32[$__err>>2] = $846;
        $$0 = 0;
        break L360;
       }
      }
     } while(0);
     $860 = HEAP32[$__gb>>2]|0;
     $861 = ($860|0)==($862|0);
     if ($861) {
      $$0 = 1;
     } else {
      HEAP32[$__et>>2] = 0;
      __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grp,$860,$862,$__et);
      $863 = HEAP32[$__et>>2]|0;
      $864 = ($863|0)==(0);
      if ($864) {
       $$0 = 1;
      } else {
       $865 = HEAP32[$__err>>2]|0;
       $866 = $865 | 4;
       HEAP32[$__err>>2] = $866;
       $$0 = 0;
      }
     }
     break;
    }
   }
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__spaces);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__nsn);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__psn);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sym);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
   $867 = HEAP32[$__gb>>2]|0;
   HEAP32[$__gb>>2] = 0;
   $868 = ($867|0)==(0|0);
   if ($868) {
    STACKTOP = sp;return ($$0|0);
   }
   $869 = HEAP32[$1>>2]|0;
   __THREW__ = 0;
   invoke_vi($869|0,($867|0));
   $870 = __THREW__; __THREW__ = 0;
   $871 = $870&1;
   if ($871) {
    $872 = ___cxa_find_matching_catch(0|0)|0;
    $873 = tempRet0;
    ___clang_call_terminate($872);
    // unreachable;
   } else {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__spaces);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__nsn);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__psn);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sym);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
 $71 = HEAP32[$__gb>>2]|0;
 HEAP32[$__gb>>2] = 0;
 $72 = ($71|0)==(0|0);
 if ($72) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $73 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($73|0,($71|0));
 $74 = __THREW__; __THREW__ = 0;
 $75 = $74&1;
 if ($75) {
  $76 = ___cxa_find_matching_catch(0|0)|0;
  $77 = tempRet0;
  ___clang_call_terminate($76);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNSt3__121__throw_runtime_errorEPKc($msg) {
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(3504,($0|0),($msg|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  ___cxa_free_exception(($0|0));
  ___resumeException($3|0);
  // unreachable;
 } else {
  ___cxa_throw(($0|0),(3105728|0),(3284|0));
  // unreachable;
 }
}
function __ZNKSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE($agg$result,$this,$__b,$__e,$__intl,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__intl = $__intl|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0113 = 0, $$0114 = 0, $$015 = 0, $$016 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__loc = 0, $__neg = 0, $__w$0$lcssa = 0, $__w$05 = 0, $__wb = 0, $__wbuf = 0, $__wn = 0, $tmp$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $$byval_copy = sp + 24|0;
 $__wbuf = sp + 32|0;
 $__wb = sp + 8|0;
 $__wn = sp + 16|0;
 $__loc = sp + 20|0;
 $__neg = sp + 28|0;
 $0 = sp;
 HEAP32[$__wb>>2] = $__wbuf;
 $1 = (($__wb) + 4|0);
 HEAP32[$1>>2] = 3855;
 $2 = (($__wbuf) + 100|0);
 __THREW__ = 0;
 invoke_vii(2475,($__loc|0),($__iob|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  HEAP32[$__wb>>2] = 0;
  $$0113 = $32;$$015 = $31;$95 = $__wbuf;
 } else {
  __THREW__ = 0;
  $5 = (invoke_iii(2228,($__loc|0),(3093336|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  L4: do {
   if (!($7)) {
    HEAP8[$__neg>>0] = 0;
    $8 = HEAP32[$__e>>2]|0;
    HEAP32[$0>>2] = $8;
    $9 = (($__iob) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $11 = (invoke_iiiiiiiiiiii(3,($__b|0),($$byval_copy|0),($__intl|0),($__loc|0),($10|0),($__err|0),($__neg|0),($5|0),($__wb|0),($__wn|0),($2|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     if ($11) {
      $14 = HEAP8[$__v>>0]|0;
      $15 = $14 & 1;
      $16 = ($15<<24>>24)==(0);
      if ($16) {
       $20 = (($__v) + 1|0);
       HEAP8[$20>>0] = 0;
       HEAP8[$__v>>0] = 0;
      } else {
       $17 = (($__v) + 8|0);
       $18 = HEAP32[$17>>2]|0;
       HEAP8[$18>>0] = 0;
       $19 = (($__v) + 4|0);
       HEAP32[$19>>2] = 0;
      }
      $21 = HEAP8[$__neg>>0]|0;
      $22 = ($21<<24>>24)==(0);
      if (!($22)) {
       $23 = HEAP32[$5>>2]|0;
       $24 = (($23) + 28|0);
       $25 = HEAP32[$24>>2]|0;
       __THREW__ = 0;
       $26 = (invoke_iii($25|0,($5|0),45)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(3508,($__v|0),($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $33 = HEAP32[$5>>2]|0;
      $34 = (($33) + 28|0);
      $35 = HEAP32[$34>>2]|0;
      __THREW__ = 0;
      $36 = (invoke_iii($35|0,($5|0),48)|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = HEAP32[$__wb>>2]|0;
      $40 = HEAP32[$__wn>>2]|0;
      $41 = (($40) + -1|0);
      $42 = ($39>>>0)<($41>>>0);
      L18: do {
       if ($42) {
        $__w$05 = $39;
        while(1) {
         $45 = HEAP8[$__w$05>>0]|0;
         $46 = ($45<<24>>24)==($36<<24>>24);
         $44 = (($__w$05) + 1|0);
         if (!($46)) {
          $__w$0$lcssa = $__w$05;
          break L18;
         }
         $43 = ($44>>>0)<($41>>>0);
         if ($43) {
          $__w$05 = $44;
         } else {
          $__w$0$lcssa = $44;
          break;
         }
        }
       } else {
        $__w$0$lcssa = $39;
       }
      } while(0);
      __THREW__ = 0;
      (invoke_iiii(1684,($__v|0),($__w$0$lcssa|0),($40|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
     }
     $49 = HEAP32[$__b>>2]|0;
     $50 = ($49|0)==(0|0);
     do {
      if ($50) {
       $64 = 0;
      } else {
       $51 = (($49) + 12|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($49) + 16|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = ($52|0)==($54|0);
       if ($55) {
        $56 = HEAP32[$49>>2]|0;
        $57 = (($56) + 36|0);
        $58 = HEAP32[$57>>2]|0;
        __THREW__ = 0;
        $59 = (invoke_ii($58|0,($49|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         break L4;
        }
        $62 = ($59|0)==(-1);
        if ($62) {
         HEAP32[$__b>>2] = 0;
         $64 = 0;
         break;
        } else {
         $$pre$i$i$i = HEAP32[$__b>>2]|0;
         $64 = $$pre$i$i$i;
         break;
        }
       } else {
        $64 = $49;
       }
      }
     } while(0);
     $63 = ($64|0)==(0|0);
     $65 = ($8|0)==(0|0);
     do {
      if ($65) {
       label = 29;
      } else {
       $66 = (($8) + 12|0);
       $67 = HEAP32[$66>>2]|0;
       $68 = (($8) + 16|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = ($67|0)==($69|0);
       if (!($70)) {
        if ($63) {
         break;
        } else {
         label = 31;
         break;
        }
       }
       $71 = HEAP32[$8>>2]|0;
       $72 = (($71) + 36|0);
       $73 = HEAP32[$72>>2]|0;
       __THREW__ = 0;
       $74 = (invoke_ii($73|0,($8|0))|0);
       $75 = __THREW__; __THREW__ = 0;
       $76 = $75&1;
       if ($76) {
        break L4;
       }
       $77 = ($74|0)==(-1);
       if ($77) {
        HEAP32[$__e>>2] = 0;
        label = 29;
        break;
       } else {
        $78 = ($8|0)==(0|0);
        $tmp$i$i = $63 ^ $78;
        if ($tmp$i$i) {
         break;
        } else {
         label = 31;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 29) {
      if ($63) {
       label = 31;
      }
     }
     if ((label|0) == 31) {
      $79 = HEAP32[$__err>>2]|0;
      $80 = $79 | 2;
      HEAP32[$__err>>2] = $80;
     }
     $81 = HEAP32[$__b>>2]|0;
     HEAP32[$agg$result>>2] = $81;
     $82 = HEAP32[$__loc>>2]|0;
     (__ZNSt3__114__shared_count16__release_sharedEv($82)|0);
     $83 = HEAP32[$__wb>>2]|0;
     HEAP32[$__wb>>2] = 0;
     $84 = ($83|0)==(0|0);
     if ($84) {
      STACKTOP = sp;return;
     }
     $85 = HEAP32[$1>>2]|0;
     __THREW__ = 0;
     invoke_vi($85|0,($83|0));
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      $88 = ___cxa_find_matching_catch(0|0)|0;
      $89 = tempRet0;
      ___clang_call_terminate($88);
      // unreachable;
     } else {
      STACKTOP = sp;return;
     }
    }
   }
  } while(0);
  $90 = ___cxa_find_matching_catch()|0;
  $91 = tempRet0;
  $92 = HEAP32[$__loc>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($92)|0);
  $$pre = HEAP32[$__wb>>2]|0;
  HEAP32[$__wb>>2] = 0;
  $93 = ($$pre|0)==(0|0);
  if ($93) {
   $$0114 = $91;$$016 = $90;
   ___resumeException($$016|0);
   // unreachable;
  } else {
   $$0113 = $91;$$015 = $90;$95 = $$pre;
  }
 }
 $94 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($94|0,($95|0));
 $96 = __THREW__; __THREW__ = 0;
 $97 = $96&1;
 if ($97) {
  $98 = ___cxa_find_matching_catch(0|0)|0;
  $99 = tempRet0;
  ___clang_call_terminate($98);
  // unreachable;
 } else {
  $$0114 = $$0113;$$016 = $$015;
  ___resumeException($$016|0);
  // unreachable;
 }
}
function __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__p$02 = 0, $phitmp$i = 0, $scevgep = 0, $scevgep3 = 0, $scevgep4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__first;
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $4 = $1&255;
  $5 = $4 >>> 1;
  $15 = 10;$16 = $5;$40 = $1;
 } else {
  $6 = (($this) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$this>>2]|0;
  $9 = $8 & -2;
  $phitmp$i = (($9) + -1)|0;
  $10 = $8&255;
  $15 = $phitmp$i;$16 = $7;$40 = $10;
 }
 $11 = $__last;
 $12 = (($11) - ($0))|0;
 $13 = ($__last|0)==($__first|0);
 if ($13) {
  STACKTOP = sp;return ($this|0);
 }
 $14 = (($15) - ($16))|0;
 $17 = ($14>>>0)<($12>>>0);
 if ($17) {
  $18 = (($16) + ($12))|0;
  $19 = (($18) - ($15))|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj($this,$15,$19,$16,$16,0,0);
  $$pre = HEAP8[$this>>0]|0;
  $21 = $$pre;
 } else {
  $21 = $40;
 }
 $20 = $21 & 1;
 $22 = ($20<<24>>24)==(0);
 if ($22) {
  $25 = (($this) + 1|0);
  $27 = $25;
 } else {
  $23 = (($this) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $27 = $24;
 }
 $26 = (($27) + ($16)|0);
 $28 = (($16) - ($0))|0;
 $scevgep = (($__last) + ($28)|0);
 $scevgep3 = $scevgep;
 $$01 = $__first;$__p$02 = $26;
 while(1) {
  $29 = HEAP8[$$01>>0]|0;
  HEAP8[$__p$02>>0] = $29;
  $30 = (($__p$02) + 1|0);
  $31 = (($$01) + 1|0);
  $32 = ($31|0)==($__last|0);
  if ($32) {
   break;
  } else {
   $$01 = $31;$__p$02 = $30;
  }
 }
 $scevgep4 = (($27) + ($scevgep3)|0);
 HEAP8[$scevgep4>>0] = 0;
 $33 = (($16) + ($12))|0;
 $34 = HEAP8[$this>>0]|0;
 $35 = $34 & 1;
 $36 = ($35<<24>>24)==(0);
 if ($36) {
  $38 = $33 << 1;
  $39 = $38&255;
  HEAP8[$this>>0] = $39;
  STACKTOP = sp;return ($this|0);
 } else {
  $37 = (($this) + 4|0);
  HEAP32[$37>>2] = $33;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZNSt3__111__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri($__intl,$__loc,$__pat,$__dp,$__ts,$__grp,$__sym,$__psn,$__nsn,$__fd) {
 $__intl = $__intl|0;
 $__loc = $__loc|0;
 $__pat = $__pat|0;
 $__dp = $__dp|0;
 $__ts = $__ts|0;
 $__grp = $__grp|0;
 $__sym = $__sym|0;
 $__psn = $__psn|0;
 $__nsn = $__nsn|0;
 $__fd = $__fd|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 100|0;
 $1 = sp + 88|0;
 $2 = sp + 76|0;
 $3 = sp + 64|0;
 $4 = sp + 52|0;
 $5 = sp + 48|0;
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp;
 $9 = sp + 36|0;
 if ($__intl) {
  $10 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3092776)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($0,$10);
  $14 = HEAP32[$0>>2]|0;
  HEAP8[$__pat>>0]=$14&255;HEAP8[$__pat+1>>0]=($14>>8)&255;HEAP8[$__pat+2>>0]=($14>>16)&255;HEAP8[$__pat+3>>0]=$14>>24;
  $15 = HEAP32[$10>>2]|0;
  $16 = (($15) + 32|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 4095]($1,$10);
  $18 = HEAP8[$__nsn>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   $24 = (($__nsn) + 1|0);
   HEAP8[$24>>0] = 0;
   HEAP8[$__nsn>>0] = 0;
  } else {
   $21 = (($__nsn) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP8[$22>>0] = 0;
   $23 = (($__nsn) + 4|0);
   HEAP32[$23>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__nsn|0),0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch(0|0)|0;
   $28 = tempRet0;
   ___clang_call_terminate($27);
   // unreachable;
  }
  ;HEAP32[$__nsn+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__nsn+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__nsn+8>>2]=HEAP32[$1+8>>2]|0;
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($1);
  $29 = HEAP32[$10>>2]|0;
  $30 = (($29) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 4095]($2,$10);
  $32 = HEAP8[$__psn>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   $38 = (($__psn) + 1|0);
   HEAP8[$38>>0] = 0;
   HEAP8[$__psn>>0] = 0;
  } else {
   $35 = (($__psn) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP8[$36>>0] = 0;
   $37 = (($__psn) + 4|0);
   HEAP32[$37>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__psn|0),0);
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if ($40) {
   $41 = ___cxa_find_matching_catch(0|0)|0;
   $42 = tempRet0;
   ___clang_call_terminate($41);
   // unreachable;
  }
  ;HEAP32[$__psn+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$__psn+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$__psn+8>>2]=HEAP32[$2+8>>2]|0;
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($2);
  $43 = HEAP32[$10>>2]|0;
  $44 = (($43) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (FUNCTION_TABLE_ii[$45 & 4095]($10)|0);
  HEAP8[$__dp>>0] = $46;
  $47 = HEAP32[$10>>2]|0;
  $48 = (($47) + 16|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (FUNCTION_TABLE_ii[$49 & 4095]($10)|0);
  HEAP8[$__ts>>0] = $50;
  $51 = HEAP32[$10>>2]|0;
  $52 = (($51) + 20|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vii[$53 & 4095]($3,$10);
  $54 = HEAP8[$__grp>>0]|0;
  $55 = $54 & 1;
  $56 = ($55<<24>>24)==(0);
  if ($56) {
   $60 = (($__grp) + 1|0);
   HEAP8[$60>>0] = 0;
   HEAP8[$__grp>>0] = 0;
  } else {
   $57 = (($__grp) + 8|0);
   $58 = HEAP32[$57>>2]|0;
   HEAP8[$58>>0] = 0;
   $59 = (($__grp) + 4|0);
   HEAP32[$59>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__grp|0),0);
  $61 = __THREW__; __THREW__ = 0;
  $62 = $61&1;
  if ($62) {
   $63 = ___cxa_find_matching_catch(0|0)|0;
   $64 = tempRet0;
   ___clang_call_terminate($63);
   // unreachable;
  }
  ;HEAP32[$__grp+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$__grp+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$__grp+8>>2]=HEAP32[$3+8>>2]|0;
  ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($3);
  $65 = HEAP32[$10>>2]|0;
  $66 = (($65) + 24|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_vii[$67 & 4095]($4,$10);
  $68 = HEAP8[$__sym>>0]|0;
  $69 = $68 & 1;
  $70 = ($69<<24>>24)==(0);
  if ($70) {
   $74 = (($__sym) + 1|0);
   HEAP8[$74>>0] = 0;
   HEAP8[$__sym>>0] = 0;
  } else {
   $71 = (($__sym) + 8|0);
   $72 = HEAP32[$71>>2]|0;
   HEAP8[$72>>0] = 0;
   $73 = (($__sym) + 4|0);
   HEAP32[$73>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__sym|0),0);
  $75 = __THREW__; __THREW__ = 0;
  $76 = $75&1;
  if ($76) {
   $77 = ___cxa_find_matching_catch(0|0)|0;
   $78 = tempRet0;
   ___clang_call_terminate($77);
   // unreachable;
  }
  ;HEAP32[$__sym+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__sym+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__sym+8>>2]=HEAP32[$4+8>>2]|0;
  ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($4);
  $79 = HEAP32[$10>>2]|0;
  $80 = (($79) + 36|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (FUNCTION_TABLE_ii[$81 & 4095]($10)|0);
  $storemerge = $82;
  HEAP32[$__fd>>2] = $storemerge;
  STACKTOP = sp;return;
 } else {
  $83 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3092712)|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + 44|0);
  $86 = HEAP32[$85>>2]|0;
  FUNCTION_TABLE_vii[$86 & 4095]($5,$83);
  $87 = HEAP32[$5>>2]|0;
  HEAP8[$__pat>>0]=$87&255;HEAP8[$__pat+1>>0]=($87>>8)&255;HEAP8[$__pat+2>>0]=($87>>16)&255;HEAP8[$__pat+3>>0]=$87>>24;
  $88 = HEAP32[$83>>2]|0;
  $89 = (($88) + 32|0);
  $90 = HEAP32[$89>>2]|0;
  FUNCTION_TABLE_vii[$90 & 4095]($6,$83);
  $91 = HEAP8[$__nsn>>0]|0;
  $92 = $91 & 1;
  $93 = ($92<<24>>24)==(0);
  if ($93) {
   $97 = (($__nsn) + 1|0);
   HEAP8[$97>>0] = 0;
   HEAP8[$__nsn>>0] = 0;
  } else {
   $94 = (($__nsn) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   HEAP8[$95>>0] = 0;
   $96 = (($__nsn) + 4|0);
   HEAP32[$96>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__nsn|0),0);
  $98 = __THREW__; __THREW__ = 0;
  $99 = $98&1;
  if ($99) {
   $100 = ___cxa_find_matching_catch(0|0)|0;
   $101 = tempRet0;
   ___clang_call_terminate($100);
   // unreachable;
  }
  ;HEAP32[$__nsn+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$__nsn+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$__nsn+8>>2]=HEAP32[$6+8>>2]|0;
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($6);
  $102 = HEAP32[$83>>2]|0;
  $103 = (($102) + 28|0);
  $104 = HEAP32[$103>>2]|0;
  FUNCTION_TABLE_vii[$104 & 4095]($7,$83);
  $105 = HEAP8[$__psn>>0]|0;
  $106 = $105 & 1;
  $107 = ($106<<24>>24)==(0);
  if ($107) {
   $111 = (($__psn) + 1|0);
   HEAP8[$111>>0] = 0;
   HEAP8[$__psn>>0] = 0;
  } else {
   $108 = (($__psn) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   HEAP8[$109>>0] = 0;
   $110 = (($__psn) + 4|0);
   HEAP32[$110>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__psn|0),0);
  $112 = __THREW__; __THREW__ = 0;
  $113 = $112&1;
  if ($113) {
   $114 = ___cxa_find_matching_catch(0|0)|0;
   $115 = tempRet0;
   ___clang_call_terminate($114);
   // unreachable;
  }
  ;HEAP32[$__psn+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$__psn+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$__psn+8>>2]=HEAP32[$7+8>>2]|0;
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($7);
  $116 = HEAP32[$83>>2]|0;
  $117 = (($116) + 12|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (FUNCTION_TABLE_ii[$118 & 4095]($83)|0);
  HEAP8[$__dp>>0] = $119;
  $120 = HEAP32[$83>>2]|0;
  $121 = (($120) + 16|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = (FUNCTION_TABLE_ii[$122 & 4095]($83)|0);
  HEAP8[$__ts>>0] = $123;
  $124 = HEAP32[$83>>2]|0;
  $125 = (($124) + 20|0);
  $126 = HEAP32[$125>>2]|0;
  FUNCTION_TABLE_vii[$126 & 4095]($8,$83);
  $127 = HEAP8[$__grp>>0]|0;
  $128 = $127 & 1;
  $129 = ($128<<24>>24)==(0);
  if ($129) {
   $133 = (($__grp) + 1|0);
   HEAP8[$133>>0] = 0;
   HEAP8[$__grp>>0] = 0;
  } else {
   $130 = (($__grp) + 8|0);
   $131 = HEAP32[$130>>2]|0;
   HEAP8[$131>>0] = 0;
   $132 = (($__grp) + 4|0);
   HEAP32[$132>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__grp|0),0);
  $134 = __THREW__; __THREW__ = 0;
  $135 = $134&1;
  if ($135) {
   $136 = ___cxa_find_matching_catch(0|0)|0;
   $137 = tempRet0;
   ___clang_call_terminate($136);
   // unreachable;
  }
  ;HEAP32[$__grp+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__grp+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__grp+8>>2]=HEAP32[$8+8>>2]|0;
  ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($8);
  $138 = HEAP32[$83>>2]|0;
  $139 = (($138) + 24|0);
  $140 = HEAP32[$139>>2]|0;
  FUNCTION_TABLE_vii[$140 & 4095]($9,$83);
  $141 = HEAP8[$__sym>>0]|0;
  $142 = $141 & 1;
  $143 = ($142<<24>>24)==(0);
  if ($143) {
   $147 = (($__sym) + 1|0);
   HEAP8[$147>>0] = 0;
   HEAP8[$__sym>>0] = 0;
  } else {
   $144 = (($__sym) + 8|0);
   $145 = HEAP32[$144>>2]|0;
   HEAP8[$145>>0] = 0;
   $146 = (($__sym) + 4|0);
   HEAP32[$146>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__sym|0),0);
  $148 = __THREW__; __THREW__ = 0;
  $149 = $148&1;
  if ($149) {
   $150 = ___cxa_find_matching_catch(0|0)|0;
   $151 = tempRet0;
   ___clang_call_terminate($150);
   // unreachable;
  }
  ;HEAP32[$__sym+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__sym+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__sym+8>>2]=HEAP32[$9+8>>2]|0;
  ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($9);
  $152 = HEAP32[$83>>2]|0;
  $153 = (($152) + 36|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = (FUNCTION_TABLE_ii[$154 & 4095]($83)|0);
  $storemerge = $155;
  HEAP32[$__fd>>2] = $storemerge;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__119__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_($__b,$__n,$__e) {
 $__b = $__b|0;
 $__n = $__n|0;
 $__e = $__e|0;
 var $$ = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(3855|0);
 $3 = HEAP32[$__e>>2]|0;
 $4 = HEAP32[$__b>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<(2147483647);
 $9 = $7 << 1;
 $$ = $8 ? $9 : -1;
 $10 = HEAP32[$__n>>2]|0;
 $11 = $10;
 $12 = (($11) - ($6))|0;
 $13 = $2 ? $4 : 0;
 $14 = (_realloc($13,$$)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  __ZSt17__throw_bad_allocv();
 }
 do {
  if ($2) {
   HEAP32[$__b>>2] = $14;
   $23 = $14;
  } else {
   $$pr = HEAP32[$__b>>2]|0;
   HEAP32[$__b>>2] = $14;
   $16 = ($$pr|0)==(0|0);
   if ($16) {
    $23 = $14;
   } else {
    $17 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi($17|0,($$pr|0));
    $18 = __THREW__; __THREW__ = 0;
    $19 = $18&1;
    if ($19) {
     $20 = ___cxa_find_matching_catch(0|0)|0;
     $21 = tempRet0;
     ___clang_call_terminate($20);
     // unreachable;
    } else {
     $$pre = HEAP32[$__b>>2]|0;
     $23 = $$pre;
     break;
    }
   }
  }
 } while(0);
 HEAP32[$0>>2] = 3853;
 $22 = (($23) + ($12)|0);
 HEAP32[$__n>>2] = $22;
 $24 = HEAP32[$__b>>2]|0;
 $25 = (($24) + ($$)|0);
 HEAP32[$__e>>2] = $25;
 STACKTOP = sp;return;
}
function __ZNSt3__119__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_($__b,$__n,$__e) {
 $__b = $__b|0;
 $__n = $__n|0;
 $__e = $__e|0;
 var $$ = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(3855|0);
 $3 = HEAP32[$__e>>2]|0;
 $4 = HEAP32[$__b>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<(2147483647);
 $9 = $7 << 1;
 $$ = $8 ? $9 : -1;
 $10 = HEAP32[$__n>>2]|0;
 $11 = $10;
 $12 = (($11) - ($6))|0;
 $13 = $12 >> 2;
 if ($2) {
  $14 = $4;
 } else {
  $14 = 0;
 }
 $15 = (_realloc($14,$$)|0);
 $16 = ($15|0)==(0|0);
 if ($16) {
  __ZSt17__throw_bad_allocv();
 }
 do {
  if ($2) {
   HEAP32[$__b>>2] = $15;
   $25 = $15;
  } else {
   $$pr = HEAP32[$__b>>2]|0;
   HEAP32[$__b>>2] = $15;
   $17 = ($$pr|0)==(0|0);
   if ($17) {
    $25 = $15;
   } else {
    $18 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi($18|0,($$pr|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $21 = ___cxa_find_matching_catch(0|0)|0;
     $22 = tempRet0;
     ___clang_call_terminate($21);
     // unreachable;
    } else {
     $$pre = HEAP32[$__b>>2]|0;
     $25 = $$pre;
     break;
    }
   }
  }
 } while(0);
 HEAP32[$0>>2] = 3853;
 $23 = $$ >>> 2;
 $24 = (($25) + ($13<<2)|0);
 HEAP32[$__n>>2] = $24;
 $26 = HEAP32[$__b>>2]|0;
 $27 = (($26) + ($23<<2)|0);
 HEAP32[$__e>>2] = $27;
 STACKTOP = sp;return;
}
function __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grouping,$__g,$__g_end,$__err) {
 $__grouping = $__grouping|0;
 $__g = $__g|0;
 $__g_end = $__g_end|0;
 $__err = $__err|0;
 var $$012$i$i = 0, $$__ig$0 = 0, $$lcssa6 = 0, $$not = 0, $$not9 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__ig$011 = 0, $__r$012 = 0;
 var $or$cond = 0, $or$cond2 = 0, $or$cond2$lcssa = 0, $or$cond210 = 0, $or$cond213 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$__grouping>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $5 = $0&255;
  $6 = $5 >>> 1;
  $8 = $6;
 } else {
  $3 = (($__grouping) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $8 = $4;
 }
 $7 = ($8|0)==(0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $9 = ($__g|0)==($__g_end|0);
 if ($9) {
  $19 = $0;
 } else {
  $10 = (($__g_end) + -4|0);
  $11 = ($10>>>0)>($__g>>>0);
  if ($11) {
   $$012$i$i = $__g;$14 = $10;
   while(1) {
    $12 = HEAP32[$$012$i$i>>2]|0;
    $13 = HEAP32[$14>>2]|0;
    HEAP32[$$012$i$i>>2] = $13;
    HEAP32[$14>>2] = $12;
    $15 = (($$012$i$i) + 4|0);
    $16 = (($14) + -4|0);
    $17 = ($15>>>0)<($16>>>0);
    if ($17) {
     $$012$i$i = $15;$14 = $16;
    } else {
     break;
    }
   }
   $$pre = HEAP8[$__grouping>>0]|0;
   $19 = $$pre;
  } else {
   $19 = $0;
  }
 }
 $18 = $19 & 1;
 $20 = ($18<<24>>24)==(0);
 if ($20) {
  $25 = (($__grouping) + 1|0);
  $26 = $19&255;
  $27 = $26 >>> 1;
  $31 = $25;$34 = $27;
 } else {
  $21 = (($__grouping) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($__grouping) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $31 = $22;$34 = $24;
 }
 $28 = (($__g_end) + -4|0);
 $29 = ($28>>>0)>($__g>>>0);
 $30 = HEAP8[$31>>0]|0;
 $$not9 = ($30<<24>>24)<(1);
 $32 = ($30<<24>>24)==(127);
 $or$cond210 = $$not9 | $32;
 L18: do {
  if ($29) {
   $33 = (($31) + ($34)|0);
   $35 = $33;
   $37 = $30;$__ig$011 = $31;$__r$012 = $__g;$or$cond213 = $or$cond210;
   while(1) {
    if (!($or$cond213)) {
     $36 = $37 << 24 >> 24;
     $38 = HEAP32[$__r$012>>2]|0;
     $39 = ($36|0)==($38|0);
     if (!($39)) {
      break;
     }
    }
    $40 = $__ig$011;
    $41 = (($35) - ($40))|0;
    $42 = ($41|0)>(1);
    $43 = (($__ig$011) + 1|0);
    $$__ig$0 = $42 ? $43 : $__ig$011;
    $44 = (($__r$012) + 4|0);
    $45 = ($44>>>0)<($28>>>0);
    $46 = HEAP8[$$__ig$0>>0]|0;
    $$not = ($46<<24>>24)<(1);
    $47 = ($46<<24>>24)==(127);
    $or$cond2 = $$not | $47;
    if ($45) {
     $37 = $46;$__ig$011 = $$__ig$0;$__r$012 = $44;$or$cond213 = $or$cond2;
    } else {
     $$lcssa6 = $46;$or$cond2$lcssa = $or$cond2;
     break L18;
    }
   }
   HEAP32[$__err>>2] = 4;
   STACKTOP = sp;return;
  } else {
   $$lcssa6 = $30;$or$cond2$lcssa = $or$cond210;
  }
 } while(0);
 if ($or$cond2$lcssa) {
  STACKTOP = sp;return;
 }
 $48 = $$lcssa6 << 24 >> 24;
 $49 = HEAP32[$28>>2]|0;
 $50 = ($48>>>0)<($49>>>0);
 $51 = ($49|0)==(0);
 $or$cond = $50 | $51;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 HEAP32[$__err>>2] = 4;
 STACKTOP = sp;return;
}
function __ZNSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe($agg$result,$this,$__b,$__e,$__intl,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__intl = $__intl|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0 = 0, $$0$i$i$i$i = 0, $$0$i$i1$i$i = 0, $$0$lcssa$i = 0, $$01 = 0, $$01$i = 0, $$113 = 0, $$114 = 0, $$1211 = 0, $$1212 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre16 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__atoms = 0, $__loc = 0, $__nbuf = 0, $__nc$0 = 0, $__nc$1 = 0, $__nc$2$lcssa = 0, $__nc$26 = 0, $__neg = 0, $__w$07 = 0, $__wb = 0, $__wbuf = 0, $__wn = 0;
 var $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 576|0;
 $$byval_copy = sp;
 $__wbuf = sp + 64|0;
 $__wb = sp + 56|0;
 $__wn = sp + 52|0;
 $__loc = sp + 48|0;
 $__neg = sp + 564|0;
 $0 = sp + 4|0;
 $__atoms = sp + 8|0;
 $__nbuf = sp + 464|0;
 HEAP32[$__wb>>2] = $__wbuf;
 $1 = (($__wb) + 4|0);
 HEAP32[$1>>2] = 3855;
 $2 = (($__wbuf) + 400|0);
 __THREW__ = 0;
 invoke_vii(2475,($__loc|0),($__iob|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 do {
  if ($4) {
   $33 = ___cxa_find_matching_catch()|0;
   $34 = tempRet0;
   HEAP32[$__wb>>2] = 0;
   $$113 = $33;$$1211 = $34;$107 = 3855;$108 = $__wbuf;
  } else {
   __THREW__ = 0;
   $5 = (invoke_iii(2228,($__loc|0),(3093328|0))|0);
   $6 = __THREW__; __THREW__ = 0;
   $7 = $6&1;
   L3: do {
    if ($7) {
     label = 11;
    } else {
     HEAP8[$__neg>>0] = 0;
     $8 = HEAP32[$__e>>2]|0;
     HEAP32[$0>>2] = $8;
     $9 = (($__iob) + 4|0);
     $10 = HEAP32[$9>>2]|0;
     __THREW__ = 0;
     ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
     $11 = (invoke_iiiiiiiiiiii(4,($__b|0),($$byval_copy|0),($__intl|0),($__loc|0),($10|0),($__err|0),($__neg|0),($5|0),($__wb|0),($__wn|0),($2|0))|0);
     $12 = __THREW__; __THREW__ = 0;
     $13 = $12&1;
     if ($13) {
      label = 11;
     } else {
      if ($11) {
       $14 = HEAP32[$5>>2]|0;
       $15 = (($14) + 48|0);
       $16 = HEAP32[$15>>2]|0;
       __THREW__ = 0;
       (invoke_iiiii($16|0,($5|0),(3093032|0),(((3093032 + 10|0))|0),($__atoms|0))|0);
       $17 = __THREW__; __THREW__ = 0;
       $18 = $17&1;
       if ($18) {
        label = 11;
        break;
       }
       $19 = HEAP32[$__wn>>2]|0;
       $20 = HEAP32[$__wb>>2]|0;
       $21 = $19;
       $22 = $20;
       $23 = (($21) - ($22))|0;
       $24 = ($23|0)>(392);
       if ($24) {
        $25 = $23 >> 2;
        $26 = (($25) + 2)|0;
        $27 = (_malloc($26)|0);
        $28 = ($27|0)==(0|0);
        if ($28) {
         __THREW__ = 0;
         invoke_v(1012);
         $29 = __THREW__; __THREW__ = 0;
         $30 = $29&1;
         if ($30) {
          $31 = ___cxa_find_matching_catch()|0;
          $32 = tempRet0;
          $$0 = $31;$$01 = $32;
          break;
         } else {
          $39 = 0;$__nc$0 = 0;
         }
        } else {
         $39 = $27;$__nc$0 = $27;
        }
       } else {
        $39 = 0;$__nc$0 = $__nbuf;
       }
       $40 = HEAP8[$__neg>>0]|0;
       $41 = ($40<<24>>24)==(0);
       if ($41) {
        $__nc$1 = $__nc$0;
       } else {
        $42 = (($__nc$0) + 1|0);
        HEAP8[$__nc$0>>0] = 45;
        $__nc$1 = $42;
       }
       $43 = ($20>>>0)<($19>>>0);
       if ($43) {
        $44 = (($__atoms) + 40|0);
        $45 = $__atoms;
        $__nc$26 = $__nc$1;$__w$07 = $20;
        while(1) {
         $46 = HEAP32[$__w$07>>2]|0;
         $$01$i = $__atoms;
         while(1) {
          $49 = HEAP32[$$01$i>>2]|0;
          $50 = ($49|0)==($46|0);
          $48 = (($$01$i) + 4|0);
          if ($50) {
           $$0$lcssa$i = $$01$i;
           break;
          }
          $47 = ($48|0)==($44|0);
          if ($47) {
           $$0$lcssa$i = $44;
           break;
          } else {
           $$01$i = $48;
          }
         }
         $51 = $$0$lcssa$i;
         $52 = (($51) - ($45))|0;
         $53 = $52 >> 2;
         $54 = (3093032 + ($53)|0);
         $55 = HEAP8[$54>>0]|0;
         HEAP8[$__nc$26>>0] = $55;
         $56 = (($__w$07) + 4|0);
         $57 = (($__nc$26) + 1|0);
         $58 = HEAP32[$__wn>>2]|0;
         $59 = ($56>>>0)<($58>>>0);
         if ($59) {
          $__nc$26 = $57;$__w$07 = $56;
         } else {
          $__nc$2$lcssa = $57;
          break;
         }
        }
       } else {
        $__nc$2$lcssa = $__nc$1;
       }
       HEAP8[$__nc$2$lcssa>>0] = 0;
       HEAP32[$$byval_copy>>2] = $__v;
       $60 = (_sscanf($__nbuf,3092968,$$byval_copy)|0);
       $61 = ($60|0)==(1);
       if (!($61)) {
        __THREW__ = 0;
        invoke_vi(3856,(3092976|0));
        $62 = __THREW__; __THREW__ = 0;
        $63 = $62&1;
        if ($63) {
         $37 = ___cxa_find_matching_catch()|0;
         $38 = tempRet0;
         _free($39);
         $$0 = $37;$$01 = $38;
         break;
        }
       }
       _free($39);
      }
      $64 = HEAP32[$__b>>2]|0;
      $65 = ($64|0)==(0|0);
      do {
       if ($65) {
        $113 = 1;
       } else {
        $66 = (($64) + 12|0);
        $67 = HEAP32[$66>>2]|0;
        $68 = (($64) + 16|0);
        $69 = HEAP32[$68>>2]|0;
        $70 = ($67|0)==($69|0);
        if ($70) {
         $71 = HEAP32[$64>>2]|0;
         $72 = (($71) + 36|0);
         $73 = HEAP32[$72>>2]|0;
         __THREW__ = 0;
         $74 = (invoke_ii($73|0,($64|0))|0);
         $75 = __THREW__; __THREW__ = 0;
         $76 = $75&1;
         if ($76) {
          label = 11;
          break L3;
         } else {
          $$0$i$i$i$i = $74;
         }
        } else {
         $77 = HEAP32[$67>>2]|0;
         $$0$i$i$i$i = $77;
        }
        $78 = ($$0$i$i$i$i|0)==(-1);
        if ($78) {
         HEAP32[$__b>>2] = 0;
         $113 = 1;
         break;
        } else {
         $$pre$i$i$i = HEAP32[$__b>>2]|0;
         $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
         $113 = $phitmp$i$i$i;
         break;
        }
       }
      } while(0);
      $79 = HEAP32[$__e>>2]|0;
      $80 = ($79|0)==(0|0);
      do {
       if ($80) {
        label = 37;
       } else {
        $81 = (($79) + 12|0);
        $82 = HEAP32[$81>>2]|0;
        $83 = (($79) + 16|0);
        $84 = HEAP32[$83>>2]|0;
        $85 = ($82|0)==($84|0);
        if ($85) {
         $86 = HEAP32[$79>>2]|0;
         $87 = (($86) + 36|0);
         $88 = HEAP32[$87>>2]|0;
         __THREW__ = 0;
         $89 = (invoke_ii($88|0,($79|0))|0);
         $90 = __THREW__; __THREW__ = 0;
         $91 = $90&1;
         if ($91) {
          label = 11;
          break L3;
         } else {
          $$0$i$i1$i$i = $89;
         }
        } else {
         $92 = HEAP32[$82>>2]|0;
         $$0$i$i1$i$i = $92;
        }
        $93 = ($$0$i$i1$i$i|0)==(-1);
        if ($93) {
         HEAP32[$__e>>2] = 0;
         label = 37;
         break;
        } else {
         if ($113) {
          break;
         } else {
          label = 39;
          break;
         }
        }
       }
      } while(0);
      if ((label|0) == 37) {
       if ($113) {
        label = 39;
       }
      }
      if ((label|0) == 39) {
       $94 = HEAP32[$__err>>2]|0;
       $95 = $94 | 2;
       HEAP32[$__err>>2] = $95;
      }
      $96 = HEAP32[$__b>>2]|0;
      HEAP32[$agg$result>>2] = $96;
      $97 = HEAP32[$__loc>>2]|0;
      (__ZNSt3__114__shared_count16__release_sharedEv($97)|0);
      $98 = HEAP32[$__wb>>2]|0;
      HEAP32[$__wb>>2] = 0;
      $99 = ($98|0)==(0|0);
      if ($99) {
       STACKTOP = sp;return;
      }
      $100 = HEAP32[$1>>2]|0;
      __THREW__ = 0;
      invoke_vi($100|0,($98|0));
      $101 = __THREW__; __THREW__ = 0;
      $102 = $101&1;
      if ($102) {
       $103 = ___cxa_find_matching_catch(0|0)|0;
       $104 = tempRet0;
       ___clang_call_terminate($103);
       // unreachable;
      } else {
       STACKTOP = sp;return;
      }
     }
    }
   } while(0);
   if ((label|0) == 11) {
    $35 = ___cxa_find_matching_catch()|0;
    $36 = tempRet0;
    $$0 = $35;$$01 = $36;
   }
   $105 = HEAP32[$__loc>>2]|0;
   (__ZNSt3__114__shared_count16__release_sharedEv($105)|0);
   $$pre = HEAP32[$__wb>>2]|0;
   HEAP32[$__wb>>2] = 0;
   $106 = ($$pre|0)==(0|0);
   if ($106) {
    $$114 = $$0;$$1212 = $$01;
    ___resumeException($$114|0);
    // unreachable;
   } else {
    $$pre16 = HEAP32[$1>>2]|0;
    $$113 = $$0;$$1211 = $$01;$107 = $$pre16;$108 = $$pre;
    break;
   }
  }
 } while(0);
 __THREW__ = 0;
 invoke_vi($107|0,($108|0));
 $109 = __THREW__; __THREW__ = 0;
 $110 = $109&1;
 if ($110) {
  $111 = ___cxa_find_matching_catch(0|0)|0;
  $112 = tempRet0;
  ___clang_call_terminate($111);
  // unreachable;
 } else {
  $$114 = $$113;$$1212 = $$1211;
  ___resumeException($$114|0);
  // unreachable;
 }
}
function __ZNSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_($__b,$__e,$__intl,$__loc,$__flags,$__err,$__neg,$__ct,$__wb,$__wn,$__we) {
 $__b = $__b|0;
 $__e = $__e|0;
 $__intl = $__intl|0;
 $__loc = $__loc|0;
 $__flags = $__flags|0;
 $__err = $__err|0;
 $__neg = $__neg|0;
 $__ct = $__ct|0;
 $__wb = $__wb|0;
 $__wn = $__wn|0;
 $__we = $__we|0;
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i112 = 0, $$0$i$i$i$i144 = 0, $$0$i$i$i$i169 = 0, $$0$i$i$i$i18 = 0, $$0$i$i$i$i39 = 0, $$0$i$i$i$i78 = 0, $$0$i$i1$i$i = 0, $$0$i$i1$i$i118 = 0, $$0$i$i1$i$i150 = 0, $$0$i$i1$i$i175 = 0, $$0$i$i1$i$i24 = 0, $$0$i$i1$i$i45 = 0, $$0$i$i1$i$i84 = 0, $$0$i$i105 = 0, $$0$i$i108 = 0, $$0$i$i130 = 0;
 var $$0$i$i141 = 0, $$0$i$i165 = 0, $$0$i$i33 = 0, $$0$i$i37 = 0, $$0$i$i54 = 0, $$0$i$i59 = 0, $$0$i$i64 = 0, $$0$i$i72 = 0, $$0$i$i75 = 0, $$0$i$i96 = 0, $$292 = 0, $$293 = 0, $$294 = 0, $$295 = 0, $$296 = 0, $$297 = 0, $$298 = 0, $$pre = 0, $$pre$i$i$i = 0, $$pre$i$i$i114 = 0;
 var $$pre$i$i$i146 = 0, $$pre$i$i$i171 = 0, $$pre$i$i$i20 = 0, $$pre$i$i$i41 = 0, $$pre$i$i$i80 = 0, $$pre$i3$i$i = 0, $$pre$i3$i$i120 = 0, $$pre$i3$i$i152 = 0, $$pre$i3$i$i177 = 0, $$pre$i3$i$i177258 = 0, $$pre$i3$i$i177259 = 0, $$pre$i3$i$i264$ph = 0, $$pre$i3$i$i264291 = 0, $$pre$i3$i$i47 = 0, $$pre$i3$i$i47255 = 0, $$pre$i3$i$i47257 = 0, $$pre$i3$i$i86 = 0, $$pre$i3$i$i86262$ph = 0, $$pre$i3$i$i86262288 = 0, $$pre276 = 0;
 var $$pre277 = 0, $$pre278 = 0, $$pre279 = 0, $$pre280 = 0, $$pre281 = 0, $$pre282 = 0, $$pre283 = 0, $$sum = 0, $$sum284 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0;
 var $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0;
 var $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0;
 var $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0;
 var $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0;
 var $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0;
 var $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0;
 var $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0;
 var $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0;
 var $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0;
 var $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0;
 var $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0;
 var $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0;
 var $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0;
 var $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0;
 var $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0;
 var $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0;
 var $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0;
 var $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0;
 var $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0;
 var $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0;
 var $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0;
 var $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0;
 var $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0;
 var $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0;
 var $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0;
 var $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0;
 var $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0;
 var $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0;
 var $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0;
 var $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0;
 var $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0;
 var $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0;
 var $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0;
 var $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0;
 var $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0;
 var $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0;
 var $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $__dp = 0, $__et = 0, $__fd = 0, $__gb = 0, $__gbuf = 0, $__ge = 0, $__gn = 0, $__grp = 0, $__i$0 = 0, $__ng$0 = 0, $__ng$1 = 0, $__nsn = 0, $__nsn$__trailing_sign$0 = 0, $__nsn$__trailing_sign$06 = 0, $__p$0245 = 0, $__pat = 0, $__psn = 0, $__psn$__trailing_sign$0 = 0, $__psn$__trailing_sign$05 = 0;
 var $__spaces = 0, $__sym = 0, $__trailing_sign$0$lcssa = 0, $__trailing_sign$0247 = 0, $__trailing_sign$1 = 0, $__ts = 0, $brmerge = 0, $cond = 0, $lpad$phi$index = 0, $lpad$phi$index8 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond299 = 0, $or$cond7$not = 0, $or$cond8 = 0, $phitmp$i$i$i = 0, $phitmp$i$i$i115 = 0, $phitmp$i$i$i147 = 0, $phitmp$i$i$i172 = 0;
 var $phitmp$i$i$i21 = 0, $phitmp$i$i$i42 = 0, $phitmp$i$i$i81 = 0, $phitmp$i4$i$i = 0, $phitmp$i4$i$i153 = 0, $phitmp$i4$i$i178 = 0, $phitmp$i4$i$i48 = 0, $phitmp$i4$i$i87 = 0, $switch = 0, $tmp$i$i = 0, $tmp$i$i155 = 0, $tmp$i$i180 = 0, $tmp$i$i50 = 0, $tmp$i$i89 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $0 = sp + 496|0;
 $__gbuf = sp + 96|0;
 $__gb = sp + 88|0;
 $__gn = sp + 84|0;
 $__ge = sp + 80|0;
 $__pat = sp + 76|0;
 $__dp = sp + 72|0;
 $__ts = sp + 68|0;
 $__grp = sp + 52|0;
 $__sym = sp + 40|0;
 $__psn = sp + 28|0;
 $__nsn = sp + 16|0;
 $__spaces = sp + 4|0;
 $__fd = sp;
 $__et = sp + 64|0;
 HEAP32[$0>>2] = $__we;
 HEAP32[$__gb>>2] = $__gbuf;
 $1 = (($__gb) + 4|0);
 HEAP32[$1>>2] = 3855;
 HEAP32[$__gn>>2] = $__gbuf;
 $2 = (($__gbuf) + 400|0);
 HEAP32[$__ge>>2] = $2;
 HEAP32[$__pat>>2] = 0;
 ;HEAP32[$__grp+0>>2]=0|0;HEAP32[$__grp+4>>2]=0|0;HEAP32[$__grp+8>>2]=0|0;
 ;HEAP32[$__sym+0>>2]=0|0;HEAP32[$__sym+4>>2]=0|0;HEAP32[$__sym+8>>2]=0|0;
 ;HEAP32[$__psn+0>>2]=0|0;HEAP32[$__psn+4>>2]=0|0;HEAP32[$__psn+8>>2]=0|0;
 ;HEAP32[$__nsn+0>>2]=0|0;HEAP32[$__nsn+4>>2]=0|0;HEAP32[$__nsn+8>>2]=0|0;
 ;HEAP32[$__spaces+0>>2]=0|0;HEAP32[$__spaces+4>>2]=0|0;HEAP32[$__spaces+8>>2]=0|0;
 __THREW__ = 0;
 invoke_viiiiiiiiii(11,($__intl|0),($__loc|0),($__pat|0),($__dp|0),($__ts|0),($__grp|0),($__sym|0),($__psn|0),($__nsn|0),($__fd|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 L1: do {
  if ($4) {
   $66 = ___cxa_find_matching_catch()|0;
   $67 = tempRet0;
   $lpad$phi$index = $66;$lpad$phi$index8 = $67;
  } else {
   $5 = HEAP32[$__wb>>2]|0;
   HEAP32[$__wn>>2] = $5;
   $6 = (($__nsn) + 4|0);
   $7 = (($__nsn) + 8|0);
   $8 = (($__psn) + 4|0);
   $9 = (($__psn) + 8|0);
   $10 = $__flags & 512;
   $11 = ($10|0)!=(0);
   $12 = (($__sym) + 4|0);
   $13 = (($__sym) + 8|0);
   $14 = (($__spaces) + 4|0);
   $15 = (($__spaces) + 8|0);
   $16 = (($__pat) + 3|0);
   $17 = (($__grp) + 4|0);
   $853 = $__gbuf;$__p$0245 = 0;$__trailing_sign$0247 = 0;
   L4: while(1) {
    $18 = HEAP32[$__b>>2]|0;
    $19 = ($18|0)==(0|0);
    do {
     if ($19) {
      $854 = 1;
     } else {
      $20 = (($18) + 12|0);
      $21 = HEAP32[$20>>2]|0;
      $22 = (($18) + 16|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ($21|0)==($23|0);
      if ($24) {
       $25 = HEAP32[$18>>2]|0;
       $26 = (($25) + 36|0);
       $27 = HEAP32[$26>>2]|0;
       __THREW__ = 0;
       $28 = (invoke_ii($27|0,($18|0))|0);
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        label = 26;
        break L4;
       } else {
        $$0$i$i$i$i18 = $28;
       }
      } else {
       $31 = HEAP32[$21>>2]|0;
       $$0$i$i$i$i18 = $31;
      }
      $32 = ($$0$i$i$i$i18|0)==(-1);
      if ($32) {
       HEAP32[$__b>>2] = 0;
       $854 = 1;
       break;
      } else {
       $$pre$i$i$i20 = HEAP32[$__b>>2]|0;
       $phitmp$i$i$i21 = ($$pre$i$i$i20|0)==(0|0);
       $854 = $phitmp$i$i$i21;
       break;
      }
     }
    } while(0);
    $33 = HEAP32[$__e>>2]|0;
    $34 = ($33|0)==(0|0);
    do {
     if ($34) {
      label = 16;
     } else {
      $35 = (($33) + 12|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($33) + 16|0);
      $38 = HEAP32[$37>>2]|0;
      $39 = ($36|0)==($38|0);
      if ($39) {
       $40 = HEAP32[$33>>2]|0;
       $41 = (($40) + 36|0);
       $42 = HEAP32[$41>>2]|0;
       __THREW__ = 0;
       $43 = (invoke_ii($42|0,($33|0))|0);
       $44 = __THREW__; __THREW__ = 0;
       $45 = $44&1;
       if ($45) {
        label = 26;
        break L4;
       } else {
        $$0$i$i1$i$i24 = $43;
       }
      } else {
       $46 = HEAP32[$36>>2]|0;
       $$0$i$i1$i$i24 = $46;
      }
      $47 = ($$0$i$i1$i$i24|0)==(-1);
      if ($47) {
       HEAP32[$__e>>2] = 0;
       label = 16;
       break;
      } else {
       if ($854) {
        $856 = $33;
        break;
       } else {
        $841 = $853;$855 = $33;$__trailing_sign$0$lcssa = $__trailing_sign$0247;
        label = 292;
        break L4;
       }
      }
     }
    } while(0);
    if ((label|0) == 16) {
     label = 0;
     if ($854) {
      $841 = $853;$855 = 0;$__trailing_sign$0$lcssa = $__trailing_sign$0247;
      label = 292;
      break;
     } else {
      $856 = 0;
     }
    }
    $48 = (($__pat) + ($__p$0245)|0);
    $49 = HEAP8[$48>>0]|0;
    $50 = $49 << 24 >> 24;
    L28: do {
     switch ($50|0) {
     case 4:  {
      $51 = HEAP32[$__ts>>2]|0;
      $$pre$i3$i$i152 = $856;$529 = $856;$581 = $853;$__ng$0 = 0;
      L30: while(1) {
       $513 = HEAP32[$__b>>2]|0;
       $514 = ($513|0)==(0|0);
       do {
        if ($514) {
         $543 = 1;
        } else {
         $515 = (($513) + 12|0);
         $516 = HEAP32[$515>>2]|0;
         $517 = (($513) + 16|0);
         $518 = HEAP32[$517>>2]|0;
         $519 = ($516|0)==($518|0);
         if ($519) {
          $520 = HEAP32[$513>>2]|0;
          $521 = (($520) + 36|0);
          $522 = HEAP32[$521>>2]|0;
          __THREW__ = 0;
          $523 = (invoke_ii($522|0,($513|0))|0);
          $524 = __THREW__; __THREW__ = 0;
          $525 = $524&1;
          if ($525) {
           label = 21;
           break L4;
          } else {
           $$0$i$i$i$i144 = $523;
          }
         } else {
          $526 = HEAP32[$516>>2]|0;
          $$0$i$i$i$i144 = $526;
         }
         $527 = ($$0$i$i$i$i144|0)==(-1);
         if ($527) {
          HEAP32[$__b>>2] = 0;
          $543 = 1;
          break;
         } else {
          $$pre$i$i$i146 = HEAP32[$__b>>2]|0;
          $phitmp$i$i$i147 = ($$pre$i$i$i146|0)==(0|0);
          $543 = $phitmp$i$i$i147;
          break;
         }
        }
       } while(0);
       $528 = ($529|0)==(0|0);
       do {
        if ($528) {
         $862 = $$pre$i3$i$i152;
         label = 208;
        } else {
         $530 = (($529) + 12|0);
         $531 = HEAP32[$530>>2]|0;
         $532 = (($529) + 16|0);
         $533 = HEAP32[$532>>2]|0;
         $534 = ($531|0)==($533|0);
         if ($534) {
          $535 = HEAP32[$529>>2]|0;
          $536 = (($535) + 36|0);
          $537 = HEAP32[$536>>2]|0;
          __THREW__ = 0;
          $538 = (invoke_ii($537|0,($529|0))|0);
          $539 = __THREW__; __THREW__ = 0;
          $540 = $539&1;
          if ($540) {
           label = 21;
           break L4;
          } else {
           $$0$i$i1$i$i150 = $538;
          }
         } else {
          $541 = HEAP32[$531>>2]|0;
          $$0$i$i1$i$i150 = $541;
         }
         $542 = ($$0$i$i1$i$i150|0)==(-1);
         if ($542) {
          HEAP32[$__e>>2] = 0;
          $862 = 0;
          label = 208;
          break;
         } else {
          $phitmp$i4$i$i153 = ($$pre$i3$i$i152|0)==(0|0);
          $tmp$i$i155 = $543 ^ $phitmp$i4$i$i153;
          if ($tmp$i$i155) {
           $863 = $$pre$i3$i$i152;$864 = $$pre$i3$i$i152;
           break;
          } else {
           $$pre$i3$i$i120 = $$pre$i3$i$i152;
           break L30;
          }
         }
        }
       } while(0);
       if ((label|0) == 208) {
        label = 0;
        if ($543) {
         $$pre$i3$i$i120 = $862;
         break;
        } else {
         $863 = $862;$864 = 0;
        }
       }
       $544 = HEAP32[$__b>>2]|0;
       $545 = (($544) + 12|0);
       $546 = HEAP32[$545>>2]|0;
       $547 = (($544) + 16|0);
       $548 = HEAP32[$547>>2]|0;
       $549 = ($546|0)==($548|0);
       if ($549) {
        $550 = HEAP32[$544>>2]|0;
        $551 = (($550) + 36|0);
        $552 = HEAP32[$551>>2]|0;
        __THREW__ = 0;
        $553 = (invoke_ii($552|0,($544|0))|0);
        $554 = __THREW__; __THREW__ = 0;
        $555 = $554&1;
        if ($555) {
         label = 21;
         break L4;
        } else {
         $$0$i$i141 = $553;
        }
       } else {
        $556 = HEAP32[$546>>2]|0;
        $$0$i$i141 = $556;
       }
       $557 = HEAP32[$__ct>>2]|0;
       $558 = (($557) + 12|0);
       $559 = HEAP32[$558>>2]|0;
       __THREW__ = 0;
       $560 = (invoke_iiii($559|0,($__ct|0),2048,($$0$i$i141|0))|0);
       $561 = __THREW__; __THREW__ = 0;
       $562 = $561&1;
       if ($562) {
        label = 21;
        break L4;
       }
       if ($560) {
        $563 = HEAP32[$__wn>>2]|0;
        $564 = HEAP32[$0>>2]|0;
        $565 = ($563|0)==($564|0);
        if ($565) {
         __THREW__ = 0;
         invoke_viii(2131,($__wb|0),($__wn|0),($0|0));
         $566 = __THREW__; __THREW__ = 0;
         $567 = $566&1;
         if ($567) {
          label = 21;
          break L4;
         }
         $$pre282 = HEAP32[$__wn>>2]|0;
         $569 = $$pre282;
        } else {
         $569 = $563;
        }
        $568 = (($569) + 4|0);
        HEAP32[$__wn>>2] = $568;
        HEAP32[$569>>2] = $$0$i$i141;
        $570 = (($__ng$0) + 1)|0;
        $865 = $581;$__ng$1 = $570;
       } else {
        $571 = HEAP8[$__grp>>0]|0;
        $572 = $571 & 1;
        $573 = ($572<<24>>24)==(0);
        if ($573) {
         $575 = $571&255;
         $576 = $575 >>> 1;
         $577 = $576;
        } else {
         $574 = HEAP32[$17>>2]|0;
         $577 = $574;
        }
        $notlhs = ($577|0)!=(0);
        $notrhs = ($__ng$0|0)!=(0);
        $or$cond7$not = $notrhs & $notlhs;
        $578 = ($$0$i$i141|0)==($51|0);
        $or$cond299 = $or$cond7$not & $578;
        if (!($or$cond299)) {
         $$pre$i3$i$i120 = $863;
         break;
        }
        $579 = HEAP32[$__ge>>2]|0;
        $580 = ($581|0)==($579|0);
        if ($580) {
         __THREW__ = 0;
         invoke_viii(2130,($__gb|0),($__gn|0),($__ge|0));
         $582 = __THREW__; __THREW__ = 0;
         $583 = $582&1;
         if ($583) {
          label = 21;
          break L4;
         }
         $$pre283 = HEAP32[$__gn>>2]|0;
         $585 = $$pre283;
        } else {
         $585 = $581;
        }
        $584 = (($585) + 4|0);
        HEAP32[$__gn>>2] = $584;
        HEAP32[$585>>2] = $__ng$0;
        $865 = $584;$__ng$1 = 0;
       }
       $586 = HEAP32[$__b>>2]|0;
       $587 = (($586) + 12|0);
       $588 = HEAP32[$587>>2]|0;
       $589 = (($586) + 16|0);
       $590 = HEAP32[$589>>2]|0;
       $591 = ($588|0)==($590|0);
       if ($591) {
        $592 = HEAP32[$586>>2]|0;
        $593 = (($592) + 40|0);
        $594 = HEAP32[$593>>2]|0;
        __THREW__ = 0;
        (invoke_ii($594|0,($586|0))|0);
        $595 = __THREW__; __THREW__ = 0;
        $596 = $595&1;
        if ($596) {
         label = 21;
         break L4;
        } else {
         $$pre$i3$i$i152 = $863;$529 = $864;$581 = $865;$__ng$0 = $__ng$1;
         continue;
        }
       } else {
        $597 = (($588) + 4|0);
        HEAP32[$587>>2] = $597;
        $$pre$i3$i$i152 = $863;$529 = $864;$581 = $865;$__ng$0 = $__ng$1;
        continue;
       }
      }
      $598 = HEAP32[$__gb>>2]|0;
      $599 = ($598|0)==($581|0);
      $600 = ($__ng$0|0)==(0);
      $or$cond8 = $599 | $600;
      if ($or$cond8) {
       $866 = $581;
      } else {
       $601 = HEAP32[$__ge>>2]|0;
       $602 = ($581|0)==($601|0);
       if ($602) {
        __THREW__ = 0;
        invoke_viii(2130,($__gb|0),($__gn|0),($__ge|0));
        $603 = __THREW__; __THREW__ = 0;
        $604 = $603&1;
        if ($604) {
         label = 26;
         break L4;
        }
        $$pre281 = HEAP32[$__gn>>2]|0;
        $606 = $$pre281;
       } else {
        $606 = $581;
       }
       $605 = (($606) + 4|0);
       HEAP32[$__gn>>2] = $605;
       HEAP32[$606>>2] = $__ng$0;
       $866 = $605;
      }
      $607 = HEAP32[$__fd>>2]|0;
      $608 = ($607|0)>(0);
      if ($608) {
       $609 = HEAP32[$__b>>2]|0;
       $610 = ($609|0)==(0|0);
       do {
        if ($610) {
         $868 = 1;
        } else {
         $611 = (($609) + 12|0);
         $612 = HEAP32[$611>>2]|0;
         $613 = (($609) + 16|0);
         $614 = HEAP32[$613>>2]|0;
         $615 = ($612|0)==($614|0);
         if ($615) {
          $616 = HEAP32[$609>>2]|0;
          $617 = (($616) + 36|0);
          $618 = HEAP32[$617>>2]|0;
          __THREW__ = 0;
          $619 = (invoke_ii($618|0,($609|0))|0);
          $620 = __THREW__; __THREW__ = 0;
          $621 = $620&1;
          if ($621) {
           label = 26;
           break L4;
          } else {
           $$0$i$i$i$i112 = $619;
          }
         } else {
          $622 = HEAP32[$612>>2]|0;
          $$0$i$i$i$i112 = $622;
         }
         $623 = ($$0$i$i$i$i112|0)==(-1);
         if ($623) {
          HEAP32[$__b>>2] = 0;
          $868 = 1;
          break;
         } else {
          $$pre$i$i$i114 = HEAP32[$__b>>2]|0;
          $phitmp$i$i$i115 = ($$pre$i$i$i114|0)==(0|0);
          $868 = $phitmp$i$i$i115;
          break;
         }
        }
       } while(0);
       $624 = ($$pre$i3$i$i120|0)==(0|0);
       do {
        if ($624) {
         label = 249;
        } else {
         $625 = (($$pre$i3$i$i120) + 12|0);
         $626 = HEAP32[$625>>2]|0;
         $627 = (($$pre$i3$i$i120) + 16|0);
         $628 = HEAP32[$627>>2]|0;
         $629 = ($626|0)==($628|0);
         if ($629) {
          $630 = HEAP32[$$pre$i3$i$i120>>2]|0;
          $631 = (($630) + 36|0);
          $632 = HEAP32[$631>>2]|0;
          __THREW__ = 0;
          $633 = (invoke_ii($632|0,($$pre$i3$i$i120|0))|0);
          $634 = __THREW__; __THREW__ = 0;
          $635 = $634&1;
          if ($635) {
           label = 26;
           break L4;
          } else {
           $$0$i$i1$i$i118 = $633;
          }
         } else {
          $636 = HEAP32[$626>>2]|0;
          $$0$i$i1$i$i118 = $636;
         }
         $637 = ($$0$i$i1$i$i118|0)==(-1);
         if ($637) {
          HEAP32[$__e>>2] = 0;
          label = 249;
          break;
         } else {
          if ($868) {
           $869 = $$pre$i3$i$i120;
           break;
          } else {
           label = 255;
           break L4;
          }
         }
        }
       } while(0);
       if ((label|0) == 249) {
        label = 0;
        if ($868) {
         label = 255;
         break L4;
        } else {
         $869 = 0;
        }
       }
       $638 = HEAP32[$__b>>2]|0;
       $639 = (($638) + 12|0);
       $640 = HEAP32[$639>>2]|0;
       $641 = (($638) + 16|0);
       $642 = HEAP32[$641>>2]|0;
       $643 = ($640|0)==($642|0);
       if ($643) {
        $644 = HEAP32[$638>>2]|0;
        $645 = (($644) + 36|0);
        $646 = HEAP32[$645>>2]|0;
        __THREW__ = 0;
        $647 = (invoke_ii($646|0,($638|0))|0);
        $648 = __THREW__; __THREW__ = 0;
        $649 = $648&1;
        if ($649) {
         label = 26;
         break L4;
        } else {
         $$0$i$i105 = $647;
        }
       } else {
        $650 = HEAP32[$640>>2]|0;
        $$0$i$i105 = $650;
       }
       $651 = HEAP32[$__dp>>2]|0;
       $652 = ($$0$i$i105|0)==($651|0);
       if (!($652)) {
        label = 255;
        break L4;
       }
       $655 = HEAP32[$__b>>2]|0;
       $656 = (($655) + 12|0);
       $657 = HEAP32[$656>>2]|0;
       $658 = (($655) + 16|0);
       $659 = HEAP32[$658>>2]|0;
       $660 = ($657|0)==($659|0);
       if ($660) {
        $661 = HEAP32[$655>>2]|0;
        $662 = (($661) + 40|0);
        $663 = HEAP32[$662>>2]|0;
        __THREW__ = 0;
        (invoke_ii($663|0,($655|0))|0);
        $664 = __THREW__; __THREW__ = 0;
        $665 = $664&1;
        if ($665) {
         label = 26;
         break L4;
        } else {
         $$pre$i3$i$i86 = $869;$683 = $869;$740 = $607;
        }
       } else {
        $666 = (($657) + 4|0);
        HEAP32[$656>>2] = $666;
        $$pre$i3$i$i86 = $869;$683 = $869;$740 = $607;
       }
       while(1) {
        $667 = HEAP32[$__b>>2]|0;
        $668 = ($667|0)==(0|0);
        do {
         if ($668) {
          $697 = 1;
         } else {
          $669 = (($667) + 12|0);
          $670 = HEAP32[$669>>2]|0;
          $671 = (($667) + 16|0);
          $672 = HEAP32[$671>>2]|0;
          $673 = ($670|0)==($672|0);
          if ($673) {
           $674 = HEAP32[$667>>2]|0;
           $675 = (($674) + 36|0);
           $676 = HEAP32[$675>>2]|0;
           __THREW__ = 0;
           $677 = (invoke_ii($676|0,($667|0))|0);
           $678 = __THREW__; __THREW__ = 0;
           $679 = $678&1;
           if ($679) {
            label = 22;
            break L4;
           } else {
            $$0$i$i$i$i78 = $677;
           }
          } else {
           $680 = HEAP32[$670>>2]|0;
           $$0$i$i$i$i78 = $680;
          }
          $681 = ($$0$i$i$i$i78|0)==(-1);
          if ($681) {
           HEAP32[$__b>>2] = 0;
           $697 = 1;
           break;
          } else {
           $$pre$i$i$i80 = HEAP32[$__b>>2]|0;
           $phitmp$i$i$i81 = ($$pre$i$i$i80|0)==(0|0);
           $697 = $phitmp$i$i$i81;
           break;
          }
         }
        } while(0);
        $682 = ($683|0)==(0|0);
        do {
         if ($682) {
          $$pre$i3$i$i86262$ph = $$pre$i3$i$i86;
          label = 272;
         } else {
          $684 = (($683) + 12|0);
          $685 = HEAP32[$684>>2]|0;
          $686 = (($683) + 16|0);
          $687 = HEAP32[$686>>2]|0;
          $688 = ($685|0)==($687|0);
          if ($688) {
           $689 = HEAP32[$683>>2]|0;
           $690 = (($689) + 36|0);
           $691 = HEAP32[$690>>2]|0;
           __THREW__ = 0;
           $692 = (invoke_ii($691|0,($683|0))|0);
           $693 = __THREW__; __THREW__ = 0;
           $694 = $693&1;
           if ($694) {
            label = 22;
            break L4;
           } else {
            $$0$i$i1$i$i84 = $692;
           }
          } else {
           $695 = HEAP32[$685>>2]|0;
           $$0$i$i1$i$i84 = $695;
          }
          $696 = ($$0$i$i1$i$i84|0)==(-1);
          if ($696) {
           HEAP32[$__e>>2] = 0;
           $$pre$i3$i$i86262$ph = 0;
           label = 272;
           break;
          } else {
           $phitmp$i4$i$i87 = ($$pre$i3$i$i86|0)==(0|0);
           $tmp$i$i89 = $697 ^ $phitmp$i4$i$i87;
           if ($tmp$i$i89) {
            $$pre$i3$i$i86262288 = $$pre$i3$i$i86;$870 = $$pre$i3$i$i86;
            break;
           } else {
            label = 279;
            break L4;
           }
          }
         }
        } while(0);
        if ((label|0) == 272) {
         label = 0;
         if ($697) {
          label = 279;
          break L4;
         } else {
          $$pre$i3$i$i86262288 = $$pre$i3$i$i86262$ph;$870 = 0;
         }
        }
        $698 = HEAP32[$__b>>2]|0;
        $699 = (($698) + 12|0);
        $700 = HEAP32[$699>>2]|0;
        $701 = (($698) + 16|0);
        $702 = HEAP32[$701>>2]|0;
        $703 = ($700|0)==($702|0);
        if ($703) {
         $704 = HEAP32[$698>>2]|0;
         $705 = (($704) + 36|0);
         $706 = HEAP32[$705>>2]|0;
         __THREW__ = 0;
         $707 = (invoke_ii($706|0,($698|0))|0);
         $708 = __THREW__; __THREW__ = 0;
         $709 = $708&1;
         if ($709) {
          label = 22;
          break L4;
         } else {
          $$0$i$i72 = $707;
         }
        } else {
         $710 = HEAP32[$700>>2]|0;
         $$0$i$i72 = $710;
        }
        $711 = HEAP32[$__ct>>2]|0;
        $712 = (($711) + 12|0);
        $713 = HEAP32[$712>>2]|0;
        __THREW__ = 0;
        $714 = (invoke_iiii($713|0,($__ct|0),2048,($$0$i$i72|0))|0);
        $715 = __THREW__; __THREW__ = 0;
        $716 = $715&1;
        if ($716) {
         label = 22;
         break L4;
        }
        if (!($714)) {
         label = 279;
         break L4;
        }
        $719 = HEAP32[$__wn>>2]|0;
        $720 = HEAP32[$0>>2]|0;
        $721 = ($719|0)==($720|0);
        if ($721) {
         __THREW__ = 0;
         invoke_viii(2131,($__wb|0),($__wn|0),($0|0));
         $722 = __THREW__; __THREW__ = 0;
         $723 = $722&1;
         if ($723) {
          label = 22;
          break L4;
         }
        }
        $724 = HEAP32[$__b>>2]|0;
        $725 = (($724) + 12|0);
        $726 = HEAP32[$725>>2]|0;
        $727 = (($724) + 16|0);
        $728 = HEAP32[$727>>2]|0;
        $729 = ($726|0)==($728|0);
        if ($729) {
         $730 = HEAP32[$724>>2]|0;
         $731 = (($730) + 36|0);
         $732 = HEAP32[$731>>2]|0;
         __THREW__ = 0;
         $733 = (invoke_ii($732|0,($724|0))|0);
         $734 = __THREW__; __THREW__ = 0;
         $735 = $734&1;
         if ($735) {
          label = 22;
          break L4;
         } else {
          $$0$i$i64 = $733;
         }
        } else {
         $736 = HEAP32[$726>>2]|0;
         $$0$i$i64 = $736;
        }
        $737 = HEAP32[$__wn>>2]|0;
        $738 = (($737) + 4|0);
        HEAP32[$__wn>>2] = $738;
        HEAP32[$737>>2] = $$0$i$i64;
        $739 = (($740) + -1)|0;
        HEAP32[$__fd>>2] = $739;
        $741 = HEAP32[$__b>>2]|0;
        $742 = (($741) + 12|0);
        $743 = HEAP32[$742>>2]|0;
        $744 = (($741) + 16|0);
        $745 = HEAP32[$744>>2]|0;
        $746 = ($743|0)==($745|0);
        if ($746) {
         $747 = HEAP32[$741>>2]|0;
         $748 = (($747) + 40|0);
         $749 = HEAP32[$748>>2]|0;
         __THREW__ = 0;
         (invoke_ii($749|0,($741|0))|0);
         $750 = __THREW__; __THREW__ = 0;
         $751 = $750&1;
         if ($751) {
          label = 22;
          break L4;
         }
        } else {
         $753 = (($743) + 4|0);
         HEAP32[$742>>2] = $753;
        }
        $752 = ($739|0)>(0);
        if ($752) {
         $$pre$i3$i$i86 = $$pre$i3$i$i86262288;$683 = $870;$740 = $739;
        } else {
         $867 = $$pre$i3$i$i86262288;
         break;
        }
       }
      } else {
       $867 = $$pre$i3$i$i120;
      }
      $754 = HEAP32[$__wn>>2]|0;
      $755 = HEAP32[$__wb>>2]|0;
      $756 = ($754|0)==($755|0);
      if ($756) {
       label = 290;
       break L4;
      } else {
       $857 = $867;$858 = $866;$__trailing_sign$1 = $__trailing_sign$0247;
      }
      break;
     }
     case 1:  {
      $cond = ($__p$0245|0)==(3);
      if ($cond) {
       $841 = $853;$855 = $856;$__trailing_sign$0$lcssa = $__trailing_sign$0247;
       label = 292;
       break L4;
      }
      $75 = HEAP32[$__b>>2]|0;
      $76 = (($75) + 12|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($75) + 16|0);
      $79 = HEAP32[$78>>2]|0;
      $80 = ($77|0)==($79|0);
      if ($80) {
       $81 = HEAP32[$75>>2]|0;
       $82 = (($81) + 36|0);
       $83 = HEAP32[$82>>2]|0;
       __THREW__ = 0;
       $84 = (invoke_ii($83|0,($75|0))|0);
       $85 = __THREW__; __THREW__ = 0;
       $86 = $85&1;
       if ($86) {
        label = 26;
        break L4;
       } else {
        $$0$i$i33 = $84;
       }
      } else {
       $87 = HEAP32[$77>>2]|0;
       $$0$i$i33 = $87;
      }
      $88 = HEAP32[$__ct>>2]|0;
      $89 = (($88) + 12|0);
      $90 = HEAP32[$89>>2]|0;
      __THREW__ = 0;
      $91 = (invoke_iiii($90|0,($__ct|0),8192,($$0$i$i33|0))|0);
      $92 = __THREW__; __THREW__ = 0;
      $93 = $92&1;
      if ($93) {
       label = 26;
       break L4;
      }
      if (!($91)) {
       label = 42;
       break L4;
      }
      $94 = HEAP32[$__b>>2]|0;
      $95 = (($94) + 12|0);
      $96 = HEAP32[$95>>2]|0;
      $97 = (($94) + 16|0);
      $98 = HEAP32[$97>>2]|0;
      $99 = ($96|0)==($98|0);
      if ($99) {
       $100 = HEAP32[$94>>2]|0;
       $101 = (($100) + 40|0);
       $102 = HEAP32[$101>>2]|0;
       __THREW__ = 0;
       $103 = (invoke_ii($102|0,($94|0))|0);
       $104 = __THREW__; __THREW__ = 0;
       $105 = $104&1;
       if ($105) {
        label = 26;
        break L4;
       } else {
        $$0$i$i37 = $103;
       }
      } else {
       $106 = (($96) + 4|0);
       HEAP32[$95>>2] = $106;
       $107 = HEAP32[$96>>2]|0;
       $$0$i$i37 = $107;
      }
      __THREW__ = 0;
      invoke_vii(3509,($__spaces|0),($$0$i$i37|0));
      $108 = __THREW__; __THREW__ = 0;
      $109 = $108&1;
      if ($109) {
       label = 26;
       break L4;
      } else {
       label = 43;
      }
      break;
     }
     case 3:  {
      $179 = HEAP8[$__psn>>0]|0;
      $180 = $179 & 1;
      $181 = ($180<<24>>24)==(0);
      if ($181) {
       $183 = $179&255;
       $184 = $183 >>> 1;
       $194 = $184;
      } else {
       $182 = HEAP32[$8>>2]|0;
       $194 = $182;
      }
      $185 = HEAP8[$__nsn>>0]|0;
      $186 = $185 & 1;
      $187 = ($186<<24>>24)==(0);
      if ($187) {
       $189 = $185&255;
       $190 = $189 >>> 1;
       $192 = $190;
      } else {
       $188 = HEAP32[$6>>2]|0;
       $192 = $188;
      }
      $191 = (0 - ($192))|0;
      $193 = ($194|0)==($191|0);
      if ($193) {
       $857 = $856;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
      } else {
       if ($181) {
        $196 = $179&255;
        $197 = $196 >>> 1;
        $199 = $197;
       } else {
        $195 = HEAP32[$8>>2]|0;
        $199 = $195;
       }
       $198 = ($199|0)==(0);
       if (!($198)) {
        if ($187) {
         $201 = $185&255;
         $202 = $201 >>> 1;
         $204 = $202;
        } else {
         $200 = HEAP32[$6>>2]|0;
         $204 = $200;
        }
        $203 = ($204|0)==(0);
        if (!($203)) {
         $282 = HEAP32[$__b>>2]|0;
         $283 = (($282) + 12|0);
         $284 = HEAP32[$283>>2]|0;
         $285 = (($282) + 16|0);
         $286 = HEAP32[$285>>2]|0;
         $287 = ($284|0)==($286|0);
         if ($287) {
          $288 = HEAP32[$282>>2]|0;
          $289 = (($288) + 36|0);
          $290 = HEAP32[$289>>2]|0;
          __THREW__ = 0;
          $291 = (invoke_ii($290|0,($282|0))|0);
          $292 = __THREW__; __THREW__ = 0;
          $293 = $292&1;
          if ($293) {
           label = 26;
           break L4;
          }
          $$pre278 = HEAP8[$__psn>>0]|0;
          $$0$i$i108 = $291;$296 = $$pre278;
         } else {
          $294 = HEAP32[$284>>2]|0;
          $$0$i$i108 = $294;$296 = $179;
         }
         $295 = $296 & 1;
         $297 = ($295<<24>>24)==(0);
         $298 = HEAP32[$9>>2]|0;
         $$293 = $297 ? $8 : $298;
         $299 = HEAP32[$$293>>2]|0;
         $300 = ($$0$i$i108|0)==($299|0);
         $301 = HEAP32[$__b>>2]|0;
         $302 = (($301) + 12|0);
         $303 = HEAP32[$302>>2]|0;
         $304 = (($301) + 16|0);
         $305 = HEAP32[$304>>2]|0;
         $306 = ($303|0)==($305|0);
         if ($300) {
          if ($306) {
           $307 = HEAP32[$301>>2]|0;
           $308 = (($307) + 40|0);
           $309 = HEAP32[$308>>2]|0;
           __THREW__ = 0;
           (invoke_ii($309|0,($301|0))|0);
           $310 = __THREW__; __THREW__ = 0;
           $311 = $310&1;
           if ($311) {
            label = 26;
            break L4;
           }
          } else {
           $312 = (($303) + 4|0);
           HEAP32[$302>>2] = $312;
          }
          $313 = HEAP8[$__psn>>0]|0;
          $314 = $313 & 1;
          $315 = ($314<<24>>24)==(0);
          if ($315) {
           $317 = $313&255;
           $318 = $317 >>> 1;
           $320 = $318;
          } else {
           $316 = HEAP32[$8>>2]|0;
           $320 = $316;
          }
          $319 = ($320>>>0)>(1);
          $__psn$__trailing_sign$05 = $319 ? $__psn : $__trailing_sign$0247;
          $857 = $856;$858 = $853;$__trailing_sign$1 = $__psn$__trailing_sign$05;
          break L28;
         }
         if ($306) {
          $321 = HEAP32[$301>>2]|0;
          $322 = (($321) + 36|0);
          $323 = HEAP32[$322>>2]|0;
          __THREW__ = 0;
          $324 = (invoke_ii($323|0,($301|0))|0);
          $325 = __THREW__; __THREW__ = 0;
          $326 = $325&1;
          if ($326) {
           label = 26;
           break L4;
          } else {
           $$0$i$i130 = $324;
          }
         } else {
          $327 = HEAP32[$303>>2]|0;
          $$0$i$i130 = $327;
         }
         $328 = HEAP8[$__nsn>>0]|0;
         $329 = $328 & 1;
         $330 = ($329<<24>>24)==(0);
         $331 = HEAP32[$7>>2]|0;
         $$294 = $330 ? $6 : $331;
         $332 = HEAP32[$$294>>2]|0;
         $333 = ($$0$i$i130|0)==($332|0);
         if (!($333)) {
          label = 135;
          break L4;
         }
         $334 = HEAP32[$__b>>2]|0;
         $335 = (($334) + 12|0);
         $336 = HEAP32[$335>>2]|0;
         $337 = (($334) + 16|0);
         $338 = HEAP32[$337>>2]|0;
         $339 = ($336|0)==($338|0);
         if ($339) {
          $340 = HEAP32[$334>>2]|0;
          $341 = (($340) + 40|0);
          $342 = HEAP32[$341>>2]|0;
          __THREW__ = 0;
          (invoke_ii($342|0,($334|0))|0);
          $343 = __THREW__; __THREW__ = 0;
          $344 = $343&1;
          if ($344) {
           label = 26;
           break L4;
          }
         } else {
          $345 = (($336) + 4|0);
          HEAP32[$335>>2] = $345;
         }
         HEAP8[$__neg>>0] = 1;
         $346 = HEAP8[$__nsn>>0]|0;
         $347 = $346 & 1;
         $348 = ($347<<24>>24)==(0);
         if ($348) {
          $350 = $346&255;
          $351 = $350 >>> 1;
          $353 = $351;
         } else {
          $349 = HEAP32[$6>>2]|0;
          $353 = $349;
         }
         $352 = ($353>>>0)>(1);
         $__nsn$__trailing_sign$06 = $352 ? $__nsn : $__trailing_sign$0247;
         $857 = $856;$858 = $853;$__trailing_sign$1 = $__nsn$__trailing_sign$06;
         break L28;
        }
       }
       if ($181) {
        $206 = $179&255;
        $207 = $206 >>> 1;
        $209 = $207;
       } else {
        $205 = HEAP32[$8>>2]|0;
        $209 = $205;
       }
       $208 = ($209|0)==(0);
       $210 = HEAP32[$__b>>2]|0;
       $211 = (($210) + 12|0);
       $212 = HEAP32[$211>>2]|0;
       $213 = (($210) + 16|0);
       $214 = HEAP32[$213>>2]|0;
       $215 = ($212|0)==($214|0);
       if ($208) {
        if ($215) {
         $249 = HEAP32[$210>>2]|0;
         $250 = (($249) + 36|0);
         $251 = HEAP32[$250>>2]|0;
         __THREW__ = 0;
         $252 = (invoke_ii($251|0,($210|0))|0);
         $253 = __THREW__; __THREW__ = 0;
         $254 = $253&1;
         if ($254) {
          label = 26;
          break L4;
         }
         $$pre276 = HEAP8[$__nsn>>0]|0;
         $$0$i$i96 = $252;$257 = $$pre276;
        } else {
         $255 = HEAP32[$212>>2]|0;
         $$0$i$i96 = $255;$257 = $185;
        }
        $256 = $257 & 1;
        $258 = ($256<<24>>24)==(0);
        $259 = HEAP32[$7>>2]|0;
        $$292 = $258 ? $6 : $259;
        $260 = HEAP32[$$292>>2]|0;
        $261 = ($$0$i$i96|0)==($260|0);
        if (!($261)) {
         $857 = $856;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
         break L28;
        }
        $262 = HEAP32[$__b>>2]|0;
        $263 = (($262) + 12|0);
        $264 = HEAP32[$263>>2]|0;
        $265 = (($262) + 16|0);
        $266 = HEAP32[$265>>2]|0;
        $267 = ($264|0)==($266|0);
        if ($267) {
         $268 = HEAP32[$262>>2]|0;
         $269 = (($268) + 40|0);
         $270 = HEAP32[$269>>2]|0;
         __THREW__ = 0;
         (invoke_ii($270|0,($262|0))|0);
         $271 = __THREW__; __THREW__ = 0;
         $272 = $271&1;
         if ($272) {
          label = 26;
          break L4;
         }
        } else {
         $273 = (($264) + 4|0);
         HEAP32[$263>>2] = $273;
        }
        HEAP8[$__neg>>0] = 1;
        $274 = HEAP8[$__nsn>>0]|0;
        $275 = $274 & 1;
        $276 = ($275<<24>>24)==(0);
        if ($276) {
         $278 = $274&255;
         $279 = $278 >>> 1;
         $281 = $279;
        } else {
         $277 = HEAP32[$6>>2]|0;
         $281 = $277;
        }
        $280 = ($281>>>0)>(1);
        $__nsn$__trailing_sign$0 = $280 ? $__nsn : $__trailing_sign$0247;
        $857 = $856;$858 = $853;$__trailing_sign$1 = $__nsn$__trailing_sign$0;
        break L28;
       }
       if ($215) {
        $216 = HEAP32[$210>>2]|0;
        $217 = (($216) + 36|0);
        $218 = HEAP32[$217>>2]|0;
        __THREW__ = 0;
        $219 = (invoke_ii($218|0,($210|0))|0);
        $220 = __THREW__; __THREW__ = 0;
        $221 = $220&1;
        if ($221) {
         label = 26;
         break L4;
        }
        $$pre277 = HEAP8[$__psn>>0]|0;
        $$0$i$i75 = $219;$224 = $$pre277;
       } else {
        $222 = HEAP32[$212>>2]|0;
        $$0$i$i75 = $222;$224 = $179;
       }
       $223 = $224 & 1;
       $225 = ($223<<24>>24)==(0);
       $226 = HEAP32[$9>>2]|0;
       $$ = $225 ? $8 : $226;
       $227 = HEAP32[$$>>2]|0;
       $228 = ($$0$i$i75|0)==($227|0);
       if (!($228)) {
        HEAP8[$__neg>>0] = 1;
        $857 = $856;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
        break L28;
       }
       $229 = HEAP32[$__b>>2]|0;
       $230 = (($229) + 12|0);
       $231 = HEAP32[$230>>2]|0;
       $232 = (($229) + 16|0);
       $233 = HEAP32[$232>>2]|0;
       $234 = ($231|0)==($233|0);
       if ($234) {
        $235 = HEAP32[$229>>2]|0;
        $236 = (($235) + 40|0);
        $237 = HEAP32[$236>>2]|0;
        __THREW__ = 0;
        (invoke_ii($237|0,($229|0))|0);
        $238 = __THREW__; __THREW__ = 0;
        $239 = $238&1;
        if ($239) {
         label = 26;
         break L4;
        }
       } else {
        $240 = (($231) + 4|0);
        HEAP32[$230>>2] = $240;
       }
       $241 = HEAP8[$__psn>>0]|0;
       $242 = $241 & 1;
       $243 = ($242<<24>>24)==(0);
       if ($243) {
        $245 = $241&255;
        $246 = $245 >>> 1;
        $248 = $246;
       } else {
        $244 = HEAP32[$8>>2]|0;
        $248 = $244;
       }
       $247 = ($248>>>0)>(1);
       $__psn$__trailing_sign$0 = $247 ? $__psn : $__trailing_sign$0247;
       $857 = $856;$858 = $853;$__trailing_sign$1 = $__psn$__trailing_sign$0;
      }
      break;
     }
     case 0:  {
      label = 43;
      break;
     }
     case 2:  {
      $356 = ($__trailing_sign$0247|0)!=(0|0);
      $357 = ($__p$0245>>>0)<(2);
      $or$cond = $356 | $357;
      if (!($or$cond)) {
       $358 = ($__p$0245|0)==(2);
       if ($358) {
        $359 = HEAP8[$16>>0]|0;
        $360 = ($359<<24>>24)!=(0);
        $361 = $360;
       } else {
        $361 = 0;
       }
       $brmerge = $11 | $361;
       if (!($brmerge)) {
        $857 = $856;$858 = $853;$__trailing_sign$1 = 0;
        break L28;
       }
      }
      $362 = HEAP8[$__sym>>0]|0;
      $363 = $362 & 1;
      $364 = ($363<<24>>24)==(0);
      $365 = HEAP32[$13>>2]|0;
      $$295 = $364 ? $12 : $365;
      $366 = ($__p$0245|0)==(0);
      L268: do {
       if ($366) {
        $$pre$i3$i$i177 = $856;$430 = $362;$440 = $$295;$457 = $856;
       } else {
        $367 = (($__p$0245) + -1)|0;
        $368 = (($__pat) + ($367)|0);
        $369 = HEAP8[$368>>0]|0;
        $switch = ($369&255)<(2);
        if ($switch) {
         $371 = $362;$381 = $$295;
         while(1) {
          $370 = $371 & 1;
          $372 = ($370<<24>>24)==(0);
          if ($372) {
           $375 = $371&255;
           $376 = $375 >>> 1;
           $378 = $12;$379 = $376;
          } else {
           $373 = HEAP32[$13>>2]|0;
           $374 = HEAP32[$12>>2]|0;
           $378 = $373;$379 = $374;
          }
          $377 = (($378) + ($379<<2)|0);
          $380 = ($381|0)==($377|0);
          if ($380) {
           $391 = $371;
           break;
          }
          $382 = HEAP32[$381>>2]|0;
          $383 = HEAP32[$__ct>>2]|0;
          $384 = (($383) + 12|0);
          $385 = HEAP32[$384>>2]|0;
          __THREW__ = 0;
          $386 = (invoke_iiii($385|0,($__ct|0),8192,($382|0))|0);
          $387 = __THREW__; __THREW__ = 0;
          $388 = $387&1;
          if ($388) {
           label = 23;
           break L4;
          }
          if (!($386)) {
           label = 149;
           break;
          }
          $389 = (($381) + 4|0);
          $$pre279 = HEAP8[$__sym>>0]|0;
          $371 = $$pre279;$381 = $389;
         }
         if ((label|0) == 149) {
          label = 0;
          $$pre280 = HEAP8[$__sym>>0]|0;
          $391 = $$pre280;
         }
         $390 = $391 & 1;
         $392 = ($390<<24>>24)==(0);
         $393 = HEAP32[$13>>2]|0;
         $$296 = $392 ? $12 : $393;
         $394 = $381;
         $395 = $$296;
         $396 = (($394) - ($395))|0;
         $397 = $396 >> 2;
         $398 = HEAP8[$__spaces>>0]|0;
         $399 = $398 & 1;
         $400 = ($399<<24>>24)==(0);
         if ($400) {
          $402 = $398&255;
          $403 = $402 >>> 1;
          $405 = $403;
         } else {
          $401 = HEAP32[$14>>2]|0;
          $405 = $401;
         }
         $404 = ($397>>>0)>($405>>>0);
         L286: do {
          if (!($404)) {
           if ($400) {
            $409 = $398&255;
            $410 = $409 >>> 1;
            $$sum284 = (($410) - ($397))|0;
            $411 = (($14) + ($$sum284<<2)|0);
            $412 = $398&255;
            $413 = $412 >>> 1;
            $415 = $14;$416 = $413;$419 = $411;
           } else {
            $406 = HEAP32[$15>>2]|0;
            $407 = HEAP32[$14>>2]|0;
            $$sum = (($407) - ($397))|0;
            $408 = (($406) + ($$sum<<2)|0);
            $415 = $406;$416 = $407;$419 = $408;
           }
           $414 = (($415) + ($416<<2)|0);
           $417 = HEAP32[$13>>2]|0;
           $$297 = $392 ? $12 : $417;
           $418 = ($419|0)==($414|0);
           if ($418) {
            $$pre$i3$i$i177 = $856;$430 = $391;$440 = $381;$457 = $856;
            break L268;
           } else {
            $421 = $419;$423 = $$297;
           }
           while(1) {
            $420 = HEAP32[$421>>2]|0;
            $422 = HEAP32[$423>>2]|0;
            $424 = ($420|0)==($422|0);
            if (!($424)) {
             break L286;
            }
            $425 = (($421) + 4|0);
            $426 = ($425|0)==($414|0);
            if ($426) {
             $$pre$i3$i$i177 = $856;$430 = $391;$440 = $381;$457 = $856;
             break L268;
            }
            $427 = (($423) + 4|0);
            $421 = $425;$423 = $427;
           }
          }
         } while(0);
         $428 = HEAP32[$13>>2]|0;
         $$298 = $392 ? $12 : $428;
         $$pre$i3$i$i177 = $856;$430 = $391;$440 = $$298;$457 = $856;
        } else {
         $$pre$i3$i$i177 = $856;$430 = $362;$440 = $$295;$457 = $856;
        }
       }
      } while(0);
      L297: while(1) {
       $429 = $430 & 1;
       $431 = ($429<<24>>24)==(0);
       if ($431) {
        $434 = $430&255;
        $435 = $434 >>> 1;
        $437 = $12;$438 = $435;
       } else {
        $432 = HEAP32[$13>>2]|0;
        $433 = HEAP32[$12>>2]|0;
        $437 = $432;$438 = $433;
       }
       $436 = (($437) + ($438<<2)|0);
       $439 = ($440|0)==($436|0);
       if ($439) {
        $860 = $$pre$i3$i$i177;
        break;
       }
       $441 = HEAP32[$__b>>2]|0;
       $442 = ($441|0)==(0|0);
       do {
        if ($442) {
         $471 = 1;
        } else {
         $443 = (($441) + 12|0);
         $444 = HEAP32[$443>>2]|0;
         $445 = (($441) + 16|0);
         $446 = HEAP32[$445>>2]|0;
         $447 = ($444|0)==($446|0);
         if ($447) {
          $448 = HEAP32[$441>>2]|0;
          $449 = (($448) + 36|0);
          $450 = HEAP32[$449>>2]|0;
          __THREW__ = 0;
          $451 = (invoke_ii($450|0,($441|0))|0);
          $452 = __THREW__; __THREW__ = 0;
          $453 = $452&1;
          if ($453) {
           label = 24;
           break L4;
          } else {
           $$0$i$i$i$i169 = $451;
          }
         } else {
          $454 = HEAP32[$444>>2]|0;
          $$0$i$i$i$i169 = $454;
         }
         $455 = ($$0$i$i$i$i169|0)==(-1);
         if ($455) {
          HEAP32[$__b>>2] = 0;
          $471 = 1;
          break;
         } else {
          $$pre$i$i$i171 = HEAP32[$__b>>2]|0;
          $phitmp$i$i$i172 = ($$pre$i$i$i171|0)==(0|0);
          $471 = $phitmp$i$i$i172;
          break;
         }
        }
       } while(0);
       $456 = ($457|0)==(0|0);
       do {
        if ($456) {
         $$pre$i3$i$i177259 = $$pre$i3$i$i177;
         label = 179;
        } else {
         $458 = (($457) + 12|0);
         $459 = HEAP32[$458>>2]|0;
         $460 = (($457) + 16|0);
         $461 = HEAP32[$460>>2]|0;
         $462 = ($459|0)==($461|0);
         if ($462) {
          $463 = HEAP32[$457>>2]|0;
          $464 = (($463) + 36|0);
          $465 = HEAP32[$464>>2]|0;
          __THREW__ = 0;
          $466 = (invoke_ii($465|0,($457|0))|0);
          $467 = __THREW__; __THREW__ = 0;
          $468 = $467&1;
          if ($468) {
           label = 24;
           break L4;
          } else {
           $$0$i$i1$i$i175 = $466;
          }
         } else {
          $469 = HEAP32[$459>>2]|0;
          $$0$i$i1$i$i175 = $469;
         }
         $470 = ($$0$i$i1$i$i175|0)==(-1);
         if ($470) {
          HEAP32[$__e>>2] = 0;
          $$pre$i3$i$i177259 = 0;
          label = 179;
          break;
         } else {
          $phitmp$i4$i$i178 = ($$pre$i3$i$i177|0)==(0|0);
          $tmp$i$i180 = $471 ^ $phitmp$i4$i$i178;
          if ($tmp$i$i180) {
           $$pre$i3$i$i177258 = $$pre$i3$i$i177;$861 = $$pre$i3$i$i177;
           break;
          } else {
           $860 = $$pre$i3$i$i177;
           break L297;
          }
         }
        }
       } while(0);
       if ((label|0) == 179) {
        label = 0;
        if ($471) {
         $860 = $$pre$i3$i$i177259;
         break;
        } else {
         $$pre$i3$i$i177258 = $$pre$i3$i$i177259;$861 = 0;
        }
       }
       $472 = HEAP32[$__b>>2]|0;
       $473 = (($472) + 12|0);
       $474 = HEAP32[$473>>2]|0;
       $475 = (($472) + 16|0);
       $476 = HEAP32[$475>>2]|0;
       $477 = ($474|0)==($476|0);
       if ($477) {
        $478 = HEAP32[$472>>2]|0;
        $479 = (($478) + 36|0);
        $480 = HEAP32[$479>>2]|0;
        __THREW__ = 0;
        $481 = (invoke_ii($480|0,($472|0))|0);
        $482 = __THREW__; __THREW__ = 0;
        $483 = $482&1;
        if ($483) {
         label = 24;
         break L4;
        } else {
         $$0$i$i165 = $481;
        }
       } else {
        $484 = HEAP32[$474>>2]|0;
        $$0$i$i165 = $484;
       }
       $485 = HEAP32[$440>>2]|0;
       $486 = ($$0$i$i165|0)==($485|0);
       if (!($486)) {
        $860 = $$pre$i3$i$i177258;
        break;
       }
       $487 = HEAP32[$__b>>2]|0;
       $488 = (($487) + 12|0);
       $489 = HEAP32[$488>>2]|0;
       $490 = (($487) + 16|0);
       $491 = HEAP32[$490>>2]|0;
       $492 = ($489|0)==($491|0);
       if ($492) {
        $493 = HEAP32[$487>>2]|0;
        $494 = (($493) + 40|0);
        $495 = HEAP32[$494>>2]|0;
        __THREW__ = 0;
        (invoke_ii($495|0,($487|0))|0);
        $496 = __THREW__; __THREW__ = 0;
        $497 = $496&1;
        if ($497) {
         label = 24;
         break L4;
        }
       } else {
        $498 = (($489) + 4|0);
        HEAP32[$488>>2] = $498;
       }
       $499 = (($440) + 4|0);
       $$pre = HEAP8[$__sym>>0]|0;
       $$pre$i3$i$i177 = $$pre$i3$i$i177258;$430 = $$pre;$440 = $499;$457 = $861;
      }
      if ($11) {
       $500 = HEAP8[$__sym>>0]|0;
       $501 = $500 & 1;
       $502 = ($501<<24>>24)==(0);
       if ($502) {
        $505 = $500&255;
        $506 = $505 >>> 1;
        $508 = $12;$509 = $506;
       } else {
        $503 = HEAP32[$13>>2]|0;
        $504 = HEAP32[$12>>2]|0;
        $508 = $503;$509 = $504;
       }
       $507 = (($508) + ($509<<2)|0);
       $510 = ($440|0)==($507|0);
       if ($510) {
        $857 = $860;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
       } else {
        label = 194;
        break L4;
       }
      } else {
       $857 = $860;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
      }
      break;
     }
     default: {
      $857 = $856;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
     }
     }
    } while(0);
    L341: do {
     if ((label|0) == 43) {
      label = 0;
      $112 = ($__p$0245|0)==(3);
      if ($112) {
       $841 = $853;$855 = $856;$__trailing_sign$0$lcssa = $__trailing_sign$0247;
       label = 292;
       break L4;
      } else {
       $$pre$i3$i$i47 = $856;$129 = $856;
      }
      while(1) {
       $113 = HEAP32[$__b>>2]|0;
       $114 = ($113|0)==(0|0);
       do {
        if ($114) {
         $143 = 1;
        } else {
         $115 = (($113) + 12|0);
         $116 = HEAP32[$115>>2]|0;
         $117 = (($113) + 16|0);
         $118 = HEAP32[$117>>2]|0;
         $119 = ($116|0)==($118|0);
         if ($119) {
          $120 = HEAP32[$113>>2]|0;
          $121 = (($120) + 36|0);
          $122 = HEAP32[$121>>2]|0;
          __THREW__ = 0;
          $123 = (invoke_ii($122|0,($113|0))|0);
          $124 = __THREW__; __THREW__ = 0;
          $125 = $124&1;
          if ($125) {
           label = 25;
           break L4;
          } else {
           $$0$i$i$i$i39 = $123;
          }
         } else {
          $126 = HEAP32[$116>>2]|0;
          $$0$i$i$i$i39 = $126;
         }
         $127 = ($$0$i$i$i$i39|0)==(-1);
         if ($127) {
          HEAP32[$__b>>2] = 0;
          $143 = 1;
          break;
         } else {
          $$pre$i$i$i41 = HEAP32[$__b>>2]|0;
          $phitmp$i$i$i42 = ($$pre$i$i$i41|0)==(0|0);
          $143 = $phitmp$i$i$i42;
          break;
         }
        }
       } while(0);
       $128 = ($129|0)==(0|0);
       do {
        if ($128) {
         $$pre$i3$i$i47255 = $$pre$i3$i$i47;
         label = 57;
        } else {
         $130 = (($129) + 12|0);
         $131 = HEAP32[$130>>2]|0;
         $132 = (($129) + 16|0);
         $133 = HEAP32[$132>>2]|0;
         $134 = ($131|0)==($133|0);
         if ($134) {
          $135 = HEAP32[$129>>2]|0;
          $136 = (($135) + 36|0);
          $137 = HEAP32[$136>>2]|0;
          __THREW__ = 0;
          $138 = (invoke_ii($137|0,($129|0))|0);
          $139 = __THREW__; __THREW__ = 0;
          $140 = $139&1;
          if ($140) {
           label = 25;
           break L4;
          } else {
           $$0$i$i1$i$i45 = $138;
          }
         } else {
          $141 = HEAP32[$131>>2]|0;
          $$0$i$i1$i$i45 = $141;
         }
         $142 = ($$0$i$i1$i$i45|0)==(-1);
         if ($142) {
          HEAP32[$__e>>2] = 0;
          $$pre$i3$i$i47255 = 0;
          label = 57;
          break;
         } else {
          $phitmp$i4$i$i48 = ($$pre$i3$i$i47|0)==(0|0);
          $tmp$i$i50 = $143 ^ $phitmp$i4$i$i48;
          if ($tmp$i$i50) {
           $$pre$i3$i$i47257 = $$pre$i3$i$i47;$859 = $$pre$i3$i$i47;
           break;
          } else {
           $857 = $$pre$i3$i$i47;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
           break L341;
          }
         }
        }
       } while(0);
       if ((label|0) == 57) {
        label = 0;
        if ($143) {
         $857 = $$pre$i3$i$i47255;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
         break L341;
        } else {
         $$pre$i3$i$i47257 = $$pre$i3$i$i47255;$859 = 0;
        }
       }
       $144 = HEAP32[$__b>>2]|0;
       $145 = (($144) + 12|0);
       $146 = HEAP32[$145>>2]|0;
       $147 = (($144) + 16|0);
       $148 = HEAP32[$147>>2]|0;
       $149 = ($146|0)==($148|0);
       if ($149) {
        $150 = HEAP32[$144>>2]|0;
        $151 = (($150) + 36|0);
        $152 = HEAP32[$151>>2]|0;
        __THREW__ = 0;
        $153 = (invoke_ii($152|0,($144|0))|0);
        $154 = __THREW__; __THREW__ = 0;
        $155 = $154&1;
        if ($155) {
         label = 25;
         break L4;
        } else {
         $$0$i$i54 = $153;
        }
       } else {
        $156 = HEAP32[$146>>2]|0;
        $$0$i$i54 = $156;
       }
       $157 = HEAP32[$__ct>>2]|0;
       $158 = (($157) + 12|0);
       $159 = HEAP32[$158>>2]|0;
       __THREW__ = 0;
       $160 = (invoke_iiii($159|0,($__ct|0),8192,($$0$i$i54|0))|0);
       $161 = __THREW__; __THREW__ = 0;
       $162 = $161&1;
       if ($162) {
        label = 25;
        break L4;
       }
       if (!($160)) {
        $857 = $$pre$i3$i$i47257;$858 = $853;$__trailing_sign$1 = $__trailing_sign$0247;
        break L341;
       }
       $163 = HEAP32[$__b>>2]|0;
       $164 = (($163) + 12|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = (($163) + 16|0);
       $167 = HEAP32[$166>>2]|0;
       $168 = ($165|0)==($167|0);
       if ($168) {
        $169 = HEAP32[$163>>2]|0;
        $170 = (($169) + 40|0);
        $171 = HEAP32[$170>>2]|0;
        __THREW__ = 0;
        $172 = (invoke_ii($171|0,($163|0))|0);
        $173 = __THREW__; __THREW__ = 0;
        $174 = $173&1;
        if ($174) {
         label = 25;
         break L4;
        } else {
         $$0$i$i59 = $172;
        }
       } else {
        $175 = (($165) + 4|0);
        HEAP32[$164>>2] = $175;
        $176 = HEAP32[$165>>2]|0;
        $$0$i$i59 = $176;
       }
       __THREW__ = 0;
       invoke_vii(3509,($__spaces|0),($$0$i$i59|0));
       $177 = __THREW__; __THREW__ = 0;
       $178 = $177&1;
       if ($178) {
        label = 25;
        break L4;
       } else {
        $$pre$i3$i$i47 = $$pre$i3$i$i47257;$129 = $859;
       }
      }
     }
    } while(0);
    $759 = (($__p$0245) + 1)|0;
    $760 = ($759>>>0)<(4);
    if ($760) {
     $853 = $858;$__p$0245 = $759;$__trailing_sign$0247 = $__trailing_sign$1;
    } else {
     $841 = $858;$855 = $857;$__trailing_sign$0$lcssa = $__trailing_sign$1;
     label = 292;
     break;
    }
   }
   L378:    switch (label|0) {
    case 21: {
     $54 = ___cxa_find_matching_catch()|0;
     $55 = tempRet0;
     $lpad$phi$index = $54;$lpad$phi$index8 = $55;
     break L1;
     break;
    }
    case 22: {
     $56 = ___cxa_find_matching_catch()|0;
     $57 = tempRet0;
     $lpad$phi$index = $56;$lpad$phi$index8 = $57;
     break L1;
     break;
    }
    case 23: {
     $58 = ___cxa_find_matching_catch()|0;
     $59 = tempRet0;
     $lpad$phi$index = $58;$lpad$phi$index8 = $59;
     break L1;
     break;
    }
    case 24: {
     $60 = ___cxa_find_matching_catch()|0;
     $61 = tempRet0;
     $lpad$phi$index = $60;$lpad$phi$index8 = $61;
     break L1;
     break;
    }
    case 25: {
     $62 = ___cxa_find_matching_catch()|0;
     $63 = tempRet0;
     $lpad$phi$index = $62;$lpad$phi$index8 = $63;
     break L1;
     break;
    }
    case 26: {
     $64 = ___cxa_find_matching_catch()|0;
     $65 = tempRet0;
     $lpad$phi$index = $64;$lpad$phi$index8 = $65;
     break L1;
     break;
    }
    case 42: {
     $110 = HEAP32[$__err>>2]|0;
     $111 = $110 | 4;
     HEAP32[$__err>>2] = $111;
     $$0 = 0;
     break;
    }
    case 135: {
     $354 = HEAP32[$__err>>2]|0;
     $355 = $354 | 4;
     HEAP32[$__err>>2] = $355;
     $$0 = 0;
     break;
    }
    case 194: {
     $511 = HEAP32[$__err>>2]|0;
     $512 = $511 | 4;
     HEAP32[$__err>>2] = $512;
     $$0 = 0;
     break;
    }
    case 255: {
     $653 = HEAP32[$__err>>2]|0;
     $654 = $653 | 4;
     HEAP32[$__err>>2] = $654;
     $$0 = 0;
     break;
    }
    case 279: {
     $717 = HEAP32[$__err>>2]|0;
     $718 = $717 | 4;
     HEAP32[$__err>>2] = $718;
     $$0 = 0;
     break;
    }
    case 290: {
     $757 = HEAP32[$__err>>2]|0;
     $758 = $757 | 4;
     HEAP32[$__err>>2] = $758;
     $$0 = 0;
     break;
    }
    case 292: {
     $761 = ($__trailing_sign$0$lcssa|0)==(0|0);
     L383: do {
      if (!($761)) {
       $762 = (($__trailing_sign$0$lcssa) + 4|0);
       $763 = (($__trailing_sign$0$lcssa) + 8|0);
       $$pre$i3$i$i = $855;$788 = $855;$__i$0 = 1;
       L385: while(1) {
        $764 = HEAP8[$__trailing_sign$0$lcssa>>0]|0;
        $765 = $764 & 1;
        $766 = ($765<<24>>24)==(0);
        if ($766) {
         $768 = $764&255;
         $769 = $768 >>> 1;
         $771 = $769;
        } else {
         $767 = HEAP32[$762>>2]|0;
         $771 = $767;
        }
        $770 = ($__i$0>>>0)<($771>>>0);
        if (!($770)) {
         break L383;
        }
        $772 = HEAP32[$__b>>2]|0;
        $773 = ($772|0)==(0|0);
        do {
         if ($773) {
          $802 = 1;
         } else {
          $774 = (($772) + 12|0);
          $775 = HEAP32[$774>>2]|0;
          $776 = (($772) + 16|0);
          $777 = HEAP32[$776>>2]|0;
          $778 = ($775|0)==($777|0);
          if ($778) {
           $779 = HEAP32[$772>>2]|0;
           $780 = (($779) + 36|0);
           $781 = HEAP32[$780>>2]|0;
           __THREW__ = 0;
           $782 = (invoke_ii($781|0,($772|0))|0);
           $783 = __THREW__; __THREW__ = 0;
           $784 = $783&1;
           if ($784) {
            label = 20;
            break L385;
           } else {
            $$0$i$i$i$i = $782;
           }
          } else {
           $785 = HEAP32[$775>>2]|0;
           $$0$i$i$i$i = $785;
          }
          $786 = ($$0$i$i$i$i|0)==(-1);
          if ($786) {
           HEAP32[$__b>>2] = 0;
           $802 = 1;
           break;
          } else {
           $$pre$i$i$i = HEAP32[$__b>>2]|0;
           $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
           $802 = $phitmp$i$i$i;
           break;
          }
         }
        } while(0);
        $787 = ($788|0)==(0|0);
        do {
         if ($787) {
          $$pre$i3$i$i264$ph = $$pre$i3$i$i;
          label = 311;
         } else {
          $789 = (($788) + 12|0);
          $790 = HEAP32[$789>>2]|0;
          $791 = (($788) + 16|0);
          $792 = HEAP32[$791>>2]|0;
          $793 = ($790|0)==($792|0);
          if ($793) {
           $794 = HEAP32[$788>>2]|0;
           $795 = (($794) + 36|0);
           $796 = HEAP32[$795>>2]|0;
           __THREW__ = 0;
           $797 = (invoke_ii($796|0,($788|0))|0);
           $798 = __THREW__; __THREW__ = 0;
           $799 = $798&1;
           if ($799) {
            label = 20;
            break L385;
           } else {
            $$0$i$i1$i$i = $797;
           }
          } else {
           $800 = HEAP32[$790>>2]|0;
           $$0$i$i1$i$i = $800;
          }
          $801 = ($$0$i$i1$i$i|0)==(-1);
          if ($801) {
           HEAP32[$__e>>2] = 0;
           $$pre$i3$i$i264$ph = 0;
           label = 311;
           break;
          } else {
           $phitmp$i4$i$i = ($$pre$i3$i$i|0)==(0|0);
           $tmp$i$i = $802 ^ $phitmp$i4$i$i;
           if ($tmp$i$i) {
            $$pre$i3$i$i264291 = $$pre$i3$i$i;$871 = $$pre$i3$i$i;
            break;
           } else {
            label = 319;
            break L385;
           }
          }
         }
        } while(0);
        if ((label|0) == 311) {
         label = 0;
         if ($802) {
          label = 319;
          break;
         } else {
          $$pre$i3$i$i264291 = $$pre$i3$i$i264$ph;$871 = 0;
         }
        }
        $803 = HEAP32[$__b>>2]|0;
        $804 = (($803) + 12|0);
        $805 = HEAP32[$804>>2]|0;
        $806 = (($803) + 16|0);
        $807 = HEAP32[$806>>2]|0;
        $808 = ($805|0)==($807|0);
        if ($808) {
         $809 = HEAP32[$803>>2]|0;
         $810 = (($809) + 36|0);
         $811 = HEAP32[$810>>2]|0;
         __THREW__ = 0;
         $812 = (invoke_ii($811|0,($803|0))|0);
         $813 = __THREW__; __THREW__ = 0;
         $814 = $813&1;
         if ($814) {
          label = 20;
          break;
         } else {
          $$0$i$i = $812;
         }
        } else {
         $815 = HEAP32[$805>>2]|0;
         $$0$i$i = $815;
        }
        $816 = HEAP8[$__trailing_sign$0$lcssa>>0]|0;
        $817 = $816 & 1;
        $818 = ($817<<24>>24)==(0);
        if ($818) {
         $821 = $762;
        } else {
         $819 = HEAP32[$763>>2]|0;
         $821 = $819;
        }
        $820 = (($821) + ($__i$0<<2)|0);
        $822 = HEAP32[$820>>2]|0;
        $823 = ($$0$i$i|0)==($822|0);
        if (!($823)) {
         label = 319;
         break;
        }
        $826 = (($__i$0) + 1)|0;
        $827 = HEAP32[$__b>>2]|0;
        $828 = (($827) + 12|0);
        $829 = HEAP32[$828>>2]|0;
        $830 = (($827) + 16|0);
        $831 = HEAP32[$830>>2]|0;
        $832 = ($829|0)==($831|0);
        if ($832) {
         $833 = HEAP32[$827>>2]|0;
         $834 = (($833) + 40|0);
         $835 = HEAP32[$834>>2]|0;
         __THREW__ = 0;
         (invoke_ii($835|0,($827|0))|0);
         $836 = __THREW__; __THREW__ = 0;
         $837 = $836&1;
         if ($837) {
          label = 20;
          break;
         } else {
          $$pre$i3$i$i = $$pre$i3$i$i264291;$788 = $871;$__i$0 = $826;
          continue;
         }
        } else {
         $838 = (($829) + 4|0);
         HEAP32[$828>>2] = $838;
         $$pre$i3$i$i = $$pre$i3$i$i264291;$788 = $871;$__i$0 = $826;
         continue;
        }
       }
       if ((label|0) == 20) {
        $52 = ___cxa_find_matching_catch()|0;
        $53 = tempRet0;
        $lpad$phi$index = $52;$lpad$phi$index8 = $53;
        break L1;
       }
       else if ((label|0) == 319) {
        $824 = HEAP32[$__err>>2]|0;
        $825 = $824 | 4;
        HEAP32[$__err>>2] = $825;
        $$0 = 0;
        break L378;
       }
      }
     } while(0);
     $839 = HEAP32[$__gb>>2]|0;
     $840 = ($839|0)==($841|0);
     if ($840) {
      $$0 = 1;
     } else {
      HEAP32[$__et>>2] = 0;
      __ZNSt3__116__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj($__grp,$839,$841,$__et);
      $842 = HEAP32[$__et>>2]|0;
      $843 = ($842|0)==(0);
      if ($843) {
       $$0 = 1;
      } else {
       $844 = HEAP32[$__err>>2]|0;
       $845 = $844 | 4;
       HEAP32[$__err>>2] = $845;
       $$0 = 0;
      }
     }
     break;
    }
   }
   __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__spaces);
   __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__nsn);
   __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__psn);
   __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sym);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
   $846 = HEAP32[$__gb>>2]|0;
   HEAP32[$__gb>>2] = 0;
   $847 = ($846|0)==(0|0);
   if ($847) {
    STACKTOP = sp;return ($$0|0);
   }
   $848 = HEAP32[$1>>2]|0;
   __THREW__ = 0;
   invoke_vi($848|0,($846|0));
   $849 = __THREW__; __THREW__ = 0;
   $850 = $849&1;
   if ($850) {
    $851 = ___cxa_find_matching_catch(0|0)|0;
    $852 = tempRet0;
    ___clang_call_terminate($851);
    // unreachable;
   } else {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__spaces);
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__nsn);
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__psn);
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sym);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
 $68 = HEAP32[$__gb>>2]|0;
 HEAP32[$__gb>>2] = 0;
 $69 = ($68|0)==(0|0);
 if ($69) {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 $70 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($70|0,($68|0));
 $71 = __THREW__; __THREW__ = 0;
 $72 = $71&1;
 if ($72) {
  $73 = ___cxa_find_matching_catch(0|0)|0;
  $74 = tempRet0;
  ___clang_call_terminate($73);
  // unreachable;
 } else {
  ___resumeException($lpad$phi$index|0);
  // unreachable;
 }
 return 0|0;
}
function __ZNKSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE($agg$result,$this,$__b,$__e,$__intl,$__iob,$__err,$__v) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__b = $__b|0;
 $__e = $__e|0;
 $__intl = $__intl|0;
 $__iob = $__iob|0;
 $__err = $__err|0;
 $__v = $__v|0;
 var $$0$i$i$i$i = 0, $$0$i$i1$i$i = 0, $$0112 = 0, $$0113 = 0, $$014 = 0, $$015 = 0, $$byval_copy = 0, $$pre = 0, $$pre$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__loc = 0, $__neg = 0, $__w$0$lcssa = 0, $__w$05 = 0, $__wb = 0, $__wbuf = 0, $__wn = 0, $phitmp$i$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 432|0;
 $$byval_copy = sp + 420|0;
 $__wbuf = sp;
 $__wb = sp + 400|0;
 $__wn = sp + 408|0;
 $__loc = sp + 412|0;
 $__neg = sp + 424|0;
 $0 = sp + 416|0;
 HEAP32[$__wb>>2] = $__wbuf;
 $1 = (($__wb) + 4|0);
 HEAP32[$1>>2] = 3855;
 $2 = (($__wbuf) + 400|0);
 __THREW__ = 0;
 invoke_vii(2475,($__loc|0),($__iob|0));
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $31 = ___cxa_find_matching_catch()|0;
  $32 = tempRet0;
  HEAP32[$__wb>>2] = 0;
  $$0112 = $32;$$014 = $31;$94 = $__wbuf;
 } else {
  __THREW__ = 0;
  $5 = (invoke_iii(2228,($__loc|0),(3093328|0))|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  L4: do {
   if (!($7)) {
    HEAP8[$__neg>>0] = 0;
    $8 = HEAP32[$__e>>2]|0;
    HEAP32[$0>>2] = $8;
    $9 = (($__iob) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    __THREW__ = 0;
    ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
    $11 = (invoke_iiiiiiiiiiii(4,($__b|0),($$byval_copy|0),($__intl|0),($__loc|0),($10|0),($__err|0),($__neg|0),($5|0),($__wb|0),($__wn|0),($2|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     if ($11) {
      $14 = HEAP8[$__v>>0]|0;
      $15 = $14 & 1;
      $16 = ($15<<24>>24)==(0);
      if ($16) {
       $20 = (($__v) + 4|0);
       HEAP32[$20>>2] = 0;
       HEAP8[$__v>>0] = 0;
      } else {
       $17 = (($__v) + 8|0);
       $18 = HEAP32[$17>>2]|0;
       HEAP32[$18>>2] = 0;
       $19 = (($__v) + 4|0);
       HEAP32[$19>>2] = 0;
      }
      $21 = HEAP8[$__neg>>0]|0;
      $22 = ($21<<24>>24)==(0);
      if (!($22)) {
       $23 = HEAP32[$5>>2]|0;
       $24 = (($23) + 44|0);
       $25 = HEAP32[$24>>2]|0;
       __THREW__ = 0;
       $26 = (invoke_iii($25|0,($5|0),45)|0);
       $27 = __THREW__; __THREW__ = 0;
       $28 = $27&1;
       if ($28) {
        break;
       }
       __THREW__ = 0;
       invoke_vii(3509,($__v|0),($26|0));
       $29 = __THREW__; __THREW__ = 0;
       $30 = $29&1;
       if ($30) {
        break;
       }
      }
      $33 = HEAP32[$5>>2]|0;
      $34 = (($33) + 44|0);
      $35 = HEAP32[$34>>2]|0;
      __THREW__ = 0;
      $36 = (invoke_iii($35|0,($5|0),48)|0);
      $37 = __THREW__; __THREW__ = 0;
      $38 = $37&1;
      if ($38) {
       break;
      }
      $39 = HEAP32[$__wb>>2]|0;
      $40 = HEAP32[$__wn>>2]|0;
      $41 = (($40) + -4|0);
      $42 = ($39>>>0)<($41>>>0);
      L18: do {
       if ($42) {
        $__w$05 = $39;
        while(1) {
         $45 = HEAP32[$__w$05>>2]|0;
         $46 = ($45|0)==($36|0);
         $44 = (($__w$05) + 4|0);
         if (!($46)) {
          $__w$0$lcssa = $__w$05;
          break L18;
         }
         $43 = ($44>>>0)<($41>>>0);
         if ($43) {
          $__w$05 = $44;
         } else {
          $__w$0$lcssa = $44;
          break;
         }
        }
       } else {
        $__w$0$lcssa = $39;
       }
      } while(0);
      __THREW__ = 0;
      (invoke_iiii(1685,($__v|0),($__w$0$lcssa|0),($40|0))|0);
      $47 = __THREW__; __THREW__ = 0;
      $48 = $47&1;
      if ($48) {
       break;
      }
     }
     $49 = HEAP32[$__b>>2]|0;
     $50 = ($49|0)==(0|0);
     do {
      if ($50) {
       $99 = 1;
      } else {
       $51 = (($49) + 12|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = (($49) + 16|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = ($52|0)==($54|0);
       if ($55) {
        $56 = HEAP32[$49>>2]|0;
        $57 = (($56) + 36|0);
        $58 = HEAP32[$57>>2]|0;
        __THREW__ = 0;
        $59 = (invoke_ii($58|0,($49|0))|0);
        $60 = __THREW__; __THREW__ = 0;
        $61 = $60&1;
        if ($61) {
         break L4;
        } else {
         $$0$i$i$i$i = $59;
        }
       } else {
        $62 = HEAP32[$52>>2]|0;
        $$0$i$i$i$i = $62;
       }
       $63 = ($$0$i$i$i$i|0)==(-1);
       if ($63) {
        HEAP32[$__b>>2] = 0;
        $99 = 1;
        break;
       } else {
        $$pre$i$i$i = HEAP32[$__b>>2]|0;
        $phitmp$i$i$i = ($$pre$i$i$i|0)==(0|0);
        $99 = $phitmp$i$i$i;
        break;
       }
      }
     } while(0);
     $64 = ($8|0)==(0|0);
     do {
      if ($64) {
       label = 30;
      } else {
       $65 = (($8) + 12|0);
       $66 = HEAP32[$65>>2]|0;
       $67 = (($8) + 16|0);
       $68 = HEAP32[$67>>2]|0;
       $69 = ($66|0)==($68|0);
       if ($69) {
        $70 = HEAP32[$8>>2]|0;
        $71 = (($70) + 36|0);
        $72 = HEAP32[$71>>2]|0;
        __THREW__ = 0;
        $73 = (invoke_ii($72|0,($8|0))|0);
        $74 = __THREW__; __THREW__ = 0;
        $75 = $74&1;
        if ($75) {
         break L4;
        } else {
         $$0$i$i1$i$i = $73;
        }
       } else {
        $76 = HEAP32[$66>>2]|0;
        $$0$i$i1$i$i = $76;
       }
       $77 = ($$0$i$i1$i$i|0)==(-1);
       if ($77) {
        HEAP32[$__e>>2] = 0;
        label = 30;
        break;
       } else {
        if ($99) {
         break;
        } else {
         label = 32;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 30) {
      if ($99) {
       label = 32;
      }
     }
     if ((label|0) == 32) {
      $78 = HEAP32[$__err>>2]|0;
      $79 = $78 | 2;
      HEAP32[$__err>>2] = $79;
     }
     $80 = HEAP32[$__b>>2]|0;
     HEAP32[$agg$result>>2] = $80;
     $81 = HEAP32[$__loc>>2]|0;
     (__ZNSt3__114__shared_count16__release_sharedEv($81)|0);
     $82 = HEAP32[$__wb>>2]|0;
     HEAP32[$__wb>>2] = 0;
     $83 = ($82|0)==(0|0);
     if ($83) {
      STACKTOP = sp;return;
     }
     $84 = HEAP32[$1>>2]|0;
     __THREW__ = 0;
     invoke_vi($84|0,($82|0));
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $87 = ___cxa_find_matching_catch(0|0)|0;
      $88 = tempRet0;
      ___clang_call_terminate($87);
      // unreachable;
     } else {
      STACKTOP = sp;return;
     }
    }
   }
  } while(0);
  $89 = ___cxa_find_matching_catch()|0;
  $90 = tempRet0;
  $91 = HEAP32[$__loc>>2]|0;
  (__ZNSt3__114__shared_count16__release_sharedEv($91)|0);
  $$pre = HEAP32[$__wb>>2]|0;
  HEAP32[$__wb>>2] = 0;
  $92 = ($$pre|0)==(0|0);
  if ($92) {
   $$0113 = $90;$$015 = $89;
   ___resumeException($$015|0);
   // unreachable;
  } else {
   $$0112 = $90;$$014 = $89;$94 = $$pre;
  }
 }
 $93 = HEAP32[$1>>2]|0;
 __THREW__ = 0;
 invoke_vi($93|0,($94|0));
 $95 = __THREW__; __THREW__ = 0;
 $96 = $95&1;
 if ($96) {
  $97 = ___cxa_find_matching_catch(0|0)|0;
  $98 = tempRet0;
  ___clang_call_terminate($97);
  // unreachable;
 } else {
  $$0113 = $$0112;$$015 = $$014;
  ___resumeException($$015|0);
  // unreachable;
 }
}
function __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeES9_S9_($this,$__first,$__last) {
 $this = $this|0;
 $__first = $__first|0;
 $__last = $__last|0;
 var $$01 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$0$lcssa = 0, $__p$02 = 0, $phitmp$i = 0, $scevgep = 0, $scevgep5 = 0, $uglygep = 0, $uglygep4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__first;
 $1 = HEAP8[$this>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $4 = $1&255;
  $5 = $4 >>> 1;
  $16 = 1;$17 = $5;$45 = $1;
 } else {
  $6 = (($this) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$this>>2]|0;
  $9 = $8 & -2;
  $phitmp$i = (($9) + -1)|0;
  $10 = $8&255;
  $16 = $phitmp$i;$17 = $7;$45 = $10;
 }
 $11 = $__last;
 $12 = (($11) - ($0))|0;
 $13 = $12 >> 2;
 $14 = ($13|0)==(0);
 if ($14) {
  STACKTOP = sp;return ($this|0);
 }
 $15 = (($16) - ($17))|0;
 $18 = ($15>>>0)<($13>>>0);
 if ($18) {
  $19 = (($17) + ($13))|0;
  $20 = (($19) - ($16))|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEjjjjjj($this,$16,$20,$17,$17,0,0);
  $$pre = HEAP8[$this>>0]|0;
  $22 = $$pre;
 } else {
  $22 = $45;
 }
 $21 = $22 & 1;
 $23 = ($21<<24>>24)==(0);
 if ($23) {
  $26 = (($this) + 4|0);
  $28 = $26;
 } else {
  $24 = (($this) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $28 = $25;
 }
 $27 = (($28) + ($17<<2)|0);
 $29 = ($__first|0)==($__last|0);
 if ($29) {
  $__p$0$lcssa = $27;
 } else {
  $scevgep = (($__last) + -4|0);
  $30 = (0 - ($0))|0;
  $uglygep = (($scevgep) + ($30)|0);
  $uglygep4 = $uglygep;
  $31 = $uglygep4 >>> 2;
  $32 = (($17) + ($31))|0;
  $33 = (($32) + 1)|0;
  $$01 = $__first;$__p$02 = $27;
  while(1) {
   $34 = HEAP32[$$01>>2]|0;
   HEAP32[$__p$02>>2] = $34;
   $35 = (($__p$02) + 4|0);
   $36 = (($$01) + 4|0);
   $37 = ($36|0)==($__last|0);
   if ($37) {
    break;
   } else {
    $$01 = $36;$__p$02 = $35;
   }
  }
  $scevgep5 = (($28) + ($33<<2)|0);
  $__p$0$lcssa = $scevgep5;
 }
 HEAP32[$__p$0$lcssa>>2] = 0;
 $38 = (($17) + ($13))|0;
 $39 = HEAP8[$this>>0]|0;
 $40 = $39 & 1;
 $41 = ($40<<24>>24)==(0);
 if ($41) {
  $43 = $38 << 1;
  $44 = $43&255;
  HEAP8[$this>>0] = $44;
  STACKTOP = sp;return ($this|0);
 } else {
  $42 = (($this) + 4|0);
  HEAP32[$42>>2] = $38;
  STACKTOP = sp;return ($this|0);
 }
 return 0|0;
}
function __ZNSt3__111__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri($__intl,$__loc,$__pat,$__dp,$__ts,$__grp,$__sym,$__psn,$__nsn,$__fd) {
 $__intl = $__intl|0;
 $__loc = $__loc|0;
 $__pat = $__pat|0;
 $__dp = $__dp|0;
 $__ts = $__ts|0;
 $__grp = $__grp|0;
 $__sym = $__sym|0;
 $__psn = $__psn|0;
 $__nsn = $__nsn|0;
 $__fd = $__fd|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 100|0;
 $1 = sp + 88|0;
 $2 = sp + 76|0;
 $3 = sp + 64|0;
 $4 = sp + 52|0;
 $5 = sp + 48|0;
 $6 = sp + 24|0;
 $7 = sp + 12|0;
 $8 = sp;
 $9 = sp + 36|0;
 if ($__intl) {
  $10 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3092904)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vii[$13 & 4095]($0,$10);
  $14 = HEAP32[$0>>2]|0;
  HEAP8[$__pat>>0]=$14&255;HEAP8[$__pat+1>>0]=($14>>8)&255;HEAP8[$__pat+2>>0]=($14>>16)&255;HEAP8[$__pat+3>>0]=$14>>24;
  $15 = HEAP32[$10>>2]|0;
  $16 = (($15) + 32|0);
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vii[$17 & 4095]($1,$10);
  $18 = HEAP8[$__nsn>>0]|0;
  $19 = $18 & 1;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   $24 = (($__nsn) + 4|0);
   HEAP32[$24>>2] = 0;
   HEAP8[$__nsn>>0] = 0;
  } else {
   $21 = (($__nsn) + 8|0);
   $22 = HEAP32[$21>>2]|0;
   HEAP32[$22>>2] = 0;
   $23 = (($__nsn) + 4|0);
   HEAP32[$23>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3510,($__nsn|0),0);
  $25 = __THREW__; __THREW__ = 0;
  $26 = $25&1;
  if ($26) {
   $27 = ___cxa_find_matching_catch(0|0)|0;
   $28 = tempRet0;
   ___clang_call_terminate($27);
   // unreachable;
  }
  ;HEAP32[$__nsn+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__nsn+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__nsn+8>>2]=HEAP32[$1+8>>2]|0;
  ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($1);
  $29 = HEAP32[$10>>2]|0;
  $30 = (($29) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  FUNCTION_TABLE_vii[$31 & 4095]($2,$10);
  $32 = HEAP8[$__psn>>0]|0;
  $33 = $32 & 1;
  $34 = ($33<<24>>24)==(0);
  if ($34) {
   $38 = (($__psn) + 4|0);
   HEAP32[$38>>2] = 0;
   HEAP8[$__psn>>0] = 0;
  } else {
   $35 = (($__psn) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   HEAP32[$36>>2] = 0;
   $37 = (($__psn) + 4|0);
   HEAP32[$37>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3510,($__psn|0),0);
  $39 = __THREW__; __THREW__ = 0;
  $40 = $39&1;
  if ($40) {
   $41 = ___cxa_find_matching_catch(0|0)|0;
   $42 = tempRet0;
   ___clang_call_terminate($41);
   // unreachable;
  }
  ;HEAP32[$__psn+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$__psn+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$__psn+8>>2]=HEAP32[$2+8>>2]|0;
  ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($2);
  $43 = HEAP32[$10>>2]|0;
  $44 = (($43) + 12|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = (FUNCTION_TABLE_ii[$45 & 4095]($10)|0);
  HEAP32[$__dp>>2] = $46;
  $47 = HEAP32[$10>>2]|0;
  $48 = (($47) + 16|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = (FUNCTION_TABLE_ii[$49 & 4095]($10)|0);
  HEAP32[$__ts>>2] = $50;
  $51 = HEAP32[$10>>2]|0;
  $52 = (($51) + 20|0);
  $53 = HEAP32[$52>>2]|0;
  FUNCTION_TABLE_vii[$53 & 4095]($3,$10);
  $54 = HEAP8[$__grp>>0]|0;
  $55 = $54 & 1;
  $56 = ($55<<24>>24)==(0);
  if ($56) {
   $60 = (($__grp) + 1|0);
   HEAP8[$60>>0] = 0;
   HEAP8[$__grp>>0] = 0;
  } else {
   $57 = (($__grp) + 8|0);
   $58 = HEAP32[$57>>2]|0;
   HEAP8[$58>>0] = 0;
   $59 = (($__grp) + 4|0);
   HEAP32[$59>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__grp|0),0);
  $61 = __THREW__; __THREW__ = 0;
  $62 = $61&1;
  if ($62) {
   $63 = ___cxa_find_matching_catch(0|0)|0;
   $64 = tempRet0;
   ___clang_call_terminate($63);
   // unreachable;
  }
  ;HEAP32[$__grp+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$__grp+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$__grp+8>>2]=HEAP32[$3+8>>2]|0;
  ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($3);
  $65 = HEAP32[$10>>2]|0;
  $66 = (($65) + 24|0);
  $67 = HEAP32[$66>>2]|0;
  FUNCTION_TABLE_vii[$67 & 4095]($4,$10);
  $68 = HEAP8[$__sym>>0]|0;
  $69 = $68 & 1;
  $70 = ($69<<24>>24)==(0);
  if ($70) {
   $74 = (($__sym) + 4|0);
   HEAP32[$74>>2] = 0;
   HEAP8[$__sym>>0] = 0;
  } else {
   $71 = (($__sym) + 8|0);
   $72 = HEAP32[$71>>2]|0;
   HEAP32[$72>>2] = 0;
   $73 = (($__sym) + 4|0);
   HEAP32[$73>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3510,($__sym|0),0);
  $75 = __THREW__; __THREW__ = 0;
  $76 = $75&1;
  if ($76) {
   $77 = ___cxa_find_matching_catch(0|0)|0;
   $78 = tempRet0;
   ___clang_call_terminate($77);
   // unreachable;
  }
  ;HEAP32[$__sym+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__sym+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__sym+8>>2]=HEAP32[$4+8>>2]|0;
  ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($4);
  $79 = HEAP32[$10>>2]|0;
  $80 = (($79) + 36|0);
  $81 = HEAP32[$80>>2]|0;
  $82 = (FUNCTION_TABLE_ii[$81 & 4095]($10)|0);
  $storemerge = $82;
  HEAP32[$__fd>>2] = $storemerge;
  STACKTOP = sp;return;
 } else {
  $83 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3092840)|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = (($84) + 44|0);
  $86 = HEAP32[$85>>2]|0;
  FUNCTION_TABLE_vii[$86 & 4095]($5,$83);
  $87 = HEAP32[$5>>2]|0;
  HEAP8[$__pat>>0]=$87&255;HEAP8[$__pat+1>>0]=($87>>8)&255;HEAP8[$__pat+2>>0]=($87>>16)&255;HEAP8[$__pat+3>>0]=$87>>24;
  $88 = HEAP32[$83>>2]|0;
  $89 = (($88) + 32|0);
  $90 = HEAP32[$89>>2]|0;
  FUNCTION_TABLE_vii[$90 & 4095]($6,$83);
  $91 = HEAP8[$__nsn>>0]|0;
  $92 = $91 & 1;
  $93 = ($92<<24>>24)==(0);
  if ($93) {
   $97 = (($__nsn) + 4|0);
   HEAP32[$97>>2] = 0;
   HEAP8[$__nsn>>0] = 0;
  } else {
   $94 = (($__nsn) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   HEAP32[$95>>2] = 0;
   $96 = (($__nsn) + 4|0);
   HEAP32[$96>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3510,($__nsn|0),0);
  $98 = __THREW__; __THREW__ = 0;
  $99 = $98&1;
  if ($99) {
   $100 = ___cxa_find_matching_catch(0|0)|0;
   $101 = tempRet0;
   ___clang_call_terminate($100);
   // unreachable;
  }
  ;HEAP32[$__nsn+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$__nsn+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$__nsn+8>>2]=HEAP32[$6+8>>2]|0;
  ;HEAP32[$6+0>>2]=0|0;HEAP32[$6+4>>2]=0|0;HEAP32[$6+8>>2]=0|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($6);
  $102 = HEAP32[$83>>2]|0;
  $103 = (($102) + 28|0);
  $104 = HEAP32[$103>>2]|0;
  FUNCTION_TABLE_vii[$104 & 4095]($7,$83);
  $105 = HEAP8[$__psn>>0]|0;
  $106 = $105 & 1;
  $107 = ($106<<24>>24)==(0);
  if ($107) {
   $111 = (($__psn) + 4|0);
   HEAP32[$111>>2] = 0;
   HEAP8[$__psn>>0] = 0;
  } else {
   $108 = (($__psn) + 8|0);
   $109 = HEAP32[$108>>2]|0;
   HEAP32[$109>>2] = 0;
   $110 = (($__psn) + 4|0);
   HEAP32[$110>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3510,($__psn|0),0);
  $112 = __THREW__; __THREW__ = 0;
  $113 = $112&1;
  if ($113) {
   $114 = ___cxa_find_matching_catch(0|0)|0;
   $115 = tempRet0;
   ___clang_call_terminate($114);
   // unreachable;
  }
  ;HEAP32[$__psn+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$__psn+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$__psn+8>>2]=HEAP32[$7+8>>2]|0;
  ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($7);
  $116 = HEAP32[$83>>2]|0;
  $117 = (($116) + 12|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (FUNCTION_TABLE_ii[$118 & 4095]($83)|0);
  HEAP32[$__dp>>2] = $119;
  $120 = HEAP32[$83>>2]|0;
  $121 = (($120) + 16|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = (FUNCTION_TABLE_ii[$122 & 4095]($83)|0);
  HEAP32[$__ts>>2] = $123;
  $124 = HEAP32[$83>>2]|0;
  $125 = (($124) + 20|0);
  $126 = HEAP32[$125>>2]|0;
  FUNCTION_TABLE_vii[$126 & 4095]($8,$83);
  $127 = HEAP8[$__grp>>0]|0;
  $128 = $127 & 1;
  $129 = ($128<<24>>24)==(0);
  if ($129) {
   $133 = (($__grp) + 1|0);
   HEAP8[$133>>0] = 0;
   HEAP8[$__grp>>0] = 0;
  } else {
   $130 = (($__grp) + 8|0);
   $131 = HEAP32[$130>>2]|0;
   HEAP8[$131>>0] = 0;
   $132 = (($__grp) + 4|0);
   HEAP32[$132>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__grp|0),0);
  $134 = __THREW__; __THREW__ = 0;
  $135 = $134&1;
  if ($135) {
   $136 = ___cxa_find_matching_catch(0|0)|0;
   $137 = tempRet0;
   ___clang_call_terminate($136);
   // unreachable;
  }
  ;HEAP32[$__grp+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$__grp+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$__grp+8>>2]=HEAP32[$8+8>>2]|0;
  ;HEAP32[$8+0>>2]=0|0;HEAP32[$8+4>>2]=0|0;HEAP32[$8+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($8);
  $138 = HEAP32[$83>>2]|0;
  $139 = (($138) + 24|0);
  $140 = HEAP32[$139>>2]|0;
  FUNCTION_TABLE_vii[$140 & 4095]($9,$83);
  $141 = HEAP8[$__sym>>0]|0;
  $142 = $141 & 1;
  $143 = ($142<<24>>24)==(0);
  if ($143) {
   $147 = (($__sym) + 4|0);
   HEAP32[$147>>2] = 0;
   HEAP8[$__sym>>0] = 0;
  } else {
   $144 = (($__sym) + 8|0);
   $145 = HEAP32[$144>>2]|0;
   HEAP32[$145>>2] = 0;
   $146 = (($__sym) + 4|0);
   HEAP32[$146>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3510,($__sym|0),0);
  $148 = __THREW__; __THREW__ = 0;
  $149 = $148&1;
  if ($149) {
   $150 = ___cxa_find_matching_catch(0|0)|0;
   $151 = tempRet0;
   ___clang_call_terminate($150);
   // unreachable;
  }
  ;HEAP32[$__sym+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__sym+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__sym+8>>2]=HEAP32[$9+8>>2]|0;
  ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($9);
  $152 = HEAP32[$83>>2]|0;
  $153 = (($152) + 36|0);
  $154 = HEAP32[$153>>2]|0;
  $155 = (FUNCTION_TABLE_ii[$154 & 4095]($83)|0);
  $storemerge = $155;
  HEAP32[$__fd>>2] = $storemerge;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__119__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_($__b,$__n,$__e) {
 $__b = $__b|0;
 $__n = $__n|0;
 $__e = $__e|0;
 var $$ = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)!=(3855|0);
 $3 = HEAP32[$__e>>2]|0;
 $4 = HEAP32[$__b>>2]|0;
 $5 = $3;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ($7>>>0)<(2147483647);
 $9 = $7 << 1;
 $$ = $8 ? $9 : -1;
 $10 = HEAP32[$__n>>2]|0;
 $11 = $10;
 $12 = (($11) - ($6))|0;
 $13 = $12 >> 2;
 if ($2) {
  $14 = $4;
 } else {
  $14 = 0;
 }
 $15 = (_realloc($14,$$)|0);
 $16 = ($15|0)==(0|0);
 if ($16) {
  __ZSt17__throw_bad_allocv();
 }
 do {
  if ($2) {
   HEAP32[$__b>>2] = $15;
   $25 = $15;
  } else {
   $$pr = HEAP32[$__b>>2]|0;
   HEAP32[$__b>>2] = $15;
   $17 = ($$pr|0)==(0|0);
   if ($17) {
    $25 = $15;
   } else {
    $18 = HEAP32[$0>>2]|0;
    __THREW__ = 0;
    invoke_vi($18|0,($$pr|0));
    $19 = __THREW__; __THREW__ = 0;
    $20 = $19&1;
    if ($20) {
     $21 = ___cxa_find_matching_catch(0|0)|0;
     $22 = tempRet0;
     ___clang_call_terminate($21);
     // unreachable;
    } else {
     $$pre = HEAP32[$__b>>2]|0;
     $25 = $$pre;
     break;
    }
   }
  }
 } while(0);
 HEAP32[$0>>2] = 3853;
 $23 = $$ >>> 2;
 $24 = (($25) + ($13<<2)|0);
 HEAP32[$__n>>2] = $24;
 $26 = HEAP32[$__b>>2]|0;
 $27 = (($26) + ($23<<2)|0);
 HEAP32[$__e>>2] = $27;
 STACKTOP = sp;return;
}
function __ZNSt3__19money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__19money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__19money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce($agg$result,$this,$__s,$__intl,$__iob,$__fl,$__units) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__intl = $__intl|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__units = +$__units;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy = 0, $$pn = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__bb = 0, $__buf = 0, $__db$0 = 0, $__digits = 0, $__dp = 0, $__fd = 0, $__grp = 0, $__loc = 0, $__mb$0 = 0, $__mbuf = 0, $__me = 0, $__mi = 0, $__n$0 = 0, $__pat = 0, $__sn = 0, $__sym = 0;
 var $__ts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 384|0;
 $$byval_copy = sp;
 $__buf = sp + 272|0;
 $__bb = sp + 48|0;
 $__digits = sp + 172|0;
 $__loc = sp + 56|0;
 $__pat = sp + 52|0;
 $__dp = sp + 372|0;
 $__ts = sp + 373|0;
 $__grp = sp + 60|0;
 $__sym = sp + 28|0;
 $__sn = sp + 16|0;
 $__fd = sp + 12|0;
 $__mbuf = sp + 72|0;
 $__mi = sp + 8|0;
 $__me = sp + 40|0;
 $0 = sp + 44|0;
 HEAP32[$__bb>>2] = $__buf;
 HEAPF64[tempDoublePtr>>3]=$__units;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $1 = (_snprintf($__buf,100,3093088,$$byval_copy)|0);
 $2 = ($1>>>0)>(99);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_i(134)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $112 = 0;$113 = 0;
   } else {
    __THREW__ = 0;
    HEAPF64[tempDoublePtr>>3]=$__units;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
    $6 = (invoke_iiiii(342,($__bb|0),($3|0),(3093088|0),($$byval_copy|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     $112 = 0;$113 = 0;
    } else {
     $9 = HEAP32[$__bb>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      __THREW__ = 0;
      invoke_v(1012);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       $112 = 0;$113 = 0;
       break;
      }
      $$pre = HEAP32[$__bb>>2]|0;
      $114 = $$pre;
     } else {
      $114 = $9;
     }
     $15 = (_malloc($6)|0);
     $16 = ($15|0)==(0|0);
     if ($16) {
      __THREW__ = 0;
      invoke_v(1012);
      $17 = __THREW__; __THREW__ = 0;
      $18 = $17&1;
      if ($18) {
       $112 = $114;$113 = 0;
      } else {
       $107 = 0;$108 = $114;$__db$0 = 0;$__n$0 = $6;
       label = 10;
      }
     } else {
      $107 = $15;$108 = $114;$__db$0 = $15;$__n$0 = $6;
      label = 10;
     }
    }
   }
  } else {
   $107 = 0;$108 = 0;$__db$0 = $__digits;$__n$0 = $1;
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  __THREW__ = 0;
  invoke_vii(2475,($__loc|0),($__iob|0));
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $112 = $108;$113 = $107;
  } else {
   __THREW__ = 0;
   $21 = (invoke_iii(2228,($__loc|0),(3093336|0))|0);
   $22 = __THREW__; __THREW__ = 0;
   $23 = $22&1;
   if ($23) {
    label = 35;
   } else {
    $24 = HEAP32[$__bb>>2]|0;
    $25 = (($24) + ($__n$0)|0);
    $26 = HEAP32[$21>>2]|0;
    $27 = (($26) + 32|0);
    $28 = HEAP32[$27>>2]|0;
    __THREW__ = 0;
    (invoke_iiiii($28|0,($21|0),($24|0),($25|0),($__db$0|0))|0);
    $29 = __THREW__; __THREW__ = 0;
    $30 = $29&1;
    if ($30) {
     label = 35;
    } else {
     $31 = ($__n$0|0)==(0);
     if ($31) {
      $35 = 0;
     } else {
      $32 = HEAP32[$__bb>>2]|0;
      $33 = HEAP8[$32>>0]|0;
      $34 = ($33<<24>>24)==(45);
      $35 = $34;
     }
     HEAP32[$__pat>>2] = 0;
     ;HEAP32[$__grp+0>>2]=0|0;HEAP32[$__grp+4>>2]=0|0;HEAP32[$__grp+8>>2]=0|0;
     ;HEAP32[$__sym+0>>2]=0|0;HEAP32[$__sym+4>>2]=0|0;HEAP32[$__sym+8>>2]=0|0;
     ;HEAP32[$__sn+0>>2]=0|0;HEAP32[$__sn+4>>2]=0|0;HEAP32[$__sn+8>>2]=0|0;
     __THREW__ = 0;
     invoke_viiiiiiiiii(12,($__intl|0),($35|0),($__loc|0),($__pat|0),($__dp|0),($__ts|0),($__grp|0),($__sym|0),($__sn|0),($__fd|0));
     $36 = __THREW__; __THREW__ = 0;
     $37 = $36&1;
     do {
      if ($37) {
       $89 = ___cxa_find_matching_catch()|0;
       $90 = tempRet0;
       $$0 = $89;$$01 = $90;
      } else {
       $38 = HEAP32[$__fd>>2]|0;
       $39 = ($__n$0|0)>($38|0);
       if ($39) {
        $40 = (($__n$0) - ($38))|0;
        $41 = $40 << 1;
        $42 = HEAP8[$__sn>>0]|0;
        $43 = $42 & 1;
        $44 = ($43<<24>>24)==(0);
        if ($44) {
         $47 = $42&255;
         $48 = $47 >>> 1;
         $58 = $48;
        } else {
         $45 = (($__sn) + 4|0);
         $46 = HEAP32[$45>>2]|0;
         $58 = $46;
        }
        $49 = HEAP8[$__sym>>0]|0;
        $50 = $49 & 1;
        $51 = ($50<<24>>24)==(0);
        if ($51) {
         $54 = $49&255;
         $55 = $54 >>> 1;
         $60 = $55;
        } else {
         $52 = (($__sym) + 4|0);
         $53 = HEAP32[$52>>2]|0;
         $60 = $53;
        }
        $56 = $41 | 1;
        $57 = (($58) + ($56))|0;
        $59 = (($57) + ($60))|0;
        $$pn = $59;
       } else {
        $61 = HEAP8[$__sn>>0]|0;
        $62 = $61 & 1;
        $63 = ($62<<24>>24)==(0);
        if ($63) {
         $66 = $61&255;
         $67 = $66 >>> 1;
         $76 = $67;
        } else {
         $64 = (($__sn) + 4|0);
         $65 = HEAP32[$64>>2]|0;
         $76 = $65;
        }
        $68 = HEAP8[$__sym>>0]|0;
        $69 = $68 & 1;
        $70 = ($69<<24>>24)==(0);
        if ($70) {
         $73 = $68&255;
         $74 = $73 >>> 1;
         $78 = $74;
        } else {
         $71 = (($__sym) + 4|0);
         $72 = HEAP32[$71>>2]|0;
         $78 = $72;
        }
        $75 = (($76) + 2)|0;
        $77 = (($75) + ($78))|0;
        $$pn = $77;
       }
       $79 = (($$pn) + ($38))|0;
       $80 = ($79>>>0)>(100);
       if ($80) {
        $81 = (_malloc($79)|0);
        $82 = ($81|0)==(0|0);
        if ($82) {
         __THREW__ = 0;
         invoke_v(1012);
         $83 = __THREW__; __THREW__ = 0;
         $84 = $83&1;
         if ($84) {
          $85 = ___cxa_find_matching_catch()|0;
          $86 = tempRet0;
          $$0 = $85;$$01 = $86;
          break;
         } else {
          $93 = 0;$__mb$0 = 0;
         }
        } else {
         $93 = $81;$__mb$0 = $81;
        }
       } else {
        $93 = 0;$__mb$0 = $__mbuf;
       }
       $94 = (($__iob) + 4|0);
       $95 = HEAP32[$94>>2]|0;
       $96 = (($__db$0) + ($__n$0)|0);
       $97 = HEAP8[$__dp>>0]|0;
       $98 = HEAP8[$__ts>>0]|0;
       __THREW__ = 0;
       invoke_viiiiiiiiiiiiiii(1,($__mb$0|0),($__mi|0),($__me|0),($95|0),($__db$0|0),($96|0),($21|0),($35|0),($__pat|0),($97|0),($98|0),($__grp|0),($__sym|0),($__sn|0),($38|0));
       $99 = __THREW__; __THREW__ = 0;
       $100 = $99&1;
       if (!($100)) {
        $101 = HEAP32[$__s>>2]|0;
        HEAP32[$0>>2] = $101;
        $102 = HEAP32[$__mi>>2]|0;
        $103 = HEAP32[$__me>>2]|0;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_viiiiiii(60,($agg$result|0),($$byval_copy|0),($__mb$0|0),($102|0),($103|0),($__iob|0),($__fl|0));
        $104 = __THREW__; __THREW__ = 0;
        $105 = $104&1;
        if (!($105)) {
         _free($93);
         __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sn);
         __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sym);
         __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
         $106 = HEAP32[$__loc>>2]|0;
         (__ZNSt3__114__shared_count16__release_sharedEv($106)|0);
         _free($107);
         _free($108);
         STACKTOP = sp;return;
        }
       }
       $91 = ___cxa_find_matching_catch()|0;
       $92 = tempRet0;
       _free($93);
       $$0 = $91;$$01 = $92;
      }
     } while(0);
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sn);
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sym);
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
     $$1 = $$0;$$12 = $$01;
    }
   }
   if ((label|0) == 35) {
    $87 = ___cxa_find_matching_catch()|0;
    $88 = tempRet0;
    $$1 = $87;$$12 = $88;
   }
   $109 = HEAP32[$__loc>>2]|0;
   (__ZNSt3__114__shared_count16__release_sharedEv($109)|0);
   $$2 = $$1;$$23 = $$12;$110 = $107;$111 = $108;
   _free($110);
   _free($111);
   ___resumeException($$2|0);
   // unreachable;
  }
 }
 $13 = ___cxa_find_matching_catch()|0;
 $14 = tempRet0;
 $$2 = $13;$$23 = $14;$110 = $113;$111 = $112;
 _free($110);
 _free($111);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZNSt3__111__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri($__intl,$__neg,$__loc,$__pat,$__dp,$__ts,$__grp,$__sym,$__sn,$__fd) {
 $__intl = $__intl|0;
 $__neg = $__neg|0;
 $__loc = $__loc|0;
 $__pat = $__pat|0;
 $__dp = $__dp|0;
 $__ts = $__ts|0;
 $__grp = $__grp|0;
 $__sym = $__sym|0;
 $__sn = $__sn|0;
 $__fd = $__fd|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 108|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 80|0;
 $4 = sp + 68|0;
 $5 = sp + 56|0;
 $6 = sp + 52|0;
 $7 = sp + 28|0;
 $8 = sp + 24|0;
 $9 = sp + 12|0;
 $10 = sp;
 $11 = sp + 40|0;
 if ($__intl) {
  $12 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3092776)|0);
  $13 = HEAP32[$12>>2]|0;
  do {
   if ($__neg) {
    $14 = (($13) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vii[$15 & 4095]($0,$12);
    $16 = HEAP32[$0>>2]|0;
    HEAP8[$__pat>>0]=$16&255;HEAP8[$__pat+1>>0]=($16>>8)&255;HEAP8[$__pat+2>>0]=($16>>16)&255;HEAP8[$__pat+3>>0]=$16>>24;
    $17 = HEAP32[$12>>2]|0;
    $18 = (($17) + 32|0);
    $19 = HEAP32[$18>>2]|0;
    FUNCTION_TABLE_vii[$19 & 4095]($1,$12);
    $20 = HEAP8[$__sn>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $26 = (($__sn) + 1|0);
     HEAP8[$26>>0] = 0;
     HEAP8[$__sn>>0] = 0;
    } else {
     $23 = (($__sn) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     HEAP8[$24>>0] = 0;
     $25 = (($__sn) + 4|0);
     HEAP32[$25>>2] = 0;
    }
    __THREW__ = 0;
    invoke_vii(3257,($__sn|0),0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $29 = ___cxa_find_matching_catch(0|0)|0;
     $30 = tempRet0;
     ___clang_call_terminate($29);
     // unreachable;
    } else {
     ;HEAP32[$__sn+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__sn+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__sn+8>>2]=HEAP32[$1+8>>2]|0;
     ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($1);
     break;
    }
   } else {
    $31 = (($13) + 40|0);
    $32 = HEAP32[$31>>2]|0;
    FUNCTION_TABLE_vii[$32 & 4095]($2,$12);
    $33 = HEAP32[$2>>2]|0;
    HEAP8[$__pat>>0]=$33&255;HEAP8[$__pat+1>>0]=($33>>8)&255;HEAP8[$__pat+2>>0]=($33>>16)&255;HEAP8[$__pat+3>>0]=$33>>24;
    $34 = HEAP32[$12>>2]|0;
    $35 = (($34) + 28|0);
    $36 = HEAP32[$35>>2]|0;
    FUNCTION_TABLE_vii[$36 & 4095]($3,$12);
    $37 = HEAP8[$__sn>>0]|0;
    $38 = $37 & 1;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     $43 = (($__sn) + 1|0);
     HEAP8[$43>>0] = 0;
     HEAP8[$__sn>>0] = 0;
    } else {
     $40 = (($__sn) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     HEAP8[$41>>0] = 0;
     $42 = (($__sn) + 4|0);
     HEAP32[$42>>2] = 0;
    }
    __THREW__ = 0;
    invoke_vii(3257,($__sn|0),0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     $46 = ___cxa_find_matching_catch(0|0)|0;
     $47 = tempRet0;
     ___clang_call_terminate($46);
     // unreachable;
    } else {
     ;HEAP32[$__sn+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$__sn+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$__sn+8>>2]=HEAP32[$3+8>>2]|0;
     ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($3);
     break;
    }
   }
  } while(0);
  $48 = HEAP32[$12>>2]|0;
  $49 = (($48) + 12|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (FUNCTION_TABLE_ii[$50 & 4095]($12)|0);
  HEAP8[$__dp>>0] = $51;
  $52 = HEAP32[$12>>2]|0;
  $53 = (($52) + 16|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (FUNCTION_TABLE_ii[$54 & 4095]($12)|0);
  HEAP8[$__ts>>0] = $55;
  $56 = HEAP32[$12>>2]|0;
  $57 = (($56) + 20|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 4095]($4,$12);
  $59 = HEAP8[$__grp>>0]|0;
  $60 = $59 & 1;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $65 = (($__grp) + 1|0);
   HEAP8[$65>>0] = 0;
   HEAP8[$__grp>>0] = 0;
  } else {
   $62 = (($__grp) + 8|0);
   $63 = HEAP32[$62>>2]|0;
   HEAP8[$63>>0] = 0;
   $64 = (($__grp) + 4|0);
   HEAP32[$64>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__grp|0),0);
  $66 = __THREW__; __THREW__ = 0;
  $67 = $66&1;
  if ($67) {
   $68 = ___cxa_find_matching_catch(0|0)|0;
   $69 = tempRet0;
   ___clang_call_terminate($68);
   // unreachable;
  }
  ;HEAP32[$__grp+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__grp+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__grp+8>>2]=HEAP32[$4+8>>2]|0;
  ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($4);
  $70 = HEAP32[$12>>2]|0;
  $71 = (($70) + 24|0);
  $72 = HEAP32[$71>>2]|0;
  FUNCTION_TABLE_vii[$72 & 4095]($5,$12);
  $73 = HEAP8[$__sym>>0]|0;
  $74 = $73 & 1;
  $75 = ($74<<24>>24)==(0);
  if ($75) {
   $79 = (($__sym) + 1|0);
   HEAP8[$79>>0] = 0;
   HEAP8[$__sym>>0] = 0;
  } else {
   $76 = (($__sym) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   HEAP8[$77>>0] = 0;
   $78 = (($__sym) + 4|0);
   HEAP32[$78>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__sym|0),0);
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  }
  ;HEAP32[$__sym+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$__sym+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$__sym+8>>2]=HEAP32[$5+8>>2]|0;
  ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($5);
  $84 = HEAP32[$12>>2]|0;
  $85 = (($84) + 36|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (FUNCTION_TABLE_ii[$86 & 4095]($12)|0);
  $storemerge = $87;
  HEAP32[$__fd>>2] = $storemerge;
  STACKTOP = sp;return;
 } else {
  $88 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3092712)|0);
  $89 = HEAP32[$88>>2]|0;
  do {
   if ($__neg) {
    $90 = (($89) + 44|0);
    $91 = HEAP32[$90>>2]|0;
    FUNCTION_TABLE_vii[$91 & 4095]($6,$88);
    $92 = HEAP32[$6>>2]|0;
    HEAP8[$__pat>>0]=$92&255;HEAP8[$__pat+1>>0]=($92>>8)&255;HEAP8[$__pat+2>>0]=($92>>16)&255;HEAP8[$__pat+3>>0]=$92>>24;
    $93 = HEAP32[$88>>2]|0;
    $94 = (($93) + 32|0);
    $95 = HEAP32[$94>>2]|0;
    FUNCTION_TABLE_vii[$95 & 4095]($7,$88);
    $96 = HEAP8[$__sn>>0]|0;
    $97 = $96 & 1;
    $98 = ($97<<24>>24)==(0);
    if ($98) {
     $102 = (($__sn) + 1|0);
     HEAP8[$102>>0] = 0;
     HEAP8[$__sn>>0] = 0;
    } else {
     $99 = (($__sn) + 8|0);
     $100 = HEAP32[$99>>2]|0;
     HEAP8[$100>>0] = 0;
     $101 = (($__sn) + 4|0);
     HEAP32[$101>>2] = 0;
    }
    __THREW__ = 0;
    invoke_vii(3257,($__sn|0),0);
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if ($104) {
     $105 = ___cxa_find_matching_catch(0|0)|0;
     $106 = tempRet0;
     ___clang_call_terminate($105);
     // unreachable;
    } else {
     ;HEAP32[$__sn+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$__sn+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$__sn+8>>2]=HEAP32[$7+8>>2]|0;
     ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($7);
     break;
    }
   } else {
    $107 = (($89) + 40|0);
    $108 = HEAP32[$107>>2]|0;
    FUNCTION_TABLE_vii[$108 & 4095]($8,$88);
    $109 = HEAP32[$8>>2]|0;
    HEAP8[$__pat>>0]=$109&255;HEAP8[$__pat+1>>0]=($109>>8)&255;HEAP8[$__pat+2>>0]=($109>>16)&255;HEAP8[$__pat+3>>0]=$109>>24;
    $110 = HEAP32[$88>>2]|0;
    $111 = (($110) + 28|0);
    $112 = HEAP32[$111>>2]|0;
    FUNCTION_TABLE_vii[$112 & 4095]($9,$88);
    $113 = HEAP8[$__sn>>0]|0;
    $114 = $113 & 1;
    $115 = ($114<<24>>24)==(0);
    if ($115) {
     $119 = (($__sn) + 1|0);
     HEAP8[$119>>0] = 0;
     HEAP8[$__sn>>0] = 0;
    } else {
     $116 = (($__sn) + 8|0);
     $117 = HEAP32[$116>>2]|0;
     HEAP8[$117>>0] = 0;
     $118 = (($__sn) + 4|0);
     HEAP32[$118>>2] = 0;
    }
    __THREW__ = 0;
    invoke_vii(3257,($__sn|0),0);
    $120 = __THREW__; __THREW__ = 0;
    $121 = $120&1;
    if ($121) {
     $122 = ___cxa_find_matching_catch(0|0)|0;
     $123 = tempRet0;
     ___clang_call_terminate($122);
     // unreachable;
    } else {
     ;HEAP32[$__sn+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__sn+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__sn+8>>2]=HEAP32[$9+8>>2]|0;
     ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($9);
     break;
    }
   }
  } while(0);
  $124 = HEAP32[$88>>2]|0;
  $125 = (($124) + 12|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (FUNCTION_TABLE_ii[$126 & 4095]($88)|0);
  HEAP8[$__dp>>0] = $127;
  $128 = HEAP32[$88>>2]|0;
  $129 = (($128) + 16|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (FUNCTION_TABLE_ii[$130 & 4095]($88)|0);
  HEAP8[$__ts>>0] = $131;
  $132 = HEAP32[$88>>2]|0;
  $133 = (($132) + 20|0);
  $134 = HEAP32[$133>>2]|0;
  FUNCTION_TABLE_vii[$134 & 4095]($10,$88);
  $135 = HEAP8[$__grp>>0]|0;
  $136 = $135 & 1;
  $137 = ($136<<24>>24)==(0);
  if ($137) {
   $141 = (($__grp) + 1|0);
   HEAP8[$141>>0] = 0;
   HEAP8[$__grp>>0] = 0;
  } else {
   $138 = (($__grp) + 8|0);
   $139 = HEAP32[$138>>2]|0;
   HEAP8[$139>>0] = 0;
   $140 = (($__grp) + 4|0);
   HEAP32[$140>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__grp|0),0);
  $142 = __THREW__; __THREW__ = 0;
  $143 = $142&1;
  if ($143) {
   $144 = ___cxa_find_matching_catch(0|0)|0;
   $145 = tempRet0;
   ___clang_call_terminate($144);
   // unreachable;
  }
  ;HEAP32[$__grp+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$__grp+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$__grp+8>>2]=HEAP32[$10+8>>2]|0;
  ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($10);
  $146 = HEAP32[$88>>2]|0;
  $147 = (($146) + 24|0);
  $148 = HEAP32[$147>>2]|0;
  FUNCTION_TABLE_vii[$148 & 4095]($11,$88);
  $149 = HEAP8[$__sym>>0]|0;
  $150 = $149 & 1;
  $151 = ($150<<24>>24)==(0);
  if ($151) {
   $155 = (($__sym) + 1|0);
   HEAP8[$155>>0] = 0;
   HEAP8[$__sym>>0] = 0;
  } else {
   $152 = (($__sym) + 8|0);
   $153 = HEAP32[$152>>2]|0;
   HEAP8[$153>>0] = 0;
   $154 = (($__sym) + 4|0);
   HEAP32[$154>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__sym|0),0);
  $156 = __THREW__; __THREW__ = 0;
  $157 = $156&1;
  if ($157) {
   $158 = ___cxa_find_matching_catch(0|0)|0;
   $159 = tempRet0;
   ___clang_call_terminate($158);
   // unreachable;
  }
  ;HEAP32[$__sym+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$__sym+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$__sym+8>>2]=HEAP32[$11+8>>2]|0;
  ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($11);
  $160 = HEAP32[$88>>2]|0;
  $161 = (($160) + 36|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = (FUNCTION_TABLE_ii[$162 & 4095]($88)|0);
  $storemerge = $163;
  HEAP32[$__fd>>2] = $storemerge;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__111__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i($__mb,$__mi,$__me,$__flags,$__db,$__de,$__ct,$__neg,$__pat,$__dp,$__ts,$__grp,$__sym,$__sn,$__fd) {
 $__mb = $__mb|0;
 $__mi = $__mi|0;
 $__me = $__me|0;
 $__flags = $__flags|0;
 $__db = $__db|0;
 $__de = $__de|0;
 $__ct = $__ct|0;
 $__neg = $__neg|0;
 $__pat = $__pat|0;
 $__dp = $__dp|0;
 $__ts = $__ts|0;
 $__grp = $__grp|0;
 $__sym = $__sym|0;
 $__sn = $__sn|0;
 $__fd = $__fd|0;
 var $$$0 = 0, $$0$lcssa$i$i = 0, $$0$lcssa$i$i17 = 0, $$01$i$i = 0, $$01$i$i15 = 0, $$012$i$i = 0, $$050 = 0, $$2 = 0, $$lcssa38 = 0, $$pn = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__d$0$lcssa = 0, $__d$0$lcssa58 = 0, $__d$029 = 0, $__d$1$lcssa73 = 0, $__d$1$lcssa74 = 0, $__d$132 = 0, $__d$2 = 0, $__d$343 = 0, $__f$0$lcssa71 = 0, $__f$0$lcssa72 = 0;
 var $__f$033 = 0, $__f$139 = 0, $__gl$046 = 0, $__gl$1 = 0, $__ig$045 = 0, $__ig$1 = 0, $__ng$044 = 0, $__ng$1 = 0, $__p$049 = 0, $brmerge = 0, $exitcond = 0, $isascii1$i = 0, $or$cond = 0, $scevgep = 0, $scevgep59 = 0, $scevgep61 = 0, $scevgep6162 = 0, $scevgep63 = 0, $umax = 0, $umax60 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$__me>>2] = $__mb;
 $0 = (($__sn) + 1|0);
 $1 = (($__sn) + 8|0);
 $2 = (($__sn) + 4|0);
 $3 = $__flags & 512;
 $4 = ($3|0)==(0);
 $5 = (($__sym) + 1|0);
 $6 = (($__sym) + 8|0);
 $7 = (($__sym) + 4|0);
 $8 = ($__fd|0)>(0);
 $9 = (($__grp) + 1|0);
 $10 = (($__grp) + 8|0);
 $11 = (($__grp) + 4|0);
 $12 = (($__ct) + 8|0);
 $13 = (0 - ($__fd))|0;
 $$050 = $__db;$__p$049 = 0;
 while(1) {
  $14 = (($__pat) + ($__p$049)|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15 << 24 >> 24;
  switch ($16|0) {
  case 1:  {
   $18 = HEAP32[$__me>>2]|0;
   HEAP32[$__mi>>2] = $18;
   $19 = HEAP32[$__ct>>2]|0;
   $20 = (($19) + 28|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (FUNCTION_TABLE_iii[$21 & 4095]($__ct,32)|0);
   $23 = HEAP32[$__me>>2]|0;
   $24 = (($23) + 1|0);
   HEAP32[$__me>>2] = $24;
   HEAP8[$23>>0] = $22;
   $$2 = $$050;
   break;
  }
  case 3:  {
   $25 = HEAP8[$__sn>>0]|0;
   $26 = $25 & 1;
   $27 = ($26<<24>>24)==(0);
   if ($27) {
    $29 = $25&255;
    $30 = $29 >>> 1;
    $32 = $30;
   } else {
    $28 = HEAP32[$2>>2]|0;
    $32 = $28;
   }
   $31 = ($32|0)==(0);
   if ($31) {
    $$2 = $$050;
   } else {
    if ($27) {
     $35 = $0;
    } else {
     $33 = HEAP32[$1>>2]|0;
     $35 = $33;
    }
    $34 = HEAP8[$35>>0]|0;
    $36 = HEAP32[$__me>>2]|0;
    $37 = (($36) + 1|0);
    HEAP32[$__me>>2] = $37;
    HEAP8[$36>>0] = $34;
    $$2 = $$050;
   }
   break;
  }
  case 2:  {
   $38 = HEAP8[$__sym>>0]|0;
   $39 = $38 & 1;
   $40 = ($39<<24>>24)==(0);
   if ($40) {
    $42 = $38&255;
    $43 = $42 >>> 1;
    $45 = $43;
   } else {
    $41 = HEAP32[$7>>2]|0;
    $45 = $41;
   }
   $44 = ($45|0)==(0);
   $brmerge = $44 | $4;
   if ($brmerge) {
    $$2 = $$050;
   } else {
    if ($40) {
     $48 = $38&255;
     $49 = $48 >>> 1;
     $51 = $5;$52 = $49;$55 = $5;
    } else {
     $46 = HEAP32[$6>>2]|0;
     $47 = HEAP32[$7>>2]|0;
     $51 = $46;$52 = $47;$55 = $46;
    }
    $50 = (($51) + ($52)|0);
    $53 = HEAP32[$__me>>2]|0;
    $54 = ($55|0)==($50|0);
    if ($54) {
     $$0$lcssa$i$i17 = $53;
    } else {
     $$01$i$i15 = $53;$57 = $55;
     while(1) {
      $56 = HEAP8[$57>>0]|0;
      HEAP8[$$01$i$i15>>0] = $56;
      $58 = (($57) + 1|0);
      $59 = (($$01$i$i15) + 1|0);
      $60 = ($58|0)==($50|0);
      if ($60) {
       $$0$lcssa$i$i17 = $59;
       break;
      } else {
       $$01$i$i15 = $59;$57 = $58;
      }
     }
    }
    HEAP32[$__me>>2] = $$0$lcssa$i$i17;
    $$2 = $$050;
   }
   break;
  }
  case 4:  {
   $61 = HEAP32[$__me>>2]|0;
   $62 = (($$050) + 1|0);
   $$$0 = $__neg ? $62 : $$050;
   $63 = ($$$0>>>0)<($__de>>>0);
   L29: do {
    if ($63) {
     $__d$029 = $$$0;
     while(1) {
      $66 = HEAP8[$__d$029>>0]|0;
      $isascii1$i = ($66<<24>>24)>(-1);
      if (!($isascii1$i)) {
       $__d$0$lcssa = $__d$029;
       break L29;
      }
      $67 = $66 << 24 >> 24;
      $68 = HEAP32[$12>>2]|0;
      $69 = (($68) + ($67<<1)|0);
      $70 = HEAP16[$69>>1]|0;
      $71 = $70 & 2048;
      $72 = ($71<<16>>16)==(0);
      $65 = (($__d$029) + 1|0);
      if ($72) {
       $__d$0$lcssa = $__d$029;
       break L29;
      }
      $64 = ($65>>>0)<($__de>>>0);
      if ($64) {
       $__d$029 = $65;
      } else {
       $__d$0$lcssa = $65;
       break;
      }
     }
    } else {
     $__d$0$lcssa = $$$0;
    }
   } while(0);
   $__d$0$lcssa58 = $__d$0$lcssa;
   if ($8) {
    $73 = ($__d$0$lcssa>>>0)>($$$0>>>0);
    if ($73) {
     $74 = (0 - ($__d$0$lcssa58))|0;
     $scevgep = (($$$0) + ($74)|0);
     $scevgep59 = $scevgep;
     $75 = ($scevgep59>>>0)<($13>>>0);
     $umax = $75 ? $13 : $scevgep59;
     $umax60 = $umax;
     $scevgep61 = (($umax60) + ($__fd)|0);
     $scevgep6162 = $scevgep61;
     $79 = $61;$__d$132 = $__d$0$lcssa;$__f$033 = $__fd;
     while(1) {
      $76 = (($__d$132) + -1|0);
      $77 = HEAP8[$76>>0]|0;
      $78 = (($79) + 1|0);
      HEAP32[$__me>>2] = $78;
      HEAP8[$79>>0] = $77;
      $80 = (($__f$033) + -1)|0;
      $81 = ($76>>>0)>($$$0>>>0);
      $82 = ($80|0)>(0);
      $or$cond = $81 & $82;
      if (!($or$cond)) {
       break;
      }
      $$pre = HEAP32[$__me>>2]|0;
      $79 = $$pre;$__d$132 = $76;$__f$033 = $80;
     }
     $scevgep63 = (($__d$0$lcssa) + ($umax)|0);
     if ($82) {
      $__d$1$lcssa74 = $scevgep63;$__f$0$lcssa72 = $scevgep6162;
      label = 32;
     } else {
      $90 = 0;$__d$1$lcssa73 = $scevgep63;$__f$0$lcssa71 = $scevgep6162;
     }
    } else {
     $__d$1$lcssa74 = $__d$0$lcssa;$__f$0$lcssa72 = $__fd;
     label = 32;
    }
    if ((label|0) == 32) {
     label = 0;
     $83 = HEAP32[$__ct>>2]|0;
     $84 = (($83) + 28|0);
     $85 = HEAP32[$84>>2]|0;
     $86 = (FUNCTION_TABLE_iii[$85 & 4095]($__ct,48)|0);
     $90 = $86;$__d$1$lcssa73 = $__d$1$lcssa74;$__f$0$lcssa71 = $__f$0$lcssa72;
    }
    $87 = ($__f$0$lcssa71|0)>(0);
    $88 = HEAP32[$__me>>2]|0;
    $89 = (($88) + 1|0);
    HEAP32[$__me>>2] = $89;
    if ($87) {
     $91 = $88;$__f$139 = $__f$0$lcssa71;
     while(1) {
      HEAP8[$91>>0] = $90;
      $92 = (($__f$139) + -1)|0;
      $93 = ($92|0)>(0);
      $94 = HEAP32[$__me>>2]|0;
      $95 = (($94) + 1|0);
      HEAP32[$__me>>2] = $95;
      if ($93) {
       $91 = $94;$__f$139 = $92;
      } else {
       $$lcssa38 = $94;
       break;
      }
     }
    } else {
     $$lcssa38 = $88;
    }
    HEAP8[$$lcssa38>>0] = $__dp;
    $__d$2 = $__d$1$lcssa73;
   } else {
    $__d$2 = $__d$0$lcssa;
   }
   $96 = ($__d$2|0)==($$$0|0);
   if ($96) {
    $97 = HEAP32[$__ct>>2]|0;
    $98 = (($97) + 28|0);
    $99 = HEAP32[$98>>2]|0;
    $100 = (FUNCTION_TABLE_iii[$99 & 4095]($__ct,48)|0);
    $101 = HEAP32[$__me>>2]|0;
    $102 = (($101) + 1|0);
    HEAP32[$__me>>2] = $102;
    HEAP8[$101>>0] = $100;
   } else {
    $103 = HEAP8[$__grp>>0]|0;
    $104 = $103 & 1;
    $105 = ($104<<24>>24)==(0);
    if ($105) {
     $107 = $103&255;
     $108 = $107 >>> 1;
     $110 = $108;
    } else {
     $106 = HEAP32[$11>>2]|0;
     $110 = $106;
    }
    $109 = ($110|0)==(0);
    if ($109) {
     $__d$343 = $__d$2;$__gl$046 = -1;$__ig$045 = 0;$__ng$044 = 0;
    } else {
     if ($105) {
      $113 = $9;
     } else {
      $111 = HEAP32[$10>>2]|0;
      $113 = $111;
     }
     $112 = HEAP8[$113>>0]|0;
     $114 = $112 << 24 >> 24;
     $__d$343 = $__d$2;$__gl$046 = $114;$__ig$045 = 0;$__ng$044 = 0;
    }
    while(1) {
     $115 = ($__ng$044|0)==($__gl$046|0);
     if ($115) {
      $116 = HEAP32[$__me>>2]|0;
      $117 = (($116) + 1|0);
      HEAP32[$__me>>2] = $117;
      HEAP8[$116>>0] = $__ts;
      $118 = (($__ig$045) + 1)|0;
      $119 = HEAP8[$__grp>>0]|0;
      $120 = $119 & 1;
      $121 = ($120<<24>>24)==(0);
      if ($121) {
       $123 = $119&255;
       $124 = $123 >>> 1;
       $126 = $124;
      } else {
       $122 = HEAP32[$11>>2]|0;
       $126 = $122;
      }
      $125 = ($118>>>0)<($126>>>0);
      if ($125) {
       if ($121) {
        $129 = $9;
       } else {
        $127 = HEAP32[$10>>2]|0;
        $129 = $127;
       }
       $128 = (($129) + ($118)|0);
       $130 = HEAP8[$128>>0]|0;
       $131 = ($130<<24>>24)==(127);
       if ($131) {
        $__gl$1 = -1;$__ig$1 = $118;$__ng$1 = 0;
       } else {
        if ($121) {
         $134 = $9;
        } else {
         $132 = HEAP32[$10>>2]|0;
         $134 = $132;
        }
        $133 = (($134) + ($118)|0);
        $135 = HEAP8[$133>>0]|0;
        $136 = $135 << 24 >> 24;
        $__gl$1 = $136;$__ig$1 = $118;$__ng$1 = 0;
       }
      } else {
       $__gl$1 = $__gl$046;$__ig$1 = $118;$__ng$1 = 0;
      }
     } else {
      $__gl$1 = $__gl$046;$__ig$1 = $__ig$045;$__ng$1 = $__ng$044;
     }
     $137 = (($__d$343) + -1|0);
     $138 = HEAP8[$137>>0]|0;
     $139 = HEAP32[$__me>>2]|0;
     $140 = (($139) + 1|0);
     HEAP32[$__me>>2] = $140;
     HEAP8[$139>>0] = $138;
     $141 = (($__ng$1) + 1)|0;
     $142 = ($137|0)==($$$0|0);
     if ($142) {
      break;
     } else {
      $__d$343 = $137;$__gl$046 = $__gl$1;$__ig$045 = $__ig$1;$__ng$044 = $141;
     }
    }
   }
   $143 = HEAP32[$__me>>2]|0;
   $144 = ($61|0)==($143|0);
   if ($144) {
    $$2 = $$$0;
   } else {
    $145 = (($143) + -1|0);
    $146 = ($145>>>0)>($61>>>0);
    if ($146) {
     $$012$i$i = $61;$149 = $145;
     while(1) {
      $147 = HEAP8[$$012$i$i>>0]|0;
      $148 = HEAP8[$149>>0]|0;
      HEAP8[$$012$i$i>>0] = $148;
      HEAP8[$149>>0] = $147;
      $150 = (($$012$i$i) + 1|0);
      $151 = (($149) + -1|0);
      $152 = ($150>>>0)<($151>>>0);
      if ($152) {
       $$012$i$i = $150;$149 = $151;
      } else {
       $$2 = $$$0;
       break;
      }
     }
    } else {
     $$2 = $$$0;
    }
   }
   break;
  }
  case 0:  {
   $17 = HEAP32[$__me>>2]|0;
   HEAP32[$__mi>>2] = $17;
   $$2 = $$050;
   break;
  }
  default: {
   $$2 = $$050;
  }
  }
  $153 = (($__p$049) + 1)|0;
  $exitcond = ($153|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $$050 = $$2;$__p$049 = $153;
  }
 }
 $154 = HEAP8[$__sn>>0]|0;
 $155 = $154 & 1;
 $156 = ($155<<24>>24)==(0);
 if ($156) {
  $158 = $154&255;
  $159 = $158 >>> 1;
  $161 = $159;
 } else {
  $157 = HEAP32[$2>>2]|0;
  $161 = $157;
 }
 $160 = ($161>>>0)>(1);
 if ($160) {
  if ($156) {
   $164 = $154&255;
   $165 = $164 >>> 1;
   $$pn = $0;$168 = $0;$169 = $165;
  } else {
   $162 = HEAP32[$1>>2]|0;
   $163 = HEAP32[$2>>2]|0;
   $$pn = $162;$168 = $162;$169 = $163;
  }
  $166 = (($$pn) + 1|0);
  $167 = (($168) + ($169)|0);
  $170 = HEAP32[$__me>>2]|0;
  $171 = ($166|0)==($167|0);
  if ($171) {
   $$0$lcssa$i$i = $170;
  } else {
   $$01$i$i = $170;$173 = $166;
   while(1) {
    $172 = HEAP8[$173>>0]|0;
    HEAP8[$$01$i$i>>0] = $172;
    $174 = (($173) + 1|0);
    $175 = (($$01$i$i) + 1|0);
    $176 = ($174|0)==($167|0);
    if ($176) {
     $$0$lcssa$i$i = $175;
     break;
    } else {
     $$01$i$i = $175;$173 = $174;
    }
   }
  }
  HEAP32[$__me>>2] = $$0$lcssa$i$i;
 }
 $177 = $__flags & 176;
 if ((($177|0) == 32)) {
  $178 = HEAP32[$__me>>2]|0;
  HEAP32[$__mi>>2] = $178;
  STACKTOP = sp;return;
 } else if ((($177|0) == 16)) {
  STACKTOP = sp;return;
 } else {
  HEAP32[$__mi>>2] = $__mb;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__19money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE($agg$result,$this,$__s,$__intl,$__iob,$__fl,$__digits) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__intl = $__intl|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__digits = $__digits|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy = 0, $$pn = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__dp = 0, $__fd = 0, $__grp = 0, $__loc = 0, $__mb$0 = 0, $__mbuf = 0, $__me = 0, $__mi = 0, $__pat = 0, $__sn = 0;
 var $__sym = 0, $__ts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $$byval_copy = sp + 60|0;
 $__loc = sp + 52|0;
 $__pat = sp + 56|0;
 $__dp = sp + 164|0;
 $__ts = sp + 165|0;
 $__grp = sp + 40|0;
 $__sym = sp + 28|0;
 $__sn = sp + 12|0;
 $__fd = sp + 8|0;
 $__mbuf = sp + 64|0;
 $__mi = sp + 4|0;
 $__me = sp;
 $0 = sp + 24|0;
 __ZNKSt3__18ios_base6getlocEv($__loc,$__iob);
 __THREW__ = 0;
 $1 = (invoke_iii(2228,($__loc|0),(3093336|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = HEAP8[$__digits>>0]|0;
   $5 = $4 & 1;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $9 = $4&255;
    $10 = $9 >>> 1;
    $12 = $10;
   } else {
    $7 = (($__digits) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $12 = $8;
   }
   $11 = ($12|0)==(0);
   if ($11) {
    $25 = 0;
   } else {
    if ($6) {
     $15 = (($__digits) + 1|0);
     $17 = $15;
    } else {
     $13 = (($__digits) + 8|0);
     $14 = HEAP32[$13>>2]|0;
     $17 = $14;
    }
    $16 = HEAP8[$17>>0]|0;
    $18 = HEAP32[$1>>2]|0;
    $19 = (($18) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    $21 = (invoke_iii($20|0,($1|0),45)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = ($16<<24>>24)==($21<<24>>24);
    $25 = $24;
   }
   HEAP32[$__pat>>2] = 0;
   ;HEAP32[$__grp+0>>2]=0|0;HEAP32[$__grp+4>>2]=0|0;HEAP32[$__grp+8>>2]=0|0;
   ;HEAP32[$__sym+0>>2]=0|0;HEAP32[$__sym+4>>2]=0|0;HEAP32[$__sym+8>>2]=0|0;
   ;HEAP32[$__sn+0>>2]=0|0;HEAP32[$__sn+4>>2]=0|0;HEAP32[$__sn+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viiiiiiiiii(12,($__intl|0),($25|0),($__loc|0),($__pat|0),($__dp|0),($__ts|0),($__grp|0),($__sym|0),($__sn|0),($__fd|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   L15: do {
    if ($27) {
     $92 = ___cxa_find_matching_catch()|0;
     $93 = tempRet0;
     $$0 = $92;$$01 = $93;
    } else {
     $28 = HEAP8[$__digits>>0]|0;
     $29 = $28 & 1;
     $30 = ($29<<24>>24)==(0);
     if ($30) {
      $33 = $28&255;
      $34 = $33 >>> 1;
      $37 = $34;
     } else {
      $31 = (($__digits) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $37 = $32;
     }
     $35 = HEAP32[$__fd>>2]|0;
     $36 = ($37|0)>($35|0);
     if ($36) {
      if ($30) {
       $40 = $28&255;
       $41 = $40 >>> 1;
       $43 = $41;
      } else {
       $38 = (($__digits) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       $43 = $39;
      }
      $42 = (($43) - ($35))|0;
      $44 = $42 << 1;
      $45 = HEAP8[$__sn>>0]|0;
      $46 = $45 & 1;
      $47 = ($46<<24>>24)==(0);
      if ($47) {
       $50 = $45&255;
       $51 = $50 >>> 1;
       $61 = $51;
      } else {
       $48 = (($__sn) + 4|0);
       $49 = HEAP32[$48>>2]|0;
       $61 = $49;
      }
      $52 = HEAP8[$__sym>>0]|0;
      $53 = $52 & 1;
      $54 = ($53<<24>>24)==(0);
      if ($54) {
       $57 = $52&255;
       $58 = $57 >>> 1;
       $63 = $58;
      } else {
       $55 = (($__sym) + 4|0);
       $56 = HEAP32[$55>>2]|0;
       $63 = $56;
      }
      $59 = $44 | 1;
      $60 = (($61) + ($59))|0;
      $62 = (($60) + ($63))|0;
      $$pn = $62;
     } else {
      $64 = HEAP8[$__sn>>0]|0;
      $65 = $64 & 1;
      $66 = ($65<<24>>24)==(0);
      if ($66) {
       $69 = $64&255;
       $70 = $69 >>> 1;
       $79 = $70;
      } else {
       $67 = (($__sn) + 4|0);
       $68 = HEAP32[$67>>2]|0;
       $79 = $68;
      }
      $71 = HEAP8[$__sym>>0]|0;
      $72 = $71 & 1;
      $73 = ($72<<24>>24)==(0);
      if ($73) {
       $76 = $71&255;
       $77 = $76 >>> 1;
       $81 = $77;
      } else {
       $74 = (($__sym) + 4|0);
       $75 = HEAP32[$74>>2]|0;
       $81 = $75;
      }
      $78 = (($79) + 2)|0;
      $80 = (($78) + ($81))|0;
      $$pn = $80;
     }
     $82 = (($$pn) + ($35))|0;
     $83 = ($82>>>0)>(100);
     do {
      if ($83) {
       $84 = (_malloc($82)|0);
       $85 = ($84|0)==(0|0);
       if ($85) {
        __THREW__ = 0;
        invoke_v(1012);
        $86 = __THREW__; __THREW__ = 0;
        $87 = $86&1;
        if ($87) {
         $88 = ___cxa_find_matching_catch()|0;
         $89 = tempRet0;
         $$0 = $88;$$01 = $89;
         break L15;
        } else {
         $$pre = HEAP8[$__digits>>0]|0;
         $100 = $$pre;$96 = 0;$__mb$0 = 0;
         break;
        }
       } else {
        $100 = $28;$96 = $84;$__mb$0 = $84;
       }
      } else {
       $100 = $28;$96 = 0;$__mb$0 = $__mbuf;
      }
     } while(0);
     $97 = (($__iob) + 4|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = $100 & 1;
     $101 = ($99<<24>>24)==(0);
     if ($101) {
      $106 = (($__digits) + 1|0);
      $107 = $100&255;
      $108 = $107 >>> 1;
      $110 = $106;$111 = $108;
     } else {
      $102 = (($__digits) + 8|0);
      $103 = HEAP32[$102>>2]|0;
      $104 = (($__digits) + 4|0);
      $105 = HEAP32[$104>>2]|0;
      $110 = $103;$111 = $105;
     }
     $109 = (($110) + ($111)|0);
     $112 = HEAP8[$__dp>>0]|0;
     $113 = HEAP8[$__ts>>0]|0;
     __THREW__ = 0;
     invoke_viiiiiiiiiiiiiii(1,($__mb$0|0),($__mi|0),($__me|0),($98|0),($110|0),($109|0),($1|0),($25|0),($__pat|0),($112|0),($113|0),($__grp|0),($__sym|0),($__sn|0),($35|0));
     $114 = __THREW__; __THREW__ = 0;
     $115 = $114&1;
     if (!($115)) {
      $116 = HEAP32[$__s>>2]|0;
      HEAP32[$0>>2] = $116;
      $117 = HEAP32[$__mi>>2]|0;
      $118 = HEAP32[$__me>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_viiiiiii(60,($agg$result|0),($$byval_copy|0),($__mb$0|0),($117|0),($118|0),($__iob|0),($__fl|0));
      $119 = __THREW__; __THREW__ = 0;
      $120 = $119&1;
      if (!($120)) {
       _free($96);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sn);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sym);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
       $121 = HEAP32[$__loc>>2]|0;
       (__ZNSt3__114__shared_count16__release_sharedEv($121)|0);
       STACKTOP = sp;return;
      }
     }
     $94 = ___cxa_find_matching_catch()|0;
     $95 = tempRet0;
     _free($96);
     $$0 = $94;$$01 = $95;
    }
   } while(0);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sn);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__sym);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
   $$1 = $$0;$$12 = $$01;
   $122 = HEAP32[$__loc>>2]|0;
   (__ZNSt3__114__shared_count16__release_sharedEv($122)|0);
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $90 = ___cxa_find_matching_catch()|0;
 $91 = tempRet0;
 $$1 = $90;$$12 = $91;
 $122 = HEAP32[$__loc>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($122)|0);
 ___resumeException($$1|0);
 // unreachable;
}
function __ZNSt3__19money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__19money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__19money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe($agg$result,$this,$__s,$__intl,$__iob,$__fl,$__units) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__intl = $__intl|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__units = +$__units;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$2 = 0, $$23 = 0, $$byval_copy = 0, $$pn = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__bb = 0, $__buf = 0, $__db$0 = 0, $__digits = 0, $__dp = 0, $__fd = 0, $__grp = 0, $__loc = 0, $__mb$0 = 0, $__mbuf = 0;
 var $__me = 0, $__mi = 0, $__n$0 = 0, $__pat = 0, $__sn = 0, $__sym = 0, $__ts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 992|0;
 $$byval_copy = sp;
 $__buf = sp + 888|0;
 $__bb = sp + 872|0;
 $__digits = sp + 472|0;
 $__loc = sp + 464|0;
 $__pat = sp + 460|0;
 $__dp = sp + 456|0;
 $__ts = sp + 452|0;
 $__grp = sp + 876|0;
 $__sym = sp + 432|0;
 $__sn = sp + 420|0;
 $__fd = sp + 416|0;
 $__mbuf = sp + 16|0;
 $__mi = sp + 8|0;
 $__me = sp + 444|0;
 $0 = sp + 448|0;
 HEAP32[$__bb>>2] = $__buf;
 HEAPF64[tempDoublePtr>>3]=$__units;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $1 = (_snprintf($__buf,100,3093088,$$byval_copy)|0);
 $2 = ($1>>>0)>(99);
 do {
  if ($2) {
   __THREW__ = 0;
   $3 = (invoke_i(134)|0);
   $4 = __THREW__; __THREW__ = 0;
   $5 = $4&1;
   if ($5) {
    $118 = 0;$119 = 0;
    label = 7;
   } else {
    __THREW__ = 0;
    HEAPF64[tempDoublePtr>>3]=$__units;HEAP32[$$byval_copy>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$$byval_copy+4>>2]=HEAP32[tempDoublePtr+4>>2];
    $6 = (invoke_iiiii(342,($__bb|0),($3|0),(3093088|0),($$byval_copy|0))|0);
    $7 = __THREW__; __THREW__ = 0;
    $8 = $7&1;
    if ($8) {
     $118 = 0;$119 = 0;
     label = 7;
    } else {
     $9 = HEAP32[$__bb>>2]|0;
     $10 = ($9|0)==(0|0);
     if ($10) {
      __THREW__ = 0;
      invoke_v(1012);
      $11 = __THREW__; __THREW__ = 0;
      $12 = $11&1;
      if ($12) {
       $118 = 0;$119 = 0;
       label = 7;
       break;
      }
      $$pre = HEAP32[$__bb>>2]|0;
      $120 = $$pre;
     } else {
      $120 = $9;
     }
     $15 = $6 << 2;
     $16 = (_malloc($15)|0);
     $17 = ($16|0)==(0|0);
     if ($17) {
      __THREW__ = 0;
      invoke_v(1012);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if ($19) {
       $118 = $120;$119 = 0;
       label = 7;
      } else {
       $112 = 0;$113 = $120;$__db$0 = 0;$__n$0 = $6;
       label = 10;
      }
     } else {
      $112 = $16;$113 = $120;$__db$0 = $16;$__n$0 = $6;
      label = 10;
     }
    }
   }
  } else {
   $112 = 0;$113 = 0;$__db$0 = $__digits;$__n$0 = $1;
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  __THREW__ = 0;
  invoke_vii(2475,($__loc|0),($__iob|0));
  $20 = __THREW__; __THREW__ = 0;
  $21 = $20&1;
  if ($21) {
   $118 = $113;$119 = $112;
   label = 7;
  } else {
   __THREW__ = 0;
   $22 = (invoke_iii(2228,($__loc|0),(3093328|0))|0);
   $23 = __THREW__; __THREW__ = 0;
   $24 = $23&1;
   if ($24) {
    label = 35;
   } else {
    $25 = HEAP32[$__bb>>2]|0;
    $26 = (($25) + ($__n$0)|0);
    $27 = HEAP32[$22>>2]|0;
    $28 = (($27) + 48|0);
    $29 = HEAP32[$28>>2]|0;
    __THREW__ = 0;
    (invoke_iiiii($29|0,($22|0),($25|0),($26|0),($__db$0|0))|0);
    $30 = __THREW__; __THREW__ = 0;
    $31 = $30&1;
    if ($31) {
     label = 35;
    } else {
     $32 = ($__n$0|0)==(0);
     if ($32) {
      $36 = 0;
     } else {
      $33 = HEAP32[$__bb>>2]|0;
      $34 = HEAP8[$33>>0]|0;
      $35 = ($34<<24>>24)==(45);
      $36 = $35;
     }
     HEAP32[$__pat>>2] = 0;
     ;HEAP32[$__grp+0>>2]=0|0;HEAP32[$__grp+4>>2]=0|0;HEAP32[$__grp+8>>2]=0|0;
     ;HEAP32[$__sym+0>>2]=0|0;HEAP32[$__sym+4>>2]=0|0;HEAP32[$__sym+8>>2]=0|0;
     ;HEAP32[$__sn+0>>2]=0|0;HEAP32[$__sn+4>>2]=0|0;HEAP32[$__sn+8>>2]=0|0;
     __THREW__ = 0;
     invoke_viiiiiiiiii(13,($__intl|0),($36|0),($__loc|0),($__pat|0),($__dp|0),($__ts|0),($__grp|0),($__sym|0),($__sn|0),($__fd|0));
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     do {
      if ($38) {
       $91 = ___cxa_find_matching_catch()|0;
       $92 = tempRet0;
       $$0 = $91;$$01 = $92;
      } else {
       $39 = HEAP32[$__fd>>2]|0;
       $40 = ($__n$0|0)>($39|0);
       if ($40) {
        $41 = (($__n$0) - ($39))|0;
        $42 = $41 << 1;
        $43 = HEAP8[$__sn>>0]|0;
        $44 = $43 & 1;
        $45 = ($44<<24>>24)==(0);
        if ($45) {
         $48 = $43&255;
         $49 = $48 >>> 1;
         $59 = $49;
        } else {
         $46 = (($__sn) + 4|0);
         $47 = HEAP32[$46>>2]|0;
         $59 = $47;
        }
        $50 = HEAP8[$__sym>>0]|0;
        $51 = $50 & 1;
        $52 = ($51<<24>>24)==(0);
        if ($52) {
         $55 = $50&255;
         $56 = $55 >>> 1;
         $61 = $56;
        } else {
         $53 = (($__sym) + 4|0);
         $54 = HEAP32[$53>>2]|0;
         $61 = $54;
        }
        $57 = $42 | 1;
        $58 = (($59) + ($57))|0;
        $60 = (($58) + ($61))|0;
        $$pn = $60;
       } else {
        $62 = HEAP8[$__sn>>0]|0;
        $63 = $62 & 1;
        $64 = ($63<<24>>24)==(0);
        if ($64) {
         $67 = $62&255;
         $68 = $67 >>> 1;
         $77 = $68;
        } else {
         $65 = (($__sn) + 4|0);
         $66 = HEAP32[$65>>2]|0;
         $77 = $66;
        }
        $69 = HEAP8[$__sym>>0]|0;
        $70 = $69 & 1;
        $71 = ($70<<24>>24)==(0);
        if ($71) {
         $74 = $69&255;
         $75 = $74 >>> 1;
         $79 = $75;
        } else {
         $72 = (($__sym) + 4|0);
         $73 = HEAP32[$72>>2]|0;
         $79 = $73;
        }
        $76 = (($77) + 2)|0;
        $78 = (($76) + ($79))|0;
        $$pn = $78;
       }
       $80 = (($$pn) + ($39))|0;
       $81 = ($80>>>0)>(100);
       if ($81) {
        $82 = $80 << 2;
        $83 = (_malloc($82)|0);
        $84 = ($83|0)==(0|0);
        if ($84) {
         __THREW__ = 0;
         invoke_v(1012);
         $85 = __THREW__; __THREW__ = 0;
         $86 = $85&1;
         if ($86) {
          $87 = ___cxa_find_matching_catch()|0;
          $88 = tempRet0;
          $$0 = $87;$$01 = $88;
          break;
         } else {
          $96 = 0;$__mb$0 = 0;
         }
        } else {
         $96 = $83;$__mb$0 = $83;
        }
       } else {
        $96 = 0;$__mb$0 = $__mbuf;
       }
       $97 = (($__iob) + 4|0);
       $98 = HEAP32[$97>>2]|0;
       $99 = (($__db$0) + ($__n$0<<2)|0);
       $100 = HEAP32[$__dp>>2]|0;
       $101 = HEAP32[$__ts>>2]|0;
       __THREW__ = 0;
       invoke_viiiiiiiiiiiiiii(2,($__mb$0|0),($__mi|0),($__me|0),($98|0),($__db$0|0),($99|0),($22|0),($36|0),($__pat|0),($100|0),($101|0),($__grp|0),($__sym|0),($__sn|0),($39|0));
       $102 = __THREW__; __THREW__ = 0;
       $103 = $102&1;
       if (!($103)) {
        $104 = HEAP32[$__s>>2]|0;
        HEAP32[$0>>2] = $104;
        $105 = HEAP32[$__mi>>2]|0;
        $106 = HEAP32[$__me>>2]|0;
        __THREW__ = 0;
        ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
        invoke_viiiiiii(81,($agg$result|0),($$byval_copy|0),($__mb$0|0),($105|0),($106|0),($__iob|0),($__fl|0));
        $107 = __THREW__; __THREW__ = 0;
        $108 = $107&1;
        if (!($108)) {
         $109 = ($96|0)==(0|0);
         if (!($109)) {
          _free($96);
         }
         __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sn);
         __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sym);
         __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
         $110 = HEAP32[$__loc>>2]|0;
         (__ZNSt3__114__shared_count16__release_sharedEv($110)|0);
         $111 = ($112|0)==(0|0);
         if ($111) {
          _free($113);
          STACKTOP = sp;return;
         }
         _free($112);
         _free($113);
         STACKTOP = sp;return;
        }
       }
       $93 = ___cxa_find_matching_catch()|0;
       $94 = tempRet0;
       $95 = ($96|0)==(0|0);
       if ($95) {
        $$0 = $93;$$01 = $94;
       } else {
        _free($96);
        $$0 = $93;$$01 = $94;
       }
      }
     } while(0);
     __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sn);
     __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sym);
     __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
     $$1 = $$0;$$12 = $$01;
    }
   }
   if ((label|0) == 35) {
    $89 = ___cxa_find_matching_catch()|0;
    $90 = tempRet0;
    $$1 = $89;$$12 = $90;
   }
   $114 = HEAP32[$__loc>>2]|0;
   (__ZNSt3__114__shared_count16__release_sharedEv($114)|0);
   $$2 = $$1;$$23 = $$12;$116 = $112;$117 = $113;
  }
 }
 if ((label|0) == 7) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  $$2 = $13;$$23 = $14;$116 = $119;$117 = $118;
 }
 $115 = ($116|0)==(0|0);
 if ($115) {
  _free($117);
  ___resumeException($$2|0);
  // unreachable;
 }
 _free($116);
 _free($117);
 ___resumeException($$2|0);
 // unreachable;
}
function __ZNSt3__111__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri($__intl,$__neg,$__loc,$__pat,$__dp,$__ts,$__grp,$__sym,$__sn,$__fd) {
 $__intl = $__intl|0;
 $__neg = $__neg|0;
 $__loc = $__loc|0;
 $__pat = $__pat|0;
 $__dp = $__dp|0;
 $__ts = $__ts|0;
 $__grp = $__grp|0;
 $__sym = $__sym|0;
 $__sn = $__sn|0;
 $__fd = $__fd|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $0 = sp + 108|0;
 $1 = sp + 96|0;
 $2 = sp + 92|0;
 $3 = sp + 80|0;
 $4 = sp + 68|0;
 $5 = sp + 56|0;
 $6 = sp + 52|0;
 $7 = sp + 28|0;
 $8 = sp + 24|0;
 $9 = sp + 12|0;
 $10 = sp;
 $11 = sp + 40|0;
 if ($__intl) {
  $12 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3092904)|0);
  $13 = HEAP32[$12>>2]|0;
  do {
   if ($__neg) {
    $14 = (($13) + 44|0);
    $15 = HEAP32[$14>>2]|0;
    FUNCTION_TABLE_vii[$15 & 4095]($0,$12);
    $16 = HEAP32[$0>>2]|0;
    HEAP8[$__pat>>0]=$16&255;HEAP8[$__pat+1>>0]=($16>>8)&255;HEAP8[$__pat+2>>0]=($16>>16)&255;HEAP8[$__pat+3>>0]=$16>>24;
    $17 = HEAP32[$12>>2]|0;
    $18 = (($17) + 32|0);
    $19 = HEAP32[$18>>2]|0;
    FUNCTION_TABLE_vii[$19 & 4095]($1,$12);
    $20 = HEAP8[$__sn>>0]|0;
    $21 = $20 & 1;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     $26 = (($__sn) + 4|0);
     HEAP32[$26>>2] = 0;
     HEAP8[$__sn>>0] = 0;
    } else {
     $23 = (($__sn) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     HEAP32[$24>>2] = 0;
     $25 = (($__sn) + 4|0);
     HEAP32[$25>>2] = 0;
    }
    __THREW__ = 0;
    invoke_vii(3510,($__sn|0),0);
    $27 = __THREW__; __THREW__ = 0;
    $28 = $27&1;
    if ($28) {
     $29 = ___cxa_find_matching_catch(0|0)|0;
     $30 = tempRet0;
     ___clang_call_terminate($29);
     // unreachable;
    } else {
     ;HEAP32[$__sn+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__sn+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__sn+8>>2]=HEAP32[$1+8>>2]|0;
     ;HEAP32[$1+0>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;
     __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($1);
     break;
    }
   } else {
    $31 = (($13) + 40|0);
    $32 = HEAP32[$31>>2]|0;
    FUNCTION_TABLE_vii[$32 & 4095]($2,$12);
    $33 = HEAP32[$2>>2]|0;
    HEAP8[$__pat>>0]=$33&255;HEAP8[$__pat+1>>0]=($33>>8)&255;HEAP8[$__pat+2>>0]=($33>>16)&255;HEAP8[$__pat+3>>0]=$33>>24;
    $34 = HEAP32[$12>>2]|0;
    $35 = (($34) + 28|0);
    $36 = HEAP32[$35>>2]|0;
    FUNCTION_TABLE_vii[$36 & 4095]($3,$12);
    $37 = HEAP8[$__sn>>0]|0;
    $38 = $37 & 1;
    $39 = ($38<<24>>24)==(0);
    if ($39) {
     $43 = (($__sn) + 4|0);
     HEAP32[$43>>2] = 0;
     HEAP8[$__sn>>0] = 0;
    } else {
     $40 = (($__sn) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     HEAP32[$41>>2] = 0;
     $42 = (($__sn) + 4|0);
     HEAP32[$42>>2] = 0;
    }
    __THREW__ = 0;
    invoke_vii(3510,($__sn|0),0);
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     $46 = ___cxa_find_matching_catch(0|0)|0;
     $47 = tempRet0;
     ___clang_call_terminate($46);
     // unreachable;
    } else {
     ;HEAP32[$__sn+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$__sn+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$__sn+8>>2]=HEAP32[$3+8>>2]|0;
     ;HEAP32[$3+0>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;
     __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($3);
     break;
    }
   }
  } while(0);
  $48 = HEAP32[$12>>2]|0;
  $49 = (($48) + 12|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (FUNCTION_TABLE_ii[$50 & 4095]($12)|0);
  HEAP32[$__dp>>2] = $51;
  $52 = HEAP32[$12>>2]|0;
  $53 = (($52) + 16|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = (FUNCTION_TABLE_ii[$54 & 4095]($12)|0);
  HEAP32[$__ts>>2] = $55;
  $56 = HEAP32[$12>>2]|0;
  $57 = (($56) + 20|0);
  $58 = HEAP32[$57>>2]|0;
  FUNCTION_TABLE_vii[$58 & 4095]($4,$12);
  $59 = HEAP8[$__grp>>0]|0;
  $60 = $59 & 1;
  $61 = ($60<<24>>24)==(0);
  if ($61) {
   $65 = (($__grp) + 1|0);
   HEAP8[$65>>0] = 0;
   HEAP8[$__grp>>0] = 0;
  } else {
   $62 = (($__grp) + 8|0);
   $63 = HEAP32[$62>>2]|0;
   HEAP8[$63>>0] = 0;
   $64 = (($__grp) + 4|0);
   HEAP32[$64>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__grp|0),0);
  $66 = __THREW__; __THREW__ = 0;
  $67 = $66&1;
  if ($67) {
   $68 = ___cxa_find_matching_catch(0|0)|0;
   $69 = tempRet0;
   ___clang_call_terminate($68);
   // unreachable;
  }
  ;HEAP32[$__grp+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__grp+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__grp+8>>2]=HEAP32[$4+8>>2]|0;
  ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($4);
  $70 = HEAP32[$12>>2]|0;
  $71 = (($70) + 24|0);
  $72 = HEAP32[$71>>2]|0;
  FUNCTION_TABLE_vii[$72 & 4095]($5,$12);
  $73 = HEAP8[$__sym>>0]|0;
  $74 = $73 & 1;
  $75 = ($74<<24>>24)==(0);
  if ($75) {
   $79 = (($__sym) + 4|0);
   HEAP32[$79>>2] = 0;
   HEAP8[$__sym>>0] = 0;
  } else {
   $76 = (($__sym) + 8|0);
   $77 = HEAP32[$76>>2]|0;
   HEAP32[$77>>2] = 0;
   $78 = (($__sym) + 4|0);
   HEAP32[$78>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3510,($__sym|0),0);
  $80 = __THREW__; __THREW__ = 0;
  $81 = $80&1;
  if ($81) {
   $82 = ___cxa_find_matching_catch(0|0)|0;
   $83 = tempRet0;
   ___clang_call_terminate($82);
   // unreachable;
  }
  ;HEAP32[$__sym+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$__sym+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$__sym+8>>2]=HEAP32[$5+8>>2]|0;
  ;HEAP32[$5+0>>2]=0|0;HEAP32[$5+4>>2]=0|0;HEAP32[$5+8>>2]=0|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($5);
  $84 = HEAP32[$12>>2]|0;
  $85 = (($84) + 36|0);
  $86 = HEAP32[$85>>2]|0;
  $87 = (FUNCTION_TABLE_ii[$86 & 4095]($12)|0);
  $storemerge = $87;
  HEAP32[$__fd>>2] = $storemerge;
  STACKTOP = sp;return;
 } else {
  $88 = (__ZNKSt3__16locale9use_facetERNS0_2idE($__loc,3092840)|0);
  $89 = HEAP32[$88>>2]|0;
  do {
   if ($__neg) {
    $90 = (($89) + 44|0);
    $91 = HEAP32[$90>>2]|0;
    FUNCTION_TABLE_vii[$91 & 4095]($6,$88);
    $92 = HEAP32[$6>>2]|0;
    HEAP8[$__pat>>0]=$92&255;HEAP8[$__pat+1>>0]=($92>>8)&255;HEAP8[$__pat+2>>0]=($92>>16)&255;HEAP8[$__pat+3>>0]=$92>>24;
    $93 = HEAP32[$88>>2]|0;
    $94 = (($93) + 32|0);
    $95 = HEAP32[$94>>2]|0;
    FUNCTION_TABLE_vii[$95 & 4095]($7,$88);
    $96 = HEAP8[$__sn>>0]|0;
    $97 = $96 & 1;
    $98 = ($97<<24>>24)==(0);
    if ($98) {
     $102 = (($__sn) + 4|0);
     HEAP32[$102>>2] = 0;
     HEAP8[$__sn>>0] = 0;
    } else {
     $99 = (($__sn) + 8|0);
     $100 = HEAP32[$99>>2]|0;
     HEAP32[$100>>2] = 0;
     $101 = (($__sn) + 4|0);
     HEAP32[$101>>2] = 0;
    }
    __THREW__ = 0;
    invoke_vii(3510,($__sn|0),0);
    $103 = __THREW__; __THREW__ = 0;
    $104 = $103&1;
    if ($104) {
     $105 = ___cxa_find_matching_catch(0|0)|0;
     $106 = tempRet0;
     ___clang_call_terminate($105);
     // unreachable;
    } else {
     ;HEAP32[$__sn+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$__sn+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$__sn+8>>2]=HEAP32[$7+8>>2]|0;
     ;HEAP32[$7+0>>2]=0|0;HEAP32[$7+4>>2]=0|0;HEAP32[$7+8>>2]=0|0;
     __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($7);
     break;
    }
   } else {
    $107 = (($89) + 40|0);
    $108 = HEAP32[$107>>2]|0;
    FUNCTION_TABLE_vii[$108 & 4095]($8,$88);
    $109 = HEAP32[$8>>2]|0;
    HEAP8[$__pat>>0]=$109&255;HEAP8[$__pat+1>>0]=($109>>8)&255;HEAP8[$__pat+2>>0]=($109>>16)&255;HEAP8[$__pat+3>>0]=$109>>24;
    $110 = HEAP32[$88>>2]|0;
    $111 = (($110) + 28|0);
    $112 = HEAP32[$111>>2]|0;
    FUNCTION_TABLE_vii[$112 & 4095]($9,$88);
    $113 = HEAP8[$__sn>>0]|0;
    $114 = $113 & 1;
    $115 = ($114<<24>>24)==(0);
    if ($115) {
     $119 = (($__sn) + 4|0);
     HEAP32[$119>>2] = 0;
     HEAP8[$__sn>>0] = 0;
    } else {
     $116 = (($__sn) + 8|0);
     $117 = HEAP32[$116>>2]|0;
     HEAP32[$117>>2] = 0;
     $118 = (($__sn) + 4|0);
     HEAP32[$118>>2] = 0;
    }
    __THREW__ = 0;
    invoke_vii(3510,($__sn|0),0);
    $120 = __THREW__; __THREW__ = 0;
    $121 = $120&1;
    if ($121) {
     $122 = ___cxa_find_matching_catch(0|0)|0;
     $123 = tempRet0;
     ___clang_call_terminate($122);
     // unreachable;
    } else {
     ;HEAP32[$__sn+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__sn+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__sn+8>>2]=HEAP32[$9+8>>2]|0;
     ;HEAP32[$9+0>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;
     __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($9);
     break;
    }
   }
  } while(0);
  $124 = HEAP32[$88>>2]|0;
  $125 = (($124) + 12|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (FUNCTION_TABLE_ii[$126 & 4095]($88)|0);
  HEAP32[$__dp>>2] = $127;
  $128 = HEAP32[$88>>2]|0;
  $129 = (($128) + 16|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = (FUNCTION_TABLE_ii[$130 & 4095]($88)|0);
  HEAP32[$__ts>>2] = $131;
  $132 = HEAP32[$88>>2]|0;
  $133 = (($132) + 20|0);
  $134 = HEAP32[$133>>2]|0;
  FUNCTION_TABLE_vii[$134 & 4095]($10,$88);
  $135 = HEAP8[$__grp>>0]|0;
  $136 = $135 & 1;
  $137 = ($136<<24>>24)==(0);
  if ($137) {
   $141 = (($__grp) + 1|0);
   HEAP8[$141>>0] = 0;
   HEAP8[$__grp>>0] = 0;
  } else {
   $138 = (($__grp) + 8|0);
   $139 = HEAP32[$138>>2]|0;
   HEAP8[$139>>0] = 0;
   $140 = (($__grp) + 4|0);
   HEAP32[$140>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3257,($__grp|0),0);
  $142 = __THREW__; __THREW__ = 0;
  $143 = $142&1;
  if ($143) {
   $144 = ___cxa_find_matching_catch(0|0)|0;
   $145 = tempRet0;
   ___clang_call_terminate($144);
   // unreachable;
  }
  ;HEAP32[$__grp+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$__grp+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$__grp+8>>2]=HEAP32[$10+8>>2]|0;
  ;HEAP32[$10+0>>2]=0|0;HEAP32[$10+4>>2]=0|0;HEAP32[$10+8>>2]=0|0;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($10);
  $146 = HEAP32[$88>>2]|0;
  $147 = (($146) + 24|0);
  $148 = HEAP32[$147>>2]|0;
  FUNCTION_TABLE_vii[$148 & 4095]($11,$88);
  $149 = HEAP8[$__sym>>0]|0;
  $150 = $149 & 1;
  $151 = ($150<<24>>24)==(0);
  if ($151) {
   $155 = (($__sym) + 4|0);
   HEAP32[$155>>2] = 0;
   HEAP8[$__sym>>0] = 0;
  } else {
   $152 = (($__sym) + 8|0);
   $153 = HEAP32[$152>>2]|0;
   HEAP32[$153>>2] = 0;
   $154 = (($__sym) + 4|0);
   HEAP32[$154>>2] = 0;
  }
  __THREW__ = 0;
  invoke_vii(3510,($__sym|0),0);
  $156 = __THREW__; __THREW__ = 0;
  $157 = $156&1;
  if ($157) {
   $158 = ___cxa_find_matching_catch(0|0)|0;
   $159 = tempRet0;
   ___clang_call_terminate($158);
   // unreachable;
  }
  ;HEAP32[$__sym+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$__sym+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$__sym+8>>2]=HEAP32[$11+8>>2]|0;
  ;HEAP32[$11+0>>2]=0|0;HEAP32[$11+4>>2]=0|0;HEAP32[$11+8>>2]=0|0;
  __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($11);
  $160 = HEAP32[$88>>2]|0;
  $161 = (($160) + 36|0);
  $162 = HEAP32[$161>>2]|0;
  $163 = (FUNCTION_TABLE_ii[$162 & 4095]($88)|0);
  $storemerge = $163;
  HEAP32[$__fd>>2] = $storemerge;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__111__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i($__mb,$__mi,$__me,$__flags,$__db,$__de,$__ct,$__neg,$__pat,$__dp,$__ts,$__grp,$__sym,$__sn,$__fd) {
 $__mb = $__mb|0;
 $__mi = $__mi|0;
 $__me = $__me|0;
 $__flags = $__flags|0;
 $__db = $__db|0;
 $__de = $__de|0;
 $__ct = $__ct|0;
 $__neg = $__neg|0;
 $__pat = $__pat|0;
 $__dp = $__dp|0;
 $__ts = $__ts|0;
 $__grp = $__grp|0;
 $__sym = $__sym|0;
 $__sn = $__sn|0;
 $__fd = $__fd|0;
 var $$$0 = 0, $$0$lcssa$i$i = 0, $$0$lcssa$i$i22 = 0, $$01$i$i = 0, $$01$i$i19 = 0, $$012$i$i = 0, $$059 = 0, $$2 = 0, $$lcssa44 = 0, $$pn = 0, $$promoted4$i$i = 0, $$promoted4$i$i13 = 0, $$sum = 0, $$sum33 = 0, $$sum75 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $87$phi = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__d$0$lcssa = 0, $__d$034 = 0, $__d$1$lcssa7880 = 0, $__d$1$lcssa79 = 0, $__d$137 = 0, $__d$2 = 0;
 var $__d$353 = 0, $__f$0$lcssa77 = 0, $__f$038 = 0, $__f$145 = 0, $__gl$056 = 0, $__gl$1 = 0, $__ig$055 = 0, $__ig$1 = 0, $__me$promoted = 0, $__ng$054 = 0, $__ng$1 = 0, $__p$058 = 0, $brmerge = 0, $exitcond = 0, $or$cond = 0, $scevgep = 0, $scevgep$i$i = 0, $scevgep$i$i14 = 0, $scevgep6$i$i = 0, $scevgep6$i$i20 = 0;
 var $scevgep70 = 0, $uglygep$i$i = 0, $uglygep$i$i16 = 0, $uglygep5$i$i = 0, $uglygep5$i$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$__me>>2] = $__mb;
 $0 = (($__sn) + 4|0);
 $1 = (($__sn) + 8|0);
 $2 = $__flags & 512;
 $3 = ($2|0)==(0);
 $4 = (($__sym) + 4|0);
 $5 = (($__sym) + 8|0);
 $6 = ($__fd|0)>(0);
 $7 = (($__grp) + 1|0);
 $8 = (($__grp) + 8|0);
 $9 = (($__grp) + 4|0);
 $$059 = $__db;$__p$058 = 0;
 while(1) {
  $10 = (($__pat) + ($__p$058)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 << 24 >> 24;
  switch ($12|0) {
  case 0:  {
   $13 = HEAP32[$__me>>2]|0;
   HEAP32[$__mi>>2] = $13;
   $$2 = $$059;
   break;
  }
  case 4:  {
   $60 = HEAP32[$__me>>2]|0;
   $61 = (($$059) + 4|0);
   $$$0 = $__neg ? $61 : $$059;
   $62 = ($$$0>>>0)<($__de>>>0);
   L6: do {
    if ($62) {
     $__d$034 = $$$0;
     while(1) {
      $65 = HEAP32[$__d$034>>2]|0;
      $66 = HEAP32[$__ct>>2]|0;
      $67 = (($66) + 12|0);
      $68 = HEAP32[$67>>2]|0;
      $69 = (FUNCTION_TABLE_iiii[$68 & 2047]($__ct,2048,$65)|0);
      $64 = (($__d$034) + 4|0);
      if (!($69)) {
       $__d$0$lcssa = $__d$034;
       break L6;
      }
      $63 = ($64>>>0)<($__de>>>0);
      if ($63) {
       $__d$034 = $64;
      } else {
       $__d$0$lcssa = $64;
       break;
      }
     }
    } else {
     $__d$0$lcssa = $$$0;
    }
   } while(0);
   if ($6) {
    $70 = ($__d$0$lcssa>>>0)>($$$0>>>0);
    if ($70) {
     $__me$promoted = HEAP32[$__me>>2]|0;
     $74 = $__me$promoted;$__d$137 = $__d$0$lcssa;$__f$038 = $__fd;
     while(1) {
      $71 = (($__d$137) + -4|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($74) + 4|0);
      HEAP32[$74>>2] = $72;
      $75 = (($__f$038) + -1)|0;
      $76 = ($71>>>0)>($$$0>>>0);
      $77 = ($75|0)>(0);
      $or$cond = $76 & $77;
      if ($or$cond) {
       $74 = $73;$__d$137 = $71;$__f$038 = $75;
      } else {
       break;
      }
     }
     HEAP32[$__me>>2] = $73;
     if ($77) {
      $__d$1$lcssa79 = $71;$__f$0$lcssa77 = $75;
      label = 34;
     } else {
      $78 = HEAP32[$__me>>2]|0;
      $79 = (($78) + 4|0);
      HEAP32[$__me>>2] = $79;
      $$lcssa44 = $78;$__d$1$lcssa7880 = $71;
     }
    } else {
     $__d$1$lcssa79 = $__d$0$lcssa;$__f$0$lcssa77 = $__fd;
     label = 34;
    }
    if ((label|0) == 34) {
     label = 0;
     $80 = HEAP32[$__ct>>2]|0;
     $81 = (($80) + 44|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = (FUNCTION_TABLE_iii[$82 & 4095]($__ct,48)|0);
     $84 = ($__f$0$lcssa77|0)>(0);
     $85 = HEAP32[$__me>>2]|0;
     $86 = (($85) + 4|0);
     HEAP32[$__me>>2] = $86;
     if ($84) {
      $87 = $85;$91 = $86;$__f$145 = $__f$0$lcssa77;
      while(1) {
       HEAP32[$87>>2] = $83;
       $88 = (($__f$145) + -1)|0;
       $89 = ($88|0)>(0);
       $90 = (($91) + 4|0);
       if ($89) {
        $87$phi = $91;$91 = $90;$__f$145 = $88;$87 = $87$phi;
       } else {
        break;
       }
      }
      $$sum75 = (($__f$0$lcssa77) + 1)|0;
      $scevgep = (($85) + ($$sum75<<2)|0);
      $scevgep70 = (($85) + ($__f$0$lcssa77<<2)|0);
      HEAP32[$__me>>2] = $scevgep;
      $$lcssa44 = $scevgep70;$__d$1$lcssa7880 = $__d$1$lcssa79;
     } else {
      $$lcssa44 = $85;$__d$1$lcssa7880 = $__d$1$lcssa79;
     }
    }
    HEAP32[$$lcssa44>>2] = $__dp;
    $__d$2 = $__d$1$lcssa7880;
   } else {
    $__d$2 = $__d$0$lcssa;
   }
   $92 = ($__d$2|0)==($$$0|0);
   if ($92) {
    $93 = HEAP32[$__ct>>2]|0;
    $94 = (($93) + 44|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (FUNCTION_TABLE_iii[$95 & 4095]($__ct,48)|0);
    $97 = HEAP32[$__me>>2]|0;
    $98 = (($97) + 4|0);
    HEAP32[$__me>>2] = $98;
    HEAP32[$97>>2] = $96;
    $140 = $98;
   } else {
    $99 = HEAP8[$__grp>>0]|0;
    $100 = $99 & 1;
    $101 = ($100<<24>>24)==(0);
    if ($101) {
     $103 = $99&255;
     $104 = $103 >>> 1;
     $106 = $104;
    } else {
     $102 = HEAP32[$9>>2]|0;
     $106 = $102;
    }
    $105 = ($106|0)==(0);
    if ($105) {
     $__d$353 = $__d$2;$__gl$056 = -1;$__ig$055 = 0;$__ng$054 = 0;
    } else {
     if ($101) {
      $109 = $7;
     } else {
      $107 = HEAP32[$8>>2]|0;
      $109 = $107;
     }
     $108 = HEAP8[$109>>0]|0;
     $110 = $108 << 24 >> 24;
     $__d$353 = $__d$2;$__gl$056 = $110;$__ig$055 = 0;$__ng$054 = 0;
    }
    while(1) {
     $111 = ($__ng$054|0)==($__gl$056|0);
     $112 = HEAP32[$__me>>2]|0;
     if ($111) {
      $113 = (($112) + 4|0);
      HEAP32[$__me>>2] = $113;
      HEAP32[$112>>2] = $__ts;
      $114 = (($__ig$055) + 1)|0;
      $115 = HEAP8[$__grp>>0]|0;
      $116 = $115 & 1;
      $117 = ($116<<24>>24)==(0);
      if ($117) {
       $119 = $115&255;
       $120 = $119 >>> 1;
       $122 = $120;
      } else {
       $118 = HEAP32[$9>>2]|0;
       $122 = $118;
      }
      $121 = ($114>>>0)<($122>>>0);
      if ($121) {
       if ($117) {
        $125 = $7;
       } else {
        $123 = HEAP32[$8>>2]|0;
        $125 = $123;
       }
       $124 = (($125) + ($114)|0);
       $126 = HEAP8[$124>>0]|0;
       $127 = ($126<<24>>24)==(127);
       if ($127) {
        $136 = $113;$__gl$1 = -1;$__ig$1 = $114;$__ng$1 = 0;
       } else {
        if ($117) {
         $130 = $7;
        } else {
         $128 = HEAP32[$8>>2]|0;
         $130 = $128;
        }
        $129 = (($130) + ($114)|0);
        $131 = HEAP8[$129>>0]|0;
        $132 = $131 << 24 >> 24;
        $136 = $113;$__gl$1 = $132;$__ig$1 = $114;$__ng$1 = 0;
       }
      } else {
       $136 = $113;$__gl$1 = $__gl$056;$__ig$1 = $114;$__ng$1 = 0;
      }
     } else {
      $136 = $112;$__gl$1 = $__gl$056;$__ig$1 = $__ig$055;$__ng$1 = $__ng$054;
     }
     $133 = (($__d$353) + -4|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = (($136) + 4|0);
     HEAP32[$__me>>2] = $135;
     HEAP32[$136>>2] = $134;
     $137 = (($__ng$1) + 1)|0;
     $138 = ($133|0)==($$$0|0);
     if ($138) {
      $140 = $135;
      break;
     } else {
      $__d$353 = $133;$__gl$056 = $__gl$1;$__ig$055 = $__ig$1;$__ng$054 = $137;
     }
    }
   }
   $139 = ($60|0)==($140|0);
   if ($139) {
    $$2 = $$$0;
   } else {
    $141 = (($140) + -4|0);
    $142 = ($141>>>0)>($60>>>0);
    if ($142) {
     $$012$i$i = $60;$145 = $141;
     while(1) {
      $143 = HEAP32[$$012$i$i>>2]|0;
      $144 = HEAP32[$145>>2]|0;
      HEAP32[$$012$i$i>>2] = $144;
      HEAP32[$145>>2] = $143;
      $146 = (($$012$i$i) + 4|0);
      $147 = (($145) + -4|0);
      $148 = ($146>>>0)<($147>>>0);
      if ($148) {
       $$012$i$i = $146;$145 = $147;
      } else {
       $$2 = $$$0;
       break;
      }
     }
    } else {
     $$2 = $$$0;
    }
   }
   break;
  }
  case 1:  {
   $14 = HEAP32[$__me>>2]|0;
   HEAP32[$__mi>>2] = $14;
   $15 = HEAP32[$__ct>>2]|0;
   $16 = (($15) + 44|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (FUNCTION_TABLE_iii[$17 & 4095]($__ct,32)|0);
   $19 = HEAP32[$__me>>2]|0;
   $20 = (($19) + 4|0);
   HEAP32[$__me>>2] = $20;
   HEAP32[$19>>2] = $18;
   $$2 = $$059;
   break;
  }
  case 3:  {
   $21 = HEAP8[$__sn>>0]|0;
   $22 = $21 & 1;
   $23 = ($22<<24>>24)==(0);
   if ($23) {
    $25 = $21&255;
    $26 = $25 >>> 1;
    $28 = $26;
   } else {
    $24 = HEAP32[$0>>2]|0;
    $28 = $24;
   }
   $27 = ($28|0)==(0);
   if ($27) {
    $$2 = $$059;
   } else {
    if ($23) {
     $31 = $0;
    } else {
     $29 = HEAP32[$1>>2]|0;
     $31 = $29;
    }
    $30 = HEAP32[$31>>2]|0;
    $32 = HEAP32[$__me>>2]|0;
    $33 = (($32) + 4|0);
    HEAP32[$__me>>2] = $33;
    HEAP32[$32>>2] = $30;
    $$2 = $$059;
   }
   break;
  }
  case 2:  {
   $34 = HEAP8[$__sym>>0]|0;
   $35 = $34 & 1;
   $36 = ($35<<24>>24)==(0);
   if ($36) {
    $38 = $34&255;
    $39 = $38 >>> 1;
    $41 = $39;
   } else {
    $37 = HEAP32[$4>>2]|0;
    $41 = $37;
   }
   $40 = ($41|0)==(0);
   $brmerge = $40 | $3;
   if ($brmerge) {
    $$2 = $$059;
   } else {
    if ($36) {
     $44 = $34&255;
     $45 = $44 >>> 1;
     $47 = $4;$48 = $45;$51 = $4;
    } else {
     $42 = HEAP32[$5>>2]|0;
     $43 = HEAP32[$4>>2]|0;
     $47 = $42;$48 = $43;$51 = $42;
    }
    $46 = (($47) + ($48<<2)|0);
    $49 = HEAP32[$__me>>2]|0;
    $50 = ($51|0)==($46|0);
    if ($50) {
     $$0$lcssa$i$i22 = $49;
    } else {
     $$promoted4$i$i13 = $51;
     $$sum33 = (($48) + -1)|0;
     $scevgep$i$i14 = (($47) + ($$sum33<<2)|0);
     $52 = (0 - ($$promoted4$i$i13))|0;
     $uglygep$i$i16 = (($scevgep$i$i14) + ($52)|0);
     $uglygep5$i$i17 = $uglygep$i$i16;
     $53 = $uglygep5$i$i17 >>> 2;
     $$01$i$i19 = $49;$55 = $51;
     while(1) {
      $54 = HEAP32[$55>>2]|0;
      HEAP32[$$01$i$i19>>2] = $54;
      $56 = (($55) + 4|0);
      $57 = ($56|0)==($46|0);
      if ($57) {
       break;
      }
      $58 = (($$01$i$i19) + 4|0);
      $$01$i$i19 = $58;$55 = $56;
     }
     $59 = (($53) + 1)|0;
     $scevgep6$i$i20 = (($49) + ($59<<2)|0);
     $$0$lcssa$i$i22 = $scevgep6$i$i20;
    }
    HEAP32[$__me>>2] = $$0$lcssa$i$i22;
    $$2 = $$059;
   }
   break;
  }
  default: {
   $$2 = $$059;
  }
  }
  $149 = (($__p$058) + 1)|0;
  $exitcond = ($149|0)==(4);
  if ($exitcond) {
   break;
  } else {
   $$059 = $$2;$__p$058 = $149;
  }
 }
 $150 = HEAP8[$__sn>>0]|0;
 $151 = $150 & 1;
 $152 = ($151<<24>>24)==(0);
 if ($152) {
  $154 = $150&255;
  $155 = $154 >>> 1;
  $157 = $155;
 } else {
  $153 = HEAP32[$0>>2]|0;
  $157 = $153;
 }
 $156 = ($157>>>0)>(1);
 if ($156) {
  if ($152) {
   $160 = $150&255;
   $161 = $160 >>> 1;
   $$pn = $0;$164 = $0;$165 = $161;
  } else {
   $158 = HEAP32[$1>>2]|0;
   $159 = HEAP32[$0>>2]|0;
   $$pn = $158;$164 = $158;$165 = $159;
  }
  $162 = (($$pn) + 4|0);
  $163 = (($164) + ($165<<2)|0);
  $166 = HEAP32[$__me>>2]|0;
  $167 = ($162|0)==($163|0);
  if ($167) {
   $$0$lcssa$i$i = $166;
  } else {
   $$promoted4$i$i = $162;
   $$sum = (($165) + -1)|0;
   $scevgep$i$i = (($164) + ($$sum<<2)|0);
   $168 = (0 - ($$promoted4$i$i))|0;
   $uglygep$i$i = (($scevgep$i$i) + ($168)|0);
   $uglygep5$i$i = $uglygep$i$i;
   $169 = $uglygep5$i$i >>> 2;
   $$01$i$i = $166;$171 = $162;
   while(1) {
    $170 = HEAP32[$171>>2]|0;
    HEAP32[$$01$i$i>>2] = $170;
    $172 = (($171) + 4|0);
    $173 = (($$01$i$i) + 4|0);
    $174 = ($172|0)==($163|0);
    if ($174) {
     break;
    } else {
     $$01$i$i = $173;$171 = $172;
    }
   }
   $175 = (($169) + 1)|0;
   $scevgep6$i$i = (($166) + ($175<<2)|0);
   $$0$lcssa$i$i = $scevgep6$i$i;
  }
  HEAP32[$__me>>2] = $$0$lcssa$i$i;
 }
 $176 = $__flags & 176;
 if ((($176|0) == 32)) {
  $177 = HEAP32[$__me>>2]|0;
  HEAP32[$__mi>>2] = $177;
  STACKTOP = sp;return;
 } else if ((($176|0) == 16)) {
  STACKTOP = sp;return;
 } else {
  HEAP32[$__mi>>2] = $__mb;
  STACKTOP = sp;return;
 }
}
function __ZNKSt3__19money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE($agg$result,$this,$__s,$__intl,$__iob,$__fl,$__digits) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__s = $__s|0;
 $__intl = $__intl|0;
 $__iob = $__iob|0;
 $__fl = $__fl|0;
 $__digits = $__digits|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $$byval_copy = 0, $$pn = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__dp = 0, $__fd = 0, $__grp = 0, $__loc = 0, $__mb$0 = 0, $__mbuf = 0, $__me = 0;
 var $__mi = 0, $__pat = 0, $__sn = 0, $__sym = 0, $__ts = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 480|0;
 $$byval_copy = sp + 468|0;
 $__loc = sp + 464|0;
 $__pat = sp + 460|0;
 $__dp = sp + 456|0;
 $__ts = sp + 452|0;
 $__grp = sp + 440|0;
 $__sym = sp + 428|0;
 $__sn = sp + 412|0;
 $__fd = sp + 408|0;
 $__mbuf = sp + 8|0;
 $__mi = sp + 4|0;
 $__me = sp;
 $0 = sp + 424|0;
 __ZNKSt3__18ios_base6getlocEv($__loc,$__iob);
 __THREW__ = 0;
 $1 = (invoke_iii(2228,($__loc|0),(3093328|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 do {
  if (!($3)) {
   $4 = HEAP8[$__digits>>0]|0;
   $5 = $4 & 1;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $9 = $4&255;
    $10 = $9 >>> 1;
    $12 = $10;
   } else {
    $7 = (($__digits) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $12 = $8;
   }
   $11 = ($12|0)==(0);
   if ($11) {
    $25 = 0;
   } else {
    if ($6) {
     $15 = (($__digits) + 4|0);
     $17 = $15;
    } else {
     $13 = (($__digits) + 8|0);
     $14 = HEAP32[$13>>2]|0;
     $17 = $14;
    }
    $16 = HEAP32[$17>>2]|0;
    $18 = HEAP32[$1>>2]|0;
    $19 = (($18) + 44|0);
    $20 = HEAP32[$19>>2]|0;
    __THREW__ = 0;
    $21 = (invoke_iii($20|0,($1|0),45)|0);
    $22 = __THREW__; __THREW__ = 0;
    $23 = $22&1;
    if ($23) {
     break;
    }
    $24 = ($16|0)==($21|0);
    $25 = $24;
   }
   HEAP32[$__pat>>2] = 0;
   ;HEAP32[$__grp+0>>2]=0|0;HEAP32[$__grp+4>>2]=0|0;HEAP32[$__grp+8>>2]=0|0;
   ;HEAP32[$__sym+0>>2]=0|0;HEAP32[$__sym+4>>2]=0|0;HEAP32[$__sym+8>>2]=0|0;
   ;HEAP32[$__sn+0>>2]=0|0;HEAP32[$__sn+4>>2]=0|0;HEAP32[$__sn+8>>2]=0|0;
   __THREW__ = 0;
   invoke_viiiiiiiiii(13,($__intl|0),($25|0),($__loc|0),($__pat|0),($__dp|0),($__ts|0),($__grp|0),($__sym|0),($__sn|0),($__fd|0));
   $26 = __THREW__; __THREW__ = 0;
   $27 = $26&1;
   L15: do {
    if ($27) {
     $93 = ___cxa_find_matching_catch()|0;
     $94 = tempRet0;
     $$0 = $93;$$01 = $94;
    } else {
     $28 = HEAP8[$__digits>>0]|0;
     $29 = $28 & 1;
     $30 = ($29<<24>>24)==(0);
     if ($30) {
      $33 = $28&255;
      $34 = $33 >>> 1;
      $37 = $34;
     } else {
      $31 = (($__digits) + 4|0);
      $32 = HEAP32[$31>>2]|0;
      $37 = $32;
     }
     $35 = HEAP32[$__fd>>2]|0;
     $36 = ($37|0)>($35|0);
     if ($36) {
      if ($30) {
       $40 = $28&255;
       $41 = $40 >>> 1;
       $43 = $41;
      } else {
       $38 = (($__digits) + 4|0);
       $39 = HEAP32[$38>>2]|0;
       $43 = $39;
      }
      $42 = (($43) - ($35))|0;
      $44 = $42 << 1;
      $45 = HEAP8[$__sn>>0]|0;
      $46 = $45 & 1;
      $47 = ($46<<24>>24)==(0);
      if ($47) {
       $50 = $45&255;
       $51 = $50 >>> 1;
       $61 = $51;
      } else {
       $48 = (($__sn) + 4|0);
       $49 = HEAP32[$48>>2]|0;
       $61 = $49;
      }
      $52 = HEAP8[$__sym>>0]|0;
      $53 = $52 & 1;
      $54 = ($53<<24>>24)==(0);
      if ($54) {
       $57 = $52&255;
       $58 = $57 >>> 1;
       $63 = $58;
      } else {
       $55 = (($__sym) + 4|0);
       $56 = HEAP32[$55>>2]|0;
       $63 = $56;
      }
      $59 = $44 | 1;
      $60 = (($61) + ($59))|0;
      $62 = (($60) + ($63))|0;
      $$pn = $62;
     } else {
      $64 = HEAP8[$__sn>>0]|0;
      $65 = $64 & 1;
      $66 = ($65<<24>>24)==(0);
      if ($66) {
       $69 = $64&255;
       $70 = $69 >>> 1;
       $79 = $70;
      } else {
       $67 = (($__sn) + 4|0);
       $68 = HEAP32[$67>>2]|0;
       $79 = $68;
      }
      $71 = HEAP8[$__sym>>0]|0;
      $72 = $71 & 1;
      $73 = ($72<<24>>24)==(0);
      if ($73) {
       $76 = $71&255;
       $77 = $76 >>> 1;
       $81 = $77;
      } else {
       $74 = (($__sym) + 4|0);
       $75 = HEAP32[$74>>2]|0;
       $81 = $75;
      }
      $78 = (($79) + 2)|0;
      $80 = (($78) + ($81))|0;
      $$pn = $80;
     }
     $82 = (($$pn) + ($35))|0;
     $83 = ($82>>>0)>(100);
     do {
      if ($83) {
       $84 = $82 << 2;
       $85 = (_malloc($84)|0);
       $86 = ($85|0)==(0|0);
       if ($86) {
        __THREW__ = 0;
        invoke_v(1012);
        $87 = __THREW__; __THREW__ = 0;
        $88 = $87&1;
        if ($88) {
         $89 = ___cxa_find_matching_catch()|0;
         $90 = tempRet0;
         $$0 = $89;$$01 = $90;
         break L15;
        } else {
         $$pre = HEAP8[$__digits>>0]|0;
         $102 = $$pre;$98 = 0;$__mb$0 = 0;
         break;
        }
       } else {
        $102 = $28;$98 = $85;$__mb$0 = $85;
       }
      } else {
       $102 = $28;$98 = 0;$__mb$0 = $__mbuf;
      }
     } while(0);
     $99 = (($__iob) + 4|0);
     $100 = HEAP32[$99>>2]|0;
     $101 = $102 & 1;
     $103 = ($101<<24>>24)==(0);
     if ($103) {
      $108 = (($__digits) + 4|0);
      $109 = $102&255;
      $110 = $109 >>> 1;
      $112 = $108;$113 = $110;
     } else {
      $104 = (($__digits) + 8|0);
      $105 = HEAP32[$104>>2]|0;
      $106 = (($__digits) + 4|0);
      $107 = HEAP32[$106>>2]|0;
      $112 = $105;$113 = $107;
     }
     $111 = (($112) + ($113<<2)|0);
     $114 = HEAP32[$__dp>>2]|0;
     $115 = HEAP32[$__ts>>2]|0;
     __THREW__ = 0;
     invoke_viiiiiiiiiiiiiii(2,($__mb$0|0),($__mi|0),($__me|0),($100|0),($112|0),($111|0),($1|0),($25|0),($__pat|0),($114|0),($115|0),($__grp|0),($__sym|0),($__sn|0),($35|0));
     $116 = __THREW__; __THREW__ = 0;
     $117 = $116&1;
     if (!($117)) {
      $118 = HEAP32[$__s>>2]|0;
      HEAP32[$0>>2] = $118;
      $119 = HEAP32[$__mi>>2]|0;
      $120 = HEAP32[$__me>>2]|0;
      __THREW__ = 0;
      ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;
      invoke_viiiiiii(81,($agg$result|0),($$byval_copy|0),($__mb$0|0),($119|0),($120|0),($__iob|0),($__fl|0));
      $121 = __THREW__; __THREW__ = 0;
      $122 = $121&1;
      if (!($122)) {
       $123 = ($98|0)==(0|0);
       if ($123) {
        __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sn);
        __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sym);
        __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
        $124 = HEAP32[$__loc>>2]|0;
        (__ZNSt3__114__shared_count16__release_sharedEv($124)|0);
        STACKTOP = sp;return;
       }
       _free($98);
       __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sn);
       __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sym);
       __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
       $124 = HEAP32[$__loc>>2]|0;
       (__ZNSt3__114__shared_count16__release_sharedEv($124)|0);
       STACKTOP = sp;return;
      }
     }
     $95 = ___cxa_find_matching_catch()|0;
     $96 = tempRet0;
     $97 = ($98|0)==(0|0);
     if ($97) {
      $$0 = $95;$$01 = $96;
     } else {
      _free($98);
      $$0 = $95;$$01 = $96;
     }
    }
   } while(0);
   __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sn);
   __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($__sym);
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__grp);
   $$1 = $$0;$$12 = $$01;
   $125 = HEAP32[$__loc>>2]|0;
   (__ZNSt3__114__shared_count16__release_sharedEv($125)|0);
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $91 = ___cxa_find_matching_catch()|0;
 $92 = tempRet0;
 $$1 = $91;$$12 = $92;
 $125 = HEAP32[$__loc>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($125)|0);
 ___resumeException($$1|0);
 // unreachable;
}
function __ZNSt3__18messagesIcED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18messagesIcED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__18messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE($this,$__nm,$0) {
 $this = $this|0;
 $__nm = $__nm|0;
 $0 = $0|0;
 var $$ = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$__nm>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($__nm) + 1|0);
  $7 = $6;
 } else {
  $4 = (($__nm) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 $8 = (_catopen(($7|0),1)|0);
 $9 = $8;
 $not$ = ($8|0)!=((-1)|0);
 $10 = $not$&1;
 $$ = $9 >>> $10;
 STACKTOP = sp;return ($$|0);
}
function __ZNKSt3__18messagesIcE6do_getEiiiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE($agg$result,$this,$__c,$__set,$__msgid,$__dflt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__c = $__c|0;
 $__set = $__set|0;
 $__msgid = $__msgid|0;
 $__dflt = $__dflt|0;
 var $$01 = 0, $$01$i = 0, $$01$i7 = 0, $$02 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__ndflt = 0, $exitcond$i = 0, $exitcond$i8 = 0, $lpad$phi$index = 0, $lpad$phi$index2 = 0;
 var $phitmp = 0, $phitmp18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__ndflt = sp;
 ;HEAP32[$__ndflt+0>>2]=0|0;HEAP32[$__ndflt+4>>2]=0|0;HEAP32[$__ndflt+8>>2]=0|0;
 $0 = HEAP8[$__dflt>>0]|0;
 $1 = $0 & 1;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $7 = (($__dflt) + 1|0);
  $8 = (($__dflt) + 1|0);
  $9 = $0&255;
  $10 = $9 >>> 1;
  $12 = $8;$13 = $10;$15 = $7;
 } else {
  $3 = (($__dflt) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($__dflt) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $12 = $4;$13 = $6;$15 = $4;
 }
 $11 = (($12) + ($13)|0);
 $14 = ($15>>>0)<($11>>>0);
 do {
  if ($14) {
   $$01$i7 = $15;
   while(1) {
    $20 = HEAP8[$$01$i7>>0]|0;
    __THREW__ = 0;
    invoke_vii(3508,($__ndflt|0),($20|0));
    $21 = __THREW__; __THREW__ = 0;
    $22 = $21&1;
    if ($22) {
     label = 12;
     break;
    }
    $23 = (($$01$i7) + 1|0);
    $exitcond$i8 = ($23|0)==($11|0);
    if ($exitcond$i8) {
     break;
    } else {
     $$01$i7 = $23;
    }
   }
   if ((label|0) == 12) {
    $36 = ___cxa_find_matching_catch()|0;
    $37 = tempRet0;
    $lpad$phi$index = $36;$lpad$phi$index2 = $37;
    break;
   }
   $$pre = HEAP8[$__ndflt>>0]|0;
   $phitmp = $$pre & 1;
   $phitmp18 = ($phitmp<<24>>24)==(0);
   $24 = ($__c|0)==(-1);
   $25 = $__c << 1;
   $26 = $25;
   $27 = $24 ? (-1) : $26;
   if ($phitmp18) {
    $49 = $27;
    label = 10;
   } else {
    $28 = (($__ndflt) + 8|0);
    $29 = HEAP32[$28>>2]|0;
    $31 = $27;$32 = $29;
    label = 11;
   }
  } else {
   $16 = ($__c|0)==(-1);
   $17 = $__c << 1;
   $18 = $17;
   $19 = $16 ? (-1) : $18;
   $49 = $19;
   label = 10;
  }
 } while(0);
 if ((label|0) == 10) {
  $30 = (($__ndflt) + 1|0);
  $31 = $49;$32 = $30;
  label = 11;
 }
 do {
  if ((label|0) == 11) {
   __THREW__ = 0;
   $33 = (invoke_iiiii(344,($31|0),($__set|0),($__msgid|0),($32|0))|0);
   $34 = __THREW__; __THREW__ = 0;
   $35 = $34&1;
   if ($35) {
    $38 = ___cxa_find_matching_catch()|0;
    $39 = tempRet0;
    $lpad$phi$index = $38;$lpad$phi$index2 = $39;
    break;
   }
   ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
   $40 = (_strlen(($33|0))|0);
   $41 = (($33) + ($40)|0);
   $42 = ($40|0)>(0);
   if ($42) {
    $$01$i = $33;
   } else {
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
    STACKTOP = sp;return;
   }
   while(1) {
    $43 = HEAP8[$$01$i>>0]|0;
    __THREW__ = 0;
    invoke_vii(3508,($agg$result|0),($43|0));
    $44 = __THREW__; __THREW__ = 0;
    $45 = $44&1;
    if ($45) {
     break;
    }
    $46 = (($$01$i) + 1|0);
    $exitcond$i = ($46|0)==($41|0);
    if ($exitcond$i) {
     label = 19;
     break;
    } else {
     $$01$i = $46;
    }
   }
   if ((label|0) == 19) {
    __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
    STACKTOP = sp;return;
   }
   $47 = ___cxa_find_matching_catch()|0;
   $48 = tempRet0;
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($agg$result);
   $$01 = $47;$$02 = $48;
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
   ___resumeException($$01|0);
   // unreachable;
  }
 } while(0);
 $$01 = $lpad$phi$index;$$02 = $lpad$phi$index2;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
 ___resumeException($$01|0);
 // unreachable;
}
function __ZNKSt3__18messagesIcE8do_closeEi($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__c|0)==(-1);
 $1 = $__c << 1;
 $2 = $1;
 $3 = $0 ? (-1) : $2;
 (_catclose(($3|0))|0);
 STACKTOP = sp;return;
}
function __ZNSt3__18messagesIwED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18messagesIwED1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt3__18messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE($this,$__nm,$0) {
 $this = $this|0;
 $__nm = $__nm|0;
 $0 = $0|0;
 var $$ = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = HEAP8[$__nm>>0]|0;
 $2 = $1 & 1;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $6 = (($__nm) + 1|0);
  $7 = $6;
 } else {
  $4 = (($__nm) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $7 = $5;
 }
 $8 = (_catopen(($7|0),1)|0);
 $9 = $8;
 $not$ = ($8|0)!=((-1)|0);
 $10 = $not$&1;
 $$ = $9 >>> $10;
 STACKTOP = sp;return ($$|0);
}
function __ZNKSt3__18messagesIwE6do_getEiiiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE($agg$result,$this,$__c,$__set,$__msgid,$__dflt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $__c = $__c|0;
 $__set = $__set|0;
 $__msgid = $__msgid|0;
 $__dflt = $__dflt|0;
 var $$04$i = 0, $$04$i16 = 0, $$1 = 0, $$13 = 0, $$pre = 0, $$pre$i = 0, $$pre$i21 = 0, $$pre44 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__bn$i = 0, $__bn$i14 = 0, $__buf$i = 0;
 var $__buf$i13 = 0, $__mb$i = 0, $__mb$i11 = 0, $__ndflt = 0, $__nn$i = 0, $__p$03$i = 0, $__p$03$i20 = 0, $__wn$i = 0, $lpad$phi$index = 0, $lpad$phi$index10 = 0, $lpad$phi38$index = 0, $lpad$phi38$index3 = 0, $or$cond2$i = 0, $or$cond2$i17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $__mb$i11 = sp + 8|0;
 $__buf$i13 = sp + 192|0;
 $__bn$i14 = sp + 60|0;
 $__wn$i = sp + 56|0;
 $__mb$i = sp;
 $__buf$i = sp + 64|0;
 $__bn$i = sp + 40|0;
 $__nn$i = sp + 16|0;
 $__ndflt = sp + 20|0;
 $0 = sp + 48|0;
 $1 = sp + 32|0;
 ;HEAP32[$__ndflt+0>>2]=0|0;HEAP32[$__ndflt+4>>2]=0|0;HEAP32[$__ndflt+8>>2]=0|0;
 $2 = (($0) + 4|0);
 HEAP32[$2>>2] = 0;
 HEAP32[$0>>2] = ((3094984 + 8|0));
 $3 = HEAP8[$__dflt>>0]|0;
 $4 = $3 & 1;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $10 = (($__dflt) + 4|0);
  $11 = (($__dflt) + 4|0);
  $12 = $3&255;
  $13 = $12 >>> 1;
  $15 = $11;$16 = $13;$22 = $10;
 } else {
  $6 = (($__dflt) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($__dflt) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $15 = $7;$16 = $9;$22 = $7;
 }
 $14 = (($15) + ($16<<2)|0);
 $17 = $__mb$i11;
 $18 = $17;
 HEAP32[$18>>2] = 0;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = 0;
 $21 = ($22>>>0)<($14>>>0);
 L5: do {
  if ($21) {
   $23 = (($__buf$i13) + 32|0);
   $$04$i16 = $22;$25 = ((3094984 + 8|0));
   L7: while(1) {
    HEAP32[$__wn$i>>2] = $$04$i16;
    $24 = (($25) + 12|0);
    $26 = HEAP32[$24>>2]|0;
    __THREW__ = 0;
    $27 = (invoke_iiiiiiiii($26|0,($0|0),($__mb$i11|0),($$04$i16|0),($14|0),($__wn$i|0),($__buf$i13|0),($23|0),($__bn$i14|0))|0);
    $28 = __THREW__; __THREW__ = 0;
    $29 = $28&1;
    if ($29) {
     label = 22;
     break;
    }
    $30 = ($27|0)==(2);
    $31 = HEAP32[$__wn$i>>2]|0;
    $32 = ($31|0)==($$04$i16|0);
    $or$cond2$i17 = $30 | $32;
    if ($or$cond2$i17) {
     label = 9;
     break;
    }
    $33 = HEAP32[$__bn$i14>>2]|0;
    $34 = ($__buf$i13>>>0)<($33>>>0);
    if ($34) {
     $__p$03$i20 = $__buf$i13;
     while(1) {
      $37 = HEAP8[$__p$03$i20>>0]|0;
      __THREW__ = 0;
      invoke_vii(3508,($__ndflt|0),($37|0));
      $38 = __THREW__; __THREW__ = 0;
      $39 = $38&1;
      if ($39) {
       label = 21;
       break L7;
      }
      $40 = (($__p$03$i20) + 1|0);
      $41 = HEAP32[$__bn$i14>>2]|0;
      $42 = ($40>>>0)<($41>>>0);
      if ($42) {
       $__p$03$i20 = $40;
      } else {
       break;
      }
     }
     $$pre$i21 = HEAP32[$__wn$i>>2]|0;
     $44 = $$pre$i21;
    } else {
     $44 = $31;
    }
    $43 = ($44>>>0)<($14>>>0);
    if (!($43)) {
     break L5;
    }
    $$pre = HEAP32[$0>>2]|0;
    $$04$i16 = $44;$25 = $$pre;
   }
   do {
    if ((label|0) == 9) {
     __THREW__ = 0;
     invoke_vi(3856,(3094216|0));
     $35 = __THREW__; __THREW__ = 0;
     $36 = $35&1;
     if ($36) {
      $65 = ___cxa_find_matching_catch()|0;
      $66 = tempRet0;
      $lpad$phi38$index = $65;$lpad$phi38$index3 = $66;
      break;
     } else {
      // unreachable;
     }
    }
    else if ((label|0) == 21) {
     $61 = ___cxa_find_matching_catch()|0;
     $62 = tempRet0;
     $lpad$phi38$index = $61;$lpad$phi38$index3 = $62;
    }
    else if ((label|0) == 22) {
     $63 = ___cxa_find_matching_catch()|0;
     $64 = tempRet0;
     $lpad$phi38$index = $63;$lpad$phi38$index3 = $64;
    }
   } while(0);
   $$1 = $lpad$phi38$index;$$13 = $lpad$phi38$index3;
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
   ___resumeException($$1|0);
   // unreachable;
  }
 } while(0);
 $45 = ($__c|0)==(-1);
 $46 = $__c << 1;
 $47 = $46;
 $48 = $45 ? (-1) : $47;
 $49 = HEAP8[$__ndflt>>0]|0;
 $50 = $49 & 1;
 $51 = ($50<<24>>24)==(0);
 if ($51) {
  $54 = (($__ndflt) + 1|0);
  $55 = $54;
 } else {
  $52 = (($__ndflt) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  $55 = $53;
 }
 __THREW__ = 0;
 $56 = (invoke_iiiii(344,($48|0),($__set|0),($__msgid|0),($55|0))|0);
 $57 = __THREW__; __THREW__ = 0;
 $58 = $57&1;
 if ($58) {
  $59 = ___cxa_find_matching_catch()|0;
  $60 = tempRet0;
  $$1 = $59;$$13 = $60;
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
  ___resumeException($$1|0);
  // unreachable;
 }
 ;HEAP32[$agg$result+0>>2]=0|0;HEAP32[$agg$result+4>>2]=0|0;HEAP32[$agg$result+8>>2]=0|0;
 $67 = (($1) + 4|0);
 HEAP32[$67>>2] = 0;
 HEAP32[$1>>2] = ((3095088 + 8|0));
 $68 = (_strlen(($56|0))|0);
 $69 = (($56) + ($68)|0);
 $70 = $__mb$i;
 $71 = $70;
 HEAP32[$71>>2] = 0;
 $72 = (($70) + 4)|0;
 $73 = $72;
 HEAP32[$73>>2] = 0;
 $74 = ($68|0)>(0);
 if (!($74)) {
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
  STACKTOP = sp;return;
 }
 $75 = $69;
 $76 = (($__buf$i) + 128|0);
 $$04$i = $56;$78 = ((3095088 + 8|0));
 L39: while(1) {
  HEAP32[$__nn$i>>2] = $$04$i;
  $77 = (($78) + 16|0);
  $79 = HEAP32[$77>>2]|0;
  $80 = $$04$i;
  $81 = (($75) - ($80))|0;
  $82 = ($81|0)>(32);
  $83 = (($$04$i) + 32|0);
  $84 = $82 ? $83 : $69;
  __THREW__ = 0;
  $85 = (invoke_iiiiiiiii($79|0,($1|0),($__mb$i|0),($$04$i|0),($84|0),($__nn$i|0),($__buf$i|0),($76|0),($__bn$i|0))|0);
  $86 = __THREW__; __THREW__ = 0;
  $87 = $86&1;
  if ($87) {
   label = 39;
   break;
  }
  $88 = ($85|0)==(2);
  $89 = HEAP32[$__nn$i>>2]|0;
  $90 = ($89|0)==($$04$i|0);
  $or$cond2$i = $88 | $90;
  if ($or$cond2$i) {
   label = 30;
   break;
  }
  $91 = HEAP32[$__bn$i>>2]|0;
  $92 = ($__buf$i>>>0)<($91>>>0);
  if ($92) {
   $__p$03$i = $__buf$i;
   while(1) {
    $95 = HEAP32[$__p$03$i>>2]|0;
    __THREW__ = 0;
    invoke_vii(3509,($agg$result|0),($95|0));
    $96 = __THREW__; __THREW__ = 0;
    $97 = $96&1;
    if ($97) {
     label = 38;
     break L39;
    }
    $98 = (($__p$03$i) + 4|0);
    $99 = HEAP32[$__bn$i>>2]|0;
    $100 = ($98>>>0)<($99>>>0);
    if ($100) {
     $__p$03$i = $98;
    } else {
     break;
    }
   }
   $$pre$i = HEAP32[$__nn$i>>2]|0;
   $102 = $$pre$i;
  } else {
   $102 = $89;
  }
  $101 = ($102>>>0)<($69>>>0);
  if (!($101)) {
   label = 37;
   break;
  }
  $$pre44 = HEAP32[$1>>2]|0;
  $$04$i = $102;$78 = $$pre44;
 }
 do {
  if ((label|0) == 30) {
   __THREW__ = 0;
   invoke_vi(3856,(3094216|0));
   $93 = __THREW__; __THREW__ = 0;
   $94 = $93&1;
   if ($94) {
    $107 = ___cxa_find_matching_catch()|0;
    $108 = tempRet0;
    $lpad$phi$index = $107;$lpad$phi$index10 = $108;
    break;
   } else {
    // unreachable;
   }
  }
  else if ((label|0) == 37) {
   __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
   STACKTOP = sp;return;
  }
  else if ((label|0) == 38) {
   $103 = ___cxa_find_matching_catch()|0;
   $104 = tempRet0;
   $lpad$phi$index = $103;$lpad$phi$index10 = $104;
  }
  else if ((label|0) == 39) {
   $105 = ___cxa_find_matching_catch()|0;
   $106 = tempRet0;
   $lpad$phi$index = $105;$lpad$phi$index10 = $106;
  }
 } while(0);
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev($agg$result);
 $$1 = $lpad$phi$index;$$13 = $lpad$phi$index10;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($__ndflt);
 ___resumeException($$1|0);
 // unreachable;
}
function __ZNKSt3__18messagesIwE8do_closeEi($this,$__c) {
 $this = $this|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__c|0)==(-1);
 $1 = $__c << 1;
 $2 = $1;
 $3 = $0 ? (-1) : $2;
 (_catclose(($3|0))|0);
 STACKTOP = sp;return;
}
function __ZNSt3__17codecvtIwc11__mbstate_tED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3093416 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_i(134)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  $5 = ($1|0)==($2|0);
  if ($5) {
   STACKTOP = sp;return;
  }
  $6 = HEAP32[$0>>2]|0;
  __THREW__ = 0;
  invoke_vi(3854,($6|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   STACKTOP = sp;return;
  }
 }
 $9 = ___cxa_find_matching_catch(0|0)|0;
 $10 = tempRet0;
 __ZSt9terminatev();
 // unreachable;
}
function __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(3505,($0|0),(3093216|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  ___cxa_free_exception(($0|0));
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[$0>>2] = ((3105576 + 8|0));
  ___cxa_throw(($0|0),(3105624|0),(3282|0));
  // unreachable;
 }
}
function __ZNKSt3__120__vector_base_commonILb1EE20__throw_out_of_rangeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_allocate_exception(8)|0);
 __THREW__ = 0;
 invoke_vii(3505,($0|0),(3093216|0));
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $3 = ___cxa_find_matching_catch()|0;
  $4 = tempRet0;
  ___cxa_free_exception(($0|0));
  ___resumeException($3|0);
  // unreachable;
 } else {
  HEAP32[$0>>2] = ((3105640 + 8|0));
  ___cxa_throw(($0|0),(3105688|0),(3282|0));
  // unreachable;
 }
}
function __ZNSt3__16locale5__impC2Ej($this,$refs) {
 $this = $this|0;
 $refs = $refs|0;
 var $$0 = 0, $$01 = 0, $$1 = 0, $$12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $__new_last2$i$i$i = 0, $eh$lpad$body$index3Z2D = 0, $eh$lpad$body$indexZ2D = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($refs) + -1)|0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $0;
 HEAP32[$this>>2] = ((3093248 + 8|0));
 $2 = (($this) + 8|0);
 __THREW__ = 0;
 invoke_vii(3511,($2|0),28);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $83 = ___cxa_find_matching_catch()|0;
  $84 = tempRet0;
  $$1 = $84;$$12 = $83;
  ___resumeException($$12|0);
  // unreachable;
 }
 $5 = (($this) + 144|0);
 __THREW__ = 0;
 invoke_viii(2132,($5|0),(3093240|0),1);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $85 = ___cxa_find_matching_catch()|0;
  $86 = tempRet0;
  $$0 = $86;$$01 = $85;
 } else {
  $8 = HEAP32[$2>>2]|0;
  $9 = (($this) + 12|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($8|0);
  if (!($11)) {
   $__new_last2$i$i$i = $8;
   $scevgep$i$i$i = (($10) + -4|0);
   $12 = (0 - ($__new_last2$i$i$i))|0;
   $uglygep$i$i$i = (($scevgep$i$i$i) + ($12)|0);
   $uglygep3$i$i$i = $uglygep$i$i$i;
   $13 = $uglygep3$i$i$i >>> 2;
   $14 = $13 ^ -1;
   $scevgep4$i$i$i = (($10) + ($14<<2)|0);
   HEAP32[$9>>2] = $scevgep4$i$i$i;
  }
  HEAP32[((3098144 + 4|0))>>2] = 0;
  HEAP32[3098144>>2] = ((3091696 + 8|0));
  __THREW__ = 0;
  invoke_vii(3512,($this|0),(3098144|0));
  $15 = __THREW__; __THREW__ = 0;
  $16 = $15&1;
  do {
   if ($16) {
    label = 41;
   } else {
    HEAP32[((3098136 + 4|0))>>2] = 0;
    HEAP32[3098136>>2] = ((3091736 + 8|0));
    __THREW__ = 0;
    invoke_vii(3513,($this|0),(3098136|0));
    $17 = __THREW__; __THREW__ = 0;
    $18 = $17&1;
    if ($18) {
     label = 41;
    } else {
     __ZNSt3__15ctypeIcEC2EPKtbj(3098120,0,0,1);
     __THREW__ = 0;
     invoke_vii(3514,($this|0),(3098120|0));
     $19 = __THREW__; __THREW__ = 0;
     $20 = $19&1;
     if ($20) {
      label = 41;
     } else {
      HEAP32[((3098112 + 4|0))>>2] = 0;
      HEAP32[3098112>>2] = ((3094304 + 8|0));
      __THREW__ = 0;
      invoke_vii(3515,($this|0),(3098112|0));
      $21 = __THREW__; __THREW__ = 0;
      $22 = $21&1;
      if ($22) {
       label = 41;
      } else {
       HEAP32[((3098104 + 4|0))>>2] = 0;
       HEAP32[3098104>>2] = ((3094520 + 8|0));
       __THREW__ = 0;
       invoke_vii(3516,($this|0),(3098104|0));
       $23 = __THREW__; __THREW__ = 0;
       $24 = $23&1;
       if ($24) {
        label = 41;
       } else {
        __THREW__ = 0;
        invoke_vii(3517,(3098088|0),1);
        $25 = __THREW__; __THREW__ = 0;
        $26 = $25&1;
        if ($26) {
         label = 41;
        } else {
         __THREW__ = 0;
         invoke_vii(3518,($this|0),(3098088|0));
         $27 = __THREW__; __THREW__ = 0;
         $28 = $27&1;
         if ($28) {
          label = 41;
         } else {
          HEAP32[((3098080 + 4|0))>>2] = 0;
          HEAP32[3098080>>2] = ((3094744 + 8|0));
          __THREW__ = 0;
          invoke_vii(3519,($this|0),(3098080|0));
          $29 = __THREW__; __THREW__ = 0;
          $30 = $29&1;
          if ($30) {
           label = 41;
          } else {
           HEAP32[((3098072 + 4|0))>>2] = 0;
           HEAP32[3098072>>2] = ((3094864 + 8|0));
           __THREW__ = 0;
           invoke_vii(3520,($this|0),(3098072|0));
           $31 = __THREW__; __THREW__ = 0;
           $32 = $31&1;
           if ($32) {
            label = 41;
           } else {
            HEAP32[((3098048 + 4|0))>>2] = 0;
            HEAP32[3098048>>2] = ((3093496 + 8|0));
            HEAP8[((3098048 + 8|0))>>0] = 46;
            HEAP8[((3098048 + 9|0))>>0] = 44;
            ;HEAP32[((3098048 + 12|0))+0>>2]=0|0;HEAP32[((3098048 + 12|0))+4>>2]=0|0;HEAP32[((3098048 + 12|0))+8>>2]=0|0;
            __THREW__ = 0;
            invoke_vii(3521,($this|0),(3098048|0));
            $33 = __THREW__; __THREW__ = 0;
            $34 = $33&1;
            if ($34) {
             label = 41;
            } else {
             HEAP32[((3098016 + 4|0))>>2] = 0;
             HEAP32[3098016>>2] = ((3093536 + 8|0));
             HEAP32[((3098016 + 8|0))>>2] = 46;
             HEAP32[((3098016 + 12|0))>>2] = 44;
             ;HEAP32[((3098016 + 16|0))+0>>2]=0|0;HEAP32[((3098016 + 16|0))+4>>2]=0|0;HEAP32[((3098016 + 16|0))+8>>2]=0|0;
             __THREW__ = 0;
             invoke_vii(3522,($this|0),(3098016|0));
             $35 = __THREW__; __THREW__ = 0;
             $36 = $35&1;
             if ($36) {
              label = 41;
             } else {
              HEAP32[((3098008 + 4|0))>>2] = 0;
              HEAP32[3098008>>2] = ((3091776 + 8|0));
              __THREW__ = 0;
              invoke_vii(3523,($this|0),(3098008|0));
              $37 = __THREW__; __THREW__ = 0;
              $38 = $37&1;
              if ($38) {
               label = 41;
              } else {
               HEAP32[((3098000 + 4|0))>>2] = 0;
               HEAP32[3098000>>2] = ((3091896 + 8|0));
               __THREW__ = 0;
               invoke_vii(3524,($this|0),(3098000|0));
               $39 = __THREW__; __THREW__ = 0;
               $40 = $39&1;
               if ($40) {
                label = 41;
               } else {
                HEAP32[((3097992 + 4|0))>>2] = 0;
                HEAP32[3097992>>2] = ((3091968 + 8|0));
                __THREW__ = 0;
                invoke_vii(3525,($this|0),(3097992|0));
                $41 = __THREW__; __THREW__ = 0;
                $42 = $41&1;
                if ($42) {
                 label = 41;
                } else {
                 HEAP32[((3097984 + 4|0))>>2] = 0;
                 HEAP32[3097984>>2] = ((3092064 + 8|0));
                 __THREW__ = 0;
                 invoke_vii(3526,($this|0),(3097984|0));
                 $43 = __THREW__; __THREW__ = 0;
                 $44 = $43&1;
                 if ($44) {
                  label = 41;
                 } else {
                  HEAP32[((3097976 + 4|0))>>2] = 0;
                  HEAP32[3097976>>2] = ((3092656 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3527,($this|0),(3097976|0));
                  $45 = __THREW__; __THREW__ = 0;
                  $46 = $45&1;
                  if ($46) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097968 + 4|0))>>2] = 0;
                  HEAP32[3097968>>2] = ((3092720 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3528,($this|0),(3097968|0));
                  $47 = __THREW__; __THREW__ = 0;
                  $48 = $47&1;
                  if ($48) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097960 + 4|0))>>2] = 0;
                  HEAP32[3097960>>2] = ((3092784 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3529,($this|0),(3097960|0));
                  $49 = __THREW__; __THREW__ = 0;
                  $50 = $49&1;
                  if ($50) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097952 + 4|0))>>2] = 0;
                  HEAP32[3097952>>2] = ((3092848 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3530,($this|0),(3097952|0));
                  $51 = __THREW__; __THREW__ = 0;
                  $52 = $51&1;
                  if ($52) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097944 + 4|0))>>2] = 0;
                  HEAP32[3097944>>2] = ((3092912 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3531,($this|0),(3097944|0));
                  $53 = __THREW__; __THREW__ = 0;
                  $54 = $53&1;
                  if ($54) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097936 + 4|0))>>2] = 0;
                  HEAP32[3097936>>2] = ((3092992 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3532,($this|0),(3097936|0));
                  $55 = __THREW__; __THREW__ = 0;
                  $56 = $55&1;
                  if ($56) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097928 + 4|0))>>2] = 0;
                  HEAP32[3097928>>2] = ((3093048 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3533,($this|0),(3097928|0));
                  $57 = __THREW__; __THREW__ = 0;
                  $58 = $57&1;
                  if ($58) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097920 + 4|0))>>2] = 0;
                  HEAP32[3097920>>2] = ((3093096 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3534,($this|0),(3097920|0));
                  $59 = __THREW__; __THREW__ = 0;
                  $60 = $59&1;
                  if ($60) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097904 + 4|0))>>2] = 0;
                  HEAP32[3097904>>2] = ((3092144 + 8|0));
                  HEAP32[((3097904 + 8|0))>>2] = ((3092144 + 56|0));
                  __THREW__ = 0;
                  invoke_vii(3535,($this|0),(3097904|0));
                  $61 = __THREW__; __THREW__ = 0;
                  $62 = $61&1;
                  if ($62) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097888 + 4|0))>>2] = 0;
                  HEAP32[3097888>>2] = ((3092296 + 8|0));
                  HEAP32[((3097888 + 8|0))>>2] = ((3092296 + 56|0));
                  __THREW__ = 0;
                  invoke_vii(3536,($this|0),(3097888|0));
                  $63 = __THREW__; __THREW__ = 0;
                  $64 = $63&1;
                  if ($64) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097872 + 4|0))>>2] = 0;
                  HEAP32[3097872>>2] = ((3094240 + 8|0));
                  __THREW__ = 0;
                  $65 = (invoke_i(134)|0);
                  $66 = __THREW__; __THREW__ = 0;
                  $67 = $66&1;
                  if ($67) {
                   $68 = ___cxa_find_matching_catch()|0;
                   $69 = tempRet0;
                   $eh$lpad$body$index3Z2D = $69;$eh$lpad$body$indexZ2D = $68;
                   break;
                  }
                  HEAP32[((3097872 + 8|0))>>2] = $65;
                  HEAP32[3097872>>2] = ((3092592 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3537,($this|0),(3097872|0));
                  $70 = __THREW__; __THREW__ = 0;
                  $71 = $70&1;
                  if ($71) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097856 + 4|0))>>2] = 0;
                  HEAP32[3097856>>2] = ((3094240 + 8|0));
                  __THREW__ = 0;
                  $72 = (invoke_i(134)|0);
                  $73 = __THREW__; __THREW__ = 0;
                  $74 = $73&1;
                  if ($74) {
                   $75 = ___cxa_find_matching_catch()|0;
                   $76 = tempRet0;
                   $eh$lpad$body$index3Z2D = $76;$eh$lpad$body$indexZ2D = $75;
                   break;
                  }
                  HEAP32[((3097856 + 8|0))>>2] = $72;
                  HEAP32[3097856>>2] = ((3092624 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3538,($this|0),(3097856|0));
                  $77 = __THREW__; __THREW__ = 0;
                  $78 = $77&1;
                  if ($78) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097848 + 4|0))>>2] = 0;
                  HEAP32[3097848>>2] = ((3093136 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3539,($this|0),(3097848|0));
                  $79 = __THREW__; __THREW__ = 0;
                  $80 = $79&1;
                  if ($80) {
                   label = 41;
                   break;
                  }
                  HEAP32[((3097840 + 4|0))>>2] = 0;
                  HEAP32[3097840>>2] = ((3093176 + 8|0));
                  __THREW__ = 0;
                  invoke_vii(3540,($this|0),(3097840|0));
                  $81 = __THREW__; __THREW__ = 0;
                  $82 = $81&1;
                  if ($82) {
                   label = 41;
                   break;
                  }
                  STACKTOP = sp;return;
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  } while(0);
  if ((label|0) == 41) {
   $87 = ___cxa_find_matching_catch()|0;
   $88 = tempRet0;
   $eh$lpad$body$index3Z2D = $88;$eh$lpad$body$indexZ2D = $87;
  }
  __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($5);
  $$0 = $eh$lpad$body$index3Z2D;$$01 = $eh$lpad$body$indexZ2D;
 }
 __ZNSt3__113__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev($2);
 $$1 = $$0;$$12 = $$01;
 ___resumeException($$12|0);
 // unreachable;
}
function __ZNSt3__16locale5__imp7installINS_7collateIcEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3091728)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7collateIwEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3091768)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_5ctypeIcEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093336)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_5ctypeIwEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093328)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093400)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093408)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093464)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093472)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_8numpunctIcEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093480)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_8numpunctIwEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093488)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3091840)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3091960)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092024)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092120)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092712)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092776)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092840)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092904)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092944)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093024)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093080)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093128)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092232)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092384)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092616)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3092648)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_8messagesIcEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093168)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__imp7installINS_8messagesIwEEEEvPT_($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale2id5__getEv(3093208)|0);
 __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale7classicEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093288>>0]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   $2 = (___cxa_guard_acquire((3093288|0))|0);
   $3 = ($2|0)==(0);
   if (!($3)) {
    __THREW__ = 0;
    (invoke_i(135)|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     ___cxa_guard_abort((3093288|0));
     ___resumeException($7|0);
     // unreachable;
    } else {
     HEAP32[3093280>>2] = 3093272;
     ___cxa_guard_release((3093288|0));
     break;
    }
   }
  }
 } while(0);
 $6 = HEAP32[3093280>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__16locale5__imp7installEPNS0_5facetEl($this,$f,$id) {
 $this = $this|0;
 $f = $f|0;
 $id = $id|0;
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__114__shared_count12__add_sharedEv($f);
 $0 = (($this) + 8|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = $2;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($id>>>0);
 do {
  if ($8) {
   $16 = $3;
  } else {
   $9 = (($id) + 1)|0;
   __THREW__ = 0;
   invoke_vii(3541,($0|0),($9|0));
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    $$pre2 = HEAP32[$0>>2]|0;
    $16 = $$pre2;
    break;
   }
   $12 = ___cxa_find_matching_catch()|0;
   $13 = tempRet0;
   $14 = ($f|0)==(0|0);
   if ($14) {
    ___resumeException($12|0);
    // unreachable;
   }
   (__ZNSt3__114__shared_count16__release_sharedEv($f)|0);
   ___resumeException($12|0);
   // unreachable;
  }
 } while(0);
 $15 = (($16) + ($id<<2)|0);
 $17 = HEAP32[$15>>2]|0;
 $18 = ($17|0)==(0|0);
 if ($18) {
  $20 = $16;
  $19 = (($20) + ($id<<2)|0);
  HEAP32[$19>>2] = $f;
  STACKTOP = sp;return;
 }
 (__ZNSt3__114__shared_count16__release_sharedEv($17)|0);
 $$pre = HEAP32[$0>>2]|0;
 $20 = $$pre;
 $19 = (($20) + ($id<<2)|0);
 HEAP32[$19>>2] = $f;
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__impD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__16locale5__impD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5__impD2Ev($this) {
 $this = $this|0;
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3093248 + 8|0));
 $0 = (($this) + 8|0);
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$0>>2]|0;
 $4 = ($2|0)==($3|0);
 if (!($4)) {
  $18 = $2;$6 = $3;$i$01 = 0;
  while(1) {
   $5 = (($6) + ($i$01<<2)|0);
   $7 = HEAP32[$5>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $11 = $18;$13 = $6;
   } else {
    (__ZNSt3__114__shared_count16__release_sharedEv($7)|0);
    $$pre = HEAP32[$1>>2]|0;
    $$pre2 = HEAP32[$0>>2]|0;
    $11 = $$pre;$13 = $$pre2;
   }
   $9 = (($i$01) + 1)|0;
   $10 = $11;
   $12 = $13;
   $14 = (($10) - ($12))|0;
   $15 = $14 >> 2;
   $16 = ($9>>>0)<($15>>>0);
   if ($16) {
    $18 = $11;$6 = $13;$i$01 = $9;
   } else {
    break;
   }
  }
 }
 $17 = (($this) + 144|0);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($17);
 __ZNSt3__113__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev($0);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE6resizeEj($this,$__sz) {
 $this = $this|0;
 $__sz = $__sz|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep4$i$i = 0, $uglygep$i$i = 0, $uglygep3$i$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = $1;
 $4 = $2;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = ($6>>>0)<($__sz>>>0);
 if ($7) {
  $8 = (($__sz) - ($6))|0;
  __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8__appendEj($this,$8);
  STACKTOP = sp;return;
 }
 $9 = ($6>>>0)>($__sz>>>0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($2) + ($__sz<<2)|0);
 $11 = ($1|0)==($10|0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $__new_last2$i$i = $10;
 $scevgep$i$i = (($1) + -4|0);
 $12 = (0 - ($__new_last2$i$i))|0;
 $uglygep$i$i = (($scevgep$i$i) + ($12)|0);
 $uglygep3$i$i = $uglygep$i$i;
 $13 = $uglygep3$i$i >>> 2;
 $14 = $13 ^ -1;
 $scevgep4$i$i = (($1) + ($14<<2)|0);
 HEAP32[$0>>2] = $scevgep4$i$i;
 STACKTOP = sp;return;
}
function __ZNKSt3__16locale5__imp9use_facetEl($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNKSt3__16locale5__imp9has_facetEl($this,$id)|0);
 if ($0) {
  $2 = (($this) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (($3) + ($id<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  STACKTOP = sp;return ($5|0);
 } else {
  $1 = (___cxa_allocate_exception(4)|0);
  __ZNSt8bad_castC2Ev($1);
  ___cxa_throw(($1|0),(3105888|0),(3289|0));
  // unreachable;
 }
 return 0|0;
}
function __ZNKSt3__16locale5__imp9has_facetEl($this,$id) {
 $this = $this|0;
 $id = $id|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)>($id>>>0);
 if (!($8)) {
  $12 = 0;
  STACKTOP = sp;return ($12|0);
 }
 $9 = (($3) + ($id<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)!=(0|0);
 $12 = $11;
 STACKTOP = sp;return ($12|0);
}
function __ZNSt3__16locale5__imp12make_classicEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__16locale5__impC2Ej(3097680,1);
 HEAP32[3093272>>2] = 3097680;
 STACKTOP = sp;return (3093272|0);
}
function __ZNSt3__16locale5__imp11make_globalEv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__16locale7classicEv()|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[3093296>>2] = $1;
 __ZNSt3__114__shared_count12__add_sharedEv($1);
 STACKTOP = sp;return (3093296|0);
}
function __ZNSt3__16locale8__globalEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093312>>0]|0;
 $1 = ($0<<24>>24)==(0);
 do {
  if ($1) {
   $2 = (___cxa_guard_acquire((3093312|0))|0);
   $3 = ($2|0)==(0);
   if (!($3)) {
    __THREW__ = 0;
    (invoke_i(136)|0);
    $4 = __THREW__; __THREW__ = 0;
    $5 = $4&1;
    if ($5) {
     $7 = ___cxa_find_matching_catch()|0;
     $8 = tempRet0;
     ___cxa_guard_abort((3093312|0));
     ___resumeException($7|0);
     // unreachable;
    } else {
     HEAP32[3093304>>2] = 3093296;
     ___cxa_guard_release((3093312|0));
     break;
    }
   }
  }
 } while(0);
 $6 = HEAP32[3093304>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__16localeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(137)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch(0|0)|0;
  $5 = tempRet0;
  ___clang_call_terminate($4);
  // unreachable;
 } else {
  $3 = HEAP32[$0>>2]|0;
  HEAP32[$this>>2] = $3;
  __ZNSt3__114__shared_count12__add_sharedEv($3);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16localeC2ERKS0_($this,$l) {
 $this = $this|0;
 $l = $l|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$l>>2]|0;
 HEAP32[$this>>2] = $0;
 __ZNSt3__114__shared_count12__add_sharedEv($0);
 STACKTOP = sp;return;
}
function __ZNSt3__16localeD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 (__ZNSt3__114__shared_count16__release_sharedEv($0)|0);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale2id5__getEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $__p$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p$i = sp;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(-1);
 if (!($1)) {
  HEAP32[$__p$i>>2] = $this;
  $2 = (($__p$i) + 4|0);
  HEAP32[$2>>2] = (3857);
  $3 = (($__p$i) + 8|0);
  HEAP32[$3>>2] = 0;
  __ZNSt3__111__call_onceERVmPvPFvS2_E($this,$__p$i,3858);
 }
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -1)|0;
 STACKTOP = sp;return ($6|0);
}
function __ZNKSt3__16locale9use_facetERNS0_2idE($this,$x) {
 $this = $this|0;
 $x = $x|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZNSt3__16locale2id5__getEv($x)|0);
 $2 = (__ZNKSt3__16locale5__imp9use_facetEl($0,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNSt3__16locale5facetD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale5facet16__on_zero_sharedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($this|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = HEAP32[$this>>2]|0;
 $2 = (($1) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 FUNCTION_TABLE_vi[$3 & 4095]($this);
 STACKTOP = sp;return;
}
function __ZNSt3__16locale2id6__initEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[3093320>>2]|0;HEAP32[3093320>>2] = (($0+1)|0);
 $1 = (($0) + 1)|0;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __ZNSt3__15ctypeIwED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNKSt3__15ctypeIwE5do_isEtw($this,$m,$c) {
 $this = $this|0;
 $m = $m|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $isascii = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isascii = ($c>>>0)<(128);
 if (!($isascii)) {
  $5 = 0;
  STACKTOP = sp;return ($5|0);
 }
 $0 = (__ZNSt3__15ctypeIcE13classic_tableEv()|0);
 $1 = (($0) + ($c<<1)|0);
 $2 = HEAP16[$1>>1]|0;
 $3 = $2 & $m;
 $4 = ($3<<16>>16)!=(0);
 $5 = $4;
 STACKTOP = sp;return ($5|0);
}
function __ZNSt3__15ctypeIcE13classic_tableEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(138)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch(0|0)|0;
  $5 = tempRet0;
  ___clang_call_terminate($4);
  // unreachable;
 } else {
  $3 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZNKSt3__15ctypeIwE5do_isEPKwS3_Pt($this,$low,$high,$vec) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 $vec = $vec|0;
 var $$01$lcssa = 0, $$012 = 0, $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isascii = 0, $low5 = 0, $scevgep = 0, $scevgep7 = 0, $uglygep = 0;
 var $uglygep6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$01$lcssa = $low;
  STACKTOP = sp;return ($$01$lcssa|0);
 }
 $low5 = $low;
 $scevgep = (($high) + -4|0);
 $1 = (0 - ($low5))|0;
 $uglygep = (($scevgep) + ($1)|0);
 $uglygep6 = $uglygep;
 $2 = $uglygep6 >>> 2;
 $3 = (($2) + 1)|0;
 $$012 = $low;$$03 = $vec;
 while(1) {
  $4 = HEAP32[$$012>>2]|0;
  $isascii = ($4>>>0)<(128);
  if ($isascii) {
   $5 = (__ZNSt3__15ctypeIcE13classic_tableEv()|0);
   $6 = (($5) + ($4<<1)|0);
   $7 = HEAP16[$6>>1]|0;
   $8 = $7;
  } else {
   $8 = 0;
  }
  HEAP16[$$03>>1] = $8;
  $9 = (($$012) + 4|0);
  $10 = (($$03) + 2|0);
  $11 = ($9|0)==($high|0);
  if ($11) {
   break;
  } else {
   $$012 = $9;$$03 = $10;
  }
 }
 $scevgep7 = (($low) + ($3<<2)|0);
 $$01$lcssa = $scevgep7;
 STACKTOP = sp;return ($$01$lcssa|0);
}
function __ZNKSt3__15ctypeIwE10do_scan_isEtPKwS3_($this,$m,$low,$high) {
 $this = $this|0;
 $m = $m|0;
 $low = $low|0;
 $high = $high|0;
 var $$0$lcssa = 0, $$01 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $isascii = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 L1: do {
  if ($0) {
   $$0$lcssa = $low;
  } else {
   $$01 = $low;
   while(1) {
    $1 = HEAP32[$$01>>2]|0;
    $isascii = ($1>>>0)<(128);
    if ($isascii) {
     $2 = (__ZNSt3__15ctypeIcE13classic_tableEv()|0);
     $3 = (($2) + ($1<<1)|0);
     $4 = HEAP16[$3>>1]|0;
     $5 = $4 & $m;
     $6 = ($5<<16>>16)==(0);
     if (!($6)) {
      $$0$lcssa = $$01;
      break L1;
     }
    }
    $7 = (($$01) + 4|0);
    $8 = ($7|0)==($high|0);
    if ($8) {
     $$0$lcssa = $high;
     break;
    } else {
     $$01 = $7;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0$lcssa|0);
}
function __ZNKSt3__15ctypeIwE11do_scan_notEtPKwS3_($this,$m,$low,$high) {
 $this = $this|0;
 $m = $m|0;
 $low = $low|0;
 $high = $high|0;
 var $$0$lcssa = 0, $$01 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $isascii = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 L1: do {
  if ($0) {
   $$0$lcssa = $low;
  } else {
   $$01 = $low;
   while(1) {
    $3 = HEAP32[$$01>>2]|0;
    $isascii = ($3>>>0)<(128);
    if (!($isascii)) {
     $$0$lcssa = $$01;
     break L1;
    }
    $4 = (__ZNSt3__15ctypeIcE13classic_tableEv()|0);
    $5 = (($4) + ($3<<1)|0);
    $6 = HEAP16[$5>>1]|0;
    $7 = $6 & $m;
    $8 = ($7<<16>>16)==(0);
    $2 = (($$01) + 4|0);
    if ($8) {
     $$0$lcssa = $$01;
     break L1;
    }
    $1 = ($2|0)==($high|0);
    if ($1) {
     $$0$lcssa = $high;
     break;
    } else {
     $$01 = $2;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0$lcssa|0);
}
function __ZNKSt3__15ctypeIwE10do_toupperEw($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $isascii = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isascii = ($c>>>0)<(128);
 if (!($isascii)) {
  $3 = $c;
  STACKTOP = sp;return ($3|0);
 }
 $0 = (__ZNSt3__15ctypeIcE21__classic_upper_tableEv()|0);
 $1 = (($0) + ($c<<2)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 STACKTOP = sp;return ($3|0);
}
function __ZNSt3__15ctypeIcE21__classic_upper_tableEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(139)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch(0|0)|0;
  $5 = tempRet0;
  ___clang_call_terminate($4);
  // unreachable;
 } else {
  $3 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZNKSt3__15ctypeIwE10do_toupperEPwPKw($this,$low,$high) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 var $$0$lcssa = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isascii = 0, $low3 = 0, $scevgep = 0, $scevgep5 = 0, $uglygep = 0, $uglygep4 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$0$lcssa = $low;
  STACKTOP = sp;return ($$0$lcssa|0);
 }
 $low3 = $low;
 $scevgep = (($high) + -4|0);
 $1 = (0 - ($low3))|0;
 $uglygep = (($scevgep) + ($1)|0);
 $uglygep4 = $uglygep;
 $2 = $uglygep4 >>> 2;
 $3 = (($2) + 1)|0;
 $$01 = $low;
 while(1) {
  $4 = HEAP32[$$01>>2]|0;
  $isascii = ($4>>>0)<(128);
  if ($isascii) {
   $5 = (__ZNSt3__15ctypeIcE21__classic_upper_tableEv()|0);
   $6 = (($5) + ($4<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $7;
  } else {
   $8 = $4;
  }
  HEAP32[$$01>>2] = $8;
  $9 = (($$01) + 4|0);
  $10 = ($9|0)==($high|0);
  if ($10) {
   break;
  } else {
   $$01 = $9;
  }
 }
 $scevgep5 = (($low) + ($3<<2)|0);
 $$0$lcssa = $scevgep5;
 STACKTOP = sp;return ($$0$lcssa|0);
}
function __ZNKSt3__15ctypeIwE10do_tolowerEw($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $isascii = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isascii = ($c>>>0)<(128);
 if (!($isascii)) {
  $3 = $c;
  STACKTOP = sp;return ($3|0);
 }
 $0 = (__ZNSt3__15ctypeIcE21__classic_lower_tableEv()|0);
 $1 = (($0) + ($c<<2)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 STACKTOP = sp;return ($3|0);
}
function __ZNSt3__15ctypeIcE21__classic_lower_tableEv() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(140)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $4 = ___cxa_find_matching_catch(0|0)|0;
  $5 = tempRet0;
  ___clang_call_terminate($4);
  // unreachable;
 } else {
  $3 = HEAP32[$0>>2]|0;
  STACKTOP = sp;return ($3|0);
 }
 return 0|0;
}
function __ZNKSt3__15ctypeIwE10do_tolowerEPwPKw($this,$low,$high) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 var $$0$lcssa = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isascii = 0, $low3 = 0, $scevgep = 0, $scevgep5 = 0, $uglygep = 0, $uglygep4 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$0$lcssa = $low;
  STACKTOP = sp;return ($$0$lcssa|0);
 }
 $low3 = $low;
 $scevgep = (($high) + -4|0);
 $1 = (0 - ($low3))|0;
 $uglygep = (($scevgep) + ($1)|0);
 $uglygep4 = $uglygep;
 $2 = $uglygep4 >>> 2;
 $3 = (($2) + 1)|0;
 $$01 = $low;
 while(1) {
  $4 = HEAP32[$$01>>2]|0;
  $isascii = ($4>>>0)<(128);
  if ($isascii) {
   $5 = (__ZNSt3__15ctypeIcE21__classic_lower_tableEv()|0);
   $6 = (($5) + ($4<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $7;
  } else {
   $8 = $4;
  }
  HEAP32[$$01>>2] = $8;
  $9 = (($$01) + 4|0);
  $10 = ($9|0)==($high|0);
  if ($10) {
   break;
  } else {
   $$01 = $9;
  }
 }
 $scevgep5 = (($low) + ($3<<2)|0);
 $$0$lcssa = $scevgep5;
 STACKTOP = sp;return ($$0$lcssa|0);
}
function __ZNKSt3__15ctypeIwE8do_widenEc($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c << 24 >> 24;
 STACKTOP = sp;return ($0|0);
}
function __ZNKSt3__15ctypeIwE8do_widenEPKcS3_Pw($this,$low,$high,$dest) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 $dest = $dest|0;
 var $$01$lcssa = 0, $$012 = 0, $$03 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$01$lcssa = $low;
  STACKTOP = sp;return ($$01$lcssa|0);
 } else {
  $$012 = $low;$$03 = $dest;
 }
 while(1) {
  $1 = HEAP8[$$012>>0]|0;
  $2 = $1 << 24 >> 24;
  HEAP32[$$03>>2] = $2;
  $3 = (($$012) + 1|0);
  $4 = (($$03) + 4|0);
  $5 = ($3|0)==($high|0);
  if ($5) {
   $$01$lcssa = $high;
   break;
  } else {
   $$012 = $3;$$03 = $4;
  }
 }
 STACKTOP = sp;return ($$01$lcssa|0);
}
function __ZNKSt3__15ctypeIwE9do_narrowEwc($this,$c,$dfault) {
 $this = $this|0;
 $c = $c|0;
 $dfault = $dfault|0;
 var $$0 = 0, $0 = 0, $isascii = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isascii = ($c>>>0)<(128);
 $0 = $c&255;
 $$0 = $isascii ? $0 : $dfault;
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__15ctypeIwE9do_narrowEPKwS3_cPc($this,$low,$high,$dfault,$dest) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 $dfault = $dfault|0;
 $dest = $dest|0;
 var $$01$lcssa = 0, $$012 = 0, $$03 = 0, $$dfault = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $isascii = 0, $low5 = 0, $scevgep = 0, $scevgep7 = 0, $uglygep = 0, $uglygep6 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$01$lcssa = $low;
  STACKTOP = sp;return ($$01$lcssa|0);
 }
 $low5 = $low;
 $scevgep = (($high) + -4|0);
 $1 = (0 - ($low5))|0;
 $uglygep = (($scevgep) + ($1)|0);
 $uglygep6 = $uglygep;
 $2 = $uglygep6 >>> 2;
 $3 = (($2) + 1)|0;
 $$012 = $low;$$03 = $dest;
 while(1) {
  $4 = HEAP32[$$012>>2]|0;
  $isascii = ($4>>>0)<(128);
  $5 = $4&255;
  $$dfault = $isascii ? $5 : $dfault;
  HEAP8[$$03>>0] = $$dfault;
  $6 = (($$012) + 4|0);
  $7 = (($$03) + 1|0);
  $8 = ($6|0)==($high|0);
  if ($8) {
   break;
  } else {
   $$012 = $6;$$03 = $7;
  }
 }
 $scevgep7 = (($low) + ($3<<2)|0);
 $$01$lcssa = $scevgep7;
 STACKTOP = sp;return ($$01$lcssa|0);
}
function __ZNSt3__15ctypeIcEC2EPKtbj($this,$tab,$del,$refs) {
 $this = $this|0;
 $tab = $tab|0;
 $del = $del|0;
 $refs = $refs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($refs) + -1)|0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $0;
 HEAP32[$this>>2] = ((3093344 + 8|0));
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $tab;
 $3 = (($this) + 12|0);
 $4 = $del&1;
 HEAP8[$3>>0] = $4;
 $5 = ($tab|0)==(0|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (__ZNSt3__15ctypeIcE13classic_tableEv()|0);
 HEAP32[$2>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNSt3__15ctypeIcED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__15ctypeIcED2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__15ctypeIcED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3093344 + 8|0));
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = (($this) + 12|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if (!($5)) {
   __ZdaPv($1);
  }
 }
 STACKTOP = sp;return;
}
function __ZNKSt3__15ctypeIcE10do_toupperEc($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $isascii1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isascii1 = ($c<<24>>24)>(-1);
 if (!($isascii1)) {
  $5 = $c;
  STACKTOP = sp;return ($5|0);
 }
 $0 = $c&255;
 $1 = (__ZNSt3__15ctypeIcE21__classic_upper_tableEv()|0);
 $2 = (($1) + ($0<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3&255;
 $5 = $4;
 STACKTOP = sp;return ($5|0);
}
function __ZNKSt3__15ctypeIcE10do_toupperEPcPKc($this,$low,$high) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 var $$0$lcssa = 0, $$02 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isascii1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$0$lcssa = $low;
  STACKTOP = sp;return ($$0$lcssa|0);
 } else {
  $$02 = $low;
 }
 while(1) {
  $1 = HEAP8[$$02>>0]|0;
  $isascii1 = ($1<<24>>24)>(-1);
  if ($isascii1) {
   $2 = $1 << 24 >> 24;
   $3 = (__ZNSt3__15ctypeIcE21__classic_upper_tableEv()|0);
   $4 = (($3) + ($2<<2)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5&255;
   $7 = $6;
  } else {
   $7 = $1;
  }
  HEAP8[$$02>>0] = $7;
  $8 = (($$02) + 1|0);
  $9 = ($8|0)==($high|0);
  if ($9) {
   $$0$lcssa = $high;
   break;
  } else {
   $$02 = $8;
  }
 }
 STACKTOP = sp;return ($$0$lcssa|0);
}
function __ZNKSt3__15ctypeIcE10do_tolowerEc($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $isascii1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isascii1 = ($c<<24>>24)>(-1);
 if (!($isascii1)) {
  $5 = $c;
  STACKTOP = sp;return ($5|0);
 }
 $0 = $c << 24 >> 24;
 $1 = (__ZNSt3__15ctypeIcE21__classic_lower_tableEv()|0);
 $2 = (($1) + ($0<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3&255;
 $5 = $4;
 STACKTOP = sp;return ($5|0);
}
function __ZNKSt3__15ctypeIcE10do_tolowerEPcPKc($this,$low,$high) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 var $$0$lcssa = 0, $$02 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isascii1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$0$lcssa = $low;
  STACKTOP = sp;return ($$0$lcssa|0);
 } else {
  $$02 = $low;
 }
 while(1) {
  $1 = HEAP8[$$02>>0]|0;
  $isascii1 = ($1<<24>>24)>(-1);
  if ($isascii1) {
   $2 = $1 << 24 >> 24;
   $3 = (__ZNSt3__15ctypeIcE21__classic_lower_tableEv()|0);
   $4 = (($3) + ($2<<2)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = $5&255;
   $7 = $6;
  } else {
   $7 = $1;
  }
  HEAP8[$$02>>0] = $7;
  $8 = (($$02) + 1|0);
  $9 = ($8|0)==($high|0);
  if ($9) {
   $$0$lcssa = $high;
   break;
  } else {
   $$02 = $8;
  }
 }
 STACKTOP = sp;return ($$0$lcssa|0);
}
function __ZNKSt3__15ctypeIcE8do_widenEc($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($c|0);
}
function __ZNKSt3__15ctypeIcE8do_widenEPKcS3_Pc($this,$low,$high,$dest) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 $dest = $dest|0;
 var $$01$lcssa = 0, $$012 = 0, $$03 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$01$lcssa = $low;
 } else {
  $$012 = $low;$$03 = $dest;
  while(1) {
   $1 = HEAP8[$$012>>0]|0;
   HEAP8[$$03>>0] = $1;
   $2 = (($$012) + 1|0);
   $3 = (($$03) + 1|0);
   $4 = ($2|0)==($high|0);
   if ($4) {
    $$01$lcssa = $high;
    break;
   } else {
    $$012 = $2;$$03 = $3;
   }
  }
 }
 STACKTOP = sp;return ($$01$lcssa|0);
}
function __ZNKSt3__15ctypeIcE9do_narrowEcc($this,$c,$dfault) {
 $this = $this|0;
 $c = $c|0;
 $dfault = $dfault|0;
 var $c$dfault = 0, $isascii1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isascii1 = ($c<<24>>24)>(-1);
 $c$dfault = $isascii1 ? $c : $dfault;
 STACKTOP = sp;return ($c$dfault|0);
}
function __ZNKSt3__15ctypeIcE9do_narrowEPKcS3_cPc($this,$low,$high,$dfault,$dest) {
 $this = $this|0;
 $low = $low|0;
 $high = $high|0;
 $dfault = $dfault|0;
 $dest = $dest|0;
 var $$01$lcssa = 0, $$013 = 0, $$04 = 0, $$dfault = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $isascii2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($low|0)==($high|0);
 if ($0) {
  $$01$lcssa = $low;
  STACKTOP = sp;return ($$01$lcssa|0);
 } else {
  $$013 = $low;$$04 = $dest;
 }
 while(1) {
  $1 = HEAP8[$$013>>0]|0;
  $isascii2 = ($1<<24>>24)>(-1);
  $$dfault = $isascii2 ? $1 : $dfault;
  HEAP8[$$04>>0] = $$dfault;
  $2 = (($$013) + 1|0);
  $3 = (($$04) + 1|0);
  $4 = ($2|0)==($high|0);
  if ($4) {
   $$01$lcssa = $high;
   break;
  } else {
   $$013 = $2;$$04 = $3;
  }
 }
 STACKTOP = sp;return ($$01$lcssa|0);
}
function __ZNSt3__17codecvtIcc11__mbstate_tED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNKSt3__17codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_($this,$0,$frm,$1,$frm_nxt,$to,$2,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $1 = $1|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $2 = $2|0;
 $to_nxt = $to_nxt|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$frm_nxt>>2] = $frm;
 HEAP32[$to_nxt>>2] = $to;
 STACKTOP = sp;return 3;
}
function __ZNKSt3__17codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_($this,$0,$frm,$1,$frm_nxt,$to,$2,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $1 = $1|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $2 = $2|0;
 $to_nxt = $to_nxt|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$frm_nxt>>2] = $frm;
 HEAP32[$to_nxt>>2] = $to;
 STACKTOP = sp;return 3;
}
function __ZNKSt3__17codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_($this,$0,$to,$1,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $to = $to|0;
 $1 = $1|0;
 $to_nxt = $to_nxt|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$to_nxt>>2] = $to;
 STACKTOP = sp;return 3;
}
function __ZNKSt3__17codecvtIcc11__mbstate_tE11do_encodingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNKSt3__17codecvtIcc11__mbstate_tE16do_always_noconvEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNKSt3__17codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_j($this,$0,$frm,$end,$mx) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $end = $end|0;
 $mx = $mx|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = $end;
 $2 = $frm;
 $3 = (($1) - ($2))|0;
 $4 = ($3>>>0)<($mx>>>0);
 $5 = $4 ? $3 : $mx;
 STACKTOP = sp;return ($5|0);
}
function __ZNKSt3__17codecvtIcc11__mbstate_tE13do_max_lengthEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNSt3__17codecvtIwc11__mbstate_tEC2Ej($this,$refs) {
 $this = $this|0;
 $refs = $refs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($refs) + -1)|0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $0;
 HEAP32[$this>>2] = ((3093416 + 8|0));
 __THREW__ = 0;
 $2 = (invoke_i(134)|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if ($4) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  ___resumeException($6|0);
  // unreachable;
 } else {
  $5 = (($this) + 8|0);
  HEAP32[$5>>2] = $2;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17codecvtIwc11__mbstate_tED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__17codecvtIwc11__mbstate_tED2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNKSt3__17codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_($this,$st,$frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt) {
 $this = $this|0;
 $st = $st|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 var $$0 = 0, $$0148 = 0, $$0247 = 0, $$1$lcssa = 0, $$19 = 0, $$pre = 0, $$pre95 = 0, $$pre98 = 0, $$pre99 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $fend$0$lcssa = 0, $fend$052 = 0, $fend$149 = 0, $fend$2$lcssa = 0, $fend$215 = 0, $fend$3 = 0, $n$011 = 0, $not$ = 0, $or$cond = 0, $or$cond46 = 0, $p$012 = 0, $save_state = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $save_state = sp;
 $tmp = sp + 8|0;
 $0 = ($frm|0)==($frm_end|0);
 L1: do {
  if ($0) {
   HEAP32[$to_nxt>>2] = $to;
   HEAP32[$frm_nxt>>2] = $frm;
   $112 = $frm;
  } else {
   $fend$052 = $frm;
   while(1) {
    $3 = HEAP32[$fend$052>>2]|0;
    $4 = ($3|0)==(0);
    $2 = (($fend$052) + 4|0);
    if ($4) {
     $fend$0$lcssa = $fend$052;
     break;
    }
    $1 = ($2|0)==($frm_end|0);
    if ($1) {
     $fend$0$lcssa = $frm_end;
     break;
    } else {
     $fend$052 = $2;
    }
   }
   HEAP32[$to_nxt>>2] = $to;
   HEAP32[$frm_nxt>>2] = $frm;
   $5 = ($to|0)==($to_end|0);
   $or$cond46 = $0 | $5;
   if ($or$cond46) {
    $112 = $frm;
   } else {
    $6 = $to_end;
    $7 = (($this) + 8|0);
    $$0148 = $frm;$$0247 = $to;$fend$149 = $fend$0$lcssa;
    while(1) {
     $8 = $st;
     $9 = $8;
     $10 = HEAP32[$9>>2]|0;
     $11 = (($8) + 4)|0;
     $12 = $11;
     $13 = HEAP32[$12>>2]|0;
     $14 = $save_state;
     $15 = $14;
     HEAP32[$15>>2] = $10;
     $16 = (($14) + 4)|0;
     $17 = $16;
     HEAP32[$17>>2] = $13;
     $18 = $fend$149;
     $19 = $$0148;
     $20 = (($18) - ($19))|0;
     $21 = $20 >> 2;
     $22 = $$0247;
     $23 = (($6) - ($22))|0;
     $24 = HEAP32[$7>>2]|0;
     $25 = (_uselocale(($24|0))|0);
     __THREW__ = 0;
     $26 = (invoke_iiiiii(241,($$0247|0),($frm_nxt|0),($21|0),($23|0),($st|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 11;
      break;
     }
     $29 = ($25|0)==(0|0);
     if (!($29)) {
      __THREW__ = 0;
      (invoke_ii(3483,($25|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 10;
       break;
      }
     }
     if ((($26|0) == -1)) {
      label = 16;
      break;
     } else if ((($26|0) == 0)) {
      $$0 = 1;
      label = 51;
      break;
     }
     $68 = HEAP32[$to_nxt>>2]|0;
     $69 = (($68) + ($26)|0);
     HEAP32[$to_nxt>>2] = $69;
     $70 = ($69|0)==($to_end|0);
     if ($70) {
      label = 49;
      break;
     }
     $71 = ($fend$149|0)==($frm_end|0);
     if ($71) {
      $$pre98 = HEAP32[$frm_nxt>>2]|0;
      $109 = $$pre98;$111 = $69;$fend$3 = $frm_end;
     } else {
      $72 = HEAP32[$7>>2]|0;
      $73 = (_uselocale(($72|0))|0);
      __THREW__ = 0;
      $74 = (invoke_iiii(1686,($tmp|0),0,($st|0))|0);
      $75 = __THREW__; __THREW__ = 0;
      $76 = $75&1;
      if ($76) {
       label = 35;
       break;
      }
      $77 = ($73|0)==(0|0);
      if (!($77)) {
       __THREW__ = 0;
       (invoke_ii(3483,($73|0))|0);
       $78 = __THREW__; __THREW__ = 0;
       $79 = $78&1;
       if ($79) {
        label = 34;
        break;
       }
      }
      $89 = ($74|0)==(-1);
      if ($89) {
       $$0 = 2;
       label = 51;
       break;
      }
      $90 = HEAP32[$to_nxt>>2]|0;
      $91 = $90;
      $92 = (($6) - ($91))|0;
      $93 = ($74>>>0)>($92>>>0);
      if ($93) {
       $$0 = 1;
       label = 51;
       break;
      }
      $94 = ($74|0)==(0);
      L24: do {
       if (!($94)) {
        $97 = $90;$n$011 = $74;$p$012 = $tmp;
        while(1) {
         $95 = HEAP8[$p$012>>0]|0;
         $96 = (($97) + 1|0);
         HEAP32[$to_nxt>>2] = $96;
         HEAP8[$97>>0] = $95;
         $98 = (($n$011) + -1)|0;
         $99 = ($98|0)==(0);
         if ($99) {
          break L24;
         }
         $100 = (($p$012) + 1|0);
         $$pre99 = HEAP32[$to_nxt>>2]|0;
         $97 = $$pre99;$n$011 = $98;$p$012 = $100;
        }
       }
      } while(0);
      $101 = HEAP32[$frm_nxt>>2]|0;
      $102 = (($101) + 4|0);
      HEAP32[$frm_nxt>>2] = $102;
      $103 = ($102|0)==($frm_end|0);
      L29: do {
       if ($103) {
        $fend$2$lcssa = $frm_end;
       } else {
        $fend$215 = $102;
        while(1) {
         $106 = HEAP32[$fend$215>>2]|0;
         $107 = ($106|0)==(0);
         $105 = (($fend$215) + 4|0);
         if ($107) {
          $fend$2$lcssa = $fend$215;
          break L29;
         }
         $104 = ($105|0)==($frm_end|0);
         if ($104) {
          $fend$2$lcssa = $frm_end;
          break;
         } else {
          $fend$215 = $105;
         }
        }
       }
      } while(0);
      $$pre95 = HEAP32[$to_nxt>>2]|0;
      $109 = $102;$111 = $$pre95;$fend$3 = $fend$2$lcssa;
     }
     $108 = ($109|0)==($frm_end|0);
     $110 = ($111|0)==($to_end|0);
     $or$cond = $108 | $110;
     if ($or$cond) {
      $112 = $109;
      break L1;
     } else {
      $$0148 = $109;$$0247 = $111;$fend$149 = $fend$3;
     }
    }
    if ((label|0) == 10) {
     $32 = ___cxa_find_matching_catch(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    }
    else if ((label|0) == 11) {
     $34 = ___cxa_find_matching_catch()|0;
     $35 = tempRet0;
     $36 = ($25|0)==(0|0);
     if ($36) {
      ___resumeException($34|0);
      // unreachable;
     }
     __THREW__ = 0;
     (invoke_ii(3483,($25|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $39 = ___cxa_find_matching_catch(0|0)|0;
      $40 = tempRet0;
      ___clang_call_terminate($39);
      // unreachable;
     } else {
      ___resumeException($34|0);
      // unreachable;
     }
    }
    else if ((label|0) == 16) {
     HEAP32[$to_nxt>>2] = $$0247;
     $41 = HEAP32[$frm_nxt>>2]|0;
     $42 = ($$0148|0)==($41|0);
     L46: do {
      if ($42) {
       $$1$lcssa = $$0148;
      } else {
       $$19 = $$0148;$46 = $$0247;
       while(1) {
        $43 = HEAP32[$$19>>2]|0;
        $44 = HEAP32[$7>>2]|0;
        $45 = (_uselocale(($44|0))|0);
        __THREW__ = 0;
        $47 = (invoke_iiii(1686,($46|0),($43|0),($save_state|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         break;
        }
        $50 = ($45|0)==(0|0);
        if (!($50)) {
         __THREW__ = 0;
         (invoke_ii(3483,($45|0))|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          label = 20;
          break;
         }
        }
        $62 = ($47|0)==(-1);
        if ($62) {
         $$1$lcssa = $$19;
         break L46;
        }
        $63 = HEAP32[$to_nxt>>2]|0;
        $64 = (($63) + ($47)|0);
        HEAP32[$to_nxt>>2] = $64;
        $65 = (($$19) + 4|0);
        $66 = HEAP32[$frm_nxt>>2]|0;
        $67 = ($65|0)==($66|0);
        if ($67) {
         $$1$lcssa = $65;
         break L46;
        } else {
         $$19 = $65;$46 = $64;
        }
       }
       if ((label|0) == 20) {
        $53 = ___cxa_find_matching_catch(0|0)|0;
        $54 = tempRet0;
        ___clang_call_terminate($53);
        // unreachable;
       }
       $55 = ___cxa_find_matching_catch()|0;
       $56 = tempRet0;
       $57 = ($45|0)==(0|0);
       if ($57) {
        ___resumeException($55|0);
        // unreachable;
       }
       __THREW__ = 0;
       (invoke_ii(3483,($45|0))|0);
       $58 = __THREW__; __THREW__ = 0;
       $59 = $58&1;
       if ($59) {
        $60 = ___cxa_find_matching_catch(0|0)|0;
        $61 = tempRet0;
        ___clang_call_terminate($60);
        // unreachable;
       } else {
        ___resumeException($55|0);
        // unreachable;
       }
      }
     } while(0);
     HEAP32[$frm_nxt>>2] = $$1$lcssa;
     $$0 = 2;
     STACKTOP = sp;return ($$0|0);
    }
    else if ((label|0) == 34) {
     $80 = ___cxa_find_matching_catch(0|0)|0;
     $81 = tempRet0;
     ___clang_call_terminate($80);
     // unreachable;
    }
    else if ((label|0) == 35) {
     $82 = ___cxa_find_matching_catch()|0;
     $83 = tempRet0;
     $84 = ($73|0)==(0|0);
     if ($84) {
      ___resumeException($82|0);
      // unreachable;
     }
     __THREW__ = 0;
     (invoke_ii(3483,($73|0))|0);
     $85 = __THREW__; __THREW__ = 0;
     $86 = $85&1;
     if ($86) {
      $87 = ___cxa_find_matching_catch(0|0)|0;
      $88 = tempRet0;
      ___clang_call_terminate($87);
      // unreachable;
     } else {
      ___resumeException($82|0);
      // unreachable;
     }
    }
    else if ((label|0) == 49) {
     $$pre = HEAP32[$frm_nxt>>2]|0;
     $112 = $$pre;
     break;
    }
    else if ((label|0) == 51) {
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $not$ = ($112|0)!=($frm_end|0);
 $113 = $not$&1;
 $$0 = $113;
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_($this,$st,$frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt) {
 $this = $this|0;
 $st = $st|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 var $$0 = 0, $$0155 = 0, $$0254 = 0, $$1$lcssa = 0, $$115 = 0, $$2 = 0, $$pre = 0, $$pre111 = 0, $$pre113 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $11 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fend$0$lcssa = 0, $fend$059 = 0, $fend$156 = 0, $fend$2$lcssa = 0, $fend$216 = 0;
 var $fend$3 = 0, $not$ = 0, $not$3 = 0, $or$cond = 0, $or$cond53 = 0, $save_state = 0, $storemerge14 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $save_state = sp;
 $0 = ($frm|0)==($frm_end|0);
 L1: do {
  if ($0) {
   HEAP32[$to_nxt>>2] = $to;
   HEAP32[$frm_nxt>>2] = $frm;
   $104 = $frm;
  } else {
   $fend$059 = $frm;
   while(1) {
    $3 = HEAP8[$fend$059>>0]|0;
    $4 = ($3<<24>>24)==(0);
    $2 = (($fend$059) + 1|0);
    if ($4) {
     $fend$0$lcssa = $fend$059;
     break;
    }
    $1 = ($2|0)==($frm_end|0);
    if ($1) {
     $fend$0$lcssa = $frm_end;
     break;
    } else {
     $fend$059 = $2;
    }
   }
   HEAP32[$to_nxt>>2] = $to;
   HEAP32[$frm_nxt>>2] = $frm;
   $5 = ($to|0)==($to_end|0);
   $or$cond53 = $0 | $5;
   if ($or$cond53) {
    $104 = $frm;
   } else {
    $6 = $to_end;
    $7 = (($this) + 8|0);
    $$0155 = $frm;$$0254 = $to;$fend$156 = $fend$0$lcssa;
    while(1) {
     $8 = $st;
     $9 = $8;
     $10 = HEAP32[$9>>2]|0;
     $11 = (($8) + 4)|0;
     $12 = $11;
     $13 = HEAP32[$12>>2]|0;
     $14 = $save_state;
     $15 = $14;
     HEAP32[$15>>2] = $10;
     $16 = (($14) + 4)|0;
     $17 = $16;
     HEAP32[$17>>2] = $13;
     $18 = $fend$156;
     $19 = $$0155;
     $20 = (($18) - ($19))|0;
     $21 = $$0254;
     $22 = (($6) - ($21))|0;
     $23 = $22 >> 2;
     $24 = HEAP32[$7>>2]|0;
     $25 = (_uselocale(($24|0))|0);
     __THREW__ = 0;
     $26 = (invoke_iiiiii(242,($$0254|0),($frm_nxt|0),($20|0),($23|0),($st|0))|0);
     $27 = __THREW__; __THREW__ = 0;
     $28 = $27&1;
     if ($28) {
      label = 11;
      break;
     }
     $29 = ($25|0)==(0|0);
     if (!($29)) {
      __THREW__ = 0;
      (invoke_ii(3483,($25|0))|0);
      $30 = __THREW__; __THREW__ = 0;
      $31 = $30&1;
      if ($31) {
       label = 10;
       break;
      }
     }
     if ((($26|0) == -1)) {
      label = 16;
      break;
     } else if ((($26|0) == 0)) {
      $$0 = 2;
      label = 50;
      break;
     }
     $69 = HEAP32[$to_nxt>>2]|0;
     $70 = (($69) + ($26<<2)|0);
     HEAP32[$to_nxt>>2] = $70;
     $71 = ($70|0)==($to_end|0);
     if ($71) {
      label = 48;
      break;
     }
     $72 = ($fend$156|0)==($frm_end|0);
     $$pre113 = HEAP32[$frm_nxt>>2]|0;
     if ($72) {
      $101 = $$pre113;$103 = $70;$fend$3 = $frm_end;
     } else {
      $73 = HEAP32[$7>>2]|0;
      $74 = (_uselocale(($73|0))|0);
      __THREW__ = 0;
      $75 = (invoke_iiiii(345,($70|0),($$pre113|0),1,($st|0))|0);
      $76 = __THREW__; __THREW__ = 0;
      $77 = $76&1;
      if ($77) {
       label = 38;
       break;
      }
      $78 = ($74|0)==(0|0);
      if (!($78)) {
       __THREW__ = 0;
       (invoke_ii(3483,($74|0))|0);
       $79 = __THREW__; __THREW__ = 0;
       $80 = $79&1;
       if ($80) {
        label = 37;
        break;
       }
      }
      $90 = ($75|0)==(0);
      if (!($90)) {
       $$0 = 2;
       label = 50;
       break;
      }
      $91 = HEAP32[$to_nxt>>2]|0;
      $92 = (($91) + 4|0);
      HEAP32[$to_nxt>>2] = $92;
      $93 = HEAP32[$frm_nxt>>2]|0;
      $94 = (($93) + 1|0);
      HEAP32[$frm_nxt>>2] = $94;
      $95 = ($94|0)==($frm_end|0);
      L23: do {
       if ($95) {
        $fend$2$lcssa = $frm_end;
       } else {
        $fend$216 = $94;
        while(1) {
         $98 = HEAP8[$fend$216>>0]|0;
         $99 = ($98<<24>>24)==(0);
         $97 = (($fend$216) + 1|0);
         if ($99) {
          $fend$2$lcssa = $fend$216;
          break L23;
         }
         $96 = ($97|0)==($frm_end|0);
         if ($96) {
          $fend$2$lcssa = $frm_end;
          break;
         } else {
          $fend$216 = $97;
         }
        }
       }
      } while(0);
      $$pre111 = HEAP32[$to_nxt>>2]|0;
      $101 = $94;$103 = $$pre111;$fend$3 = $fend$2$lcssa;
     }
     $100 = ($101|0)==($frm_end|0);
     $102 = ($103|0)==($to_end|0);
     $or$cond = $100 | $102;
     if ($or$cond) {
      $104 = $101;
      break L1;
     } else {
      $$0155 = $101;$$0254 = $103;$fend$156 = $fend$3;
     }
    }
    if ((label|0) == 10) {
     $32 = ___cxa_find_matching_catch(0|0)|0;
     $33 = tempRet0;
     ___clang_call_terminate($32);
     // unreachable;
    }
    else if ((label|0) == 11) {
     $34 = ___cxa_find_matching_catch()|0;
     $35 = tempRet0;
     $36 = ($25|0)==(0|0);
     if ($36) {
      ___resumeException($34|0);
      // unreachable;
     }
     __THREW__ = 0;
     (invoke_ii(3483,($25|0))|0);
     $37 = __THREW__; __THREW__ = 0;
     $38 = $37&1;
     if ($38) {
      $39 = ___cxa_find_matching_catch(0|0)|0;
      $40 = tempRet0;
      ___clang_call_terminate($39);
      // unreachable;
     } else {
      ___resumeException($34|0);
      // unreachable;
     }
    }
    else if ((label|0) == 16) {
     HEAP32[$to_nxt>>2] = $$0254;
     $41 = HEAP32[$frm_nxt>>2]|0;
     $42 = ($$0155|0)==($41|0);
     L46: do {
      if ($42) {
       $$1$lcssa = $$0155;
      } else {
       $$115 = $$0155;$storemerge14 = $$0254;
       while(1) {
        $43 = $$115;
        $44 = (($18) - ($43))|0;
        $45 = HEAP32[$7>>2]|0;
        $46 = (_uselocale(($45|0))|0);
        __THREW__ = 0;
        $47 = (invoke_iiiii(345,($storemerge14|0),($$115|0),($44|0),($save_state|0))|0);
        $48 = __THREW__; __THREW__ = 0;
        $49 = $48&1;
        if ($49) {
         label = 21;
         break;
        }
        $50 = ($46|0)==(0|0);
        if (!($50)) {
         __THREW__ = 0;
         (invoke_ii(3483,($46|0))|0);
         $51 = __THREW__; __THREW__ = 0;
         $52 = $51&1;
         if ($52) {
          label = 20;
          break;
         }
        }
        if ((($47|0) == -2)) {
         label = 28;
         break;
        } else if ((($47|0) == -1)) {
         label = 27;
         break;
        } else if ((($47|0) == 0)) {
         $62 = (($$115) + 1|0);
         $$2 = $62;
        } else {
         $63 = (($$115) + ($47)|0);
         $$2 = $63;
        }
        $64 = HEAP32[$to_nxt>>2]|0;
        $65 = (($64) + 4|0);
        HEAP32[$to_nxt>>2] = $65;
        $66 = HEAP32[$frm_nxt>>2]|0;
        $67 = ($$2|0)==($66|0);
        if ($67) {
         $$1$lcssa = $$2;
         break L46;
        } else {
         $$115 = $$2;$storemerge14 = $65;
        }
       }
       if ((label|0) == 20) {
        $53 = ___cxa_find_matching_catch(0|0)|0;
        $54 = tempRet0;
        ___clang_call_terminate($53);
        // unreachable;
       }
       else if ((label|0) == 21) {
        $55 = ___cxa_find_matching_catch()|0;
        $56 = tempRet0;
        $57 = ($46|0)==(0|0);
        if ($57) {
         ___resumeException($55|0);
         // unreachable;
        }
        __THREW__ = 0;
        (invoke_ii(3483,($46|0))|0);
        $58 = __THREW__; __THREW__ = 0;
        $59 = $58&1;
        if ($59) {
         $60 = ___cxa_find_matching_catch(0|0)|0;
         $61 = tempRet0;
         ___clang_call_terminate($60);
         // unreachable;
        } else {
         ___resumeException($55|0);
         // unreachable;
        }
       }
       else if ((label|0) == 27) {
        HEAP32[$frm_nxt>>2] = $$115;
        $$0 = 2;
        STACKTOP = sp;return ($$0|0);
       }
       else if ((label|0) == 28) {
        HEAP32[$frm_nxt>>2] = $$115;
        $$0 = 1;
        STACKTOP = sp;return ($$0|0);
       }
      }
     } while(0);
     HEAP32[$frm_nxt>>2] = $$1$lcssa;
     $not$3 = ($$1$lcssa|0)!=($frm_end|0);
     $68 = $not$3&1;
     $$0 = $68;
     STACKTOP = sp;return ($$0|0);
    }
    else if ((label|0) == 37) {
     $81 = ___cxa_find_matching_catch(0|0)|0;
     $82 = tempRet0;
     ___clang_call_terminate($81);
     // unreachable;
    }
    else if ((label|0) == 38) {
     $83 = ___cxa_find_matching_catch()|0;
     $84 = tempRet0;
     $85 = ($74|0)==(0|0);
     if ($85) {
      ___resumeException($83|0);
      // unreachable;
     }
     __THREW__ = 0;
     (invoke_ii(3483,($74|0))|0);
     $86 = __THREW__; __THREW__ = 0;
     $87 = $86&1;
     if ($87) {
      $88 = ___cxa_find_matching_catch(0|0)|0;
      $89 = tempRet0;
      ___clang_call_terminate($88);
      // unreachable;
     } else {
      ___resumeException($83|0);
      // unreachable;
     }
    }
    else if ((label|0) == 48) {
     $$pre = HEAP32[$frm_nxt>>2]|0;
     $104 = $$pre;
     break;
    }
    else if ((label|0) == 50) {
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 } while(0);
 $not$ = ($104|0)!=($frm_end|0);
 $105 = $not$&1;
 $$0 = $105;
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_($this,$st,$to,$to_end,$to_nxt) {
 $this = $this|0;
 $st = $st|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$02 = 0, $p$03 = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmp = sp;
 HEAP32[$to_nxt>>2] = $to;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_uselocale(($1|0))|0);
 __THREW__ = 0;
 $3 = (invoke_iiii(1686,($tmp|0),0,($st|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $11 = ___cxa_find_matching_catch()|0;
  $12 = tempRet0;
  $13 = ($2|0)==(0|0);
  if ($13) {
   ___resumeException($11|0);
   // unreachable;
  }
  __THREW__ = 0;
  (invoke_ii(3483,($2|0))|0);
  $14 = __THREW__; __THREW__ = 0;
  $15 = $14&1;
  if ($15) {
   $16 = ___cxa_find_matching_catch(0|0)|0;
   $17 = tempRet0;
   ___clang_call_terminate($16);
   // unreachable;
  } else {
   ___resumeException($11|0);
   // unreachable;
  }
 }
 $6 = ($2|0)==(0|0);
 if (!($6)) {
  __THREW__ = 0;
  (invoke_ii(3483,($2|0))|0);
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if ($8) {
   $9 = ___cxa_find_matching_catch(0|0)|0;
   $10 = tempRet0;
   ___clang_call_terminate($9);
   // unreachable;
  }
 }
 if ((($3|0) == 0) | (($3|0) == -1)) {
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (($3) + -1)|0;
 $19 = HEAP32[$to_nxt>>2]|0;
 $20 = $to_end;
 $21 = $19;
 $22 = (($20) - ($21))|0;
 $23 = ($18>>>0)>($22>>>0);
 if ($23) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $24 = ($18|0)==(0);
 if ($24) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $27 = $19;$n$02 = $18;$p$03 = $tmp;
 }
 while(1) {
  $25 = HEAP8[$p$03>>0]|0;
  $26 = (($27) + 1|0);
  HEAP32[$to_nxt>>2] = $26;
  HEAP8[$27>>0] = $25;
  $28 = (($n$02) + -1)|0;
  $29 = ($28|0)==(0);
  if ($29) {
   $$0 = 0;
   break;
  }
  $30 = (($p$03) + 1|0);
  $$pre = HEAP32[$to_nxt>>2]|0;
  $27 = $$pre;$n$02 = $28;$p$03 = $30;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17codecvtIwc11__mbstate_tE11do_encodingEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eh$lpad$body$indexZ2D = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 __THREW__ = 0;
 $2 = (invoke_ii(3483,($1|0))|0);
 $3 = __THREW__; __THREW__ = 0;
 $4 = $3&1;
 if (!($4)) {
  __THREW__ = 0;
  $5 = (invoke_iiii(1687,(0|0),(0|0),4)|0);
  $6 = __THREW__; __THREW__ = 0;
  $7 = $6&1;
  if ($7) {
   $13 = ___cxa_find_matching_catch(0|0)|0;
   $14 = tempRet0;
   $15 = ($2|0)==(0|0);
   if ($15) {
    $eh$lpad$body$indexZ2D = $13;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
   __THREW__ = 0;
   (invoke_ii(3483,($2|0))|0);
   $16 = __THREW__; __THREW__ = 0;
   $17 = $16&1;
   if ($17) {
    $18 = ___cxa_find_matching_catch(0|0)|0;
    $19 = tempRet0;
    ___clang_call_terminate($18);
    // unreachable;
   } else {
    $eh$lpad$body$indexZ2D = $13;
    ___clang_call_terminate($eh$lpad$body$indexZ2D);
    // unreachable;
   }
  }
  $8 = ($2|0)==(0|0);
  if (!($8)) {
   __THREW__ = 0;
   (invoke_ii(3483,($2|0))|0);
   $9 = __THREW__; __THREW__ = 0;
   $10 = $9&1;
   if ($10) {
    $11 = ___cxa_find_matching_catch(0|0)|0;
    $12 = tempRet0;
    ___clang_call_terminate($11);
    // unreachable;
   }
  }
  $20 = ($5|0)==(0);
  if (!($20)) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $21 = HEAP32[$0>>2]|0;
  $22 = ($21|0)==(0|0);
  if ($22) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  __THREW__ = 0;
  $23 = (invoke_ii(3483,($21|0))|0);
  $24 = __THREW__; __THREW__ = 0;
  $25 = $24&1;
  if (!($25)) {
   $26 = ($23|0)==(0|0);
   if ($26) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   __THREW__ = 0;
   (invoke_ii(3483,($23|0))|0);
   $27 = __THREW__; __THREW__ = 0;
   $28 = $27&1;
   if ($28) {
    $29 = ___cxa_find_matching_catch(0|0)|0;
    $30 = tempRet0;
    ___clang_call_terminate($29);
    // unreachable;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $31 = ___cxa_find_matching_catch(0|0)|0;
 $32 = tempRet0;
 $eh$lpad$body$indexZ2D = $31;
 ___clang_call_terminate($eh$lpad$body$indexZ2D);
 // unreachable;
 return 0|0;
}
function __ZNKSt3__17codecvtIwc11__mbstate_tE16do_always_noconvEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__17codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_j($this,$st,$frm,$frm_end,$mx) {
 $this = $this|0;
 $st = $st|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $mx = $mx|0;
 var $$016 = 0, $$1 = 0, $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $nbytes$0$lcssa = 0, $nbytes$07 = 0, $nbytes$1 = 0, $nwchar_t$08 = 0, $or$cond = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mx|0)==(0);
 $1 = ($frm|0)==($frm_end|0);
 $or$cond5 = $0 | $1;
 if ($or$cond5) {
  $nbytes$0$lcssa = 0;
  STACKTOP = sp;return ($nbytes$0$lcssa|0);
 }
 $2 = $frm_end;
 $3 = (($this) + 8|0);
 $$016 = $frm;$nbytes$07 = 0;$nwchar_t$08 = 0;
 while(1) {
  $4 = $$016;
  $5 = (($2) - ($4))|0;
  $6 = HEAP32[$3>>2]|0;
  $7 = (_uselocale(($6|0))|0);
  __THREW__ = 0;
  $8 = (invoke_iiii(1688,($$016|0),($5|0),($st|0))|0);
  $9 = __THREW__; __THREW__ = 0;
  $10 = $9&1;
  if ($10) {
   label = 7;
   break;
  }
  $11 = ($7|0)==(0|0);
  if (!($11)) {
   __THREW__ = 0;
   (invoke_ii(3483,($7|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if ($13) {
    label = 6;
    break;
   }
  }
  if ((($8|0) == 0)) {
   $23 = (($$016) + 1|0);
   $$1 = $23;$$pn = 1;
  } else if ((($8|0) == -2) | (($8|0) == -1)) {
   $nbytes$0$lcssa = $nbytes$07;
   label = 15;
   break;
  } else {
   $24 = (($$016) + ($8)|0);
   $$1 = $24;$$pn = $8;
  }
  $nbytes$1 = (($$pn) + ($nbytes$07))|0;
  $25 = (($nwchar_t$08) + 1)|0;
  $26 = ($25>>>0)>=($mx>>>0);
  $27 = ($$1|0)==($frm_end|0);
  $or$cond = $26 | $27;
  if ($or$cond) {
   $nbytes$0$lcssa = $nbytes$1;
   label = 15;
   break;
  } else {
   $$016 = $$1;$nbytes$07 = $nbytes$1;$nwchar_t$08 = $25;
  }
 }
 if ((label|0) == 6) {
  $14 = ___cxa_find_matching_catch(0|0)|0;
  $15 = tempRet0;
  ___clang_call_terminate($14);
  // unreachable;
 }
 else if ((label|0) == 7) {
  $16 = ___cxa_find_matching_catch()|0;
  $17 = tempRet0;
  $18 = ($7|0)==(0|0);
  if ($18) {
   ___resumeException($16|0);
   // unreachable;
  }
  __THREW__ = 0;
  (invoke_ii(3483,($7|0))|0);
  $19 = __THREW__; __THREW__ = 0;
  $20 = $19&1;
  if ($20) {
   $21 = ___cxa_find_matching_catch(0|0)|0;
   $22 = tempRet0;
   ___clang_call_terminate($21);
   // unreachable;
  } else {
   ___resumeException($16|0);
   // unreachable;
  }
 }
 else if ((label|0) == 15) {
  STACKTOP = sp;return ($nbytes$0$lcssa|0);
 }
 return 0|0;
}
function __ZNKSt3__17codecvtIwc11__mbstate_tE13do_max_lengthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $11 = 1;
  STACKTOP = sp;return ($11|0);
 }
 __THREW__ = 0;
 $3 = (invoke_ii(3483,($1|0))|0);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $12 = ___cxa_find_matching_catch(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 }
 $6 = ($3|0)==(0|0);
 if ($6) {
  $11 = 4;
  STACKTOP = sp;return ($11|0);
 }
 __THREW__ = 0;
 (invoke_ii(3483,($3|0))|0);
 $7 = __THREW__; __THREW__ = 0;
 $8 = $7&1;
 if ($8) {
  $9 = ___cxa_find_matching_catch(0|0)|0;
  $10 = tempRet0;
  ___clang_call_terminate($9);
  // unreachable;
 } else {
  $11 = 4;
  STACKTOP = sp;return ($11|0);
 }
 return 0|0;
}
function __ZNSt3__17codecvtIDsc11__mbstate_tED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNKSt3__17codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_($this,$0,$frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_frm_nxt = 0, $_to_nxt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_frm_nxt = sp + 4|0;
 $_to_nxt = sp;
 HEAP32[$_frm_nxt>>2] = $frm;
 HEAP32[$_to_nxt>>2] = $to;
 $1 = (__ZNSt3__1L13utf16_to_utf8EPKtS1_RS1_PhS3_RS3_mNS_12codecvt_modeE($frm,$frm_end,$_frm_nxt,$to,$to_end,$_to_nxt,1114111,0)|0);
 $2 = HEAP32[$_frm_nxt>>2]|0;
 $3 = $2;
 $4 = $frm;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 1;
 $7 = (($frm) + ($6<<1)|0);
 HEAP32[$frm_nxt>>2] = $7;
 $8 = HEAP32[$_to_nxt>>2]|0;
 $9 = $8;
 $10 = $to;
 $11 = (($9) - ($10))|0;
 $12 = (($to) + ($11)|0);
 HEAP32[$to_nxt>>2] = $12;
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__1L13utf16_to_utf8EPKtS1_RS1_PhS3_RS3_mNS_12codecvt_modeE($frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt,$Maxcode,$mode) {
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 $Maxcode = $Maxcode|0;
 $mode = $mode|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$frm_nxt>>2] = $frm;
 HEAP32[$to_nxt>>2] = $to;
 $0 = $mode & 2;
 $1 = ($0|0)==(0);
 do {
  if (!($1)) {
   $2 = $to_end;
   $3 = $to;
   $4 = (($2) - ($3))|0;
   $5 = ($4|0)<(3);
   if ($5) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $6 = (($to) + 1|0);
    HEAP32[$to_nxt>>2] = $6;
    HEAP8[$to>>0] = -17;
    $7 = HEAP32[$to_nxt>>2]|0;
    $8 = (($7) + 1|0);
    HEAP32[$to_nxt>>2] = $8;
    HEAP8[$7>>0] = -69;
    $9 = HEAP32[$to_nxt>>2]|0;
    $10 = (($9) + 1|0);
    HEAP32[$to_nxt>>2] = $10;
    HEAP8[$9>>0] = -65;
    break;
   }
  }
 } while(0);
 $11 = $frm_end;
 $12 = HEAP32[$frm_nxt>>2]|0;
 $13 = ($12>>>0)<($frm_end>>>0);
 if (!($13)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = $to_end;
 $16 = $12;
 L10: while(1) {
  $15 = HEAP16[$16>>1]|0;
  $17 = $15&65535;
  $18 = ($17>>>0)>($Maxcode>>>0);
  if ($18) {
   $$0 = 2;
   label = 26;
   break;
  }
  $19 = ($15&65535)<(128);
  do {
   if ($19) {
    $20 = HEAP32[$to_nxt>>2]|0;
    $21 = $20;
    $22 = (($14) - ($21))|0;
    $23 = ($22|0)<(1);
    if ($23) {
     $$0 = 1;
     label = 26;
     break L10;
    }
    $24 = $15&255;
    $25 = (($20) + 1|0);
    HEAP32[$to_nxt>>2] = $25;
    HEAP8[$20>>0] = $24;
   } else {
    $26 = ($15&65535)<(2048);
    if ($26) {
     $27 = HEAP32[$to_nxt>>2]|0;
     $28 = $27;
     $29 = (($14) - ($28))|0;
     $30 = ($29|0)<(2);
     if ($30) {
      $$0 = 1;
      label = 26;
      break L10;
     }
     $31 = $17 >>> 6;
     $32 = $31 | 192;
     $33 = $32&255;
     $34 = (($27) + 1|0);
     HEAP32[$to_nxt>>2] = $34;
     HEAP8[$27>>0] = $33;
     $35 = $17 & 63;
     $36 = $35 | 128;
     $37 = $36&255;
     $38 = HEAP32[$to_nxt>>2]|0;
     $39 = (($38) + 1|0);
     HEAP32[$to_nxt>>2] = $39;
     HEAP8[$38>>0] = $37;
     break;
    }
    $40 = ($15&65535)<(55296);
    if ($40) {
     $41 = HEAP32[$to_nxt>>2]|0;
     $42 = $41;
     $43 = (($14) - ($42))|0;
     $44 = ($43|0)<(3);
     if ($44) {
      $$0 = 1;
      label = 26;
      break L10;
     }
     $45 = $17 >>> 12;
     $46 = $45 | 224;
     $47 = $46&255;
     $48 = (($41) + 1|0);
     HEAP32[$to_nxt>>2] = $48;
     HEAP8[$41>>0] = $47;
     $49 = $17 >>> 6;
     $50 = $49 & 63;
     $51 = $50 | 128;
     $52 = $51&255;
     $53 = HEAP32[$to_nxt>>2]|0;
     $54 = (($53) + 1|0);
     HEAP32[$to_nxt>>2] = $54;
     HEAP8[$53>>0] = $52;
     $55 = $17 & 63;
     $56 = $55 | 128;
     $57 = $56&255;
     $58 = HEAP32[$to_nxt>>2]|0;
     $59 = (($58) + 1|0);
     HEAP32[$to_nxt>>2] = $59;
     HEAP8[$58>>0] = $57;
     break;
    }
    $60 = ($15&65535)<(56320);
    if (!($60)) {
     $112 = ($15&65535)<(57344);
     if ($112) {
      $$0 = 2;
      label = 26;
      break L10;
     }
     $113 = HEAP32[$to_nxt>>2]|0;
     $114 = $113;
     $115 = (($14) - ($114))|0;
     $116 = ($115|0)<(3);
     if ($116) {
      $$0 = 1;
      label = 26;
      break L10;
     }
     $117 = $17 >>> 12;
     $118 = $117 | 224;
     $119 = $118&255;
     $120 = (($113) + 1|0);
     HEAP32[$to_nxt>>2] = $120;
     HEAP8[$113>>0] = $119;
     $121 = $17 >>> 6;
     $122 = $121 & 63;
     $123 = $122 | 128;
     $124 = $123&255;
     $125 = HEAP32[$to_nxt>>2]|0;
     $126 = (($125) + 1|0);
     HEAP32[$to_nxt>>2] = $126;
     HEAP8[$125>>0] = $124;
     $127 = $17 & 63;
     $128 = $127 | 128;
     $129 = $128&255;
     $130 = HEAP32[$to_nxt>>2]|0;
     $131 = (($130) + 1|0);
     HEAP32[$to_nxt>>2] = $131;
     HEAP8[$130>>0] = $129;
     break;
    }
    $61 = $16;
    $62 = (($11) - ($61))|0;
    $63 = ($62|0)<(4);
    if ($63) {
     $$0 = 1;
     label = 26;
     break L10;
    }
    $64 = (($16) + 2|0);
    $65 = HEAP16[$64>>1]|0;
    $66 = $65&65535;
    $67 = $66 & 64512;
    $68 = ($67|0)==(56320);
    if (!($68)) {
     $$0 = 2;
     label = 26;
     break L10;
    }
    $69 = HEAP32[$to_nxt>>2]|0;
    $70 = $69;
    $71 = (($14) - ($70))|0;
    $72 = ($71|0)<(4);
    if ($72) {
     $$0 = 1;
     label = 26;
     break L10;
    }
    $73 = $17 & 960;
    $74 = $73 << 10;
    $75 = (($74) + 65536)|0;
    $76 = $17 << 10;
    $77 = $76 & 64512;
    $78 = $75 | $77;
    $79 = $66 & 1023;
    $80 = $78 | $79;
    $81 = ($80>>>0)>($Maxcode>>>0);
    if ($81) {
     $$0 = 2;
     label = 26;
     break L10;
    }
    HEAP32[$frm_nxt>>2] = $64;
    $82 = $73 >>> 6;
    $83 = (($82) + 1)|0;
    $84 = $83 >>> 2;
    $85 = $84 | 240;
    $86 = $85&255;
    $87 = HEAP32[$to_nxt>>2]|0;
    $88 = (($87) + 1|0);
    HEAP32[$to_nxt>>2] = $88;
    HEAP8[$87>>0] = $86;
    $89 = $83 << 4;
    $90 = $89 & 48;
    $91 = $17 >>> 2;
    $92 = $91 & 15;
    $93 = $92 | $90;
    $94 = $93 | 128;
    $95 = $94&255;
    $96 = HEAP32[$to_nxt>>2]|0;
    $97 = (($96) + 1|0);
    HEAP32[$to_nxt>>2] = $97;
    HEAP8[$96>>0] = $95;
    $98 = $17 << 4;
    $99 = $98 & 48;
    $100 = $66 >>> 6;
    $101 = $100 & 15;
    $102 = $99 | $101;
    $103 = $102 | 128;
    $104 = $103&255;
    $105 = HEAP32[$to_nxt>>2]|0;
    $106 = (($105) + 1|0);
    HEAP32[$to_nxt>>2] = $106;
    HEAP8[$105>>0] = $104;
    $107 = $66 & 63;
    $108 = $107 | 128;
    $109 = $108&255;
    $110 = HEAP32[$to_nxt>>2]|0;
    $111 = (($110) + 1|0);
    HEAP32[$to_nxt>>2] = $111;
    HEAP8[$110>>0] = $109;
   }
  } while(0);
  $132 = HEAP32[$frm_nxt>>2]|0;
  $133 = (($132) + 2|0);
  HEAP32[$frm_nxt>>2] = $133;
  $134 = ($133>>>0)<($frm_end>>>0);
  if ($134) {
   $16 = $133;
  } else {
   $$0 = 0;
   label = 26;
   break;
  }
 }
 if ((label|0) == 26) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNKSt3__17codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_($this,$0,$frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_frm_nxt = 0, $_to_nxt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_frm_nxt = sp + 4|0;
 $_to_nxt = sp;
 HEAP32[$_frm_nxt>>2] = $frm;
 HEAP32[$_to_nxt>>2] = $to;
 $1 = (__ZNSt3__1L13utf8_to_utf16EPKhS1_RS1_PtS3_RS3_mNS_12codecvt_modeE($frm,$frm_end,$_frm_nxt,$to,$to_end,$_to_nxt,1114111,0)|0);
 $2 = HEAP32[$_frm_nxt>>2]|0;
 $3 = $2;
 $4 = $frm;
 $5 = (($3) - ($4))|0;
 $6 = (($frm) + ($5)|0);
 HEAP32[$frm_nxt>>2] = $6;
 $7 = HEAP32[$_to_nxt>>2]|0;
 $8 = $7;
 $9 = $to;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 1;
 $12 = (($to) + ($11<<1)|0);
 HEAP32[$to_nxt>>2] = $12;
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__1L13utf8_to_utf16EPKhS1_RS1_PtS3_RS3_mNS_12codecvt_modeE($frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt,$Maxcode,$mode) {
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 $Maxcode = $Maxcode|0;
 $mode = $mode|0;
 var $$0 = 0, $$off = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$frm_nxt>>2] = $frm;
 HEAP32[$to_nxt>>2] = $to;
 $0 = $mode & 4;
 $1 = ($0|0)==(0);
 $$pre5 = HEAP32[$frm_nxt>>2]|0;
 if ($1) {
  $16 = $$pre5;
 } else {
  $2 = $frm_end;
  $3 = $$pre5;
  $4 = (($2) - ($3))|0;
  $5 = ($4|0)>(2);
  if ($5) {
   $6 = HEAP8[$$pre5>>0]|0;
   $7 = ($6<<24>>24)==(-17);
   if ($7) {
    $8 = (($$pre5) + 1|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(-69);
    if ($10) {
     $11 = (($$pre5) + 2|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($12<<24>>24)==(-65);
     if ($13) {
      $14 = (($$pre5) + 3|0);
      HEAP32[$frm_nxt>>2] = $14;
      $16 = $14;
     } else {
      $16 = $$pre5;
     }
    } else {
     $16 = $$pre5;
    }
   } else {
    $16 = $$pre5;
   }
  } else {
   $16 = $$pre5;
  }
 }
 $15 = ($16>>>0)<($frm_end>>>0);
 L8: do {
  if ($15) {
   $17 = $frm_end;
   $18 = $to_end;
   $$pre = HEAP32[$to_nxt>>2]|0;
   $20 = $$pre;$22 = $16;
   L10: while(1) {
    $19 = ($20>>>0)<($to_end>>>0);
    if (!($19)) {
     $135 = $22;
     break L8;
    }
    $21 = HEAP8[$22>>0]|0;
    $23 = $21&255;
    $24 = ($23>>>0)>($Maxcode>>>0);
    if ($24) {
     $$0 = 2;
     label = 41;
     break;
    }
    $25 = ($21<<24>>24)>(-1);
    do {
     if ($25) {
      $26 = $21&255;
      HEAP16[$20>>1] = $26;
      $27 = (($22) + 1|0);
      HEAP32[$frm_nxt>>2] = $27;
     } else {
      $28 = ($21&255)<(194);
      if ($28) {
       $$0 = 2;
       label = 41;
       break L10;
      }
      $29 = ($21&255)<(224);
      if ($29) {
       $30 = $22;
       $31 = (($17) - ($30))|0;
       $32 = ($31|0)<(2);
       if ($32) {
        $$0 = 1;
        label = 41;
        break L10;
       }
       $33 = (($22) + 1|0);
       $34 = HEAP8[$33>>0]|0;
       $35 = $34&255;
       $36 = $35 & 192;
       $37 = ($36|0)==(128);
       if (!($37)) {
        $$0 = 2;
        label = 41;
        break L10;
       }
       $38 = $23 << 6;
       $39 = $38 & 1984;
       $40 = $35 & 63;
       $41 = $40 | $39;
       $42 = ($41>>>0)>($Maxcode>>>0);
       if ($42) {
        $$0 = 2;
        label = 41;
        break L10;
       }
       $43 = $41&65535;
       HEAP16[$20>>1] = $43;
       $44 = (($22) + 2|0);
       HEAP32[$frm_nxt>>2] = $44;
       break;
      }
      $45 = ($21&255)<(240);
      if ($45) {
       $46 = $22;
       $47 = (($17) - ($46))|0;
       $48 = ($47|0)<(3);
       if ($48) {
        $$0 = 1;
        label = 41;
        break L10;
       }
       $49 = (($22) + 1|0);
       $50 = HEAP8[$49>>0]|0;
       $51 = (($22) + 2|0);
       $52 = HEAP8[$51>>0]|0;
       if ((($23|0) == 237)) {
        $55 = $50 & -32;
        $56 = ($55<<24>>24)==(-128);
        if (!($56)) {
         $$0 = 2;
         label = 41;
         break L10;
        }
       } else if ((($23|0) == 224)) {
        $53 = $50 & -32;
        $54 = ($53<<24>>24)==(-96);
        if (!($54)) {
         $$0 = 2;
         label = 41;
         break L10;
        }
       } else {
        $57 = $50 & -64;
        $58 = ($57<<24>>24)==(-128);
        if (!($58)) {
         $$0 = 2;
         label = 41;
         break L10;
        }
       }
       $59 = $52&255;
       $60 = $59 & 192;
       $61 = ($60|0)==(128);
       if (!($61)) {
        $$0 = 2;
        label = 41;
        break L10;
       }
       $62 = $23 << 12;
       $63 = $50&255;
       $64 = $63 << 6;
       $65 = $64 & 4032;
       $66 = $65 | $62;
       $67 = $59 & 63;
       $68 = $66 | $67;
       $69 = $68 & 65535;
       $70 = ($69>>>0)>($Maxcode>>>0);
       if ($70) {
        $$0 = 2;
        label = 41;
        break L10;
       }
       $71 = $68&65535;
       HEAP16[$20>>1] = $71;
       $72 = (($22) + 3|0);
       HEAP32[$frm_nxt>>2] = $72;
       break;
      }
      $73 = ($21&255)<(245);
      if (!($73)) {
       $$0 = 2;
       label = 41;
       break L10;
      }
      $74 = $22;
      $75 = (($17) - ($74))|0;
      $76 = ($75|0)<(4);
      if ($76) {
       $$0 = 1;
       label = 41;
       break L10;
      }
      $77 = (($22) + 1|0);
      $78 = HEAP8[$77>>0]|0;
      $79 = (($22) + 2|0);
      $80 = HEAP8[$79>>0]|0;
      $81 = (($22) + 3|0);
      $82 = HEAP8[$81>>0]|0;
      if ((($23|0) == 240)) {
       $$off = (($78) + 112)<<24>>24;
       $83 = ($$off&255)<(48);
       if (!($83)) {
        $$0 = 2;
        label = 41;
        break L10;
       }
      } else if ((($23|0) == 244)) {
       $84 = $78 & -16;
       $85 = ($84<<24>>24)==(-128);
       if (!($85)) {
        $$0 = 2;
        label = 41;
        break L10;
       }
      } else {
       $86 = $78 & -64;
       $87 = ($86<<24>>24)==(-128);
       if (!($87)) {
        $$0 = 2;
        label = 41;
        break L10;
       }
      }
      $88 = $80&255;
      $89 = $88 & 192;
      $90 = ($89|0)==(128);
      if (!($90)) {
       $$0 = 2;
       label = 41;
       break L10;
      }
      $91 = $82&255;
      $92 = $91 & 192;
      $93 = ($92|0)==(128);
      if (!($93)) {
       $$0 = 2;
       label = 41;
       break L10;
      }
      $94 = $20;
      $95 = (($18) - ($94))|0;
      $96 = ($95|0)<(4);
      if ($96) {
       $$0 = 1;
       label = 41;
       break L10;
      }
      $97 = $23 & 7;
      $98 = $97 << 18;
      $99 = $78&255;
      $100 = $99 << 12;
      $101 = $100 & 258048;
      $102 = $101 | $98;
      $103 = $88 << 6;
      $104 = $103 & 4032;
      $105 = $102 | $104;
      $106 = $91 & 63;
      $107 = $105 | $106;
      $108 = ($107>>>0)>($Maxcode>>>0);
      if ($108) {
       $$0 = 2;
       label = 41;
       break L10;
      }
      $109 = $97 << 2;
      $110 = $99 >>> 4;
      $111 = $110 & 3;
      $112 = $111 | $109;
      $113 = $112 << 6;
      $114 = (($113) + 16320)|0;
      $115 = $99 << 2;
      $116 = $115 & 60;
      $117 = $88 >>> 4;
      $118 = $117 & 3;
      $119 = $116 | $118;
      $120 = $119 | $114;
      $121 = $120 | 55296;
      $122 = $121&65535;
      HEAP16[$20>>1] = $122;
      $123 = $103 & 960;
      $124 = $106 | $123;
      $125 = $124 | 56320;
      $126 = $125&65535;
      $127 = (($20) + 2|0);
      HEAP32[$to_nxt>>2] = $127;
      HEAP16[$127>>1] = $126;
      $128 = HEAP32[$frm_nxt>>2]|0;
      $129 = (($128) + 4|0);
      HEAP32[$frm_nxt>>2] = $129;
     }
    } while(0);
    $130 = HEAP32[$to_nxt>>2]|0;
    $131 = (($130) + 2|0);
    HEAP32[$to_nxt>>2] = $131;
    $132 = HEAP32[$frm_nxt>>2]|0;
    $133 = ($132>>>0)<($frm_end>>>0);
    if ($133) {
     $20 = $131;$22 = $132;
    } else {
     $135 = $132;
     break L8;
    }
   }
   if ((label|0) == 41) {
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $135 = $16;
  }
 } while(0);
 $134 = ($135>>>0)<($frm_end>>>0);
 $136 = $134&1;
 $$0 = $136;
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_($this,$0,$to,$1,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $to = $to|0;
 $1 = $1|0;
 $to_nxt = $to_nxt|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$to_nxt>>2] = $to;
 STACKTOP = sp;return 3;
}
function __ZNKSt3__17codecvtIDsc11__mbstate_tE11do_encodingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__17codecvtIDsc11__mbstate_tE16do_always_noconvEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__17codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_j($this,$0,$frm,$frm_end,$mx) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $mx = $mx|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__1L20utf8_to_utf16_lengthEPKhS1_jmNS_12codecvt_modeE($frm,$frm_end,$mx,1114111,0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__1L20utf8_to_utf16_lengthEPKhS1_jmNS_12codecvt_modeE($frm,$frm_end,$mx,$Maxcode,$mode) {
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $mx = $mx|0;
 $Maxcode = $Maxcode|0;
 $mode = $mode|0;
 var $$0 = 0, $$frm = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $frm_nxt$1$lcssa = 0, $frm_nxt$1$ph = 0, $frm_nxt$115 = 0, $frm_nxt$2 = 0, $nchar16_t$014 = 0, $nchar16_t$1 = 0, $or$cond = 0, $or$cond13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $mode & 4;
 $1 = ($0|0)==(0);
 if ($1) {
  $frm_nxt$1$ph = $frm;
 } else {
  $2 = $frm_end;
  $3 = $frm;
  $4 = (($2) - ($3))|0;
  $5 = ($4|0)>(2);
  if ($5) {
   $6 = HEAP8[$frm>>0]|0;
   $7 = ($6<<24>>24)==(-17);
   if ($7) {
    $8 = (($frm) + 1|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(-69);
    if ($10) {
     $11 = (($frm) + 2|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($12<<24>>24)==(-65);
     $14 = (($frm) + 3|0);
     $$frm = $13 ? $14 : $frm;
     $frm_nxt$1$ph = $$frm;
    } else {
     $frm_nxt$1$ph = $frm;
    }
   } else {
    $frm_nxt$1$ph = $frm;
   }
  } else {
   $frm_nxt$1$ph = $frm;
  }
 }
 $15 = ($frm_nxt$1$ph>>>0)<($frm_end>>>0);
 $16 = ($mx|0)!=(0);
 $or$cond13 = $15 & $16;
 L7: do {
  if ($or$cond13) {
   $17 = $frm_end;
   $frm_nxt$115 = $frm_nxt$1$ph;$nchar16_t$014 = 0;
   L9: while(1) {
    $18 = HEAP8[$frm_nxt$115>>0]|0;
    $19 = $18&255;
    $20 = ($19>>>0)>($Maxcode>>>0);
    if ($20) {
     $frm_nxt$1$lcssa = $frm_nxt$115;
     break L7;
    }
    $21 = ($18<<24>>24)>(-1);
    do {
     if ($21) {
      $22 = (($frm_nxt$115) + 1|0);
      $frm_nxt$2 = $22;$nchar16_t$1 = $nchar16_t$014;
     } else {
      $23 = ($18&255)<(194);
      if ($23) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $24 = ($18&255)<(224);
      if ($24) {
       $25 = $frm_nxt$115;
       $26 = (($17) - ($25))|0;
       $27 = ($26|0)<(2);
       if ($27) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $28 = (($frm_nxt$115) + 1|0);
       $29 = HEAP8[$28>>0]|0;
       $30 = $29&255;
       $31 = $30 & 192;
       $32 = ($31|0)==(128);
       if (!($32)) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $33 = $19 << 6;
       $34 = $33 & 1984;
       $35 = $30 & 63;
       $36 = $35 | $34;
       $37 = ($36>>>0)>($Maxcode>>>0);
       if ($37) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $38 = (($frm_nxt$115) + 2|0);
       $frm_nxt$2 = $38;$nchar16_t$1 = $nchar16_t$014;
       break;
      }
      $39 = ($18&255)<(240);
      if ($39) {
       $40 = $frm_nxt$115;
       $41 = (($17) - ($40))|0;
       $42 = ($41|0)<(3);
       if ($42) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $43 = (($frm_nxt$115) + 1|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = (($frm_nxt$115) + 2|0);
       $46 = HEAP8[$45>>0]|0;
       if ((($19|0) == 224)) {
        $47 = $44 & -32;
        $48 = ($47<<24>>24)==(-96);
        if (!($48)) {
         label = 21;
         break L9;
        }
       } else if ((($19|0) == 237)) {
        $51 = $44 & -32;
        $52 = ($51<<24>>24)==(-128);
        if (!($52)) {
         label = 23;
         break L9;
        }
       } else {
        $55 = $44 & -64;
        $56 = ($55<<24>>24)==(-128);
        if (!($56)) {
         label = 25;
         break L9;
        }
       }
       $59 = $46&255;
       $60 = $59 & 192;
       $61 = ($60|0)==(128);
       if (!($61)) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $62 = $19 << 12;
       $63 = $62 & 61440;
       $64 = $44&255;
       $65 = $64 << 6;
       $66 = $65 & 4032;
       $67 = $66 | $63;
       $68 = $59 & 63;
       $69 = $67 | $68;
       $70 = ($69>>>0)>($Maxcode>>>0);
       if ($70) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $71 = (($frm_nxt$115) + 3|0);
       $frm_nxt$2 = $71;$nchar16_t$1 = $nchar16_t$014;
       break;
      }
      $72 = ($18&255)<(245);
      if (!($72)) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $73 = $frm_nxt$115;
      $74 = (($17) - ($73))|0;
      $75 = ($74|0)<(4);
      if ($75) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $76 = (($mx) - ($nchar16_t$014))|0;
      $77 = ($76>>>0)<(2);
      if ($77) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $78 = (($frm_nxt$115) + 1|0);
      $79 = HEAP8[$78>>0]|0;
      $80 = (($frm_nxt$115) + 2|0);
      $81 = HEAP8[$80>>0]|0;
      $82 = (($frm_nxt$115) + 3|0);
      $83 = HEAP8[$82>>0]|0;
      if ((($19|0) == 240)) {
       $$off = (($79) + 112)<<24>>24;
       $84 = ($$off&255)<(48);
       if (!($84)) {
        label = 34;
        break L9;
       }
      } else if ((($19|0) == 244)) {
       $87 = $79 & -16;
       $88 = ($87<<24>>24)==(-128);
       if (!($88)) {
        label = 36;
        break L9;
       }
      } else {
       $91 = $79 & -64;
       $92 = ($91<<24>>24)==(-128);
       if (!($92)) {
        label = 38;
        break L9;
       }
      }
      $95 = $81&255;
      $96 = $95 & 192;
      $97 = ($96|0)==(128);
      if (!($97)) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $98 = $83&255;
      $99 = $98 & 192;
      $100 = ($99|0)==(128);
      if (!($100)) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $101 = $19 << 18;
      $102 = $101 & 1835008;
      $103 = $79&255;
      $104 = $103 << 12;
      $105 = $104 & 258048;
      $106 = $105 | $102;
      $107 = $95 << 6;
      $108 = $107 & 4032;
      $109 = $106 | $108;
      $110 = $98 & 63;
      $111 = $109 | $110;
      $112 = ($111>>>0)>($Maxcode>>>0);
      if ($112) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $113 = (($nchar16_t$014) + 1)|0;
      $114 = (($frm_nxt$115) + 4|0);
      $frm_nxt$2 = $114;$nchar16_t$1 = $113;
     }
    } while(0);
    $115 = (($nchar16_t$1) + 1)|0;
    $116 = ($frm_nxt$2>>>0)<($frm_end>>>0);
    $117 = ($115>>>0)<($mx>>>0);
    $or$cond = $116 & $117;
    if ($or$cond) {
     $frm_nxt$115 = $frm_nxt$2;$nchar16_t$014 = $115;
    } else {
     $frm_nxt$1$lcssa = $frm_nxt$2;
     break L7;
    }
   }
   if ((label|0) == 21) {
    $49 = $frm;
    $50 = (($40) - ($49))|0;
    $$0 = $50;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 23) {
    $53 = $frm;
    $54 = (($40) - ($53))|0;
    $$0 = $54;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 25) {
    $57 = $frm;
    $58 = (($40) - ($57))|0;
    $$0 = $58;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 34) {
    $85 = $frm;
    $86 = (($73) - ($85))|0;
    $$0 = $86;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 36) {
    $89 = $frm;
    $90 = (($73) - ($89))|0;
    $$0 = $90;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 38) {
    $93 = $frm;
    $94 = (($73) - ($93))|0;
    $$0 = $94;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $frm_nxt$1$lcssa = $frm_nxt$1$ph;
  }
 } while(0);
 $118 = $frm_nxt$1$lcssa;
 $119 = $frm;
 $120 = (($118) - ($119))|0;
 $$0 = $120;
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17codecvtIDsc11__mbstate_tE13do_max_lengthEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 4;
}
function __ZNSt3__17codecvtIDic11__mbstate_tED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNKSt3__17codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_($this,$0,$frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_frm_nxt = 0, $_to_nxt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_frm_nxt = sp + 4|0;
 $_to_nxt = sp;
 HEAP32[$_frm_nxt>>2] = $frm;
 HEAP32[$_to_nxt>>2] = $to;
 $1 = (__ZNSt3__1L12ucs4_to_utf8EPKjS1_RS1_PhS3_RS3_mNS_12codecvt_modeE($frm,$frm_end,$_frm_nxt,$to,$to_end,$_to_nxt,1114111,0)|0);
 $2 = HEAP32[$_frm_nxt>>2]|0;
 $3 = $2;
 $4 = $frm;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 $7 = (($frm) + ($6<<2)|0);
 HEAP32[$frm_nxt>>2] = $7;
 $8 = HEAP32[$_to_nxt>>2]|0;
 $9 = $8;
 $10 = $to;
 $11 = (($9) - ($10))|0;
 $12 = (($to) + ($11)|0);
 HEAP32[$to_nxt>>2] = $12;
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__1L12ucs4_to_utf8EPKjS1_RS1_PhS3_RS3_mNS_12codecvt_modeE($frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt,$Maxcode,$mode) {
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 $Maxcode = $Maxcode|0;
 $mode = $mode|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$frm_nxt>>2] = $frm;
 HEAP32[$to_nxt>>2] = $to;
 $0 = $mode & 2;
 $1 = ($0|0)==(0);
 do {
  if (!($1)) {
   $2 = $to_end;
   $3 = $to;
   $4 = (($2) - ($3))|0;
   $5 = ($4|0)<(3);
   if ($5) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else {
    $6 = (($to) + 1|0);
    HEAP32[$to_nxt>>2] = $6;
    HEAP8[$to>>0] = -17;
    $7 = HEAP32[$to_nxt>>2]|0;
    $8 = (($7) + 1|0);
    HEAP32[$to_nxt>>2] = $8;
    HEAP8[$7>>0] = -69;
    $9 = HEAP32[$to_nxt>>2]|0;
    $10 = (($9) + 1|0);
    HEAP32[$to_nxt>>2] = $10;
    HEAP8[$9>>0] = -65;
    break;
   }
  }
 } while(0);
 $11 = HEAP32[$frm_nxt>>2]|0;
 $12 = ($11>>>0)<($frm_end>>>0);
 if (!($12)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = $to_end;
 $15 = $11;
 L10: while(1) {
  $14 = HEAP32[$15>>2]|0;
  $16 = $14 & -2048;
  $17 = ($16|0)==(55296);
  $18 = ($14>>>0)>($Maxcode>>>0);
  $or$cond = $17 | $18;
  if ($or$cond) {
   $$0 = 2;
   label = 19;
   break;
  }
  $19 = ($14>>>0)<(128);
  do {
   if ($19) {
    $20 = HEAP32[$to_nxt>>2]|0;
    $21 = $20;
    $22 = (($13) - ($21))|0;
    $23 = ($22|0)<(1);
    if ($23) {
     $$0 = 1;
     label = 19;
     break L10;
    }
    $24 = $14&255;
    $25 = (($20) + 1|0);
    HEAP32[$to_nxt>>2] = $25;
    HEAP8[$20>>0] = $24;
   } else {
    $26 = ($14>>>0)<(2048);
    if ($26) {
     $27 = HEAP32[$to_nxt>>2]|0;
     $28 = $27;
     $29 = (($13) - ($28))|0;
     $30 = ($29|0)<(2);
     if ($30) {
      $$0 = 1;
      label = 19;
      break L10;
     }
     $31 = $14 >>> 6;
     $32 = $31 | 192;
     $33 = $32&255;
     $34 = (($27) + 1|0);
     HEAP32[$to_nxt>>2] = $34;
     HEAP8[$27>>0] = $33;
     $35 = $14 & 63;
     $36 = $35 | 128;
     $37 = $36&255;
     $38 = HEAP32[$to_nxt>>2]|0;
     $39 = (($38) + 1|0);
     HEAP32[$to_nxt>>2] = $39;
     HEAP8[$38>>0] = $37;
     break;
    }
    $40 = ($14>>>0)<(65536);
    $41 = HEAP32[$to_nxt>>2]|0;
    $42 = $41;
    $43 = (($13) - ($42))|0;
    if ($40) {
     $44 = ($43|0)<(3);
     if ($44) {
      $$0 = 1;
      label = 19;
      break L10;
     }
     $45 = $14 >>> 12;
     $46 = $45 | 224;
     $47 = $46&255;
     $48 = (($41) + 1|0);
     HEAP32[$to_nxt>>2] = $48;
     HEAP8[$41>>0] = $47;
     $49 = $14 >>> 6;
     $50 = $49 & 63;
     $51 = $50 | 128;
     $52 = $51&255;
     $53 = HEAP32[$to_nxt>>2]|0;
     $54 = (($53) + 1|0);
     HEAP32[$to_nxt>>2] = $54;
     HEAP8[$53>>0] = $52;
     $55 = $14 & 63;
     $56 = $55 | 128;
     $57 = $56&255;
     $58 = HEAP32[$to_nxt>>2]|0;
     $59 = (($58) + 1|0);
     HEAP32[$to_nxt>>2] = $59;
     HEAP8[$58>>0] = $57;
     break;
    } else {
     $60 = ($43|0)<(4);
     if ($60) {
      $$0 = 1;
      label = 19;
      break L10;
     }
     $61 = $14 >>> 18;
     $62 = $61 | 240;
     $63 = $62&255;
     $64 = (($41) + 1|0);
     HEAP32[$to_nxt>>2] = $64;
     HEAP8[$41>>0] = $63;
     $65 = $14 >>> 12;
     $66 = $65 & 63;
     $67 = $66 | 128;
     $68 = $67&255;
     $69 = HEAP32[$to_nxt>>2]|0;
     $70 = (($69) + 1|0);
     HEAP32[$to_nxt>>2] = $70;
     HEAP8[$69>>0] = $68;
     $71 = $14 >>> 6;
     $72 = $71 & 63;
     $73 = $72 | 128;
     $74 = $73&255;
     $75 = HEAP32[$to_nxt>>2]|0;
     $76 = (($75) + 1|0);
     HEAP32[$to_nxt>>2] = $76;
     HEAP8[$75>>0] = $74;
     $77 = $14 & 63;
     $78 = $77 | 128;
     $79 = $78&255;
     $80 = HEAP32[$to_nxt>>2]|0;
     $81 = (($80) + 1|0);
     HEAP32[$to_nxt>>2] = $81;
     HEAP8[$80>>0] = $79;
     break;
    }
   }
  } while(0);
  $82 = HEAP32[$frm_nxt>>2]|0;
  $83 = (($82) + 4|0);
  HEAP32[$frm_nxt>>2] = $83;
  $84 = ($83>>>0)<($frm_end>>>0);
  if ($84) {
   $15 = $83;
  } else {
   $$0 = 0;
   label = 19;
   break;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNKSt3__17codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_($this,$0,$frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $_frm_nxt = 0, $_to_nxt = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $_frm_nxt = sp + 4|0;
 $_to_nxt = sp;
 HEAP32[$_frm_nxt>>2] = $frm;
 HEAP32[$_to_nxt>>2] = $to;
 $1 = (__ZNSt3__1L12utf8_to_ucs4EPKhS1_RS1_PjS3_RS3_mNS_12codecvt_modeE($frm,$frm_end,$_frm_nxt,$to,$to_end,$_to_nxt,1114111,0)|0);
 $2 = HEAP32[$_frm_nxt>>2]|0;
 $3 = $2;
 $4 = $frm;
 $5 = (($3) - ($4))|0;
 $6 = (($frm) + ($5)|0);
 HEAP32[$frm_nxt>>2] = $6;
 $7 = HEAP32[$_to_nxt>>2]|0;
 $8 = $7;
 $9 = $to;
 $10 = (($8) - ($9))|0;
 $11 = $10 >> 2;
 $12 = (($to) + ($11<<2)|0);
 HEAP32[$to_nxt>>2] = $12;
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__1L12utf8_to_ucs4EPKhS1_RS1_PjS3_RS3_mNS_12codecvt_modeE($frm,$frm_end,$frm_nxt,$to,$to_end,$to_nxt,$Maxcode,$mode) {
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $frm_nxt = $frm_nxt|0;
 $to = $to|0;
 $to_end = $to_end|0;
 $to_nxt = $to_nxt|0;
 $Maxcode = $Maxcode|0;
 $mode = $mode|0;
 var $$0 = 0, $$off = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$frm_nxt>>2] = $frm;
 HEAP32[$to_nxt>>2] = $to;
 $0 = $mode & 4;
 $1 = ($0|0)==(0);
 $$pre5 = HEAP32[$frm_nxt>>2]|0;
 if ($1) {
  $16 = $$pre5;
 } else {
  $2 = $frm_end;
  $3 = $$pre5;
  $4 = (($2) - ($3))|0;
  $5 = ($4|0)>(2);
  if ($5) {
   $6 = HEAP8[$$pre5>>0]|0;
   $7 = ($6<<24>>24)==(-17);
   if ($7) {
    $8 = (($$pre5) + 1|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(-69);
    if ($10) {
     $11 = (($$pre5) + 2|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($12<<24>>24)==(-65);
     if ($13) {
      $14 = (($$pre5) + 3|0);
      HEAP32[$frm_nxt>>2] = $14;
      $16 = $14;
     } else {
      $16 = $$pre5;
     }
    } else {
     $16 = $$pre5;
    }
   } else {
    $16 = $$pre5;
   }
  } else {
   $16 = $$pre5;
  }
 }
 $15 = ($16>>>0)<($frm_end>>>0);
 L8: do {
  if ($15) {
   $17 = $frm_end;
   $$pre = HEAP32[$to_nxt>>2]|0;
   $19 = $$pre;$21 = $16;
   while(1) {
    $18 = ($19>>>0)<($to_end>>>0);
    if (!($18)) {
     $108 = $21;
     label = 39;
     break L8;
    }
    $20 = HEAP8[$21>>0]|0;
    $22 = $20&255;
    $23 = ($20<<24>>24)>(-1);
    do {
     if ($23) {
      $24 = ($22>>>0)>($Maxcode>>>0);
      if ($24) {
       $$0 = 2;
       break L8;
      }
      HEAP32[$19>>2] = $22;
      $25 = (($21) + 1|0);
      HEAP32[$frm_nxt>>2] = $25;
     } else {
      $26 = ($20&255)<(194);
      if ($26) {
       $$0 = 2;
       break L8;
      }
      $27 = ($20&255)<(224);
      if ($27) {
       $28 = $21;
       $29 = (($17) - ($28))|0;
       $30 = ($29|0)<(2);
       if ($30) {
        $$0 = 1;
        break L8;
       }
       $31 = (($21) + 1|0);
       $32 = HEAP8[$31>>0]|0;
       $33 = $32&255;
       $34 = $33 & 192;
       $35 = ($34|0)==(128);
       if (!($35)) {
        $$0 = 2;
        break L8;
       }
       $36 = $22 << 6;
       $37 = $36 & 1984;
       $38 = $33 & 63;
       $39 = $38 | $37;
       $40 = ($39>>>0)>($Maxcode>>>0);
       if ($40) {
        $$0 = 2;
        break L8;
       }
       HEAP32[$19>>2] = $39;
       $41 = (($21) + 2|0);
       HEAP32[$frm_nxt>>2] = $41;
       break;
      }
      $42 = ($20&255)<(240);
      if ($42) {
       $43 = $21;
       $44 = (($17) - ($43))|0;
       $45 = ($44|0)<(3);
       if ($45) {
        $$0 = 1;
        break L8;
       }
       $46 = (($21) + 1|0);
       $47 = HEAP8[$46>>0]|0;
       $48 = (($21) + 2|0);
       $49 = HEAP8[$48>>0]|0;
       if ((($22|0) == 224)) {
        $50 = $47 & -32;
        $51 = ($50<<24>>24)==(-96);
        if (!($51)) {
         $$0 = 2;
         break L8;
        }
       } else if ((($22|0) == 237)) {
        $52 = $47 & -32;
        $53 = ($52<<24>>24)==(-128);
        if (!($53)) {
         $$0 = 2;
         break L8;
        }
       } else {
        $54 = $47 & -64;
        $55 = ($54<<24>>24)==(-128);
        if (!($55)) {
         $$0 = 2;
         break L8;
        }
       }
       $56 = $49&255;
       $57 = $56 & 192;
       $58 = ($57|0)==(128);
       if (!($58)) {
        $$0 = 2;
        break L8;
       }
       $59 = $22 << 12;
       $60 = $59 & 61440;
       $61 = $47&255;
       $62 = $61 << 6;
       $63 = $62 & 4032;
       $64 = $63 | $60;
       $65 = $56 & 63;
       $66 = $64 | $65;
       $67 = ($66>>>0)>($Maxcode>>>0);
       if ($67) {
        $$0 = 2;
        break L8;
       }
       HEAP32[$19>>2] = $66;
       $68 = (($21) + 3|0);
       HEAP32[$frm_nxt>>2] = $68;
       break;
      }
      $69 = ($20&255)<(245);
      if (!($69)) {
       $$0 = 2;
       break L8;
      }
      $70 = $21;
      $71 = (($17) - ($70))|0;
      $72 = ($71|0)<(4);
      if ($72) {
       $$0 = 1;
       break L8;
      }
      $73 = (($21) + 1|0);
      $74 = HEAP8[$73>>0]|0;
      $75 = (($21) + 2|0);
      $76 = HEAP8[$75>>0]|0;
      $77 = (($21) + 3|0);
      $78 = HEAP8[$77>>0]|0;
      if ((($22|0) == 244)) {
       $80 = $74 & -16;
       $81 = ($80<<24>>24)==(-128);
       if (!($81)) {
        $$0 = 2;
        break L8;
       }
      } else if ((($22|0) == 240)) {
       $$off = (($74) + 112)<<24>>24;
       $79 = ($$off&255)<(48);
       if (!($79)) {
        $$0 = 2;
        break L8;
       }
      } else {
       $82 = $74 & -64;
       $83 = ($82<<24>>24)==(-128);
       if (!($83)) {
        $$0 = 2;
        break L8;
       }
      }
      $84 = $76&255;
      $85 = $84 & 192;
      $86 = ($85|0)==(128);
      if (!($86)) {
       $$0 = 2;
       break L8;
      }
      $87 = $78&255;
      $88 = $87 & 192;
      $89 = ($88|0)==(128);
      if (!($89)) {
       $$0 = 2;
       break L8;
      }
      $90 = $22 << 18;
      $91 = $90 & 1835008;
      $92 = $74&255;
      $93 = $92 << 12;
      $94 = $93 & 258048;
      $95 = $94 | $91;
      $96 = $84 << 6;
      $97 = $96 & 4032;
      $98 = $95 | $97;
      $99 = $87 & 63;
      $100 = $98 | $99;
      $101 = ($100>>>0)>($Maxcode>>>0);
      if ($101) {
       $$0 = 2;
       break L8;
      }
      HEAP32[$19>>2] = $100;
      $102 = (($21) + 4|0);
      HEAP32[$frm_nxt>>2] = $102;
     }
    } while(0);
    $103 = HEAP32[$to_nxt>>2]|0;
    $104 = (($103) + 4|0);
    HEAP32[$to_nxt>>2] = $104;
    $105 = HEAP32[$frm_nxt>>2]|0;
    $106 = ($105>>>0)<($frm_end>>>0);
    if ($106) {
     $19 = $104;$21 = $105;
    } else {
     $108 = $105;
     label = 39;
     break;
    }
   }
  } else {
   $108 = $16;
   label = 39;
  }
 } while(0);
 if ((label|0) == 39) {
  $107 = ($108>>>0)<($frm_end>>>0);
  $109 = $107&1;
  $$0 = $109;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_($this,$0,$to,$1,$to_nxt) {
 $this = $this|0;
 $0 = $0|0;
 $to = $to|0;
 $1 = $1|0;
 $to_nxt = $to_nxt|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$to_nxt>>2] = $to;
 STACKTOP = sp;return 3;
}
function __ZNKSt3__17codecvtIDic11__mbstate_tE11do_encodingEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__17codecvtIDic11__mbstate_tE16do_always_noconvEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNKSt3__17codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_j($this,$0,$frm,$frm_end,$mx) {
 $this = $this|0;
 $0 = $0|0;
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $mx = $mx|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__ZNSt3__1L19utf8_to_ucs4_lengthEPKhS1_jmNS_12codecvt_modeE($frm,$frm_end,$mx,1114111,0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNSt3__1L19utf8_to_ucs4_lengthEPKhS1_jmNS_12codecvt_modeE($frm,$frm_end,$mx,$Maxcode,$mode) {
 $frm = $frm|0;
 $frm_end = $frm_end|0;
 $mx = $mx|0;
 $Maxcode = $Maxcode|0;
 $mode = $mode|0;
 var $$0 = 0, $$frm = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $frm_nxt$1$lcssa = 0, $frm_nxt$1$ph = 0, $frm_nxt$115 = 0, $frm_nxt$2 = 0, $nchar32_t$014 = 0, $or$cond = 0, $or$cond13 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $mode & 4;
 $1 = ($0|0)==(0);
 if ($1) {
  $frm_nxt$1$ph = $frm;
 } else {
  $2 = $frm_end;
  $3 = $frm;
  $4 = (($2) - ($3))|0;
  $5 = ($4|0)>(2);
  if ($5) {
   $6 = HEAP8[$frm>>0]|0;
   $7 = ($6<<24>>24)==(-17);
   if ($7) {
    $8 = (($frm) + 1|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(-69);
    if ($10) {
     $11 = (($frm) + 2|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = ($12<<24>>24)==(-65);
     $14 = (($frm) + 3|0);
     $$frm = $13 ? $14 : $frm;
     $frm_nxt$1$ph = $$frm;
    } else {
     $frm_nxt$1$ph = $frm;
    }
   } else {
    $frm_nxt$1$ph = $frm;
   }
  } else {
   $frm_nxt$1$ph = $frm;
  }
 }
 $15 = ($frm_nxt$1$ph>>>0)<($frm_end>>>0);
 $16 = ($mx|0)!=(0);
 $or$cond13 = $15 & $16;
 L7: do {
  if ($or$cond13) {
   $17 = $frm_end;
   $frm_nxt$115 = $frm_nxt$1$ph;$nchar32_t$014 = 1;
   L9: while(1) {
    $18 = HEAP8[$frm_nxt$115>>0]|0;
    $19 = $18&255;
    $20 = ($18<<24>>24)>(-1);
    do {
     if ($20) {
      $21 = ($19>>>0)>($Maxcode>>>0);
      if ($21) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $22 = (($frm_nxt$115) + 1|0);
      $frm_nxt$2 = $22;
     } else {
      $23 = ($18&255)<(194);
      if ($23) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $24 = ($18&255)<(224);
      if ($24) {
       $25 = $frm_nxt$115;
       $26 = (($17) - ($25))|0;
       $27 = ($26|0)<(2);
       if ($27) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $28 = (($frm_nxt$115) + 1|0);
       $29 = HEAP8[$28>>0]|0;
       $30 = $29&255;
       $31 = $30 & 192;
       $32 = ($31|0)==(128);
       if (!($32)) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $33 = $19 << 6;
       $34 = $33 & 1984;
       $35 = $30 & 63;
       $36 = $35 | $34;
       $37 = ($36>>>0)>($Maxcode>>>0);
       if ($37) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $38 = (($frm_nxt$115) + 2|0);
       $frm_nxt$2 = $38;
       break;
      }
      $39 = ($18&255)<(240);
      if ($39) {
       $40 = $frm_nxt$115;
       $41 = (($17) - ($40))|0;
       $42 = ($41|0)<(3);
       if ($42) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $43 = (($frm_nxt$115) + 1|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = (($frm_nxt$115) + 2|0);
       $46 = HEAP8[$45>>0]|0;
       if ((($19|0) == 224)) {
        $47 = $44 & -32;
        $48 = ($47<<24>>24)==(-96);
        if (!($48)) {
         label = 21;
         break L9;
        }
       } else if ((($19|0) == 237)) {
        $51 = $44 & -32;
        $52 = ($51<<24>>24)==(-128);
        if (!($52)) {
         label = 23;
         break L9;
        }
       } else {
        $55 = $44 & -64;
        $56 = ($55<<24>>24)==(-128);
        if (!($56)) {
         label = 25;
         break L9;
        }
       }
       $59 = $46&255;
       $60 = $59 & 192;
       $61 = ($60|0)==(128);
       if (!($61)) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $62 = $19 << 12;
       $63 = $62 & 61440;
       $64 = $44&255;
       $65 = $64 << 6;
       $66 = $65 & 4032;
       $67 = $66 | $63;
       $68 = $59 & 63;
       $69 = $67 | $68;
       $70 = ($69>>>0)>($Maxcode>>>0);
       if ($70) {
        $frm_nxt$1$lcssa = $frm_nxt$115;
        break L7;
       }
       $71 = (($frm_nxt$115) + 3|0);
       $frm_nxt$2 = $71;
       break;
      }
      $72 = ($18&255)<(245);
      if (!($72)) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $73 = $frm_nxt$115;
      $74 = (($17) - ($73))|0;
      $75 = ($74|0)<(4);
      if ($75) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $76 = (($frm_nxt$115) + 1|0);
      $77 = HEAP8[$76>>0]|0;
      $78 = (($frm_nxt$115) + 2|0);
      $79 = HEAP8[$78>>0]|0;
      $80 = (($frm_nxt$115) + 3|0);
      $81 = HEAP8[$80>>0]|0;
      if ((($19|0) == 244)) {
       $85 = $77 & -16;
       $86 = ($85<<24>>24)==(-128);
       if (!($86)) {
        label = 35;
        break L9;
       }
      } else if ((($19|0) == 240)) {
       $$off = (($77) + 112)<<24>>24;
       $82 = ($$off&255)<(48);
       if (!($82)) {
        label = 33;
        break L9;
       }
      } else {
       $89 = $77 & -64;
       $90 = ($89<<24>>24)==(-128);
       if (!($90)) {
        label = 37;
        break L9;
       }
      }
      $93 = $79&255;
      $94 = $93 & 192;
      $95 = ($94|0)==(128);
      if (!($95)) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $96 = $81&255;
      $97 = $96 & 192;
      $98 = ($97|0)==(128);
      if (!($98)) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $99 = $19 << 18;
      $100 = $99 & 1835008;
      $101 = $77&255;
      $102 = $101 << 12;
      $103 = $102 & 258048;
      $104 = $103 | $100;
      $105 = $93 << 6;
      $106 = $105 & 4032;
      $107 = $104 | $106;
      $108 = $96 & 63;
      $109 = $107 | $108;
      $110 = ($109>>>0)>($Maxcode>>>0);
      if ($110) {
       $frm_nxt$1$lcssa = $frm_nxt$115;
       break L7;
      }
      $111 = (($frm_nxt$115) + 4|0);
      $frm_nxt$2 = $111;
     }
    } while(0);
    $112 = ($frm_nxt$2>>>0)<($frm_end>>>0);
    $113 = ($nchar32_t$014>>>0)<($mx>>>0);
    $or$cond = $112 & $113;
    if (!($or$cond)) {
     $frm_nxt$1$lcssa = $frm_nxt$2;
     break L7;
    }
    $phitmp = (($nchar32_t$014) + 1)|0;
    $frm_nxt$115 = $frm_nxt$2;$nchar32_t$014 = $phitmp;
   }
   if ((label|0) == 21) {
    $49 = $frm;
    $50 = (($40) - ($49))|0;
    $$0 = $50;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 23) {
    $53 = $frm;
    $54 = (($40) - ($53))|0;
    $$0 = $54;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 25) {
    $57 = $frm;
    $58 = (($40) - ($57))|0;
    $$0 = $58;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 33) {
    $83 = $frm;
    $84 = (($73) - ($83))|0;
    $$0 = $84;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 35) {
    $87 = $frm;
    $88 = (($73) - ($87))|0;
    $$0 = $88;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 37) {
    $91 = $frm;
    $92 = (($73) - ($91))|0;
    $$0 = $92;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $frm_nxt$1$lcssa = $frm_nxt$1$ph;
  }
 } while(0);
 $114 = $frm_nxt$1$lcssa;
 $115 = $frm;
 $116 = (($114) - ($115))|0;
 $$0 = $116;
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__17codecvtIDic11__mbstate_tE13do_max_lengthEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 4;
}
function __ZNSt3__116__narrow_to_utf8ILj32EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__117__widen_from_utf8ILj32EED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18numpunctIcED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__18numpunctIcED2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18numpunctIcED2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3093496 + 8|0));
 $0 = (($this) + 12|0);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0);
 STACKTOP = sp;return;
}
function __ZNSt3__18numpunctIwED0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__18numpunctIwED2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt3__18numpunctIwED2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3093536 + 8|0));
 $0 = (($this) + 16|0);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev($0);
 STACKTOP = sp;return;
}
function __ZNKSt3__18numpunctIcE16do_decimal_pointEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP8[$0>>0]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNKSt3__18numpunctIwE16do_decimal_pointEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNKSt3__18numpunctIcE16do_thousands_sepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 9|0);
 $1 = HEAP8[$0>>0]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNKSt3__18numpunctIwE16do_thousands_sepEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNKSt3__18numpunctIcE11do_groupingEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZNKSt3__18numpunctIwE11do_groupingEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_($agg$result,$0);
 STACKTOP = sp;return;
}
function __ZNKSt3__18numpunctIcE11do_truenameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj($agg$result,3093576,4);
 STACKTOP = sp;return;
}
function __ZNKSt3__18numpunctIwE11do_truenameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_wcslen(3093584)|0);
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj($agg$result,3093584,$0);
 STACKTOP = sp;return;
}
function __ZNKSt3__18numpunctIcE12do_falsenameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj($agg$result,3093608,5);
 STACKTOP = sp;return;
}
function __ZNKSt3__18numpunctIwE12do_falsenameEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_wcslen(3093616)|0);
 __ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj($agg$result,3093616,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__114__num_get_base10__get_baseERNS_8ios_baseE($iob) {
 $iob = $iob|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($iob) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 74;
 if ((($2|0) == 0)) {
  $$0 = 0;
 } else if ((($2|0) == 8)) {
  $$0 = 16;
 } else if ((($2|0) == 64)) {
  $$0 = 8;
 } else {
  $$0 = 10;
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNKSt3__120__time_get_c_storageIcE7__weeksEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093648>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $36 = HEAP32[3093640>>2]|0;
  STACKTOP = sp;return ($36|0);
 }
 $2 = (___cxa_guard_acquire((3093648|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $36 = HEAP32[3093640>>2]|0;
  STACKTOP = sp;return ($36|0);
 }
 $4 = HEAP8[3100848>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (___cxa_guard_acquire((3100848|0))|0);
  $7 = ($6|0)==(0);
  if (!($7)) {
   _memset((3100680|0),0,168)|0;
   ___cxa_guard_release((3100848|0));
  }
 }
 __THREW__ = 0;
 (invoke_iii(2392,(3100680|0),(3100856|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  (invoke_iii(2392,(((3100680 + 12|0))|0),(3100864|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   (invoke_iii(2392,(((3100680 + 24|0))|0),(3100872|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    (invoke_iii(2392,(((3100680 + 36|0))|0),(3100880|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     (invoke_iii(2392,(((3100680 + 48|0))|0),(3100896|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_iii(2392,(((3100680 + 60|0))|0),(3100912|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       (invoke_iii(2392,(((3100680 + 72|0))|0),(3100920|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        (invoke_iii(2392,(((3100680 + 84|0))|0),(3100936|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         __THREW__ = 0;
         (invoke_iii(2392,(((3100680 + 96|0))|0),(3100944|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          (invoke_iii(2392,(((3100680 + 108|0))|0),(3100952|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           (invoke_iii(2392,(((3100680 + 120|0))|0),(3100960|0))|0);
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            __THREW__ = 0;
            (invoke_iii(2392,(((3100680 + 132|0))|0),(3100968|0))|0);
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if (!($31)) {
             __THREW__ = 0;
             (invoke_iii(2392,(((3100680 + 144|0))|0),(3100976|0))|0);
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if (!($33)) {
              __THREW__ = 0;
              (invoke_iii(2392,(((3100680 + 156|0))|0),(3100984|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               HEAP32[3093640>>2] = 3100680;
               ___cxa_guard_release((3093648|0));
               $36 = HEAP32[3093640>>2]|0;
               STACKTOP = sp;return ($36|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 ___cxa_guard_abort((3093648|0));
 ___resumeException($37|0);
 // unreachable;
 return 0|0;
}
function __ZNKSt3__120__time_get_c_storageIwE7__weeksEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093664>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $36 = HEAP32[3093656>>2]|0;
  STACKTOP = sp;return ($36|0);
 }
 $2 = (___cxa_guard_acquire((3093664|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $36 = HEAP32[3093656>>2]|0;
  STACKTOP = sp;return ($36|0);
 }
 $4 = HEAP8[3100312>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (___cxa_guard_acquire((3100312|0))|0);
  $7 = ($6|0)==(0);
  if (!($7)) {
   _memset((3100144|0),0,168)|0;
   ___cxa_guard_release((3100312|0));
  }
 }
 __THREW__ = 0;
 (invoke_iii(2787,(3100144|0),(3100320|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if (!($9)) {
  __THREW__ = 0;
  (invoke_iii(2787,(((3100144 + 12|0))|0),(3100352|0))|0);
  $10 = __THREW__; __THREW__ = 0;
  $11 = $10&1;
  if (!($11)) {
   __THREW__ = 0;
   (invoke_iii(2787,(((3100144 + 24|0))|0),(3100384|0))|0);
   $12 = __THREW__; __THREW__ = 0;
   $13 = $12&1;
   if (!($13)) {
    __THREW__ = 0;
    (invoke_iii(2787,(((3100144 + 36|0))|0),(3100416|0))|0);
    $14 = __THREW__; __THREW__ = 0;
    $15 = $14&1;
    if (!($15)) {
     __THREW__ = 0;
     (invoke_iii(2787,(((3100144 + 48|0))|0),(3100456|0))|0);
     $16 = __THREW__; __THREW__ = 0;
     $17 = $16&1;
     if (!($17)) {
      __THREW__ = 0;
      (invoke_iii(2787,(((3100144 + 60|0))|0),(3100496|0))|0);
      $18 = __THREW__; __THREW__ = 0;
      $19 = $18&1;
      if (!($19)) {
       __THREW__ = 0;
       (invoke_iii(2787,(((3100144 + 72|0))|0),(3100528|0))|0);
       $20 = __THREW__; __THREW__ = 0;
       $21 = $20&1;
       if (!($21)) {
        __THREW__ = 0;
        (invoke_iii(2787,(((3100144 + 84|0))|0),(3100568|0))|0);
        $22 = __THREW__; __THREW__ = 0;
        $23 = $22&1;
        if (!($23)) {
         __THREW__ = 0;
         (invoke_iii(2787,(((3100144 + 96|0))|0),(3100584|0))|0);
         $24 = __THREW__; __THREW__ = 0;
         $25 = $24&1;
         if (!($25)) {
          __THREW__ = 0;
          (invoke_iii(2787,(((3100144 + 108|0))|0),(3100600|0))|0);
          $26 = __THREW__; __THREW__ = 0;
          $27 = $26&1;
          if (!($27)) {
           __THREW__ = 0;
           (invoke_iii(2787,(((3100144 + 120|0))|0),(3100616|0))|0);
           $28 = __THREW__; __THREW__ = 0;
           $29 = $28&1;
           if (!($29)) {
            __THREW__ = 0;
            (invoke_iii(2787,(((3100144 + 132|0))|0),(3100632|0))|0);
            $30 = __THREW__; __THREW__ = 0;
            $31 = $30&1;
            if (!($31)) {
             __THREW__ = 0;
             (invoke_iii(2787,(((3100144 + 144|0))|0),(3100648|0))|0);
             $32 = __THREW__; __THREW__ = 0;
             $33 = $32&1;
             if (!($33)) {
              __THREW__ = 0;
              (invoke_iii(2787,(((3100144 + 156|0))|0),(3100664|0))|0);
              $34 = __THREW__; __THREW__ = 0;
              $35 = $34&1;
              if (!($35)) {
               HEAP32[3093656>>2] = 3100144;
               ___cxa_guard_release((3093664|0));
               $36 = HEAP32[3093656>>2]|0;
               STACKTOP = sp;return ($36|0);
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
 $37 = ___cxa_find_matching_catch()|0;
 $38 = tempRet0;
 ___cxa_guard_abort((3093664|0));
 ___resumeException($37|0);
 // unreachable;
 return 0|0;
}
function __ZNKSt3__120__time_get_c_storageIcE8__monthsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $56 = HEAP32[3093672>>2]|0;
  STACKTOP = sp;return ($56|0);
 }
 $2 = (___cxa_guard_acquire((3093680|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $56 = HEAP32[3093672>>2]|0;
  STACKTOP = sp;return ($56|0);
 }
 $4 = HEAP8[3099920>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (___cxa_guard_acquire((3099920|0))|0);
  $7 = ($6|0)==(0);
  if (!($7)) {
   _memset((3099632|0),0,288)|0;
   ___cxa_guard_release((3099920|0));
  }
 }
 __THREW__ = 0;
 (invoke_iii(2392,(3099632|0),(3099928|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if (!($9)) {
   __THREW__ = 0;
   (invoke_iii(2392,(((3099632 + 12|0))|0),(3099936|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    (invoke_iii(2392,(((3099632 + 24|0))|0),(3099952|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     (invoke_iii(2392,(((3099632 + 36|0))|0),(3099960|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_iii(2392,(((3099632 + 48|0))|0),(3099968|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       (invoke_iii(2392,(((3099632 + 60|0))|0),(3099976|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        (invoke_iii(2392,(((3099632 + 72|0))|0),(3099984|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         (invoke_iii(2392,(((3099632 + 84|0))|0),(3099992|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          __THREW__ = 0;
          (invoke_iii(2392,(((3099632 + 96|0))|0),(3100000|0))|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           __THREW__ = 0;
           (invoke_iii(2392,(((3099632 + 108|0))|0),(3100016|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            (invoke_iii(2392,(((3099632 + 120|0))|0),(3100024|0))|0);
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             __THREW__ = 0;
             (invoke_iii(2392,(((3099632 + 132|0))|0),(3100040|0))|0);
             $30 = __THREW__; __THREW__ = 0;
             $31 = $30&1;
             if (!($31)) {
              __THREW__ = 0;
              (invoke_iii(2392,(((3099632 + 144|0))|0),(3100056|0))|0);
              $32 = __THREW__; __THREW__ = 0;
              $33 = $32&1;
              if (!($33)) {
               __THREW__ = 0;
               (invoke_iii(2392,(((3099632 + 156|0))|0),(3100064|0))|0);
               $34 = __THREW__; __THREW__ = 0;
               $35 = $34&1;
               if (!($35)) {
                __THREW__ = 0;
                (invoke_iii(2392,(((3099632 + 168|0))|0),(3100072|0))|0);
                $36 = __THREW__; __THREW__ = 0;
                $37 = $36&1;
                if (!($37)) {
                 __THREW__ = 0;
                 (invoke_iii(2392,(((3099632 + 180|0))|0),(3100080|0))|0);
                 $38 = __THREW__; __THREW__ = 0;
                 $39 = $38&1;
                 if (!($39)) {
                  __THREW__ = 0;
                  (invoke_iii(2392,(((3099632 + 192|0))|0),(3099968|0))|0);
                  $40 = __THREW__; __THREW__ = 0;
                  $41 = $40&1;
                  if ($41) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2392,(((3099632 + 204|0))|0),(3100088|0))|0);
                  $42 = __THREW__; __THREW__ = 0;
                  $43 = $42&1;
                  if ($43) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2392,(((3099632 + 216|0))|0),(3100096|0))|0);
                  $44 = __THREW__; __THREW__ = 0;
                  $45 = $44&1;
                  if ($45) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2392,(((3099632 + 228|0))|0),(3100104|0))|0);
                  $46 = __THREW__; __THREW__ = 0;
                  $47 = $46&1;
                  if ($47) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2392,(((3099632 + 240|0))|0),(3100112|0))|0);
                  $48 = __THREW__; __THREW__ = 0;
                  $49 = $48&1;
                  if ($49) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2392,(((3099632 + 252|0))|0),(3100120|0))|0);
                  $50 = __THREW__; __THREW__ = 0;
                  $51 = $50&1;
                  if ($51) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2392,(((3099632 + 264|0))|0),(3100128|0))|0);
                  $52 = __THREW__; __THREW__ = 0;
                  $53 = $52&1;
                  if ($53) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2392,(((3099632 + 276|0))|0),(3100136|0))|0);
                  $54 = __THREW__; __THREW__ = 0;
                  $55 = $54&1;
                  if ($55) {
                   break;
                  }
                  HEAP32[3093672>>2] = 3099632;
                  ___cxa_guard_release((3093680|0));
                  $56 = HEAP32[3093672>>2]|0;
                  STACKTOP = sp;return ($56|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $57 = ___cxa_find_matching_catch()|0;
 $58 = tempRet0;
 ___cxa_guard_abort((3093680|0));
 ___resumeException($57|0);
 // unreachable;
 return 0|0;
}
function __ZNKSt3__120__time_get_c_storageIwE8__monthsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093696>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $56 = HEAP32[3093688>>2]|0;
  STACKTOP = sp;return ($56|0);
 }
 $2 = (___cxa_guard_acquire((3093696|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $56 = HEAP32[3093688>>2]|0;
  STACKTOP = sp;return ($56|0);
 }
 $4 = HEAP8[3099080>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (___cxa_guard_acquire((3099080|0))|0);
  $7 = ($6|0)==(0);
  if (!($7)) {
   _memset((3098792|0),0,288)|0;
   ___cxa_guard_release((3099080|0));
  }
 }
 __THREW__ = 0;
 (invoke_iii(2787,(3098792|0),(3099088|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 do {
  if (!($9)) {
   __THREW__ = 0;
   (invoke_iii(2787,(((3098792 + 12|0))|0),(3099120|0))|0);
   $10 = __THREW__; __THREW__ = 0;
   $11 = $10&1;
   if (!($11)) {
    __THREW__ = 0;
    (invoke_iii(2787,(((3098792 + 24|0))|0),(3099160|0))|0);
    $12 = __THREW__; __THREW__ = 0;
    $13 = $12&1;
    if (!($13)) {
     __THREW__ = 0;
     (invoke_iii(2787,(((3098792 + 36|0))|0),(3099184|0))|0);
     $14 = __THREW__; __THREW__ = 0;
     $15 = $14&1;
     if (!($15)) {
      __THREW__ = 0;
      (invoke_iii(2787,(((3098792 + 48|0))|0),(3099504|0))|0);
      $16 = __THREW__; __THREW__ = 0;
      $17 = $16&1;
      if (!($17)) {
       __THREW__ = 0;
       (invoke_iii(2787,(((3098792 + 60|0))|0),(3099208|0))|0);
       $18 = __THREW__; __THREW__ = 0;
       $19 = $18&1;
       if (!($19)) {
        __THREW__ = 0;
        (invoke_iii(2787,(((3098792 + 72|0))|0),(3099232|0))|0);
        $20 = __THREW__; __THREW__ = 0;
        $21 = $20&1;
        if (!($21)) {
         __THREW__ = 0;
         (invoke_iii(2787,(((3098792 + 84|0))|0),(3099256|0))|0);
         $22 = __THREW__; __THREW__ = 0;
         $23 = $22&1;
         if (!($23)) {
          __THREW__ = 0;
          (invoke_iii(2787,(((3098792 + 96|0))|0),(3099288|0))|0);
          $24 = __THREW__; __THREW__ = 0;
          $25 = $24&1;
          if (!($25)) {
           __THREW__ = 0;
           (invoke_iii(2787,(((3098792 + 108|0))|0),(3099328|0))|0);
           $26 = __THREW__; __THREW__ = 0;
           $27 = $26&1;
           if (!($27)) {
            __THREW__ = 0;
            (invoke_iii(2787,(((3098792 + 120|0))|0),(3099360|0))|0);
            $28 = __THREW__; __THREW__ = 0;
            $29 = $28&1;
            if (!($29)) {
             __THREW__ = 0;
             (invoke_iii(2787,(((3098792 + 132|0))|0),(3099400|0))|0);
             $30 = __THREW__; __THREW__ = 0;
             $31 = $30&1;
             if (!($31)) {
              __THREW__ = 0;
              (invoke_iii(2787,(((3098792 + 144|0))|0),(3099440|0))|0);
              $32 = __THREW__; __THREW__ = 0;
              $33 = $32&1;
              if (!($33)) {
               __THREW__ = 0;
               (invoke_iii(2787,(((3098792 + 156|0))|0),(3099456|0))|0);
               $34 = __THREW__; __THREW__ = 0;
               $35 = $34&1;
               if (!($35)) {
                __THREW__ = 0;
                (invoke_iii(2787,(((3098792 + 168|0))|0),(3099472|0))|0);
                $36 = __THREW__; __THREW__ = 0;
                $37 = $36&1;
                if (!($37)) {
                 __THREW__ = 0;
                 (invoke_iii(2787,(((3098792 + 180|0))|0),(3099488|0))|0);
                 $38 = __THREW__; __THREW__ = 0;
                 $39 = $38&1;
                 if (!($39)) {
                  __THREW__ = 0;
                  (invoke_iii(2787,(((3098792 + 192|0))|0),(3099504|0))|0);
                  $40 = __THREW__; __THREW__ = 0;
                  $41 = $40&1;
                  if ($41) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2787,(((3098792 + 204|0))|0),(3099520|0))|0);
                  $42 = __THREW__; __THREW__ = 0;
                  $43 = $42&1;
                  if ($43) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2787,(((3098792 + 216|0))|0),(3099536|0))|0);
                  $44 = __THREW__; __THREW__ = 0;
                  $45 = $44&1;
                  if ($45) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2787,(((3098792 + 228|0))|0),(3099552|0))|0);
                  $46 = __THREW__; __THREW__ = 0;
                  $47 = $46&1;
                  if ($47) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2787,(((3098792 + 240|0))|0),(3099568|0))|0);
                  $48 = __THREW__; __THREW__ = 0;
                  $49 = $48&1;
                  if ($49) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2787,(((3098792 + 252|0))|0),(3099584|0))|0);
                  $50 = __THREW__; __THREW__ = 0;
                  $51 = $50&1;
                  if ($51) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2787,(((3098792 + 264|0))|0),(3099600|0))|0);
                  $52 = __THREW__; __THREW__ = 0;
                  $53 = $52&1;
                  if ($53) {
                   break;
                  }
                  __THREW__ = 0;
                  (invoke_iii(2787,(((3098792 + 276|0))|0),(3099616|0))|0);
                  $54 = __THREW__; __THREW__ = 0;
                  $55 = $54&1;
                  if ($55) {
                   break;
                  }
                  HEAP32[3093688>>2] = 3098792;
                  ___cxa_guard_release((3093696|0));
                  $56 = HEAP32[3093688>>2]|0;
                  STACKTOP = sp;return ($56|0);
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $57 = ___cxa_find_matching_catch()|0;
 $58 = tempRet0;
 ___cxa_guard_abort((3093696|0));
 ___resumeException($57|0);
 // unreachable;
 return 0|0;
}
function __ZNKSt3__120__time_get_c_storageIcE7__am_pmEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093712>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $12 = HEAP32[3093704>>2]|0;
  STACKTOP = sp;return ($12|0);
 }
 $2 = (___cxa_guard_acquire((3093712|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $12 = HEAP32[3093704>>2]|0;
  STACKTOP = sp;return ($12|0);
 }
 $4 = HEAP8[3098768>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (___cxa_guard_acquire((3098768|0))|0);
  $7 = ($6|0)==(0);
  if (!($7)) {
   _memset((3098480|0),0,288)|0;
   ___cxa_guard_release((3098768|0));
  }
 }
 __THREW__ = 0;
 (invoke_iii(2392,(3098480|0),(3098776|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_guard_abort((3093712|0));
  ___resumeException($13|0);
  // unreachable;
 }
 __THREW__ = 0;
 (invoke_iii(2392,(((3098480 + 12|0))|0),(3098784|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_guard_abort((3093712|0));
  ___resumeException($13|0);
  // unreachable;
 }
 HEAP32[3093704>>2] = 3098480;
 ___cxa_guard_release((3093712|0));
 $12 = HEAP32[3093704>>2]|0;
 STACKTOP = sp;return ($12|0);
}
function __ZNKSt3__120__time_get_c_storageIwE7__am_pmEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093728>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $12 = HEAP32[3093720>>2]|0;
  STACKTOP = sp;return ($12|0);
 }
 $2 = (___cxa_guard_acquire((3093728|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $12 = HEAP32[3093720>>2]|0;
  STACKTOP = sp;return ($12|0);
 }
 $4 = HEAP8[3098440>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $6 = (___cxa_guard_acquire((3098440|0))|0);
  $7 = ($6|0)==(0);
  if (!($7)) {
   _memset((3098152|0),0,288)|0;
   ___cxa_guard_release((3098440|0));
  }
 }
 __THREW__ = 0;
 (invoke_iii(2787,(3098152|0),(3098448|0))|0);
 $8 = __THREW__; __THREW__ = 0;
 $9 = $8&1;
 if ($9) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_guard_abort((3093728|0));
  ___resumeException($13|0);
  // unreachable;
 }
 __THREW__ = 0;
 (invoke_iii(2787,(((3098152 + 12|0))|0),(3098464|0))|0);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $13 = ___cxa_find_matching_catch()|0;
  $14 = tempRet0;
  ___cxa_guard_abort((3093728|0));
  ___resumeException($13|0);
  // unreachable;
 }
 HEAP32[3093720>>2] = 3098152;
 ___cxa_guard_release((3093728|0));
 $12 = HEAP32[3093720>>2]|0;
 STACKTOP = sp;return ($12|0);
}
function __ZNKSt3__120__time_get_c_storageIcE3__xEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093752>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (3093736|0);
 }
 $2 = (___cxa_guard_acquire((3093752|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (3093736|0);
 }
 __THREW__ = 0;
 invoke_viii(2132,(3093736|0),(3093760|0),8);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  ___cxa_guard_abort((3093752|0));
  ___resumeException($6|0);
  // unreachable;
 }
 ___cxa_guard_release((3093752|0));
 STACKTOP = sp;return (3093736|0);
}
function __ZNKSt3__120__time_get_c_storageIwE3__xEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093792>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (3093776|0);
 }
 $2 = (___cxa_guard_acquire((3093792|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (3093776|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3484,(3093800|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  invoke_viii(2133,(3093776|0),(3093800|0),($4|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   ___cxa_guard_release((3093792|0));
   STACKTOP = sp;return (3093776|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 ___cxa_guard_abort((3093792|0));
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZNKSt3__120__time_get_c_storageIcE3__XEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093856>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (3093840|0);
 }
 $2 = (___cxa_guard_acquire((3093856|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (3093840|0);
 }
 __THREW__ = 0;
 invoke_viii(2132,(3093840|0),(3093864|0),8);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  ___cxa_guard_abort((3093856|0));
  ___resumeException($6|0);
  // unreachable;
 }
 ___cxa_guard_release((3093856|0));
 STACKTOP = sp;return (3093840|0);
}
function __ZNKSt3__120__time_get_c_storageIwE3__XEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093896>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (3093880|0);
 }
 $2 = (___cxa_guard_acquire((3093896|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (3093880|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3484,(3093904|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  invoke_viii(2133,(3093880|0),(3093904|0),($4|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   ___cxa_guard_release((3093896|0));
   STACKTOP = sp;return (3093880|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 ___cxa_guard_abort((3093896|0));
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZNKSt3__120__time_get_c_storageIcE3__cEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3093960>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (3093944|0);
 }
 $2 = (___cxa_guard_acquire((3093960|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (3093944|0);
 }
 __THREW__ = 0;
 invoke_viii(2132,(3093944|0),(3093968|0),20);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  ___cxa_guard_abort((3093960|0));
  ___resumeException($6|0);
  // unreachable;
 }
 ___cxa_guard_release((3093960|0));
 STACKTOP = sp;return (3093944|0);
}
function __ZNKSt3__120__time_get_c_storageIwE3__cEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3094008>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (3093992|0);
 }
 $2 = (___cxa_guard_acquire((3094008|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (3093992|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3484,(3094016|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  invoke_viii(2133,(3093992|0),(3094016|0),($4|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   ___cxa_guard_release((3094008|0));
   STACKTOP = sp;return (3093992|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 ___cxa_guard_abort((3094008|0));
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZNKSt3__120__time_get_c_storageIcE3__rEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3094120>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (3094104|0);
 }
 $2 = (___cxa_guard_acquire((3094120|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (3094104|0);
 }
 __THREW__ = 0;
 invoke_viii(2132,(3094104|0),(3094128|0),11);
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  ___cxa_guard_abort((3094120|0));
  ___resumeException($6|0);
  // unreachable;
 }
 ___cxa_guard_release((3094120|0));
 STACKTOP = sp;return (3094104|0);
}
function __ZNKSt3__120__time_get_c_storageIwE3__rEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[3094160>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  STACKTOP = sp;return (3094144|0);
 }
 $2 = (___cxa_guard_acquire((3094160|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return (3094144|0);
 }
 __THREW__ = 0;
 $4 = (invoke_ii(3484,(3094168|0))|0);
 $5 = __THREW__; __THREW__ = 0;
 $6 = $5&1;
 if (!($6)) {
  __THREW__ = 0;
  invoke_viii(2133,(3094144|0),(3094168|0),($4|0));
  $7 = __THREW__; __THREW__ = 0;
  $8 = $7&1;
  if (!($8)) {
   ___cxa_guard_release((3094160|0));
   STACKTOP = sp;return (3094144|0);
  }
 }
 $9 = ___cxa_find_matching_catch()|0;
 $10 = tempRet0;
 ___cxa_guard_abort((3094160|0));
 ___resumeException($9|0);
 // unreachable;
 return 0|0;
}
function __ZNSt3__115__num_get_floatIeEET_PKcS3_Rj($__a,$__a_end,$__err) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 var $$0 = 0.0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 do {
  if ($0) {
   HEAP32[$__err>>2] = 4;
   $$0 = 0.0;
  } else {
   $1 = (___errno_location()|0);
   $2 = HEAP32[$1>>2]|0;
   HEAP32[$1>>2] = 0;
   $3 = (__ZNSt3__16__clocEv()|0);
   $4 = (+_strtold_l($__a,$__p2,$3));
   $5 = HEAP32[$1>>2]|0;
   $6 = ($5|0)==(0);
   if ($6) {
    HEAP32[$1>>2] = $2;
   }
   $7 = HEAP32[$__p2>>2]|0;
   $8 = ($7|0)==($__a_end|0);
   if (!($8)) {
    HEAP32[$__err>>2] = 4;
    $$0 = 0.0;
    break;
   }
   $9 = ($5|0)==(34);
   if ($9) {
    HEAP32[$__err>>2] = 4;
    $$0 = $4;
   } else {
    $$0 = $4;
   }
  }
 } while(0);
 STACKTOP = sp;return (+$$0);
}
function __ZNSt3__115__num_get_floatIdEET_PKcS3_Rj($__a,$__a_end,$__err) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 var $$0 = 0.0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 do {
  if ($0) {
   HEAP32[$__err>>2] = 4;
   $$0 = 0.0;
  } else {
   $1 = (___errno_location()|0);
   $2 = HEAP32[$1>>2]|0;
   HEAP32[$1>>2] = 0;
   $3 = (__ZNSt3__16__clocEv()|0);
   $4 = (+_strtold_l($__a,$__p2,$3));
   $5 = HEAP32[$1>>2]|0;
   $6 = ($5|0)==(0);
   if ($6) {
    HEAP32[$1>>2] = $2;
   }
   $7 = HEAP32[$__p2>>2]|0;
   $8 = ($7|0)==($__a_end|0);
   if (!($8)) {
    HEAP32[$__err>>2] = 4;
    $$0 = 0.0;
    break;
   }
   $9 = ($5|0)==(34);
   if ($9) {
    HEAP32[$__err>>2] = 4;
    $$0 = $4;
   } else {
    $$0 = $4;
   }
  }
 } while(0);
 STACKTOP = sp;return (+$$0);
}
function __ZNSt3__115__num_get_floatIfEET_PKcS3_Rj($__a,$__a_end,$__err) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 var $$0 = Math_fround(0), $0 = 0, $1 = 0, $10 = Math_fround(0), $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 if ($0) {
  HEAP32[$__err>>2] = 4;
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $1 = (___errno_location()|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$1>>2] = 0;
 $3 = (__ZNSt3__16__clocEv()|0);
 $4 = (+_strtold_l($__a,$__p2,$3));
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  HEAP32[$1>>2] = $2;
 }
 $7 = HEAP32[$__p2>>2]|0;
 $8 = ($7|0)==($__a_end|0);
 if (!($8)) {
  HEAP32[$__err>>2] = 4;
  $$0 = Math_fround(0.0);
  STACKTOP = sp;return (Math_fround($$0));
 }
 $9 = ($5|0)==(34);
 if ($9) {
  HEAP32[$__err>>2] = 4;
 }
 $10 = Math_fround($4);
 $$0 = $10;
 STACKTOP = sp;return (Math_fround($$0));
}
function __ZNSt3__127__num_get_unsigned_integralIyEET_PKcS3_Rji($__a,$__a_end,$__err,$__base) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 $__base = $__base|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 do {
  if ($0) {
   HEAP32[$__err>>2] = 4;
   $13 = 0;$14 = 0;
  } else {
   $1 = HEAP8[$__a>>0]|0;
   $2 = ($1<<24>>24)==(45);
   if ($2) {
    HEAP32[$__err>>2] = 4;
    $13 = 0;$14 = 0;
    break;
   }
   $3 = (___errno_location()|0);
   $4 = HEAP32[$3>>2]|0;
   HEAP32[$3>>2] = 0;
   $5 = (__ZNSt3__16__clocEv()|0);
   $6 = (_strtoull_l($__a,$__p2,$__base,$5)|0);
   $7 = tempRet0;
   $8 = HEAP32[$3>>2]|0;
   $9 = ($8|0)==(0);
   if ($9) {
    HEAP32[$3>>2] = $4;
   }
   $10 = HEAP32[$__p2>>2]|0;
   $11 = ($10|0)==($__a_end|0);
   if (!($11)) {
    HEAP32[$__err>>2] = 4;
    $13 = 0;$14 = 0;
    break;
   }
   $12 = ($8|0)==(34);
   if ($12) {
    HEAP32[$__err>>2] = 4;
    $13 = -1;$14 = -1;
   } else {
    $13 = $7;$14 = $6;
   }
  }
 } while(0);
 tempRet0 = $13;
 STACKTOP = sp;return ($14|0);
}
function __ZNSt3__127__num_get_unsigned_integralImEET_PKcS3_Rji($__a,$__a_end,$__err,$__base) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 $__base = $__base|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p2 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 if ($0) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP8[$__a>>0]|0;
 $2 = ($1<<24>>24)==(45);
 if ($2) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (___errno_location()|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$3>>2] = 0;
 $5 = (__ZNSt3__16__clocEv()|0);
 $6 = (_strtoull_l($__a,$__p2,$__base,$5)|0);
 $7 = tempRet0;
 $8 = HEAP32[$3>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$3>>2] = $4;
 }
 $10 = HEAP32[$__p2>>2]|0;
 $11 = ($10|0)==($__a_end|0);
 if (!($11)) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ($8|0)==(34);
 $13 = ($7>>>0)>(0);
 $14 = ($7|0)==(0);
 $15 = ($6>>>0)>(4294967295);
 $16 = $14 & $15;
 $17 = $13 | $16;
 $or$cond = $12 | $17;
 if ($or$cond) {
  HEAP32[$__err>>2] = 4;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__127__num_get_unsigned_integralIjEET_PKcS3_Rji($__a,$__a_end,$__err,$__base) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 $__base = $__base|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p2 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 if ($0) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP8[$__a>>0]|0;
 $2 = ($1<<24>>24)==(45);
 if ($2) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (___errno_location()|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$3>>2] = 0;
 $5 = (__ZNSt3__16__clocEv()|0);
 $6 = (_strtoull_l($__a,$__p2,$__base,$5)|0);
 $7 = tempRet0;
 $8 = HEAP32[$3>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$3>>2] = $4;
 }
 $10 = HEAP32[$__p2>>2]|0;
 $11 = ($10|0)==($__a_end|0);
 if (!($11)) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ($8|0)==(34);
 $13 = ($7>>>0)>(0);
 $14 = ($7|0)==(0);
 $15 = ($6>>>0)>(4294967295);
 $16 = $14 & $15;
 $17 = $13 | $16;
 $or$cond = $12 | $17;
 if ($or$cond) {
  HEAP32[$__err>>2] = 4;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__127__num_get_unsigned_integralItEET_PKcS3_Rji($__a,$__a_end,$__err,$__base) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 $__base = $__base|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 if ($0) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP8[$__a>>0]|0;
 $2 = ($1<<24>>24)==(45);
 if ($2) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (___errno_location()|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$3>>2] = 0;
 $5 = (__ZNSt3__16__clocEv()|0);
 $6 = (_strtoull_l($__a,$__p2,$__base,$5)|0);
 $7 = tempRet0;
 $8 = HEAP32[$3>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$3>>2] = $4;
 }
 $10 = HEAP32[$__p2>>2]|0;
 $11 = ($10|0)==($__a_end|0);
 if (!($11)) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ($8|0)==(34);
 $13 = ($7>>>0)>(0);
 $14 = ($7|0)==(0);
 $15 = ($6>>>0)>(65535);
 $16 = $14 & $15;
 $17 = $13 | $16;
 $or$cond = $12 | $17;
 if ($or$cond) {
  HEAP32[$__err>>2] = 4;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $18 = $6&65535;
  $$0 = $18;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function __ZNSt3__125__num_get_signed_integralIxEET_PKcS3_Rji($__a,$__a_end,$__err,$__base) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 $__base = $__base|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__p2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 if ($0) {
  HEAP32[$__err>>2] = 4;
  $18 = 0;$19 = 0;
  tempRet0 = $18;
  STACKTOP = sp;return ($19|0);
 }
 $1 = (___errno_location()|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$1>>2] = 0;
 $3 = (__ZNSt3__16__clocEv()|0);
 $4 = (_strtoll_l($__a,$__p2,$__base,$3)|0);
 $5 = tempRet0;
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  HEAP32[$1>>2] = $2;
 }
 $8 = HEAP32[$__p2>>2]|0;
 $9 = ($8|0)==($__a_end|0);
 if (!($9)) {
  HEAP32[$__err>>2] = 4;
  $18 = 0;$19 = 0;
  tempRet0 = $18;
  STACKTOP = sp;return ($19|0);
 }
 $10 = ($6|0)==(34);
 if ($10) {
  HEAP32[$__err>>2] = 4;
  $11 = ($5|0)>(0);
  $12 = ($5|0)==(0);
  $13 = ($4>>>0)>(0);
  $14 = $12 & $13;
  $15 = $11 | $14;
  $16 = $15 ? -1 : 0;
  $17 = $15 ? 2147483647 : -2147483648;
  tempRet0 = $17;
  STACKTOP = sp;return ($16|0);
 } else {
  $18 = $5;$19 = $4;
  tempRet0 = $18;
  STACKTOP = sp;return ($19|0);
 }
 return 0|0;
}
function __ZNSt3__125__num_get_signed_integralIlEET_PKcS3_Rji($__a,$__a_end,$__err,$__base) {
 $__a = $__a|0;
 $__a_end = $__a_end|0;
 $__err = $__err|0;
 $__base = $__base|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__p2 = sp;
 $0 = ($__a|0)==($__a_end|0);
 if ($0) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (___errno_location()|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$1>>2] = 0;
 $3 = (__ZNSt3__16__clocEv()|0);
 $4 = (_strtoll_l($__a,$__p2,$__base,$3)|0);
 $5 = tempRet0;
 $6 = HEAP32[$1>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  HEAP32[$1>>2] = $2;
 }
 $8 = HEAP32[$__p2>>2]|0;
 $9 = ($8|0)==($__a_end|0);
 if (!($9)) {
  HEAP32[$__err>>2] = 4;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ($6|0)==(34);
 do {
  if ($10) {
   HEAP32[$__err>>2] = 4;
   $21 = ($5|0)>(0);
   $22 = ($5|0)==(0);
   $23 = ($4>>>0)>(0);
   $24 = $22 & $23;
   $25 = $21 | $24;
   if ($25) {
    $$0 = 2147483647;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $11 = ($5|0)<(-1);
   $12 = ($5|0)==(-1);
   $13 = ($4>>>0)<(2147483648);
   $14 = $12 & $13;
   $15 = $11 | $14;
   if ($15) {
    HEAP32[$__err>>2] = 4;
    break;
   }
   $16 = ($5|0)>(0);
   $17 = ($5|0)==(0);
   $18 = ($4>>>0)>(2147483647);
   $19 = $17 & $18;
   $20 = $16 | $19;
   if ($20) {
    HEAP32[$__err>>2] = 4;
    $$0 = 2147483647;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$0 = $4;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $$0 = -2147483648;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__117__call_once_proxyINS_5tupleIJNS_12_GLOBAL__N_111__fake_bindEEEEEEvPv($__vp) {
 $__vp = $__vp|0;
 var $$field = 0, $$field2 = 0, $$index1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__vp) + 4|0);
 $$field = HEAPU8[$0>>0]|(HEAPU8[$0+1>>0]<<8)|(HEAPU8[$0+2>>0]<<16)|(HEAPU8[$0+3>>0]<<24);
 $$index1 = (($0) + 4|0);
 $$field2 = HEAPU8[$$index1>>0]|(HEAPU8[$$index1+1>>0]<<8)|(HEAPU8[$$index1+2>>0]<<16)|(HEAPU8[$$index1+3>>0]<<24);
 $1 = HEAP32[$__vp>>2]|0;
 $2 = $$field2 >> 1;
 $3 = (($1) + ($2)|0);
 $4 = $$field2 & 1;
 $5 = ($4|0)==(0);
 if ($5) {
  $9 = $$field;
  $10 = $9;
  FUNCTION_TABLE_vi[$10 & 4095]($3);
  STACKTOP = sp;return;
 } else {
  $6 = HEAP32[$3>>2]|0;
  $7 = (($6) + ($$field)|0);
  $8 = HEAP32[$7>>2]|0;
  $10 = $8;
  FUNCTION_TABLE_vi[$10 & 4095]($3);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8__appendEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__v = sp;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = ($7>>>0)<($__n>>>0);
 if (!($8)) {
  __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj($this,$__n);
  STACKTOP = sp;return;
 }
 $9 = (($this) + 16|0);
 $10 = HEAP32[$this>>2]|0;
 $11 = $10;
 $12 = (($5) - ($11))|0;
 $13 = $12 >> 2;
 $14 = (($13) + ($__n))|0;
 $15 = ($14>>>0)>(1073741823);
 if ($15) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $16 = (($4) - ($11))|0;
 $17 = $16 >> 2;
 $18 = ($17>>>0)<(536870911);
 if ($18) {
  $19 = $16 >> 1;
  $20 = ($19>>>0)<($14>>>0);
  $21 = $20 ? $14 : $19;
  $$0$i = $21;
 } else {
  $$0$i = 1073741823;
 }
 __ZNSt3__114__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEEC2EjjS6_($__v,$$0$i,$13,$9);
 __ZNSt3__114__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj($__v,$__n);
 __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE($this,$__v);
 __ZNSt3__114__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEED2Ev($__v);
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0 = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $$pre = HEAP32[$0>>2]|0;
 $$0 = $__n;$2 = $$pre;
 while(1) {
  $1 = ($2|0)==(0|0);
  if ($1) {
   $4 = 0;
  } else {
   HEAP32[$2>>2] = 0;
   $$pre1 = HEAP32[$0>>2]|0;
   $4 = $$pre1;
  }
  $3 = (($4) + 4|0);
  HEAP32[$0>>2] = $3;
  $5 = (($$0) + -1)|0;
  $6 = ($5|0)==(0);
  if ($6) {
   break;
  } else {
   $$0 = $5;$2 = $3;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0 = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $$pre = HEAP32[$0>>2]|0;
 $$0 = $__n;$2 = $$pre;
 while(1) {
  $1 = ($2|0)==(0|0);
  if ($1) {
   $4 = 0;
  } else {
   HEAP32[$2>>2] = 0;
   $$pre1 = HEAP32[$0>>2]|0;
   $4 = $$pre1;
  }
  $3 = (($4) + 4|0);
  HEAP32[$0>>2] = $3;
  $5 = (($$0) + -1)|0;
  $6 = ($5|0)==(0);
  if ($6) {
   break;
  } else {
   $$0 = $5;$2 = $3;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE($this,$__v) {
 $this = $this|0;
 $__v = $__v|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($__v) + 4|0);
 $4 = $2;
 $5 = $0;
 $6 = (($4) - ($5))|0;
 $7 = $6 >> 2;
 $8 = HEAP32[$3>>2]|0;
 $9 = (0 - ($7))|0;
 $10 = (($8) + ($9<<2)|0);
 HEAP32[$3>>2] = $10;
 _memcpy(($10|0),($0|0),($6|0))|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = HEAP32[$3>>2]|0;
 HEAP32[$this>>2] = $12;
 HEAP32[$3>>2] = $11;
 $13 = (($__v) + 8|0);
 $14 = HEAP32[$1>>2]|0;
 $15 = HEAP32[$13>>2]|0;
 HEAP32[$1>>2] = $15;
 HEAP32[$13>>2] = $14;
 $16 = (($this) + 8|0);
 $17 = (($__v) + 12|0);
 $18 = HEAP32[$16>>2]|0;
 $19 = HEAP32[$17>>2]|0;
 HEAP32[$16>>2] = $19;
 HEAP32[$17>>2] = $18;
 $20 = HEAP32[$3>>2]|0;
 HEAP32[$__v>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNSt3__114__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i$i = 0, $scevgep$i$i$i = 0, $scevgep4$i$i$i = 0, $uglygep$i$i$i = 0, $uglygep3$i$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($1|0);
 if (!($4)) {
  $__new_last2$i$i$i = $1;
  $scevgep$i$i$i = (($3) + -4|0);
  $5 = (0 - ($__new_last2$i$i$i))|0;
  $uglygep$i$i$i = (($scevgep$i$i$i) + ($5)|0);
  $uglygep3$i$i$i = $uglygep$i$i$i;
  $6 = $uglygep3$i$i$i >>> 2;
  $7 = $6 ^ -1;
  $scevgep4$i$i$i = (($3) + ($7<<2)|0);
  HEAP32[$2>>2] = $scevgep4$i$i$i;
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==($8|0);
 if ($12) {
  $13 = (($11) + 112|0);
  HEAP8[$13>>0] = 0;
  STACKTOP = sp;return;
 } else {
  __ZdlPv($8);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__114__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lj28EEEEC2EjjS6_($this,$__cap,$__start,$__a) {
 $this = $this|0;
 $__cap = $__cap|0;
 $__start = $__start|0;
 $__a = $__a|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 16|0);
 HEAP32[$1>>2] = $__a;
 $2 = ($__cap|0)==(0);
 do {
  if ($2) {
   $9 = 0;
  } else {
   $3 = (($__a) + 112|0);
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   $6 = ($__cap>>>0)<(29);
   $or$cond$i$i = $5 & $6;
   if ($or$cond$i$i) {
    HEAP8[$3>>0] = 1;
    $9 = $__a;
    break;
   } else {
    $7 = $__cap << 2;
    $8 = (__Znwj($7)|0);
    $9 = $8;
    break;
   }
  }
 } while(0);
 HEAP32[$this>>2] = $9;
 $10 = (($9) + ($__start<<2)|0);
 $11 = (($this) + 8|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 4|0);
 HEAP32[$12>>2] = $10;
 $13 = (($9) + ($__cap<<2)|0);
 HEAP32[$0>>2] = $13;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8allocateEj($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $$0$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__n>>>0)>(1073741823);
 if ($0) {
  __ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv(0);
  // unreachable;
 }
 $1 = (($this) + 128|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 $4 = ($__n>>>0)<(29);
 $or$cond$i$i = $3 & $4;
 if ($or$cond$i$i) {
  $5 = (($this) + 16|0);
  HEAP8[$1>>0] = 1;
  $$0$i$i = $5;
 } else {
  $6 = $__n << 2;
  $7 = (__Znwj($6)|0);
  $$0$i$i = $7;
 }
 $8 = (($this) + 4|0);
 HEAP32[$8>>2] = $$0$i$i;
 HEAP32[$this>>2] = $$0$i$i;
 $9 = (($$0$i$i) + ($__n<<2)|0);
 $10 = (($this) + 8|0);
 HEAP32[$10>>2] = $9;
 STACKTOP = sp;return;
}
function __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEEC2Ej($this,$__n) {
 $this = $this|0;
 $__n = $__n|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 128|0);
 HEAP8[$2>>0] = 0;
 $3 = ($__n|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 __THREW__ = 0;
 invoke_vii(3542,($this|0),($__n|0));
 $4 = __THREW__; __THREW__ = 0;
 $5 = $4&1;
 if ($5) {
  $6 = ___cxa_find_matching_catch()|0;
  $7 = tempRet0;
  __ZNSt3__113__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev($this);
  ___resumeException($6|0);
  // unreachable;
 }
 __ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE18__construct_at_endEj($this,$__n);
 STACKTOP = sp;return;
}
function __ZNSt3__113__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__new_last2$i$i = 0, $scevgep$i$i = 0, $scevgep4$i$i = 0, $uglygep$i$i = 0, $uglygep3$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==($0|0);
 if (!($4)) {
  $__new_last2$i$i = $0;
  $scevgep$i$i = (($3) + -4|0);
  $5 = (0 - ($__new_last2$i$i))|0;
  $uglygep$i$i = (($scevgep$i$i) + ($5)|0);
  $uglygep3$i$i = $uglygep$i$i;
  $6 = $uglygep3$i$i >>> 2;
  $7 = $6 ^ -1;
  $scevgep4$i$i = (($3) + ($7<<2)|0);
  HEAP32[$2>>2] = $scevgep4$i$i;
 }
 $8 = (($this) + 16|0);
 $9 = ($8|0)==($0|0);
 if ($9) {
  $10 = (($this) + 128|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 } else {
  __ZdlPv($0);
  STACKTOP = sp;return;
 }
}
function _strtoull_l($s,$p,$base,$loc) {
 $s = $s|0;
 $p = $p|0;
 $base = $base|0;
 $loc = $loc|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strtoull($s,$p,$base)|0);
 $1 = tempRet0;
 tempRet0 = $1;
 STACKTOP = sp;return ($0|0);
}
function _strtoll_l($s,$p,$base,$loc) {
 $s = $s|0;
 $p = $p|0;
 $base = $base|0;
 $loc = $loc|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strtoll($s,$p,$base)|0);
 $1 = tempRet0;
 tempRet0 = $1;
 STACKTOP = sp;return ($0|0);
}
function _isalpha($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c | 32;
 $1 = (($0) + -97)|0;
 $2 = ($1>>>0)<(26);
 $3 = $2&1;
 STACKTOP = sp;return ($3|0);
}
function _iswalpha($wc) {
 $wc = $wc|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($wc>>>0)<(131072);
 if ($0) {
  $1 = $wc >>> 8;
  $2 = (3100992 + ($1)|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3&255;
  $5 = $4 << 5;
  $6 = $wc >>> 3;
  $7 = $6 & 31;
  $8 = $5 | $7;
  $9 = (3100992 + ($8)|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = $wc & 7;
  $13 = $11 >>> $12;
  $14 = $13 & 1;
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 } else {
  $15 = ($wc>>>0)<(196606);
  $$ = $15&1;
  $$0 = $$;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function ___towcase($wc,$lower) {
 $wc = $wc|0;
 $lower = $lower|0;
 var $$0 = 0, $$neg16 = 0, $$neg19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$024 = 0, $i$121 = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $lower << 1;
 $1 = (($0) + -1)|0;
 $2 = (($lower) + -1)|0;
 $3 = (_iswalpha($wc)|0);
 $4 = ($3|0)==(0);
 $5 = (($wc) + -1536)|0;
 $6 = ($5>>>0)<(2560);
 $or$cond9 = $4 | $6;
 $7 = (($wc) + -11776)|0;
 $8 = ($7>>>0)<(30784);
 $or$cond11 = $or$cond9 | $8;
 $9 = (($wc) + -43008)|0;
 $10 = ($9>>>0)<(22272);
 $or$cond13 = $or$cond11 | $10;
 if ($or$cond13) {
  $$0 = $wc;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ($lower|0)==(0);
 if ($11) {
  $16 = (($wc) + -11520)|0;
  $17 = ($16>>>0)<(38);
  if ($17) {
   $18 = (($wc) + -7264)|0;
   $$0 = $18;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$024 = 0;
  }
 } else {
  $12 = (($wc) + -4256)|0;
  $13 = ($12>>>0)<(46);
  if ($13) {
   $14 = ($wc|0)>(4293);
   if ($14) {
    if (!((($wc|0) == 4295) | (($wc|0) == 4301))) {
     $$0 = $wc;
     STACKTOP = sp;return ($$0|0);
    }
   }
   $15 = (($wc) + 7264)|0;
   $$0 = $15;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$024 = 0;
  }
 }
 while(1) {
  $25 = ((3103968 + ($i$024<<2)|0) + 3|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = (3103968 + ($i$024<<2)|0);
  $28 = HEAP16[$27>>1]|0;
  $29 = $28&65535;
  $30 = ((3103968 + ($i$024<<2)|0) + 2|0);
  $31 = HEAP8[$30>>0]|0;
  $32 = $31 << 24 >> 24;
  $33 = $32 & $2;
  $$neg16 = (($wc) - ($29))|0;
  $34 = (($$neg16) - ($33))|0;
  $35 = $26&255;
  $36 = ($34>>>0)<($35>>>0);
  $20 = (($i$024) + 1)|0;
  if ($36) {
   label = 12;
   break;
  }
  $19 = ($20|0)==(61);
  if ($19) {
   break;
  } else {
   $i$024 = $20;
  }
 }
 if ((label|0) == 12) {
  $37 = ($31<<24>>24)==(1);
  if ($37) {
   $38 = (($lower) + ($wc))|0;
   $39 = $$neg16 & 1;
   $40 = (($38) - ($39))|0;
   $$0 = $40;
   STACKTOP = sp;return ($$0|0);
  } else {
   $41 = Math_imul($32, $1)|0;
   $42 = (($41) + ($wc))|0;
   $$0 = $42;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $21 = (1 - ($lower))|0;
 $22 = (3104216 + ($21<<1)|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = ($23<<16>>16)==(0);
 L26: do {
  if (!($24)) {
   $48 = $23;$i$121 = 0;
   while(1) {
    $47 = $48&65535;
    $49 = ($47|0)==($wc|0);
    $44 = (($i$121) + 1)|0;
    if ($49) {
     break;
    }
    $43 = ((3104216 + ($44<<2)|0) + ($21<<1)|0);
    $45 = HEAP16[$43>>1]|0;
    $46 = ($45<<16>>16)==(0);
    if ($46) {
     break L26;
    } else {
     $48 = $45;$i$121 = $44;
    }
   }
   $50 = ((3104216 + ($i$121<<2)|0) + ($lower<<1)|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = $51&65535;
   $$0 = $52;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $53 = ($lower*40)|0;
 $$neg19 = (($wc) + -66600)|0;
 $54 = (($$neg19) + ($53))|0;
 $55 = ($54>>>0)<(40);
 if (!($55)) {
  $$0 = $wc;
  STACKTOP = sp;return ($$0|0);
 }
 $56 = (($wc) + -40)|0;
 $57 = ($lower*80)|0;
 $58 = (($56) + ($57))|0;
 $$0 = $58;
 STACKTOP = sp;return ($$0|0);
}
function _towlower($wc) {
 $wc = $wc|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___towcase($wc,1)|0);
 STACKTOP = sp;return ($0|0);
}
function _isdigit_l($c,$l) {
 $c = $c|0;
 $l = $l|0;
 var $0 = 0, $isdigit = 0, $isdigittmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isdigittmp = (($c) + -48)|0;
 $isdigit = ($isdigittmp>>>0)<(10);
 $0 = $isdigit&1;
 STACKTOP = sp;return ($0|0);
}
function _isxdigit_l($c,$l) {
 $c = $c|0;
 $l = $l|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_isxdigit($c)|0);
 STACKTOP = sp;return ($0|0);
}
function _mbrlen($s,$n,$st) {
 $s = $s|0;
 $n = $n|0;
 $st = $st|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($st|0)!=(0|0);
 $1 = $0 ? $st : 3104920;
 $2 = (_mbrtowc(0,$s,$n,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function _mbrtowc($wc,$src,$n,$st) {
 $wc = $wc|0;
 $src = $src|0;
 $n = $n|0;
 $st = $st|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0 = 0, $c$1 = 0, $c$2 = 0, $s$0 = 0, $s$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $wc;
 $1 = ($st|0)==(0|0);
 $$01 = $1 ? 3104928 : $st;
 $2 = HEAP32[$$01>>2]|0;
 $3 = ($src|0)==(0|0);
 L1: do {
  if ($3) {
   $4 = ($2|0)==(0);
   if ($4) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $5 = ($wc|0)==(0|0);
   if ($5) {
    HEAP32[$0>>2] = $0;
    $11 = $0;
   } else {
    $11 = $wc;
   }
   $6 = ($n|0)==(0);
   if ($6) {
    $$0 = -2;
    STACKTOP = sp;return ($$0|0);
   }
   $7 = ($2|0)==(0);
   do {
    if ($7) {
     $8 = HEAP8[$src>>0]|0;
     $9 = $8&255;
     $10 = ($8<<24>>24)>(-1);
     if ($10) {
      HEAP32[$11>>2] = $9;
      $12 = ($8<<24>>24)!=(0);
      $13 = $12&1;
      $$0 = $13;
      STACKTOP = sp;return ($$0|0);
     } else {
      $14 = (($9) + -194)|0;
      $15 = ($14>>>0)>(50);
      if ($15) {
       break L1;
      }
      $16 = (($src) + 1|0);
      $17 = (3104712 + ($14<<2)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($n) + -1)|0;
      $$02 = $19;$c$0 = $18;$s$0 = $16;
      break;
     }
    } else {
     $$02 = $n;$c$0 = $2;$s$0 = $src;
    }
   } while(0);
   $20 = ($$02|0)==(0);
   L19: do {
    if ($20) {
     $c$2 = $c$0;
    } else {
     $21 = HEAP8[$s$0>>0]|0;
     $22 = $21&255;
     $23 = $22 >>> 3;
     $24 = (($23) + -16)|0;
     $25 = $c$0 >> 26;
     $26 = (($23) + ($25))|0;
     $27 = $24 | $26;
     $28 = ($27>>>0)>(7);
     if ($28) {
      break L1;
     } else {
      $$1 = $$02;$32 = $21;$c$1 = $c$0;$s$1 = $s$0;
     }
     while(1) {
      $29 = $c$1 << 6;
      $30 = (($s$1) + 1|0);
      $31 = $32&255;
      $33 = (($31) + -128)|0;
      $34 = $33 | $29;
      $35 = (($$1) + -1)|0;
      $36 = ($34|0)<(0);
      if (!($36)) {
       break;
      }
      $38 = ($35|0)==(0);
      if ($38) {
       $c$2 = $34;
       break L19;
      }
      $39 = HEAP8[$30>>0]|0;
      $40 = $39&255;
      $41 = (($40) + -128)|0;
      $42 = ($41>>>0)>(63);
      if ($42) {
       break L1;
      } else {
       $$1 = $35;$32 = $39;$c$1 = $34;$s$1 = $30;
      }
     }
     HEAP32[$$01>>2] = 0;
     HEAP32[$11>>2] = $34;
     $37 = (($n) - ($35))|0;
     $$0 = $37;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   HEAP32[$$01>>2] = $c$2;
   $$0 = -2;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$$01>>2] = 0;
 $43 = (___errno_location()|0);
 HEAP32[$43>>2] = 84;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _mbsinit($st) {
 $st = $st|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($st|0)==(0|0);
 if ($0) {
  $4 = 1;
 } else {
  $1 = HEAP32[$st>>2]|0;
  $2 = ($1|0)==(0);
  $4 = $2;
 }
 $3 = $4&1;
 STACKTOP = sp;return ($3|0);
}
function _mbsnrtowcs($wcs,$src,$n,$wn,$st) {
 $wcs = $wcs|0;
 $src = $src|0;
 $n = $n|0;
 $wn = $wn|0;
 $st = $st|0;
 var $$026 = 0, $$04$ = 0, $$0423 = 0, $$1 = 0, $$15 = 0, $$214 = 0, $$26 = 0, $$311 = 0, $$pr$pre = 0, $$pr41 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cnt$024 = 0, $cnt$1 = 0, $cnt$212 = 0, $cnt$3 = 0, $or$cond = 0, $or$cond22 = 0, $or$cond7 = 0, $or$cond8 = 0, $or$cond810 = 0, $s = 0, $wbuf = 0, $wcs$ = 0, $wn$ = 0, $ws$018 = 0, $ws$025 = 0, $ws$1 = 0;
 var $ws$213 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $wbuf = sp + 8|0;
 $s = sp;
 $0 = HEAP32[$src>>2]|0;
 HEAP32[$s>>2] = $0;
 $1 = ($wcs|0)!=(0|0);
 $wn$ = $1 ? $wn : 256;
 $wcs$ = $1 ? $wcs : $wbuf;
 $2 = ($0|0)==(0|0);
 $3 = ($wn$|0)==(0);
 $or$cond22 = $2 | $3;
 L1: do {
  if ($or$cond22) {
   $$1 = $n;$$26 = $wn$;$18 = $0;$cnt$1 = 0;$ws$018 = $wcs$;
  } else {
   $$026 = $n;$$0423 = $wn$;$$pr41 = $0;$cnt$024 = 0;$ws$025 = $wcs$;
   while(1) {
    $4 = $$026 >>> 2;
    $5 = ($4>>>0)>=($$0423>>>0);
    $6 = ($$026>>>0)>(131);
    $or$cond7 = $5 | $6;
    if (!($or$cond7)) {
     $$1 = $$026;$$26 = $$0423;$18 = $$pr41;$cnt$1 = $cnt$024;$ws$018 = $ws$025;
     break L1;
    }
    $$04$ = $5 ? $$0423 : $4;
    $7 = (($$026) - ($$04$))|0;
    $8 = (_mbsrtowcs($ws$025,$s,$$04$,$st)|0);
    $9 = ($8|0)==(-1);
    if ($9) {
     break;
    }
    $10 = ($ws$025|0)==($wbuf|0);
    if ($10) {
     $$15 = $$0423;$ws$1 = $wbuf;
    } else {
     $11 = (($ws$025) + ($8<<2)|0);
     $12 = (($$0423) - ($8))|0;
     $$15 = $12;$ws$1 = $11;
    }
    $13 = (($8) + ($cnt$024))|0;
    $14 = HEAP32[$s>>2]|0;
    $15 = ($14|0)==(0|0);
    $16 = ($$15|0)==(0);
    $or$cond = $15 | $16;
    if ($or$cond) {
     $$1 = $7;$$26 = $$15;$18 = $14;$cnt$1 = $13;$ws$018 = $ws$1;
     break L1;
    } else {
     $$026 = $7;$$0423 = $$15;$$pr41 = $14;$cnt$024 = $13;$ws$025 = $ws$1;
    }
   }
   $$pr$pre = HEAP32[$s>>2]|0;
   $$1 = $7;$$26 = 0;$18 = $$pr$pre;$cnt$1 = -1;$ws$018 = $ws$025;
  }
 } while(0);
 $17 = ($18|0)==(0|0);
 L11: do {
  if ($17) {
   $cnt$3 = $cnt$1;
  } else {
   $19 = ($$26|0)==(0);
   $20 = ($$1|0)==(0);
   $or$cond810 = $19 | $20;
   if ($or$cond810) {
    $cnt$3 = $cnt$1;
   } else {
    $$214 = $$1;$$311 = $$26;$21 = $18;$cnt$212 = $cnt$1;$ws$213 = $ws$018;
    while(1) {
     $22 = (_mbrtowc($ws$213,$21,$$214,$st)|0);
     $23 = (($22) + 2)|0;
     $24 = ($23>>>0)<(3);
     if ($24) {
      break;
     }
     $25 = HEAP32[$s>>2]|0;
     $26 = (($25) + ($22)|0);
     HEAP32[$s>>2] = $26;
     $27 = (($$214) - ($22))|0;
     $28 = (($ws$213) + 4|0);
     $29 = (($$311) + -1)|0;
     $30 = (($cnt$212) + 1)|0;
     $31 = ($29|0)==(0);
     $32 = ($$214|0)==($22|0);
     $or$cond8 = $31 | $32;
     if ($or$cond8) {
      $cnt$3 = $30;
      break L11;
     } else {
      $$214 = $27;$$311 = $29;$21 = $26;$cnt$212 = $30;$ws$213 = $28;
     }
    }
    if ((($22|0) == -1)) {
     $cnt$3 = -1;
     break;
    } else if ((($22|0) == 0)) {
     HEAP32[$s>>2] = 0;
     $cnt$3 = $cnt$212;
     break;
    } else {
     HEAP32[$st>>2] = 0;
     $cnt$3 = $cnt$212;
     break;
    }
   }
  }
 } while(0);
 if (!($1)) {
  STACKTOP = sp;return ($cnt$3|0);
 }
 $33 = HEAP32[$s>>2]|0;
 HEAP32[$src>>2] = $33;
 STACKTOP = sp;return ($cnt$3|0);
}
function _mbsrtowcs($ws,$src,$wn,$st) {
 $ws = $ws|0;
 $src = $src|0;
 $wn = $wn|0;
 $st = $st|0;
 var $$0 = 0, $$01$ph = 0, $$0123 = 0, $$02 = 0, $$113 = 0, $$13$lcssa = 0, $$137 = 0, $$2 = 0, $$24 = 0, $$3 = 0, $$35 = 0, $$4 = 0, $$443 = 0, $$444 = 0, $$46$ph = 0, $$4622 = 0, $$512 = 0, $$6 = 0, $$7 = 0, $$8 = 0;
 var $$842 = 0, $$in = 0, $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$2 = 0, $c$4 = 0, $c$5 = 0, $c$6 = 0, $or$cond = 0, $s$0 = 0, $s$1$lcssa = 0, $s$10 = 0;
 var $s$1045 = 0, $s$1046 = 0, $s$18 = 0, $s$2 = 0, $s$3 = 0, $s$4 = 0, $s$5$lcssa = 0, $s$5$ph = 0, $s$524 = 0, $s$614 = 0, $s$7 = 0, $s$8 = 0, $s$9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$src>>2]|0;
 $1 = ($st|0)==(0|0);
 if ($1) {
  label = 5;
 } else {
  $2 = HEAP32[$st>>2]|0;
  $3 = ($2|0)==(0);
  if ($3) {
   label = 5;
  } else {
   $4 = ($ws|0)==(0|0);
   if ($4) {
    $$35 = $wn;$c$2 = $2;$s$3 = $0;
    label = 16;
   } else {
    HEAP32[$st>>2] = 0;
    $$3 = $ws;$$7 = $wn;$c$4 = $2;$s$8 = $0;
    label = 37;
   }
  }
 }
 if ((label|0) == 5) {
  $5 = ($ws|0)==(0|0);
  if ($5) {
   $$02 = $wn;$s$0 = $0;
   label = 7;
  } else {
   $$01$ph = $ws;$$46$ph = $wn;$s$5$ph = $0;
   label = 6;
  }
 }
 L7: while(1) {
  if ((label|0) == 6) {
   label = 0;
   $6 = ($$46$ph|0)==(0);
   if ($6) {
    $s$5$lcssa = $s$5$ph;
    label = 26;
    break;
   } else {
    $$0123 = $$01$ph;$$4622 = $$46$ph;$s$524 = $s$5$ph;
   }
   while(1) {
    $65 = HEAP8[$s$524>>0]|0;
    $66 = $65&255;
    $67 = (($66) + -1)|0;
    $68 = ($67>>>0)<(127);
    do {
     if ($68) {
      $69 = $s$524;
      $70 = $69 & 3;
      $71 = ($70|0)==(0);
      $72 = ($$4622>>>0)>(4);
      $or$cond = $71 & $72;
      if ($or$cond) {
       $$113 = $$0123;$$512 = $$4622;$s$614 = $s$524;
       while(1) {
        $73 = HEAP32[$s$614>>2]|0;
        $74 = (($73) + -16843009)|0;
        $75 = $74 | $73;
        $76 = $75 & -2139062144;
        $77 = ($76|0)==(0);
        if (!($77)) {
         label = 31;
         break;
        }
        $78 = (($s$614) + 1|0);
        $79 = $73 & 255;
        $80 = (($$113) + 4|0);
        HEAP32[$$113>>2] = $79;
        $81 = (($s$614) + 2|0);
        $82 = HEAP8[$78>>0]|0;
        $83 = $82&255;
        $84 = (($$113) + 8|0);
        HEAP32[$80>>2] = $83;
        $85 = (($s$614) + 3|0);
        $86 = HEAP8[$81>>0]|0;
        $87 = $86&255;
        $88 = (($$113) + 12|0);
        HEAP32[$84>>2] = $87;
        $89 = (($s$614) + 4|0);
        $90 = HEAP8[$85>>0]|0;
        $91 = $90&255;
        $92 = (($$113) + 16|0);
        HEAP32[$88>>2] = $91;
        $93 = (($$512) + -4)|0;
        $94 = ($93>>>0)>(4);
        if ($94) {
         $$113 = $92;$$512 = $93;$s$614 = $89;
        } else {
         label = 32;
         break;
        }
       }
       if ((label|0) == 31) {
        label = 0;
        $95 = $73&255;
        $$2 = $$113;$$6 = $$512;$97 = $95;$s$7 = $s$614;
        break;
       }
       else if ((label|0) == 32) {
        label = 0;
        $$pre$pre = HEAP8[$89>>0]|0;
        $$2 = $92;$$6 = $93;$97 = $$pre$pre;$s$7 = $89;
        break;
       }
      } else {
       $$2 = $$0123;$$6 = $$4622;$97 = $65;$s$7 = $s$524;
      }
     } else {
      $$2 = $$0123;$$6 = $$4622;$97 = $65;$s$7 = $s$524;
     }
    } while(0);
    $96 = $97&255;
    $98 = (($96) + -1)|0;
    $99 = ($98>>>0)<(127);
    if (!($99)) {
     break;
    }
    $100 = (($s$7) + 1|0);
    $101 = (($$2) + 4|0);
    HEAP32[$$2>>2] = $96;
    $102 = (($$6) + -1)|0;
    $103 = ($102|0)==(0);
    if ($103) {
     $s$5$lcssa = $100;
     label = 26;
     break L7;
    } else {
     $$0123 = $101;$$4622 = $102;$s$524 = $100;
    }
   }
   $104 = (($96) + -194)|0;
   $105 = ($104>>>0)>(50);
   if ($105) {
    $$444 = $$2;$$842 = $$6;$s$1046 = $s$7;
    label = 48;
    break;
   }
   $106 = (($s$7) + 1|0);
   $107 = (3104712 + ($104<<2)|0);
   $108 = HEAP32[$107>>2]|0;
   $$3 = $$2;$$7 = $$6;$c$4 = $108;$s$8 = $106;
   label = 37;
   continue;
  }
  else if ((label|0) == 7) {
   label = 0;
   $7 = HEAP8[$s$0>>0]|0;
   $8 = $7&255;
   $9 = (($8) + -1)|0;
   $10 = ($9>>>0)<(127);
   if ($10) {
    $11 = $s$0;
    $12 = $11 & 3;
    $13 = ($12|0)==(0);
    if ($13) {
     $14 = HEAP32[$s$0>>2]|0;
     $15 = (($14) + -16843009)|0;
     $16 = $15 | $14;
     $17 = $16 & -2139062144;
     $18 = ($17|0)==(0);
     if ($18) {
      $$137 = $$02;$s$18 = $s$0;
      while(1) {
       $19 = (($s$18) + 4|0);
       $20 = (($$137) + -4)|0;
       $21 = HEAP32[$19>>2]|0;
       $22 = (($21) + -16843009)|0;
       $23 = $22 | $21;
       $24 = $23 & -2139062144;
       $25 = ($24|0)==(0);
       if ($25) {
        $$137 = $20;$s$18 = $19;
       } else {
        $$13$lcssa = $20;$$in = $21;$s$1$lcssa = $19;
        break;
       }
      }
     } else {
      $$13$lcssa = $$02;$$in = $14;$s$1$lcssa = $s$0;
     }
     $26 = $$in&255;
     $$24 = $$13$lcssa;$28 = $26;$s$2 = $s$1$lcssa;
    } else {
     $$24 = $$02;$28 = $7;$s$2 = $s$0;
    }
   } else {
    $$24 = $$02;$28 = $7;$s$2 = $s$0;
   }
   $27 = $28&255;
   $29 = (($27) + -1)|0;
   $30 = ($29>>>0)<(127);
   if ($30) {
    $31 = (($s$2) + 1|0);
    $32 = (($$24) + -1)|0;
    $$02 = $32;$s$0 = $31;
    label = 7;
    continue;
   }
   $33 = (($27) + -194)|0;
   $34 = ($33>>>0)>(50);
   if ($34) {
    $$444 = $ws;$$842 = $$24;$s$1046 = $s$2;
    label = 48;
    break;
   }
   $35 = (($s$2) + 1|0);
   $36 = (3104712 + ($33<<2)|0);
   $37 = HEAP32[$36>>2]|0;
   $$35 = $$24;$c$2 = $37;$s$3 = $35;
   label = 16;
   continue;
  }
  else if ((label|0) == 16) {
   label = 0;
   $38 = HEAP8[$s$3>>0]|0;
   $39 = $38&255;
   $40 = $39 >>> 3;
   $41 = (($40) + -16)|0;
   $42 = $c$2 >> 26;
   $43 = (($40) + ($42))|0;
   $44 = $41 | $43;
   $45 = ($44>>>0)>(7);
   if ($45) {
    label = 17;
    break;
   }
   $47 = (($s$3) + 1|0);
   $48 = $c$2 & 33554432;
   $49 = ($48|0)==(0);
   if ($49) {
    $s$4 = $47;
   } else {
    $50 = HEAP8[$47>>0]|0;
    $51 = $50&255;
    $52 = (($51) + -128)|0;
    $53 = ($52>>>0)>(63);
    if ($53) {
     label = 20;
     break;
    }
    $55 = (($s$3) + 2|0);
    $56 = $c$2 & 524288;
    $57 = ($56|0)==(0);
    if ($57) {
     $s$4 = $55;
    } else {
     $58 = HEAP8[$55>>0]|0;
     $59 = $58&255;
     $60 = (($59) + -128)|0;
     $61 = ($60>>>0)>(63);
     if ($61) {
      label = 23;
      break;
     }
     $63 = (($s$3) + 3|0);
     $s$4 = $63;
    }
   }
   $64 = (($$35) + -1)|0;
   $$02 = $64;$s$0 = $s$4;
   label = 7;
   continue;
  }
  else if ((label|0) == 37) {
   label = 0;
   $109 = HEAP8[$s$8>>0]|0;
   $110 = $109&255;
   $111 = $110 >>> 3;
   $112 = (($111) + -16)|0;
   $113 = $c$4 >> 26;
   $114 = (($111) + ($113))|0;
   $115 = $112 | $114;
   $116 = ($115>>>0)>(7);
   if ($116) {
    label = 38;
    break;
   }
   $118 = $c$4 << 6;
   $119 = (($s$8) + 1|0);
   $120 = (($110) + -128)|0;
   $121 = $120 | $118;
   $122 = ($121|0)<(0);
   if ($122) {
    $123 = HEAP8[$119>>0]|0;
    $124 = $123&255;
    $125 = (($124) + -128)|0;
    $126 = ($125>>>0)>(63);
    if ($126) {
     label = 41;
     break;
    }
    $128 = $121 << 6;
    $129 = (($s$8) + 2|0);
    $130 = $125 | $128;
    $131 = ($130|0)<(0);
    if ($131) {
     $132 = HEAP8[$129>>0]|0;
     $133 = $132&255;
     $134 = (($133) + -128)|0;
     $135 = ($134>>>0)>(63);
     if ($135) {
      label = 44;
      break;
     }
     $137 = $130 << 6;
     $138 = (($s$8) + 3|0);
     $139 = $134 | $137;
     $c$5 = $139;$s$9 = $138;
    } else {
     $c$5 = $130;$s$9 = $129;
    }
   } else {
    $c$5 = $121;$s$9 = $119;
   }
   $140 = (($$3) + 4|0);
   HEAP32[$$3>>2] = $c$5;
   $141 = (($$7) + -1)|0;
   $$01$ph = $140;$$46$ph = $141;$s$5$ph = $s$9;
   label = 6;
   continue;
  }
 }
 if ((label|0) == 17) {
  $46 = (($s$3) + -1|0);
  $$4 = $ws;$$8 = $$35;$c$6 = $c$2;$s$10 = $46;
  label = 47;
 }
 else if ((label|0) == 20) {
  $54 = (($s$3) + -1|0);
  $$4 = $ws;$$8 = $$35;$c$6 = $c$2;$s$10 = $54;
  label = 47;
 }
 else if ((label|0) == 23) {
  $62 = (($s$3) + -1|0);
  $$4 = $ws;$$8 = $$35;$c$6 = $c$2;$s$10 = $62;
  label = 47;
 }
 else if ((label|0) == 26) {
  HEAP32[$src>>2] = $s$5$lcssa;
  $$0 = $wn;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 38) {
  $117 = (($s$8) + -1|0);
  $$4 = $$3;$$8 = $$7;$c$6 = $c$4;$s$10 = $117;
  label = 47;
 }
 else if ((label|0) == 41) {
  $127 = (($s$8) + -1|0);
  $$4 = $$3;$$8 = $$7;$c$6 = $121;$s$10 = $127;
  label = 47;
 }
 else if ((label|0) == 44) {
  $136 = (($s$8) + -1|0);
  $$4 = $$3;$$8 = $$7;$c$6 = $130;$s$10 = $136;
  label = 47;
 }
 if ((label|0) == 47) {
  $142 = ($c$6|0)==(0);
  if ($142) {
   $$444 = $$4;$$842 = $$8;$s$1046 = $s$10;
   label = 48;
  } else {
   $$443 = $$4;$s$1045 = $s$10;
  }
 }
 if ((label|0) == 48) {
  $143 = HEAP8[$s$1046>>0]|0;
  $144 = ($143<<24>>24)==(0);
  if ($144) {
   $145 = ($$444|0)==(0|0);
   if (!($145)) {
    HEAP32[$$444>>2] = 0;
    HEAP32[$src>>2] = 0;
   }
   $146 = (($wn) - ($$842))|0;
   $$0 = $146;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$443 = $$444;$s$1045 = $s$1046;
  }
 }
 $147 = (___errno_location()|0);
 HEAP32[$147>>2] = 84;
 $148 = ($$443|0)==(0|0);
 if ($148) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[$src>>2] = $s$1045;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _mbtowc($wc,$src,$n) {
 $wc = $wc|0;
 $src = $src|0;
 $n = $n|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$0>>2] = $wc;
 $1 = ($src|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($n|0)==(0);
 do {
  if (!($2)) {
   $3 = ($wc|0)==(0|0);
   if ($3) {
    HEAP32[$0>>2] = $0;
    $7 = $0;
   } else {
    $7 = $wc;
   }
   $4 = HEAP8[$src>>0]|0;
   $5 = $4&255;
   $6 = ($4<<24>>24)>(-1);
   if ($6) {
    HEAP32[$7>>2] = $5;
    $8 = ($4<<24>>24)!=(0);
    $9 = $8&1;
    $$0 = $9;
    STACKTOP = sp;return ($$0|0);
   }
   $10 = (($5) + -194)|0;
   $11 = ($10>>>0)>(50);
   if (!($11)) {
    $12 = (($src) + 1|0);
    $13 = (3104712 + ($10<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($n>>>0)<(4);
    if ($15) {
     $16 = ($n*6)|0;
     $17 = (($16) + -6)|0;
     $18 = -2147483648 >>> $17;
     $19 = $14 & $18;
     $20 = ($19|0)==(0);
     if (!($20)) {
      break;
     }
    }
    $21 = HEAP8[$12>>0]|0;
    $22 = $21&255;
    $23 = $22 >>> 3;
    $24 = (($23) + -16)|0;
    $25 = $14 >> 26;
    $26 = (($23) + ($25))|0;
    $27 = $24 | $26;
    $28 = ($27>>>0)>(7);
    if (!($28)) {
     $29 = $14 << 6;
     $30 = (($22) + -128)|0;
     $31 = $30 | $29;
     $32 = ($31|0)<(0);
     if (!($32)) {
      HEAP32[$7>>2] = $31;
      $$0 = 2;
      STACKTOP = sp;return ($$0|0);
     }
     $33 = (($src) + 2|0);
     $34 = HEAP8[$33>>0]|0;
     $35 = $34&255;
     $36 = (($35) + -128)|0;
     $37 = ($36>>>0)>(63);
     if (!($37)) {
      $38 = $31 << 6;
      $39 = $36 | $38;
      $40 = ($39|0)<(0);
      if (!($40)) {
       HEAP32[$7>>2] = $39;
       $$0 = 3;
       STACKTOP = sp;return ($$0|0);
      }
      $41 = (($src) + 3|0);
      $42 = HEAP8[$41>>0]|0;
      $43 = $42&255;
      $44 = (($43) + -128)|0;
      $45 = ($44>>>0)>(63);
      if (!($45)) {
       $46 = $39 << 6;
       $47 = $44 | $46;
       HEAP32[$7>>2] = $47;
       $$0 = 4;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
 } while(0);
 $48 = (___errno_location()|0);
 HEAP32[$48>>2] = 84;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _wcsnrtombs($dst,$wcs,$wn,$n,$st) {
 $dst = $dst|0;
 $wcs = $wcs|0;
 $wn = $wn|0;
 $n = $n|0;
 $st = $st|0;
 var $$026 = 0, $$04$$0 = 0, $$0423 = 0, $$1 = 0, $$15 = 0, $$214 = 0, $$26 = 0, $$311 = 0, $$pr$pre = 0, $$pr41 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $cnt$024 = 0, $cnt$1 = 0, $cnt$212 = 0, $cnt$3 = 0, $dst$ = 0, $n$ = 0, $or$cond = 0, $or$cond22 = 0, $or$cond7 = 0, $or$cond8 = 0, $or$cond810 = 0, $s$018 = 0, $s$025 = 0, $s$1 = 0;
 var $s$213 = 0, $ws = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $buf = sp + 8|0;
 $ws = sp;
 $0 = HEAP32[$wcs>>2]|0;
 HEAP32[$ws>>2] = $0;
 $1 = ($dst|0)!=(0|0);
 $n$ = $1 ? $n : 256;
 $dst$ = $1 ? $dst : $buf;
 $2 = ($0|0)==(0|0);
 $3 = ($n$|0)==(0);
 $or$cond22 = $2 | $3;
 L1: do {
  if ($or$cond22) {
   $$1 = $wn;$$26 = $n$;$17 = $0;$cnt$1 = 0;$s$018 = $dst$;
  } else {
   $$026 = $wn;$$0423 = $n$;$$pr41 = $0;$cnt$024 = 0;$s$025 = $dst$;
   while(1) {
    $4 = ($$026>>>0)>=($$0423>>>0);
    $5 = ($$026>>>0)>(32);
    $or$cond7 = $4 | $5;
    if (!($or$cond7)) {
     $$1 = $$026;$$26 = $$0423;$17 = $$pr41;$cnt$1 = $cnt$024;$s$018 = $s$025;
     break L1;
    }
    $$04$$0 = $4 ? $$0423 : $$026;
    $6 = (($$026) - ($$04$$0))|0;
    $7 = (_wcsrtombs($s$025,$ws,$$04$$0,0)|0);
    $8 = ($7|0)==(-1);
    if ($8) {
     break;
    }
    $9 = ($s$025|0)==($buf|0);
    if ($9) {
     $$15 = $$0423;$s$1 = $buf;
    } else {
     $10 = (($s$025) + ($7)|0);
     $11 = (($$0423) - ($7))|0;
     $$15 = $11;$s$1 = $10;
    }
    $12 = (($7) + ($cnt$024))|0;
    $13 = HEAP32[$ws>>2]|0;
    $14 = ($13|0)==(0|0);
    $15 = ($$15|0)==(0);
    $or$cond = $14 | $15;
    if ($or$cond) {
     $$1 = $6;$$26 = $$15;$17 = $13;$cnt$1 = $12;$s$018 = $s$1;
     break L1;
    } else {
     $$026 = $6;$$0423 = $$15;$$pr41 = $13;$cnt$024 = $12;$s$025 = $s$1;
    }
   }
   $$pr$pre = HEAP32[$ws>>2]|0;
   $$1 = $6;$$26 = 0;$17 = $$pr$pre;$cnt$1 = -1;$s$018 = $s$025;
  }
 } while(0);
 $16 = ($17|0)==(0|0);
 L11: do {
  if ($16) {
   $cnt$3 = $cnt$1;
  } else {
   $18 = ($$26|0)==(0);
   $19 = ($$1|0)==(0);
   $or$cond810 = $18 | $19;
   if ($or$cond810) {
    $cnt$3 = $cnt$1;
   } else {
    $$214 = $$1;$$311 = $$26;$21 = $17;$cnt$212 = $cnt$1;$s$213 = $s$018;
    while(1) {
     $20 = HEAP32[$21>>2]|0;
     $22 = (_wcrtomb($s$213,$20,0)|0);
     $23 = (($22) + 1)|0;
     $24 = ($23>>>0)<(2);
     if ($24) {
      break;
     }
     $26 = HEAP32[$ws>>2]|0;
     $27 = (($26) + 4|0);
     HEAP32[$ws>>2] = $27;
     $28 = (($$214) + -1)|0;
     $29 = (($s$213) + ($22)|0);
     $30 = (($$311) - ($22))|0;
     $31 = (($cnt$212) + 1)|0;
     $32 = ($$311|0)==($22|0);
     $33 = ($28|0)==(0);
     $or$cond8 = $32 | $33;
     if ($or$cond8) {
      $cnt$3 = $31;
      break L11;
     } else {
      $$214 = $28;$$311 = $30;$21 = $27;$cnt$212 = $31;$s$213 = $29;
     }
    }
    $25 = ($22|0)==(0);
    if ($25) {
     HEAP32[$ws>>2] = 0;
     $cnt$3 = $cnt$212;
    } else {
     $cnt$3 = -1;
    }
   }
  }
 } while(0);
 if (!($1)) {
  STACKTOP = sp;return ($cnt$3|0);
 }
 $34 = HEAP32[$ws>>2]|0;
 HEAP32[$wcs>>2] = $34;
 STACKTOP = sp;return ($cnt$3|0);
}
function _wcsrtombs($s,$ws,$n,$st) {
 $s = $s|0;
 $ws = $ws|0;
 $n = $n|0;
 $st = $st|0;
 var $$0 = 0, $$01$lcssa = 0, $$0125 = 0, $$026 = 0, $$1 = 0, $$13 = 0, $$215 = 0, $$24$lcssa = 0, $$2424 = 0, $$3 = 0, $$35 = 0, $$414 = 0, $$5 = 0, $$pn = 0, $$pre = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $ws2$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $buf = sp;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $2 = HEAP32[$ws>>2]|0;
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0);
  if ($4) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$026 = 0;$6 = $3;$ws2$07 = $2;
  }
  while(1) {
   $5 = ($6>>>0)>(127);
   if ($5) {
    $7 = (_wcrtomb($buf,$6,0)|0);
    $8 = ($7|0)==(-1);
    if ($8) {
     $$0 = -1;
     label = 26;
     break;
    } else {
     $$pn = $7;
    }
   } else {
    $$pn = 1;
   }
   $$13 = (($$pn) + ($$026))|0;
   $9 = (($ws2$07) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = ($10|0)==(0);
   if ($11) {
    $$0 = $$13;
    label = 26;
    break;
   } else {
    $$026 = $$13;$6 = $10;$ws2$07 = $9;
   }
  }
  if ((label|0) == 26) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 $1 = ($n>>>0)>(3);
 L14: do {
  if ($1) {
   $$pre40 = HEAP32[$ws>>2]|0;
   $$0125 = $s;$$2424 = $n;$14 = $$pre40;
   while(1) {
    $13 = HEAP32[$14>>2]|0;
    $15 = (($13) + -1)|0;
    $16 = ($15>>>0)>(126);
    if ($16) {
     $17 = ($13|0)==(0);
     if ($17) {
      break;
     }
     $19 = (_wcrtomb($$0125,$13,0)|0);
     $20 = ($19|0)==(-1);
     if ($20) {
      $$0 = -1;
      label = 26;
      break;
     }
     $21 = (($$0125) + ($19)|0);
     $22 = (($$2424) - ($19))|0;
     $$1 = $21;$$35 = $22;$27 = $14;
    } else {
     $23 = $13&255;
     $24 = (($$0125) + 1|0);
     HEAP8[$$0125>>0] = $23;
     $25 = (($$2424) + -1)|0;
     $$pre41 = HEAP32[$ws>>2]|0;
     $$1 = $24;$$35 = $25;$27 = $$pre41;
    }
    $26 = (($27) + 4|0);
    HEAP32[$ws>>2] = $26;
    $28 = ($$35>>>0)>(3);
    if ($28) {
     $$0125 = $$1;$$2424 = $$35;$14 = $26;
    } else {
     $$01$lcssa = $$1;$$24$lcssa = $$35;
     break L14;
    }
   }
   if ((label|0) == 26) {
    STACKTOP = sp;return ($$0|0);
   }
   HEAP8[$$0125>>0] = 0;
   HEAP32[$ws>>2] = 0;
   $18 = (($n) - ($$2424))|0;
   $$0 = $18;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$01$lcssa = $s;$$24$lcssa = $n;
  }
 } while(0);
 $12 = ($$24$lcssa|0)==(0);
 if ($12) {
  $$0 = $n;
  STACKTOP = sp;return ($$0|0);
 }
 $$pre = HEAP32[$ws>>2]|0;
 $$215 = $$01$lcssa;$$414 = $$24$lcssa;$30 = $$pre;
 while(1) {
  $29 = HEAP32[$30>>2]|0;
  $31 = (($29) + -1)|0;
  $32 = ($31>>>0)>(126);
  if ($32) {
   $33 = ($29|0)==(0);
   if ($33) {
    label = 19;
    break;
   }
   $35 = (_wcrtomb($buf,$29,0)|0);
   $36 = ($35|0)==(-1);
   if ($36) {
    $$0 = -1;
    label = 26;
    break;
   }
   $37 = ($35>>>0)>($$414>>>0);
   if ($37) {
    label = 22;
    break;
   }
   $39 = HEAP32[$30>>2]|0;
   (_wcrtomb($$215,$39,0)|0);
   $40 = (($$215) + ($35)|0);
   $41 = (($$414) - ($35))|0;
   $$3 = $40;$$5 = $41;$46 = $30;
  } else {
   $42 = $29&255;
   $43 = (($$215) + 1|0);
   HEAP8[$$215>>0] = $42;
   $44 = (($$414) + -1)|0;
   $$pre39 = HEAP32[$ws>>2]|0;
   $$3 = $43;$$5 = $44;$46 = $$pre39;
  }
  $45 = (($46) + 4|0);
  HEAP32[$ws>>2] = $45;
  $47 = ($$5|0)==(0);
  if ($47) {
   $$0 = $n;
   label = 26;
   break;
  } else {
   $$215 = $$3;$$414 = $$5;$30 = $45;
  }
 }
 if ((label|0) == 19) {
  HEAP8[$$215>>0] = 0;
  HEAP32[$ws>>2] = 0;
  $34 = (($n) - ($$414))|0;
  $$0 = $34;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 22) {
  $38 = (($n) - ($$414))|0;
  $$0 = $38;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 26) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function ___string_read($f,$buf,$len) {
 $f = $f|0;
 $buf = $buf|0;
 $len = $len|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $k$0 = 0, $k$0$len = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($len) + 256)|0;
 $3 = (_memchr($1,0,$2)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $k$0 = $2;
 } else {
  $5 = $3;
  $6 = $1;
  $7 = (($5) - ($6))|0;
  $k$0 = $7;
 }
 $8 = ($k$0>>>0)<($len>>>0);
 $k$0$len = $8 ? $k$0 : $len;
 _memcpy(($buf|0),($1|0),($k$0$len|0))|0;
 $9 = (($1) + ($k$0$len)|0);
 $10 = (($f) + 4|0);
 HEAP32[$10>>2] = $9;
 $11 = (($1) + ($k$0)|0);
 $12 = (($f) + 8|0);
 HEAP32[$12>>2] = $11;
 HEAP32[$0>>2] = $11;
 STACKTOP = sp;return ($k$0$len|0);
}
function _sscanf($s,$fmt,$varargs) {
 $s = $s|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsscanf($s,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _vasprintf($s,$fmt,$ap) {
 $s = $s|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ap2 = 0, $vacopy_currentptr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ap2 = sp;
 $0 = (_malloc(240)|0);
 $1 = ($0|0)==(0|0);
 do {
  if ($1) {
   $$0 = -1;
  } else {
   $vacopy_currentptr = HEAP32[$ap>>2]|0;
   HEAP32[$ap2>>2] = $vacopy_currentptr;
   $2 = (_vsnprintf($0,240,$fmt,$ap2)|0);
   $3 = ($2>>>0)<(240);
   if ($3) {
    $4 = (($2) + 1)|0;
    $5 = (_realloc($0,$4)|0);
    $6 = ($5|0)!=(0|0);
    $7 = $6 ? $5 : $0;
    HEAP32[$s>>2] = $7;
    $$0 = $2;
    break;
   }
   _free($0);
   $8 = ($2|0)<(0);
   if ($8) {
    $$0 = -1;
   } else {
    $9 = (($2) + 1)|0;
    $10 = (_malloc($9)|0);
    HEAP32[$s>>2] = $10;
    $11 = ($10|0)==(0|0);
    if ($11) {
     $$0 = -1;
    } else {
     $12 = (_vsnprintf($10,$9,$fmt,$ap)|0);
     $$0 = $12;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _MUSL_vfscanf($f,$fmt,$ap) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$ = 0, $$10 = 0, $$4 = 0, $$7 = 0, $$8 = 0, $$9 = 0, $$lcssa18 = 0, $$matches$0 = 0, $$not = 0, $$pre = 0, $$pre$phi241Z2D = 0, $$pre221 = 0, $$pre234 = 0, $$pre235 = 0, $$pre236 = 0, $$pre237 = 0, $$pre238 = 0, $$pre239 = 0, $$pre240 = 0, $$size$0 = 0;
 var $$width$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0;
 var $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0.0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = Math_fround(0), $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alloc$0 = 0, $alloc$1 = 0, $alloc$2 = 0, $ap2$i = 0, $arglist_current = 0, $arglist_current2 = 0, $arglist_next = 0, $arglist_next3 = 0, $base$0 = 0, $c$027 = 0, $dest$0 = 0, $factor = 0;
 var $factor14 = 0, $i$0$i = 0, $i$0$ph = 0, $i$0$ph46 = 0, $i$0$ph46$lcssa = 0, $i$0$ph46$us53 = 0, $i$1$lcssa = 0, $i$2 = 0, $i$2$ph = 0, $i$2$ph$phi = 0, $i$3 = 0, $i$4 = 0, $invert$0 = 0, $isdigit = 0, $isdigit3 = 0, $isdigit320 = 0, $isdigittmp = 0, $isdigittmp2 = 0, $isdigittmp219 = 0, $k$0$ph = 0;
 var $k$1$ph = 0, $matches$0$ = 0, $matches$0130 = 0, $matches$1 = 0, $matches$2 = 0, $matches$3 = 0, $not$ = 0, $or$cond$us = 0, $or$cond5 = 0, $or$cond6 = 0, $p$0136 = 0, $p$1 = 0, $p$10 = 0, $p$11 = 0, $p$2 = 0, $p$3$lcssa = 0, $p$321 = 0, $p$4 = 0, $p$5 = 0, $p$6 = 0;
 var $p$7 = 0, $p$7$ph = 0, $p$8 = 0, $p$9 = 0, $pos$0135 = 0, $pos$1 = 0, $pos$2 = 0, $s$0128 = 0, $s$1 = 0, $s$2$ph = 0, $s$3 = 0, $s$4 = 0, $s$5 = 0, $s$6 = 0, $s$7 = 0, $scanset = 0, $size$0 = 0, $st = 0, $vacopy_currentptr = 0, $wc = 0;
 var $wcs$0129 = 0, $wcs$1 = 0, $wcs$2 = 0, $wcs$3$ph = 0, $wcs$3$ph160 = 0, $wcs$4 = 0, $wcs$5 = 0, $wcs$6 = 0, $wcs$7 = 0, $wcs$8 = 0, $width$0$lcssa = 0, $width$022 = 0, $width$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0;
 $ap2$i = sp + 16|0;
 $st = sp;
 $scanset = sp + 33|0;
 $wc = sp + 8|0;
 $0 = sp + 32|0;
 $1 = HEAP8[$fmt>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $matches$3 = 0;
  STACKTOP = sp;return ($matches$3|0);
 }
 $3 = (($f) + 4|0);
 $4 = (($f) + 100|0);
 $5 = (($f) + 108|0);
 $6 = (($f) + 8|0);
 $7 = (($scanset) + 10|0);
 $8 = (($scanset) + 33|0);
 $9 = (($st) + 4|0);
 $10 = (($scanset) + 46|0);
 $11 = (($scanset) + 94|0);
 $13 = $1;$matches$0130 = 0;$p$0136 = $fmt;$pos$0135 = 0;$s$0128 = 0;$wcs$0129 = 0;
 L4: while(1) {
  $12 = $13&255;
  $14 = (_isspace($12)|0);
  $15 = ($14|0)==(0);
  L6: do {
   if ($15) {
    $42 = HEAP8[$p$0136>>0]|0;
    $43 = ($42<<24>>24)==(37);
    L21: do {
     if ($43) {
      $44 = (($p$0136) + 1|0);
      $45 = HEAP8[$44>>0]|0;
      do {
       if ((($45<<24>>24) == 42)) {
        $65 = (($p$0136) + 2|0);
        $dest$0 = 0;$p$2 = $65;
       } else if ((($45<<24>>24) == 37)) {
        break L21;
       } else {
        $66 = $45&255;
        $isdigittmp = (($66) + -48)|0;
        $isdigit = ($isdigittmp>>>0)<(10);
        if ($isdigit) {
         $67 = (($p$0136) + 2|0);
         $68 = HEAP8[$67>>0]|0;
         $69 = ($68<<24>>24)==(36);
         if ($69) {
          $vacopy_currentptr = HEAP32[$ap>>2]|0;
          HEAP32[$ap2$i>>2] = $vacopy_currentptr;
          $i$0$i = $isdigittmp;
          while(1) {
           $70 = ($i$0$i>>>0)>(1);
           $arglist_current = HEAP32[$ap2$i>>2]|0;
           $71 = HEAP32[$arglist_current>>2]|0;
           $arglist_next = (($arglist_current) + 4|0);
           HEAP32[$ap2$i>>2] = $arglist_next;
           $72 = (($i$0$i) + -1)|0;
           if ($70) {
            $i$0$i = $72;
           } else {
            break;
           }
          }
          $73 = (($p$0136) + 3|0);
          $dest$0 = $71;$p$2 = $73;
          break;
         }
        }
        $arglist_current2 = HEAP32[$ap>>2]|0;
        $74 = HEAP32[$arglist_current2>>2]|0;
        $arglist_next3 = (($arglist_current2) + 4|0);
        HEAP32[$ap>>2] = $arglist_next3;
        $dest$0 = $74;$p$2 = $44;
       }
      } while(0);
      $75 = HEAP8[$p$2>>0]|0;
      $76 = $75&255;
      $isdigittmp219 = (($76) + -48)|0;
      $isdigit320 = ($isdigittmp219>>>0)<(10);
      if ($isdigit320) {
       $80 = $76;$p$321 = $p$2;$width$022 = 0;
       while(1) {
        $77 = ($width$022*10)|0;
        $78 = (($77) + -48)|0;
        $79 = (($78) + ($80))|0;
        $81 = (($p$321) + 1|0);
        $82 = HEAP8[$81>>0]|0;
        $83 = $82&255;
        $isdigittmp2 = (($83) + -48)|0;
        $isdigit3 = ($isdigittmp2>>>0)<(10);
        if ($isdigit3) {
         $80 = $83;$p$321 = $81;$width$022 = $79;
        } else {
         $$lcssa18 = $82;$p$3$lcssa = $81;$width$0$lcssa = $79;
         break;
        }
       }
      } else {
       $$lcssa18 = $75;$p$3$lcssa = $p$2;$width$0$lcssa = 0;
      }
      $84 = ($$lcssa18<<24>>24)==(109);
      if ($84) {
       $85 = ($dest$0|0)!=(0|0);
       $86 = $85&1;
       $87 = (($p$3$lcssa) + 1|0);
       $$pre = HEAP8[$87>>0]|0;
       $90 = $$pre;$alloc$0 = $86;$p$4 = $87;$s$1 = 0;$wcs$1 = 0;
      } else {
       $90 = $$lcssa18;$alloc$0 = 0;$p$4 = $p$3$lcssa;$s$1 = $s$0128;$wcs$1 = $wcs$0129;
      }
      $88 = (($p$4) + 1|0);
      $89 = $90&255;
      switch ($89|0) {
      case 104:  {
       $91 = HEAP8[$88>>0]|0;
       $92 = ($91<<24>>24)==(104);
       $93 = (($p$4) + 2|0);
       $$7 = $92 ? $93 : $88;
       $$8 = $92 ? -2 : -1;
       $p$5 = $$7;$size$0 = $$8;
       break;
      }
      case 116: case 122:  {
       $p$5 = $88;$size$0 = 1;
       break;
      }
      case 110: case 112: case 67: case 83: case 91: case 99: case 115: case 88: case 71: case 70: case 69: case 65: case 103: case 102: case 101: case 97: case 120: case 117: case 111: case 105: case 100:  {
       $p$5 = $p$4;$size$0 = 0;
       break;
      }
      case 106:  {
       $p$5 = $88;$size$0 = 3;
       break;
      }
      case 76:  {
       $p$5 = $88;$size$0 = 2;
       break;
      }
      case 108:  {
       $94 = HEAP8[$88>>0]|0;
       $95 = ($94<<24>>24)==(108);
       $96 = (($p$4) + 2|0);
       $$9 = $95 ? $96 : $88;
       $$10 = $95 ? 3 : 1;
       $p$5 = $$9;$size$0 = $$10;
       break;
      }
      default: {
       $alloc$1 = $alloc$0;$s$6 = $s$1;$wcs$7 = $wcs$1;
       label = 162;
       break L4;
      }
      }
      $97 = HEAP8[$p$5>>0]|0;
      $98 = $97&255;
      $99 = $98 & 47;
      $100 = ($99|0)==(3);
      $101 = $98 | 32;
      $$ = $100 ? $101 : $98;
      $$size$0 = $100 ? 1 : $size$0;
      if ((($$|0) == 110)) {
       $103 = ($pos$0135|0)<(0);
       $104 = $103 << 31 >> 31;
       $105 = ($dest$0|0)==(0|0);
       if ($105) {
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
       }
       switch ($$size$0|0) {
       case -1:  {
        $107 = $pos$0135&65535;
        HEAP16[$dest$0>>1] = $107;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       case -2:  {
        $106 = $pos$0135&255;
        HEAP8[$dest$0>>0] = $106;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       case 0:  {
        HEAP32[$dest$0>>2] = $pos$0135;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       case 1:  {
        HEAP32[$dest$0>>2] = $pos$0135;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       case 3:  {
        $108 = $dest$0;
        $109 = $108;
        HEAP32[$109>>2] = $pos$0135;
        $110 = (($108) + 4)|0;
        $111 = $110;
        HEAP32[$111>>2] = $104;
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
        break;
       }
       default: {
        $matches$1 = $matches$0130;$p$11 = $p$5;$pos$2 = $pos$0135;$s$5 = $s$1;$wcs$6 = $wcs$1;
        break L6;
       }
       }
      } else if ((($$|0) == 99)) {
       $102 = ($width$0$lcssa|0)<(1);
       $$width$0 = $102 ? 1 : $width$0$lcssa;
       $pos$1 = $pos$0135;$width$1 = $$width$0;
      } else if ((($$|0) == 91)) {
       $pos$1 = $pos$0135;$width$1 = $width$0$lcssa;
      } else {
       ___shlim($f,0);
       while(1) {
        $112 = HEAP32[$3>>2]|0;
        $113 = HEAP32[$4>>2]|0;
        $114 = ($112>>>0)<($113>>>0);
        if ($114) {
         $115 = (($112) + 1|0);
         HEAP32[$3>>2] = $115;
         $116 = HEAP8[$112>>0]|0;
         $117 = $116&255;
         $119 = $117;
        } else {
         $118 = (___shgetc($f)|0);
         $119 = $118;
        }
        $120 = (_isspace($119)|0);
        $121 = ($120|0)==(0);
        if ($121) {
         break;
        }
       }
       $122 = HEAP32[$4>>2]|0;
       $123 = ($122|0)==(0|0);
       $$pre234 = HEAP32[$3>>2]|0;
       if ($123) {
        $128 = $$pre234;
       } else {
        $124 = (($$pre234) + -1|0);
        HEAP32[$3>>2] = $124;
        $128 = $124;
       }
       $125 = HEAP32[$5>>2]|0;
       $126 = HEAP32[$6>>2]|0;
       $127 = $128;
       $129 = $126;
       $130 = (($125) + ($pos$0135))|0;
       $131 = (($130) + ($127))|0;
       $132 = (($131) - ($129))|0;
       $pos$1 = $132;$width$1 = $width$0$lcssa;
      }
      ___shlim($f,$width$1);
      $133 = HEAP32[$3>>2]|0;
      $134 = HEAP32[$4>>2]|0;
      $135 = ($133>>>0)<($134>>>0);
      if ($135) {
       $136 = (($133) + 1|0);
       HEAP32[$3>>2] = $136;
       $140 = $134;
      } else {
       $137 = (___shgetc($f)|0);
       $138 = ($137|0)<(0);
       if ($138) {
        $alloc$1 = $alloc$0;$s$6 = $s$1;$wcs$7 = $wcs$1;
        label = 162;
        break L4;
       }
       $$pre235 = HEAP32[$4>>2]|0;
       $140 = $$pre235;
      }
      $139 = ($140|0)==(0|0);
      if (!($139)) {
       $141 = HEAP32[$3>>2]|0;
       $142 = (($141) + -1|0);
       HEAP32[$3>>2] = $142;
      }
      L78: do {
       switch ($$|0) {
       case 111:  {
        $base$0 = 8;
        label = 144;
        break;
       }
       case 117: case 100:  {
        $base$0 = 10;
        label = 144;
        break;
       }
       case 105:  {
        $base$0 = 0;
        label = 144;
        break;
       }
       case 120: case 88: case 112:  {
        $base$0 = 16;
        label = 144;
        break;
       }
       case 71: case 103: case 70: case 102: case 69: case 101: case 65: case 97:  {
        $322 = (+___floatscan($f,$$size$0,0));
        $323 = HEAP32[$5>>2]|0;
        $324 = HEAP32[$3>>2]|0;
        $325 = HEAP32[$6>>2]|0;
        $326 = $324;
        $327 = $325;
        $328 = (($327) - ($326))|0;
        $329 = ($323|0)==($328|0);
        if ($329) {
         $alloc$2 = $alloc$0;$matches$2 = $matches$0130;$s$7 = $s$1;$wcs$8 = $wcs$1;
         break L4;
        }
        $330 = ($dest$0|0)==(0|0);
        if ($330) {
         $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
        } else {
         if ((($$size$0|0) == 1)) {
          HEAPF64[$dest$0>>3] = $322;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L78;
         } else if ((($$size$0|0) == 0)) {
          $331 = Math_fround($322);
          HEAPF32[$dest$0>>2] = $331;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L78;
         } else if ((($$size$0|0) == 2)) {
          HEAPF64[$dest$0>>3] = $322;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L78;
         } else {
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L78;
         }
        }
        break;
       }
       case 91: case 99: case 115:  {
        $143 = ($$|0)==(99);
        $144 = $$ & 239;
        $145 = ($144|0)==(99);
        L90: do {
         if ($145) {
          $146 = ($$|0)==(115);
          _memset(($scanset|0),-1,257)|0;
          HEAP8[$scanset>>0] = 0;
          if ($146) {
           HEAP8[$8>>0] = 0;
           ;HEAP8[$7+0>>0]=0|0;HEAP8[$7+1>>0]=0|0;HEAP8[$7+2>>0]=0|0;HEAP8[$7+3>>0]=0|0;HEAP8[$7+4>>0]=0|0;
           $p$9 = $p$5;
          } else {
           $p$9 = $p$5;
          }
         } else {
          $147 = (($p$5) + 1|0);
          $148 = HEAP8[$147>>0]|0;
          $149 = ($148<<24>>24)==(94);
          $150 = (($p$5) + 2|0);
          $invert$0 = $149&1;
          $p$6 = $149 ? $150 : $147;
          $151 = $149&1;
          _memset(($scanset|0),($151|0),257)|0;
          HEAP8[$scanset>>0] = 0;
          $152 = HEAP8[$p$6>>0]|0;
          if ((($152<<24>>24) == 93)) {
           $156 = (($p$6) + 1|0);
           $157 = $invert$0 ^ 1;
           $158 = $157&255;
           HEAP8[$11>>0] = $158;
           $$pre$phi241Z2D = $158;$p$7$ph = $156;
          } else if ((($152<<24>>24) == 45)) {
           $153 = (($p$6) + 1|0);
           $154 = $invert$0 ^ 1;
           $155 = $154&255;
           HEAP8[$10>>0] = $155;
           $$pre$phi241Z2D = $155;$p$7$ph = $153;
          } else {
           $$pre239 = $invert$0 ^ 1;
           $$pre240 = $$pre239&255;
           $$pre$phi241Z2D = $$pre240;$p$7$ph = $p$6;
          }
          $p$7 = $p$7$ph;
          while(1) {
           $159 = HEAP8[$p$7>>0]|0;
           if ((($159<<24>>24) == 0)) {
            $alloc$1 = $alloc$0;$s$6 = $s$1;$wcs$7 = $wcs$1;
            label = 162;
            break L4;
           } else if ((($159<<24>>24) == 45)) {
            $160 = (($p$7) + 1|0);
            $161 = HEAP8[$160>>0]|0;
            if ((($161<<24>>24) == 93) | (($161<<24>>24) == 0)) {
             $172 = 45;$p$8 = $p$7;
            } else {
             $162 = (($p$7) + -1|0);
             $163 = HEAP8[$162>>0]|0;
             $164 = ($163&255)<($161&255);
             if ($164) {
              $165 = $163&255;
              $c$027 = $165;
              while(1) {
               $166 = (($c$027) + 1)|0;
               $167 = (($scanset) + ($166)|0);
               HEAP8[$167>>0] = $$pre$phi241Z2D;
               $168 = HEAP8[$160>>0]|0;
               $169 = $168&255;
               $170 = ($166|0)<($169|0);
               if ($170) {
                $c$027 = $166;
               } else {
                $172 = $168;$p$8 = $160;
                break;
               }
              }
             } else {
              $172 = $161;$p$8 = $160;
             }
            }
           } else if ((($159<<24>>24) == 93)) {
            $p$9 = $p$7;
            break L90;
           } else {
            $172 = $159;$p$8 = $p$7;
           }
           $171 = $172&255;
           $173 = (($171) + 1)|0;
           $174 = (($scanset) + ($173)|0);
           HEAP8[$174>>0] = $$pre$phi241Z2D;
           $175 = (($p$8) + 1|0);
           $p$7 = $175;
          }
         }
        } while(0);
        $176 = (($width$1) + 1)|0;
        $$4 = $143 ? $176 : 31;
        $177 = ($$size$0|0)==(1);
        $178 = ($alloc$0|0)!=(0);
        L109: do {
         if ($177) {
          if ($178) {
           $179 = $$4 << 2;
           $180 = (_malloc($179)|0);
           $181 = ($180|0)==(0|0);
           if ($181) {
            $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = $180;
            label = 162;
            break L4;
           } else {
            $wcs$2 = $180;
           }
          } else {
           $wcs$2 = $dest$0;
          }
          HEAP32[$st>>2] = 0;
          HEAP32[$9>>2] = 0;
          $i$0$ph = 0;$k$0$ph = $$4;$wcs$3$ph = $wcs$2;
          L144: while(1) {
           $182 = ($wcs$3$ph|0)==(0|0);
           if ($182) {
            while(1) {
             $185 = HEAP32[$3>>2]|0;
             $196 = HEAP32[$4>>2]|0;
             $197 = ($185>>>0)<($196>>>0);
             if ($197) {
              $184 = (($185) + 1|0);
              HEAP32[$3>>2] = $184;
              $186 = HEAP8[$185>>0]|0;
              $187 = $186&255;
              $189 = $187;
             } else {
              $183 = (___shgetc($f)|0);
              $189 = $183;
             }
             $188 = (($189) + 1)|0;
             $190 = (($scanset) + ($188)|0);
             $191 = HEAP8[$190>>0]|0;
             $192 = ($191<<24>>24)==(0);
             if ($192) {
              $i$0$ph46$lcssa = $i$0$ph;$wcs$3$ph160 = 0;
              break L144;
             }
             $193 = $189&255;
             HEAP8[$0>>0] = $193;
             $194 = (_mbrtowc($wc,$0,1,$st)|0);
             if ((($194|0) == -1)) {
              $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = 0;
              label = 162;
              break L4;
             } else if ((($194|0) == -2)) {
              continue;
             }
             $195 = ($i$0$ph|0)==($k$0$ph|0);
             $or$cond$us = $178 & $195;
             if ($or$cond$us) {
              $i$1$lcssa = $i$0$ph;
              break;
             }
            }
           } else {
            if ($178) {
             $i$0$ph46$us53 = $i$0$ph;
            } else {
             $i$0$ph46 = $i$0$ph;
             label = 98;
             break;
            }
            while(1) {
             while(1) {
              $200 = HEAP32[$3>>2]|0;
              $214 = HEAP32[$4>>2]|0;
              $215 = ($200>>>0)<($214>>>0);
              if ($215) {
               $199 = (($200) + 1|0);
               HEAP32[$3>>2] = $199;
               $201 = HEAP8[$200>>0]|0;
               $202 = $201&255;
               $204 = $202;
              } else {
               $198 = (___shgetc($f)|0);
               $204 = $198;
              }
              $203 = (($204) + 1)|0;
              $205 = (($scanset) + ($203)|0);
              $206 = HEAP8[$205>>0]|0;
              $207 = ($206<<24>>24)==(0);
              if ($207) {
               $i$0$ph46$lcssa = $i$0$ph46$us53;$wcs$3$ph160 = $wcs$3$ph;
               break L144;
              }
              $208 = $204&255;
              HEAP8[$0>>0] = $208;
              $209 = (_mbrtowc($wc,$0,1,$st)|0);
              if ((($209|0) == -1)) {
               $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = $wcs$3$ph;
               label = 162;
               break L4;
              } else if (!((($209|0) == -2))) {
               break;
              }
             }
             $210 = HEAP32[$wc>>2]|0;
             $211 = (($i$0$ph46$us53) + 1)|0;
             $212 = (($wcs$3$ph) + ($i$0$ph46$us53<<2)|0);
             HEAP32[$212>>2] = $210;
             $213 = ($211|0)==($k$0$ph|0);
             if ($213) {
              $i$1$lcssa = $k$0$ph;
              break;
             } else {
              $i$0$ph46$us53 = $211;
             }
            }
           }
           $factor = $k$0$ph << 1;
           $233 = $factor | 1;
           $234 = $233 << 2;
           $235 = (_realloc($wcs$3$ph,$234)|0);
           $236 = ($235|0)==(0|0);
           if ($236) {
            $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = $wcs$3$ph;
            label = 162;
            break L4;
           }
           $i$0$ph = $i$1$lcssa;$k$0$ph = $233;$wcs$3$ph = $235;
          }
          L168: do {
           if ((label|0) == 98) {
            while(1) {
             label = 0;
             while(1) {
              $216 = HEAP32[$3>>2]|0;
              $217 = HEAP32[$4>>2]|0;
              $218 = ($216>>>0)<($217>>>0);
              if ($218) {
               $219 = (($216) + 1|0);
               HEAP32[$3>>2] = $219;
               $220 = HEAP8[$216>>0]|0;
               $221 = $220&255;
               $224 = $221;
              } else {
               $222 = (___shgetc($f)|0);
               $224 = $222;
              }
              $223 = (($224) + 1)|0;
              $225 = (($scanset) + ($223)|0);
              $226 = HEAP8[$225>>0]|0;
              $227 = ($226<<24>>24)==(0);
              if ($227) {
               $i$0$ph46$lcssa = $i$0$ph46;$wcs$3$ph160 = $wcs$3$ph;
               break L168;
              }
              $228 = $224&255;
              HEAP8[$0>>0] = $228;
              $229 = (_mbrtowc($wc,$0,1,$st)|0);
              if ((($229|0) == -1)) {
               $alloc$1 = 0;$s$6 = 0;$wcs$7 = $wcs$3$ph;
               label = 162;
               break L4;
              } else if (!((($229|0) == -2))) {
               break;
              }
             }
             $230 = HEAP32[$wc>>2]|0;
             $231 = (($i$0$ph46) + 1)|0;
             $232 = (($wcs$3$ph) + ($i$0$ph46<<2)|0);
             HEAP32[$232>>2] = $230;
             $i$0$ph46 = $231;
             label = 98;
            }
           }
          } while(0);
          $237 = (_mbsinit($st)|0);
          $238 = ($237|0)==(0);
          if ($238) {
           $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = $wcs$3$ph160;
           label = 162;
           break L4;
          } else {
           $i$4 = $i$0$ph46$lcssa;$s$3 = 0;$wcs$4 = $wcs$3$ph160;
          }
         } else {
          if ($178) {
           $239 = (_malloc($$4)|0);
           $240 = ($239|0)==(0|0);
           if ($240) {
            $alloc$1 = $alloc$0;$s$6 = 0;$wcs$7 = 0;
            label = 162;
            break L4;
           } else {
            $i$2$ph = 0;$k$1$ph = $$4;$s$2$ph = $239;
           }
           while(1) {
            $i$2 = $i$2$ph;
            while(1) {
             $241 = HEAP32[$3>>2]|0;
             $242 = HEAP32[$4>>2]|0;
             $243 = ($241>>>0)<($242>>>0);
             if ($243) {
              $244 = (($241) + 1|0);
              HEAP32[$3>>2] = $244;
              $245 = HEAP8[$241>>0]|0;
              $246 = $245&255;
              $249 = $246;
             } else {
              $247 = (___shgetc($f)|0);
              $249 = $247;
             }
             $248 = (($249) + 1)|0;
             $250 = (($scanset) + ($248)|0);
             $251 = HEAP8[$250>>0]|0;
             $252 = ($251<<24>>24)==(0);
             if ($252) {
              $i$4 = $i$2;$s$3 = $s$2$ph;$wcs$4 = 0;
              break L109;
             }
             $253 = $249&255;
             $254 = (($i$2) + 1)|0;
             $255 = (($s$2$ph) + ($i$2)|0);
             HEAP8[$255>>0] = $253;
             $256 = ($254|0)==($k$1$ph|0);
             if ($256) {
              break;
             } else {
              $i$2 = $254;
             }
            }
            $factor14 = $k$1$ph << 1;
            $257 = $factor14 | 1;
            $258 = (_realloc($s$2$ph,$257)|0);
            $259 = ($258|0)==(0|0);
            if ($259) {
             $alloc$1 = $alloc$0;$s$6 = $s$2$ph;$wcs$7 = 0;
             label = 162;
             break L4;
            } else {
             $i$2$ph$phi = $k$1$ph;$k$1$ph = $257;$s$2$ph = $258;$i$2$ph = $i$2$ph$phi;
            }
           }
          }
          $260 = ($dest$0|0)==(0|0);
          if ($260) {
           $278 = $140;
           while(1) {
            $276 = HEAP32[$3>>2]|0;
            $277 = ($276>>>0)<($278>>>0);
            if ($277) {
             $279 = (($276) + 1|0);
             HEAP32[$3>>2] = $279;
             $280 = HEAP8[$276>>0]|0;
             $281 = $280&255;
             $284 = $281;
            } else {
             $282 = (___shgetc($f)|0);
             $284 = $282;
            }
            $283 = (($284) + 1)|0;
            $285 = (($scanset) + ($283)|0);
            $286 = HEAP8[$285>>0]|0;
            $287 = ($286<<24>>24)==(0);
            if ($287) {
             $i$4 = 0;$s$3 = 0;$wcs$4 = 0;
             break L109;
            }
            $$pre237 = HEAP32[$4>>2]|0;
            $278 = $$pre237;
           }
          } else {
           $263 = $140;$i$3 = 0;
           while(1) {
            $261 = HEAP32[$3>>2]|0;
            $262 = ($261>>>0)<($263>>>0);
            if ($262) {
             $264 = (($261) + 1|0);
             HEAP32[$3>>2] = $264;
             $265 = HEAP8[$261>>0]|0;
             $266 = $265&255;
             $269 = $266;
            } else {
             $267 = (___shgetc($f)|0);
             $269 = $267;
            }
            $268 = (($269) + 1)|0;
            $270 = (($scanset) + ($268)|0);
            $271 = HEAP8[$270>>0]|0;
            $272 = ($271<<24>>24)==(0);
            if ($272) {
             $i$4 = $i$3;$s$3 = $dest$0;$wcs$4 = 0;
             break L109;
            }
            $273 = $269&255;
            $274 = (($i$3) + 1)|0;
            $275 = (($dest$0) + ($i$3)|0);
            HEAP8[$275>>0] = $273;
            $$pre221 = HEAP32[$4>>2]|0;
            $263 = $$pre221;$i$3 = $274;
           }
          }
         }
        } while(0);
        $288 = HEAP32[$4>>2]|0;
        $289 = ($288|0)==(0|0);
        $$pre236 = HEAP32[$3>>2]|0;
        if ($289) {
         $294 = $$pre236;
        } else {
         $290 = (($$pre236) + -1|0);
         HEAP32[$3>>2] = $290;
         $294 = $290;
        }
        $291 = HEAP32[$5>>2]|0;
        $292 = HEAP32[$6>>2]|0;
        $293 = $294;
        $295 = $292;
        $296 = (($293) - ($295))|0;
        $297 = (($296) + ($291))|0;
        $298 = ($297|0)==(0);
        if ($298) {
         $alloc$2 = $alloc$0;$matches$2 = $matches$0130;$s$7 = $s$3;$wcs$8 = $wcs$4;
         break L4;
        }
        $$not = $143 ^ 1;
        $299 = ($297|0)==($width$1|0);
        $or$cond5 = $299 | $$not;
        if (!($or$cond5)) {
         $alloc$2 = $alloc$0;$matches$2 = $matches$0130;$s$7 = $s$3;$wcs$8 = $wcs$4;
         break L4;
        }
        do {
         if ($178) {
          if ($177) {
           HEAP32[$dest$0>>2] = $wcs$4;
           break;
          } else {
           HEAP32[$dest$0>>2] = $s$3;
           break;
          }
         }
        } while(0);
        if ($143) {
         $p$10 = $p$9;$s$4 = $s$3;$wcs$5 = $wcs$4;
        } else {
         $300 = ($wcs$4|0)==(0|0);
         if (!($300)) {
          $301 = (($wcs$4) + ($i$4<<2)|0);
          HEAP32[$301>>2] = 0;
         }
         $302 = ($s$3|0)==(0|0);
         if ($302) {
          $p$10 = $p$9;$s$4 = 0;$wcs$5 = $wcs$4;
         } else {
          $303 = (($s$3) + ($i$4)|0);
          HEAP8[$303>>0] = 0;
          $p$10 = $p$9;$s$4 = $s$3;$wcs$5 = $wcs$4;
         }
        }
        break;
       }
       default: {
        $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
       }
       }
      } while(0);
      L197: do {
       if ((label|0) == 144) {
        label = 0;
        $304 = (___intscan($f,$base$0,0,-1,-1)|0);
        $305 = tempRet0;
        $306 = HEAP32[$5>>2]|0;
        $307 = HEAP32[$3>>2]|0;
        $308 = HEAP32[$6>>2]|0;
        $309 = $307;
        $310 = $308;
        $311 = (($310) - ($309))|0;
        $312 = ($306|0)==($311|0);
        if ($312) {
         $alloc$2 = $alloc$0;$matches$2 = $matches$0130;$s$7 = $s$1;$wcs$8 = $wcs$1;
         break L4;
        }
        $313 = ($$|0)!=(112);
        $314 = ($dest$0|0)==(0|0);
        $or$cond6 = $313 | $314;
        if (!($or$cond6)) {
         $315 = $304;
         HEAP32[$dest$0>>2] = $315;
         $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
         break;
        }
        if ($314) {
         $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
        } else {
         switch ($$size$0|0) {
         case -2:  {
          $316 = $304&255;
          HEAP8[$dest$0>>0] = $316;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L197;
          break;
         }
         case 0:  {
          HEAP32[$dest$0>>2] = $304;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L197;
          break;
         }
         case 1:  {
          HEAP32[$dest$0>>2] = $304;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L197;
          break;
         }
         case 3:  {
          $318 = $dest$0;
          $319 = $318;
          HEAP32[$319>>2] = $304;
          $320 = (($318) + 4)|0;
          $321 = $320;
          HEAP32[$321>>2] = $305;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L197;
          break;
         }
         case -1:  {
          $317 = $304&65535;
          HEAP16[$dest$0>>1] = $317;
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L197;
          break;
         }
         default: {
          $p$10 = $p$5;$s$4 = $s$1;$wcs$5 = $wcs$1;
          break L197;
         }
         }
        }
       }
      } while(0);
      $332 = HEAP32[$5>>2]|0;
      $333 = HEAP32[$3>>2]|0;
      $334 = HEAP32[$6>>2]|0;
      $335 = $333;
      $336 = $334;
      $337 = (($332) + ($pos$1))|0;
      $338 = (($337) + ($335))|0;
      $339 = (($338) - ($336))|0;
      $not$ = ($dest$0|0)!=(0|0);
      $340 = $not$&1;
      $matches$0$ = (($340) + ($matches$0130))|0;
      $matches$1 = $matches$0$;$p$11 = $p$10;$pos$2 = $339;$s$5 = $s$4;$wcs$6 = $wcs$5;
      break L6;
     }
    } while(0);
    $46 = $43&1;
    $47 = (($p$0136) + ($46)|0);
    ___shlim($f,0);
    $48 = HEAP32[$3>>2]|0;
    $49 = HEAP32[$4>>2]|0;
    $50 = ($48>>>0)<($49>>>0);
    if ($50) {
     $51 = (($48) + 1|0);
     HEAP32[$3>>2] = $51;
     $52 = HEAP8[$48>>0]|0;
     $53 = $52&255;
     $58 = $53;
    } else {
     $54 = (___shgetc($f)|0);
     $58 = $54;
    }
    $55 = HEAP8[$47>>0]|0;
    $56 = $55&255;
    $57 = ($58|0)==($56|0);
    if (!($57)) {
     label = 19;
     break L4;
    }
    $64 = (($pos$0135) + 1)|0;
    $matches$1 = $matches$0130;$p$11 = $47;$pos$2 = $64;$s$5 = $s$0128;$wcs$6 = $wcs$0129;
   } else {
    $p$1 = $p$0136;
    while(1) {
     $16 = (($p$1) + 1|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = $17&255;
     $19 = (_isspace($18)|0);
     $20 = ($19|0)==(0);
     if ($20) {
      break;
     } else {
      $p$1 = $16;
     }
    }
    ___shlim($f,0);
    while(1) {
     $21 = HEAP32[$3>>2]|0;
     $22 = HEAP32[$4>>2]|0;
     $23 = ($21>>>0)<($22>>>0);
     if ($23) {
      $24 = (($21) + 1|0);
      HEAP32[$3>>2] = $24;
      $25 = HEAP8[$21>>0]|0;
      $26 = $25&255;
      $28 = $26;
     } else {
      $27 = (___shgetc($f)|0);
      $28 = $27;
     }
     $29 = (_isspace($28)|0);
     $30 = ($29|0)==(0);
     if ($30) {
      break;
     }
    }
    $31 = HEAP32[$4>>2]|0;
    $32 = ($31|0)==(0|0);
    $$pre238 = HEAP32[$3>>2]|0;
    if ($32) {
     $37 = $$pre238;
    } else {
     $33 = (($$pre238) + -1|0);
     HEAP32[$3>>2] = $33;
     $37 = $33;
    }
    $34 = HEAP32[$5>>2]|0;
    $35 = HEAP32[$6>>2]|0;
    $36 = $37;
    $38 = $35;
    $39 = (($34) + ($pos$0135))|0;
    $40 = (($39) + ($36))|0;
    $41 = (($40) - ($38))|0;
    $matches$1 = $matches$0130;$p$11 = $p$1;$pos$2 = $41;$s$5 = $s$0128;$wcs$6 = $wcs$0129;
   }
  } while(0);
  $341 = (($p$11) + 1|0);
  $342 = HEAP8[$341>>0]|0;
  $343 = ($342<<24>>24)==(0);
  if ($343) {
   $matches$3 = $matches$1;
   label = 165;
   break;
  } else {
   $13 = $342;$matches$0130 = $matches$1;$p$0136 = $341;$pos$0135 = $pos$2;$s$0128 = $s$5;$wcs$0129 = $wcs$6;
  }
 }
 if ((label|0) == 165) {
  STACKTOP = sp;return ($matches$3|0);
 }
 if ((label|0) == 19) {
  $59 = HEAP32[$4>>2]|0;
  $60 = ($59|0)==(0|0);
  if (!($60)) {
   $61 = HEAP32[$3>>2]|0;
   $62 = (($61) + -1|0);
   HEAP32[$3>>2] = $62;
  }
  $63 = ($58|0)<(0);
  if ($63) {
   $alloc$1 = 0;$s$6 = $s$0128;$wcs$7 = $wcs$0129;
   label = 162;
  } else {
   $matches$3 = $matches$0130;
   STACKTOP = sp;return ($matches$3|0);
  }
 }
 if ((label|0) == 162) {
  $344 = ($matches$0130|0)==(0);
  $345 = $344 << 31 >> 31;
  $$matches$0 = (($345) + ($matches$0130))|0;
  $alloc$2 = $alloc$1;$matches$2 = $$matches$0;$s$7 = $s$6;$wcs$8 = $wcs$7;
 }
 $346 = ($alloc$2|0)==(0);
 if ($346) {
  $matches$3 = $matches$2;
  STACKTOP = sp;return ($matches$3|0);
 }
 _free($s$7);
 _free($wcs$8);
 $matches$3 = $matches$2;
 STACKTOP = sp;return ($matches$3|0);
}
function _vsscanf($s,$fmt,$ap) {
 $s = $s|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $f = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $f = sp;
 dest=$f+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($f) + 32|0);
 HEAP32[$0>>2] = 1689;
 $1 = (($f) + 44|0);
 HEAP32[$1>>2] = $s;
 $2 = (($f) + 76|0);
 HEAP32[$2>>2] = -1;
 $3 = (($f) + 84|0);
 HEAP32[$3>>2] = $s;
 $4 = (_MUSL_vfscanf($f,$fmt,$ap)|0);
 STACKTOP = sp;return ($4|0);
}
function _do_read($f,$buf,$len) {
 $f = $f|0;
 $buf = $buf|0;
 $len = $len|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___string_read($f,$buf,$len)|0);
 STACKTOP = sp;return ($0|0);
}
function _bsearch($key,$base,$nel,$width,$cmp) {
 $key = $key|0;
 $base = $base|0;
 $nel = $nel|0;
 $width = $width|0;
 $cmp = $cmp|0;
 var $$ = 0, $$0 = 0, $$01$ = 0, $$014 = 0, $$023 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nel|0)==(0);
 L1: do {
  if ($0) {
   $$0 = 0;
  } else {
   $$014 = $base;$$023 = $nel;
   while(1) {
    $1 = $$023 >>> 1;
    $2 = Math_imul($1, $width)|0;
    $3 = (($$014) + ($2)|0);
    $4 = (FUNCTION_TABLE_iii[$cmp & 4095]($key,$3)|0);
    $5 = ($4|0)==(0);
    if ($5) {
     $$0 = $3;
     break L1;
    }
    $6 = ($$023|0)==(1);
    if ($6) {
     $$0 = 0;
     break L1;
    }
    $7 = ($4|0)<(0);
    $8 = (($$023) - ($1))|0;
    $$ = $7 ? $1 : $8;
    $$01$ = $7 ? $$014 : $3;
    $9 = ($$|0)==(0);
    if ($9) {
     $$0 = 0;
     break;
    } else {
     $$014 = $$01$;$$023 = $$;
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function _qsort($base,$nel,$width,$cmp) {
 $base = $base|0;
 $nel = $nel|0;
 $width = $width|0;
 $cmp = $cmp|0;
 var $$ = 0, $$$i = 0, $$0$be$i = 0, $$0$be$i20 = 0, $$0$i50 = 0, $$01$be$i = 0, $$01$be$i19 = 0, $$01$i5$i = 0, $$012$i = 0, $$012$i16 = 0, $$02$i$i = 0, $$02$i3$i = 0, $$02$i3469 = 0, $$02$i72 = 0, $$02$us$i = 0, $$02$us$i32 = 0, $$03$i = 0, $$03$i15 = 0, $$66 = 0, $$67 = 0;
 var $$lcssa75 = 0, $$lcssa76 = 0, $$pre = 0, $$pre$i = 0, $$pre$i22 = 0, $$pre$i28 = 0, $$pre$i9 = 0, $$sum = 0, $$sum$i = 0, $$sum$i18 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $4$phi = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ar$i = 0, $exitcond$i = 0, $exitcond$i31 = 0, $head$0$lcssa = 0, $head$077 = 0;
 var $head$1 = 0, $i$0 = 0, $i$0$lcssa$i = 0, $i$0$lcssa$i24 = 0, $i$01$us$i = 0, $i$01$us$i30 = 0, $i$04$i = 0, $i$04$i14 = 0, $lp = 0, $nTrailingZeros$03$i$i = 0, $nTrailingZeros$03$i2$i = 0, $pshift$0$lcssa = 0, $pshift$078 = 0, $pshift$1 = 0, $pshift$2 = 0, $sum = 0, $sum$i = 0, $sum$i17 = 0, $tmp$i = 0, $tmp$i26 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 944|0;
 $tmp$i26 = sp + 680|0;
 $tmp$i = sp + 424|0;
 $ar$i = sp;
 $lp = sp + 232|0;
 $0 = Math_imul($width, $nel)|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $$sum = (($0) - ($width))|0;
 $2 = (($lp) + 4|0);
 HEAP32[$2>>2] = $width;
 HEAP32[$lp>>2] = $width;
 $4 = $width;$6 = $width;$i$0 = 2;
 while(1) {
  $3 = (($4) + ($width))|0;
  $5 = (($3) + ($6))|0;
  $7 = (($lp) + ($i$0<<2)|0);
  HEAP32[$7>>2] = $5;
  $8 = ($5>>>0)<($0>>>0);
  $9 = (($i$0) + 1)|0;
  if ($8) {
   $4$phi = $6;$6 = $5;$i$0 = $9;$4 = $4$phi;
  } else {
   break;
  }
 }
 $10 = (0 - ($width))|0;
 $11 = (($base) + ($$sum)|0);
 $12 = ($$sum|0)>(0);
 if ($12) {
  $13 = ($width|0)==(0);
  $14 = ($width>>>0)>(256);
  $15 = $14 ? 256 : $width;
  $16 = ($15|0)==($width|0);
  $17 = $11;
  $19 = 1;$61 = 0;$head$077 = $base;$pshift$078 = 1;
  while(1) {
   $18 = $19 & 3;
   $20 = ($18|0)==(3);
   do {
    if ($20) {
     HEAP32[$ar$i>>2] = $head$077;
     $21 = ($pshift$078|0)>(1);
     L13: do {
      if ($21) {
       $$012$i = $pshift$078;$$03$i = $head$077;$27 = $head$077;$i$04$i = 1;
       while(1) {
        $22 = (($$03$i) + ($10)|0);
        $23 = (($$012$i) + -2)|0;
        $24 = (($lp) + ($23<<2)|0);
        $25 = HEAP32[$24>>2]|0;
        $sum$i = (($25) + ($width))|0;
        $$sum$i = (0 - ($sum$i))|0;
        $26 = (($$03$i) + ($$sum$i)|0);
        $28 = (FUNCTION_TABLE_iii[$cmp & 4095]($27,$26)|0);
        $29 = ($28|0)>(-1);
        if ($29) {
         $30 = (FUNCTION_TABLE_iii[$cmp & 4095]($27,$22)|0);
         $31 = ($30|0)>(-1);
         if ($31) {
          $i$0$lcssa$i = $i$04$i;
          break;
         }
        }
        $32 = (FUNCTION_TABLE_iii[$cmp & 4095]($26,$22)|0);
        $33 = ($32|0)>(-1);
        $34 = (($i$04$i) + 1)|0;
        $35 = (($ar$i) + ($i$04$i<<2)|0);
        if ($33) {
         HEAP32[$35>>2] = $26;
         $36 = (($$012$i) + -1)|0;
         $$0$be$i = $26;$$01$be$i = $36;
        } else {
         HEAP32[$35>>2] = $22;
         $$0$be$i = $22;$$01$be$i = $23;
        }
        $37 = ($$01$be$i|0)>(1);
        if (!($37)) {
         $i$0$lcssa$i = $34;
         break;
        }
        $$pre$i = HEAP32[$ar$i>>2]|0;
        $$012$i = $$01$be$i;$$03$i = $$0$be$i;$27 = $$pre$i;$i$04$i = $34;
       }
       $38 = ($i$0$lcssa$i|0)<(2);
       if (!($38)) {
        $39 = (($ar$i) + ($i$0$lcssa$i<<2)|0);
        HEAP32[$39>>2] = $tmp$i;
        if (!($13)) {
         $40 = ($i$0$lcssa$i|0)>(0);
         if ($40) {
          $$02$us$i = $width;$53 = $tmp$i;
         } else {
          $41 = HEAP32[$ar$i>>2]|0;
          _memcpy(($tmp$i|0),($41|0),($15|0))|0;
          if ($16) {
           break;
          } else {
           $$02$i72 = $width;$55 = $15;
          }
          while(1) {
           $54 = (($$02$i72) - ($55))|0;
           $56 = ($54>>>0)>(256);
           $57 = $56 ? 256 : $54;
           _memcpy(($tmp$i|0),($41|0),($57|0))|0;
           $58 = ($54|0)==($57|0);
           if ($58) {
            break L13;
           } else {
            $$02$i72 = $54;$55 = $57;
           }
          }
         }
         while(1) {
          $51 = ($$02$us$i>>>0)>(256);
          $43 = $51 ? 256 : $$02$us$i;
          $52 = HEAP32[$ar$i>>2]|0;
          _memcpy(($53|0),($52|0),($43|0))|0;
          $49 = $52;$i$01$us$i = 0;
          while(1) {
           $45 = (($ar$i) + ($i$01$us$i<<2)|0);
           $46 = (($i$01$us$i) + 1)|0;
           $47 = (($ar$i) + ($46<<2)|0);
           $48 = HEAP32[$47>>2]|0;
           _memcpy(($49|0),($48|0),($43|0))|0;
           $50 = (($49) + ($43)|0);
           HEAP32[$45>>2] = $50;
           $exitcond$i = ($46|0)==($i$0$lcssa$i|0);
           if ($exitcond$i) {
            break;
           } else {
            $49 = $48;$i$01$us$i = $46;
           }
          }
          $42 = ($$02$us$i|0)==($43|0);
          if ($42) {
           break L13;
          }
          $44 = (($$02$us$i) - ($43))|0;
          $$pre$i9 = HEAP32[$39>>2]|0;
          $$02$us$i = $44;$53 = $$pre$i9;
         }
        }
       }
      }
     } while(0);
     $59 = $19 >>> 2;
     $60 = $61 << 30;
     $62 = $59 | $60;
     $63 = $61 >>> 2;
     $64 = (($pshift$078) + 2)|0;
     $122 = $62;$182 = $63;$pshift$1 = $64;
    } else {
     $65 = (($pshift$078) + -1)|0;
     $66 = (($lp) + ($65<<2)|0);
     $67 = HEAP32[$66>>2]|0;
     $68 = $head$077;
     $69 = (($17) - ($68))|0;
     $70 = ($67>>>0)<($69>>>0);
     L39: do {
      if ($70) {
       HEAP32[$ar$i>>2] = $head$077;
       $71 = ($pshift$078|0)>(1);
       if ($71) {
        $$012$i16 = $pshift$078;$$03$i15 = $head$077;$77 = $head$077;$i$04$i14 = 1;
        while(1) {
         $72 = (($$03$i15) + ($10)|0);
         $73 = (($$012$i16) + -2)|0;
         $74 = (($lp) + ($73<<2)|0);
         $75 = HEAP32[$74>>2]|0;
         $sum$i17 = (($75) + ($width))|0;
         $$sum$i18 = (0 - ($sum$i17))|0;
         $76 = (($$03$i15) + ($$sum$i18)|0);
         $78 = (FUNCTION_TABLE_iii[$cmp & 4095]($77,$76)|0);
         $79 = ($78|0)>(-1);
         if ($79) {
          $80 = (FUNCTION_TABLE_iii[$cmp & 4095]($77,$72)|0);
          $81 = ($80|0)>(-1);
          if ($81) {
           $i$0$lcssa$i24 = $i$04$i14;
           break;
          }
         }
         $82 = (FUNCTION_TABLE_iii[$cmp & 4095]($76,$72)|0);
         $83 = ($82|0)>(-1);
         $84 = (($i$04$i14) + 1)|0;
         $85 = (($ar$i) + ($i$04$i14<<2)|0);
         if ($83) {
          HEAP32[$85>>2] = $76;
          $86 = (($$012$i16) + -1)|0;
          $$0$be$i20 = $76;$$01$be$i19 = $86;
         } else {
          HEAP32[$85>>2] = $72;
          $$0$be$i20 = $72;$$01$be$i19 = $73;
         }
         $87 = ($$01$be$i19|0)>(1);
         if (!($87)) {
          $i$0$lcssa$i24 = $84;
          break;
         }
         $$pre$i22 = HEAP32[$ar$i>>2]|0;
         $$012$i16 = $$01$be$i19;$$03$i15 = $$0$be$i20;$77 = $$pre$i22;$i$04$i14 = $84;
        }
        $88 = ($i$0$lcssa$i24|0)<(2);
        if (!($88)) {
         $89 = (($ar$i) + ($i$0$lcssa$i24<<2)|0);
         HEAP32[$89>>2] = $tmp$i26;
         if (!($13)) {
          $90 = ($i$0$lcssa$i24|0)>(0);
          if ($90) {
           $$02$us$i32 = $width;$103 = $tmp$i26;
          } else {
           $91 = HEAP32[$ar$i>>2]|0;
           _memcpy(($tmp$i26|0),($91|0),($15|0))|0;
           if ($16) {
            break;
           } else {
            $$02$i3469 = $width;$105 = $15;
           }
           while(1) {
            $104 = (($$02$i3469) - ($105))|0;
            $106 = ($104>>>0)>(256);
            $107 = $106 ? 256 : $104;
            _memcpy(($tmp$i26|0),($91|0),($107|0))|0;
            $108 = ($104|0)==($107|0);
            if ($108) {
             break L39;
            } else {
             $$02$i3469 = $104;$105 = $107;
            }
           }
          }
          while(1) {
           $101 = ($$02$us$i32>>>0)>(256);
           $93 = $101 ? 256 : $$02$us$i32;
           $102 = HEAP32[$ar$i>>2]|0;
           _memcpy(($103|0),($102|0),($93|0))|0;
           $99 = $102;$i$01$us$i30 = 0;
           while(1) {
            $95 = (($ar$i) + ($i$01$us$i30<<2)|0);
            $96 = (($i$01$us$i30) + 1)|0;
            $97 = (($ar$i) + ($96<<2)|0);
            $98 = HEAP32[$97>>2]|0;
            _memcpy(($99|0),($98|0),($93|0))|0;
            $100 = (($99) + ($93)|0);
            HEAP32[$95>>2] = $100;
            $exitcond$i31 = ($96|0)==($i$0$lcssa$i24|0);
            if ($exitcond$i31) {
             break;
            } else {
             $99 = $98;$i$01$us$i30 = $96;
            }
           }
           $92 = ($$02$us$i32|0)==($93|0);
           if ($92) {
            break L39;
           }
           $94 = (($$02$us$i32) - ($93))|0;
           $$pre$i28 = HEAP32[$89>>2]|0;
           $$02$us$i32 = $94;$103 = $$pre$i28;
          }
         }
        }
       }
      } else {
       _trinkle($head$077,$width,$cmp,$19,$61,$pshift$078,0,$lp);
      }
     } while(0);
     $109 = ($pshift$078|0)==(1);
     if ($109) {
      $110 = $61 << 1;
      $111 = $19 >>> 31;
      $112 = $111 | $110;
      $113 = $19 << 1;
      $122 = $113;$182 = $112;$pshift$1 = 0;
      break;
     } else {
      $114 = ($65>>>0)>(31);
      $115 = (($pshift$078) + -33)|0;
      $$ = $114 ? 0 : $19;
      $$66 = $114 ? $19 : $61;
      $$67 = $114 ? $115 : $65;
      $116 = $$66 << $$67;
      $117 = (32 - ($$67))|0;
      $118 = $$ >>> $117;
      $119 = $118 | $116;
      $120 = $$ << $$67;
      $122 = $120;$182 = $119;$pshift$1 = 1;
      break;
     }
    }
   } while(0);
   $121 = $122 | 1;
   $123 = (($head$077) + ($width)|0);
   $124 = ($123>>>0)<($11>>>0);
   if ($124) {
    $19 = $121;$61 = $182;$head$077 = $123;$pshift$078 = $pshift$1;
   } else {
    $$lcssa75 = $182;$$lcssa76 = $121;$head$0$lcssa = $123;$pshift$0$lcssa = $pshift$1;
    break;
   }
  }
 } else {
  $$lcssa75 = 0;$$lcssa76 = 1;$head$0$lcssa = $base;$pshift$0$lcssa = 1;
 }
 _trinkle($head$0$lcssa,$width,$cmp,$$lcssa76,$$lcssa75,$pshift$0$lcssa,0,$lp);
 $127 = $$lcssa76;$129 = $$lcssa75;$head$1 = $head$0$lcssa;$pshift$2 = $pshift$0$lcssa;
 while(1) {
  $125 = ($pshift$2|0)==(1);
  if ($125) {
   $126 = ($127|0)==(1);
   if ($126) {
    $128 = ($129|0)==(0);
    if ($128) {
     break;
    } else {
     label = 52;
    }
   }
  } else {
   label = 52;
  }
  if ((label|0) == 52) {
   label = 0;
   $130 = ($pshift$2|0)<(2);
   if (!($130)) {
    $162 = $129 << 2;
    $163 = $127 >>> 30;
    $164 = $163 | $162;
    $165 = (($pshift$2) + -2)|0;
    $166 = $127 << 1;
    $167 = $166 & 2147483646;
    $168 = $163 << 31;
    $169 = $167 | $168;
    $170 = $169 ^ 3;
    $171 = $164 >>> 1;
    $172 = (($lp) + ($165<<2)|0);
    $173 = HEAP32[$172>>2]|0;
    $sum = (($173) + ($width))|0;
    $$sum2 = (0 - ($sum))|0;
    $174 = (($head$1) + ($$sum2)|0);
    $175 = (($pshift$2) + -1)|0;
    _trinkle($174,$width,$cmp,$170,$171,$175,1,$lp);
    $176 = $171 << 1;
    $177 = $163 & 1;
    $178 = $176 | $177;
    $179 = $170 << 1;
    $180 = $179 | 1;
    $181 = (($head$1) + ($10)|0);
    _trinkle($181,$width,$cmp,$180,$178,$165,1,$lp);
    $127 = $180;$129 = $178;$head$1 = $181;$pshift$2 = $165;
    continue;
   }
  }
  $131 = (($127) + -1)|0;
  $132 = ($131|0)==(0);
  if ($132) {
   $152 = 32;
   label = 62;
  } else {
   $133 = $131 & 1;
   $134 = ($133|0)==(0);
   if ($134) {
    $$02$i$i = $131;$nTrailingZeros$03$i$i = 0;
    while(1) {
     $135 = (($nTrailingZeros$03$i$i) + 1)|0;
     $136 = $$02$i$i >>> 1;
     $137 = $136 & 1;
     $138 = ($137|0)==(0);
     if ($138) {
      $$02$i$i = $136;$nTrailingZeros$03$i$i = $135;
     } else {
      break;
     }
    }
    $139 = ($135|0)==(0);
    if ($139) {
     label = 57;
    } else {
     $150 = $135;
    }
   } else {
    label = 57;
   }
   if ((label|0) == 57) {
    label = 0;
    $140 = ($129|0)==(0);
    if ($140) {
     $$01$i5$i = 32;
    } else {
     $141 = $129 & 1;
     $142 = ($141|0)==(0);
     if ($142) {
      $$02$i3$i = $129;$nTrailingZeros$03$i2$i = 0;
      while(1) {
       $143 = (($nTrailingZeros$03$i2$i) + 1)|0;
       $144 = $$02$i3$i >>> 1;
       $145 = $144 & 1;
       $146 = ($145|0)==(0);
       if ($146) {
        $$02$i3$i = $144;$nTrailingZeros$03$i2$i = $143;
       } else {
        $$01$i5$i = $143;
        break;
       }
      }
     } else {
      $$01$i5$i = 0;
     }
    }
    $147 = (($$01$i5$i) + 32)|0;
    $148 = ($$01$i5$i|0)==(0);
    $$$i = $148 ? 0 : $147;
    $150 = $$$i;
   }
   $149 = ($150>>>0)>(31);
   if ($149) {
    $152 = $150;
    label = 62;
   } else {
    $$0$i50 = $150;$154 = $127;$157 = $129;$161 = $150;
   }
  }
  if ((label|0) == 62) {
   label = 0;
   $151 = (($152) + -32)|0;
   $$0$i50 = $151;$154 = $129;$157 = 0;$161 = $152;
  }
  $153 = $154 >>> $$0$i50;
  $155 = (32 - ($$0$i50))|0;
  $156 = $157 << $155;
  $158 = $156 | $153;
  $159 = $157 >>> $$0$i50;
  $160 = (($161) + ($pshift$2))|0;
  $$pre = (($head$1) + ($10)|0);
  $127 = $158;$129 = $159;$head$1 = $$pre;$pshift$2 = $160;
 }
 STACKTOP = sp;return;
}
function _trinkle($head,$width,$cmp,$pp$val,$pp$1$val,$pshift,$trusty,$lp) {
 $head = $head|0;
 $width = $width|0;
 $cmp = $cmp|0;
 $pp$val = $pp$val|0;
 $pp$1$val = $pp$1$val|0;
 $pshift = $pshift|0;
 $trusty = $trusty|0;
 $lp = $lp|0;
 var $$$i = 0, $$0$be$i = 0, $$0$i = 0, $$0$lcssa = 0, $$0$lcssa26 = 0, $$01$be$i = 0, $$01$i5$i = 0, $$01$lcssa = 0, $$01$lcssa28 = 0, $$0110 = 0, $$012 = 0, $$012$i = 0, $$02$i$i = 0, $$02$i146 = 0, $$02$i3 = 0, $$02$i3$i = 0, $$02$lcssa = 0, $$02$us$i = 0, $$02$us$i12 = 0, $$029 = 0;
 var $$03$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i3 = 0, $$pre$i8 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ar = 0, $ar$i = 0, $exitcond$i = 0, $exitcond$i11 = 0, $i$0$lcssa = 0, $i$0$lcssa$i = 0;
 var $i$0$lcssa27 = 0, $i$01$us$i = 0, $i$01$us$i10 = 0, $i$011 = 0, $i$04$i = 0, $nTrailingZeros$03$i$i = 0, $nTrailingZeros$03$i2$i = 0, $or$cond = 0, $or$cond1 = 0, $or$cond18 = 0, $sum = 0, $sum$i = 0, $tmp$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 720|0;
 $tmp$i6 = sp + 456|0;
 $ar$i = sp;
 $ar = sp + 228|0;
 HEAP32[$ar>>2] = $head;
 $0 = (0 - ($width))|0;
 $1 = ($pp$val|0)==(1);
 $2 = ($pp$1$val|0)==(0);
 $or$cond18 = $1 & $2;
 L1: do {
  if ($or$cond18) {
   $$0$lcssa = $head;$$01$lcssa = $pshift;$$02$lcssa = $trusty;$i$0$lcssa = 1;
   label = 18;
  } else {
   $$0110 = $pshift;$$012 = $head;$$029 = $trusty;$24 = $pp$val;$34 = $pp$1$val;$7 = $head;$i$011 = 1;
   while(1) {
    $3 = (($lp) + ($$0110<<2)|0);
    $4 = HEAP32[$3>>2]|0;
    $5 = (0 - ($4))|0;
    $6 = (($$012) + ($5)|0);
    $8 = (FUNCTION_TABLE_iii[$cmp & 4095]($6,$7)|0);
    $9 = ($8|0)<(1);
    if ($9) {
     $$0$lcssa = $$012;$$01$lcssa = $$0110;$$02$lcssa = $$029;$i$0$lcssa = $i$011;
     label = 18;
     break L1;
    }
    $10 = ($$029|0)==(0);
    $11 = ($$0110|0)>(1);
    $or$cond = $10 & $11;
    if ($or$cond) {
     $12 = (($$012) + ($0)|0);
     $13 = (($$0110) + -2)|0;
     $14 = (($lp) + ($13<<2)|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (FUNCTION_TABLE_iii[$cmp & 4095]($12,$6)|0);
     $17 = ($16|0)>(-1);
     if ($17) {
      $$0$lcssa26 = $$012;$$01$lcssa28 = $$0110;$i$0$lcssa27 = $i$011;
      break L1;
     }
     $sum = (($15) + ($width))|0;
     $$sum = (0 - ($sum))|0;
     $18 = (($$012) + ($$sum)|0);
     $19 = (FUNCTION_TABLE_iii[$cmp & 4095]($18,$6)|0);
     $20 = ($19|0)>(-1);
     if ($20) {
      $$0$lcssa26 = $$012;$$01$lcssa28 = $$0110;$i$0$lcssa27 = $i$011;
      break L1;
     }
    }
    $21 = (($i$011) + 1)|0;
    $22 = (($ar) + ($i$011<<2)|0);
    HEAP32[$22>>2] = $6;
    $23 = (($24) + -1)|0;
    $25 = ($23|0)==(0);
    if ($25) {
     $46 = 32;
     label = 15;
    } else {
     $26 = $23 & 1;
     $27 = ($26|0)==(0);
     if ($27) {
      $$02$i$i = $23;$nTrailingZeros$03$i$i = 0;
      while(1) {
       $28 = (($nTrailingZeros$03$i$i) + 1)|0;
       $29 = $$02$i$i >>> 1;
       $30 = $29 & 1;
       $31 = ($30|0)==(0);
       if ($31) {
        $$02$i$i = $29;$nTrailingZeros$03$i$i = $28;
       } else {
        break;
       }
      }
      $32 = ($28|0)==(0);
      if ($32) {
       label = 10;
      } else {
       $44 = $28;
      }
     } else {
      label = 10;
     }
     if ((label|0) == 10) {
      label = 0;
      $33 = ($34|0)==(0);
      if ($33) {
       $$01$i5$i = 32;
      } else {
       $35 = $34 & 1;
       $36 = ($35|0)==(0);
       if ($36) {
        $$02$i3$i = $34;$nTrailingZeros$03$i2$i = 0;
        while(1) {
         $37 = (($nTrailingZeros$03$i2$i) + 1)|0;
         $38 = $$02$i3$i >>> 1;
         $39 = $38 & 1;
         $40 = ($39|0)==(0);
         if ($40) {
          $$02$i3$i = $38;$nTrailingZeros$03$i2$i = $37;
         } else {
          $$01$i5$i = $37;
          break;
         }
        }
       } else {
        $$01$i5$i = 0;
       }
      }
      $41 = (($$01$i5$i) + 32)|0;
      $42 = ($$01$i5$i|0)==(0);
      $$$i = $42 ? 0 : $41;
      $44 = $$$i;
     }
     $43 = ($44>>>0)>(31);
     if ($43) {
      $46 = $44;
      label = 15;
     } else {
      $$0$i = $44;$48 = $24;$51 = $34;$55 = $44;
     }
    }
    if ((label|0) == 15) {
     label = 0;
     $45 = (($46) + -32)|0;
     $$0$i = $45;$48 = $34;$51 = 0;$55 = $46;
    }
    $47 = $48 >>> $$0$i;
    $49 = (32 - ($$0$i))|0;
    $50 = $51 << $49;
    $52 = $50 | $47;
    $53 = $51 >>> $$0$i;
    $54 = (($55) + ($$0110))|0;
    $56 = ($52|0)==(1);
    $57 = ($53|0)==(0);
    $or$cond1 = $56 & $57;
    if ($or$cond1) {
     $$0$lcssa26 = $6;$$01$lcssa28 = $54;$i$0$lcssa27 = $21;
     break L1;
    }
    $$pre = HEAP32[$ar>>2]|0;
    $$0110 = $54;$$012 = $6;$$029 = 0;$24 = $52;$34 = $53;$7 = $$pre;$i$011 = $21;
   }
  }
 } while(0);
 if ((label|0) == 18) {
  $58 = ($$02$lcssa|0)==(0);
  if ($58) {
   $$0$lcssa26 = $$0$lcssa;$$01$lcssa28 = $$01$lcssa;$i$0$lcssa27 = $i$0$lcssa;
  } else {
   STACKTOP = sp;return;
  }
 }
 $59 = ($i$0$lcssa27|0)<(2);
 L31: do {
  if (!($59)) {
   $60 = (($ar) + ($i$0$lcssa27<<2)|0);
   HEAP32[$60>>2] = $tmp$i6;
   $61 = ($width|0)==(0);
   if (!($61)) {
    $62 = ($i$0$lcssa27|0)>(0);
    if ($62) {
     $$02$us$i12 = $width;$78 = $tmp$i6;
    } else {
     $63 = ($width>>>0)>(256);
     $64 = $63 ? 256 : $width;
     $65 = HEAP32[$ar>>2]|0;
     _memcpy(($tmp$i6|0),($65|0),($64|0))|0;
     $66 = ($64|0)==($width|0);
     if ($66) {
      break;
     } else {
      $$02$i146 = $width;$80 = $64;
     }
     while(1) {
      $79 = (($$02$i146) - ($80))|0;
      $81 = ($79>>>0)>(256);
      $82 = $81 ? 256 : $79;
      _memcpy(($tmp$i6|0),($65|0),($82|0))|0;
      $83 = ($79|0)==($82|0);
      if ($83) {
       break L31;
      } else {
       $$02$i146 = $79;$80 = $82;
      }
     }
    }
    while(1) {
     $76 = ($$02$us$i12>>>0)>(256);
     $68 = $76 ? 256 : $$02$us$i12;
     $77 = HEAP32[$ar>>2]|0;
     _memcpy(($78|0),($77|0),($68|0))|0;
     $74 = $77;$i$01$us$i10 = 0;
     while(1) {
      $70 = (($ar) + ($i$01$us$i10<<2)|0);
      $71 = (($i$01$us$i10) + 1)|0;
      $72 = (($ar) + ($71<<2)|0);
      $73 = HEAP32[$72>>2]|0;
      _memcpy(($74|0),($73|0),($68|0))|0;
      $75 = (($74) + ($68)|0);
      HEAP32[$70>>2] = $75;
      $exitcond$i11 = ($71|0)==($i$0$lcssa27|0);
      if ($exitcond$i11) {
       break;
      } else {
       $74 = $73;$i$01$us$i10 = $71;
      }
     }
     $67 = ($$02$us$i12|0)==($68|0);
     if ($67) {
      break L31;
     }
     $69 = (($$02$us$i12) - ($68))|0;
     $$pre$i8 = HEAP32[$60>>2]|0;
     $$02$us$i12 = $69;$78 = $$pre$i8;
    }
   }
  }
 } while(0);
 HEAP32[$ar$i>>2] = $$0$lcssa26;
 $84 = ($$01$lcssa28|0)>(1);
 L45: do {
  if ($84) {
   $$012$i = $$01$lcssa28;$$03$i = $$0$lcssa26;$90 = $$0$lcssa26;$i$04$i = 1;
   while(1) {
    $85 = (($$03$i) + ($0)|0);
    $86 = (($$012$i) + -2)|0;
    $87 = (($lp) + ($86<<2)|0);
    $88 = HEAP32[$87>>2]|0;
    $sum$i = (($88) + ($width))|0;
    $$sum$i = (0 - ($sum$i))|0;
    $89 = (($$03$i) + ($$sum$i)|0);
    $91 = (FUNCTION_TABLE_iii[$cmp & 4095]($90,$89)|0);
    $92 = ($91|0)>(-1);
    if ($92) {
     $93 = (FUNCTION_TABLE_iii[$cmp & 4095]($90,$85)|0);
     $94 = ($93|0)>(-1);
     if ($94) {
      $i$0$lcssa$i = $i$04$i;
      break;
     }
    }
    $95 = (FUNCTION_TABLE_iii[$cmp & 4095]($89,$85)|0);
    $96 = ($95|0)>(-1);
    $97 = (($i$04$i) + 1)|0;
    $98 = (($ar$i) + ($i$04$i<<2)|0);
    if ($96) {
     HEAP32[$98>>2] = $89;
     $99 = (($$012$i) + -1)|0;
     $$0$be$i = $89;$$01$be$i = $99;
    } else {
     HEAP32[$98>>2] = $85;
     $$0$be$i = $85;$$01$be$i = $86;
    }
    $100 = ($$01$be$i|0)>(1);
    if (!($100)) {
     $i$0$lcssa$i = $97;
     break;
    }
    $$pre$i = HEAP32[$ar$i>>2]|0;
    $$012$i = $$01$be$i;$$03$i = $$0$be$i;$90 = $$pre$i;$i$04$i = $97;
   }
   $101 = ($i$0$lcssa$i|0)<(2);
   if ($101) {
    $126 = $tmp$i6;
   } else {
    $102 = (($ar$i) + ($i$0$lcssa$i<<2)|0);
    HEAP32[$102>>2] = $tmp$i6;
    $103 = ($width|0)==(0);
    if ($103) {
     $126 = $tmp$i6;
    } else {
     $104 = ($i$0$lcssa$i|0)>(0);
     if ($104) {
      $$02$us$i = $width;$120 = $tmp$i6;
     } else {
      $105 = ($width>>>0)>(256);
      $106 = $105 ? 256 : $width;
      $107 = HEAP32[$ar$i>>2]|0;
      _memcpy(($tmp$i6|0),($107|0),($106|0))|0;
      $108 = ($106|0)==($width|0);
      if ($108) {
       $126 = $tmp$i6;
       break;
      } else {
       $$02$i3 = $width;$122 = $106;
      }
      while(1) {
       $121 = (($$02$i3) - ($122))|0;
       $123 = ($121>>>0)>(256);
       $124 = $123 ? 256 : $121;
       _memcpy(($tmp$i6|0),($107|0),($124|0))|0;
       $125 = ($121|0)==($124|0);
       if ($125) {
        $126 = $tmp$i6;
        break L45;
       } else {
        $$02$i3 = $121;$122 = $124;
       }
      }
     }
     while(1) {
      $118 = ($$02$us$i>>>0)>(256);
      $110 = $118 ? 256 : $$02$us$i;
      $119 = HEAP32[$ar$i>>2]|0;
      _memcpy(($120|0),($119|0),($110|0))|0;
      $116 = $119;$i$01$us$i = 0;
      while(1) {
       $112 = (($ar$i) + ($i$01$us$i<<2)|0);
       $113 = (($i$01$us$i) + 1)|0;
       $114 = (($ar$i) + ($113<<2)|0);
       $115 = HEAP32[$114>>2]|0;
       _memcpy(($116|0),($115|0),($110|0))|0;
       $117 = (($116) + ($110)|0);
       HEAP32[$112>>2] = $117;
       $exitcond$i = ($113|0)==($i$0$lcssa$i|0);
       if ($exitcond$i) {
        break;
       } else {
        $116 = $115;$i$01$us$i = $113;
       }
      }
      $109 = ($$02$us$i|0)==($110|0);
      if ($109) {
       $126 = $tmp$i6;
       break L45;
      }
      $111 = (($$02$us$i) - ($110))|0;
      $$pre$i3 = HEAP32[$102>>2]|0;
      $$02$us$i = $111;$120 = $$pre$i3;
     }
    }
   }
  } else {
   $126 = $tmp$i6;
  }
 } while(0);
 STACKTOP = sp;return;
}
function ___memrchr($m,$c,$n) {
 $m = $m|0;
 $c = $c|0;
 $n = $n|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c&255;
 $$01 = $n;
 while(1) {
  $1 = (($$01) + -1)|0;
  $2 = ($$01|0)==(0);
  if ($2) {
   $$0 = 0;
   label = 4;
   break;
  }
  $3 = (($m) + ($1)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==($0<<24>>24);
  if ($5) {
   $$0 = $3;
   label = 4;
   break;
  } else {
   $$01 = $1;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _strchr($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___strchrnul($s,$c)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $c&255;
 $3 = ($1<<24>>24)==($2<<24>>24);
 $4 = $3 ? $0 : 0;
 STACKTOP = sp;return ($4|0);
}
function ___strchrnul($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $$0 = 0, $$02$lcssa = 0, $$026 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $w$0$lcssa = 0, $w$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c & 255;
 $1 = ($0|0)==(0);
 if ($1) {
  $6 = (_strlen(($s|0))|0);
  $7 = (($s) + ($6)|0);
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $s;
 $3 = $2 & 3;
 $4 = ($3|0)==(0);
 L5: do {
  if ($4) {
   $$02$lcssa = $s;
  } else {
   $5 = $c&255;
   $$026 = $s;
   while(1) {
    $12 = HEAP8[$$026>>0]|0;
    $13 = ($12<<24>>24)==(0);
    if ($13) {
     $$0 = $$026;
     label = 13;
     break;
    }
    $14 = ($12<<24>>24)==($5<<24>>24);
    $9 = (($$026) + 1|0);
    if ($14) {
     $$0 = $$026;
     label = 13;
     break;
    }
    $8 = $9;
    $10 = $8 & 3;
    $11 = ($10|0)==(0);
    if ($11) {
     $$02$lcssa = $9;
     break L5;
    } else {
     $$026 = $9;
    }
   }
   if ((label|0) == 13) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $15 = Math_imul($0, 16843009)|0;
 $16 = HEAP32[$$02$lcssa>>2]|0;
 $17 = (($16) + -16843009)|0;
 $18 = $16 & -2139062144;
 $19 = $18 ^ -2139062144;
 $20 = $19 & $17;
 $21 = ($20|0)==(0);
 L15: do {
  if ($21) {
   $30 = $16;$w$03 = $$02$lcssa;
   while(1) {
    $29 = $30 ^ $15;
    $31 = (($29) + -16843009)|0;
    $32 = $29 & -2139062144;
    $33 = $32 ^ -2139062144;
    $34 = $33 & $31;
    $35 = ($34|0)==(0);
    $23 = (($w$03) + 4|0);
    if (!($35)) {
     $w$0$lcssa = $w$03;
     break L15;
    }
    $22 = HEAP32[$23>>2]|0;
    $24 = (($22) + -16843009)|0;
    $25 = $22 & -2139062144;
    $26 = $25 ^ -2139062144;
    $27 = $26 & $24;
    $28 = ($27|0)==(0);
    if ($28) {
     $30 = $22;$w$03 = $23;
    } else {
     $w$0$lcssa = $23;
     break;
    }
   }
  } else {
   $w$0$lcssa = $$02$lcssa;
  }
 } while(0);
 $36 = $c&255;
 $$1 = $w$0$lcssa;
 while(1) {
  $37 = HEAP8[$$1>>0]|0;
  $38 = ($37<<24>>24)==(0);
  $39 = ($37<<24>>24)==($36<<24>>24);
  $or$cond = $38 | $39;
  $40 = (($$1) + 1|0);
  if ($or$cond) {
   $$0 = $$1;
   break;
  } else {
   $$1 = $40;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function ___strdup($s) {
 $s = $s|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($s|0))|0);
 $1 = (($0) + 1)|0;
 $2 = (_malloc($1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 _memcpy(($2|0),($s|0),($1|0))|0;
 $$0 = $2;
 STACKTOP = sp;return ($$0|0);
}
function _strlcpy($d,$s,$n) {
 $d = $d|0;
 $s = $s|0;
 $n = $n|0;
 var $$0$lcssa = 0, $$0$lcssa51 = 0, $$025 = 0, $$04$lcssa = 0, $$04$lcssa52 = 0, $$0424 = 0, $$07$lcssa = 0, $$07$lcssa53 = 0, $$0723 = 0, $$1$lcssa = 0, $$1$ph = 0, $$112 = 0, $$15$lcssa = 0, $$1514 = 0, $$18$lcssa = 0, $$18$ph = 0, $$1810 = 0, $$2 = 0, $$26$ph = 0, $$2611 = 0;
 var $$29 = 0, $$lcssa = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond22 = 0, $wd$0$lcssa = 0, $wd$015 = 0, $ws$0$lcssa = 0, $ws$016 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($n) + -1)|0;
 $1 = ($n|0)==(0);
 if ($1) {
  $$pre = $d;
  $$2 = $d;$$29 = $s;$$pre$phiZ2D = $$pre;
  $39 = $$2;
  $40 = (($39) - ($$pre$phiZ2D))|0;
  $41 = (_strlen(($$29|0))|0);
  $42 = (($40) + ($41))|0;
  STACKTOP = sp;return ($42|0);
 }
 $2 = $s;
 $3 = $d;
 $4 = $2 ^ $3;
 $5 = $4 & 3;
 $6 = ($5|0)==(0);
 do {
  if ($6) {
   $7 = $2 & 3;
   $8 = ($7|0)==(0);
   $9 = ($0|0)==(0);
   $or$cond22 = $8 | $9;
   L7: do {
    if ($or$cond22) {
     $$0$lcssa = $d;$$04$lcssa = $0;$$07$lcssa = $s;$$lcssa = $9;
     label = 7;
    } else {
     $$025 = $d;$$0424 = $0;$$0723 = $s;
     while(1) {
      $10 = HEAP8[$$0723>>0]|0;
      HEAP8[$$025>>0] = $10;
      $11 = ($10<<24>>24)==(0);
      if ($11) {
       $$0$lcssa51 = $$025;$$04$lcssa52 = $$0424;$$07$lcssa53 = $$0723;
       break L7;
      }
      $12 = (($$0424) + -1)|0;
      $13 = (($$0723) + 1|0);
      $14 = (($$025) + 1|0);
      $15 = $13;
      $16 = $15 & 3;
      $17 = ($16|0)==(0);
      $18 = ($12|0)==(0);
      $or$cond = $17 | $18;
      if ($or$cond) {
       $$0$lcssa = $14;$$04$lcssa = $12;$$07$lcssa = $13;$$lcssa = $18;
       label = 7;
       break;
      } else {
       $$025 = $14;$$0424 = $12;$$0723 = $13;
      }
     }
    }
   } while(0);
   if ((label|0) == 7) {
    if ($$lcssa) {
     $$1$lcssa = $$0$lcssa;$$18$lcssa = $$07$lcssa;
     break;
    } else {
     $$0$lcssa51 = $$0$lcssa;$$04$lcssa52 = $$04$lcssa;$$07$lcssa53 = $$07$lcssa;
    }
   }
   $19 = HEAP8[$$07$lcssa53>>0]|0;
   $20 = ($19<<24>>24)==(0);
   if ($20) {
    $$1$ph = $$0$lcssa51;$$18$ph = $$07$lcssa53;$$26$ph = $$04$lcssa52;
    label = 13;
   } else {
    $21 = ($$04$lcssa52>>>0)>(3);
    L15: do {
     if ($21) {
      $$1514 = $$04$lcssa52;$wd$015 = $$0$lcssa51;$ws$016 = $$07$lcssa53;
      while(1) {
       $22 = HEAP32[$ws$016>>2]|0;
       $23 = (($22) + -16843009)|0;
       $24 = $22 & -2139062144;
       $25 = $24 ^ -2139062144;
       $26 = $25 & $23;
       $27 = ($26|0)==(0);
       if (!($27)) {
        $$15$lcssa = $$1514;$wd$0$lcssa = $wd$015;$ws$0$lcssa = $ws$016;
        break L15;
       }
       HEAP32[$wd$015>>2] = $22;
       $28 = (($$1514) + -4)|0;
       $29 = (($ws$016) + 4|0);
       $30 = (($wd$015) + 4|0);
       $31 = ($28>>>0)>(3);
       if ($31) {
        $$1514 = $28;$wd$015 = $30;$ws$016 = $29;
       } else {
        $$15$lcssa = $28;$wd$0$lcssa = $30;$ws$0$lcssa = $29;
        break;
       }
      }
     } else {
      $$15$lcssa = $$04$lcssa52;$wd$0$lcssa = $$0$lcssa51;$ws$0$lcssa = $$07$lcssa53;
     }
    } while(0);
    $$1$ph = $wd$0$lcssa;$$18$ph = $ws$0$lcssa;$$26$ph = $$15$lcssa;
    label = 13;
   }
  } else {
   $$1$ph = $d;$$18$ph = $s;$$26$ph = $0;
   label = 13;
  }
 } while(0);
 L20: do {
  if ((label|0) == 13) {
   $32 = ($$26$ph|0)==(0);
   if ($32) {
    $$1$lcssa = $$1$ph;$$18$lcssa = $$18$ph;
   } else {
    $$112 = $$1$ph;$$1810 = $$18$ph;$$2611 = $$26$ph;
    while(1) {
     $33 = HEAP8[$$1810>>0]|0;
     HEAP8[$$112>>0] = $33;
     $34 = ($33<<24>>24)==(0);
     if ($34) {
      $$1$lcssa = $$112;$$18$lcssa = $$1810;
      break L20;
     }
     $35 = (($$2611) + -1)|0;
     $36 = (($$1810) + 1|0);
     $37 = (($$112) + 1|0);
     $38 = ($35|0)==(0);
     if ($38) {
      $$1$lcssa = $37;$$18$lcssa = $36;
      break;
     } else {
      $$112 = $37;$$1810 = $36;$$2611 = $35;
     }
    }
   }
  }
 } while(0);
 HEAP8[$$1$lcssa>>0] = 0;
 $$2 = $$1$lcssa;$$29 = $$18$lcssa;$$pre$phiZ2D = $3;
 $39 = $$2;
 $40 = (($39) - ($$pre$phiZ2D))|0;
 $41 = (_strlen(($$29|0))|0);
 $42 = (($40) + ($41))|0;
 STACKTOP = sp;return ($42|0);
}
function _strncat($d,$s,$n) {
 $d = $d|0;
 $s = $s|0;
 $n = $n|0;
 var $$0$lcssa = 0, $$014 = 0, $$023 = 0, $$05 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($d|0))|0);
 $1 = (($d) + ($0)|0);
 $2 = ($n|0)==(0);
 L1: do {
  if ($2) {
   $$0$lcssa = $1;
  } else {
   $$014 = $n;$$023 = $s;$$05 = $1;
   while(1) {
    $3 = HEAP8[$$023>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     $$0$lcssa = $$05;
     break L1;
    }
    $5 = (($$014) + -1)|0;
    $6 = (($$023) + 1|0);
    $7 = (($$05) + 1|0);
    HEAP8[$$05>>0] = $3;
    $8 = ($5|0)==(0);
    if ($8) {
     $$0$lcssa = $7;
     break;
    } else {
     $$014 = $5;$$023 = $6;$$05 = $7;
    }
   }
  }
 } while(0);
 HEAP8[$$0$lcssa>>0] = 0;
 STACKTOP = sp;return ($d|0);
}
function _strrchr($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($s|0))|0);
 $1 = (($0) + 1)|0;
 $2 = (___memrchr($s,$c,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function _strstr($h,$n) {
 $h = $h|0;
 $n = $n|0;
 var $$$i = 0, $$$i16 = 0, $$$i8 = 0, $$0 = 0, $$0$lcssa$i = 0, $$0$lcssa$i15 = 0, $$0$lcssa$i7 = 0, $$01$i = 0, $$02$i = 0, $$02$i11 = 0, $$02$i5 = 0, $$02$us$i = 0, $$lcssa$i = 0, $$lcssa$i14 = 0, $$mem$0$us$i = 0, $$pr$i = 0, $$pr$us$i = 0, $0 = 0, $1 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $byteset$i = 0, $hw$0$in2$i = 0, $hw$03$i = 0, $hw$03$i10 = 0, $ip$0$ph78$i = 0, $ip$0$ph78146$i = 0;
 var $ip$0$ph81$i = 0, $ip$1$ip$0$$i = 0, $ip$1$ip$0$i = 0, $ip$1$ph58$i = 0, $ip$1$ph61$i = 0, $jp$0$ph22$ph72$i = 0, $jp$0$ph2266$i = 0, $jp$0$ph82$i = 0, $jp$1$ph11$ph52$i = 0, $jp$1$ph1146$i = 0, $jp$1$ph62$i = 0, $k$030$i = 0, $k$117$i = 0, $k$2$us$i = 0, $k$37$i = 0, $k$37$us$i = 0, $k$4$i = 0, $k$4$us$i = 0, $l$039$i = 0, $mem$0$us$i = 0;
 var $notlhs$i = 0, $notrhs$us$i = 0, $or$cond$i = 0, $or$cond$i12 = 0, $or$cond3$us$i = 0, $p$0$ph$ph70$i = 0, $p$0$ph$ph70150$i = 0, $p$0$ph$ph73$i = 0, $p$1$p$0$i = 0, $p$1$ph$ph50$i = 0, $p$1$ph$ph53$i = 0, $p$3155$i = 0, $shift$i = 0, $z$0$i = 0, $z$0$us$i = 0, $z$1$i = 0, $z$1$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0;
 $byteset$i = sp + 1024|0;
 $shift$i = sp;
 $0 = HEAP8[$n>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$0 = $h;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $0 << 24 >> 24;
 $3 = (_strchr($h,$2)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($n) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = (($3) + 1|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($n) + 2|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $14 = $0&255;
  $15 = $14 << 8;
  $16 = $6&255;
  $17 = $16 | $15;
  $18 = HEAP8[$3>>0]|0;
  $19 = $18&255;
  $20 = $9&255;
  $21 = $19 << 8;
  $22 = $21 | $20;
  $$01$i = $8;$270 = $9;$hw$0$in2$i = $22;
  while(1) {
   $23 = $hw$0$in2$i & 65535;
   $24 = ($23|0)==($17|0);
   if ($24) {
    $$0$lcssa$i = $$01$i;$32 = $270;
    break;
   }
   $25 = $23 << 8;
   $26 = (($$01$i) + 1|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   $29 = $28 | $25;
   $30 = ($27<<24>>24)==(0);
   if ($30) {
    $$0$lcssa$i = $26;$32 = 0;
    break;
   } else {
    $$01$i = $26;$270 = $27;$hw$0$in2$i = $29;
   }
  }
  $31 = ($32<<24>>24)==(0);
  $33 = (($$0$lcssa$i) + -1|0);
  $$$i = $31 ? 0 : $33;
  $$0 = $$$i;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = (($3) + 2|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = ($35<<24>>24)==(0);
 if ($36) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = (($n) + 3|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  $40 = $0&255;
  $41 = $40 << 24;
  $42 = $6&255;
  $43 = $42 << 16;
  $44 = $43 | $41;
  $45 = $12&255;
  $46 = $45 << 8;
  $47 = $44 | $46;
  $48 = HEAP8[$3>>0]|0;
  $49 = $48&255;
  $50 = $49 << 24;
  $51 = $9&255;
  $52 = $51 << 16;
  $53 = $35&255;
  $54 = $53 << 8;
  $55 = $54 | $52;
  $56 = $55 | $50;
  $57 = ($56|0)==($47|0);
  if ($57) {
   $$0$lcssa$i7 = $34;$$lcssa$i = 0;
  } else {
   $$02$i5 = $34;$hw$03$i = $56;
   while(1) {
    $58 = (($$02$i5) + 1|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    $61 = $60 | $hw$03$i;
    $62 = $61 << 8;
    $63 = ($59<<24>>24)==(0);
    $64 = ($62|0)==($47|0);
    $or$cond$i = $63 | $64;
    if ($or$cond$i) {
     $$0$lcssa$i7 = $58;$$lcssa$i = $63;
     break;
    } else {
     $$02$i5 = $58;$hw$03$i = $62;
    }
   }
  }
  $65 = (($$0$lcssa$i7) + -2|0);
  $$$i8 = $$lcssa$i ? 0 : $65;
  $$0 = $$$i8;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = (($3) + 3|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = ($67<<24>>24)==(0);
 if ($68) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $69 = (($n) + 4|0);
 $70 = HEAP8[$69>>0]|0;
 $71 = ($70<<24>>24)==(0);
 if ($71) {
  $72 = $0&255;
  $73 = $72 << 24;
  $74 = $6&255;
  $75 = $74 << 16;
  $76 = $75 | $73;
  $77 = $12&255;
  $78 = $77 << 8;
  $79 = $76 | $78;
  $80 = $38&255;
  $81 = $79 | $80;
  $82 = HEAP8[$3>>0]|0;
  $83 = $82&255;
  $84 = $83 << 24;
  $85 = $9&255;
  $86 = $85 << 16;
  $87 = $35&255;
  $88 = $87 << 8;
  $89 = $67&255;
  $90 = $88 | $86;
  $91 = $90 | $89;
  $92 = $91 | $84;
  $93 = ($92|0)==($81|0);
  if ($93) {
   $$0$lcssa$i15 = $66;$$lcssa$i14 = 0;
  } else {
   $$02$i11 = $66;$hw$03$i10 = $92;
   while(1) {
    $94 = $hw$03$i10 << 8;
    $95 = (($$02$i11) + 1|0);
    $96 = HEAP8[$95>>0]|0;
    $97 = $96&255;
    $98 = $97 | $94;
    $99 = ($96<<24>>24)==(0);
    $100 = ($98|0)==($81|0);
    $or$cond$i12 = $99 | $100;
    if ($or$cond$i12) {
     $$0$lcssa$i15 = $95;$$lcssa$i14 = $99;
     break;
    } else {
     $$02$i11 = $95;$hw$03$i10 = $98;
    }
   }
  }
  $101 = (($$0$lcssa$i15) + -3|0);
  $$$i16 = $$lcssa$i14 ? 0 : $101;
  $$0 = $$$i16;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$byteset$i+0>>2]=0|0;HEAP32[$byteset$i+4>>2]=0|0;HEAP32[$byteset$i+8>>2]=0|0;HEAP32[$byteset$i+12>>2]=0|0;HEAP32[$byteset$i+16>>2]=0|0;HEAP32[$byteset$i+20>>2]=0|0;HEAP32[$byteset$i+24>>2]=0|0;HEAP32[$byteset$i+28>>2]=0|0;
 $106 = $0;$l$039$i = 0;
 while(1) {
  $102 = (($3) + ($l$039$i)|0);
  $103 = HEAP8[$102>>0]|0;
  $104 = ($103<<24>>24)==(0);
  if ($104) {
   $$0 = 0;
   label = 79;
   break;
  }
  $105 = $106&255;
  $107 = $105 & 31;
  $108 = 1 << $107;
  $109 = $105 >>> 5;
  $110 = (($byteset$i) + ($109<<2)|0);
  $111 = HEAP32[$110>>2]|0;
  $112 = $111 | $108;
  HEAP32[$110>>2] = $112;
  $113 = (($l$039$i) + 1)|0;
  $114 = (($shift$i) + ($105<<2)|0);
  HEAP32[$114>>2] = $113;
  $115 = (($n) + ($113)|0);
  $116 = HEAP8[$115>>0]|0;
  $117 = ($116<<24>>24)==(0);
  if ($117) {
   break;
  } else {
   $106 = $116;$l$039$i = $113;
  }
 }
 if ((label|0) == 79) {
  STACKTOP = sp;return ($$0|0);
 }
 $118 = ($113>>>0)>(1);
 L49: do {
  if ($118) {
   $271 = 1;$ip$0$ph81$i = -1;$jp$0$ph82$i = 0;
   L50: while(1) {
    $272 = $271;$jp$0$ph22$ph72$i = $jp$0$ph82$i;$p$0$ph$ph73$i = 1;
    while(1) {
     $273 = $272;$jp$0$ph2266$i = $jp$0$ph22$ph72$i;
     L54: while(1) {
      $120 = $273;$k$030$i = 1;
      while(1) {
       $125 = (($k$030$i) + ($ip$0$ph81$i))|0;
       $126 = (($n) + ($125)|0);
       $127 = HEAP8[$126>>0]|0;
       $128 = (($n) + ($120)|0);
       $129 = HEAP8[$128>>0]|0;
       $130 = ($127<<24>>24)==($129<<24>>24);
       if (!($130)) {
        break L54;
       }
       $131 = ($k$030$i|0)==($p$0$ph$ph73$i|0);
       $123 = (($k$030$i) + 1)|0;
       if ($131) {
        break;
       }
       $122 = (($123) + ($jp$0$ph2266$i))|0;
       $124 = ($122>>>0)<($113>>>0);
       if ($124) {
        $120 = $122;$k$030$i = $123;
       } else {
        $ip$0$ph78$i = $ip$0$ph81$i;$p$0$ph$ph70$i = $p$0$ph$ph73$i;
        break L50;
       }
      }
      $132 = (($jp$0$ph2266$i) + ($p$0$ph$ph73$i))|0;
      $133 = (($132) + 1)|0;
      $134 = ($133>>>0)<($113>>>0);
      if ($134) {
       $273 = $133;$jp$0$ph2266$i = $132;
      } else {
       $ip$0$ph78$i = $ip$0$ph81$i;$p$0$ph$ph70$i = $p$0$ph$ph73$i;
       break L50;
      }
     }
     $135 = ($127&255)>($129&255);
     $136 = (($120) - ($ip$0$ph81$i))|0;
     if (!($135)) {
      break;
     }
     $119 = (($120) + 1)|0;
     $121 = ($119>>>0)<($113>>>0);
     if ($121) {
      $272 = $119;$jp$0$ph22$ph72$i = $120;$p$0$ph$ph73$i = $136;
     } else {
      $ip$0$ph78$i = $ip$0$ph81$i;$p$0$ph$ph70$i = $136;
      break L50;
     }
    }
    $137 = (($jp$0$ph2266$i) + 1)|0;
    $138 = (($jp$0$ph2266$i) + 2)|0;
    $139 = ($138>>>0)<($113>>>0);
    if ($139) {
     $271 = $138;$ip$0$ph81$i = $jp$0$ph2266$i;$jp$0$ph82$i = $137;
    } else {
     $ip$0$ph78$i = $jp$0$ph2266$i;$p$0$ph$ph70$i = 1;
     break;
    }
   }
   $274 = 1;$ip$1$ph61$i = -1;$jp$1$ph62$i = 0;
   while(1) {
    $276 = $274;$jp$1$ph11$ph52$i = $jp$1$ph62$i;$p$1$ph$ph53$i = 1;
    while(1) {
     $275 = $276;$jp$1$ph1146$i = $jp$1$ph11$ph52$i;
     L69: while(1) {
      $147 = $275;$k$117$i = 1;
      while(1) {
       $143 = (($k$117$i) + ($ip$1$ph61$i))|0;
       $144 = (($n) + ($143)|0);
       $145 = HEAP8[$144>>0]|0;
       $146 = (($n) + ($147)|0);
       $148 = HEAP8[$146>>0]|0;
       $149 = ($145<<24>>24)==($148<<24>>24);
       if (!($149)) {
        break L69;
       }
       $150 = ($k$117$i|0)==($p$1$ph$ph53$i|0);
       $141 = (($k$117$i) + 1)|0;
       if ($150) {
        break;
       }
       $140 = (($141) + ($jp$1$ph1146$i))|0;
       $142 = ($140>>>0)<($113>>>0);
       if ($142) {
        $147 = $140;$k$117$i = $141;
       } else {
        $ip$0$ph78146$i = $ip$0$ph78$i;$ip$1$ph58$i = $ip$1$ph61$i;$p$0$ph$ph70150$i = $p$0$ph$ph70$i;$p$1$ph$ph50$i = $p$1$ph$ph53$i;
        break L49;
       }
      }
      $151 = (($jp$1$ph1146$i) + ($p$1$ph$ph53$i))|0;
      $152 = (($151) + 1)|0;
      $153 = ($152>>>0)<($113>>>0);
      if ($153) {
       $275 = $152;$jp$1$ph1146$i = $151;
      } else {
       $ip$0$ph78146$i = $ip$0$ph78$i;$ip$1$ph58$i = $ip$1$ph61$i;$p$0$ph$ph70150$i = $p$0$ph$ph70$i;$p$1$ph$ph50$i = $p$1$ph$ph53$i;
       break L49;
      }
     }
     $154 = ($145&255)<($148&255);
     $155 = (($147) - ($ip$1$ph61$i))|0;
     if (!($154)) {
      break;
     }
     $156 = (($147) + 1)|0;
     $157 = ($156>>>0)<($113>>>0);
     if ($157) {
      $276 = $156;$jp$1$ph11$ph52$i = $147;$p$1$ph$ph53$i = $155;
     } else {
      $ip$0$ph78146$i = $ip$0$ph78$i;$ip$1$ph58$i = $ip$1$ph61$i;$p$0$ph$ph70150$i = $p$0$ph$ph70$i;$p$1$ph$ph50$i = $155;
      break L49;
     }
    }
    $158 = (($jp$1$ph1146$i) + 1)|0;
    $159 = (($jp$1$ph1146$i) + 2)|0;
    $160 = ($159>>>0)<($113>>>0);
    if ($160) {
     $274 = $159;$ip$1$ph61$i = $jp$1$ph1146$i;$jp$1$ph62$i = $158;
    } else {
     $ip$0$ph78146$i = $ip$0$ph78$i;$ip$1$ph58$i = $jp$1$ph1146$i;$p$0$ph$ph70150$i = $p$0$ph$ph70$i;$p$1$ph$ph50$i = 1;
     break;
    }
   }
  } else {
   $ip$0$ph78146$i = -1;$ip$1$ph58$i = -1;$p$0$ph$ph70150$i = 1;$p$1$ph$ph50$i = 1;
  }
 } while(0);
 $161 = (($ip$1$ph58$i) + 1)|0;
 $162 = (($ip$0$ph78146$i) + 1)|0;
 $163 = ($161>>>0)>($162>>>0);
 $p$1$p$0$i = $163 ? $p$1$ph$ph50$i : $p$0$ph$ph70150$i;
 $ip$1$ip$0$i = $163 ? $ip$1$ph58$i : $ip$0$ph78146$i;
 $164 = (($n) + ($p$1$p$0$i)|0);
 $165 = (($ip$1$ip$0$i) + 1)|0;
 $166 = (_memcmp($n,$164,$165)|0);
 $167 = ($166|0)==(0);
 if ($167) {
  $173 = (($113) - ($p$1$p$0$i))|0;
  $174 = $113 | 63;
  $notlhs$i = ($113|0)==($p$1$p$0$i|0);
  if ($notlhs$i) {
   $228 = $174;$p$3155$i = $113;
  } else {
   $$02$us$i = $3;$mem$0$us$i = 0;$z$0$us$i = $3;
   L83: while(1) {
    $176 = $z$0$us$i;
    $177 = $$02$us$i;
    $178 = (($176) - ($177))|0;
    $179 = ($178>>>0)<($113>>>0);
    do {
     if ($179) {
      $180 = (_memchr($z$0$us$i,0,$174)|0);
      $181 = ($180|0)==(0|0);
      if ($181) {
       $185 = (($z$0$us$i) + ($174)|0);
       $z$1$us$i = $185;
       break;
      } else {
       $182 = $180;
       $183 = (($182) - ($177))|0;
       $184 = ($183>>>0)<($113>>>0);
       if ($184) {
        $$0 = 0;
        label = 79;
        break L83;
       } else {
        $z$1$us$i = $180;
        break;
       }
      }
     } else {
      $z$1$us$i = $z$0$us$i;
     }
    } while(0);
    $186 = (($$02$us$i) + ($l$039$i)|0);
    $187 = HEAP8[$186>>0]|0;
    $188 = $187&255;
    $189 = $188 >>> 5;
    $190 = (($byteset$i) + ($189<<2)|0);
    $191 = HEAP32[$190>>2]|0;
    $192 = $188 & 31;
    $193 = 1 << $192;
    $194 = $193 & $191;
    $195 = ($194|0)==(0);
    if ($195) {
     $223 = (($$02$us$i) + ($113)|0);
     $$02$us$i = $223;$mem$0$us$i = 0;$z$0$us$i = $z$1$us$i;
     continue;
    }
    $196 = (($shift$i) + ($188<<2)|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = (($113) - ($197))|0;
    $199 = ($113|0)==($197|0);
    if (!($199)) {
     $notrhs$us$i = ($mem$0$us$i|0)!=(0);
     $200 = ($198>>>0)<($p$1$p$0$i>>>0);
     $or$cond3$us$i = $notrhs$us$i & $200;
     $k$2$us$i = $or$cond3$us$i ? $173 : $198;
     $201 = (($$02$us$i) + ($k$2$us$i)|0);
     $$02$us$i = $201;$mem$0$us$i = 0;$z$0$us$i = $z$1$us$i;
     continue;
    }
    $202 = ($165>>>0)>($mem$0$us$i>>>0);
    $$mem$0$us$i = $202 ? $165 : $mem$0$us$i;
    $203 = (($n) + ($$mem$0$us$i)|0);
    $204 = HEAP8[$203>>0]|0;
    $205 = ($204<<24>>24)==(0);
    L97: do {
     if ($205) {
      $k$4$us$i = $165;
     } else {
      $$pr$us$i = $204;$k$37$us$i = $$mem$0$us$i;
      while(1) {
       $210 = (($$02$us$i) + ($k$37$us$i)|0);
       $211 = HEAP8[$210>>0]|0;
       $212 = ($$pr$us$i<<24>>24)==($211<<24>>24);
       $207 = (($k$37$us$i) + 1)|0;
       if (!($212)) {
        break;
       }
       $206 = (($n) + ($207)|0);
       $208 = HEAP8[$206>>0]|0;
       $209 = ($208<<24>>24)==(0);
       if ($209) {
        $k$4$us$i = $165;
        break L97;
       } else {
        $$pr$us$i = $208;$k$37$us$i = $207;
       }
      }
      $213 = (($k$37$us$i) - ($ip$1$ip$0$i))|0;
      $214 = (($$02$us$i) + ($213)|0);
      $$02$us$i = $214;$mem$0$us$i = 0;$z$0$us$i = $z$1$us$i;
      continue L83;
     }
    } while(0);
    while(1) {
     $215 = ($k$4$us$i>>>0)>($mem$0$us$i>>>0);
     if (!($215)) {
      $$0 = $$02$us$i;
      label = 79;
      break L83;
     }
     $216 = (($k$4$us$i) + -1)|0;
     $217 = (($n) + ($216)|0);
     $218 = HEAP8[$217>>0]|0;
     $219 = (($$02$us$i) + ($216)|0);
     $220 = HEAP8[$219>>0]|0;
     $221 = ($218<<24>>24)==($220<<24>>24);
     if ($221) {
      $k$4$us$i = $216;
     } else {
      break;
     }
    }
    $222 = (($$02$us$i) + ($p$1$p$0$i)|0);
    $$02$us$i = $222;$mem$0$us$i = $173;$z$0$us$i = $z$1$us$i;
   }
   if ((label|0) == 79) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } else {
  $168 = (($113) - ($ip$1$ip$0$i))|0;
  $169 = (($168) + -1)|0;
  $170 = ($ip$1$ip$0$i>>>0)>($169>>>0);
  $ip$1$ip$0$$i = $170 ? $ip$1$ip$0$i : $169;
  $171 = (($ip$1$ip$0$$i) + 1)|0;
  $172 = $113 | 63;
  $228 = $172;$p$3155$i = $171;
 }
 $175 = (($n) + ($165)|0);
 $$02$i = $3;$z$0$i = $3;
 L110: while(1) {
  $224 = $z$0$i;
  $225 = $$02$i;
  $226 = (($224) - ($225))|0;
  $227 = ($226>>>0)<($113>>>0);
  do {
   if ($227) {
    $229 = (_memchr($z$0$i,0,$228)|0);
    $230 = ($229|0)==(0|0);
    if ($230) {
     $234 = (($z$0$i) + ($228)|0);
     $z$1$i = $234;
     break;
    } else {
     $231 = $229;
     $232 = (($231) - ($225))|0;
     $233 = ($232>>>0)<($113>>>0);
     if ($233) {
      $$0 = 0;
      label = 79;
      break L110;
     } else {
      $z$1$i = $229;
      break;
     }
    }
   } else {
    $z$1$i = $z$0$i;
   }
  } while(0);
  $235 = (($$02$i) + ($l$039$i)|0);
  $236 = HEAP8[$235>>0]|0;
  $237 = $236&255;
  $238 = $237 >>> 5;
  $239 = (($byteset$i) + ($238<<2)|0);
  $240 = HEAP32[$239>>2]|0;
  $241 = $237 & 31;
  $242 = 1 << $241;
  $243 = $242 & $240;
  $244 = ($243|0)==(0);
  if ($244) {
   $250 = (($$02$i) + ($113)|0);
   $$02$i = $250;$z$0$i = $z$1$i;
   continue;
  }
  $245 = (($shift$i) + ($237<<2)|0);
  $246 = HEAP32[$245>>2]|0;
  $247 = ($113|0)==($246|0);
  if (!($247)) {
   $248 = (($113) - ($246))|0;
   $249 = (($$02$i) + ($248)|0);
   $$02$i = $249;$z$0$i = $z$1$i;
   continue;
  }
  $251 = HEAP8[$175>>0]|0;
  $252 = ($251<<24>>24)==(0);
  L124: do {
   if ($252) {
    $k$4$i = $165;
   } else {
    $$pr$i = $251;$k$37$i = $165;
    while(1) {
     $257 = (($$02$i) + ($k$37$i)|0);
     $258 = HEAP8[$257>>0]|0;
     $259 = ($$pr$i<<24>>24)==($258<<24>>24);
     $254 = (($k$37$i) + 1)|0;
     if (!($259)) {
      break;
     }
     $253 = (($n) + ($254)|0);
     $255 = HEAP8[$253>>0]|0;
     $256 = ($255<<24>>24)==(0);
     if ($256) {
      $k$4$i = $165;
      break L124;
     } else {
      $$pr$i = $255;$k$37$i = $254;
     }
    }
    $260 = (($k$37$i) - ($ip$1$ip$0$i))|0;
    $261 = (($$02$i) + ($260)|0);
    $$02$i = $261;$z$0$i = $z$1$i;
    continue L110;
   }
  } while(0);
  while(1) {
   $262 = ($k$4$i|0)==(0);
   if ($262) {
    $$0 = $$02$i;
    label = 79;
    break L110;
   }
   $263 = (($k$4$i) + -1)|0;
   $264 = (($n) + ($263)|0);
   $265 = HEAP8[$264>>0]|0;
   $266 = (($$02$i) + ($263)|0);
   $267 = HEAP8[$266>>0]|0;
   $268 = ($265<<24>>24)==($267<<24>>24);
   if ($268) {
    $k$4$i = $263;
   } else {
    break;
   }
  }
  $269 = (($$02$i) + ($p$3155$i)|0);
  $$02$i = $269;$z$0$i = $z$1$i;
 }
 if ((label|0) == 79) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _wcslen($s) {
 $s = $s|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $s;
 while(1) {
  $0 = HEAP32[$$0>>2]|0;
  $1 = ($0|0)==(0);
  $2 = (($$0) + 4|0);
  if ($1) {
   break;
  } else {
   $$0 = $2;
  }
 }
 $3 = $$0;
 $4 = $s;
 $5 = (($3) - ($4))|0;
 $6 = $5 >> 2;
 STACKTOP = sp;return ($6|0);
}
function _wmemcpy($d,$s,$n) {
 $d = $d|0;
 $s = $s|0;
 $n = $n|0;
 var $$014 = 0, $$023 = 0, $$05 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  STACKTOP = sp;return ($d|0);
 } else {
  $$014 = $n;$$023 = $s;$$05 = $d;
 }
 while(1) {
  $1 = (($$014) + -1)|0;
  $2 = (($$023) + 4|0);
  $3 = HEAP32[$$023>>2]|0;
  $4 = (($$05) + 4|0);
  HEAP32[$$05>>2] = $3;
  $5 = ($1|0)==(0);
  if ($5) {
   break;
  } else {
   $$014 = $1;$$023 = $2;$$05 = $4;
  }
 }
 STACKTOP = sp;return ($d|0);
}
function _wmemmove($d,$s,$n) {
 $d = $d|0;
 $s = $s|0;
 $n = $n|0;
 var $$025 = 0, $$07 = 0, $$16 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $d;
 $1 = $s;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = ($3>>>0)<($n>>>0);
 $5 = ($n|0)==(0);
 if ($4) {
  if (!($5)) {
   $$in = $n;
   while(1) {
    $6 = (($$in) + -1)|0;
    $7 = (($s) + ($6<<2)|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = (($d) + ($6<<2)|0);
    HEAP32[$9>>2] = $8;
    $10 = ($6|0)==(0);
    if ($10) {
     break;
    } else {
     $$in = $6;
    }
   }
  }
 } else {
  if (!($5)) {
   $$025 = $s;$$07 = $d;$$16 = $n;
   while(1) {
    $11 = (($$16) + -1)|0;
    $12 = (($$025) + 4|0);
    $13 = HEAP32[$$025>>2]|0;
    $14 = (($$07) + 4|0);
    HEAP32[$$07>>2] = $13;
    $15 = ($11|0)==(0);
    if ($15) {
     break;
    } else {
     $$025 = $12;$$07 = $14;$$16 = $11;
    }
   }
  }
 }
 STACKTOP = sp;return ($d|0);
}
function _wmemset($d,$c,$n) {
 $d = $d|0;
 $c = $c|0;
 $n = $n|0;
 var $$012 = 0, $$03 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if (!($0)) {
  $$012 = $n;$$03 = $d;
  while(1) {
   $1 = (($$012) + -1)|0;
   $2 = (($$03) + 4|0);
   HEAP32[$$03>>2] = $c;
   $3 = ($1|0)==(0);
   if ($3) {
    break;
   } else {
    $$012 = $1;$$03 = $2;
   }
  }
 }
 STACKTOP = sp;return ($d|0);
}
function _abort_message($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $list = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $list = sp;
 HEAP32[$list>>2] = $varargs;
 $0 = HEAP32[_stderr>>2]|0;
 (_vfprintf(($0|0),($format|0),($list|0))|0);
 (_fputc(10,($0|0))|0);
 _abort();
 // unreachable;
}
function __ZL25default_terminate_handlerv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $thrown_object = 0, $vararg_buffer10 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer10 = sp;
 $thrown_object = sp + 12|0;
 $0 = (___cxa_get_globals_fast()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  _abort_message(3105096,$vararg_buffer10);
  // unreachable;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  _abort_message(3105096,$vararg_buffer10);
  // unreachable;
 }
 $4 = (($2) + 80|0);
 $5 = (($2) + 48|0);
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $8 & -256;
 $13 = ($12|0)==(1126902528);
 $14 = ($11|0)==(1129074247);
 $15 = $13 & $14;
 if (!($15)) {
  HEAP32[$vararg_buffer10>>2] = 3104944;
  _abort_message(3105056,$vararg_buffer10);
  // unreachable;
 }
 $16 = ($8|0)==(1126902529);
 $17 = ($11|0)==(1129074247);
 $18 = $16 & $17;
 if ($18) {
  $19 = (($2) + 44|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20;
 } else {
  $21 = $4;
 }
 HEAP32[$thrown_object>>2] = $21;
 $22 = HEAP32[$2>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[3105488>>2]|0;
 $26 = (($25) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (FUNCTION_TABLE_iiii[$27 & 2047](3105488,$22,$thrown_object)|0);
 if ($28) {
  $29 = HEAP32[$thrown_object>>2]|0;
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 8|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (FUNCTION_TABLE_ii[$32 & 4095]($29)|0);
  HEAP32[$vararg_buffer10>>2] = 3104944;
  $vararg_ptr1 = (($vararg_buffer10) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $24;
  $vararg_ptr2 = (($vararg_buffer10) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $33;
  _abort_message(3104960,$vararg_buffer10);
  // unreachable;
 } else {
  HEAP32[$vararg_buffer10>>2] = 3104944;
  $vararg_ptr6 = (($vararg_buffer10) + 4|0);
  HEAP32[$vararg_ptr6>>2] = $24;
  _abort_message(3105008,$vararg_buffer10);
  // unreachable;
 }
}
function ___cxa_get_globals_fast() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (_pthread_once((3105120|0),(1013|0))|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = HEAP32[3105112>>2]|0;
  $3 = (_pthread_getspecific(($2|0))|0);
  STACKTOP = sp;return ($3|0);
 } else {
  _abort_message(3105128,$vararg_buffer);
  // unreachable;
 }
 return 0|0;
}
function __ZN10__cxxabiv112_GLOBAL__N_110construct_Ev() {
 var $0 = 0, $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (_pthread_key_create((3105112|0),(3859|0))|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  _abort_message(3105184,$vararg_buffer);
  // unreachable;
 }
}
function __ZN10__cxxabiv112_GLOBAL__N_19destruct_EPv($p) {
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 _free($p);
 $0 = HEAP32[3105112>>2]|0;
 $1 = (_pthread_setspecific(($0|0),(0|0))|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  _abort_message(3105240,$vararg_buffer);
  // unreachable;
 }
}
function __Znwj($size) {
 $size = $size|0;
 var $$lcssa = 0, $$size = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 $$size = $0 ? 1 : $size;
 $1 = (_malloc($$size)|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$lcssa = $1;
  STACKTOP = sp;return ($$lcssa|0);
 }
 while(1) {
  $3 = (__ZSt15get_new_handlerv()|0);
  $4 = ($3|0)==(0|0);
  if ($4) {
   label = 4;
   break;
  }
  FUNCTION_TABLE_v[$3 & 1023]();
  $5 = (_malloc($$size)|0);
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $$lcssa = $5;
   label = 5;
   break;
  }
 }
 if ((label|0) == 4) {
  $7 = (___cxa_allocate_exception(4)|0);
  HEAP32[$7>>2] = ((3105296 + 8|0));
  ___cxa_throw(($7|0),(3105352|0),(3280|0));
  // unreachable;
 }
 else if ((label|0) == 5) {
  STACKTOP = sp;return ($$lcssa|0);
 }
 return 0|0;
}
function __ZnwjRKSt9nothrow_t($size,$0) {
 $size = $size|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $1 = (invoke_ii(2988,($size|0))|0);
 $2 = __THREW__; __THREW__ = 0;
 $3 = $2&1;
 if (!($3)) {
  $p$0 = $1;
  STACKTOP = sp;return ($p$0|0);
 }
 $4 = ___cxa_find_matching_catch(0|0)|0;
 $5 = tempRet0;
 (___cxa_begin_catch(($4|0))|0);
 __THREW__ = 0;
 invoke_v(66);
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if ($7) {
  $8 = ___cxa_find_matching_catch(0|0)|0;
  $9 = tempRet0;
  ___clang_call_terminate($8);
  // unreachable;
 } else {
  $p$0 = 0;
  STACKTOP = sp;return ($p$0|0);
 }
 return 0|0;
}
function __Znaj($size) {
 $size = $size|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__Znwj($size)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZdlPv($ptr) {
 $ptr = $ptr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($ptr);
 STACKTOP = sp;return;
}
function __ZdaPv($ptr) {
 $ptr = $ptr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($ptr);
 STACKTOP = sp;return;
}
function __ZNSt9bad_allocC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3105296 + 8|0));
 STACKTOP = sp;return;
}
function __ZNSt9bad_allocD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt9bad_allocD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt9bad_alloc4whatEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (3105320|0);
}
function __ZSt11__terminatePFvvE($func) {
 $func = $func|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer1 = sp;
 __THREW__ = 0;
 invoke_v($func|0);
 $0 = __THREW__; __THREW__ = 0;
 $1 = $0&1;
 if (!($1)) {
  __THREW__ = 0;
  invoke_vii(3543,(3105368|0),($vararg_buffer1|0));
  $2 = __THREW__; __THREW__ = 0;
  $3 = $2&1;
  if (!($3)) {
   // unreachable;
  }
 }
 $4 = ___cxa_find_matching_catch(0|0)|0;
 $5 = tempRet0;
 (___cxa_begin_catch(($4|0))|0);
 __THREW__ = 0;
 invoke_vii(3543,(3105408|0),($vararg_buffer1|0));
 $6 = __THREW__; __THREW__ = 0;
 $7 = $6&1;
 if (!($7)) {
  // unreachable;
 }
 $8 = ___cxa_find_matching_catch(0|0)|0;
 $9 = tempRet0;
 __THREW__ = 0;
 invoke_v(66);
 $10 = __THREW__; __THREW__ = 0;
 $11 = $10&1;
 if ($11) {
  $12 = ___cxa_find_matching_catch(0|0)|0;
  $13 = tempRet0;
  ___clang_call_terminate($12);
  // unreachable;
 } else {
  __ZSt9terminatev();
  // unreachable;
 }
}
function __ZSt9terminatev() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __THREW__ = 0;
 $0 = (invoke_i(141)|0);
 $1 = __THREW__; __THREW__ = 0;
 $2 = $1&1;
 if ($2) {
  $21 = ___cxa_find_matching_catch(0|0)|0;
  $22 = tempRet0;
  ___clang_call_terminate($21);
  // unreachable;
 }
 $3 = ($0|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[$0>>2]|0;
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (($4) + 48|0);
   $7 = $6;
   $8 = $7;
   $9 = HEAP32[$8>>2]|0;
   $10 = (($7) + 4)|0;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   $13 = $9 & -256;
   $14 = ($13|0)==(1126902528);
   $15 = ($12|0)==(1129074247);
   $16 = $14 & $15;
   if ($16) {
    $17 = (($4) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    __ZSt11__terminatePFvvE($18);
    // unreachable;
   }
  }
 }
 $19 = HEAP32[776234]|0;HEAP32[776234] = (($19+0)|0);
 $20 = $19;
 __ZSt11__terminatePFvvE($20);
 // unreachable;
}
function __ZSt15get_new_handlerv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[3105464>>2]|0;HEAP32[3105464>>2] = (($0+0)|0);
 $1 = $0;
 STACKTOP = sp;return ($1|0);
}
function __ZNSt9exceptionD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt11logic_errorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt11logic_errorD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt11logic_errorD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3105496 + 8|0));
 $0 = (($this) + 4|0);
 __ZN12_GLOBAL__N_114__libcpp_nmstrD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNKSt11logic_error4whatEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNSt13runtime_errorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt13runtime_errorD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt13runtime_errorD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3105520 + 8|0));
 $0 = (($this) + 4|0);
 __ZN12_GLOBAL__N_114__libcpp_nmstrD2Ev($0);
 STACKTOP = sp;return;
}
function __ZNKSt13runtime_error4whatEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNSt12length_errorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt11logic_errorD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt12out_of_rangeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt11logic_errorD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt14overflow_errorD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNSt13runtime_errorD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_114__libcpp_nmstrD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + -4|0);
 $2 = HEAP32[$1>>2]|0;HEAP32[$1>>2] = (($2+-1)|0);
 $3 = (($2) + -1)|0;
 $4 = ($3|0)<(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($5) + -12|0);
 __ZdlPv($6);
 STACKTOP = sp;return;
}
function __ZNSt9type_infoD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt8bad_castC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((3105808 + 8|0));
 STACKTOP = sp;return;
}
function __ZNSt8bad_castD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt8bad_castD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt8bad_cast4whatEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (3105832|0);
}
function __ZN10__cxxabiv116__shim_type_infoD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv116__shim_type_info5noop1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv116__shim_type_info5noop2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10__cxxabiv117__class_type_infoD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN10__cxxabiv120__si_class_type_infoD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN10__cxxabiv121__vmi_class_type_infoD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv($this,$thrown_type,$adjustedPtr) {
 $this = $this|0;
 $thrown_type = $thrown_type|0;
 $adjustedPtr = $adjustedPtr|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $info = sp;
 $0 = ($this|0)==($thrown_type|0);
 if ($0) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $1 = ($thrown_type|0)==(0|0);
 if ($1) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $2 = (___dynamic_cast($thrown_type,3105944,3106000,0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 dest=$info+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$info>>2] = $2;
 $4 = (($info) + 8|0);
 HEAP32[$4>>2] = $this;
 $5 = (($info) + 12|0);
 HEAP32[$5>>2] = -1;
 $6 = (($info) + 48|0);
 HEAP32[$6>>2] = 1;
 $7 = HEAP32[$2>>2]|0;
 $8 = (($7) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$adjustedPtr>>2]|0;
 FUNCTION_TABLE_viiii[$9 & 511]($2,$info,$10,1);
 $11 = (($info) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(1);
 if (!($13)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $14 = (($info) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$adjustedPtr>>2] = $15;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi($this,$info,$adjustedPtr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $adjustedPtr = $adjustedPtr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$0>>2] = $adjustedPtr;
  $3 = (($info) + 24|0);
  HEAP32[$3>>2] = $path_below;
  $4 = (($info) + 36|0);
  HEAP32[$4>>2] = 1;
  STACKTOP = sp;return;
 }
 $5 = ($1|0)==($adjustedPtr|0);
 if (!($5)) {
  $9 = (($info) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$9>>2] = $11;
  $12 = (($info) + 24|0);
  HEAP32[$12>>2] = 2;
  $13 = (($info) + 54|0);
  HEAP8[$13>>0] = 1;
  STACKTOP = sp;return;
 }
 $6 = (($info) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(2);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 HEAP32[$6>>2] = $path_below;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($this,$info,$adjustedPtr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $adjustedPtr = $adjustedPtr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($this|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0,$info,$adjustedPtr,$path_below);
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($this,$info,$adjustedPtr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $adjustedPtr = $adjustedPtr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0,$info,$adjustedPtr,$path_below);
  STACKTOP = sp;return;
 } else {
  $3 = (($this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viiii[$7 & 511]($4,$info,$adjustedPtr,$path_below);
  STACKTOP = sp;return;
 }
}
function __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($this,$info,$adjustedPtr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $adjustedPtr = $adjustedPtr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset_to_base$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >> 8;
 $3 = $1 & 1;
 $4 = ($3|0)==(0);
 if ($4) {
  $offset_to_base$0 = $2;
 } else {
  $5 = HEAP32[$adjustedPtr>>2]|0;
  $6 = (($5) + ($2)|0);
  $7 = HEAP32[$6>>2]|0;
  $offset_to_base$0 = $7;
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($adjustedPtr) + ($offset_to_base$0)|0);
 $13 = $1 & 2;
 $14 = ($13|0)!=(0);
 $15 = $14 ? $path_below : 2;
 FUNCTION_TABLE_viiii[$11 & 511]($8,$info,$12,$15);
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($this,$info,$adjustedPtr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $adjustedPtr = $adjustedPtr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0,$info,$adjustedPtr,$path_below);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 16|0);
 $4 = (($this) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($this) + ($5<<3)|0) + 16|0);
 __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($3,$info,$adjustedPtr,$path_below);
 $7 = ($5|0)>(1);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 24|0);
 $9 = (($info) + 54|0);
 $p$0 = $8;
 while(1) {
  __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($p$0,$info,$adjustedPtr,$path_below);
  $10 = HEAP8[$9>>0]|0;
  $11 = ($10<<24>>24)==(0);
  if (!($11)) {
   label = 7;
   break;
  }
  $12 = (($p$0) + 8|0);
  $13 = ($12>>>0)<($6>>>0);
  if ($13) {
   $p$0 = $12;
  } else {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return;
 }
}
function ___dynamic_cast($static_ptr,$static_type,$dst_type,$src2dst_offset) {
 $static_ptr = $static_ptr|0;
 $static_type = $static_type|0;
 $dst_type = $dst_type|0;
 $src2dst_offset = $src2dst_offset|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dst_ptr$0 = 0, $info = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $info = sp;
 $0 = HEAP32[$static_ptr>>2]|0;
 $1 = (($0) + -8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = (($static_ptr) + ($3)|0);
 $5 = (($0) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$info>>2] = $dst_type;
 $7 = (($info) + 4|0);
 HEAP32[$7>>2] = $static_ptr;
 $8 = (($info) + 8|0);
 HEAP32[$8>>2] = $static_type;
 $9 = (($info) + 12|0);
 HEAP32[$9>>2] = $src2dst_offset;
 $10 = (($info) + 16|0);
 $11 = (($info) + 20|0);
 $12 = (($info) + 24|0);
 $13 = (($info) + 28|0);
 $14 = (($info) + 32|0);
 $15 = (($info) + 40|0);
 $16 = ($6|0)==($dst_type|0);
 dest=$10+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP16[$10+36>>1]=0|0;HEAP8[$10+38>>0]=0|0;
 if ($16) {
  $17 = (($info) + 48|0);
  HEAP32[$17>>2] = 1;
  $18 = HEAP32[$6>>2]|0;
  $19 = (($18) + 20|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiiiii[$20 & 255]($6,$info,$4,$4,1,0);
  $21 = HEAP32[$12>>2]|0;
  $22 = ($21|0)==(1);
  $$ = $22 ? $4 : 0;
  $dst_ptr$0 = $$;
  STACKTOP = sp;return ($dst_ptr$0|0);
 }
 $23 = (($info) + 36|0);
 $24 = HEAP32[$6>>2]|0;
 $25 = (($24) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_viiiii[$26 & 255]($6,$info,$4,1,0);
 $27 = HEAP32[$23>>2]|0;
 if ((($27|0) == 1)) {
  $35 = HEAP32[$12>>2]|0;
  $36 = ($35|0)==(1);
  if (!($36)) {
   $37 = HEAP32[$15>>2]|0;
   $38 = ($37|0)==(0);
   if (!($38)) {
    $dst_ptr$0 = 0;
    STACKTOP = sp;return ($dst_ptr$0|0);
   }
   $39 = HEAP32[$13>>2]|0;
   $40 = ($39|0)==(1);
   if (!($40)) {
    $dst_ptr$0 = 0;
    STACKTOP = sp;return ($dst_ptr$0|0);
   }
   $41 = HEAP32[$14>>2]|0;
   $42 = ($41|0)==(1);
   if (!($42)) {
    $dst_ptr$0 = 0;
    STACKTOP = sp;return ($dst_ptr$0|0);
   }
  }
  $43 = HEAP32[$10>>2]|0;
  $dst_ptr$0 = $43;
  STACKTOP = sp;return ($dst_ptr$0|0);
 } else if ((($27|0) == 0)) {
  $28 = HEAP32[$15>>2]|0;
  $29 = ($28|0)==(1);
  if (!($29)) {
   $dst_ptr$0 = 0;
   STACKTOP = sp;return ($dst_ptr$0|0);
  }
  $30 = HEAP32[$13>>2]|0;
  $31 = ($30|0)==(1);
  if (!($31)) {
   $dst_ptr$0 = 0;
   STACKTOP = sp;return ($dst_ptr$0|0);
  }
  $32 = HEAP32[$14>>2]|0;
  $33 = ($32|0)==(1);
  $34 = HEAP32[$11>>2]|0;
  $$1 = $33 ? $34 : 0;
  $dst_ptr$0 = $$1;
  STACKTOP = sp;return ($dst_ptr$0|0);
 } else {
  $dst_ptr$0 = 0;
  STACKTOP = sp;return ($dst_ptr$0|0);
 }
 return 0|0;
}
function __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i($this,$info,$dst_ptr,$current_ptr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $dst_ptr = $dst_ptr|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 53|0);
 HEAP8[$0>>0] = 1;
 $1 = (($info) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($current_ptr|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($info) + 52|0);
 HEAP8[$4>>0] = 1;
 $5 = (($info) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  HEAP32[$5>>2] = $dst_ptr;
  $8 = (($info) + 24|0);
  HEAP32[$8>>2] = $path_below;
  $9 = (($info) + 36|0);
  HEAP32[$9>>2] = 1;
  $10 = (($info) + 48|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(1);
  $13 = ($path_below|0)==(1);
  $or$cond = $12 & $13;
  if (!($or$cond)) {
   STACKTOP = sp;return;
  }
  $14 = (($info) + 54|0);
  HEAP8[$14>>0] = 1;
  STACKTOP = sp;return;
 }
 $15 = ($6|0)==($dst_ptr|0);
 if (!($15)) {
  $25 = (($info) + 36|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 1)|0;
  HEAP32[$25>>2] = $27;
  $28 = (($info) + 54|0);
  HEAP8[$28>>0] = 1;
  STACKTOP = sp;return;
 }
 $16 = (($info) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(2);
 if ($18) {
  HEAP32[$16>>2] = $path_below;
  $23 = $path_below;
 } else {
  $23 = $17;
 }
 $19 = (($info) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(1);
 $22 = ($23|0)==(1);
 $or$cond1 = $21 & $22;
 if (!($or$cond1)) {
  STACKTOP = sp;return;
 }
 $24 = (($info) + 54|0);
 HEAP8[$24>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($this,$info,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $does_dst_type_point_to_our_static_type$0$off0$lcssa = 0, $does_dst_type_point_to_our_static_type$0$off012 = 0, $does_dst_type_point_to_our_static_type$1$off0 = 0, $is_dst_type_derived_from_static_type$0$off014 = 0;
 var $is_dst_type_derived_from_static_type$1$off0 = 0, $is_dst_type_derived_from_static_type$2$off0 = 0, $is_dst_type_derived_from_static_type$2$off023 = 0, $is_dst_type_derived_from_static_type$2$off024 = 0, $p$013 = 0, $p2$0 = 0, $p2$1 = 0, $p2$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  $3 = (($info) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($current_ptr|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = (($info) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(1);
  if ($8) {
   STACKTOP = sp;return;
  }
  HEAP32[$6>>2] = $path_below;
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$info>>2]|0;
 $10 = ($this|0)==($9|0);
 if (!($10)) {
  $59 = (($this) + 16|0);
  $60 = (($this) + 12|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($this) + ($61<<3)|0) + 16|0);
  __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($59,$info,$current_ptr,$path_below,$use_strcmp);
  $63 = (($this) + 24|0);
  $64 = ($61|0)>(1);
  if (!($64)) {
   STACKTOP = sp;return;
  }
  $65 = (($this) + 8|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = $66 & 2;
  $68 = ($67|0)==(0);
  if ($68) {
   $69 = (($info) + 36|0);
   $70 = HEAP32[$69>>2]|0;
   $71 = ($70|0)==(1);
   if (!($71)) {
    $77 = $66 & 1;
    $78 = ($77|0)==(0);
    if ($78) {
     $81 = (($info) + 54|0);
     $p2$2 = $63;
     while(1) {
      $90 = HEAP8[$81>>0]|0;
      $91 = ($90<<24>>24)==(0);
      if (!($91)) {
       label = 43;
       break;
      }
      $92 = HEAP32[$69>>2]|0;
      $93 = ($92|0)==(1);
      if ($93) {
       label = 43;
       break;
      }
      __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($p2$2,$info,$current_ptr,$path_below,$use_strcmp);
      $94 = (($p2$2) + 8|0);
      $95 = ($94>>>0)<($62>>>0);
      if ($95) {
       $p2$2 = $94;
      } else {
       label = 43;
       break;
      }
     }
     if ((label|0) == 43) {
      STACKTOP = sp;return;
     }
    }
    $79 = (($info) + 24|0);
    $80 = (($info) + 54|0);
    $p2$1 = $63;
    while(1) {
     $82 = HEAP8[$80>>0]|0;
     $83 = ($82<<24>>24)==(0);
     if (!($83)) {
      label = 43;
      break;
     }
     $84 = HEAP32[$69>>2]|0;
     $85 = ($84|0)==(1);
     if ($85) {
      $86 = HEAP32[$79>>2]|0;
      $87 = ($86|0)==(1);
      if ($87) {
       label = 43;
       break;
      }
     }
     __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($p2$1,$info,$current_ptr,$path_below,$use_strcmp);
     $88 = (($p2$1) + 8|0);
     $89 = ($88>>>0)<($62>>>0);
     if ($89) {
      $p2$1 = $88;
     } else {
      label = 43;
      break;
     }
    }
    if ((label|0) == 43) {
     STACKTOP = sp;return;
    }
   }
  }
  $72 = (($info) + 54|0);
  $p2$0 = $63;
  while(1) {
   $73 = HEAP8[$72>>0]|0;
   $74 = ($73<<24>>24)==(0);
   if (!($74)) {
    label = 43;
    break;
   }
   __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($p2$0,$info,$current_ptr,$path_below,$use_strcmp);
   $75 = (($p2$0) + 8|0);
   $76 = ($75>>>0)<($62>>>0);
   if ($76) {
    $p2$0 = $75;
   } else {
    label = 43;
    break;
   }
  }
  if ((label|0) == 43) {
   STACKTOP = sp;return;
  }
 }
 $11 = (($info) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($current_ptr|0);
 if (!($13)) {
  $14 = (($info) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($current_ptr|0);
  if (!($16)) {
   $19 = (($info) + 32|0);
   HEAP32[$19>>2] = $path_below;
   $20 = (($info) + 44|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(4);
   if ($22) {
    STACKTOP = sp;return;
   }
   $23 = (($this) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($this) + ($24<<3)|0) + 16|0);
   $26 = ($24|0)>(0);
   L54: do {
    if ($26) {
     $27 = (($this) + 16|0);
     $28 = (($info) + 52|0);
     $29 = (($info) + 53|0);
     $30 = (($info) + 54|0);
     $31 = (($this) + 8|0);
     $32 = (($info) + 24|0);
     $does_dst_type_point_to_our_static_type$0$off012 = 0;$is_dst_type_derived_from_static_type$0$off014 = 0;$p$013 = $27;
     L56: while(1) {
      HEAP8[$28>>0] = 0;
      HEAP8[$29>>0] = 0;
      __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($p$013,$info,$current_ptr,$current_ptr,1,$use_strcmp);
      $33 = HEAP8[$30>>0]|0;
      $34 = ($33<<24>>24)==(0);
      if (!($34)) {
       $does_dst_type_point_to_our_static_type$0$off0$lcssa = $does_dst_type_point_to_our_static_type$0$off012;$is_dst_type_derived_from_static_type$2$off0 = $is_dst_type_derived_from_static_type$0$off014;
       break;
      }
      $35 = HEAP8[$29>>0]|0;
      $36 = ($35<<24>>24)==(0);
      do {
       if ($36) {
        $does_dst_type_point_to_our_static_type$1$off0 = $does_dst_type_point_to_our_static_type$0$off012;$is_dst_type_derived_from_static_type$1$off0 = $is_dst_type_derived_from_static_type$0$off014;
       } else {
        $37 = HEAP8[$28>>0]|0;
        $38 = ($37<<24>>24)==(0);
        if ($38) {
         $44 = HEAP32[$31>>2]|0;
         $45 = $44 & 1;
         $46 = ($45|0)==(0);
         if ($46) {
          $does_dst_type_point_to_our_static_type$0$off0$lcssa = $does_dst_type_point_to_our_static_type$0$off012;$is_dst_type_derived_from_static_type$2$off0 = 1;
          break L56;
         } else {
          $does_dst_type_point_to_our_static_type$1$off0 = $does_dst_type_point_to_our_static_type$0$off012;$is_dst_type_derived_from_static_type$1$off0 = 1;
          break;
         }
        }
        $39 = HEAP32[$32>>2]|0;
        $40 = ($39|0)==(1);
        if ($40) {
         label = 25;
         break L54;
        }
        $41 = HEAP32[$31>>2]|0;
        $42 = $41 & 2;
        $43 = ($42|0)==(0);
        if ($43) {
         label = 25;
         break L54;
        } else {
         $does_dst_type_point_to_our_static_type$1$off0 = 1;$is_dst_type_derived_from_static_type$1$off0 = 1;
        }
       }
      } while(0);
      $47 = (($p$013) + 8|0);
      $48 = ($47>>>0)<($25>>>0);
      if ($48) {
       $does_dst_type_point_to_our_static_type$0$off012 = $does_dst_type_point_to_our_static_type$1$off0;$is_dst_type_derived_from_static_type$0$off014 = $is_dst_type_derived_from_static_type$1$off0;$p$013 = $47;
      } else {
       $does_dst_type_point_to_our_static_type$0$off0$lcssa = $does_dst_type_point_to_our_static_type$1$off0;$is_dst_type_derived_from_static_type$2$off0 = $is_dst_type_derived_from_static_type$1$off0;
       break;
      }
     }
     if ($does_dst_type_point_to_our_static_type$0$off0$lcssa) {
      $is_dst_type_derived_from_static_type$2$off024 = $is_dst_type_derived_from_static_type$2$off0;
      label = 24;
     } else {
      $is_dst_type_derived_from_static_type$2$off023 = $is_dst_type_derived_from_static_type$2$off0;
      label = 21;
     }
    } else {
     $is_dst_type_derived_from_static_type$2$off023 = 0;
     label = 21;
    }
   } while(0);
   if ((label|0) == 21) {
    HEAP32[$14>>2] = $current_ptr;
    $49 = (($info) + 40|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($50) + 1)|0;
    HEAP32[$49>>2] = $51;
    $52 = (($info) + 36|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(1);
    if ($54) {
     $55 = (($info) + 24|0);
     $56 = HEAP32[$55>>2]|0;
     $57 = ($56|0)==(2);
     if ($57) {
      $58 = (($info) + 54|0);
      HEAP8[$58>>0] = 1;
      if ($is_dst_type_derived_from_static_type$2$off023) {
       label = 25;
      } else {
       label = 26;
      }
     } else {
      $is_dst_type_derived_from_static_type$2$off024 = $is_dst_type_derived_from_static_type$2$off023;
      label = 24;
     }
    } else {
     $is_dst_type_derived_from_static_type$2$off024 = $is_dst_type_derived_from_static_type$2$off023;
     label = 24;
    }
   }
   if ((label|0) == 24) {
    if ($is_dst_type_derived_from_static_type$2$off024) {
     label = 25;
    } else {
     label = 26;
    }
   }
   if ((label|0) == 25) {
    HEAP32[$20>>2] = 3;
    STACKTOP = sp;return;
   }
   else if ((label|0) == 26) {
    HEAP32[$20>>2] = 4;
    STACKTOP = sp;return;
   }
  }
 }
 $17 = ($path_below|0)==(1);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($info) + 32|0);
 HEAP32[$18>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($this,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $dst_ptr = $dst_ptr|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset_to_base$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >> 8;
 $3 = $1 & 1;
 $4 = ($3|0)==(0);
 if ($4) {
  $offset_to_base$0 = $2;
 } else {
  $5 = HEAP32[$current_ptr>>2]|0;
  $6 = (($5) + ($2)|0);
  $7 = HEAP32[$6>>2]|0;
  $offset_to_base$0 = $7;
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 20|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($current_ptr) + ($offset_to_base$0)|0);
 $13 = $1 & 2;
 $14 = ($13|0)!=(0);
 $15 = $14 ? $path_below : 2;
 FUNCTION_TABLE_viiiiii[$11 & 255]($8,$info,$dst_ptr,$12,$15,$use_strcmp);
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($this,$info,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $offset_to_base$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 >> 8;
 $3 = $1 & 1;
 $4 = ($3|0)==(0);
 if ($4) {
  $offset_to_base$0 = $2;
 } else {
  $5 = HEAP32[$current_ptr>>2]|0;
  $6 = (($5) + ($2)|0);
  $7 = HEAP32[$6>>2]|0;
  $offset_to_base$0 = $7;
 }
 $8 = HEAP32[$this>>2]|0;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 24|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($current_ptr) + ($offset_to_base$0)|0);
 $13 = $1 & 2;
 $14 = ($13|0)!=(0);
 $15 = $14 ? $path_below : 2;
 FUNCTION_TABLE_viiiii[$11 & 255]($8,$info,$12,$15,$use_strcmp);
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($this,$info,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $is_dst_type_derived_from_static_type$0$off01 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  $3 = (($info) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($current_ptr|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = (($info) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(1);
  if ($8) {
   STACKTOP = sp;return;
  }
  HEAP32[$6>>2] = $path_below;
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$info>>2]|0;
 $10 = ($this|0)==($9|0);
 if (!($10)) {
  $43 = (($this) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 24|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_viiiii[$47 & 255]($44,$info,$current_ptr,$path_below,$use_strcmp);
  STACKTOP = sp;return;
 }
 $11 = (($info) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($current_ptr|0);
 if (!($13)) {
  $14 = (($info) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($current_ptr|0);
  if (!($16)) {
   $19 = (($info) + 32|0);
   HEAP32[$19>>2] = $path_below;
   $20 = (($info) + 44|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(4);
   if ($22) {
    STACKTOP = sp;return;
   }
   $23 = (($info) + 52|0);
   HEAP8[$23>>0] = 0;
   $24 = (($info) + 53|0);
   HEAP8[$24>>0] = 0;
   $25 = (($this) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   FUNCTION_TABLE_viiiiii[$29 & 255]($26,$info,$current_ptr,$current_ptr,1,$use_strcmp);
   $30 = HEAP8[$24>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $is_dst_type_derived_from_static_type$0$off01 = 0;
    label = 13;
   } else {
    $32 = HEAP8[$23>>0]|0;
    $not$ = ($32<<24>>24)==(0);
    if ($not$) {
     $is_dst_type_derived_from_static_type$0$off01 = 1;
     label = 13;
    }
   }
   do {
    if ((label|0) == 13) {
     HEAP32[$14>>2] = $current_ptr;
     $33 = (($info) + 40|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 1)|0;
     HEAP32[$33>>2] = $35;
     $36 = (($info) + 36|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==(1);
     if ($38) {
      $39 = (($info) + 24|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)==(2);
      if ($41) {
       $42 = (($info) + 54|0);
       HEAP8[$42>>0] = 1;
       if ($is_dst_type_derived_from_static_type$0$off01) {
        break;
       }
      } else {
       label = 16;
      }
     } else {
      label = 16;
     }
     if ((label|0) == 16) {
      if ($is_dst_type_derived_from_static_type$0$off01) {
       break;
      }
     }
     HEAP32[$20>>2] = 4;
     STACKTOP = sp;return;
    }
   } while(0);
   HEAP32[$20>>2] = 3;
   STACKTOP = sp;return;
  }
 }
 $17 = ($path_below|0)==(1);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($info) + 32|0);
 HEAP32[$18>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($this,$info,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($this|0);
 if ($2) {
  $3 = (($info) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($current_ptr|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = (($info) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(1);
  if ($8) {
   STACKTOP = sp;return;
  }
  HEAP32[$6>>2] = $path_below;
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$info>>2]|0;
 $10 = ($9|0)==($this|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($info) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($current_ptr|0);
 if (!($13)) {
  $14 = (($info) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($current_ptr|0);
  if (!($16)) {
   $19 = (($info) + 32|0);
   HEAP32[$19>>2] = $path_below;
   HEAP32[$14>>2] = $current_ptr;
   $20 = (($info) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 1)|0;
   HEAP32[$20>>2] = $22;
   $23 = (($info) + 36|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(1);
   if ($25) {
    $26 = (($info) + 24|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(2);
    if ($28) {
     $29 = (($info) + 54|0);
     HEAP8[$29>>0] = 1;
    }
   }
   $30 = (($info) + 44|0);
   HEAP32[$30>>2] = 4;
   STACKTOP = sp;return;
  }
 }
 $17 = ($path_below|0)==(1);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($info) + 32|0);
 HEAP32[$18>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($this,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $dst_ptr = $dst_ptr|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0,$info,$dst_ptr,$current_ptr,$path_below);
  STACKTOP = sp;return;
 }
 $3 = (($info) + 52|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = (($info) + 53|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = (($this) + 16|0);
 $8 = (($this) + 12|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($this) + ($9<<3)|0) + 16|0);
 HEAP8[$3>>0] = 0;
 HEAP8[$5>>0] = 0;
 __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($7,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp);
 $11 = ($9|0)>(1);
 L5: do {
  if ($11) {
   $12 = (($this) + 24|0);
   $13 = (($info) + 24|0);
   $14 = (($this) + 8|0);
   $15 = (($info) + 54|0);
   $p$0 = $12;
   while(1) {
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(0);
    if (!($17)) {
     break L5;
    }
    $18 = HEAP8[$3>>0]|0;
    $19 = ($18<<24>>24)==(0);
    if ($19) {
     $25 = HEAP8[$5>>0]|0;
     $26 = ($25<<24>>24)==(0);
     if (!($26)) {
      $27 = HEAP32[$14>>2]|0;
      $28 = $27 & 1;
      $29 = ($28|0)==(0);
      if ($29) {
       break L5;
      }
     }
    } else {
     $20 = HEAP32[$13>>2]|0;
     $21 = ($20|0)==(1);
     if ($21) {
      break L5;
     }
     $22 = HEAP32[$14>>2]|0;
     $23 = $22 & 2;
     $24 = ($23|0)==(0);
     if ($24) {
      break L5;
     }
    }
    HEAP8[$3>>0] = 0;
    HEAP8[$5>>0] = 0;
    __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($p$0,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp);
    $30 = (($p$0) + 8|0);
    $31 = ($30>>>0)<($10>>>0);
    if ($31) {
     $p$0 = $30;
    } else {
     break;
    }
   }
  }
 } while(0);
 HEAP8[$3>>0] = $4;
 HEAP8[$5>>0] = $6;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($this,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $dst_ptr = $dst_ptr|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0,$info,$dst_ptr,$current_ptr,$path_below);
  STACKTOP = sp;return;
 } else {
  $3 = (($this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viiiiii[$7 & 255]($4,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp);
  STACKTOP = sp;return;
 }
}
function __ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($this,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $dst_ptr = $dst_ptr|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($this|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0,$info,$dst_ptr,$current_ptr,$path_below);
 STACKTOP = sp;return;
}
function ___cxa_can_catch($catchType,$excpType,$thrown) {
 $catchType = $catchType|0;
 $excpType = $excpType|0;
 $thrown = $thrown|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $temp = sp;
 $0 = HEAP32[$thrown>>2]|0;
 HEAP32[$temp>>2] = $0;
 $1 = HEAP32[$catchType>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$3 & 2047]($catchType,$excpType,$temp)|0);
 $5 = $4&1;
 if (!($4)) {
  STACKTOP = sp;return ($5|0);
 }
 $6 = HEAP32[$temp>>2]|0;
 HEAP32[$thrown>>2] = $6;
 STACKTOP = sp;return ($5|0);
}
function ___cxa_is_pointer_type($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($type|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (___dynamic_cast($type,3105944,3106112,0)|0);
  $phitmp = ($1|0)!=(0|0);
  $3 = $phitmp;
 }
 $2 = $3&1;
 STACKTOP = sp;return ($2|0);
}
function __ZSt17__throw_bad_allocv() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_allocate_exception(4)|0);
 __ZNSt9bad_allocC2Ev($0);
 ___cxa_throw(($0|0),(3105352|0),(3280|0));
 // unreachable;
}
function _emscripten_GetProcAddress($name_) {
 $name_ = $name_|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $end = 0, $name = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $vararg_buffer = sp;
 $0 = sp + 20|0;
 $1 = sp + 8|0;
 $name = sp + 12|0;
 $end = sp + 16|0;
 HEAP32[$1>>2] = $name_;
 $2 = HEAP32[$1>>2]|0;
 $3 = (_strlen(($2|0))|0);
 $4 = (($3) + 1)|0;
 $5 = (_malloc($4)|0);
 HEAP32[$name>>2] = $5;
 $6 = HEAP32[$name>>2]|0;
 $7 = HEAP32[$1>>2]|0;
 (_strcpy(($6|0),($7|0))|0);
 $8 = HEAP32[$name>>2]|0;
 $9 = (_strstr($8,3106368)|0);
 HEAP32[$end>>2] = $9;
 $10 = HEAP32[$end>>2]|0;
 $11 = ($10|0)!=(0|0);
 if ($11) {
  $12 = HEAP32[$end>>2]|0;
  HEAP8[$12>>0] = 0;
 }
 $13 = HEAP32[$name>>2]|0;
 $14 = (_strstr($13,3106376)|0);
 HEAP32[$end>>2] = $14;
 $15 = HEAP32[$end>>2]|0;
 $16 = ($15|0)!=(0|0);
 if ($16) {
  $17 = HEAP32[$end>>2]|0;
  HEAP8[$17>>0] = 0;
 }
 $18 = HEAP32[$name>>2]|0;
 $19 = (_strstr($18,3106384)|0);
 HEAP32[$end>>2] = $19;
 $20 = HEAP32[$end>>2]|0;
 $21 = ($20|0)!=(0|0);
 if ($21) {
  $22 = HEAP32[$end>>2]|0;
  HEAP8[$22>>0] = 0;
 }
 $23 = HEAP32[$name>>2]|0;
 $24 = (_strcmp($23,3106392)|0);
 $25 = ($24|0)!=(0);
 if ($25) {
  $26 = HEAP32[$name>>2]|0;
  $27 = (_strcmp($26,3106432)|0);
  $28 = ($27|0)!=(0);
  if ($28) {
   $29 = HEAP32[$name>>2]|0;
   $30 = (_strcmp($29,3106472)|0);
   $31 = ($30|0)!=(0);
   if ($31) {
    $32 = HEAP32[$name>>2]|0;
    $33 = (_strcmp($32,3106512)|0);
    $34 = ($33|0)!=(0);
    if ($34) {
     $35 = HEAP32[$name>>2]|0;
     $36 = (_strcmp($35,3106544)|0);
     $37 = ($36|0)!=(0);
     if (!($37)) {
      HEAP32[$name>>2] = 3106560;
     }
    } else {
     HEAP32[$name>>2] = 3106528;
    }
   } else {
    HEAP32[$name>>2] = 3106496;
   }
  } else {
   HEAP32[$name>>2] = 3106456;
  }
 } else {
  HEAP32[$name>>2] = 3106416;
 }
 $38 = HEAP32[$name>>2]|0;
 $39 = (_strcmp($38,3106576)|0);
 $40 = ($39|0)!=(0);
 do {
  if ($40) {
   $41 = HEAP32[$name>>2]|0;
   $42 = (_strcmp($41,3106592)|0);
   $43 = ($42|0)!=(0);
   if (!($43)) {
    HEAP32[$0>>2] = 3485;
    break;
   }
   $44 = HEAP32[$name>>2]|0;
   $45 = (_strcmp($44,3106608)|0);
   $46 = ($45|0)!=(0);
   if (!($46)) {
    HEAP32[$0>>2] = 3545;
    break;
   }
   $47 = HEAP32[$name>>2]|0;
   $48 = (_strcmp($47,3106624)|0);
   $49 = ($48|0)!=(0);
   if (!($49)) {
    HEAP32[$0>>2] = 3546;
    break;
   }
   $50 = HEAP32[$name>>2]|0;
   $51 = (_strcmp($50,3106640)|0);
   $52 = ($51|0)!=(0);
   if (!($52)) {
    HEAP32[$0>>2] = 3547;
    break;
   }
   $53 = HEAP32[$name>>2]|0;
   $54 = (_strcmp($53,3106656)|0);
   $55 = ($54|0)!=(0);
   if (!($55)) {
    HEAP32[$0>>2] = 3548;
    break;
   }
   $56 = HEAP32[$name>>2]|0;
   $57 = (_strcmp($56,3106672)|0);
   $58 = ($57|0)!=(0);
   if (!($58)) {
    HEAP32[$0>>2] = 3549;
    break;
   }
   $59 = HEAP32[$name>>2]|0;
   $60 = (_strcmp($59,3106696)|0);
   $61 = ($60|0)!=(0);
   if (!($61)) {
    HEAP32[$0>>2] = 37;
    break;
   }
   $62 = HEAP32[$name>>2]|0;
   $63 = (_strcmp($62,3106720)|0);
   $64 = ($63|0)!=(0);
   if (!($64)) {
    HEAP32[$0>>2] = 17;
    break;
   }
   $65 = HEAP32[$name>>2]|0;
   $66 = (_strcmp($65,3106752)|0);
   $67 = ($66|0)!=(0);
   if (!($67)) {
    HEAP32[$0>>2] = 18;
    break;
   }
   $68 = HEAP32[$name>>2]|0;
   $69 = (_strcmp($68,3106768)|0);
   $70 = ($69|0)!=(0);
   if (!($70)) {
    HEAP32[$0>>2] = 19;
    break;
   }
   $71 = HEAP32[$name>>2]|0;
   $72 = (_strcmp($71,3106784)|0);
   $73 = ($72|0)!=(0);
   if (!($73)) {
    HEAP32[$0>>2] = 82;
    break;
   }
   $74 = HEAP32[$name>>2]|0;
   $75 = (_strcmp($74,3106800)|0);
   $76 = ($75|0)!=(0);
   if (!($76)) {
    HEAP32[$0>>2] = 3550;
    break;
   }
   $77 = HEAP32[$name>>2]|0;
   $78 = (_strcmp($77,3106816)|0);
   $79 = ($78|0)!=(0);
   if (!($79)) {
    HEAP32[$0>>2] = 2134;
    break;
   }
   $80 = HEAP32[$name>>2]|0;
   $81 = (_strcmp($80,3106840)|0);
   $82 = ($81|0)!=(0);
   if (!($82)) {
    HEAP32[$0>>2] = 2135;
    break;
   }
   $83 = HEAP32[$name>>2]|0;
   $84 = (_strcmp($83,3106864)|0);
   $85 = ($84|0)!=(0);
   if (!($85)) {
    HEAP32[$0>>2] = 2136;
    break;
   }
   $86 = HEAP32[$name>>2]|0;
   $87 = (_strcmp($86,3106888)|0);
   $88 = ($87|0)!=(0);
   if (!($88)) {
    HEAP32[$0>>2] = 2137;
    break;
   }
   $89 = HEAP32[$name>>2]|0;
   $90 = (_strcmp($89,3106912)|0);
   $91 = ($90|0)!=(0);
   if (!($91)) {
    HEAP32[$0>>2] = 3486;
    break;
   }
   $92 = HEAP32[$name>>2]|0;
   $93 = (_strcmp($92,3106928)|0);
   $94 = ($93|0)!=(0);
   if (!($94)) {
    HEAP32[$0>>2] = 3551;
    break;
   }
   $95 = HEAP32[$name>>2]|0;
   $96 = (_strcmp($95,3106944)|0);
   $97 = ($96|0)!=(0);
   if (!($97)) {
    HEAP32[$0>>2] = 3552;
    break;
   }
   $98 = HEAP32[$name>>2]|0;
   $99 = (_strcmp($98,3106960)|0);
   $100 = ($99|0)!=(0);
   if (!($100)) {
    HEAP32[$0>>2] = 2138;
    break;
   }
   $101 = HEAP32[$name>>2]|0;
   $102 = (_strcmp($101,3106984)|0);
   $103 = ($102|0)!=(0);
   if (!($103)) {
    HEAP32[$0>>2] = 478;
    break;
   }
   $104 = HEAP32[$name>>2]|0;
   $105 = (_strcmp($104,3107000)|0);
   $106 = ($105|0)!=(0);
   if (!($106)) {
    HEAP32[$0>>2] = 479;
    break;
   }
   $107 = HEAP32[$name>>2]|0;
   $108 = (_strcmp($107,3107016)|0);
   $109 = ($108|0)!=(0);
   if (!($109)) {
    HEAP32[$0>>2] = 3487;
    break;
   }
   $110 = HEAP32[$name>>2]|0;
   $111 = (_strcmp($110,3107032)|0);
   $112 = ($111|0)!=(0);
   if (!($112)) {
    HEAP32[$0>>2] = 3553;
    break;
   }
   $113 = HEAP32[$name>>2]|0;
   $114 = (_strcmp($113,3107056)|0);
   $115 = ($114|0)!=(0);
   if (!($115)) {
    HEAP32[$0>>2] = 3554;
    break;
   }
   $116 = HEAP32[$name>>2]|0;
   $117 = (_strcmp($116,3107080)|0);
   $118 = ($117|0)!=(0);
   if (!($118)) {
    HEAP32[$0>>2] = 3555;
    break;
   }
   $119 = HEAP32[$name>>2]|0;
   $120 = (_strcmp($119,3107104)|0);
   $121 = ($120|0)!=(0);
   if (!($121)) {
    HEAP32[$0>>2] = 2139;
    break;
   }
   $122 = HEAP32[$name>>2]|0;
   $123 = (_strcmp($122,3107136)|0);
   $124 = ($123|0)!=(0);
   if (!($124)) {
    HEAP32[$0>>2] = 3488;
    break;
   }
   $125 = HEAP32[$name>>2]|0;
   $126 = (_strcmp($125,3107160)|0);
   $127 = ($126|0)!=(0);
   if (!($127)) {
    HEAP32[$0>>2] = 2140;
    break;
   }
   $128 = HEAP32[$name>>2]|0;
   $129 = (_strcmp($128,3107176)|0);
   $130 = ($129|0)!=(0);
   if (!($130)) {
    HEAP32[$0>>2] = 2141;
    break;
   }
   $131 = HEAP32[$name>>2]|0;
   $132 = (_strcmp($131,3107192)|0);
   $133 = ($132|0)!=(0);
   if (!($133)) {
    HEAP32[$0>>2] = 2788;
    break;
   }
   $134 = HEAP32[$name>>2]|0;
   $135 = (_strcmp($134,3107216)|0);
   $136 = ($135|0)!=(0);
   if (!($136)) {
    HEAP32[$0>>2] = 2142;
    break;
   }
   $137 = HEAP32[$name>>2]|0;
   $138 = (_strcmp($137,3107240)|0);
   $139 = ($138|0)!=(0);
   if (!($139)) {
    HEAP32[$0>>2] = 2143;
    break;
   }
   $140 = HEAP32[$name>>2]|0;
   $141 = (_strcmp($140,3107264)|0);
   $142 = ($141|0)!=(0);
   if (!($142)) {
    HEAP32[$0>>2] = 2144;
    break;
   }
   $143 = HEAP32[$name>>2]|0;
   $144 = (_strcmp($143,3107296)|0);
   $145 = ($144|0)!=(0);
   if (!($145)) {
    HEAP32[$0>>2] = 83;
    break;
   }
   $146 = HEAP32[$name>>2]|0;
   $147 = (_strcmp($146,3107320)|0);
   $148 = ($147|0)!=(0);
   if (!($148)) {
    HEAP32[$0>>2] = 191;
    break;
   }
   $149 = HEAP32[$name>>2]|0;
   $150 = (_strcmp($149,3107336)|0);
   $151 = ($150|0)!=(0);
   if (!($151)) {
    HEAP32[$0>>2] = 19;
    break;
   }
   $152 = HEAP32[$name>>2]|0;
   $153 = (_strcmp($152,3107352)|0);
   $154 = ($153|0)!=(0);
   if (!($154)) {
    HEAP32[$0>>2] = 7;
    break;
   }
   $155 = HEAP32[$name>>2]|0;
   $156 = (_strcmp($155,3107368)|0);
   $157 = ($156|0)!=(0);
   if (!($157)) {
    HEAP32[$0>>2] = 8;
    break;
   }
   $158 = HEAP32[$name>>2]|0;
   $159 = (_strcmp($158,3107384)|0);
   $160 = ($159|0)!=(0);
   if (!($160)) {
    HEAP32[$0>>2] = 3556;
    break;
   }
   $161 = HEAP32[$name>>2]|0;
   $162 = (_strcmp($161,3107400)|0);
   $163 = ($162|0)!=(0);
   if (!($163)) {
    HEAP32[$0>>2] = 2145;
    break;
   }
   $164 = HEAP32[$name>>2]|0;
   $165 = (_strcmp($164,3107416)|0);
   $166 = ($165|0)!=(0);
   if (!($166)) {
    HEAP32[$0>>2] = 480;
    break;
   }
   $167 = HEAP32[$name>>2]|0;
   $168 = (_strcmp($167,3107432)|0);
   $169 = ($168|0)!=(0);
   if (!($169)) {
    HEAP32[$0>>2] = 132;
    break;
   }
   $170 = HEAP32[$name>>2]|0;
   $171 = (_strcmp($170,3107448)|0);
   $172 = ($171|0)!=(0);
   if (!($172)) {
    HEAP32[$0>>2] = 2146;
    break;
   }
   $173 = HEAP32[$name>>2]|0;
   $174 = (_strcmp($173,3107464)|0);
   $175 = ($174|0)!=(0);
   if (!($175)) {
    HEAP32[$0>>2] = 2147;
    break;
   }
   $176 = HEAP32[$name>>2]|0;
   $177 = (_strcmp($176,3107480)|0);
   $178 = ($177|0)!=(0);
   if (!($178)) {
    HEAP32[$0>>2] = 2148;
    break;
   }
   $179 = HEAP32[$name>>2]|0;
   $180 = (_strcmp($179,3107496)|0);
   $181 = ($180|0)!=(0);
   if (!($181)) {
    HEAP32[$0>>2] = 2149;
    break;
   }
   $182 = HEAP32[$name>>2]|0;
   $183 = (_strcmp($182,3107512)|0);
   $184 = ($183|0)!=(0);
   if (!($184)) {
    HEAP32[$0>>2] = 2150;
    break;
   }
   $185 = HEAP32[$name>>2]|0;
   $186 = (_strcmp($185,3107528)|0);
   $187 = ($186|0)!=(0);
   if (!($187)) {
    HEAP32[$0>>2] = 2151;
    break;
   }
   $188 = HEAP32[$name>>2]|0;
   $189 = (_strcmp($188,3107544)|0);
   $190 = ($189|0)!=(0);
   if (!($190)) {
    HEAP32[$0>>2] = 2152;
    break;
   }
   $191 = HEAP32[$name>>2]|0;
   $192 = (_strcmp($191,3107560)|0);
   $193 = ($192|0)!=(0);
   if (!($193)) {
    HEAP32[$0>>2] = 2153;
    break;
   }
   $194 = HEAP32[$name>>2]|0;
   $195 = (_strcmp($194,3107576)|0);
   $196 = ($195|0)!=(0);
   if (!($196)) {
    HEAP32[$0>>2] = 481;
    break;
   }
   $197 = HEAP32[$name>>2]|0;
   $198 = (_strcmp($197,3107600)|0);
   $199 = ($198|0)!=(0);
   if (!($199)) {
    HEAP32[$0>>2] = 482;
    break;
   }
   $200 = HEAP32[$name>>2]|0;
   $201 = (_strcmp($200,3107624)|0);
   $202 = ($201|0)!=(0);
   if (!($202)) {
    HEAP32[$0>>2] = 483;
    break;
   }
   $203 = HEAP32[$name>>2]|0;
   $204 = (_strcmp($203,3107648)|0);
   $205 = ($204|0)!=(0);
   if (!($205)) {
    HEAP32[$0>>2] = 3557;
    break;
   }
   $206 = HEAP32[$name>>2]|0;
   $207 = (_strcmp($206,3107664)|0);
   $208 = ($207|0)!=(0);
   if (!($208)) {
    HEAP32[$0>>2] = 3558;
    break;
   }
   $209 = HEAP32[$name>>2]|0;
   $210 = (_strcmp($209,3107688)|0);
   $211 = ($210|0)!=(0);
   if (!($211)) {
    HEAP32[$0>>2] = 3559;
    break;
   }
   $212 = HEAP32[$name>>2]|0;
   $213 = (_strcmp($212,3107712)|0);
   $214 = ($213|0)!=(0);
   if (!($214)) {
    HEAP32[$0>>2] = 3560;
    break;
   }
   $215 = HEAP32[$name>>2]|0;
   $216 = (_strcmp($215,3107736)|0);
   $217 = ($216|0)!=(0);
   if (!($217)) {
    HEAP32[$0>>2] = 3561;
    break;
   }
   $218 = HEAP32[$name>>2]|0;
   $219 = (_strcmp($218,3107760)|0);
   $220 = ($219|0)!=(0);
   if (!($220)) {
    HEAP32[$0>>2] = 2789;
    break;
   }
   $221 = HEAP32[$name>>2]|0;
   $222 = (_strcmp($221,3107784)|0);
   $223 = ($222|0)!=(0);
   if (!($223)) {
    HEAP32[$0>>2] = 84;
    break;
   }
   $224 = HEAP32[$name>>2]|0;
   $225 = (_strcmp($224,3106496)|0);
   $226 = ($225|0)!=(0);
   if (!($226)) {
    HEAP32[$0>>2] = 3489;
    break;
   }
   $227 = HEAP32[$name>>2]|0;
   $228 = (_strcmp($227,3107808)|0);
   $229 = ($228|0)!=(0);
   if (!($229)) {
    HEAP32[$0>>2] = 3860;
    break;
   }
   $230 = HEAP32[$name>>2]|0;
   $231 = (_strcmp($230,3107824)|0);
   $232 = ($231|0)!=(0);
   if (!($232)) {
    HEAP32[$0>>2] = 484;
    break;
   }
   $233 = HEAP32[$name>>2]|0;
   $234 = (_strcmp($233,3107848)|0);
   $235 = ($234|0)!=(0);
   if (!($235)) {
    HEAP32[$0>>2] = 485;
    break;
   }
   $236 = HEAP32[$name>>2]|0;
   $237 = (_strcmp($236,3107864)|0);
   $238 = ($237|0)!=(0);
   if (!($238)) {
    HEAP32[$0>>2] = 486;
    break;
   }
   $239 = HEAP32[$name>>2]|0;
   $240 = (_strcmp($239,3107888)|0);
   $241 = ($240|0)!=(0);
   if (!($241)) {
    HEAP32[$0>>2] = 3861;
    break;
   }
   $242 = HEAP32[$name>>2]|0;
   $243 = (_strcmp($242,3107904)|0);
   $244 = ($243|0)!=(0);
   if (!($244)) {
    HEAP32[$0>>2] = 487;
    break;
   }
   $245 = HEAP32[$name>>2]|0;
   $246 = (_strcmp($245,3107928)|0);
   $247 = ($246|0)!=(0);
   if (!($247)) {
    HEAP32[$0>>2] = 2154;
    break;
   }
   $248 = HEAP32[$name>>2]|0;
   $249 = (_strcmp($248,3107944)|0);
   $250 = ($249|0)!=(0);
   if (!($250)) {
    HEAP32[$0>>2] = 2155;
    break;
   }
   $251 = HEAP32[$name>>2]|0;
   $252 = (_strcmp($251,3107960)|0);
   $253 = ($252|0)!=(0);
   if (!($253)) {
    HEAP32[$0>>2] = 3490;
    break;
   }
   $254 = HEAP32[$name>>2]|0;
   $255 = (_strcmp($254,3106416)|0);
   $256 = ($255|0)!=(0);
   if (!($256)) {
    HEAP32[$0>>2] = 142;
    break;
   }
   $257 = HEAP32[$name>>2]|0;
   $258 = (_strcmp($257,3107976)|0);
   $259 = ($258|0)!=(0);
   if (!($259)) {
    HEAP32[$0>>2] = 3862;
    break;
   }
   $260 = HEAP32[$name>>2]|0;
   $261 = (_strcmp($260,3106528)|0);
   $262 = ($261|0)!=(0);
   if (!($262)) {
    HEAP32[$0>>2] = 3562;
    break;
   }
   $263 = HEAP32[$name>>2]|0;
   $264 = (_strcmp($263,3106560)|0);
   $265 = ($264|0)!=(0);
   if (!($265)) {
    HEAP32[$0>>2] = 3563;
    break;
   }
   $266 = HEAP32[$name>>2]|0;
   $267 = (_strcmp($266,3107992)|0);
   $268 = ($267|0)!=(0);
   if (!($268)) {
    HEAP32[$0>>2] = 488;
    break;
   }
   $269 = HEAP32[$name>>2]|0;
   $270 = (_strcmp($269,3108024)|0);
   $271 = ($270|0)!=(0);
   if (!($271)) {
    HEAP32[$0>>2] = 3863;
    break;
   }
   $272 = HEAP32[$name>>2]|0;
   $273 = (_strcmp($272,3108040)|0);
   $274 = ($273|0)!=(0);
   if (!($274)) {
    HEAP32[$0>>2] = 489;
    break;
   }
   $275 = HEAP32[$name>>2]|0;
   $276 = (_strcmp($275,3106456)|0);
   $277 = ($276|0)!=(0);
   if (!($277)) {
    HEAP32[$0>>2] = 3864;
    break;
   }
   $278 = HEAP32[$name>>2]|0;
   $279 = (_strcmp($278,3108064)|0);
   $280 = ($279|0)!=(0);
   if (!($280)) {
    HEAP32[$0>>2] = 3865;
    break;
   }
   $281 = HEAP32[$name>>2]|0;
   $282 = (_strcmp($281,3108088)|0);
   $283 = ($282|0)!=(0);
   if (!($283)) {
    HEAP32[$0>>2] = 3491;
    break;
   }
   $284 = HEAP32[$name>>2]|0;
   $285 = (_strcmp($284,3108104)|0);
   $286 = ($285|0)!=(0);
   if (!($286)) {
    HEAP32[$0>>2] = 2156;
    break;
   }
   $287 = HEAP32[$name>>2]|0;
   $288 = (_strcmp($287,3108128)|0);
   $289 = ($288|0)!=(0);
   if (!($289)) {
    HEAP32[$0>>2] = 3564;
    break;
   }
   $290 = HEAP32[$name>>2]|0;
   $291 = (_strcmp($290,3108152)|0);
   $292 = ($291|0)!=(0);
   if (!($292)) {
    HEAP32[$0>>2] = 3565;
    break;
   }
   $293 = HEAP32[$name>>2]|0;
   $294 = (_strcmp($293,3108176)|0);
   $295 = ($294|0)!=(0);
   if (!($295)) {
    HEAP32[$0>>2] = 3566;
    break;
   }
   $296 = HEAP32[$name>>2]|0;
   $297 = (_strcmp($296,3108200)|0);
   $298 = ($297|0)!=(0);
   if (!($298)) {
    HEAP32[$0>>2] = 490;
    break;
   }
   $299 = HEAP32[$name>>2]|0;
   $300 = (_strcmp($299,3108232)|0);
   $301 = ($300|0)!=(0);
   if (!($301)) {
    HEAP32[$0>>2] = 133;
    break;
   }
   $302 = HEAP32[$name>>2]|0;
   $303 = (_strcmp($302,3108256)|0);
   $304 = ($303|0)!=(0);
   if (!($304)) {
    HEAP32[$0>>2] = 491;
    break;
   }
   $305 = HEAP32[$name>>2]|0;
   $306 = (_strcmp($305,3108296)|0);
   $307 = ($306|0)!=(0);
   if (!($307)) {
    HEAP32[$0>>2] = 3492;
    break;
   }
   $308 = HEAP32[$name>>2]|0;
   $309 = (_strcmp($308,3108312)|0);
   $310 = ($309|0)!=(0);
   if (!($310)) {
    HEAP32[$0>>2] = 3866;
    break;
   }
   $311 = HEAP32[$name>>2]|0;
   $312 = (_strcmp($311,3108328)|0);
   $313 = ($312|0)!=(0);
   if (!($313)) {
    HEAP32[$0>>2] = 2157;
    break;
   }
   $314 = HEAP32[$name>>2]|0;
   $315 = (_strcmp($314,3108352)|0);
   $316 = ($315|0)!=(0);
   if (!($316)) {
    HEAP32[$0>>2] = 492;
    break;
   }
   $317 = HEAP32[$name>>2]|0;
   $318 = (_strcmp($317,3108368)|0);
   $319 = ($318|0)!=(0);
   if (!($319)) {
    HEAP32[$0>>2] = 3567;
    break;
   }
   $320 = HEAP32[$name>>2]|0;
   $321 = (_strcmp($320,3108384)|0);
   $322 = ($321|0)!=(0);
   if (!($322)) {
    HEAP32[$0>>2] = 3568;
    break;
   }
   $323 = HEAP32[$name>>2]|0;
   $324 = (_strcmp($323,3108400)|0);
   $325 = ($324|0)!=(0);
   if (!($325)) {
    HEAP32[$0>>2] = 142;
    break;
   }
   $326 = HEAP32[$name>>2]|0;
   $327 = (_strcmp($326,3108424)|0);
   $328 = ($327|0)!=(0);
   if (!($328)) {
    HEAP32[$0>>2] = 3867;
    break;
   }
   $329 = HEAP32[$name>>2]|0;
   $330 = (_strcmp($329,3108448)|0);
   $331 = ($330|0)!=(0);
   if (!($331)) {
    HEAP32[$0>>2] = 493;
    break;
   }
   $332 = HEAP32[$name>>2]|0;
   $333 = (_strcmp($332,3108464)|0);
   $334 = ($333|0)!=(0);
   if (!($334)) {
    HEAP32[$0>>2] = 494;
    break;
   }
   $335 = HEAP32[$name>>2]|0;
   $336 = (_strcmp($335,3108488)|0);
   $337 = ($336|0)!=(0);
   if (!($337)) {
    HEAP32[$0>>2] = 2158;
    break;
   }
   $338 = HEAP32[$name>>2]|0;
   $339 = (_strcmp($338,3108504)|0);
   $340 = ($339|0)!=(0);
   if (!($340)) {
    HEAP32[$0>>2] = 495;
    break;
   }
   $341 = HEAP32[$name>>2]|0;
   $342 = (_strcmp($341,3108520)|0);
   $343 = ($342|0)!=(0);
   if (!($343)) {
    HEAP32[$0>>2] = 3868;
    break;
   }
   $344 = HEAP32[$name>>2]|0;
   $345 = (_strcmp($344,3108544)|0);
   $346 = ($345|0)!=(0);
   if (!($346)) {
    HEAP32[$0>>2] = 3569;
    break;
   }
   $347 = HEAP32[$name>>2]|0;
   $348 = (_strcmp($347,3108568)|0);
   $349 = ($348|0)!=(0);
   if (!($349)) {
    HEAP32[$0>>2] = 3570;
    break;
   }
   $350 = HEAP32[$name>>2]|0;
   $351 = (_strcmp($350,3108592)|0);
   $352 = ($351|0)!=(0);
   if (!($352)) {
    HEAP32[$0>>2] = 3869;
    break;
   }
   $353 = HEAP32[$name>>2]|0;
   $354 = (_strcmp($353,3108616)|0);
   $355 = ($354|0)!=(0);
   if (!($355)) {
    HEAP32[$0>>2] = 3870;
    break;
   }
   $356 = HEAP32[$name>>2]|0;
   $357 = (_strcmp($356,3108632)|0);
   $358 = ($357|0)!=(0);
   if (!($358)) {
    HEAP32[$0>>2] = 1014;
    break;
   }
   $359 = HEAP32[$name>>2]|0;
   $360 = (_strcmp($359,3108648)|0);
   $361 = ($360|0)!=(0);
   if (!($361)) {
    HEAP32[$0>>2] = 3871;
    break;
   }
   $362 = HEAP32[$name>>2]|0;
   $363 = (_strcmp($362,3108664)|0);
   $364 = ($363|0)!=(0);
   if (!($364)) {
    HEAP32[$0>>2] = 1;
    break;
   }
   $365 = HEAP32[$name>>2]|0;
   $366 = (_strcmp($365,3108680)|0);
   $367 = ($366|0)!=(0);
   if (!($367)) {
    HEAP32[$0>>2] = 2;
    break;
   }
   $368 = HEAP32[$name>>2]|0;
   $369 = (_strcmp($368,3108696)|0);
   $370 = ($369|0)!=(0);
   if (!($370)) {
    HEAP32[$0>>2] = 143;
    break;
   }
   $371 = HEAP32[$name>>2]|0;
   $372 = (_strcmp($371,3108720)|0);
   $373 = ($372|0)!=(0);
   if (!($373)) {
    HEAP32[$0>>2] = 3872;
    break;
   }
   $374 = HEAP32[$name>>2]|0;
   $375 = (_strcmp($374,3108752)|0);
   $376 = ($375|0)!=(0);
   if (!($376)) {
    HEAP32[$0>>2] = 3873;
    break;
   }
   $377 = HEAP32[$name>>2]|0;
   $378 = (_strcmp($377,3108784)|0);
   $379 = ($378|0)!=(0);
   if (!($379)) {
    HEAP32[$0>>2] = 2159;
    break;
   }
   $380 = HEAP32[$name>>2]|0;
   $381 = (_strcmp($380,3108800)|0);
   $382 = ($381|0)!=(0);
   if (!($382)) {
    HEAP32[$0>>2] = 496;
    break;
   }
   $383 = HEAP32[$name>>2]|0;
   $384 = (_strcmp($383,3108816)|0);
   $385 = ($384|0)!=(0);
   if (!($385)) {
    HEAP32[$0>>2] = 134;
    break;
   }
   $386 = HEAP32[$name>>2]|0;
   $387 = (_strcmp($386,3108832)|0);
   $388 = ($387|0)!=(0);
   if (!($388)) {
    HEAP32[$0>>2] = 1015;
    break;
   }
   $389 = HEAP32[$name>>2]|0;
   $390 = (_strcmp($389,3108856)|0);
   $391 = ($390|0)!=(0);
   if (!($391)) {
    HEAP32[$0>>2] = 143;
    break;
   }
   $392 = HEAP32[$name>>2]|0;
   $393 = (_strcmp($392,3108872)|0);
   $394 = ($393|0)!=(0);
   if (!($394)) {
    HEAP32[$0>>2] = 3571;
    break;
   }
   $395 = HEAP32[$name>>2]|0;
   $396 = (_strcmp($395,3108896)|0);
   $397 = ($396|0)!=(0);
   if (!($397)) {
    HEAP32[$0>>2] = 497;
    break;
   }
   $398 = HEAP32[$name>>2]|0;
   $399 = (_strcmp($398,3108920)|0);
   $400 = ($399|0)!=(0);
   if (!($400)) {
    HEAP32[$0>>2] = 135;
    break;
   }
   $401 = HEAP32[$name>>2]|0;
   $402 = (_strcmp($401,3108944)|0);
   $403 = ($402|0)!=(0);
   if (!($403)) {
    HEAP32[$0>>2] = 1016;
    break;
   }
   $404 = HEAP32[$name>>2]|0;
   $405 = (_strcmp($404,3108960)|0);
   $406 = ($405|0)!=(0);
   if (!($406)) {
    HEAP32[$0>>2] = 1017;
    break;
   }
   $407 = HEAP32[$name>>2]|0;
   $408 = (_strcmp($407,3108968)|0);
   $409 = ($408|0)!=(0);
   if (!($409)) {
    HEAP32[$0>>2] = 1;
    break;
   }
   $410 = HEAP32[$name>>2]|0;
   $411 = (_strcmp($410,3108984)|0);
   $412 = ($411|0)!=(0);
   if (!($412)) {
    HEAP32[$0>>2] = 2;
    break;
   }
   $413 = HEAP32[$name>>2]|0;
   $414 = (_strcmp($413,3109000)|0);
   $415 = ($414|0)!=(0);
   if (!($415)) {
    HEAP32[$0>>2] = 3874;
    break;
   }
   $416 = HEAP32[$name>>2]|0;
   $417 = (_strcmp($416,3109016)|0);
   $418 = ($417|0)!=(0);
   if (!($418)) {
    HEAP32[$0>>2] = 3875;
    break;
   }
   $419 = HEAP32[$name>>2]|0;
   $420 = (_strcmp($419,3109032)|0);
   $421 = ($420|0)!=(0);
   if (!($421)) {
    HEAP32[$0>>2] = 3876;
    break;
   }
   $422 = HEAP32[$name>>2]|0;
   $423 = (_strcmp($422,3109048)|0);
   $424 = ($423|0)!=(0);
   if (!($424)) {
    HEAP32[$0>>2] = 3877;
    break;
   }
   $425 = HEAP32[$name>>2]|0;
   $426 = (_strcmp($425,3109064)|0);
   $427 = ($426|0)!=(0);
   if (!($427)) {
    HEAP32[$0>>2] = 3878;
    break;
   }
   $428 = HEAP32[$name>>2]|0;
   $429 = (_strcmp($428,3109080)|0);
   $430 = ($429|0)!=(0);
   if (!($430)) {
    HEAP32[$0>>2] = 3879;
    break;
   }
   $431 = HEAP32[$name>>2]|0;
   $432 = (_strcmp($431,3109088)|0);
   $433 = ($432|0)!=(0);
   if (!($433)) {
    HEAP32[$0>>2] = 3;
    break;
   }
   $434 = HEAP32[$name>>2]|0;
   $435 = (_strcmp($434,3109104)|0);
   $436 = ($435|0)!=(0);
   if (!($436)) {
    HEAP32[$0>>2] = 3880;
    break;
   }
   $437 = HEAP32[$name>>2]|0;
   $438 = (_strcmp($437,3109120)|0);
   $439 = ($438|0)!=(0);
   if (!($439)) {
    HEAP32[$0>>2] = 3881;
    break;
   }
   $440 = HEAP32[$name>>2]|0;
   $441 = (_strcmp($440,3109136)|0);
   $442 = ($441|0)!=(0);
   if (!($442)) {
    HEAP32[$0>>2] = 3882;
    break;
   }
   $443 = HEAP32[$name>>2]|0;
   $444 = (_strcmp($443,3109152)|0);
   $445 = ($444|0)!=(0);
   if (!($445)) {
    HEAP32[$0>>2] = 3493;
    break;
   }
   $446 = HEAP32[$name>>2]|0;
   $447 = (_strcmp($446,3109184)|0);
   $448 = ($447|0)!=(0);
   if (!($448)) {
    HEAP32[$0>>2] = 3883;
    break;
   }
   $449 = HEAP32[$name>>2]|0;
   $450 = (_strcmp($449,3109208)|0);
   $451 = ($450|0)!=(0);
   if (!($451)) {
    HEAP32[$0>>2] = 3884;
    break;
   }
   $452 = HEAP32[$name>>2]|0;
   $453 = (_strcmp($452,3109224)|0);
   $454 = ($453|0)!=(0);
   if (!($454)) {
    HEAP32[$0>>2] = 3885;
    break;
   }
   $455 = HEAP32[$name>>2]|0;
   $456 = (_strcmp($455,3109240)|0);
   $457 = ($456|0)!=(0);
   if (!($457)) {
    HEAP32[$0>>2] = 3494;
    break;
   }
   $458 = HEAP32[$name>>2]|0;
   $459 = (_strcmp($458,3109256)|0);
   $460 = ($459|0)!=(0);
   if (!($460)) {
    HEAP32[$0>>2] = 3572;
    break;
   }
   $461 = HEAP32[$name>>2]|0;
   $462 = (_strcmp($461,3109272)|0);
   $463 = ($462|0)!=(0);
   if (!($463)) {
    HEAP32[$0>>2] = 3573;
    break;
   }
   $464 = HEAP32[$name>>2]|0;
   $465 = (_strcmp($464,3109296)|0);
   $466 = ($465|0)!=(0);
   if (!($466)) {
    HEAP32[$0>>2] = 1;
    break;
   }
   $467 = HEAP32[$name>>2]|0;
   $468 = (_strcmp($467,3109312)|0);
   $469 = ($468|0)!=(0);
   if (!($469)) {
    HEAP32[$0>>2] = 2;
    break;
   }
   $470 = HEAP32[$name>>2]|0;
   $471 = (_strcmp($470,3109328)|0);
   $472 = ($471|0)!=(0);
   if (!($472)) {
    HEAP32[$0>>2] = 3574;
    break;
   }
   $473 = HEAP32[$name>>2]|0;
   $474 = (_strcmp($473,3109352)|0);
   $475 = ($474|0)!=(0);
   if (!($475)) {
    HEAP32[$0>>2] = 3575;
    break;
   }
   $476 = HEAP32[$name>>2]|0;
   $477 = (_strcmp($476,3109360)|0);
   $478 = ($477|0)!=(0);
   if (!($478)) {
    HEAP32[$0>>2] = 3;
    break;
   }
   $479 = HEAP32[$name>>2]|0;
   $480 = (_strcmp($479,3109376)|0);
   $481 = ($480|0)!=(0);
   if (!($481)) {
    HEAP32[$0>>2] = 192;
    break;
   }
   $482 = HEAP32[$name>>2]|0;
   $483 = (_strcmp($482,3109400)|0);
   $484 = ($483|0)!=(0);
   if (!($484)) {
    HEAP32[$0>>2] = 1;
    break;
   }
   $485 = HEAP32[$name>>2]|0;
   $486 = (_strcmp($485,3109424)|0);
   $487 = ($486|0)!=(0);
   if (!($487)) {
    HEAP32[$0>>2] = 2160;
    break;
   }
   $488 = HEAP32[$name>>2]|0;
   $489 = (_strcmp($488,3109440)|0);
   $490 = ($489|0)!=(0);
   if (!($490)) {
    HEAP32[$0>>2] = 49;
    break;
   }
   $491 = HEAP32[$name>>2]|0;
   $492 = (_strcmp($491,3109456)|0);
   $493 = ($492|0)!=(0);
   if (!($493)) {
    HEAP32[$0>>2] = 20;
    break;
   }
   $494 = HEAP32[$name>>2]|0;
   $495 = (_strcmp($494,3109480)|0);
   $496 = ($495|0)!=(0);
   if (!($496)) {
    HEAP32[$0>>2] = 2161;
    break;
   }
   $497 = HEAP32[$name>>2]|0;
   $498 = (_strcmp($497,3109496)|0);
   $499 = ($498|0)!=(0);
   if (!($499)) {
    HEAP32[$0>>2] = 2162;
    break;
   }
   $500 = HEAP32[$name>>2]|0;
   $501 = (_strcmp($500,3109512)|0);
   $502 = ($501|0)!=(0);
   if (!($502)) {
    HEAP32[$0>>2] = 498;
    break;
   }
   $503 = HEAP32[$name>>2]|0;
   $504 = (_strcmp($503,3109528)|0);
   $505 = ($504|0)!=(0);
   if (!($505)) {
    HEAP32[$0>>2] = 3;
    break;
   }
   $506 = HEAP32[$name>>2]|0;
   $507 = (_strcmp($506,3109544)|0);
   $508 = ($507|0)!=(0);
   if (!($508)) {
    HEAP32[$0>>2] = 499;
    break;
   }
   $509 = HEAP32[$name>>2]|0;
   $510 = (_strcmp($509,3109560)|0);
   $511 = ($510|0)!=(0);
   if (!($511)) {
    HEAP32[$0>>2] = 8;
    break;
   }
   $512 = HEAP32[$name>>2]|0;
   $513 = (_strcmp($512,3109584)|0);
   $514 = ($513|0)!=(0);
   if (!($514)) {
    HEAP32[$0>>2] = 500;
    break;
   }
   $515 = HEAP32[$name>>2]|0;
   $516 = (_strcmp($515,3109600)|0);
   $517 = ($516|0)!=(0);
   if (!($517)) {
    HEAP32[$0>>2] = 501;
    break;
   }
   $518 = HEAP32[$name>>2]|0;
   $519 = (_strcmp($518,3109624)|0);
   $520 = ($519|0)!=(0);
   if (!($520)) {
    HEAP32[$0>>2] = 502;
    break;
   }
   $521 = HEAP32[$name>>2]|0;
   $522 = (_strcmp($521,3109648)|0);
   $523 = ($522|0)!=(0);
   if (!($523)) {
    HEAP32[$0>>2] = 4;
    break;
   }
   $524 = HEAP32[$name>>2]|0;
   $525 = (_strcmp($524,3109664)|0);
   $526 = ($525|0)!=(0);
   if (!($526)) {
    HEAP32[$0>>2] = 503;
    break;
   }
   $527 = HEAP32[$name>>2]|0;
   $528 = (_strcmp($527,3109688)|0);
   $529 = ($528|0)!=(0);
   if (!($529)) {
    HEAP32[$0>>2] = 504;
    break;
   }
   $530 = HEAP32[$name>>2]|0;
   $531 = (_strcmp($530,3109712)|0);
   $532 = ($531|0)!=(0);
   if (!($532)) {
    HEAP32[$0>>2] = 9;
    break;
   }
   $533 = HEAP32[$name>>2]|0;
   $534 = (_strcmp($533,3109736)|0);
   $535 = ($534|0)!=(0);
   if (!($535)) {
    HEAP32[$0>>2] = 38;
    break;
   }
   $536 = HEAP32[$name>>2]|0;
   $537 = (_strcmp($536,3109760)|0);
   $538 = ($537|0)!=(0);
   if (!($538)) {
    HEAP32[$0>>2] = 39;
    break;
   }
   $539 = HEAP32[$name>>2]|0;
   $540 = (_strcmp($539,3109784)|0);
   $541 = ($540|0)!=(0);
   if (!($541)) {
    HEAP32[$0>>2] = 3576;
    break;
   }
   $542 = HEAP32[_stderr>>2]|0;
   $543 = HEAP32[$1>>2]|0;
   $544 = HEAP32[$name>>2]|0;
   HEAP32[$vararg_buffer>>2] = $543;
   $vararg_ptr1 = (($vararg_buffer) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $544;
   (_fprintf(($542|0),(3109800|0),($vararg_buffer|0))|0);
   HEAP32[$0>>2] = 0;
  } else {
   HEAP32[$0>>2] = 3544;
  }
 } while(0);
 $545 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($545|0);
}
function _malloc($bytes) {
 $bytes = $bytes|0;
 var $$$i = 0, $$3$i = 0, $$4$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i25 = 0, $$pre$i25$i = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i26$iZ2D = 0, $$pre$phi$i26Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi58$i$iZ2D = 0, $$pre$phiZ2D = 0, $$pre57$i$i = 0, $$rsize$0$i = 0, $$rsize$3$i = 0, $$sum = 0, $$sum$i$i = 0, $$sum$i$i$i = 0;
 var $$sum$i14$i = 0, $$sum$i15$i = 0, $$sum$i18$i = 0, $$sum$i21$i = 0, $$sum$i2334 = 0, $$sum$i32 = 0, $$sum$i35 = 0, $$sum1 = 0, $$sum1$i = 0, $$sum1$i$i = 0, $$sum1$i16$i = 0, $$sum1$i22$i = 0, $$sum1$i24 = 0, $$sum10 = 0, $$sum10$i = 0, $$sum10$i$i = 0, $$sum10$pre$i$i = 0, $$sum107$i = 0, $$sum108$i = 0, $$sum109$i = 0;
 var $$sum11$i = 0, $$sum11$i$i = 0, $$sum11$i24$i = 0, $$sum110$i = 0, $$sum111$i = 0, $$sum1112 = 0, $$sum112$i = 0, $$sum113$i = 0, $$sum114$i = 0, $$sum115$i = 0, $$sum116$i = 0, $$sum117$i = 0, $$sum118$i = 0, $$sum119$i = 0, $$sum12$i = 0, $$sum12$i$i = 0, $$sum120$i = 0, $$sum13$i = 0, $$sum13$i$i = 0, $$sum14$i$i = 0;
 var $$sum14$pre$i = 0, $$sum15$i = 0, $$sum15$i$i = 0, $$sum16$i = 0, $$sum16$i$i = 0, $$sum17$i = 0, $$sum17$i$i = 0, $$sum18$i = 0, $$sum1819$i$i = 0, $$sum2 = 0, $$sum2$i = 0, $$sum2$i$i = 0, $$sum2$i$i$i = 0, $$sum2$i17$i = 0, $$sum2$i19$i = 0, $$sum2$i23$i = 0, $$sum2$pre$i = 0, $$sum20$i$i = 0, $$sum21$i$i = 0, $$sum22$i$i = 0;
 var $$sum23$i$i = 0, $$sum24$i$i = 0, $$sum25$i$i = 0, $$sum26$pre$i$i = 0, $$sum27$i$i = 0, $$sum28$i$i = 0, $$sum29$i$i = 0, $$sum3$i = 0, $$sum3$i$i = 0, $$sum3$i27 = 0, $$sum30$i$i = 0, $$sum3132$i$i = 0, $$sum34$i$i = 0, $$sum3536$i$i = 0, $$sum3738$i$i = 0, $$sum39$i$i = 0, $$sum4 = 0, $$sum4$i = 0, $$sum4$i28 = 0, $$sum40$i$i = 0;
 var $$sum41$i$i = 0, $$sum42$i$i = 0, $$sum5$i = 0, $$sum5$i$i = 0, $$sum56 = 0, $$sum6$i = 0, $$sum67$i$i = 0, $$sum7$i = 0, $$sum8$i = 0, $$sum8$pre = 0, $$sum9 = 0, $$sum9$i = 0, $$sum9$i$i = 0, $$tsize$1$i = 0, $$v$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0;
 var $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0;
 var $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0;
 var $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0;
 var $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0;
 var $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0;
 var $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0;
 var $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0;
 var $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0;
 var $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0;
 var $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0;
 var $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0;
 var $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0;
 var $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0;
 var $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0;
 var $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0;
 var $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0;
 var $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0;
 var $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0;
 var $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0;
 var $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0;
 var $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0;
 var $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0;
 var $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0;
 var $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0;
 var $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0;
 var $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0;
 var $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0;
 var $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0;
 var $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0;
 var $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0;
 var $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0;
 var $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0;
 var $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0;
 var $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0;
 var $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0;
 var $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0;
 var $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0;
 var $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0;
 var $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0;
 var $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0;
 var $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0;
 var $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0;
 var $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $F$0$i$i = 0, $F1$0$i = 0, $F4$0 = 0, $F4$0$i$i = 0, $F5$0$i = 0;
 var $I1$0$c$i$i = 0, $I1$0$i$i = 0, $I7$0$i = 0, $I7$0$i$i = 0, $K12$025$i = 0, $K2$014$i$i = 0, $K8$052$i$i = 0, $R$0$i = 0, $R$0$i$i = 0, $R$0$i18 = 0, $R$1$i = 0, $R$1$i$i = 0, $R$1$i20 = 0, $RP$0$i = 0, $RP$0$i$i = 0, $RP$0$i17 = 0, $T$0$lcssa$i = 0, $T$0$lcssa$i$i = 0, $T$0$lcssa$i28$i = 0, $T$013$i$i = 0;
 var $T$024$i = 0, $T$051$i$i = 0, $br$0$i = 0, $cond$i = 0, $cond$i$i = 0, $cond$i21 = 0, $exitcond$i$i = 0, $i$02$i$i = 0, $idx$0$i = 0, $mem$0 = 0, $nb$0 = 0, $notlhs$i = 0, $notrhs$i = 0, $oldfirst$0$i$i = 0, $or$cond$i = 0, $or$cond$i29 = 0, $or$cond1$i = 0, $or$cond10$i = 0, $or$cond19$i = 0, $or$cond2$i = 0;
 var $or$cond49$i = 0, $or$cond5$i = 0, $or$cond6$i = 0, $or$cond8$not$i = 0, $or$cond9$i = 0, $qsize$0$i$i = 0, $rsize$0$i = 0, $rsize$0$i15 = 0, $rsize$1$i = 0, $rsize$2$i = 0, $rsize$3$lcssa$i = 0, $rsize$329$i = 0, $rst$0$i = 0, $rst$1$i = 0, $sizebits$0$i = 0, $sp$0$i$i = 0, $sp$0$i$i$i = 0, $sp$075$i = 0, $sp$168$i = 0, $ssize$0$$i = 0;
 var $ssize$0$i = 0, $ssize$1$i = 0, $ssize$2$i = 0, $t$0$i = 0, $t$0$i14 = 0, $t$1$i = 0, $t$2$ph$i = 0, $t$2$v$3$i = 0, $t$228$i = 0, $tbase$0$i = 0, $tbase$247$i = 0, $tsize$0$i = 0, $tsize$0323841$i = 0, $tsize$1$i = 0, $tsize$246$i = 0, $v$0$i = 0, $v$0$i16 = 0, $v$1$i = 0, $v$2$i = 0, $v$3$lcssa$i = 0;
 var $v$330$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bytes>>>0)<(245);
 do {
  if ($0) {
   $1 = ($bytes>>>0)<(11);
   if ($1) {
    $5 = 16;
   } else {
    $2 = (($bytes) + 11)|0;
    $3 = $2 & -8;
    $5 = $3;
   }
   $4 = $5 >>> 3;
   $6 = HEAP32[3109840>>2]|0;
   $7 = $6 >>> $4;
   $8 = $7 & 3;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $10 = $7 & 1;
    $11 = $10 ^ 1;
    $12 = (($11) + ($4))|0;
    $13 = $12 << 1;
    $14 = ((3109840 + ($13<<2)|0) + 40|0);
    $$sum10 = (($13) + 2)|0;
    $15 = ((3109840 + ($$sum10<<2)|0) + 40|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($14|0)==($18|0);
    do {
     if ($19) {
      $20 = 1 << $12;
      $21 = $20 ^ -1;
      $22 = $6 & $21;
      HEAP32[3109840>>2] = $22;
     } else {
      $23 = HEAP32[((3109840 + 16|0))>>2]|0;
      $24 = ($18>>>0)<($23>>>0);
      if ($24) {
       _abort();
       // unreachable;
      }
      $25 = (($18) + 12|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==($16|0);
      if ($27) {
       HEAP32[$25>>2] = $14;
       HEAP32[$15>>2] = $18;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $28 = $12 << 3;
    $29 = $28 | 3;
    $30 = (($16) + 4|0);
    HEAP32[$30>>2] = $29;
    $$sum1112 = $28 | 4;
    $31 = (($16) + ($$sum1112)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = $32 | 1;
    HEAP32[$31>>2] = $33;
    $mem$0 = $17;
    STACKTOP = sp;return ($mem$0|0);
   }
   $34 = HEAP32[((3109840 + 8|0))>>2]|0;
   $35 = ($5>>>0)>($34>>>0);
   if ($35) {
    $36 = ($7|0)==(0);
    if (!($36)) {
     $37 = $7 << $4;
     $38 = 2 << $4;
     $39 = (0 - ($38))|0;
     $40 = $38 | $39;
     $41 = $37 & $40;
     $42 = (0 - ($41))|0;
     $43 = $41 & $42;
     $44 = (($43) + -1)|0;
     $45 = $44 >>> 12;
     $46 = $45 & 16;
     $47 = $44 >>> $46;
     $48 = $47 >>> 5;
     $49 = $48 & 8;
     $50 = $49 | $46;
     $51 = $47 >>> $49;
     $52 = $51 >>> 2;
     $53 = $52 & 4;
     $54 = $50 | $53;
     $55 = $51 >>> $53;
     $56 = $55 >>> 1;
     $57 = $56 & 2;
     $58 = $54 | $57;
     $59 = $55 >>> $57;
     $60 = $59 >>> 1;
     $61 = $60 & 1;
     $62 = $58 | $61;
     $63 = $59 >>> $61;
     $64 = (($62) + ($63))|0;
     $65 = $64 << 1;
     $66 = ((3109840 + ($65<<2)|0) + 40|0);
     $$sum4 = (($65) + 2)|0;
     $67 = ((3109840 + ($$sum4<<2)|0) + 40|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($68) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($66|0)==($70|0);
     do {
      if ($71) {
       $72 = 1 << $64;
       $73 = $72 ^ -1;
       $74 = $6 & $73;
       HEAP32[3109840>>2] = $74;
      } else {
       $75 = HEAP32[((3109840 + 16|0))>>2]|0;
       $76 = ($70>>>0)<($75>>>0);
       if ($76) {
        _abort();
        // unreachable;
       }
       $77 = (($70) + 12|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($78|0)==($68|0);
       if ($79) {
        HEAP32[$77>>2] = $66;
        HEAP32[$67>>2] = $70;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $80 = $64 << 3;
     $81 = (($80) - ($5))|0;
     $82 = $5 | 3;
     $83 = (($68) + 4|0);
     HEAP32[$83>>2] = $82;
     $84 = (($68) + ($5)|0);
     $85 = $81 | 1;
     $$sum56 = $5 | 4;
     $86 = (($68) + ($$sum56)|0);
     HEAP32[$86>>2] = $85;
     $87 = (($68) + ($80)|0);
     HEAP32[$87>>2] = $81;
     $88 = HEAP32[((3109840 + 8|0))>>2]|0;
     $89 = ($88|0)==(0);
     if (!($89)) {
      $90 = HEAP32[((3109840 + 20|0))>>2]|0;
      $91 = $88 >>> 3;
      $92 = $91 << 1;
      $93 = ((3109840 + ($92<<2)|0) + 40|0);
      $94 = HEAP32[3109840>>2]|0;
      $95 = 1 << $91;
      $96 = $94 & $95;
      $97 = ($96|0)==(0);
      if ($97) {
       $98 = $94 | $95;
       HEAP32[3109840>>2] = $98;
       $$sum8$pre = (($92) + 2)|0;
       $$pre = ((3109840 + ($$sum8$pre<<2)|0) + 40|0);
       $$pre$phiZ2D = $$pre;$F4$0 = $93;
      } else {
       $$sum9 = (($92) + 2)|0;
       $99 = ((3109840 + ($$sum9<<2)|0) + 40|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = HEAP32[((3109840 + 16|0))>>2]|0;
       $102 = ($100>>>0)<($101>>>0);
       if ($102) {
        _abort();
        // unreachable;
       } else {
        $$pre$phiZ2D = $99;$F4$0 = $100;
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = $90;
      $103 = (($F4$0) + 12|0);
      HEAP32[$103>>2] = $90;
      $104 = (($90) + 8|0);
      HEAP32[$104>>2] = $F4$0;
      $105 = (($90) + 12|0);
      HEAP32[$105>>2] = $93;
     }
     HEAP32[((3109840 + 8|0))>>2] = $81;
     HEAP32[((3109840 + 20|0))>>2] = $84;
     $mem$0 = $69;
     STACKTOP = sp;return ($mem$0|0);
    }
    $106 = HEAP32[((3109840 + 4|0))>>2]|0;
    $107 = ($106|0)==(0);
    if ($107) {
     $nb$0 = $5;
    } else {
     $108 = (0 - ($106))|0;
     $109 = $106 & $108;
     $110 = (($109) + -1)|0;
     $111 = $110 >>> 12;
     $112 = $111 & 16;
     $113 = $110 >>> $112;
     $114 = $113 >>> 5;
     $115 = $114 & 8;
     $116 = $115 | $112;
     $117 = $113 >>> $115;
     $118 = $117 >>> 2;
     $119 = $118 & 4;
     $120 = $116 | $119;
     $121 = $117 >>> $119;
     $122 = $121 >>> 1;
     $123 = $122 & 2;
     $124 = $120 | $123;
     $125 = $121 >>> $123;
     $126 = $125 >>> 1;
     $127 = $126 & 1;
     $128 = $124 | $127;
     $129 = $125 >>> $127;
     $130 = (($128) + ($129))|0;
     $131 = ((3109840 + ($130<<2)|0) + 304|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = (($132) + 4|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = $134 & -8;
     $136 = (($135) - ($5))|0;
     $rsize$0$i = $136;$t$0$i = $132;$v$0$i = $132;
     while(1) {
      $137 = (($t$0$i) + 16|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = ($138|0)==(0|0);
      if ($139) {
       $140 = (($t$0$i) + 20|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = ($141|0)==(0|0);
       if ($142) {
        break;
       } else {
        $144 = $141;
       }
      } else {
       $144 = $138;
      }
      $143 = (($144) + 4|0);
      $145 = HEAP32[$143>>2]|0;
      $146 = $145 & -8;
      $147 = (($146) - ($5))|0;
      $148 = ($147>>>0)<($rsize$0$i>>>0);
      $$rsize$0$i = $148 ? $147 : $rsize$0$i;
      $$v$0$i = $148 ? $144 : $v$0$i;
      $rsize$0$i = $$rsize$0$i;$t$0$i = $144;$v$0$i = $$v$0$i;
     }
     $149 = HEAP32[((3109840 + 16|0))>>2]|0;
     $150 = ($v$0$i>>>0)<($149>>>0);
     if ($150) {
      _abort();
      // unreachable;
     }
     $151 = (($v$0$i) + ($5)|0);
     $152 = ($v$0$i>>>0)<($151>>>0);
     if (!($152)) {
      _abort();
      // unreachable;
     }
     $153 = (($v$0$i) + 24|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (($v$0$i) + 12|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = ($156|0)==($v$0$i|0);
     do {
      if ($157) {
       $167 = (($v$0$i) + 20|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = ($168|0)==(0|0);
       if ($169) {
        $170 = (($v$0$i) + 16|0);
        $171 = HEAP32[$170>>2]|0;
        $172 = ($171|0)==(0|0);
        if ($172) {
         $R$1$i = 0;
         break;
        } else {
         $R$0$i = $171;$RP$0$i = $170;
        }
       } else {
        $R$0$i = $168;$RP$0$i = $167;
       }
       while(1) {
        $173 = (($R$0$i) + 20|0);
        $174 = HEAP32[$173>>2]|0;
        $175 = ($174|0)==(0|0);
        if (!($175)) {
         $R$0$i = $174;$RP$0$i = $173;
         continue;
        }
        $176 = (($R$0$i) + 16|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = ($177|0)==(0|0);
        if ($178) {
         break;
        } else {
         $R$0$i = $177;$RP$0$i = $176;
        }
       }
       $179 = ($RP$0$i>>>0)<($149>>>0);
       if ($179) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$RP$0$i>>2] = 0;
        $R$1$i = $R$0$i;
        break;
       }
      } else {
       $158 = (($v$0$i) + 8|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = ($159>>>0)<($149>>>0);
       if ($160) {
        _abort();
        // unreachable;
       }
       $161 = (($159) + 12|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = ($162|0)==($v$0$i|0);
       if (!($163)) {
        _abort();
        // unreachable;
       }
       $164 = (($156) + 8|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ($165|0)==($v$0$i|0);
       if ($166) {
        HEAP32[$161>>2] = $156;
        HEAP32[$164>>2] = $159;
        $R$1$i = $156;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $180 = ($154|0)==(0|0);
     do {
      if (!($180)) {
       $181 = (($v$0$i) + 28|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = ((3109840 + ($182<<2)|0) + 304|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = ($v$0$i|0)==($184|0);
       if ($185) {
        HEAP32[$183>>2] = $R$1$i;
        $cond$i = ($R$1$i|0)==(0|0);
        if ($cond$i) {
         $186 = 1 << $182;
         $187 = $186 ^ -1;
         $188 = HEAP32[((3109840 + 4|0))>>2]|0;
         $189 = $188 & $187;
         HEAP32[((3109840 + 4|0))>>2] = $189;
         break;
        }
       } else {
        $190 = HEAP32[((3109840 + 16|0))>>2]|0;
        $191 = ($154>>>0)<($190>>>0);
        if ($191) {
         _abort();
         // unreachable;
        }
        $192 = (($154) + 16|0);
        $193 = HEAP32[$192>>2]|0;
        $194 = ($193|0)==($v$0$i|0);
        if ($194) {
         HEAP32[$192>>2] = $R$1$i;
        } else {
         $195 = (($154) + 20|0);
         HEAP32[$195>>2] = $R$1$i;
        }
        $196 = ($R$1$i|0)==(0|0);
        if ($196) {
         break;
        }
       }
       $197 = HEAP32[((3109840 + 16|0))>>2]|0;
       $198 = ($R$1$i>>>0)<($197>>>0);
       if ($198) {
        _abort();
        // unreachable;
       }
       $199 = (($R$1$i) + 24|0);
       HEAP32[$199>>2] = $154;
       $200 = (($v$0$i) + 16|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ($201|0)==(0|0);
       do {
        if (!($202)) {
         $203 = HEAP32[((3109840 + 16|0))>>2]|0;
         $204 = ($201>>>0)<($203>>>0);
         if ($204) {
          _abort();
          // unreachable;
         } else {
          $205 = (($R$1$i) + 16|0);
          HEAP32[$205>>2] = $201;
          $206 = (($201) + 24|0);
          HEAP32[$206>>2] = $R$1$i;
          break;
         }
        }
       } while(0);
       $207 = (($v$0$i) + 20|0);
       $208 = HEAP32[$207>>2]|0;
       $209 = ($208|0)==(0|0);
       if (!($209)) {
        $210 = HEAP32[((3109840 + 16|0))>>2]|0;
        $211 = ($208>>>0)<($210>>>0);
        if ($211) {
         _abort();
         // unreachable;
        } else {
         $212 = (($R$1$i) + 20|0);
         HEAP32[$212>>2] = $208;
         $213 = (($208) + 24|0);
         HEAP32[$213>>2] = $R$1$i;
         break;
        }
       }
      }
     } while(0);
     $214 = ($rsize$0$i>>>0)<(16);
     if ($214) {
      $215 = (($rsize$0$i) + ($5))|0;
      $216 = $215 | 3;
      $217 = (($v$0$i) + 4|0);
      HEAP32[$217>>2] = $216;
      $$sum4$i = (($215) + 4)|0;
      $218 = (($v$0$i) + ($$sum4$i)|0);
      $219 = HEAP32[$218>>2]|0;
      $220 = $219 | 1;
      HEAP32[$218>>2] = $220;
     } else {
      $221 = $5 | 3;
      $222 = (($v$0$i) + 4|0);
      HEAP32[$222>>2] = $221;
      $223 = $rsize$0$i | 1;
      $$sum$i35 = $5 | 4;
      $224 = (($v$0$i) + ($$sum$i35)|0);
      HEAP32[$224>>2] = $223;
      $$sum1$i = (($rsize$0$i) + ($5))|0;
      $225 = (($v$0$i) + ($$sum1$i)|0);
      HEAP32[$225>>2] = $rsize$0$i;
      $226 = HEAP32[((3109840 + 8|0))>>2]|0;
      $227 = ($226|0)==(0);
      if (!($227)) {
       $228 = HEAP32[((3109840 + 20|0))>>2]|0;
       $229 = $226 >>> 3;
       $230 = $229 << 1;
       $231 = ((3109840 + ($230<<2)|0) + 40|0);
       $232 = HEAP32[3109840>>2]|0;
       $233 = 1 << $229;
       $234 = $232 & $233;
       $235 = ($234|0)==(0);
       if ($235) {
        $236 = $232 | $233;
        HEAP32[3109840>>2] = $236;
        $$sum2$pre$i = (($230) + 2)|0;
        $$pre$i = ((3109840 + ($$sum2$pre$i<<2)|0) + 40|0);
        $$pre$phi$iZ2D = $$pre$i;$F1$0$i = $231;
       } else {
        $$sum3$i = (($230) + 2)|0;
        $237 = ((3109840 + ($$sum3$i<<2)|0) + 40|0);
        $238 = HEAP32[$237>>2]|0;
        $239 = HEAP32[((3109840 + 16|0))>>2]|0;
        $240 = ($238>>>0)<($239>>>0);
        if ($240) {
         _abort();
         // unreachable;
        } else {
         $$pre$phi$iZ2D = $237;$F1$0$i = $238;
        }
       }
       HEAP32[$$pre$phi$iZ2D>>2] = $228;
       $241 = (($F1$0$i) + 12|0);
       HEAP32[$241>>2] = $228;
       $242 = (($228) + 8|0);
       HEAP32[$242>>2] = $F1$0$i;
       $243 = (($228) + 12|0);
       HEAP32[$243>>2] = $231;
      }
      HEAP32[((3109840 + 8|0))>>2] = $rsize$0$i;
      HEAP32[((3109840 + 20|0))>>2] = $151;
     }
     $244 = (($v$0$i) + 8|0);
     $mem$0 = $244;
     STACKTOP = sp;return ($mem$0|0);
    }
   } else {
    $nb$0 = $5;
   }
  } else {
   $245 = ($bytes>>>0)>(4294967231);
   if ($245) {
    $nb$0 = -1;
   } else {
    $246 = (($bytes) + 11)|0;
    $247 = $246 & -8;
    $248 = HEAP32[((3109840 + 4|0))>>2]|0;
    $249 = ($248|0)==(0);
    if ($249) {
     $nb$0 = $247;
    } else {
     $250 = (0 - ($247))|0;
     $251 = $246 >>> 8;
     $252 = ($251|0)==(0);
     if ($252) {
      $idx$0$i = 0;
     } else {
      $253 = ($247>>>0)>(16777215);
      if ($253) {
       $idx$0$i = 31;
      } else {
       $254 = (($251) + 1048320)|0;
       $255 = $254 >>> 16;
       $256 = $255 & 8;
       $257 = $251 << $256;
       $258 = (($257) + 520192)|0;
       $259 = $258 >>> 16;
       $260 = $259 & 4;
       $261 = $260 | $256;
       $262 = $257 << $260;
       $263 = (($262) + 245760)|0;
       $264 = $263 >>> 16;
       $265 = $264 & 2;
       $266 = $261 | $265;
       $267 = (14 - ($266))|0;
       $268 = $262 << $265;
       $269 = $268 >>> 15;
       $270 = (($267) + ($269))|0;
       $271 = $270 << 1;
       $272 = (($270) + 7)|0;
       $273 = $247 >>> $272;
       $274 = $273 & 1;
       $275 = $274 | $271;
       $idx$0$i = $275;
      }
     }
     $276 = ((3109840 + ($idx$0$i<<2)|0) + 304|0);
     $277 = HEAP32[$276>>2]|0;
     $278 = ($277|0)==(0|0);
     L126: do {
      if ($278) {
       $rsize$2$i = $250;$t$1$i = 0;$v$2$i = 0;
      } else {
       $279 = ($idx$0$i|0)==(31);
       if ($279) {
        $283 = 0;
       } else {
        $280 = $idx$0$i >>> 1;
        $281 = (25 - ($280))|0;
        $283 = $281;
       }
       $282 = $247 << $283;
       $rsize$0$i15 = $250;$rst$0$i = 0;$sizebits$0$i = $282;$t$0$i14 = $277;$v$0$i16 = 0;
       while(1) {
        $284 = (($t$0$i14) + 4|0);
        $285 = HEAP32[$284>>2]|0;
        $286 = $285 & -8;
        $287 = (($286) - ($247))|0;
        $288 = ($287>>>0)<($rsize$0$i15>>>0);
        if ($288) {
         $289 = ($286|0)==($247|0);
         if ($289) {
          $rsize$2$i = $287;$t$1$i = $t$0$i14;$v$2$i = $t$0$i14;
          break L126;
         } else {
          $rsize$1$i = $287;$v$1$i = $t$0$i14;
         }
        } else {
         $rsize$1$i = $rsize$0$i15;$v$1$i = $v$0$i16;
        }
        $290 = (($t$0$i14) + 20|0);
        $291 = HEAP32[$290>>2]|0;
        $292 = $sizebits$0$i >>> 31;
        $293 = ((($t$0$i14) + ($292<<2)|0) + 16|0);
        $294 = HEAP32[$293>>2]|0;
        $295 = ($291|0)==(0|0);
        $296 = ($291|0)==($294|0);
        $or$cond$i = $295 | $296;
        $rst$1$i = $or$cond$i ? $rst$0$i : $291;
        $297 = ($294|0)==(0|0);
        $298 = $sizebits$0$i << 1;
        if ($297) {
         $rsize$2$i = $rsize$1$i;$t$1$i = $rst$1$i;$v$2$i = $v$1$i;
         break;
        } else {
         $rsize$0$i15 = $rsize$1$i;$rst$0$i = $rst$1$i;$sizebits$0$i = $298;$t$0$i14 = $294;$v$0$i16 = $v$1$i;
        }
       }
      }
     } while(0);
     $299 = ($t$1$i|0)==(0|0);
     $300 = ($v$2$i|0)==(0|0);
     $or$cond19$i = $299 & $300;
     if ($or$cond19$i) {
      $301 = 2 << $idx$0$i;
      $302 = (0 - ($301))|0;
      $303 = $301 | $302;
      $304 = $248 & $303;
      $305 = ($304|0)==(0);
      if ($305) {
       $nb$0 = $247;
       break;
      }
      $306 = (0 - ($304))|0;
      $307 = $304 & $306;
      $308 = (($307) + -1)|0;
      $309 = $308 >>> 12;
      $310 = $309 & 16;
      $311 = $308 >>> $310;
      $312 = $311 >>> 5;
      $313 = $312 & 8;
      $314 = $313 | $310;
      $315 = $311 >>> $313;
      $316 = $315 >>> 2;
      $317 = $316 & 4;
      $318 = $314 | $317;
      $319 = $315 >>> $317;
      $320 = $319 >>> 1;
      $321 = $320 & 2;
      $322 = $318 | $321;
      $323 = $319 >>> $321;
      $324 = $323 >>> 1;
      $325 = $324 & 1;
      $326 = $322 | $325;
      $327 = $323 >>> $325;
      $328 = (($326) + ($327))|0;
      $329 = ((3109840 + ($328<<2)|0) + 304|0);
      $330 = HEAP32[$329>>2]|0;
      $t$2$ph$i = $330;
     } else {
      $t$2$ph$i = $t$1$i;
     }
     $331 = ($t$2$ph$i|0)==(0|0);
     if ($331) {
      $rsize$3$lcssa$i = $rsize$2$i;$v$3$lcssa$i = $v$2$i;
     } else {
      $rsize$329$i = $rsize$2$i;$t$228$i = $t$2$ph$i;$v$330$i = $v$2$i;
      while(1) {
       $332 = (($t$228$i) + 4|0);
       $333 = HEAP32[$332>>2]|0;
       $334 = $333 & -8;
       $335 = (($334) - ($247))|0;
       $336 = ($335>>>0)<($rsize$329$i>>>0);
       $$rsize$3$i = $336 ? $335 : $rsize$329$i;
       $t$2$v$3$i = $336 ? $t$228$i : $v$330$i;
       $337 = (($t$228$i) + 16|0);
       $338 = HEAP32[$337>>2]|0;
       $339 = ($338|0)==(0|0);
       if (!($339)) {
        $rsize$329$i = $$rsize$3$i;$t$228$i = $338;$v$330$i = $t$2$v$3$i;
        continue;
       }
       $340 = (($t$228$i) + 20|0);
       $341 = HEAP32[$340>>2]|0;
       $342 = ($341|0)==(0|0);
       if ($342) {
        $rsize$3$lcssa$i = $$rsize$3$i;$v$3$lcssa$i = $t$2$v$3$i;
        break;
       } else {
        $rsize$329$i = $$rsize$3$i;$t$228$i = $341;$v$330$i = $t$2$v$3$i;
       }
      }
     }
     $343 = ($v$3$lcssa$i|0)==(0|0);
     if ($343) {
      $nb$0 = $247;
     } else {
      $344 = HEAP32[((3109840 + 8|0))>>2]|0;
      $345 = (($344) - ($247))|0;
      $346 = ($rsize$3$lcssa$i>>>0)<($345>>>0);
      if ($346) {
       $347 = HEAP32[((3109840 + 16|0))>>2]|0;
       $348 = ($v$3$lcssa$i>>>0)<($347>>>0);
       if ($348) {
        _abort();
        // unreachable;
       }
       $349 = (($v$3$lcssa$i) + ($247)|0);
       $350 = ($v$3$lcssa$i>>>0)<($349>>>0);
       if (!($350)) {
        _abort();
        // unreachable;
       }
       $351 = (($v$3$lcssa$i) + 24|0);
       $352 = HEAP32[$351>>2]|0;
       $353 = (($v$3$lcssa$i) + 12|0);
       $354 = HEAP32[$353>>2]|0;
       $355 = ($354|0)==($v$3$lcssa$i|0);
       do {
        if ($355) {
         $365 = (($v$3$lcssa$i) + 20|0);
         $366 = HEAP32[$365>>2]|0;
         $367 = ($366|0)==(0|0);
         if ($367) {
          $368 = (($v$3$lcssa$i) + 16|0);
          $369 = HEAP32[$368>>2]|0;
          $370 = ($369|0)==(0|0);
          if ($370) {
           $R$1$i20 = 0;
           break;
          } else {
           $R$0$i18 = $369;$RP$0$i17 = $368;
          }
         } else {
          $R$0$i18 = $366;$RP$0$i17 = $365;
         }
         while(1) {
          $371 = (($R$0$i18) + 20|0);
          $372 = HEAP32[$371>>2]|0;
          $373 = ($372|0)==(0|0);
          if (!($373)) {
           $R$0$i18 = $372;$RP$0$i17 = $371;
           continue;
          }
          $374 = (($R$0$i18) + 16|0);
          $375 = HEAP32[$374>>2]|0;
          $376 = ($375|0)==(0|0);
          if ($376) {
           break;
          } else {
           $R$0$i18 = $375;$RP$0$i17 = $374;
          }
         }
         $377 = ($RP$0$i17>>>0)<($347>>>0);
         if ($377) {
          _abort();
          // unreachable;
         } else {
          HEAP32[$RP$0$i17>>2] = 0;
          $R$1$i20 = $R$0$i18;
          break;
         }
        } else {
         $356 = (($v$3$lcssa$i) + 8|0);
         $357 = HEAP32[$356>>2]|0;
         $358 = ($357>>>0)<($347>>>0);
         if ($358) {
          _abort();
          // unreachable;
         }
         $359 = (($357) + 12|0);
         $360 = HEAP32[$359>>2]|0;
         $361 = ($360|0)==($v$3$lcssa$i|0);
         if (!($361)) {
          _abort();
          // unreachable;
         }
         $362 = (($354) + 8|0);
         $363 = HEAP32[$362>>2]|0;
         $364 = ($363|0)==($v$3$lcssa$i|0);
         if ($364) {
          HEAP32[$359>>2] = $354;
          HEAP32[$362>>2] = $357;
          $R$1$i20 = $354;
          break;
         } else {
          _abort();
          // unreachable;
         }
        }
       } while(0);
       $378 = ($352|0)==(0|0);
       do {
        if (!($378)) {
         $379 = (($v$3$lcssa$i) + 28|0);
         $380 = HEAP32[$379>>2]|0;
         $381 = ((3109840 + ($380<<2)|0) + 304|0);
         $382 = HEAP32[$381>>2]|0;
         $383 = ($v$3$lcssa$i|0)==($382|0);
         if ($383) {
          HEAP32[$381>>2] = $R$1$i20;
          $cond$i21 = ($R$1$i20|0)==(0|0);
          if ($cond$i21) {
           $384 = 1 << $380;
           $385 = $384 ^ -1;
           $386 = HEAP32[((3109840 + 4|0))>>2]|0;
           $387 = $386 & $385;
           HEAP32[((3109840 + 4|0))>>2] = $387;
           break;
          }
         } else {
          $388 = HEAP32[((3109840 + 16|0))>>2]|0;
          $389 = ($352>>>0)<($388>>>0);
          if ($389) {
           _abort();
           // unreachable;
          }
          $390 = (($352) + 16|0);
          $391 = HEAP32[$390>>2]|0;
          $392 = ($391|0)==($v$3$lcssa$i|0);
          if ($392) {
           HEAP32[$390>>2] = $R$1$i20;
          } else {
           $393 = (($352) + 20|0);
           HEAP32[$393>>2] = $R$1$i20;
          }
          $394 = ($R$1$i20|0)==(0|0);
          if ($394) {
           break;
          }
         }
         $395 = HEAP32[((3109840 + 16|0))>>2]|0;
         $396 = ($R$1$i20>>>0)<($395>>>0);
         if ($396) {
          _abort();
          // unreachable;
         }
         $397 = (($R$1$i20) + 24|0);
         HEAP32[$397>>2] = $352;
         $398 = (($v$3$lcssa$i) + 16|0);
         $399 = HEAP32[$398>>2]|0;
         $400 = ($399|0)==(0|0);
         do {
          if (!($400)) {
           $401 = HEAP32[((3109840 + 16|0))>>2]|0;
           $402 = ($399>>>0)<($401>>>0);
           if ($402) {
            _abort();
            // unreachable;
           } else {
            $403 = (($R$1$i20) + 16|0);
            HEAP32[$403>>2] = $399;
            $404 = (($399) + 24|0);
            HEAP32[$404>>2] = $R$1$i20;
            break;
           }
          }
         } while(0);
         $405 = (($v$3$lcssa$i) + 20|0);
         $406 = HEAP32[$405>>2]|0;
         $407 = ($406|0)==(0|0);
         if (!($407)) {
          $408 = HEAP32[((3109840 + 16|0))>>2]|0;
          $409 = ($406>>>0)<($408>>>0);
          if ($409) {
           _abort();
           // unreachable;
          } else {
           $410 = (($R$1$i20) + 20|0);
           HEAP32[$410>>2] = $406;
           $411 = (($406) + 24|0);
           HEAP32[$411>>2] = $R$1$i20;
           break;
          }
         }
        }
       } while(0);
       $412 = ($rsize$3$lcssa$i>>>0)<(16);
       L204: do {
        if ($412) {
         $413 = (($rsize$3$lcssa$i) + ($247))|0;
         $414 = $413 | 3;
         $415 = (($v$3$lcssa$i) + 4|0);
         HEAP32[$415>>2] = $414;
         $$sum18$i = (($413) + 4)|0;
         $416 = (($v$3$lcssa$i) + ($$sum18$i)|0);
         $417 = HEAP32[$416>>2]|0;
         $418 = $417 | 1;
         HEAP32[$416>>2] = $418;
        } else {
         $419 = $247 | 3;
         $420 = (($v$3$lcssa$i) + 4|0);
         HEAP32[$420>>2] = $419;
         $421 = $rsize$3$lcssa$i | 1;
         $$sum$i2334 = $247 | 4;
         $422 = (($v$3$lcssa$i) + ($$sum$i2334)|0);
         HEAP32[$422>>2] = $421;
         $$sum1$i24 = (($rsize$3$lcssa$i) + ($247))|0;
         $423 = (($v$3$lcssa$i) + ($$sum1$i24)|0);
         HEAP32[$423>>2] = $rsize$3$lcssa$i;
         $424 = $rsize$3$lcssa$i >>> 3;
         $425 = ($rsize$3$lcssa$i>>>0)<(256);
         if ($425) {
          $426 = $424 << 1;
          $427 = ((3109840 + ($426<<2)|0) + 40|0);
          $428 = HEAP32[3109840>>2]|0;
          $429 = 1 << $424;
          $430 = $428 & $429;
          $431 = ($430|0)==(0);
          do {
           if ($431) {
            $432 = $428 | $429;
            HEAP32[3109840>>2] = $432;
            $$sum14$pre$i = (($426) + 2)|0;
            $$pre$i25 = ((3109840 + ($$sum14$pre$i<<2)|0) + 40|0);
            $$pre$phi$i26Z2D = $$pre$i25;$F5$0$i = $427;
           } else {
            $$sum17$i = (($426) + 2)|0;
            $433 = ((3109840 + ($$sum17$i<<2)|0) + 40|0);
            $434 = HEAP32[$433>>2]|0;
            $435 = HEAP32[((3109840 + 16|0))>>2]|0;
            $436 = ($434>>>0)<($435>>>0);
            if (!($436)) {
             $$pre$phi$i26Z2D = $433;$F5$0$i = $434;
             break;
            }
            _abort();
            // unreachable;
           }
          } while(0);
          HEAP32[$$pre$phi$i26Z2D>>2] = $349;
          $437 = (($F5$0$i) + 12|0);
          HEAP32[$437>>2] = $349;
          $$sum15$i = (($247) + 8)|0;
          $438 = (($v$3$lcssa$i) + ($$sum15$i)|0);
          HEAP32[$438>>2] = $F5$0$i;
          $$sum16$i = (($247) + 12)|0;
          $439 = (($v$3$lcssa$i) + ($$sum16$i)|0);
          HEAP32[$439>>2] = $427;
          break;
         }
         $440 = $rsize$3$lcssa$i >>> 8;
         $441 = ($440|0)==(0);
         if ($441) {
          $I7$0$i = 0;
         } else {
          $442 = ($rsize$3$lcssa$i>>>0)>(16777215);
          if ($442) {
           $I7$0$i = 31;
          } else {
           $443 = (($440) + 1048320)|0;
           $444 = $443 >>> 16;
           $445 = $444 & 8;
           $446 = $440 << $445;
           $447 = (($446) + 520192)|0;
           $448 = $447 >>> 16;
           $449 = $448 & 4;
           $450 = $449 | $445;
           $451 = $446 << $449;
           $452 = (($451) + 245760)|0;
           $453 = $452 >>> 16;
           $454 = $453 & 2;
           $455 = $450 | $454;
           $456 = (14 - ($455))|0;
           $457 = $451 << $454;
           $458 = $457 >>> 15;
           $459 = (($456) + ($458))|0;
           $460 = $459 << 1;
           $461 = (($459) + 7)|0;
           $462 = $rsize$3$lcssa$i >>> $461;
           $463 = $462 & 1;
           $464 = $463 | $460;
           $I7$0$i = $464;
          }
         }
         $465 = ((3109840 + ($I7$0$i<<2)|0) + 304|0);
         $$sum2$i = (($247) + 28)|0;
         $466 = (($v$3$lcssa$i) + ($$sum2$i)|0);
         HEAP32[$466>>2] = $I7$0$i;
         $$sum3$i27 = (($247) + 16)|0;
         $467 = (($v$3$lcssa$i) + ($$sum3$i27)|0);
         $$sum4$i28 = (($247) + 20)|0;
         $468 = (($v$3$lcssa$i) + ($$sum4$i28)|0);
         HEAP32[$468>>2] = 0;
         HEAP32[$467>>2] = 0;
         $469 = HEAP32[((3109840 + 4|0))>>2]|0;
         $470 = 1 << $I7$0$i;
         $471 = $469 & $470;
         $472 = ($471|0)==(0);
         if ($472) {
          $473 = $469 | $470;
          HEAP32[((3109840 + 4|0))>>2] = $473;
          HEAP32[$465>>2] = $349;
          $$sum5$i = (($247) + 24)|0;
          $474 = (($v$3$lcssa$i) + ($$sum5$i)|0);
          HEAP32[$474>>2] = $465;
          $$sum6$i = (($247) + 12)|0;
          $475 = (($v$3$lcssa$i) + ($$sum6$i)|0);
          HEAP32[$475>>2] = $349;
          $$sum7$i = (($247) + 8)|0;
          $476 = (($v$3$lcssa$i) + ($$sum7$i)|0);
          HEAP32[$476>>2] = $349;
          break;
         }
         $477 = HEAP32[$465>>2]|0;
         $478 = ($I7$0$i|0)==(31);
         if ($478) {
          $486 = 0;
         } else {
          $479 = $I7$0$i >>> 1;
          $480 = (25 - ($479))|0;
          $486 = $480;
         }
         $481 = (($477) + 4|0);
         $482 = HEAP32[$481>>2]|0;
         $483 = $482 & -8;
         $484 = ($483|0)==($rsize$3$lcssa$i|0);
         L225: do {
          if ($484) {
           $T$0$lcssa$i = $477;
          } else {
           $485 = $rsize$3$lcssa$i << $486;
           $K12$025$i = $485;$T$024$i = $477;
           while(1) {
            $493 = $K12$025$i >>> 31;
            $494 = ((($T$024$i) + ($493<<2)|0) + 16|0);
            $489 = HEAP32[$494>>2]|0;
            $495 = ($489|0)==(0|0);
            if ($495) {
             break;
            }
            $487 = $K12$025$i << 1;
            $488 = (($489) + 4|0);
            $490 = HEAP32[$488>>2]|0;
            $491 = $490 & -8;
            $492 = ($491|0)==($rsize$3$lcssa$i|0);
            if ($492) {
             $T$0$lcssa$i = $489;
             break L225;
            } else {
             $K12$025$i = $487;$T$024$i = $489;
            }
           }
           $496 = HEAP32[((3109840 + 16|0))>>2]|0;
           $497 = ($494>>>0)<($496>>>0);
           if ($497) {
            _abort();
            // unreachable;
           } else {
            HEAP32[$494>>2] = $349;
            $$sum11$i = (($247) + 24)|0;
            $498 = (($v$3$lcssa$i) + ($$sum11$i)|0);
            HEAP32[$498>>2] = $T$024$i;
            $$sum12$i = (($247) + 12)|0;
            $499 = (($v$3$lcssa$i) + ($$sum12$i)|0);
            HEAP32[$499>>2] = $349;
            $$sum13$i = (($247) + 8)|0;
            $500 = (($v$3$lcssa$i) + ($$sum13$i)|0);
            HEAP32[$500>>2] = $349;
            break L204;
           }
          }
         } while(0);
         $501 = (($T$0$lcssa$i) + 8|0);
         $502 = HEAP32[$501>>2]|0;
         $503 = HEAP32[((3109840 + 16|0))>>2]|0;
         $504 = ($T$0$lcssa$i>>>0)<($503>>>0);
         if ($504) {
          _abort();
          // unreachable;
         }
         $505 = ($502>>>0)<($503>>>0);
         if ($505) {
          _abort();
          // unreachable;
         } else {
          $506 = (($502) + 12|0);
          HEAP32[$506>>2] = $349;
          HEAP32[$501>>2] = $349;
          $$sum8$i = (($247) + 8)|0;
          $507 = (($v$3$lcssa$i) + ($$sum8$i)|0);
          HEAP32[$507>>2] = $502;
          $$sum9$i = (($247) + 12)|0;
          $508 = (($v$3$lcssa$i) + ($$sum9$i)|0);
          HEAP32[$508>>2] = $T$0$lcssa$i;
          $$sum10$i = (($247) + 24)|0;
          $509 = (($v$3$lcssa$i) + ($$sum10$i)|0);
          HEAP32[$509>>2] = 0;
          break;
         }
        }
       } while(0);
       $510 = (($v$3$lcssa$i) + 8|0);
       $mem$0 = $510;
       STACKTOP = sp;return ($mem$0|0);
      } else {
       $nb$0 = $247;
      }
     }
    }
   }
  }
 } while(0);
 $511 = HEAP32[((3109840 + 8|0))>>2]|0;
 $512 = ($nb$0>>>0)>($511>>>0);
 if (!($512)) {
  $513 = (($511) - ($nb$0))|0;
  $514 = HEAP32[((3109840 + 20|0))>>2]|0;
  $515 = ($513>>>0)>(15);
  if ($515) {
   $516 = (($514) + ($nb$0)|0);
   HEAP32[((3109840 + 20|0))>>2] = $516;
   HEAP32[((3109840 + 8|0))>>2] = $513;
   $517 = $513 | 1;
   $$sum2 = (($nb$0) + 4)|0;
   $518 = (($514) + ($$sum2)|0);
   HEAP32[$518>>2] = $517;
   $519 = (($514) + ($511)|0);
   HEAP32[$519>>2] = $513;
   $520 = $nb$0 | 3;
   $521 = (($514) + 4|0);
   HEAP32[$521>>2] = $520;
  } else {
   HEAP32[((3109840 + 8|0))>>2] = 0;
   HEAP32[((3109840 + 20|0))>>2] = 0;
   $522 = $511 | 3;
   $523 = (($514) + 4|0);
   HEAP32[$523>>2] = $522;
   $$sum1 = (($511) + 4)|0;
   $524 = (($514) + ($$sum1)|0);
   $525 = HEAP32[$524>>2]|0;
   $526 = $525 | 1;
   HEAP32[$524>>2] = $526;
  }
  $527 = (($514) + 8|0);
  $mem$0 = $527;
  STACKTOP = sp;return ($mem$0|0);
 }
 $528 = HEAP32[((3109840 + 12|0))>>2]|0;
 $529 = ($nb$0>>>0)<($528>>>0);
 if ($529) {
  $530 = (($528) - ($nb$0))|0;
  HEAP32[((3109840 + 12|0))>>2] = $530;
  $531 = HEAP32[((3109840 + 24|0))>>2]|0;
  $532 = (($531) + ($nb$0)|0);
  HEAP32[((3109840 + 24|0))>>2] = $532;
  $533 = $530 | 1;
  $$sum = (($nb$0) + 4)|0;
  $534 = (($531) + ($$sum)|0);
  HEAP32[$534>>2] = $533;
  $535 = $nb$0 | 3;
  $536 = (($531) + 4|0);
  HEAP32[$536>>2] = $535;
  $537 = (($531) + 8|0);
  $mem$0 = $537;
  STACKTOP = sp;return ($mem$0|0);
 }
 $538 = HEAP32[3110312>>2]|0;
 $539 = ($538|0)==(0);
 do {
  if ($539) {
   $540 = (_sysconf(30)|0);
   $541 = (($540) + -1)|0;
   $542 = $541 & $540;
   $543 = ($542|0)==(0);
   if ($543) {
    HEAP32[((3110312 + 8|0))>>2] = $540;
    HEAP32[((3110312 + 4|0))>>2] = $540;
    HEAP32[((3110312 + 12|0))>>2] = -1;
    HEAP32[((3110312 + 16|0))>>2] = -1;
    HEAP32[((3110312 + 20|0))>>2] = 0;
    HEAP32[((3109840 + 444|0))>>2] = 0;
    $544 = (_time((0|0))|0);
    $545 = $544 & -16;
    $546 = $545 ^ 1431655768;
    HEAP32[3110312>>2] = $546;
    break;
   } else {
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $547 = (($nb$0) + 48)|0;
 $548 = HEAP32[((3110312 + 8|0))>>2]|0;
 $549 = (($nb$0) + 47)|0;
 $550 = (($548) + ($549))|0;
 $551 = (0 - ($548))|0;
 $552 = $550 & $551;
 $553 = ($552>>>0)>($nb$0>>>0);
 if (!($553)) {
  $mem$0 = 0;
  STACKTOP = sp;return ($mem$0|0);
 }
 $554 = HEAP32[((3109840 + 440|0))>>2]|0;
 $555 = ($554|0)==(0);
 if (!($555)) {
  $556 = HEAP32[((3109840 + 432|0))>>2]|0;
  $557 = (($556) + ($552))|0;
  $558 = ($557>>>0)<=($556>>>0);
  $559 = ($557>>>0)>($554>>>0);
  $or$cond1$i = $558 | $559;
  if ($or$cond1$i) {
   $mem$0 = 0;
   STACKTOP = sp;return ($mem$0|0);
  }
 }
 $560 = HEAP32[((3109840 + 444|0))>>2]|0;
 $561 = $560 & 4;
 $562 = ($561|0)==(0);
 L269: do {
  if ($562) {
   $563 = HEAP32[((3109840 + 24|0))>>2]|0;
   $564 = ($563|0)==(0|0);
   L271: do {
    if ($564) {
     label = 182;
    } else {
     $sp$0$i$i = ((3109840 + 448|0));
     while(1) {
      $565 = HEAP32[$sp$0$i$i>>2]|0;
      $566 = ($565>>>0)>($563>>>0);
      if (!($566)) {
       $567 = (($sp$0$i$i) + 4|0);
       $568 = HEAP32[$567>>2]|0;
       $569 = (($565) + ($568)|0);
       $570 = ($569>>>0)>($563>>>0);
       if ($570) {
        break;
       }
      }
      $571 = (($sp$0$i$i) + 8|0);
      $572 = HEAP32[$571>>2]|0;
      $573 = ($572|0)==(0|0);
      if ($573) {
       label = 182;
       break L271;
      } else {
       $sp$0$i$i = $572;
      }
     }
     $574 = ($sp$0$i$i|0)==(0|0);
     if ($574) {
      label = 182;
     } else {
      $597 = HEAP32[((3109840 + 12|0))>>2]|0;
      $598 = (($550) - ($597))|0;
      $599 = $598 & $551;
      $600 = ($599>>>0)<(2147483647);
      if ($600) {
       $601 = (_sbrk(($599|0))|0);
       $602 = HEAP32[$sp$0$i$i>>2]|0;
       $603 = HEAP32[$567>>2]|0;
       $604 = (($602) + ($603)|0);
       $605 = ($601|0)==($604|0);
       $$3$i = $605 ? $599 : 0;
       $$4$i = $605 ? $601 : (-1);
       $br$0$i = $601;$ssize$1$i = $599;$tbase$0$i = $$4$i;$tsize$0$i = $$3$i;
       label = 191;
      } else {
       $tsize$0323841$i = 0;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 182) {
     $575 = (_sbrk(0)|0);
     $576 = ($575|0)==((-1)|0);
     if ($576) {
      $tsize$0323841$i = 0;
     } else {
      $577 = $575;
      $578 = HEAP32[((3110312 + 4|0))>>2]|0;
      $579 = (($578) + -1)|0;
      $580 = $579 & $577;
      $581 = ($580|0)==(0);
      if ($581) {
       $ssize$0$i = $552;
      } else {
       $582 = (($579) + ($577))|0;
       $583 = (0 - ($578))|0;
       $584 = $582 & $583;
       $585 = (($552) - ($577))|0;
       $586 = (($585) + ($584))|0;
       $ssize$0$i = $586;
      }
      $587 = HEAP32[((3109840 + 432|0))>>2]|0;
      $588 = (($587) + ($ssize$0$i))|0;
      $589 = ($ssize$0$i>>>0)>($nb$0>>>0);
      $590 = ($ssize$0$i>>>0)<(2147483647);
      $or$cond$i29 = $589 & $590;
      if ($or$cond$i29) {
       $591 = HEAP32[((3109840 + 440|0))>>2]|0;
       $592 = ($591|0)==(0);
       if (!($592)) {
        $593 = ($588>>>0)<=($587>>>0);
        $594 = ($588>>>0)>($591>>>0);
        $or$cond2$i = $593 | $594;
        if ($or$cond2$i) {
         $tsize$0323841$i = 0;
         break;
        }
       }
       $595 = (_sbrk(($ssize$0$i|0))|0);
       $596 = ($595|0)==($575|0);
       $ssize$0$$i = $596 ? $ssize$0$i : 0;
       $$$i = $596 ? $575 : (-1);
       $br$0$i = $595;$ssize$1$i = $ssize$0$i;$tbase$0$i = $$$i;$tsize$0$i = $ssize$0$$i;
       label = 191;
      } else {
       $tsize$0323841$i = 0;
      }
     }
    }
   } while(0);
   L291: do {
    if ((label|0) == 191) {
     $606 = (0 - ($ssize$1$i))|0;
     $607 = ($tbase$0$i|0)==((-1)|0);
     if (!($607)) {
      $tbase$247$i = $tbase$0$i;$tsize$246$i = $tsize$0$i;
      label = 202;
      break L269;
     }
     $608 = ($br$0$i|0)!=((-1)|0);
     $609 = ($ssize$1$i>>>0)<(2147483647);
     $or$cond5$i = $608 & $609;
     $610 = ($ssize$1$i>>>0)<($547>>>0);
     $or$cond6$i = $or$cond5$i & $610;
     do {
      if ($or$cond6$i) {
       $611 = HEAP32[((3110312 + 8|0))>>2]|0;
       $612 = (($549) - ($ssize$1$i))|0;
       $613 = (($612) + ($611))|0;
       $614 = (0 - ($611))|0;
       $615 = $613 & $614;
       $616 = ($615>>>0)<(2147483647);
       if ($616) {
        $617 = (_sbrk(($615|0))|0);
        $618 = ($617|0)==((-1)|0);
        if ($618) {
         (_sbrk(($606|0))|0);
         $tsize$0323841$i = $tsize$0$i;
         break L291;
        } else {
         $619 = (($615) + ($ssize$1$i))|0;
         $ssize$2$i = $619;
         break;
        }
       } else {
        $ssize$2$i = $ssize$1$i;
       }
      } else {
       $ssize$2$i = $ssize$1$i;
      }
     } while(0);
     $620 = ($br$0$i|0)==((-1)|0);
     if ($620) {
      $tsize$0323841$i = $tsize$0$i;
     } else {
      $tbase$247$i = $br$0$i;$tsize$246$i = $ssize$2$i;
      label = 202;
      break L269;
     }
    }
   } while(0);
   $621 = HEAP32[((3109840 + 444|0))>>2]|0;
   $622 = $621 | 4;
   HEAP32[((3109840 + 444|0))>>2] = $622;
   $tsize$1$i = $tsize$0323841$i;
   label = 199;
  } else {
   $tsize$1$i = 0;
   label = 199;
  }
 } while(0);
 if ((label|0) == 199) {
  $623 = ($552>>>0)<(2147483647);
  if ($623) {
   $624 = (_sbrk(($552|0))|0);
   $625 = (_sbrk(0)|0);
   $notlhs$i = ($624|0)!=((-1)|0);
   $notrhs$i = ($625|0)!=((-1)|0);
   $or$cond8$not$i = $notrhs$i & $notlhs$i;
   $626 = ($624>>>0)<($625>>>0);
   $or$cond9$i = $or$cond8$not$i & $626;
   if ($or$cond9$i) {
    $627 = $625;
    $628 = $624;
    $629 = (($627) - ($628))|0;
    $630 = (($nb$0) + 40)|0;
    $631 = ($629>>>0)>($630>>>0);
    $$tsize$1$i = $631 ? $629 : $tsize$1$i;
    if ($631) {
     $tbase$247$i = $624;$tsize$246$i = $$tsize$1$i;
     label = 202;
    }
   }
  }
 }
 if ((label|0) == 202) {
  $632 = HEAP32[((3109840 + 432|0))>>2]|0;
  $633 = (($632) + ($tsize$246$i))|0;
  HEAP32[((3109840 + 432|0))>>2] = $633;
  $634 = HEAP32[((3109840 + 436|0))>>2]|0;
  $635 = ($633>>>0)>($634>>>0);
  if ($635) {
   HEAP32[((3109840 + 436|0))>>2] = $633;
  }
  $636 = HEAP32[((3109840 + 24|0))>>2]|0;
  $637 = ($636|0)==(0|0);
  L311: do {
   if ($637) {
    $638 = HEAP32[((3109840 + 16|0))>>2]|0;
    $639 = ($638|0)==(0|0);
    $640 = ($tbase$247$i>>>0)<($638>>>0);
    $or$cond10$i = $639 | $640;
    if ($or$cond10$i) {
     HEAP32[((3109840 + 16|0))>>2] = $tbase$247$i;
    }
    HEAP32[((3109840 + 448|0))>>2] = $tbase$247$i;
    HEAP32[((3109840 + 452|0))>>2] = $tsize$246$i;
    HEAP32[((3109840 + 460|0))>>2] = 0;
    $641 = HEAP32[3110312>>2]|0;
    HEAP32[((3109840 + 36|0))>>2] = $641;
    HEAP32[((3109840 + 32|0))>>2] = -1;
    $i$02$i$i = 0;
    while(1) {
     $642 = $i$02$i$i << 1;
     $643 = ((3109840 + ($642<<2)|0) + 40|0);
     $$sum$i$i = (($642) + 3)|0;
     $644 = ((3109840 + ($$sum$i$i<<2)|0) + 40|0);
     HEAP32[$644>>2] = $643;
     $$sum1$i$i = (($642) + 2)|0;
     $645 = ((3109840 + ($$sum1$i$i<<2)|0) + 40|0);
     HEAP32[$645>>2] = $643;
     $646 = (($i$02$i$i) + 1)|0;
     $exitcond$i$i = ($646|0)==(32);
     if ($exitcond$i$i) {
      break;
     } else {
      $i$02$i$i = $646;
     }
    }
    $647 = (($tsize$246$i) + -40)|0;
    $648 = (($tbase$247$i) + 8|0);
    $649 = $648;
    $650 = $649 & 7;
    $651 = ($650|0)==(0);
    if ($651) {
     $655 = 0;
    } else {
     $652 = (0 - ($649))|0;
     $653 = $652 & 7;
     $655 = $653;
    }
    $654 = (($tbase$247$i) + ($655)|0);
    $656 = (($647) - ($655))|0;
    HEAP32[((3109840 + 24|0))>>2] = $654;
    HEAP32[((3109840 + 12|0))>>2] = $656;
    $657 = $656 | 1;
    $$sum$i14$i = (($655) + 4)|0;
    $658 = (($tbase$247$i) + ($$sum$i14$i)|0);
    HEAP32[$658>>2] = $657;
    $$sum2$i$i = (($tsize$246$i) + -36)|0;
    $659 = (($tbase$247$i) + ($$sum2$i$i)|0);
    HEAP32[$659>>2] = 40;
    $660 = HEAP32[((3110312 + 16|0))>>2]|0;
    HEAP32[((3109840 + 28|0))>>2] = $660;
   } else {
    $sp$075$i = ((3109840 + 448|0));
    while(1) {
     $661 = HEAP32[$sp$075$i>>2]|0;
     $662 = (($sp$075$i) + 4|0);
     $663 = HEAP32[$662>>2]|0;
     $664 = (($661) + ($663)|0);
     $665 = ($tbase$247$i|0)==($664|0);
     if ($665) {
      label = 214;
      break;
     }
     $666 = (($sp$075$i) + 8|0);
     $667 = HEAP32[$666>>2]|0;
     $668 = ($667|0)==(0|0);
     if ($668) {
      break;
     } else {
      $sp$075$i = $667;
     }
    }
    if ((label|0) == 214) {
     $669 = (($sp$075$i) + 12|0);
     $670 = HEAP32[$669>>2]|0;
     $671 = $670 & 8;
     $672 = ($671|0)==(0);
     if ($672) {
      $673 = ($636>>>0)>=($661>>>0);
      $674 = ($636>>>0)<($tbase$247$i>>>0);
      $or$cond49$i = $673 & $674;
      if ($or$cond49$i) {
       $675 = (($663) + ($tsize$246$i))|0;
       HEAP32[$662>>2] = $675;
       $676 = HEAP32[((3109840 + 12|0))>>2]|0;
       $677 = (($676) + ($tsize$246$i))|0;
       $678 = (($636) + 8|0);
       $679 = $678;
       $680 = $679 & 7;
       $681 = ($680|0)==(0);
       if ($681) {
        $685 = 0;
       } else {
        $682 = (0 - ($679))|0;
        $683 = $682 & 7;
        $685 = $683;
       }
       $684 = (($636) + ($685)|0);
       $686 = (($677) - ($685))|0;
       HEAP32[((3109840 + 24|0))>>2] = $684;
       HEAP32[((3109840 + 12|0))>>2] = $686;
       $687 = $686 | 1;
       $$sum$i18$i = (($685) + 4)|0;
       $688 = (($636) + ($$sum$i18$i)|0);
       HEAP32[$688>>2] = $687;
       $$sum2$i19$i = (($677) + 4)|0;
       $689 = (($636) + ($$sum2$i19$i)|0);
       HEAP32[$689>>2] = 40;
       $690 = HEAP32[((3110312 + 16|0))>>2]|0;
       HEAP32[((3109840 + 28|0))>>2] = $690;
       break;
      }
     }
    }
    $691 = HEAP32[((3109840 + 16|0))>>2]|0;
    $692 = ($tbase$247$i>>>0)<($691>>>0);
    if ($692) {
     HEAP32[((3109840 + 16|0))>>2] = $tbase$247$i;
    }
    $693 = (($tbase$247$i) + ($tsize$246$i)|0);
    $sp$168$i = ((3109840 + 448|0));
    while(1) {
     $694 = HEAP32[$sp$168$i>>2]|0;
     $695 = ($694|0)==($693|0);
     if ($695) {
      label = 224;
      break;
     }
     $696 = (($sp$168$i) + 8|0);
     $697 = HEAP32[$696>>2]|0;
     $698 = ($697|0)==(0|0);
     if ($698) {
      break;
     } else {
      $sp$168$i = $697;
     }
    }
    if ((label|0) == 224) {
     $699 = (($sp$168$i) + 12|0);
     $700 = HEAP32[$699>>2]|0;
     $701 = $700 & 8;
     $702 = ($701|0)==(0);
     if ($702) {
      HEAP32[$sp$168$i>>2] = $tbase$247$i;
      $703 = (($sp$168$i) + 4|0);
      $704 = HEAP32[$703>>2]|0;
      $705 = (($704) + ($tsize$246$i))|0;
      HEAP32[$703>>2] = $705;
      $706 = (($tbase$247$i) + 8|0);
      $707 = $706;
      $708 = $707 & 7;
      $709 = ($708|0)==(0);
      if ($709) {
       $713 = 0;
      } else {
       $710 = (0 - ($707))|0;
       $711 = $710 & 7;
       $713 = $711;
      }
      $712 = (($tbase$247$i) + ($713)|0);
      $$sum107$i = (($tsize$246$i) + 8)|0;
      $714 = (($tbase$247$i) + ($$sum107$i)|0);
      $715 = $714;
      $716 = $715 & 7;
      $717 = ($716|0)==(0);
      if ($717) {
       $720 = 0;
      } else {
       $718 = (0 - ($715))|0;
       $719 = $718 & 7;
       $720 = $719;
      }
      $$sum108$i = (($720) + ($tsize$246$i))|0;
      $721 = (($tbase$247$i) + ($$sum108$i)|0);
      $722 = $721;
      $723 = $712;
      $724 = (($722) - ($723))|0;
      $$sum$i21$i = (($713) + ($nb$0))|0;
      $725 = (($tbase$247$i) + ($$sum$i21$i)|0);
      $726 = (($724) - ($nb$0))|0;
      $727 = $nb$0 | 3;
      $$sum1$i22$i = (($713) + 4)|0;
      $728 = (($tbase$247$i) + ($$sum1$i22$i)|0);
      HEAP32[$728>>2] = $727;
      $729 = HEAP32[((3109840 + 24|0))>>2]|0;
      $730 = ($721|0)==($729|0);
      L348: do {
       if ($730) {
        $731 = HEAP32[((3109840 + 12|0))>>2]|0;
        $732 = (($731) + ($726))|0;
        HEAP32[((3109840 + 12|0))>>2] = $732;
        HEAP32[((3109840 + 24|0))>>2] = $725;
        $733 = $732 | 1;
        $$sum42$i$i = (($$sum$i21$i) + 4)|0;
        $734 = (($tbase$247$i) + ($$sum42$i$i)|0);
        HEAP32[$734>>2] = $733;
       } else {
        $735 = HEAP32[((3109840 + 20|0))>>2]|0;
        $736 = ($721|0)==($735|0);
        if ($736) {
         $737 = HEAP32[((3109840 + 8|0))>>2]|0;
         $738 = (($737) + ($726))|0;
         HEAP32[((3109840 + 8|0))>>2] = $738;
         HEAP32[((3109840 + 20|0))>>2] = $725;
         $739 = $738 | 1;
         $$sum40$i$i = (($$sum$i21$i) + 4)|0;
         $740 = (($tbase$247$i) + ($$sum40$i$i)|0);
         HEAP32[$740>>2] = $739;
         $$sum41$i$i = (($738) + ($$sum$i21$i))|0;
         $741 = (($tbase$247$i) + ($$sum41$i$i)|0);
         HEAP32[$741>>2] = $738;
         break;
        }
        $$sum2$i23$i = (($tsize$246$i) + 4)|0;
        $$sum109$i = (($$sum2$i23$i) + ($720))|0;
        $742 = (($tbase$247$i) + ($$sum109$i)|0);
        $743 = HEAP32[$742>>2]|0;
        $744 = $743 & 3;
        $745 = ($744|0)==(1);
        if ($745) {
         $746 = $743 & -8;
         $747 = $743 >>> 3;
         $748 = ($743>>>0)<(256);
         L355: do {
          if ($748) {
           $$sum3738$i$i = $720 | 8;
           $$sum119$i = (($$sum3738$i$i) + ($tsize$246$i))|0;
           $749 = (($tbase$247$i) + ($$sum119$i)|0);
           $750 = HEAP32[$749>>2]|0;
           $$sum39$i$i = (($tsize$246$i) + 12)|0;
           $$sum120$i = (($$sum39$i$i) + ($720))|0;
           $751 = (($tbase$247$i) + ($$sum120$i)|0);
           $752 = HEAP32[$751>>2]|0;
           $753 = $747 << 1;
           $754 = ((3109840 + ($753<<2)|0) + 40|0);
           $755 = ($750|0)==($754|0);
           do {
            if (!($755)) {
             $756 = HEAP32[((3109840 + 16|0))>>2]|0;
             $757 = ($750>>>0)<($756>>>0);
             if ($757) {
              _abort();
              // unreachable;
             }
             $758 = (($750) + 12|0);
             $759 = HEAP32[$758>>2]|0;
             $760 = ($759|0)==($721|0);
             if ($760) {
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $761 = ($752|0)==($750|0);
           if ($761) {
            $762 = 1 << $747;
            $763 = $762 ^ -1;
            $764 = HEAP32[3109840>>2]|0;
            $765 = $764 & $763;
            HEAP32[3109840>>2] = $765;
            break;
           }
           $766 = ($752|0)==($754|0);
           do {
            if ($766) {
             $$pre57$i$i = (($752) + 8|0);
             $$pre$phi58$i$iZ2D = $$pre57$i$i;
            } else {
             $767 = HEAP32[((3109840 + 16|0))>>2]|0;
             $768 = ($752>>>0)<($767>>>0);
             if ($768) {
              _abort();
              // unreachable;
             }
             $769 = (($752) + 8|0);
             $770 = HEAP32[$769>>2]|0;
             $771 = ($770|0)==($721|0);
             if ($771) {
              $$pre$phi58$i$iZ2D = $769;
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $772 = (($750) + 12|0);
           HEAP32[$772>>2] = $752;
           HEAP32[$$pre$phi58$i$iZ2D>>2] = $750;
          } else {
           $$sum34$i$i = $720 | 24;
           $$sum110$i = (($$sum34$i$i) + ($tsize$246$i))|0;
           $773 = (($tbase$247$i) + ($$sum110$i)|0);
           $774 = HEAP32[$773>>2]|0;
           $$sum5$i$i = (($tsize$246$i) + 12)|0;
           $$sum111$i = (($$sum5$i$i) + ($720))|0;
           $775 = (($tbase$247$i) + ($$sum111$i)|0);
           $776 = HEAP32[$775>>2]|0;
           $777 = ($776|0)==($721|0);
           do {
            if ($777) {
             $$sum67$i$i = $720 | 16;
             $$sum117$i = (($$sum2$i23$i) + ($$sum67$i$i))|0;
             $788 = (($tbase$247$i) + ($$sum117$i)|0);
             $789 = HEAP32[$788>>2]|0;
             $790 = ($789|0)==(0|0);
             if ($790) {
              $$sum118$i = (($$sum67$i$i) + ($tsize$246$i))|0;
              $791 = (($tbase$247$i) + ($$sum118$i)|0);
              $792 = HEAP32[$791>>2]|0;
              $793 = ($792|0)==(0|0);
              if ($793) {
               $R$1$i$i = 0;
               break;
              } else {
               $R$0$i$i = $792;$RP$0$i$i = $791;
              }
             } else {
              $R$0$i$i = $789;$RP$0$i$i = $788;
             }
             while(1) {
              $794 = (($R$0$i$i) + 20|0);
              $795 = HEAP32[$794>>2]|0;
              $796 = ($795|0)==(0|0);
              if (!($796)) {
               $R$0$i$i = $795;$RP$0$i$i = $794;
               continue;
              }
              $797 = (($R$0$i$i) + 16|0);
              $798 = HEAP32[$797>>2]|0;
              $799 = ($798|0)==(0|0);
              if ($799) {
               break;
              } else {
               $R$0$i$i = $798;$RP$0$i$i = $797;
              }
             }
             $800 = HEAP32[((3109840 + 16|0))>>2]|0;
             $801 = ($RP$0$i$i>>>0)<($800>>>0);
             if ($801) {
              _abort();
              // unreachable;
             } else {
              HEAP32[$RP$0$i$i>>2] = 0;
              $R$1$i$i = $R$0$i$i;
              break;
             }
            } else {
             $$sum3536$i$i = $720 | 8;
             $$sum112$i = (($$sum3536$i$i) + ($tsize$246$i))|0;
             $778 = (($tbase$247$i) + ($$sum112$i)|0);
             $779 = HEAP32[$778>>2]|0;
             $780 = HEAP32[((3109840 + 16|0))>>2]|0;
             $781 = ($779>>>0)<($780>>>0);
             if ($781) {
              _abort();
              // unreachable;
             }
             $782 = (($779) + 12|0);
             $783 = HEAP32[$782>>2]|0;
             $784 = ($783|0)==($721|0);
             if (!($784)) {
              _abort();
              // unreachable;
             }
             $785 = (($776) + 8|0);
             $786 = HEAP32[$785>>2]|0;
             $787 = ($786|0)==($721|0);
             if ($787) {
              HEAP32[$782>>2] = $776;
              HEAP32[$785>>2] = $779;
              $R$1$i$i = $776;
              break;
             } else {
              _abort();
              // unreachable;
             }
            }
           } while(0);
           $802 = ($774|0)==(0|0);
           if ($802) {
            break;
           }
           $$sum30$i$i = (($tsize$246$i) + 28)|0;
           $$sum113$i = (($$sum30$i$i) + ($720))|0;
           $803 = (($tbase$247$i) + ($$sum113$i)|0);
           $804 = HEAP32[$803>>2]|0;
           $805 = ((3109840 + ($804<<2)|0) + 304|0);
           $806 = HEAP32[$805>>2]|0;
           $807 = ($721|0)==($806|0);
           do {
            if ($807) {
             HEAP32[$805>>2] = $R$1$i$i;
             $cond$i$i = ($R$1$i$i|0)==(0|0);
             if (!($cond$i$i)) {
              break;
             }
             $808 = 1 << $804;
             $809 = $808 ^ -1;
             $810 = HEAP32[((3109840 + 4|0))>>2]|0;
             $811 = $810 & $809;
             HEAP32[((3109840 + 4|0))>>2] = $811;
             break L355;
            } else {
             $812 = HEAP32[((3109840 + 16|0))>>2]|0;
             $813 = ($774>>>0)<($812>>>0);
             if ($813) {
              _abort();
              // unreachable;
             }
             $814 = (($774) + 16|0);
             $815 = HEAP32[$814>>2]|0;
             $816 = ($815|0)==($721|0);
             if ($816) {
              HEAP32[$814>>2] = $R$1$i$i;
             } else {
              $817 = (($774) + 20|0);
              HEAP32[$817>>2] = $R$1$i$i;
             }
             $818 = ($R$1$i$i|0)==(0|0);
             if ($818) {
              break L355;
             }
            }
           } while(0);
           $819 = HEAP32[((3109840 + 16|0))>>2]|0;
           $820 = ($R$1$i$i>>>0)<($819>>>0);
           if ($820) {
            _abort();
            // unreachable;
           }
           $821 = (($R$1$i$i) + 24|0);
           HEAP32[$821>>2] = $774;
           $$sum3132$i$i = $720 | 16;
           $$sum114$i = (($$sum3132$i$i) + ($tsize$246$i))|0;
           $822 = (($tbase$247$i) + ($$sum114$i)|0);
           $823 = HEAP32[$822>>2]|0;
           $824 = ($823|0)==(0|0);
           do {
            if (!($824)) {
             $825 = HEAP32[((3109840 + 16|0))>>2]|0;
             $826 = ($823>>>0)<($825>>>0);
             if ($826) {
              _abort();
              // unreachable;
             } else {
              $827 = (($R$1$i$i) + 16|0);
              HEAP32[$827>>2] = $823;
              $828 = (($823) + 24|0);
              HEAP32[$828>>2] = $R$1$i$i;
              break;
             }
            }
           } while(0);
           $$sum115$i = (($$sum2$i23$i) + ($$sum3132$i$i))|0;
           $829 = (($tbase$247$i) + ($$sum115$i)|0);
           $830 = HEAP32[$829>>2]|0;
           $831 = ($830|0)==(0|0);
           if ($831) {
            break;
           }
           $832 = HEAP32[((3109840 + 16|0))>>2]|0;
           $833 = ($830>>>0)<($832>>>0);
           if ($833) {
            _abort();
            // unreachable;
           } else {
            $834 = (($R$1$i$i) + 20|0);
            HEAP32[$834>>2] = $830;
            $835 = (($830) + 24|0);
            HEAP32[$835>>2] = $R$1$i$i;
            break;
           }
          }
         } while(0);
         $$sum9$i$i = $746 | $720;
         $$sum116$i = (($$sum9$i$i) + ($tsize$246$i))|0;
         $836 = (($tbase$247$i) + ($$sum116$i)|0);
         $837 = (($746) + ($726))|0;
         $oldfirst$0$i$i = $836;$qsize$0$i$i = $837;
        } else {
         $oldfirst$0$i$i = $721;$qsize$0$i$i = $726;
        }
        $838 = (($oldfirst$0$i$i) + 4|0);
        $839 = HEAP32[$838>>2]|0;
        $840 = $839 & -2;
        HEAP32[$838>>2] = $840;
        $841 = $qsize$0$i$i | 1;
        $$sum10$i$i = (($$sum$i21$i) + 4)|0;
        $842 = (($tbase$247$i) + ($$sum10$i$i)|0);
        HEAP32[$842>>2] = $841;
        $$sum11$i24$i = (($qsize$0$i$i) + ($$sum$i21$i))|0;
        $843 = (($tbase$247$i) + ($$sum11$i24$i)|0);
        HEAP32[$843>>2] = $qsize$0$i$i;
        $844 = $qsize$0$i$i >>> 3;
        $845 = ($qsize$0$i$i>>>0)<(256);
        if ($845) {
         $846 = $844 << 1;
         $847 = ((3109840 + ($846<<2)|0) + 40|0);
         $848 = HEAP32[3109840>>2]|0;
         $849 = 1 << $844;
         $850 = $848 & $849;
         $851 = ($850|0)==(0);
         do {
          if ($851) {
           $852 = $848 | $849;
           HEAP32[3109840>>2] = $852;
           $$sum26$pre$i$i = (($846) + 2)|0;
           $$pre$i25$i = ((3109840 + ($$sum26$pre$i$i<<2)|0) + 40|0);
           $$pre$phi$i26$iZ2D = $$pre$i25$i;$F4$0$i$i = $847;
          } else {
           $$sum29$i$i = (($846) + 2)|0;
           $853 = ((3109840 + ($$sum29$i$i<<2)|0) + 40|0);
           $854 = HEAP32[$853>>2]|0;
           $855 = HEAP32[((3109840 + 16|0))>>2]|0;
           $856 = ($854>>>0)<($855>>>0);
           if (!($856)) {
            $$pre$phi$i26$iZ2D = $853;$F4$0$i$i = $854;
            break;
           }
           _abort();
           // unreachable;
          }
         } while(0);
         HEAP32[$$pre$phi$i26$iZ2D>>2] = $725;
         $857 = (($F4$0$i$i) + 12|0);
         HEAP32[$857>>2] = $725;
         $$sum27$i$i = (($$sum$i21$i) + 8)|0;
         $858 = (($tbase$247$i) + ($$sum27$i$i)|0);
         HEAP32[$858>>2] = $F4$0$i$i;
         $$sum28$i$i = (($$sum$i21$i) + 12)|0;
         $859 = (($tbase$247$i) + ($$sum28$i$i)|0);
         HEAP32[$859>>2] = $847;
         break;
        }
        $860 = $qsize$0$i$i >>> 8;
        $861 = ($860|0)==(0);
        do {
         if ($861) {
          $I7$0$i$i = 0;
         } else {
          $862 = ($qsize$0$i$i>>>0)>(16777215);
          if ($862) {
           $I7$0$i$i = 31;
           break;
          }
          $863 = (($860) + 1048320)|0;
          $864 = $863 >>> 16;
          $865 = $864 & 8;
          $866 = $860 << $865;
          $867 = (($866) + 520192)|0;
          $868 = $867 >>> 16;
          $869 = $868 & 4;
          $870 = $869 | $865;
          $871 = $866 << $869;
          $872 = (($871) + 245760)|0;
          $873 = $872 >>> 16;
          $874 = $873 & 2;
          $875 = $870 | $874;
          $876 = (14 - ($875))|0;
          $877 = $871 << $874;
          $878 = $877 >>> 15;
          $879 = (($876) + ($878))|0;
          $880 = $879 << 1;
          $881 = (($879) + 7)|0;
          $882 = $qsize$0$i$i >>> $881;
          $883 = $882 & 1;
          $884 = $883 | $880;
          $I7$0$i$i = $884;
         }
        } while(0);
        $885 = ((3109840 + ($I7$0$i$i<<2)|0) + 304|0);
        $$sum12$i$i = (($$sum$i21$i) + 28)|0;
        $886 = (($tbase$247$i) + ($$sum12$i$i)|0);
        HEAP32[$886>>2] = $I7$0$i$i;
        $$sum13$i$i = (($$sum$i21$i) + 16)|0;
        $887 = (($tbase$247$i) + ($$sum13$i$i)|0);
        $$sum14$i$i = (($$sum$i21$i) + 20)|0;
        $888 = (($tbase$247$i) + ($$sum14$i$i)|0);
        HEAP32[$888>>2] = 0;
        HEAP32[$887>>2] = 0;
        $889 = HEAP32[((3109840 + 4|0))>>2]|0;
        $890 = 1 << $I7$0$i$i;
        $891 = $889 & $890;
        $892 = ($891|0)==(0);
        if ($892) {
         $893 = $889 | $890;
         HEAP32[((3109840 + 4|0))>>2] = $893;
         HEAP32[$885>>2] = $725;
         $$sum15$i$i = (($$sum$i21$i) + 24)|0;
         $894 = (($tbase$247$i) + ($$sum15$i$i)|0);
         HEAP32[$894>>2] = $885;
         $$sum16$i$i = (($$sum$i21$i) + 12)|0;
         $895 = (($tbase$247$i) + ($$sum16$i$i)|0);
         HEAP32[$895>>2] = $725;
         $$sum17$i$i = (($$sum$i21$i) + 8)|0;
         $896 = (($tbase$247$i) + ($$sum17$i$i)|0);
         HEAP32[$896>>2] = $725;
         break;
        }
        $897 = HEAP32[$885>>2]|0;
        $898 = ($I7$0$i$i|0)==(31);
        if ($898) {
         $906 = 0;
        } else {
         $899 = $I7$0$i$i >>> 1;
         $900 = (25 - ($899))|0;
         $906 = $900;
        }
        $901 = (($897) + 4|0);
        $902 = HEAP32[$901>>2]|0;
        $903 = $902 & -8;
        $904 = ($903|0)==($qsize$0$i$i|0);
        L444: do {
         if ($904) {
          $T$0$lcssa$i28$i = $897;
         } else {
          $905 = $qsize$0$i$i << $906;
          $K8$052$i$i = $905;$T$051$i$i = $897;
          while(1) {
           $913 = $K8$052$i$i >>> 31;
           $914 = ((($T$051$i$i) + ($913<<2)|0) + 16|0);
           $909 = HEAP32[$914>>2]|0;
           $915 = ($909|0)==(0|0);
           if ($915) {
            break;
           }
           $907 = $K8$052$i$i << 1;
           $908 = (($909) + 4|0);
           $910 = HEAP32[$908>>2]|0;
           $911 = $910 & -8;
           $912 = ($911|0)==($qsize$0$i$i|0);
           if ($912) {
            $T$0$lcssa$i28$i = $909;
            break L444;
           } else {
            $K8$052$i$i = $907;$T$051$i$i = $909;
           }
          }
          $916 = HEAP32[((3109840 + 16|0))>>2]|0;
          $917 = ($914>>>0)<($916>>>0);
          if ($917) {
           _abort();
           // unreachable;
          } else {
           HEAP32[$914>>2] = $725;
           $$sum23$i$i = (($$sum$i21$i) + 24)|0;
           $918 = (($tbase$247$i) + ($$sum23$i$i)|0);
           HEAP32[$918>>2] = $T$051$i$i;
           $$sum24$i$i = (($$sum$i21$i) + 12)|0;
           $919 = (($tbase$247$i) + ($$sum24$i$i)|0);
           HEAP32[$919>>2] = $725;
           $$sum25$i$i = (($$sum$i21$i) + 8)|0;
           $920 = (($tbase$247$i) + ($$sum25$i$i)|0);
           HEAP32[$920>>2] = $725;
           break L348;
          }
         }
        } while(0);
        $921 = (($T$0$lcssa$i28$i) + 8|0);
        $922 = HEAP32[$921>>2]|0;
        $923 = HEAP32[((3109840 + 16|0))>>2]|0;
        $924 = ($T$0$lcssa$i28$i>>>0)<($923>>>0);
        if ($924) {
         _abort();
         // unreachable;
        }
        $925 = ($922>>>0)<($923>>>0);
        if ($925) {
         _abort();
         // unreachable;
        } else {
         $926 = (($922) + 12|0);
         HEAP32[$926>>2] = $725;
         HEAP32[$921>>2] = $725;
         $$sum20$i$i = (($$sum$i21$i) + 8)|0;
         $927 = (($tbase$247$i) + ($$sum20$i$i)|0);
         HEAP32[$927>>2] = $922;
         $$sum21$i$i = (($$sum$i21$i) + 12)|0;
         $928 = (($tbase$247$i) + ($$sum21$i$i)|0);
         HEAP32[$928>>2] = $T$0$lcssa$i28$i;
         $$sum22$i$i = (($$sum$i21$i) + 24)|0;
         $929 = (($tbase$247$i) + ($$sum22$i$i)|0);
         HEAP32[$929>>2] = 0;
         break;
        }
       }
      } while(0);
      $$sum1819$i$i = $713 | 8;
      $930 = (($tbase$247$i) + ($$sum1819$i$i)|0);
      $mem$0 = $930;
      STACKTOP = sp;return ($mem$0|0);
     }
    }
    $sp$0$i$i$i = ((3109840 + 448|0));
    while(1) {
     $931 = HEAP32[$sp$0$i$i$i>>2]|0;
     $932 = ($931>>>0)>($636>>>0);
     if (!($932)) {
      $933 = (($sp$0$i$i$i) + 4|0);
      $934 = HEAP32[$933>>2]|0;
      $935 = (($931) + ($934)|0);
      $936 = ($935>>>0)>($636>>>0);
      if ($936) {
       break;
      }
     }
     $937 = (($sp$0$i$i$i) + 8|0);
     $938 = HEAP32[$937>>2]|0;
     $sp$0$i$i$i = $938;
    }
    $$sum$i15$i = (($934) + -47)|0;
    $$sum1$i16$i = (($934) + -39)|0;
    $939 = (($931) + ($$sum1$i16$i)|0);
    $940 = $939;
    $941 = $940 & 7;
    $942 = ($941|0)==(0);
    if ($942) {
     $945 = 0;
    } else {
     $943 = (0 - ($940))|0;
     $944 = $943 & 7;
     $945 = $944;
    }
    $$sum2$i17$i = (($$sum$i15$i) + ($945))|0;
    $946 = (($931) + ($$sum2$i17$i)|0);
    $947 = (($636) + 16|0);
    $948 = ($946>>>0)<($947>>>0);
    $949 = $948 ? $636 : $946;
    $950 = (($949) + 8|0);
    $951 = (($tsize$246$i) + -40)|0;
    $952 = (($tbase$247$i) + 8|0);
    $953 = $952;
    $954 = $953 & 7;
    $955 = ($954|0)==(0);
    if ($955) {
     $959 = 0;
    } else {
     $956 = (0 - ($953))|0;
     $957 = $956 & 7;
     $959 = $957;
    }
    $958 = (($tbase$247$i) + ($959)|0);
    $960 = (($951) - ($959))|0;
    HEAP32[((3109840 + 24|0))>>2] = $958;
    HEAP32[((3109840 + 12|0))>>2] = $960;
    $961 = $960 | 1;
    $$sum$i$i$i = (($959) + 4)|0;
    $962 = (($tbase$247$i) + ($$sum$i$i$i)|0);
    HEAP32[$962>>2] = $961;
    $$sum2$i$i$i = (($tsize$246$i) + -36)|0;
    $963 = (($tbase$247$i) + ($$sum2$i$i$i)|0);
    HEAP32[$963>>2] = 40;
    $964 = HEAP32[((3110312 + 16|0))>>2]|0;
    HEAP32[((3109840 + 28|0))>>2] = $964;
    $965 = (($949) + 4|0);
    HEAP32[$965>>2] = 27;
    ;HEAP32[$950+0>>2]=HEAP32[((3109840 + 448|0))+0>>2]|0;HEAP32[$950+4>>2]=HEAP32[((3109840 + 448|0))+4>>2]|0;HEAP32[$950+8>>2]=HEAP32[((3109840 + 448|0))+8>>2]|0;HEAP32[$950+12>>2]=HEAP32[((3109840 + 448|0))+12>>2]|0;
    HEAP32[((3109840 + 448|0))>>2] = $tbase$247$i;
    HEAP32[((3109840 + 452|0))>>2] = $tsize$246$i;
    HEAP32[((3109840 + 460|0))>>2] = 0;
    HEAP32[((3109840 + 456|0))>>2] = $950;
    $966 = (($949) + 28|0);
    HEAP32[$966>>2] = 7;
    $967 = (($949) + 32|0);
    $968 = ($967>>>0)<($935>>>0);
    if ($968) {
     $970 = $966;
     while(1) {
      $969 = (($970) + 4|0);
      HEAP32[$969>>2] = 7;
      $971 = (($970) + 8|0);
      $972 = ($971>>>0)<($935>>>0);
      if ($972) {
       $970 = $969;
      } else {
       break;
      }
     }
    }
    $973 = ($949|0)==($636|0);
    if (!($973)) {
     $974 = $949;
     $975 = $636;
     $976 = (($974) - ($975))|0;
     $977 = (($636) + ($976)|0);
     $$sum3$i$i = (($976) + 4)|0;
     $978 = (($636) + ($$sum3$i$i)|0);
     $979 = HEAP32[$978>>2]|0;
     $980 = $979 & -2;
     HEAP32[$978>>2] = $980;
     $981 = $976 | 1;
     $982 = (($636) + 4|0);
     HEAP32[$982>>2] = $981;
     HEAP32[$977>>2] = $976;
     $983 = $976 >>> 3;
     $984 = ($976>>>0)<(256);
     if ($984) {
      $985 = $983 << 1;
      $986 = ((3109840 + ($985<<2)|0) + 40|0);
      $987 = HEAP32[3109840>>2]|0;
      $988 = 1 << $983;
      $989 = $987 & $988;
      $990 = ($989|0)==(0);
      do {
       if ($990) {
        $991 = $987 | $988;
        HEAP32[3109840>>2] = $991;
        $$sum10$pre$i$i = (($985) + 2)|0;
        $$pre$i$i = ((3109840 + ($$sum10$pre$i$i<<2)|0) + 40|0);
        $$pre$phi$i$iZ2D = $$pre$i$i;$F$0$i$i = $986;
       } else {
        $$sum11$i$i = (($985) + 2)|0;
        $992 = ((3109840 + ($$sum11$i$i<<2)|0) + 40|0);
        $993 = HEAP32[$992>>2]|0;
        $994 = HEAP32[((3109840 + 16|0))>>2]|0;
        $995 = ($993>>>0)<($994>>>0);
        if (!($995)) {
         $$pre$phi$i$iZ2D = $992;$F$0$i$i = $993;
         break;
        }
        _abort();
        // unreachable;
       }
      } while(0);
      HEAP32[$$pre$phi$i$iZ2D>>2] = $636;
      $996 = (($F$0$i$i) + 12|0);
      HEAP32[$996>>2] = $636;
      $997 = (($636) + 8|0);
      HEAP32[$997>>2] = $F$0$i$i;
      $998 = (($636) + 12|0);
      HEAP32[$998>>2] = $986;
      break;
     }
     $999 = $976 >>> 8;
     $1000 = ($999|0)==(0);
     if ($1000) {
      $I1$0$i$i = 0;
     } else {
      $1001 = ($976>>>0)>(16777215);
      if ($1001) {
       $I1$0$i$i = 31;
      } else {
       $1002 = (($999) + 1048320)|0;
       $1003 = $1002 >>> 16;
       $1004 = $1003 & 8;
       $1005 = $999 << $1004;
       $1006 = (($1005) + 520192)|0;
       $1007 = $1006 >>> 16;
       $1008 = $1007 & 4;
       $1009 = $1008 | $1004;
       $1010 = $1005 << $1008;
       $1011 = (($1010) + 245760)|0;
       $1012 = $1011 >>> 16;
       $1013 = $1012 & 2;
       $1014 = $1009 | $1013;
       $1015 = (14 - ($1014))|0;
       $1016 = $1010 << $1013;
       $1017 = $1016 >>> 15;
       $1018 = (($1015) + ($1017))|0;
       $1019 = $1018 << 1;
       $1020 = (($1018) + 7)|0;
       $1021 = $976 >>> $1020;
       $1022 = $1021 & 1;
       $1023 = $1022 | $1019;
       $I1$0$i$i = $1023;
      }
     }
     $1024 = ((3109840 + ($I1$0$i$i<<2)|0) + 304|0);
     $1025 = (($636) + 28|0);
     $I1$0$c$i$i = $I1$0$i$i;
     HEAP32[$1025>>2] = $I1$0$c$i$i;
     $1026 = (($636) + 20|0);
     HEAP32[$1026>>2] = 0;
     $1027 = (($636) + 16|0);
     HEAP32[$1027>>2] = 0;
     $1028 = HEAP32[((3109840 + 4|0))>>2]|0;
     $1029 = 1 << $I1$0$i$i;
     $1030 = $1028 & $1029;
     $1031 = ($1030|0)==(0);
     if ($1031) {
      $1032 = $1028 | $1029;
      HEAP32[((3109840 + 4|0))>>2] = $1032;
      HEAP32[$1024>>2] = $636;
      $1033 = (($636) + 24|0);
      HEAP32[$1033>>2] = $1024;
      $1034 = (($636) + 12|0);
      HEAP32[$1034>>2] = $636;
      $1035 = (($636) + 8|0);
      HEAP32[$1035>>2] = $636;
      break;
     }
     $1036 = HEAP32[$1024>>2]|0;
     $1037 = ($I1$0$i$i|0)==(31);
     if ($1037) {
      $1045 = 0;
     } else {
      $1038 = $I1$0$i$i >>> 1;
      $1039 = (25 - ($1038))|0;
      $1045 = $1039;
     }
     $1040 = (($1036) + 4|0);
     $1041 = HEAP32[$1040>>2]|0;
     $1042 = $1041 & -8;
     $1043 = ($1042|0)==($976|0);
     L499: do {
      if ($1043) {
       $T$0$lcssa$i$i = $1036;
      } else {
       $1044 = $976 << $1045;
       $K2$014$i$i = $1044;$T$013$i$i = $1036;
       while(1) {
        $1052 = $K2$014$i$i >>> 31;
        $1053 = ((($T$013$i$i) + ($1052<<2)|0) + 16|0);
        $1048 = HEAP32[$1053>>2]|0;
        $1054 = ($1048|0)==(0|0);
        if ($1054) {
         break;
        }
        $1046 = $K2$014$i$i << 1;
        $1047 = (($1048) + 4|0);
        $1049 = HEAP32[$1047>>2]|0;
        $1050 = $1049 & -8;
        $1051 = ($1050|0)==($976|0);
        if ($1051) {
         $T$0$lcssa$i$i = $1048;
         break L499;
        } else {
         $K2$014$i$i = $1046;$T$013$i$i = $1048;
        }
       }
       $1055 = HEAP32[((3109840 + 16|0))>>2]|0;
       $1056 = ($1053>>>0)<($1055>>>0);
       if ($1056) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$1053>>2] = $636;
        $1057 = (($636) + 24|0);
        HEAP32[$1057>>2] = $T$013$i$i;
        $1058 = (($636) + 12|0);
        HEAP32[$1058>>2] = $636;
        $1059 = (($636) + 8|0);
        HEAP32[$1059>>2] = $636;
        break L311;
       }
      }
     } while(0);
     $1060 = (($T$0$lcssa$i$i) + 8|0);
     $1061 = HEAP32[$1060>>2]|0;
     $1062 = HEAP32[((3109840 + 16|0))>>2]|0;
     $1063 = ($T$0$lcssa$i$i>>>0)<($1062>>>0);
     if ($1063) {
      _abort();
      // unreachable;
     }
     $1064 = ($1061>>>0)<($1062>>>0);
     if ($1064) {
      _abort();
      // unreachable;
     } else {
      $1065 = (($1061) + 12|0);
      HEAP32[$1065>>2] = $636;
      HEAP32[$1060>>2] = $636;
      $1066 = (($636) + 8|0);
      HEAP32[$1066>>2] = $1061;
      $1067 = (($636) + 12|0);
      HEAP32[$1067>>2] = $T$0$lcssa$i$i;
      $1068 = (($636) + 24|0);
      HEAP32[$1068>>2] = 0;
      break;
     }
    }
   }
  } while(0);
  $1069 = HEAP32[((3109840 + 12|0))>>2]|0;
  $1070 = ($1069>>>0)>($nb$0>>>0);
  if ($1070) {
   $1071 = (($1069) - ($nb$0))|0;
   HEAP32[((3109840 + 12|0))>>2] = $1071;
   $1072 = HEAP32[((3109840 + 24|0))>>2]|0;
   $1073 = (($1072) + ($nb$0)|0);
   HEAP32[((3109840 + 24|0))>>2] = $1073;
   $1074 = $1071 | 1;
   $$sum$i32 = (($nb$0) + 4)|0;
   $1075 = (($1072) + ($$sum$i32)|0);
   HEAP32[$1075>>2] = $1074;
   $1076 = $nb$0 | 3;
   $1077 = (($1072) + 4|0);
   HEAP32[$1077>>2] = $1076;
   $1078 = (($1072) + 8|0);
   $mem$0 = $1078;
   STACKTOP = sp;return ($mem$0|0);
  }
 }
 $1079 = (___errno_location()|0);
 HEAP32[$1079>>2] = 12;
 $mem$0 = 0;
 STACKTOP = sp;return ($mem$0|0);
}
function _free($mem) {
 $mem = $mem|0;
 var $$pre = 0, $$pre$phi68Z2D = 0, $$pre$phi70Z2D = 0, $$pre$phiZ2D = 0, $$pre67 = 0, $$pre69 = 0, $$sum = 0, $$sum16$pre = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum2324 = 0, $$sum25 = 0, $$sum26 = 0, $$sum28 = 0, $$sum29 = 0, $$sum3 = 0, $$sum30 = 0;
 var $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum5 = 0, $$sum67 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $322 = 0, $323 = 0, $324 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I18$0 = 0, $I18$0$c = 0, $K19$057 = 0;
 var $R$0 = 0, $R$1 = 0, $R7$0 = 0, $R7$1 = 0, $RP$0 = 0, $RP9$0 = 0, $T$0$lcssa = 0, $T$056 = 0, $cond = 0, $cond54 = 0, $p$0 = 0, $psize$0 = 0, $psize$1 = 0, $sp$0$i = 0, $sp$0$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mem|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($mem) + -8|0);
 $2 = HEAP32[((3109840 + 16|0))>>2]|0;
 $3 = ($1>>>0)<($2>>>0);
 if ($3) {
  _abort();
  // unreachable;
 }
 $4 = (($mem) + -4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 3;
 $7 = ($6|0)==(1);
 if ($7) {
  _abort();
  // unreachable;
 }
 $8 = $5 & -8;
 $$sum = (($8) + -8)|0;
 $9 = (($mem) + ($$sum)|0);
 $10 = $5 & 1;
 $11 = ($10|0)==(0);
 do {
  if ($11) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ($6|0)==(0);
   if ($13) {
    STACKTOP = sp;return;
   }
   $$sum2 = (-8 - ($12))|0;
   $14 = (($mem) + ($$sum2)|0);
   $15 = (($12) + ($8))|0;
   $16 = ($14>>>0)<($2>>>0);
   if ($16) {
    _abort();
    // unreachable;
   }
   $17 = HEAP32[((3109840 + 20|0))>>2]|0;
   $18 = ($14|0)==($17|0);
   if ($18) {
    $$sum3 = (($8) + -4)|0;
    $104 = (($mem) + ($$sum3)|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = $105 & 3;
    $107 = ($106|0)==(3);
    if (!($107)) {
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    HEAP32[((3109840 + 8|0))>>2] = $15;
    $108 = HEAP32[$104>>2]|0;
    $109 = $108 & -2;
    HEAP32[$104>>2] = $109;
    $110 = $15 | 1;
    $$sum26 = (($$sum2) + 4)|0;
    $111 = (($mem) + ($$sum26)|0);
    HEAP32[$111>>2] = $110;
    HEAP32[$9>>2] = $15;
    STACKTOP = sp;return;
   }
   $19 = $12 >>> 3;
   $20 = ($12>>>0)<(256);
   if ($20) {
    $$sum36 = (($$sum2) + 8)|0;
    $21 = (($mem) + ($$sum36)|0);
    $22 = HEAP32[$21>>2]|0;
    $$sum37 = (($$sum2) + 12)|0;
    $23 = (($mem) + ($$sum37)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = $19 << 1;
    $26 = ((3109840 + ($25<<2)|0) + 40|0);
    $27 = ($22|0)==($26|0);
    if (!($27)) {
     $28 = ($22>>>0)<($2>>>0);
     if ($28) {
      _abort();
      // unreachable;
     }
     $29 = (($22) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($14|0);
     if (!($31)) {
      _abort();
      // unreachable;
     }
    }
    $32 = ($24|0)==($22|0);
    if ($32) {
     $33 = 1 << $19;
     $34 = $33 ^ -1;
     $35 = HEAP32[3109840>>2]|0;
     $36 = $35 & $34;
     HEAP32[3109840>>2] = $36;
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    $37 = ($24|0)==($26|0);
    if ($37) {
     $$pre69 = (($24) + 8|0);
     $$pre$phi70Z2D = $$pre69;
    } else {
     $38 = ($24>>>0)<($2>>>0);
     if ($38) {
      _abort();
      // unreachable;
     }
     $39 = (($24) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($14|0);
     if ($41) {
      $$pre$phi70Z2D = $39;
     } else {
      _abort();
      // unreachable;
     }
    }
    $42 = (($22) + 12|0);
    HEAP32[$42>>2] = $24;
    HEAP32[$$pre$phi70Z2D>>2] = $22;
    $p$0 = $14;$psize$0 = $15;
    break;
   }
   $$sum28 = (($$sum2) + 24)|0;
   $43 = (($mem) + ($$sum28)|0);
   $44 = HEAP32[$43>>2]|0;
   $$sum29 = (($$sum2) + 12)|0;
   $45 = (($mem) + ($$sum29)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($14|0);
   do {
    if ($47) {
     $$sum31 = (($$sum2) + 20)|0;
     $57 = (($mem) + ($$sum31)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $$sum30 = (($$sum2) + 16)|0;
      $60 = (($mem) + ($$sum30)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $61;$RP$0 = $60;
      }
     } else {
      $R$0 = $58;$RP$0 = $57;
     }
     while(1) {
      $63 = (($R$0) + 20|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==(0|0);
      if (!($65)) {
       $R$0 = $64;$RP$0 = $63;
       continue;
      }
      $66 = (($R$0) + 16|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       break;
      } else {
       $R$0 = $67;$RP$0 = $66;
      }
     }
     $69 = ($RP$0>>>0)<($2>>>0);
     if ($69) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0>>2] = 0;
      $R$1 = $R$0;
      break;
     }
    } else {
     $$sum35 = (($$sum2) + 8)|0;
     $48 = (($mem) + ($$sum35)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49>>>0)<($2>>>0);
     if ($50) {
      _abort();
      // unreachable;
     }
     $51 = (($49) + 12|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==($14|0);
     if (!($53)) {
      _abort();
      // unreachable;
     }
     $54 = (($46) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==($14|0);
     if ($56) {
      HEAP32[$51>>2] = $46;
      HEAP32[$54>>2] = $49;
      $R$1 = $46;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $70 = ($44|0)==(0|0);
   if ($70) {
    $p$0 = $14;$psize$0 = $15;
   } else {
    $$sum32 = (($$sum2) + 28)|0;
    $71 = (($mem) + ($$sum32)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ((3109840 + ($72<<2)|0) + 304|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($14|0)==($74|0);
    if ($75) {
     HEAP32[$73>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $76 = 1 << $72;
      $77 = $76 ^ -1;
      $78 = HEAP32[((3109840 + 4|0))>>2]|0;
      $79 = $78 & $77;
      HEAP32[((3109840 + 4|0))>>2] = $79;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    } else {
     $80 = HEAP32[((3109840 + 16|0))>>2]|0;
     $81 = ($44>>>0)<($80>>>0);
     if ($81) {
      _abort();
      // unreachable;
     }
     $82 = (($44) + 16|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==($14|0);
     if ($84) {
      HEAP32[$82>>2] = $R$1;
     } else {
      $85 = (($44) + 20|0);
      HEAP32[$85>>2] = $R$1;
     }
     $86 = ($R$1|0)==(0|0);
     if ($86) {
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
    $87 = HEAP32[((3109840 + 16|0))>>2]|0;
    $88 = ($R$1>>>0)<($87>>>0);
    if ($88) {
     _abort();
     // unreachable;
    }
    $89 = (($R$1) + 24|0);
    HEAP32[$89>>2] = $44;
    $$sum33 = (($$sum2) + 16)|0;
    $90 = (($mem) + ($$sum33)|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($91|0)==(0|0);
    do {
     if (!($92)) {
      $93 = HEAP32[((3109840 + 16|0))>>2]|0;
      $94 = ($91>>>0)<($93>>>0);
      if ($94) {
       _abort();
       // unreachable;
      } else {
       $95 = (($R$1) + 16|0);
       HEAP32[$95>>2] = $91;
       $96 = (($91) + 24|0);
       HEAP32[$96>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum34 = (($$sum2) + 20)|0;
    $97 = (($mem) + ($$sum34)|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = ($98|0)==(0|0);
    if ($99) {
     $p$0 = $14;$psize$0 = $15;
    } else {
     $100 = HEAP32[((3109840 + 16|0))>>2]|0;
     $101 = ($98>>>0)<($100>>>0);
     if ($101) {
      _abort();
      // unreachable;
     } else {
      $102 = (($R$1) + 20|0);
      HEAP32[$102>>2] = $98;
      $103 = (($98) + 24|0);
      HEAP32[$103>>2] = $R$1;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
   }
  } else {
   $p$0 = $1;$psize$0 = $8;
  }
 } while(0);
 $112 = ($p$0>>>0)<($9>>>0);
 if (!($112)) {
  _abort();
  // unreachable;
 }
 $$sum25 = (($8) + -4)|0;
 $113 = (($mem) + ($$sum25)|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = $114 & 1;
 $116 = ($115|0)==(0);
 if ($116) {
  _abort();
  // unreachable;
 }
 $117 = $114 & 2;
 $118 = ($117|0)==(0);
 if ($118) {
  $119 = HEAP32[((3109840 + 24|0))>>2]|0;
  $120 = ($9|0)==($119|0);
  if ($120) {
   $121 = HEAP32[((3109840 + 12|0))>>2]|0;
   $122 = (($121) + ($psize$0))|0;
   HEAP32[((3109840 + 12|0))>>2] = $122;
   HEAP32[((3109840 + 24|0))>>2] = $p$0;
   $123 = $122 | 1;
   $124 = (($p$0) + 4|0);
   HEAP32[$124>>2] = $123;
   $125 = HEAP32[((3109840 + 20|0))>>2]|0;
   $126 = ($p$0|0)==($125|0);
   if (!($126)) {
    STACKTOP = sp;return;
   }
   HEAP32[((3109840 + 20|0))>>2] = 0;
   HEAP32[((3109840 + 8|0))>>2] = 0;
   STACKTOP = sp;return;
  }
  $127 = HEAP32[((3109840 + 20|0))>>2]|0;
  $128 = ($9|0)==($127|0);
  if ($128) {
   $129 = HEAP32[((3109840 + 8|0))>>2]|0;
   $130 = (($129) + ($psize$0))|0;
   HEAP32[((3109840 + 8|0))>>2] = $130;
   HEAP32[((3109840 + 20|0))>>2] = $p$0;
   $131 = $130 | 1;
   $132 = (($p$0) + 4|0);
   HEAP32[$132>>2] = $131;
   $133 = (($p$0) + ($130)|0);
   HEAP32[$133>>2] = $130;
   STACKTOP = sp;return;
  }
  $134 = $114 & -8;
  $135 = (($134) + ($psize$0))|0;
  $136 = $114 >>> 3;
  $137 = ($114>>>0)<(256);
  do {
   if ($137) {
    $138 = (($mem) + ($8)|0);
    $139 = HEAP32[$138>>2]|0;
    $$sum2324 = $8 | 4;
    $140 = (($mem) + ($$sum2324)|0);
    $141 = HEAP32[$140>>2]|0;
    $142 = $136 << 1;
    $143 = ((3109840 + ($142<<2)|0) + 40|0);
    $144 = ($139|0)==($143|0);
    if (!($144)) {
     $145 = HEAP32[((3109840 + 16|0))>>2]|0;
     $146 = ($139>>>0)<($145>>>0);
     if ($146) {
      _abort();
      // unreachable;
     }
     $147 = (($139) + 12|0);
     $148 = HEAP32[$147>>2]|0;
     $149 = ($148|0)==($9|0);
     if (!($149)) {
      _abort();
      // unreachable;
     }
    }
    $150 = ($141|0)==($139|0);
    if ($150) {
     $151 = 1 << $136;
     $152 = $151 ^ -1;
     $153 = HEAP32[3109840>>2]|0;
     $154 = $153 & $152;
     HEAP32[3109840>>2] = $154;
     break;
    }
    $155 = ($141|0)==($143|0);
    if ($155) {
     $$pre67 = (($141) + 8|0);
     $$pre$phi68Z2D = $$pre67;
    } else {
     $156 = HEAP32[((3109840 + 16|0))>>2]|0;
     $157 = ($141>>>0)<($156>>>0);
     if ($157) {
      _abort();
      // unreachable;
     }
     $158 = (($141) + 8|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ($159|0)==($9|0);
     if ($160) {
      $$pre$phi68Z2D = $158;
     } else {
      _abort();
      // unreachable;
     }
    }
    $161 = (($139) + 12|0);
    HEAP32[$161>>2] = $141;
    HEAP32[$$pre$phi68Z2D>>2] = $139;
   } else {
    $$sum5 = (($8) + 16)|0;
    $162 = (($mem) + ($$sum5)|0);
    $163 = HEAP32[$162>>2]|0;
    $$sum67 = $8 | 4;
    $164 = (($mem) + ($$sum67)|0);
    $165 = HEAP32[$164>>2]|0;
    $166 = ($165|0)==($9|0);
    do {
     if ($166) {
      $$sum9 = (($8) + 12)|0;
      $177 = (($mem) + ($$sum9)|0);
      $178 = HEAP32[$177>>2]|0;
      $179 = ($178|0)==(0|0);
      if ($179) {
       $$sum8 = (($8) + 8)|0;
       $180 = (($mem) + ($$sum8)|0);
       $181 = HEAP32[$180>>2]|0;
       $182 = ($181|0)==(0|0);
       if ($182) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $181;$RP9$0 = $180;
       }
      } else {
       $R7$0 = $178;$RP9$0 = $177;
      }
      while(1) {
       $183 = (($R7$0) + 20|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = ($184|0)==(0|0);
       if (!($185)) {
        $R7$0 = $184;$RP9$0 = $183;
        continue;
       }
       $186 = (($R7$0) + 16|0);
       $187 = HEAP32[$186>>2]|0;
       $188 = ($187|0)==(0|0);
       if ($188) {
        break;
       } else {
        $R7$0 = $187;$RP9$0 = $186;
       }
      }
      $189 = HEAP32[((3109840 + 16|0))>>2]|0;
      $190 = ($RP9$0>>>0)<($189>>>0);
      if ($190) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0>>2] = 0;
       $R7$1 = $R7$0;
       break;
      }
     } else {
      $167 = (($mem) + ($8)|0);
      $168 = HEAP32[$167>>2]|0;
      $169 = HEAP32[((3109840 + 16|0))>>2]|0;
      $170 = ($168>>>0)<($169>>>0);
      if ($170) {
       _abort();
       // unreachable;
      }
      $171 = (($168) + 12|0);
      $172 = HEAP32[$171>>2]|0;
      $173 = ($172|0)==($9|0);
      if (!($173)) {
       _abort();
       // unreachable;
      }
      $174 = (($165) + 8|0);
      $175 = HEAP32[$174>>2]|0;
      $176 = ($175|0)==($9|0);
      if ($176) {
       HEAP32[$171>>2] = $165;
       HEAP32[$174>>2] = $168;
       $R7$1 = $165;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $191 = ($163|0)==(0|0);
    if (!($191)) {
     $$sum18 = (($8) + 20)|0;
     $192 = (($mem) + ($$sum18)|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = ((3109840 + ($193<<2)|0) + 304|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = ($9|0)==($195|0);
     if ($196) {
      HEAP32[$194>>2] = $R7$1;
      $cond54 = ($R7$1|0)==(0|0);
      if ($cond54) {
       $197 = 1 << $193;
       $198 = $197 ^ -1;
       $199 = HEAP32[((3109840 + 4|0))>>2]|0;
       $200 = $199 & $198;
       HEAP32[((3109840 + 4|0))>>2] = $200;
       break;
      }
     } else {
      $201 = HEAP32[((3109840 + 16|0))>>2]|0;
      $202 = ($163>>>0)<($201>>>0);
      if ($202) {
       _abort();
       // unreachable;
      }
      $203 = (($163) + 16|0);
      $204 = HEAP32[$203>>2]|0;
      $205 = ($204|0)==($9|0);
      if ($205) {
       HEAP32[$203>>2] = $R7$1;
      } else {
       $206 = (($163) + 20|0);
       HEAP32[$206>>2] = $R7$1;
      }
      $207 = ($R7$1|0)==(0|0);
      if ($207) {
       break;
      }
     }
     $208 = HEAP32[((3109840 + 16|0))>>2]|0;
     $209 = ($R7$1>>>0)<($208>>>0);
     if ($209) {
      _abort();
      // unreachable;
     }
     $210 = (($R7$1) + 24|0);
     HEAP32[$210>>2] = $163;
     $$sum19 = (($8) + 8)|0;
     $211 = (($mem) + ($$sum19)|0);
     $212 = HEAP32[$211>>2]|0;
     $213 = ($212|0)==(0|0);
     do {
      if (!($213)) {
       $214 = HEAP32[((3109840 + 16|0))>>2]|0;
       $215 = ($212>>>0)<($214>>>0);
       if ($215) {
        _abort();
        // unreachable;
       } else {
        $216 = (($R7$1) + 16|0);
        HEAP32[$216>>2] = $212;
        $217 = (($212) + 24|0);
        HEAP32[$217>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum20 = (($8) + 12)|0;
     $218 = (($mem) + ($$sum20)|0);
     $219 = HEAP32[$218>>2]|0;
     $220 = ($219|0)==(0|0);
     if (!($220)) {
      $221 = HEAP32[((3109840 + 16|0))>>2]|0;
      $222 = ($219>>>0)<($221>>>0);
      if ($222) {
       _abort();
       // unreachable;
      } else {
       $223 = (($R7$1) + 20|0);
       HEAP32[$223>>2] = $219;
       $224 = (($219) + 24|0);
       HEAP32[$224>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $225 = $135 | 1;
  $226 = (($p$0) + 4|0);
  HEAP32[$226>>2] = $225;
  $227 = (($p$0) + ($135)|0);
  HEAP32[$227>>2] = $135;
  $228 = HEAP32[((3109840 + 20|0))>>2]|0;
  $229 = ($p$0|0)==($228|0);
  if ($229) {
   HEAP32[((3109840 + 8|0))>>2] = $135;
   STACKTOP = sp;return;
  } else {
   $psize$1 = $135;
  }
 } else {
  $230 = $114 & -2;
  HEAP32[$113>>2] = $230;
  $231 = $psize$0 | 1;
  $232 = (($p$0) + 4|0);
  HEAP32[$232>>2] = $231;
  $233 = (($p$0) + ($psize$0)|0);
  HEAP32[$233>>2] = $psize$0;
  $psize$1 = $psize$0;
 }
 $234 = $psize$1 >>> 3;
 $235 = ($psize$1>>>0)<(256);
 if ($235) {
  $236 = $234 << 1;
  $237 = ((3109840 + ($236<<2)|0) + 40|0);
  $238 = HEAP32[3109840>>2]|0;
  $239 = 1 << $234;
  $240 = $238 & $239;
  $241 = ($240|0)==(0);
  if ($241) {
   $242 = $238 | $239;
   HEAP32[3109840>>2] = $242;
   $$sum16$pre = (($236) + 2)|0;
   $$pre = ((3109840 + ($$sum16$pre<<2)|0) + 40|0);
   $$pre$phiZ2D = $$pre;$F16$0 = $237;
  } else {
   $$sum17 = (($236) + 2)|0;
   $243 = ((3109840 + ($$sum17<<2)|0) + 40|0);
   $244 = HEAP32[$243>>2]|0;
   $245 = HEAP32[((3109840 + 16|0))>>2]|0;
   $246 = ($244>>>0)<($245>>>0);
   if ($246) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $243;$F16$0 = $244;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $p$0;
  $247 = (($F16$0) + 12|0);
  HEAP32[$247>>2] = $p$0;
  $248 = (($p$0) + 8|0);
  HEAP32[$248>>2] = $F16$0;
  $249 = (($p$0) + 12|0);
  HEAP32[$249>>2] = $237;
  STACKTOP = sp;return;
 }
 $250 = $psize$1 >>> 8;
 $251 = ($250|0)==(0);
 if ($251) {
  $I18$0 = 0;
 } else {
  $252 = ($psize$1>>>0)>(16777215);
  if ($252) {
   $I18$0 = 31;
  } else {
   $253 = (($250) + 1048320)|0;
   $254 = $253 >>> 16;
   $255 = $254 & 8;
   $256 = $250 << $255;
   $257 = (($256) + 520192)|0;
   $258 = $257 >>> 16;
   $259 = $258 & 4;
   $260 = $259 | $255;
   $261 = $256 << $259;
   $262 = (($261) + 245760)|0;
   $263 = $262 >>> 16;
   $264 = $263 & 2;
   $265 = $260 | $264;
   $266 = (14 - ($265))|0;
   $267 = $261 << $264;
   $268 = $267 >>> 15;
   $269 = (($266) + ($268))|0;
   $270 = $269 << 1;
   $271 = (($269) + 7)|0;
   $272 = $psize$1 >>> $271;
   $273 = $272 & 1;
   $274 = $273 | $270;
   $I18$0 = $274;
  }
 }
 $275 = ((3109840 + ($I18$0<<2)|0) + 304|0);
 $276 = (($p$0) + 28|0);
 $I18$0$c = $I18$0;
 HEAP32[$276>>2] = $I18$0$c;
 $277 = (($p$0) + 20|0);
 HEAP32[$277>>2] = 0;
 $278 = (($p$0) + 16|0);
 HEAP32[$278>>2] = 0;
 $279 = HEAP32[((3109840 + 4|0))>>2]|0;
 $280 = 1 << $I18$0;
 $281 = $279 & $280;
 $282 = ($281|0)==(0);
 L199: do {
  if ($282) {
   $283 = $279 | $280;
   HEAP32[((3109840 + 4|0))>>2] = $283;
   HEAP32[$275>>2] = $p$0;
   $284 = (($p$0) + 24|0);
   HEAP32[$284>>2] = $275;
   $285 = (($p$0) + 12|0);
   HEAP32[$285>>2] = $p$0;
   $286 = (($p$0) + 8|0);
   HEAP32[$286>>2] = $p$0;
  } else {
   $287 = HEAP32[$275>>2]|0;
   $288 = ($I18$0|0)==(31);
   if ($288) {
    $296 = 0;
   } else {
    $289 = $I18$0 >>> 1;
    $290 = (25 - ($289))|0;
    $296 = $290;
   }
   $291 = (($287) + 4|0);
   $292 = HEAP32[$291>>2]|0;
   $293 = $292 & -8;
   $294 = ($293|0)==($psize$1|0);
   L205: do {
    if ($294) {
     $T$0$lcssa = $287;
    } else {
     $295 = $psize$1 << $296;
     $K19$057 = $295;$T$056 = $287;
     while(1) {
      $303 = $K19$057 >>> 31;
      $304 = ((($T$056) + ($303<<2)|0) + 16|0);
      $299 = HEAP32[$304>>2]|0;
      $305 = ($299|0)==(0|0);
      if ($305) {
       break;
      }
      $297 = $K19$057 << 1;
      $298 = (($299) + 4|0);
      $300 = HEAP32[$298>>2]|0;
      $301 = $300 & -8;
      $302 = ($301|0)==($psize$1|0);
      if ($302) {
       $T$0$lcssa = $299;
       break L205;
      } else {
       $K19$057 = $297;$T$056 = $299;
      }
     }
     $306 = HEAP32[((3109840 + 16|0))>>2]|0;
     $307 = ($304>>>0)<($306>>>0);
     if ($307) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$304>>2] = $p$0;
      $308 = (($p$0) + 24|0);
      HEAP32[$308>>2] = $T$056;
      $309 = (($p$0) + 12|0);
      HEAP32[$309>>2] = $p$0;
      $310 = (($p$0) + 8|0);
      HEAP32[$310>>2] = $p$0;
      break L199;
     }
    }
   } while(0);
   $311 = (($T$0$lcssa) + 8|0);
   $312 = HEAP32[$311>>2]|0;
   $313 = HEAP32[((3109840 + 16|0))>>2]|0;
   $314 = ($T$0$lcssa>>>0)<($313>>>0);
   if ($314) {
    _abort();
    // unreachable;
   }
   $315 = ($312>>>0)<($313>>>0);
   if ($315) {
    _abort();
    // unreachable;
   } else {
    $316 = (($312) + 12|0);
    HEAP32[$316>>2] = $p$0;
    HEAP32[$311>>2] = $p$0;
    $317 = (($p$0) + 8|0);
    HEAP32[$317>>2] = $312;
    $318 = (($p$0) + 12|0);
    HEAP32[$318>>2] = $T$0$lcssa;
    $319 = (($p$0) + 24|0);
    HEAP32[$319>>2] = 0;
    break;
   }
  }
 } while(0);
 $320 = HEAP32[((3109840 + 32|0))>>2]|0;
 $321 = (($320) + -1)|0;
 HEAP32[((3109840 + 32|0))>>2] = $321;
 $322 = ($321|0)==(0);
 if ($322) {
  $sp$0$in$i = ((3109840 + 456|0));
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $sp$0$i = HEAP32[$sp$0$in$i>>2]|0;
  $323 = ($sp$0$i|0)==(0|0);
  $324 = (($sp$0$i) + 8|0);
  if ($323) {
   break;
  } else {
   $sp$0$in$i = $324;
  }
 }
 HEAP32[((3109840 + 32|0))>>2] = -1;
 STACKTOP = sp;return;
}
function _calloc($n_elements,$elem_size) {
 $n_elements = $n_elements|0;
 $elem_size = $elem_size|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $req$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n_elements|0)==(0);
 if ($0) {
  $req$0 = 0;
 } else {
  $1 = Math_imul($elem_size, $n_elements)|0;
  $2 = $elem_size | $n_elements;
  $3 = ($2>>>0)>(65535);
  if ($3) {
   $4 = (($1>>>0) / ($n_elements>>>0))&-1;
   $5 = ($4|0)==($elem_size|0);
   $$ = $5 ? $1 : -1;
   $req$0 = $$;
  } else {
   $req$0 = $1;
  }
 }
 $6 = (_malloc($req$0)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  STACKTOP = sp;return ($6|0);
 }
 $8 = (($6) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 3;
 $11 = ($10|0)==(0);
 if ($11) {
  STACKTOP = sp;return ($6|0);
 }
 _memset(($6|0),0,($req$0|0))|0;
 STACKTOP = sp;return ($6|0);
}
function _realloc($oldmem,$bytes) {
 $oldmem = $oldmem|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $mem$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($oldmem|0)==(0|0);
 do {
  if ($0) {
   $1 = (_malloc($bytes)|0);
   $mem$0 = $1;
  } else {
   $2 = ($bytes>>>0)>(4294967231);
   if ($2) {
    $3 = (___errno_location()|0);
    HEAP32[$3>>2] = 12;
    $mem$0 = 0;
    break;
   }
   $4 = ($bytes>>>0)<(11);
   if ($4) {
    $8 = 16;
   } else {
    $5 = (($bytes) + 11)|0;
    $6 = $5 & -8;
    $8 = $6;
   }
   $7 = (($oldmem) + -8|0);
   $9 = (_try_realloc_chunk($7,$8)|0);
   $10 = ($9|0)==(0|0);
   if (!($10)) {
    $11 = (($9) + 8|0);
    $mem$0 = $11;
    break;
   }
   $12 = (_malloc($bytes)|0);
   $13 = ($12|0)==(0|0);
   if ($13) {
    $mem$0 = 0;
   } else {
    $14 = (($oldmem) + -4|0);
    $15 = HEAP32[$14>>2]|0;
    $16 = $15 & -8;
    $17 = $15 & 3;
    $18 = ($17|0)==(0);
    $19 = $18 ? 8 : 4;
    $20 = (($16) - ($19))|0;
    $21 = ($20>>>0)<($bytes>>>0);
    $22 = $21 ? $20 : $bytes;
    _memcpy(($12|0),($oldmem|0),($22|0))|0;
    _free($oldmem);
    $mem$0 = $12;
   }
  }
 } while(0);
 STACKTOP = sp;return ($mem$0|0);
}
function _try_realloc_chunk($p,$nb) {
 $p = $p|0;
 $nb = $nb|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum22 = 0, $$sum23 = 0, $$sum2728 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum78 = 0;
 var $$sum910 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $R$0 = 0, $R$1 = 0, $RP$0 = 0;
 var $cond = 0, $newp$0 = 0, $or$cond = 0, $storemerge = 0, $storemerge21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($p) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -8;
 $3 = (($p) + ($2)|0);
 $4 = HEAP32[((3109840 + 16|0))>>2]|0;
 $5 = ($p>>>0)<($4>>>0);
 if ($5) {
  _abort();
  // unreachable;
 }
 $6 = $1 & 3;
 $7 = ($6|0)!=(1);
 $8 = ($p>>>0)<($3>>>0);
 $or$cond = $7 & $8;
 if (!($or$cond)) {
  _abort();
  // unreachable;
 }
 $$sum2728 = $2 | 4;
 $9 = (($p) + ($$sum2728)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 1;
 $12 = ($11|0)==(0);
 if ($12) {
  _abort();
  // unreachable;
 }
 $13 = ($6|0)==(0);
 if ($13) {
  $14 = ($nb>>>0)<(256);
  if ($14) {
   $newp$0 = 0;
   STACKTOP = sp;return ($newp$0|0);
  }
  $15 = (($nb) + 4)|0;
  $16 = ($2>>>0)<($15>>>0);
  if (!($16)) {
   $17 = (($2) - ($nb))|0;
   $18 = HEAP32[((3110312 + 8|0))>>2]|0;
   $19 = $18 << 1;
   $20 = ($17>>>0)>($19>>>0);
   if (!($20)) {
    $newp$0 = $p;
    STACKTOP = sp;return ($newp$0|0);
   }
  }
  $newp$0 = 0;
  STACKTOP = sp;return ($newp$0|0);
 }
 $21 = ($2>>>0)<($nb>>>0);
 if (!($21)) {
  $22 = (($2) - ($nb))|0;
  $23 = ($22>>>0)>(15);
  if (!($23)) {
   $newp$0 = $p;
   STACKTOP = sp;return ($newp$0|0);
  }
  $24 = (($p) + ($nb)|0);
  $25 = $1 & 1;
  $26 = $25 | $nb;
  $27 = $26 | 2;
  HEAP32[$0>>2] = $27;
  $$sum23 = (($nb) + 4)|0;
  $28 = (($p) + ($$sum23)|0);
  $29 = $22 | 3;
  HEAP32[$28>>2] = $29;
  $30 = HEAP32[$9>>2]|0;
  $31 = $30 | 1;
  HEAP32[$9>>2] = $31;
  _dispose_chunk($24,$22);
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 }
 $32 = HEAP32[((3109840 + 24|0))>>2]|0;
 $33 = ($3|0)==($32|0);
 if ($33) {
  $34 = HEAP32[((3109840 + 12|0))>>2]|0;
  $35 = (($34) + ($2))|0;
  $36 = ($35>>>0)>($nb>>>0);
  if (!($36)) {
   $newp$0 = 0;
   STACKTOP = sp;return ($newp$0|0);
  }
  $37 = (($35) - ($nb))|0;
  $38 = (($p) + ($nb)|0);
  $39 = $1 & 1;
  $40 = $39 | $nb;
  $41 = $40 | 2;
  HEAP32[$0>>2] = $41;
  $$sum22 = (($nb) + 4)|0;
  $42 = (($p) + ($$sum22)|0);
  $43 = $37 | 1;
  HEAP32[$42>>2] = $43;
  HEAP32[((3109840 + 24|0))>>2] = $38;
  HEAP32[((3109840 + 12|0))>>2] = $37;
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 }
 $44 = HEAP32[((3109840 + 20|0))>>2]|0;
 $45 = ($3|0)==($44|0);
 if ($45) {
  $46 = HEAP32[((3109840 + 8|0))>>2]|0;
  $47 = (($46) + ($2))|0;
  $48 = ($47>>>0)<($nb>>>0);
  if ($48) {
   $newp$0 = 0;
   STACKTOP = sp;return ($newp$0|0);
  }
  $49 = (($47) - ($nb))|0;
  $50 = ($49>>>0)>(15);
  if ($50) {
   $51 = (($p) + ($nb)|0);
   $52 = (($p) + ($47)|0);
   $53 = $1 & 1;
   $54 = $53 | $nb;
   $55 = $54 | 2;
   HEAP32[$0>>2] = $55;
   $$sum19 = (($nb) + 4)|0;
   $56 = (($p) + ($$sum19)|0);
   $57 = $49 | 1;
   HEAP32[$56>>2] = $57;
   HEAP32[$52>>2] = $49;
   $$sum20 = (($47) + 4)|0;
   $58 = (($p) + ($$sum20)|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 & -2;
   HEAP32[$58>>2] = $60;
   $storemerge = $51;$storemerge21 = $49;
  } else {
   $61 = $1 & 1;
   $62 = $61 | $47;
   $63 = $62 | 2;
   HEAP32[$0>>2] = $63;
   $$sum17 = (($47) + 4)|0;
   $64 = (($p) + ($$sum17)|0);
   $65 = HEAP32[$64>>2]|0;
   $66 = $65 | 1;
   HEAP32[$64>>2] = $66;
   $storemerge = 0;$storemerge21 = 0;
  }
  HEAP32[((3109840 + 8|0))>>2] = $storemerge21;
  HEAP32[((3109840 + 20|0))>>2] = $storemerge;
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 }
 $67 = $10 & 2;
 $68 = ($67|0)==(0);
 if (!($68)) {
  $newp$0 = 0;
  STACKTOP = sp;return ($newp$0|0);
 }
 $69 = $10 & -8;
 $70 = (($69) + ($2))|0;
 $71 = ($70>>>0)<($nb>>>0);
 if ($71) {
  $newp$0 = 0;
  STACKTOP = sp;return ($newp$0|0);
 }
 $72 = (($70) - ($nb))|0;
 $73 = $10 >>> 3;
 $74 = ($10>>>0)<(256);
 do {
  if ($74) {
   $$sum15 = (($2) + 8)|0;
   $75 = (($p) + ($$sum15)|0);
   $76 = HEAP32[$75>>2]|0;
   $$sum16 = (($2) + 12)|0;
   $77 = (($p) + ($$sum16)|0);
   $78 = HEAP32[$77>>2]|0;
   $79 = $73 << 1;
   $80 = ((3109840 + ($79<<2)|0) + 40|0);
   $81 = ($76|0)==($80|0);
   if (!($81)) {
    $82 = ($76>>>0)<($4>>>0);
    if ($82) {
     _abort();
     // unreachable;
    }
    $83 = (($76) + 12|0);
    $84 = HEAP32[$83>>2]|0;
    $85 = ($84|0)==($3|0);
    if (!($85)) {
     _abort();
     // unreachable;
    }
   }
   $86 = ($78|0)==($76|0);
   if ($86) {
    $87 = 1 << $73;
    $88 = $87 ^ -1;
    $89 = HEAP32[3109840>>2]|0;
    $90 = $89 & $88;
    HEAP32[3109840>>2] = $90;
    break;
   }
   $91 = ($78|0)==($80|0);
   if ($91) {
    $$pre = (($78) + 8|0);
    $$pre$phiZ2D = $$pre;
   } else {
    $92 = ($78>>>0)<($4>>>0);
    if ($92) {
     _abort();
     // unreachable;
    }
    $93 = (($78) + 8|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==($3|0);
    if ($95) {
     $$pre$phiZ2D = $93;
    } else {
     _abort();
     // unreachable;
    }
   }
   $96 = (($76) + 12|0);
   HEAP32[$96>>2] = $78;
   HEAP32[$$pre$phiZ2D>>2] = $76;
  } else {
   $$sum = (($2) + 24)|0;
   $97 = (($p) + ($$sum)|0);
   $98 = HEAP32[$97>>2]|0;
   $$sum2 = (($2) + 12)|0;
   $99 = (($p) + ($$sum2)|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = ($100|0)==($3|0);
   do {
    if ($101) {
     $$sum4 = (($2) + 20)|0;
     $111 = (($p) + ($$sum4)|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ($112|0)==(0|0);
     if ($113) {
      $$sum3 = (($2) + 16)|0;
      $114 = (($p) + ($$sum3)|0);
      $115 = HEAP32[$114>>2]|0;
      $116 = ($115|0)==(0|0);
      if ($116) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $115;$RP$0 = $114;
      }
     } else {
      $R$0 = $112;$RP$0 = $111;
     }
     while(1) {
      $117 = (($R$0) + 20|0);
      $118 = HEAP32[$117>>2]|0;
      $119 = ($118|0)==(0|0);
      if (!($119)) {
       $R$0 = $118;$RP$0 = $117;
       continue;
      }
      $120 = (($R$0) + 16|0);
      $121 = HEAP32[$120>>2]|0;
      $122 = ($121|0)==(0|0);
      if ($122) {
       break;
      } else {
       $R$0 = $121;$RP$0 = $120;
      }
     }
     $123 = ($RP$0>>>0)<($4>>>0);
     if ($123) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0>>2] = 0;
      $R$1 = $R$0;
      break;
     }
    } else {
     $$sum14 = (($2) + 8)|0;
     $102 = (($p) + ($$sum14)|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = ($103>>>0)<($4>>>0);
     if ($104) {
      _abort();
      // unreachable;
     }
     $105 = (($103) + 12|0);
     $106 = HEAP32[$105>>2]|0;
     $107 = ($106|0)==($3|0);
     if (!($107)) {
      _abort();
      // unreachable;
     }
     $108 = (($100) + 8|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = ($109|0)==($3|0);
     if ($110) {
      HEAP32[$105>>2] = $100;
      HEAP32[$108>>2] = $103;
      $R$1 = $100;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $124 = ($98|0)==(0|0);
   if (!($124)) {
    $$sum11 = (($2) + 28)|0;
    $125 = (($p) + ($$sum11)|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ((3109840 + ($126<<2)|0) + 304|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = ($3|0)==($128|0);
    if ($129) {
     HEAP32[$127>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $130 = 1 << $126;
      $131 = $130 ^ -1;
      $132 = HEAP32[((3109840 + 4|0))>>2]|0;
      $133 = $132 & $131;
      HEAP32[((3109840 + 4|0))>>2] = $133;
      break;
     }
    } else {
     $134 = HEAP32[((3109840 + 16|0))>>2]|0;
     $135 = ($98>>>0)<($134>>>0);
     if ($135) {
      _abort();
      // unreachable;
     }
     $136 = (($98) + 16|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = ($137|0)==($3|0);
     if ($138) {
      HEAP32[$136>>2] = $R$1;
     } else {
      $139 = (($98) + 20|0);
      HEAP32[$139>>2] = $R$1;
     }
     $140 = ($R$1|0)==(0|0);
     if ($140) {
      break;
     }
    }
    $141 = HEAP32[((3109840 + 16|0))>>2]|0;
    $142 = ($R$1>>>0)<($141>>>0);
    if ($142) {
     _abort();
     // unreachable;
    }
    $143 = (($R$1) + 24|0);
    HEAP32[$143>>2] = $98;
    $$sum12 = (($2) + 16)|0;
    $144 = (($p) + ($$sum12)|0);
    $145 = HEAP32[$144>>2]|0;
    $146 = ($145|0)==(0|0);
    do {
     if (!($146)) {
      $147 = HEAP32[((3109840 + 16|0))>>2]|0;
      $148 = ($145>>>0)<($147>>>0);
      if ($148) {
       _abort();
       // unreachable;
      } else {
       $149 = (($R$1) + 16|0);
       HEAP32[$149>>2] = $145;
       $150 = (($145) + 24|0);
       HEAP32[$150>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum13 = (($2) + 20)|0;
    $151 = (($p) + ($$sum13)|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152|0)==(0|0);
    if (!($153)) {
     $154 = HEAP32[((3109840 + 16|0))>>2]|0;
     $155 = ($152>>>0)<($154>>>0);
     if ($155) {
      _abort();
      // unreachable;
     } else {
      $156 = (($R$1) + 20|0);
      HEAP32[$156>>2] = $152;
      $157 = (($152) + 24|0);
      HEAP32[$157>>2] = $R$1;
      break;
     }
    }
   }
  }
 } while(0);
 $158 = ($72>>>0)<(16);
 if ($158) {
  $159 = HEAP32[$0>>2]|0;
  $160 = $159 & 1;
  $161 = $70 | $160;
  $162 = $161 | 2;
  HEAP32[$0>>2] = $162;
  $$sum910 = $70 | 4;
  $163 = (($p) + ($$sum910)|0);
  $164 = HEAP32[$163>>2]|0;
  $165 = $164 | 1;
  HEAP32[$163>>2] = $165;
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 } else {
  $166 = (($p) + ($nb)|0);
  $167 = HEAP32[$0>>2]|0;
  $168 = $167 & 1;
  $169 = $168 | $nb;
  $170 = $169 | 2;
  HEAP32[$0>>2] = $170;
  $$sum5 = (($nb) + 4)|0;
  $171 = (($p) + ($$sum5)|0);
  $172 = $72 | 3;
  HEAP32[$171>>2] = $172;
  $$sum78 = $70 | 4;
  $173 = (($p) + ($$sum78)|0);
  $174 = HEAP32[$173>>2]|0;
  $175 = $174 | 1;
  HEAP32[$173>>2] = $175;
  _dispose_chunk($166,$72);
  $newp$0 = $p;
  STACKTOP = sp;return ($newp$0|0);
 }
 return 0|0;
}
function _dispose_chunk($p,$psize) {
 $p = $p|0;
 $psize = $psize|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$pre = 0, $$pre$phi63Z2D = 0, $$pre$phi65Z2D = 0, $$pre$phiZ2D = 0, $$pre62 = 0, $$pre64 = 0, $$sum = 0, $$sum1 = 0, $$sum12$pre = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0;
 var $$sum20 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum3 = 0, $$sum30 = 0, $$sum31 = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I19$0 = 0, $I19$0$c = 0, $K20$049 = 0, $R$0 = 0, $R$1 = 0, $R7$0 = 0, $R7$1 = 0, $RP$0 = 0, $RP9$0 = 0, $T$0$lcssa = 0, $T$048 = 0, $cond = 0, $cond46 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($p) + ($psize)|0);
 $1 = (($p) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = HEAP32[$p>>2]|0;
   $6 = $2 & 3;
   $7 = ($6|0)==(0);
   if ($7) {
    STACKTOP = sp;return;
   }
   $8 = (0 - ($5))|0;
   $9 = (($p) + ($8)|0);
   $10 = (($5) + ($psize))|0;
   $11 = HEAP32[((3109840 + 16|0))>>2]|0;
   $12 = ($9>>>0)<($11>>>0);
   if ($12) {
    _abort();
    // unreachable;
   }
   $13 = HEAP32[((3109840 + 20|0))>>2]|0;
   $14 = ($9|0)==($13|0);
   if ($14) {
    $$sum = (($psize) + 4)|0;
    $100 = (($p) + ($$sum)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = $101 & 3;
    $103 = ($102|0)==(3);
    if (!($103)) {
     $$0 = $9;$$02 = $10;
     break;
    }
    HEAP32[((3109840 + 8|0))>>2] = $10;
    $104 = HEAP32[$100>>2]|0;
    $105 = $104 & -2;
    HEAP32[$100>>2] = $105;
    $106 = $10 | 1;
    $$sum20 = (4 - ($5))|0;
    $107 = (($p) + ($$sum20)|0);
    HEAP32[$107>>2] = $106;
    HEAP32[$0>>2] = $10;
    STACKTOP = sp;return;
   }
   $15 = $5 >>> 3;
   $16 = ($5>>>0)<(256);
   if ($16) {
    $$sum30 = (8 - ($5))|0;
    $17 = (($p) + ($$sum30)|0);
    $18 = HEAP32[$17>>2]|0;
    $$sum31 = (12 - ($5))|0;
    $19 = (($p) + ($$sum31)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $15 << 1;
    $22 = ((3109840 + ($21<<2)|0) + 40|0);
    $23 = ($18|0)==($22|0);
    if (!($23)) {
     $24 = ($18>>>0)<($11>>>0);
     if ($24) {
      _abort();
      // unreachable;
     }
     $25 = (($18) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==($9|0);
     if (!($27)) {
      _abort();
      // unreachable;
     }
    }
    $28 = ($20|0)==($18|0);
    if ($28) {
     $29 = 1 << $15;
     $30 = $29 ^ -1;
     $31 = HEAP32[3109840>>2]|0;
     $32 = $31 & $30;
     HEAP32[3109840>>2] = $32;
     $$0 = $9;$$02 = $10;
     break;
    }
    $33 = ($20|0)==($22|0);
    if ($33) {
     $$pre64 = (($20) + 8|0);
     $$pre$phi65Z2D = $$pre64;
    } else {
     $34 = ($20>>>0)<($11>>>0);
     if ($34) {
      _abort();
      // unreachable;
     }
     $35 = (($20) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==($9|0);
     if ($37) {
      $$pre$phi65Z2D = $35;
     } else {
      _abort();
      // unreachable;
     }
    }
    $38 = (($18) + 12|0);
    HEAP32[$38>>2] = $20;
    HEAP32[$$pre$phi65Z2D>>2] = $18;
    $$0 = $9;$$02 = $10;
    break;
   }
   $$sum22 = (24 - ($5))|0;
   $39 = (($p) + ($$sum22)|0);
   $40 = HEAP32[$39>>2]|0;
   $$sum23 = (12 - ($5))|0;
   $41 = (($p) + ($$sum23)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==($9|0);
   do {
    if ($43) {
     $$sum24 = (16 - ($5))|0;
     $$sum25 = (($$sum24) + 4)|0;
     $53 = (($p) + ($$sum25)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      $56 = (($p) + ($$sum24)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0|0);
      if ($58) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $57;$RP$0 = $56;
      }
     } else {
      $R$0 = $54;$RP$0 = $53;
     }
     while(1) {
      $59 = (($R$0) + 20|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if (!($61)) {
       $R$0 = $60;$RP$0 = $59;
       continue;
      }
      $62 = (($R$0) + 16|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($63|0)==(0|0);
      if ($64) {
       break;
      } else {
       $R$0 = $63;$RP$0 = $62;
      }
     }
     $65 = ($RP$0>>>0)<($11>>>0);
     if ($65) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0>>2] = 0;
      $R$1 = $R$0;
      break;
     }
    } else {
     $$sum29 = (8 - ($5))|0;
     $44 = (($p) + ($$sum29)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($11>>>0);
     if ($46) {
      _abort();
      // unreachable;
     }
     $47 = (($45) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==($9|0);
     if (!($49)) {
      _abort();
      // unreachable;
     }
     $50 = (($42) + 8|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($9|0);
     if ($52) {
      HEAP32[$47>>2] = $42;
      HEAP32[$50>>2] = $45;
      $R$1 = $42;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $66 = ($40|0)==(0|0);
   if ($66) {
    $$0 = $9;$$02 = $10;
   } else {
    $$sum26 = (28 - ($5))|0;
    $67 = (($p) + ($$sum26)|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = ((3109840 + ($68<<2)|0) + 304|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($9|0)==($70|0);
    if ($71) {
     HEAP32[$69>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $72 = 1 << $68;
      $73 = $72 ^ -1;
      $74 = HEAP32[((3109840 + 4|0))>>2]|0;
      $75 = $74 & $73;
      HEAP32[((3109840 + 4|0))>>2] = $75;
      $$0 = $9;$$02 = $10;
      break;
     }
    } else {
     $76 = HEAP32[((3109840 + 16|0))>>2]|0;
     $77 = ($40>>>0)<($76>>>0);
     if ($77) {
      _abort();
      // unreachable;
     }
     $78 = (($40) + 16|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)==($9|0);
     if ($80) {
      HEAP32[$78>>2] = $R$1;
     } else {
      $81 = (($40) + 20|0);
      HEAP32[$81>>2] = $R$1;
     }
     $82 = ($R$1|0)==(0|0);
     if ($82) {
      $$0 = $9;$$02 = $10;
      break;
     }
    }
    $83 = HEAP32[((3109840 + 16|0))>>2]|0;
    $84 = ($R$1>>>0)<($83>>>0);
    if ($84) {
     _abort();
     // unreachable;
    }
    $85 = (($R$1) + 24|0);
    HEAP32[$85>>2] = $40;
    $$sum27 = (16 - ($5))|0;
    $86 = (($p) + ($$sum27)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(0|0);
    do {
     if (!($88)) {
      $89 = HEAP32[((3109840 + 16|0))>>2]|0;
      $90 = ($87>>>0)<($89>>>0);
      if ($90) {
       _abort();
       // unreachable;
      } else {
       $91 = (($R$1) + 16|0);
       HEAP32[$91>>2] = $87;
       $92 = (($87) + 24|0);
       HEAP32[$92>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum28 = (($$sum27) + 4)|0;
    $93 = (($p) + ($$sum28)|0);
    $94 = HEAP32[$93>>2]|0;
    $95 = ($94|0)==(0|0);
    if ($95) {
     $$0 = $9;$$02 = $10;
    } else {
     $96 = HEAP32[((3109840 + 16|0))>>2]|0;
     $97 = ($94>>>0)<($96>>>0);
     if ($97) {
      _abort();
      // unreachable;
     } else {
      $98 = (($R$1) + 20|0);
      HEAP32[$98>>2] = $94;
      $99 = (($94) + 24|0);
      HEAP32[$99>>2] = $R$1;
      $$0 = $9;$$02 = $10;
      break;
     }
    }
   }
  } else {
   $$0 = $p;$$02 = $psize;
  }
 } while(0);
 $108 = HEAP32[((3109840 + 16|0))>>2]|0;
 $109 = ($0>>>0)<($108>>>0);
 if ($109) {
  _abort();
  // unreachable;
 }
 $$sum1 = (($psize) + 4)|0;
 $110 = (($p) + ($$sum1)|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = $111 & 2;
 $113 = ($112|0)==(0);
 if ($113) {
  $114 = HEAP32[((3109840 + 24|0))>>2]|0;
  $115 = ($0|0)==($114|0);
  if ($115) {
   $116 = HEAP32[((3109840 + 12|0))>>2]|0;
   $117 = (($116) + ($$02))|0;
   HEAP32[((3109840 + 12|0))>>2] = $117;
   HEAP32[((3109840 + 24|0))>>2] = $$0;
   $118 = $117 | 1;
   $119 = (($$0) + 4|0);
   HEAP32[$119>>2] = $118;
   $120 = HEAP32[((3109840 + 20|0))>>2]|0;
   $121 = ($$0|0)==($120|0);
   if (!($121)) {
    STACKTOP = sp;return;
   }
   HEAP32[((3109840 + 20|0))>>2] = 0;
   HEAP32[((3109840 + 8|0))>>2] = 0;
   STACKTOP = sp;return;
  }
  $122 = HEAP32[((3109840 + 20|0))>>2]|0;
  $123 = ($0|0)==($122|0);
  if ($123) {
   $124 = HEAP32[((3109840 + 8|0))>>2]|0;
   $125 = (($124) + ($$02))|0;
   HEAP32[((3109840 + 8|0))>>2] = $125;
   HEAP32[((3109840 + 20|0))>>2] = $$0;
   $126 = $125 | 1;
   $127 = (($$0) + 4|0);
   HEAP32[$127>>2] = $126;
   $128 = (($$0) + ($125)|0);
   HEAP32[$128>>2] = $125;
   STACKTOP = sp;return;
  }
  $129 = $111 & -8;
  $130 = (($129) + ($$02))|0;
  $131 = $111 >>> 3;
  $132 = ($111>>>0)<(256);
  do {
   if ($132) {
    $$sum18 = (($psize) + 8)|0;
    $133 = (($p) + ($$sum18)|0);
    $134 = HEAP32[$133>>2]|0;
    $$sum19 = (($psize) + 12)|0;
    $135 = (($p) + ($$sum19)|0);
    $136 = HEAP32[$135>>2]|0;
    $137 = $131 << 1;
    $138 = ((3109840 + ($137<<2)|0) + 40|0);
    $139 = ($134|0)==($138|0);
    if (!($139)) {
     $140 = ($134>>>0)<($108>>>0);
     if ($140) {
      _abort();
      // unreachable;
     }
     $141 = (($134) + 12|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ($142|0)==($0|0);
     if (!($143)) {
      _abort();
      // unreachable;
     }
    }
    $144 = ($136|0)==($134|0);
    if ($144) {
     $145 = 1 << $131;
     $146 = $145 ^ -1;
     $147 = HEAP32[3109840>>2]|0;
     $148 = $147 & $146;
     HEAP32[3109840>>2] = $148;
     break;
    }
    $149 = ($136|0)==($138|0);
    if ($149) {
     $$pre62 = (($136) + 8|0);
     $$pre$phi63Z2D = $$pre62;
    } else {
     $150 = ($136>>>0)<($108>>>0);
     if ($150) {
      _abort();
      // unreachable;
     }
     $151 = (($136) + 8|0);
     $152 = HEAP32[$151>>2]|0;
     $153 = ($152|0)==($0|0);
     if ($153) {
      $$pre$phi63Z2D = $151;
     } else {
      _abort();
      // unreachable;
     }
    }
    $154 = (($134) + 12|0);
    HEAP32[$154>>2] = $136;
    HEAP32[$$pre$phi63Z2D>>2] = $134;
   } else {
    $$sum2 = (($psize) + 24)|0;
    $155 = (($p) + ($$sum2)|0);
    $156 = HEAP32[$155>>2]|0;
    $$sum3 = (($psize) + 12)|0;
    $157 = (($p) + ($$sum3)|0);
    $158 = HEAP32[$157>>2]|0;
    $159 = ($158|0)==($0|0);
    do {
     if ($159) {
      $$sum5 = (($psize) + 20)|0;
      $169 = (($p) + ($$sum5)|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = ($170|0)==(0|0);
      if ($171) {
       $$sum4 = (($psize) + 16)|0;
       $172 = (($p) + ($$sum4)|0);
       $173 = HEAP32[$172>>2]|0;
       $174 = ($173|0)==(0|0);
       if ($174) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $173;$RP9$0 = $172;
       }
      } else {
       $R7$0 = $170;$RP9$0 = $169;
      }
      while(1) {
       $175 = (($R7$0) + 20|0);
       $176 = HEAP32[$175>>2]|0;
       $177 = ($176|0)==(0|0);
       if (!($177)) {
        $R7$0 = $176;$RP9$0 = $175;
        continue;
       }
       $178 = (($R7$0) + 16|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ($179|0)==(0|0);
       if ($180) {
        break;
       } else {
        $R7$0 = $179;$RP9$0 = $178;
       }
      }
      $181 = ($RP9$0>>>0)<($108>>>0);
      if ($181) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0>>2] = 0;
       $R7$1 = $R7$0;
       break;
      }
     } else {
      $$sum17 = (($psize) + 8)|0;
      $160 = (($p) + ($$sum17)|0);
      $161 = HEAP32[$160>>2]|0;
      $162 = ($161>>>0)<($108>>>0);
      if ($162) {
       _abort();
       // unreachable;
      }
      $163 = (($161) + 12|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = ($164|0)==($0|0);
      if (!($165)) {
       _abort();
       // unreachable;
      }
      $166 = (($158) + 8|0);
      $167 = HEAP32[$166>>2]|0;
      $168 = ($167|0)==($0|0);
      if ($168) {
       HEAP32[$163>>2] = $158;
       HEAP32[$166>>2] = $161;
       $R7$1 = $158;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $182 = ($156|0)==(0|0);
    if (!($182)) {
     $$sum14 = (($psize) + 28)|0;
     $183 = (($p) + ($$sum14)|0);
     $184 = HEAP32[$183>>2]|0;
     $185 = ((3109840 + ($184<<2)|0) + 304|0);
     $186 = HEAP32[$185>>2]|0;
     $187 = ($0|0)==($186|0);
     if ($187) {
      HEAP32[$185>>2] = $R7$1;
      $cond46 = ($R7$1|0)==(0|0);
      if ($cond46) {
       $188 = 1 << $184;
       $189 = $188 ^ -1;
       $190 = HEAP32[((3109840 + 4|0))>>2]|0;
       $191 = $190 & $189;
       HEAP32[((3109840 + 4|0))>>2] = $191;
       break;
      }
     } else {
      $192 = HEAP32[((3109840 + 16|0))>>2]|0;
      $193 = ($156>>>0)<($192>>>0);
      if ($193) {
       _abort();
       // unreachable;
      }
      $194 = (($156) + 16|0);
      $195 = HEAP32[$194>>2]|0;
      $196 = ($195|0)==($0|0);
      if ($196) {
       HEAP32[$194>>2] = $R7$1;
      } else {
       $197 = (($156) + 20|0);
       HEAP32[$197>>2] = $R7$1;
      }
      $198 = ($R7$1|0)==(0|0);
      if ($198) {
       break;
      }
     }
     $199 = HEAP32[((3109840 + 16|0))>>2]|0;
     $200 = ($R7$1>>>0)<($199>>>0);
     if ($200) {
      _abort();
      // unreachable;
     }
     $201 = (($R7$1) + 24|0);
     HEAP32[$201>>2] = $156;
     $$sum15 = (($psize) + 16)|0;
     $202 = (($p) + ($$sum15)|0);
     $203 = HEAP32[$202>>2]|0;
     $204 = ($203|0)==(0|0);
     do {
      if (!($204)) {
       $205 = HEAP32[((3109840 + 16|0))>>2]|0;
       $206 = ($203>>>0)<($205>>>0);
       if ($206) {
        _abort();
        // unreachable;
       } else {
        $207 = (($R7$1) + 16|0);
        HEAP32[$207>>2] = $203;
        $208 = (($203) + 24|0);
        HEAP32[$208>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum16 = (($psize) + 20)|0;
     $209 = (($p) + ($$sum16)|0);
     $210 = HEAP32[$209>>2]|0;
     $211 = ($210|0)==(0|0);
     if (!($211)) {
      $212 = HEAP32[((3109840 + 16|0))>>2]|0;
      $213 = ($210>>>0)<($212>>>0);
      if ($213) {
       _abort();
       // unreachable;
      } else {
       $214 = (($R7$1) + 20|0);
       HEAP32[$214>>2] = $210;
       $215 = (($210) + 24|0);
       HEAP32[$215>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $216 = $130 | 1;
  $217 = (($$0) + 4|0);
  HEAP32[$217>>2] = $216;
  $218 = (($$0) + ($130)|0);
  HEAP32[$218>>2] = $130;
  $219 = HEAP32[((3109840 + 20|0))>>2]|0;
  $220 = ($$0|0)==($219|0);
  if ($220) {
   HEAP32[((3109840 + 8|0))>>2] = $130;
   STACKTOP = sp;return;
  } else {
   $$1 = $130;
  }
 } else {
  $221 = $111 & -2;
  HEAP32[$110>>2] = $221;
  $222 = $$02 | 1;
  $223 = (($$0) + 4|0);
  HEAP32[$223>>2] = $222;
  $224 = (($$0) + ($$02)|0);
  HEAP32[$224>>2] = $$02;
  $$1 = $$02;
 }
 $225 = $$1 >>> 3;
 $226 = ($$1>>>0)<(256);
 if ($226) {
  $227 = $225 << 1;
  $228 = ((3109840 + ($227<<2)|0) + 40|0);
  $229 = HEAP32[3109840>>2]|0;
  $230 = 1 << $225;
  $231 = $229 & $230;
  $232 = ($231|0)==(0);
  if ($232) {
   $233 = $229 | $230;
   HEAP32[3109840>>2] = $233;
   $$sum12$pre = (($227) + 2)|0;
   $$pre = ((3109840 + ($$sum12$pre<<2)|0) + 40|0);
   $$pre$phiZ2D = $$pre;$F16$0 = $228;
  } else {
   $$sum13 = (($227) + 2)|0;
   $234 = ((3109840 + ($$sum13<<2)|0) + 40|0);
   $235 = HEAP32[$234>>2]|0;
   $236 = HEAP32[((3109840 + 16|0))>>2]|0;
   $237 = ($235>>>0)<($236>>>0);
   if ($237) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $234;$F16$0 = $235;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $$0;
  $238 = (($F16$0) + 12|0);
  HEAP32[$238>>2] = $$0;
  $239 = (($$0) + 8|0);
  HEAP32[$239>>2] = $F16$0;
  $240 = (($$0) + 12|0);
  HEAP32[$240>>2] = $228;
  STACKTOP = sp;return;
 }
 $241 = $$1 >>> 8;
 $242 = ($241|0)==(0);
 if ($242) {
  $I19$0 = 0;
 } else {
  $243 = ($$1>>>0)>(16777215);
  if ($243) {
   $I19$0 = 31;
  } else {
   $244 = (($241) + 1048320)|0;
   $245 = $244 >>> 16;
   $246 = $245 & 8;
   $247 = $241 << $246;
   $248 = (($247) + 520192)|0;
   $249 = $248 >>> 16;
   $250 = $249 & 4;
   $251 = $250 | $246;
   $252 = $247 << $250;
   $253 = (($252) + 245760)|0;
   $254 = $253 >>> 16;
   $255 = $254 & 2;
   $256 = $251 | $255;
   $257 = (14 - ($256))|0;
   $258 = $252 << $255;
   $259 = $258 >>> 15;
   $260 = (($257) + ($259))|0;
   $261 = $260 << 1;
   $262 = (($260) + 7)|0;
   $263 = $$1 >>> $262;
   $264 = $263 & 1;
   $265 = $264 | $261;
   $I19$0 = $265;
  }
 }
 $266 = ((3109840 + ($I19$0<<2)|0) + 304|0);
 $267 = (($$0) + 28|0);
 $I19$0$c = $I19$0;
 HEAP32[$267>>2] = $I19$0$c;
 $268 = (($$0) + 20|0);
 HEAP32[$268>>2] = 0;
 $269 = (($$0) + 16|0);
 HEAP32[$269>>2] = 0;
 $270 = HEAP32[((3109840 + 4|0))>>2]|0;
 $271 = 1 << $I19$0;
 $272 = $270 & $271;
 $273 = ($272|0)==(0);
 if ($273) {
  $274 = $270 | $271;
  HEAP32[((3109840 + 4|0))>>2] = $274;
  HEAP32[$266>>2] = $$0;
  $275 = (($$0) + 24|0);
  HEAP32[$275>>2] = $266;
  $276 = (($$0) + 12|0);
  HEAP32[$276>>2] = $$0;
  $277 = (($$0) + 8|0);
  HEAP32[$277>>2] = $$0;
  STACKTOP = sp;return;
 }
 $278 = HEAP32[$266>>2]|0;
 $279 = ($I19$0|0)==(31);
 if ($279) {
  $287 = 0;
 } else {
  $280 = $I19$0 >>> 1;
  $281 = (25 - ($280))|0;
  $287 = $281;
 }
 $282 = (($278) + 4|0);
 $283 = HEAP32[$282>>2]|0;
 $284 = $283 & -8;
 $285 = ($284|0)==($$1|0);
 L194: do {
  if ($285) {
   $T$0$lcssa = $278;
  } else {
   $286 = $$1 << $287;
   $K20$049 = $286;$T$048 = $278;
   while(1) {
    $294 = $K20$049 >>> 31;
    $295 = ((($T$048) + ($294<<2)|0) + 16|0);
    $290 = HEAP32[$295>>2]|0;
    $296 = ($290|0)==(0|0);
    if ($296) {
     break;
    }
    $288 = $K20$049 << 1;
    $289 = (($290) + 4|0);
    $291 = HEAP32[$289>>2]|0;
    $292 = $291 & -8;
    $293 = ($292|0)==($$1|0);
    if ($293) {
     $T$0$lcssa = $290;
     break L194;
    } else {
     $K20$049 = $288;$T$048 = $290;
    }
   }
   $297 = HEAP32[((3109840 + 16|0))>>2]|0;
   $298 = ($295>>>0)<($297>>>0);
   if ($298) {
    _abort();
    // unreachable;
   }
   HEAP32[$295>>2] = $$0;
   $299 = (($$0) + 24|0);
   HEAP32[$299>>2] = $T$048;
   $300 = (($$0) + 12|0);
   HEAP32[$300>>2] = $$0;
   $301 = (($$0) + 8|0);
   HEAP32[$301>>2] = $$0;
   STACKTOP = sp;return;
  }
 } while(0);
 $302 = (($T$0$lcssa) + 8|0);
 $303 = HEAP32[$302>>2]|0;
 $304 = HEAP32[((3109840 + 16|0))>>2]|0;
 $305 = ($T$0$lcssa>>>0)<($304>>>0);
 if ($305) {
  _abort();
  // unreachable;
 }
 $306 = ($303>>>0)<($304>>>0);
 if ($306) {
  _abort();
  // unreachable;
 }
 $307 = (($303) + 12|0);
 HEAP32[$307>>2] = $$0;
 HEAP32[$302>>2] = $$0;
 $308 = (($$0) + 8|0);
 HEAP32[$308>>2] = $303;
 $309 = (($$0) + 12|0);
 HEAP32[$309>>2] = $T$0$lcssa;
 $310 = (($$0) + 24|0);
 HEAP32[$310>>2] = 0;
 STACKTOP = sp;return;
}
function _isdigit($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -48)|0;
 $1 = ($0>>>0)<(10);
 $2 = $1&1;
 STACKTOP = sp;return ($2|0);
}
function _isspace($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($c|0)==(32);
 if ($0) {
  $4 = 1;
 } else {
  $1 = (($c) + -9)|0;
  $2 = ($1>>>0)<(5);
  $4 = $2;
 }
 $3 = $4&1;
 STACKTOP = sp;return ($3|0);
}
function _isupper($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -65)|0;
 $1 = ($0>>>0)<(26);
 $2 = $1&1;
 STACKTOP = sp;return ($2|0);
}
function _isxdigit($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $isdigit = 0, $isdigittmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isdigittmp = (($c) + -48)|0;
 $isdigit = ($isdigittmp>>>0)<(10);
 if ($isdigit) {
  $4 = 1;
 } else {
  $0 = $c | 32;
  $1 = (($0) + -97)|0;
  $2 = ($1>>>0)<(6);
  $4 = $2;
 }
 $3 = $4&1;
 STACKTOP = sp;return ($3|0);
}
function _tolower($c) {
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_isupper($c)|0);
 $1 = ($0|0)==(0);
 $2 = $c | 32;
 $$0 = $1 ? $c : $2;
 STACKTOP = sp;return ($$0|0);
}
function ___intscan($f,$base,$pok,$0,$1) {
 $f = $f|0;
 $base = $base|0;
 $pok = $pok|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$ = 0, $$1 = 0, $$121 = 0, $$122 = 0, $$18 = 0, $$19 = 0, $$base = 0, $$base16 = 0, $$lcssa = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum1352 = 0, $$sum14 = 0, $$sum15 = 0, $$sum9 = 0, $$sum934 = 0, $10 = 0;
 var $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0;
 var $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0;
 var $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0;
 var $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0;
 var $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0;
 var $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0;
 var $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0;
 var $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0;
 var $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0;
 var $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0;
 var $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$0 = 0, $c$1 = 0, $c$123 = 0, $c$2$be = 0, $c$2$lcssa = 0, $c$3$be = 0, $c$3$lcssa = 0, $c$359 = 0, $c$4$be = 0, $c$4$lcssa = 0, $c$5$be = 0, $c$6$be = 0, $c$6$lcssa = 0, $c$7$be = 0, $c$744 = 0;
 var $c$8 = 0, $c$9$be = 0, $neg$0 = 0, $or$cond = 0, $or$cond17 = 0, $or$cond20 = 0, $or$cond26 = 0, $or$cond2628 = 0, $phitmp93 = 0, $x$068 = 0, $x$135 = 0, $x$253 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($base>>>0)>(36);
 if ($2) {
  $5 = (___errno_location()|0);
  HEAP32[$5>>2] = 22;
  $278 = 0;$279 = 0;
  tempRet0 = $278;
  STACKTOP = sp;return ($279|0);
 }
 $3 = (($f) + 4|0);
 $4 = (($f) + 100|0);
 while(1) {
  $6 = HEAP32[$3>>2]|0;
  $7 = HEAP32[$4>>2]|0;
  $8 = ($6>>>0)<($7>>>0);
  if ($8) {
   $9 = (($6) + 1|0);
   HEAP32[$3>>2] = $9;
   $10 = HEAP8[$6>>0]|0;
   $11 = $10&255;
   $13 = $11;
  } else {
   $12 = (___shgetc($f)|0);
   $13 = $12;
  }
  $14 = (_isspace($13)|0);
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  }
 }
 $16 = ($13|0)==(45);
 do {
  if ((($13|0) == 43) | (($13|0) == 45)) {
   $17 = $16 << 31 >> 31;
   $18 = HEAP32[$3>>2]|0;
   $19 = HEAP32[$4>>2]|0;
   $20 = ($18>>>0)<($19>>>0);
   if ($20) {
    $21 = (($18) + 1|0);
    HEAP32[$3>>2] = $21;
    $22 = HEAP8[$18>>0]|0;
    $23 = $22&255;
    $c$0 = $23;$neg$0 = $17;
    break;
   } else {
    $24 = (___shgetc($f)|0);
    $c$0 = $24;$neg$0 = $17;
    break;
   }
  } else {
   $c$0 = $13;$neg$0 = 0;
  }
 } while(0);
 $25 = ($base|0)==(0);
 $26 = $base & -17;
 $27 = ($26|0)==(0);
 $28 = ($c$0|0)==(48);
 $or$cond = $27 & $28;
 do {
  if ($or$cond) {
   $29 = HEAP32[$3>>2]|0;
   $30 = HEAP32[$4>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    $32 = (($29) + 1|0);
    HEAP32[$3>>2] = $32;
    $33 = HEAP8[$29>>0]|0;
    $34 = $33&255;
    $37 = $34;
   } else {
    $35 = (___shgetc($f)|0);
    $37 = $35;
   }
   $36 = $37 | 32;
   $38 = ($36|0)==(120);
   if (!($38)) {
    $$base = $25 ? 8 : $base;
    $$1 = $$base;$c$1 = $37;
    label = 32;
    break;
   }
   $39 = HEAP32[$3>>2]|0;
   $40 = HEAP32[$4>>2]|0;
   $41 = ($39>>>0)<($40>>>0);
   if ($41) {
    $42 = (($39) + 1|0);
    HEAP32[$3>>2] = $42;
    $43 = HEAP8[$39>>0]|0;
    $44 = $43&255;
    $46 = $44;
   } else {
    $45 = (___shgetc($f)|0);
    $46 = $45;
   }
   $$sum15 = (($46) + 1)|0;
   $47 = (3110336 + ($$sum15)|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48&255)>(15);
   if ($49) {
    $50 = HEAP32[$4>>2]|0;
    $51 = ($50|0)==(0|0);
    if (!($51)) {
     $52 = HEAP32[$3>>2]|0;
     $53 = (($52) + -1|0);
     HEAP32[$3>>2] = $53;
    }
    $54 = ($pok|0)==(0);
    if ($54) {
     ___shlim($f,0);
     $278 = 0;$279 = 0;
     tempRet0 = $278;
     STACKTOP = sp;return ($279|0);
    }
    if ($51) {
     $278 = 0;$279 = 0;
     tempRet0 = $278;
     STACKTOP = sp;return ($279|0);
    }
    $55 = HEAP32[$3>>2]|0;
    $56 = (($55) + -1|0);
    HEAP32[$3>>2] = $56;
    $278 = 0;$279 = 0;
    tempRet0 = $278;
    STACKTOP = sp;return ($279|0);
   } else {
    $$122 = 16;$c$123 = $46;
    label = 47;
   }
  } else {
   $$base16 = $25 ? 10 : $base;
   $$sum = (($c$0) + 1)|0;
   $57 = (3110336 + ($$sum)|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = $58&255;
   $60 = ($59>>>0)<($$base16>>>0);
   if ($60) {
    $$1 = $$base16;$c$1 = $c$0;
    label = 32;
   } else {
    $61 = HEAP32[$4>>2]|0;
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     $63 = HEAP32[$3>>2]|0;
     $64 = (($63) + -1|0);
     HEAP32[$3>>2] = $64;
    }
    ___shlim($f,0);
    $65 = (___errno_location()|0);
    HEAP32[$65>>2] = 22;
    $278 = 0;$279 = 0;
    tempRet0 = $278;
    STACKTOP = sp;return ($279|0);
   }
  }
 } while(0);
 if ((label|0) == 32) {
  $66 = ($$1|0)==(10);
  if ($66) {
   $67 = (($c$1) + -48)|0;
   $68 = ($67>>>0)<(10);
   if ($68) {
    $70 = $67;$x$068 = 0;
    while(1) {
     $69 = (($x$068) + ($70))|0;
     $71 = HEAP32[$3>>2]|0;
     $72 = HEAP32[$4>>2]|0;
     $73 = ($71>>>0)<($72>>>0);
     if ($73) {
      $74 = (($71) + 1|0);
      HEAP32[$3>>2] = $74;
      $75 = HEAP8[$71>>0]|0;
      $76 = $75&255;
      $c$2$be = $76;
     } else {
      $77 = (___shgetc($f)|0);
      $c$2$be = $77;
     }
     $78 = (($c$2$be) + -48)|0;
     $79 = ($78>>>0)<(10);
     $80 = ($69>>>0)<(429496729);
     $$ = $79 & $80;
     if (!($$)) {
      break;
     }
     $phitmp93 = ($69*10)|0;
     $70 = $78;$x$068 = $phitmp93;
    }
    $280 = $69;$281 = 0;$c$2$lcssa = $c$2$be;
   } else {
    $280 = 0;$281 = 0;$c$2$lcssa = $c$1;
   }
   $81 = (($c$2$lcssa) + -48)|0;
   $82 = ($81>>>0)<(10);
   if ($82) {
    $83 = $280;$84 = $281;$88 = $81;$c$359 = $c$2$lcssa;
    while(1) {
     $85 = (___muldi3(($83|0),($84|0),10,0)|0);
     $86 = tempRet0;
     $87 = ($88|0)<(0);
     $89 = $87 << 31 >> 31;
     $90 = $88 ^ -1;
     $91 = $89 ^ -1;
     $92 = ($86>>>0)>($91>>>0);
     $93 = ($86|0)==($91|0);
     $94 = ($85>>>0)>($90>>>0);
     $95 = $93 & $94;
     $96 = $92 | $95;
     if ($96) {
      $$lcssa = $88;$282 = $83;$283 = $84;$c$3$lcssa = $c$359;
      break;
     }
     $97 = (_i64Add(($85|0),($86|0),($88|0),($89|0))|0);
     $98 = tempRet0;
     $99 = HEAP32[$3>>2]|0;
     $100 = HEAP32[$4>>2]|0;
     $101 = ($99>>>0)<($100>>>0);
     if ($101) {
      $102 = (($99) + 1|0);
      HEAP32[$3>>2] = $102;
      $103 = HEAP8[$99>>0]|0;
      $104 = $103&255;
      $c$3$be = $104;
     } else {
      $105 = (___shgetc($f)|0);
      $c$3$be = $105;
     }
     $106 = (($c$3$be) + -48)|0;
     $107 = ($106>>>0)<(10);
     $108 = ($98>>>0)<(429496729);
     $109 = ($98|0)==(429496729);
     $110 = ($97>>>0)<(2576980378);
     $111 = $109 & $110;
     $112 = $108 | $111;
     $or$cond17 = $107 & $112;
     if ($or$cond17) {
      $83 = $97;$84 = $98;$88 = $106;$c$359 = $c$3$be;
     } else {
      $$lcssa = $106;$282 = $97;$283 = $98;$c$3$lcssa = $c$3$be;
      break;
     }
    }
    $113 = ($$lcssa>>>0)>(9);
    if ($113) {
     $252 = $283;$255 = $282;
    } else {
     $$121 = 10;$284 = $282;$285 = $283;$c$8 = $c$3$lcssa;
     label = 73;
    }
   } else {
    $252 = $281;$255 = $280;
   }
  } else {
   $$122 = $$1;$c$123 = $c$1;
   label = 47;
  }
 }
 L70: do {
  if ((label|0) == 47) {
   $114 = (($$122) + -1)|0;
   $115 = $114 & $$122;
   $116 = ($115|0)==(0);
   if ($116) {
    $121 = ($$122*23)|0;
    $122 = $121 >>> 5;
    $123 = $122 & 7;
    $124 = (3110600 + ($123)|0);
    $125 = HEAP8[$124>>0]|0;
    $126 = $125 << 24 >> 24;
    $$sum934 = (($c$123) + 1)|0;
    $127 = (3110336 + ($$sum934)|0);
    $128 = HEAP8[$127>>0]|0;
    $129 = $128&255;
    $130 = ($129>>>0)<($$122>>>0);
    if ($130) {
     $133 = $129;$x$135 = 0;
     while(1) {
      $131 = $x$135 << $126;
      $132 = $133 | $131;
      $134 = HEAP32[$3>>2]|0;
      $135 = HEAP32[$4>>2]|0;
      $136 = ($134>>>0)<($135>>>0);
      if ($136) {
       $137 = (($134) + 1|0);
       HEAP32[$3>>2] = $137;
       $138 = HEAP8[$134>>0]|0;
       $139 = $138&255;
       $c$4$be = $139;
      } else {
       $140 = (___shgetc($f)|0);
       $c$4$be = $140;
      }
      $$sum9 = (($c$4$be) + 1)|0;
      $141 = (3110336 + ($$sum9)|0);
      $142 = HEAP8[$141>>0]|0;
      $143 = $142&255;
      $144 = ($143>>>0)<($$122>>>0);
      $145 = ($132>>>0)<(134217728);
      $$18 = $144 & $145;
      if ($$18) {
       $133 = $143;$x$135 = $132;
      } else {
       break;
      }
     }
     $149 = $142;$152 = 0;$155 = $132;$c$4$lcssa = $c$4$be;
    } else {
     $149 = $128;$152 = 0;$155 = 0;$c$4$lcssa = $c$123;
    }
    $146 = (_bitshift64Lshr(-1,-1,($126|0))|0);
    $147 = tempRet0;
    $148 = $149&255;
    $150 = ($148>>>0)>=($$122>>>0);
    $151 = ($152>>>0)>($147>>>0);
    $153 = ($152|0)==($147|0);
    $154 = ($155>>>0)>($146>>>0);
    $156 = $153 & $154;
    $157 = $151 | $156;
    $or$cond2628 = $150 | $157;
    if ($or$cond2628) {
     $$121 = $$122;$284 = $155;$285 = $152;$c$8 = $c$4$lcssa;
     label = 73;
     break;
    } else {
     $158 = $155;$159 = $152;$163 = $149;
    }
    while(1) {
     $160 = (_bitshift64Shl(($158|0),($159|0),($126|0))|0);
     $161 = tempRet0;
     $162 = $163&255;
     $164 = $162 | $160;
     $165 = HEAP32[$3>>2]|0;
     $166 = HEAP32[$4>>2]|0;
     $167 = ($165>>>0)<($166>>>0);
     if ($167) {
      $168 = (($165) + 1|0);
      HEAP32[$3>>2] = $168;
      $169 = HEAP8[$165>>0]|0;
      $170 = $169&255;
      $c$5$be = $170;
     } else {
      $171 = (___shgetc($f)|0);
      $c$5$be = $171;
     }
     $$sum10 = (($c$5$be) + 1)|0;
     $172 = (3110336 + ($$sum10)|0);
     $173 = HEAP8[$172>>0]|0;
     $174 = $173&255;
     $175 = ($174>>>0)>=($$122>>>0);
     $176 = ($161>>>0)>($147>>>0);
     $177 = ($161|0)==($147|0);
     $178 = ($164>>>0)>($146>>>0);
     $179 = $177 & $178;
     $180 = $176 | $179;
     $or$cond26 = $175 | $180;
     if ($or$cond26) {
      $$121 = $$122;$284 = $164;$285 = $161;$c$8 = $c$5$be;
      label = 73;
      break L70;
     } else {
      $158 = $164;$159 = $161;$163 = $173;
     }
    }
   }
   $$sum1352 = (($c$123) + 1)|0;
   $117 = (3110336 + ($$sum1352)|0);
   $118 = HEAP8[$117>>0]|0;
   $119 = $118&255;
   $120 = ($119>>>0)<($$122>>>0);
   if ($120) {
    $183 = $119;$x$253 = 0;
    while(1) {
     $181 = Math_imul($x$253, $$122)|0;
     $182 = (($183) + ($181))|0;
     $184 = HEAP32[$3>>2]|0;
     $185 = HEAP32[$4>>2]|0;
     $186 = ($184>>>0)<($185>>>0);
     if ($186) {
      $187 = (($184) + 1|0);
      HEAP32[$3>>2] = $187;
      $188 = HEAP8[$184>>0]|0;
      $189 = $188&255;
      $c$6$be = $189;
     } else {
      $190 = (___shgetc($f)|0);
      $c$6$be = $190;
     }
     $$sum13 = (($c$6$be) + 1)|0;
     $191 = (3110336 + ($$sum13)|0);
     $192 = HEAP8[$191>>0]|0;
     $193 = $192&255;
     $194 = ($193>>>0)<($$122>>>0);
     $195 = ($182>>>0)<(119304647);
     $$19 = $194 & $195;
     if ($$19) {
      $183 = $193;$x$253 = $182;
     } else {
      break;
     }
    }
    $197 = $192;$286 = $182;$287 = 0;$c$6$lcssa = $c$6$be;
   } else {
    $197 = $118;$286 = 0;$287 = 0;$c$6$lcssa = $c$123;
   }
   $196 = $197&255;
   $198 = ($196>>>0)<($$122>>>0);
   if ($198) {
    $199 = (___udivdi3(-1,-1,($$122|0),0)|0);
    $200 = tempRet0;
    $202 = $287;$205 = $286;$211 = $197;$c$744 = $c$6$lcssa;
    while(1) {
     $201 = ($202>>>0)>($200>>>0);
     $203 = ($202|0)==($200|0);
     $204 = ($205>>>0)>($199>>>0);
     $206 = $203 & $204;
     $207 = $201 | $206;
     if ($207) {
      $$121 = $$122;$284 = $205;$285 = $202;$c$8 = $c$744;
      label = 73;
      break L70;
     }
     $208 = (___muldi3(($205|0),($202|0),($$122|0),0)|0);
     $209 = tempRet0;
     $210 = $211&255;
     $212 = $210 ^ -1;
     $213 = ($209>>>0)>(4294967295);
     $214 = ($209|0)==(-1);
     $215 = ($208>>>0)>($212>>>0);
     $216 = $214 & $215;
     $217 = $213 | $216;
     if ($217) {
      $$121 = $$122;$284 = $205;$285 = $202;$c$8 = $c$744;
      label = 73;
      break L70;
     }
     $218 = (_i64Add(($210|0),0,($208|0),($209|0))|0);
     $219 = tempRet0;
     $220 = HEAP32[$3>>2]|0;
     $221 = HEAP32[$4>>2]|0;
     $222 = ($220>>>0)<($221>>>0);
     if ($222) {
      $223 = (($220) + 1|0);
      HEAP32[$3>>2] = $223;
      $224 = HEAP8[$220>>0]|0;
      $225 = $224&255;
      $c$7$be = $225;
     } else {
      $226 = (___shgetc($f)|0);
      $c$7$be = $226;
     }
     $$sum14 = (($c$7$be) + 1)|0;
     $227 = (3110336 + ($$sum14)|0);
     $228 = HEAP8[$227>>0]|0;
     $229 = $228&255;
     $230 = ($229>>>0)<($$122>>>0);
     if ($230) {
      $202 = $219;$205 = $218;$211 = $228;$c$744 = $c$7$be;
     } else {
      $$121 = $$122;$284 = $218;$285 = $219;$c$8 = $c$7$be;
      label = 73;
      break;
     }
    }
   } else {
    $$121 = $$122;$284 = $286;$285 = $287;$c$8 = $c$6$lcssa;
    label = 73;
   }
  }
 } while(0);
 if ((label|0) == 73) {
  $$sum11 = (($c$8) + 1)|0;
  $231 = (3110336 + ($$sum11)|0);
  $232 = HEAP8[$231>>0]|0;
  $233 = $232&255;
  $234 = ($233>>>0)<($$121>>>0);
  if ($234) {
   while(1) {
    $235 = HEAP32[$3>>2]|0;
    $236 = HEAP32[$4>>2]|0;
    $237 = ($235>>>0)<($236>>>0);
    if ($237) {
     $238 = (($235) + 1|0);
     HEAP32[$3>>2] = $238;
     $239 = HEAP8[$235>>0]|0;
     $240 = $239&255;
     $c$9$be = $240;
    } else {
     $241 = (___shgetc($f)|0);
     $c$9$be = $241;
    }
    $$sum12 = (($c$9$be) + 1)|0;
    $242 = (3110336 + ($$sum12)|0);
    $243 = HEAP8[$242>>0]|0;
    $244 = $243&255;
    $245 = ($244>>>0)<($$121>>>0);
    if (!($245)) {
     break;
    }
   }
   $246 = (___errno_location()|0);
   HEAP32[$246>>2] = 34;
   $252 = $1;$255 = $0;
  } else {
   $252 = $285;$255 = $284;
  }
 }
 $247 = HEAP32[$4>>2]|0;
 $248 = ($247|0)==(0|0);
 if (!($248)) {
  $249 = HEAP32[$3>>2]|0;
  $250 = (($249) + -1|0);
  HEAP32[$3>>2] = $250;
 }
 $251 = ($252>>>0)<($1>>>0);
 $253 = ($252|0)==($1|0);
 $254 = ($255>>>0)<($0>>>0);
 $256 = $253 & $254;
 $257 = $251 | $256;
 if (!($257)) {
  $258 = $0 & 1;
  $259 = ($258|0)==(0);
  $260 = (0)==(0);
  $261 = $259 & $260;
  $262 = ($neg$0|0)==(0);
  $or$cond20 = $261 & $262;
  if ($or$cond20) {
   $263 = (___errno_location()|0);
   HEAP32[$263>>2] = 34;
   $264 = (_i64Add(($0|0),($1|0),-1,-1)|0);
   $265 = tempRet0;
   $278 = $265;$279 = $264;
   tempRet0 = $278;
   STACKTOP = sp;return ($279|0);
  }
  $266 = ($252>>>0)>($1>>>0);
  $267 = ($252|0)==($1|0);
  $268 = ($255>>>0)>($0>>>0);
  $269 = $267 & $268;
  $270 = $266 | $269;
  if ($270) {
   $271 = (___errno_location()|0);
   HEAP32[$271>>2] = 34;
   $278 = $1;$279 = $0;
   tempRet0 = $278;
   STACKTOP = sp;return ($279|0);
  }
 }
 $272 = ($neg$0|0)<(0);
 $273 = $272 << 31 >> 31;
 $274 = $255 ^ $neg$0;
 $275 = $252 ^ $273;
 $276 = (_i64Subtract(($274|0),($275|0),($neg$0|0),($273|0))|0);
 $277 = tempRet0;
 $278 = $277;$279 = $276;
 tempRet0 = $278;
 STACKTOP = sp;return ($279|0);
}
function ___floatscan($f,$prec,$pok) {
 $f = $f|0;
 $prec = $prec|0;
 $pok = $pok|0;
 var $$$i = 0, $$$i22 = 0, $$0 = 0.0, $$02$i = 0, $$08$i = 0, $$09$i = 0, $$1$be$i = 0, $$1$ph$i = 0, $$10$i = 0, $$14$i = 0, $$2$i = 0, $$3$be$i = 0, $$3$lcssa$i = 0, $$38$i = 0, $$388$i = 0, $$397$i = 0, $$in = 0, $$k$0$i = 0, $$lcssa43$i = 0, $$lnz$0$i = 0;
 var $$neg20$i = 0, $$pn$i = 0.0, $$pre$i = 0.0, $$pre$i17 = 0, $$pre$phi$iZ2D = 0.0, $$promoted$i = 0, $$sink$off0$us$i = 0, $$sink$off0$us53$i = 0, $$x$4$i = 0, $$y$3$i = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0;
 var $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0;
 var $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0;
 var $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0;
 var $18 = 0, $180 = 0, $181 = 0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0, $187 = 0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0;
 var $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0;
 var $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0;
 var $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0;
 var $251 = 0, $252 = 0, $253 = 0, $254 = 0.0, $255 = 0.0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0, $267 = 0, $268 = 0, $269 = 0;
 var $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0.0, $277 = 0.0, $278 = 0.0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0.0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0;
 var $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0.0;
 var $305 = 0.0, $306 = 0.0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0.0, $313 = 0.0, $314 = 0.0, $315 = 0.0, $316 = 0.0, $317 = 0.0, $318 = 0, $319 = 0, $32 = 0, $320 = 0.0, $321 = 0, $322 = 0;
 var $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0;
 var $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0;
 var $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0;
 var $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0;
 var $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0;
 var $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0.0, $418 = 0.0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0;
 var $431 = 0, $432 = 0, $433 = 0, $434 = 0.0, $435 = 0.0, $436 = 0.0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0.0, $447 = 0.0, $448 = 0.0, $449 = 0;
 var $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0.0, $459 = 0.0, $46 = 0, $460 = 0.0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0;
 var $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0.0, $473 = 0, $474 = 0.0, $475 = 0.0, $476 = 0, $477 = 0.0, $478 = 0, $479 = 0.0, $48 = 0, $480 = 0.0, $481 = 0, $482 = 0, $483 = 0, $484 = 0.0, $485 = 0.0;
 var $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = Math_fround(0), $490 = 0, $491 = 0.0, $492 = 0.0, $493 = 0.0, $494 = 0, $495 = 0, $496 = 0, $497 = 0.0, $498 = 0.0, $499 = 0, $5 = 0, $50 = Math_fround(0), $500 = 0, $501 = 0, $502 = 0;
 var $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0.0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0;
 var $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0;
 var $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0;
 var $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0;
 var $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0;
 var $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0;
 var $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0;
 var $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0.0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0;
 var $648 = 0.0, $649 = 0.0, $65 = 0, $650 = 0.0, $651 = 0, $652 = 0.0, $653 = 0.0, $654 = 0.0, $655 = 0.0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0;
 var $666 = 0.0, $667 = 0.0, $668 = 0.0, $669 = 0, $67 = 0, $670 = 0.0, $671 = 0.0, $672 = 0, $673 = 0, $674 = 0, $675 = 0.0, $676 = 0.0, $677 = 0.0, $678 = 0.0, $679 = 0, $68 = 0, $680 = 0, $681 = 0.0, $682 = 0, $683 = 0.0;
 var $684 = 0.0, $685 = 0.0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0.0, $691 = 0, $692 = 0, $693 = 0, $694 = 0.0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0;
 var $701 = 0.0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0.0, $707 = 0, $708 = 0, $709 = 0.0, $71 = 0, $710 = 0.0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0;
 var $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0$lcssa161$i = 0, $a$061$i = 0, $a$1$i = 0, $a$2$ph40$i = 0;
 var $a$3$i = 0, $a$3$i$ph = 0, $a$3$ph$i = 0, $a$427$i = 0, $a$5$i = 0, $bias$0$i = 0.0, $bias$07$i = 0.0, $bits$0$ph = 0, $brmerge = 0, $brmerge107 = 0, $c$0 = 0, $c$0$i = 0, $c$1$lcssa = 0, $c$1$ph$i = 0, $c$169 = 0, $c$2 = 0, $c$2$i = 0, $c$2$lcssa$i = 0, $c$364 = 0, $c$4 = 0;
 var $c$5 = 0, $c$6 = 0, $carry$063$i = 0, $carry1$0$us$i = 0, $carry1$0$us49$i = 0, $carry1$1$lcssa$lcssa$i = 0, $carry1$1$us$i = 0, $carry1$1$us54$i = 0, $carry3$030$i = 0, $cond$i = 0, $d$0$i = 0, $denormal$0$i = 0, $denormal$1$i = 0, $denormal$2$i = 0, $e2$0$ph$i = 0, $e2$0$us$i = 0, $e2$0$us44$i = 0, $e2$1$i = 0, $e2$1$i$ph = 0, $e2$1$ph$i = 0;
 var $e2$2$i = 0, $e2$3$i = 0, $emin$0$ph = 0, $exitcond$i = 0, $frac$0$i = 0.0, $frac$1$i = 0.0, $frac$2$i = 0.0, $gotdig$0$i = 0, $gotdig$0$i9 = 0, $gotdig$2$i = 0, $gotdig$2$i11 = 0, $gotdig$3$i = 0, $gotdig$3$lcssa$i = 0, $gotdig$381$i = 0, $gotdig$393$i = 0, $gotdig$4$i = 0, $gotrad$0$i = 0, $gotrad$0$i12 = 0, $gotrad$1$i = 0, $gotrad$1$lcssa$i = 0;
 var $gotrad$194$i = 0, $gotrad$2$i = 0, $gottail$0$i = 0, $gottail$1$i = 0, $gottail$2$i = 0, $i$0$lcssa = 0, $i$025$i = 0, $i$068 = 0, $i$1$i = 0, $i$166 = 0, $i$263 = 0, $i$3 = 0, $i$4 = 0, $j$0$lcssa$i = 0, $j$086$i = 0, $j$096$i = 0, $j$2$i = 0, $j$371$i = 0, $k$0$lcssa$i = 0, $k$084$i = 0;
 var $k$095$i = 0, $k$2$i = 0, $k$3$i = 0, $k$462$i = 0, $k$5$in$us$i = 0, $k$5$in$us48$i = 0, $k$5$us$i = 0, $k$5$us50$i = 0, $k$5$z$2$us$i = 0, $k$5$z$2$us56$i = 0, $k$628$i = 0, $lnz$0$lcssa$i = 0, $lnz$079$i = 0, $lnz$092$i = 0, $lnz$2$i = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i15 = 0;
 var $or$cond106$not = 0, $or$cond11$i = 0, $or$cond12$us$i = 0, $or$cond12$us55$i = 0, $or$cond13$i = 0, $or$cond15$i = 0, $or$cond16$i = 0, $or$cond17$i = 0, $or$cond3$i = 0, $or$cond3$i16 = 0, $or$cond4$i = 0, $or$cond5 = 0, $or$cond7$i = 0, $or$cond789$i = 0, $or$cond8 = 0, $rp$0$lcssa162$i = 0, $rp$060$i = 0, $rp$1$i18 = 0, $rp$2$ph38$i = 0, $rp$3$i$ph = 0;
 var $rp$3$ph33$i = 0, $rp$426$i = 0, $rp$5$i = 0, $scale$0$i = 0.0, $scale$1$i = 0.0, $scale$2$i = 0.0, $sign$0 = 0, $storemerge$i = 0, $sum$i = 0, $x$0$i = 0, $x$1$i = 0, $x$2$i = 0, $x$3$lcssa$i = 0, $x$313$i = 0, $x$4$lcssa$i = 0, $x$48$i = 0, $x$5$i = 0, $x$6$i = 0, $x$i = 0, $y$0$i = 0.0;
 var $y$1$i = 0.0, $y$1$i23 = 0.0, $y$2$i = 0.0, $y$2$i24 = 0.0, $y$3$i = 0.0, $y$3$lcssa$i = 0.0, $y$39$i = 0.0, $y$4$i = 0.0, $y$5$i = 0.0, $z$0$i = 0, $z$1$ph39$i = 0, $z$1$us$i = 0, $z$1$us45$i = 0, $z$2$us$i = 0, $z$2$us47$i = 0, $z$3$lcssa$lcssa$i = 0, $z$3$us$i = 0, $z$3$us57$i = 0, $z$4$i = 0, $z$5$ph$i = 0;
 var $z$7$1$i = 0, $z$7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $x$i = sp;
 if ((($prec|0) == 1)) {
  $bits$0$ph = 53;$emin$0$ph = -1074;
 } else if ((($prec|0) == 0)) {
  $bits$0$ph = 24;$emin$0$ph = -149;
 } else if ((($prec|0) == 2)) {
  $bits$0$ph = 53;$emin$0$ph = -1074;
 } else {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $0 = (($f) + 4|0);
 $1 = (($f) + 100|0);
 while(1) {
  $2 = HEAP32[$0>>2]|0;
  $3 = HEAP32[$1>>2]|0;
  $4 = ($2>>>0)<($3>>>0);
  if ($4) {
   $5 = (($2) + 1|0);
   HEAP32[$0>>2] = $5;
   $6 = HEAP8[$2>>0]|0;
   $7 = $6&255;
   $9 = $7;
  } else {
   $8 = (___shgetc($f)|0);
   $9 = $8;
  }
  $10 = (_isspace($9)|0);
  $11 = ($10|0)==(0);
  if ($11) {
   break;
  }
 }
 $12 = ($9|0)==(45);
 do {
  if ((($9|0) == 43) | (($9|0) == 45)) {
   $13 = $12&1;
   $14 = $13 << 1;
   $15 = (1 - ($14))|0;
   $16 = HEAP32[$0>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ($16>>>0)<($17>>>0);
   if ($18) {
    $19 = (($16) + 1|0);
    HEAP32[$0>>2] = $19;
    $20 = HEAP8[$16>>0]|0;
    $21 = $20&255;
    $c$0 = $21;$sign$0 = $15;
    break;
   } else {
    $22 = (___shgetc($f)|0);
    $c$0 = $22;$sign$0 = $15;
    break;
   }
  } else {
   $c$0 = $9;$sign$0 = 1;
  }
 } while(0);
 $c$169 = $c$0;$i$068 = 0;
 while(1) {
  $23 = $c$169 | 32;
  $24 = (3110616 + ($i$068)|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25 << 24 >> 24;
  $27 = ($23|0)==($26|0);
  if (!($27)) {
   $c$1$lcssa = $c$169;$i$0$lcssa = $i$068;
   break;
  }
  $28 = ($i$068>>>0)<(7);
  do {
   if ($28) {
    $29 = HEAP32[$0>>2]|0;
    $30 = HEAP32[$1>>2]|0;
    $31 = ($29>>>0)<($30>>>0);
    if ($31) {
     $32 = (($29) + 1|0);
     HEAP32[$0>>2] = $32;
     $33 = HEAP8[$29>>0]|0;
     $34 = $33&255;
     $c$2 = $34;
     break;
    } else {
     $35 = (___shgetc($f)|0);
     $c$2 = $35;
     break;
    }
   } else {
    $c$2 = $c$169;
   }
  } while(0);
  $36 = (($i$068) + 1)|0;
  $37 = ($36>>>0)<(8);
  if ($37) {
   $c$169 = $c$2;$i$068 = $36;
  } else {
   $c$1$lcssa = $c$2;$i$0$lcssa = $36;
   break;
  }
 }
 do {
  if ((($i$0$lcssa|0) == 3)) {
   label = 23;
  } else if (!((($i$0$lcssa|0) == 8))) {
   $38 = ($i$0$lcssa>>>0)<(4);
   $39 = ($pok|0)==(0);
   $or$cond = $38 | $39;
   if (!($or$cond)) {
    $40 = ($i$0$lcssa|0)==(8);
    if ($40) {
     break;
    } else {
     label = 23;
     break;
    }
   }
   $52 = ($i$0$lcssa|0)==(0);
   L34: do {
    if ($52) {
     $c$364 = $c$1$lcssa;$i$263 = 0;
     while(1) {
      $53 = $c$364 | 32;
      $54 = (3110632 + ($i$263)|0);
      $55 = HEAP8[$54>>0]|0;
      $56 = $55 << 24 >> 24;
      $57 = ($53|0)==($56|0);
      if (!($57)) {
       $c$5 = $c$364;$i$3 = $i$263;
       break L34;
      }
      $58 = ($i$263>>>0)<(2);
      do {
       if ($58) {
        $59 = HEAP32[$0>>2]|0;
        $60 = HEAP32[$1>>2]|0;
        $61 = ($59>>>0)<($60>>>0);
        if ($61) {
         $62 = (($59) + 1|0);
         HEAP32[$0>>2] = $62;
         $63 = HEAP8[$59>>0]|0;
         $64 = $63&255;
         $c$4 = $64;
         break;
        } else {
         $65 = (___shgetc($f)|0);
         $c$4 = $65;
         break;
        }
       } else {
        $c$4 = $c$364;
       }
      } while(0);
      $66 = (($i$263) + 1)|0;
      $67 = ($66>>>0)<(3);
      if ($67) {
       $c$364 = $c$4;$i$263 = $66;
      } else {
       $c$5 = $c$4;$i$3 = $66;
       break;
      }
     }
    } else {
     $c$5 = $c$1$lcssa;$i$3 = $i$0$lcssa;
    }
   } while(0);
   if ((($i$3|0) == 3)) {
    $68 = HEAP32[$0>>2]|0;
    $69 = HEAP32[$1>>2]|0;
    $70 = ($68>>>0)<($69>>>0);
    if ($70) {
     $71 = (($68) + 1|0);
     HEAP32[$0>>2] = $71;
     $72 = HEAP8[$68>>0]|0;
     $73 = $72&255;
     $76 = $73;
    } else {
     $74 = (___shgetc($f)|0);
     $76 = $74;
    }
    $75 = ($76|0)==(40);
    if ($75) {
     $i$4 = 1;
    } else {
     $77 = HEAP32[$1>>2]|0;
     $78 = ($77|0)==(0|0);
     if ($78) {
      $$0 = nan;
      STACKTOP = sp;return (+$$0);
     }
     $79 = HEAP32[$0>>2]|0;
     $80 = (($79) + -1|0);
     HEAP32[$0>>2] = $80;
     $$0 = nan;
     STACKTOP = sp;return (+$$0);
    }
    while(1) {
     $81 = HEAP32[$0>>2]|0;
     $82 = HEAP32[$1>>2]|0;
     $83 = ($81>>>0)<($82>>>0);
     if ($83) {
      $84 = (($81) + 1|0);
      HEAP32[$0>>2] = $84;
      $85 = HEAP8[$81>>0]|0;
      $86 = $85&255;
      $89 = $86;
     } else {
      $87 = (___shgetc($f)|0);
      $89 = $87;
     }
     $88 = (($89) + -48)|0;
     $90 = ($88>>>0)<(10);
     $91 = (($89) + -65)|0;
     $92 = ($91>>>0)<(26);
     $or$cond8 = $90 | $92;
     if (!($or$cond8)) {
      $93 = (($89) + -97)|0;
      $94 = ($93>>>0)<(26);
      $95 = ($89|0)==(95);
      $or$cond5 = $94 | $95;
      if (!($or$cond5)) {
       break;
      }
     }
     $107 = (($i$4) + 1)|0;
     $i$4 = $107;
    }
    $96 = ($89|0)==(41);
    if ($96) {
     $$0 = nan;
     STACKTOP = sp;return (+$$0);
    }
    $97 = HEAP32[$1>>2]|0;
    $98 = ($97|0)==(0|0);
    if (!($98)) {
     $99 = HEAP32[$0>>2]|0;
     $100 = (($99) + -1|0);
     HEAP32[$0>>2] = $100;
    }
    if ($39) {
     $102 = (___errno_location()|0);
     HEAP32[$102>>2] = 22;
     ___shlim($f,0);
     $$0 = 0.0;
     STACKTOP = sp;return (+$$0);
    }
    $101 = ($i$4|0)==(0);
    $brmerge107 = $101 | $98;
    if ($brmerge107) {
     $$0 = nan;
     STACKTOP = sp;return (+$$0);
    } else {
     $$in = $i$4;
    }
    while(1) {
     $103 = (($$in) + -1)|0;
     $104 = HEAP32[$0>>2]|0;
     $105 = (($104) + -1|0);
     HEAP32[$0>>2] = $105;
     $106 = ($103|0)==(0);
     if ($106) {
      $$0 = nan;
      break;
     } else {
      $$in = $103;
     }
    }
    STACKTOP = sp;return (+$$0);
   } else if ((($i$3|0) == 0)) {
    $113 = ($c$5|0)==(48);
    do {
     if ($113) {
      $114 = HEAP32[$0>>2]|0;
      $115 = HEAP32[$1>>2]|0;
      $116 = ($114>>>0)<($115>>>0);
      if ($116) {
       $117 = (($114) + 1|0);
       HEAP32[$0>>2] = $117;
       $118 = HEAP8[$114>>0]|0;
       $119 = $118&255;
       $122 = $119;
      } else {
       $120 = (___shgetc($f)|0);
       $122 = $120;
      }
      $121 = $122 | 32;
      $123 = ($121|0)==(120);
      if (!($123)) {
       $321 = HEAP32[$1>>2]|0;
       $322 = ($321|0)==(0|0);
       if ($322) {
        $c$6 = 48;
        break;
       }
       $323 = HEAP32[$0>>2]|0;
       $324 = (($323) + -1|0);
       HEAP32[$0>>2] = $324;
       $c$6 = 48;
       break;
      }
      $124 = HEAP32[$0>>2]|0;
      $125 = HEAP32[$1>>2]|0;
      $126 = ($124>>>0)<($125>>>0);
      if ($126) {
       $127 = (($124) + 1|0);
       HEAP32[$0>>2] = $127;
       $128 = HEAP8[$124>>0]|0;
       $129 = $128&255;
       $c$0$i = $129;$gotdig$0$i = 0;
      } else {
       $130 = (___shgetc($f)|0);
       $c$0$i = $130;$gotdig$0$i = 0;
      }
      while(1) {
       if ((($c$0$i|0) == 46)) {
        label = 70;
        break;
       } else if (!((($c$0$i|0) == 48))) {
        $169 = 0;$172 = 0;$212 = 0;$214 = 0;$c$2$i = $c$0$i;$gotdig$2$i = $gotdig$0$i;$gotrad$0$i = 0;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
        break;
       }
       $131 = HEAP32[$0>>2]|0;
       $132 = HEAP32[$1>>2]|0;
       $133 = ($131>>>0)<($132>>>0);
       if ($133) {
        $134 = (($131) + 1|0);
        HEAP32[$0>>2] = $134;
        $135 = HEAP8[$131>>0]|0;
        $136 = $135&255;
        $c$0$i = $136;$gotdig$0$i = 1;
        continue;
       } else {
        $137 = (___shgetc($f)|0);
        $c$0$i = $137;$gotdig$0$i = 1;
        continue;
       }
      }
      L107: do {
       if ((label|0) == 70) {
        $138 = HEAP32[$0>>2]|0;
        $139 = HEAP32[$1>>2]|0;
        $140 = ($138>>>0)<($139>>>0);
        if ($140) {
         $141 = (($138) + 1|0);
         HEAP32[$0>>2] = $141;
         $142 = HEAP8[$138>>0]|0;
         $143 = $142&255;
         $c$1$ph$i = $143;
        } else {
         $144 = (___shgetc($f)|0);
         $c$1$ph$i = $144;
        }
        $145 = ($c$1$ph$i|0)==(48);
        if ($145) {
         $155 = -1;$156 = -1;
         while(1) {
          $146 = HEAP32[$0>>2]|0;
          $147 = HEAP32[$1>>2]|0;
          $148 = ($146>>>0)<($147>>>0);
          if ($148) {
           $149 = (($146) + 1|0);
           HEAP32[$0>>2] = $149;
           $150 = HEAP8[$146>>0]|0;
           $151 = $150&255;
           $154 = $151;
          } else {
           $152 = (___shgetc($f)|0);
           $154 = $152;
          }
          $153 = ($154|0)==(48);
          if (!($153)) {
           $169 = 0;$172 = 0;$212 = $155;$214 = $156;$c$2$i = $154;$gotdig$2$i = 1;$gotrad$0$i = 1;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
           break L107;
          }
          $157 = (_i64Add(($155|0),($156|0),-1,-1)|0);
          $158 = tempRet0;
          $155 = $157;$156 = $158;
         }
        } else {
         $169 = 0;$172 = 0;$212 = 0;$214 = 0;$c$2$i = $c$1$ph$i;$gotdig$2$i = $gotdig$0$i;$gotrad$0$i = 1;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
        }
       }
      } while(0);
      L120: while(1) {
       $159 = (($c$2$i) + -48)|0;
       $160 = ($159>>>0)<(10);
       do {
        if ($160) {
         $d$0$i = $159;
         label = 84;
        } else {
         $161 = $c$2$i | 32;
         $162 = (($161) + -97)|0;
         $163 = ($162>>>0)<(6);
         $164 = ($c$2$i|0)==(46);
         $or$cond$i = $163 | $164;
         if (!($or$cond$i)) {
          $c$2$lcssa$i = $c$2$i;
          break L120;
         }
         if ($164) {
          $165 = ($gotrad$0$i|0)==(0);
          if ($165) {
           $712 = $172;$713 = $169;$714 = $172;$715 = $169;$gotdig$3$i = $gotdig$2$i;$gotrad$1$i = 1;$gottail$2$i = $gottail$0$i;$scale$2$i = $scale$0$i;$x$2$i = $x$0$i;$y$2$i = $y$0$i;
           break;
          } else {
           $c$2$lcssa$i = 46;
           break L120;
          }
         } else {
          $166 = ($c$2$i|0)>(57);
          $167 = (($161) + -87)|0;
          $$38$i = $166 ? $167 : $159;
          $d$0$i = $$38$i;
          label = 84;
          break;
         }
        }
       } while(0);
       if ((label|0) == 84) {
        label = 0;
        $168 = ($169|0)<(0);
        $170 = ($169|0)==(0);
        $171 = ($172>>>0)<(8);
        $173 = $170 & $171;
        $174 = $168 | $173;
        do {
         if ($174) {
          $175 = $x$0$i << 4;
          $176 = (($d$0$i) + ($175))|0;
          $gottail$1$i = $gottail$0$i;$scale$1$i = $scale$0$i;$x$1$i = $176;$y$1$i = $y$0$i;
         } else {
          $177 = ($169|0)<(0);
          $178 = ($169|0)==(0);
          $179 = ($172>>>0)<(14);
          $180 = $178 & $179;
          $181 = $177 | $180;
          if ($181) {
           $182 = (+($d$0$i|0));
           $183 = $scale$0$i * 0.0625;
           $184 = $183 * $182;
           $185 = $y$0$i + $184;
           $gottail$1$i = $gottail$0$i;$scale$1$i = $183;$x$1$i = $x$0$i;$y$1$i = $185;
           break;
          }
          $186 = ($d$0$i|0)!=(0);
          $187 = ($gottail$0$i|0)==(0);
          $or$cond3$i = $186 & $187;
          if ($or$cond3$i) {
           $188 = $scale$0$i * 0.5;
           $189 = $y$0$i + $188;
           $gottail$1$i = 1;$scale$1$i = $scale$0$i;$x$1$i = $x$0$i;$y$1$i = $189;
          } else {
           $gottail$1$i = $gottail$0$i;$scale$1$i = $scale$0$i;$x$1$i = $x$0$i;$y$1$i = $y$0$i;
          }
         }
        } while(0);
        $190 = (_i64Add(($172|0),($169|0),1,0)|0);
        $191 = tempRet0;
        $712 = $212;$713 = $214;$714 = $190;$715 = $191;$gotdig$3$i = 1;$gotrad$1$i = $gotrad$0$i;$gottail$2$i = $gottail$1$i;$scale$2$i = $scale$1$i;$x$2$i = $x$1$i;$y$2$i = $y$1$i;
       }
       $192 = HEAP32[$0>>2]|0;
       $193 = HEAP32[$1>>2]|0;
       $194 = ($192>>>0)<($193>>>0);
       if ($194) {
        $195 = (($192) + 1|0);
        HEAP32[$0>>2] = $195;
        $196 = HEAP8[$192>>0]|0;
        $197 = $196&255;
        $169 = $715;$172 = $714;$212 = $712;$214 = $713;$c$2$i = $197;$gotdig$2$i = $gotdig$3$i;$gotrad$0$i = $gotrad$1$i;$gottail$0$i = $gottail$2$i;$scale$0$i = $scale$2$i;$x$0$i = $x$2$i;$y$0$i = $y$2$i;
        continue;
       } else {
        $198 = (___shgetc($f)|0);
        $169 = $715;$172 = $714;$212 = $712;$214 = $713;$c$2$i = $198;$gotdig$2$i = $gotdig$3$i;$gotrad$0$i = $gotrad$1$i;$gottail$0$i = $gottail$2$i;$scale$0$i = $scale$2$i;$x$0$i = $x$2$i;$y$0$i = $y$2$i;
        continue;
       }
      }
      $199 = ($gotdig$2$i|0)==(0);
      if ($199) {
       $200 = HEAP32[$1>>2]|0;
       $201 = ($200|0)==(0|0);
       if (!($201)) {
        $202 = HEAP32[$0>>2]|0;
        $203 = (($202) + -1|0);
        HEAP32[$0>>2] = $203;
       }
       if ($39) {
        ___shlim($f,0);
       } else {
        if (!($201)) {
         $204 = HEAP32[$0>>2]|0;
         $205 = (($204) + -1|0);
         HEAP32[$0>>2] = $205;
         $206 = ($gotrad$0$i|0)==(0);
         if (!($206)) {
          $207 = (($204) + -2|0);
          HEAP32[$0>>2] = $207;
         }
        }
       }
       $208 = (+($sign$0|0));
       $209 = $208 * 0.0;
       $$0 = $209;
       STACKTOP = sp;return (+$$0);
      }
      $210 = ($gotrad$0$i|0)==(0);
      $211 = $210 ? $172 : $212;
      $213 = $210 ? $169 : $214;
      $215 = ($169|0)<(0);
      $216 = ($169|0)==(0);
      $217 = ($172>>>0)<(8);
      $218 = $216 & $217;
      $219 = $215 | $218;
      if ($219) {
       $221 = $172;$222 = $169;$x$313$i = $x$0$i;
       while(1) {
        $220 = $x$313$i << 4;
        $223 = (_i64Add(($221|0),($222|0),1,0)|0);
        $224 = tempRet0;
        $225 = ($224|0)<(0);
        $226 = ($224|0)==(0);
        $227 = ($223>>>0)<(8);
        $228 = $226 & $227;
        $229 = $225 | $228;
        if ($229) {
         $221 = $223;$222 = $224;$x$313$i = $220;
        } else {
         $x$3$lcssa$i = $220;
         break;
        }
       }
      } else {
       $x$3$lcssa$i = $x$0$i;
      }
      $230 = $c$2$lcssa$i | 32;
      $231 = ($230|0)==(112);
      do {
       if ($231) {
        $232 = (_scanexp($f,$pok)|0);
        $233 = tempRet0;
        $234 = ($232|0)==(0);
        $235 = ($233|0)==(-2147483648);
        $236 = $234 & $235;
        if ($236) {
         if ($39) {
          ___shlim($f,0);
          $$0 = 0.0;
          STACKTOP = sp;return (+$$0);
         } else {
          $237 = HEAP32[$1>>2]|0;
          $238 = ($237|0)==(0|0);
          if ($238) {
           $249 = 0;$250 = 0;
           break;
          }
          $239 = HEAP32[$0>>2]|0;
          $240 = (($239) + -1|0);
          HEAP32[$0>>2] = $240;
          $249 = 0;$250 = 0;
          break;
         }
        } else {
         $249 = $232;$250 = $233;
        }
       } else {
        $241 = HEAP32[$1>>2]|0;
        $242 = ($241|0)==(0|0);
        if ($242) {
         $249 = 0;$250 = 0;
        } else {
         $243 = HEAP32[$0>>2]|0;
         $244 = (($243) + -1|0);
         HEAP32[$0>>2] = $244;
         $249 = 0;$250 = 0;
        }
       }
      } while(0);
      $245 = (_bitshift64Shl(($211|0),($213|0),2)|0);
      $246 = tempRet0;
      $247 = (_i64Add(($245|0),($246|0),-32,-1)|0);
      $248 = tempRet0;
      $251 = (_i64Add(($247|0),($248|0),($249|0),($250|0))|0);
      $252 = tempRet0;
      $253 = ($x$3$lcssa$i|0)==(0);
      if ($253) {
       $254 = (+($sign$0|0));
       $255 = $254 * 0.0;
       $$0 = $255;
       STACKTOP = sp;return (+$$0);
      }
      $256 = (0 - ($emin$0$ph))|0;
      $257 = ($252|0)>(0);
      $258 = ($252|0)==(0);
      $259 = ($251>>>0)>($256>>>0);
      $260 = $258 & $259;
      $261 = $257 | $260;
      if ($261) {
       $262 = (___errno_location()|0);
       HEAP32[$262>>2] = 34;
       $263 = (+($sign$0|0));
       $264 = $263 * 1.79769313486231570815E+308;
       $265 = $264 * 1.79769313486231570815E+308;
       $$0 = $265;
       STACKTOP = sp;return (+$$0);
      }
      $266 = (($emin$0$ph) + -106)|0;
      $267 = ($266|0)<(0);
      $268 = $267 << 31 >> 31;
      $269 = ($252|0)<($268|0);
      $270 = ($252|0)==($268|0);
      $271 = ($251>>>0)<($266>>>0);
      $272 = $270 & $271;
      $273 = $269 | $272;
      if ($273) {
       $275 = (___errno_location()|0);
       HEAP32[$275>>2] = 34;
       $276 = (+($sign$0|0));
       $277 = $276 * 2.22507385850720138309E-308;
       $278 = $277 * 2.22507385850720138309E-308;
       $$0 = $278;
       STACKTOP = sp;return (+$$0);
      }
      $274 = ($x$3$lcssa$i|0)>(-1);
      if ($274) {
       $283 = $251;$284 = $252;$x$48$i = $x$3$lcssa$i;$y$39$i = $y$0$i;
       while(1) {
        $279 = !($y$39$i >= 0.5);
        $280 = $x$48$i << 1;
        if ($279) {
         $$pn$i = $y$39$i;$x$5$i = $280;
        } else {
         $281 = $280 | 1;
         $282 = $y$39$i + -1.0;
         $$pn$i = $282;$x$5$i = $281;
        }
        $y$4$i = $y$39$i + $$pn$i;
        $285 = (_i64Add(($283|0),($284|0),-1,-1)|0);
        $286 = tempRet0;
        $287 = ($x$5$i|0)>(-1);
        if ($287) {
         $283 = $285;$284 = $286;$x$48$i = $x$5$i;$y$39$i = $y$4$i;
        } else {
         $292 = $285;$293 = $286;$x$4$lcssa$i = $x$5$i;$y$3$lcssa$i = $y$4$i;
         break;
        }
       }
      } else {
       $292 = $251;$293 = $252;$x$4$lcssa$i = $x$3$lcssa$i;$y$3$lcssa$i = $y$0$i;
      }
      $288 = ($emin$0$ph|0)<(0);
      $289 = $288 << 31 >> 31;
      $290 = (_i64Subtract(32,0,($emin$0$ph|0),($289|0))|0);
      $291 = tempRet0;
      $294 = (_i64Add(($292|0),($293|0),($290|0),($291|0))|0);
      $295 = tempRet0;
      $296 = (0)>($295|0);
      $297 = (0)==($295|0);
      $298 = ($bits$0$ph>>>0)>($294>>>0);
      $299 = $297 & $298;
      $300 = $296 | $299;
      if ($300) {
       $301 = ($294|0)<(0);
       $$$i = $301 ? 0 : $294;
       $$02$i = $$$i;
      } else {
       $$02$i = $bits$0$ph;
      }
      $302 = ($$02$i|0)<(53);
      do {
       if ($302) {
        $303 = (84 - ($$02$i))|0;
        $304 = (+_scalbn(1.0,$303));
        $305 = (+($sign$0|0));
        $306 = (+_copysignl((+$304),(+$305)));
        $307 = ($$02$i|0)<(32);
        $308 = $y$3$lcssa$i != 0.0;
        $or$cond4$i = $307 & $308;
        if (!($or$cond4$i)) {
         $$pre$phi$iZ2D = $305;$bias$07$i = $306;$x$6$i = $x$4$lcssa$i;$y$5$i = $y$3$lcssa$i;
         break;
        }
        $309 = $x$4$lcssa$i & 1;
        $310 = ($309|0)==(0);
        $311 = $309 ^ 1;
        $$x$4$i = (($311) + ($x$4$lcssa$i))|0;
        $$y$3$i = $310 ? 0.0 : $y$3$lcssa$i;
        $$pre$phi$iZ2D = $305;$bias$07$i = $306;$x$6$i = $$x$4$i;$y$5$i = $$y$3$i;
       } else {
        $$pre$i = (+($sign$0|0));
        $$pre$phi$iZ2D = $$pre$i;$bias$07$i = 0.0;$x$6$i = $x$4$lcssa$i;$y$5$i = $y$3$lcssa$i;
       }
      } while(0);
      $312 = (+($x$6$i>>>0));
      $313 = $$pre$phi$iZ2D * $312;
      $314 = $bias$07$i + $313;
      $315 = $$pre$phi$iZ2D * $y$5$i;
      $316 = $315 + $314;
      $317 = $316 - $bias$07$i;
      $318 = $317 != 0.0;
      if (!($318)) {
       $319 = (___errno_location()|0);
       HEAP32[$319>>2] = 34;
      }
      $320 = (+_scalbnl($317,$292));
      $$0 = $320;
      STACKTOP = sp;return (+$$0);
     } else {
      $c$6 = $c$5;
     }
    } while(0);
    $sum$i = (($emin$0$ph) + ($bits$0$ph))|0;
    $325 = (0 - ($sum$i))|0;
    $$08$i = $c$6;$gotdig$0$i9 = 0;
    while(1) {
     if ((($$08$i|0) == 46)) {
      label = 139;
      break;
     } else if (!((($$08$i|0) == 48))) {
      $$2$i = $$08$i;$716 = 0;$717 = 0;$gotdig$2$i11 = $gotdig$0$i9;$gotrad$0$i12 = 0;
      break;
     }
     $326 = HEAP32[$0>>2]|0;
     $327 = HEAP32[$1>>2]|0;
     $328 = ($326>>>0)<($327>>>0);
     if ($328) {
      $329 = (($326) + 1|0);
      HEAP32[$0>>2] = $329;
      $330 = HEAP8[$326>>0]|0;
      $331 = $330&255;
      $$08$i = $331;$gotdig$0$i9 = 1;
      continue;
     } else {
      $332 = (___shgetc($f)|0);
      $$08$i = $332;$gotdig$0$i9 = 1;
      continue;
     }
    }
    L209: do {
     if ((label|0) == 139) {
      $333 = HEAP32[$0>>2]|0;
      $334 = HEAP32[$1>>2]|0;
      $335 = ($333>>>0)<($334>>>0);
      if ($335) {
       $336 = (($333) + 1|0);
       HEAP32[$0>>2] = $336;
       $337 = HEAP8[$333>>0]|0;
       $338 = $337&255;
       $$1$ph$i = $338;
      } else {
       $339 = (___shgetc($f)|0);
       $$1$ph$i = $339;
      }
      $340 = ($$1$ph$i|0)==(48);
      if ($340) {
       $349 = -1;$350 = -1;
       while(1) {
        $341 = HEAP32[$0>>2]|0;
        $342 = HEAP32[$1>>2]|0;
        $343 = ($341>>>0)<($342>>>0);
        if ($343) {
         $344 = (($341) + 1|0);
         HEAP32[$0>>2] = $344;
         $345 = HEAP8[$341>>0]|0;
         $346 = $345&255;
         $$1$be$i = $346;
        } else {
         $347 = (___shgetc($f)|0);
         $$1$be$i = $347;
        }
        $348 = ($$1$be$i|0)==(48);
        if (!($348)) {
         $$2$i = $$1$be$i;$716 = $349;$717 = $350;$gotdig$2$i11 = 1;$gotrad$0$i12 = 1;
         break L209;
        }
        $351 = (_i64Add(($349|0),($350|0),-1,-1)|0);
        $352 = tempRet0;
        $349 = $351;$350 = $352;
       }
      } else {
       $$2$i = $$1$ph$i;$716 = 0;$717 = 0;$gotdig$2$i11 = $gotdig$0$i9;$gotrad$0$i12 = 1;
      }
     }
    } while(0);
    HEAP32[$x$i>>2] = 0;
    $353 = (($$2$i) + -48)|0;
    $354 = ($353>>>0)<(10);
    $355 = ($$2$i|0)==(46);
    $or$cond789$i = $354 | $355;
    L223: do {
     if ($or$cond789$i) {
      $356 = (($x$i) + 496|0);
      $$397$i = $$2$i;$358 = 0;$359 = 0;$718 = $355;$719 = $353;$720 = $716;$721 = $717;$gotdig$393$i = $gotdig$2$i11;$gotrad$194$i = $gotrad$0$i12;$j$096$i = 0;$k$095$i = 0;$lnz$092$i = 0;
      while(1) {
       do {
        if ($718) {
         $cond$i = ($gotrad$194$i|0)==(0);
         if ($cond$i) {
          $722 = $358;$723 = $359;$724 = $358;$725 = $359;$gotdig$4$i = $gotdig$393$i;$gotrad$2$i = 1;$j$2$i = $j$096$i;$k$2$i = $k$095$i;$lnz$2$i = $lnz$092$i;
         } else {
          $$388$i = $$397$i;$405 = $720;$406 = $721;$421 = $358;$424 = $359;$gotdig$381$i = $gotdig$393$i;$j$086$i = $j$096$i;$k$084$i = $k$095$i;$lnz$079$i = $lnz$092$i;
          break L223;
         }
        } else {
         $357 = ($k$095$i|0)<(125);
         $360 = (_i64Add(($358|0),($359|0),1,0)|0);
         $361 = tempRet0;
         $362 = ($$397$i|0)!=(48);
         if (!($357)) {
          if (!($362)) {
           $722 = $720;$723 = $721;$724 = $360;$725 = $361;$gotdig$4$i = $gotdig$393$i;$gotrad$2$i = $gotrad$194$i;$j$2$i = $j$096$i;$k$2$i = $k$095$i;$lnz$2$i = $lnz$092$i;
           break;
          }
          $372 = HEAP32[$356>>2]|0;
          $373 = $372 | 1;
          HEAP32[$356>>2] = $373;
          $722 = $720;$723 = $721;$724 = $360;$725 = $361;$gotdig$4$i = $gotdig$393$i;$gotrad$2$i = $gotrad$194$i;$j$2$i = $j$096$i;$k$2$i = $k$095$i;$lnz$2$i = $lnz$092$i;
          break;
         }
         $$lnz$0$i = $362 ? $360 : $lnz$092$i;
         $363 = ($j$096$i|0)==(0);
         $364 = (($x$i) + ($k$095$i<<2)|0);
         if ($363) {
          $storemerge$i = $719;
         } else {
          $365 = HEAP32[$364>>2]|0;
          $366 = ($365*10)|0;
          $367 = (($$397$i) + -48)|0;
          $368 = (($367) + ($366))|0;
          $storemerge$i = $368;
         }
         HEAP32[$364>>2] = $storemerge$i;
         $369 = (($j$096$i) + 1)|0;
         $370 = ($369|0)==(9);
         $371 = $370&1;
         $$k$0$i = (($371) + ($k$095$i))|0;
         $$10$i = $370 ? 0 : $369;
         $722 = $720;$723 = $721;$724 = $360;$725 = $361;$gotdig$4$i = 1;$gotrad$2$i = $gotrad$194$i;$j$2$i = $$10$i;$k$2$i = $$k$0$i;$lnz$2$i = $$lnz$0$i;
        }
       } while(0);
       $374 = HEAP32[$0>>2]|0;
       $375 = HEAP32[$1>>2]|0;
       $376 = ($374>>>0)<($375>>>0);
       if ($376) {
        $377 = (($374) + 1|0);
        HEAP32[$0>>2] = $377;
        $378 = HEAP8[$374>>0]|0;
        $379 = $378&255;
        $$3$be$i = $379;
       } else {
        $380 = (___shgetc($f)|0);
        $$3$be$i = $380;
       }
       $381 = (($$3$be$i) + -48)|0;
       $382 = ($381>>>0)<(10);
       $383 = ($$3$be$i|0)==(46);
       $or$cond7$i = $382 | $383;
       if ($or$cond7$i) {
        $$397$i = $$3$be$i;$358 = $724;$359 = $725;$718 = $383;$719 = $381;$720 = $722;$721 = $723;$gotdig$393$i = $gotdig$4$i;$gotrad$194$i = $gotrad$2$i;$j$096$i = $j$2$i;$k$095$i = $k$2$i;$lnz$092$i = $lnz$2$i;
       } else {
        $$3$lcssa$i = $$3$be$i;$386 = $724;$387 = $722;$389 = $725;$390 = $723;$gotdig$3$lcssa$i = $gotdig$4$i;$gotrad$1$lcssa$i = $gotrad$2$i;$j$0$lcssa$i = $j$2$i;$k$0$lcssa$i = $k$2$i;$lnz$0$lcssa$i = $lnz$2$i;
        label = 162;
        break;
       }
      }
     } else {
      $$3$lcssa$i = $$2$i;$386 = 0;$387 = $716;$389 = 0;$390 = $717;$gotdig$3$lcssa$i = $gotdig$2$i11;$gotrad$1$lcssa$i = $gotrad$0$i12;$j$0$lcssa$i = 0;$k$0$lcssa$i = 0;$lnz$0$lcssa$i = 0;
      label = 162;
     }
    } while(0);
    if ((label|0) == 162) {
     $384 = ($gotrad$1$lcssa$i|0)==(0);
     $385 = $384 ? $386 : $387;
     $388 = $384 ? $389 : $390;
     $$388$i = $$3$lcssa$i;$405 = $385;$406 = $388;$421 = $386;$424 = $389;$gotdig$381$i = $gotdig$3$lcssa$i;$j$086$i = $j$0$lcssa$i;$k$084$i = $k$0$lcssa$i;$lnz$079$i = $lnz$0$lcssa$i;
    }
    $391 = ($gotdig$381$i|0)!=(0);
    if ($391) {
     $392 = $$388$i | 32;
     $393 = ($392|0)==(101);
     if ($393) {
      $394 = (_scanexp($f,$pok)|0);
      $395 = tempRet0;
      $396 = ($394|0)==(0);
      $397 = ($395|0)==(-2147483648);
      $398 = $396 & $397;
      do {
       if ($398) {
        if ($39) {
         ___shlim($f,0);
         $$0 = 0.0;
         STACKTOP = sp;return (+$$0);
        } else {
         $399 = HEAP32[$1>>2]|0;
         $400 = ($399|0)==(0|0);
         if ($400) {
          $403 = 0;$404 = 0;
          break;
         }
         $401 = HEAP32[$0>>2]|0;
         $402 = (($401) + -1|0);
         HEAP32[$0>>2] = $402;
         $403 = 0;$404 = 0;
         break;
        }
       } else {
        $403 = $394;$404 = $395;
       }
      } while(0);
      $407 = (_i64Add(($403|0),($404|0),($405|0),($406|0))|0);
      $408 = tempRet0;
      $420 = $407;$423 = $408;
     } else {
      label = 171;
     }
    } else {
     label = 171;
    }
    if ((label|0) == 171) {
     $409 = ($$388$i|0)>(-1);
     if ($409) {
      $410 = HEAP32[$1>>2]|0;
      $411 = ($410|0)==(0|0);
      if ($411) {
       $420 = $405;$423 = $406;
      } else {
       $412 = HEAP32[$0>>2]|0;
       $413 = (($412) + -1|0);
       HEAP32[$0>>2] = $413;
       $420 = $405;$423 = $406;
      }
     } else {
      $420 = $405;$423 = $406;
     }
    }
    if (!($391)) {
     $414 = (___errno_location()|0);
     HEAP32[$414>>2] = 22;
     ___shlim($f,0);
     $$0 = 0.0;
     STACKTOP = sp;return (+$$0);
    }
    $415 = HEAP32[$x$i>>2]|0;
    $416 = ($415|0)==(0);
    if ($416) {
     $417 = (+($sign$0|0));
     $418 = $417 * 0.0;
     $$0 = $418;
     STACKTOP = sp;return (+$$0);
    }
    $419 = ($420|0)==($421|0);
    $422 = ($423|0)==($424|0);
    $425 = $419 & $422;
    $426 = ($424|0)<(0);
    $427 = ($424|0)==(0);
    $428 = ($421>>>0)<(10);
    $429 = $427 & $428;
    $430 = $426 | $429;
    $or$cond$i15 = $425 & $430;
    do {
     if ($or$cond$i15) {
      $431 = ($bits$0$ph>>>0)>(30);
      if (!($431)) {
       $432 = $415 >>> $bits$0$ph;
       $433 = ($432|0)==(0);
       if (!($433)) {
        break;
       }
      }
      $434 = (+($sign$0|0));
      $435 = (+($415>>>0));
      $436 = $434 * $435;
      $$0 = $436;
      STACKTOP = sp;return (+$$0);
     }
    } while(0);
    $437 = (($emin$0$ph|0) / -2)&-1;
    $438 = ($437|0)<(0);
    $439 = $438 << 31 >> 31;
    $440 = ($423|0)>($439|0);
    $441 = ($423|0)==($439|0);
    $442 = ($420>>>0)>($437>>>0);
    $443 = $441 & $442;
    $444 = $440 | $443;
    if ($444) {
     $445 = (___errno_location()|0);
     HEAP32[$445>>2] = 34;
     $446 = (+($sign$0|0));
     $447 = $446 * 1.79769313486231570815E+308;
     $448 = $447 * 1.79769313486231570815E+308;
     $$0 = $448;
     STACKTOP = sp;return (+$$0);
    }
    $449 = (($emin$0$ph) + -106)|0;
    $450 = ($449|0)<(0);
    $451 = $450 << 31 >> 31;
    $452 = ($423|0)<($451|0);
    $453 = ($423|0)==($451|0);
    $454 = ($420>>>0)<($449>>>0);
    $455 = $453 & $454;
    $456 = $452 | $455;
    if ($456) {
     $457 = (___errno_location()|0);
     HEAP32[$457>>2] = 34;
     $458 = (+($sign$0|0));
     $459 = $458 * 2.22507385850720138309E-308;
     $460 = $459 * 2.22507385850720138309E-308;
     $$0 = $460;
     STACKTOP = sp;return (+$$0);
    }
    $461 = ($j$086$i|0)==(0);
    if ($461) {
     $k$3$i = $k$084$i;
    } else {
     $462 = ($j$086$i|0)<(9);
     if ($462) {
      $463 = (($x$i) + ($k$084$i<<2)|0);
      $$promoted$i = HEAP32[$463>>2]|0;
      $465 = $$promoted$i;$j$371$i = $j$086$i;
      while(1) {
       $464 = ($465*10)|0;
       $466 = (($j$371$i) + 1)|0;
       $exitcond$i = ($466|0)==(9);
       if ($exitcond$i) {
        break;
       } else {
        $465 = $464;$j$371$i = $466;
       }
      }
      HEAP32[$463>>2] = $464;
     }
     $467 = (($k$084$i) + 1)|0;
     $k$3$i = $467;
    }
    $468 = ($lnz$079$i|0)<(9);
    do {
     if ($468) {
      $469 = ($lnz$079$i|0)<=($420|0);
      $470 = ($420|0)<(18);
      $or$cond3$i16 = $469 & $470;
      if ($or$cond3$i16) {
       $471 = ($420|0)==(9);
       if ($471) {
        $472 = (+($sign$0|0));
        $473 = HEAP32[$x$i>>2]|0;
        $474 = (+($473>>>0));
        $475 = $472 * $474;
        $$0 = $475;
        STACKTOP = sp;return (+$$0);
       }
       $476 = ($420|0)<(9);
       if ($476) {
        $477 = (+($sign$0|0));
        $478 = HEAP32[$x$i>>2]|0;
        $479 = (+($478>>>0));
        $480 = $477 * $479;
        $481 = (8 - ($420))|0;
        $482 = (3110648 + ($481<<2)|0);
        $483 = HEAP32[$482>>2]|0;
        $484 = (+($483|0));
        $485 = $480 / $484;
        $$0 = $485;
        STACKTOP = sp;return (+$$0);
       }
       $486 = Math_imul($420, -3)|0;
       $$neg20$i = (($bits$0$ph) + 27)|0;
       $487 = (($$neg20$i) + ($486))|0;
       $488 = ($487|0)>(30);
       $$pre$i17 = HEAP32[$x$i>>2]|0;
       if (!($488)) {
        $489 = $$pre$i17 >>> $487;
        $490 = ($489|0)==(0);
        if (!($490)) {
         break;
        }
       }
       $491 = (+($sign$0|0));
       $492 = (+($$pre$i17>>>0));
       $493 = $491 * $492;
       $494 = (($420) + -10)|0;
       $495 = (3110648 + ($494<<2)|0);
       $496 = HEAP32[$495>>2]|0;
       $497 = (+($496|0));
       $498 = $493 * $497;
       $$0 = $498;
       STACKTOP = sp;return (+$$0);
      }
     }
    } while(0);
    $499 = (($420|0) % 9)&-1;
    $500 = ($499|0)==(0);
    if ($500) {
     $a$2$ph40$i = 0;$e2$0$ph$i = 0;$rp$2$ph38$i = $420;$z$1$ph39$i = $k$3$i;
    } else {
     $501 = ($420|0)>(-1);
     $502 = (($499) + 9)|0;
     $503 = $501 ? $499 : $502;
     $504 = (8 - ($503))|0;
     $505 = (3110648 + ($504<<2)|0);
     $506 = HEAP32[$505>>2]|0;
     $507 = ($k$3$i|0)==(0);
     if ($507) {
      $a$0$lcssa161$i = 0;$rp$0$lcssa162$i = $420;$z$0$i = 0;
     } else {
      $508 = (1000000000 / ($506|0))&-1;
      $a$061$i = 0;$carry$063$i = 0;$k$462$i = 0;$rp$060$i = $420;
      while(1) {
       $509 = (($x$i) + ($k$462$i<<2)|0);
       $510 = HEAP32[$509>>2]|0;
       $511 = (($510>>>0) % ($506>>>0))&-1;
       $512 = (($510>>>0) / ($506>>>0))&-1;
       $513 = (($512) + ($carry$063$i))|0;
       HEAP32[$509>>2] = $513;
       $514 = Math_imul($511, $508)|0;
       $515 = ($k$462$i|0)==($a$061$i|0);
       $516 = ($513|0)==(0);
       $or$cond11$i = $515 & $516;
       $517 = (($k$462$i) + 1)|0;
       if ($or$cond11$i) {
        $518 = $517 & 127;
        $519 = (($rp$060$i) + -9)|0;
        $a$1$i = $518;$rp$1$i18 = $519;
       } else {
        $a$1$i = $a$061$i;$rp$1$i18 = $rp$060$i;
       }
       $520 = ($517|0)==($k$3$i|0);
       if ($520) {
        break;
       } else {
        $a$061$i = $a$1$i;$carry$063$i = $514;$k$462$i = $517;$rp$060$i = $rp$1$i18;
       }
      }
      $521 = ($514|0)==(0);
      if ($521) {
       $a$0$lcssa161$i = $a$1$i;$rp$0$lcssa162$i = $rp$1$i18;$z$0$i = $k$3$i;
      } else {
       $522 = (($k$3$i) + 1)|0;
       $523 = (($x$i) + ($k$3$i<<2)|0);
       HEAP32[$523>>2] = $514;
       $a$0$lcssa161$i = $a$1$i;$rp$0$lcssa162$i = $rp$1$i18;$z$0$i = $522;
      }
     }
     $524 = (9 - ($503))|0;
     $525 = (($524) + ($rp$0$lcssa162$i))|0;
     $a$2$ph40$i = $a$0$lcssa161$i;$e2$0$ph$i = 0;$rp$2$ph38$i = $525;$z$1$ph39$i = $z$0$i;
    }
    L321: while(1) {
     $526 = ($rp$2$ph38$i|0)<(18);
     $527 = (($x$i) + ($a$2$ph40$i<<2)|0);
     if ($526) {
      $e2$0$us$i = $e2$0$ph$i;$z$1$us$i = $z$1$ph39$i;
      while(1) {
       $529 = (($z$1$us$i) + 127)|0;
       $carry1$0$us$i = 0;$k$5$in$us$i = $529;$z$2$us$i = $z$1$us$i;
       while(1) {
        $k$5$us$i = $k$5$in$us$i & 127;
        $530 = (($x$i) + ($k$5$us$i<<2)|0);
        $531 = HEAP32[$530>>2]|0;
        $532 = (_bitshift64Shl(($531|0),0,29)|0);
        $533 = tempRet0;
        $534 = (_i64Add(($532|0),($533|0),($carry1$0$us$i|0),0)|0);
        $535 = tempRet0;
        $536 = ($535>>>0)>(0);
        $537 = ($535|0)==(0);
        $538 = ($534>>>0)>(1000000000);
        $539 = $537 & $538;
        $540 = $536 | $539;
        if ($540) {
         $541 = (___udivdi3(($534|0),($535|0),1000000000,0)|0);
         $542 = tempRet0;
         $543 = (___uremdi3(($534|0),($535|0),1000000000,0)|0);
         $544 = tempRet0;
         $$sink$off0$us$i = $543;$carry1$1$us$i = $541;
        } else {
         $$sink$off0$us$i = $534;$carry1$1$us$i = 0;
        }
        HEAP32[$530>>2] = $$sink$off0$us$i;
        $545 = (($z$2$us$i) + 127)|0;
        $546 = $545 & 127;
        $547 = ($k$5$us$i|0)!=($546|0);
        $548 = ($k$5$us$i|0)==($a$2$ph40$i|0);
        $or$cond12$us$i = $547 | $548;
        if ($or$cond12$us$i) {
         $z$3$us$i = $z$2$us$i;
        } else {
         $549 = ($$sink$off0$us$i|0)==(0);
         $k$5$z$2$us$i = $549 ? $k$5$us$i : $z$2$us$i;
         $z$3$us$i = $k$5$z$2$us$i;
        }
        $550 = (($k$5$us$i) + -1)|0;
        if ($548) {
         break;
        } else {
         $carry1$0$us$i = $carry1$1$us$i;$k$5$in$us$i = $550;$z$2$us$i = $z$3$us$i;
        }
       }
       $551 = (($e2$0$us$i) + -29)|0;
       $552 = ($carry1$1$us$i|0)==(0);
       if ($552) {
        $e2$0$us$i = $551;$z$1$us$i = $z$3$us$i;
       } else {
        $$lcssa43$i = $551;$carry1$1$lcssa$lcssa$i = $carry1$1$us$i;$z$3$lcssa$lcssa$i = $z$3$us$i;
        break;
       }
      }
     } else {
      $528 = ($rp$2$ph38$i|0)==(18);
      if ($528) {
       $e2$0$us44$i = $e2$0$ph$i;$z$1$us45$i = $z$1$ph39$i;
      } else {
       $a$3$ph$i = $a$2$ph40$i;$e2$1$ph$i = $e2$0$ph$i;$rp$3$ph33$i = $rp$2$ph38$i;$z$5$ph$i = $z$1$ph39$i;
       break;
      }
      while(1) {
       $553 = HEAP32[$527>>2]|0;
       $554 = ($553>>>0)<(9007199);
       if (!($554)) {
        $a$3$ph$i = $a$2$ph40$i;$e2$1$ph$i = $e2$0$us44$i;$rp$3$ph33$i = 18;$z$5$ph$i = $z$1$us45$i;
        break L321;
       }
       $555 = (($z$1$us45$i) + 127)|0;
       $carry1$0$us49$i = 0;$k$5$in$us48$i = $555;$z$2$us47$i = $z$1$us45$i;
       while(1) {
        $k$5$us50$i = $k$5$in$us48$i & 127;
        $556 = (($x$i) + ($k$5$us50$i<<2)|0);
        $557 = HEAP32[$556>>2]|0;
        $558 = (_bitshift64Shl(($557|0),0,29)|0);
        $559 = tempRet0;
        $560 = (_i64Add(($558|0),($559|0),($carry1$0$us49$i|0),0)|0);
        $561 = tempRet0;
        $562 = ($561>>>0)>(0);
        $563 = ($561|0)==(0);
        $564 = ($560>>>0)>(1000000000);
        $565 = $563 & $564;
        $566 = $562 | $565;
        if ($566) {
         $567 = (___udivdi3(($560|0),($561|0),1000000000,0)|0);
         $568 = tempRet0;
         $569 = (___uremdi3(($560|0),($561|0),1000000000,0)|0);
         $570 = tempRet0;
         $$sink$off0$us53$i = $569;$carry1$1$us54$i = $567;
        } else {
         $$sink$off0$us53$i = $560;$carry1$1$us54$i = 0;
        }
        HEAP32[$556>>2] = $$sink$off0$us53$i;
        $571 = (($z$2$us47$i) + 127)|0;
        $572 = $571 & 127;
        $573 = ($k$5$us50$i|0)!=($572|0);
        $574 = ($k$5$us50$i|0)==($a$2$ph40$i|0);
        $or$cond12$us55$i = $573 | $574;
        if ($or$cond12$us55$i) {
         $z$3$us57$i = $z$2$us47$i;
        } else {
         $575 = ($$sink$off0$us53$i|0)==(0);
         $k$5$z$2$us56$i = $575 ? $k$5$us50$i : $z$2$us47$i;
         $z$3$us57$i = $k$5$z$2$us56$i;
        }
        $576 = (($k$5$us50$i) + -1)|0;
        if ($574) {
         break;
        } else {
         $carry1$0$us49$i = $carry1$1$us54$i;$k$5$in$us48$i = $576;$z$2$us47$i = $z$3$us57$i;
        }
       }
       $577 = (($e2$0$us44$i) + -29)|0;
       $578 = ($carry1$1$us54$i|0)==(0);
       if ($578) {
        $e2$0$us44$i = $577;$z$1$us45$i = $z$3$us57$i;
       } else {
        $$lcssa43$i = $577;$carry1$1$lcssa$lcssa$i = $carry1$1$us54$i;$z$3$lcssa$lcssa$i = $z$3$us57$i;
        break;
       }
      }
     }
     $579 = (($rp$2$ph38$i) + 9)|0;
     $580 = (($a$2$ph40$i) + 127)|0;
     $581 = $580 & 127;
     $582 = ($581|0)==($z$3$lcssa$lcssa$i|0);
     if ($582) {
      $583 = (($z$3$lcssa$lcssa$i) + 127)|0;
      $584 = $583 & 127;
      $585 = (($x$i) + ($584<<2)|0);
      $586 = HEAP32[$585>>2]|0;
      $587 = (($z$3$lcssa$lcssa$i) + 126)|0;
      $588 = $587 & 127;
      $589 = (($x$i) + ($588<<2)|0);
      $590 = HEAP32[$589>>2]|0;
      $591 = $590 | $586;
      HEAP32[$589>>2] = $591;
      $z$4$i = $584;
     } else {
      $z$4$i = $z$3$lcssa$lcssa$i;
     }
     $592 = (($x$i) + ($581<<2)|0);
     HEAP32[$592>>2] = $carry1$1$lcssa$lcssa$i;
     $a$2$ph40$i = $581;$e2$0$ph$i = $$lcssa43$i;$rp$2$ph38$i = $579;$z$1$ph39$i = $z$4$i;
    }
    L352: while(1) {
     $629 = (($z$5$ph$i) + 1)|0;
     $627 = $629 & 127;
     $630 = (($z$5$ph$i) + 127)|0;
     $631 = $630 & 127;
     $632 = (($x$i) + ($631<<2)|0);
     $a$3$i$ph = $a$3$ph$i;$e2$1$i$ph = $e2$1$ph$i;$rp$3$i$ph = $rp$3$ph33$i;
     while(1) {
      $605 = ($rp$3$i$ph|0)==(18);
      $633 = ($rp$3$i$ph|0)>(27);
      $$14$i = $633 ? 9 : 1;
      $a$3$i = $a$3$i$ph;$e2$1$i = $e2$1$i$ph;
      while(1) {
       $i$025$i = 0;
       while(1) {
        $595 = (($i$025$i) + ($a$3$i))|0;
        $596 = $595 & 127;
        $597 = ($596|0)==($z$5$ph$i|0);
        if ($597) {
         $i$1$i = 2;
         break;
        }
        $598 = (($x$i) + ($596<<2)|0);
        $599 = HEAP32[$598>>2]|0;
        $600 = (3110640 + ($i$025$i<<2)|0);
        $601 = HEAP32[$600>>2]|0;
        $602 = ($599>>>0)<($601>>>0);
        if ($602) {
         $i$1$i = 2;
         break;
        }
        $603 = ($599>>>0)>($601>>>0);
        $594 = (($i$025$i) + 1)|0;
        if ($603) {
         $i$1$i = $i$025$i;
         break;
        }
        $593 = ($594|0)<(2);
        if ($593) {
         $i$025$i = $594;
        } else {
         $i$1$i = $594;
         break;
        }
       }
       $604 = ($i$1$i|0)==(2);
       $or$cond13$i = $604 & $605;
       if ($or$cond13$i) {
        break L352;
       }
       $608 = (($$14$i) + ($e2$1$i))|0;
       $609 = ($a$3$i|0)==($z$5$ph$i|0);
       if ($609) {
        $a$3$i = $z$5$ph$i;$e2$1$i = $608;
       } else {
        break;
       }
      }
      $610 = 1 << $$14$i;
      $611 = (($610) + -1)|0;
      $612 = 1000000000 >>> $$14$i;
      $a$427$i = $a$3$i;$carry3$030$i = 0;$k$628$i = $a$3$i;$rp$426$i = $rp$3$i$ph;
      while(1) {
       $613 = (($x$i) + ($k$628$i<<2)|0);
       $614 = HEAP32[$613>>2]|0;
       $615 = $614 & $611;
       $616 = $614 >>> $$14$i;
       $617 = (($616) + ($carry3$030$i))|0;
       HEAP32[$613>>2] = $617;
       $618 = Math_imul($615, $612)|0;
       $619 = ($k$628$i|0)==($a$427$i|0);
       $620 = ($617|0)==(0);
       $or$cond15$i = $619 & $620;
       $621 = (($k$628$i) + 1)|0;
       $622 = $621 & 127;
       $623 = (($rp$426$i) + -9)|0;
       $rp$5$i = $or$cond15$i ? $623 : $rp$426$i;
       $a$5$i = $or$cond15$i ? $622 : $a$427$i;
       $624 = ($622|0)==($z$5$ph$i|0);
       if ($624) {
        break;
       } else {
        $a$427$i = $a$5$i;$carry3$030$i = $618;$k$628$i = $622;$rp$426$i = $rp$5$i;
       }
      }
      $625 = ($618|0)==(0);
      if ($625) {
       $a$3$i$ph = $a$5$i;$e2$1$i$ph = $608;$rp$3$i$ph = $rp$5$i;
       continue;
      }
      $626 = ($627|0)==($a$5$i|0);
      if (!($626)) {
       break;
      }
      $634 = HEAP32[$632>>2]|0;
      $635 = $634 | 1;
      HEAP32[$632>>2] = $635;
      $a$3$i$ph = $a$5$i;$e2$1$i$ph = $608;$rp$3$i$ph = $rp$5$i;
     }
     $628 = (($x$i) + ($z$5$ph$i<<2)|0);
     HEAP32[$628>>2] = $618;
     $a$3$ph$i = $a$5$i;$e2$1$ph$i = $608;$rp$3$ph33$i = $rp$5$i;$z$5$ph$i = $627;
    }
    $606 = $a$3$i & 127;
    $607 = ($606|0)==($z$5$ph$i|0);
    if ($607) {
     $636 = (($627) + -1)|0;
     $637 = (($x$i) + ($636<<2)|0);
     HEAP32[$637>>2] = 0;
     $z$7$i = $627;
    } else {
     $z$7$i = $z$5$ph$i;
    }
    $638 = (($x$i) + ($606<<2)|0);
    $639 = HEAP32[$638>>2]|0;
    $640 = (+($639>>>0));
    $641 = (($a$3$i) + 1)|0;
    $642 = $641 & 127;
    $643 = ($642|0)==($z$7$i|0);
    if ($643) {
     $702 = (($z$7$i) + 1)|0;
     $703 = $702 & 127;
     $704 = (($703) + -1)|0;
     $705 = (($x$i) + ($704<<2)|0);
     HEAP32[$705>>2] = 0;
     $z$7$1$i = $703;
    } else {
     $z$7$1$i = $z$7$i;
    }
    $706 = $640 * 1.0E+9;
    $707 = (($x$i) + ($642<<2)|0);
    $708 = HEAP32[$707>>2]|0;
    $709 = (+($708>>>0));
    $710 = $706 + $709;
    $667 = (+($sign$0|0));
    $649 = $667 * $710;
    $687 = (($e2$1$i) + 53)|0;
    $645 = (($687) - ($emin$0$ph))|0;
    $711 = ($645|0)<($bits$0$ph|0);
    if ($711) {
     $644 = ($645|0)<(0);
     $$$i22 = $644 ? 0 : $645;
     $$09$i = $$$i22;$denormal$0$i = 1;
    } else {
     $$09$i = $bits$0$ph;$denormal$0$i = 0;
    }
    $646 = ($$09$i|0)<(53);
    if ($646) {
     $647 = (105 - ($$09$i))|0;
     $648 = (+_scalbn(1.0,$647));
     $650 = (+_copysignl((+$648),(+$649)));
     $651 = (53 - ($$09$i))|0;
     $652 = (+_scalbn(1.0,$651));
     $653 = (+_fmodl((+$649),(+$652)));
     $654 = $649 - $653;
     $655 = $650 + $654;
     $bias$0$i = $650;$frac$0$i = $653;$y$1$i23 = $655;
    } else {
     $bias$0$i = 0.0;$frac$0$i = 0.0;$y$1$i23 = $649;
    }
    $656 = (($a$3$i) + 2)|0;
    $657 = $656 & 127;
    $658 = ($657|0)==($z$7$1$i|0);
    do {
     if ($658) {
      $frac$2$i = $frac$0$i;
     } else {
      $659 = (($x$i) + ($657<<2)|0);
      $660 = HEAP32[$659>>2]|0;
      $661 = ($660>>>0)<(500000000);
      do {
       if ($661) {
        $662 = ($660|0)==(0);
        if ($662) {
         $663 = (($a$3$i) + 3)|0;
         $664 = $663 & 127;
         $665 = ($664|0)==($z$7$1$i|0);
         if ($665) {
          $frac$1$i = $frac$0$i;
          break;
         }
        }
        $666 = $667 * 0.25;
        $668 = $666 + $frac$0$i;
        $frac$1$i = $668;
       } else {
        $669 = ($660>>>0)>(500000000);
        if ($669) {
         $670 = $667 * 0.75;
         $671 = $670 + $frac$0$i;
         $frac$1$i = $671;
         break;
        }
        $672 = (($a$3$i) + 3)|0;
        $673 = $672 & 127;
        $674 = ($673|0)==($z$7$1$i|0);
        if ($674) {
         $675 = $667 * 0.5;
         $676 = $675 + $frac$0$i;
         $frac$1$i = $676;
         break;
        } else {
         $677 = $667 * 0.75;
         $678 = $677 + $frac$0$i;
         $frac$1$i = $678;
         break;
        }
       }
      } while(0);
      $679 = (53 - ($$09$i))|0;
      $680 = ($679|0)>(1);
      if (!($680)) {
       $frac$2$i = $frac$1$i;
       break;
      }
      $681 = (+_fmodl((+$frac$1$i),1.0));
      $682 = $681 != 0.0;
      if ($682) {
       $frac$2$i = $frac$1$i;
       break;
      }
      $683 = $frac$1$i + 1.0;
      $frac$2$i = $683;
     }
    } while(0);
    $684 = $y$1$i23 + $frac$2$i;
    $685 = $684 - $bias$0$i;
    $686 = $687 & 2147483647;
    $688 = (-2 - ($sum$i))|0;
    $689 = ($686|0)>($688|0);
    do {
     if ($689) {
      $690 = (+Math_abs((+$685)));
      $691 = !($690 >= 9007199254740992.0);
      if ($691) {
       $denormal$2$i = $denormal$0$i;$e2$2$i = $e2$1$i;$y$2$i24 = $685;
      } else {
       $692 = ($denormal$0$i|0)!=(0);
       $693 = ($$09$i|0)==($645|0);
       $or$cond16$i = $692 & $693;
       $denormal$1$i = $or$cond16$i ? 0 : $denormal$0$i;
       $694 = $685 * 0.5;
       $695 = (($e2$1$i) + 1)|0;
       $denormal$2$i = $denormal$1$i;$e2$2$i = $695;$y$2$i24 = $694;
      }
      $696 = (($e2$2$i) + 50)|0;
      $697 = ($696|0)>($325|0);
      if (!($697)) {
       $698 = ($denormal$2$i|0)!=(0);
       $699 = $frac$2$i != 0.0;
       $or$cond17$i = $698 & $699;
       if (!($or$cond17$i)) {
        $e2$3$i = $e2$2$i;$y$3$i = $y$2$i24;
        break;
       }
      }
      $700 = (___errno_location()|0);
      HEAP32[$700>>2] = 34;
      $e2$3$i = $e2$2$i;$y$3$i = $y$2$i24;
     } else {
      $e2$3$i = $e2$1$i;$y$3$i = $685;
     }
    } while(0);
    $701 = (+_scalbnl($y$3$i,$e2$3$i));
    $$0 = $701;
    STACKTOP = sp;return (+$$0);
   } else {
    $108 = HEAP32[$1>>2]|0;
    $109 = ($108|0)==(0|0);
    if (!($109)) {
     $110 = HEAP32[$0>>2]|0;
     $111 = (($110) + -1|0);
     HEAP32[$0>>2] = $111;
    }
    $112 = (___errno_location()|0);
    HEAP32[$112>>2] = 22;
    ___shlim($f,0);
    $$0 = 0.0;
    STACKTOP = sp;return (+$$0);
   }
  }
 } while(0);
 if ((label|0) == 23) {
  $41 = HEAP32[$1>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = HEAP32[$0>>2]|0;
   $44 = (($43) + -1|0);
   HEAP32[$0>>2] = $44;
  }
  $notlhs = ($pok|0)==(0);
  $notrhs = ($i$0$lcssa>>>0)<(4);
  $or$cond106$not = $notrhs | $notlhs;
  $brmerge = $or$cond106$not | $42;
  if (!($brmerge)) {
   $i$166 = $i$0$lcssa;
   while(1) {
    $45 = HEAP32[$0>>2]|0;
    $46 = (($45) + -1|0);
    HEAP32[$0>>2] = $46;
    $47 = (($i$166) + -1)|0;
    $48 = ($47>>>0)>(3);
    if ($48) {
     $i$166 = $47;
    } else {
     break;
    }
   }
  }
 }
 $49 = (Math_fround(($sign$0|0)));
 $50 = Math_fround($49 * Math_fround(inf));
 $51 = +$50;
 $$0 = $51;
 STACKTOP = sp;return (+$$0);
}
function _scanexp($f,$pok) {
 $f = $f|0;
 $pok = $pok|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $c$0 = 0, $c$1$be = 0;
 var $c$18 = 0, $c$2$be = 0, $c$2$lcssa = 0, $c$23 = 0, $c$3$be = 0, $neg$0 = 0, $or$cond = 0, $or$cond2 = 0, $phitmp16 = 0, $x$09 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($f) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  $5 = (($1) + 1|0);
  HEAP32[$0>>2] = $5;
  $6 = HEAP8[$1>>0]|0;
  $7 = $6&255;
  $10 = $7;
 } else {
  $8 = (___shgetc($f)|0);
  $10 = $8;
 }
 $9 = ($10|0)==(45);
 if ((($10|0) == 43) | (($10|0) == 45)) {
  $11 = $9&1;
  $12 = HEAP32[$0>>2]|0;
  $13 = HEAP32[$2>>2]|0;
  $14 = ($12>>>0)<($13>>>0);
  if ($14) {
   $15 = (($12) + 1|0);
   HEAP32[$0>>2] = $15;
   $16 = HEAP8[$12>>0]|0;
   $17 = $16&255;
   $20 = $17;
  } else {
   $18 = (___shgetc($f)|0);
   $20 = $18;
  }
  $19 = (($20) + -48)|0;
  $21 = ($19>>>0)<(10);
  $22 = ($pok|0)==(0);
  $or$cond = $21 | $22;
  if ($or$cond) {
   $c$0 = $20;$neg$0 = $11;
  } else {
   $23 = HEAP32[$2>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $c$0 = $20;$neg$0 = $11;
   } else {
    $25 = HEAP32[$0>>2]|0;
    $26 = (($25) + -1|0);
    HEAP32[$0>>2] = $26;
    $c$0 = $20;$neg$0 = $11;
   }
  }
 } else {
  $c$0 = $10;$neg$0 = 0;
 }
 $27 = (($c$0) + -48)|0;
 $28 = ($27>>>0)>(9);
 if ($28) {
  $29 = HEAP32[$2>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $95 = -2147483648;$96 = 0;
   tempRet0 = $95;
   STACKTOP = sp;return ($96|0);
  }
  $31 = HEAP32[$0>>2]|0;
  $32 = (($31) + -1|0);
  HEAP32[$0>>2] = $32;
  $95 = -2147483648;$96 = 0;
  tempRet0 = $95;
  STACKTOP = sp;return ($96|0);
 } else {
  $c$18 = $c$0;$x$09 = 0;
 }
 while(1) {
  $33 = (($c$18) + -48)|0;
  $34 = (($33) + ($x$09))|0;
  $35 = HEAP32[$0>>2]|0;
  $36 = HEAP32[$2>>2]|0;
  $37 = ($35>>>0)<($36>>>0);
  if ($37) {
   $38 = (($35) + 1|0);
   HEAP32[$0>>2] = $38;
   $39 = HEAP8[$35>>0]|0;
   $40 = $39&255;
   $c$1$be = $40;
  } else {
   $41 = (___shgetc($f)|0);
   $c$1$be = $41;
  }
  $42 = (($c$1$be) + -48)|0;
  $43 = ($42>>>0)<(10);
  $44 = ($34|0)<(214748364);
  $$ = $43 & $44;
  if (!($$)) {
   break;
  }
  $phitmp16 = ($34*10)|0;
  $c$18 = $c$1$be;$x$09 = $phitmp16;
 }
 $45 = ($34|0)<(0);
 $46 = $45 << 31 >> 31;
 $47 = (($c$1$be) + -48)|0;
 $48 = ($47>>>0)<(10);
 if ($48) {
  $51 = $34;$52 = $46;$c$23 = $c$1$be;
  while(1) {
   $53 = (___muldi3(($51|0),($52|0),10,0)|0);
   $54 = tempRet0;
   $55 = ($c$23|0)<(0);
   $56 = $55 << 31 >> 31;
   $57 = (_i64Add(($c$23|0),($56|0),-48,-1)|0);
   $58 = tempRet0;
   $59 = (_i64Add(($57|0),($58|0),($53|0),($54|0))|0);
   $60 = tempRet0;
   $61 = HEAP32[$0>>2]|0;
   $62 = HEAP32[$2>>2]|0;
   $63 = ($61>>>0)<($62>>>0);
   if ($63) {
    $64 = (($61) + 1|0);
    HEAP32[$0>>2] = $64;
    $65 = HEAP8[$61>>0]|0;
    $66 = $65&255;
    $c$2$be = $66;
   } else {
    $67 = (___shgetc($f)|0);
    $c$2$be = $67;
   }
   $68 = (($c$2$be) + -48)|0;
   $69 = ($68>>>0)<(10);
   $70 = ($60|0)<(21474836);
   $71 = ($60|0)==(21474836);
   $72 = ($59>>>0)<(2061584302);
   $73 = $71 & $72;
   $74 = $70 | $73;
   $or$cond2 = $69 & $74;
   if ($or$cond2) {
    $51 = $59;$52 = $60;$c$23 = $c$2$be;
   } else {
    $89 = $59;$90 = $60;$c$2$lcssa = $c$2$be;
    break;
   }
  }
 } else {
  $89 = $34;$90 = $46;$c$2$lcssa = $c$1$be;
 }
 $49 = (($c$2$lcssa) + -48)|0;
 $50 = ($49>>>0)<(10);
 if ($50) {
  while(1) {
   $75 = HEAP32[$0>>2]|0;
   $76 = HEAP32[$2>>2]|0;
   $77 = ($75>>>0)<($76>>>0);
   if ($77) {
    $78 = (($75) + 1|0);
    HEAP32[$0>>2] = $78;
    $79 = HEAP8[$75>>0]|0;
    $80 = $79&255;
    $c$3$be = $80;
   } else {
    $81 = (___shgetc($f)|0);
    $c$3$be = $81;
   }
   $82 = (($c$3$be) + -48)|0;
   $83 = ($82>>>0)<(10);
   if (!($83)) {
    break;
   }
  }
 }
 $84 = HEAP32[$2>>2]|0;
 $85 = ($84|0)==(0|0);
 if (!($85)) {
  $86 = HEAP32[$0>>2]|0;
  $87 = (($86) + -1|0);
  HEAP32[$0>>2] = $87;
 }
 $88 = ($neg$0|0)!=(0);
 $91 = (_i64Subtract(0,0,($89|0),($90|0))|0);
 $92 = tempRet0;
 $93 = $88 ? $91 : $89;
 $94 = $88 ? $92 : $90;
 $95 = $94;$96 = $93;
 tempRet0 = $95;
 STACKTOP = sp;return ($96|0);
}
function ___shlim($f,$lim) {
 $f = $f|0;
 $lim = $lim|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 104|0);
 HEAP32[$0>>2] = $lim;
 $1 = (($f) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($f) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = (($f) + 108|0);
 HEAP32[$8>>2] = $7;
 $9 = ($lim|0)!=(0);
 $10 = ($7|0)>($lim|0);
 $or$cond = $9 & $10;
 if ($or$cond) {
  $11 = (($4) + ($lim)|0);
  $12 = (($f) + 100|0);
  HEAP32[$12>>2] = $11;
  STACKTOP = sp;return;
 } else {
  $13 = (($f) + 100|0);
  HEAP32[$13>>2] = $2;
  STACKTOP = sp;return;
 }
}
function ___shgetc($f) {
 $f = $f|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert2 = 0, $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  label = 3;
 } else {
  $3 = (($f) + 108|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)<($1|0);
  if ($5) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $6 = (___uflow($f)|0);
  $7 = ($6|0)<(0);
  if (!($7)) {
   $9 = HEAP32[$0>>2]|0;
   $10 = ($9|0)==(0);
   $$phi$trans$insert = (($f) + 8|0);
   $$pre = HEAP32[$$phi$trans$insert>>2]|0;
   if ($10) {
    label = 8;
   } else {
    $11 = (($f) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = $$pre;
    $14 = $12;
    $15 = (($13) - ($14))|0;
    $16 = (($f) + 108|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($9) - ($17))|0;
    $19 = (($18) + -1)|0;
    $20 = ($15|0)>($19|0);
    if ($20) {
     $21 = (($12) + ($19)|0);
     $22 = (($f) + 100|0);
     HEAP32[$22>>2] = $21;
    } else {
     label = 8;
    }
   }
   if ((label|0) == 8) {
    $23 = (($f) + 100|0);
    HEAP32[$23>>2] = $$pre;
   }
   $24 = ($$pre|0)==(0|0);
   $$phi$trans$insert2 = (($f) + 4|0);
   $$pre3 = HEAP32[$$phi$trans$insert2>>2]|0;
   if (!($24)) {
    $25 = $$pre;
    $26 = $$pre3;
    $27 = (($f) + 108|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($25) + 1)|0;
    $30 = (($29) - ($26))|0;
    $31 = (($30) + ($28))|0;
    HEAP32[$27>>2] = $31;
   }
   $32 = (($$pre3) + -1|0);
   $33 = HEAP8[$32>>0]|0;
   $34 = $33&255;
   $35 = ($34|0)==($6|0);
   if ($35) {
    $$0 = $6;
    STACKTOP = sp;return ($$0|0);
   }
   $36 = $6&255;
   HEAP8[$32>>0] = $36;
   $$0 = $6;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $8 = (($f) + 100|0);
 HEAP32[$8>>2] = 0;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _frexp($x,$e) {
 $x = +$x;
 $e = $e|0;
 var $$0 = 0.0, $$01 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
 $3 = tempRet0;
 $4 = $2 & 2047;
 if ((($4|0) == 0)) {
  $5 = $x != 0.0;
  if ($5) {
   $6 = $x * 18446744073709551616.0;
   $7 = (+_frexp($6,$e));
   $8 = HEAP32[$e>>2]|0;
   $9 = (($8) + -64)|0;
   $$01 = $7;$storemerge = $9;
  } else {
   $$01 = $x;$storemerge = 0;
  }
  HEAP32[$e>>2] = $storemerge;
  $$0 = $$01;
  STACKTOP = sp;return (+$$0);
 } else if ((($4|0) == 2047)) {
  $$0 = $x;
  STACKTOP = sp;return (+$$0);
 } else {
  $10 = (($4) + -1022)|0;
  HEAP32[$e>>2] = $10;
  $11 = $1 & -2146435073;
  $12 = $11 | 1071644672;
  HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $12;$13 = +HEAPF64[tempDoublePtr>>3];
  $$0 = $13;
  STACKTOP = sp;return (+$$0);
 }
 return +0;
}
function _frexpl($x,$e) {
 $x = +$x;
 $e = $e|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_frexp($x,$e));
 STACKTOP = sp;return (+$0);
}
function _scalbn($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0.0, $9 = 0, $y$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)>(1023);
 if ($0) {
  $1 = $x * 8.98846567431157953864E+307;
  $2 = (($n) + -1023)|0;
  $3 = ($2|0)>(1023);
  if ($3) {
   $4 = $1 * 8.98846567431157953864E+307;
   $5 = (($n) + -2046)|0;
   $6 = ($5|0)>(1023);
   $$ = $6 ? 1023 : $5;
   $$0 = $$;$y$0 = $4;
  } else {
   $$0 = $2;$y$0 = $1;
  }
 } else {
  $7 = ($n|0)<(-1022);
  if ($7) {
   $8 = $x * 2.22507385850720138309E-308;
   $9 = (($n) + 1022)|0;
   $10 = ($9|0)<(-1022);
   if ($10) {
    $11 = $8 * 2.22507385850720138309E-308;
    $12 = (($n) + 2044)|0;
    $13 = ($12|0)<(-1022);
    $$1 = $13 ? -1022 : $12;
    $$0 = $$1;$y$0 = $11;
   } else {
    $$0 = $9;$y$0 = $8;
   }
  } else {
   $$0 = $n;$y$0 = $x;
  }
 }
 $14 = (($$0) + 1023)|0;
 $15 = (_bitshift64Shl(($14|0),0,52)|0);
 $16 = tempRet0;
 HEAP32[tempDoublePtr>>2] = $15;HEAP32[tempDoublePtr+4>>2] = $16;$17 = +HEAPF64[tempDoublePtr>>3];
 $18 = $y$0 * $17;
 STACKTOP = sp;return (+$18);
}
function _scalbnl($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_scalbn($x,$n));
 STACKTOP = sp;return (+$0);
}
function _wctomb($s,$wc) {
 $s = $s|0;
 $wc = $wc|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_wcrtomb($s,$wc,0)|0);
  $$0 = $1;
 }
 STACKTOP = sp;return ($$0|0);
}
function _wcrtomb($s,$wc,$st) {
 $s = $s|0;
 $wc = $wc|0;
 $st = $st|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($wc>>>0)<(128);
 if ($1) {
  $2 = $wc&255;
  HEAP8[$s>>0] = $2;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = ($wc>>>0)<(2048);
 if ($3) {
  $4 = $wc >>> 6;
  $5 = $4 | 192;
  $6 = $5&255;
  $7 = (($s) + 1|0);
  HEAP8[$s>>0] = $6;
  $8 = $wc & 63;
  $9 = $8 | 128;
  $10 = $9&255;
  HEAP8[$7>>0] = $10;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ($wc>>>0)<(55296);
 $12 = (($wc) + -57344)|0;
 $13 = ($12>>>0)<(8192);
 $or$cond = $11 | $13;
 if ($or$cond) {
  $14 = $wc >>> 12;
  $15 = $14 | 224;
  $16 = $15&255;
  $17 = (($s) + 1|0);
  HEAP8[$s>>0] = $16;
  $18 = $wc >>> 6;
  $19 = $18 & 63;
  $20 = $19 | 128;
  $21 = $20&255;
  $22 = (($s) + 2|0);
  HEAP8[$17>>0] = $21;
  $23 = $wc & 63;
  $24 = $23 | 128;
  $25 = $24&255;
  HEAP8[$22>>0] = $25;
  $$0 = 3;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = (($wc) + -65536)|0;
 $27 = ($26>>>0)<(1048576);
 if ($27) {
  $28 = $wc >>> 18;
  $29 = $28 | 240;
  $30 = $29&255;
  $31 = (($s) + 1|0);
  HEAP8[$s>>0] = $30;
  $32 = $wc >>> 12;
  $33 = $32 & 63;
  $34 = $33 | 128;
  $35 = $34&255;
  $36 = (($s) + 2|0);
  HEAP8[$31>>0] = $35;
  $37 = $wc >>> 6;
  $38 = $37 & 63;
  $39 = $38 | 128;
  $40 = $39&255;
  $41 = (($s) + 3|0);
  HEAP8[$36>>0] = $40;
  $42 = $wc & 63;
  $43 = $42 | 128;
  $44 = $43&255;
  HEAP8[$41>>0] = $44;
  $$0 = 4;
  STACKTOP = sp;return ($$0|0);
 } else {
  $45 = (___errno_location()|0);
  HEAP32[$45>>2] = 84;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _rand() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 3110680;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___muldi3(($2|0),($5|0),1284865837,1481765933)|0);
 $7 = tempRet0;
 $8 = (_i64Add(($6|0),($7|0),1,0)|0);
 $9 = tempRet0;
 $10 = 3110680;
 $11 = $10;
 HEAP32[$11>>2] = $8;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (_bitshift64Lshr(($8|0),($9|0),33)|0);
 $15 = tempRet0;
 STACKTOP = sp;return ($14|0);
}
function ___toread($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 74|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = (($2) + 255)|0;
 $4 = $3 | $2;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = (($f) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($f) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  $11 = (($f) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  (FUNCTION_TABLE_iiii[$12 & 2047]($f,0,0)|0);
 }
 $13 = (($f) + 16|0);
 HEAP32[$13>>2] = 0;
 $14 = (($f) + 28|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$6>>2] = 0;
 $15 = HEAP32[$f>>2]|0;
 $16 = $15 & 20;
 $17 = ($16|0)==(0);
 if ($17) {
  $21 = HEAP32[$8>>2]|0;
  $22 = (($f) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = (($f) + 4|0);
  HEAP32[$23>>2] = $21;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = $15 & 4;
 $19 = ($18|0)==(0);
 if ($19) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = $15 | 32;
 HEAP32[$f>>2] = $20;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function ___towrite($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 74|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = (($2) + 255)|0;
 $4 = $3 | $2;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = HEAP32[$f>>2]|0;
 $7 = $6 & 8;
 $8 = ($7|0)==(0);
 if ($8) {
  $10 = (($f) + 8|0);
  HEAP32[$10>>2] = 0;
  $11 = (($f) + 4|0);
  HEAP32[$11>>2] = 0;
  $12 = (($f) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($f) + 28|0);
  HEAP32[$14>>2] = $13;
  $15 = (($f) + 20|0);
  HEAP32[$15>>2] = $13;
  $16 = (($f) + 48|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($13) + ($17)|0);
  $19 = (($f) + 16|0);
  HEAP32[$19>>2] = $18;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $9 = $6 | 32;
  HEAP32[$f>>2] = $9;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function ___uflow($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $c = sp;
 $0 = (($f) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (___toread($f)|0);
  $4 = ($3|0)==(0);
  if ($4) {
   label = 3;
  } else {
   $$0 = -1;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $5 = (($f) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiii[$6 & 2047]($f,$c,1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   $9 = HEAP8[$c>>0]|0;
   $10 = $9&255;
   $$0 = $10;
  } else {
   $$0 = -1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function ___fwritex($s,$l,$f) {
 $s = $s|0;
 $l = $l|0;
 $f = $f|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $3 = (___towrite($f)|0);
   $4 = ($3|0)==(0);
   if ($4) {
    $$pre6 = HEAP32[$0>>2]|0;
    $8 = $$pre6;
    break;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $8 = $1;
  }
 } while(0);
 $5 = (($f) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $8;
 $9 = $6;
 $10 = (($7) - ($9))|0;
 $11 = ($10>>>0)<($l>>>0);
 if ($11) {
  $12 = (($f) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$13 & 2047]($f,$s,$l)|0);
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (($f) + 75|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)>(-1);
 L11: do {
  if ($17) {
   $i$0 = $l;
   while(1) {
    $18 = ($i$0|0)==(0);
    if ($18) {
     $$01 = $l;$$02 = $s;$29 = $6;$i$1 = 0;
     break L11;
    }
    $19 = (($i$0) + -1)|0;
    $20 = (($s) + ($19)|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)==(10);
    if ($22) {
     break;
    } else {
     $i$0 = $19;
    }
   }
   $23 = (($f) + 36|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (FUNCTION_TABLE_iiii[$24 & 2047]($f,$s,$i$0)|0);
   $26 = ($25>>>0)<($i$0>>>0);
   if ($26) {
    $$0 = $i$0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $27 = (($s) + ($i$0)|0);
    $28 = (($l) - ($i$0))|0;
    $$pre = HEAP32[$5>>2]|0;
    $$01 = $28;$$02 = $27;$29 = $$pre;$i$1 = $i$0;
    break;
   }
  } else {
   $$01 = $l;$$02 = $s;$29 = $6;$i$1 = 0;
  }
 } while(0);
 _memcpy(($29|0),($$02|0),($$01|0))|0;
 $30 = HEAP32[$5>>2]|0;
 $31 = (($30) + ($$01)|0);
 HEAP32[$5>>2] = $31;
 $32 = (($i$1) + ($$01))|0;
 $$0 = $32;
 STACKTOP = sp;return ($$0|0);
}
function _snprintf($s,$n,$fmt,$varargs) {
 $s = $s|0;
 $n = $n|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsnprintf($s,$n,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _sprintf($s,$fmt,$varargs) {
 $s = $s|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsprintf($s,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _MUSL_vfprintf($f,$fmt,$ap) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ap2 = 0, $internal_buf = 0, $nl_arg = 0, $nl_type = 0, $ret$1 = 0, $vacopy_currentptr = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $ap2 = sp + 120|0;
 $nl_type = sp + 80|0;
 $nl_arg = sp;
 $internal_buf = sp + 136|0;
 dest=$nl_type+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $vacopy_currentptr = HEAP32[$ap>>2]|0;
 HEAP32[$ap2>>2] = $vacopy_currentptr;
 $0 = (_printf_core(0,$fmt,$ap2,$nl_arg,$nl_type)|0);
 $1 = ($0|0)<(0);
 if ($1) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($f) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $6 = (($f) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$6>>2] = $internal_buf;
  $8 = (($f) + 28|0);
  HEAP32[$8>>2] = $internal_buf;
  $9 = (($f) + 20|0);
  HEAP32[$9>>2] = $internal_buf;
  HEAP32[$2>>2] = 80;
  $10 = (($internal_buf) + 80|0);
  $11 = (($f) + 16|0);
  HEAP32[$11>>2] = $10;
  $12 = (_printf_core($f,$fmt,$ap2,$nl_arg,$nl_type)|0);
  $13 = ($7|0)==(0|0);
  if ($13) {
   $ret$1 = $12;
  } else {
   $14 = (($f) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   (FUNCTION_TABLE_iiii[$15 & 2047]($f,0,0)|0);
   $16 = HEAP32[$9>>2]|0;
   $17 = ($16|0)==(0|0);
   $$ = $17 ? -1 : $12;
   HEAP32[$6>>2] = $7;
   HEAP32[$2>>2] = 0;
   HEAP32[$11>>2] = 0;
   HEAP32[$8>>2] = 0;
   HEAP32[$9>>2] = 0;
   $ret$1 = $$;
  }
 } else {
  $5 = (_printf_core($f,$fmt,$ap2,$nl_arg,$nl_type)|0);
  $ret$1 = $5;
 }
 $$0 = $ret$1;
 STACKTOP = sp;return ($$0|0);
}
function _printf_core($f,$fmt,$ap,$nl_arg,$nl_type) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 $nl_arg = $nl_arg|0;
 $nl_type = $nl_type|0;
 var $$ = 0, $$$5$i = 0, $$$i = 0, $$$p$i = 0, $$0 = 0, $$0$lcssa$i = 0, $$0$lcssa$i$i = 0, $$0$lcssa$i103$i = 0, $$0$lcssa$i127$i = 0, $$0$lcssa$i142$i = 0, $$0$lcssa$i37 = 0, $$0$lcssa$i38$i = 0, $$0$lcssa$i43 = 0, $$0$lcssa$i45 = 0, $$0$lcssa$i45$i = 0, $$0$lcssa$i48$i = 0, $$0$lcssa$i52 = 0, $$0$lcssa$i55$i = 0, $$0$lcssa$i59 = 0, $$0$lcssa$i62$i = 0;
 var $$0$lcssa$i66 = 0, $$0$lcssa$i68$i = 0, $$0$lcssa$i75$i = 0, $$0$lcssa$i76 = 0, $$0$lcssa$i84$i = 0, $$0$lcssa$i96$i = 0, $$01$i = 0, $$01$i$i = 0, $$01$i101$i = 0, $$01$i125$i = 0, $$01$i140$i = 0, $$01$i35 = 0, $$01$i36$i = 0, $$01$i43$i = 0, $$01$i50 = 0, $$01$i53$i = 0, $$01$i57 = 0, $$01$i60$i = 0, $$01$i64 = 0, $$01$i66$i = 0;
 var $$01$i73$i = 0, $$01$i74 = 0, $$01$i94$i = 0, $$01$lcssa$off0$i = 0, $$01$lcssa$off0$i$i = 0, $$01$lcssa$off0$i85$i = 0, $$012$i = 0, $$013$i = 0, $$03$i40 = 0, $$05$i = 0, $$05$i$i = 0, $$05$i79$i = 0, $$07$i = 0.0, $$1$i = 0.0, $$1$lcssa$i$i = 0, $$1$lcssa$i112$i = 0, $$114$i = 0, $$12$i = 0, $$12$i$i = 0, $$12$i110$i = 0;
 var $$12$i119$i = 0, $$12$i134$i = 0, $$12$i87$i = 0, $$13 = 0, $$14 = 0, $$15 = 0, $$17 = 0, $$2$i = 0.0, $$2$us$i = 0.0, $$2$us$us$i = 0.0, $$2$us159$i = 0.0, $$20$i = 0, $$20$us$i = 0, $$21$i = 0, $$210$$23$i = 0, $$210$$25$i = 0, $$210$i = 0, $$22$i = 0.0, $$23$i = 0, $$25$i = 0;
 var $$3$i = 0.0, $$31$i = 0, $$311$i = 0, $$4$i = 0.0, $$412$lcssa$i = 0, $$412175$i = 0, $$5193$i = 0, $$a$3$i = 0, $$a$3$us$i = 0, $$a$3$us322$i = 0, $$a$3$us323$i = 0, $$a$3324$i = 0, $$a$3325$i = 0, $$fl$4 = 0, $$lcssa300$i = 0, $$lcssa92 = 0, $$mask$i = 0, $$mask$i30 = 0, $$mask1$i = 0, $$mask1$i29 = 0;
 var $$neg151$i = 0, $$neg152$i = 0, $$not$i = 0, $$p$5 = 0, $$p$i = 0, $$pn$i = 0, $$pr$i = 0, $$pr146$i = 0, $$pre = 0, $$pre$i = 0, $$pre290 = 0, $$pre292 = 0, $$pre319$i = 0, $$sum$i = 0, $$sum15$i = 0, $$sum16$i = 0, $$z$3$i = 0, $$z$4$us$i = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0;
 var $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0;
 var $1035 = 0, $1036 = 0.0, $1037 = 0.0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1045$phi = 0, $1046 = 0, $1046$phi = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0;
 var $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0.0;
 var $37 = 0, $370 = 0, $371 = 0.0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0.0, $408 = 0.0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0.0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0.0, $427 = 0.0, $428 = 0.0, $429 = 0.0, $43 = 0, $430 = 0.0, $431 = 0.0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0.0, $481 = 0.0, $482 = 0.0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0.0;
 var $496 = 0.0, $497 = 0.0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0.0, $511 = 0.0, $512 = 0.0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0.0, $526 = 0.0, $527 = 0.0, $528 = 0, $529 = 0, $53 = 0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0;
 var $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0;
 var $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0.0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0.0;
 var $586 = 0.0, $587 = 0.0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0;
 var $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0;
 var $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0;
 var $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0;
 var $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0;
 var $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0;
 var $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0;
 var $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0.0, $726 = 0.0, $727 = 0, $728 = 0.0, $729 = 0;
 var $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0;
 var $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0;
 var $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0;
 var $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0;
 var $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0;
 var $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0;
 var $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0;
 var $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0;
 var $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0;
 var $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0;
 var $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0;
 var $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0;
 var $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0;
 var $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0;
 var $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $a$0 = 0;
 var $a$1 = 0, $a$1$lcssa$i = 0, $a$1263$i = 0, $a$2 = 0, $a$2$ph$i = 0, $a$3$lcssa$i = 0, $a$3249$i = 0, $a$3249$us$i = 0, $a$5$lcssa$i = 0, $a$5223$i = 0, $a$6$i = 0, $a$7$i = 0, $a$8$ph$i = 0, $arglist_current = 0, $arglist_current11 = 0, $arglist_current14 = 0, $arglist_current17 = 0, $arglist_current2 = 0, $arglist_current20 = 0, $arglist_current23 = 0;
 var $arglist_current26 = 0, $arglist_current29 = 0, $arglist_current32 = 0, $arglist_current35 = 0, $arglist_current38 = 0, $arglist_current41 = 0, $arglist_current44 = 0, $arglist_current47 = 0, $arglist_current5 = 0, $arglist_current50 = 0, $arglist_current53 = 0, $arglist_current56 = 0, $arglist_current59 = 0, $arglist_current62 = 0, $arglist_current8 = 0, $arglist_next = 0, $arglist_next12 = 0, $arglist_next15 = 0, $arglist_next18 = 0, $arglist_next21 = 0;
 var $arglist_next24 = 0, $arglist_next27 = 0, $arglist_next3 = 0, $arglist_next30 = 0, $arglist_next33 = 0, $arglist_next36 = 0, $arglist_next39 = 0, $arglist_next42 = 0, $arglist_next45 = 0, $arglist_next48 = 0, $arglist_next51 = 0, $arglist_next54 = 0, $arglist_next57 = 0, $arglist_next6 = 0, $arglist_next60 = 0, $arglist_next63 = 0, $arglist_next9 = 0, $argpos$0 = 0, $big$i = 0, $brmerge$i = 0;
 var $buf = 0, $buf$i = 0, $carry$0255$i = 0, $carry3$0243$i = 0, $carry3$0243$us$i = 0, $cnt$0 = 0, $cnt$1 = 0, $d$0$i = 0, $d$0254$i = 0, $d$0256$i = 0, $d$1242$i = 0, $d$1242$us$i = 0, $d$2$lcssa$i = 0, $d$2222$i = 0, $d$3$i = 0, $d$4183$i = 0, $d$5174$i = 0, $d$6192$i = 0, $e$0238$i = 0, $e$1$i = 0;
 var $e$2218$i = 0, $e$3$i = 0, $e$4$ph$i = 0, $e2$i = 0, $ebuf0$i = 0, $estr$0$i = 0, $estr$1$lcssa$i = 0, $estr$1$ph$i = 0, $estr$1200$i = 0, $estr$2$i = 0, $exitcond$i = 0, $fl$0100 = 0, $fl$0104 = 0, $fl$1 = 0, $fl$1$ = 0, $fl$3 = 0, $fl$4 = 0, $fl$6 = 0, $i$0$lcssa = 0, $i$0166 = 0;
 var $i$0168 = 0, $i$0237$i = 0, $i$03$i = 0, $i$03$i22 = 0, $i$1$lcssa$i = 0, $i$1174 = 0, $i$1230$i = 0, $i$2217$i = 0, $i$289 = 0, $i$3209$i = 0, $i$388 = 0, $isdigit = 0, $isdigit$i = 0, $isdigit$i24 = 0, $isdigit11 = 0, $isdigit2$i = 0, $isdigit2$i21 = 0, $isdigit9 = 0, $isdigittmp = 0, $isdigittmp$i = 0;
 var $isdigittmp$i23 = 0, $isdigittmp1$i = 0, $isdigittmp1$i20 = 0, $isdigittmp10 = 0, $isdigittmp8 = 0, $j$0$i = 0, $j$0229$i = 0, $j$0231$i = 0, $j$1210$i = 0, $j$2$i = 0, $l$0 = 0, $l$0$i = 0, $l$1$i = 0, $l$1$lcssa = 0, $l$1167 = 0, $l10n$0 = 0, $l10n$0$phi = 0, $l10n$1 = 0, $l10n$2 = 0, $l10n$3 = 0;
 var $mb = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i100$i = 0, $or$cond$i35$i = 0, $or$cond$i42$i = 0, $or$cond$i49 = 0, $or$cond$i52$i = 0, $or$cond$i56 = 0, $or$cond$i59$i = 0, $or$cond$i63 = 0, $or$cond$i71 = 0, $or$cond$i72$i = 0, $or$cond$i73 = 0, $or$cond$i93$i = 0, $or$cond28$i = 0, $or$cond28173$i = 0, $or$cond29$i = 0, $or$cond4$i = 0;
 var $p$0 = 0, $p$1 = 0, $p$2 = 0, $p$2$ = 0, $p$4296 = 0, $p$5 = 0, $pad$i = 0, $pl$0 = 0, $pl$0$i = 0, $pl$1 = 0, $pl$1$i = 0, $pl$2 = 0, $prefix$0 = 0, $prefix$0$$i = 0, $prefix$0$i = 0, $prefix$1 = 0, $prefix$2 = 0, $r$0$a$8$i = 0, $re$0$i = 0, $re$1165$i = 0;
 var $round$0164$i = 0.0, $round6$1$i = 0.0, $s$0$i = 0, $s$0$us$i = 0, $s$0$us$us$i = 0, $s$0$us158$i = 0, $s$1$i = 0, $s$1$lcssa$i = 0, $s$1$us$i = 0, $s$1$us$us$i = 0, $s$1$us160$i = 0, $s1$0$i = 0, $s7$0180$i = 0, $s7$1$i = 0, $s8$0$lcssa$i = 0, $s8$0169$i = 0, $s9$0$i = 0, $s9$1188$i = 0, $s9$2$i = 0, $sext = 0;
 var $sext84 = 0, $small$0$i = 0.0, $small$1$i = 0.0, $st$0 = 0, $storemerge = 0, $storemerge12 = 0, $storemerge7103 = 0, $storemerge798 = 0, $t$0 = 0, $t$1 = 0, $w$$i = 0, $w$0 = 0, $w$1 = 0, $w$18$i = 0, $w$2 = 0, $w$30$i = 0, $wc = 0, $ws$0169 = 0, $ws$1175 = 0, $y$03$i = 0;
 var $y$03$i$i = 0, $y$03$i109$i = 0, $y$03$i118$i = 0, $y$03$i133$i = 0, $y$03$i86$i = 0, $z$0$i = 0, $z$0$lcssa = 0, $z$093 = 0, $z$1$lcssa$i = 0, $z$1262$i = 0, $z$2 = 0, $z$2$i = 0, $z$3$lcssa$i = 0, $z$3248$i = 0, $z$3248$us$i = 0, $z$4$i = 0, $z$4$us$i = 0, $z$5$i = 0, $z$6$$i = 0, $z$6$i = 0;
 var $z$6$ph$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 864|0;
 $big$i = sp + 16|0;
 $e2$i = sp;
 $buf$i = sp + 832|0;
 $0 = $buf$i;
 $ebuf0$i = sp + 816|0;
 $pad$i = sp + 520|0;
 $buf = sp + 776|0;
 $wc = sp + 8|0;
 $mb = sp + 828|0;
 $1 = ($f|0)!=(0|0);
 $2 = (($buf) + 40|0);
 $3 = $2;
 $4 = (($buf) + 39|0);
 $5 = (($wc) + 4|0);
 $6 = (($ebuf0$i) + 12|0);
 $7 = (($ebuf0$i) + 11|0);
 $8 = $6;
 $9 = (($8) - ($0))|0;
 $10 = (-2 - ($0))|0;
 $11 = (($8) + 2)|0;
 $12 = (($big$i) + 288|0);
 $13 = (($buf$i) + 9|0);
 $14 = $13;
 $15 = (($buf$i) + 8|0);
 $1045 = 0;$1046 = 0;$22 = $fmt;$cnt$0 = 0;$l$0 = 0;$l10n$0 = 0;
 L1: while(1) {
  $16 = ($cnt$0|0)>(-1);
  do {
   if ($16) {
    $17 = (2147483647 - ($cnt$0))|0;
    $18 = ($l$0|0)>($17|0);
    if ($18) {
     $19 = (___errno_location()|0);
     HEAP32[$19>>2] = 75;
     $cnt$1 = -1;
     break;
    } else {
     $20 = (($l$0) + ($cnt$0))|0;
     $cnt$1 = $20;
     break;
    }
   } else {
    $cnt$1 = $cnt$0;
   }
  } while(0);
  $21 = HEAP8[$22>>0]|0;
  $23 = ($21<<24>>24)==(0);
  if ($23) {
   label = 344;
   break;
  } else {
   $1047 = $21;$25 = $22;
  }
  while(1) {
   if ((($1047<<24>>24) == 37)) {
    $27 = $25;$z$093 = $25;
    label = 9;
    break;
   } else if ((($1047<<24>>24) == 0)) {
    $$lcssa92 = $25;$z$0$lcssa = $25;
    break;
   }
   $24 = (($25) + 1|0);
   $$pre = HEAP8[$24>>0]|0;
   $1047 = $$pre;$25 = $24;
  }
  L12: do {
   if ((label|0) == 9) {
    while(1) {
     label = 0;
     $26 = (($27) + 1|0);
     $28 = HEAP8[$26>>0]|0;
     $29 = ($28<<24>>24)==(37);
     if (!($29)) {
      $$lcssa92 = $27;$z$0$lcssa = $z$093;
      break L12;
     }
     $30 = (($z$093) + 1|0);
     $31 = (($27) + 2|0);
     $32 = HEAP8[$31>>0]|0;
     $33 = ($32<<24>>24)==(37);
     if ($33) {
      $27 = $31;$z$093 = $30;
      label = 9;
     } else {
      $$lcssa92 = $31;$z$0$lcssa = $30;
      break;
     }
    }
   }
  } while(0);
  $34 = $z$0$lcssa;
  $35 = $22;
  $36 = (($34) - ($35))|0;
  if ($1) {
   (___fwritex($22,$36,$f)|0);
  }
  $37 = ($z$0$lcssa|0)==($22|0);
  if (!($37)) {
   $l10n$0$phi = $l10n$0;$1046$phi = $1046;$1045$phi = $1045;$22 = $$lcssa92;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$0$phi;$1046 = $1046$phi;$1045 = $1045$phi;
   continue;
  }
  $38 = (($$lcssa92) + 1|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39 << 24 >> 24;
  $isdigittmp = (($40) + -48)|0;
  $isdigit = ($isdigittmp>>>0)<(10);
  if ($isdigit) {
   $41 = (($$lcssa92) + 2|0);
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(36);
   if ($43) {
    $44 = (($$lcssa92) + 3|0);
    $$pre290 = HEAP8[$44>>0]|0;
    $46 = $$pre290;$argpos$0 = $isdigittmp;$l10n$1 = 1;$storemerge = $44;
   } else {
    $46 = $39;$argpos$0 = -1;$l10n$1 = $l10n$0;$storemerge = $38;
   }
  } else {
   $46 = $39;$argpos$0 = -1;$l10n$1 = $l10n$0;$storemerge = $38;
  }
  $45 = $46 << 24 >> 24;
  $47 = (($45) + -32)|0;
  $48 = ($47>>>0)<(32);
  L25: do {
   if ($48) {
    $50 = $45;$55 = $46;$fl$0104 = 0;$storemerge7103 = $storemerge;
    while(1) {
     $49 = (($50) + -32)|0;
     $51 = 1 << $49;
     $52 = $51 & 75913;
     $53 = ($52|0)==(0);
     if ($53) {
      $65 = $55;$fl$0100 = $fl$0104;$storemerge798 = $storemerge7103;
      break L25;
     }
     $54 = $55 << 24 >> 24;
     $56 = (($54) + -32)|0;
     $57 = 1 << $56;
     $58 = $57 | $fl$0104;
     $59 = (($storemerge7103) + 1|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60 << 24 >> 24;
     $62 = (($61) + -32)|0;
     $63 = ($62>>>0)<(32);
     if ($63) {
      $50 = $61;$55 = $60;$fl$0104 = $58;$storemerge7103 = $59;
     } else {
      $65 = $60;$fl$0100 = $58;$storemerge798 = $59;
      break;
     }
    }
   } else {
    $65 = $46;$fl$0100 = 0;$storemerge798 = $storemerge;
   }
  } while(0);
  $64 = ($65<<24>>24)==(42);
  do {
   if ($64) {
    $66 = (($storemerge798) + 1|0);
    $67 = HEAP8[$66>>0]|0;
    $68 = $67 << 24 >> 24;
    $isdigittmp10 = (($68) + -48)|0;
    $isdigit11 = ($isdigittmp10>>>0)<(10);
    if ($isdigit11) {
     $69 = (($storemerge798) + 2|0);
     $70 = HEAP8[$69>>0]|0;
     $71 = ($70<<24>>24)==(36);
     if ($71) {
      $72 = (($nl_type) + ($isdigittmp10<<2)|0);
      HEAP32[$72>>2] = 10;
      $73 = HEAP8[$66>>0]|0;
      $74 = $73 << 24 >> 24;
      $75 = (($74) + -48)|0;
      $76 = (($nl_arg) + ($75<<3)|0);
      $77 = $76;
      $78 = $77;
      $79 = HEAP32[$78>>2]|0;
      $80 = (($77) + 4)|0;
      $81 = $80;
      $82 = HEAP32[$81>>2]|0;
      $83 = (($storemerge798) + 3|0);
      $l10n$2 = 1;$storemerge12 = $83;$w$0 = $79;
     } else {
      label = 24;
     }
    } else {
     label = 24;
    }
    if ((label|0) == 24) {
     label = 0;
     $84 = ($l10n$1|0)==(0);
     if (!($84)) {
      $$0 = -1;
      label = 362;
      break L1;
     }
     if (!($1)) {
      $100 = $66;$fl$1 = $fl$0100;$l10n$3 = 0;$w$1 = 0;
      break;
     }
     $arglist_current = HEAP32[$ap>>2]|0;
     $85 = HEAP32[$arglist_current>>2]|0;
     $arglist_next = (($arglist_current) + 4|0);
     HEAP32[$ap>>2] = $arglist_next;
     $l10n$2 = 0;$storemerge12 = $66;$w$0 = $85;
    }
    $86 = ($w$0|0)<(0);
    if ($86) {
     $87 = $fl$0100 | 8192;
     $88 = (0 - ($w$0))|0;
     $100 = $storemerge12;$fl$1 = $87;$l10n$3 = $l10n$2;$w$1 = $88;
    } else {
     $100 = $storemerge12;$fl$1 = $fl$0100;$l10n$3 = $l10n$2;$w$1 = $w$0;
    }
   } else {
    $89 = $65 << 24 >> 24;
    $isdigittmp1$i = (($89) + -48)|0;
    $isdigit2$i = ($isdigittmp1$i>>>0)<(10);
    if ($isdigit2$i) {
     $92 = $89;$95 = $storemerge798;$i$03$i = 0;
     while(1) {
      $90 = ($i$03$i*10)|0;
      $91 = (($92) + -48)|0;
      $93 = (($91) + ($90))|0;
      $94 = (($95) + 1|0);
      $96 = HEAP8[$94>>0]|0;
      $97 = $96 << 24 >> 24;
      $isdigittmp$i = (($97) + -48)|0;
      $isdigit$i = ($isdigittmp$i>>>0)<(10);
      if ($isdigit$i) {
       $92 = $97;$95 = $94;$i$03$i = $93;
      } else {
       break;
      }
     }
     $98 = ($93|0)<(0);
     if ($98) {
      $$0 = -1;
      label = 362;
      break L1;
     } else {
      $100 = $94;$fl$1 = $fl$0100;$l10n$3 = $l10n$1;$w$1 = $93;
     }
    } else {
     $100 = $storemerge798;$fl$1 = $fl$0100;$l10n$3 = $l10n$1;$w$1 = 0;
    }
   }
  } while(0);
  $99 = HEAP8[$100>>0]|0;
  $101 = ($99<<24>>24)==(46);
  L46: do {
   if ($101) {
    $102 = (($100) + 1|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = ($103<<24>>24)==(42);
    if (!($104)) {
     $125 = $103 << 24 >> 24;
     $isdigittmp1$i20 = (($125) + -48)|0;
     $isdigit2$i21 = ($isdigittmp1$i20>>>0)<(10);
     if ($isdigit2$i21) {
      $128 = $125;$131 = $102;$i$03$i22 = 0;
     } else {
      $1048 = $102;$p$0 = 0;
      break;
     }
     while(1) {
      $126 = ($i$03$i22*10)|0;
      $127 = (($128) + -48)|0;
      $129 = (($127) + ($126))|0;
      $130 = (($131) + 1|0);
      $132 = HEAP8[$130>>0]|0;
      $133 = $132 << 24 >> 24;
      $isdigittmp$i23 = (($133) + -48)|0;
      $isdigit$i24 = ($isdigittmp$i23>>>0)<(10);
      if ($isdigit$i24) {
       $128 = $133;$131 = $130;$i$03$i22 = $129;
      } else {
       $1048 = $130;$p$0 = $129;
       break L46;
      }
     }
    }
    $105 = (($100) + 2|0);
    $106 = HEAP8[$105>>0]|0;
    $107 = $106 << 24 >> 24;
    $isdigittmp8 = (($107) + -48)|0;
    $isdigit9 = ($isdigittmp8>>>0)<(10);
    if ($isdigit9) {
     $108 = (($100) + 3|0);
     $109 = HEAP8[$108>>0]|0;
     $110 = ($109<<24>>24)==(36);
     if ($110) {
      $111 = (($nl_type) + ($isdigittmp8<<2)|0);
      HEAP32[$111>>2] = 10;
      $112 = HEAP8[$105>>0]|0;
      $113 = $112 << 24 >> 24;
      $114 = (($113) + -48)|0;
      $115 = (($nl_arg) + ($114<<3)|0);
      $116 = $115;
      $117 = $116;
      $118 = HEAP32[$117>>2]|0;
      $119 = (($116) + 4)|0;
      $120 = $119;
      $121 = HEAP32[$120>>2]|0;
      $122 = (($100) + 4|0);
      $1048 = $122;$p$0 = $118;
      break;
     }
    }
    $123 = ($l10n$3|0)==(0);
    if (!($123)) {
     $$0 = -1;
     label = 362;
     break L1;
    }
    if ($1) {
     $arglist_current2 = HEAP32[$ap>>2]|0;
     $124 = HEAP32[$arglist_current2>>2]|0;
     $arglist_next3 = (($arglist_current2) + 4|0);
     HEAP32[$ap>>2] = $arglist_next3;
     $1048 = $105;$p$0 = $124;
    } else {
     $1048 = $105;$p$0 = 0;
    }
   } else {
    $1048 = $100;$p$0 = -1;
   }
  } while(0);
  $135 = $1048;$st$0 = 0;
  while(1) {
   $134 = HEAP8[$135>>0]|0;
   $136 = $134 << 24 >> 24;
   $137 = (($136) + -65)|0;
   $138 = ($137>>>0)>(57);
   if ($138) {
    $$0 = -1;
    label = 362;
    break L1;
   }
   $139 = (($135) + 1|0);
   $140 = ((3110688 + (($st$0*58)|0)|0) + ($137)|0);
   $141 = HEAP8[$140>>0]|0;
   $142 = $141&255;
   $143 = (($142) + -1)|0;
   $144 = ($143>>>0)<(8);
   if ($144) {
    $135 = $139;$st$0 = $142;
   } else {
    break;
   }
  }
  $145 = ($141<<24>>24)==(0);
  if ($145) {
   $$0 = -1;
   label = 362;
   break;
  }
  $146 = ($141<<24>>24)==(19);
  $147 = ($argpos$0|0)>(-1);
  L65: do {
   if ($146) {
    if ($147) {
     $$0 = -1;
     label = 362;
     break L1;
    } else {
     $1049 = $1045;$1050 = $1046;
     label = 63;
    }
   } else {
    if ($147) {
     $148 = (($nl_type) + ($argpos$0<<2)|0);
     HEAP32[$148>>2] = $142;
     $149 = (($nl_arg) + ($argpos$0<<3)|0);
     $150 = $149;
     $151 = $150;
     $152 = HEAP32[$151>>2]|0;
     $153 = (($150) + 4)|0;
     $154 = $153;
     $155 = HEAP32[$154>>2]|0;
     $156 = $152;
     $1049 = $155;$1050 = $156;
     label = 63;
     break;
    }
    if (!($1)) {
     $$0 = 0;
     label = 362;
     break L1;
    }
    $157 = ($141&255)>(20);
    if ($157) {
     $199 = $134;$207 = $1046;$229 = $1045;
    } else {
     do {
      switch ($142|0) {
      case 10:  {
       $arglist_current8 = HEAP32[$ap>>2]|0;
       $159 = HEAP32[$arglist_current8>>2]|0;
       $arglist_next9 = (($arglist_current8) + 4|0);
       HEAP32[$ap>>2] = $arglist_next9;
       $160 = ($159|0)<(0);
       $161 = $160 << 31 >> 31;
       $162 = $159;
       $1051 = $162;$1052 = $161;
       label = 64;
       break L65;
       break;
      }
      case 9:  {
       $arglist_current5 = HEAP32[$ap>>2]|0;
       $158 = HEAP32[$arglist_current5>>2]|0;
       $arglist_next6 = (($arglist_current5) + 4|0);
       HEAP32[$ap>>2] = $arglist_next6;
       $1051 = $158;$1052 = $1045;
       label = 64;
       break L65;
       break;
      }
      case 14:  {
       $arglist_current20 = HEAP32[$ap>>2]|0;
       $179 = HEAP32[$arglist_current20>>2]|0;
       $arglist_next21 = (($arglist_current20) + 4|0);
       HEAP32[$ap>>2] = $arglist_next21;
       $$mask1$i29 = $179 & 65535;
       $180 = $$mask1$i29;
       $1051 = $180;$1052 = 0;
       label = 64;
       break L65;
       break;
      }
      case 11:  {
       $arglist_current11 = HEAP32[$ap>>2]|0;
       $163 = HEAP32[$arglist_current11>>2]|0;
       $arglist_next12 = (($arglist_current11) + 4|0);
       HEAP32[$ap>>2] = $arglist_next12;
       $164 = $163;
       $1051 = $164;$1052 = 0;
       label = 64;
       break L65;
       break;
      }
      case 16:  {
       $arglist_current26 = HEAP32[$ap>>2]|0;
       $188 = HEAP32[$arglist_current26>>2]|0;
       $arglist_next27 = (($arglist_current26) + 4|0);
       HEAP32[$ap>>2] = $arglist_next27;
       $$mask$i30 = $188 & 255;
       $189 = $$mask$i30;
       $1051 = $189;$1052 = 0;
       label = 64;
       break L65;
       break;
      }
      case 12:  {
       $arglist_current14 = HEAP32[$ap>>2]|0;
       $165 = $arglist_current14;
       $166 = $165;
       $167 = HEAP32[$166>>2]|0;
       $168 = (($165) + 4)|0;
       $169 = $168;
       $170 = HEAP32[$169>>2]|0;
       $arglist_next15 = (($arglist_current14) + 8|0);
       HEAP32[$ap>>2] = $arglist_next15;
       $171 = $167;
       $1051 = $171;$1052 = $170;
       label = 64;
       break L65;
       break;
      }
      case 15:  {
       $arglist_current23 = HEAP32[$ap>>2]|0;
       $181 = HEAP32[$arglist_current23>>2]|0;
       $arglist_next24 = (($arglist_current23) + 4|0);
       HEAP32[$ap>>2] = $arglist_next24;
       $182 = $181&255;
       $183 = $182 << 24 >> 24;
       $184 = ($183|0)<(0);
       $185 = $184 << 31 >> 31;
       $sext = $181 << 24;
       $186 = $sext >> 24;
       $187 = $186;
       $1051 = $187;$1052 = $185;
       label = 64;
       break L65;
       break;
      }
      case 18:  {
       $arglist_current32 = HEAP32[$ap>>2]|0;
       HEAP32[tempDoublePtr>>2]=HEAP32[$arglist_current32>>2];HEAP32[tempDoublePtr+4>>2]=HEAP32[$arglist_current32+4>>2];$194 = +HEAPF64[tempDoublePtr>>3];
       $arglist_next33 = (($arglist_current32) + 8|0);
       HEAP32[$ap>>2] = $arglist_next33;
       HEAPF64[tempDoublePtr>>3] = $194;$195 = HEAP32[tempDoublePtr>>2]|0;
       $196 = HEAP32[tempDoublePtr+4>>2]|0;
       $197 = $195;
       $1049 = $196;$1050 = $197;
       label = 63;
       break L65;
       break;
      }
      case 17:  {
       $arglist_current29 = HEAP32[$ap>>2]|0;
       HEAP32[tempDoublePtr>>2]=HEAP32[$arglist_current29>>2];HEAP32[tempDoublePtr+4>>2]=HEAP32[$arglist_current29+4>>2];$190 = +HEAPF64[tempDoublePtr>>3];
       $arglist_next30 = (($arglist_current29) + 8|0);
       HEAP32[$ap>>2] = $arglist_next30;
       HEAPF64[tempDoublePtr>>3] = $190;$191 = HEAP32[tempDoublePtr>>2]|0;
       $192 = HEAP32[tempDoublePtr+4>>2]|0;
       $193 = $191;
       $1051 = $193;$1052 = $192;
       label = 64;
       break L65;
       break;
      }
      case 13:  {
       $arglist_current17 = HEAP32[$ap>>2]|0;
       $172 = HEAP32[$arglist_current17>>2]|0;
       $arglist_next18 = (($arglist_current17) + 4|0);
       HEAP32[$ap>>2] = $arglist_next18;
       $173 = $172&65535;
       $174 = $173 << 16 >> 16;
       $175 = ($174|0)<(0);
       $176 = $175 << 31 >> 31;
       $sext84 = $172 << 16;
       $177 = $sext84 >> 16;
       $178 = $177;
       $1051 = $178;$1052 = $176;
       label = 64;
       break L65;
       break;
      }
      default: {
       $1051 = $1046;$1052 = $1045;
       label = 64;
       break L65;
      }
      }
     } while(0);
    }
   }
  } while(0);
  if ((label|0) == 63) {
   label = 0;
   if ($1) {
    $1051 = $1050;$1052 = $1049;
    label = 64;
   } else {
    $1045 = $1049;$1046 = $1050;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
    continue;
   }
  }
  if ((label|0) == 64) {
   label = 0;
   $$pre292 = HEAP8[$135>>0]|0;
   $199 = $$pre292;$207 = $1051;$229 = $1052;
  }
  $198 = $199 << 24 >> 24;
  $200 = ($st$0|0)==(0);
  if ($200) {
   $t$0 = $198;
  } else {
   $201 = $198 & 15;
   $202 = ($201|0)==(3);
   $203 = $198 & -33;
   $$ = $202 ? $203 : $198;
   $t$0 = $$;
  }
  $204 = $fl$1 & 8192;
  $205 = ($204|0)==(0);
  $206 = $fl$1 & -65537;
  $fl$1$ = $205 ? $fl$1 : $206;
  L92: do {
   switch ($t$0|0) {
   case 112:  {
    $222 = ($p$0>>>0)>(8);
    $223 = $222 ? $p$0 : 8;
    $224 = $fl$1$ | 8;
    $fl$3 = $224;$p$1 = $223;$t$1 = 120;
    label = 77;
    break;
   }
   case 110:  {
    switch ($st$0|0) {
    case 7:  {
     $216 = ($cnt$1|0)<(0);
     $217 = $216 << 31 >> 31;
     $218 = $207;
     $219 = $218;
     HEAP32[$219>>2] = $cnt$1;
     $220 = (($218) + 4)|0;
     $221 = $220;
     HEAP32[$221>>2] = $217;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 1:  {
     HEAP32[$207>>2] = $cnt$1;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 2:  {
     $208 = ($cnt$1|0)<(0);
     $209 = $208 << 31 >> 31;
     $210 = $207;
     $211 = $210;
     HEAP32[$211>>2] = $cnt$1;
     $212 = (($210) + 4)|0;
     $213 = $212;
     HEAP32[$213>>2] = $209;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 4:  {
     $215 = $cnt$1&255;
     HEAP8[$207>>0] = $215;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 0:  {
     HEAP32[$207>>2] = $cnt$1;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 3:  {
     $214 = $cnt$1&65535;
     HEAP16[$207>>1] = $214;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 6:  {
     HEAP32[$207>>2] = $cnt$1;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    default: {
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $36;$l10n$0 = $l10n$3;
     continue L1;
    }
    }
    break;
   }
   case 88: case 120:  {
    $fl$3 = $fl$1$;$p$1 = $p$0;$t$1 = $t$0;
    label = 77;
    break;
   }
   case 111:  {
    $249 = $207;
    $250 = ($249|0)==(0);
    $251 = ($229|0)==(0);
    $252 = $250 & $251;
    if ($252) {
     $$0$lcssa$i43 = $2;
    } else {
     $$03$i40 = $2;$254 = $249;$258 = $229;
     while(1) {
      $253 = $254 & 7;
      $255 = $253 | 48;
      $256 = $255&255;
      $257 = (($$03$i40) + -1|0);
      HEAP8[$257>>0] = $256;
      $259 = (_bitshift64Lshr(($254|0),($258|0),3)|0);
      $260 = tempRet0;
      $261 = ($259|0)==(0);
      $262 = ($260|0)==(0);
      $263 = $261 & $262;
      if ($263) {
       $$0$lcssa$i43 = $257;
       break;
      } else {
       $$03$i40 = $257;$254 = $259;$258 = $260;
      }
     }
    }
    $264 = $fl$1$ & 8;
    $265 = ($264|0)==(0);
    if ($265) {
     $308 = $207;$311 = $229;$a$0 = $$0$lcssa$i43;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = 0;$prefix$1 = 3111152;
     label = 94;
    } else {
     $$13 = $252 ? 3111152 : ((3111152 + 5|0));
     $266 = $252&1;
     $$14 = $266 ^ 1;
     $308 = $207;$311 = $229;$a$0 = $$0$lcssa$i43;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $$14;$prefix$1 = $$13;
     label = 94;
    }
    break;
   }
   case 105: case 100:  {
    $267 = $207;
    $268 = ($229|0)<(0);
    if ($268) {
     $269 = (_i64Subtract(0,0,($267|0),($229|0))|0);
     $270 = tempRet0;
     $271 = $269;
     $277 = $271;$279 = $270;$pl$0 = 1;$prefix$0 = 3111152;
     label = 89;
     break L92;
    }
    $272 = $fl$1$ & 2048;
    $273 = ($272|0)==(0);
    if ($273) {
     $274 = $fl$1$ & 1;
     $275 = ($274|0)==(0);
     $$15 = $275 ? 3111152 : ((3111152 + 2|0));
     $277 = $207;$279 = $229;$pl$0 = $274;$prefix$0 = $$15;
     label = 89;
    } else {
     $277 = $207;$279 = $229;$pl$0 = 1;$prefix$0 = ((3111152 + 1|0));
     label = 89;
    }
    break;
   }
   case 117:  {
    $277 = $207;$279 = $229;$pl$0 = 0;$prefix$0 = 3111152;
    label = 89;
    break;
   }
   case 115:  {
    $324 = ($207|0)==(0|0);
    $$17 = $324 ? 3111168 : $207;
    $a$1 = $$17;
    label = 99;
    break;
   }
   case 99:  {
    $319 = $207;
    $320 = $319&255;
    HEAP8[$4>>0] = $320;
    $1053 = $229;$1054 = $207;$a$2 = $4;$fl$6 = $206;$p$5 = 1;$pl$2 = 0;$prefix$2 = 3111152;$z$2 = $2;
    break;
   }
   case 67:  {
    $331 = $207;
    HEAP32[$wc>>2] = $331;
    HEAP32[$5>>2] = 0;
    $1055 = $wc;$1056 = $wc;$p$4296 = -1;
    label = 104;
    break;
   }
   case 109:  {
    $321 = (___errno_location()|0);
    $322 = HEAP32[$321>>2]|0;
    $323 = (_strerror(($322|0))|0);
    $a$1 = $323;
    label = 99;
    break;
   }
   case 65: case 71: case 70: case 69: case 97: case 103: case 102: case 101:  {
    $368 = $207;
    HEAP32[tempDoublePtr>>2] = $368;HEAP32[tempDoublePtr+4>>2] = $229;$369 = +HEAPF64[tempDoublePtr>>3];
    HEAP32[$e2$i>>2] = 0;
    $370 = ($229|0)<(0);
    if ($370) {
     $371 = -$369;
     $$07$i = $371;$pl$0$i = 1;$prefix$0$i = 3111176;
    } else {
     $372 = $fl$1$ & 2048;
     $373 = ($372|0)==(0);
     if ($373) {
      $374 = $fl$1$ & 1;
      $375 = ($374|0)==(0);
      $$$i = $375 ? ((3111176 + 1|0)) : ((3111176 + 6|0));
      $$07$i = $369;$pl$0$i = $374;$prefix$0$i = $$$i;
     } else {
      $$07$i = $369;$pl$0$i = 1;$prefix$0$i = ((3111176 + 3|0));
     }
    }
    HEAPF64[tempDoublePtr>>3] = $$07$i;$376 = HEAP32[tempDoublePtr>>2]|0;
    $377 = HEAP32[tempDoublePtr+4>>2]|0;
    $378 = $377 & 2146435072;
    $379 = ($378>>>0)<(2146435072);
    $380 = ($378|0)==(2146435072);
    $381 = (0)<(0);
    $382 = $380 & $381;
    $383 = $379 | $382;
    if (!($383)) {
     $384 = $t$0 & 32;
     $385 = ($384|0)!=(0);
     $386 = $385 ? 3111200 : 3111208;
     $387 = ($$07$i != $$07$i) | (0.0 != 0.0);
     if ($387) {
      $388 = $385 ? 3111216 : 3111224;
      $pl$1$i = 0;$s1$0$i = $388;
     } else {
      $pl$1$i = $pl$0$i;$s1$0$i = $386;
     }
     $389 = (($pl$1$i) + 3)|0;
     $390 = $fl$1$ & 8192;
     $391 = ($390|0)==(0);
     $392 = ($389|0)<($w$1|0);
     $or$cond$i35$i = $391 & $392;
     if ($or$cond$i35$i) {
      $393 = (($w$1) - ($389))|0;
      $394 = ($393>>>0)>(256);
      $395 = $394 ? 256 : $393;
      _memset(($pad$i|0),32,($395|0))|0;
      $396 = ($393>>>0)>(255);
      if ($396) {
       $$01$i36$i = $393;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $397 = (($$01$i36$i) + -256)|0;
        $398 = ($397>>>0)>(255);
        if ($398) {
         $$01$i36$i = $397;
        } else {
         $$0$lcssa$i38$i = $397;
         break;
        }
       }
      } else {
       $$0$lcssa$i38$i = $393;
      }
      (___fwritex($pad$i,$$0$lcssa$i38$i,$f)|0);
     }
     (___fwritex($prefix$0$i,$pl$1$i,$f)|0);
     (___fwritex($s1$0$i,3,$f)|0);
     $399 = $fl$1$ & 73728;
     $400 = ($399|0)==(8192);
     $or$cond$i42$i = $400 & $392;
     if ($or$cond$i42$i) {
      $401 = (($w$1) - ($389))|0;
      $402 = ($401>>>0)>(256);
      $403 = $402 ? 256 : $401;
      _memset(($pad$i|0),32,($403|0))|0;
      $404 = ($401>>>0)>(255);
      if ($404) {
       $$01$i43$i = $401;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $405 = (($$01$i43$i) + -256)|0;
        $406 = ($405>>>0)>(255);
        if ($406) {
         $$01$i43$i = $405;
        } else {
         $$0$lcssa$i45$i = $405;
         break;
        }
       }
      } else {
       $$0$lcssa$i45$i = $401;
      }
      (___fwritex($pad$i,$$0$lcssa$i45$i,$f)|0);
     }
     $w$$i = $392 ? $w$1 : $389;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$$i;$l10n$0 = $l10n$3;
     continue L1;
    }
    $407 = (+_frexpl($$07$i,$e2$i));
    $408 = $407 * 2.0;
    $409 = $408 != 0.0;
    if ($409) {
     $410 = HEAP32[$e2$i>>2]|0;
     $411 = (($410) + -1)|0;
     HEAP32[$e2$i>>2] = $411;
    }
    $412 = $t$0 | 32;
    $413 = ($412|0)==(97);
    if ($413) {
     $414 = $t$0 & 32;
     $415 = ($414|0)==(0);
     $416 = (($prefix$0$i) + 9|0);
     $prefix$0$$i = $415 ? $prefix$0$i : $416;
     $417 = $pl$0$i | 2;
     $418 = ($p$0>>>0)>(11);
     $419 = (12 - ($p$0))|0;
     $re$0$i = $418 ? 0 : $419;
     $420 = ($re$0$i|0)==(0);
     do {
      if ($420) {
       $$1$i = $408;
      } else {
       $re$1165$i = $re$0$i;$round$0164$i = 8.0;
       while(1) {
        $421 = (($re$1165$i) + -1)|0;
        $422 = $round$0164$i * 16.0;
        $423 = ($421|0)==(0);
        if ($423) {
         break;
        } else {
         $re$1165$i = $421;$round$0164$i = $422;
        }
       }
       $424 = HEAP8[$prefix$0$$i>>0]|0;
       $425 = ($424<<24>>24)==(45);
       if ($425) {
        $426 = -$408;
        $427 = $426 - $422;
        $428 = $422 + $427;
        $429 = -$428;
        $$1$i = $429;
        break;
       } else {
        $430 = $408 + $422;
        $431 = $430 - $422;
        $$1$i = $431;
        break;
       }
      }
     } while(0);
     $432 = HEAP32[$e2$i>>2]|0;
     $433 = ($432|0)<(0);
     $434 = (0 - ($432))|0;
     $435 = $433 ? $434 : $432;
     $436 = ($435|0)<(0);
     if ($436) {
      $437 = ($435|0)<(0);
      $438 = $437 << 31 >> 31;
      $$05$i$i = $6;$439 = $435;$440 = $438;
      while(1) {
       $441 = (___uremdi3(($439|0),($440|0),10,0)|0);
       $442 = tempRet0;
       $443 = $441 | 48;
       $444 = $443&255;
       $445 = (($$05$i$i) + -1|0);
       HEAP8[$445>>0] = $444;
       $446 = (___udivdi3(($439|0),($440|0),10,0)|0);
       $447 = tempRet0;
       $448 = ($440>>>0)>(9);
       $449 = ($440|0)==(9);
       $450 = ($439>>>0)>(4294967295);
       $451 = $449 & $450;
       $452 = $448 | $451;
       if ($452) {
        $$05$i$i = $445;$439 = $446;$440 = $447;
       } else {
        break;
       }
      }
      $$0$lcssa$i48$i = $445;$$01$lcssa$off0$i$i = $446;
     } else {
      $$0$lcssa$i48$i = $6;$$01$lcssa$off0$i$i = $435;
     }
     $453 = ($$01$lcssa$off0$i$i|0)==(0);
     if ($453) {
      $$1$lcssa$i$i = $$0$lcssa$i48$i;
     } else {
      $$12$i$i = $$0$lcssa$i48$i;$y$03$i$i = $$01$lcssa$off0$i$i;
      while(1) {
       $454 = (($y$03$i$i>>>0) % 10)&-1;
       $455 = $454 | 48;
       $456 = $455&255;
       $457 = (($$12$i$i) + -1|0);
       HEAP8[$457>>0] = $456;
       $458 = (($y$03$i$i>>>0) / 10)&-1;
       $459 = ($y$03$i$i>>>0)<(10);
       if ($459) {
        $$1$lcssa$i$i = $457;
        break;
       } else {
        $$12$i$i = $457;$y$03$i$i = $458;
       }
      }
     }
     $460 = ($$1$lcssa$i$i|0)==($6|0);
     if ($460) {
      HEAP8[$7>>0] = 48;
      $estr$0$i = $7;
     } else {
      $estr$0$i = $$1$lcssa$i$i;
     }
     $461 = HEAP32[$e2$i>>2]|0;
     $462 = $461 >> 31;
     $463 = $462 & 2;
     $464 = (($463) + 43)|0;
     $465 = $464&255;
     $466 = (($estr$0$i) + -1|0);
     HEAP8[$466>>0] = $465;
     $467 = (($t$0) + 15)|0;
     $468 = $467&255;
     $469 = (($estr$0$i) + -2|0);
     HEAP8[$469>>0] = $468;
     $470 = ($p$0|0)>(0);
     $471 = $fl$1$ & 8;
     $472 = ($471|0)==(0);
     if ($470) {
      if ($472) {
       $$2$us$us$i = $$1$i;$s$0$us$us$i = $buf$i;
       while(1) {
        $473 = (~~(($$2$us$us$i)));
        $474 = (3111232 + ($473)|0);
        $475 = HEAP8[$474>>0]|0;
        $476 = $475&255;
        $477 = $476 | $414;
        $478 = $477&255;
        $479 = (($s$0$us$us$i) + 1|0);
        HEAP8[$s$0$us$us$i>>0] = $478;
        $480 = (+($473|0));
        $481 = $$2$us$us$i - $480;
        $482 = $481 * 16.0;
        $483 = $479;
        $484 = (($483) - ($0))|0;
        $485 = ($484|0)==(1);
        if ($485) {
         $486 = (($s$0$us$us$i) + 2|0);
         HEAP8[$479>>0] = 46;
         $s$1$us$us$i = $486;
        } else {
         $s$1$us$us$i = $479;
        }
        $487 = $482 != 0.0;
        if ($487) {
         $$2$us$us$i = $482;$s$0$us$us$i = $s$1$us$us$i;
        } else {
         $s$1$lcssa$i = $s$1$us$us$i;
         break;
        }
       }
      } else {
       $$2$us$i = $$1$i;$s$0$us$i = $buf$i;
       while(1) {
        $488 = (~~(($$2$us$i)));
        $489 = (3111232 + ($488)|0);
        $490 = HEAP8[$489>>0]|0;
        $491 = $490&255;
        $492 = $491 | $414;
        $493 = $492&255;
        $494 = (($s$0$us$i) + 1|0);
        HEAP8[$s$0$us$i>>0] = $493;
        $495 = (+($488|0));
        $496 = $$2$us$i - $495;
        $497 = $496 * 16.0;
        $498 = $494;
        $499 = (($498) - ($0))|0;
        $500 = ($499|0)==(1);
        if ($500) {
         $501 = (($s$0$us$i) + 2|0);
         HEAP8[$494>>0] = 46;
         $s$1$us$i = $501;
        } else {
         $s$1$us$i = $494;
        }
        $502 = $497 != 0.0;
        if ($502) {
         $$2$us$i = $497;$s$0$us$i = $s$1$us$i;
        } else {
         $s$1$lcssa$i = $s$1$us$i;
         break;
        }
       }
      }
     } else {
      if ($472) {
       $$2$us159$i = $$1$i;$s$0$us158$i = $buf$i;
       while(1) {
        $503 = (~~(($$2$us159$i)));
        $504 = (3111232 + ($503)|0);
        $505 = HEAP8[$504>>0]|0;
        $506 = $505&255;
        $507 = $506 | $414;
        $508 = $507&255;
        $509 = (($s$0$us158$i) + 1|0);
        HEAP8[$s$0$us158$i>>0] = $508;
        $510 = (+($503|0));
        $511 = $$2$us159$i - $510;
        $512 = $511 * 16.0;
        $513 = $509;
        $514 = (($513) - ($0))|0;
        $515 = ($514|0)==(1);
        $516 = $512 != 0.0;
        $or$cond$i71 = $515 & $516;
        if ($or$cond$i71) {
         $517 = (($s$0$us158$i) + 2|0);
         HEAP8[$509>>0] = 46;
         $s$1$us160$i = $517;
        } else {
         $s$1$us160$i = $509;
        }
        if ($516) {
         $$2$us159$i = $512;$s$0$us158$i = $s$1$us160$i;
        } else {
         $s$1$lcssa$i = $s$1$us160$i;
         break;
        }
       }
      } else {
       $$2$i = $$1$i;$s$0$i = $buf$i;
       while(1) {
        $518 = (~~(($$2$i)));
        $519 = (3111232 + ($518)|0);
        $520 = HEAP8[$519>>0]|0;
        $521 = $520&255;
        $522 = $521 | $414;
        $523 = $522&255;
        $524 = (($s$0$i) + 1|0);
        HEAP8[$s$0$i>>0] = $523;
        $525 = (+($518|0));
        $526 = $$2$i - $525;
        $527 = $526 * 16.0;
        $528 = $524;
        $529 = (($528) - ($0))|0;
        $530 = ($529|0)==(1);
        if ($530) {
         $531 = (($s$0$i) + 2|0);
         HEAP8[$524>>0] = 46;
         $s$1$i = $531;
        } else {
         $s$1$i = $524;
        }
        $532 = $527 != 0.0;
        if ($532) {
         $$2$i = $527;$s$0$i = $s$1$i;
        } else {
         $s$1$lcssa$i = $s$1$i;
         break;
        }
       }
      }
     }
     $533 = ($p$0|0)==(0);
     $$pre319$i = $s$1$lcssa$i;
     do {
      if ($533) {
       label = 173;
      } else {
       $534 = (($10) + ($$pre319$i))|0;
       $535 = ($534|0)<($p$0|0);
       if (!($535)) {
        label = 173;
        break;
       }
       $536 = $469;
       $537 = (($11) + ($p$0))|0;
       $538 = (($537) - ($536))|0;
       $l$0$i = $538;
      }
     } while(0);
     if ((label|0) == 173) {
      label = 0;
      $539 = $469;
      $540 = (($9) - ($539))|0;
      $541 = (($540) + ($$pre319$i))|0;
      $l$0$i = $541;
     }
     $542 = (($l$0$i) + ($417))|0;
     $543 = $fl$1$ & 73728;
     $544 = ($543|0)==(0);
     $545 = ($542|0)<($w$1|0);
     $or$cond$i52$i = $544 & $545;
     if ($or$cond$i52$i) {
      $546 = (($w$1) - ($542))|0;
      $547 = ($546>>>0)>(256);
      $548 = $547 ? 256 : $546;
      _memset(($pad$i|0),32,($548|0))|0;
      $549 = ($546>>>0)>(255);
      if ($549) {
       $$01$i53$i = $546;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $550 = (($$01$i53$i) + -256)|0;
        $551 = ($550>>>0)>(255);
        if ($551) {
         $$01$i53$i = $550;
        } else {
         $$0$lcssa$i55$i = $550;
         break;
        }
       }
      } else {
       $$0$lcssa$i55$i = $546;
      }
      (___fwritex($pad$i,$$0$lcssa$i55$i,$f)|0);
     }
     (___fwritex($prefix$0$$i,$417,$f)|0);
     $552 = ($543|0)==(65536);
     $or$cond$i59$i = $552 & $545;
     if ($or$cond$i59$i) {
      $553 = (($w$1) - ($542))|0;
      $554 = ($553>>>0)>(256);
      $555 = $554 ? 256 : $553;
      _memset(($pad$i|0),48,($555|0))|0;
      $556 = ($553>>>0)>(255);
      if ($556) {
       $$01$i60$i = $553;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $557 = (($$01$i60$i) + -256)|0;
        $558 = ($557>>>0)>(255);
        if ($558) {
         $$01$i60$i = $557;
        } else {
         $$0$lcssa$i62$i = $557;
         break;
        }
       }
      } else {
       $$0$lcssa$i62$i = $553;
      }
      (___fwritex($pad$i,$$0$lcssa$i62$i,$f)|0);
     }
     $559 = (($$pre319$i) - ($0))|0;
     (___fwritex($buf$i,$559,$f)|0);
     $560 = $469;
     $561 = (($8) - ($560))|0;
     $562 = (($l$0$i) - ($561))|0;
     $563 = (($562) - ($559))|0;
     $564 = ($563|0)>(0);
     if ($564) {
      $565 = ($563>>>0)>(256);
      $566 = $565 ? 256 : $563;
      _memset(($pad$i|0),48,($566|0))|0;
      $567 = ($563>>>0)>(255);
      if ($567) {
       $$01$i66$i = $563;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $568 = (($$01$i66$i) + -256)|0;
        $569 = ($568>>>0)>(255);
        if ($569) {
         $$01$i66$i = $568;
        } else {
         $$0$lcssa$i68$i = $568;
         break;
        }
       }
      } else {
       $$0$lcssa$i68$i = $563;
      }
      (___fwritex($pad$i,$$0$lcssa$i68$i,$f)|0);
     }
     (___fwritex($469,$561,$f)|0);
     $570 = ($543|0)==(8192);
     $or$cond$i72$i = $570 & $545;
     if ($or$cond$i72$i) {
      $571 = (($w$1) - ($542))|0;
      $572 = ($571>>>0)>(256);
      $573 = $572 ? 256 : $571;
      _memset(($pad$i|0),32,($573|0))|0;
      $574 = ($571>>>0)>(255);
      if ($574) {
       $$01$i73$i = $571;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $575 = (($$01$i73$i) + -256)|0;
        $576 = ($575>>>0)>(255);
        if ($576) {
         $$01$i73$i = $575;
        } else {
         $$0$lcssa$i75$i = $575;
         break;
        }
       }
      } else {
       $$0$lcssa$i75$i = $571;
      }
      (___fwritex($pad$i,$$0$lcssa$i75$i,$f)|0);
     }
     $w$18$i = $545 ? $w$1 : $542;
     $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$18$i;$l10n$0 = $l10n$3;
     continue L1;
    }
    $577 = ($p$0|0)<(0);
    $$p$i = $577 ? 6 : $p$0;
    if ($409) {
     $578 = $408 * 268435456.0;
     $579 = HEAP32[$e2$i>>2]|0;
     $580 = (($579) + -28)|0;
     HEAP32[$e2$i>>2] = $580;
     $$3$i = $578;$582 = $580;
    } else {
     $$pre$i = HEAP32[$e2$i>>2]|0;
     $$3$i = $408;$582 = $$pre$i;
    }
    $581 = ($582|0)<(0);
    $$31$i = $581 ? $big$i : $12;
    $$4$i = $$3$i;$z$0$i = $$31$i;
    while(1) {
     $583 = (~~(($$4$i))>>>0);
     HEAP32[$z$0$i>>2] = $583;
     $584 = (($z$0$i) + 4|0);
     $585 = (+($583>>>0));
     $586 = $$4$i - $585;
     $587 = $586 * 1.0E+9;
     $588 = $587 != 0.0;
     if ($588) {
      $$4$i = $587;$z$0$i = $584;
     } else {
      break;
     }
    }
    $$pr$i = HEAP32[$e2$i>>2]|0;
    $589 = ($$pr$i|0)>(0);
    if ($589) {
     $591 = $$pr$i;$a$1263$i = $$31$i;$z$1262$i = $584;
     while(1) {
      $590 = ($591|0)>(29);
      $592 = $590 ? 29 : $591;
      $d$0254$i = (($z$1262$i) + -4|0);
      $593 = ($d$0254$i>>>0)<($a$1263$i>>>0);
      do {
       if ($593) {
        $a$2$ph$i = $a$1263$i;
       } else {
        $carry$0255$i = 0;$d$0256$i = $d$0254$i;
        while(1) {
         $594 = HEAP32[$d$0256$i>>2]|0;
         $595 = (_bitshift64Shl(($594|0),0,($592|0))|0);
         $596 = tempRet0;
         $597 = (_i64Add(($595|0),($596|0),($carry$0255$i|0),0)|0);
         $598 = tempRet0;
         $599 = (___uremdi3(($597|0),($598|0),1000000000,0)|0);
         $600 = tempRet0;
         HEAP32[$d$0256$i>>2] = $599;
         $601 = (___udivdi3(($597|0),($598|0),1000000000,0)|0);
         $602 = tempRet0;
         $d$0$i = (($d$0256$i) + -4|0);
         $603 = ($d$0$i>>>0)<($a$1263$i>>>0);
         if ($603) {
          break;
         } else {
          $carry$0255$i = $601;$d$0256$i = $d$0$i;
         }
        }
        $604 = ($601|0)==(0);
        if ($604) {
         $a$2$ph$i = $a$1263$i;
         break;
        }
        $605 = (($a$1263$i) + -4|0);
        HEAP32[$605>>2] = $601;
        $a$2$ph$i = $605;
       }
      } while(0);
      $z$2$i = $z$1262$i;
      while(1) {
       $606 = ($z$2$i>>>0)>($a$2$ph$i>>>0);
       if (!($606)) {
        break;
       }
       $607 = (($z$2$i) + -4|0);
       $608 = HEAP32[$607>>2]|0;
       $609 = ($608|0)==(0);
       if ($609) {
        $z$2$i = $607;
       } else {
        break;
       }
      }
      $610 = HEAP32[$e2$i>>2]|0;
      $611 = (($610) - ($592))|0;
      HEAP32[$e2$i>>2] = $611;
      $612 = ($611|0)>(0);
      if ($612) {
       $591 = $611;$a$1263$i = $a$2$ph$i;$z$1262$i = $z$2$i;
      } else {
       $$pr146$i = $611;$a$1$lcssa$i = $a$2$ph$i;$z$1$lcssa$i = $z$2$i;
       break;
      }
     }
    } else {
     $$pr146$i = $$pr$i;$a$1$lcssa$i = $$31$i;$z$1$lcssa$i = $584;
    }
    $613 = ($$pr146$i|0)<(0);
    L253: do {
     if ($613) {
      $614 = (($$p$i) + 25)|0;
      $615 = (($614|0) / 9)&-1;
      $616 = (($615) + 1)|0;
      $617 = ($412|0)==(102);
      if ($617) {
       $618 = $$31$i;
       $619 = (($$31$i) + ($616<<2)|0);
       $621 = $$pr146$i;$a$3249$us$i = $a$1$lcssa$i;$z$3248$us$i = $z$1$lcssa$i;
       while(1) {
        $620 = (0 - ($621))|0;
        $622 = ($620|0)>(9);
        $$20$us$i = $622 ? 9 : $620;
        $623 = ($a$3249$us$i>>>0)<($z$3248$us$i>>>0);
        do {
         if ($623) {
          $648 = 1 << $$20$us$i;
          $642 = (($648) + -1)|0;
          $645 = 1000000000 >>> $$20$us$i;
          $carry3$0243$us$i = 0;$d$1242$us$i = $a$3249$us$i;
          while(1) {
           $640 = HEAP32[$d$1242$us$i>>2]|0;
           $641 = $640 & $642;
           $643 = $640 >>> $$20$us$i;
           $644 = (($643) + ($carry3$0243$us$i))|0;
           HEAP32[$d$1242$us$i>>2] = $644;
           $631 = Math_imul($641, $645)|0;
           $646 = (($d$1242$us$i) + 4|0);
           $647 = ($646>>>0)<($z$3248$us$i>>>0);
           if ($647) {
            $carry3$0243$us$i = $631;$d$1242$us$i = $646;
           } else {
            break;
           }
          }
          $627 = HEAP32[$a$3249$us$i>>2]|0;
          $628 = ($627|0)==(0);
          $629 = (($a$3249$us$i) + 4|0);
          $$a$3$us$i = $628 ? $629 : $a$3249$us$i;
          $630 = ($631|0)==(0);
          if ($630) {
           $$a$3$us323$i = $$a$3$us$i;$z$4$us$i = $z$3248$us$i;
           break;
          }
          $632 = (($z$3248$us$i) + 4|0);
          HEAP32[$z$3248$us$i>>2] = $631;
          $$a$3$us323$i = $$a$3$us$i;$z$4$us$i = $632;
         } else {
          $624 = HEAP32[$a$3249$us$i>>2]|0;
          $625 = ($624|0)==(0);
          $626 = (($a$3249$us$i) + 4|0);
          $$a$3$us322$i = $625 ? $626 : $a$3249$us$i;
          $$a$3$us323$i = $$a$3$us322$i;$z$4$us$i = $z$3248$us$i;
         }
        } while(0);
        $633 = $z$4$us$i;
        $634 = (($633) - ($618))|0;
        $635 = $634 >> 2;
        $636 = ($635|0)>($616|0);
        $$z$4$us$i = $636 ? $619 : $z$4$us$i;
        $637 = HEAP32[$e2$i>>2]|0;
        $638 = (($637) + ($$20$us$i))|0;
        HEAP32[$e2$i>>2] = $638;
        $639 = ($638|0)<(0);
        if ($639) {
         $621 = $638;$a$3249$us$i = $$a$3$us323$i;$z$3248$us$i = $$z$4$us$i;
        } else {
         $a$3$lcssa$i = $$a$3$us323$i;$z$3$lcssa$i = $$z$4$us$i;
         break L253;
        }
       }
      } else {
       $650 = $$pr146$i;$a$3249$i = $a$1$lcssa$i;$z$3248$i = $z$1$lcssa$i;
      }
      while(1) {
       $649 = (0 - ($650))|0;
       $651 = ($649|0)>(9);
       $$20$i = $651 ? 9 : $649;
       $652 = ($a$3249$i>>>0)<($z$3248$i>>>0);
       do {
        if ($652) {
         $656 = 1 << $$20$i;
         $657 = (($656) + -1)|0;
         $658 = 1000000000 >>> $$20$i;
         $carry3$0243$i = 0;$d$1242$i = $a$3249$i;
         while(1) {
          $659 = HEAP32[$d$1242$i>>2]|0;
          $660 = $659 & $657;
          $661 = $659 >>> $$20$i;
          $662 = (($661) + ($carry3$0243$i))|0;
          HEAP32[$d$1242$i>>2] = $662;
          $663 = Math_imul($660, $658)|0;
          $664 = (($d$1242$i) + 4|0);
          $665 = ($664>>>0)<($z$3248$i>>>0);
          if ($665) {
           $carry3$0243$i = $663;$d$1242$i = $664;
          } else {
           break;
          }
         }
         $666 = HEAP32[$a$3249$i>>2]|0;
         $667 = ($666|0)==(0);
         $668 = (($a$3249$i) + 4|0);
         $$a$3$i = $667 ? $668 : $a$3249$i;
         $669 = ($663|0)==(0);
         if ($669) {
          $$a$3325$i = $$a$3$i;$z$4$i = $z$3248$i;
          break;
         }
         $670 = (($z$3248$i) + 4|0);
         HEAP32[$z$3248$i>>2] = $663;
         $$a$3325$i = $$a$3$i;$z$4$i = $670;
        } else {
         $653 = HEAP32[$a$3249$i>>2]|0;
         $654 = ($653|0)==(0);
         $655 = (($a$3249$i) + 4|0);
         $$a$3324$i = $654 ? $655 : $a$3249$i;
         $$a$3325$i = $$a$3324$i;$z$4$i = $z$3248$i;
        }
       } while(0);
       $671 = $z$4$i;
       $672 = $$a$3325$i;
       $673 = (($671) - ($672))|0;
       $674 = $673 >> 2;
       $675 = ($674|0)>($616|0);
       if ($675) {
        $676 = (($$a$3325$i) + ($616<<2)|0);
        $z$5$i = $676;
       } else {
        $z$5$i = $z$4$i;
       }
       $677 = HEAP32[$e2$i>>2]|0;
       $678 = (($677) + ($$20$i))|0;
       HEAP32[$e2$i>>2] = $678;
       $679 = ($678|0)<(0);
       if ($679) {
        $650 = $678;$a$3249$i = $$a$3325$i;$z$3248$i = $z$5$i;
       } else {
        $a$3$lcssa$i = $$a$3325$i;$z$3$lcssa$i = $z$5$i;
        break;
       }
      }
     } else {
      $a$3$lcssa$i = $a$1$lcssa$i;$z$3$lcssa$i = $z$1$lcssa$i;
     }
    } while(0);
    $680 = ($a$3$lcssa$i>>>0)<($z$3$lcssa$i>>>0);
    $681 = $$31$i;
    do {
     if ($680) {
      $682 = $a$3$lcssa$i;
      $683 = (($681) - ($682))|0;
      $684 = $683 >> 2;
      $685 = ($684*9)|0;
      $686 = HEAP32[$a$3$lcssa$i>>2]|0;
      $687 = ($686>>>0)<(10);
      if ($687) {
       $e$1$i = $685;
       break;
      } else {
       $e$0238$i = $685;$i$0237$i = 10;
      }
      while(1) {
       $688 = ($i$0237$i*10)|0;
       $689 = (($e$0238$i) + 1)|0;
       $690 = ($686>>>0)<($688>>>0);
       if ($690) {
        $e$1$i = $689;
        break;
       } else {
        $e$0238$i = $689;$i$0237$i = $688;
       }
      }
     } else {
      $e$1$i = 0;
     }
    } while(0);
    $691 = ($412|0)!=(102);
    $692 = $691 ? $e$1$i : 0;
    $693 = (($$p$i) - ($692))|0;
    $694 = ($412|0)==(103);
    $695 = ($$p$i|0)!=(0);
    $$21$i = $694 & $695;
    $$neg151$i = $$21$i << 31 >> 31;
    $696 = (($693) + ($$neg151$i))|0;
    $697 = $z$3$lcssa$i;
    $698 = (($697) - ($681))|0;
    $699 = $698 >> 2;
    $700 = ($699*9)|0;
    $701 = (($700) + -9)|0;
    $702 = ($696|0)<($701|0);
    if ($702) {
     $703 = (($696) + 9216)|0;
     $704 = (($703|0) / 9)&-1;
     $$sum$i = (($704) + -1023)|0;
     $705 = (($$31$i) + ($$sum$i<<2)|0);
     $706 = (($703|0) % 9)&-1;
     $j$0229$i = (($706) + 1)|0;
     $707 = ($j$0229$i|0)<(9);
     if ($707) {
      $i$1230$i = 10;$j$0231$i = $j$0229$i;
      while(1) {
       $708 = ($i$1230$i*10)|0;
       $j$0$i = (($j$0231$i) + 1)|0;
       $exitcond$i = ($j$0$i|0)==(9);
       if ($exitcond$i) {
        $i$1$lcssa$i = $708;
        break;
       } else {
        $i$1230$i = $708;$j$0231$i = $j$0$i;
       }
      }
     } else {
      $i$1$lcssa$i = 10;
     }
     $709 = HEAP32[$705>>2]|0;
     $710 = (($709>>>0) % ($i$1$lcssa$i>>>0))&-1;
     $711 = ($710|0)==(0);
     if ($711) {
      $$sum15$i = (($704) + -1022)|0;
      $712 = (($$31$i) + ($$sum15$i<<2)|0);
      $713 = ($712|0)==($z$3$lcssa$i|0);
      if ($713) {
       $a$7$i = $a$3$lcssa$i;$d$3$i = $705;$e$3$i = $e$1$i;
      } else {
       label = 233;
      }
     } else {
      label = 233;
     }
     do {
      if ((label|0) == 233) {
       label = 0;
       $714 = (($709>>>0) / ($i$1$lcssa$i>>>0))&-1;
       $715 = $714 & 1;
       $716 = ($715|0)==(0);
       $$22$i = $716 ? 9007199254740992.0 : 9007199254740994.0;
       $717 = (($i$1$lcssa$i|0) / 2)&-1;
       $718 = ($710>>>0)<($717>>>0);
       do {
        if ($718) {
         $small$0$i = 0.5;
        } else {
         $719 = ($710|0)==($717|0);
         if ($719) {
          $$sum16$i = (($704) + -1022)|0;
          $720 = (($$31$i) + ($$sum16$i<<2)|0);
          $721 = ($720|0)==($z$3$lcssa$i|0);
          if ($721) {
           $small$0$i = 1.0;
           break;
          }
         }
         $small$0$i = 1.5;
        }
       } while(0);
       $722 = ($pl$0$i|0)==(0);
       do {
        if ($722) {
         $round6$1$i = $$22$i;$small$1$i = $small$0$i;
        } else {
         $723 = HEAP8[$prefix$0$i>>0]|0;
         $724 = ($723<<24>>24)==(45);
         if (!($724)) {
          $round6$1$i = $$22$i;$small$1$i = $small$0$i;
          break;
         }
         $725 = $$22$i * -1.0;
         $726 = $small$0$i * -1.0;
         $round6$1$i = $725;$small$1$i = $726;
        }
       } while(0);
       $727 = (($709) - ($710))|0;
       HEAP32[$705>>2] = $727;
       $728 = $round6$1$i + $small$1$i;
       $729 = $728 != $round6$1$i;
       if (!($729)) {
        $a$7$i = $a$3$lcssa$i;$d$3$i = $705;$e$3$i = $e$1$i;
        break;
       }
       $730 = (($727) + ($i$1$lcssa$i))|0;
       HEAP32[$705>>2] = $730;
       $731 = ($730>>>0)>(999999999);
       if ($731) {
        $a$5223$i = $a$3$lcssa$i;$d$2222$i = $705;
        while(1) {
         $732 = (($d$2222$i) + -4|0);
         HEAP32[$d$2222$i>>2] = 0;
         $733 = ($732>>>0)<($a$5223$i>>>0);
         if ($733) {
          $734 = (($a$5223$i) + -4|0);
          HEAP32[$734>>2] = 0;
          $a$6$i = $734;
         } else {
          $a$6$i = $a$5223$i;
         }
         $735 = HEAP32[$732>>2]|0;
         $736 = (($735) + 1)|0;
         HEAP32[$732>>2] = $736;
         $737 = ($736>>>0)>(999999999);
         if ($737) {
          $a$5223$i = $a$6$i;$d$2222$i = $732;
         } else {
          $a$5$lcssa$i = $a$6$i;$d$2$lcssa$i = $732;
          break;
         }
        }
       } else {
        $a$5$lcssa$i = $a$3$lcssa$i;$d$2$lcssa$i = $705;
       }
       $738 = $a$5$lcssa$i;
       $739 = (($681) - ($738))|0;
       $740 = $739 >> 2;
       $741 = ($740*9)|0;
       $742 = HEAP32[$a$5$lcssa$i>>2]|0;
       $743 = ($742>>>0)<(10);
       if ($743) {
        $a$7$i = $a$5$lcssa$i;$d$3$i = $d$2$lcssa$i;$e$3$i = $741;
        break;
       } else {
        $e$2218$i = $741;$i$2217$i = 10;
       }
       while(1) {
        $744 = ($i$2217$i*10)|0;
        $745 = (($e$2218$i) + 1)|0;
        $746 = ($742>>>0)<($744>>>0);
        if ($746) {
         $a$7$i = $a$5$lcssa$i;$d$3$i = $d$2$lcssa$i;$e$3$i = $745;
         break;
        } else {
         $e$2218$i = $745;$i$2217$i = $744;
        }
       }
      }
     } while(0);
     $747 = (($d$3$i) + 4|0);
     $748 = ($z$3$lcssa$i>>>0)>($747>>>0);
     $$z$3$i = $748 ? $747 : $z$3$lcssa$i;
     $a$8$ph$i = $a$7$i;$e$4$ph$i = $e$3$i;$z$6$ph$i = $$z$3$i;
    } else {
     $a$8$ph$i = $a$3$lcssa$i;$e$4$ph$i = $e$1$i;$z$6$ph$i = $z$3$lcssa$i;
    }
    $749 = (0 - ($e$4$ph$i))|0;
    $z$6$i = $z$6$ph$i;
    while(1) {
     $750 = ($z$6$i>>>0)>($a$8$ph$i>>>0);
     if (!($750)) {
      $$lcssa300$i = 0;
      break;
     }
     $751 = (($z$6$i) + -4|0);
     $752 = HEAP32[$751>>2]|0;
     $753 = ($752|0)==(0);
     if ($753) {
      $z$6$i = $751;
     } else {
      $$lcssa300$i = 1;
      break;
     }
    }
    do {
     if ($694) {
      $754 = ($$p$i|0)==(0);
      $755 = $754&1;
      $$$p$i = (($755) + ($$p$i))|0;
      $756 = ($$$p$i|0)>($e$4$ph$i|0);
      $757 = ($e$4$ph$i|0)>(-5);
      $or$cond4$i = $756 & $757;
      if ($or$cond4$i) {
       $758 = (($t$0) + -1)|0;
       $$neg152$i = (($$$p$i) + -1)|0;
       $759 = (($$neg152$i) - ($e$4$ph$i))|0;
       $$013$i = $758;$$210$i = $759;
      } else {
       $760 = (($t$0) + -2)|0;
       $761 = (($$$p$i) + -1)|0;
       $$013$i = $760;$$210$i = $761;
      }
      $762 = $fl$1$ & 8;
      $763 = ($762|0)==(0);
      if (!($763)) {
       $$114$i = $$013$i;$$311$i = $$210$i;
       break;
      }
      do {
       if ($$lcssa300$i) {
        $764 = (($z$6$i) + -4|0);
        $765 = HEAP32[$764>>2]|0;
        $766 = ($765|0)==(0);
        if ($766) {
         $j$2$i = 9;
         break;
        }
        $767 = (($765>>>0) % 10)&-1;
        $768 = ($767|0)==(0);
        if ($768) {
         $i$3209$i = 10;$j$1210$i = 0;
        } else {
         $j$2$i = 0;
         break;
        }
        while(1) {
         $769 = ($i$3209$i*10)|0;
         $770 = (($j$1210$i) + 1)|0;
         $771 = (($765>>>0) % ($769>>>0))&-1;
         $772 = ($771|0)==(0);
         if ($772) {
          $i$3209$i = $769;$j$1210$i = $770;
         } else {
          $j$2$i = $770;
          break;
         }
        }
       } else {
        $j$2$i = 9;
       }
      } while(0);
      $773 = $$013$i | 32;
      $774 = ($773|0)==(102);
      $775 = $z$6$i;
      $776 = (($775) - ($681))|0;
      $777 = $776 >> 2;
      $778 = ($777*9)|0;
      $779 = (($778) + -9)|0;
      if ($774) {
       $780 = (($779) - ($j$2$i))|0;
       $781 = ($780|0)<(0);
       $$23$i = $781 ? 0 : $780;
       $782 = ($$210$i|0)<($$23$i|0);
       $$210$$23$i = $782 ? $$210$i : $$23$i;
       $$114$i = $$013$i;$$311$i = $$210$$23$i;
       break;
      } else {
       $783 = (($779) + ($e$4$ph$i))|0;
       $784 = (($783) - ($j$2$i))|0;
       $785 = ($784|0)<(0);
       $$25$i = $785 ? 0 : $784;
       $786 = ($$210$i|0)<($$25$i|0);
       $$210$$25$i = $786 ? $$210$i : $$25$i;
       $$114$i = $$013$i;$$311$i = $$210$$25$i;
       break;
      }
     } else {
      $$114$i = $t$0;$$311$i = $$p$i;
     }
    } while(0);
    $787 = ($$311$i|0)!=(0);
    if ($787) {
     $791 = 1;
    } else {
     $788 = $fl$1$ & 8;
     $789 = ($788|0)!=(0);
     $791 = $789;
    }
    $790 = $791&1;
    $792 = $$114$i | 32;
    $793 = ($792|0)==(102);
    if ($793) {
     $794 = ($e$4$ph$i|0)>(0);
     $795 = $794 ? $e$4$ph$i : 0;
     $$pn$i = $795;$estr$2$i = 0;
    } else {
     $796 = ($e$4$ph$i|0)<(0);
     $797 = $796 ? $749 : $e$4$ph$i;
     $798 = ($797|0)<(0);
     if ($798) {
      $799 = ($797|0)<(0);
      $800 = $799 << 31 >> 31;
      $$05$i79$i = $6;$801 = $797;$802 = $800;
      while(1) {
       $803 = (___uremdi3(($801|0),($802|0),10,0)|0);
       $804 = tempRet0;
       $805 = $803 | 48;
       $806 = $805&255;
       $807 = (($$05$i79$i) + -1|0);
       HEAP8[$807>>0] = $806;
       $808 = (___udivdi3(($801|0),($802|0),10,0)|0);
       $809 = tempRet0;
       $810 = ($802>>>0)>(9);
       $811 = ($802|0)==(9);
       $812 = ($801>>>0)>(4294967295);
       $813 = $811 & $812;
       $814 = $810 | $813;
       if ($814) {
        $$05$i79$i = $807;$801 = $808;$802 = $809;
       } else {
        break;
       }
      }
      $$0$lcssa$i84$i = $807;$$01$lcssa$off0$i85$i = $808;
     } else {
      $$0$lcssa$i84$i = $6;$$01$lcssa$off0$i85$i = $797;
     }
     $815 = ($$01$lcssa$off0$i85$i|0)==(0);
     if ($815) {
      $estr$1$ph$i = $$0$lcssa$i84$i;
     } else {
      $$12$i87$i = $$0$lcssa$i84$i;$y$03$i86$i = $$01$lcssa$off0$i85$i;
      while(1) {
       $816 = (($y$03$i86$i>>>0) % 10)&-1;
       $817 = $816 | 48;
       $818 = $817&255;
       $819 = (($$12$i87$i) + -1|0);
       HEAP8[$819>>0] = $818;
       $820 = (($y$03$i86$i>>>0) / 10)&-1;
       $821 = ($y$03$i86$i>>>0)<(10);
       if ($821) {
        $estr$1$ph$i = $819;
        break;
       } else {
        $$12$i87$i = $819;$y$03$i86$i = $820;
       }
      }
     }
     $822 = $estr$1$ph$i;
     $823 = (($8) - ($822))|0;
     $824 = ($823|0)<(2);
     if ($824) {
      $estr$1200$i = $estr$1$ph$i;
      while(1) {
       $825 = (($estr$1200$i) + -1|0);
       HEAP8[$825>>0] = 48;
       $826 = $825;
       $827 = (($8) - ($826))|0;
       $828 = ($827|0)<(2);
       if ($828) {
        $estr$1200$i = $825;
       } else {
        $estr$1$lcssa$i = $825;
        break;
       }
      }
     } else {
      $estr$1$lcssa$i = $estr$1$ph$i;
     }
     $829 = $e$4$ph$i >> 31;
     $830 = $829 & 2;
     $831 = (($830) + 43)|0;
     $832 = $831&255;
     $833 = (($estr$1$lcssa$i) + -1|0);
     HEAP8[$833>>0] = $832;
     $834 = $$114$i&255;
     $835 = (($estr$1$lcssa$i) + -2|0);
     HEAP8[$835>>0] = $834;
     $836 = $835;
     $837 = (($8) - ($836))|0;
     $$pn$i = $837;$estr$2$i = $835;
    }
    $838 = (($pl$0$i) + 1)|0;
    $839 = (($838) + ($$311$i))|0;
    $l$1$i = (($839) + ($790))|0;
    $840 = (($l$1$i) + ($$pn$i))|0;
    $841 = $fl$1$ & 73728;
    $842 = ($841|0)==(0);
    $843 = ($840|0)<($w$1|0);
    $or$cond$i93$i = $842 & $843;
    if ($or$cond$i93$i) {
     $844 = (($w$1) - ($840))|0;
     $845 = ($844>>>0)>(256);
     $846 = $845 ? 256 : $844;
     _memset(($pad$i|0),32,($846|0))|0;
     $847 = ($844>>>0)>(255);
     if ($847) {
      $$01$i94$i = $844;
      while(1) {
       (___fwritex($pad$i,256,$f)|0);
       $848 = (($$01$i94$i) + -256)|0;
       $849 = ($848>>>0)>(255);
       if ($849) {
        $$01$i94$i = $848;
       } else {
        $$0$lcssa$i96$i = $848;
        break;
       }
      }
     } else {
      $$0$lcssa$i96$i = $844;
     }
     (___fwritex($pad$i,$$0$lcssa$i96$i,$f)|0);
    }
    (___fwritex($prefix$0$i,$pl$0$i,$f)|0);
    $850 = ($841|0)==(65536);
    $or$cond$i100$i = $850 & $843;
    if ($or$cond$i100$i) {
     $851 = (($w$1) - ($840))|0;
     $852 = ($851>>>0)>(256);
     $853 = $852 ? 256 : $851;
     _memset(($pad$i|0),48,($853|0))|0;
     $854 = ($851>>>0)>(255);
     if ($854) {
      $$01$i101$i = $851;
      while(1) {
       (___fwritex($pad$i,256,$f)|0);
       $855 = (($$01$i101$i) + -256)|0;
       $856 = ($855>>>0)>(255);
       if ($856) {
        $$01$i101$i = $855;
       } else {
        $$0$lcssa$i103$i = $855;
        break;
       }
      }
     } else {
      $$0$lcssa$i103$i = $851;
     }
     (___fwritex($pad$i,$$0$lcssa$i103$i,$f)|0);
    }
    do {
     if ($793) {
      $857 = ($a$8$ph$i>>>0)>($$31$i>>>0);
      $r$0$a$8$i = $857 ? $$31$i : $a$8$ph$i;
      $d$4183$i = $r$0$a$8$i;
      while(1) {
       $858 = HEAP32[$d$4183$i>>2]|0;
       $859 = ($858|0)==(0);
       if ($859) {
        $$1$lcssa$i112$i = $13;
       } else {
        $$12$i110$i = $13;$y$03$i109$i = $858;
        while(1) {
         $860 = (($y$03$i109$i>>>0) % 10)&-1;
         $861 = $860 | 48;
         $862 = $861&255;
         $863 = (($$12$i110$i) + -1|0);
         HEAP8[$863>>0] = $862;
         $864 = (($y$03$i109$i>>>0) / 10)&-1;
         $865 = ($y$03$i109$i>>>0)<(10);
         if ($865) {
          $$1$lcssa$i112$i = $863;
          break;
         } else {
          $$12$i110$i = $863;$y$03$i109$i = $864;
         }
        }
       }
       $866 = ($d$4183$i|0)==($r$0$a$8$i|0);
       do {
        if ($866) {
         $870 = ($$1$lcssa$i112$i|0)==($13|0);
         if (!($870)) {
          $s7$1$i = $$1$lcssa$i112$i;
          break;
         }
         HEAP8[$15>>0] = 48;
         $s7$1$i = $15;
        } else {
         $867 = ($$1$lcssa$i112$i>>>0)>($buf$i>>>0);
         if ($867) {
          $s7$0180$i = $$1$lcssa$i112$i;
         } else {
          $s7$1$i = $$1$lcssa$i112$i;
          break;
         }
         while(1) {
          $868 = (($s7$0180$i) + -1|0);
          HEAP8[$868>>0] = 48;
          $869 = ($868>>>0)>($buf$i>>>0);
          if ($869) {
           $s7$0180$i = $868;
          } else {
           $s7$1$i = $868;
           break;
          }
         }
        }
       } while(0);
       $871 = $s7$1$i;
       $872 = (($14) - ($871))|0;
       (___fwritex($s7$1$i,$872,$f)|0);
       $873 = (($d$4183$i) + 4|0);
       $874 = ($873>>>0)>($$31$i>>>0);
       if ($874) {
        break;
       } else {
        $d$4183$i = $873;
       }
      }
      if (!($787)) {
       $875 = $fl$1$ & 8;
       $876 = ($875|0)==(0);
       if ($876) {
        break;
       }
      }
      (___fwritex(3111248,1,$f)|0);
      $877 = ($873>>>0)<($z$6$i>>>0);
      $878 = ($$311$i|0)>(0);
      $or$cond28173$i = $877 & $878;
      if ($or$cond28173$i) {
       $$412175$i = $$311$i;$d$5174$i = $873;
       while(1) {
        $879 = HEAP32[$d$5174$i>>2]|0;
        $880 = ($879|0)==(0);
        if ($880) {
         $s8$0169$i = $13;
         label = 300;
        } else {
         $$12$i119$i = $13;$y$03$i118$i = $879;
         while(1) {
          $881 = (($y$03$i118$i>>>0) % 10)&-1;
          $882 = $881 | 48;
          $883 = $882&255;
          $884 = (($$12$i119$i) + -1|0);
          HEAP8[$884>>0] = $883;
          $885 = (($y$03$i118$i>>>0) / 10)&-1;
          $886 = ($y$03$i118$i>>>0)<(10);
          if ($886) {
           break;
          } else {
           $$12$i119$i = $884;$y$03$i118$i = $885;
          }
         }
         $887 = ($884>>>0)>($buf$i>>>0);
         if ($887) {
          $s8$0169$i = $884;
          label = 300;
         } else {
          $s8$0$lcssa$i = $884;
         }
        }
        if ((label|0) == 300) {
         while(1) {
          label = 0;
          $888 = (($s8$0169$i) + -1|0);
          HEAP8[$888>>0] = 48;
          $889 = ($888>>>0)>($buf$i>>>0);
          if ($889) {
           $s8$0169$i = $888;
           label = 300;
          } else {
           $s8$0$lcssa$i = $888;
           break;
          }
         }
        }
        $890 = ($$412175$i|0)>(9);
        $891 = $890 ? 9 : $$412175$i;
        (___fwritex($s8$0$lcssa$i,$891,$f)|0);
        $892 = (($d$5174$i) + 4|0);
        $893 = (($$412175$i) + -9)|0;
        $894 = ($892>>>0)<($z$6$i>>>0);
        $895 = ($893|0)>(0);
        $or$cond28$i = $894 & $895;
        if ($or$cond28$i) {
         $$412175$i = $893;$d$5174$i = $892;
        } else {
         $$412$lcssa$i = $893;
         break;
        }
       }
      } else {
       $$412$lcssa$i = $$311$i;
      }
      $896 = ($$412$lcssa$i|0)>(0);
      if (!($896)) {
       break;
      }
      $897 = ($$412$lcssa$i>>>0)>(256);
      $898 = $897 ? 256 : $$412$lcssa$i;
      _memset(($pad$i|0),48,($898|0))|0;
      $899 = ($$412$lcssa$i>>>0)>(255);
      if ($899) {
       $$01$i125$i = $$412$lcssa$i;
       while(1) {
        (___fwritex($pad$i,256,$f)|0);
        $900 = (($$01$i125$i) + -256)|0;
        $901 = ($900>>>0)>(255);
        if ($901) {
         $$01$i125$i = $900;
        } else {
         $$0$lcssa$i127$i = $900;
         break;
        }
       }
      } else {
       $$0$lcssa$i127$i = $$412$lcssa$i;
      }
      (___fwritex($pad$i,$$0$lcssa$i127$i,$f)|0);
     } else {
      $902 = (($a$8$ph$i) + 4|0);
      $z$6$$i = $$lcssa300$i ? $z$6$i : $902;
      $903 = ($$311$i|0)>(-1);
      do {
       if ($903) {
        $904 = $fl$1$ & 8;
        $$not$i = ($904|0)!=(0);
        $$5193$i = $$311$i;$d$6192$i = $a$8$ph$i;
        while(1) {
         $905 = HEAP32[$d$6192$i>>2]|0;
         $906 = ($905|0)==(0);
         if ($906) {
          label = 311;
         } else {
          $$12$i134$i = $13;$y$03$i133$i = $905;
          while(1) {
           $907 = (($y$03$i133$i>>>0) % 10)&-1;
           $908 = $907 | 48;
           $909 = $908&255;
           $910 = (($$12$i134$i) + -1|0);
           HEAP8[$910>>0] = $909;
           $911 = (($y$03$i133$i>>>0) / 10)&-1;
           $912 = ($y$03$i133$i>>>0)<(10);
           if ($912) {
            break;
           } else {
            $$12$i134$i = $910;$y$03$i133$i = $911;
           }
          }
          $913 = ($910|0)==($13|0);
          if ($913) {
           label = 311;
          } else {
           $s9$0$i = $910;
          }
         }
         if ((label|0) == 311) {
          label = 0;
          HEAP8[$15>>0] = 48;
          $s9$0$i = $15;
         }
         $914 = ($d$6192$i|0)==($a$8$ph$i|0);
         do {
          if ($914) {
           $918 = (($s9$0$i) + 1|0);
           (___fwritex($s9$0$i,1,$f)|0);
           $919 = ($$5193$i|0)>(0);
           $brmerge$i = $919 | $$not$i;
           if (!($brmerge$i)) {
            $s9$2$i = $918;
            break;
           }
           (___fwritex(3111248,1,$f)|0);
           $s9$2$i = $918;
          } else {
           $915 = ($s9$0$i>>>0)>($buf$i>>>0);
           if ($915) {
            $s9$1188$i = $s9$0$i;
           } else {
            $s9$2$i = $s9$0$i;
            break;
           }
           while(1) {
            $916 = (($s9$1188$i) + -1|0);
            HEAP8[$916>>0] = 48;
            $917 = ($916>>>0)>($buf$i>>>0);
            if ($917) {
             $s9$1188$i = $916;
            } else {
             $s9$2$i = $916;
             break;
            }
           }
          }
         } while(0);
         $920 = $s9$2$i;
         $921 = (($14) - ($920))|0;
         $922 = ($921|0)<($$5193$i|0);
         $$$5$i = $922 ? $921 : $$5193$i;
         (___fwritex($s9$2$i,$$$5$i,$f)|0);
         $923 = (($$5193$i) - ($921))|0;
         $924 = (($d$6192$i) + 4|0);
         $925 = ($924>>>0)<($z$6$$i>>>0);
         $926 = ($923|0)>(-1);
         $or$cond29$i = $925 & $926;
         if ($or$cond29$i) {
          $$5193$i = $923;$d$6192$i = $924;
         } else {
          break;
         }
        }
        $927 = ($923|0)>(0);
        if (!($927)) {
         break;
        }
        $928 = ($923>>>0)>(256);
        $929 = $928 ? 256 : $923;
        _memset(($pad$i|0),48,($929|0))|0;
        $930 = ($923>>>0)>(255);
        if ($930) {
         $$01$i140$i = $923;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $931 = (($$01$i140$i) + -256)|0;
          $932 = ($931>>>0)>(255);
          if ($932) {
           $$01$i140$i = $931;
          } else {
           $$0$lcssa$i142$i = $931;
           break;
          }
         }
        } else {
         $$0$lcssa$i142$i = $923;
        }
        (___fwritex($pad$i,$$0$lcssa$i142$i,$f)|0);
       }
      } while(0);
      $933 = $estr$2$i;
      $934 = (($8) - ($933))|0;
      (___fwritex($estr$2$i,$934,$f)|0);
     }
    } while(0);
    $935 = ($841|0)==(8192);
    $or$cond$i$i = $935 & $843;
    if ($or$cond$i$i) {
     $936 = (($w$1) - ($840))|0;
     $937 = ($936>>>0)>(256);
     $938 = $937 ? 256 : $936;
     _memset(($pad$i|0),32,($938|0))|0;
     $939 = ($936>>>0)>(255);
     if ($939) {
      $$01$i$i = $936;
      while(1) {
       (___fwritex($pad$i,256,$f)|0);
       $940 = (($$01$i$i) + -256)|0;
       $941 = ($940>>>0)>(255);
       if ($941) {
        $$01$i$i = $940;
       } else {
        $$0$lcssa$i$i = $940;
        break;
       }
      }
     } else {
      $$0$lcssa$i$i = $936;
     }
     (___fwritex($pad$i,$$0$lcssa$i$i,$f)|0);
    }
    $w$30$i = $843 ? $w$1 : $840;
    $1045 = $229;$1046 = $207;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$30$i;$l10n$0 = $l10n$3;
    continue L1;
    break;
   }
   case 83:  {
    $332 = ($p$0|0)==(0);
    if ($332) {
     $1057 = $207;$1058 = $207;$i$0166 = 0;
     label = 110;
    } else {
     $1055 = $207;$1056 = $207;$p$4296 = $p$0;
     label = 104;
    }
    break;
   }
   default: {
    $1053 = $229;$1054 = $207;$a$2 = $22;$fl$6 = $fl$1$;$p$5 = $p$0;$pl$2 = 0;$prefix$2 = 3111152;$z$2 = $2;
   }
   }
  } while(0);
  L445: do {
   if ((label|0) == 77) {
    label = 0;
    $225 = $207;
    $226 = $t$1 & 32;
    $227 = ($225|0)==(0);
    $228 = ($229|0)==(0);
    $230 = $227 & $228;
    if ($230) {
     $308 = $207;$311 = $229;$a$0 = $2;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 0;$prefix$1 = 3111152;
     label = 94;
    } else {
     $$012$i = $2;$232 = $225;$239 = $229;
     while(1) {
      $231 = $232 & 15;
      $233 = (3111232 + ($231)|0);
      $234 = HEAP8[$233>>0]|0;
      $235 = $234&255;
      $236 = $235 | $226;
      $237 = $236&255;
      $238 = (($$012$i) + -1|0);
      HEAP8[$238>>0] = $237;
      $240 = (_bitshift64Lshr(($232|0),($239|0),4)|0);
      $241 = tempRet0;
      $242 = ($240|0)==(0);
      $243 = ($241|0)==(0);
      $244 = $242 & $243;
      if ($244) {
       break;
      } else {
       $$012$i = $238;$232 = $240;$239 = $241;
      }
     }
     $245 = $fl$3 & 8;
     $246 = ($245|0)==(0);
     if ($246) {
      $308 = $207;$311 = $229;$a$0 = $238;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 0;$prefix$1 = 3111152;
      label = 94;
     } else {
      $247 = $t$1 >> 4;
      $248 = (3111152 + ($247)|0);
      $308 = $207;$311 = $229;$a$0 = $238;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 2;$prefix$1 = $248;
      label = 94;
     }
    }
   }
   else if ((label|0) == 89) {
    label = 0;
    $276 = $277;
    $278 = ($279>>>0)>(0);
    $280 = ($279|0)==(0);
    $281 = ($276>>>0)>(4294967295);
    $282 = $280 & $281;
    $283 = $278 | $282;
    if ($283) {
     $$05$i = $2;$284 = $276;$285 = $279;
     while(1) {
      $286 = (___uremdi3(($284|0),($285|0),10,0)|0);
      $287 = tempRet0;
      $288 = $286 | 48;
      $289 = $288&255;
      $290 = (($$05$i) + -1|0);
      HEAP8[$290>>0] = $289;
      $291 = (___udivdi3(($284|0),($285|0),10,0)|0);
      $292 = tempRet0;
      $293 = ($285>>>0)>(9);
      $294 = ($285|0)==(9);
      $295 = ($284>>>0)>(4294967295);
      $296 = $294 & $295;
      $297 = $293 | $296;
      if ($297) {
       $$05$i = $290;$284 = $291;$285 = $292;
      } else {
       break;
      }
     }
     $$0$lcssa$i45 = $290;$$01$lcssa$off0$i = $291;
    } else {
     $$0$lcssa$i45 = $2;$$01$lcssa$off0$i = $276;
    }
    $298 = ($$01$lcssa$off0$i|0)==(0);
    if ($298) {
     $308 = $277;$311 = $279;$a$0 = $$0$lcssa$i45;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $pl$0;$prefix$1 = $prefix$0;
     label = 94;
    } else {
     $$12$i = $$0$lcssa$i45;$y$03$i = $$01$lcssa$off0$i;
     while(1) {
      $299 = (($y$03$i>>>0) % 10)&-1;
      $300 = $299 | 48;
      $301 = $300&255;
      $302 = (($$12$i) + -1|0);
      HEAP8[$302>>0] = $301;
      $303 = (($y$03$i>>>0) / 10)&-1;
      $304 = ($y$03$i>>>0)<(10);
      if ($304) {
       $308 = $277;$311 = $279;$a$0 = $302;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $pl$0;$prefix$1 = $prefix$0;
       label = 94;
       break;
      } else {
       $$12$i = $302;$y$03$i = $303;
      }
     }
    }
   }
   else if ((label|0) == 99) {
    label = 0;
    $325 = (_memchr($a$1,0,$p$0)|0);
    $326 = ($325|0)==(0|0);
    if ($326) {
     $327 = (($a$1) + ($p$0)|0);
     $1053 = $229;$1054 = $207;$a$2 = $a$1;$fl$6 = $206;$p$5 = $p$0;$pl$2 = 0;$prefix$2 = 3111152;$z$2 = $327;
     break;
    } else {
     $328 = $325;
     $329 = $a$1;
     $330 = (($328) - ($329))|0;
     $1053 = $229;$1054 = $207;$a$2 = $a$1;$fl$6 = $206;$p$5 = $330;$pl$2 = 0;$prefix$2 = 3111152;$z$2 = $325;
     break;
    }
   }
   else if ((label|0) == 104) {
    label = 0;
    $i$0168 = 0;$l$1167 = 0;$ws$0169 = $1055;
    while(1) {
     $336 = HEAP32[$ws$0169>>2]|0;
     $337 = ($336|0)==(0);
     if ($337) {
      $i$0$lcssa = $i$0168;$l$1$lcssa = $l$1167;
      break;
     }
     $338 = (_wctomb($mb,$336)|0);
     $339 = ($338|0)>(-1);
     if (!($339)) {
      $$0 = -1;
      label = 362;
      break L1;
     }
     $340 = (($p$4296) - ($i$0168))|0;
     $341 = ($338>>>0)>($340>>>0);
     $335 = (($338) + ($i$0168))|0;
     if ($341) {
      $1057 = $1055;$1058 = $1056;$i$0166 = $i$0168;
      label = 110;
      break L445;
     }
     $333 = (($ws$0169) + 4|0);
     $334 = ($335>>>0)<($p$4296>>>0);
     if ($334) {
      $i$0168 = $335;$l$1167 = $338;$ws$0169 = $333;
     } else {
      $i$0$lcssa = $335;$l$1$lcssa = $338;
      break;
     }
    }
    $342 = ($l$1$lcssa|0)<(0);
    if ($342) {
     $$0 = -1;
     label = 362;
     break L1;
    } else {
     $1057 = $1055;$1058 = $1056;$i$0166 = $i$0$lcssa;
     label = 110;
    }
   }
  } while(0);
  if ((label|0) == 94) {
   label = 0;
   $305 = ($p$2|0)>(-1);
   $306 = $fl$4 & -65537;
   $$fl$4 = $305 ? $306 : $fl$4;
   $307 = $308;
   $309 = ($307|0)==(0);
   $310 = ($311|0)==(0);
   $312 = $309 & $310;
   $313 = ($p$2|0)==(0);
   $or$cond = $312 & $313;
   if ($or$cond) {
    $1053 = $311;$1054 = $308;$a$2 = $2;$fl$6 = $$fl$4;$p$5 = 0;$pl$2 = $pl$1;$prefix$2 = $prefix$1;$z$2 = $2;
   } else {
    $314 = $a$0;
    $315 = (($3) - ($314))|0;
    $316 = $312&1;
    $317 = (($316) + ($315))|0;
    $318 = ($p$2|0)>($317|0);
    $p$2$ = $318 ? $p$2 : $317;
    $1053 = $311;$1054 = $308;$a$2 = $a$0;$fl$6 = $$fl$4;$p$5 = $p$2$;$pl$2 = $pl$1;$prefix$2 = $prefix$1;$z$2 = $2;
   }
  }
  else if ((label|0) == 110) {
   label = 0;
   $343 = $fl$1$ & 73728;
   $344 = ($343|0)==(0);
   $345 = ($i$0166|0)<($w$1|0);
   $or$cond$i56 = $344 & $345;
   if ($or$cond$i56) {
    $346 = (($w$1) - ($i$0166))|0;
    $347 = ($346>>>0)>(256);
    $348 = $347 ? 256 : $346;
    _memset(($pad$i|0),32,($348|0))|0;
    $349 = ($346>>>0)>(255);
    if ($349) {
     $$01$i57 = $346;
     while(1) {
      (___fwritex($pad$i,256,$f)|0);
      $350 = (($$01$i57) + -256)|0;
      $351 = ($350>>>0)>(255);
      if ($351) {
       $$01$i57 = $350;
      } else {
       $$0$lcssa$i59 = $350;
       break;
      }
     }
    } else {
     $$0$lcssa$i59 = $346;
    }
    (___fwritex($pad$i,$$0$lcssa$i59,$f)|0);
   }
   $352 = ($i$0166|0)==(0);
   L479: do {
    if (!($352)) {
     $i$1174 = 0;$ws$1175 = $1057;
     while(1) {
      $353 = HEAP32[$ws$1175>>2]|0;
      $354 = ($353|0)==(0);
      if ($354) {
       break L479;
      }
      $355 = (_wctomb($mb,$353)|0);
      $356 = (($355) + ($i$1174))|0;
      $357 = ($356|0)>($i$0166|0);
      if ($357) {
       break L479;
      }
      $358 = (($ws$1175) + 4|0);
      (___fwritex($mb,$355,$f)|0);
      $359 = ($356>>>0)<($i$0166>>>0);
      if ($359) {
       $i$1174 = $356;$ws$1175 = $358;
      } else {
       break;
      }
     }
    }
   } while(0);
   $360 = ($343|0)==(8192);
   $or$cond$i63 = $360 & $345;
   if ($or$cond$i63) {
    $361 = (($w$1) - ($i$0166))|0;
    $362 = ($361>>>0)>(256);
    $363 = $362 ? 256 : $361;
    _memset(($pad$i|0),32,($363|0))|0;
    $364 = ($361>>>0)>(255);
    if ($364) {
     $$01$i64 = $361;
     while(1) {
      (___fwritex($pad$i,256,$f)|0);
      $365 = (($$01$i64) + -256)|0;
      $366 = ($365>>>0)>(255);
      if ($366) {
       $$01$i64 = $365;
      } else {
       $$0$lcssa$i66 = $365;
       break;
      }
     }
    } else {
     $$0$lcssa$i66 = $361;
    }
    (___fwritex($pad$i,$$0$lcssa$i66,$f)|0);
   }
   $367 = $345 ? $w$1 : $i$0166;
   $1045 = $229;$1046 = $1058;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $367;$l10n$0 = $l10n$3;
   continue;
  }
  $942 = $z$2;
  $943 = $a$2;
  $944 = (($942) - ($943))|0;
  $945 = ($p$5|0)<($944|0);
  $$p$5 = $945 ? $944 : $p$5;
  $946 = (($pl$2) + ($$p$5))|0;
  $947 = ($w$1|0)<($946|0);
  $w$2 = $947 ? $946 : $w$1;
  $948 = $fl$6 & 73728;
  $949 = ($948|0)==(0);
  $950 = ($946|0)<($w$2|0);
  $or$cond$i73 = $949 & $950;
  if ($or$cond$i73) {
   $951 = (($w$2) - ($946))|0;
   $952 = ($951>>>0)>(256);
   $953 = $952 ? 256 : $951;
   _memset(($pad$i|0),32,($953|0))|0;
   $954 = ($951>>>0)>(255);
   if ($954) {
    $$01$i74 = $951;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $955 = (($$01$i74) + -256)|0;
     $956 = ($955>>>0)>(255);
     if ($956) {
      $$01$i74 = $955;
     } else {
      $$0$lcssa$i76 = $955;
      break;
     }
    }
   } else {
    $$0$lcssa$i76 = $951;
   }
   (___fwritex($pad$i,$$0$lcssa$i76,$f)|0);
  }
  (___fwritex($prefix$2,$pl$2,$f)|0);
  $957 = ($948|0)==(65536);
  $or$cond$i49 = $957 & $950;
  if ($or$cond$i49) {
   $958 = (($w$2) - ($946))|0;
   $959 = ($958>>>0)>(256);
   $960 = $959 ? 256 : $958;
   _memset(($pad$i|0),48,($960|0))|0;
   $961 = ($958>>>0)>(255);
   if ($961) {
    $$01$i50 = $958;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $962 = (($$01$i50) + -256)|0;
     $963 = ($962>>>0)>(255);
     if ($963) {
      $$01$i50 = $962;
     } else {
      $$0$lcssa$i52 = $962;
      break;
     }
    }
   } else {
    $$0$lcssa$i52 = $958;
   }
   (___fwritex($pad$i,$$0$lcssa$i52,$f)|0);
  }
  $964 = ($944|0)<($$p$5|0);
  if ($964) {
   $965 = (($$p$5) - ($944))|0;
   $966 = ($965>>>0)>(256);
   $967 = $966 ? 256 : $965;
   _memset(($pad$i|0),48,($967|0))|0;
   $968 = ($965>>>0)>(255);
   if ($968) {
    $$01$i35 = $965;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $969 = (($$01$i35) + -256)|0;
     $970 = ($969>>>0)>(255);
     if ($970) {
      $$01$i35 = $969;
     } else {
      $$0$lcssa$i37 = $969;
      break;
     }
    }
   } else {
    $$0$lcssa$i37 = $965;
   }
   (___fwritex($pad$i,$$0$lcssa$i37,$f)|0);
  }
  (___fwritex($a$2,$944,$f)|0);
  $971 = ($948|0)==(8192);
  $or$cond$i = $971 & $950;
  if (!($or$cond$i)) {
   $1045 = $1053;$1046 = $1054;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$2;$l10n$0 = $l10n$3;
   continue;
  }
  $972 = (($w$2) - ($946))|0;
  $973 = ($972>>>0)>(256);
  $974 = $973 ? 256 : $972;
  _memset(($pad$i|0),32,($974|0))|0;
  $975 = ($972>>>0)>(255);
  if ($975) {
   $$01$i = $972;
   while(1) {
    (___fwritex($pad$i,256,$f)|0);
    $976 = (($$01$i) + -256)|0;
    $977 = ($976>>>0)>(255);
    if ($977) {
     $$01$i = $976;
    } else {
     $$0$lcssa$i = $976;
     break;
    }
   }
  } else {
   $$0$lcssa$i = $972;
  }
  (___fwritex($pad$i,$$0$lcssa$i,$f)|0);
  $1045 = $1053;$1046 = $1054;$22 = $139;$cnt$0 = $cnt$1;$l$0 = $w$2;$l10n$0 = $l10n$3;
 }
 if ((label|0) == 344) {
  $978 = ($f|0)==(0|0);
  if (!($978)) {
   $$0 = $cnt$1;
   STACKTOP = sp;return ($$0|0);
  }
  $979 = ($l10n$0|0)==(0);
  if ($979) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$289 = 1;
  }
  while(1) {
   $980 = (($nl_type) + ($i$289<<2)|0);
   $981 = HEAP32[$980>>2]|0;
   $982 = ($981|0)==(0);
   if ($982) {
    $i$388 = $i$289;
    break;
   }
   $983 = (($nl_arg) + ($i$289<<3)|0);
   $984 = ($981>>>0)>(20);
   L535: do {
    if (!($984)) {
     do {
      switch ($981|0) {
      case 14:  {
       $arglist_current50 = HEAP32[$ap>>2]|0;
       $1017 = HEAP32[$arglist_current50>>2]|0;
       $arglist_next51 = (($arglist_current50) + 4|0);
       HEAP32[$ap>>2] = $arglist_next51;
       $$mask1$i = $1017 & 65535;
       $1018 = $983;
       $1019 = $1018;
       HEAP32[$1019>>2] = $$mask1$i;
       $1020 = (($1018) + 4)|0;
       $1021 = $1020;
       HEAP32[$1021>>2] = 0;
       break L535;
       break;
      }
      case 12:  {
       $arglist_current44 = HEAP32[$ap>>2]|0;
       $998 = $arglist_current44;
       $999 = $998;
       $1000 = HEAP32[$999>>2]|0;
       $1001 = (($998) + 4)|0;
       $1002 = $1001;
       $1003 = HEAP32[$1002>>2]|0;
       $arglist_next45 = (($arglist_current44) + 8|0);
       HEAP32[$ap>>2] = $arglist_next45;
       $1004 = $983;
       $1005 = $1004;
       HEAP32[$1005>>2] = $1000;
       $1006 = (($1004) + 4)|0;
       $1007 = $1006;
       HEAP32[$1007>>2] = $1003;
       break L535;
       break;
      }
      case 18:  {
       $arglist_current62 = HEAP32[$ap>>2]|0;
       HEAP32[tempDoublePtr>>2]=HEAP32[$arglist_current62>>2];HEAP32[tempDoublePtr+4>>2]=HEAP32[$arglist_current62+4>>2];$1037 = +HEAPF64[tempDoublePtr>>3];
       $arglist_next63 = (($arglist_current62) + 8|0);
       HEAP32[$ap>>2] = $arglist_next63;
       HEAPF64[$983>>3] = $1037;
       break L535;
       break;
      }
      case 9:  {
       $arglist_current35 = HEAP32[$ap>>2]|0;
       $985 = HEAP32[$arglist_current35>>2]|0;
       $arglist_next36 = (($arglist_current35) + 4|0);
       HEAP32[$ap>>2] = $arglist_next36;
       HEAP32[$983>>2] = $985;
       break L535;
       break;
      }
      case 10:  {
       $arglist_current38 = HEAP32[$ap>>2]|0;
       $986 = HEAP32[$arglist_current38>>2]|0;
       $arglist_next39 = (($arglist_current38) + 4|0);
       HEAP32[$ap>>2] = $arglist_next39;
       $987 = ($986|0)<(0);
       $988 = $987 << 31 >> 31;
       $989 = $983;
       $990 = $989;
       HEAP32[$990>>2] = $986;
       $991 = (($989) + 4)|0;
       $992 = $991;
       HEAP32[$992>>2] = $988;
       break L535;
       break;
      }
      case 16:  {
       $arglist_current56 = HEAP32[$ap>>2]|0;
       $1031 = HEAP32[$arglist_current56>>2]|0;
       $arglist_next57 = (($arglist_current56) + 4|0);
       HEAP32[$ap>>2] = $arglist_next57;
       $$mask$i = $1031 & 255;
       $1032 = $983;
       $1033 = $1032;
       HEAP32[$1033>>2] = $$mask$i;
       $1034 = (($1032) + 4)|0;
       $1035 = $1034;
       HEAP32[$1035>>2] = 0;
       break L535;
       break;
      }
      case 15:  {
       $arglist_current53 = HEAP32[$ap>>2]|0;
       $1022 = HEAP32[$arglist_current53>>2]|0;
       $arglist_next54 = (($arglist_current53) + 4|0);
       HEAP32[$ap>>2] = $arglist_next54;
       $1023 = $1022&255;
       $1024 = $1023 << 24 >> 24;
       $1025 = ($1024|0)<(0);
       $1026 = $1025 << 31 >> 31;
       $1027 = $983;
       $1028 = $1027;
       HEAP32[$1028>>2] = $1024;
       $1029 = (($1027) + 4)|0;
       $1030 = $1029;
       HEAP32[$1030>>2] = $1026;
       break L535;
       break;
      }
      case 11:  {
       $arglist_current41 = HEAP32[$ap>>2]|0;
       $993 = HEAP32[$arglist_current41>>2]|0;
       $arglist_next42 = (($arglist_current41) + 4|0);
       HEAP32[$ap>>2] = $arglist_next42;
       $994 = $983;
       $995 = $994;
       HEAP32[$995>>2] = $993;
       $996 = (($994) + 4)|0;
       $997 = $996;
       HEAP32[$997>>2] = 0;
       break L535;
       break;
      }
      case 13:  {
       $arglist_current47 = HEAP32[$ap>>2]|0;
       $1008 = HEAP32[$arglist_current47>>2]|0;
       $arglist_next48 = (($arglist_current47) + 4|0);
       HEAP32[$ap>>2] = $arglist_next48;
       $1009 = $1008&65535;
       $1010 = $1009 << 16 >> 16;
       $1011 = ($1010|0)<(0);
       $1012 = $1011 << 31 >> 31;
       $1013 = $983;
       $1014 = $1013;
       HEAP32[$1014>>2] = $1010;
       $1015 = (($1013) + 4)|0;
       $1016 = $1015;
       HEAP32[$1016>>2] = $1012;
       break L535;
       break;
      }
      case 17:  {
       $arglist_current59 = HEAP32[$ap>>2]|0;
       HEAP32[tempDoublePtr>>2]=HEAP32[$arglist_current59>>2];HEAP32[tempDoublePtr+4>>2]=HEAP32[$arglist_current59+4>>2];$1036 = +HEAPF64[tempDoublePtr>>3];
       $arglist_next60 = (($arglist_current59) + 8|0);
       HEAP32[$ap>>2] = $arglist_next60;
       HEAPF64[$983>>3] = $1036;
       break L535;
       break;
      }
      default: {
       break L535;
      }
      }
     } while(0);
    }
   } while(0);
   $1038 = (($i$289) + 1)|0;
   $1039 = ($1038|0)<(10);
   if ($1039) {
    $i$289 = $1038;
   } else {
    $$0 = 1;
    label = 362;
    break;
   }
  }
  if ((label|0) == 362) {
   STACKTOP = sp;return ($$0|0);
  }
  while(1) {
   $1042 = (($nl_type) + ($i$388<<2)|0);
   $1043 = HEAP32[$1042>>2]|0;
   $1044 = ($1043|0)==(0);
   $1041 = (($i$388) + 1)|0;
   if (!($1044)) {
    $$0 = -1;
    label = 362;
    break;
   }
   $1040 = ($1041|0)<(10);
   if ($1040) {
    $i$388 = $1041;
   } else {
    $$0 = 1;
    label = 362;
    break;
   }
  }
  if ((label|0) == 362) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 362) {
  STACKTOP = sp;return ($$0|0);
 }
 return 0|0;
}
function _vsnprintf($s,$n,$fmt,$ap) {
 $s = $s|0;
 $n = $n|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$$02 = 0, $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $f = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $b = sp + 112|0;
 $f = sp;
 dest=$f+0|0; src=3111256+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $0 = (($n) + -1)|0;
 $1 = ($0>>>0)>(2147483646);
 if ($1) {
  $2 = ($n|0)==(0);
  if ($2) {
   $$01 = $b;$$02 = 1;
  } else {
   $3 = (___errno_location()|0);
   HEAP32[$3>>2] = 75;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$01 = $s;$$02 = $n;
 }
 $4 = $$01;
 $5 = (-2 - ($4))|0;
 $6 = ($$02>>>0)>($5>>>0);
 $$$02 = $6 ? $5 : $$02;
 $7 = (($f) + 48|0);
 HEAP32[$7>>2] = $$$02;
 $8 = (($f) + 20|0);
 HEAP32[$8>>2] = $$01;
 $9 = (($f) + 44|0);
 HEAP32[$9>>2] = $$01;
 $10 = (($$01) + ($$$02)|0);
 $11 = (($f) + 16|0);
 HEAP32[$11>>2] = $10;
 $12 = (($f) + 28|0);
 HEAP32[$12>>2] = $10;
 $13 = (_MUSL_vfprintf($f,$fmt,$ap)|0);
 $14 = ($$$02|0)==(0);
 if ($14) {
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = HEAP32[$11>>2]|0;
 $17 = ($15|0)==($16|0);
 $18 = $17 << 31 >> 31;
 $19 = (($15) + ($18)|0);
 HEAP8[$19>>0] = 0;
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function _sn_write($f,$s,$l) {
 $f = $f|0;
 $s = $s|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($f) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($f) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = ($6>>>0)>($l>>>0);
 $l$ = $7 ? $l : $6;
 _memcpy(($3|0),($s|0),($l$|0))|0;
 $8 = HEAP32[$2>>2]|0;
 $9 = (($8) + ($l$)|0);
 HEAP32[$2>>2] = $9;
 STACKTOP = sp;return ($l|0);
}
function _vsprintf($s,$fmt,$ap) {
 $s = $s|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_vsnprintf($s,2147483647,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _atoi($s) {
 $s = $s|0;
 var $$0 = 0, $$1$ph = 0, $$12 = 0, $$neg1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$0$lcssa = 0, $n$03 = 0, $neg$0 = 0, $neg$1$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $s;
 while(1) {
  $0 = HEAP8[$$0>>0]|0;
  $1 = $0 << 24 >> 24;
  $2 = (_isspace($1)|0);
  $3 = ($2|0)==(0);
  $4 = (($$0) + 1|0);
  if ($3) {
   break;
  } else {
   $$0 = $4;
  }
 }
 $5 = HEAP8[$$0>>0]|0;
 $6 = $5 << 24 >> 24;
 if ((($6|0) == 43)) {
  $neg$0 = 0;
  label = 5;
 } else if ((($6|0) == 45)) {
  $neg$0 = 1;
  label = 5;
 } else {
  $$1$ph = $$0;$8 = $5;$neg$1$ph = 0;
 }
 if ((label|0) == 5) {
  $$pre = HEAP8[$4>>0]|0;
  $$1$ph = $4;$8 = $$pre;$neg$1$ph = $neg$0;
 }
 $7 = $8 << 24 >> 24;
 $9 = (_isdigit($7)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  $n$0$lcssa = 0;
  $20 = ($neg$1$ph|0)!=(0);
  $21 = (0 - ($n$0$lcssa))|0;
  $22 = $20 ? $n$0$lcssa : $21;
  STACKTOP = sp;return ($22|0);
 } else {
  $$12 = $$1$ph;$n$03 = 0;
 }
 while(1) {
  $11 = ($n$03*10)|0;
  $12 = (($$12) + 1|0);
  $13 = HEAP8[$$12>>0]|0;
  $14 = $13 << 24 >> 24;
  $$neg1 = (($11) + 48)|0;
  $15 = (($$neg1) - ($14))|0;
  $16 = HEAP8[$12>>0]|0;
  $17 = $16 << 24 >> 24;
  $18 = (_isdigit($17)|0);
  $19 = ($18|0)==(0);
  if ($19) {
   $n$0$lcssa = $15;
   break;
  } else {
   $$12 = $12;$n$03 = $15;
  }
 }
 $20 = ($neg$1$ph|0)!=(0);
 $21 = (0 - ($n$0$lcssa))|0;
 $22 = $20 ? $n$0$lcssa : $21;
 STACKTOP = sp;return ($22|0);
}
function _atol($s) {
 $s = $s|0;
 var $$0 = 0, $$1$ph = 0, $$12 = 0, $$neg1 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$0$lcssa = 0, $n$03 = 0, $neg$0 = 0, $neg$1$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $s;
 while(1) {
  $0 = HEAP8[$$0>>0]|0;
  $1 = $0 << 24 >> 24;
  $2 = (_isspace($1)|0);
  $3 = ($2|0)==(0);
  $4 = (($$0) + 1|0);
  if ($3) {
   break;
  } else {
   $$0 = $4;
  }
 }
 $5 = HEAP8[$$0>>0]|0;
 $6 = $5 << 24 >> 24;
 if ((($6|0) == 43)) {
  $neg$0 = 0;
  label = 5;
 } else if ((($6|0) == 45)) {
  $neg$0 = 1;
  label = 5;
 } else {
  $$1$ph = $$0;$8 = $5;$neg$1$ph = 0;
 }
 if ((label|0) == 5) {
  $$pre = HEAP8[$4>>0]|0;
  $$1$ph = $4;$8 = $$pre;$neg$1$ph = $neg$0;
 }
 $7 = $8 << 24 >> 24;
 $9 = (_isdigit($7)|0);
 $10 = ($9|0)==(0);
 if ($10) {
  $n$0$lcssa = 0;
  $20 = ($neg$1$ph|0)!=(0);
  $21 = (0 - ($n$0$lcssa))|0;
  $22 = $20 ? $n$0$lcssa : $21;
  STACKTOP = sp;return ($22|0);
 } else {
  $$12 = $$1$ph;$n$03 = 0;
 }
 while(1) {
  $11 = ($n$03*10)|0;
  $12 = (($$12) + 1|0);
  $13 = HEAP8[$$12>>0]|0;
  $14 = $13 << 24 >> 24;
  $$neg1 = (($11) + 48)|0;
  $15 = (($$neg1) - ($14))|0;
  $16 = HEAP8[$12>>0]|0;
  $17 = $16 << 24 >> 24;
  $18 = (_isdigit($17)|0);
  $19 = ($18|0)==(0);
  if ($19) {
   $n$0$lcssa = $15;
   break;
  } else {
   $$12 = $12;$n$03 = $15;
  }
 }
 $20 = ($neg$1$ph|0)!=(0);
 $21 = (0 - ($n$0$lcssa))|0;
 $22 = $20 ? $n$0$lcssa : $21;
 STACKTOP = sp;return ($22|0);
}
function _strtod($s,$p) {
 $s = $s|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f$i = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $f$i = sp;
 dest=$f$i+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($f$i) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = (($f$i) + 8|0);
 HEAP32[$1>>2] = (-1);
 $2 = (($f$i) + 44|0);
 HEAP32[$2>>2] = $s;
 $3 = (($f$i) + 76|0);
 HEAP32[$3>>2] = -1;
 ___shlim($f$i,0);
 $4 = (+___floatscan($f$i,1,1));
 $5 = (($f$i) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$1>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = (($11) + ($6))|0;
 $13 = ($p|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return (+$4);
 }
 $14 = ($12|0)==(0);
 if ($14) {
  $16 = $s;
 } else {
  $15 = (($s) + ($12)|0);
  $16 = $15;
 }
 HEAP32[$p>>2] = $16;
 STACKTOP = sp;return (+$4);
}
function _strtold_l($s,$p,$loc) {
 $s = $s|0;
 $p = $p|0;
 $loc = $loc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f$i$i = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $f$i$i = sp;
 dest=$f$i$i+0|0; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = (($f$i$i) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = (($f$i$i) + 8|0);
 HEAP32[$1>>2] = (-1);
 $2 = (($f$i$i) + 44|0);
 HEAP32[$2>>2] = $s;
 $3 = (($f$i$i) + 76|0);
 HEAP32[$3>>2] = -1;
 ___shlim($f$i$i,0);
 $4 = (+___floatscan($f$i$i,2,1));
 $5 = (($f$i$i) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$1>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = (($11) + ($6))|0;
 $13 = ($p|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return (+$4);
 }
 $14 = ($12|0)==(0);
 if ($14) {
  $16 = $s;
 } else {
  $15 = (($s) + ($12)|0);
  $16 = $15;
 }
 HEAP32[$p>>2] = $16;
 STACKTOP = sp;return (+$4);
}
function _strtoull($s,$p,$base) {
 $s = $s|0;
 $p = $p|0;
 $base = $base|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $f$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $f$i = sp;
 HEAP32[$f$i>>2] = 0;
 $0 = (($f$i) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = (($f$i) + 44|0);
 HEAP32[$1>>2] = $s;
 $2 = ($s|0)<(0|0);
 if ($2) {
  $3 = (($f$i) + 8|0);
  HEAP32[$3>>2] = (-1);
 } else {
  $4 = (($s) + 2147483647|0);
  $5 = (($f$i) + 8|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($f$i) + 76|0);
 HEAP32[$6>>2] = -1;
 ___shlim($f$i,0);
 $7 = (___intscan($f$i,$base,1,-1,-1)|0);
 $8 = tempRet0;
 $9 = ($p|0)==(0|0);
 if ($9) {
  tempRet0 = $8;
  STACKTOP = sp;return ($7|0);
 }
 $10 = (($f$i) + 108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 $13 = (($f$i) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $12;
 $16 = $14;
 $17 = (($15) + ($11))|0;
 $18 = (($17) - ($16))|0;
 $19 = (($s) + ($18)|0);
 HEAP32[$p>>2] = $19;
 tempRet0 = $8;
 STACKTOP = sp;return ($7|0);
}
function _strtoll($s,$p,$base) {
 $s = $s|0;
 $p = $p|0;
 $base = $base|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $f$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $f$i = sp;
 HEAP32[$f$i>>2] = 0;
 $0 = (($f$i) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = (($f$i) + 44|0);
 HEAP32[$1>>2] = $s;
 $2 = ($s|0)<(0|0);
 if ($2) {
  $3 = (($f$i) + 8|0);
  HEAP32[$3>>2] = (-1);
 } else {
  $4 = (($s) + 2147483647|0);
  $5 = (($f$i) + 8|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($f$i) + 76|0);
 HEAP32[$6>>2] = -1;
 ___shlim($f$i,0);
 $7 = (___intscan($f$i,$base,1,0,-2147483648)|0);
 $8 = tempRet0;
 $9 = ($p|0)==(0|0);
 if ($9) {
  tempRet0 = $8;
  STACKTOP = sp;return ($7|0);
 }
 $10 = (($f$i) + 108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 $13 = (($f$i) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $12;
 $16 = $14;
 $17 = (($15) + ($11))|0;
 $18 = (($17) - ($16))|0;
 $19 = (($s) + ($18)|0);
 HEAP32[$p>>2] = $19;
 tempRet0 = $8;
 STACKTOP = sp;return ($7|0);
}
function _strtoul($s,$p,$base) {
 $s = $s|0;
 $p = $p|0;
 $base = $base|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $f$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $f$i = sp;
 HEAP32[$f$i>>2] = 0;
 $0 = (($f$i) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = (($f$i) + 44|0);
 HEAP32[$1>>2] = $s;
 $2 = ($s|0)<(0|0);
 if ($2) {
  $3 = (($f$i) + 8|0);
  HEAP32[$3>>2] = (-1);
 } else {
  $4 = (($s) + 2147483647|0);
  $5 = (($f$i) + 8|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($f$i) + 76|0);
 HEAP32[$6>>2] = -1;
 ___shlim($f$i,0);
 $7 = (___intscan($f$i,$base,1,-1,0)|0);
 $8 = tempRet0;
 $9 = ($p|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return ($7|0);
 }
 $10 = (($f$i) + 108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 $13 = (($f$i) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $12;
 $16 = $14;
 $17 = (($15) + ($11))|0;
 $18 = (($17) - ($16))|0;
 $19 = (($s) + ($18)|0);
 HEAP32[$p>>2] = $19;
 STACKTOP = sp;return ($7|0);
}
function _strtol($s,$p,$base) {
 $s = $s|0;
 $p = $p|0;
 $base = $base|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $f$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $f$i = sp;
 HEAP32[$f$i>>2] = 0;
 $0 = (($f$i) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = (($f$i) + 44|0);
 HEAP32[$1>>2] = $s;
 $2 = ($s|0)<(0|0);
 if ($2) {
  $3 = (($f$i) + 8|0);
  HEAP32[$3>>2] = (-1);
 } else {
  $4 = (($s) + 2147483647|0);
  $5 = (($f$i) + 8|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = (($f$i) + 76|0);
 HEAP32[$6>>2] = -1;
 ___shlim($f$i,0);
 $7 = (___intscan($f$i,$base,1,-2147483648,0)|0);
 $8 = tempRet0;
 $9 = ($p|0)==(0|0);
 if ($9) {
  STACKTOP = sp;return ($7|0);
 }
 $10 = (($f$i) + 108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = HEAP32[$0>>2]|0;
 $13 = (($f$i) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $12;
 $16 = $14;
 $17 = (($15) + ($11))|0;
 $18 = (($17) - ($16))|0;
 $19 = (($s) + ($18)|0);
 HEAP32[$p>>2] = $19;
 STACKTOP = sp;return ($7|0);
}
function _memchr($src,$c,$n) {
 $src = $src|0;
 $c = $c|0;
 $n = $n|0;
 var $$0$lcssa = 0, $$0$lcssa34 = 0, $$013 = 0, $$1$lcssa = 0, $$17 = 0, $$24 = 0, $$3 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond12 = 0, $s$0$lcssa = 0, $s$0$lcssa33 = 0, $s$014 = 0, $s$15 = 0, $s$2 = 0, $w$0$lcssa = 0, $w$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c & 255;
 $1 = $src;
 $2 = $1 & 3;
 $3 = ($2|0)==(0);
 $4 = ($n|0)==(0);
 $or$cond12 = $3 | $4;
 L1: do {
  if ($or$cond12) {
   $$0$lcssa = $n;$$lcssa = $4;$s$0$lcssa = $src;
   label = 5;
  } else {
   $5 = $c&255;
   $$013 = $n;$s$014 = $src;
   while(1) {
    $6 = HEAP8[$s$014>>0]|0;
    $7 = ($6<<24>>24)==($5<<24>>24);
    if ($7) {
     $$0$lcssa34 = $$013;$s$0$lcssa33 = $s$014;
     label = 6;
     break L1;
    }
    $8 = (($s$014) + 1|0);
    $9 = (($$013) + -1)|0;
    $10 = $8;
    $11 = $10 & 3;
    $12 = ($11|0)==(0);
    $13 = ($9|0)==(0);
    $or$cond = $12 | $13;
    if ($or$cond) {
     $$0$lcssa = $9;$$lcssa = $13;$s$0$lcssa = $8;
     label = 5;
     break;
    } else {
     $$013 = $9;$s$014 = $8;
    }
   }
  }
 } while(0);
 if ((label|0) == 5) {
  if ($$lcssa) {
   $$3 = 0;$s$2 = $s$0$lcssa;
  } else {
   $$0$lcssa34 = $$0$lcssa;$s$0$lcssa33 = $s$0$lcssa;
   label = 6;
  }
 }
 L8: do {
  if ((label|0) == 6) {
   $14 = HEAP8[$s$0$lcssa33>>0]|0;
   $15 = $c&255;
   $16 = ($14<<24>>24)==($15<<24>>24);
   if ($16) {
    $$3 = $$0$lcssa34;$s$2 = $s$0$lcssa33;
   } else {
    $17 = Math_imul($0, 16843009)|0;
    $18 = ($$0$lcssa34>>>0)>(3);
    L11: do {
     if ($18) {
      $$17 = $$0$lcssa34;$w$08 = $s$0$lcssa33;
      while(1) {
       $19 = HEAP32[$w$08>>2]|0;
       $20 = $19 ^ $17;
       $21 = (($20) + -16843009)|0;
       $22 = $20 & -2139062144;
       $23 = $22 ^ -2139062144;
       $24 = $23 & $21;
       $25 = ($24|0)==(0);
       if (!($25)) {
        $$1$lcssa = $$17;$w$0$lcssa = $w$08;
        break L11;
       }
       $26 = (($w$08) + 4|0);
       $27 = (($$17) + -4)|0;
       $28 = ($27>>>0)>(3);
       if ($28) {
        $$17 = $27;$w$08 = $26;
       } else {
        $$1$lcssa = $27;$w$0$lcssa = $26;
        break;
       }
      }
     } else {
      $$1$lcssa = $$0$lcssa34;$w$0$lcssa = $s$0$lcssa33;
     }
    } while(0);
    $29 = ($$1$lcssa|0)==(0);
    if ($29) {
     $$3 = 0;$s$2 = $w$0$lcssa;
    } else {
     $$24 = $$1$lcssa;$s$15 = $w$0$lcssa;
     while(1) {
      $30 = HEAP8[$s$15>>0]|0;
      $31 = ($30<<24>>24)==($15<<24>>24);
      if ($31) {
       $$3 = $$24;$s$2 = $s$15;
       break L8;
      }
      $32 = (($s$15) + 1|0);
      $33 = (($$24) + -1)|0;
      $34 = ($33|0)==(0);
      if ($34) {
       $$3 = 0;$s$2 = $32;
       break;
      } else {
       $$24 = $33;$s$15 = $32;
      }
     }
    }
   }
  }
 } while(0);
 $35 = ($$3|0)!=(0);
 $36 = $35 ? $s$2 : 0;
 STACKTOP = sp;return ($36|0);
}
function _memcmp($vl,$vr,$n) {
 $vl = $vl|0;
 $vr = $vr|0;
 $n = $n|0;
 var $$03 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$04 = 0, $r$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 L1: do {
  if ($0) {
   $11 = 0;
  } else {
   $$03 = $n;$l$04 = $vl;$r$05 = $vr;
   while(1) {
    $1 = HEAP8[$l$04>>0]|0;
    $2 = HEAP8[$r$05>>0]|0;
    $3 = ($1<<24>>24)==($2<<24>>24);
    if (!($3)) {
     break;
    }
    $4 = (($$03) + -1)|0;
    $5 = (($l$04) + 1|0);
    $6 = (($r$05) + 1|0);
    $7 = ($4|0)==(0);
    if ($7) {
     $11 = 0;
     break L1;
    } else {
     $$03 = $4;$l$04 = $5;$r$05 = $6;
    }
   }
   $8 = $1&255;
   $9 = $2&255;
   $10 = (($8) - ($9))|0;
   $11 = $10;
  }
 } while(0);
 STACKTOP = sp;return ($11|0);
}
function _strcasecmp($_l,$_r) {
 $_l = $_l|0;
 $_r = $_r|0;
 var $$pre$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$03 = 0, $r$0$lcssa = 0, $r$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$_l>>0]|0;
 $1 = ($0<<24>>24)==(0);
 L1: do {
  if ($1) {
   $19 = 0;$r$0$lcssa = $_r;
  } else {
   $2 = $0&255;
   $6 = $0;$7 = $2;$l$03 = $_l;$r$04 = $_r;
   while(1) {
    $3 = HEAP8[$r$04>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     $19 = $6;$r$0$lcssa = $r$04;
     break L1;
    }
    $5 = ($6<<24>>24)==($3<<24>>24);
    if (!($5)) {
     $8 = (_tolower($7)|0);
     $9 = HEAP8[$r$04>>0]|0;
     $10 = $9&255;
     $11 = (_tolower($10)|0);
     $12 = ($8|0)==($11|0);
     if (!($12)) {
      break;
     }
    }
    $13 = (($l$03) + 1|0);
    $14 = (($r$04) + 1|0);
    $15 = HEAP8[$13>>0]|0;
    $16 = $15&255;
    $17 = ($15<<24>>24)==(0);
    if ($17) {
     $19 = 0;$r$0$lcssa = $14;
     break L1;
    } else {
     $6 = $15;$7 = $16;$l$03 = $13;$r$04 = $14;
    }
   }
   $$pre$pre = HEAP8[$l$03>>0]|0;
   $19 = $$pre$pre;$r$0$lcssa = $r$04;
  }
 } while(0);
 $18 = $19&255;
 $20 = (_tolower($18)|0);
 $21 = HEAP8[$r$0$lcssa>>0]|0;
 $22 = $21&255;
 $23 = (_tolower($22)|0);
 $24 = (($20) - ($23))|0;
 STACKTOP = sp;return ($24|0);
}
function _strcmp($l,$r) {
 $l = $l|0;
 $r = $r|0;
 var $$014 = 0, $$05 = 0, $$lcssa = 0, $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$l>>0]|0;
 $1 = HEAP8[$r>>0]|0;
 $2 = ($0<<24>>24)!=($1<<24>>24);
 $3 = ($0<<24>>24)==(0);
 $or$cond3 = $2 | $3;
 if ($or$cond3) {
  $$lcssa = $0;$$lcssa2 = $1;
 } else {
  $$014 = $l;$$05 = $r;
  while(1) {
   $4 = (($$014) + 1|0);
   $5 = (($$05) + 1|0);
   $6 = HEAP8[$4>>0]|0;
   $7 = HEAP8[$5>>0]|0;
   $8 = ($6<<24>>24)!=($7<<24>>24);
   $9 = ($6<<24>>24)==(0);
   $or$cond = $8 | $9;
   if ($or$cond) {
    $$lcssa = $6;$$lcssa2 = $7;
    break;
   } else {
    $$014 = $4;$$05 = $5;
   }
  }
 }
 $10 = $$lcssa&255;
 $11 = $$lcssa2&255;
 $12 = (($10) - ($11))|0;
 STACKTOP = sp;return ($12|0);
}
function _strncmp($_l,$_r,$n) {
 $_l = $_l|0;
 $_r = $_r|0;
 $n = $n|0;
 var $$03 = 0, $$08 = 0, $$08$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$06 = 0, $notlhs = 0;
 var $notrhs = 0, $or$cond$not = 0, $or$cond4 = 0, $r$0$lcssa = 0, $r$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $$03 = 0;
  STACKTOP = sp;return ($$03|0);
 }
 $1 = HEAP8[$_l>>0]|0;
 $2 = ($1<<24>>24)==(0);
 L4: do {
  if ($2) {
   $11 = 0;$r$0$lcssa = $_r;
  } else {
   $$08$in = $n;$5 = $1;$l$06 = $_l;$r$07 = $_r;
   while(1) {
    $$08 = (($$08$in) + -1)|0;
    $3 = HEAP8[$r$07>>0]|0;
    $notlhs = ($3<<24>>24)!=(0);
    $notrhs = ($$08|0)!=(0);
    $or$cond$not = $notrhs & $notlhs;
    $4 = ($5<<24>>24)==($3<<24>>24);
    $or$cond4 = $or$cond$not & $4;
    if (!($or$cond4)) {
     $11 = $5;$r$0$lcssa = $r$07;
     break L4;
    }
    $6 = (($l$06) + 1|0);
    $7 = (($r$07) + 1|0);
    $8 = HEAP8[$6>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $11 = 0;$r$0$lcssa = $7;
     break;
    } else {
     $$08$in = $$08;$5 = $8;$l$06 = $6;$r$07 = $7;
    }
   }
  }
 } while(0);
 $10 = $11&255;
 $12 = HEAP8[$r$0$lcssa>>0]|0;
 $13 = $12&255;
 $14 = (($10) - ($13))|0;
 $$03 = $14;
 STACKTOP = sp;return ($$03|0);
}
function runPostSets() {
 
}
function _llvm_ctlz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((ctlz_i8)+(x >>> 24))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((ctlz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((ctlz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((ctlz_i8)+(x&0xff))>>0)])|0) + 24)|0;
}
function _saveSetjmp(env, label, table) {
    // Not particularly fast: slow table lookup of setjmpId to label. But setjmp
    // prevents relooping anyhow, so slowness is to be expected. And typical case
    // is 1 setjmp per invocation, or less.
    env = env|0;
    label = label|0;
    table = table|0;
    var i = 0;
    setjmpId = (setjmpId+1)|0;
    HEAP32[((env)>>2)]=setjmpId;
    while ((i|0) < 20) {
      if (((HEAP32[(((table)+((i<<3)))>>2)])|0) == 0) {
        HEAP32[(((table)+((i<<3)))>>2)]=setjmpId;
        HEAP32[(((table)+((i<<3)+4))>>2)]=label;
        // prepare next slot
        HEAP32[(((table)+((i<<3)+8))>>2)]=0;
        return 0;
      }
      i = i+1|0;
    }
    _putchar(116);_putchar(111);_putchar(111);_putchar(32);_putchar(109);_putchar(97);_putchar(110);_putchar(121);_putchar(32);_putchar(115);_putchar(101);_putchar(116);_putchar(106);_putchar(109);_putchar(112);_putchar(115);_putchar(32);_putchar(105);_putchar(110);_putchar(32);_putchar(97);_putchar(32);_putchar(102);_putchar(117);_putchar(110);_putchar(99);_putchar(116);_putchar(105);_putchar(111);_putchar(110);_putchar(32);_putchar(99);_putchar(97);_putchar(108);_putchar(108);_putchar(44);_putchar(32);_putchar(98);_putchar(117);_putchar(105);_putchar(108);_putchar(100);_putchar(32);_putchar(119);_putchar(105);_putchar(116);_putchar(104);_putchar(32);_putchar(97);_putchar(32);_putchar(104);_putchar(105);_putchar(103);_putchar(104);_putchar(101);_putchar(114);_putchar(32);_putchar(118);_putchar(97);_putchar(108);_putchar(117);_putchar(101);_putchar(32);_putchar(102);_putchar(111);_putchar(114);_putchar(32);_putchar(77);_putchar(65);_putchar(88);_putchar(95);_putchar(83);_putchar(69);_putchar(84);_putchar(74);_putchar(77);_putchar(80);_putchar(83);_putchar(10);
    abort(0);
    return 0;
}
function _strlen(ptr) {
    ptr = ptr|0;
    var curr = 0;
    curr = ptr;
    while (((HEAP8[((curr)>>0)])|0)) {
      curr = (curr + 1)|0;
    }
    return (curr - ptr)|0;
}
function _bitshift64Ashr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = (high|0) < 0 ? -1 : 0;
    return (high >> (bits - 32))|0;
}
function _bitshift64Shl(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits));
      return low << bits;
    }
    tempRet0 = low << (bits - 32);
    return 0;
}
function _strncpy(pdest, psrc, num) {
    pdest = pdest|0; psrc = psrc|0; num = num|0;
    var padding = 0, curr = 0, i = 0;
    while ((i|0) < (num|0)) {
      curr = padding ? 0 : ((HEAP8[(((psrc)+(i))>>0)])|0);
      HEAP8[(((pdest)+(i))>>0)]=curr;
      padding = padding ? 1 : (((HEAP8[(((psrc)+(i))>>0)])|0) == 0);
      i = (i+1)|0;
    }
    return pdest|0;
}
function _bitshift64Lshr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >>> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = 0;
    return (high >>> (bits - 32))|0;
}
function _memset(ptr, value, num) {
    ptr = ptr|0; value = value|0; num = num|0;
    var stop = 0, value4 = 0, stop4 = 0, unaligned = 0;
    stop = (ptr + num)|0;
    if ((num|0) >= 20) {
      // This is unaligned, but quite large, so work hard to get to aligned settings
      value = value & 0xff;
      unaligned = ptr & 3;
      value4 = value | (value << 8) | (value << 16) | (value << 24);
      stop4 = stop & ~3;
      if (unaligned) {
        unaligned = (ptr + 4 - unaligned)|0;
        while ((ptr|0) < (unaligned|0)) { // no need to check for stop, since we have large num
          HEAP8[((ptr)>>0)]=value;
          ptr = (ptr+1)|0;
        }
      }
      while ((ptr|0) < (stop4|0)) {
        HEAP32[((ptr)>>2)]=value4;
        ptr = (ptr+4)|0;
      }
    }
    while ((ptr|0) < (stop|0)) {
      HEAP8[((ptr)>>0)]=value;
      ptr = (ptr+1)|0;
    }
    return (ptr-num)|0;
}
function _testSetjmp(id, table) {
    id = id|0;
    table = table|0;
    var i = 0, curr = 0;
    while ((i|0) < 20) {
      curr = ((HEAP32[(((table)+((i<<3)))>>2)])|0);
      if ((curr|0) == 0) break;
      if ((curr|0) == (id|0)) {
        return ((HEAP32[(((table)+((i<<3)+4))>>2)])|0);
      }
      i = i+1|0;
    }
    return 0;
}
function _llvm_bswap_i32(x) {
    x = x|0;
    return (((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24))|0;
}
function _memcpy(dest, src, num) {

    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if ((num|0) >= 4096) return _emscripten_memcpy_big(dest|0, src|0, num|0)|0;
    ret = dest|0;
    if ((dest&3) == (src&3)) {
      while (dest & 3) {
        if ((num|0) == 0) return ret|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        dest = (dest+1)|0;
        src = (src+1)|0;
        num = (num-1)|0;
      }
      while ((num|0) >= 4) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
        num = (num-4)|0;
      }
    }
    while ((num|0) > 0) {
      HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      dest = (dest+1)|0;
      src = (src+1)|0;
      num = (num-1)|0;
    }
    return ret|0;
}
function _i64Subtract(a, b, c, d) {
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a - c)>>>0;
    h = (b - d)>>>0;
    h = (b - d - (((c>>>0) > (a>>>0))|0))>>>0; // Borrow one from high word to low word on underflow.
    return ((tempRet0 = h,l|0)|0);
}
function _i64Add(a, b, c, d) {
    /*
      x = a + b*2^32
      y = c + d*2^32
      result = l + h*2^32
    */
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a + c)>>>0;
    h = (b + d + (((l>>>0) < (a>>>0))|0))>>>0; // Add carry from low word to high word on overflow.
    return ((tempRet0 = h,l|0)|0);
}
function _llvm_cttz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((cttz_i8)+(x & 0xff))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((cttz_i8)+(x >>> 24))>>0)])|0) + 24)|0;
}
function _memmove(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if (((src|0) < (dest|0)) & ((dest|0) < ((src + num)|0))) {
      // Unlikely case: Copy backwards in a safe manner
      ret = dest;
      src = (src + num)|0;
      dest = (dest + num)|0;
      while ((num|0) > 0) {
        dest = (dest - 1)|0;
        src = (src - 1)|0;
        num = (num - 1)|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      }
      dest = ret;
    } else {
      _memcpy(dest, src, num) | 0;
    }
    return dest | 0;
}
function _strcpy(pdest, psrc) {
    pdest = pdest|0; psrc = psrc|0;
    var i = 0;
    do {
      HEAP8[(((pdest+i)|0)>>0)]=HEAP8[(((psrc+i)|0)>>0)];
      i = (i+1)|0;
    } while (((HEAP8[(((psrc)+(i-1))>>0)])|0));
    return pdest|0;
}
// ======== compiled code from system/lib/compiler-rt , see readme therein
function ___muldsi3($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
  $1 = $a & 65535;
  $2 = $b & 65535;
  $3 = Math_imul($2, $1) | 0;
  $6 = $a >>> 16;
  $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0;
  $11 = $b >>> 16;
  $12 = Math_imul($11, $1) | 0;
  return (tempRet0 = (($8 >>> 16) + (Math_imul($11, $6) | 0) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0, 0 | ($8 + $12 << 16 | $3 & 65535)) | 0;
}
function ___divdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $7$0 = 0, $7$1 = 0, $8$0 = 0, $10$0 = 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  $7$0 = $2$0 ^ $1$0;
  $7$1 = $2$1 ^ $1$1;
  $8$0 = ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, 0) | 0;
  $10$0 = _i64Subtract($8$0 ^ $7$0, tempRet0 ^ $7$1, $7$0, $7$1) | 0;
  return (tempRet0 = tempRet0, $10$0) | 0;
}
function ___remdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $10$0 = 0, $10$1 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, $rem) | 0;
  $10$0 = _i64Subtract(HEAP32[$rem >> 2] ^ $1$0, HEAP32[$rem + 4 >> 2] ^ $1$1, $1$0, $1$1) | 0;
  $10$1 = tempRet0;
  STACKTOP = __stackBase__;
  return (tempRet0 = $10$1, $10$0) | 0;
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0, $2 = 0;
  $x_sroa_0_0_extract_trunc = $a$0;
  $y_sroa_0_0_extract_trunc = $b$0;
  $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0;
  $1$1 = tempRet0;
  $2 = Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0;
  return (tempRet0 = ((Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $2 | 0) + $1$1 | $1$1 & 0, 0 | $1$0 & -1) | 0;
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0;
  $1$0 = ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0;
  return (tempRet0 = tempRet0, $1$0) | 0;
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0;
  STACKTOP = __stackBase__;
  return (tempRet0 = HEAP32[$rem + 4 >> 2] | 0, HEAP32[$rem >> 2] | 0) | 0;
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  $rem = $rem | 0;
  var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $49 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $117 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $147 = 0, $149 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $152 = 0, $154$0 = 0, $r_sroa_0_0_extract_trunc = 0, $r_sroa_1_4_extract_trunc = 0, $155 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $q_sroa_0_0_insert_insert77$1 = 0, $_0$0 = 0, $_0$1 = 0;
  $n_sroa_0_0_extract_trunc = $a$0;
  $n_sroa_1_4_extract_shift$0 = $a$1;
  $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0;
  $d_sroa_0_0_extract_trunc = $b$0;
  $d_sroa_1_4_extract_shift$0 = $b$1;
  $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0;
  if (($n_sroa_1_4_extract_trunc | 0) == 0) {
    $4 = ($rem | 0) != 0;
    if (($d_sroa_1_4_extract_trunc | 0) == 0) {
      if ($4) {
        HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
        HEAP32[$rem + 4 >> 2] = 0;
      }
      $_0$1 = 0;
      $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$4) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    }
  }
  $17 = ($d_sroa_1_4_extract_trunc | 0) == 0;
  do {
    if (($d_sroa_0_0_extract_trunc | 0) == 0) {
      if ($17) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
          HEAP32[$rem + 4 >> 2] = 0;
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      if (($n_sroa_0_0_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0;
          HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0);
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $37 = $d_sroa_1_4_extract_trunc - 1 | 0;
      if (($37 & $d_sroa_1_4_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0 | $a$0 & -1;
          HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0;
        }
        $_0$1 = 0;
        $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0);
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $49 = _llvm_ctlz_i32($d_sroa_1_4_extract_trunc | 0) | 0;
      $51 = $49 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
      if ($51 >>> 0 <= 30) {
        $57 = $51 + 1 | 0;
        $58 = 31 - $51 | 0;
        $sr_1_ph = $57;
        $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0);
        $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0);
        $q_sroa_0_1_ph = 0;
        $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58;
        break;
      }
      if (($rem | 0) == 0) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = 0 | $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$17) {
        $117 = _llvm_ctlz_i32($d_sroa_1_4_extract_trunc | 0) | 0;
        $119 = $117 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        if ($119 >>> 0 <= 31) {
          $125 = $119 + 1 | 0;
          $126 = 31 - $119 | 0;
          $130 = $119 - 31 >> 31;
          $sr_1_ph = $125;
          $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126;
          $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130;
          $q_sroa_0_1_ph = 0;
          $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126;
          break;
        }
        if (($rem | 0) == 0) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = 0 | $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $66 = $d_sroa_0_0_extract_trunc - 1 | 0;
      if (($66 & $d_sroa_0_0_extract_trunc | 0) != 0) {
        $86 = (_llvm_ctlz_i32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 | 0;
        $88 = $86 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        $89 = 64 - $88 | 0;
        $91 = 32 - $88 | 0;
        $92 = $91 >> 31;
        $95 = $88 - 32 | 0;
        $105 = $95 >> 31;
        $sr_1_ph = $88;
        $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105;
        $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0);
        $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92;
        $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31;
        break;
      }
      if (($rem | 0) != 0) {
        HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc;
        HEAP32[$rem + 4 >> 2] = 0;
      }
      if (($d_sroa_0_0_extract_trunc | 0) == 1) {
        $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$0 = 0 | $a$0 & -1;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      } else {
        $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0;
        $_0$1 = 0 | $n_sroa_1_4_extract_trunc >>> ($78 >>> 0);
        $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
    }
  } while (0);
  if (($sr_1_ph | 0) == 0) {
    $q_sroa_1_1_lcssa = $q_sroa_1_1_ph;
    $q_sroa_0_1_lcssa = $q_sroa_0_1_ph;
    $r_sroa_1_1_lcssa = $r_sroa_1_1_ph;
    $r_sroa_0_1_lcssa = $r_sroa_0_1_ph;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = 0;
  } else {
    $d_sroa_0_0_insert_insert99$0 = 0 | $b$0 & -1;
    $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0;
    $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0, $d_sroa_0_0_insert_insert99$1, -1, -1) | 0;
    $137$1 = tempRet0;
    $q_sroa_1_1198 = $q_sroa_1_1_ph;
    $q_sroa_0_1199 = $q_sroa_0_1_ph;
    $r_sroa_1_1200 = $r_sroa_1_1_ph;
    $r_sroa_0_1201 = $r_sroa_0_1_ph;
    $sr_1202 = $sr_1_ph;
    $carry_0203 = 0;
    while (1) {
      $147 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1;
      $149 = $carry_0203 | $q_sroa_0_1199 << 1;
      $r_sroa_0_0_insert_insert42$0 = 0 | ($r_sroa_0_1201 << 1 | $q_sroa_1_1198 >>> 31);
      $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0;
      _i64Subtract($137$0, $137$1, $r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1) | 0;
      $150$1 = tempRet0;
      $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1;
      $152 = $151$0 & 1;
      $154$0 = _i64Subtract($r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1, $151$0 & $d_sroa_0_0_insert_insert99$0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1) | 0;
      $r_sroa_0_0_extract_trunc = $154$0;
      $r_sroa_1_4_extract_trunc = tempRet0;
      $155 = $sr_1202 - 1 | 0;
      if (($155 | 0) == 0) {
        break;
      } else {
        $q_sroa_1_1198 = $147;
        $q_sroa_0_1199 = $149;
        $r_sroa_1_1200 = $r_sroa_1_4_extract_trunc;
        $r_sroa_0_1201 = $r_sroa_0_0_extract_trunc;
        $sr_1202 = $155;
        $carry_0203 = $152;
      }
    }
    $q_sroa_1_1_lcssa = $147;
    $q_sroa_0_1_lcssa = $149;
    $r_sroa_1_1_lcssa = $r_sroa_1_4_extract_trunc;
    $r_sroa_0_1_lcssa = $r_sroa_0_0_extract_trunc;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = $152;
  }
  $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa;
  $q_sroa_0_0_insert_ext75$1 = 0;
  $q_sroa_0_0_insert_insert77$1 = $q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1;
  if (($rem | 0) != 0) {
    HEAP32[$rem >> 2] = 0 | $r_sroa_0_1_lcssa;
    HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa | 0;
  }
  $_0$1 = (0 | $q_sroa_0_0_insert_ext75$0) >>> 31 | $q_sroa_0_0_insert_insert77$1 << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1;
  $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0;
  return (tempRet0 = $_0$1, $_0$0) | 0;
}
// =======================================================================



// EMSCRIPTEN_END_FUNCS

    
    function dynCall_fiff(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3);
      return Math_fround(FUNCTION_TABLE_fiff[index&15](a1|0,Math_fround(a2),Math_fround(a3)));
    }
  

    function dynCall_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0;
      return FUNCTION_TABLE_iiiiiii[index&255](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0)|0;
    }
  

    function dynCall_vifiiiiiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0; a16=a16|0; a17=a17|0; a18=a18|0; a19=a19|0; a20=a20|0; a21=a21|0;
      FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiiii[index&1](a1|0,Math_fround(a2),a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0,a16|0,a17|0,a18|0,a19|0,a20|0,a21|0);
    }
  

    function dynCall_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0;
      FUNCTION_TABLE_viiiiiiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0);
    }
  

    function dynCall_fff(index,a1,a2) {
      index = index|0;
      a1=Math_fround(a1); a2=Math_fround(a2);
      return Math_fround(FUNCTION_TABLE_fff[index&3](Math_fround(a1),Math_fround(a2)));
    }
  

    function dynCall_iidi(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=+a2; a3=a3|0;
      return FUNCTION_TABLE_iidi[index&3](a1|0,+a2,a3|0)|0;
    }
  

    function dynCall_fiiiiiifiiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=Math_fround(a7); a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=Math_fround(a14);
      return Math_fround(FUNCTION_TABLE_fiiiiiifiiiiiif[index&7](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,Math_fround(a7),a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,Math_fround(a14)));
    }
  

    function dynCall_iiiiifiif(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=a6|0; a7=a7|0; a8=Math_fround(a8);
      return FUNCTION_TABLE_iiiiifiif[index&31](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),a6|0,a7|0,Math_fround(a8))|0;
    }
  

    function dynCall_viiiiiffi(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=Math_fround(a6); a7=Math_fround(a7); a8=a8|0;
      FUNCTION_TABLE_viiiiiffi[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,Math_fround(a6),Math_fround(a7),a8|0);
    }
  

    function dynCall_iiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0;
      return FUNCTION_TABLE_iiiiiiiiiiii[index&7](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0)|0;
    }
  

    function dynCall_fiffifff(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=a4|0; a5=Math_fround(a5); a6=Math_fround(a6); a7=Math_fround(a7);
      return Math_fround(FUNCTION_TABLE_fiffifff[index&3](a1|0,Math_fround(a2),Math_fround(a3),a4|0,Math_fround(a5),Math_fround(a6),Math_fround(a7)));
    }
  

    function dynCall_fif(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2);
      return Math_fround(FUNCTION_TABLE_fif[index&31](a1|0,Math_fround(a2)));
    }
  

    function dynCall_viiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0;
      FUNCTION_TABLE_viiiiiiiiiiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0);
    }
  

    function dynCall_fid(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=+a2;
      return Math_fround(FUNCTION_TABLE_fid[index&1](a1|0,+a2));
    }
  

    function dynCall_fii(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=a2|0;
      return Math_fround(FUNCTION_TABLE_fii[index&63](a1|0,a2|0));
    }
  

    function dynCall_ddii(index,a1,a2,a3) {
      index = index|0;
      a1=+a1; a2=a2|0; a3=a3|0;
      return +FUNCTION_TABLE_ddii[index&1](+a1,a2|0,a3|0);
    }
  

    function dynCall_di(index,a1) {
      index = index|0;
      a1=a1|0;
      return +FUNCTION_TABLE_di[index&15](a1|0);
    }
  

    function dynCall_dd(index,a1) {
      index = index|0;
      a1=+a1;
      return +FUNCTION_TABLE_dd[index&15](+a1);
    }
  

    function dynCall_viff(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3);
      FUNCTION_TABLE_viff[index&31](a1|0,Math_fround(a2),Math_fround(a3));
    }
  

    function dynCall_vffi(index,a1,a2,a3) {
      index = index|0;
      a1=Math_fround(a1); a2=Math_fround(a2); a3=a3|0;
      FUNCTION_TABLE_vffi[index&1](Math_fround(a1),Math_fround(a2),a3|0);
    }
  

    function dynCall_viiiifiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=a6|0; a7=a7|0; a8=a8|0;
      FUNCTION_TABLE_viiiifiii[index&1](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),a6|0,a7|0,a8|0);
    }
  

    function dynCall_viffff(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5);
      FUNCTION_TABLE_viffff[index&15](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4),Math_fround(a5));
    }
  

    function dynCall_d(index) {
      index = index|0;
      
      return +FUNCTION_TABLE_d[index&3]();
    }
  

    function dynCall_didd(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=+a2; a3=+a3;
      return +FUNCTION_TABLE_didd[index&3](a1|0,+a2,+a3);
    }
  

    function dynCall_viiiiifffiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=Math_fround(a6); a7=Math_fround(a7); a8=Math_fround(a8); a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0;
      FUNCTION_TABLE_viiiiifffiiiii[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,Math_fround(a6),Math_fround(a7),Math_fround(a8),a9|0,a10|0,a11|0,a12|0,a13|0);
    }
  

    function dynCall_iiiiifffiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=Math_fround(a6); a7=Math_fround(a7); a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0;
      return FUNCTION_TABLE_iiiiifffiiiii[index&1](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),Math_fround(a6),Math_fround(a7),a8|0,a9|0,a10|0,a11|0,a12|0)|0;
    }
  

    function dynCall_dii(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=a2|0;
      return +FUNCTION_TABLE_dii[index&31](a1|0,a2|0);
    }
  

    function dynCall_did(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=+a2;
      return +FUNCTION_TABLE_did[index&15](a1|0,+a2);
    }
  

    function dynCall_dif(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2);
      return +FUNCTION_TABLE_dif[index&1](a1|0,Math_fround(a2));
    }
  

    function dynCall_iifii(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0; a4=a4|0;
      return FUNCTION_TABLE_iifii[index&1](a1|0,Math_fround(a2),a3|0,a4|0)|0;
    }
  

    function dynCall_iiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0;
      return FUNCTION_TABLE_iiiiiiiiii[index&15](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0)|0;
    }
  

    function dynCall_vdddddd(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=+a1; a2=+a2; a3=+a3; a4=+a4; a5=+a5; a6=+a6;
      FUNCTION_TABLE_vdddddd[index&1](+a1,+a2,+a3,+a4,+a5,+a6);
    }
  

    function dynCall_fiffiff(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=a4|0; a5=Math_fround(a5); a6=Math_fround(a6);
      return Math_fround(FUNCTION_TABLE_fiffiff[index&1](a1|0,Math_fround(a2),Math_fround(a3),a4|0,Math_fround(a5),Math_fround(a6)));
    }
  

    function dynCall_iiiiiiiiiiiiffffii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=Math_fround(a12); a13=Math_fround(a13); a14=Math_fround(a14); a15=Math_fround(a15); a16=a16|0; a17=a17|0;
      return FUNCTION_TABLE_iiiiiiiiiiiiffffii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,Math_fround(a12),Math_fround(a13),Math_fround(a14),Math_fround(a15),a16|0,a17|0)|0;
    }
  

    function dynCall_vdd(index,a1,a2) {
      index = index|0;
      a1=+a1; a2=+a2;
      FUNCTION_TABLE_vdd[index&1](+a1,+a2);
    }
  

    function dynCall_viiifiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0;
      FUNCTION_TABLE_viiifiiii[index&1](a1|0,a2|0,a3|0,Math_fround(a4),a5|0,a6|0,a7|0,a8|0);
    }
  

    function dynCall_iiiif(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4);
      return FUNCTION_TABLE_iiiif[index&1](a1|0,a2|0,a3|0,Math_fround(a4))|0;
    }
  

    function dynCall_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0;
      return FUNCTION_TABLE_iiiiiiii[index&127](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0)|0;
    }
  

    function dynCall_iiiiiifffiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=Math_fround(a6); a7=Math_fround(a7); a8=Math_fround(a8); a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0;
      return FUNCTION_TABLE_iiiiiifffiiiii[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,Math_fround(a6),Math_fround(a7),Math_fround(a8),a9|0,a10|0,a11|0,a12|0,a13|0)|0;
    }
  

    function dynCall_vifiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0;
      FUNCTION_TABLE_vifiiiiiiiiiiiii[index&3](a1|0,Math_fround(a2),a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0);
    }
  

    function dynCall_iiiii(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
      return FUNCTION_TABLE_iiiii[index&511](a1|0,a2|0,a3|0,a4|0)|0;
    }
  

    function dynCall_iiifii(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=a4|0; a5=a5|0;
      return FUNCTION_TABLE_iiifii[index&1](a1|0,a2|0,Math_fround(a3),a4|0,a5|0)|0;
    }
  

    function dynCall_fifff(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4);
      return Math_fround(FUNCTION_TABLE_fifff[index&3](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4)));
    }
  

    function dynCall_viffi(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=a4|0;
      FUNCTION_TABLE_viffi[index&3](a1|0,Math_fround(a2),Math_fround(a3),a4|0);
    }
  

    function dynCall_viiiiid(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=+a6;
      FUNCTION_TABLE_viiiiid[index&7](a1|0,a2|0,a3|0,a4|0,a5|0,+a6);
    }
  

    function dynCall_iiiifiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0;
      return FUNCTION_TABLE_iiiifiiii[index&1](a1|0,a2|0,a3|0,Math_fround(a4),a5|0,a6|0,a7|0,a8|0)|0;
    }
  

    function dynCall_vifi(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0;
      FUNCTION_TABLE_vifi[index&3](a1|0,Math_fround(a2),a3|0);
    }
  

    function dynCall_vifff(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4);
      FUNCTION_TABLE_vifff[index&15](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4));
    }
  

    function dynCall_viiiiii(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0;
      FUNCTION_TABLE_viiiiii[index&255](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0);
    }
  

    function dynCall_ddd(index,a1,a2) {
      index = index|0;
      a1=+a1; a2=+a2;
      return +FUNCTION_TABLE_ddd[index&3](+a1,+a2);
    }
  

    function dynCall_fiii(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0;
      return Math_fround(FUNCTION_TABLE_fiii[index&31](a1|0,a2|0,a3|0));
    }
  

    function dynCall_iifff(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4);
      return FUNCTION_TABLE_iifff[index&3](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4))|0;
    }
  

    function dynCall_fiif(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3);
      return Math_fround(FUNCTION_TABLE_fiif[index&1](a1|0,a2|0,Math_fround(a3)));
    }
  

    function dynCall_iiiiiifiiiiiiiiiffffi(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=Math_fround(a6); a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0; a16=Math_fround(a16); a17=Math_fround(a17); a18=Math_fround(a18); a19=Math_fround(a19); a20=a20|0;
      return FUNCTION_TABLE_iiiiiifiiiiiiiiiffffi[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,Math_fround(a6),a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0,Math_fround(a16),Math_fround(a17),Math_fround(a18),Math_fround(a19),a20|0)|0;
    }
  

    function dynCall_iiiiifiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=Math_fround(a10);
      return FUNCTION_TABLE_iiiiifiiiif[index&1](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),a6|0,a7|0,a8|0,a9|0,Math_fround(a10))|0;
    }
  

    function dynCall_viiffffff(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5); a6=Math_fround(a6); a7=Math_fround(a7); a8=Math_fround(a8);
      FUNCTION_TABLE_viiffffff[index&1](a1|0,a2|0,Math_fround(a3),Math_fround(a4),Math_fround(a5),Math_fround(a6),Math_fround(a7),Math_fround(a8));
    }
  

    function dynCall_viiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0;
      FUNCTION_TABLE_viiiiiiiiii[index&15](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0);
    }
  

    function dynCall_diii(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0;
      return +FUNCTION_TABLE_diii[index&15](a1|0,a2|0,a3|0);
    }
  

    function dynCall_fiiii(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
      return Math_fround(FUNCTION_TABLE_fiiii[index&3](a1|0,a2|0,a3|0,a4|0));
    }
  

    function dynCall_iiiiii(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0;
      return FUNCTION_TABLE_iiiiii[index&255](a1|0,a2|0,a3|0,a4|0,a5|0)|0;
    }
  

    function dynCall_viiiiifiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=Math_fround(a6); a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0; a16=a16|0; a17=a17|0; a18=a18|0; a19=a19|0;
      FUNCTION_TABLE_viiiiifiiiiiiiiiiiii[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,Math_fround(a6),a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0,a16|0,a17|0,a18|0,a19|0);
    }
  

    function dynCall_viiiff(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=Math_fround(a5);
      FUNCTION_TABLE_viiiff[index&1](a1|0,a2|0,a3|0,Math_fround(a4),Math_fround(a5));
    }
  

    function dynCall_iiiiiifiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=Math_fround(a6); a7=a7|0; a8=a8|0; a9=Math_fround(a9);
      return FUNCTION_TABLE_iiiiiifiif[index&7](a1|0,a2|0,a3|0,a4|0,a5|0,Math_fround(a6),a7|0,a8|0,Math_fround(a9))|0;
    }
  

    function dynCall_viiii(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
      FUNCTION_TABLE_viiii[index&511](a1|0,a2|0,a3|0,a4|0);
    }
  

    function dynCall_viiiii(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0;
      FUNCTION_TABLE_viiiii[index&255](a1|0,a2|0,a3|0,a4|0,a5|0);
    }
  

    function dynCall_iifffi(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4); a5=a5|0;
      return FUNCTION_TABLE_iifffi[index&1](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4),a5|0)|0;
    }
  

    function dynCall_vif(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2);
      FUNCTION_TABLE_vif[index&255](a1|0,Math_fround(a2));
    }
  

    function dynCall_vid(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=+a2;
      FUNCTION_TABLE_vid[index&3](a1|0,+a2);
    }
  

    function dynCall_iiidi(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=+a3; a4=a4|0;
      return FUNCTION_TABLE_iiidi[index&1](a1|0,a2|0,+a3,a4|0)|0;
    }
  

    function dynCall_viiidii(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=+a4; a5=a5|0; a6=a6|0;
      FUNCTION_TABLE_viiidii[index&1](a1|0,a2|0,a3|0,+a4,a5|0,a6|0);
    }
  

    function dynCall_vii(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=a2|0;
      FUNCTION_TABLE_vii[index&4095](a1|0,a2|0);
    }
  

    function dynCall_iiffff(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5);
      return FUNCTION_TABLE_iiffff[index&1](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4),Math_fround(a5))|0;
    }
  

    function dynCall_viiiif(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5);
      FUNCTION_TABLE_viiiif[index&3](a1|0,a2|0,a3|0,a4|0,Math_fround(a5));
    }
  

    function dynCall_viifii(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=a4|0; a5=a5|0;
      FUNCTION_TABLE_viifii[index&3](a1|0,a2|0,Math_fround(a3),a4|0,a5|0);
    }
  

    function dynCall_fi(index,a1) {
      index = index|0;
      a1=a1|0;
      return Math_fround(FUNCTION_TABLE_fi[index&255](a1|0));
    }
  

    function dynCall_viidi(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=+a3; a4=a4|0;
      FUNCTION_TABLE_viidi[index&1](a1|0,a2|0,+a3,a4|0);
    }
  

    function dynCall_viifif(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=a4|0; a5=Math_fround(a5);
      FUNCTION_TABLE_viifif[index&1](a1|0,a2|0,Math_fround(a3),a4|0,Math_fround(a5));
    }
  

    function dynCall_vf(index,a1) {
      index = index|0;
      a1=Math_fround(a1);
      FUNCTION_TABLE_vf[index&3](Math_fround(a1));
    }
  

    function dynCall_fiiiiiiiifiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=Math_fround(a9); a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=Math_fround(a14);
      return Math_fround(FUNCTION_TABLE_fiiiiiiiifiiiif[index&15](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,Math_fround(a9),a10|0,a11|0,a12|0,a13|0,Math_fround(a14)));
    }
  

    function dynCall_vi(index,a1) {
      index = index|0;
      a1=a1|0;
      FUNCTION_TABLE_vi[index&4095](a1|0);
    }
  

    function dynCall_vifiii(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0; a4=a4|0; a5=a5|0;
      FUNCTION_TABLE_vifiii[index&3](a1|0,Math_fround(a2),a3|0,a4|0,a5|0);
    }
  

    function dynCall_iiiiiiifiiiiiiiiiffffi(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=Math_fround(a7); a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0; a16=a16|0; a17=Math_fround(a17); a18=Math_fround(a18); a19=Math_fround(a19); a20=Math_fround(a20); a21=a21|0;
      return FUNCTION_TABLE_iiiiiiifiiiiiiiiiffffi[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,Math_fround(a7),a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0,a16|0,Math_fround(a17),Math_fround(a18),Math_fround(a19),Math_fround(a20),a21|0)|0;
    }
  

    function dynCall_diiii(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
      return +FUNCTION_TABLE_diiii[index&1](a1|0,a2|0,a3|0,a4|0);
    }
  

    function dynCall_iiifiiii(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0;
      return FUNCTION_TABLE_iiifiiii[index&1](a1|0,a2|0,Math_fround(a3),a4|0,a5|0,a6|0,a7|0)|0;
    }
  

    function dynCall_viiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0;
      FUNCTION_TABLE_viiiiiiiiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0);
    }
  

    function dynCall_iiiiiiiiiiffffii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=Math_fround(a10); a11=Math_fround(a11); a12=Math_fround(a12); a13=Math_fround(a13); a14=a14|0; a15=a15|0;
      return FUNCTION_TABLE_iiiiiiiiiiffffii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,Math_fround(a10),Math_fround(a11),Math_fround(a12),Math_fround(a13),a14|0,a15|0)|0;
    }
  

    function dynCall_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0;
      FUNCTION_TABLE_viiiiiiii[index&63](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0);
    }
  

    function dynCall_iid(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=+a2;
      return FUNCTION_TABLE_iid[index&31](a1|0,+a2)|0;
    }
  

    function dynCall_iif(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2);
      return FUNCTION_TABLE_iif[index&31](a1|0,Math_fround(a2))|0;
    }
  

    function dynCall_vifiiii(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0;
      FUNCTION_TABLE_vifiiii[index&3](a1|0,Math_fround(a2),a3|0,a4|0,a5|0,a6|0);
    }
  

    function dynCall_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0;
      FUNCTION_TABLE_viiiiiii[index&127](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0);
    }
  

    function dynCall_vifiiiiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0; a16=a16|0; a17=a17|0; a18=a18|0; a19=a19|0; a20=a20|0;
      FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiii[index&7](a1|0,Math_fround(a2),a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0,a16|0,a17|0,a18|0,a19|0,a20|0);
    }
  

    function dynCall_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0;
      FUNCTION_TABLE_viiiiiiiii[index&31](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0);
    }
  

    function dynCall_viiiiiif(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=Math_fround(a7);
      FUNCTION_TABLE_viiiiiif[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,Math_fround(a7));
    }
  

    function dynCall_iii(index,a1,a2) {
      index = index|0;
      a1=a1|0; a2=a2|0;
      return FUNCTION_TABLE_iii[index&4095](a1|0,a2|0)|0;
    }
  

    function dynCall_iiiifii(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=a5|0; a6=a6|0;
      return FUNCTION_TABLE_iiiifii[index&1](a1|0,a2|0,a3|0,Math_fround(a4),a5|0,a6|0)|0;
    }
  

    function dynCall_f(index) {
      index = index|0;
      
      return Math_fround(FUNCTION_TABLE_f[index&3]());
    }
  

    function dynCall_vffff(index,a1,a2,a3,a4) {
      index = index|0;
      a1=Math_fround(a1); a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4);
      FUNCTION_TABLE_vffff[index&7](Math_fround(a1),Math_fround(a2),Math_fround(a3),Math_fround(a4));
    }
  

    function dynCall_vifffi(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4); a5=a5|0;
      FUNCTION_TABLE_vifffi[index&3](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4),a5|0);
    }
  

    function dynCall_viiiifiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=Math_fround(a11);
      FUNCTION_TABLE_viiiifiiiiif[index&1](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),a6|0,a7|0,a8|0,a9|0,a10|0,Math_fround(a11));
    }
  

    function dynCall_viii(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0;
      FUNCTION_TABLE_viii[index&4095](a1|0,a2|0,a3|0);
    }
  

    function dynCall_viiiifi(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=a6|0;
      FUNCTION_TABLE_viiiifi[index&1](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),a6|0);
    }
  

    function dynCall_v(index) {
      index = index|0;
      
      FUNCTION_TABLE_v[index&1023]();
    }
  

    function dynCall_viid(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=+a3;
      FUNCTION_TABLE_viid[index&7](a1|0,a2|0,+a3);
    }
  

    function dynCall_viiiiff(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=Math_fround(a6);
      FUNCTION_TABLE_viiiiff[index&3](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),Math_fround(a6));
    }
  

    function dynCall_viif(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3);
      FUNCTION_TABLE_viif[index&63](a1|0,a2|0,Math_fround(a3));
    }
  

    function dynCall_fiffif(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=a4|0; a5=Math_fround(a5);
      return Math_fround(FUNCTION_TABLE_fiffif[index&1](a1|0,Math_fround(a2),Math_fround(a3),a4|0,Math_fround(a5)));
    }
  

    function dynCall_iiiifi(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=a5|0;
      return FUNCTION_TABLE_iiiifi[index&3](a1|0,a2|0,a3|0,Math_fround(a4),a5|0)|0;
    }
  

    function dynCall_vd(index,a1) {
      index = index|0;
      a1=+a1;
      FUNCTION_TABLE_vd[index&1](+a1);
    }
  

    function dynCall_iiffffff(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5); a6=Math_fround(a6); a7=Math_fround(a7);
      return FUNCTION_TABLE_iiffffff[index&1](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4),Math_fround(a5),Math_fround(a6),Math_fround(a7))|0;
    }
  

    function dynCall_viiiiiiiifiiifiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=Math_fround(a9); a10=a10|0; a11=a11|0; a12=a12|0; a13=Math_fround(a13); a14=a14|0; a15=a15|0; a16=a16|0;
      FUNCTION_TABLE_viiiiiiiifiiifiii[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,Math_fround(a9),a10|0,a11|0,a12|0,Math_fround(a13),a14|0,a15|0,a16|0);
    }
  

    function dynCall_fiiff(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=Math_fround(a4);
      return Math_fround(FUNCTION_TABLE_fiiff[index&1](a1|0,a2|0,Math_fround(a3),Math_fround(a4)));
    }
  

    function dynCall_viiifffii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=Math_fround(a5); a6=Math_fround(a6); a7=a7|0; a8=a8|0;
      FUNCTION_TABLE_viiifffii[index&1](a1|0,a2|0,a3|0,Math_fround(a4),Math_fround(a5),Math_fround(a6),a7|0,a8|0);
    }
  

    function dynCall_iiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0;
      return FUNCTION_TABLE_iiiiiiiiiii[index&7](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0)|0;
    }
  

    function dynCall_ii(index,a1) {
      index = index|0;
      a1=a1|0;
      return FUNCTION_TABLE_ii[index&4095](a1|0)|0;
    }
  

    function dynCall_iiff(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3);
      return FUNCTION_TABLE_iiff[index&1](a1|0,Math_fround(a2),Math_fround(a3))|0;
    }
  

    function dynCall_viifi(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=a4|0;
      FUNCTION_TABLE_viifi[index&7](a1|0,a2|0,Math_fround(a3),a4|0);
    }
  

    function dynCall_iiiiifiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0;
      return FUNCTION_TABLE_iiiiifiiiiii[index&7](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),a6|0,a7|0,a8|0,a9|0,a10|0,a11|0)|0;
    }
  

    function dynCall_iiiiifiiiiif(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=Math_fround(a5); a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=Math_fround(a11);
      return FUNCTION_TABLE_iiiiifiiiiif[index&1](a1|0,a2|0,a3|0,a4|0,Math_fround(a5),a6|0,a7|0,a8|0,a9|0,a10|0,Math_fround(a11))|0;
    }
  

    function dynCall_viiff(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=Math_fround(a4);
      FUNCTION_TABLE_viiff[index&3](a1|0,a2|0,Math_fround(a3),Math_fround(a4));
    }
  

    function dynCall_viiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0;
      FUNCTION_TABLE_viiiiiiiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0);
    }
  

    function dynCall_iifi(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0;
      return FUNCTION_TABLE_iifi[index&7](a1|0,Math_fround(a2),a3|0)|0;
    }
  

    function dynCall_viiif(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4);
      FUNCTION_TABLE_viiif[index&15](a1|0,a2|0,a3|0,Math_fround(a4));
    }
  

    function dynCall_viiiiifiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=Math_fround(a6); a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0;
      FUNCTION_TABLE_viiiiifiiii[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,Math_fround(a6),a7|0,a8|0,a9|0,a10|0);
    }
  

    function dynCall_viiiffii(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=Math_fround(a5); a6=a6|0; a7=a7|0;
      FUNCTION_TABLE_viiiffii[index&3](a1|0,a2|0,a3|0,Math_fround(a4),Math_fround(a5),a6|0,a7|0);
    }
  

    function dynCall_vifiiiiiiiiiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21,a22,a23,a24,a25) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0; a16=a16|0; a17=a17|0; a18=a18|0; a19=a19|0; a20=a20|0; a21=a21|0; a22=a22|0; a23=a23|0; a24=a24|0; a25=a25|0;
      FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiiiiiiii[index&1](a1|0,Math_fround(a2),a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0,a16|0,a17|0,a18|0,a19|0,a20|0,a21|0,a22|0,a23|0,a24|0,a25|0);
    }
  

    function dynCall_iifiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0;
      return FUNCTION_TABLE_iifiiiii[index&1](a1|0,Math_fround(a2),a3|0,a4|0,a5|0,a6|0,a7|0)|0;
    }
  

    function dynCall_iiifi(index,a1,a2,a3,a4) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=a4|0;
      return FUNCTION_TABLE_iiifi[index&7](a1|0,a2|0,Math_fround(a3),a4|0)|0;
    }
  

    function dynCall_iiii(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0;
      return FUNCTION_TABLE_iiii[index&2047](a1|0,a2|0,a3|0)|0;
    }
  

    function dynCall_viifff(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5);
      FUNCTION_TABLE_viifff[index&3](a1|0,a2|0,Math_fround(a3),Math_fround(a4),Math_fround(a5));
    }
  

    function dynCall_viiffi(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=Math_fround(a4); a5=a5|0;
      FUNCTION_TABLE_viiffi[index&3](a1|0,a2|0,Math_fround(a3),Math_fround(a4),a5|0);
    }
  

    function dynCall_iiif(index,a1,a2,a3) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3);
      return FUNCTION_TABLE_iiif[index&3](a1|0,a2|0,Math_fround(a3))|0;
    }
  

    function dynCall_viiiiiid(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=+a7;
      FUNCTION_TABLE_viiiiiid[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,+a7);
    }
  

    function dynCall_viiifi(index,a1,a2,a3,a4,a5) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=a5|0;
      FUNCTION_TABLE_viiifi[index&7](a1|0,a2|0,a3|0,Math_fround(a4),a5|0);
    }
  

    function dynCall_viffffff(index,a1,a2,a3,a4,a5,a6,a7) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5); a6=Math_fround(a6); a7=Math_fround(a7);
      FUNCTION_TABLE_viffffff[index&1](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4),Math_fround(a5),Math_fround(a6),Math_fround(a7));
    }
  

    function dynCall_iiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0;
      return FUNCTION_TABLE_iiiiiiiiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0)|0;
    }
  

    function dynCall_iiiifiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0;
      return FUNCTION_TABLE_iiiifiiiii[index&1](a1|0,a2|0,a3|0,Math_fround(a4),a5|0,a6|0,a7|0,a8|0,a9|0)|0;
    }
  

    function dynCall_iiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0;
      return FUNCTION_TABLE_iiiiiiiiiiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0)|0;
    }
  

    function dynCall_viiiiiiiiiiiiiiiiiiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18,a19,a20,a21,a22,a23,a24,a25,a26,a27,a28,a29) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0; a16=a16|0; a17=a17|0; a18=a18|0; a19=a19|0; a20=a20|0; a21=a21|0; a22=a22|0; a23=a23|0; a24=a24|0; a25=a25|0; a26=a26|0; a27=a27|0; a28=a28|0; a29=a29|0;
      FUNCTION_TABLE_viiiiiiiiiiiiiiiiiiiiiiiiiiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0,a16|0,a17|0,a18|0,a19|0,a20|0,a21|0,a22|0,a23|0,a24|0,a25|0,a26|0,a27|0,a28|0,a29|0);
    }
  

    function dynCall_viffffffffffffiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5); a6=Math_fround(a6); a7=Math_fround(a7); a8=Math_fround(a8); a9=Math_fround(a9); a10=Math_fround(a10); a11=Math_fround(a11); a12=Math_fround(a12); a13=Math_fround(a13); a14=a14|0; a15=a15|0; a16=a16|0; a17=a17|0;
      FUNCTION_TABLE_viffffffffffffiiii[index&1](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4),Math_fround(a5),Math_fround(a6),Math_fround(a7),Math_fround(a8),Math_fround(a9),Math_fround(a10),Math_fround(a11),Math_fround(a12),Math_fround(a13),a14|0,a15|0,a16|0,a17|0);
    }
  

    function dynCall_vfi(index,a1,a2) {
      index = index|0;
      a1=Math_fround(a1); a2=a2|0;
      FUNCTION_TABLE_vfi[index&1](Math_fround(a1),a2|0);
    }
  

    function dynCall_i(index) {
      index = index|0;
      
      return FUNCTION_TABLE_i[index&255]()|0;
    }
  

    function dynCall_vff(index,a1,a2) {
      index = index|0;
      a1=Math_fround(a1); a2=Math_fround(a2);
      FUNCTION_TABLE_vff[index&3](Math_fround(a1),Math_fround(a2));
    }
  

    function dynCall_viiifiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=Math_fround(a4); a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0; a9=a9|0;
      FUNCTION_TABLE_viiifiiiii[index&1](a1|0,a2|0,a3|0,Math_fround(a4),a5|0,a6|0,a7|0,a8|0,a9|0);
    }
  

    function dynCall_iiiiiifiiiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12,a13,a14,a15,a16,a17,a18) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=Math_fround(a6); a7=a7|0; a8=a8|0; a9=a9|0; a10=a10|0; a11=a11|0; a12=a12|0; a13=a13|0; a14=a14|0; a15=a15|0; a16=a16|0; a17=a17|0; a18=a18|0;
      return FUNCTION_TABLE_iiiiiifiiiiiiiiiiii[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,Math_fround(a6),a7|0,a8|0,a9|0,a10|0,a11|0,a12|0,a13|0,a14|0,a15|0,a16|0,a17|0,a18|0)|0;
    }
  

    function dynCall_viiffff(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5); a6=Math_fround(a6);
      FUNCTION_TABLE_viiffff[index&1](a1|0,a2|0,Math_fround(a3),Math_fround(a4),Math_fround(a5),Math_fround(a6));
    }
  

    function dynCall_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
      index = index|0;
      a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0; a7=a7|0; a8=a8|0;
      return FUNCTION_TABLE_iiiiiiiii[index&63](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0,a7|0,a8|0)|0;
    }
  

    function dynCall_viffffi(index,a1,a2,a3,a4,a5,a6) {
      index = index|0;
      a1=a1|0; a2=Math_fround(a2); a3=Math_fround(a3); a4=Math_fround(a4); a5=Math_fround(a5); a6=a6|0;
      FUNCTION_TABLE_viffffi[index&3](a1|0,Math_fround(a2),Math_fround(a3),Math_fround(a4),Math_fround(a5),a6|0);
    }
  
function b0(p0,p1,p2) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2); abort(0);return Math_fround(0); }
  function b1(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; abort(1);return 0; }
  function b2(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0;p15 = p15|0;p16 = p16|0;p17 = p17|0;p18 = p18|0;p19 = p19|0;p20 = p20|0; abort(2); }
  function b3(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0; abort(3); }
  function b4(p0,p1) { p0 = Math_fround(p0);p1 = Math_fround(p1); abort(4);return Math_fround(0); }
  function b5(p0,p1,p2) { p0 = p0|0;p1 = +p1;p2 = p2|0; abort(5);return 0; }
  function b6(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = Math_fround(p6);p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = Math_fround(p13); abort(6);return Math_fround(0); }
  function b7(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = p5|0;p6 = p6|0;p7 = Math_fround(p7); abort(7);return 0; }
  function b8(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = Math_fround(p5);p6 = Math_fround(p6);p7 = p7|0; abort(8); }
  function b9(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0; abort(9);return 0; }
  function b10(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = p3|0;p4 = Math_fround(p4);p5 = Math_fround(p5);p6 = Math_fround(p6); abort(10);return Math_fround(0); }
  function b11(p0,p1) { p0 = p0|0;p1 = Math_fround(p1); abort(11);return Math_fround(0); }
  function b12(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0; abort(12); }
  function b13(p0,p1) { p0 = p0|0;p1 = +p1; abort(13);return Math_fround(0); }
  function b14(p0,p1) { p0 = p0|0;p1 = p1|0; abort(14);return Math_fround(0); }
  function b15(p0,p1,p2) { p0 = +p0;p1 = p1|0;p2 = p2|0; abort(15);return +0; }
  function b16(p0) { p0 = p0|0; abort(16);return +0; }
  function b17(p0) { p0 = +p0; abort(17);return +0; }
  function b18(p0,p1,p2) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2); abort(18); }
  function _emscripten_glUniform2f__wrapper(p0,p1,p2) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2); _emscripten_glUniform2f(p0|0,+p1,+p2); }
  function _emscripten_glVertexAttrib2f__wrapper(p0,p1,p2) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2); _emscripten_glVertexAttrib2f(p0|0,+p1,+p2); }
  function b19(p0,p1,p2) { p0 = Math_fround(p0);p1 = Math_fround(p1);p2 = p2|0; abort(19); }
  function b20(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = p5|0;p6 = p6|0;p7 = p7|0; abort(20); }
  function b21(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4); abort(21); }
  function _glVertexAttrib4f__wrapper(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4); _glVertexAttrib4f(p0|0,+p1,+p2,+p3,+p4); }
  function _emscripten_glUniform4f__wrapper(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4); _emscripten_glUniform4f(p0|0,+p1,+p2,+p3,+p4); }
  function _emscripten_glVertexAttrib4f__wrapper(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4); _emscripten_glVertexAttrib4f(p0|0,+p1,+p2,+p3,+p4); }
  function b22() { ; abort(22);return +0; }
  function _emscripten_get_now__wrapper() { ; return +_emscripten_get_now(); }
  function b23(p0,p1,p2) { p0 = p0|0;p1 = +p1;p2 = +p2; abort(23);return +0; }
  function b24(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = Math_fround(p5);p6 = Math_fround(p6);p7 = Math_fround(p7);p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0; abort(24); }
  function b25(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = Math_fround(p5);p6 = Math_fround(p6);p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0; abort(25);return 0; }
  function b26(p0,p1) { p0 = p0|0;p1 = p1|0; abort(26);return +0; }
  function b27(p0,p1) { p0 = p0|0;p1 = +p1; abort(27);return +0; }
  function b28(p0,p1) { p0 = p0|0;p1 = Math_fround(p1); abort(28);return +0; }
  function b29(p0,p1,p2,p3) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0;p3 = p3|0; abort(29);return 0; }
  function b30(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; abort(30);return 0; }
  function b31(p0,p1,p2,p3,p4,p5) { p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3;p4 = +p4;p5 = +p5; abort(31); }
  function _emscripten_glFrustum__wrapper(p0,p1,p2,p3,p4,p5) { p0 = +p0;p1 = +p1;p2 = +p2;p3 = +p3;p4 = +p4;p5 = +p5; _emscripten_glFrustum(+p0,+p1,+p2,+p3,+p4,+p5); }
  function b32(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = p3|0;p4 = Math_fround(p4);p5 = Math_fround(p5); abort(32);return Math_fround(0); }
  function b33(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = Math_fround(p11);p12 = Math_fround(p12);p13 = Math_fround(p13);p14 = Math_fround(p14);p15 = p15|0;p16 = p16|0; abort(33);return 0; }
  function b34(p0,p1) { p0 = +p0;p1 = +p1; abort(34); }
  function _emscripten_glDepthRange__wrapper(p0,p1) { p0 = +p0;p1 = +p1; _emscripten_glDepthRange(+p0,+p1); }
  function b35(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; abort(35); }
  function b36(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3); abort(36);return 0; }
  function b37(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; abort(37);return 0; }
  function b38(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = Math_fround(p5);p6 = Math_fround(p6);p7 = Math_fround(p7);p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0; abort(38);return 0; }
  function b39(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0; abort(39); }
  function b40(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; abort(40);return 0; }
  function _catgets__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; return _catgets(p0|0,p1|0,p2|0,p3|0)|0; }
  function b41(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = p3|0;p4 = p4|0; abort(41);return 0; }
  function b42(p0,p1,p2,p3) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); abort(42);return Math_fround(0); }
  function b43(p0,p1,p2,p3) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = p3|0; abort(43); }
  function b44(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = +p5; abort(44); }
  function b45(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; abort(45);return 0; }
  function b46(p0,p1,p2) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0; abort(46); }
  function b47(p0,p1,p2,p3) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); abort(47); }
  function _emscripten_glUniform3f__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); _emscripten_glUniform3f(p0|0,+p1,+p2,+p3); }
  function _emscripten_glVertexAttrib3f__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); _emscripten_glVertexAttrib3f(p0|0,+p1,+p2,+p3); }
  function b48(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; abort(48); }
  function _glVertexAttribPointer__wrapper(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; _glVertexAttribPointer(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0); }
  function _emscripten_glDrawRangeElements__wrapper(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; _emscripten_glDrawRangeElements(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0); }
  function _emscripten_glVertexAttribPointer__wrapper(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; _emscripten_glVertexAttribPointer(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0); }
  function b49(p0,p1) { p0 = +p0;p1 = +p1; abort(49);return +0; }
  function _fmod__wrapper(p0,p1) { p0 = +p0;p1 = +p1; return +_fmod(+p0,+p1); }
  function b50(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(50);return Math_fround(0); }
  function b51(p0,p1,p2,p3) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); abort(51);return 0; }
  function b52(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2); abort(52);return Math_fround(0); }
  function b53(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = Math_fround(p5);p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0;p15 = Math_fround(p15);p16 = Math_fround(p16);p17 = Math_fround(p17);p18 = Math_fround(p18);p19 = p19|0; abort(53);return 0; }
  function b54(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = Math_fround(p9); abort(54);return 0; }
  function b55(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4);p5 = Math_fround(p5);p6 = Math_fround(p6);p7 = Math_fround(p7); abort(55); }
  function b56(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0; abort(56); }
  function b57(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(57);return +0; }
  function b58(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; abort(58);return Math_fround(0); }
  function b59(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; abort(59);return 0; }
  function b60(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = Math_fround(p5);p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0;p15 = p15|0;p16 = p16|0;p17 = p17|0;p18 = p18|0; abort(60); }
  function b61(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = Math_fround(p4); abort(61); }
  function b62(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = Math_fround(p5);p6 = p6|0;p7 = p7|0;p8 = Math_fround(p8); abort(62);return 0; }
  function b63(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; abort(63); }
  function _glBlendFuncSeparate__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glBlendFuncSeparate(p0|0,p1|0,p2|0,p3|0); }
  function _glBufferData__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glBufferData(p0|0,p1|0,p2|0,p3|0); }
  function _glBufferSubData__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glBufferSubData(p0|0,p1|0,p2|0,p3|0); }
  function _glColorMask__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glColorMask(p0|0,p1|0,p2|0,p3|0); }
  function _glDrawElements__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glDrawElements(p0|0,p1|0,p2|0,p3|0); }
  function _glFramebufferRenderbuffer__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glFramebufferRenderbuffer(p0|0,p1|0,p2|0,p3|0); }
  function _glGetFramebufferAttachmentParameteriv__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glGetFramebufferAttachmentParameteriv(p0|0,p1|0,p2|0,p3|0); }
  function _glGetProgramInfoLog__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glGetProgramInfoLog(p0|0,p1|0,p2|0,p3|0); }
  function _glGetShaderInfoLog__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glGetShaderInfoLog(p0|0,p1|0,p2|0,p3|0); }
  function _glRenderbufferStorage__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glRenderbufferStorage(p0|0,p1|0,p2|0,p3|0); }
  function _glScissor__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glScissor(p0|0,p1|0,p2|0,p3|0); }
  function _glShaderSource__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glShaderSource(p0|0,p1|0,p2|0,p3|0); }
  function _glStencilFuncSeparate__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glStencilFuncSeparate(p0|0,p1|0,p2|0,p3|0); }
  function _glStencilOpSeparate__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glStencilOpSeparate(p0|0,p1|0,p2|0,p3|0); }
  function _glUniformMatrix3fv__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glUniformMatrix3fv(p0|0,p1|0,p2|0,p3|0); }
  function _glUniformMatrix4fv__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glUniformMatrix4fv(p0|0,p1|0,p2|0,p3|0); }
  function _glViewport__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _glViewport(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glBufferData__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glBufferData(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glBufferSubData__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glBufferSubData(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glUniform3i__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glUniform3i(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glUniformMatrix2fv__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glUniformMatrix2fv(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glUniformMatrix3fv__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glUniformMatrix3fv(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glUniformMatrix4fv__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glUniformMatrix4fv(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glGetAttachedShaders__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetAttachedShaders(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glShaderSource__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glShaderSource(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glGetShaderSource__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetShaderSource(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glGetShaderInfoLog__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetShaderInfoLog(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glGetShaderPrecisionFormat__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetShaderPrecisionFormat(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glGetProgramInfoLog__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetProgramInfoLog(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glFramebufferRenderbuffer__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glFramebufferRenderbuffer(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glGetFramebufferAttachmentParameteriv__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetFramebufferAttachmentParameteriv(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glGetInfoLogARB__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glGetInfoLogARB(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glVertexPointer__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glVertexPointer(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glTexCoordPointer__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glTexCoordPointer(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glColorPointer__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glColorPointer(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glDrawElements__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glDrawElements(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glDrawArraysInstanced__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glDrawArraysInstanced(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glViewport__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glViewport(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glScissor__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glScissor(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glColorMask__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glColorMask(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glRenderbufferStorage__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glRenderbufferStorage(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glBlendFuncSeparate__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glBlendFuncSeparate(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glStencilFuncSeparate__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glStencilFuncSeparate(p0|0,p1|0,p2|0,p3|0); }
  function _emscripten_glStencilOpSeparate__wrapper(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; _emscripten_glStencilOpSeparate(p0|0,p1|0,p2|0,p3|0); }
  function b64(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; abort(64); }
  function _glFramebufferTexture2D__wrapper(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _glFramebufferTexture2D(p0|0,p1|0,p2|0,p3|0,p4|0); }
  function _emscripten_glUniform4i__wrapper(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _emscripten_glUniform4i(p0|0,p1|0,p2|0,p3|0,p4|0); }
  function _emscripten_glFramebufferTexture2D__wrapper(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _emscripten_glFramebufferTexture2D(p0|0,p1|0,p2|0,p3|0,p4|0); }
  function _emscripten_glShaderBinary__wrapper(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _emscripten_glShaderBinary(p0|0,p1|0,p2|0,p3|0,p4|0); }
  function _emscripten_glDrawElementsInstanced__wrapper(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; _emscripten_glDrawElementsInstanced(p0|0,p1|0,p2|0,p3|0,p4|0); }
  function b65(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = p4|0; abort(65);return 0; }
  function b66(p0,p1) { p0 = p0|0;p1 = Math_fround(p1); abort(66); }
  function _emscripten_glUniform1f__wrapper(p0,p1) { p0 = p0|0;p1 = Math_fround(p1); _emscripten_glUniform1f(p0|0,+p1); }
  function _emscripten_glVertexAttrib1f__wrapper(p0,p1) { p0 = p0|0;p1 = Math_fround(p1); _emscripten_glVertexAttrib1f(p0|0,+p1); }
  function b67(p0,p1) { p0 = p0|0;p1 = +p1; abort(67); }
  function b68(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = +p2;p3 = p3|0; abort(68);return 0; }
  function b69(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = +p3;p4 = p4|0;p5 = p5|0; abort(69); }
  function b70(p0,p1) { p0 = p0|0;p1 = p1|0; abort(70); }
  function _emscripten_longjmp__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_longjmp(p0|0,p1|0); }
  function _JS_Log_Dump__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _JS_Log_Dump(p0|0,p1|0); }
  function _JS_Cursor_SetImage__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _JS_Cursor_SetImage(p0|0,p1|0); }
  function _glAttachShader__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glAttachShader(p0|0,p1|0); }
  function _glBindBuffer__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glBindBuffer(p0|0,p1|0); }
  function _glBindFramebuffer__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glBindFramebuffer(p0|0,p1|0); }
  function _glBindRenderbuffer__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glBindRenderbuffer(p0|0,p1|0); }
  function _glBindTexture__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glBindTexture(p0|0,p1|0); }
  function _glBlendEquationSeparate__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glBlendEquationSeparate(p0|0,p1|0); }
  function _glDeleteBuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glDeleteBuffers(p0|0,p1|0); }
  function _glDeleteFramebuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glDeleteFramebuffers(p0|0,p1|0); }
  function _glDeleteRenderbuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glDeleteRenderbuffers(p0|0,p1|0); }
  function _glDeleteTextures__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glDeleteTextures(p0|0,p1|0); }
  function _glGenBuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glGenBuffers(p0|0,p1|0); }
  function _glGenFramebuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glGenFramebuffers(p0|0,p1|0); }
  function _glGenRenderbuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glGenRenderbuffers(p0|0,p1|0); }
  function _glGenTextures__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glGenTextures(p0|0,p1|0); }
  function _glGetIntegerv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glGetIntegerv(p0|0,p1|0); }
  function _glPixelStorei__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glPixelStorei(p0|0,p1|0); }
  function _glUniform1i__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _glUniform1i(p0|0,p1|0); }
  function _emscripten_glPixelStorei__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glPixelStorei(p0|0,p1|0); }
  function _emscripten_glGetIntegerv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGetIntegerv(p0|0,p1|0); }
  function _emscripten_glGetFloatv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGetFloatv(p0|0,p1|0); }
  function _emscripten_glGetBooleanv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGetBooleanv(p0|0,p1|0); }
  function _emscripten_glGenTextures__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGenTextures(p0|0,p1|0); }
  function _emscripten_glDeleteTextures__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glDeleteTextures(p0|0,p1|0); }
  function _emscripten_glBindTexture__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glBindTexture(p0|0,p1|0); }
  function _emscripten_glGenBuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGenBuffers(p0|0,p1|0); }
  function _emscripten_glDeleteBuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glDeleteBuffers(p0|0,p1|0); }
  function _emscripten_glGenRenderbuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGenRenderbuffers(p0|0,p1|0); }
  function _emscripten_glDeleteRenderbuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glDeleteRenderbuffers(p0|0,p1|0); }
  function _emscripten_glBindRenderbuffer__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glBindRenderbuffer(p0|0,p1|0); }
  function _emscripten_glUniform1i__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glUniform1i(p0|0,p1|0); }
  function _emscripten_glBindBuffer__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glBindBuffer(p0|0,p1|0); }
  function _emscripten_glVertexAttrib1fv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttrib1fv(p0|0,p1|0); }
  function _emscripten_glVertexAttrib2fv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttrib2fv(p0|0,p1|0); }
  function _emscripten_glVertexAttrib3fv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttrib3fv(p0|0,p1|0); }
  function _emscripten_glVertexAttrib4fv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttrib4fv(p0|0,p1|0); }
  function _emscripten_glAttachShader__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glAttachShader(p0|0,p1|0); }
  function _emscripten_glDetachShader__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glDetachShader(p0|0,p1|0); }
  function _emscripten_glBindFramebuffer__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glBindFramebuffer(p0|0,p1|0); }
  function _emscripten_glGenFramebuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGenFramebuffers(p0|0,p1|0); }
  function _emscripten_glDeleteFramebuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glDeleteFramebuffers(p0|0,p1|0); }
  function _emscripten_glBindProgramARB__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glBindProgramARB(p0|0,p1|0); }
  function _emscripten_glGetPointerv__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGetPointerv(p0|0,p1|0); }
  function _emscripten_glGenVertexArrays__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glGenVertexArrays(p0|0,p1|0); }
  function _emscripten_glDeleteVertexArrays__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glDeleteVertexArrays(p0|0,p1|0); }
  function _emscripten_glVertexAttribDivisor__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glVertexAttribDivisor(p0|0,p1|0); }
  function _emscripten_glBlendFunc__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glBlendFunc(p0|0,p1|0); }
  function _emscripten_glBlendEquationSeparate__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glBlendEquationSeparate(p0|0,p1|0); }
  function _emscripten_glStencilMaskSeparate__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glStencilMaskSeparate(p0|0,p1|0); }
  function _emscripten_glHint__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glHint(p0|0,p1|0); }
  function _emscripten_glDrawBuffers__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; _emscripten_glDrawBuffers(p0|0,p1|0); }
  function b71(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4); abort(71);return 0; }
  function b72(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4); abort(72); }
  function b73(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = p3|0;p4 = p4|0; abort(73); }
  function b74(p0) { p0 = p0|0; abort(74);return Math_fround(0); }
  function b75(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = +p2;p3 = p3|0; abort(75); }
  function b76(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = p3|0;p4 = Math_fround(p4); abort(76); }
  function b77(p0) { p0 = Math_fround(p0); abort(77); }
  function _glClearDepthf__wrapper(p0) { p0 = Math_fround(p0); _glClearDepthf(+p0); }
  function _emscripten_glClearDepthf__wrapper(p0) { p0 = Math_fround(p0); _emscripten_glClearDepthf(+p0); }
  function _emscripten_glLineWidth__wrapper(p0) { p0 = Math_fround(p0); _emscripten_glLineWidth(+p0); }
  function b78(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = Math_fround(p8);p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = Math_fround(p13); abort(78);return Math_fround(0); }
  function b79(p0) { p0 = p0|0; abort(79); }
  function _JS_Eval_EvalJS__wrapper(p0) { p0 = p0|0; _JS_Eval_EvalJS(p0|0); }
  function _glActiveTexture__wrapper(p0) { p0 = p0|0; _glActiveTexture(p0|0); }
  function _glClear__wrapper(p0) { p0 = p0|0; _glClear(p0|0); }
  function _glClearStencil__wrapper(p0) { p0 = p0|0; _glClearStencil(p0|0); }
  function _glCompileShader__wrapper(p0) { p0 = p0|0; _glCompileShader(p0|0); }
  function _glCullFace__wrapper(p0) { p0 = p0|0; _glCullFace(p0|0); }
  function _glDeleteProgram__wrapper(p0) { p0 = p0|0; _glDeleteProgram(p0|0); }
  function _glDeleteShader__wrapper(p0) { p0 = p0|0; _glDeleteShader(p0|0); }
  function _glDepthFunc__wrapper(p0) { p0 = p0|0; _glDepthFunc(p0|0); }
  function _glDepthMask__wrapper(p0) { p0 = p0|0; _glDepthMask(p0|0); }
  function _glDisable__wrapper(p0) { p0 = p0|0; _glDisable(p0|0); }
  function _glDisableVertexAttribArray__wrapper(p0) { p0 = p0|0; _glDisableVertexAttribArray(p0|0); }
  function _glEnable__wrapper(p0) { p0 = p0|0; _glEnable(p0|0); }
  function _glEnableVertexAttribArray__wrapper(p0) { p0 = p0|0; _glEnableVertexAttribArray(p0|0); }
  function _glFrontFace__wrapper(p0) { p0 = p0|0; _glFrontFace(p0|0); }
  function _glGenerateMipmap__wrapper(p0) { p0 = p0|0; _glGenerateMipmap(p0|0); }
  function _glLinkProgram__wrapper(p0) { p0 = p0|0; _glLinkProgram(p0|0); }
  function _glStencilMask__wrapper(p0) { p0 = p0|0; _glStencilMask(p0|0); }
  function _glUseProgram__wrapper(p0) { p0 = p0|0; _glUseProgram(p0|0); }
  function _freelocale__wrapper(p0) { p0 = p0|0; _freelocale(p0|0); }
  function _emscripten_glDeleteShader__wrapper(p0) { p0 = p0|0; _emscripten_glDeleteShader(p0|0); }
  function _emscripten_glCompileShader__wrapper(p0) { p0 = p0|0; _emscripten_glCompileShader(p0|0); }
  function _emscripten_glDeleteProgram__wrapper(p0) { p0 = p0|0; _emscripten_glDeleteProgram(p0|0); }
  function _emscripten_glLinkProgram__wrapper(p0) { p0 = p0|0; _emscripten_glLinkProgram(p0|0); }
  function _emscripten_glUseProgram__wrapper(p0) { p0 = p0|0; _emscripten_glUseProgram(p0|0); }
  function _emscripten_glValidateProgram__wrapper(p0) { p0 = p0|0; _emscripten_glValidateProgram(p0|0); }
  function _emscripten_glDeleteObjectARB__wrapper(p0) { p0 = p0|0; _emscripten_glDeleteObjectARB(p0|0); }
  function _emscripten_glEnableClientState__wrapper(p0) { p0 = p0|0; _emscripten_glEnableClientState(p0|0); }
  function _emscripten_glClientActiveTexture__wrapper(p0) { p0 = p0|0; _emscripten_glClientActiveTexture(p0|0); }
  function _emscripten_glBindVertexArray__wrapper(p0) { p0 = p0|0; _emscripten_glBindVertexArray(p0|0); }
  function _emscripten_glMatrixMode__wrapper(p0) { p0 = p0|0; _emscripten_glMatrixMode(p0|0); }
  function _emscripten_glLoadMatrixf__wrapper(p0) { p0 = p0|0; _emscripten_glLoadMatrixf(p0|0); }
  function _emscripten_glEnableVertexAttribArray__wrapper(p0) { p0 = p0|0; _emscripten_glEnableVertexAttribArray(p0|0); }
  function _emscripten_glDisableVertexAttribArray__wrapper(p0) { p0 = p0|0; _emscripten_glDisableVertexAttribArray(p0|0); }
  function _emscripten_glDepthFunc__wrapper(p0) { p0 = p0|0; _emscripten_glDepthFunc(p0|0); }
  function _emscripten_glEnable__wrapper(p0) { p0 = p0|0; _emscripten_glEnable(p0|0); }
  function _emscripten_glDisable__wrapper(p0) { p0 = p0|0; _emscripten_glDisable(p0|0); }
  function _emscripten_glFrontFace__wrapper(p0) { p0 = p0|0; _emscripten_glFrontFace(p0|0); }
  function _emscripten_glCullFace__wrapper(p0) { p0 = p0|0; _emscripten_glCullFace(p0|0); }
  function _emscripten_glClear__wrapper(p0) { p0 = p0|0; _emscripten_glClear(p0|0); }
  function _emscripten_glClearStencil__wrapper(p0) { p0 = p0|0; _emscripten_glClearStencil(p0|0); }
  function _emscripten_glDepthMask__wrapper(p0) { p0 = p0|0; _emscripten_glDepthMask(p0|0); }
  function _emscripten_glStencilMask__wrapper(p0) { p0 = p0|0; _emscripten_glStencilMask(p0|0); }
  function _emscripten_glGenerateMipmap__wrapper(p0) { p0 = p0|0; _emscripten_glGenerateMipmap(p0|0); }
  function _emscripten_glActiveTexture__wrapper(p0) { p0 = p0|0; _emscripten_glActiveTexture(p0|0); }
  function _emscripten_glBlendEquation__wrapper(p0) { p0 = p0|0; _emscripten_glBlendEquation(p0|0); }
  function b80(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0;p3 = p3|0;p4 = p4|0; abort(80); }
  function b81(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = Math_fround(p6);p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0;p15 = p15|0;p16 = Math_fround(p16);p17 = Math_fround(p17);p18 = Math_fround(p18);p19 = Math_fround(p19);p20 = p20|0; abort(81);return 0; }
  function b82(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; abort(82);return +0; }
  function b83(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; abort(83);return 0; }
  function b84(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0; abort(84); }
  function b85(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = Math_fround(p9);p10 = Math_fround(p10);p11 = Math_fround(p11);p12 = Math_fround(p12);p13 = p13|0;p14 = p14|0; abort(85);return 0; }
  function b86(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; abort(86); }
  function _glCompressedTexImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; _glCompressedTexImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0); }
  function _glCopyTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; _glCopyTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0); }
  function _emscripten_glCompressedTexImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; _emscripten_glCompressedTexImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0); }
  function _emscripten_glCopyTexImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; _emscripten_glCopyTexImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0); }
  function _emscripten_glCopyTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; _emscripten_glCopyTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0); }
  function b87(p0,p1) { p0 = p0|0;p1 = +p1; abort(87);return 0; }
  function b88(p0,p1) { p0 = p0|0;p1 = Math_fround(p1); abort(88);return 0; }
  function b89(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; abort(89); }
  function b90(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; abort(90); }
  function _glGetActiveAttrib__wrapper(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _glGetActiveAttrib(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0); }
  function _glGetActiveUniform__wrapper(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _glGetActiveUniform(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0); }
  function _glReadPixels__wrapper(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _glReadPixels(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0); }
  function _emscripten_glReadPixels__wrapper(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _emscripten_glReadPixels(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0); }
  function _emscripten_glGetActiveUniform__wrapper(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _emscripten_glGetActiveUniform(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0); }
  function _emscripten_glGetActiveAttrib__wrapper(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; _emscripten_glGetActiveAttrib(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0); }
  function b91(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0;p15 = p15|0;p16 = p16|0;p17 = p17|0;p18 = p18|0;p19 = p19|0; abort(91); }
  function b92(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; abort(92); }
  function _glCompressedTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _glCompressedTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0); }
  function _glTexImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _glTexImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0); }
  function _glTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _glTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0); }
  function _emscripten_glCompressedTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _emscripten_glCompressedTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0); }
  function _emscripten_glTexImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _emscripten_glTexImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0); }
  function _emscripten_glTexSubImage2D__wrapper(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; _emscripten_glTexSubImage2D(p0|0,p1|0,p2|0,p3|0,p4|0,p5|0,p6|0,p7|0,p8|0); }
  function b93(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = Math_fround(p6); abort(93); }
  function b94(p0,p1) { p0 = p0|0;p1 = p1|0; abort(94);return 0; }
  function _flock__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; return _flock(p0|0,p1|0)|0; }
  function _JS_Sound_Create_Channel__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; return _JS_Sound_Create_Channel(p0|0,p1|0)|0; }
  function _JS_SystemInfo_GetDocumentURL__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; return _JS_SystemInfo_GetDocumentURL(p0|0,p1|0)|0; }
  function _glGetAttribLocation__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; return _glGetAttribLocation(p0|0,p1|0)|0; }
  function _glGetUniformLocation__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; return _glGetUniformLocation(p0|0,p1|0)|0; }
  function _emscripten_glGetUniformLocation__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; return _emscripten_glGetUniformLocation(p0|0,p1|0)|0; }
  function _emscripten_glGetAttribLocation__wrapper(p0,p1) { p0 = p0|0;p1 = p1|0; return _emscripten_glGetAttribLocation(p0|0,p1|0)|0; }
  function b95(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = p4|0;p5 = p5|0; abort(95);return 0; }
  function b96() { ; abort(96);return Math_fround(0); }
  function b97(p0,p1,p2,p3) { p0 = Math_fround(p0);p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); abort(97); }
  function _glClearColor__wrapper(p0,p1,p2,p3) { p0 = Math_fround(p0);p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); _glClearColor(+p0,+p1,+p2,+p3); }
  function _emscripten_glRotatef__wrapper(p0,p1,p2,p3) { p0 = Math_fround(p0);p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); _emscripten_glRotatef(+p0,+p1,+p2,+p3); }
  function _emscripten_glClearColor__wrapper(p0,p1,p2,p3) { p0 = Math_fround(p0);p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); _emscripten_glClearColor(+p0,+p1,+p2,+p3); }
  function _emscripten_glBlendColor__wrapper(p0,p1,p2,p3) { p0 = Math_fround(p0);p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3); _emscripten_glBlendColor(+p0,+p1,+p2,+p3); }
  function b98(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = p4|0; abort(98); }
  function b99(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = Math_fround(p10); abort(99); }
  function b100(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(100); }
  function ___cxa_throw__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; ___cxa_throw(p0|0,p1|0,p2|0); }
  function _emscripten_set_main_loop__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_set_main_loop(p0|0,p1|0,p2|0); }
  function _glBindAttribLocation__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glBindAttribLocation(p0|0,p1|0,p2|0); }
  function _glDrawArrays__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glDrawArrays(p0|0,p1|0,p2|0); }
  function _glGetProgramiv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glGetProgramiv(p0|0,p1|0,p2|0); }
  function _glGetShaderiv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glGetShaderiv(p0|0,p1|0,p2|0); }
  function _glGetTexParameteriv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glGetTexParameteriv(p0|0,p1|0,p2|0); }
  function _glGetVertexAttribfv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glGetVertexAttribfv(p0|0,p1|0,p2|0); }
  function _glGetVertexAttribiv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glGetVertexAttribiv(p0|0,p1|0,p2|0); }
  function _glGetVertexAttribPointerv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glGetVertexAttribPointerv(p0|0,p1|0,p2|0); }
  function _glStencilFunc__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glStencilFunc(p0|0,p1|0,p2|0); }
  function _glStencilOp__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glStencilOp(p0|0,p1|0,p2|0); }
  function _glTexParameteri__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glTexParameteri(p0|0,p1|0,p2|0); }
  function _glUniform1fv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glUniform1fv(p0|0,p1|0,p2|0); }
  function _glUniform1iv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glUniform1iv(p0|0,p1|0,p2|0); }
  function _glUniform2fv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glUniform2fv(p0|0,p1|0,p2|0); }
  function _glUniform2iv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glUniform2iv(p0|0,p1|0,p2|0); }
  function _glUniform3fv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glUniform3fv(p0|0,p1|0,p2|0); }
  function _glUniform3iv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glUniform3iv(p0|0,p1|0,p2|0); }
  function _glUniform4fv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glUniform4fv(p0|0,p1|0,p2|0); }
  function _glUniform4iv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _glUniform4iv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetTexParameterfv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetTexParameterfv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetTexParameteriv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetTexParameteriv(p0|0,p1|0,p2|0); }
  function _emscripten_glTexParameterfv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glTexParameterfv(p0|0,p1|0,p2|0); }
  function _emscripten_glTexParameteriv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glTexParameteriv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetBufferParameteriv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetBufferParameteriv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetRenderbufferParameteriv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetRenderbufferParameteriv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetUniformfv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetUniformfv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetUniformiv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetUniformiv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetVertexAttribfv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetVertexAttribfv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetVertexAttribiv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetVertexAttribiv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetVertexAttribPointerv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetVertexAttribPointerv(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform2i__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform2i(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform1iv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform1iv(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform2iv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform2iv(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform3iv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform3iv(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform4iv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform4iv(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform1fv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform1fv(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform2fv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform2fv(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform3fv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform3fv(p0|0,p1|0,p2|0); }
  function _emscripten_glUniform4fv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glUniform4fv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetShaderiv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetShaderiv(p0|0,p1|0,p2|0); }
  function _emscripten_glGetProgramiv__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetProgramiv(p0|0,p1|0,p2|0); }
  function _emscripten_glBindAttribLocation__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glBindAttribLocation(p0|0,p1|0,p2|0); }
  function _emscripten_glGetObjectParameterivARB__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glGetObjectParameterivARB(p0|0,p1|0,p2|0); }
  function _emscripten_glNormalPointer__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glNormalPointer(p0|0,p1|0,p2|0); }
  function _emscripten_glDrawArrays__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glDrawArrays(p0|0,p1|0,p2|0); }
  function _emscripten_glTexParameteri__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glTexParameteri(p0|0,p1|0,p2|0); }
  function _emscripten_glStencilFunc__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glStencilFunc(p0|0,p1|0,p2|0); }
  function _emscripten_glStencilOp__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; _emscripten_glStencilOp(p0|0,p1|0,p2|0); }
  function b101(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = p5|0; abort(101); }
  function b102() { ; abort(102); }
  function ___cxa_pure_virtual__wrapper() { ; ___cxa_pure_virtual(); }
  function ___cxa_end_catch__wrapper() { ; ___cxa_end_catch(); }
  function ___cxa_rethrow__wrapper() { ; ___cxa_rethrow(); }
  function _JS_FileSystem_Sync__wrapper() { ; _JS_FileSystem_Sync(); }
  function _glFinish__wrapper() { ; _glFinish(); }
  function _glFlush__wrapper() { ; _glFlush(); }
  function _emscripten_glLoadIdentity__wrapper() { ; _emscripten_glLoadIdentity(); }
  function _emscripten_glReleaseShaderCompiler__wrapper() { ; _emscripten_glReleaseShaderCompiler(); }
  function _emscripten_glFinish__wrapper() { ; _emscripten_glFinish(); }
  function _emscripten_glFlush__wrapper() { ; _emscripten_glFlush(); }
  function b103(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = +p2; abort(103); }
  function b104(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = Math_fround(p5); abort(104); }
  function b105(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2); abort(105); }
  function _emscripten_glTexParameterf__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2); _emscripten_glTexParameterf(p0|0,p1|0,+p2); }
  function b106(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = p3|0;p4 = Math_fround(p4); abort(106);return Math_fround(0); }
  function b107(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = p4|0; abort(107);return 0; }
  function b108(p0) { p0 = +p0; abort(108); }
  function _emscripten_glClearDepth__wrapper(p0) { p0 = +p0; _emscripten_glClearDepth(+p0); }
  function b109(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4);p5 = Math_fround(p5);p6 = Math_fround(p6); abort(109);return 0; }
  function b110(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = Math_fround(p8);p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = Math_fround(p12);p13 = p13|0;p14 = p14|0;p15 = p15|0; abort(110); }
  function b111(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = Math_fround(p3); abort(111);return Math_fround(0); }
  function b112(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = Math_fround(p4);p5 = Math_fround(p5);p6 = p6|0;p7 = p7|0; abort(112); }
  function b113(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0; abort(113);return 0; }
  function b114(p0) { p0 = p0|0; abort(114);return 0; }
  function _time__wrapper(p0) { p0 = p0|0; return _time(p0|0)|0; }
  function _readdir__wrapper(p0) { p0 = p0|0; return _readdir(p0|0)|0; }
  function _JS_Sound_ReleaseInstance__wrapper(p0) { p0 = p0|0; return _JS_Sound_ReleaseInstance(p0|0)|0; }
  function _glCheckFramebufferStatus__wrapper(p0) { p0 = p0|0; return _glCheckFramebufferStatus(p0|0)|0; }
  function _glCreateShader__wrapper(p0) { p0 = p0|0; return _glCreateShader(p0|0)|0; }
  function _glGetString__wrapper(p0) { p0 = p0|0; return _glGetString(p0|0)|0; }
  function _abs__wrapper(p0) { p0 = p0|0; return _abs(p0|0)|0; }
  function _pthread_mutex_unlock__wrapper(p0) { p0 = p0|0; return _pthread_mutex_unlock(p0|0)|0; }
  function _pthread_mutex_lock__wrapper(p0) { p0 = p0|0; return _pthread_mutex_lock(p0|0)|0; }
  function _pthread_cond_broadcast__wrapper(p0) { p0 = p0|0; return _pthread_cond_broadcast(p0|0)|0; }
  function _uselocale__wrapper(p0) { p0 = p0|0; return _uselocale(p0|0)|0; }
  function _emscripten_glGetString__wrapper(p0) { p0 = p0|0; return _emscripten_glGetString(p0|0)|0; }
  function _emscripten_glIsTexture__wrapper(p0) { p0 = p0|0; return _emscripten_glIsTexture(p0|0)|0; }
  function _emscripten_glIsBuffer__wrapper(p0) { p0 = p0|0; return _emscripten_glIsBuffer(p0|0)|0; }
  function _emscripten_glIsRenderbuffer__wrapper(p0) { p0 = p0|0; return _emscripten_glIsRenderbuffer(p0|0)|0; }
  function _emscripten_glCreateShader__wrapper(p0) { p0 = p0|0; return _emscripten_glCreateShader(p0|0)|0; }
  function _emscripten_glIsShader__wrapper(p0) { p0 = p0|0; return _emscripten_glIsShader(p0|0)|0; }
  function _emscripten_glIsProgram__wrapper(p0) { p0 = p0|0; return _emscripten_glIsProgram(p0|0)|0; }
  function _emscripten_glIsFramebuffer__wrapper(p0) { p0 = p0|0; return _emscripten_glIsFramebuffer(p0|0)|0; }
  function _emscripten_glCheckFramebufferStatus__wrapper(p0) { p0 = p0|0; return _emscripten_glCheckFramebufferStatus(p0|0)|0; }
  function _emscripten_glIsEnabled__wrapper(p0) { p0 = p0|0; return _emscripten_glIsEnabled(p0|0)|0; }
  function b115(p0,p1,p2) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2); abort(115);return 0; }
  function b116(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = p3|0; abort(116); }
  function b117(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0; abort(117);return 0; }
  function b118(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = Math_fround(p4);p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = Math_fround(p10); abort(118);return 0; }
  function b119(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = Math_fround(p3); abort(119); }
  function b120(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0; abort(120); }
  function b121(p0,p1,p2) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0; abort(121);return 0; }
  function b122(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3); abort(122); }
  function b123(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = Math_fround(p5);p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0; abort(123); }
  function b124(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = Math_fround(p4);p5 = p5|0;p6 = p6|0; abort(124); }
  function b125(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20,p21,p22,p23,p24) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0;p15 = p15|0;p16 = p16|0;p17 = p17|0;p18 = p18|0;p19 = p19|0;p20 = p20|0;p21 = p21|0;p22 = p22|0;p23 = p23|0;p24 = p24|0; abort(125); }
  function b126(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = Math_fround(p1);p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0; abort(126);return 0; }
  function b127(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = p3|0; abort(127);return 0; }
  function b128(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(128);return 0; }
  function _newlocale__wrapper(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; return _newlocale(p0|0,p1|0,p2|0)|0; }
  function b129(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4); abort(129); }
  function b130(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = p4|0; abort(130); }
  function b131(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2); abort(131);return 0; }
  function b132(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = +p6; abort(132); }
  function b133(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = p4|0; abort(133); }
  function b134(p0,p1,p2,p3,p4,p5,p6) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4);p5 = Math_fround(p5);p6 = Math_fround(p6); abort(134); }
  function b135(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0; abort(135);return 0; }
  function b136(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; abort(136);return 0; }
  function b137(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0; abort(137);return 0; }
  function b138(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20,p21,p22,p23,p24,p25,p26,p27,p28) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0;p15 = p15|0;p16 = p16|0;p17 = p17|0;p18 = p18|0;p19 = p19|0;p20 = p20|0;p21 = p21|0;p22 = p22|0;p23 = p23|0;p24 = p24|0;p25 = p25|0;p26 = p26|0;p27 = p27|0;p28 = p28|0; abort(138); }
  function b139(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4);p5 = Math_fround(p5);p6 = Math_fround(p6);p7 = Math_fround(p7);p8 = Math_fround(p8);p9 = Math_fround(p9);p10 = Math_fround(p10);p11 = Math_fround(p11);p12 = Math_fround(p12);p13 = p13|0;p14 = p14|0;p15 = p15|0;p16 = p16|0; abort(139); }
  function b140(p0,p1) { p0 = Math_fround(p0);p1 = p1|0; abort(140); }
  function _emscripten_glSampleCoverage__wrapper(p0,p1) { p0 = Math_fround(p0);p1 = p1|0; _emscripten_glSampleCoverage(+p0,p1|0); }
  function b141() { ; abort(141);return 0; }
  function _glCreateProgram__wrapper() { ; return _glCreateProgram()|0; }
  function _glGetError__wrapper() { ; return _glGetError()|0; }
  function ___ctype_b_loc__wrapper() { ; return ___ctype_b_loc()|0; }
  function ___ctype_toupper_loc__wrapper() { ; return ___ctype_toupper_loc()|0; }
  function ___ctype_tolower_loc__wrapper() { ; return ___ctype_tolower_loc()|0; }
  function _emscripten_glCreateProgram__wrapper() { ; return _emscripten_glCreateProgram()|0; }
  function _emscripten_glGetError__wrapper() { ; return _emscripten_glGetError()|0; }
  function b142(p0,p1) { p0 = Math_fround(p0);p1 = Math_fround(p1); abort(142); }
  function _glPolygonOffset__wrapper(p0,p1) { p0 = Math_fround(p0);p1 = Math_fround(p1); _glPolygonOffset(+p0,+p1); }
  function _emscripten_glDepthRangef__wrapper(p0,p1) { p0 = Math_fround(p0);p1 = Math_fround(p1); _emscripten_glDepthRangef(+p0,+p1); }
  function _emscripten_glPolygonOffset__wrapper(p0,p1) { p0 = Math_fround(p0);p1 = Math_fround(p1); _emscripten_glPolygonOffset(+p0,+p1); }
  function b143(p0,p1,p2,p3,p4,p5,p6,p7,p8) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = Math_fround(p3);p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0;p8 = p8|0; abort(143); }
  function b144(p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = Math_fround(p5);p6 = p6|0;p7 = p7|0;p8 = p8|0;p9 = p9|0;p10 = p10|0;p11 = p11|0;p12 = p12|0;p13 = p13|0;p14 = p14|0;p15 = p15|0;p16 = p16|0;p17 = p17|0; abort(144);return 0; }
  function b145(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4);p5 = Math_fround(p5); abort(145); }
  function b146(p0,p1,p2,p3,p4,p5,p6,p7) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0;p6 = p6|0;p7 = p7|0; abort(146);return 0; }
  function b147(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = Math_fround(p1);p2 = Math_fround(p2);p3 = Math_fround(p3);p4 = Math_fround(p4);p5 = p5|0; abort(147); }
  // EMSCRIPTEN_END_FUNCS
  var FUNCTION_TABLE_fiff = [b0,__ZNK5physx2Gu11HeightField9getHeightEff,__Z72AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_AngleDistanceP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraff,__Z104UnityEngine_UnityEngine_Mathf_m_Min_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_Objectff,__Z104UnityEngine_UnityEngine_Mathf_m_Max_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_Objectff,__Z38UnityEngine_UnityEngine_Mathf_m_RepeatP22mscorlib_System_Objectff,__Z42UnityEngine_UnityEngine_Mathf_m_DeltaAngleP22mscorlib_System_Objectff,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked21CompareExchangeSingleEPfff,__ZNK9Heightmap21GetInterpolatedHeightEff,b0,b0,b0,b0,b0,b0,b0];
  var FUNCTION_TABLE_iiiiiii = [b1,__ZL15SweepBoxUserBoxPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL19SweepBoxUserCapsulePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL12SweepBoxMeshPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL11SweepBoxBoxPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL14SweepBoxSpherePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL15SweepBoxCapsulePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL19SweepCapsuleUserBoxPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL23SweepCapsuleUserCapsulePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL16SweepCapsuleMeshPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL15SweepCapsuleBoxPKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL18SweepCapsuleSpherePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZL19SweepCapsuleCapsulePKN5physx3Cct9SweepTestEPKNS0_11SweptVolumeEPKNS0_11TouchedGeomERKNS_14PxExtendedVec3ERKNS_6PxVec3ERNS0_12SweptContactE,__ZN5physx9NpPhysics11createShapeERKNS_10PxGeometryEPKPNS_10PxMaterialEtbNS_7PxFlagsINS_11PxShapeFlag4EnumEhEE,__ZN5physx9NpPhysics16createConstraintEPNS_12PxRigidActorES2_RNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableEj,__ZNK5physx14NpSceneQueries7overlapERKNS_10PxGeometryERKNS_11PxTransformERNS_13PxHitCallbackINS_12PxOverlapHitEEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackE,__ZNK5physx13NpVolumeCache7overlapERKNS_10PxGeometryERKNS_11PxTransformERNS_13PxHitCallbackINS_12PxOverlapHitEEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackE,__ZL28GeomMTDCallback_SphereSphereRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL27GeomMTDCallback_SpherePlaneRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL29GeomMTDCallback_SphereCapsuleRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL25GeomMTDCallback_SphereBoxRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL28GeomMTDCallback_SphereConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL26GeomMTDCallback_SphereMeshRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL33GeomMTDCallback_SphereHeightFieldRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL28GeomMTDCallback_NotSupportedRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL28GeomMTDCallback_PlaneCapsuleRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL24GeomMTDCallback_PlaneBoxRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL27GeomMTDCallback_PlaneConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL30GeomMTDCallback_CapsuleCapsuleRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_
  ,__ZL26GeomMTDCallback_CapsuleBoxRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL29GeomMTDCallback_CapsuleConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL27GeomMTDCallback_CapsuleMeshRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL34GeomMTDCallback_CapsuleHeightFieldRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL22GeomMTDCallback_BoxBoxRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL25GeomMTDCallback_BoxConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL23GeomMTDCallback_BoxMeshRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL30GeomMTDCallback_BoxHeightFieldRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL28GeomMTDCallback_ConvexConvexRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL26GeomMTDCallback_ConvexMeshRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZL33GeomMTDCallback_ConvexHeightFieldRN5physx6PxVec3ERfRKNS_10PxGeometryERKNS_11PxTransformES5_S8_,__ZN16MemoryFileSystem4ReadER13FileEntryDatayPvPy,__ZN16MemoryFileSystem5WriteER13FileEntryDatayPvPy,__ZNK16MemoryFileSystem9EnumerateEPKcP13dynamic_arrayI13FileEntryInfoLj8EEbPPv19FileEnumerationFlag,__ZNK25MultiBlocksMemoryFileData4ReadEyyPv,__ZN25MultiBlocksMemoryFileData5WriteEyyPKv,__ZN20LocalFileSystemPosix4ReadER13FileEntryDatayPvPy,__ZN20LocalFileSystemPosix5WriteER13FileEntryDatayPvPy,__ZNK20LocalFileSystemPosix9EnumerateEPKcP13dynamic_arrayI13FileEntryInfoLj8EEbPPv19FileEnumerationFlag,__ZN13GfxDeviceGLES22CreateTextureCombinersEiPKN9ShaderLab14TextureBindingEPKNS0_13PropertySheetEbb,__ZN13GfxDeviceGLES17CaptureScreenshotEiiiiPh,__Z37mscorlib_System_Int32_m_JumpOverWhiteP22mscorlib_System_ObjectPiP22mscorlib_System_StringbbPP25mscorlib_System_Exception,__Z36mscorlib_System_Int32_m_FindExponentP22mscorlib_System_ObjectPiP22mscorlib_System_StringS1_bPP25mscorlib_System_Exception,__Z39mscorlib_System_String_m_CompareOrdinalP22mscorlib_System_ObjectP22mscorlib_System_StringiS2_ii,__Z38mscorlib_System_Decimal_m_PerformParseP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_P23mscorlib_System_Decimalb,__Z32mscorlib_System_Array_m_FastCopyP22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii,__Z185mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayiiS0_S0_,__Z38mscorlib_System_Array_m_DoBinarySearchP22mscorlib_System_ObjectP21mscorlib_System_ArrayiiS0_S0_,__Z249mscorlib_System_Type_m_GetMethod_mscorlib_System_Reflection_MethodInfo_mscorlib_System_String_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z282mscorlib_System_Type_m_GetConstructor_mscorlib_System_Reflection_ConstructorInfo_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Reflection_CallingConventions_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr
  ,__Z220mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsPrefix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iii,__Z220mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsSuffix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iii,__Z65mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_QuickIndexOfP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iiPb,__Z217mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iii,__Z221mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iii,__Z208mscorlib_System_Globalization_CompareInfo_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_iii,__Z212mscorlib_System_Globalization_CompareInfo_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_iii,__Z252mscorlib_System_Reflection_Emit_ConstructorBuilder_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP50mscorlib_System_Reflection_Emit_ConstructorBuilderP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo,__Z64mscorlib_System_Reflection_Emit_EnumBuilder_m_GetConstructorImplP43mscorlib_System_Reflection_Emit_EnumBuilderiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z80mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetConstructorImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z54mscorlib_System_Reflection_Emit_MethodBuilder_m_InvokeP45mscorlib_System_Reflection_Emit_MethodBuilderP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo,__Z251mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP47mscorlib_System_Reflection_Emit_PropertyBuilderP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo,__Z64mscorlib_System_Reflection_Emit_TypeBuilder_m_GetConstructorImplP43mscorlib_System_Reflection_Emit_TypeBuilderiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z286mscorlib_System_Reflection_Binder_Default_m_SelectMethod_mscorlib_System_Reflection_MethodBase_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_MethodBase_arr_arr_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arr_mscorlib_System_BooleanP41mscorlib_System_Reflection_Binder_DefaultiP41mscorlib_System_Reflection_MethodBase_arrP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arrb,__Z58mscorlib_System_Reflection_Binder_Default_m_SelectPropertyP41mscorlib_System_Reflection_Binder_DefaultiP43mscorlib_System_Reflection_PropertyInfo_arrP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z46mscorlib_System_Reflection_MonoMethod_m_InvokeP37mscorlib_System_Reflection_MonoMethodP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo,__Z240mscorlib_System_Reflection_MonoCMethod_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP38mscorlib_System_Reflection_MonoCMethodP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo,__Z243mscorlib_System_Reflection_MonoProperty_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP39mscorlib_System_Reflection_MonoPropertyP22mscorlib_System_ObjectiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo,__Z191mscorlib_System_Text_ASCIIEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri,__Z191mscorlib_System_Text_ASCIIEncoding_m_GetChars_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri,__Z192mscorlib_System_Text_Latin1Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri,__Z46mscorlib_System_Text_Latin1Encoding_m_GetCharsP35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri,__Z191mscorlib_System_Text_UTF32Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri,__Z45mscorlib_System_Text_UTF32Encoding_m_GetCharsP34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri,__Z190mscorlib_System_Text_UTF7Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri,__Z44mscorlib_System_Text_UTF7Encoding_m_GetCharsP33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri,__Z205mscorlib_System_Text_UTF8Encoding_m_InternalGetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_CharU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectP24mscorlib_System_Char_arriiPtb,__Z190mscorlib_System_Text_UTF8Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri,__Z44mscorlib_System_Text_UTF8Encoding_m_GetCharsP33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri,__Z193mscorlib_System_Text_UnicodeEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arri
  ,__Z47mscorlib_System_Text_UnicodeEncoding_m_GetCharsP36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arri,__Z42mscorlib_System_Buffer_m_BlockCopyInternalP22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii,__Z39mscorlib_System_DateTime_m__ParseStringP22mscorlib_System_ObjectP22mscorlib_System_StringiiS2_Pi,__Z46mscorlib_System_DateTime_m__ParseTimeSeparatorP22mscorlib_System_ObjectP22mscorlib_System_StringiP48mscorlib_System_Globalization_DateTimeFormatInfobPi,__Z46mscorlib_System_DateTime_m__ParseDateSeparatorP22mscorlib_System_ObjectP22mscorlib_System_StringiP48mscorlib_System_Globalization_DateTimeFormatInfobPi,__Z233mscorlib_System_DateTimeUtils_m_GetStandardPattern_mscorlib_System_String_mscorlib_System_Char_mscorlib_System_Globalization_DateTimeFormatInfo_mscorlib_System_BooleanU0026_ref_mscorlib_System_BooleanU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjecttP48mscorlib_System_Globalization_DateTimeFormatInfoPbS3_b,__Z45mscorlib_System_MonoType_m_GetConstructorImplP24mscorlib_System_MonoTypeiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z41mscorlib_System_TimeSpan_m_CalculateTicksP22mscorlib_System_Objectiiiii,__Z61UnityEngine_UnityEngine_Application_LogCallback_m_BeginInvokeP47UnityEngine_UnityEngine_Application_LogCallbackP22mscorlib_System_StringS2_iP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z187mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt32_mscorlib_System_Int32_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_T_mscorlib_System_Collections_Generic_IComparer_1_TP22mscorlib_System_ObjectP26mscorlib_System_UInt32_arriijS0_,__Z187mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt16_mscorlib_System_Int32_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_T_mscorlib_System_Collections_Generic_IComparer_1_TP22mscorlib_System_ObjectP26mscorlib_System_UInt16_arriitS0_,__Z185mscorlib_System_Array_m_BinarySearch_mscorlib_System_Byte_mscorlib_System_Int32_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_T_mscorlib_System_Collections_Generic_IComparer_1_TP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriihS0_,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO4OpenEP12Il2CppStringiiiiPi,__Z15malloc_internaljj10MemLabelIdiPKci,__Znwj10MemLabelIdbiPKci,__ZL30CollectComponentsWithoutAddingRN5Unity10GameObjectEiP14ScriptingClassR13dynamic_arrayI16AddComponentDataLj4EES7_PNSt3__112basic_stringIcNS8_11char_traitsIcEENS8_9allocatorIcEEEE,__ZN14SerializedFile12ReadMetadataILb0EEEbijPKhjj,__ZN14SerializedFile12ReadMetadataILb1EEEbijPKhjj,__ZN14SerializedFile4Type8ReadTypeILb0EEEbibiRPKhS3_,__ZN14SerializedFile4Type8ReadTypeILb1EEEbibiRPKhS3_,__ZN14SafeBinaryRead4InitERK16TypeTreeIteratorii24TransferInstructionFlags10MemLabelId,__ZN6Shader7SetPassEiijPKN9ShaderLab13PropertySheetERKNS0_17ShaderPassContextE,__ZN9ShaderLab4Pass9ApplyPassEjPKNS_13PropertySheetERKNS_17ShaderPassContextEP6Shaderi,__ZN9ShaderLab7Program21GetMatchingSubProgramEP6ShaderPNS_4PassERK16ShaderKeywordSetRS5_R19ShaderSnippetResult,__ZNK12PhysXRaycast17BroadPhaseCullingER13dynamic_arrayIN5physx12PxOverlapHitELj4EERS0_I4AABBLj4EERK10MinMaxAABBib,__ZL37UnityAudioEffect_InternalReadCallbackP14FMOD_DSP_STATEPfS1_jii,__Z29AudioMasterDSPProcessCallbackP21UnityAudioEffectStatePfS1_jii,__ZN17AudioCustomFilter12readCallbackEP14FMOD_DSP_STATEPfS2_jii,__Z29AudioMixerSendProcessCallbackP21UnityAudioEffectStatePfS1_jii,__Z32AudioMixerReceiveProcessCallbackP21UnityAudioEffectStatePfS1_jii
  ,__Z32AudioMixerDuckingProcessCallbackP21UnityAudioEffectStatePfS1_jii,__Z30AudioMixerFaderProcessCallbackP21UnityAudioEffectStatePfS1_jii,__ZN11UnityEngine9Animation31CreateControllerBindingConstantEPKN7mecanim9animation18ControllerConstantEPKNS2_12AnimationSetEPNS1_18ValueArrayConstantEjPKNS2_14AvatarConstantERNS1_6memory9AllocatorE,__ZN4Mesh17SetIndicesComplexEPKvjj16GfxPrimitiveTypei,__ZN20TextRenderingPrivate15DynamicFontData21GetFontMetricsForFaceENSt3__16vectorI8UnityStr13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEEEiRNS2_I4PPtrINS_4FontEES4_ISA_LS5_27ELi16EEEEPfSE_,__ZN20TextRenderingPrivate4Font16CacheFontForTextEPtiijNSt3__16vectorINS_16TextFormatChangeENS2_9allocatorIS4_EEEE,_ps_unicodes_init,_tt_find_sbit_image,__ZN17PersistentManager14LoadFileStreamERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_24TransferInstructionFlagsii,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsS1_E6InvokeEP10MethodInfoPvyy,__ZN16VirtFuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_E6InvokeEP10MethodInfoPvS5_S5_ii,__Z140mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32_gsharedP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_iiPPv,__ZN16VirtFuncInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEP10MethodInfoPviS5_S5_S5_,__ZN16VirtFuncInvoker4I28mscorlib_System_ObjectTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS2_S2_E6InvokeEP10MethodInfoPviS6_S6_S6_,__ZN16VirtFuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_E6InvokeEP10MethodInfoPvS5_iS5_i,__ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsS1_E6InvokeEP10MethodInfoPvyy,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
  ,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1];
  var FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiiii = [b2,__ZNK5physx20PxsSolverCoreGeneral26solveVParallelAndWriteBackEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjPiS9_PNS_25PxcThresholdStreamElementEjS9_RNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENSC_19ReflectionAllocatorISE_EEEESI_PNS_2Cm13SpatialVectorERi];
  var FUNCTION_TABLE_viiiiiiiiiii = [b3,__ZN13GfxDeviceGLES22UploadTextureSubData2DE9TextureIDPKhiiiiii13TextureFormat17TextureColorSpace,__Z27TransformVerticesStridedREFPhRK10Matrix4x4fjPKhiiiS4_iib,b3];
  var FUNCTION_TABLE_fff = [b4,__Z32AudioMeasurement_GetTimeConstantff,__ZN11PerlinNoise5NoiseEff,b4];
  var FUNCTION_TABLE_iidi = [b5,__Z126mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_Double_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectdS0_,__Z142mscorlib_System_NumberFormatter_m_FormatRoundtrip_mscorlib_System_String_mscorlib_System_Double_mscorlib_System_Globalization_NumberFormatInfoP31mscorlib_System_NumberFormatterdP46mscorlib_System_Globalization_NumberFormatInfo,__ZN14AnimationState20UpdateAnimationStateEdRN5Unity9ComponentE];
  var FUNCTION_TABLE_fiiiiiifiiiiiif = [b6,__ZN5physxL23PxcSweepSphereTrianglesERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf,__ZN5physxL29PxcUnimplementedTriangleSweepERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf,__ZN5physxL24PxcSweepCapsuleTrianglesERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf,__ZN5physxL20PxcSweepBoxTrianglesERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf,__ZN5physxL23PxcSweepConvexTrianglesERKNS_11PxsCCDShapeES2_RKNS_11PxTransformES5_S5_S5_fRNS_6PxVec3ES7_RNS_10PxcNpCacheERNS_18PxcNpThreadContextERKNS_2Cm23FastVertex2ShapeScalingERNS_2Gu9TriangleVEf,b6,b6];
  var FUNCTION_TABLE_iiiiifiif = [b7,__Z23sweepCapsule_SphereGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z22sweepCapsule_PlaneGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z24sweepCapsule_CapsuleGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z20sweepCapsule_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z23sweepCapsule_ConvexGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z21sweepCapsule_MeshGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z28sweepCapsule_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z23sweepCCTCapsule_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu7CapsuleERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z19sweepBox_SphereGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z18sweepBox_PlaneGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z20sweepBox_CapsuleGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z16sweepBox_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z19sweepBox_ConvexGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z17sweepBox_MeshGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z24sweepBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z22sweepCCTBox_SphereGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z23sweepCCTBox_CapsuleGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z19sweepCCTBox_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z27sweepCCTBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,b7,b7,b7,b7,b7,b7,b7,b7,b7
  ,b7,b7,b7];
  var FUNCTION_TABLE_viiiiiffi = [b8,__Z48UnityEngine_UnityEngine_GUI_m_CallWindowDelegateP22mscorlib_System_ObjectP42UnityEngine_UnityEngine_GUI_WindowFunctioniP31UnityEngine_UnityEngine_GUISkiniffP32UnityEngine_UnityEngine_GUIStyle];
  var FUNCTION_TABLE_iiiiiiiiiiii = [b9,__Z72mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesBackwardCoreP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringPiiiiPhbiPP47mscorlib_Mono_Globalization_Unicode_ContractionP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z381mscorlib_System_Text_UTF8Encoding_m_InternalGetChars_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_UInt32U0026_ref_mscorlib_System_UInt32U0026_ref_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectPhiPtiPjS3_S0_PP42mscorlib_System_Text_DecoderFallbackBufferPP24mscorlib_System_Byte_arrb,__ZNSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_,__ZNSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_,b9,b9,b9];
  var FUNCTION_TABLE_fiffifff = [b10,__Z212UnityEngine_UnityEngine_Mathf_m_SmoothDamp_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_ObjectffPffff,__Z217UnityEngine_UnityEngine_Mathf_m_SmoothDampAngle_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_ObjectffPffff,b10];
  var FUNCTION_TABLE_fif = [b11,__Z82AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_CalculateJumpVerticalSpeedP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorf,__Z89AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_CalculateJumpVerticalSpeedP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerf,__Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z72mscorlib_System_Math_m_Abs_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z35UnityEngine_UnityEngine_Mathf_m_CosP22mscorlib_System_Objectf,__Z36UnityEngine_UnityEngine_Mathf_m_AsinP22mscorlib_System_Objectf,__Z36UnityEngine_UnityEngine_Mathf_m_AcosP22mscorlib_System_Objectf,__Z36UnityEngine_UnityEngine_Mathf_m_SqrtP22mscorlib_System_Objectf,__Z35UnityEngine_UnityEngine_Mathf_m_AbsP22mscorlib_System_Objectf,__Z37UnityEngine_UnityEngine_Mathf_m_FloorP22mscorlib_System_Objectf,__Z37UnityEngine_UnityEngine_Mathf_m_RoundP22mscorlib_System_Objectf,__Z39UnityEngine_UnityEngine_Mathf_m_Clamp01P22mscorlib_System_Objectf,__Z49UnityEngine_UnityEngine_AnimationCurve_m_EvaluateP38UnityEngine_UnityEngine_AnimationCurvef,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked14ExchangeSingleEPff,__ZN11AudioSource15rolloffCallbackEP12FMOD_CHANNELf,__ZNK17AnimationCurveTplIfE13EvaluateClampEf,__Z30AnimationCurve_CUSTOM_EvaluateP15ScriptingObjectf,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11,b11
  ,b11,b11,b11];
  var FUNCTION_TABLE_viiiiiiiiiiiiiii = [b12,__ZNSt3__111__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i,__ZNSt3__111__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i,b12];
  var FUNCTION_TABLE_fid = [b13,__Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_DoubleP22mscorlib_System_Objectd];
  var FUNCTION_TABLE_fii = [b14,__ZNK5physx7NpScene25getVisualizationParameterENS_24PxVisualizationParameter4EnumE,__ZNK32RendererMaterialAnimationBinding13GetFloatValueERKN11UnityEngine9Animation10BoundCurveE,__ZNK24RendererAnimationBinding13GetFloatValueERKN11UnityEngine9Animation10BoundCurveE,__ZNK28MonoBehaviourPropertyBinding13GetFloatValueERKN11UnityEngine9Animation10BoundCurveE,__Z74AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_GetMaxAccelerationP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorb,__Z75AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_MaxSpeedInDirectionP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3,__Z52mscorlib_System_Int32_m_System_IConvertible_ToSinglePiP22mscorlib_System_Object,__Z52mscorlib_System_Int64_m_System_IConvertible_ToSinglePxP22mscorlib_System_Object,__Z53mscorlib_System_UInt32_m_System_IConvertible_ToSinglePjP22mscorlib_System_Object,__Z53mscorlib_System_UInt64_m_System_IConvertible_ToSinglePyP22mscorlib_System_Object,__Z51mscorlib_System_Byte_m_System_IConvertible_ToSinglePhP22mscorlib_System_Object,__Z52mscorlib_System_SByte_m_System_IConvertible_ToSinglePaP22mscorlib_System_Object,__Z52mscorlib_System_Int16_m_System_IConvertible_ToSinglePsP22mscorlib_System_Object,__Z53mscorlib_System_UInt16_m_System_IConvertible_ToSinglePtP22mscorlib_System_Object,__Z51mscorlib_System_Char_m_System_IConvertible_ToSinglePtP22mscorlib_System_Object,__Z53mscorlib_System_String_m_System_IConvertible_ToSingleP22mscorlib_System_StringP22mscorlib_System_Object,__Z53mscorlib_System_Single_m_System_IConvertible_ToSinglePfP22mscorlib_System_Object,__Z76mscorlib_System_Single_m_Parse_mscorlib_System_Single_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z53mscorlib_System_Double_m_System_IConvertible_ToSinglePdP22mscorlib_System_Object,__Z54mscorlib_System_Decimal_m_System_IConvertible_ToSingleP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Single_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z54mscorlib_System_Boolean_m_System_IConvertible_ToSinglePbP22mscorlib_System_Object,__Z51mscorlib_System_Enum_m_System_IConvertible_ToSingleP22mscorlib_System_ObjectS0_,__Z81mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z78mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z81mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z79mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z79mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_SByteP22mscorlib_System_Objecta
  ,__Z79mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_Int16P22mscorlib_System_Objects,__Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z53mscorlib_System_DBNull_m_System_IConvertible_ToSingleP22mscorlib_System_DBNullP22mscorlib_System_Object,__Z55mscorlib_System_DateTime_m_System_IConvertible_ToSingleP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z46UnityEngine_UnityEngine_Vector2_m_SqrMagnitudeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector2,__Z43UnityEngine_UnityEngine_Vector3_m_MagnitudeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z46UnityEngine_UnityEngine_Vector3_m_SqrMagnitudeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z89UnityEngine_UnityEngine_Matrix4x4_m_get_Item_mscorlib_System_Single_mscorlib_System_Int32P33UnityEngine_UnityEngine_Matrix4x4i,__Z44UnityEngine_UnityEngine_Bounds_m_SqrDistanceP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z46UnityEngine_UnityEngine_Vector4_m_SqrMagnitudeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4,__Z39UnityEngine_UnityEngine_Input_m_GetAxisP22mscorlib_System_ObjectP22mscorlib_System_String,__Z42UnityEngine_UnityEngine_Input_m_GetAxisRawP22mscorlib_System_ObjectP22mscorlib_System_String,__Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_SingleP21mscorlib_System_Arrayi,__Z31getPxVehicleGearsData_GearRatioPKN5physx18PxVehicleGearsDataENS0_4EnumE,__Z32getPxVehicleAutoBoxData_UpRatiosPKN5physx20PxVehicleAutoBoxDataENS_18PxVehicleGearsData4EnumE,__Z34getPxVehicleAutoBoxData_DownRatiosPKN5physx20PxVehicleAutoBoxDataENS_18PxVehicleGearsData4EnumE,__Z44getPxVehicleWheelsDynData_WheelRotationSpeedPKN5physx22PxVehicleWheelsDynDataEj,__Z44getPxVehicleWheelsDynData_WheelRotationAnglePKN5physx22PxVehicleWheelsDynDataEj,__Z36getPxVehicleDriveDynData_AnalogInputPKN5physx21PxVehicleDriveDynDataEj,__Z31getPxVehicleNoDrive_BrakeTorquePKN5physx16PxVehicleNoDriveEj,__Z31getPxVehicleNoDrive_DriveTorquePKN5physx16PxVehicleNoDriveEj,__Z30getPxVehicleNoDrive_SteerAnglePKN5physx16PxVehicleNoDriveEj,__ZN5physx18GetTorqueCurvePairEPKNS_19PxVehicleEngineDataEj,__Z48Bounds_CUSTOM_INTERNAL_CALL_Internal_SqrDistanceRK4AABBRK8Vector3f,__ZN12InputManager7GetAxisERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN12InputManager10GetAxisRawERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN16VirtFuncInvoker0I28mscorlib_System_SingleTraitsE6InvokeEP10MethodInfoPv,b14
  ,b14,b14,b14,b14,b14];
  var FUNCTION_TABLE_ddii = [b15,__ZN6il2cpp6icalls8mscorlib6System4Math6Round2Edib];
  var FUNCTION_TABLE_di = [b16,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double,__Z40mscorlib_System_TimeSpan_m_get_TotalDaysP24mscorlib_System_TimeSpan,__Z41mscorlib_System_TimeSpan_m_get_TotalHoursP24mscorlib_System_TimeSpan,__Z48mscorlib_System_TimeSpan_m_get_TotalMillisecondsP24mscorlib_System_TimeSpan,__Z43mscorlib_System_TimeSpan_m_get_TotalMinutesP24mscorlib_System_TimeSpan,__Z43mscorlib_System_TimeSpan_m_get_TotalSecondsP24mscorlib_System_TimeSpan,__ZN6il2cpp6icalls8mscorlib6System7Decimal14decimal2doubleEP19il2cpp_decimal_repr,__ZN11TimeManager11GetRealtimeEv,b16,b16,b16,b16,b16,b16,b16];
  var FUNCTION_TABLE_dd = [b17,__ZN6il2cpp6icalls8mscorlib6System4Math4AcosEd,__ZN6il2cpp6icalls8mscorlib6System4Math4AsinEd,__ZN6il2cpp6icalls8mscorlib6System4Math4AtanEd,__ZN6il2cpp6icalls8mscorlib6System4Math3CosEd,__ZN6il2cpp6icalls8mscorlib6System4Math4CoshEd,__ZN6il2cpp6icalls8mscorlib6System4Math3ExpEd,__ZN6il2cpp6icalls8mscorlib6System4Math5FloorEd,__ZN6il2cpp6icalls8mscorlib6System4Math3LogEd,__ZN6il2cpp6icalls8mscorlib6System4Math5Log10Ed,__ZN6il2cpp6icalls8mscorlib6System4Math5RoundEd,__ZN6il2cpp6icalls8mscorlib6System4Math3SinEd,__ZN6il2cpp6icalls8mscorlib6System4Math4SinhEd,__ZN6il2cpp6icalls8mscorlib6System4Math4SqrtEd,__ZN6il2cpp6icalls8mscorlib6System4Math3TanEd,__ZN6il2cpp6icalls8mscorlib6System4Math4TanhEd];
  var FUNCTION_TABLE_viff = [b18,__ZN5physx19NpArticulationJoint13setSwingLimitEff,__ZN5physx19NpArticulationJoint13setTwistLimitEff,__ZN5physx12NpConstraint13setBreakForceEff,__ZN5physx5cloth9ClothImplINS0_7SwClothEE28setMotionConstraintScaleBiasEff,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE28setMotionConstraintScaleBiasEff,__ZN9GfxDevice18SetGlobalDepthBiasEff,__ZN13ScreenManager24SetupScreenManagerEditorEff,__Z48UnityEngine_UnityEngine_GradientAlphaKey_m__ctorP40UnityEngine_UnityEngine_GradientAlphaKeyff,__Z54UnityEngine_UnityEngine_GUILayoutGroup_m_SetHorizontalP38UnityEngine_UnityEngine_GUILayoutGroupff,__Z52UnityEngine_UnityEngine_GUILayoutGroup_m_SetVerticalP38UnityEngine_UnityEngine_GUILayoutGroupff,__Z54UnityEngine_UnityEngine_GUILayoutEntry_m_SetHorizontalP38UnityEngine_UnityEngine_GUILayoutEntryff,__Z52UnityEngine_UnityEngine_GUILayoutEntry_m_SetVerticalP38UnityEngine_UnityEngine_GUILayoutEntryff,__Z54UnityEngine_UnityEngine_GUIScrollGroup_m_SetHorizontalP38UnityEngine_UnityEngine_GUIScrollGroupff,__Z52UnityEngine_UnityEngine_GUIScrollGroup_m_SetVerticalP38UnityEngine_UnityEngine_GUIScrollGroupff,__Z39UnityEngine_UnityEngine_Vector2_m__ctorP31UnityEngine_UnityEngine_Vector2ff,__Z40UnityEngine_UnityEngine_Keyframe_m__ctorP32UnityEngine_UnityEngine_Keyframeff,__ZN9ShaderLab6TexEnv15SetTextureScaleEff,__ZN9ShaderLab6TexEnv16SetTextureOffsetEff,_emscripten_glUniform2f__wrapper,_emscripten_glVertexAttrib2f__wrapper,b18,b18,b18,b18,b18,b18,b18,b18
  ,b18,b18,b18];
  var FUNCTION_TABLE_vffi = [b19,__Z25LoadFullScreenOrthoMatrixffb];
  var FUNCTION_TABLE_viiiifiii = [b20,__ZL18AddDepthPassObjectRNSt3__16vectorI17RODataReplacement13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEEPN5Unity8MaterialERK17ShaderReplaceDataPK11VisibleNodefii18GlobalLayeringData];
  var FUNCTION_TABLE_viffff = [b21,__ZN9GfxDevice14ImmediateColorEffff,__Z150UnityEngine_UnityEngine_Color_m__ctor_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP29UnityEngine_UnityEngine_Colorffff,__Z42UnityEngine_UnityEngine_Quaternion_m__ctorP34UnityEngine_UnityEngine_Quaternionffff,__Z36UnityEngine_UnityEngine_Rect_m__ctorP28UnityEngine_UnityEngine_Rectffff,__Z39UnityEngine_UnityEngine_Vector4_m__ctorP31UnityEngine_UnityEngine_Vector4ffff,__Z28Matrix4x4_CUSTOM_Perspectiveffff,_glVertexAttrib4f__wrapper,_emscripten_glUniform4f__wrapper,_emscripten_glVertexAttrib4f__wrapper,b21,b21,b21,b21,b21,b21];
  var FUNCTION_TABLE_d = [b22,__Z19GetTimeSinceStartupv,_emscripten_get_now__wrapper,b22];
  var FUNCTION_TABLE_didd = [b23,__Z26mscorlib_System_Math_m_PowP22mscorlib_System_Objectdd,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked21CompareExchangeDoubleEPddd,b23];
  var FUNCTION_TABLE_viiiiifffiiiii = [b24,__ZN20TextRenderingPrivate17TextMeshGeneratorC2ERK11UTF16StringPNS_4FontE10TextAnchor13TextAlignmentfffbb11ColorRGBA32ii];
  var FUNCTION_TABLE_iiiiifffiiiii = [b25,__ZN20TextRenderingPrivate17TextMeshGenerator3GetERK11UTF16StringPNS_4FontE10TextAnchor13TextAlignmentfffbb11ColorRGBA32ii];
  var FUNCTION_TABLE_dii = [b26,__Z52mscorlib_System_Int32_m_System_IConvertible_ToDoublePiP22mscorlib_System_Object,__Z52mscorlib_System_Int64_m_System_IConvertible_ToDoublePxP22mscorlib_System_Object,__Z53mscorlib_System_UInt32_m_System_IConvertible_ToDoublePjP22mscorlib_System_Object,__Z53mscorlib_System_UInt64_m_System_IConvertible_ToDoublePyP22mscorlib_System_Object,__Z51mscorlib_System_Byte_m_System_IConvertible_ToDoublePhP22mscorlib_System_Object,__Z52mscorlib_System_SByte_m_System_IConvertible_ToDoublePaP22mscorlib_System_Object,__Z52mscorlib_System_Int16_m_System_IConvertible_ToDoublePsP22mscorlib_System_Object,__Z53mscorlib_System_UInt16_m_System_IConvertible_ToDoublePtP22mscorlib_System_Object,__Z51mscorlib_System_Char_m_System_IConvertible_ToDoublePtP22mscorlib_System_Object,__Z53mscorlib_System_String_m_System_IConvertible_ToDoubleP22mscorlib_System_StringP22mscorlib_System_Object,__Z53mscorlib_System_Single_m_System_IConvertible_ToDoublePfP22mscorlib_System_Object,__Z53mscorlib_System_Double_m_System_IConvertible_ToDoublePdP22mscorlib_System_Object,__Z54mscorlib_System_Decimal_m_System_IConvertible_ToDoubleP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z40mscorlib_System_Decimal_m_decimal2doubleP22mscorlib_System_ObjectP23mscorlib_System_Decimal,__Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Double_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z54mscorlib_System_Boolean_m_System_IConvertible_ToDoublePbP22mscorlib_System_Object,__Z51mscorlib_System_Enum_m_System_IConvertible_ToDoubleP22mscorlib_System_ObjectS0_,__Z81mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z78mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z81mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z79mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z79mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z79mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_Int16P22mscorlib_System_Objects,__Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z53mscorlib_System_DBNull_m_System_IConvertible_ToDoubleP22mscorlib_System_DBNullP22mscorlib_System_Object,__Z55mscorlib_System_DateTime_m_System_IConvertible_ToDoubleP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DoubleP21mscorlib_System_Arrayi
  ,b26,b26,b26];
  var FUNCTION_TABLE_did = [b27,__Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z28mscorlib_System_Math_m_FloorP22mscorlib_System_Objectd,__Z74mscorlib_System_Math_m_Round_mscorlib_System_Double_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z26mscorlib_System_Math_m_CosP22mscorlib_System_Objectd,__Z27mscorlib_System_Math_m_AcosP22mscorlib_System_Objectd,__Z27mscorlib_System_Math_m_AsinP22mscorlib_System_Objectd,__Z27mscorlib_System_Math_m_SqrtP22mscorlib_System_Objectd,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked14ExchangeDoubleEPdd,b27,b27,b27,b27,b27,b27,b27];
  var FUNCTION_TABLE_dif = [b28,__Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_SingleP22mscorlib_System_Objectf];
  var FUNCTION_TABLE_iifii = [b29,__ZN5physx14PxRigidBodyExt23setMassAndUpdateInertiaERNS_11PxRigidBodyEfPKNS_6PxVec3Eb];
  var FUNCTION_TABLE_iiiiiiiiii = [b30,__ZN5physx7Cooking19computeHullPolygonsERKNS_20PxSimpleTriangleMeshERNS_19PxAllocatorCallbackERjRPNS_6PxVec3ES6_RPjS6_RPNS_13PxHullPolygonE,__ZN13GfxDeviceGLES24CreateRenderColorSurfaceE9TextureIDiiii16TextureDimension19RenderTextureFormatj,__Z37mscorlib_System_Decimal_m_stripStylesP22mscorlib_System_ObjectP22mscorlib_System_StringiP46mscorlib_System_Globalization_NumberFormatInfoPiPbS6_S5_b,__Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOfSortKeyP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiPhtibP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOfSortKeyP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiiPhibP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesBackwardP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringPiiiiPhbP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z55mscorlib_System_Diagnostics_StackFrame_m_get_frame_infoP22mscorlib_System_ObjectibPP37mscorlib_System_Reflection_MethodBasePiS4_PP22mscorlib_System_StringS4_S4_,__Z58mscorlib_System_Reflection_Emit_EnumBuilder_m_InvokeMemberP43mscorlib_System_Reflection_Emit_EnumBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP22mscorlib_System_ObjectP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arr,__Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_InvokeMemberP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP22mscorlib_System_ObjectP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arr,__Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_InvokeMemberP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP22mscorlib_System_ObjectP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arr,__Z315mscorlib_System_Text_UTF8Encoding_m_InternalGetCharCount_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_UInt32_mscorlib_System_UInt32_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectPhijjS0_PP42mscorlib_System_Text_DecoderFallbackBufferPP24mscorlib_System_Byte_arrb,__Z39mscorlib_System_MonoType_m_InvokeMemberP24mscorlib_System_MonoTypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP22mscorlib_System_ObjectP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arr,__Z51mscorlib_System_NumberFormatter_CustomInfo_m_FormatP42mscorlib_System_NumberFormatter_CustomInfoP22mscorlib_System_StringiiP46mscorlib_System_Globalization_NumberFormatInfobP34mscorlib_System_Text_StringBuilderS6_S6_,__ZN16VirtFuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_S0_E6InvokeEP10MethodInfoPvS5_iiS5_iii,__ZN16VirtFuncInvoker7I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_S0_S0_S0_E6InvokeEP10MethodInfoPviS5_S5_S5_S5_S5_S5_];
  var FUNCTION_TABLE_vdddddd = [b31,_emscripten_glFrustum__wrapper];
  var FUNCTION_TABLE_fiffiff = [b32,__Z194UnityEngine_UnityEngine_Mathf_m_SmoothDampAngle_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_Single_mscorlib_System_SingleP22mscorlib_System_ObjectffPfff];
  var FUNCTION_TABLE_iiiiiiiiiiiiffffii = [b33,__ZN5physx28createFinalizeSolverContactsERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEbbRNS_23PxcSolverConstraintDescEPKNS_13PxcSolverBodyES8_PKNS_17PxcSolverBodyDataESB_PKNS_12PxsRigidCoreESE_ffffRNS_25PxsConstraintBlockManagerENS_14PxFrictionType4EnumE,__ZN5physx35createFinalizeSolverContactsCoulombERNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEbbRNS_23PxcSolverConstraintDescEPKNS_13PxcSolverBodyES8_PKNS_17PxcSolverBodyDataESB_PKNS_12PxsRigidCoreESE_ffffRNS_25PxsConstraintBlockManagerENS_14PxFrictionType4EnumE,b33];
  var FUNCTION_TABLE_vdd = [b34,_emscripten_glDepthRange__wrapper];
  var FUNCTION_TABLE_viiifiiii = [b35,__ZN20TextRenderingPrivate4Font21AddCharacterInfoEntryERK5RectTIfES4_fibij];
  var FUNCTION_TABLE_iiiif = [b36,__Z143AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_SingleU0026_ref_mscorlib_System_String_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectPfP22mscorlib_System_Stringf];
  var FUNCTION_TABLE_iiiiiiii = [b37,__ZN26PxcContactCellMeshCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZZN5physxL20PxcSweepAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEEN13AccumCallback10processHitERKNS_12PxRaycastHitERKS9_SK_SK_RfPKj,__ZZN5physx28PxcSweepEstimateAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fEN2CB10processHitERKNS_12PxRaycastHitERKNS_6PxVec3ESF_SF_RfPKj,__ZN5physx22PxcContactSphereSphereERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx21PxcContactSpherePlaneERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx23PxcContactSphereCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx19PxcContactSphereBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx22PxcContactSphereConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx20PxcContactSphereMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physxL21PxcInvalidContactPairERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx22PxcContactPlaneCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx18PxcContactPlaneBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx21PxcContactPlaneConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx24PxcContactCapsuleCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx20PxcContactCapsuleBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx23PxcContactCapsuleConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx21PxcContactCapsuleMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx16PxcContactBoxBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx19PxcContactBoxConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx17PxcContactBoxMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx22PxcContactConvexConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx21PxcContactConvexMesh2ERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx25PxcPCMContactSphereSphereERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx24PxcPCMContactSpherePlaneERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx26PxcPCMContactSphereCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx22PxcPCMContactSphereBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx25PxcPCMContactSphereConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx23PxcPCMContactSphereMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE
  ,__ZN5physx25PxcPCMContactPlaneCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx21PxcPCMContactPlaneBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx24PxcPCMContactPlaneConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx27PxcPCMContactCapsuleCapsuleERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx23PxcPCMContactCapsuleBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx26PxcPCMContactCapsuleConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx24PxcPCMContactCapsuleMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx19PxcPCMContactBoxBoxERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx22PxcPCMContactBoxConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx20PxcPCMContactBoxMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx25PxcPCMContactConvexConvexERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx23PxcPCMContactConvexMeshERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx25PxVehicleConstraintShader36vehicleSuspLimitConstraintSolverPrepEPNS_14Px1DConstraintERNS_6PxVec3EjRNS_24PxConstraintInvMassScaleEPKvRKNS_11PxTransformESB_,__ZN23RayMeshColliderCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZN25MeshMTDGenerationCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZN26ContactCapsuleMeshCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZN37ConvexVsMeshContactGenerationCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZN12_GLOBAL__N_135SphereMeshContactGenerationCallback10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj,__ZN26IntersectAnyVsMeshCallbackILi2ELb0EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj,__ZN26IntersectAnyVsMeshCallbackILi2ELb1EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj,__ZN26IntersectAnyVsMeshCallbackILi1ELb0EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj,__ZN26IntersectAnyVsMeshCallbackILi1ELb1EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj,__ZN26IntersectAnyVsMeshCallbackILi0ELb0EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj,__ZN26IntersectAnyVsMeshCallbackILi0ELb1EE10processHitERKN5physx12PxRaycastHitERKNS1_6PxVec3ES7_S7_RfPKj,__ZN27ConvexVsMeshOverlapCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZN25ConvexVsMeshSweepCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZN23SweepBoxMeshHitCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZN20SweepCapsuleCallback10processHitERKN5physx12PxRaycastHitERKNS0_6PxVec3ES6_S6_RfPKj,__ZN5physx2Gu32PCMMeshContactGenerationCallbackINS_41PCMCapsuleVsMeshContactGenerationCallbackEE10processHitERKNS_12PxRaycastHitERKNS_6PxVec3ES9_S9_RfPKj,__ZN5physx2Gu32PCMMeshContactGenerationCallbackINS_40PCMConvexVsMeshContactGenerationCallbackEE10processHitERKNS_12PxRaycastHitERKNS_6PxVec3ES9_S9_RfPKj
  ,__ZN5physx2Gu32PCMMeshContactGenerationCallbackINS_40PCMSphereVsMeshContactGenerationCallbackEE10processHitERKNS_12PxRaycastHitERKNS_6PxVec3ES9_S9_RfPKj,__ZN17GenericDynamicVBO8GetChunkEjjj16GfxPrimitiveTypePPvS2_,__ZN7Cubemap11InitTextureEii13TextureFormatiii,__ZN9Texture2D11InitTextureEii13TextureFormatiii,__ZN10MemoryFile4ReadEyyPvPy,__ZN10MemoryFile5WriteEyyPKvPy,__Z241mscorlib_System_Int32_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_Int32U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPiPP25mscorlib_System_Exception,__Z241mscorlib_System_Int64_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_Int64U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPxPP25mscorlib_System_Exception,__Z243mscorlib_System_UInt32_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_UInt32U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPjPP25mscorlib_System_Exception,__Z243mscorlib_System_UInt64_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_UInt64U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPyPP25mscorlib_System_Exception,__Z48mscorlib_System_String_m_CompareOrdinalUncheckedP22mscorlib_System_ObjectP22mscorlib_System_StringiiS2_ii,__Z63mscorlib_System_String_m_CompareOrdinalCaseInsensitiveUncheckedP22mscorlib_System_ObjectP22mscorlib_System_StringiiS2_ii,__Z243mscorlib_System_Double_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProvider_mscorlib_System_Boolean_mscorlib_System_DoubleU0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_bPdPP25mscorlib_System_Exception,__Z121mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64_mscorlib_System_Int64P21mscorlib_System_Arrayxxx,__Z295mscorlib_System_Type_m_GetMethod_mscorlib_System_Reflection_MethodInfo_mscorlib_System_String_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Reflection_CallingConventions_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z274mscorlib_System_Type_m_GetProperty_mscorlib_System_Reflection_PropertyInfo_mscorlib_System_String_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Type_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderS0_P24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareOrdinalP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_ii,__Z77mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareOrdinalIgnoreCaseP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_ii,__Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_QuickCheckPossibleP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_ii,__Z267mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsPrefix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ContextU0026_refP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iibP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z270mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ContextU0026_refP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iiPhP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z274mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ContextU0026_refP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_iiPhP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z58mscorlib_System_Globalization_CompareInfo_m_internal_indexP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_ib,__Z66mscorlib_System_Globalization_CompareInfo_m_internal_index_managedP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_ib,__Z65mscorlib_System_Globalization_CompareInfo_m_internal_index_switchP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_ib,__Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_GetMethodImplP43mscorlib_System_Reflection_Emit_EnumBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z61mscorlib_System_Reflection_Emit_EnumBuilder_m_GetPropertyImplP43mscorlib_System_Reflection_Emit_EnumBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetMethodImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetPropertyImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_GetMethodImplP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr
  ,__Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_GetPropertyImplP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z243mscorlib_System_Text_ASCIIEncoding_m_GetChars_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Text_DecoderFallbackBufferU0026_refP34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arriPP42mscorlib_System_Text_DecoderFallbackBuffer,__Z52mscorlib_System_Text_UTF7Encoding_m_InternalGetCharsP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arriPi,__Z232mscorlib_System_Text_UTF8Encoding_m_InternalGetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_CharU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectPtiPhiS1_b,__Z264mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_Type_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfo_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfoS6_,__Z37mscorlib_System_DateTime_m__ParseEnumP22mscorlib_System_ObjectP22mscorlib_System_StringiP26mscorlib_System_String_arrS4_bPi,__Z40mscorlib_System_MonoType_m_GetMethodImplP24mscorlib_System_MonoTypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderiP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z42mscorlib_System_MonoType_m_GetPropertyImplP24mscorlib_System_MonoTypeP22mscorlib_System_StringiP33mscorlib_System_Reflection_BinderP20mscorlib_System_TypeP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z187mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt64_mscorlib_System_Int32_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_T_mscorlib_System_Collections_Generic_IComparer_1_TP22mscorlib_System_ObjectP26mscorlib_System_UInt64_arriiyS0_,__ZN6il2cpp6icalls8mscorlib6System7Decimal14decimal2stringEP19il2cpp_decimal_repriiP11Il2CppArrayiPiS8_,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo14internal_indexEP41mscorlib_System_Globalization_CompareInfoP12Il2CppStringiiS8_ib,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO15DuplicateHandleE12Il2CppIntPtrS5_S5_PS5_iii,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly15LoadPermissionsEP35mscorlib_System_Reflection_AssemblyP12Il2CppIntPtrPiS8_S9_S8_S9_,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit22CustomAttributeBuilder7GetBlobEP14Il2CppAssemblyPvP11Il2CppArraySA_SA_SA_SA_,__ZN5physx27PxcContactSphereHeightFieldERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx28PxcContactCapsuleHeightFieldERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx24PxcContactBoxHeightFieldERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN5physx27PxcContactConvexHeightFieldERKNS_2Gu13GeometryUnionES3_RKNS_11PxTransformES6_RKfRNS_10PxcNpCacheERNS0_13ContactBufferE,__ZN13MemoryManager8AllocateEji10MemLabelIdiPKci,__Z16realloc_internalPvji10MemLabelIdiPKci,__ZN13RenderTexture9SetActiveEiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_PS_i11CubemapFacej,__Z16PackTextureAtlasP9Texture2DiiPS0_P5RectTIfEii,__ZN17PersistentManager26LoadFileCompletelyThreadedERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPxPiibR12LoadProgress,__ZL21CheckMethodParameters21ScriptingMethodIl2CppP14ScriptingClassPS1_jP6ObjectR11MonoManager,__ZNK20GpuProgramParameters13PrepareValuesEPKN9ShaderLab13PropertySheetERKNS0_17ShaderPassContextEPhPKhP12GfxPatchInfoPb,__ZN4FMOD6System17getSoftwareFormatEPiP17FMOD_SOUND_FORMATS1_S1_P18FMOD_DSP_RESAMPLERS1_,__ZN20TextRenderingPrivate15GetFontMetadataERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERS6_S9_RjSA_iPi,_tt_face_load_sbit_image,__ZN16VirtFuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S0_E6InvokeEP10MethodInfoPvS5_S5_iii,__ZN16VirtFuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_S0_S0_E6InvokeEP10MethodInfoPviS5_iS5_S5_
  ,__ZN16VirtFuncInvoker5I28mscorlib_System_ObjectTraitsS0_27mscorlib_System_Int32Traits17VoidPointerTraitsS2_S2_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectiS6_S6_S6_,__ZN16VirtFuncInvoker5I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEP10MethodInfoPvS5_iS5_S5_S5_,__ZN16VirtFuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_E6InvokeEP10MethodInfoPvS5_iiS5_i,__ZN16VirtFuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEP10MethodInfoPviS5_S5_S5_S5_,__ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb,__ZNSt3__114__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb,b37,b37,b37];
  var FUNCTION_TABLE_iiiiiifffiiiii = [b38,__ZNK19TextRenderingModule8TMGenGetERK11UTF16StringPN13TextRendering4FontE10TextAnchor13TextAlignmentfffbb11ColorRGBA32ii];
  var FUNCTION_TABLE_vifiiiiiiiiiiiii = [b39,__ZNK5physx20PxsSolverCoreGeneral6solveVEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jPNS_2Cm13SpatialVectorE,__ZNK5physx20PxsSolverCoreGeneral13solveVCoulombEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jPNS_2Cm13SpatialVectorE,b39];
  var FUNCTION_TABLE_iiiii = [b40,__ZN5physx3Cct26CharacterControllerManager16createControllerERNS_9PxPhysicsEPNS_7PxSceneERKNS_16PxControllerDescE,__ZNK5physx11NpAggregate9getActorsEPPNS_7PxActorEjj,__ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE9getShapesEPPNS_7PxShapeEjj,__ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE14getConstraintsEPPNS_12PxConstraintEjj,__ZNK5physx9NpPhysics17getTriangleMeshesEPPNS_14PxTriangleMeshEjj,__ZNK5physx9NpPhysics15getHeightFieldsEPPNS_13PxHeightFieldEjj,__ZNK5physx9NpPhysics15getConvexMeshesEPPNS_12PxConvexMeshEjj,__ZNK5physx9NpPhysics9getScenesEPPNS_7PxSceneEjj,__ZNK5physx9NpPhysics9getShapesEPPNS_7PxShapeEjj,__ZNK5physx9NpPhysics12getMaterialsEPPNS_10PxMaterialEjj,__ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE9getShapesEPPNS_7PxShapeEjj,__ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE14getConstraintsEPPNS_12PxConstraintEjj,__ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE9getShapesEPPNS_7PxShapeEjj,__ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE14getConstraintsEPPNS_12PxConstraintEjj,__ZNK5physx7NpScene16getArticulationsEPPNS_14PxArticulationEjj,__ZNK5physx7NpScene14getConstraintsEPPNS_12PxConstraintEjj,__ZNK5physx7NpScene13getAggregatesEPPNS_11PxAggregateEjj,__ZNK5physx7NpScene20getBroadPhaseRegionsEPNS_22PxBroadPhaseRegionInfoEjj,__ZN18MultiQueryCallbackIN5physx10PxSweepHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj,__ZN18MultiQueryCallbackIN5physx12PxOverlapHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj,__ZN18MultiQueryCallbackIN5physx12PxRaycastHitEE6invokeERfPKNS0_2Sq13PrunerPayloadEj,__ZNK5physx16PxsBroadPhaseMBP10getRegionsEPNS_22PxBroadPhaseRegionInfoEjj,__ZNK5physx16PxBroadPhaseBase10getRegionsEPNS_22PxBroadPhaseRegionInfoEjj,__ZN5physx19PxcGetMaterialShapeEPKNS_12PxsShapeCoreEjRNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE,__ZN5physx18PxcGetMaterialMeshEPKNS_12PxsShapeCoreEjRNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE,__ZN5physx25PxcGetMaterialHeightFieldEPKNS_12PxsShapeCoreEjRNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE,__ZN5physx24PxcGetMaterialShapeShapeEPKNS_12PxsShapeCoreES2_RNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE,__ZN5physx23PxcGetMaterialShapeMeshEPKNS_12PxsShapeCoreES2_RNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE
  ,__ZN5physx30PxcGetMaterialShapeHeightFieldEPKNS_12PxsShapeCoreES2_RNS_18PxcNpThreadContextEPNS_15PxsMaterialInfoE,__ZNK5physx25PxVehicleConstraintShader19updatePvdPropertiesERNS_8debugger4comm13PvdDataStreamEPKNS_12PxConstraintENS_15PxPvdUpdateType4EnumE,__ZN5physx7Cooking14cookConvexMeshERKNS_16PxConvexMeshDescERNS_14PxOutputStreamEPNS_25PxConvexMeshCookingResult4EnumE,__ZN5physx9PxTaskMgr15submitNamedTaskEPNS_6PxTaskEPKcNS_10PxTaskType4EnumE,__ZN16RayRTreeCallbackILi1ELb1EE14processResultsEjPjRf,__ZN16RayRTreeCallbackILi0ELb1EE14processResultsEjPjRf,__ZN16RayRTreeCallbackILi1ELb0EE14processResultsEjPjRf,__ZN16RayRTreeCallbackILi0ELb0EE14processResultsEjPjRf,__ZN21UnityDefaultAllocatorI17LowLevelAllocatorE10ReallocateEPvji,__ZN20DynamicHeapAllocatorI17LowLevelAllocatorE10ReallocateEPvji,__ZN14StackAllocator10ReallocateEPvji,__ZN12TLSAllocatorI14StackAllocatorE10ReallocateEPvji,__ZN15CacheWriterBase23WriteHeaderAndCloseFileEPvjj,__ZN9GfxDevice17BeginWriteIndicesEP11IndexBufferjj,__ZN9GfxDevice18BeginWriteVerticesEP12VertexBufferjj,__ZNK32RendererMaterialAnimationBinding15GenerateBindingERK8UnityStrbRN11UnityEngine9Animation14GenericBindingE,__ZNK32RendererMaterialAnimationBinding9BindValueER6ObjectRKN11UnityEngine9Animation14GenericBindingERNS3_10BoundCurveE,__ZNK24RendererAnimationBinding15GenerateBindingERK8UnityStrbRN11UnityEngine9Animation14GenericBindingE,__ZNK24RendererAnimationBinding9BindValueER6ObjectRKN11UnityEngine9Animation14GenericBindingERNS3_10BoundCurveE,__ZNK28MonoBehaviourPropertyBinding15GenerateBindingERK8UnityStrbRN11UnityEngine9Animation14GenericBindingE,__ZNK28MonoBehaviourPropertyBinding9BindValueER6ObjectRKN11UnityEngine9Animation14GenericBindingERNS3_10BoundCurveE,__ZN16MemoryFileSystem4OpenER13FileEntryData14FilePermission16FileAutoBehavior,__ZN16MemoryFileSystem9SetLengthER13FileEntryDatay,__ZN16MemoryFileSystem8SetFlagsER13FileEntryDatajj,__ZN10MemoryFile4SeekEy10FileOrigin,__ZN20LocalFileSystemPosix4OpenER13FileEntryData14FilePermission16FileAutoBehavior,__ZN20LocalFileSystemPosix9SetLengthER13FileEntryDatay,__ZN20LocalFileSystemPosix8SetFlagsER13FileEntryDatajj,__ZN13PhysicsModule24CreateNxMeshFromNxStreamEbPKvj,__ZN11AudioModule22CreateAudioClipFromWWWER3WWWbi
  ,__ZNK19TextRenderingModule29TMGenGetCursorIndexAtPositionEPN13TextRendering17TextMeshGeneratorERK5RectTIfERK8Vector2f,__Z9FTReallocP13FT_MemoryRec_llPv,__ZN13GfxDeviceGLES17BeginWriteIndicesEP11IndexBufferjj,__ZN13GfxDeviceGLES18BeginWriteVerticesEP12VertexBufferjj,__Z59AssemblyU002DCSharp_JSONObject_AddJSONConents_m_BeginInvokeP45AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z58AssemblyU002DCSharp_JSONObject_FieldNotFound_m_BeginInvokeP44AssemblyU002DCSharp_JSONObject_FieldNotFoundP22mscorlib_System_StringP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z61AssemblyU002DCSharp_JSONObject_GetFieldResponse_m_BeginInvokeP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z145AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_BooleanU0026_ref_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectPbP22mscorlib_System_Stringb,__Z166AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_BooleanU0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPbP22mscorlib_System_StringP44AssemblyU002DCSharp_JSONObject_FieldNotFound,__Z165AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_SingleU0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPfP22mscorlib_System_StringP44AssemblyU002DCSharp_JSONObject_FieldNotFound,__Z141AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_Int32U0026_ref_mscorlib_System_String_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjectPiP22mscorlib_System_Stringi,__Z164AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_Int32U0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPiP22mscorlib_System_StringP44AssemblyU002DCSharp_JSONObject_FieldNotFound,__Z143AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_UInt32U0026_ref_mscorlib_System_String_mscorlib_System_UInt32P30AssemblyU002DCSharp_JSONObjectPjP22mscorlib_System_Stringj,__Z165AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_UInt32U0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPjP22mscorlib_System_StringP44AssemblyU002DCSharp_JSONObject_FieldNotFound,__Z143AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_StringU0026_ref_mscorlib_System_String_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectPP22mscorlib_System_StringS2_S2_,__Z165AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Boolean_mscorlib_System_StringU0026_ref_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectPP22mscorlib_System_StringS2_P44AssemblyU002DCSharp_JSONObject_FieldNotFound,__ZL89System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_SlotsContainsAtP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectiiP22mscorlib_System_Object,__Z42mscorlib_System_ValueType_m_InternalEqualsP22mscorlib_System_ObjectS0_S0_PP26mscorlib_System_Object_arr,__Z155mscorlib_System_Attribute_m_GetCustomAttribute_mscorlib_System_Attribute_mscorlib_System_Reflection_MemberInfo_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoP20mscorlib_System_Typeb,__Z144mscorlib_System_Attribute_m_IsDefined_mscorlib_System_Boolean_mscorlib_System_Reflection_MemberInfo_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoP20mscorlib_System_Typeb,__Z147mscorlib_System_Attribute_m_IsDefined_mscorlib_System_Boolean_mscorlib_System_Reflection_ParameterInfo_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectP40mscorlib_System_Reflection_ParameterInfoP20mscorlib_System_Typeb,__Z34mscorlib_System_Int32_m_CheckStyleP22mscorlib_System_ObjectibPP25mscorlib_System_Exception,__Z33mscorlib_System_Int32_m_FindOtherP22mscorlib_System_ObjectPiP22mscorlib_System_StringS3_,__Z149mscorlib_System_Int32_m_Parse_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z149mscorlib_System_Int64_m_Parse_mscorlib_System_Int64_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z151mscorlib_System_UInt32_m_Parse_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z151mscorlib_System_UInt64_m_Parse_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z147mscorlib_System_Byte_m_Parse_mscorlib_System_Byte_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z149mscorlib_System_SByte_m_Parse_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z149mscorlib_System_Int16_m_Parse_mscorlib_System_Int16_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_
  ,__Z151mscorlib_System_UInt16_m_Parse_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z42mscorlib_System_String_m_FindNotWhiteSpaceP22mscorlib_System_Stringiii,__Z124mscorlib_System_String_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_BooleanP22mscorlib_System_ObjectP22mscorlib_System_StringS2_b,__Z44mscorlib_System_String_m_IndexOfAnyUncheckedP22mscorlib_System_StringP24mscorlib_System_Char_arrii,__Z48mscorlib_System_String_m_IndexOfOrdinalUncheckedP22mscorlib_System_StringS0_ii,__Z41mscorlib_System_String_m_IndexOfUncheckedP22mscorlib_System_Stringtii,__Z121mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringS0_ii,__Z125mscorlib_System_String_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringS0_ii,__Z40mscorlib_System_String_m_ReplaceFallbackP22mscorlib_System_StringS0_S0_i,__Z123mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectP22mscorlib_System_StringS0_S0_,__Z140mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_IFormatProvider_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectS0_P22mscorlib_System_StringP26mscorlib_System_Object_arr,__Z123mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_S0_S0_,__Z123mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_String_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_S2_,__Z135mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_SByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringPaii,__Z134mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringPtii,__Z133mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringP24mscorlib_System_Char_arrii,__Z38mscorlib_System_String_m_InternalSplitP22mscorlib_System_StringP24mscorlib_System_Char_arrii,__Z36mscorlib_System_Decimal_m_decimalDivP22mscorlib_System_ObjectP23mscorlib_System_DecimalS2_S2_,__Z39mscorlib_System_MulticastDelegate_m_KPMP22mscorlib_System_ObjectP33mscorlib_System_MulticastDelegateS2_PS2_,__Z40mscorlib_System_Enum_m_FormatSpecifier_XP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_b,__Z29mscorlib_System_Enum_m_FormatP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_P22mscorlib_System_String,__Z42mscorlib_System_Array_m_CreateInstanceImplP22mscorlib_System_ObjectP20mscorlib_System_TypeP25mscorlib_System_Int32_arrS4_,__Z121mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P21mscorlib_System_Arrayiii,__Z125mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP20mscorlib_System_Typeii,__Z141mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32_arr_arr_mscorlib_System_Int32_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP25mscorlib_System_Int32_arrS4_,__Z141mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_S0_,__Z120mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_i,__Z124mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_i,__Z137mscorlib_System_Array_m_compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectS0_S0_S0_,__Z41mscorlib_System_Type_m_internal_from_nameP22mscorlib_System_ObjectP22mscorlib_System_Stringbb
  ,__Z41mscorlib_System_Type_m_type_is_subtype_ofP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_b,__Z147mscorlib_System_Type_m_GetProperty_mscorlib_System_Reflection_PropertyInfo_mscorlib_System_String_mscorlib_System_Type_mscorlib_System_Type_arr_arrP20mscorlib_System_TypeP22mscorlib_System_StringS0_P24mscorlib_System_Type_arr,__Z43mscorlib_System_AsyncCallback_m_BeginInvokeP29mscorlib_System_AsyncCallbackP22mscorlib_System_ObjectS0_S2_,__Z182mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetContraction_mscorlib_Mono_Globalization_Unicode_Contraction_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_Stringii,__Z186mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetTailContraction_mscorlib_Mono_Globalization_Unicode_Contraction_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_Stringii,__Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_FilterExtenderP50mscorlib_Mono_Globalization_Unicode_SimpleCollatoriii,__Z176mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsPrefix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_i,__Z176mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsSuffix_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_i,__Z70mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_GetOptimizedLengthP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferP24mscorlib_System_Byte_arrih,__Z153mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Objectii,__Z136mscorlib_System_Collections_ArrayList_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListP22mscorlib_System_Objectii,__Z165mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Objectii,__Z164mscorlib_System_Globalization_CompareInfo_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_i,__Z50mscorlib_System_Diagnostics_StackTrace_m_get_traceP22mscorlib_System_ObjectP25mscorlib_System_Exceptionib,__Z46mscorlib_System_Globalization_CCMath_m_div_modP22mscorlib_System_ObjectPiii,__Z66mscorlib_System_Globalization_CCGregorianCalendar_m_fixed_from_dmyP22mscorlib_System_Objectiii,__Z52mscorlib_System_Globalization_CompareInfo_m_IsPrefixP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_i,__Z52mscorlib_System_Globalization_CompareInfo_m_IsSuffixP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_i,__Z65mscorlib_System_Reflection_Assembly_m_GetManifestResourceInternalP35mscorlib_System_Reflection_AssemblyP22mscorlib_System_StringPiPP33mscorlib_System_Reflection_Module,__Z137mscorlib_System_Reflection_Assembly_m_GetType_mscorlib_System_Type_mscorlib_System_String_mscorlib_System_Boolean_mscorlib_System_BooleanP35mscorlib_System_Reflection_AssemblyP22mscorlib_System_Stringbb,__Z54mscorlib_System_Reflection_Binder_Default_m_ChangeTypeP41mscorlib_System_Reflection_Binder_DefaultP22mscorlib_System_ObjectP20mscorlib_System_TypeP41mscorlib_System_Globalization_CultureInfo,__Z59mscorlib_System_Reflection_Binder_Default_m_check_argumentsP22mscorlib_System_ObjectP24mscorlib_System_Type_arrP44mscorlib_System_Reflection_ParameterInfo_arrb,__Z59mscorlib_System_Reflection_Binder_Default_m_GetBetterMethodP41mscorlib_System_Reflection_Binder_DefaultP37mscorlib_System_Reflection_MethodBaseS2_P24mscorlib_System_Type_arr,__Z54mscorlib_System_Reflection_MonoMethod_m_InternalInvokeP37mscorlib_System_Reflection_MonoMethodP22mscorlib_System_ObjectP26mscorlib_System_Object_arrPP25mscorlib_System_Exception,__Z55mscorlib_System_Reflection_MonoCMethod_m_InternalInvokeP38mscorlib_System_Reflection_MonoCMethodP22mscorlib_System_ObjectP26mscorlib_System_Object_arrPP25mscorlib_System_Exception,__Z67mscorlib_System_Reflection_MonoProperty_GetterAdapter_m_BeginInvokeP53mscorlib_System_Reflection_MonoProperty_GetterAdapterP22mscorlib_System_ObjectP29mscorlib_System_AsyncCallbackS2_,__Z87mscorlib_System_Runtime_Remoting_Activation_ActivationServices_m_CreateConstructionCallP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringP26mscorlib_System_Object_arr,__Z73mscorlib_System_Runtime_Remoting_RemotingServices_m_GetMethodBaseFromNameP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringP24mscorlib_System_Type_arr,__Z71mscorlib_System_Runtime_Remoting_RemotingServices_m_FindInterfaceMethodP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringP24mscorlib_System_Type_arr,__Z81mscorlib_System_Runtime_Remoting_RemotingServices_m_CreateWellKnownServerIdentityP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_Stringi
  ,__Z167mscorlib_System_Security_Cryptography_HashAlgorithm_m_ComputeHash_mscorlib_System_Byte_arr_arr_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P51mscorlib_System_Security_Cryptography_HashAlgorithmP24mscorlib_System_Byte_arrii,__Z144mscorlib_System_Text_ASCIIEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Char_arrii,__Z49mscorlib_System_Text_ASCIIEncoding_m_GetCharCountP34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Byte_arrii,__Z46mscorlib_System_Text_ASCIIEncoding_m_GetStringP34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Byte_arrii,__Z150mscorlib_System_Text_EncoderExceptionFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Char_mscorlib_System_Char_mscorlib_System_Int32P51mscorlib_System_Text_EncoderExceptionFallbackBuffertti,__Z152mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Char_mscorlib_System_Char_mscorlib_System_Int32P53mscorlib_System_Text_EncoderReplacementFallbackBuffertti,__Z142mscorlib_System_Text_Encoding_m_GetBytes_mscorlib_System_Byte_arr_arr_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P29mscorlib_System_Text_EncodingP24mscorlib_System_Char_arrii,__Z142mscorlib_System_Text_Encoding_m_GetChars_mscorlib_System_Char_arr_arr_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P29mscorlib_System_Text_EncodingP24mscorlib_System_Byte_arrii,__Z137mscorlib_System_Text_Encoding_m_GetString_mscorlib_System_String_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P29mscorlib_System_Text_EncodingP24mscorlib_System_Byte_arrii,__Z145mscorlib_System_Text_Latin1Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Char_arrii,__Z50mscorlib_System_Text_Latin1Encoding_m_GetCharCountP35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Byte_arrii,__Z143mscorlib_System_Text_Latin1Encoding_m_GetString_mscorlib_System_String_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Byte_arrii,__Z145mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderP22mscorlib_System_Stringii,__Z170mscorlib_System_Text_StringBuilder_m_AppendFormat_mscorlib_System_Text_StringBuilder_mscorlib_System_IFormatProvider_mscorlib_System_String_mscorlib_System_Object_arr_arrP34mscorlib_System_Text_StringBuilderP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr,__Z153mscorlib_System_Text_StringBuilder_m_AppendFormat_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringP22mscorlib_System_ObjectS4_,__Z145mscorlib_System_Text_StringBuilder_m_Insert_mscorlib_System_Text_StringBuilder_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderiP22mscorlib_System_Stringi,__Z144mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Char_arrii,__Z49mscorlib_System_Text_UTF32Encoding_m_GetCharCountP34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Byte_arrii,__Z46mscorlib_System_Text_UTF32Encoding_m_GetStringP34mscorlib_System_Text_UTF32EncodingP24mscorlib_System_Byte_arrii,__Z143mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Char_arrii,__Z48mscorlib_System_Text_UTF7Encoding_m_GetCharCountP33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Byte_arrii,__Z45mscorlib_System_Text_UTF7Encoding_m_GetStringP33mscorlib_System_Text_UTF7EncodingP24mscorlib_System_Byte_arrii,__Z143mscorlib_System_Text_UTF8Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Char_arrii,__Z48mscorlib_System_Text_UTF8Encoding_m_GetCharCountP33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Byte_arrii,__Z45mscorlib_System_Text_UTF8Encoding_m_GetStringP33mscorlib_System_Text_UTF8EncodingP24mscorlib_System_Byte_arrii,__Z146mscorlib_System_Text_UnicodeEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Char_arrii,__Z51mscorlib_System_Text_UnicodeEncoding_m_GetCharCountP36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Byte_arrii,__Z48mscorlib_System_Text_UnicodeEncoding_m_GetStringP36mscorlib_System_Text_UnicodeEncodingP24mscorlib_System_Byte_arrii,__Z55mscorlib_System_Threading_Interlocked_m_CompareExchangeP22mscorlib_System_ObjectPiii,__Z148mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_Type_mscorlib_System_Object_arr_arr_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP26mscorlib_System_Object_arrS4_
  ,__Z39mscorlib_System_DateTime_m_AbsoluteDaysP22mscorlib_System_Objectiii,__Z46mscorlib_System_DateTime_m_YearMonthDayFormatsP22mscorlib_System_ObjectP48mscorlib_System_Globalization_DateTimeFormatInfobPP25mscorlib_System_Exception,__Z43mscorlib_System_DateTimeUtils_m_CountRepeatP22mscorlib_System_ObjectP22mscorlib_System_Stringit,__Z49mscorlib_System_DateTimeUtils_m_ParseQuotedStringP22mscorlib_System_ObjectP22mscorlib_System_StringiP34mscorlib_System_Text_StringBuilder,__Z160mscorlib_System_DateTimeUtils_m_ToString_mscorlib_System_String_mscorlib_System_DateTime_mscorlib_System_String_mscorlib_System_Globalization_DateTimeFormatInfoP22mscorlib_System_Object24mscorlib_System_DateTimeP22mscorlib_System_StringP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z35mscorlib_System_Guid_m_BaseToStringP20mscorlib_System_Guidbbb,__Z61mscorlib_System_MonoCustomAttrs_m_GetCustomAttributesInternalP22mscorlib_System_ObjectS0_P20mscorlib_System_Typeb,__Z52mscorlib_System_MonoCustomAttrs_m_GetCustomAttributeP22mscorlib_System_ObjectS0_P20mscorlib_System_Typeb,__Z181mscorlib_System_MonoCustomAttrs_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Reflection_ICustomAttributeProvider_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectS0_P20mscorlib_System_Typeb,__Z43mscorlib_System_MonoCustomAttrs_m_IsDefinedP22mscorlib_System_ObjectS0_P20mscorlib_System_Typeb,__Z148mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_SByte_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringaS0_,__Z147mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Byte_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringhS0_,__Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_UInt16_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringtS0_,__Z148mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int16_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringsS0_,__Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_UInt32_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringjS0_,__Z148mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z150mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Decimal_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_String23mscorlib_System_DecimalS0_,__Z126mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_UInt64_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectyS0_,__Z125mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_Int64_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectxS0_,__Z165mscorlib_System_NumberFormatter_m_FormatExponential_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Globalization_NumberFormatInfo_mscorlib_System_Int32P31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfoi,__Z55mscorlib_System_CurrentSystemTimeZone_m_GetTimeZoneDataP22mscorlib_System_ObjectiPP25mscorlib_System_Int64_arrPP26mscorlib_System_String_arr,__Z50mscorlib_System_AppDomainInitializer_m_BeginInvokeP36mscorlib_System_AppDomainInitializerP26mscorlib_System_String_arrP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z53UnityEngine_UnityEngine_SetupCoroutine_m_InvokeMemberP22mscorlib_System_ObjectS0_P22mscorlib_System_StringS0_,__Z53UnityEngine_UnityEngine_SetupCoroutine_m_InvokeStaticP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringS0_,__Z56UnityEngine_UnityEngine_GUI_WindowFunction_m_BeginInvokeP42UnityEngine_UnityEngine_GUI_WindowFunctioniP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z54UnityEngine_UnityEngine_Bounds_m_Internal_IntersectRayP22mscorlib_System_ObjectP27UnityEngine_UnityEngine_RayP30UnityEngine_UnityEngine_BoundsPf,__Z68UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_IntersectRayP22mscorlib_System_ObjectP27UnityEngine_UnityEngine_RayP30UnityEngine_UnityEngine_BoundsPf,__Z59UnityEngine_UnityEngine_Camera_CameraCallback_m_BeginInvokeP45UnityEngine_UnityEngine_Camera_CameraCallbackP30UnityEngine_UnityEngine_CameraP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z65UnityEngine_UnityEngine_AudioClip_PCMReaderCallback_m_BeginInvokeP51UnityEngine_UnityEngine_AudioClip_PCMReaderCallbackP26mscorlib_System_Single_arrP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z70UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallback_m_BeginInvokeP56UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallbackiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object
  ,__Z93mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt64_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP26mscorlib_System_UInt64_arry,__ZNKSt3__15ctypeIcE8do_widenEPKcS3_Pc,__ZNKSt3__15ctypeIwE5do_isEPKwS3_Pt,__ZNKSt3__15ctypeIwE10do_scan_isEtPKwS3_,__ZNKSt3__15ctypeIwE11do_scan_notEtPKwS3_,__ZNKSt3__15ctypeIwE8do_widenEPKcS3_Pw,__ZN6il2cpp6icalls8mscorlib6System9AppDomain12LoadAssemblyEP15Il2CppAppDomainP12Il2CppStringP40mscorlib_System_Security_Policy_Evidenceb,__ZN6il2cpp6icalls8mscorlib6System7Decimal14string2decimalEP19il2cpp_decimal_reprP12Il2CppStringji,__ZN6il2cpp6icalls8mscorlib6System8Delegate23CreateDelegate_internalEP20Il2CppReflectionTypeP12Il2CppObjectP22Il2CppReflectionMethodb,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO13CopyFileICallEP12Il2CppStringS6_bPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO9SetLengthE12Il2CppIntPtrxPi,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly27GetManifestResourceInternalEP35mscorlib_System_Reflection_AssemblyP12Il2CppStringPiPP33mscorlib_System_Reflection_Module,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod14InternalInvokeEP22Il2CppReflectionMethodP12Il2CppObjectP11Il2CppArrayPS8_,__ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting16RemotingServices15InternalExecuteEP22Il2CppReflectionMethodP12Il2CppObjectP11Il2CppArrayPSB_,__ZN6il2cpp6icalls8mscorlib6System6String13InternalSplitEP12Il2CppStringP11Il2CppArrayii,__ZN6il2cpp6icalls8mscorlib6System9Threading16NativeEventCalls20CreateEvent_internalEbbP12Il2CppStringPb,__ZN6il2cpp6icalls8mscorlib6System9Threading10WaitHandle22SignalAndWait_InternalE12Il2CppIntPtrS5_ib,__ZN6il2cpp6icalls8mscorlib6System9Threading10WaitHandle16WaitOne_internalEP12Il2CppObject12Il2CppIntPtrib,__ZN6il2cpp6icalls6System6System9Threading9Semaphore24CreateSemaphore_internalEiiP12Il2CppStringPb,__ZN12_GLOBAL__N_111createClothERKN5physx11PxTransformERNS0_13PxClothFabricEPKNS0_15PxClothParticleENS0_7PxFlagsINS0_11PxClothFlag4EnumEtEE,__ZN5physx10PxsContext21addParticleSystemImplEPNS_15PxsParticleDataERKNS_26PxvParticleSystemParameterEb,__ZN17PersistentManager30GetInstanceIDFromPathAndFileIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEx,__ZN6Object7ProduceEii10MemLabelId18ObjectCreationMode,__Z19RenderBasePassDepthRK17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EERS2_I17PrePassRenderDataLj4EERN9ShaderLab17ShaderPassContextE,__ZN5Unity8Material29SetShadowCasterPassWithShaderEP6ShaderRN9ShaderLab17ShaderPassContextEi,__ZN10Matrix4x4f18SetBasisTransposedERK8Vector3fS2_S2_,__ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfo16MeshVertexFormatEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEENS_9allocatorIS4_EEE12__find_equalIS4_EERPNS_16__tree_node_baseIPvEENS_21__tree_const_iteratorIS4_PNS_11__tree_nodeIS4_SE_EEiEESH_RKT_,__ZN9Texture2D22GetWriteImageReferenceEP14ImageReferenceii,__Z18ConvertUTF16toUTF8PKtiPcRi,_il2cpp_runtime_invoke
  ,_png_create_write_struct,__ZN18AssetBundleManager18CollectPreloadDataEiRKNSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEER13dynamic_arrayIiLj4EE,__ZN4File4OpenERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS_10PermissionENS_12AutoBehaviorE,__ZN5Cache17ReadCacheInfoFileERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEPlS9_,__Z36scripting_liveness_calculation_beginP14ScriptingClassiPFvPPviS1_ES1_,__Z15WeldVertexArrayR13dynamic_arrayI8Vector3fLj4EERS_I13BoneInfluenceLj16EERS_ItLj2EES7_,__Z24TransferPPtrToMonoObjectiP14ScriptingClassP23DataToCreateNullWrapper24TransferInstructionFlags,__ZL34GetComponentsImplementationRecurseILb1ELi1ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZL34GetComponentsImplementationRecurseILb1ELi1ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZL27GetComponentsImplementationILb0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZL27GetComponentsImplementationILb0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZL34GetComponentsImplementationRecurseILb1ELi0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZL34GetComponentsImplementationRecurseILb1ELi0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZN12FileAccessor4OpenER15FileSystemEntry14FilePermission16FileAutoBehavior,__ZN4File19OpenFileSystemEntryERK15FileSystemEntryNS_10PermissionENS_12AutoBehaviorE,__ZN12FileAccessor4OpenEPKc14FilePermission16FileAutoBehavior,__ZN9ShaderLab11shaderprops8GetFloatEPKNS_13PropertySheetERKNS_17ShaderPassContextENS_16FastPropertyNameERNS0_16PropertyLocationE,__ZN11RadixSorter4SortEPjjb,__Z34Display_CUSTOM_RelativeMouseAtImpliiPiS_,__ZN9Scripting20SendScriptingMessageERN5Unity10GameObjectERKNSt3__112basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEEP15ScriptingObjecti,__ZN5physx19PxClothFabricCreateERNS_9PxPhysicsERKNS_15PxClothMeshDescERKNS_6PxVec3Eb,__Z19ExtractDataFromMeshR4MeshR13dynamic_arrayI8Vector3fLj4EERS1_ItLj2EES6_,__ZN20SoundChannelInstance8setDelayE14FMOD_DELAYTYPEjj,__Z15_CheckFMODError11FMOD_RESULTPKciS1_,__ZN9AudioClip28ScriptPCMSetPositionCallbackEP10FMOD_SOUNDijj,__ZL50UnityAudioEffect_InternalGetFloatParameterCallbackP14FMOD_DSP_STATEiPfPc,__ZN12AudioManager14systemCallbackEP11FMOD_SYSTEM24FMOD_SYSTEM_CALLBACKTYPEPvS3_,__ZN29AudioEffectInternalDefinition9CreateDSPEPN4FMOD6SystemEPvPf,__Z39AudioMixerDuckingGetFloatBufferCallbackP21UnityAudioEffectStatePKcPfi,__ZN20SoundChannelInstance19FMODChannelCallbackEP12FMOD_CHANNEL25FMOD_CHANNEL_CALLBACKTYPEPvS3_
  ,__ZN11UnityEngine9Animation28GenericAnimationBindingCache11BindGenericERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE,__ZN11UnityEngine9Animation28GenericAnimationBindingCache15BindPPtrGenericERKNS0_14GenericBindingER9TransformRNS0_10BoundCurveE,__Z15HiearchyMatchesP9TransformPKN7mecanim8skeleton8SkeletonEiRKNS1_5crc32E,__ZN7mecanim9animation19CreateBlendingStateEjbbRNS_6memory9AllocatorE,__ZNK9Texture2D11GetPixels32EiP11ColorRGBA32i,_FT_New_Face,__ZN20TextRenderingPrivate15DynamicFontData36GetFaceForCharacterIfAvailableInFontERNS_7FontRefERNSt3__16vectorI4PPtrINS_4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEEj,__ZN20TextRenderingPrivate4Font21HasCharacterInTextureEjij,__ZN20TextRenderingPrivate4Font21AddCharacterToTextureEjij,_ft_ansi_stream_io,_cff_get_glyph_name,_cff_get_ros,_Load_Glyph,_cff_get_kerning,_sfnt_get_glyph_name,_tt_face_goto_table,_tt_face_load_sfnt_header_stub,_tt_face_set_sbit_strike_stub,_tt_cmap14_char_var_index,_gray_cubic_to,_ft_smooth_render,_ft_smooth_transform,_Load_Glyph20750,_tt_get_kerning,_TT_Access_Glyph_Frame,_ps_hints_apply,_ft_raster1_render,_ft_raster1_transform,__ZN18GlslGpuProgramGLES14CompileProgramERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_R14ChannelAssigns,__ZN16VirtFuncInvoker2I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS5_
  ,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS6_,__ZN21InterfaceFuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS1_E6InvokeEP10MethodInfoPvtt,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS1_E6InvokeEP10MethodInfoPvii,__ZN21InterfaceFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_,__ZN21InterfaceFuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS1_E6InvokeEP10MethodInfoPvii,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsS1_E6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpanS6_,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsS1_E6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpanS6_,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UILineInfoTraitsS1_E6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UILineInfoS6_,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPviS6_,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsS1_E6InvokeEP10MethodInfoPvjj,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsS1_E6InvokeEP10MethodInfoPvtt,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsS1_E6InvokeEP10MethodInfoPvhh,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsE6InvokeEP10MethodInfoPvy,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS5_b,__ZN21InterfaceFuncInvoker2I17VoidPointerTraitsS0_S0_E6InvokeEP10MethodInfoPvS4_S4_,__ZN16VirtFuncInvoker2I17VoidPointerTraitsS0_S0_E6InvokeEP10MethodInfoPvS4_S4_,__ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS0_E6InvokeEP10MethodInfoPvP22mscorlib_System_Objecti,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_,__ZN16VirtFuncInvoker2I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvS5_b,__ZN16VirtFuncInvoker2I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS5_i,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvti,__ZN16VirtFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_i,__ZN16VirtFuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS5_i,__ZN21InterfaceFuncInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_,__ZN21InterfaceFuncInvoker2I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvS5_b
  ,__ZN21InterfaceFuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS5_b,__ZN16VirtFuncInvoker2I28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS6_,__ZN16VirtFuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_E6InvokeEP10MethodInfoPviS5_,__ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsS1_E6InvokeEP10MethodInfoPvjj,__ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsS1_E6InvokeEP10MethodInfoPvtt,__ZN21InterfaceFuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsS1_E6InvokeEP10MethodInfoPvhh,__ZNSt3__125__num_get_signed_integralIlEET_PKcS3_Rji,__ZNSt3__125__num_get_signed_integralIxEET_PKcS3_Rji,__ZNSt3__127__num_get_unsigned_integralItEET_PKcS3_Rji,__ZNSt3__127__num_get_unsigned_integralIjEET_PKcS3_Rji,__ZNSt3__127__num_get_unsigned_integralImEET_PKcS3_Rji,__ZNSt3__127__num_get_unsigned_integralIyEET_PKcS3_Rji,__ZNSt3__110__sscanf_lEPKcP15__locale_structS1_z,__ZNSt3__112__asprintf_lEPPcP15__locale_structPKcz,_mbsrtowcs,_catgets__wrapper,_mbrtowc,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
  ,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
  ,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
  ,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
  ,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
  ,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40,b40
  ,b40,b40,b40];
  var FUNCTION_TABLE_iiifii = [b41,__ZN12PhysXRaycast7RaycastERK3RayfiR10RaycastHit];
  var FUNCTION_TABLE_fifff = [b42,__Z37UnityEngine_UnityEngine_Mathf_m_ClampP22mscorlib_System_Objectfff,__Z36UnityEngine_UnityEngine_Mathf_m_LerpP22mscorlib_System_Objectfff,b42];
  var FUNCTION_TABLE_viffi = [b43,__ZNK6Camera27GetImplicitProjectionMatrixEffR10Matrix4x4f,__Z17GetFrustumPortionPK8Vector3fffPS_,b43];
  var FUNCTION_TABLE_viiiiid = [b44,__ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd,__ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce,__ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd,__ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe,b44,b44,b44];
  var FUNCTION_TABLE_iiiifiiii = [b45,__ZNK5physx13NpVolumeCache7raycastERKNS_6PxVec3ES3_fRNS_13PxHitCallbackINS_12PxRaycastHitEEENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackE];
  var FUNCTION_TABLE_vifi = [b46,__ZN5physx3Cct26CharacterControllerManager19computeInteractionsEfPNS_26PxControllerFilterCallbackE,__ZNK6Camera25GetSkyboxProjectionMatrixEfR10Matrix4x4f,__ZN14AvatarPlayback11RecordFrameEfPKN7mecanim9animation12AvatarMemoryE];
  var FUNCTION_TABLE_vifff = [b47,__ZN9GfxDevice15ImmediateVertexEfff,__ZN9GfxDevice15ImmediateNormalEfff,__ZN9GfxDevice20ImmediateTexCoordAllEfff,__Z39UnityEngine_UnityEngine_Vector3_m__ctorP31UnityEngine_UnityEngine_Vector3fff,__Z127UnityEngine_UnityEngine_Color_m__ctor_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP29UnityEngine_UnityEngine_Colorfff,__Z132UnityEngine_UnityEngine_Transform_m_Rotate_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP33UnityEngine_UnityEngine_Transformfff,_emscripten_glUniform3f__wrapper,_emscripten_glVertexAttrib3f__wrapper,b47,b47,b47,b47,b47,b47,b47];
  var FUNCTION_TABLE_viiiiii = [b48,__ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekoffExNS_8ios_base7seekdirEj,__ZNK5physx7NpCloth16getCollisionDataEPNS_22PxClothCollisionSphereEPjPNS_21PxClothCollisionPlaneES3_PNS_24PxClothCollisionTriangleE,__ZN5physx20PxsParticleSystemSim15addInteractionVERKNS_16PxvParticleShapeEjjbb,__ZN5physx26solveContactBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx21solve1DBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx34solveContact_BStaticBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx30solveContactPreBlock_WriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx36solveContactPreBlock_WriteBackStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx23solve1D4Block_WriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx33solveContactCoulombBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx41solveContactCoulomb_BStaticBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx37solveContactCoulombPreBlock_WriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx43solveContactCoulombPreBlock_WriteBackStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx27solveFrictionBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx35solveFriction_BStaticBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx38solveFrictionCoulombPreBlock_WriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx44solveFrictionCoulombPreBlock_WriteBackStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx18RepXSerializerImplINS_16PxVehicleDrive4WEE12objectToFileERKNS_12PxRepXObjectEPNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEE12fileToObjectERNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEE16objectToFileImplEPKS1_PNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE,__ZN5physx18RepXSerializerImplINS_16PxVehicleDrive4WEE16fileToObjectImplEPS1_RNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE,__ZN5physx18RepXSerializerImplINS_18PxVehicleDriveTankEE12objectToFileERKNS_12PxRepXObjectEPNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE,__ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEE12fileToObjectERNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE,__ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEE16objectToFileImplEPKS1_PNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE,__ZN5physx18RepXSerializerImplINS_18PxVehicleDriveTankEE16fileToObjectImplEPS1_RNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE,__ZN5physx18RepXSerializerImplINS_16PxVehicleDriveNWEE12objectToFileERKNS_12PxRepXObjectEPNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEE12fileToObjectERNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEE16objectToFileImplEPKS1_PNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE
  ,__ZN5physx18RepXSerializerImplINS_16PxVehicleDriveNWEE16fileToObjectImplEPS1_RNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE,__ZN5physx18RepXSerializerImplINS_16PxVehicleNoDriveEE12objectToFileERKNS_12PxRepXObjectEPNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEE12fileToObjectERNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEE16objectToFileImplEPKS1_PNS_12PxCollectionERNS_9XmlWriterERNS_12MemoryBufferERNS_23PxRepXInstantiationArgsE,__ZN5physx18RepXSerializerImplINS_16PxVehicleNoDriveEE16fileToObjectImplEPS1_RNS_9XmlReaderERNS_18XmlMemoryAllocatorERNS_23PxRepXInstantiationArgsEPNS_12PxCollectionE,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10eventValueEtyx,__ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10eventValueEtyx,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_E18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES7_S7_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_E18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES7_S7_,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_E18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES7_S7_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEE18doWarmStartSupportEiiRNS_6shdfnd3aos5Vec3VES8_S8_,__ZN9GfxDevice17EndStaticBatchingEPK18VertexStreamSourcejP17VertexDeclarationRK10Matrix4x4fi,__Z32mscorlib_System_Int32_m_FindSignP22mscorlib_System_ObjectPiP22mscorlib_System_StringP46mscorlib_System_Globalization_NumberFormatInfoPbS6_,__Z166mscorlib_System_String_m_CharCopy_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP22mscorlib_System_StringiS2_ii,__Z173mscorlib_System_String_m_CharCopyReverse_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP22mscorlib_System_StringiS2_ii,__Z163mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_System_ByteP23mscorlib_System_Decimaliiibh,__Z120mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64P21mscorlib_System_ArrayP22mscorlib_System_Objectxx,__Z159mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii,__Z175mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_iiS0_,__Z176mscorlib_System_Array_m_qsort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_iiS0_,__Z39mscorlib_System_Array_m_ConstrainedCopyP22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii
  ,__Z73mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributehhjjj,__Z246mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetSortKey_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferi,__Z55mscorlib_System_Reflection_Emit_FieldBuilder_m_SetValueP44mscorlib_System_Reflection_Emit_FieldBuilderP22mscorlib_System_ObjectS2_iP33mscorlib_System_Reflection_BinderP41mscorlib_System_Globalization_CultureInfo,__Z251mscorlib_System_Reflection_MemberInfoSerializationHolder_m_Serialize_mscorlib_System_Void_mscorlib_System_Runtime_Serialization_SerializationInfo_mscorlib_System_String_mscorlib_System_Type_mscorlib_System_String_mscorlib_System_Reflection_MemberTypesP22mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_StringP20mscorlib_System_TypeS4_i,__Z47mscorlib_System_Reflection_MonoField_m_SetValueP36mscorlib_System_Reflection_MonoFieldP22mscorlib_System_ObjectS2_iP33mscorlib_System_Reflection_BinderP41mscorlib_System_Globalization_CultureInfo,__Z174mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderP22mscorlib_System_Stringiiii,__Z34mscorlib_System_Buffer_m_BlockCopyP22mscorlib_System_ObjectP21mscorlib_System_ArrayiS2_ii,__Z61mscorlib_System_NumberFormatter_CustomInfo_m_GetActiveSectionP22mscorlib_System_ObjectP22mscorlib_System_StringPbbPiS4_,__Z163mscorlib_System_TimeSpan_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P24mscorlib_System_TimeSpaniiiii,__Z36mscorlib_System_Version_m_CheckedSetP23mscorlib_System_Versioniiiii,__Z47UnityEngine_UnityEngine_Display_m_SetParamsImplP22mscorlib_System_Object22mscorlib_System_IntPtriiii,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj,__ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb,__ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl,__ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm,__ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv,__ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb,__ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl,__ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm,__ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv,__ZNKSt3__18messagesIcE6do_getEiiiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZNKSt3__18messagesIwE6do_getEiiiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE,__ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,__ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,__ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,__ZN6il2cpp6icalls8mscorlib4Mono13Globalization7Unicode13Normalization27load_normalization_resourceEP12Il2CppIntPtrS7_S7_S7_S7_S7_,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO4LockE12Il2CppIntPtrxxPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO6UnlockE12Il2CppIntPtrxxPi,__ZN6il2cpp6icalls8mscorlib6System15NumberFormatter18GetFormatterTablesEPPyPPiPPsS9_PPxS7_
  ,__ZN6il2cpp6icalls8mscorlib6System10Reflection16MonoGenericClass10initializeEP43mscorlib_System_Reflection_MonoGenericClassP11Il2CppArrayS8_S8_S8_S8_,__ZN5physx29solveExtContactBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx24solveExt1DBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx36solveExtContactCoulombBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZN5physx30solveExtFrictionBlockWriteBackEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextEPNS_25PxcThresholdStreamElementEjPi,__ZL28HullProjectionCB_SmallConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_,__ZL26HullProjectionCB_BigConvexRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_,__ZL20HullProjectionCB_BoxRKN5physx2Gu13PolygonalDataERKNS_6PxVec3ERKNS_2Cm8Matrix34ERKNS7_23FastVertex2ShapeScalingERfSE_,__ZdlPv10MemLabelIdbiPKci,__ZN10MemoryPoolC2EbPKcii10MemLabelId,__ZNK23ForwardShaderRenderLoop19SetLightShadowPropsERK5LightP7TextureRK10Matrix4x4fbRN9ShaderLab17ShaderPassContextE,__ZN12LightManager26FindForwardLightsForObjectER13dynamic_arrayIhLj1EEPK11CulledLightjRK12ActiveLightsRK11VisibleNodeRK23FindForwardLightsParams,__ZN12LightManager25FindVertexLightsForObjectER13dynamic_arrayIhLj1EEP11CulledLightjRK12ActiveLightsRK11VisibleNode,__Z31ResolveDepthIntoTextureIfNeededR9GfxDeviceR10RenderLoop17DepthBufferFormatRP13RenderTextureP9TextureIDPb,__ZN12ImageFilters4BlitEP7TextureP13RenderTexturePN5Unity8MaterialEib11CubemapFace,__Z25DoForwardVertexRenderLoopR17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EEbR12ActiveLightsbb,__ZN6Camera23SetTargetTextureBuffersEP13RenderTextureiP12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES6_S1_,__Z23CullDirectionalCascadesRNSt3__16vectorI16ShadowCasterData13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEEPK17ShadowCascadeInfoiRK11QuaternionfRK8Vector3fRK14ShadowCullData,__ZN4Mesh14ResizeVerticesEjjjRK20VertexChannelsLayoutRK19VertexStreamsLayout,__ZNK14ImageReference9ClipImageEiiii,__Z28BlitCopyCompressedDXT1ToDXT5PKhiiPhii,__ZNSt3__113__stable_sortIRN10vector_mapIijNS_4lessIiEENS_9allocatorINS_4pairIijEEEEE13value_compareENS_11__wrap_iterIPS6_EEEEvT0_SE_T_NS_15iterator_traitsISE_E15difference_typeEPNSH_10value_typeEi,__Z14EmptyNormalMapP9Texture2DPhiiii,__Z5WhiteP9Texture2DPhiiii,__Z5BlackP9Texture2DPhiiii,__Z14RandomRotationP9Texture2DPhiiii,__Z3RedP9Texture2DPhiiii,__Z4GrayP9Texture2DPhiiii,__Z13GrayscaleRampP9Texture2DPhiiii,__Z7HaloTexP9Texture2DPhiiii
  ,__Z16LightAttenuationItEvP9Texture2DPT_iiii,__Z16LightAttenuationIhEvP9Texture2DPT_iiii,__Z7Empty2DP9Texture2DPhiiii,__Z12NHxRoughnessItEvP9Texture2DPT_iiii,__Z12NHxRoughnessIhEvP9Texture2DPT_iiii,__ZN6prcore7SurfaceC2EjjjRKNS_11PixelFormatEPv,__ZN14ImageReferenceC2Eiii13TextureFormatPv,__Z14GUIClipTextureP9Texture2DPhiiii,__ZNSt3__113__stable_sortIRN10vector_mapIP14ScriptingClassiNS_4lessIS3_EENS_9allocatorINS_4pairIS3_iEEEEE13value_compareENS_11__wrap_iterIPS8_EEEEvT0_SG_T_NS_15iterator_traitsISG_E15difference_typeEPNSJ_10value_typeEi,__ZL20ShaderWarmupFuncImplP6ShaderiPN9ShaderLab4PassERK16ShaderKeywordSetP10DynamicVBOPv,__Z18TransformPoints3x3RK10Matrix4x4fPK8Vector3fjPS2_ji,__ZN15AnimationBinder10BindCurvesERK14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEER9TransformR13dynamic_arrayI20BoundCurveDeprecatedLj4EERNS3_6vectorIPSF_S6_ISM_LSA_18ELi16EEEERi,__ZN7mecanim9animation22EvaluateAvatarRetargetEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantE,__ZN7mecanim9animation17EvaluateAvatarEndEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantE,__ZN23LODTreeInstanceRendererC2ER12TreeRendereriR12MeshRendererRK10Matrix4x4fi,__ZN29BillboardTreeInstanceRendererC2ER12TreeRendereriiib,_Vertical_Sweep_Span,_Vertical_Sweep_Drop,_Horizontal_Sweep_Span,_Horizontal_Sweep_Drop,_glVertexAttribPointer__wrapper,__ZL29glVertexAttribPointerOverridejijhiPKv,__ZN18VirtActionInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_E6InvokeEP10MethodInfoPviS5_ii,_emscripten_glDrawRangeElements__wrapper,_emscripten_glVertexAttribPointer__wrapper,b48,b48,b48,b48,b48
  ,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
  ,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
  ,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48
  ,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48,b48];
  var FUNCTION_TABLE_ddd = [b49,__ZN6il2cpp6icalls8mscorlib6System4Math5Atan2Edd,__ZN6il2cpp6icalls8mscorlib6System4Math3PowEdd,_fmod__wrapper];
  var FUNCTION_TABLE_fiii = [b50,__Z108mscorlib_System_Single_m_Parse_mscorlib_System_Single_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z79mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_Int64P22mscorlib_System_Objectx,__Z112mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z80mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt64P22mscorlib_System_Objecty,__Z112mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__Z57UnityEngine_UnityEngine_TextGenerator_m_GetPreferredWidthP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_String46UnityEngine_UnityEngine_TextGenerationSettings,__Z58UnityEngine_UnityEngine_TextGenerator_m_GetPreferredHeightP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_String46UnityEngine_UnityEngine_TextGenerationSettings,__Z37UnityEngine_UnityEngine_Vector3_m_DotP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z39UnityEngine_UnityEngine_Vector3_m_AngleP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z111UnityEngine_UnityEngine_Matrix4x4_m_get_Item_mscorlib_System_Single_mscorlib_System_Int32_mscorlib_System_Int32P33UnityEngine_UnityEngine_Matrix4x4ii,__Z53UnityEngine_UnityEngine_Bounds_m_Internal_SqrDistanceP22mscorlib_System_Object30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z67UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_SqrDistanceP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_BoundsP31UnityEngine_UnityEngine_Vector3,__Z37UnityEngine_UnityEngine_Vector4_m_DotP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4S1_,__ZN5physx23GetMFrictionVsSlipGraphEPKNS_17PxVehicleTireDataEjj,__ZN16VirtFuncInvoker1I28mscorlib_System_SingleTraits29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb,__ZN16VirtFuncInvoker1I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEP10MethodInfoPv31UnityEngine_UnityEngine_Vector3,__ZN21InterfaceFuncInvoker1I28mscorlib_System_SingleTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZNSt3__115__num_get_floatIfEET_PKcS3_Rj,b50,b50,b50,b50,b50,b50,b50,b50,b50,b50
  ,b50,b50,b50];
  var FUNCTION_TABLE_iifff = [b51,__ZN5physx9NpPhysics14createMaterialEfff,__ZN10Matrix4x4f19SetPerspectiveCotanEfff,b51];
  var FUNCTION_TABLE_fiif = [b52,__ZN16VirtFuncInvoker1I28mscorlib_System_SingleTraitsS0_E6InvokeEP10MethodInfoPvf];
  var FUNCTION_TABLE_iiiiiifiiiiiiiiiffffi = [b53,__Z61UnityEngine_UnityEngine_TextGenerator_m_Populate_Internal_cppP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_StringP28UnityEngine_UnityEngine_Font29UnityEngine_UnityEngine_Colorifibbiiiibiffffb,__Z56TextGenerator_CUSTOM_INTERNAL_CALL_Populate_Internal_cppP15ScriptingObjectP15ScriptingStringS0_RK10ColorRGBAfifihhiiiihiffffh,b53];
  var FUNCTION_TABLE_iiiiifiiiif = [b54,__ZNK5physx13NpVolumeCache5sweepERKNS_10PxGeometryERKNS_11PxTransformERKNS_6PxVec3EfRNS_13PxHitCallbackINS_10PxSweepHitEEENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEf];
  var FUNCTION_TABLE_viiffffff = [b55,__Z41UnityEngine_UnityEngine_Matrix4x4_m_OrthoP22mscorlib_System_Objectffffff];
  var FUNCTION_TABLE_viiiiiiiiii = [b56,__ZNK5physx20PxsSolverCoreGeneral10writeBackVEPKNS_23PxcSolverConstraintDescEjPNS_24PxsConstraintBatchHeaderEjPNS_25PxcThresholdStreamElementEjRjPNS_17PxcSolverBodyDataEPPFvS3_jRNS_16PxcSolverContextES7_jPiE,__ZN9GfxDevice24DrawBuffersCustomIndicesEPKtj16GfxPrimitiveTypePK18VertexStreamSourcejjjP17VertexDeclarationRK14ChannelAssigns,__ZN13GfxDeviceGLES17UploadTextureCubeE9TextureIDPKhiii13TextureFormatij17TextureColorSpace,__ZN13GfxDeviceGLES15UploadTexture3DE9TextureIDPKhiiii13TextureFormatij,__Z316mscorlib_System_Text_UTF8Encoding_m_Fallback_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int64_mscorlib_System_UInt32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32U0026_refP22mscorlib_System_ObjectS0_PP42mscorlib_System_Text_DecoderFallbackBufferPP24mscorlib_System_Byte_arrPhxjPtPi,__ZN17PrePassRenderLoop14RenderLightingER12ActiveLightsP13RenderTexture9TextureIDS3_RS3_RK8Vector4fRK14LightingLayersR10MinMaxAABBPS3_,__ZN18DeferredRenderLoop14RenderLightingER12ActiveLightsP13RenderTexture9TextureIDPS3_iRK8Vector4fRK14LightingLayersR10MinMaxAABBS5_,__ZN9Texture2D10ReadPixelsEiiiiiiibb,__Z40DebugStringToFilePostprocessedStacktracePKcS0_S0_iS0_iiiiPFvRK11CppLogEntryE,__ZNSt3__111__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri,__ZNSt3__111__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri,__ZNSt3__111__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri,__ZNSt3__111__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri,b56,b56];
  var FUNCTION_TABLE_diii = [b57,__Z108mscorlib_System_Double_m_Parse_mscorlib_System_Double_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z79mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_Int64P22mscorlib_System_Objectx,__Z112mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z80mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt64P22mscorlib_System_Objecty,__Z112mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN21InterfaceFuncInvoker1I28mscorlib_System_DoubleTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZNSt3__115__num_get_floatIdEET_PKcS3_Rj,__ZNSt3__115__num_get_floatIeEET_PKcS3_Rj,b57,b57,b57,b57,b57,b57,b57];
  var FUNCTION_TABLE_fiiii = [b58,__ZN15LODGroupManager16CalculateLODFadeEjjPKhPKf,__ZNK20TextRenderingPrivate4Font17GetCharacterWidthEjij,b58];
  var FUNCTION_TABLE_iiiiii = [b59,__ZN16ControllerFilter9preFilterERKN5physx12PxFilterDataEPKNS0_7PxShapeEPKNS0_12PxRigidActorERNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEE,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE11createShapeERKNS_10PxGeometryEPKPNS_10PxMaterialEtNS_7PxFlagsINS_11PxShapeFlag4EnumEhEE,__ZN5physx9NpPhysics11createClothERKNS_11PxTransformERNS_13PxClothFabricEPKNS_15PxClothParticleENS_7PxFlagsINS_11PxClothFlag4EnumEtEE,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE11createShapeERKNS_10PxGeometryEPKPNS_10PxMaterialEtNS_7PxFlagsINS_11PxShapeFlag4EnumEhEE,__ZN5physx13NpRigidStatic11createShapeERKNS_10PxGeometryEPKPNS_10PxMaterialEtNS_7PxFlagsINS_11PxShapeFlag4EnumEhEE,__ZNK5physx7NpScene9getActorsENS_7PxFlagsINS_15PxActorTypeFlag4EnumEtEEPPNS_7PxActorEjj,__ZN5physx2Sq10AABBPruner10addObjectsEPjPKNS_9PxBounds3EPKNS0_13PrunerPayloadEj,__ZNK5physx2Sq10AABBPruner7raycastERKNS_6PxVec3ES4_RfRNS0_14PrunerCallbackE,__ZNK5physx2Sq10AABBPruner5sweepERKNS0_9ShapeDataERKNS_6PxVec3ERfRNS0_14PrunerCallbackE,__ZN5physx2Sq12BucketPruner10addObjectsEPjPKNS_9PxBounds3EPKNS0_13PrunerPayloadEj,__ZNK5physx2Sq12BucketPruner7raycastERKNS_6PxVec3ES4_RfRNS0_14PrunerCallbackE,__ZNK5physx2Sq12BucketPruner5sweepERKNS0_9ShapeDataERKNS_6PxVec3ERfRNS0_14PrunerCallbackE,__ZN5physx6shdfnd10Foundation19AlignCheckAllocator8allocateEjPKcS4_i,__ZL32GeomOverlapCallback_SphereSphereRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL31GeomOverlapCallback_SpherePlaneRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL33GeomOverlapCallback_SphereCapsuleRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL29GeomOverlapCallback_SphereBoxRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL32GeomOverlapCallback_SphereConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__Z30GeomOverlapCallback_SphereMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL43GeomOverlapCallback_HeightfieldUnregisteredRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL30GeomOverlapCallback_PlanePlaneRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL32GeomOverlapCallback_PlaneCapsuleRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL28GeomOverlapCallback_PlaneBoxRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL31GeomOverlapCallback_PlaneConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL29GeomOverlapCallback_PlaneMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL34GeomOverlapCallback_CapsuleCapsuleRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL30GeomOverlapCallback_CapsuleBoxRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL33GeomOverlapCallback_CapsuleConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE
  ,__Z31GeomOverlapCallback_CapsuleMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL26GeomOverlapCallback_BoxBoxRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL29GeomOverlapCallback_BoxConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__Z27GeomOverlapCallback_BoxMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL32GeomOverlapCallback_ConvexConvexRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__Z30GeomOverlapCallback_ConvexMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL28GeomOverlapCallback_MeshMeshRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZN5physx2Gu11HeightField13modifySamplesEiiRKNS_17PxHeightFieldDescEb,__ZN9GfxDevice25IsRenderTargetConfigValidEjj19RenderTextureFormat17DepthBufferFormat,__ZN13ScreenManager22SetResolutionImmediateEiibi,__ZN16MemoryFileSystem4SeekER13FileEntryDatay10FileOrigin,__ZN10MemoryFile4ReadEyPvPy,__ZN10MemoryFile5WriteEyPKvPy,__ZN20LocalFileSystemPosix4SeekER13FileEntryDatay10FileOrigin,__ZN23ControllerContactFilter9preFilterERKN5physx12PxFilterDataEPKNS0_7PxShapeEPKNS0_12PxRigidActorERNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEE,__ZN10CastFilter9preFilterERKN5physx12PxFilterDataEPKNS0_7PxShapeEPKNS0_12PxRigidActorERNS0_7PxFlagsINS0_9PxHitFlag4EnumEtEE,__ZN16NovodexAllocator8allocateEjPKcS1_i,__ZNK12PhysXRaycast14BatchIntersectERK13dynamic_arrayI14BatchedRaycastLj4EERS0_I20BatchedRaycastResultLj4EEjb,__ZN13PhysicsModule25CreateNxMeshFromUnityMeshEP4MeshbRK10Matrix4x4f13TransformType,__ZN16MecanimAnimation19PathHashesToIndicesERN5Unity9ComponentEPKjjPt,__ZNK14TerrainManager21GetInterpolatedHeightEPK6ObjectRK8Vector3fS5_Rf,_raccess_guess_apple_double,_raccess_guess_apple_single,_raccess_guess_darwin_ufs_export,_raccess_guess_darwin_newvfs,_raccess_guess_darwin_hfsplus,_raccess_guess_vfat,_raccess_guess_linux_cap,_raccess_guess_linux_double,_raccess_guess_linux_netatalk
  ,__ZN18ScreenManagerWebGL22SetResolutionImmediateEiibi,__ZL161mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_,__Z182mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_,__Z244mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_BeginInvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_P29mscorlib_System_AsyncCallbackS2_,__ZL161mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String_m_BeginInvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_P29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z182mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringS2_P29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z244mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_BeginInvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_P29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__ZL177mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject_m_BeginInvokeP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z190mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z260mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_BeginInvokeP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z159mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32_m_BeginInvokeP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32P22mscorlib_System_StringiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z181mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z242mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_BeginInvokeP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_StringiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z214mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_BeginInvokeP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_EventiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z212mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntryP29UnityEngine_UnityEngine_EventiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z304mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_BeginInvokeP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_EventiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z220mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_BeginInvokeP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z211mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntryiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z302mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_BeginInvokeP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__ZL181mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle_m_BeginInvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyleP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z192mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry_m_BeginInvokeP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyleP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z264mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_BeginInvokeP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyleP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt64_m_CompareP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt64yy,__Z52mscorlib_U003CModuleU003E_m_UnsupportedMember_ObjectP22mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_StringP26mscorlib_System_Object_arrS4_,__Z49mscorlib_System_Int32_m_ProcessTrailingWhitespaceP22mscorlib_System_ObjectbP22mscorlib_System_StringiPP25mscorlib_System_Exception,__Z166mscorlib_System_Int32_m_Parse_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_Boolean_mscorlib_System_Int32U0026_ref_mscorlib_System_ExceptionU0026_refP22mscorlib_System_ObjectP22mscorlib_System_StringbPiPP25mscorlib_System_Exception,__Z39mscorlib_System_String_m_FindNotInTableP22mscorlib_System_StringiiiP24mscorlib_System_Char_arr,__Z166mscorlib_System_String_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Boolean_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_ObjectP22mscorlib_System_StringS2_bP41mscorlib_System_Globalization_CultureInfo,__Z146mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectP22mscorlib_System_StringS0_S0_S0_,__Z37mscorlib_System_String_m_FormatHelperP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderS0_P22mscorlib_System_StringP26mscorlib_System_Object_arr
  ,__Z146mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_String_mscorlib_System_String_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_S2_S2_,__Z165mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_SByteU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Text_EncodingP22mscorlib_System_StringPaiiP29mscorlib_System_Text_Encoding,__Z47mscorlib_System_Double_m_TryParseStringConstantP22mscorlib_System_ObjectP22mscorlib_System_StringS2_ii,__Z40mscorlib_System_Decimal_m_string2decimalP22mscorlib_System_ObjectP23mscorlib_System_DecimalP22mscorlib_System_Stringji,__Z43mscorlib_System_Array_Swapper_m_BeginInvokeP29mscorlib_System_Array_SwapperiiP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z99mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64P21mscorlib_System_Arrayxx,__Z147mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP20mscorlib_System_Typeiii,__Z147mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_ObjectP22mscorlib_System_ObjectP21mscorlib_System_ArrayiiS0_,__Z142mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_ii,__Z146mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_ii,__Z236mscorlib_System_Type_m_GetConstructor_mscorlib_System_Reflection_ConstructorInfo_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP20mscorlib_System_TypeiP33mscorlib_System_Reflection_BinderP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z238mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetContraction_mscorlib_Mono_Globalization_Unicode_Contraction_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_Mono_Globalization_Unicode_Contraction_arr_arrP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiP51mscorlib_Mono_Globalization_Unicode_Contraction_arr,__Z242mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetTailContraction_mscorlib_Mono_Globalization_Unicode_Contraction_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_Mono_Globalization_Unicode_Contraction_arr_arrP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiP51mscorlib_Mono_Globalization_Unicode_Contraction_arr,__Z213mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetSortKey_mscorlib_System_Globalization_SortKey_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_Stringiii,__Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOfOrdinalP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_ii,__Z77mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IndexOfOrdinalIgnoreCaseP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_ii,__Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOfOrdinalP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_ii,__Z81mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_LastIndexOfOrdinalIgnoreCaseP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringS2_ii,__Z163mscorlib_System_Globalization_CompareInfo_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_ii,__Z167mscorlib_System_Globalization_CompareInfo_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_ii,__Z229mscorlib_System_Reflection_Emit_ConstructorBuilder_m_Invoke_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP50mscorlib_System_Reflection_Emit_ConstructorBuilderiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo,__Z62mscorlib_System_Reflection_Emit_TypeBuilder_m_GetMethodsByNameP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_StringibP20mscorlib_System_Type,__Z53mscorlib_System_Reflection_Assembly_m_InternalGetTypeP35mscorlib_System_Reflection_AssemblyP33mscorlib_System_Reflection_ModuleP22mscorlib_System_Stringbb,__Z262mscorlib_System_Reflection_Binder_Default_m_SelectMethod_mscorlib_System_Reflection_MethodBase_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_MethodBase_arr_arr_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP41mscorlib_System_Reflection_Binder_DefaultiP41mscorlib_System_Reflection_MethodBase_arrP24mscorlib_System_Type_arrP48mscorlib_System_Reflection_ParameterModifier_arr,__Z47mscorlib_System_Reflection_Binder_m_ConvertArgsP22mscorlib_System_ObjectP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP44mscorlib_System_Reflection_ParameterInfo_arrP41mscorlib_System_Globalization_CultureInfo,__Z217mscorlib_System_Reflection_MonoCMethod_m_Invoke_mscorlib_System_Object_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Object_arr_arr_mscorlib_System_Globalization_CultureInfoP38mscorlib_System_Reflection_MonoCMethodiP33mscorlib_System_Reflection_BinderP26mscorlib_System_Object_arrP41mscorlib_System_Globalization_CultureInfo,__Z171mscorlib_System_Text_ASCIIEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingPtiPhi,__Z166mscorlib_System_Text_Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P29mscorlib_System_Text_EncodingPtiPhi,__Z169mscorlib_System_Text_StringBuilder_m_Replace_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringS2_ii,__Z171mscorlib_System_Text_UTF32Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P34mscorlib_System_Text_UTF32EncodingPtiPhi
  ,__Z56mscorlib_System_Text_UTF7Encoding_m_InternalGetCharCountP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriii,__Z170mscorlib_System_Text_UTF7Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P33mscorlib_System_Text_UTF7EncodingPtiPhi,__Z184mscorlib_System_Text_UTF8Encoding_m_InternalGetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_CharU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectPtiS1_b,__Z170mscorlib_System_Text_UTF8Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P33mscorlib_System_Text_UTF8EncodingPtiPhi,__Z173mscorlib_System_Text_UnicodeEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P36mscorlib_System_Text_UnicodeEncodingPtiPhi,__Z55mscorlib_System_Text_UnicodeEncoding_m_GetBytesInternalP36mscorlib_System_Text_UnicodeEncodingPtiPhi,__Z55mscorlib_System_Text_UnicodeEncoding_m_GetCharsInternalP36mscorlib_System_Text_UnicodeEncodingPhiPti,__Z32mscorlib_System_Convert_m_ToTypeP22mscorlib_System_ObjectS0_P20mscorlib_System_TypeS0_b,__Z209mscorlib_System_DateTimeUtils_m_GetStandardPattern_mscorlib_System_String_mscorlib_System_Char_mscorlib_System_Globalization_DateTimeFormatInfo_mscorlib_System_BooleanU0026_ref_mscorlib_System_BooleanU0026_refP22mscorlib_System_ObjecttP48mscorlib_System_Globalization_DateTimeFormatInfoPbS3_,__Z212mscorlib_System_DateTimeUtils_m_ToString_mscorlib_System_String_mscorlib_System_DateTime_mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_mscorlib_System_String_mscorlib_System_Globalization_DateTimeFormatInfoP22mscorlib_System_Object24mscorlib_System_DateTime51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanP22mscorlib_System_StringP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z117mscorlib_System_MonoEnumInfo_LongComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Int64_mscorlib_System_Int64P41mscorlib_System_MonoEnumInfo_LongComparerxx,__Z43mscorlib_System_MonoType_m_GetMethodsByNameP24mscorlib_System_MonoTypeP22mscorlib_System_StringibP20mscorlib_System_Type,__Z46mscorlib_System_MonoType_m_GetPropertiesByNameP24mscorlib_System_MonoTypeP22mscorlib_System_StringibP20mscorlib_System_Type,__Z50mscorlib_System_NumberFormatter_CustomInfo_m_ParseP22mscorlib_System_ObjectP22mscorlib_System_StringiiP46mscorlib_System_Globalization_NumberFormatInfo,__Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_UInt64_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringyS0_,__Z148mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Int64_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringxS0_,__Z53mscorlib_System_Reflection_MemberFilter_m_BeginInvokeP39mscorlib_System_Reflection_MemberFilterP37mscorlib_System_Reflection_MemberInfoP22mscorlib_System_ObjectP29mscorlib_System_AsyncCallbackS4_,__Z51mscorlib_System_Reflection_TypeFilter_m_BeginInvokeP37mscorlib_System_Reflection_TypeFilterP20mscorlib_System_TypeP22mscorlib_System_ObjectP29mscorlib_System_AsyncCallbackS4_,__Z54mscorlib_System_AssemblyLoadEventHandler_m_BeginInvokeP40mscorlib_System_AssemblyLoadEventHandlerP22mscorlib_System_ObjectP37mscorlib_System_AssemblyLoadEventArgsP29mscorlib_System_AsyncCallbackS2_,__Z42mscorlib_System_EventHandler_m_BeginInvokeP28mscorlib_System_EventHandlerP22mscorlib_System_ObjectP25mscorlib_System_EventArgsP29mscorlib_System_AsyncCallbackS2_,__Z49mscorlib_System_ResolveEventHandler_m_BeginInvokeP35mscorlib_System_ResolveEventHandlerP22mscorlib_System_ObjectP32mscorlib_System_ResolveEventArgsP29mscorlib_System_AsyncCallbackS2_,__Z60mscorlib_System_UnhandledExceptionEventHandler_m_BeginInvokeP46mscorlib_System_UnhandledExceptionEventHandlerP22mscorlib_System_ObjectP43mscorlib_System_UnhandledExceptionEventArgsP29mscorlib_System_AsyncCallbackS2_,__Z53UnityEngine_UnityEngine_Display_m_RelativeMouseAtImplP22mscorlib_System_ObjectiiPiS1_,__ZL132mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_ii,__ZL140mscorlib_System_Array_m_IndexOf_AssemblyU002DCSharp_JSONObject_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP34AssemblyU002DCSharp_JSONObject_arrP30AssemblyU002DCSharp_JSONObjectii,__ZL132mscorlib_System_Array_m_IndexOf_mscorlib_System_String_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP26mscorlib_System_String_arrP22mscorlib_System_Stringii,__Z130mscorlib_System_Array_m_IndexOf_mscorlib_System_Char_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP24mscorlib_System_Char_arrtii,__ZL130mscorlib_System_Array_m_IndexOf_mscorlib_System_Type_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP24mscorlib_System_Type_arrP20mscorlib_System_Typeii,__Z142mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_UIVertex_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP36UnityEngine_UnityEngine_UIVertex_arr32UnityEngine_UnityEngine_UIVertexii,__Z144mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_UICharInfo_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP38UnityEngine_UnityEngine_UICharInfo_arr34UnityEngine_UnityEngine_UICharInfoii
  ,__Z144mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_UILineInfo_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP38UnityEngine_UnityEngine_UILineInfo_arr34UnityEngine_UnityEngine_UILineInfoii,__ZL155mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_Events_PersistentCall_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP49UnityEngine_UnityEngine_Events_PersistentCall_arrP45UnityEngine_UnityEngine_Events_PersistentCallii,__ZL158mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_Events_BaseInvokableCall_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arrP48UnityEngine_UnityEngine_Events_BaseInvokableCallii,__ZL148mscorlib_System_Array_m_IndexOf_UnityEngine_UnityEngine_GUILayoutEntry_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP42UnityEngine_UnityEngine_GUILayoutEntry_arrP38UnityEngine_UnityEngine_GUILayoutEntryii,__ZL134mscorlib_System_Array_m_IndexOf_mscorlib_System_Byte_arr_mscorlib_System_Int32_T_arr_arr_T_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP34mscorlib_System_ByteU005BU005D_arrP24mscorlib_System_Byte_arrii,__ZNKSt3__17collateIcE10do_compareEPKcS3_S3_S3_,__ZNKSt3__17collateIwE10do_compareEPKwS3_S3_S3_,__ZNKSt3__15ctypeIcE9do_narrowEPKcS3_cPc,__ZNKSt3__17codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,__ZNKSt3__17codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_j,__ZNKSt3__15ctypeIwE9do_narrowEPKwS3_cPc,__ZNKSt3__17codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,__ZNKSt3__17codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_j,__ZNKSt3__17codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,__ZNKSt3__17codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_j,__ZNKSt3__17codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_,__ZNKSt3__17codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_j,_bsearch,__ZN6il2cpp6icalls8mscorlib6System9AppDomain15LoadAssemblyRawEP15Il2CppAppDomainP11Il2CppArrayS7_Pvb,__ZN6il2cpp6icalls8mscorlib6System5Array8FastCopyEP11Il2CppArrayiS5_ii,__ZN6il2cpp6icalls8mscorlib6System6Buffer17BlockCopyInternalEP11Il2CppArrayiS5_ii,__ZN6il2cpp6icalls8mscorlib6System2IO9DriveInfo24GetDiskFreeSpaceInternalEP12Il2CppStringPyS7_S7_Pi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO20GetFileSystemEntriesEP12Il2CppStringS6_iiPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO4ReadE12Il2CppIntPtrP11Il2CppArrayiiPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11ReplaceFileEP12Il2CppStringS6_S6_bPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO4SeekE12Il2CppIntPtrxiPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO5WriteE12Il2CppIntPtrP11Il2CppArrayiiPi,__ZN6il2cpp6icalls8mscorlib6System8MonoType16GetMethodsByNameEP20Il2CppReflectionTypeP12Il2CppStringibS5_,__ZN6il2cpp6icalls8mscorlib6System8MonoType19GetPropertiesByNameEP20Il2CppReflectionTypeP12Il2CppStringjbS5_,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly15InternalGetTypeEP24Il2CppReflectionAssemblyP33mscorlib_System_Reflection_ModuleP12Il2CppStringbb
  ,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module17ResolveFieldTokenE12Il2CppIntPtriP11Il2CppArrayS7_Pi,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module18ResolveMemberTokenE12Il2CppIntPtriP11Il2CppArrayS7_Pi,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module18ResolveMethodTokenE12Il2CppIntPtriP11Il2CppArrayS7_Pi,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module16ResolveTypeTokenE12Il2CppIntPtriP11Il2CppArrayS7_Pi,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked17CompareExchange64EPxxx,__ZN6il2cpp2vm14TypeNameParser12ParseVersionERKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEERtSB_SB_SB_,__Z37GeomOverlapCallback_SphereHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__Z36GeomOverlapCallback_PlaneHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__Z38GeomOverlapCallback_CapsuleHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__Z34GeomOverlapCallback_BoxHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__Z37GeomOverlapCallback_ConvexHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL35GeomOverlapCallback_MeshHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZL42GeomOverlapCallback_HeightfieldHeightfieldRKN5physx10PxGeometryERKNS_11PxTransformES2_S5_PNS_2Gu12TriggerCacheE,__ZN14SafeBinaryRead13BeginTransferEPKcS1_PPFbPvRS_Eb,__ZN5Unity8Material17SetPassWithShaderEiP6ShaderRN9ShaderLab17ShaderPassContextEi,__ZN17PrePassRenderLoop14RenderBasePassEP13RenderTextureRK14LightingLayersR13dynamic_arrayI16RenderObjectDataLj4EER10MinMaxAABB,__ZN5Unity8Material7SetPassEiRN9ShaderLab17ShaderPassContextEib,__ZN6Camera25StandaloneRenderToCubemapEP7TextureiPFvPK9SceneNodePK4AABBR9IndexListPvESA_,__Z29CreateGameObjectWithHideFlagsRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEbiPKcz,__ZN10Matrix4x4f30SetPositionAndOrthoNormalBasisERK8Vector3fS2_S2_S2_,__ZN22RenderingCommandBuffer13GetAndCheckRTE24BuiltinRenderTextureTypeRKN9ShaderLab16FastPropertyNameEPKcPP13RenderTexture,__ZL21AddComponentUncheckedRN5Unity10GameObjectEiP14ScriptingClassP10MonoScriptPNSt3__112basic_stringIcNS6_11char_traitsIcEENS6_9allocatorIcEEEE,__ZN18LoadLevelOperation9LoadLevelERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_iNS_11LoadingModeEb,__Z19ShouldTransferFieldR32SerializationCommandQueueBuilderP14ScriptingClassiR18TransferField_InfoRK22CommonScriptingClasses,__ZN17PersistentManager32CreateThreadActivationQueueEntryER14SerializedFile26SerializedObjectIdentifierib,__Z12ReadTypeTreeR8TypeTreeRPKhS2_ib,__ZNK10FileSystem9EnumerateEPKcP13dynamic_arrayI13FileEntryInfoLj8EEb19FileEnumerationFlag,__ZN12FileAccessor4ReadEyPvPy,__ZN12FileAccessor5WriteEyPKvPy,__ZL28VehicleWheelRaycastPreFilterN5physx12PxFilterDataES0_PKvjRNS_7PxFlagsINS_9PxHitFlag4EnumEtEE
  ,__Z27CreatePxStreamFromUnityMeshP4MeshbRK10Matrix4x4f13TransformTypeR12MemoryStream,__Z14FMOD_FILE_OpenPKciPjPPvS3_,__Z14FMOD_FILE_ReadPvS_jPjS_,__ZN9AudioClip7WWWOpenEPKciPjPPvS4_,__ZN9AudioClip7WWWReadEPvS0_jPjS0_,__ZN4FMOD6System7playDSPE17FMOD_CHANNELINDEXPNS_3DSPEbPPNS_7ChannelE,__ZN4FMOD6System9playSoundE17FMOD_CHANNELINDEXPNS_5SoundEbPPNS_7ChannelE,__ZN4FMOD6System11createSoundEPKcjP22FMOD_CREATESOUNDEXINFOPPNS_5SoundE,__ZN11UnityEngine9AnimationL56CalculateTransformBindingSizeBasedOnConstantOptimizationERKNS0_20AnimationSetBindingsERK13dynamic_arrayINS0_14BoundTransformELj4EEPKiPKN7mecanim9animation14AvatarConstantEb,_FT_New_Memory_Face,__ZN20TextRenderingPrivate4Font24CollectAllUsedCharactersEPtRiRPiRPj,_cff_face_init,_ft_stub_set_char_sizes,_cff_get_advances,_tt_face_load_any,_sfnt_table_info,_sfnt_init_face,_sfnt_load_face,_tt_face_get_metrics,_tt_face_init,_tt_get_advances,_psh_globals_set_scale,__ZN16VirtFuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_E6InvokeEP10MethodInfoPvS5_S5_i,__ZN16VirtFuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_S6_i,__ZN21InterfaceFuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS0_E6InvokeEP10MethodInfoPvS5_P22mscorlib_System_ObjectS5_,__ZN16VirtFuncInvoker3I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEP10MethodInfoPvP22mscorlib_System_Objectii,__ZN16VirtFuncInvoker3I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsS1_E6InvokeEP10MethodInfoPvS5_bb,__ZN16VirtFuncInvoker3I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS5_S5_,__ZN16VirtFuncInvoker3I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvtti,__ZN16VirtFuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_E6InvokeEP10MethodInfoPvS5_ii
  ,__ZN16VirtFuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_E6InvokeEP10MethodInfoPvS5_ii,__ZN16VirtFuncInvoker3I17VoidPointerTraitsS0_S0_S0_E6InvokeEP10MethodInfoPvS4_S4_S4_,_wcsnrtombs,_mbsnrtowcs,b59,b59,b59,b59,b59,b59,b59,b59,b59,b59,b59,b59,b59];
  var FUNCTION_TABLE_viiiiifiiiiiiiiiiiii = [b60,__ZN20TextRenderingPrivate22ScriptingTextGenerator19GetStringRenderInfoERS0_RKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPNS_4FontE11ColorRGBA32ifibbiiNS0_16VerticalWrapModeENS0_18HorizontalWrapModeEbiRK8Vector2fSI_bb];
  var FUNCTION_TABLE_viiiff = [b61,__Z42Vector3_CUSTOM_INTERNAL_CALL_RotateTowardsRK8Vector3fS1_ff];
  var FUNCTION_TABLE_iiiiiifiif = [b62,__Z22sweepConvex_SphereGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z21sweepConvex_PlaneGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z23sweepConvex_CapsuleGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z19sweepConvex_BoxGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z22sweepConvex_ConvexGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z20sweepConvex_MeshGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf,__Z27sweepConvex_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_20PxConvexMeshGeometryES5_RKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEf];
  var FUNCTION_TABLE_viiii = [b63,__ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE7seekposENS_4fposI11__mbstate_tEEj,__ZN5physx3Cct10Controller9onReleaseEPKNS_6PxBaseEPvNS_19PxDeletionEventFlag4EnumE,__ZN5physx18NpArticulationLink8addForceERKNS_6PxVec3ENS_11PxForceMode4EnumEb,__ZN5physx18NpArticulationLink9addTorqueERKNS_6PxVec3ENS_11PxForceMode4EnumEb,__ZN5physx9NpPhysics24registerDeletionListenerERNS_18PxDeletionListenerERKNS_7PxFlagsINS_19PxDeletionEventFlag4EnumEhEEb,__ZN5physx9NpPhysics31registerDeletionListenerObjectsERNS_18PxDeletionListenerEPKPKNS_6PxBaseEj,__ZN5physx9NpPhysics33unregisterDeletionListenerObjectsERNS_18PxDeletionListenerEPKPKNS_6PxBaseEj,__ZN5physx9NpPhysics20MeshDeletionListener28onGuMeshFactoryBufferReleaseEPKNS_6PxBaseEtb,__ZN5physx14NpRigidDynamic8addForceERKNS_6PxVec3ENS_11PxForceMode4EnumEb,__ZN5physx14NpRigidDynamic9addTorqueERKNS_6PxVec3ENS_11PxForceMode4EnumEb,__ZN5physx7NpScene12removeActorsEPKPNS_7PxActorEjb,__ZN5physx7NpScene21setDominanceGroupPairEhhRKNS_20PxDominanceGroupPairE,__ZNK5physx7NpScene21getDominanceGroupPairEhh,__ZN5physx7NpScene14resetFilteringERNS_12PxRigidActorEPKPNS_7PxShapeEj,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEE,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEE,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS4_IKfEE,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE12setPositionsEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEE,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE13setVelocitiesEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEE,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14setRestOffsetsEjRKNS_16PxStrideIteratorIKjEERKNS4_IKfEE,__ZNK5physx5cloth9SwFactory23extractVirtualParticlesERKNS0_5ClothENS0_5RangeIA4_jEENS5_INS_6PxVec3EEE,__ZNK5physx5cloth9SwFactory10copyToHostEPKvS3_Pv,__ZNK5physx5cloth9SwFactory12copyFromHostEPKvS3_Pv,__ZThn4_NK5physx5cloth9SwFactory23extractVirtualParticlesERKNS0_5ClothENS0_5RangeIA4_jEENS5_INS_6PxVec3EEE,__ZThn4_NK5physx5cloth9SwFactory10copyToHostEPKvS3_Pv,__ZThn4_NK5physx5cloth9SwFactory12copyFromHostEPKvS3_Pv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE10setSpheresENS0_5RangeIKNS_6PxVec4EEEjj,__ZN5physx5cloth9ClothImplINS0_7SwClothEE11setCapsulesENS0_5RangeIKjEEjj
  ,__ZN5physx5cloth9ClothImplINS0_7SwClothEE9setPlanesENS0_5RangeIKNS_6PxVec4EEEjj,__ZN5physx5cloth9ClothImplINS0_7SwClothEE11setConvexesENS0_5RangeIKjEEjj,__ZN5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEEjj,__ZN5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEES7_j,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE10setSpheresENS0_5RangeIKNS_6PxVec4EEEjj,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setCapsulesENS0_5RangeIKjEEjj,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE9setPlanesENS0_5RangeIKNS_6PxVec4EEEjj,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setConvexesENS0_5RangeIKjEEjj,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEEjj,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE12setTrianglesENS0_5RangeIKNS_6PxVec3EEES7_j,__ZNK5physx15PxsParticleData13getParticlesVERNS_30PxvParticleSystemStateDataDescEbb,__ZN5physx15PxsParticleData13setPositionsVEjRKNS_16PxStrideIteratorIKjEERKNS1_IKNS_6PxVec3EEE,__ZN5physx15PxsParticleData14setVelocitiesVEjRKNS_16PxStrideIteratorIKjEERKNS1_IKNS_6PxVec3EEE,__ZN5physx15PxsParticleData15setRestOffsetsVEjRKNS_16PxStrideIteratorIKjEERKNS1_IKfEE,__ZN5physx20PxsParticleSystemSim16onRbShapeChangeVERKNS_16PxvParticleShapeEjj,__ZN5physx2Sq10AABBPruner13updateObjectsEPKjPKNS_9PxBounds3Ej,__ZN5physx2Sq12BucketPruner13updateObjectsEPKjPKNS_9PxBounds3Ej,__ZN16RTreeCookerRemap5remapEPjjj,__ZNK5physx2Gu10ConvexMesh18getMassInformationERfRNS_7PxMat33ERNS_6PxVec3E,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10startEventEty,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9stopEventEty,__ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10startEventEty,__ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9stopEventEty,__ZNK5physx2Gu16SupportLocalImplINS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERNS5_6FloatVESA_,__ZNK5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEE9doSupportERKNS_6shdfnd3aos5Vec3VERNS5_6FloatVESA_,__ZNK5physx2Gu16SupportLocalImplINS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERNS5_6FloatVESA_,__ZNK5physx2Gu16SupportLocalImplINS0_9TriangleVEE9doSupportERKNS_6shdfnd3aos5Vec3VERNS5_6FloatVESA_,__ZN22BlockMemoryCacheWriter14LockCacheBlockEjPPhS1_,__ZN9GfxDevice13SetFFLightingEbb17ColorMaterialMode,__ZN9GfxDevice16RecordSetFFColorERKN9ShaderLab9VectorValEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE
  ,__ZN9GfxDevice19SetTextureCombinersE12ObjectHandleI20TextureCombiners_TagPvEPKN9ShaderLab13PropertySheetERKNS4_17ShaderPassContextE,__ZN9GfxDevice16AddBatchingStatsEiii,__ZN9GfxDevice20UpdateSkinPoseBufferEP17GPUSkinPoseBufferPK10Matrix4x4fi,__ZNK9GfxDevice31CalculateDeviceProjectionMatrixER10Matrix4x4fbb,__ZN9GfxDevice20SetComputeBufferDataE15ComputeBufferIDPKvj,__ZN9GfxDevice20GetComputeBufferDataE15ComputeBufferIDPvj,__ZN9GfxDevice22CopyComputeBufferCountE15ComputeBufferIDS0_j,__ZN9GfxDevice28CreateComputeConstantBuffersEjPKjP12ObjectHandleI18ConstantBuffer_TagPvE,__ZN9GfxDevice16DrawNullGeometryE16GfxPrimitiveTypeii,__ZN9GfxDevice24DrawNullGeometryIndirectE16GfxPrimitiveType15ComputeBufferIDj,__ZNK17IAnimationBinding38SerializedPropertyPathToCurveAttributeER6ObjectPKc,__ZN13ScreenManager14GetResolutionsEib,__ZN14FileCacherRead10DirectReadEPvjj,__ZN14FileCacherRead14LockCacheBlockEjPPhS1_,__ZN22MemoryCacherReadBlocks10DirectReadEPvjj,__ZN22MemoryCacherReadBlocks14LockCacheBlockEjPPhS1_,__ZN14PhysicsManager9onContactERKN5physx19PxContactPairHeaderEPKNS0_13PxContactPairEj,__ZThn24_N14PhysicsManager9onContactERKN5physx19PxContactPairHeaderEPKNS0_13PxContactPairEj,__ZN29AnimationStateNetworkProvider24GetNetworkAnimationStateER9AnimationP24AnimationStateForNetworki,__ZN29AnimationStateNetworkProvider24SetNetworkAnimationStateER9AnimationPK24AnimationStateForNetworki,__ZN16MecanimAnimation25RegisterIAnimationBindingE11ClassIDTypeiP17IAnimationBinding,__ZN13GfxDeviceGLES13SetFFLightingEbb17ColorMaterialMode,__ZN13GfxDeviceGLES19SetTextureCombinersE12ObjectHandleI20TextureCombiners_TagPvEPKN9ShaderLab13PropertySheetERKNS4_17ShaderPassContextE,__ZN19GfxThreadableDevice20SetShadersMainThreadEPPN9ShaderLab10SubProgramEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE,__ZN13GfxDeviceGLES20UpdateSkinPoseBufferEP17GPUSkinPoseBufferPK10Matrix4x4fi,__ZN13GfxDeviceGLES15SetSurfaceFlagsE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseEjj,__ZN13GfxDeviceGLES20SetShadersThreadableEPP10GpuProgramPPK20GpuProgramParametersPKPKh,__Z178AssemblyU002DCSharp_JSONObject_m_GetField_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_GetFieldResponse_AssemblyU002DCSharp_JSONObject_FieldNotFoundP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP44AssemblyU002DCSharp_JSONObject_FieldNotFound,__Z84AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_AdjustGroundVelocityToNormalP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3S1_,__Z81AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_ProjectOntoPlaneP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController31UnityEngine_UnityEngine_Vector3S1_
  ,__Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_make_pairP22mscorlib_System_ObjectP22mscorlib_System_StringS2_,__ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP22mscorlib_System_StringS2_,__Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_make_pairP22mscorlib_System_ObjectS0_S0_,__ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectS0_S0_,__Z177mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_ObjectS2_,__Z239mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_,__Z177mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringS2_,__Z239mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_InvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_,__Z123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_make_pairP22mscorlib_System_ObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__ZL134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__Z185mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__Z255mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_InvokeP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__ZL155System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_CopyTo_mscorlib_System_Void_T_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arrii,__Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP22mscorlib_System_Stringi,__Z114mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_make_pairP22mscorlib_System_ObjectP22mscorlib_System_Stringi,__Z176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Stringi,__Z237mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_InvokeP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi,__Z156mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP29UnityEngine_UnityEngine_Eventi,__Z145mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_make_pairP22mscorlib_System_ObjectP29UnityEngine_UnityEngine_Eventi,__Z207mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntryP29UnityEngine_UnityEngine_Eventi,__Z299mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_InvokeP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi,__Z155mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z144mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_make_pairP22mscorlib_System_ObjectiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntryiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z297mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_InvokeP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_make_pairP22mscorlib_System_ObjectP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__ZL136mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_U003CCopyToU003Em__0P22mscorlib_System_ObjectP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__Z187mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry_m_InvokeP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__Z259mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_InvokeP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__Z125mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringPtii
  ,__Z124mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_StringP24mscorlib_System_Char_arrii,__Z32mscorlib_System_String_m_memcpy4P22mscorlib_System_ObjectPhS1_i,__Z32mscorlib_System_String_m_memcpy2P22mscorlib_System_ObjectPhS1_i,__Z32mscorlib_System_String_m_memcpy1P22mscorlib_System_ObjectPhS1_i,__Z31mscorlib_System_String_m_memcpyP22mscorlib_System_ObjectPhS1_i,__Z136mscorlib_System_String_m_CharCopy_mscorlib_System_Void_mscorlib_System_CharU002A_ptr_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P22mscorlib_System_ObjectPtS1_i,__Z143mscorlib_System_String_m_CharCopyReverse_mscorlib_System_Void_mscorlib_System_CharU002A_ptr_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P22mscorlib_System_ObjectPtS1_i,__Z29mscorlib_System_Decimal_m_AddP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z34mscorlib_System_Decimal_m_SubtractP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z34mscorlib_System_Decimal_m_MultiplyP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z32mscorlib_System_Decimal_m_DivideP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z110mscorlib_System_Decimal_m_Parse_mscorlib_System_Decimal_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z112mscorlib_System_Decimal_m_op_Subtraction_mscorlib_System_Decimal_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z109mscorlib_System_Decimal_m_op_Multiply_mscorlib_System_Decimal_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z109mscorlib_System_Decimal_m_op_Division_mscorlib_System_Decimal_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z83mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_Int64P22mscorlib_System_Objectx,__Z84mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt64P22mscorlib_System_Objecty,__Z98mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64P21mscorlib_System_ArrayP22mscorlib_System_Objectx,__Z120mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P21mscorlib_System_ArrayP22mscorlib_System_Objectii,__Z29mscorlib_System_Array_m_ClearP22mscorlib_System_ObjectP21mscorlib_System_Arrayii,__Z37mscorlib_System_Array_m_ClearInternalP22mscorlib_System_ObjectP21mscorlib_System_Arrayii,__Z115mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_i,__Z118mscorlib_System_Array_m_Reverse_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_Arrayii,__Z115mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_Arrayii,__Z131mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_S0_,__Z95mscorlib_System_Array_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int64P21mscorlib_System_ArrayS0_x,__Z71mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m__ctorP63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeiii,__Z55mscorlib_Mono_Globalization_Unicode_Contraction_m__ctorP47mscorlib_Mono_Globalization_Unicode_ContractionP24mscorlib_System_Char_arrP22mscorlib_System_StringP24mscorlib_System_Byte_arr,__Z156mscorlib_System_Globalization_SortKey_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP37mscorlib_System_Globalization_SortKeyiP22mscorlib_System_Stringi,__Z73mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendBufferPrimitiveP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhPP24mscorlib_System_Byte_arrPi
  ,__Z55mscorlib_Mono_Security_BitConverterLE_m_UShortFromBytesP22mscorlib_System_ObjectPhP24mscorlib_System_Byte_arri,__Z53mscorlib_Mono_Security_BitConverterLE_m_UIntFromBytesP22mscorlib_System_ObjectPhP24mscorlib_System_Byte_arri,__Z75mscorlib_System_Collections_ArrayList_m_ThrowNewArgumentOutOfRangeExceptionP22mscorlib_System_ObjectP22mscorlib_System_StringS0_S2_,__Z47mscorlib_System_Collections_Hashtable_m_PutImplP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_b,__Z51mscorlib_System_Collections_Hashtable_m_CopyToArrayP37mscorlib_System_Collections_HashtableP21mscorlib_System_Arrayii,__Z139mscorlib_System_Diagnostics_StackTrace_m__ctor_mscorlib_System_Void_mscorlib_System_Exception_mscorlib_System_Int32_mscorlib_System_BooleanP38mscorlib_System_Diagnostics_StackTraceP25mscorlib_System_Exceptionib,__Z65mscorlib_System_Globalization_CCGregorianCalendar_m_my_from_fixedP22mscorlib_System_ObjectPiS1_i,__Z58mscorlib_System_Globalization_CompareInfo_m_assign_sortkeyP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_ObjectP22mscorlib_System_Stringi,__Z140mscorlib_System_Globalization_CultureInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_System_BooleanP41mscorlib_System_Globalization_CultureInfoibb,__Z50mscorlib_System_Globalization_DaylightTime_m__ctorP42mscorlib_System_Globalization_DaylightTime24mscorlib_System_DateTimeS1_24mscorlib_System_TimeSpan,__Z61mscorlib_System_Reflection_Binder_Default_m_ReorderParametersP41mscorlib_System_Reflection_Binder_DefaultP26mscorlib_System_String_arrPP26mscorlib_System_Object_arrP37mscorlib_System_Reflection_MethodBase,__Z55mscorlib_System_Reflection_MonoField_m_SetValueInternalP22mscorlib_System_ObjectP36mscorlib_System_Reflection_FieldInfoS0_S0_,__Z63mscorlib_System_Reflection_MonoPropertyInfo_m_get_property_infoP22mscorlib_System_ObjectP39mscorlib_System_Reflection_MonoPropertyP43mscorlib_System_Reflection_MonoPropertyInfoi,__Z146mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m__ctor_mscorlib_System_Void_mscorlib_System_Type_mscorlib_System_IntPtr_mscorlib_System_ObjectP50mscorlib_System_Runtime_Remoting_Proxies_RealProxyP20mscorlib_System_Type22mscorlib_System_IntPtrP22mscorlib_System_Object,__Z62mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy_m__ctorP54mscorlib_System_Runtime_Remoting_Proxies_RemotingProxyP20mscorlib_System_TypeP22mscorlib_System_StringP26mscorlib_System_Object_arr,__Z55mscorlib_System_Runtime_Remoting_ServerIdentity_m__ctorP47mscorlib_System_Runtime_Remoting_ServerIdentityP22mscorlib_System_StringP49mscorlib_System_Runtime_Remoting_Contexts_ContextP20mscorlib_System_Type,__Z58mscorlib_System_Runtime_Remoting_SingletonIdentity_m__ctorP50mscorlib_System_Runtime_Remoting_SingletonIdentityP22mscorlib_System_StringP49mscorlib_System_Runtime_Remoting_Contexts_ContextP20mscorlib_System_Type,__Z59mscorlib_System_Runtime_Remoting_SingleCallIdentity_m__ctorP51mscorlib_System_Runtime_Remoting_SingleCallIdentityP22mscorlib_System_StringP49mscorlib_System_Runtime_Remoting_Contexts_ContextP20mscorlib_System_Type,__Z64mscorlib_System_Runtime_Serialization_SerializationEntry_m__ctorP56mscorlib_System_Runtime_Serialization_SerializationEntryP22mscorlib_System_StringP20mscorlib_System_TypeP22mscorlib_System_Object,__Z154mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_TypeP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_StringP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z132mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int64P55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringx,__Z133mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_UInt64P55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringy,__Z53mscorlib_System_Text_DecoderFallbackException_m__ctorP45mscorlib_System_Text_DecoderFallbackExceptionP22mscorlib_System_StringP24mscorlib_System_Byte_arri,__Z138mscorlib_System_Text_EncoderFallbackException_m__ctor_mscorlib_System_Void_mscorlib_System_Char_mscorlib_System_Char_mscorlib_System_Int32P45mscorlib_System_Text_EncoderFallbackExceptiontti,__Z135mscorlib_System_Text_UTF32Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_Boolean_mscorlib_System_BooleanP34mscorlib_System_Text_UTF32Encodingbbb,__Z137mscorlib_System_Text_UnicodeEncoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_Boolean_mscorlib_System_BooleanP36mscorlib_System_Text_UnicodeEncodingbbb,__Z134mscorlib_System_ArgumentException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_String_mscorlib_System_ExceptionP33mscorlib_System_ArgumentExceptionP22mscorlib_System_StringS2_P25mscorlib_System_Exception,__Z141mscorlib_System_ArgumentOutOfRangeException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_StringP43mscorlib_System_ArgumentOutOfRangeExceptionP22mscorlib_System_StringP22mscorlib_System_ObjectS2_,__Z116mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z83mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_Int64P22mscorlib_System_Objectx
  ,__Z116mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__Z84mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt64P22mscorlib_System_Objecty,__Z81mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_Int64P22mscorlib_System_Objectx,__Z114mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt64P22mscorlib_System_Objecty,__Z114mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__Z119mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P24mscorlib_System_DateTimeiii,__Z104mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Int64_mscorlib_System_DateTimeKindP24mscorlib_System_DateTimexi,__Z35mscorlib_System_DateTime_m_AddTicksP24mscorlib_System_DateTimex,__Z38mscorlib_System_DateTime_m_SpecifyKindP22mscorlib_System_Object24mscorlib_System_DateTimei,__Z112mscorlib_System_DateTime_m_Parse_mscorlib_System_DateTime_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z113mscorlib_System_DateTime_m_op_Addition_mscorlib_System_DateTime_mscorlib_System_DateTime_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_DateTime24mscorlib_System_TimeSpan,__Z116mscorlib_System_DateTime_m_op_Subtraction_mscorlib_System_DateTime_mscorlib_System_DateTime_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_DateTime24mscorlib_System_TimeSpan,__Z106mscorlib_System_DateTimeOffset_m__ctor_mscorlib_System_Void_mscorlib_System_Int64_mscorlib_System_TimeSpanP30mscorlib_System_DateTimeOffsetx24mscorlib_System_TimeSpan,__Z39mscorlib_System_DateTimeUtils_m_ZeroPadP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderii,__Z61mscorlib_System_DelegateSerializationHolder_m_GetDelegateDataP22mscorlib_System_ObjectP24mscorlib_System_DelegateP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z117mscorlib_System_NumberFormatter_m_InitDecHexDigits_mscorlib_System_Void_mscorlib_System_UInt32_mscorlib_System_UInt64P31mscorlib_System_NumberFormatterjy,__Z126mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringii,__Z127mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_UInt32_mscorlib_System_Int32P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringji,__Z104mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int64P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringx,__Z105mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_UInt64P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringy,__Z48mscorlib_System_NumberFormatter_m_AppendExponentP31mscorlib_System_NumberFormatterP46mscorlib_System_Globalization_NumberFormatInfoii,__Z146mscorlib_System_NumberFormatter_m_AppendDigits_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Text_StringBuilderP31mscorlib_System_NumberFormatteriiP34mscorlib_System_Text_StringBuilder,__Z119mscorlib_System_TimeSpan_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P24mscorlib_System_TimeSpaniii,__Z54mscorlib_System_UnitySerializationHolder_m_GetTypeDataP22mscorlib_System_ObjectP20mscorlib_System_TypeP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z56mscorlib_System_UnitySerializationHolder_m_GetDBNullDataP22mscorlib_System_ObjectP22mscorlib_System_DBNullP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z56mscorlib_System_UnitySerializationHolder_m_GetModuleDataP22mscorlib_System_ObjectP33mscorlib_System_Reflection_ModuleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z78UnityEngine_UnityEngine_StackTraceUtility_m_ExtractStringFromExceptionInternalP22mscorlib_System_ObjectS0_PP22mscorlib_System_StringS3_,__Z60UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateEnterP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi,__Z61UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateUpdateP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi
  ,__Z59UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateExitP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi,__Z59UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateMoveP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi,__Z57UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateIKP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animator41UnityEngine_UnityEngine_AnimatorStateInfoi,__Z56UnityEngine_UnityEngine_Application_LogCallback_m_InvokeP47UnityEngine_UnityEngine_Application_LogCallbackP22mscorlib_System_StringS2_i,__Z157UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Object_UnityEngine_UnityEngine_SendMessageOptionsP33UnityEngine_UnityEngine_ComponentP22mscorlib_System_StringP22mscorlib_System_Objecti,__Z48UnityEngine_UnityEngine_GameObject_m_SendMessageP34UnityEngine_UnityEngine_GameObjectP22mscorlib_System_StringP22mscorlib_System_Objecti,__Z54UnityEngine_UnityEngine_GUILayoutUtility_m_BeginWindowP22mscorlib_System_ObjectiP32UnityEngine_UnityEngine_GUIStyleP43UnityEngine_UnityEngine_GUILayoutOption_arr,__Z45UnityEngine_UnityEngine_GUIUtility_m_BeginGUIP22mscorlib_System_Objectiii,__Z144UnityEngine_UnityEngine_Vector2_m_op_Subtraction_UnityEngine_UnityEngine_Vector2_UnityEngine_UnityEngine_Vector2_UnityEngine_UnityEngine_Vector2P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector2S1_,__Z39UnityEngine_UnityEngine_Vector3_m_CrossP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z41UnityEngine_UnityEngine_Vector3_m_ProjectP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z37UnityEngine_UnityEngine_Vector3_m_MinP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z37UnityEngine_UnityEngine_Vector3_m_MaxP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z141UnityEngine_UnityEngine_Vector3_m_op_Addition_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z144UnityEngine_UnityEngine_Vector3_m_op_Subtraction_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z51UnityEngine_UnityEngine_Quaternion_m_FromToRotationP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z65UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_FromToRotationP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_,__Z148UnityEngine_UnityEngine_Quaternion_m_LookRotation_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z63UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_LookRotationP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_,__Z153UnityEngine_UnityEngine_Quaternion_m_op_Multiply_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_QuaternionP22mscorlib_System_Object34UnityEngine_UnityEngine_QuaternionS1_,__Z147UnityEngine_UnityEngine_Quaternion_m_op_Multiply_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object34UnityEngine_UnityEngine_Quaternion31UnityEngine_UnityEngine_Vector3,__Z42UnityEngine_UnityEngine_Matrix4x4_m_SetTRSP33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector334UnityEngine_UnityEngine_QuaternionS1_,__Z149UnityEngine_UnityEngine_Matrix4x4_m_op_Multiply_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4S1_,__Z145UnityEngine_UnityEngine_Matrix4x4_m_op_Multiply_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Vector4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector4,__Z57UnityEngine_UnityEngine_Bounds_m_Internal_GetClosestPointP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_BoundsP31UnityEngine_UnityEngine_Vector3,__Z71UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_GetClosestPointP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_BoundsP31UnityEngine_UnityEngine_Vector3,__Z144UnityEngine_UnityEngine_Vector4_m_op_Subtraction_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_Vector4P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4S1_,__Z57UnityEngine_UnityEngine_Material_m_INTERNAL_CALL_SetColorP22mscorlib_System_ObjectP32UnityEngine_UnityEngine_MaterialiP29UnityEngine_UnityEngine_Color,__Z139UnityEngine_UnityEngine_WWWForm_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Text_EncodingP31UnityEngine_UnityEngine_WWWFormP22mscorlib_System_StringS2_P29mscorlib_System_Text_Encoding,__Z65UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_ViewportPointToRayP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_CameraP31UnityEngine_UnityEngine_Vector3
  ,__Z63UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_ScreenPointToRayP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_CameraP31UnityEngine_UnityEngine_Vector3,__Z44UnityEngine_UnityEngine_Debug_m_Internal_LogP22mscorlib_System_ObjectiP22mscorlib_System_StringP30UnityEngine_UnityEngine_Object,__Z129UnityEngine_UnityEngine_Display_m_Activate_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P31UnityEngine_UnityEngine_Displayiii,__Z50UnityEngine_UnityEngine_Display_m_GetSystemExtImplP22mscorlib_System_Object22mscorlib_System_IntPtrPiS2_,__Z53UnityEngine_UnityEngine_Display_m_GetRenderingExtImplP22mscorlib_System_Object22mscorlib_System_IntPtrPiS2_,__Z57UnityEngine_UnityEngine_Display_m_GetRenderingBuffersImplP22mscorlib_System_Object22mscorlib_System_IntPtrP36UnityEngine_UnityEngine_RenderBufferS3_,__Z60UnityEngine_UnityEngine_Display_m_SetRenderingResolutionImplP22mscorlib_System_Object22mscorlib_System_IntPtrii,__Z68UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_TransformDirectionP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__Z75UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_InverseTransformDirectionP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__Z64UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_TransformPointP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__Z71UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_InverseTransformPointP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__ZL139mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP26mscorlib_System_Object_arrii,__ZL147mscorlib_System_Array_m_Resize_AssemblyU002DCSharp_JSONObject_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP34AssemblyU002DCSharp_JSONObject_arrii,__ZL139mscorlib_System_Array_m_Resize_mscorlib_System_String_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP26mscorlib_System_String_arrii,__ZL149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z170mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_CopyTo_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arriP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z212mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP47mscorlib_System_Collections_DictionaryEntry_arriP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry,__Z232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayiP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z253mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arriP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z336mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arriP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_ICollectionCopyTo_mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_ArrayiP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String,__Z170mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_StringU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP26mscorlib_System_Object_arriP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String,__Z170mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP26mscorlib_System_String_arriP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String,__Z212mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP47mscorlib_System_Collections_DictionaryEntry_arriP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry,__Z232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_ArrayiP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z253mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP26mscorlib_System_Object_arriP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z336mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_StringU003E_arriP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL165mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_ICollectionCopyTo_AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayiP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject,__Z186mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_ObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP26mscorlib_System_Object_arriP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject,__Z194mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP34AssemblyU002DCSharp_JSONObject_arriP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject
  ,__Z220mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP47mscorlib_System_Collections_DictionaryEntry_arriP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry,__Z248mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayiP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z269mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_ObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP26mscorlib_System_Object_arriP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z360mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP92mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CJSONObjectU003E_arriP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z147mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_ICollectionCopyTo_mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_ArrayiP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32,__Z168mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Int32U002CU0020mscorlib_System_ObjectP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P26mscorlib_System_Object_arriP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32,__Z167mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Int32U002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P25mscorlib_System_Int32_arriP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32,__Z211mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P47mscorlib_System_Collections_DictionaryEntry_arriP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry,__Z230mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_ArrayiP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z251mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_ObjectP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P26mscorlib_System_Object_arriP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z333mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P94mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_Int32U003E_arriP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__ZL137mscorlib_System_Array_m_Resize_mscorlib_System_Type_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP24mscorlib_System_Type_arrii,__Z202mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_ICollectionCopyTo_UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_ArrayiP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z223mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_ObjectP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP26mscorlib_System_Object_arriP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z246mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP49UnityEngine_UnityEngine_TextEditor_TextEditOp_arriP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z242mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP47mscorlib_System_Collections_DictionaryEntry_arriP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry,__Z292mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_ArrayiP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z313mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_ObjectP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP26mscorlib_System_Object_arriP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z426mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP119mscorlib_System_Collections_Generic_KeyValuePair_2U003CUnityEngine_EventU002CUnityEngine_TextEditor_TextEditOpU003E_arriP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z149mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UIVertex_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP36UnityEngine_UnityEngine_UIVertex_arrii,__Z151mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UICharInfo_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP38UnityEngine_UnityEngine_UICharInfo_arrii,__Z151mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UILineInfo_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP38UnityEngine_UnityEngine_UILineInfo_arrii,__ZL162mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_Events_PersistentCall_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP49UnityEngine_UnityEngine_Events_PersistentCall_arrii,__ZL165mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_Events_BaseInvokableCall_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arrii,__Z208mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_ICollectionCopyTo_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayiP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z229mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_ObjectP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP26mscorlib_System_Object_arriP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z259mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP56UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_arriP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP47mscorlib_System_Collections_DictionaryEntry_arriP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry,__Z290mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayiP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z311mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_ObjectP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP26mscorlib_System_Object_arriP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache
  ,__Z423mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP121mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_Int32U002CUnityEngine_GUILayoutUtility_LayoutCacheU003E_arriP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL155mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_GUILayoutEntry_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP42UnityEngine_UnityEngine_GUILayoutEntry_arrii,__ZL169mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_ICollectionCopyTo_UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayiP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z190mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_ObjectP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP26mscorlib_System_Object_arriP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z200mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP36UnityEngine_UnityEngine_GUIStyle_arriP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z222mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_mscorlib_System_Collections_DictionaryEntryU002CU0020mscorlib_System_Collections_DictionaryEntryP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP47mscorlib_System_Collections_DictionaryEntry_arriP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry,__Z252mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_ICollectionCopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayiP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z273mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_ObjectP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP26mscorlib_System_Object_arriP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z366mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_Do_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP102mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CUnityEngine_GUIStyleU003E_arriP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL141mscorlib_System_Array_m_Resize_mscorlib_System_Byte_arr_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectPP34mscorlib_System_ByteU005BU005D_arrii,__Z67mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Int64P21mscorlib_System_Arrayix,__Z69mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Int64P21mscorlib_System_Arrayix,__Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_UInt64P21mscorlib_System_Arrayiy,__Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_UInt64P21mscorlib_System_Arrayiy,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj,__ZNKSt3__17collateIcE12do_transformEPKcS3_,__ZNKSt3__17collateIwE12do_transformEPKwS3_,__ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,__ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,__ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo14assign_sortkeyEPvP12Il2CppObjectP12Il2CppStringNS3_14CompareOptionsE,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal19copy_from_unmanagedE12Il2CppIntPtriP11Il2CppArrayi,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal17copy_to_unmanagedEP11Il2CppArrayi12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10WriteInt64E12Il2CppIntPtrix,__ZN6il2cpp6icalls8mscorlib6System4Type19GetInterfaceMapDataEP20Il2CppReflectionTypeS5_PP11Il2CppArrayS8_,__ZN6il2cpp2vm4Type15GetNameInternalERNSt3__119basic_ostringstreamIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEPK10Il2CppType20Il2CppTypeNameFormatb,_png_set_mem_fn,_png_set_error_fn,__Z22ValidateTlsfAllocationPvjiS_
  ,__Z14DrawGUITextureRK5RectTIfEP7Texture11ColorRGBA32PN5Unity8MaterialE,__ZN17PersistentManager32GetAllFileIDsAndClassIDsFromPathERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER13dynamic_arrayIxLj8EERS9_IiLj4EE,__ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE6insertENS_11__wrap_iterIPKS1_EERS6_,__ZN13ProxyTransfer8TransferINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_PKc17TransferMetaFlags,__Z19GetReflectionSamplePK12BaseRendererRK4AABBRK16ReflectionSamplePS5_,__Z19SetLightScissorRectRK5RectTIfES2_bR9GfxDevice,__ZN23ForwardVertexRenderLoop16PerformRenderingEbbb,__Z20RenderSceneDepthPassR13dynamic_arrayI16RenderObjectDataLj4EERK17ShaderReplaceDatabRN9ShaderLab17ShaderPassContextE,__ZN13RenderTexture9SetActiveEPS_i11CubemapFacej,__Z34GetAmbientAndLightProbeSHConstantsRK11VisibleNodeRK19SphericalHarmonics3bRS2_,__Z33CalculateLightShadowCenterAndTypeRK6CameraR8Vector4fRfS4_,__ZN18DeferredRenderLoop15RenderFinalPassEP13RenderTextureS1_b,__Z28RenderSceneShaderReplacementRK13dynamic_arrayI16RenderObjectDataLj4EEP6ShaderRKNSt3__112basic_stringIcNS6_11char_traitsIcEENS6_9allocatorIcEEEERN9ShaderLab17ShaderPassContextE,__ZL25PerformRenderingDepthPassR6CameraRK10Matrix4x4fRNSt3__16vectorI17RODataReplacement13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEEEbRN9ShaderLab17ShaderPassContextE,__ZNK15LODGroupManager17CalculateLODMasksERK17CullingParametersPhPf,__ZN6Camera6RenderER11CullResultsRN9ShaderLab17ShaderPassContextEi,__Z28RenderSceneShaderReplacementRK13dynamic_arrayI11VisibleNodeLj4EEP6ShaderRKNSt3__112basic_stringIcNS6_11char_traitsIcEENS6_9allocatorIcEEEERN9ShaderLab17ShaderPassContextE,__Z27CullLocalLightShadowCastersiibR11CullResults,__ZL37PostProcessCullResultsForSkyboxProbesPK9SceneNodePK4AABBR9IndexListPv,__ZN6Camera16StandaloneRenderEjP6ShaderRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,__Z25CalculateFocusedLightHullPK8Vector3fRS0_RK10MinMaxAABBRNSt3__16vectorIS_NS6_9allocatorIS_EEEE,__Z11ScheduleJobR8JobFencePFvPvES1_11JobPriority,__ZNK4Mesh14ExtractUvArrayEiPfi,__ZN8RendererC2E12RendererType10MemLabelId18ObjectCreationMode,__ZN13ProxyTransfer16TransferTypelessEPjPKc17TransferMetaFlags,__ZN13ProxyTransfer20TransferTypelessDataEjPvi,__ZN14SafeBinaryRead16TransferTypelessEPjPKc17TransferMetaFlags,__ZN14SafeBinaryRead20TransferTypelessDataEjPvi,__ZN18StreamedBinaryReadILb0EE16TransferTypelessEPjPKc17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE20TransferTypelessDataEjPvi
  ,__ZN18StreamedBinaryReadILb1EE16TransferTypelessEPjPKc17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE20TransferTypelessDataEjPvi,__ZN19StreamedBinaryWriteILb0EE16TransferTypelessEPjPKc17TransferMetaFlags,__ZN19StreamedBinaryWriteILb0EE20TransferTypelessDataEjPvi,__ZN22MemoryCacherReadBlocksC2EPPhij,__ZN12CachedReader8InitReadER15CacheReaderBasejj,__ZN5ImageC2Eii13TextureFormat,__ZNK4Mesh26GetSubMeshDrawBuffersRangeEib,__ZN16MeshVertexFormatC2EjRK18VertexChannelsInfob,_png_set_write_fn,__ZN14SafeBinaryRead8TransferIiEEvRT_PKc17TransferMetaFlags,__ZN14SafeBinaryRead8TransferIfEEvRT_PKc17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE8TransferINSt3__14pairI8UnityStrN11AssetBundle9AssetInfoEEEEEvRT_PKc17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE8TransferINSt3__14pairI8UnityStrN11AssetBundle9AssetInfoEEEEEvRT_PKc17TransferMetaFlags,__ZN13ProxyTransfer8TransferIN11AssetBundle9AssetInfoEEEvRT_PKc17TransferMetaFlags,__ZN18AssetBundleManager14AddPreloadDataEiR13dynamic_arrayINS_11PreloadDataELj8EEb,__ZN18AssetBundleManager29CollectPreloadDataRecursivelyERKNSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEERK13dynamic_arrayIiLj4EERNS0_3setIiNS0_4lessIiEENS3_IiEEEE,__Z27FindSeparatedPathComponentsPKcjc,__ZNSt3__16vectorIiNS_9allocatorIiEEE6insertENS_11__wrap_iterIPKiEERS5_,__ZN17PersistentManager19LoadObjectsThreadedEPiiR12LoadProgress,__ZN17PersistentManager25ExtractAwakeFromLoadQueueEPKijR18AwakeFromLoadQueue,__ZN15ResourceManager19PreloadDependenciesEiRNSt3__13setIiNS0_4lessIiEENS0_9allocatorIiEEEEb,__Z33BuildSerializationCommandQueueForI18StreamedBinaryReadILb0EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb,__Z33BuildSerializationCommandQueueForI19StreamedBinaryWriteILb0EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb,__Z33BuildSerializationCommandQueueForI13ProxyTransferEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb,__Z33BuildSerializationCommandQueueForI17RemapPPtrTransferEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb,__Z33BuildSerializationCommandQueueForI14SafeBinaryReadEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb,__Z33BuildSerializationCommandQueueForI18StreamedBinaryReadILb1EEEvRK34BuildSerializationCommandQueueArgsR32SerializationCommandQueueBuilderRP20AllowNameConversionsb,__ZN13ProxyTransfer8TransferI8MonoPPtrEEvRT_PKc17TransferMetaFlags,__ZN9Scripting26GetMethodWithSearchOptionsEP14ScriptingClassPKci
  ,__ZN13ProxyTransfer8TransferINSt3__16vectorI8GUIStyle13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_PKc17TransferMetaFlags,__ZN13ProxyTransfer8TransferINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_PKc17TransferMetaFlags,__ZN13ProxyTransfer8TransferI8Vector3fEEvRT_PKc17TransferMetaFlags,__Z18BuildScriptClassIdRK8UnityStrS1_S1_,__Z36scripting_class_get_method_from_nameP14ScriptingClassPKci,__ZL34GetComponentsImplementationRecurseILb0ELi1ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZL34GetComponentsImplementationRecurseILb0ELi1ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZL34GetComponentsImplementationRecurseILb0ELi0ELi0EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZL34GetComponentsImplementationRecurseILb0ELi0ELi2EEbRN5Unity10GameObjectEbRK17CompareParametersRK39GetComponentsImplementation_ReturnValue,__ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier30ELi16EEE6insertENS_11__wrap_iterIPKS2_EERS8_,__ZN14FileCacherReadC2ERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEjj,__Z13ReadFileCacheR15CacheReaderBasePvjj,__ZN23ShaderVariantCollection17WarmupShadersImplEPFvP6ShaderiPN9ShaderLab4PassERK16ShaderKeywordSetP10DynamicVBOPvES9_SA_,__ZN10MemoryFileC2EP14MemoryFileData14FilePermission10MemLabelId,__Z36LoadAssetWithSubAssetFromAssetBundleR11AssetBundleRKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP15ScriptingObjectRNS1_6vectorIP6ObjectNS5_ISE_EEEE,__Z34Matrix4x4_CUSTOM_INTERNAL_CALL_TRSRK8Vector3fRK11QuaternionfS1_,__Z34Display_CUSTOM_ActivateDisplayImpl6IntPtriii,__Z28Component_CUSTOM_SendMessageP15ScriptingObjectP15ScriptingStringS0_i,__Z29GameObject_CUSTOM_SendMessageP15ScriptingObjectP15ScriptingStringS0_i,__ZN13dynamic_arrayIN5Unity5Cloth26ClothConstrainCoefficientsELj4EE18resize_initializedEjRKS2_b,__Z18TransformPoints3x3RK10Matrix4x4fPK8Vector3fPS2_i,__ZN11SoundHandle8Instance13CreateChannelERS_b,__ZN11UnityEngine9AnimationL23InitializeDefaultValuesERKNS0_30AnimatorGenericBindingConstantEPKN7mecanim9animation14AvatarConstantEbRNS5_25ControllerBindingConstantE,__ZN11UnityEngine9AnimationL22GenerateBindingRecurseERK16TypeTreeIteratorP15ScriptingObjectN7mecanim5crc32ER13dynamic_arrayINS0_13CachedBindingELj4EE,__ZN13ProxyTransfer8TransferINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags,__ZN13ProxyTransfer8TransferINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_PKc17TransferMetaFlags,__ZN13ProxyTransfer8TransferI17AnimationCurveTplI8Vector3fEEEvRT_PKc17TransferMetaFlags,__ZN14SafeBinaryRead8TransferIjEEvRT_PKc17TransferMetaFlags,__ZN9BlobWriteC2ER13dynamic_arrayIhLj16EE24TransferInstructionFlags19BuildTargetPlatform,__ZN9BlobWrite8TransferIN7mecanim9animation12AvatarMemoryEEEvRT_PKc17TransferMetaFlags
  ,__ZN10Matrix4x4f6SetTRSERK8Vector3fRK11QuaternionfS2_,__ZN15TerrainRendererC2Ei4PPtrI11TerrainDataERK8Vector3f,__ZN14DetailRendererC2E4PPtrI11TerrainDataE8Vector3fi,__ZN21TreeBinaryTreeBuilder5SplitER14TreeBinaryTreeRK8Vector3fS4_i,__ZN12TreeRenderer21GenerateBillboardMeshER4MeshRK13dynamic_arrayIjLj4EEb,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE6insertENS_11__wrap_iterIPKS1_EERS7_,_gray_render_span,_Direct_Move,_Direct_Move_Orig,_Direct_Move_X,_Direct_Move_Orig_X,_Direct_Move_Y,_Direct_Move_Orig_Y,_t2_hints_stems,_ps_hints_t2mask,__ZN21MaterialPropertyBlock18AddPropertyTextureERKN9ShaderLab16FastPropertyNameE16TextureDimension9TextureID,__ZN6prcore6BitmapC2EjjRKNS_11PixelFormatE,_default_walker,_glBlendFuncSeparate__wrapper,_glBufferData__wrapper,_glBufferSubData__wrapper,_glColorMask__wrapper,_glDrawElements__wrapper,_glFramebufferRenderbuffer__wrapper,_glGetFramebufferAttachmentParameteriv__wrapper,_glGetProgramInfoLog__wrapper,_glGetShaderInfoLog__wrapper,_glRenderbufferStorage__wrapper,_glScissor__wrapper,_glShaderSource__wrapper,_glStencilFuncSeparate__wrapper,_glStencilOpSeparate__wrapper,_glUniformMatrix3fv__wrapper,_glUniformMatrix4fv__wrapper,_glViewport__wrapper,__Z18FillParamsBaseGLESjR20GpuProgramParametersP16PropertyNamesSetb,__ZN16UniformCacheGLES6CreateEPK20GpuProgramParametersii,__ZL17ExtractDefineBockRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_PS5_,__Z5SplitRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEcRNS_6vectorIS5_NS3_IS5_EEEEi,__ZL22AddTextureCombinerBodyRNSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEEijN8combiner8ChannelsE,__ZN18VirtActionInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPviS5_,__ZN18VirtActionInvoker2I17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS4_S4_,__ZN18VirtActionInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS5_i,__ZN18VirtActionInvoker2I17VoidPointerTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEP10MethodInfoPvS5_31UnityEngine_UnityEngine_Vector3,__ZN18VirtActionInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPviP22mscorlib_System_Object,__ZN23InterfaceActionInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS5_i,__ZN18VirtActionInvoker2I28mscorlib_System_ObjectTraitsS0_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS6_,__Z121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_PPv,__ZN16VirtFuncInvoker1I38UnityEngine_UnityEngine_UIVertexTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi,__ZN18VirtActionInvoker2I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPvi34UnityEngine_UnityEngine_UICharInfo,__ZN16VirtFuncInvoker1I40UnityEngine_UnityEngine_UICharInfoTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi,__ZN18VirtActionInvoker2I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPvi34UnityEngine_UnityEngine_UILineInfo,__ZN16VirtFuncInvoker1I40UnityEngine_UnityEngine_UILineInfoTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi,__ZN18VirtActionInvoker2I27mscorlib_System_Int32TraitsS0_E6InvokeEP10MethodInfoPvii,__ZN16VirtFuncInvoker1I57mscorlib_System_Security_Cryptography_RSAParametersTraits29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb,__ZN21InterfaceFuncInvoker1I30mscorlib_System_DateTimeTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I29mscorlib_System_DecimalTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN18VirtActionInvoker2I17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvS5_P22mscorlib_System_Object,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcjj,_emscripten_glBufferData__wrapper,_emscripten_glBufferSubData__wrapper,_emscripten_glUniform3i__wrapper,_emscripten_glUniformMatrix2fv__wrapper,_emscripten_glUniformMatrix3fv__wrapper,_emscripten_glUniformMatrix4fv__wrapper,_emscripten_glGetAttachedShaders__wrapper,_emscripten_glShaderSource__wrapper,_emscripten_glGetShaderSource__wrapper,_emscripten_glGetShaderInfoLog__wrapper,_emscripten_glGetShaderPrecisionFormat__wrapper,_emscripten_glGetProgramInfoLog__wrapper,_emscripten_glFramebufferRenderbuffer__wrapper,_emscripten_glGetFramebufferAttachmentParameteriv__wrapper,_emscripten_glGetInfoLogARB__wrapper,_emscripten_glVertexPointer__wrapper,_emscripten_glTexCoordPointer__wrapper,_emscripten_glColorPointer__wrapper,_emscripten_glDrawElements__wrapper,_emscripten_glDrawArraysInstanced__wrapper,_emscripten_glViewport__wrapper,_emscripten_glScissor__wrapper,_emscripten_glColorMask__wrapper,_emscripten_glRenderbufferStorage__wrapper,_emscripten_glBlendFuncSeparate__wrapper,_emscripten_glStencilFuncSeparate__wrapper,_emscripten_glStencilOpSeparate__wrapper,b63,b63,b63,b63
  ,b63,b63,b63];
  var FUNCTION_TABLE_viiiii = [b64,__ZNK5physx3Cct8SweptBox18computeTemporalBoxERKNS0_9SweepTestERNS_17PxExtendedBounds3ERKNS_14PxExtendedVec3ERKNS_6PxVec3E,__ZNK5physx3Cct12SweptCapsule18computeTemporalBoxERKNS0_9SweepTestERNS_17PxExtendedBounds3ERKNS_14PxExtendedVec3ERKNS_6PxVec3E,__ZN5physx14NpArticulation12applyImpulseEPNS_18PxArticulationLinkERKNS_24PxArticulationDriveCacheERKNS_6PxVec3ES8_,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE9addForcesEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEENS_11PxForceMode4EnumE,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE9addForcesEjRKNS_16PxStrideIteratorIKjEERKNS4_IKNS_6PxVec3EEENS_11PxForceMode4EnumE,__ZN5physx7NpCloth19setVirtualParticlesEjPKjjPKNS_6PxVec3E,__ZNK5physx5cloth9SwFactory10copyToHostEPKvS3_PvP11CUstream_st,__ZNK5physx5cloth9SwFactory12copyFromHostEPKvS3_PvP11CUstream_st,__ZThn4_NK5physx5cloth9SwFactory10copyToHostEPKvS3_PvP11CUstream_st,__ZThn4_NK5physx5cloth9SwFactory12copyFromHostEPKvS3_PvP11CUstream_st,__ZN5physx16PxsBroadPhaseMBP6updateEjjRKNS_23PxcBroadPhaseUpdateDataEPNS_10PxBaseTaskE,__ZN5physx23PxsBroadPhaseContextSap6updateEjjRKNS_23PxcBroadPhaseUpdateDataEPNS_10PxBaseTaskE,__ZN5physx25PxVehicleConstraintShader19visualiseConstraintERNS_22PxConstraintVisualizerEPKvRKNS_11PxTransformES7_j,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10startEventEtyj,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9stopEventEtyj,__ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10startEventEtyj,__ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9stopEventEtyj,__ZNK5physx2Gu16SupportLocalImplINS0_11ConvexHullVEE13populateVertsEPKhjPKNS_6PxVec3EPNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEE13populateVertsEPKhjPKNS_6PxVec3EPNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu16SupportLocalImplINS0_4BoxVEE13populateVertsEPKhjPKNS_6PxVec3EPNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_E9doSupportERKNS_6shdfnd3aos5Vec3VERS6_S9_S9_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_E9doSupportERKNS_6shdfnd3aos5Vec3VERS6_S9_S9_,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_
  ,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_E9doSupportERKNS_6shdfnd3aos5Vec3VERS6_S9_S9_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VERS7_SA_SA_,__ZNK5physx2Gu16SupportLocalImplINS0_9TriangleVEE13populateVertsEPKhjPKNS_6PxVec3EPNS_6shdfnd3aos5Vec3VE,__ZN9GfxDevice19RecordSetBlendStateEPK16DeviceBlendStateRKN9ShaderLab8FloatValEPKNS3_13PropertySheetERKNS3_17ShaderPassContextE,__ZN9GfxDevice15StaticBatchMeshEjjPKtj,__ZN9GfxDevice22DynamicBatchBillboardsEPKPK9BillboardiPfi,__ZN9GfxDevice19CreateComputeBufferE15ComputeBufferIDjjj,__ZN9GfxDevice22DispatchComputeProgramE12ObjectHandleI18ComputeProgram_TagPvEjjj,__ZN13ScreenManager17RequestResolutionEiibi,__ZN11ErrorStream11reportErrorEN5physx11PxErrorCode4EnumEPKcS4_i,__ZN13PhysicsModule29BakeNxMeshStreamFromUnityMeshEP4MeshbbR13dynamic_arrayIhLj1EE,__ZNK19TextRenderingModule22TMGenGetCursorPositionEPN13TextRendering17TextMeshGeneratorERK5RectTIfEi,__ZN13GfxDeviceGLES29SetTextureCombinersThreadableE12ObjectHandleI20TextureCombiners_TagPvEPK10TexEnvDataPK8Vector4fPK10ColorRGBAf,__Z36mscorlib_System_Int32_m_FindCurrencyP22mscorlib_System_ObjectPiP22mscorlib_System_StringP46mscorlib_System_Globalization_NumberFormatInfoPb,__Z153mscorlib_System_Decimal_m_Parse_mscorlib_System_Decimal_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_,__Z142mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P21mscorlib_System_ArrayP22mscorlib_System_Objectiii,__Z115mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int64P22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_x,__Z137mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_ii,__Z153mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayiiS0_,__Z158mscorlib_System_Array_m_combsort_mscorlib_System_Void_mscorlib_System_Double_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Array_SwapperP22mscorlib_System_ObjectP26mscorlib_System_Double_arriiP29mscorlib_System_Array_Swapper,__Z157mscorlib_System_Array_m_combsort_mscorlib_System_Void_mscorlib_System_Int32_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Array_SwapperP22mscorlib_System_ObjectP25mscorlib_System_Int32_arriiP29mscorlib_System_Array_Swapper,__Z156mscorlib_System_Array_m_combsort_mscorlib_System_Void_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Array_SwapperP22mscorlib_System_ObjectP24mscorlib_System_Char_arriiP29mscorlib_System_Array_Swapper,__Z137mscorlib_System_Array_m_swap_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_ii,__Z60mscorlib_Mono_Globalization_Unicode_CodePointIndexer_m__ctorP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerP25mscorlib_System_Int32_arrS2_ii,__Z57mscorlib_Mono_Globalization_Unicode_TailoringInfo_m__ctorP49mscorlib_Mono_Globalization_Unicode_TailoringInfoiiib,__Z79mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_BuildTailoringTablesP22mscorlib_System_ObjectP41mscorlib_System_Globalization_CultureInfoP49mscorlib_Mono_Globalization_Unicode_TailoringInfoPP51mscorlib_Mono_Globalization_Unicode_Contraction_arrPP49mscorlib_Mono_Globalization_Unicode_Level2Map_arr,__Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_FillSortKeyRawP50mscorlib_Mono_Globalization_Unicode_SimpleCollatoriiP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferi
  ,__Z62mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_InitializeP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferiiP22mscorlib_System_Stringb,__Z64mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendNormalP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhhhh,__Z172mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P54mscorlib_System_Collections_ArrayList_ArrayListWrapperiP21mscorlib_System_Arrayii,__Z155mscorlib_System_Collections_ArrayList_m_CopyTo_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListiP21mscorlib_System_Arrayii,__Z184mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperiP21mscorlib_System_Arrayii,__Z163mscorlib_System_Diagnostics_StackTrace_m__ctor_mscorlib_System_Void_mscorlib_System_Exception_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_System_BooleanP38mscorlib_System_Diagnostics_StackTraceP25mscorlib_System_Exceptionibb,__Z66mscorlib_System_Globalization_CCGregorianCalendar_m_dmy_from_fixedP22mscorlib_System_ObjectPiS1_S1_i,__Z46mscorlib_System_Globalization_TextInfo_m__ctorP38mscorlib_System_Globalization_TextInfoP41mscorlib_System_Globalization_CultureInfoiPvb,__Z199mscorlib_System_Reflection_ParameterInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Reflection_Emit_ParameterBuilder_mscorlib_System_Type_mscorlib_System_Reflection_MemberInfo_mscorlib_System_Int32P40mscorlib_System_Reflection_ParameterInfoP48mscorlib_System_Reflection_Emit_ParameterBuilderP20mscorlib_System_TypeP37mscorlib_System_Reflection_MemberInfoi,__Z69mscorlib_System_Runtime_InteropServices_Marshal_m_copy_from_unmanagedP22mscorlib_System_Object22mscorlib_System_IntPtriP21mscorlib_System_Arrayi,__Z54mscorlib_System_Runtime_InteropServices_Marshal_m_CopyP22mscorlib_System_Object22mscorlib_System_IntPtrP24mscorlib_System_Char_arrii,__Z152mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderP22mscorlib_System_Stringiii,__Z48mscorlib_System_Text_UnicodeEncoding_m_CopyCharsP22mscorlib_System_ObjectPhS1_ib,__Z39mscorlib_System_BitConverter_m_PutBytesP22mscorlib_System_ObjectPhP24mscorlib_System_Byte_arrii,__Z157mscorlib_System_DateTime_m_Parse_mscorlib_System_DateTime_mscorlib_System_String_mscorlib_System_IFormatProvider_mscorlib_System_Globalization_DateTimeStylesP22mscorlib_System_ObjectP22mscorlib_System_StringS0_i,__Z140mscorlib_System_Version_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P23mscorlib_System_Versioniiii,__Z53UnityEngine_UnityEngine_Application_m_CallLogCallbackP22mscorlib_System_ObjectP22mscorlib_System_StringS2_ib,__Z151UnityEngine_UnityEngine_RectOffset_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P34UnityEngine_UnityEngine_RectOffsetiiii,__Z39UnityEngine_UnityEngine_Color32_m__ctorP31UnityEngine_UnityEngine_Color32hhhh,__Z39UnityEngine_UnityEngine_Matrix4x4_m_TRSP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector334UnityEngine_UnityEngine_QuaternionS1_,__Z53UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_TRSP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3P34UnityEngine_UnityEngine_QuaternionS2_,__Z43UnityEngine_UnityEngine_Display_m_SetParamsP31UnityEngine_UnityEngine_Displayiiii,__Z53UnityEngine_UnityEngine_Display_m_ActivateDisplayImplP22mscorlib_System_Object22mscorlib_System_IntPtriii,__ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,__ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,__ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_jjRKS4_,__ZN13ProxyTransfer13BeginTransferEPKcS1_Pc17TransferMetaFlags,__ZN13ProxyTransfer18BeginArrayTransferEPKcS1_Ri17TransferMetaFlags,__Z18SetShadowsKeywordsRN9ShaderLab17ShaderPassContextE9LightType10ShadowTypebb
  ,__ZN13BatchRenderer12RenderSingleER12BaseRendererRK13TransformInfoiPK14ChannelAssigns,__ZN13BatchRenderer3AddER12BaseRendererRK13TransformInfoiPK14ChannelAssigns,__ZN17PrePassRenderLoop15RenderFinalPassEP13RenderTextureS1_bb,__Z16FindActiveLightsR13dynamic_arrayIPK5LightLj4EES4_RS_I8Vector4fLj4EERS_IiLj4EERK14ShadowCullData,__ZL13RenderCastersiRK5LightRK8Vector3fS4_RNSt3__16vectorI16ShadowCasterData13stl_allocatorIS7_L18MemLabelIdentifier90ELi16EEEERNS6_I20ShadowCasterPartDataS8_ISD_LS9_90ELi16EEEERK16ShadowCameraDataRN9ShaderLab17ShaderPassContextE,__ZN21MaterialPropertyBlockC2EPNS_8PropertyEjPfj,__ZN8DrawUtil11DrawMeshRawERK14ChannelAssignsR4MeshiiPS3_,__ZN18AwakeFromLoadQueue3AddER6ObjectPK8TypeTreeb17AwakeFromLoadMode,__ZN5Image8SetImageEii13TextureFormatb,__ZN9InputAxis13MakeAnalogKeyEiiii,__ZL25ProcessAssetBundleEntriesR11AssetBundleNSt3__14pairINS1_14__map_iteratorINS1_15__tree_iteratorINS1_12__value_typeI8UnityStrNS_9AssetInfoEEEPNS1_11__tree_nodeIS8_PvEEiEEEESE_EEP15ScriptingObjectRNS1_6vectorIP6ObjectNS1_9allocatorISK_EEEEb,__ZN18AssetBundleManager18CollectPreloadDataERKNSt3__16vectorI14ConstantStringNS0_9allocatorIS2_EEEER13dynamic_arrayIiLj4EEbb,__ZN14CachingManager15SetCurrentCacheERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEExb,__ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEC2INS_11__wrap_iterIPS1_EEEET_SA_RKS4_PNS_9enable_ifIXaasr21__is_forward_iteratorISA_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeE,__ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEC2INS_11__wrap_iterIPS1_EEEET_SA_RKS4_PNS_9enable_ifIXaasr21__is_forward_iteratorISA_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeE,__ZN12ShaderErrors14AddShaderErrorERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEibb,__ZN9ShaderLab16ParserSubProgram14AddVectorParamE15ShaderParamTypeiiRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,__ZN9ShaderLab16ParserSubProgram14AddMatrixParamE15ShaderParamTypeiRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEEi,__Z28Display_CUSTOM_SetParamsImpl6IntPtriiii,__ZL16AssignBoundCurveRK14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS0_EE13stl_allocatorINS2_4pairIKS0_jEEL18MemLabelIdentifier90ELi16EEERS7_P17AnimationCurveTplIfERK13dynamic_arrayI20BoundCurveDeprecatedLj4EER14AnimationState,__Z16CalculateWeightsILb1EEvPP14AnimationStateiiPfi,__Z16CalculateWeightsILb0EEvPP14AnimationStateiiPfi,__ZN11UnityEngine9Animation36GenerateTransformBindingMapRecursiveER9TransformRKN7mecanim5crc32ER13dynamic_arrayINS0_14BoundTransformELj4EEPKNS3_9animation14AvatarConstantEb,__ZNK5Unity8Material6GetTagERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEbS9_,__ZN21TreeBinaryTreeBuilder5BuildER12TreeDatabaseRK8Vector3fS4_i,__ZN12TreeRenderer13RenderRecurseEP14TreeBinaryTreePK5PlaneR13dynamic_arrayIjLj4EERK8Vector3f,_glFramebufferTexture2D__wrapper,__ZN17GenericDynamicVBOC2ER9GfxDevice13GfxBufferModejj,__ZN8combiner31DecodeTextureCombinerDescriptorEjRNS_9OperationEPNS_6SourceEPNS_7OperandERi,__ZL16AddTexOperandSrcRNSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEEEiN8combiner8ChannelsENS7_7OperandENS7_6SourceE
  ,__ZN18VirtActionInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEP10MethodInfoPvS5_ii,__ZN18VirtActionInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS5_S5_i,__ZN16VirtFuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_,__ZN16VirtFuncInvoker2I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS7_,__ZN16VirtFuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_,__ZN16VirtFuncInvoker2I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_,__ZN16VirtFuncInvoker2I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_,__ZN16VirtFuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_i,__ZN16VirtFuncInvoker2I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32Traits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_i,__ZN16VirtFuncInvoker2I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvS6_i,__ZN16VirtFuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPviS6_,__ZN16VirtFuncInvoker2I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPviS6_,__ZN16VirtFuncInvoker2I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraits17VoidPointerTraitsS1_E6InvokeEP10MethodInfoPvS5_S5_,_emscripten_glUniform4i__wrapper,_emscripten_glFramebufferTexture2D__wrapper,_emscripten_glShaderBinary__wrapper,_emscripten_glDrawElementsInstanced__wrapper,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64
  ,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64
  ,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64
  ,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64
  ,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64,b64];
  var FUNCTION_TABLE_iifffi = [b65,__ZN4Node6InsertEfffb];
  var FUNCTION_TABLE_vif = [b66,__ZN5physx3Cct13BoxController13setStepOffsetEf,__ZN5physx3Cct13BoxController16setContactOffsetEf,__ZN5physx3Cct13BoxController13setSlopeLimitEf,__ZN5physx3Cct13BoxController6resizeEf,__ZN5physx3Cct17CapsuleController13setStepOffsetEf,__ZN5physx3Cct17CapsuleController16setContactOffsetEf,__ZN5physx3Cct17CapsuleController13setSlopeLimitEf,__ZN5physx3Cct17CapsuleController6resizeEf,__ZN5physx14NpArticulation22setSeparationToleranceEf,__ZN5physx14NpArticulation17setSleepThresholdEf,__ZN5physx14NpArticulation25setStabilizationThresholdEf,__ZN5physx14NpArticulation14setWakeCounterEf,__ZN5physx19NpArticulationJoint12setStiffnessEf,__ZN5physx19NpArticulationJoint10setDampingEf,__ZN5physx19NpArticulationJoint21setInternalComplianceEf,__ZN5physx19NpArticulationJoint21setExternalComplianceEf,__ZN5physx19NpArticulationJoint22setTangentialStiffnessEf,__ZN5physx19NpArticulationJoint20setTangentialDampingEf,__ZN5physx19NpArticulationJoint28setSwingLimitContactDistanceEf,__ZN5physx19NpArticulationJoint28setTwistLimitContactDistanceEf,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE7setMassEf,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE27setMinCCDAdvanceCoefficientEf,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE27setMaxDepenetrationVelocityEf,__ZN5physx10NpMaterial18setDynamicFrictionEf,__ZN5physx10NpMaterial17setStaticFrictionEf,__ZN5physx10NpMaterial14setRestitutionEf,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE7setMassEf,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE27setMinCCDAdvanceCoefficientEf
  ,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE27setMaxDepenetrationVelocityEf,__ZN5physx14NpRigidDynamic16setLinearDampingEf,__ZN5physx14NpRigidDynamic17setAngularDampingEf,__ZN5physx14NpRigidDynamic21setMaxAngularVelocityEf,__ZN5physx14NpRigidDynamic17setSleepThresholdEf,__ZN5physx14NpRigidDynamic25setStabilizationThresholdEf,__ZN5physx14NpRigidDynamic14setWakeCounterEf,__ZN5physx14NpRigidDynamic25setContactReportThresholdEf,__ZN5physx7NpScene30setClothInterCollisionDistanceEf,__ZN5physx7NpScene31setClothInterCollisionStiffnessEf,__ZN5physx7NpScene26setBounceThresholdVelocityEf,__ZN5physx7NpShape16setContactOffsetEf,__ZN5physx7NpShape13setRestOffsetEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE10setDampingEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE15setParticleMassEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14setRestitutionEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE18setDynamicFrictionEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE17setStaticFrictionEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20setMaxMotionDistanceEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE13setRestOffsetEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE16setContactOffsetEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE11setGridSizeEf,__ZN5physx15NpParticleFluid12setStiffnessEf,__ZN5physx15NpParticleFluid12setViscosityEf,__ZN5physx15NpParticleFluid23setRestParticleDistanceEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE10setDampingEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE15setParticleMassEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14setRestitutionEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE18setDynamicFrictionEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE17setStaticFrictionEf
  ,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20setMaxMotionDistanceEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE13setRestOffsetEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE16setContactOffsetEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE11setGridSizeEf,__ZN5physx7NpCloth18setSolverFrequencyEf,__ZN5physx7NpCloth21setStiffnessFrequencyEf,__ZN5physx7NpCloth15setInertiaScaleEf,__ZN5physx7NpCloth18setDragCoefficientEf,__ZN5physx7NpCloth22setFrictionCoefficientEf,__ZN5physx7NpCloth21setCollisionMassScaleEf,__ZN5physx7NpCloth24setSelfCollisionDistanceEf,__ZN5physx7NpCloth25setSelfCollisionStiffnessEf,__ZN5physx7NpCloth16setContactOffsetEf,__ZN5physx7NpCloth13setRestOffsetEf,__ZN5physx7NpCloth22setSleepLinearVelocityEf,__ZN5physx7NpCloth14setWakeCounterEf,__ZN5physx13NpClothFabric16scaleRestlengthsEf,__ZN5physx5cloth8SwFabric15scaleRestvaluesEf,__ZN5physx5cloth8SwFabric18scaleTetherLengthsEf,__ZThn4_N5physx5cloth8SwFabric15scaleRestvaluesEf,__ZThn4_N5physx5cloth8SwFabric18scaleTetherLengthsEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE18setSolverFrequencyEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE21setStiffnessFrequencyEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE21setCollisionMassScaleEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE11setFrictionEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE24setTetherConstraintScaleEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE28setTetherConstraintStiffnessEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE28setMotionConstraintStiffnessEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE24setSelfCollisionDistanceEf,__ZN5physx5cloth9ClothImplINS0_7SwClothEE25setSelfCollisionStiffnessEf
  ,__ZN5physx5cloth9ClothImplINS0_7SwClothEE17setSleepThresholdEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE18setSolverFrequencyEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE21setStiffnessFrequencyEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE21setCollisionMassScaleEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setFrictionEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE24setTetherConstraintScaleEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE28setTetherConstraintStiffnessEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE28setMotionConstraintStiffnessEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE24setSelfCollisionDistanceEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE25setSelfCollisionStiffnessEf,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE17setSleepThresholdEf,__ZN5physx5cloth8SwSolver25setInterCollisionDistanceEf,__ZN5physx5cloth8SwSolver26setInterCollisionStiffnessEf,__ZThn4_N5physx5cloth8SwSolver25setInterCollisionDistanceEf,__ZThn4_N5physx5cloth8SwSolver26setInterCollisionStiffnessEf,__ZN5physx20PxsParticleSystemSim22setSimulationTimeStepVEf,__ZN9GfxDevice10SetLODFadeEf,__Z82AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectf,__Z80AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectf,__Z75mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_SingleP23mscorlib_System_Decimalf,__Z46UnityEngine_UnityEngine_WaitForSeconds_m__ctorP38UnityEngine_UnityEngine_WaitForSecondsf,__Z48UnityEngine_UnityEngine_BoneWeight_m_set_weight0P34UnityEngine_UnityEngine_BoneWeightf,__Z48UnityEngine_UnityEngine_BoneWeight_m_set_weight1P34UnityEngine_UnityEngine_BoneWeightf,__Z48UnityEngine_UnityEngine_BoneWeight_m_set_weight2P34UnityEngine_UnityEngine_BoneWeightf,__Z48UnityEngine_UnityEngine_BoneWeight_m_set_weight3P34UnityEngine_UnityEngine_BoneWeightf,__Z36UnityEngine_UnityEngine_Rect_m_set_xP28UnityEngine_UnityEngine_Rectf,__Z36UnityEngine_UnityEngine_Rect_m_set_yP28UnityEngine_UnityEngine_Rectf,__Z40UnityEngine_UnityEngine_Rect_m_set_widthP28UnityEngine_UnityEngine_Rectf,__Z41UnityEngine_UnityEngine_Rect_m_set_heightP28UnityEngine_UnityEngine_Rectf,__Z83UnityEngine_UnityEngine_Bounds_m_Expand_mscorlib_System_Void_mscorlib_System_SingleP30UnityEngine_UnityEngine_Boundsf
  ,__Z45UnityEngine_UnityEngine_Particle_m_set_energyP32UnityEngine_UnityEngine_Particlef,__Z50UnityEngine_UnityEngine_Particle_m_set_startEnergyP32UnityEngine_UnityEngine_Particlef,__Z43UnityEngine_UnityEngine_Particle_m_set_sizeP32UnityEngine_UnityEngine_Particlef,__Z47UnityEngine_UnityEngine_Particle_m_set_rotationP32UnityEngine_UnityEngine_Particlef,__Z54UnityEngine_UnityEngine_Particle_m_set_angularVelocityP32UnityEngine_UnityEngine_Particlef,__Z59UnityEngine_UnityEngine_AnimationEvent_m_set_floatParameterP38UnityEngine_UnityEngine_AnimationEventf,__Z49UnityEngine_UnityEngine_AnimationEvent_m_set_timeP38UnityEngine_UnityEngine_AnimationEventf,__Z50UnityEngine_UnityEngine_AnimationState_m_set_speedP38UnityEngine_UnityEngine_AnimationStatef,__Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_SingleP21mscorlib_System_Arrayf,__ZN5physx21PxcArticulationHelper12updateBodiesERKNS_25PxcArticulationSolverDescEf,__Z26setPxVehicleEngineDataMMOIPN5physx19PxVehicleEngineDataEf,__Z33setPxVehicleEngineDataMPeakTorquePN5physx19PxVehicleEngineDataEf,__Z31setPxVehicleEngineDataMMaxOmegaPN5physx19PxVehicleEngineDataEf,__Z46setPxVehicleEngineDataMDampingRateFullThrottlePN5physx19PxVehicleEngineDataEf,__Z59setPxVehicleEngineDataMDampingRateZeroThrottleClutchEngagedPN5physx19PxVehicleEngineDataEf,__Z62setPxVehicleEngineDataMDampingRateZeroThrottleClutchDisengagedPN5physx19PxVehicleEngineDataEf,__Z32setPxVehicleGearsDataMFinalRatioPN5physx18PxVehicleGearsDataEf,__Z32setPxVehicleGearsDataMSwitchTimePN5physx18PxVehicleGearsDataEf,__Z31setPxVehicleAutoBoxData_LatencyPN5physx20PxVehicleAutoBoxDataEf,__Z45setPxVehicleDifferential4WDataMFrontRearSplitPN5physx27PxVehicleDifferential4WDataEf,__Z50setPxVehicleDifferential4WDataMFrontLeftRightSplitPN5physx27PxVehicleDifferential4WDataEf,__Z49setPxVehicleDifferential4WDataMRearLeftRightSplitPN5physx27PxVehicleDifferential4WDataEf,__Z41setPxVehicleDifferential4WDataMCentreBiasPN5physx27PxVehicleDifferential4WDataEf,__Z40setPxVehicleDifferential4WDataMFrontBiasPN5physx27PxVehicleDifferential4WDataEf,__Z39setPxVehicleDifferential4WDataMRearBiasPN5physx27PxVehicleDifferential4WDataEf,__Z42setPxVehicleAckermannGeometryDataMAccuracyPN5physx30PxVehicleAckermannGeometryDataEf,__Z44setPxVehicleAckermannGeometryDataMFrontWidthPN5physx30PxVehicleAckermannGeometryDataEf,__Z43setPxVehicleAckermannGeometryDataMRearWidthPN5physx30PxVehicleAckermannGeometryDataEf,__Z48setPxVehicleAckermannGeometryDataMAxleSeparationPN5physx30PxVehicleAckermannGeometryDataEf,__Z31setPxVehicleClutchDataMStrengthPN5physx19PxVehicleClutchDataEf
  ,__Z48setPxVehicleTireLoadFilterDataMMinNormalisedLoadPN5physx27PxVehicleTireLoadFilterDataEf,__Z56setPxVehicleTireLoadFilterDataMMinFilteredNormalisedLoadPN5physx27PxVehicleTireLoadFilterDataEf,__Z48setPxVehicleTireLoadFilterDataMMaxNormalisedLoadPN5physx27PxVehicleTireLoadFilterDataEf,__Z56setPxVehicleTireLoadFilterDataMMaxFilteredNormalisedLoadPN5physx27PxVehicleTireLoadFilterDataEf,__Z28setPxVehicleWheelDataMRadiusPN5physx18PxVehicleWheelDataEf,__Z27setPxVehicleWheelDataMWidthPN5physx18PxVehicleWheelDataEf,__Z26setPxVehicleWheelDataMMassPN5physx18PxVehicleWheelDataEf,__Z25setPxVehicleWheelDataMMOIPN5physx18PxVehicleWheelDataEf,__Z33setPxVehicleWheelDataMDampingRatePN5physx18PxVehicleWheelDataEf,__Z36setPxVehicleWheelDataMMaxBrakeTorquePN5physx18PxVehicleWheelDataEf,__Z40setPxVehicleWheelDataMMaxHandBrakeTorquePN5physx18PxVehicleWheelDataEf,__Z30setPxVehicleWheelDataMMaxSteerPN5physx18PxVehicleWheelDataEf,__Z30setPxVehicleWheelDataMToeAnglePN5physx18PxVehicleWheelDataEf,__Z58setPxVehicleSuspensionData_MassAndPreserveNaturalFrequencyPN5physx23PxVehicleSuspensionDataEf,__Z41setPxVehicleSuspensionDataMSpringStrengthPN5physx23PxVehicleSuspensionDataEf,__Z43setPxVehicleSuspensionDataMSpringDamperRatePN5physx23PxVehicleSuspensionDataEf,__Z41setPxVehicleSuspensionDataMMaxCompressionPN5physx23PxVehicleSuspensionDataEf,__Z35setPxVehicleSuspensionDataMMaxDroopPN5physx23PxVehicleSuspensionDataEf,__Z37setPxVehicleSuspensionDataMSprungMassPN5physx23PxVehicleSuspensionDataEf,__Z39setPxVehicleSuspensionDataMCamberAtRestPN5physx23PxVehicleSuspensionDataEf,__Z49setPxVehicleSuspensionDataMCamberAtMaxCompressionPN5physx23PxVehicleSuspensionDataEf,__Z43setPxVehicleSuspensionDataMCamberAtMaxDroopPN5physx23PxVehicleSuspensionDataEf,__Z30setPxVehicleTireDataMLatStiffXPN5physx17PxVehicleTireDataEf,__Z30setPxVehicleTireDataMLatStiffYPN5physx17PxVehicleTireDataEf,__Z56setPxVehicleTireDataMLongitudinalStiffnessPerUnitGravityPN5physx17PxVehicleTireDataEf,__Z50setPxVehicleTireDataMCamberStiffnessPerUnitGravityPN5physx17PxVehicleTireDataEf,__Z37setPxVehicleWheelsSimData_ChassisMassPN5physx22PxVehicleWheelsSimDataEf,__Z48setPxVehicleWheelsSimData_MinLongSlipDenominatorPN5physx22PxVehicleWheelsSimDataEf,__Z44setPxVehicleDriveDynData_EngineRotationSpeedPN5physx21PxVehicleDriveDynDataEf,__Z39setPxVehicleDriveDynData_GearSwitchTimePN5physx21PxVehicleDriveDynDataEf
  ,__Z42setPxVehicleDriveDynData_AutoBoxSwitchTimePN5physx21PxVehicleDriveDynDataEf,__Z36setPxVehicleDriveDynDataMEnginespeedPN5physx21PxVehicleDriveDynDataEf,__Z39setPxVehicleDriveDynDataMGearSwitchTimePN5physx21PxVehicleDriveDynDataEf,__Z42setPxVehicleDriveDynDataMAutoBoxSwitchTimePN5physx21PxVehicleDriveDynDataEf,__ZN12LightManager20SetupForwardAddLightEP5Lightf,__ZN15QualitySettings28SetShadowDistanceTemporarilyEf,__ZN6Camera7SetNearEf,__ZN6Camera6SetFarEf,__ZN6Camera9SetAspectEf,__Z21Object_CUSTOM_DestroyP15ScriptingObjectf,__ZN8Animator8InitStepEf,__Z35AnimationState_Set_Custom_PropSpeedP15ScriptingObjectf,_emscripten_glUniform1f__wrapper,_emscripten_glVertexAttrib1f__wrapper,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66
  ,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66
  ,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66,b66];
  var FUNCTION_TABLE_vid = [b67,__Z75mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_DoubleP23mscorlib_System_Decimald,__Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DoubleP21mscorlib_System_Arrayd,b67];
  var FUNCTION_TABLE_iiidi = [b68,__Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Double_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringdS0_];
  var FUNCTION_TABLE_viiidii = [b69,__ZN14AnimationState4InitERK8UnityStrP13AnimationClipdib];
  var FUNCTION_TABLE_vii = [b70,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE,__ZNK5physx3Cct13BoxController15getFootPositionEv,__ZN5physx3Cct13BoxController18setNonWalkableModeENS_27PxControllerNonWalkableMode4EnumE,__ZNK5physx3Cct13BoxController14getUpDirectionEv,__ZN5physx3Cct13BoxController14setUpDirectionERKNS_6PxVec3E,__ZN5physx3Cct13BoxController11setUserDataEPv,__ZNK5physx3Cct13BoxController8getStateERNS_17PxControllerStateE,__ZNK5physx3Cct13BoxController8getStatsERNS_17PxControllerStatsE,__ZNK5physx3Cct17CapsuleController15getFootPositionEv,__ZN5physx3Cct17CapsuleController18setNonWalkableModeENS_27PxControllerNonWalkableMode4EnumE,__ZNK5physx3Cct17CapsuleController14getUpDirectionEv,__ZN5physx3Cct17CapsuleController14setUpDirectionERKNS_6PxVec3E,__ZN5physx3Cct17CapsuleController11setUserDataEPv,__ZNK5physx3Cct17CapsuleController8getStateERNS_17PxControllerStateE,__ZNK5physx3Cct17CapsuleController8getStatsERNS_17PxControllerStatsE,__ZN5physx3Cct26CharacterControllerManager22setDebugRenderingFlagsENS_7PxFlagsINS_27PxControllerDebugRenderFlag4EnumEjEE,__ZN5physx3Cct26CharacterControllerManager24setOverlapRecoveryModuleEb,__ZN5physx3Cct26CharacterControllerManager16setPreciseSweepsEb,__ZN5physx3Cct26CharacterControllerManager39setPreventVerticalSlidingAgainstCeilingEb,__ZN5physx3Cct26CharacterControllerManager11shiftOriginERKNS_6PxVec3E,__ZN5physx2Cm12RenderBuffer6appendERKNS_14PxRenderBufferE,__ZN5physx11NpAggregate15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx11NpAggregate8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx14NpArticulation26setMaxProjectionIterationsEj,__ZN5physx14NpArticulation26setInternalDriveIterationsEj,__ZN5physx14NpArticulation26setExternalDriveIterationsEj,__ZN5physx14NpArticulation7setNameEPKc,__ZNK5physx14NpArticulation17releaseDriveCacheERNS_24PxArticulationDriveCacheE
  ,__ZN5physx14NpArticulation15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx14NpArticulation8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx19NpArticulationJoint13setParentPoseERKNS_11PxTransformE,__ZNK5physx19NpArticulationJoint13getParentPoseEv,__ZN5physx19NpArticulationJoint12setChildPoseERKNS_11PxTransformE,__ZNK5physx19NpArticulationJoint12getChildPoseEv,__ZN5physx19NpArticulationJoint20setTargetOrientationERKNS_6PxQuatE,__ZNK5physx19NpArticulationJoint20getTargetOrientationEv,__ZN5physx19NpArticulationJoint17setTargetVelocityERKNS_6PxVec3E,__ZNK5physx19NpArticulationJoint17getTargetVelocityEv,__ZN5physx19NpArticulationJoint20setSwingLimitEnabledEb,__ZN5physx19NpArticulationJoint20setTwistLimitEnabledEb,__ZN5physx19NpArticulationJoint17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx19NpArticulationJoint8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE7setNameEPKc,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE,__ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE13getActorFlagsEv,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE17setDominanceGroupEh,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE14setOwnerClientEh,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE,__ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE22getClientBehaviorFlagsEv,__ZNK5physx18NpArticulationLink13getGlobalPoseEv,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE11attachShapeERNS_7PxShapeE,__ZN5physx18NpArticulationLink17setCMassLocalPoseERKNS_11PxTransformE,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17getCMassLocalPoseEv,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25setMassSpaceInertiaTensorERKNS_6PxVec3E,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE25getMassSpaceInertiaTensorEv,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE28getMassSpaceInvInertiaTensorEv,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17getLinearVelocityEv,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE18getAngularVelocityEv
  ,__ZN5physx18NpArticulationLink10clearForceENS_11PxForceMode4EnumE,__ZN5physx18NpArticulationLink11clearTorqueENS_11PxForceMode4EnumE,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE20setRigidDynamicFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17setRigidBodyFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE20getRigidDynamicFlagsEv,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE17getRigidBodyFlagsEv,__ZN5physx18NpArticulationLink15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx18NpArticulationLink17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx18NpArticulationLink8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx18NpArticulationLink13setGlobalPoseERKNS_11PxTransformE,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE11attachShapeERNS_7PxShapeE,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx12NpBatchQuery13setUserMemoryERKNS_18PxBatchQueryMemoryE,__ZN5physx12NpBatchQuery11setRunOnSpuEb,__ZN5physx12NpConstraint8setFlagsENS_7PxFlagsINS_16PxConstraintFlag4EnumEtEE,__ZNK5physx12NpConstraint8getFlagsEv,__ZN5physx12NpConstraint8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx10NpMaterial8setFlagsENS_7PxFlagsINS_14PxMaterialFlag4EnumEtEE,__ZNK5physx10NpMaterial8getFlagsEv,__ZN5physx10NpMaterial22setFrictionCombineModeENS_13PxCombineMode4EnumE,__ZN5physx10NpMaterial25setRestitutionCombineModeENS_13PxCombineMode4EnumE,__ZN5physx10NpMaterial17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx10NpMaterial8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx9NpPhysics26unregisterDeletionListenerERNS_18PxDeletionListenerE
  ,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE7setNameEPKc,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE,__ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE13getActorFlagsEv,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE17setDominanceGroupEh,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE14setOwnerClientEh,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE,__ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE22getClientBehaviorFlagsEv,__ZNK5physx14NpRigidDynamic13getGlobalPoseEv,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE11attachShapeERNS_7PxShapeE,__ZN5physx14NpRigidDynamic17setCMassLocalPoseERKNS_11PxTransformE,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17getCMassLocalPoseEv,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25setMassSpaceInertiaTensorERKNS_6PxVec3E,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE25getMassSpaceInertiaTensorEv,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE28getMassSpaceInvInertiaTensorEv,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17getLinearVelocityEv,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE18getAngularVelocityEv,__ZN5physx14NpRigidDynamic10clearForceENS_11PxForceMode4EnumE,__ZN5physx14NpRigidDynamic11clearTorqueENS_11PxForceMode4EnumE,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE20setRigidDynamicFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17setRigidBodyFlagsENS_7PxFlagsINS_15PxRigidBodyFlag4EnumEhEE,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE20getRigidDynamicFlagsEv,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE17getRigidBodyFlagsEv,__ZN5physx14NpRigidDynamic18setKinematicTargetERKNS_11PxTransformE,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx14NpRigidDynamic8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE11attachShapeERNS_7PxShapeE,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE
  ,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE7setNameEPKc,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE,__ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE13getActorFlagsEv,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE17setDominanceGroupEh,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE14setOwnerClientEh,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE,__ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE22getClientBehaviorFlagsEv,__ZNK5physx13NpRigidStatic13getGlobalPoseEv,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE11attachShapeERNS_7PxShapeE,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx13NpRigidStatic8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE17resolveReferencesERNS_24PxDeserializationContextE,__ZNK5physx7NpScene8getFlagsEv,__ZN5physx7NpScene9setLimitsERKNS_13PxSceneLimitsE,__ZNK5physx7NpScene9getLimitsEv,__ZN5physx7NpScene15addArticulationERNS_14PxArticulationE,__ZN5physx7NpScene8addActorERNS_7PxActorE,__ZN5physx7NpScene12addAggregateERNS_11PxAggregateE,__ZN5physx7NpScene13addCollectionERKNS_12PxCollectionE,__ZN5physx7NpScene34setClothInterCollisionNbIterationsEj,__ZN5physx7NpScene24setContactModifyCallbackEPNS_23PxContactModifyCallbackE,__ZN5physx7NpScene27setCCDContactModifyCallbackEPNS_26PxCCDContactModifyCallbackE,__ZN5physx7NpScene14resetFilteringERNS_7PxActorE
  ,__ZN5physx7NpScene5flushEb,__ZN5physx7NpScene15flushSimulationEb,__ZN5physx7NpScene10setGravityERKNS_6PxVec3E,__ZNK5physx7NpScene10getGravityEv,__ZN5physx7NpScene15setCCDMaxPassesEj,__ZN5physx7NpScene15setFrictionTypeENS_14PxFrictionType4EnumE,__ZN5physx7NpScene26setVisualizationCullingBoxERKNS_9PxBounds3E,__ZNK5physx7NpScene23getSimulationStatisticsERNS_22PxSimulationStatisticsE,__ZN5physx7NpScene29setDynamicTreeRebuildRateHintEj,__ZN5physx7NpScene22setNbContactDataBlocksEj,__ZN5physx7NpScene18setSolverBatchSizeEj,__ZN5physx7NpScene11shiftOriginERKNS_6PxVec3E,__ZN5physx7NpShape11setGeometryERKNS_10PxGeometryE,__ZNK5physx7NpShape11getGeometryEv,__ZN5physx7NpShape12setLocalPoseERKNS_11PxTransformE,__ZNK5physx7NpShape12getLocalPoseEv,__ZN5physx7NpShape23setSimulationFilterDataERKNS_12PxFilterDataE,__ZNK5physx7NpShape23getSimulationFilterDataEv,__ZN5physx7NpShape18setQueryFilterDataERKNS_12PxFilterDataE,__ZNK5physx7NpShape18getQueryFilterDataEv,__ZN5physx7NpShape8setFlagsENS_7PxFlagsINS_11PxShapeFlag4EnumEhEE,__ZNK5physx7NpShape8getFlagsEv,__ZN5physx7NpShape7setNameEPKc,__ZN5physx7NpShape15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx7NpShape8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx13NpVolumeCache7forEachERNS_13PxVolumeCache8IteratorE,__ZN5physx13NpVolumeCache20setMaxNbStaticShapesEj,__ZN5physx13NpVolumeCache21setMaxNbDynamicShapesEj,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE7setNameEPKc,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE
  ,__ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE13getActorFlagsEv,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE17setDominanceGroupEh,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE14setOwnerClientEh,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE,__ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE22getClientBehaviorFlagsEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23getExternalAccelerationEv,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23setExternalAccelerationERKNS_6PxVec3E,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23setSimulationFilterDataERKNS_12PxFilterDataE,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23getSimulationFilterDataEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20getParticleBaseFlagsEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE24getParticleReadDataFlagsEv,__ZN5physx15NpParticleFluid15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx15NpParticleFluid8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx23NpParticleFluidReadData18getDataAccessFlagsEv,__ZN5physx23NpParticleFluidReadData18setDataAccessFlagsENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE7setNameEPKc,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE,__ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE13getActorFlagsEv,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE17setDominanceGroupEh,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE14setOwnerClientEh,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE,__ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE22getClientBehaviorFlagsEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23getExternalAccelerationEv,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23setExternalAccelerationERKNS_6PxVec3E,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23setSimulationFilterDataERKNS_12PxFilterDataE,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23getSimulationFilterDataEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20getParticleBaseFlagsEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE24getParticleReadDataFlagsEv
  ,__ZN5physx16NpParticleSystem15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx16NpParticleSystem8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15NpActorTemplateINS_7PxClothEE7setNameEPKc,__ZN5physx15NpActorTemplateINS_7PxClothEE13setActorFlagsENS_7PxFlagsINS_11PxActorFlag4EnumEtEE,__ZNK5physx15NpActorTemplateINS_7PxClothEE13getActorFlagsEv,__ZN5physx15NpActorTemplateINS_7PxClothEE17setDominanceGroupEh,__ZN5physx15NpActorTemplateINS_7PxClothEE14setOwnerClientEh,__ZN5physx15NpActorTemplateINS_7PxClothEE22setClientBehaviorFlagsENS_7PxFlagsINS_25PxActorClientBehaviorFlag4EnumEhEE,__ZNK5physx15NpActorTemplateINS_7PxClothEE22getClientBehaviorFlagsEv,__ZN5physx7NpCloth13setClothFlagsENS_7PxFlagsINS_11PxClothFlag4EnumEtEE,__ZNK5physx7NpCloth13getClothFlagsEv,__ZN5physx7NpCloth13setTargetPoseERKNS_11PxTransformE,__ZN5physx7NpCloth13setGlobalPoseERKNS_11PxTransformE,__ZNK5physx7NpCloth13getGlobalPoseEv,__ZN5physx7NpCloth21setLinearInertiaScaleENS_6PxVec3E,__ZNK5physx7NpCloth21getLinearInertiaScaleEv,__ZN5physx7NpCloth22setAngularInertiaScaleENS_6PxVec3E,__ZNK5physx7NpCloth22getAngularInertiaScaleEv,__ZN5physx7NpCloth26setCentrifugalInertiaScaleENS_6PxVec3E,__ZNK5physx7NpCloth26getCentrifugalInertiaScaleEv,__ZN5physx7NpCloth21setDampingCoefficientENS_6PxVec3E,__ZNK5physx7NpCloth21getDampingCoefficientEv,__ZN5physx7NpCloth24setLinearDragCoefficientENS_6PxVec3E,__ZNK5physx7NpCloth24getLinearDragCoefficientEv,__ZN5physx7NpCloth25setAngularDragCoefficientENS_6PxVec3E,__ZNK5physx7NpCloth25getAngularDragCoefficientEv,__ZN5physx7NpCloth23setExternalAccelerationENS_6PxVec3E,__ZNK5physx7NpCloth23getExternalAccelerationEv
  ,__ZN5physx7NpCloth24setParticleAccelerationsEPKNS_6PxVec4E,__ZN5physx7NpCloth20setMotionConstraintsEPKNS_31PxClothParticleMotionConstraintE,__ZN5physx7NpCloth25setMotionConstraintConfigERKNS_29PxClothMotionConstraintConfigE,__ZNK5physx7NpCloth25getMotionConstraintConfigEv,__ZN5physx7NpCloth24setSeparationConstraintsEPKNS_35PxClothParticleSeparationConstraintE,__ZN5physx7NpCloth15setTetherConfigERKNS_19PxClothTetherConfigE,__ZNK5physx7NpCloth15getTetherConfigEv,__ZN5physx7NpCloth18addCollisionSphereERKNS_22PxClothCollisionSphereE,__ZN5physx7NpCloth21removeCollisionSphereEj,__ZN5physx7NpCloth22removeCollisionCapsuleEj,__ZN5physx7NpCloth17addCollisionPlaneERKNS_21PxClothCollisionPlaneE,__ZN5physx7NpCloth20removeCollisionPlaneEj,__ZN5physx7NpCloth18addCollisionConvexEj,__ZN5physx7NpCloth21removeCollisionConvexEj,__ZN5physx7NpCloth20addCollisionTriangleERKNS_24PxClothCollisionTriangleE,__ZN5physx7NpCloth23removeCollisionTriangleEj,__ZNK5physx7NpCloth19getVirtualParticlesEPj,__ZNK5physx7NpCloth25getVirtualParticleWeightsEPNS_6PxVec3E,__ZN5physx7NpCloth16setRestPositionsEPKNS_6PxVec4E,__ZN5physx7NpCloth23setSimulationFilterDataERKNS_12PxFilterDataE,__ZNK5physx7NpCloth23getSimulationFilterDataEv,__ZN5physx7NpCloth15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx7NpCloth17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx7NpCloth8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx15NpActorTemplateINS_7PxClothEE15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15NpActorTemplateINS_7PxClothEE17resolveReferencesERNS_24PxDeserializationContextE,__ZN5physx13NpClothFabric15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx13NpClothFabric8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx19NpClothParticleData18getDataAccessFlagsEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE19getCurrentParticlesEv
  ,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE19getCurrentParticlesEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE20getPreviousParticlesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE20getPreviousParticlesEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE15getGpuParticlesEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE14setTranslationERKNS_6PxVec3E,__ZN5physx5cloth9ClothImplINS0_7SwClothEE11setRotationERKNS_6PxQuatE,__ZN5physx5cloth9ClothImplINS0_7SwClothEE8teleportERKNS_6PxVec3E,__ZN5physx5cloth9ClothImplINS0_7SwClothEE10setGravityERKNS_6PxVec3E,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE10getGravityEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE10setDampingERKNS_6PxVec3E,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE10getDampingEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE13setLinearDragERKNS_6PxVec3E,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE13getLinearDragEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE14setAngularDragERKNS_6PxVec3E,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE14getAngularDragEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE16setLinearInertiaERKNS_6PxVec3E,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE16getLinearInertiaEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE17setAngularInertiaERKNS_6PxVec3E,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE17getAngularInertiaEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE21setCentrifugalInertiaERKNS_6PxVec3E,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE21getCentrifugalInertiaEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE25setAcceleationFilterWidthEj,__ZN5physx5cloth9ClothImplINS0_7SwClothEE14setPhaseConfigENS0_5RangeIKNS0_11PhaseConfigEEE,__ZN5physx5cloth9ClothImplINS0_7SwClothEE25enableContinuousCollisionEb,__ZN5physx5cloth9ClothImplINS0_7SwClothEE20getMotionConstraintsEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE24getSeparationConstraintsEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE24getParticleAccelerationsEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE23setSelfCollisionIndicesENS0_5RangeIKjEE,__ZN5physx5cloth9ClothImplINS0_7SwClothEE16setRestPositionsENS0_5RangeIKNS_6PxVec4EEE,__ZN5physx5cloth9ClothImplINS0_7SwClothEE20setSleepTestIntervalEj
  ,__ZN5physx5cloth9ClothImplINS0_7SwClothEE18setSleepAfterCountEj,__ZN5physx5cloth9ClothImplINS0_7SwClothEE11setUserDataEPv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE19getCurrentParticlesEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE19getCurrentParticlesEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE20getPreviousParticlesEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE20getPreviousParticlesEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE15getGpuParticlesEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE14setTranslationERKNS_6PxVec3E,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setRotationERKNS_6PxQuatE,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE8teleportERKNS_6PxVec3E,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE10setGravityERKNS_6PxVec3E,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE10getGravityEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE10setDampingERKNS_6PxVec3E,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE10getDampingEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE13setLinearDragERKNS_6PxVec3E,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE13getLinearDragEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE14setAngularDragERKNS_6PxVec3E,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE14getAngularDragEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE16setLinearInertiaERKNS_6PxVec3E,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE16getLinearInertiaEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE17setAngularInertiaERKNS_6PxVec3E,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE17getAngularInertiaEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE21setCentrifugalInertiaERKNS_6PxVec3E,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE21getCentrifugalInertiaEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE25setAcceleationFilterWidthEj,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE14setPhaseConfigENS0_5RangeIKNS0_11PhaseConfigEEE,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE25enableContinuousCollisionEb,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE20getMotionConstraintsEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE24getSeparationConstraintsEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE24getParticleAccelerationsEv
  ,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE23setSelfCollisionIndicesENS0_5RangeIKjEE,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE16setRestPositionsENS0_5RangeIKNS_6PxVec4EEE,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE20setSleepTestIntervalEj,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE18setSleepAfterCountEj,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE11setUserDataEPv,__ZN5physx5cloth8SwSolver8addClothEPNS0_5ClothE,__ZN5physx5cloth8SwSolver11removeClothEPNS0_5ClothE,__ZN5physx5cloth8SwSolver29setInterCollisionNbIterationsEj,__ZN5physx5cloth8SwSolver23setInterCollisionFilterEPFbPvS2_E,__ZThn4_N5physx5cloth8SwSolver8addClothEPNS0_5ClothE,__ZThn4_N5physx5cloth8SwSolver11removeClothEPNS0_5ClothE,__ZThn4_N5physx5cloth8SwSolver29setInterCollisionNbIterationsEj,__ZThn4_N5physx5cloth8SwSolver23setInterCollisionFilterEPFbPvS2_E,__ZN5physx16PxsBroadPhaseMBP11shiftOriginERKNS_6PxVec3E,__ZN5physx23PxsBroadPhaseContextSap11shiftOriginERKNS_6PxVec3E,__ZN5physx11NodeManager6resizeEj,__ZN5physx11EdgeManager6resizeEj,__ZN5physx13IslandManager6resizeEj,__ZN5physx23ArticulationRootManager6resizeEj,__ZNK5physx15PxsParticleData15getWorldBoundsVEv,__ZNK5physx16PxsParticleShape10getBoundsVEv,__ZN5physx16PxsParticleShape12setUserDataVEPv,__ZNK5physx20PxsParticleSystemSim16getShapesUpdateVERNS_29PxvParticleShapeUpdateResultsE,__ZN5physx20PxsParticleSystemSim24setExternalAccelerationVERKNS_6PxVec3E,__ZN5physx20PxsParticleSystemSim13setSimulatedVEb,__ZN5physx20PxsParticleSystemSim19passCollisionInputVENS_31PxvParticleCollisionUpdateInputE,__ZN5physx12solveContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx7solve1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx20solveContact_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx20solveConcludeContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE
  ,__ZN5physx15solveConclude1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx28solveConcludeContact_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx19solveContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx27solveContactCoulomb_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx13solveFrictionERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx21solveFriction_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx27solveConcludeContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx35solveConcludeContactCoulomb_BStaticERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx15concludeContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx10conclude1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx22concludeContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx2Sq10AABBPruner11preallocateEj,__ZN5physx2Sq10AABBPruner11shiftOriginERKNS_6PxVec3E,__ZN5physx2Sq12BucketPruner11preallocateEj,__ZN5physx2Sq12BucketPruner11shiftOriginERKNS_6PxVec3E,__ZN5physx2Sq11PruningPool11shiftOriginERKNS_6PxVec3E,__ZN5physx15PxVehicleWheels8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx16PxVehicleNoDrive15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx15PxVehicleWheels15exportExtraDataERNS_22PxSerializationContextE,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallback7processE_4S4_,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallback7processE_3S4_,__ZZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallback7processE_2S4_,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallback7processE_1S4_,__ZN5physx25PxVehicleConstraintShader10onComShiftEj,__ZN5physx25PxVehicleConstraintShader13onOriginShiftERKNS_6PxVec3E,__ZN5physx7Cooking9setParamsERKNS_15PxCookingParamsE,__ZNK5physx2Gu12TriangleMesh20getTriangleMeshFlagsEv,__ZNK5physx2Gu12TriangleMesh14getLocalBoundsEv,__ZN5physx2Gu12TriangleMesh15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx2Gu12TriangleMesh8requiresERNS_23PxProcessPxBaseCallbackE
  ,__ZNK5physx2Gu10ConvexMesh14getLocalBoundsEv,__ZN5physx2Gu10ConvexMesh15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx2Gu10ConvexMesh8requiresERNS_23PxProcessPxBaseCallbackE,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21setUserCustomProfilerEPNS_20PxUserCustomProfilerE,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21setProfileZoneManagerEPNS_20PxProfileZoneManagerE,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9addClientERNS_19PxProfileZoneClientE,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE12removeClientERNS_19PxProfileZoneClientE,__ZNK5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE15getProfileNamesEv,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE9addClientERNS_19PxProfileZoneClientE,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE12removeClientERNS_19PxProfileZoneClientE,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21setProfileZoneManagerEPNS_20PxProfileZoneManagerE,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21setUserCustomProfilerEPNS_20PxUserCustomProfilerE,__ZThn120_NK5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE15getProfileNamesEv,__ZN5physx9PxTaskMgr16setCpuDispatcherERNS_15PxCpuDispatcherE,__ZN5physx9PxTaskMgr16setGpuDispatcherERNS_15PxGpuDispatcherE,__ZN5physx9PxTaskMgr16setSpuDispatcherERNS_15PxSpuDispatcherE,__ZN5physx9PxTaskMgr19initializeProfilingERNS_20PxProfileZoneManagerE,__ZN5physx9PxTaskMgr13taskCompletedERNS_6PxTaskE,__ZN5physx9PxTaskMgr12addReferenceEm,__ZN5physx9PxTaskMgr13decrReferenceEm,__ZN5physx9PxTaskMgr13decrReferenceERNS_14PxLightCpuTaskE,__ZN5physx9PxTaskMgr12addReferenceERNS_14PxLightCpuTaskE,__ZN5physx9PxTaskMgr13decrReferenceERNS_9PxSpuTaskE,__ZN5physx6shdfnd10Foundation13setErrorLevelENS_11PxErrorCode4EnumE,__ZN5physx6shdfnd10Foundation24setReportAllocationNamesEb,__ZN5physx6shdfnd10Foundation19AlignCheckAllocator10deallocateEPv,__ZN5physx6shdfnd10Foundation19AlignCheckAllocator26registerAllocationListenerERNS_20PxAllocationListenerE,__ZN5physx6shdfnd10Foundation19AlignCheckAllocator28deregisterAllocationListenerERNS_20PxAllocationListenerE,__ZNK5physx2Cm19CmEventNameProvider15getProfileNamesEv,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_E6getDirEv
  ,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEE6getDirEv,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_E6getDirEv,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEE6getDirEv,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEE6getDirEv,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEE6getDirEv,__ZNK5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEE6getDirEv,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEE6getDirEv,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEE6getDirEv,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_E6getDirEv,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEE6getDirEv,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEE6getDirEv,__ZNK5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEE6getDirEv,__ZNK5physx2Gu11HeightField8getFlagsEv,__ZN5physx2Gu11HeightField15exportExtraDataERNS_22PxSerializationContextE,__ZN5physx2Gu11HeightField8requiresERNS_23PxProcessPxBaseCallbackE,__ZN13BaseAllocator16ThreadInitializeEPS_,__ZN13BaseAllocator16FrameMaintenanceEb,__ZN21UnityDefaultAllocatorI17LowLevelAllocatorE10DeallocateEPv,__ZN20DynamicHeapAllocatorI17LowLevelAllocatorE10DeallocateEPv,__ZN14StackAllocator10DeallocateEPv,__ZN14StackAllocator16FrameMaintenanceEb,__ZN12TLSAllocatorI14StackAllocatorE10DeallocateEPv,__ZN12TLSAllocatorI14StackAllocatorE16ThreadInitializeEP13BaseAllocator,__ZN12TLSAllocatorI14StackAllocatorE16FrameMaintenanceEb,__ZN6Object13AwakeFromLoadE17AwakeFromLoadMode,__ZN6Object7SetNameEPKc,__ZN6Object12SetHideFlagsEi,__ZN6Object24SetCachedScriptingObjectEP15ScriptingObject,__ZN6Object23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN6Object23VirtualRedirectTransferER18StreamedBinaryReadILb0EE
  ,__ZN6Object23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN6Object23VirtualRedirectTransferER13ProxyTransfer,__ZN6Object23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN6Object23VirtualRedirectTransferER14SafeBinaryRead,__ZN6Object23VirtualRedirectTransferER19StreamedBinaryWriteILb1EE,__ZN16LevelGameManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN16LevelGameManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN16LevelGameManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN16LevelGameManager23VirtualRedirectTransferER13ProxyTransfer,__ZN16LevelGameManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN16LevelGameManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN17GlobalGameManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN17GlobalGameManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN17GlobalGameManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN17GlobalGameManager23VirtualRedirectTransferER13ProxyTransfer,__ZN17GlobalGameManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN17GlobalGameManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN5Unity10GameObject13AwakeFromLoadE17AwakeFromLoadMode,__ZN5Unity10GameObject7SetNameEPKc,__ZN5Unity10GameObject12SetHideFlagsEi,__ZN5Unity10GameObject23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN5Unity10GameObject23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN5Unity10GameObject23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN5Unity10GameObject23VirtualRedirectTransferER13ProxyTransfer,__ZN5Unity10GameObject23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN5Unity10GameObject23VirtualRedirectTransferER14SafeBinaryRead,__ZN5Unity9Component13AwakeFromLoadE17AwakeFromLoadMode,__ZN5Unity9Component7SetNameEPKc,__ZN5Unity9Component23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN5Unity9Component23VirtualRedirectTransferER18StreamedBinaryReadILb0EE
  ,__ZN5Unity9Component23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN5Unity9Component23VirtualRedirectTransferER13ProxyTransfer,__ZN5Unity9Component23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN5Unity9Component23VirtualRedirectTransferER14SafeBinaryRead,__ZN5Unity9Component26SupportedMessagesDidChangeEi,__ZN5Unity9Component10DeactivateENS_19DeactivateOperationE,__ZN11NamedObject7SetNameEPKc,__ZN11NamedObject23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN11NamedObject23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN11NamedObject23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN11NamedObject23VirtualRedirectTransferER13ProxyTransfer,__ZN11NamedObject23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN11NamedObject23VirtualRedirectTransferER14SafeBinaryRead,__ZN10TagManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN10TagManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN10TagManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN10TagManager23VirtualRedirectTransferER13ProxyTransfer,__ZN10TagManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN10TagManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN9Behaviour13AwakeFromLoadE17AwakeFromLoadMode,__ZN9Behaviour23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN9Behaviour23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN9Behaviour23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN9Behaviour23VirtualRedirectTransferER13ProxyTransfer,__ZN9Behaviour23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN9Behaviour23VirtualRedirectTransferER14SafeBinaryRead,__ZN9Behaviour10DeactivateEN5Unity19DeactivateOperationE,__ZN9Behaviour10SetEnabledEb,__ZN6Camera13AwakeFromLoadE17AwakeFromLoadMode,__ZN6Camera23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE
  ,__ZN6Camera23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN6Camera23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN6Camera23VirtualRedirectTransferER13ProxyTransfer,__ZN6Camera23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN6Camera23VirtualRedirectTransferER14SafeBinaryRead,__ZN16GraphicsSettings13AwakeFromLoadE17AwakeFromLoadMode,__ZN16GraphicsSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN16GraphicsSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN16GraphicsSettings23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN16GraphicsSettings23VirtualRedirectTransferER13ProxyTransfer,__ZN16GraphicsSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN16GraphicsSettings23VirtualRedirectTransferER14SafeBinaryRead,__ZN11HaloManager13AwakeFromLoadE17AwakeFromLoadMode,__ZN5Light13AwakeFromLoadE17AwakeFromLoadMode,__ZN5Light23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN5Light23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN5Light23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN5Light23VirtualRedirectTransferER13ProxyTransfer,__ZN5Light23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN5Light23VirtualRedirectTransferER14SafeBinaryRead,__ZN11LightProbes13AwakeFromLoadE17AwakeFromLoadMode,__ZN11LightProbes23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN11LightProbes23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN11LightProbes23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN11LightProbes23VirtualRedirectTransferER13ProxyTransfer,__ZN11LightProbes23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN11LightProbes23VirtualRedirectTransferER14SafeBinaryRead,__ZN14RenderSettings13AwakeFromLoadE17AwakeFromLoadMode,__ZN14RenderSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN14RenderSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE
  ,__ZN14RenderSettings23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN14RenderSettings23VirtualRedirectTransferER13ProxyTransfer,__ZN14RenderSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN14RenderSettings23VirtualRedirectTransferER14SafeBinaryRead,__ZN4Mesh13AwakeFromLoadE17AwakeFromLoadMode,__ZN4Mesh23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN4Mesh23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN4Mesh23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN4Mesh23VirtualRedirectTransferER13ProxyTransfer,__ZN4Mesh23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN4Mesh23VirtualRedirectTransferER14SafeBinaryRead,__ZN10MeshFilter13AwakeFromLoadE17AwakeFromLoadMode,__ZN10MeshFilter23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN10MeshFilter23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN10MeshFilter23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN10MeshFilter23VirtualRedirectTransferER13ProxyTransfer,__ZN10MeshFilter23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN10MeshFilter23VirtualRedirectTransferER14SafeBinaryRead,__ZN12MeshRenderer13AwakeFromLoadE17AwakeFromLoadMode,__ZN12MeshRenderer23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN12MeshRenderer23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN12MeshRenderer23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN12MeshRenderer23VirtualRedirectTransferER13ProxyTransfer,__ZN12MeshRenderer23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN12MeshRenderer23VirtualRedirectTransferER14SafeBinaryRead,__ZN8Renderer26SupportedMessagesDidChangeEi,__ZN12MeshRenderer10DeactivateEN5Unity19DeactivateOperationE,__ZN18DelayedCallManager6UpdateEi,__ZN22BlockMemoryCacheWriter16UnlockCacheBlockEj,__ZN22BlockMemoryCacheWriter11GetPathNameEv
  ,__ZN9GfxDevice20SetMaxBufferedFramesEi,__ZN9GfxDevice25SetInvertProjectionMatrixEb,__ZN9GfxDevice34SetStencilRefWhenStencilWasSkippedEi,__ZN9GfxDevice24SetFFLightmapScaleOffsetERK8Vector4f,__ZN9GfxDevice13SetFFMaterialERK17GfxMaterialParams,__ZN9GfxDevice10SetFFColorERK10ColorRGBAf,__ZN9GfxDevice11EnableFFFogERK12GfxFogParams,__ZN9GfxDevice17DestroyGpuProgramEPK10GpuProgram,__ZN9GfxDevice17DeleteIndexBufferEP11IndexBuffer,__ZN9GfxDevice18DeleteVertexBufferEP12VertexBuffer,__ZN9GfxDevice13BeginSkinningEi,__ZN9GfxDevice19EndSkinningInstanceEi,__ZN9GfxDevice18EndDynamicBatchingE13TransformType,__ZN9GfxDevice21ReleaseSharedMeshDataEP14SharedMeshData,__ZN9GfxDevice24ReleaseSharedTextureDataEP17SharedTextureData,__ZN9GfxDevice23DeleteGPUSkinPoseBufferEP17GPUSkinPoseBuffer,__ZN9GfxDevice23IgnoreNextUnresolveOnRSE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseE,__ZN9GfxDevice25SetBackBufferColorSurfaceEP17RenderSurfaceBase,__ZN9GfxDevice25SetBackBufferDepthSurfaceEP17RenderSurfaceBase,__ZN9GfxDevice13FreeTextureIDE9TextureID,__ZN9GfxDevice23UnregisterNativeTextureE9TextureID,__ZN9GfxDevice14WaitOnCPUFenceEj,__ZN9GfxDevice16SetActiveContextEPv,__ZN9GfxDevice18InsertCustomMarkerEi,__ZN9GfxDevice19FreeComputeBufferIDE15ComputeBufferID,__ZN9GfxDevice21DestroyComputeProgramER12ObjectHandleI18ComputeProgram_TagPvE,__ZN9GfxDevice20DestroyComputeBufferE15ComputeBufferID,__ZN9GfxDevice17SetComputeProgramE12ObjectHandleI18ComputeProgram_TagPvE,__ZN11MonoManager13AwakeFromLoadE17AwakeFromLoadMode,__ZN11MonoManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE
  ,__ZN11MonoManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN11MonoManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN11MonoManager23VirtualRedirectTransferER13ProxyTransfer,__ZN11MonoManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN11MonoManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN9Texture2D13AwakeFromLoadE17AwakeFromLoadMode,__ZN7Cubemap23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN7Cubemap23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN7Cubemap23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN7Cubemap23VirtualRedirectTransferER13ProxyTransfer,__ZN7Cubemap23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN7Cubemap23VirtualRedirectTransferER14SafeBinaryRead,__ZN9Texture2D19UnloadFromGfxDeviceEb,__ZN7Cubemap13UploadTextureEb,__ZN16LightmapSettings13AwakeFromLoadE17AwakeFromLoadMode,__ZN16LightmapSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN16LightmapSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN16LightmapSettings23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN16LightmapSettings23VirtualRedirectTransferER13ProxyTransfer,__ZN16LightmapSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN16LightmapSettings23VirtualRedirectTransferER14SafeBinaryRead,__ZN15QualitySettings13AwakeFromLoadE17AwakeFromLoadMode,__ZN15QualitySettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN15QualitySettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN15QualitySettings23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN15QualitySettings23VirtualRedirectTransferER13ProxyTransfer,__ZN15QualitySettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN15QualitySettings23VirtualRedirectTransferER14SafeBinaryRead,__ZN8Renderer13AwakeFromLoadE17AwakeFromLoadMode,__ZN8Renderer23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE
  ,__ZN8Renderer23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN8Renderer23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN8Renderer23VirtualRedirectTransferER13ProxyTransfer,__ZN8Renderer23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN8Renderer23VirtualRedirectTransferER14SafeBinaryRead,__ZN8Renderer10DeactivateEN5Unity19DeactivateOperationE,__ZN13RenderTexture13AwakeFromLoadE17AwakeFromLoadMode,__ZN13RenderTexture23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN13RenderTexture23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN13RenderTexture23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN13RenderTexture23VirtualRedirectTransferER13ProxyTransfer,__ZN13RenderTexture23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN13RenderTexture23VirtualRedirectTransferER14SafeBinaryRead,__ZN13RenderTexture19UnloadFromGfxDeviceEb,__ZNK13ScreenManager19GetSystemResolutionEv,__ZNK13ScreenManager20GetCurrentResolutionEv,__ZN13ScreenManager13SetShowCursorEb,__ZN13ScreenManager13SetLockCursorE14CursorLockMode,__ZN13ScreenManager24SetAllowLayeredRenderingEb,__ZN13ScreenManager16SetScreenTimeoutEi,__ZN13ScreenManager12SetIsFocusedEb,__ZN13ScreenManager21SetCursorInsideWindowEb,__ZN13ScreenManager18RequestOrientationE17ScreenOrientation,__ZN13ScreenManager20SetScreenOrientationE17ScreenOrientation,__ZN7Texture23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN7Texture23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN7Texture23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN7Texture23VirtualRedirectTransferER13ProxyTransfer,__ZN7Texture23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN7Texture23VirtualRedirectTransferER14SafeBinaryRead
  ,__ZN9Texture2D23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN9Texture2D23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN9Texture2D23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN9Texture2D23VirtualRedirectTransferER13ProxyTransfer,__ZN9Texture2D23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN9Texture2D23VirtualRedirectTransferER14SafeBinaryRead,__ZN9Texture2D13UploadTextureEb,__ZN9Texture3D13AwakeFromLoadE17AwakeFromLoadMode,__ZN9Texture3D23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN9Texture3D23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN9Texture3D23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN9Texture3D23VirtualRedirectTransferER13ProxyTransfer,__ZN9Texture3D23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN9Texture3D23VirtualRedirectTransferER14SafeBinaryRead,__ZN9Texture3D19UnloadFromGfxDeviceEb,__ZN9Transform13AwakeFromLoadE17AwakeFromLoadMode,__ZN9Transform23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN9Transform23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN9Transform23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN9Transform23VirtualRedirectTransferER13ProxyTransfer,__ZN9Transform23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN9Transform23VirtualRedirectTransferER14SafeBinaryRead,__ZN9Transform26SupportedMessagesDidChangeEi,__ZN18ProceduralMaterial13AwakeFromLoadE17AwakeFromLoadMode,__ZN18ProceduralMaterial23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN18ProceduralMaterial23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN18ProceduralMaterial23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN18ProceduralMaterial23VirtualRedirectTransferER13ProxyTransfer,__ZN18ProceduralMaterial23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN18ProceduralMaterial23VirtualRedirectTransferER14SafeBinaryRead
  ,__ZN12InputManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN12InputManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN12InputManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN12InputManager23VirtualRedirectTransferER13ProxyTransfer,__ZN12InputManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN12InputManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN11TimeManager13AwakeFromLoadE17AwakeFromLoadMode,__ZN11TimeManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN11TimeManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN11TimeManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN11TimeManager23VirtualRedirectTransferER13ProxyTransfer,__ZN11TimeManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN11TimeManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN11AssetBundle23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN11AssetBundle23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN11AssetBundle23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN11AssetBundle23VirtualRedirectTransferER13ProxyTransfer,__ZN11AssetBundle23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN11AssetBundle23VirtualRedirectTransferER14SafeBinaryRead,__ZN14AsyncOperation11SetPriorityEi,__ZN14AsyncOperation23SetAllowSceneActivationEb,__ZN13BuildSettings13AwakeFromLoadE17AwakeFromLoadMode,__ZN13BuildSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN13BuildSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN13BuildSettings23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN13BuildSettings23VirtualRedirectTransferER13ProxyTransfer,__ZN13BuildSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN13BuildSettings23VirtualRedirectTransferER14SafeBinaryRead,__ZN23PreloadManagerOperation11SetPriorityEi,__ZN11PreloadData23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE
  ,__ZN11PreloadData23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN11PreloadData23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN11PreloadData23VirtualRedirectTransferER13ProxyTransfer,__ZN11PreloadData23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN11PreloadData23VirtualRedirectTransferER14SafeBinaryRead,__ZN18LoadLevelOperation23SetAllowSceneActivationEb,__ZN14PlayerSettings13AwakeFromLoadE17AwakeFromLoadMode,__ZN14PlayerSettings23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN14PlayerSettings23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN14PlayerSettings23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN14PlayerSettings23VirtualRedirectTransferER13ProxyTransfer,__ZN14PlayerSettings23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN14PlayerSettings23VirtualRedirectTransferER14SafeBinaryRead,__ZN15ResourceManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN15ResourceManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN15ResourceManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN15ResourceManager23VirtualRedirectTransferER13ProxyTransfer,__ZN15ResourceManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN15ResourceManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN13MonoBehaviour13AwakeFromLoadE17AwakeFromLoadMode,__ZN13MonoBehaviour7SetNameEPKc,__ZN13MonoBehaviour23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN13MonoBehaviour23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN13MonoBehaviour23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN13MonoBehaviour23VirtualRedirectTransferER13ProxyTransfer,__ZN13MonoBehaviour23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN13MonoBehaviour23VirtualRedirectTransferER14SafeBinaryRead,__ZN13MonoBehaviour10DeactivateEN5Unity19DeactivateOperationE,__ZN10MonoScript13AwakeFromLoadE17AwakeFromLoadMode,__ZN10MonoScript23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE
  ,__ZN10MonoScript23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN10MonoScript23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN10MonoScript23VirtualRedirectTransferER13ProxyTransfer,__ZN10MonoScript23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN10MonoScript23VirtualRedirectTransferER14SafeBinaryRead,__ZN9TextAsset13AwakeFromLoadE17AwakeFromLoadMode,__ZN9TextAsset23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN9TextAsset23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN9TextAsset23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN9TextAsset23VirtualRedirectTransferER13ProxyTransfer,__ZN9TextAsset23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN9TextAsset23VirtualRedirectTransferER14SafeBinaryRead,__ZN14FileCacherRead16UnlockCacheBlockEj,__ZN14FileCacherRead11GetPathNameEv,__ZN22MemoryCacherReadBlocks16UnlockCacheBlockEj,__ZN22MemoryCacherReadBlocks11GetPathNameEv,__ZN5Unity8Material13AwakeFromLoadE17AwakeFromLoadMode,__ZN5Unity8Material23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN5Unity8Material23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN5Unity8Material23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN5Unity8Material23VirtualRedirectTransferER13ProxyTransfer,__ZN5Unity8Material23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN5Unity8Material23VirtualRedirectTransferER14SafeBinaryRead,__ZN6Shader13AwakeFromLoadE17AwakeFromLoadMode,__ZN6Shader23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN6Shader23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN6Shader23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN6Shader23VirtualRedirectTransferER13ProxyTransfer,__ZN6Shader23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN6Shader23VirtualRedirectTransferER14SafeBinaryRead
  ,__ZN12ScriptMapper23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN12ScriptMapper23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN12ScriptMapper23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN12ScriptMapper23VirtualRedirectTransferER13ProxyTransfer,__ZN12ScriptMapper23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN12ScriptMapper23VirtualRedirectTransferER14SafeBinaryRead,__ZN16MemoryFileSystem19InitializeFileEntryER13FileEntryData,__ZN16MemoryFileSystem16DestroyFileEntryER13FileEntryData,__ZN25MultiBlocksMemoryFileData6UnlockEPv,__ZN22LocalFileSystemHandler19InitializeFileEntryER13FileEntryData,__ZN22LocalFileSystemHandler16DestroyFileEntryER13FileEntryData,__ZNK20LocalFileSystemPosix18GetApplicationPathEv,__ZNK20LocalFileSystemPosix20GetApplicationFolderEv,__ZNK20LocalFileSystemPosix25GetApplicationManagedPathEv,__ZNK20LocalFileSystemPosix26GetApplicationContentsPathEv,__ZNK20LocalFileSystemPosix21GetUserAppCacheFolderEv,__ZNK20LocalFileSystemPosix20GetUserAppDataFolderEv,__ZNK20LocalFileSystemPosix19GetUserConfigFolderEv,__ZN22LocalFileSystemHandler16LastErrorMessageEv,__ZN19CharacterController13AwakeFromLoadE17AwakeFromLoadMode,__ZN19CharacterController23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN19CharacterController23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN19CharacterController23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN19CharacterController23VirtualRedirectTransferER13ProxyTransfer,__ZN19CharacterController23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN19CharacterController23VirtualRedirectTransferER14SafeBinaryRead,__ZN8Collider26SupportedMessagesDidChangeEi,__ZN8Collider10DeactivateEN5Unity19DeactivateOperationE,__ZN8Collider10SetEnabledEb,__ZN19CharacterController12SetIsTriggerEb
  ,__ZN19CharacterController9GetBoundsEv,__ZN19CharacterController6CreateEPK9Rigidbody,__ZN19CharacterController16TransformChangedEi,__ZN19ControllerHitReport10onShapeHitERKN5physx20PxControllerShapeHitE,__ZN19ControllerHitReport15onControllerHitERKN5physx16PxControllersHitE,__ZN19ControllerHitReport13onObstacleHitERKN5physx23PxControllerObstacleHitE,__ZN8Collider13AwakeFromLoadE17AwakeFromLoadMode,__ZN8Collider23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN8Collider23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN8Collider23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN8Collider23VirtualRedirectTransferER13ProxyTransfer,__ZN8Collider23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN8Collider23VirtualRedirectTransferER14SafeBinaryRead,__ZN8Collider12SetIsTriggerEb,__ZN8Collider9GetBoundsEv,__ZN8Collider16TransformChangedEi,__ZN12MeshCollider13AwakeFromLoadE17AwakeFromLoadMode,__ZN12MeshCollider23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN12MeshCollider23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN12MeshCollider23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN12MeshCollider23VirtualRedirectTransferER13ProxyTransfer,__ZN12MeshCollider23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN12MeshCollider23VirtualRedirectTransferER14SafeBinaryRead,__ZN12MeshCollider6CreateEPK9Rigidbody,__ZN12MeshCollider16TransformChangedEi,__ZN14PhysicsManager13AwakeFromLoadE17AwakeFromLoadMode,__ZN14PhysicsManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN14PhysicsManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN14PhysicsManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN14PhysicsManager23VirtualRedirectTransferER13ProxyTransfer
  ,__ZN14PhysicsManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN14PhysicsManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN18PhysxJobDispatcher10submitTaskERN5physx10PxBaseTaskE,__ZN16NovodexAllocator10deallocateEPv,__ZN9Rigidbody13AwakeFromLoadE17AwakeFromLoadMode,__ZN9Rigidbody23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN9Rigidbody23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN9Rigidbody23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN9Rigidbody23VirtualRedirectTransferER13ProxyTransfer,__ZN9Rigidbody23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN9Rigidbody23VirtualRedirectTransferER14SafeBinaryRead,__ZN9Rigidbody26SupportedMessagesDidChangeEi,__ZN9Rigidbody10DeactivateEN5Unity19DeactivateOperationE,__ZN13PhysicsModule10GetGravityEv,__ZN13PhysicsModule18ReleaseHeightFieldEPv,__ZN13PhysicsModule21ReleaseNxTriangleMeshEP17PhysicsModuleMesh,__ZN13PhysicsModule19ReleaseNxConvexMeshEP17PhysicsModuleMesh,__ZN13PhysicsModule18DeleteMemoryStreamEP19PhysicsModuleStream,__ZN19CollisionListener2D12BeginContactEP9b2Contact,__ZN19CollisionListener2D10EndContactEP9b2Contact,__ZN10SampleClip23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN10SampleClip23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN10SampleClip23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN10SampleClip23VirtualRedirectTransferER13ProxyTransfer,__ZN10SampleClip23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN10SampleClip23VirtualRedirectTransferER14SafeBinaryRead,__ZN10SampleClip20AllocatePreviewSoundEv,__ZN9AudioClip13AwakeFromLoadE17AwakeFromLoadMode,__ZN9AudioClip23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN9AudioClip23VirtualRedirectTransferER18StreamedBinaryReadILb0EE
  ,__ZN9AudioClip23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN9AudioClip23VirtualRedirectTransferER13ProxyTransfer,__ZN9AudioClip23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN9AudioClip23VirtualRedirectTransferER14SafeBinaryRead,__ZN9AudioClip20AllocatePreviewSoundEv,__ZN13AudioListener13AwakeFromLoadE17AwakeFromLoadMode,__ZN13AudioListener23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN13AudioListener23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN13AudioListener23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN13AudioListener23VirtualRedirectTransferER13ProxyTransfer,__ZN13AudioListener23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN13AudioListener23VirtualRedirectTransferER14SafeBinaryRead,__ZN12AudioManager13AwakeFromLoadE17AwakeFromLoadMode,__ZN12AudioManager23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN12AudioManager23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN12AudioManager23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN12AudioManager23VirtualRedirectTransferER13ProxyTransfer,__ZN12AudioManager23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN12AudioManager23VirtualRedirectTransferER14SafeBinaryRead,__ZN7mecanim6memory16MecanimAllocator10DeallocateEPv,__ZN11AudioModule8SetPauseEb,__ZN11AudioModule23DeleteAudioCustomFilterEP17AudioCustomFilter,__ZN11AudioModule25AudioManagerAwakeFromLoadE17AwakeFromLoadMode,__ZN9Animation13AwakeFromLoadE17AwakeFromLoadMode,__ZN9Animation23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN9Animation23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN9Animation23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN9Animation23VirtualRedirectTransferER13ProxyTransfer,__ZN9Animation23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN9Animation23VirtualRedirectTransferER14SafeBinaryRead
  ,__ZN9Animation10DeactivateEN5Unity19DeactivateOperationE,__ZN6Motion7AddUserER8UserList,__ZN13AnimationClip13AwakeFromLoadE17AwakeFromLoadMode,__ZN13AnimationClip23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN13AnimationClip23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN13AnimationClip23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN13AnimationClip23VirtualRedirectTransferER13ProxyTransfer,__ZN13AnimationClip23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN13AnimationClip23VirtualRedirectTransferER14SafeBinaryRead,__ZN13AnimationClip15GetAverageSpeedEv,__ZNK13AnimationClip17GetAnimationClipsEv,__ZN7mecanim6memory16ChainedAllocator10DeallocateEPv,__ZN8Animator13AwakeFromLoadE17AwakeFromLoadMode,__ZN8Animator23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN8Animator23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN8Animator23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN8Animator23VirtualRedirectTransferER13ProxyTransfer,__ZN8Animator23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN8Animator23VirtualRedirectTransferER14SafeBinaryRead,__ZN8Animator10DeactivateEN5Unity19DeactivateOperationE,__ZN8Animator16TransformChangedEi,__ZN7mecanim6memory16InPlaceAllocator10DeallocateEPv,__ZN25RuntimeAnimatorController23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN25RuntimeAnimatorController23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN25RuntimeAnimatorController23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN25RuntimeAnimatorController23VirtualRedirectTransferER13ProxyTransfer,__ZN25RuntimeAnimatorController23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN25RuntimeAnimatorController23VirtualRedirectTransferER14SafeBinaryRead,__ZN18AnimatorController13AwakeFromLoadE17AwakeFromLoadMode,__ZN18AnimatorController23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE
  ,__ZN18AnimatorController23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN18AnimatorController23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN18AnimatorController23VirtualRedirectTransferER13ProxyTransfer,__ZN18AnimatorController23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN18AnimatorController23VirtualRedirectTransferER14SafeBinaryRead,__ZNK18AnimatorController27GetAnimationClipsToRegisterEv,__ZN7Terrain23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN7Terrain23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN7Terrain23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN7Terrain23VirtualRedirectTransferER13ProxyTransfer,__ZN7Terrain23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN7Terrain23VirtualRedirectTransferER14SafeBinaryRead,__ZN14TerrainManager15CullAllTerrainsEi,__ZN14TerrainManager29SetLightmapIndexOnAllTerrainsEi,__ZN14TerrainManager10AddTerrainEP7Terrain,__ZN14TerrainManager13RemoveTerrainEP7Terrain,__Z6FTFreeP13FT_MemoryRec_Pv,__ZN20TextRenderingPrivate4Font13AwakeFromLoadE17AwakeFromLoadMode,__ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER13ProxyTransfer,__ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN20TextRenderingPrivate4Font23VirtualRedirectTransferER14SafeBinaryRead,__ZN20TextRenderingPrivate8TextMesh13AwakeFromLoadE17AwakeFromLoadMode,__ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER13ProxyTransfer,__ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER18StreamedBinaryReadILb1EE
  ,__ZN20TextRenderingPrivate8TextMesh23VirtualRedirectTransferER14SafeBinaryRead,__ZN2UI6Canvas13AwakeFromLoadE17AwakeFromLoadMode,__ZN2UI6Canvas23VirtualRedirectTransferER19StreamedBinaryWriteILb0EE,__ZN2UI6Canvas23VirtualRedirectTransferER18StreamedBinaryReadILb0EE,__ZN2UI6Canvas23VirtualRedirectTransferER17RemapPPtrTransfer,__ZN2UI6Canvas23VirtualRedirectTransferER13ProxyTransfer,__ZN2UI6Canvas23VirtualRedirectTransferER18StreamedBinaryReadILb1EE,__ZN2UI6Canvas23VirtualRedirectTransferER14SafeBinaryRead,__ZL21inner_remap_i8_rgb332P7BlitterPK9InnerInfo,__ZL21inner_remap_i8_rgb565P7BlitterPK9InnerInfo,__ZL21inner_remap_i8_rgb888P7BlitterPK9InnerInfo,__ZL23inner_remap_i8_argb1555P7BlitterPK9InnerInfo,__ZL23inner_remap_i8_argb4444P7BlitterPK9InnerInfo,__ZL23inner_remap_i8_argb8888P7BlitterPK9InnerInfo,__ZL21inner_remap_rgb332_i8P7BlitterPK9InnerInfo,__ZL25inner_remap_rgb332_rgb565P7BlitterPK9InnerInfo,__ZL25inner_remap_rgb332_rgb888P7BlitterPK9InnerInfo,__ZL27inner_remap_rgb332_argb1555P7BlitterPK9InnerInfo,__ZL27inner_remap_rgb332_argb4444P7BlitterPK9InnerInfo,__ZL27inner_remap_rgb332_argb8888P7BlitterPK9InnerInfo,__ZL21inner_remap_rgb565_i8P7BlitterPK9InnerInfo,__ZL25inner_remap_rgb565_rgb332P7BlitterPK9InnerInfo,__ZL33inner_remap_rgb565_rgb888_correctP7BlitterPK9InnerInfo,__ZL27inner_remap_rgb565_argb1555P7BlitterPK9InnerInfo,__ZL27inner_remap_rgb565_argb4444P7BlitterPK9InnerInfo,__ZL27inner_remap_rgb565_argb8888P7BlitterPK9InnerInfo,__ZL33inner_remap_rgb565_bgr888_correctP7BlitterPK9InnerInfo,__ZL21inner_remap_rgb888_i8P7BlitterPK9InnerInfo,__ZL25inner_remap_rgb888_rgb332P7BlitterPK9InnerInfo,__ZL25inner_remap_rgb888_rgb565P7BlitterPK9InnerInfo
  ,__ZL27inner_remap_rgb888_argb1555P7BlitterPK9InnerInfo,__ZL27inner_remap_rgb888_argb4444P7BlitterPK9InnerInfo,__ZL27inner_remap_rgb888_argb8888P7BlitterPK9InnerInfo,__ZL23inner_remap_argb1555_i8P7BlitterPK9InnerInfo,__ZL27inner_remap_argb1555_rgb332P7BlitterPK9InnerInfo,__ZL27inner_remap_argb1555_rgb565P7BlitterPK9InnerInfo,__ZL27inner_remap_argb1555_rgb888P7BlitterPK9InnerInfo,__ZL29inner_remap_argb1555_argb4444P7BlitterPK9InnerInfo,__ZL29inner_remap_argb1555_argb8888P7BlitterPK9InnerInfo,__ZL23inner_remap_argb4444_i8P7BlitterPK9InnerInfo,__ZL27inner_remap_argb4444_rgb332P7BlitterPK9InnerInfo,__ZL27inner_remap_argb4444_rgb565P7BlitterPK9InnerInfo,__ZL27inner_remap_argb4444_rgb888P7BlitterPK9InnerInfo,__ZL29inner_remap_argb4444_argb1555P7BlitterPK9InnerInfo,__ZL37inner_remap_argb4444_argb8888_correctP7BlitterPK9InnerInfo,__ZL37inner_remap_argb4444_abgr8888_correctP7BlitterPK9InnerInfo,__ZL23inner_remap_argb8888_i8P7BlitterPK9InnerInfo,__ZL27inner_remap_argb8888_rgb332P7BlitterPK9InnerInfo,__ZL27inner_remap_argb8888_rgb565P7BlitterPK9InnerInfo,__ZL27inner_remap_argb8888_rgb888P7BlitterPK9InnerInfo,__ZL29inner_remap_argb8888_argb1555P7BlitterPK9InnerInfo,__ZL29inner_remap_argb8888_argb4444P7BlitterPK9InnerInfo,__ZL37inner_remap_rgba4444_argb8888_correctP7BlitterPK9InnerInfo,__ZL37inner_remap_rgba4444_abgr8888_correctP7BlitterPK9InnerInfo,__ZL21inner_remap_1rgba_1iaP7BlitterPK9InnerInfo,__ZL21inner_remap_1rgba_2iaP7BlitterPK9InnerInfo,__ZL21inner_remap_1rgba_3iaP7BlitterPK9InnerInfo,__ZL21inner_remap_1rgba_4iaP7BlitterPK9InnerInfo,__ZL21inner_remap_2rgba_1iaP7BlitterPK9InnerInfo,__ZL21inner_remap_2rgba_2iaP7BlitterPK9InnerInfo
  ,__ZL21inner_remap_2rgba_3iaP7BlitterPK9InnerInfo,__ZL21inner_remap_2rgba_4iaP7BlitterPK9InnerInfo,__ZL21inner_remap_3rgba_1iaP7BlitterPK9InnerInfo,__ZL21inner_remap_3rgba_2iaP7BlitterPK9InnerInfo,__ZL21inner_remap_3rgba_3iaP7BlitterPK9InnerInfo,__ZL21inner_remap_3rgba_4iaP7BlitterPK9InnerInfo,__ZL21inner_remap_4rgba_1iaP7BlitterPK9InnerInfo,__ZL21inner_remap_4rgba_2iaP7BlitterPK9InnerInfo,__ZL21inner_remap_4rgba_3iaP7BlitterPK9InnerInfo,__ZL21inner_remap_4rgba_4iaP7BlitterPK9InnerInfo,__ZL23inner_remap_1rgba_1rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_1rgba_2rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_1rgba_3rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_1rgba_4rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_2rgba_1rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_2rgba_2rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_2rgba_3rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_2rgba_4rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_3rgba_1rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_3rgba_2rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_3rgba_3rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_3rgba_4rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_4rgba_1rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_4rgba_2rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_4rgba_3rgbaP7BlitterPK9InnerInfo,__ZL23inner_remap_4rgba_4rgbaP7BlitterPK9InnerInfo,__ZL17inner_stretch_1iaP7BlitterPK9InnerInfo,__ZL17inner_stretch_2iaP7BlitterPK9InnerInfo,__ZL17inner_stretch_3iaP7BlitterPK9InnerInfo,__ZL17inner_stretch_4iaP7BlitterPK9InnerInfo
  ,__ZL19inner_stretch_1rgbaP7BlitterPK9InnerInfo,__ZL19inner_stretch_2rgbaP7BlitterPK9InnerInfo,__ZL19inner_stretch_3rgbaP7BlitterPK9InnerInfo,__ZL19inner_stretch_4rgbaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_i8_rgb332P7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_i8_rgb565P7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_i8_rgb888P7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_i8_argb1555P7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_i8_argb4444P7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_i8_argb8888P7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_rgb332_i8P7BlitterPK9InnerInfo,__ZL33inner_stretch_remap_rgb332_rgb565P7BlitterPK9InnerInfo,__ZL33inner_stretch_remap_rgb332_rgb888P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb332_argb1555P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb332_argb4444P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb332_argb8888P7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_rgb565_i8P7BlitterPK9InnerInfo,__ZL33inner_stretch_remap_rgb565_rgb332P7BlitterPK9InnerInfo,__ZL33inner_stretch_remap_rgb565_rgb888P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb565_argb1555P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb565_argb4444P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb565_argb8888P7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_rgb888_i8P7BlitterPK9InnerInfo,__ZL33inner_stretch_remap_rgb888_rgb332P7BlitterPK9InnerInfo,__ZL33inner_stretch_remap_rgb888_rgb565P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb888_argb1555P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb888_argb4444P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_rgb888_argb8888P7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_argb1555_i8P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_argb1555_rgb332P7BlitterPK9InnerInfo
  ,__ZL35inner_stretch_remap_argb1555_rgb565P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_argb1555_rgb888P7BlitterPK9InnerInfo,__ZL37inner_stretch_remap_argb1555_argb4444P7BlitterPK9InnerInfo,__ZL37inner_stretch_remap_argb1555_argb8888P7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_argb4444_i8P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_argb4444_rgb332P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_argb4444_rgb565P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_argb4444_rgb888P7BlitterPK9InnerInfo,__ZL37inner_stretch_remap_argb4444_argb1555P7BlitterPK9InnerInfo,__ZL37inner_stretch_remap_argb4444_argb8888P7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_argb8888_i8P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_argb8888_rgb332P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_argb8888_rgb565P7BlitterPK9InnerInfo,__ZL35inner_stretch_remap_argb8888_rgb888P7BlitterPK9InnerInfo,__ZL37inner_stretch_remap_argb8888_argb1555P7BlitterPK9InnerInfo,__ZL37inner_stretch_remap_argb8888_argb4444P7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_1rgba_1iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_1rgba_2iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_1rgba_3iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_1rgba_4iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_2rgba_1iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_2rgba_2iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_2rgba_3iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_2rgba_4iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_3rgba_1iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_3rgba_2iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_3rgba_3iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_3rgba_4iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_4rgba_1iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_4rgba_2iaP7BlitterPK9InnerInfo
  ,__ZL29inner_stretch_remap_4rgba_3iaP7BlitterPK9InnerInfo,__ZL29inner_stretch_remap_4rgba_4iaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_1rgba_1rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_1rgba_2rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_1rgba_3rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_1rgba_4rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_2rgba_1rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_2rgba_2rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_2rgba_3rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_2rgba_4rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_3rgba_1rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_3rgba_2rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_3rgba_3rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_3rgba_4rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_4rgba_1rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_4rgba_2rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_4rgba_3rgbaP7BlitterPK9InnerInfo,__ZL31inner_stretch_remap_4rgba_4rgbaP7BlitterPK9InnerInfo,__ZL25inner_stretch_i8_bilinearP7BlitterPK9InnerInfo,__ZL29inner_stretch_rgb565_bilinearP7BlitterPK9InnerInfo,__ZL29inner_stretch_rgb888_bilinearP7BlitterPK9InnerInfo,__ZL31inner_stretch_argb1555_bilinearP7BlitterPK9InnerInfo,__ZL31inner_stretch_argb4444_bilinearP7BlitterPK9InnerInfo,__ZL31inner_stretch_argb8888_bilinearP7BlitterPK9InnerInfo,__ZL26inner_stretch_1ia_bilinearP7BlitterPK9InnerInfo,__ZL26inner_stretch_2ia_bilinearP7BlitterPK9InnerInfo,__ZL26inner_stretch_3ia_bilinearP7BlitterPK9InnerInfo,__ZL26inner_stretch_4ia_bilinearP7BlitterPK9InnerInfo,__ZL28inner_stretch_1rgba_bilinearP7BlitterPK9InnerInfo,__ZL28inner_stretch_2rgba_bilinearP7BlitterPK9InnerInfo
  ,__ZL28inner_stretch_3rgba_bilinearP7BlitterPK9InnerInfo,__ZL28inner_stretch_4rgba_bilinearP7BlitterPK9InnerInfo,__ZNK18ScreenManagerWebGL20GetCurrentResolutionEv,__ZN18ScreenManagerWebGL13SetShowCursorEb,__ZN18ScreenManagerWebGL13SetLockCursorE14CursorLockMode,__ZN13GfxDeviceGLES25SetInvertProjectionMatrixEb,__ZN13GfxDeviceGLES14SetRasterStateEPK17DeviceRasterState,__ZN13GfxDeviceGLES13SetDepthStateEPK16DeviceDepthState,__ZN13GfxDeviceGLES12SetSRGBWriteEb,__ZN13GfxDeviceGLES19SetUserBackfaceModeEb,__ZN13GfxDeviceGLES12SetWireframeEb,__ZN13GfxDeviceGLES14SetWorldMatrixERK10Matrix4x4f,__ZN13GfxDeviceGLES13SetViewMatrixERK10Matrix4x4f,__ZN13GfxDeviceGLES19SetProjectionMatrixERK10Matrix4x4f,__ZN13GfxDeviceGLES15SetBackfaceModeEb,__ZN13GfxDeviceGLES13SetFFMaterialERK17GfxMaterialParams,__ZN13GfxDeviceGLES10SetFFColorERK10ColorRGBAf,__ZN13GfxDeviceGLES11EnableFFFogERK12GfxFogParams,__ZN13GfxDeviceGLES11SetViewportERK5RectTIiE,__ZNK13GfxDeviceGLES11GetViewportEv,__ZN13GfxDeviceGLES14SetScissorRectERK5RectTIiE,__ZNK13GfxDeviceGLES14GetScissorRectEv,__ZN13GfxDeviceGLES22DeleteTextureCombinersER12ObjectHandleI20TextureCombiners_TagPvE,__ZN13GfxDeviceGLES21SetMaterialPropertiesERK21MaterialPropertyBlock,__ZN13GfxDeviceGLES17DestroySubProgramEPN9ShaderLab10SubProgramE,__ZN13GfxDeviceGLES13DisableLightsEi,__ZN13GfxDeviceGLES10SetAmbientERK10ColorRGBAf,__ZN13GfxDeviceGLES17DeleteIndexBufferEP11IndexBuffer,__ZN13GfxDeviceGLES18DeleteVertexBufferEP12VertexBuffer,__ZN13GfxDeviceGLES23DeleteGPUSkinPoseBufferEP17GPUSkinPoseBuffer
  ,__ZN13GfxDeviceGLES20DestroyRenderSurfaceER12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseE,__ZN13GfxDeviceGLES16SetRenderTargetsERK20GfxRenderTargetSetup,__ZN13GfxDeviceGLES15DiscardContentsER12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseE,__ZN13GfxDeviceGLES13DeleteTextureE9TextureID,__ZN19GfxThreadableDevice15OnDeviceCreatedEb,__ZN26VertexDeclarationCacheGLES24DestroyVertexDeclarationEP17VertexDeclaration,__ZN15TextureTFMethod16BindForRenderingEj,__ZN21UniformBufferTFMethod16BindForRenderingEj,__ZN15UniformTFMethod16BindForRenderingEj,__Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__0P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P30AssemblyU002DCSharp_JSONObject,__Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__1P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P30AssemblyU002DCSharp_JSONObject,__Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__2P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P22mscorlib_System_String,__Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__3P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P30AssemblyU002DCSharp_JSONObject,__Z84AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m_U003CU003Em__4P67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0P30AssemblyU002DCSharp_JSONObject,__Z45AssemblyU002DCSharp_LevelBuilder_m_RecieveDOMP32AssemblyU002DCSharp_LevelBuilderP22mscorlib_System_String,__Z54AssemblyU002DCSharp_JSONObject_AddJSONConents_m_InvokeP45AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObject,__Z57AssemblyU002DCSharp_JSONObject_AddJSONConents_m_EndInvokeP45AssemblyU002DCSharp_JSONObject_AddJSONConentsP22mscorlib_System_Object,__Z53AssemblyU002DCSharp_JSONObject_FieldNotFound_m_InvokeP44AssemblyU002DCSharp_JSONObject_FieldNotFoundP22mscorlib_System_String,__Z56AssemblyU002DCSharp_JSONObject_FieldNotFound_m_EndInvokeP44AssemblyU002DCSharp_JSONObject_FieldNotFoundP22mscorlib_System_Object,__Z56AssemblyU002DCSharp_JSONObject_GetFieldResponse_m_InvokeP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP30AssemblyU002DCSharp_JSONObject,__Z59AssemblyU002DCSharp_JSONObject_GetFieldResponse_m_EndInvokeP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP22mscorlib_System_Object,__Z95AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_AssemblyU002DCSharp_JSONObject_TypeP30AssemblyU002DCSharp_JSONObjecti,__Z83AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectb,__Z163AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z171AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z105AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObjectP45AssemblyU002DCSharp_JSONObject_AddJSONConents,__Z98AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_AssemblyU002DCSharp_JSONObject_arr_arrP30AssemblyU002DCSharp_JSONObjectP34AssemblyU002DCSharp_JSONObject_arr,__Z39AssemblyU002DCSharp_JSONObject_m_AbsorbP30AssemblyU002DCSharp_JSONObjectS0_,__Z81AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectb,__Z79AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjecti
  ,__Z80AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String,__Z103AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObjectP45AssemblyU002DCSharp_JSONObject_AddJSONConents,__Z88AssemblyU002DCSharp_JSONObject_m_Add_mscorlib_System_Void_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectS0_,__Z44AssemblyU002DCSharp_JSONObject_m_RemoveFieldP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String,__Z38AssemblyU002DCSharp_JSONObject_m_MergeP30AssemblyU002DCSharp_JSONObjectS0_,__Z106AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024_m__ctorP98AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024P53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z100AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_m__ctorP92AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243P53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z79AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_OnControllerColliderHitP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP45UnityEngine_UnityEngine_ControllerColliderHit,__Z84AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_GetDesiredHorizontalVelocityP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z68AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_GetDirectionP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z71AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_SetControllableP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorb,__Z67AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_SetVelocityP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3,__Z74AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_GetCenterOffsetP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__Z86AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_OnControllerColliderHitP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP45UnityEngine_UnityEngine_ControllerColliderHit,__Z75AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_GetDirectionP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__ZL83mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJControllerP21mscorlib_System_Array,__ZL73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObjectP21mscorlib_System_Array,__ZL83mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_Array,__ZL73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_StringP21mscorlib_System_Array,__Z71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m__ctorP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CharP21mscorlib_System_Array,__ZL92mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m__ctorP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObjectP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL84mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctorP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL146mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL116mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti,__ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_RemoveP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL71mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GrowIfNeededP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti,__ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddCollectionP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddEnumerableP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRangeP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object
  ,__Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_GetEnumeratorP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckIndexP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti,__ZL83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CheckCollectionP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveAtP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti,__ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_CapacityP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti,__ZL71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m__ctorP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeP21mscorlib_System_Array,__Z89mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_GetEnumeratorP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL154mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL124mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti,__ZL107mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_RemoveP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL79mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_AddP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL88mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_GrowIfNeededP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti,__ZL89mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_AddCollectionP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL89mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_AddEnumerableP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_AddRangeP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL86mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_CheckIndexP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti,__ZL91mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_CheckCollectionP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_RemoveAtP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti,__ZL88mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_set_CapacityP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti,__ZL81mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array,__Z81mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_GetEnumeratorP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL146mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL116mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi,__ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_RemoveP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL71mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_AddP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_String,__ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_GrowIfNeededP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi,__ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_AddCollectionP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_AddEnumerableP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_AddRangeP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_CheckIndexP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi
  ,__ZL83mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_CheckCollectionP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_RemoveAtP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi,__ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_set_CapacityP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi,__ZL84mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m__ctorP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_StringP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__Z222mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL193mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object,__ZL154mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Stringi,__ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_InitArraysP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Stringi,__ZL193mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__ZL154mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti,__Z222mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitArraysP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Objecti,__Z119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_KeyP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_ValueP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__Z156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array,__Z162mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z72mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m__ctorP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32P21mscorlib_System_Array,__Z91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array,__Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link,__ZL127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL180mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetEnumeratorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionaryEnumerator_get_EntryP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m__ctorP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array,__Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry
  ,__ZL126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL130mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_EntryP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_set_KeyP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String,__ZL117mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_set_ValueP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String,__Z156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array,__Z162mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_GetEnumeratorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL180mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String,__ZL138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IDictionaryEnumerator_get_EntryP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL130mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_EntryP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z230mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_GetEnumeratorP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL201mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL162mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjecti,__ZL124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_InitArraysP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjecti,__ZL123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_set_KeyP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String,__ZL125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_set_ValueP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__Z164mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array,__Z170mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z143mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_GetEnumeratorP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject
  ,__ZL175mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IDictionaryEnumerator_get_EntryP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL134mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL138mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_EntryP126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m__ctorP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Array,__ZL127System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_AddP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL84System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_InitArraysP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Objecti,__Z127mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m__ctorP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array,__Z133mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m_get_CurrentP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__ZL90System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m__ctorP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_ObjectP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object,__Z192mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Object,__Z153mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32i,__Z221mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_InitArraysP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32i,__Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_GetEnumeratorP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z114mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_set_KeyP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_String,__Z116mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_set_ValueP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32i,__Z155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array,__Z161mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z126mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z179mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32i,__Z134mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_GetEnumeratorP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z137mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z121mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z166mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IDictionaryEnumerator_get_EntryP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z127mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z125mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP117mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32P102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z129mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_EntryP117mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__ZL87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m__ctorP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_Array,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_Array,__ZL94mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m__ctorP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_Array
  ,__Z107mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Array,__Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array,__Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe,__Z112mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m__ctorP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Array,__ZL104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_Array,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m__ctorP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_Array,__ZL108mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m__ctorP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_Array,__ZL113mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_Array,__Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m__ctorP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Array,__ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_Array,__Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Array,__ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_Array,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_Array,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_Array,__ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_Array,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Array,__ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CalendarP21mscorlib_System_Array,__Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Array,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Array,__Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Array,__Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Array,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Array,__ZL99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m__ctorP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_Array,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_Array,__ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_Array,__ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m__ctorP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_Array,__ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_Array,__ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_Array,__ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_Array,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_Array
  ,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m__ctorP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_Array,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_Array,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_Array,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_Array,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m__ctorP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_Array,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m__ctorP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_Array,__ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m__ctorP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_Array,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_Array,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_Array,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Array,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_Array,__ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_Array,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_Array,__Z90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Array,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Array,__Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Array,__Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Array,__Z89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Array,__Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m__ctorP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Array,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Array,__Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfoP21mscorlib_System_Array,__Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m__ctorP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Array,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Array,__Z92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m__ctorP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Array,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_Array,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_Array,__Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Array,__ZL123mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m__ctorP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_Array,__ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m__ctorP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_Array,__Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Array
  ,__ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m__ctorP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_Array,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m__ctorP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Array,__Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Array,__ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_Array,__ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_Array,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Array,__ZL119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_Array,__Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Array,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_Array,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m__ctorP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_Array,__ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_Array,__ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_Array,__Z104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Array,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_Array,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_Array,__Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Array,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m__ctorP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_Array,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_Array,__Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Array,__Z122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m__ctorP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Array,__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m__ctorP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Array,__Z115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m__ctorP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Array,__Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m__ctorP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Array,__Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m__ctorP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Array,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_Array,__ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_Array,__ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m__ctorP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_Array,__Z88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Array,__Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargetsP21mscorlib_System_Array,__Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_WhichP21mscorlib_System_Array
  ,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m__ctorP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKindP21mscorlib_System_Array,__Z59mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m__ctorP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan24mscorlib_System_TimeSpan,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m__ctorP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeekP21mscorlib_System_Array,__ZL81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttributeP21mscorlib_System_Array,__Z85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimizationP21mscorlib_System_Array,__ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m__ctorP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTypeP21mscorlib_System_Array,__ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttributeP21mscorlib_System_Array,__Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m__ctorP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformIDP21mscorlib_System_Array,__ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_Array,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m__ctorP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCodeP21mscorlib_System_Array,__ZL107mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m__ctorP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_Array,__ZL111mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m__ctorP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_Array,__Z104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationP21mscorlib_System_Array,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_Array,__ZL100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_Array,__ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m__ctorP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_Array,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_Array,__Z78System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_GetEnumeratorP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type,__ZL69System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_PushP62System_System_Collections_Generic_Stack_1_mscorlib_System_TypeP20mscorlib_System_Type,__ZL71System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_PushP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP22mscorlib_System_Object,__Z80System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_GetEnumeratorP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__ZL83System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m__ctorP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__ZL81System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m__ctorP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_TypeP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_Array,__Z79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_GetEnumeratorP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL144mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL114mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei,__ZL97mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_RemoveP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL69mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_AddP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP20mscorlib_System_Type
  ,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_GrowIfNeededP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei,__ZL79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_AddCollectionP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_AddEnumerableP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_AddRangeP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_CheckIndexP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei,__ZL81mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_CheckCollectionP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_RemoveAtP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_set_CapacityP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei,__ZL82mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m__ctorP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_TypeP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array,__ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m__ctorP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_Array,__ZL99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m__ctorP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_Array,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_Array,__Z98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array,__Z104mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraP21mscorlib_System_Array,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_Array,__ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_Array,__Z223mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object,__Z184mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi,__Z252mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z146mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_InitArraysP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi,__Z149mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_GetEnumeratorP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z145mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_set_KeyP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Event,__Z147mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_set_ValueP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi,__Z186mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array,__Z192mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__ZL80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m__ctorP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventP21mscorlib_System_Array,__Z96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array,__Z157mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp
  ,__Z210mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi,__Z165mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_GetEnumeratorP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z168mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z152mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z197mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IDictionaryEnumerator_get_EntryP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z158mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z156mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP148mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z160mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_EntryP148mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Array,__Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array,__Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex,__Z156mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z126mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi,__Z81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_AddP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex,__Z109mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_RemoveP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_GrowIfNeededP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi,__Z91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_AddCollectionP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_AddEnumerableP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_AddRangeP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_GetEnumeratorP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_CheckIndexP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi,__Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_CheckCollectionP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_RemoveAtP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi,__Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_set_CapacityP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi,__Z94mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m__ctorP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertexP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z100mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_get_CurrentP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array,__Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo,__Z158mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z128mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi
  ,__Z83mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_AddP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo,__Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_RemoveP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_GrowIfNeededP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi,__Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_AddCollectionP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_AddEnumerableP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_AddRangeP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_GetEnumeratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_CheckIndexP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi,__Z95mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_CheckCollectionP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_RemoveAtP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi,__Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_set_CapacityP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi,__Z96mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m__ctorP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfoP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_get_CurrentP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array,__Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo,__Z158mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z128mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi,__Z83mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_AddP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo,__Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_RemoveP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_GrowIfNeededP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi,__Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_AddCollectionP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_AddEnumerableP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_AddRangeP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_GetEnumeratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_CheckIndexP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi,__Z95mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_CheckCollectionP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_RemoveAtP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi,__Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_set_CapacityP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi,__Z96mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m__ctorP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfoP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_get_CurrentP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo
  ,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ComponentP21mscorlib_System_Array,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_Array,__ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ObjectP21mscorlib_System_Array,__Z104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_GetEnumeratorP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL169mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL139mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli,__ZL122mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_RemoveP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL94mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_AddP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL103mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_GrowIfNeededP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli,__ZL104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_AddCollectionP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_AddEnumerableP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_AddRangeP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL101mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_CheckIndexP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli,__ZL106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_CheckCollectionP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_RemoveAtP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli,__ZL103mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_set_CapacityP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli,__ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_Array,__ZL107mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m__ctorP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCallP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__Z107mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_GetEnumeratorP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL172mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL142mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli,__ZL125mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_RemoveP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_AddP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_GrowIfNeededP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli,__ZL107mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_AddCollectionP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL107mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_AddEnumerableP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_AddRangeP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_CheckIndexP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli,__ZL109mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_CheckCollectionP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_RemoveAtP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli
  ,__ZL106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_set_CapacityP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli,__ZL99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctorP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_Array,__ZL110mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctorP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCallP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_Array,__ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_Array,__ZL108mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_Array,__ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m__ctorP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_Array,__Z101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m__ctorP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Array,__ZL109mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_Array,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m__ctorP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_Array,__Z93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Array,__Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Array,__Z80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m__ctorP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Array,__Z82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Array,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_Array,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_Array,__Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Array,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RendererP21mscorlib_System_Array,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_Array,__ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextureP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_Array,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_Array,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_Array,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_Array,__Z222mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object,__Z183mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachei,__Z251mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z145mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_InitArraysP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachei,__Z148mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_GetEnumeratorP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z144mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_set_KeyP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachei
  ,__Z146mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_set_ValueP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z185mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array,__Z191mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL103mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array,__Z156mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z209mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z164mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_GetEnumeratorP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z151mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z196mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IDictionaryEnumerator_get_EntryP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z157mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z155mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP147mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z159mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_EntryP147mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL100mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntryP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__Z97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_GetEnumeratorP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL162mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL132mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi,__ZL115mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_RemoveP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_AddP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_GrowIfNeededP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi,__ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_AddCollectionP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_AddEnumerableP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_AddRangeP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL94mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_CheckIndexP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi,__ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_CheckCollectionP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_RemoveAtP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi,__ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_set_CapacityP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_Array,__Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Array,__ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_Array
  ,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array,__Z232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_AddP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z129mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_GetEnumeratorP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL203mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKeyP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object,__ZL164mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylei,__ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_InitArraysP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylei,__ZL125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_set_KeyP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_String,__ZL127mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_set_ValueP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle,__Z166mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array,__Z172mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z145mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_GetEnumeratorP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL137mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_AddP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle,__ZL148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL177mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IDictionaryEnumerator_get_EntryP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL136mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_EntryP128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Array,__Z82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Array,__Z84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Array,__Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_Array,__ZL100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_Array,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_Array,__ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ShaderP21mscorlib_System_Array,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MaterialP21mscorlib_System_Array,__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_GetEnumeratorP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL148mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_TP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object
  ,__ZL118mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri,__ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_RemoveP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object,__ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_AddP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr,__ZL82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_GrowIfNeededP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri,__ZL83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_AddCollectionP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object,__ZL83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_AddEnumerableP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_AddRangeP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object,__ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_CheckIndexP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri,__ZL85mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_CheckCollectionP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_RemoveAtP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri,__ZL82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_set_CapacityP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri,__ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m__ctorP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arrP21mscorlib_System_Array,__ZL86mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m__ctorP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arrP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__Z71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m__ctorP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ByteP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_Array,__ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisplayP21mscorlib_System_Array,__Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtrP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TransformP21mscorlib_System_Array,__ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MotionP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_Array,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ColliderP21mscorlib_System_Array,__Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m__ctorP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_Array,__Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SingleP21mscorlib_System_Array,__Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Array,__Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m__ctorP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Array,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_Array,__Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Array,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m__ctorP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_Array,__ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m__ctorP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TerrainP21mscorlib_System_Array
  ,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m__ctorP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Array,__Z93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Array,__Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m__ctorP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Array,__ZL79mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m__ctorP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontP21mscorlib_System_Array,__ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m__ctorP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CanvasP21mscorlib_System_Array,__ZL113mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_Array,__ZL87mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m__ctorP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttributeP21mscorlib_System_Array,__ZL76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m__ctorP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeP21mscorlib_System_Array,__ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttributeP21mscorlib_System_Array,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m__ctorP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_Array,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_Array,__Z72mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m__ctorP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64P21mscorlib_System_Array,__Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32P21mscorlib_System_Array,__ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_Array,__Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64P21mscorlib_System_Array,__Z72mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m__ctorP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByteP21mscorlib_System_Array,__Z72mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m__ctorP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16P21mscorlib_System_Array,__Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16P21mscorlib_System_Array,__Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m__ctorP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DoubleP21mscorlib_System_Array,__Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m__ctorP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_BooleanP21mscorlib_System_Array,__Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m__ctorP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtrP21mscorlib_System_Array,__ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m__ctorP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DelegateP21mscorlib_System_Array,__ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m__ctorP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_Array,__ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_Array,__ZL86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m__ctorP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttributeP21mscorlib_System_Array,__ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttributeP21mscorlib_System_Array,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_Array,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_Array,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_Array
  ,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_Array,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m__ctorP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_Array,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m__ctorP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_Array,__ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_Array,__ZL119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m__ctorP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_Array,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m__ctorP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_Array,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m__ctorP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_Array,__ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_Array,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_Array,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m__ctorP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_Array,__ZL84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m__ctorP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttributeP21mscorlib_System_Array,__Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array,__Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m__ctorP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_Array,__ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m__ctorP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_Array,__ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m__ctorP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_Array,__Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m__ctorP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Array,__Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m__ctorP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot,__Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m__ctorP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Array,__Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m__ctorP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Array,__Z47mscorlib_System_AttributeUsageAttribute_m__ctorP39mscorlib_System_AttributeUsageAttributei,__Z59mscorlib_System_AttributeUsageAttribute_m_set_AllowMultipleP39mscorlib_System_AttributeUsageAttributeb,__Z55mscorlib_System_AttributeUsageAttribute_m_set_InheritedP39mscorlib_System_AttributeUsageAttributeb,__Z67mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m__ctorP59mscorlib_System_Runtime_InteropServices_ComVisibleAttributeb,__Z45mscorlib_System_CLSCompliantAttribute_m__ctorP37mscorlib_System_CLSCompliantAttributeb,__Z80mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr,__Z42mscorlib_System_String_m_InternalSetLengthP22mscorlib_System_Stringi,__Z74mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P23mscorlib_System_Decimali,__Z75mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_UInt32P23mscorlib_System_Decimalj
  ,__Z36mscorlib_System_Decimal_m_ThrowAtPosP22mscorlib_System_Objecti,__Z73mscorlib_System_IntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P22mscorlib_System_IntPtri,__Z81mscorlib_System_IntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_VoidU002A_ptrP22mscorlib_System_IntPtrPv,__Z75mscorlib_System_UIntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_UInt32P23mscorlib_System_UIntPtrj,__Z82mscorlib_System_UIntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_VoidU002A_ptrP23mscorlib_System_UIntPtrPv,__Z46mscorlib_System_Array_SimpleEnumerator_m__ctorP38mscorlib_System_Array_SimpleEnumeratorP21mscorlib_System_Array,__Z41mscorlib_System_Array_Swapper_m_EndInvokeP29mscorlib_System_Array_SwapperP22mscorlib_System_Object,__Z55mscorlib_System_Array_m_System_Collections_IList_RemoveP21mscorlib_System_ArrayP22mscorlib_System_Object,__Z57mscorlib_System_Array_m_System_Collections_IList_RemoveAtP21mscorlib_System_Arrayi,__Z47mscorlib_System_Array_m_InternalArray__RemoveAtP21mscorlib_System_Arrayi,__Z74mscorlib_System_Array_m_Reverse_mscorlib_System_Void_mscorlib_System_ArrayP22mscorlib_System_ObjectP21mscorlib_System_Array,__Z71mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_ArrayP22mscorlib_System_ObjectP21mscorlib_System_Array,__Z77mscorlib_System_Exception_m__ctor_mscorlib_System_Void_mscorlib_System_StringP25mscorlib_System_ExceptionP22mscorlib_System_String,__Z40mscorlib_System_Exception_m_set_HelpLinkP25mscorlib_System_ExceptionP22mscorlib_System_String,__Z39mscorlib_System_Exception_m_set_HResultP25mscorlib_System_Exceptioni,__Z38mscorlib_System_Exception_m_set_SourceP25mscorlib_System_ExceptionP22mscorlib_System_String,__Z85mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_String,__Z66mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m__ctorP58mscorlib_System_Runtime_InteropServices_MarshalAsAttributei,__Z61mscorlib_System_Runtime_InteropServices_GuidAttribute_m__ctorP53mscorlib_System_Runtime_InteropServices_GuidAttributeP22mscorlib_System_String,__Z76mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m__ctorP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP22mscorlib_System_String,__Z99mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_set_WrapNonExceptionThrowsP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeb,__Z57mscorlib_System_Reflection_DefaultMemberAttribute_m__ctorP49mscorlib_System_Reflection_DefaultMemberAttributeP22mscorlib_System_String,__Z68mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m__ctorP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttributei,__Z38mscorlib_System_AsyncCallback_m_InvokeP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z41mscorlib_System_AsyncCallback_m_EndInvokeP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z85mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_MonoTODOAttributeP22mscorlib_System_String,__Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_PreviousInfo_m__ctorP63mscorlib_Mono_Globalization_Unicode_SimpleCollator_PreviousInfob,__Z58mscorlib_Mono_Globalization_Unicode_SimpleCollator_m__ctorP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP41mscorlib_System_Globalization_CultureInfo,__Z57mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m__ctorP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferi,__Z62mscorlib_System_Collections_ArrayList_SimpleEnumerator_m__ctorP54mscorlib_System_Collections_ArrayList_SimpleEnumeratorP37mscorlib_System_Collections_ArrayList
  ,__Z62mscorlib_System_Collections_ArrayList_ArrayListWrapper_m__ctorP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP37mscorlib_System_Collections_ArrayList,__Z63mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_RemoveP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object,__Z46mscorlib_System_Collections_ArrayList_m_RemoveP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object,__Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_RemoveAtP54mscorlib_System_Collections_ArrayList_ArrayListWrapperi,__Z48mscorlib_System_Collections_ArrayList_m_RemoveAtP37mscorlib_System_Collections_ArrayListi,__Z106mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_ArrayP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP21mscorlib_System_Array,__Z89mscorlib_System_Collections_ArrayList_m_CopyTo_mscorlib_System_Void_mscorlib_System_ArrayP37mscorlib_System_Collections_ArrayListP21mscorlib_System_Array,__Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_AddRangeP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object,__Z48mscorlib_System_Collections_ArrayList_m_AddRangeP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object,__Z61mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_SortP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object,__Z44mscorlib_System_Collections_ArrayList_m_SortP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object,__Z74mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m__ctorP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP37mscorlib_System_Collections_ArrayList,__Z75mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_RemoveP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object,__Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_RemoveAtP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperi,__Z118mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_ArrayP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP21mscorlib_System_Array,__Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_AddRangeP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object,__Z73mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_SortP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object,__Z88mscorlib_System_Collections_ArrayList_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListi,__Z54mscorlib_System_Collections_ArrayList_m_EnsureCapacityP37mscorlib_System_Collections_ArrayListi,__Z104mscorlib_System_Collections_CaseInsensitiveComparer_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP51mscorlib_System_Collections_CaseInsensitiveComparerb,__Z130mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m__ctor_mscorlib_System_Void_mscorlib_System_Globalization_CultureInfoP59mscorlib_System_Collections_CaseInsensitiveHashCodeProviderP41mscorlib_System_Globalization_CultureInfo,__Z107mscorlib_System_Collections_Comparer_m__ctor_mscorlib_System_Void_mscorlib_System_Globalization_CultureInfoP36mscorlib_System_Collections_ComparerP41mscorlib_System_Globalization_CultureInfo,__Z60mscorlib_System_Collections_Hashtable_Enumerator_m_get_EntryP48mscorlib_System_Collections_Hashtable_Enumerator,__Z88mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P37mscorlib_System_Collections_Hashtablei,__Z52mscorlib_System_Collections_Hashtable_m_set_comparerP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object,__Z47mscorlib_System_Collections_Hashtable_m_set_hcpP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object,__Z46mscorlib_System_Collections_Hashtable_m_RemoveP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object,__Z42mscorlib_System_Collections_Stack_m_ResizeP33mscorlib_System_Collections_Stacki,__Z40mscorlib_System_Collections_Stack_m_PushP33mscorlib_System_Collections_StackP22mscorlib_System_Object,__Z55mscorlib_System_Diagnostics_DebuggableAttribute_m__ctorP47mscorlib_System_Diagnostics_DebuggableAttributei
  ,__Z60mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m__ctorP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String,__Z63mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_set_NameP52mscorlib_System_Diagnostics_DebuggerDisplayAttributeP22mscorlib_System_String,__Z62mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m__ctorP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP20mscorlib_System_Type,__Z49mscorlib_System_Globalization_CompareInfo_m__ctorP41mscorlib_System_Globalization_CompareInfoP41mscorlib_System_Globalization_CultureInfo,__Z65mscorlib_System_Globalization_CompareInfo_m_construct_compareinfoP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_String,__Z92mscorlib_System_Globalization_CultureInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P41mscorlib_System_Globalization_CultureInfoi,__Z62mscorlib_System_Globalization_CultureInfo_m_ConstructInvariantP41mscorlib_System_Globalization_CultureInfob,__Z101mscorlib_System_Globalization_DateTimeFormatInfo_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP48mscorlib_System_Globalization_DateTimeFormatInfob,__Z63mscorlib_System_Globalization_DateTimeFormatInfo_m_set_CalendarP48mscorlib_System_Globalization_DateTimeFormatInfoP38mscorlib_System_Globalization_Calendar,__Z54mscorlib_System_Globalization_DaylightTime_m_get_StartP42mscorlib_System_Globalization_DaylightTime,__Z52mscorlib_System_Globalization_DaylightTime_m_get_EndP42mscorlib_System_Globalization_DaylightTime,__Z129mscorlib_System_Globalization_GregorianCalendar_m__ctor_mscorlib_System_Void_mscorlib_System_Globalization_GregorianCalendarTypesP47mscorlib_System_Globalization_GregorianCalendari,__Z66mscorlib_System_Globalization_GregorianCalendar_m_set_CalendarTypeP47mscorlib_System_Globalization_GregorianCalendari,__Z99mscorlib_System_Globalization_NumberFormatInfo_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP46mscorlib_System_Globalization_NumberFormatInfob,__Z74mscorlib_System_Globalization_NumberFormatInfo_m_set_NumberNegativePatternP46mscorlib_System_Globalization_NumberFormatInfoi,__Z102mscorlib_System_Reflection_AmbiguousMatchException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP50mscorlib_System_Reflection_AmbiguousMatchExceptionP22mscorlib_System_String,__Z59mscorlib_System_Reflection_AssemblyCompanyAttribute_m__ctorP51mscorlib_System_Reflection_AssemblyCompanyAttributeP22mscorlib_System_String,__Z65mscorlib_System_Reflection_AssemblyConfigurationAttribute_m__ctorP57mscorlib_System_Reflection_AssemblyConfigurationAttributeP22mscorlib_System_String,__Z61mscorlib_System_Reflection_AssemblyCopyrightAttribute_m__ctorP53mscorlib_System_Reflection_AssemblyCopyrightAttributeP22mscorlib_System_String,__Z64mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m__ctorP56mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP22mscorlib_System_String,__Z61mscorlib_System_Reflection_AssemblyDelaySignAttribute_m__ctorP53mscorlib_System_Reflection_AssemblyDelaySignAttributeb,__Z63mscorlib_System_Reflection_AssemblyDescriptionAttribute_m__ctorP55mscorlib_System_Reflection_AssemblyDescriptionAttributeP22mscorlib_System_String,__Z63mscorlib_System_Reflection_AssemblyFileVersionAttribute_m__ctorP55mscorlib_System_Reflection_AssemblyFileVersionAttributeP22mscorlib_System_String,__Z72mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m__ctorP64mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP22mscorlib_System_String,__Z59mscorlib_System_Reflection_AssemblyKeyFileAttribute_m__ctorP51mscorlib_System_Reflection_AssemblyKeyFileAttributeP22mscorlib_System_String,__Z59mscorlib_System_Reflection_AssemblyKeyNameAttribute_m__ctorP51mscorlib_System_Reflection_AssemblyKeyNameAttributeP22mscorlib_System_String,__Z54mscorlib_System_Reflection_AssemblyName_m_SetPublicKeyP39mscorlib_System_Reflection_AssemblyNameP24mscorlib_System_Byte_arr,__Z59mscorlib_System_Reflection_AssemblyName_m_SetPublicKeyTokenP39mscorlib_System_Reflection_AssemblyNameP24mscorlib_System_Byte_arr,__Z59mscorlib_System_Reflection_AssemblyProductAttribute_m__ctorP51mscorlib_System_Reflection_AssemblyProductAttributeP22mscorlib_System_String,__Z57mscorlib_System_Reflection_AssemblyTitleAttribute_m__ctorP49mscorlib_System_Reflection_AssemblyTitleAttributeP22mscorlib_System_String
  ,__Z61mscorlib_System_Reflection_AssemblyTrademarkAttribute_m__ctorP53mscorlib_System_Reflection_AssemblyTrademarkAttributeP22mscorlib_System_String,__Z59mscorlib_System_Reflection_MonoProperty_m_CachePropertyInfoP39mscorlib_System_Reflection_MonoPropertyi,__Z50mscorlib_System_Reflection_TargetException_m__ctorP42mscorlib_System_Reflection_TargetExceptionP22mscorlib_System_String,__Z60mscorlib_System_Reflection_TargetInvocationException_m__ctorP52mscorlib_System_Reflection_TargetInvocationExceptionP25mscorlib_System_Exception,__Z108mscorlib_System_Reflection_TargetParameterCountException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP56mscorlib_System_Reflection_TargetParameterCountExceptionP22mscorlib_System_String,__Z67mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m__ctorP59mscorlib_System_Resources_NeutralResourcesLanguageAttributeP22mscorlib_System_String,__Z67mscorlib_System_Resources_SatelliteContractVersionAttribute_m__ctorP59mscorlib_System_Resources_SatelliteContractVersionAttributeP22mscorlib_System_String,__Z80mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m__ctorP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributei,__Z75mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributei,__Z71mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributei,__Z76mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m__ctorP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP20mscorlib_System_Type,__Z70mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m__ctorP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributei,__Z105mscorlib_System_Runtime_InteropServices_SafeHandle_m_Dispose_mscorlib_System_Void_mscorlib_System_BooleanP50mscorlib_System_Runtime_InteropServices_SafeHandleb,__Z75mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m__ctorP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP20mscorlib_System_Type,__Z73mscorlib_System_Runtime_Remoting_Activation_ContextLevelActivator_m__ctorP65mscorlib_System_Runtime_Remoting_Activation_ContextLevelActivatorP22mscorlib_System_Object,__Z85mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_GetPropertiesForNewContextP56mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP22mscorlib_System_Object,__Z147mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m_RegisterChannel_mscorlib_System_Void_mscorlib_System_Runtime_Remoting_Channels_IChannelP22mscorlib_System_ObjectS0_,__Z68mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainData_m__ctorP60mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainDatai,__Z80mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_StartListeningP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannelP22mscorlib_System_Object,__Z87mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_GetPropertiesForNewContextP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP22mscorlib_System_Object,__Z67mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m__ctorP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallP20mscorlib_System_Type,__Z77mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_set_IsContextOkP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallb,__Z75mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_set_ActivatorP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallP22mscorlib_System_Object,__Z85mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_SetActivationAttributesP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallP26mscorlib_System_Object_arr,__Z84mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_GetPropertiesForNewContextP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP22mscorlib_System_Object,__Z100mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m__ctor_mscorlib_System_Void_mscorlib_System_TypeP50mscorlib_System_Runtime_Remoting_Proxies_RealProxyP20mscorlib_System_Type,__Z50mscorlib_System_Runtime_Remoting_EnvoyInfo_m__ctorP42mscorlib_System_Runtime_Remoting_EnvoyInfoP22mscorlib_System_Object,__Z49mscorlib_System_Runtime_Remoting_Identity_m__ctorP41mscorlib_System_Runtime_Remoting_IdentityP22mscorlib_System_String,__Z56mscorlib_System_Runtime_Remoting_Identity_m_set_DisposedP41mscorlib_System_Runtime_Remoting_Identityb,__Z55mscorlib_System_Runtime_Remoting_ObjRef_m_set_EnvoyInfoP39mscorlib_System_Runtime_Remoting_ObjRefP22mscorlib_System_Object
  ,__Z54mscorlib_System_Runtime_Remoting_ObjRef_m_set_TypeInfoP39mscorlib_System_Runtime_Remoting_ObjRefP22mscorlib_System_Object,__Z49mscorlib_System_Runtime_Remoting_ObjRef_m_set_URIP39mscorlib_System_Runtime_Remoting_ObjRefP22mscorlib_System_String,__Z58mscorlib_System_Runtime_Remoting_RemotingException_m__ctorP50mscorlib_System_Runtime_Remoting_RemotingExceptionP22mscorlib_System_String,__Z74mscorlib_System_Runtime_Remoting_RemotingServices_m_RegisterServerIdentityP22mscorlib_System_ObjectP47mscorlib_System_Runtime_Remoting_ServerIdentity,__Z67mscorlib_System_Runtime_Remoting_RemotingServices_m_DisposeIdentityP22mscorlib_System_ObjectP41mscorlib_System_Runtime_Remoting_Identity,__Z49mscorlib_System_Runtime_Remoting_TypeInfo_m__ctorP41mscorlib_System_Runtime_Remoting_TypeInfoP20mscorlib_System_Type,__Z92mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatter_m_set_AssemblyFormatP71mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatteri,__Z68mscorlib_System_Runtime_Serialization_SerializationException_m__ctorP60mscorlib_System_Runtime_Serialization_SerializationExceptionP22mscorlib_System_String,__Z65mscorlib_System_Runtime_Serialization_SerializationInfo_m_SetTypeP55mscorlib_System_Runtime_Serialization_SerializationInfoP20mscorlib_System_Type,__Z68mscorlib_System_Security_Cryptography_CryptographicException_m__ctorP60mscorlib_System_Security_Cryptography_CryptographicExceptionP22mscorlib_System_String,__Z61mscorlib_System_Security_Cryptography_HashAlgorithm_m_DisposeP51mscorlib_System_Security_Cryptography_HashAlgorithmb,__Z73mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_RngCloseP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z73mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_GetBytesP62mscorlib_System_Security_Cryptography_RNGCryptoServiceProviderP24mscorlib_System_Byte_arr,__Z92mscorlib_System_Security_SecurityElement_m__ctor_mscorlib_System_Void_mscorlib_System_StringP40mscorlib_System_Security_SecurityElementP22mscorlib_System_String,__Z51mscorlib_System_Security_SecurityElement_m_set_TextP40mscorlib_System_Security_SecurityElementP22mscorlib_System_String,__Z51mscorlib_System_Security_SecurityElement_m_AddChildP40mscorlib_System_Security_SecurityElementS0_,__Z99mscorlib_System_Text_DecoderReplacementFallback_m__ctor_mscorlib_System_Void_mscorlib_System_StringP47mscorlib_System_Text_DecoderReplacementFallbackP22mscorlib_System_String,__Z61mscorlib_System_Text_DecoderReplacementFallbackBuffer_m__ctorP53mscorlib_System_Text_DecoderReplacementFallbackBufferP47mscorlib_System_Text_DecoderReplacementFallback,__Z99mscorlib_System_Text_EncoderReplacementFallback_m__ctor_mscorlib_System_Void_mscorlib_System_StringP47mscorlib_System_Text_EncoderReplacementFallbackP22mscorlib_System_String,__Z61mscorlib_System_Text_EncoderReplacementFallbackBuffer_m__ctorP53mscorlib_System_Text_EncoderReplacementFallbackBufferP47mscorlib_System_Text_EncoderReplacementFallback,__Z37mscorlib_System_Text_Encoding_m__ctorP29mscorlib_System_Text_Encodingi,__Z85mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderi,__Z86mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_Void_mscorlib_System_StringP34mscorlib_System_Text_StringBuilderP22mscorlib_System_String,__Z47mscorlib_System_Text_StringBuilder_m_set_LengthP34mscorlib_System_Text_StringBuilderi,__Z59mscorlib_System_Text_StringBuilder_m_InternalEnsureCapacityP34mscorlib_System_Text_StringBuilderi,__Z86mscorlib_System_Text_UTF7Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP33mscorlib_System_Text_UTF7Encodingb,__Z86mscorlib_System_Text_UTF8Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_BooleanP33mscorlib_System_Text_UTF8Encodingb,__Z41mscorlib_System_Threading_Monitor_m_EnterP22mscorlib_System_ObjectS0_,__Z40mscorlib_System_Threading_Monitor_m_ExitP22mscorlib_System_ObjectS0_,__Z64mscorlib_System_Threading_NativeEventCalls_m_CloseEvent_internalP22mscorlib_System_Object22mscorlib_System_IntPtr
  ,__Z55mscorlib_System_Threading_Thread_m_Thread_free_internalP32mscorlib_System_Threading_Thread22mscorlib_System_IntPtr,__Z46mscorlib_System_Threading_WaitHandle_m_DisposeP36mscorlib_System_Threading_WaitHandleb,__Z88mscorlib_System_ActivationContext_m_Dispose_mscorlib_System_Void_mscorlib_System_BooleanP33mscorlib_System_ActivationContextb,__Z37mscorlib_System_Activator_m_CheckTypeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z45mscorlib_System_Activator_m_CheckAbstractTypeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z85mscorlib_System_ArgumentException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_ArgumentExceptionP22mscorlib_System_String,__Z89mscorlib_System_ArgumentNullException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP37mscorlib_System_ArgumentNullExceptionP22mscorlib_System_String,__Z95mscorlib_System_ArgumentOutOfRangeException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP43mscorlib_System_ArgumentOutOfRangeExceptionP22mscorlib_System_String,__Z43mscorlib_System_ArithmeticException_m__ctorP35mscorlib_System_ArithmeticExceptionP22mscorlib_System_String,__Z94mscorlib_System_ArrayTypeMismatchException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP42mscorlib_System_ArrayTypeMismatchExceptionP22mscorlib_System_String,__Z38mscorlib_System_CharEnumerator_m__ctorP30mscorlib_System_CharEnumeratorP22mscorlib_System_String,__Z34mscorlib_System_DateTime_m_get_NowP22mscorlib_System_Object,__Z36mscorlib_System_DateTime_m_get_TodayP22mscorlib_System_Object,__Z44mscorlib_System_DateTime_m_CheckDateTimeKindP24mscorlib_System_DateTimei,__Z38mscorlib_System_DateTime_m_ToLocalTimeP24mscorlib_System_DateTime,__Z42mscorlib_System_DateTime_m_ToUniversalTimeP24mscorlib_System_DateTime,__Z84mscorlib_System_DateTimeOffset_m__ctor_mscorlib_System_Void_mscorlib_System_DateTimeP30mscorlib_System_DateTimeOffset24mscorlib_System_DateTime,__Z45mscorlib_System_DateTimeOffset_m_get_DateTimeP30mscorlib_System_DateTimeOffset,__Z48mscorlib_System_DateTimeOffset_m_get_UtcDateTimeP30mscorlib_System_DateTimeOffset,__Z36mscorlib_System_MonoEnumInfo_m__ctorP28mscorlib_System_MonoEnumInfoS_,__Z44mscorlib_System_FieldAccessException_m__ctorP36mscorlib_System_FieldAccessExceptionP22mscorlib_System_String,__Z83mscorlib_System_FormatException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP31mscorlib_System_FormatExceptionP22mscorlib_System_String,__Z37mscorlib_System_GC_m_SuppressFinalizeP22mscorlib_System_ObjectS0_,__Z78mscorlib_System_Guid_m__ctor_mscorlib_System_Void_mscorlib_System_Byte_arr_arrP20mscorlib_System_GuidP24mscorlib_System_Byte_arr,__Z32mscorlib_System_Guid_m_CheckNullP22mscorlib_System_ObjectS0_,__Z30mscorlib_System_Guid_m_NewGuidP22mscorlib_System_Object,__Z92mscorlib_System_IndexOutOfRangeException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP40mscorlib_System_IndexOutOfRangeExceptionP22mscorlib_System_String,__Z88mscorlib_System_InvalidCastException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP36mscorlib_System_InvalidCastExceptionP22mscorlib_System_String,__Z93mscorlib_System_InvalidOperationException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP41mscorlib_System_InvalidOperationExceptionP22mscorlib_System_String,__Z89mscorlib_System_MemberAccessException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP37mscorlib_System_MemberAccessExceptionP22mscorlib_System_String
  ,__Z45mscorlib_System_MissingFieldException_m__ctorP37mscorlib_System_MissingFieldExceptionP22mscorlib_System_String,__Z90mscorlib_System_MissingMemberException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP38mscorlib_System_MissingMemberExceptionP22mscorlib_System_String,__Z90mscorlib_System_MissingMethodException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP38mscorlib_System_MissingMethodExceptionP22mscorlib_System_String,__Z54mscorlib_System_MulticastNotSupportedException_m__ctorP46mscorlib_System_MulticastNotSupportedExceptionP22mscorlib_System_String,__Z91mscorlib_System_NotImplementedException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP39mscorlib_System_NotImplementedExceptionP22mscorlib_System_String,__Z89mscorlib_System_NotSupportedException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP37mscorlib_System_NotSupportedExceptionP22mscorlib_System_String,__Z90mscorlib_System_NullReferenceException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP38mscorlib_System_NullReferenceExceptionP22mscorlib_System_String,__Z39mscorlib_System_NumberFormatter_m__ctorP31mscorlib_System_NumberFormatterP32mscorlib_System_Threading_Thread,__Z94mscorlib_System_NumberFormatter_m_InitDecHexDigits_mscorlib_System_Void_mscorlib_System_UInt32P31mscorlib_System_NumberFormatterj,__Z82mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_StringP31mscorlib_System_NumberFormatterP22mscorlib_System_String,__Z46mscorlib_System_NumberFormatter_m_ResetCharBufP31mscorlib_System_NumberFormatteri,__Z40mscorlib_System_NumberFormatter_m_ResizeP31mscorlib_System_NumberFormatteri,__Z82mscorlib_System_NumberFormatter_m_Append_mscorlib_System_Void_mscorlib_System_CharP31mscorlib_System_NumberFormattert,__Z84mscorlib_System_NumberFormatter_m_Append_mscorlib_System_Void_mscorlib_System_StringP31mscorlib_System_NumberFormatterP22mscorlib_System_String,__Z52mscorlib_System_NumberFormatter_m_set_CurrentCultureP31mscorlib_System_NumberFormatterP41mscorlib_System_Globalization_CultureInfo,__Z42mscorlib_System_NumberFormatter_m_RoundPosP31mscorlib_System_NumberFormatteri,__Z96mscorlib_System_NumberFormatter_m_AppendIntegerString_mscorlib_System_Void_mscorlib_System_Int32P31mscorlib_System_NumberFormatteri,__Z96mscorlib_System_NumberFormatter_m_AppendDecimalString_mscorlib_System_Void_mscorlib_System_Int32P31mscorlib_System_NumberFormatteri,__Z48mscorlib_System_NumberFormatter_m_AppendOneDigitP31mscorlib_System_NumberFormatteri,__Z44mscorlib_System_NumberFormatter_m_Multiply10P31mscorlib_System_NumberFormatteri,__Z42mscorlib_System_NumberFormatter_m_Divide10P31mscorlib_System_NumberFormatteri,__Z47mscorlib_System_ObjectDisposedException_m__ctorP39mscorlib_System_ObjectDisposedExceptionP22mscorlib_System_String,__Z85mscorlib_System_OverflowException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_OverflowExceptionP22mscorlib_System_String,__Z81mscorlib_System_RankException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP29mscorlib_System_RankExceptionP22mscorlib_System_String,__Z43mscorlib_System_RuntimeMethodHandle_m__ctorP35mscorlib_System_RuntimeMethodHandle22mscorlib_System_IntPtr,__Z39mscorlib_System_OrdinalComparer_m__ctorP31mscorlib_System_OrdinalComparerb,__Z83mscorlib_System_SystemException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP31mscorlib_System_SystemExceptionP22mscorlib_System_String,__Z57mscorlib_System_CurrentSystemTimeZone_m_OnDeserializationP37mscorlib_System_CurrentSystemTimeZoneP42mscorlib_System_Globalization_DaylightTime,__Z85mscorlib_System_TypeLoadException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP33mscorlib_System_TypeLoadExceptionP22mscorlib_System_String,__Z75mscorlib_System_Version_m__ctor_mscorlib_System_Void_mscorlib_System_StringP23mscorlib_System_VersionP22mscorlib_System_String
  ,__Z45mscorlib_System_AppDomainInitializer_m_InvokeP36mscorlib_System_AppDomainInitializerP26mscorlib_System_String_arr,__Z48mscorlib_System_AppDomainInitializer_m_EndInvokeP36mscorlib_System_AppDomainInitializerP22mscorlib_System_Object,__Z52mscorlib_System_AssemblyLoadEventHandler_m_EndInvokeP40mscorlib_System_AssemblyLoadEventHandlerP22mscorlib_System_Object,__Z40mscorlib_System_EventHandler_m_EndInvokeP28mscorlib_System_EventHandlerP22mscorlib_System_Object,__Z58mscorlib_System_UnhandledExceptionEventHandler_m_EndInvokeP46mscorlib_System_UnhandledExceptionEventHandlerP22mscorlib_System_Object,__Z51UnityEngine_UnityEngine_GUI_WindowFunction_m_InvokeP42UnityEngine_UnityEngine_GUI_WindowFunctioni,__Z54UnityEngine_UnityEngine_GUI_WindowFunction_m_EndInvokeP42UnityEngine_UnityEngine_GUI_WindowFunctionP22mscorlib_System_Object,__Z52UnityEngine_UnityEngine_GUI_m_set_nextScrollStepTimeP22mscorlib_System_Object24mscorlib_System_DateTime,__Z38UnityEngine_UnityEngine_GUI_m_set_skinP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_GUISkin,__Z41UnityEngine_UnityEngine_GUI_m_set_changedP22mscorlib_System_Objectb,__Z61UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_SendMessageP47UnityEngine_UnityEngine_SendMouseEvents_HitInfoP22mscorlib_System_String,__Z60UnityEngine_UnityEngine_StackTraceUtility_m_SetProjectFolderP22mscorlib_System_ObjectP22mscorlib_System_String,__Z90UnityEngine_UnityEngine_UnityException_m__ctor_mscorlib_System_Void_mscorlib_System_StringP38UnityEngine_UnityEngine_UnityExceptionP22mscorlib_System_String,__Z88UnityEngine_UnityEngine_TextGenerator_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P37UnityEngine_UnityEngine_TextGeneratori,__Z55UnityEngine_UnityEngine_TextGenerator_m_get_rectExtentsP37UnityEngine_UnityEngine_TextGenerator,__Z51UnityEngine_UnityEngine_TextGenerator_m_GetVerticesP37UnityEngine_UnityEngine_TextGeneratorP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z59UnityEngine_UnityEngine_TextGenerator_m_GetVerticesInternalP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_Object,__Z53UnityEngine_UnityEngine_TextGenerator_m_GetCharactersP37UnityEngine_UnityEngine_TextGeneratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z61UnityEngine_UnityEngine_TextGenerator_m_GetCharactersInternalP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_Object,__Z48UnityEngine_UnityEngine_TextGenerator_m_GetLinesP37UnityEngine_UnityEngine_TextGeneratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z56UnityEngine_UnityEngine_TextGenerator_m_GetLinesInternalP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_Object,__Z59UnityEngine_UnityEngine_Application_LogCallback_m_EndInvokeP47UnityEngine_UnityEngine_Application_LogCallbackP22mscorlib_System_Object,__Z59UnityEngine_UnityEngine_Application_m_Internal_ExternalCallP22mscorlib_System_ObjectP22mscorlib_System_String,__Z91UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_StringP33UnityEngine_UnityEngine_ComponentP22mscorlib_System_String,__Z44UnityEngine_UnityEngine_GameObject_m_set_tagP34UnityEngine_UnityEngine_GameObjectP22mscorlib_System_String,__Z92UnityEngine_UnityEngine_Object_m_Destroy_mscorlib_System_Void_UnityEngine_UnityEngine_ObjectP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Object,__Z41UnityEngine_UnityEngine_Object_m_set_nameP30UnityEngine_UnityEngine_ObjectP22mscorlib_System_String,__Z75UnityEngine_UnityEngine_UserAuthorizationDialog_m_DoUserAuthorizationDialogP47UnityEngine_UnityEngine_UserAuthorizationDialogi,__Z62UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m__ctorP54UnityEngine_UnityEngine_Internal_DefaultValueAttributeP22mscorlib_System_String,__Z62UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m__ctorP54UnityEngine_UnityEngine_RenamedSerializedDataAttributeP22mscorlib_System_String
  ,__Z138UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngineInternal_TypeInferenceRulesP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributei,__Z110UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_StringP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP22mscorlib_System_String,__Z45UnityEngine_UnityEngine_LayerMask_m_set_valueP33UnityEngine_UnityEngine_LayerMaski,__Z48UnityEngine_UnityEngine_RequireComponent_m__ctorP40UnityEngine_UnityEngine_RequireComponentP20mscorlib_System_Type,__Z48UnityEngine_UnityEngine_AddComponentMenu_m__ctorP40UnityEngine_UnityEngine_AddComponentMenuP22mscorlib_System_String,__Z74UnityEngine_UnityEngine_ScriptableObject_m_Internal_CreateScriptableObjectP22mscorlib_System_ObjectP40UnityEngine_UnityEngine_ScriptableObject,__Z51UnityEngine_UnityEngine_BoneWeight_m_set_boneIndex0P34UnityEngine_UnityEngine_BoneWeighti,__Z51UnityEngine_UnityEngine_BoneWeight_m_set_boneIndex1P34UnityEngine_UnityEngine_BoneWeighti,__Z51UnityEngine_UnityEngine_BoneWeight_m_set_boneIndex2P34UnityEngine_UnityEngine_BoneWeighti,__Z51UnityEngine_UnityEngine_BoneWeight_m_set_boneIndex3P34UnityEngine_UnityEngine_BoneWeighti,__Z46UnityEngine_UnityEngine_Resolution_m_set_widthP34UnityEngine_UnityEngine_Resolutioni,__Z47UnityEngine_UnityEngine_Resolution_m_set_heightP34UnityEngine_UnityEngine_Resolutioni,__Z52UnityEngine_UnityEngine_Resolution_m_set_refreshRateP34UnityEngine_UnityEngine_Resolutioni,__Z48UnityEngine_UnityEngine_GUILayoutUtility_m_BeginP22mscorlib_System_Objecti,__Z53UnityEngine_UnityEngine_GUILayoutGroup_m_ApplyOptionsP38UnityEngine_UnityEngine_GUILayoutGroupP43UnityEngine_UnityEngine_GUILayoutOption_arr,__Z58UnityEngine_UnityEngine_GUILayoutUtility_m_LayoutFreeGroupP22mscorlib_System_ObjectP38UnityEngine_UnityEngine_GUILayoutGroup,__Z60UnityEngine_UnityEngine_GUILayoutUtility_m_LayoutSingleGroupP22mscorlib_System_ObjectP38UnityEngine_UnityEngine_GUILayoutGroup,__Z50UnityEngine_UnityEngine_GUILayoutEntry_m_set_styleP38UnityEngine_UnityEngine_GUILayoutEntryP32UnityEngine_UnityEngine_GUIStyle,__Z59UnityEngine_UnityEngine_GUILayoutEntry_m_ApplyStyleSettingsP38UnityEngine_UnityEngine_GUILayoutEntryP32UnityEngine_UnityEngine_GUIStyle,__Z53UnityEngine_UnityEngine_GUILayoutEntry_m_ApplyOptionsP38UnityEngine_UnityEngine_GUILayoutEntryP43UnityEngine_UnityEngine_GUILayoutOption_arr,__Z59UnityEngine_UnityEngine_GUILayoutGroup_m_ApplyStyleSettingsP38UnityEngine_UnityEngine_GUILayoutGroupP32UnityEngine_UnityEngine_GUIStyle,__Z43UnityEngine_UnityEngine_GUIUtility_m_EndGUIP22mscorlib_System_Objecti,__Z63UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate_m_EndInvokeP51UnityEngine_UnityEngine_GUISkin_SkinChangedDelegateP22mscorlib_System_Object,__Z42UnityEngine_UnityEngine_GUISkin_m_set_fontP31UnityEngine_UnityEngine_GUISkinP28UnityEngine_UnityEngine_Font,__Z41UnityEngine_UnityEngine_GUISkin_m_set_boxP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z43UnityEngine_UnityEngine_GUISkin_m_set_labelP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z47UnityEngine_UnityEngine_GUISkin_m_set_textFieldP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z46UnityEngine_UnityEngine_GUISkin_m_set_textAreaP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z44UnityEngine_UnityEngine_GUISkin_m_set_buttonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z44UnityEngine_UnityEngine_GUISkin_m_set_toggleP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle
  ,__Z44UnityEngine_UnityEngine_GUISkin_m_set_windowP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z54UnityEngine_UnityEngine_GUISkin_m_set_horizontalSliderP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z59UnityEngine_UnityEngine_GUISkin_m_set_horizontalSliderThumbP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z52UnityEngine_UnityEngine_GUISkin_m_set_verticalSliderP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z57UnityEngine_UnityEngine_GUISkin_m_set_verticalSliderThumbP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z57UnityEngine_UnityEngine_GUISkin_m_set_horizontalScrollbarP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z62UnityEngine_UnityEngine_GUISkin_m_set_horizontalScrollbarThumbP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z67UnityEngine_UnityEngine_GUISkin_m_set_horizontalScrollbarLeftButtonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z68UnityEngine_UnityEngine_GUISkin_m_set_horizontalScrollbarRightButtonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z55UnityEngine_UnityEngine_GUISkin_m_set_verticalScrollbarP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z60UnityEngine_UnityEngine_GUISkin_m_set_verticalScrollbarThumbP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z63UnityEngine_UnityEngine_GUISkin_m_set_verticalScrollbarUpButtonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z65UnityEngine_UnityEngine_GUISkin_m_set_verticalScrollbarDownButtonP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z48UnityEngine_UnityEngine_GUISkin_m_set_scrollViewP31UnityEngine_UnityEngine_GUISkinP32UnityEngine_UnityEngine_GUIStyle,__Z50UnityEngine_UnityEngine_GUISkin_m_set_customStylesP31UnityEngine_UnityEngine_GUISkinP36UnityEngine_UnityEngine_GUIStyle_arr,__Z86UnityEngine_UnityEngine_GUIContent_m__ctor_mscorlib_System_Void_mscorlib_System_StringP34UnityEngine_UnityEngine_GUIContentP22mscorlib_System_String,__Z62UnityEngine_UnityEngine_GUIStyleState_m_INTERNAL_set_textColorP37UnityEngine_UnityEngine_GUIStyleStateP29UnityEngine_UnityEngine_Color,__Z53UnityEngine_UnityEngine_GUIStyleState_m_set_textColorP37UnityEngine_UnityEngine_GUIStyleState29UnityEngine_UnityEngine_Color,__Z45UnityEngine_UnityEngine_RectOffset_m_set_leftP34UnityEngine_UnityEngine_RectOffseti,__Z46UnityEngine_UnityEngine_RectOffset_m_set_rightP34UnityEngine_UnityEngine_RectOffseti,__Z44UnityEngine_UnityEngine_RectOffset_m_set_topP34UnityEngine_UnityEngine_RectOffseti,__Z47UnityEngine_UnityEngine_RectOffset_m_set_bottomP34UnityEngine_UnityEngine_RectOffseti,__Z43UnityEngine_UnityEngine_GUIStyle_m_set_nameP32UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_String,__Z51UnityEngine_UnityEngine_GUIStyle_m_set_stretchWidthP32UnityEngine_UnityEngine_GUIStyleb,__Z52UnityEngine_UnityEngine_GUIStyle_m_set_stretchHeightP32UnityEngine_UnityEngine_GUIStyleb,__Z49UnityEngine_UnityEngine_GUIStyle_m_SetDefaultFontP22mscorlib_System_ObjectP28UnityEngine_UnityEngine_Font,__Z49UnityEngine_UnityEngine_Event_m_get_mousePositionP29UnityEngine_UnityEngine_Event,__Z57UnityEngine_UnityEngine_Event_m_Internal_GetMousePositionP29UnityEngine_UnityEngine_EventP31UnityEngine_UnityEngine_Vector2,__Z55UnityEngine_UnityEngine_Event_m_Internal_SetNativeEventP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z42UnityEngine_UnityEngine_Vector2_m_get_zeroP22mscorlib_System_Object
  ,__Z48UnityEngine_UnityEngine_Vector3_m_get_normalizedP31UnityEngine_UnityEngine_Vector3,__Z42UnityEngine_UnityEngine_Vector3_m_get_zeroP22mscorlib_System_Object,__Z45UnityEngine_UnityEngine_Vector3_m_get_forwardP22mscorlib_System_Object,__Z42UnityEngine_UnityEngine_Vector3_m_get_backP22mscorlib_System_Object,__Z40UnityEngine_UnityEngine_Vector3_m_get_upP22mscorlib_System_Object,__Z42UnityEngine_UnityEngine_Vector3_m_get_downP22mscorlib_System_Object,__Z39UnityEngine_UnityEngine_Color_m_get_redP22mscorlib_System_Object,__Z41UnityEngine_UnityEngine_Color_m_get_whiteP22mscorlib_System_Object,__Z52UnityEngine_UnityEngine_Quaternion_m_get_eulerAnglesP34UnityEngine_UnityEngine_Quaternion,__Z47UnityEngine_UnityEngine_Matrix4x4_m_get_inverseP33UnityEngine_UnityEngine_Matrix4x4,__Z49UnityEngine_UnityEngine_Matrix4x4_m_get_transposeP33UnityEngine_UnityEngine_Matrix4x4,__Z44UnityEngine_UnityEngine_Matrix4x4_m_get_zeroP22mscorlib_System_Object,__Z48UnityEngine_UnityEngine_Matrix4x4_m_get_identityP22mscorlib_System_Object,__Z43UnityEngine_UnityEngine_Bounds_m_get_centerP30UnityEngine_UnityEngine_Bounds,__Z43UnityEngine_UnityEngine_Bounds_m_set_centerP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z41UnityEngine_UnityEngine_Bounds_m_get_sizeP30UnityEngine_UnityEngine_Bounds,__Z41UnityEngine_UnityEngine_Bounds_m_set_sizeP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z44UnityEngine_UnityEngine_Bounds_m_get_extentsP30UnityEngine_UnityEngine_Bounds,__Z44UnityEngine_UnityEngine_Bounds_m_set_extentsP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z40UnityEngine_UnityEngine_Bounds_m_get_minP30UnityEngine_UnityEngine_Bounds,__Z40UnityEngine_UnityEngine_Bounds_m_set_minP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z40UnityEngine_UnityEngine_Bounds_m_get_maxP30UnityEngine_UnityEngine_Bounds,__Z40UnityEngine_UnityEngine_Bounds_m_set_maxP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z97UnityEngine_UnityEngine_Bounds_m_Encapsulate_mscorlib_System_Void_UnityEngine_UnityEngine_Vector3P30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z96UnityEngine_UnityEngine_Bounds_m_Encapsulate_mscorlib_System_Void_UnityEngine_UnityEngine_BoundsP30UnityEngine_UnityEngine_BoundsS_,__Z92UnityEngine_UnityEngine_Bounds_m_Expand_mscorlib_System_Void_UnityEngine_UnityEngine_Vector3P30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z43UnityEngine_UnityEngine_Ray_m_get_directionP27UnityEngine_UnityEngine_Ray,__Z44UnityEngine_UnityEngine_Material_m_get_colorP32UnityEngine_UnityEngine_Material,__Z44UnityEngine_UnityEngine_Material_m_set_colorP32UnityEngine_UnityEngine_Material29UnityEngine_UnityEngine_Color,__Z50UnityEngine_UnityEngine_Material_m_set_renderQueueP32UnityEngine_UnityEngine_Materiali
  ,__Z48UnityEngine_UnityEngine_Material_m_EnableKeywordP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_String,__Z49UnityEngine_UnityEngine_Material_m_DisableKeywordP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_String,__Z47UnityEngine_UnityEngine_Behaviour_m_set_enabledP33UnityEngine_UnityEngine_Behaviourb,__Z54UnityEngine_UnityEngine_Camera_CameraCallback_m_InvokeP45UnityEngine_UnityEngine_Camera_CameraCallbackP30UnityEngine_UnityEngine_Camera,__Z57UnityEngine_UnityEngine_Camera_CameraCallback_m_EndInvokeP45UnityEngine_UnityEngine_Camera_CameraCallbackP22mscorlib_System_Object,__Z55UnityEngine_UnityEngine_Camera_m_INTERNAL_get_pixelRectP30UnityEngine_UnityEngine_CameraP28UnityEngine_UnityEngine_Rect,__Z46UnityEngine_UnityEngine_Camera_m_get_pixelRectP30UnityEngine_UnityEngine_Camera,__Z46UnityEngine_UnityEngine_Camera_m_FireOnPreCullP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Camera,__Z48UnityEngine_UnityEngine_Camera_m_FireOnPreRenderP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Camera,__Z49UnityEngine_UnityEngine_Camera_m_FireOnPostRenderP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Camera,__Z35UnityEngine_UnityEngine_Debug_m_LogP22mscorlib_System_ObjectS0_,__Z40UnityEngine_UnityEngine_Debug_m_LogErrorP22mscorlib_System_ObjectS0_,__Z42UnityEngine_UnityEngine_Debug_m_LogWarningP22mscorlib_System_ObjectS0_,__Z67UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate_m_EndInvokeP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegateP22mscorlib_System_Object,__Z83UnityEngine_UnityEngine_Display_m__ctor_mscorlib_System_Void_mscorlib_System_IntPtrP31UnityEngine_UnityEngine_Display22mscorlib_System_IntPtr,__Z55UnityEngine_UnityEngine_Display_m_add_onDisplaysUpdatedP22mscorlib_System_ObjectP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate,__Z58UnityEngine_UnityEngine_Display_m_remove_onDisplaysUpdatedP22mscorlib_System_ObjectP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate,__Z49UnityEngine_UnityEngine_Display_m_get_colorBufferP31UnityEngine_UnityEngine_Display,__Z49UnityEngine_UnityEngine_Display_m_get_depthBufferP31UnityEngine_UnityEngine_Display,__Z53UnityEngine_UnityEngine_Display_m_RecreateDisplayListP22mscorlib_System_ObjectP26mscorlib_System_IntPtr_arr,__Z49UnityEngine_UnityEngine_Input_m_get_mousePositionP22mscorlib_System_Object,__Z57UnityEngine_UnityEngine_Transform_m_INTERNAL_get_positionP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__Z57UnityEngine_UnityEngine_Transform_m_INTERNAL_set_positionP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__Z48UnityEngine_UnityEngine_Transform_m_get_positionP33UnityEngine_UnityEngine_Transform,__Z48UnityEngine_UnityEngine_Transform_m_set_positionP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3,__Z51UnityEngine_UnityEngine_Transform_m_get_eulerAnglesP33UnityEngine_UnityEngine_Transform,__Z65UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localEulerAnglesP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__Z65UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localEulerAnglesP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__Z56UnityEngine_UnityEngine_Transform_m_get_localEulerAnglesP33UnityEngine_UnityEngine_Transform,__Z56UnityEngine_UnityEngine_Transform_m_set_localEulerAnglesP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3
  ,__Z42UnityEngine_UnityEngine_Transform_m_get_upP33UnityEngine_UnityEngine_Transform,__Z47UnityEngine_UnityEngine_Transform_m_get_forwardP33UnityEngine_UnityEngine_Transform,__Z57UnityEngine_UnityEngine_Transform_m_INTERNAL_get_rotationP33UnityEngine_UnityEngine_TransformP34UnityEngine_UnityEngine_Quaternion,__Z57UnityEngine_UnityEngine_Transform_m_INTERNAL_set_rotationP33UnityEngine_UnityEngine_TransformP34UnityEngine_UnityEngine_Quaternion,__Z48UnityEngine_UnityEngine_Transform_m_get_rotationP33UnityEngine_UnityEngine_Transform,__Z48UnityEngine_UnityEngine_Transform_m_set_rotationP33UnityEngine_UnityEngine_Transform34UnityEngine_UnityEngine_Quaternion,__Z62UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localRotationP33UnityEngine_UnityEngine_TransformP34UnityEngine_UnityEngine_Quaternion,__Z62UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localRotationP33UnityEngine_UnityEngine_TransformP34UnityEngine_UnityEngine_Quaternion,__Z53UnityEngine_UnityEngine_Transform_m_get_localRotationP33UnityEngine_UnityEngine_Transform,__Z53UnityEngine_UnityEngine_Transform_m_set_localRotationP33UnityEngine_UnityEngine_Transform34UnityEngine_UnityEngine_Quaternion,__Z59UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localScaleP33UnityEngine_UnityEngine_TransformP31UnityEngine_UnityEngine_Vector3,__Z50UnityEngine_UnityEngine_Transform_m_set_localScaleP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3,__Z67UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localToWorldMatrixP33UnityEngine_UnityEngine_TransformP33UnityEngine_UnityEngine_Matrix4x4,__Z58UnityEngine_UnityEngine_Transform_m_get_localToWorldMatrixP33UnityEngine_UnityEngine_Transform,__Z47UnityEngine_UnityEngine_Particle_m_get_positionP32UnityEngine_UnityEngine_Particle,__Z47UnityEngine_UnityEngine_Particle_m_set_positionP32UnityEngine_UnityEngine_Particle31UnityEngine_UnityEngine_Vector3,__Z47UnityEngine_UnityEngine_Particle_m_get_velocityP32UnityEngine_UnityEngine_Particle,__Z47UnityEngine_UnityEngine_Particle_m_set_velocityP32UnityEngine_UnityEngine_Particle31UnityEngine_UnityEngine_Vector3,__Z44UnityEngine_UnityEngine_Particle_m_get_colorP32UnityEngine_UnityEngine_Particle,__Z44UnityEngine_UnityEngine_Particle_m_set_colorP32UnityEngine_UnityEngine_Particle29UnityEngine_UnityEngine_Color,__Z54UnityEngine_UnityEngine_Rigidbody_m_set_freezeRotationP33UnityEngine_UnityEngine_Rigidbodyb,__Z46UnityEngine_UnityEngine_Collider_m_set_enabledP32UnityEngine_UnityEngine_Colliderb,__Z54UnityEngine_UnityEngine_Collider_m_INTERNAL_get_boundsP32UnityEngine_UnityEngine_ColliderP30UnityEngine_UnityEngine_Bounds,__Z45UnityEngine_UnityEngine_Collider_m_get_boundsP32UnityEngine_UnityEngine_Collider,__Z57UnityEngine_UnityEngine_ControllerColliderHit_m_get_pointP45UnityEngine_UnityEngine_ControllerColliderHit,__Z58UnityEngine_UnityEngine_ControllerColliderHit_m_get_normalP45UnityEngine_UnityEngine_ControllerColliderHit,__Z65UnityEngine_UnityEngine_ControllerColliderHit_m_get_moveDirectionP45UnityEngine_UnityEngine_ControllerColliderHit,__Z67UnityEngine_UnityEngine_CharacterController_m_INTERNAL_get_velocityP43UnityEngine_UnityEngine_CharacterControllerP31UnityEngine_UnityEngine_Vector3,__Z58UnityEngine_UnityEngine_CharacterController_m_get_velocityP43UnityEngine_UnityEngine_CharacterController,__Z65UnityEngine_UnityEngine_CharacterController_m_INTERNAL_get_centerP43UnityEngine_UnityEngine_CharacterControllerP31UnityEngine_UnityEngine_Vector3
  ,__Z56UnityEngine_UnityEngine_CharacterController_m_get_centerP43UnityEngine_UnityEngine_CharacterController,__Z60UnityEngine_UnityEngine_AudioClip_PCMReaderCallback_m_InvokeP51UnityEngine_UnityEngine_AudioClip_PCMReaderCallbackP26mscorlib_System_Single_arr,__Z63UnityEngine_UnityEngine_AudioClip_PCMReaderCallback_m_EndInvokeP51UnityEngine_UnityEngine_AudioClip_PCMReaderCallbackP22mscorlib_System_Object,__Z65UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallback_m_InvokeP56UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallbacki,__Z68UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallback_m_EndInvokeP56UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallbackP22mscorlib_System_Object,__Z68UnityEngine_UnityEngine_AudioClip_m_InvokePCMReaderCallback_InternalP33UnityEngine_UnityEngine_AudioClipP26mscorlib_System_Single_arr,__Z73UnityEngine_UnityEngine_AudioClip_m_InvokePCMSetPositionCallback_InternalP33UnityEngine_UnityEngine_AudioClipi,__Z49UnityEngine_UnityEngine_AnimationEvent_m_set_dataP38UnityEngine_UnityEngine_AnimationEventP22mscorlib_System_String,__Z60UnityEngine_UnityEngine_AnimationEvent_m_set_stringParameterP38UnityEngine_UnityEngine_AnimationEventP22mscorlib_System_String,__Z57UnityEngine_UnityEngine_AnimationEvent_m_set_intParameterP38UnityEngine_UnityEngine_AnimationEventi,__Z69UnityEngine_UnityEngine_AnimationEvent_m_set_objectReferenceParameterP38UnityEngine_UnityEngine_AnimationEventP30UnityEngine_UnityEngine_Object,__Z57UnityEngine_UnityEngine_AnimationEvent_m_set_functionNameP38UnityEngine_UnityEngine_AnimationEventP22mscorlib_System_String,__Z59UnityEngine_UnityEngine_AnimationEvent_m_set_messageOptionsP38UnityEngine_UnityEngine_AnimationEventi,__Z62UnityEngine_UnityEngine_AnimationEvent_m_get_animatorStateInfoP38UnityEngine_UnityEngine_AnimationEvent,__Z61UnityEngine_UnityEngine_AnimationEvent_m_get_animatorClipInfoP38UnityEngine_UnityEngine_AnimationEvent,__Z108UnityEngine_UnityEngine_AnimationCurve_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngine_Keyframe_arr_arrP38UnityEngine_UnityEngine_AnimationCurveP36UnityEngine_UnityEngine_Keyframe_arr,__Z45UnityEngine_UnityEngine_AnimationCurve_m_InitP38UnityEngine_UnityEngine_AnimationCurveP36UnityEngine_UnityEngine_Keyframe_arr,__Z89UnityEngine_UnityEngine_Animation_m_CrossFade_mscorlib_System_Void_mscorlib_System_StringP33UnityEngine_UnityEngine_AnimationP22mscorlib_System_String,__Z53UnityEngine_UnityEngine_AnimationState_m_set_wrapModeP38UnityEngine_UnityEngine_AnimationStatei,__Z82UnityEngine_UnityEngine_Animator_m_Play_mscorlib_System_Void_mscorlib_System_Int32P32UnityEngine_UnityEngine_Animatori,__Z48UnityEngine_UnityEngine_HumanBone_m_set_boneNameP33UnityEngine_UnityEngine_HumanBoneP22mscorlib_System_String,__Z49UnityEngine_UnityEngine_HumanBone_m_set_humanNameP33UnityEngine_UnityEngine_HumanBoneP22mscorlib_System_String,__Z65UnityEngine_UnityEngine_CharacterInfo_m_get_uvBottomLeftUnFlippedP37UnityEngine_UnityEngine_CharacterInfo,__Z66UnityEngine_UnityEngine_CharacterInfo_m_get_uvBottomRightUnFlippedP37UnityEngine_UnityEngine_CharacterInfo,__Z63UnityEngine_UnityEngine_CharacterInfo_m_get_uvTopRightUnFlippedP37UnityEngine_UnityEngine_CharacterInfo,__Z62UnityEngine_UnityEngine_CharacterInfo_m_get_uvTopLeftUnFlippedP37UnityEngine_UnityEngine_CharacterInfo,__Z56UnityEngine_UnityEngine_CharacterInfo_m_get_uvBottomLeftP37UnityEngine_UnityEngine_CharacterInfo,__Z57UnityEngine_UnityEngine_CharacterInfo_m_get_uvBottomRightP37UnityEngine_UnityEngine_CharacterInfo,__Z54UnityEngine_UnityEngine_CharacterInfo_m_get_uvTopRightP37UnityEngine_UnityEngine_CharacterInfo,__Z53UnityEngine_UnityEngine_CharacterInfo_m_get_uvTopLeftP37UnityEngine_UnityEngine_CharacterInfo
  ,__Z67UnityEngine_UnityEngine_Font_FontTextureRebuildCallback_m_EndInvokeP55UnityEngine_UnityEngine_Font_FontTextureRebuildCallbackP22mscorlib_System_Object,__Z61UnityEngine_UnityEngine_Canvas_WillRenderCanvases_m_EndInvokeP49UnityEngine_UnityEngine_Canvas_WillRenderCanvasesP22mscorlib_System_Object,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP32AssemblyU002DCSharp_BJController,__ZL77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ObjectP21mscorlib_System_ArrayP22mscorlib_System_Object,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP32AssemblyU002DCSharp_LevelBuilder,__ZL77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_StringP21mscorlib_System_ArrayP22mscorlib_System_String,__Z75mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_CharP21mscorlib_System_Arrayt,__ZL75mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_TypeP21mscorlib_System_ArrayP20mscorlib_System_Type,__ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP30AssemblyU002DCSharp_JSONObject,__Z160mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z76mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z95mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array40mscorlib_System_Collections_Generic_Link,__Z98mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array43mscorlib_System_Collections_DictionaryEntry,__Z160mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z168mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z90mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi,__Z131mscorlib_System_Array_m_InternalArray__ICollection_Add_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__Z159mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_FieldInfo,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP39mscorlib_System_Reflection_PropertyInfo,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__Z111mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi,__Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array32UnityEngine_UnityEngine_Keyframe,__Z116mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_CharacterController,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController
  ,__Z108mscorlib_System_Array_m_InternalArray__ICollection_Add_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Animation,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_WrapperlessIcall,__ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_ExecuteInEditMode,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_RequireComponent,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_MonoBehaviour,__Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array44mscorlib_System_Reflection_ParameterModifier,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_WritableAttribute,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_GUILayoutOption,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array47UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Camera,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_ParameterInfo,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_StateMachineBehaviour,__Z190mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__ZL84mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP29UnityEngine_UnityEngine_Event,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi,__Z106mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayh,__Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array32UnityEngine_UnityEngine_UIVertex,__Z89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UICharInfo,__Z89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UILineInfo,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Component,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GameObject,__ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Object,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL102mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute
  ,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__Z105mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_AssetBundle,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi,__Z84mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi,__Z86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_AddComponentMenu,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_ScriptableObject,__Z95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Renderer,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_ReflectionProbe,__ZL86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Texture,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Texture2D,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_RenderTexture,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GUIElement,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUILayer,__Z189mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUILayoutEntry,__Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi,__ZL86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_GUISkin,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUIStyle,__Z170mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi,__Z86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi,__Z88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_TextAsset
  ,__ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_SerializePrivateVariables,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_SerializeField,__ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Shader,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Material,__ZL79mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP24mscorlib_System_Byte_arr,__Z75mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ByteP21mscorlib_System_Arrayh,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Behaviour,__ZL86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Display,__Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_IntPtrP21mscorlib_System_Array22mscorlib_System_IntPtr,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Transform,__ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Motion,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Rigidbody,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Collider,__Z93mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_AudioClip,__Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi,__Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AnimationClip,__Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Animator,__ZL86mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Terrain,__Z89mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi,__Z95mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi,__ZL83mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP28UnityEngine_UnityEngine_Font,__ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Canvas,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Add_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Add_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP36System_Core_System_MonoTODOAttribute,__ZL80mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_AttributeP21mscorlib_System_ArrayP25mscorlib_System_Attribute,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP37mscorlib_System_SerializableAttribute
  ,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP39mscorlib_System_AttributeUsageAttribute,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_UInt32P21mscorlib_System_Arrayj,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP37mscorlib_System_CLSCompliantAttribute,__Z76mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_SByteP21mscorlib_System_Arraya,__Z76mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Int16P21mscorlib_System_Arrays,__Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_UInt16P21mscorlib_System_Arrayt,__Z78mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_BooleanP21mscorlib_System_Arrayb,__Z78mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_UIntPtrP21mscorlib_System_Array23mscorlib_System_UIntPtr,__ZL79mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DelegateP21mscorlib_System_ArrayP24mscorlib_System_Delegate,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodInfo,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP42mscorlib_System_Reflection_ConstructorInfo,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP35mscorlib_System_ParamArrayAttribute,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP52mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP33mscorlib_System_ObsoleteAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP51mscorlib_System_Runtime_InteropServices_InAttribute,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP53mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL123mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL125mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_DefaultMemberAttribute,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP33mscorlib_System_MonoTODOAttribute,__Z118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange
  ,__ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL102mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP47mscorlib_Mono_Globalization_Unicode_Contraction,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP45mscorlib_Mono_Globalization_Unicode_Level2Map,__Z118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array42mscorlib_System_Collections_Hashtable_Slot,__Z107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi,__Z117mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi,__Z124mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi,__ZL102mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP47mscorlib_System_Diagnostics_DebuggableAttribute,__Z117mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP38mscorlib_System_Diagnostics_StackFrame,__Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP38mscorlib_System_Globalization_Calendar,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi,__Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi,__Z107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP45mscorlib_System_Reflection_Emit_MethodBuilder,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL102mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP47mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP44mscorlib_System_Reflection_Emit_FieldBuilder,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodBase,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyConfigurationAttribute
  ,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL119mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyNameAttribute,__Z99mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyProductAttribute,__ZL104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTrademarkAttribute,__Z94mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi,__Z98mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi,__Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi,__Z101mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi,__Z96mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_SatelliteContractVersionAttribute,__Z118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi,__ZL127mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi,__ZL119mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute
  ,__Z103mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi,__Z111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi,__ZL128mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__Z113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi,__ZL123mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__Z111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__Z108mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__Z109mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayh,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP22mscorlib_System_Object,__Z107mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi,__Z126mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi,__Z122mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi,__Z119mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi,__Z115mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi,__Z105mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP50mscorlib_System_Security_UnverifiableCodeAttribute,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi,__Z87mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi,__Z85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi,__Z83mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi
  ,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi,__ZL85mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP30mscorlib_System_FlagsAttribute,__Z89mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi,__ZL79mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP24mscorlib_System_MonoType,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP38mscorlib_System_NonSerializedAttribute,__Z81mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP37mscorlib_System_ThreadStaticAttribute,__Z79mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi,__ZNSt3__111__stdoutbufIwE5imbueERKNS_6localeE,__ZNSt3__110__stdinbufIwE5imbueERKNS_6localeE,__ZNSt3__111__stdoutbufIcE5imbueERKNS_6localeE,__ZNSt3__110__stdinbufIcE5imbueERKNS_6localeE,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE,__ZNKSt3__110moneypunctIcLb0EE11do_groupingEv,__ZNKSt3__110moneypunctIcLb0EE14do_curr_symbolEv,__ZNKSt3__110moneypunctIcLb0EE16do_positive_signEv,__ZNKSt3__110moneypunctIcLb0EE16do_negative_signEv,__ZNKSt3__110moneypunctIcLb0EE13do_pos_formatEv,__ZNKSt3__110moneypunctIcLb0EE13do_neg_formatEv,__ZNKSt3__110moneypunctIcLb1EE11do_groupingEv,__ZNKSt3__110moneypunctIcLb1EE14do_curr_symbolEv,__ZNKSt3__110moneypunctIcLb1EE16do_positive_signEv,__ZNKSt3__110moneypunctIcLb1EE16do_negative_signEv,__ZNKSt3__110moneypunctIcLb1EE13do_pos_formatEv,__ZNKSt3__110moneypunctIcLb1EE13do_neg_formatEv,__ZNKSt3__110moneypunctIwLb0EE11do_groupingEv,__ZNKSt3__110moneypunctIwLb0EE14do_curr_symbolEv,__ZNKSt3__110moneypunctIwLb0EE16do_positive_signEv,__ZNKSt3__110moneypunctIwLb0EE16do_negative_signEv,__ZNKSt3__110moneypunctIwLb0EE13do_pos_formatEv
  ,__ZNKSt3__110moneypunctIwLb0EE13do_neg_formatEv,__ZNKSt3__110moneypunctIwLb1EE11do_groupingEv,__ZNKSt3__110moneypunctIwLb1EE14do_curr_symbolEv,__ZNKSt3__110moneypunctIwLb1EE16do_positive_signEv,__ZNKSt3__110moneypunctIwLb1EE16do_negative_signEv,__ZNKSt3__110moneypunctIwLb1EE13do_pos_formatEv,__ZNKSt3__110moneypunctIwLb1EE13do_neg_formatEv,__ZNKSt3__18messagesIcE8do_closeEi,__ZNKSt3__18messagesIwE8do_closeEi,__ZNKSt3__18numpunctIcE11do_groupingEv,__ZNKSt3__18numpunctIcE11do_truenameEv,__ZNKSt3__18numpunctIcE12do_falsenameEv,__ZNKSt3__18numpunctIwE11do_groupingEv,__ZNKSt3__18numpunctIwE11do_truenameEv,__ZNKSt3__18numpunctIwE12do_falsenameEv,_GC_default_warn_proc,__ZNKSt3__18ios_base6getlocEv,__ZNSt3__18ios_base5clearEj,__Z22il2cpp_gc_run_finalizePvS_,__ZNSt3__16vectorIP12Il2CppObjectN6il2cpp2gc9AllocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,__ZN6il2cpp5utils11StringUtils11Utf16ToUtf8EPKt,__ZNSt3__18ios_base4initEPv,__ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strERKNS_12basic_stringIcS2_S4_EE,__ZNKSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE3strEv,__ZN6il2cpp6icalls8mscorlib6System13GlobalizationL17construct_cultureEP17Il2CppCultureInfoPK16CultureInfoEntry,__ZN6il2cpp2os5MutexC2Eb,__ZN6il2cpp2vm6Thread8SetStateEP12Il2CppThreadNS0_11ThreadStateE,__ZN6il2cpp2vm6Thread8ClrStateEP12Il2CppThreadNS0_11ThreadStateE,__ZN6il2cpp2os13SemaphoreImplC2Ei,__ZN6il2cpp6icalls8mscorlib4Mono7Interop15ComInteropProxy8AddProxyE12Il2CppIntPtrP37mscorlib_Mono_Interop_ComInteropProxy
  ,__ZN6il2cpp6icalls8mscorlib6System11ArgIterator44IntGetNextArg_mscorlib_System_TypedReferenceEP27mscorlib_System_ArgIterator,__ZN6il2cpp6icalls8mscorlib6System7Decimal20decimalFloorAndTruncEP19il2cpp_decimal_repri,__ZN6il2cpp6icalls8mscorlib6System11Environment30InternalSetEnvironmentVariableEP12Il2CppStringS5_,__ZN6il2cpp6icalls8mscorlib6System2GC14RecordPressureEx,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo21construct_compareinfoEP41mscorlib_System_Globalization_CompareInfoP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System12MonoEnumInfo13get_enum_infoEP20Il2CppReflectionTypeP14Il2CppEnumInfo,__ZN6il2cpp6icalls8mscorlib6System8MonoType13type_from_objEPvP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly8FillNameEP35mscorlib_System_Reflection_AssemblyP39mscorlib_System_Reflection_AssemblyName,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly23InternalGetAssemblyNameEP12Il2CppStringP18Il2CppAssemblyName,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13DynamicMethod21create_dynamic_methodEP29Il2CppReflectionDynamicMethodS7_,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13DynamicMethod22destroy_dynamic_methodEP29Il2CppReflectionDynamicMethodS7_,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11EnumBuilder15setup_enum_typeEP20Il2CppReflectionTypeS7_,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder17set_wrappers_typeEP29Il2CppReflectionModuleBuilderP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder11WriteToFileEP29Il2CppReflectionModuleBuilder12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder20setup_internal_classEP27Il2CppReflectionTypeBuilderS7_,__ZN6il2cpp6icalls8mscorlib6System10Reflection13MonoEventInfo14get_event_infoEP36mscorlib_System_Reflection_MonoEventP40mscorlib_System_Reflection_MonoEventInfo,__ZN6il2cpp6icalls8mscorlib6System10Reflection14MonoMethodInfo15get_method_infoE12Il2CppIntPtrP16Il2CppMethodInfo,__ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers15InitializeArrayEP11Il2CppArray12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal16DestroyStructureE12Il2CppIntPtrP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting10Activation18ActivationServices21EnableProxyActivationEP20Il2CppReflectionTypeb,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread14Abort_internalEPvP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread8ClrStateEP12Il2CppThreadNS_2vm11ThreadStateE,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread19FreeLocalSlotValuesEib,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread23SetCachedCurrentCultureEP12Il2CppThreadP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread25SetCachedCurrentUICultureEPvS5_,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread16SetName_internalEP32mscorlib_System_Threading_ThreadP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread27SetSerializedCurrentCultureEPvP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread29SetSerializedCurrentUICultureEPvP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread8SetStateEP12Il2CppThreadNS_2vm11ThreadStateE,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread20Thread_free_internalEP12Il2CppThread12Il2CppIntPtr
  ,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread13VolatileWriteEPhh,__ZN6il2cpp6icalls8mscorlib6System9Threading10ThreadPool13GetMaxThreadsEPiS5_,__ZN6il2cpp6icalls8mscorlib6System9Threading10ThreadPool13GetMinThreadsEPiS5_,__ZN6il2cpp2vm8Profiler10AllocationEP12Il2CppObjectP8TypeInfo,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE21__push_back_slow_pathIKS6_EEvRT_,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS7_EE,_emscripten_longjmp__wrapper,_png_zfree,_png_free,_zcfree,__ZN5physx15solveExtContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx10solveExt1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx23solveConcludeExtContactERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx18solveConcludeExt1DERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx22solveExtContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx30solveConcludeExtContactCoulombERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__ZN5physx16solveExtFrictionERKNS_23PxcSolverConstraintDescERNS_16PxcSolverContextE,__Z30setPxVehicleGearsDataMNbRatiosPN5physx18PxVehicleGearsDataEj,__Z35setPxVehicleDifferential4WDataMTypePN5physx27PxVehicleDifferential4WDataENS0_4EnumE,__Z48setPxVehicleDifferentialNWData_DrivenWheelStatusPN5physx27PxVehicleDifferentialNWDataEj,__Z35setPxVehicleClutchDataMAccuracyModePN5physx19PxVehicleClutchDataENS_27PxVehicleClutchAccuracyMode4EnumE,__Z41setPxVehicleClutchDataMEstimateIterationsPN5physx19PxVehicleClutchDataEj,__Z25setPxVehicleTireDataMTypePN5physx17PxVehicleTireDataEj,__Z44getPxVehicleWheelsSimData_TireLoadFilterDataPKN5physx22PxVehicleWheelsSimDataE,__Z44setPxVehicleWheelsSimData_TireLoadFilterDataPN5physx22PxVehicleWheelsSimDataERKNS_27PxVehicleTireLoadFilterDataE,__Z49setPxVehicleWheelsDynData_TireForceShaderFunctionPN5physx22PxVehicleWheelsDynDataEPFvPKvffffffffffffRfS4_S4_S4_E,__Z31setPxVehicleDriveDynData_GearUpPN5physx21PxVehicleDriveDynDataEb,__Z33setPxVehicleDriveDynData_GearDownPN5physx21PxVehicleDriveDynDataEb,__Z37setPxVehicleDriveDynData_UseAutoGearsPN5physx21PxVehicleDriveDynDataEb,__Z36setPxVehicleDriveDynData_CurrentGearPN5physx21PxVehicleDriveDynDataEj
  ,__Z35setPxVehicleDriveDynData_TargetGearPN5physx21PxVehicleDriveDynDataEj,__Z35setPxVehicleDriveDynData_GearChangePN5physx21PxVehicleDriveDynDataEj,__Z37setPxVehicleDriveDynDataMUseAutoGearsPN5physx21PxVehicleDriveDynDataEb,__Z38setPxVehicleDriveDynDataMGearUpPressedPN5physx21PxVehicleDriveDynDataEb,__Z40setPxVehicleDriveDynDataMGearDownPressedPN5physx21PxVehicleDriveDynDataEb,__Z36setPxVehicleDriveDynDataMCurrentGearPN5physx21PxVehicleDriveDynDataEj,__Z35setPxVehicleDriveDynDataMTargetGearPN5physx21PxVehicleDriveDynDataEj,__Z35getPxVehicleDriveSimData_EngineDataPKN5physx21PxVehicleDriveSimDataE,__Z35setPxVehicleDriveSimData_EngineDataPN5physx21PxVehicleDriveSimDataERKNS_19PxVehicleEngineDataE,__Z34getPxVehicleDriveSimData_GearsDataPKN5physx21PxVehicleDriveSimDataE,__Z34setPxVehicleDriveSimData_GearsDataPN5physx21PxVehicleDriveSimDataERKNS_18PxVehicleGearsDataE,__Z35getPxVehicleDriveSimData_ClutchDataPKN5physx21PxVehicleDriveSimDataE,__Z35setPxVehicleDriveSimData_ClutchDataPN5physx21PxVehicleDriveSimDataERKNS_19PxVehicleClutchDataE,__Z36getPxVehicleDriveSimData_AutoBoxDataPKN5physx21PxVehicleDriveSimDataE,__Z36setPxVehicleDriveSimData_AutoBoxDataPN5physx21PxVehicleDriveSimDataERKNS_20PxVehicleAutoBoxDataE,__Z35getPxVehicleDriveSimData4W_DiffDataPKN5physx23PxVehicleDriveSimData4WE,__Z35setPxVehicleDriveSimData4W_DiffDataPN5physx23PxVehicleDriveSimData4WERKNS_27PxVehicleDifferential4WDataE,__Z48getPxVehicleDriveSimData4W_AckermannGeometryDataPKN5physx23PxVehicleDriveSimData4WE,__Z48setPxVehicleDriveSimData4W_AckermannGeometryDataPN5physx23PxVehicleDriveSimData4WERKNS_30PxVehicleAckermannGeometryDataE,__Z32getPxVehicleWheelsMWheelsSimDataPKN5physx15PxVehicleWheelsE,__Z32setPxVehicleWheelsMWheelsSimDataPN5physx15PxVehicleWheelsENS_22PxVehicleWheelsSimDataE,__Z32getPxVehicleWheelsMWheelsDynDataPKN5physx15PxVehicleWheelsE,__Z32setPxVehicleWheelsMWheelsDynDataPN5physx15PxVehicleWheelsENS_22PxVehicleWheelsDynDataE,__Z30getPxVehicleDriveMDriveDynDataPKN5physx14PxVehicleDriveE,__Z30setPxVehicleDriveMDriveDynDataPN5physx14PxVehicleDriveENS_21PxVehicleDriveDynDataE,__Z32getPxVehicleDrive4WMDriveSimDataPKN5physx16PxVehicleDrive4WE,__Z32setPxVehicleDrive4WMDriveSimDataPN5physx16PxVehicleDrive4WENS_23PxVehicleDriveSimData4WE,__Z32setPxVehicleDriveTank_DriveModelPN5physx18PxVehicleDriveTankENS_30PxVehicleDriveTankControlModel4EnumE,__Z34getPxVehicleDriveTankMDriveSimDataPKN5physx18PxVehicleDriveTankE,__Z34setPxVehicleDriveTankMDriveSimDataPN5physx18PxVehicleDriveTankENS_21PxVehicleDriveSimDataE
  ,__Z35getPxVehicleDriveSimDataNW_DiffDataPKN5physx23PxVehicleDriveSimDataNWE,__Z35setPxVehicleDriveSimDataNW_DiffDataPN5physx23PxVehicleDriveSimDataNWERKNS_27PxVehicleDifferentialNWDataE,__Z32getPxVehicleDriveNWMDriveSimDataPKN5physx16PxVehicleDriveNWE,__Z32setPxVehicleDriveNWMDriveSimDataPN5physx16PxVehicleDriveNWENS_23PxVehicleDriveSimDataNWE,__ZL15gHullPrefetchCBjPKN5physx6PxVec3E,__ZN5physx2GuL18gPCMHullPrefetchCBEjPKNS_6PxVec3E,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE7reserveEj,__Z21PrintShortMemoryStatsRNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEE10MemLabelId,_printf_console,__ZN17LowLevelAllocator4FreeEPvj,__ZN13MemoryManager12LowLevelFreeEPvj,__ZN28InstanceIdToObjectPtrHashMapC2Ei,__Z19free_alloc_internalPv10MemLabelId,__ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE6resizeEj,__ZN16MessageForwarder15AddBaseMessagesERKS_,__ZNSt3__16vectorI16MessageForwarder13stl_allocatorIS1_L18MemLabelIdentifier1ELi8EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS4_EE,__ZNSt3__16vectorIiNS_9allocatorIiEEEC2ERKS3_,__Z24CollectLevelGameManagersR13dynamic_arrayIiLj4EEb,__Z22DestroyObjectHighLevelP6Objectb,__ZL21ExtractGlobalManagersRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER10vector_mapIiiNS_4lessIiEENS3_INS_4pairIiiEEEEE,__Z22SetManagerPtrInContextiP6Object,__ZNSt3__16vectorI17MessageIdentifierNS_9allocatorIS1_EEE8__appendEj,__ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_,__ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_,__ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE,__ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE7reserveEj,__ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE8__appendEj,__ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE,__ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE7reserveEj,__ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE8__appendEj
  ,__ZN10MemoryPool10DeallocateEPv,__ZN28ApplyBuiltinInstanceProperty4InitER9GfxDevice,__ZNK16ReflectionProbes16GetDefaultSampleEv,__ZN15LightmapSTCache5ApplyER12BaseRenderer,__Z14SetSHConstantsR13BatchRendererRK19SphericalHarmonics3,__Z14SetReflectionsR13BatchRendererRK16ReflectionSample,__Z20SetupObjectLightmapsRK16LightmapSettingsRK15LightmapIndices,__ZN12LightManager17SetupVertexLightsEiPKPK11ActiveLight,__ZN19RenderBufferManager17ReleaseTempBufferEP13RenderTexture,__ZN9ShaderLab16FastPropertyName4InitEPKc,__ZN6Camera13ClearNoSkyboxEb,__ZNK9Transform11GetPositionEv,__ZNK6Camera18GetRenderRectangleEv,__Z18RestoreRenderStateR20CameraRenderOldStateRN9ShaderLab17ShaderPassContextE,__ZN7Texture19SetStoredColorSpaceE17TextureColorSpace,__Z13InitIndexListR9IndexListj,__ZNSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE7reserveEj,__ZNSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE8__appendEj,__ZNSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE7reserveEj,__ZNSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE8__appendEj,__ZN12BaseRendererC2E12RendererType,__ZL38FrustumAndOcculusionCullLocalLightsJobPvj,__ZNSt3__16vectorIP5Light13stl_allocatorIS2_L18MemLabelIdentifier44ELi16EEE21__push_back_slow_pathIKS2_EEvRT_,__ZN9Transform11SetRotationERK11Quaternionf,__ZN6Camera15SetOrthographicEb,__ZN9Transform11SetPositionERK8Vector3f,__ZN6Camera13SetClearFlagsEi,__ZN6Camera18SetBackgroundColorERK10ColorRGBAf,__ZN6Camera14SetCullingMaskEj,__ZNK15ReflectionProbe10GetTextureEv
  ,__ZN16ReflectionProbes11RenderProbeEP15ReflectionProbe,__ZN6Camera4CullER11CullResults,__ZL25CullLocalShadowCastersJobPvj,__Z31CullDirectionalShadowCastersJobPvj,__ZNSt3__16vectorI20ShadowCasterPartData13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_,__ZNSt3__16vectorI16ShadowCasterData13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_,__ZNK9Transform11GetRotationEv,__Z23ExtractProjectionPlanesRK10Matrix4x4fP5Plane,__Z16GetFrustumPointsRK10Matrix4x4fP8Vector3f,__ZNK10MinMaxAABB11GetVerticesEP8Vector3f,__ZNK6Camera22GetCameraToWorldMatrixEv,__ZNK9Transform28GetWorldToLocalMatrixNoScaleEv,__ZN13BatchRendererC2ER15RenderLoopStats,__Z14SetSHConstantsR28ApplyBuiltinInstancePropertyRK19SphericalHarmonics3,__ZNK6Camera11GetPositionEv,__ZN13dynamic_arrayIN15SkyboxGenerator19CubemapSkyboxVertexELj4EE9push_backERKS1_,__ZL24QueryPortalVisibilityJobPvj,__ZL21CullDynamicObjectsJobPvj,__ZN5Unity5Scene28SceneAfterCullingOutputReadyEPK9IndexListPK16RendererCullData,__ZN21IntermediateRenderers5ClearEj,__ZL25CullAllPerObjectLightsJobPvj,__ZN12WWWDelayCall8CallbackEP6ObjectPv,__Z17SetupObjectMatrixRK10Matrix4x4fi,__ZN12ImageFilters4BlitEP7TextureP13RenderTexture,__ZN7Texture13SetFilterModeEi,__ZNK4Mesh17ExtractColorArrayEP10ColorRGBAf,__ZN4Mesh27SwizzleVertexColorsIfNeededEb,__ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE21__push_back_slow_pathIKS1_EEvRT_,__Z4swapR10VertexDataS0_,__Z27ConvertSubMeshesToTrianglesRNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEEER13dynamic_arrayItLj2EE
  ,__ZN17RemapPPtrTransfer12PushMetaFlagE17TransferMetaFlags,__ZN10VertexData8TransferI17RemapPPtrTransferEEvRT_,__ZN10VertexData8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN14CompressedMesh8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN10VertexData8TransferI18StreamedBinaryReadILb1EEEEvRT_,__ZN14CompressedMesh8TransferI18StreamedBinaryReadILb1EEEEvRT_,__ZN14CompressedMesh10DecompressER4Mesh,__ZNSt3__16vectorIhNS_9allocatorIhEEE8__appendEj,__ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE8__appendEj,__ZNSt3__16vectorI17BlendShapeChannelNS_9allocatorIS1_EEE7reserveEj,__ZNSt3__16vectorI17BlendShapeChannelNS_9allocatorIS1_EEE8__appendEj,__ZN14ConstantString6assignERKS_,__ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE8__appendEj,__ZN10VertexData8TransferI18StreamedBinaryReadILb0EEEEvRT_,__ZN14CompressedMesh8TransferI18StreamedBinaryReadILb0EEEEvRT_,__ZNK14VertexDataInfo16GetStreamsLayoutEv,__ZN10VertexData8TransferI14SafeBinaryReadEEvRT_,__ZN14CompressedMesh8TransferI14SafeBinaryReadEEvRT_,__ZN13BoneInfluence8TransferI13ProxyTransferEEvRT_,__ZN10VertexData8TransferI13ProxyTransferEEvRT_,__ZN14CompressedMesh8TransferI13ProxyTransferEEvRT_,__ZN17BlendShapeChannel8TransferI13ProxyTransferEEvRT_,__ZN11ChannelInfo8TransferI13ProxyTransferEEvRT_,__ZN11ChannelInfo8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN9BillboardC2ERKS_,__ZN18AwakeFromLoadQueue7ReserveEj,__ZN12CachedWriter9InitWriteER15CacheWriterBase,__Z22DelayedDestroyCallbackP6ObjectPv,__ZNSt3__16vectorIiNS_9allocatorIiEEE8__appendEj,__ZNSt3__16vectorI5RectTIfENS_9allocatorIS2_EEE8__appendEj
  ,__ZNSt3__16vectorINS_4pairIiiEENS_9allocatorIS2_EEE8__appendEj,__ZNSt3__16vectorIP4NodeNS_9allocatorIS2_EEE8__appendEj,__ZN13DrawImmediateC2ER9GfxDevice,__Z26scripting_class_get_fieldsP14ScriptingClassRNSt3__16vectorIP14ScriptingField13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEE,__Z24scripting_cpp_string_forP15ScriptingString,__Z21PostprocessStacktracePKcRNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,__ZN17UniqueIDGenerator8RemoveIDEj,__ZN17UniqueIDGeneratorC2E10MemLabelId,__ZNSt3__16vectorI4PPtrI9Texture2DENS_9allocatorIS3_EEE8__appendEj,__Z9BlackCubePh8Vector3f,__Z9EmptyCubePh8Vector3f,_png_set_compression_level,_png_write_info,_png_write_row,_png_write_end,_png_destroy_write_struct,__ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,__ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE,__ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE7reserveEj,__ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE8__appendEj,__ZN15QualitySettings14QualitySetting8TransferI14SafeBinaryReadEEvRT_,__ZN15QualitySettings14QualitySetting8TransferI13ProxyTransferEEvRT_,__ZN15TextureSettings8TransferI13ProxyTransferEEvRT_,__ZN15TextureSettings8TransferI18StreamedBinaryReadILb0EEEEvRT_,__ZN15TextureSettings8TransferI18StreamedBinaryReadILb1EEEEvRT_,__ZN15TextureSettings8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__Z15reserve_trimmedINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEvRT_j,__ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE7reserveEj,__ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE8__appendEj,__ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE
  ,__ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE7reserveEj,__ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE8__appendEj,__ZN14SubstanceInputC2ERKS_,__ZNSt3__16vectorI4PPtrI17ProceduralTextureENS_9allocatorIS3_EEE8__appendEj,__ZN14SubstanceInput8TransferI13ProxyTransferEEvRT_,__ZN10InputEventaSERKS_,__ZNSt3__16vectorIN10GUIManager16GUIObjectWrapperENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,__ZNSt3__14listIN10GUIManager12SortedScriptE11memory_poolIS2_EE9push_backERKS2_,__ZN12GUIClipState10BeginOnGUIER10InputEvent,__ZN5IMGUI10EndWindowsER8GUIStateb,__ZN12GUIClipState8EndOnGUIER10InputEvent,__ZN16GUIKeyboardState16SaveFromGUIStateER8GUIState,__ZN15GUIEventManager18RemoveEventAtIndexEi,__ZNSt3__114__split_bufferIP10InputEventRNS_9allocatorIS2_EEE10push_frontERKS2_,__ZNSt3__16vectorINS0_IfNS_9allocatorIfEEEENS1_IS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN9InputAxisC2ERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN9InputAxisC2ERKS_,__ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_,__ZNSt3__16vectorIfNS_9allocatorIfEEEC2ERKS3_,__Z11KeyToStringi,__ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE7reserveEj,__ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE6resizeEj,__ZN9InputAxis8TransferI13ProxyTransferEEvRT_,__Z20GetPathNameExtensionRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z23DeletePathNameExtensionRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z24GetLastPathNameComponentRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZNSt3__16vectorI14ConstantStringNS_9allocatorIS1_EEE7reserveEj,__ZNSt3__16vectorI14ConstantStringNS_9allocatorIS1_EEE8__appendEj,__ZN4PPtrI6ObjectE8TransferI14SafeBinaryReadEEvRT_,__ZN15SerializeTraitsINSt3__14pairI8UnityStrN11AssetBundle9AssetInfoEEEE8TransferI14SafeBinaryReadEEvRS5_RT_
  ,__ZN15SerializeTraitsINSt3__14pairI8UnityStr4PPtrI6ObjectEEEE8TransferI14SafeBinaryReadEEvRS6_RT_,__ZN14CachingManager20DidUnloadAssetBundleERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZL20GetAssetBundlePrefixRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE8__appendEj,__ZN5Cache18WriteCacheInfoFileEb,__ZN15TextureSettings14GetAnisoLimitsERiS0_,__ZN15TextureSettings14SetAnisoLimitsEii,__ZN6Camera19SetProjectionMatrixERK10Matrix4x4f,__ZN13RenderManager13RenderCamerasEi,__ZN6Camera25SetNormalizedViewportRectERK5RectTIfE,__Z20AddRequiredClassIMPLii,__Z23AddConflictingClassIMPLii,__Z22FindGameObjectsWithTagjRNSt3__16vectorIPN5Unity10GameObjectENS_9allocatorIS3_EEEE,__ZN5Unity10GameObject22RemoveComponentAtIndexEi,__ZN13MonoBehaviour22GetScriptFullClassNameEv,__ZN9Scripting18RaiseMonoExceptionEPKcz,__Z20MarkInstanceIDAsRootiR21GarbageCollectorState,__Z16MarkDependenciesR27GarbageCollectorThreadStatej,__Z25BatchDeleteObjectInternalPKii,__ZN10MeshFilter13SetSharedMeshE4PPtrI4MeshE,__Z12CollectPPtrsR6ObjectPNSt3__13setIiNS1_4lessIiEENS1_9allocatorIiEEEE,__Z31CompletePreloadManagerLoadLevelRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER18AwakeFromLoadQueue,__Z21SendMessageToEveryone17MessageIdentifier11MessageData,__Z26PlayerLoadSettingsAndInputRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z24PlayerLoadGlobalManagersPKc,__ZN19RenderBufferManager14GarbageCollectEi,__ZN19ScriptingInvocationC2E21ScriptingMethodIl2Cpp,__ZN18ScriptingArguments6AddIntEi,__ZN19SkinnedMeshRenderer22UpdateAllSkinnedMeshesENS_10UpdateTypeEP13dynamic_arrayIPS_Lj4EE,__ZN13MemoryManager16FrameMaintenanceEb
  ,__Z48AddToTimeSliceAwakeFromLoadQueueProgressCallbackR6ObjectPv,__ZN17PersistentManager34ExtractTimeSliceAwakeFromLoadQueueER27TimeSliceAwakeFromLoadQueue,__ZN18AwakeFromLoadQueueC2E10MemLabelId,__ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEE8__appendEj,__ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEE7reserveEj,__ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEE8__appendEj,__ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEEC2ERKS6_,__ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb1EEEEvRT_,__ZN4PPtrI6ObjectE8TransferI18StreamedBinaryReadILb0EEEEvRT_,__ZN15SerializeTraitsINSt3__14pairI8UnityStr4PPtrI6ObjectEEEE8TransferI13ProxyTransferEEvRS6_RT_,__ZN15ResourceManager10Dependency8TransferI13ProxyTransferEEvRT_,__ZL12InvokeMethodI19StreamedBinaryWriteILb0EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN32SerializationCommandQueueBuilder3AddERK20SerializationCommand,__ZL12InvokeMethodI18StreamedBinaryReadILb0EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL12InvokeMethodI17RemapPPtrTransferEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL12InvokeMethodI13ProxyTransferEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL12InvokeMethodI14SafeBinaryReadEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL12InvokeMethodI18StreamedBinaryReadILb1EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIy18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinI8Vector2f18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3218StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z30TransferField_LinearCollectionI18StreamedBinaryReadILb1EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIy18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinI11Quaternionf18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3218StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb1EE8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL22Transfer_ManagedObjectI18StreamedBinaryReadILb1EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN32SerializationCommandQueueBuilder3AddERK13dynamic_arrayI20SerializationCommandLj4EE,__ZN8GUIStyle8TransferI18StreamedBinaryReadILb1EEEEvRT_,__ZN25ScriptingInvocationNoArgsC2E21ScriptingMethodIl2Cpp,__ZN11GradientNEW8TransferI18StreamedBinaryReadILb1EEEEvRT_,__ZN17AnimationCurveTplIfE8TransferI18StreamedBinaryReadILb1EEEEvRT_,__ZL22Transfer_ManagedObjectI18StreamedBinaryReadILb1EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZNSt3__16vectorI8MonoPPtr13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE7reserveEj,__ZNSt3__16vectorI8MonoPPtr13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE7reserveEj,__ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZN8GUIStyleC2ERKS_,__ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE7reserveEj,__ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI11GradientNEW13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE7reserveEj,__ZNSt3__16vectorI11GradientNEW13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE7reserveEj,__ZNSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI8BitField13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj
  ,__ZNSt3__16vectorI11ColorRGBA3213stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI10ColorRGBAf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI4AABB13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI10Matrix4x4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI11Quaternionf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI5RectTIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI8Vector4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI8Vector2f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorI8Vector3f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE7reserveEj,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE8__appendEj,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE26__swap_out_circular_bufferERNS_14__split_bufferIS7_RS8_EE,__Z15Transfer_StringI14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinIy14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3214SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI14SafeBinaryRead17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI14SafeBinaryRead11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI14SafeBinaryRead10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI14SafeBinaryRead8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z30TransferField_LinearCollectionI14SafeBinaryReadEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIy14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinI8Vector3f14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3214SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI14SafeBinaryRead17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI14SafeBinaryRead11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI14SafeBinaryRead10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI14SafeBinaryRead8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL22Transfer_ManagedObjectI14SafeBinaryReadLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN8GUIStyle8TransferI14SafeBinaryReadEEvRT_,__ZN11GradientNEW8TransferI14SafeBinaryReadEEvRT_,__ZN17AnimationCurveTplIfE8TransferI14SafeBinaryReadEEvRT_,__ZL22Transfer_ManagedObjectI14SafeBinaryReadLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIy13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinId13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3213ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI13ProxyTransfer17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI13ProxyTransfer11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI13ProxyTransfer10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI13ProxyTransfer8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z30TransferField_LinearCollectionI13ProxyTransferEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIy13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinI8Vector4f13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3213ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI13ProxyTransfer17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI13ProxyTransfer11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI13ProxyTransfer10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI13ProxyTransfer8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL22Transfer_ManagedObjectI13ProxyTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN17AnimationCurveTplIfE8TransferI13ProxyTransferEEvRT_,__ZN11GradientNEW8TransferI13ProxyTransferEEvRT_,__ZN8GUIStyle8TransferI13ProxyTransferEEvRT_,__ZL22Transfer_ManagedObjectI13ProxyTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN10RectOffset8TransferI13ProxyTransferEEvRT_,__ZN13ProxyTransfer10SetVersionEi,__ZN10ColorRGBAf8TransferI13ProxyTransferEEvRT_,__ZN10Matrix4x4f8TransferI13ProxyTransferEEvRT_,__ZN11Quaternionf8TransferI13ProxyTransferEEvRT_,__ZN5RectTIfE8TransferI13ProxyTransferEEvRT_,__ZN8Vector4f8TransferI13ProxyTransferEEvRT_,__Z15Transfer_StringI17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinIi17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIy17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3217RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z30TransferField_LinearCollectionI17RemapPPtrTransferEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinIy17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3217RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI17RemapPPtrTransfer8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL22Transfer_ManagedObjectI17RemapPPtrTransferLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN8GUIStyle8TransferI17RemapPPtrTransferEEvRT_,__ZL22Transfer_ManagedObjectI17RemapPPtrTransferLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN12NativeBufferI27Converter_UnityEngineObjectE15SetupForWritingER9ArrayInfo,__ZN12NativeBufferI27Converter_SimpleNativeClassI8GUIStyleEE15SetupForWritingER9ArrayInfo,__ZN12NativeBufferI27Converter_SimpleNativeClassI11GradientNEWEE15SetupForWritingER9ArrayInfo,__ZN12NativeBufferI27Converter_SimpleNativeClassI17AnimationCurveTplIfEEE15SetupForWritingER9ArrayInfo,__Z15Transfer_StringI18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinIi18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIy18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3218StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z30TransferField_LinearCollectionI18StreamedBinaryReadILb0EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinIy18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3218StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI18StreamedBinaryReadILb0EE8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL22Transfer_ManagedObjectI18StreamedBinaryReadILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN8GUIStyle8TransferI18StreamedBinaryReadILb0EEEEvRT_,__ZN11GradientNEW8TransferI18StreamedBinaryReadILb0EEEEvRT_,__ZL22Transfer_ManagedObjectI18StreamedBinaryReadILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinIy19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector3f19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3219StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE17AnimationCurveTplIfELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE11GradientNEWLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE10RectOffsetLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE8GUIStyleLb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z30TransferField_LinearCollectionI19StreamedBinaryWriteILb0EEEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z15Transfer_StringI19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIt19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIa19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIh19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z22Transfer_Builtin_AlignIs19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIi19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIj19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIx19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIy19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinIf19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinId19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo
  ,__Z16Transfer_BuiltinI8Vector3f19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector2f19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8Vector4f19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI5RectTIfE19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11Quaternionf19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10Matrix4x4f19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI4AABB19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI10ColorRGBAf19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI11ColorRGBA3219StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z16Transfer_BuiltinI8BitField19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE17AnimationCurveTplIfELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE11GradientNEWLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE10RectOffsetLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL26Transfer_SimpleNativeClassI19StreamedBinaryWriteILb0EE8GUIStyleLb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__Z26Transfer_UnityEngineObjectI19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZL22Transfer_ManagedObjectI19StreamedBinaryWriteILb0EELb0EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN8GUIStyle8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN11GradientNEW8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN17AnimationCurveTplIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZL22Transfer_ManagedObjectI19StreamedBinaryWriteILb0EELb1EEvRK29SerializationCommandArgumentsR31RuntimeSerializationCommandInfo,__ZN4PPtrI6ObjectE8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN10RectOffset8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN12NativeBufferI19Converter_PrimitiveI10ColorRGBAfEE15SetupForWritingER9ArrayInfo,__ZN10ColorRGBAf8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN4AABB8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN10Matrix4x4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN11Quaternionf8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN5RectTIfE8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN8Vector4f8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZN12NativeBufferI16Converter_StringE15SetupForWritingER9ArrayInfo
  ,__ZN9Coroutine17ContinueCoroutineEP6ObjectPv,__ZN13MonoBehaviour16DelayedStartCallEP6ObjectPv,__Z18BuildScriptClassIdRKP14ScriptingClass,__Z27scripting_class_get_methodsP14ScriptingClassRNSt3__16vectorI21ScriptingMethodIl2Cpp13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEE,__Z30scripting_stack_trace_info_forP18ScriptingExceptionR14StackTraceInfo,__ZNSt3__16vectorI17TransferMetaFlags13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS1_EEvRT_,__ZNSt3__114__split_bufferIPN14SafeBinaryRead17ArrayPositionInfoERNS_9allocatorIS3_EEE10push_frontERKS3_,__ZNSt3__114__split_bufferIPN14SafeBinaryRead11StackedInfoERNS_9allocatorIS3_EEE10push_frontERKS3_,__ZNK14SerializedFile13GetAllFileIDsER13dynamic_arrayIxLj8EE,__ZN14SerializedFile14AddExternalRefERK14FileIdentifier,__ZN17PersistentManager25ExtractAwakeFromLoadQueueER18AwakeFromLoadQueue,__ZN6Object22CheckInstanceIDsLoadedEPii,__ZNSt3__16vectorINS_4pairIiiEE13stl_allocatorIS2_L18MemLabelIdentifier30ELi16EEEC2ERKS6_,__ZNSt3__16vectorI10vector_mapIiiNS_4lessIiEE13stl_allocatorINS_4pairIiiEEL18MemLabelIdentifier30ELi16EEES4_IS9_LS7_30ELi16EEE21__push_back_slow_pathIKS9_EEvRT_,__ZNSt3__14pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES6_EC2ERKS7_,__ZNSt3__16vectorINS_4pairIxN14SerializedFile10ObjectInfoEEENS_9allocatorIS4_EEE21__push_back_slow_pathIKS4_EEvRT_,__ZN12CachedReader18InitResourceImagesER18ResourceImageGroup,__Z18PathToAbsolutePathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZN15FileSystemEntryC2EPKc,__ZNSt3__114__split_bufferIPN9BlobWrite11TypeContextERNS_9allocatorIS3_EEE10push_frontERKS3_,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram13BufferBindingENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram13BufferBindingENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15VectorParameterENS_9allocatorIS3_EEE7reserveEj,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS_9allocatorIS3_EEE7reserveEj,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram16TextureParameterENS_9allocatorIS3_EEE7reserveEj,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15VectorParameterENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram16TextureParameterENS_9allocatorIS3_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE,__ZNSt3__16vectorIN5Unity8Material15CachedSubShaderENS_9allocatorIS3_EEE8__appendEj,__ZN9ShaderLab13PropertySheetC2ERKS0_
  ,__ZN8keywords20KeywordNamesToStringERKNSt3__16vectorI8UnityStrNS0_9allocatorIS2_EEEERS2_,__ZN9ShaderLab9SubShader17InsertDefaultPassEPNS_4PassE,__ZNSt3__16vectorI4PPtrI6ShaderENS_9allocatorIS3_EEE8__appendEj,__ZNSt3__16vectorI4PPtrI6ShaderENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb1EEEEvRT_,__ZN4PPtrI6ShaderE8TransferI18StreamedBinaryReadILb0EEEEvRT_,__ZN15SerializeTraitsINSt3__14pairI4PPtrI6ShaderE8UnityStrEEE8TransferI14SafeBinaryReadEEvRS6_RT_,__ZN15SerializeTraitsINSt3__14pairI4PPtrI6ShaderE8UnityStrEEE8TransferI13ProxyTransferEEvRS6_RT_,__ZN8keywords24KeywordSetToKeywordNamesERK16ShaderKeywordSetRNSt3__16vectorINS3_12basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEENS8_ISA_EEEE,__ZL26KeywordSetToStringDontSortRKNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEER8UnityStr,__ZN15FileSystemEntry3SetEPKc,__ZN16MemoryFileSystemC2EPKc,__ZNK10FileSystem16CurrentDirectoryEv,__Z27DeleteLastPathNameComponentRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z19StandardizePathNameRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZNK10FileSystem16LastErrorMessageEv,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE7reserveEj,_JS_Log_Dump__wrapper,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEj,__ZN9ShaderLab6TexEnvC2ERKS0_,__ZNSt3__16vectorINS_4pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EENS5_IS8_EEE21__push_back_slow_pathIKS8_EEvRT_,__ZN9ShaderLab17ParserShaderStateC2ERKS0_,__Z7ToUpperINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_,__ZNSt3__114__split_bufferIPPN9ShaderLab17ParserShaderStateERNS_9allocatorIS4_EEE10push_frontERKS4_,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEEC2ERKS8_,__ZN12ShaderErrors11ShaderErrorC2ERKS0_,__ZN9ShaderLab6TexEnvC2ERKNS_21ParserTexturePropertyE,__ZN13dynamic_arrayIPN9ShaderLab4PassELj4EE9push_backERKS2_,__ZN9ShaderLab4PassC2ENS0_8PassTypeE,__ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE
  ,__Z10SetupLexerPKcj,__ZN9ShaderLab16ParserSubProgram14ConstantBufferC2ERKS1_,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram14ConstantBufferENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15VectorParameterENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram16TextureParameterENS_9allocatorIS3_EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN9ShaderLab14ParserPropertyC2ERKS0_,__ZNSt3__16vectorIN9ShaderLab14ParserPropertyENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15MatrixParameterENS_9allocatorIS3_EEEC2ERKS6_,__ZNSt3__16vectorIN9ShaderLab16ParserSubProgram15VectorParameterENS_9allocatorIS3_EEEC2ERKS6_,__ZN9ShaderLab9SubShaderC2ERKS0_,__ZN11CustomArrayC2Em,__ZNK11ICallStringcvNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEEv,__Z7ToLowerINSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEET_RKS7_,__ZN15ResourceManager19PreloadDependenciesEi,__Z46GUILayoutUtility_CUSTOM_Internal_GetWindowRecti,__Z57GUILayoutUtility_CUSTOM_INTERNAL_CALL_Internal_MoveWindowiRK5RectTIfE,__Z43GUIStyleState_CUSTOM_INTERNAL_set_textColorP15ScriptingObjectRK10ColorRGBAf,__Z30RectOffset_Set_Custom_PropLeftP15ScriptingObjecti,__Z31RectOffset_Set_Custom_PropRightP15ScriptingObjecti,__Z29RectOffset_Set_Custom_PropTopP15ScriptingObjecti,__Z32RectOffset_Set_Custom_PropBottomP15ScriptingObjecti,__Z28GUIStyle_Set_Custom_PropNameP15ScriptingObjectP15ScriptingString,__Z36GUIStyle_Set_Custom_PropStretchWidthP15ScriptingObjecth,__Z37GUIStyle_Set_Custom_PropStretchHeightP15ScriptingObjecth,__Z38Event_CUSTOM_Internal_GetMousePositionP15ScriptingObjectP13Vector2fIcall,__Z39Quaternion_CUSTOM_INTERNAL_CALL_InverseRK11Quaternionf,__Z51Quaternion_CUSTOM_INTERNAL_CALL_Internal_ToEulerRadRK11Quaternionf,__Z53Quaternion_CUSTOM_INTERNAL_CALL_Internal_FromEulerRadRK8Vector3f,__Z38Matrix4x4_CUSTOM_INTERNAL_CALL_InverseRK10Matrix4x4f
  ,__Z40Matrix4x4_CUSTOM_INTERNAL_CALL_TransposeRK10Matrix4x4f,__ZN5Unity8Material13EnableKeywordERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,__ZN5Unity8Material14DisableKeywordERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,__Z35Material_Set_Custom_PropRenderQueueP15ScriptingObjecti,__Z29Material_CUSTOM_EnableKeywordP15ScriptingObjectP15ScriptingString,__Z30Material_CUSTOM_DisableKeywordP15ScriptingObjectP15ScriptingString,__Z32Behaviour_Set_Custom_PropEnabledP15ScriptingObjecth,__Z36Camera_CUSTOM_INTERNAL_get_pixelRectP15ScriptingObjectR5RectTIfE,__Z26Object_Set_Custom_PropNameP15ScriptingObjectP15ScriptingString,__Z29GameObject_Set_Custom_PropTagP15ScriptingObjectP15ScriptingString,__Z38Transform_CUSTOM_INTERNAL_get_positionP15ScriptingObjectR8Vector3f,__Z38Transform_CUSTOM_INTERNAL_set_positionP15ScriptingObjectRK8Vector3f,__Z46Transform_CUSTOM_INTERNAL_get_localEulerAnglesP15ScriptingObjectR8Vector3f,__Z46Transform_CUSTOM_INTERNAL_set_localEulerAnglesP15ScriptingObjectRK8Vector3f,__Z38Transform_CUSTOM_INTERNAL_get_rotationP15ScriptingObjectR11Quaternionf,__Z38Transform_CUSTOM_INTERNAL_set_rotationP15ScriptingObjectRK11Quaternionf,__Z43Transform_CUSTOM_INTERNAL_get_localRotationP15ScriptingObjectR11Quaternionf,__Z43Transform_CUSTOM_INTERNAL_set_localRotationP15ScriptingObjectRK11Quaternionf,__Z40Transform_CUSTOM_INTERNAL_set_localScaleP15ScriptingObjectRK8Vector3f,__Z48Transform_CUSTOM_INTERNAL_get_localToWorldMatrixP15ScriptingObjectR10Matrix4x4f,__ZNK9Transform13GetWorldScaleEv,__ZN10Matrix4x4fC2ERK10Matrix3x3f,__ZNSt3__16vectorI9CollisionNS_9allocatorIS1_EEE21__push_back_slow_pathIKS1_EEvRT_,__ZN14PhysicsManager11SweepShapes4InitEj,__ZNSt3__16vectorIN5physx10PxSweepHitENS_9allocatorIS2_EEE8__appendEj,__ZNSt3__16vectorIN5physx12PxRaycastHitENS_9allocatorIS2_EEE8__appendEj,__ZNSt3__16vectorIN5physx12PxOverlapHitENS_9allocatorIS2_EEE8__appendEj,__ZNSt3__16vectorIjNS_9allocatorIjEEE8__appendEj,__ZNSt3__16vectorI9CollisionNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EE,__ZN8Collider16RecreateColliderEPK9Rigidbody
  ,__ZN13WheelCollider16RecreateColliderEPK9Rigidbody,__Z39Rigidbody_Set_Custom_PropFreezeRotationP15ScriptingObjecth,__Z31Collider_Set_Custom_PropEnabledP15ScriptingObjecth,__Z35Collider_CUSTOM_INTERNAL_get_boundsP15ScriptingObjectR4AABB,__Z48CharacterController_CUSTOM_INTERNAL_get_velocityP15ScriptingObjectR8Vector3f,__Z46CharacterController_CUSTOM_INTERNAL_get_centerP15ScriptingObjectR8Vector3f,__ZN18ScriptingArguments8AddArrayEP14ScriptingArray,__ZN11SoundHandleaSERKS_,__ZN9AudioClip11CreateSoundEv,__ZN30AudioEffectInternalDescriptionC2EP26UnityAudioEffectDefinition,__Z20GetFirstValueForARGVRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZN12AudioManager17RemoveAudioSourceEP11AudioSource,__ZN11SoundHandleC2ERKS_,__ZN20SoundChannelInstance14SetFMODChannelEPN4FMOD7ChannelE,__ZN11AudioSource4StopEb,__ZN11AudioSource25UnbindFromChannelInstanceEP20SoundChannelInstance,__ZN17AudioCustomFilterC2EP13MonoBehaviour,__ZN4FMOD7SystemIC2Ei,__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEE7SetSizeEi,__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEE7SetSizeEi,__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEE7SetSizeEi,__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEE7SetSizeEi,__ZN10ObjectPoolIN4FMOD6ReverbENS0_7ReverbIEE7SetSizeEi,__ZN4FMOD8ChannelIC2EPNS_7SystemIE,__ZN4FMOD13ChannelGroupIC2EPNS_7SystemIE,__ZN4FMOD6SoundIC2EPNS_7SystemIE,__ZN4FMOD4DSPIC2EPNS_7SystemIE,__ZN4FMOD7ReverbIC2EPNS_7SystemIE,__Z27InsertAnimationClipCurveIDsR14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS0_EE13stl_allocatorINS2_4pairIKS0_jEEL18MemLabelIdentifier90ELi16EEER13AnimationClip,__ZN15AnimationBinder19RemoveUnboundCurvesER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEER13dynamic_arrayI20BoundCurveDeprecatedLj4EE
  ,__ZN14AnimationState14AllocateCurvesEi,__ZN9Animation22UpdateQueuedAnimationsERb,__ZNSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEE7reserveEj,__ZNSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEE8__appendEj,__ZNK16TypeTreeIterator8ChildrenEv,__ZNK16TypeTreeIterator4NextEv,__ZN13dynamic_arrayINSt3__14pairIN11UnityEngine9Animation14GenericBindingEPNS3_10BoundIndexEEELj4EE9push_backERKS7_,__ZN13dynamic_arrayIN11UnityEngine9Animation14GenericBindingELj4EE9push_backERKS2_,__ZN13AnimationClip15QuaternionCurveC2ERKS0_,__ZN24CompressedAnimationCurveC2ERKS_,__ZN13AnimationClip14CompressCurvesERNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEEE,__ZN24CompressedAnimationCurve8TransferI19StreamedBinaryWriteILb0EEEEvRT_,__ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6resizeEj,__ZN24CompressedAnimationCurve19DecompressQuatCurveERN13AnimationClip15QuaternionCurveE,__ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE7reserveEj,__ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE6resizeEj,__ZN14AnimationEventC1ERKS_,__ZNSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE7reserveEj,__ZNSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj,__ZN13AnimationClip9PPtrCurveC2ERKS0_,__ZNSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE7reserveEj,__ZNSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE8__appendEj,__ZN13AnimationClip10FloatCurveC2ERKS0_,__ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE7reserveEj,__ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6resizeEj,__ZN13AnimationClip12Vector3CurveC2ERKS0_,__ZNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE7reserveEj,__ZNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE8__appendEj,__ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE7reserveEj,__ZN13AnimationClip10FloatCurve8TransferI13ProxyTransferEEvRT_
  ,__ZN13AnimationClip9PPtrCurve8TransferI13ProxyTransferEEvRT_,__ZN17AnimationCurveTplI11QuaternionfE8TransferI13ProxyTransferEEvRT_,__ZN24CompressedAnimationCurve8TransferI13ProxyTransferEEvRT_,__ZN14AnimationEvent8TransferI13ProxyTransferEEvRT_,__ZN14AnimationState22DidModifyAnimationClipEP13AnimationClipR4ListI8ListNodeIS_EE,__ZN14AvatarPlaybackC2E10MemLabelId,__ZN27StateMachineBehaviourPlayerC2EP28IStateMachineBehaviourSender,__ZN11UnityEngine9Animation29SetGenericFloatPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayE,__ZN11UnityEngine9Animation28SetGenericPPtrPropertyValuesERKNS0_30AnimatorGenericBindingConstantERKN7mecanim10ValueArrayE,__ZN7mecanim9animation19DestroyAvatarMemoryEPNS0_12AvatarMemoryERNS_6memory9AllocatorE,__ZN8UserList7ReserveEj,__ZN8UserList7AddUserERS_,__ZNSt3__16vectorI25StateMachineBehaviourInfoNS_9allocatorIS1_EEE8__appendEj,__Z18BuildTransformListR9TransformR13dynamic_arrayIPS_Lj4EE,__Z26AnimationCurve_CUSTOM_InitP15ScriptingObjectP14ScriptingArray,__Z38AnimationState_Set_Custom_PropWrapModeP15ScriptingObjecti,__ZN14DetailDatabase22RefreshPrototypesStep1EPP9Texture2D,__ZN7Texture11SetWrapModeEi,__Z18UploadTextureAtlasP9Texture2Db,__ZN7Texture33SetStoredColorSpaceNoDirtyNoApplyE17TextureColorSpace,__ZNK4Mesh12GetTrianglesERNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEE,__ZN4Mesh5ClearEb,__ZN4Mesh9SetBoundsERK4AABB,__ZN6Camera16SetTargetTextureEP13RenderTexture,__ZN15TerrainRenderer24ReclaimPatchVertexBufferEP12VertexBuffer,__ZN14TerrainManager23AfterCullingOutputReadyEPK9IndexListPK16RendererCullData,__ZNK14SplatMaterials12GetMaterialsER13dynamic_arrayIPN5Unity8MaterialELj4EE,__ZN12TreeRenderer16UpdateProbeIndexEi,__ZNSt3__16vectorIP7Terrain13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE21__push_back_slow_pathIKS2_EEvRT_,__ZNK12MeshRenderer13GetSharedMeshEv
  ,__ZN15LODGroupManagerC2E10MemLabelId,__ZNK9Heightmap7GetSizeEv,__ZN21ImposterRenderTextureC2ERK12TreeDatabase,__ZNSt3__14listIN12TreeRenderer18BillboardRenderersE13stl_allocatorIS2_L18MemLabelIdentifier55ELi16EEE9push_backERKS2_,__ZN21MaterialPropertyBlockC2ERKS_,__ZNSt3__16vectorIN12TreeRenderer19LODTreeInstanceDataE13stl_allocatorIS2_L18MemLabelIdentifier55ELi16EEE21__push_back_slow_pathIKS2_EEvRT_,__ZN20SpeedTreeWindManager21PrepareWindPropertiesER21MaterialPropertyBlockb,__ZN12TreeRenderer17UpdateShaderPropsERK6Camera,__Z17EulerToQuaternionRK8Vector3f,__ZN26LegacyTreeInstanceRenderer6UpdateEb,__ZNSt3__16vectorIN12TreeRenderer19LODTreeInstanceDataE13stl_allocatorIS2_L18MemLabelIdentifier55ELi16EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS5_EE,__ZNSt3__16vectorINS_4pairIiN12TreeRenderer15RendererLODInfoEEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEEC2ERKS8_,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS4_EE,__ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE8__appendEj,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE21__push_back_slow_pathIKS1_EEvRT_,__ZNSt3__16vectorIN20TextRenderingPrivate4Font7IntRectE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN20TextRenderingPrivate11FormatStack10PushFormatERNS_16TextFormatChangeE,__ZNSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEE7reserveEj,__ZNSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEE8__appendEj,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE7reserveEj,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE8__appendEj,__ZNSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEE8__appendEj,__ZNSt3__16vectorINS_4pairIifEE13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEE8__appendEj,__ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE8__appendEj,__ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE21__push_back_slow_pathIKS3_EEvRT_,__ZN20TextRenderingPrivate4Font13CharacterInfo8TransferI13ProxyTransferEEvRT_,__Z14ParseHTMLColorNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZN11UTF16StringC2ERKS_,__ZN20TextRenderingPrivate22ScriptingTextGenerator9InitVertsEi,__ZN20TextRenderingPrivate19NativeTextGenerator9GetBoundsEv
  ,__ZN20TextRenderingPrivate19NativeTextGenerator11SetMeshDataERNS_17TextMeshGeneratorE,_ft_bitmap_glyph_bbox,_ft_outline_glyph_bbox,_ps_hints_t1reset,__Z40TextGenerator_Get_Custom_PropRectExtentsP15ScriptingObject,__Z40TextGenerator_CUSTOM_GetVerticesInternalP15ScriptingObjectS0_,__Z42TextGenerator_CUSTOM_GetCharactersInternalP15ScriptingObjectS0_,__Z37TextGenerator_CUSTOM_GetLinesInternalP15ScriptingObjectS0_,__ZN4Mesh15SetSubMeshCountEj,__ZN4Mesh24UpdateSubMeshVertexRangeEi,__ZN2UI14SyncInstuctionEPNS_6CanvasERNS_13UIInstructionE,__ZL26BlitIntegerToFloatInternalRN6prcore7SurfaceERKS0_,__ZL17BlitBilinearFloatIffEvRN6prcore7SurfaceERKS1_,__ZL26BlitFloatToIntegerInternalRN6prcore7SurfaceERKS0_,__ZL18BlitIntegerToFloatI4halfEvRN6prcore7SurfaceERKS2_,_JS_Cursor_SetImage__wrapper,__ZN7Cursors17InitializeCursorsEP9Texture2D8Vector2f,__ZN15GUIEventManager10QueueEventERK10InputEvent,__Z20InitGUIInputEventSDLR10InputEventRKN3SDL9SDL_EventE,_glAttachShader__wrapper,_glBindBuffer__wrapper,_glBindFramebuffer__wrapper,_glBindRenderbuffer__wrapper,_glBindTexture__wrapper,_glBlendEquationSeparate__wrapper,_glDeleteBuffers__wrapper,_glDeleteFramebuffers__wrapper,_glDeleteRenderbuffers__wrapper,_glDeleteTextures__wrapper,_glGenBuffers__wrapper,_glGenFramebuffers__wrapper,_glGenRenderbuffers__wrapper,_glGenTextures__wrapper,_glGetIntegerv__wrapper,_glPixelStorei__wrapper,_glUniform1i__wrapper,__ZL20glBindBufferOverridejj,__ZL23glDeleteBuffersOverrideiPKj,__ZN4gles14InitBackbufferEPP17RenderSurfaceBaseS2_,__ZN4gles14UseGLSLProgramER15DeviceStateGLESj,__ZNSt3__16vectorIN20GpuProgramParameters14ConstantBufferENS_9allocatorIS2_EEE21__push_back_slow_pathIKS2_EEvRT_,__Z19DebugTextLineByLinePKci,__ZN23InterfaceActionInvoker06InvokeEP10MethodInfoPv,__Z21ArrayElementTypeCheckP21mscorlib_System_ArrayPv,__Z154mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEnumerable_1_T_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__Z84mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_AddRange_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZN18VirtActionInvoker06InvokeEP10MethodInfoPv,__Z92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__Z130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z91System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m__ctor_gsharedP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__Z79System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_Push_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZN16StackTraceSentryC2EP10MethodInfo,__Z201mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_Generic_IEqualityComparer_1_TKey_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__ZN12_GLOBAL__N_114__libcpp_nmstrC2EPKc,__ZNSt13runtime_errorC2ERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZNSt13runtime_errorC2EPKc,__ZNSt11logic_errorC2EPKc,__ZNSt3__18ios_base16__call_callbacksENS0_5eventE,__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc
  ,__ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw,__ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEj,__ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEEC2Ej,__ZNSt3__16locale5__imp7installINS_7collateIcEEEEvPT_,__ZNSt3__16locale5__imp7installINS_7collateIwEEEEvPT_,__ZNSt3__16locale5__imp7installINS_5ctypeIcEEEEvPT_,__ZNSt3__16locale5__imp7installINS_5ctypeIwEEEEvPT_,__ZNSt3__16locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_,__ZNSt3__17codecvtIwc11__mbstate_tEC2Ej,__ZNSt3__16locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_,__ZNSt3__16locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_,__ZNSt3__16locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_,__ZNSt3__16locale5__imp7installINS_8numpunctIcEEEEvPT_,__ZNSt3__16locale5__imp7installINS_8numpunctIwEEEEvPT_,__ZNSt3__16locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_,__ZNSt3__16locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_,__ZNSt3__16locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_,__ZNSt3__16locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_,__ZNSt3__16locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_,__ZNSt3__16locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_
  ,__ZNSt3__16locale5__imp7installINS_8messagesIcEEEEvPT_,__ZNSt3__16locale5__imp7installINS_8messagesIwEEEEvPT_,__ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE6resizeEj,__ZNSt3__16vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lj28EEEE8allocateEj,_abort_message,_emscripten_glPixelStorei__wrapper,_emscripten_glGetIntegerv__wrapper,_emscripten_glGetFloatv__wrapper,_emscripten_glGetBooleanv__wrapper,_emscripten_glGenTextures__wrapper,_emscripten_glDeleteTextures__wrapper,_emscripten_glBindTexture__wrapper,_emscripten_glGenBuffers__wrapper,_emscripten_glDeleteBuffers__wrapper,_emscripten_glGenRenderbuffers__wrapper,_emscripten_glDeleteRenderbuffers__wrapper,_emscripten_glBindRenderbuffer__wrapper,_emscripten_glUniform1i__wrapper,_emscripten_glBindBuffer__wrapper,_emscripten_glVertexAttrib1fv__wrapper,_emscripten_glVertexAttrib2fv__wrapper,_emscripten_glVertexAttrib3fv__wrapper,_emscripten_glVertexAttrib4fv__wrapper,_emscripten_glAttachShader__wrapper,_emscripten_glDetachShader__wrapper,_emscripten_glBindFramebuffer__wrapper,_emscripten_glGenFramebuffers__wrapper,_emscripten_glDeleteFramebuffers__wrapper,_emscripten_glBindProgramARB__wrapper,_emscripten_glGetPointerv__wrapper,_emscripten_glGenVertexArrays__wrapper,_emscripten_glDeleteVertexArrays__wrapper,_emscripten_glVertexAttribDivisor__wrapper,_emscripten_glBlendFunc__wrapper,_emscripten_glBlendEquationSeparate__wrapper,_emscripten_glStencilMaskSeparate__wrapper,_emscripten_glHint__wrapper,_emscripten_glDrawBuffers__wrapper,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70
  ,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70,b70];
  var FUNCTION_TABLE_iiffff = [b71,__ZN10Matrix4x4f14SetPerspectiveEffff];
  var FUNCTION_TABLE_viiiif = [b72,__Z78AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_ConstantSlerpP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController31UnityEngine_UnityEngine_Vector3S1_f,__Z39UnityEngine_UnityEngine_Vector3_m_SlerpP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_f,__Z53UnityEngine_UnityEngine_Vector3_m_INTERNAL_CALL_SlerpP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_f];
  var FUNCTION_TABLE_viifii = [b73,__ZN12PhysXRaycast10RaycastAllERK3RayfiR13dynamic_arrayI10RaycastHitLj4EE,__Z195mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Single_mscorlib_System_Collections_IHashCodeProvider_mscorlib_System_Collections_IComparerP37mscorlib_System_Collections_HashtableifP22mscorlib_System_ObjectS2_,__ZN14GraphicsHelper5ClearEjRK10ColorRGBAffjRKN9ShaderLab17ShaderPassContextE];
  var FUNCTION_TABLE_fi = [b74,__ZNK5physx3Cct13BoxController13getStepOffsetEv,__ZNK5physx3Cct13BoxController16getContactOffsetEv,__ZNK5physx3Cct13BoxController13getSlopeLimitEv,__ZNK5physx3Cct13BoxController13getHalfHeightEv,__ZNK5physx3Cct13BoxController17getHalfSideExtentEv,__ZNK5physx3Cct13BoxController20getHalfForwardExtentEv,__ZNK5physx3Cct13BoxController21getHalfHeightInternalEv,__ZThn8_NK5physx3Cct13BoxController21getHalfHeightInternalEv,__ZNK5physx3Cct17CapsuleController13getStepOffsetEv,__ZNK5physx3Cct17CapsuleController16getContactOffsetEv,__ZNK5physx3Cct17CapsuleController13getSlopeLimitEv,__ZNK5physx3Cct17CapsuleController9getRadiusEv,__ZNK5physx3Cct17CapsuleController9getHeightEv,__ZNK5physx3Cct17CapsuleController21getHalfHeightInternalEv,__ZThn8_NK5physx3Cct17CapsuleController21getHalfHeightInternalEv,__ZNK5physx14NpArticulation22getSeparationToleranceEv,__ZNK5physx14NpArticulation17getSleepThresholdEv,__ZNK5physx14NpArticulation25getStabilizationThresholdEv,__ZNK5physx14NpArticulation14getWakeCounterEv,__ZNK5physx19NpArticulationJoint12getStiffnessEv,__ZNK5physx19NpArticulationJoint10getDampingEv,__ZNK5physx19NpArticulationJoint21getInternalComplianceEv,__ZNK5physx19NpArticulationJoint21getExternalComplianceEv,__ZNK5physx19NpArticulationJoint22getTangentialStiffnessEv,__ZNK5physx19NpArticulationJoint20getTangentialDampingEv,__ZNK5physx19NpArticulationJoint28getSwingLimitContactDistanceEv,__ZNK5physx19NpArticulationJoint28getTwistLimitContactDistanceEv,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE7getMassEv
  ,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE10getInvMassEv,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE27getMinCCDAdvanceCoefficientEv,__ZNK5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE27getMaxDepenetrationVelocityEv,__ZNK5physx10NpMaterial18getDynamicFrictionEv,__ZNK5physx10NpMaterial17getStaticFrictionEv,__ZNK5physx10NpMaterial14getRestitutionEv,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE7getMassEv,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE10getInvMassEv,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE27getMinCCDAdvanceCoefficientEv,__ZNK5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE27getMaxDepenetrationVelocityEv,__ZNK5physx14NpRigidDynamic16getLinearDampingEv,__ZNK5physx14NpRigidDynamic17getAngularDampingEv,__ZNK5physx14NpRigidDynamic21getMaxAngularVelocityEv,__ZNK5physx14NpRigidDynamic17getSleepThresholdEv,__ZNK5physx14NpRigidDynamic25getStabilizationThresholdEv,__ZNK5physx14NpRigidDynamic14getWakeCounterEv,__ZNK5physx14NpRigidDynamic25getContactReportThresholdEv,__ZNK5physx7NpScene30getClothInterCollisionDistanceEv,__ZNK5physx7NpScene31getClothInterCollisionStiffnessEv,__ZNK5physx7NpScene26getBounceThresholdVelocityEv,__ZNK5physx7NpScene29getContactCorrelationDistanceEv,__ZNK5physx7NpScene26getFrictionOffsetThresholdEv,__ZNK5physx7NpScene20getMeshContactMarginEv,__ZNK5physx7NpScene24getWakeCounterResetValueEv,__ZNK5physx7NpShape16getContactOffsetEv,__ZNK5physx7NpShape13getRestOffsetEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE10getDampingEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE15getParticleMassEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14getRestitutionEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE18getDynamicFrictionEv
  ,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE17getStaticFrictionEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20getMaxMotionDistanceEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE13getRestOffsetEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE16getContactOffsetEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE11getGridSizeEv,__ZNK5physx15NpParticleFluid12getStiffnessEv,__ZNK5physx15NpParticleFluid12getViscosityEv,__ZNK5physx15NpParticleFluid23getRestParticleDistanceEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE10getDampingEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE15getParticleMassEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14getRestitutionEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE18getDynamicFrictionEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE17getStaticFrictionEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20getMaxMotionDistanceEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE13getRestOffsetEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE16getContactOffsetEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE11getGridSizeEv,__ZNK5physx7NpCloth18getSolverFrequencyEv,__ZNK5physx7NpCloth19getPreviousTimeStepEv,__ZNK5physx7NpCloth21getStiffnessFrequencyEv,__ZNK5physx7NpCloth22getFrictionCoefficientEv,__ZNK5physx7NpCloth21getCollisionMassScaleEv,__ZNK5physx7NpCloth24getSelfCollisionDistanceEv,__ZNK5physx7NpCloth25getSelfCollisionStiffnessEv,__ZNK5physx7NpCloth16getContactOffsetEv,__ZNK5physx7NpCloth13getRestOffsetEv,__ZNK5physx7NpCloth22getSleepLinearVelocityEv,__ZNK5physx7NpCloth14getWakeCounterEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE22getPreviousIterationDtEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE18getSolverFrequencyEv
  ,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE21getStiffnessFrequencyEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE21getCollisionMassScaleEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE11getFrictionEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE24getTetherConstraintScaleEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE28getTetherConstraintStiffnessEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE24getMotionConstraintScaleEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE23getMotionConstraintBiasEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE28getMotionConstraintStiffnessEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE24getSelfCollisionDistanceEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE25getSelfCollisionStiffnessEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE17getSleepThresholdEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE22getPreviousIterationDtEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE18getSolverFrequencyEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE21getStiffnessFrequencyEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE21getCollisionMassScaleEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE11getFrictionEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE24getTetherConstraintScaleEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE28getTetherConstraintStiffnessEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE24getMotionConstraintScaleEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE23getMotionConstraintBiasEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE28getMotionConstraintStiffnessEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE24getSelfCollisionDistanceEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE25getSelfCollisionStiffnessEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE17getSleepThresholdEv,__ZNK5physx5cloth8SwSolver25getInterCollisionDistanceEv,__ZNK5physx5cloth8SwSolver26getInterCollisionStiffnessEv,__ZThn4_NK5physx5cloth8SwSolver25getInterCollisionDistanceEv,__ZThn4_NK5physx5cloth8SwSolver26getInterCollisionStiffnessEv,__ZNK5physx20PxsParticleSystemSim22getSimulationTimeStepVEv,__ZNK5physx2Gu11HeightField12getThicknessEv
  ,__ZNK5physx2Gu11HeightField22getConvexEdgeThresholdEv,__ZNK12BaseRenderer15GetSortingFudgeEv,__ZNK13ScreenManager6GetDPIEv,__ZN23PreloadManagerOperation11GetProgressEv,__ZN13AnimationClip18GetAverageDurationEv,__ZN13AnimationClip22GetAverageAngularSpeedEv,__ZN13AnimationClip16GetApparentSpeedEv,__Z38AssemblyU002DCSharp_JSONObject_m_get_fP30AssemblyU002DCSharp_JSONObject,__Z81AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_GetLockCameraTimerP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z71AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_GetSpeedP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single,__Z48UnityEngine_UnityEngine_BoneWeight_m_get_weight0P34UnityEngine_UnityEngine_BoneWeight,__Z48UnityEngine_UnityEngine_BoneWeight_m_get_weight1P34UnityEngine_UnityEngine_BoneWeight,__Z48UnityEngine_UnityEngine_BoneWeight_m_get_weight2P34UnityEngine_UnityEngine_BoneWeight,__Z48UnityEngine_UnityEngine_BoneWeight_m_get_weight3P34UnityEngine_UnityEngine_BoneWeight,__Z49UnityEngine_UnityEngine_GUIStyle_m_get_fixedWidthP32UnityEngine_UnityEngine_GUIStyle,__Z50UnityEngine_UnityEngine_GUIStyle_m_get_fixedHeightP32UnityEngine_UnityEngine_GUIStyle,__Z47UnityEngine_UnityEngine_Vector3_m_get_magnitudeP31UnityEngine_UnityEngine_Vector3,__Z50UnityEngine_UnityEngine_Vector3_m_get_sqrMagnitudeP31UnityEngine_UnityEngine_Vector3,__Z36UnityEngine_UnityEngine_Rect_m_get_xP28UnityEngine_UnityEngine_Rect,__Z36UnityEngine_UnityEngine_Rect_m_get_yP28UnityEngine_UnityEngine_Rect,__Z40UnityEngine_UnityEngine_Rect_m_get_widthP28UnityEngine_UnityEngine_Rect,__Z41UnityEngine_UnityEngine_Rect_m_get_heightP28UnityEngine_UnityEngine_Rect,__Z39UnityEngine_UnityEngine_Rect_m_get_xMinP28UnityEngine_UnityEngine_Rect,__Z39UnityEngine_UnityEngine_Rect_m_get_yMinP28UnityEngine_UnityEngine_Rect,__Z39UnityEngine_UnityEngine_Rect_m_get_xMaxP28UnityEngine_UnityEngine_Rect,__Z39UnityEngine_UnityEngine_Rect_m_get_yMaxP28UnityEngine_UnityEngine_Rect,__Z50UnityEngine_UnityEngine_Camera_m_get_nearClipPlaneP30UnityEngine_UnityEngine_Camera,__Z49UnityEngine_UnityEngine_Camera_m_get_farClipPlaneP30UnityEngine_UnityEngine_Camera,__Z39UnityEngine_UnityEngine_Time_m_get_timeP22mscorlib_System_Object
  ,__Z44UnityEngine_UnityEngine_Time_m_get_deltaTimeP22mscorlib_System_Object,__Z45UnityEngine_UnityEngine_Particle_m_get_energyP32UnityEngine_UnityEngine_Particle,__Z50UnityEngine_UnityEngine_Particle_m_get_startEnergyP32UnityEngine_UnityEngine_Particle,__Z43UnityEngine_UnityEngine_Particle_m_get_sizeP32UnityEngine_UnityEngine_Particle,__Z47UnityEngine_UnityEngine_Particle_m_get_rotationP32UnityEngine_UnityEngine_Particle,__Z54UnityEngine_UnityEngine_Particle_m_get_angularVelocityP32UnityEngine_UnityEngine_Particle,__Z56UnityEngine_UnityEngine_CharacterController_m_get_radiusP43UnityEngine_UnityEngine_CharacterController,__Z56UnityEngine_UnityEngine_CharacterController_m_get_heightP43UnityEngine_UnityEngine_CharacterController,__Z60UnityEngine_UnityEngine_CharacterController_m_get_slopeLimitP43UnityEngine_UnityEngine_CharacterController,__Z60UnityEngine_UnityEngine_CharacterController_m_get_stepOffsetP43UnityEngine_UnityEngine_CharacterController,__Z59UnityEngine_UnityEngine_AnimationEvent_m_get_floatParameterP38UnityEngine_UnityEngine_AnimationEvent,__Z49UnityEngine_UnityEngine_AnimationEvent_m_get_timeP38UnityEngine_UnityEngine_AnimationEvent,__Z62UnityEngine_UnityEngine_AnimatorStateInfo_m_get_normalizedTimeP41UnityEngine_UnityEngine_AnimatorStateInfo,__Z54UnityEngine_UnityEngine_AnimatorStateInfo_m_get_lengthP41UnityEngine_UnityEngine_AnimatorStateInfo,__Z67UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_normalizedTimeP46UnityEngine_UnityEngine_AnimatorTransitionInfo,__Z31getPxVehicleEngineData_RecipMOIPKN5physx19PxVehicleEngineDataE,__Z36getPxVehicleEngineData_RecipMaxOmegaPKN5physx19PxVehicleEngineDataE,__Z26getPxVehicleEngineDataMMOIPKN5physx19PxVehicleEngineDataE,__Z33getPxVehicleEngineDataMPeakTorquePKN5physx19PxVehicleEngineDataE,__Z31getPxVehicleEngineDataMMaxOmegaPKN5physx19PxVehicleEngineDataE,__Z46getPxVehicleEngineDataMDampingRateFullThrottlePKN5physx19PxVehicleEngineDataE,__Z59getPxVehicleEngineDataMDampingRateZeroThrottleClutchEngagedPKN5physx19PxVehicleEngineDataE,__Z62getPxVehicleEngineDataMDampingRateZeroThrottleClutchDisengagedPKN5physx19PxVehicleEngineDataE,__Z32getPxVehicleGearsDataMFinalRatioPKN5physx18PxVehicleGearsDataE,__Z32getPxVehicleGearsDataMSwitchTimePKN5physx18PxVehicleGearsDataE,__Z31getPxVehicleAutoBoxData_LatencyPKN5physx20PxVehicleAutoBoxDataE,__Z45getPxVehicleDifferential4WDataMFrontRearSplitPKN5physx27PxVehicleDifferential4WDataE,__Z50getPxVehicleDifferential4WDataMFrontLeftRightSplitPKN5physx27PxVehicleDifferential4WDataE,__Z49getPxVehicleDifferential4WDataMRearLeftRightSplitPKN5physx27PxVehicleDifferential4WDataE,__Z41getPxVehicleDifferential4WDataMCentreBiasPKN5physx27PxVehicleDifferential4WDataE
  ,__Z40getPxVehicleDifferential4WDataMFrontBiasPKN5physx27PxVehicleDifferential4WDataE,__Z39getPxVehicleDifferential4WDataMRearBiasPKN5physx27PxVehicleDifferential4WDataE,__Z42getPxVehicleAckermannGeometryDataMAccuracyPKN5physx30PxVehicleAckermannGeometryDataE,__Z44getPxVehicleAckermannGeometryDataMFrontWidthPKN5physx30PxVehicleAckermannGeometryDataE,__Z43getPxVehicleAckermannGeometryDataMRearWidthPKN5physx30PxVehicleAckermannGeometryDataE,__Z48getPxVehicleAckermannGeometryDataMAxleSeparationPKN5physx30PxVehicleAckermannGeometryDataE,__Z31getPxVehicleClutchDataMStrengthPKN5physx19PxVehicleClutchDataE,__Z42getPxVehicleTireLoadFilterData_DenominatorPKN5physx27PxVehicleTireLoadFilterDataE,__Z48getPxVehicleTireLoadFilterDataMMinNormalisedLoadPKN5physx27PxVehicleTireLoadFilterDataE,__Z56getPxVehicleTireLoadFilterDataMMinFilteredNormalisedLoadPKN5physx27PxVehicleTireLoadFilterDataE,__Z48getPxVehicleTireLoadFilterDataMMaxNormalisedLoadPKN5physx27PxVehicleTireLoadFilterDataE,__Z56getPxVehicleTireLoadFilterDataMMaxFilteredNormalisedLoadPKN5physx27PxVehicleTireLoadFilterDataE,__Z33getPxVehicleWheelData_RecipRadiusPKN5physx18PxVehicleWheelDataE,__Z30getPxVehicleWheelData_RecipMOIPKN5physx18PxVehicleWheelDataE,__Z28getPxVehicleWheelDataMRadiusPKN5physx18PxVehicleWheelDataE,__Z27getPxVehicleWheelDataMWidthPKN5physx18PxVehicleWheelDataE,__Z26getPxVehicleWheelDataMMassPKN5physx18PxVehicleWheelDataE,__Z25getPxVehicleWheelDataMMOIPKN5physx18PxVehicleWheelDataE,__Z33getPxVehicleWheelDataMDampingRatePKN5physx18PxVehicleWheelDataE,__Z36getPxVehicleWheelDataMMaxBrakeTorquePKN5physx18PxVehicleWheelDataE,__Z40getPxVehicleWheelDataMMaxHandBrakeTorquePKN5physx18PxVehicleWheelDataE,__Z30getPxVehicleWheelDataMMaxSteerPKN5physx18PxVehicleWheelDataE,__Z30getPxVehicleWheelDataMToeAnglePKN5physx18PxVehicleWheelDataE,__Z46getPxVehicleSuspensionData_RecipMaxCompressionPKN5physx23PxVehicleSuspensionDataE,__Z40getPxVehicleSuspensionData_RecipMaxDroopPKN5physx23PxVehicleSuspensionDataE,__Z41getPxVehicleSuspensionDataMSpringStrengthPKN5physx23PxVehicleSuspensionDataE,__Z43getPxVehicleSuspensionDataMSpringDamperRatePKN5physx23PxVehicleSuspensionDataE,__Z41getPxVehicleSuspensionDataMMaxCompressionPKN5physx23PxVehicleSuspensionDataE,__Z35getPxVehicleSuspensionDataMMaxDroopPKN5physx23PxVehicleSuspensionDataE,__Z37getPxVehicleSuspensionDataMSprungMassPKN5physx23PxVehicleSuspensionDataE
  ,__Z39getPxVehicleSuspensionDataMCamberAtRestPKN5physx23PxVehicleSuspensionDataE,__Z49getPxVehicleSuspensionDataMCamberAtMaxCompressionPKN5physx23PxVehicleSuspensionDataE,__Z43getPxVehicleSuspensionDataMCamberAtMaxDroopPKN5physx23PxVehicleSuspensionDataE,__Z61getPxVehicleTireData_RecipLongitudinalStiffnessPerUnitGravityPKN5physx17PxVehicleTireDataE,__Z54getPxVehicleTireData_FrictionVsSlipGraphRecipx1Minusx0PKN5physx17PxVehicleTireDataE,__Z54getPxVehicleTireData_FrictionVsSlipGraphRecipx2Minusx1PKN5physx17PxVehicleTireDataE,__Z30getPxVehicleTireDataMLatStiffXPKN5physx17PxVehicleTireDataE,__Z30getPxVehicleTireDataMLatStiffYPKN5physx17PxVehicleTireDataE,__Z56getPxVehicleTireDataMLongitudinalStiffnessPerUnitGravityPKN5physx17PxVehicleTireDataE,__Z50getPxVehicleTireDataMCamberStiffnessPerUnitGravityPKN5physx17PxVehicleTireDataE,__Z44getPxVehicleDriveDynData_EngineRotationSpeedPKN5physx21PxVehicleDriveDynDataE,__Z39getPxVehicleDriveDynData_GearSwitchTimePKN5physx21PxVehicleDriveDynDataE,__Z42getPxVehicleDriveDynData_AutoBoxSwitchTimePKN5physx21PxVehicleDriveDynDataE,__Z36getPxVehicleDriveDynDataMEnginespeedPKN5physx21PxVehicleDriveDynDataE,__Z39getPxVehicleDriveDynDataMGearSwitchTimePKN5physx21PxVehicleDriveDynDataE,__Z42getPxVehicleDriveDynDataMAutoBoxSwitchTimePKN5physx21PxVehicleDriveDynDataE,__ZNK6Camera16GetProjectionFarEv,__Z27CalculateShadowSphereOffsetRK6Camera,__Z34GUIStyle_Get_Custom_PropFixedWidthP15ScriptingObject,__Z35GUIStyle_Get_Custom_PropFixedHeightP15ScriptingObject,__Z35Camera_Get_Custom_PropNearClipPlaneP15ScriptingObject,__Z34Camera_Get_Custom_PropFarClipPlaneP15ScriptingObject,__Z20Input_CUSTOM_GetAxisP15ScriptingString,__Z23Input_CUSTOM_GetAxisRawP15ScriptingString,__Z41CharacterController_Get_Custom_PropRadiusP15ScriptingObject,__Z41CharacterController_Get_Custom_PropHeightP15ScriptingObject,__Z45CharacterController_Get_Custom_PropSlopeLimitP15ScriptingObject,__Z45CharacterController_Get_Custom_PropStepOffsetP15ScriptingObject,b74,b74
  ,b74,b74,b74,b74,b74,b74,b74,b74,b74,b74,b74,b74,b74,b74,b74,b74,b74];
  var FUNCTION_TABLE_viidi = [b75,__Z127mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Double_mscorlib_System_Int32P31mscorlib_System_NumberFormatterP22mscorlib_System_Stringdi];
  var FUNCTION_TABLE_viifif = [b76,__ZN14DetailRenderer6RenderEP6Camerafif];
  var FUNCTION_TABLE_vf = [b77,_glClearDepthf__wrapper,_emscripten_glClearDepthf__wrapper,_emscripten_glLineWidth__wrapper];
  var FUNCTION_TABLE_fiiiiiiiifiiiif = [b78,__ZN5physx20PxcSweepSphereSphereERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx21PxcUnimplementedSweepERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx22PxcSweepCapsuleCapsuleERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx17PxcSweepSphereBoxERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx21PxcSweepCapsuleConvexERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx18PxcSweepConvexMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx25PxcSweepConvexHeightfieldERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx18PxcSweepCapsuleBoxERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx14PxcSweepBoxBoxERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx17PxcSweepBoxConvexERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,__ZN5physx20PxcSweepConvexConvexERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_S8_S8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEf,b78,b78,b78,b78];
  var FUNCTION_TABLE_vi = [b79,__ZNSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZNSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZThn8_NSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZThn8_NSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZTv0_n12_NSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZTv0_n12_NSt3__118basic_stringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZNSt3__113basic_istreamIcNS_11char_traitsIcEEED1Ev,__ZNSt3__113basic_istreamIcNS_11char_traitsIcEEED0Ev,__ZTv0_n12_NSt3__113basic_istreamIcNS_11char_traitsIcEEED1Ev,__ZTv0_n12_NSt3__113basic_istreamIcNS_11char_traitsIcEEED0Ev,__ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZN6il2cpp2os11MutexHandleD1Ev,__ZN6il2cpp2os11MutexHandleD0Ev,__ZN6il2cpp2os11MutexHandle6SignalEv,__ZN6il2cpp2os11EventHandleD1Ev,__ZN6il2cpp2os11EventHandleD0Ev,__ZN6il2cpp2os11EventHandle6SignalEv,__ZN6il2cpp2os15SemaphoreHandleD1Ev,__ZN6il2cpp2os15SemaphoreHandleD0Ev,__ZN6il2cpp2os15SemaphoreHandle6SignalEv,__ZNSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZNSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZTv0_n12_NSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev,__ZTv0_n12_NSt3__119basic_ostringstreamIcNS_11char_traitsIcEENS_9allocatorIcEEED0Ev,__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEED1Ev,__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEED0Ev,__ZTv0_n12_NSt3__113basic_ostreamIcNS_11char_traitsIcEEED1Ev
  ,__ZTv0_n12_NSt3__113basic_ostreamIcNS_11char_traitsIcEEED0Ev,__ZN5physx3Cct13BoxControllerD2Ev,__ZN5physx3Cct13BoxControllerD0Ev,__ZN5physx3Cct13BoxController7releaseEv,__ZN5physx3Cct13BoxController15invalidateCacheEv,__ZThn8_N5physx3Cct13BoxControllerD1Ev,__ZThn8_N5physx3Cct13BoxControllerD0Ev,__ZN5physx15PxBoxControllerD1Ev,__ZN5physx15PxBoxControllerD0Ev,__ZN5physx3Cct17CapsuleControllerD2Ev,__ZN5physx3Cct17CapsuleControllerD0Ev,__ZN5physx3Cct17CapsuleController7releaseEv,__ZN5physx3Cct17CapsuleController15invalidateCacheEv,__ZThn8_N5physx3Cct17CapsuleControllerD1Ev,__ZThn8_N5physx3Cct17CapsuleControllerD0Ev,__ZN5physx19PxCapsuleControllerD1Ev,__ZN5physx19PxCapsuleControllerD0Ev,__ZN5physx13PxHitCallbackINS_12PxRaycastHitEE13finalizeQueryEv,__ZN5physx11PxHitBufferINS_12PxRaycastHitEED1Ev,__ZN5physx11PxHitBufferINS_12PxRaycastHitEED0Ev,__ZN16ControllerFilterD1Ev,__ZN16ControllerFilterD0Ev,__ZN5physx13PxHitCallbackINS_12PxOverlapHitEE13finalizeQueryEv,__ZN5physx11PxHitBufferINS_12PxOverlapHitEED1Ev,__ZN5physx11PxHitBufferINS_12PxOverlapHitEED0Ev,__ZN5physx3Cct26CharacterControllerManager7releaseEv,__ZN5physx3Cct26CharacterControllerManager16purgeControllersEv,__ZN5physx3Cct26CharacterControllerManagerD2Ev,__ZN5physx3Cct26CharacterControllerManagerD0Ev,__ZN5physx2Cm12RenderBufferD1Ev
  ,__ZN5physx2Cm12RenderBufferD0Ev,__ZN5physx2Cm12RenderBuffer5clearEv,__ZN5physx3Cct10ControllerD2Ev,__ZN5physx3Cct10ControllerD0Ev,__ZN5physx3Cct15ObstacleContextD2Ev,__ZN5physx3Cct15ObstacleContextD0Ev,__ZN5physx3Cct15ObstacleContext7releaseEv,__ZN5physx3Cct8SweptBoxD2Ev,__ZN5physx3Cct8SweptBoxD0Ev,__ZN5physx3Cct12SweptCapsuleD2Ev,__ZN5physx3Cct12SweptCapsuleD0Ev,__ZN5physx3Cct11SweptVolumeD2Ev,__ZN5physx3Cct11SweptVolumeD0Ev,__ZN5physx13PxHitCallbackINS_10PxSweepHitEE13finalizeQueryEv,__ZN5physx11PxHitBufferINS_10PxSweepHitEED1Ev,__ZN5physx11PxHitBufferINS_10PxSweepHitEED0Ev,__ZN5physx11NpAggregate7releaseEv,__ZN5physx11NpAggregateD2Ev,__ZN5physx11NpAggregateD0Ev,__ZN5physx14NpArticulation7releaseEv,__ZN5physx14NpArticulationD2Ev,__ZN5physx14NpArticulationD0Ev,__ZN5physx14NpArticulation6wakeUpEv,__ZN5physx14NpArticulation10putToSleepEv,__ZN5physx19NpArticulationJoint7releaseEv,__ZN5physx19NpArticulationJointD2Ev,__ZN5physx19NpArticulationJointD0Ev,__ZN5physx18NpArticulationLink7releaseEv,__ZN5physx18NpArticulationLinkD2Ev,__ZN5physx18NpArticulationLinkD0Ev
  ,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE13switchToNoSimEv,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE15switchFromNoSimEv,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE7releaseEv,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEED1Ev,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEED0Ev,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEED1Ev,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEED0Ev,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE7releaseEv,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEED1Ev,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEED0Ev,__ZN5physx18PxArticulationLinkD1Ev,__ZN5physx18PxArticulationLinkD0Ev,__ZN5physx2Cm29ConstraintImmediateVisualizerD1Ev,__ZN5physx2Cm29ConstraintImmediateVisualizerD0Ev,__ZN5physx12NpBatchQuery7executeEv,__ZN5physx12NpBatchQuery7releaseEv,__ZN5physx12NpBatchQueryD2Ev,__ZN5physx12NpBatchQueryD0Ev,__ZN16PxOverflowBufferIN5physx10PxSweepHitEE13finalizeQueryEv,__ZN16PxOverflowBufferIN5physx10PxSweepHitEED1Ev,__ZN16PxOverflowBufferIN5physx10PxSweepHitEED0Ev,__ZN16PxOverflowBufferIN5physx12PxOverlapHitEE13finalizeQueryEv,__ZN16PxOverflowBufferIN5physx12PxOverlapHitEED1Ev,__ZN16PxOverflowBufferIN5physx12PxOverlapHitEED0Ev,__ZN16PxOverflowBufferIN5physx12PxRaycastHitEE13finalizeQueryEv,__ZN16PxOverflowBufferIN5physx12PxRaycastHitEED1Ev,__ZN16PxOverflowBufferIN5physx12PxRaycastHitEED0Ev,__ZN5physx12NpConstraint7releaseEv,__ZN5physx12NpConstraintD2Ev,__ZN5physx12NpConstraintD0Ev
  ,__ZN5physx12NpConstraint9markDirtyEv,__ZN5physx9NpFactoryD2Ev,__ZN5physx9NpFactoryD0Ev,__ZN5physx10NpMaterial7releaseEv,__ZN5physx10NpMaterialD2Ev,__ZN5physx10NpMaterialD0Ev,__ZN5physx10NpMaterial14onRefCountZeroEv,__ZThn12_N5physx10NpMaterialD1Ev,__ZThn12_N5physx10NpMaterialD0Ev,__ZThn12_N5physx10NpMaterial14onRefCountZeroEv,__ZN5physx2Cm12RefCountableD1Ev,__ZN5physx2Cm12RefCountableD0Ev,__ZN5physx2Cm12RefCountable14onRefCountZeroEv,__ZN5physx10PxMaterialD1Ev,__ZN5physx10PxMaterialD0Ev,__ZN5physx9NpPhysicsD2Ev,__ZN5physx9NpPhysicsD0Ev,__ZN5physx9NpPhysics7releaseEv,__ZN5physx9NpPhysics20MeshDeletionListenerD1Ev,__ZN5physx9NpPhysics20MeshDeletionListenerD0Ev,__ZN5physx26NpPhysicsInsertionCallbackD1Ev,__ZN5physx26NpPhysicsInsertionCallbackD0Ev,__ZN5physx14NpRigidDynamic7releaseEv,__ZN5physx14NpRigidDynamicD2Ev,__ZN5physx14NpRigidDynamicD0Ev,__ZN5physx14NpRigidDynamic6wakeUpEv,__ZN5physx14NpRigidDynamic10putToSleepEv,__ZN5physx14NpRigidDynamic13switchToNoSimEv,__ZN5physx14NpRigidDynamic15switchFromNoSimEv,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE7releaseEv
  ,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEED1Ev,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEED0Ev,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE13switchToNoSimEv,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE15switchFromNoSimEv,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEED1Ev,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEED0Ev,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE7releaseEv,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEED1Ev,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEED0Ev,__ZN5physx14PxRigidDynamicD1Ev,__ZN5physx14PxRigidDynamicD0Ev,__ZN5physx13NpRigidStatic7releaseEv,__ZN5physx13NpRigidStaticD2Ev,__ZN5physx13NpRigidStaticD0Ev,__ZN5physx13NpRigidStatic13switchToNoSimEv,__ZN5physx13NpRigidStatic15switchFromNoSimEv,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE7releaseEv,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEED1Ev,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEED0Ev,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE13switchToNoSimEv,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE15switchFromNoSimEv,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE7releaseEv,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEED1Ev,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEED0Ev,__ZN5physx13PxRigidStaticD1Ev,__ZN5physx13PxRigidStaticD0Ev,__ZN5physx14NpSceneQueriesD2Ev,__ZN5physx14NpSceneQueriesD0Ev,__ZN5physx7NpSceneD2Ev,__ZN5physx7NpSceneD0Ev
  ,__ZN5physx7NpScene7releaseEv,__ZN5physx7NpScene17flushQueryUpdatesEv,__ZN5physx7NpScene10unlockReadEv,__ZN5physx7NpScene11unlockWriteEv,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSolveEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSolveEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm4Task3runEv,__ZN5physx14PxLightCpuTask12addReferenceEv,__ZN5physx14PxLightCpuTask15removeReferenceEv,__ZN5physx14PxLightCpuTask7releaseEv,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSolveEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx14PxLightCpuTaskD1Ev,__ZN5physx14PxLightCpuTaskD0Ev,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_14executeCollideEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_14executeCollideEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_14executeCollideEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSceneEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSceneEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSceneEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm10FanoutTaskD1Ev,__ZN5physx2Cm10FanoutTaskD0Ev,__ZN5physx2Cm8BaseTask3runEv,__ZN5physx2Cm10FanoutTask12addReferenceEv,__ZN5physx2Cm10FanoutTask15removeReferenceEv,__ZN5physx2Cm10FanoutTask7releaseEv,__ZN5physx2Cm10FanoutTask11runInternalEv,__ZN5physx7NpScene15SceneCompletionD1Ev,__ZN5physx7NpScene15SceneCompletionD0Ev,__ZN5physx7NpScene15SceneCompletion7releaseEv,__ZN5physx7NpScene15SceneCompletion11runInternalEv
  ,__ZN18MultiQueryCallbackIN5physx10PxSweepHitEED1Ev,__ZN18MultiQueryCallbackIN5physx10PxSweepHitEED0Ev,__ZN18MultiQueryCallbackIN5physx12PxOverlapHitEED1Ev,__ZN18MultiQueryCallbackIN5physx12PxOverlapHitEED0Ev,__ZN18MultiQueryCallbackIN5physx12PxRaycastHitEED1Ev,__ZN18MultiQueryCallbackIN5physx12PxRaycastHitEED0Ev,__ZN5physx7NpShape7releaseEv,__ZN5physx7NpShapeD2Ev,__ZN5physx7NpShapeD0Ev,__ZN5physx7NpShape14resetFilteringEv,__ZN5physx7NpShape14onRefCountZeroEv,__ZThn12_N5physx7NpShapeD1Ev,__ZThn12_N5physx7NpShapeD0Ev,__ZThn12_N5physx7NpShape14onRefCountZeroEv,__ZN5physx7PxShapeD1Ev,__ZN5physx7PxShapeD0Ev,__ZN5physx13NpVolumeCache10invalidateEv,__ZN5physx13NpVolumeCache7releaseEv,__ZN5physx13NpVolumeCacheD2Ev,__ZN5physx13NpVolumeCacheD0Ev,__ZN5physx23NpVolumeCacheSqCallbackD1Ev,__ZN5physx23NpVolumeCacheSqCallbackD0Ev,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE7releaseEv,__ZN5physx15NpParticleFluidD2Ev,__ZN5physx15NpParticleFluidD0Ev,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE16releaseParticlesEv,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14resetFilteringEv,__ZN5physx23NpParticleFluidReadData6unlockEv,__ZN5physx23NpParticleFluidReadDataD1Ev,__ZN5physx23NpParticleFluidReadDataD0Ev
  ,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEED1Ev,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEED0Ev,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE7releaseEv,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEED1Ev,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEED0Ev,__ZN5physx15PxParticleFluidD1Ev,__ZN5physx15PxParticleFluidD0Ev,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE7releaseEv,__ZN5physx16NpParticleSystemD2Ev,__ZN5physx16NpParticleSystemD0Ev,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE16releaseParticlesEv,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14resetFilteringEv,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEED1Ev,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEED0Ev,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE7releaseEv,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEED1Ev,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEED0Ev,__ZN5physx16PxParticleSystemD1Ev,__ZN5physx16PxParticleSystemD0Ev,__ZN5physx7NpCloth7releaseEv,__ZN5physx7NpClothD2Ev,__ZN5physx7NpClothD0Ev,__ZN5physx7NpCloth18clearInterpolationEv,__ZN5physx7NpCloth6wakeUpEv,__ZN5physx7NpCloth10putToSleepEv,__ZN5physx15NpActorTemplateINS_7PxClothEE7releaseEv,__ZN5physx15NpActorTemplateINS_7PxClothEED1Ev,__ZN5physx15NpActorTemplateINS_7PxClothEED0Ev,__ZN5physx7PxClothD1Ev,__ZN5physx7PxClothD0Ev
  ,__ZN5physx13NpClothFabric7releaseEv,__ZN5physx13NpClothFabricD2Ev,__ZN5physx13NpClothFabricD0Ev,__ZN5physx13NpClothFabric14onRefCountZeroEv,__ZThn8_N5physx13NpClothFabricD1Ev,__ZThn8_N5physx13NpClothFabricD0Ev,__ZThn8_N5physx13NpClothFabric14onRefCountZeroEv,__ZN5physx13PxClothFabricD1Ev,__ZN5physx13PxClothFabricD0Ev,__ZN5physx19NpClothParticleData6unlockEv,__ZN5physx19NpClothParticleDataD1Ev,__ZN5physx19NpClothParticleDataD0Ev,__ZN5physx2Sc8ActorSimD2Ev,__ZN5physx2Sc8ActorSimD0Ev,__ZN5physx2Sc5Actor10onActivateEv,__ZN5physx2Sc5Actor12onDeactivateEv,__ZN5physx2Sc11Interaction10initializeEv,__ZN5physx2Sc20ArticulationJointSim7destroyEv,__ZN5physx2Sc20ArticulationJointSimD2Ev,__ZN5physx2Sc20ArticulationJointSimD0Ev,__ZThn24_N5physx2Sc20ArticulationJointSimD1Ev,__ZThn24_N5physx2Sc20ArticulationJointSimD0Ev,__ZN5physx2Sc15CoreInteraction11updateStateEv,__ZN5physx2Sc7BodySimD2Ev,__ZN5physx2Sc7BodySimD0Ev,__ZN5physx2Sc7BodySim10onActivateEv,__ZN5physx2Sc7BodySim12onDeactivateEv,__ZN5physx2Sc21ConstraintInteraction7destroyEv,__ZN5physx2Sc21ConstraintInteractionD2Ev,__ZN5physx2Sc21ConstraintInteractionD0Ev
  ,__ZN5physx2Sc21ConstraintInteraction11updateStateEv,__ZThn24_N5physx2Sc21ConstraintInteractionD1Ev,__ZThn24_N5physx2Sc21ConstraintInteractionD0Ev,__ZThn24_N5physx2Sc21ConstraintInteraction11updateStateEv,__ZN5physx2Sc24ElementInteractionMarkerD1Ev,__ZN5physx2Sc24ElementInteractionMarkerD0Ev,__ZN5physx2Sc24ElementInteractionMarker11updateStateEv,__ZN5physx2Sc24ElementInteractionMarker10initializeEv,__ZN5physx2Sc24ElementInteractionMarker7destroyEv,__ZThn8_N5physx2Sc24ElementInteractionMarker10initializeEv,__ZThn8_N5physx2Sc24ElementInteractionMarker7destroyEv,__ZThn8_N5physx2Sc24ElementInteractionMarkerD1Ev,__ZThn8_N5physx2Sc24ElementInteractionMarkerD0Ev,__ZN5physx2Sc15CoreInteractionD1Ev,__ZN5physx2Sc15CoreInteractionD0Ev,__ZN5physx2Sc8RigidSimD2Ev,__ZN5physx2Sc8RigidSimD0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13ccdBroadPhaseEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13ccdBroadPhaseEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13ccdBroadPhaseEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx10PxBaseTaskD1Ev,__ZN5physx10PxBaseTaskD0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19updateCCDSinglePassEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19updateCCDSinglePassEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19updateCCDSinglePassEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11postCCDPassEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11postCCDPassEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11postCCDPassEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11collideStepEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11collideStepEPNS_10PxBaseTaskEEEED0Ev
  ,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11collideStepEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9solveStepEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9solveStepEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9solveStepEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10broadPhaseEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10broadPhaseEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10broadPhaseEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_14postBroadPhaseEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_14postBroadPhaseEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_14postBroadPhaseEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_20rigidBodyNarrowPhaseEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_20rigidBodyNarrowPhaseEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_20rigidBodyNarrowPhaseEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9islandGenEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9islandGenEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9islandGenEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13postIslandGenEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13postIslandGenEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13postIslandGenEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19islandGenSecondPassEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19islandGenSecondPassEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19islandGenSecondPassEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_23postIslandGenSecondPassEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_23postIslandGenSecondPassEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_23postIslandGenSecondPassEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_6solverEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_6solverEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_6solverEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10postSolverEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10postSolverEPNS_10PxBaseTaskEEEED0Ev
  ,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10postSolverEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18updateCCDMultiPassEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18updateCCDMultiPassEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18updateCCDMultiPassEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_17finalizationPhaseEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_17finalizationPhaseEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_17finalizationPhaseEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_20particlePostShapeGenEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_20particlePostShapeGenEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm18DelegateFanoutTaskINS_2Sc5SceneEXadL_ZNS3_20particlePostShapeGenEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_15postNarrowPhaseEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_15postNarrowPhaseEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_15postNarrowPhaseEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18clothPreprocessingEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18clothPreprocessingEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18clothPreprocessingEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Sc19ShapeInstancePairLLD1Ev,__ZN5physx2Sc19ShapeInstancePairLLD0Ev,__ZN5physx2Sc19ShapeInstancePairLL11updateStateEv,__ZN5physx2Sc19ShapeInstancePairLL10initializeEv,__ZN5physx2Sc19ShapeInstancePairLL7destroyEv,__ZThn8_N5physx2Sc19ShapeInstancePairLL10initializeEv,__ZThn8_N5physx2Sc19ShapeInstancePairLL7destroyEv,__ZThn8_N5physx2Sc19ShapeInstancePairLLD1Ev,__ZThn8_N5physx2Sc19ShapeInstancePairLLD0Ev,__ZN5physx2Sc8ShapeSimD2Ev,__ZN5physx2Sc8ShapeSimD0Ev,__ZN5physx2Sc9StaticSimD2Ev,__ZN5physx2Sc9StaticSimD0Ev,__ZN5physx2Sc18TriggerInteractionD2Ev
  ,__ZN5physx2Sc18TriggerInteractionD0Ev,__ZN5physx2Sc18TriggerInteraction10initializeEv,__ZN5physx2Sc18TriggerInteraction7destroyEv,__ZThn8_N5physx2Sc18TriggerInteraction10initializeEv,__ZThn8_N5physx2Sc18TriggerInteraction7destroyEv,__ZThn8_N5physx2Sc18TriggerInteractionD1Ev,__ZThn8_N5physx2Sc18TriggerInteractionD0Ev,__ZN5physx2Sc35ParticleElementRbElementInteractionD2Ev,__ZN5physx2Sc35ParticleElementRbElementInteractionD0Ev,__ZN5physx2Sc35ParticleElementRbElementInteraction11updateStateEv,__ZN5physx2Sc35ParticleElementRbElementInteraction10initializeEv,__ZN5physx2Sc35ParticleElementRbElementInteraction7destroyEv,__ZThn8_N5physx2Sc35ParticleElementRbElementInteraction10initializeEv,__ZThn8_N5physx2Sc35ParticleElementRbElementInteraction7destroyEv,__ZThn8_N5physx2Sc35ParticleElementRbElementInteractionD1Ev,__ZThn8_N5physx2Sc35ParticleElementRbElementInteractionD0Ev,__ZN5physx2Sc19ParticlePacketShapeD2Ev,__ZN5physx2Sc19ParticlePacketShapeD0Ev,__ZN5physx2Sc17ParticleSystemSimD1Ev,__ZN5physx2Sc17ParticleSystemSimD0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc17ParticleSystemSimEXadL_ZNS3_21prepareCollisionInputEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc17ParticleSystemSimEXadL_ZNS3_21prepareCollisionInputEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_2Sc17ParticleSystemSimEXadL_ZNS3_21prepareCollisionInputEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Sc5ActorD2Ev,__ZN5physx2Sc5ActorD0Ev,__ZN5physx2Sc7ElementD2Ev,__ZN5physx2Sc7ElementD0Ev,__ZN5physx2Sc11Interaction7destroyEv,__ZN5physx2Sc11InteractionD1Ev,__ZN5physx2Sc11InteractionD0Ev
  ,__ZN5physx2Sc10ClothShapeD2Ev,__ZN5physx2Sc10ClothShapeD0Ev,__ZN5physx2Sc8ClothSimD2Ev,__ZN5physx2Sc8ClothSimD0Ev,__ZN5physx5cloth8SwFabricD2Ev,__ZN5physx5cloth8SwFabricD0Ev,__ZThn4_N5physx5cloth8SwFabricD1Ev,__ZThn4_N5physx5cloth8SwFabricD0Ev,__ZN5physx5cloth13UserAllocatedD1Ev,__ZN5physx5cloth13UserAllocatedD0Ev,__ZN5physx5cloth6FabricD1Ev,__ZN5physx5cloth6FabricD0Ev,__ZN5physx5cloth9SwFactoryD2Ev,__ZN5physx5cloth9SwFactoryD0Ev,__ZThn4_N5physx5cloth9SwFactoryD1Ev,__ZThn4_N5physx5cloth9SwFactoryD0Ev,__ZN5physx5cloth9ClothImplINS0_7SwClothEED1Ev,__ZN5physx5cloth9ClothImplINS0_7SwClothEED0Ev,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE13lockParticlesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE15unlockParticlesEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE12clearInertiaEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE22clearMotionConstraintsEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE26clearSeparationConstraintsEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE18clearInterpolationEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE26clearParticleAccelerationsEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE10putToSleepEv,__ZN5physx5cloth9ClothImplINS0_7SwClothEE6wakeUpEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEED1Ev,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEED0Ev,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE13lockParticlesEv
  ,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE15unlockParticlesEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE12clearInertiaEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE22clearMotionConstraintsEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE26clearSeparationConstraintsEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE18clearInterpolationEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE26clearParticleAccelerationsEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE10putToSleepEv,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE6wakeUpEv,__ZN5physx5cloth8SwSolverD2Ev,__ZN5physx5cloth8SwSolverD0Ev,__ZThn4_N5physx5cloth8SwSolverD1Ev,__ZThn4_N5physx5cloth8SwSolverD0Ev,__ZN5physx5cloth8SwSolver22CpuClothSimulationTaskD1Ev,__ZN5physx5cloth8SwSolver22CpuClothSimulationTaskD0Ev,__ZN5physx5cloth8SwSolver22CpuClothSimulationTask7releaseEv,__ZN5physx5cloth8SwSolver22CpuClothSimulationTask11runInternalEv,__ZN5physx5cloth8SwSolver19StartSimulationTaskD1Ev,__ZN5physx5cloth8SwSolver19StartSimulationTaskD0Ev,__ZN5physx5cloth8SwSolver19StartSimulationTask11runInternalEv,__ZN5physx5cloth8SwSolver17EndSimulationTaskD1Ev,__ZN5physx5cloth8SwSolver17EndSimulationTaskD0Ev,__ZN5physx5cloth8SwSolver17EndSimulationTask11runInternalEv,__ZN5physx14SingleAABBTaskD2Ev,__ZN5physx14SingleAABBTaskD0Ev,__ZN5physx14SingleAABBTask11runInternalEv,__ZN5physx13ActorAABBTaskD2Ev,__ZN5physx13ActorAABBTaskD0Ev,__ZN5physx13ActorAABBTask11runInternalEv,__ZN5physx17AggregateAABBTaskD2Ev,__ZN5physx17AggregateAABBTaskD0Ev
  ,__ZN5physx17AggregateAABBTask11runInternalEv,__ZN5physx20SingleAABBUpdateTaskD1Ev,__ZN5physx20SingleAABBUpdateTaskD0Ev,__ZN5physx20SingleAABBUpdateTask11runInternalEv,__ZN5physx19ActorAABBUpdateTaskD1Ev,__ZN5physx19ActorAABBUpdateTaskD0Ev,__ZN5physx19ActorAABBUpdateTask11runInternalEv,__ZN5physx23AggregateAABBUpdateTaskD1Ev,__ZN5physx23AggregateAABBUpdateTaskD0Ev,__ZN5physx23AggregateAABBUpdateTask11runInternalEv,__ZN5physx10BPWorkTaskD1Ev,__ZN5physx10BPWorkTaskD0Ev,__ZN5physx10BPWorkTask11runInternalEv,__ZN5physx20ProcessBPResultsTaskD1Ev,__ZN5physx20ProcessBPResultsTaskD0Ev,__ZN5physx20ProcessBPResultsTask11runInternalEv,__ZN5physx20AggregateOverlapTaskD1Ev,__ZN5physx20AggregateOverlapTaskD0Ev,__ZN5physx20AggregateOverlapTask11runInternalEv,__ZN3MBPD2Ev,__ZN3MBPD0Ev,__ZN5physx16PxsBroadPhaseMBPD2Ev,__ZN5physx16PxsBroadPhaseMBPD0Ev,__ZN5physx16PxsBroadPhaseMBP7destroyEv,__ZN5physx16PxsBroadPhaseMBP11freeBuffersEv,__ZN5physx23PxsBroadPhaseContextSapD2Ev,__ZN5physx23PxsBroadPhaseContextSapD0Ev,__ZN5physx23PxsBroadPhaseContextSap7destroyEv,__ZN5physx23PxsBroadPhaseContextSap11freeBuffersEv,__ZN5physx29BroadPhaseBatchUpdateWorkTaskD1Ev
  ,__ZN5physx29BroadPhaseBatchUpdateWorkTaskD0Ev,__ZN5physx29BroadPhaseBatchUpdateWorkTask11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_18postCCDDepenetrateEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_18postCCDDepenetrateEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_18postCCDDepenetrateEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_14postCCDAdvanceEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_14postCCDAdvanceEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_14postCCDAdvanceEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_12postCCDSweepEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_12postCCDSweepEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_12postCCDSweepEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx17PxsCCDAdvanceTaskD1Ev,__ZN5physx17PxsCCDAdvanceTaskD0Ev,__ZN5physx17PxsCCDAdvanceTask11runInternalEv,__ZN5physx15PxsCCDSweepTaskD1Ev,__ZN5physx15PxsCCDSweepTaskD0Ev,__ZN5physx15PxsCCDSweepTask11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_23prepareCMDiscreteUpdateEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_23prepareCMDiscreteUpdateEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_23prepareCMDiscreteUpdateEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN23PxsCMDiscreteUpdateTaskD1Ev,__ZN23PxsCMDiscreteUpdateTaskD0Ev,__ZN15PxsCMUpdateTask7releaseEv,__ZN23PxsCMDiscreteUpdateTask11runInternalEv,__ZN20PxsAtomIntegrateTaskD1Ev,__ZN20PxsAtomIntegrateTaskD0Ev,__ZN20PxsAtomIntegrateTask11runInternalEv
  ,__ZN5physx38PxsSolverCreateFinalizeConstraintsTaskD1Ev,__ZN5physx38PxsSolverCreateFinalizeConstraintsTaskD0Ev,__ZN5physx38PxsSolverCreateFinalizeConstraintsTask11runInternalEv,__ZN21PxsCreateFinalizeTaskD1Ev,__ZN21PxsCreateFinalizeTaskD0Ev,__ZN21PxsCreateFinalizeTask11runInternalEv,__ZN5physx32PxsSolverConstraintPartitionTaskD1Ev,__ZN5physx32PxsSolverConstraintPartitionTaskD0Ev,__ZN5physx32PxsSolverConstraintPartitionTask11runInternalEv,__ZN5physx23PxsSolverSetupSolveTaskD1Ev,__ZN5physx23PxsSolverSetupSolveTaskD0Ev,__ZN5physx23PxsSolverSetupSolveTask11runInternalEv,__ZN21PxsParallelSolverTaskD1Ev,__ZN21PxsParallelSolverTaskD0Ev,__ZN21PxsParallelSolverTask11runInternalEv,__ZN5physx16PxsSolverEndTaskD1Ev,__ZN5physx16PxsSolverEndTaskD0Ev,__ZN5physx16PxsSolverEndTask11runInternalEv,__ZN5physx18PxsSolverStartTaskD1Ev,__ZN5physx18PxsSolverStartTaskD0Ev,__ZN5physx18PxsSolverStartTask11runInternalEv,__ZN5physx34PxsSolverConstraintPostProcessTaskD1Ev,__ZN5physx34PxsSolverConstraintPostProcessTaskD0Ev,__ZN5physx34PxsSolverConstraintPostProcessTask11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_17PxsFluidCollisionEXadL_ZNS2_12mergeResultsEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_17PxsFluidCollisionEXadL_ZNS2_12mergeResultsEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_17PxsFluidCollisionEXadL_ZNS2_12mergeResultsEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx21PxsFluidCollisionTaskD1Ev,__ZN5physx21PxsFluidCollisionTaskD0Ev,__ZN5physx21PxsFluidCollisionTask11runInternalEv
  ,__ZN26PxcContactCellMeshCallbackD1Ev,__ZN26PxcContactCellMeshCallbackD0Ev,__ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_10mergeForceEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_10mergeForceEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_10mergeForceEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_12mergeDensityEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_12mergeDensityEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_12mergeDensityEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx23PxsFluidDynamicsSphTaskD1Ev,__ZN5physx23PxsFluidDynamicsSphTaskD0Ev,__ZN5physx23PxsFluidDynamicsSphTask11runInternalEv,__ZN5physx11NodeManagerD1Ev,__ZN5physx11NodeManagerD0Ev,__ZN5physx11EdgeManagerD1Ev,__ZN5physx11EdgeManagerD0Ev,__ZN5physx13IslandManagerD1Ev,__ZN5physx13IslandManagerD0Ev,__ZN5physx23ArticulationRootManagerD1Ev,__ZN5physx23ArticulationRootManagerD0Ev,__ZN5physx17MBPUpdateWorkTaskD2Ev,__ZN5physx17MBPUpdateWorkTaskD0Ev,__ZN5physx17MBPUpdateWorkTask11runInternalEv,__ZN5physx21MBPPostUpdateWorkTaskD1Ev,__ZN5physx21MBPPostUpdateWorkTaskD0Ev,__ZN5physx21MBPPostUpdateWorkTask11runInternalEv,__ZN5physx15PxsParticleDataD2Ev,__ZN5physx15PxsParticleDataD0Ev,__ZN5physx15PxsParticleData16removeParticlesVEv,__ZN5physx16PxsParticleShapeD2Ev,__ZN5physx16PxsParticleShapeD0Ev
  ,__ZN5physx16PxsParticleShape8destroyVEv,__ZN5physx20PxsParticleSystemSim32flushBufferedInteractionUpdatesVEv,__ZN5physx20PxsParticleSystemSimD2Ev,__ZN5physx20PxsParticleSystemSimD0Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_25spatialHashUpdateSectionsEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_25spatialHashUpdateSectionsEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_25spatialHashUpdateSectionsEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_21collisionFinalizationEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_21collisionFinalizationEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_21collisionFinalizationEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_15collisionUpdateEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_15collisionUpdateEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_15collisionUpdateEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_14dynamicsUpdateEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_14dynamicsUpdateEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_14dynamicsUpdateEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_24packetShapesFinalizationEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_24packetShapesFinalizationEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_24packetShapesFinalizationEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_18packetShapesUpdateEPNS_10PxBaseTaskEEEED1Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_18packetShapesUpdateEPNS_10PxBaseTaskEEEED0Ev,__ZN5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_18packetShapesUpdateEPNS_10PxBaseTaskEEEE11runInternalEv,__ZN5physx17SapUpdateWorkTaskD1Ev,__ZN5physx17SapUpdateWorkTaskD0Ev,__ZN5physx17SapUpdateWorkTask11runInternalEv,__ZN5physx21SapPostUpdateWorkTaskD1Ev,__ZN5physx21SapPostUpdateWorkTaskD0Ev,__ZN5physx21SapPostUpdateWorkTask11runInternalEv,__ZN5physx20PxsSolverCoreGeneral8destroyVEv,__ZN5physx20PxsSolverCoreGeneralD1Ev
  ,__ZN5physx20PxsSolverCoreGeneralD0Ev,__ZZN5physxL20PxcSweepAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEEN13AccumCallbackD2Ev,__ZZN5physxL20PxcSweepAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fRNS_6PxVec3ESA_RNS_10PxcNpCacheERNS_18PxcNpThreadContextEEN13AccumCallbackD0Ev,__ZN5physx29EntityReportContainerCallbackD1Ev,__ZN5physx29EntityReportContainerCallbackD0Ev,__ZZN5physx28PxcSweepEstimateAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fEN2CBD2Ev,__ZZN5physx28PxcSweepEstimateAnyShapeMeshERKNS_11PxsCCDShapeES2_PKNS_12PxsRigidBodyES5_RKNS_11PxTransformES8_fEN2CBD0Ev,__ZN5physx2Sq10AABBPruner6commitEv,__ZN5physx2Sq10AABBPrunerD2Ev,__ZN5physx2Sq10AABBPrunerD0Ev,__ZN5physx2Sq12BucketPruner6commitEv,__ZN5physx2Sq12BucketPrunerD2Ev,__ZN5physx2Sq12BucketPrunerD0Ev,__ZN5physx2Sq11PruningPoolD2Ev,__ZN5physx2Sq11PruningPoolD0Ev,__ZN5physx15PxVehicleWheels7releaseEv,__ZN5physx16PxVehicleNoDriveD1Ev,__ZN5physx16PxVehicleNoDriveD0Ev,__ZN5physx18PxVehicleDriveTankD1Ev,__ZN5physx18PxVehicleDriveTankD0Ev,__ZN5physx16PxVehicleDriveNWD1Ev,__ZN5physx16PxVehicleDriveNWD0Ev,__ZN5physx16PxVehicleDrive4WD1Ev,__ZN5physx16PxVehicleDrive4WD0Ev,__ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEED1Ev,__ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEED0Ev,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD2E_4v,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD0E_4v,__ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEED1Ev,__ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEED0Ev
  ,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD2E_3v,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD0E_3v,__ZN5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEED1Ev,__ZN5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEED0Ev,__ZZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD2E_2v,__ZZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD0E_2v,__ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEED1Ev,__ZN5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEED0Ev,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD2E_1v,__ZZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextEEN16RequiresCallbackD0E_1v,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEED1Ev,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEED0Ev,__ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEED1Ev,__ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEED0Ev,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEED1Ev,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEED0Ev,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEED1Ev,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEED0Ev,__ZN5physx14PxVehicleDriveD1Ev,__ZN5physx14PxVehicleDriveD0Ev,__ZN5physx25PxVehicleConstraintShader19onConstraintReleaseEv,__ZN5physx25PxVehicleConstraintShaderD1Ev,__ZN5physx25PxVehicleConstraintShaderD0Ev,__ZN5physx7Cooking7releaseEv,__ZN5physx7CookingD1Ev,__ZN5physx7CookingD0Ev,__ZN5physx2Gu12TriangleMesh7releaseEv,__ZN5physx19TriangleMeshBuilderD1Ev,__ZN5physx19TriangleMeshBuilderD0Ev,__ZN5physx2Gu12TriangleMesh14onRefCountZeroEv
  ,__ZThn8_N5physx19TriangleMeshBuilderD1Ev,__ZThn8_N5physx19TriangleMeshBuilderD0Ev,__ZThn8_N5physx2Gu12TriangleMesh14onRefCountZeroEv,__ZN16RTreeCookerRemapD1Ev,__ZN16RTreeCookerRemapD0Ev,__ZN5physx2Gu10ConvexMesh7releaseEv,__ZN5physx17ConvexMeshBuilderD2Ev,__ZN5physx17ConvexMeshBuilderD0Ev,__ZN5physx2Gu10ConvexMesh14onRefCountZeroEv,__ZThn8_N5physx17ConvexMeshBuilderD1Ev,__ZThn8_N5physx17ConvexMeshBuilderD0Ev,__ZThn8_N5physx2Gu10ConvexMesh14onRefCountZeroEv,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev,__ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEE11flushEventsEv,__ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEE15clearCachedDataEv,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE7releaseEv,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19handleClientRemovedEv,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE18flushProfileEventsEv,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE7releaseEv,__ZThn120_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev,__ZThn120_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev,__ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev,__ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev,__ZThn128_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev,__ZThn128_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev,__ZThn128_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE18flushProfileEventsEv,__ZThn132_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED1Ev
  ,__ZThn132_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEED0Ev,__ZThn132_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19handleClientRemovedEv,__ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED1Ev,__ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEED0Ev,__ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEE15clearCachedDataEv,__ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEED1Ev,__ZN5physx7profile11EventBufferINS_24PxDefaultContextProviderENS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS7_EENS_24PxProfileNullEventFilterEED0Ev,__ZN5physx9PxTaskMgr17resetDependenciesEv,__ZN5physx9PxTaskMgr15startSimulationEv,__ZN5physx9PxTaskMgr14stopSimulationEv,__ZN5physx9PxTaskMgr7releaseEv,__ZN5physx9PxTaskMgrD2Ev,__ZN5physx9PxTaskMgrD0Ev,__ZN5physx6shdfnd10Foundation7releaseEv,__ZN5physx6shdfnd10FoundationD2Ev,__ZN5physx6shdfnd10FoundationD0Ev,__ZN5physx6shdfnd10Foundation19AlignCheckAllocatorD1Ev,__ZN5physx6shdfnd10Foundation19AlignCheckAllocatorD0Ev,__ZN5physx2Cm19CmEventNameProviderD1Ev,__ZN5physx2Cm19CmEventNameProviderD0Ev,__ZZ27sweepCCTBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEfEN11LocalReportD2Ev,__ZZ27sweepCCTBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEfEN11LocalReportD0Ev,__ZN5physx2Gu16SupportLocalImplINS0_11ConvexHullVEED1Ev,__ZN5physx2Gu16SupportLocalImplINS0_11ConvexHullVEED0Ev,__ZN5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEED1Ev,__ZN5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEED0Ev,__ZN5physx2Gu16SupportLocalImplINS0_4BoxVEED1Ev,__ZN5physx2Gu16SupportLocalImplINS0_4BoxVEED0Ev,__ZN5physx13GuMeshFactoryD2Ev,__ZN5physx13GuMeshFactoryD0Ev
  ,__ZN23RayMeshColliderCallbackD1Ev,__ZN23RayMeshColliderCallbackD0Ev,__ZN5physx2Gu9RadixSortD2Ev,__ZN5physx2Gu9RadixSortD0Ev,__ZN5physx2Gu17RadixSortBufferedD2Ev,__ZN5physx2Gu17RadixSortBufferedD0Ev,__ZN24MidPhaseQueryLocalReportD1Ev,__ZN24MidPhaseQueryLocalReportD0Ev,__ZN25MeshMTDGenerationCallbackD1Ev,__ZN25MeshMTDGenerationCallbackD0Ev,__ZN43CapsuleHeightfieldContactGenerationCallbackD1Ev,__ZN43CapsuleHeightfieldContactGenerationCallbackD0Ev,__ZN26ContactCapsuleMeshCallbackD1Ev,__ZN26ContactCapsuleMeshCallbackD0Ev,__ZN44ConvexVsHeightfieldContactGenerationCallbackD1Ev,__ZN44ConvexVsHeightfieldContactGenerationCallbackD0Ev,__ZN37ConvexVsMeshContactGenerationCallbackD1Ev,__ZN37ConvexVsMeshContactGenerationCallbackD0Ev,__ZN12_GLOBAL__N_142SphereHeightfieldContactGenerationCallbackD2Ev,__ZN12_GLOBAL__N_142SphereHeightfieldContactGenerationCallbackD0Ev,__ZN12_GLOBAL__N_127SphereMeshContactGenerationD2Ev,__ZN12_GLOBAL__N_127SphereMeshContactGenerationD0Ev,__ZN12_GLOBAL__N_135SphereMeshContactGenerationCallbackD2Ev,__ZN12_GLOBAL__N_135SphereMeshContactGenerationCallbackD0Ev,__ZN5physx2Gu10ConvexMeshD2Ev,__ZN5physx2Gu10ConvexMeshD0Ev,__ZThn8_N5physx2Gu10ConvexMeshD1Ev,__ZThn8_N5physx2Gu10ConvexMeshD0Ev,__ZN5physx12PxConvexMeshD1Ev,__ZN5physx12PxConvexMeshD0Ev
  ,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_ED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_11ConvexHullVES2_ED0Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVENS0_11ConvexHullVEED0Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_ED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_4BoxVES2_ED0Ev,__ZN5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEED1Ev,__ZN5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_11ConvexHullVEED0Ev,__ZN5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEED1Ev,__ZN5physx2Gu26EPASupportMapPairLocalImplINS0_9TriangleVENS0_4BoxVEED0Ev,__ZN5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEED1Ev,__ZN5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_11ConvexHullVEED0Ev,__ZN5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEED1Ev,__ZN5physx2Gu26EPASupportMapPairLocalImplINS0_8CapsuleVENS0_4BoxVEED0Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_11ConvexHullVEED0Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVENS0_4BoxVEED0Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_ED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_8CapsuleVES2_ED0Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_11ConvexHullVEED0Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_8CapsuleVEED0Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEED1Ev,__ZN5physx2Gu29EPASupportMapPairRelativeImplINS0_9TriangleVENS0_4BoxVEED0Ev,__ZN5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEED1Ev,__ZN5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEED0Ev,__ZN5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEED1Ev,__ZN5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEED0Ev
  ,__ZN5physx2Gu22SupportMapRelativeImplINS0_4BoxVEED1Ev,__ZN5physx2Gu22SupportMapRelativeImplINS0_4BoxVEED0Ev,__ZN12_GLOBAL__N_124HfTrianglesEntityReport2D2Ev,__ZN12_GLOBAL__N_124HfTrianglesEntityReport2D0Ev,__ZN16RayRTreeCallbackILi1ELb1EED1Ev,__ZN16RayRTreeCallbackILi1ELb1EED0Ev,__ZN5physx2Gu5RTree8Callback7profileEv,__ZThn4_N16RayRTreeCallbackILi1ELb1EED1Ev,__ZThn4_N16RayRTreeCallbackILi1ELb1EED0Ev,__ZN16RayRTreeCallbackILi0ELb1EED1Ev,__ZN16RayRTreeCallbackILi0ELb1EED0Ev,__ZThn4_N16RayRTreeCallbackILi0ELb1EED1Ev,__ZThn4_N16RayRTreeCallbackILi0ELb1EED0Ev,__ZN16RayRTreeCallbackILi1ELb0EED1Ev,__ZN16RayRTreeCallbackILi1ELb0EED0Ev,__ZThn4_N16RayRTreeCallbackILi1ELb0EED1Ev,__ZThn4_N16RayRTreeCallbackILi1ELb0EED0Ev,__ZN16RayRTreeCallbackILi0ELb0EED1Ev,__ZN16RayRTreeCallbackILi0ELb0EED0Ev,__ZThn4_N16RayRTreeCallbackILi0ELb0EED1Ev,__ZThn4_N16RayRTreeCallbackILi0ELb0EED0Ev,__ZN26IntersectAnyVsMeshCallbackILi2ELb0EED1Ev,__ZN26IntersectAnyVsMeshCallbackILi2ELb0EED0Ev,__ZN26IntersectAnyVsMeshCallbackILi2ELb1EED1Ev,__ZN26IntersectAnyVsMeshCallbackILi2ELb1EED0Ev,__ZN26IntersectAnyVsMeshCallbackILi1ELb0EED1Ev,__ZN26IntersectAnyVsMeshCallbackILi1ELb0EED0Ev,__ZN26IntersectAnyVsMeshCallbackILi1ELb1EED1Ev,__ZN26IntersectAnyVsMeshCallbackILi1ELb1EED0Ev,__ZN26IntersectAnyVsMeshCallbackILi0ELb0EED1Ev
  ,__ZN26IntersectAnyVsMeshCallbackILi0ELb0EED0Ev,__ZN26IntersectAnyVsMeshCallbackILi0ELb1EED1Ev,__ZN26IntersectAnyVsMeshCallbackILi0ELb1EED0Ev,__ZN27ConvexVsMeshOverlapCallbackD1Ev,__ZN27ConvexVsMeshOverlapCallbackD0Ev,__ZN25ConvexVsMeshSweepCallbackD1Ev,__ZN25ConvexVsMeshSweepCallbackD0Ev,__ZN23SweepBoxMeshHitCallbackD1Ev,__ZN23SweepBoxMeshHitCallbackD0Ev,__ZN20SweepCapsuleCallbackD1Ev,__ZN20SweepCapsuleCallbackD0Ev,__ZN5physx2Gu12TriangleMeshD2Ev,__ZN5physx2Gu12TriangleMeshD0Ev,__ZThn8_N5physx2Gu12TriangleMeshD1Ev,__ZThn8_N5physx2Gu12TriangleMeshD0Ev,__ZN5physx14PxTriangleMeshD1Ev,__ZN5physx14PxTriangleMeshD0Ev,__ZN5physx2Gu11HeightField7releaseEv,__ZN5physx2Gu11HeightFieldD2Ev,__ZN5physx2Gu11HeightFieldD0Ev,__ZN5physx2Gu11HeightField14onRefCountZeroEv,__ZThn8_N5physx2Gu11HeightFieldD1Ev,__ZThn8_N5physx2Gu11HeightFieldD0Ev,__ZThn8_N5physx2Gu11HeightField14onRefCountZeroEv,__ZN5physx13PxHeightFieldD1Ev,__ZN5physx13PxHeightFieldD0Ev,__ZN21BoxTraceSegmentReportD1Ev,__ZN21BoxTraceSegmentReportD0Ev,__ZN24ConvexVsHeightfieldSweepD1Ev,__ZN24ConvexVsHeightfieldSweepD0Ev
  ,__ZN25CapsuleTraceSegmentReportD1Ev,__ZN25CapsuleTraceSegmentReportD0Ev,__ZN5physx41PCMCapsuleVsMeshContactGenerationCallbackD1Ev,__ZN5physx41PCMCapsuleVsMeshContactGenerationCallbackD0Ev,__ZN5physx2Gu16SupportLocalImplINS0_9TriangleVEED1Ev,__ZN5physx2Gu16SupportLocalImplINS0_9TriangleVEED0Ev,__ZN5physx40PCMConvexVsMeshContactGenerationCallbackD1Ev,__ZN5physx40PCMConvexVsMeshContactGenerationCallbackD0Ev,__ZN5physx40PCMSphereVsMeshContactGenerationCallbackD1Ev,__ZN5physx40PCMSphereVsMeshContactGenerationCallbackD0Ev,__ZN13BaseAllocatorD1Ev,__ZN13BaseAllocatorD0Ev,__ZN13BaseAllocator13ThreadCleanupEv,__ZN21UnityDefaultAllocatorI17LowLevelAllocatorED1Ev,__ZN21UnityDefaultAllocatorI17LowLevelAllocatorED0Ev,__ZN20DynamicHeapAllocatorI17LowLevelAllocatorED1Ev,__ZN20DynamicHeapAllocatorI17LowLevelAllocatorED0Ev,__ZN14StackAllocatorD2Ev,__ZN14StackAllocatorD0Ev,__ZN12TLSAllocatorI14StackAllocatorED1Ev,__ZN12TLSAllocatorI14StackAllocatorED0Ev,__ZN12TLSAllocatorI14StackAllocatorE13ThreadCleanupEv,__ZN6ObjectD2Ev,__ZN6ObjectD0Ev,__ZN6Object17MainThreadCleanupEv,__ZN6Object21AwakeFromLoadThreadedEv,__ZN6Object16CheckConsistencyEv,__ZN6Object5ResetEv,__ZN6Object10SmartResetEv,__ZN15EditorExtensionD1Ev
  ,__ZN15EditorExtensionD0Ev,__ZN16LevelGameManagerD1Ev,__ZN16LevelGameManagerD0Ev,__ZN11GameManager17MainThreadCleanupEv,__ZN11GameManager24NetworkOnApplicationQuitEv,__ZN11GameManager13NetworkUpdateEv,__ZN17GlobalGameManagerD1Ev,__ZN17GlobalGameManagerD0Ev,__ZN11GameManagerD1Ev,__ZN11GameManagerD0Ev,__ZN5Unity10GameObjectD1Ev,__ZN5Unity10GameObjectD0Ev,__ZN5Unity10GameObject16CheckConsistencyEv,__ZN5Unity10GameObject5ResetEv,__ZN5Unity9ComponentD1Ev,__ZN5Unity9ComponentD0Ev,__ZN5Unity9Component16CheckConsistencyEv,__ZN5Unity9Component20WillDestroyComponentEv,__ZN11NamedObjectD1Ev,__ZN11NamedObjectD0Ev,__ZN10TagManagerD1Ev,__ZN10TagManagerD0Ev,__ZN10TagManager6UpdateEv,__ZN8GUILayerD1Ev,__ZN8GUILayerD0Ev,__ZN9Behaviour6UpdateEv,__ZN9Behaviour11FixedUpdateEv,__ZN9Behaviour10LateUpdateEv,__ZN8GUILayer12AddToManagerEv,__ZN8GUILayer17RemoveFromManagerEv
  ,__ZN12BaseRendererD2Ev,__ZN12BaseRendererD0Ev,__ZN12BaseRenderer21RendererBecameVisibleEv,__ZN12BaseRenderer23RendererBecameInvisibleEv,__ZN6CameraD1Ev,__ZN6CameraD0Ev,__ZN6Camera17MainThreadCleanupEv,__ZN6Camera16CheckConsistencyEv,__ZN6Camera5ResetEv,__ZN6Camera12AddToManagerEv,__ZN6Camera17RemoveFromManagerEv,__ZN10FlareLayerD1Ev,__ZN10FlareLayerD0Ev,__ZN10FlareLayer12AddToManagerEv,__ZN10FlareLayer17RemoveFromManagerEv,__ZN16GraphicsSettingsD1Ev,__ZN16GraphicsSettingsD0Ev,__ZN16GraphicsSettings10SmartResetEv,__ZN11HaloManagerD1Ev,__ZN11HaloManagerD0Ev,__ZN11HaloManager17MainThreadCleanupEv,__ZN20IntermediateRendererD2Ev,__ZN20IntermediateRendererD0Ev,__ZN20IntermediateRenderer19UpdateTransformInfoEv,__ZN20IntermediateRenderer20OnAssetBoundsChangedEv,__ZN20IntermediateRenderer10UpdateAABBEv,__ZN24MeshIntermediateRendererD2Ev,__ZN24MeshIntermediateRendererD0Ev,__ZN24MeshIntermediateRenderer14OnAssetDeletedEv,__ZN48MeshIntermediateRendererWithDistanceSortingOrderD0Ev
  ,__ZN5LightD1Ev,__ZN5LightD0Ev,__ZN5Light16CheckConsistencyEv,__ZN5Light5ResetEv,__ZN5Light12AddToManagerEv,__ZN5Light17RemoveFromManagerEv,__ZN11LightProbesD1Ev,__ZN11LightProbesD0Ev,__ZN14RenderSettingsD1Ev,__ZN14RenderSettingsD0Ev,__ZN14RenderSettings16CheckConsistencyEv,__ZN14RenderSettings5ResetEv,__ZN17GenericDynamicVBOD2Ev,__ZN17GenericDynamicVBOD0Ev,__ZN4MeshD1Ev,__ZN4MeshD0Ev,__ZN4Mesh17MainThreadCleanupEv,__ZN4Mesh21AwakeFromLoadThreadedEv,__ZN14SharedMeshDataD1Ev,__ZN14SharedMeshDataD0Ev,__ZN18ThreadSharedObjectD1Ev,__ZN18ThreadSharedObjectD0Ev,__ZN10MeshFilterD1Ev,__ZN10MeshFilterD0Ev,__ZN12MeshRendererD1Ev,__ZN12MeshRendererD0Ev,__ZN12MeshRenderer17MainThreadCleanupEv,__ZN8Renderer16CheckConsistencyEv,__ZN8Renderer10SmartResetEv,__ZN8Renderer21RendererBecameVisibleEv
  ,__ZN8Renderer23RendererBecameInvisibleEv,__ZN8Renderer19UpdateTransformInfoEv,__ZN12MeshRenderer15UpdateLocalAABBEv,__ZN8Renderer14UpdateRendererEv,__ZN8Renderer10AddToSceneEv,__ZN8Renderer15RemoveFromSceneEv,__ZThn28_N12MeshRendererD1Ev,__ZThn28_N12MeshRendererD0Ev,__ZThn28_N8Renderer19UpdateTransformInfoEv,__ZThn28_N8Renderer21RendererBecameVisibleEv,__ZThn28_N8Renderer23RendererBecameInvisibleEv,__ZN20BaseBehaviourManagerD2Ev,__ZN20BaseBehaviourManagerD0Ev,__ZN9BehaviourD1Ev,__ZN9BehaviourD0Ev,__ZN13UpdateManagerD1Ev,__ZN13UpdateManagerD0Ev,__ZN13UpdateManager6UpdateEv,__ZN20LateBehaviourManagerD1Ev,__ZN20LateBehaviourManagerD0Ev,__ZN20LateBehaviourManager6UpdateEv,__ZN21FixedBehaviourManagerD1Ev,__ZN21FixedBehaviourManagerD0Ev,__ZN21FixedBehaviourManager6UpdateEv,__ZN16BehaviourManagerD1Ev,__ZN16BehaviourManagerD0Ev,__ZN16BehaviourManager6UpdateEv,__ZN18DelayedCallManagerD1Ev,__ZN18DelayedCallManagerD0Ev,__ZN18DelayedCallManager17MainThreadCleanupEv
  ,__ZN22BlockMemoryCacheWriterD1Ev,__ZN22BlockMemoryCacheWriterD0Ev,__ZN9GfxDeviceD2Ev,__ZN9GfxDeviceD0Ev,__ZN9GfxDevice15InvalidateStateEv,__ZN9GfxDevice18BeforePluginRenderEv,__ZN9GfxDevice17AfterPluginRenderEv,__ZN9GfxDevice12DisableFFFogEv,__ZN9GfxDevice11EndSkinningEv,__ZN9GfxDevice40IgnoreNextUnresolveOnCurrentRenderTargetEv,__ZN9GfxDevice21ResetDynamicResourcesEv,__ZN9GfxDevice22AcquireThreadOwnershipEv,__ZN9GfxDevice22ReleaseThreadOwnershipEv,__ZN9GfxDevice12ImmediateEndEv,__ZN9GfxDevice13AfterDrawCallEv,__ZN9GfxDevice15ResetFrameStatsEv,__ZN9GfxDevice15BeginFrameStatsEv,__ZN9GfxDevice13EndFrameStatsEv,__ZN9GfxDevice13SaveDrawStatsEv,__ZN9GfxDevice16RestoreDrawStatsEv,__ZN9GfxDevice16SynchronizeStatsEv,__ZN9GfxDevice23ClearRandomWriteTargetsEv,__ZN14GfxDeviceStats26AccumulateUsedTextureUsageEv,__ZN10GpuProgramD2Ev,__ZN10GpuProgramD0Ev,__ZN11MonoManagerD1Ev,__ZN11MonoManagerD0Ev,__ZN16ScriptingManager30RebuildClassIDToScriptingClassEv,__ZN7CubemapD1Ev,__ZN7CubemapD0Ev
  ,__ZN9Texture2D17MainThreadCleanupEv,__ZN9Texture2D21AwakeFromLoadThreadedEv,__ZN7Texture16CheckConsistencyEv,__ZN9Texture2D5ResetEv,__ZN9Texture2D13ApplySettingsEv,__ZN9Texture2D17UploadToGfxDeviceEv,__ZN9Texture2D15UpdateImageDataEv,__ZN9Texture2D30UpdateImageDataDontTouchMipmapEv,__ZN7Cubemap13RebuildMipMapEv,__ZN16LightmapSettingsD1Ev,__ZN16LightmapSettingsD0Ev,__ZN16LightmapSettings16CheckConsistencyEv,__ZN15QualitySettingsD1Ev,__ZN15QualitySettingsD0Ev,__ZN15QualitySettings16CheckConsistencyEv,__ZN15QualitySettings5ResetEv,__ZN8RendererD1Ev,__ZN8RendererD0Ev,__ZN8Renderer17MainThreadCleanupEv,__ZN8Renderer15UpdateLocalAABBEv,__ZThn28_N8RendererD1Ev,__ZThn28_N8RendererD0Ev,__ZN13RenderTextureD1Ev,__ZN13RenderTextureD0Ev,__ZN13RenderTexture17MainThreadCleanupEv,__ZN7Texture5ResetEv,__ZN13RenderTexture13ApplySettingsEv,__ZN13RenderTexture17UploadToGfxDeviceEv,__ZN13ScreenManagerD1Ev,__ZN13ScreenManagerD0Ev
  ,__ZN17SharedTextureDataD1Ev,__ZN17SharedTextureDataD0Ev,__ZN7TextureD1Ev,__ZN7TextureD0Ev,__ZN7Texture17MainThreadCleanupEv,__ZN7Texture13ApplySettingsEv,__ZN9Texture2DD1Ev,__ZN9Texture2DD0Ev,__ZN9Texture2D13RebuildMipMapEv,__ZN9Texture3DD1Ev,__ZN9Texture3DD0Ev,__ZN9Texture3D17MainThreadCleanupEv,__ZN9Texture3D5ResetEv,__ZN9Texture3D17UploadToGfxDeviceEv,__ZN9TransformD1Ev,__ZN9TransformD0Ev,__ZN9Transform16CheckConsistencyEv,__ZN9Transform5ResetEv,__ZN18ProceduralMaterialD1Ev,__ZN18ProceduralMaterialD0Ev,__ZN18ProceduralMaterial17MainThreadCleanupEv,__ZN18ProceduralMaterial21AwakeFromLoadThreadedEv,__ZN5Unity8Material5ResetEv,__ZN9InputAxis6UpdateEv,__ZN12InputManagerD1Ev,__ZN12InputManagerD0Ev,__ZN12InputManager16CheckConsistencyEv,__ZN12InputManager5ResetEv,__ZN11TimeManagerD1Ev,__ZN11TimeManagerD0Ev
  ,__ZN11TimeManager16CheckConsistencyEv,__ZN11TimeManager6UpdateEv,__ZN11AssetBundleD1Ev,__ZN11AssetBundleD0Ev,__ZN14AsyncOperationD2Ev,__ZN14AsyncOperationD0Ev,__ZN13BuildSettingsD1Ev,__ZN13BuildSettingsD0Ev,__ZN27GenericSlowGarbageCollectorD1Ev,__ZN27GenericSlowGarbageCollectorD0Ev,__ZN23PreloadManagerOperationD1Ev,__ZN23PreloadManagerOperationD0Ev,__ZN23PreloadManagerOperation19IntegrateMainThreadEv,__ZN11PreloadDataD1Ev,__ZN11PreloadDataD0Ev,__ZN18LoadLevelOperationD2Ev,__ZN18LoadLevelOperationD0Ev,__ZN18LoadLevelOperation7PerformEv,__ZN18LoadLevelOperation19IntegrateMainThreadEv,__ZN27UnloadUnusedAssetsOperationD1Ev,__ZN27UnloadUnusedAssetsOperationD0Ev,__ZN27UnloadUnusedAssetsOperation7PerformEv,__ZN27UnloadUnusedAssetsOperation19IntegrateMainThreadEv,__ZN14PlayerSettingsD1Ev,__ZN14PlayerSettingsD0Ev,__ZN14PlayerSettings16CheckConsistencyEv,__ZN15ResourceManagerD1Ev,__ZN15ResourceManagerD0Ev,__ZN13MonoBehaviourD1Ev,__ZN13MonoBehaviourD0Ev
  ,__ZN13MonoBehaviour17MainThreadCleanupEv,__ZN13MonoBehaviour10SmartResetEv,__ZN13MonoBehaviour20WillDestroyComponentEv,__ZN13MonoBehaviour6UpdateEv,__ZN13MonoBehaviour11FixedUpdateEv,__ZN13MonoBehaviour10LateUpdateEv,__ZN13MonoBehaviour12AddToManagerEv,__ZN13MonoBehaviour17RemoveFromManagerEv,__ZN10MonoScriptD1Ev,__ZN10MonoScriptD0Ev,__ZN10MonoScript17MainThreadCleanupEv,__ZN10MonoScript21AwakeFromLoadThreadedEv,__ZN16ScriptingManagerD2Ev,__ZN16ScriptingManagerD0Ev,__ZN9TextAssetD1Ev,__ZN9TextAssetD0Ev,__ZN25PathNamePersistentManagerD1Ev,__ZN25PathNamePersistentManagerD0Ev,__ZN17PersistentManagerD2Ev,__ZN17PersistentManagerD0Ev,__ZN18IDCollectorFunctorD1Ev,__ZN18IDCollectorFunctorD0Ev,__ZN14FileCacherReadD2Ev,__ZN14FileCacherReadD0Ev,__ZN22MemoryCacherReadBlocksD2Ev,__ZN22MemoryCacherReadBlocksD0Ev,__ZN5Unity8MaterialD1Ev,__ZN5Unity8MaterialD0Ev,__ZN5Unity8Material17MainThreadCleanupEv,__ZN6ShaderD1Ev
  ,__ZN6ShaderD0Ev,__ZN6Shader17MainThreadCleanupEv,__ZN6Shader21AwakeFromLoadThreadedEv,__ZN12ScriptMapperD1Ev,__ZN12ScriptMapperD0Ev,__ZN12FileAccessorD2Ev,__ZN12FileAccessorD0Ev,__ZN16MemoryFileSystemD2Ev,__ZN16MemoryFileSystemD0Ev,__ZN10MemoryFileD2Ev,__ZN10MemoryFileD0Ev,__ZN25MultiBlocksMemoryFileDataD2Ev,__ZN25MultiBlocksMemoryFileDataD0Ev,__ZN20LocalFileSystemPosixD1Ev,__ZN20LocalFileSystemPosixD0Ev,__ZN9ShaderLab7ProgramD2Ev,__ZN9ShaderLab7ProgramD0Ev,__ZN9ShaderLab13PropertySheetD2Ev,__ZN9ShaderLab13PropertySheetD0Ev,__ZN9ShaderLab14ParserGrabPassD1Ev,__ZN9ShaderLab14ParserGrabPassD0Ev,__ZN9ShaderLab13ParserUsePassD1Ev,__ZN9ShaderLab13ParserUsePassD0Ev,__ZN9ShaderLab10ParserPassD2Ev,__ZN9ShaderLab10ParserPassD0Ev,__ZN19CharacterControllerD1Ev,__ZN19CharacterControllerD0Ev,__ZN19CharacterController5ResetEv,__ZN19CharacterController10SmartResetEv,__ZN19CharacterController12ScaleChangedEv
  ,__ZN19CharacterController7CleanupEv,__ZN8Collider8ReCreateEv,__ZN8Collider22CreatePhysXObjIfNeededEv,__ZN8Collider22FetchPoseFromTransformEv,__ZN5physx23PxCapsuleControllerDescD1Ev,__ZN5physx23PxCapsuleControllerDescD0Ev,__ZN5physx23PxCapsuleControllerDesc12setToDefaultEv,__ZN23ControllerContactFilterD1Ev,__ZN23ControllerContactFilterD0Ev,__ZN19ControllerHitReportD1Ev,__ZN19ControllerHitReportD0Ev,__ZN24ControllerFilterCallbackD1Ev,__ZN24ControllerFilterCallbackD0Ev,__ZN8ColliderD1Ev,__ZN8ColliderD0Ev,__ZN8Collider7CleanupEv,__ZN12MeshColliderD1Ev,__ZN12MeshColliderD0Ev,__ZN12MeshCollider17MainThreadCleanupEv,__ZN12MeshCollider5ResetEv,__ZN12MeshCollider12ScaleChangedEv,__ZN12MeshCollider7CleanupEv,__ZN14PhysicsManagerD1Ev,__ZN14PhysicsManagerD0Ev,__ZN14PhysicsManager17MainThreadCleanupEv,__ZN14PhysicsManager5ResetEv,__ZThn24_N14PhysicsManagerD1Ev,__ZThn24_N14PhysicsManagerD0Ev,__ZN10CastFilterD1Ev,__ZN10CastFilterD0Ev
  ,__ZN18PhysxJobDispatcherD1Ev,__ZN18PhysxJobDispatcherD0Ev,__ZN16NovodexAllocatorD1Ev,__ZN16NovodexAllocatorD0Ev,__ZN11ErrorStreamD1Ev,__ZN11ErrorStreamD0Ev,__ZN9RigidbodyD1Ev,__ZN9RigidbodyD0Ev,__ZN9Rigidbody17MainThreadCleanupEv,__ZN9Rigidbody16CheckConsistencyEv,__ZN9Rigidbody5ResetEv,__ZN12PhysXRaycastD1Ev,__ZN12PhysXRaycastD0Ev,__ZN12MemoryStreamD2Ev,__ZN12MemoryStreamD0Ev,__ZThn4_N12MemoryStreamD1Ev,__ZThn4_N12MemoryStreamD0Ev,__ZN19CollisionListener2DD1Ev,__ZN19CollisionListener2DD0Ev,__ZN15ContactFilter2DD1Ev,__ZN15ContactFilter2DD0Ev,__ZN14AudioBehaviourD1Ev,__ZN14AudioBehaviourD0Ev,__ZN10SampleClipD1Ev,__ZN10SampleClipD0Ev,__ZN10SampleClip17MainThreadCleanupEv,__ZN9AudioClipD1Ev,__ZN9AudioClipD0Ev,__ZN9AudioClip17MainThreadCleanupEv,__ZN9AudioClip21AwakeFromLoadThreadedEv
  ,__ZN13AudioListenerD1Ev,__ZN13AudioListenerD0Ev,__ZN13AudioListener6UpdateEv,__ZN13AudioListener11FixedUpdateEv,__ZN13AudioListener12AddToManagerEv,__ZN13AudioListener17RemoveFromManagerEv,__ZN12AudioManagerD1Ev,__ZN12AudioManagerD0Ev,__ZN12AudioManager17MainThreadCleanupEv,__ZN12AudioManager16CheckConsistencyEv,__ZN17AudioCustomFilterD2Ev,__ZN17AudioCustomFilterD0Ev,__ZN20SoundChannelInstanceD2Ev,__ZN20SoundChannelInstanceD0Ev,__ZN11AudioModule11FixedUpdateEv,__ZN11AudioModule6UpdateEv,__ZN11AudioModule17StopVideoTexturesEv,__ZN11AudioModule19UpdateVideoTexturesEv,__ZN11AudioModule18PauseVideoTexturesEv,__ZN11AudioModule20SuspendVideoTexturesEv,__ZN11AudioModule19ResumeVideoTexturesEv,__ZN9AnimationD1Ev,__ZN9AnimationD0Ev,__ZN9Animation17MainThreadCleanupEv,__ZN9Animation12AddToManagerEv,__ZN9Animation17RemoveFromManagerEv,__ZN6MotionD1Ev,__ZN6MotionD0Ev,__ZN6Motion17MainThreadCleanupEv,__ZN13AnimationClipD1Ev
  ,__ZN13AnimationClipD0Ev,__ZN13AnimationClip17MainThreadCleanupEv,__ZN13AnimationClip16CheckConsistencyEv,__ZN8AnimatorD1Ev,__ZN8AnimatorD0Ev,__ZN8Animator17MainThreadCleanupEv,__ZN8Animator16CheckConsistencyEv,__ZN8Animator5ResetEv,__ZN8Animator12AddToManagerEv,__ZN8Animator17RemoveFromManagerEv,__ZN15AnimatorManager17FixedUpdateFKMoveEv,__ZN15AnimatorManager26FixedUpdateRetargetIKWriteEv,__ZN15AnimatorManager12UpdateFKMoveEv,__ZN15AnimatorManager21UpdateRetargetIKWriteEv,__ZN14AvatarPlaybackD2Ev,__ZN14AvatarPlaybackD0Ev,__ZN25RuntimeAnimatorControllerD1Ev,__ZN25RuntimeAnimatorControllerD0Ev,__ZN25RuntimeAnimatorController17MainThreadCleanupEv,__ZN25RuntimeAnimatorController22RegisterAnimationClipsEv,__ZN18AnimatorControllerD1Ev,__ZN18AnimatorControllerD0Ev,__ZN18AnimatorController17MainThreadCleanupEv,__ZN18AnimatorController16CheckConsistencyEv,__ZN16MecanimAnimationD1Ev,__ZN16MecanimAnimationD0Ev,__ZN20QuadTreeNodeRendererD1Ev,__ZN20QuadTreeNodeRendererD0Ev,__ZN20QuadTreeNodeRenderer14OnAssetDeletedEv,__ZN7TerrainD1Ev
  ,__ZN7TerrainD0Ev,__ZN7Terrain17MainThreadCleanupEv,__ZN7Terrain5ResetEv,__ZN7Terrain10SmartResetEv,__ZN7Terrain12AddToManagerEv,__ZN7Terrain17RemoveFromManagerEv,__ZN14TerrainManagerD2Ev,__ZN14TerrainManagerD0Ev,__ZN14TerrainManager27UnloadTerrainsFromGfxDeviceEv,__ZN14TerrainManager25ReloadTerrainsToGfxDeviceEv,__ZN14TerrainManager20ReconnectTerrainDataEv,__ZN26LegacyTreeInstanceRendererD1Ev,__ZN26LegacyTreeInstanceRendererD0Ev,__ZN24TreeIntermediateRenderer14OnAssetDeletedEv,__ZN23LODTreeInstanceRendererD1Ev,__ZN23LODTreeInstanceRendererD0Ev,__ZN29BillboardTreeInstanceRendererD1Ev,__ZN29BillboardTreeInstanceRendererD0Ev,__ZNK19TextRenderingModule10TMGenFlushEv,__ZN20TextRenderingPrivate4FontD1Ev,__ZN20TextRenderingPrivate4FontD0Ev,__ZN20TextRenderingPrivate4Font5ResetEv,__ZN20TextRenderingPrivate8TextMeshD1Ev,__ZN20TextRenderingPrivate8TextMeshD0Ev,__ZN20TextRenderingPrivate8TextMesh17MainThreadCleanupEv,__ZN20TextRenderingPrivate8TextMesh5ResetEv,__ZN2UI6CanvasD1Ev,__ZN2UI6CanvasD0Ev,__ZN2UI6Canvas16CheckConsistencyEv,__ZN2UI6Canvas12AddToManagerEv
  ,__ZN2UI6Canvas17RemoveFromManagerEv,__ZN18ScreenManagerWebGLD1Ev,__ZN18ScreenManagerWebGLD0Ev,__ZN13GfxDeviceGLESD2Ev,__ZN13GfxDeviceGLESD0Ev,__ZN13GfxDeviceGLES15InvalidateStateEv,__ZN13GfxDeviceGLES18BeforePluginRenderEv,__ZN13GfxDeviceGLES17AfterPluginRenderEv,__ZN13GfxDeviceGLES12DisableFFFogEv,__ZN13GfxDeviceGLES14DisableScissorEv,__ZN13GfxDeviceGLES10BeginFrameEv,__ZN13GfxDeviceGLES8EndFrameEv,__ZN13GfxDeviceGLES12PresentFrameEv,__ZN13GfxDeviceGLES15FinishRenderingEv,__ZN13GfxDeviceGLES22AcquireThreadOwnershipEv,__ZN13GfxDeviceGLES22ReleaseThreadOwnershipEv,__ZN13GfxDeviceGLES14BeforeDrawCallEv,__ZN13GfxDeviceGLES15ReloadResourcesEv,__ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESED1Ev,__ZN14DrawBufferGLESI12VertexBuffer27VertexBufferUsageMapperGLESED0Ev,__ZN9GfxBuffer5ResetEv,__ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESED1Ev,__ZN14DrawBufferGLESI11IndexBuffer26IndexBufferUsageMapperGLESED0Ev,__ZN31TransformFeedbackSkinPoseBufferD1Ev,__ZN31TransformFeedbackSkinPoseBufferD0Ev,__ZN22VertexDeclarationCacheD1Ev,__ZN22VertexDeclarationCacheD0Ev,__ZN26VertexDeclarationCacheGLESD1Ev,__ZN26VertexDeclarationCacheGLESD0Ev,__ZN21VertexDeclarationGLESD1Ev
  ,__ZN21VertexDeclarationGLESD0Ev,__ZN18GlslGpuProgramGLESD2Ev,__ZN18GlslGpuProgramGLESD0Ev,__ZN15TextureTFMethodD1Ev,__ZN15TextureTFMethodD0Ev,__ZN15TextureTFMethod15UnmapBoneBufferEv,__ZN15TextureTFMethod13DoneRenderingEv,__ZN21UniformBufferTFMethodD1Ev,__ZN21UniformBufferTFMethodD0Ev,__ZN21UniformBufferTFMethod15UnmapBoneBufferEv,__ZN21UniformBufferTFMethod13DoneRenderingEv,__ZN15UniformTFMethodD1Ev,__ZN15UniformTFMethodD0Ev,__ZN15UniformTFMethod15UnmapBoneBufferEv,__ZN15UniformTFMethod13DoneRenderingEv,__ZN15GfxDeviceGLES20D1Ev,__ZN15GfxDeviceGLES20D0Ev,__Z51AssemblyU002DCSharpU002Dfirstpass_MouseLook_m__ctorP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__Z52AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_UpdateP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__Z51AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_StartP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__Z74AssemblyU002DCSharpU002Dfirstpass_MouseLook_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z40AssemblyU002DCSharp_BJController_m__ctorP32AssemblyU002DCSharp_BJController,__Z42AssemblyU002DCSharp_BJController_m_OnStartP32AssemblyU002DCSharp_BJController,__Z75AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_m__ctorP67AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0,__Z98AssemblyU002DCSharp_LevelBuilder_U003CCreateNodeU003Ec__AnonStorey0_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z40AssemblyU002DCSharp_LevelBuilder_m__ctorP32AssemblyU002DCSharp_LevelBuilder,__Z40AssemblyU002DCSharp_LevelBuilder_m_StartP32AssemblyU002DCSharp_LevelBuilder,__Z59AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_VoidP30AssemblyU002DCSharp_JSONObject,__Z39AssemblyU002DCSharp_JSONObject_m__cctorP22mscorlib_System_Object,__Z38AssemblyU002DCSharp_JSONObject_m_ClearP30AssemblyU002DCSharp_JSONObject
  ,__Z61AssemblyU002DCSharp_JSONObject_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z42AssemblyU002DCSharp_JSONTemplates_m__cctorP22mscorlib_System_Object,__Z93AssemblyU002DCSharp_JSONTemplates_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map0P21CustomAttributesCache,__Z93AssemblyU002DCSharp_JSONTemplates_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map1P21CustomAttributesCache,__Z93AssemblyU002DCSharp_JSONTemplates_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map2P21CustomAttributesCache,__Z66AssemblyU002DCSharp_U003CPrivateImplementationDetailsU003E_m__ctorP58AssemblyU002DCSharp_U003CPrivateImplementationDetailsU003E,__Z89AssemblyU002DCSharp_U003CPrivateImplementationDetailsU003E_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorMovement_m__ctorP61AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorMovement,__Z68AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorJumping_m__ctorP60AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorJumping,__Z75AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorMovingPlatform_m__ctorP67AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorMovingPlatform,__Z68AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorSliding_m__ctorP60AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorSliding,__Z129AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z123AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z61AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m__ctorP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z61AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_AwakeP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z70AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_UpdateFunctionP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z67AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_FixedUpdateP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z62AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_UpdateP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z60AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_MainP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z84AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z65AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m__ctorP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__Z65AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_AwakeP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__Z66AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_UpdateP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__Z64AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_MainP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__Z88AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m__ctorP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__Z70AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_AwakeP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__Z71AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_UpdateP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__Z69AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_MainP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__Z93AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z64AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m__ctorP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__Z64AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_AwakeP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__Z73AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_DebugDrawStuffP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__Z69AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_LateUpdateP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__Z63AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_MainP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__Z68AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m__ctorP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z68AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_AwakeP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z94AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_UpdateSmoothedMovementDirectionP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z75AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_ApplyJumpingP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z75AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_ApplyGravityP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z70AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_DidJumpP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z69AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_UpdateP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z68AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_ResetP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z67AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_MainP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z91AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_CustomAttributesCacheGeneratorP21CustomAttributesCache,__ZL85mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController,__ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object,__ZL85mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder,__ZL75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String,__Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m_DisposeP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char,__ZL94mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_DisposeP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject,__ZL98mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_VerifyStateP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject,__ZL86mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_DisposeP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object,__ZL90mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_VerifyStateP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object,__ZL94mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_VoidP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__cctorP22mscorlib_System_Object,__ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ClearP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__ctorP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object,__ZL86mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m__cctorP22mscorlib_System_Object,__ZL73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m_DisposeP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type
  ,__ZL101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m__ctorP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object,__ZL102mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_VoidP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL82mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m__cctorP22mscorlib_System_Object,__ZL81mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_ClearP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL83mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject,__ZL93mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m__ctorP85mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject,__ZL94mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m__cctorP22mscorlib_System_Object,__ZL109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObject_m__ctorP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObject,__ZL94mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m__ctor_mscorlib_System_VoidP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m__cctorP22mscorlib_System_Object,__ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_ClearP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL86mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_DisposeP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String,__ZL90mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_VerifyStateP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String,__ZL85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m__ctorP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String,__ZL86mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m__cctorP22mscorlib_System_Object,__ZL101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_String_m__ctorP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_String,__ZL132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctor_mscorlib_System_VoidP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ResizeP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ClearP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_VoidP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ResizeP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ClearP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_DisposeP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m_DisposeP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32,__Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link,__ZL182mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_DisposeP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyStateP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_VerifyCurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_DisposeP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object
  ,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m_DisposeP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry,__Z158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_DisposeP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL182mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_DisposeP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_VerifyStateP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_VerifyCurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_DisposeP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_VoidP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ResizeP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ClearP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z166mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_DisposeP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_DisposeP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL136mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_VerifyStateP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_VerifyCurrentP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_DisposeP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z83mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m__ctorP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char,__Z84mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m__cctorP22mscorlib_System_Object,__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Char_m__ctorP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Char,__Z88mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m_DisposeP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type,__ZL79System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m__ctorP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object,__ZL80System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_ResizeP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object,__ZL79System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_ClearP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object,__Z129mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m_DisposeP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__ZL92System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_DisposeP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object,__ZL95System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_CheckStateP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object,__ZL92System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m__cctorP22mscorlib_System_Object,__Z131mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctor_mscorlib_System_VoidP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ResizeP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z110mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ClearP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32
  ,__Z157mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_DisposeP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z181mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_DisposeP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z127mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_VerifyStateP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z129mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_VerifyCurrentP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z123mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_DisposeP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z84mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m__ctorP76mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32,__Z85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m__cctorP22mscorlib_System_Object,__Z100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32_m__ctorP92mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32,__ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m_DisposeP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo,__ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo,__ZL96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_DisposeP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook,__Z109mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe,__Z114mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m_DisposeP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump,__ZL106mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m_DisposeP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController,__ZL67Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m__ctorP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object,__ZL77Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m__ctorP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object,__ZL79Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_DisposeP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object,__ZL77Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_ResetP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object,__ZL110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_DisposeP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL115mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__Z122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m_DisposeP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility,__ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute,__Z115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame
  ,__Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar,__Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags,__Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles,__Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory,__ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m_DisposeP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder,__ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m_DisposeP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m_DisposeP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m_DisposeP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m_DisposeP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m_DisposeP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute,__Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute,__Z92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions
  ,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes,__Z91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m_DisposeP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes,__Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes,__Z85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m_DisposeP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes,__Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m_DisposeP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute,__Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations,__ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m_DisposeP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m_DisposeP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint,__ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m_DisposeP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m_DisposeP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency,__ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m_DisposeP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m_DisposeP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType,__ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m_DisposeP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m_DisposeP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute
  ,__Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_DisposeP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute,__Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode,__Z124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m_DisposeP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle,__Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m_DisposeP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle,__Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m_DisposeP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel,__Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m_DisposeP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates,__Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m_DisposeP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m_DisposeP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute,__Z90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState,__Z85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets,__Z86mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTime_m__ctorP78mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTime,__Z79mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime_m__ctorP71mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime,__Z80mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime_m__cctorP22mscorlib_System_Object,__Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTime_m__ctorP87mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTime,__Z94mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime_m__ctorP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime,__Z87mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m__ctorP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime,__Z88mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m__cctorP22mscorlib_System_Object,__Z103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime_m__ctorP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime,__Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which,__Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m_DisposeP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind,__Z92mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTimeOffset_m__ctorP84mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTimeOffset,__Z85mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset_m__ctorP77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset,__Z86mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset_m__cctorP22mscorlib_System_Object,__Z101mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m__ctorP93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTimeOffset,__Z100mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset_m__ctorP92mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset,__Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m__ctorP85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset
  ,__Z94mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m__cctorP22mscorlib_System_Object,__Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m__ctorP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset,__Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m_DisposeP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek,__ZL83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute,__Z82mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_Guid_m__ctorP74mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_Guid,__Z75mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid_m__ctorP67mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid,__Z76mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid_m__cctorP22mscorlib_System_Object,__Z91mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Guid_m__ctorP83mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Guid,__Z90mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid_m__ctorP82mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid,__Z83mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m__ctorP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid,__Z84mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m__cctorP22mscorlib_System_Object,__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid_m__ctorP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid,__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization,__ZL77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m_DisposeP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m_DisposeP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute,__Z86mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_TimeSpan_m__ctorP78mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_TimeSpan,__Z79mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan_m__ctorP71mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan,__Z80mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan_m__cctorP22mscorlib_System_Object,__Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_TimeSpan_m__ctorP87mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_TimeSpan,__Z94mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan_m__ctorP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan,__Z87mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m__ctorP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan,__Z88mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m__cctorP22mscorlib_System_Object,__Z103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan_m__ctorP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan,__Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m_DisposeP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode,__ZL109mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_DisposeP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL113mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_DisposeP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z106mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation
  ,__ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall,__ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m_DisposeP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode,__ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent,__ZL70System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m__ctorP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type,__ZL72System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m__ctorP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__ZL85System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_DisposeP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object,__ZL83System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m_DisposeP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour,__ZL92mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m__ctor_mscorlib_System_VoidP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL72mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m__cctorP22mscorlib_System_Object,__ZL71mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_ClearP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL84mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_DisposeP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type,__ZL88mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_VerifyStateP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type,__ZL83mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m__ctorP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type,__ZL84mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m__cctorP22mscorlib_System_Object,__ZL99mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Type_m__ctorP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Type,__Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m_DisposeP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute,__ZL101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m_DisposeP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption,__Z100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera,__ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo,__ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour,__Z162mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctor_mscorlib_System_VoidP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z142mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ResizeP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z141mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ClearP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z188mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_DisposeP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m_DisposeP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event
  ,__Z98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z212mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z170mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_DisposeP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z158mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_VerifyStateP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z160mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_VerifyCurrentP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z154mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_DisposeP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__ZL92mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m__ctorP84mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event,__ZL93mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m__cctorP22mscorlib_System_Object,__ZL108mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Event_m__ctorP100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Event,__Z108mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z109mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m__cctorP22mscorlib_System_Object,__Z124mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z104mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex,__Z104mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m__ctor_mscorlib_System_VoidP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z84mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m__cctorP22mscorlib_System_Object,__Z83mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_ClearP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z96mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_DisposeP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex,__Z100mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_VerifyStateP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex,__Z95mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m__ctorP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex,__Z96mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m__cctorP22mscorlib_System_Object,__Z111mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex_m__ctorP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex,__Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo,__Z106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m__ctor_mscorlib_System_VoidP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m__cctorP22mscorlib_System_Object,__Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_ClearP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_DisposeP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo,__Z102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_VerifyStateP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo,__Z97mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m__ctorP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo,__Z98mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m__cctorP22mscorlib_System_Object
  ,__Z113mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo_m__ctorP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo,__Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo,__Z106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m__ctor_mscorlib_System_VoidP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m__cctorP22mscorlib_System_Object,__Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_ClearP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_DisposeP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo,__Z102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_VerifyStateP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo,__Z97mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m__ctorP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo,__Z98mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m__cctorP22mscorlib_System_Object,__Z113mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo_m__ctorP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object,__ZL117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctor_mscorlib_System_VoidP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m__cctorP22mscorlib_System_Object,__ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_ClearP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL109mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_DisposeP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall,__ZL113mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_VerifyStateP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall,__ZL108mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m__ctorP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL109mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m__cctorP22mscorlib_System_Object,__ZL124mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCall_m__ctorP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCall,__ZL120mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctor_mscorlib_System_VoidP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__cctorP22mscorlib_System_Object,__ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_ClearP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_DisposeP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL112mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_DisposeP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL116mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_VerifyStateP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL111mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctorP103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL112mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__cctorP22mscorlib_System_Object
  ,__ZL127mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCall_m__ctorP119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL107mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL110mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m_DisposeP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL107mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m_DisposeP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__Z103mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m_DisposeP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules,__ZL111mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m_DisposeP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle,__Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions,__Z90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType,__Z82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m_DisposeP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space,__Z84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType,__ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu,__ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject,__Z93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer,__ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer,__Z161mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctor_mscorlib_System_VoidP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z141mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ResizeP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ClearP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z187mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_DisposeP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z211mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z169mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_DisposeP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z157mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_VerifyStateP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache
  ,__Z159mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_VerifyCurrentP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z153mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_DisposeP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL115mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP107mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL116mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__cctorP22mscorlib_System_Object,__ZL131mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP123mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_DisposeP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry,__ZL106mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_VerifyStateP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry,__ZL110mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctor_mscorlib_System_VoidP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m__cctorP22mscorlib_System_Object,__ZL89mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_ClearP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL101mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP93mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL102mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m__cctorP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntry,__Z97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle,__ZL142mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctor_mscorlib_System_VoidP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ResizeP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL121mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ClearP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z168mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_DisposeP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL192mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_ClearP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL150mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_DisposeP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL138mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_VerifyStateP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL140mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_VerifyCurrentP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL134mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_DisposeP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL95mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m__ctorP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle,__ZL96mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m__cctorP22mscorlib_System_Object,__ZL111mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyle_m__ctorP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyle,__Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle
  ,__Z84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode,__Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType,__Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset,__ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material,__ZL96mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m__ctor_mscorlib_System_VoidP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m__cctorP22mscorlib_System_Object,__ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_ClearP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m_DisposeP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr,__ZL88mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_DisposeP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr,__ZL92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_VerifyStateP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr,__ZL87mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m__ctorP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr,__ZL88mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m__cctorP22mscorlib_System_Object,__ZL103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arr_m__ctorP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arr,__Z73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m_DisposeP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider,__Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m_DisposeP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode,__Z97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m_DisposeP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource
  ,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m_DisposeP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m_DisposeP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain,__Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m_DisposeP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor,__Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode,__Z93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m_DisposeP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode,__ZL81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m_DisposeP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m_DisposeP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas,__ZL115mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL89mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m_DisposeP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute,__ZL78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m_DisposeP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute,__ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m_DisposeP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m_DisposeP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m_DisposeP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64,__Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m_DisposeP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte,__Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m_DisposeP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m_DisposeP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m_DisposeP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m_DisposeP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr,__ZL77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m_DisposeP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate,__Z77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32_m__ctorP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32,__Z78mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32_m__cctorP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt32_m__ctorP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt32,__Z77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16_m__ctorP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16
  ,__Z78mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16_m__cctorP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt16_m__ctorP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt16,__Z75mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte_m__ctorP67mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte,__Z76mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte_m__cctorP22mscorlib_System_Object,__Z91mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Byte_m__ctorP83mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Byte,__Z77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64_m__ctorP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64,__Z78mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64_m__cctorP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt64_m__ctorP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt64,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m_DisposeP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo,__ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo,__ZL88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m_DisposeP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m_DisposeP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m_DisposeP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m_DisposeP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m_DisposeP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m_DisposeP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL123mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_DisposeP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m_DisposeP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute,__ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m_DisposeP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m_DisposeP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m_DisposeP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute,__Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m_DisposeP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL100mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m_DisposeP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction
  ,__ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m_DisposeP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map,__Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m_DisposeP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m_DisposeP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot,__Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m_DisposeP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode,__Z115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m_DisposeP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm,__Z30mscorlib_System_Object_m__ctorP22mscorlib_System_Object,__Z33mscorlib_System_Object_m_FinalizeP22mscorlib_System_Object,__Z84mscorlib_System_Object_CustomAttributesCacheGenerator_mscorlib_System_Object_m__ctorP21CustomAttributesCache,__Z87mscorlib_System_Object_CustomAttributesCacheGenerator_mscorlib_System_Object_m_FinalizeP21CustomAttributesCache,__Z94mscorlib_System_Object_CustomAttributesCacheGenerator_mscorlib_System_Object_m_ReferenceEqualsP21CustomAttributesCache,__Z53mscorlib_System_Object_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z56mscorlib_System_ValueType_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z33mscorlib_System_Attribute_m__ctorP25mscorlib_System_Attribute,__Z56mscorlib_System_Attribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Runtime_InteropServices__Attribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z52mscorlib_System_Int32_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_IFormattable_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_IConvertible_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z58mscorlib_System_IComparable_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z45mscorlib_System_SerializableAttribute_m__ctorP37mscorlib_System_SerializableAttribute,__Z68mscorlib_System_SerializableAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_AttributeUsageAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z90mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z52mscorlib_System_Int64_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z205mscorlib_System_UInt32_CustomAttributesCacheGenerator_mscorlib_System_UInt32_m_Parse_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z162mscorlib_System_UInt32_CustomAttributesCacheGenerator_mscorlib_System_UInt32_m_Parse_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z53mscorlib_System_UInt32_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_CLSCompliantAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z162mscorlib_System_UInt64_CustomAttributesCacheGenerator_mscorlib_System_UInt64_m_Parse_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z205mscorlib_System_UInt64_CustomAttributesCacheGenerator_mscorlib_System_UInt64_m_Parse_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP21CustomAttributesCache
  ,__Z53mscorlib_System_UInt64_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z51mscorlib_System_Byte_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z159mscorlib_System_SByte_CustomAttributesCacheGenerator_mscorlib_System_SByte_m_Parse_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z202mscorlib_System_SByte_CustomAttributesCacheGenerator_mscorlib_System_SByte_m_Parse_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z52mscorlib_System_SByte_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z52mscorlib_System_Int16_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z162mscorlib_System_UInt16_CustomAttributesCacheGenerator_mscorlib_System_UInt16_m_Parse_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z205mscorlib_System_UInt16_CustomAttributesCacheGenerator_mscorlib_System_UInt16_m_Parse_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z53mscorlib_System_UInt16_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_Collections_IEnumerator_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_Collections_IEnumerable_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z58mscorlib_System_IDisposable_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z29mscorlib_System_Char_m__cctorP22mscorlib_System_Object,__Z51mscorlib_System_Char_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z31mscorlib_System_String_m__cctorP22mscorlib_System_Object,__Z179mscorlib_System_String_CustomAttributesCacheGenerator_mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache,__Z132mscorlib_System_String_CustomAttributesCacheGenerator_mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP21CustomAttributesCache,__Z132mscorlib_System_String_CustomAttributesCacheGenerator_mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_StringP21CustomAttributesCache,__Z90mscorlib_System_String_CustomAttributesCacheGenerator_mscorlib_System_String_m_GetHashCodeP21CustomAttributesCache,__Z53mscorlib_System_String_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z57mscorlib_System_ICloneable_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Single_CustomAttributesCacheGenerator_mscorlib_System_Single_m_IsNaNP21CustomAttributesCache,__Z53mscorlib_System_Single_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Double_CustomAttributesCacheGenerator_mscorlib_System_Double_m_IsNaNP21CustomAttributesCache,__Z53mscorlib_System_Double_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z32mscorlib_System_Decimal_m__cctorP22mscorlib_System_Object,__Z41mscorlib_System_Decimal_m_ThrowInvalidExpP22mscorlib_System_Object,__Z63mscorlib_System_Decimal_CustomAttributesCacheGenerator_MinValueP21CustomAttributesCache,__Z63mscorlib_System_Decimal_CustomAttributesCacheGenerator_MaxValueP21CustomAttributesCache,__Z63mscorlib_System_Decimal_CustomAttributesCacheGenerator_MinusOneP21CustomAttributesCache
  ,__Z58mscorlib_System_Decimal_CustomAttributesCacheGenerator_OneP21CustomAttributesCache,__Z130mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_UInt32P21CustomAttributesCache,__Z130mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_UInt64P21CustomAttributesCache,__Z88mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_CompareP21CustomAttributesCache,__Z138mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_SByte_mscorlib_System_DecimalP21CustomAttributesCache,__Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt16_mscorlib_System_DecimalP21CustomAttributesCache,__Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt32_mscorlib_System_DecimalP21CustomAttributesCache,__Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt64_mscorlib_System_DecimalP21CustomAttributesCache,__Z138mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_SByteP21CustomAttributesCache,__Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt16P21CustomAttributesCache,__Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt32P21CustomAttributesCache,__Z139mscorlib_System_Decimal_CustomAttributesCacheGenerator_mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt64P21CustomAttributesCache,__Z54mscorlib_System_Decimal_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z32mscorlib_System_Boolean_m__cctorP22mscorlib_System_Object,__Z54mscorlib_System_Boolean_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z127mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_Int32P21CustomAttributesCache,__Z135mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_VoidU002A_ptrP21CustomAttributesCache,__Z87mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_get_SizeP21CustomAttributesCache,__Z86mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_ToInt64P21CustomAttributesCache,__Z160mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_IntPtr_mscorlib_System_IntPtrP21CustomAttributesCache,__Z162mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_IntPtr_mscorlib_System_IntPtrP21CustomAttributesCache,__Z135mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_IntPtr_mscorlib_System_Int32P21CustomAttributesCache,__Z143mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_IntPtr_mscorlib_System_VoidU002A_ptrP21CustomAttributesCache,__Z143mscorlib_System_IntPtr_CustomAttributesCacheGenerator_mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_VoidU002A_ptr_mscorlib_System_IntPtrP21CustomAttributesCache,__Z53mscorlib_System_IntPtr_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Runtime_Serialization_ISerializable_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z32mscorlib_System_UIntPtr_m__cctorP22mscorlib_System_Object,__Z137mscorlib_System_UIntPtr_CustomAttributesCacheGenerator_mscorlib_System_UIntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_VoidU002A_ptrP21CustomAttributesCache,__Z90mscorlib_System_UIntPtr_CustomAttributesCacheGenerator_mscorlib_System_UIntPtr_m_ToPointerP21CustomAttributesCache,__Z146mscorlib_System_UIntPtr_CustomAttributesCacheGenerator_mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UIntPtr_mscorlib_System_VoidU002A_ptrP21CustomAttributesCache
  ,__Z146mscorlib_System_UIntPtr_CustomAttributesCacheGenerator_mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_VoidU002A_ptr_mscorlib_System_UIntPtrP21CustomAttributesCache,__Z54mscorlib_System_UIntPtr_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z64mscorlib_System_MulticastDelegate_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z45mscorlib_System_Delegate_m_SetMulticastInvokeP24mscorlib_System_Delegate,__Z55mscorlib_System_Delegate_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z29mscorlib_System_Enum_m__cctorP22mscorlib_System_Object,__Z82mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_GetNameP21CustomAttributesCache,__Z92mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_GetUnderlyingTypeP21CustomAttributesCache,__Z138mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z161mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z83mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_ToObjectP21CustomAttributesCache,__Z81mscorlib_System_Enum_CustomAttributesCacheGenerator_mscorlib_System_Enum_m_FormatP21CustomAttributesCache,__Z51mscorlib_System_Enum_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z29mscorlib_System_Array_m__ctorP21mscorlib_System_Array,__Z54mscorlib_System_Array_m_System_Collections_IList_ClearP21mscorlib_System_Array,__Z56mscorlib_System_Array_m_InternalArray__ICollection_ClearP21mscorlib_System_Array,__Z34mscorlib_System_Array_m_InitializeP21mscorlib_System_Array,__Z109mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_System_Collections_IList_IndexOfP21CustomAttributesCache,__Z87mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_get_LengthP21CustomAttributesCache,__Z91mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_get_LongLengthP21CustomAttributesCache,__Z85mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_get_RankP21CustomAttributesCache,__Z90mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetLongLengthP21CustomAttributesCache,__Z90mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetLowerBoundP21CustomAttributesCache,__Z90mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetUpperBoundP21CustomAttributesCache,__Z130mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64P21CustomAttributesCache,__Z152mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache,__Z174mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache,__Z151mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64P21CustomAttributesCache,__Z173mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache,__Z195mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache
  ,__Z138mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_arr_arrP21CustomAttributesCache,__Z159mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_arr_arrP21CustomAttributesCache,__Z156mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP21CustomAttributesCache,__Z194mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Collections_IComparerP21CustomAttributesCache,__Z200mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_ObjectP21CustomAttributesCache,__Z238mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Collections_IComparerP21CustomAttributesCache,__Z82mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_ClearP21CustomAttributesCache,__Z168mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32P21CustomAttributesCache,__Z212mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache,__Z212mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int64_mscorlib_System_Array_mscorlib_System_Int64_mscorlib_System_Int64P21CustomAttributesCache,__Z168mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int64P21CustomAttributesCache,__Z151mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP21CustomAttributesCache,__Z173mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32P21CustomAttributesCache,__Z195mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache,__Z155mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP21CustomAttributesCache,__Z177mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32P21CustomAttributesCache,__Z199mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache,__Z127mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Reverse_mscorlib_System_Void_mscorlib_System_ArrayP21CustomAttributesCache,__Z171mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Reverse_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache,__Z124mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_ArrayP21CustomAttributesCache,__Z146mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_ArrayP21CustomAttributesCache,__Z162mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Collections_IComparerP21CustomAttributesCache,__Z168mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache,__Z184mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Collections_IComparerP21CustomAttributesCache,__Z190mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache,__Z206mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP21CustomAttributesCache,__Z228mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Array_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Collections_IComparerP21CustomAttributesCache,__Z148mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int64P21CustomAttributesCache,__Z92mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_Array_m_ConstrainedCopyP21CustomAttributesCache,__Z52mscorlib_System_Array_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z104mscorlib_System_Array_CustomAttributesCacheGenerator_mscorlib_System_ArrayTraits_LongLength_PropertyInfoP21CustomAttributesCache,__Z70mscorlib_System_Collections_ICollection_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z64mscorlib_System_Collections_IList_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_Collections_Generic_IList_1_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z51mscorlib_System_Void_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z29mscorlib_System_Type_m__cctorP22mscorlib_System_Object,__Z87mscorlib_System_Type_CustomAttributesCacheGenerator_mscorlib_System_Type_m_IsSubclassOfP21CustomAttributesCache,__Z288mscorlib_System_Type_CustomAttributesCacheGenerator_mscorlib_System_Type_m_GetConstructor_mscorlib_System_Reflection_ConstructorInfo_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP21CustomAttributesCache,__Z334mscorlib_System_Type_CustomAttributesCacheGenerator_mscorlib_System_Type_m_GetConstructor_mscorlib_System_Reflection_ConstructorInfo_mscorlib_System_Reflection_BindingFlags_mscorlib_System_Reflection_Binder_mscorlib_System_Reflection_CallingConventions_mscorlib_System_Type_arr_arr_mscorlib_System_Reflection_ParameterModifier_arr_arrP21CustomAttributesCache,__Z90mscorlib_System_Type_CustomAttributesCacheGenerator_mscorlib_System_Type_m_GetConstructorsP21CustomAttributesCache,__Z51mscorlib_System_Type_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_Reflection_MemberInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Reflection_ICustomAttributeProvider_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Runtime_InteropServices__MemberInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_Reflection_IReflect_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_Runtime_InteropServices__Type_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z54mscorlib_System_Exception_m__ctor_mscorlib_System_VoidP25mscorlib_System_Exception,__Z56mscorlib_System_Exception_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Runtime_InteropServices__Exception_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z109mscorlib_System_RuntimeFieldHandle_CustomAttributesCacheGenerator_mscorlib_System_RuntimeFieldHandle_m_EqualsP21CustomAttributesCache,__Z65mscorlib_System_RuntimeFieldHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z107mscorlib_System_RuntimeTypeHandle_CustomAttributesCacheGenerator_mscorlib_System_RuntimeTypeHandle_m_EqualsP21CustomAttributesCache,__Z64mscorlib_System_RuntimeTypeHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z43mscorlib_System_ParamArrayAttribute_m__ctorP35mscorlib_System_ParamArrayAttribute,__Z66mscorlib_System_ParamArrayAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z60mscorlib_System_Runtime_InteropServices_OutAttribute_m__ctorP52mscorlib_System_Runtime_InteropServices_OutAttribute,__Z83mscorlib_System_Runtime_InteropServices_OutAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z62mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_ObsoleteAttribute,__Z64mscorlib_System_ObsoleteAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z89mscorlib_System_Runtime_InteropServices_DllImportAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z101mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_CustomAttributesCacheGenerator_MarshalTypeP21CustomAttributesCache,__Z104mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_CustomAttributesCacheGenerator_MarshalTypeRefP21CustomAttributesCache,__Z89mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_Runtime_InteropServices_InAttribute_m__ctorP51mscorlib_System_Runtime_InteropServices_InAttribute,__Z82mscorlib_System_Runtime_InteropServices_InAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Runtime_InteropServices_GuidAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_Runtime_InteropServices_ComImportAttribute_m__ctorP58mscorlib_System_Runtime_InteropServices_ComImportAttribute,__Z89mscorlib_System_Runtime_InteropServices_ComImportAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z65mscorlib_System_Runtime_InteropServices_OptionalAttribute_m__ctorP57mscorlib_System_Runtime_InteropServices_OptionalAttribute,__Z88mscorlib_System_Runtime_InteropServices_OptionalAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z75mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m__ctorP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__Z98mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z99mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m__ctorP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__Z101mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m__ctorP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__Z82mscorlib_System_Diagnostics_DebuggerHiddenAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z80mscorlib_System_Reflection_DefaultMemberAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z170mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m__ctorP21CustomAttributesCache,__Z96mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z91mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_RuntimeArgumentHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z60mscorlib_System_AsyncCallback_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_IAsyncResult_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z61mscorlib_System_TypedReference_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z65mscorlib_System_MarshalByRefObject_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z62mscorlib_System_MonoTODOAttribute_m__ctor_mscorlib_System_VoidP33mscorlib_System_MonoTODOAttribute,__Z64mscorlib_System_MonoTODOAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z63mscorlib_Mono_Globalization_Unicode_ContractionComparer_m__ctorP55mscorlib_Mono_Globalization_Unicode_ContractionComparer,__Z64mscorlib_Mono_Globalization_Unicode_ContractionComparer_m__cctorP22mscorlib_System_Object
  ,__Z61mscorlib_Mono_Globalization_Unicode_Level2MapComparer_m__ctorP53mscorlib_Mono_Globalization_Unicode_Level2MapComparer,__Z62mscorlib_Mono_Globalization_Unicode_Level2MapComparer_m__cctorP22mscorlib_System_Object,__Z65mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m__cctorP22mscorlib_System_Object,__Z116mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map2P21CustomAttributesCache,__Z116mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map3P21CustomAttributesCache,__Z116mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map4P21CustomAttributesCache,__Z69mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTableUtil_m__cctorP22mscorlib_System_Object,__Z59mscorlib_Mono_Globalization_Unicode_SimpleCollator_m__cctorP22mscorlib_System_Object,__Z68mscorlib_System_Globalization_SortKey_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z57mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_ResetP49mscorlib_Mono_Globalization_Unicode_SortKeyBuffer,__Z42mscorlib_Mono_Security_StrongName_m__cctorP22mscorlib_System_Object,__Z95mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z79mscorlib_System_Collections_Generic_Dictionary_2_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z106mscorlib_System_Collections_Generic_Dictionary_2_CustomAttributesCacheGenerator_U003CU003Ef__amU0024cacheBP21CustomAttributesCache,__Z151mscorlib_System_Collections_Generic_Dictionary_2_CustomAttributesCacheGenerator_mscorlib_System_Collections_Generic_Dictionary_2_m_U003CCopyToU003Em__0P21CustomAttributesCache,__Z80mscorlib_System_Collections_Generic_IDictionary_2_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Collections_Generic_KeyValuePair_2_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z73mscorlib_System_Collections_Generic_List_1_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z63mscorlib_System_Collections_ArrayList_SimpleEnumerator_m__cctorP22mscorlib_System_Object,__Z62mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_ClearP54mscorlib_System_Collections_ArrayList_ArrayListWrapper,__Z45mscorlib_System_Collections_ArrayList_m_ClearP37mscorlib_System_Collections_ArrayList,__Z85mscorlib_System_Collections_ArrayList_ArrayListWrapper_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_ClearP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper,__Z97mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_Collections_ArrayList_m__ctor_mscorlib_System_VoidP37mscorlib_System_Collections_ArrayList,__Z46mscorlib_System_Collections_ArrayList_m__cctorP22mscorlib_System_Object,__Z68mscorlib_System_Collections_ArrayList_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z80mscorlib_System_Collections_CaseInsensitiveComparer_m__ctor_mscorlib_System_VoidP51mscorlib_System_Collections_CaseInsensitiveComparer,__Z60mscorlib_System_Collections_CaseInsensitiveComparer_m__cctorP22mscorlib_System_Object,__Z82mscorlib_System_Collections_CaseInsensitiveComparer_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z88mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m__ctor_mscorlib_System_VoidP59mscorlib_System_Collections_CaseInsensitiveHashCodeProvider,__Z68mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m__cctorP22mscorlib_System_Object,__Z90mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z65mscorlib_System_Collections_Comparer_m__ctor_mscorlib_System_VoidP36mscorlib_System_Collections_Comparer,__Z45mscorlib_System_Collections_Comparer_m__cctorP22mscorlib_System_Object,__Z67mscorlib_System_Collections_Comparer_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_Collections_DictionaryEntry_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z55mscorlib_System_Collections_Hashtable_KeyMarker_m__ctorP47mscorlib_System_Collections_Hashtable_KeyMarker,__Z56mscorlib_System_Collections_Hashtable_KeyMarker_m__cctorP22mscorlib_System_Object,__Z56mscorlib_System_Collections_Hashtable_Enumerator_m_ResetP48mscorlib_System_Collections_Hashtable_Enumerator,__Z57mscorlib_System_Collections_Hashtable_Enumerator_m__cctorP22mscorlib_System_Object,__Z59mscorlib_System_Collections_Hashtable_Enumerator_m_FailFastP48mscorlib_System_Collections_Hashtable_Enumerator,__Z77mscorlib_System_Collections_Hashtable_HashKeys_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z79mscorlib_System_Collections_Hashtable_HashValues_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_VoidP37mscorlib_System_Collections_Hashtable,__Z46mscorlib_System_Collections_Hashtable_m__cctorP22mscorlib_System_Object,__Z55mscorlib_System_Collections_Hashtable_m_AdjustThresholdP37mscorlib_System_Collections_Hashtable,__Z46mscorlib_System_Collections_Hashtable_m_RehashP37mscorlib_System_Collections_Hashtable,__Z264mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Single_mscorlib_System_Collections_IHashCodeProvider_mscorlib_System_Collections_IComparerP21CustomAttributesCache,__Z219mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_IHashCodeProvider_mscorlib_System_Collections_IComparerP21CustomAttributesCache,__Z115mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_Hashtable_m_RemoveP21CustomAttributesCache,__Z68mscorlib_System_Collections_Hashtable_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z134mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_HashtableTraits_comparer_PropertyInfoP21CustomAttributesCache,__Z129mscorlib_System_Collections_Hashtable_CustomAttributesCacheGenerator_mscorlib_System_Collections_HashtableTraits_hcp_PropertyInfoP21CustomAttributesCache,__Z68mscorlib_System_Collections_IComparer_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_Collections_IDictionary_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z80mscorlib_System_Collections_IDictionaryEnumerator_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_Collections_IEqualityComparer_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_Collections_IHashCodeProvider_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z41mscorlib_System_Collections_Stack_m__ctorP33mscorlib_System_Collections_Stack
  ,__Z41mscorlib_System_Collections_Stack_m_ClearP33mscorlib_System_Collections_Stack,__Z64mscorlib_System_Collections_Stack_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z93mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z100mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z93mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_System_Diagnostics_DebuggableAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z83mscorlib_System_Diagnostics_DebuggerDisplayAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z64mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m__ctorP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__Z87mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_Diagnostics_StackFrame_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_Diagnostics_StackTrace_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z46mscorlib_System_Globalization_Calendar_m__ctorP38mscorlib_System_Globalization_Calendar,__Z54mscorlib_System_Globalization_Calendar_m_CheckReadOnlyP38mscorlib_System_Globalization_Calendar,__Z69mscorlib_System_Globalization_Calendar_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z50mscorlib_System_Globalization_CompareInfo_m__cctorP22mscorlib_System_Object,__Z66mscorlib_System_Globalization_CompareInfo_m_free_internal_collatorP41mscorlib_System_Globalization_CompareInfo,__Z52mscorlib_System_Globalization_CompareInfo_m_FinalizeP41mscorlib_System_Globalization_CompareInfo,__Z72mscorlib_System_Globalization_CompareInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z75mscorlib_System_Globalization_CompareOptions_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z50mscorlib_System_Globalization_CultureInfo_m__cctorP22mscorlib_System_Object,__Z56mscorlib_System_Globalization_CultureInfo_m_CheckNeutralP41mscorlib_System_Globalization_CultureInfo,__Z53mscorlib_System_Globalization_CultureInfo_m_ConstructP41mscorlib_System_Globalization_CultureInfo,__Z69mscorlib_System_Globalization_CultureInfo_m_construct_datetime_formatP41mscorlib_System_Globalization_CultureInfo,__Z67mscorlib_System_Globalization_CultureInfo_m_construct_number_formatP41mscorlib_System_Globalization_CultureInfo,__Z102mscorlib_System_Globalization_CultureInfo_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map19P21CustomAttributesCache,__Z102mscorlib_System_Globalization_CultureInfo_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map1AP21CustomAttributesCache,__Z72mscorlib_System_Globalization_CultureInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z80mscorlib_System_Globalization_DateTimeFormatFlags_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z77mscorlib_System_Globalization_DateTimeFormatInfo_m__ctor_mscorlib_System_VoidP48mscorlib_System_Globalization_DateTimeFormatInfo
  ,__Z57mscorlib_System_Globalization_DateTimeFormatInfo_m__cctorP22mscorlib_System_Object,__Z74mscorlib_System_Globalization_DateTimeFormatInfo_m_FillAllDateTimePatternsP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z72mscorlib_System_Globalization_DateTimeFormatInfo_m_FillInvariantPatternsP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z79mscorlib_System_Globalization_DateTimeFormatInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z75mscorlib_System_Globalization_DateTimeStyles_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z73mscorlib_System_Globalization_DaylightTime_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_Globalization_GregorianCalendar_m__ctor_mscorlib_System_VoidP47mscorlib_System_Globalization_GregorianCalendar,__Z78mscorlib_System_Globalization_GregorianCalendar_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z83mscorlib_System_Globalization_GregorianCalendarTypes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z75mscorlib_System_Globalization_NumberFormatInfo_m__ctor_mscorlib_System_VoidP46mscorlib_System_Globalization_NumberFormatInfo,__Z55mscorlib_System_Globalization_NumberFormatInfo_m__cctorP22mscorlib_System_Object,__Z77mscorlib_System_Globalization_NumberFormatInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z73mscorlib_System_Globalization_NumberStyles_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_Globalization_TextInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z139mscorlib_System_Globalization_TextInfo_CustomAttributesCacheGenerator_mscorlib_System_Globalization_TextInfoTraits_CultureName_PropertyInfoP21CustomAttributesCache,__Z76mscorlib_System_Globalization_UnicodeCategory_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_System_Reflection_Emit_AssemblyBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Reflection_Emit_ConstructorBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z169mscorlib_System_Reflection_Emit_ConstructorBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_ConstructorBuilderTraits_CallingConvention_PropertyInfoP21CustomAttributesCache,__Z136mscorlib_System_Reflection_Emit_EnumBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_EnumBuilder_m_GetConstructorsP21CustomAttributesCache,__Z74mscorlib_System_Reflection_Emit_EnumBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z75mscorlib_System_Reflection_Emit_FieldBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z165mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsSubclassOfP21CustomAttributesCache,__Z168mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetConstructorsP21CustomAttributesCache,__Z159mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_EqualsP21CustomAttributesCache,__Z164mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetHashCodeP21CustomAttributesCache,__Z168mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_MakeGenericTypeP21CustomAttributesCache,__Z90mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z131mscorlib_System_Reflection_Emit_MethodBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_MethodBuilder_m_EqualsP21CustomAttributesCache,__Z76mscorlib_System_Reflection_Emit_MethodBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z54mscorlib_System_Reflection_Emit_ModuleBuilder_m__cctorP22mscorlib_System_Object,__Z76mscorlib_System_Reflection_Emit_ModuleBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z79mscorlib_System_Reflection_Emit_ParameterBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_System_Reflection_Emit_PropertyBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_check_createdP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z136mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_GetConstructorsP21CustomAttributesCache,__Z136mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_MakeGenericTypeP21CustomAttributesCache,__Z137mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_IsAssignableFromP21CustomAttributesCache,__Z133mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_IsSubclassOfP21CustomAttributesCache,__Z135mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Emit_TypeBuilder_m_IsAssignableToP21CustomAttributesCache,__Z74mscorlib_System_Reflection_Emit_TypeBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z79mscorlib_System_Reflection_Emit_UnmanagedMarshal_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z79mscorlib_System_Reflection_AmbiguousMatchException_m__ctor_mscorlib_System_VoidP50mscorlib_System_Reflection_AmbiguousMatchException,__Z81mscorlib_System_Reflection_AmbiguousMatchException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_Reflection_Assembly_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Reflection_AssemblyCompanyAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z88mscorlib_System_Reflection_AssemblyConfigurationAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Reflection_AssemblyCopyrightAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Reflection_AssemblyDelaySignAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z86mscorlib_System_Reflection_AssemblyDescriptionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z86mscorlib_System_Reflection_AssemblyFileVersionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z95mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Reflection_AssemblyKeyFileAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Reflection_AssemblyKeyNameAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z47mscorlib_System_Reflection_AssemblyName_m__ctorP39mscorlib_System_Reflection_AssemblyName,__Z70mscorlib_System_Reflection_AssemblyName_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z75mscorlib_System_Reflection_AssemblyNameFlags_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Reflection_AssemblyProductAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z80mscorlib_System_Reflection_AssemblyTitleAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z84mscorlib_System_Reflection_AssemblyTrademarkAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z49mscorlib_System_Reflection_Binder_Default_m__ctorP41mscorlib_System_Reflection_Binder_Default,__Z137mscorlib_System_Reflection_Binder_Default_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Binder_Default_m_ReorderArgumentArrayP21CustomAttributesCache,__Z41mscorlib_System_Reflection_Binder_m__ctorP33mscorlib_System_Reflection_Binder,__Z42mscorlib_System_Reflection_Binder_m__cctorP22mscorlib_System_Object,__Z64mscorlib_System_Reflection_Binder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_Reflection_BindingFlags_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_Reflection_CallingConventions_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z51mscorlib_System_Reflection_ConstructorInfo_m__cctorP22mscorlib_System_Object,__Z89mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGenerator_ConstructorNameP21CustomAttributesCache,__Z93mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGenerator_TypeConstructorNameP21CustomAttributesCache,__Z179mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_ConstructorInfo_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_arr_arrP21CustomAttributesCache,__Z73mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z146mscorlib_System_Reflection_ConstructorInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_ConstructorInfoTraits_MemberType_PropertyInfoP21CustomAttributesCache,__Z73mscorlib_System_Reflection_EventAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z67mscorlib_System_Reflection_EventInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z73mscorlib_System_Reflection_FieldAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z182mscorlib_System_Reflection_FieldInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_FieldInfo_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_ObjectP21CustomAttributesCache,__Z67mscorlib_System_Reflection_FieldInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_Reflection_MemberTypes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_Reflection_MethodAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z192mscorlib_System_Reflection_MethodBase_CustomAttributesCacheGenerator_mscorlib_System_Reflection_MethodBase_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP21CustomAttributesCache,__Z128mscorlib_System_Reflection_MethodBase_CustomAttributesCacheGenerator_mscorlib_System_Reflection_MethodBase_m_GetGenericArgumentsP21CustomAttributesCache,__Z68mscorlib_System_Reflection_MethodBase_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z139mscorlib_System_Reflection_MethodBase_CustomAttributesCacheGenerator_mscorlib_System_Reflection_MethodBaseTraits_IsConstructor_PropertyInfoP21CustomAttributesCache,__Z78mscorlib_System_Reflection_MethodImplAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z128mscorlib_System_Reflection_MethodInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_MethodInfo_m_GetGenericArgumentsP21CustomAttributesCache,__Z68mscorlib_System_Reflection_MethodInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z42mscorlib_System_Reflection_Missing_m__ctorP34mscorlib_System_Reflection_Missing,__Z43mscorlib_System_Reflection_Missing_m__cctorP22mscorlib_System_Object
  ,__Z159mscorlib_System_Reflection_Missing_CustomAttributesCacheGenerator_mscorlib_System_Reflection_Missing_m_System_Runtime_Serialization_ISerializable_GetObjectDataP21CustomAttributesCache,__Z65mscorlib_System_Reflection_Missing_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z42mscorlib_System_Reflection_Module_m__cctorP22mscorlib_System_Object,__Z64mscorlib_System_Reflection_Module_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z51mscorlib_System_Reflection_MonoField_m_CheckGenericP36mscorlib_System_Reflection_MonoField,__Z63mscorlib_System_Reflection_PInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z77mscorlib_System_Reflection_ParameterAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z71mscorlib_System_Reflection_ParameterInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z75mscorlib_System_Reflection_ParameterModifier_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_Reflection_PropertyAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z198mscorlib_System_Reflection_PropertyInfo_CustomAttributesCacheGenerator_mscorlib_System_Reflection_PropertyInfo_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP21CustomAttributesCache,__Z70mscorlib_System_Reflection_PropertyInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z75mscorlib_System_Reflection_StrongNameKeyPair_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z73mscorlib_System_Reflection_TargetException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z83mscorlib_System_Reflection_TargetInvocationException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85mscorlib_System_Reflection_TargetParameterCountException_m__ctor_mscorlib_System_VoidP56mscorlib_System_Reflection_TargetParameterCountException,__Z87mscorlib_System_Reflection_TargetParameterCountException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z72mscorlib_System_Reflection_TypeAttributes_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z90mscorlib_System_Resources_NeutralResourcesLanguageAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z90mscorlib_System_Resources_SatelliteContractVersionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z94mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z103mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z98mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Runtime_CompilerServices_IsVolatile_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z72mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m__ctorP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__Z95mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z79mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject_m_FinalizeP68mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject,__Z179mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject_CustomAttributesCacheGenerator_mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject_m_FinalizeP21CustomAttributesCache,__Z99mscorlib_System_Runtime_ConstrainedExecution_CriticalFinalizerObject_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z104mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z82mscorlib_System_Runtime_Hosting_ActivationArguments_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z94mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z89mscorlib_System_Runtime_InteropServices_ClassInterfaceType_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z99mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_Runtime_InteropServices_ComInterfaceType_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z93mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z56mscorlib_System_Runtime_InteropServices_Marshal_m__cctorP22mscorlib_System_Object,__Z78mscorlib_System_Runtime_InteropServices_Marshal_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m__ctorP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__Z91mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z58mscorlib_System_Runtime_InteropServices_SafeHandle_m_CloseP50mscorlib_System_Runtime_InteropServices_SafeHandle,__Z81mscorlib_System_Runtime_InteropServices_SafeHandle_m_Dispose_mscorlib_System_VoidP50mscorlib_System_Runtime_InteropServices_SafeHandle,__Z61mscorlib_System_Runtime_InteropServices_SafeHandle_m_FinalizeP50mscorlib_System_Runtime_InteropServices_SafeHandle,__Z140mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_CloseP21CustomAttributesCache,__Z163mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_Dispose_mscorlib_System_VoidP21CustomAttributesCache,__Z187mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_Dispose_mscorlib_System_Void_mscorlib_System_BooleanP21CustomAttributesCache,__Z148mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_ReleaseHandleP21CustomAttributesCache,__Z148mscorlib_System_Runtime_InteropServices_SafeHandle_CustomAttributesCacheGenerator_mscorlib_System_Runtime_InteropServices_SafeHandle_m_get_IsInvalidP21CustomAttributesCache,__Z98mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z94mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Runtime_InteropServices_UnmanagedType_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Runtime_InteropServices__Activator_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z80mscorlib_System_Runtime_InteropServices__Assembly_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_Runtime_InteropServices__AssemblyBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Runtime_InteropServices__AssemblyName_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z90mscorlib_System_Runtime_InteropServices__ConstructorBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_Runtime_InteropServices__ConstructorInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z83mscorlib_System_Runtime_InteropServices__EnumBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Runtime_InteropServices__EventInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Runtime_InteropServices__FieldBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z81mscorlib_System_Runtime_InteropServices__FieldInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Runtime_InteropServices__MethodBase_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85mscorlib_System_Runtime_InteropServices__MethodBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Runtime_InteropServices__MethodInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_System_Runtime_InteropServices__Module_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85mscorlib_System_Runtime_InteropServices__ModuleBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z88mscorlib_System_Runtime_InteropServices__ParameterBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85mscorlib_System_Runtime_InteropServices__ParameterInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_Runtime_InteropServices__PropertyBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z84mscorlib_System_Runtime_InteropServices__PropertyInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_System_Runtime_InteropServices__Thread_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z83mscorlib_System_Runtime_InteropServices__TypeBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_System_Runtime_Remoting_Activation_ConstructionLevelActivator_m__ctorP70mscorlib_System_Runtime_Remoting_Activation_ConstructionLevelActivator,__Z85mscorlib_System_Runtime_Remoting_Activation_IActivator_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z99mscorlib_System_Runtime_Remoting_Activation_IConstructionCallMessage_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z173mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_GetPropertiesForNewContextP21CustomAttributesCache,__Z158mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_IsContextOKP21CustomAttributesCache,__Z87mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z52mscorlib_System_Runtime_Remoting_ChannelInfo_m__ctorP44mscorlib_System_Runtime_Remoting_ChannelInfo,__Z66mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m__cctorP22mscorlib_System_Object,__Z236mscorlib_System_Runtime_Remoting_Channels_ChannelServices_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m_RegisterChannel_mscorlib_System_Void_mscorlib_System_Runtime_Remoting_Channels_IChannelP21CustomAttributesCache,__Z88mscorlib_System_Runtime_Remoting_Channels_ChannelServices_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z71mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m__ctorP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel,__Z72mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m__cctorP22mscorlib_System_Object,__Z95mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_RegisterCrossAppDomainChannelP22mscorlib_System_Object,__Z81mscorlib_System_Runtime_Remoting_Channels_IChannel_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z89mscorlib_System_Runtime_Remoting_Channels_IChannelReceiver_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_Runtime_Remoting_Channels_IChannelSender_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z58mscorlib_System_Runtime_Remoting_Contexts_Context_m__cctorP22mscorlib_System_Object,__Z60mscorlib_System_Runtime_Remoting_Contexts_Context_m_FinalizeP49mscorlib_System_Runtime_Remoting_Contexts_Context
  ,__Z80mscorlib_System_Runtime_Remoting_Contexts_Context_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z89mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_Runtime_Remoting_Contexts_CrossContextChannel_m__ctorP61mscorlib_System_Runtime_Remoting_Contexts_CrossContextChannel,__Z90mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z89mscorlib_System_Runtime_Remoting_Contexts_IContextProperty_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z90mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_Runtime_Remoting_Messaging_EnvoyTerminatorSink_m__ctorP62mscorlib_System_Runtime_Remoting_Messaging_EnvoyTerminatorSink,__Z71mscorlib_System_Runtime_Remoting_Messaging_EnvoyTerminatorSink_m__cctorP22mscorlib_System_Object,__Z82mscorlib_System_Runtime_Remoting_Messaging_IMessage_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z86mscorlib_System_Runtime_Remoting_Messaging_IMessageSink_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z92mscorlib_System_Runtime_Remoting_Messaging_IMethodCallMessage_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z88mscorlib_System_Runtime_Remoting_Messaging_IMethodMessage_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z92mscorlib_System_Runtime_Remoting_Messaging_IRemotingFormatter_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContext_m__ctorP61mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContext,__Z92mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContext_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_Runtime_Remoting_Messaging_CallContextRemotingData_m__ctorP66mscorlib_System_Runtime_Remoting_Messaging_CallContextRemotingData,__Z61mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m__ctorP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z69mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_ResolveMethodP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z84mscorlib_System_Runtime_Remoting_Messaging_MethodCall_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogate_m__ctorP60mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogate,__Z66mscorlib_System_Runtime_Remoting_Messaging_ObjRefSurrogate_m__ctorP58mscorlib_System_Runtime_Remoting_Messaging_ObjRefSurrogate,__Z76mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogateSelector_m__ctorP68mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogateSelector,__Z77mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogateSelector_m__cctorP22mscorlib_System_Object,__Z99mscorlib_System_Runtime_Remoting_Messaging_RemotingSurrogateSelector_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z171mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_GetPropertiesForNewContextP21CustomAttributesCache,__Z156mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_IsContextOKP21CustomAttributesCache,__Z86mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Runtime_Remoting_Proxies_RealProxy_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z63mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy_m__cctorP22mscorlib_System_Object,__Z65mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy_m_FinalizeP54mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy
  ,__Z88mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_Runtime_Remoting_IChannelInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_Runtime_Remoting_IEnvoyInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Runtime_Remoting_IRemotingTypeInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z47mscorlib_System_Runtime_Remoting_ObjRef_m__ctorP39mscorlib_System_Runtime_Remoting_ObjRef,__Z48mscorlib_System_Runtime_Remoting_ObjRef_m__cctorP22mscorlib_System_Object,__Z59mscorlib_System_Runtime_Remoting_ObjRef_m_UpdateChannelInfoP39mscorlib_System_Runtime_Remoting_ObjRef,__Z70mscorlib_System_Runtime_Remoting_ObjRef_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z63mscorlib_System_Runtime_Remoting_RemotingConfiguration_m__cctorP22mscorlib_System_Object,__Z85mscorlib_System_Runtime_Remoting_RemotingConfiguration_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Runtime_Remoting_RemotingException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z58mscorlib_System_Runtime_Remoting_RemotingServices_m__cctorP22mscorlib_System_Object,__Z76mscorlib_System_Runtime_Remoting_RemotingServices_m_RegisterInternalChannelsP22mscorlib_System_Object,__Z80mscorlib_System_Runtime_Remoting_RemotingServices_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z73mscorlib_System_Runtime_Remoting_TypeEntry_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z83mscorlib_System_Runtime_Remoting_WellKnownObjectMode_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z102mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatter_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z102mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z98mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z95mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z93mscorlib_System_Runtime_Serialization_IDeserializationCallback_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z79mscorlib_System_Runtime_Serialization_IFormatter_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z88mscorlib_System_Runtime_Serialization_IFormatterConverter_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85mscorlib_System_Runtime_Serialization_IObjectReference_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z92mscorlib_System_Runtime_Serialization_ISerializationSurrogate_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_Runtime_Serialization_ISurrogateSelector_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_Runtime_Serialization_SerializationEntry_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z91mscorlib_System_Runtime_Serialization_SerializationException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z220mscorlib_System_Runtime_Serialization_SerializationInfo_CustomAttributesCacheGenerator_mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_UInt64P21CustomAttributesCache,__Z86mscorlib_System_Runtime_Serialization_SerializationInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z85mscorlib_System_Runtime_Serialization_StreamingContext_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z91mscorlib_System_Runtime_Serialization_StreamingContextStates_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z86mscorlib_System_Security_Cryptography_AsymmetricAlgorithm_m_System_IDisposable_DisposeP57mscorlib_System_Security_Cryptography_AsymmetricAlgorithm,__Z88mscorlib_System_Security_Cryptography_AsymmetricAlgorithm_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_Security_Cryptography_CryptoConfig_m__cctorP22mscorlib_System_Object,__Z63mscorlib_System_Security_Cryptography_CryptoConfig_m_InitializeP22mscorlib_System_Object,__Z81mscorlib_System_Security_Cryptography_CryptoConfig_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z91mscorlib_System_Security_Cryptography_CryptographicException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z80mscorlib_System_Security_Cryptography_HashAlgorithm_m_System_IDisposable_DisposeP51mscorlib_System_Security_Cryptography_HashAlgorithm,__Z82mscorlib_System_Security_Cryptography_HashAlgorithm_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85mscorlib_System_Security_Cryptography_ICryptoTransform_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m__ctorP62mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider,__Z71mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m__cctorP22mscorlib_System_Object,__Z70mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_CheckP62mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider,__Z73mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_FinalizeP62mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider,__Z72mscorlib_System_Security_Cryptography_RSA_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z82mscorlib_System_Security_Cryptography_RSAParameters_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z67mscorlib_System_Security_Cryptography_RandomNumberGenerator_m__ctorP59mscorlib_System_Security_Cryptography_RandomNumberGenerator,__Z79mscorlib_System_Security_Policy_ApplicationTrust_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z121mscorlib_System_Security_Policy_Evidence_CustomAttributesCacheGenerator_mscorlib_System_Security_Policy_Evidence_m_EqualsP21CustomAttributesCache,__Z126mscorlib_System_Security_Policy_Evidence_CustomAttributesCacheGenerator_mscorlib_System_Security_Policy_Evidence_m_GetHashCodeP21CustomAttributesCache,__Z71mscorlib_System_Security_Policy_Evidence_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z67mscorlib_System_Security_Policy_Hash_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_Security_Principal_IPrincipal_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_Security_Principal_PrincipalPolicy_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z67mscorlib_System_Security_IPermission_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_Security_ISecurityEncodable_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z49mscorlib_System_Security_SecurityElement_m__cctorP22mscorlib_System_Object,__Z71mscorlib_System_Security_SecurityElement_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z73mscorlib_System_Security_SecurityException_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z144mscorlib_System_Security_SecurityException_CustomAttributesCacheGenerator_mscorlib_System_Security_SecurityExceptionTraits_Demanded_PropertyInfoP21CustomAttributesCache,__Z62mscorlib_System_Security_SecuritySafeCriticalAttribute_m__ctorP54mscorlib_System_Security_SecuritySafeCriticalAttribute,__Z85mscorlib_System_Security_SecuritySafeCriticalAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z71mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m__ctorP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__Z94mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z58mscorlib_System_Security_UnverifiableCodeAttribute_m__ctorP50mscorlib_System_Security_UnverifiableCodeAttribute,__Z81mscorlib_System_Security_UnverifiableCodeAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z42mscorlib_System_Text_ASCIIEncoding_m__ctorP34mscorlib_System_Text_ASCIIEncoding,__Z237mscorlib_System_Text_ASCIIEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_ASCIIEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z189mscorlib_System_Text_ASCIIEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_ASCIIEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z65mscorlib_System_Text_ASCIIEncoding_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_Text_Decoder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z122mscorlib_System_Text_Decoder_CustomAttributesCacheGenerator_mscorlib_System_Text_DecoderTraits_FallbackBuffer_PropertyInfoP21CustomAttributesCache,__Z53mscorlib_System_Text_DecoderExceptionFallback_m__ctorP45mscorlib_System_Text_DecoderExceptionFallback,__Z59mscorlib_System_Text_DecoderExceptionFallbackBuffer_m__ctorP51mscorlib_System_Text_DecoderExceptionFallbackBuffer,__Z44mscorlib_System_Text_DecoderFallback_m__ctorP36mscorlib_System_Text_DecoderFallback,__Z45mscorlib_System_Text_DecoderFallback_m__cctorP22mscorlib_System_Object,__Z50mscorlib_System_Text_DecoderFallbackBuffer_m__ctorP42mscorlib_System_Text_DecoderFallbackBuffer,__Z50mscorlib_System_Text_DecoderFallbackBuffer_m_ResetP42mscorlib_System_Text_DecoderFallbackBuffer,__Z76mscorlib_System_Text_DecoderReplacementFallback_m__ctor_mscorlib_System_VoidP47mscorlib_System_Text_DecoderReplacementFallback,__Z178mscorlib_System_Text_DecoderReplacementFallback_CustomAttributesCacheGenerator_mscorlib_System_Text_DecoderReplacementFallback_m__ctor_mscorlib_System_Void_mscorlib_System_StringP21CustomAttributesCache,__Z61mscorlib_System_Text_DecoderReplacementFallbackBuffer_m_ResetP53mscorlib_System_Text_DecoderReplacementFallbackBuffer,__Z53mscorlib_System_Text_EncoderExceptionFallback_m__ctorP45mscorlib_System_Text_EncoderExceptionFallback,__Z59mscorlib_System_Text_EncoderExceptionFallbackBuffer_m__ctorP51mscorlib_System_Text_EncoderExceptionFallbackBuffer,__Z44mscorlib_System_Text_EncoderFallback_m__ctorP36mscorlib_System_Text_EncoderFallback,__Z45mscorlib_System_Text_EncoderFallback_m__cctorP22mscorlib_System_Object,__Z50mscorlib_System_Text_EncoderFallbackBuffer_m__ctorP42mscorlib_System_Text_EncoderFallbackBuffer,__Z76mscorlib_System_Text_EncoderReplacementFallback_m__ctor_mscorlib_System_VoidP47mscorlib_System_Text_EncoderReplacementFallback,__Z178mscorlib_System_Text_EncoderReplacementFallback_CustomAttributesCacheGenerator_mscorlib_System_Text_EncoderReplacementFallback_m__ctor_mscorlib_System_Void_mscorlib_System_StringP21CustomAttributesCache,__Z38mscorlib_System_Text_Encoding_m__cctorP22mscorlib_System_Object
  ,__Z179mscorlib_System_Text_Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z227mscorlib_System_Text_Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z60mscorlib_System_Text_Encoding_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z125mscorlib_System_Text_Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_EncodingTraits_DecoderFallback_PropertyInfoP21CustomAttributesCache,__Z125mscorlib_System_Text_Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_EncodingTraits_EncoderFallback_PropertyInfoP21CustomAttributesCache,__Z43mscorlib_System_Text_Latin1Encoding_m__ctorP35mscorlib_System_Text_Latin1Encoding,__Z63mscorlib_System_Text_StringBuilder_m__ctor_mscorlib_System_VoidP34mscorlib_System_Text_StringBuilder,__Z65mscorlib_System_Text_StringBuilder_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z210mscorlib_System_Text_UTF32Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P21CustomAttributesCache,__Z257mscorlib_System_Text_UTF32Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF32Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32P21CustomAttributesCache,__Z189mscorlib_System_Text_UTF32Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z237mscorlib_System_Text_UTF32Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF32Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z62mscorlib_System_Text_UTF7Encoding_m__ctor_mscorlib_System_VoidP33mscorlib_System_Text_UTF7Encoding,__Z42mscorlib_System_Text_UTF7Encoding_m__cctorP22mscorlib_System_Object,__Z112mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetHashCodeP21CustomAttributesCache,__Z107mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_EqualsP21CustomAttributesCache,__Z187mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z158mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP21CustomAttributesCache,__Z235mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z110mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF7Encoding_m_GetStringP21CustomAttributesCache,__Z64mscorlib_System_Text_UTF7Encoding_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z187mscorlib_System_Text_UTF8Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF8Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z235mscorlib_System_Text_UTF8Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF8Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z110mscorlib_System_Text_UTF8Encoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UTF8Encoding_m_GetStringP21CustomAttributesCache,__Z64mscorlib_System_Text_UTF8Encoding_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z193mscorlib_System_Text_UnicodeEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UnicodeEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z241mscorlib_System_Text_UnicodeEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UnicodeEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P21CustomAttributesCache,__Z116mscorlib_System_Text_UnicodeEncoding_CustomAttributesCacheGenerator_mscorlib_System_Text_UnicodeEncoding_m_GetStringP21CustomAttributesCache,__Z67mscorlib_System_Text_UnicodeEncoding_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z132mscorlib_System_Threading_ExecutionContext_CustomAttributesCacheGenerator_mscorlib_System_Threading_ExecutionContext_m_GetObjectDataP21CustomAttributesCache
  ,__Z124mscorlib_System_Threading_Interlocked_CustomAttributesCacheGenerator_mscorlib_System_Threading_Interlocked_m_CompareExchangeP21CustomAttributesCache,__Z118mscorlib_System_Threading_Interlocked_CustomAttributesCacheGenerator_mscorlib_System_Threading_Interlocked_m_IncrementP21CustomAttributesCache,__Z105mscorlib_System_Threading_Monitor_CustomAttributesCacheGenerator_mscorlib_System_Threading_Monitor_m_ExitP21CustomAttributesCache,__Z64mscorlib_System_Threading_Monitor_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z41mscorlib_System_Threading_Thread_m__cctorP22mscorlib_System_Object,__Z43mscorlib_System_Threading_Thread_m_FinalizeP32mscorlib_System_Threading_Thread,__Z75mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_local_slotsP21CustomAttributesCache,__Z67mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator__ecP21CustomAttributesCache,__Z116mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_mscorlib_System_Threading_Thread_m_get_CurrentThreadP21CustomAttributesCache,__Z107mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_mscorlib_System_Threading_Thread_m_FinalizeP21CustomAttributesCache,__Z118mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_mscorlib_System_Threading_Thread_m_get_ManagedThreadIdP21CustomAttributesCache,__Z110mscorlib_System_Threading_Thread_CustomAttributesCacheGenerator_mscorlib_System_Threading_Thread_m_GetHashCodeP21CustomAttributesCache,__Z63mscorlib_System_Threading_Thread_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z77mscorlib_System_Threading_ThreadAbortException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_Threading_ThreadState_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z45mscorlib_System_Threading_WaitHandle_m__cctorP22mscorlib_System_Object,__Z65mscorlib_System_Threading_WaitHandle_m_System_IDisposable_DisposeP36mscorlib_System_Threading_WaitHandle,__Z47mscorlib_System_Threading_WaitHandle_m_FinalizeP36mscorlib_System_Threading_WaitHandle,__Z67mscorlib_System_Threading_WaitHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z71mscorlib_System_AccessViolationException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z44mscorlib_System_ActivationContext_m_FinalizeP33mscorlib_System_ActivationContext,__Z64mscorlib_System_ActivationContext_m_Dispose_mscorlib_System_VoidP33mscorlib_System_ActivationContext,__Z157mscorlib_System_ActivationContext_CustomAttributesCacheGenerator_mscorlib_System_ActivationContext_m_System_Runtime_Serialization_ISerializable_GetObjectDataP21CustomAttributesCache,__Z64mscorlib_System_ActivationContext_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z56mscorlib_System_Activator_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z81mscorlib_System_AppDomain_CustomAttributesCacheGenerator_type_resolve_in_progressP21CustomAttributesCache,__Z85mscorlib_System_AppDomain_CustomAttributesCacheGenerator_assembly_resolve_in_progressP21CustomAttributesCache,__Z93mscorlib_System_AppDomain_CustomAttributesCacheGenerator_assembly_resolve_in_progress_refonlyP21CustomAttributesCache,__Z67mscorlib_System_AppDomain_CustomAttributesCacheGenerator__principalP21CustomAttributesCache,__Z56mscorlib_System_AppDomain_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z63mscorlib_System_AppDomainManager_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z61mscorlib_System_AppDomainSetup_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z161mscorlib_System_ApplicationIdentity_CustomAttributesCacheGenerator_mscorlib_System_ApplicationIdentity_m_System_Runtime_Serialization_ISerializable_GetObjectDataP21CustomAttributesCache,__Z66mscorlib_System_ApplicationIdentity_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z62mscorlib_System_ArgumentException_m__ctor_mscorlib_System_VoidP33mscorlib_System_ArgumentException,__Z64mscorlib_System_ArgumentException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_ArgumentNullException_m__ctor_mscorlib_System_VoidP37mscorlib_System_ArgumentNullException,__Z68mscorlib_System_ArgumentNullException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z72mscorlib_System_ArgumentOutOfRangeException_m__ctor_mscorlib_System_VoidP43mscorlib_System_ArgumentOutOfRangeException,__Z74mscorlib_System_ArgumentOutOfRangeException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_ArithmeticException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z71mscorlib_System_ArrayTypeMismatchException_m__ctor_mscorlib_System_VoidP42mscorlib_System_ArrayTypeMismatchException,__Z73mscorlib_System_ArrayTypeMismatchException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_AssemblyLoadEventArgs_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z63mscorlib_System_AttributeTargets_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z37mscorlib_System_BitConverter_m__cctorP22mscorlib_System_Object,__Z53mscorlib_System_Buffer_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_CharEnumerator_m_System_IDisposable_DisposeP30mscorlib_System_CharEnumerator,__Z61mscorlib_System_CharEnumerator_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z65mscorlib_System_ContextBoundObject_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z32mscorlib_System_Convert_m__cctorP22mscorlib_System_Object,__Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_SByteP21CustomAttributesCache,__Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt32P21CustomAttributesCache,__Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt64P21CustomAttributesCache,__Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt16P21CustomAttributesCache,__Z130mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_SByteP21CustomAttributesCache,__Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt32P21CustomAttributesCache,__Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt64P21CustomAttributesCache,__Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt16P21CustomAttributesCache,__Z130mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_SByteP21CustomAttributesCache
  ,__Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt32P21CustomAttributesCache,__Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt64P21CustomAttributesCache,__Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt16P21CustomAttributesCache,__Z138mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_SByteP21CustomAttributesCache,__Z139mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt16P21CustomAttributesCache,__Z139mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt32P21CustomAttributesCache,__Z139mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt64P21CustomAttributesCache,__Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_SByteP21CustomAttributesCache,__Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt32P21CustomAttributesCache,__Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt64P21CustomAttributesCache,__Z137mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt16P21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_SByteP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt32P21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt64P21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToDouble_mscorlib_System_Double_mscorlib_System_UInt16P21CustomAttributesCache,__Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_SByteP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt32P21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt64P21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt16P21CustomAttributesCache,__Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_SByteP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt32P21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt64P21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt16P21CustomAttributesCache,__Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_SByteP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt32P21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt64P21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt16P21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_BooleanP21CustomAttributesCache,__Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_ByteP21CustomAttributesCache,__Z131mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_CharP21CustomAttributesCache
  ,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_DecimalP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_DoubleP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_SingleP21CustomAttributesCache,__Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int32P21CustomAttributesCache,__Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int64P21CustomAttributesCache,__Z132mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int16P21CustomAttributesCache,__Z165mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt32P21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt64P21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt16P21CustomAttributesCache,__Z165mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Object_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_SByteP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt32P21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt64P21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToSingle_mscorlib_System_Single_mscorlib_System_UInt16P21CustomAttributesCache,__Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_BooleanP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_ByteP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_CharP21CustomAttributesCache,__Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_DecimalP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_DoubleP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_SingleP21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int32P21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int64P21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_SByteP21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int16P21CustomAttributesCache,__Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_UInt32P21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_UInt64P21CustomAttributesCache,__Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Object_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_BooleanP21CustomAttributesCache
  ,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_ByteP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_CharP21CustomAttributesCache,__Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_DecimalP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_DoubleP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_SingleP21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int32P21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int64P21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_SByteP21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int16P21CustomAttributesCache,__Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_UInt64P21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_UInt16P21CustomAttributesCache,__Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Object_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_BooleanP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_ByteP21CustomAttributesCache,__Z133mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_CharP21CustomAttributesCache,__Z136mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_DecimalP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_DoubleP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_SingleP21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int32P21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int64P21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_SByteP21CustomAttributesCache,__Z134mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int16P21CustomAttributesCache,__Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_UInt32P21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_UInt16P21CustomAttributesCache,__Z135mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_ObjectP21CustomAttributesCache,__Z167mscorlib_System_Convert_CustomAttributesCacheGenerator_mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Object_mscorlib_System_IFormatProviderP21CustomAttributesCache,__Z30mscorlib_System_DBNull_m__ctorP22mscorlib_System_DBNull,__Z31mscorlib_System_DBNull_m__cctorP22mscorlib_System_Object
  ,__Z53mscorlib_System_DBNull_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z33mscorlib_System_DateTime_m__cctorP22mscorlib_System_Object,__Z59mscorlib_System_DateTimeKind_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z39mscorlib_System_DateTimeOffset_m__cctorP22mscorlib_System_Object,__Z56mscorlib_System_DayOfWeek_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z45mscorlib_System_DivideByZeroException_m__ctorP37mscorlib_System_DivideByZeroException,__Z68mscorlib_System_DivideByZeroException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z44mscorlib_System_DllNotFoundException_m__ctorP36mscorlib_System_DllNotFoundException,__Z67mscorlib_System_DllNotFoundException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z51mscorlib_System_EntryPointNotFoundException_m__ctorP43mscorlib_System_EntryPointNotFoundException,__Z74mscorlib_System_EntryPointNotFoundException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z50mscorlib_System_MonoEnumInfo_SByteComparer_m__ctorP42mscorlib_System_MonoEnumInfo_SByteComparer,__Z50mscorlib_System_MonoEnumInfo_ShortComparer_m__ctorP42mscorlib_System_MonoEnumInfo_ShortComparer,__Z48mscorlib_System_MonoEnumInfo_IntComparer_m__ctorP40mscorlib_System_MonoEnumInfo_IntComparer,__Z49mscorlib_System_MonoEnumInfo_LongComparer_m__ctorP41mscorlib_System_MonoEnumInfo_LongComparer,__Z37mscorlib_System_MonoEnumInfo_m__cctorP22mscorlib_System_Object,__Z65mscorlib_System_MonoEnumInfo_CustomAttributesCacheGenerator_cacheP21CustomAttributesCache,__Z58mscorlib_System_Environment_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z33mscorlib_System_EventArgs_m__ctorP25mscorlib_System_EventArgs,__Z34mscorlib_System_EventArgs_m__cctorP22mscorlib_System_Object,__Z56mscorlib_System_EventArgs_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z67mscorlib_System_FieldAccessException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z38mscorlib_System_FlagsAttribute_m__ctorP30mscorlib_System_FlagsAttribute,__Z61mscorlib_System_FlagsAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z60mscorlib_System_FormatException_m__ctor_mscorlib_System_VoidP31mscorlib_System_FormatException,__Z62mscorlib_System_FormatException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z87mscorlib_System_GC_CustomAttributesCacheGenerator_mscorlib_System_GC_m_SuppressFinalizeP21CustomAttributesCache,__Z29mscorlib_System_Guid_m__cctorP22mscorlib_System_Object,__Z51mscorlib_System_Guid_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z63mscorlib_System_ICustomFormatter_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z62mscorlib_System_IFormatProvider_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_IndexOutOfRangeException_m__ctor_mscorlib_System_VoidP40mscorlib_System_IndexOutOfRangeException,__Z71mscorlib_System_IndexOutOfRangeException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z65mscorlib_System_InvalidCastException_m__ctor_mscorlib_System_VoidP36mscorlib_System_InvalidCastException,__Z67mscorlib_System_InvalidCastException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_InvalidOperationException_m__ctor_mscorlib_System_VoidP41mscorlib_System_InvalidOperationException,__Z72mscorlib_System_InvalidOperationException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z76mscorlib_System_LoaderOptimization_CustomAttributesCacheGenerator_DomainMaskP21CustomAttributesCache,__Z82mscorlib_System_LoaderOptimization_CustomAttributesCacheGenerator_DisallowBindingsP21CustomAttributesCache,__Z65mscorlib_System_LoaderOptimization_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_System_Math_CustomAttributesCacheGenerator_mscorlib_System_Math_m_MaxP21CustomAttributesCache,__Z78mscorlib_System_Math_CustomAttributesCacheGenerator_mscorlib_System_Math_m_MinP21CustomAttributesCache,__Z79mscorlib_System_Math_CustomAttributesCacheGenerator_mscorlib_System_Math_m_SqrtP21CustomAttributesCache,__Z66mscorlib_System_MemberAccessException_m__ctor_mscorlib_System_VoidP37mscorlib_System_MemberAccessException,__Z68mscorlib_System_MemberAccessException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_MethodAccessException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_MissingFieldException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_MissingMemberException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z69mscorlib_System_MissingMethodException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z40mscorlib_System_MonoCustomAttrs_m__cctorP22mscorlib_System_Object,__Z43mscorlib_System_MonoTouchAOTHelper_m__cctorP22mscorlib_System_Object,__Z36mscorlib_System_MonoTypeInfo_m__ctorP28mscorlib_System_MonoTypeInfo,__Z77mscorlib_System_MulticastNotSupportedException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z46mscorlib_System_NonSerializedAttribute_m__ctorP38mscorlib_System_NonSerializedAttribute,__Z69mscorlib_System_NonSerializedAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_NotImplementedException_m__ctor_mscorlib_System_VoidP39mscorlib_System_NotImplementedException,__Z70mscorlib_System_NotImplementedException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_NotSupportedException_m__ctor_mscorlib_System_VoidP37mscorlib_System_NotSupportedException,__Z68mscorlib_System_NotSupportedException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z67mscorlib_System_NullReferenceException_m__ctor_mscorlib_System_VoidP38mscorlib_System_NullReferenceException
  ,__Z69mscorlib_System_NullReferenceException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z50mscorlib_System_NumberFormatter_CustomInfo_m__ctorP42mscorlib_System_NumberFormatter_CustomInfo,__Z40mscorlib_System_NumberFormatter_m__cctorP22mscorlib_System_Object,__Z53mscorlib_System_NumberFormatter_m_RemoveTrailingZerosP31mscorlib_System_NumberFormatter,__Z69mscorlib_System_NumberFormatter_m_AddOneToDecHex_mscorlib_System_VoidP31mscorlib_System_NumberFormatter,__Z41mscorlib_System_NumberFormatter_m_ReleaseP31mscorlib_System_NumberFormatter,__Z84mscorlib_System_NumberFormatter_CustomAttributesCacheGenerator_threadNumberFormatterP21CustomAttributesCache,__Z70mscorlib_System_ObjectDisposedException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z62mscorlib_System_OperatingSystem_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z44mscorlib_System_OutOfMemoryException_m__ctorP36mscorlib_System_OutOfMemoryException,__Z67mscorlib_System_OutOfMemoryException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z62mscorlib_System_OverflowException_m__ctor_mscorlib_System_VoidP33mscorlib_System_OverflowException,__Z64mscorlib_System_OverflowException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z57mscorlib_System_PlatformID_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z58mscorlib_System_RankException_m__ctor_mscorlib_System_VoidP29mscorlib_System_RankException,__Z60mscorlib_System_RankException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z63mscorlib_System_ResolveEventArgs_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z111mscorlib_System_RuntimeMethodHandle_CustomAttributesCacheGenerator_mscorlib_System_RuntimeMethodHandle_m_EqualsP21CustomAttributesCache,__Z66mscorlib_System_RuntimeMethodHandle_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z38mscorlib_System_StringComparer_m__ctorP30mscorlib_System_StringComparer,__Z39mscorlib_System_StringComparer_m__cctorP22mscorlib_System_Object,__Z61mscorlib_System_StringComparer_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z62mscorlib_System_SystemException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z45mscorlib_System_ThreadStaticAttribute_m__ctorP37mscorlib_System_ThreadStaticAttribute,__Z68mscorlib_System_ThreadStaticAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z33mscorlib_System_TimeSpan_m__cctorP22mscorlib_System_Object,__Z55mscorlib_System_TimeSpan_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z32mscorlib_System_TimeZone_m__ctorP24mscorlib_System_TimeZone,__Z33mscorlib_System_TimeZone_m__cctorP22mscorlib_System_Object,__Z55mscorlib_System_TimeZone_CustomAttributesCacheGeneratorP21CustomAttributesCache
  ,__Z55mscorlib_System_TypeCode_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_TypeInitializationException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z62mscorlib_System_TypeLoadException_m__ctor_mscorlib_System_VoidP33mscorlib_System_TypeLoadException,__Z64mscorlib_System_TypeLoadException_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z74mscorlib_System_UnhandledExceptionEventArgs_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z54mscorlib_System_Version_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70mscorlib_System_Reflection_MemberFilter_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z68mscorlib_System_Reflection_TypeFilter_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z67mscorlib_System_AppDomainInitializer_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z71mscorlib_System_AssemblyLoadEventHandler_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z59mscorlib_System_EventHandler_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z66mscorlib_System_ResolveEventHandler_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z77mscorlib_System_UnhandledExceptionEventHandler_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z78mscorlib_U003CPrivateImplementationDetailsU003E_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z70System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m__ctorP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__Z93System_Core_System_Runtime_CompilerServices_ExtensionAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z44System_Core_System_MonoTODOAttribute_m__ctorP36System_Core_System_MonoTODOAttribute,__Z67System_Core_System_MonoTODOAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z144System_Core_System_Collections_Generic_HashSet_1_CustomAttributesCacheGenerator_System_Core_System_Collections_Generic_HashSet_1_m_GetObjectDataP21CustomAttributesCache,__Z81System_Core_U003CPrivateImplementationDetailsU003E_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z72System_System_Collections_Generic_Stack_1_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z48UnityEngine_UnityEngine_WrapperlessIcall_m__ctorP40UnityEngine_UnityEngine_WrapperlessIcall,__Z54UnityEngine_UnityEngine_AttributeHelperEngine_m__cctorP22mscorlib_System_Object,__Z46UnityEngine_UnityEngine_SetupCoroutine_m__ctorP38UnityEngine_UnityEngine_SetupCoroutine,__Z49UnityEngine_UnityEngine_WritableAttribute_m__ctorP41UnityEngine_UnityEngine_WritableAttribute,__Z72UnityEngine_UnityEngine_WritableAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z56UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m__ctorP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__Z79UnityEngine_UnityEngine_AssemblyIsEditorAssembly_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z51UnityEngine_UnityEngine_GUI_ScrollViewState_m__ctorP43UnityEngine_UnityEngine_GUI_ScrollViewState,__Z36UnityEngine_UnityEngine_GUI_m__cctorP22mscorlib_System_Object
  ,__Z102UnityEngine_UnityEngine_GUI_CustomAttributesCacheGenerator_U003CnextScrollStepTimeU003Ek__BackingFieldP21CustomAttributesCache,__Z100UnityEngine_UnityEngine_GUI_CustomAttributesCacheGenerator_U003CscrollTroughSideU003Ek__BackingFieldP21CustomAttributesCache,__Z111UnityEngine_UnityEngine_GUI_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUI_m_set_nextScrollStepTimeP21CustomAttributesCache,__Z100UnityEngine_UnityEngine_GUI_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUI_m_set_changedP21CustomAttributesCache,__Z48UnityEngine_UnityEngine_SendMouseEvents_m__cctorP22mscorlib_System_Object,__Z43UnityEngine_UnityEngine_SliderState_m__ctorP35UnityEngine_UnityEngine_SliderState,__Z49UnityEngine_UnityEngine_StackTraceUtility_m__ctorP41UnityEngine_UnityEngine_StackTraceUtility,__Z50UnityEngine_UnityEngine_StackTraceUtility_m__cctorP22mscorlib_System_Object,__Z67UnityEngine_UnityEngine_UnityException_m__ctor_mscorlib_System_VoidP38UnityEngine_UnityEngine_UnityException,__Z53UnityEngine_UnityEngine_StateMachineBehaviour_m__ctorP45UnityEngine_UnityEngine_StateMachineBehaviour,__Z42UnityEngine_UnityEngine_TextEditor_m__ctorP34UnityEngine_UnityEngine_TextEditor,__Z66UnityEngine_UnityEngine_TextGenerator_m__ctor_mscorlib_System_VoidP37UnityEngine_UnityEngine_TextGenerator,__Z66UnityEngine_UnityEngine_TextGenerator_m_System_IDisposable_DisposeP37UnityEngine_UnityEngine_TextGenerator,__Z50UnityEngine_UnityEngine_TextGenerator_m_InvalidateP37UnityEngine_UnityEngine_TextGenerator,__Z44UnityEngine_UnityEngine_TextGenerator_m_InitP37UnityEngine_UnityEngine_TextGenerator,__Z51UnityEngine_UnityEngine_TextGenerator_m_Dispose_cppP37UnityEngine_UnityEngine_TextGenerator,__Z48UnityEngine_UnityEngine_TextGenerator_m_FinalizeP37UnityEngine_UnityEngine_TextGenerator,__Z113UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_InitP21CustomAttributesCache,__Z120UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_Dispose_cppP21CustomAttributesCache,__Z144UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_INTERNAL_CALL_Populate_Internal_cppP21CustomAttributesCache,__Z124UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_rectExtentsP21CustomAttributesCache,__Z124UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_vertexCountP21CustomAttributesCache,__Z128UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetVerticesInternalP21CustomAttributesCache,__Z125UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetVerticesArrayP21CustomAttributesCache,__Z127UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_characterCountP21CustomAttributesCache,__Z130UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetCharactersInternalP21CustomAttributesCache,__Z127UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetCharactersArrayP21CustomAttributesCache,__Z122UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_lineCountP21CustomAttributesCache,__Z125UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetLinesInternalP21CustomAttributesCache,__Z122UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_GetLinesArrayP21CustomAttributesCache
  ,__Z135UnityEngine_UnityEngine_TextGenerator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextGenerator_m_get_fontSizeUsedForBestFitP21CustomAttributesCache,__Z126UnityEngine_UnityEngine_Application_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Application_m_Internal_ExternalCallP21CustomAttributesCache,__Z41UnityEngine_UnityEngine_Component_m__ctorP33UnityEngine_UnityEngine_Component,__Z114UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_get_transformP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_get_gameObjectP21CustomAttributesCache,__Z168UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Component_mscorlib_System_TypeP21CustomAttributesCache,__Z222UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Object_UnityEngine_UnityEngine_SendMessageOptionsP21CustomAttributesCache,__Z156UnityEngine_UnityEngine_Component_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_StringP21CustomAttributesCache,__Z118UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_CreatePrimitiveP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_GetComponentP21CustomAttributesCache,__Z116UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_get_transformP21CustomAttributesCache,__Z110UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_set_tagP21CustomAttributesCache,__Z114UnityEngine_UnityEngine_GameObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GameObject_m_SendMessageP21CustomAttributesCache,__Z38UnityEngine_UnityEngine_Object_m__ctorP30UnityEngine_UnityEngine_Object,__Z177UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_Destroy_mscorlib_System_Void_UnityEngine_UnityEngine_Object_mscorlib_System_SingleP21CustomAttributesCache,__Z154UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_Destroy_mscorlib_System_Void_UnityEngine_UnityEngine_ObjectP21CustomAttributesCache,__Z103UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_get_nameP21CustomAttributesCache,__Z103UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_set_nameP21CustomAttributesCache,__Z103UnityEngine_UnityEngine_Object_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Object_m_ToStringP21CustomAttributesCache,__Z58UnityEngine_UnityEngine_Events_PersistentCallGroup_m__ctorP50UnityEngine_UnityEngine_Events_PersistentCallGroup,__Z89UnityEngine_UnityEngine_Events_PersistentCallGroup_CustomAttributesCacheGenerator_m_CallsP21CustomAttributesCache,__Z56UnityEngine_UnityEngine_Events_InvokableCallList_m__ctorP48UnityEngine_UnityEngine_Events_InvokableCallList,__Z66UnityEngine_UnityEngine_Events_InvokableCallList_m_ClearPersistentP48UnityEngine_UnityEngine_Events_InvokableCallList,__Z53UnityEngine_UnityEngine_Events_UnityEventBase_m__ctorP45UnityEngine_UnityEngine_Events_UnityEventBase,__Z108UnityEngine_UnityEngine_Events_UnityEventBase_m_UnityEngine_ISerializationCallbackReceiver_OnBeforeSerializeP45UnityEngine_UnityEngine_Events_UnityEventBase,__Z109UnityEngine_UnityEngine_Events_UnityEventBase_m_UnityEngine_ISerializationCallbackReceiver_OnAfterDeserializeP45UnityEngine_UnityEngine_Events_UnityEventBase,__Z68UnityEngine_UnityEngine_Events_UnityEventBase_m_DirtyPersistentCallsP45UnityEngine_UnityEngine_Events_UnityEventBase,__Z94UnityEngine_UnityEngine_Events_UnityEventBase_CustomAttributesCacheGenerator_m_PersistentCallsP21CustomAttributesCache,__Z87UnityEngine_UnityEngine_Events_UnityEventBase_CustomAttributesCacheGenerator_m_TypeNameP21CustomAttributesCache,__Z49UnityEngine_UnityEngine_Events_UnityEvent_m__ctorP41UnityEngine_UnityEngine_Events_UnityEvent
  ,__Z55UnityEngine_UnityEngine_UserAuthorizationDialog_m__ctorP47UnityEngine_UnityEngine_UserAuthorizationDialog,__Z55UnityEngine_UnityEngine_UserAuthorizationDialog_m_StartP47UnityEngine_UnityEngine_UserAuthorizationDialog,__Z55UnityEngine_UnityEngine_UserAuthorizationDialog_m_OnGUIP47UnityEngine_UnityEngine_UserAuthorizationDialog,__Z78UnityEngine_UnityEngine_UserAuthorizationDialog_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85UnityEngine_UnityEngine_Internal_DefaultValueAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z65UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m__ctorP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__Z88UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z85UnityEngine_UnityEngine_RenamedSerializedDataAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z89UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z52UnityEngine_UnityEngineInternal_GenericStack_m__ctorP44UnityEngine_UnityEngineInternal_GenericStack,__Z56UnityEngine_UnityEngine_AssetBundleCreateRequest_m__ctorP48UnityEngine_UnityEngine_AssetBundleCreateRequest,__Z77UnityEngine_UnityEngine_AssetBundleCreateRequest_m_DisableCompatibilityChecksP48UnityEngine_UnityEngine_AssetBundleCreateRequest,__Z146UnityEngine_UnityEngine_AssetBundleCreateRequest_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AssetBundleCreateRequest_m_get_assetBundleP21CustomAttributesCache,__Z157UnityEngine_UnityEngine_AssetBundleCreateRequest_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AssetBundleCreateRequest_m_DisableCompatibilityChecksP21CustomAttributesCache,__Z50UnityEngine_UnityEngine_AssetBundleRequest_m__ctorP42UnityEngine_UnityEngine_AssetBundleRequest,__Z123UnityEngine_UnityEngine_AssetBundle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AssetBundle_m_LoadAsset_InternalP21CustomAttributesCache,__Z136UnityEngine_UnityEngine_AssetBundle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AssetBundle_m_LoadAssetWithSubAssets_InternalP21CustomAttributesCache,__Z112UnityEngine_UnityEngine_LayerMask_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_LayerMask_m_LayerToNameP21CustomAttributesCache,__Z112UnityEngine_UnityEngine_LayerMask_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_LayerMask_m_NameToLayerP21CustomAttributesCache,__Z50UnityEngine_UnityEngine_WaitForFixedUpdate_m__ctorP42UnityEngine_UnityEngine_WaitForFixedUpdate,__Z49UnityEngine_UnityEngine_WaitForEndOfFrame_m__ctorP41UnityEngine_UnityEngine_WaitForEndOfFrame,__Z41UnityEngine_UnityEngine_Coroutine_m__ctorP33UnityEngine_UnityEngine_Coroutine,__Z52UnityEngine_UnityEngine_Coroutine_m_ReleaseCoroutineP33UnityEngine_UnityEngine_Coroutine,__Z44UnityEngine_UnityEngine_Coroutine_m_FinalizeP33UnityEngine_UnityEngine_Coroutine,__Z117UnityEngine_UnityEngine_Coroutine_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Coroutine_m_ReleaseCoroutineP21CustomAttributesCache,__Z80UnityEngine_UnityEngine_DisallowMultipleComponent_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z71UnityEngine_UnityEngine_RequireComponent_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z49UnityEngine_UnityEngine_ExecuteInEditMode_m__ctorP41UnityEngine_UnityEngine_ExecuteInEditMode,__Z48UnityEngine_UnityEngine_ScriptableObject_m__ctorP40UnityEngine_UnityEngine_ScriptableObject,__Z146UnityEngine_UnityEngine_ScriptableObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_ScriptableObject_m_Internal_CreateScriptableObjectP21CustomAttributesCache
  ,__Z193UnityEngine_UnityEngine_ScriptableObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_ScriptableObject_m_CreateInstance_UnityEngine_UnityEngine_ScriptableObject_mscorlib_System_StringP21CustomAttributesCache,__Z137UnityEngine_UnityEngine_ScriptableObject_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_ScriptableObject_m_CreateInstanceFromTypeP21CustomAttributesCache,__Z180UnityEngine_UnityEngine_Resources_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Resources_m_Load_UnityEngine_UnityEngine_Object_mscorlib_System_String_mscorlib_System_TypeP21CustomAttributesCache,__Z111UnityEngine_UnityEngine_Renderer_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Renderer_m_get_materialP21CustomAttributesCache,__Z104UnityEngine_UnityEngine_Screen_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Screen_m_get_widthP21CustomAttributesCache,__Z105UnityEngine_UnityEngine_Screen_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Screen_m_get_heightP21CustomAttributesCache,__Z120UnityEngine_UnityEngine_GUILayer_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUILayer_m_INTERNAL_CALL_HitTestP21CustomAttributesCache,__Z40UnityEngine_UnityEngine_Gradient_m__ctorP32UnityEngine_UnityEngine_Gradient,__Z39UnityEngine_UnityEngine_Gradient_m_InitP32UnityEngine_UnityEngine_Gradient,__Z42UnityEngine_UnityEngine_Gradient_m_CleanupP32UnityEngine_UnityEngine_Gradient,__Z43UnityEngine_UnityEngine_Gradient_m_FinalizeP32UnityEngine_UnityEngine_Gradient,__Z103UnityEngine_UnityEngine_Gradient_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Gradient_m_InitP21CustomAttributesCache,__Z106UnityEngine_UnityEngine_Gradient_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Gradient_m_CleanupP21CustomAttributesCache,__Z60UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z49UnityEngine_UnityEngine_GUILayoutUtility_m__cctorP22mscorlib_System_Object,__Z49UnityEngine_UnityEngine_GUILayoutUtility_m_LayoutP22mscorlib_System_Object,__Z50UnityEngine_UnityEngine_GUILayoutGroup_m_CalcWidthP38UnityEngine_UnityEngine_GUILayoutGroup,__Z51UnityEngine_UnityEngine_GUILayoutGroup_m_CalcHeightP38UnityEngine_UnityEngine_GUILayoutGroup,__Z65UnityEngine_UnityEngine_GUILayoutUtility_m_LayoutFromEditorWindowP22mscorlib_System_Object,__Z137UnityEngine_UnityEngine_GUILayoutUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUILayoutUtility_m_Internal_GetWindowRectP21CustomAttributesCache,__Z148UnityEngine_UnityEngine_GUILayoutUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUILayoutUtility_m_INTERNAL_CALL_Internal_MoveWindowP21CustomAttributesCache,__Z47UnityEngine_UnityEngine_GUILayoutEntry_m__cctorP22mscorlib_System_Object,__Z50UnityEngine_UnityEngine_GUILayoutEntry_m_CalcWidthP38UnityEngine_UnityEngine_GUILayoutEntry,__Z51UnityEngine_UnityEngine_GUILayoutEntry_m_CalcHeightP38UnityEngine_UnityEngine_GUILayoutEntry,__Z46UnityEngine_UnityEngine_GUILayoutGroup_m__ctorP38UnityEngine_UnityEngine_GUILayoutGroup,__Z52UnityEngine_UnityEngine_GUILayoutGroup_m_ResetCursorP38UnityEngine_UnityEngine_GUILayoutGroup,__Z46UnityEngine_UnityEngine_GUIScrollGroup_m__ctorP38UnityEngine_UnityEngine_GUIScrollGroup,__Z50UnityEngine_UnityEngine_GUIScrollGroup_m_CalcWidthP38UnityEngine_UnityEngine_GUIScrollGroup,__Z51UnityEngine_UnityEngine_GUIScrollGroup_m_CalcHeightP38UnityEngine_UnityEngine_GUIScrollGroup,__Z43UnityEngine_UnityEngine_GUIUtility_m__cctorP22mscorlib_System_Object
  ,__Z53UnityEngine_UnityEngine_GUIUtility_m_Internal_ExitGUIP22mscorlib_System_Object,__Z47UnityEngine_UnityEngine_GUIUtility_m_CheckOnGUIP22mscorlib_System_Object,__Z126UnityEngine_UnityEngine_GUIUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIUtility_m_Internal_GetDefaultSkinP21CustomAttributesCache,__Z119UnityEngine_UnityEngine_GUIUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIUtility_m_Internal_ExitGUIP21CustomAttributesCache,__Z123UnityEngine_UnityEngine_GUIUtility_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIUtility_m_Internal_GetGUIDepthP21CustomAttributesCache,__Z43UnityEngine_UnityEngine_GUISettings_m__ctorP35UnityEngine_UnityEngine_GUISettings,__Z91UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_DoubleClickSelectsWordP21CustomAttributesCache,__Z91UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_TripleClickSelectsLineP21CustomAttributesCache,__Z80UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_CursorColorP21CustomAttributesCache,__Z85UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_CursorFlashSpeedP21CustomAttributesCache,__Z83UnityEngine_UnityEngine_GUISettings_CustomAttributesCacheGenerator_m_SelectionColorP21CustomAttributesCache,__Z60UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate_m_InvokeP51UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate,__Z39UnityEngine_UnityEngine_GUISkin_m__ctorP31UnityEngine_UnityEngine_GUISkin,__Z42UnityEngine_UnityEngine_GUISkin_m_OnEnableP31UnityEngine_UnityEngine_GUISkin,__Z39UnityEngine_UnityEngine_GUISkin_m_ApplyP31UnityEngine_UnityEngine_GUISkin,__Z49UnityEngine_UnityEngine_GUISkin_m_BuildStyleCacheP31UnityEngine_UnityEngine_GUISkin,__Z45UnityEngine_UnityEngine_GUISkin_m_MakeCurrentP31UnityEngine_UnityEngine_GUISkin,__Z69UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_FontP21CustomAttributesCache,__Z68UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_boxP21CustomAttributesCache,__Z71UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_buttonP21CustomAttributesCache,__Z71UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_toggleP21CustomAttributesCache,__Z70UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_labelP21CustomAttributesCache,__Z74UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_textFieldP21CustomAttributesCache,__Z73UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_textAreaP21CustomAttributesCache,__Z71UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_windowP21CustomAttributesCache,__Z81UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalSliderP21CustomAttributesCache,__Z86UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalSliderThumbP21CustomAttributesCache,__Z79UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalSliderP21CustomAttributesCache,__Z84UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalSliderThumbP21CustomAttributesCache,__Z84UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalScrollbarP21CustomAttributesCache
  ,__Z89UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalScrollbarThumbP21CustomAttributesCache,__Z94UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalScrollbarLeftButtonP21CustomAttributesCache,__Z95UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_horizontalScrollbarRightButtonP21CustomAttributesCache,__Z82UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalScrollbarP21CustomAttributesCache,__Z87UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalScrollbarThumbP21CustomAttributesCache,__Z90UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalScrollbarUpButtonP21CustomAttributesCache,__Z92UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_verticalScrollbarDownButtonP21CustomAttributesCache,__Z75UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_ScrollViewP21CustomAttributesCache,__Z77UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_CustomStylesP21CustomAttributesCache,__Z73UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGenerator_m_SettingsP21CustomAttributesCache,__Z62UnityEngine_UnityEngine_GUISkin_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z63UnityEngine_UnityEngine_GUIContent_m__ctor_mscorlib_System_VoidP34UnityEngine_UnityEngine_GUIContent,__Z43UnityEngine_UnityEngine_GUIContent_m__cctorP22mscorlib_System_Object,__Z53UnityEngine_UnityEngine_GUIContent_m_ClearStaticCacheP22mscorlib_System_Object,__Z72UnityEngine_UnityEngine_GUIContent_CustomAttributesCacheGenerator_m_TextP21CustomAttributesCache,__Z73UnityEngine_UnityEngine_GUIContent_CustomAttributesCacheGenerator_m_ImageP21CustomAttributesCache,__Z75UnityEngine_UnityEngine_GUIContent_CustomAttributesCacheGenerator_m_TooltipP21CustomAttributesCache,__Z48UnityEngine_UnityEngine_GUIStyleState_m_FinalizeP37UnityEngine_UnityEngine_GUIStyleState,__Z47UnityEngine_UnityEngine_GUIStyleState_m_CleanupP37UnityEngine_UnityEngine_GUIStyleState,__Z116UnityEngine_UnityEngine_GUIStyleState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyleState_m_CleanupP21CustomAttributesCache,__Z130UnityEngine_UnityEngine_GUIStyleState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyleState_m_GetBackgroundInternalP21CustomAttributesCache,__Z131UnityEngine_UnityEngine_GUIStyleState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyleState_m_INTERNAL_set_textColorP21CustomAttributesCache,__Z63UnityEngine_UnityEngine_RectOffset_m__ctor_mscorlib_System_VoidP34UnityEngine_UnityEngine_RectOffset,__Z45UnityEngine_UnityEngine_RectOffset_m_FinalizeP34UnityEngine_UnityEngine_RectOffset,__Z41UnityEngine_UnityEngine_RectOffset_m_InitP34UnityEngine_UnityEngine_RectOffset,__Z44UnityEngine_UnityEngine_RectOffset_m_CleanupP34UnityEngine_UnityEngine_RectOffset,__Z107UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_InitP21CustomAttributesCache,__Z110UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_CleanupP21CustomAttributesCache,__Z111UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_leftP21CustomAttributesCache,__Z111UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_set_leftP21CustomAttributesCache
  ,__Z112UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_rightP21CustomAttributesCache,__Z112UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_set_rightP21CustomAttributesCache,__Z110UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_topP21CustomAttributesCache,__Z110UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_set_topP21CustomAttributesCache,__Z113UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_bottomP21CustomAttributesCache,__Z113UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_set_bottomP21CustomAttributesCache,__Z117UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_horizontalP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_RectOffset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_RectOffset_m_get_verticalP21CustomAttributesCache,__Z40UnityEngine_UnityEngine_GUIStyle_m__ctorP32UnityEngine_UnityEngine_GUIStyle,__Z41UnityEngine_UnityEngine_GUIStyle_m__cctorP22mscorlib_System_Object,__Z43UnityEngine_UnityEngine_GUIStyle_m_FinalizeP32UnityEngine_UnityEngine_GUIStyle,__Z39UnityEngine_UnityEngine_GUIStyle_m_InitP32UnityEngine_UnityEngine_GUIStyle,__Z42UnityEngine_UnityEngine_GUIStyle_m_CleanupP32UnityEngine_UnityEngine_GUIStyle,__Z103UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_InitP21CustomAttributesCache,__Z106UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_CleanupP21CustomAttributesCache,__Z107UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_nameP21CustomAttributesCache,__Z107UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_set_nameP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_GetStyleStatePtrP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_GetRectOffsetPtrP21CustomAttributesCache,__Z113UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_fixedWidthP21CustomAttributesCache,__Z114UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_fixedHeightP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_stretchWidthP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_set_stretchWidthP21CustomAttributesCache,__Z116UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_get_stretchHeightP21CustomAttributesCache,__Z116UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_set_stretchHeightP21CustomAttributesCache,__Z113UnityEngine_UnityEngine_GUIStyle_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_GUIStyle_m_SetDefaultFontP21CustomAttributesCache,__Z37UnityEngine_UnityEngine_Event_m__ctorP29UnityEngine_UnityEngine_Event,__Z36UnityEngine_UnityEngine_Event_m_InitP29UnityEngine_UnityEngine_Event,__Z40UnityEngine_UnityEngine_Event_m_FinalizeP29UnityEngine_UnityEngine_Event,__Z39UnityEngine_UnityEngine_Event_m_CleanupP29UnityEngine_UnityEngine_Event
  ,__Z63UnityEngine_UnityEngine_Event_m_Internal_MakeMasterEventCurrentP22mscorlib_System_Object,__Z89UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_U003CU003Ef__switchU0024map0P21CustomAttributesCache,__Z97UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_InitP21CustomAttributesCache,__Z100UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_CleanupP21CustomAttributesCache,__Z101UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_typeP21CustomAttributesCache,__Z118UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_Internal_GetMousePositionP21CustomAttributesCache,__Z106UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_modifiersP21CustomAttributesCache,__Z106UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_characterP21CustomAttributesCache,__Z108UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_commandNameP21CustomAttributesCache,__Z104UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_get_keyCodeP21CustomAttributesCache,__Z116UnityEngine_UnityEngine_Event_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Event_m_Internal_SetNativeEventP21CustomAttributesCache,__Z69UnityEngine_UnityEngine_EventModifiers_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z62UnityEngine_UnityEngine_Vector2_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z116UnityEngine_UnityEngine_Vector3_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Vector3_m_INTERNAL_CALL_SlerpP21CustomAttributesCache,__Z124UnityEngine_UnityEngine_Vector3_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Vector3_m_INTERNAL_CALL_RotateTowardsP21CustomAttributesCache,__Z62UnityEngine_UnityEngine_Vector3_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z60UnityEngine_UnityEngine_Color_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z131UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_FromToRotationP21CustomAttributesCache,__Z182UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_LookRotation_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Vector3P21CustomAttributesCache,__Z129UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_LookRotationP21CustomAttributesCache,__Z124UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_InverseP21CustomAttributesCache,__Z136UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_Internal_ToEulerRadP21CustomAttributesCache,__Z138UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_Internal_FromEulerRadP21CustomAttributesCache,__Z65UnityEngine_UnityEngine_Quaternion_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z122UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_InverseP21CustomAttributesCache,__Z124UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_TransposeP21CustomAttributesCache,__Z121UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_InvertP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_get_isIdentityP21CustomAttributesCache,__Z118UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_TRSP21CustomAttributesCache,__Z106UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_OrthoP21CustomAttributesCache
  ,__Z112UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Matrix4x4_m_PerspectiveP21CustomAttributesCache,__Z64UnityEngine_UnityEngine_Matrix4x4_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z126UnityEngine_UnityEngine_Bounds_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_ContainsP21CustomAttributesCache,__Z129UnityEngine_UnityEngine_Bounds_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_SqrDistanceP21CustomAttributesCache,__Z130UnityEngine_UnityEngine_Bounds_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_IntersectRayP21CustomAttributesCache,__Z133UnityEngine_UnityEngine_Bounds_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_GetClosestPointP21CustomAttributesCache,__Z62UnityEngine_UnityEngine_Vector4_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z54UnityEngine_UnityEngineInternal_MathfInternal_m__cctorP22mscorlib_System_Object,__Z38UnityEngine_UnityEngine_Mathf_m__cctorP22mscorlib_System_Object,__Z227UnityEngine_UnityEngine_Mathf_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Mathf_m_SmoothDamp_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_SingleP21CustomAttributesCache,__Z255UnityEngine_UnityEngine_Mathf_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Mathf_m_SmoothDampAngle_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_Single_mscorlib_System_SingleP21CustomAttributesCache,__Z109UnityEngine_UnityEngine_TextAsset_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_TextAsset_m_get_textP21CustomAttributesCache,__Z57UnityEngine_UnityEngine_SerializePrivateVariables_m__ctorP49UnityEngine_UnityEngine_SerializePrivateVariables,__Z80UnityEngine_UnityEngine_SerializePrivateVariables_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z46UnityEngine_UnityEngine_SerializeField_m__ctorP38UnityEngine_UnityEngine_SerializeField,__Z107UnityEngine_UnityEngine_Shader_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Shader_m_PropertyToIDP21CustomAttributesCache,__Z121UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_INTERNAL_CALL_SetColorP21CustomAttributesCache,__Z159UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_GetColor_UnityEngine_UnityEngine_Color_mscorlib_System_Int32P21CustomAttributesCache,__Z173UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_SetFloat_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_SingleP21CustomAttributesCache,__Z114UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_set_renderQueueP21CustomAttributesCache,__Z112UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_EnableKeywordP21CustomAttributesCache,__Z113UnityEngine_UnityEngine_Material_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Material_m_DisableKeywordP21CustomAttributesCache,__Z39UnityEngine_UnityEngine_WWWForm_m__ctorP31UnityEngine_UnityEngine_WWWForm,__Z172UnityEngine_UnityEngine_WWWForm_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_WWWForm_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP21CustomAttributesCache,__Z65UnityEngine_UnityEngine_CacheIndex_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z46UnityEngine_UnityEngine_AsyncOperation_m__ctorP38UnityEngine_UnityEngine_AsyncOperation,__Z56UnityEngine_UnityEngine_AsyncOperation_m_InternalDestroyP38UnityEngine_UnityEngine_AsyncOperation,__Z49UnityEngine_UnityEngine_AsyncOperation_m_FinalizeP38UnityEngine_UnityEngine_AsyncOperation,__Z126UnityEngine_UnityEngine_AsyncOperation_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AsyncOperation_m_InternalDestroyP21CustomAttributesCache,__Z41UnityEngine_UnityEngine_Behaviour_m__ctorP33UnityEngine_UnityEngine_Behaviour
  ,__Z112UnityEngine_UnityEngine_Behaviour_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Behaviour_m_set_enabledP21CustomAttributesCache,__Z112UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_nearClipPlaneP21CustomAttributesCache,__Z111UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_farClipPlaneP21CustomAttributesCache,__Z110UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_cullingMaskP21CustomAttributesCache,__Z108UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_eventMaskP21CustomAttributesCache,__Z117UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_get_pixelRectP21CustomAttributesCache,__Z112UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_targetTextureP21CustomAttributesCache,__Z109UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_clearFlagsP21CustomAttributesCache,__Z127UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_ViewportPointToRayP21CustomAttributesCache,__Z125UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_ScreenPointToRayP21CustomAttributesCache,__Z103UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_mainP21CustomAttributesCache,__Z114UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_get_allCamerasCountP21CustomAttributesCache,__Z108UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_GetAllCamerasP21CustomAttributesCache,__Z119UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_RaycastTryP21CustomAttributesCache,__Z121UnityEngine_UnityEngine_Camera_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_RaycastTry2DP21CustomAttributesCache,__Z101UnityEngine_UnityEngine_Debug_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Debug_m_DrawLineP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_Debug_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Debug_m_INTERNAL_CALL_DrawLineP21CustomAttributesCache,__Z105UnityEngine_UnityEngine_Debug_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Debug_m_Internal_LogP21CustomAttributesCache,__Z64UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate_m_InvokeP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate,__Z60UnityEngine_UnityEngine_Display_m__ctor_mscorlib_System_VoidP31UnityEngine_UnityEngine_Display,__Z40UnityEngine_UnityEngine_Display_m__cctorP22mscorlib_System_Object,__Z63UnityEngine_UnityEngine_Display_m_Activate_mscorlib_System_VoidP31UnityEngine_UnityEngine_Display,__Z53UnityEngine_UnityEngine_Display_m_FireDisplaysUpdatedP22mscorlib_System_Object,__Z113UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_GetSystemExtImplP21CustomAttributesCache,__Z116UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_GetRenderingExtImplP21CustomAttributesCache,__Z120UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_GetRenderingBuffersImplP21CustomAttributesCache,__Z123UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_SetRenderingResolutionImplP21CustomAttributesCache,__Z116UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_ActivateDisplayImplP21CustomAttributesCache,__Z110UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_SetParamsImplP21CustomAttributesCache,__Z120UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_MultiDisplayLicenseImplP21CustomAttributesCache
  ,__Z116UnityEngine_UnityEngine_Display_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Display_m_RelativeMouseAtImplP21CustomAttributesCache,__Z45UnityEngine_UnityEngine_MonoBehaviour_m__ctorP37UnityEngine_UnityEngine_MonoBehaviour,__Z128UnityEngine_UnityEngine_MonoBehaviour_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_MonoBehaviour_m_StartCoroutine_AutoP21CustomAttributesCache,__Z38UnityEngine_UnityEngine_Input_m__cctorP22mscorlib_System_Object,__Z46UnityEngine_UnityEngine_Input_m_ResetInputAxesP22mscorlib_System_Object,__Z102UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetKeyIntP21CustomAttributesCache,__Z100UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetAxisP21CustomAttributesCache,__Z103UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetAxisRawP21CustomAttributesCache,__Z102UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetButtonP21CustomAttributesCache,__Z106UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetButtonDownP21CustomAttributesCache,__Z107UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetMouseButtonP21CustomAttributesCache,__Z111UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_GetMouseButtonDownP21CustomAttributesCache,__Z107UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_ResetInputAxesP21CustomAttributesCache,__Z110UnityEngine_UnityEngine_Input_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Input_m_get_mousePositionP21CustomAttributesCache,__Z122UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_positionP21CustomAttributesCache,__Z122UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_positionP21CustomAttributesCache,__Z130UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localEulerAnglesP21CustomAttributesCache,__Z130UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localEulerAnglesP21CustomAttributesCache,__Z122UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_rotationP21CustomAttributesCache,__Z122UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_rotationP21CustomAttributesCache,__Z127UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localRotationP21CustomAttributesCache,__Z127UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localRotationP21CustomAttributesCache,__Z124UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_set_localScaleP21CustomAttributesCache,__Z132UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_get_localToWorldMatrixP21CustomAttributesCache,__Z197UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_Rotate_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleP21CustomAttributesCache,__Z133UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_TransformDirectionP21CustomAttributesCache,__Z140UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_InverseTransformDirectionP21CustomAttributesCache,__Z129UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_TransformPointP21CustomAttributesCache,__Z136UnityEngine_UnityEngine_Transform_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Transform_m_INTERNAL_CALL_InverseTransformPointP21CustomAttributesCache,__Z99UnityEngine_UnityEngine_Time_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Time_m_get_timeP21CustomAttributesCache
  ,__Z104UnityEngine_UnityEngine_Time_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Time_m_get_deltaTimeP21CustomAttributesCache,__Z109UnityEngine_UnityEngine_Random_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Random_m_RandomRangeIntP21CustomAttributesCache,__Z48UnityEngine_UnityEngine_YieldInstruction_m__ctorP40UnityEngine_UnityEngine_YieldInstruction,__Z119UnityEngine_UnityEngine_Rigidbody_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Rigidbody_m_set_freezeRotationP21CustomAttributesCache,__Z110UnityEngine_UnityEngine_Collider_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Collider_m_set_enabledP21CustomAttributesCache,__Z118UnityEngine_UnityEngine_Collider_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Collider_m_INTERNAL_get_boundsP21CustomAttributesCache,__Z139UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_INTERNAL_CALL_MoveP21CustomAttributesCache,__Z142UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_INTERNAL_get_velocityP21CustomAttributesCache,__Z131UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_get_radiusP21CustomAttributesCache,__Z131UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_get_heightP21CustomAttributesCache,__Z140UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_INTERNAL_get_centerP21CustomAttributesCache,__Z135UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_get_slopeLimitP21CustomAttributesCache,__Z135UnityEngine_UnityEngine_CharacterController_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_CharacterController_m_get_stepOffsetP21CustomAttributesCache,__Z46UnityEngine_UnityEngine_AnimationEvent_m__ctorP38UnityEngine_UnityEngine_AnimationEvent,__Z132UnityEngine_UnityEngine_AnimationEvent_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationEventTraits_data_PropertyInfoP21CustomAttributesCache,__Z67UnityEngine_UnityEngine_AnimationCurve_m__ctor_mscorlib_System_VoidP38UnityEngine_UnityEngine_AnimationCurve,__Z48UnityEngine_UnityEngine_AnimationCurve_m_CleanupP38UnityEngine_UnityEngine_AnimationCurve,__Z49UnityEngine_UnityEngine_AnimationCurve_m_FinalizeP38UnityEngine_UnityEngine_AnimationCurve,__Z118UnityEngine_UnityEngine_AnimationCurve_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationCurve_m_CleanupP21CustomAttributesCache,__Z119UnityEngine_UnityEngine_AnimationCurve_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationCurve_m_EvaluateP21CustomAttributesCache,__Z115UnityEngine_UnityEngine_AnimationCurve_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationCurve_m_InitP21CustomAttributesCache,__Z69UnityEngine_UnityEngine_AnimationCurve_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z210UnityEngine_UnityEngine_Animation_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animation_m_CrossFade_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Single_UnityEngine_UnityEngine_PlayModeP21CustomAttributesCache,__Z154UnityEngine_UnityEngine_Animation_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animation_m_CrossFade_mscorlib_System_Void_mscorlib_System_StringP21CustomAttributesCache,__Z109UnityEngine_UnityEngine_Animation_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animation_m_GetStateP21CustomAttributesCache,__Z64UnityEngine_UnityEngine_Animation_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z123UnityEngine_UnityEngine_AnimationState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationState_m_set_wrapModeP21CustomAttributesCache,__Z120UnityEngine_UnityEngine_AnimationState_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimationState_m_set_speedP21CustomAttributesCache,__Z68UnityEngine_UnityEngine_AnimationInfo_CustomAttributesCacheGeneratorP21CustomAttributesCache,__Z142UnityEngine_UnityEngine_AnimatorStateInfo_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_AnimatorStateInfoTraits_nameHash_PropertyInfoP21CustomAttributesCache
  ,__Z191UnityEngine_UnityEngine_Animator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animator_m_Play_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_SingleP21CustomAttributesCache,__Z146UnityEngine_UnityEngine_Animator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animator_m_Play_mscorlib_System_Void_mscorlib_System_Int32P21CustomAttributesCache,__Z111UnityEngine_UnityEngine_Animator_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Animator_m_StringToHashP21CustomAttributesCache,__Z39UnityEngine_UnityEngine_Terrain_m__ctorP31UnityEngine_UnityEngine_Terrain,__Z71UnityEngine_UnityEngine_CharacterInfo_CustomAttributesCacheGenerator_uvP21CustomAttributesCache,__Z73UnityEngine_UnityEngine_CharacterInfo_CustomAttributesCacheGenerator_vertP21CustomAttributesCache,__Z74UnityEngine_UnityEngine_CharacterInfo_CustomAttributesCacheGenerator_widthP21CustomAttributesCache,__Z76UnityEngine_UnityEngine_CharacterInfo_CustomAttributesCacheGenerator_flippedP21CustomAttributesCache,__Z64UnityEngine_UnityEngine_Font_FontTextureRebuildCallback_m_InvokeP55UnityEngine_UnityEngine_Font_FontTextureRebuildCallback,__Z72UnityEngine_UnityEngine_Font_m_InvokeFontTextureRebuildCallback_InternalP28UnityEngine_UnityEngine_Font,__Z102UnityEngine_UnityEngine_Font_CustomAttributesCacheGenerator_UnityEngine_UnityEngine_Font_m_get_dynamicP21CustomAttributesCache,__Z58UnityEngine_UnityEngine_Canvas_WillRenderCanvases_m_InvokeP49UnityEngine_UnityEngine_Canvas_WillRenderCanvases,__Z55UnityEngine_UnityEngine_Canvas_m_SendWillRenderCanvasesP22mscorlib_System_Object,__Z41UnityEngine_UnityEngine_UIVertex_m__cctorP22mscorlib_System_Object,__ZNSt3__111__stdoutbufIwED1Ev,__ZNSt3__111__stdoutbufIwED0Ev,__ZNSt3__110__stdinbufIwED1Ev,__ZNSt3__110__stdinbufIwED0Ev,__ZNSt3__111__stdoutbufIcED1Ev,__ZNSt3__111__stdoutbufIcED0Ev,__ZNSt3__110__stdinbufIcED1Ev,__ZNSt3__110__stdinbufIcED0Ev,__ZNSt3__112system_errorD2Ev,__ZNSt3__112system_errorD0Ev,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEED1Ev,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEED0Ev,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEED1Ev,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEED0Ev,__ZNSt3__113basic_istreamIwNS_11char_traitsIwEEED1Ev,__ZNSt3__113basic_istreamIwNS_11char_traitsIwEEED0Ev
  ,__ZTv0_n12_NSt3__113basic_istreamIwNS_11char_traitsIwEEED1Ev,__ZTv0_n12_NSt3__113basic_istreamIwNS_11char_traitsIwEEED0Ev,__ZNSt3__113basic_ostreamIwNS_11char_traitsIwEEED1Ev,__ZNSt3__113basic_ostreamIwNS_11char_traitsIwEEED0Ev,__ZTv0_n12_NSt3__113basic_ostreamIwNS_11char_traitsIwEEED1Ev,__ZTv0_n12_NSt3__113basic_ostreamIwNS_11char_traitsIwEEED0Ev,__ZNSt3__18ios_base7failureD2Ev,__ZNSt3__18ios_base7failureD0Ev,__ZNSt3__18ios_baseD2Ev,__ZNSt3__18ios_baseD0Ev,__ZNSt3__119__iostream_categoryD1Ev,__ZNSt3__119__iostream_categoryD0Ev,__ZNSt3__17collateIcED1Ev,__ZNSt3__17collateIcED0Ev,__ZNSt3__16locale5facet16__on_zero_sharedEv,__ZNSt3__17collateIwED1Ev,__ZNSt3__17collateIwED0Ev,__ZNSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev,__ZNSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev,__ZNSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev,__ZNSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev,__ZNSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev,__ZNSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev,__ZNSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__18time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev
  ,__ZNSt3__18time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__18time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev,__ZNSt3__18time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__110moneypunctIcLb0EED1Ev,__ZNSt3__110moneypunctIcLb0EED0Ev,__ZNSt3__110moneypunctIcLb1EED1Ev,__ZNSt3__110moneypunctIcLb1EED0Ev,__ZNSt3__110moneypunctIwLb0EED1Ev,__ZNSt3__110moneypunctIwLb0EED0Ev,__ZNSt3__110moneypunctIwLb1EED1Ev,__ZNSt3__110moneypunctIwLb1EED0Ev,__ZNSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev,__ZNSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev,__ZNSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__19money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED1Ev,__ZNSt3__19money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev,__ZNSt3__19money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED1Ev,__ZNSt3__19money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev,__ZNSt3__18messagesIcED1Ev,__ZNSt3__18messagesIcED0Ev,__ZNSt3__18messagesIwED1Ev,__ZNSt3__18messagesIwED0Ev,__ZNSt3__16locale5__impD2Ev,__ZNSt3__16locale5__impD0Ev,__ZNSt3__15ctypeIcED2Ev,__ZNSt3__15ctypeIcED0Ev,__ZNSt3__17codecvtIwc11__mbstate_tED2Ev,__ZNSt3__17codecvtIwc11__mbstate_tED0Ev,__ZNSt3__18numpunctIcED2Ev
  ,__ZNSt3__18numpunctIcED0Ev,__ZNSt3__18numpunctIwED2Ev,__ZNSt3__18numpunctIwED0Ev,__ZNSt3__16locale5facetD2Ev,__ZNSt3__16locale5facetD0Ev,__ZNSt3__15ctypeIwED0Ev,__ZNSt3__17codecvtIcc11__mbstate_tED0Ev,__ZNSt3__17codecvtIDsc11__mbstate_tED0Ev,__ZNSt3__17codecvtIDic11__mbstate_tED0Ev,__ZNSt3__116__narrow_to_utf8ILj32EED0Ev,__ZNSt3__117__widen_from_utf8ILj32EED0Ev,__ZNSt9bad_allocD2Ev,__ZNSt9bad_allocD0Ev,__ZNSt11logic_errorD2Ev,__ZNSt11logic_errorD0Ev,__ZNSt13runtime_errorD2Ev,__ZNSt13runtime_errorD0Ev,__ZNSt12length_errorD0Ev,__ZNSt12out_of_rangeD0Ev,__ZNSt14overflow_errorD0Ev,__ZNSt8bad_castD2Ev,__ZNSt8bad_castD0Ev,__ZN10__cxxabiv116__shim_type_infoD2Ev,__ZN10__cxxabiv117__class_type_infoD0Ev,__ZNK10__cxxabiv116__shim_type_info5noop1Ev,__ZNK10__cxxabiv116__shim_type_info5noop2Ev,__ZN10__cxxabiv120__si_class_type_infoD0Ev,__ZN10__cxxabiv121__vmi_class_type_infoD0Ev,_GC_null_finalize_mark_proc,_GC_unreachable_finalize_mark_proc
  ,__ZNSt3__16localeD2Ev,__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev,__ZNSt3__18ios_base33__set_badbit_and_consider_rethrowEv,__ZN6il2cpp2vm9Exception5RaiseEP15Il2CppException,__Z20il2cpp_gc_free_fixedPv,__ZNKSt3__121__basic_string_commonILb1EE20__throw_out_of_rangeEv,__ZN6il2cpp2vm17TypeNameParseInfoC2Ev,__ZN6il2cpp2vm17TypeNameParseInfoD2Ev,_il2cpp_raise_exception,__ZNKSt3__120__vector_base_commonILb1EE20__throw_length_errorEv,__ZNKSt3__121__basic_string_commonILb1EE20__throw_length_errorEv,__ZN6il2cpp2os5MutexD2Ev,__ZN6il2cpp2os5EventD2Ev,__ZN6il2cpp2os6ThreadC2Ev,__ZN6il2cpp6icalls8mscorlib6System9ThreadingL11ThreadStartEPv,__ZN6il2cpp2os9SemaphoreD2Ev,__ZN6il2cpp2os9EventImplD2Ev,__ZN6il2cpp2os9MutexImplC2Ev,__ZN6il2cpp2os9MutexImplD2Ev,__ZN6il2cpp2os13SemaphoreImplD2Ev,__ZN6il2cpp2os10ThreadImplC2Ev,__ZN6il2cpp2os20ThreadLocalValueImplC2Ev,__ZN6il2cpp6icalls8mscorlib6System11__ComObject17ReleaseInterfacesEP27mscorlib_System___ComObject,__ZN6il2cpp6icalls8mscorlib6System9AppDomain21InternalPushDomainRefEP25mscorlib_System_AppDomain,__ZN6il2cpp6icalls8mscorlib6System9AppDomain25InternalPushDomainRefByIDEi,__ZN6il2cpp6icalls8mscorlib6System9AppDomain14InternalUnloadEi,__ZN6il2cpp6icalls8mscorlib6System8Delegate18SetMulticastInvokeEP14Il2CppDelegate,__ZN6il2cpp6icalls8mscorlib6System11Environment4ExitEi,__ZN6il2cpp6icalls8mscorlib6System11Environment12set_ExitCodeEi,__ZN6il2cpp6icalls8mscorlib6System2GC15InternalCollectEi
  ,__ZN6il2cpp6icalls8mscorlib6System2GC9KeepAliveEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System2GC21ReRegisterForFinalizeEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System2GC16SuppressFinalizeEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo22free_internal_collatorEP41mscorlib_System_Globalization_CompareInfo,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo25construct_datetime_formatEP17Il2CppCultureInfo,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo23construct_number_formatEP17Il2CppCultureInfo,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit15AssemblyBuilder10basic_initEP47mscorlib_System_Reflection_Emit_AssemblyBuilder,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11DerivedType21create_unmanaged_typeEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit27GenericTypeParameterBuilder10initializeEP28Il2CppReflectionGenericParam,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder10basic_initEP29Il2CppReflectionModuleBuilder,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder14build_metadataEP29Il2CppReflectionModuleBuilder,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder20create_generic_classEP27Il2CppReflectionTypeBuilder,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder21create_internal_classEP27Il2CppReflectionTypeBuilder,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder19setup_generic_classEP27Il2CppReflectionTypeBuilder,__ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers19RunClassConstructorE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers20RunModuleConstructorE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle10FreeHandleEi,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal8FreeBSTRE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal13FreeCoTaskMemE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal11FreeHGlobalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal7PrelinkEP22Il2CppReflectionMethod,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10PrelinkAllEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8Security12Cryptography24RNGCryptoServiceProvider8RngCloseE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager24set_CheckExecutionRightsEb,__ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager19set_SecurityEnabledEb,__ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor5EnterEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor4ExitEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor13Monitor_pulseEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor17Monitor_pulse_allEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System9Threading16NativeEventCalls19CloseEvent_internalE12Il2CppIntPtr
  ,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread18Interrupt_internalEPv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread15Resume_internalEPv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread14Sleep_internalEi,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread16Suspend_internalEPv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread11Thread_initEP12Il2CppThread,__ZN6il2cpp2vm13LivenessStateD2Ev,__ZN6il2cpp2os5Mutex6UnlockEv,__ZN6il2cpp2vm17TypeNameParseInfo12AssemblyNameD2Ev,_png_default_flush,__ZN5physx21PxcArticulationHelper12saveVelocityERKNS_25PxcArticulationSolverDescE,__ZN5physx16PxVehicleDrive4W17getBinaryMetaDataERNS_14PxOutputStreamE,__ZN5physx18PxVehicleDriveTank17getBinaryMetaDataERNS_14PxOutputStreamE,__ZN5physx16PxVehicleNoDrive17getBinaryMetaDataERNS_14PxOutputStreamE,__ZN5physx16PxVehicleDriveNW17getBinaryMetaDataERNS_14PxOutputStreamE,__ZN15dense_hashtableINSt3__14pairIKiP6ObjectEEi21InstanceIDHashFunctorN14dense_hash_mapIiS4_S6_NS0_8equal_toIiEE13stl_allocatorIS5_L18MemLabelIdentifier58ELi16EEE9SelectKeyES9_SC_E14squash_deletedEv,__ZN7Cursors16GetCursorHotspotEv,__ZN22DeviceMVPMatricesStateD2Ev,__ZN18StreamedBinaryReadILb0EE5AlignEv,__ZN18StreamedBinaryReadILb1EE5AlignEv,__ZN19StreamedBinaryWriteILb0EE5AlignEv,__ZN14ConstantString12create_emptyEv,__ZN5Unity10GameObjectD2Ev,__ZN16MessageForwarderC2Ev,__ZN14ConstantStringD2Ev,__ZN17PersistentManager6UnlockEv,__Z29ResetManagerContextFromLoadedv,__ZN17PersistentManager19DoneLoadingManagersEv,__ZN10TagManagerD2Ev,__ZN10TagManager32RegisterDefaultTagsAndLayerMasksEv,__ZN10TagManager23AddDefaultLayerIfNeededEv
  ,__ZN14SafeBinaryRead11EndTransferEv,__ZN13ProxyTransfer11EndTransferEv,__ZN13ProxyTransfer16EndArrayTransferEv,__ZN13ProxyTransfer5AlignEv,__ZN10TagManager15ThreadedCleanupEv,__ZN5Unity9ComponentD2Ev,__ZN10MemoryPool24RegisterStaticMemoryPoolEPS_,__ZN13RenderTexture37SetTemporarilyAllowIndieRenderTextureEb,__ZN16ReflectionSampleC2Ev,__ZN13BatchRenderer5FlushEv,__ZN13BatchRendererD1Ev,__Z20SetNoShadowsKeywordsRN9ShaderLab17ShaderPassContextE,__ZN12LightManager22SetupForwardBaseLightsERK18ForwardLightsBlock,__Z21CompleteFenceInternalR8JobFence,__ZN23ForwardShaderRenderLoopD2Ev,__ZN27DeviceViewProjMatricesStateD2Ev,__ZN22DeviceMVPMatricesStateC2Ev,__ZN10RenderLoopD2Ev,__ZN6Camera12RenderSkyboxEv,__ZN19RenderEventsContextC2Ev,__ZN19RenderEventsContextD2Ev,__ZN9BehaviourD2Ev,__ZN11CullResultsD2Ev,__ZN11CullResultsC2Ev,__ZN10GUIManager7RepaintEv,__ZN6CameraD2Ev,__ZN6Camera15ThreadedCleanupEv,__Z20PrepareSceneNodesJobPv,__Z16DestroyIndexListR9IndexList,__ZN16GraphicsSettingsD2Ev
  ,__ZN14ShadowSettings5ResetEv,__ZL45FrustumAndOcculusionCullLocalLightsCombineJobPv,__ZN11LightProbesD2Ev,__ZN11LightProbes14LightProbeDataD2Ev,__ZN11NamedObjectD2Ev,__ZN16ReflectionProbes17RuntimeLookupDataD2Ev,__ZN13RenderManagerD2Ev,__ZN5Light16SetupAttenuationEv,__ZN5Light9SetupHaloEv,__ZN5Light10SetupFlareEv,__ZL54CombineLocalShadowCasterCullignIndexListsAndDestroyJobPv,__Z37GenerateCombinedDynamicVisibleListJobPv,__Z21CreateShadowCullerJobPv,__ZL60CombineDirectionalShadowCasterCullignIndexListsAndDestroyJobPv,__ZN5Unity8Material15BuildPropertiesEv,__ZN28ApplyBuiltinInstanceProperty30PerformFlushMaterialPropertiesEv,__ZN6Skybox8SetupSunER9GfxDevice,__ZN6Skybox14RenderAllFacesEPN5Unity8MaterialE,__ZL31QueryPortalVisibilityCombineJobPv,__ZL26CullDynamicSceneCombineJobPv,__ZN5Unity5SceneC2Ev,__ZN5Unity5SceneD2Ev,__ZL32CullAllPerObjectLightsCombineJobPv,__ZN17CommonStringTableC2Ev,__ZN13SpeedTreeWindC2Ev,__ZN12WWWDelayCall7CleanupEPv,__ZN14GrowableBufferD2Ev,__ZN22RenderingCommandBufferD2Ev,__ZN8Renderer15ThreadedCleanupEv,__Z20DeformSkinnedMeshJobPv
  ,__ZN8RendererD2Ev,__ZN17AnimationCurveTplI11QuaternionfE15InvalidateCacheEv,__ZN17CollisionMeshDataC2Ev,__ZN14VertexDataInfoC2Ev,__ZN4Mesh12UploadedData6UnloadEv,__ZN17CollisionMeshDataD2Ev,__ZN14BlendShapeDataD2Ev,__ZN10VertexDataD2Ev,__ZN4MeshD2Ev,__ZN17RemapPPtrTransfer11PopMetaFlagEv,__ZN14CompressedMeshD2Ev,__ZN17CollisionMeshData7CleanupEv,__ZN14SharedMeshDataD2Ev,__ZN16MeshSkinningDataD2Ev,__ZN9BillboardD2Ev,__ZN18DelayedCallManagerD2Ev,__Z29AwakeAndActivateClonedObjectsRK10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS0_4pairIiiEEL18MemLabelIdentifier90ELi16EEE,__ZN12CachedReaderC2Ev,__ZN22BlockMemoryCacheWriterD2Ev,__ZN4NodeD1Ev,__ZN4NodeD2Ev,__ZN9Texture2D18UnshareTextureDataEv,__ZN14GfxDeviceStatsC2Ev,__ZN9GfxDevice8OnCreateEv,__ZN9ShaderLab6TexEnvD2Ev,__ZN9GfxDevice8OnDeleteEv,__ZN20GpuProgramParametersD2Ev,__ZN14ChannelAssignsC2Ev,__ZNKSt3__120__vector_base_commonILb1EE20__throw_out_of_rangeEv,__ZN9Texture2DD2Ev
  ,__ZN9Texture2D15ThreadedCleanupEv,__ZN6prcore7Surface10FlipImageYEv,__ZL17PngWriteFlushFuncP14png_struct_def,___clang_call_terminate,__ZN10GISettingsC2Ev,__ZN16LightmapSettingsD2Ev,__ZN21EnlightenSceneMappingD2Ev,__ZL32InitializeDefaultQualitySettingsPN15QualitySettings14QualitySettingE,__ZN9TransformD2Ev,__ZN7TextureD2Ev,__ZN18ScreenManagerWebGLC2Ev,__ZN15TextureSettings5ResetEv,__ZN9Texture2D14DestroyTextureEv,__ZN7StriperD2Ev,__ZN5Unity8Material15ThreadedCleanupEv,__ZN18ProceduralMaterialD2Ev,__ZN14SubstanceInputD2Ev,__ZN5Unity8MaterialD2Ev,__ZN16GUIKeyboardStateC2Ev,__ZN10InputEventD2Ev,__ZN5IMGUI18RepaintModalWindowER8GUIState,__ZN16GUIKeyboardState8EndFrameEv,__ZN11UTF16StringD2Ev,__ZN12GUIClipStateC2Ev,__ZN10OnGUIStateD2Ev,__ZN5IMGUI14GUIWindowStateD2Ev,__ZN8GUIStateC2Ev,__Z23scripting_gchandle_freei,__ZN14ObjectGUIStateD2Ev,__ZN5IMGUI9GUIWindowD2Ev
  ,__ZN12InputManager11MakeDefaultEv,__ZN12InputManagerD2Ev,__ZN9InputAxisC2Ev,__ZN11AssetBundleD2Ev,__ZN14SafeBinaryRead16EndArrayTransferEv,__ZN14UnityWebStream7ReleaseEv,__ZN20CachedUnityWebStreamD2Ev,__ZN13BuildSettingsD2Ev,__ZN4FileD2Ev,__ZN14CachingManager5ResetEv,__ZN4FileC2Ev,__ZN14CachingManager15ClearTempFolderEv,__ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E14squash_deletedEv,__ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E12maybe_shrinkEv,__Z43scripting_liveness_calculation_from_staticsPv,__Z34scripting_liveness_calculation_endPv,__ZN13CallbackArray6InvokeEv,__ZN11TimeManager21DidFinishLoadingLevelEv,__ZN8GUIStyle14SetDefaultFontEPN13TextRendering4FontE,__Z12LoadManagersR18AwakeFromLoadQueue,__ZN14PreloadManager35WaitForAllAsyncOperationsToCompleteEv,__ZN14AsyncOperation7ReleaseEv,__ZN14PreloadManager16UpdatePreloadingEv,__ZN5Unity5Scene15NotifyInvisibleEv,__ZN12InputManager12ProcessInputEv,__ZN10GUIManager16SendQueuedEventsEv,__Z12PlayerRenderb,__ZN5Unity5Scene26ClearIntermediateRenderersEv,__ZN12InputManager13InputEndFrameEv,__ZN15GUIEventManager11ClearEventsEv
  ,__ZN12InputManager14ResetInputAxesEv,__ZN11PreloadDataD2Ev,__ZN17PersistentManager4LockEv,__ZN18LoadLevelOperationC2Ev,__ZN23PreloadManagerOperationC2Ev,__ZN14PlayerSettingsD2Ev,__ZN15ResourceManagerD2Ev,__ZN18AwakeFromLoadQueue30PersistentManagerAwakeFromLoadEv,__Z23CollectSceneGameObjectsR13dynamic_arrayIiLj4EE,__ZN14SafeBinaryReadD2Ev,__ZN9Scripting29RuntimeObjectInitLogExceptionEP15ScriptingObject,__ZN8GUIStyleC2Ev,__ZN11GradientNEWC2Ev,__ZN17AnimationCurveTplIfE15InvalidateCacheEv,__ZN9Coroutine16CleanupCoroutineEPv,__ZN14ObjectGUIStateC2Ev,__ZN9CoroutineC2Ev,__ZN13MonoBehaviourD2Ev,__ZN10MonoScriptD2Ev,__ZN9TextAssetD2Ev,__ZN13sorted_vectorINSt3__14pairIP14ScriptingClassiEEN10vector_mapIS3_iNS0_4lessIS3_EENS0_9allocatorIS4_EEE13value_compareES9_E21sort_clear_duplicatesEv,__ZN17PersistentManager9AddStreamEv,__ZN18AwakeFromLoadQueue25RegisterObjectInstanceIDsEv,__ZN17PersistentManager40LoadRemainingPreallocatedObjectsInternalEv,__ZN15dense_hashtableINSt3__14pairIKi17ThreadedAwakeDataEEi21InstanceIDHashFunctorN14dense_hash_mapIiS3_S5_NS0_8equal_toIiEENS0_9allocatorIS4_EEE9SelectKeyES8_SA_E14squash_deletedEv,__ZN14SerializedFile7ReleaseEv,__ZN14SerializedFileC2Ev,__ZN14SerializedFile27PatchRemapDeprecatedClassesEv,__ZN20dynamic_block_vectorI14FileIdentifierE5clearEv,__ZN8TypeTreeC2Ev
  ,__ZN8TypeTreeD2Ev,__ZN20dynamic_block_vectorI14FileIdentifierE9push_backEv,__ZN20dynamic_block_vectorI14FileIdentifierE8pop_backEv,__ZN13FileEntryDataD2Ev,__Z23AsyncReadForceCloseFileRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZN9ShaderLab16ParserSubProgram14ConstantBufferD2Ev,__ZN9ShaderLab18ParserBindChannelsC2Ev,__ZN5Unity8Material22InvalidateDisplayListsEv,__ZN6Shader8PostLoadEv,__ZN9ShaderLab12ParserShaderD2Ev,__ZN9ShaderLab9IntShaderD2Ev,__ZN5Unity8Material12UpdateHashesEv,__ZN6Shader16DeleteAllShadersERNSt3__16vectorIiNS0_9allocatorIiEEEE,__ZN6Shader18RecreateAllShadersERKNSt3__16vectorIiNS0_9allocatorIiEEEE,__ZN12ScriptMapperD2Ev,__ZN12FileAccessorC2Ev,__ZN8DateTimeC2Ev,__ZN13OpenFileCacheC2Ev,__ZN9ShaderLab9SubShaderD2Ev,__ZN9ShaderLab11ShaderStateD2Ev,__ZN22CreateGpuProgramOutputD2Ev,__ZN9ShaderLab10SubProgramD2Ev,__Z9yyrestartP8_IO_FILE,__ZN9ShaderLab14ParserPropertyD2Ev,__ZN9ShaderLab21ParserTexturePropertyC2Ev,__ZN9ShaderLab13ParserProgramD2Ev,__ZN9ShaderLab16ParserSubProgramC2Ev,__ZN9ShaderLab9IntShaderC2Ev,__ZN9ShaderLab9SubShaderC2Ev,__Z24CreateDefaultShaderStateRN9ShaderLab17ParserShaderStateE
  ,__ZNSt3__15dequeIPN9ShaderLab17ParserShaderStateENS_9allocatorIS3_EEE19__add_back_capacityEv,__ZN9ShaderLab16ParserSubProgramD2Ev,__ZN9ShaderLab15ParserSubShaderD2Ev,__ZN9ShaderLab4Pass6RetainEv,__ZN9ShaderLab4Pass7ReleaseEv,__ZN11CustomArrayD2Ev,__ZN5Unity11AdjacenciesD2Ev,__ZN5Unity11AdjacenciesC2Ev,__ZN11RadixSorterD2Ev,__ZN14BestStripCacheD2Ev,__ZN9Scripting24RaiseNullExceptionObjectEP15ScriptingObject,__Z58AssetBundleCreateRequest_CUSTOM_DisableCompatibilityChecksP15ScriptingObject,__Z33Coroutine_CUSTOM_ReleaseCoroutineP15ScriptingObject,__Z55ScriptableObject_CUSTOM_Internal_CreateScriptableObjectP15ScriptingObject,__Z20Gradient_CUSTOM_InitP15ScriptingObject,__Z23Gradient_CUSTOM_CleanupP15ScriptingObject,__Z26GUI_Set_Custom_PropChangedh,__Z28GUIStyleState_CUSTOM_CleanupP15ScriptingObject,__Z22RectOffset_CUSTOM_InitP15ScriptingObject,__Z25RectOffset_CUSTOM_CleanupP15ScriptingObject,__Z20GUIStyle_CUSTOM_InitP15ScriptingObject,__Z23GUIStyle_CUSTOM_CleanupP15ScriptingObject,__Z30GUIStyle_CUSTOM_SetDefaultFontP15ScriptingObject,__Z17Event_CUSTOM_InitP15ScriptingObject,__Z20Event_CUSTOM_CleanupP15ScriptingObject,__Z36Event_CUSTOM_Internal_SetNativeEvent6IntPtr,__Z37AsyncOperation_CUSTOM_InternalDestroyP15ScriptingObject,_JS_Eval_EvalJS__wrapper,__Z40Application_CUSTOM_Internal_ExternalCallP15ScriptingString,__Z34Input_Get_Custom_PropMousePositionv
  ,__ZN8ColliderD2Ev,__Z30SetDisableImmediateDestructionb,__ZN5Unity5Cloth15UpdateCollidersEv,__ZN5Unity5Cloth18ApplyConfigurationEv,__ZN14PhysicMaterial17ReleasePxMaterialEv,__ZN5physx17PxCloseVehicleSDKEPNS_23PxSerializationRegistryE,__ZN14PhysicsManager20SetupDefaultMaterialEv,__ZN14PhysicsManager11SweepShapesD2Ev,__ZN14PhysicsManager19CreateDynamicsSceneEb,__ZN5Unity5Cloth22ReadBackSkinnedBuffersEv,__ZN14PhysicsManagerD2Ev,__ZN9Rigidbody16ApplyConstraintsEv,__ZN15dense_hashtableINSt3__14pairIKNS1_IP10Collider2DS3_EE11Collision2DEES4_NS2_23ColliderPairHashFunctorEN14dense_hash_mapIS4_S6_S8_NS0_8equal_toIS4_EE13stl_allocatorIS7_L18MemLabelIdentifier58ELi16EEE9SelectKeyESB_SE_E14squash_deletedEv,__ZN11SoundHandleD2Ev,__ZN11SoundHandleC2Ev,__ZN3WWW6RetainEv,__ZN11SoundHandle7ReleaseEv,__ZN10SampleClipD2Ev,__ZN11AudioSource7CleanupEv,__ZN13AudioListener7CleanupEv,__ZN15AudioReverbZone7CleanupEv,__ZN10AudioMixer13CleanupMemoryEv,__ZN9AudioClip7CleanupEv,__ZN12SoundManagerD2Ev,__ZN12AudioManager21FixMasterGroupRoutingEv,__ZN12SoundManagerC2Ev,__ZN29AudioEffectInternalDefinitionD2Ev,__ZN9AudioClip6ReloadEv,__ZN13AudioListener12ApplyFiltersEv,__ZN15AudioReverbZone4InitEv
  ,__ZN24AudioScriptBufferManagerC2Ev,__ZN20SoundChannelInstance11UpdatePitchEv,__ZN20SoundChannelInstance12UpdateVolumeEv,__ZN20SoundChannelInstance4StopEv,__ZN11SoundHandle8InstanceD2Ev,__ZN11SoundHandle8Instance15UpdateLoadStateEv,__ZN12SoundManager6UpdateEv,__ZN10ObjectPoolIN4FMOD3DSPENS0_4DSPIEED2Ev,__ZN10ObjectPoolIN4FMOD5SoundENS0_6SoundIEED2Ev,__ZN10ObjectPoolIN4FMOD12ChannelGroupENS0_13ChannelGroupIEED2Ev,__ZN10ObjectPoolIN4FMOD7ChannelENS0_8ChannelIEED2Ev,__ZN4FMOD22FakeModChannelCallbackEPv,__ZN4FMOD8ChannelID2Ev,__ZN4FMOD13ChannelGroupID2Ev,__ZN4FMOD6SoundID2Ev,__ZN4FMOD4DSPID2Ev,__ZN4FMOD7ReverbID2Ev,__Z31DoCalculateAnimatorSkinMatricesPv,__ZN14AnimationStateD2Ev,__ZN14AnimationStateC2Ev,__ZN15AnimationBinder17InitCurveIDLookupER14dense_hash_mapI7CurveIDj10hash_curveNSt3__18equal_toIS1_EE13stl_allocatorINS3_4pairIKS1_jEEL18MemLabelIdentifier90ELi16EEE,__ZN14AnimationState13CleanupCurvesEv,__ZN9Transform24RecalculateTransformTypeEv,__ZN14AnimationState19SetupUnstoppedStateEv,__ZN9Animation14SampleInternalEv,__ZN14AnimationState21CleanupUnstoppedStateEv,__ZN9AnimationD2Ev,__ZN9Animation15ThreadedCleanupEv,__ZN11UnityEngine9Animation28RegisterAvatarBindingObjectsEPNS0_21AvatarBindingConstantE,__ZN11UnityEngine9Animation28GenericAnimationBindingCacheC2Ev
  ,__ZN25RuntimeAnimatorControllerD2Ev,__ZN24CompressedAnimationCurveD2Ev,__ZN13AnimationClipD2Ev,__ZN13AnimationClip9PPtrCurveD2Ev,__ZN13AnimationClip10FloatCurveD2Ev,__ZN13AnimationClip18CleanupMecanimDataEv,__ZN11UnityEngine9Animation30UnregisterAvatarBindingObjectsEPNS0_21AvatarBindingConstantE,__ZN11UnityEngine9Animation31UnregisterGenericBindingObjectsEPNS0_30AnimatorGenericBindingConstantE,__ZN8Animator12CreateObjectEv,__ZN8Animator6FKStepEv,__ZN8Animator19FireAnimationEventsEv,__ZN8Animator19ApplyOnAnimatorMoveEv,__ZN8Animator15AvatarWriteStepEv,__ZN8AnimatorD2Ev,__ZN8UserList5ClearEv,__ZN18AnimatorControllerD2Ev,__ZN7mecanim5human9HumanPoseC2Ev,__Z29AnimationCurve_CUSTOM_CleanupP15ScriptingObject,__ZN4Mesh17RecalculateBoundsEv,__ZN21MaterialPropertyBlock11ComputeHashEv,__Z19DestroySingleObjectP6Object,__ZN14DetailRenderer7CleanupEv,__ZN15TerrainRenderer12RebuildNodesEv,__ZN20QuadTreeNodeRendererC2Ev,__ZN14TerrainManagerC2Ev,__ZN21ImposterRenderTextureD2Ev,__ZN14TreeBinaryTreeD2Ev,__ZN12TreeRenderer17PopulateRenderersEv,__ZN12TreeRenderer19LODTreeInstanceDataD2Ev,__ZN15LODGroupManagerD2Ev
  ,__ZN22ForwardLinearAllocatorD2Ev,__ZN12TreeRenderer14ClearRenderersEv,__ZN4Mesh11MarkDynamicEv,__ZN20TextRenderingPrivate12GetFontPathsERNSt3__16vectorINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEENS5_IS7_EEEE,__ZN20TextRenderingPrivate15DynamicFontDataC2Ev,__ZN20TextRenderingPrivate8TextMesh11ApplyToMeshEv,__ZN20TextRenderingPrivate4FontD2Ev,__ZN20TextRenderingPrivate15DynamicFontDataD2Ev,__ZN20TextRenderingPrivate19NativeTextGeneratorD2Ev,_ft_bitmap_glyph_done,_ft_outline_glyph_done,_memory_stream_close,_ft_ansi_stream_close,_cff_driver_done,_cff_face_done,_cff_size_done,_cff_slot_done,_cff_cmap_encoding_done,_cff_cmap_unicode_done,_sfnt_done_face,_tt_face_free_name,_tt_face_free_hdmx_stub,_tt_face_free_sbit_stub,_tt_face_free_ps_names,_tt_face_free_eblc,_tt_cmap14_done,_gray_raster_done,_tt_driver_done,_tt_face_done,_tt_size_done
  ,_TT_Forget_Glyph_Frame,_t1_hints_open,_t2_hints_open,_psh_globals_destroy,_ps_hinter_done,_Vertical_Sweep_Step,_Horizontal_Sweep_Step,_ft_black_done,_Split_Conic,_Split_Cubic,__ZN20TextRenderingPrivate22ScriptingTextGeneratorD2Ev,__Z25TextGenerator_CUSTOM_InitP15ScriptingObject,__Z32TextGenerator_CUSTOM_Dispose_cppP15ScriptingObject,__ZN2UI15ClearCanvasDataERNS_10CanvasDataE,__ZN2UI6CanvasD2Ev,__ZN2UI11BatchOutputD2Ev,__ZN6prcore6BitmapD2Ev,__Z16SanitizeKeyEventR10InputEvent,_glActiveTexture__wrapper,_glClear__wrapper,_glClearStencil__wrapper,_glCompileShader__wrapper,_glCullFace__wrapper,_glDeleteProgram__wrapper,_glDeleteShader__wrapper,_glDepthFunc__wrapper,_glDepthMask__wrapper,_glDisable__wrapper,_glDisableVertexAttribArray__wrapper,_glEnable__wrapper,_glEnableVertexAttribArray__wrapper,_glFrontFace__wrapper,_glGenerateMipmap__wrapper,_glLinkProgram__wrapper,_glStencilMask__wrapper,_glUseProgram__wrapper,__ZL25glBindVertexArrayOverridej,__ZL34glDisableVertexAttribArrayOverridej,__ZL33glEnableVertexAttribArrayOverridej,__ZN19ConstantBuffersGLESC2Ev,__ZN4gles24InvalidatePipelineStatesER15DeviceStateGLES,__ZN15DeviceStateGLESD2Ev,__ZN19ConstantBuffersGLES5ClearEv,__ZN9GfxDevice16DeleteDynamicVBOEv,__ZN22VertexDeclarationCache5ClearEv,__ZN14DataBufferGLES7ReleaseEv,__ZN19ConstantBuffersGLESD2Ev,__ZN20GpuProgramParameters9MakeReadyEv,__ZN13GfxDeviceGLESC2Ev,__ZN3WWW7ReleaseEv,__Z9NullCheckPv,__ZN6il2cpp2vm6Thread8PopFrameEP12Il2CppThread,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception,__ZL11RuntimeInitP8TypeInfo,__Z102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__Z140mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctor_mscorlib_System_Void_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z87System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m__ctor_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object,__Z85Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m__ctor_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object,__Z75Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m__ctor_gsharedP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1050
  ,__ZL11RuntimeInitP8TypeInfo1058,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1501,__ZL11RuntimeInitP8TypeInfo1504,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1676,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1833,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception1990,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2147,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2282,__ZL11RuntimeInitP8TypeInfo2284,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2334,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2608,__ZL11RuntimeInitP8TypeInfo2874,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception2875,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3068,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3328,__ZL11RuntimeInitP8TypeInfo3330,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3541,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3698,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3830,__ZL11RuntimeInitP8TypeInfo3832,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception3992,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception4477,__ZL11RuntimeInitP8TypeInfo4495,__ZL11RuntimeInitP8TypeInfo5701,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception5704,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception6636,__ZL11RuntimeInitP8TypeInfo6649,__ZL11RuntimeInitP8TypeInfo7311,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception7308,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception8559
  ,__ZL11RuntimeInitP8TypeInfo8566,__ZL11RuntimeInitP8TypeInfo9430,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception9431,__Z80System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m__ctor_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__ZL11RuntimeInitP8TypeInfo10827,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception10836,__ZL11RuntimeInitP8TypeInfo11882,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception11973,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception12995,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception13875,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception14770,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception15629,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception16498,__ZL30il2cpp_codegen_raise_exceptionP25mscorlib_System_Exception17121,_free,_freelocale__wrapper,__ZNSt3__112__do_nothingEPv,__ZNSt3__121__throw_runtime_errorEPKc,__ZNSt3__16locale2id6__initEv,__ZNSt3__117__call_once_proxyINS_5tupleIJNS_12_GLOBAL__N_111__fake_bindEEEEEEvPv,__ZN10__cxxabiv112_GLOBAL__N_19destruct_EPv,_emscripten_glDeleteShader__wrapper,_emscripten_glCompileShader__wrapper,_emscripten_glDeleteProgram__wrapper,_emscripten_glLinkProgram__wrapper,_emscripten_glUseProgram__wrapper,_emscripten_glValidateProgram__wrapper,_emscripten_glDeleteObjectARB__wrapper,_emscripten_glEnableClientState__wrapper,_emscripten_glClientActiveTexture__wrapper,_emscripten_glBindVertexArray__wrapper,_emscripten_glMatrixMode__wrapper,_emscripten_glLoadMatrixf__wrapper,_emscripten_glEnableVertexAttribArray__wrapper,_emscripten_glDisableVertexAttribArray__wrapper,_emscripten_glDepthFunc__wrapper,_emscripten_glEnable__wrapper,_emscripten_glDisable__wrapper,_emscripten_glFrontFace__wrapper,_emscripten_glCullFace__wrapper,_emscripten_glClear__wrapper,_emscripten_glClearStencil__wrapper,_emscripten_glDepthMask__wrapper,_emscripten_glStencilMask__wrapper,_emscripten_glGenerateMipmap__wrapper,_emscripten_glActiveTexture__wrapper,_emscripten_glBlendEquation__wrapper,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79
  ,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79
  ,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79
  ,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79
  ,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79
  ,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79
  ,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79
  ,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79,b79];
  var FUNCTION_TABLE_vifiii = [b80,__ZN5physx7NpScene7collideEfPNS_10PxBaseTaskEPvj,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17CUDAProfileBufferEfPKhjj,__ZThn124_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17CUDAProfileBufferEfPKhjj];
  var FUNCTION_TABLE_iiiiiiifiiiiiiiiiffffi = [b81,__Z75UnityEngine_UnityEngine_TextGenerator_m_INTERNAL_CALL_Populate_Internal_cppP22mscorlib_System_ObjectP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_StringP28UnityEngine_UnityEngine_FontP29UnityEngine_UnityEngine_Colorifibbiiiibiffffb];
  var FUNCTION_TABLE_diiii = [b82,__Z151mscorlib_System_Double_m_Parse_mscorlib_System_Double_mscorlib_System_String_mscorlib_System_Globalization_NumberStyles_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringiS0_];
  var FUNCTION_TABLE_iiifiiii = [b83,__ZNK12PhysXRaycast9IntersectERK3RayfPN5physx12PxOverlapHitEP4AABBjR20BatchedRaycastResult];
  var FUNCTION_TABLE_viiiiiiiiiiiii = [b84,__ZN9GfxDevice22UpdateComputeResourcesEjPK9TextureIDPKijPKjjPK15ComputeBufferIDS4_jS9_S2_S6_,__Z361mscorlib_System_Globalization_SortKey_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Byte_arr_arr_mscorlib_System_Globalization_CompareOptions_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P37mscorlib_System_Globalization_SortKeyiP22mscorlib_System_StringP24mscorlib_System_Byte_arriiiiiiiii,b84];
  var FUNCTION_TABLE_iiiiiiiiiiffffii = [b85,__ZN5physx29createFinalizeSolverContacts4EPPNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPPNS_23PxcSolverConstraintDescEPPKNS_13PxcSolverBodyESB_PPKNS_17PxcSolverBodyDataESF_PPKNS_12PxsRigidCoreESJ_ffffRNS_25PxsConstraintBlockManagerENS_14PxFrictionType4EnumE,__ZN5physx36createFinalizeSolverContacts4CoulombEPPNS_13PxcNpWorkUnitERNS_18PxcNpThreadContextEPPNS_23PxcSolverConstraintDescEPPKNS_13PxcSolverBodyESB_PPKNS_17PxcSolverBodyDataESF_PPKNS_12PxsRigidCoreESJ_ffffRNS_25PxsConstraintBlockManagerENS_14PxFrictionType4EnumE,b85];
  var FUNCTION_TABLE_viiiiiiii = [b86,__ZNK5physx5cloth9SwFactory17extractFabricDataERKNS0_6FabricENS0_5RangeIjEES6_NS5_IfEES6_S6_S7_,__ZThn4_NK5physx5cloth9SwFactory17extractFabricDataERKNS0_6FabricENS0_5RangeIjEES6_NS5_IfEES6_S6_S7_,__ZNK5physx20PxsSolverCoreGeneral10writeBackVEPKNS_23PxcSolverConstraintDescEjPNS_25PxcThresholdStreamElementEjRjPNS_17PxcSolverBodyDataEPPFvRS2_RNS_16PxcSolverContextERS7_SC_E,__ZN9GfxDevice19RecordSetFFMaterialERKN9ShaderLab9VectorValES3_S3_S3_RKNS0_8FloatValEPKNS0_13PropertySheetERKNS0_17ShaderPassContextE,__ZN9GfxDevice17RecordEnableFFFogE7FogModeRKN9ShaderLab8FloatValES4_S4_RKNS1_9VectorValEPKNS1_13PropertySheetERKNS1_17ShaderPassContextE,__ZN9GfxDevice11DrawBuffersEP11IndexBufferPK18VertexStreamSourceiPK16DrawBuffersRangeiP17VertexDeclarationRK14ChannelAssigns,__ZN9GfxDevice19CreateSparseTextureE9TextureIDii13TextureFormati17TextureColorSpace,__ZN9GfxDevice23UploadSparseTextureTileE9TextureIDiiiPKhii,__ZN13GfxDeviceGLES16SetTextureParamsE9TextureID16TextureDimension17TextureFilterMode15TextureWrapModeib17TextureColorSpace,__ZN13GfxDeviceGLES11DrawBuffersEP11IndexBufferPK18VertexStreamSourceiPK16DrawBuffersRangeiP17VertexDeclarationRK14ChannelAssigns,__Z43mscorlib_System_Char_m_GetDataTablePointersP22mscorlib_System_ObjectPPhS2_PPdPPtS6_S6_S6_,__Z142mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_mscorlib_System_Int64_mscorlib_System_Int64P21mscorlib_System_ArrayP22mscorlib_System_Objectxxx,__Z66mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context_m__ctorP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_ContextiPhS1_S1_S1_S1_b,__Z207mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P24mscorlib_System_DateTimeiiiiiii,__ZNKSt3__18time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc,__ZNKSt3__18time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc,__ZNKSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe,__ZNKSt3__19money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE,__ZNKSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe,__ZNKSt3__19money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE,__Z17DebugStringToFilePKciS0_iiiiPFvRK11CppLogEntryE,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE21__grow_by_and_replaceEjjjjjjPKc,__ZN23ForwardShaderRenderLoop16PerformRenderingEPK11ActiveLightP13RenderTextureRK14ShadowCullDatabbbb,__Z29RenderForwardObjectsIntoDepthRK17RenderLoopContextP13RenderTextureP13dynamic_arrayI16RenderObjectDataLj4EE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseESC_iib,__Z25DoForwardShaderRenderLoopR17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EEbbP13RenderTextureR12ActiveLightsbb,__Z15CullLocalLightsR8JobFenceS0_RK22SceneCullingParametersRK13dynamic_arrayI8Vector4fLj4EERKS4_IiLj4EER9IndexListSD_RS4_IfLj4EE,__Z23BlitCopyCompressedImage13TextureFormatPKhiiPhiib,__ZN14SerializedFile10ReadObjectEx18ObjectCreationModebPPK8TypeTreePbR6Object
  ,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEjjjjjjPKc,__ZN12ShaderErrors11ShaderErrorC2ERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_S9_iibb,__Z23_SimulationFilterShaderjN5physx12PxFilterDataEjS0_RNS_7PxFlagsINS_10PxPairFlag4EnumEtEEPKvj,__ZN5physx31PxDefaultSimulationFilterShaderEjNS_12PxFilterDataEjS0_RNS_7PxFlagsINS_10PxPairFlag4EnumEtEEPKvj,__ZN9Heightmap17FillPatchVerticesERK14StrideIteratorI8Vector3fES4_RKS0_I8Vector2fEiiiP15TerrainRenderer,_glCompressedTexImage2D__wrapper,_glCopyTexSubImage2D__wrapper,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier60ELi16EEE21__grow_by_and_replaceEjjjjjjPKc,_emscripten_glCompressedTexImage2D__wrapper,_emscripten_glCopyTexImage2D__wrapper,_emscripten_glCopyTexSubImage2D__wrapper,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86,b86
  ,b86,b86,b86,b86,b86];
  var FUNCTION_TABLE_iid = [b87,__Z79mscorlib_System_Double_m_CompareTo_mscorlib_System_Int32_mscorlib_System_DoublePdd,__Z78mscorlib_System_Double_m_Equals_mscorlib_System_Boolean_mscorlib_System_DoublePdd,__Z35mscorlib_System_Double_m_IsInfinityP22mscorlib_System_Objectd,__Z30mscorlib_System_Double_m_IsNaNP22mscorlib_System_Objectd,__Z43mscorlib_System_Double_m_IsNegativeInfinityP22mscorlib_System_Objectd,__Z43mscorlib_System_Double_m_IsPositiveInfinityP22mscorlib_System_Objectd,__Z48mscorlib_System_BitConverter_m_DoubleToInt64BitsP22mscorlib_System_Objectd,__Z91mscorlib_System_BitConverter_m_GetBytes_mscorlib_System_Byte_arr_arr_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z80mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z80mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DoubleP21mscorlib_System_Arrayd,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DoubleP21mscorlib_System_Arrayd,__Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DoubleP21mscorlib_System_Arrayd,b87,b87,b87,b87,b87,b87,b87,b87
  ,b87,b87,b87];
  var FUNCTION_TABLE_iif = [b88,__ZN5physx3Cct13BoxController13setHalfHeightEf,__ZN5physx3Cct13BoxController17setHalfSideExtentEf,__ZN5physx3Cct13BoxController20setHalfForwardExtentEf,__ZN5physx3Cct17CapsuleController9setRadiusEf,__ZN5physx3Cct17CapsuleController9setHeightEf,__Z79mscorlib_System_Single_m_CompareTo_mscorlib_System_Int32_mscorlib_System_SinglePff,__Z78mscorlib_System_Single_m_Equals_mscorlib_System_Boolean_mscorlib_System_SinglePff,__Z35mscorlib_System_Single_m_IsInfinityP22mscorlib_System_Objectf,__Z30mscorlib_System_Single_m_IsNaNP22mscorlib_System_Objectf,__Z43mscorlib_System_Single_m_IsNegativeInfinityP22mscorlib_System_Objectf,__Z43mscorlib_System_Single_m_IsPositiveInfinityP22mscorlib_System_Objectf,__Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z76mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z80mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z80mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z41UnityEngine_UnityEngine_GUILayout_m_WidthP22mscorlib_System_Objectf,__Z42UnityEngine_UnityEngine_GUILayout_m_HeightP22mscorlib_System_Objectf,__Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_SingleP21mscorlib_System_Arrayf,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_SingleP21mscorlib_System_Arrayf,__Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_SingleP21mscorlib_System_Arrayf,__Z22ShaderDisablesBatchingP6Shaderf,__ZL19DrawSimpleWatermarkRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEff
  ,__ZN4FMOD7Channel12setFrequencyEf,__ZN15AnimationBinder13SetFloatValueERK20BoundCurveDeprecatedf,b88];
  var FUNCTION_TABLE_vifiiii = [b89,__ZN5physx7NpScene8simulateEfPNS_10PxBaseTaskEPvjb,__ZN5physx7NpScene5solveEfPNS_10PxBaseTaskEPvjb,b89];
  var FUNCTION_TABLE_viiiiiii = [b90,__ZNK5physx14NpArticulation22computeImpulseResponseEPNS_18PxArticulationLinkERNS_6PxVec3ES4_RKNS_24PxArticulationDriveCacheERKS3_S9_,__ZN5physx12NpBatchQuery7overlapERKNS_10PxGeometryERKNS_11PxTransformEtRKNS_17PxQueryFilterDataEPvPKNS_12PxQueryCacheE,__ZNK5physx5cloth9SwFactory20extractCollisionDataERKNS0_5ClothENS0_5RangeINS_6PxVec4EEENS5_IjEES7_S8_NS5_INS_6PxVec3EEE,__ZThn4_NK5physx5cloth9SwFactory20extractCollisionDataERKNS0_5ClothENS0_5RangeINS_6PxVec4EEENS5_IjEES7_S8_NS5_INS_6PxVec3EEE,__ZN5physx20PxsParticleSystemSim18removeInteractionVERKNS_16PxvParticleShapeEjjbbb,__ZN9GfxDevice17UpdateIndexBufferEP11IndexBuffer13GfxBufferMode14GfxBufferLabeljPKvj,__ZN9GfxDevice18UpdateVertexBufferEP12VertexBuffer13GfxBufferMode14GfxBufferLabeljPKvj,__ZN9GfxDevice16DynamicBatchMeshERK10Matrix4x4fRK16VertexBufferDatajjPKtj,__ZN9GfxDevice18DynamicBatchSpriteEPK10Matrix4x4fPK12SpriteVertexjPKtj11ColorRGBA32,__ZN14GfxDeviceStats15SetScreenParamsEiiiiii,__ZN13PhysicsModule33SetUpSkinnedBuffersOnSkinnedClothERN5Unity5ClothEPvS3_S3_jb,__ZN13GfxDeviceGLES17UpdateIndexBufferEP11IndexBuffer13GfxBufferMode14GfxBufferLabeljPKvj,__ZN13GfxDeviceGLES18UpdateVertexBufferEP12VertexBuffer13GfxBufferMode14GfxBufferLabeljPKvj,__ZN13GfxDeviceGLES21GrabIntoRenderTextureE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_iiii,__Z45mscorlib_System_String_m_ParseFormatSpecifierP22mscorlib_System_ObjectP22mscorlib_System_StringPiS3_S3_PbPS2_,__Z75mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_SetCJKReferencesP22mscorlib_System_ObjectP22mscorlib_System_StringPP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerPPhS7_S5_S7_,__Z66mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_FillCJKP22mscorlib_System_ObjectP22mscorlib_System_StringPP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerPPhS7_S5_S7_,__Z70mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_FillCJKCoreP22mscorlib_System_ObjectP22mscorlib_System_StringPP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerPPhS7_S5_S7_,__Z64mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_SetCJKTableP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP41mscorlib_System_Globalization_CultureInfoPP52mscorlib_Mono_Globalization_Unicode_CodePointIndexerPPhS7_S5_S7_,__Z280mscorlib_System_Reflection_MemberInfoSerializationHolder_m_Serialize_mscorlib_System_Void_mscorlib_System_Runtime_Serialization_SerializationInfo_mscorlib_System_String_mscorlib_System_Type_mscorlib_System_String_mscorlib_System_Reflection_MemberTypes_mscorlib_System_Type_arr_arrP22mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_StringP20mscorlib_System_TypeS4_iP24mscorlib_System_Type_arr,__Z52mscorlib_System_NumberFormatter_m_GetFormatterTablesP22mscorlib_System_ObjectPPyPPiPPtS6_PPxS4_,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy
  ,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe,__ZNKSt3__17num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe,__ZNKSt3__17num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv,__ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx,__ZNKSt3__17num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy,__ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx,__ZNKSt3__17num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy,__ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm,__ZNKSt3__19money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE
  ,__ZNKSt3__19money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE,__ZNSt3__116__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEjjjjjj,__ZN6il2cpp6icalls8mscorlib6System4Char20GetDataTablePointersEPPhS5_PPdPPtS9_S9_S9_,__ZN6Object13RegisterClassEiiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEiPFPS_10MemLabelId18ObjectCreationModeEbb,__ZN23ForwardShaderRenderLoop21RenderLightShadowMapsER16ForwardShadowMapR16ShadowCameraDatabbbRN9ShaderLab17ShaderPassContextE,__Z20AddActiveLocalLightsRK14ShadowCullDataPPK5LightPK8Vector4fRK9IndexListPfRS9_R12ActiveLights,__ZN17PackedFloatVector10PackFloatsEPKfiiiib,__Z7Empty3DPhiiiiii,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE9__grow_byEjjjjjj,__ZN7mecanim9animation16EvaluateAvatarSMEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantERKNS0_12AnimationSetE,__ZN7mecanim9animation16EvaluateAvatarIKEPKNS0_14AvatarConstantEPKNS0_11AvatarInputEPNS0_12AvatarOutputEPNS0_12AvatarMemoryEPNS0_15AvatarWorkspaceEPKNS0_18ControllerConstantEb,__ZN15TerrainRenderer11RenderStep3EP6CameraibPPN5Unity8MaterialEiS4_,__ZN20IntermediateRenderer10InitializeERK10Matrix4x4fRK4AABB4PPtrIN5Unity8MaterialEEibb,_glGetActiveAttrib__wrapper,_glGetActiveUniform__wrapper,_glReadPixels__wrapper,__ZN18VirtActionInvoker5I28mscorlib_System_ObjectTraitsS0_27mscorlib_System_Int32Traits17VoidPointerTraitsS2_E6InvokeEP10MethodInfoPvP22mscorlib_System_ObjectS8_iS6_S6_,__ZNSt3__19__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE,__ZNSt3__19__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE,__ZNSt3__19__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE,__ZNSt3__19__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE,__ZNSt3__116__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_,_emscripten_glReadPixels__wrapper,_emscripten_glGetActiveUniform__wrapper,_emscripten_glGetActiveAttrib__wrapper,b90,b90,b90,b90
  ,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90,b90
  ,b90,b90,b90,b90,b90,b90,b90,b90,b90];
  var FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiii = [b91,__ZN5physx26solveVBlockDefaultFrictionEPNS_13PxsSolverCoreEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS9_jRNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENSA_19ReflectionAllocatorISC_EEEESG_PNS_2Cm13SpatialVectorEPNS_25PxcThresholdStreamElementEjRj,__ZN5physx26solveVBlockCoulombFrictionEPNS_13PxsSolverCoreEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS9_jRNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENSA_19ReflectionAllocatorISC_EEEESG_PNS_2Cm13SpatialVectorEPNS_25PxcThresholdStreamElementEjRj,__ZNK5physx20PxsSolverCoreGeneral13solveV_BlocksEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jRNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENS9_19ReflectionAllocatorISB_EEEESF_PNS_2Cm13SpatialVectorEPNS_25PxcThresholdStreamElementEjRj,__ZNK5physx20PxsSolverCoreGeneral20solveVCoulomb_BlocksEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jRNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENS9_19ReflectionAllocatorISB_EEEESF_PNS_2Cm13SpatialVectorEPNS_25PxcThresholdStreamElementEjRj,b91,b91,b91];
  var FUNCTION_TABLE_viiiiiiiii = [b92,__ZN9GfxDevice20BeginDynamicBatchingERK14ChannelAssignsjbjP17VertexDeclarationjj16GfxPrimitiveType,__ZN9GfxDevice9SkinOnGPUERK18VertexStreamSourceP12VertexBufferP17GPUSkinPoseBufferS4_iijb,__ZN9GfxDevice28UpdateComputeConstantBuffersEjP12ObjectHandleI18ConstantBuffer_TagPvEjjPKhPKjS8_PKi,__ZN13GfxDeviceGLES9SkinOnGPUERK18VertexStreamSourceP12VertexBufferP17GPUSkinPoseBufferS4_iijb,__Z159mscorlib_System_Array_m_Copy_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int64_mscorlib_System_Array_mscorlib_System_Int64_mscorlib_System_Int64P22mscorlib_System_ObjectP21mscorlib_System_ArrayxS2_xx,__Z62mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendKanaP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhhhhbhbb,__ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc,__ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc,__Z19DoPrePassRenderLoopR17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EES4_RP13RenderTextureS7_S7_R12ActiveLightsbPb,__ZL25UpdateCameraDepthTexturesR6CameraP13RenderTextureS2_R13dynamic_arrayI16RenderObjectDataLj4EERK17ShaderReplaceDatabbbRN9ShaderLab17ShaderPassContextE,__Z20DoDeferredRenderLoopR17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EES4_RP13RenderTextureS7_S7_R12ActiveLightsbPb,_png_set_IHDR,__ZN17SharedTextureDataC2E10MemLabelIdii13TextureFormatiibb,_glCompressedTexSubImage2D__wrapper,_glTexImage2D__wrapper,_glTexSubImage2D__wrapper,_emscripten_glCompressedTexSubImage2D__wrapper,_emscripten_glTexImage2D__wrapper,_emscripten_glTexSubImage2D__wrapper,b92,b92,b92,b92,b92,b92,b92,b92,b92
  ,b92,b92,b92];
  var FUNCTION_TABLE_viiiiiif = [b93,__ZN13GfxDeviceGLES10SetTextureE10ShaderTypeii9TextureID16TextureDimensionf];
  var FUNCTION_TABLE_iii = [b94,__ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9pbackfailEi,__ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE8overflowEi,__ZN6il2cpp2os11MutexHandle4WaitEj,__ZN6il2cpp2os11EventHandle4WaitEj,__ZN6il2cpp2os15SemaphoreHandle4WaitEj,_deflate_stored,_deflate_fast,_deflate_slow,__ZN5physx3Cct13BoxController11setPositionERKNS_14PxExtendedVec3E,__ZN5physx3Cct13BoxController15setFootPositionERKNS_14PxExtendedVec3E,__ZNK5physx3Cct13BoxController11getWorldBoxERNS_17PxExtendedBounds3E,__ZThn8_NK5physx3Cct13BoxController11getWorldBoxERNS_17PxExtendedBounds3E,__ZN5physx3Cct17CapsuleController11setPositionERKNS_14PxExtendedVec3E,__ZN5physx3Cct17CapsuleController15setFootPositionERKNS_14PxExtendedVec3E,__ZN5physx3Cct17CapsuleController15setClimbingModeENS_21PxCapsuleClimbingMode4EnumE,__ZNK5physx3Cct17CapsuleController11getWorldBoxERNS_17PxExtendedBounds3E,__ZThn8_NK5physx3Cct17CapsuleController11getWorldBoxERNS_17PxExtendedBounds3E,__ZN5physx3Cct26CharacterControllerManager13getControllerEj,__ZN5physx3Cct26CharacterControllerManager16createControllerERKNS_16PxControllerDescE,__ZN5physx3Cct26CharacterControllerManager18getObstacleContextEj,__ZN5physx3Cct15ObstacleContext11addObstacleERKNS_10PxObstacleE,__ZN5physx3Cct15ObstacleContext14removeObstacleEj,__ZNK5physx3Cct15ObstacleContext11getObstacleEj,__ZNK5physx3Cct15ObstacleContext19getObstacleByHandleEj,__ZNK5physx11PxAggregate8isKindOfEPKc,__ZN5physx11NpAggregate8addActorERNS_7PxActorE,__ZN5physx11NpAggregate11removeActorERNS_7PxActorE,__ZN5physx11NpAggregate15addArticulationERNS_14PxArticulationE
  ,__ZN5physx11NpAggregate18removeArticulationERNS_14PxArticulationE,__ZNK5physx14PxArticulation8isKindOfEPKc,__ZNK5physx19PxArticulationJoint8isKindOfEPKc,__ZNK5physx18PxArticulationLink8isKindOfEPKc,__ZNK5physx12PxConstraint8isKindOfEPKc,__ZN5physx12NpConstraint20getExternalReferenceERj,__ZNK5physx10PxMaterial8isKindOfEPKc,__ZN5physx9NpPhysics18createTriangleMeshERNS_13PxInputStreamE,__ZN5physx9NpPhysics17createHeightFieldERKNS_17PxHeightFieldDescE,__ZN5physx9NpPhysics17createHeightFieldERNS_13PxInputStreamE,__ZN5physx9NpPhysics16createConvexMeshERNS_13PxInputStreamE,__ZN5physx9NpPhysics17createClothFabricERNS_13PxInputStreamE,__ZN5physx9NpPhysics17createClothFabricERKNS_17PxClothFabricDescE,__ZN5physx9NpPhysics11createSceneERKNS_11PxSceneDescE,__ZN5physx9NpPhysics17createRigidStaticERKNS_11PxTransformE,__ZN5physx9NpPhysics18createRigidDynamicERKNS_11PxTransformE,__ZN5physx26NpPhysicsInsertionCallback12insertObjectERNS_6PxBaseE,__ZNK5physx14PxRigidDynamic8isKindOfEPKc,__ZN5physx14NpRigidDynamic18getKinematicTargetERNS_11PxTransformE,__ZNK5physx13PxRigidStatic8isKindOfEPKc,__ZNK5physx7NpScene11getNbActorsENS_7PxFlagsINS_15PxActorTypeFlag4EnumEtEE,__ZNK5physx7NpScene26getSimulationEventCallbackEh,__ZNK5physx7NpScene21getBroadPhaseCallbackEh,__ZN5physx7NpScene12checkResultsEb,__ZN5physx7NpScene16createBatchQueryERKNS_16PxBatchQueryDescE,__ZNK5physx7NpScene17getBroadPhaseCapsERNS_16PxBroadPhaseCapsE,__ZN5physx7NpScene22removeBroadPhaseRegionEj,__ZN5physx7NpScene14checkCollisionEb,__ZNK5physx7PxShape8isKindOfEPKc,__ZNK5physx7NpShape14getBoxGeometryERNS_13PxBoxGeometryE
  ,__ZNK5physx7NpShape17getSphereGeometryERNS_16PxSphereGeometryE,__ZNK5physx7NpShape18getCapsuleGeometryERNS_17PxCapsuleGeometryE,__ZNK5physx7NpShape16getPlaneGeometryERNS_15PxPlaneGeometryE,__ZNK5physx7NpShape21getConvexMeshGeometryERNS_20PxConvexMeshGeometryE,__ZNK5physx7NpShape23getTriangleMeshGeometryERNS_22PxTriangleMeshGeometryE,__ZNK5physx7NpShape22getHeightFieldGeometryERNS_21PxHeightFieldGeometryE,__ZNK5physx7NpShape32getMaterialFromInternalFaceIndexEj,__ZNK5physx15PxParticleFluid8isKindOfEPKc,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE15createParticlesERKNS_22PxParticleCreationDataE,__ZN5physx15NpParticleFluid25lockParticleFluidReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE,__ZN5physx15NpParticleFluid2isENS_11PxActorType4EnumE,__ZNK5physx15NpParticleFluid2isENS_11PxActorType4EnumE,__ZNK5physx16PxParticleSystem8isKindOfEPKc,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20lockParticleReadDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE15createParticlesERKNS_22PxParticleCreationDataE,__ZNK5physx7PxCloth8isKindOfEPKc,__ZN5physx7NpCloth16lockParticleDataENS_7PxFlagsINS_16PxDataAccessFlag4EnumEhEE,__ZNK5physx7NpCloth24getParticleAccelerationsEPNS_6PxVec4E,__ZNK5physx7NpCloth20getMotionConstraintsEPNS_31PxClothParticleMotionConstraintE,__ZNK5physx7NpCloth24getSeparationConstraintsEPNS_35PxClothParticleSeparationConstraintE,__ZNK5physx7NpCloth23getSelfCollisionIndicesEPj,__ZNK5physx7NpCloth16getRestPositionsEPNS_6PxVec4E,__ZNK5physx13PxClothFabric8isKindOfEPKc,__ZNK5physx13NpClothFabric12getPhaseTypeEj,__ZN5physx2Sc20ArticulationJointSim10onActivateEj,__ZN5physx2Sc20ArticulationJointSim12onDeactivateEj,__ZN5physx2Sc21ConstraintInteraction10onActivateEj,__ZN5physx2Sc21ConstraintInteraction12onDeactivateEj,__ZN5physx2Sc24ElementInteractionMarker10onActivateEj
  ,__ZN5physx2Sc24ElementInteractionMarker12onDeactivateEj,__ZThn8_N5physx2Sc24ElementInteractionMarker10onActivateEj,__ZThn8_N5physx2Sc24ElementInteractionMarker12onDeactivateEj,__ZN5physx2Sc19ShapeInstancePairLL10onActivateEj,__ZN5physx2Sc19ShapeInstancePairLL12onDeactivateEj,__ZThn8_N5physx2Sc19ShapeInstancePairLL10onActivateEj,__ZThn8_N5physx2Sc19ShapeInstancePairLL12onDeactivateEj,__ZN5physx2Sc18TriggerInteraction10onActivateEj,__ZN5physx2Sc18TriggerInteraction12onDeactivateEj,__ZThn8_N5physx2Sc18TriggerInteraction10onActivateEj,__ZThn8_N5physx2Sc18TriggerInteraction12onDeactivateEj,__ZN5physx2Sc35ParticleElementRbElementInteraction10onActivateEj,__ZN5physx2Sc35ParticleElementRbElementInteraction12onDeactivateEj,__ZThn8_N5physx2Sc35ParticleElementRbElementInteraction10onActivateEj,__ZThn8_N5physx2Sc35ParticleElementRbElementInteraction12onDeactivateEj,__ZN5physx2Sc11Interaction10onActivateEj,__ZN5physx2Sc11Interaction12onDeactivateEj,__ZN5physx5cloth9SwFactory5cloneERKNS0_5ClothE,__ZThn4_N5physx5cloth9SwFactory5cloneERKNS0_5ClothE,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE5cloneERNS0_7FactoryE,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE5cloneERNS0_7FactoryE,__ZNK5physx16PxsBroadPhaseMBP7getCapsERNS_16PxBroadPhaseCapsE,__ZN5physx16PxsBroadPhaseMBP12removeRegionEj,__ZNK5physx16PxBroadPhaseBase7getCapsERNS_16PxBroadPhaseCapsE,__ZN5physx16PxBroadPhaseBase12removeRegionEj,__ZN5physx15PxsParticleData13addParticlesVERKNS_22PxParticleCreationDataE,__ZNK5physx2Sq10AABBPruner10getPayloadERKj,__ZNK5physx2Sq12BucketPruner10getPayloadERKj,__ZNK5physx2Sq11PruningPool10getPayloadERKj,__ZNK5physx16PxVehicleNoDrive8isKindOfEPKc
  ,__ZNK5physx18PxVehicleDriveTank8isKindOfEPKc,__ZNK5physx16PxVehicleDriveNW8isKindOfEPKc,__ZNK5physx16PxVehicleDrive4W8isKindOfEPKc,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDrive4WEE14allocateObjectERNS_23PxRepXInstantiationArgsE,__ZN5physx23PxVehicleRepXSerializerINS_18PxVehicleDriveTankEE14allocateObjectERNS_23PxRepXInstantiationArgsE,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleDriveNWEE14allocateObjectERNS_23PxRepXInstantiationArgsE,__ZN5physx23PxVehicleRepXSerializerINS_16PxVehicleNoDriveEE14allocateObjectERNS_23PxRepXInstantiationArgsE,__ZNK5physx14PxVehicleDrive8isKindOfEPKc,__ZN5physx25PxVehicleConstraintShader20getExternalReferenceERj,__ZN5physx7Cooking20validateTriangleMeshERKNS_18PxTriangleMeshDescE,__ZNK5physx14PxTriangleMesh8isKindOfEPKc,__ZNK5physx2Gu12TriangleMesh24getTriangleMaterialIndexEj,__ZNK5physx12PxConvexMesh8isKindOfEPKc,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17getEventIdForNameEPKc,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17getEventIdForNameEPKc,__ZN5physx9PxTaskMgr12getNamedTaskEPKc,__ZN5physx9PxTaskMgr13getTaskFromIDEm,__ZNK5physx9PxTaskMgr12getReferenceEm,__ZNK5physx13PxHeightField8isKindOfEPKc,__ZNK5physx2Gu11HeightField24getTriangleMaterialIndexEj,__ZN13BaseAllocator13TryDeallocateEPv,__ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE8ContainsEPKv,__ZNK21UnityDefaultAllocatorI17LowLevelAllocatorE10GetPtrSizeEPKv,__ZN20DynamicHeapAllocatorI17LowLevelAllocatorE13TryDeallocateEPv,__ZNK20DynamicHeapAllocatorI17LowLevelAllocatorE8ContainsEPKv,__ZNK20DynamicHeapAllocatorI17LowLevelAllocatorE10GetPtrSizeEPKv,__ZN14StackAllocator13TryDeallocateEPv,__ZNK14StackAllocator8ContainsEPKv,__ZNK14StackAllocator10GetPtrSizeEPKv,__ZN12TLSAllocatorI14StackAllocatorE13TryDeallocateEPv
  ,__ZNK12TLSAllocatorI14StackAllocatorE8ContainsEPKv,__ZNK12TLSAllocatorI14StackAllocatorE10GetPtrSizeEPKv,__ZNK12BaseRenderer14GetSubsetIndexEi,__ZNK24MeshIntermediateRenderer14GetSubsetIndexEi,__ZNK8Renderer14GetSubsetIndexEi,__ZThn28_NK8Renderer14GetSubsetIndexEi,__ZN22BlockMemoryCacheWriter15CompleteWritingEj,__ZN9GfxDevice20GetVertexDeclarationERK18VertexChannelsInfo,__ZN9GfxDevice23GetNativeTexturePointerE9TextureID,__ZN9GfxDevice18GetNativeTextureIDE9TextureID,__ZN16ScriptingManager14IsTrustedTokenERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZNK32RendererMaterialAnimationBinding12GetPPtrValueERKN11UnityEngine9Animation10BoundCurveE,__ZNK24RendererAnimationBinding12GetPPtrValueERKN11UnityEngine9Animation10BoundCurveE,__ZN23PreloadManagerOperation19IntegrateTimeSlicedEi,__ZN18LoadLevelOperation19IntegrateTimeSlicedEi,__ZN9TextAsset9SetScriptERK8UnityStr,__ZNK28MonoBehaviourPropertyBinding12GetPPtrValueERKN11UnityEngine9Animation10BoundCurveE,__ZN19ScriptingInvocation6InvokeEPP18ScriptingException,__ZN25ScriptingInvocationNoArgs6InvokeEPP18ScriptingException,__ZN6Shader9SetScriptERK8UnityStr,__ZN16MemoryFileSystem5CloseER13FileEntryData,__ZNK16MemoryFileSystem8PositionERK13FileEntryData,__ZNK16MemoryFileSystem4SizeERK13FileEntryData,__ZNK16MemoryFileSystem9CanHandleEPKc,__ZN16MemoryFileSystem18IsAbsoluteFilePathEPKc,__ZNK16MemoryFileSystem8FilenameERK13FileEntryData,__ZNK16MemoryFileSystem5IsDirERK13FileEntryData,__ZNK16MemoryFileSystem8IsHiddenERK13FileEntryData,__ZNK16MemoryFileSystem9IsSymLinkERK13FileEntryData,__ZN16MemoryFileSystem8IsLockedERK13FileEntryData
  ,__ZN16MemoryFileSystem12CreateAsFileER13FileEntryData,__ZN16MemoryFileSystem11CreateAsDirER13FileEntryData,__ZN16MemoryFileSystem11MoveToTrashER13FileEntryData,__ZN16MemoryFileSystem5TouchER13FileEntryData,__ZNK16MemoryFileSystem6ExistsERK13FileEntryData,__ZN25MultiBlocksMemoryFileData4LockEPPv,__ZN20LocalFileSystemPosix5CloseER13FileEntryData,__ZNK20LocalFileSystemPosix8PositionERK13FileEntryData,__ZNK20LocalFileSystemPosix4SizeERK13FileEntryData,__ZNK22LocalFileSystemHandler9CanHandleEPKc,__ZN22LocalFileSystemHandler18IsAbsoluteFilePathEPKc,__ZNK20LocalFileSystemPosix8FilenameERK13FileEntryData,__ZNK20LocalFileSystemPosix5IsDirERK13FileEntryData,__ZNK20LocalFileSystemPosix8IsHiddenERK13FileEntryData,__ZNK20LocalFileSystemPosix9IsSymLinkERK13FileEntryData,__ZN20LocalFileSystemPosix8IsLockedERK13FileEntryData,__ZN20LocalFileSystemPosix12CreateAsFileER13FileEntryData,__ZN20LocalFileSystemPosix11CreateAsDirER13FileEntryData,__ZN17FileSystemHandler11MoveToTrashER13FileEntryData,__ZN17FileSystemHandler5TouchER13FileEntryData,__ZNK20LocalFileSystemPosix6ExistsERK13FileEntryData,__ZN12PhysXRaycast26GetGameObjectForRaycastHitERK10RaycastHit,__ZN13PhysicsModule20ConvertContactToMonoEP9Collision,__ZN13PhysicsModule29GetColliderMaterialInstanceIDER8Collider,__ZN13PhysicsModule31GetColliderSharedMeshInstanceIDER12MeshCollider,__ZN13PhysicsModule19CreateNxHeightFieldEPv,__ZN11AudioModule27IsFormatSupportedByPlatformEPKc,__ZN11AudioModule30GetOrCreateDSPFromCustomFilterEP17AudioCustomFilter,__ZN11AudioModule23CreateAudioCustomFilterEP13MonoBehaviour,__ZN11AudioModule27GetDSPFromAudioCustomFilterEP17AudioCustomFilter
  ,__ZN29AnimationStateNetworkProvider29GetNetworkAnimationStateCountER9Animation,__ZN14TerrainManager26Heightmap_GetPxHeightFieldER9Heightmap,__ZN14TerrainManager23TryGetSplatBaseMaterialEP7Terrain,__ZN14TerrainManager21GetEnlightenProxyMeshEP7Terrain,__ZN14TerrainManager23CreateTerrainGameObjectEP11TerrainData,__ZNK26LegacyTreeInstanceRenderer14GetSubsetIndexEi,__ZNK23LODTreeInstanceRenderer14GetSubsetIndexEi,__Z7FTAllocP13FT_MemoryRec_l,__ZN13GfxDeviceGLES16CreateBlendStateERK13GfxBlendState,__ZN13GfxDeviceGLES16CreateDepthStateERK13GfxDepthState,__ZN13GfxDeviceGLES18CreateStencilStateERK15GfxStencilState,__ZN13GfxDeviceGLES17CreateRasterStateERK14GfxRasterState,__ZNK13GfxDeviceGLES14IsShaderActiveE10ShaderType,__ZN13GfxDeviceGLES20GetVertexDeclarationERK18VertexChannelsInfo,__ZN13GfxDeviceGLES27GetActiveRenderColorSurfaceEi,__ZN13GfxDeviceGLES23GetNativeTexturePointerE9TextureID,__ZN13GfxDeviceGLES22IsCombineModeSupportedEj,__ZN13GfxDeviceGLES15ActivateDisplayEj,__ZN13GfxDeviceGLES16SetDisplayTargetEj,__ZN26VertexDeclarationCacheGLES23CreateVertexDeclarationERK18VertexChannelsInfo,__ZN15TextureTFMethod13MapBoneBufferEj,__ZN15TextureTFMethod20IsBoneCountSupportedEi,__ZN21UniformBufferTFMethod13MapBoneBufferEj,__ZN21UniformBufferTFMethod20IsBoneCountSupportedEi,__ZN15UniformTFMethod13MapBoneBufferEj,__ZN15UniformTFMethod20IsBoneCountSupportedEi,__Z45AssemblyU002DCSharp_LevelBuilder_m_CreateNodeP32AssemblyU002DCSharp_LevelBuilderP30AssemblyU002DCSharp_JSONObject,__Z45AssemblyU002DCSharp_JSONObject_m_StringObjectP22mscorlib_System_ObjectP22mscorlib_System_String,__Z95AssemblyU002DCSharp_JSONObject_m_GetField_AssemblyU002DCSharp_JSONObject_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String,__Z42AssemblyU002DCSharp_JSONObject_m_HasFieldsP30AssemblyU002DCSharp_JSONObjectP26mscorlib_System_String_arr
  ,__Z41AssemblyU002DCSharp_JSONObject_m_HasFieldP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String,__Z85AssemblyU002DCSharp_JSONObject_m_print_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectb,__Z94AssemblyU002DCSharp_JSONObject_m_get_Item_AssemblyU002DCSharp_JSONObject_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjecti,__Z95AssemblyU002DCSharp_JSONObject_m_get_Item_AssemblyU002DCSharp_JSONObject_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String,__Z88AssemblyU002DCSharp_JSONObject_m_ToString_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectb,__Z107AssemblyU002DCSharp_JSONObject_m_op_Implicit_UnityEngine_UnityEngine_WWWForm_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z99AssemblyU002DCSharp_JSONObject_m_op_Implicit_mscorlib_System_Boolean_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z42AssemblyU002DCSharp_JSONTemplates_m_TOJSONP22mscorlib_System_ObjectS0_,__Z47AssemblyU002DCSharp_JSONTemplates_m_FromVector2P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector2,__Z47AssemblyU002DCSharp_JSONTemplates_m_FromVector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z47AssemblyU002DCSharp_JSONTemplates_m_FromVector4P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4,__Z49AssemblyU002DCSharp_JSONTemplates_m_FromMatrix4x4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4,__Z50AssemblyU002DCSharp_JSONTemplates_m_FromQuaternionP22mscorlib_System_Object34UnityEngine_UnityEngine_Quaternion,__Z45AssemblyU002DCSharp_JSONTemplates_m_FromColorP22mscorlib_System_Object29UnityEngine_UnityEngine_Color,__Z49AssemblyU002DCSharp_JSONTemplates_m_FromLayerMaskP22mscorlib_System_Object33UnityEngine_UnityEngine_LayerMask,__Z47AssemblyU002DCSharp_JSONTemplates_m_ToLayerMaskP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z44AssemblyU002DCSharp_JSONTemplates_m_FromRectP22mscorlib_System_Object28UnityEngine_UnityEngine_Rect,__Z50AssemblyU002DCSharp_JSONTemplates_m_FromRectOffsetP22mscorlib_System_ObjectP34UnityEngine_UnityEngine_RectOffset,__Z48AssemblyU002DCSharp_JSONTemplates_m_ToRectOffsetP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__ZL96mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_AddP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_ContainsP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL100mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_IndexOfP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_get_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ContainsP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_IndexOfP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_RemoveP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objecti,__ZL128mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_GetHashCodeP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL107mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_GetHashCodeP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL104mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_AddP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object
  ,__ZL109mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_ContainsP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL108mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_IndexOfP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL109mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_get_ItemP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti,__ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_ContainsP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL83mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_IndexOfP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL82mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_RemoveP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_get_ItemP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjecti,__ZL136mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IEqualityComparer_GetHashCodeP85mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObject_m_GetHashCodeP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL96mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_AddP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_ContainsP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL100mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_IndexOfP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_get_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_ContainsP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_String,__ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_IndexOfP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_String,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_RemoveP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP22mscorlib_System_String,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_get_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringi,__ZL128mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m_System_Collections_IEqualityComparer_GetHashCodeP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_StringP22mscorlib_System_Object,__ZL107mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_String_m_GetHashCodeP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_StringP22mscorlib_System_String,__Z227mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z225mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_RemoveP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String,__Z126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ContainsKeyValuePairP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ContainsValueP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String,__Z227mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z225mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_RemoveP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsValueP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__Z126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ContainsKeyValuePairP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL185mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object
  ,__ZL183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__ZL159mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__ZL185mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String,__ZL183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_String,__ZL159mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String_m_EndInvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object,__Z235mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_RemoveP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_String,__Z134mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ContainsKeyValuePairP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ContainsValueP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObject,__ZL175mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject_m_EndInvokeP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__Z126mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m_System_Collections_IEqualityComparer_GetHashCodeP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_CharP22mscorlib_System_Object,__Z105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Char_m_GetHashCodeP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Chart,__ZL89System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetLinkHashCodeP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Objecti,__ZL89System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetItemHashCodeP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL77System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_AddP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL82System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_ContainsP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL80System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_RemoveP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object,__ZL95System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_TestPrimeP22mscorlib_System_Objecti,__ZL95System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_CalcPrimeP22mscorlib_System_Objecti,__ZL93System_Core_System_Collections_Generic_HashSet_1_PrimeHelper_mscorlib_System_Object_m_ToPrimeP22mscorlib_System_Objecti,__Z226mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z224mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_RemoveP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_String,__Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ContainsValueP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32i,__Z125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ContainsKeyValuePairP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z184mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32i,__Z182mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32i
  ,__Z157mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32_m_EndInvokeP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32P22mscorlib_System_Object,__Z127mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m_System_Collections_IEqualityComparer_GetHashCodeP76mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32P22mscorlib_System_Object,__Z106mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32_m_GetHashCodeP92mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32i,__ZL84Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_YieldDefaultP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Objecti,__Z100mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime_m_GetHashCodeP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime24mscorlib_System_DateTime,__Z130mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m_System_Collections_IEqualityComparer_GetHashCodeP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeP22mscorlib_System_Object,__Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime_m_GetHashCodeP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime24mscorlib_System_DateTime,__Z106mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset_m_GetHashCodeP92mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffset,__Z136mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m_System_Collections_IEqualityComparer_GetHashCodeP85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffsetP22mscorlib_System_Object,__Z115mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m_GetHashCodeP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffset,__Z107mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanP22mscorlib_System_Object,__Z113mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_Equals_mscorlib_System_Boolean_mscorlib_System_Nullable_1_TP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanS_,__Z96mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid_m_GetHashCodeP82mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid20mscorlib_System_Guid,__Z126mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m_System_Collections_IEqualityComparer_GetHashCodeP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_GuidP22mscorlib_System_Object,__Z105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid_m_GetHashCodeP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid20mscorlib_System_Guid,__Z100mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan_m_GetHashCodeP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan24mscorlib_System_TimeSpan,__Z130mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m_System_Collections_IEqualityComparer_GetHashCodeP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpanP22mscorlib_System_Object,__Z109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan_m_GetHashCodeP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan24mscorlib_System_TimeSpan,__ZL94mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_AddP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_ContainsP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL98mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_IndexOfP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_get_ItemP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_ContainsP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP20mscorlib_System_Type,__ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_IndexOfP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP20mscorlib_System_Type,__ZL72mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_RemoveP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP20mscorlib_System_Type,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_get_ItemP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typei,__ZL126mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m_System_Collections_IEqualityComparer_GetHashCodeP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TypeP22mscorlib_System_Object,__ZL105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Type_m_GetHashCodeP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TypeP20mscorlib_System_Type,__Z257mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z255mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp
  ,__Z142mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_RemoveP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Event,__Z149mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ContainsValueP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi,__Z156mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ContainsKeyValuePairP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z215mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi,__Z213mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpi,__Z212mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_EndInvokeP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object,__ZL135mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m_System_Collections_IEqualityComparer_GetHashCodeP84mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_EventP22mscorlib_System_Object,__ZL114mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Event_m_GetHashCodeP100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_EventP29UnityEngine_UnityEngine_Event,__Z151mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEqualityComparer_GetHashCodeP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object,__Z130mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_GetHashCodeP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOpi,__Z106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_AddP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_ContainsP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_ContainsP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex,__Z110mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_IndexOfP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_IndexOfP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex,__Z84mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_RemoveP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex,__Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_get_ItemP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi,__Z138mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IEqualityComparer_GetHashCodeP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_Object,__Z117mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex_m_GetHashCodeP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertex,__Z108mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_AddP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_ContainsP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_ContainsP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo,__Z112mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_IndexOfP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_IndexOfP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_RemoveP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo,__Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_get_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi,__Z140mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IEqualityComparer_GetHashCodeP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_Object,__Z119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo_m_GetHashCodeP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfo,__Z108mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_AddP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_ContainsP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object
  ,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_ContainsP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo,__Z112mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_IndexOfP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_IndexOfP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_RemoveP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo,__Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_get_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi,__Z140mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IEqualityComparer_GetHashCodeP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_Object,__Z119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo_m_GetHashCodeP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfo,__ZL119mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_AddP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL124mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_ContainsP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL123mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_IndexOfP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL124mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_get_ItemP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli,__ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_ContainsP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL98mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_IndexOfP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_RemoveP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_ItemP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalli,__ZL151mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IEqualityComparer_GetHashCodeP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_Object,__ZL130mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCall_m_GetHashCodeP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL122mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_AddP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL127mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_ContainsP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL126mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_IndexOfP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL127mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_get_ItemP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli,__ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_ContainsP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL101mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_IndexOfP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_RemoveP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_ItemP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalli,__ZL154mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IEqualityComparer_GetHashCodeP103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_Object,__ZL133mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_GetHashCodeP119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__Z256mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z254mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z141mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_RemoveP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachei
  ,__Z148mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ContainsValueP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z155mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ContainsKeyValuePairP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z214mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z212mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z218mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_EndInvokeP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object,__ZL158mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEqualityComparer_GetHashCodeP107mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object,__ZL137mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_GetHashCodeP123mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL112mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_AddP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_ContainsP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL116mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_IndexOfP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_get_ItemP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi,__ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_ContainsP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_IndexOfP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_RemoveP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_ItemP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryi,__ZL144mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IEqualityComparer_GetHashCodeP93mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_Object,__ZL123mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntry_m_GetHashCodeP109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntry,__Z237mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_ContainsP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z235mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_RemoveP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_RemoveP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_String,__Z136mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ContainsKeyValuePairP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL129mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ContainsValueP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle,__ZL195mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_ContainsP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle,__ZL193mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_RemoveP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle,__ZL179mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle_m_EndInvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object,__ZL138mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEqualityComparer_GetHashCodeP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyle_m_GetHashCodeP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyle,__ZL98mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_AddP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object,__ZL103mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_ContainsP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object,__ZL102mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_IndexOfP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP22mscorlib_System_Object
  ,__ZL103mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_get_ItemP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_ContainsP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr,__ZL77mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_IndexOfP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_RemoveP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_get_ItemP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arri,__ZL130mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m_System_Collections_IEqualityComparer_GetHashCodeP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arrP22mscorlib_System_Object,__ZL109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arr_m_GetHashCodeP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arr,__Z78mscorlib_System_Object_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_,__Z44mscorlib_System_Object_m_InternalGetHashCodeP22mscorlib_System_ObjectS0_,__Z34mscorlib_System_ValueType_m_EqualsP22mscorlib_System_ObjectS0_,__Z34mscorlib_System_Attribute_m_EqualsP25mscorlib_System_AttributeP22mscorlib_System_Object,__Z53mscorlib_System_Int32_m_System_IConvertible_ToBooleanPiP22mscorlib_System_Object,__Z50mscorlib_System_Int32_m_System_IConvertible_ToBytePiP22mscorlib_System_Object,__Z50mscorlib_System_Int32_m_System_IConvertible_ToCharPiP22mscorlib_System_Object,__Z51mscorlib_System_Int32_m_System_IConvertible_ToInt16PiP22mscorlib_System_Object,__Z51mscorlib_System_Int32_m_System_IConvertible_ToInt32PiP22mscorlib_System_Object,__Z51mscorlib_System_Int32_m_System_IConvertible_ToInt64PiP22mscorlib_System_Object,__Z51mscorlib_System_Int32_m_System_IConvertible_ToSBytePiP22mscorlib_System_Object,__Z52mscorlib_System_Int32_m_System_IConvertible_ToUInt16PiP22mscorlib_System_Object,__Z52mscorlib_System_Int32_m_System_IConvertible_ToUInt32PiP22mscorlib_System_Object,__Z52mscorlib_System_Int32_m_System_IConvertible_ToUInt64PiP22mscorlib_System_Object,__Z78mscorlib_System_Int32_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPiP22mscorlib_System_Object,__Z77mscorlib_System_Int32_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPiP22mscorlib_System_Object,__Z77mscorlib_System_Int32_m_CompareTo_mscorlib_System_Int32_mscorlib_System_Int32Pii,__Z76mscorlib_System_Int32_m_Equals_mscorlib_System_Boolean_mscorlib_System_Int32Pii,__Z74mscorlib_System_Int32_m_Parse_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z87mscorlib_System_Int32_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPiP22mscorlib_System_Object,__Z78mscorlib_System_Int32_m_ToString_mscorlib_System_String_mscorlib_System_StringPiP22mscorlib_System_String,__Z53mscorlib_System_Int64_m_System_IConvertible_ToBooleanPxP22mscorlib_System_Object,__Z50mscorlib_System_Int64_m_System_IConvertible_ToBytePxP22mscorlib_System_Object
  ,__Z50mscorlib_System_Int64_m_System_IConvertible_ToCharPxP22mscorlib_System_Object,__Z51mscorlib_System_Int64_m_System_IConvertible_ToInt16PxP22mscorlib_System_Object,__Z51mscorlib_System_Int64_m_System_IConvertible_ToInt32PxP22mscorlib_System_Object,__Z51mscorlib_System_Int64_m_System_IConvertible_ToInt64PxP22mscorlib_System_Object,__Z51mscorlib_System_Int64_m_System_IConvertible_ToSBytePxP22mscorlib_System_Object,__Z52mscorlib_System_Int64_m_System_IConvertible_ToUInt16PxP22mscorlib_System_Object,__Z52mscorlib_System_Int64_m_System_IConvertible_ToUInt32PxP22mscorlib_System_Object,__Z52mscorlib_System_Int64_m_System_IConvertible_ToUInt64PxP22mscorlib_System_Object,__Z78mscorlib_System_Int64_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPxP22mscorlib_System_Object,__Z77mscorlib_System_Int64_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPxP22mscorlib_System_Object,__Z87mscorlib_System_Int64_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPxP22mscorlib_System_Object,__Z78mscorlib_System_Int64_m_ToString_mscorlib_System_String_mscorlib_System_StringPxP22mscorlib_System_String,__Z54mscorlib_System_UInt32_m_System_IConvertible_ToBooleanPjP22mscorlib_System_Object,__Z51mscorlib_System_UInt32_m_System_IConvertible_ToBytePjP22mscorlib_System_Object,__Z51mscorlib_System_UInt32_m_System_IConvertible_ToCharPjP22mscorlib_System_Object,__Z52mscorlib_System_UInt32_m_System_IConvertible_ToInt16PjP22mscorlib_System_Object,__Z52mscorlib_System_UInt32_m_System_IConvertible_ToInt32PjP22mscorlib_System_Object,__Z52mscorlib_System_UInt32_m_System_IConvertible_ToInt64PjP22mscorlib_System_Object,__Z52mscorlib_System_UInt32_m_System_IConvertible_ToSBytePjP22mscorlib_System_Object,__Z53mscorlib_System_UInt32_m_System_IConvertible_ToUInt16PjP22mscorlib_System_Object,__Z53mscorlib_System_UInt32_m_System_IConvertible_ToUInt32PjP22mscorlib_System_Object,__Z53mscorlib_System_UInt32_m_System_IConvertible_ToUInt64PjP22mscorlib_System_Object,__Z79mscorlib_System_UInt32_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPjP22mscorlib_System_Object,__Z78mscorlib_System_UInt32_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPjP22mscorlib_System_Object,__Z79mscorlib_System_UInt32_m_CompareTo_mscorlib_System_Int32_mscorlib_System_UInt32Pjj,__Z78mscorlib_System_UInt32_m_Equals_mscorlib_System_Boolean_mscorlib_System_UInt32Pjj,__Z88mscorlib_System_UInt32_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPjP22mscorlib_System_Object,__Z79mscorlib_System_UInt32_m_ToString_mscorlib_System_String_mscorlib_System_StringPjP22mscorlib_System_String,__Z54mscorlib_System_UInt64_m_System_IConvertible_ToBooleanPyP22mscorlib_System_Object,__Z51mscorlib_System_UInt64_m_System_IConvertible_ToBytePyP22mscorlib_System_Object
  ,__Z51mscorlib_System_UInt64_m_System_IConvertible_ToCharPyP22mscorlib_System_Object,__Z52mscorlib_System_UInt64_m_System_IConvertible_ToInt16PyP22mscorlib_System_Object,__Z52mscorlib_System_UInt64_m_System_IConvertible_ToInt32PyP22mscorlib_System_Object,__Z52mscorlib_System_UInt64_m_System_IConvertible_ToInt64PyP22mscorlib_System_Object,__Z52mscorlib_System_UInt64_m_System_IConvertible_ToSBytePyP22mscorlib_System_Object,__Z53mscorlib_System_UInt64_m_System_IConvertible_ToUInt16PyP22mscorlib_System_Object,__Z53mscorlib_System_UInt64_m_System_IConvertible_ToUInt32PyP22mscorlib_System_Object,__Z53mscorlib_System_UInt64_m_System_IConvertible_ToUInt64PyP22mscorlib_System_Object,__Z79mscorlib_System_UInt64_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPyP22mscorlib_System_Object,__Z78mscorlib_System_UInt64_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPyP22mscorlib_System_Object,__Z88mscorlib_System_UInt64_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPyP22mscorlib_System_Object,__Z79mscorlib_System_UInt64_m_ToString_mscorlib_System_String_mscorlib_System_StringPyP22mscorlib_System_String,__Z52mscorlib_System_Byte_m_System_IConvertible_ToBooleanPhP22mscorlib_System_Object,__Z49mscorlib_System_Byte_m_System_IConvertible_ToBytePhP22mscorlib_System_Object,__Z49mscorlib_System_Byte_m_System_IConvertible_ToCharPhP22mscorlib_System_Object,__Z50mscorlib_System_Byte_m_System_IConvertible_ToInt16PhP22mscorlib_System_Object,__Z50mscorlib_System_Byte_m_System_IConvertible_ToInt32PhP22mscorlib_System_Object,__Z50mscorlib_System_Byte_m_System_IConvertible_ToInt64PhP22mscorlib_System_Object,__Z50mscorlib_System_Byte_m_System_IConvertible_ToSBytePhP22mscorlib_System_Object,__Z51mscorlib_System_Byte_m_System_IConvertible_ToUInt16PhP22mscorlib_System_Object,__Z51mscorlib_System_Byte_m_System_IConvertible_ToUInt32PhP22mscorlib_System_Object,__Z51mscorlib_System_Byte_m_System_IConvertible_ToUInt64PhP22mscorlib_System_Object,__Z77mscorlib_System_Byte_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPhP22mscorlib_System_Object,__Z76mscorlib_System_Byte_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPhP22mscorlib_System_Object,__Z75mscorlib_System_Byte_m_CompareTo_mscorlib_System_Int32_mscorlib_System_BytePhh,__Z74mscorlib_System_Byte_m_Equals_mscorlib_System_Boolean_mscorlib_System_BytePhh,__Z77mscorlib_System_Byte_m_ToString_mscorlib_System_String_mscorlib_System_StringPhP22mscorlib_System_String,__Z86mscorlib_System_Byte_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPhP22mscorlib_System_Object,__Z53mscorlib_System_SByte_m_System_IConvertible_ToBooleanPaP22mscorlib_System_Object,__Z50mscorlib_System_SByte_m_System_IConvertible_ToBytePaP22mscorlib_System_Object
  ,__Z50mscorlib_System_SByte_m_System_IConvertible_ToCharPaP22mscorlib_System_Object,__Z51mscorlib_System_SByte_m_System_IConvertible_ToInt16PaP22mscorlib_System_Object,__Z51mscorlib_System_SByte_m_System_IConvertible_ToInt32PaP22mscorlib_System_Object,__Z51mscorlib_System_SByte_m_System_IConvertible_ToInt64PaP22mscorlib_System_Object,__Z51mscorlib_System_SByte_m_System_IConvertible_ToSBytePaP22mscorlib_System_Object,__Z52mscorlib_System_SByte_m_System_IConvertible_ToUInt16PaP22mscorlib_System_Object,__Z52mscorlib_System_SByte_m_System_IConvertible_ToUInt32PaP22mscorlib_System_Object,__Z52mscorlib_System_SByte_m_System_IConvertible_ToUInt64PaP22mscorlib_System_Object,__Z78mscorlib_System_SByte_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPaP22mscorlib_System_Object,__Z77mscorlib_System_SByte_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPaP22mscorlib_System_Object,__Z77mscorlib_System_SByte_m_CompareTo_mscorlib_System_Int32_mscorlib_System_SBytePaa,__Z76mscorlib_System_SByte_m_Equals_mscorlib_System_Boolean_mscorlib_System_SBytePaa,__Z87mscorlib_System_SByte_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPaP22mscorlib_System_Object,__Z78mscorlib_System_SByte_m_ToString_mscorlib_System_String_mscorlib_System_StringPaP22mscorlib_System_String,__Z53mscorlib_System_Int16_m_System_IConvertible_ToBooleanPsP22mscorlib_System_Object,__Z50mscorlib_System_Int16_m_System_IConvertible_ToBytePsP22mscorlib_System_Object,__Z50mscorlib_System_Int16_m_System_IConvertible_ToCharPsP22mscorlib_System_Object,__Z51mscorlib_System_Int16_m_System_IConvertible_ToInt16PsP22mscorlib_System_Object,__Z51mscorlib_System_Int16_m_System_IConvertible_ToInt32PsP22mscorlib_System_Object,__Z51mscorlib_System_Int16_m_System_IConvertible_ToInt64PsP22mscorlib_System_Object,__Z51mscorlib_System_Int16_m_System_IConvertible_ToSBytePsP22mscorlib_System_Object,__Z52mscorlib_System_Int16_m_System_IConvertible_ToUInt16PsP22mscorlib_System_Object,__Z52mscorlib_System_Int16_m_System_IConvertible_ToUInt32PsP22mscorlib_System_Object,__Z52mscorlib_System_Int16_m_System_IConvertible_ToUInt64PsP22mscorlib_System_Object,__Z78mscorlib_System_Int16_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPsP22mscorlib_System_Object,__Z77mscorlib_System_Int16_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPsP22mscorlib_System_Object,__Z77mscorlib_System_Int16_m_CompareTo_mscorlib_System_Int32_mscorlib_System_Int16Pss,__Z76mscorlib_System_Int16_m_Equals_mscorlib_System_Boolean_mscorlib_System_Int16Pss,__Z87mscorlib_System_Int16_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPsP22mscorlib_System_Object,__Z78mscorlib_System_Int16_m_ToString_mscorlib_System_String_mscorlib_System_StringPsP22mscorlib_System_String
  ,__Z54mscorlib_System_UInt16_m_System_IConvertible_ToBooleanPtP22mscorlib_System_Object,__Z51mscorlib_System_UInt16_m_System_IConvertible_ToBytePtP22mscorlib_System_Object,__Z51mscorlib_System_UInt16_m_System_IConvertible_ToCharPtP22mscorlib_System_Object,__Z52mscorlib_System_UInt16_m_System_IConvertible_ToInt16PtP22mscorlib_System_Object,__Z52mscorlib_System_UInt16_m_System_IConvertible_ToInt32PtP22mscorlib_System_Object,__Z52mscorlib_System_UInt16_m_System_IConvertible_ToInt64PtP22mscorlib_System_Object,__Z52mscorlib_System_UInt16_m_System_IConvertible_ToSBytePtP22mscorlib_System_Object,__Z53mscorlib_System_UInt16_m_System_IConvertible_ToUInt16PtP22mscorlib_System_Object,__Z53mscorlib_System_UInt16_m_System_IConvertible_ToUInt32PtP22mscorlib_System_Object,__Z53mscorlib_System_UInt16_m_System_IConvertible_ToUInt64PtP22mscorlib_System_Object,__Z79mscorlib_System_UInt16_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPtP22mscorlib_System_Object,__Z78mscorlib_System_UInt16_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPtP22mscorlib_System_Object,__Z79mscorlib_System_UInt16_m_CompareTo_mscorlib_System_Int32_mscorlib_System_UInt16Ptt,__Z78mscorlib_System_UInt16_m_Equals_mscorlib_System_Boolean_mscorlib_System_UInt16Ptt,__Z88mscorlib_System_UInt16_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPtP22mscorlib_System_Object,__Z79mscorlib_System_UInt16_m_ToString_mscorlib_System_String_mscorlib_System_StringPtP22mscorlib_System_String,__Z52mscorlib_System_Char_m_System_IConvertible_ToBooleanPtP22mscorlib_System_Object,__Z49mscorlib_System_Char_m_System_IConvertible_ToBytePtP22mscorlib_System_Object,__Z49mscorlib_System_Char_m_System_IConvertible_ToCharPtP22mscorlib_System_Object,__Z50mscorlib_System_Char_m_System_IConvertible_ToInt16PtP22mscorlib_System_Object,__Z50mscorlib_System_Char_m_System_IConvertible_ToInt32PtP22mscorlib_System_Object,__Z50mscorlib_System_Char_m_System_IConvertible_ToInt64PtP22mscorlib_System_Object,__Z50mscorlib_System_Char_m_System_IConvertible_ToSBytePtP22mscorlib_System_Object,__Z51mscorlib_System_Char_m_System_IConvertible_ToUInt16PtP22mscorlib_System_Object,__Z51mscorlib_System_Char_m_System_IConvertible_ToUInt32PtP22mscorlib_System_Object,__Z51mscorlib_System_Char_m_System_IConvertible_ToUInt64PtP22mscorlib_System_Object,__Z77mscorlib_System_Char_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPtP22mscorlib_System_Object,__Z76mscorlib_System_Char_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPtP22mscorlib_System_Object,__Z75mscorlib_System_Char_m_CompareTo_mscorlib_System_Int32_mscorlib_System_CharPtt,__Z74mscorlib_System_Char_m_Equals_mscorlib_System_Boolean_mscorlib_System_CharPtt
  ,__Z41mscorlib_System_Char_m_GetUnicodeCategoryP22mscorlib_System_Objectt,__Z30mscorlib_System_Char_m_IsDigitP22mscorlib_System_Objectt,__Z31mscorlib_System_Char_m_IsLetterP22mscorlib_System_Objectt,__Z30mscorlib_System_Char_m_IsLowerP22mscorlib_System_Objectt,__Z34mscorlib_System_Char_m_IsSurrogateP22mscorlib_System_Objectt,__Z35mscorlib_System_Char_m_IsWhiteSpaceP22mscorlib_System_Objectt,__Z28mscorlib_System_Char_m_ParseP22mscorlib_System_ObjectP22mscorlib_System_String,__Z39mscorlib_System_Char_m_ToLowerInvariantP22mscorlib_System_Objectt,__Z39mscorlib_System_Char_m_ToUpperInvariantP22mscorlib_System_Objectt,__Z86mscorlib_System_Char_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPtP22mscorlib_System_Object,__Z54mscorlib_System_String_m_System_IConvertible_ToBooleanP22mscorlib_System_StringP22mscorlib_System_Object,__Z51mscorlib_System_String_m_System_IConvertible_ToByteP22mscorlib_System_StringP22mscorlib_System_Object,__Z51mscorlib_System_String_m_System_IConvertible_ToCharP22mscorlib_System_StringP22mscorlib_System_Object,__Z52mscorlib_System_String_m_System_IConvertible_ToInt16P22mscorlib_System_StringP22mscorlib_System_Object,__Z52mscorlib_System_String_m_System_IConvertible_ToInt32P22mscorlib_System_StringP22mscorlib_System_Object,__Z52mscorlib_System_String_m_System_IConvertible_ToInt64P22mscorlib_System_StringP22mscorlib_System_Object,__Z52mscorlib_System_String_m_System_IConvertible_ToSByteP22mscorlib_System_StringP22mscorlib_System_Object,__Z53mscorlib_System_String_m_System_IConvertible_ToUInt16P22mscorlib_System_StringP22mscorlib_System_Object,__Z53mscorlib_System_String_m_System_IConvertible_ToUInt32P22mscorlib_System_StringP22mscorlib_System_Object,__Z53mscorlib_System_String_m_System_IConvertible_ToUInt64P22mscorlib_System_StringP22mscorlib_System_Object,__Z78mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP22mscorlib_System_StringP22mscorlib_System_Object,__Z78mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_StringP22mscorlib_System_StringS0_,__Z34mscorlib_System_String_m_get_CharsP22mscorlib_System_Stringi,__Z90mscorlib_System_String_m_Split_mscorlib_System_String_arr_arr_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr,__Z79mscorlib_System_String_m_Substring_mscorlib_System_String_mscorlib_System_Int32P22mscorlib_System_Stringi,__Z81mscorlib_System_String_m_Trim_mscorlib_System_String_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr,__Z34mscorlib_System_String_m_TrimStartP22mscorlib_System_StringP24mscorlib_System_Char_arr,__Z32mscorlib_System_String_m_TrimEndP22mscorlib_System_StringP24mscorlib_System_Char_arr,__Z79mscorlib_System_String_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP22mscorlib_System_StringP22mscorlib_System_Object,__Z79mscorlib_System_String_m_CompareTo_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_StringS0_
  ,__Z33mscorlib_System_String_m_EndsWithP22mscorlib_System_StringS0_,__Z86mscorlib_System_String_m_IndexOfAny_mscorlib_System_Int32_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr,__Z75mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_CharP22mscorlib_System_Stringt,__Z77mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_StringS0_,__Z81mscorlib_System_String_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_StringS0_,__Z38mscorlib_System_String_m_IsNullOrEmptyP22mscorlib_System_ObjectP22mscorlib_System_String,__Z35mscorlib_System_String_m_StartsWithP22mscorlib_System_StringS0_,__Z97mscorlib_System_String_m_ToLower_mscorlib_System_String_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_StringP41mscorlib_System_Globalization_CultureInfo,__Z88mscorlib_System_String_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_StringP22mscorlib_System_Object,__Z85mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP26mscorlib_System_Object_arr,__Z85mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_String_arr_arrP22mscorlib_System_ObjectP26mscorlib_System_String_arr,__Z91mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_SByteU002A_ptrP22mscorlib_System_StringPa,__Z90mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_CharU002A_ptrP22mscorlib_System_StringPt,__Z89mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_Char_arr_arrP22mscorlib_System_StringP24mscorlib_System_Char_arr,__Z44mscorlib_System_String_m_InternalAllocateStrP22mscorlib_System_Objecti,__Z54mscorlib_System_Single_m_System_IConvertible_ToBooleanPfP22mscorlib_System_Object,__Z51mscorlib_System_Single_m_System_IConvertible_ToBytePfP22mscorlib_System_Object,__Z51mscorlib_System_Single_m_System_IConvertible_ToCharPfP22mscorlib_System_Object,__Z52mscorlib_System_Single_m_System_IConvertible_ToInt16PfP22mscorlib_System_Object,__Z52mscorlib_System_Single_m_System_IConvertible_ToInt32PfP22mscorlib_System_Object,__Z52mscorlib_System_Single_m_System_IConvertible_ToInt64PfP22mscorlib_System_Object,__Z52mscorlib_System_Single_m_System_IConvertible_ToSBytePfP22mscorlib_System_Object,__Z53mscorlib_System_Single_m_System_IConvertible_ToUInt16PfP22mscorlib_System_Object,__Z53mscorlib_System_Single_m_System_IConvertible_ToUInt32PfP22mscorlib_System_Object,__Z53mscorlib_System_Single_m_System_IConvertible_ToUInt64PfP22mscorlib_System_Object,__Z79mscorlib_System_Single_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPfP22mscorlib_System_Object,__Z78mscorlib_System_Single_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPfP22mscorlib_System_Object,__Z88mscorlib_System_Single_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPfP22mscorlib_System_Object,__Z79mscorlib_System_Single_m_ToString_mscorlib_System_String_mscorlib_System_StringPfP22mscorlib_System_String,__Z54mscorlib_System_Double_m_System_IConvertible_ToBooleanPdP22mscorlib_System_Object
  ,__Z51mscorlib_System_Double_m_System_IConvertible_ToBytePdP22mscorlib_System_Object,__Z51mscorlib_System_Double_m_System_IConvertible_ToCharPdP22mscorlib_System_Object,__Z52mscorlib_System_Double_m_System_IConvertible_ToInt16PdP22mscorlib_System_Object,__Z52mscorlib_System_Double_m_System_IConvertible_ToInt32PdP22mscorlib_System_Object,__Z52mscorlib_System_Double_m_System_IConvertible_ToInt64PdP22mscorlib_System_Object,__Z52mscorlib_System_Double_m_System_IConvertible_ToSBytePdP22mscorlib_System_Object,__Z53mscorlib_System_Double_m_System_IConvertible_ToUInt16PdP22mscorlib_System_Object,__Z53mscorlib_System_Double_m_System_IConvertible_ToUInt32PdP22mscorlib_System_Object,__Z53mscorlib_System_Double_m_System_IConvertible_ToUInt64PdP22mscorlib_System_Object,__Z79mscorlib_System_Double_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPdP22mscorlib_System_Object,__Z78mscorlib_System_Double_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPdP22mscorlib_System_Object,__Z88mscorlib_System_Double_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPdP22mscorlib_System_Object,__Z55mscorlib_System_Decimal_m_System_IConvertible_ToBooleanP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z52mscorlib_System_Decimal_m_System_IConvertible_ToByteP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z52mscorlib_System_Decimal_m_System_IConvertible_ToCharP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z53mscorlib_System_Decimal_m_System_IConvertible_ToInt16P23mscorlib_System_DecimalP22mscorlib_System_Object,__Z53mscorlib_System_Decimal_m_System_IConvertible_ToInt32P23mscorlib_System_DecimalP22mscorlib_System_Object,__Z53mscorlib_System_Decimal_m_System_IConvertible_ToInt64P23mscorlib_System_DecimalP22mscorlib_System_Object,__Z53mscorlib_System_Decimal_m_System_IConvertible_ToSByteP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z54mscorlib_System_Decimal_m_System_IConvertible_ToUInt16P23mscorlib_System_DecimalP22mscorlib_System_Object,__Z54mscorlib_System_Decimal_m_System_IConvertible_ToUInt32P23mscorlib_System_DecimalP22mscorlib_System_Object,__Z54mscorlib_System_Decimal_m_System_IConvertible_ToUInt64P23mscorlib_System_DecimalP22mscorlib_System_Object,__Z33mscorlib_System_Decimal_m_GetBitsP22mscorlib_System_Object23mscorlib_System_Decimal,__Z29mscorlib_System_Decimal_m_u64P22mscorlib_System_Object23mscorlib_System_Decimal,__Z29mscorlib_System_Decimal_m_s64P22mscorlib_System_Object23mscorlib_System_Decimal,__Z79mscorlib_System_Decimal_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z80mscorlib_System_Decimal_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z81mscorlib_System_Decimal_m_CompareTo_mscorlib_System_Int32_mscorlib_System_DecimalP23mscorlib_System_DecimalS_,__Z80mscorlib_System_Decimal_m_Equals_mscorlib_System_Boolean_mscorlib_System_DecimalP23mscorlib_System_DecimalS_,__Z89mscorlib_System_Decimal_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP23mscorlib_System_DecimalP22mscorlib_System_Object
  ,__Z82mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Byte_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z83mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_SByte_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z83mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Int16_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt16_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z83mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Int32_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt32_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z83mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Int64_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_UInt64_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z55mscorlib_System_Boolean_m_System_IConvertible_ToBooleanPbP22mscorlib_System_Object,__Z52mscorlib_System_Boolean_m_System_IConvertible_ToBytePbP22mscorlib_System_Object,__Z52mscorlib_System_Boolean_m_System_IConvertible_ToCharPbP22mscorlib_System_Object,__Z53mscorlib_System_Boolean_m_System_IConvertible_ToInt16PbP22mscorlib_System_Object,__Z53mscorlib_System_Boolean_m_System_IConvertible_ToInt32PbP22mscorlib_System_Object,__Z53mscorlib_System_Boolean_m_System_IConvertible_ToInt64PbP22mscorlib_System_Object,__Z53mscorlib_System_Boolean_m_System_IConvertible_ToSBytePbP22mscorlib_System_Object,__Z54mscorlib_System_Boolean_m_System_IConvertible_ToUInt16PbP22mscorlib_System_Object,__Z54mscorlib_System_Boolean_m_System_IConvertible_ToUInt32PbP22mscorlib_System_Object,__Z54mscorlib_System_Boolean_m_System_IConvertible_ToUInt64PbP22mscorlib_System_Object,__Z80mscorlib_System_Boolean_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectPbP22mscorlib_System_Object,__Z79mscorlib_System_Boolean_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectPbP22mscorlib_System_Object,__Z81mscorlib_System_Boolean_m_CompareTo_mscorlib_System_Int32_mscorlib_System_BooleanPbb,__Z80mscorlib_System_Boolean_m_Equals_mscorlib_System_Boolean_mscorlib_System_BooleanPbb,__Z31mscorlib_System_Boolean_m_ParseP22mscorlib_System_ObjectP22mscorlib_System_String,__Z89mscorlib_System_Boolean_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderPbP22mscorlib_System_Object,__Z31mscorlib_System_IntPtr_m_EqualsP22mscorlib_System_IntPtrP22mscorlib_System_Object,__Z79mscorlib_System_IntPtr_m_ToString_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_IntPtrP22mscorlib_System_String,__Z81mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_IntPtr_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z89mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_IntPtr_mscorlib_System_VoidU002A_ptrP22mscorlib_System_ObjectPv,__Z81mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_Int32_mscorlib_System_IntPtrP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z89mscorlib_System_IntPtr_m_op_Explicit_mscorlib_System_VoidU002A_ptr_mscorlib_System_IntPtrP22mscorlib_System_Object22mscorlib_System_IntPtr
  ,__Z32mscorlib_System_UIntPtr_m_EqualsP23mscorlib_System_UIntPtrP22mscorlib_System_Object,__Z84mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UInt64_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtr,__Z84mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UInt32_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtr,__Z91mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UIntPtr_mscorlib_System_VoidU002A_ptrP22mscorlib_System_ObjectPv,__Z91mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_VoidU002A_ptr_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtr,__Z84mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UIntPtr_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z42mscorlib_System_MulticastDelegate_m_EqualsP33mscorlib_System_MulticastDelegateP22mscorlib_System_Object,__Z47mscorlib_System_MulticastDelegate_m_CombineImplP33mscorlib_System_MulticastDelegateP24mscorlib_System_Delegate,__Z46mscorlib_System_MulticastDelegate_m_BaseEqualsP33mscorlib_System_MulticastDelegateS0_,__Z46mscorlib_System_MulticastDelegate_m_RemoveImplP33mscorlib_System_MulticastDelegateP24mscorlib_System_Delegate,__Z33mscorlib_System_Delegate_m_EqualsP24mscorlib_System_DelegateP22mscorlib_System_Object,__Z38mscorlib_System_Delegate_m_CombineImplP24mscorlib_System_DelegateS0_,__Z37mscorlib_System_Delegate_m_RemoveImplP24mscorlib_System_DelegateS0_,__Z52mscorlib_System_Enum_m_System_IConvertible_ToBooleanP22mscorlib_System_ObjectS0_,__Z49mscorlib_System_Enum_m_System_IConvertible_ToByteP22mscorlib_System_ObjectS0_,__Z49mscorlib_System_Enum_m_System_IConvertible_ToCharP22mscorlib_System_ObjectS0_,__Z50mscorlib_System_Enum_m_System_IConvertible_ToInt16P22mscorlib_System_ObjectS0_,__Z50mscorlib_System_Enum_m_System_IConvertible_ToInt32P22mscorlib_System_ObjectS0_,__Z50mscorlib_System_Enum_m_System_IConvertible_ToInt64P22mscorlib_System_ObjectS0_,__Z50mscorlib_System_Enum_m_System_IConvertible_ToSByteP22mscorlib_System_ObjectS0_,__Z86mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_,__Z51mscorlib_System_Enum_m_System_IConvertible_ToUInt16P22mscorlib_System_ObjectS0_,__Z51mscorlib_System_Enum_m_System_IConvertible_ToUInt32P22mscorlib_System_ObjectS0_,__Z51mscorlib_System_Enum_m_System_IConvertible_ToUInt64P22mscorlib_System_ObjectS0_,__Z42mscorlib_System_Enum_m_get_underlying_typeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z40mscorlib_System_Enum_m_GetUnderlyingTypeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z39mscorlib_System_Enum_m_compare_value_toP22mscorlib_System_ObjectS0_,__Z32mscorlib_System_Enum_m_CompareToP22mscorlib_System_ObjectS0_,__Z77mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z29mscorlib_System_Enum_m_EqualsP22mscorlib_System_ObjectS0_
  ,__Z57mscorlib_System_Array_m_System_Collections_IList_get_ItemP21mscorlib_System_Arrayi,__Z52mscorlib_System_Array_m_System_Collections_IList_AddP21mscorlib_System_ArrayP22mscorlib_System_Object,__Z57mscorlib_System_Array_m_System_Collections_IList_ContainsP21mscorlib_System_ArrayP22mscorlib_System_Object,__Z56mscorlib_System_Array_m_System_Collections_IList_IndexOfP21mscorlib_System_ArrayP22mscorlib_System_Object,__Z33mscorlib_System_Array_m_GetLengthP21mscorlib_System_Arrayi,__Z37mscorlib_System_Array_m_GetLongLengthP21mscorlib_System_Arrayi,__Z37mscorlib_System_Array_m_GetLowerBoundP21mscorlib_System_Arrayi,__Z85mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int32_arr_arrP21mscorlib_System_ArrayP25mscorlib_System_Int32_arr,__Z36mscorlib_System_Array_m_GetValueImplP21mscorlib_System_Arrayi,__Z37mscorlib_System_Array_m_GetUpperBoundP21mscorlib_System_Arrayi,__Z77mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z74mscorlib_System_Type_m_Equals_mscorlib_System_Boolean_mscorlib_System_TypeP20mscorlib_System_TypeS0_,__Z35mscorlib_System_Array_m_GetIntArrayP22mscorlib_System_ObjectP25mscorlib_System_Int64_arr,__Z85mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64_arr_arrP21mscorlib_System_ArrayP25mscorlib_System_Int64_arr,__Z87mscorlib_System_Array_m_get_swapper_mscorlib_System_Array_Swapper_mscorlib_System_ArrayP22mscorlib_System_ObjectP21mscorlib_System_Array,__Z31mscorlib_System_Array_m_new_gapP22mscorlib_System_Objecti,__Z35mscorlib_System_Type_m_IsSubclassOfP20mscorlib_System_TypeS0_,__Z76mscorlib_System_Type_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP20mscorlib_System_TypeP22mscorlib_System_Object,__Z37mscorlib_System_Type_m_EqualsInternalP20mscorlib_System_TypeS0_,__Z43mscorlib_System_Type_m_internal_from_handleP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z30mscorlib_System_Type_m_GetTypeP22mscorlib_System_ObjectP22mscorlib_System_String,__Z42mscorlib_System_Type_m_GetTypeCodeInternalP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z34mscorlib_System_Type_m_GetTypeCodeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z40mscorlib_System_Type_m_GetTypeFromHandleP22mscorlib_System_Object33mscorlib_System_RuntimeTypeHandle,__Z36mscorlib_System_Type_m_GetTypeHandleP22mscorlib_System_ObjectS0_,__Z39mscorlib_System_Type_m_IsAssignableFromP20mscorlib_System_TypeS0_,__Z39mscorlib_System_Type_m_IsInstanceOfTypeP20mscorlib_System_TypeP22mscorlib_System_Object,__Z93mscorlib_System_Type_m_GetMethod_mscorlib_System_Reflection_MethodInfo_mscorlib_System_StringP20mscorlib_System_TypeP22mscorlib_System_String,__Z79mscorlib_System_Type_m_IsArrayImpl_mscorlib_System_Boolean_mscorlib_System_TypeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z88mscorlib_System_Type_m_MakeGenericType_mscorlib_System_Type_mscorlib_System_Type_arr_arrP20mscorlib_System_TypeP24mscorlib_System_Type_arr
  ,__Z43mscorlib_System_RuntimeFieldHandle_m_EqualsP34mscorlib_System_RuntimeFieldHandleP22mscorlib_System_Object,__Z42mscorlib_System_RuntimeTypeHandle_m_EqualsP33mscorlib_System_RuntimeTypeHandleP22mscorlib_System_Object,__Z39mscorlib_System_TypedReference_m_EqualsP30mscorlib_System_TypedReferenceP22mscorlib_System_Object,__Z36mscorlib_System_ArgIterator_m_EqualsP27mscorlib_System_ArgIteratorP22mscorlib_System_Object,__Z71mscorlib_Locale_m_GetText_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z62mscorlib_Mono_Globalization_Unicode_CodePointIndexer_m_ToIndexP52mscorlib_Mono_Globalization_Unicode_CodePointIndexeri,__Z75mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_GetTailoringInfoP22mscorlib_System_Objecti,__Z67mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_CategoryP22mscorlib_System_Objecti,__Z65mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_Level1P22mscorlib_System_Objecti,__Z65mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_Level2P22mscorlib_System_Objecti,__Z65mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_Level3P22mscorlib_System_Objecti,__Z80mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsIgnorableNonSpacingP22mscorlib_System_Objecti,__Z80mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_ToKanaTypeInsensitiveP22mscorlib_System_Objecti,__Z72mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_ToWidthCompatP22mscorlib_System_Objecti,__Z75mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_HasSpecialWeightP22mscorlib_System_Objectt,__Z74mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsHalfWidthKanaP22mscorlib_System_Objectt,__Z69mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsHiraganaP22mscorlib_System_Objectt,__Z80mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsJapaneseSmallLetterP22mscorlib_System_Objectt,__Z70mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_GetResourceP22mscorlib_System_ObjectP22mscorlib_System_String,__Z70mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetNeutralCultureP22mscorlib_System_ObjectP41mscorlib_System_Globalization_CultureInfo,__Z61mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CategoryP50mscorlib_Mono_Globalization_Unicode_SimpleCollatori,__Z59mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_Level1P50mscorlib_Mono_Globalization_Unicode_SimpleCollatori,__Z90mscorlib_System_Globalization_TextInfo_m_ToLower_mscorlib_System_Char_mscorlib_System_CharP38mscorlib_System_Globalization_TextInfot,__Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetExtenderTypeP50mscorlib_Mono_Globalization_Unicode_SimpleCollatori,__Z59mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsSafeP50mscorlib_Mono_Globalization_Unicode_SimpleCollatori,__Z46mscorlib_System_Globalization_SortKey_m_EqualsP37mscorlib_System_Globalization_SortKeyP22mscorlib_System_Object,__Z62mscorlib_Mono_Security_Cryptography_CryptoConvert_m_GetBytesLEP22mscorlib_System_Objecti,__Z72mscorlib_Mono_Security_Cryptography_CryptoConvert_m_ToCapiPrivateKeyBlobP22mscorlib_System_ObjectP41mscorlib_System_Security_Cryptography_RSA,__Z71mscorlib_Mono_Security_Cryptography_CryptoConvert_m_ToCapiPublicKeyBlobP22mscorlib_System_ObjectP41mscorlib_System_Security_Cryptography_RSA,__Z52mscorlib_Mono_Security_BitConverterLE_m_GetUIntBytesP22mscorlib_System_ObjectPh
  ,__Z48mscorlib_Mono_Security_BitConverterLE_m_GetBytesP22mscorlib_System_Objecti,__Z48mscorlib_System_Collections_ArrayList_m_get_ItemP37mscorlib_System_Collections_ArrayListi,__Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_get_ItemP54mscorlib_System_Collections_ArrayList_ArrayListWrapperi,__Z60mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_AddP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object,__Z43mscorlib_System_Collections_ArrayList_m_AddP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object,__Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_ContainsP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object,__Z48mscorlib_System_Collections_ArrayList_m_ContainsP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object,__Z109mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_ObjectP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Object,__Z92mscorlib_System_Collections_ArrayList_m_IndexOf_mscorlib_System_Int32_mscorlib_System_ObjectP37mscorlib_System_Collections_ArrayListP22mscorlib_System_Object,__Z107mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_ToArray_mscorlib_System_Array_mscorlib_System_TypeP54mscorlib_System_Collections_ArrayList_ArrayListWrapperP20mscorlib_System_Type,__Z90mscorlib_System_Collections_ArrayList_m_ToArray_mscorlib_System_Array_mscorlib_System_TypeP37mscorlib_System_Collections_ArrayListP20mscorlib_System_Type,__Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_get_ItemP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperi,__Z72mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_AddP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object,__Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_ContainsP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object,__Z121mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_ObjectP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Object,__Z119mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_ToArray_mscorlib_System_Array_mscorlib_System_TypeP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP20mscorlib_System_Type,__Z52mscorlib_System_Collections_ArrayList_m_SynchronizedP22mscorlib_System_ObjectP37mscorlib_System_Collections_ArrayList,__Z73mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m_GetHashCodeP59mscorlib_System_Collections_CaseInsensitiveHashCodeProviderP22mscorlib_System_Object,__Z94mscorlib_System_Globalization_TextInfo_m_ToLower_mscorlib_System_String_mscorlib_System_StringP38mscorlib_System_Globalization_TextInfoP22mscorlib_System_String,__Z48mscorlib_System_Collections_Hashtable_m_get_ItemP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object,__Z47mscorlib_System_Collections_Hashtable_m_GetHashP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object,__Z48mscorlib_System_Collections_Hashtable_m_ContainsP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object,__Z51mscorlib_System_Collections_Hashtable_m_ContainsKeyP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object,__Z44mscorlib_System_Collections_Hashtable_m_FindP37mscorlib_System_Collections_HashtableP22mscorlib_System_Object,__Z49mscorlib_System_Collections_Hashtable_m_TestPrimeP22mscorlib_System_Objecti,__Z49mscorlib_System_Collections_Hashtable_m_CalcPrimeP22mscorlib_System_Objecti,__Z47mscorlib_System_Collections_Hashtable_m_ToPrimeP22mscorlib_System_Objecti,__Z49mscorlib_System_Diagnostics_StackTrace_m_GetFrameP38mscorlib_System_Diagnostics_StackTracei,__Z52mscorlib_System_Globalization_CCFixed_m_FromDateTimeP22mscorlib_System_Object24mscorlib_System_DateTime,__Z51mscorlib_System_Globalization_CCFixed_m_day_of_weekP22mscorlib_System_Objecti
  ,__Z64mscorlib_System_Globalization_CCGregorianCalendar_m_is_leap_yearP22mscorlib_System_Objecti,__Z67mscorlib_System_Globalization_CCGregorianCalendar_m_year_from_fixedP22mscorlib_System_Objecti,__Z68mscorlib_System_Globalization_CCGregorianCalendar_m_month_from_fixedP22mscorlib_System_Objecti,__Z66mscorlib_System_Globalization_CCGregorianCalendar_m_day_from_fixedP22mscorlib_System_Objecti,__Z65mscorlib_System_Globalization_CCGregorianCalendar_m_GetDayOfMonthP22mscorlib_System_Object24mscorlib_System_DateTime,__Z60mscorlib_System_Globalization_CCGregorianCalendar_m_GetMonthP22mscorlib_System_Object24mscorlib_System_DateTime,__Z59mscorlib_System_Globalization_CCGregorianCalendar_m_GetYearP22mscorlib_System_Object24mscorlib_System_DateTime,__Z50mscorlib_System_Globalization_CompareInfo_m_EqualsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_Object,__Z50mscorlib_System_Globalization_CultureInfo_m_EqualsP41mscorlib_System_Globalization_CultureInfoP22mscorlib_System_Object,__Z53mscorlib_System_Globalization_CultureInfo_m_GetFormatP41mscorlib_System_Globalization_CultureInfoP20mscorlib_System_Type,__Z75mscorlib_System_Globalization_CultureInfo_m_ConstructInternalLocaleFromLcidP41mscorlib_System_Globalization_CultureInfoi,__Z79mscorlib_System_Globalization_CultureInfo_m_construct_internal_locale_from_lcidP41mscorlib_System_Globalization_CultureInfoi,__Z58mscorlib_System_Globalization_CultureInfo_m_CreateTextInfoP41mscorlib_System_Globalization_CultureInfob,__Z62mscorlib_System_Globalization_DateTimeFormatInfo_m_GetInstanceP22mscorlib_System_ObjectS0_,__Z59mscorlib_System_Globalization_DateTimeFormatInfo_m_ReadOnlyP22mscorlib_System_ObjectP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z60mscorlib_System_Globalization_DateTimeFormatInfo_m_GetFormatP48mscorlib_System_Globalization_DateTimeFormatInfoP20mscorlib_System_Type,__Z74mscorlib_System_Globalization_DateTimeFormatInfo_m_GetAbbreviatedMonthNameP48mscorlib_System_Globalization_DateTimeFormatInfoi,__Z61mscorlib_System_Globalization_DateTimeFormatInfo_m_GetEraNameP48mscorlib_System_Globalization_DateTimeFormatInfoi,__Z63mscorlib_System_Globalization_DateTimeFormatInfo_m_GetMonthNameP48mscorlib_System_Globalization_DateTimeFormatInfoi,__Z76mscorlib_System_Globalization_DateTimeFormatInfo_m_GetAllRawDateTimePatternsP48mscorlib_System_Globalization_DateTimeFormatInfot,__Z61mscorlib_System_Globalization_DateTimeFormatInfo_m_GetDayNameP48mscorlib_System_Globalization_DateTimeFormatInfoi,__Z72mscorlib_System_Globalization_DateTimeFormatInfo_m_GetAbbreviatedDayNameP48mscorlib_System_Globalization_DateTimeFormatInfoi,__Z63mscorlib_System_Globalization_GregorianCalendar_m_GetDayOfMonthP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime,__Z62mscorlib_System_Globalization_GregorianCalendar_m_GetDayOfWeekP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime,__Z56mscorlib_System_Globalization_GregorianCalendar_m_GetEraP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime,__Z58mscorlib_System_Globalization_GregorianCalendar_m_GetMonthP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime,__Z57mscorlib_System_Globalization_GregorianCalendar_m_GetYearP47mscorlib_System_Globalization_GregorianCalendar24mscorlib_System_DateTime,__Z58mscorlib_System_Globalization_NumberFormatInfo_m_GetFormatP46mscorlib_System_Globalization_NumberFormatInfoP20mscorlib_System_Type,__Z60mscorlib_System_Globalization_NumberFormatInfo_m_GetInstanceP22mscorlib_System_ObjectS0_,__Z47mscorlib_System_Globalization_TextInfo_m_EqualsP38mscorlib_System_Globalization_TextInfoP22mscorlib_System_Object
  ,__Z127mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP50mscorlib_System_Reflection_Emit_ConstructorBuilderb,__Z61mscorlib_System_Reflection_Emit_EnumBuilder_m_GetConstructorsP43mscorlib_System_Reflection_Emit_EnumBuilderi,__Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_GetConstructorsP43mscorlib_System_Reflection_Emit_TypeBuilderi,__Z120mscorlib_System_Reflection_Emit_EnumBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP43mscorlib_System_Reflection_Emit_EnumBuilderb,__Z120mscorlib_System_Reflection_Emit_TypeBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP43mscorlib_System_Reflection_Emit_TypeBuilderb,__Z55mscorlib_System_Reflection_Emit_EnumBuilder_m_GetFieldsP43mscorlib_System_Reflection_Emit_EnumBuilderi,__Z55mscorlib_System_Reflection_Emit_TypeBuilder_m_GetFieldsP43mscorlib_System_Reflection_Emit_TypeBuilderi,__Z56mscorlib_System_Reflection_Emit_EnumBuilder_m_GetMethodsP43mscorlib_System_Reflection_Emit_EnumBuilderi,__Z56mscorlib_System_Reflection_Emit_TypeBuilder_m_GetMethodsP43mscorlib_System_Reflection_Emit_TypeBuilderi,__Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_GetPropertiesP43mscorlib_System_Reflection_Emit_EnumBuilderi,__Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_GetPropertiesP43mscorlib_System_Reflection_Emit_TypeBuilderi,__Z121mscorlib_System_Reflection_Emit_FieldBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP44mscorlib_System_Reflection_Emit_FieldBuilderb,__Z55mscorlib_System_Reflection_Emit_FieldBuilder_m_GetValueP44mscorlib_System_Reflection_Emit_FieldBuilderP22mscorlib_System_Object,__Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsSubclassOfP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP20mscorlib_System_Type,__Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetConstructorsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderi,__Z71mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetFieldsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderi,__Z72mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetMethodsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderi,__Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetPropertiesP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderi,__Z78mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsAssignableFromP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP20mscorlib_System_Type,__Z78mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsInstanceOfTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_Object,__Z136mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderb,__Z68mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_EqualsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_Object,__Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_MakeGenericTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP24mscorlib_System_Type_arr,__Z122mscorlib_System_Reflection_Emit_MethodBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP45mscorlib_System_Reflection_Emit_MethodBuilderb,__Z54mscorlib_System_Reflection_Emit_MethodBuilder_m_EqualsP45mscorlib_System_Reflection_Emit_MethodBuilderP22mscorlib_System_Object,__Z65mscorlib_System_Reflection_Emit_MethodBuilder_m_MakeGenericMethodP45mscorlib_System_Reflection_Emit_MethodBuilderP24mscorlib_System_Type_arr,__Z124mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP47mscorlib_System_Reflection_Emit_PropertyBuilderb,__Z62mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetGetMethodP47mscorlib_System_Reflection_Emit_PropertyBuilderb,__Z62mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetSetMethodP47mscorlib_System_Reflection_Emit_PropertyBuilderb,__Z69mscorlib_System_Reflection_Emit_TypeBuilder_m_GetConstructorsInternalP43mscorlib_System_Reflection_Emit_TypeBuilderi
  ,__Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_MakeGenericTypeP43mscorlib_System_Reflection_Emit_TypeBuilderP24mscorlib_System_Type_arr,__Z62mscorlib_System_Reflection_Emit_TypeBuilder_m_IsAssignableFromP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Type,__Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_IsSubclassOfP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Type,__Z60mscorlib_System_Reflection_Emit_TypeBuilder_m_IsAssignableToP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Type,__Z89mscorlib_System_Reflection_Assembly_m_GetType_mscorlib_System_Type_mscorlib_System_StringP35mscorlib_System_Reflection_AssemblyP22mscorlib_System_String,__Z51mscorlib_System_Reflection_Binder_m_GetDerivedLevelP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z56mscorlib_System_Reflection_Binder_m_FindMostDerivedMatchP22mscorlib_System_ObjectP41mscorlib_System_Reflection_MethodBase_arr,__Z105mscorlib_System_Reflection_ConstructorInfo_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_arr_arrP42mscorlib_System_Reflection_ConstructorInfoP26mscorlib_System_Object_arr,__Z57mscorlib_System_Reflection_FieldInfo_m_GetFieldFromHandleP22mscorlib_System_Object34mscorlib_System_RuntimeFieldHandle,__Z73mscorlib_System_Reflection_MethodBase_m_GetMethodFromHandleNoGenericCheckP22mscorlib_System_Object35mscorlib_System_RuntimeMethodHandle,__Z59mscorlib_System_Reflection_MethodBase_m_GetMethodFromHandleP22mscorlib_System_Object35mscorlib_System_RuntimeMethodHandle,__Z57mscorlib_System_Reflection_MethodInfo_m_MakeGenericMethodP37mscorlib_System_Reflection_MethodInfoP24mscorlib_System_Type_arr,__Z51mscorlib_System_Reflection_MonoEvent_m_GetAddMethodP36mscorlib_System_Reflection_MonoEventb,__Z113mscorlib_System_Reflection_MonoEvent_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP36mscorlib_System_Reflection_MonoEventb,__Z52mscorlib_System_Reflection_MonoField_m_GetParentTypeP36mscorlib_System_Reflection_MonoFieldb,__Z113mscorlib_System_Reflection_MonoField_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP36mscorlib_System_Reflection_MonoFieldb,__Z55mscorlib_System_Reflection_MonoField_m_GetValueInternalP36mscorlib_System_Reflection_MonoFieldP22mscorlib_System_Object,__Z47mscorlib_System_Reflection_MonoField_m_GetValueP36mscorlib_System_Reflection_MonoFieldP22mscorlib_System_Object,__Z60mscorlib_System_Reflection_MonoMethodInfo_m_GetDeclaringTypeP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z57mscorlib_System_Reflection_MonoMethodInfo_m_GetReturnTypeP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z57mscorlib_System_Reflection_MonoMethodInfo_m_GetAttributesP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z64mscorlib_System_Reflection_MonoMethodInfo_m_GetCallingConventionP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z72mscorlib_System_Reflection_MonoMethodInfo_m_GetMethodImplementationFlagsP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z48mscorlib_System_Reflection_MonoMethod_m_get_nameP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MethodBase,__Z59mscorlib_System_Reflection_MonoMethod_m_get_base_definitionP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MonoMethod,__Z114mscorlib_System_Reflection_MonoMethod_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP37mscorlib_System_Reflection_MonoMethodb,__Z61mscorlib_System_Reflection_MonoMethod_m_GetDllImportAttributeP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z59mscorlib_System_Reflection_MonoMethod_m_ShouldPrintFullNameP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z57mscorlib_System_Reflection_MonoMethod_m_MakeGenericMethodP37mscorlib_System_Reflection_MonoMethodP24mscorlib_System_Type_arr,__Z62mscorlib_System_Reflection_MonoMethod_m_MakeGenericMethod_implP37mscorlib_System_Reflection_MonoMethodP24mscorlib_System_Type_arr
  ,__Z115mscorlib_System_Reflection_MonoCMethod_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP38mscorlib_System_Reflection_MonoCMethodb,__Z62mscorlib_System_Reflection_MonoProperty_GetterAdapter_m_InvokeP53mscorlib_System_Reflection_MonoProperty_GetterAdapterP22mscorlib_System_Object,__Z65mscorlib_System_Reflection_MonoProperty_GetterAdapter_m_EndInvokeP53mscorlib_System_Reflection_MonoProperty_GetterAdapterP22mscorlib_System_Object,__Z54mscorlib_System_Reflection_MonoProperty_m_GetGetMethodP39mscorlib_System_Reflection_MonoPropertyb,__Z54mscorlib_System_Reflection_MonoProperty_m_GetSetMethodP39mscorlib_System_Reflection_MonoPropertyb,__Z116mscorlib_System_Reflection_MonoProperty_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP39mscorlib_System_Reflection_MonoPropertyb,__Z65mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_EqualsP56mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP22mscorlib_System_Object,__Z63mscorlib_System_Runtime_Remoting_Contexts_Context_m_GetPropertyP49mscorlib_System_Runtime_Remoting_Contexts_ContextP22mscorlib_System_String,__Z67mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_EqualsP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP22mscorlib_System_Object,__Z69mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m_GetInOutArgIndexP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfoi,__Z68mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m_GetInOutArgNameP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfoi,__Z65mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m_GetInOutArgsP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfoP26mscorlib_System_Object_arr,__Z62mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetArgP53mscorlib_System_Runtime_Remoting_Messaging_MethodCalli,__Z66mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetArgNameP53mscorlib_System_Runtime_Remoting_Messaging_MethodCalli,__Z64mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetInArgP53mscorlib_System_Runtime_Remoting_Messaging_MethodCalli,__Z68mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetInArgNameP53mscorlib_System_Runtime_Remoting_Messaging_MethodCalli,__Z92mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetTypeNameFromAssemblyQualifiedNameP22mscorlib_System_ObjectP22mscorlib_System_String,__Z72mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_CreateInstanceP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP20mscorlib_System_Type,__Z73mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m_InternalGetProxyTypeP22mscorlib_System_ObjectS0_,__Z80mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m_InternalGetTransparentProxyP50mscorlib_System_Runtime_Remoting_Proxies_RealProxyP22mscorlib_System_String,__Z62mscorlib_System_Runtime_Remoting_ClientIdentity_m_CreateObjRefP47mscorlib_System_Runtime_Remoting_ClientIdentityP20mscorlib_System_Type,__Z86mscorlib_System_Runtime_Remoting_RemotingConfiguration_m_IsRemotelyActivatedClientTypeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z71mscorlib_System_Runtime_Remoting_RemotingServices_m_GetServerTypeForUriP22mscorlib_System_ObjectP22mscorlib_System_String,__Z82mscorlib_System_Runtime_Remoting_RemotingServices_m_GetMethodBaseFromMethodMessageP22mscorlib_System_ObjectS0_,__Z69mscorlib_System_Runtime_Remoting_RemotingServices_m_GetIdentityForUriP22mscorlib_System_ObjectP22mscorlib_System_String,__Z72mscorlib_System_Runtime_Remoting_RemotingServices_m_RemoveAppNameFromUriP22mscorlib_System_ObjectP22mscorlib_System_String,__Z68mscorlib_System_Runtime_Remoting_RemotingServices_m_GetNormalizedUriP22mscorlib_System_ObjectP22mscorlib_System_String,__Z62mscorlib_System_Runtime_Remoting_ServerIdentity_m_CreateObjRefP47mscorlib_System_Runtime_Remoting_ServerIdentityP20mscorlib_System_Type,__Z63mscorlib_System_Runtime_Serialization_StreamingContext_m_EqualsP54mscorlib_System_Runtime_Serialization_StreamingContextP22mscorlib_System_Object,__Z113mscorlib_System_Security_Cryptography_CryptoConfig_m_CreateFromName_mscorlib_System_Object_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String
  ,__Z123mscorlib_System_Security_Cryptography_HashAlgorithm_m_ComputeHash_mscorlib_System_Byte_arr_arr_mscorlib_System_Byte_arr_arrP51mscorlib_System_Security_Cryptography_HashAlgorithmP24mscorlib_System_Byte_arr,__Z60mscorlib_System_Security_Cryptography_HashAlgorithm_m_CreateP22mscorlib_System_ObjectP22mscorlib_System_String,__Z78mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_RngInitializeP22mscorlib_System_ObjectP24mscorlib_System_Byte_arr,__Z151mscorlib_System_Security_Cryptography_RandomNumberGenerator_m_Create_mscorlib_System_Security_Cryptography_RandomNumberGenerator_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z49mscorlib_System_Security_Policy_Evidence_m_EqualsP40mscorlib_System_Security_Policy_EvidenceP22mscorlib_System_Object,__Z49mscorlib_System_Security_SecurityElement_m_EscapeP22mscorlib_System_ObjectP22mscorlib_System_String,__Z51mscorlib_System_Security_SecurityElement_m_UnescapeP22mscorlib_System_ObjectP22mscorlib_System_String,__Z63mscorlib_System_Security_SecurityElement_m_IsValidAttributeNameP22mscorlib_System_ObjectP22mscorlib_System_String,__Z64mscorlib_System_Security_SecurityElement_m_IsValidAttributeValueP22mscorlib_System_ObjectP22mscorlib_System_String,__Z53mscorlib_System_Security_SecurityElement_m_IsValidTagP22mscorlib_System_ObjectP22mscorlib_System_String,__Z54mscorlib_System_Security_SecurityElement_m_IsValidTextP22mscorlib_System_ObjectP22mscorlib_System_String,__Z55mscorlib_System_Security_SecurityElement_m_GetAttributeP40mscorlib_System_Security_SecurityElementP22mscorlib_System_String,__Z94mscorlib_System_Text_ASCIIEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP34mscorlib_System_Text_ASCIIEncodingP22mscorlib_System_String,__Z54mscorlib_System_Text_DecoderExceptionFallback_m_EqualsP45mscorlib_System_Text_DecoderExceptionFallbackP22mscorlib_System_Object,__Z56mscorlib_System_Text_DecoderReplacementFallback_m_EqualsP47mscorlib_System_Text_DecoderReplacementFallbackP22mscorlib_System_Object,__Z54mscorlib_System_Text_EncoderExceptionFallback_m_EqualsP45mscorlib_System_Text_EncoderExceptionFallbackP22mscorlib_System_Object,__Z56mscorlib_System_Text_EncoderReplacementFallback_m_EqualsP47mscorlib_System_Text_EncoderReplacementFallbackP22mscorlib_System_Object,__Z110mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Int32P53mscorlib_System_Text_EncoderReplacementFallbackBufferi,__Z33mscorlib_System_Text_Encoding_m__P22mscorlib_System_ObjectP22mscorlib_System_String,__Z38mscorlib_System_Text_Encoding_m_EqualsP29mscorlib_System_Text_EncodingP22mscorlib_System_Object,__Z89mscorlib_System_Text_Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP29mscorlib_System_Text_EncodingP22mscorlib_System_String,__Z95mscorlib_System_Text_Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_Char_arr_arrP29mscorlib_System_Text_EncodingP24mscorlib_System_Char_arr,__Z92mscorlib_System_Text_Encoding_m_GetBytes_mscorlib_System_Byte_arr_arr_mscorlib_System_StringP29mscorlib_System_Text_EncodingP22mscorlib_System_String,__Z95mscorlib_System_Text_Encoding_m_GetEncoding_mscorlib_System_Text_Encoding_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z96mscorlib_System_Text_Encoding_m_GetEncoding_mscorlib_System_Text_Encoding_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z93mscorlib_System_Text_Encoding_m_GetString_mscorlib_System_String_mscorlib_System_Byte_arr_arrP29mscorlib_System_Text_EncodingP24mscorlib_System_Byte_arr,__Z48mscorlib_System_Text_Encoding_m_InternalCodePageP22mscorlib_System_ObjectPi,__Z95mscorlib_System_Text_Latin1Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP35mscorlib_System_Text_Latin1EncodingP22mscorlib_System_String,__Z99mscorlib_System_Text_Latin1Encoding_m_GetString_mscorlib_System_String_mscorlib_System_Byte_arr_arrP35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Byte_arr,__Z46mscorlib_System_Text_StringBuilder_m_get_CharsP34mscorlib_System_Text_StringBuilderi
  ,__Z101mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_StringP34mscorlib_System_Text_StringBuilderP22mscorlib_System_String,__Z100mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderi,__Z101mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderP22mscorlib_System_Object,__Z99mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_CharP34mscorlib_System_Text_StringBuildert,__Z43mscorlib_System_Text_UTF32Encoding_m_EqualsP34mscorlib_System_Text_UTF32EncodingP22mscorlib_System_Object,__Z94mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP34mscorlib_System_Text_UTF32EncodingP22mscorlib_System_String,__Z42mscorlib_System_Text_UTF7Encoding_m_EqualsP33mscorlib_System_Text_UTF7EncodingP22mscorlib_System_Object,__Z93mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP33mscorlib_System_Text_UTF7EncodingP22mscorlib_System_String,__Z42mscorlib_System_Text_UTF8Encoding_m_EqualsP33mscorlib_System_Text_UTF8EncodingP22mscorlib_System_Object,__Z93mscorlib_System_Text_UTF8Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP33mscorlib_System_Text_UTF8EncodingP22mscorlib_System_String,__Z96mscorlib_System_Text_UnicodeEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_StringP36mscorlib_System_Text_UnicodeEncodingP22mscorlib_System_String,__Z45mscorlib_System_Text_UnicodeEncoding_m_EqualsP36mscorlib_System_Text_UnicodeEncodingP22mscorlib_System_Object,__Z49mscorlib_System_Threading_Interlocked_m_IncrementP22mscorlib_System_ObjectPi,__Z86mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_TypeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z50mscorlib_System_Activator_m_CreateInstanceInternalP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z50mscorlib_System_AppDomain_m_InternalGetProcessGuidP22mscorlib_System_ObjectP22mscorlib_System_String,__Z35mscorlib_System_Buffer_m_ByteLengthP22mscorlib_System_ObjectP21mscorlib_System_Array,__Z43mscorlib_System_Buffer_m_ByteLengthInternalP22mscorlib_System_ObjectP21mscorlib_System_Array,__Z80mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z83mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z81mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z81mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z81mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_Int16P22mscorlib_System_Objects,__Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z77mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z74mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_CharP22mscorlib_System_Objectt,__Z77mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z75mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z75mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_SByteP22mscorlib_System_Objecta
  ,__Z75mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_Int16P22mscorlib_System_Objects,__Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z74mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z75mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z75mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z75mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_Int16P22mscorlib_System_Objects,__Z76mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z76mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z79mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z76mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z76mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_CharP22mscorlib_System_Objectt,__Z79mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z77mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z77mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z77mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_Int16P22mscorlib_System_Objects,__Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z79mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z76mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z76mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_CharP22mscorlib_System_Objectt,__Z79mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z77mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z77mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_Int16P22mscorlib_System_Objects,__Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z79mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z76mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z76mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_CharP22mscorlib_System_Objectt
  ,__Z79mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z77mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z77mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z77mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_Int16P22mscorlib_System_Objects,__Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_,__Z79mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z76mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z76mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_CharP22mscorlib_System_Objectt,__Z79mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z77mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z77mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int16P22mscorlib_System_Objects,__Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z81mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z78mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z78mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_CharP22mscorlib_System_Objectt,__Z81mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z79mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z79mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z79mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int16P22mscorlib_System_Objects,__Z80mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z81mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z78mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z78mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_CharP22mscorlib_System_Objectt,__Z81mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z79mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z79mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z79mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int16P22mscorlib_System_Objects
  ,__Z80mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z81mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z78mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z78mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_CharP22mscorlib_System_Objectt,__Z81mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z79mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z79mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z79mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int16P22mscorlib_System_Objects,__Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z80mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_,__Z54mscorlib_System_DBNull_m_System_IConvertible_ToBooleanP22mscorlib_System_DBNullP22mscorlib_System_Object,__Z51mscorlib_System_DBNull_m_System_IConvertible_ToByteP22mscorlib_System_DBNullP22mscorlib_System_Object,__Z51mscorlib_System_DBNull_m_System_IConvertible_ToCharP22mscorlib_System_DBNullP22mscorlib_System_Object,__Z52mscorlib_System_DBNull_m_System_IConvertible_ToInt16P22mscorlib_System_DBNullP22mscorlib_System_Object,__Z52mscorlib_System_DBNull_m_System_IConvertible_ToInt32P22mscorlib_System_DBNullP22mscorlib_System_Object,__Z52mscorlib_System_DBNull_m_System_IConvertible_ToInt64P22mscorlib_System_DBNullP22mscorlib_System_Object,__Z52mscorlib_System_DBNull_m_System_IConvertible_ToSByteP22mscorlib_System_DBNullP22mscorlib_System_Object,__Z53mscorlib_System_DBNull_m_System_IConvertible_ToUInt16P22mscorlib_System_DBNullP22mscorlib_System_Object,__Z53mscorlib_System_DBNull_m_System_IConvertible_ToUInt32P22mscorlib_System_DBNullP22mscorlib_System_Object,__Z53mscorlib_System_DBNull_m_System_IConvertible_ToUInt64P22mscorlib_System_DBNullP22mscorlib_System_Object,__Z88mscorlib_System_DBNull_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_DBNullP22mscorlib_System_Object,__Z56mscorlib_System_DateTime_m_System_IConvertible_ToBooleanP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z53mscorlib_System_DateTime_m_System_IConvertible_ToByteP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z53mscorlib_System_DateTime_m_System_IConvertible_ToCharP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z54mscorlib_System_DateTime_m_System_IConvertible_ToInt16P24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z54mscorlib_System_DateTime_m_System_IConvertible_ToInt32P24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z54mscorlib_System_DateTime_m_System_IConvertible_ToInt64P24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z54mscorlib_System_DateTime_m_System_IConvertible_ToSByteP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z55mscorlib_System_DateTime_m_System_IConvertible_ToUInt16P24mscorlib_System_DateTimeP22mscorlib_System_Object
  ,__Z55mscorlib_System_DateTime_m_System_IConvertible_ToUInt32P24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z55mscorlib_System_DateTime_m_System_IConvertible_ToUInt64P24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z36mscorlib_System_DateTime_m_FromTicksP24mscorlib_System_DateTimei,__Z81mscorlib_System_DateTime_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z83mscorlib_System_DateTime_m_CompareTo_mscorlib_System_Int32_mscorlib_System_DateTimeP24mscorlib_System_DateTimeS_,__Z82mscorlib_System_DateTime_m_Equals_mscorlib_System_Boolean_mscorlib_System_DateTimeP24mscorlib_System_DateTimeS_,__Z80mscorlib_System_DateTime_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z37mscorlib_System_DateTime_m_IsLeapYearP22mscorlib_System_Objecti,__Z90mscorlib_System_DateTime_m_ToString_mscorlib_System_String_mscorlib_System_IFormatProviderP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z61mscorlib_System_DateTimeOffset_m_System_IComparable_CompareToP30mscorlib_System_DateTimeOffsetP22mscorlib_System_Object,__Z42mscorlib_System_DateTimeOffset_m_CompareToP30mscorlib_System_DateTimeOffsetS_,__Z94mscorlib_System_DateTimeOffset_m_Equals_mscorlib_System_Boolean_mscorlib_System_DateTimeOffsetP30mscorlib_System_DateTimeOffsetS_,__Z86mscorlib_System_DateTimeOffset_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP30mscorlib_System_DateTimeOffsetP22mscorlib_System_Object,__Z60mscorlib_System_Environment_m_internalGetEnvironmentVariableP22mscorlib_System_ObjectP22mscorlib_System_String,__Z77mscorlib_System_Guid_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP20mscorlib_System_GuidP22mscorlib_System_Object,__Z76mscorlib_System_Guid_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP20mscorlib_System_GuidP22mscorlib_System_Object,__Z75mscorlib_System_Guid_m_CompareTo_mscorlib_System_Int32_mscorlib_System_GuidP20mscorlib_System_GuidS_,__Z74mscorlib_System_Guid_m_Equals_mscorlib_System_Boolean_mscorlib_System_GuidP20mscorlib_System_GuidS_,__Z28mscorlib_System_Guid_m_ToHexP22mscorlib_System_Objecti,__Z77mscorlib_System_Guid_m_ToString_mscorlib_System_String_mscorlib_System_StringP20mscorlib_System_GuidP22mscorlib_System_String,__Z70mscorlib_System_Math_m_Abs_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z53mscorlib_System_MonoCustomAttrs_m_IsUserCattrProviderP22mscorlib_System_ObjectS0_,__Z59mscorlib_System_MonoCustomAttrs_m_GetBasePropertyDefinitionP22mscorlib_System_ObjectP39mscorlib_System_Reflection_PropertyInfo,__Z41mscorlib_System_MonoCustomAttrs_m_GetBaseP22mscorlib_System_ObjectS0_,__Z56mscorlib_System_MonoCustomAttrs_m_RetrieveAttributeUsageP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z41mscorlib_System_MonoType_m_get_attributesP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z42mscorlib_System_MonoType_m_GetConstructorsP24mscorlib_System_MonoTypei,__Z36mscorlib_System_MonoType_m_GetFieldsP24mscorlib_System_MonoTypei,__Z37mscorlib_System_MonoType_m_GetMethodsP24mscorlib_System_MonoTypei,__Z40mscorlib_System_MonoType_m_GetPropertiesP24mscorlib_System_MonoTypei
  ,__Z39mscorlib_System_MonoType_m_IsSubclassOfP24mscorlib_System_MonoTypeP20mscorlib_System_Type,__Z101mscorlib_System_MonoType_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_BooleanP24mscorlib_System_MonoTypeb,__Z46mscorlib_System_MonoType_m_CheckMethodSecurityP24mscorlib_System_MonoTypeP37mscorlib_System_Reflection_MethodBase,__Z47mscorlib_System_NumberFormatter_m_GetTenPowerOfP22mscorlib_System_Objecti,__Z46mscorlib_System_NumberFormatter_m_FastToDecHexP22mscorlib_System_Objecti,__Z42mscorlib_System_NumberFormatter_m_ToDecHexP22mscorlib_System_Objecti,__Z47mscorlib_System_NumberFormatter_m_FastDecHexLenP22mscorlib_System_Objecti,__Z88mscorlib_System_NumberFormatter_m_DecHexLen_mscorlib_System_Int32_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z48mscorlib_System_NumberFormatter_m_ParsePrecisionP22mscorlib_System_ObjectP22mscorlib_System_String,__Z57mscorlib_System_NumberFormatter_m_GetNumberFormatInstanceP31mscorlib_System_NumberFormatterP22mscorlib_System_Object,__Z46mscorlib_System_NumberFormatter_m_RoundDecimalP31mscorlib_System_NumberFormatteri,__Z43mscorlib_System_NumberFormatter_m_RoundBitsP31mscorlib_System_NumberFormatteri,__Z94mscorlib_System_NumberFormatter_m_AddOneToDecHex_mscorlib_System_UInt32_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z97mscorlib_System_NumberFormatter_m_CountTrailingZeros_mscorlib_System_Int32_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z51mscorlib_System_NumberFormatter_m_FormatHexadecimalP31mscorlib_System_NumberFormatteri,__Z44mscorlib_System_NumberFormatter_m_IsZeroOnlyP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilder,__Z44mscorlib_System_RuntimeMethodHandle_m_EqualsP35mscorlib_System_RuntimeMethodHandleP22mscorlib_System_Object,__Z89mscorlib_System_StringComparer_m_GetHashCode_mscorlib_System_Int32_mscorlib_System_ObjectP30mscorlib_System_StringComparerP22mscorlib_System_Object,__Z50mscorlib_System_CultureAwareComparer_m_GetHashCodeP36mscorlib_System_CultureAwareComparerP22mscorlib_System_String,__Z45mscorlib_System_OrdinalComparer_m_GetHashCodeP31mscorlib_System_OrdinalComparerP22mscorlib_System_String,__Z30mscorlib_System_TimeSpan_m_AddP24mscorlib_System_TimeSpanS_,__Z81mscorlib_System_TimeSpan_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP24mscorlib_System_TimeSpanP22mscorlib_System_Object,__Z83mscorlib_System_TimeSpan_m_CompareTo_mscorlib_System_Int32_mscorlib_System_TimeSpanP24mscorlib_System_TimeSpanS_,__Z82mscorlib_System_TimeSpan_m_Equals_mscorlib_System_Boolean_mscorlib_System_TimeSpanP24mscorlib_System_TimeSpanS_,__Z80mscorlib_System_TimeSpan_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP24mscorlib_System_TimeSpanP22mscorlib_System_Object,__Z35mscorlib_System_TimeSpan_m_SubtractP24mscorlib_System_TimeSpanS_,__Z96mscorlib_System_TimeZone_m_IsDaylightSavingTime_mscorlib_System_Boolean_mscorlib_System_DateTimeP24mscorlib_System_TimeZone24mscorlib_System_DateTime,__Z93mscorlib_System_TimeZone_m_GetLocalTimeDiff_mscorlib_System_TimeSpan_mscorlib_System_DateTimeP24mscorlib_System_TimeZone24mscorlib_System_DateTime,__Z58mscorlib_System_CurrentSystemTimeZone_m_GetDaylightChangesP37mscorlib_System_CurrentSystemTimeZonei,__Z52mscorlib_System_CurrentSystemTimeZone_m_GetUtcOffsetP37mscorlib_System_CurrentSystemTimeZone24mscorlib_System_DateTime
  ,__Z63mscorlib_System_CurrentSystemTimeZone_m_GetDaylightTimeFromDataP37mscorlib_System_CurrentSystemTimeZoneP25mscorlib_System_Int64_arr,__Z80mscorlib_System_Version_m_CompareTo_mscorlib_System_Int32_mscorlib_System_ObjectP23mscorlib_System_VersionP22mscorlib_System_Object,__Z81mscorlib_System_Version_m_CompareTo_mscorlib_System_Int32_mscorlib_System_VersionP23mscorlib_System_VersionS0_,__Z79mscorlib_System_Version_m_Equals_mscorlib_System_Boolean_mscorlib_System_ObjectP23mscorlib_System_VersionP22mscorlib_System_Object,__Z80mscorlib_System_Version_m_Equals_mscorlib_System_Boolean_mscorlib_System_VersionP23mscorlib_System_VersionS0_,__Z42mscorlib_System_Version_m_CreateFromStringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z51mscorlib_System_Reflection_MemberFilter_m_EndInvokeP39mscorlib_System_Reflection_MemberFilterP22mscorlib_System_Object,__Z49mscorlib_System_Reflection_TypeFilter_m_EndInvokeP37mscorlib_System_Reflection_TypeFilterP22mscorlib_System_Object,__Z47mscorlib_System_ResolveEventHandler_m_EndInvokeP35mscorlib_System_ResolveEventHandlerP22mscorlib_System_Object,__Z52replacements_Replacements_Thread_m_GetCurrentCultureP22mscorlib_System_ObjectP32mscorlib_System_Threading_Thread,__Z89UnityEngine_UnityEngine_AttributeHelperEngine_m_GetParentTypeDisallowingMultipleInclusionP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z69UnityEngine_UnityEngine_AttributeHelperEngine_m_GetRequiredComponentsP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z67UnityEngine_UnityEngine_AttributeHelperEngine_m_CheckIsEditorScriptP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z133UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_op_Implicit_mscorlib_System_Boolean_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP22mscorlib_System_Object47UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__Z66UnityEngine_UnityEngine_StackTraceUtility_m_IsSystemStacktraceTypeP22mscorlib_System_ObjectS0_,__Z70UnityEngine_UnityEngine_StackTraceUtility_m_ExtractStringFromExceptionP22mscorlib_System_ObjectS0_,__Z70UnityEngine_UnityEngine_StackTraceUtility_m_ExtractFormattedStackTraceP22mscorlib_System_ObjectP38mscorlib_System_Diagnostics_StackTrace,__Z55UnityEngine_UnityEngine_TextGenerationSettings_m_EqualsP46UnityEngine_UnityEngine_TextGenerationSettingsS_,__Z49UnityEngine_UnityEngine_TrackedReference_m_EqualsP40UnityEngine_UnityEngine_TrackedReferenceP22mscorlib_System_Object,__Z54UnityEngine_UnityEngine_Application_m_ObjectToJSStringP22mscorlib_System_ObjectS0_,__Z103UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Component_mscorlib_System_TypeP33UnityEngine_UnityEngine_ComponentP20mscorlib_System_Type,__Z52UnityEngine_UnityEngine_GameObject_m_CreatePrimitiveP22mscorlib_System_Objecti,__Z49UnityEngine_UnityEngine_GameObject_m_GetComponentP34UnityEngine_UnityEngine_GameObjectP20mscorlib_System_Type,__Z39UnityEngine_UnityEngine_Object_m_EqualsP30UnityEngine_UnityEngine_ObjectP22mscorlib_System_Object,__Z52UnityEngine_UnityEngine_Object_m_IsNativeObjectAliveP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Object,__Z99UnityEngine_UnityEngine_Object_m_op_Implicit_mscorlib_System_Boolean_UnityEngine_UnityEngine_ObjectP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Object,__Z63UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_EqualsP54UnityEngine_UnityEngine_Internal_DefaultValueAttributeP22mscorlib_System_Object,__Z47UnityEngine_UnityEngine_LayerMask_m_LayerToNameP22mscorlib_System_Objecti,__Z47UnityEngine_UnityEngine_LayerMask_m_NameToLayerP22mscorlib_System_ObjectP22mscorlib_System_String,__Z43UnityEngine_UnityEngine_LayerMask_m_GetMaskP22mscorlib_System_ObjectP26mscorlib_System_String_arr
  ,__Z103UnityEngine_UnityEngine_LayerMask_m_op_Implicit_mscorlib_System_Int32_UnityEngine_UnityEngine_LayerMaskP22mscorlib_System_Object33UnityEngine_UnityEngine_LayerMask,__Z103UnityEngine_UnityEngine_LayerMask_m_op_Implicit_UnityEngine_UnityEngine_LayerMask_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z121UnityEngine_UnityEngine_ScriptableObject_m_CreateInstance_UnityEngine_UnityEngine_ScriptableObject_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z119UnityEngine_UnityEngine_ScriptableObject_m_CreateInstance_UnityEngine_UnityEngine_ScriptableObject_mscorlib_System_TypeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z65UnityEngine_UnityEngine_ScriptableObject_m_CreateInstanceFromTypeP22mscorlib_System_ObjectP20mscorlib_System_Type,__Z94UnityEngine_UnityEngine_Resources_m_Load_UnityEngine_UnityEngine_Object_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_String,__Z43UnityEngine_UnityEngine_BoneWeight_m_EqualsP34UnityEngine_UnityEngine_BoneWeightP22mscorlib_System_Object,__Z42UnityEngine_UnityEngine_GUILayer_m_HitTestP32UnityEngine_UnityEngine_GUILayer31UnityEngine_UnityEngine_Vector3,__Z60UnityEngine_UnityEngine_GUIUtility_m_Internal_GetDefaultSkinP22mscorlib_System_Objecti,__Z42UnityEngine_UnityEngine_GUISkin_m_GetStyleP31UnityEngine_UnityEngine_GUISkinP22mscorlib_System_String,__Z43UnityEngine_UnityEngine_GUISkin_m_FindStyleP31UnityEngine_UnityEngine_GUISkinP22mscorlib_System_String,__Z51UnityEngine_UnityEngine_GUIStyle_m_GetStyleStatePtrP32UnityEngine_UnityEngine_GUIStylei,__Z51UnityEngine_UnityEngine_GUIStyle_m_GetRectOffsetPtrP32UnityEngine_UnityEngine_GUIStylei,__Z38UnityEngine_UnityEngine_Event_m_EqualsP29UnityEngine_UnityEngine_EventP22mscorlib_System_Object,__Z40UnityEngine_UnityEngine_Vector2_m_EqualsP31UnityEngine_UnityEngine_Vector2P22mscorlib_System_Object,__Z40UnityEngine_UnityEngine_Vector3_m_EqualsP31UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object,__Z88UnityEngine_UnityEngine_Vector3_m_ToString_mscorlib_System_String_mscorlib_System_StringP31UnityEngine_UnityEngine_Vector3P22mscorlib_System_String,__Z38UnityEngine_UnityEngine_Color_m_EqualsP29UnityEngine_UnityEngine_ColorP22mscorlib_System_Object,__Z43UnityEngine_UnityEngine_Quaternion_m_EqualsP34UnityEngine_UnityEngine_QuaternionP22mscorlib_System_Object,__Z39UnityEngine_UnityEngine_Rect_m_ContainsP28UnityEngine_UnityEngine_Rect31UnityEngine_UnityEngine_Vector3,__Z37UnityEngine_UnityEngine_Rect_m_EqualsP28UnityEngine_UnityEngine_RectP22mscorlib_System_Object,__Z42UnityEngine_UnityEngine_Matrix4x4_m_EqualsP33UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_Object,__Z90UnityEngine_UnityEngine_Matrix4x4_m_ToString_mscorlib_System_String_mscorlib_System_StringP33UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_String,__Z39UnityEngine_UnityEngine_Bounds_m_EqualsP30UnityEngine_UnityEngine_BoundsP22mscorlib_System_Object,__Z43UnityEngine_UnityEngine_Bounds_m_IntersectsP30UnityEngine_UnityEngine_BoundsS_,__Z41UnityEngine_UnityEngine_Bounds_m_ContainsP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z97UnityEngine_UnityEngine_Bounds_m_IntersectRay_mscorlib_System_Boolean_UnityEngine_UnityEngine_RayP30UnityEngine_UnityEngine_Bounds27UnityEngine_UnityEngine_Ray,__Z87UnityEngine_UnityEngine_Bounds_m_ToString_mscorlib_System_String_mscorlib_System_StringP30UnityEngine_UnityEngine_BoundsP22mscorlib_System_String,__Z40UnityEngine_UnityEngine_Vector4_m_EqualsP31UnityEngine_UnityEngine_Vector4P22mscorlib_System_Object,__Z45UnityEngine_UnityEngine_Shader_m_PropertyToIDP22mscorlib_System_ObjectP22mscorlib_System_String
  ,__Z46UnityEngine_UnityEngine_Camera_m_GetAllCamerasP22mscorlib_System_ObjectP34UnityEngine_UnityEngine_Camera_arr,__Z59UnityEngine_UnityEngine_MonoBehaviour_m_StartCoroutine_AutoP37UnityEngine_UnityEngine_MonoBehaviourP22mscorlib_System_Object,__Z41UnityEngine_UnityEngine_Input_m_GetKeyIntP22mscorlib_System_Objecti,__Z41UnityEngine_UnityEngine_Input_m_GetButtonP22mscorlib_System_ObjectP22mscorlib_System_String,__Z45UnityEngine_UnityEngine_Input_m_GetButtonDownP22mscorlib_System_ObjectP22mscorlib_System_String,__Z38UnityEngine_UnityEngine_Input_m_GetKeyP22mscorlib_System_Objecti,__Z46UnityEngine_UnityEngine_Input_m_GetMouseButtonP22mscorlib_System_Objecti,__Z50UnityEngine_UnityEngine_Input_m_GetMouseButtonDownP22mscorlib_System_Objecti,__Z50UnityEngine_UnityEngine_CharacterController_m_MoveP43UnityEngine_UnityEngine_CharacterController31UnityEngine_UnityEngine_Vector3,__Z44UnityEngine_UnityEngine_Animation_m_get_ItemP33UnityEngine_UnityEngine_AnimationP22mscorlib_System_String,__Z44UnityEngine_UnityEngine_Animation_m_GetStateP33UnityEngine_UnityEngine_AnimationP22mscorlib_System_String,__Z50UnityEngine_UnityEngine_AnimatorStateInfo_m_IsNameP41UnityEngine_UnityEngine_AnimatorStateInfoP22mscorlib_System_String,__Z49UnityEngine_UnityEngine_AnimatorStateInfo_m_IsTagP41UnityEngine_UnityEngine_AnimatorStateInfoP22mscorlib_System_String,__Z55UnityEngine_UnityEngine_AnimatorTransitionInfo_m_IsNameP46UnityEngine_UnityEngine_AnimatorTransitionInfoP22mscorlib_System_String,__Z59UnityEngine_UnityEngine_AnimatorTransitionInfo_m_IsUserNameP46UnityEngine_UnityEngine_AnimatorTransitionInfoP22mscorlib_System_String,__Z47UnityEngine_UnityEngine_Animator_m_StringToHashP22mscorlib_System_ObjectP22mscorlib_System_String,__ZL70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ObjectP21mscorlib_System_Arrayi,__ZL80mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharp_BJControllerP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP32AssemblyU002DCSharp_BJController,__ZL82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ObjectP21mscorlib_System_ArrayP22mscorlib_System_Object,__ZL80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ObjectP21mscorlib_System_ArrayP22mscorlib_System_Object,__ZL69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ObjectP21mscorlib_System_ArrayP22mscorlib_System_Object,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP32AssemblyU002DCSharp_BJController,__ZL79mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP32AssemblyU002DCSharp_BJController,__ZL80mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP32AssemblyU002DCSharp_LevelBuilder,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP32AssemblyU002DCSharp_LevelBuilder,__ZL79mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP32AssemblyU002DCSharp_LevelBuilder,__ZL70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_StringP21mscorlib_System_Arrayi,__ZL82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_StringP21mscorlib_System_ArrayP22mscorlib_System_String
  ,__ZL80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_StringP21mscorlib_System_ArrayP22mscorlib_System_String,__ZL69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_StringP21mscorlib_System_ArrayP22mscorlib_System_String,__Z68mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_CharP21mscorlib_System_Arrayi,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_CharP21mscorlib_System_Arrayt,__Z78mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_CharP21mscorlib_System_Arrayt,__Z67mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_CharP21mscorlib_System_Arrayt,__ZL68mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_TypeP21mscorlib_System_Arrayi,__ZL80mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_TypeP21mscorlib_System_ArrayP20mscorlib_System_Type,__ZL78mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_TypeP21mscorlib_System_ArrayP20mscorlib_System_Type,__ZL67mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_TypeP21mscorlib_System_ArrayP20mscorlib_System_Type,__ZL78mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP30AssemblyU002DCSharp_JSONObject,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP30AssemblyU002DCSharp_JSONObject,__ZL77mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP30AssemblyU002DCSharp_JSONObject,__Z165mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z163mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z152mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z69mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z81mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z79mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z68mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array40mscorlib_System_Collections_Generic_Link,__Z98mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array40mscorlib_System_Collections_Generic_Link,__Z87mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array40mscorlib_System_Collections_Generic_Link,__Z103mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array43mscorlib_System_Collections_DictionaryEntry,__Z101mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array43mscorlib_System_Collections_DictionaryEntry,__Z90mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array43mscorlib_System_Collections_DictionaryEntry,__Z165mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z163mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z152mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String
  ,__Z173mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z171mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z160mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z83mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi,__Z95mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi,__Z82mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayi,__Z136mscorlib_System_Array_m_InternalArray__ICollection_Contains_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__Z134mscorlib_System_Array_m_InternalArray__ICollection_Remove_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__Z123mscorlib_System_Array_m_InternalArray__IndexOf_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__Z164mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z162mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z151mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__ZL84mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_Arrayi,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_FieldInfo,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_FieldInfo,__ZL83mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_FieldInfo,__ZL87mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_Arrayi,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP39mscorlib_System_Reflection_PropertyInfo,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP39mscorlib_System_Reflection_PropertyInfo,__ZL86mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP39mscorlib_System_Reflection_PropertyInfo,__ZL91mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_Arrayi,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__ZL101mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__ZL90mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__Z104mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi,__Z116mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi,__Z114mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi,__Z103mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array32UnityEngine_UnityEngine_Keyframe
  ,__Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array32UnityEngine_UnityEngine_Keyframe,__Z79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array32UnityEngine_UnityEngine_Keyframe,__Z109mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi,__Z121mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi,__Z119mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi,__Z108mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayi,__ZL101mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_Arrayi,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL100mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL91mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_Arrayi,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_CharacterController,__ZL101mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_CharacterController,__ZL90mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_CharacterController,__ZL105mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_Arrayi,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL104mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL110mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_Arrayi,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__ZL109mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__ZL104mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_Arrayi,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL103mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL108mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_Arrayi,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__ZL107mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController
  ,__Z101mscorlib_System_Array_m_InternalArray__get_Item_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi,__Z113mscorlib_System_Array_m_InternalArray__ICollection_Contains_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi,__Z111mscorlib_System_Array_m_InternalArray__ICollection_Remove_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__IndexOf_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayi,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AnimationP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Animation,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Animation,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Animation,__ZL88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_Arrayi,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_WrapperlessIcall,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_WrapperlessIcall,__ZL87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_WrapperlessIcall,__ZL97mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_Arrayi,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL96mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL89mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_Arrayi,__ZL101mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_ExecuteInEditMode,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_ExecuteInEditMode,__ZL88mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_ExecuteInEditMode,__ZL88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_Arrayi,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_RequireComponent,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_RequireComponent,__ZL87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_RequireComponent,__ZL85mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_MonoBehaviour,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_MonoBehaviour,__ZL84mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_MonoBehaviour,__Z92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Arrayi,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array44mscorlib_System_Reflection_ParameterModifier
  ,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array44mscorlib_System_Reflection_ParameterModifier,__Z91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array44mscorlib_System_Reflection_ParameterModifier,__ZL89mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_Arrayi,__ZL101mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_WritableAttribute,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_WritableAttribute,__ZL88mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_WritableAttribute,__ZL96mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_Arrayi,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL95mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL87mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_Arrayi,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_GUILayoutOption,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_GUILayoutOption,__ZL86mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_GUILayoutOption,__Z107mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array47UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__Z105mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array47UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__Z94mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array47UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CameraP21mscorlib_System_Arrayi,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Camera,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Camera,__ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Camera,__ZL88mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_Arrayi,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_ParameterInfo,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_ParameterInfo,__ZL87mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_ParameterInfo,__ZL93mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_Arrayi,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_StateMachineBehaviour,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_StateMachineBehaviour,__ZL92mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_StateMachineBehaviour,__Z195mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp
  ,__Z193mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z182mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__ZL77mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_EventP21mscorlib_System_Arrayi,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP29UnityEngine_UnityEngine_Event,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP29UnityEngine_UnityEngine_Event,__ZL76mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP29UnityEngine_UnityEngine_Event,__Z93mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi,__Z105mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi,__Z103mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi,__Z99mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayi,__Z111mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayh,__Z109mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayh,__Z98mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayh,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array32UnityEngine_UnityEngine_UIVertex,__Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array32UnityEngine_UnityEngine_UIVertex,__Z79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array32UnityEngine_UnityEngine_UIVertex,__Z94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UICharInfo,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UICharInfo,__Z81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UICharInfo,__Z94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UILineInfo,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UILineInfo,__Z81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array34UnityEngine_UnityEngine_UILineInfo,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ComponentP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Component,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Component,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Component,__ZL82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_Arrayi,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GameObject,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GameObject
  ,__ZL81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GameObject,__ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ObjectP21mscorlib_System_Arrayi,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Object,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Object,__ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Object,__ZL93mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_Arrayi,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL92mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL96mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_Arrayi,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL95mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL95mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_Arrayi,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL94mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL102mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_Arrayi,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL101mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL105mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_Arrayi,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL104mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL102mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_Arrayi,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__ZL101mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__Z98mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi
  ,__Z110mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi,__Z108mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayi,__ZL106mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_Arrayi,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL105mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL83mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_Arrayi,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_AssetBundle,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_AssetBundle,__ZL82mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_AssetBundle,__Z90mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayi,__Z85mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi,__Z95mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi,__Z84mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayi,__Z77mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi,__Z87mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi,__Z76mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayi,__Z79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi,__Z78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayi,__ZL88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_Arrayi,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_AddComponentMenu,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_AddComponentMenu
  ,__ZL87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_AddComponentMenu,__ZL88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_Arrayi,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_ScriptableObject,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_ScriptableObject,__ZL87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP40UnityEngine_UnityEngine_ScriptableObject,__Z88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi,__Z98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi,__Z87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayi,__ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RendererP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Renderer,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Renderer,__ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Renderer,__ZL87mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_Arrayi,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_ReflectionProbe,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_ReflectionProbe,__ZL86mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_ReflectionProbe,__ZL79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextureP21mscorlib_System_Arrayi,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Texture,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Texture,__ZL78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Texture,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Texture2D,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Texture2D,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Texture2D,__ZL85mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_RenderTexture,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_RenderTexture,__ZL84mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_RenderTexture,__ZL82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_Arrayi
  ,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GUIElement,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GUIElement,__ZL81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_GUIElement,__ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUILayer,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUILayer,__ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUILayer,__Z194mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z192mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z181mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL100mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL99mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL86mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_Arrayi,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL85mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUILayoutEntry,__Z92mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayi,__ZL79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_Arrayi,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_GUISkin,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_GUISkin,__ZL78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_GUISkin,__ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUIStyle,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUIStyle,__ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_GUIStyle
  ,__Z175mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z173mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z162mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi,__Z80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayi,__Z79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi,__Z78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayi,__Z81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi,__Z80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayi,__Z86mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi,__Z98mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi,__Z96mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi,__Z85mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayi,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_TextAsset,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_TextAsset,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_TextAsset,__ZL97mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_Arrayi,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_SerializePrivateVariables,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_SerializePrivateVariables,__ZL96mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_SerializePrivateVariables,__ZL86mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_Arrayi,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_SerializeField,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_SerializeField
  ,__ZL85mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_SerializeField,__ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ShaderP21mscorlib_System_Arrayi,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Shader,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Shader,__ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Shader,__ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_MaterialP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Material,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Material,__ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Material,__ZL72mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Byte_arrP21mscorlib_System_Arrayi,__ZL84mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP24mscorlib_System_Byte_arr,__ZL82mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP24mscorlib_System_Byte_arr,__ZL71mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP24mscorlib_System_Byte_arr,__Z68mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ByteP21mscorlib_System_Arrayi,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ByteP21mscorlib_System_Arrayh,__Z78mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ByteP21mscorlib_System_Arrayh,__Z67mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ByteP21mscorlib_System_Arrayh,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Behaviour,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Behaviour,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Behaviour,__ZL79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_DisplayP21mscorlib_System_Arrayi,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Display,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Display,__ZL78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Display,__Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_IntPtrP21mscorlib_System_Arrayi,__Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_IntPtrP21mscorlib_System_Array22mscorlib_System_IntPtr,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_IntPtrP21mscorlib_System_Array22mscorlib_System_IntPtr,__Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_IntPtrP21mscorlib_System_Array22mscorlib_System_IntPtr,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TransformP21mscorlib_System_Arrayi
  ,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Transform,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Transform,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Transform,__ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_MotionP21mscorlib_System_Arrayi,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Motion,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Motion,__ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Motion,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Rigidbody,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Rigidbody,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Rigidbody,__ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_ColliderP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Collider,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Collider,__ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Collider,__Z86mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi,__Z98mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi,__Z96mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi,__Z85mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayi,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_AudioClip,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_AudioClip,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_AudioClip,__Z80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi,__Z79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi
  ,__Z91mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayi,__ZL85mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AnimationClip,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AnimationClip,__ZL84mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AnimationClip,__Z80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi,__Z79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayi,__ZL80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_Arrayi,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Animator,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Animator,__ZL79mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Animator,__ZL79mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TerrainP21mscorlib_System_Arrayi,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Terrain,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Terrain,__ZL78mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP31UnityEngine_UnityEngine_Terrain,__Z82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi,__Z94mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi,__Z81mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayi,__Z88mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi,__Z98mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi,__Z87mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayi,__ZL76mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_FontP21mscorlib_System_Arrayi
  ,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP28UnityEngine_UnityEngine_Font,__ZL86mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP28UnityEngine_UnityEngine_Font,__ZL75mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP28UnityEngine_UnityEngine_Font,__ZL78mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_CanvasP21mscorlib_System_Arrayi,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Canvas,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Canvas,__ZL77mscorlib_System_Array_m_InternalArray__IndexOf_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP30UnityEngine_UnityEngine_Canvas,__ZL110mscorlib_System_Array_m_InternalArray__get_Item_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_Arrayi,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_Contains_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_Remove_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL109mscorlib_System_Array_m_InternalArray__IndexOf_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL84mscorlib_System_Array_m_InternalArray__get_Item_System_Core_System_MonoTODOAttributeP21mscorlib_System_Arrayi,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Contains_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP36System_Core_System_MonoTODOAttribute,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_Remove_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP36System_Core_System_MonoTODOAttribute,__ZL83mscorlib_System_Array_m_InternalArray__IndexOf_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP36System_Core_System_MonoTODOAttribute,__ZL73mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_AttributeP21mscorlib_System_Arrayi,__ZL85mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_AttributeP21mscorlib_System_ArrayP25mscorlib_System_Attribute,__ZL83mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_AttributeP21mscorlib_System_ArrayP25mscorlib_System_Attribute,__ZL72mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_AttributeP21mscorlib_System_ArrayP25mscorlib_System_Attribute,__ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_SerializableAttributeP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP37mscorlib_System_SerializableAttribute,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP37mscorlib_System_SerializableAttribute,__ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP37mscorlib_System_SerializableAttribute,__ZL87mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_Arrayi,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP39mscorlib_System_AttributeUsageAttribute,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP39mscorlib_System_AttributeUsageAttribute,__ZL86mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP39mscorlib_System_AttributeUsageAttribute,__ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_Arrayi,__ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute
  ,__ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__Z69mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Int64P21mscorlib_System_Arrayi,__Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_UInt32P21mscorlib_System_Arrayi,__Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_UInt32P21mscorlib_System_Arrayj,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_UInt32P21mscorlib_System_Arrayj,__Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_UInt32P21mscorlib_System_Arrayj,__ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP37mscorlib_System_CLSCompliantAttribute,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP37mscorlib_System_CLSCompliantAttribute,__ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP37mscorlib_System_CLSCompliantAttribute,__Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_UInt64P21mscorlib_System_Arrayi,__Z69mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_SByteP21mscorlib_System_Arrayi,__Z81mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_SByteP21mscorlib_System_Arraya,__Z79mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_SByteP21mscorlib_System_Arraya,__Z68mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_SByteP21mscorlib_System_Arraya,__Z69mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Int16P21mscorlib_System_Arrayi,__Z81mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Int16P21mscorlib_System_Arrays,__Z79mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Int16P21mscorlib_System_Arrays,__Z68mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Int16P21mscorlib_System_Arrays,__Z70mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_UInt16P21mscorlib_System_Arrayi,__Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_UInt16P21mscorlib_System_Arrayt,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_UInt16P21mscorlib_System_Arrayt,__Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_UInt16P21mscorlib_System_Arrayt,__Z71mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_BooleanP21mscorlib_System_Arrayi,__Z83mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_BooleanP21mscorlib_System_Arrayb,__Z81mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_BooleanP21mscorlib_System_Arrayb,__Z70mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_BooleanP21mscorlib_System_Arrayb,__Z71mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_UIntPtrP21mscorlib_System_Arrayi,__Z83mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_UIntPtrP21mscorlib_System_Array23mscorlib_System_UIntPtr,__Z81mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_UIntPtrP21mscorlib_System_Array23mscorlib_System_UIntPtr
  ,__Z70mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_UIntPtrP21mscorlib_System_Array23mscorlib_System_UIntPtr,__ZL72mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DelegateP21mscorlib_System_Arrayi,__ZL84mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DelegateP21mscorlib_System_ArrayP24mscorlib_System_Delegate,__ZL82mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DelegateP21mscorlib_System_ArrayP24mscorlib_System_Delegate,__ZL71mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DelegateP21mscorlib_System_ArrayP24mscorlib_System_Delegate,__ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodInfo,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodInfo,__ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodInfo,__ZL90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_Arrayi,__ZL102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP42mscorlib_System_Reflection_ConstructorInfo,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP42mscorlib_System_Reflection_ConstructorInfo,__ZL89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP42mscorlib_System_Reflection_ConstructorInfo,__ZL83mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ParamArrayAttributeP21mscorlib_System_Arrayi,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP35mscorlib_System_ParamArrayAttribute,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP35mscorlib_System_ParamArrayAttribute,__ZL82mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP35mscorlib_System_ParamArrayAttribute,__ZL100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_Arrayi,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP52mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP52mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP52mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ObsoleteAttributeP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP33mscorlib_System_ObsoleteAttribute,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP33mscorlib_System_ObsoleteAttribute,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP33mscorlib_System_ObsoleteAttribute,__ZL106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_Arrayi,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_Arrayi
  ,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_Arrayi,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP51mscorlib_System_Runtime_InteropServices_InAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP51mscorlib_System_Runtime_InteropServices_InAttribute,__ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP51mscorlib_System_Runtime_InteropServices_InAttribute,__ZL101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_Arrayi,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP53mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP53mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP53mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_Arrayi,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL105mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_Arrayi,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL104mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL115mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_Arrayi,__ZL127mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL125mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL114mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL116mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_Arrayi,__ZL128mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL126mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL115mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL118mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_Arrayi,__ZL130mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL128mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute
  ,__ZL117mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_Arrayi,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_Arrayi,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_DefaultMemberAttribute,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_DefaultMemberAttribute,__ZL96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_DefaultMemberAttribute,__ZL113mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_Arrayi,__ZL125mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL123mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL112mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL108mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_Arrayi,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL107mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL81mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_MonoTODOAttributeP21mscorlib_System_Arrayi,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP33mscorlib_System_MonoTODOAttribute,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP33mscorlib_System_MonoTODOAttribute,__ZL80mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP33mscorlib_System_MonoTODOAttribute,__Z123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__Z121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__Z110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__ZL97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_Arrayi,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL95mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_Arrayi,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP47mscorlib_Mono_Globalization_Unicode_Contraction
  ,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP47mscorlib_Mono_Globalization_Unicode_Contraction,__ZL94mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP47mscorlib_Mono_Globalization_Unicode_Contraction,__ZL93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_Arrayi,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP45mscorlib_Mono_Globalization_Unicode_Level2Map,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP45mscorlib_Mono_Globalization_Unicode_Level2Map,__ZL92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP45mscorlib_Mono_Globalization_Unicode_Level2Map,__Z111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi,__Z123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi,__Z121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi,__Z110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array42mscorlib_System_Collections_Hashtable_Slot,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array42mscorlib_System_Collections_Hashtable_Slot,__Z89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array42mscorlib_System_Collections_Hashtable_Slot,__Z100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi,__Z112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi,__Z110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi,__Z99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayi,__Z110mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi,__Z122mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi,__Z120mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi,__Z109mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayi,__Z117mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi,__Z129mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi,__Z127mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi,__Z116mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayi,__ZL95mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_Arrayi,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP47mscorlib_System_Diagnostics_DebuggableAttribute,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP47mscorlib_System_Diagnostics_DebuggableAttribute,__ZL94mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP47mscorlib_System_Diagnostics_DebuggableAttribute,__Z110mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi
  ,__Z122mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi,__Z120mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi,__Z109mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayi,__ZL100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_Arrayi,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_Arrayi,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL102mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_Arrayi,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL101mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL86mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_Arrayi,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP38mscorlib_System_Diagnostics_StackFrame,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP38mscorlib_System_Diagnostics_StackFrame,__ZL85mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP38mscorlib_System_Diagnostics_StackFrame,__Z92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayi,__ZL86mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_CalendarP21mscorlib_System_Arrayi,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP38mscorlib_System_Globalization_Calendar,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP38mscorlib_System_Globalization_Calendar,__ZL85mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP38mscorlib_System_Globalization_Calendar,__Z97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi,__Z109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi,__Z107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi
  ,__Z96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi,__Z112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi,__Z110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi,__Z99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi,__Z105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi,__Z103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayi,__ZL96mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_Arrayi,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL95mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_Arrayi,__ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_Arrayi,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP45mscorlib_System_Reflection_Emit_MethodBuilder,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP45mscorlib_System_Reflection_Emit_MethodBuilder,__ZL92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP45mscorlib_System_Reflection_Emit_MethodBuilder,__ZL98mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_Arrayi
  ,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL97mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL95mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_Arrayi,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP47mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP47mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL94mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP47mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_Arrayi,__ZL104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP44mscorlib_System_Reflection_Emit_FieldBuilder,__ZL102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP44mscorlib_System_Reflection_Emit_FieldBuilder,__ZL91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP44mscorlib_System_Reflection_Emit_FieldBuilder,__ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodBase,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodBase,__ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP37mscorlib_System_Reflection_MethodBase,__ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_Arrayi,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL105mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_Arrayi,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL104mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_Arrayi,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_Arrayi,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute
  ,__ZL103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute,__ZL101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_Arrayi,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL103mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_Arrayi,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL102mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL103mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_Arrayi,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL102mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL112mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_Arrayi,__ZL124mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL111mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_Arrayi,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_Arrayi,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyNameAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyNameAttribute,__ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyKeyNameAttribute,__Z92mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayi,__ZL99mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_Arrayi
  ,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyProductAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyProductAttribute,__ZL98mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP51mscorlib_System_Reflection_AssemblyProductAttribute,__ZL97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_Arrayi,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP49mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_Arrayi,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTrademarkAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTrademarkAttribute,__ZL100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTrademarkAttribute,__Z87mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi,__Z99mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi,__Z86mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi,__Z105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi,__Z103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi,__Z102mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayi,__Z86mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi,__Z98mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi,__Z96mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi
  ,__Z85mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayi,__Z91mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi,__Z103mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi,__Z101mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayi,__Z95mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi,__Z107mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi,__Z105mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi,__Z94mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayi,__Z80mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi,__Z79mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayi,__Z94mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi,__Z106mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi,__Z104mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayi,__Z93mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi,__Z105mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi,__Z103mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayi,__Z89mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi,__Z101mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi,__Z99mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi,__Z88mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayi,__ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_Arrayi,__ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_Arrayi
  ,__ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_SatelliteContractVersionAttribute,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_SatelliteContractVersionAttribute,__ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Resources_SatelliteContractVersionAttribute,__Z111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi,__Z123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi,__Z121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi,__Z110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayi,__ZL120mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_Arrayi,__ZL132mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL130mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL119mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL115mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_Arrayi,__ZL127mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__ZL125mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__ZL114mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__Z97mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi,__Z109mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi,__Z107mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi,__Z96mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayi,__ZL112mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_Arrayi,__ZL124mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__ZL111mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__Z96mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi,__Z108mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi,__Z106mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi,__Z95mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayi,__Z104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi,__Z116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi,__Z114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi
  ,__Z103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayi,__ZL121mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_Arrayi,__ZL133mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL131mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL120mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_Arrayi,__ZL123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__ZL121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__ZL110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__Z106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi,__Z118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi,__Z116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi,__Z105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayi,__ZL116mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_Arrayi,__ZL128mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__ZL126mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__ZL115mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__Z104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi,__Z116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi,__Z114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi,__Z103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayi,__ZL110mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_Arrayi,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL109mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL108mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_Arrayi,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL107mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL115mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_Arrayi
  ,__ZL127mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL125mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL114mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_Arrayi,__ZL123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__ZL121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__ZL110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__Z101mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi,__Z113mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi,__Z111mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayi,__ZL104mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_Arrayi,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL103mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL106mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_Arrayi,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__ZL105mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__Z102mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayi,__Z114mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayh,__Z112mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayh,__Z101mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayh,__ZL103mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_Arrayi,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL102mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL107mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_Arrayi,__ZL119mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP22mscorlib_System_Object,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP22mscorlib_System_Object
  ,__ZL106mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP22mscorlib_System_Object,__Z100mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi,__Z112mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi,__Z110mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi,__Z99mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayi,__Z119mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi,__Z131mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi,__Z129mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi,__Z118mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayi,__Z115mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi,__Z127mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi,__Z125mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi,__Z114mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayi,__Z112mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi,__Z124mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi,__Z122mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi,__Z111mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayi,__Z108mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi,__Z120mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi,__Z118mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi,__Z107mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayi,__Z98mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi,__Z110mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi,__Z108mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayi,__ZL102mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_Arrayi,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL101mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_Arrayi
  ,__ZL123mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL121mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL110mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL98mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_Arrayi,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP50mscorlib_System_Security_UnverifiableCodeAttribute,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP50mscorlib_System_Security_UnverifiableCodeAttribute,__ZL97mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP50mscorlib_System_Security_UnverifiableCodeAttribute,__Z85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi,__Z97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi,__Z95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi,__Z84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayi,__Z80mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi,__Z79mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayi,__Z78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi,__Z88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi,__Z77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayi,__Z76mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi,__Z88mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi,__Z86mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi,__Z75mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayi,__Z73mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi,__Z85mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi,__Z83mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi,__Z72mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayi,__ZL78mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_FlagsAttributeP21mscorlib_System_Arrayi,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP30mscorlib_System_FlagsAttribute,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP30mscorlib_System_FlagsAttribute
  ,__ZL77mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP30mscorlib_System_FlagsAttribute,__Z82mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi,__Z94mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi,__Z81mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayi,__ZL72mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_MonoTypeP21mscorlib_System_Arrayi,__ZL84mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP24mscorlib_System_MonoType,__ZL82mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP24mscorlib_System_MonoType,__ZL71mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP24mscorlib_System_MonoType,__ZL86mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_NonSerializedAttributeP21mscorlib_System_Arrayi,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP38mscorlib_System_NonSerializedAttribute,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP38mscorlib_System_NonSerializedAttribute,__ZL85mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP38mscorlib_System_NonSerializedAttribute,__Z74mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi,__Z86mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi,__Z84mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi,__Z73mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_PlatformIDP21mscorlib_System_Arrayi,__ZL85mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP37mscorlib_System_ThreadStaticAttribute,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP37mscorlib_System_ThreadStaticAttribute,__ZL84mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP37mscorlib_System_ThreadStaticAttribute,__Z72mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi,__Z84mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi,__Z82mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi,__Z71mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_TypeCodeP21mscorlib_System_Arrayi,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj,__ZNSt3__111__stdoutbufIwE8overflowEj,__ZNSt3__110__stdinbufIwE9pbackfailEj,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE8overflowEj,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi
  ,__ZNSt3__111__stdoutbufIcE8overflowEi,__ZNSt3__110__stdinbufIcE9pbackfailEi,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE8overflowEi,__ZNKSt3__15ctypeIcE10do_toupperEc,__ZNKSt3__15ctypeIcE10do_tolowerEc,__ZNKSt3__15ctypeIcE8do_widenEc,__ZNKSt3__15ctypeIwE10do_toupperEw,__ZNKSt3__15ctypeIwE10do_tolowerEw,__ZNKSt3__15ctypeIwE8do_widenEc,__ZNKSt3__16locale9use_facetERNS0_2idE,__ZN6il2cpp2vm5Array3NewEP8TypeInfoj,__ZN6il2cpp2vm5Class10GetMethodsEPK8TypeInfoPPv,__ZN6il2cpp2vm10Reflection15GetMethodObjectEP10MethodInfoP8TypeInfo,__ZN6il2cpp2vm5Array11NewSpecificEP8TypeInfoj,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_,__ZN6il2cpp2vm5Class13GetPropertiesEPK8TypeInfoPPv,__ZN6il2cpp2vm10Reflection17GetPropertyObjectEP8TypeInfoP12PropertyInfo,__ZNSt3__113unordered_mapIP12PropertyInfoP24Il2CppReflectionPropertyN6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashENS8_25Il2CppPropertyInfoCompareENS5_2gc9AllocatorINS_4pairIKS2_S4_EEEEEixERSE_,__ZN6il2cpp2vm5Image21FromTypeNameParseInfoEP11Il2CppImageRKNS0_17TypeNameParseInfoE,__ZN6il2cpp2vm5Class7GetTypeEP8TypeInfoRKNS0_17TypeNameParseInfoE,__ZNSt3__1lsINS_11char_traitsIcEEEERNS_13basic_ostreamIcT_EES6_PKc,__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEi,__ZN6il2cpp2vm5Image22GetGenericInstanceTypeEP8TypeInfoRKNSt3__16vectorIPK10Il2CppTypeNS4_9allocatorIS8_EEEE,__ZN6il2cpp6icalls8mscorlib6System13GlobalizationL20culture_name_locatorEPKvS5_,__ZN6il2cpp6icalls8mscorlib6System13GlobalizationL20culture_lcid_locatorEPKvS5_,__ZN6il2cpp2os4File13GetAttributesENSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEERNS1_14FileAttributesE,__ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPFvvENS_4lessIS6_EENS4_INS_4pairIKS6_S8_EEEEEixERSC_,__ZN6il2cpp6icalls8mscorlib6System9AppDomain12createDomainEP12Il2CppStringP30mscorlib_System_AppDomainSetup,__ZN6il2cpp6icalls8mscorlib6System9AppDomain13GetAssembliesEP15Il2CppAppDomainb,__ZN6il2cpp6icalls8mscorlib6System9AppDomain7GetDataEP15Il2CppAppDomainP12Il2CppString
  ,__ZN6il2cpp6icalls8mscorlib6System5Array9GetLengthEP11Il2CppArrayi,__ZN6il2cpp6icalls8mscorlib6System5Array13GetLowerBoundEP11Il2CppArrayi,__ZN6il2cpp6icalls8mscorlib6System5Array8GetValueEP11Il2CppArrayS5_,__ZN6il2cpp6icalls8mscorlib6System5Array12GetValueImplEP11Il2CppArrayi,__ZN6il2cpp6icalls8mscorlib6System6Buffer15GetByteInternalEP11Il2CppArrayi,__ZN6il2cpp6icalls8mscorlib6System7Convert24InternalFromBase64StringEP12Il2CppStringb,__ZN6il2cpp6icalls8mscorlib6System7Decimal13decimal2Int64EP19il2cpp_decimal_reprPx,__ZN6il2cpp6icalls8mscorlib6System7Decimal14decimal2UInt64EP19il2cpp_decimal_reprPy,__ZN6il2cpp6icalls8mscorlib6System7Decimal14decimalCompareEP19il2cpp_decimal_reprS5_,__ZN6il2cpp6icalls8mscorlib6System7Decimal11decimalIncrEP19il2cpp_decimal_reprS5_,__ZN6il2cpp6icalls8mscorlib6System7Decimal11decimalMultEP19il2cpp_decimal_reprS5_,__ZN6il2cpp6icalls8mscorlib6System7Decimal18decimalSetExponentEP19il2cpp_decimal_repri,__ZN6il2cpp6icalls8mscorlib6System6Double9ParseImplEPcPd,__ZN6il2cpp6icalls8mscorlib6System4Enum16compare_value_toEP12Il2CppObjectS5_,__ZN6il2cpp6icalls8mscorlib6System4Enum8ToObjectEP20Il2CppReflectionTypeP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo35construct_internal_locale_from_lcidEP17Il2CppCultureInfoi,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo35construct_internal_locale_from_nameEP17Il2CppCultureInfoP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo44construct_internal_locale_from_specific_nameEPvP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo24internal_is_lcid_neutralEiPb,__ZN6il2cpp6icalls8mscorlib6System13Globalization10RegionInfo35construct_internal_region_from_nameEPvP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO5CloseE12Il2CppIntPtrPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO20CreateDirectoryICallEP12Il2CppStringPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO10CreatePipeEP12Il2CppIntPtrS6_,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO15DeleteFileICallEP12Il2CppStringPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO5FlushE12Il2CppIntPtrPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO22GetFileAttributesICallEP12Il2CppStringPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11GetFileTypeE12Il2CppIntPtrPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO9GetLengthE12Il2CppIntPtrPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO15RemoveDirectoryEP12Il2CppStringPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO24SetCurrentDirectoryICallEP12Il2CppStringPi
  ,__ZN6il2cpp6icalls8mscorlib6System15MonoCustomAttrs17IsDefinedInternalEP12Il2CppObjectP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType30GetCorrespondingInflatedMethodEP24Il2CppReflectionMonoTypeS5_,__ZN6il2cpp6icalls8mscorlib6System8MonoType14GetNestedTypesEP24Il2CppReflectionMonoTypei,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly13get_code_baseEP35mscorlib_System_Reflection_Assemblyb,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly8GetTypesEP35mscorlib_System_Reflection_Assemblyb,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly22load_with_partial_nameEP12Il2CppStringP40mscorlib_System_Security_Policy_Evidence,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly8LoadFromEP12Il2CppStringb,__ZN6il2cpp6icalls8mscorlib6System10Reflection12AssemblyName9ParseNameEP18Il2CppAssemblyNameP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit15AssemblyBuilder17InternalAddModuleEP47mscorlib_System_Reflection_Emit_AssemblyBuilderP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13MethodBuilder17MakeGenericMethodEP22Il2CppReflectionMethodP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder20create_modified_typeEP27Il2CppReflectionTypeBuilderP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder8getTokenEP29Il2CppReflectionModuleBuilderP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder10getUSIndexEP29Il2CppReflectionModuleBuilderP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder20create_runtime_classEP27Il2CppReflectionTypeBuilderS7_,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder14get_event_infoEP27Il2CppReflectionTypeBuilderP28Il2CppReflectionEventBuilder,__ZN6il2cpp6icalls8mscorlib6System10Reflection9FieldInfo16GetTypeModifiersEP21Il2CppReflectionFieldb,__ZN6il2cpp6icalls8mscorlib6System10Reflection9FieldInfo25internal_from_handle_typeE12Il2CppIntPtrS5_,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MethodBase31GetMethodFromHandleInternalTypeE12Il2CppIntPtrS5_,__ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField13GetParentTypeEP21Il2CppReflectionFieldb,__ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField16GetValueInternalEP21Il2CppReflectionFieldP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod22MakeGenericMethod_implEP22Il2CppReflectionMethodP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System10Reflection14MonoMethodInfo18get_parameter_infoE12Il2CppIntPtrP22Il2CppReflectionMethod,__ZN6il2cpp6icalls8mscorlib6System10Reflection16MonoPropertyInfo16GetTypeModifiersEPvb,__ZN6il2cpp6icalls8mscorlib6System10Reflection13ParameterInfo16GetTypeModifiersEPvb,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal6GetCCWEP12Il2CppObjectP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal37GetDelegateForFunctionPointerInternalE12Il2CppIntPtrP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal8OffsetOfEP20Il2CppReflectionTypeP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal83PtrToStringAnsi_mscorlib_System_String_mscorlib_System_IntPtr_mscorlib_System_Int32E12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal82PtrToStringUni_mscorlib_System_String_mscorlib_System_IntPtr_mscorlib_System_Int32E12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14PtrToStructureE12Il2CppIntPtrP20Il2CppReflectionType
  ,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal8ReadByteE12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal9ReadInt16E12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal9ReadInt32E12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal9ReadInt64E12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10ReadIntPtrE12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal16ReAllocCoTaskMemE12Il2CppIntPtri,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14ReAllocHGlobalE12Il2CppIntPtrS6_,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal30UnsafeAddrOfPinnedArrayElementEP11Il2CppArrayi,__ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting7Proxies9RealProxy27InternalGetTransparentProxyEP12Il2CppObjectP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting16RemotingServices16GetVirtualMethodEP20Il2CppReflectionTypeP22Il2CppReflectionMethod,__ZN6il2cpp6icalls8mscorlib6System8Security12Cryptography24RNGCryptoServiceProvider11RngGetBytesE12Il2CppIntPtrP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal16WindowsPrincipal17IsMemberOfGroupIdE12Il2CppIntPtrS6_,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal16WindowsPrincipal19IsMemberOfGroupNameE12Il2CppIntPtrP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked3AddEPii,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked15ExchangePointerEPPvS5_,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked8ExchangeEPii,__ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor17Monitor_try_enterEP12Il2CppObjecti,__ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor12Monitor_waitEP12Il2CppObjecti,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread15Thread_internalEP12Il2CppThreadP14Il2CppDelegate,__ZN6il2cpp6icalls8mscorlib6System9Threading10ThreadPool13SetMaxThreadsEii,__ZN6il2cpp6icalls8mscorlib6System9Threading10ThreadPool13SetMinThreadsEii,__ZN6il2cpp6icalls8mscorlib6System4Type14EqualsInternalEP20Il2CppReflectionTypeS5_,__ZN6il2cpp6icalls8mscorlib6System4Type16IsInstanceOfTypeEP20Il2CppReflectionTypeP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System4Type15make_array_typeEP20Il2CppReflectionTypei,__ZN6il2cpp6icalls8mscorlib6System4Type15MakeGenericTypeEP20Il2CppReflectionTypeP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System4Type23type_is_assignable_fromEP20Il2CppReflectionTypeS5_,__ZN6il2cpp6icalls8mscorlib6System9ValueType19InternalGetHashCodeEP12Il2CppObjectPP11Il2CppArray,__ZN6il2cpp2vm9Exception30GetTypeInitializationExceptionEPKcP15Il2CppException,__ZN6il2cpp2vm6Object15AllocatePtrFreeEjP8TypeInfo,__ZN6il2cpp2os16ThreadLocalValue8GetValueEPPv
  ,__Z21il2cpp_gc_alloc_fixedjPv,__ZNSt3__13mapIP12Il2CppThreadPNS_6vectorI20Il2CppStackFrameInfoNS_9allocatorIS4_EEEENS_4lessIS2_EENS5_INS_4pairIKS2_S8_EEEEEixERSC_,__ZNSt3__1lsIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_13basic_ostreamIT_T0_EES9_RKNS_12basic_stringIS6_S7_T1_EE,_png_user_version_check,_png_malloc_warn,__ZN12_GLOBAL__N_120createParticleSystemEjb,__ZN12_GLOBAL__N_119createParticleFluidEjb,__ZN5physx2Sc32DefaultClothInterCollisionFilterEPvS1_,__ZN12_GLOBAL__N_116clothSizeGreaterIN5physx5cloth8SwSolver22CpuClothSimulationTaskEEEbRKT_S7_,__Z43getPxVehicleWheelsSimData_WheelShapeMappingPKN5physx22PxVehicleWheelsSimDataEj,__ZN15EditorExtension7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN16LevelGameManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN11GameManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN17GlobalGameManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6assignEPKc,__ZN5Unity10GameObject7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN5Unity9Component7PRODUCEE10MemLabelId18ObjectCreationMode,__ZNSt3__13mapIiNS_3setIP11GameManagerNS_4lessIS3_EENS_9allocatorIS3_EEEENS4_IiEENS6_INS_4pairIKiS8_EEEEEixERSB_,__ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiNS_4lessIS6_EENS4_INS_4pairIKS6_iEEEEEixERSA_,__ZN11NamedObject7PRODUCEE10MemLabelId18ObjectCreationMode,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEaSERKS6_,__ZN10TagManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN14SafeBinaryRead12IsOldVersionEi,__Z14SortGUIByDepthP10GUIElementS0_,__ZNK5Unity10GameObject37QueryComponentExactTypeImplementationEi,__ZN8GUILayer7PRODUCEE10MemLabelId18ObjectCreationMode,__Z25IsObjectWithinShadowRangeRK14ShadowCullDataRK4AABB,__ZN12ScriptMapper10FindShaderERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__Z26CombineDepthNormalsTextureRK17RenderLoopContextR13dynamic_arrayI16RenderObjectDataLj4EE,__ZN13RenderTexture17SetGlobalPropertyERKN9ShaderLab16FastPropertyNameE
  ,__ZNK9ShaderLab9IntShader14GetRenderQueueEi,__ZN10Matrix4x4f12SetTranslateERK8Vector3f,__ZN10Matrix4x4fmLERKS_,__ZN6Camera7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN10FlareLayer7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN16GraphicsSettings7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN11HaloManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN5Light7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN11LightProbes7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN14RenderSettings7PRODUCEE10MemLabelId18ObjectCreationMode,__Z24IntersectAABBFrustumFullRK4AABBPK5Plane,__Z20InvertMatrix4x4_FullPKfPf,__ZN10Matrix4x4f8SetScaleERK8Vector3f,__ZN5Unity5Scene14RemoveRendererEi,__ZN12WWWDelayCall14MatchForCancelEPvS0_,__ZN4Mesh24QueryGpuSkinSourceBufferEi,__ZN4Mesh7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN10MeshFilter7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN12MeshRenderer7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN18UnityPropertySheetaSERKS_,__ZN9Behaviour7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN18DelayedCallManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZL15CloneObjectImplP6ObjectR10vector_mapIiiNSt3__14lessIiEE13stl_allocatorINS2_4pairIiiEEL18MemLabelIdentifier90ELi16EEE,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc,__ZN11MonoManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN7Cubemap7PRODUCEE10MemLabelId18ObjectCreationMode,__Z23ConvertImageToPNGBufferRK14ImageReferenceR13dynamic_arrayIhLj1EE,__ZN16LightmapSettings7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN15QualitySettings7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN11PlayerPrefs6GetIntERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEi
  ,__ZN14SafeBinaryRead23IsVersionSmallerOrEqualEi,__ZN8Renderer7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN13RenderTexture7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN7Texture7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN9Texture2D7PRODUCEE10MemLabelId18ObjectCreationMode,__Z29GetRowBytesFromWidthAndFormati13TextureFormat,__ZN9Texture3D7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN9Transform7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN7Striper4InitER13STRIPERCREATE,__ZN7Striper7ComputeER13STRIPERRESULT,__ZNK15GUIEventManager15GetEventAtIndexEi,__ZN5IMGUIL14SortTwoWindowsEPKNS_9GUIWindowES2_,__ZN12InputManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN8UnityStraSINSt3__19allocatorIcEEEERS_RKNS1_12basic_stringIcNS1_11char_traitsIcEET_EE,__ZN11TimeManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN11AssetBundle7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN17PersistentManager20GetSerializedClassIDEi,__ZN13BuildSettings7PRODUCEE10MemLabelId18ObjectCreationMode,__Z23GetFolderContentsAtPathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_3setIS5_NS_4lessIS5_EENS3_IS5_EEEE,__Z18ReadStringFromFilePNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEERKNS0_IcS2_NS_9allocatorIcEEEE,__ZNSt3__13mapIi10vector_setIiNS_4lessIiEENS_9allocatorIiEEES3_NS4_INS_4pairIKiS6_EEEEEixERS8_,__ZN17MonoScriptManager17FindRuntimeScriptEP14ScriptingClass,__ZN17MonoScriptManager17FindRuntimeScriptERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN5Unity10GameObject17GetComponentIndexEPNS_9ComponentE,__ZN10TagManager11StringToTagERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN16ScriptingManager23ClassIDToScriptingClassEi,__Z14GetProfileTimey,__Z15CreatePrimitiveNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi,__ZN11PreloadData7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN17PersistentManager31HasMemoryOrCachedSerializedFileERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE
  ,__ZN14PlayerSettings7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN15ResourceManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN13dynamic_arrayI20SerializationCommandLj4EEaSERKS1_,__Z30scripting_class_is_subclass_ofP14ScriptingClassS0_,__ZN9Scripting34GetScriptingArrayObjectElementImplEP14ScriptingArrayi,__ZN13MonoBehaviour7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN10MonoScript7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN16ScriptingManager18GetMonoScriptCacheEj,__ZNSt3__13mapIPKc21ScriptingMethodIl2Cpp14CStringCompare13stl_allocatorINS_4pairIS2_S3_EEL18MemLabelIdentifier90ELi16EEEixERKS2_,__ZN14MessageHandler15MessageIDToNameEi,__ZN14MessageHandler20MessageIDToParameterEi,__Z37scripting_method_get_nth_argumenttype21ScriptingMethodIl2Cppi,__Z29scripting_class_has_attributeP14ScriptingClassS0_,__ZN16ScriptingManager24ClassIDForScriptingClassEP14ScriptingClass,__ZN9TextAsset7PRODUCEE10MemLabelId18ObjectCreationMode,__Z20SortItemByInstanceIDRKN18AwakeFromLoadQueue4ItemES2_,__ZL53SortBehaviourItemByExecutionOrderAndReverseInstanceIDRKN18AwakeFromLoadQueue4ItemES2_,__ZN17PersistentManager26GetStreamNameSpaceInternalEi,__ZN17PersistentManager18ReadObjectThreadedEi,__Z7StrICmpPKcS0_,__ZNSt3__13mapIiN14SerializedFile4TypeENS_4lessIiEENS_9allocatorINS_4pairIKiS2_EEEEEixERS7_,__Z29StdTemplateConversionFunctionIfdEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIdfEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIifEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIyyEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIyxEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIyiEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIyjEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIytEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIysEbPvR14SafeBinaryRead
  ,__Z29StdTemplateConversionFunctionIyhEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIyaEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIybEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIiyEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIixEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIiiEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIijEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIitEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIisEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIihEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIiaEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIibEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjyEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjxEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjiEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjjEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjtEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjsEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjhEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjaEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIjbEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionItyEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionItxEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionItiEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionItjEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIttEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionItsEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIthEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionItaEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionItbEbPvR14SafeBinaryRead
  ,__Z29StdTemplateConversionFunctionIsyEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIsxEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIsiEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIsjEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIstEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIssEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIshEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIsaEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIsbEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhyEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhxEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhiEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhjEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhtEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhsEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhhEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhaEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIhbEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIayEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIaxEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIaiEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIajEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIatEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIasEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIahEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIaaEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIabEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIbyEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIbxEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIbiEbPvR14SafeBinaryRead
  ,__Z29StdTemplateConversionFunctionIbjEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIbtEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIbsEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIbhEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIbaEbPvR14SafeBinaryRead,__Z29StdTemplateConversionFunctionIbbEbPvR14SafeBinaryRead,__ZN5Unity8Material7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN6Shader7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN15NameToObjectMapI6ShaderNSt3__13mapI4PPtrIS0_E8UnityStrNS1_4lessIS4_EENS1_9allocatorINS1_4pairIKS4_S5_EEEEEENS1_8multimapIS5_S4_NS6_IS5_EENS8_INS9_IKS5_S4_EEEEEEE4FindERKNS1_12basic_stringIcNS1_11char_traitsIcEENS8_IcEEEE,__ZN12ScriptMapper7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN15FileSystemEntry6CopyToERS_,__ZN13FileEntryDataaSERKS_,__ZN15FileSystemEntry6DeleteEb,_flock__wrapper,__ZN9ShaderLab19ParseQueueAndOffsetERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERi,__ZN20GpuProgramParametersaSERKS_,__Z20IsVectorBuiltinParamPKcPi,__ZNSt3__13mapIiiNS_4lessIiEENS_9allocatorINS_4pairIKiiEEEEEixERS5_,__ZN11CustomArray8CollapseEPv,__ZN7Striper16ConnectAllStripsER13STRIPERRESULT,__Z36CreateScriptingArrayFromUnityObjectsINSt3__16vectorIP6ObjectNS0_9allocatorIS3_EEEEEP14ScriptingArrayRKT_i,__ZN10TagManager13StringToLayerERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__Z21Resources_CUSTOM_LoadP15ScriptingStringP15ScriptingObject,__Z37GUILayer_CUSTOM_INTERNAL_CALL_HitTestP15ScriptingObjectRK8Vector3f,__Z32GUIStyle_CUSTOM_GetStyleStatePtrP15ScriptingObjecti,__Z32GUIStyle_CUSTOM_GetRectOffsetPtrP15ScriptingObjecti,__Z37Matrix4x4_CUSTOM_INTERNAL_CALL_InvertRK10Matrix4x4fPS_,__Z45Bounds_CUSTOM_INTERNAL_CALL_Internal_ContainsRK4AABBRK8Vector3f,__Z40MonoBehaviour_CUSTOM_StartCoroutine_AutoP15ScriptingObjectS0_,__ZN12InputManager9GetButtonERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE
  ,__ZN12InputManager13GetButtonDownERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__Z30GameObject_CUSTOM_GetComponentP15ScriptingObjectS0_,__Z28Random_CUSTOM_RandomRangeIntii,__ZN19CharacterController7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN8Collider7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN12MeshCollider7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN14PhysicsManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZNK5physx22PxVehicleWheelsDynData11getUserDataEj,__ZN9Rigidbody7PRODUCEE10MemLabelId18ObjectCreationMode,__Z45CharacterController_CUSTOM_INTERNAL_CALL_MoveP15ScriptingObjectRK8Vector3f,__ZN14AudioBehaviour7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN10SampleClip7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN9AudioClip7PRODUCEE10MemLabelId18ObjectCreationMode,__ZL44UnityAudioEffect_InternalSetPositionCallbackP14FMOD_DSP_STATEj,__ZN13AudioListener7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN4FMOD3DSP11getUserDataEPPv,__ZN4FMOD3DSP9getBypassEPb,__Z15FMOD_FILE_ClosePvS_,__ZN4FMOD6System11setCallbackEPF11FMOD_RESULTP11FMOD_SYSTEM24FMOD_SYSTEM_CALLBACKTYPEPvS5_E,__ZN4FMOD6System20set3DRolloffCallbackEPFfP12FMOD_CHANNELfE,__ZN4FMOD6System21getMasterChannelGroupEPPNS_12ChannelGroupE,__ZN4FMOD12ChannelGroup8addGroupEPS0_,__ZN4FMOD3DSP9setBypassEb,__ZN9AudioClip8WWWCloseEPvS0_,__ZN12AudioManager7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN4FMOD7Channel7setModeEj,__ZN11AudioSource16UpdateParametersE12SoundChannel,_JS_Sound_Create_Channel__wrapper,__ZN9Animation7PRODUCEE10MemLabelId18ObjectCreationMode,__Z10BeginsWithPKcS0_
  ,__Z15GetChannelIndexRK14BlendShapeDataPKc,__ZNK5Unity10GameObject28QueryComponentImplementationEi,__ZN7mecanim8skeleton16SkeletonFindNodeEPKNS0_8SkeletonEj,__ZN7mecanim20CreateValueArrayMaskEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE,__ZN7mecanim14FindValueIndexEPKNS_18ValueArrayConstantEj,__ZN6Motion7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN13AnimationClip7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN8Animator7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN8Animator14FireBehavioursEN7mecanim12statemachine19StateMachineMessageE,__ZNK8Animator26GetGlobalSpaceSkeletonPoseEPPN7mecanim8skeleton12SkeletonPoseE,__ZN25RuntimeAnimatorController7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN18AnimatorController7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN7mecanim16CreateValueArrayEPKNS_18ValueArrayConstantERNS_6memory9AllocatorE,__ZN7mecanim6memory9Allocator9ConstructINS_9animation12MotionOutputEEEPT_j,__ZN7mecanim9animationL25MuscleIndexIdSortFunctionENS0_13MuscleIndexIdES1_,__ZN9Animation8GetStateERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__Z25Animation_CUSTOM_GetStateP15ScriptingObjectP15ScriptingString,__ZN5Unity8Material10GetTextureEN9ShaderLab16FastPropertyNameE,__ZL16CreateImposterRTii,__ZN6Shader13GetDependencyERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN7Terrain7PRODUCEE10MemLabelId18ObjectCreationMode,__ZNK11TerrainData7HasUserEPN5Unity10GameObjectE,__ZN5Unity8Material11HasPropertyEN9ShaderLab16FastPropertyNameE,__ZN21ImposterRenderTexture15UpdateImpostersERK6Camera,__ZN13dynamic_arrayIiLj4EEaSERKS0_,__ZNSt3__13mapIN20TextRenderingPrivate7FontRefENS1_6OSFontENS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S3_EEEEEixERS8_,__ZNSt3__13mapIN20TextRenderingPrivate7FontRefEP11FT_FaceRec_NS_4lessIS2_EENS_9allocatorINS_4pairIKS2_S4_EEEEEixERS9_,_FT_Get_Char_Index,__ZN20TextRenderingPrivate4Font19HasCharacterDynamicEj,__ZN20TextRenderingPrivate4Font7PRODUCEE10MemLabelId18ObjectCreationMode
  ,__Z6StrCmpPKcS0_,__ZN20TextRenderingPrivate8TextMesh7PRODUCEE10MemLabelId18ObjectCreationMode,_ft_bitmap_glyph_init,_ft_bitmap_glyph_copy,_ft_outline_glyph_init,_ft_outline_glyph_copy,_ft_outline_glyph_prepare,_ft_raccess_sort_ref_by_id,_cff_get_name_index,_cff_ps_get_font_info,_cff_get_cmap_info,_cff_get_is_cid,_cff_get_interface,_cff_size_request,_cff_size_select,_cff_cmap_encoding_char_index,_cff_cmap_encoding_char_next,_cff_cmap_unicode_char_index,_cff_cmap_unicode_char_next,_cff_sid_to_glyph_name,_ps_unicodes_char_index,_ps_unicodes_char_next,_compare_uni_maps,_psnames_get_service,_tt_name_entry_ascii_from_utf16,_tt_name_entry_ascii_from_other,_get_sfnt_table,_sfnt_get_name_index,_tt_get_cmap_info,_sfnt_get_interface
  ,_tt_face_load_head,_tt_face_load_cmap,_tt_face_load_maxp,_tt_face_load_os2,_tt_face_load_post,_tt_face_load_name,_tt_face_load_hdmx_stub,_tt_face_load_kern,_tt_face_load_gasp,_tt_face_load_pclt,_tt_face_load_bhed,_tt_face_load_sbit_stub,_tt_face_free_charmap_stub,_tt_face_load_font_dir,_tt_face_load_eblc,_tt_cmap_init,_tt_cmap0_char_index,_tt_cmap0_char_next,_tt_cmap0_validate,_tt_cmap0_get_info,_tt_cmap2_char_index,_tt_cmap2_char_next,_tt_cmap2_validate,_tt_cmap2_get_info,_tt_cmap4_init,_tt_cmap4_char_index,_tt_cmap4_char_next,_tt_cmap4_validate,_tt_cmap4_get_info,_tt_cmap6_char_index
  ,_tt_cmap6_char_next,_tt_cmap6_validate,_tt_cmap6_get_info,_tt_cmap8_char_index,_tt_cmap8_char_next,_tt_cmap8_validate,_tt_cmap8_get_info,_tt_cmap10_char_index,_tt_cmap10_char_next,_tt_cmap10_validate,_tt_cmap10_get_info,_tt_cmap12_init,_tt_cmap12_char_index,_tt_cmap12_char_next,_tt_cmap12_validate,_tt_cmap12_get_info,_tt_cmap13_init,_tt_cmap13_char_index,_tt_cmap13_char_next,_tt_cmap13_validate,_tt_cmap13_get_info,_tt_cmap14_init,_tt_cmap14_char_index,_tt_cmap14_char_next,_tt_cmap14_variants,_tt_cmap14_validate,_tt_cmap14_get_info,_gray_raster_new,_gray_raster_render,_gray_move_to
  ,_gray_line_to,_TT_Get_MM_Var,_tt_get_interface,_tt_size_request,_tt_size_select,_Read_CVT_Stretched,_Read_CVT,_ps_hints_close,_ft_black_new,_ft_black_render,__ZN10Matrix4x4f9TranslateERK8Vector3f,__ZN4Mesh18GetSubMeshBuffer16Ei,__ZN2UI18CompareCanvasDepthERK8ListNodeINS_6CanvasEES4_,__ZN2UI6Canvas7PRODUCEE10MemLabelId18ObjectCreationMode,__ZN2UI11CompareFuncERK8ListNodeINS_6CanvasEES4_,__ZNSt3__13mapINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE9PrefValueNS_4lessIS6_EENS4_INS_4pairIKS6_S7_EEEEEixERSB_,__Z26PlayerInitEngineNoGraphicsRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_,_JS_SystemInfo_GetDocumentURL__wrapper,__Z18ConvertUTF8toUTF16RKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER13dynamic_arrayItLj2EE,_glGetAttribLocation__wrapper,_glGetUniformLocation__wrapper,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier60ELi16EEEaSERKS6_,__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEElsEj,__ZN17PersistentManager14IsStreamLoadedERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZL10SZArrayNewP8TypeInfoj,__ZN6il2cpp2vm6Object3BoxEPK8TypeInfoPv,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo,__Z81UnityEngine_UnityEngine_Component_m_GetComponent_mscorlib_System_Object_T_gsharedP33UnityEngine_UnityEngine_ComponentPPv,__ZN6il2cpp2vm5Class16IsAssignableFromEPK8TypeInfoS4_,__Z133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNext_gsharedP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPPv
  ,__ZN16VirtFuncInvoker0I27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPv,__ZN16VirtFuncInvoker0I17VoidPointerTraitsE6InvokeEP10MethodInfoPv,__Z85System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_Add_gsharedP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP22mscorlib_System_Object,__Z92Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_YieldDefault_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Objecti,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo620,__ZN16VirtFuncInvoker0I29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPv,__ZN6il2cpp2vm6Object6IsInstEP12Il2CppObjectP8TypeInfo,__ZN21InterfaceFuncInvoker0I27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPv,__ZL10SZArrayNewP8TypeInfoj1061,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo1062,__ZN21InterfaceFuncInvoker0I17VoidPointerTraitsE6InvokeEP10MethodInfoPv,__ZN21InterfaceFuncInvoker0I28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPv,__ZN21InterfaceFuncInvoker0I29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPv,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo,__ZL10SZArrayNewP8TypeInfoj1507,__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_Default_gsharedP22mscorlib_System_ObjectPPv,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo2283,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo2285,__ZL10SZArrayNewP8TypeInfoj2609,__ZL10SZArrayNewP8TypeInfoj2873,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo2886,__ZL10SZArrayNewP8TypeInfoj3329,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo3831,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo3833,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo4482,__ZL10SZArrayNewP8TypeInfoj4491,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo4494,__ZN16VirtFuncInvoker0I28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPv,__ZN16VirtFuncInvoker0I39mscorlib_System_RuntimeTypeHandleTraitsE6InvokeEP10MethodInfoPv,__ZL10SZArrayNewP8TypeInfoj5700
  ,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo5705,__ZL10SZArrayNewP8TypeInfoj6650,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo6651,__ZL86mscorlib_System_Array_m_IndexOf_mscorlib_System_Type_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP24mscorlib_System_Type_arrP20mscorlib_System_Type,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo6662,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo7306,__ZL10SZArrayNewP8TypeInfoj7307,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo7320,__ZN16VirtFuncInvoker0I26mscorlib_System_CharTraitsE6InvokeEP10MethodInfoPv,__ZL10SZArrayNewP8TypeInfoj8569,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo8580,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo8583,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo9456,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo9479,__ZL10SZArrayNewP8TypeInfoj10825,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo10826,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo10837,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo11868,__ZL10SZArrayNewP8TypeInfoj11875,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo12068,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo12998,__ZL10SZArrayNewP8TypeInfoj13002,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo13013,__ZL9CastclassP22mscorlib_System_ObjectP8TypeInfo13880,__ZL5UnBoxP22mscorlib_System_ObjectP8TypeInfo13883,__ZL10SZArrayNewP8TypeInfoj13896,_isxdigit_l,_isdigit_l,__ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw,_emscripten_glGetUniformLocation__wrapper,_emscripten_glGetAttribLocation__wrapper,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94
  ,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94,b94];
  var FUNCTION_TABLE_iiiifii = [b95,__ZNK19TextRenderingModule38FontGetNumCharactersThatFitWithinWidthEPN13TextRendering4FontERK11UTF16Stringfij];
  var FUNCTION_TABLE_f = [b96,__Z24Time_Get_Custom_PropTimev,__Z29Time_Get_Custom_PropDeltaTimev,b96];
  var FUNCTION_TABLE_vffff = [b97,_glClearColor__wrapper,_emscripten_glRotatef__wrapper,_emscripten_glClearColor__wrapper,_emscripten_glBlendColor__wrapper,b97,b97,b97];
  var FUNCTION_TABLE_vifffi = [b98,__Z162UnityEngine_UnityEngine_Transform_m_Rotate_mscorlib_System_Void_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_UnityEngine_UnityEngine_SpaceP33UnityEngine_UnityEngine_Transformfffi,__Z24CalculateLightShadowFadeRK6CamerafffR8Vector4f,b98];
  var FUNCTION_TABLE_viiiifiiiiif = [b99,__ZN5physx12NpBatchQuery5sweepERKNS_10PxGeometryERKNS_11PxTransformERKNS_6PxVec3EftNS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPvPKNS_12PxQueryCacheEf];
  var FUNCTION_TABLE_viii = [b100,__ZN12_GLOBAL__N_1L4gANDERN5physx12PxGroupsMaskERKS1_S4_,__ZN12_GLOBAL__N_1L3gORERN5physx12PxGroupsMaskERKS1_S4_,__ZN12_GLOBAL__N_1L4gXORERN5physx12PxGroupsMaskERKS1_S4_,__ZN12_GLOBAL__N_1L5gNANDERN5physx12PxGroupsMaskERKS1_S4_,__ZN12_GLOBAL__N_1L4gNORERN5physx12PxGroupsMaskERKS1_S4_,__ZN12_GLOBAL__N_1L5gNXORERN5physx12PxGroupsMaskERKS1_S4_,__ZN12_GLOBAL__N_1L9gSWAP_ANDERN5physx12PxGroupsMaskERKS1_S4_,__ZN5physx14NpArticulation24setSolverIterationCountsEjj,__ZNK5physx14NpArticulation24getSolverIterationCountsERjS1_,__ZNK5physx19NpArticulationJoint13getSwingLimitERfS1_,__ZNK5physx19NpArticulationJoint13getTwistLimitERfS1_,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE12setActorFlagENS_11PxActorFlag4EnumEb,__ZN5physx18NpArticulationLink13setGlobalPoseERKNS_11PxTransformEb,__ZN5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE11detachShapeERNS_7PxShapeEb,__ZN5physx18NpArticulationLink17setLinearVelocityERKNS_6PxVec3Eb,__ZN5physx18NpArticulationLink18setAngularVelocityERKNS_6PxVec3Eb,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE19setRigidDynamicFlagENS_15PxRigidBodyFlag4EnumEb,__ZN5physx19NpRigidBodyTemplateINS_18PxArticulationLinkEE16setRigidBodyFlagENS_15PxRigidBodyFlag4EnumEb,__ZN5physx15NpActorTemplateINS_18PxArticulationLinkEE12setActorFlagENS_11PxActorFlag4EnumEb,__ZN5physx2Cm29ConstraintImmediateVisualizer20visualizeJointFramesERKNS_11PxTransformES4_,__ZNK5physx12NpConstraint9getActorsERPNS_12PxRigidActorES3_,__ZN5physx12NpConstraint9setActorsEPNS_12PxRigidActorES2_,__ZN5physx12NpConstraint7setFlagENS_16PxConstraintFlag4EnumEb,__ZNK5physx12NpConstraint8getForceERNS_6PxVec3ES2_,__ZNK5physx12NpConstraint13getBreakForceERfS1_,__ZN5physx12NpConstraint22setConstraintFunctionsERNS_21PxConstraintConnectorERKNS_23PxConstraintShaderTableE,__ZN5physx10NpMaterial7setFlagENS_14PxMaterialFlag4EnumEb,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE12setActorFlagENS_11PxActorFlag4EnumEb
  ,__ZN5physx14NpRigidDynamic13setGlobalPoseERKNS_11PxTransformEb,__ZN5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE11detachShapeERNS_7PxShapeEb,__ZN5physx14NpRigidDynamic17setLinearVelocityERKNS_6PxVec3Eb,__ZN5physx14NpRigidDynamic18setAngularVelocityERKNS_6PxVec3Eb,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE19setRigidDynamicFlagENS_15PxRigidBodyFlag4EnumEb,__ZN5physx19NpRigidBodyTemplateINS_14PxRigidDynamicEE16setRigidBodyFlagENS_15PxRigidBodyFlag4EnumEb,__ZN5physx14NpRigidDynamic24setSolverIterationCountsEjj,__ZNK5physx14NpRigidDynamic24getSolverIterationCountsERjS1_,__ZN5physx15NpActorTemplateINS_14PxRigidDynamicEE12setActorFlagENS_11PxActorFlag4EnumEb,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE12setActorFlagENS_11PxActorFlag4EnumEb,__ZN5physx13NpRigidStatic13setGlobalPoseERKNS_11PxTransformEb,__ZN5physx20NpRigidActorTemplateINS_13PxRigidStaticEE11detachShapeERNS_7PxShapeEb,__ZN5physx15NpActorTemplateINS_13PxRigidStaticEE12setActorFlagENS_11PxActorFlag4EnumEb,__ZN5physx7NpScene7setFlagENS_11PxSceneFlag4EnumEb,__ZN5physx7NpScene18removeArticulationERNS_14PxArticulationEb,__ZN5physx7NpScene9addActorsEPKPNS_7PxActorEj,__ZN5physx7NpScene11removeActorERNS_7PxActorEb,__ZN5physx7NpScene15removeAggregateERNS_11PxAggregateEb,__ZN5physx7NpScene22setClientBehaviorFlagsEhNS_7PxFlagsINS_20PxClientBehaviorFlag4EnumEhEE,__ZNK5physx7NpScene22getClientBehaviorFlagsEh,__ZN5physx7NpScene26setSimulationEventCallbackEPNS_25PxSimulationEventCallbackEh,__ZN5physx7NpScene21setBroadPhaseCallbackEPNS_20PxBroadPhaseCallbackEh,__ZN5physx7NpScene23forceDynamicTreeRebuildEbb,__ZN5physx7NpScene8lockReadEPKcj,__ZN5physx7NpScene9lockWriteEPKcj,__ZN5physx7NpShape12setMaterialsEPKPNS_10PxMaterialEt,__ZN5physx7NpShape7setFlagENS_11PxShapeFlag4EnumEb,__ZN5physx7NpShape9visualizeERNS_2Cm12RenderOutputERKNS_12PxRigidActorE,__ZN5physx15NpActorTemplateINS_15PxParticleFluidEE12setActorFlagENS_11PxActorFlag4EnumEb,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE
  ,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE18getProjectionPlaneERNS_6PxVec3ERf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE19setParticleBaseFlagENS_18PxParticleBaseFlag4EnumEb,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE23setParticleReadDataFlagENS_22PxParticleReadDataFlag4EnumEb,__ZN5physx15NpActorTemplateINS_16PxParticleSystemEE12setActorFlagENS_11PxActorFlag4EnumEb,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE16releaseParticlesEjRKNS_16PxStrideIteratorIKjEE,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE18getProjectionPlaneERNS_6PxVec3ERf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE19setParticleBaseFlagENS_18PxParticleBaseFlag4EnumEb,__ZN5physx16NpParticleSystem23setParticleReadDataFlagENS_22PxParticleReadDataFlag4EnumEb,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE23setParticleReadDataFlagENS_22PxParticleReadDataFlag4EnumEb,__ZN5physx15NpActorTemplateINS_7PxClothEE12setActorFlagENS_11PxActorFlag4EnumEb,__ZN5physx7NpCloth12setParticlesEPKNS_15PxClothParticleES3_,__ZN5physx7NpCloth12setClothFlagENS_11PxClothFlag4EnumEb,__ZN5physx7NpCloth16setStretchConfigENS_22PxClothFabricPhaseType4EnumERKNS_20PxClothStretchConfigE,__ZNK5physx7NpCloth16getStretchConfigENS_22PxClothFabricPhaseType4EnumE,__ZN5physx7NpCloth19setCollisionSpheresEPKNS_22PxClothCollisionSphereEj,__ZN5physx7NpCloth19addCollisionCapsuleEjj,__ZN5physx7NpCloth18setCollisionPlanesEPKNS_21PxClothCollisionPlaneEj,__ZN5physx7NpCloth21setCollisionTrianglesEPKNS_24PxClothCollisionTriangleEj,__ZN5physx7NpCloth23setSelfCollisionIndicesEPKjj,__ZN5physx7NpCloth9visualizeERNS_2Cm12RenderOutputEPNS_7NpSceneE,__ZN5physx2Sc8ActorSim19postActorFlagChangeEjj,__ZN5physx2Sc7BodySim19postActorFlagChangeEjj,__ZNK5physx2Sc8ShapeSim13getFilterInfoERjRNS_12PxFilterDataE,__ZNK5physx2Sc19ParticlePacketShape13getFilterInfoERjRNS_12PxFilterDataE,__ZNK5physx2Sc10ClothShape13getFilterInfoERjRNS_12PxFilterDataE,__ZNK5physx5cloth9SwFactory24extractMotionConstraintsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE,__ZNK5physx5cloth9SwFactory28extractSeparationConstraintsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE,__ZNK5physx5cloth9SwFactory28extractParticleAccelerationsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE,__ZNK5physx5cloth9SwFactory27extractSelfCollisionIndicesERKNS0_5ClothENS0_5RangeIjEE,__ZNK5physx5cloth9SwFactory20extractRestPositionsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE
  ,__ZThn4_NK5physx5cloth9SwFactory24extractMotionConstraintsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE,__ZThn4_NK5physx5cloth9SwFactory28extractSeparationConstraintsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE,__ZThn4_NK5physx5cloth9SwFactory28extractParticleAccelerationsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE,__ZThn4_NK5physx5cloth9SwFactory27extractSelfCollisionIndicesERKNS0_5ClothENS0_5RangeIjEE,__ZThn4_NK5physx5cloth9SwFactory20extractRestPositionsERKNS0_5ClothENS0_5RangeINS_6PxVec4EEE,__ZN5physx5cloth9ClothImplINS0_7SwClothEE19setVirtualParticlesENS0_5RangeIA4_KjEENS4_IKNS_6PxVec3EEE,__ZThn4_N5physx5cloth9ClothImplINS0_7SwClothEE19setVirtualParticlesENS0_5RangeIA4_KjEENS4_IKNS_6PxVec3EEE,__ZN5physx15PxsParticleData16removeParticlesVEjRKNS_16PxStrideIteratorIKjEE,__ZNK5physx20PxsParticleSystemSim19getSimParticleDataVERNS_28PxvParticleSystemSimDataDescEb,__ZN5physx17solveContactBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx12solve1DBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx25solveContact_BStaticBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx20solveContactPreBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx27solveContactPreBlock_StaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx14solve1D4_BlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx25solveContactConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx20solve1DConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx33solveContact_BStaticConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx29solveContactPreBlock_ConcludeEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx35solveContactPreBlock_ConcludeStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx22solve1D4Block_ConcludeEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx24solveContactCoulombBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx32solveContactCoulomb_BStaticBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx27solveContactCoulombPreBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx34solveContactCoulombPreBlock_StaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx18solveFrictionBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx26solveFriction_BStaticBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx28solveFrictionCoulombPreBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx35solveFrictionCoulombPreBlock_StaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx32solveContactCoulombConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE
  ,__ZN5physx40solveContactCoulomb_BStaticConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx36solveContactCoulombPreBlock_ConcludeEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx42solveContactCoulombPreBlock_ConcludeStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx37solveFrictionCoulombPreBlock_ConcludeEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx43solveFrictionCoulombPreBlock_ConcludeStaticEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx2Sq10AABBPruner13removeObjectsEPKjj,__ZNK5physx2Sq10AABBPruner9visualizeERNS_2Cm12RenderOutputEj,__ZN5physx2Sq12BucketPruner13removeObjectsEPKjj,__ZNK5physx2Sq12BucketPruner9visualizeERNS_2Cm12RenderOutputEj,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE8requiresERNS_6PxBaseERNS_23PxProcessPxBaseCallbackE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE15exportExtraDataERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE10exportDataERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE8requiresERNS_6PxBaseERNS_23PxProcessPxBaseCallbackE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE15exportExtraDataERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE10exportDataERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE8requiresERNS_6PxBaseERNS_23PxProcessPxBaseCallbackE,__ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE15exportExtraDataERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE10exportDataERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE8requiresERNS_6PxBaseERNS_23PxProcessPxBaseCallbackE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE15exportExtraDataERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE10exportDataERNS_6PxBaseERNS_22PxSerializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE18registerReferencesERNS_6PxBaseERNS_22PxSerializationContextE,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17handleBufferFlushEPKhj,__ZThn132_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE17handleBufferFlushEPKhj,__ZN5physx7profile10DataBufferINS_6shdfnd6MutexTINS0_26WrapperReflectionAllocatorIhEEEENS0_14ScopedLockImplIS6_EEE17handleBufferFlushEPKhj,__ZN5physx9PxTaskMgr12finishBeforeERNS_6PxTaskEm,__ZN5physx9PxTaskMgr10startAfterERNS_6PxTaskEm
  ,__ZN5physx9PxTaskMgr14emitStartEventERNS_10PxBaseTaskEj,__ZN5physx9PxTaskMgr13emitStopEventERNS_10PxBaseTaskEj,__ZNK5physx2Gu16SupportLocalImplINS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu16SupportLocalImplINS0_18ConvexHullNoScaleVEE9doSupportERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu16SupportLocalImplINS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEE18doWarmStartSupportEiRNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu19SupportMapLocalImplINS0_11ConvexHullVEE14doSupportSweepERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEE18doWarmStartSupportEiRNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEE9doSupportERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu22SupportMapRelativeImplINS0_11ConvexHullVEE14doSupportSweepERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu22SupportMapRelativeImplINS0_4BoxVEE18doWarmStartSupportEiRNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu22SupportMapRelativeImplINS0_4BoxVEE9doSupportERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu22SupportMapRelativeImplINS0_4BoxVEE14doSupportSweepERKNS_6shdfnd3aos5Vec3VE,__ZNK5physx2Gu11HeightField17getTriangleNormalEj,__ZNK5physx2Gu16SupportLocalImplINS0_9TriangleVEE9doSupportERKNS_6shdfnd3aos5Vec3VE,__ZN13BaseAllocator17GetFreeBlockCountEPii,__ZN13BaseAllocator17GetUsedBlockCountEPii,__ZN12BaseRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns,__ZN11HaloManager16RenderRenderableERK11CullResultsRN9ShaderLab17ShaderPassContextE,__ZThn24_N11HaloManager16RenderRenderableERK11CullResultsRN9ShaderLab17ShaderPassContextE,__ZNK20IntermediateRenderer11GetMaterialEi,__ZN24MeshIntermediateRenderer6RenderEiRK14ChannelAssigns,__ZN24MeshIntermediateRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns,__ZN17GenericDynamicVBO12ReleaseChunkEjj,__ZN17GenericDynamicVBO9DrawChunkERK14ChannelAssignsP17VertexDeclaration,__ZNK8Renderer11GetMaterialEi,__ZN8Renderer14SetSubsetIndexEii,__ZN12MeshRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns,__ZN12MeshRenderer6RenderEiRK14ChannelAssigns
  ,__ZThn28_N12MeshRenderer6RenderEiRK14ChannelAssigns,__ZThn28_N12MeshRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns,__ZThn28_NK8Renderer11GetMaterialEi,__ZN9GfxDevice21SetWorldMatrixAndTypeERK10Matrix4x4f13TransformType,__ZN9GfxDevice21SetConstantBufferInfoEii,__ZN9GfxDevice15EndWriteIndicesEP11IndexBufferj,__ZN9GfxDevice16EndWriteVerticesEP12VertexBufferj,__ZN9GfxDevice19BeginStaticBatchingERK14ChannelAssigns16GfxPrimitiveType,__ZN9GfxDevice23ResolveDepthIntoTextureE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_,__ZN9GfxDevice21RegisterNativeTextureE9TextureIDi,__ZN9GfxDevice14ImmediateBeginE16GfxPrimitiveTypePK14ChannelAssigns,__ZN9GfxDevice14SetTextureNameE9TextureIDPKc,__ZN9GfxDevice20SetRenderSurfaceNameEP17RenderSurfaceBasePKc,__ZN9GfxDevice19SetVertexBufferNameEP12VertexBufferPKc,__ZN9GfxDevice18SetIndexBufferNameEP11IndexBufferPKc,__ZN9GfxDevice17SetGpuProgramNameEP10GpuProgramPKc,__ZN9GfxDevice27SetRandomWriteTargetTextureEi9TextureID,__ZN9GfxDevice26SetRandomWriteTargetBufferEi15ComputeBufferID,__ZN9GfxDevice29DestroyComputeConstantBuffersEjP12ObjectHandleI18ConstantBuffer_TagPvE,__ZN9GfxDevice16SetStereoBuffersE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_,__ZNK32RendererMaterialAnimationBinding12SetPPtrValueERKN11UnityEngine9Animation10BoundCurveEi,__ZNK17IAnimationBinding30CurveAttributeToSerializedPathERKN11UnityEngine9Animation10BoundCurveE,__ZNK24RendererAnimationBinding12SetPPtrValueERKN11UnityEngine9Animation10BoundCurveEi,__ZN13ScreenManager23SetIsOrientationEnabledE18EnabledOrientationb,__ZNK28MonoBehaviourPropertyBinding12SetPPtrValueERKN11UnityEngine9Animation10BoundCurveEi,__ZN25PathNamePersistentManager24PathIDToPathNameInternalEi,__ZN25PathNamePersistentManager30PathIDToFileIdentifierInternalEi,__ZN16MemoryFileSystem10ToAbsoluteEPKc,__ZNK16MemoryFileSystem12LastModifiedERK13FileEntryData,__ZNK16MemoryFileSystem12GetAssetGUIDERK13FileEntryData
  ,__ZN25MultiBlocksMemoryFileData9SetLengthEy,__ZN22LocalFileSystemHandler10ToAbsoluteEPKc,__ZNK20LocalFileSystemPosix12LastModifiedERK13FileEntryData,__ZNK17FileSystemHandler12GetAssetGUIDERK13FileEntryData,__ZN8Collider22GetPositionAndRotationERK9TransformR10Matrix4x4f,__ZN14PhysicsManager9onTriggerEPN5physx13PxTriggerPairEj,__ZN14PhysicsManager17onConstraintBreakEPN5physx16PxConstraintInfoEj,__ZN14PhysicsManager6onWakeEPPN5physx7PxActorEj,__ZN14PhysicsManager7onSleepEPPN5physx7PxActorEj,__ZThn24_N14PhysicsManager17onConstraintBreakEPN5physx16PxConstraintInfoEj,__ZThn24_N14PhysicsManager6onWakeEPPN5physx7PxActorEj,__ZThn24_N14PhysicsManager7onSleepEPPN5physx7PxActorEj,__ZThn24_N14PhysicsManager9onTriggerEPN5physx13PxTriggerPairEj,__ZN13PhysicsModule17SetRigidBodyStateER9RigidbodyRKN8IPhysics14RigidBodyStateE,__ZN13PhysicsModule17GetRigidBodyStateERK9RigidbodyPN8IPhysics14RigidBodyStateE,__ZN13PhysicsModule20GetRigidBodyVelocityERK9Rigidbody,__ZN19CollisionListener2D8PreSolveEP9b2ContactPK10b2Manifold,__ZN17b2ContactListener9PostSolveEP9b2ContactPK16b2ContactImpulse,__ZN11AudioModule14SetBypassOnDSPEPN4FMOD3DSPEb,__ZNK18AnimatorController12StringFromIDEj,__ZN16MecanimAnimation34SetGetGlobalSpaceSkeletonPoseFenceEPN5Unity9ComponentER8JobFence,__ZN20QuadTreeNodeRenderer6RenderEiRK14ChannelAssigns,__ZN14TerrainManager17Heightmap_GetSizeER9Heightmap,__ZN14TerrainManager12GetWorldAABBEP7Terrain,__ZN14TerrainManager20CollectTreeRenderersER13dynamic_arrayI9SceneNodeLj4EERS0_I4AABBLj4EE,__ZNK14TerrainManager23CollectLODGroupManagersEPPK15LODGroupManageri,__ZN26LegacyTreeInstanceRenderer6RenderEiRK14ChannelAssigns,__ZN24TreeIntermediateRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns,__ZNK26LegacyTreeInstanceRenderer11GetMaterialEi,__ZN23LODTreeInstanceRenderer6RenderEiRK14ChannelAssigns
  ,__ZNK23LODTreeInstanceRenderer11GetMaterialEi,__ZN29BillboardTreeInstanceRenderer6RenderEiRK14ChannelAssigns,__ZN29BillboardTreeInstanceRenderer14RenderMultipleERK22RenderMultipleMeshDataRK14ChannelAssigns,__ZN13GfxDeviceGLES15SetStencilStateEPK18DeviceStencilStatei,__ZN13GfxDeviceGLES21SetConstantBufferInfoEii,__ZN13GfxDeviceGLES8SetLightEiRK14GfxVertexLight,__ZN13GfxDeviceGLES15EndWriteIndicesEP11IndexBufferj,__ZN13GfxDeviceGLES16EndWriteVerticesEP12VertexBufferj,__ZN13GfxDeviceGLES19ResolveColorSurfaceE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_,__ZN13GfxDeviceGLES23ResolveDepthIntoTextureE12ObjectHandleI17RenderSurface_TagP17RenderSurfaceBaseES4_,__ZN13GfxDeviceGLES14SetTextureNameE9TextureIDPKc,__ZN13GfxDeviceGLES20SetRenderSurfaceNameEP17RenderSurfaceBasePKc,__ZN13GfxDeviceGLES19SetVertexBufferNameEP12VertexBufferPKc,__ZN13GfxDeviceGLES18SetIndexBufferNameEP11IndexBufferPKc,__ZN13GfxDeviceGLES17SetGpuProgramNameEP10GpuProgramPKc,__ZN18GlslGpuProgramGLES15ApplyGpuProgramERK20GpuProgramParametersPKh,__Z53AssemblyU002DCSharp_JSONObject_AddJSONConents_m__ctorP45AssemblyU002DCSharp_JSONObject_AddJSONConentsP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z52AssemblyU002DCSharp_JSONObject_FieldNotFound_m__ctorP44AssemblyU002DCSharp_JSONObject_FieldNotFoundP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z55AssemblyU002DCSharp_JSONObject_GetFieldResponse_m__ctorP47AssemblyU002DCSharp_JSONObject_GetFieldResponseP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z106AssemblyU002DCSharp_JSONObject_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringb,__Z109AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringb,__Z107AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringi,__Z131AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObject_AddJSONConentsP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP45AssemblyU002DCSharp_JSONObject_AddJSONConents,__Z108AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringS2_,__Z116AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringS0_,__Z109AssemblyU002DCSharp_JSONObject_m_SetField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringb,__Z107AssemblyU002DCSharp_JSONObject_m_SetField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32P30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringi,__Z116AssemblyU002DCSharp_JSONObject_m_SetField_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringS0_,__Z43AssemblyU002DCSharp_JSONObject_m_MergeRecurP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObjectS2_,__Z115AssemblyU002DCSharp_JSONObject_m_set_Item_mscorlib_System_Void_mscorlib_System_Int32_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectiS0_
  ,__Z116AssemblyU002DCSharp_JSONObject_m_set_Item_mscorlib_System_Void_mscorlib_System_String_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringS0_,__Z45AssemblyU002DCSharp_JSONTemplates_m_ToVector2P22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z45AssemblyU002DCSharp_JSONTemplates_m_ToVector3P22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z45AssemblyU002DCSharp_JSONTemplates_m_ToVector4P22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z47AssemblyU002DCSharp_JSONTemplates_m_ToMatrix4x4P22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z48AssemblyU002DCSharp_JSONTemplates_m_ToQuaternionP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z43AssemblyU002DCSharp_JSONTemplates_m_ToColorP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z42AssemblyU002DCSharp_JSONTemplates_m_ToRectP22mscorlib_System_ObjectP30AssemblyU002DCSharp_JSONObject,__Z80AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_ApplyInputVelocityChangeP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3,__Z78AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_ApplyGravityAndJumpingP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor31UnityEngine_UnityEngine_Vector3,__Z62AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_CutP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3,__Z64AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_ApplyP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3,__Z72AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_SetUpRotationP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera31UnityEngine_UnityEngine_Vector3S1_,__ZL105mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyToP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi,__ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_InsertP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object,__ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_IList_set_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_CopyToP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri,__ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ShiftP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Objectii,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_InsertP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_set_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_ObjectiP22mscorlib_System_Object,__ZL113mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_CopyToP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi,__ZL107mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_InsertP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectiP22mscorlib_System_Object,__ZL109mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IList_set_ItemP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectiP22mscorlib_System_Object,__ZL82mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_CopyToP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectP34AssemblyU002DCSharp_JSONObject_arri,__ZL81mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_ShiftP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectii,__ZL82mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_InsertP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectiP30AssemblyU002DCSharp_JSONObject,__ZL84mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_set_ItemP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObjectiP30AssemblyU002DCSharp_JSONObject,__ZL105mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_ICollection_CopyToP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP21mscorlib_System_Arrayi,__ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_InsertP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringiP22mscorlib_System_Object,__ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_IList_set_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringiP22mscorlib_System_Object
  ,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_CopyToP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringP26mscorlib_System_String_arri,__ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_ShiftP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Stringii,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_InsertP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringiP22mscorlib_System_String,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_set_ItemP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_StringiP22mscorlib_System_String,__ZL109mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_AddP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_,__ZL225mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_StringU003E_arri,__ZL143mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_ICollection_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi,__ZL114mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_set_ItemP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_,__ZL110mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_InitP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringiP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_CopyToCheckP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi,__ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_StringU003E_arri,__ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_GetObjectDataP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__ZL109mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_AddP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_,__ZL225mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri,__ZL143mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi,__ZL114mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_set_ItemP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_,__ZL110mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InitP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectiP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToCheckP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi,__ZL112mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri,__ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_GetObjectDataP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__ZL113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_,__ZL159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_CopyToP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi,__ZL128mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_CopyToP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP26mscorlib_System_Object_arri,__ZL155mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z180mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object,__Z238mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m__ctorP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z242mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_EndInvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_Object,__ZL113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_,__ZL159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_ICollection_CopyToP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi
  ,__ZL128mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_CopyToP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_StringP26mscorlib_System_String_arri,__ZL155mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z180mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP168mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object,__Z238mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m__ctorP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z242mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_EndInvokeP230mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_AddP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__ZL233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP92mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CJSONObjectU003E_arri,__ZL151mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_CopyToP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi,__ZL122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_set_ItemP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__ZL118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_InitP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectiP22mscorlib_System_Object,__ZL125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_CopyToCheckP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi,__ZL120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_CopyToP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP92mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CJSONObjectU003E_arri,__ZL127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_GetObjectDataP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__ZL121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__ZL167mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_CopyToP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi,__ZL136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_CopyToP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP34AssemblyU002DCSharp_JSONObject_arri,__ZL171mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z184mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z188mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object,__Z254mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m__ctorP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z258mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_EndInvokeP246mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Object,__ZL130System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_CopyToP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri,__ZL78System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_InitP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectiP22mscorlib_System_Object,__ZL133System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_CopyTo_mscorlib_System_Void_T_arr_arr_mscorlib_System_Int32P71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP26mscorlib_System_Object_arri,__ZL87System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_GetObjectDataP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z108mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_AddP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi,__Z224mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P94mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_Int32U003E_arri,__Z142mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_ICollection_CopyToP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_set_ItemP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi
  ,__Z109mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_InitP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32iP22mscorlib_System_Object,__Z116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_CopyToCheckP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_CopyToP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P94mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_Int32U003E_arri,__Z118mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_GetObjectDataP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z112mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi,__Z158mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_ICollection_CopyToP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_CopyToP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32P25mscorlib_System_Int32_arri,__Z153mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32_m__ctorP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32P22mscorlib_System_Object22mscorlib_System_IntPtr,__Z175mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z179mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object,__Z236mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m__ctorP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Object22mscorlib_System_IntPtr,__Z240mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_EndInvokeP228mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_Object,__ZL102System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_System_Collections_ICollection_CopyToP62System_System_Collections_Generic_Stack_1_mscorlib_System_TypeP21mscorlib_System_Arrayi,__ZL104System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_CopyToP64System_System_Collections_Generic_Stack_1_mscorlib_System_ObjectP21mscorlib_System_Arrayi,__ZL103mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_ICollection_CopyToP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP21mscorlib_System_Arrayi,__ZL97mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_InsertP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeiP22mscorlib_System_Object,__ZL99mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_IList_set_ItemP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeiP22mscorlib_System_Object,__ZL72mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_CopyToP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeP24mscorlib_System_Type_arri,__ZL71mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_ShiftP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Typeii,__ZL72mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_InsertP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeiP20mscorlib_System_Type,__ZL74mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_set_ItemP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_TypeiP20mscorlib_System_Type,__Z139mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_AddP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi,__Z255mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP119mscorlib_System_Collections_Generic_KeyValuePair_2U003CUnityEngine_EventU002CUnityEngine_TextEditor_TextEditOpU003E_arri,__Z173mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_ICollection_CopyToP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi,__Z144mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_set_ItemP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi,__Z140mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_InitP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpiP22mscorlib_System_Object,__Z147mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_CopyToCheckP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi,__Z142mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_CopyToP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP119mscorlib_System_Collections_Generic_KeyValuePair_2U003CUnityEngine_EventU002CUnityEngine_TextEditor_TextEditOpU003E_arri,__Z149mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_GetObjectDataP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z143mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi
  ,__Z189mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_ICollection_CopyToP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi,__Z158mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_CopyToP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP49UnityEngine_UnityEngine_TextEditor_TextEditOp_arri,__Z208mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z210mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP198mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object,__Z298mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m__ctorP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z302mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_EndInvokeP290mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_Object,__Z115mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_ICollection_CopyToP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Arrayi,__Z109mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_InsertP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexiP22mscorlib_System_Object,__Z84mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_InsertP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi32UnityEngine_UnityEngine_UIVertex,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_get_ItemP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi,__Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IList_set_ItemP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexiP22mscorlib_System_Object,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_set_ItemP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexi32UnityEngine_UnityEngine_UIVertex,__Z84mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_CopyToP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexP36UnityEngine_UnityEngine_UIVertex_arri,__Z83mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_ShiftP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertexii,__Z117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_ICollection_CopyToP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Arrayi,__Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_InsertP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoiP22mscorlib_System_Object,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_InsertP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi34UnityEngine_UnityEngine_UICharInfo,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_get_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi,__Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IList_set_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoiP22mscorlib_System_Object,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_set_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoi34UnityEngine_UnityEngine_UICharInfo,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_CopyToP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoP38UnityEngine_UnityEngine_UICharInfo_arri,__Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_ShiftP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfoii,__Z117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_ICollection_CopyToP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Arrayi,__Z111mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_InsertP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoiP22mscorlib_System_Object,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_InsertP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi34UnityEngine_UnityEngine_UILineInfo,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_get_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi,__Z113mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IList_set_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoiP22mscorlib_System_Object,__Z88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_set_ItemP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoi34UnityEngine_UnityEngine_UILineInfo,__Z86mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_CopyToP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoP38UnityEngine_UnityEngine_UILineInfo_arri
  ,__Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_ShiftP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfoii,__ZL128mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_ICollection_CopyToP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_Arrayi,__ZL122mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_InsertP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalliP22mscorlib_System_Object,__ZL124mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IList_set_ItemP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalliP22mscorlib_System_Object,__ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_CopyToP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallP49UnityEngine_UnityEngine_Events_PersistentCall_arri,__ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_ShiftP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCallii,__ZL97mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_InsertP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalliP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_set_ItemP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCalliP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL131mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_ICollection_CopyToP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_Arrayi,__ZL125mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_InsertP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalliP22mscorlib_System_Object,__ZL127mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IList_set_ItemP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalliP22mscorlib_System_Object,__ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_CopyToP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arri,__ZL99mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_ShiftP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCallii,__ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_InsertP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalliP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL102mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_set_ItemP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCalliP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__Z138mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_AddP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z254mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP121mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_Int32U002CUnityEngine_GUILayoutUtility_LayoutCacheU003E_arri,__Z172mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_ICollection_CopyToP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi,__Z143mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_set_ItemP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z139mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_InitP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP22mscorlib_System_Object,__Z146mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_CopyToCheckP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi,__Z141mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_CopyToP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP121mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_Int32U002CUnityEngine_GUILayoutUtility_LayoutCacheU003E_arri,__Z148mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_GetObjectDataP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z142mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z188mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_ICollection_CopyToP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi,__Z157mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_CopyToP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP56UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_arri,__Z214mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z205mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z209mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP197mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object,__Z296mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m__ctorP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object22mscorlib_System_IntPtr
  ,__Z300mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_EndInvokeP288mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_Object,__ZL121mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_ICollection_CopyToP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_Arrayi,__ZL115mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_InsertP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryiP22mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IList_set_ItemP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryiP22mscorlib_System_Object,__ZL90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_CopyToP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryP42UnityEngine_UnityEngine_GUILayoutEntry_arri,__ZL89mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_ShiftP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryii,__ZL90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_InsertP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryiP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_set_ItemP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntryiP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL119mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_AddP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__ZL235mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_CopyToP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP102mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CUnityEngine_GUIStyleU003E_arri,__ZL153mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_ICollection_CopyToP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi,__ZL124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_set_ItemP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__ZL120mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_InitP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleiP22mscorlib_System_Object,__ZL127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_CopyToCheckP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi,__ZL122mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_CopyToP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP102mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CUnityEngine_GUIStyleU003E_arri,__ZL129mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_GetObjectDataP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__ZL123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__ZL169mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_ICollection_CopyToP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi,__ZL138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_CopyToP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP36UnityEngine_UnityEngine_GUIStyle_arri,__ZL175mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z186mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry_m__ctorP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z190mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntry_m_EndInvokeP178mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_Object,__Z258mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m__ctorP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z262mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_EndInvokeP250mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_Object,__ZL107mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_ICollection_CopyToP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP21mscorlib_System_Arrayi,__ZL101mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_InsertP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arriP22mscorlib_System_Object,__ZL103mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_IList_set_ItemP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arriP22mscorlib_System_Object,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_CopyToP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrP34mscorlib_System_ByteU005BU005D_arri,__ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_ShiftP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arrii,__ZL76mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_InsertP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arriP24mscorlib_System_Byte_arr
  ,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_set_ItemP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arriP24mscorlib_System_Byte_arr,__Z54mscorlib_System_Int32_m_System_IConvertible_ToDateTimePiP22mscorlib_System_Object,__Z53mscorlib_System_Int32_m_System_IConvertible_ToDecimalPiP22mscorlib_System_Object,__Z54mscorlib_System_Int64_m_System_IConvertible_ToDateTimePxP22mscorlib_System_Object,__Z53mscorlib_System_Int64_m_System_IConvertible_ToDecimalPxP22mscorlib_System_Object,__Z55mscorlib_System_UInt32_m_System_IConvertible_ToDateTimePjP22mscorlib_System_Object,__Z54mscorlib_System_UInt32_m_System_IConvertible_ToDecimalPjP22mscorlib_System_Object,__Z55mscorlib_System_UInt64_m_System_IConvertible_ToDateTimePyP22mscorlib_System_Object,__Z54mscorlib_System_UInt64_m_System_IConvertible_ToDecimalPyP22mscorlib_System_Object,__Z53mscorlib_System_Byte_m_System_IConvertible_ToDateTimePhP22mscorlib_System_Object,__Z52mscorlib_System_Byte_m_System_IConvertible_ToDecimalPhP22mscorlib_System_Object,__Z54mscorlib_System_SByte_m_System_IConvertible_ToDateTimePaP22mscorlib_System_Object,__Z53mscorlib_System_SByte_m_System_IConvertible_ToDecimalPaP22mscorlib_System_Object,__Z54mscorlib_System_Int16_m_System_IConvertible_ToDateTimePsP22mscorlib_System_Object,__Z53mscorlib_System_Int16_m_System_IConvertible_ToDecimalPsP22mscorlib_System_Object,__Z55mscorlib_System_UInt16_m_System_IConvertible_ToDateTimePtP22mscorlib_System_Object,__Z54mscorlib_System_UInt16_m_System_IConvertible_ToDecimalPtP22mscorlib_System_Object,__Z53mscorlib_System_Char_m_System_IConvertible_ToDateTimePtP22mscorlib_System_Object,__Z52mscorlib_System_Char_m_System_IConvertible_ToDecimalPtP22mscorlib_System_Object,__Z94mscorlib_System_String_m__ctor_mscorlib_System_Void_mscorlib_System_Char_mscorlib_System_Int32P22mscorlib_System_Stringti,__Z55mscorlib_System_String_m_System_IConvertible_ToDateTimeP22mscorlib_System_StringP22mscorlib_System_Object,__Z54mscorlib_System_String_m_System_IConvertible_ToDecimalP22mscorlib_System_StringP22mscorlib_System_Object,__Z40mscorlib_System_String_m_InternalSetCharP22mscorlib_System_Stringit,__Z55mscorlib_System_Single_m_System_IConvertible_ToDateTimePfP22mscorlib_System_Object,__Z54mscorlib_System_Single_m_System_IConvertible_ToDecimalPfP22mscorlib_System_Object,__Z55mscorlib_System_Double_m_System_IConvertible_ToDateTimePdP22mscorlib_System_Object,__Z54mscorlib_System_Double_m_System_IConvertible_ToDecimalPdP22mscorlib_System_Object,__Z74mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_Int64P23mscorlib_System_Decimalx,__Z75mscorlib_System_Decimal_m__ctor_mscorlib_System_Void_mscorlib_System_UInt64P23mscorlib_System_Decimaly,__Z56mscorlib_System_Decimal_m_System_IConvertible_ToDateTimeP23mscorlib_System_DecimalP22mscorlib_System_Object
  ,__Z55mscorlib_System_Decimal_m_System_IConvertible_ToDecimalP23mscorlib_System_DecimalP22mscorlib_System_Object,__Z31mscorlib_System_Decimal_m_FloorP22mscorlib_System_Object23mscorlib_System_Decimal,__Z46mscorlib_System_Decimal_m_decimalFloorAndTruncP22mscorlib_System_ObjectP23mscorlib_System_Decimali,__Z86mscorlib_System_Decimal_m_op_Increment_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z82mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z83mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z83mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_Int16P22mscorlib_System_Objects,__Z84mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z83mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z84mscorlib_System_Decimal_m_op_Implicit_mscorlib_System_Decimal_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z56mscorlib_System_Boolean_m_System_IConvertible_ToDateTimePbP22mscorlib_System_Object,__Z55mscorlib_System_Boolean_m_System_IConvertible_ToDecimalPbP22mscorlib_System_Object,__Z81mscorlib_System_IntPtr_m_System_Runtime_Serialization_ISerializable_GetObjectDataP22mscorlib_System_IntPtrP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z75mscorlib_System_UIntPtr_m__ctor_mscorlib_System_Void_mscorlib_System_UInt64P23mscorlib_System_UIntPtry,__Z82mscorlib_System_UIntPtr_m_System_Runtime_Serialization_ISerializable_GetObjectDataP23mscorlib_System_UIntPtrP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z49mscorlib_System_MulticastDelegate_m_GetObjectDataP33mscorlib_System_MulticastDelegateP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z40mscorlib_System_Delegate_m_GetObjectDataP24mscorlib_System_DelegateP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z53mscorlib_System_Enum_m_System_IConvertible_ToDateTimeP22mscorlib_System_ObjectS0_,__Z52mscorlib_System_Enum_m_System_IConvertible_ToDecimalP22mscorlib_System_ObjectS0_,__Z37mscorlib_System_Array_Swapper_m__ctorP29mscorlib_System_Array_SwapperP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z38mscorlib_System_Array_Swapper_m_InvokeP29mscorlib_System_Array_Swapperii,__Z57mscorlib_System_Array_m_System_Collections_IList_set_ItemP21mscorlib_System_ArrayiP22mscorlib_System_Object,__Z55mscorlib_System_Array_m_System_Collections_IList_InsertP21mscorlib_System_ArrayiP22mscorlib_System_Object,__Z106mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int32_arr_arrP21mscorlib_System_ArrayP22mscorlib_System_ObjectP25mscorlib_System_Int32_arr,__Z36mscorlib_System_Array_m_SetValueImplP21mscorlib_System_ArrayP22mscorlib_System_Objecti,__Z98mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int32P21mscorlib_System_ArrayP22mscorlib_System_Objecti,__Z106mscorlib_System_Array_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_Int64_arr_arrP21mscorlib_System_ArrayP22mscorlib_System_ObjectP25mscorlib_System_Int64_arr,__Z35mscorlib_System_Array_m_int_swapperP21mscorlib_System_Arrayii,__Z38mscorlib_System_Array_m_double_swapperP21mscorlib_System_Arrayii,__Z35mscorlib_System_Array_m_obj_swapperP21mscorlib_System_Arrayii
  ,__Z36mscorlib_System_Array_m_slow_swapperP21mscorlib_System_Arrayii,__Z93mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_ArrayP22mscorlib_System_ObjectP21mscorlib_System_ArrayS2_,__Z109mscorlib_System_Array_m_Sort_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Collections_IComparerP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_,__Z95mscorlib_System_Array_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32P21mscorlib_System_ArrayS0_i,__Z103mscorlib_System_Exception_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ExceptionP25mscorlib_System_ExceptionP22mscorlib_System_StringS0_,__Z41mscorlib_System_Exception_m_GetObjectDataP25mscorlib_System_ExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z52mscorlib_System_Exception_m_GetFullNameForStackTraceP25mscorlib_System_ExceptionP34mscorlib_System_Text_StringBuilderP37mscorlib_System_Reflection_MethodBase,__Z50mscorlib_System_RuntimeFieldHandle_m_GetObjectDataP34mscorlib_System_RuntimeFieldHandleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z49mscorlib_System_RuntimeTypeHandle_m_GetObjectDataP33mscorlib_System_RuntimeTypeHandleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z109mscorlib_System_ObsoleteAttribute_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP33mscorlib_System_ObsoleteAttributeP22mscorlib_System_Stringb,__Z37mscorlib_System_AsyncCallback_m__ctorP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z139mscorlib_System_Runtime_CompilerServices_RuntimeHelpers_m_InitializeArray_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_IntPtrP22mscorlib_System_ObjectP21mscorlib_System_Array22mscorlib_System_IntPtr,__Z151mscorlib_System_Runtime_CompilerServices_RuntimeHelpers_m_InitializeArray_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_RuntimeFieldHandleP22mscorlib_System_ObjectP21mscorlib_System_Array34mscorlib_System_RuntimeFieldHandle,__Z53mscorlib_Mono_Globalization_Unicode_Level2Map_m__ctorP45mscorlib_Mono_Globalization_Unicode_Level2Maphh,__Z76mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_FillSurrogateSortKeyRawP50mscorlib_Mono_Globalization_Unicode_SimpleCollatoriP49mscorlib_Mono_Globalization_Unicode_SortKeyBuffer,__Z64mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_ClearBufferP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorPhi,__Z70mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendCJKExtensionP49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhh,__Z64mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_AppendLevel5P49mscorlib_Mono_Globalization_Unicode_SortKeyBufferhh,__Z65mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_set_ItemP54mscorlib_System_Collections_ArrayList_ArrayListWrapperiP22mscorlib_System_Object,__Z48mscorlib_System_Collections_ArrayList_m_set_ItemP37mscorlib_System_Collections_ArrayListiP22mscorlib_System_Object,__Z63mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_InsertP54mscorlib_System_Collections_ArrayList_ArrayListWrapperiP22mscorlib_System_Object,__Z46mscorlib_System_Collections_ArrayList_m_InsertP37mscorlib_System_Collections_ArrayListiP22mscorlib_System_Object,__Z68mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_InsertRangeP54mscorlib_System_Collections_ArrayList_ArrayListWrapperiP22mscorlib_System_Object,__Z51mscorlib_System_Collections_ArrayList_m_InsertRangeP37mscorlib_System_Collections_ArrayListiP22mscorlib_System_Object,__Z128mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32P54mscorlib_System_Collections_ArrayList_ArrayListWrapperP21mscorlib_System_Arrayi,__Z111mscorlib_System_Collections_ArrayList_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListP21mscorlib_System_Arrayi,__Z77mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_set_ItemP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperiP22mscorlib_System_Object,__Z75mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_InsertP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperiP22mscorlib_System_Object,__Z80mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_InsertRangeP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperiP22mscorlib_System_Object,__Z140mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_CopyTo_mscorlib_System_Void_mscorlib_System_Array_mscorlib_System_Int32P66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP21mscorlib_System_Arrayi
  ,__Z45mscorlib_System_Collections_ArrayList_m_ShiftP37mscorlib_System_Collections_ArrayListii,__Z52mscorlib_System_Collections_Comparer_m_GetObjectDataP36mscorlib_System_Collections_ComparerP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z51mscorlib_System_Collections_DictionaryEntry_m__ctorP43mscorlib_System_Collections_DictionaryEntryP22mscorlib_System_ObjectS2_,__Z56mscorlib_System_Collections_Hashtable_Enumerator_m__ctorP48mscorlib_System_Collections_Hashtable_EnumeratorP37mscorlib_System_Collections_Hashtablei,__Z55mscorlib_System_Collections_Hashtable_HashKeys_m_CopyToP46mscorlib_System_Collections_Hashtable_HashKeysP21mscorlib_System_Arrayi,__Z57mscorlib_System_Collections_Hashtable_HashValues_m_CopyToP48mscorlib_System_Collections_Hashtable_HashValuesP21mscorlib_System_Arrayi,__Z150mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Collections_IHashCodeProvider_mscorlib_System_Collections_IComparerP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_,__Z48mscorlib_System_Collections_Hashtable_m_set_ItemP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_,__Z46mscorlib_System_Collections_Hashtable_m_CopyToP37mscorlib_System_Collections_HashtableP21mscorlib_System_Arrayi,__Z43mscorlib_System_Collections_Hashtable_m_AddP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_,__Z53mscorlib_System_Collections_Hashtable_m_GetObjectDataP37mscorlib_System_Collections_HashtableP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z48mscorlib_System_Collections_Hashtable_m_SetTableP37mscorlib_System_Collections_HashtableP46mscorlib_System_Collections_Hashtable_Slot_arrP25mscorlib_System_Int32_arr,__Z42mscorlib_System_Collections_Stack_m_CopyToP33mscorlib_System_Collections_StackP21mscorlib_System_Arrayi,__Z46mscorlib_System_Diagnostics_StackFrame_m__ctorP38mscorlib_System_Diagnostics_StackFrameib,__Z113mscorlib_System_Diagnostics_StackTrace_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_BooleanP38mscorlib_System_Diagnostics_StackTraceib,__Z117mscorlib_System_Diagnostics_StackTrace_m__ctor_mscorlib_System_Void_mscorlib_System_Exception_mscorlib_System_BooleanP38mscorlib_System_Diagnostics_StackTraceP25mscorlib_System_Exceptionb,__Z52mscorlib_System_Diagnostics_StackTrace_m_init_framesP38mscorlib_System_Diagnostics_StackTraceib,__Z116mscorlib_System_Globalization_CultureInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_BooleanP41mscorlib_System_Globalization_CultureInfoib,__Z121mscorlib_System_Globalization_NumberFormatInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_BooleanP46mscorlib_System_Globalization_NumberFormatInfoib,__Z46mscorlib_System_Reflection_Assembly_m_FillNameP22mscorlib_System_ObjectP35mscorlib_System_Reflection_AssemblyP39mscorlib_System_Reflection_AssemblyName,__Z55mscorlib_System_Reflection_AssemblyName_m_GetObjectDataP39mscorlib_System_Reflection_AssemblyNameP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z64mscorlib_System_Reflection_Binder_Default_m_ReorderArgumentArrayP41mscorlib_System_Reflection_Binder_DefaultPP26mscorlib_System_Object_arrP22mscorlib_System_Object,__Z114mscorlib_System_Reflection_FieldInfo_m_SetValue_mscorlib_System_Void_mscorlib_System_Object_mscorlib_System_ObjectP36mscorlib_System_Reflection_FieldInfoP22mscorlib_System_ObjectS2_,__Z72mscorlib_System_Reflection_MemberInfoSerializationHolder_m_GetObjectDataP56mscorlib_System_Reflection_MemberInfoSerializationHolderP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z93mscorlib_System_Reflection_Missing_m_System_Runtime_Serialization_ISerializable_GetObjectDataP34mscorlib_System_Reflection_MissingP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z49mscorlib_System_Reflection_Module_m_GetObjectDataP33mscorlib_System_Reflection_ModuleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z57mscorlib_System_Reflection_MonoEventInfo_m_get_event_infoP22mscorlib_System_ObjectP36mscorlib_System_Reflection_MonoEventP40mscorlib_System_Reflection_MonoEventInfo,__Z55mscorlib_System_Reflection_MonoEventInfo_m_GetEventInfoP22mscorlib_System_ObjectP36mscorlib_System_Reflection_MonoEvent,__Z52mscorlib_System_Reflection_MonoEvent_m_GetObjectDataP36mscorlib_System_Reflection_MonoEventP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z52mscorlib_System_Reflection_MonoField_m_GetObjectDataP36mscorlib_System_Reflection_MonoFieldP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext
  ,__Z59mscorlib_System_Reflection_MonoMethodInfo_m_get_method_infoP22mscorlib_System_Object22mscorlib_System_IntPtrP41mscorlib_System_Reflection_MonoMethodInfo,__Z57mscorlib_System_Reflection_MonoMethodInfo_m_GetMethodInfoP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z53mscorlib_System_Reflection_MonoMethod_m_GetObjectDataP37mscorlib_System_Reflection_MonoMethodP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z54mscorlib_System_Reflection_MonoCMethod_m_GetObjectDataP38mscorlib_System_Reflection_MonoCMethodP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z61mscorlib_System_Reflection_MonoProperty_GetterAdapter_m__ctorP53mscorlib_System_Reflection_MonoProperty_GetterAdapterP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z55mscorlib_System_Reflection_MonoProperty_m_GetObjectDataP39mscorlib_System_Reflection_MonoPropertyP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z148mscorlib_System_Reflection_ParameterInfo_m__ctor_mscorlib_System_Void_mscorlib_System_Reflection_ParameterInfo_mscorlib_System_Reflection_MemberInfoP40mscorlib_System_Reflection_ParameterInfoS0_P37mscorlib_System_Reflection_MemberInfo,__Z103mscorlib_System_Reflection_StrongNameKeyPair_m_System_Runtime_Serialization_ISerializable_GetObjectDataP44mscorlib_System_Reflection_StrongNameKeyPairP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z81mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m__ctorP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeii,__Z71mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m__ctorP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeii,__Z75mscorlib_System_Runtime_Remoting_Activation_AppDomainLevelActivator_m__ctorP67mscorlib_System_Runtime_Remoting_Activation_AppDomainLevelActivatorP22mscorlib_System_StringP22mscorlib_System_Object,__Z171mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m_RegisterChannel_mscorlib_System_Void_mscorlib_System_Runtime_Remoting_Channels_IChannel_mscorlib_System_BooleanP22mscorlib_System_ObjectS0_b,__Z58mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m__ctorP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfoP37mscorlib_System_Reflection_MethodBaseh,__Z75mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_GetObjectDataP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCallP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z77mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContext_m_GetObjectDataP61mscorlib_System_Runtime_Remoting_Messaging_LogicalCallContextP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z69mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_GetObjectDataP53mscorlib_System_Runtime_Remoting_Messaging_MethodCallP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z55mscorlib_System_Runtime_Remoting_ObjRef_m_GetObjectDataP39mscorlib_System_Runtime_Remoting_ObjRefP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z79mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatter_m__ctorP71mscorlib_System_Runtime_Serialization_Formatters_Binary_BinaryFormatterP22mscorlib_System_Object54mscorlib_System_Runtime_Serialization_StreamingContext,__Z132mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int16P55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Strings,__Z132mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Int32P55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringi,__Z134mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_BooleanP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringb,__Z135mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_DateTimeP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_String24mscorlib_System_DateTime,__Z133mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ObjectP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_StringP22mscorlib_System_Object,__Z62mscorlib_System_Runtime_Serialization_StreamingContext_m__ctorP54mscorlib_System_Runtime_Serialization_StreamingContextiP22mscorlib_System_Object,__Z67mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator_m__ctorP59mscorlib_System_Security_Policy_Evidence_EvidenceEnumeratorP22mscorlib_System_ObjectS2_,__Z49mscorlib_System_Security_Policy_Evidence_m_CopyToP40mscorlib_System_Security_Policy_EvidenceP21mscorlib_System_Arrayi,__Z52mscorlib_System_Security_Policy_Hash_m_GetObjectDataP36mscorlib_System_Security_Policy_HashP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z66mscorlib_System_Security_SecurityElement_SecurityAttribute_m__ctorP58mscorlib_System_Security_SecurityElement_SecurityAttributeP22mscorlib_System_StringS2_,__Z115mscorlib_System_Security_SecurityElement_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP40mscorlib_System_Security_SecurityElementP22mscorlib_System_StringS2_,__Z55mscorlib_System_Security_SecurityElement_m_AddAttributeP40mscorlib_System_Security_SecurityElementP22mscorlib_System_StringS2_
  ,__Z48mscorlib_System_Security_SecurityElement_m_ToXmlP40mscorlib_System_Security_SecurityElementPP34mscorlib_System_Text_StringBuilderi,__Z58mscorlib_System_Security_SecurityException_m_GetObjectDataP42mscorlib_System_Security_SecurityExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z117mscorlib_System_Text_EncoderFallbackException_m__ctor_mscorlib_System_Void_mscorlib_System_Char_mscorlib_System_Int32P45mscorlib_System_Text_EncoderFallbackExceptionti,__Z51mscorlib_System_Text_Encoding_m_SetFallbackInternalP29mscorlib_System_Text_EncodingP36mscorlib_System_Text_EncoderFallbackP36mscorlib_System_Text_DecoderFallback,__Z93mscorlib_System_Text_StringBuilder_m_System_Runtime_Serialization_ISerializable_GetObjectDataP34mscorlib_System_Text_StringBuilderP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z46mscorlib_System_Text_StringBuilder_m_set_CharsP34mscorlib_System_Text_StringBuilderit,__Z111mscorlib_System_Text_UTF32Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_BooleanP34mscorlib_System_Text_UTF32Encodingbb,__Z110mscorlib_System_Text_UTF8Encoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_BooleanP33mscorlib_System_Text_UTF8Encodingbb,__Z113mscorlib_System_Text_UnicodeEncoding_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_BooleanP36mscorlib_System_Text_UnicodeEncodingbb,__Z58mscorlib_System_Threading_ExecutionContext_m_GetObjectDataP42mscorlib_System_Threading_ExecutionContextP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z92mscorlib_System_ActivationContext_m_System_Runtime_Serialization_ISerializable_GetObjectDataP33mscorlib_System_ActivationContextP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z94mscorlib_System_ApplicationIdentity_m_System_Runtime_Serialization_ISerializable_GetObjectDataP35mscorlib_System_ApplicationIdentityP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z108mscorlib_System_ArgumentException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP33mscorlib_System_ArgumentExceptionP22mscorlib_System_StringS2_,__Z49mscorlib_System_ArgumentException_m_GetObjectDataP33mscorlib_System_ArgumentExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z112mscorlib_System_ArgumentNullException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP37mscorlib_System_ArgumentNullExceptionP22mscorlib_System_StringS2_,__Z118mscorlib_System_ArgumentOutOfRangeException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP43mscorlib_System_ArgumentOutOfRangeExceptionP22mscorlib_System_StringS2_,__Z59mscorlib_System_ArgumentOutOfRangeException_m_GetObjectDataP43mscorlib_System_ArgumentOutOfRangeExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z83mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_Int16P22mscorlib_System_Objects,__Z83mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z83mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z84mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z84mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z83mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_BooleanP22mscorlib_System_Objectb,__Z80mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_ByteP22mscorlib_System_Objecth,__Z81mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_Int32P22mscorlib_System_Objecti,__Z81mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_SByteP22mscorlib_System_Objecta,__Z81mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_Int16P22mscorlib_System_Objects,__Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt32P22mscorlib_System_Objectj,__Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_UInt16P22mscorlib_System_Objectt,__Z55mscorlib_System_DBNull_m_System_IConvertible_ToDateTimeP22mscorlib_System_DBNullP22mscorlib_System_Object
  ,__Z54mscorlib_System_DBNull_m_System_IConvertible_ToDecimalP22mscorlib_System_DBNullP22mscorlib_System_Object,__Z38mscorlib_System_DBNull_m_GetObjectDataP22mscorlib_System_DBNullP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z75mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Int64P24mscorlib_System_DateTimex,__Z102mscorlib_System_DateTime_m__ctor_mscorlib_System_Void_mscorlib_System_Boolean_mscorlib_System_TimeSpanP24mscorlib_System_DateTimeb24mscorlib_System_TimeSpan,__Z57mscorlib_System_DateTime_m_System_IConvertible_ToDateTimeP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z56mscorlib_System_DateTime_m_System_IConvertible_ToDecimalP24mscorlib_System_DateTimeP22mscorlib_System_Object,__Z30mscorlib_System_DateTime_m_AddP24mscorlib_System_DateTime24mscorlib_System_TimeSpan,__Z35mscorlib_System_DateTime_m_SubtractP24mscorlib_System_DateTime24mscorlib_System_TimeSpan,__Z109mscorlib_System_DateTimeOffset_m__ctor_mscorlib_System_Void_mscorlib_System_DateTime_mscorlib_System_TimeSpanP30mscorlib_System_DateTimeOffset24mscorlib_System_DateTime24mscorlib_System_TimeSpan,__Z89mscorlib_System_DateTimeOffset_m_System_Runtime_Serialization_ISerializable_GetObjectDataP30mscorlib_System_DateTimeOffsetP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z65mscorlib_System_DelegateSerializationHolder_DelegateEntry_m__ctorP57mscorlib_System_DelegateSerializationHolder_DelegateEntryP24mscorlib_System_DelegateP22mscorlib_System_String,__Z59mscorlib_System_DelegateSerializationHolder_m_GetObjectDataP43mscorlib_System_DelegateSerializationHolderP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z44mscorlib_System_MonoEnumInfo_m_get_enum_infoP22mscorlib_System_ObjectP20mscorlib_System_TypeP28mscorlib_System_MonoEnumInfo,__Z38mscorlib_System_MonoEnumInfo_m_GetInfoP22mscorlib_System_ObjectP20mscorlib_System_TypeP28mscorlib_System_MonoEnumInfo,__Z34mscorlib_System_Guid_m_CheckLengthP22mscorlib_System_ObjectP24mscorlib_System_Byte_arri,__Z33mscorlib_System_Guid_m_CheckArrayP22mscorlib_System_ObjectP24mscorlib_System_Byte_arri,__Z32mscorlib_System_Guid_m_AppendIntP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderi,__Z34mscorlib_System_Guid_m_AppendShortP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilders,__Z33mscorlib_System_Guid_m_AppendByteP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderh,__Z119mscorlib_System_InvalidOperationException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ExceptionP41mscorlib_System_InvalidOperationExceptionP22mscorlib_System_StringP25mscorlib_System_Exception,__Z76mscorlib_System_Math_m_Round_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_Decimal,__Z113mscorlib_System_MissingMemberException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP38mscorlib_System_MissingMemberExceptionP22mscorlib_System_StringS2_,__Z54mscorlib_System_MissingMemberException_m_GetObjectDataP38mscorlib_System_MissingMemberExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z113mscorlib_System_MissingMethodException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP38mscorlib_System_MissingMethodExceptionP22mscorlib_System_StringS2_,__Z53mscorlib_System_MonoCustomAttrs_AttributeInfo_m__ctorP45mscorlib_System_MonoCustomAttrs_AttributeInfoP39mscorlib_System_AttributeUsageAttributei,__Z40mscorlib_System_MonoType_m_GetObjectDataP24mscorlib_System_MonoTypeP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z53mscorlib_System_MonoType_m_ReorderParamArrayArgumentsP24mscorlib_System_MonoTypePP26mscorlib_System_Object_arrP37mscorlib_System_Reflection_MethodBase,__Z94mscorlib_System_NumberFormatter_m_InitDecHexDigits_mscorlib_System_Void_mscorlib_System_UInt64P31mscorlib_System_NumberFormattery,__Z41mscorlib_System_NumberFormatter_m_InitHexP31mscorlib_System_NumberFormattery,__Z106mscorlib_System_NumberFormatter_m_Init_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_DecimalP31mscorlib_System_NumberFormatterP22mscorlib_System_String23mscorlib_System_Decimal
  ,__Z104mscorlib_System_NumberFormatter_m_Append_mscorlib_System_Void_mscorlib_System_Char_mscorlib_System_Int32P31mscorlib_System_NumberFormatterti,__Z45mscorlib_System_NumberFormatter_m_ZeroTrimEndP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderb,__Z57mscorlib_System_NumberFormatter_m_AppendNonNegativeNumberP22mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderi,__Z131mscorlib_System_NumberFormatter_m_AppendIntegerString_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Text_StringBuilderP31mscorlib_System_NumberFormatteriP34mscorlib_System_Text_StringBuilder,__Z131mscorlib_System_NumberFormatter_m_AppendDecimalString_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Text_StringBuilderP31mscorlib_System_NumberFormatteriP34mscorlib_System_Text_StringBuilder,__Z71mscorlib_System_NumberFormatter_m_AppendIntegerStringWithGroupSeparatorP31mscorlib_System_NumberFormatterP25mscorlib_System_Int32_arrP22mscorlib_System_String,__Z50mscorlib_System_NumberFormatter_m_FastAppendDigitsP31mscorlib_System_NumberFormatterib,__Z111mscorlib_System_NumberFormatter_m_AppendDigits_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32P31mscorlib_System_NumberFormatterii,__Z55mscorlib_System_ObjectDisposedException_m_GetObjectDataP39mscorlib_System_ObjectDisposedExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z39mscorlib_System_OperatingSystem_m__ctorP31mscorlib_System_OperatingSystemiP23mscorlib_System_Version,__Z47mscorlib_System_OperatingSystem_m_GetObjectDataP31mscorlib_System_OperatingSystemP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z51mscorlib_System_RuntimeMethodHandle_m_GetObjectDataP35mscorlib_System_RuntimeMethodHandleP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z44mscorlib_System_CultureAwareComparer_m__ctorP36mscorlib_System_CultureAwareComparerP41mscorlib_System_Globalization_CultureInfob,__Z109mscorlib_System_SystemException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ExceptionP31mscorlib_System_SystemExceptionP22mscorlib_System_StringP25mscorlib_System_Exception,__Z75mscorlib_System_TimeSpan_m__ctor_mscorlib_System_Void_mscorlib_System_Int64P24mscorlib_System_TimeSpanx,__Z38mscorlib_System_TimeZone_m_ToLocalTimeP24mscorlib_System_TimeZone24mscorlib_System_DateTime,__Z42mscorlib_System_TimeZone_m_ToUniversalTimeP24mscorlib_System_TimeZone24mscorlib_System_DateTime,__Z45mscorlib_System_CurrentSystemTimeZone_m__ctorP37mscorlib_System_CurrentSystemTimeZonex,__Z59mscorlib_System_TypeInitializationException_m_GetObjectDataP43mscorlib_System_TypeInitializationExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z49mscorlib_System_TypeLoadException_m_GetObjectDataP33mscorlib_System_TypeLoadExceptionP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z56mscorlib_System_UnitySerializationHolder_m_GetObjectDataP40mscorlib_System_UnitySerializationHolderP55mscorlib_System_Runtime_Serialization_SerializationInfo54mscorlib_System_Runtime_Serialization_StreamingContext,__Z47mscorlib_System_Reflection_MemberFilter_m__ctorP39mscorlib_System_Reflection_MemberFilterP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z45mscorlib_System_Reflection_TypeFilter_m__ctorP37mscorlib_System_Reflection_TypeFilterP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z44mscorlib_System_AppDomainInitializer_m__ctorP36mscorlib_System_AppDomainInitializerP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z48mscorlib_System_AssemblyLoadEventHandler_m__ctorP40mscorlib_System_AssemblyLoadEventHandlerP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z49mscorlib_System_AssemblyLoadEventHandler_m_InvokeP40mscorlib_System_AssemblyLoadEventHandlerP22mscorlib_System_ObjectP37mscorlib_System_AssemblyLoadEventArgs,__Z36mscorlib_System_EventHandler_m__ctorP28mscorlib_System_EventHandlerP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z37mscorlib_System_EventHandler_m_InvokeP28mscorlib_System_EventHandlerP22mscorlib_System_ObjectP25mscorlib_System_EventArgs,__Z43mscorlib_System_ResolveEventHandler_m__ctorP35mscorlib_System_ResolveEventHandlerP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z54mscorlib_System_UnhandledExceptionEventHandler_m__ctorP46mscorlib_System_UnhandledExceptionEventHandlerP22mscorlib_System_Object22mscorlib_System_IntPtr
  ,__Z55mscorlib_System_UnhandledExceptionEventHandler_m_InvokeP46mscorlib_System_UnhandledExceptionEventHandlerP22mscorlib_System_ObjectP43mscorlib_System_UnhandledExceptionEventArgs,__Z53replacements_Replacements_Attribute_m_CheckParametersP22mscorlib_System_ObjectS0_P20mscorlib_System_Type,__Z50UnityEngine_UnityEngine_GUI_WindowFunction_m__ctorP42UnityEngine_UnityEngine_GUI_WindowFunctionP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z59UnityEngine_UnityEngine_SendMouseEvents_m_DoSendMouseEventsP22mscorlib_System_Objectii,__Z52UnityEngine_UnityEngine_SendMouseEvents_m_SendEventsP22mscorlib_System_Objecti47UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__Z116UnityEngine_UnityEngine_UnityException_m__ctor_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_ExceptionP38UnityEngine_UnityEngine_UnityExceptionP22mscorlib_System_StringP25mscorlib_System_Exception,__Z67UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateMachineEnterP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animatori,__Z66UnityEngine_UnityEngine_StateMachineBehaviour_m_OnStateMachineExitP45UnityEngine_UnityEngine_StateMachineBehaviourP32UnityEngine_UnityEngine_Animatori,__Z57UnityEngine_UnityEngine_TextGenerator_m_ValidatedSettingsP37UnityEngine_UnityEngine_TextGenerator46UnityEngine_UnityEngine_TextGenerationSettings,__Z55UnityEngine_UnityEngine_Application_LogCallback_m__ctorP47UnityEngine_UnityEngine_Application_LogCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z50UnityEngine_UnityEngine_Application_m_ExternalCallP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr,__Z134UnityEngine_UnityEngine_Component_m_SendMessage_mscorlib_System_Void_mscorlib_System_String_UnityEngine_UnityEngine_SendMessageOptionsP33UnityEngine_UnityEngine_ComponentP22mscorlib_System_Stringi,__Z65UnityEngine_UnityEngine_GUILayoutUtility_m_Internal_GetWindowRectP22mscorlib_System_Objecti,__Z62UnityEngine_UnityEngine_GUILayoutUtility_m_Internal_MoveWindowP22mscorlib_System_Objecti28UnityEngine_UnityEngine_Rect,__Z76UnityEngine_UnityEngine_GUILayoutUtility_m_INTERNAL_CALL_Internal_MoveWindowP22mscorlib_System_ObjectiP28UnityEngine_UnityEngine_Rect,__Z47UnityEngine_UnityEngine_GUILayoutOption_m__ctorP39UnityEngine_UnityEngine_GUILayoutOptioniP22mscorlib_System_Object,__Z59UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate_m__ctorP51UnityEngine_UnityEngine_GUISkin_SkinChangedDelegateP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z45UnityEngine_UnityEngine_GUIStyleState_m__ctorP37UnityEngine_UnityEngine_GUIStyleStateP32UnityEngine_UnityEngine_GUIStyle22mscorlib_System_IntPtr,__Z119UnityEngine_UnityEngine_RectOffset_m__ctor_mscorlib_System_Void_UnityEngine_UnityEngine_GUIStyle_mscorlib_System_IntPtrP34UnityEngine_UnityEngine_RectOffsetP32UnityEngine_UnityEngine_GUIStyle22mscorlib_System_IntPtr,__Z43UnityEngine_UnityEngine_Vector3_m_NormalizeP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z114UnityEngine_UnityEngine_Vector3_m_op_UnaryNegation_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z105UnityEngine_UnityEngine_Color_m_op_Implicit_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_ColorP22mscorlib_System_Object29UnityEngine_UnityEngine_Color,__Z107UnityEngine_UnityEngine_Color32_m_op_Implicit_UnityEngine_UnityEngine_Color32_UnityEngine_UnityEngine_ColorP22mscorlib_System_Object29UnityEngine_UnityEngine_Color,__Z116UnityEngine_UnityEngine_Quaternion_m_LookRotation_UnityEngine_UnityEngine_Quaternion_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z44UnityEngine_UnityEngine_Quaternion_m_InverseP22mscorlib_System_Object34UnityEngine_UnityEngine_Quaternion,__Z58UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_InverseP22mscorlib_System_ObjectP34UnityEngine_UnityEngine_Quaternion,__Z56UnityEngine_UnityEngine_Quaternion_m_Internal_ToEulerRadP22mscorlib_System_Object34UnityEngine_UnityEngine_Quaternion,__Z70UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_Internal_ToEulerRadP22mscorlib_System_ObjectP34UnityEngine_UnityEngine_Quaternion,__Z58UnityEngine_UnityEngine_Quaternion_m_Internal_FromEulerRadP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z72UnityEngine_UnityEngine_Quaternion_m_INTERNAL_CALL_Internal_FromEulerRadP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3
  ,__Z43UnityEngine_UnityEngine_Matrix4x4_m_InverseP22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4,__Z57UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_InverseP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_Matrix4x4,__Z45UnityEngine_UnityEngine_Matrix4x4_m_TransposeP22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4,__Z59UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_TransposeP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_Matrix4x4,__Z45UnityEngine_UnityEngine_Matrix4x4_m_GetColumnP33UnityEngine_UnityEngine_Matrix4x4i,__Z42UnityEngine_UnityEngine_Matrix4x4_m_GetRowP33UnityEngine_UnityEngine_Matrix4x4i,__Z45UnityEngine_UnityEngine_Matrix4x4_m_SetColumnP33UnityEngine_UnityEngine_Matrix4x4i31UnityEngine_UnityEngine_Vector4,__Z42UnityEngine_UnityEngine_Matrix4x4_m_SetRowP33UnityEngine_UnityEngine_Matrix4x4i31UnityEngine_UnityEngine_Vector4,__Z49UnityEngine_UnityEngine_Matrix4x4_m_MultiplyPointP33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector3,__Z52UnityEngine_UnityEngine_Matrix4x4_m_MultiplyPoint3x4P33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector3,__Z50UnityEngine_UnityEngine_Matrix4x4_m_MultiplyVectorP33UnityEngine_UnityEngine_Matrix4x431UnityEngine_UnityEngine_Vector3,__Z41UnityEngine_UnityEngine_Matrix4x4_m_ScaleP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z38UnityEngine_UnityEngine_Bounds_m__ctorP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3S1_,__Z42UnityEngine_UnityEngine_Bounds_m_SetMinMaxP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3S1_,__Z45UnityEngine_UnityEngine_Bounds_m_ClosestPointP30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__Z117UnityEngine_UnityEngine_Material_m_SetColor_mscorlib_System_Void_mscorlib_System_String_UnityEngine_UnityEngine_ColorP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_String29UnityEngine_UnityEngine_Color,__Z116UnityEngine_UnityEngine_Material_m_SetColor_mscorlib_System_Void_mscorlib_System_Int32_UnityEngine_UnityEngine_ColorP32UnityEngine_UnityEngine_Materiali29UnityEngine_UnityEngine_Color,__Z96UnityEngine_UnityEngine_Material_m_GetColor_UnityEngine_UnityEngine_Color_mscorlib_System_StringP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_String,__Z95UnityEngine_UnityEngine_Material_m_GetColor_UnityEngine_UnityEngine_Color_mscorlib_System_Int32P32UnityEngine_UnityEngine_Materiali,__Z41UnityEngine_UnityEngine_Material_m_SetIntP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_Stringi,__Z109UnityEngine_UnityEngine_WWWForm_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_StringP31UnityEngine_UnityEngine_WWWFormP22mscorlib_System_StringS2_,__Z53UnityEngine_UnityEngine_Camera_CameraCallback_m__ctorP45UnityEngine_UnityEngine_Camera_CameraCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z51UnityEngine_UnityEngine_Camera_m_ViewportPointToRayP30UnityEngine_UnityEngine_Camera31UnityEngine_UnityEngine_Vector3,__Z49UnityEngine_UnityEngine_Camera_m_ScreenPointToRayP30UnityEngine_UnityEngine_Camera31UnityEngine_UnityEngine_Vector3,__Z40UnityEngine_UnityEngine_Debug_m_DrawLineP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__Z63UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate_m__ctorP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegateP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z56UnityEngine_UnityEngine_Display_m_SetRenderingResolutionP31UnityEngine_UnityEngine_Displayii,__Z49UnityEngine_UnityEngine_Display_m_RelativeMouseAtP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3,__Z125UnityEngine_UnityEngine_Transform_m_Rotate_mscorlib_System_Void_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_SpaceP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3i,__Z54UnityEngine_UnityEngine_Transform_m_TransformDirectionP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3
  ,__Z61UnityEngine_UnityEngine_Transform_m_InverseTransformDirectionP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3,__Z50UnityEngine_UnityEngine_Transform_m_TransformPointP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3,__Z57UnityEngine_UnityEngine_Transform_m_InverseTransformPointP33UnityEngine_UnityEngine_Transform31UnityEngine_UnityEngine_Vector3,__Z59UnityEngine_UnityEngine_AudioClip_PCMReaderCallback_m__ctorP51UnityEngine_UnityEngine_AudioClip_PCMReaderCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z64UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallback_m__ctorP56UnityEngine_UnityEngine_AudioClip_PCMSetPositionCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z63UnityEngine_UnityEngine_Font_FontTextureRebuildCallback_m__ctorP55UnityEngine_UnityEngine_Font_FontTextureRebuildCallbackP22mscorlib_System_Object22mscorlib_System_IntPtr,__Z57UnityEngine_UnityEngine_Canvas_WillRenderCanvases_m__ctorP49UnityEngine_UnityEngine_Canvas_WillRenderCanvasesP22mscorlib_System_Object22mscorlib_System_IntPtr,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayP36AssemblyU002DCSharp_BJController_arri,__ZL80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ObjectP21mscorlib_System_ArrayP26mscorlib_System_Object_arri,__ZL68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ObjectP21mscorlib_System_ArrayiP22mscorlib_System_Object,__ZL70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ObjectP21mscorlib_System_ArrayiP22mscorlib_System_Object,__ZL78mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayiP32AssemblyU002DCSharp_BJController,__ZL80mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharp_BJControllerP21mscorlib_System_ArrayiP32AssemblyU002DCSharp_BJController,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayP36AssemblyU002DCSharp_LevelBuilder_arri,__ZL78mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayiP32AssemblyU002DCSharp_LevelBuilder,__ZL80mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_ArrayiP32AssemblyU002DCSharp_LevelBuilder,__ZL80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_StringP21mscorlib_System_ArrayP26mscorlib_System_String_arri,__ZL68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_StringP21mscorlib_System_ArrayiP22mscorlib_System_String,__ZL70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_StringP21mscorlib_System_ArrayiP22mscorlib_System_String,__Z78mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_CharP21mscorlib_System_ArrayP24mscorlib_System_Char_arri,__Z66mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_CharP21mscorlib_System_Arrayit,__Z68mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_CharP21mscorlib_System_Arrayit,__ZL117mscorlib_System_Array_m_Resize_mscorlib_System_Object_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP26mscorlib_System_Object_arri,__ZL78mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_TypeP21mscorlib_System_ArrayP24mscorlib_System_Type_arri,__ZL66mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_TypeP21mscorlib_System_ArrayiP20mscorlib_System_Type,__ZL68mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_TypeP21mscorlib_System_ArrayiP20mscorlib_System_Type,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP34AssemblyU002DCSharp_JSONObject_arri,__ZL76mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayiP30AssemblyU002DCSharp_JSONObject,__ZL78mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayiP30AssemblyU002DCSharp_JSONObject,__ZL125mscorlib_System_Array_m_Resize_AssemblyU002DCSharp_JSONObject_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP34AssemblyU002DCSharp_JSONObject_arri
  ,__ZL117mscorlib_System_Array_m_Resize_mscorlib_System_String_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP26mscorlib_System_String_arri,__Z153mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi,__Z163mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_ArrayP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_ObjectU002CSystem_ObjectU003E_arri,__Z151mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z153mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Arrayi105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z79mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Int32P21mscorlib_System_ArrayP25mscorlib_System_Int32_arri,__Z67mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Int32P21mscorlib_System_Arrayii,__Z69mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Int32P21mscorlib_System_Arrayii,__Z88mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Arrayi,__Z98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_ArrayP44mscorlib_System_Collections_Generic_Link_arri,__Z86mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Arrayi40mscorlib_System_Collections_Generic_Link,__Z88mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Arrayi40mscorlib_System_Collections_Generic_Link,__Z91mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Arrayi,__Z101mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_ArrayP47mscorlib_System_Collections_DictionaryEntry_arri,__Z89mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Arrayi43mscorlib_System_Collections_DictionaryEntry,__Z91mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Arrayi43mscorlib_System_Collections_DictionaryEntry,__Z153mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi,__Z163mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_ArrayP95mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_StringU003E_arri,__Z151mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z153mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Arrayi105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z161mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi,__Z171mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_ArrayP92mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CJSONObjectU003E_arri,__Z159mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z161mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Arrayi113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z93mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_ArrayP39AssemblyU002DCSharp_JSONObject_Type_arri,__Z81mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayii,__Z83mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Arrayii,__Z124mscorlib_System_Array_m_InternalArray__get_Item_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Arrayi,__Z134mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_ArrayP80System_Core_System_Collections_Generic_HashSet_1_LinkU003CSystem_ObjectU003E_arri,__Z122mscorlib_System_Array_m_InternalArray__Insert_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Arrayi76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object
  ,__Z124mscorlib_System_Array_m_InternalArray__set_Item_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Arrayi76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__Z152mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi,__Z162mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_ArrayP94mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CSystem_Int32U003E_arri,__Z150mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z152mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Arrayi104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayP40mscorlib_System_Reflection_FieldInfo_arri,__ZL82mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayiP36mscorlib_System_Reflection_FieldInfo,__ZL84mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_ArrayiP36mscorlib_System_Reflection_FieldInfo,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayP43mscorlib_System_Reflection_PropertyInfo_arri,__ZL85mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayiP39mscorlib_System_Reflection_PropertyInfo,__ZL87mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_ArrayiP39mscorlib_System_Reflection_PropertyInfo,__ZL101mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayP47AssemblyU002DCSharpU002Dfirstpass_MouseLook_arri,__ZL89mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayiP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__ZL91mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_ArrayiP43AssemblyU002DCSharpU002Dfirstpass_MouseLook,__Z114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_ArrayP60AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_arri,__Z102mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayii,__Z104mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Arrayii,__Z80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Keyframe_arri,__Z78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Arrayi32UnityEngine_UnityEngine_Keyframe,__Z80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Arrayi32UnityEngine_UnityEngine_Keyframe,__Z119mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_ArrayP65AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_arri,__Z107mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayii,__Z109mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Arrayii,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_arri,__ZL99mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayiP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL101mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_ArrayiP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL101mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayP47UnityEngine_UnityEngine_CharacterController_arri,__ZL89mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayiP43UnityEngine_UnityEngine_CharacterController,__ZL91mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_ArrayiP43UnityEngine_UnityEngine_CharacterController
  ,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayP61AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_arri,__ZL103mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayiP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL105mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_ArrayiP57AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayP66AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_arri,__ZL108mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayiP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__ZL110mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_ArrayiP62AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_arri,__ZL102mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayiP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL104mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_ArrayiP56AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayP64AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_arri,__ZL106mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayiP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__ZL108mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_ArrayiP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_ArrayP57AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_arri,__Z99mscorlib_System_Array_m_InternalArray__Insert_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayii,__Z101mscorlib_System_Array_m_InternalArray__set_Item_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Arrayii,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Animation_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Animation,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AnimationP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Animation,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_WrapperlessIcall_arri,__ZL86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_WrapperlessIcall,__ZL88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_WrapperlessIcall,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayP53UnityEngine_UnityEngine_DisallowMultipleComponent_arri,__ZL95mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayiP49UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL97mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_ArrayiP49UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_ExecuteInEditMode_arri,__ZL87mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayiP41UnityEngine_UnityEngine_ExecuteInEditMode,__ZL89mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_ArrayiP41UnityEngine_UnityEngine_ExecuteInEditMode,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_RequireComponent_arri,__ZL86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_RequireComponent,__ZL88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_RequireComponent
  ,__ZL115mscorlib_System_Array_m_Resize_mscorlib_System_Type_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP24mscorlib_System_Type_arri,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_MonoBehaviour_arri,__ZL83mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_MonoBehaviour,__ZL85mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_MonoBehaviour,__Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_ArrayP48mscorlib_System_Reflection_ParameterModifier_arri,__Z90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Arrayi44mscorlib_System_Reflection_ParameterModifier,__Z92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Arrayi44mscorlib_System_Reflection_ParameterModifier,__ZL99mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayP45UnityEngine_UnityEngine_WritableAttribute_arri,__ZL87mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayiP41UnityEngine_UnityEngine_WritableAttribute,__ZL89mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_ArrayiP41UnityEngine_UnityEngine_WritableAttribute,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_AssemblyIsEditorAssembly_arri,__ZL94mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayiP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL96mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_ArrayiP48UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_GUILayoutOption_arri,__ZL85mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayiP39UnityEngine_UnityEngine_GUILayoutOption,__ZL87mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_ArrayiP39UnityEngine_UnityEngine_GUILayoutOption,__Z95mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Arrayi,__Z105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_ArrayP51UnityEngine_UnityEngine_SendMouseEvents_HitInfo_arri,__Z93mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Arrayi47UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__Z95mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Arrayi47UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Camera_arri,__ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Camera,__ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CameraP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Camera,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayP44mscorlib_System_Reflection_ParameterInfo_arri,__ZL86mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayiP40mscorlib_System_Reflection_ParameterInfo,__ZL88mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_ArrayiP40mscorlib_System_Reflection_ParameterInfo,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_StateMachineBehaviour_arri,__ZL91mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayiP45UnityEngine_UnityEngine_StateMachineBehaviour,__ZL93mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_ArrayiP45UnityEngine_UnityEngine_StateMachineBehaviour,__Z183mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi
  ,__Z193mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_ArrayP119mscorlib_System_Collections_Generic_KeyValuePair_2U003CUnityEngine_EventU002CUnityEngine_TextEditor_TextEditOpU003E_arri,__Z181mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z183mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayi135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__ZL87mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Event_arri,__ZL75mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayiP29UnityEngine_UnityEngine_Event,__ZL77mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_EventP21mscorlib_System_ArrayiP29UnityEngine_UnityEngine_Event,__Z103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_TextEditor_TextEditOp_arri,__Z91mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayii,__Z93mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Arrayii,__Z109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_ArrayP55UnityEngine_UnityEngine_TextEditor_DblClickSnapping_arri,__Z97mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayih,__Z99mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Arrayih,__Z80mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Arrayi,__Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_UIVertex_arri,__Z78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Arrayi32UnityEngine_UnityEngine_UIVertex,__Z80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Arrayi32UnityEngine_UnityEngine_UIVertex,__Z127mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UIVertex_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP36UnityEngine_UnityEngine_UIVertex_arri,__Z82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_UICharInfo_arri,__Z80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Arrayi34UnityEngine_UnityEngine_UICharInfo,__Z82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Arrayi34UnityEngine_UnityEngine_UICharInfo,__Z129mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UICharInfo_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP38UnityEngine_UnityEngine_UICharInfo_arri,__Z82mscorlib_System_Array_m_InternalArray__get_Item_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Arrayi,__Z92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_UILineInfo_arri,__Z80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Arrayi34UnityEngine_UnityEngine_UILineInfo,__Z82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Arrayi34UnityEngine_UnityEngine_UILineInfo,__Z129mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_UILineInfo_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP38UnityEngine_UnityEngine_UILineInfo_arri,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Component_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Component,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ComponentP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Component
  ,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GameObject_arri,__ZL80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayiP34UnityEngine_UnityEngine_GameObject,__ZL82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_ArrayiP34UnityEngine_UnityEngine_GameObject,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Object_arri,__ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Object,__ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ObjectP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Object,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayP49UnityEngine_UnityEngine_Events_PersistentCall_arri,__ZL91mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayiP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL93mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_ArrayiP45UnityEngine_UnityEngine_Events_PersistentCall,__ZL140mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_Events_PersistentCall_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP49UnityEngine_UnityEngine_Events_PersistentCall_arri,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arri,__ZL94mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayiP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL96mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_ArrayiP48UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL143mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_Events_BaseInvokableCall_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP52UnityEngine_UnityEngine_Events_BaseInvokableCall_arri,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayP51UnityEngine_UnityEngine_UserAuthorizationDialog_arri,__ZL93mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayiP47UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL95mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_ArrayiP47UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngine_Internal_DefaultValueAttribute_arri,__ZL100mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayiP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL102mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_ArrayiP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayP61UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_arri,__ZL103mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayiP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL105mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_ArrayiP57UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayP58UnityEngine_UnityEngine_RenamedSerializedDataAttribute_arri,__ZL100mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayiP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__ZL102mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_ArrayiP54UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__Z108mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_ArrayP54UnityEngine_UnityEngineInternal_TypeInferenceRules_arri,__Z96mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayii,__Z98mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Arrayii,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayP62UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_arri
  ,__ZL104mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayiP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL106mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_ArrayiP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayP39UnityEngine_UnityEngine_AssetBundle_arri,__ZL81mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayiP35UnityEngine_UnityEngine_AssetBundle,__ZL83mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_ArrayiP35UnityEngine_UnityEngine_AssetBundle,__Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_ArrayP46UnityEngine_UnityEngine_SendMessageOptions_arri,__Z88mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayii,__Z90mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Arrayii,__Z95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_PrimitiveType_arri,__Z83mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayii,__Z85mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Arrayii,__Z87mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SpaceP21mscorlib_System_ArrayP33UnityEngine_UnityEngine_Space_arri,__Z75mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayii,__Z77mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Arrayii,__Z89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_LogType_arri,__Z77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayii,__Z79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Arrayii,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_AddComponentMenu_arri,__ZL86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_AddComponentMenu,__ZL88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_AddComponentMenu,__ZL98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_ScriptableObject_arri,__ZL86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_ScriptableObject,__ZL88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_ArrayiP40UnityEngine_UnityEngine_ScriptableObject,__Z98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_CameraClearFlags_arri,__Z86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayii,__Z88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Arrayii,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Renderer_arri,__ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Renderer,__ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RendererP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Renderer,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayP43UnityEngine_UnityEngine_ReflectionProbe_arri
  ,__ZL85mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayiP39UnityEngine_UnityEngine_ReflectionProbe,__ZL87mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_ArrayiP39UnityEngine_UnityEngine_ReflectionProbe,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_Texture_arri,__ZL77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Texture,__ZL79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextureP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Texture,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Texture2D_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Texture2D,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Texture2D,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_RenderTexture_arri,__ZL83mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_RenderTexture,__ZL85mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_RenderTexture,__ZL92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_GUIElement_arri,__ZL80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayiP34UnityEngine_UnityEngine_GUIElement,__ZL82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_ArrayiP34UnityEngine_UnityEngine_GUIElement,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_GUILayer_arri,__ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_GUILayer,__ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_GUILayer,__Z182mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi,__Z192mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP121mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_Int32U002CUnityEngine_GUILayoutUtility_LayoutCacheU003E_arri,__Z180mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z182mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Arrayi134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayP56UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_arri,__ZL98mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL100mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_ArrayiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayP42UnityEngine_UnityEngine_GUILayoutEntry_arri,__ZL84mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayiP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL86mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_ArrayiP38UnityEngine_UnityEngine_GUILayoutEntry,__ZL133mscorlib_System_Array_m_Resize_UnityEngine_UnityEngine_GUILayoutEntry_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP42UnityEngine_UnityEngine_GUILayoutEntry_arri,__Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_GUILayoutOption_Type_arri,__Z90mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayii
  ,__Z92mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Arrayii,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_GUISkin_arri,__ZL77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_GUISkin,__ZL79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_GUISkin,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_GUIStyle_arri,__ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_GUIStyle,__ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_GUIStyle,__Z163mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi,__Z173mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_ArrayP102mscorlib_System_Collections_Generic_KeyValuePair_2U003CSystem_StringU002CUnityEngine_GUIStyleU003E_arri,__Z161mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z163mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Arrayi115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_FontStyle_arri,__Z79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayii,__Z81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Arrayii,__Z89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_KeyCode_arri,__Z77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayii,__Z79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Arrayii,__Z91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_EventType_arri,__Z79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayii,__Z81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Arrayii,__Z96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_ArrayP42UnityEngine_UnityEngine_EventModifiers_arri,__Z84mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayii,__Z86mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Arrayii,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_TextAsset_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_TextAsset,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_TextAsset,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayP53UnityEngine_UnityEngine_SerializePrivateVariables_arri,__ZL95mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayiP49UnityEngine_UnityEngine_SerializePrivateVariables,__ZL97mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_ArrayiP49UnityEngine_UnityEngine_SerializePrivateVariables,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayP42UnityEngine_UnityEngine_SerializeField_arri
  ,__ZL84mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayiP38UnityEngine_UnityEngine_SerializeField,__ZL86mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_ArrayiP38UnityEngine_UnityEngine_SerializeField,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Shader_arri,__ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Shader,__ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ShaderP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Shader,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Material_arri,__ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Material,__ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_MaterialP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Material,__ZL82mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Byte_arrP21mscorlib_System_ArrayP34mscorlib_System_ByteU005BU005D_arri,__ZL70mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Byte_arrP21mscorlib_System_ArrayiP24mscorlib_System_Byte_arr,__ZL72mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Byte_arrP21mscorlib_System_ArrayiP24mscorlib_System_Byte_arr,__ZL119mscorlib_System_Array_m_Resize_mscorlib_System_Byte_arr_mscorlib_System_Void_TU005BU005DU0026_ref_mscorlib_System_Int32P22mscorlib_System_ObjectPP34mscorlib_System_ByteU005BU005D_arri,__Z78mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ByteP21mscorlib_System_ArrayP24mscorlib_System_Byte_arri,__Z66mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ByteP21mscorlib_System_Arrayih,__Z68mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ByteP21mscorlib_System_Arrayih,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Behaviour_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Behaviour,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Behaviour,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_Display_arri,__ZL77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Display,__ZL79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_DisplayP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Display,__Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_IntPtrP21mscorlib_System_ArrayP26mscorlib_System_IntPtr_arri,__Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_IntPtrP21mscorlib_System_Arrayi22mscorlib_System_IntPtr,__Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_IntPtrP21mscorlib_System_Arrayi22mscorlib_System_IntPtr,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Transform_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Transform,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TransformP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Transform,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Motion_arri,__ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Motion,__ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_MotionP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Motion
  ,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_Rigidbody_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Rigidbody,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_Rigidbody,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Collider_arri,__ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Collider,__ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_ColliderP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Collider,__Z96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_ArrayP42UnityEngine_UnityEngine_CollisionFlags_arri,__Z84mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayii,__Z86mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Arrayii,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayP37UnityEngine_UnityEngine_AudioClip_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_AudioClip,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_ArrayiP33UnityEngine_UnityEngine_AudioClip,__Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_SingleP21mscorlib_System_ArrayP26mscorlib_System_Single_arri,__Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_WrapMode_arri,__Z78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayii,__Z80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Arrayii,__Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_ArrayP48UnityEngine_UnityEngine_AnimationEventSource_arri,__Z90mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayii,__Z92mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Arrayii,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayP41UnityEngine_UnityEngine_AnimationClip_arri,__ZL83mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_AnimationClip,__ZL85mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_ArrayiP37UnityEngine_UnityEngine_AnimationClip,__Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_PlayMode_arri,__Z78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayii,__Z80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Arrayii,__ZL90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayP36UnityEngine_UnityEngine_Animator_arri,__ZL78mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Animator,__ZL80mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_ArrayiP32UnityEngine_UnityEngine_Animator,__ZL89mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayP35UnityEngine_UnityEngine_Terrain_arri,__ZL77mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Terrain
  ,__ZL79mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TerrainP21mscorlib_System_ArrayiP31UnityEngine_UnityEngine_Terrain,__Z92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_ArrayP38UnityEngine_UnityEngine_TextAnchor_arri,__Z80mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayii,__Z82mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Arrayii,__Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_ArrayP46UnityEngine_UnityEngine_HorizontalWrapMode_arri,__Z88mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayii,__Z90mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Arrayii,__Z98mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_ArrayP44UnityEngine_UnityEngine_VerticalWrapMode_arri,__Z86mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayii,__Z88mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Arrayii,__ZL86mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayP32UnityEngine_UnityEngine_Font_arri,__ZL74mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayiP28UnityEngine_UnityEngine_Font,__ZL76mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_FontP21mscorlib_System_ArrayiP28UnityEngine_UnityEngine_Font,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayP34UnityEngine_UnityEngine_Canvas_arri,__ZL76mscorlib_System_Array_m_InternalArray__Insert_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Canvas,__ZL78mscorlib_System_Array_m_InternalArray__set_Item_UnityEngine_UnityEngine_CanvasP21mscorlib_System_ArrayiP30UnityEngine_UnityEngine_Canvas,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayP66System_Core_System_Runtime_CompilerServices_ExtensionAttribute_arri,__ZL108mscorlib_System_Array_m_InternalArray__Insert_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayiP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL110mscorlib_System_Array_m_InternalArray__set_Item_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_ArrayiP62System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL94mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayP40System_Core_System_MonoTODOAttribute_arri,__ZL82mscorlib_System_Array_m_InternalArray__Insert_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayiP36System_Core_System_MonoTODOAttribute,__ZL84mscorlib_System_Array_m_InternalArray__set_Item_System_Core_System_MonoTODOAttributeP21mscorlib_System_ArrayiP36System_Core_System_MonoTODOAttribute,__ZL83mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_AttributeP21mscorlib_System_ArrayP29mscorlib_System_Attribute_arri,__ZL71mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_AttributeP21mscorlib_System_ArrayiP25mscorlib_System_Attribute,__ZL73mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_AttributeP21mscorlib_System_ArrayiP25mscorlib_System_Attribute,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayP41mscorlib_System_SerializableAttribute_arri,__ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayiP37mscorlib_System_SerializableAttribute,__ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_SerializableAttributeP21mscorlib_System_ArrayiP37mscorlib_System_SerializableAttribute,__ZL97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayP43mscorlib_System_AttributeUsageAttribute_arri,__ZL85mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayiP39mscorlib_System_AttributeUsageAttribute
  ,__ZL87mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_ArrayiP39mscorlib_System_AttributeUsageAttribute,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_arri,__ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__Z76mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_Int64P21mscorlib_System_Arrayx,__Z79mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Int64P21mscorlib_System_ArrayP25mscorlib_System_Int64_arri,__Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_UInt32P21mscorlib_System_ArrayP26mscorlib_System_UInt32_arri,__Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_UInt32P21mscorlib_System_Arrayij,__Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_UInt32P21mscorlib_System_Arrayij,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayP41mscorlib_System_CLSCompliantAttribute_arri,__ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayiP37mscorlib_System_CLSCompliantAttribute,__ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_ArrayiP37mscorlib_System_CLSCompliantAttribute,__Z77mscorlib_System_Array_m_InternalArray__ICollection_Add_mscorlib_System_UInt64P21mscorlib_System_Arrayy,__Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_UInt64P21mscorlib_System_ArrayP26mscorlib_System_UInt64_arri,__Z79mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_SByteP21mscorlib_System_ArrayP25mscorlib_System_SByte_arri,__Z67mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_SByteP21mscorlib_System_Arrayia,__Z69mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_SByteP21mscorlib_System_Arrayia,__Z79mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Int16P21mscorlib_System_ArrayP25mscorlib_System_Int16_arri,__Z67mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Int16P21mscorlib_System_Arrayis,__Z69mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Int16P21mscorlib_System_Arrayis,__Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_UInt16P21mscorlib_System_ArrayP26mscorlib_System_UInt16_arri,__Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_UInt16P21mscorlib_System_Arrayit,__Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_UInt16P21mscorlib_System_Arrayit,__Z80mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DoubleP21mscorlib_System_ArrayP26mscorlib_System_Double_arri,__Z81mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_BooleanP21mscorlib_System_ArrayP27mscorlib_System_Boolean_arri,__Z69mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_BooleanP21mscorlib_System_Arrayib,__Z71mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_BooleanP21mscorlib_System_Arrayib,__Z81mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_UIntPtrP21mscorlib_System_ArrayP27mscorlib_System_UIntPtr_arri,__Z69mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_UIntPtrP21mscorlib_System_Arrayi23mscorlib_System_UIntPtr,__Z71mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_UIntPtrP21mscorlib_System_Arrayi23mscorlib_System_UIntPtr
  ,__ZL82mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DelegateP21mscorlib_System_ArrayP28mscorlib_System_Delegate_arri,__ZL70mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DelegateP21mscorlib_System_ArrayiP24mscorlib_System_Delegate,__ZL72mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DelegateP21mscorlib_System_ArrayiP24mscorlib_System_Delegate,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayP41mscorlib_System_Reflection_MethodInfo_arri,__ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayiP37mscorlib_System_Reflection_MethodInfo,__ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_ArrayiP37mscorlib_System_Reflection_MethodInfo,__ZL100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayP46mscorlib_System_Reflection_ConstructorInfo_arri,__ZL88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayiP42mscorlib_System_Reflection_ConstructorInfo,__ZL90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_ArrayiP42mscorlib_System_Reflection_ConstructorInfo,__ZL93mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayP39mscorlib_System_ParamArrayAttribute_arri,__ZL81mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayiP35mscorlib_System_ParamArrayAttribute,__ZL83mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ParamArrayAttributeP21mscorlib_System_ArrayiP35mscorlib_System_ParamArrayAttribute,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_InteropServices_OutAttribute_arri,__ZL98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayiP52mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_ArrayiP52mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayP37mscorlib_System_ObsoleteAttribute_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayiP33mscorlib_System_ObsoleteAttribute,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ObsoleteAttributeP21mscorlib_System_ArrayiP33mscorlib_System_ObsoleteAttribute,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_DllImportAttribute_arri,__ZL104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_arri,__ZL104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayP55mscorlib_System_Runtime_InteropServices_InAttribute_arri,__ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Runtime_InteropServices_InAttribute,__ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Runtime_InteropServices_InAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_GuidAttribute_arri,__ZL99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Runtime_InteropServices_GuidAttribute
  ,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_ComImportAttribute_arri,__ZL104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayP61mscorlib_System_Runtime_InteropServices_OptionalAttribute_arri,__ZL103mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayiP57mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL105mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_ArrayiP57mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL125mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayP71mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_arri,__ZL113mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL115mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL126mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_arri,__ZL114mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayiP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL116mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_ArrayiP68mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL128mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayP74mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_arri,__ZL116mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayiP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL118mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_ArrayiP70mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayP55mscorlib_System_Diagnostics_DebuggerHiddenAttribute_arri,__ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_DefaultMemberAttribute_arri,__ZL95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayiP49mscorlib_System_Reflection_DefaultMemberAttribute,__ZL97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_ArrayiP49mscorlib_System_Reflection_DefaultMemberAttribute,__ZL123mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayP69mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_arri,__ZL111mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayiP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL113mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_ArrayiP65mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_arri,__ZL106mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayiP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL108mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_ArrayiP60mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL91mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayP37mscorlib_System_MonoTODOAttribute_arri,__ZL79mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayiP33mscorlib_System_MonoTODOAttribute,__ZL81mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_MonoTODOAttributeP21mscorlib_System_ArrayiP33mscorlib_System_MonoTODOAttribute
  ,__Z111mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Arrayi,__Z121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_ArrayP67mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_arri,__Z109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Arrayi63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__Z111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Arrayi63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayP53mscorlib_Mono_Globalization_Unicode_TailoringInfo_arri,__ZL95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayiP49mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_ArrayiP49mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayP51mscorlib_Mono_Globalization_Unicode_Contraction_arri,__ZL93mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayiP47mscorlib_Mono_Globalization_Unicode_Contraction,__ZL95mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_ArrayiP47mscorlib_Mono_Globalization_Unicode_Contraction,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayP49mscorlib_Mono_Globalization_Unicode_Level2Map_arri,__ZL91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayiP45mscorlib_Mono_Globalization_Unicode_Level2Map,__ZL93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_ArrayiP45mscorlib_Mono_Globalization_Unicode_Level2Map,__Z121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_ArrayP67mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_arri,__Z109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayii,__Z111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Arrayii,__Z90mscorlib_System_Array_m_InternalArray__get_Item_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Arrayi,__Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_ArrayP46mscorlib_System_Collections_Hashtable_Slot_arri,__Z88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Arrayi42mscorlib_System_Collections_Hashtable_Slot,__Z90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Arrayi42mscorlib_System_Collections_Hashtable_Slot,__Z110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_ArrayP56mscorlib_System_Collections_Hashtable_EnumeratorMode_arri,__Z98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayii,__Z100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Arrayii,__Z120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_ArrayP66mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_arri,__Z108mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayii,__Z110mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Arrayii,__Z127mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_ArrayP73mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_arri,__Z115mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayii,__Z117mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Arrayii,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayP51mscorlib_System_Diagnostics_DebuggableAttribute_arri
  ,__ZL93mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayiP47mscorlib_System_Diagnostics_DebuggableAttribute,__ZL95mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_ArrayiP47mscorlib_System_Diagnostics_DebuggableAttribute,__Z120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_ArrayP66mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_arri,__Z108mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayii,__Z110mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Arrayii,__ZL110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayP56mscorlib_System_Diagnostics_DebuggerDisplayAttribute_arri,__ZL98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayiP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_ArrayiP52mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayP60mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_arri,__ZL102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayP58mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_arri,__ZL100mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayiP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL102mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_ArrayiP54mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayP42mscorlib_System_Diagnostics_StackFrame_arri,__ZL84mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayiP38mscorlib_System_Diagnostics_StackFrame,__ZL86mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_ArrayiP38mscorlib_System_Diagnostics_StackFrame,__Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_ArrayP48mscorlib_System_Globalization_CompareOptions_arri,__Z90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayii,__Z92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Arrayii,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayP42mscorlib_System_Globalization_Calendar_arri,__ZL84mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayiP38mscorlib_System_Globalization_Calendar,__ZL86mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_CalendarP21mscorlib_System_ArrayiP38mscorlib_System_Globalization_Calendar,__Z107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_ArrayP53mscorlib_System_Globalization_DateTimeFormatFlags_arri,__Z95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayii,__Z97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Arrayii,__Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_ArrayP48mscorlib_System_Globalization_DateTimeStyles_arri,__Z90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayii,__Z92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Arrayii,__Z110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_ArrayP56mscorlib_System_Globalization_GregorianCalendarTypes_arri
  ,__Z98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayii,__Z100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Arrayii,__Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_ArrayP46mscorlib_System_Globalization_NumberStyles_arri,__Z88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayii,__Z90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Arrayii,__Z103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_ArrayP49mscorlib_System_Globalization_UnicodeCategory_arri,__Z91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayii,__Z93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Arrayii,__ZL106mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayP52mscorlib_System_Reflection_Emit_ParameterBuilder_arri,__ZL94mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayiP48mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL96mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_ArrayiP48mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayP63mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_arri,__ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayiP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_ArrayiP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayP49mscorlib_System_Reflection_Emit_MethodBuilder_arri,__ZL91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayiP45mscorlib_System_Reflection_Emit_MethodBuilder,__ZL93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_ArrayiP45mscorlib_System_Reflection_Emit_MethodBuilder,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayP54mscorlib_System_Reflection_Emit_ConstructorBuilder_arri,__ZL96mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayiP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL98mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_ArrayiP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayP51mscorlib_System_Reflection_Emit_PropertyBuilder_arri,__ZL93mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayiP47mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL95mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_ArrayiP47mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayP48mscorlib_System_Reflection_Emit_FieldBuilder_arri,__ZL90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayiP44mscorlib_System_Reflection_Emit_FieldBuilder,__ZL92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_ArrayiP44mscorlib_System_Reflection_Emit_FieldBuilder,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayP41mscorlib_System_Reflection_MethodBase_arri,__ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayiP37mscorlib_System_Reflection_MethodBase,__ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_ArrayiP37mscorlib_System_Reflection_MethodBase,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyCompanyAttribute_arri
  ,__ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL115mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayP61mscorlib_System_Reflection_AssemblyConfigurationAttribute_arri,__ZL103mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayiP57mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL105mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_ArrayiP57mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyCopyrightAttribute_arri,__ZL99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayP60mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_arri,__ZL102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute,__ZL104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Reflection_AssemblyDefaultAliasAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyDelaySignAttribute_arri,__ZL99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Reflection_AssemblyDescriptionAttribute_arri,__ZL101mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL103mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayP59mscorlib_System_Reflection_AssemblyFileVersionAttribute_arri,__ZL101mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL103mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayP68mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_arri,__ZL110mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayiP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL112mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_ArrayiP64mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyKeyFileAttribute_arri,__ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyKeyNameAttribute_arri,__ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyKeyNameAttribute,__ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyKeyNameAttribute,__Z102mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_ArrayP48mscorlib_System_Reflection_AssemblyNameFlags_arri
  ,__Z90mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayii,__Z92mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Arrayii,__ZL109mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayP55mscorlib_System_Reflection_AssemblyProductAttribute_arri,__ZL97mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyProductAttribute,__ZL99mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_ArrayiP51mscorlib_System_Reflection_AssemblyProductAttribute,__ZL107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayP53mscorlib_System_Reflection_AssemblyTitleAttribute_arri,__ZL95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayiP49mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_ArrayiP49mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayP57mscorlib_System_Reflection_AssemblyTrademarkAttribute_arri,__ZL99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyTrademarkAttribute,__ZL101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_ArrayiP53mscorlib_System_Reflection_AssemblyTrademarkAttribute,__Z97mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_ArrayP43mscorlib_System_Reflection_BindingFlags_arri,__Z85mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayii,__Z87mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Arrayii,__Z103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_ArrayP49mscorlib_System_Reflection_CallingConventions_arri,__Z91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayii,__Z93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Arrayii,__Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_ArrayP46mscorlib_System_Reflection_EventAttributes_arri,__Z88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayii,__Z90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Arrayii,__Z100mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_ArrayP46mscorlib_System_Reflection_FieldAttributes_arri,__Z88mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayii,__Z90mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Arrayii,__Z96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_ArrayP42mscorlib_System_Reflection_MemberTypes_arri,__Z84mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayii,__Z86mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Arrayii,__Z101mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_ArrayP47mscorlib_System_Reflection_MethodAttributes_arri,__Z89mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayii,__Z91mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Arrayii,__Z105mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_ArrayP51mscorlib_System_Reflection_MethodImplAttributes_arri
  ,__Z93mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayii,__Z95mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Arrayii,__Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_PInfoP21mscorlib_System_ArrayP36mscorlib_System_Reflection_PInfo_arri,__Z78mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayii,__Z80mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_PInfoP21mscorlib_System_Arrayii,__Z104mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_ArrayP50mscorlib_System_Reflection_ParameterAttributes_arri,__Z92mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayii,__Z94mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Arrayii,__Z103mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_ArrayP49mscorlib_System_Reflection_PropertyAttributes_arri,__Z91mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayii,__Z93mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Arrayii,__Z99mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_ArrayP45mscorlib_System_Reflection_TypeAttributes_arri,__Z87mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayii,__Z89mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Arrayii,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayP63mscorlib_System_Resources_NeutralResourcesLanguageAttribute_arri,__ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayP63mscorlib_System_Resources_SatelliteContractVersionAttribute_arri,__ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Resources_SatelliteContractVersionAttribute,__ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_ArrayiP59mscorlib_System_Resources_SatelliteContractVersionAttribute,__Z121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_ArrayP67mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_arri,__Z109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayii,__Z111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Arrayii,__ZL130mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayP76mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_arri,__ZL118mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayiP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL120mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_ArrayiP72mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL125mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayP71mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_arri,__ZL113mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__ZL115mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__Z107mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_ArrayP53mscorlib_System_Runtime_CompilerServices_LoadHint_arri
  ,__Z95mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayii,__Z97mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Arrayii,__ZL122mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayP68mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_arri,__ZL110mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayiP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__ZL112mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_ArrayiP64mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__Z106mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_ArrayP52mscorlib_System_Runtime_ConstrainedExecution_Cer_arri,__Z94mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayii,__Z96mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Arrayii,__Z114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_ArrayP60mscorlib_System_Runtime_ConstrainedExecution_Consistency_arri,__Z102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayii,__Z104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Arrayii,__ZL131mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayP77mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_arri,__ZL119mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayiP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL121mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_ArrayiP73mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_arri,__ZL109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__ZL111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__Z116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_InteropServices_ClassInterfaceType_arri,__Z104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayii,__Z106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Arrayii,__ZL126mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayP72mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_arri,__ZL114mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayiP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__ZL116mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_ArrayiP68mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__Z114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_InteropServices_ComInterfaceType_arri,__Z102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayii,__Z104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Arrayii,__ZL120mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayP66mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_arri,__ZL108mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayiP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL110mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_ArrayiP62mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL118mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayP64mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_arri
  ,__ZL106mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayiP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL108mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_ArrayiP60mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL125mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayP71mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_arri,__ZL113mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL115mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_ArrayiP67mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayP67mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_arri,__ZL109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__ZL111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__Z111mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_ArrayP57mscorlib_System_Runtime_InteropServices_UnmanagedType_arri,__Z99mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayii,__Z101mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Arrayii,__ZL114mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayP60mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_arri,__ZL102mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL104mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_ArrayiP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL116mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayP62mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_arri,__ZL104mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__ZL106mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_ArrayiP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__Z112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_ArrayP58mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_arri,__Z100mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayih,__Z102mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Arrayih,__ZL113mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayP59mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_arri,__ZL101mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL103mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_ArrayiP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL117mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayP63mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_arri,__ZL105mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayiP22mscorlib_System_Object,__ZL107mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_ArrayiP22mscorlib_System_Object,__Z110mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_ArrayP56mscorlib_System_Runtime_Remoting_WellKnownObjectMode_arri,__Z98mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayii,__Z100mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Arrayii,__Z129mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_ArrayP75mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_arri
  ,__Z117mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayii,__Z119mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Arrayii,__Z125mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_ArrayP71mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_arri,__Z113mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayii,__Z115mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Arrayii,__Z122mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_ArrayP68mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_arri,__Z110mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayii,__Z112mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Arrayii,__Z118mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_ArrayP64mscorlib_System_Runtime_Serialization_StreamingContextStates_arri,__Z106mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayii,__Z108mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Arrayii,__Z108mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_ArrayP54mscorlib_System_Security_Principal_PrincipalPolicy_arri,__Z96mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayii,__Z98mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Arrayii,__ZL112mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayP58mscorlib_System_Security_SecuritySafeCriticalAttribute_arri,__ZL100mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayiP54mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL102mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_ArrayiP54mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL121mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayP67mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_arri,__ZL109mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL111mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_ArrayiP63mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL108mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayP54mscorlib_System_Security_UnverifiableCodeAttribute_arri,__ZL96mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayiP50mscorlib_System_Security_UnverifiableCodeAttribute,__ZL98mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_ArrayiP50mscorlib_System_Security_UnverifiableCodeAttribute,__Z95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_Threading_ThreadStateP21mscorlib_System_ArrayP41mscorlib_System_Threading_ThreadState_arri,__Z83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayii,__Z85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Arrayii,__Z90mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_AttributeTargetsP21mscorlib_System_ArrayP36mscorlib_System_AttributeTargets_arri,__Z78mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayii,__Z80mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_AttributeTargetsP21mscorlib_System_Arrayii,__Z88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DateTime_WhichP21mscorlib_System_ArrayP34mscorlib_System_DateTime_Which_arri
  ,__Z76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayii,__Z78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DateTime_WhichP21mscorlib_System_Arrayii,__Z86mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DateTimeKindP21mscorlib_System_ArrayP32mscorlib_System_DateTimeKind_arri,__Z74mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayii,__Z76mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DateTimeKindP21mscorlib_System_Arrayii,__Z83mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_DayOfWeekP21mscorlib_System_ArrayP29mscorlib_System_DayOfWeek_arri,__Z71mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayii,__Z73mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DayOfWeekP21mscorlib_System_Arrayii,__ZL88mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayP34mscorlib_System_FlagsAttribute_arri,__ZL76mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayiP30mscorlib_System_FlagsAttribute,__ZL78mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_FlagsAttributeP21mscorlib_System_ArrayiP30mscorlib_System_FlagsAttribute,__Z92mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_LoaderOptimizationP21mscorlib_System_ArrayP38mscorlib_System_LoaderOptimization_arri,__Z80mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayii,__Z82mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_LoaderOptimizationP21mscorlib_System_Arrayii,__ZL82mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_MonoTypeP21mscorlib_System_ArrayP28mscorlib_System_MonoType_arri,__ZL70mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_MonoTypeP21mscorlib_System_ArrayiP24mscorlib_System_MonoType,__ZL72mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_MonoTypeP21mscorlib_System_ArrayiP24mscorlib_System_MonoType,__ZL96mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayP42mscorlib_System_NonSerializedAttribute_arri,__ZL84mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayiP38mscorlib_System_NonSerializedAttribute,__ZL86mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_NonSerializedAttributeP21mscorlib_System_ArrayiP38mscorlib_System_NonSerializedAttribute,__Z84mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_PlatformIDP21mscorlib_System_ArrayP30mscorlib_System_PlatformID_arri,__Z72mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_PlatformIDP21mscorlib_System_Arrayii,__Z74mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_PlatformIDP21mscorlib_System_Arrayii,__ZL95mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayP41mscorlib_System_ThreadStaticAttribute_arri,__ZL83mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayiP37mscorlib_System_ThreadStaticAttribute,__ZL85mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_ArrayiP37mscorlib_System_ThreadStaticAttribute,__Z82mscorlib_System_Array_m_InternalArray__ICollection_CopyTo_mscorlib_System_TypeCodeP21mscorlib_System_ArrayP28mscorlib_System_TypeCode_arri,__Z70mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_TypeCodeP21mscorlib_System_Arrayii,__Z72mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_TypeCodeP21mscorlib_System_Arrayii,__ZNKSt3__114error_category23default_error_conditionEi
  ,__ZNKSt3__119__iostream_category7messageEi,__ZNSt3__16__treeIP8TypeInfoNS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_,__ZNSt3__16__treeIhNS_4lessIhEENS_9allocatorIhEEE15__insert_uniqueERKh,__ZNSt3__112__hash_tableINS_17__hash_value_typeIP12PropertyInfoP24Il2CppReflectionPropertyEENS_22__unordered_map_hasherIS3_S6_N6il2cpp6icalls8mscorlib6System22Il2CppPropertyInfoHashELb1EEENS_21__unordered_map_equalIS3_S6_NSB_25Il2CppPropertyInfoCompareELb1EEENS8_2gc9AllocatorIS6_EEE20__node_insert_uniqueEPNS_11__hash_nodeIS6_PvEE,__ZN6il2cpp2vm14TypeNameParserC2ERNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEERNS0_17TypeNameParseInfoE,__ZN6il2cpp2os5EventC2Ebb,__ZN6il2cpp2os9SemaphoreC2Eii,__ZN6il2cpp2os9EventImplC2Ebb,___cxa_throw__wrapper,__ZN6il2cpp6icalls8mscorlib6System9AppDomain7SetDataEP15Il2CppAppDomainP12Il2CppStringP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System11ArgIterator67IntGetNextArg_mscorlib_System_TypedReference_mscorlib_System_IntPtrEP27mscorlib_System_ArgIterator12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System11ArgIterator5SetupEP27mscorlib_System_ArgIterator12Il2CppIntPtrS6_,__ZN6il2cpp6icalls8mscorlib6System5Array13ClearInternalEP11Il2CppArrayii,__ZN6il2cpp6icalls8mscorlib6System5Array8SetValueEP11Il2CppArrayP12Il2CppObjectS5_,__ZN6il2cpp6icalls8mscorlib6System5Array12SetValueImplEP11Il2CppArrayP12Il2CppObjecti,__ZN6il2cpp6icalls8mscorlib6System6Buffer15SetByteInternalEP11Il2CppArrayii,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder13RegisterTokenEP29Il2CppReflectionModuleBuilderP12Il2CppObjecti,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module9GetPEKindE12Il2CppIntPtrPiS6_,__ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField16SetValueInternalEP21Il2CppReflectionFieldP12Il2CppObjectS8_,__ZN6il2cpp6icalls8mscorlib6System10Reflection16MonoPropertyInfo17get_property_infoEP24Il2CppReflectionPropertyP18Il2CppPropertyInfoNS3_5PInfoE,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14StructureToPtrEP12Il2CppObject12Il2CppIntPtrb,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal9WriteByteE12Il2CppIntPtrih,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10WriteInt16E12Il2CppIntPtris,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal10WriteInt32E12Il2CppIntPtrii,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal11WriteIntPtrE12Il2CppIntPtriS6_,__ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting9Messaging17MonoMethodMessage11InitMessageEP19Il2CppMethodMessageP22Il2CppReflectionMethodP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System4Type10GetPackingEP20Il2CppReflectionTypePiS6_,__ZNSt3__112__hash_tableINS_17__hash_value_typeIP14ReflectedEntryPvEENS_22__unordered_map_hasherIS3_S5_19Il2CppReflectedHashLb1EEENS_21__unordered_map_equalIS3_S5_22Il2CppReflectedCompareLb1EEEN6il2cpp2gc9AllocatorIS5_EEE20__node_insert_uniqueEPNS_11__hash_nodeIS5_S4_EE,__ZNSt3__112__hash_tableINS_17__hash_value_typeIPK10Il2CppTypeP20Il2CppReflectionTypeEENS_22__unordered_map_hasherIS4_S7_N6il2cpp2vm14Il2CppTypeHashELb1EEENS_21__unordered_map_equalIS4_S7_NSA_17Il2CppTypeCompareELb1EEENS_9allocatorIS7_EEE20__node_insert_uniqueEPNS_11__hash_nodeIS7_PvEE,__ZNSt3__112__hash_tableINS_17__hash_value_typeIN6il2cpp2vm14InternedStringEP12Il2CppStringEENS_22__unordered_map_hasherIS4_S7_NS3_18InternedStringHashELb1EEENS_21__unordered_map_equalIS4_S7_NS3_21InternedStringCompareELb1EEENS_9allocatorIS7_EEE20__node_insert_uniqueEPNS_11__hash_nodeIS7_PvEE
  ,_png_default_write_data,__ZN5physx20solveExtContactBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx15solveExt1DBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx28solveExtContactConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx23solveExt1DConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx27solveExtContactCoulombBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx35solveExtContactCoulombConcludeBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__ZN5physx21solveExtFrictionBlockEPKNS_23PxcSolverConstraintDescEjRNS_16PxcSolverContextE,__Z40setPxVehicleWheelsSimData_SuspensionDataPN5physx22PxVehicleWheelsSimDataEjNS_23PxVehicleSuspensionDataE,__Z40getPxVehicleWheelsSimData_SuspensionDataPKN5physx22PxVehicleWheelsSimDataEj,__Z35setPxVehicleWheelsSimData_WheelDataPN5physx22PxVehicleWheelsSimDataEjNS_18PxVehicleWheelDataE,__Z35getPxVehicleWheelsSimData_WheelDataPKN5physx22PxVehicleWheelsSimDataEj,__Z34setPxVehicleWheelsSimData_TireDataPN5physx22PxVehicleWheelsSimDataEjNS_17PxVehicleTireDataE,__Z34getPxVehicleWheelsSimData_TireDataPKN5physx22PxVehicleWheelsSimDataEj,__Z45setPxVehicleWheelsSimData_SuspTravelDirectionPN5physx22PxVehicleWheelsSimDataEjNS_6PxVec3E,__Z45getPxVehicleWheelsSimData_SuspTravelDirectionPKN5physx22PxVehicleWheelsSimDataEj,__Z49setPxVehicleWheelsSimData_SuspForceAppPointOffsetPN5physx22PxVehicleWheelsSimDataEjNS_6PxVec3E,__Z49getPxVehicleWheelsSimData_SuspForceAppPointOffsetPKN5physx22PxVehicleWheelsSimDataEj,__Z49setPxVehicleWheelsSimData_TireForceAppPointOffsetPN5physx22PxVehicleWheelsSimDataEjNS_6PxVec3E,__Z49getPxVehicleWheelsSimData_TireForceAppPointOffsetPKN5physx22PxVehicleWheelsSimDataEj,__Z43setPxVehicleWheelsSimData_WheelCentreOffsetPN5physx22PxVehicleWheelsSimDataEjNS_6PxVec3E,__Z43getPxVehicleWheelsSimData_WheelCentreOffsetPKN5physx22PxVehicleWheelsSimDataEj,__Z43setPxVehicleWheelsSimData_WheelShapeMappingPN5physx22PxVehicleWheelsSimDataEji,__Z46setPxVehicleWheelsSimData_SceneQueryFilterDataPN5physx22PxVehicleWheelsSimDataEjNS_12PxFilterDataE,__Z46getPxVehicleWheelsSimData_SceneQueryFilterDataPKN5physx22PxVehicleWheelsSimDataEj,__ZN14StackAllocatorC2EjPKc,__ZN13MemoryManager10DeallocateEPv10MemLabelId,__Z12FormatStringINSt3__112basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEET_PKcz,__Z6FormatPKcz,__ZNSt3__16__treeINS_12__value_typeIPv17ExternalAllocInfoEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier51ELi16EEE15__insert_uniqueERKS4_
  ,__ZN6ObjectC2E10MemLabelId18ObjectCreationMode,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__112basic_stringIcNS1_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14ConstantString6assignEPKc10MemLabelId,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN5Unity10GameObject32ActivateAwakeRecursivelyInternalENS_19DeactivateOperationER18AwakeFromLoadQueue,__ZN18AwakeFromLoadQueue13AwakeFromLoadE17AwakeFromLoadModeb,__ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_,__ZN6Object21FindAllDerivedClassesEiPNSt3__16vectorIiNS0_9allocatorIiEEEEb,__ZN5Unity10GameObjectC2E10MemLabelId18ObjectCreationMode,__ZN10vector_mapIiiNSt3__14lessIiEENS0_9allocatorINS0_4pairIiiEEEEE13push_unsortedERKiS9_,__ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_,__ZNSt3__16__treeIP11GameManagerNS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_,__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE17MessageIdentifierEENS_19__map_value_compareIS7_S9_NS_4lessIS7_EELb1EEENS5_IS9_EEE15__insert_uniqueERKS9_,__ZNSt3__114__split_bufferI17SortingLayerEntryRNS_9allocatorIS1_EEE18__construct_at_endINS_13move_iteratorIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_,__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE16__construct_nodeERKS8_,__ZNSt3__16__treeINS_12__value_typeIjNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_19__map_value_compareIjS8_NS_4lessIjEELb1EEE13stl_allocatorIS8_L18MemLabelIdentifier1ELi16EEE15__insert_uniqueERKS8_,__ZN10TagManager11RegisterTagEjRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN10TagManager13RegisterLayerEjRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN10TagManagerC2E10MemLabelId18ObjectCreationMode,__ZN12CachedWriter16UpdateWriteCacheEPKvj,__ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags,__ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SortingLayerEntryNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17SortingLayerEntryNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_
  ,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17SortingLayerEntryNS2_9allocatorIS4_EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8UnityStrNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI17SortingLayerEntryNS1_9allocatorIS3_EEEEEEvRT_17TransferMetaFlags,__ZN13ProxyTransfer32TransferSTLStyleArrayWithElementI17SortingLayerEntryEEvRT_17TransferMetaFlags,__ZNSt3__16__sortIRPFbP10GUIElementS2_EPS2_EEvT0_S7_T_,__ZNK6Camera13GetCameraRectEb,__ZN5Unity9ComponentC2E10MemLabelId18ObjectCreationMode,__ZNSt3__16vectorIP10GUIElement13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE18__construct_at_endINS_21__tree_const_iteratorI4PPtrIS1_EPNS_11__tree_nodeISA_PvEEiEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESH_SH_,__ZN15SHConstantCacheC2ER13BatchRendererR15RenderLoopStats,__ZN20ReflectionProbeCacheC2ER13BatchRendererR15RenderLoopStats,__ZN15LightmapSTCacheC2ER13BatchRendererR15RenderLoopStats,__Z16ClearScissorRectbRK5RectTIiER9GfxDevice,__ZN19RenderEventsContext21ExecuteCommandBuffersE15RenderEventTypeRN9ShaderLab17ShaderPassContextE,__ZN15LightmapSTCache18ApplyFixedFunctionER12BaseRendererR9GfxDevice,__ZNK6Camera21ViewportToCameraPointERK8Vector3f,__Z23AddRenderLoopTempBufferP10RenderLoop24BuiltinRenderTextureTypeP13RenderTexture,__ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_S6_,__Z18RenderImageFiltersR10RenderLoopP13RenderTextureb,__ZL27PerformRenderingReplacementR6CameraRK10Matrix4x4fRNSt3__16vectorI17RODataReplacement13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEEERN9ShaderLab17ShaderPassContextE,__ZZN6Camera15InitializeClassEvEN36FunctorImpl_Camera_kTransformChanged4CallEPviR11MessageData,__ZNSt3__16vectorI13dynamic_arrayIhLj1EE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEjRKS2_,__ZNSt3__16vectorI13dynamic_arrayIfLj4EE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE8__appendEjRKS2_,__ZN6Camera10CustomCullERK23CameraCullingParametersR11CullResults,__ZN6CameraC2E10MemLabelId18ObjectCreationMode,__Z20AddDirectionalLightsPPK5LightjR12ActiveLights,__Z28CullDirectionalShadowCastersiRK22SceneCullingParametersR11CullResults,__ZNSt3__16vectorIfNS_9allocatorIfEEE6assignIPfEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIfNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_,__ZN17GlobalGameManagerC2E10MemLabelId18ObjectCreationMode
  ,__ZNSt3__16vectorI4PPtrI23ShaderVariantCollectionE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_,__ZNSt3__16vectorI4PPtrI6ShaderE13stl_allocatorIS3_L18MemLabelIdentifier44ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_,__ZN16LevelGameManagerC2E10MemLabelId18ObjectCreationMode,__ZN5Unity8Material10SetTextureEN9ShaderLab16FastPropertyNameEP7Texture,__ZZN5Light15InitializeClassEvEN35FunctorImpl_Light_kTransformChanged4CallEPviR11MessageData,__ZN5LightC2E10MemLabelId18ObjectCreationMode,__ZN11NamedObjectC2E10MemLabelId18ObjectCreationMode,__ZN16ReflectionProbes22ForceProbeToUseTextureER15ReflectionProbeP7Texture,__ZN16ReflectionProbes11UpdateProbeER15ReflectionProbej,__Z22MultiplyMatrices4x4REFPK10Matrix4x4fS1_PS_,__ZN9ShaderLab13PropertySheet9SetVectorERKNS_16FastPropertyNameERK8Vector4f,__ZNK9Transform18TransformDirectionERK8Vector3f,__Z7AddAABBRK10MinMaxAABBS1_,__Z40CalculateBoundingSphereFromFrustumPointsPK8Vector3fRS_Rf,__ZN5Unity8Material8SetColorEN9ShaderLab16FastPropertyNameERK10ColorRGBAf,__ZN9ShaderLab13PropertySheet9SetMatrixERKNS_16FastPropertyNameERK10Matrix4x4f,__ZN19SkinnedMeshRenderer24AnimatorModifiedCallbackEPvS0_i,__ZN15PackedIntVector8PackIntsIjEEvPT_i,__ZN16PackedQuatVector9PackQuatsEP11Quaternionfi,__ZN4MeshC2E10MemLabelId18ObjectCreationMode,__ZN14CompressedMesh8CompressERK4MeshRK21CompressedMeshQuality,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayIhLj1EEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIhNS_9allocatorIhEEE6assignINS_11__wrap_iterIPhEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_,__ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEE6assignINS_11__wrap_iterIPhEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI17BlendShapeChannelNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI7SubMesh13stl_allocatorIS1_L18MemLabelIdentifier10ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags
  ,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayIhLj1EEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI8Vector3fLj4EEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI8Vector2fLj4EEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI8Vector4fLj4EEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11ColorRGBA32Lj4EEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier8ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI13BoneInfluenceLj16EEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayIhLj1EEEEvRT_17TransferMetaFlags,__ZZN10MeshFilter15InitializeClassEvEN39FunctorImpl_MeshFilter_kDidAddComponent4CallEPviR11MessageData,__ZZN12MeshRenderer15InitializeClassEvEN41FunctorImpl_MeshRenderer_kDidModifyBounds4CallEPviR11MessageData,__ZZN12MeshRenderer15InitializeClassEvEN39FunctorImpl_MeshRenderer_kDidDeleteMesh4CallE_0PviR11MessageData,__ZZN12MeshRenderer15InitializeClassEvEN39FunctorImpl_MeshRenderer_kDidModifyMesh4CallE_1PviR11MessageData,__ZNSt3__16__treeINS_12__value_typeI18VertexChannelsInfo16MeshVertexFormatEENS_19__map_value_compareIS2_S4_NS_4lessIS2_EELb1EEENS_9allocatorIS4_EEE16__construct_nodeERKS4_,__ZN14SafeBinaryRead21TransferSTLStyleArrayI13dynamic_arrayI11ChannelInfoLj4EEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11ChannelInfoLj4EEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI13dynamic_arrayI11ChannelInfoLj4EEEEvRT_17TransferMetaFlags,__ZNSt3__16__treeINS_12__value_typeIiN21BillboardBatchManager18BillboardAssetDataEEENS_19__map_value_compareIiS4_NS_4lessIiEELb1EEE13stl_allocatorIS4_L18MemLabelIdentifier55ELi16EEE15__insert_uniqueERKS4_,__ZN5Unity8MaterialC2E10MemLabelId18ObjectCreationMode,__Z6AppendPKcS0_,__ZN17RemapPPtrTransferC2E24TransferInstructionFlagsb,__ZN14ImageReference9BlitImageERKS_NS_8BlitModeE,__ZN18GlslGpuProgramGLESC2ERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER22CreateGpuProgramOutput,__ZN9Scripting12LogExceptionEP18ScriptingExceptioniRKNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,__ZN16ScriptingManagerC2E10MemLabelId18ObjectCreationMode,__ZN9Texture2DC2E10MemLabelId18ObjectCreationMode,__ZNSt3__16vectorI4PPtrI9Texture2DENS_9allocatorIS3_EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZN9Texture3DC2E10MemLabelId18ObjectCreationMode,__ZN7CubemapC2E10MemLabelId18ObjectCreationMode,__ZN6prcore7Surface9BlitImageERKS0_NS0_8BlitModeE,__ZL20PngWriteToMemoryFuncP14png_struct_defPhj
  ,__ZN16LightmapSettingsC2E10MemLabelId18ObjectCreationMode,__ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE6assignIPS2_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_,__ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZNSt3__16vectorIN15QualitySettings14QualitySettingENS_9allocatorIS2_EEE18__construct_at_endINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_,__ZN13RenderTextureC2E10MemLabelId18ObjectCreationMode,__ZZN8Renderer15InitializeClassEvEN38FunctorImpl_Renderer_kTransformChanged4CallEPviR11MessageData,__ZZN8Renderer15InitializeClassEvEN34FunctorImpl_Renderer_kLayerChanged4CallE_0PviR11MessageData,__ZN9TransformC2E10MemLabelId18ObjectCreationMode,__Z14PadImageBorderR14ImageReferenceii,__ZN12CachedReader15UpdateReadCacheEPvj,__ZN7TextureC2E10MemLabelId18ObjectCreationMode,__ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE6assignIPjEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS8_E9referenceEEE5valueEvE4typeES8_S8_,__ZNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPjEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI8UnityStrNS_9allocatorIS1_EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_,__ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES8_S8_,__ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI17SubstanceEnumItemNS_9allocatorIS1_EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI14SubstanceInputNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI4PPtrI17ProceduralTextureENS_9allocatorIS3_EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZN10GUIManager10DoGUIEventER10InputEventb,__ZN5IMGUI12BeginWindowsER8GUIStatebb,__ZN8GUIState18CycleKeyboardFocusERNSt3__16vectorIP6IDListNS0_9allocatorIS3_EEEEb,__ZN12GUIClipState9SetMatrixER10InputEventRK10Matrix4x4f,__ZN12InputManagerC2E10MemLabelId18ObjectCreationMode,__ZN14dynamic_bitset6resizeEjb,__ZN9InputAxis10MakeButtonEii,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI9InputAxisNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI8UnityStrEEvRT_17TransferMetaFlags,__ZN11TimeManagerC2E10MemLabelId18ObjectCreationMode
  ,__ZN11AssetBundleC2E10MemLabelId18ObjectCreationMode,__ZNSt3__16vectorI14ConstantStringNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN14SafeBinaryRead19TransferSTLStyleMapINSt3__18multimapI8UnityStr4PPtrI6ObjectENS1_4lessIS3_EENS1_9allocatorINS1_4pairIKS3_S6_EEEEEEEEvRT_17TransferMetaFlags,__ZN18AssetBundleManager20SortPreloadDataArrayER13dynamic_arrayINS_11PreloadDataELj8EERS0_IiLj4EE,__ZNSt3__16__treeIiNS_4lessIiEENS_9allocatorIiEEE15__insert_uniqueERKi,__ZNSt3__1plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_SB_,__ZN13BuildSettingsC2E10MemLabelId18ObjectCreationMode,__Z14AppendPathNameRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_,__Z21GetCachingManagerPathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEb,__ZNSt3__16__treeIN5Cache10CachedFileENS_4lessIS2_EENS_9allocatorIS2_EEE14__insert_multiERKS2_,__ZN5Cache10AddToCacheERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEi,__Z6AppendRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKc,__ZN5Unity10GameObject14SendMessageAnyERK17MessageIdentifierR11MessageData,__ZN15dense_hashtableINSt3__14pairIKiiEEi21InstanceIDHashFunctorN14dense_hash_mapIiiS4_NS0_8equal_toIiEE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE9SelectKeyES7_SA_E12resize_deltaEjj,__ZL30RegisterFilteredObjectCallbackPPviS_,__ZN17PersistentManager12SetPathRemapERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES8_,__ZN17PersistentManager12UnloadStreamERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEb,__ZN14PlayerSettingsC2E10MemLabelId18ObjectCreationMode,__ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEE6assignIPS3_EENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorI4PPtrI6ObjectENS_9allocatorIS3_EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZNSt3__16vectorIN15ResourceManager10DependencyENS_9allocatorIS2_EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__Z33EmitSerializationCommandsForFieldI19StreamedBinaryWriteILb0EEEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions,__Z35scripting_object_get_virtual_methodP15ScriptingObject21ScriptingMethodIl2Cpp,__Z33EmitSerializationCommandsForFieldI18StreamedBinaryReadILb0EEEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions,__Z33EmitSerializationCommandsForFieldI17RemapPPtrTransferEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions,__Z33EmitSerializationCommandsForFieldI13ProxyTransferEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions,__Z33EmitSerializationCommandsForFieldI14SafeBinaryReadEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions,__Z33EmitSerializationCommandsForFieldI18StreamedBinaryReadILb1EEEvR18TransferField_InfoR32SerializationCommandQueueBuilderRP20AllowNameConversions,__ZN27Converter_SimpleNativeClassI8GUIStyleE17NativeToScriptingERKS0_RP15ScriptingObject,__ZN27Converter_SimpleNativeClassI17AnimationCurveTplIfEE17NativeToScriptingERKS1_RP15ScriptingObject
  ,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8MonoPPtr13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI8MonoPPtr13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8GUIStyle13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI8GUIStyle13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI10RectOffset13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN12NativeBufferI27Converter_SimpleNativeClassI10RectOffsetEE19ProcessAfterReadingER9ArrayInfoP14ScriptingClass,__ZNSt3__16vectorI10RectOffset13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI11GradientNEW13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN12NativeBufferI27Converter_SimpleNativeClassI11GradientNEWEE19ProcessAfterReadingER9ArrayInfoP14ScriptingClass,__ZNSt3__16vectorI11GradientNEW13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8BitField13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI8BitField13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI11ColorRGBA3213stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI11ColorRGBA3213stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI10ColorRGBAf13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI10ColorRGBAf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI4AABB13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI4AABB13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI10Matrix4x4f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI10Matrix4x4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI11Quaternionf13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI11Quaternionf13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI5RectTIfE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI5RectTIfE13stl_allocatorIS2_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8Vector4f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI8Vector4f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8Vector2f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI8Vector2f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_
  ,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI8Vector3f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI8Vector3f13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPdEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIdNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPfEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIfNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPyEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIyNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPxEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIxNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPiEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIiNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPtEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleItNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPsEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIsNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPhEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIhNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPaEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIaNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorINS2_12basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES7_ISA_LS8_90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES4_IS7_LS5_90ELi16EEE6assignINS_11__wrap_iterIPS7_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS7_NS_15iterator_traitsISF_E9referenceEEE5valueEvE4typeESF_SF_,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8MonoPPtr13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8GUIStyle13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI10RectOffset13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI11GradientNEW13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8BitField13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI11ColorRGBA3213stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags
  ,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI10ColorRGBAf13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI4AABB13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI10Matrix4x4f13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI11Quaternionf13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI5RectTIfE13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8Vector4f13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8Vector2f13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI8Vector3f13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorINS1_12basic_stringIcNS1_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES6_IS9_LS7_90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN27Converter_SimpleNativeClassI17AnimationCurveTplIfEE17ScriptingToNativeERP15ScriptingObjectPS1_,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayI13dynamic_arrayI11KeyframeTplIfELj4EEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8MonoPPtr13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8GUIStyle13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI10RectOffset13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI11GradientNEW13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI17AnimationCurveTplIfE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8BitField13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI11ColorRGBA3213stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI10ColorRGBAf13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI4AABB13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags
  ,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI10Matrix4x4f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI11Quaternionf13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI5RectTIfE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector4f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector2f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector3f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorId13stl_allocatorIdL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIf13stl_allocatorIfL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIy13stl_allocatorIyL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIx13stl_allocatorIxL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIi13stl_allocatorIiL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIs13stl_allocatorIsL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIh13stl_allocatorIhL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIa13stl_allocatorIaL18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorINS2_12basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEES7_ISA_LS8_90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN16Converter_String17ScriptingToNativeEP15ScriptingObjectPNSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEEE,__ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector2f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN19StreamedBinaryWriteILb0EE21TransferSTLStyleArrayINSt3__16vectorI8Vector3f13stl_allocatorIS4_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN13MonoBehaviour19HandleNotificationsEPviR11MessageData,__ZN13MonoBehaviour17RenderImageFilterEPN5Unity9ComponentEP13RenderTextureS4_,__Z21FormatScriptTypeError14MonoScriptTypeRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZNSt3__1plIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEENS_12basic_stringIT_T0_T1_EERKSA_PKS7_,__ZNSt3__1plIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEEENS_12basic_stringIT_T0_T1_EERKSA_SC_,__ZN9TextAssetC2E10MemLabelId18ObjectCreationMode,__ZN14MessageHandler28MessageIDToMessageIdentifierEi,__ZN9Scripting34SetScriptingArrayObjectElementImplEP14ScriptingArrayiP15ScriptingObject,__ZNSt3__16vectorIP14ScriptingClassNS_9allocatorIS2_EEE8__appendEjRKS2_,__ZN13MonoBehaviourC2E10MemLabelId18ObjectCreationMode
  ,__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_NS_4lessIS7_EELb1EEENS5_IS8_EEE15__insert_uniqueERKS8_,__ZN17PersistentManagerC2Eii,__ZNSt3__16vectorIiNS_9allocatorIiEEE6assignIPiEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIiNS_15iterator_traitsIS7_E9referenceEEE5valueEvE4typeES7_S7_,__ZN17PersistentManager22CheckInstanceIDsLoadedEPii,__ZN17PersistentManager13GetAllFileIDsERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER13dynamic_arrayIxLj8EE,__ZNSt3__16__treeINS_12__value_typeI26SerializedObjectIdentifieriEENS_19__map_value_compareIS2_S3_NS_4lessIS2_EELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_,__ZNSt3__16__treeINS_12__value_typeIi26SerializedObjectIdentifierEENS_19__map_value_compareIiS3_NS_4lessIiEELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_,__ZN17PersistentManager19RemapToAbsolutePathERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN17PersistentManager23PostLoadStreamNameSpaceER15StreamNameSpacei,__ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EE13stl_allocatorIS6_L18MemLabelIdentifier30ELi16EEE16__construct_nodeERKS6_,__ZN13sorted_vectorINSt3__14pairINS0_12basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEES7_EEN10vector_mapIS7_S7_26compare_string_insensitive13stl_allocatorIS8_L18MemLabelIdentifier30ELi16EEE13value_compareESD_E10insert_oneERKS8_,__ZL23OutOfBoundsReadingErroriii,__ZN6ShaderC2E10MemLabelId18ObjectCreationMode,__ZNSt3__16vectorI4PPtrI6ShaderENS_9allocatorIS3_EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZN6Shader5ParseEPKcj,__ZNSt3__16__treeINS_12__value_typeI4PPtrI6ShaderE8UnityStrEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_,__ZNSt3__16vectorINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS4_IS6_EEE6assignINS_11__wrap_iterIPK8UnityStrEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS6_NS_15iterator_traitsISG_E9referenceEEE5valueEvE4typeESG_SG_,__ZNSt3__16__sortIRNS_6__lessINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_EEPS7_EEvT0_SB_T_,__ZNK16MemoryFileSystem11GetGoodPathEPKcRNSt3__112basic_stringIcNS2_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEE,__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEPN16MemoryFileSystem4NodeEEENS_19__map_value_compareIS8_SC_NS_4lessIS8_EELb1EEES5_ISC_LS6_46ELi16EEE16__construct_nodeERKSC_,__ZN25MultiBlocksMemoryFileDataC2E10MemLabelIdj,__ZNSt3__16__treeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_4lessIS6_EENS4_IS6_EEE15__insert_uniqueERKS6_,__Z15CleanLogHandler7LogTypePKcz,__ZL18AppendPathNameImplRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES7_cRS5_,__ZN9ShaderLab13PropertySheet22SetupTexturePropertiesERKNS_16FastPropertyNameERNS0_15TexturePropertyE,__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameENS2_13PropertySheet15TexturePropertyEEENS_19__map_value_compareIS3_S6_NS_4lessIS3_EELb1EEENS_9allocatorIS6_EEE15__insert_uniqueERKS6_,__ZNSt3__16__treeINS_12__value_typeIN9ShaderLab16FastPropertyNameE8Vector4fEENS_19__map_value_compareIS3_S5_NS_4lessIS3_EELb1EEENS_9allocatorIS5_EEE15__insert_uniqueERKS5_,__ZNSt3__16__treeINS_12__value_typeINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEiEENS_19__map_value_compareIS7_S8_26compare_string_insensitiveLb1EEENS5_IS8_EEE15__insert_uniqueERKS8_,__ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE15__insert_uniqueERKS2_,__ZN9ShaderLab9SubShader15FindNamedPassesERK8UnityStrR13dynamic_arrayIPNS_4PassELj4EE
  ,__ZN9ShaderLab7ProgramC2Ei10ShaderType,__ZN9ShaderLab10SubProgramC2ERKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP16PropertyNamesSet,__ZNSt3__16__treeIN12ShaderErrors11ShaderErrorENS_4lessIS2_EENS_9allocatorIS2_EEE14__assign_multiINS_21__tree_const_iteratorIS2_PNS_11__tree_nodeIS2_PvEEiEEEEvT_SF_,__ZN15ResourceManager12GetPathRangeERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__Z46Quaternion_CUSTOM_INTERNAL_CALL_FromToRotationRK8Vector3fS1_,__Z44Quaternion_CUSTOM_INTERNAL_CALL_LookRotationRK8Vector3fS1_,__Z52Bounds_CUSTOM_INTERNAL_CALL_Internal_GetClosestPointR4AABBR8Vector3f,__Z38Material_CUSTOM_INTERNAL_CALL_SetColorP15ScriptingObjectiRK10ColorRGBAf,__Z24Material_CUSTOM_GetColorP15ScriptingObjecti,__Z46Camera_CUSTOM_INTERNAL_CALL_ViewportPointToRayP15ScriptingObjectRK8Vector3f,__Z44Camera_CUSTOM_INTERNAL_CALL_ScreenPointToRayP15ScriptingObjectRK8Vector3f,__Z25Debug_CUSTOM_Internal_LogiP15ScriptingStringP15ScriptingObject,__Z31Display_CUSTOM_GetSystemExtImpl6IntPtrPiS0_,__Z34Display_CUSTOM_GetRenderingExtImpl6IntPtrPiS0_,__Z38Display_CUSTOM_GetRenderingBuffersImpl6IntPtrP21ScriptingRenderBufferS1_,__Z41Display_CUSTOM_SetRenderingResolutionImpl6IntPtrii,__Z49Transform_CUSTOM_INTERNAL_CALL_TransformDirectionP15ScriptingObjectRK8Vector3f,__Z56Transform_CUSTOM_INTERNAL_CALL_InverseTransformDirectionP15ScriptingObjectRK8Vector3f,__Z45Transform_CUSTOM_INTERNAL_CALL_TransformPointP15ScriptingObjectRK8Vector3f,__Z52Transform_CUSTOM_INTERNAL_CALL_InverseTransformPointP15ScriptingObjectRK8Vector3f,__ZN5Unity9Component14SendMessageAnyERK17MessageIdentifierR11MessageData,__ZN9Transform26SetPositionWithLocalOffsetERK8Vector3fS2_,__ZZN19CharacterController15InitializeClassEvEN52FunctorImpl_CharacterController_kAnimatorMoveBuiltin4CallEPviR11MessageData,__ZN8ColliderC2E10MemLabelId18ObjectCreationMode,__ZZN8Collider15InitializeClassEvEN34FunctorImpl_Collider_kLayerChanged4CallEPviR11MessageData,__ZZN8Collider15InitializeClassEvEN43FunctorImpl_Collider_kForceRecreateCollider4CallE_0PviR11MessageData,__ZZN8Collider15InitializeClassEvEN38FunctorImpl_Collider_kTransformChanged4CallE_1PviR11MessageData,__ZZN12MeshCollider15InitializeClassEvEN39FunctorImpl_MeshCollider_kDidDeleteMesh4CallEPviR11MessageData,__ZNSt3__16vectorIjNS_9allocatorIjEEE8__appendEjRKj,__ZN14PhysicsManagerC2E10MemLabelId18ObjectCreationMode
  ,__ZNSt3__16vectorIjNS_9allocatorIjEEE6assignINS_11__wrap_iterIPjEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIjNS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_,__ZZN9Rigidbody15InitializeClassEvEN39FunctorImpl_Rigidbody_kTransformChanged4CallEPviR11MessageData,__ZZN9Rigidbody15InitializeClassEvEN42FunctorImpl_Rigidbody_kAnimatorMoveBuiltin4CallE_0PviR11MessageData,__ZN24AudioScriptBufferManager15GetPCMReadArrayEjRP14ScriptingArray,__ZN9AudioClipC2E10MemLabelId18ObjectCreationMode,__ZZN13AudioListener15InitializeClassEvEN42FunctorImpl_AudioListener_kDidAddComponent4CallEPviR11MessageData,__ZN14AudioBehaviourC2E10MemLabelId18ObjectCreationMode,__ZN29AudioEffectInternalDefinitionC2EP26UnityAudioEffectDefinitionb,__ZN20SoundChannelInstanceC2E11SoundHandleb,__ZN20SoundManagerWatchDog6UpdateEPKci,__ZN12SoundChannel6CreateE11SoundHandleb,__Z21UnsignedInt64ToStringy,__ZL27AnimationVisibilityCallbackPvS_i,__ZNSt3__16vectorI4PPtrI13AnimationClipE13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_,__ZN11UnityEngine9Animation21AvatarBindingCallbackEPvS1_i,__ZN11UnityEngine9AnimationL22GenericBindingCallbackEPvS1_i,__ZN6Object8AddEventEPFvPvS0_iES0_,__Z16GenerateTypeTreeR6ObjectP8TypeTree24TransferInstructionFlags,__ZNSt3__16__treeINS_12__value_typeIN11UnityEngine9Animation14GenericBindingENS3_10BoundIndexEEENS_19__map_value_compareIS4_S6_NS_4lessIS4_EELb1EEE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEE15__insert_uniqueERKS6_,__ZN6MotionC2E10MemLabelId18ObjectCreationMode,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI14AnimationEvent13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZNSt3__16vectorIN13AnimationClip9PPtrCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZNSt3__16vectorIN13AnimationClip10FloatCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZNSt3__16vectorIN13AnimationClip12Vector3CurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZNSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS1_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZNSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS2_L18MemLabelIdentifier18ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS5_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags
  ,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorI24CompressedAnimationCurve13stl_allocatorIS3_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN13AnimationClip15QuaternionCurveE13stl_allocatorIS4_L18MemLabelIdentifier18ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16__treeINS_12__value_typeIj8UnityStrEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_,__ZZN8Animator15InitializeClassEvEN38FunctorImpl_Animator_kTransformChanged4CallEPviR11MessageData,__ZZN8Animator15InitializeClassEvEN49FunctorImpl_Animator_kDidModifyAnimatorController4CallE_0PviR11MessageData,__ZZN8Animator15InitializeClassEvEN37FunctorImpl_Animator_kDidModifyMotion4CallE_1PviR11MessageData,__ZZN8Animator15InitializeClassEvEN37FunctorImpl_Animator_kDidModifyAvatar4CallE_2PviR11MessageData,__ZZN8Animator15InitializeClassEvEN37FunctorImpl_Animator_kDidAddComponent4CallE_3PviR11MessageData,__ZN8AnimatorC2E10MemLabelId18ObjectCreationMode,__ZN8Animator26AnimatorVisibilityCallbackEPvS0_i,__ZN11UnityEngine9Animation35SetTransformPropertyApplyMainThreadER9TransformRKNS0_30AnimatorGenericBindingConstantERKNS0_21AvatarBindingConstantE,__ZN11UnityEngine9Animation40SetFlattenedSkeletonTransformsMainThreadERKNS0_21AvatarBindingConstantERKN7mecanim8skeleton12SkeletonPoseERKNS4_9animation14AvatarConstantE,__ZZN18AnimatorController15InitializeClassEvEN47FunctorImpl_AnimatorController_kDidModifyMotion4CallEPviR11MessageData,__ZN25RuntimeAnimatorControllerC2E10MemLabelId18ObjectCreationMode,__ZNSt3__16vectorI25StateMachineBehaviourInfoNS_9allocatorIS1_EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorItNS_9allocatorItEEE6assignINS_11__wrap_iterIPjEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleItNS_15iterator_traitsIS9_E9referenceEEE5valueEvE4typeES9_S9_,__ZN4Mesh14ResizeVerticesEjj,__ZN4Mesh16SetChannelsDirtyEjb,__ZN21MaterialPropertyBlock17AddPropertyVectorERKN9ShaderLab16FastPropertyNameERK8Vector4f,__ZN21MaterialPropertyBlock16AddPropertyColorERKN9ShaderLab16FastPropertyNameERK10ColorRGBAf,__ZN12BaseRenderer26SetLightmapIndexIntNoDirtyEi12LightmapType,__ZNSt3__16__treeINS_12__value_typeIj17DetailPatchRenderEENS_19__map_value_compareIjS3_NS_4lessIjEELb1EEE11memory_poolIS3_EE5eraseENS_21__tree_const_iteratorIS3_PNS_11__tree_nodeIS3_PvEEiEE,__ZN13SplatDatabase12GetAlphamapsER13dynamic_arrayIhLj1EEb,__ZN14SplatMaterialsC2ERK4PPtrI11TerrainDataERKS0_IN5Unity8MaterialEE,__ZN12TreeRendererC2ER12TreeDatabaseRK8Vector3f,__Z10DestripifyPKtiRNSt3__16vectorIt13stl_allocatorItL18MemLabelIdentifier90ELi16EEEE,__ZNK21EnlightenSceneMapping22GetTerrainInstanceHashEi,__ZNK11LightProbes47GetNonTetrahedralizedProbeSetIndexOffsetAndSizeERK7Hash128,__ZL27PostLoadLevelAdditiveStaticRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER18AwakeFromLoadQueueN18LoadLevelOperation11LoadingModeE19992,__Z13TransformAABBRK4AABBRK10Matrix4x4fRS_
  ,__ZNK21ImposterRenderTexture18GetBillboardParamsERfS0_,__ZN11WindManager16ComputeWindForceERK4AABB,__ZN21MaterialPropertyBlock17AddPropertyMatrixERKN9ShaderLab16FastPropertyNameERK10Matrix4x4f,__ZNSt3__114__split_bufferI8UnityStrR13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE18__construct_at_endINS_13move_iteratorIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESC_SC_,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE18__construct_at_endIPS1_EENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeES9_S9_,__ZNSt3__16__treeIN20TextRenderingPrivate4Font15TexturePositionENS_4lessIS3_EE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE15__insert_uniqueERKS3_,__ZN20TextRenderingPrivate4FontC2E10MemLabelId18ObjectCreationMode,__ZN18StreamedBinaryReadILb1EE21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZNSt3__16vectorI4PPtrIN20TextRenderingPrivate4FontEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPS4_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS4_NS_15iterator_traitsISE_E9referenceEEE5valueEvE4typeESE_SE_,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS1_NS_15iterator_traitsISB_E9referenceEEE5valueEvE4typeESB_SB_,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE18__construct_at_endINS_11__wrap_iterIPS1_EEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueEvE4typeESB_SB_,__ZNSt3__16vectorIc13stl_allocatorIcL18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPcEEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIcNS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_,__ZNSt3__16vectorINS_4pairIifEE13stl_allocatorIS2_L18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPS2_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS2_NS_15iterator_traitsISC_E9referenceEEE5valueEvE4typeESC_SC_,__ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier90ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_,__ZNSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS3_L18MemLabelIdentifier27ELi16EEE6assignINS_11__wrap_iterIPS3_EEEENS_9enable_ifIXaasr21__is_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISD_E9referenceEEE5valueEvE4typeESD_SD_,__ZN18StreamedBinaryReadILb0EE21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS6_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorIN20TextRenderingPrivate4Font13CharacterInfoE13stl_allocatorIS5_L18MemLabelIdentifier90ELi16EEEEEEvRT_17TransferMetaFlags,__ZN14SafeBinaryRead21TransferSTLStyleArrayINSt3__16vectorINS1_4pairIifEE13stl_allocatorIS4_L18MemLabelIdentifier27ELi16EEEEEEvRT_17TransferMetaFlags,__ZN20TextRenderingPrivate22ScriptingTextGenerator19InitCharAndLineInfoEii,__ZZN20TextRenderingPrivate8TextMesh15InitializeClassEvEN37FunctorImpl_TextMesh_kDidAddComponent4CallEPviR11MessageData,_ft_outline_glyph_transform,_destroy_size,_destroy_face,_gray_raster_reset,_ft_smooth_get_cbox,_Write_CVT_Stretched,_Move_CVT_Stretched,_Write_CVT,_Move_CVT,_t1_hints_stem
  ,_ps_hints_t1stem3,_ps_hints_t2counter,_Vertical_Sweep_Init,_Horizontal_Sweep_Init,_ft_black_reset,_ft_black_set_mode,_ft_raster1_get_cbox,__ZN2UI14PrepareBatchesEPKNS_13UIInstructionES2_R13dynamic_arrayINS_17BatchInstructionsELj4EE,__ZN2UIL19PrepareDepthEntriesEPKNS_13UIInstructionEjPNS_14DepthSortEntryE,__Z27GetComponentsInChildrenImplILb1EEvRN5Unity10GameObjectEiR13dynamic_arrayIPNS0_9ComponentELj4EE,__ZNSt3__16__sortIRPFbRK8ListNodeIN2UI6CanvasEES6_EPPS3_EEvT0_SC_T_,__ZZN2UI6Canvas15InitializeClassEvEN36FunctorImpl_Canvas_kTransformChanged4CallEPviR11MessageData,__ZL11inner_flip2PvS_j,__ZL11inner_flip4PvS_j,__ZL11inner_flip1PvS_j,__ZL11inner_flip3PvS_j,__ZL11DecodeValuePPKcS0_,_emscripten_set_main_loop__wrapper,__ZN12InputManager11SetKeyStateEib,_glBindAttribLocation__wrapper,_glDrawArrays__wrapper,_glGetProgramiv__wrapper,_glGetShaderiv__wrapper,_glGetTexParameteriv__wrapper,_glGetVertexAttribfv__wrapper,_glGetVertexAttribiv__wrapper,_glGetVertexAttribPointerv__wrapper,_glStencilFunc__wrapper,_glStencilOp__wrapper,_glTexParameteri__wrapper,_glUniform1fv__wrapper,_glUniform1iv__wrapper,_glUniform2fv__wrapper,_glUniform2iv__wrapper,_glUniform3fv__wrapper,_glUniform3iv__wrapper,_glUniform4fv__wrapper,_glUniform4iv__wrapper,__ZNSt3__16__treeI20DeviceDepthStateGLES11memcmp_lessIS1_S1_ENS_9allocatorIS1_EEE15__insert_uniqueERKS1_,__ZN17FfpGpuProgramGLESC2Ejj,__ZNSt3__16__treeINS_12__value_typeIy8TFShaderEENS_19__map_value_compareIyS3_NS_4lessIyEELb1EEENS_9allocatorIS3_EEE15__insert_uniqueERKS3_,__ZN18VirtActionInvoker1I17VoidPointerTraitsE6InvokeEP10MethodInfoPvS4_,__ZN18VirtActionInvoker1I27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi,__ZN6il2cpp2vm7Runtime20GetVirtualInvokeDataEP10MethodInfoPv,__ZN18VirtActionInvoker1I28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object,__ZN21InterfaceFuncInvoker0I49mscorlib_System_Collections_DictionaryEntryTraitsE6InvokeEP10MethodInfoPv,__ZN16VirtFuncInvoker0I49mscorlib_System_Collections_DictionaryEntryTraitsE6InvokeEP10MethodInfoPv,__ZN6il2cpp2vm7Runtime22GetInterfaceInvokeDataEP10MethodInfoPv,__ZN21InterfaceFuncInvoker0I38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEP10MethodInfoPv,__ZN21InterfaceFuncInvoker0I40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPv,__ZN18VirtActionInvoker1I40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UICharInfo,__ZN21InterfaceFuncInvoker0I40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPv,__ZN18VirtActionInvoker1I40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UILineInfo,__ZN18VirtActionInvoker1I29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb,__ZN23InterfaceActionInvoker1I17VoidPointerTraitsE6InvokeEP10MethodInfoPvS4_,__ZN23InterfaceActionInvoker1I29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb,__ZN23InterfaceActionInvoker1I28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object,__ZNSt3__112system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZNSt3__18ios_base7failureC2EPKcRKNS_10error_codeE,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEjc
  ,__ZNSt3__119__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_,__ZNSt3__119__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_,__ZNSt3__119__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcj,__ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwj,_emscripten_glGetTexParameterfv__wrapper,_emscripten_glGetTexParameteriv__wrapper,_emscripten_glTexParameterfv__wrapper,_emscripten_glTexParameteriv__wrapper,_emscripten_glGetBufferParameteriv__wrapper,_emscripten_glGetRenderbufferParameteriv__wrapper,_emscripten_glGetUniformfv__wrapper,_emscripten_glGetUniformiv__wrapper,_emscripten_glGetVertexAttribfv__wrapper,_emscripten_glGetVertexAttribiv__wrapper,_emscripten_glGetVertexAttribPointerv__wrapper,_emscripten_glUniform2i__wrapper,_emscripten_glUniform1iv__wrapper,_emscripten_glUniform2iv__wrapper,_emscripten_glUniform3iv__wrapper,_emscripten_glUniform4iv__wrapper,_emscripten_glUniform1fv__wrapper,_emscripten_glUniform2fv__wrapper,_emscripten_glUniform3fv__wrapper,_emscripten_glUniform4fv__wrapper,_emscripten_glGetShaderiv__wrapper,_emscripten_glGetProgramiv__wrapper,_emscripten_glBindAttribLocation__wrapper,_emscripten_glGetObjectParameterivARB__wrapper,_emscripten_glNormalPointer__wrapper,_emscripten_glDrawArrays__wrapper,_emscripten_glTexParameteri__wrapper,_emscripten_glStencilFunc__wrapper,_emscripten_glStencilOp__wrapper,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100
  ,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100,b100];
  var FUNCTION_TABLE_viiiifi = [b101,__Z54UnityEngine_UnityEngine_Debug_m_INTERNAL_CALL_DrawLineP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_P29UnityEngine_UnityEngine_Colorfb];
  var FUNCTION_TABLE_v = [b102,___cxa_pure_virtual__wrapper,__ZN17BaseObjectManager16StaticInitializeEv,__ZN17BaseObjectManager13StaticDestroyEv,__ZN12EventManager16StaticInitializeEv,__ZN12EventManager13StaticDestroyEv,__ZL24KeywordsStaticInitializev,__ZL21KeywordsStaticDestroyv,__ZN24MeshIntermediateRenderer16StaticInitializeEv,__ZN24MeshIntermediateRenderer13StaticDestroyEv,__ZN48MeshIntermediateRendererWithDistanceSortingOrder16StaticInitializeEv,__ZN48MeshIntermediateRendererWithDistanceSortingOrder13StaticDestroyEv,__ZN26SpriteIntermediateRenderer16StaticInitializeEv,__ZN26SpriteIntermediateRenderer13StaticDestroyEv,__ZN5Unity5Scene15InitializeClassEv,__ZN5Unity5Scene12CleanupClassEv,__ZN17CommonStringTable16StaticInitializeEv,__ZN17CommonStringTable13StaticCleanupEv,__ZL16StaticInitializev,__ZL13StaticDestroyv,__ZN11WindManager16StaticInitializeEv,__ZN11WindManager13StaticDestroyEv,__ZL29CreateMeshVertexFormatManagerv,__ZL30DestroyMeshVertexFormatManagerv,__ZL16StaticInitializev4150,__ZL13StaticDestroyv4151,__Z25InitializeLODGroupManagerv,__Z22CleanupLODGroupManagerv,__ZL19InitGUIEventManagerv
  ,__ZL22CleanupGUIEventManagerv,__ZN18AssetBundleManager16StaticInitializeEv,__ZN18AssetBundleManager13StaticDestroyEv,__ZN21ComponentRequirements16StaticInitializeEv,__ZN21ComponentRequirements13StaticDestroyEv,__ZN22BuiltinResourceManager16StaticInitializeEv,__ZN22BuiltinResourceManager13StaticDestroyEv,__ZN21SafeBinaryReadManagerL16StaticInitializeEv,__ZN21SafeBinaryReadManagerL13StaticDestroyEv,__ZL30InitializeGlobalNameConversionv,__ZL27CleanupGlobalNameConversionv,__ZL22StaticInitializeShaderv,__ZL19StaticDestroyShaderv,__ZN10FileSystem16StaticInitializeEv,__ZN10FileSystem13StaticDestroyEv,__ZN12_GLOBAL__N_138ArchiveRedirectFileSystemStaticDestroyEv,__ZN10MemoryPool16StaticInitializeEv,__ZN10MemoryPool13StaticDestroyEv,__ZN9ShaderLab33ShaderPassContextStaticInitializeEv,__ZN9ShaderLab30ShaderPassContextStaticDestroyEv,__ZN15AnimationBinder16StaticInitializeEv,__ZN15AnimationBinder13StaticDestroyEv,__ZN11UnityEngine9Animation38InitializeGenericAnimationBindingCacheEv,__ZN11UnityEngine9Animation35CleanupGenericAnimationBindingCacheEv,__ZN20QuadTreeNodeRenderer16StaticInitializeEv,__ZN20QuadTreeNodeRenderer13StaticDestroyEv,__ZL21InitializeCachedStripv,__ZL18DestroyCachedStripv,__ZN11PlayerPrefs16StaticInitializeEv,__ZN11PlayerPrefs13StaticDestroyEv
  ,__Z23CleanupLZMASharedBufferv,__ZL25InitializeUnityWebStreamsv,__ZL22CleanupUnityWebStreamsv,__ZN20CacheDownloadBuffers16StaticInitializeEv,__ZN20CacheDownloadBuffers13StaticDestroyEv,__ZL25default_terminate_handlerv,_GC_exit_check,___cxa_end_catch__wrapper,__ZN6il2cpp6icalls8mscorlib4Mono7Runtime29mono_runtime_install_handlersEv,__ZN6il2cpp6icalls8mscorlib6System9AppDomain20InternalPopDomainRefEv,__ZN6il2cpp6icalls8mscorlib6System11Environment30internalBroadcastSettingChangeEv,__ZN6il2cpp6icalls8mscorlib6System2GC24WaitForPendingFinalizersEv,__ZN6il2cpp6icalls8mscorlib6System6String22RedirectToCreateStringEv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread14MemoryBarrier_Ev,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread19ResetAbort_internalEv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread12SpinWait_nopEv,__ZN6il2cpp2vm9Exception25RaiseOutOfMemoryExceptionEv,__Z28SetupPixelCorrectCoordinatesv,__ZN15EditorExtension13RegisterClassEv,__ZN16LevelGameManager13RegisterClassEv,__ZN11GameManager13RegisterClassEv,__ZN5Unity9Component13RegisterClassEv,__ZN5Unity10GameObject13RegisterClassEv,__ZN5Unity10GameObject15InitializeClassEv,__ZN5Unity10GameObject12CleanupClassEv,__ZN11NamedObject13RegisterClassEv,__ZN10TagManager13RegisterClassEv,__ZN8GUILayer13RegisterClassEv,__ZN8GUILayer15InitializeClassEv,__ZN8GUILayer12CleanupClassEv
  ,__ZN6Camera13RegisterClassEv,__ZN6Camera15InitializeClassEv,__ZN6Camera12CleanupClassEv,__ZN10FlareLayer13RegisterClassEv,__ZN16GraphicsSettings13RegisterClassEv,__ZN16GraphicsSettings15InitializeClassEv,__ZN16GraphicsSettings12CleanupClassEv,__ZN11HaloManager13RegisterClassEv,__ZN5Light13RegisterClassEv,__ZN5Light15InitializeClassEv,__ZN5Light12CleanupClassEv,__ZN11LightProbes13RegisterClassEv,__ZN11LightProbes15InitializeClassEv,__ZN11LightProbes12CleanupClassEv,__ZN14RenderSettings13RegisterClassEv,__ZN14RenderSettings15InitializeClassEv,__ZN14RenderSettings19PostInitializeClassEv,__ZN14RenderSettings12CleanupClassEv,__Z27SetClippingPlaneShaderPropsv,__ZZN20SpeedTreeWindManagerC1EvEN10WindUpdate7ForwardEv,__ZL30InitializeSpeedTreeWindManagerv,__ZL27DestroySpeedTreeWindManagerv,__ZN4Mesh13RegisterClassEv,__ZN10MeshFilter13RegisterClassEv,__ZN10MeshFilter15InitializeClassEv,__ZN10MeshFilter12CleanupClassEv,__ZN12MeshRenderer13RegisterClassEv,__ZN12MeshRenderer15InitializeClassEv,__ZL31InitializeBillboardBatchManagerv,__ZL28DestroyBillboardBatchManagerv
  ,__ZN9Behaviour13RegisterClassEv,__ZN9Behaviour15InitializeClassEv,__ZN9Behaviour12CleanupClassEv,__ZN18DelayedCallManager13RegisterClassEv,__ZN11MonoManager13RegisterClassEv,__ZN7Cubemap13RegisterClassEv,__ZN16LightmapSettings13RegisterClassEv,__ZN15QualitySettings13RegisterClassEv,__ZN15QualitySettings15InitializeClassEv,__ZN15QualitySettings12CleanupClassEv,__ZN8Renderer13RegisterClassEv,__ZN8Renderer15InitializeClassEv,__ZN8Renderer19PostInitializeClassEv,__ZN8Renderer12CleanupClassEv,__ZN13RenderTexture13RegisterClassEv,__ZN7Texture13RegisterClassEv,__ZN9Texture2D13RegisterClassEv,__ZN9Texture2D15InitializeClassEv,__ZN9Texture2D12CleanupClassEv,__ZN9Texture3D13RegisterClassEv,__ZN9Transform13RegisterClassEv,___cxa_rethrow__wrapper,__ZN12InputManager13RegisterClassEv,__ZN12InputManager15InitializeClassEv,__ZN12InputManager12CleanupClassEv,__ZN11TimeManager13RegisterClassEv,__ZN11AssetBundle13RegisterClassEv,__ZZN13BuildSettingsC1E10MemLabelId18ObjectCreationModeEN27initializedPreloadedPlugins7ForwardEv,__ZN13BuildSettings13RegisterClassEv,_JS_FileSystem_Sync__wrapper,__ZZN2UI23InitializeCanvasManagerEvEN27CanvasManagerRenderOverlays7ForwardE_1v,__Z15UnloadGameScenev,__ZN14UnityWebStream24UpdateAllUnityWebStreamsEv,__ZZ29InitializeTextRenderingModulevEN27TextRenderingGarbageCollect7ForwardEv,__ZZN2UI23InitializeCanvasManagerEvEN25UpdateCanvasRectTransform7ForwardE_2v,__ZZN14PhysicsManager15InitializeClassEvEN24PhysicsRefreshWhenPaused7ForwardE_1v,__ZZN14PhysicsManager15InitializeClassEvEN41PhysicsResetInterpolatedTransformPosition7ForwardE_3v,__ZZN15AnimatorManager15InitializeClassEvEN25AnimatorFixedUpdateFKMove7ForwardE_2v,__ZZN16AnimationManager15InitializeClassEvEN21LegacyAnimationUpdate7ForwardE_0v,__ZZN14PhysicsManager15InitializeClassEvEN18PhysicsFixedUpdate7ForwardEv,__ZZN15AnimatorManager15InitializeClassEvEN34AnimatorFixedUpdateRetargetIKWrite7ForwardEv,__ZZN14PhysicsManager15InitializeClassEvEN13PhysicsUpdate7ForwardE_0v,__ZZN15AnimatorManager15InitializeClassEvEN20AnimatorUpdateFKMove7ForwardE_1v,__ZZN15AnimatorManager15InitializeClassEvEN29AnimatorUpdateRetargetIKWrite7ForwardE_0v,__ZZN14PhysicsManager15InitializeClassEvEN25PhysicsSkinnedClothUpdate7ForwardE_2v,__ZN13RenderManager18UpdateAllRenderersEv,__ZZN2UI23InitializeCanvasManagerEvEN18WillRenderCanvases7ForwardE_3v,__ZZN2UI23InitializeCanvasManagerEvEN30CanvasManagerEmitWorldGeometry7ForwardEv,__ZZN2UI23InitializeCanvasManagerEvEN42CanvasmanagerEmitScreenSpaceCameraGeometry7ForwardE_0v,__Z23UpdateCaptureScreenshotv,__ZN6Shader23HandleShadersWithErrorsEv,__ZN11PreloadData13RegisterClassEv,__ZN14PlayerSettings13RegisterClassEv,__ZN14PlayerSettings15InitializeClassEv,__ZN14PlayerSettings19PostInitializeClassEv,__ZN14PlayerSettings12CleanupClassEv,__ZN15ResourceManager13RegisterClassEv,__ZN13MonoBehaviour13RegisterClassEv,__ZN13MonoBehaviour15InitializeClassEv,__ZN13MonoBehaviour12CleanupClassEv
  ,__ZN10MonoScript13RegisterClassEv,__ZN9TextAsset13RegisterClassEv,__Z23InitializeStdConvertersv,__Z20CleanupStdConvertersv,__ZN5Unity8Material13RegisterClassEv,__ZN9ShaderLab13InitShaderLabEv,__ZN6Shader13RegisterClassEv,__ZN12ScriptMapper13RegisterClassEv,__Z13TearDownLexerv,__Z34GUIUtility_CUSTOM_Internal_ExitGUIv,__Z27Input_CUSTOM_ResetInputAxesv,__ZN19CharacterController13RegisterClassEv,__ZN19CharacterController15InitializeClassEv,__ZN19CharacterController12CleanupClassEv,__ZN8Collider13RegisterClassEv,__ZN8Collider15InitializeClassEv,__ZN8Collider12CleanupClassEv,__ZN12MeshCollider13RegisterClassEv,__ZN12MeshCollider15InitializeClassEv,__ZN12MeshCollider12CleanupClassEv,__ZZN14PhysicsManager15InitializeClassEvEN14didUnloadScene7ForwardE_4v,__ZN14PhysicsManager20CleanupDynamicsSceneEv,__Z17PxCloseExtensionsv,__ZN14PhysicsManager13RegisterClassEv,__ZN14PhysicsManager15InitializeClassEv,__ZN14PhysicsManager12CleanupClassEv,__ZN9Rigidbody13RegisterClassEv,__ZN9Rigidbody15InitializeClassEv,__ZN9Rigidbody12CleanupClassEv,__ZL28RegisterModuleICalls_Physicsv
  ,__ZL24InitializeModule_Physicsv,__ZL21CleanupModule_Physicsv,__ZN14AudioBehaviour13RegisterClassEv,__ZN9AudioClip13RegisterClassEv,__ZN9AudioClip15InitializeClassEv,__ZN9AudioClip12CleanupClassEv,__ZN13AudioListener13RegisterClassEv,__ZN13AudioListener15InitializeClassEv,__ZN13AudioListener12CleanupClassEv,__ZN12AudioManager13RegisterClassEv,__ZN12AudioManager15InitializeClassEv,__ZN12AudioManager12CleanupClassEv,__ZN12SoundManager20OnExitPlayModeStaticEv,__ZL26RegisterModuleICalls_Audiov,__ZL22InitializeModule_Audiov,__ZL19CleanupModule_Audiov,__ZL30RegisterModuleICalls_Animationv,__ZL26InitializeModule_Animationv,__ZL23CleanupModule_Animationv,__ZN9Animation13RegisterClassEv,__ZN9Animation15InitializeClassEv,__ZN9Animation12CleanupClassEv,__ZN11UnityEngine9Animation28GenericAnimationBindingCache15DidReloadDomainEv,__ZN6Motion13RegisterClassEv,__ZN13AnimationClip13RegisterClassEv,__ZN13AnimationClip15InitializeClassEv,__ZN13AnimationClip12CleanupClassEv,__ZN8Animator13RegisterClassEv,__ZN8Animator15InitializeClassEv,__ZN8Animator12CleanupClassEv
  ,__ZN25RuntimeAnimatorController13RegisterClassEv,__ZN18AnimatorController13RegisterClassEv,__ZN18AnimatorController15InitializeClassEv,__ZN25RuntimeAnimatorController12CleanupClassEv,__ZN7Terrain13RegisterClassEv,__ZN7Terrain15InitializeClassEv,__ZN7Terrain12CleanupClassEv,__ZL28RegisterModuleICalls_Terrainv,__ZL24InitializeModule_Terrainv,__ZL21CleanupModule_Terrainv,__ZZ29InitializeTextRenderingModulevEN16cleanupAfterLoad7ForwardE_0v,__ZN20TextRenderingPrivate4Font12LoadAllFontsEv,__ZN20TextRenderingPrivate17TextMeshGenerator5FlushEv,__ZL34RegisterModuleICalls_TextRenderingv,__ZL30InitializeModule_TextRenderingv,__ZL27CleanupModule_TextRenderingv,__Z13ApplyToMeshesv,__ZN20TextRenderingPrivate4Font13RegisterClassEv,__ZN20TextRenderingPrivate4Font15InitializeClassEv,__ZN20TextRenderingPrivate4Font12CleanupClassEv,__ZN20TextRenderingPrivate8TextMesh13RegisterClassEv,__ZN20TextRenderingPrivate8TextMesh15InitializeClassEv,__ZN20TextRenderingPrivate8TextMesh12CleanupClassEv,__ZN2UI6Canvas13RegisterClassEv,__ZN2UI6Canvas15InitializeClassEv,__ZN2UI6Canvas12CleanupClassEv,__ZL23RegisterModuleICalls_UIv,__ZL19InitializeModule_UIv,__ZL16CleanupModule_UIv,__Z20PlayerLoadFirstLevelv
  ,__ZL8mainloopv,_glFinish__wrapper,_glFlush__wrapper,__ZN25TransformFeedbackSkinning31CleanupTransformFeedbackShadersEv,__ZN4gles26ClearFixedFunctionProgramsEv,__ZN4gles11ClearFBOMapEv,__ZN11ContextGLES7DestroyEv,__ZL47s_AssemblyU002DCSharpU002DfirstpassRegistrationv,__ZL33s_AssemblyU002DCSharpRegistrationv,__ZL52s_AssemblyU002DUnityScriptU002DfirstpassRegistrationv,__ZL22s_Boo_LangRegistrationv,__Z20_il2cpp_strinit_s_1Cv,__Z19_il2cpp_strinit_s_0v,__Z19_il2cpp_strinit_s_1v,__Z19_il2cpp_strinit_s_3v,__Z19_il2cpp_strinit_s_2v,__Z19_il2cpp_strinit_s_4v,__Z19_il2cpp_strinit_s_5v,__Z19_il2cpp_strinit_s_6v,__Z19_il2cpp_strinit_s_7v,__Z19_il2cpp_strinit_s_8v,__Z19_il2cpp_strinit_s_9v,__Z19_il2cpp_strinit_s_Av,__Z19_il2cpp_strinit_s_Bv,__Z19_il2cpp_strinit_s_Cv,__Z19_il2cpp_strinit_s_Dv,__Z19_il2cpp_strinit_s_Ev,__Z19_il2cpp_strinit_s_Fv,__Z20_il2cpp_strinit_s_10v,__Z20_il2cpp_strinit_s_11v
  ,__Z20_il2cpp_strinit_s_12v,__Z20_il2cpp_strinit_s_13v,__Z20_il2cpp_strinit_s_14v,__Z20_il2cpp_strinit_s_15v,__Z20_il2cpp_strinit_s_16v,__Z20_il2cpp_strinit_s_17v,__Z20_il2cpp_strinit_s_18v,__Z20_il2cpp_strinit_s_19v,__Z20_il2cpp_strinit_s_1Av,__Z20_il2cpp_strinit_s_1Bv,__Z20_il2cpp_strinit_s_1Dv,__Z20_il2cpp_strinit_s_1Ev,__Z20_il2cpp_strinit_s_1Fv,__Z20_il2cpp_strinit_s_20v,__Z20_il2cpp_strinit_s_21v,__Z20_il2cpp_strinit_s_22v,__Z20_il2cpp_strinit_s_23v,__Z20_il2cpp_strinit_s_24v,__Z20_il2cpp_strinit_s_25v,__Z20_il2cpp_strinit_s_26v,__Z20_il2cpp_strinit_s_27v,__Z20_il2cpp_strinit_s_28v,__Z20_il2cpp_strinit_s_29v,__Z20_il2cpp_strinit_s_2Av,__Z21_il2cpp_strinit_s_2B7v,__Z21_il2cpp_strinit_s_2B8v,__Z21_il2cpp_strinit_s_2B9v,__Z21_il2cpp_strinit_s_2BAv,__Z21_il2cpp_strinit_s_2BBv,__Z21_il2cpp_strinit_s_2BCv
  ,__Z21_il2cpp_strinit_s_2BDv,__Z21_il2cpp_strinit_s_2BEv,__Z21_il2cpp_strinit_s_2BFv,__Z21_il2cpp_strinit_s_2C0v,__Z21_il2cpp_strinit_s_2C1v,__Z21_il2cpp_strinit_s_2C2v,__Z21_il2cpp_strinit_s_2C3v,__Z21_il2cpp_strinit_s_2C4v,__Z21_il2cpp_strinit_s_2C5v,__Z21_il2cpp_strinit_s_2C6v,__Z21_il2cpp_strinit_s_2C7v,__Z21_il2cpp_strinit_s_2C8v,__Z21_il2cpp_strinit_s_2C9v,__Z21_il2cpp_strinit_s_2CAv,__Z21_il2cpp_strinit_s_2CBv,__Z21_il2cpp_strinit_s_2CCv,__Z21_il2cpp_strinit_s_2CDv,__Z21_il2cpp_strinit_s_2CEv,__Z21_il2cpp_strinit_s_2CFv,__Z21_il2cpp_strinit_s_2D0v,__Z21_il2cpp_strinit_s_2D1v,__Z21_il2cpp_strinit_s_2D2v,__Z21_il2cpp_strinit_s_2D3v,__Z21_il2cpp_strinit_s_2D4v,__Z21_il2cpp_strinit_s_2D5v,__Z21_il2cpp_strinit_s_2D6v,__Z20_il2cpp_strinit_s_5Av,__Z20_il2cpp_strinit_s_5Bv,__Z20_il2cpp_strinit_s_5Cv,__Z20_il2cpp_strinit_s_60v
  ,__Z20_il2cpp_strinit_s_5Dv,__Z20_il2cpp_strinit_s_5Ev,__Z20_il2cpp_strinit_s_86v,__Z20_il2cpp_strinit_s_80v,__Z20_il2cpp_strinit_s_5Fv,__Z20_il2cpp_strinit_s_61v,__Z20_il2cpp_strinit_s_62v,__Z20_il2cpp_strinit_s_63v,__Z20_il2cpp_strinit_s_64v,__Z20_il2cpp_strinit_s_8Ev,__Z20_il2cpp_strinit_s_65v,__Z20_il2cpp_strinit_s_66v,__Z20_il2cpp_strinit_s_67v,__Z20_il2cpp_strinit_s_68v,__Z20_il2cpp_strinit_s_69v,__Z20_il2cpp_strinit_s_6Av,__Z20_il2cpp_strinit_s_6Bv,__Z20_il2cpp_strinit_s_6Cv,__Z20_il2cpp_strinit_s_6Dv,__Z20_il2cpp_strinit_s_6Ev,__Z20_il2cpp_strinit_s_6Fv,__Z20_il2cpp_strinit_s_70v,__Z20_il2cpp_strinit_s_71v,__Z20_il2cpp_strinit_s_72v,__Z20_il2cpp_strinit_s_73v,__Z20_il2cpp_strinit_s_74v,__Z20_il2cpp_strinit_s_75v,__Z20_il2cpp_strinit_s_76v,__Z20_il2cpp_strinit_s_77v,__Z20_il2cpp_strinit_s_78v
  ,__Z20_il2cpp_strinit_s_79v,__Z20_il2cpp_strinit_s_7Av,__Z20_il2cpp_strinit_s_98v,__Z20_il2cpp_strinit_s_7Bv,__Z20_il2cpp_strinit_s_7Cv,__Z20_il2cpp_strinit_s_7Dv,__Z20_il2cpp_strinit_s_7Ev,__Z20_il2cpp_strinit_s_7Fv,__Z20_il2cpp_strinit_s_81v,__Z20_il2cpp_strinit_s_82v,__Z20_il2cpp_strinit_s_83v,__Z20_il2cpp_strinit_s_84v,__Z20_il2cpp_strinit_s_85v,__Z20_il2cpp_strinit_s_87v,__Z20_il2cpp_strinit_s_88v,__Z20_il2cpp_strinit_s_89v,__Z20_il2cpp_strinit_s_8Av,__Z20_il2cpp_strinit_s_8Bv,__Z20_il2cpp_strinit_s_8Cv,__Z20_il2cpp_strinit_s_8Dv,__Z20_il2cpp_strinit_s_91v,__Z20_il2cpp_strinit_s_8Fv,__Z20_il2cpp_strinit_s_90v,__Z20_il2cpp_strinit_s_92v,__Z20_il2cpp_strinit_s_93v,__Z20_il2cpp_strinit_s_94v,__Z20_il2cpp_strinit_s_95v,__Z20_il2cpp_strinit_s_96v,__Z20_il2cpp_strinit_s_97v,__Z20_il2cpp_strinit_s_99v
  ,__Z20_il2cpp_strinit_s_9Av,__Z20_il2cpp_strinit_s_9Bv,__Z20_il2cpp_strinit_s_9Cv,__Z20_il2cpp_strinit_s_9Dv,__Z20_il2cpp_strinit_s_9Ev,__Z20_il2cpp_strinit_s_9Fv,__Z20_il2cpp_strinit_s_A8v,__Z20_il2cpp_strinit_s_A0v,__Z20_il2cpp_strinit_s_A1v,__Z20_il2cpp_strinit_s_A2v,__Z20_il2cpp_strinit_s_A3v,__Z20_il2cpp_strinit_s_A4v,__Z20_il2cpp_strinit_s_A5v,__Z20_il2cpp_strinit_s_A6v,__Z20_il2cpp_strinit_s_A7v,__Z20_il2cpp_strinit_s_A9v,__Z20_il2cpp_strinit_s_AAv,__Z20_il2cpp_strinit_s_ABv,__Z20_il2cpp_strinit_s_ACv,__Z20_il2cpp_strinit_s_ADv,__Z20_il2cpp_strinit_s_AEv,__Z20_il2cpp_strinit_s_AFv,__Z20_il2cpp_strinit_s_B0v,__Z20_il2cpp_strinit_s_B1v,__Z20_il2cpp_strinit_s_B2v,__Z20_il2cpp_strinit_s_B3v,__Z20_il2cpp_strinit_s_B4v,__Z20_il2cpp_strinit_s_B5v,__Z20_il2cpp_strinit_s_B7v,__Z20_il2cpp_strinit_s_D6v
  ,__Z20_il2cpp_strinit_s_D5v,__Z20_il2cpp_strinit_s_B6v,__Z20_il2cpp_strinit_s_B8v,__Z20_il2cpp_strinit_s_B9v,__Z20_il2cpp_strinit_s_BBv,__Z20_il2cpp_strinit_s_BAv,__Z20_il2cpp_strinit_s_BFv,__Z20_il2cpp_strinit_s_BCv,__Z20_il2cpp_strinit_s_BDv,__Z20_il2cpp_strinit_s_BEv,__Z20_il2cpp_strinit_s_C7v,__Z20_il2cpp_strinit_s_C0v,__Z20_il2cpp_strinit_s_C1v,__Z20_il2cpp_strinit_s_C2v,__Z20_il2cpp_strinit_s_DAv,__Z20_il2cpp_strinit_s_C3v,__Z20_il2cpp_strinit_s_C4v,__Z20_il2cpp_strinit_s_C5v,__Z20_il2cpp_strinit_s_C6v,__Z20_il2cpp_strinit_s_C8v,__Z20_il2cpp_strinit_s_C9v,__Z20_il2cpp_strinit_s_CAv,__Z20_il2cpp_strinit_s_CBv,__Z20_il2cpp_strinit_s_CEv,__Z20_il2cpp_strinit_s_CCv,__Z20_il2cpp_strinit_s_CDv,__Z20_il2cpp_strinit_s_CFv,__Z20_il2cpp_strinit_s_D0v,__Z20_il2cpp_strinit_s_D1v,__Z20_il2cpp_strinit_s_D2v
  ,__Z20_il2cpp_strinit_s_D3v,__Z20_il2cpp_strinit_s_D4v,__Z20_il2cpp_strinit_s_D9v,__Z20_il2cpp_strinit_s_D7v,__Z20_il2cpp_strinit_s_D8v,__Z20_il2cpp_strinit_s_DBv,__Z20_il2cpp_strinit_s_DCv,__Z20_il2cpp_strinit_s_DDv,__Z20_il2cpp_strinit_s_DEv,__Z20_il2cpp_strinit_s_DFv,__Z20_il2cpp_strinit_s_E1v,__Z20_il2cpp_strinit_s_E0v,__Z20_il2cpp_strinit_s_E2v,__Z20_il2cpp_strinit_s_E3v,__Z20_il2cpp_strinit_s_E4v,__Z20_il2cpp_strinit_s_E5v,__Z20_il2cpp_strinit_s_E6v,__Z20_il2cpp_strinit_s_E7v,__Z20_il2cpp_strinit_s_EBv,__Z20_il2cpp_strinit_s_E8v,__Z20_il2cpp_strinit_s_E9v,__Z20_il2cpp_strinit_s_EAv,__Z20_il2cpp_strinit_s_ECv,__Z20_il2cpp_strinit_s_EDv,__Z20_il2cpp_strinit_s_EEv,__Z20_il2cpp_strinit_s_EFv,__Z20_il2cpp_strinit_s_F0v,__Z20_il2cpp_strinit_s_F1v,__Z20_il2cpp_strinit_s_F2v,__Z20_il2cpp_strinit_s_F3v
  ,__Z20_il2cpp_strinit_s_F4v,__Z20_il2cpp_strinit_s_F5v,__Z20_il2cpp_strinit_s_F6v,__Z20_il2cpp_strinit_s_F7v,__Z20_il2cpp_strinit_s_F8v,__Z20_il2cpp_strinit_s_FBv,__Z20_il2cpp_strinit_s_F9v,__Z20_il2cpp_strinit_s_FAv,__Z20_il2cpp_strinit_s_FCv,__Z20_il2cpp_strinit_s_FDv,__Z20_il2cpp_strinit_s_FEv,__Z20_il2cpp_strinit_s_FFv,__Z21_il2cpp_strinit_s_100v,__Z21_il2cpp_strinit_s_101v,__Z21_il2cpp_strinit_s_102v,__Z21_il2cpp_strinit_s_103v,__Z21_il2cpp_strinit_s_104v,__Z21_il2cpp_strinit_s_105v,__Z21_il2cpp_strinit_s_106v,__Z21_il2cpp_strinit_s_107v,__Z21_il2cpp_strinit_s_108v,__Z21_il2cpp_strinit_s_109v,__Z21_il2cpp_strinit_s_10Av,__Z21_il2cpp_strinit_s_10Bv,__Z21_il2cpp_strinit_s_10Cv,__Z21_il2cpp_strinit_s_10Dv,__Z21_il2cpp_strinit_s_10Ev,__Z21_il2cpp_strinit_s_10Fv,__Z21_il2cpp_strinit_s_110v,__Z21_il2cpp_strinit_s_111v
  ,__Z21_il2cpp_strinit_s_112v,__Z21_il2cpp_strinit_s_113v,__Z21_il2cpp_strinit_s_114v,__Z21_il2cpp_strinit_s_115v,__Z21_il2cpp_strinit_s_116v,__Z21_il2cpp_strinit_s_117v,__Z21_il2cpp_strinit_s_118v,__Z21_il2cpp_strinit_s_119v,__Z21_il2cpp_strinit_s_11Av,__Z21_il2cpp_strinit_s_11Bv,__Z21_il2cpp_strinit_s_11Cv,__Z21_il2cpp_strinit_s_11Dv,__Z21_il2cpp_strinit_s_11Ev,__Z21_il2cpp_strinit_s_11Fv,__Z21_il2cpp_strinit_s_120v,__Z21_il2cpp_strinit_s_121v,__Z21_il2cpp_strinit_s_125v,__Z21_il2cpp_strinit_s_122v,__Z21_il2cpp_strinit_s_127v,__Z21_il2cpp_strinit_s_123v,__Z21_il2cpp_strinit_s_126v,__Z21_il2cpp_strinit_s_124v,__Z21_il2cpp_strinit_s_128v,__Z21_il2cpp_strinit_s_129v,__Z21_il2cpp_strinit_s_12Av,__Z21_il2cpp_strinit_s_12Cv,__Z21_il2cpp_strinit_s_12Bv,__Z21_il2cpp_strinit_s_12Dv,__Z21_il2cpp_strinit_s_12Ev,__Z21_il2cpp_strinit_s_12Fv
  ,__Z21_il2cpp_strinit_s_130v,__Z21_il2cpp_strinit_s_131v,__Z21_il2cpp_strinit_s_132v,__Z21_il2cpp_strinit_s_133v,__Z21_il2cpp_strinit_s_134v,__Z21_il2cpp_strinit_s_135v,__Z21_il2cpp_strinit_s_136v,__Z21_il2cpp_strinit_s_137v,__Z21_il2cpp_strinit_s_138v,__Z21_il2cpp_strinit_s_139v,__Z21_il2cpp_strinit_s_13Cv,__Z21_il2cpp_strinit_s_13Av,__Z21_il2cpp_strinit_s_13Bv,__Z21_il2cpp_strinit_s_13Dv,__Z21_il2cpp_strinit_s_13Ev,__Z21_il2cpp_strinit_s_13Fv,__Z21_il2cpp_strinit_s_140v,__Z21_il2cpp_strinit_s_143v,__Z21_il2cpp_strinit_s_141v,__Z21_il2cpp_strinit_s_142v,__Z21_il2cpp_strinit_s_144v,__Z21_il2cpp_strinit_s_145v,__Z21_il2cpp_strinit_s_146v,__Z21_il2cpp_strinit_s_147v,__Z21_il2cpp_strinit_s_148v,__Z21_il2cpp_strinit_s_149v,__Z21_il2cpp_strinit_s_14Av,__Z21_il2cpp_strinit_s_14Dv,__Z21_il2cpp_strinit_s_14Cv,__Z21_il2cpp_strinit_s_14Bv
  ,__Z21_il2cpp_strinit_s_14Ev,__Z21_il2cpp_strinit_s_14Fv,__Z21_il2cpp_strinit_s_151v,__Z21_il2cpp_strinit_s_150v,__Z21_il2cpp_strinit_s_152v,__Z21_il2cpp_strinit_s_153v,__Z21_il2cpp_strinit_s_154v,__Z21_il2cpp_strinit_s_157v,__Z21_il2cpp_strinit_s_155v,__Z21_il2cpp_strinit_s_156v,__Z21_il2cpp_strinit_s_158v,__Z21_il2cpp_strinit_s_159v,__Z21_il2cpp_strinit_s_15Av,__Z21_il2cpp_strinit_s_15Bv,__Z21_il2cpp_strinit_s_15Cv,__Z21_il2cpp_strinit_s_15Dv,__Z21_il2cpp_strinit_s_176v,__Z21_il2cpp_strinit_s_15Ev,__Z21_il2cpp_strinit_s_15Fv,__Z21_il2cpp_strinit_s_160v,__Z21_il2cpp_strinit_s_161v,__Z21_il2cpp_strinit_s_162v,__Z21_il2cpp_strinit_s_163v,__Z21_il2cpp_strinit_s_164v,__Z21_il2cpp_strinit_s_165v,__Z21_il2cpp_strinit_s_166v,__Z21_il2cpp_strinit_s_167v,__Z21_il2cpp_strinit_s_168v,__Z21_il2cpp_strinit_s_169v,__Z21_il2cpp_strinit_s_16Cv
  ,__Z21_il2cpp_strinit_s_16Av,__Z21_il2cpp_strinit_s_16Bv,__Z21_il2cpp_strinit_s_16Dv,__Z21_il2cpp_strinit_s_175v,__Z21_il2cpp_strinit_s_16Ev,__Z21_il2cpp_strinit_s_16Fv,__Z21_il2cpp_strinit_s_170v,__Z21_il2cpp_strinit_s_171v,__Z21_il2cpp_strinit_s_172v,__Z21_il2cpp_strinit_s_173v,__Z21_il2cpp_strinit_s_174v,__Z21_il2cpp_strinit_s_177v,__Z21_il2cpp_strinit_s_178v,__Z21_il2cpp_strinit_s_179v,__Z21_il2cpp_strinit_s_17Av,__Z21_il2cpp_strinit_s_17Bv,__Z21_il2cpp_strinit_s_17Cv,__Z21_il2cpp_strinit_s_17Dv,__Z21_il2cpp_strinit_s_17Ev,__Z21_il2cpp_strinit_s_17Fv,__Z21_il2cpp_strinit_s_181v,__Z21_il2cpp_strinit_s_180v,__Z21_il2cpp_strinit_s_182v,__Z21_il2cpp_strinit_s_189v,__Z21_il2cpp_strinit_s_188v,__Z21_il2cpp_strinit_s_183v,__Z21_il2cpp_strinit_s_184v,__Z21_il2cpp_strinit_s_185v,__Z21_il2cpp_strinit_s_186v,__Z21_il2cpp_strinit_s_18Fv
  ,__Z21_il2cpp_strinit_s_18Ev,__Z21_il2cpp_strinit_s_187v,__Z21_il2cpp_strinit_s_18Av,__Z21_il2cpp_strinit_s_18Dv,__Z21_il2cpp_strinit_s_18Bv,__Z21_il2cpp_strinit_s_18Cv,__Z21_il2cpp_strinit_s_190v,__Z21_il2cpp_strinit_s_191v,__Z21_il2cpp_strinit_s_192v,__Z21_il2cpp_strinit_s_193v,__Z21_il2cpp_strinit_s_194v,__Z21_il2cpp_strinit_s_195v,__Z21_il2cpp_strinit_s_196v,__Z21_il2cpp_strinit_s_197v,__Z21_il2cpp_strinit_s_198v,__Z21_il2cpp_strinit_s_19Cv,__Z21_il2cpp_strinit_s_19Av,__Z21_il2cpp_strinit_s_19Dv,__Z21_il2cpp_strinit_s_199v,__Z21_il2cpp_strinit_s_19Fv,__Z21_il2cpp_strinit_s_19Bv,__Z21_il2cpp_strinit_s_19Ev,__Z21_il2cpp_strinit_s_1A0v,__Z21_il2cpp_strinit_s_1A1v,__Z21_il2cpp_strinit_s_1A2v,__Z21_il2cpp_strinit_s_1A3v,__Z21_il2cpp_strinit_s_1A4v,__Z21_il2cpp_strinit_s_1A5v,__Z21_il2cpp_strinit_s_1A6v,__Z21_il2cpp_strinit_s_1A7v
  ,__Z21_il2cpp_strinit_s_1A8v,__Z21_il2cpp_strinit_s_1A9v,__Z21_il2cpp_strinit_s_1AAv,__Z21_il2cpp_strinit_s_1ABv,__Z21_il2cpp_strinit_s_1ACv,__Z21_il2cpp_strinit_s_1F4v,__Z21_il2cpp_strinit_s_1ADv,__Z21_il2cpp_strinit_s_1F5v,__Z21_il2cpp_strinit_s_1AEv,__Z21_il2cpp_strinit_s_1F7v,__Z21_il2cpp_strinit_s_1AFv,__Z21_il2cpp_strinit_s_1B0v,__Z21_il2cpp_strinit_s_1B1v,__Z21_il2cpp_strinit_s_1B2v,__Z21_il2cpp_strinit_s_1B3v,__Z21_il2cpp_strinit_s_1B4v,__Z21_il2cpp_strinit_s_1B5v,__Z21_il2cpp_strinit_s_1B6v,__Z21_il2cpp_strinit_s_1B7v,__Z21_il2cpp_strinit_s_1B8v,__Z21_il2cpp_strinit_s_1B9v,__Z21_il2cpp_strinit_s_1D6v,__Z21_il2cpp_strinit_s_1BAv,__Z21_il2cpp_strinit_s_1BBv,__Z21_il2cpp_strinit_s_1BCv,__Z21_il2cpp_strinit_s_1BDv,__Z21_il2cpp_strinit_s_1BEv,__Z21_il2cpp_strinit_s_1BFv,__Z21_il2cpp_strinit_s_1C0v,__Z21_il2cpp_strinit_s_1C1v
  ,__Z21_il2cpp_strinit_s_1C2v,__Z21_il2cpp_strinit_s_1C3v,__Z21_il2cpp_strinit_s_1C4v,__Z21_il2cpp_strinit_s_1C5v,__Z21_il2cpp_strinit_s_1F6v,__Z21_il2cpp_strinit_s_1C9v,__Z21_il2cpp_strinit_s_26Fv,__Z21_il2cpp_strinit_s_1C6v,__Z21_il2cpp_strinit_s_1C7v,__Z21_il2cpp_strinit_s_1C8v,__Z21_il2cpp_strinit_s_1CAv,__Z21_il2cpp_strinit_s_1CBv,__Z21_il2cpp_strinit_s_1CCv,__Z21_il2cpp_strinit_s_1CDv,__Z21_il2cpp_strinit_s_1CEv,__Z21_il2cpp_strinit_s_1CFv,__Z21_il2cpp_strinit_s_1D0v,__Z21_il2cpp_strinit_s_1D1v,__Z21_il2cpp_strinit_s_1D2v,__Z21_il2cpp_strinit_s_1D3v,__Z21_il2cpp_strinit_s_1D4v,__Z21_il2cpp_strinit_s_1D5v,__Z21_il2cpp_strinit_s_1D7v,__Z21_il2cpp_strinit_s_1D8v,__Z21_il2cpp_strinit_s_1D9v,__Z21_il2cpp_strinit_s_1DAv,__Z21_il2cpp_strinit_s_1DBv,__Z21_il2cpp_strinit_s_1DCv,__Z21_il2cpp_strinit_s_1DDv,__Z21_il2cpp_strinit_s_1DEv
  ,__Z21_il2cpp_strinit_s_1DFv,__Z21_il2cpp_strinit_s_1E0v,__Z21_il2cpp_strinit_s_1E1v,__Z21_il2cpp_strinit_s_1E2v,__Z21_il2cpp_strinit_s_1E3v,__Z21_il2cpp_strinit_s_1E5v,__Z21_il2cpp_strinit_s_1E4v,__Z21_il2cpp_strinit_s_1E6v,__Z21_il2cpp_strinit_s_1E7v,__Z21_il2cpp_strinit_s_1E9v,__Z21_il2cpp_strinit_s_1E8v,__Z21_il2cpp_strinit_s_1EAv,__Z21_il2cpp_strinit_s_281v,__Z21_il2cpp_strinit_s_1EBv,__Z21_il2cpp_strinit_s_1EDv,__Z21_il2cpp_strinit_s_1ECv,__Z21_il2cpp_strinit_s_1EEv,__Z21_il2cpp_strinit_s_1EFv,__Z21_il2cpp_strinit_s_1F0v,__Z21_il2cpp_strinit_s_1F1v,__Z21_il2cpp_strinit_s_1F2v,__Z21_il2cpp_strinit_s_1F3v,__Z21_il2cpp_strinit_s_1F8v,__Z21_il2cpp_strinit_s_1F9v,__Z21_il2cpp_strinit_s_1FAv,__Z21_il2cpp_strinit_s_1FBv,__Z21_il2cpp_strinit_s_1FCv,__Z21_il2cpp_strinit_s_1FDv,__Z21_il2cpp_strinit_s_1FEv,__Z21_il2cpp_strinit_s_1FFv
  ,__Z21_il2cpp_strinit_s_200v,__Z21_il2cpp_strinit_s_201v,__Z21_il2cpp_strinit_s_202v,__Z21_il2cpp_strinit_s_203v,__Z21_il2cpp_strinit_s_204v,__Z21_il2cpp_strinit_s_205v,__Z21_il2cpp_strinit_s_206v,__Z21_il2cpp_strinit_s_207v,__Z21_il2cpp_strinit_s_208v,__Z21_il2cpp_strinit_s_209v,__Z21_il2cpp_strinit_s_20Av,__Z21_il2cpp_strinit_s_20Bv,__Z21_il2cpp_strinit_s_20Cv,__Z21_il2cpp_strinit_s_20Dv,__Z21_il2cpp_strinit_s_20Ev,__Z21_il2cpp_strinit_s_20Fv,__Z21_il2cpp_strinit_s_210v,__Z21_il2cpp_strinit_s_211v,__Z21_il2cpp_strinit_s_212v,__Z21_il2cpp_strinit_s_213v,__Z21_il2cpp_strinit_s_214v,__Z21_il2cpp_strinit_s_215v,__Z21_il2cpp_strinit_s_216v,__Z21_il2cpp_strinit_s_217v,__Z21_il2cpp_strinit_s_218v,__Z21_il2cpp_strinit_s_219v,__Z21_il2cpp_strinit_s_21Av,__Z21_il2cpp_strinit_s_21Bv,__Z21_il2cpp_strinit_s_21Cv,__Z21_il2cpp_strinit_s_21Dv
  ,__Z21_il2cpp_strinit_s_21Ev,__Z21_il2cpp_strinit_s_21Fv,__Z21_il2cpp_strinit_s_220v,__Z21_il2cpp_strinit_s_221v,__Z21_il2cpp_strinit_s_222v,__Z21_il2cpp_strinit_s_223v,__Z21_il2cpp_strinit_s_224v,__Z21_il2cpp_strinit_s_225v,__Z21_il2cpp_strinit_s_226v,__Z21_il2cpp_strinit_s_227v,__Z21_il2cpp_strinit_s_228v,__Z21_il2cpp_strinit_s_229v,__Z21_il2cpp_strinit_s_22Av,__Z21_il2cpp_strinit_s_22Bv,__Z21_il2cpp_strinit_s_22Cv,__Z21_il2cpp_strinit_s_22Dv,__Z21_il2cpp_strinit_s_22Ev,__Z21_il2cpp_strinit_s_22Fv,__Z21_il2cpp_strinit_s_230v,__Z21_il2cpp_strinit_s_231v,__Z21_il2cpp_strinit_s_232v,__Z21_il2cpp_strinit_s_233v,__Z21_il2cpp_strinit_s_234v,__Z21_il2cpp_strinit_s_235v,__Z21_il2cpp_strinit_s_236v,__Z21_il2cpp_strinit_s_237v,__Z21_il2cpp_strinit_s_238v,__Z21_il2cpp_strinit_s_239v,__Z21_il2cpp_strinit_s_23Av,__Z21_il2cpp_strinit_s_23Bv
  ,__Z21_il2cpp_strinit_s_23Cv,__Z21_il2cpp_strinit_s_23Dv,__Z21_il2cpp_strinit_s_23Ev,__Z21_il2cpp_strinit_s_23Fv,__Z21_il2cpp_strinit_s_240v,__Z21_il2cpp_strinit_s_241v,__Z21_il2cpp_strinit_s_242v,__Z21_il2cpp_strinit_s_243v,__Z21_il2cpp_strinit_s_244v,__Z21_il2cpp_strinit_s_245v,__Z21_il2cpp_strinit_s_246v,__Z21_il2cpp_strinit_s_247v,__Z21_il2cpp_strinit_s_248v,__Z21_il2cpp_strinit_s_249v,__Z21_il2cpp_strinit_s_24Av,__Z21_il2cpp_strinit_s_24Bv,__Z21_il2cpp_strinit_s_24Cv,__Z21_il2cpp_strinit_s_24Dv,__Z21_il2cpp_strinit_s_24Ev,__Z21_il2cpp_strinit_s_24Fv,__Z21_il2cpp_strinit_s_250v,__Z21_il2cpp_strinit_s_270v,__Z21_il2cpp_strinit_s_251v,__Z21_il2cpp_strinit_s_252v,__Z21_il2cpp_strinit_s_256v,__Z21_il2cpp_strinit_s_253v,__Z21_il2cpp_strinit_s_254v,__Z21_il2cpp_strinit_s_255v,__Z21_il2cpp_strinit_s_257v,__Z21_il2cpp_strinit_s_258v
  ,__Z21_il2cpp_strinit_s_259v,__Z21_il2cpp_strinit_s_25Bv,__Z21_il2cpp_strinit_s_25Cv,__Z21_il2cpp_strinit_s_25Av,__Z21_il2cpp_strinit_s_25Fv,__Z21_il2cpp_strinit_s_260v,__Z21_il2cpp_strinit_s_25Dv,__Z21_il2cpp_strinit_s_25Ev,__Z21_il2cpp_strinit_s_261v,__Z21_il2cpp_strinit_s_262v,__Z21_il2cpp_strinit_s_264v,__Z21_il2cpp_strinit_s_265v,__Z21_il2cpp_strinit_s_263v,__Z21_il2cpp_strinit_s_266v,__Z21_il2cpp_strinit_s_282v,__Z21_il2cpp_strinit_s_267v,__Z21_il2cpp_strinit_s_268v,__Z21_il2cpp_strinit_s_269v,__Z21_il2cpp_strinit_s_28Av,__Z21_il2cpp_strinit_s_26Av,__Z21_il2cpp_strinit_s_26Bv,__Z21_il2cpp_strinit_s_26Cv,__Z21_il2cpp_strinit_s_26Dv,__Z21_il2cpp_strinit_s_26Ev,__Z21_il2cpp_strinit_s_271v,__Z21_il2cpp_strinit_s_272v,__Z21_il2cpp_strinit_s_273v,__Z21_il2cpp_strinit_s_274v,__Z21_il2cpp_strinit_s_275v,__Z21_il2cpp_strinit_s_277v
  ,__Z21_il2cpp_strinit_s_276v,__Z21_il2cpp_strinit_s_278v,__Z21_il2cpp_strinit_s_279v,__Z21_il2cpp_strinit_s_27Av,__Z21_il2cpp_strinit_s_27Dv,__Z21_il2cpp_strinit_s_27Bv,__Z21_il2cpp_strinit_s_27Cv,__Z21_il2cpp_strinit_s_27Ev,__Z21_il2cpp_strinit_s_27Fv,__Z21_il2cpp_strinit_s_280v,__Z21_il2cpp_strinit_s_283v,__Z21_il2cpp_strinit_s_284v,__Z21_il2cpp_strinit_s_285v,__Z21_il2cpp_strinit_s_286v,__Z21_il2cpp_strinit_s_287v,__Z21_il2cpp_strinit_s_288v,__Z21_il2cpp_strinit_s_289v,__Z21_il2cpp_strinit_s_28Bv,__Z21_il2cpp_strinit_s_28Cv,__Z21_il2cpp_strinit_s_28Dv,__Z21_il2cpp_strinit_s_28Ev,__Z21_il2cpp_strinit_s_28Fv,__Z21_il2cpp_strinit_s_290v,__Z21_il2cpp_strinit_s_291v,__Z21_il2cpp_strinit_s_292v,__Z21_il2cpp_strinit_s_293v,__Z21_il2cpp_strinit_s_294v,__Z21_il2cpp_strinit_s_295v,__Z21_il2cpp_strinit_s_296v,__Z21_il2cpp_strinit_s_297v
  ,__Z21_il2cpp_strinit_s_298v,__Z21_il2cpp_strinit_s_299v,__Z21_il2cpp_strinit_s_29Av,__Z21_il2cpp_strinit_s_29Cv,__Z21_il2cpp_strinit_s_29Bv,__Z21_il2cpp_strinit_s_29Ev,__Z21_il2cpp_strinit_s_29Dv,__Z21_il2cpp_strinit_s_29Fv,__Z21_il2cpp_strinit_s_2A0v,__Z21_il2cpp_strinit_s_2A1v,__Z21_il2cpp_strinit_s_2A2v,__Z21_il2cpp_strinit_s_2A3v,__Z21_il2cpp_strinit_s_2A4v,__Z21_il2cpp_strinit_s_2A5v,__Z21_il2cpp_strinit_s_2A6v,__Z21_il2cpp_strinit_s_2A7v,__Z21_il2cpp_strinit_s_2A8v,__Z21_il2cpp_strinit_s_2A9v,__Z20_il2cpp_strinit_s_2Bv,__Z20_il2cpp_strinit_s_3Bv,__Z20_il2cpp_strinit_s_2Cv,__Z20_il2cpp_strinit_s_31v,__Z20_il2cpp_strinit_s_2Dv,__Z20_il2cpp_strinit_s_2Ev,__Z20_il2cpp_strinit_s_2Fv,__Z20_il2cpp_strinit_s_30v,__Z20_il2cpp_strinit_s_32v,__Z20_il2cpp_strinit_s_33v,__Z20_il2cpp_strinit_s_34v,__Z20_il2cpp_strinit_s_35v
  ,__Z20_il2cpp_strinit_s_36v,__Z20_il2cpp_strinit_s_37v,__Z20_il2cpp_strinit_s_38v,__Z20_il2cpp_strinit_s_39v,__Z20_il2cpp_strinit_s_3Av,__Z20_il2cpp_strinit_s_3Cv,__Z20_il2cpp_strinit_s_3Dv,__Z20_il2cpp_strinit_s_3Ev,__Z20_il2cpp_strinit_s_3Fv,__Z20_il2cpp_strinit_s_40v,__Z20_il2cpp_strinit_s_41v,__Z20_il2cpp_strinit_s_42v,__Z20_il2cpp_strinit_s_43v,__Z20_il2cpp_strinit_s_44v,__Z20_il2cpp_strinit_s_45v,__Z20_il2cpp_strinit_s_46v,__Z20_il2cpp_strinit_s_47v,__Z20_il2cpp_strinit_s_48v,__Z20_il2cpp_strinit_s_49v,__Z20_il2cpp_strinit_s_4Av,__Z20_il2cpp_strinit_s_4Bv,__Z20_il2cpp_strinit_s_4Cv,__Z20_il2cpp_strinit_s_4Dv,__Z20_il2cpp_strinit_s_4Ev,__Z20_il2cpp_strinit_s_4Fv,__Z20_il2cpp_strinit_s_50v,__Z20_il2cpp_strinit_s_51v,__Z20_il2cpp_strinit_s_52v,__Z20_il2cpp_strinit_s_53v,__Z20_il2cpp_strinit_s_54v
  ,__Z20_il2cpp_strinit_s_55v,__Z20_il2cpp_strinit_s_56v,__Z20_il2cpp_strinit_s_57v,__Z20_il2cpp_strinit_s_58v,__Z20_il2cpp_strinit_s_59v,__Z21_il2cpp_strinit_s_2AAv,__Z21_il2cpp_strinit_s_2ABv,__Z21_il2cpp_strinit_s_2ACv,__Z21_il2cpp_strinit_s_2ADv,__Z21_il2cpp_strinit_s_2AEv,__Z21_il2cpp_strinit_s_2AFv,__Z21_il2cpp_strinit_s_2B0v,__Z21_il2cpp_strinit_s_2B1v,__Z21_il2cpp_strinit_s_2B2v,__Z21_il2cpp_strinit_s_2B3v,__Z21_il2cpp_strinit_s_2B4v,__Z21_il2cpp_strinit_s_2B5v,__Z21_il2cpp_strinit_s_2B6v,__ZL22s_mscorlibRegistrationv,__ZL26s_replacementsRegistrationv,__ZL25s_System_CoreRegistrationv,__ZL20s_SystemRegistrationv,__ZL25s_UnityEngineRegistrationv,__ZSt17__throw_bad_allocv,__ZN10__cxxabiv112_GLOBAL__N_110construct_Ev,_emscripten_glLoadIdentity__wrapper,_emscripten_glReleaseShaderCompiler__wrapper,_emscripten_glFinish__wrapper,_emscripten_glFlush__wrapper,b102
  ,b102,b102,b102,b102,b102];
  var FUNCTION_TABLE_viid = [b103,__Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Decimal_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_DoubleP22mscorlib_System_Objectd,__Z42mscorlib_System_DateTime_m_AddMillisecondsP24mscorlib_System_DateTimed,__Z37mscorlib_System_DateTime_m_AddSecondsP24mscorlib_System_DateTimed,__Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_DoubleP21mscorlib_System_Arrayid,__Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_DoubleP21mscorlib_System_Arrayid,b103];
  var FUNCTION_TABLE_viiiiff = [b104,__Z47UnityEngine_UnityEngine_Vector3_m_RotateTowardsP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_ff,__Z61UnityEngine_UnityEngine_Vector3_m_INTERNAL_CALL_RotateTowardsP22mscorlib_System_ObjectP31UnityEngine_UnityEngine_Vector3S2_ff,b104];
  var FUNCTION_TABLE_viif = [b105,__ZN5physx3Cct26CharacterControllerManager15setTessellationEbf,__ZNK5physx14NpArticulation14getWorldBoundsEf,__ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE14getWorldBoundsEf,__ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE14getWorldBoundsEf,__ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE14getWorldBoundsEf,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE14getWorldBoundsEf,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE18setProjectionPlaneERKNS_6PxVec3Ef,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE14getWorldBoundsEf,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE18setProjectionPlaneERKNS_6PxVec3Ef,__ZNK5physx7NpCloth14getWorldBoundsEf,__ZNK32RendererMaterialAnimationBinding13SetFloatValueERKN11UnityEngine9Animation10BoundCurveEf,__ZNK24RendererAnimationBinding13SetFloatValueERKN11UnityEngine9Animation10BoundCurveEf,__ZNK28MonoBehaviourPropertyBinding13SetFloatValueERKN11UnityEngine9Animation10BoundCurveEf,__ZN13PhysicsModule24CapsuleColliderSetHeightER15CapsuleColliderf,__ZN13GfxDeviceGLES13SetBlendStateEPK16DeviceBlendStatef,__Z108AssemblyU002DCSharp_JSONObject_m_AddField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringf,__Z108AssemblyU002DCSharp_JSONObject_m_SetField_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_SingleP30AssemblyU002DCSharp_JSONObjectP22mscorlib_System_Stringf,__Z84mscorlib_System_Decimal_m_op_Explicit_mscorlib_System_Decimal_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z111mscorlib_System_Collections_Hashtable_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_SingleP37mscorlib_System_Collections_Hashtableif,__Z133mscorlib_System_Runtime_Serialization_SerializationInfo_m_AddValue_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_SingleP55mscorlib_System_Runtime_Serialization_SerializationInfoP22mscorlib_System_Stringf,__Z84mscorlib_System_Convert_m_ToDateTime_mscorlib_System_DateTime_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z82mscorlib_System_Convert_m_ToDecimal_mscorlib_System_Decimal_mscorlib_System_SingleP22mscorlib_System_Objectf,__Z115UnityEngine_UnityEngine_Object_m_Destroy_mscorlib_System_Void_UnityEngine_UnityEngine_Object_mscorlib_System_SingleP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_Objectf,__Z48UnityEngine_UnityEngine_GradientColorKey_m__ctorP40UnityEngine_UnityEngine_GradientColorKey29UnityEngine_UnityEngine_Colorf,__Z110UnityEngine_UnityEngine_Matrix4x4_m_set_Item_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_SingleP33UnityEngine_UnityEngine_Matrix4x4if,__Z38UnityEngine_UnityEngine_Ray_m_GetPointP27UnityEngine_UnityEngine_Rayf,__Z110UnityEngine_UnityEngine_Material_m_SetFloat_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_SingleP32UnityEngine_UnityEngine_MaterialP22mscorlib_System_Stringf,__Z109UnityEngine_UnityEngine_Material_m_SetFloat_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_SingleP32UnityEngine_UnityEngine_Materialif
  ,__Z68mscorlib_System_Array_m_InternalArray__Insert_mscorlib_System_SingleP21mscorlib_System_Arrayif,__Z70mscorlib_System_Array_m_InternalArray__set_Item_mscorlib_System_SingleP21mscorlib_System_Arrayif,__Z31setPxVehicleGearsData_GearRatioPN5physx18PxVehicleGearsDataENS0_4EnumEf,__Z32setPxVehicleAutoBoxData_UpRatiosPN5physx20PxVehicleAutoBoxDataENS_18PxVehicleGearsData4EnumEf,__Z34setPxVehicleAutoBoxData_DownRatiosPN5physx20PxVehicleAutoBoxDataENS_18PxVehicleGearsData4EnumEf,__Z44setPxVehicleWheelsDynData_WheelRotationSpeedPN5physx22PxVehicleWheelsDynDataEjf,__Z44setPxVehicleWheelsDynData_WheelRotationAnglePN5physx22PxVehicleWheelsDynDataEjf,__Z36setPxVehicleDriveDynData_AnalogInputPN5physx21PxVehicleDriveDynDataEjf,__Z31setPxVehicleNoDrive_BrakeTorquePN5physx16PxVehicleNoDriveEjf,__Z31setPxVehicleNoDrive_DriveTorquePN5physx16PxVehicleNoDriveEjf,__Z30setPxVehicleNoDrive_SteerAnglePN5physx16PxVehicleNoDriveEjf,__ZN5physx18SetTorqueCurvePairEPNS_19PxVehicleEngineDataEjf,__Z12SetupLODFadeR9GfxDeviceRN9ShaderLab17ShaderPassContextEf,__ZN9ShaderLab13PropertySheet8SetFloatERKNS_16FastPropertyNameEf,__Z24Material_CUSTOM_SetFloatP15ScriptingObjectif,__ZN13WheelCollider37UpdateVehicleSpringCMOffsetsAndMassesEP9RigidbodyPN5physx16PxVehicleNoDriveEf,__ZNK17AnimationCurveTplI11QuaternionfE13EvaluateClampEf,__ZNK17AnimationCurveTplI8Vector3fE13EvaluateClampEf,__ZN5Unity8Material8SetFloatEN9ShaderLab16FastPropertyNameEf,__ZN21MaterialPropertyBlock16AddPropertyFloatERKN9ShaderLab16FastPropertyNameEf,_emscripten_glTexParameterf__wrapper,b105,b105,b105,b105,b105,b105,b105,b105,b105
  ,b105,b105,b105,b105,b105];
  var FUNCTION_TABLE_fiffif = [b106,__Z166UnityEngine_UnityEngine_Mathf_m_SmoothDamp_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_Single_mscorlib_System_SingleU0026_ref_mscorlib_System_SingleP22mscorlib_System_ObjectffPff];
  var FUNCTION_TABLE_iiiifi = [b107,__Z57UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_RaycastTryP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_CameraP27UnityEngine_UnityEngine_Rayfi,__Z59UnityEngine_UnityEngine_Camera_m_INTERNAL_CALL_RaycastTry2DP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_CameraP27UnityEngine_UnityEngine_Rayfi,b107];
  var FUNCTION_TABLE_vd = [b108,_emscripten_glClearDepth__wrapper];
  var FUNCTION_TABLE_iiffffff = [b109,__ZN10Matrix4x4f8SetOrthoEffffff];
  var FUNCTION_TABLE_viiiiiiiifiiifiii = [b110,__ZN20TextRenderingPrivate19NativeTextGeneratorC2ERK11UTF16StringPNS_4FontE11ColorRGBA32iRK8Vector2fbifiibfbbP13dynamic_arrayIN2UI8UIVertexELj4EE];
  var FUNCTION_TABLE_fiiff = [b111,__ZN16VirtFuncInvoker2I28mscorlib_System_SingleTraitsS0_S0_E6InvokeEP10MethodInfoPvff];
  var FUNCTION_TABLE_viiifffii = [b112,__ZN12TreeRenderer6RenderER6CameraRKNSt3__16vectorIP5Light13stl_allocatorIS5_L18MemLabelIdentifier44ELi16EEEEfffii];
  var FUNCTION_TABLE_iiiiiiiiiii = [b113,__Z65mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareQuickP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_iiPbS3_b,__Z71mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesForwardCoreP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringPiiiPhbiPP47mscorlib_Mono_Globalization_Unicode_ContractionP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z52mscorlib_System_Text_UTF7Encoding_m_InternalGetBytesP22mscorlib_System_ObjectP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arribPiPbb,__Z336mscorlib_System_Text_UTF8Encoding_m_InternalGetCharCount_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_UInt32_mscorlib_System_UInt32_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriijjS0_PP42mscorlib_System_Text_DecoderFallbackBufferPS2_b,__Z37mscorlib_System_DateTime_m_ParseExactP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_String_arrP48mscorlib_System_Globalization_DateTimeFormatInfoiP24mscorlib_System_DateTimebPbbPP25mscorlib_System_Exception,__ZN16VirtFuncInvoker8I28mscorlib_System_ObjectTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_S1_S1_S1_E6InvokeEP10MethodInfoPvS6_iS6_P22mscorlib_System_ObjectS6_S6_S6_S6_,b113];
  var FUNCTION_TABLE_ii = [b114,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE4syncEv,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE9showmanycEv,__ZNSt3__115basic_stringbufIcNS_11char_traitsIcEENS_9allocatorIcEEE9underflowEv,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE5uflowEv,__ZN6il2cpp2os11MutexHandle4WaitEv,__ZN6il2cpp2os11MutexHandle10IsSignaledEv,__ZN6il2cpp2os11EventHandle4WaitEv,__ZN6il2cpp2os11EventHandle10IsSignaledEv,__ZN6il2cpp2os15SemaphoreHandle4WaitEv,__ZN6il2cpp2os15SemaphoreHandle10IsSignaledEv,__ZNK5physx3Cct13BoxController7getTypeEv,__ZNK5physx3Cct13BoxController11getPositionEv,__ZNK5physx3Cct13BoxController8getActorEv,__ZNK5physx3Cct13BoxController18getNonWalkableModeEv,__ZN5physx3Cct13BoxController8getSceneEv,__ZNK5physx3Cct13BoxController11getUserDataEv,__ZN5physx3Cct13BoxController15getPxControllerEv,__ZThn8_N5physx3Cct13BoxController15getPxControllerEv,__ZNK5physx3Cct17CapsuleController7getTypeEv,__ZNK5physx3Cct17CapsuleController11getPositionEv,__ZNK5physx3Cct17CapsuleController8getActorEv,__ZNK5physx3Cct17CapsuleController18getNonWalkableModeEv,__ZN5physx3Cct17CapsuleController8getSceneEv,__ZNK5physx3Cct17CapsuleController11getUserDataEv,__ZNK5physx3Cct17CapsuleController15getClimbingModeEv,__ZN5physx3Cct17CapsuleController15getPxControllerEv,__ZThn8_N5physx3Cct17CapsuleController15getPxControllerEv,__ZNK5physx3Cct26CharacterControllerManager8getSceneEv
  ,__ZNK5physx3Cct26CharacterControllerManager16getNbControllersEv,__ZN5physx3Cct26CharacterControllerManager15getRenderBufferEv,__ZNK5physx3Cct26CharacterControllerManager21getNbObstacleContextsEv,__ZN5physx3Cct26CharacterControllerManager21createObstacleContextEv,__ZNK5physx2Cm12RenderBuffer11getNbPointsEv,__ZNK5physx2Cm12RenderBuffer9getPointsEv,__ZNK5physx2Cm12RenderBuffer10getNbLinesEv,__ZNK5physx2Cm12RenderBuffer8getLinesEv,__ZNK5physx2Cm12RenderBuffer14getNbTrianglesEv,__ZNK5physx2Cm12RenderBuffer12getTrianglesEv,__ZNK5physx2Cm12RenderBuffer10getNbTextsEv,__ZNK5physx2Cm12RenderBuffer8getTextsEv,__ZNK5physx3Cct15ObstacleContext20getControllerManagerEv,__ZNK5physx3Cct15ObstacleContext14getNbObstaclesEv,__ZNK5physx11PxAggregate19getConcreteTypeNameEv,__ZNK5physx6PxBase12isReleasableEv,__ZNK5physx11NpAggregate11getNbActorsEv,__ZNK5physx11NpAggregate14getMaxNbActorsEv,__ZN5physx11NpAggregate8getSceneEv,__ZNK5physx11NpAggregate16getSelfCollisionEv,__ZNK5physx14PxArticulation19getConcreteTypeNameEv,__ZNK5physx14NpArticulation8getSceneEv,__ZNK5physx14NpArticulation26getMaxProjectionIterationsEv,__ZNK5physx14NpArticulation26getInternalDriveIterationsEv,__ZNK5physx14NpArticulation26getExternalDriveIterationsEv,__ZNK5physx14NpArticulation10isSleepingEv,__ZNK5physx14NpArticulation10getNbLinksEv,__ZNK5physx14NpArticulation7getNameEv,__ZNK5physx14NpArticulation12getAggregateEv,__ZNK5physx19PxArticulationJoint19getConcreteTypeNameEv
  ,__ZNK5physx19NpArticulationJoint20getSwingLimitEnabledEv,__ZNK5physx19NpArticulationJoint20getTwistLimitEnabledEv,__ZNK5physx19NpArticulationJoint13isSubordinateEv,__ZNK5physx18PxArticulationLink19getConcreteTypeNameEv,__ZNK5physx18NpArticulationLink7getTypeEv,__ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE8getSceneEv,__ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE7getNameEv,__ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE17getDominanceGroupEv,__ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE14getOwnerClientEv,__ZNK5physx15NpActorTemplateINS_18PxArticulationLinkEE12getAggregateEv,__ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE11getNbShapesEv,__ZNK5physx20NpRigidActorTemplateINS_18PxArticulationLinkEE16getNbConstraintsEv,__ZNK5physx18NpArticulationLink15getArticulationEv,__ZNK5physx18NpArticulationLink15getInboundJointEv,__ZNK5physx18NpArticulationLink13getNbChildrenEv,__ZNK5physx18NpArticulationLink13isSubordinateEv,__ZNK5physx12NpBatchQuery18getPreFilterShaderEv,__ZNK5physx12NpBatchQuery19getPostFilterShaderEv,__ZNK5physx12NpBatchQuery19getFilterShaderDataEv,__ZNK5physx12NpBatchQuery23getFilterShaderDataSizeEv,__ZNK5physx12NpBatchQuery14getOwnerClientEv,__ZN5physx12NpBatchQuery13getUserMemoryEv,__ZN5physx12NpBatchQuery11getRunOnSpuEv,__ZNK5physx12NpBatchQuery7getDescEv,__ZNK5physx12PxConstraint19getConcreteTypeNameEv,__ZNK5physx12NpConstraint8getSceneEv,__ZNK5physx12NpConstraint13isSubordinateEv,__ZNK5physx10PxMaterial19getConcreteTypeNameEv,__ZNK5physx10NpMaterial17getReferenceCountEv,__ZNK5physx10NpMaterial22getFrictionCombineModeEv
  ,__ZNK5physx10NpMaterial25getRestitutionCombineModeEv,__ZN5physx9NpPhysics13getFoundationEv,__ZN5physx9NpPhysics17getVisualDebuggerEv,__ZN5physx9NpPhysics23getPvdConnectionManagerEv,__ZN5physx9NpPhysics21getProfileZoneManagerEv,__ZNK5physx9NpPhysics18getTolerancesScaleEv,__ZNK5physx9NpPhysics19getNbTriangleMeshesEv,__ZNK5physx9NpPhysics17getNbHeightFieldsEv,__ZNK5physx9NpPhysics17getNbConvexMeshesEv,__ZNK5physx9NpPhysics17getNbClothFabricsEv,__ZNK5physx9NpPhysics11getNbScenesEv,__ZNK5physx9NpPhysics11getNbShapesEv,__ZN5physx9NpPhysics18createArticulationEv,__ZNK5physx9NpPhysics14getNbMaterialsEv,__ZN5physx9NpPhysics27getPhysicsInsertionCallbackEv,__ZN5physx9NpPhysics14getProfileZoneEv,__ZNK5physx14PxRigidDynamic19getConcreteTypeNameEv,__ZNK5physx14NpRigidDynamic7getTypeEv,__ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE8getSceneEv,__ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE7getNameEv,__ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE17getDominanceGroupEv,__ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE14getOwnerClientEv,__ZNK5physx15NpActorTemplateINS_14PxRigidDynamicEE12getAggregateEv,__ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE11getNbShapesEv,__ZNK5physx20NpRigidActorTemplateINS_14PxRigidDynamicEE16getNbConstraintsEv,__ZNK5physx14NpRigidDynamic10isSleepingEv,__ZNK5physx13PxRigidStatic19getConcreteTypeNameEv,__ZNK5physx13NpRigidStatic7getTypeEv,__ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE8getSceneEv,__ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE7getNameEv
  ,__ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE17getDominanceGroupEv,__ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE14getOwnerClientEv,__ZNK5physx15NpActorTemplateINS_13PxRigidStaticEE12getAggregateEv,__ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE11getNbShapesEv,__ZNK5physx20NpRigidActorTemplateINS_13PxRigidStaticEE16getNbConstraintsEv,__ZN5physx7NpScene10getPhysicsEv,__ZNK5physx7NpScene12getTimestampEv,__ZNK5physx7NpScene18getNbArticulationsEv,__ZNK5physx7NpScene16getNbConstraintsEv,__ZNK5physx7NpScene15getNbAggregatesEv,__ZNK5physx7NpScene16getCpuDispatcherEv,__ZNK5physx7NpScene16getGpuDispatcherEv,__ZNK5physx7NpScene16getSpuDispatcherEv,__ZN5physx7NpScene12createClientEv,__ZNK5physx7NpScene34getClothInterCollisionNbIterationsEv,__ZNK5physx7NpScene24getContactModifyCallbackEv,__ZNK5physx7NpScene27getCCDContactModifyCallbackEv,__ZNK5physx7NpScene19getFilterShaderDataEv,__ZNK5physx7NpScene23getFilterShaderDataSizeEv,__ZNK5physx7NpScene15getFilterShaderEv,__ZNK5physx7NpScene17getFilterCallbackEv,__ZNK5physx7NpScene15getCCDMaxPassesEv,__ZNK5physx7NpScene15getFrictionTypeEv,__ZNK5physx7NpScene26getVisualizationCullingBoxEv,__ZN5physx7NpScene15getRenderBufferEv,__ZNK5physx7NpScene18getStaticStructureEv,__ZNK5physx7NpScene19getDynamicStructureEv,__ZNK5physx7NpScene29getDynamicTreeRebuildRateHintEv,__ZNK5physx7NpScene28getSceneQueryStaticTimestampEv,__ZNK5physx7NpScene17getBroadPhaseTypeEv
  ,__ZNK5physx7NpScene22getNbBroadPhaseRegionsEv,__ZNK5physx7NpScene14getTaskManagerEv,__ZNK5physx7NpScene26getNbContactDataBlocksUsedEv,__ZNK5physx7NpScene29getMaxNbContactDataBlocksUsedEv,__ZNK5physx7NpScene32getContactReportStreamBufferSizeEv,__ZNK5physx7NpScene18getSolverBatchSizeEv,__ZN5physx7NpScene14getTaskManagerEv,__ZNK5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSolveEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx14PxLightCpuTask12getReferenceEv,__ZNK5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_14executeCollideEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_7NpSceneEXadL_ZNS2_12executeSceneEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm10FanoutTask7getNameEv,__ZNK5physx2Cm10FanoutTask12getReferenceEv,__ZNK5physx7NpScene15SceneCompletion7getNameEv,__ZNK5physx7PxShape19getConcreteTypeNameEv,__ZNK5physx7NpShape15getGeometryTypeEv,__ZNK5physx7NpShape8getActorEv,__ZNK5physx7NpShape14getNbMaterialsEv,__ZNK5physx7NpShape11isExclusiveEv,__ZNK5physx7NpShape7getNameEv,__ZNK5physx13NpVolumeCache7isValidEv,__ZN5physx13NpVolumeCache17getNbCachedShapesEv,__ZN5physx13NpVolumeCache20getMaxNbStaticShapesEv,__ZN5physx13NpVolumeCache21getMaxNbDynamicShapesEv,__ZNK5physx15PxParticleFluid19getConcreteTypeNameEv,__ZNK5physx15NpParticleFluid7getTypeEv,__ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE8getSceneEv,__ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE7getNameEv,__ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE17getDominanceGroupEv,__ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE14getOwnerClientEv
  ,__ZNK5physx15NpActorTemplateINS_15PxParticleFluidEE12getAggregateEv,__ZN5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE20lockParticleReadDataEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE15getMaxParticlesEv,__ZN5physx15NpParticleFluid25lockParticleFluidReadDataEv,__ZNK5physx22NpParticleBaseTemplateINS_15PxParticleFluidENS_15NpParticleFluidEE7getTypeEv,__ZNK5physx16PxParticleSystem19getConcreteTypeNameEv,__ZNK5physx16NpParticleSystem7getTypeEv,__ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE8getSceneEv,__ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE7getNameEv,__ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE17getDominanceGroupEv,__ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE14getOwnerClientEv,__ZNK5physx15NpActorTemplateINS_16PxParticleSystemEE12getAggregateEv,__ZN5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE20lockParticleReadDataEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE15getMaxParticlesEv,__ZNK5physx22NpParticleBaseTemplateINS_16PxParticleSystemENS_16NpParticleSystemEE7getTypeEv,__ZNK5physx7PxCloth19getConcreteTypeNameEv,__ZNK5physx7NpCloth7getTypeEv,__ZNK5physx15NpActorTemplateINS_7PxClothEE8getSceneEv,__ZNK5physx15NpActorTemplateINS_7PxClothEE7getNameEv,__ZNK5physx15NpActorTemplateINS_7PxClothEE17getDominanceGroupEv,__ZNK5physx15NpActorTemplateINS_7PxClothEE14getOwnerClientEv,__ZNK5physx15NpActorTemplateINS_7PxClothEE12getAggregateEv,__ZNK5physx7NpCloth9getFabricEv,__ZNK5physx7NpCloth14getNbParticlesEv,__ZNK5physx7NpCloth16lockParticleDataEv,__ZNK5physx7NpCloth26getNbParticleAccelerationsEv,__ZNK5physx7NpCloth22getNbMotionConstraintsEv,__ZNK5physx7NpCloth26getNbSeparationConstraintsEv,__ZNK5physx7NpCloth21getNbCollisionSpheresEv,__ZNK5physx7NpCloth22getNbCollisionCapsulesEv
  ,__ZNK5physx7NpCloth20getNbCollisionPlanesEv,__ZNK5physx7NpCloth22getNbCollisionConvexesEv,__ZNK5physx7NpCloth23getNbCollisionTrianglesEv,__ZNK5physx7NpCloth21getNbVirtualParticlesEv,__ZNK5physx7NpCloth27getNbVirtualParticleWeightsEv,__ZNK5physx7NpCloth25getNbSelfCollisionIndicesEv,__ZNK5physx7NpCloth18getNbRestPositionsEv,__ZNK5physx7NpCloth10isSleepingEv,__ZNK5physx13PxClothFabric19getConcreteTypeNameEv,__ZNK5physx13NpClothFabric14getNbParticlesEv,__ZNK5physx13NpClothFabric11getNbPhasesEv,__ZNK5physx13NpClothFabric15getNbRestvaluesEv,__ZNK5physx13NpClothFabric9getNbSetsEv,__ZNK5physx13NpClothFabric20getNbParticleIndicesEv,__ZNK5physx13NpClothFabric12getNbTethersEv,__ZNK5physx13NpClothFabric17getReferenceCountEv,__ZNK5physx2Sc16ActorInteraction13getNPhaseCoreEv,__ZThn24_NK5physx2Sc16ActorInteraction13getNPhaseCoreEv,__ZNK5physx2Sc21ElementSimInteraction13getNPhaseCoreEv,__ZNK5physx2Sc21ElementSimInteraction23isLastFilterInteractionEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13ccdBroadPhaseEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19updateCCDSinglePassEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11postCCDPassEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_11collideStepEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9solveStepEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10broadPhaseEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_20rigidBodyNarrowPhaseEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_9islandGenEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_13postIslandGenEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_19islandGenSecondPassEPNS_10PxBaseTaskEEEE7getNameEv
  ,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_23postIslandGenSecondPassEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_6solverEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_10postSolverEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18updateCCDMultiPassEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_15postNarrowPhaseEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc5SceneEXadL_ZNS3_18clothPreprocessingEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Sc23ElementActorInteraction23isLastFilterInteractionEv,__ZNK5physx2Sc19ParticlePacketShape8isActiveEv,__ZNK5physx2Cm12DelegateTaskINS_2Sc17ParticleSystemSimEXadL_ZNS3_21prepareCollisionInputEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Sc10ClothShape8isActiveEv,__ZNK5physx5cloth8SwFabric10getFactoryEv,__ZNK5physx5cloth8SwFabric12getNumPhasesEv,__ZNK5physx5cloth8SwFabric16getNumRestvaluesEv,__ZNK5physx5cloth8SwFabric10getNumSetsEv,__ZNK5physx5cloth8SwFabric13getNumIndicesEv,__ZNK5physx5cloth8SwFabric15getNumParticlesEv,__ZNK5physx5cloth8SwFabric13getNumTethersEv,__ZThn4_NK5physx5cloth8SwFabric10getFactoryEv,__ZThn4_NK5physx5cloth8SwFabric12getNumPhasesEv,__ZThn4_NK5physx5cloth8SwFabric16getNumRestvaluesEv,__ZThn4_NK5physx5cloth8SwFabric10getNumSetsEv,__ZThn4_NK5physx5cloth8SwFabric13getNumIndicesEv,__ZThn4_NK5physx5cloth8SwFabric15getNumParticlesEv,__ZThn4_NK5physx5cloth8SwFabric13getNumTethersEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE9getFabricEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE10getFactoryEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE15getNumParticlesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE14getTranslationEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE11getRotationEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE26getAccelerationFilterWidthEv
  ,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE13getNumSpheresEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE14getNumCapsulesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE12getNumPlanesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE14getNumConvexesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE15getNumTrianglesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE28isContinuousCollisionEnabledEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE22getNumVirtualParticlesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE28getNumVirtualParticleWeightsEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE23getNumMotionConstraintsEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE27getNumSeparationConstraintsEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE27getNumParticleAccelerationsEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE26getNumSelfCollisionIndicesEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE19getNumRestPositionsEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE20getBoundingBoxCenterEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE19getBoundingBoxScaleEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE20getSleepTestIntervalEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE18getSleepAfterCountEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE17getSleepPassCountEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE8isAsleepEv,__ZNK5physx5cloth9ClothImplINS0_7SwClothEE11getUserDataEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE9getFabricEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE10getFactoryEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE15getNumParticlesEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE14getTranslationEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE11getRotationEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE26getAccelerationFilterWidthEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE13getNumSpheresEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE14getNumCapsulesEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE12getNumPlanesEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE14getNumConvexesEv
  ,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE15getNumTrianglesEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE28isContinuousCollisionEnabledEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE22getNumVirtualParticlesEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE28getNumVirtualParticleWeightsEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE23getNumMotionConstraintsEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE27getNumSeparationConstraintsEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE27getNumParticleAccelerationsEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE26getNumSelfCollisionIndicesEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE19getNumRestPositionsEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE20getBoundingBoxCenterEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE19getBoundingBoxScaleEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE20getSleepTestIntervalEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE18getSleepAfterCountEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE17getSleepPassCountEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE8isAsleepEv,__ZThn4_NK5physx5cloth9ClothImplINS0_7SwClothEE11getUserDataEv,__ZNK5physx5cloth8SwSolver29getInterCollisionNbIterationsEv,__ZNK5physx5cloth8SwSolver8hasErrorEv,__ZThn4_NK5physx5cloth8SwSolver29getInterCollisionNbIterationsEv,__ZThn4_NK5physx5cloth8SwSolver8hasErrorEv,__ZNK5physx5cloth8SwSolver22CpuClothSimulationTask7getNameEv,__ZNK5physx5cloth8SwSolver19StartSimulationTask7getNameEv,__ZNK5physx5cloth8SwSolver17EndSimulationTask7getNameEv,__ZNK5physx14SingleAABBTask7getNameEv,__ZNK5physx13ActorAABBTask7getNameEv,__ZNK5physx17AggregateAABBTask7getNameEv,__ZNK5physx20SingleAABBUpdateTask7getNameEv,__ZNK5physx19ActorAABBUpdateTask7getNameEv,__ZNK5physx23AggregateAABBUpdateTask7getNameEv,__ZNK5physx10BPWorkTask7getNameEv
  ,__ZNK5physx20ProcessBPResultsTask7getNameEv,__ZNK5physx20AggregateOverlapTask7getNameEv,__ZNK5physx16PxsBroadPhaseMBP12getNbRegionsEv,__ZNK5physx16PxsBroadPhaseMBP24getNumOutOfBoundsObjectsEv,__ZNK5physx16PxsBroadPhaseMBP21getOutOfBoundsObjectsEv,__ZNK5physx16PxsBroadPhaseMBP7getTypeEv,__ZNK5physx16PxsBroadPhaseMBP18getNumCreatedPairsEv,__ZN5physx16PxsBroadPhaseMBP15getCreatedPairsEv,__ZNK5physx16PxsBroadPhaseMBP18getNumDeletedPairsEv,__ZN5physx16PxsBroadPhaseMBP15getDeletedPairsEv,__ZNK5physx16PxBroadPhaseBase12getNbRegionsEv,__ZNK5physx16PxBroadPhaseBase24getNumOutOfBoundsObjectsEv,__ZNK5physx16PxBroadPhaseBase21getOutOfBoundsObjectsEv,__ZNK5physx23PxsBroadPhaseContextSap7getTypeEv,__ZNK5physx23PxsBroadPhaseContextSap18getNumCreatedPairsEv,__ZN5physx23PxsBroadPhaseContextSap15getCreatedPairsEv,__ZNK5physx23PxsBroadPhaseContextSap18getNumDeletedPairsEv,__ZN5physx23PxsBroadPhaseContextSap15getDeletedPairsEv,__ZNK5physx29BroadPhaseBatchUpdateWorkTask7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_18postCCDDepenetrateEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_14postCCDAdvanceEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_13PxsCCDContextEXadL_ZNS2_12postCCDSweepEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx17PxsCCDAdvanceTask7getNameEv,__ZNK5physx15PxsCCDSweepTask7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_28mergeCMDiscreteUpdateResultsEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_10PxsContextEXadL_ZNS2_23prepareCMDiscreteUpdateEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK23PxsCMDiscreteUpdateTask7getNameEv,__ZNK20PxsAtomIntegrateTask7getNameEv,__ZNK5physx38PxsSolverCreateFinalizeConstraintsTask7getNameEv,__ZNK21PxsCreateFinalizeTask7getNameEv
  ,__ZNK5physx32PxsSolverConstraintPartitionTask7getNameEv,__ZNK5physx23PxsSolverSetupSolveTask7getNameEv,__ZNK21PxsParallelSolverTask7getNameEv,__ZNK5physx16PxsSolverEndTask7getNameEv,__ZNK5physx18PxsSolverStartTask7getNameEv,__ZNK5physx34PxsSolverConstraintPostProcessTask7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_17PxsFluidCollisionEXadL_ZNS2_12mergeResultsEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx21PxsFluidCollisionTask7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_10mergeForceEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_16PxsFluidDynamicsEXadL_ZNS2_12mergeDensityEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx23PxsFluidDynamicsSphTask7getNameEv,__ZNK5physx17MBPUpdateWorkTask7getNameEv,__ZNK5physx21MBPPostUpdateWorkTask7getNameEv,__ZNK5physx15PxsParticleData16getMaxParticlesVEv,__ZNK5physx15PxsParticleData17getParticleCountVEv,__ZNK5physx16PxsParticleShape12getUserDataVEv,__ZN5physx20PxsParticleSystemSim17getParticleStateVEv,__ZNK5physx20PxsParticleSystemSim24getExternalAccelerationVEv,__ZNK5physx20PxsParticleSystemSim12isSimulatedVEv,__ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_25spatialHashUpdateSectionsEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_21collisionFinalizationEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_15collisionUpdateEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_14dynamicsUpdateEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_24packetShapesFinalizationEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx2Cm12DelegateTaskINS_20PxsParticleSystemSimEXadL_ZNS2_18packetShapesUpdateEPNS_10PxBaseTaskEEEE7getNameEv,__ZNK5physx17SapUpdateWorkTask7getNameEv,__ZNK5physx21SapPostUpdateWorkTask7getNameEv,__ZNK5physx16PxVehicleNoDrive19getConcreteTypeNameEv,__ZNK5physx18PxVehicleDriveTank19getConcreteTypeNameEv,__ZNK5physx16PxVehicleDriveNW19getConcreteTypeNameEv
  ,__ZNK5physx16PxVehicleDrive4W19getConcreteTypeNameEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE19getConcreteTypeNameEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE13isSubordinateEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE12getClassSizeEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE19getConcreteTypeNameEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE13isSubordinateEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE12getClassSizeEv,__ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE19getConcreteTypeNameEv,__ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE13isSubordinateEv,__ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE12getClassSizeEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE19getConcreteTypeNameEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE13isSubordinateEv,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE12getClassSizeEv,__ZN5physx18RepXSerializerImplINS_16PxVehicleDrive4WEE11getTypeNameEv,__ZN5physx18RepXSerializerImplINS_18PxVehicleDriveTankEE11getTypeNameEv,__ZN5physx18RepXSerializerImplINS_16PxVehicleDriveNWEE11getTypeNameEv,__ZN5physx18RepXSerializerImplINS_16PxVehicleNoDriveEE11getTypeNameEv,__ZNK5physx14PxVehicleDrive19getConcreteTypeNameEv,__ZN5physx25PxVehicleConstraintShader11prepareDataEv,__ZN5physx25PxVehicleConstraintShader15getSerializableEv,__ZN5physx7Cooking9getParamsEv,__ZN5physx7Cooking16platformMismatchEv,__ZNK5physx14PxTriangleMesh19getConcreteTypeNameEv,__ZNK5physx2Gu12TriangleMesh13getNbVerticesEv,__ZNK5physx2Gu12TriangleMesh11getVerticesEv,__ZNK5physx2Gu12TriangleMesh14getNbTrianglesEv,__ZNK5physx2Gu12TriangleMesh12getTrianglesEv,__ZNK5physx2Gu12TriangleMesh17getTrianglesRemapEv,__ZNK5physx2Gu12TriangleMesh17getReferenceCountEv,__ZNK5physx12PxConvexMesh19getConcreteTypeNameEv
  ,__ZNK5physx2Gu10ConvexMesh13getNbVerticesEv,__ZNK5physx2Gu10ConvexMesh11getVerticesEv,__ZNK5physx2Gu10ConvexMesh14getIndexBufferEv,__ZNK5physx2Gu10ConvexMesh13getNbPolygonsEv,__ZNK5physx2Gu10ConvexMesh17getReferenceCountEv,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21getProfileZoneManagerEv,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE7getNameEv,__ZNK5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10hasClientsEv,__ZThn116_NK5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE10hasClientsEv,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE7getNameEv,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE21getProfileZoneManagerEv,__ZNK5physx9PxTaskMgr16getCpuDispatcherEv,__ZNK5physx9PxTaskMgr16getGpuDispatcherEv,__ZNK5physx9PxTaskMgr16getSpuDispatcherEv,__ZNK5physx6shdfnd10Foundation16getErrorCallbackEv,__ZNK5physx6shdfnd10Foundation13getErrorLevelEv,__ZNK5physx6shdfnd10Foundation12getAllocatorEv,__ZNK5physx6shdfnd10Foundation20getAllocatorCallbackEv,__ZNK5physx6shdfnd10Foundation24getReportAllocationNamesEv,__ZNK5physx13PxHeightField19getConcreteTypeNameEv,__ZNK5physx2Gu11HeightField9getNbRowsEv,__ZNK5physx2Gu11HeightField12getNbColumnsEv,__ZNK5physx2Gu11HeightField9getFormatEv,__ZNK5physx2Gu11HeightField15getSampleStrideEv,__ZNK5physx2Gu11HeightField17getReferenceCountEv,__ZNK13BaseAllocator7GetNameEv,__ZNK13BaseAllocator10IsAssignedEv,__ZN13BaseAllocator14CheckIntegrityEv,__ZNK13BaseAllocator22GetAllocatedMemorySizeEv,__ZNK13BaseAllocator21GetReservedMemorySizeEv
  ,__ZNK13BaseAllocator26GetPeakAllocatedMemorySizeEv,__ZNK13BaseAllocator24GetBookKeepingMemorySizeEv,__ZNK13BaseAllocator22GetNumberOfAllocationsEv,__ZNK13BaseAllocator16IsDelayedReleaseEv,__ZN20DynamicHeapAllocatorI17LowLevelAllocatorE14CheckIntegrityEv,__ZNK12TLSAllocatorI14StackAllocatorE10IsAssignedEv,__ZN12TLSAllocatorI14StackAllocatorE14CheckIntegrityEv,__ZNK12TLSAllocatorI14StackAllocatorE22GetAllocatedMemorySizeEv,__ZNK12TLSAllocatorI14StackAllocatorE21GetReservedMemorySizeEv,__ZNK12TLSAllocatorI14StackAllocatorE24GetBookKeepingMemorySizeEv,__ZNK6Object7GetNameEv,__ZN6Object39ShouldIgnoreInGarbageDependencyTrackingEv,__ZNK6Object20GetRuntimeMemorySizeEv,__ZNK6Object25GetClassIDVirtualInternalEv,__ZNK6Object25GetNeedsPerObjectTypeTreeEv,__ZNK15EditorExtension25GetClassIDVirtualInternalEv,__ZNK16LevelGameManager7GetNameEv,__ZNK16LevelGameManager25GetClassIDVirtualInternalEv,__ZNK16LevelGameManager19ShouldWriteForBuildEv,__ZNK17GlobalGameManager7GetNameEv,__ZNK17GlobalGameManager25GetClassIDVirtualInternalEv,__ZNK11GameManager25GetClassIDVirtualInternalEv,__ZNK5Unity10GameObject7GetNameEv,__ZNK5Unity10GameObject25GetClassIDVirtualInternalEv,__ZNK5Unity9Component7GetNameEv,__ZNK5Unity9Component25GetClassIDVirtualInternalEv,__ZN5Unity9Component26CalculateSupportedMessagesEv,__ZNK11NamedObject7GetNameEv,__ZNK11NamedObject25GetClassIDVirtualInternalEv,__ZN10TagManager39ShouldIgnoreInGarbageDependencyTrackingEv
  ,__ZNK10TagManager25GetClassIDVirtualInternalEv,__ZNK8GUILayer25GetClassIDVirtualInternalEv,__ZNK12BaseRenderer14AllowsBatchingEv,__ZNK12BaseRenderer19GetStaticBatchIndexEv,__ZNK12BaseRenderer14GetMeshIDSmallEv,__ZNK12BaseRenderer23GetDistanceSortPriorityEv,__ZNK6Camera25GetClassIDVirtualInternalEv,__ZNK10FlareLayer25GetClassIDVirtualInternalEv,__ZNK16GraphicsSettings25GetClassIDVirtualInternalEv,__ZNK11HaloManager25GetClassIDVirtualInternalEv,__ZNK20IntermediateRenderer8GetLayerEv,__ZNK20IntermediateRenderer16GetMaterialCountEv,__ZNK20IntermediateRenderer12GetLayerMaskEv,__ZN20IntermediateRenderer7GetMeshEv,__ZNK24MeshIntermediateRenderer14AllowsBatchingEv,__ZN24MeshIntermediateRenderer7GetMeshEv,__ZNK48MeshIntermediateRendererWithDistanceSortingOrder23GetDistanceSortPriorityEv,__ZNK5Light25GetClassIDVirtualInternalEv,__ZNK11LightProbes25GetClassIDVirtualInternalEv,__ZNK14RenderSettings25GetClassIDVirtualInternalEv,__ZN4Mesh39ShouldIgnoreInGarbageDependencyTrackingEv,__ZNK4Mesh20GetRuntimeMemorySizeEv,__ZNK4Mesh25GetClassIDVirtualInternalEv,__ZNK10MeshFilter25GetClassIDVirtualInternalEv,__ZNK12MeshRenderer25GetClassIDVirtualInternalEv,__ZNK8Renderer8GetLayerEv,__ZNK8Renderer16GetMaterialCountEv,__ZNK12MeshRenderer14AllowsBatchingEv,__ZNK12MeshRenderer19GetStaticBatchIndexEv,__ZNK12MeshRenderer14GetMeshIDSmallEv
  ,__ZThn28_NK12MeshRenderer14AllowsBatchingEv,__ZThn28_NK8Renderer8GetLayerEv,__ZThn28_NK8Renderer16GetMaterialCountEv,__ZThn28_NK12MeshRenderer19GetStaticBatchIndexEv,__ZThn28_NK12MeshRenderer14GetMeshIDSmallEv,__ZNK9Behaviour25GetClassIDVirtualInternalEv,__ZNK18DelayedCallManager25GetClassIDVirtualInternalEv,__ZN22BlockMemoryCacheWriter12GetCacheSizeEv,__ZN22BlockMemoryCacheWriter13GetFileLengthEv,__ZN15CacheWriterBase18GetAddressOfMemoryEv,__ZN9GfxDevice17CreateIndexBufferEv,__ZN9GfxDevice18CreateVertexBufferEv,__ZN9GfxDevice23CreateGPUSkinPoseBufferEv,__ZN9GfxDevice25GetBackBufferColorSurfaceEv,__ZN9GfxDevice25GetBackBufferDepthSurfaceEv,__ZN9GfxDevice15CreateTextureIDEv,__ZN9GfxDevice18HandleInvalidStateEv,__ZN9GfxDevice19IsReadyToBeginFrameEv,__ZN9GfxDevice14InsertCPUFenceEv,__ZN9GfxDevice15GetNextCPUFenceEv,__ZN9GfxDevice14BeginRecordingEv,__ZNK9GfxDevice18GetDefaultRTFormatEv,__ZNK9GfxDevice21GetDefaultHDRRTFormatEv,__ZN9GfxDevice18GetNativeGfxDeviceEv,__ZN9GfxDevice21CreateComputeBufferIDEv,__ZN9GfxDevice13GetStereoModeEv,__ZN9GfxDevice16GetMultiGPUCountEv,__ZN9GfxDevice13GetCurrentGPUEv,__ZNK10GpuProgram11IsSupportedEv,__ZNK11MonoManager25GetClassIDVirtualInternalEv
  ,__ZN7Texture39ShouldIgnoreInGarbageDependencyTrackingEv,__ZNK9Texture2D20GetRuntimeMemorySizeEv,__ZNK7Cubemap25GetClassIDVirtualInternalEv,__ZNK7Cubemap12GetDimensionEv,__ZNK9Texture2D20GetUnscaledTextureIDEv,__ZNK9Texture2D12GetDataWidthEv,__ZNK9Texture2D13GetDataHeightEv,__ZNK9Texture2D13IsNPOTAllowedEv,__ZNK9Texture2D10GetGLWidthEv,__ZNK9Texture2D11GetGLHeightEv,__ZNK7Texture9HasMipMapEv,__ZNK9Texture2D12CountMipmapsEv,__ZNK16LightmapSettings25GetClassIDVirtualInternalEv,__ZNK15QualitySettings25GetClassIDVirtualInternalEv,__ZNK8Renderer25GetClassIDVirtualInternalEv,__ZNK13RenderTexture20GetRuntimeMemorySizeEv,__ZNK13RenderTexture25GetClassIDVirtualInternalEv,__ZNK13RenderTexture12GetDimensionEv,__ZNK7Texture20GetUnscaledTextureIDEv,__ZNK13RenderTexture12GetDataWidthEv,__ZNK13RenderTexture13GetDataHeightEv,__ZNK7Texture13IsNPOTAllowedEv,__ZNK7Texture10GetGLWidthEv,__ZNK7Texture11GetGLHeightEv,__ZNK13RenderTexture9HasMipMapEv,__ZNK13RenderTexture12CountMipmapsEv,__ZN13ScreenManager22SetRequestedResolutionEv,__ZNK13ScreenManager13GetShowCursorEv,__ZNK13ScreenManager13GetLockCursorEv,__ZNK13ScreenManager24GetAllowLayeredRenderingEv
  ,__ZNK13ScreenManager16GetScreenTimeoutEv,__ZNK13ScreenManager12GetIsFocusedEv,__ZNK13ScreenManager21GetCursorInsideWindowEv,__ZNK13ScreenManager8GetWidthEv,__ZNK13ScreenManager9GetHeightEv,__ZNK13ScreenManager12IsFullScreenEv,__ZNK13ScreenManager21IsMultiDisplayEnabledEv,__ZNK13ScreenManager20GetScreenOrientationEv,__ZNK7Texture25GetClassIDVirtualInternalEv,__ZNK9Texture2D25GetClassIDVirtualInternalEv,__ZNK9Texture2D12GetDimensionEv,__ZNK9Texture3D20GetRuntimeMemorySizeEv,__ZNK9Texture3D25GetClassIDVirtualInternalEv,__ZNK9Texture3D12GetDimensionEv,__ZNK9Texture3D12GetDataWidthEv,__ZNK9Texture3D13GetDataHeightEv,__ZNK9Texture3D9HasMipMapEv,__ZNK9Texture3D12CountMipmapsEv,__ZNK9Transform25GetClassIDVirtualInternalEv,__ZN9Transform26CalculateSupportedMessagesEv,__ZNK5Unity8Material20GetRuntimeMemorySizeEv,__ZNK18ProceduralMaterial25GetClassIDVirtualInternalEv,__ZNK12InputManager25GetClassIDVirtualInternalEv,__ZNK11TimeManager25GetClassIDVirtualInternalEv,__ZN11AssetBundle39ShouldIgnoreInGarbageDependencyTrackingEv,__ZNK11AssetBundle25GetClassIDVirtualInternalEv,__ZN14AsyncOperation11GetPriorityEv,__ZN14AsyncOperation23GetAllowSceneActivationEv,__ZNK13BuildSettings25GetClassIDVirtualInternalEv,__ZN23PreloadManagerOperation6IsDoneEv
  ,__ZN23PreloadManagerOperation11GetPriorityEv,__ZN23PreloadManagerOperation21MustCompleteNextFrameEv,__ZNK23PreloadManagerOperation25GetAllowParallelExecutionEv,__ZN11PreloadData39ShouldIgnoreInGarbageDependencyTrackingEv,__ZNK11PreloadData25GetClassIDVirtualInternalEv,__ZN18LoadLevelOperation23GetAllowSceneActivationEv,__ZN18LoadLevelOperation21MustCompleteNextFrameEv,__ZNK27UnloadUnusedAssetsOperation25GetAllowParallelExecutionEv,__ZNK14PlayerSettings25GetClassIDVirtualInternalEv,__ZN15ResourceManager39ShouldIgnoreInGarbageDependencyTrackingEv,__ZNK15ResourceManager25GetClassIDVirtualInternalEv,__ZNK13MonoBehaviour7GetNameEv,__ZNK13MonoBehaviour25GetClassIDVirtualInternalEv,__ZNK13MonoBehaviour25GetNeedsPerObjectTypeTreeEv,__ZN13MonoBehaviour26CalculateSupportedMessagesEv,__ZN10MonoScript39ShouldIgnoreInGarbageDependencyTrackingEv,__ZNK10MonoScript25GetClassIDVirtualInternalEv,__ZNK10MonoScript18GetScriptClassNameEv,__ZN19ScriptingInvocation5CheckEv,__ZN25ScriptingInvocationNoArgs5CheckEv,__ZNK9TextAsset25GetClassIDVirtualInternalEv,__ZNK9TextAsset18GetScriptClassNameEv,__ZN14FileCacherRead12GetCacheSizeEv,__ZN14FileCacherRead13GetFileLengthEv,__ZN15CacheReaderBase18GetAddressOfMemoryEv,__ZN22MemoryCacherReadBlocks12GetCacheSizeEv,__ZN22MemoryCacherReadBlocks13GetFileLengthEv,__ZN22MemoryCacherReadBlocks18GetAddressOfMemoryEv,__ZNK5Unity8Material25GetClassIDVirtualInternalEv,__ZNK6Shader7GetNameEv
  ,__ZNK6Shader25GetClassIDVirtualInternalEv,__ZNK6Shader18GetScriptClassNameEv,__ZNK12ScriptMapper25GetClassIDVirtualInternalEv,__ZN16MemoryFileSystem4NameEv,__ZNK10MemoryFile6IsOpenEv,__ZN10MemoryFile5CloseEv,__ZNK10MemoryFile8PositionEv,__ZNK10MemoryFile4SizeEv,__ZN10MemoryFile5FlushEv,__ZNK25MultiBlocksMemoryFileData4SizeEv,__ZN22LocalFileSystemHandler4NameEv,__ZN22LocalFileSystemHandler9LastErrorEv,__ZNK19CharacterController25GetClassIDVirtualInternalEv,__ZNK8Collider16SupportsMaterialEv,__ZNK8Collider15SupportsTriggerEv,__ZN8Collider12GetIsTriggerEv,__ZNK8Collider12GetRigidbodyEv,__ZNK5physx23PxCapsuleControllerDesc7isValidEv,__ZNK8Collider25GetClassIDVirtualInternalEv,__ZNK12MeshCollider25GetClassIDVirtualInternalEv,__ZNK14PhysicsManager25GetClassIDVirtualInternalEv,__ZNK18PhysxJobDispatcher14getWorkerCountEv,__ZNK9Rigidbody25GetClassIDVirtualInternalEv,__ZNK14AudioBehaviour25GetClassIDVirtualInternalEv,__ZNK10SampleClip25GetClassIDVirtualInternalEv,__ZNK10SampleClip12GetLoadStateEv,__ZNK9AudioClip25GetClassIDVirtualInternalEv,__ZNK13AudioListener25GetClassIDVirtualInternalEv,__ZNK12AudioManager25GetClassIDVirtualInternalEv,__ZNK9Animation25GetClassIDVirtualInternalEv
  ,__ZNK6Motion25GetClassIDVirtualInternalEv,__ZNK13AnimationClip25GetClassIDVirtualInternalEv,__ZN13AnimationClip9IsLoopingEv,__ZN13AnimationClip13IsHumanMotionEv,__ZNK13AnimationClip8IsLegacyEv,__ZNK8Animator25GetClassIDVirtualInternalEv,__ZNK8Animator12IsInitializeEv,__ZNK8Animator25GetStateMachineBehavioursEv,__ZNK8Animator41GetStateMachineBehaviourVectorDescriptionEv,__ZNK8Animator16GetObjectPointerEv,__ZThn32_NK8Animator12IsInitializeEv,__ZThn32_NK8Animator25GetStateMachineBehavioursEv,__ZThn32_NK8Animator41GetStateMachineBehaviourVectorDescriptionEv,__ZThn32_NK8Animator16GetObjectPointerEv,__ZNK25RuntimeAnimatorController25GetClassIDVirtualInternalEv,__ZNK18AnimatorController25GetClassIDVirtualInternalEv,__ZN18AnimatorController8GetAssetEv,__ZN18AnimatorController23GetAnimationSetBindingsEv,__ZNK18AnimatorController17GetAnimationClipsEv,__ZNK18AnimatorController13GetBehavioursEv,__ZNK18AnimatorController41GetStateMachineBehaviourVectorDescriptionEv,__ZNK18AnimatorController28HasMultiThreadedStateMachineEv,__ZNK7Terrain25GetClassIDVirtualInternalEv,__ZNK14TerrainManager16GetActiveTerrainEv,__ZNK14TerrainManager17GetActiveTerrainsEv,__ZNK14TerrainManager31GetSplatBaseMaterialTextureNameEv,__ZNK24TreeIntermediateRenderer14AllowsBatchingEv,__ZNK24TreeIntermediateRenderer8GetLayerEv,__ZNK26LegacyTreeInstanceRenderer16GetMaterialCountEv,__ZNK24TreeIntermediateRenderer12GetLayerMaskEv
  ,__ZN24TreeIntermediateRenderer7GetMeshEv,__ZNK23LODTreeInstanceRenderer14AllowsBatchingEv,__ZNK23LODTreeInstanceRenderer16GetMaterialCountEv,__ZNK20TextRenderingPrivate4Font25GetClassIDVirtualInternalEv,__ZNK20TextRenderingPrivate8TextMesh25GetClassIDVirtualInternalEv,__ZNK2UI6Canvas25GetClassIDVirtualInternalEv,__ZNK18ScreenManagerWebGL13GetShowCursorEv,__ZNK18ScreenManagerWebGL13GetLockCursorEv,__ZNK18ScreenManagerWebGL8GetWidthEv,__ZNK18ScreenManagerWebGL9GetHeightEv,__ZNK18ScreenManagerWebGL12IsFullScreenEv,__ZN13GfxDeviceGLES12GetSRGBWriteEv,__ZNK13GfxDeviceGLES12GetWireframeEv,__ZNK13GfxDeviceGLES18GetWorldViewMatrixEv,__ZNK13GfxDeviceGLES14GetWorldMatrixEv,__ZNK13GfxDeviceGLES13GetViewMatrixEv,__ZNK13GfxDeviceGLES19GetProjectionMatrixEv,__ZNK13GfxDeviceGLES25GetDeviceProjectionMatrixEv,__ZNK13GfxDeviceGLES16IsScissorEnabledEv,__ZN13GfxDeviceGLES17CreateIndexBufferEv,__ZN13GfxDeviceGLES18CreateVertexBufferEv,__ZN13GfxDeviceGLES23CreateGPUSkinPoseBufferEv,__ZN13GfxDeviceGLES27GetActiveRenderDepthSurfaceEv,__ZN13GfxDeviceGLES26GetActiveRenderTargetCountEv,__ZN13GfxDeviceGLES14GetPresentModeEv,__ZN13GfxDeviceGLES12IsValidStateEv,__ZN13GfxDeviceGLES18HandleInvalidStateEv,__ZNK13GfxDeviceGLES18GetDefaultRTFormatEv,__ZNK13GfxDeviceGLES21GetDefaultHDRRTFormatEv,__ZN13GfxDeviceGLES16CreateDynamicVBOEv
  ,__ZNK9GfxBuffer6IsLostEv,__ZNK17GPUSkinPoseBuffer12GetBoneCountEv,__Z48AssemblyU002DCSharp_JSONObject_m_get_isContainerP30AssemblyU002DCSharp_JSONObject,__Z42AssemblyU002DCSharp_JSONObject_m_get_CountP30AssemblyU002DCSharp_JSONObject,__Z43AssemblyU002DCSharp_JSONObject_m_get_nullJOP22mscorlib_System_Object,__Z40AssemblyU002DCSharp_JSONObject_m_get_objP22mscorlib_System_Object,__Z40AssemblyU002DCSharp_JSONObject_m_get_arrP22mscorlib_System_Object,__Z45AssemblyU002DCSharp_JSONObject_m_get_IsNumberP30AssemblyU002DCSharp_JSONObject,__Z43AssemblyU002DCSharp_JSONObject_m_get_IsNullP30AssemblyU002DCSharp_JSONObject,__Z45AssemblyU002DCSharp_JSONObject_m_get_IsStringP30AssemblyU002DCSharp_JSONObject,__Z43AssemblyU002DCSharp_JSONObject_m_get_IsBoolP30AssemblyU002DCSharp_JSONObject,__Z44AssemblyU002DCSharp_JSONObject_m_get_IsArrayP30AssemblyU002DCSharp_JSONObject,__Z45AssemblyU002DCSharp_JSONObject_m_get_IsObjectP30AssemblyU002DCSharp_JSONObject,__Z37AssemblyU002DCSharp_JSONObject_m_CopyP30AssemblyU002DCSharp_JSONObject,__Z64AssemblyU002DCSharp_JSONObject_m_ToString_mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__Z45AssemblyU002DCSharp_JSONObject_m_ToDictionaryP30AssemblyU002DCSharp_JSONObject,__Z109AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024_m_MoveNextP98AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_U0024,__Z108AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243_m_GetEnumeratorP92AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_U0024SubtractNewPlatformVelocityU00243,__Z64AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_TooSteepP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z83AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_SubtractNewPlatformVelocityP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z72AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_MoveWithPlatformP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z70AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsGroundedTestP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z65AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsJumpingP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z65AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsSlidingP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z73AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsTouchingCeilingP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z66AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_IsGroundedP53AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__Z80AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsMovingBackwardsP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z72AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsJumpingP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z73AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsGroundedP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z71AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsMovingP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController
  ,__Z81AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_HasJumpReachedApexP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z84AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_IsGroundedWithTimeoutP60AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__ZL120mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController,__ZL86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController,__ZL89mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_BJController,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object,__ZL76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object,__ZL79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Object,__ZL120mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder,__ZL86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder,__ZL89mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_LevelBuilder,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String,__ZL76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String,__ZL79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_String,__Z108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m_System_Collections_IEnumerator_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char,__Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m_MoveNextP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char,__Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char_m_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Char,__ZL129mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject,__ZL95mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_MoveNextP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject1051,__ZL98mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_get_CurrentP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject,__ZL121mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object,__ZL87mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_MoveNextP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object,__ZL90mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_CurrentP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object,__ZL131mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL132mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL111mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRootP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArrayP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_CapacityP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL77mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_get_CountP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL91mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_get_DefaultP22mscorlib_System_Object
  ,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m_System_Collections_IEnumerator_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type,__ZL74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m_MoveNextP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type,__ZL77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type_m_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Type,__ZL139mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL140mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL119mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_get_SyncRootP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL83mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_ToArrayP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL88mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_get_CapacityP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL85mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject_m_get_CountP73mscorlib_System_Collections_Generic_List_1_AssemblyU002DCSharp_JSONObject,__ZL118mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject,__ZL84mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject,__ZL87mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject,__ZL99mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m_get_DefaultP22mscorlib_System_Object,__ZL131mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL132mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL111mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_System_Collections_ICollection_get_SyncRootP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_ToArrayP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL80mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_get_CapacityP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL77mscorlib_System_Collections_Generic_List_1_mscorlib_System_String_m_get_CountP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_String,__ZL121mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String,__ZL87mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_MoveNextP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String,__ZL90mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String_m_get_CurrentP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_String,__ZL91mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m_get_DefaultP22mscorlib_System_Object,__ZL149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_ICollection_get_SyncRootP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL150mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IDictionary_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CountP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_ValuesP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRootP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object
  ,__ZL233mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL150mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IDictionary_GetEnumeratorP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CountP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_ValuesP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_KeyP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL117mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_ValueP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL116mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_ToStringP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z193mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z159mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNextP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m_System_Collections_IEnumerator_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m_MoveNextP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32,__Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32_m_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int32,__Z128mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link,__Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_Link,__ZL190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL165mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRootP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL131mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CountP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL175mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL141mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNextP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL144mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL159mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL125mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNextP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentValueP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z131mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry,__Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry_m_MoveNextP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_DictionaryEntry,__ZL129mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_MoveNextP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL132mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_CurrentP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_KeyP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String
  ,__ZL117mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_ValueP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL116mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_ToStringP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z193mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__Z159mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_MoveNextP148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL191mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL165mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_ICollection_get_SyncRootP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL131mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CountP119mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL175mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL141mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_MoveNextP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL144mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentP130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL159mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_System_Collections_IEnumerator_get_CurrentP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL125mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_MoveNextP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentValueP114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL129mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_MoveNextP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL132mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String_m_get_CurrentP118mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_String,__ZL157mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_get_SyncRootP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL241mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL240mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL158mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IDictionary_GetEnumeratorP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL123mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CountP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_ValuesP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_KeyP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_ValueP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL124mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_ToStringP113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z201mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z167mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_MoveNextP156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL198mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL199mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_ICollection_get_SyncRootP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject
  ,__ZL139mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CountP127mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL183mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_MoveNextP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL152mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentP138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL167mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_System_Collections_IEnumerator_get_CurrentP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL133mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_MoveNextP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL141mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentValueP122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL137mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_MoveNextP126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__ZL140mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_get_CurrentP126mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject,__Z89mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m_get_DefaultP22mscorlib_System_Object,__Z123mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m_System_Collections_IEnumerator_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type,__Z89mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m_MoveNextP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type,__Z92mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type_m_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharp_JSONObject_Type,__ZL137System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object,__ZL138System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object,__ZL83System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object_m_get_CountP71System_Core_System_Collections_Generic_HashSet_1_mscorlib_System_Object,__Z164mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__Z130mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object_m_MoveNextP119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_Object,__ZL127System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object,__ZL93System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_MoveNextP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object,__ZL96System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object_m_get_CurrentP82System_Core_System_Collections_Generic_HashSet_1_Enumerator_mscorlib_System_Object,__Z148mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_ICollection_get_SyncRootP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z232mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z231mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z149mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IDictionary_GetEnumeratorP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z114mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CountP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_ValuesP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z114mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_KeyP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z116mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_ValueP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_ToStringP104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32
  ,__Z192mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IEnumerator_get_CurrentP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_MoveNextP147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z189mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z190mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z164mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_ICollection_get_SyncRootP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CountP118mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z174mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IEnumerator_get_CurrentP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_MoveNextP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z143mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z158mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_System_Collections_IEnumerator_get_CurrentP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_MoveNextP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z132mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentValueP113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_MoveNextP117mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z131mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_get_CurrentP117mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32,__Z90mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m_get_DefaultP22mscorlib_System_Object,__ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m_System_Collections_IEnumerator_get_CurrentP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m_MoveNextP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo,__ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo_m_get_CurrentP79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldInfo,__ZL127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo,__ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo,__ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyInfo,__ZL131mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook,__ZL97mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_MoveNextP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook,__ZL100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_m_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook,__Z144mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes,__Z110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes,__Z113mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxes,__Z120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe,__Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Keyframe,__Z149mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m_System_Collections_IEnumerator_get_CurrentP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump
  ,__Z115mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m_MoveNextP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump,__Z118mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump_m_get_CurrentP104mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJump,__ZL141mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL107mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotor,__ZL131mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController,__ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m_MoveNextP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController,__ZL100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController_m_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CharacterController,__ZL70Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object_m_ToStringP59Boo_Lang_Boo_Lang_GenericGenerator_1_mscorlib_System_Object,__ZL114Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object,__ZL83Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_get_CurrentP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object,__ZL145mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_System_Collections_IEnumerator_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL111mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_MoveNextP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL114mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController_m_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputController,__ZL150mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__ZL116mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__ZL119mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputController,__Z157mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m_System_Collections_IEnumerator_get_CurrentP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility,__Z123mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m_MoveNextP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility,__Z126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility_m_get_CurrentP112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibility,__ZL135mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute,__ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute,__Z150mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes,__Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes,__Z119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModes,__ZL140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerDisplayAttribute,__ZL144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute
  ,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerStepThroughAttribute,__ZL142mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerTypeProxyAttribute,__ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame,__ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame,__ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_StackFrame,__Z132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions,__Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_CompareOptions,__ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar,__ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar,__ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_Calendar,__Z137mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags,__Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags,__Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeFormatFlags,__Z132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles,__Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_DateTimeStyles,__Z140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes,__Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_GregorianCalendarTypes,__Z130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_NumberStyles,__Z133mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory,__Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Globalization_UnicodeCategory,__ZL136mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m_System_Collections_IEnumerator_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder
  ,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m_MoveNextP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder_m_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ParameterBuilder,__ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__ZL133mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder,__ZL99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_MethodBuilder,__ZL138mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m_System_Collections_IEnumerator_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m_MoveNextP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_ConstructorBuilder,__ZL135mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_PropertyBuilder,__ZL132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder,__ZL98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder,__ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_Emit_FieldBuilder,__ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase,__ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodBase,__ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCompanyAttribute,__ZL145mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m_System_Collections_IEnumerator_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m_MoveNextP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute_m_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyConfigurationAttribute,__ZL141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyCopyrightAttribute,__ZL144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute
  ,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDefaultAliasAttribute,__ZL141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDelaySignAttribute,__ZL143mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m_System_Collections_IEnumerator_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m_MoveNextP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute_m_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyDescriptionAttribute,__ZL143mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m_System_Collections_IEnumerator_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m_MoveNextP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute_m_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyFileVersionAttribute,__ZL152mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m_System_Collections_IEnumerator_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m_MoveNextP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute_m_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyInformationalVersionAttribute,__ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyFileAttribute,__ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyKeyNameAttribute,__Z132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags,__Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyNameFlags,__ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyProductAttribute,__ZL137mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTitleAttribute,__ZL141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute
  ,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_AssemblyTrademarkAttribute,__Z127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags,__Z93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_BindingFlags,__Z133mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions,__Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_CallingConventions,__Z130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_EventAttributes,__Z130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_FieldAttributes,__Z126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes,__Z92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MemberTypes,__Z131mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes,__Z97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m_MoveNextP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes,__Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes_m_get_CurrentP86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodAttributes,__Z135mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes,__Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes,__Z104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodImplAttributes,__Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo,__Z86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo,__Z89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PInfo,__Z134mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m_System_Collections_IEnumerator_get_CurrentP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes,__Z100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m_MoveNextP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes,__Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes_m_get_CurrentP89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterAttributes,__Z133mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes
  ,__Z99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes,__Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_PropertyAttributes,__Z129mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m_System_Collections_IEnumerator_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes,__Z95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m_MoveNextP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes_m_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_TypeAttributes,__ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_NeutralResourcesLanguageAttribute,__ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Resources_SatelliteContractVersionAttribute,__Z151mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations,__Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations,__Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxations,__ZL160mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m_System_Collections_IEnumerator_get_CurrentP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m_MoveNextP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL129mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute_m_get_CurrentP115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttribute,__ZL155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m_System_Collections_IEnumerator_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m_MoveNextP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute_m_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttribute,__Z137mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint,__Z103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint,__Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_LoadHint,__ZL152mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m_System_Collections_IEnumerator_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m_MoveNextP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute_m_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_StringFreezingAttribute,__Z136mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m_System_Collections_IEnumerator_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer,__Z102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m_MoveNextP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer,__Z105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer_m_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Cer,__Z144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency
  ,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency,__Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_Consistency,__ZL161mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m_System_Collections_IEnumerator_get_CurrentP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m_MoveNextP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute_m_get_CurrentP116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttribute,__ZL151mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttribute,__Z146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType,__Z112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType,__Z115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ClassInterfaceType,__ZL156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m_System_Collections_IEnumerator_get_CurrentP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__ZL122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m_MoveNextP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute_m_get_CurrentP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttribute,__Z144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType,__Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComInterfaceType,__ZL150mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttribute,__ZL148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m_System_Collections_IEnumerator_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m_MoveNextP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute_m_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_PreserveSigAttribute,__ZL155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m_System_Collections_IEnumerator_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m_MoveNextP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute_m_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttribute,__ZL151mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttribute,__Z141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType
  ,__Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_UnmanagedType,__ZL144mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__ZL146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__Z142mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType,__Z108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType,__Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoType,__ZL143mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_System_Collections_IEnumerator_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_MoveNextP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_get_CurrentP98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute,__ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_Contexts_IContextAttribute,__Z140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode,__Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Remoting_WellKnownObjectMode,__Z159mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m_System_Collections_IEnumerator_get_CurrentP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle,__Z125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m_MoveNextP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle,__Z128mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle_m_get_CurrentP114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyle,__Z155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m_System_Collections_IEnumerator_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle,__Z121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m_MoveNextP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle,__Z124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle_m_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyle,__Z152mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m_System_Collections_IEnumerator_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel,__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m_MoveNextP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel,__Z121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel_m_get_CurrentP107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevel,__Z148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m_System_Collections_IEnumerator_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates
  ,__Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m_MoveNextP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates,__Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates_m_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_Serialization_StreamingContextStates,__Z138mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m_System_Collections_IEnumerator_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy,__Z104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m_MoveNextP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy,__Z107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy_m_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_Principal_PrincipalPolicy,__ZL142mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SecuritySafeCriticalAttribute,__ZL151mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttribute,__ZL138mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m_System_Collections_IEnumerator_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m_MoveNextP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute_m_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Security_UnverifiableCodeAttribute,__Z125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState,__Z91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState,__Z94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Threading_ThreadState,__Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets,__Z86mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets,__Z89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeTargets,__Z85mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime_m_get_DefaultP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m_get_DefaultP22mscorlib_System_Object,__Z118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which,__Z84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which,__Z87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTime_Which,__Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m_System_Collections_IEnumerator_get_CurrentP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind,__Z82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m_MoveNextP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind,__Z85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind_m_get_CurrentP71mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DateTimeKind,__Z91mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset_m_get_DefaultP22mscorlib_System_Object,__Z99mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m_get_DefaultP22mscorlib_System_Object
  ,__Z66mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_get_HasValueP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan,__Z63mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_get_ValueP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan,__Z65mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_GetHashCodeP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan,__Z62mscorlib_System_Nullable_1_mscorlib_System_TimeSpan_m_ToStringP51mscorlib_System_Nullable_1_mscorlib_System_TimeSpan,__Z113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m_System_Collections_IEnumerator_get_CurrentP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m_MoveNextP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek,__Z82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek_m_get_CurrentP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_DayOfWeek,__ZL118mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute,__ZL84mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute,__ZL87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_FlagsAttribute,__Z81mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid_m_get_DefaultP22mscorlib_System_Object,__Z89mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m_get_DefaultP22mscorlib_System_Object,__Z122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization,__Z88mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization,__Z91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_LoaderOptimization,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m_System_Collections_IEnumerator_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType,__ZL78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m_MoveNextP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType,__ZL81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType_m_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoType,__ZL126mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute,__ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute,__ZL95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_NonSerializedAttribute,__Z114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m_System_Collections_IEnumerator_get_CurrentP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID,__Z80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m_MoveNextP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID,__Z83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID_m_get_CurrentP69mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_PlatformID,__ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute,__ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ThreadStaticAttribute,__Z85mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan_m_get_DefaultP22mscorlib_System_Object,__Z93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m_get_DefaultP22mscorlib_System_Object,__Z112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m_System_Collections_IEnumerator_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode
  ,__Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m_MoveNextP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode,__Z81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode_m_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_TypeCode,__ZL144mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_MoveNextP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL113mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera_m_get_CurrentP99mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCamera,__ZL148mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_System_Collections_IEnumerator_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__ZL114mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_MoveNextP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__ZL117mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController_m_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonController,__Z141mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState,__Z107mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState,__Z110mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_AssemblyU002DUnityScriptU002Dfirstpass_CharacterState,__ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animation,__ZL128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall,__ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapperlessIcall,__ZL137mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL103mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL106mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_DisallowMultipleComponent,__ZL129mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m_System_Collections_IEnumerator_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode,__ZL95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m_MoveNextP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode,__ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode_m_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ExecuteInEditMode,__ZL128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent,__ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RequireComponent,__ZL108System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_System_Collections_ICollection_get_SyncRootP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type,__ZL128System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type,__ZL68System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_PopP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type,__ZL74System_System_Collections_Generic_Stack_1_mscorlib_System_Type_m_get_CountP62System_System_Collections_Generic_Stack_1_mscorlib_System_Type
  ,__ZL110System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_ICollection_get_SyncRootP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__ZL130System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__ZL70System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_PopP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__ZL76System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_get_CountP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__ZL120System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_System_Collections_IEnumerator_get_CurrentP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object,__ZL86System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_MoveNextP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object,__ZL89System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object_m_get_CurrentP75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Object,__ZL118System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m_System_Collections_IEnumerator_get_CurrentP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type,__ZL84System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m_MoveNextP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type,__ZL87System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type_m_get_CurrentP73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_Type,__ZL125mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_MonoBehaviour,__ZL129mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL130mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL109mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_System_Collections_ICollection_get_SyncRootP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL73mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_ToArrayP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL78mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_get_CapacityP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL75mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type_m_get_CountP63mscorlib_System_Collections_Generic_List_1_mscorlib_System_Type,__ZL119mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type,__ZL85mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_MoveNextP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type,__ZL88mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type_m_get_CurrentP74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Type,__ZL89mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m_get_DefaultP22mscorlib_System_Object,__Z132mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier,__Z98mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier,__Z101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterModifier,__ZL129mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m_System_Collections_IEnumerator_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute,__ZL95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m_MoveNextP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute,__ZL98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute_m_get_CurrentP84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WritableAttribute,__ZL136mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m_System_Collections_IEnumerator_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly
  ,__ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m_MoveNextP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly_m_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssemblyIsEditorAssembly,__ZL127mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption,__ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption,__ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption,__Z135mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__Z101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMouseEvents_HitInfo,__ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Camera,__ZL128mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo,__ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo,__ZL97mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ParameterInfo,__ZL133mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour,__ZL99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour,__ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_StateMachineBehaviour,__Z179mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_ICollection_get_SyncRootP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z263mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z262mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z180mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IDictionary_GetEnumeratorP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z145mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CountP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z146mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_ValuesP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z145mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_KeyP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z147mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_ValueP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z146mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_ToStringP135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z223mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEnumerator_get_CurrentP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z189mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP178mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__ZL117mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m_System_Collections_IEnumerator_get_CurrentP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event,__ZL83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m_MoveNextP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event_m_get_CurrentP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Event
  ,__Z133mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z220mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z221mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z195mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_ICollection_get_SyncRootP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z161mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CountP149mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z205mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEnumerator_get_CurrentP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z171mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z174mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z189mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEnumerator_get_CurrentP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z155mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z163mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentValueP144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z159mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_MoveNextP148mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__Z162mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_CurrentP148mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp,__ZL98mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m_get_DefaultP22mscorlib_System_Object,__Z114mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_get_DefaultP22mscorlib_System_Object,__Z139mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping,__Z105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping,__Z108mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextEditor_DblClickSnapping,__Z120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex,__Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UIVertex,__Z141mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z142mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z121mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_ICollection_get_SyncRootP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z85mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_ToArrayP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z90mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_get_CapacityP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex_m_get_CountP75mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UIVertex,__Z131mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IEnumerator_get_CurrentP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex,__Z97mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex_m_MoveNextP86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertex
  ,__Z101mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m_get_DefaultP22mscorlib_System_Object,__Z122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo,__Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UICharInfo,__Z143mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z144mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z123mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_ICollection_get_SyncRootP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_ToArrayP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_get_CapacityP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z89mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo_m_get_CountP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UICharInfo,__Z133mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo,__Z99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo_m_MoveNextP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfo,__Z103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m_get_DefaultP22mscorlib_System_Object,__Z122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo,__Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UILineInfo,__Z143mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z144mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z123mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_ICollection_get_SyncRootP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z87mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_ToArrayP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z92mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_get_CapacityP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z89mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo_m_get_CountP77mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_UILineInfo,__Z133mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo,__Z99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo_m_MoveNextP88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfo,__Z103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m_get_DefaultP22mscorlib_System_Object,__ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Component,__ZL122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GameObject,__ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object
  ,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Object,__ZL154mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL155mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL134mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_ICollection_get_SyncRootP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL98mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_ToArrayP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL103mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_CapacityP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL100mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_CountP88mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL133mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_PersistentCall,__ZL144mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IEnumerator_get_CurrentP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall,__ZL110mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_MoveNextP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall,__ZL113mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall_m_get_CurrentP99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCall,__ZL114mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m_get_DefaultP22mscorlib_System_Object,__ZL157mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL158mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL137mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_ICollection_get_SyncRootP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL101mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_ToArrayP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL106mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_CapacityP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL103mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_CountP91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL136mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IEnumerator_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL102mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_MoveNextP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL105mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_CurrentP91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL147mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL113mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_MoveNextP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL116mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_CurrentP102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCall,__ZL117mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_get_DefaultP22mscorlib_System_Object,__ZL135mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog
  ,__ZL104mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_UserAuthorizationDialog,__ZL142mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__ZL145mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m_System_Collections_IEnumerator_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m_MoveNextP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL114mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute_m_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttribute,__ZL142mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m_System_Collections_IEnumerator_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m_MoveNextP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute_m_get_CurrentP97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenamedSerializedDataAttribute,__Z138mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m_System_Collections_IEnumerator_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules,__Z104mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m_MoveNextP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules,__Z107mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules_m_get_CurrentP93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRules,__ZL146mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL115mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__ZL123mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m_System_Collections_IEnumerator_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m_MoveNextP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle,__ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle_m_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AssetBundle,__Z130mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions,__Z96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions,__Z99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SendMessageOptions,__Z125mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType,__Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType,__Z94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PrimitiveType,__Z117mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m_System_Collections_IEnumerator_get_CurrentP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space,__Z83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m_MoveNextP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space,__Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space_m_get_CurrentP72mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Space,__Z119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType
  ,__Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_LogType,__ZL128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu,__ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AddComponentMenu,__ZL128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject,__ZL97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ScriptableObject,__Z128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags,__Z94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags,__Z97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CameraClearFlags,__ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Renderer,__ZL127mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe,__ZL93mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe,__ZL96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_ReflectionProbe,__ZL119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture,__ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Texture2D,__ZL125mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_RenderTexture,__ZL122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIElement,__ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer
  ,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayer,__Z178mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_ICollection_get_SyncRootP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z262mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z261mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z179mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IDictionary_GetEnumeratorP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z144mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CountP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z145mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_ValuesP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z144mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_KeyP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z146mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_ValueP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z145mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_ToStringP134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z222mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEnumerator_get_CurrentP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z188mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP177mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL140mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL106mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL109mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z219mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z220mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z194mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_ICollection_get_SyncRootP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CountP148mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z204mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEnumerator_get_CurrentP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z170mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z173mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z188mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEnumerator_get_CurrentP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z154mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z162mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentValueP143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z158mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_MoveNextP147mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__Z161mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_CurrentP147mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZL121mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_get_DefaultP22mscorlib_System_Object,__ZL137mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry,__ZL103mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_MoveNextP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry
  ,__ZL106mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_get_CurrentP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry,__ZL147mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL148mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL127mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_ICollection_get_SyncRootP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL91mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_ToArrayP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL96mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_CapacityP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL93mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_CountP81mscorlib_System_Collections_Generic_List_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL126mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutEntry,__ZL107mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m_get_DefaultP22mscorlib_System_Object,__Z132mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type,__Z98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type,__Z101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUILayoutOption_Type,__ZL119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUISkin,__ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_GUIStyle,__ZL159mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_ICollection_get_SyncRootP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL243mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_get_IsReadOnlyP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL242mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_IEnumerableU003CSystem_Collections_Generic_KeyValuePairU003CTKeyU002CTValueU003EU003E_GetEnumeratorP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL160mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IDictionary_GetEnumeratorP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CountP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_ValuesP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_KeyP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL127mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_ValueP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL126mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_ToStringP115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__Z203mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEnumerator_get_CurrentP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle
  ,__Z169mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_MoveNextP158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL200mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_IEnumerableU003CTValueU003E_GetEnumeratorP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL201mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_Generic_ICollectionU003CTValueU003E_get_IsReadOnlyP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL175mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_ICollection_get_SyncRootP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL141mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CountP129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL185mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEnumerator_get_CurrentP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL151mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_MoveNextP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL154mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL169mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEnumerator_get_CurrentP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL135mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_MoveNextP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentValueP124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL139mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_MoveNextP128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL142mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_get_CurrentP128mscorlib_System_Collections_Generic_Dictionary_2_ShimEnumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle,__ZL101mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m_get_DefaultP22mscorlib_System_Object,__Z121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle,__Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle,__Z90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_FontStyle,__Z119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode,__Z85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode,__Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_KeyCode,__Z121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType,__Z87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType,__Z90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventType,__Z126mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers,__Z92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers,__Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_EventModifiers,__ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAsset,__ZL137mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables
  ,__ZL103mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables,__ZL106mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializePrivateVariables,__ZL126mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField,__ZL92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField,__ZL95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_SerializeField,__ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Shader,__ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Material,__ZL133mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_Generic_IEnumerableU003CTU003E_GetEnumeratorP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL134mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_Generic_ICollectionU003CTU003E_get_IsReadOnlyP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL113mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_System_Collections_ICollection_get_SyncRootP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL77mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_ToArrayP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL82mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_get_CapacityP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL79mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr_m_get_CountP67mscorlib_System_Collections_Generic_List_1_mscorlib_System_Byte_arr,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m_System_Collections_IEnumerator_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr,__ZL78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m_MoveNextP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr,__ZL81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr_m_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_arr,__ZL123mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_System_Collections_IEnumerator_get_CurrentP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr,__ZL89mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_MoveNextP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr,__ZL92mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr_m_get_CurrentP78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arr,__ZL93mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m_get_DefaultP22mscorlib_System_Object,__Z108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m_System_Collections_IEnumerator_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte,__Z74mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m_MoveNextP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte,__Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte_m_get_CurrentP63mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Byte,__ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Behaviour
  ,__ZL119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Display,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_IntPtr,__ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Transform,__ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Motion,__ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Rigidbody,__ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Collider,__Z126mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m_System_Collections_IEnumerator_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags,__Z92mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m_MoveNextP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags,__Z95mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags_m_get_CurrentP81mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_CollisionFlags,__ZL121mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip,__ZL90mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AudioClip,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Single,__Z120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode,__Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode,__Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_WrapMode,__Z132mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m_System_Collections_IEnumerator_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource
  ,__Z98mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m_MoveNextP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource,__Z101mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource_m_get_CurrentP87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationEventSource,__ZL125mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip,__ZL91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip,__ZL94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_AnimationClip,__Z120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode,__Z86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode,__Z89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_PlayMode,__ZL120mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m_System_Collections_IEnumerator_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator,__ZL86mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m_MoveNextP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator,__ZL89mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator_m_get_CurrentP75mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Animator,__ZL119mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m_System_Collections_IEnumerator_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m_MoveNextP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain,__ZL88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain_m_get_CurrentP74mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Terrain,__Z122mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m_System_Collections_IEnumerator_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor,__Z88mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m_MoveNextP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor,__Z91mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor_m_get_CurrentP77mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_TextAnchor,__Z130mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode,__Z96mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode,__Z99mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_HorizontalWrapMode,__Z128mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m_System_Collections_IEnumerator_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode,__Z94mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m_MoveNextP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode,__Z97mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode_m_get_CurrentP83mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_VerticalWrapMode,__ZL116mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m_System_Collections_IEnumerator_get_CurrentP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font,__ZL82mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m_MoveNextP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font,__ZL85mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font_m_get_CurrentP71mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Font,__ZL118mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m_System_Collections_IEnumerator_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas,__ZL84mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m_MoveNextP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas,__ZL87mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas_m_get_CurrentP73mscorlib_System_Array_InternalEnumerator_1_UnityEngine_UnityEngine_Canvas,__ZL150mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute
  ,__ZL116mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL119mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_System_Core_System_Runtime_CompilerServices_ExtensionAttribute,__ZL124mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m_System_Collections_IEnumerator_get_CurrentP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute,__ZL90mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m_MoveNextP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute,__ZL93mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute_m_get_CurrentP79mscorlib_System_Array_InternalEnumerator_1_System_Core_System_MonoTODOAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m_System_Collections_IEnumerator_get_CurrentP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute,__ZL79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m_MoveNextP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute,__ZL82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute_m_get_CurrentP68mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Attribute,__ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute,__ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SerializableAttribute,__ZL127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m_System_Collections_IEnumerator_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute,__ZL93mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m_MoveNextP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute,__ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute_m_get_CurrentP82mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_AttributeUsageAttribute,__ZL147mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m_System_Collections_IEnumerator_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__ZL113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m_MoveNextP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__ZL116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute_m_get_CurrentP102mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComVisibleAttribute,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m_System_Collections_IEnumerator_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m_MoveNextP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64,__Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64_m_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int64,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt32,__ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute,__ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_CLSCompliantAttribute,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt64,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m_System_Collections_IEnumerator_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte
  ,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m_MoveNextP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte,__Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte_m_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_SByte,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m_System_Collections_IEnumerator_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16,__Z75mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m_MoveNextP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16,__Z78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16_m_get_CurrentP64mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Int16,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16,__Z79mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16_m_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UInt16,__Z110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m_System_Collections_IEnumerator_get_CurrentP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double,__Z76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double_m_MoveNextP65mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Double,__Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m_System_Collections_IEnumerator_get_CurrentP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean,__Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m_MoveNextP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean,__Z80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean_m_get_CurrentP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Boolean,__Z111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m_System_Collections_IEnumerator_get_CurrentP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr,__Z77mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m_MoveNextP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr,__Z80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr_m_get_CurrentP66mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_UIntPtr,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m_System_Collections_IEnumerator_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate,__ZL78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m_MoveNextP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate,__ZL81mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate_m_get_CurrentP67mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Delegate,__Z83mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32_m_get_DefaultP22mscorlib_System_Object,__Z83mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16_m_get_DefaultP22mscorlib_System_Object,__Z81mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte_m_get_DefaultP22mscorlib_System_Object,__Z83mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64_m_get_DefaultP22mscorlib_System_Object,__ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m_System_Collections_IEnumerator_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo,__ZL91mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m_MoveNextP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo,__ZL94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo_m_get_CurrentP80mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_MethodInfo,__ZL130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo,__ZL96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo,__ZL99mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo_m_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_ConstructorInfo,__ZL123mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m_System_Collections_IEnumerator_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute
  ,__ZL89mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m_MoveNextP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute,__ZL92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute_m_get_CurrentP78mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ParamArrayAttribute,__ZL140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OutAttribute,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute,__ZL87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_ObsoleteAttribute,__ZL146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_DllImportAttribute,__ZL146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_MarshalAsAttribute,__ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_InAttribute,__ZL141mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m_System_Collections_IEnumerator_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL107mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m_MoveNextP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute_m_get_CurrentP96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_GuidAttribute,__ZL146mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m_System_Collections_IEnumerator_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL112mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m_MoveNextP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL115mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute_m_get_CurrentP101mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_ComImportAttribute,__ZL145mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m_System_Collections_IEnumerator_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m_MoveNextP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute_m_get_CurrentP100mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_OptionalAttribute,__ZL155mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m_System_Collections_IEnumerator_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m_MoveNextP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute_m_get_CurrentP110mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttribute,__ZL156mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m_System_Collections_IEnumerator_get_CurrentP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute
  ,__ZL122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m_MoveNextP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL125mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute_m_get_CurrentP111mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttribute,__ZL158mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_System_Collections_IEnumerator_get_CurrentP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL124mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_MoveNextP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL127mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute_m_get_CurrentP113mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttribute,__ZL139mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m_System_Collections_IEnumerator_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m_MoveNextP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute_m_get_CurrentP94mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Diagnostics_DebuggerHiddenAttribute,__ZL137mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute,__ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Reflection_DefaultMemberAttribute,__ZL153mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m_System_Collections_IEnumerator_get_CurrentP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m_MoveNextP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL122mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute_m_get_CurrentP108mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttribute,__ZL148mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m_System_Collections_IEnumerator_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL114mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m_MoveNextP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL117mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute_m_get_CurrentP103mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Runtime_InteropServices_FieldOffsetAttribute,__ZL121mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m_System_Collections_IEnumerator_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute,__ZL87mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m_MoveNextP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute,__ZL90mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute_m_get_CurrentP76mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_MonoTODOAttribute,__Z151mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRange,__ZL137mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m_System_Collections_IEnumerator_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL103mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m_MoveNextP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo_m_get_CurrentP92mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_TailoringInfo,__ZL135mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m_System_Collections_IEnumerator_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction,__ZL101mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m_MoveNextP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction,__ZL104mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction_m_get_CurrentP90mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Contraction,__ZL133mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m_System_Collections_IEnumerator_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map,__ZL99mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m_MoveNextP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map
  ,__ZL102mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map_m_get_CurrentP88mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_Level2Map,__Z151mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m_System_Collections_IEnumerator_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType,__Z117mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m_MoveNextP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType,__Z120mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType_m_get_CurrentP106mscorlib_System_Array_InternalEnumerator_1_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderType,__Z130mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m_System_Collections_IEnumerator_get_CurrentP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot,__Z96mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot_m_MoveNextP85mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_Slot,__Z140mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m_System_Collections_IEnumerator_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode,__Z106mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m_MoveNextP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode,__Z109mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode_m_get_CurrentP95mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Collections_Hashtable_EnumeratorMode,__Z150mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m_System_Collections_IEnumerator_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm,__Z116mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m_MoveNextP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm,__Z119mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm_m_get_CurrentP105mscorlib_System_Array_InternalEnumerator_1_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithm,__Z36mscorlib_System_Object_m_GetHashCodeP22mscorlib_System_Object,__Z32mscorlib_System_Object_m_GetTypeP22mscorlib_System_Object,__Z40mscorlib_System_Object_m_MemberwiseCloneP22mscorlib_System_Object,__Z33mscorlib_System_Object_m_ToStringP22mscorlib_System_Object,__Z31mscorlib_System_Type_m_ToStringP20mscorlib_System_Type,__Z39mscorlib_System_ValueType_m_GetHashCodeP22mscorlib_System_Object,__Z36mscorlib_System_ValueType_m_ToStringP22mscorlib_System_Object,__Z39mscorlib_System_Attribute_m_GetHashCodeP25mscorlib_System_Attribute,__Z35mscorlib_System_Int32_m_GetHashCodePi,__Z42mscorlib_System_Int32_m_GetFormatExceptionP22mscorlib_System_Object,__Z55mscorlib_System_Int32_m_ToString_mscorlib_System_StringPi,__Z59mscorlib_System_AttributeUsageAttribute_m_get_AllowMultipleP39mscorlib_System_AttributeUsageAttribute,__Z55mscorlib_System_AttributeUsageAttribute_m_get_InheritedP39mscorlib_System_AttributeUsageAttribute,__Z35mscorlib_System_Int64_m_GetHashCodePx,__Z55mscorlib_System_Int64_m_ToString_mscorlib_System_StringPx,__Z36mscorlib_System_UInt32_m_GetHashCodePj,__Z56mscorlib_System_UInt32_m_ToString_mscorlib_System_StringPj,__Z36mscorlib_System_UInt64_m_GetHashCodePy
  ,__Z56mscorlib_System_UInt64_m_ToString_mscorlib_System_StringPy,__Z34mscorlib_System_Byte_m_GetHashCodePh,__Z54mscorlib_System_Byte_m_ToString_mscorlib_System_StringPh,__Z35mscorlib_System_SByte_m_GetHashCodePa,__Z55mscorlib_System_SByte_m_ToString_mscorlib_System_StringPa,__Z35mscorlib_System_Int16_m_GetHashCodePs,__Z55mscorlib_System_Int16_m_ToString_mscorlib_System_StringPs,__Z36mscorlib_System_UInt16_m_GetHashCodePt,__Z56mscorlib_System_UInt16_m_ToString_mscorlib_System_StringPt,__Z34mscorlib_System_Char_m_GetHashCodePt,__Z54mscorlib_System_Char_m_ToString_mscorlib_System_StringPt,__Z91mscorlib_System_String_m_System_Collections_Generic_IEnumerableU003CcharU003E_GetEnumeratorP22mscorlib_System_String,__Z65mscorlib_System_String_m_ToCharArray_mscorlib_System_Char_arr_arrP22mscorlib_System_String,__Z52mscorlib_System_String_m_Trim_mscorlib_System_StringP22mscorlib_System_String,__Z55mscorlib_System_String_m_ToLower_mscorlib_System_StringP22mscorlib_System_String,__Z41mscorlib_System_String_m_ToLowerInvariantP22mscorlib_System_String,__Z56mscorlib_System_String_m_ToString_mscorlib_System_StringP22mscorlib_System_String,__Z35mscorlib_System_String_m_get_LengthP22mscorlib_System_String,__Z36mscorlib_System_String_m_GetHashCodeP22mscorlib_System_String,__Z51mscorlib_System_String_m_GetCaseInsensitiveHashCodeP22mscorlib_System_String,__Z36mscorlib_System_Single_m_GetHashCodePf,__Z56mscorlib_System_Single_m_ToString_mscorlib_System_StringPf,__Z36mscorlib_System_Double_m_GetHashCodePd,__Z56mscorlib_System_Double_m_ToString_mscorlib_System_StringPd,__Z37mscorlib_System_Decimal_m_GetHashCodeP23mscorlib_System_Decimal,__Z32mscorlib_System_Decimal_m_IsZeroP23mscorlib_System_Decimal,__Z57mscorlib_System_Decimal_m_ToString_mscorlib_System_StringP23mscorlib_System_Decimal,__Z37mscorlib_System_Boolean_m_GetHashCodePb,__Z57mscorlib_System_Boolean_m_ToString_mscorlib_System_StringPb,__Z33mscorlib_System_IntPtr_m_get_SizeP22mscorlib_System_Object
  ,__Z36mscorlib_System_IntPtr_m_GetHashCodeP22mscorlib_System_IntPtr,__Z32mscorlib_System_IntPtr_m_ToInt64P22mscorlib_System_IntPtr,__Z56mscorlib_System_IntPtr_m_ToString_mscorlib_System_StringP22mscorlib_System_IntPtr,__Z37mscorlib_System_UIntPtr_m_GetHashCodeP23mscorlib_System_UIntPtr,__Z34mscorlib_System_UIntPtr_m_ToUInt32P23mscorlib_System_UIntPtr,__Z34mscorlib_System_UIntPtr_m_ToUInt64P23mscorlib_System_UIntPtr,__Z35mscorlib_System_UIntPtr_m_ToPointerP23mscorlib_System_UIntPtr,__Z34mscorlib_System_UIntPtr_m_ToStringP23mscorlib_System_UIntPtr,__Z34mscorlib_System_UIntPtr_m_get_SizeP22mscorlib_System_Object,__Z47mscorlib_System_MulticastDelegate_m_GetHashCodeP33mscorlib_System_MulticastDelegate,__Z53mscorlib_System_MulticastDelegate_m_GetInvocationListP33mscorlib_System_MulticastDelegate,__Z32mscorlib_System_Delegate_m_CloneP24mscorlib_System_Delegate,__Z37mscorlib_System_Delegate_m_get_MethodP24mscorlib_System_Delegate,__Z37mscorlib_System_Delegate_m_get_TargetP24mscorlib_System_Delegate,__Z38mscorlib_System_Delegate_m_GetHashCodeP24mscorlib_System_Delegate,__Z44mscorlib_System_Delegate_m_GetInvocationListP24mscorlib_System_Delegate,__Z34mscorlib_System_Enum_m_GetTypeCodeP22mscorlib_System_Object,__Z32mscorlib_System_Enum_m_get_valueP22mscorlib_System_Object,__Z32mscorlib_System_Enum_m_get_ValueP22mscorlib_System_Object,__Z33mscorlib_System_Type_m_get_IsEnumP20mscorlib_System_Type,__Z54mscorlib_System_Enum_m_ToString_mscorlib_System_StringP22mscorlib_System_Object,__Z35mscorlib_System_Enum_m_get_hashcodeP22mscorlib_System_Object,__Z34mscorlib_System_Enum_m_GetHashCodeP22mscorlib_System_Object,__Z52mscorlib_System_Array_SimpleEnumerator_m_get_CurrentP38mscorlib_System_Array_SimpleEnumerator,__Z49mscorlib_System_Array_SimpleEnumerator_m_MoveNextP38mscorlib_System_Array_SimpleEnumerator,__Z64mscorlib_System_Array_m_System_Collections_ICollection_get_CountP21mscorlib_System_Array,__Z60mscorlib_System_Array_m_InternalArray__ICollection_get_CountP21mscorlib_System_Array,__Z65mscorlib_System_Array_m_InternalArray__ICollection_get_IsReadOnlyP21mscorlib_System_Array,__Z34mscorlib_System_Array_m_get_LengthP21mscorlib_System_Array,__Z38mscorlib_System_Array_m_get_LongLengthP21mscorlib_System_Array
  ,__Z32mscorlib_System_Array_m_get_RankP21mscorlib_System_Array,__Z31mscorlib_System_Array_m_GetRankP21mscorlib_System_Array,__Z42mscorlib_System_Array_m_get_IsSynchronizedP21mscorlib_System_Array,__Z36mscorlib_System_Array_m_get_SyncRootP21mscorlib_System_Array,__Z39mscorlib_System_Array_m_get_IsFixedSizeP21mscorlib_System_Array,__Z38mscorlib_System_Array_m_get_IsReadOnlyP21mscorlib_System_Array,__Z37mscorlib_System_Array_m_GetEnumeratorP21mscorlib_System_Array,__Z52mscorlib_System_Type_m_get_ContainsGenericParametersP20mscorlib_System_Type,__Z29mscorlib_System_Array_m_CloneP21mscorlib_System_Array,__Z37mscorlib_System_Type_m_get_AttributesP20mscorlib_System_Type,__Z40mscorlib_System_Type_m_get_DeclaringTypeP20mscorlib_System_Type,__Z41mscorlib_System_Type_m_get_HasElementTypeP20mscorlib_System_Type,__Z37mscorlib_System_Type_m_get_IsAbstractP20mscorlib_System_Type,__Z34mscorlib_System_Type_m_get_IsArrayP20mscorlib_System_Type,__Z34mscorlib_System_Type_m_get_IsByRefP20mscorlib_System_Type,__Z34mscorlib_System_Type_m_get_IsClassP20mscorlib_System_Type,__Z38mscorlib_System_Type_m_get_IsInterfaceP20mscorlib_System_Type,__Z38mscorlib_System_Type_m_get_IsValueTypeP20mscorlib_System_Type,__Z39mscorlib_System_Type_m_get_IsContextfulP20mscorlib_System_Type,__Z39mscorlib_System_Type_m_IsContextfulImplP20mscorlib_System_Type,__Z43mscorlib_System_Type_m_get_IsExplicitLayoutP20mscorlib_System_Type,__Z41mscorlib_System_Type_m_get_IsMarshalByRefP20mscorlib_System_Type,__Z41mscorlib_System_Type_m_IsMarshalByRefImplP20mscorlib_System_Type,__Z36mscorlib_System_Type_m_get_IsPointerP20mscorlib_System_Type,__Z38mscorlib_System_Type_m_get_IsPrimitiveP20mscorlib_System_Type,__Z35mscorlib_System_Type_m_get_IsSealedP20mscorlib_System_Type,__Z38mscorlib_System_Type_m_IsValueTypeImplP20mscorlib_System_Type,__Z37mscorlib_System_Type_m_get_MemberTypeP20mscorlib_System_Type,__Z40mscorlib_System_Type_m_get_ReflectedTypeP20mscorlib_System_Type,__Z37mscorlib_System_Type_m_get_TypeHandleP20mscorlib_System_Type
  ,__Z77mscorlib_System_Type_m_GetFields_mscorlib_System_Reflection_FieldInfo_arr_arrP20mscorlib_System_Type,__Z34mscorlib_System_Type_m_GetHashCodeP20mscorlib_System_Type,__Z84mscorlib_System_Type_m_GetProperties_mscorlib_System_Reflection_PropertyInfo_arr_arrP20mscorlib_System_Type,__Z39mscorlib_System_Type_m_get_IsSystemTypeP20mscorlib_System_Type,__Z42mscorlib_System_Type_m_GetGenericArgumentsP20mscorlib_System_Type,__Z50mscorlib_System_Type_m_get_IsGenericTypeDefinitionP20mscorlib_System_Type,__Z52mscorlib_System_Type_m_GetGenericTypeDefinition_implP20mscorlib_System_Type,__Z47mscorlib_System_Type_m_GetGenericTypeDefinitionP20mscorlib_System_Type,__Z40mscorlib_System_Type_m_get_IsGenericTypeP20mscorlib_System_Type,__Z45mscorlib_System_Type_m_get_IsGenericParameterP20mscorlib_System_Type,__Z35mscorlib_System_Type_m_get_IsNestedP20mscorlib_System_Type,__Z48mscorlib_System_Type_m_GetPseudoCustomAttributesP20mscorlib_System_Type,__Z50mscorlib_System_Reflection_MemberInfo_m_get_ModuleP37mscorlib_System_Reflection_MemberInfo,__Z46mscorlib_System_Exception_m_get_InnerExceptionP25mscorlib_System_Exception,__Z40mscorlib_System_Exception_m_get_HelpLinkP25mscorlib_System_Exception,__Z41mscorlib_System_Exception_m_get_ClassNameP25mscorlib_System_Exception,__Z35mscorlib_System_Exception_m_GetTypeP25mscorlib_System_Exception,__Z39mscorlib_System_Exception_m_get_MessageP25mscorlib_System_Exception,__Z38mscorlib_System_Exception_m_get_SourceP25mscorlib_System_Exception,__Z42mscorlib_System_Exception_m_get_StackTraceP25mscorlib_System_Exception,__Z42mscorlib_System_Exception_m_get_TargetSiteP25mscorlib_System_Exception,__Z44mscorlib_System_Exception_m_GetBaseExceptionP25mscorlib_System_Exception,__Z36mscorlib_System_Exception_m_ToStringP25mscorlib_System_Exception,__Z46mscorlib_System_RuntimeFieldHandle_m_get_ValueP34mscorlib_System_RuntimeFieldHandle,__Z48mscorlib_System_RuntimeFieldHandle_m_GetHashCodeP34mscorlib_System_RuntimeFieldHandle,__Z45mscorlib_System_RuntimeTypeHandle_m_get_ValueP33mscorlib_System_RuntimeTypeHandle,__Z47mscorlib_System_RuntimeTypeHandle_m_GetHashCodeP33mscorlib_System_RuntimeTypeHandle,__Z66mscorlib_System_Reflection_DefaultMemberAttribute_m_get_MemberNameP49mscorlib_System_Reflection_DefaultMemberAttribute,__Z44mscorlib_System_TypedReference_m_GetHashCodeP30mscorlib_System_TypedReference,__Z41mscorlib_System_ArgIterator_m_GetHashCodeP27mscorlib_System_ArgIterator
  ,__Z80mscorlib_System_Runtime_CompilerServices_RuntimeHelpers_m_get_OffsetToStringDataP22mscorlib_System_Object,__Z86mscorlib_Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid_m_get_IsInvalidP70mscorlib_Microsoft_Win32_SafeHandles_SafeHandleZeroOrMinusOneIsInvalid,__Z67mscorlib_Microsoft_Win32_SafeHandles_SafeWaitHandle_m_ReleaseHandleP51mscorlib_Microsoft_Win32_SafeHandles_SafeWaitHandle,__Z52mscorlib_System_Globalization_CultureInfo_m_get_LCIDP41mscorlib_System_Globalization_CultureInfo,__Z56mscorlib_System_Globalization_CultureInfo_m_get_TextInfoP41mscorlib_System_Globalization_CultureInfo,__Z54mscorlib_System_Globalization_CultureInfo_m_get_ParentP41mscorlib_System_Globalization_CultureInfo,__Z52mscorlib_System_Globalization_CultureInfo_m_get_NameP41mscorlib_System_Globalization_CultureInfo,__Z58mscorlib_System_Globalization_SortKey_m_get_OriginalStringP37mscorlib_System_Globalization_SortKey,__Z51mscorlib_System_Globalization_SortKey_m_get_KeyDataP37mscorlib_System_Globalization_SortKey,__Z51mscorlib_System_Globalization_SortKey_m_GetHashCodeP37mscorlib_System_Globalization_SortKey,__Z48mscorlib_System_Globalization_SortKey_m_ToStringP37mscorlib_System_Globalization_SortKey,__Z69mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_GetResultAndResetP49mscorlib_Mono_Globalization_Unicode_SortKeyBuffer,__Z61mscorlib_Mono_Globalization_Unicode_SortKeyBuffer_m_GetResultP49mscorlib_Mono_Globalization_Unicode_SortKeyBuffer,__Z49mscorlib_Mono_Security_StrongName_m_get_PublicKeyP33mscorlib_Mono_Security_StrongName,__Z54mscorlib_Mono_Security_StrongName_m_get_PublicKeyTokenP33mscorlib_Mono_Security_StrongName,__Z54mscorlib_Mono_Security_StrongName_m_get_TokenAlgorithmP33mscorlib_Mono_Security_StrongName,__Z38mscorlib_Mono_Runtime_m_GetDisplayNameP22mscorlib_System_Object,__Z65mscorlib_System_Collections_ArrayList_SimpleEnumerator_m_MoveNextP54mscorlib_System_Collections_ArrayList_SimpleEnumerator,__Z49mscorlib_System_Collections_ArrayList_m_get_CountP37mscorlib_System_Collections_ArrayList,__Z68mscorlib_System_Collections_ArrayList_SimpleEnumerator_m_get_CurrentP54mscorlib_System_Collections_ArrayList_SimpleEnumerator,__Z66mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_get_CountP54mscorlib_System_Collections_ArrayList_ArrayListWrapper,__Z75mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_get_IsSynchronizedP54mscorlib_System_Collections_ArrayList_ArrayListWrapper,__Z58mscorlib_System_Collections_ArrayList_m_get_IsSynchronizedP37mscorlib_System_Collections_ArrayList,__Z69mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_get_SyncRootP54mscorlib_System_Collections_ArrayList_ArrayListWrapper,__Z52mscorlib_System_Collections_ArrayList_m_get_SyncRootP37mscorlib_System_Collections_ArrayList,__Z70mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_GetEnumeratorP54mscorlib_System_Collections_ArrayList_ArrayListWrapper,__Z53mscorlib_System_Collections_ArrayList_m_GetEnumeratorP37mscorlib_System_Collections_ArrayList,__Z95mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_ToArray_mscorlib_System_Object_arr_arrP54mscorlib_System_Collections_ArrayList_ArrayListWrapper,__Z78mscorlib_System_Collections_ArrayList_m_ToArray_mscorlib_System_Object_arr_arrP37mscorlib_System_Collections_ArrayList,__Z78mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_get_CountP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper
  ,__Z87mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_get_IsSynchronizedP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper,__Z81mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_get_SyncRootP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper,__Z82mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_GetEnumeratorP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper,__Z107mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_ToArray_mscorlib_System_Object_arr_arrP66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper,__Z59mscorlib_System_Globalization_CultureInfo_m_get_CompareInfoP41mscorlib_System_Globalization_CultureInfo,__Z53mscorlib_System_Collections_DictionaryEntry_m_get_KeyP43mscorlib_System_Collections_DictionaryEntry,__Z55mscorlib_System_Collections_DictionaryEntry_m_get_ValueP43mscorlib_System_Collections_DictionaryEntry,__Z59mscorlib_System_Collections_Hashtable_Enumerator_m_MoveNextP48mscorlib_System_Collections_Hashtable_Enumerator,__Z62mscorlib_System_Collections_Hashtable_Enumerator_m_get_CurrentP48mscorlib_System_Collections_Hashtable_Enumerator,__Z58mscorlib_System_Collections_Hashtable_HashKeys_m_get_CountP46mscorlib_System_Collections_Hashtable_HashKeys,__Z49mscorlib_System_Collections_Hashtable_m_get_CountP37mscorlib_System_Collections_Hashtable,__Z61mscorlib_System_Collections_Hashtable_HashKeys_m_get_SyncRootP46mscorlib_System_Collections_Hashtable_HashKeys,__Z52mscorlib_System_Collections_Hashtable_m_get_SyncRootP37mscorlib_System_Collections_Hashtable,__Z60mscorlib_System_Collections_Hashtable_HashValues_m_get_CountP48mscorlib_System_Collections_Hashtable_HashValues,__Z63mscorlib_System_Collections_Hashtable_HashValues_m_get_SyncRootP48mscorlib_System_Collections_Hashtable_HashValues,__Z53mscorlib_System_Collections_Hashtable_m_GetEnumeratorP37mscorlib_System_Collections_Hashtable,__Z45mscorlib_System_Collections_Stack_m_get_CountP33mscorlib_System_Collections_Stack,__Z48mscorlib_System_Collections_Stack_m_get_SyncRootP33mscorlib_System_Collections_Stack,__Z58mscorlib_System_Diagnostics_StackFrame_m_GetFileLineNumberP38mscorlib_System_Diagnostics_StackFrame,__Z52mscorlib_System_Diagnostics_StackFrame_m_GetFileNameP38mscorlib_System_Diagnostics_StackFrame,__Z58mscorlib_System_Diagnostics_StackFrame_m_GetSecureFileNameP38mscorlib_System_Diagnostics_StackFrame,__Z52mscorlib_System_Diagnostics_StackFrame_m_GetILOffsetP38mscorlib_System_Diagnostics_StackFrame,__Z50mscorlib_System_Diagnostics_StackFrame_m_GetMethodP38mscorlib_System_Diagnostics_StackFrame,__Z56mscorlib_System_Diagnostics_StackFrame_m_GetNativeOffsetP38mscorlib_System_Diagnostics_StackFrame,__Z62mscorlib_System_Diagnostics_StackFrame_m_GetInternalMethodNameP38mscorlib_System_Diagnostics_StackFrame,__Z49mscorlib_System_Diagnostics_StackFrame_m_ToStringP38mscorlib_System_Diagnostics_StackFrame,__Z55mscorlib_System_Diagnostics_StackTrace_m_get_FrameCountP38mscorlib_System_Diagnostics_StackTrace,__Z49mscorlib_System_Diagnostics_StackTrace_m_ToStringP38mscorlib_System_Diagnostics_StackTrace,__Z53mscorlib_System_Globalization_Calendar_m_get_EraNamesP38mscorlib_System_Globalization_Calendar,__Z67mscorlib_System_Globalization_CompareInfo_m_get_UseManagedCollationP22mscorlib_System_Object
  ,__Z55mscorlib_System_Globalization_CompareInfo_m_GetHashCodeP41mscorlib_System_Globalization_CompareInfo,__Z52mscorlib_System_Globalization_CompareInfo_m_ToStringP41mscorlib_System_Globalization_CompareInfo,__Z52mscorlib_System_Globalization_CompareInfo_m_get_LCIDP41mscorlib_System_Globalization_CompareInfo,__Z64mscorlib_System_Globalization_CultureInfo_m_get_InvariantCultureP22mscorlib_System_Object,__Z55mscorlib_System_Globalization_CultureInfo_m_get_IcuNameP41mscorlib_System_Globalization_CultureInfo,__Z55mscorlib_System_Globalization_CultureInfo_m_GetHashCodeP41mscorlib_System_Globalization_CultureInfo,__Z52mscorlib_System_Globalization_CultureInfo_m_ToStringP41mscorlib_System_Globalization_CultureInfo,__Z64mscorlib_System_Globalization_CultureInfo_m_get_IsNeutralCultureP41mscorlib_System_Globalization_CultureInfo,__Z60mscorlib_System_Globalization_CultureInfo_m_get_NumberFormatP41mscorlib_System_Globalization_CultureInfo,__Z62mscorlib_System_Globalization_CultureInfo_m_get_DateTimeFormatP41mscorlib_System_Globalization_CultureInfo,__Z58mscorlib_System_Globalization_CultureInfo_m_get_IsReadOnlyP41mscorlib_System_Globalization_CultureInfo,__Z54mscorlib_System_Globalization_NumberFormatInfo_m_CloneP46mscorlib_System_Globalization_NumberFormatInfo,__Z56mscorlib_System_Globalization_DateTimeFormatInfo_m_CloneP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z65mscorlib_System_Globalization_DateTimeFormatInfo_m_get_IsReadOnlyP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z77mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RawAbbreviatedDayNamesP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z79mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RawAbbreviatedMonthNamesP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z66mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RawDayNamesP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z68mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RawMonthNamesP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z67mscorlib_System_Globalization_DateTimeFormatInfo_m_get_AMDesignatorP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z67mscorlib_System_Globalization_DateTimeFormatInfo_m_get_PMDesignatorP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z68mscorlib_System_Globalization_DateTimeFormatInfo_m_get_DateSeparatorP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z68mscorlib_System_Globalization_DateTimeFormatInfo_m_get_TimeSeparatorP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z70mscorlib_System_Globalization_DateTimeFormatInfo_m_get_LongDatePatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_get_ShortDatePatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_get_ShortTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z70mscorlib_System_Globalization_DateTimeFormatInfo_m_get_LongTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z70mscorlib_System_Globalization_DateTimeFormatInfo_m_get_MonthDayPatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_get_YearMonthPatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z74mscorlib_System_Globalization_DateTimeFormatInfo_m_get_FullDateTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z66mscorlib_System_Globalization_DateTimeFormatInfo_m_get_CurrentInfoP22mscorlib_System_Object
  ,__Z68mscorlib_System_Globalization_DateTimeFormatInfo_m_get_InvariantInfoP22mscorlib_System_Object,__Z63mscorlib_System_Globalization_DateTimeFormatInfo_m_get_CalendarP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z69mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RFC1123PatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_get_RoundtripPatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z78mscorlib_System_Globalization_DateTimeFormatInfo_m_get_SortableDateTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z87mscorlib_System_Globalization_DateTimeFormatInfo_m_get_UniversalSortableDateTimePatternP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z81mscorlib_System_Globalization_DateTimeFormatInfo_m_GetAllDateTimePatternsInternalP48mscorlib_System_Globalization_DateTimeFormatInfo,__Z54mscorlib_System_Globalization_DaylightTime_m_get_DeltaP42mscorlib_System_Globalization_DaylightTime,__Z58mscorlib_System_Globalization_GregorianCalendar_m_get_ErasP47mscorlib_System_Globalization_GregorianCalendar,__Z74mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyDecimalDigitsP46mscorlib_System_Globalization_NumberFormatInfo,__Z77mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyDecimalSeparatorP46mscorlib_System_Globalization_NumberFormatInfo,__Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyGroupSeparatorP46mscorlib_System_Globalization_NumberFormatInfo,__Z74mscorlib_System_Globalization_NumberFormatInfo_m_get_RawCurrencyGroupSizesP46mscorlib_System_Globalization_NumberFormatInfo,__Z76mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyNegativePatternP46mscorlib_System_Globalization_NumberFormatInfo,__Z76mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencyPositivePatternP46mscorlib_System_Globalization_NumberFormatInfo,__Z67mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrencySymbolP46mscorlib_System_Globalization_NumberFormatInfo,__Z64mscorlib_System_Globalization_NumberFormatInfo_m_get_CurrentInfoP22mscorlib_System_Object,__Z66mscorlib_System_Globalization_NumberFormatInfo_m_get_InvariantInfoP22mscorlib_System_Object,__Z62mscorlib_System_Globalization_NumberFormatInfo_m_get_NaNSymbolP46mscorlib_System_Globalization_NumberFormatInfo,__Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_NegativeInfinitySymbolP46mscorlib_System_Globalization_NumberFormatInfo,__Z65mscorlib_System_Globalization_NumberFormatInfo_m_get_NegativeSignP46mscorlib_System_Globalization_NumberFormatInfo,__Z72mscorlib_System_Globalization_NumberFormatInfo_m_get_NumberDecimalDigitsP46mscorlib_System_Globalization_NumberFormatInfo,__Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_NumberDecimalSeparatorP46mscorlib_System_Globalization_NumberFormatInfo,__Z73mscorlib_System_Globalization_NumberFormatInfo_m_get_NumberGroupSeparatorP46mscorlib_System_Globalization_NumberFormatInfo,__Z72mscorlib_System_Globalization_NumberFormatInfo_m_get_RawNumberGroupSizesP46mscorlib_System_Globalization_NumberFormatInfo,__Z74mscorlib_System_Globalization_NumberFormatInfo_m_get_NumberNegativePatternP46mscorlib_System_Globalization_NumberFormatInfo,__Z73mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentDecimalDigitsP46mscorlib_System_Globalization_NumberFormatInfo,__Z76mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentDecimalSeparatorP46mscorlib_System_Globalization_NumberFormatInfo,__Z74mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentGroupSeparatorP46mscorlib_System_Globalization_NumberFormatInfo,__Z73mscorlib_System_Globalization_NumberFormatInfo_m_get_RawPercentGroupSizesP46mscorlib_System_Globalization_NumberFormatInfo
  ,__Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentNegativePatternP46mscorlib_System_Globalization_NumberFormatInfo,__Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentPositivePatternP46mscorlib_System_Globalization_NumberFormatInfo,__Z66mscorlib_System_Globalization_NumberFormatInfo_m_get_PercentSymbolP46mscorlib_System_Globalization_NumberFormatInfo,__Z67mscorlib_System_Globalization_NumberFormatInfo_m_get_PerMilleSymbolP46mscorlib_System_Globalization_NumberFormatInfo,__Z75mscorlib_System_Globalization_NumberFormatInfo_m_get_PositiveInfinitySymbolP46mscorlib_System_Globalization_NumberFormatInfo,__Z65mscorlib_System_Globalization_NumberFormatInfo_m_get_PositiveSignP46mscorlib_System_Globalization_NumberFormatInfo,__Z56mscorlib_System_Globalization_TextInfo_m_get_CultureNameP38mscorlib_System_Globalization_TextInfo,__Z52mscorlib_System_Globalization_TextInfo_m_GetHashCodeP38mscorlib_System_Globalization_TextInfo,__Z49mscorlib_System_Globalization_TextInfo_m_ToStringP38mscorlib_System_Globalization_TextInfo,__Z71mscorlib_System_Reflection_Emit_AssemblyBuilder_m_get_IsCompilerContextP47mscorlib_System_Reflection_Emit_AssemblyBuilder,__Z68mscorlib_System_Reflection_Emit_AssemblyBuilder_m_UnprotectedGetNameP47mscorlib_System_Reflection_Emit_AssemblyBuilder,__Z74mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_CallingConventionP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z68mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_TypeBuilderP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z81mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetMethodImplementationFlagsP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z66mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetParametersP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z74mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetParametersInternalP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z69mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_MethodHandleP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z67mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_AttributesP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z70mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_ReflectedTypeP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z70mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_DeclaringTypeP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z61mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_NameP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z63mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_ModuleP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z61mscorlib_System_Reflection_Emit_ConstructorBuilder_m_ToStringP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z54mscorlib_System_Reflection_Emit_TypeBuilder_m_get_NameP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z74mscorlib_System_Reflection_Emit_ConstructorBuilder_m_get_IsCompilerContextP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z56mscorlib_System_Reflection_Emit_TypeBuilder_m_get_ModuleP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z66mscorlib_System_Reflection_Emit_ConstructorBuilder_m_not_supportedP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z64mscorlib_System_Reflection_Emit_ConstructorBuilder_m_not_createdP50mscorlib_System_Reflection_Emit_ConstructorBuilder,__Z58mscorlib_System_Reflection_Emit_EnumBuilder_m_get_AssemblyP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_get_AssemblyP43mscorlib_System_Reflection_Emit_TypeBuilder
  ,__Z71mscorlib_System_Reflection_Emit_EnumBuilder_m_get_AssemblyQualifiedNameP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z71mscorlib_System_Reflection_Emit_TypeBuilder_m_get_AssemblyQualifiedNameP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z58mscorlib_System_Reflection_Emit_EnumBuilder_m_get_BaseTypeP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_get_BaseTypeP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z63mscorlib_System_Reflection_Emit_EnumBuilder_m_get_DeclaringTypeP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z63mscorlib_System_Reflection_Emit_TypeBuilder_m_get_DeclaringTypeP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z58mscorlib_System_Reflection_Emit_EnumBuilder_m_get_FullNameP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z58mscorlib_System_Reflection_Emit_TypeBuilder_m_get_FullNameP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z56mscorlib_System_Reflection_Emit_EnumBuilder_m_get_ModuleP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z54mscorlib_System_Reflection_Emit_EnumBuilder_m_get_NameP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_get_NamespaceP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_get_NamespaceP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z63mscorlib_System_Reflection_Emit_EnumBuilder_m_get_ReflectedTypeP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z63mscorlib_System_Reflection_Emit_TypeBuilder_m_get_ReflectedTypeP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z60mscorlib_System_Reflection_Emit_EnumBuilder_m_get_TypeHandleP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z60mscorlib_System_Reflection_Emit_TypeBuilder_m_get_TypeHandleP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z70mscorlib_System_Reflection_Emit_EnumBuilder_m_get_UnderlyingSystemTypeP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z67mscorlib_System_Reflection_Emit_EnumBuilder_m_GetAttributeFlagsImplP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z60mscorlib_System_Reflection_Emit_EnumBuilder_m_GetElementTypeP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z60mscorlib_System_Reflection_Emit_TypeBuilder_m_GetElementTypeP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_GetInterfacesP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_GetInterfacesP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z64mscorlib_System_Reflection_Emit_EnumBuilder_m_HasElementTypeImplP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z57mscorlib_System_Reflection_Emit_EnumBuilder_m_IsArrayImplP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z57mscorlib_System_Reflection_Emit_EnumBuilder_m_IsByRefImplP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z59mscorlib_System_Reflection_Emit_EnumBuilder_m_IsPointerImplP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z61mscorlib_System_Reflection_Emit_EnumBuilder_m_IsPrimitiveImplP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z61mscorlib_System_Reflection_Emit_EnumBuilder_m_IsValueTypeImplP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z73mscorlib_System_Reflection_Emit_EnumBuilder_m_CreateNotSupportedExceptionP43mscorlib_System_Reflection_Emit_EnumBuilder,__Z61mscorlib_System_Reflection_Emit_FieldBuilder_m_get_AttributesP44mscorlib_System_Reflection_Emit_FieldBuilder
  ,__Z64mscorlib_System_Reflection_Emit_FieldBuilder_m_get_DeclaringTypeP44mscorlib_System_Reflection_Emit_FieldBuilder,__Z60mscorlib_System_Reflection_Emit_FieldBuilder_m_get_FieldTypeP44mscorlib_System_Reflection_Emit_FieldBuilder,__Z55mscorlib_System_Reflection_Emit_FieldBuilder_m_get_NameP44mscorlib_System_Reflection_Emit_FieldBuilder,__Z64mscorlib_System_Reflection_Emit_FieldBuilder_m_get_ReflectedTypeP44mscorlib_System_Reflection_Emit_FieldBuilder,__Z61mscorlib_System_Reflection_Emit_FieldBuilder_m_GetFieldOffsetP44mscorlib_System_Reflection_Emit_FieldBuilder,__Z59mscorlib_System_Reflection_Emit_FieldBuilder_m_get_UMarshalP44mscorlib_System_Reflection_Emit_FieldBuilder,__Z74mscorlib_System_Reflection_Emit_FieldBuilder_m_CreateNotSupportedExceptionP44mscorlib_System_Reflection_Emit_FieldBuilder,__Z57mscorlib_System_Reflection_Emit_FieldBuilder_m_get_ModuleP44mscorlib_System_Reflection_Emit_FieldBuilder,__Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_BaseTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z83mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetAttributeFlagsImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetInterfacesP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z80mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_HasElementTypeImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z73mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsArrayImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z73mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsByRefImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsPointerImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsPrimitiveImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z77mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsValueTypeImplP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z76mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetElementTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z86mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_UnderlyingSystemTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_AssemblyP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z87mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_AssemblyQualifiedNameP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z74mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_FullNameP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z70mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_NameP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_NamespaceP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z72mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_ModuleP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z79mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_DeclaringTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z65mscorlib_System_Reflection_Emit_MethodBuilder_m_get_DeclaringTypeP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z79mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_ReflectedTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z76mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_TypeHandleP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z81mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetGenericArgumentsP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder
  ,__Z86mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetGenericTypeDefinitionP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z91mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_ContainsGenericParametersP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z84mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_IsGenericParameterP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z79mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_IsGenericTypeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z89mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_get_IsGenericTypeDefinitionP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z75mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_not_supportedP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z70mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_ToStringP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z73mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetHashCodeP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder,__Z77mscorlib_System_Reflection_Emit_MethodBuilder_m_get_ContainsGenericParametersP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z64mscorlib_System_Reflection_Emit_MethodBuilder_m_get_MethodHandleP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z62mscorlib_System_Reflection_Emit_MethodBuilder_m_get_ReturnTypeP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z65mscorlib_System_Reflection_Emit_MethodBuilder_m_get_ReflectedTypeP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z56mscorlib_System_Reflection_Emit_MethodBuilder_m_get_NameP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z62mscorlib_System_Reflection_Emit_MethodBuilder_m_get_AttributesP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z69mscorlib_System_Reflection_Emit_MethodBuilder_m_get_CallingConventionP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z65mscorlib_System_Reflection_Emit_MethodBuilder_m_GetBaseDefinitionP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z76mscorlib_System_Reflection_Emit_MethodBuilder_m_GetMethodImplementationFlagsP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z61mscorlib_System_Reflection_Emit_MethodBuilder_m_GetParametersP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z56mscorlib_System_Reflection_Emit_MethodBuilder_m_ToStringP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z59mscorlib_System_Reflection_Emit_MethodBuilder_m_GetHashCodeP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z60mscorlib_System_Reflection_Emit_MethodBuilder_m_NotSupportedP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z77mscorlib_System_Reflection_Emit_MethodBuilder_m_get_IsGenericMethodDefinitionP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z67mscorlib_System_Reflection_Emit_MethodBuilder_m_get_IsGenericMethodP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z67mscorlib_System_Reflection_Emit_MethodBuilder_m_GetGenericArgumentsP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z58mscorlib_System_Reflection_Emit_MethodBuilder_m_get_ModuleP45mscorlib_System_Reflection_Emit_MethodBuilder,__Z65mscorlib_System_Reflection_Emit_ParameterBuilder_m_get_AttributesP48mscorlib_System_Reflection_Emit_ParameterBuilder,__Z59mscorlib_System_Reflection_Emit_ParameterBuilder_m_get_NameP48mscorlib_System_Reflection_Emit_ParameterBuilder,__Z63mscorlib_System_Reflection_Emit_ParameterBuilder_m_get_PositionP48mscorlib_System_Reflection_Emit_ParameterBuilder,__Z64mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_AttributesP47mscorlib_System_Reflection_Emit_PropertyBuilder,__Z67mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_DeclaringTypeP47mscorlib_System_Reflection_Emit_PropertyBuilder
  ,__Z58mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_NameP47mscorlib_System_Reflection_Emit_PropertyBuilder,__Z66mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_PropertyTypeP47mscorlib_System_Reflection_Emit_PropertyBuilder,__Z67mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_ReflectedTypeP47mscorlib_System_Reflection_Emit_PropertyBuilder,__Z68mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetIndexParametersP47mscorlib_System_Reflection_Emit_PropertyBuilder,__Z60mscorlib_System_Reflection_Emit_PropertyBuilder_m_get_ModuleP47mscorlib_System_Reflection_Emit_PropertyBuilder,__Z63mscorlib_System_Reflection_Emit_PropertyBuilder_m_not_supportedP47mscorlib_System_Reflection_Emit_PropertyBuilder,__Z67mscorlib_System_Reflection_Emit_TypeBuilder_m_GetAttributeFlagsImplP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z50mscorlib_System_Reflection_Assembly_m_get_FullNameP35mscorlib_System_Reflection_Assembly,__Z70mscorlib_System_Reflection_Emit_TypeBuilder_m_get_UnderlyingSystemTypeP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z64mscorlib_System_Reflection_Emit_TypeBuilder_m_HasElementTypeImplP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z57mscorlib_System_Reflection_Emit_TypeBuilder_m_IsArrayImplP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z57mscorlib_System_Reflection_Emit_TypeBuilder_m_IsByRefImplP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_IsPointerImplP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_IsPrimitiveImplP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z61mscorlib_System_Reflection_Emit_TypeBuilder_m_IsValueTypeImplP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z67mscorlib_System_Reflection_Emit_TypeBuilder_m_get_IsCompilerContextP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z60mscorlib_System_Reflection_Emit_TypeBuilder_m_get_is_createdP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z59mscorlib_System_Reflection_Emit_TypeBuilder_m_not_supportedP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z54mscorlib_System_Reflection_Emit_TypeBuilder_m_ToStringP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z65mscorlib_System_Reflection_Emit_TypeBuilder_m_GetGenericArgumentsP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z70mscorlib_System_Reflection_Emit_TypeBuilder_m_GetGenericTypeDefinitionP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z75mscorlib_System_Reflection_Emit_TypeBuilder_m_get_ContainsGenericParametersP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z68mscorlib_System_Reflection_Emit_TypeBuilder_m_get_IsGenericParameterP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z73mscorlib_System_Reflection_Emit_TypeBuilder_m_get_IsGenericTypeDefinitionP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z63mscorlib_System_Reflection_Emit_TypeBuilder_m_get_IsGenericTypeP43mscorlib_System_Reflection_Emit_TypeBuilder,__Z71mscorlib_System_Reflection_Emit_UnmanagedMarshal_m_ToMarshalAsAttributeP48mscorlib_System_Reflection_Emit_UnmanagedMarshal,__Z50mscorlib_System_Reflection_Assembly_m_get_fullnameP35mscorlib_System_Reflection_Assembly,__Z46mscorlib_System_Reflection_Assembly_m_ToStringP35mscorlib_System_Reflection_Assembly,__Z56mscorlib_System_Reflection_Assembly_m_UnprotectedGetNameP35mscorlib_System_Reflection_Assembly,__Z58mscorlib_System_Reflection_Assembly_m_GetExecutingAssemblyP22mscorlib_System_Object
  ,__Z50mscorlib_System_Reflection_AssemblyName_m_get_NameP39mscorlib_System_Reflection_AssemblyName,__Z53mscorlib_System_Reflection_AssemblyName_m_get_VersionP39mscorlib_System_Reflection_AssemblyName,__Z50mscorlib_System_Reflection_AssemblyName_m_ToStringP39mscorlib_System_Reflection_AssemblyName,__Z51mscorlib_System_Reflection_ParameterInfo_m_get_NameP40mscorlib_System_Reflection_ParameterInfo,__Z60mscorlib_System_Reflection_ParameterInfo_m_get_ParameterTypeP40mscorlib_System_Reflection_ParameterInfo,__Z69mscorlib_System_Reflection_MethodBase_m_get_IsGenericMethodDefinitionP37mscorlib_System_Reflection_MethodBase,__Z61mscorlib_System_Reflection_MethodBase_m_get_CallingConventionP37mscorlib_System_Reflection_MethodBase,__Z53mscorlib_System_Reflection_Binder_m_get_DefaultBinderP22mscorlib_System_Object,__Z59mscorlib_System_Reflection_ConstructorInfo_m_get_MemberTypeP42mscorlib_System_Reflection_ConstructorInfo,__Z59mscorlib_System_Reflection_EventInfo_m_get_EventHandlerTypeP36mscorlib_System_Reflection_EventInfo,__Z53mscorlib_System_Reflection_EventInfo_m_get_MemberTypeP36mscorlib_System_Reflection_EventInfo,__Z53mscorlib_System_Reflection_FieldInfo_m_get_MemberTypeP36mscorlib_System_Reflection_FieldInfo,__Z52mscorlib_System_Reflection_FieldInfo_m_get_IsLiteralP36mscorlib_System_Reflection_FieldInfo,__Z51mscorlib_System_Reflection_FieldInfo_m_get_IsStaticP36mscorlib_System_Reflection_FieldInfo,__Z58mscorlib_System_Reflection_FieldInfo_m_get_IsNotSerializedP36mscorlib_System_Reflection_FieldInfo,__Z53mscorlib_System_Reflection_FieldInfo_m_GetFieldOffsetP36mscorlib_System_Reflection_FieldInfo,__Z58mscorlib_System_Reflection_FieldInfo_m_GetUnmanagedMarshalP36mscorlib_System_Reflection_FieldInfo,__Z51mscorlib_System_Reflection_FieldInfo_m_get_UMarshalP36mscorlib_System_Reflection_FieldInfo,__Z64mscorlib_System_Reflection_FieldInfo_m_GetPseudoCustomAttributesP36mscorlib_System_Reflection_FieldInfo,__Z52mscorlib_System_Reflection_MethodBase_m_get_IsPublicP37mscorlib_System_Reflection_MethodBase,__Z53mscorlib_System_Reflection_MethodBase_m_get_IsPrivateP37mscorlib_System_Reflection_MethodBase,__Z52mscorlib_System_Reflection_MethodBase_m_get_IsFamilyP37mscorlib_System_Reflection_MethodBase,__Z54mscorlib_System_Reflection_MethodBase_m_get_IsAssemblyP37mscorlib_System_Reflection_MethodBase,__Z63mscorlib_System_Reflection_MethodBase_m_get_IsFamilyAndAssemblyP37mscorlib_System_Reflection_MethodBase,__Z62mscorlib_System_Reflection_MethodBase_m_get_IsFamilyOrAssemblyP37mscorlib_System_Reflection_MethodBase,__Z52mscorlib_System_Reflection_MethodBase_m_get_IsStaticP37mscorlib_System_Reflection_MethodBase,__Z51mscorlib_System_Reflection_MethodBase_m_get_IsFinalP37mscorlib_System_Reflection_MethodBase,__Z53mscorlib_System_Reflection_MethodBase_m_get_IsVirtualP37mscorlib_System_Reflection_MethodBase,__Z55mscorlib_System_Reflection_MethodBase_m_get_IsHideBySigP37mscorlib_System_Reflection_MethodBase,__Z54mscorlib_System_Reflection_MethodBase_m_get_IsAbstractP37mscorlib_System_Reflection_MethodBase
  ,__Z57mscorlib_System_Reflection_MethodBase_m_get_IsSpecialNameP37mscorlib_System_Reflection_MethodBase,__Z57mscorlib_System_Reflection_MethodBase_m_get_IsConstructorP37mscorlib_System_Reflection_MethodBase,__Z59mscorlib_System_Reflection_MethodBase_m_GetGenericArgumentsP37mscorlib_System_Reflection_MethodBase,__Z69mscorlib_System_Reflection_MethodBase_m_get_ContainsGenericParametersP37mscorlib_System_Reflection_MethodBase,__Z59mscorlib_System_Reflection_MethodBase_m_get_IsGenericMethodP37mscorlib_System_Reflection_MethodBase,__Z54mscorlib_System_Reflection_MethodInfo_m_get_MemberTypeP37mscorlib_System_Reflection_MethodInfo,__Z54mscorlib_System_Reflection_MethodInfo_m_get_ReturnTypeP37mscorlib_System_Reflection_MethodInfo,__Z59mscorlib_System_Reflection_MethodInfo_m_GetGenericArgumentsP37mscorlib_System_Reflection_MethodInfo,__Z59mscorlib_System_Reflection_MethodInfo_m_get_IsGenericMethodP37mscorlib_System_Reflection_MethodInfo,__Z69mscorlib_System_Reflection_MethodInfo_m_get_IsGenericMethodDefinitionP37mscorlib_System_Reflection_MethodInfo,__Z69mscorlib_System_Reflection_MethodInfo_m_get_ContainsGenericParametersP37mscorlib_System_Reflection_MethodInfo,__Z48mscorlib_System_Reflection_Module_m_get_AssemblyP33mscorlib_System_Reflection_Module,__Z49mscorlib_System_Reflection_Module_m_get_ScopeNameP33mscorlib_System_Reflection_Module,__Z44mscorlib_System_Reflection_Module_m_ToStringP33mscorlib_System_Reflection_Module,__Z53mscorlib_System_Reflection_MonoEvent_m_get_AttributesP36mscorlib_System_Reflection_MonoEvent,__Z56mscorlib_System_Reflection_MonoEvent_m_get_DeclaringTypeP36mscorlib_System_Reflection_MonoEvent,__Z56mscorlib_System_Reflection_MonoEvent_m_get_ReflectedTypeP36mscorlib_System_Reflection_MonoEvent,__Z47mscorlib_System_Reflection_MonoEvent_m_get_NameP36mscorlib_System_Reflection_MonoEvent,__Z47mscorlib_System_Reflection_MonoEvent_m_ToStringP36mscorlib_System_Reflection_MonoEvent,__Z53mscorlib_System_Reflection_MonoField_m_get_AttributesP36mscorlib_System_Reflection_MonoField,__Z52mscorlib_System_Reflection_MonoField_m_get_FieldTypeP36mscorlib_System_Reflection_MonoField,__Z56mscorlib_System_Reflection_MonoField_m_get_ReflectedTypeP36mscorlib_System_Reflection_MonoField,__Z56mscorlib_System_Reflection_MonoField_m_get_DeclaringTypeP36mscorlib_System_Reflection_MonoField,__Z47mscorlib_System_Reflection_MonoField_m_get_NameP36mscorlib_System_Reflection_MonoField,__Z53mscorlib_System_Reflection_MonoField_m_GetFieldOffsetP36mscorlib_System_Reflection_MonoField,__Z47mscorlib_System_Reflection_MonoField_m_ToStringP36mscorlib_System_Reflection_MonoField,__Z64mscorlib_System_Reflection_MonoGenericMethod_m_get_ReflectedTypeP44mscorlib_System_Reflection_MonoGenericMethod,__Z65mscorlib_System_Reflection_MonoGenericCMethod_m_get_ReflectedTypeP45mscorlib_System_Reflection_MonoGenericCMethod,__Z57mscorlib_System_Reflection_MonoMethod_m_GetBaseDefinitionP37mscorlib_System_Reflection_MonoMethod,__Z54mscorlib_System_Reflection_MonoMethod_m_get_ReturnTypeP37mscorlib_System_Reflection_MonoMethod
  ,__Z68mscorlib_System_Reflection_MonoMethod_m_GetMethodImplementationFlagsP37mscorlib_System_Reflection_MonoMethod,__Z53mscorlib_System_Reflection_MonoMethod_m_GetParametersP37mscorlib_System_Reflection_MonoMethod,__Z69mscorlib_System_Reflection_MonoMethod_m_get_ContainsGenericParametersP37mscorlib_System_Reflection_MonoMethod,__Z56mscorlib_System_Reflection_MonoMethod_m_get_MethodHandleP37mscorlib_System_Reflection_MonoMethod,__Z54mscorlib_System_Reflection_MonoMethod_m_get_AttributesP37mscorlib_System_Reflection_MonoMethod,__Z61mscorlib_System_Reflection_MonoMethod_m_get_CallingConventionP37mscorlib_System_Reflection_MonoMethod,__Z57mscorlib_System_Reflection_MonoMethod_m_get_ReflectedTypeP37mscorlib_System_Reflection_MonoMethod,__Z57mscorlib_System_Reflection_MonoMethod_m_get_DeclaringTypeP37mscorlib_System_Reflection_MonoMethod,__Z48mscorlib_System_Reflection_MonoMethod_m_get_NameP37mscorlib_System_Reflection_MonoMethod,__Z65mscorlib_System_Reflection_MonoMethod_m_GetPseudoCustomAttributesP37mscorlib_System_Reflection_MonoMethod,__Z48mscorlib_System_Reflection_MonoMethod_m_ToStringP37mscorlib_System_Reflection_MonoMethod,__Z59mscorlib_System_Reflection_MonoMethod_m_get_IsGenericMethodP37mscorlib_System_Reflection_MonoMethod,__Z59mscorlib_System_Reflection_MonoMethod_m_GetGenericArgumentsP37mscorlib_System_Reflection_MonoMethod,__Z69mscorlib_System_Reflection_MonoMethod_m_get_IsGenericMethodDefinitionP37mscorlib_System_Reflection_MonoMethod,__Z69mscorlib_System_Reflection_MonoCMethod_m_GetMethodImplementationFlagsP38mscorlib_System_Reflection_MonoCMethod,__Z54mscorlib_System_Reflection_MonoCMethod_m_GetParametersP38mscorlib_System_Reflection_MonoCMethod,__Z58mscorlib_System_Reflection_MonoCMethod_m_get_DeclaringTypeP38mscorlib_System_Reflection_MonoCMethod,__Z57mscorlib_System_Reflection_MonoCMethod_m_get_MethodHandleP38mscorlib_System_Reflection_MonoCMethod,__Z55mscorlib_System_Reflection_MonoCMethod_m_get_AttributesP38mscorlib_System_Reflection_MonoCMethod,__Z62mscorlib_System_Reflection_MonoCMethod_m_get_CallingConventionP38mscorlib_System_Reflection_MonoCMethod,__Z58mscorlib_System_Reflection_MonoCMethod_m_get_ReflectedTypeP38mscorlib_System_Reflection_MonoCMethod,__Z49mscorlib_System_Reflection_MonoCMethod_m_get_NameP38mscorlib_System_Reflection_MonoCMethod,__Z49mscorlib_System_Reflection_MonoCMethod_m_ToStringP38mscorlib_System_Reflection_MonoCMethod,__Z56mscorlib_System_Reflection_MonoProperty_m_get_AttributesP39mscorlib_System_Reflection_MonoProperty,__Z58mscorlib_System_Reflection_MonoProperty_m_get_PropertyTypeP39mscorlib_System_Reflection_MonoProperty,__Z59mscorlib_System_Reflection_MonoProperty_m_get_ReflectedTypeP39mscorlib_System_Reflection_MonoProperty,__Z59mscorlib_System_Reflection_MonoProperty_m_get_DeclaringTypeP39mscorlib_System_Reflection_MonoProperty,__Z50mscorlib_System_Reflection_MonoProperty_m_get_NameP39mscorlib_System_Reflection_MonoProperty,__Z60mscorlib_System_Reflection_MonoProperty_m_GetIndexParametersP39mscorlib_System_Reflection_MonoProperty,__Z50mscorlib_System_Reflection_MonoProperty_m_ToStringP39mscorlib_System_Reflection_MonoProperty
  ,__Z55mscorlib_System_Reflection_ParameterInfo_m_get_PositionP40mscorlib_System_Reflection_ParameterInfo,__Z57mscorlib_System_Reflection_ParameterInfo_m_get_AttributesP40mscorlib_System_Reflection_ParameterInfo,__Z51mscorlib_System_Reflection_ParameterInfo_m_ToStringP40mscorlib_System_Reflection_ParameterInfo,__Z51mscorlib_System_Reflection_ParameterInfo_m_get_IsInP40mscorlib_System_Reflection_ParameterInfo,__Z57mscorlib_System_Reflection_ParameterInfo_m_get_IsOptionalP40mscorlib_System_Reflection_ParameterInfo,__Z52mscorlib_System_Reflection_ParameterInfo_m_get_IsOutP40mscorlib_System_Reflection_ParameterInfo,__Z55mscorlib_System_Reflection_ParameterInfo_m_get_IsRetvalP40mscorlib_System_Reflection_ParameterInfo,__Z53mscorlib_System_Reflection_ParameterInfo_m_get_MemberP40mscorlib_System_Reflection_ParameterInfo,__Z68mscorlib_System_Reflection_ParameterInfo_m_GetPseudoCustomAttributesP40mscorlib_System_Reflection_ParameterInfo,__Z56mscorlib_System_Reflection_PropertyInfo_m_get_MemberTypeP39mscorlib_System_Reflection_PropertyInfo,__Z90mscorlib_System_Runtime_Remoting_Activation_ActivationServices_m_get_ConstructionActivatorP22mscorlib_System_Object,__Z71mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_get_UrlValueP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__Z70mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_GetHashCodeP56mscorlib_System_Runtime_Remoting_Activation_UrlAttribute,__Z81mscorlib_System_Runtime_Remoting_Channels_ChannelServices_m_GetCurrentChannelInfoP22mscorlib_System_Object,__Z81mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_get_ChannelNameP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel,__Z85mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_get_ChannelPriorityP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel,__Z81mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel_m_get_ChannelDataP63mscorlib_System_Runtime_Remoting_Channels_CrossAppDomainChannel,__Z70mscorlib_System_Runtime_Remoting_Contexts_Context_m_get_DefaultContextP22mscorlib_System_Object,__Z60mscorlib_System_Runtime_Remoting_Contexts_Context_m_ToStringP49mscorlib_System_Runtime_Remoting_Contexts_Context,__Z69mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_get_NameP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__Z72mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_GetHashCodeP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute,__Z69mscorlib_System_Runtime_Remoting_Messaging_ArgInfo_m_GetInOutArgCountP50mscorlib_System_Runtime_Remoting_Messaging_ArgInfo,__Z80mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_get_ActivationTypeP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall,__Z83mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall_m_get_ContextPropertiesP59mscorlib_System_Runtime_Remoting_Messaging_ConstructionCall,__Z68mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_ArgCountP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z64mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_ArgsP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z70mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_HasVarArgsP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z70mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_MethodBaseP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z70mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_InArgCountP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z66mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_InArgsP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall
  ,__Z78mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_LogicalCallContextP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z70mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_MethodNameP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z75mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_MethodSignatureP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z68mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_TypeNameP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z63mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_UriP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z76mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_get_GenericArgumentsP53mscorlib_System_Runtime_Remoting_Messaging_MethodCall,__Z72mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m_GetTransparentProxyP50mscorlib_System_Runtime_Remoting_Proxies_RealProxy,__Z67mscorlib_System_Runtime_Remoting_Proxies_RealProxy_m_GetProxiedTypeP50mscorlib_System_Runtime_Remoting_Proxies_RealProxy,__Z69mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy_m_get_TypeNameP54mscorlib_System_Runtime_Remoting_Proxies_RemotingProxy,__Z54mscorlib_System_Runtime_Remoting_ObjRef_m_get_TypeInfoP39mscorlib_System_Runtime_Remoting_ObjRef,__Z78mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_m_get_ApplicationUrlP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry,__Z81mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_m_get_ContextAttributesP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry,__Z74mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_m_get_ObjectTypeP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry,__Z68mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry_m_ToStringP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntry,__Z57mscorlib_System_Runtime_Remoting_Identity_m_get_ObjectUriP41mscorlib_System_Runtime_Remoting_Identity,__Z56mscorlib_System_Runtime_Remoting_Identity_m_get_DisposedP41mscorlib_System_Runtime_Remoting_Identity,__Z63mscorlib_System_Runtime_Remoting_ClientIdentity_m_get_TargetUriP47mscorlib_System_Runtime_Remoting_ClientIdentity,__Z49mscorlib_System_Runtime_Remoting_ObjRef_m_get_URIP39mscorlib_System_Runtime_Remoting_ObjRef,__Z76mscorlib_System_Runtime_Remoting_RemotingConfiguration_m_get_ApplicationNameP22mscorlib_System_Object,__Z70mscorlib_System_Runtime_Remoting_RemotingConfiguration_m_get_ProcessIdP22mscorlib_System_Object,__Z64mscorlib_System_Runtime_Remoting_ServerIdentity_m_get_ObjectTypeP47mscorlib_System_Runtime_Remoting_ServerIdentity,__Z61mscorlib_System_Runtime_Remoting_TypeEntry_m_get_AssemblyNameP42mscorlib_System_Runtime_Remoting_TypeEntry,__Z57mscorlib_System_Runtime_Remoting_TypeEntry_m_get_TypeNameP42mscorlib_System_Runtime_Remoting_TypeEntry,__Z56mscorlib_System_Runtime_Remoting_TypeInfo_m_get_TypeNameP41mscorlib_System_Runtime_Remoting_TypeInfo,__Z68mscorlib_System_Runtime_Serialization_StreamingContext_m_GetHashCodeP54mscorlib_System_Runtime_Serialization_StreamingContext,__Z71mscorlib_System_Security_Cryptography_AsymmetricAlgorithm_m_get_KeySizeP57mscorlib_System_Security_Cryptography_AsymmetricAlgorithm,__Z72mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_RngOpenP22mscorlib_System_Object,__Z128mscorlib_System_Security_Cryptography_RandomNumberGenerator_m_Create_mscorlib_System_Security_Cryptography_RandomNumberGeneratorP22mscorlib_System_Object,__Z70mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator_m_MoveNextP59mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator,__Z73mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator_m_get_CurrentP59mscorlib_System_Security_Policy_Evidence_EvidenceEnumerator
  ,__Z52mscorlib_System_Security_Policy_Evidence_m_get_CountP40mscorlib_System_Security_Policy_Evidence,__Z55mscorlib_System_Security_Policy_Evidence_m_get_SyncRootP40mscorlib_System_Security_Policy_Evidence,__Z63mscorlib_System_Security_Policy_Evidence_m_get_HostEvidenceListP40mscorlib_System_Security_Policy_Evidence,__Z67mscorlib_System_Security_Policy_Evidence_m_get_AssemblyEvidenceListP40mscorlib_System_Security_Policy_Evidence,__Z56mscorlib_System_Security_Policy_Evidence_m_GetEnumeratorP40mscorlib_System_Security_Policy_Evidence,__Z54mscorlib_System_Security_Policy_Evidence_m_GetHashCodeP40mscorlib_System_Security_Policy_Evidence,__Z47mscorlib_System_Security_Policy_Hash_m_ToStringP36mscorlib_System_Security_Policy_Hash,__Z69mscorlib_System_Security_SecurityElement_SecurityAttribute_m_get_NameP58mscorlib_System_Security_SecurityElement_SecurityAttribute,__Z70mscorlib_System_Security_SecurityElement_SecurityAttribute_m_get_ValueP58mscorlib_System_Security_SecurityElement_SecurityAttribute,__Z51mscorlib_System_Security_SecurityElement_m_ToStringP40mscorlib_System_Security_SecurityElement,__Z57mscorlib_System_Security_SecurityException_m_get_DemandedP42mscorlib_System_Security_SecurityException,__Z74mscorlib_System_Security_SecurityException_m_get_FirstPermissionThatFailedP42mscorlib_System_Security_SecurityException,__Z64mscorlib_System_Security_SecurityException_m_get_PermissionStateP42mscorlib_System_Security_SecurityException,__Z63mscorlib_System_Security_SecurityException_m_get_PermissionTypeP42mscorlib_System_Security_SecurityException,__Z59mscorlib_System_Security_SecurityException_m_get_GrantedSetP42mscorlib_System_Security_SecurityException,__Z59mscorlib_System_Security_SecurityException_m_get_RefusedSetP42mscorlib_System_Security_SecurityException,__Z53mscorlib_System_Security_SecurityException_m_ToStringP42mscorlib_System_Security_SecurityException,__Z49mscorlib_System_Text_Decoder_m_get_FallbackBufferP28mscorlib_System_Text_Decoder,__Z68mscorlib_System_Text_DecoderExceptionFallback_m_CreateFallbackBufferP45mscorlib_System_Text_DecoderExceptionFallback,__Z59mscorlib_System_Text_DecoderExceptionFallback_m_GetHashCodeP45mscorlib_System_Text_DecoderExceptionFallback,__Z67mscorlib_System_Text_DecoderExceptionFallbackBuffer_m_get_RemainingP51mscorlib_System_Text_DecoderExceptionFallbackBuffer,__Z65mscorlib_System_Text_DecoderExceptionFallbackBuffer_m_GetNextCharP51mscorlib_System_Text_DecoderExceptionFallbackBuffer,__Z60mscorlib_System_Text_DecoderFallback_m_get_ExceptionFallbackP22mscorlib_System_Object,__Z62mscorlib_System_Text_DecoderFallback_m_get_ReplacementFallbackP22mscorlib_System_Object,__Z63mscorlib_System_Text_DecoderFallback_m_get_StandardSafeFallbackP22mscorlib_System_Object,__Z67mscorlib_System_Text_DecoderReplacementFallback_m_get_DefaultStringP47mscorlib_System_Text_DecoderReplacementFallback,__Z70mscorlib_System_Text_DecoderReplacementFallback_m_CreateFallbackBufferP47mscorlib_System_Text_DecoderReplacementFallback,__Z61mscorlib_System_Text_DecoderReplacementFallback_m_GetHashCodeP47mscorlib_System_Text_DecoderReplacementFallback,__Z69mscorlib_System_Text_DecoderReplacementFallbackBuffer_m_get_RemainingP53mscorlib_System_Text_DecoderReplacementFallbackBuffer,__Z67mscorlib_System_Text_DecoderReplacementFallbackBuffer_m_GetNextCharP53mscorlib_System_Text_DecoderReplacementFallbackBuffer
  ,__Z68mscorlib_System_Text_EncoderExceptionFallback_m_CreateFallbackBufferP45mscorlib_System_Text_EncoderExceptionFallback,__Z59mscorlib_System_Text_EncoderExceptionFallback_m_GetHashCodeP45mscorlib_System_Text_EncoderExceptionFallback,__Z67mscorlib_System_Text_EncoderExceptionFallbackBuffer_m_get_RemainingP51mscorlib_System_Text_EncoderExceptionFallbackBuffer,__Z65mscorlib_System_Text_EncoderExceptionFallbackBuffer_m_GetNextCharP51mscorlib_System_Text_EncoderExceptionFallbackBuffer,__Z60mscorlib_System_Text_EncoderFallback_m_get_ExceptionFallbackP22mscorlib_System_Object,__Z62mscorlib_System_Text_EncoderFallback_m_get_ReplacementFallbackP22mscorlib_System_Object,__Z63mscorlib_System_Text_EncoderFallback_m_get_StandardSafeFallbackP22mscorlib_System_Object,__Z67mscorlib_System_Text_EncoderReplacementFallback_m_get_DefaultStringP47mscorlib_System_Text_EncoderReplacementFallback,__Z70mscorlib_System_Text_EncoderReplacementFallback_m_CreateFallbackBufferP47mscorlib_System_Text_EncoderReplacementFallback,__Z61mscorlib_System_Text_EncoderReplacementFallback_m_GetHashCodeP47mscorlib_System_Text_EncoderReplacementFallback,__Z69mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_get_RemainingP53mscorlib_System_Text_EncoderReplacementFallbackBuffer,__Z67mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_GetNextCharP53mscorlib_System_Text_EncoderReplacementFallbackBuffer,__Z51mscorlib_System_Text_Encoding_m_get_DecoderFallbackP29mscorlib_System_Text_Encoding,__Z51mscorlib_System_Text_Encoding_m_get_EncoderFallbackP29mscorlib_System_Text_Encoding,__Z43mscorlib_System_Text_Encoding_m_GetHashCodeP29mscorlib_System_Text_Encoding,__Z43mscorlib_System_Text_Encoding_m_get_WebNameP29mscorlib_System_Text_Encoding,__Z41mscorlib_System_Text_Encoding_m_get_ASCIIP22mscorlib_System_Object,__Z52mscorlib_System_Text_Encoding_m_get_BigEndianUnicodeP22mscorlib_System_Object,__Z43mscorlib_System_Text_Encoding_m_get_DefaultP22mscorlib_System_Object,__Z45mscorlib_System_Text_Encoding_m_get_ISOLatin1P22mscorlib_System_Object,__Z40mscorlib_System_Text_Encoding_m_get_UTF7P22mscorlib_System_Object,__Z40mscorlib_System_Text_Encoding_m_get_UTF8P22mscorlib_System_Object,__Z48mscorlib_System_Text_Encoding_m_get_UTF8UnmarkedP22mscorlib_System_Object,__Z43mscorlib_System_Text_Encoding_m_get_UnicodeP22mscorlib_System_Object,__Z41mscorlib_System_Text_Encoding_m_get_UTF32P22mscorlib_System_Object,__Z50mscorlib_System_Text_Encoding_m_get_BigEndianUTF32P22mscorlib_System_Object,__Z49mscorlib_System_Text_Latin1Encoding_m_get_WebNameP35mscorlib_System_Text_Latin1Encoding,__Z45mscorlib_System_Text_StringBuilder_m_ToStringP34mscorlib_System_Text_StringBuilder,__Z49mscorlib_System_Text_StringBuilder_m_get_CapacityP34mscorlib_System_Text_StringBuilder,__Z47mscorlib_System_Text_StringBuilder_m_get_LengthP34mscorlib_System_Text_StringBuilder
  ,__Z48mscorlib_System_Text_UTF32Encoding_m_GetHashCodeP34mscorlib_System_Text_UTF32Encoding,__Z47mscorlib_System_Text_UTF7Encoding_m_GetHashCodeP33mscorlib_System_Text_UTF7Encoding,__Z47mscorlib_System_Text_UTF8Encoding_m_GetHashCodeP33mscorlib_System_Text_UTF8Encoding,__Z50mscorlib_System_Text_UnicodeEncoding_m_GetHashCodeP36mscorlib_System_Text_UnicodeEncoding,__Z53mscorlib_System_Threading_Thread_m_get_CurrentContextP22mscorlib_System_Object,__Z57mscorlib_System_Threading_Thread_m_CurrentThread_internalP22mscorlib_System_Object,__Z52mscorlib_System_Threading_Thread_m_get_CurrentThreadP22mscorlib_System_Object,__Z46mscorlib_System_Threading_Thread_m_GetDomainIDP22mscorlib_System_Object,__Z50mscorlib_System_Threading_Thread_m_GetNewManagedIdP22mscorlib_System_Object,__Z54mscorlib_System_Threading_Thread_m_get_ManagedThreadIdP32mscorlib_System_Threading_Thread,__Z46mscorlib_System_Threading_Thread_m_GetHashCodeP32mscorlib_System_Threading_Thread,__Z43mscorlib_System_AppDomain_m_getFriendlyNameP25mscorlib_System_AppDomain,__Z46mscorlib_System_AppDomain_m_InternalGetContextP22mscorlib_System_Object,__Z53mscorlib_System_AppDomain_m_InternalGetDefaultContextP22mscorlib_System_Object,__Z42mscorlib_System_AppDomain_m_GetProcessGuidP22mscorlib_System_Object,__Z36mscorlib_System_AppDomain_m_ToStringP25mscorlib_System_AppDomain,__Z46mscorlib_System_ApplicationIdentity_m_ToStringP35mscorlib_System_ApplicationIdentity,__Z49mscorlib_System_ArgumentException_m_get_ParamNameP33mscorlib_System_ArgumentException,__Z47mscorlib_System_ArgumentException_m_get_MessageP33mscorlib_System_ArgumentException,__Z57mscorlib_System_ArgumentOutOfRangeException_m_get_MessageP43mscorlib_System_ArgumentOutOfRangeException,__Z46mscorlib_System_BitConverter_m_AmILittleEndianP22mscorlib_System_Object,__Z52mscorlib_System_BitConverter_m_DoubleWordsAreSwappedP22mscorlib_System_Object,__Z75mscorlib_System_CharEnumerator_m_System_Collections_IEnumerator_get_CurrentP30mscorlib_System_CharEnumerator,__Z44mscorlib_System_CharEnumerator_m_get_CurrentP30mscorlib_System_CharEnumerator,__Z41mscorlib_System_CharEnumerator_m_MoveNextP30mscorlib_System_CharEnumerator,__Z56mscorlib_System_DBNull_m_ToString_mscorlib_System_StringP22mscorlib_System_DBNull,__Z36mscorlib_System_DateTime_m_get_MonthP24mscorlib_System_DateTime,__Z34mscorlib_System_DateTime_m_get_DayP24mscorlib_System_DateTime,__Z40mscorlib_System_DateTime_m_get_DayOfWeekP24mscorlib_System_DateTime,__Z35mscorlib_System_DateTime_m_get_HourP24mscorlib_System_DateTime
  ,__Z37mscorlib_System_DateTime_m_get_MinuteP24mscorlib_System_DateTime,__Z37mscorlib_System_DateTime_m_get_SecondP24mscorlib_System_DateTime,__Z33mscorlib_System_DateTime_m_GetNowP22mscorlib_System_Object,__Z36mscorlib_System_DateTime_m_get_TicksP24mscorlib_System_DateTime,__Z35mscorlib_System_DateTime_m_get_YearP24mscorlib_System_DateTime,__Z35mscorlib_System_DateTime_m_get_KindP24mscorlib_System_DateTime,__Z38mscorlib_System_DateTime_m_GetHashCodeP24mscorlib_System_DateTime,__Z58mscorlib_System_DateTime_m_ToString_mscorlib_System_StringP24mscorlib_System_DateTime,__Z44mscorlib_System_DateTimeOffset_m_GetHashCodeP30mscorlib_System_DateTimeOffset,__Z64mscorlib_System_DateTimeOffset_m_ToString_mscorlib_System_StringP30mscorlib_System_DateTimeOffset,__Z43mscorlib_System_DateTimeOffset_m_get_OffsetP30mscorlib_System_DateTimeOffset,__Z40mscorlib_System_MonoEnumInfo_m_get_CacheP22mscorlib_System_Object,__Z41mscorlib_System_Environment_m_get_NewLineP22mscorlib_System_Object,__Z42mscorlib_System_Environment_m_get_PlatformP22mscorlib_System_Object,__Z48mscorlib_System_Environment_m_GetOSVersionStringP22mscorlib_System_Object,__Z43mscorlib_System_Environment_m_get_OSVersionP22mscorlib_System_Object,__Z34mscorlib_System_Guid_m_GetHashCodeP20mscorlib_System_Guid,__Z54mscorlib_System_Guid_m_ToString_mscorlib_System_StringP20mscorlib_System_Guid,__Z51mscorlib_System_MissingFieldException_m_get_MessageP37mscorlib_System_MissingFieldException,__Z52mscorlib_System_MissingMemberException_m_get_MessageP38mscorlib_System_MissingMemberException,__Z52mscorlib_System_MissingMethodException_m_get_MessageP38mscorlib_System_MissingMethodException,__Z57mscorlib_System_MonoCustomAttrs_AttributeInfo_m_get_UsageP45mscorlib_System_MonoCustomAttrs_AttributeInfo,__Z68mscorlib_System_MonoCustomAttrs_AttributeInfo_m_get_InheritanceLevelP45mscorlib_System_MonoCustomAttrs_AttributeInfo,__Z48mscorlib_System_MonoType_m_GetDefaultConstructorP24mscorlib_System_MonoType,__Z48mscorlib_System_MonoType_m_GetAttributeFlagsImplP24mscorlib_System_MonoType,__Z40mscorlib_System_MonoType_m_GetInterfacesP24mscorlib_System_MonoType,__Z45mscorlib_System_MonoType_m_HasElementTypeImplP24mscorlib_System_MonoType,__Z38mscorlib_System_MonoType_m_IsArrayImplP24mscorlib_System_MonoType,__Z38mscorlib_System_MonoType_m_IsByRefImplP24mscorlib_System_MonoType,__Z40mscorlib_System_MonoType_m_IsPointerImplP24mscorlib_System_MonoType
  ,__Z42mscorlib_System_MonoType_m_IsPrimitiveImplP24mscorlib_System_MonoType,__Z39mscorlib_System_MonoType_m_get_FullNameP24mscorlib_System_MonoType,__Z41mscorlib_System_MonoType_m_GetElementTypeP24mscorlib_System_MonoType,__Z51mscorlib_System_MonoType_m_get_UnderlyingSystemTypeP24mscorlib_System_MonoType,__Z39mscorlib_System_MonoType_m_get_AssemblyP24mscorlib_System_MonoType,__Z52mscorlib_System_MonoType_m_get_AssemblyQualifiedNameP24mscorlib_System_MonoType,__Z39mscorlib_System_MonoType_m_get_BaseTypeP24mscorlib_System_MonoType,__Z41mscorlib_System_MonoType_m_get_MemberTypeP24mscorlib_System_MonoType,__Z44mscorlib_System_MonoType_m_get_DeclaringTypeP24mscorlib_System_MonoType,__Z49mscorlib_System_MonoType_m_get_IsGenericParameterP24mscorlib_System_MonoType,__Z35mscorlib_System_MonoType_m_get_NameP24mscorlib_System_MonoType,__Z40mscorlib_System_MonoType_m_get_NamespaceP24mscorlib_System_MonoType,__Z37mscorlib_System_MonoType_m_get_ModuleP24mscorlib_System_MonoType,__Z44mscorlib_System_MonoType_m_get_ReflectedTypeP24mscorlib_System_MonoType,__Z41mscorlib_System_MonoType_m_get_TypeHandleP24mscorlib_System_MonoType,__Z35mscorlib_System_MonoType_m_ToStringP24mscorlib_System_MonoType,__Z46mscorlib_System_MonoType_m_GetGenericArgumentsP24mscorlib_System_MonoType,__Z56mscorlib_System_MonoType_m_get_ContainsGenericParametersP24mscorlib_System_MonoType,__Z51mscorlib_System_MonoType_m_GetGenericTypeDefinitionP24mscorlib_System_MonoType,__Z65mscorlib_System_NumberFormatter_m_DecHexLen_mscorlib_System_Int32P31mscorlib_System_NumberFormatter,__Z58mscorlib_System_NumberFormatter_m_InitialFloatingPrecisionP31mscorlib_System_NumberFormatter,__Z51mscorlib_System_NumberFormatter_m_get_IntegerDigitsP31mscorlib_System_NumberFormatter,__Z51mscorlib_System_NumberFormatter_m_get_DecimalDigitsP31mscorlib_System_NumberFormatter,__Z54mscorlib_System_NumberFormatter_m_get_IsFloatingSourceP31mscorlib_System_NumberFormatter,__Z44mscorlib_System_NumberFormatter_m_get_IsZeroP31mscorlib_System_NumberFormatter,__Z51mscorlib_System_NumberFormatter_m_get_IsZeroIntegerP31mscorlib_System_NumberFormatter,__Z74mscorlib_System_NumberFormatter_m_CountTrailingZeros_mscorlib_System_Int32P31mscorlib_System_NumberFormatter,__Z45mscorlib_System_NumberFormatter_m_GetInstanceP22mscorlib_System_Object,__Z42mscorlib_System_NumberFormatter_m_GetCloneP31mscorlib_System_NumberFormatter,__Z53mscorlib_System_ObjectDisposedException_m_get_MessageP39mscorlib_System_ObjectDisposedException
  ,__Z46mscorlib_System_OperatingSystem_m_get_PlatformP31mscorlib_System_OperatingSystem,__Z42mscorlib_System_OperatingSystem_m_ToStringP31mscorlib_System_OperatingSystem,__Z47mscorlib_System_RuntimeMethodHandle_m_get_ValueP35mscorlib_System_RuntimeMethodHandle,__Z49mscorlib_System_RuntimeMethodHandle_m_GetHashCodeP35mscorlib_System_RuntimeMethodHandle,__Z54mscorlib_System_StringComparer_m_get_OrdinalIgnoreCaseP22mscorlib_System_Object,__Z35mscorlib_System_TimeSpan_m_get_DaysP24mscorlib_System_TimeSpan,__Z36mscorlib_System_TimeSpan_m_get_HoursP24mscorlib_System_TimeSpan,__Z43mscorlib_System_TimeSpan_m_get_MillisecondsP24mscorlib_System_TimeSpan,__Z38mscorlib_System_TimeSpan_m_get_MinutesP24mscorlib_System_TimeSpan,__Z38mscorlib_System_TimeSpan_m_get_SecondsP24mscorlib_System_TimeSpan,__Z36mscorlib_System_TimeSpan_m_get_TicksP24mscorlib_System_TimeSpan,__Z35mscorlib_System_TimeSpan_m_DurationP24mscorlib_System_TimeSpan,__Z38mscorlib_System_TimeSpan_m_GetHashCodeP24mscorlib_System_TimeSpan,__Z33mscorlib_System_TimeSpan_m_NegateP24mscorlib_System_TimeSpan,__Z35mscorlib_System_TimeSpan_m_ToStringP24mscorlib_System_TimeSpan,__Z46mscorlib_System_TimeZone_m_get_CurrentTimeZoneP22mscorlib_System_Object,__Z47mscorlib_System_TypeLoadException_m_get_MessageP33mscorlib_System_TypeLoadException,__Z37mscorlib_System_Version_m_GetHashCodeP23mscorlib_System_Version,__Z34mscorlib_System_Version_m_ToStringP23mscorlib_System_Version,__Z60replacements_Replacements_MSCompatUnicodeTable_m_get_IsReadyP22mscorlib_System_Object,__Z38UnityEngine_UnityEngine_GUI_m_get_skinP22mscorlib_System_Object,__Z61UnityEngine_UnityEngine_StackTraceUtility_m_ExtractStackTraceP22mscorlib_System_Object,__Z49UnityEngine_UnityEngine_TextGenerator_m_get_vertsP37UnityEngine_UnityEngine_TextGenerator,__Z54UnityEngine_UnityEngine_TextGenerator_m_get_charactersP37UnityEngine_UnityEngine_TextGenerator,__Z49UnityEngine_UnityEngine_TextGenerator_m_get_linesP37UnityEngine_UnityEngine_TextGenerator,__Z55UnityEngine_UnityEngine_TextGenerator_m_get_vertexCountP37UnityEngine_UnityEngine_TextGenerator,__Z56UnityEngine_UnityEngine_TextGenerator_m_GetVerticesArrayP37UnityEngine_UnityEngine_TextGenerator,__Z58UnityEngine_UnityEngine_TextGenerator_m_get_characterCountP37UnityEngine_UnityEngine_TextGenerator,__Z58UnityEngine_UnityEngine_TextGenerator_m_GetCharactersArrayP37UnityEngine_UnityEngine_TextGenerator,__Z53UnityEngine_UnityEngine_TextGenerator_m_get_lineCountP37UnityEngine_UnityEngine_TextGenerator
  ,__Z53UnityEngine_UnityEngine_TextGenerator_m_GetLinesArrayP37UnityEngine_UnityEngine_TextGenerator,__Z66UnityEngine_UnityEngine_TextGenerator_m_get_fontSizeUsedForBestFitP37UnityEngine_UnityEngine_TextGenerator,__Z54UnityEngine_UnityEngine_TrackedReference_m_GetHashCodeP40UnityEngine_UnityEngine_TrackedReference,__Z49UnityEngine_UnityEngine_Component_m_get_transformP33UnityEngine_UnityEngine_Component,__Z50UnityEngine_UnityEngine_Component_m_get_gameObjectP33UnityEngine_UnityEngine_Component,__Z50UnityEngine_UnityEngine_GameObject_m_get_transformP34UnityEngine_UnityEngine_GameObject,__Z44UnityEngine_UnityEngine_Object_m_GetHashCodeP30UnityEngine_UnityEngine_Object,__Z46UnityEngine_UnityEngine_Object_m_GetInstanceIDP30UnityEngine_UnityEngine_Object,__Z45UnityEngine_UnityEngine_Object_m_GetCachedPtrP30UnityEngine_UnityEngine_Object,__Z41UnityEngine_UnityEngine_Object_m_get_nameP30UnityEngine_UnityEngine_Object,__Z41UnityEngine_UnityEngine_Object_m_ToStringP30UnityEngine_UnityEngine_Object,__Z56UnityEngine_UnityEngine_Events_UnityEventBase_m_ToStringP45UnityEngine_UnityEngine_Events_UnityEventBase,__Z66UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_get_ValueP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__Z68UnityEngine_UnityEngine_Internal_DefaultValueAttribute_m_GetHashCodeP54UnityEngine_UnityEngine_Internal_DefaultValueAttribute,__Z69UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute_m_ToStringP58UnityEngine_UnityEngineInternal_TypeInferenceRuleAttribute,__Z66UnityEngine_UnityEngine_AssetBundleCreateRequest_m_get_assetBundleP48UnityEngine_UnityEngine_AssetBundleCreateRequest,__Z54UnityEngine_UnityEngine_AssetBundleRequest_m_get_assetP42UnityEngine_UnityEngine_AssetBundleRequest,__Z58UnityEngine_UnityEngine_AssetBundleRequest_m_get_allAssetsP42UnityEngine_UnityEngine_AssetBundleRequest,__Z45UnityEngine_UnityEngine_LayerMask_m_get_valueP33UnityEngine_UnityEngine_LayerMask,__Z51UnityEngine_UnityEngine_BoneWeight_m_get_boneIndex0P34UnityEngine_UnityEngine_BoneWeight,__Z51UnityEngine_UnityEngine_BoneWeight_m_get_boneIndex1P34UnityEngine_UnityEngine_BoneWeight,__Z51UnityEngine_UnityEngine_BoneWeight_m_get_boneIndex2P34UnityEngine_UnityEngine_BoneWeight,__Z51UnityEngine_UnityEngine_BoneWeight_m_get_boneIndex3P34UnityEngine_UnityEngine_BoneWeight,__Z48UnityEngine_UnityEngine_BoneWeight_m_GetHashCodeP34UnityEngine_UnityEngine_BoneWeight,__Z47UnityEngine_UnityEngine_Renderer_m_get_materialP32UnityEngine_UnityEngine_Renderer,__Z46UnityEngine_UnityEngine_Resolution_m_get_widthP34UnityEngine_UnityEngine_Resolution,__Z47UnityEngine_UnityEngine_Resolution_m_get_heightP34UnityEngine_UnityEngine_Resolution,__Z52UnityEngine_UnityEngine_Resolution_m_get_refreshRateP34UnityEngine_UnityEngine_Resolution,__Z42UnityEngine_UnityEngine_Screen_m_get_widthP22mscorlib_System_Object,__Z43UnityEngine_UnityEngine_Screen_m_get_heightP22mscorlib_System_Object
  ,__Z57UnityEngine_UnityEngine_GUILayoutUtility_m_get_spaceStyleP22mscorlib_System_Object,__Z50UnityEngine_UnityEngine_GUILayoutEntry_m_get_styleP38UnityEngine_UnityEngine_GUILayoutEntry,__Z51UnityEngine_UnityEngine_GUILayoutEntry_m_get_marginP38UnityEngine_UnityEngine_GUILayoutEntry,__Z49UnityEngine_UnityEngine_GUILayoutEntry_m_ToStringP38UnityEngine_UnityEngine_GUILayoutEntry,__Z51UnityEngine_UnityEngine_GUILayoutGroup_m_get_marginP38UnityEngine_UnityEngine_GUILayoutGroup,__Z49UnityEngine_UnityEngine_GUILayoutGroup_m_ToStringP38UnityEngine_UnityEngine_GUILayoutGroup,__Z51UnityEngine_UnityEngine_GUIUtility_m_GetDefaultSkinP22mscorlib_System_Object,__Z57UnityEngine_UnityEngine_GUIUtility_m_Internal_GetGUIDepthP22mscorlib_System_Object,__Z42UnityEngine_UnityEngine_GUISkin_m_get_fontP31UnityEngine_UnityEngine_GUISkin,__Z41UnityEngine_UnityEngine_GUISkin_m_get_boxP31UnityEngine_UnityEngine_GUISkin,__Z43UnityEngine_UnityEngine_GUISkin_m_get_labelP31UnityEngine_UnityEngine_GUISkin,__Z47UnityEngine_UnityEngine_GUISkin_m_get_textFieldP31UnityEngine_UnityEngine_GUISkin,__Z46UnityEngine_UnityEngine_GUISkin_m_get_textAreaP31UnityEngine_UnityEngine_GUISkin,__Z44UnityEngine_UnityEngine_GUISkin_m_get_buttonP31UnityEngine_UnityEngine_GUISkin,__Z44UnityEngine_UnityEngine_GUISkin_m_get_toggleP31UnityEngine_UnityEngine_GUISkin,__Z44UnityEngine_UnityEngine_GUISkin_m_get_windowP31UnityEngine_UnityEngine_GUISkin,__Z54UnityEngine_UnityEngine_GUISkin_m_get_horizontalSliderP31UnityEngine_UnityEngine_GUISkin,__Z59UnityEngine_UnityEngine_GUISkin_m_get_horizontalSliderThumbP31UnityEngine_UnityEngine_GUISkin,__Z52UnityEngine_UnityEngine_GUISkin_m_get_verticalSliderP31UnityEngine_UnityEngine_GUISkin,__Z57UnityEngine_UnityEngine_GUISkin_m_get_verticalSliderThumbP31UnityEngine_UnityEngine_GUISkin,__Z57UnityEngine_UnityEngine_GUISkin_m_get_horizontalScrollbarP31UnityEngine_UnityEngine_GUISkin,__Z62UnityEngine_UnityEngine_GUISkin_m_get_horizontalScrollbarThumbP31UnityEngine_UnityEngine_GUISkin,__Z67UnityEngine_UnityEngine_GUISkin_m_get_horizontalScrollbarLeftButtonP31UnityEngine_UnityEngine_GUISkin,__Z68UnityEngine_UnityEngine_GUISkin_m_get_horizontalScrollbarRightButtonP31UnityEngine_UnityEngine_GUISkin,__Z55UnityEngine_UnityEngine_GUISkin_m_get_verticalScrollbarP31UnityEngine_UnityEngine_GUISkin,__Z60UnityEngine_UnityEngine_GUISkin_m_get_verticalScrollbarThumbP31UnityEngine_UnityEngine_GUISkin,__Z63UnityEngine_UnityEngine_GUISkin_m_get_verticalScrollbarUpButtonP31UnityEngine_UnityEngine_GUISkin,__Z65UnityEngine_UnityEngine_GUISkin_m_get_verticalScrollbarDownButtonP31UnityEngine_UnityEngine_GUISkin,__Z48UnityEngine_UnityEngine_GUISkin_m_get_scrollViewP31UnityEngine_UnityEngine_GUISkin,__Z50UnityEngine_UnityEngine_GUISkin_m_get_customStylesP31UnityEngine_UnityEngine_GUISkin
  ,__Z46UnityEngine_UnityEngine_GUISkin_m_get_settingsP31UnityEngine_UnityEngine_GUISkin,__Z43UnityEngine_UnityEngine_GUISkin_m_get_errorP22mscorlib_System_Object,__Z47UnityEngine_UnityEngine_GUISkin_m_GetEnumeratorP31UnityEngine_UnityEngine_GUISkin,__Z61UnityEngine_UnityEngine_GUIStyleState_m_GetBackgroundInternalP37UnityEngine_UnityEngine_GUIStyleState,__Z45UnityEngine_UnityEngine_RectOffset_m_get_leftP34UnityEngine_UnityEngine_RectOffset,__Z46UnityEngine_UnityEngine_RectOffset_m_get_rightP34UnityEngine_UnityEngine_RectOffset,__Z44UnityEngine_UnityEngine_RectOffset_m_get_topP34UnityEngine_UnityEngine_RectOffset,__Z47UnityEngine_UnityEngine_RectOffset_m_get_bottomP34UnityEngine_UnityEngine_RectOffset,__Z51UnityEngine_UnityEngine_RectOffset_m_get_horizontalP34UnityEngine_UnityEngine_RectOffset,__Z49UnityEngine_UnityEngine_RectOffset_m_get_verticalP34UnityEngine_UnityEngine_RectOffset,__Z45UnityEngine_UnityEngine_RectOffset_m_ToStringP34UnityEngine_UnityEngine_RectOffset,__Z43UnityEngine_UnityEngine_GUIStyle_m_get_nameP32UnityEngine_UnityEngine_GUIStyle,__Z45UnityEngine_UnityEngine_GUIStyle_m_get_normalP32UnityEngine_UnityEngine_GUIStyle,__Z45UnityEngine_UnityEngine_GUIStyle_m_get_marginP32UnityEngine_UnityEngine_GUIStyle,__Z46UnityEngine_UnityEngine_GUIStyle_m_get_paddingP32UnityEngine_UnityEngine_GUIStyle,__Z51UnityEngine_UnityEngine_GUIStyle_m_get_stretchWidthP32UnityEngine_UnityEngine_GUIStyle,__Z52UnityEngine_UnityEngine_GUIStyle_m_get_stretchHeightP32UnityEngine_UnityEngine_GUIStyle,__Z43UnityEngine_UnityEngine_GUIStyle_m_get_noneP22mscorlib_System_Object,__Z43UnityEngine_UnityEngine_GUIStyle_m_ToStringP32UnityEngine_UnityEngine_GUIStyle,__Z40UnityEngine_UnityEngine_Event_m_get_typeP29UnityEngine_UnityEngine_Event,__Z45UnityEngine_UnityEngine_Event_m_get_modifiersP29UnityEngine_UnityEngine_Event,__Z45UnityEngine_UnityEngine_Event_m_get_characterP29UnityEngine_UnityEngine_Event,__Z47UnityEngine_UnityEngine_Event_m_get_commandNameP29UnityEngine_UnityEngine_Event,__Z43UnityEngine_UnityEngine_Event_m_get_keyCodeP29UnityEngine_UnityEngine_Event,__Z43UnityEngine_UnityEngine_Event_m_get_currentP22mscorlib_System_Object,__Z41UnityEngine_UnityEngine_Event_m_get_isKeyP29UnityEngine_UnityEngine_Event,__Z43UnityEngine_UnityEngine_Event_m_get_isMouseP29UnityEngine_UnityEngine_Event,__Z43UnityEngine_UnityEngine_Event_m_GetHashCodeP29UnityEngine_UnityEngine_Event,__Z40UnityEngine_UnityEngine_Event_m_ToStringP29UnityEngine_UnityEngine_Event,__Z42UnityEngine_UnityEngine_Vector2_m_ToStringP31UnityEngine_UnityEngine_Vector2
  ,__Z45UnityEngine_UnityEngine_Vector2_m_GetHashCodeP31UnityEngine_UnityEngine_Vector2,__Z45UnityEngine_UnityEngine_Vector3_m_GetHashCodeP31UnityEngine_UnityEngine_Vector3,__Z65UnityEngine_UnityEngine_Vector3_m_ToString_mscorlib_System_StringP31UnityEngine_UnityEngine_Vector3,__Z40UnityEngine_UnityEngine_Color_m_ToStringP29UnityEngine_UnityEngine_Color,__Z43UnityEngine_UnityEngine_Color_m_GetHashCodeP29UnityEngine_UnityEngine_Color,__Z42UnityEngine_UnityEngine_Color32_m_ToStringP31UnityEngine_UnityEngine_Color32,__Z45UnityEngine_UnityEngine_Quaternion_m_ToStringP34UnityEngine_UnityEngine_Quaternion,__Z48UnityEngine_UnityEngine_Quaternion_m_GetHashCodeP34UnityEngine_UnityEngine_Quaternion,__Z39UnityEngine_UnityEngine_Rect_m_ToStringP28UnityEngine_UnityEngine_Rect,__Z42UnityEngine_UnityEngine_Rect_m_GetHashCodeP28UnityEngine_UnityEngine_Rect,__Z47UnityEngine_UnityEngine_Matrix4x4_m_GetHashCodeP33UnityEngine_UnityEngine_Matrix4x4,__Z50UnityEngine_UnityEngine_Matrix4x4_m_get_isIdentityP33UnityEngine_UnityEngine_Matrix4x4,__Z67UnityEngine_UnityEngine_Matrix4x4_m_ToString_mscorlib_System_StringP33UnityEngine_UnityEngine_Matrix4x4,__Z44UnityEngine_UnityEngine_Bounds_m_GetHashCodeP30UnityEngine_UnityEngine_Bounds,__Z64UnityEngine_UnityEngine_Bounds_m_ToString_mscorlib_System_StringP30UnityEngine_UnityEngine_Bounds,__Z45UnityEngine_UnityEngine_Vector4_m_GetHashCodeP31UnityEngine_UnityEngine_Vector4,__Z42UnityEngine_UnityEngine_Vector4_m_ToStringP31UnityEngine_UnityEngine_Vector4,__Z38UnityEngine_UnityEngine_Ray_m_ToStringP27UnityEngine_UnityEngine_Ray,__Z44UnityEngine_UnityEngine_TextAsset_m_get_textP33UnityEngine_UnityEngine_TextAsset,__Z44UnityEngine_UnityEngine_TextAsset_m_ToStringP33UnityEngine_UnityEngine_TextAsset,__Z48UnityEngine_UnityEngine_Camera_m_get_cullingMaskP30UnityEngine_UnityEngine_Camera,__Z46UnityEngine_UnityEngine_Camera_m_get_eventMaskP30UnityEngine_UnityEngine_Camera,__Z50UnityEngine_UnityEngine_Camera_m_get_targetTextureP30UnityEngine_UnityEngine_Camera,__Z47UnityEngine_UnityEngine_Camera_m_get_clearFlagsP30UnityEngine_UnityEngine_Camera,__Z41UnityEngine_UnityEngine_Camera_m_get_mainP22mscorlib_System_Object,__Z52UnityEngine_UnityEngine_Camera_m_get_allCamerasCountP22mscorlib_System_Object,__Z52UnityEngine_UnityEngine_Display_m_get_renderingWidthP31UnityEngine_UnityEngine_Display,__Z53UnityEngine_UnityEngine_Display_m_get_renderingHeightP31UnityEngine_UnityEngine_Display,__Z49UnityEngine_UnityEngine_Display_m_get_systemWidthP31UnityEngine_UnityEngine_Display,__Z50UnityEngine_UnityEngine_Display_m_get_systemHeightP31UnityEngine_UnityEngine_Display
  ,__Z53UnityEngine_UnityEngine_Display_m_MultiDisplayLicenseP22mscorlib_System_Object,__Z42UnityEngine_UnityEngine_Display_m_get_mainP22mscorlib_System_Object,__Z57UnityEngine_UnityEngine_Display_m_MultiDisplayLicenseImplP22mscorlib_System_Object,__Z60UnityEngine_UnityEngine_ControllerColliderHit_m_get_colliderP45UnityEngine_UnityEngine_ControllerColliderHit,__Z49UnityEngine_UnityEngine_AnimationEvent_m_get_dataP38UnityEngine_UnityEngine_AnimationEvent,__Z60UnityEngine_UnityEngine_AnimationEvent_m_get_stringParameterP38UnityEngine_UnityEngine_AnimationEvent,__Z57UnityEngine_UnityEngine_AnimationEvent_m_get_intParameterP38UnityEngine_UnityEngine_AnimationEvent,__Z69UnityEngine_UnityEngine_AnimationEvent_m_get_objectReferenceParameterP38UnityEngine_UnityEngine_AnimationEvent,__Z57UnityEngine_UnityEngine_AnimationEvent_m_get_functionNameP38UnityEngine_UnityEngine_AnimationEvent,__Z59UnityEngine_UnityEngine_AnimationEvent_m_get_messageOptionsP38UnityEngine_UnityEngine_AnimationEvent,__Z60UnityEngine_UnityEngine_AnimationEvent_m_get_isFiredByLegacyP38UnityEngine_UnityEngine_AnimationEvent,__Z62UnityEngine_UnityEngine_AnimationEvent_m_get_isFiredByAnimatorP38UnityEngine_UnityEngine_AnimationEvent,__Z59UnityEngine_UnityEngine_AnimationEvent_m_get_animationStateP38UnityEngine_UnityEngine_AnimationEvent,__Z60UnityEngine_UnityEngine_AnimatorStateInfo_m_get_fullPathHashP41UnityEngine_UnityEngine_AnimatorStateInfo,__Z56UnityEngine_UnityEngine_AnimatorStateInfo_m_get_nameHashP41UnityEngine_UnityEngine_AnimatorStateInfo,__Z61UnityEngine_UnityEngine_AnimatorStateInfo_m_get_shortNameHashP41UnityEngine_UnityEngine_AnimatorStateInfo,__Z55UnityEngine_UnityEngine_AnimatorStateInfo_m_get_tagHashP41UnityEngine_UnityEngine_AnimatorStateInfo,__Z52UnityEngine_UnityEngine_AnimatorStateInfo_m_get_loopP41UnityEngine_UnityEngine_AnimatorStateInfo,__Z65UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_fullPathHashP46UnityEngine_UnityEngine_AnimatorTransitionInfo,__Z61UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_nameHashP46UnityEngine_UnityEngine_AnimatorTransitionInfo,__Z65UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_userNameHashP46UnityEngine_UnityEngine_AnimatorTransitionInfo,__Z61UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_anyStateP46UnityEngine_UnityEngine_AnimatorTransitionInfo,__Z58UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_entryP46UnityEngine_UnityEngine_AnimatorTransitionInfo,__Z57UnityEngine_UnityEngine_AnimatorTransitionInfo_m_get_exitP46UnityEngine_UnityEngine_AnimatorTransitionInfo,__Z48UnityEngine_UnityEngine_HumanBone_m_get_boneNameP33UnityEngine_UnityEngine_HumanBone,__Z49UnityEngine_UnityEngine_HumanBone_m_get_humanNameP33UnityEngine_UnityEngine_HumanBone,__Z51UnityEngine_UnityEngine_CharacterInfo_m_get_advanceP37UnityEngine_UnityEngine_CharacterInfo,__Z54UnityEngine_UnityEngine_CharacterInfo_m_get_glyphWidthP37UnityEngine_UnityEngine_CharacterInfo,__Z55UnityEngine_UnityEngine_CharacterInfo_m_get_glyphHeightP37UnityEngine_UnityEngine_CharacterInfo,__Z51UnityEngine_UnityEngine_CharacterInfo_m_get_bearingP37UnityEngine_UnityEngine_CharacterInfo
  ,__Z48UnityEngine_UnityEngine_CharacterInfo_m_get_minYP37UnityEngine_UnityEngine_CharacterInfo,__Z48UnityEngine_UnityEngine_CharacterInfo_m_get_maxYP37UnityEngine_UnityEngine_CharacterInfo,__Z48UnityEngine_UnityEngine_CharacterInfo_m_get_minXP37UnityEngine_UnityEngine_CharacterInfo,__Z48UnityEngine_UnityEngine_CharacterInfo_m_get_maxXP37UnityEngine_UnityEngine_CharacterInfo,__Z42UnityEngine_UnityEngine_Font_m_get_dynamicP28UnityEngine_UnityEngine_Font,__ZL87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ObjectP21mscorlib_System_Array,__ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharp_BJControllerP21mscorlib_System_Array,__ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharp_LevelBuilderP21mscorlib_System_Array,__ZL73UnityEngine_UnityEngine_Component_m_GetComponent_mscorlib_System_Object_TP33UnityEngine_UnityEngine_Component,__ZL87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_StringP21mscorlib_System_Array,__Z85mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_CharP21mscorlib_System_Array,__ZL85mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_TypeP21mscorlib_System_Array,__ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array,__Z170mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP21mscorlib_System_Array,__Z86mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Int32P21mscorlib_System_Array,__Z105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_LinkP21mscorlib_System_Array,__Z108mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_DictionaryEntryP21mscorlib_System_Array,__Z170mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP21mscorlib_System_Array,__Z178mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP21mscorlib_System_Array,__Z100mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharp_JSONObject_TypeP21mscorlib_System_Array,__Z141mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectP21mscorlib_System_Array,__Z169mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P21mscorlib_System_Array,__ZL101mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_FieldInfoP21mscorlib_System_Array,__ZL104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_PropertyInfoP21mscorlib_System_Array,__ZL108mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharpU002Dfirstpass_MouseLookP21mscorlib_System_Array,__Z121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DCSharpU002Dfirstpass_MouseLook_RotationAxesP21mscorlib_System_Array,__Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_KeyframeP21mscorlib_System_Array,__Z126mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_MovementTransferOnJumpP21mscorlib_System_Array,__ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_CharacterMotorP21mscorlib_System_Array,__ZL108mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CharacterControllerP21mscorlib_System_Array
  ,__ZL122mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_FPSInputControllerP21mscorlib_System_Array,__ZL127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_PlatformInputControllerP21mscorlib_System_Array,__ZL121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonCameraP21mscorlib_System_Array,__ZL125mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_ThirdPersonControllerP21mscorlib_System_Array,__Z118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_AssemblyU002DUnityScriptU002Dfirstpass_CharacterStateP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AnimationP21mscorlib_System_Array,__ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_WrapperlessIcallP21mscorlib_System_Array,__ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_DisallowMultipleComponentP21mscorlib_System_Array,__ZL106mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ExecuteInEditModeP21mscorlib_System_Array,__ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RequireComponentP21mscorlib_System_Array,__ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_MonoBehaviourP21mscorlib_System_Array,__Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_ParameterModifierP21mscorlib_System_Array,__ZL106mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_WritableAttributeP21mscorlib_System_Array,__ZL113mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AssemblyIsEditorAssemblyP21mscorlib_System_Array,__ZL104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayoutOptionP21mscorlib_System_Array,__Z112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SendMouseEvents_HitInfoP21mscorlib_System_Array,__ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CameraP21mscorlib_System_Array,__ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_ParameterInfoP21mscorlib_System_Array,__ZL110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_StateMachineBehaviourP21mscorlib_System_Array,__Z200mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array,__ZL94mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_EventP21mscorlib_System_Array,__Z110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextEditor_TextEditOpP21mscorlib_System_Array,__Z116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextEditor_DblClickSnappingP21mscorlib_System_Array,__Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_UIVertexP21mscorlib_System_Array,__Z99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_UICharInfoP21mscorlib_System_Array,__Z99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_UILineInfoP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ComponentP21mscorlib_System_Array,__ZL99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GameObjectP21mscorlib_System_Array,__ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ObjectP21mscorlib_System_Array,__ZL110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Events_PersistentCallP21mscorlib_System_Array
  ,__ZL113mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Events_BaseInvokableCallP21mscorlib_System_Array,__ZL112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_UserAuthorizationDialogP21mscorlib_System_Array,__ZL119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Internal_DefaultValueAttributeP21mscorlib_System_Array,__ZL122mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Internal_ExcludeFromDocsAttributeP21mscorlib_System_Array,__ZL119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RenamedSerializedDataAttributeP21mscorlib_System_Array,__Z115mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngineInternal_TypeInferenceRulesP21mscorlib_System_Array,__ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngineInternal_TypeInferenceRuleAttributeP21mscorlib_System_Array,__ZL100mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AssetBundleP21mscorlib_System_Array,__Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SendMessageOptionsP21mscorlib_System_Array,__Z102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_PrimitiveTypeP21mscorlib_System_Array,__Z94mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SpaceP21mscorlib_System_Array,__Z96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_LogTypeP21mscorlib_System_Array,__ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AddComponentMenuP21mscorlib_System_Array,__ZL105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ScriptableObjectP21mscorlib_System_Array,__Z105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CameraClearFlagsP21mscorlib_System_Array,__ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RendererP21mscorlib_System_Array,__ZL104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ReflectionProbeP21mscorlib_System_Array,__ZL96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextureP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_Texture2DP21mscorlib_System_Array,__ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RenderTextureP21mscorlib_System_Array,__ZL99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUIElementP21mscorlib_System_Array,__ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayerP21mscorlib_System_Array,__Z199mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array,__ZL117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP21mscorlib_System_Array,__ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayoutEntryP21mscorlib_System_Array,__Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUILayoutOption_TypeP21mscorlib_System_Array,__ZL96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUISkinP21mscorlib_System_Array,__ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array,__Z180mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP21mscorlib_System_Array,__Z98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_FontStyleP21mscorlib_System_Array
  ,__Z96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_KeyCodeP21mscorlib_System_Array,__Z98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_EventTypeP21mscorlib_System_Array,__Z103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_EventModifiersP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextAssetP21mscorlib_System_Array,__ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SerializePrivateVariablesP21mscorlib_System_Array,__ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_SerializeFieldP21mscorlib_System_Array,__ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ShaderP21mscorlib_System_Array,__ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_MaterialP21mscorlib_System_Array,__ZL89mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Byte_arrP21mscorlib_System_Array,__Z85mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ByteP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_BehaviourP21mscorlib_System_Array,__ZL96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_DisplayP21mscorlib_System_Array,__Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_IntPtrP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TransformP21mscorlib_System_Array,__ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_MotionP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_RigidbodyP21mscorlib_System_Array,__ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_ColliderP21mscorlib_System_Array,__Z103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CollisionFlagsP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AudioClipP21mscorlib_System_Array,__Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_SingleP21mscorlib_System_Array,__Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_WrapModeP21mscorlib_System_Array,__Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AnimationEventSourceP21mscorlib_System_Array,__ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AnimationClipP21mscorlib_System_Array,__Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_PlayModeP21mscorlib_System_Array,__ZL97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_AnimatorP21mscorlib_System_Array,__ZL96mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TerrainP21mscorlib_System_Array,__Z99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_TextAnchorP21mscorlib_System_Array,__Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_HorizontalWrapModeP21mscorlib_System_Array,__Z105mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_VerticalWrapModeP21mscorlib_System_Array,__ZL93mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_FontP21mscorlib_System_Array
  ,__ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_UnityEngine_UnityEngine_CanvasP21mscorlib_System_Array,__ZL127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_System_Core_System_Runtime_CompilerServices_ExtensionAttributeP21mscorlib_System_Array,__ZL101mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_System_Core_System_MonoTODOAttributeP21mscorlib_System_Array,__ZL90mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_AttributeP21mscorlib_System_Array,__ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_SerializableAttributeP21mscorlib_System_Array,__ZL104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_AttributeUsageAttributeP21mscorlib_System_Array,__ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ComVisibleAttributeP21mscorlib_System_Array,__Z86mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Int64P21mscorlib_System_Array,__Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_UInt32P21mscorlib_System_Array,__ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_CLSCompliantAttributeP21mscorlib_System_Array,__Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_UInt64P21mscorlib_System_Array,__Z86mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_SByteP21mscorlib_System_Array,__Z86mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Int16P21mscorlib_System_Array,__Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_UInt16P21mscorlib_System_Array,__Z87mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DoubleP21mscorlib_System_Array,__Z88mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_BooleanP21mscorlib_System_Array,__Z88mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_UIntPtrP21mscorlib_System_Array,__ZL89mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DelegateP21mscorlib_System_Array,__ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MethodInfoP21mscorlib_System_Array,__ZL107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_ConstructorInfoP21mscorlib_System_Array,__ZL100mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ParamArrayAttributeP21mscorlib_System_Array,__ZL117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_OutAttributeP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ObsoleteAttributeP21mscorlib_System_Array,__ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_DllImportAttributeP21mscorlib_System_Array,__ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_MarshalAsAttributeP21mscorlib_System_Array,__ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_InAttributeP21mscorlib_System_Array,__ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_GuidAttributeP21mscorlib_System_Array,__ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ComImportAttributeP21mscorlib_System_Array,__ZL122mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_OptionalAttributeP21mscorlib_System_Array,__ZL132mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_CompilerGeneratedAttributeP21mscorlib_System_Array
  ,__ZL133mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_InternalsVisibleToAttributeP21mscorlib_System_Array,__ZL135mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_RuntimeCompatibilityAttributeP21mscorlib_System_Array,__ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggerHiddenAttributeP21mscorlib_System_Array,__ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_DefaultMemberAttributeP21mscorlib_System_Array,__ZL130mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_DecimalConstantAttributeP21mscorlib_System_Array,__ZL125mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_FieldOffsetAttributeP21mscorlib_System_Array,__ZL98mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_MonoTODOAttributeP21mscorlib_System_Array,__Z128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeP21mscorlib_System_Array,__ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_TailoringInfoP21mscorlib_System_Array,__ZL112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_ContractionP21mscorlib_System_Array,__ZL110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_Level2MapP21mscorlib_System_Array,__Z128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_Mono_Globalization_Unicode_SimpleCollator_ExtenderTypeP21mscorlib_System_Array,__Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Hashtable_SlotP21mscorlib_System_Array,__Z117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Collections_Hashtable_EnumeratorModeP21mscorlib_System_Array,__Z127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Configuration_Assemblies_AssemblyHashAlgorithmP21mscorlib_System_Array,__Z134mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Configuration_Assemblies_AssemblyVersionCompatibilityP21mscorlib_System_Array,__ZL112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggableAttributeP21mscorlib_System_Array,__Z127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggableAttribute_DebuggingModesP21mscorlib_System_Array,__ZL117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggerDisplayAttributeP21mscorlib_System_Array,__ZL121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggerStepThroughAttributeP21mscorlib_System_Array,__ZL119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_DebuggerTypeProxyAttributeP21mscorlib_System_Array,__ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Diagnostics_StackFrameP21mscorlib_System_Array,__Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_CompareOptionsP21mscorlib_System_Array,__ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_CalendarP21mscorlib_System_Array,__Z114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_DateTimeFormatFlagsP21mscorlib_System_Array,__Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_DateTimeStylesP21mscorlib_System_Array,__Z117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_GregorianCalendarTypesP21mscorlib_System_Array,__Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_NumberStylesP21mscorlib_System_Array,__Z110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Globalization_UnicodeCategoryP21mscorlib_System_Array,__ZL113mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_ParameterBuilderP21mscorlib_System_Array
  ,__ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP21mscorlib_System_Array,__ZL110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_MethodBuilderP21mscorlib_System_Array,__ZL115mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_ConstructorBuilderP21mscorlib_System_Array,__ZL112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_PropertyBuilderP21mscorlib_System_Array,__ZL109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_Emit_FieldBuilderP21mscorlib_System_Array,__ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MethodBaseP21mscorlib_System_Array,__ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyCompanyAttributeP21mscorlib_System_Array,__ZL122mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyConfigurationAttributeP21mscorlib_System_Array,__ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyCopyrightAttributeP21mscorlib_System_Array,__ZL121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyDefaultAliasAttributeP21mscorlib_System_Array,__ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyDelaySignAttributeP21mscorlib_System_Array,__ZL120mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyDescriptionAttributeP21mscorlib_System_Array,__ZL120mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyFileVersionAttributeP21mscorlib_System_Array,__ZL129mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyInformationalVersionAttributeP21mscorlib_System_Array,__ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyKeyFileAttributeP21mscorlib_System_Array,__ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyKeyNameAttributeP21mscorlib_System_Array,__Z109mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyNameFlagsP21mscorlib_System_Array,__ZL116mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyProductAttributeP21mscorlib_System_Array,__ZL114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyTitleAttributeP21mscorlib_System_Array,__ZL118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_AssemblyTrademarkAttributeP21mscorlib_System_Array,__Z104mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_BindingFlagsP21mscorlib_System_Array,__Z110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_CallingConventionsP21mscorlib_System_Array,__Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_EventAttributesP21mscorlib_System_Array,__Z107mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_FieldAttributesP21mscorlib_System_Array,__Z103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MemberTypesP21mscorlib_System_Array,__Z108mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MethodAttributesP21mscorlib_System_Array,__Z112mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_MethodImplAttributesP21mscorlib_System_Array,__Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_PInfoP21mscorlib_System_Array,__Z111mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_ParameterAttributesP21mscorlib_System_Array,__Z110mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_PropertyAttributesP21mscorlib_System_Array
  ,__Z106mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Reflection_TypeAttributesP21mscorlib_System_Array,__ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Resources_NeutralResourcesLanguageAttributeP21mscorlib_System_Array,__ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Resources_SatelliteContractVersionAttributeP21mscorlib_System_Array,__Z128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsP21mscorlib_System_Array,__ZL137mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_CompilationRelaxationsAttributeP21mscorlib_System_Array,__ZL132mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_DefaultDependencyAttributeP21mscorlib_System_Array,__Z114mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_LoadHintP21mscorlib_System_Array,__ZL129mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_CompilerServices_StringFreezingAttributeP21mscorlib_System_Array,__Z113mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_ConstrainedExecution_CerP21mscorlib_System_Array,__Z121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_ConstrainedExecution_ConsistencyP21mscorlib_System_Array,__ZL138mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_ConstrainedExecution_ReliabilityContractAttributeP21mscorlib_System_Array,__ZL128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ClassInterfaceAttributeP21mscorlib_System_Array,__Z123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ClassInterfaceTypeP21mscorlib_System_Array,__ZL133mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ComDefaultInterfaceAttributeP21mscorlib_System_Array,__Z121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_ComInterfaceTypeP21mscorlib_System_Array,__ZL127mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_InterfaceTypeAttributeP21mscorlib_System_Array,__ZL125mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_PreserveSigAttributeP21mscorlib_System_Array,__ZL132mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_TypeLibImportClassAttributeP21mscorlib_System_Array,__ZL128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_TypeLibVersionAttributeP21mscorlib_System_Array,__Z118mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_InteropServices_UnmanagedTypeP21mscorlib_System_Array,__ZL121mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP21mscorlib_System_Array,__ZL123mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP21mscorlib_System_Array,__Z119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Messaging_ArgInfoTypeP21mscorlib_System_Array,__ZL120mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP21mscorlib_System_Array,__ZL124mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_Contexts_IContextAttributeP21mscorlib_System_Array,__Z117mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Remoting_WellKnownObjectModeP21mscorlib_System_Array,__Z136mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Serialization_Formatters_FormatterAssemblyStyleP21mscorlib_System_Array,__Z132mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Serialization_Formatters_FormatterTypeStyleP21mscorlib_System_Array,__Z129mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Serialization_Formatters_TypeFilterLevelP21mscorlib_System_Array,__Z125mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Runtime_Serialization_StreamingContextStatesP21mscorlib_System_Array
  ,__Z115mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Security_Principal_PrincipalPolicyP21mscorlib_System_Array,__ZL119mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Security_SecuritySafeCriticalAttributeP21mscorlib_System_Array,__ZL128mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Security_SuppressUnmanagedCodeSecurityAttributeP21mscorlib_System_Array,__ZL115mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Security_UnverifiableCodeAttributeP21mscorlib_System_Array,__Z102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_Threading_ThreadStateP21mscorlib_System_Array,__Z97mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_AttributeTargetsP21mscorlib_System_Array,__Z95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DateTime_WhichP21mscorlib_System_Array,__Z93mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DateTimeKindP21mscorlib_System_Array,__Z90mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_DayOfWeekP21mscorlib_System_Array,__ZL95mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_FlagsAttributeP21mscorlib_System_Array,__Z99mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_LoaderOptimizationP21mscorlib_System_Array,__ZL89mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_MonoTypeP21mscorlib_System_Array,__ZL103mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_NonSerializedAttributeP21mscorlib_System_Array,__Z91mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_PlatformIDP21mscorlib_System_Array,__ZL102mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_ThreadStaticAttributeP21mscorlib_System_Array,__Z89mscorlib_System_Array_m_InternalArray__IEnumerable_GetEnumerator_mscorlib_System_TypeCodeP21mscorlib_System_Array,__ZNSt3__111__stdoutbufIwE4syncEv,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE9showmanycEv,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE9underflowEv,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE5uflowEv,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE4syncEv,__ZNSt3__110__stdinbufIwE9underflowEv,__ZNSt3__110__stdinbufIwE5uflowEv,__ZNSt3__111__stdoutbufIcE4syncEv,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE9underflowEv,__ZNSt3__110__stdinbufIcE9underflowEv,__ZNSt3__110__stdinbufIcE5uflowEv,__ZNKSt13runtime_error4whatEv,__ZNKSt3__119__iostream_category4nameEv,__ZNKSt3__18time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv
  ,__ZNKSt3__120__time_get_c_storageIcE7__weeksEv,__ZNKSt3__120__time_get_c_storageIcE8__monthsEv,__ZNKSt3__120__time_get_c_storageIcE7__am_pmEv,__ZNKSt3__120__time_get_c_storageIcE3__cEv,__ZNKSt3__120__time_get_c_storageIcE3__rEv,__ZNKSt3__120__time_get_c_storageIcE3__xEv,__ZNKSt3__120__time_get_c_storageIcE3__XEv,__ZNKSt3__18time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv,__ZNKSt3__120__time_get_c_storageIwE7__weeksEv,__ZNKSt3__120__time_get_c_storageIwE8__monthsEv,__ZNKSt3__120__time_get_c_storageIwE7__am_pmEv,__ZNKSt3__120__time_get_c_storageIwE3__cEv,__ZNKSt3__120__time_get_c_storageIwE3__rEv,__ZNKSt3__120__time_get_c_storageIwE3__xEv,__ZNKSt3__120__time_get_c_storageIwE3__XEv,__ZNKSt3__110moneypunctIcLb0EE16do_decimal_pointEv,__ZNKSt3__110moneypunctIcLb0EE16do_thousands_sepEv,__ZNKSt3__110moneypunctIcLb0EE14do_frac_digitsEv,__ZNKSt3__110moneypunctIcLb1EE16do_decimal_pointEv,__ZNKSt3__110moneypunctIcLb1EE16do_thousands_sepEv,__ZNKSt3__110moneypunctIcLb1EE14do_frac_digitsEv,__ZNKSt3__110moneypunctIwLb0EE16do_decimal_pointEv,__ZNKSt3__110moneypunctIwLb0EE16do_thousands_sepEv,__ZNKSt3__110moneypunctIwLb0EE14do_frac_digitsEv,__ZNKSt3__110moneypunctIwLb1EE16do_decimal_pointEv,__ZNKSt3__110moneypunctIwLb1EE16do_thousands_sepEv,__ZNKSt3__110moneypunctIwLb1EE14do_frac_digitsEv,__ZNKSt3__17codecvtIwc11__mbstate_tE11do_encodingEv,__ZNKSt3__17codecvtIwc11__mbstate_tE16do_always_noconvEv,__ZNKSt3__17codecvtIwc11__mbstate_tE13do_max_lengthEv
  ,__ZNKSt3__18numpunctIcE16do_decimal_pointEv,__ZNKSt3__18numpunctIcE16do_thousands_sepEv,__ZNKSt3__18numpunctIwE16do_decimal_pointEv,__ZNKSt3__18numpunctIwE16do_thousands_sepEv,__ZNKSt3__17codecvtIcc11__mbstate_tE11do_encodingEv,__ZNKSt3__17codecvtIcc11__mbstate_tE16do_always_noconvEv,__ZNKSt3__17codecvtIcc11__mbstate_tE13do_max_lengthEv,__ZNKSt3__17codecvtIDsc11__mbstate_tE11do_encodingEv,__ZNKSt3__17codecvtIDsc11__mbstate_tE16do_always_noconvEv,__ZNKSt3__17codecvtIDsc11__mbstate_tE13do_max_lengthEv,__ZNKSt3__17codecvtIDic11__mbstate_tE11do_encodingEv,__ZNKSt3__17codecvtIDic11__mbstate_tE16do_always_noconvEv,__ZNKSt3__17codecvtIDic11__mbstate_tE13do_max_lengthEv,__ZNKSt9bad_alloc4whatEv,__ZNKSt11logic_error4whatEv,__ZNKSt8bad_cast4whatEv,_GC_page_was_dirty,__ZNSt3__113basic_ostreamIcNS_11char_traitsIcEEE5flushEv,__ZL11reveal_linkPv,__Znwj,__ZN6il2cpp2vm9Exception24GetArgumentNullExceptionEPKc,__ZN6il2cpp2vm6String3NewEPKc,__ZN6il2cpp2vm5Class14FromIl2CppTypeEPK10Il2CppType,__ZN6il2cpp2vm10Reflection13GetTypeObjectEPK10Il2CppType,__ZN6il2cpp2vm6Method7GetNameEP10MethodInfo,__ZN6il2cpp2vm6String9GetLengthEP12Il2CppString,__ZN6il2cpp2vm6String8GetCharsEP12Il2CppString,__ZN6il2cpp2vm5Class4InitEP8TypeInfo,__ZN6il2cpp5utils11StringUtils4HashEPKc,__ZN6il2cpp2vm14TypeNameParser5ParseEv
  ,__ZN6il2cpp2vm6Thread14GetStackFramesEP12Il2CppThread,__ZN6il2cpp2vm8Assembly4LoadEPKc,__ZN6il2cpp2vm8Assembly8GetImageEPK14Il2CppAssembly,__ZN6il2cpp2vm9Exception20GetTypeLoadExceptionEPKc,_tolower,__ZN6il2cpp2os9Directory10GetCurrentERNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,__ZN6il2cpp6icalls8mscorlib6System9Threading29il2cpp_wait_handle_get_handleEP16Il2CppWaitHandle,__ZN6il2cpp2os6Thread5SleepEj,__ZN6il2cpp2osL18ThreadStartWrapperEPv,__ZN6il2cpp6icalls8mscorlib4Mono7Interop15ComInteropProxy9FindProxyE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence10_CanSecureEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence19_IsMachineProtectedEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence16_IsUserProtectedEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence15_ProtectMachineEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib4Mono8Security12Cryptography18KeyPairPersistence12_ProtectUserEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System11__ComObject9CreateRCWEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System9Activator22CreateInstanceInternalEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System9AppDomain15getFriendlyNameEP15Il2CppAppDomain,__ZN6il2cpp6icalls8mscorlib6System9AppDomain8getSetupEP15Il2CppAppDomain,__ZN6il2cpp6icalls8mscorlib6System9AppDomain22InternalGetProcessGuidEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System9AppDomain29InternalIsFinalizingForUnloadEi,__ZN6il2cpp6icalls8mscorlib6System9AppDomain18InternalSetContextEP49mscorlib_System_Runtime_Remoting_Contexts_Context,__ZN6il2cpp6icalls8mscorlib6System9AppDomain17InternalSetDomainEP25mscorlib_System_AppDomain,__ZN6il2cpp6icalls8mscorlib6System9AppDomain21InternalSetDomainByIDEi,__ZN6il2cpp6icalls8mscorlib6System11ArgIterator17IntGetNextArgTypeEP27mscorlib_System_ArgIterator,__ZN6il2cpp6icalls8mscorlib6System5Array5CloneEP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System5Array7GetRankEP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System6Buffer18ByteLengthInternalEP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System4Enum12get_hashcodeEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System4Enum19get_underlying_typeEP20Il2CppReflectionType
  ,__ZN6il2cpp6icalls8mscorlib6System4Enum9get_valueEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System11Environment20GetWindowsFolderPathEi,__ZN6il2cpp6icalls8mscorlib6System11Environment30internalGetEnvironmentVariableEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System2GC15CollectionCountEi,__ZN6il2cpp6icalls8mscorlib6System2GC13GetGenerationEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System2GC14GetTotalMemoryEb,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo45construct_internal_locale_from_current_localeEP17Il2CppCultureInfo,__ZN6il2cpp6icalls8mscorlib6System2IO9DriveInfo20GetDriveTypeInternalEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO24GetCurrentDirectoryICallEPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11GetTempPathEPP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System15MonoCustomAttrs31GetCustomAttributesDataInternalEPv,__ZN6il2cpp6icalls8mscorlib6System8MonoType12get_AssemblyEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType14get_attributesEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType12get_BaseTypeEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType19get_DeclaringMethodEPv,__ZN6il2cpp6icalls8mscorlib6System8MonoType17get_DeclaringTypeEP24Il2CppReflectionMonoType,__ZN6il2cpp6icalls8mscorlib6System8MonoType22get_IsGenericParameterEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType10get_ModuleEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType8get_NameEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType13get_NamespaceEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType12GetArrayRankEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType14GetElementTypeEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType19GetGenericArgumentsEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType13GetInterfacesEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType11IsByRefImplEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System8MonoType15IsCOMObjectImplEP24Il2CppReflectionMonoType,__ZN6il2cpp6icalls8mscorlib6System8MonoType13IsPointerImplEP24Il2CppReflectionMonoType,__ZN6il2cpp6icalls8mscorlib6System8MonoType15IsPrimitiveImplEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System6Object7GetTypeEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System6Object19InternalGetHashCodeEP12Il2CppObject
  ,__ZN6il2cpp6icalls8mscorlib6System6Object15MemberwiseCloneEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System6Object11obj_addressEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly14get_EntryPointEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly12get_fullnameEP24Il2CppReflectionAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly25get_global_assembly_cacheEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly12get_locationEP35mscorlib_System_Reflection_Assembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly18get_ReflectionOnlyEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly25GetManifestModuleInternalEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly24GetManifestResourceNamesEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly18GetModulesInternalEP35mscorlib_System_Reflection_Assembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly13GetNamespacesEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly23GetReferencedAssembliesEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly27InternalImageRuntimeVersionEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly27MonoDebugger_GetMethodTokenEPv,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit15SignatureHelper19get_signature_fieldEP25Il2CppReflectionSigHelper,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit15SignatureHelper19get_signature_localEP25Il2CppReflectionSigHelper,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit11TypeBuilder22get_IsGenericParameterEP27Il2CppReflectionTypeBuilder,__ZN6il2cpp6icalls8mscorlib6System10Reflection9FieldInfo19GetUnmanagedMarshalEP21Il2CppReflectionField,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MemberInfo17get_MetadataTokenEPv,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MethodBase21GetMethodBodyInternalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module17get_MetadataTokenEP22Il2CppReflectionModule,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module13GetGlobalTypeEP22Il2CppReflectionModule,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module15GetGuidInternalEP33mscorlib_System_Reflection_Module,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module12GetHINSTANCEEP33mscorlib_System_Reflection_Module,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module18GetMDStreamVersionE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module16InternalGetTypesEP33mscorlib_System_Reflection_Module,__ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField14GetFieldOffsetEP21Il2CppReflectionField,__ZN6il2cpp6icalls8mscorlib6System10Reflection9MonoField19GetRawConstantValueEPv,__ZN6il2cpp6icalls8mscorlib6System10Reflection18MonoGenericCMethod17get_ReflectedTypeEPv,__ZN6il2cpp6icalls8mscorlib6System10Reflection17MonoGenericMethod17get_ReflectedTypeEPv
  ,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod19get_base_definitionEP22Il2CppReflectionMethod,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod19get_IsGenericMethodEP22Il2CppReflectionMethod,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod29get_IsGenericMethodDefinitionEP22Il2CppReflectionMethod,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod8get_nameEP22Il2CppReflectionMethod,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod21GetDllImportAttributeE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod19GetGenericArgumentsEP22Il2CppReflectionMethod,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MonoMethod31GetGenericMethodDefinition_implEPv,__ZN6il2cpp6icalls8mscorlib6System10Reflection14MonoMethodInfo18get_retval_marshalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System10Reflection13ParameterInfo16GetMetadataTokenEPv,__ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers14GetObjectValueEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle18CheckCurrentDomainEi,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle21GetAddrOfPinnedObjectEi,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle9GetTargetEi,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14AddRefInternalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal14AllocCoTaskMemEi,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal12AllocHGlobalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal31GetComSlotForMethodInfoInternalEP37mscorlib_System_Reflection_MemberInfo,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal37GetFunctionPointerForDelegateInternalEP24mscorlib_System_Delegate,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal29GetIDispatchForObjectInternalEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal28GetIUnknownForObjectInternalEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal15GetObjectForCCWE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal11IsComObjectEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal61PtrToStringAnsi_mscorlib_System_String_mscorlib_System_IntPtrE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal15PtrToStringBSTRE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal60PtrToStringUni_mscorlib_System_String_mscorlib_System_IntPtrE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal24ReleaseComObjectInternalEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal15ReleaseInternalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal6SizeOfEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal12StringToBSTREP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal19StringToHGlobalAnsiEP12Il2CppString
  ,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal18StringToHGlobalUniEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting10Activation18ActivationServices34AllocateUninitializedClassInstanceEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting7Proxies9RealProxy20InternalGetProxyTypeEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System7Runtime8Remoting16RemotingServices18IsTransparentProxyEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System19RuntimeMethodHandle18GetFunctionPointerE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System8Security12Cryptography24RNGCryptoServiceProvider13RngInitializeEP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System8Security6Policy8Evidence21IsAuthenticodePresentEP14Il2CppAssembly,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal15WindowsIdentity9_GetRolesE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal15WindowsIdentity12GetTokenNameE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal15WindowsIdentity12GetUserTokenEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal27WindowsImpersonationContext10CloseTokenE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal27WindowsImpersonationContext14DuplicateTokenE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal27WindowsImpersonationContext15SetCurrentTokenE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System8Security13SecurityFrame17_GetSecurityFrameEi,__ZN6il2cpp6icalls8mscorlib6System8Security13SecurityFrame17_GetSecurityStackEi,__ZN6il2cpp6icalls8mscorlib6System6String19InternalAllocateStrEi,__ZN6il2cpp6icalls8mscorlib6System6String14InternalInternEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System6String18InternalIsInternedEP12Il2CppString,__ZN6il2cpp6icalls8mscorlib6System4Text8Encoding16InternalCodePageEPi,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked9DecrementEPi,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked11Decrement64EPx,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked9IncrementEPi,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked11Increment64EPx,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked4ReadEPx,__ZN6il2cpp6icalls8mscorlib6System9Threading7Monitor25Monitor_test_synchronisedEP12Il2CppObject,__ZN6il2cpp6icalls8mscorlib6System9Threading5Mutex21ReleaseMutex_internalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System9Threading16NativeEventCalls19ResetEvent_internalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System9Threading16NativeEventCalls17SetEvent_internalE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread22GetAbortExceptionStateEPv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread23GetCachedCurrentCultureEP12Il2CppThread
  ,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread25GetCachedCurrentUICultureEPv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread16GetName_internalEPv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread27GetSerializedCurrentCultureEP12Il2CppThread,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread29GetSerializedCurrentUICultureEPv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread8GetStateEP12Il2CppThread,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread12VolatileReadEPh,__ZN6il2cpp6icalls8mscorlib6System4Type17get_IsGenericTypeEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type27get_IsGenericTypeDefinitionEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type29GetGenericParameterAttributesEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type35GetGenericParameterConstraints_implEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type27GetGenericParameterPositionEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type29GetGenericTypeDefinition_implEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type19GetTypeCodeInternalEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type20internal_from_handleE12Il2CppIntPtr,__ZN6il2cpp6icalls8mscorlib6System4Type11IsArrayImplEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type15make_byref_typeEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System4Type15MakePointerTypeEP20Il2CppReflectionType,__ZN6il2cpp6icalls8mscorlib6System14TypedReference8ToObjectEPv,__Znaj,__ZN12_GLOBAL__N_117createClothFabricERN5physx13PxInputStreamE,__ZN12_GLOBAL__N_117createClothFabricERKN5physx17PxClothFabricDescE,__Z30getPxVehicleGearsDataMNbRatiosPKN5physx18PxVehicleGearsDataE,__Z35getPxVehicleDifferential4WDataMTypePKN5physx27PxVehicleDifferential4WDataE,__Z48getPxVehicleDifferentialNWData_DrivenWheelStatusPKN5physx27PxVehicleDifferentialNWDataE,__Z35getPxVehicleClutchDataMAccuracyModePKN5physx19PxVehicleClutchDataE,__Z41getPxVehicleClutchDataMEstimateIterationsPKN5physx19PxVehicleClutchDataE,__Z25getPxVehicleTireDataMTypePKN5physx17PxVehicleTireDataE,__Z42getNbPxVehicleWheelsSimData_SuspensionDataPKN5physx22PxVehicleWheelsSimDataE,__Z37getNbPxVehicleWheelsSimData_WheelDataPKN5physx22PxVehicleWheelsSimDataE,__Z36getNbPxVehicleWheelsSimData_TireDataPKN5physx22PxVehicleWheelsSimDataE
  ,__Z47getNbPxVehicleWheelsSimData_SuspTravelDirectionPKN5physx22PxVehicleWheelsSimDataE,__Z51getNbPxVehicleWheelsSimData_SuspForceAppPointOffsetPKN5physx22PxVehicleWheelsSimDataE,__Z51getNbPxVehicleWheelsSimData_TireForceAppPointOffsetPKN5physx22PxVehicleWheelsSimDataE,__Z45getNbPxVehicleWheelsSimData_WheelCentreOffsetPKN5physx22PxVehicleWheelsSimDataE,__Z45getNbPxVehicleWheelsSimData_WheelShapeMappingPKN5physx22PxVehicleWheelsSimDataE,__Z48getNbPxVehicleWheelsSimData_SceneQueryFilterDataPKN5physx22PxVehicleWheelsSimDataE,__Z46getNbPxVehicleWheelsDynData_WheelRotationSpeedPKN5physx22PxVehicleWheelsDynDataE,__Z46getNbPxVehicleWheelsDynData_WheelRotationAnglePKN5physx22PxVehicleWheelsDynDataE,__Z39getPxVehicleWheelsDynData_Wheel4DynDataPKN5physx22PxVehicleWheelsDynDataE,__Z38getNbPxVehicleDriveDynData_AnalogInputPKN5physx21PxVehicleDriveDynDataE,__Z31getPxVehicleDriveDynData_GearUpPKN5physx21PxVehicleDriveDynDataE,__Z33getPxVehicleDriveDynData_GearDownPKN5physx21PxVehicleDriveDynDataE,__Z37getPxVehicleDriveDynData_UseAutoGearsPKN5physx21PxVehicleDriveDynDataE,__Z36getPxVehicleDriveDynData_CurrentGearPKN5physx21PxVehicleDriveDynDataE,__Z35getPxVehicleDriveDynData_TargetGearPKN5physx21PxVehicleDriveDynDataE,__Z35getPxVehicleDriveDynData_GearChangePKN5physx21PxVehicleDriveDynDataE,__Z37getPxVehicleDriveDynDataMUseAutoGearsPKN5physx21PxVehicleDriveDynDataE,__Z38getPxVehicleDriveDynDataMGearUpPressedPKN5physx21PxVehicleDriveDynDataE,__Z40getPxVehicleDriveDynDataMGearDownPressedPKN5physx21PxVehicleDriveDynDataE,__Z36getPxVehicleDriveDynDataMCurrentGearPKN5physx21PxVehicleDriveDynDataE,__Z35getPxVehicleDriveDynDataMTargetGearPKN5physx21PxVehicleDriveDynDataE,__Z30getPxVehicleWheels_VehicleTypePKN5physx15PxVehicleWheelsE,__Z36getPxVehicleWheels_RigidDynamicActorPKN5physx15PxVehicleWheelsE,__Z35getPxVehicleWheels_ConcreteTypeNamePKN5physx15PxVehicleWheelsE,__Z34getPxVehicleDrive_ConcreteTypeNamePKN5physx14PxVehicleDriveE,__Z36getPxVehicleDrive4W_ConcreteTypeNamePKN5physx16PxVehicleDrive4WE,__Z32getPxVehicleDriveTank_DriveModelPKN5physx18PxVehicleDriveTankE,__Z38getPxVehicleDriveTank_ConcreteTypeNamePKN5physx18PxVehicleDriveTankE,__Z36getPxVehicleDriveNW_ConcreteTypeNamePKN5physx16PxVehicleDriveNWE,__Z33getNbPxVehicleNoDrive_BrakeTorquePKN5physx16PxVehicleNoDriveE
  ,__Z33getNbPxVehicleNoDrive_DriveTorquePKN5physx16PxVehicleNoDriveE,__Z32getNbPxVehicleNoDrive_SteerAnglePKN5physx16PxVehicleNoDriveE,__Z36getPxVehicleNoDrive_ConcreteTypeNamePKN5physx16PxVehicleNoDriveE,__ZN5physx20GetNbTorqueCurvePairEPKNS_19PxVehicleEngineDataE,__ZN6Object13ClassIDToRTTIEi,__ZN6Object15GetSuperClassIDEi,__Z31ReadObjectFromPersistentManageri,__ZN6Object15ClassIDToStringEi,__ZNK16LightmapSettings22GetLightmapsModeLegacyEv,__ZN13RenderTexture6CreateEv,__ZNK6Camera22GetWorldToCameraMatrixEv,__ZNK5Unity10GameObject23QueryComponentTransformEv,__ZN5Unity8Material9GetShaderEv,__Z16CreateRenderLoopR6Camera,__ZNK6Object14GetMemoryLabelEv,__ZN9ShaderLab14GetShaderTagIDERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZN13dynamic_arrayI13ShadowedLightLj4EE19push_back_constructEv,__ZN5Unity8Material12GetPassCountEv,__ZNK5Light15IsValidToRenderEv,__ZN16ReflectionProbes22GetCurrentFrameCounterEv,__ZN16ReflectionProbes9GetCameraEv,__ZN10Matrix4x4f11SetIdentityEv,__ZNK6Shader11IsSupportedEv,__ZNK6Shader23GetActiveSubShaderIndexEv,__ZN15SkyboxGenerator33GetSixFaceSkyboxVertexDeclarationEj,__Z28EnsureRenderTextureIsCreatedP13RenderTexture,__ZN14CompressedMesh10GetQualityE15MeshCompression,__ZN12CachedWriter15CompleteWritingEv,__ZNK12CachedWriter11GetPositionEv,__ZN12CachedReader3EndEv
  ,__ZNK9Texture2D16CountDataMipmapsEv,_il2cpp_string_new_wrapper,_il2cpp_object_get_class,_il2cpp_class_get_name,__ZN17UniqueIDGenerator10AllocateIDEv,__ZN13dynamic_arrayIN15LODGroupManager16LODSelectionDataELj4EE9push_backEv,_png_create_info_struct,__Z21HasAlphaTextureFormat13TextureFormat,__ZN9ShaderLab33GenerateFastPropertyName28BitHashEPKc,__Z19GetBytesForOnePixel13TextureFormat,__Z29GetTextureSizeAllowedMultiple13TextureFormat,__Z27FindActiveTransformWithPathPKc,__ZNK5Unity10GameObject8IsActiveEv,__ZL30MonoBehaviourGetObjectGUIStatePv,__ZN13MonoBehaviour15GetUseGUILayoutEv,__ZN5IMGUI16GetFocusedWindowER8GUIState,__ZNK15GUIEventManager13GetEventCountEv,__Z17GetNumericVersionPKc,__Z18IsDirectoryCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z22GetFolderSizeRecursiveRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z13GetFileLengthRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z24CreateDirectoryRecursiveRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZN4File5CloseEv,__Z21DeleteFileOrDirectoryRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z11StringToIntPKc,_time__wrapper,__ZN5Cache22ReadCacheIndexThreadedEPv,__Z13IsFileCreatedRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z22IsFileOrDirectoryInUseRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZNK6Camera19GetProjectionMatrixEv
  ,__ZN6Object15StringToClassIDEPKc,__ZNK6Object12GetClassNameEv,__Z24GetManagerPtrFromContexti,__ZN13MonoBehaviour26WillUnloadScriptableObjectEv,__ZN11TimeManager13StepFixedTimeEv,__ZN12InputManager17GetTextFieldInputEv,__ZN19ScriptingInvocation6InvokeEv,__Z24scripting_field_get_typeP14ScriptingField,__Z23scripting_type_get_typeP13ScriptingType,__Z25scripting_class_from_typeP13ScriptingType,__Z25scripting_field_get_flagsP14ScriptingField,__Z24scripting_field_get_nameP14ScriptingField,__Z28scripting_class_is_valuetypeP14ScriptingClass,__Z20scripting_object_newP14ScriptingClass,__Z26scripting_field_get_offsetP14ScriptingField,__Z24scripting_class_get_nameP14ScriptingClass,__ZN25ScriptingInvocationNoArgs6InvokeEv,_il2cpp_object_new,__Z20scripting_string_newPKc,__Z34scripting_class_array_element_sizeP14ScriptingClass,__ZNK16TypeTreeIterator7GetNodeEv,__Z25scripting_method_get_name21ScriptingMethodIl2Cpp,__Z29scripting_class_get_namespaceP14ScriptingClass,__Z32scripting_class_get_assemblynameP14ScriptingClass,__Z27scripting_class_is_abstractP14ScriptingClass,__Z26scripting_class_is_genericP14ScriptingClass,__Z26scripting_class_get_parentP14ScriptingClass,__Z28scripting_method_is_instance21ScriptingMethodIl2Cpp,__Z35scripting_method_get_argument_count21ScriptingMethodIl2Cpp,__Z31scripting_method_get_returntype21ScriptingMethodIl2Cpp
  ,__ZN9Scripting28GetClassIDFromScriptingClassEP14ScriptingClass,__Z39scripting_class_from_systemtypeinstanceP15ScriptingObject,__ZNK13MonoBehaviour8GetClassEv,__ZN9Scripting19ScriptingWrapperForEP6Object,__Z21GetScriptingArraySizeP14ScriptingArray,__ZN6Object21IDToPointerThreadSafeEi,__ZN14SerializedFile29ExtractLegacyScriptReferencesEv,__ZNK15FileSystemEntry4SizeEv,__Z22IsBuildTarget64BitBlob19BuildTargetPlatform,__ZN9GfxDevice13GetDynamicVBOEv,__ZNK9ShaderLab16FastPropertyName7GetNameEv,__Z21GetManagerFromContexti,__ZN8keywords6CreateEPKc,__ZNK16MemoryFileSystem7IsEmptyEv,__Z16TrimSlashInplaceINSt3__112basic_stringIcNS0_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEEEERT_S9_,__ZNK15FileSystemEntry12FolderExistsEv,__ZNK15FileSystemEntry5IsDirEv,__ZNK15FileSystemEntry6ExistsEv,__ZNK15FileSystemEntry4PathEv,__ZN12FileAccessor5CloseEv,__ZN15FileSystemEntry11CreateAsDirEv,__ZN15FileSystemEntry8IsLockedEv,__ZNK15FileSystemEntry8FilenameEv,_readdir__wrapper,__Z15CreateDirectoryRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z7HasARGVRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z7yyerrorPKc,__Z24GetShaderChannelFromNameRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZN9Scripting32GetCachedPtrFromScriptingWrapperEP15ScriptingObject,__Z51AssetBundleCreateRequest_Get_Custom_PropAssetBundleP15ScriptingObject
  ,__ZN9Scripting22CreateScriptableObjectERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__Z26scripting_object_get_classP15ScriptingObject,__Z42ScriptingGetComponentsOfTypeFromGameObjectRK26ScriptingGetComponentsArgs,__Z28LayerMask_CUSTOM_LayerToNamei,__Z28LayerMask_CUSTOM_NameToLayerP15ScriptingString,__Z38ScriptableObject_CUSTOM_CreateInstanceP15ScriptingString,__Z46ScriptableObject_CUSTOM_CreateInstanceFromTypeP15ScriptingObject,__Z32Renderer_Get_Custom_PropMaterialP15ScriptingObject,__Z41GUIUtility_CUSTOM_Internal_GetDefaultSkini,__Z20scripting_string_newRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__Z42GUIStyleState_CUSTOM_GetBackgroundInternalP15ScriptingObject,__Z30RectOffset_Get_Custom_PropLeftP15ScriptingObject,__Z31RectOffset_Get_Custom_PropRightP15ScriptingObject,__Z29RectOffset_Get_Custom_PropTopP15ScriptingObject,__Z32RectOffset_Get_Custom_PropBottomP15ScriptingObject,__Z36RectOffset_Get_Custom_PropHorizontalP15ScriptingObject,__Z34RectOffset_Get_Custom_PropVerticalP15ScriptingObject,__Z28GUIStyle_Get_Custom_PropNameP15ScriptingObject,__Z36GUIStyle_Get_Custom_PropStretchWidthP15ScriptingObject,__Z37GUIStyle_Get_Custom_PropStretchHeightP15ScriptingObject,__Z25Event_Get_Custom_PropTypeP15ScriptingObject,__Z30Event_Get_Custom_PropModifiersP15ScriptingObject,__Z30Event_Get_Custom_PropCharacterP15ScriptingObject,__Z32Event_Get_Custom_PropCommandNameP15ScriptingObject,__Z28Event_Get_Custom_PropKeyCodeP15ScriptingObject,__Z35Matrix4x4_Get_Custom_PropIsIdentity10Matrix4x4f,__Z29TextAsset_Get_Custom_PropTextP15ScriptingObject,__Z26Shader_CUSTOM_PropertyToIDP15ScriptingString,__Z33Camera_Get_Custom_PropCullingMaskP15ScriptingObject,__Z31Camera_Get_Custom_PropEventMaskP15ScriptingObject
  ,__Z35Camera_Get_Custom_PropTargetTextureP15ScriptingObject,__Z32Camera_Get_Custom_PropClearFlagsP15ScriptingObject,__Z27Camera_CUSTOM_GetAllCamerasP14ScriptingArray,__ZN9Scripting33GetInstanceIDFromScriptingWrapperEP15ScriptingObject,__Z22Input_CUSTOM_GetKeyInti,__Z22Input_CUSTOM_GetButtonP15ScriptingString,__Z26Input_CUSTOM_GetButtonDownP15ScriptingString,__Z27Input_CUSTOM_GetMouseButtoni,__Z31Input_CUSTOM_GetMouseButtonDowni,__Z26Object_Get_Custom_PropNameP15ScriptingObject,__Z22Object_CUSTOM_ToStringP15ScriptingObject,__Z34Component_Get_Custom_PropTransformP15ScriptingObject,__Z35Component_Get_Custom_PropGameObjectP15ScriptingObject,__Z33GameObject_CUSTOM_CreatePrimitivei,__Z35GameObject_Get_Custom_PropTransformP15ScriptingObject,__ZN19SkinnedMeshRenderer17GetActualRootBoneEv,__ZN9AudioClip22GetFormatFromExtensionERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__ZL39UnityAudioEffect_InternalCreateCallbackP14FMOD_DSP_STATE,__ZL40UnityAudioEffect_InternalReleaseCallbackP14FMOD_DSP_STATE,__ZL38UnityAudioEffect_InternalResetCallbackP14FMOD_DSP_STATE,__ZN4FMOD3DSP7releaseEv,__Z14StringToUInt64PKc,__ZNK13MonoBehaviour6GetDSPEv,__ZN4FMOD12ChannelGroup7releaseEv,__ZN4FMOD6System5closeEv,_FMOD_System_Create,__ZN12AudioManager10InitNormalEv,__ZN13MonoBehaviour14GetOrCreateDSPEv,__ZN4FMOD3DSP6removeEv,__Z31AudioMixerDuckingCreateCallbackP21UnityAudioEffectState
  ,__Z32AudioMixerDuckingDestroyCallbackP21UnityAudioEffectState,__ZN4FMOD5Sound7releaseEv,__ZN12AudioManager15GetSoundManagerEv,__ZN10SampleClip20ResolveFMODSoundTypeENS_9SoundTypeE,__ZN4FMOD6System6updateEv,__ZN9AudioClip27IsFormatSupportedByPlatformERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,_JS_Sound_ReleaseInstance__wrapper,__ZN19SkinnedMeshRenderer7GetMeshEv,__ZN13AnimationClip15GetRuntimeAssetEv,__ZN11UnityEngine9Animation15IsMuscleBindingERKNS0_14GenericBindingE,__ZN7mecanim6CRCKeyENS_7eStringE,__ZN7mecanim4hand10FingerNameEj,__ZN7mecanim4hand13FingerDoFNameEj,__ZN7mecanim4hand12PhalangeNameEj,__ZNK8Animator7IsHumanEv,__Z28Animator_CUSTOM_StringToHashP15ScriptingString,__ZN6Object27AllocateAndAssignInstanceIDEPS_,__Z25GetBytesFromTextureFormat13TextureFormat,__Z17dynamic_pptr_castIP9Texture2D6ObjectET_RK4PPtrIT0_E,__Z20GetChannelFormatSizeh,__ZNK14SplatMaterials20GetSplatBaseMaterialEv,__ZN16LightmapSettings14GetLightProbesEv,__ZNK16LightmapSettings24GetEnlightenSceneMappingEv,_FT_Done_Face,__ZN20TextRenderingPrivate4Font18ResetCachedTextureEv,__Z17dynamic_pptr_castIP9Texture2D7TextureET_RK4PPtrIT0_E,__ZN20TextRenderingPrivate19NativeTextGenerator5SetupEv,__ZN20TextRenderingPrivate19NativeTextGenerator13ProcessStringEv,__ZNK20TextRenderingPrivate8TextMesh7GetFontEv,_cff_ps_has_glyph_names
  ,_cff_get_ps_name,_cff_driver_init,_cff_size_init,_cff_slot_init,_cff_parse_font_matrix,_cff_parse_font_bbox,_cff_parse_private_dict,_cff_parse_cid_ros,_cff_cmap_encoding_init,_cff_cmap_unicode_init,_ps_unicode_value,_ps_get_macintosh_name,_ps_get_standard_strings,_sfnt_get_ps_name,_ft_smooth_init,_tt_driver_init,_tt_size_init,_tt_slot_init,_TT_RunIns,_TT_Load_Glyph_Header,_TT_Load_Simple_Glyph,_TT_Load_Composite_Glyph,_pshinter_get_globals_funcs,_pshinter_get_t1_funcs,_pshinter_get_t2_funcs,_ps_hinter_init,_ft_raster1_init,__Z27Font_Get_Custom_PropDynamicP15ScriptingObject,__Z40TextGenerator_Get_Custom_PropVertexCountP15ScriptingObject,__Z37TextGenerator_CUSTOM_GetVerticesArrayP15ScriptingObject
  ,__Z43TextGenerator_Get_Custom_PropCharacterCountP15ScriptingObject,__Z39TextGenerator_CUSTOM_GetCharactersArrayP15ScriptingObject,__Z38TextGenerator_Get_Custom_PropLineCountP15ScriptingObject,__Z34TextGenerator_CUSTOM_GetLinesArrayP15ScriptingObject,__Z51TextGenerator_Get_Custom_PropFontSizeUsedForBestFitP15ScriptingObject,__Z11StringToKeyRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,_glCheckFramebufferStatus__wrapper,_glCreateShader__wrapper,_glGetString__wrapper,__ZN22CreateGpuProgramOutput20CreateChannelAssignsEv,__ZN22CreateGpuProgramOutput12CreateParamsEv,_isspace,__Z14QueryExtensionPKc,__Z32GetShaderInstanceMatrixParamNamei,__Z25GetBuiltinVectorParamNamei,__Z28IsBinaryBlobResourceFilePathRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE,__ZL84UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Rigidbody_TP33UnityEngine_UnityEngine_Component,__ZL83UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Renderer_TP33UnityEngine_UnityEngine_Component,__ZL95mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject_m_MoveNextP84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObject,__Z98mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object_m_get_Current_gsharedP76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Object,__ZN6il2cpp2vm6Object3NewEP8TypeInfo,__Z123mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Key_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__Z125mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Value_gsharedP105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,__ZL81UnityEngine_UnityEngine_Component_m_GetComponent_UnityEngine_UnityEngine_Camera_TP33UnityEngine_UnityEngine_Component,__ZN6il2cpp2vm13InternalCalls7ResolveEPKc,_abs__wrapper,__ZN6il2cpp2vm6Thread19GetThreadStaticDataEi,__Z78System_System_Collections_Generic_Stack_1_mscorlib_System_Object_m_Pop_gsharedP64System_System_Collections_Generic_Stack_1_mscorlib_System_Object,__Z83mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object_m_ToArray_gsharedP65mscorlib_System_Collections_Generic_List_1_mscorlib_System_Object,__ZL103mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry_m_MoveNextP92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntry10874
  ,__Z124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_get_Values_gsharedP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object,_pthread_mutex_unlock__wrapper,_pthread_mutex_lock__wrapper,_pthread_cond_broadcast__wrapper,_uselocale__wrapper,_wcslen,_emscripten_glGetString__wrapper,_emscripten_glIsTexture__wrapper,_emscripten_glIsBuffer__wrapper,_emscripten_glIsRenderbuffer__wrapper,_emscripten_glCreateShader__wrapper,_emscripten_glIsShader__wrapper,_emscripten_glIsProgram__wrapper,_emscripten_glIsFramebuffer__wrapper,_emscripten_glCheckFramebufferStatus__wrapper,_emscripten_glIsEnabled__wrapper,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114
  ,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114,b114];
  var FUNCTION_TABLE_iiff = [b115,__Z45UnityEngine_UnityEngine_Mathf_m_ApproximatelyP22mscorlib_System_Objectff];
  var FUNCTION_TABLE_viifi = [b116,__ZNK5physx14NpArticulation16updateDriveCacheERNS_24PxArticulationDriveCacheEfj,__ZN5physx2Cm29ConstraintImmediateVisualizer19visualizeDoubleConeERKNS_11PxTransformEfb,__Z132UnityEngine_UnityEngine_Vector3_m_op_Multiply_UnityEngine_UnityEngine_Vector3_mscorlib_System_Single_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Objectf31UnityEngine_UnityEngine_Vector3,__Z145UnityEngine_UnityEngine_Animation_m_CrossFade_mscorlib_System_Void_mscorlib_System_String_mscorlib_System_Single_UnityEngine_UnityEngine_PlayModeP33UnityEngine_UnityEngine_AnimationP22mscorlib_System_Stringfi,__ZN9Animation9CrossFadeERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEfi,__Z26Animation_CUSTOM_CrossFadeP15ScriptingObjectP15ScriptingStringfi,b116];
  var FUNCTION_TABLE_iiiiifiiiiii = [b117,__Z14raycast_sphereRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_,__Z13raycast_planeRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_,__Z15raycast_capsuleRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_,__Z11raycast_boxRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_,__Z18raycast_convexMeshRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_,__Z20raycast_triangleMeshRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_,__Z19raycast_heightFieldRKN5physx10PxGeometryERKNS_11PxTransformERKNS_6PxVec3ES8_fNS_7PxFlagsINS_9PxHitFlag4EnumEtEEjPNS_12PxRaycastHitEbPFbRSD_PvESG_];
  var FUNCTION_TABLE_iiiiifiiiiif = [b118,__ZNK5physx14NpSceneQueries5sweepERKNS_10PxGeometryERKNS_11PxTransformERKNS_6PxVec3EfRNS_13PxHitCallbackINS_10PxSweepHitEEENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPKNS_12PxQueryCacheEf];
  var FUNCTION_TABLE_viiff = [b119,__ZNK9Heightmap21GetInterpolatedNormalEff,__ZN18VirtActionInvoker2I28mscorlib_System_SingleTraitsS0_E6InvokeEP10MethodInfoPvff,b119];
  var FUNCTION_TABLE_viiiiiiiiiiii = [b120,__ZN13GfxDeviceGLES15UploadTexture2DE9TextureID16TextureDimensionPKhiii13TextureFormatij16TextureUsageMode17TextureColorSpace,__Z283mscorlib_System_Guid_m__ctor_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int16_mscorlib_System_Int16_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_Byte_mscorlib_System_ByteP20mscorlib_System_Guidisshhhhhhhh,b120];
  var FUNCTION_TABLE_iifi = [b121,__ZNK5physx14NpArticulation16createDriveCacheEfj,__ZN5physx5cloth8SwSolver8simulateEfRNS_10PxBaseTaskE,__ZThn4_N5physx5cloth8SwSolver8simulateEfRNS_10PxBaseTaskE,__Z126mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_Single_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectfS0_,__Z142mscorlib_System_NumberFormatter_m_FormatRoundtrip_mscorlib_System_String_mscorlib_System_Single_mscorlib_System_Globalization_NumberFormatInfoP31mscorlib_System_NumberFormatterfP46mscorlib_System_Globalization_NumberFormatInfo,b121,b121];
  var FUNCTION_TABLE_viiif = [b122,__ZN5physx15PxsParticleData19addDeltaVelocitiesVERKNS_2Cm10BitMapBaseINS_6shdfnd9AllocatorEEEPKNS_6PxVec3Ef,__Z132UnityEngine_UnityEngine_Vector3_m_op_Multiply_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3_mscorlib_System_SingleP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3f,__Z132UnityEngine_UnityEngine_Vector3_m_op_Division_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3_mscorlib_System_SingleP22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3f,__Z132UnityEngine_UnityEngine_Matrix4x4_m_set_Item_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_SingleP33UnityEngine_UnityEngine_Matrix4x4iif,__Z127UnityEngine_UnityEngine_Animator_m_Play_mscorlib_System_Void_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_SingleP32UnityEngine_UnityEngine_Animatoriif,__ZN5physx23SetMFrictionVsSlipGraphEPNS_17PxVehicleTireDataEjjf,__Z22GetTextureDecodeValues16TextureUsageMode17TextureColorSpacef,__Z34Vector3_CUSTOM_INTERNAL_CALL_SlerpRK8Vector3fS1_f,__Z20Animator_CUSTOM_PlayP15ScriptingObjectiif,b122,b122,b122,b122,b122,b122];
  var FUNCTION_TABLE_viiiiifiiii = [b123,__ZL20AddReplacementObjectRNSt3__16vectorI17RODataReplacement13stl_allocatorIS1_L18MemLabelIdentifier90ELi16EEEEPN5Unity8MaterialEP6ShaderiPK11VisibleNodefii18GlobalLayeringDatat];
  var FUNCTION_TABLE_viiiffii = [b124,__ZN5physx3Cct13BoxController4moveERKNS_6PxVec3EffRKNS_19PxControllerFiltersEPKNS_17PxObstacleContextE,__ZN5physx3Cct17CapsuleController4moveERKNS_6PxVec3EffRKNS_19PxControllerFiltersEPKNS_17PxObstacleContextE,b124];
  var FUNCTION_TABLE_vifiiiiiiiiiiiiiiiiiiiiiii = [b125,__ZNK5physx20PxsSolverCoreGeneral33solveVCoulombParallelAndWriteBackEfjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS8_jPiS9_S9_PNS_25PxcThresholdStreamElementEjS9_RNS_6shdfnd5ArrayINS_24PxsConstraintBatchHeaderENSC_19ReflectionAllocatorISE_EEEESI_PNS_2Cm13SpatialVectorERiSM_];
  var FUNCTION_TABLE_iifiiiii = [b126,__ZN5physx21PxcArticulationHelper30computeUnconstrainedVelocitiesERKNS_25PxcArticulationSolverDescEfRNS_24PxcConstraintBlockStreamEPNS_23PxcSolverConstraintDescERjRNS_2Cm13EventProfilerERNS_25PxsConstraintBlockManagerE];
  var FUNCTION_TABLE_iiifi = [b127,__Z149mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Single_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringfS0_,__Z43UnityEngine_UnityEngine_Camera_m_RaycastTryP30UnityEngine_UnityEngine_Camera27UnityEngine_UnityEngine_Rayfi,__Z45UnityEngine_UnityEngine_Camera_m_RaycastTry2DP30UnityEngine_UnityEngine_Camera27UnityEngine_UnityEngine_Rayfi,__Z38Camera_CUSTOM_INTERNAL_CALL_RaycastTryP15ScriptingObjectRK3Rayfi,__Z40Camera_CUSTOM_INTERNAL_CALL_RaycastTry2DP15ScriptingObjectRK3Rayfi,b127,b127];
  var FUNCTION_TABLE_iiii = [b128,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE6setbufEPci,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPci,__ZNSt3__115basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKci,__ZN5physx11PxHitBufferINS_12PxRaycastHitEE14processTouchesEPKS1_j,__ZN16ControllerFilter10postFilterERKN5physx12PxFilterDataERKNS0_10PxQueryHitE,__ZN5physx11PxHitBufferINS_12PxOverlapHitEE14processTouchesEPKS1_j,__ZN5physx3Cct15ObstacleContext14updateObstacleEjRKNS_10PxObstacleE,__ZN5physx11PxHitBufferINS_10PxSweepHitEE14processTouchesEPKS1_j,__ZN5physx14NpArticulation10createLinkEPNS_18PxArticulationLinkERKNS_11PxTransformE,__ZNK5physx14NpArticulation8getLinksEPPNS_18PxArticulationLinkEj,__ZNK5physx18NpArticulationLink11getChildrenEPPNS_18PxArticulationLinkEj,__ZN16PxOverflowBufferIN5physx10PxSweepHitEE14processTouchesEPKS1_j,__ZN16PxOverflowBufferIN5physx12PxOverlapHitEE14processTouchesEPKS1_j,__ZN16PxOverflowBufferIN5physx12PxRaycastHitEE14processTouchesEPKS1_j,__ZN5physx9NpPhysics15createAggregateEjb,__ZNK5physx9NpPhysics15getClothFabricsEPPNS_13PxClothFabricEj,__ZN5physx9NpPhysics20createParticleSystemEjb,__ZN5physx9NpPhysics19createParticleFluidEjb,__ZN5physx7NpScene19getActiveTransformsERjh,__ZN5physx7NpScene12fetchResultsEbPj,__ZN5physx7NpScene17createVolumeCacheEjj,__ZN5physx7NpScene19addBroadPhaseRegionERKNS_18PxBroadPhaseRegionEb,__ZNK5physx7NpShape12getMaterialsEPPNS_10PxMaterialEj,__ZN5physx13NpVolumeCache4fillERKNS_10PxGeometryERKNS_11PxTransformE,__ZN5physx13NpVolumeCache14getCacheVolumeERNS_16PxGeometryHolderERNS_11PxTransformE,__ZN5physx23NpVolumeCacheSqCallback14processTouchesEPKNS_12PxOverlapHitEj,__ZNK5physx13NpClothFabric9getPhasesEPNS_18PxClothFabricPhaseEj,__ZNK5physx13NpClothFabric7getSetsEPjj
  ,__ZNK5physx13NpClothFabric18getParticleIndicesEPjj,__ZNK5physx13NpClothFabric13getRestvaluesEPfj,__ZNK5physx13NpClothFabric16getTetherAnchorsEPjj,__ZNK5physx13NpClothFabric16getTetherLengthsEPfj,__ZN5physx5cloth9SwFactory11createClothENS0_5RangeIKNS_6PxVec4EEERNS0_6FabricE,__ZN5physx5cloth9SwFactory12createSolverEPNS_13PxProfileZoneEPNS_13PxTaskManagerE,__ZThn4_N5physx5cloth9SwFactory11createClothENS0_5RangeIKNS_6PxVec4EEERNS0_6FabricE,__ZThn4_N5physx5cloth9SwFactory12createSolverEPNS_13PxProfileZoneEPNS_13PxTaskManagerE,__ZN5physx16PxsBroadPhaseMBP9addRegionERKNS_18PxBroadPhaseRegionEb,__ZN5physx16PxBroadPhaseBase9addRegionERKNS_18PxBroadPhaseRegionEb,__ZN5physx29EntityReportContainerCallback7onEventEjPj,__ZNK5physx2Sq10AABBPruner7overlapERKNS0_9ShapeDataERNS0_14PrunerCallbackE,__ZNK5physx2Sq12BucketPruner7overlapERKNS0_9ShapeDataERNS0_14PrunerCallbackE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDriveNWEE12createObjectERPhRNS_24PxDeserializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleNoDriveEE12createObjectERPhRNS_24PxDeserializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_18PxVehicleDriveTankEE12createObjectERPhRNS_24PxDeserializationContextE,__ZNK5physx26PxSerializerDefaultAdapterINS_16PxVehicleDrive4WEE12createObjectERPhRNS_24PxDeserializationContextE,__ZN5physx7Cooking16cookTriangleMeshERKNS_18PxTriangleMeshDescERNS_14PxOutputStreamE,__ZN5physx7Cooking18createTriangleMeshERKNS_18PxTriangleMeshDescERNS_26PxPhysicsInsertionCallbackE,__ZN5physx7Cooking15cookHeightFieldERKNS_17PxHeightFieldDescERNS_14PxOutputStreamE,__ZN5physx7Cooking17createHeightFieldERKNS_17PxHeightFieldDescERNS_26PxPhysicsInsertionCallbackE,__ZNK5physx2Gu10ConvexMesh14getPolygonDataEjRNS_13PxHullPolygonE,__ZN5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19getEventIdsForNamesEPPKcj,__ZThn116_N5physx7profile8ZoneImplINS_28PxProfileNameProviderForwardEE19getEventIdsForNamesEPPKcj,__ZN5physx9PxTaskMgr17submitUnnamedTaskERNS_6PxTaskENS_10PxTaskType4EnumE,__ZZ27sweepCCTBox_HeightFieldGeomRKN5physx10PxGeometryERKNS_11PxTransformERKNS_2Gu3BoxERKNS_6PxVec3EfRNS_10PxSweepHitENS_7PxFlagsINS_9PxHitFlag4EnumEtEEfEN11LocalReport7onEventEjPj,__ZN24MidPhaseQueryLocalReport7onEventEjPj,__ZN43CapsuleHeightfieldContactGenerationCallback7onEventEjPj,__ZN44ConvexVsHeightfieldContactGenerationCallback7onEventEjPj,__ZN12_GLOBAL__N_142SphereHeightfieldContactGenerationCallback7onEventEjPj
  ,__ZN12_GLOBAL__N_124HfTrianglesEntityReport27onEventEjPj,__ZN16RayRTreeCallbackILi1ELb1EE14processResultsEjPj,__ZThn4_N16RayRTreeCallbackILi1ELb1EE14processResultsEjPj,__ZN16RayRTreeCallbackILi0ELb1EE14processResultsEjPj,__ZThn4_N16RayRTreeCallbackILi0ELb1EE14processResultsEjPj,__ZN16RayRTreeCallbackILi1ELb0EE14processResultsEjPj,__ZThn4_N16RayRTreeCallbackILi1ELb0EE14processResultsEjPj,__ZN16RayRTreeCallbackILi0ELb0EE14processResultsEjPj,__ZThn4_N16RayRTreeCallbackILi0ELb0EE14processResultsEjPj,__ZNK5physx2Gu11HeightField9saveCellsEPvj,__ZN21BoxTraceSegmentReport7onEventEjPj,__ZN24ConvexVsHeightfieldSweep7onEventEjPj,__ZN25CapsuleTraceSegmentReport7onEventEjPj,__ZN21UnityDefaultAllocatorI17LowLevelAllocatorE8AllocateEji,__ZN20DynamicHeapAllocatorI17LowLevelAllocatorE8AllocateEji,__ZN14StackAllocator8AllocateEji,__ZN12TLSAllocatorI14StackAllocatorE8AllocateEji,__ZN26RemapFunctorTempRemapTable18GenerateInstanceIDEi17TransferMetaFlags,__ZN9GfxDevice16CreateGpuProgramERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER22CreateGpuProgramOutput,__ZN9GfxDevice8SkinMeshER12SkinMeshInfoP12VertexBuffer,__ZN9GfxDevice12EndRecordingEPP14GfxDisplayListRKN9ShaderLab17ShaderPassContextE,__ZN9GfxDevice20CreateComputeProgramEPKhj,__ZNK9Texture2D12ExtractImageEP14ImageReferencei,__ZNK13RenderTexture12ExtractImageEP14ImageReferencei,__ZNK9Texture3D12ExtractImageEP14ImageReferencei,__ZN27GenericSlowGarbageCollector18GenerateInstanceIDEi17TransferMetaFlags,__ZN13MonoBehaviour5DoGUIENS_13GUILayoutTypeEi,__ZN9TextAsset9SetScriptERK8UnityStrb,__ZN25PathNamePersistentManager28InsertFileIdentifierInternalE14FileIdentifierb,__ZN25PathNamePersistentManager22InsertPathNameInternalERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEEb
  ,__ZN18IDCollectorFunctor18GenerateInstanceIDEi17TransferMetaFlags,__ZN16MemoryFileSystem6ParentERK13FileEntryDataRNSt3__112basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE,__ZN16MemoryFileSystem11HasFastHashERK13FileEntryDataR7Hash128,__ZN16MemoryFileSystem6DeleteER13FileEntryDatab,__ZNK16MemoryFileSystem6TargetERK13FileEntryDataR15FileSystemEntry,__ZN16MemoryFileSystem4LockER13FileEntryData12FileLockMode,__ZN16MemoryFileSystem4CopyER13FileEntryDataS1_,__ZN17FileSystemHandler10AtomicMoveER13FileEntryDataS1_,__ZN16MemoryFileSystem9MakeLocalER13FileEntryDatab,__ZN10MemoryFile9SetLengthEy,__ZN20LocalFileSystemPosix6ParentERK13FileEntryDataRNSt3__112basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE,__ZN17FileSystemHandler11HasFastHashERK13FileEntryDataR7Hash128,__ZN20LocalFileSystemPosix6DeleteER13FileEntryDatab,__ZNK20LocalFileSystemPosix6TargetERK13FileEntryDataR15FileSystemEntry,__ZN20LocalFileSystemPosix4LockER13FileEntryData12FileLockMode,__ZN20LocalFileSystemPosix4CopyER13FileEntryDataS1_,__ZN20LocalFileSystemPosix10AtomicMoveER13FileEntryDataS1_,__ZN22LocalFileSystemHandler9MakeLocalER13FileEntryDatab,__ZN23ControllerContactFilter10postFilterERKN5physx12PxFilterDataERKNS0_10PxQueryHitE,__ZN24ControllerFilterCallback6filterERKN5physx12PxControllerES3_,__ZN10CastFilter10postFilterERKN5physx12PxFilterDataERKNS0_10PxQueryHitE,__ZN12MemoryStream5writeEPKvj,__ZN12MemoryStream4readEPvj,__ZThn4_N12MemoryStream4readEPvj,__ZN15ContactFilter2D13ShouldCollideEP9b2FixtureS1_,__ZN7mecanim6memory16MecanimAllocator8AllocateEjj,__ZN7mecanim6memory16ChainedAllocator8AllocateEjj,__ZN7mecanim6memory16InPlaceAllocator8AllocateEjj,__ZNK25RuntimeAnimatorController21BuildCustomControllerERK13AnimationClipRN7mecanim6memory9AllocatorE,__ZN14ActionInvoker06InvokeEPFvPvES0_PS0_
  ,__ZN14ActionInvoker1I17VoidPointerTraitsE6InvokeEPFvPvS2_ES2_PS2_,__ZN12FuncInvoker1I17VoidPointerTraitsS0_E6InvokeEPFPvS2_S2_ES2_PS2_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS3_S3_S3_P22mscorlib_System_ObjectES3_PS3_,__ZN14ActionInvoker1I27mscorlib_System_Int32TraitsE6InvokeEPFvPviES2_PS2_,__ZN14ActionInvoker1I29mscorlib_System_BooleanTraitsE6InvokeEPFvPvbES2_PS2_,__ZN14ActionInvoker1I28mscorlib_System_SingleTraitsE6InvokeEPFvPvfES2_PS2_,__ZN14ActionInvoker2I17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS3_bES3_PS3_,__ZN12FuncInvoker0I29mscorlib_System_BooleanTraitsE6InvokeEPFbPvES2_PS2_,__ZN12FuncInvoker0I27mscorlib_System_Int32TraitsE6InvokeEPFiPvES2_PS2_,__ZN12FuncInvoker0I28mscorlib_System_SingleTraitsE6InvokeEPFfPvES2_PS2_,__ZN12FuncInvoker0I17VoidPointerTraitsE6InvokeEPFPvS2_ES2_PS2_,__ZN14ActionInvoker2I17VoidPointerTraits28mscorlib_System_SingleTraitsE6InvokeEPFvPvS3_fES3_PS3_,__ZN14ActionInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS3_iES3_PS3_,__ZN14ActionInvoker2I17VoidPointerTraitsS0_E6InvokeEPFvPvS2_S2_ES2_PS2_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S0_E6InvokeEPFbPvS3_S3_bES3_PS3_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_E6InvokeEPFbPvS3_S3_S3_ES3_PS3_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_28mscorlib_System_SingleTraitsE6InvokeEPFbPvS4_S4_fES4_PS4_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEPFbPvS4_S4_iES4_PS4_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_28mscorlib_System_UInt32TraitsE6InvokeEPFbPvS4_S4_jES4_PS4_,__ZN14ActionInvoker3I17VoidPointerTraitsS0_S0_E6InvokeEPFvPvS2_S2_S2_ES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits17VoidPointerTraitsE6InvokeEPFbPvS3_ES3_PS3_,__ZN12FuncInvoker1I17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEPFPvS3_bES3_PS3_,__Z107AssemblyU002DCSharp_JSONObject_m_print_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_BooleanP30AssemblyU002DCSharp_JSONObjectib,__ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_ibES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFPvS3_iES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPFvPviS3_ES3_PS3_,__ZN12FuncInvoker1I17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEPFPvS3_P22mscorlib_System_ObjectES3_PS3_,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector2Traits17VoidPointerTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector2PvS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits37UnityEngine_UnityEngine_Vector2TraitsE6InvokeEPFPvS3_31UnityEngine_UnityEngine_Vector2ES3_PS3_,__ZN12FuncInvoker1I17VoidPointerTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFPvS3_31UnityEngine_UnityEngine_Vector3ES3_PS3_
  ,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector3Traits17VoidPointerTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits37UnityEngine_UnityEngine_Vector4TraitsE6InvokeEPFPvS3_31UnityEngine_UnityEngine_Vector4ES3_PS3_,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector4Traits17VoidPointerTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector4PvS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits39UnityEngine_UnityEngine_Matrix4x4TraitsE6InvokeEPFPvS3_33UnityEngine_UnityEngine_Matrix4x4ES3_PS3_,__ZN12FuncInvoker1I39UnityEngine_UnityEngine_Matrix4x4Traits17VoidPointerTraitsE6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits40UnityEngine_UnityEngine_QuaternionTraitsE6InvokeEPFPvS3_34UnityEngine_UnityEngine_QuaternionES3_PS3_,__ZN12FuncInvoker1I40UnityEngine_UnityEngine_QuaternionTraits17VoidPointerTraitsE6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPFPvS3_29UnityEngine_UnityEngine_ColorES3_PS3_,__ZN12FuncInvoker1I35UnityEngine_UnityEngine_ColorTraits17VoidPointerTraitsE6InvokeEPF29UnityEngine_UnityEngine_ColorPvS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits39UnityEngine_UnityEngine_LayerMaskTraitsE6InvokeEPFPvS3_33UnityEngine_UnityEngine_LayerMaskES3_PS3_,__ZN12FuncInvoker1I39UnityEngine_UnityEngine_LayerMaskTraits17VoidPointerTraitsE6InvokeEPF33UnityEngine_UnityEngine_LayerMaskPvS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits34UnityEngine_UnityEngine_RectTraitsE6InvokeEPFPvS3_28UnityEngine_UnityEngine_RectES3_PS3_,__ZN12FuncInvoker1I34UnityEngine_UnityEngine_RectTraits17VoidPointerTraitsE6InvokeEPF28UnityEngine_UnityEngine_RectPvS4_ES4_PS4_,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector3TraitsS0_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS2_ES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits29mscorlib_System_BooleanTraitsE6InvokeEPFfPvbES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraitsS0_E6InvokeEPFfPvfES2_PS2_,__ZN12FuncInvoker0I37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFfPv31UnityEngine_UnityEngine_Vector3ES3_PS3_,__ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3TraitsS0_S0_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS2_S2_ES3_PS3_,__ZN14ActionInvoker1I37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFvPv31UnityEngine_UnityEngine_Vector3ES2_PS2_,__ZN12FuncInvoker3I37UnityEngine_UnityEngine_Vector3TraitsS0_S0_28mscorlib_System_SingleTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS3_S3_fES4_PS4_,__ZN14ActionInvoker2I17VoidPointerTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFvPvS3_31UnityEngine_UnityEngine_Vector3ES3_PS3_,__ZN12FuncInvoker2I28mscorlib_System_SingleTraitsS0_S0_E6InvokeEPFfPvffES2_PS2_,__ZN14ActionInvoker2I37UnityEngine_UnityEngine_Vector3TraitsS0_E6InvokeEPFvPv31UnityEngine_UnityEngine_Vector3S3_ES2_PS2_,__ZN12FuncInvoker0I28mscorlib_System_ObjectTraitsE6InvokeEPFP22mscorlib_System_ObjectPvES4_PS4_,__ZN12FuncInvoker0I26mscorlib_System_CharTraitsE6InvokeEPFtPvES2_PS2_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEPFiPvP22mscorlib_System_ObjectES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsE6InvokeEPFbPvP22mscorlib_System_ObjectES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEPFvPviP22mscorlib_System_ObjectES3_PS3_,__ZN14ActionInvoker1I28mscorlib_System_ObjectTraitsE6InvokeEPFvPvP22mscorlib_System_ObjectES2_PS2_
  ,__ZN12FuncInvoker1I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEPFP22mscorlib_System_ObjectPviES5_PS5_,__ZN12FuncInvoker0I82mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectTraitsE6InvokeEPF76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_ObjectPvES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32TraitsS0_E6InvokeEPFvPviiES2_PS2_,__ZL123mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Object_m_System_Collections_IEqualityComparer_EqualsP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFbPvP22mscorlib_System_ObjectS5_ES3_PS3_,__ZL102mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Object_m_EqualsP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_ObjectP22mscorlib_System_ObjectS2_,__ZN12FuncInvoker0I90mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPF84mscorlib_System_Collections_Generic_List_1_Enumerator_AssemblyU002DCSharp_JSONObjectPvES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPFiPvS3_ES3_PS3_,__ZL131mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObject_m_System_Collections_IEqualityComparer_EqualsP85mscorlib_System_Collections_Generic_EqualityComparer_1_AssemblyU002DCSharp_JSONObjectP22mscorlib_System_ObjectS2_,__ZL110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObject_m_EqualsP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_AssemblyU002DCSharp_JSONObjectP30AssemblyU002DCSharp_JSONObjectS2_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_E6InvokeEPFbPvS3_S3_ES3_PS3_,__ZN12FuncInvoker0I82mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_StringTraitsE6InvokeEPF76mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_StringPvES3_PS3_,__ZL123mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_String_m_System_Collections_IEqualityComparer_EqualsP77mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_StringP22mscorlib_System_ObjectS2_,__ZL102mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_String_m_EqualsP93mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_StringP22mscorlib_System_StringS2_,__ZN14ActionInvoker1I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPFvPv105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPFbPv105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringES3_PS3_,__ZN12FuncInvoker2I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraits17VoidPointerTraitsS1_E6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringPvS4_S4_ES4_PS4_,__ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_TryGetValueP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringPS2_,__ZN12FuncInvoker0I120mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPF114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringPvES3_PS3_,__ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_String_m_pick_valueP22mscorlib_System_ObjectP22mscorlib_System_StringS2_,__ZN12FuncInvoker2I17VoidPointerTraitsS0_S0_E6InvokeEPFPvS2_S2_S2_ES2_PS2_,__ZN14ActionInvoker2I17VoidPointerTraits60mscorlib_System_Runtime_Serialization_StreamingContextTraitsE6InvokeEPFvPvS3_54mscorlib_System_Runtime_Serialization_StreamingContextES3_PS3_,__ZN12FuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraitsS1_E6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvS4_S4_ES4_PS4_,__ZN14ActionInvoker1I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPFvPv105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectES2_PS2_,__ZN14ActionInvoker2I28mscorlib_System_ObjectTraitsS0_E6InvokeEPFvPvP22mscorlib_System_ObjectS4_ES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPFbPv105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectES3_PS3_,__ZN12FuncInvoker2I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvP22mscorlib_System_ObjectS6_ES4_PS4_,__ZL116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_pick_valueP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEPFP22mscorlib_System_ObjectPvS3_S3_ES4_PS4_,__ZL117mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_TryGetValueP103mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectPS2_
  ,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFbPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker0I120mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPF114mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvES3_PS3_,__ZN12FuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvP22mscorlib_System_ObjectS6_ES4_PS4_,__ZN12FuncInvoker0I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvES3_PS3_,__ZN12FuncInvoker0I46mscorlib_System_Collections_Generic_LinkTraitsE6InvokeEPF40mscorlib_System_Collections_Generic_LinkPvES3_PS3_,__ZN12FuncInvoker0I136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraitsE6InvokeEPF130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvES3_PS3_,__ZN12FuncInvoker0I49mscorlib_System_Collections_DictionaryEntryTraitsE6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvES3_PS3_,__ZL156mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_InvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_,__ZN12FuncInvoker4I17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_S0_S1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS5_S3_S5_ES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFP22mscorlib_System_ObjectPvS5_ES5_PS5_,__ZN12FuncInvoker1I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraitsE6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvS4_ES4_PS4_,__ZN12FuncInvoker1I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectPvS4_ES4_PS4_,__ZN12FuncInvoker0I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringPvES3_PS3_,__ZN12FuncInvoker0I136mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringTraitsE6InvokeEPF130mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_StringPvES3_PS3_,__ZL156mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_String_m_InvokeP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_StringU002CU0020mscorlib_System_StringP22mscorlib_System_StringS2_,__ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS3_S3_S3_S3_P22mscorlib_System_ObjectES3_PS3_,__ZN12FuncInvoker1I111mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringTraits17VoidPointerTraitsE6InvokeEPF105mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_StringPvS4_ES4_PS4_,__ZN14ActionInvoker1I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPFvPv113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPFbPv113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectES3_PS3_,__ZN12FuncInvoker2I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraits17VoidPointerTraitsS1_E6InvokeEPF113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvS4_S4_ES4_PS4_,__ZL125mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_TryGetValueP111mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringPP30AssemblyU002DCSharp_JSONObject,__ZN12FuncInvoker0I128mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPF122mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvES3_PS3_,__ZL124mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObject_m_pick_valueP22mscorlib_System_ObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__ZN12FuncInvoker0I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPF113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvES3_PS3_,__ZN12FuncInvoker0I144mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraitsE6InvokeEPF138mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvES3_PS3_,__ZL172mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObject_m_InvokeP163mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectU002CU0020AssemblyU002DCSharp_JSONObjectP22mscorlib_System_StringP30AssemblyU002DCSharp_JSONObject,__ZN12FuncInvoker1I119mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectTraits17VoidPointerTraitsE6InvokeEPF113mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020AssemblyU002DCSharp_JSONObjectPvS4_ES4_PS4_,__Z121mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Char_m_System_Collections_IEqualityComparer_EqualsP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_CharP22mscorlib_System_ObjectS2_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsE6InvokeEPFiPvtES3_PS3_,__Z100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Char_m_EqualsP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Chartt
  ,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS1_E6InvokeEPFbPvttES3_PS3_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS1_28mscorlib_System_ObjectTraitsE6InvokeEPFbPviiP22mscorlib_System_ObjectES4_PS4_,__ZN14ActionInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFvPvS3_iiES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int32TraitsS0_E6InvokeEPFiPviES2_PS2_,__ZN12FuncInvoker0I82System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectTraitsE6InvokeEPF76System_Core_System_Collections_Generic_HashSet_1_Link_mscorlib_System_ObjectPvES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsE6InvokeEPFbPviES3_PS3_,__ZN14ActionInvoker1I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPFvPv104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32ES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPFbPv104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32ES3_PS3_,__ZN12FuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPvS5_iES5_PS5_,__ZN12FuncInvoker2I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32Traits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPF104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvS5_iES5_PS5_,__Z115mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_pick_valueP22mscorlib_System_ObjectP22mscorlib_System_Stringi,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_E6InvokeEPFiPvS3_iES3_PS3_,__Z116mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32_m_TryGetValueP102mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32P22mscorlib_System_StringPi,__ZN12FuncInvoker0I119mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPF113mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvES3_PS3_,__ZN12FuncInvoker0I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPF104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvES3_PS3_,__ZN12FuncInvoker0I135mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32TraitsE6InvokeEPF129mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvES3_PS3_,__Z154mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32_m_InvokeP145mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020mscorlib_System_Int32U002CU0020mscorlib_System_Int32P22mscorlib_System_Stringi,__ZN12FuncInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_S4_iS4_P22mscorlib_System_ObjectES4_PS4_,__ZN12FuncInvoker1I110mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPF104mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020mscorlib_System_Int32PvS4_ES4_PS4_,__Z122mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32_m_System_Collections_IEqualityComparer_EqualsP76mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Int32P22mscorlib_System_ObjectS2_,__Z101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32_m_EqualsP92mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Int32ii,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFbPviiES3_PS3_,__ZN12FuncInvoker0I38UnityEngine_UnityEngine_KeyframeTraitsE6InvokeEPF32UnityEngine_UnityEngine_KeyframePvES3_PS3_,__ZL77Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_YieldP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_ObjectiP22mscorlib_System_Object,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEPFbPviP22mscorlib_System_ObjectES4_PS4_,__ZN12FuncInvoker0I26mscorlib_System_ByteTraitsE6InvokeEPFhPvES2_PS2_,__Z88mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTime_m_CompareP78mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTime24mscorlib_System_DateTimeS1_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits30mscorlib_System_DateTimeTraitsS1_E6InvokeEPFiPv24mscorlib_System_DateTimeS4_ES3_PS3_,__Z110mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTime_m_System_Collections_IComparer_CompareP71mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeP22mscorlib_System_ObjectS2_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFiPvP22mscorlib_System_ObjectS5_ES3_PS3_
  ,__Z97mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTime_m_CompareP87mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTime24mscorlib_System_DateTimeS1_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits30mscorlib_System_DateTimeTraitsE6InvokeEPFiPv24mscorlib_System_DateTimeES3_PS3_,__Z95mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime_m_EqualsP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTime24mscorlib_System_DateTimeS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_DateTimeTraitsS1_E6InvokeEPFbPv24mscorlib_System_DateTimeS4_ES3_PS3_,__Z125mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTime_m_System_Collections_IEqualityComparer_EqualsP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeP22mscorlib_System_ObjectS2_,__Z104mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime_m_EqualsP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTime24mscorlib_System_DateTimeS1_,__Z94mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTimeOffset_m_CompareP84mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffsetS1_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits36mscorlib_System_DateTimeOffsetTraitsS1_E6InvokeEPFiPv30mscorlib_System_DateTimeOffsetS4_ES3_PS3_,__Z116mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffset_m_System_Collections_IComparer_CompareP77mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_DateTimeOffsetP22mscorlib_System_ObjectS2_,__Z103mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m_CompareP93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffsetS1_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits36mscorlib_System_DateTimeOffsetTraitsE6InvokeEPFiPv30mscorlib_System_DateTimeOffsetES3_PS3_,__Z101mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset_m_EqualsP92mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffsetS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits36mscorlib_System_DateTimeOffsetTraitsS1_E6InvokeEPFbPv30mscorlib_System_DateTimeOffsetS4_ES3_PS3_,__Z131mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffset_m_System_Collections_IEqualityComparer_EqualsP85mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_DateTimeOffsetP22mscorlib_System_ObjectS2_,__Z110mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset_m_EqualsP101mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_DateTimeOffset30mscorlib_System_DateTimeOffsetS1_,__ZN14ActionInvoker1I30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPv24mscorlib_System_TimeSpanES2_PS2_,__ZN12FuncInvoker0I30mscorlib_System_TimeSpanTraitsE6InvokeEPF24mscorlib_System_TimeSpanPvES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits57mscorlib_System_Nullable_1_mscorlib_System_TimeSpanTraitsE6InvokeEPFbPv51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanES3_PS3_,__Z84mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_Guid_m_CompareP74mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_Guid20mscorlib_System_GuidS1_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_GuidTraitsS1_E6InvokeEPFiPv20mscorlib_System_GuidS4_ES3_PS3_,__Z106mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Guid_m_System_Collections_IComparer_CompareP67mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_GuidP22mscorlib_System_ObjectS2_,__Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Guid_m_CompareP83mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Guid20mscorlib_System_GuidS1_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_GuidTraitsE6InvokeEPFiPv20mscorlib_System_GuidES3_PS3_,__Z91mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid_m_EqualsP82mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_Guid20mscorlib_System_GuidS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_GuidTraitsS1_E6InvokeEPFbPv20mscorlib_System_GuidS4_ES3_PS3_,__Z121mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Guid_m_System_Collections_IEqualityComparer_EqualsP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_GuidP22mscorlib_System_ObjectS2_,__Z100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid_m_EqualsP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Guid20mscorlib_System_GuidS1_,__Z88mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_TimeSpan_m_CompareP78mscorlib_System_Collections_Generic_GenericComparer_1_mscorlib_System_TimeSpan24mscorlib_System_TimeSpanS1_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsS1_E6InvokeEPFiPv24mscorlib_System_TimeSpanS4_ES3_PS3_,__Z110mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpan_m_System_Collections_IComparer_CompareP71mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_TimeSpanP22mscorlib_System_ObjectS2_
  ,__Z97mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_TimeSpan_m_CompareP87mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_TimeSpan24mscorlib_System_TimeSpanS1_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsE6InvokeEPFiPv24mscorlib_System_TimeSpanES3_PS3_,__Z95mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan_m_EqualsP86mscorlib_System_Collections_Generic_GenericEqualityComparer_1_mscorlib_System_TimeSpan24mscorlib_System_TimeSpanS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsS1_E6InvokeEPFbPv24mscorlib_System_TimeSpanS4_ES3_PS3_,__Z125mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpan_m_System_Collections_IEqualityComparer_EqualsP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TimeSpanP22mscorlib_System_ObjectS2_,__Z104mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan_m_EqualsP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TimeSpan24mscorlib_System_TimeSpanS1_,__ZN12FuncInvoker0I79System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_TypeTraitsE6InvokeEPF73System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_TypePvES3_PS3_,__ZN12FuncInvoker0I81System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectTraitsE6InvokeEPF75System_System_Collections_Generic_Stack_1_Enumerator_mscorlib_System_ObjectPvES3_PS3_,__ZN12FuncInvoker0I80mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_TypeTraitsE6InvokeEPF74mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_TypePvES3_PS3_,__ZL121mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Type_m_System_Collections_IEqualityComparer_EqualsP75mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_TypeP22mscorlib_System_ObjectS2_,__ZL100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Type_m_EqualsP91mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_TypeP20mscorlib_System_TypeS2_,__ZN12FuncInvoker0I50mscorlib_System_Reflection_ParameterModifierTraitsE6InvokeEPF44mscorlib_System_Reflection_ParameterModifierPvES3_PS3_,__ZN12FuncInvoker0I53UnityEngine_UnityEngine_SendMouseEvents_HitInfoTraitsE6InvokeEPF47UnityEngine_UnityEngine_SendMouseEvents_HitInfoPvES3_PS3_,__ZN14ActionInvoker1I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPFvPv135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPFbPv135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpES3_PS3_,__ZN12FuncInvoker2I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPF135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvS5_iES5_PS5_,__Z146mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_pick_valueP22mscorlib_System_ObjectP29UnityEngine_UnityEngine_Eventi,__Z147mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_TryGetValueP133mscorlib_System_Collections_Generic_Dictionary_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_EventPi,__ZN12FuncInvoker0I150mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPF144mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvES3_PS3_,__ZN12FuncInvoker0I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPF135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvES3_PS3_,__ZN12FuncInvoker0I166mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraitsE6InvokeEPF160mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvES3_PS3_,__Z209mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOp_m_InvokeP200mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpP29UnityEngine_UnityEngine_Eventi,__ZN12FuncInvoker1I141mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpTraits17VoidPointerTraitsE6InvokeEPF135mscorlib_System_Collections_Generic_KeyValuePair_2_UnityEngine_UnityEngine_EventU002CU0020UnityEngine_UnityEngine_TextEditor_TextEditOpPvS4_ES4_PS4_,__ZL130mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Event_m_System_Collections_IEqualityComparer_EqualsP84mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_EventP22mscorlib_System_ObjectS2_,__ZL109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Event_m_EqualsP100mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_EventP29UnityEngine_UnityEngine_EventS2_,__Z146mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_System_Collections_IEqualityComparer_EqualsP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_TextEditor_TextEditOpP22mscorlib_System_ObjectS2_,__Z125mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOp_m_EqualsP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_TextEditor_TextEditOpii,__ZN12FuncInvoker0I38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPF32UnityEngine_UnityEngine_UIVertexPvES3_PS3_,__ZN14ActionInvoker1I38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPFvPv32UnityEngine_UnityEngine_UIVertexES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPFbPv32UnityEngine_UnityEngine_UIVertexES3_PS3_
  ,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPFiPv32UnityEngine_UnityEngine_UIVertexES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits38UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPFvPvi32UnityEngine_UnityEngine_UIVertexES3_PS3_,__ZN12FuncInvoker1I38UnityEngine_UnityEngine_UIVertexTraits27mscorlib_System_Int32TraitsE6InvokeEPF32UnityEngine_UnityEngine_UIVertexPviES4_PS4_,__ZN12FuncInvoker0I92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertexTraitsE6InvokeEPF86mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UIVertexPvES3_PS3_,__Z133mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertex_m_System_Collections_IEqualityComparer_EqualsP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UIVertexP22mscorlib_System_ObjectS2_,__Z112mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex_m_EqualsP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UIVertex32UnityEngine_UnityEngine_UIVertexS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits38UnityEngine_UnityEngine_UIVertexTraitsS1_E6InvokeEPFbPv32UnityEngine_UnityEngine_UIVertexS4_ES3_PS3_,__ZN12FuncInvoker0I40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPF34UnityEngine_UnityEngine_UICharInfoPvES3_PS3_,__ZN14ActionInvoker1I40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPFvPv34UnityEngine_UnityEngine_UICharInfoES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPFbPv34UnityEngine_UnityEngine_UICharInfoES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPFiPv34UnityEngine_UnityEngine_UICharInfoES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPFvPvi34UnityEngine_UnityEngine_UICharInfoES3_PS3_,__ZN12FuncInvoker1I40UnityEngine_UnityEngine_UICharInfoTraits27mscorlib_System_Int32TraitsE6InvokeEPF34UnityEngine_UnityEngine_UICharInfoPviES4_PS4_,__ZN12FuncInvoker0I94mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEPF88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UICharInfoPvES3_PS3_,__Z135mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfo_m_System_Collections_IEqualityComparer_EqualsP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UICharInfoP22mscorlib_System_ObjectS2_,__Z114mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo_m_EqualsP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UICharInfo34UnityEngine_UnityEngine_UICharInfoS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UICharInfoTraitsS1_E6InvokeEPFbPv34UnityEngine_UnityEngine_UICharInfoS4_ES3_PS3_,__ZN12FuncInvoker0I40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPF34UnityEngine_UnityEngine_UILineInfoPvES3_PS3_,__ZN14ActionInvoker1I40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPFvPv34UnityEngine_UnityEngine_UILineInfoES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPFbPv34UnityEngine_UnityEngine_UILineInfoES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPFiPv34UnityEngine_UnityEngine_UILineInfoES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPFvPvi34UnityEngine_UnityEngine_UILineInfoES3_PS3_,__ZN12FuncInvoker1I40UnityEngine_UnityEngine_UILineInfoTraits27mscorlib_System_Int32TraitsE6InvokeEPF34UnityEngine_UnityEngine_UILineInfoPviES4_PS4_,__ZN12FuncInvoker0I94mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEPF88mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_UILineInfoPvES3_PS3_,__Z135mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfo_m_System_Collections_IEqualityComparer_EqualsP89mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_UILineInfoP22mscorlib_System_ObjectS2_,__Z114mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo_m_EqualsP105mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_UILineInfo34UnityEngine_UnityEngine_UILineInfoS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UILineInfoTraitsS1_E6InvokeEPFbPv34UnityEngine_UnityEngine_UILineInfoS4_ES3_PS3_,__ZN12FuncInvoker0I105mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCallTraitsE6InvokeEPF99mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_PersistentCallPvES3_PS3_,__ZL146mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCall_m_System_Collections_IEqualityComparer_EqualsP100mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_PersistentCallP22mscorlib_System_ObjectS2_,__ZL125mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCall_m_EqualsP116mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_PersistentCallP45UnityEngine_UnityEngine_Events_PersistentCallS2_
  ,__ZN12FuncInvoker0I108mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCallTraitsE6InvokeEPF102mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_Events_BaseInvokableCallPvES3_PS3_,__ZL149mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_System_Collections_IEqualityComparer_EqualsP103mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_Events_BaseInvokableCallP22mscorlib_System_ObjectS2_,__ZL128mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCall_m_EqualsP119mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_Events_BaseInvokableCallP48UnityEngine_UnityEngine_Events_BaseInvokableCallS2_,__ZN14ActionInvoker1I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPFvPv134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPFbPv134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheES3_PS3_,__ZN12FuncInvoker2I49mscorlib_System_Collections_DictionaryEntryTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPF43mscorlib_System_Collections_DictionaryEntryPviS5_ES5_PS5_,__ZN12FuncInvoker2I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPF134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePviS5_ES5_PS5_,__Z145mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_pick_valueP22mscorlib_System_ObjectiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_E6InvokeEPFPvS3_iS3_ES3_PS3_,__Z146mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_TryGetValueP132mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiPP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEPFbPviS4_ES4_PS4_,__ZN12FuncInvoker0I149mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPF143mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePvES3_PS3_,__ZN12FuncInvoker0I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPF134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePvES3_PS3_,__ZN12FuncInvoker0I165mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraitsE6InvokeEPF159mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePvES3_PS3_,__Z215mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_InvokeP206mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheU002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheiP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache,__ZN12FuncInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_iS4_S4_P22mscorlib_System_ObjectES4_PS4_,__ZN12FuncInvoker1I140mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheTraits17VoidPointerTraitsE6InvokeEPF134mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_Int32U002CU0020UnityEngine_UnityEngine_GUILayoutUtility_LayoutCachePvS4_ES4_PS4_,__ZL153mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_System_Collections_IEqualityComparer_EqualsP107mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP22mscorlib_System_ObjectS2_,__ZL132mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCache_m_EqualsP123mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheP52UnityEngine_UnityEngine_GUILayoutUtility_LayoutCacheS2_,__ZN12FuncInvoker0I98mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntryTraitsE6InvokeEPF92mscorlib_System_Collections_Generic_List_1_Enumerator_UnityEngine_UnityEngine_GUILayoutEntryPvES3_PS3_,__ZL139mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntry_m_System_Collections_IEqualityComparer_EqualsP93mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUILayoutEntryP22mscorlib_System_ObjectS2_,__ZL118mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntry_m_EqualsP109mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUILayoutEntryP38UnityEngine_UnityEngine_GUILayoutEntryS2_,__ZN14ActionInvoker1I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPFvPv115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPFbPv115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleES3_PS3_,__ZN12FuncInvoker2I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraits17VoidPointerTraitsS1_E6InvokeEPF115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvS4_S4_ES4_PS4_,__ZL127mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_TryGetValueP113mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringPP32UnityEngine_UnityEngine_GUIStyle,__ZN12FuncInvoker0I130mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPF124mscorlib_System_Collections_Generic_Dictionary_2_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvES3_PS3_,__ZL126mscorlib_System_Collections_Generic_Dictionary_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyle_m_pick_valueP22mscorlib_System_ObjectP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__ZN12FuncInvoker0I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPF115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvES3_PS3_,__ZN12FuncInvoker0I146mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraitsE6InvokeEPF140mscorlib_System_Collections_Generic_Dictionary_2_ValueCollection_Enumerator_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvES3_PS3_
  ,__ZL176mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyle_m_InvokeP167mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleU002CU0020UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_StringP32UnityEngine_UnityEngine_GUIStyle,__ZN12FuncInvoker1I121mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStyleTraits17VoidPointerTraitsE6InvokeEPF115mscorlib_System_Collections_Generic_KeyValuePair_2_mscorlib_System_StringU002CU0020UnityEngine_UnityEngine_GUIStylePvS4_ES4_PS4_,__ZL133mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyle_m_System_Collections_IEqualityComparer_EqualsP87mscorlib_System_Collections_Generic_EqualityComparer_1_UnityEngine_UnityEngine_GUIStyleP22mscorlib_System_ObjectS2_,__ZL112mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyle_m_EqualsP103mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_UnityEngine_UnityEngine_GUIStyleP32UnityEngine_UnityEngine_GUIStyleS2_,__ZN12FuncInvoker0I84mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arrTraitsE6InvokeEPF78mscorlib_System_Collections_Generic_List_1_Enumerator_mscorlib_System_Byte_arrPvES3_PS3_,__ZL125mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arr_m_System_Collections_IEqualityComparer_EqualsP79mscorlib_System_Collections_Generic_EqualityComparer_1_mscorlib_System_Byte_arrP22mscorlib_System_ObjectS2_,__ZL104mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arr_m_EqualsP95mscorlib_System_Collections_Generic_EqualityComparer_1_DefaultComparer_mscorlib_System_Byte_arrP24mscorlib_System_Byte_arrS2_,__ZN12FuncInvoker0I28mscorlib_System_IntPtrTraitsE6InvokeEPF22mscorlib_System_IntPtrPvES3_PS3_,__ZN12FuncInvoker0I27mscorlib_System_Int64TraitsE6InvokeEPFxPvES2_PS2_,__ZN12FuncInvoker0I28mscorlib_System_UInt32TraitsE6InvokeEPFjPvES2_PS2_,__ZN12FuncInvoker0I28mscorlib_System_UInt64TraitsE6InvokeEPFyPvES2_PS2_,__ZN12FuncInvoker0I27mscorlib_System_SByteTraitsE6InvokeEPFaPvES2_PS2_,__ZN12FuncInvoker0I27mscorlib_System_Int16TraitsE6InvokeEPFsPvES2_PS2_,__ZN12FuncInvoker0I28mscorlib_System_UInt16TraitsE6InvokeEPFtPvES2_PS2_,__ZN12FuncInvoker0I28mscorlib_System_DoubleTraitsE6InvokeEPFdPvES2_PS2_,__ZN12FuncInvoker0I29mscorlib_System_UIntPtrTraitsE6InvokeEPF23mscorlib_System_UIntPtrPvES3_PS3_,__Z108mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32_m_System_Collections_IComparer_CompareP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt32P22mscorlib_System_ObjectS2_,__Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt32_m_CompareP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt32jj,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsS1_E6InvokeEPFiPvjjES3_PS3_,__Z108mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16_m_System_Collections_IComparer_CompareP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt16P22mscorlib_System_ObjectS2_,__Z95mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt16_m_CompareP85mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_UInt16tt,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsS1_E6InvokeEPFiPvttES3_PS3_,__Z106mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_Byte_m_System_Collections_IComparer_CompareP67mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_ByteP22mscorlib_System_ObjectS2_,__Z93mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Byte_m_CompareP83mscorlib_System_Collections_Generic_Comparer_1_DefaultComparer_mscorlib_System_Bytehh,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsS1_E6InvokeEPFiPvhhES3_PS3_,__Z108mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64_m_System_Collections_IComparer_CompareP69mscorlib_System_Collections_Generic_Comparer_1_mscorlib_System_UInt64P22mscorlib_System_ObjectS2_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsS1_E6InvokeEPFiPvyyES3_PS3_,__ZN12FuncInvoker0I69mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangeTraitsE6InvokeEPF63mscorlib_Mono_Globalization_Unicode_CodePointIndexer_TableRangePvES3_PS3_,__ZN12FuncInvoker0I48mscorlib_System_Collections_Hashtable_SlotTraitsE6InvokeEPF42mscorlib_System_Collections_Hashtable_SlotPvES3_PS3_,__Z124mscorlib_U003CModuleU003E_m_UnsupportedMember_String_mscorlib_System_String_mscorlib_System_Exception_mscorlib_System_StringP22mscorlib_System_ObjectP25mscorlib_System_ExceptionP22mscorlib_System_String
  ,__Z139mscorlib_U003CModuleU003E_m_UnsupportedMember_String_mscorlib_System_String_mscorlib_System_Security_SecurityElement_mscorlib_System_StringP22mscorlib_System_ObjectP40mscorlib_System_Security_SecurityElementP22mscorlib_System_String,__Z138mscorlib_U003CModuleU003E_m_UnsupportedMember_String_mscorlib_System_String_mscorlib_System_Reflection_AssemblyName_mscorlib_System_StringP22mscorlib_System_ObjectP39mscorlib_System_Reflection_AssemblyNameP22mscorlib_System_String,__ZN12FuncInvoker4I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_S1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S5_S5_S5_ES5_PS5_,__Z60mscorlib_U003CModuleU003E_m_UnsupportedMember_ByteU005BU005DP22mscorlib_System_ObjectP36mscorlib_System_Security_Policy_HashP22mscorlib_System_String,__Z101mscorlib_System_Object_m_Equals_mscorlib_System_Boolean_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_S0_,__Z40mscorlib_System_Object_m_ReferenceEqualsP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsS1_17VoidPointerTraitsE6InvokeEPFbPvP22mscorlib_System_ObjectS6_S4_ES4_PS4_,__Z41mscorlib_System_ValueType_m_DefaultEqualsP22mscorlib_System_ObjectS0_S0_,__Z47mscorlib_System_ValueType_m_InternalGetHashCodeP22mscorlib_System_ObjectS0_PP26mscorlib_System_Object_arr,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFiPvP22mscorlib_System_ObjectS4_ES4_PS4_,__Z131mscorlib_System_Attribute_m_GetCustomAttribute_mscorlib_System_Attribute_mscorlib_System_Reflection_MemberInfo_mscorlib_System_TypeP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoP20mscorlib_System_Type,__ZN12FuncInvoker3I17VoidPointerTraitsS0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS3_S3_S3_bES3_PS3_,__Z123mscorlib_System_Attribute_m_IsDefined_mscorlib_System_Boolean_mscorlib_System_Reflection_ParameterInfo_mscorlib_System_TypeP22mscorlib_System_ObjectP40mscorlib_System_Reflection_ParameterInfoP20mscorlib_System_Type,__Z120mscorlib_System_Attribute_m_IsDefined_mscorlib_System_Boolean_mscorlib_System_Reflection_MemberInfo_mscorlib_System_TypeP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoP20mscorlib_System_Type,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits17VoidPointerTraitsE6InvokeEPFhPvS3_ES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_CharTraits17VoidPointerTraitsE6InvokeEPFtPvS3_ES3_PS3_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits17VoidPointerTraitsE6InvokeEPF24mscorlib_System_DateTimePvS4_ES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits17VoidPointerTraitsE6InvokeEPF23mscorlib_System_DecimalPvS4_ES4_PS4_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits17VoidPointerTraitsE6InvokeEPFdPvS3_ES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits17VoidPointerTraitsE6InvokeEPFsPvS3_ES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits17VoidPointerTraitsE6InvokeEPFxPvS3_ES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits17VoidPointerTraitsE6InvokeEPFaPvS3_ES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits17VoidPointerTraitsE6InvokeEPFfPvS3_ES3_PS3_,__Z50mscorlib_System_Int32_m_System_IConvertible_ToTypePiP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S5_ES5_PS5_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits17VoidPointerTraitsE6InvokeEPFtPvS3_ES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits17VoidPointerTraitsE6InvokeEPFjPvS3_ES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits17VoidPointerTraitsE6InvokeEPFyPvS3_ES3_PS3_,__ZN12FuncInvoker4I29mscorlib_System_BooleanTraitsS0_17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFbPvbS4_iS4_ES4_PS4_,__ZN12FuncInvoker4I29mscorlib_System_BooleanTraits17VoidPointerTraitsS0_S1_S1_E6InvokeEPFbPvS3_bS3_S3_ES3_PS3_
  ,__Z106mscorlib_System_Int32_m_Parse_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_E6InvokeEPFiPvS3_S3_ES3_PS3_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS0_17VoidPointerTraitsE6InvokeEPFbPvibS4_ES4_PS4_,__ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S0_S0_S1_E6InvokeEPFbPvS3_S3_bbS3_ES3_PS3_,__ZN14ActionInvoker5I17VoidPointerTraitsS0_S0_S0_S0_E6InvokeEPFvPvS2_S2_S2_S2_S2_ES2_PS2_,__ZN14ActionInvoker4I17VoidPointerTraitsS0_S0_S0_E6InvokeEPFvPvS2_S2_S2_S2_ES2_PS2_,__ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_S0_S1_E6InvokeEPFbPvS3_S3_S3_bS3_ES3_PS3_,__Z34mscorlib_System_Int32_m_ValidDigitP22mscorlib_System_Objecttb,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS0_E6InvokeEPFbPvtbES3_PS3_,__ZN12FuncInvoker6I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_S1_E6InvokeEPFbPvS4_iS4_bS4_S4_ES4_PS4_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_E6InvokeEPFiPvS3_iS3_ES3_PS3_,__Z110mscorlib_System_Int32_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPiP22mscorlib_System_StringP22mscorlib_System_Object,__Z50mscorlib_System_Int64_m_System_IConvertible_ToTypePxP20mscorlib_System_TypeP22mscorlib_System_Object,__Z77mscorlib_System_Int64_m_CompareTo_mscorlib_System_Int32_mscorlib_System_Int64Pxx,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits27mscorlib_System_Int64TraitsE6InvokeEPFiPvxES3_PS3_,__Z76mscorlib_System_Int64_m_Equals_mscorlib_System_Boolean_mscorlib_System_Int64Pxx,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_Int64TraitsE6InvokeEPFbPvxES3_PS3_,__Z106mscorlib_System_Int64_m_Parse_mscorlib_System_Int64_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I27mscorlib_System_Int64Traits17VoidPointerTraitsS1_E6InvokeEPFxPvS3_S3_ES3_PS3_,__ZN12FuncInvoker3I27mscorlib_System_Int64Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFxPvS4_iS4_ES4_PS4_,__Z110mscorlib_System_Int64_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPxP22mscorlib_System_StringP22mscorlib_System_Object,__Z51mscorlib_System_UInt32_m_System_IConvertible_ToTypePjP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsE6InvokeEPFiPvjES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_UInt32TraitsE6InvokeEPFbPvjES3_PS3_,__ZN12FuncInvoker3I28mscorlib_System_UInt32Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFjPvS4_iS4_ES4_PS4_,__Z108mscorlib_System_UInt32_m_Parse_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I28mscorlib_System_UInt32Traits17VoidPointerTraitsS1_E6InvokeEPFjPvS3_S3_ES3_PS3_,__Z111mscorlib_System_UInt32_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPjP22mscorlib_System_StringP22mscorlib_System_Object,__Z51mscorlib_System_UInt64_m_System_IConvertible_ToTypePyP20mscorlib_System_TypeP22mscorlib_System_Object,__Z79mscorlib_System_UInt64_m_CompareTo_mscorlib_System_Int32_mscorlib_System_UInt64Pyy
  ,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt64TraitsE6InvokeEPFiPvyES3_PS3_,__Z78mscorlib_System_UInt64_m_Equals_mscorlib_System_Boolean_mscorlib_System_UInt64Pyy,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_UInt64TraitsE6InvokeEPFbPvyES3_PS3_,__Z108mscorlib_System_UInt64_m_Parse_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I28mscorlib_System_UInt64Traits17VoidPointerTraitsS1_E6InvokeEPFyPvS3_S3_ES3_PS3_,__ZN12FuncInvoker3I28mscorlib_System_UInt64Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFyPvS4_iS4_ES4_PS4_,__Z111mscorlib_System_UInt64_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPyP22mscorlib_System_StringP22mscorlib_System_Object,__Z49mscorlib_System_Byte_m_System_IConvertible_ToTypePhP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsE6InvokeEPFiPvhES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits26mscorlib_System_ByteTraitsE6InvokeEPFbPvhES3_PS3_,__Z104mscorlib_System_Byte_m_Parse_mscorlib_System_Byte_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I26mscorlib_System_ByteTraits17VoidPointerTraitsS1_E6InvokeEPFhPvS3_S3_ES3_PS3_,__ZN12FuncInvoker3I26mscorlib_System_ByteTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFhPvS4_iS4_ES4_PS4_,__Z109mscorlib_System_Byte_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPhP22mscorlib_System_StringP22mscorlib_System_Object,__Z50mscorlib_System_SByte_m_System_IConvertible_ToTypePaP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits27mscorlib_System_SByteTraitsE6InvokeEPFiPvaES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_SByteTraitsE6InvokeEPFbPvaES3_PS3_,__Z106mscorlib_System_SByte_m_Parse_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I27mscorlib_System_SByteTraits17VoidPointerTraitsS1_E6InvokeEPFaPvS3_S3_ES3_PS3_,__ZN12FuncInvoker3I27mscorlib_System_SByteTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFaPvS4_iS4_ES4_PS4_,__Z110mscorlib_System_SByte_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPaP22mscorlib_System_StringP22mscorlib_System_Object,__Z50mscorlib_System_Int16_m_System_IConvertible_ToTypePsP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits27mscorlib_System_Int16TraitsE6InvokeEPFiPvsES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_Int16TraitsE6InvokeEPFbPvsES3_PS3_,__Z106mscorlib_System_Int16_m_Parse_mscorlib_System_Int16_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I27mscorlib_System_Int16Traits17VoidPointerTraitsS1_E6InvokeEPFsPvS3_S3_ES3_PS3_,__ZN12FuncInvoker3I27mscorlib_System_Int16Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFsPvS4_iS4_ES4_PS4_,__Z110mscorlib_System_Int16_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPsP22mscorlib_System_StringP22mscorlib_System_Object,__Z51mscorlib_System_UInt16_m_System_IConvertible_ToTypePtP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsE6InvokeEPFiPvtES3_PS3_
  ,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_UInt16TraitsE6InvokeEPFbPvtES3_PS3_,__Z108mscorlib_System_UInt16_m_Parse_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I28mscorlib_System_UInt16Traits17VoidPointerTraitsS1_E6InvokeEPFtPvS3_S3_ES3_PS3_,__ZN12FuncInvoker3I28mscorlib_System_UInt16Traits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFtPvS4_iS4_ES4_PS4_,__Z111mscorlib_System_UInt16_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPtP22mscorlib_System_StringP22mscorlib_System_Object,__Z49mscorlib_System_Char_m_System_IConvertible_ToTypePtP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN14ActionInvoker7I17VoidPointerTraitsS0_S0_S0_S0_S0_S0_E6InvokeEPFvPvS2_S2_S2_S2_S2_S2_S2_ES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsE6InvokeEPFbPvtES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_CharTraitsS0_E6InvokeEPFtPvtES2_PS2_,__Z30mscorlib_System_Char_m_ToLowerP22mscorlib_System_ObjecttP41mscorlib_System_Globalization_CultureInfo,__ZN12FuncInvoker2I26mscorlib_System_CharTraitsS0_17VoidPointerTraitsE6InvokeEPFtPvtS3_ES3_PS3_,__ZN14ActionInvoker2I26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvtiES3_PS3_,__Z51mscorlib_System_String_m_System_IConvertible_ToTypeP22mscorlib_System_StringP20mscorlib_System_TypeP22mscorlib_System_Object,__Z101mscorlib_System_String_m_Equals_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_,__ZN12FuncInvoker1I26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEPFtPviES3_PS3_,__Z109mscorlib_System_String_m_ToCharArray_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Stringii,__ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFPvS3_iiES3_PS3_,__Z112mscorlib_System_String_m_Split_mscorlib_System_String_arr_arr_mscorlib_System_Char_arr_arr_mscorlib_System_Int32P22mscorlib_System_StringP24mscorlib_System_Char_arri,__ZN12FuncInvoker2I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEPFPvS3_S3_iES3_PS3_,__Z101mscorlib_System_String_m_Substring_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Stringii,__Z43mscorlib_System_String_m_SubstringUncheckedP22mscorlib_System_Stringii,__ZN12FuncInvoker3I27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEPFiPviiiES2_PS2_,__ZN12FuncInvoker4I27mscorlib_System_Int32TraitsS0_S0_S0_17VoidPointerTraitsE6InvokeEPFiPviiiS3_ES3_PS3_,__Z100mscorlib_System_String_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_S4_bES4_PS4_,__ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS4_S4_bS4_ES4_PS4_,__ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_S0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS4_iS4_iibS4_ES4_PS4_,__ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_S0_E6InvokeEPFiPvS3_iS3_iiES3_PS3_,__ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_E6InvokeEPFiPvS3_iiS3_iiES3_PS3_,__Z108mscorlib_System_String_m_IndexOfAny_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32P22mscorlib_System_StringP24mscorlib_System_Char_arri
  ,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_E6InvokeEPFiPvS3_iiES3_PS3_,__Z97mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Char_mscorlib_System_Int32P22mscorlib_System_Stringti,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsS0_E6InvokeEPFiPvtiES3_PS3_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsS0_S0_E6InvokeEPFiPvtiiES3_PS3_,__Z99mscorlib_System_String_m_IndexOf_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32P22mscorlib_System_StringS0_i,__Z33mscorlib_System_String_m_PadRightP22mscorlib_System_Stringit,__ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsE6InvokeEPFPvS4_itES4_PS4_,__Z97mscorlib_System_String_m_Replace_mscorlib_System_String_mscorlib_System_Char_mscorlib_System_CharP22mscorlib_System_Stringtt,__ZN12FuncInvoker2I17VoidPointerTraits26mscorlib_System_CharTraitsS1_E6InvokeEPFPvS3_ttES3_PS3_,__Z101mscorlib_System_String_m_Replace_mscorlib_System_String_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_StringS0_S0_,__Z41mscorlib_System_String_m_ReplaceUncheckedP22mscorlib_System_StringS0_S0_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_S0_27mscorlib_System_Int32TraitsE6InvokeEPFPvS3_S3_S3_iES3_PS3_,__Z31mscorlib_System_String_m_RemoveP22mscorlib_System_Stringii,__Z100mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_String_mscorlib_System_ObjectP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS1_E6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectS5_ES3_PS3_,__ZN12FuncInvoker4I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS1_S1_E6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectS5_S5_ES3_PS3_,__Z108mscorlib_System_String_m_Format_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr,__ZN12FuncInvoker3I17VoidPointerTraitsS0_S0_S0_E6InvokeEPFPvS2_S2_S2_S2_ES2_PS2_,__ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_S0_S0_E6InvokeEPFPvS2_S2_S2_S2_S2_ES2_PS2_,__Z100mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_Object_mscorlib_System_ObjectP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS5_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_S1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS5_S5_ES3_PS3_,__Z100mscorlib_System_String_m_Concat_mscorlib_System_String_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_,__Z39mscorlib_System_String_m_ConcatInternalP22mscorlib_System_ObjectP26mscorlib_System_String_arri,__Z31mscorlib_System_String_m_InsertP22mscorlib_System_StringiS0_,__ZN14ActionInvoker6I17VoidPointerTraitsS0_S0_S0_S0_S0_E6InvokeEPFvPvS2_S2_S2_S2_S2_S2_ES2_PS2_,__Z37mscorlib_System_String_m_ParseDecimalP22mscorlib_System_ObjectP22mscorlib_System_StringPi,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsE6InvokeEPFvPvitES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_E6InvokeEPFPvS3_S3_iiES3_PS3_
  ,__ZN12FuncInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_S0_E6InvokeEPFPvS3_S3_iiS3_ES3_PS3_,__Z103mscorlib_System_String_m_CreateString_mscorlib_System_String_mscorlib_System_Char_mscorlib_System_Int32P22mscorlib_System_Stringti,__ZN12FuncInvoker2I17VoidPointerTraits26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEPFPvS4_tiES4_PS4_,__ZN14ActionInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvS3_S3_iES3_PS3_,__ZN14ActionInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_S1_E6InvokeEPFvPvS3_iS3_iiES3_PS3_,__Z106mscorlib_System_String_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_,__Z108mscorlib_System_String_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_StringP22mscorlib_System_ObjectP22mscorlib_System_StringS2_,__Z51mscorlib_System_Single_m_System_IConvertible_ToTypePfP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsE6InvokeEPFiPvfES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_SingleTraitsE6InvokeEPFbPvfES3_PS3_,__ZN12FuncInvoker2I28mscorlib_System_SingleTraits17VoidPointerTraitsS1_E6InvokeEPFfPvS3_S3_ES3_PS3_,__Z111mscorlib_System_Single_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPfP22mscorlib_System_StringP22mscorlib_System_Object,__Z51mscorlib_System_Double_m_System_IConvertible_ToTypePdP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_DoubleTraitsE6InvokeEPFiPvdES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_DoubleTraitsE6InvokeEPFbPvdES3_PS3_,__ZN12FuncInvoker2I28mscorlib_System_DoubleTraits17VoidPointerTraitsS1_E6InvokeEPFdPvS3_S3_ES3_PS3_,__ZN12FuncInvoker3I28mscorlib_System_DoubleTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFdPvS4_iS4_ES4_PS4_,__ZN12FuncInvoker4I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_E6InvokeEPFbPvS4_S4_iiES4_PS4_,__Z34mscorlib_System_Double_m_ParseImplP22mscorlib_System_ObjectPhPd,__Z111mscorlib_System_Double_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderPdP22mscorlib_System_StringP22mscorlib_System_Object,__ZN14ActionInvoker5I27mscorlib_System_Int32TraitsS0_S0_29mscorlib_System_BooleanTraits26mscorlib_System_ByteTraitsE6InvokeEPFvPviiibhES4_PS4_,__ZN14ActionInvoker1I28mscorlib_System_UInt32TraitsE6InvokeEPFvPvjES2_PS2_,__ZN14ActionInvoker1I27mscorlib_System_Int64TraitsE6InvokeEPFvPvxES2_PS2_,__ZN14ActionInvoker1I28mscorlib_System_UInt64TraitsE6InvokeEPFvPvyES2_PS2_,__ZN14ActionInvoker1I28mscorlib_System_DoubleTraitsE6InvokeEPFvPvdES2_PS2_,__Z52mscorlib_System_Decimal_m_System_IConvertible_ToTypeP23mscorlib_System_DecimalP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I17VoidPointerTraits29mscorlib_System_DecimalTraitsE6InvokeEPFPvS3_23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker2I29mscorlib_System_DecimalTraitsS0_S0_E6InvokeEPF23mscorlib_System_DecimalPvS2_S2_ES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits29mscorlib_System_DecimalTraitsE6InvokeEPFyPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits29mscorlib_System_DecimalTraitsE6InvokeEPFxPv23mscorlib_System_DecimalES3_PS3_
  ,__Z104mscorlib_System_Decimal_m_Equals_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits29mscorlib_System_DecimalTraitsS1_E6InvokeEPFbPv23mscorlib_System_DecimalS4_ES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraitsS0_E6InvokeEPF23mscorlib_System_DecimalPvS2_ES3_PS3_,__Z33mscorlib_System_Decimal_m_CompareP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits29mscorlib_System_DecimalTraitsS1_E6InvokeEPFiPv23mscorlib_System_DecimalS4_ES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits29mscorlib_System_DecimalTraitsE6InvokeEPFiPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits29mscorlib_System_DecimalTraitsE6InvokeEPFbPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker2I29mscorlib_System_DecimalTraits17VoidPointerTraitsS1_E6InvokeEPF23mscorlib_System_DecimalPvS4_S4_ES4_PS4_,__ZN12FuncInvoker8I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_S0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_S4_iS4_S4_S4_S4_S4_bES4_PS4_,__ZN12FuncInvoker3I29mscorlib_System_DecimalTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPF23mscorlib_System_DecimalPvS5_iS5_ES5_PS5_,__ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S1_S0_E6InvokeEPFbPvS4_iS4_S4_bES4_PS4_,__Z112mscorlib_System_Decimal_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP23mscorlib_System_DecimalP22mscorlib_System_StringP22mscorlib_System_Object,__Z40mscorlib_System_Decimal_m_decimal2UInt64P22mscorlib_System_ObjectP23mscorlib_System_DecimalPy,__Z39mscorlib_System_Decimal_m_decimal2Int64P22mscorlib_System_ObjectP23mscorlib_System_DecimalPx,__Z37mscorlib_System_Decimal_m_decimalIncrP22mscorlib_System_ObjectP23mscorlib_System_DecimalS2_,__ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_28mscorlib_System_UInt32TraitsS0_E6InvokeEPFiPvS4_S4_jiES4_PS4_,__Z44mscorlib_System_Decimal_m_decimalSetExponentP22mscorlib_System_ObjectP23mscorlib_System_Decimali,__Z37mscorlib_System_Decimal_m_decimalMultP22mscorlib_System_ObjectP23mscorlib_System_DecimalS2_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S1_E6InvokeEPFiPvS3_S3_S3_ES3_PS3_,__Z40mscorlib_System_Decimal_m_decimalCompareP22mscorlib_System_ObjectP23mscorlib_System_DecimalS2_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits29mscorlib_System_DecimalTraitsE6InvokeEPFhPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits29mscorlib_System_DecimalTraitsE6InvokeEPFaPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits29mscorlib_System_DecimalTraitsE6InvokeEPFsPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits29mscorlib_System_DecimalTraitsE6InvokeEPFtPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits29mscorlib_System_DecimalTraitsE6InvokeEPFjPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits26mscorlib_System_ByteTraitsE6InvokeEPF23mscorlib_System_DecimalPvhES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits27mscorlib_System_SByteTraitsE6InvokeEPF23mscorlib_System_DecimalPvaES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits27mscorlib_System_Int16TraitsE6InvokeEPF23mscorlib_System_DecimalPvsES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_UInt16TraitsE6InvokeEPF23mscorlib_System_DecimalPvtES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits27mscorlib_System_Int32TraitsE6InvokeEPF23mscorlib_System_DecimalPviES4_PS4_
  ,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_UInt32TraitsE6InvokeEPF23mscorlib_System_DecimalPvjES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits27mscorlib_System_Int64TraitsE6InvokeEPF23mscorlib_System_DecimalPvxES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_UInt64TraitsE6InvokeEPF23mscorlib_System_DecimalPvyES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_SingleTraitsE6InvokeEPF23mscorlib_System_DecimalPvfES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits28mscorlib_System_DoubleTraitsE6InvokeEPF23mscorlib_System_DecimalPvdES4_PS4_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits29mscorlib_System_DecimalTraitsE6InvokeEPFfPv23mscorlib_System_DecimalES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits29mscorlib_System_DecimalTraitsE6InvokeEPFdPv23mscorlib_System_DecimalES3_PS3_,__Z111mscorlib_System_Decimal_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z109mscorlib_System_Decimal_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z112mscorlib_System_Decimal_m_op_GreaterThan_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z109mscorlib_System_Decimal_m_op_LessThan_mscorlib_System_Boolean_mscorlib_System_Decimal_mscorlib_System_DecimalP22mscorlib_System_Object23mscorlib_System_DecimalS1_,__Z52mscorlib_System_Boolean_m_System_IConvertible_ToTypePbP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFiPvbES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraitsS0_E6InvokeEPFbPvbES2_PS2_,__Z106mscorlib_System_IntPtr_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_IntPtr_mscorlib_System_IntPtrP22mscorlib_System_Object22mscorlib_System_IntPtrS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_IntPtrTraitsS1_E6InvokeEPFbPv22mscorlib_System_IntPtrS4_ES3_PS3_,__Z108mscorlib_System_IntPtr_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_IntPtr_mscorlib_System_IntPtrP22mscorlib_System_Object22mscorlib_System_IntPtrS1_,__ZN12FuncInvoker1I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32TraitsE6InvokeEPF22mscorlib_System_IntPtrPviES4_PS4_,__ZN12FuncInvoker1I28mscorlib_System_IntPtrTraits17VoidPointerTraitsE6InvokeEPF22mscorlib_System_IntPtrPvS4_ES4_PS4_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_IntPtrTraitsE6InvokeEPFiPv22mscorlib_System_IntPtrES3_PS3_,__ZN12FuncInvoker1I17VoidPointerTraits28mscorlib_System_IntPtrTraitsE6InvokeEPFPvS3_22mscorlib_System_IntPtrES3_PS3_,__Z109mscorlib_System_UIntPtr_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_UIntPtr_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtrS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits29mscorlib_System_UIntPtrTraitsS1_E6InvokeEPFbPv23mscorlib_System_UIntPtrS4_ES3_PS3_,__Z111mscorlib_System_UIntPtr_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_UIntPtr_mscorlib_System_UIntPtrP22mscorlib_System_Object23mscorlib_System_UIntPtrS1_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits29mscorlib_System_UIntPtrTraitsE6InvokeEPFyPv23mscorlib_System_UIntPtrES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits29mscorlib_System_UIntPtrTraitsE6InvokeEPFjPv23mscorlib_System_UIntPtrES3_PS3_,__Z84mscorlib_System_UIntPtr_m_op_Explicit_mscorlib_System_UIntPtr_mscorlib_System_UInt64P22mscorlib_System_Objecty,__ZN12FuncInvoker1I29mscorlib_System_UIntPtrTraits28mscorlib_System_UInt64TraitsE6InvokeEPF23mscorlib_System_UIntPtrPvyES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_UIntPtrTraits17VoidPointerTraitsE6InvokeEPF23mscorlib_System_UIntPtrPvS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits29mscorlib_System_UIntPtrTraitsE6InvokeEPFPvS3_23mscorlib_System_UIntPtrES3_PS3_
  ,__ZN12FuncInvoker1I29mscorlib_System_UIntPtrTraits28mscorlib_System_UInt32TraitsE6InvokeEPF23mscorlib_System_UIntPtrPvjES4_PS4_,__Z34mscorlib_System_Delegate_m_CombineP22mscorlib_System_ObjectP24mscorlib_System_DelegateS2_,__Z33mscorlib_System_Delegate_m_RemoveP22mscorlib_System_ObjectP24mscorlib_System_DelegateS2_,__Z49mscorlib_System_Enum_m_System_IConvertible_ToTypeP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_,__Z35mscorlib_System_Enum_m_FindPositionP22mscorlib_System_ObjectS0_P21mscorlib_System_Array,__Z30mscorlib_System_Enum_m_GetNameP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_,__Z109mscorlib_System_Enum_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z31mscorlib_System_Enum_m_ToObjectP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_,__ZN12FuncInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraitsS0_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S4_ES5_PS5_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraits29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_S4_P22mscorlib_System_ObjectbES4_PS4_,__Z34mscorlib_System_Enum_m_FormatFlagsP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS0_E6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectS3_ES3_PS3_,__ZN12FuncInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_iiS4_P22mscorlib_System_ObjectES4_PS4_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits27mscorlib_System_Int32TraitsE6InvokeEPFxPviES3_PS3_,__ZN14ActionInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFvPvP22mscorlib_System_ObjectS3_ES3_PS3_,__ZN14ActionInvoker2I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvP22mscorlib_System_ObjectiES3_PS3_,__ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S2_S2_E6InvokeEPFbPvS4_iS4_iiES4_PS4_,__Z99mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int32_mscorlib_System_Int32P21mscorlib_System_Arrayii,__ZN12FuncInvoker2I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFP22mscorlib_System_ObjectPviiES5_PS5_,__ZN12FuncInvoker3I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFP22mscorlib_System_ObjectPviiiES5_PS5_,__Z77mscorlib_System_Array_m_GetValue_mscorlib_System_Object_mscorlib_System_Int64P21mscorlib_System_Arrayx,__ZN12FuncInvoker1I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsE6InvokeEPFP22mscorlib_System_ObjectPvxES5_PS5_,__ZN12FuncInvoker2I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsS1_E6InvokeEPFP22mscorlib_System_ObjectPvxxES5_PS5_,__ZN12FuncInvoker3I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsS1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvxxxES5_PS5_,__ZN14ActionInvoker2I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsE6InvokeEPFvPvP22mscorlib_System_ObjectxES3_PS3_,__ZN14ActionInvoker3I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsS1_E6InvokeEPFvPvP22mscorlib_System_ObjectxxES3_PS3_,__ZN14ActionInvoker4I28mscorlib_System_ObjectTraits27mscorlib_System_Int64TraitsS1_S1_E6InvokeEPFvPvP22mscorlib_System_ObjectxxxES3_PS3_,__ZN14ActionInvoker3I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFvPvP22mscorlib_System_ObjectiiES3_PS3_,__ZN14ActionInvoker4I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFvPvP22mscorlib_System_ObjectiiiES3_PS3_,__Z103mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32P22mscorlib_System_ObjectP20mscorlib_System_Typei
  ,__ZN12FuncInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFPvS3_S3_iiiES3_PS3_,__Z111mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int32_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP25mscorlib_System_Int32_arr,__Z111mscorlib_System_Array_m_CreateInstance_mscorlib_System_Array_mscorlib_System_Type_mscorlib_System_Int64_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP25mscorlib_System_Int64_arr,__Z103mscorlib_System_Array_m_BinarySearch_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEPFiPvS4_P22mscorlib_System_ObjectES4_PS4_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFiPvS4_P22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_28mscorlib_System_ObjectTraitsE6InvokeEPFiPvS4_iiP22mscorlib_System_ObjectES4_PS4_,__ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_28mscorlib_System_ObjectTraitsS1_E6InvokeEPFiPvS4_iiP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN14ActionInvoker5I17VoidPointerTraits27mscorlib_System_Int64TraitsS0_S1_S1_E6InvokeEPFvPvS3_xS3_xxES3_PS3_,__ZN14ActionInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int64TraitsE6InvokeEPFvPvS3_S3_xES3_PS3_,__Z98mscorlib_System_Array_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_E6InvokeEPFiPvS4_P22mscorlib_System_ObjectiES4_PS4_,__ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEPFiPvS4_P22mscorlib_System_ObjectiiES4_PS4_,__Z102mscorlib_System_Array_m_LastIndexOf_mscorlib_System_Int32_mscorlib_System_Array_mscorlib_System_ObjectP22mscorlib_System_ObjectP21mscorlib_System_ArrayS0_,__ZN14ActionInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_E6InvokeEPFvPvS3_S3_iiES3_PS3_,__ZN14ActionInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_E6InvokeEPFvPvS3_iiS3_ES3_PS3_,__ZN14ActionInvoker5I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_S0_E6InvokeEPFvPvS3_S3_iiS3_ES3_PS3_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS1_17VoidPointerTraitsE6InvokeEPFiPvP22mscorlib_System_ObjectS6_S4_ES4_PS4_,__ZN14ActionInvoker2I17VoidPointerTraits27mscorlib_System_Int64TraitsE6InvokeEPFvPvS3_xES3_PS3_,__Z43mscorlib_System_Type_m_FilterAttribute_implP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoS0_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEPFbPvS4_P22mscorlib_System_ObjectES4_PS4_,__Z38mscorlib_System_Type_m_FilterName_implP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoS0_,__Z48mscorlib_System_Type_m_FilterNameIgnoreCase_implP22mscorlib_System_ObjectP37mscorlib_System_Reflection_MemberInfoS0_,__ZN12FuncInvoker0I39mscorlib_System_RuntimeTypeHandleTraitsE6InvokeEPF33mscorlib_System_RuntimeTypeHandlePvES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFPvS3_S3_bbES3_PS3_,__ZN12FuncInvoker1I17VoidPointerTraits39mscorlib_System_RuntimeTypeHandleTraitsE6InvokeEPFPvS3_33mscorlib_System_RuntimeTypeHandleES3_PS3_,__ZN12FuncInvoker1I39mscorlib_System_RuntimeTypeHandleTraits28mscorlib_System_ObjectTraitsE6InvokeEPF33mscorlib_System_RuntimeTypeHandlePvP22mscorlib_System_ObjectES4_PS4_,__Z46mscorlib_System_Type_m_type_is_assignable_fromP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_,__Z133mscorlib_System_Type_m_GetMethod_mscorlib_System_Reflection_MethodInfo_mscorlib_System_String_mscorlib_System_Reflection_BindingFlagsP20mscorlib_System_TypeP22mscorlib_System_Stringi,__ZN12FuncInvoker5I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEPFPvS3_S3_iS3_S3_S3_ES3_PS3_
  ,__ZN12FuncInvoker6I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S1_S0_S0_E6InvokeEPFPvS3_S3_iS3_iS3_S3_ES3_PS3_,__Z118mscorlib_System_Type_m_GetProperty_mscorlib_System_Reflection_PropertyInfo_mscorlib_System_String_mscorlib_System_TypeP20mscorlib_System_TypeP22mscorlib_System_StringS0_,__ZN12FuncInvoker6I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEPFPvS3_S3_iS3_S3_S3_S3_ES3_PS3_,__ZN12FuncInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEPFPvS3_iS3_S3_S3_ES3_PS3_,__ZN12FuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_S0_S0_E6InvokeEPFPvS3_iS3_iS3_S3_ES3_PS3_,__Z109mscorlib_System_Type_m_MakeGenericType_mscorlib_System_Type_mscorlib_System_Type_mscorlib_System_Type_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP24mscorlib_System_Type_arr,__ZN14ActionInvoker5I26mscorlib_System_ByteTraitsS0_28mscorlib_System_UInt32TraitsS1_S1_E6InvokeEPFvPvhhjjjES3_PS3_,__ZN14ActionInvoker2I17VoidPointerTraits28mscorlib_System_IntPtrTraitsE6InvokeEPFvPvS3_22mscorlib_System_IntPtrES3_PS3_,__ZN14ActionInvoker2I17VoidPointerTraits40mscorlib_System_RuntimeFieldHandleTraitsE6InvokeEPFvPvS3_34mscorlib_System_RuntimeFieldHandleES3_PS3_,__Z102mscorlib_Locale_m_GetText_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr,__ZN14ActionInvoker3I27mscorlib_System_Int32TraitsS0_S0_E6InvokeEPFvPviiiES2_PS2_,__ZN14ActionInvoker4I27mscorlib_System_Int32TraitsS0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFvPviiibES3_PS3_,__Z65mscorlib_Mono_Globalization_Unicode_ContractionComparer_m_CompareP55mscorlib_Mono_Globalization_Unicode_ContractionComparerP22mscorlib_System_ObjectS2_,__ZN14ActionInvoker2I26mscorlib_System_ByteTraitsS0_E6InvokeEPFvPvhhES2_PS2_,__Z63mscorlib_Mono_Globalization_Unicode_Level2MapComparer_m_CompareP53mscorlib_Mono_Globalization_Unicode_Level2MapComparerP22mscorlib_System_ObjectS2_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits27mscorlib_System_Int32TraitsE6InvokeEPFhPviES3_PS3_,__Z70mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_IsIgnorableP22mscorlib_System_Objectih,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsE6InvokeEPFbPvihES4_PS4_,__Z76mscorlib_Mono_Globalization_Unicode_MSCompatUnicodeTable_m_UInt32FromBytePtrP22mscorlib_System_ObjectPhj,__ZN12FuncInvoker2I28mscorlib_System_UInt32Traits17VoidPointerTraitsS0_E6InvokeEPFjPvS3_jES3_PS3_,__ZN14ActionInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S1_S1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFvPviS4_S4_S4_S4_S4_bES4_PS4_,__Z59mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_Level2P50mscorlib_Mono_Globalization_Unicode_SimpleCollatorii,__ZN12FuncInvoker2I26mscorlib_System_ByteTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFhPviiES3_PS3_,__Z63mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsHalfKanaP22mscorlib_System_Objectii,__Z66mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_FilterOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorii,__ZN12FuncInvoker2I27mscorlib_System_Int32TraitsS0_S0_E6InvokeEPFiPviiES2_PS2_,__Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_ToDashTypeValueP22mscorlib_System_Objectii,__Z64mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_IsIgnorableP22mscorlib_System_Objectii,__Z169mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_GetSortKey_mscorlib_System_Globalization_SortKey_mscorlib_System_String_mscorlib_System_Globalization_CompareOptionsP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_Stringi,__ZN14ActionInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_E6InvokeEPFvPvS3_iiS3_iES3_PS3_
  ,__ZN14ActionInvoker4I27mscorlib_System_Int32TraitsS0_17VoidPointerTraitsS0_E6InvokeEPFvPviiS3_iES3_PS3_,__ZN12FuncInvoker9I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_S1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iiS4_iiS4_S4_bES4_PS4_,__ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_S0_E6InvokeEPFiPvS3_iiS3_iiiES3_PS3_,__ZN12FuncInvoker6I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS2_S1_S2_S2_E6InvokeEPFbPvS4_iiS4_iiES4_PS4_,__ZN13FuncInvoker11I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S0_S1_S1_29mscorlib_System_BooleanTraitsS2_S1_E6InvokeEPFiPvS4_iiS4_iiS4_S4_bbS4_ES4_PS4_,__Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareFlagPairP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorbb,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvbbES3_PS3_,__ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S2_E6InvokeEPFbPvS4_S4_iiiES4_PS4_,__ZN12FuncInvoker6I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S0_S1_E6InvokeEPFbPvS4_S4_iibS4_ES4_PS4_,__ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S1_E6InvokeEPFiPvS3_S3_iiS3_ES3_PS3_,__ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S0_E6InvokeEPFiPvS3_S3_iiiES3_PS3_,__ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_E6InvokeEPFiPvS3_S3_iiES3_PS3_,__ZN12FuncInvoker8I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_26mscorlib_System_CharTraitsS0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS5_iiS5_tibS5_ES5_PS5_,__ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S1_S1_E6InvokeEPFiPvS3_S3_iiS3_S3_ES3_PS3_,__ZN12FuncInvoker8I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S0_S1_S0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS4_iiiS4_ibS4_ES4_PS4_,__ZN12FuncInvoker7I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S1_S0_S1_E6InvokeEPFbPvS4_S4_iiS4_bS4_ES4_PS4_,__ZN12FuncInvoker9I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S1_S0_S2_S1_S1_E6InvokeEPFbPvS4_S4_iiS4_biS4_S4_ES4_PS4_,__ZN12FuncInvoker7I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S1_S2_S1_S0_E6InvokeEPFbPviS4_iiS4_ibES4_PS4_,__ZN12FuncInvoker8I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S2_S1_S0_S1_E6InvokeEPFbPvS4_S4_iiiS4_bS4_ES4_PS4_,__ZN13FuncInvoker10I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS2_S2_S1_S0_S2_S1_S1_E6InvokeEPFbPvS4_S4_iiiS4_biS4_S4_ES4_PS4_,__ZN14ActionInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_E6InvokeEPFvPviS3_iES3_PS3_,__ZN15ActionInvoker12I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_S0_S0_S0_S0_S0_S0_S0_S0_E6InvokeEPFvPviS3_S3_iiiiiiiiiES3_PS3_,__Z47mscorlib_System_Globalization_SortKey_m_CompareP22mscorlib_System_ObjectP37mscorlib_System_Globalization_SortKeyS2_,__ZN14ActionInvoker4I27mscorlib_System_Int32TraitsS0_17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEPFvPviiS4_bES4_PS4_,__ZN14ActionInvoker8I26mscorlib_System_ByteTraitsS0_S0_S0_29mscorlib_System_BooleanTraitsS0_S1_S1_E6InvokeEPFvPvhhhhbhbbES3_PS3_,__ZN14ActionInvoker4I26mscorlib_System_ByteTraitsS0_S0_S0_E6InvokeEPFvPvhhhhES2_PS2_,__ZN14ActionInvoker3I26mscorlib_System_ByteTraits17VoidPointerTraitsS1_E6InvokeEPFvPvhS3_S3_ES3_PS3_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_26mscorlib_System_ByteTraitsE6InvokeEPFiPvS4_ihES4_PS4_,__Z65mscorlib_Mono_Security_Cryptography_CryptoConvert_m_ToCapiKeyBlobP22mscorlib_System_ObjectP41mscorlib_System_Security_Cryptography_RSAb,__ZN12FuncInvoker2I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS3_S3_bES3_PS3_
  ,__Z47mscorlib_Mono_Security_BitConverterLE_m_ToInt16P22mscorlib_System_ObjectP24mscorlib_System_Byte_arri,__ZN12FuncInvoker2I27mscorlib_System_Int16Traits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFsPvS4_iES4_PS4_,__Z47mscorlib_Mono_Security_BitConverterLE_m_ToInt32P22mscorlib_System_ObjectP24mscorlib_System_Byte_arri,__Z131mscorlib_System_Collections_ArrayList_ArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32P54mscorlib_System_Collections_ArrayList_ArrayListWrapperP22mscorlib_System_Objecti,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS0_E6InvokeEPFiPvP22mscorlib_System_ObjectiES3_PS3_,__Z114mscorlib_System_Collections_ArrayList_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32P37mscorlib_System_Collections_ArrayListP22mscorlib_System_Objecti,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsS0_S0_E6InvokeEPFiPvP22mscorlib_System_ObjectiiES3_PS3_,__ZN14ActionInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_E6InvokeEPFvPviS3_iiES3_PS3_,__Z143mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapper_m_IndexOf_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Int32P66mscorlib_System_Collections_ArrayList_SynchronizedArrayListWrapperP22mscorlib_System_Objecti,__ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_E6InvokeEPFvPvS3_P22mscorlib_System_ObjectS3_ES3_PS3_,__Z61mscorlib_System_Collections_CaseInsensitiveComparer_m_CompareP51mscorlib_System_Collections_CaseInsensitiveComparerP22mscorlib_System_ObjectS2_,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_S0_E6InvokeEPFiPvS3_S3_iES3_PS3_,__Z46mscorlib_System_Collections_Comparer_m_CompareP36mscorlib_System_Collections_ComparerP22mscorlib_System_ObjectS2_,__Z178mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m_AreEqual_mscorlib_System_Boolean_mscorlib_System_Globalization_CultureInfo_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_ObjectP41mscorlib_System_Globalization_CultureInfoS2_,__Z175mscorlib_System_Collections_CaseInsensitiveHashCodeProvider_m_AreEqual_mscorlib_System_Boolean_mscorlib_System_Globalization_TextInfo_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_ObjectP38mscorlib_System_Globalization_TextInfoP41mscorlib_System_Globalization_CultureInfo,__Z119mscorlib_System_Globalization_CompareInfo_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_StringP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringS2_,__ZN14ActionInvoker4I27mscorlib_System_Int32Traits28mscorlib_System_SingleTraits17VoidPointerTraitsS2_E6InvokeEPFvPvifS4_S4_ES4_PS4_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsE6InvokeEPFvPvifES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_ObjectTraitsS0_E6InvokeEPFP22mscorlib_System_ObjectPvS3_ES4_PS4_,__Z49mscorlib_System_Collections_Hashtable_m_KeyEqualsP37mscorlib_System_Collections_HashtableP22mscorlib_System_ObjectS2_,__ZN14ActionInvoker3I28mscorlib_System_ObjectTraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEPFvPvP22mscorlib_System_ObjectS5_bES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvibES3_PS3_,__ZN12FuncInvoker8I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsS0_17VoidPointerTraitsS2_S2_S2_S2_S2_E6InvokeEPFbPvibS4_S4_S4_S4_S4_S4_ES4_PS4_,__ZN14ActionInvoker3I17VoidPointerTraits27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS4_ibES4_PS4_,__ZN14ActionInvoker4I17VoidPointerTraits27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsS2_E6InvokeEPFvPvS4_ibbES4_PS4_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_S4_ibES4_PS4_,__Z42mscorlib_System_Globalization_CCMath_m_divP22mscorlib_System_Objectii,__Z42mscorlib_System_Globalization_CCMath_m_modP22mscorlib_System_Objectii,__ZN14ActionInvoker4I17VoidPointerTraitsS0_S0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvS3_S3_S3_iES3_PS3_,__ZN14ActionInvoker3I28mscorlib_System_ObjectTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvP22mscorlib_System_ObjectS4_iES4_PS4_
  ,__ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iiS4_ibES4_PS4_,__Z54mscorlib_System_Globalization_CompareInfo_m_GetSortKeyP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_Stringi,__ZN14ActionInvoker3I27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsS1_E6InvokeEPFvPvibbES3_PS3_,__ZN12FuncInvoker1I17VoidPointerTraits26mscorlib_System_CharTraitsE6InvokeEPFPvS3_tES3_PS3_,__Z71mscorlib_System_Globalization_DateTimeFormatInfo_m_PopulateCombinedListP48mscorlib_System_Globalization_DateTimeFormatInfoP26mscorlib_System_String_arrS2_,__ZN14ActionInvoker3I30mscorlib_System_DateTimeTraitsS0_30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPv24mscorlib_System_DateTimeS4_24mscorlib_System_TimeSpanES3_PS3_,__ZN12FuncInvoker0I30mscorlib_System_DateTimeTraitsE6InvokeEPF24mscorlib_System_DateTimePvES3_PS3_,__ZN14ActionInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS4_iS4_bES4_PS4_,__ZN12FuncInvoker5I28mscorlib_System_ObjectTraitsS0_27mscorlib_System_Int32Traits17VoidPointerTraitsS2_S2_E6InvokeEPFP22mscorlib_System_ObjectPvS5_iS6_S6_S6_ES6_PS6_,__ZN12FuncInvoker4I28mscorlib_System_ObjectTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS2_S2_E6InvokeEPFP22mscorlib_System_ObjectPviS6_S6_S6_ES6_PS6_,__ZN12FuncInvoker0I41mscorlib_System_RuntimeMethodHandleTraitsE6InvokeEPF35mscorlib_System_RuntimeMethodHandlePvES3_PS3_,__Z62mscorlib_System_Reflection_Emit_ConstructorBuilder_m_IsDefinedP50mscorlib_System_Reflection_Emit_ConstructorBuilderP20mscorlib_System_Typeb,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraitsS0_E6InvokeEPFbPvS3_bES3_PS3_,__Z148mscorlib_System_Reflection_Emit_ConstructorBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP50mscorlib_System_Reflection_Emit_ConstructorBuilderP20mscorlib_System_Typeb,__Z141mscorlib_System_Reflection_Emit_EnumBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP43mscorlib_System_Reflection_Emit_EnumBuilderP20mscorlib_System_Typeb,__Z141mscorlib_System_Reflection_Emit_TypeBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Typeb,__Z54mscorlib_System_Reflection_Emit_EnumBuilder_m_GetFieldP43mscorlib_System_Reflection_Emit_EnumBuilderP22mscorlib_System_Stringi,__Z54mscorlib_System_Reflection_Emit_TypeBuilder_m_GetFieldP43mscorlib_System_Reflection_Emit_TypeBuilderP22mscorlib_System_Stringi,__ZN12FuncInvoker8I28mscorlib_System_ObjectTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_S1_S1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvS6_iS6_S5_S6_S6_S6_S6_ES6_PS6_,__Z55mscorlib_System_Reflection_Emit_EnumBuilder_m_IsDefinedP43mscorlib_System_Reflection_Emit_EnumBuilderP20mscorlib_System_Typeb,__Z55mscorlib_System_Reflection_Emit_TypeBuilder_m_IsDefinedP43mscorlib_System_Reflection_Emit_TypeBuilderP20mscorlib_System_Typeb,__Z142mscorlib_System_Reflection_Emit_FieldBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP44mscorlib_System_Reflection_Emit_FieldBuilderP20mscorlib_System_Typeb,__Z56mscorlib_System_Reflection_Emit_FieldBuilder_m_IsDefinedP44mscorlib_System_Reflection_Emit_FieldBuilderP20mscorlib_System_Typeb,__ZN14ActionInvoker5I28mscorlib_System_ObjectTraitsS0_27mscorlib_System_Int32Traits17VoidPointerTraitsS2_E6InvokeEPFvPvP22mscorlib_System_ObjectS6_iS4_S4_ES4_PS4_,__Z70mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetFieldP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP22mscorlib_System_Stringi,__Z71mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_IsDefinedP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP20mscorlib_System_Typeb,__Z157mscorlib_System_Reflection_Emit_GenericTypeParameterBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP59mscorlib_System_Reflection_Emit_GenericTypeParameterBuilderP20mscorlib_System_Typeb,__Z57mscorlib_System_Reflection_Emit_MethodBuilder_m_IsDefinedP45mscorlib_System_Reflection_Emit_MethodBuilderP20mscorlib_System_Typeb,__Z143mscorlib_System_Reflection_Emit_MethodBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP45mscorlib_System_Reflection_Emit_MethodBuilderP20mscorlib_System_Typeb,__Z145mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP47mscorlib_System_Reflection_Emit_PropertyBuilderP20mscorlib_System_Typeb
  ,__Z135mscorlib_System_Reflection_Emit_PropertyBuilder_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP47mscorlib_System_Reflection_Emit_PropertyBuilderP22mscorlib_System_ObjectP26mscorlib_System_Object_arr,__ZN12FuncInvoker2I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsE6InvokeEPFP22mscorlib_System_ObjectPvS4_S5_ES5_PS5_,__Z59mscorlib_System_Reflection_Emit_PropertyBuilder_m_IsDefinedP47mscorlib_System_Reflection_Emit_PropertyBuilderP20mscorlib_System_Typeb,__ZN12FuncInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsS0_E6InvokeEPFPvS4_S4_ibS4_ES4_PS4_,__Z47mscorlib_System_Reflection_Assembly_m_IsDefinedP35mscorlib_System_Reflection_AssemblyP20mscorlib_System_Typeb,__Z57mscorlib_System_Reflection_Assembly_m_GetCustomAttributesP35mscorlib_System_Reflection_AssemblyP20mscorlib_System_Typeb,__ZN12FuncInvoker3I28mscorlib_System_IntPtrTraits17VoidPointerTraitsS1_S1_E6InvokeEPF22mscorlib_System_IntPtrPvS4_S4_S4_ES4_PS4_,__ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFPvS3_S3_S3_bbES3_PS3_,__ZN12FuncInvoker7I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_S0_S0_S0_E6InvokeEPFPvS3_iS3_S3_S3_S3_S3_S3_ES3_PS3_,__Z61mscorlib_System_Reflection_Binder_Default_m_IsArrayAssignableP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_,__ZN12FuncInvoker3I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsS1_E6InvokeEPFP22mscorlib_System_ObjectPvS4_S5_S5_ES5_PS5_,__ZN14ActionInvoker2I17VoidPointerTraits28mscorlib_System_ObjectTraitsE6InvokeEPFvPvS3_P22mscorlib_System_ObjectES3_PS3_,__Z54mscorlib_System_Reflection_Binder_Default_m_check_typeP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_,__ZN12FuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_iS4_S4_S4_bES4_PS4_,__Z61mscorlib_System_Reflection_Binder_Default_m_CompareCloserTypeP41mscorlib_System_Reflection_Binder_DefaultP20mscorlib_System_TypeS2_,__ZN12FuncInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEPFPvS3_iS3_S3_S3_S3_ES3_PS3_,__Z70mscorlib_System_Reflection_Binder_Default_m_check_arguments_with_scoreP22mscorlib_System_ObjectP24mscorlib_System_Type_arrP44mscorlib_System_Reflection_ParameterInfo_arr,__Z65mscorlib_System_Reflection_Binder_Default_m_check_type_with_scoreP22mscorlib_System_ObjectP20mscorlib_System_TypeS2_,__ZN12FuncInvoker4I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_S1_E6InvokeEPFbPvS3_S3_S3_S3_ES3_PS3_,__Z64mscorlib_System_Reflection_FieldInfo_m_internal_from_handle_typeP22mscorlib_System_Object22mscorlib_System_IntPtrS1_,__ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_IntPtrTraitsS1_E6InvokeEPFPvS3_22mscorlib_System_IntPtrS4_ES3_PS3_,__ZN12FuncInvoker1I17VoidPointerTraits40mscorlib_System_RuntimeFieldHandleTraitsE6InvokeEPFPvS3_34mscorlib_System_RuntimeFieldHandleES3_PS3_,__ZN14ActionInvoker5I17VoidPointerTraitsS0_S0_S0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvS3_S3_S3_S3_iES3_PS3_,__ZN14ActionInvoker6I17VoidPointerTraitsS0_S0_S0_27mscorlib_System_Int32TraitsS0_E6InvokeEPFvPvS3_S3_S3_S3_iS3_ES3_PS3_,__ZN12FuncInvoker1I17VoidPointerTraits41mscorlib_System_RuntimeMethodHandleTraitsE6InvokeEPFPvS3_35mscorlib_System_RuntimeMethodHandleES3_PS3_,__Z59mscorlib_System_Reflection_MethodBase_m_GetMethodFromIntPtrP22mscorlib_System_Object22mscorlib_System_IntPtrS1_,__Z71mscorlib_System_Reflection_MethodBase_m_GetMethodFromHandleInternalTypeP22mscorlib_System_Object22mscorlib_System_IntPtrS1_,__Z123mscorlib_System_Reflection_MethodBase_m_Invoke_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP37mscorlib_System_Reflection_MethodBaseP22mscorlib_System_ObjectP26mscorlib_System_Object_arr,__Z55mscorlib_System_Reflection_Module_m_filter_by_type_nameP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_,__Z67mscorlib_System_Reflection_Module_m_filter_by_type_name_ignore_caseP22mscorlib_System_ObjectP20mscorlib_System_TypeS0_
  ,__Z55mscorlib_System_Reflection_Module_m_GetCustomAttributesP33mscorlib_System_Reflection_ModuleP20mscorlib_System_Typeb,__Z45mscorlib_System_Reflection_Module_m_IsDefinedP33mscorlib_System_Reflection_ModuleP20mscorlib_System_Typeb,__ZN12FuncInvoker1I46mscorlib_System_Reflection_MonoEventInfoTraits17VoidPointerTraitsE6InvokeEPF40mscorlib_System_Reflection_MonoEventInfoPvS4_ES4_PS4_,__Z48mscorlib_System_Reflection_MonoEvent_m_IsDefinedP36mscorlib_System_Reflection_MonoEventP20mscorlib_System_Typeb,__Z134mscorlib_System_Reflection_MonoEvent_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP36mscorlib_System_Reflection_MonoEventP20mscorlib_System_Typeb,__Z48mscorlib_System_Reflection_MonoField_m_IsDefinedP36mscorlib_System_Reflection_MonoFieldP20mscorlib_System_Typeb,__Z134mscorlib_System_Reflection_MonoField_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP36mscorlib_System_Reflection_MonoFieldP20mscorlib_System_Typeb,__ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraitsS1_E6InvokeEPFvPvS3_P22mscorlib_System_ObjectS5_ES3_PS3_,__ZN14ActionInvoker2I28mscorlib_System_IntPtrTraits17VoidPointerTraitsE6InvokeEPFvPv22mscorlib_System_IntPtrS3_ES3_PS3_,__ZN12FuncInvoker1I47mscorlib_System_Reflection_MonoMethodInfoTraits28mscorlib_System_IntPtrTraitsE6InvokeEPF41mscorlib_System_Reflection_MonoMethodInfoPv22mscorlib_System_IntPtrES4_PS4_,__Z62mscorlib_System_Reflection_MonoMethodInfo_m_get_parameter_infoP22mscorlib_System_Object22mscorlib_System_IntPtrP37mscorlib_System_Reflection_MemberInfo,__ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_IntPtrTraitsS0_E6InvokeEPFPvS3_22mscorlib_System_IntPtrS3_ES3_PS3_,__Z61mscorlib_System_Reflection_MonoMethodInfo_m_GetParametersInfoP22mscorlib_System_Object22mscorlib_System_IntPtrP37mscorlib_System_Reflection_MemberInfo,__Z49mscorlib_System_Reflection_MonoMethod_m_IsDefinedP37mscorlib_System_Reflection_MonoMethodP20mscorlib_System_Typeb,__Z135mscorlib_System_Reflection_MonoMethod_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP37mscorlib_System_Reflection_MonoMethodP20mscorlib_System_Typeb,__Z50mscorlib_System_Reflection_MonoCMethod_m_IsDefinedP38mscorlib_System_Reflection_MonoCMethodP20mscorlib_System_Typeb,__Z136mscorlib_System_Reflection_MonoCMethod_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP38mscorlib_System_Reflection_MonoCMethodP20mscorlib_System_Typeb,__ZN12FuncInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_S1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS3_S5_ES3_PS3_,__Z51mscorlib_System_Reflection_MonoProperty_m_IsDefinedP39mscorlib_System_Reflection_MonoPropertyP20mscorlib_System_Typeb,__Z137mscorlib_System_Reflection_MonoProperty_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP39mscorlib_System_Reflection_MonoPropertyP20mscorlib_System_Typeb,__Z127mscorlib_System_Reflection_MonoProperty_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP39mscorlib_System_Reflection_MonoPropertyP22mscorlib_System_ObjectP26mscorlib_System_Object_arr,__Z62mscorlib_System_Reflection_ParameterInfo_m_GetCustomAttributesP40mscorlib_System_Reflection_ParameterInfoP20mscorlib_System_Typeb,__Z52mscorlib_System_Reflection_ParameterInfo_m_IsDefinedP40mscorlib_System_Reflection_ParameterInfoP20mscorlib_System_Typeb,__Z127mscorlib_System_Reflection_PropertyInfo_m_GetValue_mscorlib_System_Object_mscorlib_System_Object_mscorlib_System_Object_arr_arrP39mscorlib_System_Reflection_PropertyInfoP22mscorlib_System_ObjectP26mscorlib_System_Object_arr,__ZN14ActionInvoker4I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS1_E6InvokeEPFvPv22mscorlib_System_IntPtriS4_iES4_PS4_,__ZN14ActionInvoker4I28mscorlib_System_IntPtrTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS2_E6InvokeEPFvPv22mscorlib_System_IntPtrS4_iiES4_PS4_,__Z90mscorlib_System_Runtime_Remoting_Activation_ActivationServices_m_CreateProxyFromAttributesP22mscorlib_System_ObjectP20mscorlib_System_TypeP26mscorlib_System_Object_arr,__Z70mscorlib_System_Runtime_Remoting_Activation_UrlAttribute_m_IsContextOKP56mscorlib_System_Runtime_Remoting_Activation_UrlAttributeP49mscorlib_System_Runtime_Remoting_Contexts_ContextP22mscorlib_System_Object,__Z72mscorlib_System_Runtime_Remoting_Contexts_ContextAttribute_m_IsContextOKP58mscorlib_System_Runtime_Remoting_Contexts_ContextAttributeP49mscorlib_System_Runtime_Remoting_Contexts_ContextP22mscorlib_System_Object,__ZN14ActionInvoker2I17VoidPointerTraits26mscorlib_System_ByteTraitsE6InvokeEPFvPvS3_hES3_PS3_
  ,__Z62mscorlib_System_Runtime_Remoting_Messaging_MethodCall_m_CastToP53mscorlib_System_Runtime_Remoting_Messaging_MethodCallP22mscorlib_System_StringP20mscorlib_System_Type,__Z69mscorlib_System_Runtime_Remoting_Proxies_ProxyAttribute_m_IsContextOKP55mscorlib_System_Runtime_Remoting_Proxies_ProxyAttributeP49mscorlib_System_Runtime_Remoting_Contexts_ContextP22mscorlib_System_Object,__ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_IntPtrTraits28mscorlib_System_ObjectTraitsE6InvokeEPFvPvS4_22mscorlib_System_IntPtrP22mscorlib_System_ObjectES4_PS4_,__Z68mscorlib_System_Runtime_Remoting_RemotingServices_m_GetVirtualMethodP22mscorlib_System_ObjectP20mscorlib_System_TypeP37mscorlib_System_Reflection_MethodBase,__Z69mscorlib_System_Runtime_Remoting_RemotingServices_m_CreateClientProxyP22mscorlib_System_ObjectP57mscorlib_System_Runtime_Remoting_ActivatedClientTypeEntryP26mscorlib_System_Object_arr,__Z84mscorlib_System_Runtime_Remoting_RemotingServices_m_CreateClientProxyForContextBoundP22mscorlib_System_ObjectP20mscorlib_System_TypeP26mscorlib_System_Object_arr,__ZN14ActionInvoker3I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFvPvS3_S3_P22mscorlib_System_ObjectES3_PS3_,__ZN14ActionInvoker2I17VoidPointerTraits27mscorlib_System_Int16TraitsE6InvokeEPFvPvS3_sES3_PS3_,__ZN14ActionInvoker2I17VoidPointerTraits30mscorlib_System_DateTimeTraitsE6InvokeEPFvPvS3_24mscorlib_System_DateTimeES3_PS3_,__ZN14ActionInvoker2I17VoidPointerTraits28mscorlib_System_UInt64TraitsE6InvokeEPFvPvS3_yES3_PS3_,__Z144mscorlib_System_Security_Cryptography_CryptoConfig_m_CreateFromName_mscorlib_System_Object_mscorlib_System_String_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr,__Z76mscorlib_System_Security_Cryptography_RNGCryptoServiceProvider_m_RngGetBytesP22mscorlib_System_Object22mscorlib_System_IntPtrP24mscorlib_System_Byte_arr,__ZN12FuncInvoker2I28mscorlib_System_IntPtrTraitsS0_17VoidPointerTraitsE6InvokeEPF22mscorlib_System_IntPtrPvS3_S4_ES4_PS4_,__ZN14ActionInvoker1I28mscorlib_System_IntPtrTraitsE6InvokeEPFvPv22mscorlib_System_IntPtrES2_PS2_,__ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_E6InvokeEPFiPvS3_iiS3_iES3_PS3_,__ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S1_S1_E6InvokeEPFiPvS3_iiS3_iS3_S3_ES3_PS3_,__ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S1_E6InvokeEPFiPvS3_iiS3_iS3_ES3_PS3_,__ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_E6InvokeEPFiPvS3_iS3_iES3_PS3_,__Z123mscorlib_System_Text_ASCIIEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P34mscorlib_System_Text_ASCIIEncodingPti,__Z62mscorlib_System_Text_DecoderExceptionFallbackBuffer_m_FallbackP51mscorlib_System_Text_DecoderExceptionFallbackBufferP24mscorlib_System_Byte_arri,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFbPvS4_iES4_PS4_,__Z64mscorlib_System_Text_DecoderReplacementFallbackBuffer_m_FallbackP53mscorlib_System_Text_DecoderReplacementFallbackBufferP24mscorlib_System_Byte_arri,__Z129mscorlib_System_Text_EncoderExceptionFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Char_mscorlib_System_Int32P51mscorlib_System_Text_EncoderExceptionFallbackBufferti,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraits27mscorlib_System_Int32TraitsE6InvokeEPFbPvtiES4_PS4_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits26mscorlib_System_CharTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEPFbPvttiES4_PS4_,__ZN14ActionInvoker3I26mscorlib_System_CharTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvttiES3_PS3_,__Z131mscorlib_System_Text_EncoderReplacementFallbackBuffer_m_Fallback_mscorlib_System_Boolean_mscorlib_System_Char_mscorlib_System_Int32P53mscorlib_System_Text_EncoderReplacementFallbackBufferti,__Z118mscorlib_System_Text_Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P29mscorlib_System_Text_EncodingPti,__ZN14ActionInvoker4I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFvPvS3_iiiES3_PS3_,__ZN14ActionInvoker5I17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S1_S1_E6InvokeEPFvPvS3_iiiiES3_PS3_
  ,__Z43mscorlib_System_Text_StringBuilder_m_RemoveP34mscorlib_System_Text_StringBuilderii,__Z125mscorlib_System_Text_StringBuilder_m_Replace_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_StringP34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringS2_,__ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_27mscorlib_System_Int32TraitsS1_E6InvokeEPFPvS3_S3_S3_iiES3_PS3_,__Z121mscorlib_System_Text_StringBuilder_m_Append_mscorlib_System_Text_StringBuilder_mscorlib_System_Char_mscorlib_System_Int32P34mscorlib_System_Text_StringBuilderti,__Z138mscorlib_System_Text_StringBuilder_m_AppendFormat_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_Object_arr_arrP34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringP26mscorlib_System_Object_arr,__Z130mscorlib_System_Text_StringBuilder_m_AppendFormat_mscorlib_System_Text_StringBuilder_mscorlib_System_String_mscorlib_System_ObjectP34mscorlib_System_Text_StringBuilderP22mscorlib_System_StringP22mscorlib_System_Object,__Z123mscorlib_System_Text_StringBuilder_m_Insert_mscorlib_System_Text_StringBuilder_mscorlib_System_Int32_mscorlib_System_StringP34mscorlib_System_Text_StringBuilderiP22mscorlib_System_String,__Z121mscorlib_System_Text_StringBuilder_m_Insert_mscorlib_System_Text_StringBuilder_mscorlib_System_Int32_mscorlib_System_CharP34mscorlib_System_Text_StringBuilderit,__ZN12FuncInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_E6InvokeEPFPvS3_iS3_iES3_PS3_,__ZN14ActionInvoker2I29mscorlib_System_BooleanTraitsS0_E6InvokeEPFvPvbbES2_PS2_,__ZN14ActionInvoker3I29mscorlib_System_BooleanTraitsS0_S0_E6InvokeEPFvPvbbbES2_PS2_,__Z123mscorlib_System_Text_UTF32Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P34mscorlib_System_Text_UTF32EncodingPti,__ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_29mscorlib_System_BooleanTraitsS0_S2_S2_E6InvokeEPFiPvS4_iibibbES4_PS4_,__ZN12FuncInvoker9I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_29mscorlib_System_BooleanTraitsS1_S1_S2_E6InvokeEPFiPvS4_iiS4_ibS4_S4_bES4_PS4_,__ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S0_E6InvokeEPFiPvS3_iiiES3_PS3_,__Z122mscorlib_System_Text_UTF7Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P33mscorlib_System_Text_UTF7EncodingPti,__ZN12FuncInvoker5I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iiS4_bES4_PS4_,__ZN12FuncInvoker4I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iS4_bES4_PS4_,__Z122mscorlib_System_Text_UTF8Encoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P33mscorlib_System_Text_UTF8EncodingPti,__ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iiS4_iS4_bES4_PS4_,__ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS4_iS4_iS4_bES4_PS4_,__ZN12FuncInvoker9I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_28mscorlib_System_UInt32TraitsS2_28mscorlib_System_ObjectTraitsS1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS6_iijjP22mscorlib_System_ObjectS6_S6_bES6_PS6_,__ZN12FuncInvoker8I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_28mscorlib_System_UInt32TraitsS2_28mscorlib_System_ObjectTraitsS1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS6_ijjP22mscorlib_System_ObjectS6_S6_bES6_PS6_,__ZN12FuncInvoker6I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsS2_S2_27mscorlib_System_Int64Traits28mscorlib_System_UInt32TraitsE6InvokeEPFiPvP22mscorlib_System_ObjectS6_S6_S6_xjES6_PS6_,__ZN14ActionInvoker8I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_S1_27mscorlib_System_Int64Traits28mscorlib_System_UInt32TraitsS1_S1_E6InvokeEPFvPvP22mscorlib_System_ObjectS5_S5_S5_xjS5_S5_ES5_PS5_,__ZN13FuncInvoker11I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S1_S0_S1_S1_28mscorlib_System_ObjectTraitsS1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS5_iiS5_iS5_S5_P22mscorlib_System_ObjectS5_S5_bES5_PS5_,__ZN13FuncInvoker10I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S0_S1_S1_28mscorlib_System_ObjectTraitsS1_S1_29mscorlib_System_BooleanTraitsE6InvokeEPFiPvS5_iS5_iS5_S5_P22mscorlib_System_ObjectS5_S5_bES5_PS5_,__Z125mscorlib_System_Text_UnicodeEncoding_m_GetByteCount_mscorlib_System_Int32_mscorlib_System_CharU002A_ptr_mscorlib_System_Int32P36mscorlib_System_Text_UnicodeEncodingPti,__ZN14ActionInvoker4I17VoidPointerTraitsS0_27mscorlib_System_Int32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS4_S4_ibES4_PS4_,__Z117mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_Type_mscorlib_System_Object_arr_arrP22mscorlib_System_ObjectP20mscorlib_System_TypeP26mscorlib_System_Object_arr
  ,__ZN12FuncInvoker3I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S5_S5_ES5_PS5_,__ZN12FuncInvoker6I28mscorlib_System_ObjectTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S1_S1_S1_E6InvokeEPFP22mscorlib_System_ObjectPvS6_iS6_S6_S6_S6_ES6_PS6_,__Z110mscorlib_System_Activator_m_CreateInstance_mscorlib_System_Object_mscorlib_System_Type_mscorlib_System_BooleanP22mscorlib_System_ObjectP20mscorlib_System_Typeb,__ZN12FuncInvoker2I28mscorlib_System_ObjectTraits17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEPFP22mscorlib_System_ObjectPvS6_bES6_PS6_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_DoubleTraitsE6InvokeEPFxPvdES3_PS3_,__Z120mscorlib_System_BitConverter_m_GetBytes_mscorlib_System_Byte_arr_arr_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int32P22mscorlib_System_ObjectPhi,__ZN12FuncInvoker1I17VoidPointerTraits28mscorlib_System_DoubleTraitsE6InvokeEPFPvS3_dES3_PS3_,__Z38mscorlib_System_BitConverter_m_ToInt64P22mscorlib_System_ObjectP24mscorlib_System_Byte_arri,__ZN12FuncInvoker2I27mscorlib_System_Int64Traits17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEPFxPvS4_iES4_PS4_,__Z81mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_Int64P22mscorlib_System_Objectx,__Z114mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z82mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_UInt64P22mscorlib_System_Objecty,__Z114mscorlib_System_Convert_m_ToBoolean_mscorlib_System_Boolean_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits29mscorlib_System_BooleanTraitsE6InvokeEPFhPvbES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits26mscorlib_System_CharTraitsE6InvokeEPFhPvtES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_DoubleTraitsE6InvokeEPFhPvdES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_SingleTraitsE6InvokeEPFhPvfES3_PS3_,__Z75mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_Int64P22mscorlib_System_Objectx,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits27mscorlib_System_Int64TraitsE6InvokeEPFhPvxES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits27mscorlib_System_SByteTraitsE6InvokeEPFhPvaES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits27mscorlib_System_Int16TraitsE6InvokeEPFhPvsES3_PS3_,__Z108mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_UInt32TraitsE6InvokeEPFhPvjES3_PS3_,__Z76mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_UInt64P22mscorlib_System_Objecty,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_UInt64TraitsE6InvokeEPFhPvyES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_ByteTraits28mscorlib_System_UInt16TraitsE6InvokeEPFhPvtES3_PS3_,__Z108mscorlib_System_Convert_m_ToByte_mscorlib_System_Byte_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I26mscorlib_System_ByteTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFhPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker1I26mscorlib_System_CharTraits26mscorlib_System_ByteTraitsE6InvokeEPFtPvhES3_PS3_,__Z75mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_Int64P22mscorlib_System_Objectx
  ,__ZN12FuncInvoker1I26mscorlib_System_CharTraits27mscorlib_System_Int64TraitsE6InvokeEPFtPvxES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_CharTraits28mscorlib_System_SingleTraitsE6InvokeEPFtPvfES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_CharTraits27mscorlib_System_SByteTraitsE6InvokeEPFtPvaES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_CharTraits27mscorlib_System_Int16TraitsE6InvokeEPFtPvsES3_PS3_,__Z108mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker2I26mscorlib_System_CharTraits17VoidPointerTraitsS1_E6InvokeEPFtPvS3_S3_ES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_CharTraits28mscorlib_System_UInt32TraitsE6InvokeEPFtPvjES3_PS3_,__Z76mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_UInt64P22mscorlib_System_Objecty,__ZN12FuncInvoker1I26mscorlib_System_CharTraits28mscorlib_System_UInt64TraitsE6InvokeEPFtPvyES3_PS3_,__ZN12FuncInvoker1I26mscorlib_System_CharTraits28mscorlib_System_UInt16TraitsE6InvokeEPFtPvtES3_PS3_,__Z108mscorlib_System_Convert_m_ToChar_mscorlib_System_Char_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I26mscorlib_System_CharTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFtPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker2I30mscorlib_System_DateTimeTraits17VoidPointerTraitsS1_E6InvokeEPF24mscorlib_System_DateTimePvS4_S4_ES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits27mscorlib_System_Int16TraitsE6InvokeEPF24mscorlib_System_DateTimePvsES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits27mscorlib_System_Int32TraitsE6InvokeEPF24mscorlib_System_DateTimePviES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits27mscorlib_System_Int64TraitsE6InvokeEPF24mscorlib_System_DateTimePvxES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_SingleTraitsE6InvokeEPF24mscorlib_System_DateTimePvfES4_PS4_,__ZN12FuncInvoker2I30mscorlib_System_DateTimeTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPF24mscorlib_System_DateTimePvP22mscorlib_System_ObjectS5_ES5_PS5_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits27mscorlib_System_SByteTraitsE6InvokeEPF24mscorlib_System_DateTimePvaES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_UInt16TraitsE6InvokeEPF24mscorlib_System_DateTimePvtES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_UInt32TraitsE6InvokeEPF24mscorlib_System_DateTimePvjES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_UInt64TraitsE6InvokeEPF24mscorlib_System_DateTimePvyES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_DecimalTraits29mscorlib_System_BooleanTraitsE6InvokeEPF23mscorlib_System_DecimalPvbES4_PS4_,__ZN12FuncInvoker2I29mscorlib_System_DecimalTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPF23mscorlib_System_DecimalPvP22mscorlib_System_ObjectS5_ES5_PS5_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits29mscorlib_System_BooleanTraitsE6InvokeEPFdPvbES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits26mscorlib_System_ByteTraitsE6InvokeEPFdPvhES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraitsS0_E6InvokeEPFdPvdES2_PS2_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits28mscorlib_System_SingleTraitsE6InvokeEPFdPvfES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits27mscorlib_System_Int32TraitsE6InvokeEPFdPviES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits27mscorlib_System_Int64TraitsE6InvokeEPFdPvxES3_PS3_
  ,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits27mscorlib_System_SByteTraitsE6InvokeEPFdPvaES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits27mscorlib_System_Int16TraitsE6InvokeEPFdPvsES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits28mscorlib_System_UInt32TraitsE6InvokeEPFdPvjES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits28mscorlib_System_UInt64TraitsE6InvokeEPFdPvyES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_DoubleTraits28mscorlib_System_UInt16TraitsE6InvokeEPFdPvtES3_PS3_,__ZN12FuncInvoker2I28mscorlib_System_DoubleTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFdPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits29mscorlib_System_BooleanTraitsE6InvokeEPFsPvbES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits26mscorlib_System_ByteTraitsE6InvokeEPFsPvhES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits26mscorlib_System_CharTraitsE6InvokeEPFsPvtES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_DoubleTraitsE6InvokeEPFsPvdES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_SingleTraitsE6InvokeEPFsPvfES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits27mscorlib_System_Int32TraitsE6InvokeEPFsPviES3_PS3_,__Z77mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_Int64P22mscorlib_System_Objectx,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits27mscorlib_System_Int64TraitsE6InvokeEPFsPvxES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits27mscorlib_System_SByteTraitsE6InvokeEPFsPvaES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16TraitsS0_E6InvokeEPFsPvsES2_PS2_,__Z110mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_UInt32TraitsE6InvokeEPFsPvjES3_PS3_,__Z78mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_UInt64P22mscorlib_System_Objecty,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_UInt64TraitsE6InvokeEPFsPvyES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int16Traits28mscorlib_System_UInt16TraitsE6InvokeEPFsPvtES3_PS3_,__Z110mscorlib_System_Convert_m_ToInt16_mscorlib_System_Int16_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I27mscorlib_System_Int16Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFsPvP22mscorlib_System_ObjectS4_ES4_PS4_,__Z77mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_Int64P22mscorlib_System_Objectx,__Z110mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z78mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_UInt64P22mscorlib_System_Objecty,__Z110mscorlib_System_Convert_m_ToInt32_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits29mscorlib_System_BooleanTraitsE6InvokeEPFxPvbES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits26mscorlib_System_ByteTraitsE6InvokeEPFxPvhES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits26mscorlib_System_CharTraitsE6InvokeEPFxPvtES3_PS3_
  ,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_SingleTraitsE6InvokeEPFxPvfES3_PS3_,__Z77mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_Int64P22mscorlib_System_Objectx,__ZN12FuncInvoker1I27mscorlib_System_Int64TraitsS0_E6InvokeEPFxPvxES2_PS2_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits27mscorlib_System_SByteTraitsE6InvokeEPFxPvaES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits27mscorlib_System_Int16TraitsE6InvokeEPFxPvsES3_PS3_,__Z110mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_UInt32TraitsE6InvokeEPFxPvjES3_PS3_,__Z78mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_UInt64P22mscorlib_System_Objecty,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_UInt64TraitsE6InvokeEPFxPvyES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_UInt16TraitsE6InvokeEPFxPvtES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int64Traits28mscorlib_System_ObjectTraitsE6InvokeEPFxPvP22mscorlib_System_ObjectES3_PS3_,__Z110mscorlib_System_Convert_m_ToInt64_mscorlib_System_Int64_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I27mscorlib_System_Int64Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFxPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits29mscorlib_System_BooleanTraitsE6InvokeEPFaPvbES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits26mscorlib_System_ByteTraitsE6InvokeEPFaPvhES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits26mscorlib_System_CharTraitsE6InvokeEPFaPvtES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_DoubleTraitsE6InvokeEPFaPvdES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_SingleTraitsE6InvokeEPFaPvfES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits27mscorlib_System_Int32TraitsE6InvokeEPFaPviES3_PS3_,__Z77mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Int64P22mscorlib_System_Objectx,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits27mscorlib_System_Int64TraitsE6InvokeEPFaPvxES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits27mscorlib_System_Int16TraitsE6InvokeEPFaPvsES3_PS3_,__Z110mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_UInt32TraitsE6InvokeEPFaPvjES3_PS3_,__Z78mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_UInt64P22mscorlib_System_Objecty,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_UInt64TraitsE6InvokeEPFaPvyES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_SByteTraits28mscorlib_System_UInt16TraitsE6InvokeEPFaPvtES3_PS3_,__Z110mscorlib_System_Convert_m_ToSByte_mscorlib_System_SByte_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I27mscorlib_System_SByteTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFaPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits26mscorlib_System_ByteTraitsE6InvokeEPFfPvhES3_PS3_
  ,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits28mscorlib_System_DoubleTraitsE6InvokeEPFfPvdES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsE6InvokeEPFfPviES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits27mscorlib_System_Int64TraitsE6InvokeEPFfPvxES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits27mscorlib_System_SByteTraitsE6InvokeEPFfPvaES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits27mscorlib_System_Int16TraitsE6InvokeEPFfPvsES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits28mscorlib_System_UInt32TraitsE6InvokeEPFfPvjES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits28mscorlib_System_UInt64TraitsE6InvokeEPFfPvyES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits28mscorlib_System_UInt16TraitsE6InvokeEPFfPvtES3_PS3_,__ZN12FuncInvoker2I28mscorlib_System_SingleTraits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFfPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits29mscorlib_System_BooleanTraitsE6InvokeEPFtPvbES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits26mscorlib_System_ByteTraitsE6InvokeEPFtPvhES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits26mscorlib_System_CharTraitsE6InvokeEPFtPvtES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits28mscorlib_System_DoubleTraitsE6InvokeEPFtPvdES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits28mscorlib_System_SingleTraitsE6InvokeEPFtPvfES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits27mscorlib_System_Int32TraitsE6InvokeEPFtPviES3_PS3_,__Z79mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Int64P22mscorlib_System_Objectx,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits27mscorlib_System_Int64TraitsE6InvokeEPFtPvxES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits27mscorlib_System_SByteTraitsE6InvokeEPFtPvaES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits27mscorlib_System_Int16TraitsE6InvokeEPFtPvsES3_PS3_,__Z112mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits28mscorlib_System_UInt32TraitsE6InvokeEPFtPvjES3_PS3_,__Z80mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_UInt64P22mscorlib_System_Objecty,__ZN12FuncInvoker1I28mscorlib_System_UInt16Traits28mscorlib_System_UInt64TraitsE6InvokeEPFtPvyES3_PS3_,__Z112mscorlib_System_Convert_m_ToUInt16_mscorlib_System_UInt16_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I28mscorlib_System_UInt16Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFtPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits29mscorlib_System_BooleanTraitsE6InvokeEPFjPvbES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits26mscorlib_System_ByteTraitsE6InvokeEPFjPvhES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits26mscorlib_System_CharTraitsE6InvokeEPFjPvtES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits28mscorlib_System_DoubleTraitsE6InvokeEPFjPvdES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits28mscorlib_System_SingleTraitsE6InvokeEPFjPvfES3_PS3_
  ,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits27mscorlib_System_Int32TraitsE6InvokeEPFjPviES3_PS3_,__Z79mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Int64P22mscorlib_System_Objectx,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits27mscorlib_System_Int64TraitsE6InvokeEPFjPvxES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits27mscorlib_System_SByteTraitsE6InvokeEPFjPvaES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits27mscorlib_System_Int16TraitsE6InvokeEPFjPvsES3_PS3_,__Z112mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__Z80mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_UInt64P22mscorlib_System_Objecty,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits28mscorlib_System_UInt64TraitsE6InvokeEPFjPvyES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt32Traits28mscorlib_System_UInt16TraitsE6InvokeEPFjPvtES3_PS3_,__Z112mscorlib_System_Convert_m_ToUInt32_mscorlib_System_UInt32_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I28mscorlib_System_UInt32Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFjPvP22mscorlib_System_ObjectS4_ES4_PS4_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits29mscorlib_System_BooleanTraitsE6InvokeEPFyPvbES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits26mscorlib_System_ByteTraitsE6InvokeEPFyPvhES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits26mscorlib_System_CharTraitsE6InvokeEPFyPvtES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_DoubleTraitsE6InvokeEPFyPvdES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_SingleTraitsE6InvokeEPFyPvfES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits27mscorlib_System_Int32TraitsE6InvokeEPFyPviES3_PS3_,__Z79mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Int64P22mscorlib_System_Objectx,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits27mscorlib_System_Int64TraitsE6InvokeEPFyPvxES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits27mscorlib_System_SByteTraitsE6InvokeEPFyPvaES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits27mscorlib_System_Int16TraitsE6InvokeEPFyPvsES3_PS3_,__Z112mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_String_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectP22mscorlib_System_StringS0_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_UInt32TraitsE6InvokeEPFyPvjES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_UInt16TraitsE6InvokeEPFyPvtES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_UInt64Traits28mscorlib_System_ObjectTraitsE6InvokeEPFyPvP22mscorlib_System_ObjectES3_PS3_,__Z112mscorlib_System_Convert_m_ToUInt64_mscorlib_System_UInt64_mscorlib_System_Object_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectS0_S0_,__ZN12FuncInvoker2I28mscorlib_System_UInt64Traits28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEPFyPvP22mscorlib_System_ObjectS4_ES4_PS4_,__Z36mscorlib_System_Convert_m_ChangeTypeP22mscorlib_System_ObjectS0_P20mscorlib_System_Type,__ZN12FuncInvoker4I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsS1_29mscorlib_System_BooleanTraitsE6InvokeEPFP22mscorlib_System_ObjectPvS5_S6_S6_bES6_PS6_,__Z51mscorlib_System_DBNull_m_System_IConvertible_ToTypeP22mscorlib_System_DBNullP20mscorlib_System_TypeP22mscorlib_System_Object
  ,__ZN14ActionInvoker7I27mscorlib_System_Int32TraitsS0_S0_S0_S0_S0_S0_E6InvokeEPFvPviiiiiiiES2_PS2_,__ZN14ActionInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPvb24mscorlib_System_TimeSpanES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int64Traits27mscorlib_System_Int32TraitsE6InvokeEPFvPvxiES3_PS3_,__Z53mscorlib_System_DateTime_m_System_IConvertible_ToTypeP24mscorlib_System_DateTimeP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits30mscorlib_System_TimeSpanTraitsE6InvokeEPF24mscorlib_System_DateTimePv24mscorlib_System_TimeSpanES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraits28mscorlib_System_DoubleTraitsE6InvokeEPF24mscorlib_System_DateTimePvdES4_PS4_,__Z34mscorlib_System_DateTime_m_CompareP22mscorlib_System_Object24mscorlib_System_DateTimeS1_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits30mscorlib_System_DateTimeTraitsE6InvokeEPFbPv24mscorlib_System_DateTimeES3_PS3_,__ZN12FuncInvoker2I30mscorlib_System_DateTimeTraitsS0_27mscorlib_System_Int32TraitsE6InvokeEPF24mscorlib_System_DateTimePvS3_iES4_PS4_,__Z38mscorlib_System_DateTime_m_DaysInMonthP22mscorlib_System_Objectii,__ZN12FuncInvoker3I30mscorlib_System_DateTimeTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsE6InvokeEPF24mscorlib_System_DateTimePvS5_S5_iES5_PS5_,__ZN12FuncInvoker7I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_27mscorlib_System_Int32TraitsS1_S1_S0_S1_E6InvokeEPFbPvS4_S4_iS4_S4_bS4_ES4_PS4_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsS0_E6InvokeEPFPvS3_S3_bS3_ES3_PS3_,__ZN12FuncInvoker7I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S0_S0_29mscorlib_System_BooleanTraitsS2_S1_E6InvokeEPFiPvS4_iiibbS4_ES4_PS4_,__ZN12FuncInvoker6I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_S1_S1_29mscorlib_System_BooleanTraitsS1_E6InvokeEPFiPvS4_iS4_S4_bS4_ES4_PS4_,__ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS2_S1_S1_E6InvokeEPFbPvS4_iiS4_S4_ES4_PS4_,__ZN12FuncInvoker7I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS2_S1_S0_S1_S1_E6InvokeEPFbPvS4_iiS4_bS4_S4_ES4_PS4_,__ZN12FuncInvoker5I29mscorlib_System_BooleanTraits17VoidPointerTraits27mscorlib_System_Int32TraitsS1_S0_S1_E6InvokeEPFbPvS4_iS4_bS4_ES4_PS4_,__Z35mscorlib_System_DateTime_m_IsLetterP22mscorlib_System_ObjectP22mscorlib_System_Stringi,__ZN13FuncInvoker11I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_S0_S1_S1_S1_27mscorlib_System_Int32TraitsS0_S1_S1_E6InvokeEPFbPvS4_S4_S4_bS4_S4_S4_ibS4_S4_ES4_PS4_,__ZN12FuncInvoker9I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_27mscorlib_System_Int32TraitsS1_S0_S1_S0_S1_E6InvokeEPFbPvS4_S4_S4_iS4_bS4_bS4_ES4_PS4_,__Z113mscorlib_System_DateTime_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP24mscorlib_System_DateTimeP22mscorlib_System_StringP22mscorlib_System_Object,__ZN12FuncInvoker2I30mscorlib_System_DateTimeTraitsS0_30mscorlib_System_TimeSpanTraitsE6InvokeEPF24mscorlib_System_DateTimePvS3_24mscorlib_System_TimeSpanES4_PS4_,__Z112mscorlib_System_DateTime_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_,__Z115mscorlib_System_DateTime_m_op_GreaterThan_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_,__Z122mscorlib_System_DateTime_m_op_GreaterThanOrEqual_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_,__Z114mscorlib_System_DateTime_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_,__Z112mscorlib_System_DateTime_m_op_LessThan_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_,__Z119mscorlib_System_DateTime_m_op_LessThanOrEqual_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_DateTimeP22mscorlib_System_Object24mscorlib_System_DateTimeS1_,__ZN14ActionInvoker1I30mscorlib_System_DateTimeTraitsE6InvokeEPFvPv24mscorlib_System_DateTimeES2_PS2_
  ,__ZN14ActionInvoker2I30mscorlib_System_DateTimeTraits30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPv24mscorlib_System_DateTime24mscorlib_System_TimeSpanES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int64Traits30mscorlib_System_TimeSpanTraitsE6InvokeEPFvPvx24mscorlib_System_TimeSpanES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits36mscorlib_System_DateTimeOffsetTraitsE6InvokeEPFbPv30mscorlib_System_DateTimeOffsetES3_PS3_,__Z119mscorlib_System_DateTimeOffset_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP30mscorlib_System_DateTimeOffsetP22mscorlib_System_StringP22mscorlib_System_Object,__ZN12FuncInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS0_26mscorlib_System_CharTraitsE6InvokeEPFiPvS4_itES4_PS4_,__ZN12FuncInvoker4I17VoidPointerTraits26mscorlib_System_CharTraitsS0_S0_S0_E6InvokeEPFPvS3_tS3_S3_S3_ES3_PS3_,__ZN12FuncInvoker5I17VoidPointerTraits26mscorlib_System_CharTraitsS0_S0_S0_29mscorlib_System_BooleanTraitsE6InvokeEPFPvS4_tS4_S4_S4_bES4_PS4_,__ZN12FuncInvoker3I17VoidPointerTraits30mscorlib_System_DateTimeTraitsS0_S0_E6InvokeEPFPvS3_24mscorlib_System_DateTimeS3_S3_ES3_PS3_,__ZN12FuncInvoker4I17VoidPointerTraits30mscorlib_System_DateTimeTraits57mscorlib_System_Nullable_1_mscorlib_System_TimeSpanTraitsS0_S0_E6InvokeEPFPvS4_24mscorlib_System_DateTime51mscorlib_System_Nullable_1_mscorlib_System_TimeSpanS4_S4_ES4_PS4_,__ZN14ActionInvoker3I17VoidPointerTraitsS0_60mscorlib_System_Runtime_Serialization_StreamingContextTraitsE6InvokeEPFvPvS3_S3_54mscorlib_System_Runtime_Serialization_StreamingContextES3_PS3_,__Z120mscorlib_System_MonoEnumInfo_SByteComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP42mscorlib_System_MonoEnumInfo_SByteComparerP22mscorlib_System_ObjectS2_,__Z118mscorlib_System_MonoEnumInfo_SByteComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_SByte_mscorlib_System_SByteP42mscorlib_System_MonoEnumInfo_SByteCompareraa,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits27mscorlib_System_SByteTraitsS1_E6InvokeEPFiPvaaES3_PS3_,__Z120mscorlib_System_MonoEnumInfo_ShortComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP42mscorlib_System_MonoEnumInfo_ShortComparerP22mscorlib_System_ObjectS2_,__Z118mscorlib_System_MonoEnumInfo_ShortComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Int16_mscorlib_System_Int16P42mscorlib_System_MonoEnumInfo_ShortComparerss,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits27mscorlib_System_Int16TraitsS1_E6InvokeEPFiPvssES3_PS3_,__Z118mscorlib_System_MonoEnumInfo_IntComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP40mscorlib_System_MonoEnumInfo_IntComparerP22mscorlib_System_ObjectS2_,__Z116mscorlib_System_MonoEnumInfo_IntComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P40mscorlib_System_MonoEnumInfo_IntComparerii,__Z119mscorlib_System_MonoEnumInfo_LongComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP41mscorlib_System_MonoEnumInfo_LongComparerP22mscorlib_System_ObjectS2_,__ZN12FuncInvoker2I27mscorlib_System_Int32Traits27mscorlib_System_Int64TraitsS1_E6InvokeEPFiPvxxES3_PS3_,__ZN14ActionInvoker1I34mscorlib_System_MonoEnumInfoTraitsE6InvokeEPFvPv28mscorlib_System_MonoEnumInfoES2_PS2_,__ZN15ActionInvoker11I27mscorlib_System_Int32Traits27mscorlib_System_Int16TraitsS1_26mscorlib_System_ByteTraitsS2_S2_S2_S2_S2_S2_S2_E6InvokeEPFvPvisshhhhhhhhES4_PS4_,__Z30mscorlib_System_Guid_m_CompareP22mscorlib_System_Objectii,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits26mscorlib_System_GuidTraitsE6InvokeEPFbPv20mscorlib_System_GuidES3_PS3_,__ZN12FuncInvoker0I26mscorlib_System_GuidTraitsE6InvokeEPF20mscorlib_System_GuidPvES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraits29mscorlib_System_BooleanTraitsS1_S1_E6InvokeEPFPvS3_bbbES3_PS3_,__Z109mscorlib_System_Guid_m_ToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_IFormatProviderP20mscorlib_System_GuidP22mscorlib_System_StringP22mscorlib_System_Object,__Z70mscorlib_System_Math_m_Abs_mscorlib_System_Int64_mscorlib_System_Int64P22mscorlib_System_Objectx,__Z26mscorlib_System_Math_m_MaxP22mscorlib_System_Objectii,__Z26mscorlib_System_Math_m_MinP22mscorlib_System_Objectii
  ,__ZN12FuncInvoker2I28mscorlib_System_DoubleTraitsS0_S0_E6InvokeEPFdPvddES2_PS2_,__Z59mscorlib_System_MonoCustomAttrs_m_GetPseudoCustomAttributesP22mscorlib_System_ObjectS0_P20mscorlib_System_Type,__Z57mscorlib_System_MonoCustomAttrs_m_GetCustomAttributesBaseP22mscorlib_System_ObjectS0_P20mscorlib_System_Type,__Z160mscorlib_System_MonoCustomAttrs_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Reflection_ICustomAttributeProvider_mscorlib_System_BooleanP22mscorlib_System_ObjectS0_b,__Z51mscorlib_System_MonoCustomAttrs_m_IsDefinedInternalP22mscorlib_System_ObjectS0_P20mscorlib_System_Type,__Z51mscorlib_System_MonoType_m_GetConstructors_internalP24mscorlib_System_MonoTypeiP20mscorlib_System_Type,__Z35mscorlib_System_MonoType_m_GetFieldP24mscorlib_System_MonoTypeP22mscorlib_System_Stringi,__Z45mscorlib_System_MonoType_m_GetFields_internalP24mscorlib_System_MonoTypeiP20mscorlib_System_Type,__Z38mscorlib_System_MonoType_m_getFullNameP24mscorlib_System_MonoTypebb,__ZN12FuncInvoker2I17VoidPointerTraits29mscorlib_System_BooleanTraitsS1_E6InvokeEPFPvS3_bbES3_PS3_,__Z36mscorlib_System_MonoType_m_IsDefinedP24mscorlib_System_MonoTypeP20mscorlib_System_Typeb,__Z122mscorlib_System_MonoType_m_GetCustomAttributes_mscorlib_System_Object_arr_arr_mscorlib_System_Type_mscorlib_System_BooleanP24mscorlib_System_MonoTypeP20mscorlib_System_Typeb,__ZN14ActionInvoker5I17VoidPointerTraitsS0_29mscorlib_System_BooleanTraitsS0_S0_E6InvokeEPFvPvS3_S3_bS3_S3_ES3_PS3_,__ZN12FuncInvoker8I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS1_S0_29mscorlib_System_BooleanTraitsS0_S0_S0_E6InvokeEPFPvS4_S4_iiS4_bS4_S4_S4_ES4_PS4_,__ZN14ActionInvoker2I28mscorlib_System_UInt32Traits28mscorlib_System_UInt64TraitsE6InvokeEPFvPvjyES3_PS3_,__Z44mscorlib_System_NumberFormatter_m_ScaleOrderP22mscorlib_System_Objectx,__ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_UInt32Traits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_jiES4_PS4_,__ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_DoubleTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_diES4_PS4_,__ZN14ActionInvoker2I17VoidPointerTraits29mscorlib_System_DecimalTraitsE6InvokeEPFvPvS3_23mscorlib_System_DecimalES3_PS3_,__ZN14ActionInvoker1I26mscorlib_System_CharTraitsE6InvokeEPFvPvtES2_PS2_,__ZN12FuncInvoker1I28mscorlib_System_UInt32TraitsS0_E6InvokeEPFjPvjES2_PS2_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_SByteTraitsS0_E6InvokeEPFPvS3_S3_aS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_26mscorlib_System_ByteTraitsS0_E6InvokeEPFPvS3_S3_hS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_UInt16TraitsS0_E6InvokeEPFPvS3_S3_tS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int16TraitsS0_E6InvokeEPFPvS3_S3_sS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_UInt32TraitsS0_E6InvokeEPFPvS3_S3_jS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_E6InvokeEPFPvS3_S3_iS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_UInt64TraitsS0_E6InvokeEPFPvS3_S3_yS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_27mscorlib_System_Int64TraitsS0_E6InvokeEPFPvS3_S3_xS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_SingleTraitsS0_E6InvokeEPFPvS3_S3_fS3_ES3_PS3_
  ,__ZN12FuncInvoker3I17VoidPointerTraitsS0_28mscorlib_System_DoubleTraitsS0_E6InvokeEPFPvS3_S3_dS3_ES3_PS3_,__ZN12FuncInvoker3I17VoidPointerTraitsS0_29mscorlib_System_DecimalTraitsS0_E6InvokeEPFPvS3_S3_23mscorlib_System_DecimalS3_ES3_PS3_,__Z126mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_UInt32_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectjS0_,__ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_UInt32TraitsS0_E6InvokeEPFPvS3_jS3_ES3_PS3_,__Z125mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_IFormatProviderP22mscorlib_System_ObjectiS0_,__ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_UInt64TraitsS0_E6InvokeEPFPvS3_yS3_ES3_PS3_,__ZN12FuncInvoker2I17VoidPointerTraits27mscorlib_System_Int64TraitsS0_E6InvokeEPFPvS3_xS3_ES3_PS3_,__ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_SingleTraitsS0_E6InvokeEPFPvS3_fS3_ES3_PS3_,__ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_DoubleTraitsS0_E6InvokeEPFPvS3_dS3_ES3_PS3_,__Z53mscorlib_System_NumberFormatter_m_FastIntegerToStringP31mscorlib_System_NumberFormatteriP22mscorlib_System_Object,__Z49mscorlib_System_NumberFormatter_m_IntegerToStringP31mscorlib_System_NumberFormatterP22mscorlib_System_StringP22mscorlib_System_Object,__Z141mscorlib_System_NumberFormatter_m_NumberToString_mscorlib_System_String_mscorlib_System_String_mscorlib_System_Globalization_NumberFormatInfoP31mscorlib_System_NumberFormatterP22mscorlib_System_StringP46mscorlib_System_Globalization_NumberFormatInfo,__Z48mscorlib_System_NumberFormatter_m_FormatCurrencyP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo,__Z47mscorlib_System_NumberFormatter_m_FormatDecimalP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo,__Z50mscorlib_System_NumberFormatter_m_FormatFixedPointP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo,__Z47mscorlib_System_NumberFormatter_m_FormatGeneralP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo,__Z46mscorlib_System_NumberFormatter_m_FormatNumberP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo,__Z47mscorlib_System_NumberFormatter_m_FormatPercentP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo,__Z143mscorlib_System_NumberFormatter_m_FormatExponential_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Globalization_NumberFormatInfoP31mscorlib_System_NumberFormatteriP46mscorlib_System_Globalization_NumberFormatInfo,__Z46mscorlib_System_NumberFormatter_m_FormatCustomP31mscorlib_System_NumberFormatterP22mscorlib_System_StringP46mscorlib_System_Globalization_NumberFormatInfo,__ZN14ActionInvoker3I27mscorlib_System_Int32TraitsS0_17VoidPointerTraitsE6InvokeEPFvPviiS3_ES3_PS3_,__Z108mscorlib_System_StringComparer_m_Compare_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_ObjectP30mscorlib_System_StringComparerP22mscorlib_System_ObjectS2_,__Z109mscorlib_System_StringComparer_m_Equals_mscorlib_System_Boolean_mscorlib_System_Object_mscorlib_System_ObjectP30mscorlib_System_StringComparerP22mscorlib_System_ObjectS2_,__Z46mscorlib_System_CultureAwareComparer_m_CompareP36mscorlib_System_CultureAwareComparerP22mscorlib_System_StringS2_,__Z45mscorlib_System_CultureAwareComparer_m_EqualsP36mscorlib_System_CultureAwareComparerP22mscorlib_System_StringS2_,__Z41mscorlib_System_OrdinalComparer_m_CompareP31mscorlib_System_OrdinalComparerP22mscorlib_System_StringS2_,__Z40mscorlib_System_OrdinalComparer_m_EqualsP31mscorlib_System_OrdinalComparerP22mscorlib_System_StringS2_,__ZN14ActionInvoker5I27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEPFvPviiiiiES2_PS2_,__ZN12FuncInvoker5I27mscorlib_System_Int64Traits27mscorlib_System_Int32TraitsS1_S1_S1_S1_E6InvokeEPFxPviiiiiES3_PS3_,__ZN12FuncInvoker1I30mscorlib_System_TimeSpanTraitsS0_E6InvokeEPF24mscorlib_System_TimeSpanPvS2_ES3_PS3_
  ,__Z34mscorlib_System_TimeSpan_m_CompareP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsE6InvokeEPFbPv24mscorlib_System_TimeSpanES3_PS3_,__Z113mscorlib_System_TimeSpan_m_op_Addition_mscorlib_System_TimeSpan_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__ZN12FuncInvoker2I30mscorlib_System_TimeSpanTraitsS0_S0_E6InvokeEPF24mscorlib_System_TimeSpanPvS2_S2_ES3_PS3_,__Z112mscorlib_System_TimeSpan_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__Z115mscorlib_System_TimeSpan_m_op_GreaterThan_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__Z122mscorlib_System_TimeSpan_m_op_GreaterThanOrEqual_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__Z114mscorlib_System_TimeSpan_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__Z112mscorlib_System_TimeSpan_m_op_LessThan_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__Z119mscorlib_System_TimeSpan_m_op_LessThanOrEqual_mscorlib_System_Boolean_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__Z116mscorlib_System_TimeSpan_m_op_Subtraction_mscorlib_System_TimeSpan_mscorlib_System_TimeSpan_mscorlib_System_TimeSpanP22mscorlib_System_Object24mscorlib_System_TimeSpanS1_,__Z139mscorlib_System_TimeZone_m_IsDaylightSavingTime_mscorlib_System_Boolean_mscorlib_System_DateTime_mscorlib_System_Globalization_DaylightTimeP22mscorlib_System_Object24mscorlib_System_DateTimeP42mscorlib_System_Globalization_DaylightTime,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits30mscorlib_System_DateTimeTraits17VoidPointerTraitsE6InvokeEPFbPv24mscorlib_System_DateTimeS4_ES4_PS4_,__ZN12FuncInvoker1I30mscorlib_System_DateTimeTraitsS0_E6InvokeEPF24mscorlib_System_DateTimePvS2_ES3_PS3_,__ZN12FuncInvoker1I30mscorlib_System_TimeSpanTraits30mscorlib_System_DateTimeTraitsE6InvokeEPF24mscorlib_System_TimeSpanPv24mscorlib_System_DateTimeES4_PS4_,__Z118mscorlib_System_TimeZone_m_GetLocalTimeDiff_mscorlib_System_TimeSpan_mscorlib_System_DateTime_mscorlib_System_TimeSpanP24mscorlib_System_TimeZone24mscorlib_System_DateTime24mscorlib_System_TimeSpan,__ZN12FuncInvoker2I30mscorlib_System_TimeSpanTraits30mscorlib_System_DateTimeTraitsS0_E6InvokeEPF24mscorlib_System_TimeSpanPv24mscorlib_System_DateTimeS3_ES4_PS4_,__ZN12FuncInvoker3I29mscorlib_System_BooleanTraits27mscorlib_System_Int32Traits17VoidPointerTraitsS2_E6InvokeEPFbPviS4_S4_ES4_PS4_,__ZN14ActionInvoker4I27mscorlib_System_Int32TraitsS0_S0_S0_E6InvokeEPFvPviiiiES2_PS2_,__Z109mscorlib_System_Version_m_op_Equality_mscorlib_System_Boolean_mscorlib_System_Version_mscorlib_System_VersionP22mscorlib_System_ObjectP23mscorlib_System_VersionS2_,__Z111mscorlib_System_Version_m_op_Inequality_mscorlib_System_Boolean_mscorlib_System_Version_mscorlib_System_VersionP22mscorlib_System_ObjectP23mscorlib_System_VersionS2_,__Z48mscorlib_System_Reflection_MemberFilter_m_InvokeP39mscorlib_System_Reflection_MemberFilterP37mscorlib_System_Reflection_MemberInfoP22mscorlib_System_Object,__ZN12FuncInvoker4I17VoidPointerTraitsS0_28mscorlib_System_ObjectTraitsS0_S1_E6InvokeEPFPvS3_S3_P22mscorlib_System_ObjectS3_S5_ES3_PS3_,__Z46mscorlib_System_Reflection_TypeFilter_m_InvokeP37mscorlib_System_Reflection_TypeFilterP20mscorlib_System_TypeP22mscorlib_System_Object,__ZN12FuncInvoker4I17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_S0_S1_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS3_S3_S5_ES3_PS3_,__Z44mscorlib_System_ResolveEventHandler_m_InvokeP35mscorlib_System_ResolveEventHandlerP22mscorlib_System_ObjectP32mscorlib_System_ResolveEventArgs,__ZN12FuncInvoker2I17VoidPointerTraits28mscorlib_System_ObjectTraitsS0_E6InvokeEPFPvS3_P22mscorlib_System_ObjectS3_ES3_PS3_,__Z47replacements_Replacements_Encoding_m_InvokeI18NP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr,__ZN12FuncInvoker3I28mscorlib_System_ObjectTraitsS0_17VoidPointerTraitsS0_E6InvokeEPFP22mscorlib_System_ObjectPvS4_S5_S4_ES5_PS5_,__ZN12FuncInvoker3I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_S0_E6InvokeEPFP22mscorlib_System_ObjectPvS5_S5_S4_ES5_PS5_
  ,__ZN12FuncInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_iS4_P22mscorlib_System_ObjectES4_PS4_,__ZN14ActionInvoker7I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_S1_28mscorlib_System_SingleTraitsS2_S0_E6InvokeEPFvPvS4_iS4_iffS4_ES4_PS4_,__ZN12FuncInvoker1I17VoidPointerTraits28mscorlib_System_SingleTraitsE6InvokeEPFPvS3_fES3_PS3_,__Z57UnityEngine_UnityEngine_SendMouseEvents_HitInfo_m_CompareP22mscorlib_System_Object47UnityEngine_UnityEngine_SendMouseEvents_HitInfoS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits53UnityEngine_UnityEngine_SendMouseEvents_HitInfoTraitsS1_E6InvokeEPFbPv47UnityEngine_UnityEngine_SendMouseEvents_HitInfoS4_ES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits53UnityEngine_UnityEngine_SendMouseEvents_HitInfoTraitsE6InvokeEPFbPv47UnityEngine_UnityEngine_SendMouseEvents_HitInfoES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits53UnityEngine_UnityEngine_SendMouseEvents_HitInfoTraitsE6InvokeEPFvPvi47UnityEngine_UnityEngine_SendMouseEvents_HitInfoES3_PS3_,__ZN14ActionInvoker3I28mscorlib_System_ObjectTraits17VoidPointerTraitsS1_E6InvokeEPFvPvP22mscorlib_System_ObjectS3_S3_ES3_PS3_,__Z65UnityEngine_UnityEngine_StackTraceUtility_m_PostprocessStacktraceP22mscorlib_System_ObjectP22mscorlib_System_Stringb,__ZN14ActionInvoker3I17VoidPointerTraits47UnityEngine_UnityEngine_AnimatorStateInfoTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_41UnityEngine_UnityEngine_AnimatorStateInfoiES4_PS4_,__Z62UnityEngine_UnityEngine_TextGenerationSettings_m_CompareColorsP46UnityEngine_UnityEngine_TextGenerationSettings29UnityEngine_UnityEngine_ColorS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits35UnityEngine_UnityEngine_ColorTraitsS1_E6InvokeEPFbPv29UnityEngine_UnityEngine_ColorS4_ES3_PS3_,__Z63UnityEngine_UnityEngine_TextGenerationSettings_m_CompareVector2P46UnityEngine_UnityEngine_TextGenerationSettings31UnityEngine_UnityEngine_Vector2S1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits37UnityEngine_UnityEngine_Vector2TraitsS1_E6InvokeEPFbPv31UnityEngine_UnityEngine_Vector2S4_ES3_PS3_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits52UnityEngine_UnityEngine_TextGenerationSettingsTraitsE6InvokeEPFbPv46UnityEngine_UnityEngine_TextGenerationSettingsES3_PS3_,__ZN12FuncInvoker1I52UnityEngine_UnityEngine_TextGenerationSettingsTraitsS0_E6InvokeEPF46UnityEngine_UnityEngine_TextGenerationSettingsPvS2_ES3_PS3_,__ZN12FuncInvoker2I28mscorlib_System_SingleTraits17VoidPointerTraits52UnityEngine_UnityEngine_TextGenerationSettingsTraitsE6InvokeEPFfPvS4_46UnityEngine_UnityEngine_TextGenerationSettingsES4_PS4_,__Z48UnityEngine_UnityEngine_TextGenerator_m_PopulateP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_String46UnityEngine_UnityEngine_TextGenerationSettings,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits17VoidPointerTraits52UnityEngine_UnityEngine_TextGenerationSettingsTraitsE6InvokeEPFbPvS4_46UnityEngine_UnityEngine_TextGenerationSettingsES4_PS4_,__Z54UnityEngine_UnityEngine_TextGenerator_m_PopulateAlwaysP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_String46UnityEngine_UnityEngine_TextGenerationSettings,__ZN13FuncInvoker17I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_35UnityEngine_UnityEngine_ColorTraits27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsS3_S0_S0_S3_S3_S3_S3_S0_S3_37UnityEngine_UnityEngine_Vector2TraitsS5_S0_E6InvokeEPFbPvS7_S7_29UnityEngine_UnityEngine_Colorifibbiiiibi31UnityEngine_UnityEngine_Vector2S9_bES7_PS7_,__ZN13FuncInvoker19I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_35UnityEngine_UnityEngine_ColorTraits27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsS3_S0_S0_S3_S3_S3_S3_S0_S3_S4_S4_S4_S4_S0_E6InvokeEPFbPvS6_S6_29UnityEngine_UnityEngine_ColorifibbiiiibiffffbES6_PS6_,__ZN13FuncInvoker20I29mscorlib_System_BooleanTraits17VoidPointerTraitsS1_S1_S1_27mscorlib_System_Int32Traits28mscorlib_System_SingleTraitsS2_S0_S0_S2_S2_S2_S2_S0_S2_S3_S3_S3_S3_S0_E6InvokeEPFbPvS5_S5_S5_S5_ifibbiiiibiffffbES5_PS5_,__ZN12FuncInvoker0I34UnityEngine_UnityEngine_RectTraitsE6InvokeEPF28UnityEngine_UnityEngine_RectPvES3_PS3_,__Z160UnityEngine_UnityEngine_TrackedReference_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_TrackedReference_UnityEngine_UnityEngine_TrackedReferenceP22mscorlib_System_ObjectP40UnityEngine_UnityEngine_TrackedReferenceS2_,__ZN12FuncInvoker5I17VoidPointerTraitsS0_S0_27mscorlib_System_Int32TraitsS0_28mscorlib_System_ObjectTraitsE6InvokeEPFPvS4_S4_S4_iS4_P22mscorlib_System_ObjectES4_PS4_,__Z65UnityEngine_UnityEngine_Application_m_BuildInvocationForArgumentsP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr,__ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_P22mscorlib_System_ObjectiES4_PS4_,__Z51UnityEngine_UnityEngine_Object_m_CompareBaseObjectsP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_ObjectS2_,__Z130UnityEngine_UnityEngine_Object_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Object_UnityEngine_UnityEngine_ObjectP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_ObjectS2_
  ,__Z132UnityEngine_UnityEngine_Object_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Object_UnityEngine_UnityEngine_ObjectP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_ObjectS2_,__Z47UnityEngine_UnityEngine_AssetBundle_m_LoadAssetP35UnityEngine_UnityEngine_AssetBundleP22mscorlib_System_StringP20mscorlib_System_Type,__Z56UnityEngine_UnityEngine_AssetBundle_m_LoadAsset_InternalP35UnityEngine_UnityEngine_AssetBundleP22mscorlib_System_StringP20mscorlib_System_Type,__Z60UnityEngine_UnityEngine_AssetBundle_m_LoadAssetWithSubAssetsP35UnityEngine_UnityEngine_AssetBundleP22mscorlib_System_StringP20mscorlib_System_Type,__Z69UnityEngine_UnityEngine_AssetBundle_m_LoadAssetWithSubAssets_InternalP35UnityEngine_UnityEngine_AssetBundleP22mscorlib_System_StringP20mscorlib_System_Type,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits39UnityEngine_UnityEngine_LayerMaskTraitsE6InvokeEPFiPv33UnityEngine_UnityEngine_LayerMaskES3_PS3_,__ZN12FuncInvoker1I39UnityEngine_UnityEngine_LayerMaskTraits27mscorlib_System_Int32TraitsE6InvokeEPF33UnityEngine_UnityEngine_LayerMaskPviES4_PS4_,__Z115UnityEngine_UnityEngine_Resources_m_Load_UnityEngine_UnityEngine_Object_mscorlib_System_String_mscorlib_System_TypeP22mscorlib_System_ObjectP22mscorlib_System_StringP20mscorlib_System_Type,__Z142UnityEngine_UnityEngine_BoneWeight_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_BoneWeight_UnityEngine_UnityEngine_BoneWeightP22mscorlib_System_Object34UnityEngine_UnityEngine_BoneWeightS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_BoneWeightTraitsS1_E6InvokeEPFbPv34UnityEngine_UnityEngine_BoneWeightS4_ES3_PS3_,__Z144UnityEngine_UnityEngine_BoneWeight_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_BoneWeight_UnityEngine_UnityEngine_BoneWeightP22mscorlib_System_Object34UnityEngine_UnityEngine_BoneWeightS1_,__Z56UnityEngine_UnityEngine_GUILayer_m_INTERNAL_CALL_HitTestP22mscorlib_System_ObjectP32UnityEngine_UnityEngine_GUILayerP31UnityEngine_UnityEngine_Vector3,__ZN14ActionInvoker2I35UnityEngine_UnityEngine_ColorTraits28mscorlib_System_SingleTraitsE6InvokeEPFvPv29UnityEngine_UnityEngine_ColorfES3_PS3_,__ZN14ActionInvoker2I28mscorlib_System_SingleTraitsS0_E6InvokeEPFvPvffES2_PS2_,__Z55UnityEngine_UnityEngine_GUILayoutUtility_m_SelectIDListP22mscorlib_System_Objectib,__ZN14ActionInvoker3I27mscorlib_System_Int32Traits17VoidPointerTraitsS1_E6InvokeEPFvPviS3_S3_ES3_PS3_,__ZN12FuncInvoker1I34UnityEngine_UnityEngine_RectTraits27mscorlib_System_Int32TraitsE6InvokeEPF28UnityEngine_UnityEngine_RectPviES4_PS4_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits34UnityEngine_UnityEngine_RectTraitsE6InvokeEPFvPvi28UnityEngine_UnityEngine_RectES3_PS3_,__ZN14ActionInvoker5I28mscorlib_System_SingleTraitsS0_S0_S0_17VoidPointerTraitsE6InvokeEPFvPvffffS3_ES3_PS3_,__Z65UnityEngine_UnityEngine_GUISkin_SkinChangedDelegate_m_BeginInvokeP51UnityEngine_UnityEngine_GUISkin_SkinChangedDelegateP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__ZN14ActionInvoker1I35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPFvPv29UnityEngine_UnityEngine_ColorES2_PS2_,__ZN12FuncInvoker0I37UnityEngine_UnityEngine_Vector2TraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector2PvES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector2TraitsE6InvokeEPFfPv31UnityEngine_UnityEngine_Vector2ES3_PS3_,__ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector2TraitsS0_S0_E6InvokeEPF31UnityEngine_UnityEngine_Vector2PvS2_S2_ES3_PS3_,__Z133UnityEngine_UnityEngine_Vector2_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Vector2_UnityEngine_UnityEngine_Vector2P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector2S1_,__ZN14ActionInvoker3I28mscorlib_System_SingleTraitsS0_S0_E6InvokeEPFvPvfffES2_PS2_,__ZN12FuncInvoker3I37UnityEngine_UnityEngine_Vector3Traits17VoidPointerTraitsS1_28mscorlib_System_SingleTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS5_S5_fES5_PS5_,__ZN12FuncInvoker4I37UnityEngine_UnityEngine_Vector3TraitsS0_S0_28mscorlib_System_SingleTraitsS1_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS3_S3_ffES4_PS4_,__ZN12FuncInvoker4I37UnityEngine_UnityEngine_Vector3Traits17VoidPointerTraitsS1_28mscorlib_System_SingleTraitsS2_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS5_S5_ffES5_PS5_,__ZN12FuncInvoker2I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector3TraitsS1_E6InvokeEPFfPv31UnityEngine_UnityEngine_Vector3S4_ES3_PS3_
  ,__ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3TraitsS0_28mscorlib_System_SingleTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS3_fES4_PS4_,__ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3Traits28mscorlib_System_SingleTraitsS0_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvfS3_ES4_PS4_,__Z133UnityEngine_UnityEngine_Vector3_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits37UnityEngine_UnityEngine_Vector3TraitsS1_E6InvokeEPFbPv31UnityEngine_UnityEngine_Vector3S4_ES3_PS3_,__Z135UnityEngine_UnityEngine_Vector3_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Vector3_UnityEngine_UnityEngine_Vector3P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector3S1_,__ZN14ActionInvoker4I28mscorlib_System_SingleTraitsS0_S0_S0_E6InvokeEPFvPvffffES2_PS2_,__ZN12FuncInvoker0I35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPF29UnityEngine_UnityEngine_ColorPvES3_PS3_,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector4Traits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector4Pv29UnityEngine_UnityEngine_ColorES4_PS4_,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Color32Traits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPF31UnityEngine_UnityEngine_Color32Pv29UnityEngine_UnityEngine_ColorES4_PS4_,__ZN12FuncInvoker2I40UnityEngine_UnityEngine_QuaternionTraits37UnityEngine_UnityEngine_Vector3TraitsS1_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPv31UnityEngine_UnityEngine_Vector3S5_ES4_PS4_,__ZN12FuncInvoker2I40UnityEngine_UnityEngine_QuaternionTraits17VoidPointerTraitsS1_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvS4_S4_ES4_PS4_,__ZN12FuncInvoker1I40UnityEngine_UnityEngine_QuaternionTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPF34UnityEngine_UnityEngine_QuaternionPv31UnityEngine_UnityEngine_Vector3ES4_PS4_,__ZN12FuncInvoker1I40UnityEngine_UnityEngine_QuaternionTraitsS0_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvS2_ES3_PS3_,__ZN12FuncInvoker3I40UnityEngine_UnityEngine_QuaternionTraits28mscorlib_System_SingleTraitsS1_S1_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvfffES4_PS4_,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector3Traits40UnityEngine_UnityEngine_QuaternionTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3Pv34UnityEngine_UnityEngine_QuaternionES4_PS4_,__ZN12FuncInvoker2I40UnityEngine_UnityEngine_QuaternionTraitsS0_S0_E6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvS2_S2_ES3_PS3_,__ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3Traits40UnityEngine_UnityEngine_QuaternionTraitsS0_E6InvokeEPF31UnityEngine_UnityEngine_Vector3Pv34UnityEngine_UnityEngine_QuaternionS3_ES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFbPv31UnityEngine_UnityEngine_Vector3ES3_PS3_,__ZN12FuncInvoker2I28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFfPviiES3_PS3_,__ZN14ActionInvoker3I27mscorlib_System_Int32TraitsS0_28mscorlib_System_SingleTraitsE6InvokeEPFvPviifES3_PS3_,__ZN12FuncInvoker1I39UnityEngine_UnityEngine_Matrix4x4TraitsS0_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvS2_ES3_PS3_,__Z42UnityEngine_UnityEngine_Matrix4x4_m_InvertP22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4PS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits39UnityEngine_UnityEngine_Matrix4x4Traits17VoidPointerTraitsE6InvokeEPFbPv33UnityEngine_UnityEngine_Matrix4x4S4_ES4_PS4_,__Z56UnityEngine_UnityEngine_Matrix4x4_m_INTERNAL_CALL_InvertP22mscorlib_System_ObjectP33UnityEngine_UnityEngine_Matrix4x4S2_,__ZN12FuncInvoker0I39UnityEngine_UnityEngine_Matrix4x4TraitsE6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvES3_PS3_,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector4Traits27mscorlib_System_Int32TraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector4PviES4_PS4_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits37UnityEngine_UnityEngine_Vector4TraitsE6InvokeEPFvPvi31UnityEngine_UnityEngine_Vector4ES3_PS3_,__ZN12FuncInvoker1I39UnityEngine_UnityEngine_Matrix4x4Traits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4Pv31UnityEngine_UnityEngine_Vector3ES4_PS4_,__ZN14ActionInvoker3I37UnityEngine_UnityEngine_Vector3Traits40UnityEngine_UnityEngine_QuaternionTraitsS0_E6InvokeEPFvPv31UnityEngine_UnityEngine_Vector334UnityEngine_UnityEngine_QuaternionS4_ES3_PS3_,__ZN12FuncInvoker3I39UnityEngine_UnityEngine_Matrix4x4Traits37UnityEngine_UnityEngine_Vector3Traits40UnityEngine_UnityEngine_QuaternionTraitsS1_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4Pv31UnityEngine_UnityEngine_Vector334UnityEngine_UnityEngine_QuaternionS6_ES5_PS5_
  ,__ZN12FuncInvoker3I39UnityEngine_UnityEngine_Matrix4x4Traits17VoidPointerTraitsS1_S1_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvS4_S4_S4_ES4_PS4_,__ZN12FuncInvoker6I39UnityEngine_UnityEngine_Matrix4x4Traits28mscorlib_System_SingleTraitsS1_S1_S1_S1_S1_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvffffffES4_PS4_,__ZN12FuncInvoker4I39UnityEngine_UnityEngine_Matrix4x4Traits28mscorlib_System_SingleTraitsS1_S1_S1_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvffffES4_PS4_,__ZN12FuncInvoker2I39UnityEngine_UnityEngine_Matrix4x4TraitsS0_S0_E6InvokeEPF33UnityEngine_UnityEngine_Matrix4x4PvS2_S2_ES3_PS3_,__ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector4Traits39UnityEngine_UnityEngine_Matrix4x4TraitsS0_E6InvokeEPF31UnityEngine_UnityEngine_Vector4Pv33UnityEngine_UnityEngine_Matrix4x4S3_ES4_PS4_,__Z139UnityEngine_UnityEngine_Matrix4x4_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4S1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits39UnityEngine_UnityEngine_Matrix4x4TraitsS1_E6InvokeEPFbPv33UnityEngine_UnityEngine_Matrix4x4S4_ES3_PS3_,__Z141UnityEngine_UnityEngine_Matrix4x4_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Matrix4x4_UnityEngine_UnityEngine_Matrix4x4P22mscorlib_System_Object33UnityEngine_UnityEngine_Matrix4x4S1_,__ZN14ActionInvoker1I36UnityEngine_UnityEngine_BoundsTraitsE6InvokeEPFvPv30UnityEngine_UnityEngine_BoundsES2_PS2_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits36UnityEngine_UnityEngine_BoundsTraitsE6InvokeEPFbPv30UnityEngine_UnityEngine_BoundsES3_PS3_,__Z50UnityEngine_UnityEngine_Bounds_m_Internal_ContainsP22mscorlib_System_Object30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits36UnityEngine_UnityEngine_BoundsTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFbPv30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3ES4_PS4_,__Z64UnityEngine_UnityEngine_Bounds_m_INTERNAL_CALL_Internal_ContainsP22mscorlib_System_ObjectP30UnityEngine_UnityEngine_BoundsP31UnityEngine_UnityEngine_Vector3,__ZN12FuncInvoker2I28mscorlib_System_SingleTraits36UnityEngine_UnityEngine_BoundsTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFfPv30UnityEngine_UnityEngine_Bounds31UnityEngine_UnityEngine_Vector3ES4_PS4_,__ZN12FuncInvoker1I29mscorlib_System_BooleanTraits33UnityEngine_UnityEngine_RayTraitsE6InvokeEPFbPv27UnityEngine_UnityEngine_RayES3_PS3_,__Z129UnityEngine_UnityEngine_Bounds_m_IntersectRay_mscorlib_System_Boolean_UnityEngine_UnityEngine_Ray_mscorlib_System_SingleU0026_refP30UnityEngine_UnityEngine_Bounds27UnityEngine_UnityEngine_RayPf,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits33UnityEngine_UnityEngine_RayTraits17VoidPointerTraitsE6InvokeEPFbPv27UnityEngine_UnityEngine_RayS4_ES4_PS4_,__ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector3Traits17VoidPointerTraitsS1_E6InvokeEPF31UnityEngine_UnityEngine_Vector3PvS4_S4_ES4_PS4_,__Z130UnityEngine_UnityEngine_Bounds_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Bounds_UnityEngine_UnityEngine_BoundsP22mscorlib_System_Object30UnityEngine_UnityEngine_BoundsS1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits36UnityEngine_UnityEngine_BoundsTraitsS1_E6InvokeEPFbPv30UnityEngine_UnityEngine_BoundsS4_ES3_PS3_,__Z132UnityEngine_UnityEngine_Bounds_m_op_Inequality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Bounds_UnityEngine_UnityEngine_BoundsP22mscorlib_System_Object30UnityEngine_UnityEngine_BoundsS1_,__ZN12FuncInvoker2I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector4TraitsS1_E6InvokeEPFfPv31UnityEngine_UnityEngine_Vector4S4_ES3_PS3_,__ZN12FuncInvoker1I28mscorlib_System_SingleTraits37UnityEngine_UnityEngine_Vector4TraitsE6InvokeEPFfPv31UnityEngine_UnityEngine_Vector4ES3_PS3_,__ZN12FuncInvoker2I37UnityEngine_UnityEngine_Vector4TraitsS0_S0_E6InvokeEPF31UnityEngine_UnityEngine_Vector4PvS2_S2_ES3_PS3_,__Z133UnityEngine_UnityEngine_Vector4_m_op_Equality_mscorlib_System_Boolean_UnityEngine_UnityEngine_Vector4_UnityEngine_UnityEngine_Vector4P22mscorlib_System_Object31UnityEngine_UnityEngine_Vector4S1_,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits37UnityEngine_UnityEngine_Vector4TraitsS1_E6InvokeEPFbPv31UnityEngine_UnityEngine_Vector4S4_ES3_PS3_,__ZN12FuncInvoker1I37UnityEngine_UnityEngine_Vector3Traits28mscorlib_System_SingleTraitsE6InvokeEPF31UnityEngine_UnityEngine_Vector3PvfES4_PS4_,__Z101UnityEngine_UnityEngine_Mathf_m_Min_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Objectii,__Z101UnityEngine_UnityEngine_Mathf_m_Max_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Int32P22mscorlib_System_Objectii,__ZN12FuncInvoker3I28mscorlib_System_SingleTraitsS0_S0_S0_E6InvokeEPFfPvfffES2_PS2_
  ,__ZN12FuncInvoker2I29mscorlib_System_BooleanTraits28mscorlib_System_SingleTraitsS1_E6InvokeEPFbPvffES3_PS3_,__ZN12FuncInvoker4I28mscorlib_System_SingleTraitsS0_S0_17VoidPointerTraitsS0_E6InvokeEPFfPvffS3_fES3_PS3_,__ZN12FuncInvoker6I28mscorlib_System_SingleTraitsS0_S0_17VoidPointerTraitsS0_S0_S0_E6InvokeEPFfPvffS3_fffES3_PS3_,__ZN12FuncInvoker5I28mscorlib_System_SingleTraitsS0_S0_17VoidPointerTraitsS0_S0_E6InvokeEPFfPvffS3_ffES3_PS3_,__ZN14ActionInvoker2I17VoidPointerTraits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPFvPvS3_29UnityEngine_UnityEngine_ColorES3_PS3_,__ZN14ActionInvoker2I27mscorlib_System_Int32Traits35UnityEngine_UnityEngine_ColorTraitsE6InvokeEPFvPvi29UnityEngine_UnityEngine_ColorES3_PS3_,__ZN14ActionInvoker3I17VoidPointerTraits27mscorlib_System_Int32TraitsS0_E6InvokeEPFvPvS3_iS3_ES3_PS3_,__ZN12FuncInvoker1I35UnityEngine_UnityEngine_ColorTraits27mscorlib_System_Int32TraitsE6InvokeEPF29UnityEngine_UnityEngine_ColorPviES4_PS4_,__Z44UnityEngine_UnityEngine_UnityString_m_FormatP22mscorlib_System_ObjectP22mscorlib_System_StringP26mscorlib_System_Object_arr,__ZN12FuncInvoker1I33UnityEngine_UnityEngine_RayTraits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPF27UnityEngine_UnityEngine_RayPv31UnityEngine_UnityEngine_Vector3ES4_PS4_,__ZN12FuncInvoker2I33UnityEngine_UnityEngine_RayTraits17VoidPointerTraitsS1_E6InvokeEPF27UnityEngine_UnityEngine_RayPvS4_S4_ES4_PS4_,__ZN12FuncInvoker3I17VoidPointerTraits33UnityEngine_UnityEngine_RayTraits28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsE6InvokeEPFPvS5_27UnityEngine_UnityEngine_RayfiES5_PS5_,__ZN12FuncInvoker4I17VoidPointerTraitsS0_S0_28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsE6InvokeEPFPvS4_S4_S4_fiES4_PS4_,__ZN14ActionInvoker5I17VoidPointerTraitsS0_S0_28mscorlib_System_SingleTraits29mscorlib_System_BooleanTraitsE6InvokeEPFvPvS4_S4_S4_fbES4_PS4_,__Z69UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegate_m_BeginInvokeP55UnityEngine_UnityEngine_Display_DisplaysUpdatedDelegateP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__ZN12FuncInvoker0I42UnityEngine_UnityEngine_RenderBufferTraitsE6InvokeEPF36UnityEngine_UnityEngine_RenderBufferPvES3_PS3_,__ZN14ActionInvoker3I28mscorlib_System_IntPtrTraits17VoidPointerTraitsS1_E6InvokeEPFvPv22mscorlib_System_IntPtrS3_S3_ES3_PS3_,__ZN14ActionInvoker3I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32TraitsS1_E6InvokeEPFvPv22mscorlib_System_IntPtriiES3_PS3_,__ZN14ActionInvoker4I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32TraitsS1_S1_E6InvokeEPFvPv22mscorlib_System_IntPtriiiES3_PS3_,__ZN14ActionInvoker5I28mscorlib_System_IntPtrTraits27mscorlib_System_Int32TraitsS1_S1_S1_E6InvokeEPFvPv22mscorlib_System_IntPtriiiiES3_PS3_,__ZN12FuncInvoker4I27mscorlib_System_Int32TraitsS0_S0_17VoidPointerTraitsS1_E6InvokeEPFiPviiS3_S3_ES3_PS3_,__ZN12FuncInvoker0I40UnityEngine_UnityEngine_QuaternionTraitsE6InvokeEPF34UnityEngine_UnityEngine_QuaternionPvES3_PS3_,__ZN14ActionInvoker1I40UnityEngine_UnityEngine_QuaternionTraitsE6InvokeEPFvPv34UnityEngine_UnityEngine_QuaternionES2_PS2_,__ZN14ActionInvoker2I37UnityEngine_UnityEngine_Vector3Traits27mscorlib_System_Int32TraitsE6InvokeEPFvPv31UnityEngine_UnityEngine_Vector3iES3_PS3_,__ZN14ActionInvoker4I28mscorlib_System_SingleTraitsS0_S0_27mscorlib_System_Int32TraitsE6InvokeEPFvPvfffiES3_PS3_,__Z38UnityEngine_UnityEngine_Random_m_RangeP22mscorlib_System_Objectii,__Z47UnityEngine_UnityEngine_Random_m_RandomRangeIntP22mscorlib_System_Objectii,__ZN12FuncInvoker0I36UnityEngine_UnityEngine_BoundsTraitsE6InvokeEPF30UnityEngine_UnityEngine_BoundsPvES3_PS3_,__ZN12FuncInvoker1I27mscorlib_System_Int32Traits37UnityEngine_UnityEngine_Vector3TraitsE6InvokeEPFiPv31UnityEngine_UnityEngine_Vector3ES3_PS3_,__Z64UnityEngine_UnityEngine_CharacterController_m_INTERNAL_CALL_MoveP22mscorlib_System_ObjectP43UnityEngine_UnityEngine_CharacterControllerP31UnityEngine_UnityEngine_Vector3
  ,__ZN12FuncInvoker0I47UnityEngine_UnityEngine_AnimatorStateInfoTraitsE6InvokeEPF41UnityEngine_UnityEngine_AnimatorStateInfoPvES3_PS3_,__ZN12FuncInvoker0I46UnityEngine_UnityEngine_AnimatorClipInfoTraitsE6InvokeEPF40UnityEngine_UnityEngine_AnimatorClipInfoPvES3_PS3_,__ZN14ActionInvoker3I17VoidPointerTraits28mscorlib_System_SingleTraits27mscorlib_System_Int32TraitsE6InvokeEPFvPvS4_fiES4_PS4_,__Z69UnityEngine_UnityEngine_Font_FontTextureRebuildCallback_m_BeginInvokeP55UnityEngine_UnityEngine_Font_FontTextureRebuildCallbackP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z63UnityEngine_UnityEngine_Canvas_WillRenderCanvases_m_BeginInvokeP49UnityEngine_UnityEngine_Canvas_WillRenderCanvasesP29mscorlib_System_AsyncCallbackP22mscorlib_System_Object,__Z86mscorlib_System_Array_m_IndexOf_mscorlib_System_Char_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP24mscorlib_System_Char_arrt,__Z81mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_Int64P21mscorlib_System_Arrayx,__Z79mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_Int64P21mscorlib_System_Arrayx,__Z68mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_Int64P21mscorlib_System_Arrayx,__Z82mscorlib_System_Array_m_InternalArray__ICollection_Contains_mscorlib_System_UInt64P21mscorlib_System_Arrayy,__Z80mscorlib_System_Array_m_InternalArray__ICollection_Remove_mscorlib_System_UInt64P21mscorlib_System_Arrayy,__Z69mscorlib_System_Array_m_InternalArray__IndexOf_mscorlib_System_UInt64P21mscorlib_System_Arrayy,__Z93mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt32_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP26mscorlib_System_UInt32_arrj,__Z93mscorlib_System_Array_m_BinarySearch_mscorlib_System_UInt16_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP26mscorlib_System_UInt16_arrt,__Z91mscorlib_System_Array_m_BinarySearch_mscorlib_System_Byte_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP24mscorlib_System_Byte_arrh,__ZL88mscorlib_System_Array_m_IndexOf_mscorlib_System_Object_mscorlib_System_Int32_T_arr_arr_TP22mscorlib_System_ObjectP26mscorlib_System_Object_arrS0_,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE6setbufEPwi,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwi,__ZNSt3__111__stdoutbufIwE6xsputnEPKwi,__ZNSt3__115basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwi,__ZNSt3__111__stdoutbufIcE6xsputnEPKci,__ZNKSt3__114error_category10equivalentEiRKNS_15error_conditionE,__ZNKSt3__114error_category10equivalentERKNS_10error_codeEi,__ZNKSt3__17collateIcE7do_hashEPKcS3_,__ZNKSt3__17collateIwE7do_hashEPKwS3_,__ZNKSt3__18messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE,__ZNKSt3__18messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE,__ZNKSt3__15ctypeIcE10do_toupperEPcPKc,__ZNKSt3__15ctypeIcE10do_tolowerEPcPKc,__ZNKSt3__15ctypeIcE9do_narrowEcc
  ,__ZNKSt3__15ctypeIwE5do_isEtw,__ZNKSt3__15ctypeIwE10do_toupperEPwPKw,__ZNKSt3__15ctypeIwE10do_tolowerEPwPKw,__ZNKSt3__15ctypeIwE9do_narrowEwc,__ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv,_sn_write,__ZN6il2cpp2vm5Array7NewFullEP8TypeInfoPjS4_,__ZN6il2cpp2os8TimeZone15GetTimeZoneDataEiPxPNSt3__112basic_stringIcNS3_11char_traitsIcEENS3_9allocatorIcEEEE,__Z27il2cpp_array_addr_with_sizeP11Il2CppArrayij,__ZN6il2cpp2vm5Class8FromNameEPK11Il2CppImagePKcS6_,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEjc,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcj,__ZN6il2cpp6icalls8mscorlib6System11__ComObject20GetInterfaceInternalEP27mscorlib_System___ComObjectP20Il2CppReflectionTypeb,__ZN6il2cpp6icalls8mscorlib6System9AppDomain15ExecuteAssemblyEP15Il2CppAppDomainP14Il2CppAssemblyP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System5Array18CreateInstanceImplEP20Il2CppReflectionTypeP11Il2CppArrayS7_,__ZN6il2cpp6icalls8mscorlib6System7Convert27InternalFromBase64CharArrayEP11Il2CppArrayii,__ZN6il2cpp6icalls8mscorlib6System21CurrentSystemTimeZone15GetTimeZoneDataEiPP11Il2CppArrayS6_,__ZN6il2cpp6icalls8mscorlib6System7Decimal10decimalDivEP19il2cpp_decimal_reprS5_S5_,__ZN6il2cpp6icalls8mscorlib6System7Decimal13decimalIntDivEP19il2cpp_decimal_reprS5_S5_,__ZN6il2cpp6icalls8mscorlib6System11Diagnostics10StackTrace9get_traceEP15Il2CppExceptionib,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CultureInfo21internal_get_culturesEbbb,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11GetFileStatEP12Il2CppStringP29mscorlib_System_IO_MonoIOStatPi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO8MoveFileEP12Il2CppStringS6_Pi,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO17SetFileAttributesEP12Il2CppStringiPi,__ZN6il2cpp6icalls8mscorlib6System15MonoCustomAttrs27GetCustomAttributesInternalEP12Il2CppObjectP20Il2CppReflectionTypeb,__ZN6il2cpp6icalls8mscorlib6System8MonoType24GetConstructors_internalEP20Il2CppReflectionTypeiS5_,__ZN6il2cpp6icalls8mscorlib6System8MonoType18GetEvents_internalEP20Il2CppReflectionTypeiS5_,__ZN6il2cpp6icalls8mscorlib6System8MonoType8GetFieldEP20Il2CppReflectionTypeP12Il2CppStringi,__ZN6il2cpp6icalls8mscorlib6System8MonoType18GetFields_internalEP20Il2CppReflectionTypeiS5_,__ZN6il2cpp6icalls8mscorlib6System8MonoType11getFullNameEP20Il2CppReflectionTypebb
  ,__ZN6il2cpp6icalls8mscorlib6System8MonoType13GetNestedTypeEPvP12Il2CppStringi,__ZN6il2cpp6icalls8mscorlib6System8MonoType16InternalGetEventEP20Il2CppReflectionTypeP12Il2CppStringi,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly16GetFilesInternalEP14Il2CppAssemblyP12Il2CppStringb,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly31GetManifestResourceInfoInternalEP14Il2CppAssemblyP12Il2CppStringPv,__ZN6il2cpp6icalls8mscorlib6System10Reflection4Emit13ModuleBuilder14getMethodTokenEP29Il2CppReflectionModuleBuilderP22Il2CppReflectionMethodP11Il2CppArray,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module16ResolveSignatureE12Il2CppIntPtriPi,__ZN6il2cpp6icalls8mscorlib6System10Reflection6Module18ResolveStringTokenE12Il2CppIntPtriPi,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices8GCHandle15GetTargetHandleEP12Il2CppObjectii,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal22QueryInterfaceInternalE12Il2CppIntPtrP20mscorlib_System_GuidPS6_,__ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager21GetLinkDemandSecurityEP37mscorlib_System_Reflection_MethodBaseP51mscorlib_System_Security_RuntimeDeclSecurityActionsS8_,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked5Add64EPxx,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked15CompareExchangeEPiii,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked21CompareExchangeIntPtrEP12Il2CppIntPtrS5_S5_,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked17CompareExchange_TEPPvS5_S5_,__ZN6il2cpp6icalls8mscorlib6System9Threading11Interlocked10Exchange64EPxx,__ZN6il2cpp6icalls8mscorlib6System9Threading5Mutex20CreateMutex_internalEbP12Il2CppStringPb,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread13Join_internalEP12Il2CppThreadiPv,__ZN6il2cpp6icalls8mscorlib6System9Threading10WaitHandle16WaitAll_internalEP11Il2CppArrayib,__ZN6il2cpp6icalls8mscorlib6System9Threading10WaitHandle16WaitAny_internalEP11Il2CppArrayib,__ZN6il2cpp6icalls8mscorlib6System4Type18internal_from_nameEP12Il2CppStringbb,__ZN6il2cpp6icalls8mscorlib6System4Type18type_is_subtype_ofEP20Il2CppReflectionTypeS5_b,__ZN6il2cpp6icalls8mscorlib6System9ValueType14InternalEqualsEP12Il2CppObjectS5_PP11Il2CppArray,__ZN6il2cpp6icalls6System6System9Threading9Semaphore22OpenSemaphore_internalEP12Il2CppStringiPi,__ZN6il2cpp6icalls6System6System9Threading9Semaphore25ReleaseSemaphore_internalE12Il2CppIntPtriPb,_png_zalloc,_zcalloc,__ZN12_GLOBAL__N_122createArticulationLinkERN5physx14NpArticulationEPNS0_18NpArticulationLinkERKNS0_11PxTransformE,__ZN5physx10PxsContext24removeParticleSystemImplEPNS_20PxvParticleSystemSimEb,__ZL26SelectClosestEdgeCB_ConvexRKN5physx2Gu13PolygonalDataERKNS_2Cm23FastVertex2ShapeScalingERKNS_6PxVec3E,__ZL23SelectClosestEdgeCB_BoxRKN5physx2Gu13PolygonalDataERKNS_2Cm23FastVertex2ShapeScalingERKNS_6PxVec3E
  ,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6appendEPKcj,__ZN6Object17FindObjectsOfTypeEiPNSt3__16vectorIPS_NS0_9allocatorIS2_EEEEb,__ZNSt3__16vectorI17SortingLayerEntryNS_9allocatorIS1_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS3_EEPS1_,__ZNK22BuiltinResourceManager11GetResourceEiRKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE,__Z30IsUsingLightProbesForRenderingPK12BaseRendererbb,__ZN9ShaderLab13PropertySheet10SetTextureERKNS_16FastPropertyNameEP7Texture,__Z28CalculateSubShaderIndexToUseP6ShaderS0_i,__ZN6Object21FindAllDerivedObjectsEiPNSt3__16vectorIiNS0_9allocatorIiEEEEb,__ZN6Shader24GetShadowCasterPassToUseEiRi,__Z20IntersectAABBFrustumRK4AABBPK5Planej,__ZN5Unity8Material14CreateMaterialER6Shaderib,__ZN19SkinnedMeshRenderer17PrepareSkinCommonEiR12SkinMeshInfo,__ZN19SkinnedMeshRenderer8SkinMeshER12SkinMeshInfob,__ZN19StreamedBinaryWriteILb0EE4InitE24TransferInstructionFlags20BuildTargetSelection,__Z18CalculateImageSizeii13TextureFormat,_png_set_longjmp_fn,__Z16WriteBytesToFilePKviRKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE,__Z29FindRelativeTransformWithPathR9TransformPKcb,__ZL18MonoBehaviourDoGUIPvN13MonoBehaviour13GUILayoutTypeEi,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier59ELi16EEE6appendEPKcj,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignINS_11__wrap_iterIPKcEEEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeESC_SC_,__Z12SetFileFlagsRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEjj,__ZN4File5WriteEPKvi,__Z12AddComponentRN5Unity10GameObjectEPKcPNSt3__112basic_stringIcNS4_11char_traitsIcEENS4_9allocatorIcEEEE,__Z19CanReplaceComponentRN5Unity9ComponentEiPNSt3__112basic_stringIcNS2_11char_traitsIcEENS2_9allocatorIcEEEE,__Z19scripting_array_newP14ScriptingClassjj,__Z27scripting_array_element_ptrP14ScriptingArrayij,__ZN13MonoBehaviour22CanHandleNotificationsEPviR11MessageData,__Z12MurmurHash2APKvij,__Z25scripting_class_from_nameP14ScriptingImagePKcS2_
  ,__Z29scripting_class_from_fullnamePKcS0_S0_,__ZNK14SerializedFile10GetClassIDEx,__ZNK14SerializedFile11IsAvailableEx,__Z10ReadStringR8UnityStrRPKhS2_,__ZNK6Shader17CanPassBeRecordedEii,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier46ELi16EEE6appendEjc,__ZN16MemoryFileSystem16FindNodeOrCreateEPKcb,__ZNSt3__112basic_stringIcNS_11char_traitsIcEE13stl_allocatorIcL18MemLabelIdentifier90ELi16EEE6appendEjc,__ZN15FileSystemEntry8SetFlagsEjj,__Z16CreateGameObjectRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPKcz,__Z19FindShaderLabShaderRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS_6vectorI4PPtrI6ShaderENS3_ISB_EEEEb,__ZN7Striper16ComputeBestStripEjR14BestStripCache,__Z30LoadNamedObjectFromAssetBundleR11AssetBundleRKNSt3__112basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEEP15ScriptingObject,__Z37AssetBundle_CUSTOM_LoadAsset_InternalP15ScriptingObjectP15ScriptingStringS0_,__Z50AssetBundle_CUSTOM_LoadAssetWithSubAssets_InternalP15ScriptingObjectP15ScriptingStringS0_,__Z49Bounds_CUSTOM_INTERNAL_CALL_Internal_IntersectRayR3RayR4AABBPf,__ZN8IRaycast12IntersectAnyERK14BatchedRaycastP4AABBj,__ZN9AudioClip21ScriptPCMReadCallbackEP10FMOD_SOUNDPvj,__ZN12AudioManager18ValidateFMODResultE11FMOD_RESULTPKc,__Z14FMOD_FILE_SeekPvjS_,__ZN4FMOD6System19setStreamBufferSizeEjj,__ZN4FMOD6System11getDSPClockEPjS1_,__ZN4FMOD12ChannelGroup6addDSPEPNS_3DSPEPPNS_13DSPConnectionE,__ZN4FMOD6System18createChannelGroupEPKcPPNS_12ChannelGroupE,__ZN9AudioClip7WWWSeekEPvjS0_,__ZN9AudioClip7pcmreadEP10FMOD_SOUNDPvj,__ZNK11AudioSource19GetFilterComponentsERNSt3__16vectorIPN4FMOD3DSPENS0_9allocatorIS4_EEEEb,__ZNK6Object8HasEventEPFvPvS0_iEPKv,__ZN7mecanim9animation18CreateAnimationSetEPKNS0_18ControllerConstantEjRNS_6memory9AllocatorE,__ZN7mecanim24CreateValueArrayConstantENS_9ValueTypeEjRNS_6memory9AllocatorE
  ,__Z8CopyBlobIN7mecanim9animation12AvatarMemoryEEPT_RKS3_RNS0_6memory9AllocatorERj,__Z18HiearchyMatchesOptP9TransformPKN7mecanim8skeleton8SkeletonEPKj,__ZN7mecanim12statemachine24CreateStateMachineOutputEPKNS0_20StateMachineConstantEjRNS_6memory9AllocatorE,__ZN7mecanim12statemachine27CreateStateMachineWorkspaceEPKNS0_20StateMachineConstantEjRNS_6memory9AllocatorE,__Z8StripifyPKjiRNSt3__16vectorIj13stl_allocatorIjL18MemLabelIdentifier90ELi16EEEE,__ZN20TextRenderingPrivate15DynamicFontData17GetFaceForFontRefERNS_7FontRefERNSt3__16vectorI4PPtrINS_4FontEE13stl_allocatorIS7_L18MemLabelIdentifier27ELi16EEEE,_FT_Set_Pixel_Sizes,__ZNSt3__16vectorI8UnityStr13stl_allocatorIS1_L18MemLabelIdentifier27ELi16EEE26__swap_out_circular_bufferERNS_14__split_bufferIS1_RS4_EEPS1_,_cff_get_cid_from_glyph_index,_ft_stub_set_pixel_sizes,_tt_face_load_directory_stub,_tt_face_load_hhea,_tt_load_sbit_metrics,_tt_face_get_ps_name,_tt_face_load_charmap_stub,_tt_face_get_kerning,_tt_face_load_hmtx,_tt_face_set_sbit_strike,_tt_face_load_strike_metrics,_tt_cmap14_char_var_isdefault,_tt_cmap14_char_variants,_tt_cmap14_variant_chars,_gray_conic_to,_ft_smooth_set_mode,_TT_Set_MM_Blend,_TT_Set_Var_Design,_tt_face_get_location,_Round_None,_Round_To_Grid,_Round_Up_To_Grid
  ,_Round_Down_To_Grid,_Round_To_Half_Grid,_Round_To_Double_Grid,_Round_Super,_Round_Super_45,_Project_x,_Project_y,_Project,_Dual_Project,_psh_globals_new,_ft_raster1_set_mode,__ZN2UI15SortForBatchingEPKNS_13UIInstructionEjPS0_,__ZN2UI14CanvasRenderer14AttachToCanvasEPNS_6CanvasENS_8MaskModeE,__Z12MouseHandleriPK20EmscriptenMouseEventPv,__Z10KeyHandleriPK23EmscriptenKeyboardEventPv,__Z24FullscreenChangeCallbackiPK31EmscriptenFullscreenChangeEventPv,__Z13FocusCallbackiPK20EmscriptenFocusEventPv,__ZN18GlslGpuProgramGLES17CompileGlslShaderEj10ShaderTypePKc,__ZN17FfpGpuProgramGLES6CreateEjj,__ZN18GlslGpuProgramGLES6CreateERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER14ChannelAssigns,__ZL18BindVProgAttrbutesRKNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEER14ChannelAssignsj,__ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN16VirtFuncInvoker1I17VoidPointerTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi,__ZN16VirtFuncInvoker1I28mscorlib_System_ObjectTraitsS0_E6InvokeEP10MethodInfoPvP22mscorlib_System_Object,__ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object,__ZN16VirtFuncInvoker1I17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS4_,__Z85Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_Object_m_Yield_gsharedP69Boo_Lang_Boo_Lang_GenericGeneratorEnumerator_1_mscorlib_System_ObjectiP22mscorlib_System_Object,__ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object,__ZN16VirtFuncInvoker1I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi
  ,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object,__Z164mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_Object_m_Invoke_gsharedP147mscorlib_System_Collections_Generic_Dictionary_2_Transform_1_mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectU002CU0020mscorlib_System_ObjectP22mscorlib_System_ObjectS2_,__ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_CharTraitsE6InvokeEP10MethodInfoPvt,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN16VirtFuncInvoker1I27mscorlib_System_Int32TraitsS0_E6InvokeEP10MethodInfoPvi,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsE6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpan,__ZN21InterfaceFuncInvoker1I29mscorlib_System_BooleanTraits30mscorlib_System_TimeSpanTraitsE6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpan,__ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits30mscorlib_System_TimeSpanTraitsE6InvokeEP10MethodInfoPv24mscorlib_System_TimeSpan,__ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UICharInfo,__ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UICharInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UICharInfo,__ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UILineInfo,__ZN16VirtFuncInvoker1I27mscorlib_System_Int32Traits40UnityEngine_UnityEngine_UILineInfoTraitsE6InvokeEP10MethodInfoPv34UnityEngine_UnityEngine_UILineInfo,__ZN16VirtFuncInvoker1I29mscorlib_System_BooleanTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32TraitsS0_E6InvokeEP10MethodInfoPvi,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt32TraitsE6InvokeEP10MethodInfoPvj,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits28mscorlib_System_UInt16TraitsE6InvokeEP10MethodInfoPvt,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int32Traits26mscorlib_System_ByteTraitsE6InvokeEP10MethodInfoPvh,__ZN21InterfaceFuncInvoker1I28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN16VirtFuncInvoker1I26mscorlib_System_CharTraitsS0_E6InvokeEP10MethodInfoPvt,__ZN16VirtFuncInvoker1I17VoidPointerTraits29mscorlib_System_BooleanTraitsE6InvokeEP10MethodInfoPvb,__ZN21InterfaceFuncInvoker1I29mscorlib_System_BooleanTraits28mscorlib_System_ObjectTraitsE6InvokeEP10MethodInfoPvP22mscorlib_System_Object,__ZN16VirtFuncInvoker1I28mscorlib_System_ObjectTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I29mscorlib_System_BooleanTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I26mscorlib_System_ByteTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I26mscorlib_System_CharTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int16Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I27mscorlib_System_Int64Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I27mscorlib_System_SByteTraits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I28mscorlib_System_UInt16Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I28mscorlib_System_UInt32Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_
  ,__ZN21InterfaceFuncInvoker1I28mscorlib_System_UInt64Traits17VoidPointerTraitsE6InvokeEP10MethodInfoPvS5_,__ZN21InterfaceFuncInvoker1I17VoidPointerTraitsS0_E6InvokeEP10MethodInfoPvS4_,__ZN21InterfaceFuncInvoker1I28mscorlib_System_ObjectTraits27mscorlib_System_Int32TraitsE6InvokeEP10MethodInfoPvi,_newlocale__wrapper,_vasprintf,__ZNSt3__112basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeES9_S9_,__ZNSt3__112basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXsr21__is_forward_iteratorIT_EE5valueERS5_E4typeES9_S9_,_wcrtomb,_mbtowc,_mbrlen,_do_read,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128,b128
  ,b128,b128,b128,b128,b128,b128,b128,b128,b128];
  var FUNCTION_TABLE_viifff = [b129,__ZN9GfxDevice17ImmediateTexCoordEifff,__Z42UnityEngine_UnityEngine_Quaternion_m_EulerP22mscorlib_System_Objectfff,b129];
  var FUNCTION_TABLE_viiffi = [b130,__ZN5physx2Cm29ConstraintImmediateVisualizer21visualizeAngularLimitERKNS_11PxTransformEffb,__ZN5physx2Cm29ConstraintImmediateVisualizer18visualizeLimitConeERKNS_11PxTransformEffb,b130];
  var FUNCTION_TABLE_iiif = [b131,__ZN5physx7NpScene25setVisualizationParameterENS_24PxVisualizationParameter4EnumEf,__ZL50UnityAudioEffect_InternalSetFloatParameterCallbackP14FMOD_DSP_STATEif,__Z37AudioMixerDuckingSetParameterCallbackP21UnityAudioEffectStateif];
  var FUNCTION_TABLE_viiiiiid = [b132,__ZNKSt3__19money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce,__ZNKSt3__19money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe,b132];
  var FUNCTION_TABLE_viiifi = [b133,__ZN5physx2Cm29ConstraintImmediateVisualizer20visualizeLinearLimitERKNS_11PxTransformES4_fb,__ZN13GfxDeviceGLES5ClearEjRK10ColorRGBAffj,__ZL24PutAdditionalShadowLightRK4AABBRK11ActiveLightRK10Matrix4x4ffR13dynamic_arrayI16ForwardShadowMapLj4EE,__Z35Debug_CUSTOM_INTERNAL_CALL_DrawLineRK8Vector3fS1_RK10ColorRGBAffh,b133,b133,b133];
  var FUNCTION_TABLE_viffffff = [b134,__Z22Matrix4x4_CUSTOM_Orthoffffff];
  var FUNCTION_TABLE_iiiiiiiiiiiii = [b135,__Z68mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareInternalP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_iiPbS3_bbP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z401mscorlib_System_Text_UTF8Encoding_m_InternalGetChars_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_UInt32U0026_ref_mscorlib_System_UInt32U0026_ref_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectP24mscorlib_System_Byte_arriiP24mscorlib_System_Char_arriPjS5_S0_PP42mscorlib_System_Text_DecoderFallbackBufferPS2_b,__Z35mscorlib_System_DateTime_m__DoParseP22mscorlib_System_ObjectP22mscorlib_System_StringS2_S2_bP24mscorlib_System_DateTimeP30mscorlib_System_DateTimeOffsetP48mscorlib_System_Globalization_DateTimeFormatInfoibPbS9_];
  var FUNCTION_TABLE_iiiifiiiii = [b136,__ZNK5physx14NpSceneQueries7raycastERKNS_6PxVec3ES3_fRNS_13PxHitCallbackINS_12PxRaycastHitEEENS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPNS_21PxQueryFilterCallbackEPKNS_12PxQueryCacheE];
  var FUNCTION_TABLE_iiiiiiiiiiiiiii = [b137,__ZL11RenderLightRK17RenderLoopContextRK14ShadowCullDataN15QualitySettings13ShadowQualityEN16LightmapSettings19LightmapsModeLegacyERP13RenderTextureSA_iiPK18DeviceStencilStateRK10MinMaxAABBRK22DeviceMVPMatricesStateRK8Vector4fRK14LightingLayersRK11ActiveLightbRN9ShaderLab17ShaderPassContextE,__ZL19RenderLightDeferredRK17RenderLoopContextRK14ShadowCullDataN15QualitySettings13ShadowQualityEN16LightmapSettings19LightmapsModeLegacyEP13RenderTextureSA_iiPK18DeviceStencilStateRK10MinMaxAABBRK22DeviceMVPMatricesStateRK8Vector4fRK14LightingLayersRK11ActiveLightbRN9ShaderLab17ShaderPassContextE,b137];
  var FUNCTION_TABLE_viiiiiiiiiiiiiiiiiiiiiiiiiiiii = [b138,__ZN5physx28solveParallelDefaultFrictionERNS_18PxsDynamicsContextEjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS9_jPiSA_SA_SA_PNS_25PxcThresholdStreamElementEjSA_PNS_2Cm13SpatialVectorEPKPNS_11PxsBodyCoreERNSD_10BitMapBaseINS_6shdfnd9AllocatorEEEPKPNS_15PxsArticulationEjPViRNSL_5ArrayINS_24PxsConstraintBatchHeaderENSL_19ReflectionAllocatorISW_EEEES10_PPNS_12PxsRigidBodyE,__ZN5physx28solveParallelCouloumFrictionERNS_18PxsDynamicsContextEjjPNS_13PxcSolverBodyEPNS_17PxcSolverBodyDataEjjPNS_25PxcArticulationSolverDescEjPNS_23PxcSolverConstraintDescEjS9_jPiSA_SA_SA_PNS_25PxcThresholdStreamElementEjSA_PNS_2Cm13SpatialVectorEPKPNS_11PxsBodyCoreERNSD_10BitMapBaseINS_6shdfnd9AllocatorEEEPKPNS_15PxsArticulationEjPViRNSL_5ArrayINS_24PxsConstraintBatchHeaderENSL_19ReflectionAllocatorISW_EEEES10_PPNS_12PxsRigidBodyE,b138];
  var FUNCTION_TABLE_viffffffffffffiiii = [b139,__ZN5physx32PxVehicleComputeTireForceDefaultEPKvffffffffffffRfS2_S2_S2_];
  var FUNCTION_TABLE_vfi = [b140,_emscripten_glSampleCoverage__wrapper];
  var FUNCTION_TABLE_i = [b141,_GC_never_stop_func,_GC_timeout_stop_func,__ZN6il2cpp2vm9Exception20GetTypeLoadExceptionEv,__ZN6il2cpp2vm6Thread7CurrentEv,__ZN6il2cpp2vm5Image9GetCorlibEv,__ZN6il2cpp6icalls8mscorlib4Mono7Runtime14GetDisplayNameEv,__ZN6il2cpp6icalls8mscorlib6System9AppDomain12getCurDomainEv,__ZN6il2cpp6icalls8mscorlib6System9AppDomain13getRootDomainEv,__ZN6il2cpp6icalls8mscorlib6System9AppDomain18InternalGetContextEv,__ZN6il2cpp6icalls8mscorlib6System9AppDomain25InternalGetDefaultContextEv,__ZN6il2cpp6icalls8mscorlib6System8DateTime6GetNowEv,__ZN6il2cpp6icalls8mscorlib6System8DateTime16GetTimeMonotonicEv,__ZN6il2cpp6icalls8mscorlib6System11Diagnostics8Debugger19IsAttached_internalEv,__ZN6il2cpp6icalls6System6System11Diagnostics9Stopwatch12GetTimestampEv,__ZN6il2cpp6icalls8mscorlib6System11Environment21get_EmbeddingHostNameEv,__ZN6il2cpp6icalls8mscorlib6System11Environment12get_ExitCodeEv,__ZN6il2cpp6icalls8mscorlib6System11Environment22get_HasShutdownStartedEv,__ZN6il2cpp6icalls8mscorlib6System11Environment15get_MachineNameEv,__ZN6il2cpp6icalls8mscorlib6System11Environment11get_NewLineEv,__ZN6il2cpp6icalls8mscorlib6System11Environment12get_PlatformEv,__ZN6il2cpp6icalls8mscorlib6System11Environment18get_ProcessorCountEv,__ZN6il2cpp6icalls8mscorlib6System11Environment25get_SocketSecurityEnabledEv,__ZN6il2cpp6icalls8mscorlib6System11Environment13get_TickCountEv,__ZN6il2cpp6icalls8mscorlib6System11Environment12get_UserNameEv,__ZN6il2cpp6icalls8mscorlib6System11Environment18GetCommandLineArgsEv,__ZN6il2cpp6icalls8mscorlib6System11Environment27GetEnvironmentVariableNamesEv,__ZN6il2cpp6icalls8mscorlib6System11Environment24GetLogicalDrivesInternalEv,__ZN6il2cpp6icalls8mscorlib6System11Environment20GetMachineConfigPathEv
  ,__ZN6il2cpp6icalls8mscorlib6System11Environment18GetOSVersionStringEv,__ZN6il2cpp6icalls8mscorlib6System11Environment15internalGetHomeEv,__ZN6il2cpp6icalls8mscorlib6System2GC17get_MaxGenerationEv,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO29get_AltDirectorySeparatorCharEv,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO16get_ConsoleErrorEv,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO16get_ConsoleInputEv,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO17get_ConsoleOutputEv,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO26get_DirectorySeparatorCharEv,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO17get_PathSeparatorEv,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO23get_VolumeSeparatorCharEv,__ZN6il2cpp6icalls8mscorlib6System2IO4Path13get_temp_pathEv,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly18GetCallingAssemblyEv,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly16GetEntryAssemblyEv,__ZN6il2cpp6icalls8mscorlib6System10Reflection8Assembly20GetExecutingAssemblyEv,__ZN6il2cpp6icalls8mscorlib6System10Reflection10MethodBase16GetCurrentMethodEv,__ZN6il2cpp6icalls8mscorlib6System7Runtime16CompilerServices14RuntimeHelpers22get_OffsetToStringDataEv,__ZN6il2cpp6icalls8mscorlib6System7Runtime15InteropServices7Marshal17GetLastWin32ErrorEv,__ZN6il2cpp6icalls8mscorlib6System8Security12Cryptography24RNGCryptoServiceProvider7RngOpenEv,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal15WindowsIdentity15GetCurrentTokenEv,__ZN6il2cpp6icalls8mscorlib6System8Security9Principal27WindowsImpersonationContext12RevertToSelfEv,__ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager24get_CheckExecutionRightsEv,__ZN6il2cpp6icalls8mscorlib6System8Security15SecurityManager19get_SecurityEnabledEv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread22CurrentThread_internalEv,__ZN6il2cpp6icalls8mscorlib6System9Threading6Thread11GetDomainIDEv,__ZN12_GLOBAL__N_118createArticulationEv,__Z16GetMemoryManagerv,__Z15GetInputManagerv,__Z17GetManagerContextv,__Z20GetPersistentManagerv,__Z25GetBuiltinResourceManagerv
  ,__Z12GetGfxDevicev,__Z19GetReflectionProbesv,__Z22GetRenderBufferManagerv,__Z23GetCurrentRenderOptionsv,__Z17GetRenderSettingsv,__Z19GetLightmapSettingsv,__Z15GetLightManagerv,__Z19GetActiveColorSpacev,__Z23CalculateLightingLayersv,__ZN10builtintex15GetWhiteTextureEv,__Z16GetBuildSettingsv,__ZN5Unity8Material10GetDefaultEv,__Z21GetUncheckedGfxDevicev,__Z18GetLODGroupManagerv,__Z18GetITerrainManagerv,__ZN12ImageFilters19GetBlitCopyMaterialEv,__Z13GetGUIManagerv,__Z18GetQualitySettingsv,__Z9GetIUmbrav,__ZN15GlobalCallbacks3GetEv,__Z16GetRenderManagerv,__Z15GetScriptMapperv,__ZN15SkyboxGenerator19GetSixFaceSkyboxVBOEv,__ZN13RenderTexture9GetActiveEv,__Z11GetIPhysicsv,__Z19GetScriptingManagerv,__Z25GetUncheckedRealGfxDevicev,__Z11GetGUIStatev,__Z14GetTimeManagerv,__Z14IsWorldPlayingv
  ,__Z17GetCachingManagerv,__Z21GetAssetBundleManagerv,__Z13GetTagManagerv,__Z17GetPreloadManagerv,__Z16GetScreenManagerv,__ZN5Unity8GetSceneEv,__Z21GetDelayedCallManagerv,__Z9GetIAudiov,__Z24GetFixedBehaviourManagerv,__Z19GetBehaviourManagerv,__Z23GetLateBehaviourManagerv,__Z16GetUpdateManagerv,__Z18GetGUIEventManagerv,__Z14GetMonoManagerv,__ZN5Unity10GameObject17GetMessageHandlerEv,__ZN6Shader10GetDefaultEv,__Z13GetFileSystemv,__ZL18yy_get_next_bufferv,__Z7yyparsev,__Z18GetResourceManagerv,__Z27Screen_Get_Custom_PropWidthv,__Z28Screen_Get_Custom_PropHeightv,__Z38GUIUtility_CUSTOM_Internal_GetGUIDepthv,__Z26Camera_Get_Custom_PropMainv,__Z37Camera_Get_Custom_PropAllCamerasCountv,__Z38Display_CUSTOM_MultiDisplayLicenseImplv,__Z14GetDynamicsSDKv,__Z16GetDynamicsScenev,__Z10GetCookingv,__Z15GetAudioManagerv
  ,__Z15GetSoundManagerv,_rand,__Z18GetAnimationBinderv,__ZN11UnityEngine9Animation31GetGenericAnimationBindingCacheEv,__Z30GetDisableImmediateDestructionv,__ZN13RenderTexture9IsEnabledEv,__Z24GetBillboardBatchManagerv,__ZN11WindManager11GetInstanceEv,__Z17GetPlayerSettingsv,_glCreateProgram__wrapper,_glGetError__wrapper,__Z16GetRealGfxDevicev,__ZN10systeminfo19GetPhysicalMemoryMBEv,__ZN6il2cpp2vm9Exception27GetIndexOutOfRangeExceptionEv,__ZN6il2cpp2vm9Exception20GetOverflowExceptionEv,__ZNSt3__16__clocEv,__ZNSt3__16locale5__imp12make_classicEv,__ZNSt3__16locale5__imp11make_globalEv,__ZNSt3__16locale8__globalEv,___ctype_b_loc__wrapper,___ctype_toupper_loc__wrapper,___ctype_tolower_loc__wrapper,___cxa_get_globals_fast,_emscripten_glCreateProgram__wrapper,_emscripten_glGetError__wrapper,b141,b141,b141,b141,b141
  ,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141
  ,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141
  ,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141
  ,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141,b141];
  var FUNCTION_TABLE_vff = [b142,_glPolygonOffset__wrapper,_emscripten_glDepthRangef__wrapper,_emscripten_glPolygonOffset__wrapper];
  var FUNCTION_TABLE_viiifiiiii = [b143,__ZN5physx12NpBatchQuery7raycastERKNS_6PxVec3ES3_ftNS_7PxFlagsINS_9PxHitFlag4EnumEtEERKNS_17PxQueryFilterDataEPvPKNS_12PxQueryCacheE];
  var FUNCTION_TABLE_iiiiiifiiiiiiiiiiii = [b144,__Z57UnityEngine_UnityEngine_TextGenerator_m_Populate_InternalP37UnityEngine_UnityEngine_TextGeneratorP22mscorlib_System_StringP28UnityEngine_UnityEngine_Font29UnityEngine_UnityEngine_Colorifibbiiiibi31UnityEngine_UnityEngine_Vector2S6_b];
  var FUNCTION_TABLE_viiffff = [b145,__Z47UnityEngine_UnityEngine_Matrix4x4_m_PerspectiveP22mscorlib_System_Objectffff];
  var FUNCTION_TABLE_iiiiiiiii = [b146,__ZN5physx5cloth9SwFactory12createFabricEjNS0_5RangeIKjEES4_NS2_IKfEES4_S4_S6_,__ZThn4_N5physx5cloth9SwFactory12createFabricEjNS0_5RangeIKjEES4_NS2_IKfEES4_S4_S6_,__ZN16MemoryFileSystem4ReadER13FileEntryDatayyPvPy,__ZN16MemoryFileSystem5WriteER13FileEntryDatayyPvPy,__ZN20LocalFileSystemPosix4ReadER13FileEntryDatayyPvPy,__ZN20LocalFileSystemPosix5WriteER13FileEntryDatayyPvPy,__ZN13GfxDeviceGLES24CreateRenderDepthSurfaceE9TextureIDiii16TextureDimension17DepthBufferFormatj,__ZN13GfxDeviceGLES13ReadbackImageER14ImageReferenceiiiiii,__Z232mscorlib_System_String_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Boolean_mscorlib_System_Globalization_CultureInfoP22mscorlib_System_ObjectP22mscorlib_System_StringiS2_iibP41mscorlib_System_Globalization_CultureInfo,__Z60mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_CompareP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringiiS2_iii,__Z67mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesForwardP50mscorlib_Mono_Globalization_Unicode_SimpleCollatorP22mscorlib_System_StringPiiiPhbP58mscorlib_Mono_Globalization_Unicode_SimpleCollator_Context,__Z69mscorlib_Mono_Globalization_Unicode_SimpleCollator_m_MatchesPrimitiveP50mscorlib_Mono_Globalization_Unicode_SimpleCollatoriPhiiS1_ib,__Z60mscorlib_System_Globalization_CompareInfo_m_internal_compareP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_iii,__Z68mscorlib_System_Globalization_CompareInfo_m_internal_compare_managedP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_iii,__Z67mscorlib_System_Globalization_CompareInfo_m_internal_compare_switchP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_iii,__Z252mscorlib_System_Globalization_CompareInfo_m_Compare_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_String_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Globalization_CompareOptionsP41mscorlib_System_Globalization_CompareInfoP22mscorlib_System_StringiiS2_iii,__Z56mscorlib_System_Reflection_Binder_Default_m_BindToMethodP41mscorlib_System_Reflection_Binder_DefaultiP41mscorlib_System_Reflection_MethodBase_arrPP26mscorlib_System_Object_arrP48mscorlib_System_Reflection_ParameterModifier_arrP41mscorlib_System_Globalization_CultureInfoP26mscorlib_System_String_arrPP22mscorlib_System_Object,__Z283mscorlib_System_Text_ASCIIEncoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Text_EncoderFallbackBufferU0026_ref_mscorlib_System_CharU005BU005DU0026_refP34mscorlib_System_Text_ASCIIEncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arriPP42mscorlib_System_Text_EncoderFallbackBufferPS2_,__Z284mscorlib_System_Text_Latin1Encoding_m_GetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_Text_EncoderFallbackBufferU0026_ref_mscorlib_System_CharU005BU005DU0026_refP35mscorlib_System_Text_Latin1EncodingP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arriPP42mscorlib_System_Text_EncoderFallbackBufferPS2_,__Z56mscorlib_System_Text_UTF7Encoding_m_InternalGetByteCountP22mscorlib_System_ObjectP24mscorlib_System_Char_arriibibb,__Z252mscorlib_System_Text_UTF8Encoding_m_InternalGetBytes_mscorlib_System_Int32_mscorlib_System_Char_arr_arr_mscorlib_System_Int32_mscorlib_System_Int32_mscorlib_System_Byte_arr_arr_mscorlib_System_Int32_mscorlib_System_CharU0026_ref_mscorlib_System_BooleanP22mscorlib_System_ObjectP24mscorlib_System_Char_arriiP24mscorlib_System_Byte_arriPtb,__Z256mscorlib_System_Text_UTF8Encoding_m_Fallback_mscorlib_System_Int32_mscorlib_System_Object_mscorlib_System_Text_DecoderFallbackBufferU0026_ref_mscorlib_System_ByteU005BU005DU0026_ref_mscorlib_System_ByteU002A_ptr_mscorlib_System_Int64_mscorlib_System_UInt32P22mscorlib_System_ObjectS0_PP42mscorlib_System_Text_DecoderFallbackBufferPP24mscorlib_System_Byte_arrPhxj,__Z36mscorlib_System_DateTime_m_CoreParseP22mscorlib_System_ObjectP22mscorlib_System_StringS0_iP24mscorlib_System_DateTimeP30mscorlib_System_DateTimeOffsetbPP25mscorlib_System_Exception,__Z39mscorlib_System_DateTime_m__ParseNumberP22mscorlib_System_ObjectP22mscorlib_System_StringiiibbPi,__Z37mscorlib_System_DateTime_m__ParseAmPmP22mscorlib_System_ObjectP22mscorlib_System_StringiiP48mscorlib_System_Globalization_DateTimeFormatInfobPiS5_,__ZNKSt3__17codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_,__ZNKSt3__17codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_,__ZNKSt3__17codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_
  ,__ZNKSt3__17codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_,__ZNKSt3__17codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_,__ZNKSt3__17codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_,__ZNKSt3__17codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_,__ZNKSt3__17codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_,__ZN6il2cpp6icalls8mscorlib6System11Diagnostics10StackFrame14get_frame_infoEibPP22Il2CppReflectionMethodPiS8_PP12Il2CppStringS8_S8_,__ZN6il2cpp6icalls8mscorlib6System13Globalization11CompareInfo16internal_compareEP41mscorlib_System_Globalization_CompareInfoP12Il2CppStringiiS8_iii,__ZN6il2cpp6icalls8mscorlib6System2IO6MonoIO11SetFileTimeE12Il2CppIntPtrxxxPi,__ZN19RenderBufferManager13GetTempBufferEii17DepthBufferFormat19RenderTextureFormatj22RenderTextureReadWritei,__ZN18DeferredRenderLoop13RenderGBufferEP13RenderTextureRK14LightingLayersR13dynamic_arrayI16RenderObjectDataLj4EER10MinMaxAABBPS1_bb,__Z41DecompressNativeTextureFormatWithMipLevel13TextureFormatiiiPKjiiPj,__ZN14SerializedFile14InitializeReadERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEER18ResourceImageGroupjj24TransferInstructionFlagsii,__Z11ParseShaderPKcjRNSt3__16vectorI4PPtrI6ShaderENS1_9allocatorIS5_EEEEbPPN9ShaderLab12ParserShaderER12ShaderErrors17GfxDeviceRendererPS4_,__ZN4FMOD6System13setFileSystemEPF11FMOD_RESULTPKciPjPPvS6_EPFS1_S5_S5_EPFS1_S5_S5_jS4_S5_EPFS1_S5_jS5_EPFS1_P18FMOD_ASYNCREADINFOS5_ESA_i,__Z22PackTextureAtlasSimpleP9Texture2DiiPS0_P5RectTIfEibb,__Z27AddMeshIntermediateRendererRK10Matrix4x4fP4Mesh4PPtrIN5Unity8MaterialEEibbiP6Camera,__ZN20TextRenderingPrivate21GetFontMetadataPresetERKNSt3__112basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEERS6_S9_RjSA_iPiPb,__ZN16VirtFuncInvoker6I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S1_S0_S0_E6InvokeEP10MethodInfoPvS5_iS5_iS5_S5_,__ZN16VirtFuncInvoker6I17VoidPointerTraitsS0_27mscorlib_System_Int32TraitsS0_S0_S0_S0_E6InvokeEP10MethodInfoPvS5_iS5_S5_S5_S5_,b146,b146,b146,b146,b146,b146,b146,b146,b146,b146,b146
  ,b146,b146,b146,b146,b146];
  var FUNCTION_TABLE_viffffi = [b147,__ZN9GfxDevice14ImmediateShapeEffffNS_18ImmediateShapeTypeE,__Z46UnityEngine_UnityEngine_GUILayoutEntry_m__ctorP38UnityEngine_UnityEngine_GUILayoutEntryffffP32UnityEngine_UnityEngine_GUIStyle,b147];

    return { _SetFullscreen: _SetFullscreen, _strlen: _strlen, _main: _main, _memset: _memset, _SendMessageFloat: _SendMessageFloat, _bitshift64Lshr: _bitshift64Lshr, _calloc: _calloc, _bitshift64Shl: _bitshift64Shl, ___cxa_is_pointer_type: ___cxa_is_pointer_type, _strncpy: _strncpy, _bitshift64Ashr: _bitshift64Ashr, _llvm_cttz_i32: _llvm_cttz_i32, _memcpy: _memcpy, _i64Subtract: _i64Subtract, _realloc: _realloc, _i64Add: _i64Add, _saveSetjmp: _saveSetjmp, _llvm_bswap_i32: _llvm_bswap_i32, _SendMessageString: _SendMessageString, _testSetjmp: _testSetjmp, ___cxa_can_catch: ___cxa_can_catch, _free: _free, _memmove: _memmove, _strstr: _strstr, _malloc: _malloc, _llvm_ctlz_i32: _llvm_ctlz_i32, _strcpy: _strcpy, _SendMessage: _SendMessage, __GLOBAL__I_a1261: __GLOBAL__I_a1261, __GLOBAL__I_a1253: __GLOBAL__I_a1253, __GLOBAL__I_a4171: __GLOBAL__I_a4171, __GLOBAL__I_a4182: __GLOBAL__I_a4182, __GLOBAL__I_a4186: __GLOBAL__I_a4186, __GLOBAL__I_a4208: __GLOBAL__I_a4208, __GLOBAL__I_a4557: __GLOBAL__I_a4557, __GLOBAL__I_a6522: __GLOBAL__I_a6522, __GLOBAL__I_a1306: __GLOBAL__I_a1306, __GLOBAL__I_a1532: __GLOBAL__I_a1532, __GLOBAL__I_a1629: __GLOBAL__I_a1629, __GLOBAL__I_a1638: __GLOBAL__I_a1638, __GLOBAL__I_a1651: __GLOBAL__I_a1651, __GLOBAL__I_a1667: __GLOBAL__I_a1667, __GLOBAL__I_a1688: __GLOBAL__I_a1688, __GLOBAL__I_a1817: __GLOBAL__I_a1817, __GLOBAL__I_a1915: __GLOBAL__I_a1915, __GLOBAL__I_a1998: __GLOBAL__I_a1998, __GLOBAL__I_a2062: __GLOBAL__I_a2062, __GLOBAL__I_a2431: __GLOBAL__I_a2431, __GLOBAL__I_a2482: __GLOBAL__I_a2482, __GLOBAL__I_a2517: __GLOBAL__I_a2517, __GLOBAL__I_a2967: __GLOBAL__I_a2967, __GLOBAL__I_a3258: __GLOBAL__I_a3258, __GLOBAL__I_a3392: __GLOBAL__I_a3392, __GLOBAL__I_a3547: __GLOBAL__I_a3547, __GLOBAL__I_a3708: __GLOBAL__I_a3708, __GLOBAL__I_a4056: __GLOBAL__I_a4056, __GLOBAL__I_a4778: __GLOBAL__I_a4778, __GLOBAL__I_a6056: __GLOBAL__I_a6056, __GLOBAL__I_a6584: __GLOBAL__I_a6584, __GLOBAL__I_a8226: __GLOBAL__I_a8226, __GLOBAL__I_a8687: __GLOBAL__I_a8687, __GLOBAL__I_a9384: __GLOBAL__I_a9384, __GLOBAL__I_a11687: __GLOBAL__I_a11687, __GLOBAL__I_a11737: __GLOBAL__I_a11737, __GLOBAL__I_a13766: __GLOBAL__I_a13766, __GLOBAL__I_a18997: __GLOBAL__I_a18997, __GLOBAL__I_a19751: __GLOBAL__I_a19751, __GLOBAL__I_a19771: __GLOBAL__I_a19771, __GLOBAL__I_a19829: __GLOBAL__I_a19829, __GLOBAL__I_a20005: __GLOBAL__I_a20005, __GLOBAL__I_a20041: __GLOBAL__I_a20041, __GLOBAL__I_a20087: __GLOBAL__I_a20087, __GLOBAL__I_a21124: __GLOBAL__I_a21124, __GLOBAL__I_a21804: __GLOBAL__I_a21804, __GLOBAL__I_a1263: __GLOBAL__I_a1263, __GLOBAL__I_a5: __GLOBAL__I_a5, __GLOBAL__I_a9: __GLOBAL__I_a9, __GLOBAL__I_a14: __GLOBAL__I_a14, __GLOBAL__I_a23365: __GLOBAL__I_a23365, __GLOBAL__I_a23371: __GLOBAL__I_a23371, __GLOBAL__I_a23378: __GLOBAL__I_a23378, __GLOBAL__I_a23385: __GLOBAL__I_a23385, __GLOBAL__I_a23391: __GLOBAL__I_a23391, __GLOBAL__I_a1496: __GLOBAL__I_a1496, runPostSets: runPostSets, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, setThrew: setThrew, setTempRet0: setTempRet0, getTempRet0: getTempRet0, dynCall_fiff: dynCall_fiff, dynCall_iiiiiii: dynCall_iiiiiii, dynCall_vifiiiiiiiiiiiiiiiiiii: dynCall_vifiiiiiiiiiiiiiiiiiii, dynCall_viiiiiiiiiii: dynCall_viiiiiiiiiii, dynCall_fff: dynCall_fff, dynCall_iidi: dynCall_iidi, dynCall_fiiiiiifiiiiiif: dynCall_fiiiiiifiiiiiif, dynCall_iiiiifiif: dynCall_iiiiifiif, dynCall_viiiiiffi: dynCall_viiiiiffi, dynCall_iiiiiiiiiiii: dynCall_iiiiiiiiiiii, dynCall_fiffifff: dynCall_fiffifff, dynCall_fif: dynCall_fif, dynCall_viiiiiiiiiiiiiii: dynCall_viiiiiiiiiiiiiii, dynCall_fid: dynCall_fid, dynCall_fii: dynCall_fii, dynCall_ddii: dynCall_ddii, dynCall_di: dynCall_di, dynCall_dd: dynCall_dd, dynCall_viff: dynCall_viff, dynCall_vffi: dynCall_vffi, dynCall_viiiifiii: dynCall_viiiifiii, dynCall_viffff: dynCall_viffff, dynCall_d: dynCall_d, dynCall_didd: dynCall_didd, dynCall_viiiiifffiiiii: dynCall_viiiiifffiiiii, dynCall_iiiiifffiiiii: dynCall_iiiiifffiiiii, dynCall_dii: dynCall_dii, dynCall_did: dynCall_did, dynCall_dif: dynCall_dif, dynCall_iifii: dynCall_iifii, dynCall_iiiiiiiiii: dynCall_iiiiiiiiii, dynCall_vdddddd: dynCall_vdddddd, dynCall_fiffiff: dynCall_fiffiff, dynCall_iiiiiiiiiiiiffffii: dynCall_iiiiiiiiiiiiffffii, dynCall_vdd: dynCall_vdd, dynCall_viiifiiii: dynCall_viiifiiii, dynCall_iiiif: dynCall_iiiif, dynCall_iiiiiiii: dynCall_iiiiiiii, dynCall_iiiiiifffiiiii: dynCall_iiiiiifffiiiii, dynCall_vifiiiiiiiiiiiii: dynCall_vifiiiiiiiiiiiii, dynCall_iiiii: dynCall_iiiii, dynCall_iiifii: dynCall_iiifii, dynCall_fifff: dynCall_fifff, dynCall_viffi: dynCall_viffi, dynCall_viiiiid: dynCall_viiiiid, dynCall_iiiifiiii: dynCall_iiiifiiii, dynCall_vifi: dynCall_vifi, dynCall_vifff: dynCall_vifff, dynCall_viiiiii: dynCall_viiiiii, dynCall_ddd: dynCall_ddd, dynCall_fiii: dynCall_fiii, dynCall_iifff: dynCall_iifff, dynCall_fiif: dynCall_fiif, dynCall_iiiiiifiiiiiiiiiffffi: dynCall_iiiiiifiiiiiiiiiffffi, dynCall_iiiiifiiiif: dynCall_iiiiifiiiif, dynCall_viiffffff: dynCall_viiffffff, dynCall_viiiiiiiiii: dynCall_viiiiiiiiii, dynCall_diii: dynCall_diii, dynCall_fiiii: dynCall_fiiii, dynCall_iiiiii: dynCall_iiiiii, dynCall_viiiiifiiiiiiiiiiiii: dynCall_viiiiifiiiiiiiiiiiii, dynCall_viiiff: dynCall_viiiff, dynCall_iiiiiifiif: dynCall_iiiiiifiif, dynCall_viiii: dynCall_viiii, dynCall_viiiii: dynCall_viiiii, dynCall_iifffi: dynCall_iifffi, dynCall_vif: dynCall_vif, dynCall_vid: dynCall_vid, dynCall_iiidi: dynCall_iiidi, dynCall_viiidii: dynCall_viiidii, dynCall_vii: dynCall_vii, dynCall_iiffff: dynCall_iiffff, dynCall_viiiif: dynCall_viiiif, dynCall_viifii: dynCall_viifii, dynCall_fi: dynCall_fi, dynCall_viidi: dynCall_viidi, dynCall_viifif: dynCall_viifif, dynCall_vf: dynCall_vf, dynCall_fiiiiiiiifiiiif: dynCall_fiiiiiiiifiiiif, dynCall_vi: dynCall_vi, dynCall_vifiii: dynCall_vifiii, dynCall_iiiiiiifiiiiiiiiiffffi: dynCall_iiiiiiifiiiiiiiiiffffi, dynCall_diiii: dynCall_diiii, dynCall_iiifiiii: dynCall_iiifiiii, dynCall_viiiiiiiiiiiii: dynCall_viiiiiiiiiiiii, dynCall_iiiiiiiiiiffffii: dynCall_iiiiiiiiiiffffii, dynCall_viiiiiiii: dynCall_viiiiiiii, dynCall_iid: dynCall_iid, dynCall_iif: dynCall_iif, dynCall_vifiiii: dynCall_vifiiii, dynCall_viiiiiii: dynCall_viiiiiii, dynCall_vifiiiiiiiiiiiiiiiiii: dynCall_vifiiiiiiiiiiiiiiiiii, dynCall_viiiiiiiii: dynCall_viiiiiiiii, dynCall_viiiiiif: dynCall_viiiiiif, dynCall_iii: dynCall_iii, dynCall_iiiifii: dynCall_iiiifii, dynCall_f: dynCall_f, dynCall_vffff: dynCall_vffff, dynCall_vifffi: dynCall_vifffi, dynCall_viiiifiiiiif: dynCall_viiiifiiiiif, dynCall_viii: dynCall_viii, dynCall_viiiifi: dynCall_viiiifi, dynCall_v: dynCall_v, dynCall_viid: dynCall_viid, dynCall_viiiiff: dynCall_viiiiff, dynCall_viif: dynCall_viif, dynCall_fiffif: dynCall_fiffif, dynCall_iiiifi: dynCall_iiiifi, dynCall_vd: dynCall_vd, dynCall_iiffffff: dynCall_iiffffff, dynCall_viiiiiiiifiiifiii: dynCall_viiiiiiiifiiifiii, dynCall_fiiff: dynCall_fiiff, dynCall_viiifffii: dynCall_viiifffii, dynCall_iiiiiiiiiii: dynCall_iiiiiiiiiii, dynCall_ii: dynCall_ii, dynCall_iiff: dynCall_iiff, dynCall_viifi: dynCall_viifi, dynCall_iiiiifiiiiii: dynCall_iiiiifiiiiii, dynCall_iiiiifiiiiif: dynCall_iiiiifiiiiif, dynCall_viiff: dynCall_viiff, dynCall_viiiiiiiiiiii: dynCall_viiiiiiiiiiii, dynCall_iifi: dynCall_iifi, dynCall_viiif: dynCall_viiif, dynCall_viiiiifiiii: dynCall_viiiiifiiii, dynCall_viiiffii: dynCall_viiiffii, dynCall_vifiiiiiiiiiiiiiiiiiiiiiii: dynCall_vifiiiiiiiiiiiiiiiiiiiiiii, dynCall_iifiiiii: dynCall_iifiiiii, dynCall_iiifi: dynCall_iiifi, dynCall_iiii: dynCall_iiii, dynCall_viifff: dynCall_viifff, dynCall_viiffi: dynCall_viiffi, dynCall_iiif: dynCall_iiif, dynCall_viiiiiid: dynCall_viiiiiid, dynCall_viiifi: dynCall_viiifi, dynCall_viffffff: dynCall_viffffff, dynCall_iiiiiiiiiiiii: dynCall_iiiiiiiiiiiii, dynCall_iiiifiiiii: dynCall_iiiifiiiii, dynCall_iiiiiiiiiiiiiii: dynCall_iiiiiiiiiiiiiii, dynCall_viiiiiiiiiiiiiiiiiiiiiiiiiiiii: dynCall_viiiiiiiiiiiiiiiiiiiiiiiiiiiii, dynCall_viffffffffffffiiii: dynCall_viffffffffffffiiii, dynCall_vfi: dynCall_vfi, dynCall_i: dynCall_i, dynCall_vff: dynCall_vff, dynCall_viiifiiiii: dynCall_viiifiiiii, dynCall_iiiiiifiiiiiiiiiiii: dynCall_iiiiiifiiiiiiiiiiii, dynCall_viiffff: dynCall_viiffff, dynCall_iiiiiiiii: dynCall_iiiiiiiii, dynCall_viffffi: dynCall_viffffi };
  })
  // EMSCRIPTEN_END_ASM
  ({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "min": Math_min, "invoke_fiff": invoke_fiff, "invoke_iiiiiii": invoke_iiiiiii, "invoke_vifiiiiiiiiiiiiiiiiiii": invoke_vifiiiiiiiiiiiiiiiiiii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_fff": invoke_fff, "invoke_iidi": invoke_iidi, "invoke_fiiiiiifiiiiiif": invoke_fiiiiiifiiiiiif, "invoke_iiiiifiif": invoke_iiiiifiif, "invoke_viiiiiffi": invoke_viiiiiffi, "invoke_iiiiiiiiiiii": invoke_iiiiiiiiiiii, "invoke_fiffifff": invoke_fiffifff, "invoke_fif": invoke_fif, "invoke_viiiiiiiiiiiiiii": invoke_viiiiiiiiiiiiiii, "invoke_fid": invoke_fid, "invoke_fii": invoke_fii, "invoke_ddii": invoke_ddii, "invoke_di": invoke_di, "invoke_dd": invoke_dd, "invoke_viff": invoke_viff, "invoke_vffi": invoke_vffi, "invoke_viiiifiii": invoke_viiiifiii, "invoke_viffff": invoke_viffff, "invoke_d": invoke_d, "invoke_didd": invoke_didd, "invoke_viiiiifffiiiii": invoke_viiiiifffiiiii, "invoke_iiiiifffiiiii": invoke_iiiiifffiiiii, "invoke_dii": invoke_dii, "invoke_did": invoke_did, "invoke_dif": invoke_dif, "invoke_iifii": invoke_iifii, "invoke_iiiiiiiiii": invoke_iiiiiiiiii, "invoke_vdddddd": invoke_vdddddd, "invoke_fiffiff": invoke_fiffiff, "invoke_iiiiiiiiiiiiffffii": invoke_iiiiiiiiiiiiffffii, "invoke_vdd": invoke_vdd, "invoke_viiifiiii": invoke_viiifiiii, "invoke_iiiif": invoke_iiiif, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_iiiiiifffiiiii": invoke_iiiiiifffiiiii, "invoke_vifiiiiiiiiiiiii": invoke_vifiiiiiiiiiiiii, "invoke_iiiii": invoke_iiiii, "invoke_iiifii": invoke_iiifii, "invoke_fifff": invoke_fifff, "invoke_viffi": invoke_viffi, "invoke_viiiiid": invoke_viiiiid, "invoke_iiiifiiii": invoke_iiiifiiii, "invoke_vifi": invoke_vifi, "invoke_vifff": invoke_vifff, "invoke_viiiiii": invoke_viiiiii, "invoke_ddd": invoke_ddd, "invoke_fiii": invoke_fiii, "invoke_iifff": invoke_iifff, "invoke_fiif": invoke_fiif, "invoke_iiiiiifiiiiiiiiiffffi": invoke_iiiiiifiiiiiiiiiffffi, "invoke_iiiiifiiiif": invoke_iiiiifiiiif, "invoke_viiffffff": invoke_viiffffff, "invoke_viiiiiiiiii": invoke_viiiiiiiiii, "invoke_diii": invoke_diii, "invoke_fiiii": invoke_fiiii, "invoke_iiiiii": invoke_iiiiii, "invoke_viiiiifiiiiiiiiiiiii": invoke_viiiiifiiiiiiiiiiiii, "invoke_viiiff": invoke_viiiff, "invoke_iiiiiifiif": invoke_iiiiiifiif, "invoke_viiii": invoke_viiii, "invoke_viiiii": invoke_viiiii, "invoke_iifffi": invoke_iifffi, "invoke_vif": invoke_vif, "invoke_vid": invoke_vid, "invoke_iiidi": invoke_iiidi, "invoke_viiidii": invoke_viiidii, "invoke_vii": invoke_vii, "invoke_iiffff": invoke_iiffff, "invoke_viiiif": invoke_viiiif, "invoke_viifii": invoke_viifii, "invoke_fi": invoke_fi, "invoke_viidi": invoke_viidi, "invoke_viifif": invoke_viifif, "invoke_vf": invoke_vf, "invoke_fiiiiiiiifiiiif": invoke_fiiiiiiiifiiiif, "invoke_vi": invoke_vi, "invoke_vifiii": invoke_vifiii, "invoke_iiiiiiifiiiiiiiiiffffi": invoke_iiiiiiifiiiiiiiiiffffi, "invoke_diiii": invoke_diiii, "invoke_iiifiiii": invoke_iiifiiii, "invoke_viiiiiiiiiiiii": invoke_viiiiiiiiiiiii, "invoke_iiiiiiiiiiffffii": invoke_iiiiiiiiiiffffii, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_iid": invoke_iid, "invoke_iif": invoke_iif, "invoke_vifiiii": invoke_vifiiii, "invoke_viiiiiii": invoke_viiiiiii, "invoke_vifiiiiiiiiiiiiiiiiii": invoke_vifiiiiiiiiiiiiiiiiii, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_viiiiiif": invoke_viiiiiif, "invoke_iii": invoke_iii, "invoke_iiiifii": invoke_iiiifii, "invoke_f": invoke_f, "invoke_vffff": invoke_vffff, "invoke_vifffi": invoke_vifffi, "invoke_viiiifiiiiif": invoke_viiiifiiiiif, "invoke_viii": invoke_viii, "invoke_viiiifi": invoke_viiiifi, "invoke_v": invoke_v, "invoke_viid": invoke_viid, "invoke_viiiiff": invoke_viiiiff, "invoke_viif": invoke_viif, "invoke_fiffif": invoke_fiffif, "invoke_iiiifi": invoke_iiiifi, "invoke_vd": invoke_vd, "invoke_iiffffff": invoke_iiffffff, "invoke_viiiiiiiifiiifiii": invoke_viiiiiiiifiiifiii, "invoke_fiiff": invoke_fiiff, "invoke_viiifffii": invoke_viiifffii, "invoke_iiiiiiiiiii": invoke_iiiiiiiiiii, "invoke_ii": invoke_ii, "invoke_iiff": invoke_iiff, "invoke_viifi": invoke_viifi, "invoke_iiiiifiiiiii": invoke_iiiiifiiiiii, "invoke_iiiiifiiiiif": invoke_iiiiifiiiiif, "invoke_viiff": invoke_viiff, "invoke_viiiiiiiiiiii": invoke_viiiiiiiiiiii, "invoke_iifi": invoke_iifi, "invoke_viiif": invoke_viiif, "invoke_viiiiifiiii": invoke_viiiiifiiii, "invoke_viiiffii": invoke_viiiffii, "invoke_vifiiiiiiiiiiiiiiiiiiiiiii": invoke_vifiiiiiiiiiiiiiiiiiiiiiii, "invoke_iifiiiii": invoke_iifiiiii, "invoke_iiifi": invoke_iiifi, "invoke_iiii": invoke_iiii, "invoke_viifff": invoke_viifff, "invoke_viiffi": invoke_viiffi, "invoke_iiif": invoke_iiif, "invoke_viiiiiid": invoke_viiiiiid, "invoke_viiifi": invoke_viiifi, "invoke_viffffff": invoke_viffffff, "invoke_iiiiiiiiiiiii": invoke_iiiiiiiiiiiii, "invoke_iiiifiiiii": invoke_iiiifiiiii, "invoke_iiiiiiiiiiiiiii": invoke_iiiiiiiiiiiiiii, "invoke_viiiiiiiiiiiiiiiiiiiiiiiiiiiii": invoke_viiiiiiiiiiiiiiiiiiiiiiiiiiiii, "invoke_viffffffffffffiiii": invoke_viffffffffffffiiii, "invoke_vfi": invoke_vfi, "invoke_i": invoke_i, "invoke_vff": invoke_vff, "invoke_viiifiiiii": invoke_viiifiiiii, "invoke_iiiiiifiiiiiiiiiiii": invoke_iiiiiifiiiiiiiiiiii, "invoke_viiffff": invoke_viiffff, "invoke_iiiiiiiii": invoke_iiiiiiiii, "invoke_viffffi": invoke_viffffi, "_emscripten_glGetTexParameterfv": _emscripten_glGetTexParameterfv, "_log2f": _log2f, "_glClearStencil": _glClearStencil, "_asinf": _asinf, "_emscripten_glBlendFuncSeparate": _emscripten_glBlendFuncSeparate, "_emscripten_glGetIntegerv": _emscripten_glGetIntegerv, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glVertexAttrib4f": _glVertexAttrib4f, "_emscripten_glDepthFunc": _emscripten_glDepthFunc, "_emscripten_webgl_create_context": _emscripten_webgl_create_context, "_pthread_key_delete": _pthread_key_delete, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_pthread_attr_init": _pthread_attr_init, "_ceilf": _ceilf, "_emscripten_glUniform1f": _emscripten_glUniform1f, "_Mix_PlayMusic": _Mix_PlayMusic, "_emscripten_glUniform1i": _emscripten_glUniform1i, "_puts": _puts, "_emscripten_glIsProgram": _emscripten_glIsProgram, "_ftell": _ftell, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_gmtime_r": _gmtime_r, "___cxa_rethrow": ___cxa_rethrow, "_emscripten_glTexParameteriv": _emscripten_glTexParameteriv, "_catclose": _catclose, "_emscripten_glAttachShader": _emscripten_glAttachShader, "_emscripten_get_now_is_monotonic": _emscripten_get_now_is_monotonic, "_pthread_cond_timedwait": _pthread_cond_timedwait, "_emscripten_glTexParameterfv": _emscripten_glTexParameterfv, "_pthread_attr_destroy": _pthread_attr_destroy, "_emscripten_glUniformMatrix2fv": _emscripten_glUniformMatrix2fv, "_SDL_GetTicks": _SDL_GetTicks, "_emscripten_glDrawArraysInstanced": _emscripten_glDrawArraysInstanced, "_JS_Sound_SetListenerVelocity": _JS_Sound_SetListenerVelocity, "_glDepthMask": _glDepthMask, "_strerror_r": _strerror_r, "_glViewport": _glViewport, "_newlocale": _newlocale, "_emscripten_glFlush": _emscripten_glFlush, "___cxa_call_unexpected": ___cxa_call_unexpected, "_nanosleep": _nanosleep, "_pthread_once": _pthread_once, "_fopen": _fopen, "_JS_Sound_SetListenerOrientation": _JS_Sound_SetListenerOrientation, "_emscripten_glGetAttribLocation": _emscripten_glGetAttribLocation, "_stat": _stat, "_glAttachShader": _glAttachShader, "_emscripten_glTexCoordPointer": _emscripten_glTexCoordPointer, "__addDays": __addDays, "_emscripten_glLoadMatrixf": _emscripten_glLoadMatrixf, "_emscripten_glStencilFuncSeparate": _emscripten_glStencilFuncSeparate, "_emscripten_glVertexAttrib3f": _emscripten_glVertexAttrib3f, "_pthread_mutex_lock": _pthread_mutex_lock, "___cxa_guard_abort": ___cxa_guard_abort, "_readdir_r": _readdir_r, "_glCullFace": _glCullFace, "_getcwd": _getcwd, "_lseek": _lseek, "_pthread_mutex_trylock": _pthread_mutex_trylock, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_emscripten_glUniform1iv": _emscripten_glUniform1iv, "_cosf": _cosf, "_glClearColor": _glClearColor, "_glFinish": _glFinish, "_emscripten_glUniform3iv": _emscripten_glUniform3iv, "_emscripten_glGetBufferParameteriv": _emscripten_glGetBufferParameteriv, "_emscripten_glVertexAttrib4fv": _emscripten_glVertexAttrib4fv, "_glGetTexParameteriv": _glGetTexParameteriv, "_pthread_getspecific": _pthread_getspecific, "_glDrawArrays": _glDrawArrays, "_glCreateShader": _glCreateShader, "_glGetError": _glGetError, "_emscripten_glDepthRange": _emscripten_glDepthRange, "_floorf": _floorf, "_sqrtf": _sqrtf, "_glActiveTexture": _glActiveTexture, "_SDL_NumJoysticks": _SDL_NumJoysticks, "_emscripten_glCopyTexSubImage2D": _emscripten_glCopyTexSubImage2D, "_emscripten_glCopyTexImage2D": _emscripten_glCopyTexImage2D, "_emscripten_glFramebufferTexture2D": _emscripten_glFramebufferTexture2D, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "_emscripten_glStencilFunc": _emscripten_glStencilFunc, "_glDeleteBuffers": _glDeleteBuffers, "_localtime": _localtime, "_sin": _sin, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_emscripten_glRenderbufferStorage": _emscripten_glRenderbufferStorage, "_emscripten_glVertexPointer": _emscripten_glVertexPointer, "_fmin": _fmin, "_JS_SystemInfo_GetHeight": _JS_SystemInfo_GetHeight, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_glLinkProgram": _glLinkProgram, "_emscripten_glGetUniformfv": _emscripten_glGetUniformfv, "_SDL_FreeRW": _SDL_FreeRW, "_log10": _log10, "_fileno": _fileno, "_Mix_LoadWAV_RW": _Mix_LoadWAV_RW, "_emscripten_glStencilOp": _emscripten_glStencilOp, "_emscripten_glBlendEquation": _emscripten_glBlendEquation, "___ctype_tolower_loc": ___ctype_tolower_loc, "_pthread_self": _pthread_self, "_emscripten_glVertexAttrib1fv": _emscripten_glVertexAttrib1fv, "_emscripten_glBufferSubData": _emscripten_glBufferSubData, "_emscripten_glGetProgramInfoLog": _emscripten_glGetProgramInfoLog, "_emscripten_glUniform4fv": _emscripten_glUniform4fv, "_fgetc": _fgetc, "___cxa_throw": ___cxa_throw, "_glUniform1iv": _glUniform1iv, "_emscripten_glUniform2fv": _emscripten_glUniform2fv, "_emscripten_glBindBuffer": _emscripten_glBindBuffer, "_emscripten_glGetFloatv": _emscripten_glGetFloatv, "_pthread_mutex_init": _pthread_mutex_init, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_glTexSubImage2D": _glTexSubImage2D, "_glUseProgram": _glUseProgram, "_glUniformMatrix3fv": _glUniformMatrix3fv, "_exp": _exp, "_SDL_StartTextInput": _SDL_StartTextInput, "_emscripten_glCullFace": _emscripten_glCullFace, "_emscripten_glStencilMaskSeparate": _emscripten_glStencilMaskSeparate, "_emscripten_glUniform3fv": _emscripten_glUniform3fv, "_glBindBuffer": _glBindBuffer, "_emscripten_request_fullscreen": _emscripten_request_fullscreen, "_emscripten_webgl_make_context_current": _emscripten_webgl_make_context_current, "_JS_Sound_Play": _JS_Sound_Play, "_rename": _rename, "_emscripten_glDisableVertexAttribArray": _emscripten_glDisableVertexAttribArray, "_TTF_RenderText_Solid": _TTF_RenderText_Solid, "_glPolygonOffset": _glPolygonOffset, "_emscripten_webgl_get_current_context": _emscripten_webgl_get_current_context, "_clock": _clock, "_SDL_InitSubSystem": _SDL_InitSubSystem, "_JS_Sound_SetListenerPosition": _JS_Sound_SetListenerPosition, "_emscripten_glGetBooleanv": _emscripten_glGetBooleanv, "_emscripten_glVertexAttribDivisor": _emscripten_glVertexAttribDivisor, "_readdir": _readdir, "_tanh": _tanh, "_emscripten_glGenBuffers": _emscripten_glGenBuffers, "_emscripten_glDeleteObjectARB": _emscripten_glDeleteObjectARB, "_emscripten_glUniform4f": _emscripten_glUniform4f, "_emscripten_glGetShaderPrecisionFormat": _emscripten_glGetShaderPrecisionFormat, "_write": _write, "_fsync": _fsync, "_emscripten_glIsEnabled": _emscripten_glIsEnabled, "_SDL_JoystickOpen": _SDL_JoystickOpen, "_JS_SystemInfo_HasFullscreen": _JS_SystemInfo_HasFullscreen, "_pthread_cond_destroy": _pthread_cond_destroy, "_JS_Sound_Set3D": _JS_Sound_Set3D, "_emscripten_glGetActiveAttrib": _emscripten_glGetActiveAttrib, "_glGenerateMipmap": _glGenerateMipmap, "_JS_Sound_SetPosition": _JS_Sound_SetPosition, "_uselocale": _uselocale, "_truncf": _truncf, "_log2": _log2, "_setlocale": _setlocale, "___cxa_free_exception": ___cxa_free_exception, "_atan2f": _atan2f, "___cxa_find_matching_catch": ___cxa_find_matching_catch, "_JS_SystemInfo_HasCursorLock": _JS_SystemInfo_HasCursorLock, "_emscripten_glClear": _emscripten_glClear, "_glDrawElements": _glDrawElements, "___cxa_guard_release": ___cxa_guard_release, "_glBufferSubData": _glBufferSubData, "_emscripten_glValidateProgram": _emscripten_glValidateProgram, "_emscripten_glUniform4iv": _emscripten_glUniform4iv, "___setErrNo": ___setErrNo, "_glStencilOpSeparate": _glStencilOpSeparate, "_emscripten_glVertexAttrib2f": _emscripten_glVertexAttrib2f, "___resumeException": ___resumeException, "_asin": _asin, "_mktime": _mktime, "_emscripten_glGetError": _emscripten_glGetError, "_putchar": _putchar, "_emscripten_glBufferData": _emscripten_glBufferData, "_glBlendFuncSeparate": _glBlendFuncSeparate, "_glGenTextures": _glGenTextures, "_glGetIntegerv": _glGetIntegerv, "_glUniform3iv": _glUniform3iv, "_emscripten_glClearStencil": _emscripten_glClearStencil, "_JS_Sound_Stop": _JS_Sound_Stop, "_emscripten_set_mouseup_callback": _emscripten_set_mouseup_callback, "_emscripten_glFinish": _emscripten_glFinish, "_emscripten_glClearDepth": _emscripten_glClearDepth, "_emscripten_glUniform1fv": _emscripten_glUniform1fv, "_fwrite": _fwrite, "_glBindFramebuffer": _glBindFramebuffer, "_emscripten_glStencilOpSeparate": _emscripten_glStencilOpSeparate, "_glGenFramebuffers": _glGenFramebuffers, "_SDL_UpperBlitScaled": _SDL_UpperBlitScaled, "_emscripten_glGetActiveUniform": _emscripten_glGetActiveUniform, "_emscripten_glUniform4i": _emscripten_glUniform4i, "_glUniform1fv": _glUniform1fv, "_llvm_pow_f64": _llvm_pow_f64, "_trunc": _trunc, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_JS_FileSystem_Sync": _JS_FileSystem_Sync, "_IMG_Load": _IMG_Load, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "_vfprintf": _vfprintf, "___ctype_b_loc": ___ctype_b_loc, "_emscripten_glBlendFunc": _emscripten_glBlendFunc, "_floor": _floor, "_emscripten_glStencilMask": _emscripten_glStencilMask, "_modff": _modff, "_localtime_r": _localtime_r, "_glBindTexture": _glBindTexture, "_fabsf": _fabsf, "_readlink": _readlink, "_strftime": _strftime, "_sem_wait": _sem_wait, "_emscripten_glGetVertexAttribiv": _emscripten_glGetVertexAttribiv, "_glReadPixels": _glReadPixels, "_fseek": _fseek, "_glGetActiveAttrib": _glGetActiveAttrib, "_emscripten_glUniformMatrix3fv": _emscripten_glUniformMatrix3fv, "_glUniform2iv": _glUniform2iv, "_pthread_key_create": _pthread_key_create, "_emscripten_glDeleteFramebuffers": _emscripten_glDeleteFramebuffers, "_recv": _recv, "_glFrontFace": _glFrontFace, "_emscripten_glGetObjectParameterivARB": _emscripten_glGetObjectParameterivARB, "_JS_SystemInfo_HasWebGL": _JS_SystemInfo_HasWebGL, "_emscripten_glGetUniformiv": _emscripten_glGetUniformiv, "_ceil": _ceil, "_exp2f": _exp2f, "_emscripten_glVertexAttrib2fv": _emscripten_glVertexAttrib2fv, "_copysignl": _copysignl, "_glGetProgramiv": _glGetProgramiv, "_glScissor": _glScissor, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_fabs": _fabs, "_difftime": _difftime, "_emscripten_glTexSubImage2D": _emscripten_glTexSubImage2D, "_ungetc": _ungetc, "_emscripten_glDeleteTextures": _emscripten_glDeleteTextures, "_fflush": _fflush, "_emscripten_exit_fullscreen": _emscripten_exit_fullscreen, "_strftime_l": _strftime_l, "_glGetShaderiv": _glGetShaderiv, "_llvm_eh_typeid_for": _llvm_eh_typeid_for, "_SDL_PollEvent": _SDL_PollEvent, "_catgets": _catgets, "_glUniform4fv": _glUniform4fv, "_glRenderbufferStorage": _glRenderbufferStorage, "_sem_post": _sem_post, "_IMG_Load_RW": _IMG_Load_RW, "_glBindAttribLocation": _glBindAttribLocation, "_emscripten_glColorMask": _emscripten_glColorMask, "_emscripten_webgl_destroy_context": _emscripten_webgl_destroy_context, "_pthread_mutex_unlock": _pthread_mutex_unlock, "_emscripten_glBindTexture": _emscripten_glBindTexture, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glUniform4iv": _glUniform4iv, "_emscripten_set_main_loop": _emscripten_set_main_loop, "___errno_location": ___errno_location, "_emscripten_glIsShader": _emscripten_glIsShader, "_copysign": _copysign, "_fputc": _fputc, "_emscripten_glCompressedTexImage2D": _emscripten_glCompressedTexImage2D, "_glDisable": _glDisable, "_emscripten_glGetInfoLogARB": _emscripten_glGetInfoLogARB, "_emscripten_longjmp": _emscripten_longjmp, "__formatString": __formatString, "_atexit": _atexit, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_JS_Sound_ReleaseInstance": _JS_Sound_ReleaseInstance, "_emscripten_glGenRenderbuffers": _emscripten_glGenRenderbuffers, "_emscripten_glReleaseShaderCompiler": _emscripten_glReleaseShaderCompiler, "_glStencilFunc": _glStencilFunc, "__ZN4FMOD13DSPConnection6setMixEf": __ZN4FMOD13DSPConnection6setMixEf, "_flock": _flock, "___cxa_guard_acquire": ___cxa_guard_acquire, "_SDL_RWFromFile": _SDL_RWFromFile, "_glUniform2fv": _glUniform2fv, "_emscripten_glFrontFace": _emscripten_glFrontFace, "_truncate": _truncate, "_glDeleteProgram": _glDeleteProgram, "__ZSt18uncaught_exceptionv": __ZSt18uncaught_exceptionv, "_emscripten_glUseProgram": _emscripten_glUseProgram, "___ctype_toupper_loc": ___ctype_toupper_loc, "_glCreateProgram": _glCreateProgram, "_clock_gettime": _clock_gettime, "_SDL_GetError": _SDL_GetError, "_uname": _uname, "_glGetAttribLocation": _glGetAttribLocation, "_Mix_PlayChannel": _Mix_PlayChannel, "_sinf": _sinf, "_sinh": _sinh, "_sysconf": _sysconf, "__reallyNegative": __reallyNegative, "_ferror": _ferror, "_emscripten_glLineWidth": _emscripten_glLineWidth, "_pthread_mutexattr_settype": _pthread_mutexattr_settype, "_tan": _tan, "_glGenBuffers": _glGenBuffers, "_glShaderSource": _glShaderSource, "_round": _round, "_emscripten_glScissor": _emscripten_glScissor, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_mkdir": _mkdir, "_closedir": _closedir, "_llvm_trap": _llvm_trap, "_JS_Sound_SetVolume": _JS_Sound_SetVolume, "_JS_Cursor_SetShow": _JS_Cursor_SetShow, "_emscripten_glIsBuffer": _emscripten_glIsBuffer, "_emscripten_glVertexAttrib1f": _emscripten_glVertexAttrib1f, "_emscripten_set_keyup_callback": _emscripten_set_keyup_callback, "_emscripten_glCompressedTexSubImage2D": _emscripten_glCompressedTexSubImage2D, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_JS_Log_Dump": _JS_Log_Dump, "_emscripten_glGetAttachedShaders": _emscripten_glGetAttachedShaders, "_emscripten_glGenTextures": _emscripten_glGenTextures, "_JS_Cursor_SetCursorString": _JS_Cursor_SetCursorString, "_glBindRenderbuffer": _glBindRenderbuffer, "_pthread_cond_init": _pthread_cond_init, "_SDL_LockSurface": _SDL_LockSurface, "_gmtime": _gmtime, "_emscripten_glGetTexParameteriv": _emscripten_glGetTexParameteriv, "_glDeleteTextures": _glDeleteTextures, "_emscripten_glClientActiveTexture": _emscripten_glClientActiveTexture, "_emscripten_glPolygonOffset": _emscripten_glPolygonOffset, "_emscripten_glCheckFramebufferStatus": _emscripten_glCheckFramebufferStatus, "_abs": _abs, "_emscripten_glUniform3f": _emscripten_glUniform3f, "_emscripten_glUniform3i": _emscripten_glUniform3i, "_emscripten_glDeleteShader": _emscripten_glDeleteShader, "_glEnable": _glEnable, "_glGetString": _glGetString, "_emscripten_glGetUniformLocation": _emscripten_glGetUniformLocation, "_emscripten_glEnableVertexAttribArray": _emscripten_glEnableVertexAttribArray, "_emscripten_get_now": _emscripten_get_now, "_fprintf": _fprintf, "_gettimeofday": _gettimeofday, "_catopen": _catopen, "_emscripten_glEnableClientState": _emscripten_glEnableClientState, "_pthread_join": _pthread_join, "_fmod": _fmod, "_JS_Sound_Init": _JS_Sound_Init, "_emscripten_glReadPixels": _emscripten_glReadPixels, "_emscripten_glDrawElements": _emscripten_glDrawElements, "___buildEnvironment": ___buildEnvironment, "_glClearDepthf": _glClearDepthf, "_tzset": _tzset, "_emscripten_asm_const": _emscripten_asm_const, "_SDL_Init": _SDL_Init, "_emscripten_glDisable": _emscripten_glDisable, "___cxa_end_catch": ___cxa_end_catch, "_emscripten_glDeleteRenderbuffers": _emscripten_glDeleteRenderbuffers, "_emscripten_glDrawElementsInstanced": _emscripten_glDrawElementsInstanced, "_emscripten_glVertexAttrib4f": _emscripten_glVertexAttrib4f, "_JS_Sound_Create_Channel": _JS_Sound_Create_Channel, "_emscripten_glPixelStorei": _emscripten_glPixelStorei, "_emscripten_webgl_init_context_attributes": _emscripten_webgl_init_context_attributes, "_fclose": _fclose, "_log": _log, "_emscripten_glFramebufferRenderbuffer": _emscripten_glFramebufferRenderbuffer, "_fminf": _fminf, "_glBufferData": _glBufferData, "_JS_Sound_SetPaused": _JS_Sound_SetPaused, "_emscripten_glRotatef": _emscripten_glRotatef, "_emscripten_glGetShaderiv": _emscripten_glGetShaderiv, "___cxa_pure_virtual": ___cxa_pure_virtual, "_emscripten_glUniformMatrix4fv": _emscripten_glUniformMatrix4fv, "_emscripten_glGetPointerv": _emscripten_glGetPointerv, "_pthread_cond_wait": _pthread_cond_wait, "_emscripten_set_blur_callback": _emscripten_set_blur_callback, "_acosf": _acosf, "_acos": _acos, "_cosh": _cosh, "_emscripten_glIsRenderbuffer": _emscripten_glIsRenderbuffer, "_emscripten_request_pointerlock": _emscripten_request_pointerlock, "_tanf": _tanf, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_JS_SystemInfo_GetMemory": _JS_SystemInfo_GetMemory, "_JS_Sound_SetLoop": _JS_Sound_SetLoop, "_emscripten_set_focus_callback": _emscripten_set_focus_callback, "_pthread_mutexattr_destroy": _pthread_mutexattr_destroy, "_emscripten_glGetVertexAttribfv": _emscripten_glGetVertexAttribfv, "_SDL_PauseAudio": _SDL_PauseAudio, "_emscripten_glVertexAttrib3fv": _emscripten_glVertexAttrib3fv, "_glGetUniformLocation": _glGetUniformLocation, "_emscripten_glCompileShader": _emscripten_glCompileShader, "_glClear": _glClear, "__arraySum": __arraySum, "_emscripten_glLinkProgram": _emscripten_glLinkProgram, "_atan": _atan, "_pread": _pread, "_mkport": _mkport, "_emscripten_get_pointerlock_status": _emscripten_get_pointerlock_status, "_emscripten_glDrawRangeElements": _emscripten_glDrawRangeElements, "_getc": _getc, "_pthread_create": _pthread_create, "_copysignf": _copysignf, "_pthread_setspecific": _pthread_setspecific, "_rmdir": _rmdir, "_glColorMask": _glColorMask, "_emscripten_glClearColor": _emscripten_glClearColor, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_emscripten_glCreateProgram": _emscripten_glCreateProgram, "_glTexParameteri": _glTexParameteri, "_emscripten_glDetachShader": _emscripten_glDetachShader, "_SDL_RWFromConstMem": _SDL_RWFromConstMem, "_emscripten_set_fullscreenchange_callback": _emscripten_set_fullscreenchange_callback, "_emscripten_glVertexAttribPointer": _emscripten_glVertexAttribPointer, "_fmodl": _fmodl, "_fread": _fread, "_emscripten_glDrawArrays": _emscripten_glDrawArrays, "_fmodf": _fmodf, "_longjmp": _longjmp, "_emscripten_glBlendColor": _emscripten_glBlendColor, "_emscripten_get_now_res": _emscripten_get_now_res, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_clock_getres": _clock_getres, "_sbrk": _sbrk, "___cxa_begin_catch": ___cxa_begin_catch, "_emscripten_glGetProgramiv": _emscripten_glGetProgramiv, "_exp2": _exp2, "_close": _close, "_glStencilOp": _glStencilOp, "_emscripten_glGetShaderSource": _emscripten_glGetShaderSource, "_cos": _cos, "_sem_timedwait": _sem_timedwait, "_expf": _expf, "_emscripten_glTexImage2D": _emscripten_glTexImage2D, "__isLeapYear": __isLeapYear, "_emscripten_glBlendEquationSeparate": _emscripten_glBlendEquationSeparate, "_emscripten_glGetString": _emscripten_glGetString, "_emscripten_glIsFramebuffer": _emscripten_glIsFramebuffer, "__exit": __exit, "_JS_Eval_EvalJS": _JS_Eval_EvalJS, "_emscripten_glBindProgramARB": _emscripten_glBindProgramARB, "_mknod": _mknod, "_gethostname": _gethostname, "_emscripten_glUniform2i": _emscripten_glUniform2i, "_send": _send, "_JS_SystemInfo_GetWidth": _JS_SystemInfo_GetWidth, "_atan2": _atan2, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_emscripten_glTexParameterf": _emscripten_glTexParameterf, "_emscripten_glTexParameteri": _emscripten_glTexParameteri, "_JS_Sound_Load": _JS_Sound_Load, "_sem_init": _sem_init, "_JS_Sound_Load_PCM": _JS_Sound_Load_PCM, "_emscripten_glGenVertexArrays": _emscripten_glGenVertexArrays, "_JS_SystemInfo_GetDocumentURL": _JS_SystemInfo_GetDocumentURL, "_Mix_HaltMusic": _Mix_HaltMusic, "_emscripten_glBindAttribLocation": _emscripten_glBindAttribLocation, "_llvm_pow_f32": _llvm_pow_f32, "_glDepthFunc": _glDepthFunc, "___cxa_allocate_exception": ___cxa_allocate_exception, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "_unlink": _unlink, "_freelocale": _freelocale, "_emscripten_glClearDepthf": _emscripten_glClearDepthf, "_atanf": _atanf, "_printf": _printf, "_emscripten_glMatrixMode": _emscripten_glMatrixMode, "_fmaxf": _fmaxf, "_emscripten_glNormalPointer": _emscripten_glNormalPointer, "_emscripten_glHint": _emscripten_glHint, "_emscripten_glEnable": _emscripten_glEnable, "_read": _read, "_emscripten_glBindFramebuffer": _emscripten_glBindFramebuffer, "_emscripten_glBindRenderbuffer": _emscripten_glBindRenderbuffer, "_time": _time, "_emscripten_glGetFramebufferAttachmentParameteriv": _emscripten_glGetFramebufferAttachmentParameteriv, "_exit": _exit, "_roundf": _roundf, "_putenv": _putenv, "_emscripten_glDeleteBuffers": _emscripten_glDeleteBuffers, "_access": _access, "_JS_Cursor_SetImage": _JS_Cursor_SetImage, "_emscripten_glShaderBinary": _emscripten_glShaderBinary, "_emscripten_glGetShaderInfoLog": _emscripten_glGetShaderInfoLog, "_glUniform3fv": _glUniform3fv, "_emscripten_glGetVertexAttribPointerv": _emscripten_glGetVertexAttribPointerv, "_pwrite": _pwrite, "_open": _open, "_emscripten_glUniform2f": _emscripten_glUniform2f, "_emscripten_glDeleteProgram": _emscripten_glDeleteProgram, "_glUniform1i": _glUniform1i, "_emscripten_glCreateShader": _emscripten_glCreateShader, "_pthread_mutex_destroy": _pthread_mutex_destroy, "_emscripten_glColorPointer": _emscripten_glColorPointer, "_SDL_UpperBlit": _SDL_UpperBlit, "_emscripten_glViewport": _emscripten_glViewport, "_pthread_cond_broadcast": _pthread_cond_broadcast, "_emscripten_glDepthMask": _emscripten_glDepthMask, "_emscripten_glDrawBuffers": _emscripten_glDrawBuffers, "_SDL_JoystickNumAxes": _SDL_JoystickNumAxes, "_clearerr": _clearerr, "_glCompileShader": _glCompileShader, "_emscripten_exit_pointerlock": _emscripten_exit_pointerlock, "_log10f": _log10f, "_abort": _abort, "_emscripten_glGenerateMipmap": _emscripten_glGenerateMipmap, "_glTexImage2D": _glTexImage2D, "_emscripten_glGenFramebuffers": _emscripten_glGenFramebuffers, "_glFlush": _glFlush, "_emscripten_glLoadIdentity": _emscripten_glLoadIdentity, "_glDeleteShader": _glDeleteShader, "_emscripten_glShaderSource": _emscripten_glShaderSource, "_glGetActiveUniform": _glGetActiveUniform, "_sem_destroy": _sem_destroy, "_SDL_CloseAudio": _SDL_CloseAudio, "___gxx_personality_v0": ___gxx_personality_v0, "_emscripten_asm_const_int": _emscripten_asm_const_int, "_usleep": _usleep, "_fmax": _fmax, "_emscripten_get_fullscreen_status": _emscripten_get_fullscreen_status, "_glVertexAttribPointer": _glVertexAttribPointer, "_JS_Sound_SetVelocity": _JS_Sound_SetVelocity, "_emscripten_glGetRenderbufferParameteriv": _emscripten_glGetRenderbufferParameteriv, "_glGenRenderbuffers": _glGenRenderbuffers, "_strerror": _strerror, "_emscripten_glSampleCoverage": _emscripten_glSampleCoverage, "_emscripten_glFrustum": _emscripten_glFrustum, "_Mix_FreeChunk": _Mix_FreeChunk, "_emscripten_glDepthRangef": _emscripten_glDepthRangef, "_glPixelStorei": _glPixelStorei, "_emscripten_glIsTexture": _emscripten_glIsTexture, "_fputs": _fputs, "_emscripten_glBindVertexArray": _emscripten_glBindVertexArray, "_glStencilMask": _glStencilMask, "_emscripten_glActiveTexture": _emscripten_glActiveTexture, "_emscripten_glDeleteVertexArrays": _emscripten_glDeleteVertexArrays, "_emscripten_glUniform2iv": _emscripten_glUniform2iv, "_lstat": _lstat, "_pthread_mutexattr_init": _pthread_mutexattr_init, "_getenv": _getenv, "_SDL_GL_SwapBuffers": _SDL_GL_SwapBuffers, "_opendir": _opendir, "_sqrt": _sqrt, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stderr": _stderr, "_stdin": _stdin, "_stdout": _stdout }, buffer);
  var _SetFullscreen = Module["_SetFullscreen"] = asm["_SetFullscreen"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _main = Module["_main"] = asm["_main"];
var _memset = Module["_memset"] = asm["_memset"];
var _SendMessageFloat = Module["_SendMessageFloat"] = asm["_SendMessageFloat"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var _calloc = Module["_calloc"] = asm["_calloc"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var ___cxa_is_pointer_type = Module["___cxa_is_pointer_type"] = asm["___cxa_is_pointer_type"];
var _strncpy = Module["_strncpy"] = asm["_strncpy"];
var _bitshift64Ashr = Module["_bitshift64Ashr"] = asm["_bitshift64Ashr"];
var _llvm_cttz_i32 = Module["_llvm_cttz_i32"] = asm["_llvm_cttz_i32"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _llvm_bswap_i32 = Module["_llvm_bswap_i32"] = asm["_llvm_bswap_i32"];
var _SendMessageString = Module["_SendMessageString"] = asm["_SendMessageString"];
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var ___cxa_can_catch = Module["___cxa_can_catch"] = asm["___cxa_can_catch"];
var _free = Module["_free"] = asm["_free"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _strstr = Module["_strstr"] = asm["_strstr"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _llvm_ctlz_i32 = Module["_llvm_ctlz_i32"] = asm["_llvm_ctlz_i32"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var _SendMessage = Module["_SendMessage"] = asm["_SendMessage"];
var __GLOBAL__I_a1261 = Module["__GLOBAL__I_a1261"] = asm["__GLOBAL__I_a1261"];
var __GLOBAL__I_a1253 = Module["__GLOBAL__I_a1253"] = asm["__GLOBAL__I_a1253"];
var __GLOBAL__I_a4171 = Module["__GLOBAL__I_a4171"] = asm["__GLOBAL__I_a4171"];
var __GLOBAL__I_a4182 = Module["__GLOBAL__I_a4182"] = asm["__GLOBAL__I_a4182"];
var __GLOBAL__I_a4186 = Module["__GLOBAL__I_a4186"] = asm["__GLOBAL__I_a4186"];
var __GLOBAL__I_a4208 = Module["__GLOBAL__I_a4208"] = asm["__GLOBAL__I_a4208"];
var __GLOBAL__I_a4557 = Module["__GLOBAL__I_a4557"] = asm["__GLOBAL__I_a4557"];
var __GLOBAL__I_a6522 = Module["__GLOBAL__I_a6522"] = asm["__GLOBAL__I_a6522"];
var __GLOBAL__I_a1306 = Module["__GLOBAL__I_a1306"] = asm["__GLOBAL__I_a1306"];
var __GLOBAL__I_a1532 = Module["__GLOBAL__I_a1532"] = asm["__GLOBAL__I_a1532"];
var __GLOBAL__I_a1629 = Module["__GLOBAL__I_a1629"] = asm["__GLOBAL__I_a1629"];
var __GLOBAL__I_a1638 = Module["__GLOBAL__I_a1638"] = asm["__GLOBAL__I_a1638"];
var __GLOBAL__I_a1651 = Module["__GLOBAL__I_a1651"] = asm["__GLOBAL__I_a1651"];
var __GLOBAL__I_a1667 = Module["__GLOBAL__I_a1667"] = asm["__GLOBAL__I_a1667"];
var __GLOBAL__I_a1688 = Module["__GLOBAL__I_a1688"] = asm["__GLOBAL__I_a1688"];
var __GLOBAL__I_a1817 = Module["__GLOBAL__I_a1817"] = asm["__GLOBAL__I_a1817"];
var __GLOBAL__I_a1915 = Module["__GLOBAL__I_a1915"] = asm["__GLOBAL__I_a1915"];
var __GLOBAL__I_a1998 = Module["__GLOBAL__I_a1998"] = asm["__GLOBAL__I_a1998"];
var __GLOBAL__I_a2062 = Module["__GLOBAL__I_a2062"] = asm["__GLOBAL__I_a2062"];
var __GLOBAL__I_a2431 = Module["__GLOBAL__I_a2431"] = asm["__GLOBAL__I_a2431"];
var __GLOBAL__I_a2482 = Module["__GLOBAL__I_a2482"] = asm["__GLOBAL__I_a2482"];
var __GLOBAL__I_a2517 = Module["__GLOBAL__I_a2517"] = asm["__GLOBAL__I_a2517"];
var __GLOBAL__I_a2967 = Module["__GLOBAL__I_a2967"] = asm["__GLOBAL__I_a2967"];
var __GLOBAL__I_a3258 = Module["__GLOBAL__I_a3258"] = asm["__GLOBAL__I_a3258"];
var __GLOBAL__I_a3392 = Module["__GLOBAL__I_a3392"] = asm["__GLOBAL__I_a3392"];
var __GLOBAL__I_a3547 = Module["__GLOBAL__I_a3547"] = asm["__GLOBAL__I_a3547"];
var __GLOBAL__I_a3708 = Module["__GLOBAL__I_a3708"] = asm["__GLOBAL__I_a3708"];
var __GLOBAL__I_a4056 = Module["__GLOBAL__I_a4056"] = asm["__GLOBAL__I_a4056"];
var __GLOBAL__I_a4778 = Module["__GLOBAL__I_a4778"] = asm["__GLOBAL__I_a4778"];
var __GLOBAL__I_a6056 = Module["__GLOBAL__I_a6056"] = asm["__GLOBAL__I_a6056"];
var __GLOBAL__I_a6584 = Module["__GLOBAL__I_a6584"] = asm["__GLOBAL__I_a6584"];
var __GLOBAL__I_a8226 = Module["__GLOBAL__I_a8226"] = asm["__GLOBAL__I_a8226"];
var __GLOBAL__I_a8687 = Module["__GLOBAL__I_a8687"] = asm["__GLOBAL__I_a8687"];
var __GLOBAL__I_a9384 = Module["__GLOBAL__I_a9384"] = asm["__GLOBAL__I_a9384"];
var __GLOBAL__I_a11687 = Module["__GLOBAL__I_a11687"] = asm["__GLOBAL__I_a11687"];
var __GLOBAL__I_a11737 = Module["__GLOBAL__I_a11737"] = asm["__GLOBAL__I_a11737"];
var __GLOBAL__I_a13766 = Module["__GLOBAL__I_a13766"] = asm["__GLOBAL__I_a13766"];
var __GLOBAL__I_a18997 = Module["__GLOBAL__I_a18997"] = asm["__GLOBAL__I_a18997"];
var __GLOBAL__I_a19751 = Module["__GLOBAL__I_a19751"] = asm["__GLOBAL__I_a19751"];
var __GLOBAL__I_a19771 = Module["__GLOBAL__I_a19771"] = asm["__GLOBAL__I_a19771"];
var __GLOBAL__I_a19829 = Module["__GLOBAL__I_a19829"] = asm["__GLOBAL__I_a19829"];
var __GLOBAL__I_a20005 = Module["__GLOBAL__I_a20005"] = asm["__GLOBAL__I_a20005"];
var __GLOBAL__I_a20041 = Module["__GLOBAL__I_a20041"] = asm["__GLOBAL__I_a20041"];
var __GLOBAL__I_a20087 = Module["__GLOBAL__I_a20087"] = asm["__GLOBAL__I_a20087"];
var __GLOBAL__I_a21124 = Module["__GLOBAL__I_a21124"] = asm["__GLOBAL__I_a21124"];
var __GLOBAL__I_a21804 = Module["__GLOBAL__I_a21804"] = asm["__GLOBAL__I_a21804"];
var __GLOBAL__I_a1263 = Module["__GLOBAL__I_a1263"] = asm["__GLOBAL__I_a1263"];
var __GLOBAL__I_a5 = Module["__GLOBAL__I_a5"] = asm["__GLOBAL__I_a5"];
var __GLOBAL__I_a9 = Module["__GLOBAL__I_a9"] = asm["__GLOBAL__I_a9"];
var __GLOBAL__I_a14 = Module["__GLOBAL__I_a14"] = asm["__GLOBAL__I_a14"];
var __GLOBAL__I_a23365 = Module["__GLOBAL__I_a23365"] = asm["__GLOBAL__I_a23365"];
var __GLOBAL__I_a23371 = Module["__GLOBAL__I_a23371"] = asm["__GLOBAL__I_a23371"];
var __GLOBAL__I_a23378 = Module["__GLOBAL__I_a23378"] = asm["__GLOBAL__I_a23378"];
var __GLOBAL__I_a23385 = Module["__GLOBAL__I_a23385"] = asm["__GLOBAL__I_a23385"];
var __GLOBAL__I_a23391 = Module["__GLOBAL__I_a23391"] = asm["__GLOBAL__I_a23391"];
var __GLOBAL__I_a1496 = Module["__GLOBAL__I_a1496"] = asm["__GLOBAL__I_a1496"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_fiff = Module["dynCall_fiff"] = asm["dynCall_fiff"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_vifiiiiiiiiiiiiiiiiiii = Module["dynCall_vifiiiiiiiiiiiiiiiiiii"] = asm["dynCall_vifiiiiiiiiiiiiiiiiiii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_fff = Module["dynCall_fff"] = asm["dynCall_fff"];
var dynCall_iidi = Module["dynCall_iidi"] = asm["dynCall_iidi"];
var dynCall_fiiiiiifiiiiiif = Module["dynCall_fiiiiiifiiiiiif"] = asm["dynCall_fiiiiiifiiiiiif"];
var dynCall_iiiiifiif = Module["dynCall_iiiiifiif"] = asm["dynCall_iiiiifiif"];
var dynCall_viiiiiffi = Module["dynCall_viiiiiffi"] = asm["dynCall_viiiiiffi"];
var dynCall_iiiiiiiiiiii = Module["dynCall_iiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiii"];
var dynCall_fiffifff = Module["dynCall_fiffifff"] = asm["dynCall_fiffifff"];
var dynCall_fif = Module["dynCall_fif"] = asm["dynCall_fif"];
var dynCall_viiiiiiiiiiiiiii = Module["dynCall_viiiiiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiiiiii"];
var dynCall_fid = Module["dynCall_fid"] = asm["dynCall_fid"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_ddii = Module["dynCall_ddii"] = asm["dynCall_ddii"];
var dynCall_di = Module["dynCall_di"] = asm["dynCall_di"];
var dynCall_dd = Module["dynCall_dd"] = asm["dynCall_dd"];
var dynCall_viff = Module["dynCall_viff"] = asm["dynCall_viff"];
var dynCall_vffi = Module["dynCall_vffi"] = asm["dynCall_vffi"];
var dynCall_viiiifiii = Module["dynCall_viiiifiii"] = asm["dynCall_viiiifiii"];
var dynCall_viffff = Module["dynCall_viffff"] = asm["dynCall_viffff"];
var dynCall_d = Module["dynCall_d"] = asm["dynCall_d"];
var dynCall_didd = Module["dynCall_didd"] = asm["dynCall_didd"];
var dynCall_viiiiifffiiiii = Module["dynCall_viiiiifffiiiii"] = asm["dynCall_viiiiifffiiiii"];
var dynCall_iiiiifffiiiii = Module["dynCall_iiiiifffiiiii"] = asm["dynCall_iiiiifffiiiii"];
var dynCall_dii = Module["dynCall_dii"] = asm["dynCall_dii"];
var dynCall_did = Module["dynCall_did"] = asm["dynCall_did"];
var dynCall_dif = Module["dynCall_dif"] = asm["dynCall_dif"];
var dynCall_iifii = Module["dynCall_iifii"] = asm["dynCall_iifii"];
var dynCall_iiiiiiiiii = Module["dynCall_iiiiiiiiii"] = asm["dynCall_iiiiiiiiii"];
var dynCall_vdddddd = Module["dynCall_vdddddd"] = asm["dynCall_vdddddd"];
var dynCall_fiffiff = Module["dynCall_fiffiff"] = asm["dynCall_fiffiff"];
var dynCall_iiiiiiiiiiiiffffii = Module["dynCall_iiiiiiiiiiiiffffii"] = asm["dynCall_iiiiiiiiiiiiffffii"];
var dynCall_vdd = Module["dynCall_vdd"] = asm["dynCall_vdd"];
var dynCall_viiifiiii = Module["dynCall_viiifiiii"] = asm["dynCall_viiifiiii"];
var dynCall_iiiif = Module["dynCall_iiiif"] = asm["dynCall_iiiif"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_iiiiiifffiiiii = Module["dynCall_iiiiiifffiiiii"] = asm["dynCall_iiiiiifffiiiii"];
var dynCall_vifiiiiiiiiiiiii = Module["dynCall_vifiiiiiiiiiiiii"] = asm["dynCall_vifiiiiiiiiiiiii"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_iiifii = Module["dynCall_iiifii"] = asm["dynCall_iiifii"];
var dynCall_fifff = Module["dynCall_fifff"] = asm["dynCall_fifff"];
var dynCall_viffi = Module["dynCall_viffi"] = asm["dynCall_viffi"];
var dynCall_viiiiid = Module["dynCall_viiiiid"] = asm["dynCall_viiiiid"];
var dynCall_iiiifiiii = Module["dynCall_iiiifiiii"] = asm["dynCall_iiiifiiii"];
var dynCall_vifi = Module["dynCall_vifi"] = asm["dynCall_vifi"];
var dynCall_vifff = Module["dynCall_vifff"] = asm["dynCall_vifff"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_ddd = Module["dynCall_ddd"] = asm["dynCall_ddd"];
var dynCall_fiii = Module["dynCall_fiii"] = asm["dynCall_fiii"];
var dynCall_iifff = Module["dynCall_iifff"] = asm["dynCall_iifff"];
var dynCall_fiif = Module["dynCall_fiif"] = asm["dynCall_fiif"];
var dynCall_iiiiiifiiiiiiiiiffffi = Module["dynCall_iiiiiifiiiiiiiiiffffi"] = asm["dynCall_iiiiiifiiiiiiiiiffffi"];
var dynCall_iiiiifiiiif = Module["dynCall_iiiiifiiiif"] = asm["dynCall_iiiiifiiiif"];
var dynCall_viiffffff = Module["dynCall_viiffffff"] = asm["dynCall_viiffffff"];
var dynCall_viiiiiiiiii = Module["dynCall_viiiiiiiiii"] = asm["dynCall_viiiiiiiiii"];
var dynCall_diii = Module["dynCall_diii"] = asm["dynCall_diii"];
var dynCall_fiiii = Module["dynCall_fiiii"] = asm["dynCall_fiiii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viiiiifiiiiiiiiiiiii = Module["dynCall_viiiiifiiiiiiiiiiiii"] = asm["dynCall_viiiiifiiiiiiiiiiiii"];
var dynCall_viiiff = Module["dynCall_viiiff"] = asm["dynCall_viiiff"];
var dynCall_iiiiiifiif = Module["dynCall_iiiiiifiif"] = asm["dynCall_iiiiiifiif"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_iifffi = Module["dynCall_iifffi"] = asm["dynCall_iifffi"];
var dynCall_vif = Module["dynCall_vif"] = asm["dynCall_vif"];
var dynCall_vid = Module["dynCall_vid"] = asm["dynCall_vid"];
var dynCall_iiidi = Module["dynCall_iiidi"] = asm["dynCall_iiidi"];
var dynCall_viiidii = Module["dynCall_viiidii"] = asm["dynCall_viiidii"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiffff = Module["dynCall_iiffff"] = asm["dynCall_iiffff"];
var dynCall_viiiif = Module["dynCall_viiiif"] = asm["dynCall_viiiif"];
var dynCall_viifii = Module["dynCall_viifii"] = asm["dynCall_viifii"];
var dynCall_fi = Module["dynCall_fi"] = asm["dynCall_fi"];
var dynCall_viidi = Module["dynCall_viidi"] = asm["dynCall_viidi"];
var dynCall_viifif = Module["dynCall_viifif"] = asm["dynCall_viifif"];
var dynCall_vf = Module["dynCall_vf"] = asm["dynCall_vf"];
var dynCall_fiiiiiiiifiiiif = Module["dynCall_fiiiiiiiifiiiif"] = asm["dynCall_fiiiiiiiifiiiif"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vifiii = Module["dynCall_vifiii"] = asm["dynCall_vifiii"];
var dynCall_iiiiiiifiiiiiiiiiffffi = Module["dynCall_iiiiiiifiiiiiiiiiffffi"] = asm["dynCall_iiiiiiifiiiiiiiiiffffi"];
var dynCall_diiii = Module["dynCall_diiii"] = asm["dynCall_diiii"];
var dynCall_iiifiiii = Module["dynCall_iiifiiii"] = asm["dynCall_iiifiiii"];
var dynCall_viiiiiiiiiiiii = Module["dynCall_viiiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiiii"];
var dynCall_iiiiiiiiiiffffii = Module["dynCall_iiiiiiiiiiffffii"] = asm["dynCall_iiiiiiiiiiffffii"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_iid = Module["dynCall_iid"] = asm["dynCall_iid"];
var dynCall_iif = Module["dynCall_iif"] = asm["dynCall_iif"];
var dynCall_vifiiii = Module["dynCall_vifiiii"] = asm["dynCall_vifiiii"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_vifiiiiiiiiiiiiiiiiii = Module["dynCall_vifiiiiiiiiiiiiiiiiii"] = asm["dynCall_vifiiiiiiiiiiiiiiiiii"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_viiiiiif = Module["dynCall_viiiiiif"] = asm["dynCall_viiiiiif"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiifii = Module["dynCall_iiiifii"] = asm["dynCall_iiiifii"];
var dynCall_f = Module["dynCall_f"] = asm["dynCall_f"];
var dynCall_vffff = Module["dynCall_vffff"] = asm["dynCall_vffff"];
var dynCall_vifffi = Module["dynCall_vifffi"] = asm["dynCall_vifffi"];
var dynCall_viiiifiiiiif = Module["dynCall_viiiifiiiiif"] = asm["dynCall_viiiifiiiiif"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_viiiifi = Module["dynCall_viiiifi"] = asm["dynCall_viiiifi"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_viid = Module["dynCall_viid"] = asm["dynCall_viid"];
var dynCall_viiiiff = Module["dynCall_viiiiff"] = asm["dynCall_viiiiff"];
var dynCall_viif = Module["dynCall_viif"] = asm["dynCall_viif"];
var dynCall_fiffif = Module["dynCall_fiffif"] = asm["dynCall_fiffif"];
var dynCall_iiiifi = Module["dynCall_iiiifi"] = asm["dynCall_iiiifi"];
var dynCall_vd = Module["dynCall_vd"] = asm["dynCall_vd"];
var dynCall_iiffffff = Module["dynCall_iiffffff"] = asm["dynCall_iiffffff"];
var dynCall_viiiiiiiifiiifiii = Module["dynCall_viiiiiiiifiiifiii"] = asm["dynCall_viiiiiiiifiiifiii"];
var dynCall_fiiff = Module["dynCall_fiiff"] = asm["dynCall_fiiff"];
var dynCall_viiifffii = Module["dynCall_viiifffii"] = asm["dynCall_viiifffii"];
var dynCall_iiiiiiiiiii = Module["dynCall_iiiiiiiiiii"] = asm["dynCall_iiiiiiiiiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_iiff = Module["dynCall_iiff"] = asm["dynCall_iiff"];
var dynCall_viifi = Module["dynCall_viifi"] = asm["dynCall_viifi"];
var dynCall_iiiiifiiiiii = Module["dynCall_iiiiifiiiiii"] = asm["dynCall_iiiiifiiiiii"];
var dynCall_iiiiifiiiiif = Module["dynCall_iiiiifiiiiif"] = asm["dynCall_iiiiifiiiiif"];
var dynCall_viiff = Module["dynCall_viiff"] = asm["dynCall_viiff"];
var dynCall_viiiiiiiiiiii = Module["dynCall_viiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiii"];
var dynCall_iifi = Module["dynCall_iifi"] = asm["dynCall_iifi"];
var dynCall_viiif = Module["dynCall_viiif"] = asm["dynCall_viiif"];
var dynCall_viiiiifiiii = Module["dynCall_viiiiifiiii"] = asm["dynCall_viiiiifiiii"];
var dynCall_viiiffii = Module["dynCall_viiiffii"] = asm["dynCall_viiiffii"];
var dynCall_vifiiiiiiiiiiiiiiiiiiiiiii = Module["dynCall_vifiiiiiiiiiiiiiiiiiiiiiii"] = asm["dynCall_vifiiiiiiiiiiiiiiiiiiiiiii"];
var dynCall_iifiiiii = Module["dynCall_iifiiiii"] = asm["dynCall_iifiiiii"];
var dynCall_iiifi = Module["dynCall_iiifi"] = asm["dynCall_iiifi"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viifff = Module["dynCall_viifff"] = asm["dynCall_viifff"];
var dynCall_viiffi = Module["dynCall_viiffi"] = asm["dynCall_viiffi"];
var dynCall_iiif = Module["dynCall_iiif"] = asm["dynCall_iiif"];
var dynCall_viiiiiid = Module["dynCall_viiiiiid"] = asm["dynCall_viiiiiid"];
var dynCall_viiifi = Module["dynCall_viiifi"] = asm["dynCall_viiifi"];
var dynCall_viffffff = Module["dynCall_viffffff"] = asm["dynCall_viffffff"];
var dynCall_iiiiiiiiiiiii = Module["dynCall_iiiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiiii"];
var dynCall_iiiifiiiii = Module["dynCall_iiiifiiiii"] = asm["dynCall_iiiifiiiii"];
var dynCall_iiiiiiiiiiiiiii = Module["dynCall_iiiiiiiiiiiiiii"] = asm["dynCall_iiiiiiiiiiiiiii"];
var dynCall_viiiiiiiiiiiiiiiiiiiiiiiiiiiii = Module["dynCall_viiiiiiiiiiiiiiiiiiiiiiiiiiiii"] = asm["dynCall_viiiiiiiiiiiiiiiiiiiiiiiiiiiii"];
var dynCall_viffffffffffffiiii = Module["dynCall_viffffffffffffiiii"] = asm["dynCall_viffffffffffffiiii"];
var dynCall_vfi = Module["dynCall_vfi"] = asm["dynCall_vfi"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_vff = Module["dynCall_vff"] = asm["dynCall_vff"];
var dynCall_viiifiiiii = Module["dynCall_viiifiiiii"] = asm["dynCall_viiifiiiii"];
var dynCall_iiiiiifiiiiiiiiiiii = Module["dynCall_iiiiiifiiiiiiiiiiii"] = asm["dynCall_iiiiiifiiiiiiiiiiii"];
var dynCall_viiffff = Module["dynCall_viiffff"] = asm["dynCall_viiffff"];
var dynCall_iiiiiiiii = Module["dynCall_iiiiiiiii"] = asm["dynCall_iiiiiiiii"];
var dynCall_viffffi = Module["dynCall_viffffi"] = asm["dynCall_viffffi"];
  
  Runtime.stackAlloc = asm['stackAlloc'];
  Runtime.stackSave = asm['stackSave'];
  Runtime.stackRestore = asm['stackRestore'];
  Runtime.setTempRet0 = asm['setTempRet0'];
  Runtime.getTempRet0 = asm['getTempRet0'];
  

// TODO: strip out parts of this we do not need

//======= begin closure i64 code =======

// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */

var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };


  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.

    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };


  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.


  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};


  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }

    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };


  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };


  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };


  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }

    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }

    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));

    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };


  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.


  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;


  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);


  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);


  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);


  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);


  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);


  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);


  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };


  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };


  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (this.isZero()) {
      return '0';
    }

    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }

    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));

    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);

      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };


  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };


  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };


  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };


  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };


  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };


  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };


  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };


  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }

    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }

    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };


  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };


  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };


  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }

    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }

    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }

    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));

      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);

      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }

      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }

      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };


  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };


  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };


  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };


  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };


  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };


  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };

  //======= begin jsbn =======

  var navigator = { appName: 'Modern Browser' }; // polyfill a little

  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/

  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */

  // Basic JavaScript BN library - subset useful for RSA encryption.

  // Bits per digit
  var dbits;

  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);

  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }

  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }

  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.

  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }

  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);

  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;

  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }

  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }

  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }

  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }

  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }

  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }

  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }

  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }

  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }

  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }

  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }

  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }

  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }

  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }

  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }

  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }

  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }

  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }

  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;

  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }

  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }

  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }

  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }

  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }

  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;

  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }

  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }

  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;

  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;

  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);

  // jsbn2 stuff

  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }

  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }

  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }

  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }

  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }

  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }

  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;

  //======= end jsbn =======

  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();

//======= end closure i64 code =======



// === Auto-generated postamble setup entry stuff ===

if (memoryInitializer) {
  if (typeof Module['locateFile'] === 'function') {
    memoryInitializer = Module['locateFile'](memoryInitializer);
  } else if (Module['memoryInitializerPrefixURL']) {
    memoryInitializer = Module['memoryInitializerPrefixURL'] + memoryInitializer;
  }
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    var data = Module['readBinary'](memoryInitializer);
    HEAPU8.set(data, STATIC_BASE);
  } else {
    addRunDependency('memory initializer');
    Browser.asyncLoad(memoryInitializer, function(data) {
      HEAPU8.set(data, STATIC_BASE);
      removeRunDependency('memory initializer');
    }, function(data) {
      throw 'could not load memory initializer ' + memoryInitializer;
    });
  }
}

function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun'] && shouldRunNow) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString(Module['thisProgram']), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);

  initialStackTop = STACKTOP;

  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    exit(ret);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return; 

    ensureInitRuntime();

    preMain();

    if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
      Module.printErr('pre-main prep time: ' + (Date.now() - preloadStartTime) + ' ms');
    }

    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status) {
  if (Module['noExitRuntime']) {
    return;
  }

  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;

  // exit the runtime
  exitRuntime();

  if (ENVIRONMENT_IS_NODE) {
    // Work around a node.js bug where stdout buffer is not flushed at process exit:
    // Instead of process.exit() directly, wait for stdout flush event.
    // See https://github.com/joyent/node/issues/1669 and https://github.com/kripken/emscripten/issues/2582
    // Workaround is based on https://github.com/RReverser/acorn/commit/50ab143cecc9ed71a2d66f78b4aec3bb2e9844f6
    process['stdout']['once']('drain', function () {
      process['exit'](status);
    });
    console.log(' '); // Make sure to print something to force the drain event to occur, in case the stdout buffer was empty.
    // Work around another node bug where sometimes 'drain' is never fired - make another effort
    // to emit the exit status, after a significant delay (if node hasn't fired drain by then, give up)
    setTimeout(function() {
      process['exit'](status);
    }, 500);
  } else
  if (ENVIRONMENT_IS_SHELL && typeof quit === 'function') {
    quit(status);
  }
  // if we reach here, we must throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.';

  throw 'abort() at ' + stackTrace() + extra;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}

Module["noExitRuntime"] = true;

run();

// {{POST_RUN_ADDITIONS}}






// {{MODULE_ADDITIONS}}



